{
 "cells": [
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "tags": [
     "remove_cell"
    ]
   },
   "outputs": [],
   "source": [
    "from textbook_utils import *"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Analyzing Shifts in $A$ and $\\alpha$"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Shifts in $A$ and their Effect on Output\n",
    "\n",
    "First, let us plot a 3D surface of the Cobb-Douglas production function. Output, $Y$, will go on the vertical (or $z$) axis. Capital and labor will go on the $y$ and $x$ axes, resp. The plot below plots the Cobb-Douglas function with $A=2$, also showing $A=1$ for reference."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {
    "tags": [
     "remove_input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<html>\n",
       "<head><meta charset=\"utf-8\" /></head>\n",
       "<body>\n",
       "    <div>\n",
       "            <script src=\"https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.5/MathJax.js?config=TeX-AMS-MML_SVG\"></script><script type=\"text/javascript\">if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}</script>\n",
       "                <script type=\"text/javascript\">window.PlotlyConfig = {MathJaxConfig: 'local'};</script>\n",
       "        <script type=\"text/javascript\">/**\n",
       "* plotly.js v1.49.1\n",
       "* Copyright 2012-2019, Plotly, Inc.\n",
       "* All rights reserved.\n",
       "* Licensed under the MIT license\n",
       "*/\n",
       "!function(t){if(\"object\"==typeof exports&&\"undefined\"!=typeof module)module.exports=t();else if(\"function\"==typeof define&&define.amd)define([],t);else{(\"undefined\"!=typeof window?window:\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:this).Plotly=t()}}(function(){return function(){return function t(e,r,n){function i(o,s){if(!r[o]){if(!e[o]){var l=\"function\"==typeof require&&require;if(!s&&l)return l(o,!0);if(a)return a(o,!0);var c=new Error(\"Cannot find module '\"+o+\"'\");throw c.code=\"MODULE_NOT_FOUND\",c}var u=r[o]={exports:{}};e[o][0].call(u.exports,function(t){return i(e[o][1][t]||t)},u,u.exports,t,e,r,n)}return r[o].exports}for(var a=\"function\"==typeof require&&require,o=0;o<n.length;o++)i(n[o]);return i}}()({1:[function(t,e,r){\"use strict\";var n=t(\"../src/lib\"),i={\"X,X div\":\"direction:ltr;font-family:'Open Sans', verdana, arial, sans-serif;margin:0;padding:0;\",\"X input,X button\":\"font-family:'Open Sans', verdana, arial, sans-serif;\",\"X input:focus,X button:focus\":\"outline:none;\",\"X a\":\"text-decoration:none;\",\"X a:hover\":\"text-decoration:none;\",\"X .crisp\":\"shape-rendering:crispEdges;\",\"X .user-select-none\":\"-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;\",\"X svg\":\"overflow:hidden;\",\"X svg a\":\"fill:#447adb;\",\"X svg a:hover\":\"fill:#3c6dc5;\",\"X .main-svg\":\"position:absolute;top:0;left:0;pointer-events:none;\",\"X .main-svg .draglayer\":\"pointer-events:all;\",\"X .cursor-default\":\"cursor:default;\",\"X .cursor-pointer\":\"cursor:pointer;\",\"X .cursor-crosshair\":\"cursor:crosshair;\",\"X .cursor-move\":\"cursor:move;\",\"X .cursor-col-resize\":\"cursor:col-resize;\",\"X .cursor-row-resize\":\"cursor:row-resize;\",\"X .cursor-ns-resize\":\"cursor:ns-resize;\",\"X .cursor-ew-resize\":\"cursor:ew-resize;\",\"X .cursor-sw-resize\":\"cursor:sw-resize;\",\"X .cursor-s-resize\":\"cursor:s-resize;\",\"X .cursor-se-resize\":\"cursor:se-resize;\",\"X .cursor-w-resize\":\"cursor:w-resize;\",\"X .cursor-e-resize\":\"cursor:e-resize;\",\"X .cursor-nw-resize\":\"cursor:nw-resize;\",\"X .cursor-n-resize\":\"cursor:n-resize;\",\"X .cursor-ne-resize\":\"cursor:ne-resize;\",\"X .cursor-grab\":\"cursor:-webkit-grab;cursor:grab;\",\"X .modebar\":\"position:absolute;top:2px;right:2px;\",\"X .ease-bg\":\"-webkit-transition:background-color 0.3s ease 0s;-moz-transition:background-color 0.3s ease 0s;-ms-transition:background-color 0.3s ease 0s;-o-transition:background-color 0.3s ease 0s;transition:background-color 0.3s ease 0s;\",\"X .modebar--hover>:not(.watermark)\":\"opacity:0;-webkit-transition:opacity 0.3s ease 0s;-moz-transition:opacity 0.3s ease 0s;-ms-transition:opacity 0.3s ease 0s;-o-transition:opacity 0.3s ease 0s;transition:opacity 0.3s ease 0s;\",\"X:hover .modebar--hover .modebar-group\":\"opacity:1;\",\"X .modebar-group\":\"float:left;display:inline-block;box-sizing:border-box;padding-left:8px;position:relative;vertical-align:middle;white-space:nowrap;\",\"X .modebar-btn\":\"position:relative;font-size:16px;padding:3px 4px;height:22px;cursor:pointer;line-height:normal;box-sizing:border-box;\",\"X .modebar-btn svg\":\"position:relative;top:2px;\",\"X .modebar.vertical\":\"display:flex;flex-direction:column;flex-wrap:wrap;align-content:flex-end;max-height:100%;\",\"X .modebar.vertical svg\":\"top:-1px;\",\"X .modebar.vertical .modebar-group\":\"display:block;float:none;padding-left:0px;padding-bottom:8px;\",\"X .modebar.vertical .modebar-group .modebar-btn\":\"display:block;text-align:center;\",\"X [data-title]:before,X [data-title]:after\":\"position:absolute;-webkit-transform:translate3d(0, 0, 0);-moz-transform:translate3d(0, 0, 0);-ms-transform:translate3d(0, 0, 0);-o-transform:translate3d(0, 0, 0);transform:translate3d(0, 0, 0);display:none;opacity:0;z-index:1001;pointer-events:none;top:110%;right:50%;\",\"X [data-title]:hover:before,X [data-title]:hover:after\":\"display:block;opacity:1;\",\"X [data-title]:before\":\"content:'';position:absolute;background:transparent;border:6px solid transparent;z-index:1002;margin-top:-12px;border-bottom-color:#69738a;margin-right:-6px;\",\"X [data-title]:after\":\"content:attr(data-title);background:#69738a;color:white;padding:8px 10px;font-size:12px;line-height:12px;white-space:nowrap;margin-right:-18px;border-radius:2px;\",\"X .vertical [data-title]:before,X .vertical [data-title]:after\":\"top:0%;right:200%;\",\"X .vertical [data-title]:before\":\"border:6px solid transparent;border-left-color:#69738a;margin-top:8px;margin-right:-30px;\",\"X .select-outline\":\"fill:none;stroke-width:1;shape-rendering:crispEdges;\",\"X .select-outline-1\":\"stroke:white;\",\"X .select-outline-2\":\"stroke:black;stroke-dasharray:2px 2px;\",Y:\"font-family:'Open Sans';position:fixed;top:50px;right:20px;z-index:10000;font-size:10pt;max-width:180px;\",\"Y p\":\"margin:0;\",\"Y .notifier-note\":\"min-width:180px;max-width:250px;border:1px solid #fff;z-index:3000;margin:0;background-color:#8c97af;background-color:rgba(140,151,175,0.9);color:#fff;padding:10px;overflow-wrap:break-word;word-wrap:break-word;-ms-hyphens:auto;-webkit-hyphens:auto;hyphens:auto;\",\"Y .notifier-close\":\"color:#fff;opacity:0.8;float:right;padding:0 5px;background:none;border:none;font-size:20px;font-weight:bold;line-height:20px;\",\"Y .notifier-close:hover\":\"color:#444;text-decoration:none;cursor:pointer;\"};for(var a in i){var o=a.replace(/^,/,\" ,\").replace(/X/g,\".js-plotly-plot .plotly\").replace(/Y/g,\".plotly-notifier\");n.addStyleRule(o,i[a])}},{\"../src/lib\":719}],2:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/aggregate\")},{\"../src/transforms/aggregate\":1265}],3:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/bar\")},{\"../src/traces/bar\":864}],4:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/barpolar\")},{\"../src/traces/barpolar\":876}],5:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/box\")},{\"../src/traces/box\":886}],6:[function(t,e,r){\"use strict\";e.exports=t(\"../src/components/calendars\")},{\"../src/components/calendars\":591}],7:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/candlestick\")},{\"../src/traces/candlestick\":895}],8:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/carpet\")},{\"../src/traces/carpet\":914}],9:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choropleth\")},{\"../src/traces/choropleth\":928}],10:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choroplethmapbox\")},{\"../src/traces/choroplethmapbox\":935}],11:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/cone\")},{\"../src/traces/cone\":941}],12:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contour\")},{\"../src/traces/contour\":956}],13:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contourcarpet\")},{\"../src/traces/contourcarpet\":967}],14:[function(t,e,r){\"use strict\";e.exports=t(\"../src/core\")},{\"../src/core\":697}],15:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/densitymapbox\")},{\"../src/traces/densitymapbox\":977}],16:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/filter\")},{\"../src/transforms/filter\":1266}],17:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnel\")},{\"../src/traces/funnel\":987}],18:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnelarea\")},{\"../src/traces/funnelarea\":996}],19:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/groupby\")},{\"../src/transforms/groupby\":1267}],20:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmap\")},{\"../src/traces/heatmap\":1009}],21:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmapgl\")},{\"../src/traces/heatmapgl\":1018}],22:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram\")},{\"../src/traces/histogram\":1030}],23:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2d\")},{\"../src/traces/histogram2d\":1036}],24:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2dcontour\")},{\"../src/traces/histogram2dcontour\":1040}],25:[function(t,e,r){\"use strict\";var n=t(\"./core\");n.register([t(\"./bar\"),t(\"./box\"),t(\"./heatmap\"),t(\"./histogram\"),t(\"./histogram2d\"),t(\"./histogram2dcontour\"),t(\"./contour\"),t(\"./scatterternary\"),t(\"./violin\"),t(\"./funnel\"),t(\"./waterfall\"),t(\"./pie\"),t(\"./sunburst\"),t(\"./funnelarea\"),t(\"./scatter3d\"),t(\"./surface\"),t(\"./isosurface\"),t(\"./volume\"),t(\"./mesh3d\"),t(\"./cone\"),t(\"./streamtube\"),t(\"./scattergeo\"),t(\"./choropleth\"),t(\"./scattergl\"),t(\"./splom\"),t(\"./pointcloud\"),t(\"./heatmapgl\"),t(\"./parcoords\"),t(\"./parcats\"),t(\"./scattermapbox\"),t(\"./choroplethmapbox\"),t(\"./densitymapbox\"),t(\"./sankey\"),t(\"./indicator\"),t(\"./table\"),t(\"./carpet\"),t(\"./scattercarpet\"),t(\"./contourcarpet\"),t(\"./ohlc\"),t(\"./candlestick\"),t(\"./scatterpolar\"),t(\"./scatterpolargl\"),t(\"./barpolar\")]),n.register([t(\"./aggregate\"),t(\"./filter\"),t(\"./groupby\"),t(\"./sort\")]),n.register([t(\"./calendars\")]),e.exports=n},{\"./aggregate\":2,\"./bar\":3,\"./barpolar\":4,\"./box\":5,\"./calendars\":6,\"./candlestick\":7,\"./carpet\":8,\"./choropleth\":9,\"./choroplethmapbox\":10,\"./cone\":11,\"./contour\":12,\"./contourcarpet\":13,\"./core\":14,\"./densitymapbox\":15,\"./filter\":16,\"./funnel\":17,\"./funnelarea\":18,\"./groupby\":19,\"./heatmap\":20,\"./heatmapgl\":21,\"./histogram\":22,\"./histogram2d\":23,\"./histogram2dcontour\":24,\"./indicator\":26,\"./isosurface\":27,\"./mesh3d\":28,\"./ohlc\":29,\"./parcats\":30,\"./parcoords\":31,\"./pie\":32,\"./pointcloud\":33,\"./sankey\":34,\"./scatter3d\":35,\"./scattercarpet\":36,\"./scattergeo\":37,\"./scattergl\":38,\"./scattermapbox\":39,\"./scatterpolar\":40,\"./scatterpolargl\":41,\"./scatterternary\":42,\"./sort\":43,\"./splom\":44,\"./streamtube\":45,\"./sunburst\":46,\"./surface\":47,\"./table\":48,\"./violin\":49,\"./volume\":50,\"./waterfall\":51}],26:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/indicator\")},{\"../src/traces/indicator\":1046}],27:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/isosurface\")},{\"../src/traces/isosurface\":1052}],28:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/mesh3d\")},{\"../src/traces/mesh3d\":1057}],29:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/ohlc\")},{\"../src/traces/ohlc\":1062}],30:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcats\")},{\"../src/traces/parcats\":1071}],31:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcoords\")},{\"../src/traces/parcoords\":1081}],32:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pie\")},{\"../src/traces/pie\":1092}],33:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pointcloud\")},{\"../src/traces/pointcloud\":1101}],34:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sankey\")},{\"../src/traces/sankey\":1107}],35:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatter3d\")},{\"../src/traces/scatter3d\":1143}],36:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattercarpet\")},{\"../src/traces/scattercarpet\":1149}],37:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergeo\")},{\"../src/traces/scattergeo\":1156}],38:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergl\")},{\"../src/traces/scattergl\":1167}],39:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattermapbox\")},{\"../src/traces/scattermapbox\":1176}],40:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolar\")},{\"../src/traces/scatterpolar\":1183}],41:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolargl\")},{\"../src/traces/scatterpolargl\":1189}],42:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterternary\")},{\"../src/traces/scatterternary\":1196}],43:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/sort\")},{\"../src/transforms/sort\":1269}],44:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/splom\")},{\"../src/traces/splom\":1205}],45:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/streamtube\")},{\"../src/traces/streamtube\":1213}],46:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sunburst\")},{\"../src/traces/sunburst\":1219}],47:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/surface\")},{\"../src/traces/surface\":1228}],48:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/table\")},{\"../src/traces/table\":1236}],49:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/violin\")},{\"../src/traces/violin\":1244}],50:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/volume\")},{\"../src/traces/volume\":1252}],51:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/waterfall\")},{\"../src/traces/waterfall\":1260}],52:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).eye||[0,0,1],r=t.center||[0,0,0],s=t.up||[0,1,0],l=t.distanceLimits||[0,1/0],c=t.mode||\"turntable\",u=n(),h=i(),f=a();return u.setDistanceLimits(l[0],l[1]),u.lookAt(0,e,r,s),h.setDistanceLimits(l[0],l[1]),h.lookAt(0,e,r,s),f.setDistanceLimits(l[0],l[1]),f.lookAt(0,e,r,s),new o({turntable:u,orbit:h,matrix:f},c)};var n=t(\"turntable-camera-controller\"),i=t(\"orbit-camera-controller\"),a=t(\"matrix-camera-controller\");function o(t,e){this._controllerNames=Object.keys(t),this._controllerList=this._controllerNames.map(function(e){return t[e]}),this._mode=e,this._active=t[e],this._active||(this._mode=\"turntable\",this._active=t.turntable),this.modes=this._controllerNames,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}var s=o.prototype;[[\"flush\",1],[\"idle\",1],[\"lookAt\",4],[\"rotate\",4],[\"pan\",4],[\"translate\",4],[\"setMatrix\",2],[\"setDistanceLimits\",2],[\"setDistance\",2]].forEach(function(t){for(var e=t[0],r=[],n=0;n<t[1];++n)r.push(\"a\"+n);var i=\"var cc=this._controllerList;for(var i=0;i<cc.length;++i){cc[i].\"+t[0]+\"(\"+r.join()+\")}\";s[e]=Function.apply(null,r.concat(i))}),s.recalcMatrix=function(t){this._active.recalcMatrix(t)},s.getDistance=function(t){return this._active.getDistance(t)},s.getDistanceLimits=function(t){return this._active.getDistanceLimits(t)},s.lastT=function(){return this._active.lastT()},s.setMode=function(t){if(t!==this._mode){var e=this._controllerNames.indexOf(t);if(!(e<0)){var r=this._active,n=this._controllerList[e],i=Math.max(r.lastT(),n.lastT());r.recalcMatrix(i),n.setMatrix(i,r.computedMatrix),this._active=n,this._mode=t,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}}},s.getMode=function(){return this._mode}},{\"matrix-camera-controller\":433,\"orbit-camera-controller\":456,\"turntable-camera-controller\":542}],53:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n,i){\"use strict\";function a(t){return t.target.depth}function o(t,e){return t.sourceLinks.length?t.depth:e-1}function s(t){return function(){return t}}i=i&&i.hasOwnProperty(\"default\")?i.default:i;var l=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&\"function\"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?\"symbol\":typeof t};function c(t,e){return h(t.source,e.source)||t.index-e.index}function u(t,e){return h(t.target,e.target)||t.index-e.index}function h(t,e){return t.partOfCycle===e.partOfCycle?t.y0-e.y0:\"top\"===t.circularLinkType||\"bottom\"===e.circularLinkType?-1:1}function f(t){return t.value}function p(t){return(t.y0+t.y1)/2}function d(t){return p(t.source)}function g(t){return p(t.target)}function v(t){return t.index}function m(t){return t.nodes}function y(t){return t.links}function x(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function b(t,e){return e(t)}var _=25,w=10,k=.3;function T(t,e){var r=0,n=0;t.links.forEach(function(i){i.circular&&(i.source.circularLinkType||i.target.circularLinkType?i.circularLinkType=i.source.circularLinkType?i.source.circularLinkType:i.target.circularLinkType:i.circularLinkType=r<n?\"top\":\"bottom\",\"top\"==i.circularLinkType?r+=1:n+=1,t.nodes.forEach(function(t){b(t,e)!=b(i.source,e)&&b(t,e)!=b(i.target,e)||(t.circularLinkType=i.circularLinkType)}))}),t.links.forEach(function(t){t.circular&&(t.source.circularLinkType==t.target.circularLinkType&&(t.circularLinkType=t.source.circularLinkType),Y(t,e)&&(t.circularLinkType=t.source.circularLinkType))})}function A(t){var e=Math.abs(t.y1-t.y0),r=Math.abs(t.target.x0-t.source.x1);return Math.atan(r/e)}function M(t,e){var r=0;t.sourceLinks.forEach(function(t){r=t.circular&&!Y(t,e)?r+1:r});var n=0;return t.targetLinks.forEach(function(t){n=t.circular&&!Y(t,e)?n+1:n}),r+n}function S(t){var e=t.source.sourceLinks,r=0;e.forEach(function(t){r=t.circular?r+1:r});var n=t.target.targetLinks,i=0;return n.forEach(function(t){i=t.circular?i+1:i}),!(r>1||i>1)}function E(t,e,r){return t.sort(L),t.forEach(function(n,i){var a,o,s=0;if(Y(n,r)&&S(n))n.circularPathData.verticalBuffer=s+n.width/2;else{for(var l=0;l<i;l++)if(a=t[i],o=t[l],!(a.source.column<o.target.column||a.target.column>o.source.column)){var c=t[l].circularPathData.verticalBuffer+t[l].width/2+e;s=c>s?c:s}n.circularPathData.verticalBuffer=s+n.width/2}}),t}function C(t,r,i,a){var o=e.min(t.links,function(t){return t.source.y0});t.links.forEach(function(t){t.circular&&(t.circularPathData={})}),E(t.links.filter(function(t){return\"top\"==t.circularLinkType}),r,a),E(t.links.filter(function(t){return\"bottom\"==t.circularLinkType}),r,a),t.links.forEach(function(e){if(e.circular){if(e.circularPathData.arcRadius=e.width+w,e.circularPathData.leftNodeBuffer=5,e.circularPathData.rightNodeBuffer=5,e.circularPathData.sourceWidth=e.source.x1-e.source.x0,e.circularPathData.sourceX=e.source.x0+e.circularPathData.sourceWidth,e.circularPathData.targetX=e.target.x0,e.circularPathData.sourceY=e.y0,e.circularPathData.targetY=e.y1,Y(e,a)&&S(e))e.circularPathData.leftSmallArcRadius=w+e.width/2,e.circularPathData.leftLargeArcRadius=w+e.width/2,e.circularPathData.rightSmallArcRadius=w+e.width/2,e.circularPathData.rightLargeArcRadius=w+e.width/2,\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=e.source.y1+_+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=e.source.y0-_-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius);else{var s=e.source.column,l=e.circularLinkType,c=t.links.filter(function(t){return t.source.column==s&&t.circularLinkType==l});\"bottom\"==e.circularLinkType?c.sort(O):c.sort(P);var u=0;c.forEach(function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.leftSmallArcRadius=w+e.width/2+u,e.circularPathData.leftLargeArcRadius=w+e.width/2+n*r+u),u+=t.width}),s=e.target.column,c=t.links.filter(function(t){return t.target.column==s&&t.circularLinkType==l}),\"bottom\"==e.circularLinkType?c.sort(I):c.sort(z),u=0,c.forEach(function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.rightSmallArcRadius=w+e.width/2+u,e.circularPathData.rightLargeArcRadius=w+e.width/2+n*r+u),u+=t.width}),\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=Math.max(i,e.source.y1,e.target.y1)+_+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=o-_-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius)}e.circularPathData.leftInnerExtent=e.circularPathData.sourceX+e.circularPathData.leftNodeBuffer,e.circularPathData.rightInnerExtent=e.circularPathData.targetX-e.circularPathData.rightNodeBuffer,e.circularPathData.leftFullExtent=e.circularPathData.sourceX+e.circularPathData.leftLargeArcRadius+e.circularPathData.leftNodeBuffer,e.circularPathData.rightFullExtent=e.circularPathData.targetX-e.circularPathData.rightLargeArcRadius-e.circularPathData.rightNodeBuffer}if(e.circular)e.path=function(t){var e=\"\";e=\"top\"==t.circularLinkType?\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 0 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY-t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 0 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 0 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY-t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 0 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY:\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 1 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY+t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 1 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 1 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY+t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 1 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY;return e}(e);else{var h=n.linkHorizontal().source(function(t){return[t.source.x0+(t.source.x1-t.source.x0),t.y0]}).target(function(t){return[t.target.x0,t.y1]});e.path=h(e)}})}function L(t,e){return D(t)==D(e)?\"bottom\"==t.circularLinkType?O(t,e):P(t,e):D(e)-D(t)}function P(t,e){return t.y0-e.y0}function O(t,e){return e.y0-t.y0}function z(t,e){return t.y1-e.y1}function I(t,e){return e.y1-t.y1}function D(t){return t.target.column-t.source.column}function R(t){return t.target.x0-t.source.x1}function F(t,e){var r=A(t),n=R(e)/Math.tan(r);return\"up\"==G(t)?t.y1+n:t.y1-n}function B(t,e){var r=A(t),n=R(e)/Math.tan(r);return\"up\"==G(t)?t.y1-n:t.y1+n}function N(t,e,r,n){t.links.forEach(function(i){if(!i.circular&&i.target.column-i.source.column>1){var a=i.source.column+1,o=i.target.column-1,s=1,l=o-a+1;for(s=1;a<=o;a++,s++)t.nodes.forEach(function(o){if(o.column==a){var c,u=s/(l+1),h=Math.pow(1-u,3),f=3*u*Math.pow(1-u,2),p=3*Math.pow(u,2)*(1-u),d=Math.pow(u,3),g=h*i.y0+f*i.y0+p*i.y1+d*i.y1,v=g-i.width/2,m=g+i.width/2;v>o.y0&&v<o.y1?(c=o.y1-v+10,c=\"bottom\"==o.circularLinkType?c:-c,o=U(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&j(o,t)&&U(t,c,e,r)})):m>o.y0&&m<o.y1?(c=m-o.y0+10,o=U(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&U(t,c,e,r)})):v<o.y0&&m>o.y1&&(c=m-o.y0+10,o=U(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&U(t,c,e,r)}))}})}})}function j(t,e){return t.y0>e.y0&&t.y0<e.y1||(t.y1>e.y0&&t.y1<e.y1||t.y0<e.y0&&t.y1>e.y1)}function U(t,e,r,n){return t.y0+e>=r&&t.y1+e<=n&&(t.y0=t.y0+e,t.y1=t.y1+e,t.targetLinks.forEach(function(t){t.y1=t.y1+e}),t.sourceLinks.forEach(function(t){t.y0=t.y0+e})),t}function V(t,e,r,n){t.nodes.forEach(function(i){n&&i.y+(i.y1-i.y0)>e&&(i.y=i.y-(i.y+(i.y1-i.y0)-e));var a=t.links.filter(function(t){return b(t.source,r)==b(i,r)}),o=a.length;o>1&&a.sort(function(t,e){if(!t.circular&&!e.circular){if(t.target.column==e.target.column)return t.y1-e.y1;if(!H(t,e))return t.y1-e.y1;if(t.target.column>e.target.column){var r=B(e,t);return t.y1-r}if(e.target.column>t.target.column)return B(t,e)-e.y1}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.target.column===e.target.column?t.target.y1-e.target.y1:e.target.column-t.target.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.target.column===e.target.column?e.target.y1-t.target.y1:t.target.column-e.target.column:\"top\"==t.circularLinkType?-1:1:void 0});var s=i.y0;a.forEach(function(t){t.y0=s+t.width/2,s+=t.width}),a.forEach(function(t,e){if(\"bottom\"==t.circularLinkType){for(var r=e+1,n=0;r<o;r++)n+=a[r].width;t.y0=i.y1-n-t.width/2}})})}function q(t,e,r){t.nodes.forEach(function(e){var n=t.links.filter(function(t){return b(t.target,r)==b(e,r)}),i=n.length;i>1&&n.sort(function(t,e){if(!t.circular&&!e.circular){if(t.source.column==e.source.column)return t.y0-e.y0;if(!H(t,e))return t.y0-e.y0;if(e.source.column<t.source.column){var r=F(e,t);return t.y0-r}if(t.source.column<e.source.column)return F(t,e)-e.y0}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:t.source.column-e.source.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:e.source.column-t.source.column:\"top\"==t.circularLinkType?-1:1:void 0});var a=e.y0;n.forEach(function(t){t.y1=a+t.width/2,a+=t.width}),n.forEach(function(t,r){if(\"bottom\"==t.circularLinkType){for(var a=r+1,o=0;a<i;a++)o+=n[a].width;t.y1=e.y1-o-t.width/2}})})}function H(t,e){return G(t)==G(e)}function G(t){return t.y0-t.y1>0?\"up\":\"down\"}function Y(t,e){return b(t.source,e)==b(t.target,e)}t.sankeyCircular=function(){var t,n,a=0,b=0,A=1,S=1,E=24,L=v,P=o,O=m,z=y,I=32,D=2,R=null;function F(){var o={nodes:O.apply(null,arguments),links:z.apply(null,arguments)};!function(t){t.nodes.forEach(function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]});var e=r.map(t.nodes,L);t.links.forEach(function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!==(\"undefined\"==typeof n?\"undefined\":l(n))&&(n=t.source=x(e,n)),\"object\"!==(\"undefined\"==typeof i?\"undefined\":l(i))&&(i=t.target=x(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)})}(o),function(t,e,r){var n=0;if(null===r){for(var a=[],o=0;o<t.links.length;o++){var s=t.links[o],l=s.source.index,c=s.target.index;a[l]||(a[l]=[]),a[c]||(a[c]=[]),-1===a[l].indexOf(c)&&a[l].push(c)}var u=i(a);u.sort(function(t,e){return t.length-e.length});var h={};for(o=0;o<u.length;o++){var f=u[o],p=f.slice(-2);h[p[0]]||(h[p[0]]={}),h[p[0]][p[1]]=!0}t.links.forEach(function(t){var e=t.target.index,r=t.source.index;e===r||h[r]&&h[r][e]?(t.circular=!0,t.circularLinkID=n,n+=1):t.circular=!1})}else t.links.forEach(function(t){t.source[r]<t.target[r]?t.circular=!1:(t.circular=!0,t.circularLinkID=n,n+=1)})}(o,0,R),function(t){t.nodes.forEach(function(t){t.partOfCycle=!1,t.value=Math.max(e.sum(t.sourceLinks,f),e.sum(t.targetLinks,f)),t.sourceLinks.forEach(function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)}),t.targetLinks.forEach(function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)})})}(o),function(t){var e,r,n;for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach(function(t){t.depth=n,t.sourceLinks.forEach(function(t){r.indexOf(t.target)<0&&!t.circular&&r.push(t.target)})});for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach(function(t){t.height=n,t.targetLinks.forEach(function(t){r.indexOf(t.source)<0&&!t.circular&&r.push(t.source)})});t.nodes.forEach(function(t){t.column=Math.floor(P.call(null,t,n))})}(o),T(o,L),function(i,o,s){var l=r.nest().key(function(t){return t.column}).sortKeys(e.ascending).entries(i.nodes).map(function(t){return t.values});(function(r){if(n){var o=1/0;l.forEach(function(t){var e=S*n/(t.length+1);o=e<o?e:o}),t=o}var s=e.min(l,function(r){return(S-b-(r.length-1)*t)/e.sum(r,f)});s*=k,i.links.forEach(function(t){t.width=t.value*s});var c=function(t){var r=0,n=0,i=0,a=0,o=e.max(t.nodes,function(t){return t.column});return t.links.forEach(function(t){t.circular&&(\"top\"==t.circularLinkType?r+=t.width:n+=t.width,0==t.target.column&&(a+=t.width),t.source.column==o&&(i+=t.width))}),{top:r=r>0?r+_+w:r,bottom:n=n>0?n+_+w:n,left:a=a>0?a+_+w:a,right:i=i>0?i+_+w:i}}(i),u=function(t,r){var n=e.max(t.nodes,function(t){return t.column}),i=A-a,o=S-b,s=i+r.right+r.left,l=o+r.top+r.bottom,c=i/s,u=o/l;return a=a*c+r.left,A=0==r.right?A:A*c,b=b*u+r.top,S*=u,t.nodes.forEach(function(t){t.x0=a+t.column*((A-a-E)/n),t.x1=t.x0+E}),u}(i,c);s*=u,i.links.forEach(function(t){t.width=t.value*s}),l.forEach(function(t){var e=t.length;t.forEach(function(t,n){t.depth==l.length-1&&1==e?(t.y0=S/2-t.value*s,t.y1=t.y0+t.value*s):0==t.depth&&1==e?(t.y0=S/2-t.value*s,t.y1=t.y0+t.value*s):t.partOfCycle?0==M(t,r)?(t.y0=S/2+n,t.y1=t.y0+t.value*s):\"top\"==t.circularLinkType?(t.y0=b+n,t.y1=t.y0+t.value*s):(t.y0=S-t.value*s-n,t.y1=t.y0+t.value*s):0==c.top||0==c.bottom?(t.y0=(S-b)/e*n,t.y1=t.y0+t.value*s):(t.y0=(S-b)/2-e/2+n,t.y1=t.y0+t.value*s)})})})(s),m();for(var c=1,u=o;u>0;--u)v(c*=.99,s),m();function v(t,r){var n=l.length;l.forEach(function(i){var a=i.length,o=i[0].depth;i.forEach(function(i){var s;if(i.sourceLinks.length||i.targetLinks.length)if(i.partOfCycle&&M(i,r)>0);else if(0==o&&1==a)s=i.y1-i.y0,i.y0=S/2-s/2,i.y1=S/2+s/2;else if(o==n-1&&1==a)s=i.y1-i.y0,i.y0=S/2-s/2,i.y1=S/2+s/2;else{var l=e.mean(i.sourceLinks,g),c=e.mean(i.targetLinks,d),u=((l&&c?(l+c)/2:l||c)-p(i))*t;i.y0+=u,i.y1+=u}})})}function m(){l.forEach(function(e){var r,n,i,a=b,o=e.length;for(e.sort(h),i=0;i<o;++i)r=e[i],(n=a-r.y0)>0&&(r.y0+=n,r.y1+=n),a=r.y1+t;if((n=a-t-S)>0)for(a=r.y0-=n,r.y1-=n,i=o-2;i>=0;--i)r=e[i],(n=r.y1+t-a)>0&&(r.y0-=n,r.y1-=n),a=r.y0})}}(o,I,L),B(o);for(var s=0;s<4;s++)V(o,S,L),q(o,0,L),N(o,b,S,L),V(o,S,L),q(o,0,L);return function(t,r,n){var i=t.nodes,a=t.links,o=!1,s=!1;if(a.forEach(function(t){\"top\"==t.circularLinkType?o=!0:\"bottom\"==t.circularLinkType&&(s=!0)}),0==o||0==s){var l=e.min(i,function(t){return t.y0}),c=e.max(i,function(t){return t.y1}),u=c-l,h=n-r,f=h/u;i.forEach(function(t){var e=(t.y1-t.y0)*f;t.y0=(t.y0-l)*f,t.y1=t.y0+e}),a.forEach(function(t){t.y0=(t.y0-l)*f,t.y1=(t.y1-l)*f,t.width=t.width*f})}}(o,b,S),C(o,D,S,L),o}function B(t){t.nodes.forEach(function(t){t.sourceLinks.sort(u),t.targetLinks.sort(c)}),t.nodes.forEach(function(t){var e=t.y0,r=e,n=t.y1,i=n;t.sourceLinks.forEach(function(t){t.circular?(t.y0=n-t.width/2,n-=t.width):(t.y0=e+t.width/2,e+=t.width)}),t.targetLinks.forEach(function(t){t.circular?(t.y1=i-t.width/2,i-=t.width):(t.y1=r+t.width/2,r+=t.width)})})}return F.nodeId=function(t){return arguments.length?(L=\"function\"==typeof t?t:s(t),F):L},F.nodeAlign=function(t){return arguments.length?(P=\"function\"==typeof t?t:s(t),F):P},F.nodeWidth=function(t){return arguments.length?(E=+t,F):E},F.nodePadding=function(e){return arguments.length?(t=+e,F):t},F.nodes=function(t){return arguments.length?(O=\"function\"==typeof t?t:s(t),F):O},F.links=function(t){return arguments.length?(z=\"function\"==typeof t?t:s(t),F):z},F.size=function(t){return arguments.length?(a=b=0,A=+t[0],S=+t[1],F):[A-a,S-b]},F.extent=function(t){return arguments.length?(a=+t[0][0],A=+t[1][0],b=+t[0][1],S=+t[1][1],F):[[a,b],[A,S]]},F.iterations=function(t){return arguments.length?(I=+t,F):I},F.circularLinkGap=function(t){return arguments.length?(D=+t,F):D},F.nodePaddingRatio=function(t){return arguments.length?(n=+t,F):n},F.sortNodes=function(t){return arguments.length?(R=t,F):R},F.update=function(t){return T(t,L),B(t),t.links.forEach(function(t){t.circular&&(t.circularLinkType=t.y0+t.y1<S?\"top\":\"bottom\",t.source.circularLinkType=t.circularLinkType,t.target.circularLinkType=t.circularLinkType)}),V(t,S,L,!1),q(t,0,L),C(t,D,S,L),t},F},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,a)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=o,Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\"),t(\"elementary-circuits-directed-graph\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,null)},{\"d3-array\":152,\"d3-collection\":153,\"d3-shape\":161,\"elementary-circuits-directed-graph\":172}],54:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n){\"use strict\";function i(t){return t.target.depth}function a(t,e){return t.sourceLinks.length?t.depth:e-1}function o(t){return function(){return t}}function s(t,e){return c(t.source,e.source)||t.index-e.index}function l(t,e){return c(t.target,e.target)||t.index-e.index}function c(t,e){return t.y0-e.y0}function u(t){return t.value}function h(t){return(t.y0+t.y1)/2}function f(t){return h(t.source)*t.value}function p(t){return h(t.target)*t.value}function d(t){return t.index}function g(t){return t.nodes}function v(t){return t.links}function m(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function y(t){return[t.source.x1,t.y0]}function x(t){return[t.target.x0,t.y1]}t.sankey=function(){var t=0,n=0,i=1,y=1,x=24,b=8,_=d,w=a,k=g,T=v,A=32,M=2/3;function S(){var a={nodes:k.apply(null,arguments),links:T.apply(null,arguments)};return function(t){t.nodes.forEach(function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]});var e=r.map(t.nodes,_);t.links.forEach(function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!=typeof n&&(n=t.source=m(e,n)),\"object\"!=typeof i&&(i=t.target=m(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)})}(a),function(t){t.nodes.forEach(function(t){t.value=Math.max(e.sum(t.sourceLinks,u),e.sum(t.targetLinks,u))})}(a),function(e){var r,n,a;for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach(function(t){t.depth=a,t.sourceLinks.forEach(function(t){n.indexOf(t.target)<0&&n.push(t.target)})});for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach(function(t){t.height=a,t.targetLinks.forEach(function(t){n.indexOf(t.source)<0&&n.push(t.source)})});var o=(i-t-x)/(a-1);e.nodes.forEach(function(e){e.x1=(e.x0=t+Math.max(0,Math.min(a-1,Math.floor(w.call(null,e,a))))*o)+x})}(a),function(t){var i=r.nest().key(function(t){return t.x0}).sortKeys(e.ascending).entries(t.nodes).map(function(t){return t.values});(function(){var r=e.max(i,function(t){return t.length}),a=M*(y-n)/(r-1);b>a&&(b=a);var o=e.min(i,function(t){return(y-n-(t.length-1)*b)/e.sum(t,u)});i.forEach(function(t){t.forEach(function(t,e){t.y1=(t.y0=e)+t.value*o})}),t.links.forEach(function(t){t.width=t.value*o})})(),d();for(var a=1,o=A;o>0;--o)l(a*=.99),d(),s(a),d();function s(t){i.forEach(function(r){r.forEach(function(r){if(r.targetLinks.length){var n=(e.sum(r.targetLinks,f)/e.sum(r.targetLinks,u)-h(r))*t;r.y0+=n,r.y1+=n}})})}function l(t){i.slice().reverse().forEach(function(r){r.forEach(function(r){if(r.sourceLinks.length){var n=(e.sum(r.sourceLinks,p)/e.sum(r.sourceLinks,u)-h(r))*t;r.y0+=n,r.y1+=n}})})}function d(){i.forEach(function(t){var e,r,i,a=n,o=t.length;for(t.sort(c),i=0;i<o;++i)e=t[i],(r=a-e.y0)>0&&(e.y0+=r,e.y1+=r),a=e.y1+b;if((r=a-b-y)>0)for(a=e.y0-=r,e.y1-=r,i=o-2;i>=0;--i)e=t[i],(r=e.y1+b-a)>0&&(e.y0-=r,e.y1-=r),a=e.y0})}}(a),E(a),a}function E(t){t.nodes.forEach(function(t){t.sourceLinks.sort(l),t.targetLinks.sort(s)}),t.nodes.forEach(function(t){var e=t.y0,r=e;t.sourceLinks.forEach(function(t){t.y0=e+t.width/2,e+=t.width}),t.targetLinks.forEach(function(t){t.y1=r+t.width/2,r+=t.width})})}return S.update=function(t){return E(t),t},S.nodeId=function(t){return arguments.length?(_=\"function\"==typeof t?t:o(t),S):_},S.nodeAlign=function(t){return arguments.length?(w=\"function\"==typeof t?t:o(t),S):w},S.nodeWidth=function(t){return arguments.length?(x=+t,S):x},S.nodePadding=function(t){return arguments.length?(b=+t,S):b},S.nodes=function(t){return arguments.length?(k=\"function\"==typeof t?t:o(t),S):k},S.links=function(t){return arguments.length?(T=\"function\"==typeof t?t:o(t),S):T},S.size=function(e){return arguments.length?(t=n=0,i=+e[0],y=+e[1],S):[i-t,y-n]},S.extent=function(e){return arguments.length?(t=+e[0][0],i=+e[1][0],n=+e[0][1],y=+e[1][1],S):[[t,n],[i,y]]},S.iterations=function(t){return arguments.length?(A=+t,S):A},S},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,i)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=a,t.sankeyLinkHorizontal=function(){return n.linkHorizontal().source(y).target(x)},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3)},{\"d3-array\":152,\"d3-collection\":153,\"d3-shape\":161}],55:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\"),i=6378137;function a(t){var e=0;if(t&&t.length>0){e+=Math.abs(o(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(o(t[r]))}return e}function o(t){var e,r,n,a,o,l,c=0,u=t.length;if(u>2){for(l=0;l<u;l++)l===u-2?(n=u-2,a=u-1,o=0):l===u-1?(n=u-1,a=0,o=1):(n=l,a=l+1,o=l+2),e=t[n],r=t[a],c+=(s(t[o][0])-s(e[0]))*Math.sin(s(r[1]));c=c*i*i/2}return c}function s(t){return t*Math.PI/180}r.default=function(t){return n.geomReduce(t,function(t,e){return t+function(t){var e,r=0;switch(t.type){case\"Polygon\":return a(t.coordinates);case\"MultiPolygon\":for(e=0;e<t.coordinates.length;e++)r+=a(t.coordinates[e]);return r;case\"Point\":case\"MultiPoint\":case\"LineString\":case\"MultiLineString\":return 0}return 0}(e)},0)}},{\"@turf/meta\":58}],56:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\"),i=t(\"@turf/helpers\");r.default=function(t,e){void 0===e&&(e={});var r=0,a=0,o=0;return n.coordEach(t,function(t){r+=t[0],a+=t[1],o++}),i.point([r/o,a/o],e.properties)}},{\"@turf/helpers\":57,\"@turf/meta\":58}],57:[function(t,e,r){\"use strict\";function n(t,e,r){void 0===r&&(r={});var n={type:\"Feature\"};return(0===r.id||r.id)&&(n.id=r.id),r.bbox&&(n.bbox=r.bbox),n.properties=e||{},n.geometry=t,n}function i(t,e,r){return void 0===r&&(r={}),n({type:\"Point\",coordinates:t},e,r)}function a(t,e,r){void 0===r&&(r={});for(var i=0,a=t;i<a.length;i++){var o=a[i];if(o.length<4)throw new Error(\"Each LinearRing of a Polygon must have 4 or more Positions.\");for(var s=0;s<o[o.length-1].length;s++)if(o[o.length-1][s]!==o[0][s])throw new Error(\"First and last Position are not equivalent.\")}return n({type:\"Polygon\",coordinates:t},e,r)}function o(t,e,r){if(void 0===r&&(r={}),t.length<2)throw new Error(\"coordinates must be an array of two or more positions\");return n({type:\"LineString\",coordinates:t},e,r)}function s(t,e){void 0===e&&(e={});var r={type:\"FeatureCollection\"};return e.id&&(r.id=e.id),e.bbox&&(r.bbox=e.bbox),r.features=t,r}function l(t,e,r){return void 0===r&&(r={}),n({type:\"MultiLineString\",coordinates:t},e,r)}function c(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPoint\",coordinates:t},e,r)}function u(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPolygon\",coordinates:t},e,r)}function h(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t*n}function f(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t/n}function p(t){return 180*(t%(2*Math.PI))/Math.PI}function d(t){return!isNaN(t)&&null!==t&&!Array.isArray(t)&&!/^\\s*$/.test(t)}Object.defineProperty(r,\"__esModule\",{value:!0}),r.earthRadius=6371008.8,r.factors={centimeters:100*r.earthRadius,centimetres:100*r.earthRadius,degrees:r.earthRadius/111325,feet:3.28084*r.earthRadius,inches:39.37*r.earthRadius,kilometers:r.earthRadius/1e3,kilometres:r.earthRadius/1e3,meters:r.earthRadius,metres:r.earthRadius,miles:r.earthRadius/1609.344,millimeters:1e3*r.earthRadius,millimetres:1e3*r.earthRadius,nauticalmiles:r.earthRadius/1852,radians:1,yards:r.earthRadius/1.0936},r.unitsFactors={centimeters:100,centimetres:100,degrees:1/111325,feet:3.28084,inches:39.37,kilometers:.001,kilometres:.001,meters:1,metres:1,miles:1/1609.344,millimeters:1e3,millimetres:1e3,nauticalmiles:1/1852,radians:1/r.earthRadius,yards:1/1.0936},r.areaFactors={acres:247105e-9,centimeters:1e4,centimetres:1e4,feet:10.763910417,inches:1550.003100006,kilometers:1e-6,kilometres:1e-6,meters:1,metres:1,miles:3.86e-7,millimeters:1e6,millimetres:1e6,yards:1.195990046},r.feature=n,r.geometry=function(t,e,r){switch(void 0===r&&(r={}),t){case\"Point\":return i(e).geometry;case\"LineString\":return o(e).geometry;case\"Polygon\":return a(e).geometry;case\"MultiPoint\":return c(e).geometry;case\"MultiLineString\":return l(e).geometry;case\"MultiPolygon\":return u(e).geometry;default:throw new Error(t+\" is invalid\")}},r.point=i,r.points=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return i(t,e)}),r)},r.polygon=a,r.polygons=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return a(t,e)}),r)},r.lineString=o,r.lineStrings=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return o(t,e)}),r)},r.featureCollection=s,r.multiLineString=l,r.multiPoint=c,r.multiPolygon=u,r.geometryCollection=function(t,e,r){return void 0===r&&(r={}),n({type:\"GeometryCollection\",geometries:t},e,r)},r.round=function(t,e){if(void 0===e&&(e=0),e&&!(e>=0))throw new Error(\"precision must be a positive number\");var r=Math.pow(10,e||0);return Math.round(t*r)/r},r.radiansToLength=h,r.lengthToRadians=f,r.lengthToDegrees=function(t,e){return p(f(t,e))},r.bearingToAzimuth=function(t){var e=t%360;return e<0&&(e+=360),e},r.radiansToDegrees=p,r.degreesToRadians=function(t){return t%360*Math.PI/180},r.convertLength=function(t,e,r){if(void 0===e&&(e=\"kilometers\"),void 0===r&&(r=\"kilometers\"),!(t>=0))throw new Error(\"length must be a positive number\");return h(f(t,e),r)},r.convertArea=function(t,e,n){if(void 0===e&&(e=\"meters\"),void 0===n&&(n=\"kilometers\"),!(t>=0))throw new Error(\"area must be a positive number\");var i=r.areaFactors[e];if(!i)throw new Error(\"invalid original units\");var a=r.areaFactors[n];if(!a)throw new Error(\"invalid final units\");return t/i*a},r.isNumber=d,r.isObject=function(t){return!!t&&t.constructor===Object},r.validateBBox=function(t){if(!t)throw new Error(\"bbox is required\");if(!Array.isArray(t))throw new Error(\"bbox must be an Array\");if(4!==t.length&&6!==t.length)throw new Error(\"bbox must be an Array of 4 or 6 numbers\");t.forEach(function(t){if(!d(t))throw new Error(\"bbox must only contain numbers\")})},r.validateId=function(t){if(!t)throw new Error(\"id is required\");if(-1===[\"string\",\"number\"].indexOf(typeof t))throw new Error(\"id must be a number or a string\")},r.radians2degrees=function(){throw new Error(\"method has been renamed to `radiansToDegrees`\")},r.degrees2radians=function(){throw new Error(\"method has been renamed to `degreesToRadians`\")},r.distanceToDegrees=function(){throw new Error(\"method has been renamed to `lengthToDegrees`\")},r.distanceToRadians=function(){throw new Error(\"method has been renamed to `lengthToRadians`\")},r.radiansToDistance=function(){throw new Error(\"method has been renamed to `radiansToLength`\")},r.bearingToAngle=function(){throw new Error(\"method has been renamed to `bearingToAzimuth`\")},r.convertDistance=function(){throw new Error(\"method has been renamed to `convertLength`\")}},{}],58:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/helpers\");function i(t,e,r){if(null!==t)for(var n,a,o,s,l,c,u,h,f=0,p=0,d=t.type,g=\"FeatureCollection\"===d,v=\"Feature\"===d,m=g?t.features.length:1,y=0;y<m;y++){l=(h=!!(u=g?t.features[y].geometry:v?t.geometry:t)&&\"GeometryCollection\"===u.type)?u.geometries.length:1;for(var x=0;x<l;x++){var b=0,_=0;if(null!==(s=h?u.geometries[x]:u)){c=s.coordinates;var w=s.type;switch(f=!r||\"Polygon\"!==w&&\"MultiPolygon\"!==w?0:1,w){case null:break;case\"Point\":if(!1===e(c,p,y,b,_))return!1;p++,b++;break;case\"LineString\":case\"MultiPoint\":for(n=0;n<c.length;n++){if(!1===e(c[n],p,y,b,_))return!1;p++,\"MultiPoint\"===w&&b++}\"LineString\"===w&&b++;break;case\"Polygon\":case\"MultiLineString\":for(n=0;n<c.length;n++){for(a=0;a<c[n].length-f;a++){if(!1===e(c[n][a],p,y,b,_))return!1;p++}\"MultiLineString\"===w&&b++,\"Polygon\"===w&&_++}\"Polygon\"===w&&b++;break;case\"MultiPolygon\":for(n=0;n<c.length;n++){for(_=0,a=0;a<c[n].length;a++){for(o=0;o<c[n][a].length-f;o++){if(!1===e(c[n][a][o],p,y,b,_))return!1;p++}_++}b++}break;case\"GeometryCollection\":for(n=0;n<s.geometries.length;n++)if(!1===i(s.geometries[n],e,r))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}}}}}function a(t,e){var r;switch(t.type){case\"FeatureCollection\":for(r=0;r<t.features.length&&!1!==e(t.features[r].properties,r);r++);break;case\"Feature\":e(t.properties,0)}}function o(t,e){if(\"Feature\"===t.type)e(t,0);else if(\"FeatureCollection\"===t.type)for(var r=0;r<t.features.length&&!1!==e(t.features[r],r);r++);}function s(t,e){var r,n,i,a,o,s,l,c,u,h,f=0,p=\"FeatureCollection\"===t.type,d=\"Feature\"===t.type,g=p?t.features.length:1;for(r=0;r<g;r++){for(s=p?t.features[r].geometry:d?t.geometry:t,c=p?t.features[r].properties:d?t.properties:{},u=p?t.features[r].bbox:d?t.bbox:void 0,h=p?t.features[r].id:d?t.id:void 0,o=(l=!!s&&\"GeometryCollection\"===s.type)?s.geometries.length:1,i=0;i<o;i++)if(null!==(a=l?s.geometries[i]:s))switch(a.type){case\"Point\":case\"LineString\":case\"MultiPoint\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":if(!1===e(a,f,c,u,h))return!1;break;case\"GeometryCollection\":for(n=0;n<a.geometries.length;n++)if(!1===e(a.geometries[n],f,c,u,h))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}else if(!1===e(null,f,c,u,h))return!1;f++}}function l(t,e){s(t,function(t,r,i,a,o){var s,l=null===t?null:t.type;switch(l){case null:case\"Point\":case\"LineString\":case\"Polygon\":return!1!==e(n.feature(t,i,{bbox:a,id:o}),r,0)&&void 0}switch(l){case\"MultiPoint\":s=\"Point\";break;case\"MultiLineString\":s=\"LineString\";break;case\"MultiPolygon\":s=\"Polygon\"}for(var c=0;c<t.coordinates.length;c++){var u={type:s,coordinates:t.coordinates[c]};if(!1===e(n.feature(u,i),r,c))return!1}})}function c(t,e){l(t,function(t,r,a){var o=0;if(t.geometry){var s=t.geometry.type;if(\"Point\"!==s&&\"MultiPoint\"!==s){var l,c=0,u=0,h=0;return!1!==i(t,function(i,s,f,p,d){if(void 0===l||r>c||p>u||d>h)return l=i,c=r,u=p,h=d,void(o=0);var g=n.lineString([l,i],t.properties);if(!1===e(g,r,a,d,o))return!1;o++,l=i})&&void 0}}})}function u(t,e){if(!t)throw new Error(\"geojson is required\");l(t,function(t,r,i){if(null!==t.geometry){var a=t.geometry.type,o=t.geometry.coordinates;switch(a){case\"LineString\":if(!1===e(t,r,i,0,0))return!1;break;case\"Polygon\":for(var s=0;s<o.length;s++)if(!1===e(n.lineString(o[s],t.properties),r,i,s))return!1}}})}r.coordEach=i,r.coordReduce=function(t,e,r,n){var a=r;return i(t,function(t,n,i,o,s){a=0===n&&void 0===r?t:e(a,t,n,i,o,s)},n),a},r.propEach=a,r.propReduce=function(t,e,r){var n=r;return a(t,function(t,i){n=0===i&&void 0===r?t:e(n,t,i)}),n},r.featureEach=o,r.featureReduce=function(t,e,r){var n=r;return o(t,function(t,i){n=0===i&&void 0===r?t:e(n,t,i)}),n},r.coordAll=function(t){var e=[];return i(t,function(t){e.push(t)}),e},r.geomEach=s,r.geomReduce=function(t,e,r){var n=r;return s(t,function(t,i,a,o,s){n=0===i&&void 0===r?t:e(n,t,i,a,o,s)}),n},r.flattenEach=l,r.flattenReduce=function(t,e,r){var n=r;return l(t,function(t,i,a){n=0===i&&0===a&&void 0===r?t:e(n,t,i,a)}),n},r.segmentEach=c,r.segmentReduce=function(t,e,r){var n=r,i=!1;return c(t,function(t,a,o,s,l){n=!1===i&&void 0===r?t:e(n,t,a,o,s,l),i=!0}),n},r.lineEach=u,r.lineReduce=function(t,e,r){var n=r;return u(t,function(t,i,a,o){n=0===i&&void 0===r?t:e(n,t,i,a,o)}),n},r.findSegment=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.segmentIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":case\"MultiPoint\":return null;case\"LineString\":return s<0&&(s=c.length+s-1),n.lineString([c[s],c[s+1]],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s-1),n.lineString([c[o][s],c[o][s+1]],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s-1),n.lineString([c[a][s],c[a][s+1]],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s-1),n.lineString([c[a][o][s],c[a][o][s+1]],l,e)}throw new Error(\"geojson is invalid\")},r.findPoint=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.coordIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":return n.point(c,l,e);case\"MultiPoint\":return a<0&&(a=c.length+a),n.point(c[a],l,e);case\"LineString\":return s<0&&(s=c.length+s),n.point(c[s],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s),n.point(c[o][s],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s),n.point(c[a][s],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s),n.point(c[a][o][s],l,e)}throw new Error(\"geojson is invalid\")}},{\"@turf/helpers\":57}],59:[function(t,e,r){\"use strict\";var n=\"undefined\"==typeof WeakMap?t(\"weak-map\"):WeakMap,i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=new n;e.exports=function(t){var e=o.get(t),r=e&&(e._triangleBuffer.handle||e._triangleBuffer.buffer);if(!r||!t.isBuffer(r)){var n=i(t,new Float32Array([-1,-1,-1,4,4,-1]));(e=a(t,[{buffer:n,type:t.FLOAT,size:2}]))._triangleBuffer=n,o.set(t,e)}e.bind(),t.drawArrays(t.TRIANGLES,0,3),e.unbind()}},{\"gl-buffer\":241,\"gl-vao\":327,\"weak-map\":552}],60:[function(t,e,r){e.exports=function(t){var e=0,r=0,n=0,i=0;return t.map(function(t){var a=(t=t.slice())[0],o=a.toUpperCase();if(a!=o)switch(t[0]=o,a){case\"a\":t[6]+=n,t[7]+=i;break;case\"v\":t[1]+=i;break;case\"h\":t[1]+=n;break;default:for(var s=1;s<t.length;)t[s++]+=n,t[s++]+=i}switch(o){case\"Z\":n=e,i=r;break;case\"H\":n=t[1];break;case\"V\":i=t[1];break;case\"M\":n=e=t[1],i=r=t[2];break;default:n=t[t.length-2],i=t[t.length-1]}return t})}},{}],61:[function(t,e,r){var n=t(\"pad-left\");e.exports=function(t,e,r){e=\"number\"==typeof e?e:1,r=r||\": \";var i=t.split(/\\r?\\n/),a=String(i.length+e-1).length;return i.map(function(t,i){var o=i+e,s=String(o).length,l=n(o,a-s);return l+r+t}).join(\"\\n\")}},{\"pad-left\":457}],62:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[0];for(var r=t[0].length,n=[t[0]],a=[0],o=1;o<e;++o)if(n.push(t[o]),i(n,r)){if(a.push(o),a.length===r+1)return a}else n.pop();return a};var n=t(\"robust-orientation\");function i(t,e){for(var r=new Array(e+1),i=0;i<t.length;++i)r[i]=t[i];for(i=0;i<=t.length;++i){for(var a=t.length;a<=e;++a){for(var o=new Array(e),s=0;s<e;++s)o[s]=Math.pow(a+1-i,s);r[a]=o}if(n.apply(void 0,r))return!0}return!1}},{\"robust-orientation\":510}],63:[function(t,e,r){\"use strict\";e.exports=function(t,e){return n(e).filter(function(r){for(var n=new Array(r.length),a=0;a<r.length;++a)n[a]=e[r[a]];return i(n)*t<1})};var n=t(\"delaunay-triangulate\"),i=t(\"circumradius\")},{circumradius:114,\"delaunay-triangulate\":165}],64:[function(t,e,r){e.exports=function(t,e){return i(n(t,e))};var n=t(\"alpha-complex\"),i=t(\"simplicial-complex-boundary\")},{\"alpha-complex\":63,\"simplicial-complex-boundary\":517}],65:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(!t||null==t.length)throw Error(\"Argument should be an array\");e=null==e?1:Math.floor(e);for(var r=Array(2*e),n=0;n<e;n++){for(var i=-1/0,a=1/0,o=n,s=t.length;o<s;o+=e)t[o]>i&&(i=t[o]),t[o]<a&&(a=t[o]);r[n]=a,r[e+n]=i}return r}},{}],66:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\");e.exports=function(t,e,r){if(!t||null==t.length)throw Error(\"Argument should be an array\");null==e&&(e=1);null==r&&(r=n(t,e));for(var i=0;i<e;i++){var a=r[e+i],o=r[i],s=i,l=t.length;if(a===1/0&&o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:t[s]===o?0:.5;else if(a===1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:0;else if(o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===o?0:1;else{var c=a-o;for(s=i;s<l;s+=e)t[s]=0===c?.5:(t[s]-o)/c}}return t}},{\"array-bounds\":65}],67:[function(t,e,r){e.exports=function(t,e){var r=\"number\"==typeof t,n=\"number\"==typeof e;r&&!n?(e=t,t=0):r||n||(t=0,e=0);var i=(e|=0)-(t|=0);if(i<0)throw new Error(\"array length must be positive\");for(var a=new Array(i),o=0,s=t;o<i;o++,s++)a[o]=s;return a}},{}],68:[function(t,e,r){(function(r){\"use strict\";var n=t(\"object-assign\");function i(t,e){if(t===e)return 0;for(var r=t.length,n=e.length,i=0,a=Math.min(r,n);i<a;++i)if(t[i]!==e[i]){r=t[i],n=e[i];break}return r<n?-1:n<r?1:0}function a(t){return r.Buffer&&\"function\"==typeof r.Buffer.isBuffer?r.Buffer.isBuffer(t):!(null==t||!t._isBuffer)}var o=t(\"util/\"),s=Object.prototype.hasOwnProperty,l=Array.prototype.slice,c=\"foo\"===function(){}.name;function u(t){return Object.prototype.toString.call(t)}function h(t){return!a(t)&&(\"function\"==typeof r.ArrayBuffer&&(\"function\"==typeof ArrayBuffer.isView?ArrayBuffer.isView(t):!!t&&(t instanceof DataView||!!(t.buffer&&t.buffer instanceof ArrayBuffer))))}var f=e.exports=y,p=/\\s*function\\s+([^\\(\\s]*)\\s*/;function d(t){if(o.isFunction(t)){if(c)return t.name;var e=t.toString().match(p);return e&&e[1]}}function g(t,e){return\"string\"==typeof t?t.length<e?t:t.slice(0,e):t}function v(t){if(c||!o.isFunction(t))return o.inspect(t);var e=d(t);return\"[Function\"+(e?\": \"+e:\"\")+\"]\"}function m(t,e,r,n,i){throw new f.AssertionError({message:r,actual:t,expected:e,operator:n,stackStartFunction:i})}function y(t,e){t||m(t,!0,e,\"==\",f.ok)}function x(t,e,r,n){if(t===e)return!0;if(a(t)&&a(e))return 0===i(t,e);if(o.isDate(t)&&o.isDate(e))return t.getTime()===e.getTime();if(o.isRegExp(t)&&o.isRegExp(e))return t.source===e.source&&t.global===e.global&&t.multiline===e.multiline&&t.lastIndex===e.lastIndex&&t.ignoreCase===e.ignoreCase;if(null!==t&&\"object\"==typeof t||null!==e&&\"object\"==typeof e){if(h(t)&&h(e)&&u(t)===u(e)&&!(t instanceof Float32Array||t instanceof Float64Array))return 0===i(new Uint8Array(t.buffer),new Uint8Array(e.buffer));if(a(t)!==a(e))return!1;var s=(n=n||{actual:[],expected:[]}).actual.indexOf(t);return-1!==s&&s===n.expected.indexOf(e)||(n.actual.push(t),n.expected.push(e),function(t,e,r,n){if(null==t||null==e)return!1;if(o.isPrimitive(t)||o.isPrimitive(e))return t===e;if(r&&Object.getPrototypeOf(t)!==Object.getPrototypeOf(e))return!1;var i=b(t),a=b(e);if(i&&!a||!i&&a)return!1;if(i)return t=l.call(t),e=l.call(e),x(t,e,r);var s,c,u=k(t),h=k(e);if(u.length!==h.length)return!1;for(u.sort(),h.sort(),c=u.length-1;c>=0;c--)if(u[c]!==h[c])return!1;for(c=u.length-1;c>=0;c--)if(s=u[c],!x(t[s],e[s],r,n))return!1;return!0}(t,e,r,n))}return r?t===e:t==e}function b(t){return\"[object Arguments]\"==Object.prototype.toString.call(t)}function _(t,e){if(!t||!e)return!1;if(\"[object RegExp]\"==Object.prototype.toString.call(e))return e.test(t);try{if(t instanceof e)return!0}catch(t){}return!Error.isPrototypeOf(e)&&!0===e.call({},t)}function w(t,e,r,n){var i;if(\"function\"!=typeof e)throw new TypeError('\"block\" argument must be a function');\"string\"==typeof r&&(n=r,r=null),i=function(t){var e;try{t()}catch(t){e=t}return e}(e),n=(r&&r.name?\" (\"+r.name+\").\":\".\")+(n?\" \"+n:\".\"),t&&!i&&m(i,r,\"Missing expected exception\"+n);var a=\"string\"==typeof n,s=!t&&i&&!r;if((!t&&o.isError(i)&&a&&_(i,r)||s)&&m(i,r,\"Got unwanted exception\"+n),t&&i&&r&&!_(i,r)||!t&&i)throw i}f.AssertionError=function(t){var e;this.name=\"AssertionError\",this.actual=t.actual,this.expected=t.expected,this.operator=t.operator,t.message?(this.message=t.message,this.generatedMessage=!1):(this.message=g(v((e=this).actual),128)+\" \"+e.operator+\" \"+g(v(e.expected),128),this.generatedMessage=!0);var r=t.stackStartFunction||m;if(Error.captureStackTrace)Error.captureStackTrace(this,r);else{var n=new Error;if(n.stack){var i=n.stack,a=d(r),o=i.indexOf(\"\\n\"+a);if(o>=0){var s=i.indexOf(\"\\n\",o+1);i=i.substring(s+1)}this.stack=i}}},o.inherits(f.AssertionError,Error),f.fail=m,f.ok=y,f.equal=function(t,e,r){t!=e&&m(t,e,r,\"==\",f.equal)},f.notEqual=function(t,e,r){t==e&&m(t,e,r,\"!=\",f.notEqual)},f.deepEqual=function(t,e,r){x(t,e,!1)||m(t,e,r,\"deepEqual\",f.deepEqual)},f.deepStrictEqual=function(t,e,r){x(t,e,!0)||m(t,e,r,\"deepStrictEqual\",f.deepStrictEqual)},f.notDeepEqual=function(t,e,r){x(t,e,!1)&&m(t,e,r,\"notDeepEqual\",f.notDeepEqual)},f.notDeepStrictEqual=function t(e,r,n){x(e,r,!0)&&m(e,r,n,\"notDeepStrictEqual\",t)},f.strictEqual=function(t,e,r){t!==e&&m(t,e,r,\"===\",f.strictEqual)},f.notStrictEqual=function(t,e,r){t===e&&m(t,e,r,\"!==\",f.notStrictEqual)},f.throws=function(t,e,r){w(!0,t,e,r)},f.doesNotThrow=function(t,e,r){w(!1,t,e,r)},f.ifError=function(t){if(t)throw t},f.strict=n(function t(e,r){e||m(e,!0,r,\"==\",t)},f,{equal:f.strictEqual,deepEqual:f.deepStrictEqual,notEqual:f.notStrictEqual,notDeepEqual:f.notDeepStrictEqual}),f.strict.strict=f.strict;var k=Object.keys||function(t){var e=[];for(var r in t)s.call(t,r)&&e.push(r);return e}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"object-assign\":454,\"util/\":71}],69:[function(t,e,r){\"function\"==typeof Object.create?e.exports=function(t,e){t.super_=e,t.prototype=Object.create(e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}})}:e.exports=function(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}},{}],70:[function(t,e,r){e.exports=function(t){return t&&\"object\"==typeof t&&\"function\"==typeof t.copy&&\"function\"==typeof t.fill&&\"function\"==typeof t.readUInt8}},{}],71:[function(t,e,r){(function(e,n){var i=/%[sdj%]/g;r.format=function(t){if(!m(t)){for(var e=[],r=0;r<arguments.length;r++)e.push(s(arguments[r]));return e.join(\" \")}r=1;for(var n=arguments,a=n.length,o=String(t).replace(i,function(t){if(\"%%\"===t)return\"%\";if(r>=a)return t;switch(t){case\"%s\":return String(n[r++]);case\"%d\":return Number(n[r++]);case\"%j\":try{return JSON.stringify(n[r++])}catch(t){return\"[Circular]\"}default:return t}}),l=n[r];r<a;l=n[++r])g(l)||!b(l)?o+=\" \"+l:o+=\" \"+s(l);return o},r.deprecate=function(t,i){if(y(n.process))return function(){return r.deprecate(t,i).apply(this,arguments)};if(!0===e.noDeprecation)return t;var a=!1;return function(){if(!a){if(e.throwDeprecation)throw new Error(i);e.traceDeprecation?console.trace(i):console.error(i),a=!0}return t.apply(this,arguments)}};var a,o={};function s(t,e){var n={seen:[],stylize:c};return arguments.length>=3&&(n.depth=arguments[2]),arguments.length>=4&&(n.colors=arguments[3]),d(e)?n.showHidden=e:e&&r._extend(n,e),y(n.showHidden)&&(n.showHidden=!1),y(n.depth)&&(n.depth=2),y(n.colors)&&(n.colors=!1),y(n.customInspect)&&(n.customInspect=!0),n.colors&&(n.stylize=l),u(n,t,n.depth)}function l(t,e){var r=s.styles[e];return r?\"\\x1b[\"+s.colors[r][0]+\"m\"+t+\"\\x1b[\"+s.colors[r][1]+\"m\":t}function c(t,e){return t}function u(t,e,n){if(t.customInspect&&e&&k(e.inspect)&&e.inspect!==r.inspect&&(!e.constructor||e.constructor.prototype!==e)){var i=e.inspect(n,t);return m(i)||(i=u(t,i,n)),i}var a=function(t,e){if(y(e))return t.stylize(\"undefined\",\"undefined\");if(m(e)){var r=\"'\"+JSON.stringify(e).replace(/^\"|\"$/g,\"\").replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"')+\"'\";return t.stylize(r,\"string\")}if(v(e))return t.stylize(\"\"+e,\"number\");if(d(e))return t.stylize(\"\"+e,\"boolean\");if(g(e))return t.stylize(\"null\",\"null\")}(t,e);if(a)return a;var o=Object.keys(e),s=function(t){var e={};return t.forEach(function(t,r){e[t]=!0}),e}(o);if(t.showHidden&&(o=Object.getOwnPropertyNames(e)),w(e)&&(o.indexOf(\"message\")>=0||o.indexOf(\"description\")>=0))return h(e);if(0===o.length){if(k(e)){var l=e.name?\": \"+e.name:\"\";return t.stylize(\"[Function\"+l+\"]\",\"special\")}if(x(e))return t.stylize(RegExp.prototype.toString.call(e),\"regexp\");if(_(e))return t.stylize(Date.prototype.toString.call(e),\"date\");if(w(e))return h(e)}var c,b=\"\",T=!1,A=[\"{\",\"}\"];(p(e)&&(T=!0,A=[\"[\",\"]\"]),k(e))&&(b=\" [Function\"+(e.name?\": \"+e.name:\"\")+\"]\");return x(e)&&(b=\" \"+RegExp.prototype.toString.call(e)),_(e)&&(b=\" \"+Date.prototype.toUTCString.call(e)),w(e)&&(b=\" \"+h(e)),0!==o.length||T&&0!=e.length?n<0?x(e)?t.stylize(RegExp.prototype.toString.call(e),\"regexp\"):t.stylize(\"[Object]\",\"special\"):(t.seen.push(e),c=T?function(t,e,r,n,i){for(var a=[],o=0,s=e.length;o<s;++o)S(e,String(o))?a.push(f(t,e,r,n,String(o),!0)):a.push(\"\");return i.forEach(function(i){i.match(/^\\d+$/)||a.push(f(t,e,r,n,i,!0))}),a}(t,e,n,s,o):o.map(function(r){return f(t,e,n,s,r,T)}),t.seen.pop(),function(t,e,r){if(t.reduce(function(t,e){return 0,e.indexOf(\"\\n\")>=0&&0,t+e.replace(/\\u001b\\[\\d\\d?m/g,\"\").length+1},0)>60)return r[0]+(\"\"===e?\"\":e+\"\\n \")+\" \"+t.join(\",\\n  \")+\" \"+r[1];return r[0]+e+\" \"+t.join(\", \")+\" \"+r[1]}(c,b,A)):A[0]+b+A[1]}function h(t){return\"[\"+Error.prototype.toString.call(t)+\"]\"}function f(t,e,r,n,i,a){var o,s,l;if((l=Object.getOwnPropertyDescriptor(e,i)||{value:e[i]}).get?s=l.set?t.stylize(\"[Getter/Setter]\",\"special\"):t.stylize(\"[Getter]\",\"special\"):l.set&&(s=t.stylize(\"[Setter]\",\"special\")),S(n,i)||(o=\"[\"+i+\"]\"),s||(t.seen.indexOf(l.value)<0?(s=g(r)?u(t,l.value,null):u(t,l.value,r-1)).indexOf(\"\\n\")>-1&&(s=a?s.split(\"\\n\").map(function(t){return\"  \"+t}).join(\"\\n\").substr(2):\"\\n\"+s.split(\"\\n\").map(function(t){return\"   \"+t}).join(\"\\n\")):s=t.stylize(\"[Circular]\",\"special\")),y(o)){if(a&&i.match(/^\\d+$/))return s;(o=JSON.stringify(\"\"+i)).match(/^\"([a-zA-Z_][a-zA-Z_0-9]*)\"$/)?(o=o.substr(1,o.length-2),o=t.stylize(o,\"name\")):(o=o.replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"').replace(/(^\"|\"$)/g,\"'\"),o=t.stylize(o,\"string\"))}return o+\": \"+s}function p(t){return Array.isArray(t)}function d(t){return\"boolean\"==typeof t}function g(t){return null===t}function v(t){return\"number\"==typeof t}function m(t){return\"string\"==typeof t}function y(t){return void 0===t}function x(t){return b(t)&&\"[object RegExp]\"===T(t)}function b(t){return\"object\"==typeof t&&null!==t}function _(t){return b(t)&&\"[object Date]\"===T(t)}function w(t){return b(t)&&(\"[object Error]\"===T(t)||t instanceof Error)}function k(t){return\"function\"==typeof t}function T(t){return Object.prototype.toString.call(t)}function A(t){return t<10?\"0\"+t.toString(10):t.toString(10)}r.debuglog=function(t){if(y(a)&&(a=e.env.NODE_DEBUG||\"\"),t=t.toUpperCase(),!o[t])if(new RegExp(\"\\\\b\"+t+\"\\\\b\",\"i\").test(a)){var n=e.pid;o[t]=function(){var e=r.format.apply(r,arguments);console.error(\"%s %d: %s\",t,n,e)}}else o[t]=function(){};return o[t]},r.inspect=s,s.colors={bold:[1,22],italic:[3,23],underline:[4,24],inverse:[7,27],white:[37,39],grey:[90,39],black:[30,39],blue:[34,39],cyan:[36,39],green:[32,39],magenta:[35,39],red:[31,39],yellow:[33,39]},s.styles={special:\"cyan\",number:\"yellow\",boolean:\"yellow\",undefined:\"grey\",null:\"bold\",string:\"green\",date:\"magenta\",regexp:\"red\"},r.isArray=p,r.isBoolean=d,r.isNull=g,r.isNullOrUndefined=function(t){return null==t},r.isNumber=v,r.isString=m,r.isSymbol=function(t){return\"symbol\"==typeof t},r.isUndefined=y,r.isRegExp=x,r.isObject=b,r.isDate=_,r.isError=w,r.isFunction=k,r.isPrimitive=function(t){return null===t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||\"symbol\"==typeof t||\"undefined\"==typeof t},r.isBuffer=t(\"./support/isBuffer\");var M=[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"];function S(t,e){return Object.prototype.hasOwnProperty.call(t,e)}r.log=function(){var t,e;console.log(\"%s - %s\",(t=new Date,e=[A(t.getHours()),A(t.getMinutes()),A(t.getSeconds())].join(\":\"),[t.getDate(),M[t.getMonth()],e].join(\" \")),r.format.apply(r,arguments))},r.inherits=t(\"inherits\"),r._extend=function(t,e){if(!e||!b(e))return t;for(var r=Object.keys(e),n=r.length;n--;)t[r[n]]=e[r[n]];return t}}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./support/isBuffer\":70,_process:482,inherits:69}],72:[function(t,e,r){e.exports=function(t){return atob(t)}},{}],73:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=e.length,a=new Array(r+1),o=0;o<r;++o){for(var s=new Array(r+1),l=0;l<=r;++l)s[l]=t[l][o];a[o]=s}a[r]=new Array(r+1);for(var o=0;o<=r;++o)a[r][o]=1;for(var c=new Array(r+1),o=0;o<r;++o)c[o]=e[o];c[r]=1;var u=n(a,c),h=i(u[r+1]);0===h&&(h=1);for(var f=new Array(r+1),o=0;o<=r;++o)f[o]=i(u[o])/h;return f};var n=t(\"robust-linear-solve\");function i(t){for(var e=0,r=0;r<t.length;++r)e+=t[r];return e}},{\"robust-linear-solve\":509}],74:[function(t,e,r){\"use strict\";r.byteLength=function(t){var e=c(t),r=e[0],n=e[1];return 3*(r+n)/4-n},r.toByteArray=function(t){for(var e,r=c(t),n=r[0],o=r[1],s=new a(function(t,e,r){return 3*(e+r)/4-r}(0,n,o)),l=0,u=o>0?n-4:n,h=0;h<u;h+=4)e=i[t.charCodeAt(h)]<<18|i[t.charCodeAt(h+1)]<<12|i[t.charCodeAt(h+2)]<<6|i[t.charCodeAt(h+3)],s[l++]=e>>16&255,s[l++]=e>>8&255,s[l++]=255&e;2===o&&(e=i[t.charCodeAt(h)]<<2|i[t.charCodeAt(h+1)]>>4,s[l++]=255&e);1===o&&(e=i[t.charCodeAt(h)]<<10|i[t.charCodeAt(h+1)]<<4|i[t.charCodeAt(h+2)]>>2,s[l++]=e>>8&255,s[l++]=255&e);return s},r.fromByteArray=function(t){for(var e,r=t.length,i=r%3,a=[],o=0,s=r-i;o<s;o+=16383)a.push(u(t,o,o+16383>s?s:o+16383));1===i?(e=t[r-1],a.push(n[e>>2]+n[e<<4&63]+\"==\")):2===i&&(e=(t[r-2]<<8)+t[r-1],a.push(n[e>>10]+n[e>>4&63]+n[e<<2&63]+\"=\"));return a.join(\"\")};for(var n=[],i=[],a=\"undefined\"!=typeof Uint8Array?Uint8Array:Array,o=\"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/\",s=0,l=o.length;s<l;++s)n[s]=o[s],i[o.charCodeAt(s)]=s;function c(t){var e=t.length;if(e%4>0)throw new Error(\"Invalid string. Length must be a multiple of 4\");var r=t.indexOf(\"=\");return-1===r&&(r=e),[r,r===e?0:4-r%4]}function u(t,e,r){for(var i,a,o=[],s=e;s<r;s+=3)i=(t[s]<<16&16711680)+(t[s+1]<<8&65280)+(255&t[s+2]),o.push(n[(a=i)>>18&63]+n[a>>12&63]+n[a>>6&63]+n[63&a]);return o.join(\"\")}i[\"-\".charCodeAt(0)]=62,i[\"_\".charCodeAt(0)]=63},{}],75:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).add(e[0].mul(t[1])),t[1].mul(e[1]))}},{\"./lib/rationalize\":85}],76:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t[0].mul(e[1]).cmp(e[0].mul(t[1]))}},{}],77:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]),t[1].mul(e[0]))}},{\"./lib/rationalize\":85}],78:[function(t,e,r){\"use strict\";var n=t(\"./is-rat\"),i=t(\"./lib/is-bn\"),a=t(\"./lib/num-to-bn\"),o=t(\"./lib/str-to-bn\"),s=t(\"./lib/rationalize\"),l=t(\"./div\");e.exports=function t(e,r){if(n(e))return r?l(e,t(r)):[e[0].clone(),e[1].clone()];var c=0;var u,h;if(i(e))u=e.clone();else if(\"string\"==typeof e)u=o(e);else{if(0===e)return[a(0),a(1)];if(e===Math.floor(e))u=a(e);else{for(;e!==Math.floor(e);)e*=Math.pow(2,256),c-=256;u=a(e)}}if(n(r))u.mul(r[1]),h=r[0].clone();else if(i(r))h=r.clone();else if(\"string\"==typeof r)h=o(r);else if(r)if(r===Math.floor(r))h=a(r);else{for(;r!==Math.floor(r);)r*=Math.pow(2,256),c+=256;h=a(r)}else h=a(1);c>0?u=u.ushln(c):c<0&&(h=h.ushln(-c));return s(u,h)}},{\"./div\":77,\"./is-rat\":79,\"./lib/is-bn\":83,\"./lib/num-to-bn\":84,\"./lib/rationalize\":85,\"./lib/str-to-bn\":86}],79:[function(t,e,r){\"use strict\";var n=t(\"./lib/is-bn\");e.exports=function(t){return Array.isArray(t)&&2===t.length&&n(t[0])&&n(t[1])}},{\"./lib/is-bn\":83}],80:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return t.cmp(new n(0))}},{\"bn.js\":94}],81:[function(t,e,r){\"use strict\";var n=t(\"./bn-sign\");e.exports=function(t){var e=t.length,r=t.words,i=0;if(1===e)i=r[0];else if(2===e)i=r[0]+67108864*r[1];else for(var a=0;a<e;a++){var o=r[a];i+=o*Math.pow(67108864,a)}return n(t)*i}},{\"./bn-sign\":80}],82:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=t(\"bit-twiddle\").countTrailingZeros;e.exports=function(t){var e=i(n.lo(t));if(e<32)return e;var r=i(n.hi(t));if(r>20)return 52;return r+32}},{\"bit-twiddle\":92,\"double-bits\":167}],83:[function(t,e,r){\"use strict\";t(\"bn.js\");e.exports=function(t){return t&&\"object\"==typeof t&&Boolean(t.words)}},{\"bn.js\":94}],84:[function(t,e,r){\"use strict\";var n=t(\"bn.js\"),i=t(\"double-bits\");e.exports=function(t){var e=i.exponent(t);return e<52?new n(t):new n(t*Math.pow(2,52-e)).ushln(e-52)}},{\"bn.js\":94,\"double-bits\":167}],85:[function(t,e,r){\"use strict\";var n=t(\"./num-to-bn\"),i=t(\"./bn-sign\");e.exports=function(t,e){var r=i(t),a=i(e);if(0===r)return[n(0),n(1)];if(0===a)return[n(0),n(0)];a<0&&(t=t.neg(),e=e.neg());var o=t.gcd(e);if(o.cmpn(1))return[t.div(o),e.div(o)];return[t,e]}},{\"./bn-sign\":80,\"./num-to-bn\":84}],86:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return new n(t)}},{\"bn.js\":94}],87:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[0]),t[1].mul(e[1]))}},{\"./lib/rationalize\":85}],88:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-sign\");e.exports=function(t){return n(t[0])*n(t[1])}},{\"./lib/bn-sign\":80}],89:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).sub(t[1].mul(e[0])),t[1].mul(e[1]))}},{\"./lib/rationalize\":85}],90:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-to-num\"),i=t(\"./lib/ctz\");e.exports=function(t){var e=t[0],r=t[1];if(0===e.cmpn(0))return 0;var a=e.abs().divmod(r.abs()),o=a.div,s=n(o),l=a.mod,c=e.negative!==r.negative?-1:1;if(0===l.cmpn(0))return c*s;if(s){var u=i(s)+4,h=n(l.ushln(u).divRound(r));return c*(s+h*Math.pow(2,-u))}var f=r.bitLength()-l.bitLength()+53,h=n(l.ushln(f).divRound(r));return f<1023?c*h*Math.pow(2,-f):(h*=Math.pow(2,-1023),c*h*Math.pow(2,1023-f))}},{\"./lib/bn-to-num\":81,\"./lib/ctz\":82}],91:[function(t,e,r){\"use strict\";function n(t,e,r,n,i,a){var o=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",a?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a\",i?\".get(m)\":\"[m]\"];return a?e.indexOf(\"c\")<0?o.push(\";if(x===y){return m}else if(x<=y){\"):o.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):o.push(\";if(\",e,\"){i=m;\"),r?o.push(\"l=m+1}else{h=m-1}\"):o.push(\"h=m-1}else{l=m+1}\"),o.push(\"}\"),a?o.push(\"return -1};\"):o.push(\"return i};\"),o.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],!1,i),n(\"B\",\"x\"+t+\"y\",e,[\"y\"],!0,i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!1,i),n(\"Q\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!0,i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(a.shape){if(typeof(c)==='function'){return Q(a,(l===undefined)?0:l|0,(h===undefined)?a.shape[0]-1:h|0,y,c)}else{return B(a,(c===undefined)?0:c|0,(l===undefined)?a.shape[0]-1:l|0,y)}}else{if(typeof(c)==='function'){return P(a,(l===undefined)?0:l|0,(h===undefined)?a.length-1:h|0,y,c)}else{return A(a,(c===undefined)?0:c|0,(l===undefined)?a.length-1:l|0,y)}}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],92:[function(t,e,r){\"use strict\";function n(t){var e=32;return(t&=-t)&&e--,65535&t&&(e-=16),16711935&t&&(e-=8),252645135&t&&(e-=4),858993459&t&&(e-=2),1431655765&t&&(e-=1),e}r.INT_BITS=32,r.INT_MAX=2147483647,r.INT_MIN=-1<<31,r.sign=function(t){return(t>0)-(t<0)},r.abs=function(t){var e=t>>31;return(t^e)-e},r.min=function(t,e){return e^(t^e)&-(t<e)},r.max=function(t,e){return t^(t^e)&-(t<e)},r.isPow2=function(t){return!(t&t-1||!t)},r.log2=function(t){var e,r;return e=(t>65535)<<4,e|=r=((t>>>=e)>255)<<3,e|=r=((t>>>=r)>15)<<2,(e|=r=((t>>>=r)>3)<<1)|(t>>>=r)>>1},r.log10=function(t){return t>=1e9?9:t>=1e8?8:t>=1e7?7:t>=1e6?6:t>=1e5?5:t>=1e4?4:t>=1e3?3:t>=100?2:t>=10?1:0},r.popCount=function(t){return 16843009*((t=(858993459&(t-=t>>>1&1431655765))+(t>>>2&858993459))+(t>>>4)&252645135)>>>24},r.countTrailingZeros=n,r.nextPow2=function(t){return t+=0===t,--t,t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)+1},r.prevPow2=function(t){return t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)-(t>>>1)},r.parity=function(t){return t^=t>>>16,t^=t>>>8,t^=t>>>4,27030>>>(t&=15)&1};var i=new Array(256);!function(t){for(var e=0;e<256;++e){var r=e,n=e,i=7;for(r>>>=1;r;r>>>=1)n<<=1,n|=1&r,--i;t[e]=n<<i&255}}(i),r.reverse=function(t){return i[255&t]<<24|i[t>>>8&255]<<16|i[t>>>16&255]<<8|i[t>>>24&255]},r.interleave2=function(t,e){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t&=65535)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e&=65535)|e<<8))|e<<4))|e<<2))|e<<1))<<1},r.deinterleave2=function(t,e){return(t=65535&((t=16711935&((t=252645135&((t=858993459&((t=t>>>e&1431655765)|t>>>1))|t>>>2))|t>>>4))|t>>>16))<<16>>16},r.interleave3=function(t,e,r){return t=1227133513&((t=3272356035&((t=251719695&((t=4278190335&((t&=1023)|t<<16))|t<<8))|t<<4))|t<<2),(t|=(e=1227133513&((e=3272356035&((e=251719695&((e=4278190335&((e&=1023)|e<<16))|e<<8))|e<<4))|e<<2))<<1)|(r=1227133513&((r=3272356035&((r=251719695&((r=4278190335&((r&=1023)|r<<16))|r<<8))|r<<4))|r<<2))<<2},r.deinterleave3=function(t,e){return(t=1023&((t=4278190335&((t=251719695&((t=3272356035&((t=t>>>e&1227133513)|t>>>2))|t>>>4))|t>>>8))|t>>>16))<<22>>22},r.nextCombination=function(t){var e=t|t-1;return e+1|(~e&-~e)-1>>>n(t)+1}},{}],93:[function(t,e,r){\"use strict\";var n=t(\"clamp\");e.exports=function(t,e){e||(e={});var r,o,s,l,c,u,h,f,p,d,g,v=null==e.cutoff?.25:e.cutoff,m=null==e.radius?8:e.radius,y=e.channel||0;if(ArrayBuffer.isView(t)||Array.isArray(t)){if(!e.width||!e.height)throw Error(\"For raw data width and height should be provided by options\");r=e.width,o=e.height,l=t,u=e.stride?e.stride:Math.floor(t.length/r/o)}else window.HTMLCanvasElement&&t instanceof window.HTMLCanvasElement?(h=(f=t).getContext(\"2d\"),r=f.width,o=f.height,p=h.getImageData(0,0,r,o),l=p.data,u=4):window.CanvasRenderingContext2D&&t instanceof window.CanvasRenderingContext2D?(f=t.canvas,h=t,r=f.width,o=f.height,p=h.getImageData(0,0,r,o),l=p.data,u=4):window.ImageData&&t instanceof window.ImageData&&(p=t,r=t.width,o=t.height,l=p.data,u=4);if(s=Math.max(r,o),window.Uint8ClampedArray&&l instanceof window.Uint8ClampedArray||window.Uint8Array&&l instanceof window.Uint8Array)for(c=l,l=Array(r*o),d=0,g=c.length;d<g;d++)l[d]=c[d*u+y]/255;else if(1!==u)throw Error(\"Raw data can have only 1 value per pixel\");var x=Array(r*o),b=Array(r*o),_=Array(s),w=Array(s),k=Array(s+1),T=Array(s);for(d=0,g=r*o;d<g;d++){var A=l[d];x[d]=1===A?0:0===A?i:Math.pow(Math.max(0,.5-A),2),b[d]=1===A?i:0===A?0:Math.pow(Math.max(0,A-.5),2)}a(x,r,o,_,w,T,k),a(b,r,o,_,w,T,k);var M=window.Float32Array?new Float32Array(r*o):new Array(r*o);for(d=0,g=r*o;d<g;d++)M[d]=n(1-((x[d]-b[d])/m+v),0,1);return M};var i=1e20;function a(t,e,r,n,i,a,s){for(var l=0;l<e;l++){for(var c=0;c<r;c++)n[c]=t[c*e+l];for(o(n,i,a,s,r),c=0;c<r;c++)t[c*e+l]=i[c]}for(c=0;c<r;c++){for(l=0;l<e;l++)n[l]=t[c*e+l];for(o(n,i,a,s,e),l=0;l<e;l++)t[c*e+l]=Math.sqrt(i[l])}}function o(t,e,r,n,a){r[0]=0,n[0]=-i,n[1]=+i;for(var o=1,s=0;o<a;o++){for(var l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);l<=n[s];)s--,l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);r[++s]=o,n[s]=l,n[s+1]=+i}for(o=0,s=0;o<a;o++){for(;n[s+1]<o;)s++;e[o]=(o-r[s])*(o-r[s])+t[r[s]]}}},{clamp:115}],94:[function(t,e,r){!function(e,r){\"use strict\";function n(t,e){if(!t)throw new Error(e||\"Assertion failed\")}function i(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}function a(t,e,r){if(a.isBN(t))return t;this.negative=0,this.words=null,this.length=0,this.red=null,null!==t&&(\"le\"!==e&&\"be\"!==e||(r=e,e=10),this._init(t||0,e||10,r||\"be\"))}var o;\"object\"==typeof e?e.exports=a:r.BN=a,a.BN=a,a.wordSize=26;try{o=t(\"buffer\").Buffer}catch(t){}function s(t,e,r){for(var n=0,i=Math.min(t.length,r),a=e;a<i;a++){var o=t.charCodeAt(a)-48;n<<=4,n|=o>=49&&o<=54?o-49+10:o>=17&&o<=22?o-17+10:15&o}return n}function l(t,e,r,n){for(var i=0,a=Math.min(t.length,r),o=e;o<a;o++){var s=t.charCodeAt(o)-48;i*=n,i+=s>=49?s-49+10:s>=17?s-17+10:s}return i}a.isBN=function(t){return t instanceof a||null!==t&&\"object\"==typeof t&&t.constructor.wordSize===a.wordSize&&Array.isArray(t.words)},a.max=function(t,e){return t.cmp(e)>0?t:e},a.min=function(t,e){return t.cmp(e)<0?t:e},a.prototype._init=function(t,e,r){if(\"number\"==typeof t)return this._initNumber(t,e,r);if(\"object\"==typeof t)return this._initArray(t,e,r);\"hex\"===e&&(e=16),n(e===(0|e)&&e>=2&&e<=36);var i=0;\"-\"===(t=t.toString().replace(/\\s+/g,\"\"))[0]&&i++,16===e?this._parseHex(t,i):this._parseBase(t,e,i),\"-\"===t[0]&&(this.negative=1),this.strip(),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initNumber=function(t,e,r){t<0&&(this.negative=1,t=-t),t<67108864?(this.words=[67108863&t],this.length=1):t<4503599627370496?(this.words=[67108863&t,t/67108864&67108863],this.length=2):(n(t<9007199254740992),this.words=[67108863&t,t/67108864&67108863,1],this.length=3),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initArray=function(t,e,r){if(n(\"number\"==typeof t.length),t.length<=0)return this.words=[0],this.length=1,this;this.length=Math.ceil(t.length/3),this.words=new Array(this.length);for(var i=0;i<this.length;i++)this.words[i]=0;var a,o,s=0;if(\"be\"===r)for(i=t.length-1,a=0;i>=0;i-=3)o=t[i]|t[i-1]<<8|t[i-2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);else if(\"le\"===r)for(i=0,a=0;i<t.length;i+=3)o=t[i]|t[i+1]<<8|t[i+2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);return this.strip()},a.prototype._parseHex=function(t,e){this.length=Math.ceil((t.length-e)/6),this.words=new Array(this.length);for(var r=0;r<this.length;r++)this.words[r]=0;var n,i,a=0;for(r=t.length-6,n=0;r>=e;r-=6)i=s(t,r,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303,(a+=24)>=26&&(a-=26,n++);r+6!==e&&(i=s(t,e,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303),this.strip()},a.prototype._parseBase=function(t,e,r){this.words=[0],this.length=1;for(var n=0,i=1;i<=67108863;i*=e)n++;n--,i=i/e|0;for(var a=t.length-r,o=a%n,s=Math.min(a,a-o)+r,c=0,u=r;u<s;u+=n)c=l(t,u,u+n,e),this.imuln(i),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c);if(0!==o){var h=1;for(c=l(t,u,t.length,e),u=0;u<o;u++)h*=e;this.imuln(h),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c)}},a.prototype.copy=function(t){t.words=new Array(this.length);for(var e=0;e<this.length;e++)t.words[e]=this.words[e];t.length=this.length,t.negative=this.negative,t.red=this.red},a.prototype.clone=function(){var t=new a(null);return this.copy(t),t},a.prototype._expand=function(t){for(;this.length<t;)this.words[this.length++]=0;return this},a.prototype.strip=function(){for(;this.length>1&&0===this.words[this.length-1];)this.length--;return this._normSign()},a.prototype._normSign=function(){return 1===this.length&&0===this.words[0]&&(this.negative=0),this},a.prototype.inspect=function(){return(this.red?\"<BN-R: \":\"<BN: \")+this.toString(16)+\">\"};var c=[\"\",\"0\",\"00\",\"000\",\"0000\",\"00000\",\"000000\",\"0000000\",\"00000000\",\"000000000\",\"0000000000\",\"00000000000\",\"000000000000\",\"0000000000000\",\"00000000000000\",\"000000000000000\",\"0000000000000000\",\"00000000000000000\",\"000000000000000000\",\"0000000000000000000\",\"00000000000000000000\",\"000000000000000000000\",\"0000000000000000000000\",\"00000000000000000000000\",\"000000000000000000000000\",\"0000000000000000000000000\"],u=[0,0,25,16,12,11,10,9,8,8,7,7,7,7,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5],h=[0,0,33554432,43046721,16777216,48828125,60466176,40353607,16777216,43046721,1e7,19487171,35831808,62748517,7529536,11390625,16777216,24137569,34012224,47045881,64e6,4084101,5153632,6436343,7962624,9765625,11881376,14348907,17210368,20511149,243e5,28629151,33554432,39135393,45435424,52521875,60466176];function f(t,e,r){r.negative=e.negative^t.negative;var n=t.length+e.length|0;r.length=n,n=n-1|0;var i=0|t.words[0],a=0|e.words[0],o=i*a,s=67108863&o,l=o/67108864|0;r.words[0]=s;for(var c=1;c<n;c++){for(var u=l>>>26,h=67108863&l,f=Math.min(c,e.length-1),p=Math.max(0,c-t.length+1);p<=f;p++){var d=c-p|0;u+=(o=(i=0|t.words[d])*(a=0|e.words[p])+h)/67108864|0,h=67108863&o}r.words[c]=0|h,l=0|u}return 0!==l?r.words[c]=0|l:r.length--,r.strip()}a.prototype.toString=function(t,e){var r;if(e=0|e||1,16===(t=t||10)||\"hex\"===t){r=\"\";for(var i=0,a=0,o=0;o<this.length;o++){var s=this.words[o],l=(16777215&(s<<i|a)).toString(16);r=0!==(a=s>>>24-i&16777215)||o!==this.length-1?c[6-l.length]+l+r:l+r,(i+=2)>=26&&(i-=26,o--)}for(0!==a&&(r=a.toString(16)+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}if(t===(0|t)&&t>=2&&t<=36){var f=u[t],p=h[t];r=\"\";var d=this.clone();for(d.negative=0;!d.isZero();){var g=d.modn(p).toString(t);r=(d=d.idivn(p)).isZero()?g+r:c[f-g.length]+g+r}for(this.isZero()&&(r=\"0\"+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}n(!1,\"Base should be between 2 and 36\")},a.prototype.toNumber=function(){var t=this.words[0];return 2===this.length?t+=67108864*this.words[1]:3===this.length&&1===this.words[2]?t+=4503599627370496+67108864*this.words[1]:this.length>2&&n(!1,\"Number can only safely store up to 53 bits\"),0!==this.negative?-t:t},a.prototype.toJSON=function(){return this.toString(16)},a.prototype.toBuffer=function(t,e){return n(\"undefined\"!=typeof o),this.toArrayLike(o,t,e)},a.prototype.toArray=function(t,e){return this.toArrayLike(Array,t,e)},a.prototype.toArrayLike=function(t,e,r){var i=this.byteLength(),a=r||Math.max(1,i);n(i<=a,\"byte array longer than desired length\"),n(a>0,\"Requested array length <= 0\"),this.strip();var o,s,l=\"le\"===e,c=new t(a),u=this.clone();if(l){for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[s]=o;for(;s<a;s++)c[s]=0}else{for(s=0;s<a-i;s++)c[s]=0;for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[a-s-1]=o}return c},Math.clz32?a.prototype._countBits=function(t){return 32-Math.clz32(t)}:a.prototype._countBits=function(t){var e=t,r=0;return e>=4096&&(r+=13,e>>>=13),e>=64&&(r+=7,e>>>=7),e>=8&&(r+=4,e>>>=4),e>=2&&(r+=2,e>>>=2),r+e},a.prototype._zeroBits=function(t){if(0===t)return 26;var e=t,r=0;return 0==(8191&e)&&(r+=13,e>>>=13),0==(127&e)&&(r+=7,e>>>=7),0==(15&e)&&(r+=4,e>>>=4),0==(3&e)&&(r+=2,e>>>=2),0==(1&e)&&r++,r},a.prototype.bitLength=function(){var t=this.words[this.length-1],e=this._countBits(t);return 26*(this.length-1)+e},a.prototype.zeroBits=function(){if(this.isZero())return 0;for(var t=0,e=0;e<this.length;e++){var r=this._zeroBits(this.words[e]);if(t+=r,26!==r)break}return t},a.prototype.byteLength=function(){return Math.ceil(this.bitLength()/8)},a.prototype.toTwos=function(t){return 0!==this.negative?this.abs().inotn(t).iaddn(1):this.clone()},a.prototype.fromTwos=function(t){return this.testn(t-1)?this.notn(t).iaddn(1).ineg():this.clone()},a.prototype.isNeg=function(){return 0!==this.negative},a.prototype.neg=function(){return this.clone().ineg()},a.prototype.ineg=function(){return this.isZero()||(this.negative^=1),this},a.prototype.iuor=function(t){for(;this.length<t.length;)this.words[this.length++]=0;for(var e=0;e<t.length;e++)this.words[e]=this.words[e]|t.words[e];return this.strip()},a.prototype.ior=function(t){return n(0==(this.negative|t.negative)),this.iuor(t)},a.prototype.or=function(t){return this.length>t.length?this.clone().ior(t):t.clone().ior(this)},a.prototype.uor=function(t){return this.length>t.length?this.clone().iuor(t):t.clone().iuor(this)},a.prototype.iuand=function(t){var e;e=this.length>t.length?t:this;for(var r=0;r<e.length;r++)this.words[r]=this.words[r]&t.words[r];return this.length=e.length,this.strip()},a.prototype.iand=function(t){return n(0==(this.negative|t.negative)),this.iuand(t)},a.prototype.and=function(t){return this.length>t.length?this.clone().iand(t):t.clone().iand(this)},a.prototype.uand=function(t){return this.length>t.length?this.clone().iuand(t):t.clone().iuand(this)},a.prototype.iuxor=function(t){var e,r;this.length>t.length?(e=this,r=t):(e=t,r=this);for(var n=0;n<r.length;n++)this.words[n]=e.words[n]^r.words[n];if(this!==e)for(;n<e.length;n++)this.words[n]=e.words[n];return this.length=e.length,this.strip()},a.prototype.ixor=function(t){return n(0==(this.negative|t.negative)),this.iuxor(t)},a.prototype.xor=function(t){return this.length>t.length?this.clone().ixor(t):t.clone().ixor(this)},a.prototype.uxor=function(t){return this.length>t.length?this.clone().iuxor(t):t.clone().iuxor(this)},a.prototype.inotn=function(t){n(\"number\"==typeof t&&t>=0);var e=0|Math.ceil(t/26),r=t%26;this._expand(e),r>0&&e--;for(var i=0;i<e;i++)this.words[i]=67108863&~this.words[i];return r>0&&(this.words[i]=~this.words[i]&67108863>>26-r),this.strip()},a.prototype.notn=function(t){return this.clone().inotn(t)},a.prototype.setn=function(t,e){n(\"number\"==typeof t&&t>=0);var r=t/26|0,i=t%26;return this._expand(r+1),this.words[r]=e?this.words[r]|1<<i:this.words[r]&~(1<<i),this.strip()},a.prototype.iadd=function(t){var e,r,n;if(0!==this.negative&&0===t.negative)return this.negative=0,e=this.isub(t),this.negative^=1,this._normSign();if(0===this.negative&&0!==t.negative)return t.negative=0,e=this.isub(t),t.negative=1,e._normSign();this.length>t.length?(r=this,n=t):(r=t,n=this);for(var i=0,a=0;a<n.length;a++)e=(0|r.words[a])+(0|n.words[a])+i,this.words[a]=67108863&e,i=e>>>26;for(;0!==i&&a<r.length;a++)e=(0|r.words[a])+i,this.words[a]=67108863&e,i=e>>>26;if(this.length=r.length,0!==i)this.words[this.length]=i,this.length++;else if(r!==this)for(;a<r.length;a++)this.words[a]=r.words[a];return this},a.prototype.add=function(t){var e;return 0!==t.negative&&0===this.negative?(t.negative=0,e=this.sub(t),t.negative^=1,e):0===t.negative&&0!==this.negative?(this.negative=0,e=t.sub(this),this.negative=1,e):this.length>t.length?this.clone().iadd(t):t.clone().iadd(this)},a.prototype.isub=function(t){if(0!==t.negative){t.negative=0;var e=this.iadd(t);return t.negative=1,e._normSign()}if(0!==this.negative)return this.negative=0,this.iadd(t),this.negative=1,this._normSign();var r,n,i=this.cmp(t);if(0===i)return this.negative=0,this.length=1,this.words[0]=0,this;i>0?(r=this,n=t):(r=t,n=this);for(var a=0,o=0;o<n.length;o++)a=(e=(0|r.words[o])-(0|n.words[o])+a)>>26,this.words[o]=67108863&e;for(;0!==a&&o<r.length;o++)a=(e=(0|r.words[o])+a)>>26,this.words[o]=67108863&e;if(0===a&&o<r.length&&r!==this)for(;o<r.length;o++)this.words[o]=r.words[o];return this.length=Math.max(this.length,o),r!==this&&(this.negative=1),this.strip()},a.prototype.sub=function(t){return this.clone().isub(t)};var p=function(t,e,r){var n,i,a,o=t.words,s=e.words,l=r.words,c=0,u=0|o[0],h=8191&u,f=u>>>13,p=0|o[1],d=8191&p,g=p>>>13,v=0|o[2],m=8191&v,y=v>>>13,x=0|o[3],b=8191&x,_=x>>>13,w=0|o[4],k=8191&w,T=w>>>13,A=0|o[5],M=8191&A,S=A>>>13,E=0|o[6],C=8191&E,L=E>>>13,P=0|o[7],O=8191&P,z=P>>>13,I=0|o[8],D=8191&I,R=I>>>13,F=0|o[9],B=8191&F,N=F>>>13,j=0|s[0],U=8191&j,V=j>>>13,q=0|s[1],H=8191&q,G=q>>>13,Y=0|s[2],W=8191&Y,X=Y>>>13,Z=0|s[3],J=8191&Z,K=Z>>>13,$=0|s[4],Q=8191&$,tt=$>>>13,et=0|s[5],rt=8191&et,nt=et>>>13,it=0|s[6],at=8191&it,ot=it>>>13,st=0|s[7],lt=8191&st,ct=st>>>13,ut=0|s[8],ht=8191&ut,ft=ut>>>13,pt=0|s[9],dt=8191&pt,gt=pt>>>13;r.negative=t.negative^e.negative,r.length=19;var vt=(c+(n=Math.imul(h,U))|0)+((8191&(i=(i=Math.imul(h,V))+Math.imul(f,U)|0))<<13)|0;c=((a=Math.imul(f,V))+(i>>>13)|0)+(vt>>>26)|0,vt&=67108863,n=Math.imul(d,U),i=(i=Math.imul(d,V))+Math.imul(g,U)|0,a=Math.imul(g,V);var mt=(c+(n=n+Math.imul(h,H)|0)|0)+((8191&(i=(i=i+Math.imul(h,G)|0)+Math.imul(f,H)|0))<<13)|0;c=((a=a+Math.imul(f,G)|0)+(i>>>13)|0)+(mt>>>26)|0,mt&=67108863,n=Math.imul(m,U),i=(i=Math.imul(m,V))+Math.imul(y,U)|0,a=Math.imul(y,V),n=n+Math.imul(d,H)|0,i=(i=i+Math.imul(d,G)|0)+Math.imul(g,H)|0,a=a+Math.imul(g,G)|0;var yt=(c+(n=n+Math.imul(h,W)|0)|0)+((8191&(i=(i=i+Math.imul(h,X)|0)+Math.imul(f,W)|0))<<13)|0;c=((a=a+Math.imul(f,X)|0)+(i>>>13)|0)+(yt>>>26)|0,yt&=67108863,n=Math.imul(b,U),i=(i=Math.imul(b,V))+Math.imul(_,U)|0,a=Math.imul(_,V),n=n+Math.imul(m,H)|0,i=(i=i+Math.imul(m,G)|0)+Math.imul(y,H)|0,a=a+Math.imul(y,G)|0,n=n+Math.imul(d,W)|0,i=(i=i+Math.imul(d,X)|0)+Math.imul(g,W)|0,a=a+Math.imul(g,X)|0;var xt=(c+(n=n+Math.imul(h,J)|0)|0)+((8191&(i=(i=i+Math.imul(h,K)|0)+Math.imul(f,J)|0))<<13)|0;c=((a=a+Math.imul(f,K)|0)+(i>>>13)|0)+(xt>>>26)|0,xt&=67108863,n=Math.imul(k,U),i=(i=Math.imul(k,V))+Math.imul(T,U)|0,a=Math.imul(T,V),n=n+Math.imul(b,H)|0,i=(i=i+Math.imul(b,G)|0)+Math.imul(_,H)|0,a=a+Math.imul(_,G)|0,n=n+Math.imul(m,W)|0,i=(i=i+Math.imul(m,X)|0)+Math.imul(y,W)|0,a=a+Math.imul(y,X)|0,n=n+Math.imul(d,J)|0,i=(i=i+Math.imul(d,K)|0)+Math.imul(g,J)|0,a=a+Math.imul(g,K)|0;var bt=(c+(n=n+Math.imul(h,Q)|0)|0)+((8191&(i=(i=i+Math.imul(h,tt)|0)+Math.imul(f,Q)|0))<<13)|0;c=((a=a+Math.imul(f,tt)|0)+(i>>>13)|0)+(bt>>>26)|0,bt&=67108863,n=Math.imul(M,U),i=(i=Math.imul(M,V))+Math.imul(S,U)|0,a=Math.imul(S,V),n=n+Math.imul(k,H)|0,i=(i=i+Math.imul(k,G)|0)+Math.imul(T,H)|0,a=a+Math.imul(T,G)|0,n=n+Math.imul(b,W)|0,i=(i=i+Math.imul(b,X)|0)+Math.imul(_,W)|0,a=a+Math.imul(_,X)|0,n=n+Math.imul(m,J)|0,i=(i=i+Math.imul(m,K)|0)+Math.imul(y,J)|0,a=a+Math.imul(y,K)|0,n=n+Math.imul(d,Q)|0,i=(i=i+Math.imul(d,tt)|0)+Math.imul(g,Q)|0,a=a+Math.imul(g,tt)|0;var _t=(c+(n=n+Math.imul(h,rt)|0)|0)+((8191&(i=(i=i+Math.imul(h,nt)|0)+Math.imul(f,rt)|0))<<13)|0;c=((a=a+Math.imul(f,nt)|0)+(i>>>13)|0)+(_t>>>26)|0,_t&=67108863,n=Math.imul(C,U),i=(i=Math.imul(C,V))+Math.imul(L,U)|0,a=Math.imul(L,V),n=n+Math.imul(M,H)|0,i=(i=i+Math.imul(M,G)|0)+Math.imul(S,H)|0,a=a+Math.imul(S,G)|0,n=n+Math.imul(k,W)|0,i=(i=i+Math.imul(k,X)|0)+Math.imul(T,W)|0,a=a+Math.imul(T,X)|0,n=n+Math.imul(b,J)|0,i=(i=i+Math.imul(b,K)|0)+Math.imul(_,J)|0,a=a+Math.imul(_,K)|0,n=n+Math.imul(m,Q)|0,i=(i=i+Math.imul(m,tt)|0)+Math.imul(y,Q)|0,a=a+Math.imul(y,tt)|0,n=n+Math.imul(d,rt)|0,i=(i=i+Math.imul(d,nt)|0)+Math.imul(g,rt)|0,a=a+Math.imul(g,nt)|0;var wt=(c+(n=n+Math.imul(h,at)|0)|0)+((8191&(i=(i=i+Math.imul(h,ot)|0)+Math.imul(f,at)|0))<<13)|0;c=((a=a+Math.imul(f,ot)|0)+(i>>>13)|0)+(wt>>>26)|0,wt&=67108863,n=Math.imul(O,U),i=(i=Math.imul(O,V))+Math.imul(z,U)|0,a=Math.imul(z,V),n=n+Math.imul(C,H)|0,i=(i=i+Math.imul(C,G)|0)+Math.imul(L,H)|0,a=a+Math.imul(L,G)|0,n=n+Math.imul(M,W)|0,i=(i=i+Math.imul(M,X)|0)+Math.imul(S,W)|0,a=a+Math.imul(S,X)|0,n=n+Math.imul(k,J)|0,i=(i=i+Math.imul(k,K)|0)+Math.imul(T,J)|0,a=a+Math.imul(T,K)|0,n=n+Math.imul(b,Q)|0,i=(i=i+Math.imul(b,tt)|0)+Math.imul(_,Q)|0,a=a+Math.imul(_,tt)|0,n=n+Math.imul(m,rt)|0,i=(i=i+Math.imul(m,nt)|0)+Math.imul(y,rt)|0,a=a+Math.imul(y,nt)|0,n=n+Math.imul(d,at)|0,i=(i=i+Math.imul(d,ot)|0)+Math.imul(g,at)|0,a=a+Math.imul(g,ot)|0;var kt=(c+(n=n+Math.imul(h,lt)|0)|0)+((8191&(i=(i=i+Math.imul(h,ct)|0)+Math.imul(f,lt)|0))<<13)|0;c=((a=a+Math.imul(f,ct)|0)+(i>>>13)|0)+(kt>>>26)|0,kt&=67108863,n=Math.imul(D,U),i=(i=Math.imul(D,V))+Math.imul(R,U)|0,a=Math.imul(R,V),n=n+Math.imul(O,H)|0,i=(i=i+Math.imul(O,G)|0)+Math.imul(z,H)|0,a=a+Math.imul(z,G)|0,n=n+Math.imul(C,W)|0,i=(i=i+Math.imul(C,X)|0)+Math.imul(L,W)|0,a=a+Math.imul(L,X)|0,n=n+Math.imul(M,J)|0,i=(i=i+Math.imul(M,K)|0)+Math.imul(S,J)|0,a=a+Math.imul(S,K)|0,n=n+Math.imul(k,Q)|0,i=(i=i+Math.imul(k,tt)|0)+Math.imul(T,Q)|0,a=a+Math.imul(T,tt)|0,n=n+Math.imul(b,rt)|0,i=(i=i+Math.imul(b,nt)|0)+Math.imul(_,rt)|0,a=a+Math.imul(_,nt)|0,n=n+Math.imul(m,at)|0,i=(i=i+Math.imul(m,ot)|0)+Math.imul(y,at)|0,a=a+Math.imul(y,ot)|0,n=n+Math.imul(d,lt)|0,i=(i=i+Math.imul(d,ct)|0)+Math.imul(g,lt)|0,a=a+Math.imul(g,ct)|0;var Tt=(c+(n=n+Math.imul(h,ht)|0)|0)+((8191&(i=(i=i+Math.imul(h,ft)|0)+Math.imul(f,ht)|0))<<13)|0;c=((a=a+Math.imul(f,ft)|0)+(i>>>13)|0)+(Tt>>>26)|0,Tt&=67108863,n=Math.imul(B,U),i=(i=Math.imul(B,V))+Math.imul(N,U)|0,a=Math.imul(N,V),n=n+Math.imul(D,H)|0,i=(i=i+Math.imul(D,G)|0)+Math.imul(R,H)|0,a=a+Math.imul(R,G)|0,n=n+Math.imul(O,W)|0,i=(i=i+Math.imul(O,X)|0)+Math.imul(z,W)|0,a=a+Math.imul(z,X)|0,n=n+Math.imul(C,J)|0,i=(i=i+Math.imul(C,K)|0)+Math.imul(L,J)|0,a=a+Math.imul(L,K)|0,n=n+Math.imul(M,Q)|0,i=(i=i+Math.imul(M,tt)|0)+Math.imul(S,Q)|0,a=a+Math.imul(S,tt)|0,n=n+Math.imul(k,rt)|0,i=(i=i+Math.imul(k,nt)|0)+Math.imul(T,rt)|0,a=a+Math.imul(T,nt)|0,n=n+Math.imul(b,at)|0,i=(i=i+Math.imul(b,ot)|0)+Math.imul(_,at)|0,a=a+Math.imul(_,ot)|0,n=n+Math.imul(m,lt)|0,i=(i=i+Math.imul(m,ct)|0)+Math.imul(y,lt)|0,a=a+Math.imul(y,ct)|0,n=n+Math.imul(d,ht)|0,i=(i=i+Math.imul(d,ft)|0)+Math.imul(g,ht)|0,a=a+Math.imul(g,ft)|0;var At=(c+(n=n+Math.imul(h,dt)|0)|0)+((8191&(i=(i=i+Math.imul(h,gt)|0)+Math.imul(f,dt)|0))<<13)|0;c=((a=a+Math.imul(f,gt)|0)+(i>>>13)|0)+(At>>>26)|0,At&=67108863,n=Math.imul(B,H),i=(i=Math.imul(B,G))+Math.imul(N,H)|0,a=Math.imul(N,G),n=n+Math.imul(D,W)|0,i=(i=i+Math.imul(D,X)|0)+Math.imul(R,W)|0,a=a+Math.imul(R,X)|0,n=n+Math.imul(O,J)|0,i=(i=i+Math.imul(O,K)|0)+Math.imul(z,J)|0,a=a+Math.imul(z,K)|0,n=n+Math.imul(C,Q)|0,i=(i=i+Math.imul(C,tt)|0)+Math.imul(L,Q)|0,a=a+Math.imul(L,tt)|0,n=n+Math.imul(M,rt)|0,i=(i=i+Math.imul(M,nt)|0)+Math.imul(S,rt)|0,a=a+Math.imul(S,nt)|0,n=n+Math.imul(k,at)|0,i=(i=i+Math.imul(k,ot)|0)+Math.imul(T,at)|0,a=a+Math.imul(T,ot)|0,n=n+Math.imul(b,lt)|0,i=(i=i+Math.imul(b,ct)|0)+Math.imul(_,lt)|0,a=a+Math.imul(_,ct)|0,n=n+Math.imul(m,ht)|0,i=(i=i+Math.imul(m,ft)|0)+Math.imul(y,ht)|0,a=a+Math.imul(y,ft)|0;var Mt=(c+(n=n+Math.imul(d,dt)|0)|0)+((8191&(i=(i=i+Math.imul(d,gt)|0)+Math.imul(g,dt)|0))<<13)|0;c=((a=a+Math.imul(g,gt)|0)+(i>>>13)|0)+(Mt>>>26)|0,Mt&=67108863,n=Math.imul(B,W),i=(i=Math.imul(B,X))+Math.imul(N,W)|0,a=Math.imul(N,X),n=n+Math.imul(D,J)|0,i=(i=i+Math.imul(D,K)|0)+Math.imul(R,J)|0,a=a+Math.imul(R,K)|0,n=n+Math.imul(O,Q)|0,i=(i=i+Math.imul(O,tt)|0)+Math.imul(z,Q)|0,a=a+Math.imul(z,tt)|0,n=n+Math.imul(C,rt)|0,i=(i=i+Math.imul(C,nt)|0)+Math.imul(L,rt)|0,a=a+Math.imul(L,nt)|0,n=n+Math.imul(M,at)|0,i=(i=i+Math.imul(M,ot)|0)+Math.imul(S,at)|0,a=a+Math.imul(S,ot)|0,n=n+Math.imul(k,lt)|0,i=(i=i+Math.imul(k,ct)|0)+Math.imul(T,lt)|0,a=a+Math.imul(T,ct)|0,n=n+Math.imul(b,ht)|0,i=(i=i+Math.imul(b,ft)|0)+Math.imul(_,ht)|0,a=a+Math.imul(_,ft)|0;var St=(c+(n=n+Math.imul(m,dt)|0)|0)+((8191&(i=(i=i+Math.imul(m,gt)|0)+Math.imul(y,dt)|0))<<13)|0;c=((a=a+Math.imul(y,gt)|0)+(i>>>13)|0)+(St>>>26)|0,St&=67108863,n=Math.imul(B,J),i=(i=Math.imul(B,K))+Math.imul(N,J)|0,a=Math.imul(N,K),n=n+Math.imul(D,Q)|0,i=(i=i+Math.imul(D,tt)|0)+Math.imul(R,Q)|0,a=a+Math.imul(R,tt)|0,n=n+Math.imul(O,rt)|0,i=(i=i+Math.imul(O,nt)|0)+Math.imul(z,rt)|0,a=a+Math.imul(z,nt)|0,n=n+Math.imul(C,at)|0,i=(i=i+Math.imul(C,ot)|0)+Math.imul(L,at)|0,a=a+Math.imul(L,ot)|0,n=n+Math.imul(M,lt)|0,i=(i=i+Math.imul(M,ct)|0)+Math.imul(S,lt)|0,a=a+Math.imul(S,ct)|0,n=n+Math.imul(k,ht)|0,i=(i=i+Math.imul(k,ft)|0)+Math.imul(T,ht)|0,a=a+Math.imul(T,ft)|0;var Et=(c+(n=n+Math.imul(b,dt)|0)|0)+((8191&(i=(i=i+Math.imul(b,gt)|0)+Math.imul(_,dt)|0))<<13)|0;c=((a=a+Math.imul(_,gt)|0)+(i>>>13)|0)+(Et>>>26)|0,Et&=67108863,n=Math.imul(B,Q),i=(i=Math.imul(B,tt))+Math.imul(N,Q)|0,a=Math.imul(N,tt),n=n+Math.imul(D,rt)|0,i=(i=i+Math.imul(D,nt)|0)+Math.imul(R,rt)|0,a=a+Math.imul(R,nt)|0,n=n+Math.imul(O,at)|0,i=(i=i+Math.imul(O,ot)|0)+Math.imul(z,at)|0,a=a+Math.imul(z,ot)|0,n=n+Math.imul(C,lt)|0,i=(i=i+Math.imul(C,ct)|0)+Math.imul(L,lt)|0,a=a+Math.imul(L,ct)|0,n=n+Math.imul(M,ht)|0,i=(i=i+Math.imul(M,ft)|0)+Math.imul(S,ht)|0,a=a+Math.imul(S,ft)|0;var Ct=(c+(n=n+Math.imul(k,dt)|0)|0)+((8191&(i=(i=i+Math.imul(k,gt)|0)+Math.imul(T,dt)|0))<<13)|0;c=((a=a+Math.imul(T,gt)|0)+(i>>>13)|0)+(Ct>>>26)|0,Ct&=67108863,n=Math.imul(B,rt),i=(i=Math.imul(B,nt))+Math.imul(N,rt)|0,a=Math.imul(N,nt),n=n+Math.imul(D,at)|0,i=(i=i+Math.imul(D,ot)|0)+Math.imul(R,at)|0,a=a+Math.imul(R,ot)|0,n=n+Math.imul(O,lt)|0,i=(i=i+Math.imul(O,ct)|0)+Math.imul(z,lt)|0,a=a+Math.imul(z,ct)|0,n=n+Math.imul(C,ht)|0,i=(i=i+Math.imul(C,ft)|0)+Math.imul(L,ht)|0,a=a+Math.imul(L,ft)|0;var Lt=(c+(n=n+Math.imul(M,dt)|0)|0)+((8191&(i=(i=i+Math.imul(M,gt)|0)+Math.imul(S,dt)|0))<<13)|0;c=((a=a+Math.imul(S,gt)|0)+(i>>>13)|0)+(Lt>>>26)|0,Lt&=67108863,n=Math.imul(B,at),i=(i=Math.imul(B,ot))+Math.imul(N,at)|0,a=Math.imul(N,ot),n=n+Math.imul(D,lt)|0,i=(i=i+Math.imul(D,ct)|0)+Math.imul(R,lt)|0,a=a+Math.imul(R,ct)|0,n=n+Math.imul(O,ht)|0,i=(i=i+Math.imul(O,ft)|0)+Math.imul(z,ht)|0,a=a+Math.imul(z,ft)|0;var Pt=(c+(n=n+Math.imul(C,dt)|0)|0)+((8191&(i=(i=i+Math.imul(C,gt)|0)+Math.imul(L,dt)|0))<<13)|0;c=((a=a+Math.imul(L,gt)|0)+(i>>>13)|0)+(Pt>>>26)|0,Pt&=67108863,n=Math.imul(B,lt),i=(i=Math.imul(B,ct))+Math.imul(N,lt)|0,a=Math.imul(N,ct),n=n+Math.imul(D,ht)|0,i=(i=i+Math.imul(D,ft)|0)+Math.imul(R,ht)|0,a=a+Math.imul(R,ft)|0;var Ot=(c+(n=n+Math.imul(O,dt)|0)|0)+((8191&(i=(i=i+Math.imul(O,gt)|0)+Math.imul(z,dt)|0))<<13)|0;c=((a=a+Math.imul(z,gt)|0)+(i>>>13)|0)+(Ot>>>26)|0,Ot&=67108863,n=Math.imul(B,ht),i=(i=Math.imul(B,ft))+Math.imul(N,ht)|0,a=Math.imul(N,ft);var zt=(c+(n=n+Math.imul(D,dt)|0)|0)+((8191&(i=(i=i+Math.imul(D,gt)|0)+Math.imul(R,dt)|0))<<13)|0;c=((a=a+Math.imul(R,gt)|0)+(i>>>13)|0)+(zt>>>26)|0,zt&=67108863;var It=(c+(n=Math.imul(B,dt))|0)+((8191&(i=(i=Math.imul(B,gt))+Math.imul(N,dt)|0))<<13)|0;return c=((a=Math.imul(N,gt))+(i>>>13)|0)+(It>>>26)|0,It&=67108863,l[0]=vt,l[1]=mt,l[2]=yt,l[3]=xt,l[4]=bt,l[5]=_t,l[6]=wt,l[7]=kt,l[8]=Tt,l[9]=At,l[10]=Mt,l[11]=St,l[12]=Et,l[13]=Ct,l[14]=Lt,l[15]=Pt,l[16]=Ot,l[17]=zt,l[18]=It,0!==c&&(l[19]=c,r.length++),r};function d(t,e,r){return(new g).mulp(t,e,r)}function g(t,e){this.x=t,this.y=e}Math.imul||(p=f),a.prototype.mulTo=function(t,e){var r=this.length+t.length;return 10===this.length&&10===t.length?p(this,t,e):r<63?f(this,t,e):r<1024?function(t,e,r){r.negative=e.negative^t.negative,r.length=t.length+e.length;for(var n=0,i=0,a=0;a<r.length-1;a++){var o=i;i=0;for(var s=67108863&n,l=Math.min(a,e.length-1),c=Math.max(0,a-t.length+1);c<=l;c++){var u=a-c,h=(0|t.words[u])*(0|e.words[c]),f=67108863&h;s=67108863&(f=f+s|0),i+=(o=(o=o+(h/67108864|0)|0)+(f>>>26)|0)>>>26,o&=67108863}r.words[a]=s,n=o,o=i}return 0!==n?r.words[a]=n:r.length--,r.strip()}(this,t,e):d(this,t,e)},g.prototype.makeRBT=function(t){for(var e=new Array(t),r=a.prototype._countBits(t)-1,n=0;n<t;n++)e[n]=this.revBin(n,r,t);return e},g.prototype.revBin=function(t,e,r){if(0===t||t===r-1)return t;for(var n=0,i=0;i<e;i++)n|=(1&t)<<e-i-1,t>>=1;return n},g.prototype.permute=function(t,e,r,n,i,a){for(var o=0;o<a;o++)n[o]=e[t[o]],i[o]=r[t[o]]},g.prototype.transform=function(t,e,r,n,i,a){this.permute(a,t,e,r,n,i);for(var o=1;o<i;o<<=1)for(var s=o<<1,l=Math.cos(2*Math.PI/s),c=Math.sin(2*Math.PI/s),u=0;u<i;u+=s)for(var h=l,f=c,p=0;p<o;p++){var d=r[u+p],g=n[u+p],v=r[u+p+o],m=n[u+p+o],y=h*v-f*m;m=h*m+f*v,v=y,r[u+p]=d+v,n[u+p]=g+m,r[u+p+o]=d-v,n[u+p+o]=g-m,p!==s&&(y=l*h-c*f,f=l*f+c*h,h=y)}},g.prototype.guessLen13b=function(t,e){var r=1|Math.max(e,t),n=1&r,i=0;for(r=r/2|0;r;r>>>=1)i++;return 1<<i+1+n},g.prototype.conjugate=function(t,e,r){if(!(r<=1))for(var n=0;n<r/2;n++){var i=t[n];t[n]=t[r-n-1],t[r-n-1]=i,i=e[n],e[n]=-e[r-n-1],e[r-n-1]=-i}},g.prototype.normalize13b=function(t,e){for(var r=0,n=0;n<e/2;n++){var i=8192*Math.round(t[2*n+1]/e)+Math.round(t[2*n]/e)+r;t[n]=67108863&i,r=i<67108864?0:i/67108864|0}return t},g.prototype.convert13b=function(t,e,r,i){for(var a=0,o=0;o<e;o++)a+=0|t[o],r[2*o]=8191&a,a>>>=13,r[2*o+1]=8191&a,a>>>=13;for(o=2*e;o<i;++o)r[o]=0;n(0===a),n(0==(-8192&a))},g.prototype.stub=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=0;return e},g.prototype.mulp=function(t,e,r){var n=2*this.guessLen13b(t.length,e.length),i=this.makeRBT(n),a=this.stub(n),o=new Array(n),s=new Array(n),l=new Array(n),c=new Array(n),u=new Array(n),h=new Array(n),f=r.words;f.length=n,this.convert13b(t.words,t.length,o,n),this.convert13b(e.words,e.length,c,n),this.transform(o,a,s,l,n,i),this.transform(c,a,u,h,n,i);for(var p=0;p<n;p++){var d=s[p]*u[p]-l[p]*h[p];l[p]=s[p]*h[p]+l[p]*u[p],s[p]=d}return this.conjugate(s,l,n),this.transform(s,l,f,a,n,i),this.conjugate(f,a,n),this.normalize13b(f,n),r.negative=t.negative^e.negative,r.length=t.length+e.length,r.strip()},a.prototype.mul=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),this.mulTo(t,e)},a.prototype.mulf=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),d(this,t,e)},a.prototype.imul=function(t){return this.clone().mulTo(t,this)},a.prototype.imuln=function(t){n(\"number\"==typeof t),n(t<67108864);for(var e=0,r=0;r<this.length;r++){var i=(0|this.words[r])*t,a=(67108863&i)+(67108863&e);e>>=26,e+=i/67108864|0,e+=a>>>26,this.words[r]=67108863&a}return 0!==e&&(this.words[r]=e,this.length++),this},a.prototype.muln=function(t){return this.clone().imuln(t)},a.prototype.sqr=function(){return this.mul(this)},a.prototype.isqr=function(){return this.imul(this.clone())},a.prototype.pow=function(t){var e=function(t){for(var e=new Array(t.bitLength()),r=0;r<e.length;r++){var n=r/26|0,i=r%26;e[r]=(t.words[n]&1<<i)>>>i}return e}(t);if(0===e.length)return new a(1);for(var r=this,n=0;n<e.length&&0===e[n];n++,r=r.sqr());if(++n<e.length)for(var i=r.sqr();n<e.length;n++,i=i.sqr())0!==e[n]&&(r=r.mul(i));return r},a.prototype.iushln=function(t){n(\"number\"==typeof t&&t>=0);var e,r=t%26,i=(t-r)/26,a=67108863>>>26-r<<26-r;if(0!==r){var o=0;for(e=0;e<this.length;e++){var s=this.words[e]&a,l=(0|this.words[e])-s<<r;this.words[e]=l|o,o=s>>>26-r}o&&(this.words[e]=o,this.length++)}if(0!==i){for(e=this.length-1;e>=0;e--)this.words[e+i]=this.words[e];for(e=0;e<i;e++)this.words[e]=0;this.length+=i}return this.strip()},a.prototype.ishln=function(t){return n(0===this.negative),this.iushln(t)},a.prototype.iushrn=function(t,e,r){var i;n(\"number\"==typeof t&&t>=0),i=e?(e-e%26)/26:0;var a=t%26,o=Math.min((t-a)/26,this.length),s=67108863^67108863>>>a<<a,l=r;if(i-=o,i=Math.max(0,i),l){for(var c=0;c<o;c++)l.words[c]=this.words[c];l.length=o}if(0===o);else if(this.length>o)for(this.length-=o,c=0;c<this.length;c++)this.words[c]=this.words[c+o];else this.words[0]=0,this.length=1;var u=0;for(c=this.length-1;c>=0&&(0!==u||c>=i);c--){var h=0|this.words[c];this.words[c]=u<<26-a|h>>>a,u=h&s}return l&&0!==u&&(l.words[l.length++]=u),0===this.length&&(this.words[0]=0,this.length=1),this.strip()},a.prototype.ishrn=function(t,e,r){return n(0===this.negative),this.iushrn(t,e,r)},a.prototype.shln=function(t){return this.clone().ishln(t)},a.prototype.ushln=function(t){return this.clone().iushln(t)},a.prototype.shrn=function(t){return this.clone().ishrn(t)},a.prototype.ushrn=function(t){return this.clone().iushrn(t)},a.prototype.testn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26,i=1<<e;return!(this.length<=r)&&!!(this.words[r]&i)},a.prototype.imaskn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26;if(n(0===this.negative,\"imaskn works only with positive numbers\"),this.length<=r)return this;if(0!==e&&r++,this.length=Math.min(r,this.length),0!==e){var i=67108863^67108863>>>e<<e;this.words[this.length-1]&=i}return this.strip()},a.prototype.maskn=function(t){return this.clone().imaskn(t)},a.prototype.iaddn=function(t){return n(\"number\"==typeof t),n(t<67108864),t<0?this.isubn(-t):0!==this.negative?1===this.length&&(0|this.words[0])<t?(this.words[0]=t-(0|this.words[0]),this.negative=0,this):(this.negative=0,this.isubn(t),this.negative=1,this):this._iaddn(t)},a.prototype._iaddn=function(t){this.words[0]+=t;for(var e=0;e<this.length&&this.words[e]>=67108864;e++)this.words[e]-=67108864,e===this.length-1?this.words[e+1]=1:this.words[e+1]++;return this.length=Math.max(this.length,e+1),this},a.prototype.isubn=function(t){if(n(\"number\"==typeof t),n(t<67108864),t<0)return this.iaddn(-t);if(0!==this.negative)return this.negative=0,this.iaddn(t),this.negative=1,this;if(this.words[0]-=t,1===this.length&&this.words[0]<0)this.words[0]=-this.words[0],this.negative=1;else for(var e=0;e<this.length&&this.words[e]<0;e++)this.words[e]+=67108864,this.words[e+1]-=1;return this.strip()},a.prototype.addn=function(t){return this.clone().iaddn(t)},a.prototype.subn=function(t){return this.clone().isubn(t)},a.prototype.iabs=function(){return this.negative=0,this},a.prototype.abs=function(){return this.clone().iabs()},a.prototype._ishlnsubmul=function(t,e,r){var i,a,o=t.length+r;this._expand(o);var s=0;for(i=0;i<t.length;i++){a=(0|this.words[i+r])+s;var l=(0|t.words[i])*e;s=((a-=67108863&l)>>26)-(l/67108864|0),this.words[i+r]=67108863&a}for(;i<this.length-r;i++)s=(a=(0|this.words[i+r])+s)>>26,this.words[i+r]=67108863&a;if(0===s)return this.strip();for(n(-1===s),s=0,i=0;i<this.length;i++)s=(a=-(0|this.words[i])+s)>>26,this.words[i]=67108863&a;return this.negative=1,this.strip()},a.prototype._wordDiv=function(t,e){var r=(this.length,t.length),n=this.clone(),i=t,o=0|i.words[i.length-1];0!==(r=26-this._countBits(o))&&(i=i.ushln(r),n.iushln(r),o=0|i.words[i.length-1]);var s,l=n.length-i.length;if(\"mod\"!==e){(s=new a(null)).length=l+1,s.words=new Array(s.length);for(var c=0;c<s.length;c++)s.words[c]=0}var u=n.clone()._ishlnsubmul(i,1,l);0===u.negative&&(n=u,s&&(s.words[l]=1));for(var h=l-1;h>=0;h--){var f=67108864*(0|n.words[i.length+h])+(0|n.words[i.length+h-1]);for(f=Math.min(f/o|0,67108863),n._ishlnsubmul(i,f,h);0!==n.negative;)f--,n.negative=0,n._ishlnsubmul(i,1,h),n.isZero()||(n.negative^=1);s&&(s.words[h]=f)}return s&&s.strip(),n.strip(),\"div\"!==e&&0!==r&&n.iushrn(r),{div:s||null,mod:n}},a.prototype.divmod=function(t,e,r){return n(!t.isZero()),this.isZero()?{div:new a(0),mod:new a(0)}:0!==this.negative&&0===t.negative?(s=this.neg().divmod(t,e),\"mod\"!==e&&(i=s.div.neg()),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.iadd(t)),{div:i,mod:o}):0===this.negative&&0!==t.negative?(s=this.divmod(t.neg(),e),\"mod\"!==e&&(i=s.div.neg()),{div:i,mod:s.mod}):0!=(this.negative&t.negative)?(s=this.neg().divmod(t.neg(),e),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.isub(t)),{div:s.div,mod:o}):t.length>this.length||this.cmp(t)<0?{div:new a(0),mod:this}:1===t.length?\"div\"===e?{div:this.divn(t.words[0]),mod:null}:\"mod\"===e?{div:null,mod:new a(this.modn(t.words[0]))}:{div:this.divn(t.words[0]),mod:new a(this.modn(t.words[0]))}:this._wordDiv(t,e);var i,o,s},a.prototype.div=function(t){return this.divmod(t,\"div\",!1).div},a.prototype.mod=function(t){return this.divmod(t,\"mod\",!1).mod},a.prototype.umod=function(t){return this.divmod(t,\"mod\",!0).mod},a.prototype.divRound=function(t){var e=this.divmod(t);if(e.mod.isZero())return e.div;var r=0!==e.div.negative?e.mod.isub(t):e.mod,n=t.ushrn(1),i=t.andln(1),a=r.cmp(n);return a<0||1===i&&0===a?e.div:0!==e.div.negative?e.div.isubn(1):e.div.iaddn(1)},a.prototype.modn=function(t){n(t<=67108863);for(var e=(1<<26)%t,r=0,i=this.length-1;i>=0;i--)r=(e*r+(0|this.words[i]))%t;return r},a.prototype.idivn=function(t){n(t<=67108863);for(var e=0,r=this.length-1;r>=0;r--){var i=(0|this.words[r])+67108864*e;this.words[r]=i/t|0,e=i%t}return this.strip()},a.prototype.divn=function(t){return this.clone().idivn(t)},a.prototype.egcd=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i=new a(1),o=new a(0),s=new a(0),l=new a(1),c=0;e.isEven()&&r.isEven();)e.iushrn(1),r.iushrn(1),++c;for(var u=r.clone(),h=e.clone();!e.isZero();){for(var f=0,p=1;0==(e.words[0]&p)&&f<26;++f,p<<=1);if(f>0)for(e.iushrn(f);f-- >0;)(i.isOdd()||o.isOdd())&&(i.iadd(u),o.isub(h)),i.iushrn(1),o.iushrn(1);for(var d=0,g=1;0==(r.words[0]&g)&&d<26;++d,g<<=1);if(d>0)for(r.iushrn(d);d-- >0;)(s.isOdd()||l.isOdd())&&(s.iadd(u),l.isub(h)),s.iushrn(1),l.iushrn(1);e.cmp(r)>=0?(e.isub(r),i.isub(s),o.isub(l)):(r.isub(e),s.isub(i),l.isub(o))}return{a:s,b:l,gcd:r.iushln(c)}},a.prototype._invmp=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i,o=new a(1),s=new a(0),l=r.clone();e.cmpn(1)>0&&r.cmpn(1)>0;){for(var c=0,u=1;0==(e.words[0]&u)&&c<26;++c,u<<=1);if(c>0)for(e.iushrn(c);c-- >0;)o.isOdd()&&o.iadd(l),o.iushrn(1);for(var h=0,f=1;0==(r.words[0]&f)&&h<26;++h,f<<=1);if(h>0)for(r.iushrn(h);h-- >0;)s.isOdd()&&s.iadd(l),s.iushrn(1);e.cmp(r)>=0?(e.isub(r),o.isub(s)):(r.isub(e),s.isub(o))}return(i=0===e.cmpn(1)?o:s).cmpn(0)<0&&i.iadd(t),i},a.prototype.gcd=function(t){if(this.isZero())return t.abs();if(t.isZero())return this.abs();var e=this.clone(),r=t.clone();e.negative=0,r.negative=0;for(var n=0;e.isEven()&&r.isEven();n++)e.iushrn(1),r.iushrn(1);for(;;){for(;e.isEven();)e.iushrn(1);for(;r.isEven();)r.iushrn(1);var i=e.cmp(r);if(i<0){var a=e;e=r,r=a}else if(0===i||0===r.cmpn(1))break;e.isub(r)}return r.iushln(n)},a.prototype.invm=function(t){return this.egcd(t).a.umod(t)},a.prototype.isEven=function(){return 0==(1&this.words[0])},a.prototype.isOdd=function(){return 1==(1&this.words[0])},a.prototype.andln=function(t){return this.words[0]&t},a.prototype.bincn=function(t){n(\"number\"==typeof t);var e=t%26,r=(t-e)/26,i=1<<e;if(this.length<=r)return this._expand(r+1),this.words[r]|=i,this;for(var a=i,o=r;0!==a&&o<this.length;o++){var s=0|this.words[o];a=(s+=a)>>>26,s&=67108863,this.words[o]=s}return 0!==a&&(this.words[o]=a,this.length++),this},a.prototype.isZero=function(){return 1===this.length&&0===this.words[0]},a.prototype.cmpn=function(t){var e,r=t<0;if(0!==this.negative&&!r)return-1;if(0===this.negative&&r)return 1;if(this.strip(),this.length>1)e=1;else{r&&(t=-t),n(t<=67108863,\"Number is too big\");var i=0|this.words[0];e=i===t?0:i<t?-1:1}return 0!==this.negative?0|-e:e},a.prototype.cmp=function(t){if(0!==this.negative&&0===t.negative)return-1;if(0===this.negative&&0!==t.negative)return 1;var e=this.ucmp(t);return 0!==this.negative?0|-e:e},a.prototype.ucmp=function(t){if(this.length>t.length)return 1;if(this.length<t.length)return-1;for(var e=0,r=this.length-1;r>=0;r--){var n=0|this.words[r],i=0|t.words[r];if(n!==i){n<i?e=-1:n>i&&(e=1);break}}return e},a.prototype.gtn=function(t){return 1===this.cmpn(t)},a.prototype.gt=function(t){return 1===this.cmp(t)},a.prototype.gten=function(t){return this.cmpn(t)>=0},a.prototype.gte=function(t){return this.cmp(t)>=0},a.prototype.ltn=function(t){return-1===this.cmpn(t)},a.prototype.lt=function(t){return-1===this.cmp(t)},a.prototype.lten=function(t){return this.cmpn(t)<=0},a.prototype.lte=function(t){return this.cmp(t)<=0},a.prototype.eqn=function(t){return 0===this.cmpn(t)},a.prototype.eq=function(t){return 0===this.cmp(t)},a.red=function(t){return new w(t)},a.prototype.toRed=function(t){return n(!this.red,\"Already a number in reduction context\"),n(0===this.negative,\"red works only with positives\"),t.convertTo(this)._forceRed(t)},a.prototype.fromRed=function(){return n(this.red,\"fromRed works only with numbers in reduction context\"),this.red.convertFrom(this)},a.prototype._forceRed=function(t){return this.red=t,this},a.prototype.forceRed=function(t){return n(!this.red,\"Already a number in reduction context\"),this._forceRed(t)},a.prototype.redAdd=function(t){return n(this.red,\"redAdd works only with red numbers\"),this.red.add(this,t)},a.prototype.redIAdd=function(t){return n(this.red,\"redIAdd works only with red numbers\"),this.red.iadd(this,t)},a.prototype.redSub=function(t){return n(this.red,\"redSub works only with red numbers\"),this.red.sub(this,t)},a.prototype.redISub=function(t){return n(this.red,\"redISub works only with red numbers\"),this.red.isub(this,t)},a.prototype.redShl=function(t){return n(this.red,\"redShl works only with red numbers\"),this.red.shl(this,t)},a.prototype.redMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.mul(this,t)},a.prototype.redIMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.imul(this,t)},a.prototype.redSqr=function(){return n(this.red,\"redSqr works only with red numbers\"),this.red._verify1(this),this.red.sqr(this)},a.prototype.redISqr=function(){return n(this.red,\"redISqr works only with red numbers\"),this.red._verify1(this),this.red.isqr(this)},a.prototype.redSqrt=function(){return n(this.red,\"redSqrt works only with red numbers\"),this.red._verify1(this),this.red.sqrt(this)},a.prototype.redInvm=function(){return n(this.red,\"redInvm works only with red numbers\"),this.red._verify1(this),this.red.invm(this)},a.prototype.redNeg=function(){return n(this.red,\"redNeg works only with red numbers\"),this.red._verify1(this),this.red.neg(this)},a.prototype.redPow=function(t){return n(this.red&&!t.red,\"redPow(normalNum)\"),this.red._verify1(this),this.red.pow(this,t)};var v={k256:null,p224:null,p192:null,p25519:null};function m(t,e){this.name=t,this.p=new a(e,16),this.n=this.p.bitLength(),this.k=new a(1).iushln(this.n).isub(this.p),this.tmp=this._tmp()}function y(){m.call(this,\"k256\",\"ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffe fffffc2f\")}function x(){m.call(this,\"p224\",\"ffffffff ffffffff ffffffff ffffffff 00000000 00000000 00000001\")}function b(){m.call(this,\"p192\",\"ffffffff ffffffff ffffffff fffffffe ffffffff ffffffff\")}function _(){m.call(this,\"25519\",\"7fffffffffffffff ffffffffffffffff ffffffffffffffff ffffffffffffffed\")}function w(t){if(\"string\"==typeof t){var e=a._prime(t);this.m=e.p,this.prime=e}else n(t.gtn(1),\"modulus must be greater than 1\"),this.m=t,this.prime=null}function k(t){w.call(this,t),this.shift=this.m.bitLength(),this.shift%26!=0&&(this.shift+=26-this.shift%26),this.r=new a(1).iushln(this.shift),this.r2=this.imod(this.r.sqr()),this.rinv=this.r._invmp(this.m),this.minv=this.rinv.mul(this.r).isubn(1).div(this.m),this.minv=this.minv.umod(this.r),this.minv=this.r.sub(this.minv)}m.prototype._tmp=function(){var t=new a(null);return t.words=new Array(Math.ceil(this.n/13)),t},m.prototype.ireduce=function(t){var e,r=t;do{this.split(r,this.tmp),e=(r=(r=this.imulK(r)).iadd(this.tmp)).bitLength()}while(e>this.n);var n=e<this.n?-1:r.ucmp(this.p);return 0===n?(r.words[0]=0,r.length=1):n>0?r.isub(this.p):r.strip(),r},m.prototype.split=function(t,e){t.iushrn(this.n,0,e)},m.prototype.imulK=function(t){return t.imul(this.k)},i(y,m),y.prototype.split=function(t,e){for(var r=Math.min(t.length,9),n=0;n<r;n++)e.words[n]=t.words[n];if(e.length=r,t.length<=9)return t.words[0]=0,void(t.length=1);var i=t.words[9];for(e.words[e.length++]=4194303&i,n=10;n<t.length;n++){var a=0|t.words[n];t.words[n-10]=(4194303&a)<<4|i>>>22,i=a}i>>>=22,t.words[n-10]=i,0===i&&t.length>10?t.length-=10:t.length-=9},y.prototype.imulK=function(t){t.words[t.length]=0,t.words[t.length+1]=0,t.length+=2;for(var e=0,r=0;r<t.length;r++){var n=0|t.words[r];e+=977*n,t.words[r]=67108863&e,e=64*n+(e/67108864|0)}return 0===t.words[t.length-1]&&(t.length--,0===t.words[t.length-1]&&t.length--),t},i(x,m),i(b,m),i(_,m),_.prototype.imulK=function(t){for(var e=0,r=0;r<t.length;r++){var n=19*(0|t.words[r])+e,i=67108863&n;n>>>=26,t.words[r]=i,e=n}return 0!==e&&(t.words[t.length++]=e),t},a._prime=function(t){if(v[t])return v[t];var e;if(\"k256\"===t)e=new y;else if(\"p224\"===t)e=new x;else if(\"p192\"===t)e=new b;else{if(\"p25519\"!==t)throw new Error(\"Unknown prime \"+t);e=new _}return v[t]=e,e},w.prototype._verify1=function(t){n(0===t.negative,\"red works only with positives\"),n(t.red,\"red works only with red numbers\")},w.prototype._verify2=function(t,e){n(0==(t.negative|e.negative),\"red works only with positives\"),n(t.red&&t.red===e.red,\"red works only with red numbers\")},w.prototype.imod=function(t){return this.prime?this.prime.ireduce(t)._forceRed(this):t.umod(this.m)._forceRed(this)},w.prototype.neg=function(t){return t.isZero()?t.clone():this.m.sub(t)._forceRed(this)},w.prototype.add=function(t,e){this._verify2(t,e);var r=t.add(e);return r.cmp(this.m)>=0&&r.isub(this.m),r._forceRed(this)},w.prototype.iadd=function(t,e){this._verify2(t,e);var r=t.iadd(e);return r.cmp(this.m)>=0&&r.isub(this.m),r},w.prototype.sub=function(t,e){this._verify2(t,e);var r=t.sub(e);return r.cmpn(0)<0&&r.iadd(this.m),r._forceRed(this)},w.prototype.isub=function(t,e){this._verify2(t,e);var r=t.isub(e);return r.cmpn(0)<0&&r.iadd(this.m),r},w.prototype.shl=function(t,e){return this._verify1(t),this.imod(t.ushln(e))},w.prototype.imul=function(t,e){return this._verify2(t,e),this.imod(t.imul(e))},w.prototype.mul=function(t,e){return this._verify2(t,e),this.imod(t.mul(e))},w.prototype.isqr=function(t){return this.imul(t,t.clone())},w.prototype.sqr=function(t){return this.mul(t,t)},w.prototype.sqrt=function(t){if(t.isZero())return t.clone();var e=this.m.andln(3);if(n(e%2==1),3===e){var r=this.m.add(new a(1)).iushrn(2);return this.pow(t,r)}for(var i=this.m.subn(1),o=0;!i.isZero()&&0===i.andln(1);)o++,i.iushrn(1);n(!i.isZero());var s=new a(1).toRed(this),l=s.redNeg(),c=this.m.subn(1).iushrn(1),u=this.m.bitLength();for(u=new a(2*u*u).toRed(this);0!==this.pow(u,c).cmp(l);)u.redIAdd(l);for(var h=this.pow(u,i),f=this.pow(t,i.addn(1).iushrn(1)),p=this.pow(t,i),d=o;0!==p.cmp(s);){for(var g=p,v=0;0!==g.cmp(s);v++)g=g.redSqr();n(v<d);var m=this.pow(h,new a(1).iushln(d-v-1));f=f.redMul(m),h=m.redSqr(),p=p.redMul(h),d=v}return f},w.prototype.invm=function(t){var e=t._invmp(this.m);return 0!==e.negative?(e.negative=0,this.imod(e).redNeg()):this.imod(e)},w.prototype.pow=function(t,e){if(e.isZero())return new a(1).toRed(this);if(0===e.cmpn(1))return t.clone();var r=new Array(16);r[0]=new a(1).toRed(this),r[1]=t;for(var n=2;n<r.length;n++)r[n]=this.mul(r[n-1],t);var i=r[0],o=0,s=0,l=e.bitLength()%26;for(0===l&&(l=26),n=e.length-1;n>=0;n--){for(var c=e.words[n],u=l-1;u>=0;u--){var h=c>>u&1;i!==r[0]&&(i=this.sqr(i)),0!==h||0!==o?(o<<=1,o|=h,(4===++s||0===n&&0===u)&&(i=this.mul(i,r[o]),s=0,o=0)):s=0}l=26}return i},w.prototype.convertTo=function(t){var e=t.umod(this.m);return e===t?e.clone():e},w.prototype.convertFrom=function(t){var e=t.clone();return e.red=null,e},a.mont=function(t){return new k(t)},i(k,w),k.prototype.convertTo=function(t){return this.imod(t.ushln(this.shift))},k.prototype.convertFrom=function(t){var e=this.imod(t.mul(this.rinv));return e.red=null,e},k.prototype.imul=function(t,e){if(t.isZero()||e.isZero())return t.words[0]=0,t.length=1,t;var r=t.imul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),a=i;return i.cmp(this.m)>=0?a=i.isub(this.m):i.cmpn(0)<0&&(a=i.iadd(this.m)),a._forceRed(this)},k.prototype.mul=function(t,e){if(t.isZero()||e.isZero())return new a(0)._forceRed(this);var r=t.mul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),o=i;return i.cmp(this.m)>=0?o=i.isub(this.m):i.cmpn(0)<0&&(o=i.iadd(this.m)),o._forceRed(this)},k.prototype.invm=function(t){return this.imod(t._invmp(this.m).mul(this.r2))._forceRed(this)}}(\"undefined\"==typeof e||e,this)},{buffer:103}],95:[function(t,e,r){\"use strict\";e.exports=function(t){var e,r,n,i=t.length,a=0;for(e=0;e<i;++e)a+=t[e].length;var o=new Array(a),s=0;for(e=0;e<i;++e){var l=t[e],c=l.length;for(r=0;r<c;++r){var u=o[s++]=new Array(c-1),h=0;for(n=0;n<c;++n)n!==r&&(u[h++]=l[n]);if(1&r){var f=u[1];u[1]=u[0],u[0]=f}}}return o}},{}],96:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 1:return n=[],c(i=t,i,u,!0),n;case 2:return\"function\"==typeof e?c(t,t,e,!0):function(t,e){return n=[],c(t,e,u,!1),n}(t,e);case 3:return c(t,e,r,!1);default:throw new Error(\"box-intersect: Invalid arguments\")}var i};var n,i=t(\"typedarray-pool\"),a=t(\"./lib/sweep\"),o=t(\"./lib/intersect\");function s(t,e){for(var r=0;r<t;++r)if(!(e[r]<=e[r+t]))return!0;return!1}function l(t,e,r,n){for(var i=0,a=0,o=0,l=t.length;o<l;++o){var c=t[o];if(!s(e,c)){for(var u=0;u<2*e;++u)r[i++]=c[u];n[a++]=o}}return a}function c(t,e,r,n){var s=t.length,c=e.length;if(!(s<=0||c<=0)){var u=t[0].length>>>1;if(!(u<=0)){var h,f=i.mallocDouble(2*u*s),p=i.mallocInt32(s);if((s=l(t,u,f,p))>0){if(1===u&&n)a.init(s),h=a.sweepComplete(u,r,0,s,f,p,0,s,f,p);else{var d=i.mallocDouble(2*u*c),g=i.mallocInt32(c);(c=l(e,u,d,g))>0&&(a.init(s+c),h=1===u?a.sweepBipartite(u,r,0,s,f,p,0,c,d,g):o(u,r,n,s,f,p,c,d,g),i.free(d),i.free(g))}i.free(f),i.free(p)}return h}}}function u(t,e){n.push([t,e])}},{\"./lib/intersect\":98,\"./lib/sweep\":102,\"typedarray-pool\":545}],97:[function(t,e,r){\"use strict\";var n=\"d\",i=\"ax\",a=\"vv\",o=\"fp\",s=\"es\",l=\"rs\",c=\"re\",u=\"rb\",h=\"ri\",f=\"rp\",p=\"bs\",d=\"be\",g=\"bb\",v=\"bi\",m=\"bp\",y=\"rv\",x=\"Q\",b=[n,i,a,l,c,u,h,p,d,g,v];function _(t){var e=\"bruteForce\"+(t?\"Full\":\"Partial\"),r=[],_=b.slice();t||_.splice(3,0,o);var w=[\"function \"+e+\"(\"+_.join()+\"){\"];function k(e,o){var _=function(t,e,r){var o=\"bruteForce\"+(t?\"Red\":\"Blue\")+(e?\"Flip\":\"\")+(r?\"Full\":\"\"),_=[\"function \",o,\"(\",b.join(),\"){\",\"var \",s,\"=2*\",n,\";\"],w=\"for(var i=\"+l+\",\"+f+\"=\"+s+\"*\"+l+\";i<\"+c+\";++i,\"+f+\"+=\"+s+\"){var x0=\"+u+\"[\"+i+\"+\"+f+\"],x1=\"+u+\"[\"+i+\"+\"+f+\"+\"+n+\"],xi=\"+h+\"[i];\",k=\"for(var j=\"+p+\",\"+m+\"=\"+s+\"*\"+p+\";j<\"+d+\";++j,\"+m+\"+=\"+s+\"){var y0=\"+g+\"[\"+i+\"+\"+m+\"],\"+(r?\"y1=\"+g+\"[\"+i+\"+\"+m+\"+\"+n+\"],\":\"\")+\"yi=\"+v+\"[j];\";return t?_.push(w,x,\":\",k):_.push(k,x,\":\",w),r?_.push(\"if(y1<x0||x1<y0)continue;\"):e?_.push(\"if(y0<=x0||x1<y0)continue;\"):_.push(\"if(y0<x0||x1<y0)continue;\"),_.push(\"for(var k=\"+i+\"+1;k<\"+n+\";++k){var r0=\"+u+\"[k+\"+f+\"],r1=\"+u+\"[k+\"+n+\"+\"+f+\"],b0=\"+g+\"[k+\"+m+\"],b1=\"+g+\"[k+\"+n+\"+\"+m+\"];if(r1<b0||b1<r0)continue \"+x+\";}var \"+y+\"=\"+a+\"(\"),e?_.push(\"yi,xi\"):_.push(\"xi,yi\"),_.push(\");if(\"+y+\"!==void 0)return \"+y+\";}}}\"),{name:o,code:_.join(\"\")}}(e,o,t);r.push(_.code),w.push(\"return \"+_.name+\"(\"+b.join()+\");\")}w.push(\"if(\"+c+\"-\"+l+\">\"+d+\"-\"+p+\"){\"),t?(k(!0,!1),w.push(\"}else{\"),k(!1,!1)):(w.push(\"if(\"+o+\"){\"),k(!0,!0),w.push(\"}else{\"),k(!0,!1),w.push(\"}}else{if(\"+o+\"){\"),k(!1,!0),w.push(\"}else{\"),k(!1,!1),w.push(\"}\")),w.push(\"}}return \"+e);var T=r.join(\"\")+w.join(\"\");return new Function(T)()}r.partial=_(!1),r.full=_(!0)},{}],98:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,u,S,E,C,L){!function(t,e){var r=8*i.log2(e+1)*(t+1)|0,a=i.nextPow2(b*r);w.length<a&&(n.free(w),w=n.mallocInt32(a));var o=i.nextPow2(_*r);k<o&&(n.free(k),k=n.mallocDouble(o))}(t,a+E);var P,O=0,z=2*t;T(O++,0,0,a,0,E,r?16:0,-1/0,1/0),r||T(O++,0,0,E,0,a,1,-1/0,1/0);for(;O>0;){var I=(O-=1)*b,D=w[I],R=w[I+1],F=w[I+2],B=w[I+3],N=w[I+4],j=w[I+5],U=O*_,V=k[U],q=k[U+1],H=1&j,G=!!(16&j),Y=u,W=S,X=C,Z=L;if(H&&(Y=C,W=L,X=u,Z=S),!(2&j&&(F=v(t,D,R,F,Y,W,q),R>=F)||4&j&&(R=m(t,D,R,F,Y,W,V))>=F)){var J=F-R,K=N-B;if(G){if(t*J*(J+K)<p){if(void 0!==(P=l.scanComplete(t,D,e,R,F,Y,W,B,N,X,Z)))return P;continue}}else{if(t*Math.min(J,K)<h){if(void 0!==(P=o(t,D,e,H,R,F,Y,W,B,N,X,Z)))return P;continue}if(t*J*K<f){if(void 0!==(P=l.scanBipartite(t,D,e,H,R,F,Y,W,B,N,X,Z)))return P;continue}}var $=d(t,D,R,F,Y,W,V,q);if(R<$)if(t*($-R)<h){if(void 0!==(P=s(t,D+1,e,R,$,Y,W,B,N,X,Z)))return P}else if(D===t-2){if(void 0!==(P=H?l.sweepBipartite(t,e,B,N,X,Z,R,$,Y,W):l.sweepBipartite(t,e,R,$,Y,W,B,N,X,Z)))return P}else T(O++,D+1,R,$,B,N,H,-1/0,1/0),T(O++,D+1,B,N,R,$,1^H,-1/0,1/0);if($<F){var Q=c(t,D,B,N,X,Z),tt=X[z*Q+D],et=g(t,D,Q,N,X,Z,tt);if(et<N&&T(O++,D,$,F,et,N,(4|H)+(G?16:0),tt,q),B<Q&&T(O++,D,$,F,B,Q,(2|H)+(G?16:0),V,tt),Q+1===et){if(void 0!==(P=G?M(t,D,e,$,F,Y,W,Q,X,Z[Q]):A(t,D,e,H,$,F,Y,W,Q,X,Z[Q])))return P}else if(Q<et){var rt;if(G){if(rt=y(t,D,$,F,Y,W,tt),$<rt){var nt=g(t,D,$,rt,Y,W,tt);if(D===t-2){if($<nt&&void 0!==(P=l.sweepComplete(t,e,$,nt,Y,W,Q,et,X,Z)))return P;if(nt<rt&&void 0!==(P=l.sweepBipartite(t,e,nt,rt,Y,W,Q,et,X,Z)))return P}else $<nt&&T(O++,D+1,$,nt,Q,et,16,-1/0,1/0),nt<rt&&(T(O++,D+1,nt,rt,Q,et,0,-1/0,1/0),T(O++,D+1,Q,et,nt,rt,1,-1/0,1/0))}}else rt=H?x(t,D,$,F,Y,W,tt):y(t,D,$,F,Y,W,tt),$<rt&&(D===t-2?P=H?l.sweepBipartite(t,e,Q,et,X,Z,$,rt,Y,W):l.sweepBipartite(t,e,$,rt,Y,W,Q,et,X,Z):(T(O++,D+1,$,rt,Q,et,H,-1/0,1/0),T(O++,D+1,Q,et,$,rt,1^H,-1/0,1/0)))}}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./brute\"),o=a.partial,s=a.full,l=t(\"./sweep\"),c=t(\"./median\"),u=t(\"./partition\"),h=128,f=1<<22,p=1<<22,d=u(\"!(lo>=p0)&&!(p1>=hi)\",[\"p0\",\"p1\"]),g=u(\"lo===p0\",[\"p0\"]),v=u(\"lo<p0\",[\"p0\"]),m=u(\"hi<=p0\",[\"p0\"]),y=u(\"lo<=p0&&p0<=hi\",[\"p0\"]),x=u(\"lo<p0&&p0<=hi\",[\"p0\"]),b=6,_=2,w=n.mallocInt32(1024),k=n.mallocDouble(1024);function T(t,e,r,n,i,a,o,s,l){var c=b*t;w[c]=e,w[c+1]=r,w[c+2]=n,w[c+3]=i,w[c+4]=a,w[c+5]=o;var u=_*t;k[u]=s,k[u+1]=l}function A(t,e,r,n,i,a,o,s,l,c,u){var h=2*t,f=l*h,p=c[f+e];t:for(var d=i,g=i*h;d<a;++d,g+=h){var v=o[g+e],m=o[g+e+t];if(!(p<v||m<p)&&(!n||p!==v)){for(var y,x=s[d],b=e+1;b<t;++b){v=o[g+b],m=o[g+b+t];var _=c[f+b],w=c[f+b+t];if(m<_||w<v)continue t}if(void 0!==(y=n?r(u,x):r(x,u)))return y}}}function M(t,e,r,n,i,a,o,s,l,c){var u=2*t,h=s*u,f=l[h+e];t:for(var p=n,d=n*u;p<i;++p,d+=u){var g=o[p];if(g!==c){var v=a[d+e],m=a[d+e+t];if(!(f<v||m<f)){for(var y=e+1;y<t;++y){v=a[d+y],m=a[d+y+t];var x=l[h+y],b=l[h+y+t];if(m<x||b<v)continue t}var _=r(g,c);if(void 0!==_)return _}}}}},{\"./brute\":97,\"./median\":99,\"./partition\":100,\"./sweep\":102,\"bit-twiddle\":92,\"typedarray-pool\":545}],99:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,o,s,l){if(o<=r+1)return r;var c=r,u=o,h=o+r>>>1,f=2*t,p=h,d=s[f*h+e];for(;c<u;){if(u-c<i){a(t,e,c,u,s,l),d=s[f*h+e];break}var g=u-c,v=Math.random()*g+c|0,m=s[f*v+e],y=Math.random()*g+c|0,x=s[f*y+e],b=Math.random()*g+c|0,_=s[f*b+e];m<=x?_>=x?(p=y,d=x):m>=_?(p=v,d=m):(p=b,d=_):x>=_?(p=y,d=x):_>=m?(p=v,d=m):(p=b,d=_);for(var w=f*(u-1),k=f*p,T=0;T<f;++T,++w,++k){var A=s[w];s[w]=s[k],s[k]=A}var M=l[u-1];l[u-1]=l[p],l[p]=M,p=n(t,e,c,u-1,s,l,d);for(var w=f*(u-1),k=f*p,T=0;T<f;++T,++w,++k){var A=s[w];s[w]=s[k],s[k]=A}var M=l[u-1];if(l[u-1]=l[p],l[p]=M,h<p){for(u=p-1;c<u&&s[f*(u-1)+e]===d;)u-=1;u+=1}else{if(!(p<h))break;for(c=p+1;c<u&&s[f*c+e]===d;)c+=1}}return n(t,e,r,h,s,l,s[f*h+e])};var n=t(\"./partition\")(\"lo<p0\",[\"p0\"]),i=8;function a(t,e,r,n,i,a){for(var o=2*t,s=o*(r+1)+e,l=r+1;l<n;++l,s+=o)for(var c=i[s],u=l,h=o*(l-1);u>r&&i[h+e]>c;--u,h-=o){for(var f=h,p=h+o,d=0;d<o;++d,++f,++p){var g=i[f];i[f]=i[p],i[p]=g}var v=a[u];a[u]=a[u-1],a[u-1]=v}}},{\"./partition\":100}],100:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=\"abcdef\".split(\"\").concat(e),i=[];t.indexOf(\"lo\")>=0&&i.push(\"lo=e[k+n]\");t.indexOf(\"hi\")>=0&&i.push(\"hi=e[k+o]\");return r.push(n.replace(\"_\",i.join()).replace(\"$\",t)),Function.apply(void 0,r)};var n=\"for(var j=2*a,k=j*c,l=k,m=c,n=b,o=a+b,p=c;d>p;++p,k+=j){var _;if($)if(m===p)m+=1,l+=j;else{for(var s=0;j>s;++s){var t=e[k+s];e[k+s]=e[l],e[l++]=t}var u=f[p];f[p]=f[m],f[m++]=u}}return m\"},{}],101:[function(t,e,r){\"use strict\";e.exports=function(t,e){e<=4*n?i(0,e-1,t):function t(e,r,h){var f=(r-e+1)/6|0,p=e+f,d=r-f,g=e+r>>1,v=g-f,m=g+f,y=p,x=v,b=g,_=m,w=d,k=e+1,T=r-1,A=0;c(y,x,h)&&(A=y,y=x,x=A);c(_,w,h)&&(A=_,_=w,w=A);c(y,b,h)&&(A=y,y=b,b=A);c(x,b,h)&&(A=x,x=b,b=A);c(y,_,h)&&(A=y,y=_,_=A);c(b,_,h)&&(A=b,b=_,_=A);c(x,w,h)&&(A=x,x=w,w=A);c(x,b,h)&&(A=x,x=b,b=A);c(_,w,h)&&(A=_,_=w,w=A);var M=h[2*x];var S=h[2*x+1];var E=h[2*_];var C=h[2*_+1];var L=2*y;var P=2*b;var O=2*w;var z=2*p;var I=2*g;var D=2*d;for(var R=0;R<2;++R){var F=h[L+R],B=h[P+R],N=h[O+R];h[z+R]=F,h[I+R]=B,h[D+R]=N}o(v,e,h);o(m,r,h);for(var j=k;j<=T;++j)if(u(j,M,S,h))j!==k&&a(j,k,h),++k;else if(!u(j,E,C,h))for(;;){if(u(T,E,C,h)){u(T,M,S,h)?(s(j,k,T,h),++k,--T):(a(j,T,h),--T);break}if(--T<j)break}l(e,k-1,M,S,h);l(r,T+1,E,C,h);k-2-e<=n?i(e,k-2,h):t(e,k-2,h);r-(T+2)<=n?i(T+2,r,h):t(T+2,r,h);T-k<=n?i(k,T,h):t(k,T,h)}(0,e-1,t)};var n=32;function i(t,e,r){for(var n=2*(t+1),i=t+1;i<=e;++i){for(var a=r[n++],o=r[n++],s=i,l=n-2;s-- >t;){var c=r[l-2],u=r[l-1];if(c<a)break;if(c===a&&u<o)break;r[l]=c,r[l+1]=u,l-=2}r[l]=a,r[l+1]=o}}function a(t,e,r){e*=2;var n=r[t*=2],i=r[t+1];r[t]=r[e],r[t+1]=r[e+1],r[e]=n,r[e+1]=i}function o(t,e,r){e*=2,r[t*=2]=r[e],r[t+1]=r[e+1]}function s(t,e,r,n){e*=2,r*=2;var i=n[t*=2],a=n[t+1];n[t]=n[e],n[t+1]=n[e+1],n[e]=n[r],n[e+1]=n[r+1],n[r]=i,n[r+1]=a}function l(t,e,r,n,i){e*=2,i[t*=2]=i[e],i[e]=r,i[t+1]=i[e+1],i[e+1]=n}function c(t,e,r){e*=2;var n=r[t*=2],i=r[e];return!(n<i)&&(n!==i||r[t+1]>r[e+1])}function u(t,e,r,n){var i=n[t*=2];return i<e||i===e&&n[t+1]<r}},{}],102:[function(t,e,r){\"use strict\";e.exports={init:function(t){var e=i.nextPow2(t);s.length<e&&(n.free(s),s=n.mallocInt32(e));l.length<e&&(n.free(l),l=n.mallocInt32(e));c.length<e&&(n.free(c),c=n.mallocInt32(e));u.length<e&&(n.free(u),u=n.mallocInt32(e));h.length<e&&(n.free(h),h=n.mallocInt32(e));f.length<e&&(n.free(f),f=n.mallocInt32(e));var r=8*e;p.length<r&&(n.free(p),p=n.mallocDouble(r))},sweepBipartite:function(t,e,r,n,i,h,f,v,m,y){for(var x=0,b=2*t,_=t-1,w=b-1,k=r;k<n;++k){var T=h[k],A=b*k;p[x++]=i[A+_],p[x++]=-(T+1),p[x++]=i[A+w],p[x++]=T}for(var k=f;k<v;++k){var T=y[k]+o,M=b*k;p[x++]=m[M+_],p[x++]=-T,p[x++]=m[M+w],p[x++]=T}var S=x>>>1;a(p,S);for(var E=0,C=0,k=0;k<S;++k){var L=0|p[2*k+1];if(L>=o)d(c,u,C--,L=L-o|0);else if(L>=0)d(s,l,E--,L);else if(L<=-o){L=-L-o|0;for(var P=0;P<E;++P){var O=e(s[P],L);if(void 0!==O)return O}g(c,u,C++,L)}else{L=-L-1|0;for(var P=0;P<C;++P){var O=e(L,c[P]);if(void 0!==O)return O}g(s,l,E++,L)}}},sweepComplete:function(t,e,r,n,i,o,v,m,y,x){for(var b=0,_=2*t,w=t-1,k=_-1,T=r;T<n;++T){var A=o[T]+1<<1,M=_*T;p[b++]=i[M+w],p[b++]=-A,p[b++]=i[M+k],p[b++]=A}for(var T=v;T<m;++T){var A=x[T]+1<<1,S=_*T;p[b++]=y[S+w],p[b++]=1|-A,p[b++]=y[S+k],p[b++]=1|A}var E=b>>>1;a(p,E);for(var C=0,L=0,P=0,T=0;T<E;++T){var O=0|p[2*T+1],z=1&O;if(T<E-1&&O>>1==p[2*T+3]>>1&&(z=2,T+=1),O<0){for(var I=-(O>>1)-1,D=0;D<P;++D){var R=e(h[D],I);if(void 0!==R)return R}if(0!==z)for(var D=0;D<C;++D){var R=e(s[D],I);if(void 0!==R)return R}if(1!==z)for(var D=0;D<L;++D){var R=e(c[D],I);if(void 0!==R)return R}0===z?g(s,l,C++,I):1===z?g(c,u,L++,I):2===z&&g(h,f,P++,I)}else{var I=(O>>1)-1;0===z?d(s,l,C--,I):1===z?d(c,u,L--,I):2===z&&d(h,f,P--,I)}}},scanBipartite:function(t,e,r,n,i,c,u,h,f,v,m,y){var x=0,b=2*t,_=e,w=e+t,k=1,T=1;n?T=o:k=o;for(var A=i;A<c;++A){var M=A+k,S=b*A;p[x++]=u[S+_],p[x++]=-M,p[x++]=u[S+w],p[x++]=M}for(var A=f;A<v;++A){var M=A+T,E=b*A;p[x++]=m[E+_],p[x++]=-M}var C=x>>>1;a(p,C);for(var L=0,A=0;A<C;++A){var P=0|p[2*A+1];if(P<0){var M=-P,O=!1;if(M>=o?(O=!n,M-=o):(O=!!n,M-=1),O)g(s,l,L++,M);else{var z=y[M],I=b*M,D=m[I+e+1],R=m[I+e+1+t];t:for(var F=0;F<L;++F){var B=s[F],N=b*B;if(!(R<u[N+e+1]||u[N+e+1+t]<D)){for(var j=e+2;j<t;++j)if(m[I+j+t]<u[N+j]||u[N+j+t]<m[I+j])continue t;var U,V=h[B];if(void 0!==(U=n?r(z,V):r(V,z)))return U}}}}else d(s,l,L--,P-k)}},scanComplete:function(t,e,r,n,i,l,c,u,h,f,d){for(var g=0,v=2*t,m=e,y=e+t,x=n;x<i;++x){var b=x+o,_=v*x;p[g++]=l[_+m],p[g++]=-b,p[g++]=l[_+y],p[g++]=b}for(var x=u;x<h;++x){var b=x+1,w=v*x;p[g++]=f[w+m],p[g++]=-b}var k=g>>>1;a(p,k);for(var T=0,x=0;x<k;++x){var A=0|p[2*x+1];if(A<0){var b=-A;if(b>=o)s[T++]=b-o;else{var M=d[b-=1],S=v*b,E=f[S+e+1],C=f[S+e+1+t];t:for(var L=0;L<T;++L){var P=s[L],O=c[P];if(O===M)break;var z=v*P;if(!(C<l[z+e+1]||l[z+e+1+t]<E)){for(var I=e+2;I<t;++I)if(f[S+I+t]<l[z+I]||l[z+I+t]<f[S+I])continue t;var D=r(O,M);if(void 0!==D)return D}}}}else{for(var b=A-o,L=T-1;L>=0;--L)if(s[L]===b){for(var I=L+1;I<T;++I)s[I-1]=s[I];break}--T}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./sort\"),o=1<<28,s=n.mallocInt32(1024),l=n.mallocInt32(1024),c=n.mallocInt32(1024),u=n.mallocInt32(1024),h=n.mallocInt32(1024),f=n.mallocInt32(1024),p=n.mallocDouble(8192);function d(t,e,r,n){var i=e[n],a=t[r-1];t[i]=a,e[a]=i}function g(t,e,r,n){t[r]=n,e[n]=r}},{\"./sort\":101,\"bit-twiddle\":92,\"typedarray-pool\":545}],103:[function(t,e,r){},{}],104:[function(t,e,r){var n=Object.create||function(t){var e=function(){};return e.prototype=t,new e},i=Object.keys||function(t){var e=[];for(var r in t)Object.prototype.hasOwnProperty.call(t,r)&&e.push(r);return r},a=Function.prototype.bind||function(t){var e=this;return function(){return e.apply(t,arguments)}};function o(){this._events&&Object.prototype.hasOwnProperty.call(this,\"_events\")||(this._events=n(null),this._eventsCount=0),this._maxListeners=this._maxListeners||void 0}e.exports=o,o.EventEmitter=o,o.prototype._events=void 0,o.prototype._maxListeners=void 0;var s,l=10;try{var c={};Object.defineProperty&&Object.defineProperty(c,\"x\",{value:0}),s=0===c.x}catch(t){s=!1}function u(t){return void 0===t._maxListeners?o.defaultMaxListeners:t._maxListeners}function h(t,e,r,i){var a,o,s;if(\"function\"!=typeof r)throw new TypeError('\"listener\" argument must be a function');if((o=t._events)?(o.newListener&&(t.emit(\"newListener\",e,r.listener?r.listener:r),o=t._events),s=o[e]):(o=t._events=n(null),t._eventsCount=0),s){if(\"function\"==typeof s?s=o[e]=i?[r,s]:[s,r]:i?s.unshift(r):s.push(r),!s.warned&&(a=u(t))&&a>0&&s.length>a){s.warned=!0;var l=new Error(\"Possible EventEmitter memory leak detected. \"+s.length+' \"'+String(e)+'\" listeners added. Use emitter.setMaxListeners() to increase limit.');l.name=\"MaxListenersExceededWarning\",l.emitter=t,l.type=e,l.count=s.length,\"object\"==typeof console&&console.warn&&console.warn(\"%s: %s\",l.name,l.message)}}else s=o[e]=r,++t._eventsCount;return t}function f(){if(!this.fired)switch(this.target.removeListener(this.type,this.wrapFn),this.fired=!0,arguments.length){case 0:return this.listener.call(this.target);case 1:return this.listener.call(this.target,arguments[0]);case 2:return this.listener.call(this.target,arguments[0],arguments[1]);case 3:return this.listener.call(this.target,arguments[0],arguments[1],arguments[2]);default:for(var t=new Array(arguments.length),e=0;e<t.length;++e)t[e]=arguments[e];this.listener.apply(this.target,t)}}function p(t,e,r){var n={fired:!1,wrapFn:void 0,target:t,type:e,listener:r},i=a.call(f,n);return i.listener=r,n.wrapFn=i,i}function d(t,e,r){var n=t._events;if(!n)return[];var i=n[e];return i?\"function\"==typeof i?r?[i.listener||i]:[i]:r?function(t){for(var e=new Array(t.length),r=0;r<e.length;++r)e[r]=t[r].listener||t[r];return e}(i):v(i,i.length):[]}function g(t){var e=this._events;if(e){var r=e[t];if(\"function\"==typeof r)return 1;if(r)return r.length}return 0}function v(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t[n];return r}s?Object.defineProperty(o,\"defaultMaxListeners\",{enumerable:!0,get:function(){return l},set:function(t){if(\"number\"!=typeof t||t<0||t!=t)throw new TypeError('\"defaultMaxListeners\" must be a positive number');l=t}}):o.defaultMaxListeners=l,o.prototype.setMaxListeners=function(t){if(\"number\"!=typeof t||t<0||isNaN(t))throw new TypeError('\"n\" argument must be a positive number');return this._maxListeners=t,this},o.prototype.getMaxListeners=function(){return u(this)},o.prototype.emit=function(t){var e,r,n,i,a,o,s=\"error\"===t;if(o=this._events)s=s&&null==o.error;else if(!s)return!1;if(s){if(arguments.length>1&&(e=arguments[1]),e instanceof Error)throw e;var l=new Error('Unhandled \"error\" event. ('+e+\")\");throw l.context=e,l}if(!(r=o[t]))return!1;var c=\"function\"==typeof r;switch(n=arguments.length){case 1:!function(t,e,r){if(e)t.call(r);else for(var n=t.length,i=v(t,n),a=0;a<n;++a)i[a].call(r)}(r,c,this);break;case 2:!function(t,e,r,n){if(e)t.call(r,n);else for(var i=t.length,a=v(t,i),o=0;o<i;++o)a[o].call(r,n)}(r,c,this,arguments[1]);break;case 3:!function(t,e,r,n,i){if(e)t.call(r,n,i);else for(var a=t.length,o=v(t,a),s=0;s<a;++s)o[s].call(r,n,i)}(r,c,this,arguments[1],arguments[2]);break;case 4:!function(t,e,r,n,i,a){if(e)t.call(r,n,i,a);else for(var o=t.length,s=v(t,o),l=0;l<o;++l)s[l].call(r,n,i,a)}(r,c,this,arguments[1],arguments[2],arguments[3]);break;default:for(i=new Array(n-1),a=1;a<n;a++)i[a-1]=arguments[a];!function(t,e,r,n){if(e)t.apply(r,n);else for(var i=t.length,a=v(t,i),o=0;o<i;++o)a[o].apply(r,n)}(r,c,this,i)}return!0},o.prototype.addListener=function(t,e){return h(this,t,e,!1)},o.prototype.on=o.prototype.addListener,o.prototype.prependListener=function(t,e){return h(this,t,e,!0)},o.prototype.once=function(t,e){if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');return this.on(t,p(this,t,e)),this},o.prototype.prependOnceListener=function(t,e){if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');return this.prependListener(t,p(this,t,e)),this},o.prototype.removeListener=function(t,e){var r,i,a,o,s;if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');if(!(i=this._events))return this;if(!(r=i[t]))return this;if(r===e||r.listener===e)0==--this._eventsCount?this._events=n(null):(delete i[t],i.removeListener&&this.emit(\"removeListener\",t,r.listener||e));else if(\"function\"!=typeof r){for(a=-1,o=r.length-1;o>=0;o--)if(r[o]===e||r[o].listener===e){s=r[o].listener,a=o;break}if(a<0)return this;0===a?r.shift():function(t,e){for(var r=e,n=r+1,i=t.length;n<i;r+=1,n+=1)t[r]=t[n];t.pop()}(r,a),1===r.length&&(i[t]=r[0]),i.removeListener&&this.emit(\"removeListener\",t,s||e)}return this},o.prototype.removeAllListeners=function(t){var e,r,a;if(!(r=this._events))return this;if(!r.removeListener)return 0===arguments.length?(this._events=n(null),this._eventsCount=0):r[t]&&(0==--this._eventsCount?this._events=n(null):delete r[t]),this;if(0===arguments.length){var o,s=i(r);for(a=0;a<s.length;++a)\"removeListener\"!==(o=s[a])&&this.removeAllListeners(o);return this.removeAllListeners(\"removeListener\"),this._events=n(null),this._eventsCount=0,this}if(\"function\"==typeof(e=r[t]))this.removeListener(t,e);else if(e)for(a=e.length-1;a>=0;a--)this.removeListener(t,e[a]);return this},o.prototype.listeners=function(t){return d(this,t,!0)},o.prototype.rawListeners=function(t){return d(this,t,!1)},o.listenerCount=function(t,e){return\"function\"==typeof t.listenerCount?t.listenerCount(e):g.call(t,e)},o.prototype.listenerCount=g,o.prototype.eventNames=function(){return this._eventsCount>0?Reflect.ownKeys(this._events):[]}},{}],105:[function(t,e,r){(function(e){\"use strict\";var n=t(\"base64-js\"),i=t(\"ieee754\");r.Buffer=e,r.SlowBuffer=function(t){+t!=t&&(t=0);return e.alloc(+t)},r.INSPECT_MAX_BYTES=50;var a=2147483647;function o(t){if(t>a)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"');var r=new Uint8Array(t);return r.__proto__=e.prototype,r}function e(t,e,r){if(\"number\"==typeof t){if(\"string\"==typeof e)throw new TypeError('The \"string\" argument must be of type string. Received type number');return c(t)}return s(t,e,r)}function s(t,r,n){if(\"string\"==typeof t)return function(t,r){\"string\"==typeof r&&\"\"!==r||(r=\"utf8\");if(!e.isEncoding(r))throw new TypeError(\"Unknown encoding: \"+r);var n=0|f(t,r),i=o(n),a=i.write(t,r);a!==n&&(i=i.slice(0,a));return i}(t,r);if(ArrayBuffer.isView(t))return u(t);if(null==t)throw TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t);if(N(t,ArrayBuffer)||t&&N(t.buffer,ArrayBuffer))return function(t,r,n){if(r<0||t.byteLength<r)throw new RangeError('\"offset\" is outside of buffer bounds');if(t.byteLength<r+(n||0))throw new RangeError('\"length\" is outside of buffer bounds');var i;i=void 0===r&&void 0===n?new Uint8Array(t):void 0===n?new Uint8Array(t,r):new Uint8Array(t,r,n);return i.__proto__=e.prototype,i}(t,r,n);if(\"number\"==typeof t)throw new TypeError('The \"value\" argument must not be of type number. Received type number');var i=t.valueOf&&t.valueOf();if(null!=i&&i!==t)return e.from(i,r,n);var a=function(t){if(e.isBuffer(t)){var r=0|h(t.length),n=o(r);return 0===n.length?n:(t.copy(n,0,0,r),n)}if(void 0!==t.length)return\"number\"!=typeof t.length||j(t.length)?o(0):u(t);if(\"Buffer\"===t.type&&Array.isArray(t.data))return u(t.data)}(t);if(a)return a;if(\"undefined\"!=typeof Symbol&&null!=Symbol.toPrimitive&&\"function\"==typeof t[Symbol.toPrimitive])return e.from(t[Symbol.toPrimitive](\"string\"),r,n);throw new TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t)}function l(t){if(\"number\"!=typeof t)throw new TypeError('\"size\" argument must be of type number');if(t<0)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"')}function c(t){return l(t),o(t<0?0:0|h(t))}function u(t){for(var e=t.length<0?0:0|h(t.length),r=o(e),n=0;n<e;n+=1)r[n]=255&t[n];return r}function h(t){if(t>=a)throw new RangeError(\"Attempt to allocate Buffer larger than maximum size: 0x\"+a.toString(16)+\" bytes\");return 0|t}function f(t,r){if(e.isBuffer(t))return t.length;if(ArrayBuffer.isView(t)||N(t,ArrayBuffer))return t.byteLength;if(\"string\"!=typeof t)throw new TypeError('The \"string\" argument must be one of type string, Buffer, or ArrayBuffer. Received type '+typeof t);var n=t.length,i=arguments.length>2&&!0===arguments[2];if(!i&&0===n)return 0;for(var a=!1;;)switch(r){case\"ascii\":case\"latin1\":case\"binary\":return n;case\"utf8\":case\"utf-8\":return R(t).length;case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return 2*n;case\"hex\":return n>>>1;case\"base64\":return F(t).length;default:if(a)return i?-1:R(t).length;r=(\"\"+r).toLowerCase(),a=!0}}function p(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function d(t,r,n,i,a){if(0===t.length)return-1;if(\"string\"==typeof n?(i=n,n=0):n>2147483647?n=2147483647:n<-2147483648&&(n=-2147483648),j(n=+n)&&(n=a?0:t.length-1),n<0&&(n=t.length+n),n>=t.length){if(a)return-1;n=t.length-1}else if(n<0){if(!a)return-1;n=0}if(\"string\"==typeof r&&(r=e.from(r,i)),e.isBuffer(r))return 0===r.length?-1:g(t,r,n,i,a);if(\"number\"==typeof r)return r&=255,\"function\"==typeof Uint8Array.prototype.indexOf?a?Uint8Array.prototype.indexOf.call(t,r,n):Uint8Array.prototype.lastIndexOf.call(t,r,n):g(t,[r],n,i,a);throw new TypeError(\"val must be string, number or Buffer\")}function g(t,e,r,n,i){var a,o=1,s=t.length,l=e.length;if(void 0!==n&&(\"ucs2\"===(n=String(n).toLowerCase())||\"ucs-2\"===n||\"utf16le\"===n||\"utf-16le\"===n)){if(t.length<2||e.length<2)return-1;o=2,s/=2,l/=2,r/=2}function c(t,e){return 1===o?t[e]:t.readUInt16BE(e*o)}if(i){var u=-1;for(a=r;a<s;a++)if(c(t,a)===c(e,-1===u?0:a-u)){if(-1===u&&(u=a),a-u+1===l)return u*o}else-1!==u&&(a-=a-u),u=-1}else for(r+l>s&&(r=s-l),a=r;a>=0;a--){for(var h=!0,f=0;f<l;f++)if(c(t,a+f)!==c(e,f)){h=!1;break}if(h)return a}return-1}function v(t,e,r,n){r=Number(r)||0;var i=t.length-r;n?(n=Number(n))>i&&(n=i):n=i;var a=e.length;n>a/2&&(n=a/2);for(var o=0;o<n;++o){var s=parseInt(e.substr(2*o,2),16);if(j(s))return o;t[r+o]=s}return o}function m(t,e,r,n){return B(R(e,t.length-r),t,r,n)}function y(t,e,r,n){return B(function(t){for(var e=[],r=0;r<t.length;++r)e.push(255&t.charCodeAt(r));return e}(e),t,r,n)}function x(t,e,r,n){return y(t,e,r,n)}function b(t,e,r,n){return B(F(e),t,r,n)}function _(t,e,r,n){return B(function(t,e){for(var r,n,i,a=[],o=0;o<t.length&&!((e-=2)<0);++o)r=t.charCodeAt(o),n=r>>8,i=r%256,a.push(i),a.push(n);return a}(e,t.length-r),t,r,n)}function w(t,e,r){return 0===e&&r===t.length?n.fromByteArray(t):n.fromByteArray(t.slice(e,r))}function k(t,e,r){r=Math.min(t.length,r);for(var n=[],i=e;i<r;){var a,o,s,l,c=t[i],u=null,h=c>239?4:c>223?3:c>191?2:1;if(i+h<=r)switch(h){case 1:c<128&&(u=c);break;case 2:128==(192&(a=t[i+1]))&&(l=(31&c)<<6|63&a)>127&&(u=l);break;case 3:a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&(l=(15&c)<<12|(63&a)<<6|63&o)>2047&&(l<55296||l>57343)&&(u=l);break;case 4:a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&(l=(15&c)<<18|(63&a)<<12|(63&o)<<6|63&s)>65535&&l<1114112&&(u=l)}null===u?(u=65533,h=1):u>65535&&(u-=65536,n.push(u>>>10&1023|55296),u=56320|1023&u),n.push(u),i+=h}return function(t){var e=t.length;if(e<=T)return String.fromCharCode.apply(String,t);var r=\"\",n=0;for(;n<e;)r+=String.fromCharCode.apply(String,t.slice(n,n+=T));return r}(n)}r.kMaxLength=a,e.TYPED_ARRAY_SUPPORT=function(){try{var t=new Uint8Array(1);return t.__proto__={__proto__:Uint8Array.prototype,foo:function(){return 42}},42===t.foo()}catch(t){return!1}}(),e.TYPED_ARRAY_SUPPORT||\"undefined\"==typeof console||\"function\"!=typeof console.error||console.error(\"This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support.\"),Object.defineProperty(e.prototype,\"parent\",{enumerable:!0,get:function(){if(e.isBuffer(this))return this.buffer}}),Object.defineProperty(e.prototype,\"offset\",{enumerable:!0,get:function(){if(e.isBuffer(this))return this.byteOffset}}),\"undefined\"!=typeof Symbol&&null!=Symbol.species&&e[Symbol.species]===e&&Object.defineProperty(e,Symbol.species,{value:null,configurable:!0,enumerable:!1,writable:!1}),e.poolSize=8192,e.from=function(t,e,r){return s(t,e,r)},e.prototype.__proto__=Uint8Array.prototype,e.__proto__=Uint8Array,e.alloc=function(t,e,r){return function(t,e,r){return l(t),t<=0?o(t):void 0!==e?\"string\"==typeof r?o(t).fill(e,r):o(t).fill(e):o(t)}(t,e,r)},e.allocUnsafe=function(t){return c(t)},e.allocUnsafeSlow=function(t){return c(t)},e.isBuffer=function(t){return null!=t&&!0===t._isBuffer&&t!==e.prototype},e.compare=function(t,r){if(N(t,Uint8Array)&&(t=e.from(t,t.offset,t.byteLength)),N(r,Uint8Array)&&(r=e.from(r,r.offset,r.byteLength)),!e.isBuffer(t)||!e.isBuffer(r))throw new TypeError('The \"buf1\", \"buf2\" arguments must be one of type Buffer or Uint8Array');if(t===r)return 0;for(var n=t.length,i=r.length,a=0,o=Math.min(n,i);a<o;++a)if(t[a]!==r[a]){n=t[a],i=r[a];break}return n<i?-1:i<n?1:0},e.isEncoding=function(t){switch(String(t).toLowerCase()){case\"hex\":case\"utf8\":case\"utf-8\":case\"ascii\":case\"latin1\":case\"binary\":case\"base64\":case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return!0;default:return!1}},e.concat=function(t,r){if(!Array.isArray(t))throw new TypeError('\"list\" argument must be an Array of Buffers');if(0===t.length)return e.alloc(0);var n;if(void 0===r)for(r=0,n=0;n<t.length;++n)r+=t[n].length;var i=e.allocUnsafe(r),a=0;for(n=0;n<t.length;++n){var o=t[n];if(N(o,Uint8Array)&&(o=e.from(o)),!e.isBuffer(o))throw new TypeError('\"list\" argument must be an Array of Buffers');o.copy(i,a),a+=o.length}return i},e.byteLength=f,e.prototype._isBuffer=!0,e.prototype.swap16=function(){var t=this.length;if(t%2!=0)throw new RangeError(\"Buffer size must be a multiple of 16-bits\");for(var e=0;e<t;e+=2)p(this,e,e+1);return this},e.prototype.swap32=function(){var t=this.length;if(t%4!=0)throw new RangeError(\"Buffer size must be a multiple of 32-bits\");for(var e=0;e<t;e+=4)p(this,e,e+3),p(this,e+1,e+2);return this},e.prototype.swap64=function(){var t=this.length;if(t%8!=0)throw new RangeError(\"Buffer size must be a multiple of 64-bits\");for(var e=0;e<t;e+=8)p(this,e,e+7),p(this,e+1,e+6),p(this,e+2,e+5),p(this,e+3,e+4);return this},e.prototype.toString=function(){var t=this.length;return 0===t?\"\":0===arguments.length?k(this,0,t):function(t,e,r){var n=!1;if((void 0===e||e<0)&&(e=0),e>this.length)return\"\";if((void 0===r||r>this.length)&&(r=this.length),r<=0)return\"\";if((r>>>=0)<=(e>>>=0))return\"\";for(t||(t=\"utf8\");;)switch(t){case\"hex\":return S(this,e,r);case\"utf8\":case\"utf-8\":return k(this,e,r);case\"ascii\":return A(this,e,r);case\"latin1\":case\"binary\":return M(this,e,r);case\"base64\":return w(this,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return E(this,e,r);default:if(n)throw new TypeError(\"Unknown encoding: \"+t);t=(t+\"\").toLowerCase(),n=!0}}.apply(this,arguments)},e.prototype.toLocaleString=e.prototype.toString,e.prototype.equals=function(t){if(!e.isBuffer(t))throw new TypeError(\"Argument must be a Buffer\");return this===t||0===e.compare(this,t)},e.prototype.inspect=function(){var t=\"\",e=r.INSPECT_MAX_BYTES;return t=this.toString(\"hex\",0,e).replace(/(.{2})/g,\"$1 \").trim(),this.length>e&&(t+=\" ... \"),\"<Buffer \"+t+\">\"},e.prototype.compare=function(t,r,n,i,a){if(N(t,Uint8Array)&&(t=e.from(t,t.offset,t.byteLength)),!e.isBuffer(t))throw new TypeError('The \"target\" argument must be one of type Buffer or Uint8Array. Received type '+typeof t);if(void 0===r&&(r=0),void 0===n&&(n=t?t.length:0),void 0===i&&(i=0),void 0===a&&(a=this.length),r<0||n>t.length||i<0||a>this.length)throw new RangeError(\"out of range index\");if(i>=a&&r>=n)return 0;if(i>=a)return-1;if(r>=n)return 1;if(this===t)return 0;for(var o=(a>>>=0)-(i>>>=0),s=(n>>>=0)-(r>>>=0),l=Math.min(o,s),c=this.slice(i,a),u=t.slice(r,n),h=0;h<l;++h)if(c[h]!==u[h]){o=c[h],s=u[h];break}return o<s?-1:s<o?1:0},e.prototype.includes=function(t,e,r){return-1!==this.indexOf(t,e,r)},e.prototype.indexOf=function(t,e,r){return d(this,t,e,r,!0)},e.prototype.lastIndexOf=function(t,e,r){return d(this,t,e,r,!1)},e.prototype.write=function(t,e,r,n){if(void 0===e)n=\"utf8\",r=this.length,e=0;else if(void 0===r&&\"string\"==typeof e)n=e,r=this.length,e=0;else{if(!isFinite(e))throw new Error(\"Buffer.write(string, encoding, offset[, length]) is no longer supported\");e>>>=0,isFinite(r)?(r>>>=0,void 0===n&&(n=\"utf8\")):(n=r,r=void 0)}var i=this.length-e;if((void 0===r||r>i)&&(r=i),t.length>0&&(r<0||e<0)||e>this.length)throw new RangeError(\"Attempt to write outside buffer bounds\");n||(n=\"utf8\");for(var a=!1;;)switch(n){case\"hex\":return v(this,t,e,r);case\"utf8\":case\"utf-8\":return m(this,t,e,r);case\"ascii\":return y(this,t,e,r);case\"latin1\":case\"binary\":return x(this,t,e,r);case\"base64\":return b(this,t,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return _(this,t,e,r);default:if(a)throw new TypeError(\"Unknown encoding: \"+n);n=(\"\"+n).toLowerCase(),a=!0}},e.prototype.toJSON=function(){return{type:\"Buffer\",data:Array.prototype.slice.call(this._arr||this,0)}};var T=4096;function A(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(127&t[i]);return n}function M(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(t[i]);return n}function S(t,e,r){var n=t.length;(!e||e<0)&&(e=0),(!r||r<0||r>n)&&(r=n);for(var i=\"\",a=e;a<r;++a)i+=D(t[a]);return i}function E(t,e,r){for(var n=t.slice(e,r),i=\"\",a=0;a<n.length;a+=2)i+=String.fromCharCode(n[a]+256*n[a+1]);return i}function C(t,e,r){if(t%1!=0||t<0)throw new RangeError(\"offset is not uint\");if(t+e>r)throw new RangeError(\"Trying to access beyond buffer length\")}function L(t,r,n,i,a,o){if(!e.isBuffer(t))throw new TypeError('\"buffer\" argument must be a Buffer instance');if(r>a||r<o)throw new RangeError('\"value\" argument is out of bounds');if(n+i>t.length)throw new RangeError(\"Index out of range\")}function P(t,e,r,n,i,a){if(r+n>t.length)throw new RangeError(\"Index out of range\");if(r<0)throw new RangeError(\"Index out of range\")}function O(t,e,r,n,a){return e=+e,r>>>=0,a||P(t,0,r,4),i.write(t,e,r,n,23,4),r+4}function z(t,e,r,n,a){return e=+e,r>>>=0,a||P(t,0,r,8),i.write(t,e,r,n,52,8),r+8}e.prototype.slice=function(t,r){var n=this.length;(t=~~t)<0?(t+=n)<0&&(t=0):t>n&&(t=n),(r=void 0===r?n:~~r)<0?(r+=n)<0&&(r=0):r>n&&(r=n),r<t&&(r=t);var i=this.subarray(t,r);return i.__proto__=e.prototype,i},e.prototype.readUIntLE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n},e.prototype.readUIntBE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t+--e],i=1;e>0&&(i*=256);)n+=this[t+--e]*i;return n},e.prototype.readUInt8=function(t,e){return t>>>=0,e||C(t,1,this.length),this[t]},e.prototype.readUInt16LE=function(t,e){return t>>>=0,e||C(t,2,this.length),this[t]|this[t+1]<<8},e.prototype.readUInt16BE=function(t,e){return t>>>=0,e||C(t,2,this.length),this[t]<<8|this[t+1]},e.prototype.readUInt32LE=function(t,e){return t>>>=0,e||C(t,4,this.length),(this[t]|this[t+1]<<8|this[t+2]<<16)+16777216*this[t+3]},e.prototype.readUInt32BE=function(t,e){return t>>>=0,e||C(t,4,this.length),16777216*this[t]+(this[t+1]<<16|this[t+2]<<8|this[t+3])},e.prototype.readIntLE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n>=(i*=128)&&(n-=Math.pow(2,8*e)),n},e.prototype.readIntBE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=e,i=1,a=this[t+--n];n>0&&(i*=256);)a+=this[t+--n]*i;return a>=(i*=128)&&(a-=Math.pow(2,8*e)),a},e.prototype.readInt8=function(t,e){return t>>>=0,e||C(t,1,this.length),128&this[t]?-1*(255-this[t]+1):this[t]},e.prototype.readInt16LE=function(t,e){t>>>=0,e||C(t,2,this.length);var r=this[t]|this[t+1]<<8;return 32768&r?4294901760|r:r},e.prototype.readInt16BE=function(t,e){t>>>=0,e||C(t,2,this.length);var r=this[t+1]|this[t]<<8;return 32768&r?4294901760|r:r},e.prototype.readInt32LE=function(t,e){return t>>>=0,e||C(t,4,this.length),this[t]|this[t+1]<<8|this[t+2]<<16|this[t+3]<<24},e.prototype.readInt32BE=function(t,e){return t>>>=0,e||C(t,4,this.length),this[t]<<24|this[t+1]<<16|this[t+2]<<8|this[t+3]},e.prototype.readFloatLE=function(t,e){return t>>>=0,e||C(t,4,this.length),i.read(this,t,!0,23,4)},e.prototype.readFloatBE=function(t,e){return t>>>=0,e||C(t,4,this.length),i.read(this,t,!1,23,4)},e.prototype.readDoubleLE=function(t,e){return t>>>=0,e||C(t,8,this.length),i.read(this,t,!0,52,8)},e.prototype.readDoubleBE=function(t,e){return t>>>=0,e||C(t,8,this.length),i.read(this,t,!1,52,8)},e.prototype.writeUIntLE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||L(this,t,e,r,Math.pow(2,8*r)-1,0);var i=1,a=0;for(this[e]=255&t;++a<r&&(i*=256);)this[e+a]=t/i&255;return e+r},e.prototype.writeUIntBE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||L(this,t,e,r,Math.pow(2,8*r)-1,0);var i=r-1,a=1;for(this[e+i]=255&t;--i>=0&&(a*=256);)this[e+i]=t/a&255;return e+r},e.prototype.writeUInt8=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,1,255,0),this[e]=255&t,e+1},e.prototype.writeUInt16LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,65535,0),this[e]=255&t,this[e+1]=t>>>8,e+2},e.prototype.writeUInt16BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,65535,0),this[e]=t>>>8,this[e+1]=255&t,e+2},e.prototype.writeUInt32LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,4294967295,0),this[e+3]=t>>>24,this[e+2]=t>>>16,this[e+1]=t>>>8,this[e]=255&t,e+4},e.prototype.writeUInt32BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,4294967295,0),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},e.prototype.writeIntLE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);L(this,t,e,r,i-1,-i)}var a=0,o=1,s=0;for(this[e]=255&t;++a<r&&(o*=256);)t<0&&0===s&&0!==this[e+a-1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},e.prototype.writeIntBE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);L(this,t,e,r,i-1,-i)}var a=r-1,o=1,s=0;for(this[e+a]=255&t;--a>=0&&(o*=256);)t<0&&0===s&&0!==this[e+a+1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},e.prototype.writeInt8=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,1,127,-128),t<0&&(t=255+t+1),this[e]=255&t,e+1},e.prototype.writeInt16LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,32767,-32768),this[e]=255&t,this[e+1]=t>>>8,e+2},e.prototype.writeInt16BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,32767,-32768),this[e]=t>>>8,this[e+1]=255&t,e+2},e.prototype.writeInt32LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,2147483647,-2147483648),this[e]=255&t,this[e+1]=t>>>8,this[e+2]=t>>>16,this[e+3]=t>>>24,e+4},e.prototype.writeInt32BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,2147483647,-2147483648),t<0&&(t=4294967295+t+1),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},e.prototype.writeFloatLE=function(t,e,r){return O(this,t,e,!0,r)},e.prototype.writeFloatBE=function(t,e,r){return O(this,t,e,!1,r)},e.prototype.writeDoubleLE=function(t,e,r){return z(this,t,e,!0,r)},e.prototype.writeDoubleBE=function(t,e,r){return z(this,t,e,!1,r)},e.prototype.copy=function(t,r,n,i){if(!e.isBuffer(t))throw new TypeError(\"argument should be a Buffer\");if(n||(n=0),i||0===i||(i=this.length),r>=t.length&&(r=t.length),r||(r=0),i>0&&i<n&&(i=n),i===n)return 0;if(0===t.length||0===this.length)return 0;if(r<0)throw new RangeError(\"targetStart out of bounds\");if(n<0||n>=this.length)throw new RangeError(\"Index out of range\");if(i<0)throw new RangeError(\"sourceEnd out of bounds\");i>this.length&&(i=this.length),t.length-r<i-n&&(i=t.length-r+n);var a=i-n;if(this===t&&\"function\"==typeof Uint8Array.prototype.copyWithin)this.copyWithin(r,n,i);else if(this===t&&n<r&&r<i)for(var o=a-1;o>=0;--o)t[o+r]=this[o+n];else Uint8Array.prototype.set.call(t,this.subarray(n,i),r);return a},e.prototype.fill=function(t,r,n,i){if(\"string\"==typeof t){if(\"string\"==typeof r?(i=r,r=0,n=this.length):\"string\"==typeof n&&(i=n,n=this.length),void 0!==i&&\"string\"!=typeof i)throw new TypeError(\"encoding must be a string\");if(\"string\"==typeof i&&!e.isEncoding(i))throw new TypeError(\"Unknown encoding: \"+i);if(1===t.length){var a=t.charCodeAt(0);(\"utf8\"===i&&a<128||\"latin1\"===i)&&(t=a)}}else\"number\"==typeof t&&(t&=255);if(r<0||this.length<r||this.length<n)throw new RangeError(\"Out of range index\");if(n<=r)return this;var o;if(r>>>=0,n=void 0===n?this.length:n>>>0,t||(t=0),\"number\"==typeof t)for(o=r;o<n;++o)this[o]=t;else{var s=e.isBuffer(t)?t:e.from(t,i),l=s.length;if(0===l)throw new TypeError('The value \"'+t+'\" is invalid for argument \"value\"');for(o=0;o<n-r;++o)this[o+r]=s[o%l]}return this};var I=/[^+\\/0-9A-Za-z-_]/g;function D(t){return t<16?\"0\"+t.toString(16):t.toString(16)}function R(t,e){var r;e=e||1/0;for(var n=t.length,i=null,a=[],o=0;o<n;++o){if((r=t.charCodeAt(o))>55295&&r<57344){if(!i){if(r>56319){(e-=3)>-1&&a.push(239,191,189);continue}if(o+1===n){(e-=3)>-1&&a.push(239,191,189);continue}i=r;continue}if(r<56320){(e-=3)>-1&&a.push(239,191,189),i=r;continue}r=65536+(i-55296<<10|r-56320)}else i&&(e-=3)>-1&&a.push(239,191,189);if(i=null,r<128){if((e-=1)<0)break;a.push(r)}else if(r<2048){if((e-=2)<0)break;a.push(r>>6|192,63&r|128)}else if(r<65536){if((e-=3)<0)break;a.push(r>>12|224,r>>6&63|128,63&r|128)}else{if(!(r<1114112))throw new Error(\"Invalid code point\");if((e-=4)<0)break;a.push(r>>18|240,r>>12&63|128,r>>6&63|128,63&r|128)}}return a}function F(t){return n.toByteArray(function(t){if((t=(t=t.split(\"=\")[0]).trim().replace(I,\"\")).length<2)return\"\";for(;t.length%4!=0;)t+=\"=\";return t}(t))}function B(t,e,r,n){for(var i=0;i<n&&!(i+r>=e.length||i>=t.length);++i)e[i+r]=t[i];return i}function N(t,e){return t instanceof e||null!=t&&null!=t.constructor&&null!=t.constructor.name&&t.constructor.name===e.name}function j(t){return t!=t}}).call(this,t(\"buffer\").Buffer)},{\"base64-js\":74,buffer:105,ieee754:412}],106:[function(t,e,r){\"use strict\";var n=t(\"./lib/monotone\"),i=t(\"./lib/triangulation\"),a=t(\"./lib/delaunay\"),o=t(\"./lib/filter\");function s(t){return[Math.min(t[0],t[1]),Math.max(t[0],t[1])]}function l(t,e){return t[0]-e[0]||t[1]-e[1]}function c(t,e,r){return e in t?t[e]:r}e.exports=function(t,e,r){Array.isArray(e)?(r=r||{},e=e||[]):(r=e||{},e=[]);var u=!!c(r,\"delaunay\",!0),h=!!c(r,\"interior\",!0),f=!!c(r,\"exterior\",!0),p=!!c(r,\"infinity\",!1);if(!h&&!f||0===t.length)return[];var d=n(t,e);if(u||h!==f||p){for(var g=i(t.length,function(t){return t.map(s).sort(l)}(e)),v=0;v<d.length;++v){var m=d[v];g.addTriangle(m[0],m[1],m[2])}return u&&a(t,g),f?h?p?o(g,0,p):g.cells():o(g,1,p):o(g,-1)}return d}},{\"./lib/delaunay\":107,\"./lib/filter\":108,\"./lib/monotone\":109,\"./lib/triangulation\":110}],107:[function(t,e,r){\"use strict\";var n=t(\"robust-in-sphere\")[4];t(\"binary-search-bounds\");function i(t,e,r,i,a,o){var s=e.opposite(i,a);if(!(s<0)){if(a<i){var l=i;i=a,a=l,l=o,o=s,s=l}e.isConstraint(i,a)||n(t[i],t[a],t[o],t[s])<0&&r.push(i,a)}}e.exports=function(t,e){for(var r=[],a=t.length,o=e.stars,s=0;s<a;++s)for(var l=o[s],c=1;c<l.length;c+=2){var u=l[c];if(!(u<s)&&!e.isConstraint(s,u)){for(var h=l[c-1],f=-1,p=1;p<l.length;p+=2)if(l[p-1]===u){f=l[p];break}f<0||n(t[s],t[u],t[h],t[f])<0&&r.push(s,u)}}for(;r.length>0;){for(var u=r.pop(),s=r.pop(),h=-1,f=-1,l=o[s],d=1;d<l.length;d+=2){var g=l[d-1],v=l[d];g===u?f=v:v===u&&(h=g)}h<0||f<0||(n(t[s],t[u],t[h],t[f])>=0||(e.flip(s,u),i(t,e,r,h,s,f),i(t,e,r,s,f,h),i(t,e,r,f,u,h),i(t,e,r,u,h,f)))}}},{\"binary-search-bounds\":111,\"robust-in-sphere\":508}],108:[function(t,e,r){\"use strict\";var n,i=t(\"binary-search-bounds\");function a(t,e,r,n,i,a,o){this.cells=t,this.neighbor=e,this.flags=n,this.constraint=r,this.active=i,this.next=a,this.boundary=o}function o(t,e){return t[0]-e[0]||t[1]-e[1]||t[2]-e[2]}e.exports=function(t,e,r){var n=function(t,e){for(var r=t.cells(),n=r.length,i=0;i<n;++i){var s=r[i],l=s[0],c=s[1],u=s[2];c<u?c<l&&(s[0]=c,s[1]=u,s[2]=l):u<l&&(s[0]=u,s[1]=l,s[2]=c)}r.sort(o);for(var h=new Array(n),i=0;i<h.length;++i)h[i]=0;var f=[],p=[],d=new Array(3*n),g=new Array(3*n),v=null;e&&(v=[]);for(var m=new a(r,d,g,h,f,p,v),i=0;i<n;++i)for(var s=r[i],y=0;y<3;++y){var l=s[y],c=s[(y+1)%3],x=d[3*i+y]=m.locate(c,l,t.opposite(c,l)),b=g[3*i+y]=t.isConstraint(l,c);x<0&&(b?p.push(i):(f.push(i),h[i]=1),e&&v.push([c,l,-1]))}return m}(t,r);if(0===e)return r?n.cells.concat(n.boundary):n.cells;var i=1,s=n.active,l=n.next,c=n.flags,u=n.cells,h=n.constraint,f=n.neighbor;for(;s.length>0||l.length>0;){for(;s.length>0;){var p=s.pop();if(c[p]!==-i){c[p]=i;u[p];for(var d=0;d<3;++d){var g=f[3*p+d];g>=0&&0===c[g]&&(h[3*p+d]?l.push(g):(s.push(g),c[g]=i))}}}var v=l;l=s,s=v,l.length=0,i=-i}var m=function(t,e,r){for(var n=0,i=0;i<t.length;++i)e[i]===r&&(t[n++]=t[i]);return t.length=n,t}(u,c,e);if(r)return m.concat(n.boundary);return m},a.prototype.locate=(n=[0,0,0],function(t,e,r){var a=t,s=e,l=r;return e<r?e<t&&(a=e,s=r,l=t):r<t&&(a=r,s=t,l=e),a<0?-1:(n[0]=a,n[1]=s,n[2]=l,i.eq(this.cells,n,o))})},{\"binary-search-bounds\":111}],109:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"robust-orientation\")[3],a=0,o=1,s=2;function l(t,e,r,n,i){this.a=t,this.b=e,this.idx=r,this.lowerIds=n,this.upperIds=i}function c(t,e,r,n){this.a=t,this.b=e,this.type=r,this.idx=n}function u(t,e){var r=t.a[0]-e.a[0]||t.a[1]-e.a[1]||t.type-e.type;return r||(t.type!==a&&(r=i(t.a,t.b,e.b))?r:t.idx-e.idx)}function h(t,e){return i(t.a,t.b,e)}function f(t,e,r,a,o){for(var s=n.lt(e,a,h),l=n.gt(e,a,h),c=s;c<l;++c){for(var u=e[c],f=u.lowerIds,p=f.length;p>1&&i(r[f[p-2]],r[f[p-1]],a)>0;)t.push([f[p-1],f[p-2],o]),p-=1;f.length=p,f.push(o);var d=u.upperIds;for(p=d.length;p>1&&i(r[d[p-2]],r[d[p-1]],a)<0;)t.push([d[p-2],d[p-1],o]),p-=1;d.length=p,d.push(o)}}function p(t,e){var r;return(r=t.a[0]<e.a[0]?i(t.a,t.b,e.a):i(e.b,e.a,t.a))?r:(r=e.b[0]<t.b[0]?i(t.a,t.b,e.b):i(e.b,e.a,t.b))||t.idx-e.idx}function d(t,e,r){var i=n.le(t,r,p),a=t[i],o=a.upperIds,s=o[o.length-1];a.upperIds=[s],t.splice(i+1,0,new l(r.a,r.b,r.idx,[s],o))}function g(t,e,r){var i=r.a;r.a=r.b,r.b=i;var a=n.eq(t,r,p),o=t[a];t[a-1].upperIds=o.upperIds,t.splice(a,1)}e.exports=function(t,e){for(var r=t.length,n=e.length,i=[],h=0;h<r;++h)i.push(new c(t[h],null,a,h));for(var h=0;h<n;++h){var p=e[h],v=t[p[0]],m=t[p[1]];v[0]<m[0]?i.push(new c(v,m,s,h),new c(m,v,o,h)):v[0]>m[0]&&i.push(new c(m,v,s,h),new c(v,m,o,h))}i.sort(u);for(var y=i[0].a[0]-(1+Math.abs(i[0].a[0]))*Math.pow(2,-52),x=[new l([y,1],[y,0],-1,[],[],[],[])],b=[],h=0,_=i.length;h<_;++h){var w=i[h],k=w.type;k===a?f(b,x,t,w.a,w.idx):k===s?d(x,t,w):g(x,t,w)}return b}},{\"binary-search-bounds\":111,\"robust-orientation\":510}],110:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\");function i(t,e){this.stars=t,this.edges=e}e.exports=function(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=[];return new i(r,e)};var a=i.prototype;function o(t,e,r){for(var n=1,i=t.length;n<i;n+=2)if(t[n-1]===e&&t[n]===r)return t[n-1]=t[i-2],t[n]=t[i-1],void(t.length=i-2)}a.isConstraint=function(){var t=[0,0];function e(t,e){return t[0]-e[0]||t[1]-e[1]}return function(r,i){return t[0]=Math.min(r,i),t[1]=Math.max(r,i),n.eq(this.edges,t,e)>=0}}(),a.removeTriangle=function(t,e,r){var n=this.stars;o(n[t],e,r),o(n[e],r,t),o(n[r],t,e)},a.addTriangle=function(t,e,r){var n=this.stars;n[t].push(e,r),n[e].push(r,t),n[r].push(t,e)},a.opposite=function(t,e){for(var r=this.stars[e],n=1,i=r.length;n<i;n+=2)if(r[n]===t)return r[n-1];return-1},a.flip=function(t,e){var r=this.opposite(t,e),n=this.opposite(e,t);this.removeTriangle(t,e,r),this.removeTriangle(e,t,n),this.addTriangle(t,n,r),this.addTriangle(e,r,n)},a.edges=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2)e.push([i[a],i[a+1]]);return e},a.cells=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2){var s=i[a],l=i[a+1];r<Math.min(s,l)&&e.push([r,s,l])}return e}},{\"binary-search-bounds\":111}],111:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",i?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a[m]\"];return i?e.indexOf(\"c\")<0?a.push(\";if(x===y){return m}else if(x<=y){\"):a.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):a.push(\";if(\",e,\"){i=m;\"),r?a.push(\"l=m+1}else{h=m-1}\"):a.push(\"h=m-1}else{l=m+1}\"),a.push(\"}\"),i?a.push(\"return -1};\"):a.push(\"return i};\"),a.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(typeof(c)==='function'){return P(a,(l===void 0)?0:l|0,(h===void 0)?a.length-1:h|0,y,c)}else{return A(a,(c===void 0)?0:c|0,(l===void 0)?a.length-1:l|0,y)}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],112:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1,r=1;r<t.length;++r)for(var n=0;n<r;++n)if(t[r]<t[n])e=-e;else if(t[n]===t[r])return 0;return e}},{}],113:[function(t,e,r){\"use strict\";var n=t(\"dup\"),i=t(\"robust-linear-solve\");function a(t,e){for(var r=0,n=t.length,i=0;i<n;++i)r+=t[i]*e[i];return r}function o(t){var e=t.length;if(0===e)return[];t[0].length;var r=n([t.length+1,t.length+1],1),o=n([t.length+1],1);r[e][e]=0;for(var s=0;s<e;++s){for(var l=0;l<=s;++l)r[l][s]=r[s][l]=2*a(t[s],t[l]);o[s]=a(t[s],t[s])}var c=i(r,o),u=0,h=c[e+1];for(s=0;s<h.length;++s)u+=h[s];var f=new Array(e);for(s=0;s<e;++s){h=c[s];var p=0;for(l=0;l<h.length;++l)p+=h[l];f[s]=p/u}return f}function s(t){if(0===t.length)return[];for(var e=t[0].length,r=n([e]),i=o(t),a=0;a<t.length;++a)for(var s=0;s<e;++s)r[s]+=t[a][s]*i[a];return r}s.barycenetric=o,e.exports=s},{dup:170,\"robust-linear-solve\":509}],114:[function(t,e,r){e.exports=function(t){for(var e=n(t),r=0,i=0;i<t.length;++i)for(var a=t[i],o=0;o<e.length;++o)r+=Math.pow(a[o]-e[o],2);return Math.sqrt(r/t.length)};var n=t(\"circumcenter\")},{circumcenter:113}],115:[function(t,e,r){e.exports=function(t,e,r){return e<r?t<e?e:t>r?r:t:t<r?r:t>e?e:t}},{}],116:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n;if(r){n=e;for(var i=new Array(e.length),a=0;a<e.length;++a){var o=e[a];i[a]=[o[0],o[1],r[a]]}e=i}var s=function(t,e,r){var n=d(t,[],p(t));return m(e,n,r),!!n}(t,e,!!r);for(;y(t,e,!!r);)s=!0;if(r&&s){n.length=0,r.length=0;for(var a=0;a<e.length;++a){var o=e[a];n.push([o[0],o[1]]),r.push(o[2])}}return s};var n=t(\"union-find\"),i=t(\"box-intersect\"),a=t(\"robust-segment-intersect\"),o=t(\"big-rat\"),s=t(\"big-rat/cmp\"),l=t(\"big-rat/to-float\"),c=t(\"rat-vec\"),u=t(\"nextafter\"),h=t(\"./lib/rat-seg-intersect\");function f(t){var e=l(t);return[u(e,-1/0),u(e,1/0)]}function p(t){for(var e=new Array(t.length),r=0;r<t.length;++r){var n=t[r];e[r]=[u(n[0],-1/0),u(n[1],-1/0),u(n[0],1/0),u(n[1],1/0)]}return e}function d(t,e,r){for(var a=e.length,o=new n(a),s=[],l=0;l<e.length;++l){var c=e[l],h=f(c[0]),p=f(c[1]);s.push([u(h[0],-1/0),u(p[0],-1/0),u(h[1],1/0),u(p[1],1/0)])}i(s,function(t,e){o.link(t,e)});var d=!0,g=new Array(a);for(l=0;l<a;++l){(m=o.find(l))!==l&&(d=!1,t[m]=[Math.min(t[l][0],t[m][0]),Math.min(t[l][1],t[m][1])])}if(d)return null;var v=0;for(l=0;l<a;++l){var m;(m=o.find(l))===l?(g[l]=v,t[v++]=t[l]):g[l]=-1}t.length=v;for(l=0;l<a;++l)g[l]<0&&(g[l]=g[o.find(l)]);return g}function g(t,e){return t[0]-e[0]||t[1]-e[1]}function v(t,e){var r=t[0]-e[0]||t[1]-e[1];return r||(t[2]<e[2]?-1:t[2]>e[2]?1:0)}function m(t,e,r){if(0!==t.length){if(e)for(var n=0;n<t.length;++n){var i=e[(o=t[n])[0]],a=e[o[1]];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}else for(n=0;n<t.length;++n){var o;i=(o=t[n])[0],a=o[1];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}r?t.sort(v):t.sort(g);var s=1;for(n=1;n<t.length;++n){var l=t[n-1],c=t[n];(c[0]!==l[0]||c[1]!==l[1]||r&&c[2]!==l[2])&&(t[s++]=c)}t.length=s}}function y(t,e,r){var n=function(t,e){for(var r=new Array(e.length),n=0;n<e.length;++n){var i=e[n],a=t[i[0]],o=t[i[1]];r[n]=[u(Math.min(a[0],o[0]),-1/0),u(Math.min(a[1],o[1]),-1/0),u(Math.max(a[0],o[0]),1/0),u(Math.max(a[1],o[1]),1/0)]}return r}(t,e),f=function(t,e,r){var n=[];return i(r,function(r,i){var o=e[r],s=e[i];if(o[0]!==s[0]&&o[0]!==s[1]&&o[1]!==s[0]&&o[1]!==s[1]){var l=t[o[0]],c=t[o[1]],u=t[s[0]],h=t[s[1]];a(l,c,u,h)&&n.push([r,i])}}),n}(t,e,n),g=p(t),v=function(t,e,r,n){var o=[];return i(r,n,function(r,n){var i=e[r];if(i[0]!==n&&i[1]!==n){var s=t[n],l=t[i[0]],c=t[i[1]];a(l,c,s,s)&&o.push([r,n])}}),o}(t,e,n,g),y=d(t,function(t,e,r,n,i){var a,u,f=t.map(function(t){return[o(t[0]),o(t[1])]});for(a=0;a<r.length;++a){var p=r[a];u=p[0];var d=p[1],g=e[u],v=e[d],m=h(c(t[g[0]]),c(t[g[1]]),c(t[v[0]]),c(t[v[1]]));if(m){var y=t.length;t.push([l(m[0]),l(m[1])]),f.push(m),n.push([u,y],[d,y])}}for(n.sort(function(t,e){if(t[0]!==e[0])return t[0]-e[0];var r=f[t[1]],n=f[e[1]];return s(r[0],n[0])||s(r[1],n[1])}),a=n.length-1;a>=0;--a){var x=e[u=(S=n[a])[0]],b=x[0],_=x[1],w=t[b],k=t[_];if((w[0]-k[0]||w[1]-k[1])<0){var T=b;b=_,_=T}x[0]=b;var A,M=x[1]=S[1];for(i&&(A=x[2]);a>0&&n[a-1][0]===u;){var S,E=(S=n[--a])[1];i?e.push([M,E,A]):e.push([M,E]),M=E}i?e.push([M,_,A]):e.push([M,_])}return f}(t,e,f,v,r));return m(e,y,r),!!y||(f.length>0||v.length>0)}},{\"./lib/rat-seg-intersect\":117,\"big-rat\":78,\"big-rat/cmp\":76,\"big-rat/to-float\":90,\"box-intersect\":96,nextafter:451,\"rat-vec\":486,\"robust-segment-intersect\":513,\"union-find\":546}],117:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var a=s(e,t),h=s(n,r),f=u(a,h);if(0===o(f))return null;var p=s(t,r),d=u(h,p),g=i(d,f),v=c(a,g);return l(t,v)};var n=t(\"big-rat/mul\"),i=t(\"big-rat/div\"),a=t(\"big-rat/sub\"),o=t(\"big-rat/sign\"),s=t(\"rat-vec/sub\"),l=t(\"rat-vec/add\"),c=t(\"rat-vec/muls\");function u(t,e){return a(n(t[0],e[1]),n(t[1],e[0]))}},{\"big-rat/div\":77,\"big-rat/mul\":87,\"big-rat/sign\":88,\"big-rat/sub\":89,\"rat-vec/add\":485,\"rat-vec/muls\":487,\"rat-vec/sub\":488}],118:[function(t,e,r){\"use strict\";var n=t(\"clamp\");function i(t,e){null==e&&(e=!0);var r=t[0],i=t[1],a=t[2],o=t[3];return null==o&&(o=e?1:255),e&&(r*=255,i*=255,a*=255,o*=255),16777216*(r=255&n(r,0,255))+((i=255&n(i,0,255))<<16)+((a=255&n(a,0,255))<<8)+(o=255&n(o,0,255))}e.exports=i,e.exports.to=i,e.exports.from=function(t,e){var r=(t=+t)>>>24,n=(16711680&t)>>>16,i=(65280&t)>>>8,a=255&t;return!1===e?[r,n,i,a]:[r/255,n/255,i/255,a/255]}},{clamp:115}],119:[function(t,e,r){\"use strict\";e.exports={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]}},{}],120:[function(t,e,r){\"use strict\";var n=t(\"color-rgba\"),i=t(\"clamp\"),a=t(\"dtype\");e.exports=function(t,e){\"float\"!==e&&e||(e=\"array\"),\"uint\"===e&&(e=\"uint8\"),\"uint_clamped\"===e&&(e=\"uint8_clamped\");var r=new(a(e))(4),o=\"uint8\"!==e&&\"uint8_clamped\"!==e;return t.length&&\"string\"!=typeof t||((t=n(t))[0]/=255,t[1]/=255,t[2]/=255),function(t){return t instanceof Uint8Array||t instanceof Uint8ClampedArray||!!(Array.isArray(t)&&(t[0]>1||0===t[0])&&(t[1]>1||0===t[1])&&(t[2]>1||0===t[2])&&(!t[3]||t[3]>1))}(t)?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:255,o&&(r[0]/=255,r[1]/=255,r[2]/=255,r[3]/=255),r):(o?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:1):(r[0]=i(Math.floor(255*t[0]),0,255),r[1]=i(Math.floor(255*t[1]),0,255),r[2]=i(Math.floor(255*t[2]),0,255),r[3]=null==t[3]?255:i(Math.floor(255*t[3]),0,255)),r)}},{clamp:115,\"color-rgba\":122,dtype:169}],121:[function(t,e,r){(function(r){\"use strict\";var n=t(\"color-name\"),i=t(\"is-plain-obj\"),a=t(\"defined\");e.exports=function(t){var e,s,l=[],c=1;if(\"string\"==typeof t)if(n[t])l=n[t].slice(),s=\"rgb\";else if(\"transparent\"===t)c=0,s=\"rgb\",l=[0,0,0];else if(/^#[A-Fa-f0-9]+$/.test(t)){var u=t.slice(1),h=u.length,f=h<=4;c=1,f?(l=[parseInt(u[0]+u[0],16),parseInt(u[1]+u[1],16),parseInt(u[2]+u[2],16)],4===h&&(c=parseInt(u[3]+u[3],16)/255)):(l=[parseInt(u[0]+u[1],16),parseInt(u[2]+u[3],16),parseInt(u[4]+u[5],16)],8===h&&(c=parseInt(u[6]+u[7],16)/255)),l[0]||(l[0]=0),l[1]||(l[1]=0),l[2]||(l[2]=0),s=\"rgb\"}else if(e=/^((?:rgb|hs[lvb]|hwb|cmyk?|xy[zy]|gray|lab|lchu?v?|[ly]uv|lms)a?)\\s*\\(([^\\)]*)\\)/.exec(t)){var p=e[1],d=\"rgb\"===p,u=p.replace(/a$/,\"\");s=u;var h=\"cmyk\"===u?4:\"gray\"===u?1:3;l=e[2].trim().split(/\\s*,\\s*/).map(function(t,e){if(/%$/.test(t))return e===h?parseFloat(t)/100:\"rgb\"===u?255*parseFloat(t)/100:parseFloat(t);if(\"h\"===u[e]){if(/deg$/.test(t))return parseFloat(t);if(void 0!==o[t])return o[t]}return parseFloat(t)}),p===u&&l.push(1),c=d?1:void 0===l[h]?1:l[h],l=l.slice(0,h)}else t.length>10&&/[0-9](?:\\s|\\/)/.test(t)&&(l=t.match(/([0-9]+)/g).map(function(t){return parseFloat(t)}),s=t.match(/([a-z])/gi).join(\"\").toLowerCase());else if(isNaN(t))if(i(t)){var g=a(t.r,t.red,t.R,null);null!==g?(s=\"rgb\",l=[g,a(t.g,t.green,t.G),a(t.b,t.blue,t.B)]):(s=\"hsl\",l=[a(t.h,t.hue,t.H),a(t.s,t.saturation,t.S),a(t.l,t.lightness,t.L,t.b,t.brightness)]),c=a(t.a,t.alpha,t.opacity,1),null!=t.opacity&&(c/=100)}else(Array.isArray(t)||r.ArrayBuffer&&ArrayBuffer.isView&&ArrayBuffer.isView(t))&&(l=[t[0],t[1],t[2]],s=\"rgb\",c=4===t.length?t[3]:1);else s=\"rgb\",l=[t>>>16,(65280&t)>>>8,255&t];return{space:s,values:l,alpha:c}};var o={red:0,orange:60,yellow:120,green:180,blue:240,purple:300}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"color-name\":119,defined:164,\"is-plain-obj\":422}],122:[function(t,e,r){\"use strict\";var n=t(\"color-parse\"),i=t(\"color-space/hsl\"),a=t(\"clamp\");e.exports=function(t){var e,r=n(t);return r.space?((e=Array(3))[0]=a(r.values[0],0,255),e[1]=a(r.values[1],0,255),e[2]=a(r.values[2],0,255),\"h\"===r.space[0]&&(e=i.rgb(e)),e.push(a(r.alpha,0,1)),e):[]}},{clamp:115,\"color-parse\":121,\"color-space/hsl\":123}],123:[function(t,e,r){\"use strict\";var n=t(\"./rgb\");e.exports={name:\"hsl\",min:[0,0,0],max:[360,100,100],channel:[\"hue\",\"saturation\",\"lightness\"],alias:[\"HSL\"],rgb:function(t){var e,r,n,i,a,o=t[0]/360,s=t[1]/100,l=t[2]/100;if(0===s)return[a=255*l,a,a];e=2*l-(r=l<.5?l*(1+s):l+s-l*s),i=[0,0,0];for(var c=0;c<3;c++)(n=o+1/3*-(c-1))<0?n++:n>1&&n--,a=6*n<1?e+6*(r-e)*n:2*n<1?r:3*n<2?e+(r-e)*(2/3-n)*6:e,i[c]=255*a;return i}},n.hsl=function(t){var e,r,n=t[0]/255,i=t[1]/255,a=t[2]/255,o=Math.min(n,i,a),s=Math.max(n,i,a),l=s-o;return s===o?e=0:n===s?e=(i-a)/l:i===s?e=2+(a-n)/l:a===s&&(e=4+(n-i)/l),(e=Math.min(60*e,360))<0&&(e+=360),r=(o+s)/2,[e,100*(s===o?0:r<=.5?l/(s+o):l/(2-s-o)),100*r]}},{\"./rgb\":124}],124:[function(t,e,r){\"use strict\";e.exports={name:\"rgb\",min:[0,0,0],max:[255,255,255],channel:[\"red\",\"green\",\"blue\"],alias:[\"RGB\"]}},{}],125:[function(t,e,r){e.exports={jet:[{index:0,rgb:[0,0,131]},{index:.125,rgb:[0,60,170]},{index:.375,rgb:[5,255,255]},{index:.625,rgb:[255,255,0]},{index:.875,rgb:[250,0,0]},{index:1,rgb:[128,0,0]}],hsv:[{index:0,rgb:[255,0,0]},{index:.169,rgb:[253,255,2]},{index:.173,rgb:[247,255,2]},{index:.337,rgb:[0,252,4]},{index:.341,rgb:[0,252,10]},{index:.506,rgb:[1,249,255]},{index:.671,rgb:[2,0,253]},{index:.675,rgb:[8,0,253]},{index:.839,rgb:[255,0,251]},{index:.843,rgb:[255,0,245]},{index:1,rgb:[255,0,6]}],hot:[{index:0,rgb:[0,0,0]},{index:.3,rgb:[230,0,0]},{index:.6,rgb:[255,210,0]},{index:1,rgb:[255,255,255]}],cool:[{index:0,rgb:[0,255,255]},{index:1,rgb:[255,0,255]}],spring:[{index:0,rgb:[255,0,255]},{index:1,rgb:[255,255,0]}],summer:[{index:0,rgb:[0,128,102]},{index:1,rgb:[255,255,102]}],autumn:[{index:0,rgb:[255,0,0]},{index:1,rgb:[255,255,0]}],winter:[{index:0,rgb:[0,0,255]},{index:1,rgb:[0,255,128]}],bone:[{index:0,rgb:[0,0,0]},{index:.376,rgb:[84,84,116]},{index:.753,rgb:[169,200,200]},{index:1,rgb:[255,255,255]}],copper:[{index:0,rgb:[0,0,0]},{index:.804,rgb:[255,160,102]},{index:1,rgb:[255,199,127]}],greys:[{index:0,rgb:[0,0,0]},{index:1,rgb:[255,255,255]}],yignbu:[{index:0,rgb:[8,29,88]},{index:.125,rgb:[37,52,148]},{index:.25,rgb:[34,94,168]},{index:.375,rgb:[29,145,192]},{index:.5,rgb:[65,182,196]},{index:.625,rgb:[127,205,187]},{index:.75,rgb:[199,233,180]},{index:.875,rgb:[237,248,217]},{index:1,rgb:[255,255,217]}],greens:[{index:0,rgb:[0,68,27]},{index:.125,rgb:[0,109,44]},{index:.25,rgb:[35,139,69]},{index:.375,rgb:[65,171,93]},{index:.5,rgb:[116,196,118]},{index:.625,rgb:[161,217,155]},{index:.75,rgb:[199,233,192]},{index:.875,rgb:[229,245,224]},{index:1,rgb:[247,252,245]}],yiorrd:[{index:0,rgb:[128,0,38]},{index:.125,rgb:[189,0,38]},{index:.25,rgb:[227,26,28]},{index:.375,rgb:[252,78,42]},{index:.5,rgb:[253,141,60]},{index:.625,rgb:[254,178,76]},{index:.75,rgb:[254,217,118]},{index:.875,rgb:[255,237,160]},{index:1,rgb:[255,255,204]}],bluered:[{index:0,rgb:[0,0,255]},{index:1,rgb:[255,0,0]}],rdbu:[{index:0,rgb:[5,10,172]},{index:.35,rgb:[106,137,247]},{index:.5,rgb:[190,190,190]},{index:.6,rgb:[220,170,132]},{index:.7,rgb:[230,145,90]},{index:1,rgb:[178,10,28]}],picnic:[{index:0,rgb:[0,0,255]},{index:.1,rgb:[51,153,255]},{index:.2,rgb:[102,204,255]},{index:.3,rgb:[153,204,255]},{index:.4,rgb:[204,204,255]},{index:.5,rgb:[255,255,255]},{index:.6,rgb:[255,204,255]},{index:.7,rgb:[255,153,255]},{index:.8,rgb:[255,102,204]},{index:.9,rgb:[255,102,102]},{index:1,rgb:[255,0,0]}],rainbow:[{index:0,rgb:[150,0,90]},{index:.125,rgb:[0,0,200]},{index:.25,rgb:[0,25,255]},{index:.375,rgb:[0,152,255]},{index:.5,rgb:[44,255,150]},{index:.625,rgb:[151,255,0]},{index:.75,rgb:[255,234,0]},{index:.875,rgb:[255,111,0]},{index:1,rgb:[255,0,0]}],portland:[{index:0,rgb:[12,51,131]},{index:.25,rgb:[10,136,186]},{index:.5,rgb:[242,211,56]},{index:.75,rgb:[242,143,56]},{index:1,rgb:[217,30,30]}],blackbody:[{index:0,rgb:[0,0,0]},{index:.2,rgb:[230,0,0]},{index:.4,rgb:[230,210,0]},{index:.7,rgb:[255,255,255]},{index:1,rgb:[160,200,255]}],earth:[{index:0,rgb:[0,0,130]},{index:.1,rgb:[0,180,180]},{index:.2,rgb:[40,210,40]},{index:.4,rgb:[230,230,50]},{index:.6,rgb:[120,70,20]},{index:1,rgb:[255,255,255]}],electric:[{index:0,rgb:[0,0,0]},{index:.15,rgb:[30,0,100]},{index:.4,rgb:[120,0,100]},{index:.6,rgb:[160,90,0]},{index:.8,rgb:[230,200,0]},{index:1,rgb:[255,250,220]}],alpha:[{index:0,rgb:[255,255,255,0]},{index:1,rgb:[255,255,255,1]}],viridis:[{index:0,rgb:[68,1,84]},{index:.13,rgb:[71,44,122]},{index:.25,rgb:[59,81,139]},{index:.38,rgb:[44,113,142]},{index:.5,rgb:[33,144,141]},{index:.63,rgb:[39,173,129]},{index:.75,rgb:[92,200,99]},{index:.88,rgb:[170,220,50]},{index:1,rgb:[253,231,37]}],inferno:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[31,12,72]},{index:.25,rgb:[85,15,109]},{index:.38,rgb:[136,34,106]},{index:.5,rgb:[186,54,85]},{index:.63,rgb:[227,89,51]},{index:.75,rgb:[249,140,10]},{index:.88,rgb:[249,201,50]},{index:1,rgb:[252,255,164]}],magma:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[28,16,68]},{index:.25,rgb:[79,18,123]},{index:.38,rgb:[129,37,129]},{index:.5,rgb:[181,54,122]},{index:.63,rgb:[229,80,100]},{index:.75,rgb:[251,135,97]},{index:.88,rgb:[254,194,135]},{index:1,rgb:[252,253,191]}],plasma:[{index:0,rgb:[13,8,135]},{index:.13,rgb:[75,3,161]},{index:.25,rgb:[125,3,168]},{index:.38,rgb:[168,34,150]},{index:.5,rgb:[203,70,121]},{index:.63,rgb:[229,107,93]},{index:.75,rgb:[248,148,65]},{index:.88,rgb:[253,195,40]},{index:1,rgb:[240,249,33]}],warm:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[172,0,187]},{index:.25,rgb:[219,0,170]},{index:.38,rgb:[255,0,130]},{index:.5,rgb:[255,63,74]},{index:.63,rgb:[255,123,0]},{index:.75,rgb:[234,176,0]},{index:.88,rgb:[190,228,0]},{index:1,rgb:[147,255,0]}],cool:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[116,0,218]},{index:.25,rgb:[98,74,237]},{index:.38,rgb:[68,146,231]},{index:.5,rgb:[0,204,197]},{index:.63,rgb:[0,247,146]},{index:.75,rgb:[0,255,88]},{index:.88,rgb:[40,255,8]},{index:1,rgb:[147,255,0]}],\"rainbow-soft\":[{index:0,rgb:[125,0,179]},{index:.1,rgb:[199,0,180]},{index:.2,rgb:[255,0,121]},{index:.3,rgb:[255,108,0]},{index:.4,rgb:[222,194,0]},{index:.5,rgb:[150,255,0]},{index:.6,rgb:[0,255,55]},{index:.7,rgb:[0,246,150]},{index:.8,rgb:[50,167,222]},{index:.9,rgb:[103,51,235]},{index:1,rgb:[124,0,186]}],bathymetry:[{index:0,rgb:[40,26,44]},{index:.13,rgb:[59,49,90]},{index:.25,rgb:[64,76,139]},{index:.38,rgb:[63,110,151]},{index:.5,rgb:[72,142,158]},{index:.63,rgb:[85,174,163]},{index:.75,rgb:[120,206,163]},{index:.88,rgb:[187,230,172]},{index:1,rgb:[253,254,204]}],cdom:[{index:0,rgb:[47,15,62]},{index:.13,rgb:[87,23,86]},{index:.25,rgb:[130,28,99]},{index:.38,rgb:[171,41,96]},{index:.5,rgb:[206,67,86]},{index:.63,rgb:[230,106,84]},{index:.75,rgb:[242,149,103]},{index:.88,rgb:[249,193,135]},{index:1,rgb:[254,237,176]}],chlorophyll:[{index:0,rgb:[18,36,20]},{index:.13,rgb:[25,63,41]},{index:.25,rgb:[24,91,59]},{index:.38,rgb:[13,119,72]},{index:.5,rgb:[18,148,80]},{index:.63,rgb:[80,173,89]},{index:.75,rgb:[132,196,122]},{index:.88,rgb:[175,221,162]},{index:1,rgb:[215,249,208]}],density:[{index:0,rgb:[54,14,36]},{index:.13,rgb:[89,23,80]},{index:.25,rgb:[110,45,132]},{index:.38,rgb:[120,77,178]},{index:.5,rgb:[120,113,213]},{index:.63,rgb:[115,151,228]},{index:.75,rgb:[134,185,227]},{index:.88,rgb:[177,214,227]},{index:1,rgb:[230,241,241]}],\"freesurface-blue\":[{index:0,rgb:[30,4,110]},{index:.13,rgb:[47,14,176]},{index:.25,rgb:[41,45,236]},{index:.38,rgb:[25,99,212]},{index:.5,rgb:[68,131,200]},{index:.63,rgb:[114,156,197]},{index:.75,rgb:[157,181,203]},{index:.88,rgb:[200,208,216]},{index:1,rgb:[241,237,236]}],\"freesurface-red\":[{index:0,rgb:[60,9,18]},{index:.13,rgb:[100,17,27]},{index:.25,rgb:[142,20,29]},{index:.38,rgb:[177,43,27]},{index:.5,rgb:[192,87,63]},{index:.63,rgb:[205,125,105]},{index:.75,rgb:[216,162,148]},{index:.88,rgb:[227,199,193]},{index:1,rgb:[241,237,236]}],oxygen:[{index:0,rgb:[64,5,5]},{index:.13,rgb:[106,6,15]},{index:.25,rgb:[144,26,7]},{index:.38,rgb:[168,64,3]},{index:.5,rgb:[188,100,4]},{index:.63,rgb:[206,136,11]},{index:.75,rgb:[220,174,25]},{index:.88,rgb:[231,215,44]},{index:1,rgb:[248,254,105]}],par:[{index:0,rgb:[51,20,24]},{index:.13,rgb:[90,32,35]},{index:.25,rgb:[129,44,34]},{index:.38,rgb:[159,68,25]},{index:.5,rgb:[182,99,19]},{index:.63,rgb:[199,134,22]},{index:.75,rgb:[212,171,35]},{index:.88,rgb:[221,210,54]},{index:1,rgb:[225,253,75]}],phase:[{index:0,rgb:[145,105,18]},{index:.13,rgb:[184,71,38]},{index:.25,rgb:[186,58,115]},{index:.38,rgb:[160,71,185]},{index:.5,rgb:[110,97,218]},{index:.63,rgb:[50,123,164]},{index:.75,rgb:[31,131,110]},{index:.88,rgb:[77,129,34]},{index:1,rgb:[145,105,18]}],salinity:[{index:0,rgb:[42,24,108]},{index:.13,rgb:[33,50,162]},{index:.25,rgb:[15,90,145]},{index:.38,rgb:[40,118,137]},{index:.5,rgb:[59,146,135]},{index:.63,rgb:[79,175,126]},{index:.75,rgb:[120,203,104]},{index:.88,rgb:[193,221,100]},{index:1,rgb:[253,239,154]}],temperature:[{index:0,rgb:[4,35,51]},{index:.13,rgb:[23,51,122]},{index:.25,rgb:[85,59,157]},{index:.38,rgb:[129,79,143]},{index:.5,rgb:[175,95,130]},{index:.63,rgb:[222,112,101]},{index:.75,rgb:[249,146,66]},{index:.88,rgb:[249,196,65]},{index:1,rgb:[232,250,91]}],turbidity:[{index:0,rgb:[34,31,27]},{index:.13,rgb:[65,50,41]},{index:.25,rgb:[98,69,52]},{index:.38,rgb:[131,89,57]},{index:.5,rgb:[161,112,59]},{index:.63,rgb:[185,140,66]},{index:.75,rgb:[202,174,88]},{index:.88,rgb:[216,209,126]},{index:1,rgb:[233,246,171]}],\"velocity-blue\":[{index:0,rgb:[17,32,64]},{index:.13,rgb:[35,52,116]},{index:.25,rgb:[29,81,156]},{index:.38,rgb:[31,113,162]},{index:.5,rgb:[50,144,169]},{index:.63,rgb:[87,173,176]},{index:.75,rgb:[149,196,189]},{index:.88,rgb:[203,221,211]},{index:1,rgb:[254,251,230]}],\"velocity-green\":[{index:0,rgb:[23,35,19]},{index:.13,rgb:[24,64,38]},{index:.25,rgb:[11,95,45]},{index:.38,rgb:[39,123,35]},{index:.5,rgb:[95,146,12]},{index:.63,rgb:[152,165,18]},{index:.75,rgb:[201,186,69]},{index:.88,rgb:[233,216,137]},{index:1,rgb:[255,253,205]}],cubehelix:[{index:0,rgb:[0,0,0]},{index:.07,rgb:[22,5,59]},{index:.13,rgb:[60,4,105]},{index:.2,rgb:[109,1,135]},{index:.27,rgb:[161,0,147]},{index:.33,rgb:[210,2,142]},{index:.4,rgb:[251,11,123]},{index:.47,rgb:[255,29,97]},{index:.53,rgb:[255,54,69]},{index:.6,rgb:[255,85,46]},{index:.67,rgb:[255,120,34]},{index:.73,rgb:[255,157,37]},{index:.8,rgb:[241,191,57]},{index:.87,rgb:[224,220,93]},{index:.93,rgb:[218,241,142]},{index:1,rgb:[227,253,198]}]}},{}],126:[function(t,e,r){\"use strict\";var n=t(\"./colorScale\"),i=t(\"lerp\");function a(t){return[t[0]/255,t[1]/255,t[2]/255,t[3]]}function o(t){for(var e,r=\"#\",n=0;n<3;++n)r+=(\"00\"+(e=(e=t[n]).toString(16))).substr(e.length);return r}function s(t){return\"rgba(\"+t.join(\",\")+\")\"}e.exports=function(t){var e,r,l,c,u,h,f,p,d,g;t||(t={});p=(t.nshades||72)-1,f=t.format||\"hex\",(h=t.colormap)||(h=\"jet\");if(\"string\"==typeof h){if(h=h.toLowerCase(),!n[h])throw Error(h+\" not a supported colorscale\");u=n[h]}else{if(!Array.isArray(h))throw Error(\"unsupported colormap option\",h);u=h.slice()}if(u.length>p+1)throw new Error(h+\" map requires nshades to be at least size \"+u.length);d=Array.isArray(t.alpha)?2!==t.alpha.length?[1,1]:t.alpha.slice():\"number\"==typeof t.alpha?[t.alpha,t.alpha]:[1,1];e=u.map(function(t){return Math.round(t.index*p)}),d[0]=Math.min(Math.max(d[0],0),1),d[1]=Math.min(Math.max(d[1],0),1);var v=u.map(function(t,e){var r=u[e].index,n=u[e].rgb.slice();return 4===n.length&&n[3]>=0&&n[3]<=1?n:(n[3]=d[0]+(d[1]-d[0])*r,n)}),m=[];for(g=0;g<e.length-1;++g){c=e[g+1]-e[g],r=v[g],l=v[g+1];for(var y=0;y<c;y++){var x=y/c;m.push([Math.round(i(r[0],l[0],x)),Math.round(i(r[1],l[1],x)),Math.round(i(r[2],l[2],x)),i(r[3],l[3],x)])}}m.push(u[u.length-1].rgb.concat(d[1])),\"hex\"===f?m=m.map(o):\"rgbaString\"===f?m=m.map(s):\"float\"===f&&(m=m.map(a));return m}},{\"./colorScale\":125,lerp:425}],127:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a){var o=n(e,r,a);if(0===o){var s=i(n(t,e,r)),c=i(n(t,e,a));if(s===c){if(0===s){var u=l(t,e,r),h=l(t,e,a);return u===h?0:u?1:-1}return 0}return 0===c?s>0?-1:l(t,e,a)?-1:1:0===s?c>0?1:l(t,e,r)?1:-1:i(c-s)}var f=n(t,e,r);if(f>0)return o>0&&n(t,e,a)>0?1:-1;if(f<0)return o>0||n(t,e,a)>0?1:-1;var p=n(t,e,a);return p>0?1:l(t,e,r)?1:-1};var n=t(\"robust-orientation\"),i=t(\"signum\"),a=t(\"two-sum\"),o=t(\"robust-product\"),s=t(\"robust-sum\");function l(t,e,r){var n=a(t[0],-e[0]),i=a(t[1],-e[1]),l=a(r[0],-e[0]),c=a(r[1],-e[1]),u=s(o(n,l),o(i,c));return u[u.length-1]>=0}},{\"robust-orientation\":510,\"robust-product\":511,\"robust-sum\":515,signum:516,\"two-sum\":544}],128:[function(t,e,r){e.exports=function(t,e){var r=t.length,a=t.length-e.length;if(a)return a;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return t[0]+t[1]-e[0]-e[1]||n(t[0],t[1])-n(e[0],e[1]);case 3:var o=t[0]+t[1],s=e[0]+e[1];if(a=o+t[2]-(s+e[2]))return a;var l=n(t[0],t[1]),c=n(e[0],e[1]);return n(l,t[2])-n(c,e[2])||n(l+t[2],o)-n(c+e[2],s);case 4:var u=t[0],h=t[1],f=t[2],p=t[3],d=e[0],g=e[1],v=e[2],m=e[3];return u+h+f+p-(d+g+v+m)||n(u,h,f,p)-n(d,g,v,m,d)||n(u+h,u+f,u+p,h+f,h+p,f+p)-n(d+g,d+v,d+m,g+v,g+m,v+m)||n(u+h+f,u+h+p,u+f+p,h+f+p)-n(d+g+v,d+g+m,d+v+m,g+v+m);default:for(var y=t.slice().sort(i),x=e.slice().sort(i),b=0;b<r;++b)if(a=y[b]-x[b])return a;return 0}};var n=Math.min;function i(t,e){return t-e}},{}],129:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"cell-orientation\");e.exports=function(t,e){return n(t,e)||i(t)-i(e)}},{\"cell-orientation\":112,\"compare-cell\":128}],130:[function(t,e,r){\"use strict\";var n=t(\"./lib/ch1d\"),i=t(\"./lib/ch2d\"),a=t(\"./lib/chnd\");e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[[0]];var r=t[0].length;if(0===r)return[];if(1===r)return n(t);if(2===r)return i(t);return a(t,r)}},{\"./lib/ch1d\":131,\"./lib/ch2d\":132,\"./lib/chnd\":133}],131:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0,r=0,n=1;n<t.length;++n)t[n][0]<t[e][0]&&(e=n),t[n][0]>t[r][0]&&(r=n);return e<r?[[e],[r]]:e>r?[[r],[e]]:[[e]]}},{}],132:[function(t,e,r){\"use strict\";e.exports=function(t){var e=n(t),r=e.length;if(r<=2)return[];for(var i=new Array(r),a=e[r-1],o=0;o<r;++o){var s=e[o];i[o]=[a,s],a=s}return i};var n=t(\"monotone-convex-hull-2d\")},{\"monotone-convex-hull-2d\":434}],133:[function(t,e,r){\"use strict\";e.exports=function(t,e){try{return n(t,!0)}catch(s){var r=i(t);if(r.length<=e)return[];var a=function(t,e){for(var r=t.length,n=new Array(r),i=0;i<e.length;++i)n[i]=t[e[i]];for(var a=e.length,i=0;i<r;++i)e.indexOf(i)<0&&(n[a++]=t[i]);return n}(t,r),o=n(a,!0);return function(t,e){for(var r=t.length,n=e.length,i=0;i<r;++i)for(var a=t[i],o=0;o<a.length;++o){var s=a[o];if(s<n)a[o]=e[s];else{s-=n;for(var l=0;l<n;++l)s>=e[l]&&(s+=1);a[o]=s}}return t}(o,r)}};var n=t(\"incremental-convex-hull\"),i=t(\"affine-hull\")},{\"affine-hull\":62,\"incremental-convex-hull\":413}],134:[function(t,e,r){e.exports={AFG:\"afghan\",ALA:\"\\\\b\\\\wland\",ALB:\"albania\",DZA:\"algeria\",ASM:\"^(?=.*americ).*samoa\",AND:\"andorra\",AGO:\"angola\",AIA:\"anguill?a\",ATA:\"antarctica\",ATG:\"antigua\",ARG:\"argentin\",ARM:\"armenia\",ABW:\"^(?!.*bonaire).*\\\\baruba\",AUS:\"australia\",AUT:\"^(?!.*hungary).*austria|\\\\baustri.*\\\\bemp\",AZE:\"azerbaijan\",BHS:\"bahamas\",BHR:\"bahrain\",BGD:\"bangladesh|^(?=.*east).*paki?stan\",BRB:\"barbados\",BLR:\"belarus|byelo\",BEL:\"^(?!.*luxem).*belgium\",BLZ:\"belize|^(?=.*british).*honduras\",BEN:\"benin|dahome\",BMU:\"bermuda\",BTN:\"bhutan\",BOL:\"bolivia\",BES:\"^(?=.*bonaire).*eustatius|^(?=.*carib).*netherlands|\\\\bbes.?islands\",BIH:\"herzegovina|bosnia\",BWA:\"botswana|bechuana\",BVT:\"bouvet\",BRA:\"brazil\",IOT:\"british.?indian.?ocean\",BRN:\"brunei\",BGR:\"bulgaria\",BFA:\"burkina|\\\\bfaso|upper.?volta\",BDI:\"burundi\",CPV:\"verde\",KHM:\"cambodia|kampuchea|khmer\",CMR:\"cameroon\",CAN:\"canada\",CYM:\"cayman\",CAF:\"\\\\bcentral.african.republic\",TCD:\"\\\\bchad\",CHL:\"\\\\bchile\",CHN:\"^(?!.*\\\\bmac)(?!.*\\\\bhong)(?!.*\\\\btai)(?!.*\\\\brep).*china|^(?=.*peo)(?=.*rep).*china\",CXR:\"christmas\",CCK:\"\\\\bcocos|keeling\",COL:\"colombia\",COM:\"comoro\",COG:\"^(?!.*\\\\bdem)(?!.*\\\\bd[\\\\.]?r)(?!.*kinshasa)(?!.*zaire)(?!.*belg)(?!.*l.opoldville)(?!.*free).*\\\\bcongo\",COK:\"\\\\bcook\",CRI:\"costa.?rica\",CIV:\"ivoire|ivory\",HRV:\"croatia\",CUB:\"\\\\bcuba\",CUW:\"^(?!.*bonaire).*\\\\bcura(c|\\xe7)ao\",CYP:\"cyprus\",CSK:\"czechoslovakia\",CZE:\"^(?=.*rep).*czech|czechia|bohemia\",COD:\"\\\\bdem.*congo|congo.*\\\\bdem|congo.*\\\\bd[\\\\.]?r|\\\\bd[\\\\.]?r.*congo|belgian.?congo|congo.?free.?state|kinshasa|zaire|l.opoldville|drc|droc|rdc\",DNK:\"denmark\",DJI:\"djibouti\",DMA:\"dominica(?!n)\",DOM:\"dominican.rep\",ECU:\"ecuador\",EGY:\"egypt\",SLV:\"el.?salvador\",GNQ:\"guine.*eq|eq.*guine|^(?=.*span).*guinea\",ERI:\"eritrea\",EST:\"estonia\",ETH:\"ethiopia|abyssinia\",FLK:\"falkland|malvinas\",FRO:\"faroe|faeroe\",FJI:\"fiji\",FIN:\"finland\",FRA:\"^(?!.*\\\\bdep)(?!.*martinique).*france|french.?republic|\\\\bgaul\",GUF:\"^(?=.*french).*guiana\",PYF:\"french.?polynesia|tahiti\",ATF:\"french.?southern\",GAB:\"gabon\",GMB:\"gambia\",GEO:\"^(?!.*south).*georgia\",DDR:\"german.?democratic.?republic|democratic.?republic.*germany|east.germany\",DEU:\"^(?!.*east).*germany|^(?=.*\\\\bfed.*\\\\brep).*german\",GHA:\"ghana|gold.?coast\",GIB:\"gibraltar\",GRC:\"greece|hellenic|hellas\",GRL:\"greenland\",GRD:\"grenada\",GLP:\"guadeloupe\",GUM:\"\\\\bguam\",GTM:\"guatemala\",GGY:\"guernsey\",GIN:\"^(?!.*eq)(?!.*span)(?!.*bissau)(?!.*portu)(?!.*new).*guinea\",GNB:\"bissau|^(?=.*portu).*guinea\",GUY:\"guyana|british.?guiana\",HTI:\"haiti\",HMD:\"heard.*mcdonald\",VAT:\"holy.?see|vatican|papal.?st\",HND:\"^(?!.*brit).*honduras\",HKG:\"hong.?kong\",HUN:\"^(?!.*austr).*hungary\",ISL:\"iceland\",IND:\"india(?!.*ocea)\",IDN:\"indonesia\",IRN:\"\\\\biran|persia\",IRQ:\"\\\\biraq|mesopotamia\",IRL:\"(^ireland)|(^republic.*ireland)\",IMN:\"^(?=.*isle).*\\\\bman\",ISR:\"israel\",ITA:\"italy\",JAM:\"jamaica\",JPN:\"japan\",JEY:\"jersey\",JOR:\"jordan\",KAZ:\"kazak\",KEN:\"kenya|british.?east.?africa|east.?africa.?prot\",KIR:\"kiribati\",PRK:\"^(?=.*democrat|people|north|d.*p.*.r).*\\\\bkorea|dprk|korea.*(d.*p.*r)\",KWT:\"kuwait\",KGZ:\"kyrgyz|kirghiz\",LAO:\"\\\\blaos?\\\\b\",LVA:\"latvia\",LBN:\"lebanon\",LSO:\"lesotho|basuto\",LBR:\"liberia\",LBY:\"libya\",LIE:\"liechtenstein\",LTU:\"lithuania\",LUX:\"^(?!.*belg).*luxem\",MAC:\"maca(o|u)\",MDG:\"madagascar|malagasy\",MWI:\"malawi|nyasa\",MYS:\"malaysia\",MDV:\"maldive\",MLI:\"\\\\bmali\\\\b\",MLT:\"\\\\bmalta\",MHL:\"marshall\",MTQ:\"martinique\",MRT:\"mauritania\",MUS:\"mauritius\",MYT:\"\\\\bmayotte\",MEX:\"\\\\bmexic\",FSM:\"fed.*micronesia|micronesia.*fed\",MCO:\"monaco\",MNG:\"mongolia\",MNE:\"^(?!.*serbia).*montenegro\",MSR:\"montserrat\",MAR:\"morocco|\\\\bmaroc\",MOZ:\"mozambique\",MMR:\"myanmar|burma\",NAM:\"namibia\",NRU:\"nauru\",NPL:\"nepal\",NLD:\"^(?!.*\\\\bant)(?!.*\\\\bcarib).*netherlands\",ANT:\"^(?=.*\\\\bant).*(nether|dutch)\",NCL:\"new.?caledonia\",NZL:\"new.?zealand\",NIC:\"nicaragua\",NER:\"\\\\bniger(?!ia)\",NGA:\"nigeria\",NIU:\"niue\",NFK:\"norfolk\",MNP:\"mariana\",NOR:\"norway\",OMN:\"\\\\boman|trucial\",PAK:\"^(?!.*east).*paki?stan\",PLW:\"palau\",PSE:\"palestin|\\\\bgaza|west.?bank\",PAN:\"panama\",PNG:\"papua|new.?guinea\",PRY:\"paraguay\",PER:\"peru\",PHL:\"philippines\",PCN:\"pitcairn\",POL:\"poland\",PRT:\"portugal\",PRI:\"puerto.?rico\",QAT:\"qatar\",KOR:\"^(?!.*d.*p.*r)(?!.*democrat)(?!.*people)(?!.*north).*\\\\bkorea(?!.*d.*p.*r)\",MDA:\"moldov|b(a|e)ssarabia\",REU:\"r(e|\\xe9)union\",ROU:\"r(o|u|ou)mania\",RUS:\"\\\\brussia|soviet.?union|u\\\\.?s\\\\.?s\\\\.?r|socialist.?republics\",RWA:\"rwanda\",BLM:\"barth(e|\\xe9)lemy\",SHN:\"helena\",KNA:\"kitts|\\\\bnevis\",LCA:\"\\\\blucia\",MAF:\"^(?=.*collectivity).*martin|^(?=.*france).*martin(?!ique)|^(?=.*french).*martin(?!ique)\",SPM:\"miquelon\",VCT:\"vincent\",WSM:\"^(?!.*amer).*samoa\",SMR:\"san.?marino\",STP:\"\\\\bs(a|\\xe3)o.?tom(e|\\xe9)\",SAU:\"\\\\bsa\\\\w*.?arabia\",SEN:\"senegal\",SRB:\"^(?!.*monte).*serbia\",SYC:\"seychell\",SLE:\"sierra\",SGP:\"singapore\",SXM:\"^(?!.*martin)(?!.*saba).*maarten\",SVK:\"^(?!.*cze).*slovak\",SVN:\"slovenia\",SLB:\"solomon\",SOM:\"somali\",ZAF:\"south.africa|s\\\\\\\\..?africa\",SGS:\"south.?georgia|sandwich\",SSD:\"\\\\bs\\\\w*.?sudan\",ESP:\"spain\",LKA:\"sri.?lanka|ceylon\",SDN:\"^(?!.*\\\\bs(?!u)).*sudan\",SUR:\"surinam|dutch.?guiana\",SJM:\"svalbard\",SWZ:\"swaziland\",SWE:\"sweden\",CHE:\"switz|swiss\",SYR:\"syria\",TWN:\"taiwan|taipei|formosa|^(?!.*peo)(?=.*rep).*china\",TJK:\"tajik\",THA:\"thailand|\\\\bsiam\",MKD:\"macedonia|fyrom\",TLS:\"^(?=.*leste).*timor|^(?=.*east).*timor\",TGO:\"togo\",TKL:\"tokelau\",TON:\"tonga\",TTO:\"trinidad|tobago\",TUN:\"tunisia\",TUR:\"turkey\",TKM:\"turkmen\",TCA:\"turks\",TUV:\"tuvalu\",UGA:\"uganda\",UKR:\"ukrain\",ARE:\"emirates|^u\\\\.?a\\\\.?e\\\\.?$|united.?arab.?em\",GBR:\"united.?kingdom|britain|^u\\\\.?k\\\\.?$\",TZA:\"tanzania\",USA:\"united.?states\\\\b(?!.*islands)|\\\\bu\\\\.?s\\\\.?a\\\\.?\\\\b|^\\\\s*u\\\\.?s\\\\.?\\\\b(?!.*islands)\",UMI:\"minor.?outlying.?is\",URY:\"uruguay\",UZB:\"uzbek\",VUT:\"vanuatu|new.?hebrides\",VEN:\"venezuela\",VNM:\"^(?!.*republic).*viet.?nam|^(?=.*socialist).*viet.?nam\",VGB:\"^(?=.*\\\\bu\\\\.?\\\\s?k).*virgin|^(?=.*brit).*virgin|^(?=.*kingdom).*virgin\",VIR:\"^(?=.*\\\\bu\\\\.?\\\\s?s).*virgin|^(?=.*states).*virgin\",WLF:\"futuna|wallis\",ESH:\"western.sahara\",YEM:\"^(?!.*arab)(?!.*north)(?!.*sana)(?!.*peo)(?!.*dem)(?!.*south)(?!.*aden)(?!.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YMD:\"^(?=.*peo).*yemen|^(?!.*rep)(?=.*dem).*yemen|^(?=.*south).*yemen|^(?=.*aden).*yemen|^(?=.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YUG:\"yugoslavia\",ZMB:\"zambia|northern.?rhodesia\",EAZ:\"zanzibar\",ZWE:\"zimbabwe|^(?!.*northern).*rhodesia\"}},{}],135:[function(t,e,r){e.exports=[\"xx-small\",\"x-small\",\"small\",\"medium\",\"large\",\"x-large\",\"xx-large\",\"larger\",\"smaller\"]},{}],136:[function(t,e,r){e.exports=[\"normal\",\"condensed\",\"semi-condensed\",\"extra-condensed\",\"ultra-condensed\",\"expanded\",\"semi-expanded\",\"extra-expanded\",\"ultra-expanded\"]},{}],137:[function(t,e,r){e.exports=[\"normal\",\"italic\",\"oblique\"]},{}],138:[function(t,e,r){e.exports=[\"normal\",\"bold\",\"bolder\",\"lighter\",\"100\",\"200\",\"300\",\"400\",\"500\",\"600\",\"700\",\"800\",\"900\"]},{}],139:[function(t,e,r){\"use strict\";e.exports={parse:t(\"./parse\"),stringify:t(\"./stringify\")}},{\"./parse\":141,\"./stringify\":142}],140:[function(t,e,r){\"use strict\";var n=t(\"css-font-size-keywords\");e.exports={isSize:function(t){return/^[\\d\\.]/.test(t)||-1!==t.indexOf(\"/\")||-1!==n.indexOf(t)}}},{\"css-font-size-keywords\":135}],141:[function(t,e,r){\"use strict\";var n=t(\"unquote\"),i=t(\"css-global-keywords\"),a=t(\"css-system-font-keywords\"),o=t(\"css-font-weight-keywords\"),s=t(\"css-font-style-keywords\"),l=t(\"css-font-stretch-keywords\"),c=t(\"string-split-by\"),u=t(\"./lib/util\").isSize;e.exports=f;var h=f.cache={};function f(t){if(\"string\"!=typeof t)throw new Error(\"Font argument must be a string.\");if(h[t])return h[t];if(\"\"===t)throw new Error(\"Cannot parse an empty string.\");if(-1!==a.indexOf(t))return h[t]={system:t};for(var e,r={style:\"normal\",variant:\"normal\",weight:\"normal\",stretch:\"normal\",lineHeight:\"normal\",size:\"1rem\",family:[\"serif\"]},f=c(t,/\\s+/);e=f.shift();){if(-1!==i.indexOf(e))return[\"style\",\"variant\",\"weight\",\"stretch\"].forEach(function(t){r[t]=e}),h[t]=r;if(-1===s.indexOf(e))if(\"normal\"!==e&&\"small-caps\"!==e)if(-1===l.indexOf(e)){if(-1===o.indexOf(e)){if(u(e)){var d=c(e,\"/\");if(r.size=d[0],null!=d[1]?r.lineHeight=p(d[1]):\"/\"===f[0]&&(f.shift(),r.lineHeight=p(f.shift())),!f.length)throw new Error(\"Missing required font-family.\");return r.family=c(f.join(\" \"),/\\s*,\\s*/).map(n),h[t]=r}throw new Error(\"Unknown or unsupported font token: \"+e)}r.weight=e}else r.stretch=e;else r.variant=e;else r.style=e}throw new Error(\"Missing required font-size.\")}function p(t){var e=parseFloat(t);return e.toString()===t?e:t}},{\"./lib/util\":140,\"css-font-stretch-keywords\":136,\"css-font-style-keywords\":137,\"css-font-weight-keywords\":138,\"css-global-keywords\":143,\"css-system-font-keywords\":144,\"string-split-by\":529,unquote:548}],142:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\"),i=t(\"./lib/util\").isSize,a=g(t(\"css-global-keywords\")),o=g(t(\"css-system-font-keywords\")),s=g(t(\"css-font-weight-keywords\")),l=g(t(\"css-font-style-keywords\")),c=g(t(\"css-font-stretch-keywords\")),u={normal:1,\"small-caps\":1},h={serif:1,\"sans-serif\":1,monospace:1,cursive:1,fantasy:1,\"system-ui\":1},f=\"1rem\",p=\"serif\";function d(t,e){if(t&&!e[t]&&!a[t])throw Error(\"Unknown keyword `\"+t+\"`\");return t}function g(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=1;return e}e.exports=function(t){if((t=n(t,{style:\"style fontstyle fontStyle font-style slope distinction\",variant:\"variant font-variant fontVariant fontvariant var capitalization\",weight:\"weight w font-weight fontWeight fontweight\",stretch:\"stretch font-stretch fontStretch fontstretch width\",size:\"size s font-size fontSize fontsize height em emSize\",lineHeight:\"lh line-height lineHeight lineheight leading\",family:\"font family fontFamily font-family fontfamily type typeface face\",system:\"system reserved default global\"})).system)return t.system&&d(t.system,o),t.system;if(d(t.style,l),d(t.variant,u),d(t.weight,s),d(t.stretch,c),null==t.size&&(t.size=f),\"number\"==typeof t.size&&(t.size+=\"px\"),!i)throw Error(\"Bad size value `\"+t.size+\"`\");t.family||(t.family=p),Array.isArray(t.family)&&(t.family.length||(t.family=[p]),t.family=t.family.map(function(t){return h[t]?t:'\"'+t+'\"'}).join(\", \"));var e=[];return e.push(t.style),t.variant!==t.style&&e.push(t.variant),t.weight!==t.variant&&t.weight!==t.style&&e.push(t.weight),t.stretch!==t.weight&&t.stretch!==t.variant&&t.stretch!==t.style&&e.push(t.stretch),e.push(t.size+(null==t.lineHeight||\"normal\"===t.lineHeight||t.lineHeight+\"\"==\"1\"?\"\":\"/\"+t.lineHeight)),e.push(t.family),e.filter(Boolean).join(\" \")}},{\"./lib/util\":140,\"css-font-stretch-keywords\":136,\"css-font-style-keywords\":137,\"css-font-weight-keywords\":138,\"css-global-keywords\":143,\"css-system-font-keywords\":144,\"pick-by-alias\":465}],143:[function(t,e,r){e.exports=[\"inherit\",\"initial\",\"unset\"]},{}],144:[function(t,e,r){e.exports=[\"caption\",\"icon\",\"menu\",\"message-box\",\"small-caption\",\"status-bar\"]},{}],145:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i-1,s=i*i,l=o*o,c=(1+2*i)*l,u=i*l,h=s*(3-2*i),f=s*o;if(t.length){a||(a=new Array(t.length));for(var p=t.length-1;p>=0;--p)a[p]=c*t[p]+u*e[p]+h*r[p]+f*n[p];return a}return c*t+u*e+h*r+f*n},e.exports.derivative=function(t,e,r,n,i,a){var o=6*i*i-6*i,s=3*i*i-4*i+1,l=-6*i*i+6*i,c=3*i*i-2*i;if(t.length){a||(a=new Array(t.length));for(var u=t.length-1;u>=0;--u)a[u]=o*t[u]+s*e[u]+l*r[u]+c*n[u];return a}return o*t+s*e+l*r[u]+c*n}},{}],146:[function(t,e,r){\"use strict\";var n=t(\"./lib/thunk.js\");function i(){this.argTypes=[],this.shimArgs=[],this.arrayArgs=[],this.arrayBlockIndices=[],this.scalarArgs=[],this.offsetArgs=[],this.offsetArgIndex=[],this.indexArgs=[],this.shapeArgs=[],this.funcName=\"\",this.pre=null,this.body=null,this.post=null,this.debug=!1}e.exports=function(t){var e=new i;e.pre=t.pre,e.body=t.body,e.post=t.post;var r=t.args.slice(0);e.argTypes=r;for(var a=0;a<r.length;++a){var o=r[a];if(\"array\"===o||\"object\"==typeof o&&o.blockIndices){if(e.argTypes[a]=\"array\",e.arrayArgs.push(a),e.arrayBlockIndices.push(o.blockIndices?o.blockIndices:0),e.shimArgs.push(\"array\"+a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array args\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array args\")}else if(\"scalar\"===o)e.scalarArgs.push(a),e.shimArgs.push(\"scalar\"+a);else if(\"index\"===o){if(e.indexArgs.push(a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array index\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array index\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array index\")}else if(\"shape\"===o){if(e.shapeArgs.push(a),a<e.pre.args.length&&e.pre.args[a].lvalue)throw new Error(\"cwise: pre() block may not write to array shape\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array shape\");if(a<e.post.args.length&&e.post.args[a].lvalue)throw new Error(\"cwise: post() block may not write to array shape\")}else{if(\"object\"!=typeof o||!o.offset)throw new Error(\"cwise: Unknown argument type \"+r[a]);e.argTypes[a]=\"offset\",e.offsetArgs.push({array:o.array,offset:o.offset}),e.offsetArgIndex.push(a)}}if(e.arrayArgs.length<=0)throw new Error(\"cwise: No array arguments specified\");if(e.pre.args.length>r.length)throw new Error(\"cwise: Too many arguments in pre() block\");if(e.body.args.length>r.length)throw new Error(\"cwise: Too many arguments in body() block\");if(e.post.args.length>r.length)throw new Error(\"cwise: Too many arguments in post() block\");return e.debug=!!t.printCode||!!t.debug,e.funcName=t.funcName||\"cwise\",e.blockSize=t.blockSize||64,n(e)}},{\"./lib/thunk.js\":148}],147:[function(t,e,r){\"use strict\";var n=t(\"uniq\");function i(t,e,r){var n,i,a=t.length,o=e.arrayArgs.length,s=e.indexArgs.length>0,l=[],c=[],u=0,h=0;for(n=0;n<a;++n)c.push([\"i\",n,\"=0\"].join(\"\"));for(i=0;i<o;++i)for(n=0;n<a;++n)h=u,u=t[n],0===n?c.push([\"d\",i,\"s\",n,\"=t\",i,\"p\",u].join(\"\")):c.push([\"d\",i,\"s\",n,\"=(t\",i,\"p\",u,\"-s\",h,\"*t\",i,\"p\",h,\")\"].join(\"\"));for(c.length>0&&l.push(\"var \"+c.join(\",\")),n=a-1;n>=0;--n)u=t[n],l.push([\"for(i\",n,\"=0;i\",n,\"<s\",u,\";++i\",n,\"){\"].join(\"\"));for(l.push(r),n=0;n<a;++n){for(h=u,u=t[n],i=0;i<o;++i)l.push([\"p\",i,\"+=d\",i,\"s\",n].join(\"\"));s&&(n>0&&l.push([\"index[\",h,\"]-=s\",h].join(\"\")),l.push([\"++index[\",u,\"]\"].join(\"\"))),l.push(\"}\")}return l.join(\"\\n\")}function a(t,e,r){for(var n=t.body,i=[],a=[],o=0;o<t.args.length;++o){var s=t.args[o];if(!(s.count<=0)){var l=new RegExp(s.name,\"g\"),c=\"\",u=e.arrayArgs.indexOf(o);switch(e.argTypes[o]){case\"offset\":var h=e.offsetArgIndex.indexOf(o);u=e.offsetArgs[h].array,c=\"+q\"+h;case\"array\":c=\"p\"+u+c;var f=\"l\"+o,p=\"a\"+u;if(0===e.arrayBlockIndices[u])1===s.count?\"generic\"===r[u]?s.lvalue?(i.push([\"var \",f,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,f),a.push([p,\".set(\",c,\",\",f,\")\"].join(\"\"))):n=n.replace(l,[p,\".get(\",c,\")\"].join(\"\")):n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\")):\"generic\"===r[u]?(i.push([\"var \",f,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,f),s.lvalue&&a.push([p,\".set(\",c,\",\",f,\")\"].join(\"\"))):(i.push([\"var \",f,\"=\",p,\"[\",c,\"]\"].join(\"\")),n=n.replace(l,f),s.lvalue&&a.push([p,\"[\",c,\"]=\",f].join(\"\")));else{for(var d=[s.name],g=[c],v=0;v<Math.abs(e.arrayBlockIndices[u]);v++)d.push(\"\\\\s*\\\\[([^\\\\]]+)\\\\]\"),g.push(\"$\"+(v+1)+\"*t\"+u+\"b\"+v);if(l=new RegExp(d.join(\"\"),\"g\"),c=g.join(\"+\"),\"generic\"===r[u])throw new Error(\"cwise: Generic arrays not supported in combination with blocks!\");n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\"))}break;case\"scalar\":n=n.replace(l,\"Y\"+e.scalarArgs.indexOf(o));break;case\"index\":n=n.replace(l,\"index\");break;case\"shape\":n=n.replace(l,\"shape\")}}}return[i.join(\"\\n\"),n,a.join(\"\\n\")].join(\"\\n\").trim()}e.exports=function(t,e){for(var r=e[1].length-Math.abs(t.arrayBlockIndices[0])|0,o=new Array(t.arrayArgs.length),s=new Array(t.arrayArgs.length),l=0;l<t.arrayArgs.length;++l)s[l]=e[2*l],o[l]=e[2*l+1];var c=[],u=[],h=[],f=[],p=[];for(l=0;l<t.arrayArgs.length;++l){t.arrayBlockIndices[l]<0?(h.push(0),f.push(r),c.push(r),u.push(r+t.arrayBlockIndices[l])):(h.push(t.arrayBlockIndices[l]),f.push(t.arrayBlockIndices[l]+r),c.push(0),u.push(t.arrayBlockIndices[l]));for(var d=[],g=0;g<o[l].length;g++)h[l]<=o[l][g]&&o[l][g]<f[l]&&d.push(o[l][g]-h[l]);p.push(d)}var v=[\"SS\"],m=[\"'use strict'\"],y=[];for(g=0;g<r;++g)y.push([\"s\",g,\"=SS[\",g,\"]\"].join(\"\"));for(l=0;l<t.arrayArgs.length;++l){for(v.push(\"a\"+l),v.push(\"t\"+l),v.push(\"p\"+l),g=0;g<r;++g)y.push([\"t\",l,\"p\",g,\"=t\",l,\"[\",h[l]+g,\"]\"].join(\"\"));for(g=0;g<Math.abs(t.arrayBlockIndices[l]);++g)y.push([\"t\",l,\"b\",g,\"=t\",l,\"[\",c[l]+g,\"]\"].join(\"\"))}for(l=0;l<t.scalarArgs.length;++l)v.push(\"Y\"+l);if(t.shapeArgs.length>0&&y.push(\"shape=SS.slice(0)\"),t.indexArgs.length>0){var x=new Array(r);for(l=0;l<r;++l)x[l]=\"0\";y.push([\"index=[\",x.join(\",\"),\"]\"].join(\"\"))}for(l=0;l<t.offsetArgs.length;++l){var b=t.offsetArgs[l],_=[];for(g=0;g<b.offset.length;++g)0!==b.offset[g]&&(1===b.offset[g]?_.push([\"t\",b.array,\"p\",g].join(\"\")):_.push([b.offset[g],\"*t\",b.array,\"p\",g].join(\"\")));0===_.length?y.push(\"q\"+l+\"=0\"):y.push([\"q\",l,\"=\",_.join(\"+\")].join(\"\"))}var w=n([].concat(t.pre.thisVars).concat(t.body.thisVars).concat(t.post.thisVars));for((y=y.concat(w)).length>0&&m.push(\"var \"+y.join(\",\")),l=0;l<t.arrayArgs.length;++l)m.push(\"p\"+l+\"|=0\");t.pre.body.length>3&&m.push(a(t.pre,t,s));var k=a(t.body,t,s),T=function(t){for(var e=0,r=t[0].length;e<r;){for(var n=1;n<t.length;++n)if(t[n][e]!==t[0][e])return e;++e}return e}(p);T<r?m.push(function(t,e,r,n){for(var a=e.length,o=r.arrayArgs.length,s=r.blockSize,l=r.indexArgs.length>0,c=[],u=0;u<o;++u)c.push([\"var offset\",u,\"=p\",u].join(\"\"));for(u=t;u<a;++u)c.push([\"for(var j\"+u+\"=SS[\",e[u],\"]|0;j\",u,\">0;){\"].join(\"\")),c.push([\"if(j\",u,\"<\",s,\"){\"].join(\"\")),c.push([\"s\",e[u],\"=j\",u].join(\"\")),c.push([\"j\",u,\"=0\"].join(\"\")),c.push([\"}else{s\",e[u],\"=\",s].join(\"\")),c.push([\"j\",u,\"-=\",s,\"}\"].join(\"\")),l&&c.push([\"index[\",e[u],\"]=j\",u].join(\"\"));for(u=0;u<o;++u){for(var h=[\"offset\"+u],f=t;f<a;++f)h.push([\"j\",f,\"*t\",u,\"p\",e[f]].join(\"\"));c.push([\"p\",u,\"=(\",h.join(\"+\"),\")\"].join(\"\"))}for(c.push(i(e,r,n)),u=t;u<a;++u)c.push(\"}\");return c.join(\"\\n\")}(T,p[0],t,k)):m.push(i(p[0],t,k)),t.post.body.length>3&&m.push(a(t.post,t,s)),t.debug&&console.log(\"-----Generated cwise routine for \",e,\":\\n\"+m.join(\"\\n\")+\"\\n----------\");var A=[t.funcName||\"unnamed\",\"_cwise_loop_\",o[0].join(\"s\"),\"m\",T,function(t){for(var e=new Array(t.length),r=!0,n=0;n<t.length;++n){var i=t[n],a=i.match(/\\d+/);a=a?a[0]:\"\",0===i.charAt(0)?e[n]=\"u\"+i.charAt(1)+a:e[n]=i.charAt(0)+a,n>0&&(r=r&&e[n]===e[n-1])}return r?e[0]:e.join(\"\")}(s)].join(\"\");return new Function([\"function \",A,\"(\",v.join(\",\"),\"){\",m.join(\"\\n\"),\"} return \",A].join(\"\"))()}},{uniq:547}],148:[function(t,e,r){\"use strict\";var n=t(\"./compile.js\");e.exports=function(t){var e=[\"'use strict'\",\"var CACHED={}\"],r=[],i=t.funcName+\"_cwise_thunk\";e.push([\"return function \",i,\"(\",t.shimArgs.join(\",\"),\"){\"].join(\"\"));for(var a=[],o=[],s=[[\"array\",t.arrayArgs[0],\".shape.slice(\",Math.max(0,t.arrayBlockIndices[0]),t.arrayBlockIndices[0]<0?\",\"+t.arrayBlockIndices[0]+\")\":\")\"].join(\"\")],l=[],c=[],u=0;u<t.arrayArgs.length;++u){var h=t.arrayArgs[u];r.push([\"t\",h,\"=array\",h,\".dtype,\",\"r\",h,\"=array\",h,\".order\"].join(\"\")),a.push(\"t\"+h),a.push(\"r\"+h),o.push(\"t\"+h),o.push(\"r\"+h+\".join()\"),s.push(\"array\"+h+\".data\"),s.push(\"array\"+h+\".stride\"),s.push(\"array\"+h+\".offset|0\"),u>0&&(l.push(\"array\"+t.arrayArgs[0]+\".shape.length===array\"+h+\".shape.length+\"+(Math.abs(t.arrayBlockIndices[0])-Math.abs(t.arrayBlockIndices[u]))),c.push(\"array\"+t.arrayArgs[0]+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[0])+\"]===array\"+h+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[u])+\"]\"))}for(t.arrayArgs.length>1&&(e.push(\"if (!(\"+l.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same dimensionality!')\"),e.push(\"for(var shapeIndex=array\"+t.arrayArgs[0]+\".shape.length-\"+Math.abs(t.arrayBlockIndices[0])+\"; shapeIndex--\\x3e0;) {\"),e.push(\"if (!(\"+c.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same shape!')\"),e.push(\"}\")),u=0;u<t.scalarArgs.length;++u)s.push(\"scalar\"+t.scalarArgs[u]);return r.push([\"type=[\",o.join(\",\"),\"].join()\"].join(\"\")),r.push(\"proc=CACHED[type]\"),e.push(\"var \"+r.join(\",\")),e.push([\"if(!proc){\",\"CACHED[type]=proc=compile([\",a.join(\",\"),\"])}\",\"return proc(\",s.join(\",\"),\")}\"].join(\"\")),t.debug&&console.log(\"-----Generated thunk:\\n\"+e.join(\"\\n\")+\"\\n----------\"),new Function(\"compile\",e.join(\"\\n\"))(n.bind(void 0,t))}},{\"./compile.js\":147}],149:[function(t,e,r){e.exports=t(\"cwise-compiler\")},{\"cwise-compiler\":146}],150:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/copy\"),a=t(\"es5-ext/object/normalize-options\"),o=t(\"es5-ext/object/valid-callable\"),s=t(\"es5-ext/object/map\"),l=t(\"es5-ext/object/valid-callable\"),c=t(\"es5-ext/object/valid-value\"),u=Function.prototype.bind,h=Object.defineProperty,f=Object.prototype.hasOwnProperty;n=function(t,e,r){var n,a=c(e)&&l(e.value);return delete(n=i(e)).writable,delete n.value,n.get=function(){return!r.overwriteDefinition&&f.call(this,t)?a:(e.value=u.call(a,r.resolveContext?r.resolveContext(this):this),h(this,t,e),this[t])},n},e.exports=function(t){var e=a(arguments[1]);return null!=e.resolveContext&&o(e.resolveContext),s(t,function(t,r){return n(r,t,e)})}},{\"es5-ext/object/copy\":189,\"es5-ext/object/map\":198,\"es5-ext/object/normalize-options\":199,\"es5-ext/object/valid-callable\":203,\"es5-ext/object/valid-value\":205}],151:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/object/assign\"),i=t(\"es5-ext/object/normalize-options\"),a=t(\"es5-ext/object/is-callable\"),o=t(\"es5-ext/string/#/contains\");(e.exports=function(t,e){var r,a,s,l,c;return arguments.length<2||\"string\"!=typeof t?(l=e,e=t,t=null):l=arguments[2],null==t?(r=s=!0,a=!1):(r=o.call(t,\"c\"),a=o.call(t,\"e\"),s=o.call(t,\"w\")),c={value:e,configurable:r,enumerable:a,writable:s},l?n(i(l),c):c}).gs=function(t,e,r){var s,l,c,u;return\"string\"!=typeof t?(c=r,r=e,e=t,t=null):c=arguments[3],null==e?e=void 0:a(e)?null==r?r=void 0:a(r)||(c=r,r=void 0):(c=e,e=r=void 0),null==t?(s=!0,l=!1):(s=o.call(t,\"c\"),l=o.call(t,\"e\")),u={get:e,set:r,configurable:s,enumerable:l},c?n(i(c),u):u}},{\"es5-ext/object/assign\":186,\"es5-ext/object/is-callable\":192,\"es5-ext/object/normalize-options\":199,\"es5-ext/string/#/contains\":206}],152:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function r(t){var r;return 1===t.length&&(r=t,t=function(t,n){return e(r(t),n)}),{left:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}var n=r(e),i=n.right,a=n.left;function o(t,e){return[t,e]}function s(t){return null===t?NaN:+t}function l(t,e){var r,n,i=t.length,a=0,o=-1,l=0,c=0;if(null==e)for(;++o<i;)isNaN(r=s(t[o]))||(c+=(n=r-l)*(r-(l+=n/++a)));else for(;++o<i;)isNaN(r=s(e(t[o],o,t)))||(c+=(n=r-l)*(r-(l+=n/++a)));if(a>1)return c/(a-1)}function c(t,e){var r=l(t,e);return r?Math.sqrt(r):r}function u(t,e){var r,n,i,a=t.length,o=-1;if(null==e){for(;++o<a;)if(null!=(r=t[o])&&r>=r)for(n=i=r;++o<a;)null!=(r=t[o])&&(n>r&&(n=r),i<r&&(i=r))}else for(;++o<a;)if(null!=(r=e(t[o],o,t))&&r>=r)for(n=i=r;++o<a;)null!=(r=e(t[o],o,t))&&(n>r&&(n=r),i<r&&(i=r));return[n,i]}var h=Array.prototype,f=h.slice,p=h.map;function d(t){return function(){return t}}function g(t){return t}function v(t,e,r){t=+t,e=+e,r=(i=arguments.length)<2?(e=t,t=0,1):i<3?1:+r;for(var n=-1,i=0|Math.max(0,Math.ceil((e-t)/r)),a=new Array(i);++n<i;)a[n]=t+n*r;return a}var m=Math.sqrt(50),y=Math.sqrt(10),x=Math.sqrt(2);function b(t,e,r){var n=(e-t)/Math.max(0,r),i=Math.floor(Math.log(n)/Math.LN10),a=n/Math.pow(10,i);return i>=0?(a>=m?10:a>=y?5:a>=x?2:1)*Math.pow(10,i):-Math.pow(10,-i)/(a>=m?10:a>=y?5:a>=x?2:1)}function _(t,e,r){var n=Math.abs(e-t)/Math.max(0,r),i=Math.pow(10,Math.floor(Math.log(n)/Math.LN10)),a=n/i;return a>=m?i*=10:a>=y?i*=5:a>=x&&(i*=2),e<t?-i:i}function w(t){return Math.ceil(Math.log(t.length)/Math.LN2)+1}function k(t,e,r){if(null==r&&(r=s),n=t.length){if((e=+e)<=0||n<2)return+r(t[0],0,t);if(e>=1)return+r(t[n-1],n-1,t);var n,i=(n-1)*e,a=Math.floor(i),o=+r(t[a],a,t);return o+(+r(t[a+1],a+1,t)-o)*(i-a)}}function T(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&n>r&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&n>r&&(n=r);return n}function A(t){if(!(i=t.length))return[];for(var e=-1,r=T(t,M),n=new Array(r);++e<r;)for(var i,a=-1,o=n[e]=new Array(i);++a<i;)o[a]=t[a][e];return n}function M(t){return t.length}t.bisect=i,t.bisectRight=i,t.bisectLeft=a,t.ascending=e,t.bisector=r,t.cross=function(t,e,r){var n,i,a,s,l=t.length,c=e.length,u=new Array(l*c);for(null==r&&(r=o),n=a=0;n<l;++n)for(s=t[n],i=0;i<c;++i,++a)u[a]=r(s,e[i]);return u},t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.deviation=c,t.extent=u,t.histogram=function(){var t=g,e=u,r=w;function n(n){var a,o,s=n.length,l=new Array(s);for(a=0;a<s;++a)l[a]=t(n[a],a,n);var c=e(l),u=c[0],h=c[1],f=r(l,u,h);Array.isArray(f)||(f=_(u,h,f),f=v(Math.ceil(u/f)*f,h,f));for(var p=f.length;f[0]<=u;)f.shift(),--p;for(;f[p-1]>h;)f.pop(),--p;var d,g=new Array(p+1);for(a=0;a<=p;++a)(d=g[a]=[]).x0=a>0?f[a-1]:u,d.x1=a<p?f[a]:h;for(a=0;a<s;++a)u<=(o=l[a])&&o<=h&&g[i(f,o,0,p)].push(n[a]);return g}return n.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:d(e),n):t},n.domain=function(t){return arguments.length?(e=\"function\"==typeof t?t:d([t[0],t[1]]),n):e},n.thresholds=function(t){return arguments.length?(r=\"function\"==typeof t?t:Array.isArray(t)?d(f.call(t)):d(t),n):r},n},t.thresholdFreedmanDiaconis=function(t,r,n){return t=p.call(t,s).sort(e),Math.ceil((n-r)/(2*(k(t,.75)-k(t,.25))*Math.pow(t.length,-1/3)))},t.thresholdScott=function(t,e,r){return Math.ceil((r-e)/(3.5*c(t)*Math.pow(t.length,-1/3)))},t.thresholdSturges=w,t.max=function(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&r>n&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&r>n&&(n=r);return n},t.mean=function(t,e){var r,n=t.length,i=n,a=-1,o=0;if(null==e)for(;++a<n;)isNaN(r=s(t[a]))?--i:o+=r;else for(;++a<n;)isNaN(r=s(e(t[a],a,t)))?--i:o+=r;if(i)return o/i},t.median=function(t,r){var n,i=t.length,a=-1,o=[];if(null==r)for(;++a<i;)isNaN(n=s(t[a]))||o.push(n);else for(;++a<i;)isNaN(n=s(r(t[a],a,t)))||o.push(n);return k(o.sort(e),.5)},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r},t.min=T,t.pairs=function(t,e){null==e&&(e=o);for(var r=0,n=t.length-1,i=t[0],a=new Array(n<0?0:n);r<n;)a[r]=e(i,i=t[++r]);return a},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.quantile=k,t.range=v,t.scan=function(t,r){if(n=t.length){var n,i,a=0,o=0,s=t[o];for(null==r&&(r=e);++a<n;)(r(i=t[a],s)<0||0!==r(s,s))&&(s=i,o=a);return 0===r(s,s)?o:void 0}},t.shuffle=function(t,e,r){for(var n,i,a=(null==r?t.length:r)-(e=null==e?0:+e);a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.sum=function(t,e){var r,n=t.length,i=-1,a=0;if(null==e)for(;++i<n;)(r=+t[i])&&(a+=r);else for(;++i<n;)(r=+e(t[i],i,t))&&(a+=r);return a},t.ticks=function(t,e,r){var n,i,a,o,s=-1;if(r=+r,(t=+t)==(e=+e)&&r>0)return[t];if((n=e<t)&&(i=t,t=e,e=i),0===(o=b(t,e,r))||!isFinite(o))return[];if(o>0)for(t=Math.ceil(t/o),e=Math.floor(e/o),a=new Array(i=Math.ceil(e-t+1));++s<i;)a[s]=(t+s)*o;else for(t=Math.floor(t*o),e=Math.ceil(e*o),a=new Array(i=Math.ceil(t-e+1));++s<i;)a[s]=(t-s)/o;return n&&a.reverse(),a},t.tickIncrement=b,t.tickStep=_,t.transpose=A,t.variance=l,t.zip=function(){return A(arguments)},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],153:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(){}function r(t,r){var n=new e;if(t instanceof e)t.each(function(t,e){n.set(e,t)});else if(Array.isArray(t)){var i,a=-1,o=t.length;if(null==r)for(;++a<o;)n.set(a,t[a]);else for(;++a<o;)n.set(r(i=t[a],a,t),i)}else if(t)for(var s in t)n.set(s,t[s]);return n}e.prototype=r.prototype={constructor:e,has:function(t){return\"$\"+t in this},get:function(t){return this[\"$\"+t]},set:function(t,e){return this[\"$\"+t]=e,this},remove:function(t){var e=\"$\"+t;return e in this&&delete this[e]},clear:function(){for(var t in this)\"$\"===t[0]&&delete this[t]},keys:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(e.slice(1));return t},values:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(this[e]);return t},entries:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push({key:e.slice(1),value:this[e]});return t},size:function(){var t=0;for(var e in this)\"$\"===e[0]&&++t;return t},empty:function(){for(var t in this)if(\"$\"===t[0])return!1;return!0},each:function(t){for(var e in this)\"$\"===e[0]&&t(this[e],e.slice(1),this)}};function n(){return{}}function i(t,e,r){t[e]=r}function a(){return r()}function o(t,e,r){t.set(e,r)}function s(){}var l=r.prototype;function c(t,e){var r=new s;if(t instanceof s)t.each(function(t){r.add(t)});else if(t){var n=-1,i=t.length;if(null==e)for(;++n<i;)r.add(t[n]);else for(;++n<i;)r.add(e(t[n],n,t))}return r}s.prototype=c.prototype={constructor:s,has:l.has,add:function(t){return this[\"$\"+(t+=\"\")]=t,this},remove:l.remove,clear:l.clear,values:l.keys,size:l.size,empty:l.empty,each:l.each};t.nest=function(){var t,e,s,l=[],c=[];function u(n,i,a,o){if(i>=l.length)return null!=t&&n.sort(t),null!=e?e(n):n;for(var s,c,h,f=-1,p=n.length,d=l[i++],g=r(),v=a();++f<p;)(h=g.get(s=d(c=n[f])+\"\"))?h.push(c):g.set(s,[c]);return g.each(function(t,e){o(v,e,u(t,i,a,o))}),v}return s={object:function(t){return u(t,0,n,i)},map:function(t){return u(t,0,a,o)},entries:function(t){return function t(r,n){if(++n>l.length)return r;var i,a=c[n-1];return null!=e&&n>=l.length?i=r.entries():(i=[],r.each(function(e,r){i.push({key:r,values:t(e,n)})})),null!=a?i.sort(function(t,e){return a(t.key,e.key)}):i}(u(t,0,a,o),0)},key:function(t){return l.push(t),s},sortKeys:function(t){return c[l.length-1]=t,s},sortValues:function(e){return t=e,s},rollup:function(t){return e=t,s}}},t.set=c,t.map=r,t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],154:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e,r){t.prototype=e.prototype=r,r.constructor=t}function r(t,e){var r=Object.create(t.prototype);for(var n in e)r[n]=e[n];return r}function n(){}var i=\"\\\\s*([+-]?\\\\d+)\\\\s*\",a=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)\\\\s*\",o=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)%\\\\s*\",s=/^#([0-9a-f]{3})$/,l=/^#([0-9a-f]{6})$/,c=new RegExp(\"^rgb\\\\(\"+[i,i,i]+\"\\\\)$\"),u=new RegExp(\"^rgb\\\\(\"+[o,o,o]+\"\\\\)$\"),h=new RegExp(\"^rgba\\\\(\"+[i,i,i,a]+\"\\\\)$\"),f=new RegExp(\"^rgba\\\\(\"+[o,o,o,a]+\"\\\\)$\"),p=new RegExp(\"^hsl\\\\(\"+[a,o,o]+\"\\\\)$\"),d=new RegExp(\"^hsla\\\\(\"+[a,o,o,a]+\"\\\\)$\"),g={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};function v(t){var e;return t=(t+\"\").trim().toLowerCase(),(e=s.exec(t))?new _((e=parseInt(e[1],16))>>8&15|e>>4&240,e>>4&15|240&e,(15&e)<<4|15&e,1):(e=l.exec(t))?m(parseInt(e[1],16)):(e=c.exec(t))?new _(e[1],e[2],e[3],1):(e=u.exec(t))?new _(255*e[1]/100,255*e[2]/100,255*e[3]/100,1):(e=h.exec(t))?y(e[1],e[2],e[3],e[4]):(e=f.exec(t))?y(255*e[1]/100,255*e[2]/100,255*e[3]/100,e[4]):(e=p.exec(t))?k(e[1],e[2]/100,e[3]/100,1):(e=d.exec(t))?k(e[1],e[2]/100,e[3]/100,e[4]):g.hasOwnProperty(t)?m(g[t]):\"transparent\"===t?new _(NaN,NaN,NaN,0):null}function m(t){return new _(t>>16&255,t>>8&255,255&t,1)}function y(t,e,r,n){return n<=0&&(t=e=r=NaN),new _(t,e,r,n)}function x(t){return t instanceof n||(t=v(t)),t?new _((t=t.rgb()).r,t.g,t.b,t.opacity):new _}function b(t,e,r,n){return 1===arguments.length?x(t):new _(t,e,r,null==n?1:n)}function _(t,e,r,n){this.r=+t,this.g=+e,this.b=+r,this.opacity=+n}function w(t){return((t=Math.max(0,Math.min(255,Math.round(t)||0)))<16?\"0\":\"\")+t.toString(16)}function k(t,e,r,n){return n<=0?t=e=r=NaN:r<=0||r>=1?t=e=NaN:e<=0&&(t=NaN),new A(t,e,r,n)}function T(t,e,r,i){return 1===arguments.length?function(t){if(t instanceof A)return new A(t.h,t.s,t.l,t.opacity);if(t instanceof n||(t=v(t)),!t)return new A;if(t instanceof A)return t;var e=(t=t.rgb()).r/255,r=t.g/255,i=t.b/255,a=Math.min(e,r,i),o=Math.max(e,r,i),s=NaN,l=o-a,c=(o+a)/2;return l?(s=e===o?(r-i)/l+6*(r<i):r===o?(i-e)/l+2:(e-r)/l+4,l/=c<.5?o+a:2-o-a,s*=60):l=c>0&&c<1?0:s,new A(s,l,c,t.opacity)}(t):new A(t,e,r,null==i?1:i)}function A(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}function M(t,e,r){return 255*(t<60?e+(r-e)*t/60:t<180?r:t<240?e+(r-e)*(240-t)/60:e)}e(n,v,{displayable:function(){return this.rgb().displayable()},hex:function(){return this.rgb().hex()},toString:function(){return this.rgb()+\"\"}}),e(_,b,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new _(this.r*t,this.g*t,this.b*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new _(this.r*t,this.g*t,this.b*t,this.opacity)},rgb:function(){return this},displayable:function(){return 0<=this.r&&this.r<=255&&0<=this.g&&this.g<=255&&0<=this.b&&this.b<=255&&0<=this.opacity&&this.opacity<=1},hex:function(){return\"#\"+w(this.r)+w(this.g)+w(this.b)},toString:function(){var t=this.opacity;return(1===(t=isNaN(t)?1:Math.max(0,Math.min(1,t)))?\"rgb(\":\"rgba(\")+Math.max(0,Math.min(255,Math.round(this.r)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.g)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.b)||0))+(1===t?\")\":\", \"+t+\")\")}})),e(A,T,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new A(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new A(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=this.h%360+360*(this.h<0),e=isNaN(t)||isNaN(this.s)?0:this.s,r=this.l,n=r+(r<.5?r:1-r)*e,i=2*r-n;return new _(M(t>=240?t-240:t+120,i,n),M(t,i,n),M(t<120?t+240:t-120,i,n),this.opacity)},displayable:function(){return(0<=this.s&&this.s<=1||isNaN(this.s))&&0<=this.l&&this.l<=1&&0<=this.opacity&&this.opacity<=1}}));var S=Math.PI/180,E=180/Math.PI,C=.96422,L=1,P=.82521,O=4/29,z=6/29,I=3*z*z,D=z*z*z;function R(t){if(t instanceof B)return new B(t.l,t.a,t.b,t.opacity);if(t instanceof G){if(isNaN(t.h))return new B(t.l,0,0,t.opacity);var e=t.h*S;return new B(t.l,Math.cos(e)*t.c,Math.sin(e)*t.c,t.opacity)}t instanceof _||(t=x(t));var r,n,i=V(t.r),a=V(t.g),o=V(t.b),s=N((.2225045*i+.7168786*a+.0606169*o)/L);return i===a&&a===o?r=n=s:(r=N((.4360747*i+.3850649*a+.1430804*o)/C),n=N((.0139322*i+.0971045*a+.7141733*o)/P)),new B(116*s-16,500*(r-s),200*(s-n),t.opacity)}function F(t,e,r,n){return 1===arguments.length?R(t):new B(t,e,r,null==n?1:n)}function B(t,e,r,n){this.l=+t,this.a=+e,this.b=+r,this.opacity=+n}function N(t){return t>D?Math.pow(t,1/3):t/I+O}function j(t){return t>z?t*t*t:I*(t-O)}function U(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function V(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function q(t){if(t instanceof G)return new G(t.h,t.c,t.l,t.opacity);if(t instanceof B||(t=R(t)),0===t.a&&0===t.b)return new G(NaN,0,t.l,t.opacity);var e=Math.atan2(t.b,t.a)*E;return new G(e<0?e+360:e,Math.sqrt(t.a*t.a+t.b*t.b),t.l,t.opacity)}function H(t,e,r,n){return 1===arguments.length?q(t):new G(t,e,r,null==n?1:n)}function G(t,e,r,n){this.h=+t,this.c=+e,this.l=+r,this.opacity=+n}e(B,F,r(n,{brighter:function(t){return new B(this.l+18*(null==t?1:t),this.a,this.b,this.opacity)},darker:function(t){return new B(this.l-18*(null==t?1:t),this.a,this.b,this.opacity)},rgb:function(){var t=(this.l+16)/116,e=isNaN(this.a)?t:t+this.a/500,r=isNaN(this.b)?t:t-this.b/200;return new _(U(3.1338561*(e=C*j(e))-1.6168667*(t=L*j(t))-.4906146*(r=P*j(r))),U(-.9787684*e+1.9161415*t+.033454*r),U(.0719453*e-.2289914*t+1.4052427*r),this.opacity)}})),e(G,H,r(n,{brighter:function(t){return new G(this.h,this.c,this.l+18*(null==t?1:t),this.opacity)},darker:function(t){return new G(this.h,this.c,this.l-18*(null==t?1:t),this.opacity)},rgb:function(){return R(this).rgb()}}));var Y=-.14861,W=1.78277,X=-.29227,Z=-.90649,J=1.97294,K=J*Z,$=J*W,Q=W*X-Z*Y;function tt(t,e,r,n){return 1===arguments.length?function(t){if(t instanceof et)return new et(t.h,t.s,t.l,t.opacity);t instanceof _||(t=x(t));var e=t.r/255,r=t.g/255,n=t.b/255,i=(Q*n+K*e-$*r)/(Q+K-$),a=n-i,o=(J*(r-i)-X*a)/Z,s=Math.sqrt(o*o+a*a)/(J*i*(1-i)),l=s?Math.atan2(o,a)*E-120:NaN;return new et(l<0?l+360:l,s,i,t.opacity)}(t):new et(t,e,r,null==n?1:n)}function et(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}e(et,tt,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new et(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new et(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=isNaN(this.h)?0:(this.h+120)*S,e=+this.l,r=isNaN(this.s)?0:this.s*e*(1-e),n=Math.cos(t),i=Math.sin(t);return new _(255*(e+r*(Y*n+W*i)),255*(e+r*(X*n+Z*i)),255*(e+r*(J*n)),this.opacity)}})),t.color=v,t.rgb=b,t.hsl=T,t.lab=F,t.hcl=H,t.lch=function(t,e,r,n){return 1===arguments.length?q(t):new G(r,e,t,null==n?1:n)},t.gray=function(t,e){return new B(t,0,0,null==e?1:e)},t.cubehelix=tt,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],155:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e={value:function(){}};function r(){for(var t,e=0,r=arguments.length,i={};e<r;++e){if(!(t=arguments[e]+\"\")||t in i)throw new Error(\"illegal type: \"+t);i[t]=[]}return new n(i)}function n(t){this._=t}function i(t,e){for(var r,n=0,i=t.length;n<i;++n)if((r=t[n]).name===e)return r.value}function a(t,r,n){for(var i=0,a=t.length;i<a;++i)if(t[i].name===r){t[i]=e,t=t.slice(0,i).concat(t.slice(i+1));break}return null!=n&&t.push({name:r,value:n}),t}n.prototype=r.prototype={constructor:n,on:function(t,e){var r,n,o=this._,s=(n=o,(t+\"\").trim().split(/^|\\s+/).map(function(t){var e=\"\",r=t.indexOf(\".\");if(r>=0&&(e=t.slice(r+1),t=t.slice(0,r)),t&&!n.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);return{type:t,name:e}})),l=-1,c=s.length;if(!(arguments.length<2)){if(null!=e&&\"function\"!=typeof e)throw new Error(\"invalid callback: \"+e);for(;++l<c;)if(r=(t=s[l]).type)o[r]=a(o[r],t.name,e);else if(null==e)for(r in o)o[r]=a(o[r],t.name,null);return this}for(;++l<c;)if((r=(t=s[l]).type)&&(r=i(o[r],t.name)))return r},copy:function(){var t={},e=this._;for(var r in e)t[r]=e[r].slice();return new n(t)},call:function(t,e){if((r=arguments.length-2)>0)for(var r,n,i=new Array(r),a=0;a<r;++a)i[a]=arguments[a+2];if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(a=0,r=(n=this._[t]).length;a<r;++a)n[a].value.apply(e,i)},apply:function(t,e,r){if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(var n=this._[t],i=0,a=n.length;i<a;++i)n[i].value.apply(e,r)}},t.dispatch=r,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],156:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n,i){\"use strict\";var a=function(t){return function(){return t}},o=function(){return 1e-6*(Math.random()-.5)};function s(t){return t.x+t.vx}function l(t){return t.y+t.vy}function c(t){return t.index}function u(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function h(t){return t.x}function f(t){return t.y}var p=10,d=Math.PI*(3-Math.sqrt(5));t.forceCenter=function(t,e){var r;function n(){var n,i,a=r.length,o=0,s=0;for(n=0;n<a;++n)o+=(i=r[n]).x,s+=i.y;for(o=o/a-t,s=s/a-e,n=0;n<a;++n)(i=r[n]).x-=o,i.y-=s}return null==t&&(t=0),null==e&&(e=0),n.initialize=function(t){r=t},n.x=function(e){return arguments.length?(t=+e,n):t},n.y=function(t){return arguments.length?(e=+t,n):e},n},t.forceCollide=function(t){var r,n,i=1,c=1;function u(){for(var t,a,u,f,p,d,g,v=r.length,m=0;m<c;++m)for(a=e.quadtree(r,s,l).visitAfter(h),t=0;t<v;++t)u=r[t],d=n[u.index],g=d*d,f=u.x+u.vx,p=u.y+u.vy,a.visit(y);function y(t,e,r,n,a){var s=t.data,l=t.r,c=d+l;if(!s)return e>f+c||n<f-c||r>p+c||a<p-c;if(s.index>u.index){var h=f-s.x-s.vx,v=p-s.y-s.vy,m=h*h+v*v;m<c*c&&(0===h&&(m+=(h=o())*h),0===v&&(m+=(v=o())*v),m=(c-(m=Math.sqrt(m)))/m*i,u.vx+=(h*=m)*(c=(l*=l)/(g+l)),u.vy+=(v*=m)*c,s.vx-=h*(c=1-c),s.vy-=v*c)}}}function h(t){if(t.data)return t.r=n[t.data.index];for(var e=t.r=0;e<4;++e)t[e]&&t[e].r>t.r&&(t.r=t[e].r)}function f(){if(r){var e,i,a=r.length;for(n=new Array(a),e=0;e<a;++e)i=r[e],n[i.index]=+t(i,e,r)}}return\"function\"!=typeof t&&(t=a(null==t?1:+t)),u.initialize=function(t){r=t,f()},u.iterations=function(t){return arguments.length?(c=+t,u):c},u.strength=function(t){return arguments.length?(i=+t,u):i},u.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),f(),u):t},u},t.forceLink=function(t){var e,n,i,s,l,h=c,f=function(t){return 1/Math.min(s[t.source.index],s[t.target.index])},p=a(30),d=1;function g(r){for(var i=0,a=t.length;i<d;++i)for(var s,c,u,h,f,p,g,v=0;v<a;++v)c=(s=t[v]).source,h=(u=s.target).x+u.vx-c.x-c.vx||o(),f=u.y+u.vy-c.y-c.vy||o(),h*=p=((p=Math.sqrt(h*h+f*f))-n[v])/p*r*e[v],f*=p,u.vx-=h*(g=l[v]),u.vy-=f*g,c.vx+=h*(g=1-g),c.vy+=f*g}function v(){if(i){var a,o,c=i.length,f=t.length,p=r.map(i,h);for(a=0,s=new Array(c);a<f;++a)(o=t[a]).index=a,\"object\"!=typeof o.source&&(o.source=u(p,o.source)),\"object\"!=typeof o.target&&(o.target=u(p,o.target)),s[o.source.index]=(s[o.source.index]||0)+1,s[o.target.index]=(s[o.target.index]||0)+1;for(a=0,l=new Array(f);a<f;++a)o=t[a],l[a]=s[o.source.index]/(s[o.source.index]+s[o.target.index]);e=new Array(f),m(),n=new Array(f),y()}}function m(){if(i)for(var r=0,n=t.length;r<n;++r)e[r]=+f(t[r],r,t)}function y(){if(i)for(var e=0,r=t.length;e<r;++e)n[e]=+p(t[e],e,t)}return null==t&&(t=[]),g.initialize=function(t){i=t,v()},g.links=function(e){return arguments.length?(t=e,v(),g):t},g.id=function(t){return arguments.length?(h=t,g):h},g.iterations=function(t){return arguments.length?(d=+t,g):d},g.strength=function(t){return arguments.length?(f=\"function\"==typeof t?t:a(+t),m(),g):f},g.distance=function(t){return arguments.length?(p=\"function\"==typeof t?t:a(+t),y(),g):p},g},t.forceManyBody=function(){var t,r,n,i,s=a(-30),l=1,c=1/0,u=.81;function p(i){var a,o=t.length,s=e.quadtree(t,h,f).visitAfter(g);for(n=i,a=0;a<o;++a)r=t[a],s.visit(v)}function d(){if(t){var e,r,n=t.length;for(i=new Array(n),e=0;e<n;++e)r=t[e],i[r.index]=+s(r,e,t)}}function g(t){var e,r,n,a,o,s=0,l=0;if(t.length){for(n=a=o=0;o<4;++o)(e=t[o])&&(r=Math.abs(e.value))&&(s+=e.value,l+=r,n+=r*e.x,a+=r*e.y);t.x=n/l,t.y=a/l}else{(e=t).x=e.data.x,e.y=e.data.y;do{s+=i[e.data.index]}while(e=e.next)}t.value=s}function v(t,e,a,s){if(!t.value)return!0;var h=t.x-r.x,f=t.y-r.y,p=s-e,d=h*h+f*f;if(p*p/u<d)return d<c&&(0===h&&(d+=(h=o())*h),0===f&&(d+=(f=o())*f),d<l&&(d=Math.sqrt(l*d)),r.vx+=h*t.value*n/d,r.vy+=f*t.value*n/d),!0;if(!(t.length||d>=c)){(t.data!==r||t.next)&&(0===h&&(d+=(h=o())*h),0===f&&(d+=(f=o())*f),d<l&&(d=Math.sqrt(l*d)));do{t.data!==r&&(p=i[t.data.index]*n/d,r.vx+=h*p,r.vy+=f*p)}while(t=t.next)}}return p.initialize=function(e){t=e,d()},p.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),d(),p):s},p.distanceMin=function(t){return arguments.length?(l=t*t,p):Math.sqrt(l)},p.distanceMax=function(t){return arguments.length?(c=t*t,p):Math.sqrt(c)},p.theta=function(t){return arguments.length?(u=t*t,p):Math.sqrt(u)},p},t.forceRadial=function(t,e,r){var n,i,o,s=a(.1);function l(t){for(var a=0,s=n.length;a<s;++a){var l=n[a],c=l.x-e||1e-6,u=l.y-r||1e-6,h=Math.sqrt(c*c+u*u),f=(o[a]-h)*i[a]*t/h;l.vx+=c*f,l.vy+=u*f}}function c(){if(n){var e,r=n.length;for(i=new Array(r),o=new Array(r),e=0;e<r;++e)o[e]=+t(n[e],e,n),i[e]=isNaN(o[e])?0:+s(n[e],e,n)}}return\"function\"!=typeof t&&(t=a(+t)),null==e&&(e=0),null==r&&(r=0),l.initialize=function(t){n=t,c()},l.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),c(),l):s},l.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),c(),l):t},l.x=function(t){return arguments.length?(e=+t,l):e},l.y=function(t){return arguments.length?(r=+t,l):r},l},t.forceSimulation=function(t){var e,a=1,o=.001,s=1-Math.pow(o,1/300),l=0,c=.6,u=r.map(),h=i.timer(g),f=n.dispatch(\"tick\",\"end\");function g(){v(),f.call(\"tick\",e),a<o&&(h.stop(),f.call(\"end\",e))}function v(){var e,r,n=t.length;for(a+=(l-a)*s,u.each(function(t){t(a)}),e=0;e<n;++e)null==(r=t[e]).fx?r.x+=r.vx*=c:(r.x=r.fx,r.vx=0),null==r.fy?r.y+=r.vy*=c:(r.y=r.fy,r.vy=0)}function m(){for(var e,r=0,n=t.length;r<n;++r){if((e=t[r]).index=r,isNaN(e.x)||isNaN(e.y)){var i=p*Math.sqrt(r),a=r*d;e.x=i*Math.cos(a),e.y=i*Math.sin(a)}(isNaN(e.vx)||isNaN(e.vy))&&(e.vx=e.vy=0)}}function y(e){return e.initialize&&e.initialize(t),e}return null==t&&(t=[]),m(),e={tick:v,restart:function(){return h.restart(g),e},stop:function(){return h.stop(),e},nodes:function(r){return arguments.length?(t=r,m(),u.each(y),e):t},alpha:function(t){return arguments.length?(a=+t,e):a},alphaMin:function(t){return arguments.length?(o=+t,e):o},alphaDecay:function(t){return arguments.length?(s=+t,e):+s},alphaTarget:function(t){return arguments.length?(l=+t,e):l},velocityDecay:function(t){return arguments.length?(c=1-t,e):1-c},force:function(t,r){return arguments.length>1?(null==r?u.remove(t):u.set(t,y(r)),e):u.get(t)},find:function(e,r,n){var i,a,o,s,l,c=0,u=t.length;for(null==n?n=1/0:n*=n,c=0;c<u;++c)(o=(i=e-(s=t[c]).x)*i+(a=r-s.y)*a)<n&&(l=s,n=o);return l},on:function(t,r){return arguments.length>1?(f.on(t,r),e):f.on(t)}}},t.forceX=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vx+=(n[a]-i.x)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},t.forceY=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vy+=(n[a]-i.y)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.y=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-quadtree\"),t(\"d3-collection\"),t(\"d3-dispatch\"),t(\"d3-timer\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,n.d3)},{\"d3-collection\":153,\"d3-dispatch\":155,\"d3-quadtree\":160,\"d3-timer\":162}],157:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e){return t.parent===e.parent?1:2}function r(t,e){return t+e.x}function n(t,e){return Math.max(t,e.y)}function i(t){var e=0,r=t.children,n=r&&r.length;if(n)for(;--n>=0;)e+=r[n].value;else e=1;t.value=e}function a(t,e){var r,n,i,a,s,u=new c(t),h=+t.value&&(u.value=t.value),f=[u];for(null==e&&(e=o);r=f.pop();)if(h&&(r.value=+r.data.value),(i=e(r.data))&&(s=i.length))for(r.children=new Array(s),a=s-1;a>=0;--a)f.push(n=r.children[a]=new c(i[a])),n.parent=r,n.depth=r.depth+1;return u.eachBefore(l)}function o(t){return t.children}function s(t){t.data=t.data.data}function l(t){var e=0;do{t.height=e}while((t=t.parent)&&t.height<++e)}function c(t){this.data=t,this.depth=this.height=0,this.parent=null}c.prototype=a.prototype={constructor:c,count:function(){return this.eachAfter(i)},each:function(t){var e,r,n,i,a=this,o=[a];do{for(e=o.reverse(),o=[];a=e.pop();)if(t(a),r=a.children)for(n=0,i=r.length;n<i;++n)o.push(r[n])}while(o.length);return this},eachAfter:function(t){for(var e,r,n,i=this,a=[i],o=[];i=a.pop();)if(o.push(i),e=i.children)for(r=0,n=e.length;r<n;++r)a.push(e[r]);for(;i=o.pop();)t(i);return this},eachBefore:function(t){for(var e,r,n=this,i=[n];n=i.pop();)if(t(n),e=n.children)for(r=e.length-1;r>=0;--r)i.push(e[r]);return this},sum:function(t){return this.eachAfter(function(e){for(var r=+t(e.data)||0,n=e.children,i=n&&n.length;--i>=0;)r+=n[i].value;e.value=r})},sort:function(t){return this.eachBefore(function(e){e.children&&e.children.sort(t)})},path:function(t){for(var e=this,r=function(t,e){if(t===e)return t;var r=t.ancestors(),n=e.ancestors(),i=null;for(t=r.pop(),e=n.pop();t===e;)i=t,t=r.pop(),e=n.pop();return i}(e,t),n=[e];e!==r;)e=e.parent,n.push(e);for(var i=n.length;t!==r;)n.splice(i,0,t),t=t.parent;return n},ancestors:function(){for(var t=this,e=[t];t=t.parent;)e.push(t);return e},descendants:function(){var t=[];return this.each(function(e){t.push(e)}),t},leaves:function(){var t=[];return this.eachBefore(function(e){e.children||t.push(e)}),t},links:function(){var t=this,e=[];return t.each(function(r){r!==t&&e.push({source:r.parent,target:r})}),e},copy:function(){return a(this).eachBefore(s)}};var u=Array.prototype.slice;function h(t){for(var e,r,n=0,i=(t=function(t){for(var e,r,n=t.length;n;)r=Math.random()*n--|0,e=t[n],t[n]=t[r],t[r]=e;return t}(u.call(t))).length,a=[];n<i;)e=t[n],r&&d(r,e)?++n:(r=v(a=f(a,e)),n=0);return r}function f(t,e){var r,n;if(g(e,t))return[e];for(r=0;r<t.length;++r)if(p(e,t[r])&&g(m(t[r],e),t))return[t[r],e];for(r=0;r<t.length-1;++r)for(n=r+1;n<t.length;++n)if(p(m(t[r],t[n]),e)&&p(m(t[r],e),t[n])&&p(m(t[n],e),t[r])&&g(y(t[r],t[n],e),t))return[t[r],t[n],e];throw new Error}function p(t,e){var r=t.r-e.r,n=e.x-t.x,i=e.y-t.y;return r<0||r*r<n*n+i*i}function d(t,e){var r=t.r-e.r+1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function g(t,e){for(var r=0;r<e.length;++r)if(!d(t,e[r]))return!1;return!0}function v(t){switch(t.length){case 1:return{x:(e=t[0]).x,y:e.y,r:e.r};case 2:return m(t[0],t[1]);case 3:return y(t[0],t[1],t[2])}var e}function m(t,e){var r=t.x,n=t.y,i=t.r,a=e.x,o=e.y,s=e.r,l=a-r,c=o-n,u=s-i,h=Math.sqrt(l*l+c*c);return{x:(r+a+l/h*u)/2,y:(n+o+c/h*u)/2,r:(h+i+s)/2}}function y(t,e,r){var n=t.x,i=t.y,a=t.r,o=e.x,s=e.y,l=e.r,c=r.x,u=r.y,h=r.r,f=n-o,p=n-c,d=i-s,g=i-u,v=l-a,m=h-a,y=n*n+i*i-a*a,x=y-o*o-s*s+l*l,b=y-c*c-u*u+h*h,_=p*d-f*g,w=(d*b-g*x)/(2*_)-n,k=(g*v-d*m)/_,T=(p*x-f*b)/(2*_)-i,A=(f*m-p*v)/_,M=k*k+A*A-1,S=2*(a+w*k+T*A),E=w*w+T*T-a*a,C=-(M?(S+Math.sqrt(S*S-4*M*E))/(2*M):E/S);return{x:n+w+k*C,y:i+T+A*C,r:C}}function x(t,e,r){var n,i,a,o,s=t.x-e.x,l=t.y-e.y,c=s*s+l*l;c?(i=e.r+r.r,i*=i,o=t.r+r.r,i>(o*=o)?(n=(c+o-i)/(2*c),a=Math.sqrt(Math.max(0,o/c-n*n)),r.x=t.x-n*s-a*l,r.y=t.y-n*l+a*s):(n=(c+i-o)/(2*c),a=Math.sqrt(Math.max(0,i/c-n*n)),r.x=e.x+n*s-a*l,r.y=e.y+n*l+a*s)):(r.x=e.x+r.r,r.y=e.y)}function b(t,e){var r=t.r+e.r-1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function _(t){var e=t._,r=t.next._,n=e.r+r.r,i=(e.x*r.r+r.x*e.r)/n,a=(e.y*r.r+r.y*e.r)/n;return i*i+a*a}function w(t){this._=t,this.next=null,this.previous=null}function k(t){if(!(i=t.length))return 0;var e,r,n,i,a,o,s,l,c,u,f;if((e=t[0]).x=0,e.y=0,!(i>1))return e.r;if(r=t[1],e.x=-r.r,r.x=e.r,r.y=0,!(i>2))return e.r+r.r;x(r,e,n=t[2]),e=new w(e),r=new w(r),n=new w(n),e.next=n.previous=r,r.next=e.previous=n,n.next=r.previous=e;t:for(s=3;s<i;++s){x(e._,r._,n=t[s]),n=new w(n),l=r.next,c=e.previous,u=r._.r,f=e._.r;do{if(u<=f){if(b(l._,n._)){r=l,e.next=r,r.previous=e,--s;continue t}u+=l._.r,l=l.next}else{if(b(c._,n._)){(e=c).next=r,r.previous=e,--s;continue t}f+=c._.r,c=c.previous}}while(l!==c.next);for(n.previous=e,n.next=r,e.next=r.previous=r=n,a=_(e);(n=n.next)!==r;)(o=_(n))<a&&(e=n,a=o);r=e.next}for(e=[r._],n=r;(n=n.next)!==r;)e.push(n._);for(n=h(e),s=0;s<i;++s)(e=t[s]).x-=n.x,e.y-=n.y;return n.r}function T(t){if(\"function\"!=typeof t)throw new Error;return t}function A(){return 0}function M(t){return function(){return t}}function S(t){return Math.sqrt(t.value)}function E(t){return function(e){e.children||(e.r=Math.max(0,+t(e)||0))}}function C(t,e){return function(r){if(n=r.children){var n,i,a,o=n.length,s=t(r)*e||0;if(s)for(i=0;i<o;++i)n[i].r+=s;if(a=k(n),s)for(i=0;i<o;++i)n[i].r-=s;r.r=a+s}}}function L(t){return function(e){var r=e.parent;e.r*=t,r&&(e.x=r.x+t*e.x,e.y=r.y+t*e.y)}}function P(t){t.x0=Math.round(t.x0),t.y0=Math.round(t.y0),t.x1=Math.round(t.x1),t.y1=Math.round(t.y1)}function O(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(n-e)/t.value;++s<l;)(a=o[s]).y0=r,a.y1=i,a.x0=e,a.x1=e+=a.value*c}var z=\"$\",I={depth:-1},D={};function R(t){return t.id}function F(t){return t.parentId}function B(t,e){return t.parent===e.parent?1:2}function N(t){var e=t.children;return e?e[0]:t.t}function j(t){var e=t.children;return e?e[e.length-1]:t.t}function U(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function V(t,e,r){return t.a.parent===e.parent?t.a:r}function q(t,e){this._=t,this.parent=null,this.children=null,this.A=null,this.a=this,this.z=0,this.m=0,this.c=0,this.s=0,this.t=null,this.i=e}function H(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(i-r)/t.value;++s<l;)(a=o[s]).x0=e,a.x1=n,a.y0=r,a.y1=r+=a.value*c}q.prototype=Object.create(c.prototype);var G=(1+Math.sqrt(5))/2;function Y(t,e,r,n,i,a){for(var o,s,l,c,u,h,f,p,d,g,v,m=[],y=e.children,x=0,b=0,_=y.length,w=e.value;x<_;){l=i-r,c=a-n;do{u=y[b++].value}while(!u&&b<_);for(h=f=u,v=u*u*(g=Math.max(c/l,l/c)/(w*t)),d=Math.max(f/v,v/h);b<_;++b){if(u+=s=y[b].value,s<h&&(h=s),s>f&&(f=s),v=u*u*g,(p=Math.max(f/v,v/h))>d){u-=s;break}d=p}m.push(o={value:u,dice:l<c,children:y.slice(x,b)}),o.dice?O(o,r,n,i,w?n+=c*u/w:a):H(o,r,n,w?r+=l*u/w:i,a),w-=u,x=b}return m}var W=function t(e){function r(t,r,n,i,a){Y(e,t,r,n,i,a)}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);var X=function t(e){function r(t,r,n,i,a){if((o=t._squarify)&&o.ratio===e)for(var o,s,l,c,u,h=-1,f=o.length,p=t.value;++h<f;){for(l=(s=o[h]).children,c=s.value=0,u=l.length;c<u;++c)s.value+=l[c].value;s.dice?O(s,r,n,i,n+=(a-n)*s.value/p):H(s,r,n,r+=(i-r)*s.value/p,a),p-=s.value}else t._squarify=o=Y(e,t,r,n,i,a),o.ratio=e}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);t.cluster=function(){var t=e,i=1,a=1,o=!1;function s(e){var s,l=0;e.eachAfter(function(e){var i=e.children;i?(e.x=function(t){return t.reduce(r,0)/t.length}(i),e.y=function(t){return 1+t.reduce(n,0)}(i)):(e.x=s?l+=t(e,s):0,e.y=0,s=e)});var c=function(t){for(var e;e=t.children;)t=e[0];return t}(e),u=function(t){for(var e;e=t.children;)t=e[e.length-1];return t}(e),h=c.x-t(c,u)/2,f=u.x+t(u,c)/2;return e.eachAfter(o?function(t){t.x=(t.x-e.x)*i,t.y=(e.y-t.y)*a}:function(t){t.x=(t.x-h)/(f-h)*i,t.y=(1-(e.y?t.y/e.y:1))*a})}return s.separation=function(e){return arguments.length?(t=e,s):t},s.size=function(t){return arguments.length?(o=!1,i=+t[0],a=+t[1],s):o?null:[i,a]},s.nodeSize=function(t){return arguments.length?(o=!0,i=+t[0],a=+t[1],s):o?[i,a]:null},s},t.hierarchy=a,t.pack=function(){var t=null,e=1,r=1,n=A;function i(i){return i.x=e/2,i.y=r/2,t?i.eachBefore(E(t)).eachAfter(C(n,.5)).eachBefore(L(1)):i.eachBefore(E(S)).eachAfter(C(A,1)).eachAfter(C(n,i.r/Math.min(e,r))).eachBefore(L(Math.min(e,r)/(2*i.r))),i}return i.radius=function(e){return arguments.length?(t=null==(r=e)?null:T(r),i):t;var r},i.size=function(t){return arguments.length?(e=+t[0],r=+t[1],i):[e,r]},i.padding=function(t){return arguments.length?(n=\"function\"==typeof t?t:M(+t),i):n},i},t.packSiblings=function(t){return k(t),t},t.packEnclose=h,t.partition=function(){var t=1,e=1,r=0,n=!1;function i(i){var a=i.height+1;return i.x0=i.y0=r,i.x1=t,i.y1=e/a,i.eachBefore(function(t,e){return function(n){n.children&&O(n,n.x0,t*(n.depth+1)/e,n.x1,t*(n.depth+2)/e);var i=n.x0,a=n.y0,o=n.x1-r,s=n.y1-r;o<i&&(i=o=(i+o)/2),s<a&&(a=s=(a+s)/2),n.x0=i,n.y0=a,n.x1=o,n.y1=s}}(e,a)),n&&i.eachBefore(P),i}return i.round=function(t){return arguments.length?(n=!!t,i):n},i.size=function(r){return arguments.length?(t=+r[0],e=+r[1],i):[t,e]},i.padding=function(t){return arguments.length?(r=+t,i):r},i},t.stratify=function(){var t=R,e=F;function r(r){var n,i,a,o,s,u,h,f=r.length,p=new Array(f),d={};for(i=0;i<f;++i)n=r[i],s=p[i]=new c(n),null!=(u=t(n,i,r))&&(u+=\"\")&&(d[h=z+(s.id=u)]=h in d?D:s);for(i=0;i<f;++i)if(s=p[i],null!=(u=e(r[i],i,r))&&(u+=\"\")){if(!(o=d[z+u]))throw new Error(\"missing: \"+u);if(o===D)throw new Error(\"ambiguous: \"+u);o.children?o.children.push(s):o.children=[s],s.parent=o}else{if(a)throw new Error(\"multiple roots\");a=s}if(!a)throw new Error(\"no root\");if(a.parent=I,a.eachBefore(function(t){t.depth=t.parent.depth+1,--f}).eachBefore(l),a.parent=null,f>0)throw new Error(\"cycle\");return a}return r.id=function(e){return arguments.length?(t=T(e),r):t},r.parentId=function(t){return arguments.length?(e=T(t),r):e},r},t.tree=function(){var t=B,e=1,r=1,n=null;function i(i){var l=function(t){for(var e,r,n,i,a,o=new q(t,0),s=[o];e=s.pop();)if(n=e._.children)for(e.children=new Array(a=n.length),i=a-1;i>=0;--i)s.push(r=e.children[i]=new q(n[i],i)),r.parent=e;return(o.parent=new q(null,0)).children=[o],o}(i);if(l.eachAfter(a),l.parent.m=-l.z,l.eachBefore(o),n)i.eachBefore(s);else{var c=i,u=i,h=i;i.eachBefore(function(t){t.x<c.x&&(c=t),t.x>u.x&&(u=t),t.depth>h.depth&&(h=t)});var f=c===u?1:t(c,u)/2,p=f-c.x,d=e/(u.x+f+p),g=r/(h.depth||1);i.eachBefore(function(t){t.x=(t.x+p)*d,t.y=t.depth*g})}return i}function a(e){var r=e.children,n=e.parent.children,i=e.i?n[e.i-1]:null;if(r){!function(t){for(var e,r=0,n=0,i=t.children,a=i.length;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(e);var a=(r[0].z+r[r.length-1].z)/2;i?(e.z=i.z+t(e._,i._),e.m=e.z-a):e.z=a}else i&&(e.z=i.z+t(e._,i._));e.parent.A=function(e,r,n){if(r){for(var i,a=e,o=e,s=r,l=a.parent.children[0],c=a.m,u=o.m,h=s.m,f=l.m;s=j(s),a=N(a),s&&a;)l=N(l),(o=j(o)).a=e,(i=s.z+h-a.z-c+t(s._,a._))>0&&(U(V(s,e,n),e,i),c+=i,u+=i),h+=s.m,c+=a.m,f+=l.m,u+=o.m;s&&!j(o)&&(o.t=s,o.m+=h-u),a&&!N(l)&&(l.t=a,l.m+=c-f,n=e)}return n}(e,i,e.parent.A||n[0])}function o(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function s(t){t.x*=e,t.y=t.depth*r}return i.separation=function(e){return arguments.length?(t=e,i):t},i.size=function(t){return arguments.length?(n=!1,e=+t[0],r=+t[1],i):n?null:[e,r]},i.nodeSize=function(t){return arguments.length?(n=!0,e=+t[0],r=+t[1],i):n?[e,r]:null},i},t.treemap=function(){var t=W,e=!1,r=1,n=1,i=[0],a=A,o=A,s=A,l=A,c=A;function u(t){return t.x0=t.y0=0,t.x1=r,t.y1=n,t.eachBefore(h),i=[0],e&&t.eachBefore(P),t}function h(e){var r=i[e.depth],n=e.x0+r,u=e.y0+r,h=e.x1-r,f=e.y1-r;h<n&&(n=h=(n+h)/2),f<u&&(u=f=(u+f)/2),e.x0=n,e.y0=u,e.x1=h,e.y1=f,e.children&&(r=i[e.depth+1]=a(e)/2,n+=c(e)-r,u+=o(e)-r,(h-=s(e)-r)<n&&(n=h=(n+h)/2),(f-=l(e)-r)<u&&(u=f=(u+f)/2),t(e,n,u,h,f))}return u.round=function(t){return arguments.length?(e=!!t,u):e},u.size=function(t){return arguments.length?(r=+t[0],n=+t[1],u):[r,n]},u.tile=function(e){return arguments.length?(t=T(e),u):t},u.padding=function(t){return arguments.length?u.paddingInner(t).paddingOuter(t):u.paddingInner()},u.paddingInner=function(t){return arguments.length?(a=\"function\"==typeof t?t:M(+t),u):a},u.paddingOuter=function(t){return arguments.length?u.paddingTop(t).paddingRight(t).paddingBottom(t).paddingLeft(t):u.paddingTop()},u.paddingTop=function(t){return arguments.length?(o=\"function\"==typeof t?t:M(+t),u):o},u.paddingRight=function(t){return arguments.length?(s=\"function\"==typeof t?t:M(+t),u):s},u.paddingBottom=function(t){return arguments.length?(l=\"function\"==typeof t?t:M(+t),u):l},u.paddingLeft=function(t){return arguments.length?(c=\"function\"==typeof t?t:M(+t),u):c},u},t.treemapBinary=function(t,e,r,n,i){var a,o,s=t.children,l=s.length,c=new Array(l+1);for(c[0]=o=a=0;a<l;++a)c[a+1]=o+=s[a].value;!function t(e,r,n,i,a,o,l){if(e>=r-1){var u=s[e];return u.x0=i,u.y0=a,u.x1=o,void(u.y1=l)}for(var h=c[e],f=n/2+h,p=e+1,d=r-1;p<d;){var g=p+d>>>1;c[g]<f?p=g+1:d=g}f-c[p-1]<c[p]-f&&e+1<p&&--p;var v=c[p]-h,m=n-v;if(o-i>l-a){var y=(i*m+o*v)/n;t(e,p,v,i,a,y,l),t(p,r,m,y,a,o,l)}else{var x=(a*m+l*v)/n;t(e,p,v,i,a,o,x),t(p,r,m,i,x,o,l)}}(0,l,t.value,e,r,n,i)},t.treemapDice=O,t.treemapSlice=H,t.treemapSliceDice=function(t,e,r,n,i){(1&t.depth?H:O)(t,e,r,n,i)},t.treemapSquarify=W,t.treemapResquarify=X,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],158:[function(t,e,r){var n,i;n=this,i=function(t,e){\"use strict\";function r(t,e,r,n,i){var a=t*t,o=a*t;return((1-3*t+3*a-o)*e+(4-6*a+3*o)*r+(1+3*t+3*a-3*o)*n+o*i)/6}function n(t){var e=t.length-1;return function(n){var i=n<=0?n=0:n>=1?(n=1,e-1):Math.floor(n*e),a=t[i],o=t[i+1],s=i>0?t[i-1]:2*a-o,l=i<e-1?t[i+2]:2*o-a;return r((n-i/e)*e,s,a,o,l)}}function i(t){var e=t.length;return function(n){var i=Math.floor(((n%=1)<0?++n:n)*e),a=t[(i+e-1)%e],o=t[i%e],s=t[(i+1)%e],l=t[(i+2)%e];return r((n-i/e)*e,a,o,s,l)}}function a(t){return function(){return t}}function o(t,e){return function(r){return t+r*e}}function s(t,e){var r=e-t;return r?o(t,r>180||r<-180?r-360*Math.round(r/360):r):a(isNaN(t)?e:t)}function l(t){return 1==(t=+t)?c:function(e,r){return r-e?function(t,e,r){return t=Math.pow(t,r),e=Math.pow(e,r)-t,r=1/r,function(n){return Math.pow(t+n*e,r)}}(e,r,t):a(isNaN(e)?r:e)}}function c(t,e){var r=e-t;return r?o(t,r):a(isNaN(t)?e:t)}var u=function t(r){var n=l(r);function i(t,r){var i=n((t=e.rgb(t)).r,(r=e.rgb(r)).r),a=n(t.g,r.g),o=n(t.b,r.b),s=c(t.opacity,r.opacity);return function(e){return t.r=i(e),t.g=a(e),t.b=o(e),t.opacity=s(e),t+\"\"}}return i.gamma=t,i}(1);function h(t){return function(r){var n,i,a=r.length,o=new Array(a),s=new Array(a),l=new Array(a);for(n=0;n<a;++n)i=e.rgb(r[n]),o[n]=i.r||0,s[n]=i.g||0,l[n]=i.b||0;return o=t(o),s=t(s),l=t(l),i.opacity=1,function(t){return i.r=o(t),i.g=s(t),i.b=l(t),i+\"\"}}}var f=h(n),p=h(i);function d(t,e){var r,n=e?e.length:0,i=t?Math.min(n,t.length):0,a=new Array(i),o=new Array(n);for(r=0;r<i;++r)a[r]=_(t[r],e[r]);for(;r<n;++r)o[r]=e[r];return function(t){for(r=0;r<i;++r)o[r]=a[r](t);return o}}function g(t,e){var r=new Date;return e-=t=+t,function(n){return r.setTime(t+e*n),r}}function v(t,e){return e-=t=+t,function(r){return t+e*r}}function m(t,e){var r,n={},i={};for(r in null!==t&&\"object\"==typeof t||(t={}),null!==e&&\"object\"==typeof e||(e={}),e)r in t?n[r]=_(t[r],e[r]):i[r]=e[r];return function(t){for(r in n)i[r]=n[r](t);return i}}var y=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,x=new RegExp(y.source,\"g\");function b(t,e){var r,n,i,a=y.lastIndex=x.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=y.exec(t))&&(n=x.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:v(r,n)})),a=x.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?function(t){return function(e){return t(e)+\"\"}}(l[0].x):function(t){return function(){return t}}(e):(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}function _(t,r){var n,i=typeof r;return null==r||\"boolean\"===i?a(r):(\"number\"===i?v:\"string\"===i?(n=e.color(r))?(r=n,u):b:r instanceof e.color?u:r instanceof Date?g:Array.isArray(r)?d:\"function\"!=typeof r.valueOf&&\"function\"!=typeof r.toString||isNaN(r)?m:v)(t,r)}var w,k,T,A,M=180/Math.PI,S={translateX:0,translateY:0,rotate:0,skewX:0,scaleX:1,scaleY:1};function E(t,e,r,n,i,a){var o,s,l;return(o=Math.sqrt(t*t+e*e))&&(t/=o,e/=o),(l=t*r+e*n)&&(r-=t*l,n-=e*l),(s=Math.sqrt(r*r+n*n))&&(r/=s,n/=s,l/=s),t*n<e*r&&(t=-t,e=-e,l=-l,o=-o),{translateX:i,translateY:a,rotate:Math.atan2(e,t)*M,skewX:Math.atan(l)*M,scaleX:o,scaleY:s}}function C(t,e,r,n){function i(t){return t.length?t.pop()+\" \":\"\"}return function(a,o){var s=[],l=[];return a=t(a),o=t(o),function(t,n,i,a,o,s){if(t!==i||n!==a){var l=o.push(\"translate(\",null,e,null,r);s.push({i:l-4,x:v(t,i)},{i:l-2,x:v(n,a)})}else(i||a)&&o.push(\"translate(\"+i+e+a+r)}(a.translateX,a.translateY,o.translateX,o.translateY,s,l),function(t,e,r,a){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),a.push({i:r.push(i(r)+\"rotate(\",null,n)-2,x:v(t,e)})):e&&r.push(i(r)+\"rotate(\"+e+n)}(a.rotate,o.rotate,s,l),function(t,e,r,a){t!==e?a.push({i:r.push(i(r)+\"skewX(\",null,n)-2,x:v(t,e)}):e&&r.push(i(r)+\"skewX(\"+e+n)}(a.skewX,o.skewX,s,l),function(t,e,r,n,a,o){if(t!==r||e!==n){var s=a.push(i(a)+\"scale(\",null,\",\",null,\")\");o.push({i:s-4,x:v(t,r)},{i:s-2,x:v(e,n)})}else 1===r&&1===n||a.push(i(a)+\"scale(\"+r+\",\"+n+\")\")}(a.scaleX,a.scaleY,o.scaleX,o.scaleY,s,l),a=o=null,function(t){for(var e,r=-1,n=l.length;++r<n;)s[(e=l[r]).i]=e.x(t);return s.join(\"\")}}}var L=C(function(t){return\"none\"===t?S:(w||(w=document.createElement(\"DIV\"),k=document.documentElement,T=document.defaultView),w.style.transform=t,t=T.getComputedStyle(k.appendChild(w),null).getPropertyValue(\"transform\"),k.removeChild(w),E(+(t=t.slice(7,-1).split(\",\"))[0],+t[1],+t[2],+t[3],+t[4],+t[5]))},\"px, \",\"px)\",\"deg)\"),P=C(function(t){return null==t?S:(A||(A=document.createElementNS(\"http://www.w3.org/2000/svg\",\"g\")),A.setAttribute(\"transform\",t),(t=A.transform.baseVal.consolidate())?E((t=t.matrix).a,t.b,t.c,t.d,t.e,t.f):S)},\", \",\")\",\")\"),O=Math.SQRT2,z=2,I=4,D=1e-12;function R(t){return((t=Math.exp(t))+1/t)/2}function F(t){return function(r,n){var i=t((r=e.hsl(r)).h,(n=e.hsl(n)).h),a=c(r.s,n.s),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.s=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var B=F(s),N=F(c);function j(t){return function(r,n){var i=t((r=e.hcl(r)).h,(n=e.hcl(n)).h),a=c(r.c,n.c),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.c=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var U=j(s),V=j(c);function q(t){return function r(n){function i(r,i){var a=t((r=e.cubehelix(r)).h,(i=e.cubehelix(i)).h),o=c(r.s,i.s),s=c(r.l,i.l),l=c(r.opacity,i.opacity);return function(t){return r.h=a(t),r.s=o(t),r.l=s(Math.pow(t,n)),r.opacity=l(t),r+\"\"}}return n=+n,i.gamma=r,i}(1)}var H=q(s),G=q(c);t.interpolate=_,t.interpolateArray=d,t.interpolateBasis=n,t.interpolateBasisClosed=i,t.interpolateDate=g,t.interpolateDiscrete=function(t){var e=t.length;return function(r){return t[Math.max(0,Math.min(e-1,Math.floor(r*e)))]}},t.interpolateHue=function(t,e){var r=s(+t,+e);return function(t){var e=r(t);return e-360*Math.floor(e/360)}},t.interpolateNumber=v,t.interpolateObject=m,t.interpolateRound=function(t,e){return e-=t=+t,function(r){return Math.round(t+e*r)}},t.interpolateString=b,t.interpolateTransformCss=L,t.interpolateTransformSvg=P,t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,h=l-a,f=u*u+h*h;if(f<D)n=Math.log(c/o)/O,r=function(t){return[i+t*u,a+t*h,o*Math.exp(O*t*n)]};else{var p=Math.sqrt(f),d=(c*c-o*o+I*f)/(2*o*z*p),g=(c*c-o*o-I*f)/(2*c*z*p),v=Math.log(Math.sqrt(d*d+1)-d),m=Math.log(Math.sqrt(g*g+1)-g);n=(m-v)/O,r=function(t){var e,r=t*n,s=R(v),l=o/(z*p)*(s*(e=O*r+v,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(v));return[i+l*u,a+l*h,o*s/R(O*r+v)]}}return r.duration=1e3*n,r},t.interpolateRgb=u,t.interpolateRgbBasis=f,t.interpolateRgbBasisClosed=p,t.interpolateHsl=B,t.interpolateHslLong=N,t.interpolateLab=function(t,r){var n=c((t=e.lab(t)).l,(r=e.lab(r)).l),i=c(t.a,r.a),a=c(t.b,r.b),o=c(t.opacity,r.opacity);return function(e){return t.l=n(e),t.a=i(e),t.b=a(e),t.opacity=o(e),t+\"\"}},t.interpolateHcl=U,t.interpolateHclLong=V,t.interpolateCubehelix=H,t.interpolateCubehelixLong=G,t.piecewise=function(t,e){for(var r=0,n=e.length-1,i=e[0],a=new Array(n<0?0:n);r<n;)a[r]=t(i,i=e[++r]);return function(t){var e=Math.max(0,Math.min(n-1,Math.floor(t*=n)));return a[e](t-e)}},t.quantize=function(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t(n/(e-1));return r},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-color\")):i(n.d3=n.d3||{},n.d3)},{\"d3-color\":154}],159:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e=Math.PI,r=2*e,n=r-1e-6;function i(){this._x0=this._y0=this._x1=this._y1=null,this._=\"\"}function a(){return new i}i.prototype=a.prototype={constructor:i,moveTo:function(t,e){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)},closePath:function(){null!==this._x1&&(this._x1=this._x0,this._y1=this._y0,this._+=\"Z\")},lineTo:function(t,e){this._+=\"L\"+(this._x1=+t)+\",\"+(this._y1=+e)},quadraticCurveTo:function(t,e,r,n){this._+=\"Q\"+ +t+\",\"+ +e+\",\"+(this._x1=+r)+\",\"+(this._y1=+n)},bezierCurveTo:function(t,e,r,n,i,a){this._+=\"C\"+ +t+\",\"+ +e+\",\"+ +r+\",\"+ +n+\",\"+(this._x1=+i)+\",\"+(this._y1=+a)},arcTo:function(t,r,n,i,a){t=+t,r=+r,n=+n,i=+i,a=+a;var o=this._x1,s=this._y1,l=n-t,c=i-r,u=o-t,h=s-r,f=u*u+h*h;if(a<0)throw new Error(\"negative radius: \"+a);if(null===this._x1)this._+=\"M\"+(this._x1=t)+\",\"+(this._y1=r);else if(f>1e-6)if(Math.abs(h*l-c*u)>1e-6&&a){var p=n-o,d=i-s,g=l*l+c*c,v=p*p+d*d,m=Math.sqrt(g),y=Math.sqrt(f),x=a*Math.tan((e-Math.acos((g+f-v)/(2*m*y)))/2),b=x/y,_=x/m;Math.abs(b-1)>1e-6&&(this._+=\"L\"+(t+b*u)+\",\"+(r+b*h)),this._+=\"A\"+a+\",\"+a+\",0,0,\"+ +(h*p>u*d)+\",\"+(this._x1=t+_*l)+\",\"+(this._y1=r+_*c)}else this._+=\"L\"+(this._x1=t)+\",\"+(this._y1=r);else;},arc:function(t,i,a,o,s,l){t=+t,i=+i;var c=(a=+a)*Math.cos(o),u=a*Math.sin(o),h=t+c,f=i+u,p=1^l,d=l?o-s:s-o;if(a<0)throw new Error(\"negative radius: \"+a);null===this._x1?this._+=\"M\"+h+\",\"+f:(Math.abs(this._x1-h)>1e-6||Math.abs(this._y1-f)>1e-6)&&(this._+=\"L\"+h+\",\"+f),a&&(d<0&&(d=d%r+r),d>n?this._+=\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(t-c)+\",\"+(i-u)+\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(this._x1=h)+\",\"+(this._y1=f):d>1e-6&&(this._+=\"A\"+a+\",\"+a+\",0,\"+ +(d>=e)+\",\"+p+\",\"+(this._x1=t+a*Math.cos(s))+\",\"+(this._y1=i+a*Math.sin(s))))},rect:function(t,e,r,n){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)+\"h\"+ +r+\"v\"+ +n+\"h\"+-r+\"Z\"},toString:function(){return this._}},t.path=a,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],160:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e,r,n){if(isNaN(e)||isNaN(r))return t;var i,a,o,s,l,c,u,h,f,p=t._root,d={data:n},g=t._x0,v=t._y0,m=t._x1,y=t._y1;if(!p)return t._root=d,t;for(;p.length;)if((c=e>=(a=(g+m)/2))?g=a:m=a,(u=r>=(o=(v+y)/2))?v=o:y=o,i=p,!(p=p[h=u<<1|c]))return i[h]=d,t;if(s=+t._x.call(null,p.data),l=+t._y.call(null,p.data),e===s&&r===l)return d.next=p,i?i[h]=d:t._root=d,t;do{i=i?i[h]=new Array(4):t._root=new Array(4),(c=e>=(a=(g+m)/2))?g=a:m=a,(u=r>=(o=(v+y)/2))?v=o:y=o}while((h=u<<1|c)==(f=(l>=o)<<1|s>=a));return i[f]=p,i[h]=d,t}var r=function(t,e,r,n,i){this.node=t,this.x0=e,this.y0=r,this.x1=n,this.y1=i};function n(t){return t[0]}function i(t){return t[1]}function a(t,e,r){var a=new o(null==e?n:e,null==r?i:r,NaN,NaN,NaN,NaN);return null==t?a:a.addAll(t)}function o(t,e,r,n,i,a){this._x=t,this._y=e,this._x0=r,this._y0=n,this._x1=i,this._y1=a,this._root=void 0}function s(t){for(var e={data:t.data},r=e;t=t.next;)r=r.next={data:t.data};return e}var l=a.prototype=o.prototype;l.copy=function(){var t,e,r=new o(this._x,this._y,this._x0,this._y0,this._x1,this._y1),n=this._root;if(!n)return r;if(!n.length)return r._root=s(n),r;for(t=[{source:n,target:r._root=new Array(4)}];n=t.pop();)for(var i=0;i<4;++i)(e=n.source[i])&&(e.length?t.push({source:e,target:n.target[i]=new Array(4)}):n.target[i]=s(e));return r},l.add=function(t){var r=+this._x.call(null,t),n=+this._y.call(null,t);return e(this.cover(r,n),r,n,t)},l.addAll=function(t){var r,n,i,a,o=t.length,s=new Array(o),l=new Array(o),c=1/0,u=1/0,h=-1/0,f=-1/0;for(n=0;n<o;++n)isNaN(i=+this._x.call(null,r=t[n]))||isNaN(a=+this._y.call(null,r))||(s[n]=i,l[n]=a,i<c&&(c=i),i>h&&(h=i),a<u&&(u=a),a>f&&(f=a));for(h<c&&(c=this._x0,h=this._x1),f<u&&(u=this._y0,f=this._y1),this.cover(c,u).cover(h,f),n=0;n<o;++n)e(this,s[n],l[n],t[n]);return this},l.cover=function(t,e){if(isNaN(t=+t)||isNaN(e=+e))return this;var r=this._x0,n=this._y0,i=this._x1,a=this._y1;if(isNaN(r))i=(r=Math.floor(t))+1,a=(n=Math.floor(e))+1;else{if(!(r>t||t>i||n>e||e>a))return this;var o,s,l=i-r,c=this._root;switch(s=(e<(n+a)/2)<<1|t<(r+i)/2){case 0:do{(o=new Array(4))[s]=c,c=o}while(a=n+(l*=2),t>(i=r+l)||e>a);break;case 1:do{(o=new Array(4))[s]=c,c=o}while(a=n+(l*=2),(r=i-l)>t||e>a);break;case 2:do{(o=new Array(4))[s]=c,c=o}while(n=a-(l*=2),t>(i=r+l)||n>e);break;case 3:do{(o=new Array(4))[s]=c,c=o}while(n=a-(l*=2),(r=i-l)>t||n>e)}this._root&&this._root.length&&(this._root=c)}return this._x0=r,this._y0=n,this._x1=i,this._y1=a,this},l.data=function(){var t=[];return this.visit(function(e){if(!e.length)do{t.push(e.data)}while(e=e.next)}),t},l.extent=function(t){return arguments.length?this.cover(+t[0][0],+t[0][1]).cover(+t[1][0],+t[1][1]):isNaN(this._x0)?void 0:[[this._x0,this._y0],[this._x1,this._y1]]},l.find=function(t,e,n){var i,a,o,s,l,c,u,h=this._x0,f=this._y0,p=this._x1,d=this._y1,g=[],v=this._root;for(v&&g.push(new r(v,h,f,p,d)),null==n?n=1/0:(h=t-n,f=e-n,p=t+n,d=e+n,n*=n);c=g.pop();)if(!(!(v=c.node)||(a=c.x0)>p||(o=c.y0)>d||(s=c.x1)<h||(l=c.y1)<f))if(v.length){var m=(a+s)/2,y=(o+l)/2;g.push(new r(v[3],m,y,s,l),new r(v[2],a,y,m,l),new r(v[1],m,o,s,y),new r(v[0],a,o,m,y)),(u=(e>=y)<<1|t>=m)&&(c=g[g.length-1],g[g.length-1]=g[g.length-1-u],g[g.length-1-u]=c)}else{var x=t-+this._x.call(null,v.data),b=e-+this._y.call(null,v.data),_=x*x+b*b;if(_<n){var w=Math.sqrt(n=_);h=t-w,f=e-w,p=t+w,d=e+w,i=v.data}}return i},l.remove=function(t){if(isNaN(a=+this._x.call(null,t))||isNaN(o=+this._y.call(null,t)))return this;var e,r,n,i,a,o,s,l,c,u,h,f,p=this._root,d=this._x0,g=this._y0,v=this._x1,m=this._y1;if(!p)return this;if(p.length)for(;;){if((c=a>=(s=(d+v)/2))?d=s:v=s,(u=o>=(l=(g+m)/2))?g=l:m=l,e=p,!(p=p[h=u<<1|c]))return this;if(!p.length)break;(e[h+1&3]||e[h+2&3]||e[h+3&3])&&(r=e,f=h)}for(;p.data!==t;)if(n=p,!(p=p.next))return this;return(i=p.next)&&delete p.next,n?(i?n.next=i:delete n.next,this):e?(i?e[h]=i:delete e[h],(p=e[0]||e[1]||e[2]||e[3])&&p===(e[3]||e[2]||e[1]||e[0])&&!p.length&&(r?r[f]=p:this._root=p),this):(this._root=i,this)},l.removeAll=function(t){for(var e=0,r=t.length;e<r;++e)this.remove(t[e]);return this},l.root=function(){return this._root},l.size=function(){var t=0;return this.visit(function(e){if(!e.length)do{++t}while(e=e.next)}),t},l.visit=function(t){var e,n,i,a,o,s,l=[],c=this._root;for(c&&l.push(new r(c,this._x0,this._y0,this._x1,this._y1));e=l.pop();)if(!t(c=e.node,i=e.x0,a=e.y0,o=e.x1,s=e.y1)&&c.length){var u=(i+o)/2,h=(a+s)/2;(n=c[3])&&l.push(new r(n,u,h,o,s)),(n=c[2])&&l.push(new r(n,i,h,u,s)),(n=c[1])&&l.push(new r(n,u,a,o,h)),(n=c[0])&&l.push(new r(n,i,a,u,h))}return this},l.visitAfter=function(t){var e,n=[],i=[];for(this._root&&n.push(new r(this._root,this._x0,this._y0,this._x1,this._y1));e=n.pop();){var a=e.node;if(a.length){var o,s=e.x0,l=e.y0,c=e.x1,u=e.y1,h=(s+c)/2,f=(l+u)/2;(o=a[0])&&n.push(new r(o,s,l,h,f)),(o=a[1])&&n.push(new r(o,h,l,c,f)),(o=a[2])&&n.push(new r(o,s,f,h,u)),(o=a[3])&&n.push(new r(o,h,f,c,u))}i.push(e)}for(;e=i.pop();)t(e.node,e.x0,e.y0,e.x1,e.y1);return this},l.x=function(t){return arguments.length?(this._x=t,this):this._x},l.y=function(t){return arguments.length?(this._y=t,this):this._y},t.quadtree=a,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],161:[function(t,e,r){var n,i;n=this,i=function(t,e){\"use strict\";function r(t){return function(){return t}}var n=Math.abs,i=Math.atan2,a=Math.cos,o=Math.max,s=Math.min,l=Math.sin,c=Math.sqrt,u=1e-12,h=Math.PI,f=h/2,p=2*h;function d(t){return t>=1?f:t<=-1?-f:Math.asin(t)}function g(t){return t.innerRadius}function v(t){return t.outerRadius}function m(t){return t.startAngle}function y(t){return t.endAngle}function x(t){return t&&t.padAngle}function b(t,e,r,n,i,a,s){var l=t-r,u=e-n,h=(s?a:-a)/c(l*l+u*u),f=h*u,p=-h*l,d=t+f,g=e+p,v=r+f,m=n+p,y=(d+v)/2,x=(g+m)/2,b=v-d,_=m-g,w=b*b+_*_,k=i-a,T=d*m-v*g,A=(_<0?-1:1)*c(o(0,k*k*w-T*T)),M=(T*_-b*A)/w,S=(-T*b-_*A)/w,E=(T*_+b*A)/w,C=(-T*b+_*A)/w,L=M-y,P=S-x,O=E-y,z=C-x;return L*L+P*P>O*O+z*z&&(M=E,S=C),{cx:M,cy:S,x01:-f,y01:-p,x11:M*(i/k-1),y11:S*(i/k-1)}}function _(t){this._context=t}function w(t){return new _(t)}function k(t){return t[0]}function T(t){return t[1]}function A(){var t=k,n=T,i=r(!0),a=null,o=w,s=null;function l(r){var l,c,u,h=r.length,f=!1;for(null==a&&(s=o(u=e.path())),l=0;l<=h;++l)!(l<h&&i(c=r[l],l,r))===f&&((f=!f)?s.lineStart():s.lineEnd()),f&&s.point(+t(c,l,r),+n(c,l,r));if(u)return s=null,u+\"\"||null}return l.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),l):t},l.y=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),l):n},l.defined=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(!!t),l):i},l.curve=function(t){return arguments.length?(o=t,null!=a&&(s=o(a)),l):o},l.context=function(t){return arguments.length?(null==t?a=s=null:s=o(a=t),l):a},l}function M(){var t=k,n=null,i=r(0),a=T,o=r(!0),s=null,l=w,c=null;function u(r){var u,h,f,p,d,g=r.length,v=!1,m=new Array(g),y=new Array(g);for(null==s&&(c=l(d=e.path())),u=0;u<=g;++u){if(!(u<g&&o(p=r[u],u,r))===v)if(v=!v)h=u,c.areaStart(),c.lineStart();else{for(c.lineEnd(),c.lineStart(),f=u-1;f>=h;--f)c.point(m[f],y[f]);c.lineEnd(),c.areaEnd()}v&&(m[u]=+t(p,u,r),y[u]=+i(p,u,r),c.point(n?+n(p,u,r):m[u],a?+a(p,u,r):y[u]))}if(d)return c=null,d+\"\"||null}function h(){return A().defined(o).curve(l).context(s)}return u.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),n=null,u):t},u.x0=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),u):t},u.x1=function(t){return arguments.length?(n=null==t?null:\"function\"==typeof t?t:r(+t),u):n},u.y=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a=null,u):i},u.y0=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),u):i},u.y1=function(t){return arguments.length?(a=null==t?null:\"function\"==typeof t?t:r(+t),u):a},u.lineX0=u.lineY0=function(){return h().x(t).y(i)},u.lineY1=function(){return h().x(t).y(a)},u.lineX1=function(){return h().x(n).y(i)},u.defined=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(!!t),u):o},u.curve=function(t){return arguments.length?(l=t,null!=s&&(c=l(s)),u):l},u.context=function(t){return arguments.length?(null==t?s=c=null:c=l(s=t),u):s},u}function S(t,e){return e<t?-1:e>t?1:e>=t?0:NaN}function E(t){return t}_.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._point=0},lineEnd:function(){(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:this._context.lineTo(t,e)}}};var C=P(w);function L(t){this._curve=t}function P(t){function e(e){return new L(t(e))}return e._curve=t,e}function O(t){var e=t.curve;return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function z(){return O(A().curve(C))}function I(){var t=M().curve(C),e=t.curve,r=t.lineX0,n=t.lineX1,i=t.lineY0,a=t.lineY1;return t.angle=t.x,delete t.x,t.startAngle=t.x0,delete t.x0,t.endAngle=t.x1,delete t.x1,t.radius=t.y,delete t.y,t.innerRadius=t.y0,delete t.y0,t.outerRadius=t.y1,delete t.y1,t.lineStartAngle=function(){return O(r())},delete t.lineX0,t.lineEndAngle=function(){return O(n())},delete t.lineX1,t.lineInnerRadius=function(){return O(i())},delete t.lineY0,t.lineOuterRadius=function(){return O(a())},delete t.lineY1,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function D(t,e){return[(e=+e)*Math.cos(t-=Math.PI/2),e*Math.sin(t)]}L.prototype={areaStart:function(){this._curve.areaStart()},areaEnd:function(){this._curve.areaEnd()},lineStart:function(){this._curve.lineStart()},lineEnd:function(){this._curve.lineEnd()},point:function(t,e){this._curve.point(e*Math.sin(t),e*-Math.cos(t))}};var R=Array.prototype.slice;function F(t){return t.source}function B(t){return t.target}function N(t){var n=F,i=B,a=k,o=T,s=null;function l(){var r,l=R.call(arguments),c=n.apply(this,l),u=i.apply(this,l);if(s||(s=r=e.path()),t(s,+a.apply(this,(l[0]=c,l)),+o.apply(this,l),+a.apply(this,(l[0]=u,l)),+o.apply(this,l)),r)return s=null,r+\"\"||null}return l.source=function(t){return arguments.length?(n=t,l):n},l.target=function(t){return arguments.length?(i=t,l):i},l.x=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),l):a},l.y=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),l):o},l.context=function(t){return arguments.length?(s=null==t?null:t,l):s},l}function j(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e=(e+n)/2,r,e,i,n,i)}function U(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e,r=(r+i)/2,n,r,n,i)}function V(t,e,r,n,i){var a=D(e,r),o=D(e,r=(r+i)/2),s=D(n,r),l=D(n,i);t.moveTo(a[0],a[1]),t.bezierCurveTo(o[0],o[1],s[0],s[1],l[0],l[1])}var q={draw:function(t,e){var r=Math.sqrt(e/h);t.moveTo(r,0),t.arc(0,0,r,0,p)}},H={draw:function(t,e){var r=Math.sqrt(e/5)/2;t.moveTo(-3*r,-r),t.lineTo(-r,-r),t.lineTo(-r,-3*r),t.lineTo(r,-3*r),t.lineTo(r,-r),t.lineTo(3*r,-r),t.lineTo(3*r,r),t.lineTo(r,r),t.lineTo(r,3*r),t.lineTo(-r,3*r),t.lineTo(-r,r),t.lineTo(-3*r,r),t.closePath()}},G=Math.sqrt(1/3),Y=2*G,W={draw:function(t,e){var r=Math.sqrt(e/Y),n=r*G;t.moveTo(0,-r),t.lineTo(n,0),t.lineTo(0,r),t.lineTo(-n,0),t.closePath()}},X=Math.sin(h/10)/Math.sin(7*h/10),Z=Math.sin(p/10)*X,J=-Math.cos(p/10)*X,K={draw:function(t,e){var r=Math.sqrt(.8908130915292852*e),n=Z*r,i=J*r;t.moveTo(0,-r),t.lineTo(n,i);for(var a=1;a<5;++a){var o=p*a/5,s=Math.cos(o),l=Math.sin(o);t.lineTo(l*r,-s*r),t.lineTo(s*n-l*i,l*n+s*i)}t.closePath()}},$={draw:function(t,e){var r=Math.sqrt(e),n=-r/2;t.rect(n,n,r,r)}},Q=Math.sqrt(3),tt={draw:function(t,e){var r=-Math.sqrt(e/(3*Q));t.moveTo(0,2*r),t.lineTo(-Q*r,-r),t.lineTo(Q*r,-r),t.closePath()}},et=-.5,rt=Math.sqrt(3)/2,nt=1/Math.sqrt(12),it=3*(nt/2+1),at={draw:function(t,e){var r=Math.sqrt(e/it),n=r/2,i=r*nt,a=n,o=r*nt+r,s=-a,l=o;t.moveTo(n,i),t.lineTo(a,o),t.lineTo(s,l),t.lineTo(et*n-rt*i,rt*n+et*i),t.lineTo(et*a-rt*o,rt*a+et*o),t.lineTo(et*s-rt*l,rt*s+et*l),t.lineTo(et*n+rt*i,et*i-rt*n),t.lineTo(et*a+rt*o,et*o-rt*a),t.lineTo(et*s+rt*l,et*l-rt*s),t.closePath()}},ot=[q,H,W,$,K,tt,at];function st(){}function lt(t,e,r){t._context.bezierCurveTo((2*t._x0+t._x1)/3,(2*t._y0+t._y1)/3,(t._x0+2*t._x1)/3,(t._y0+2*t._y1)/3,(t._x0+4*t._x1+e)/6,(t._y0+4*t._y1+r)/6)}function ct(t){this._context=t}function ut(t){this._context=t}function ht(t){this._context=t}function ft(t,e){this._basis=new ct(t),this._beta=e}ct.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){switch(this._point){case 3:lt(this,this._x1,this._y1);case 2:this._context.lineTo(this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,this._context.lineTo((5*this._x0+this._x1)/6,(5*this._y0+this._y1)/6);default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ut.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._y0=this._y1=this._y2=this._y3=this._y4=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x2,this._y2),this._context.closePath();break;case 2:this._context.moveTo((this._x2+2*this._x3)/3,(this._y2+2*this._y3)/3),this._context.lineTo((this._x3+2*this._x2)/3,(this._y3+2*this._y2)/3),this._context.closePath();break;case 3:this.point(this._x2,this._y2),this.point(this._x3,this._y3),this.point(this._x4,this._y4)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x2=t,this._y2=e;break;case 1:this._point=2,this._x3=t,this._y3=e;break;case 2:this._point=3,this._x4=t,this._y4=e,this._context.moveTo((this._x0+4*this._x1+t)/6,(this._y0+4*this._y1+e)/6);break;default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ht.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3;var r=(this._x0+4*this._x1+t)/6,n=(this._y0+4*this._y1+e)/6;this._line?this._context.lineTo(r,n):this._context.moveTo(r,n);break;case 3:this._point=4;default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ft.prototype={lineStart:function(){this._x=[],this._y=[],this._basis.lineStart()},lineEnd:function(){var t=this._x,e=this._y,r=t.length-1;if(r>0)for(var n,i=t[0],a=e[0],o=t[r]-i,s=e[r]-a,l=-1;++l<=r;)n=l/r,this._basis.point(this._beta*t[l]+(1-this._beta)*(i+n*o),this._beta*e[l]+(1-this._beta)*(a+n*s));this._x=this._y=null,this._basis.lineEnd()},point:function(t,e){this._x.push(+t),this._y.push(+e)}};var pt=function t(e){function r(t){return 1===e?new ct(t):new ft(t,e)}return r.beta=function(e){return t(+e)},r}(.85);function dt(t,e,r){t._context.bezierCurveTo(t._x1+t._k*(t._x2-t._x0),t._y1+t._k*(t._y2-t._y0),t._x2+t._k*(t._x1-e),t._y2+t._k*(t._y1-r),t._x2,t._y2)}function gt(t,e){this._context=t,this._k=(1-e)/6}gt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:dt(this,this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2,this._x1=t,this._y1=e;break;case 2:this._point=3;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var vt=function t(e){function r(t){return new gt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function mt(t,e){this._context=t,this._k=(1-e)/6}mt.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var yt=function t(e){function r(t){return new mt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function xt(t,e){this._context=t,this._k=(1-e)/6}xt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var bt=function t(e){function r(t){return new xt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function _t(t,e,r){var n=t._x1,i=t._y1,a=t._x2,o=t._y2;if(t._l01_a>u){var s=2*t._l01_2a+3*t._l01_a*t._l12_a+t._l12_2a,l=3*t._l01_a*(t._l01_a+t._l12_a);n=(n*s-t._x0*t._l12_2a+t._x2*t._l01_2a)/l,i=(i*s-t._y0*t._l12_2a+t._y2*t._l01_2a)/l}if(t._l23_a>u){var c=2*t._l23_2a+3*t._l23_a*t._l12_a+t._l12_2a,h=3*t._l23_a*(t._l23_a+t._l12_a);a=(a*c+t._x1*t._l23_2a-e*t._l12_2a)/h,o=(o*c+t._y1*t._l23_2a-r*t._l12_2a)/h}t._context.bezierCurveTo(n,i,a,o,t._x2,t._y2)}function wt(t,e){this._context=t,this._alpha=e}wt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:this.point(this._x2,this._y2)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var kt=function t(e){function r(t){return e?new wt(t,e):new gt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Tt(t,e){this._context=t,this._alpha=e}Tt.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var At=function t(e){function r(t){return e?new Tt(t,e):new mt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Mt(t,e){this._context=t,this._alpha=e}Mt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var St=function t(e){function r(t){return e?new Mt(t,e):new xt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Et(t){this._context=t}function Ct(t){return t<0?-1:1}function Lt(t,e,r){var n=t._x1-t._x0,i=e-t._x1,a=(t._y1-t._y0)/(n||i<0&&-0),o=(r-t._y1)/(i||n<0&&-0),s=(a*i+o*n)/(n+i);return(Ct(a)+Ct(o))*Math.min(Math.abs(a),Math.abs(o),.5*Math.abs(s))||0}function Pt(t,e){var r=t._x1-t._x0;return r?(3*(t._y1-t._y0)/r-e)/2:e}function Ot(t,e,r){var n=t._x0,i=t._y0,a=t._x1,o=t._y1,s=(a-n)/3;t._context.bezierCurveTo(n+s,i+s*e,a-s,o-s*r,a,o)}function zt(t){this._context=t}function It(t){this._context=new Dt(t)}function Dt(t){this._context=t}function Rt(t){this._context=t}function Ft(t){var e,r,n=t.length-1,i=new Array(n),a=new Array(n),o=new Array(n);for(i[0]=0,a[0]=2,o[0]=t[0]+2*t[1],e=1;e<n-1;++e)i[e]=1,a[e]=4,o[e]=4*t[e]+2*t[e+1];for(i[n-1]=2,a[n-1]=7,o[n-1]=8*t[n-1]+t[n],e=1;e<n;++e)r=i[e]/a[e-1],a[e]-=r,o[e]-=r*o[e-1];for(i[n-1]=o[n-1]/a[n-1],e=n-2;e>=0;--e)i[e]=(o[e]-i[e+1])/a[e];for(a[n-1]=(t[n]+i[n-1])/2,e=0;e<n-1;++e)a[e]=2*t[e+1]-i[e+1];return[i,a]}function Bt(t,e){this._context=t,this._t=e}function Nt(t,e){if((i=t.length)>1)for(var r,n,i,a=1,o=t[e[0]],s=o.length;a<i;++a)for(n=o,o=t[e[a]],r=0;r<s;++r)o[r][1]+=o[r][0]=isNaN(n[r][1])?n[r][0]:n[r][1]}function jt(t){for(var e=t.length,r=new Array(e);--e>=0;)r[e]=e;return r}function Ut(t,e){return t[e]}function Vt(t){var e=t.map(qt);return jt(t).sort(function(t,r){return e[t]-e[r]})}function qt(t){for(var e,r=-1,n=0,i=t.length,a=-1/0;++r<i;)(e=+t[r][1])>a&&(a=e,n=r);return n}function Ht(t){var e=t.map(Gt);return jt(t).sort(function(t,r){return e[t]-e[r]})}function Gt(t){for(var e,r=0,n=-1,i=t.length;++n<i;)(e=+t[n][1])&&(r+=e);return r}Et.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._point=0},lineEnd:function(){this._point&&this._context.closePath()},point:function(t,e){t=+t,e=+e,this._point?this._context.lineTo(t,e):(this._point=1,this._context.moveTo(t,e))}},zt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=this._t0=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x1,this._y1);break;case 3:Ot(this,this._t0,Pt(this,this._t0))}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){var r=NaN;if(e=+e,(t=+t)!==this._x1||e!==this._y1){switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,Ot(this,Pt(this,r=Lt(this,t,e)),r);break;default:Ot(this,this._t0,r=Lt(this,t,e))}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e,this._t0=r}}},(It.prototype=Object.create(zt.prototype)).point=function(t,e){zt.prototype.point.call(this,e,t)},Dt.prototype={moveTo:function(t,e){this._context.moveTo(e,t)},closePath:function(){this._context.closePath()},lineTo:function(t,e){this._context.lineTo(e,t)},bezierCurveTo:function(t,e,r,n,i,a){this._context.bezierCurveTo(e,t,n,r,a,i)}},Rt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=[],this._y=[]},lineEnd:function(){var t=this._x,e=this._y,r=t.length;if(r)if(this._line?this._context.lineTo(t[0],e[0]):this._context.moveTo(t[0],e[0]),2===r)this._context.lineTo(t[1],e[1]);else for(var n=Ft(t),i=Ft(e),a=0,o=1;o<r;++a,++o)this._context.bezierCurveTo(n[0][a],i[0][a],n[1][a],i[1][a],t[o],e[o]);(this._line||0!==this._line&&1===r)&&this._context.closePath(),this._line=1-this._line,this._x=this._y=null},point:function(t,e){this._x.push(+t),this._y.push(+e)}},Bt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=this._y=NaN,this._point=0},lineEnd:function(){0<this._t&&this._t<1&&2===this._point&&this._context.lineTo(this._x,this._y),(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line>=0&&(this._t=1-this._t,this._line=1-this._line)},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:if(this._t<=0)this._context.lineTo(this._x,e),this._context.lineTo(t,e);else{var r=this._x*(1-this._t)+t*this._t;this._context.lineTo(r,this._y),this._context.lineTo(r,e)}}this._x=t,this._y=e}},t.arc=function(){var t=g,o=v,_=r(0),w=null,k=m,T=y,A=x,M=null;function S(){var r,g,v,m=+t.apply(this,arguments),y=+o.apply(this,arguments),x=k.apply(this,arguments)-f,S=T.apply(this,arguments)-f,E=n(S-x),C=S>x;if(M||(M=r=e.path()),y<m&&(g=y,y=m,m=g),y>u)if(E>p-u)M.moveTo(y*a(x),y*l(x)),M.arc(0,0,y,x,S,!C),m>u&&(M.moveTo(m*a(S),m*l(S)),M.arc(0,0,m,S,x,C));else{var L,P,O=x,z=S,I=x,D=S,R=E,F=E,B=A.apply(this,arguments)/2,N=B>u&&(w?+w.apply(this,arguments):c(m*m+y*y)),j=s(n(y-m)/2,+_.apply(this,arguments)),U=j,V=j;if(N>u){var q=d(N/m*l(B)),H=d(N/y*l(B));(R-=2*q)>u?(I+=q*=C?1:-1,D-=q):(R=0,I=D=(x+S)/2),(F-=2*H)>u?(O+=H*=C?1:-1,z-=H):(F=0,O=z=(x+S)/2)}var G=y*a(O),Y=y*l(O),W=m*a(D),X=m*l(D);if(j>u){var Z,J=y*a(z),K=y*l(z),$=m*a(I),Q=m*l(I);if(E<h&&(Z=function(t,e,r,n,i,a,o,s){var l=r-t,c=n-e,h=o-i,f=s-a,p=f*l-h*c;if(!(p*p<u))return[t+(p=(h*(e-a)-f*(t-i))/p)*l,e+p*c]}(G,Y,$,Q,J,K,W,X))){var tt=G-Z[0],et=Y-Z[1],rt=J-Z[0],nt=K-Z[1],it=1/l(((v=(tt*rt+et*nt)/(c(tt*tt+et*et)*c(rt*rt+nt*nt)))>1?0:v<-1?h:Math.acos(v))/2),at=c(Z[0]*Z[0]+Z[1]*Z[1]);U=s(j,(m-at)/(it-1)),V=s(j,(y-at)/(it+1))}}F>u?V>u?(L=b($,Q,G,Y,y,V,C),P=b(J,K,W,X,y,V,C),M.moveTo(L.cx+L.x01,L.cy+L.y01),V<j?M.arc(L.cx,L.cy,V,i(L.y01,L.x01),i(P.y01,P.x01),!C):(M.arc(L.cx,L.cy,V,i(L.y01,L.x01),i(L.y11,L.x11),!C),M.arc(0,0,y,i(L.cy+L.y11,L.cx+L.x11),i(P.cy+P.y11,P.cx+P.x11),!C),M.arc(P.cx,P.cy,V,i(P.y11,P.x11),i(P.y01,P.x01),!C))):(M.moveTo(G,Y),M.arc(0,0,y,O,z,!C)):M.moveTo(G,Y),m>u&&R>u?U>u?(L=b(W,X,J,K,m,-U,C),P=b(G,Y,$,Q,m,-U,C),M.lineTo(L.cx+L.x01,L.cy+L.y01),U<j?M.arc(L.cx,L.cy,U,i(L.y01,L.x01),i(P.y01,P.x01),!C):(M.arc(L.cx,L.cy,U,i(L.y01,L.x01),i(L.y11,L.x11),!C),M.arc(0,0,m,i(L.cy+L.y11,L.cx+L.x11),i(P.cy+P.y11,P.cx+P.x11),C),M.arc(P.cx,P.cy,U,i(P.y11,P.x11),i(P.y01,P.x01),!C))):M.arc(0,0,m,D,I,C):M.lineTo(W,X)}else M.moveTo(0,0);if(M.closePath(),r)return M=null,r+\"\"||null}return S.centroid=function(){var e=(+t.apply(this,arguments)+ +o.apply(this,arguments))/2,r=(+k.apply(this,arguments)+ +T.apply(this,arguments))/2-h/2;return[a(r)*e,l(r)*e]},S.innerRadius=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),S):t},S.outerRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),S):o},S.cornerRadius=function(t){return arguments.length?(_=\"function\"==typeof t?t:r(+t),S):_},S.padRadius=function(t){return arguments.length?(w=null==t?null:\"function\"==typeof t?t:r(+t),S):w},S.startAngle=function(t){return arguments.length?(k=\"function\"==typeof t?t:r(+t),S):k},S.endAngle=function(t){return arguments.length?(T=\"function\"==typeof t?t:r(+t),S):T},S.padAngle=function(t){return arguments.length?(A=\"function\"==typeof t?t:r(+t),S):A},S.context=function(t){return arguments.length?(M=null==t?null:t,S):M},S},t.area=M,t.line=A,t.pie=function(){var t=E,e=S,n=null,i=r(0),a=r(p),o=r(0);function s(r){var s,l,c,u,h,f=r.length,d=0,g=new Array(f),v=new Array(f),m=+i.apply(this,arguments),y=Math.min(p,Math.max(-p,a.apply(this,arguments)-m)),x=Math.min(Math.abs(y)/f,o.apply(this,arguments)),b=x*(y<0?-1:1);for(s=0;s<f;++s)(h=v[g[s]=s]=+t(r[s],s,r))>0&&(d+=h);for(null!=e?g.sort(function(t,r){return e(v[t],v[r])}):null!=n&&g.sort(function(t,e){return n(r[t],r[e])}),s=0,c=d?(y-f*b)/d:0;s<f;++s,m=u)l=g[s],u=m+((h=v[l])>0?h*c:0)+b,v[l]={data:r[l],index:s,value:h,startAngle:m,endAngle:u,padAngle:x};return v}return s.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),s):t},s.sortValues=function(t){return arguments.length?(e=t,n=null,s):e},s.sort=function(t){return arguments.length?(n=t,e=null,s):n},s.startAngle=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),s):i},s.endAngle=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),s):a},s.padAngle=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),s):o},s},t.areaRadial=I,t.radialArea=I,t.lineRadial=z,t.radialLine=z,t.pointRadial=D,t.linkHorizontal=function(){return N(j)},t.linkVertical=function(){return N(U)},t.linkRadial=function(){var t=N(V);return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t},t.symbol=function(){var t=r(q),n=r(64),i=null;function a(){var r;if(i||(i=r=e.path()),t.apply(this,arguments).draw(i,+n.apply(this,arguments)),r)return i=null,r+\"\"||null}return a.type=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(e),a):t},a.size=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),a):n},a.context=function(t){return arguments.length?(i=null==t?null:t,a):i},a},t.symbols=ot,t.symbolCircle=q,t.symbolCross=H,t.symbolDiamond=W,t.symbolSquare=$,t.symbolStar=K,t.symbolTriangle=tt,t.symbolWye=at,t.curveBasisClosed=function(t){return new ut(t)},t.curveBasisOpen=function(t){return new ht(t)},t.curveBasis=function(t){return new ct(t)},t.curveBundle=pt,t.curveCardinalClosed=yt,t.curveCardinalOpen=bt,t.curveCardinal=vt,t.curveCatmullRomClosed=At,t.curveCatmullRomOpen=St,t.curveCatmullRom=kt,t.curveLinearClosed=function(t){return new Et(t)},t.curveLinear=w,t.curveMonotoneX=function(t){return new zt(t)},t.curveMonotoneY=function(t){return new It(t)},t.curveNatural=function(t){return new Rt(t)},t.curveStep=function(t){return new Bt(t,.5)},t.curveStepAfter=function(t){return new Bt(t,1)},t.curveStepBefore=function(t){return new Bt(t,0)},t.stack=function(){var t=r([]),e=jt,n=Nt,i=Ut;function a(r){var a,o,s=t.apply(this,arguments),l=r.length,c=s.length,u=new Array(c);for(a=0;a<c;++a){for(var h,f=s[a],p=u[a]=new Array(l),d=0;d<l;++d)p[d]=h=[0,+i(r[d],f,d,r)],h.data=r[d];p.key=f}for(a=0,o=e(u);a<c;++a)u[o[a]].index=a;return n(u,o),u}return a.keys=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(R.call(e)),a):t},a.value=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a):i},a.order=function(t){return arguments.length?(e=null==t?jt:\"function\"==typeof t?t:r(R.call(t)),a):e},a.offset=function(t){return arguments.length?(n=null==t?Nt:t,a):n},a},t.stackOffsetExpand=function(t,e){if((n=t.length)>0){for(var r,n,i,a=0,o=t[0].length;a<o;++a){for(i=r=0;r<n;++r)i+=t[r][a][1]||0;if(i)for(r=0;r<n;++r)t[r][a][1]/=i}Nt(t,e)}},t.stackOffsetDiverging=function(t,e){if((s=t.length)>1)for(var r,n,i,a,o,s,l=0,c=t[e[0]].length;l<c;++l)for(a=o=0,r=0;r<s;++r)(i=(n=t[e[r]][l])[1]-n[0])>=0?(n[0]=a,n[1]=a+=i):i<0?(n[1]=o,n[0]=o+=i):n[0]=a},t.stackOffsetNone=Nt,t.stackOffsetSilhouette=function(t,e){if((r=t.length)>0){for(var r,n=0,i=t[e[0]],a=i.length;n<a;++n){for(var o=0,s=0;o<r;++o)s+=t[o][n][1]||0;i[n][1]+=i[n][0]=-s/2}Nt(t,e)}},t.stackOffsetWiggle=function(t,e){if((i=t.length)>0&&(n=(r=t[e[0]]).length)>0){for(var r,n,i,a=0,o=1;o<n;++o){for(var s=0,l=0,c=0;s<i;++s){for(var u=t[e[s]],h=u[o][1]||0,f=(h-(u[o-1][1]||0))/2,p=0;p<s;++p){var d=t[e[p]];f+=(d[o][1]||0)-(d[o-1][1]||0)}l+=h,c+=f*h}r[o-1][1]+=r[o-1][0]=a,l&&(a-=c/l)}r[o-1][1]+=r[o-1][0]=a,Nt(t,e)}},t.stackOrderAppearance=Vt,t.stackOrderAscending=Ht,t.stackOrderDescending=function(t){return Ht(t).reverse()},t.stackOrderInsideOut=function(t){var e,r,n=t.length,i=t.map(Gt),a=Vt(t),o=0,s=0,l=[],c=[];for(e=0;e<n;++e)r=a[e],o<s?(o+=i[r],l.push(r)):(s+=i[r],c.push(r));return c.reverse().concat(l)},t.stackOrderNone=jt,t.stackOrderReverse=function(t){return jt(t).reverse()},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-path\")):i(n.d3=n.d3||{},n.d3)},{\"d3-path\":159}],162:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e,r,n=0,i=0,a=0,o=1e3,s=0,l=0,c=0,u=\"object\"==typeof performance&&performance.now?performance:Date,h=\"object\"==typeof window&&window.requestAnimationFrame?window.requestAnimationFrame.bind(window):function(t){setTimeout(t,17)};function f(){return l||(h(p),l=u.now()+c)}function p(){l=0}function d(){this._call=this._time=this._next=null}function g(t,e,r){var n=new d;return n.restart(t,e,r),n}function v(){f(),++n;for(var t,r=e;r;)(t=l-r._time)>=0&&r._call.call(null,t),r=r._next;--n}function m(){l=(s=u.now())+c,n=i=0;try{v()}finally{n=0,function(){var t,n,i=e,a=1/0;for(;i;)i._call?(a>i._time&&(a=i._time),t=i,i=i._next):(n=i._next,i._next=null,i=t?t._next=n:e=n);r=t,x(a)}(),l=0}}function y(){var t=u.now(),e=t-s;e>o&&(c-=e,s=t)}function x(t){n||(i&&(i=clearTimeout(i)),t-l>24?(t<1/0&&(i=setTimeout(m,t-u.now()-c)),a&&(a=clearInterval(a))):(a||(s=u.now(),a=setInterval(y,o)),n=1,h(m)))}d.prototype=g.prototype={constructor:d,restart:function(t,n,i){if(\"function\"!=typeof t)throw new TypeError(\"callback is not a function\");i=(null==i?f():+i)+(null==n?0:+n),this._next||r===this||(r?r._next=this:e=this,r=this),this._call=t,this._time=i,x()},stop:function(){this._call&&(this._call=null,this._time=1/0,x())}};t.now=f,t.timer=g,t.timerFlush=v,t.timeout=function(t,e,r){var n=new d;return e=null==e?0:+e,n.restart(function(r){n.stop(),t(r+e)},e,r),n},t.interval=function(t,e,r){var n=new d,i=e;return null==e?(n.restart(t,e,r),n):(e=+e,r=null==r?f():+r,n.restart(function a(o){o+=i,n.restart(a,i+=e,r),t(o)},e,r),n)},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],163:[function(t,e,r){!function(){var t={version:\"3.5.17\"},r=[].slice,n=function(t){return r.call(t)},i=this.document;function a(t){return t&&(t.ownerDocument||t.document||t).documentElement}function o(t){return t&&(t.ownerDocument&&t.ownerDocument.defaultView||t.document&&t||t.defaultView)}if(i)try{n(i.documentElement.childNodes)[0].nodeType}catch(t){n=function(t){for(var e=t.length,r=new Array(e);e--;)r[e]=t[e];return r}}if(Date.now||(Date.now=function(){return+new Date}),i)try{i.createElement(\"DIV\").style.setProperty(\"opacity\",0,\"\")}catch(t){var s=this.Element.prototype,l=s.setAttribute,c=s.setAttributeNS,u=this.CSSStyleDeclaration.prototype,h=u.setProperty;s.setAttribute=function(t,e){l.call(this,t,e+\"\")},s.setAttributeNS=function(t,e,r){c.call(this,t,e,r+\"\")},u.setProperty=function(t,e,r){h.call(this,t,e+\"\",r)}}function f(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function p(t){return null===t?NaN:+t}function d(t){return!isNaN(t)}function g(t){return{left:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}t.ascending=f,t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.min=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&r>n&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&r>n&&(r=n)}return r},t.max=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&n>r&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&n>r&&(r=n)}return r},t.extent=function(t,e){var r,n,i,a=-1,o=t.length;if(1===arguments.length){for(;++a<o;)if(null!=(n=t[a])&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=t[a])&&(r>n&&(r=n),i<n&&(i=n))}else{for(;++a<o;)if(null!=(n=e.call(t,t[a],a))&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=e.call(t,t[a],a))&&(r>n&&(r=n),i<n&&(i=n))}return[r,i]},t.sum=function(t,e){var r,n=0,i=t.length,a=-1;if(1===arguments.length)for(;++a<i;)d(r=+t[a])&&(n+=r);else for(;++a<i;)d(r=+e.call(t,t[a],a))&&(n+=r);return n},t.mean=function(t,e){var r,n=0,i=t.length,a=-1,o=i;if(1===arguments.length)for(;++a<i;)d(r=p(t[a]))?n+=r:--o;else for(;++a<i;)d(r=p(e.call(t,t[a],a)))?n+=r:--o;if(o)return n/o},t.quantile=function(t,e){var r=(t.length-1)*e+1,n=Math.floor(r),i=+t[n-1],a=r-n;return a?i+a*(t[n]-i):i},t.median=function(e,r){var n,i=[],a=e.length,o=-1;if(1===arguments.length)for(;++o<a;)d(n=p(e[o]))&&i.push(n);else for(;++o<a;)d(n=p(r.call(e,e[o],o)))&&i.push(n);if(i.length)return t.quantile(i.sort(f),.5)},t.variance=function(t,e){var r,n,i=t.length,a=0,o=0,s=-1,l=0;if(1===arguments.length)for(;++s<i;)d(r=p(t[s]))&&(o+=(n=r-a)*(r-(a+=n/++l)));else for(;++s<i;)d(r=p(e.call(t,t[s],s)))&&(o+=(n=r-a)*(r-(a+=n/++l)));if(l>1)return o/(l-1)},t.deviation=function(){var e=t.variance.apply(this,arguments);return e?Math.sqrt(e):e};var v=g(f);function m(t){return t.length}t.bisectLeft=v.left,t.bisect=t.bisectRight=v.right,t.bisector=function(t){return g(1===t.length?function(e,r){return f(t(e),r)}:t)},t.shuffle=function(t,e,r){(a=arguments.length)<3&&(r=t.length,a<2&&(e=0));for(var n,i,a=r-e;a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.pairs=function(t){for(var e=0,r=t.length-1,n=t[0],i=new Array(r<0?0:r);e<r;)i[e]=[n,n=t[++e]];return i},t.transpose=function(e){if(!(a=e.length))return[];for(var r=-1,n=t.min(e,m),i=new Array(n);++r<n;)for(var a,o=-1,s=i[r]=new Array(a);++o<a;)s[o]=e[o][r];return i},t.zip=function(){return t.transpose(arguments)},t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r};var y=Math.abs;function x(t,e){for(var r in e)Object.defineProperty(t.prototype,r,{value:e[r],enumerable:!1})}function b(){this._=Object.create(null)}t.range=function(t,e,r){if(arguments.length<3&&(r=1,arguments.length<2&&(e=t,t=0)),(e-t)/r==1/0)throw new Error(\"infinite range\");var n,i=[],a=function(t){var e=1;for(;t*e%1;)e*=10;return e}(y(r)),o=-1;if(t*=a,e*=a,(r*=a)<0)for(;(n=t+r*++o)>e;)i.push(n/a);else for(;(n=t+r*++o)<e;)i.push(n/a);return i},t.map=function(t,e){var r=new b;if(t instanceof b)t.forEach(function(t,e){r.set(t,e)});else if(Array.isArray(t)){var n,i=-1,a=t.length;if(1===arguments.length)for(;++i<a;)r.set(i,t[i]);else for(;++i<a;)r.set(e.call(t,n=t[i],i),n)}else for(var o in t)r.set(o,t[o]);return r};var _=\"__proto__\",w=\"\\0\";function k(t){return(t+=\"\")===_||t[0]===w?w+t:t}function T(t){return(t+=\"\")[0]===w?t.slice(1):t}function A(t){return k(t)in this._}function M(t){return(t=k(t))in this._&&delete this._[t]}function S(){var t=[];for(var e in this._)t.push(T(e));return t}function E(){var t=0;for(var e in this._)++t;return t}function C(){for(var t in this._)return!1;return!0}function L(){this._=Object.create(null)}function P(t){return t}function O(t,e,r){return function(){var n=r.apply(e,arguments);return n===e?t:n}}function z(t,e){if(e in t)return e;e=e.charAt(0).toUpperCase()+e.slice(1);for(var r=0,n=I.length;r<n;++r){var i=I[r]+e;if(i in t)return i}}x(b,{has:A,get:function(t){return this._[k(t)]},set:function(t,e){return this._[k(t)]=e},remove:M,keys:S,values:function(){var t=[];for(var e in this._)t.push(this._[e]);return t},entries:function(){var t=[];for(var e in this._)t.push({key:T(e),value:this._[e]});return t},size:E,empty:C,forEach:function(t){for(var e in this._)t.call(this,T(e),this._[e])}}),t.nest=function(){var e,r,n={},i=[],a=[];function o(t,a,s){if(s>=i.length)return r?r.call(n,a):e?a.sort(e):a;for(var l,c,u,h,f=-1,p=a.length,d=i[s++],g=new b;++f<p;)(h=g.get(l=d(c=a[f])))?h.push(c):g.set(l,[c]);return t?(c=t(),u=function(e,r){c.set(e,o(t,r,s))}):(c={},u=function(e,r){c[e]=o(t,r,s)}),g.forEach(u),c}return n.map=function(t,e){return o(e,t,0)},n.entries=function(e){return function t(e,r){if(r>=i.length)return e;var n=[],o=a[r++];return e.forEach(function(e,i){n.push({key:e,values:t(i,r)})}),o?n.sort(function(t,e){return o(t.key,e.key)}):n}(o(t.map,e,0),0)},n.key=function(t){return i.push(t),n},n.sortKeys=function(t){return a[i.length-1]=t,n},n.sortValues=function(t){return e=t,n},n.rollup=function(t){return r=t,n},n},t.set=function(t){var e=new L;if(t)for(var r=0,n=t.length;r<n;++r)e.add(t[r]);return e},x(L,{has:A,add:function(t){return this._[k(t+=\"\")]=!0,t},remove:M,values:S,size:E,empty:C,forEach:function(t){for(var e in this._)t.call(this,T(e))}}),t.behavior={},t.rebind=function(t,e){for(var r,n=1,i=arguments.length;++n<i;)t[r=arguments[n]]=O(t,e,e[r]);return t};var I=[\"webkit\",\"ms\",\"moz\",\"Moz\",\"o\",\"O\"];function D(){}function R(){}function F(t){var e=[],r=new b;function n(){for(var r,n=e,i=-1,a=n.length;++i<a;)(r=n[i].on)&&r.apply(this,arguments);return t}return n.on=function(n,i){var a,o=r.get(n);return arguments.length<2?o&&o.on:(o&&(o.on=null,e=e.slice(0,a=e.indexOf(o)).concat(e.slice(a+1)),r.remove(n)),i&&e.push(r.set(n,{on:i})),t)},n}function B(){t.event.preventDefault()}function N(){for(var e,r=t.event;e=r.sourceEvent;)r=e;return r}function j(e){for(var r=new R,n=0,i=arguments.length;++n<i;)r[arguments[n]]=F(r);return r.of=function(n,i){return function(a){try{var o=a.sourceEvent=t.event;a.target=e,t.event=a,r[a.type].apply(n,i)}finally{t.event=o}}},r}t.dispatch=function(){for(var t=new R,e=-1,r=arguments.length;++e<r;)t[arguments[e]]=F(t);return t},R.prototype.on=function(t,e){var r=t.indexOf(\".\"),n=\"\";if(r>=0&&(n=t.slice(r+1),t=t.slice(0,r)),t)return arguments.length<2?this[t].on(n):this[t].on(n,e);if(2===arguments.length){if(null==e)for(t in this)this.hasOwnProperty(t)&&this[t].on(n,null);return this}},t.event=null,t.requote=function(t){return t.replace(U,\"\\\\$&\")};var U=/[\\\\\\^\\$\\*\\+\\?\\|\\[\\]\\(\\)\\.\\{\\}]/g,V={}.__proto__?function(t,e){t.__proto__=e}:function(t,e){for(var r in e)t[r]=e[r]};function q(t){return V(t,W),t}var H=function(t,e){return e.querySelector(t)},G=function(t,e){return e.querySelectorAll(t)},Y=function(t,e){var r=t.matches||t[z(t,\"matchesSelector\")];return(Y=function(t,e){return r.call(t,e)})(t,e)};\"function\"==typeof Sizzle&&(H=function(t,e){return Sizzle(t,e)[0]||null},G=Sizzle,Y=Sizzle.matchesSelector),t.selection=function(){return t.select(i.documentElement)};var W=t.selection.prototype=[];function X(t){return\"function\"==typeof t?t:function(){return H(t,this)}}function Z(t){return\"function\"==typeof t?t:function(){return G(t,this)}}W.select=function(t){var e,r,n,i,a=[];t=X(t);for(var o=-1,s=this.length;++o<s;){a.push(e=[]),e.parentNode=(n=this[o]).parentNode;for(var l=-1,c=n.length;++l<c;)(i=n[l])?(e.push(r=t.call(i,i.__data__,l,o)),r&&\"__data__\"in i&&(r.__data__=i.__data__)):e.push(null)}return q(a)},W.selectAll=function(t){var e,r,i=[];t=Z(t);for(var a=-1,o=this.length;++a<o;)for(var s=this[a],l=-1,c=s.length;++l<c;)(r=s[l])&&(i.push(e=n(t.call(r,r.__data__,l,a))),e.parentNode=r);return q(i)};var J=\"http://www.w3.org/1999/xhtml\",K={svg:\"http://www.w3.org/2000/svg\",xhtml:J,xlink:\"http://www.w3.org/1999/xlink\",xml:\"http://www.w3.org/XML/1998/namespace\",xmlns:\"http://www.w3.org/2000/xmlns/\"};function $(e,r){return e=t.ns.qualify(e),null==r?e.local?function(){this.removeAttributeNS(e.space,e.local)}:function(){this.removeAttribute(e)}:\"function\"==typeof r?e.local?function(){var t=r.apply(this,arguments);null==t?this.removeAttributeNS(e.space,e.local):this.setAttributeNS(e.space,e.local,t)}:function(){var t=r.apply(this,arguments);null==t?this.removeAttribute(e):this.setAttribute(e,t)}:e.local?function(){this.setAttributeNS(e.space,e.local,r)}:function(){this.setAttribute(e,r)}}function Q(t){return t.trim().replace(/\\s+/g,\" \")}function tt(e){return new RegExp(\"(?:^|\\\\s+)\"+t.requote(e)+\"(?:\\\\s+|$)\",\"g\")}function et(t){return(t+\"\").trim().split(/^|\\s+/)}function rt(t,e){var r=(t=et(t).map(nt)).length;return\"function\"==typeof e?function(){for(var n=-1,i=e.apply(this,arguments);++n<r;)t[n](this,i)}:function(){for(var n=-1;++n<r;)t[n](this,e)}}function nt(t){var e=tt(t);return function(r,n){if(i=r.classList)return n?i.add(t):i.remove(t);var i=r.getAttribute(\"class\")||\"\";n?(e.lastIndex=0,e.test(i)||r.setAttribute(\"class\",Q(i+\" \"+t))):r.setAttribute(\"class\",Q(i.replace(e,\" \")))}}function it(t,e,r){return null==e?function(){this.style.removeProperty(t)}:\"function\"==typeof e?function(){var n=e.apply(this,arguments);null==n?this.style.removeProperty(t):this.style.setProperty(t,n,r)}:function(){this.style.setProperty(t,e,r)}}function at(t,e){return null==e?function(){delete this[t]}:\"function\"==typeof e?function(){var r=e.apply(this,arguments);null==r?delete this[t]:this[t]=r}:function(){this[t]=e}}function ot(e){return\"function\"==typeof e?e:(e=t.ns.qualify(e)).local?function(){return this.ownerDocument.createElementNS(e.space,e.local)}:function(){var t=this.ownerDocument,r=this.namespaceURI;return r===J&&t.documentElement.namespaceURI===J?t.createElement(e):t.createElementNS(r,e)}}function st(){var t=this.parentNode;t&&t.removeChild(this)}function lt(t){return{__data__:t}}function ct(t){return function(){return Y(this,t)}}function ut(t,e){for(var r=0,n=t.length;r<n;r++)for(var i,a=t[r],o=0,s=a.length;o<s;o++)(i=a[o])&&e(i,o,r);return t}function ht(t){return V(t,ft),t}t.ns={prefix:K,qualify:function(t){var e=t.indexOf(\":\"),r=t;return e>=0&&\"xmlns\"!==(r=t.slice(0,e))&&(t=t.slice(e+1)),K.hasOwnProperty(r)?{space:K[r],local:t}:t}},W.attr=function(e,r){if(arguments.length<2){if(\"string\"==typeof e){var n=this.node();return(e=t.ns.qualify(e)).local?n.getAttributeNS(e.space,e.local):n.getAttribute(e)}for(r in e)this.each($(r,e[r]));return this}return this.each($(e,r))},W.classed=function(t,e){if(arguments.length<2){if(\"string\"==typeof t){var r=this.node(),n=(t=et(t)).length,i=-1;if(e=r.classList){for(;++i<n;)if(!e.contains(t[i]))return!1}else for(e=r.getAttribute(\"class\");++i<n;)if(!tt(t[i]).test(e))return!1;return!0}for(e in t)this.each(rt(e,t[e]));return this}return this.each(rt(t,e))},W.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.each(it(r,t[r],e));return this}if(n<2){var i=this.node();return o(i).getComputedStyle(i,null).getPropertyValue(t)}r=\"\"}return this.each(it(t,e,r))},W.property=function(t,e){if(arguments.length<2){if(\"string\"==typeof t)return this.node()[t];for(e in t)this.each(at(e,t[e]));return this}return this.each(at(t,e))},W.text=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.textContent=null==e?\"\":e}:null==t?function(){this.textContent=\"\"}:function(){this.textContent=t}):this.node().textContent},W.html=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.innerHTML=null==e?\"\":e}:null==t?function(){this.innerHTML=\"\"}:function(){this.innerHTML=t}):this.node().innerHTML},W.append=function(t){return t=ot(t),this.select(function(){return this.appendChild(t.apply(this,arguments))})},W.insert=function(t,e){return t=ot(t),e=X(e),this.select(function(){return this.insertBefore(t.apply(this,arguments),e.apply(this,arguments)||null)})},W.remove=function(){return this.each(st)},W.data=function(t,e){var r,n,i=-1,a=this.length;if(!arguments.length){for(t=new Array(a=(r=this[0]).length);++i<a;)(n=r[i])&&(t[i]=n.__data__);return t}function o(t,r){var n,i,a,o=t.length,u=r.length,h=Math.min(o,u),f=new Array(u),p=new Array(u),d=new Array(o);if(e){var g,v=new b,m=new Array(o);for(n=-1;++n<o;)(i=t[n])&&(v.has(g=e.call(i,i.__data__,n))?d[n]=i:v.set(g,i),m[n]=g);for(n=-1;++n<u;)(i=v.get(g=e.call(r,a=r[n],n)))?!0!==i&&(f[n]=i,i.__data__=a):p[n]=lt(a),v.set(g,!0);for(n=-1;++n<o;)n in m&&!0!==v.get(m[n])&&(d[n]=t[n])}else{for(n=-1;++n<h;)i=t[n],a=r[n],i?(i.__data__=a,f[n]=i):p[n]=lt(a);for(;n<u;++n)p[n]=lt(r[n]);for(;n<o;++n)d[n]=t[n]}p.update=f,p.parentNode=f.parentNode=d.parentNode=t.parentNode,s.push(p),l.push(f),c.push(d)}var s=ht([]),l=q([]),c=q([]);if(\"function\"==typeof t)for(;++i<a;)o(r=this[i],t.call(r,r.parentNode.__data__,i));else for(;++i<a;)o(r=this[i],t);return l.enter=function(){return s},l.exit=function(){return c},l},W.datum=function(t){return arguments.length?this.property(\"__data__\",t):this.property(\"__data__\")},W.filter=function(t){var e,r,n,i=[];\"function\"!=typeof t&&(t=ct(t));for(var a=0,o=this.length;a<o;a++){i.push(e=[]),e.parentNode=(r=this[a]).parentNode;for(var s=0,l=r.length;s<l;s++)(n=r[s])&&t.call(n,n.__data__,s,a)&&e.push(n)}return q(i)},W.order=function(){for(var t=-1,e=this.length;++t<e;)for(var r,n=this[t],i=n.length-1,a=n[i];--i>=0;)(r=n[i])&&(a&&a!==r.nextSibling&&a.parentNode.insertBefore(r,a),a=r);return this},W.sort=function(t){t=function(t){arguments.length||(t=f);return function(e,r){return e&&r?t(e.__data__,r.__data__):!e-!r}}.apply(this,arguments);for(var e=-1,r=this.length;++e<r;)this[e].sort(t);return this.order()},W.each=function(t){return ut(this,function(e,r,n){t.call(e,e.__data__,r,n)})},W.call=function(t){var e=n(arguments);return t.apply(e[0]=this,e),this},W.empty=function(){return!this.node()},W.node=function(){for(var t=0,e=this.length;t<e;t++)for(var r=this[t],n=0,i=r.length;n<i;n++){var a=r[n];if(a)return a}return null},W.size=function(){var t=0;return ut(this,function(){++t}),t};var ft=[];function pt(e,r,i){var a=\"__on\"+e,o=e.indexOf(\".\"),s=gt;o>0&&(e=e.slice(0,o));var l=dt.get(e);function c(){var t=this[a];t&&(this.removeEventListener(e,t,t.$),delete this[a])}return l&&(e=l,s=vt),o?r?function(){var t=s(r,n(arguments));c.call(this),this.addEventListener(e,this[a]=t,t.$=i),t._=r}:c:r?D:function(){var r,n=new RegExp(\"^__on([^.]+)\"+t.requote(e)+\"$\");for(var i in this)if(r=i.match(n)){var a=this[i];this.removeEventListener(r[1],a,a.$),delete this[i]}}}t.selection.enter=ht,t.selection.enter.prototype=ft,ft.append=W.append,ft.empty=W.empty,ft.node=W.node,ft.call=W.call,ft.size=W.size,ft.select=function(t){for(var e,r,n,i,a,o=[],s=-1,l=this.length;++s<l;){n=(i=this[s]).update,o.push(e=[]),e.parentNode=i.parentNode;for(var c=-1,u=i.length;++c<u;)(a=i[c])?(e.push(n[c]=r=t.call(i.parentNode,a.__data__,c,s)),r.__data__=a.__data__):e.push(null)}return q(o)},ft.insert=function(t,e){var r,n,i;return arguments.length<2&&(r=this,e=function(t,e,a){var o,s=r[a].update,l=s.length;for(a!=i&&(i=a,n=0),e>=n&&(n=e+1);!(o=s[n])&&++n<l;);return o}),W.insert.call(this,t,e)},t.select=function(t){var e;return\"string\"==typeof t?(e=[H(t,i)]).parentNode=i.documentElement:(e=[t]).parentNode=a(t),q([e])},t.selectAll=function(t){var e;return\"string\"==typeof t?(e=n(G(t,i))).parentNode=i.documentElement:(e=n(t)).parentNode=null,q([e])},W.on=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=!1),t)this.each(pt(r,t[r],e));return this}if(n<2)return(n=this.node()[\"__on\"+t])&&n._;r=!1}return this.each(pt(t,e,r))};var dt=t.map({mouseenter:\"mouseover\",mouseleave:\"mouseout\"});function gt(e,r){return function(n){var i=t.event;t.event=n,r[0]=this.__data__;try{e.apply(this,r)}finally{t.event=i}}}function vt(t,e){var r=gt(t,e);return function(t){var e=t.relatedTarget;e&&(e===this||8&e.compareDocumentPosition(this))||r.call(this,t)}}i&&dt.forEach(function(t){\"on\"+t in i&&dt.remove(t)});var mt,yt=0;function xt(e){var r=\".dragsuppress-\"+ ++yt,n=\"click\"+r,i=t.select(o(e)).on(\"touchmove\"+r,B).on(\"dragstart\"+r,B).on(\"selectstart\"+r,B);if(null==mt&&(mt=!(\"onselectstart\"in e)&&z(e.style,\"userSelect\")),mt){var s=a(e).style,l=s[mt];s[mt]=\"none\"}return function(t){if(i.on(r,null),mt&&(s[mt]=l),t){var e=function(){i.on(n,null)};i.on(n,function(){B(),e()},!0),setTimeout(e,0)}}}t.mouse=function(t){return _t(t,N())};var bt=this.navigator&&/WebKit/.test(this.navigator.userAgent)?-1:0;function _t(e,r){r.changedTouches&&(r=r.changedTouches[0]);var n=e.ownerSVGElement||e;if(n.createSVGPoint){var i=n.createSVGPoint();if(bt<0){var a=o(e);if(a.scrollX||a.scrollY){var s=(n=t.select(\"body\").append(\"svg\").style({position:\"absolute\",top:0,left:0,margin:0,padding:0,border:\"none\"},\"important\"))[0][0].getScreenCTM();bt=!(s.f||s.e),n.remove()}}return bt?(i.x=r.pageX,i.y=r.pageY):(i.x=r.clientX,i.y=r.clientY),[(i=i.matrixTransform(e.getScreenCTM().inverse())).x,i.y]}var l=e.getBoundingClientRect();return[r.clientX-l.left-e.clientLeft,r.clientY-l.top-e.clientTop]}function wt(){return t.event.changedTouches[0].identifier}t.touch=function(t,e,r){if(arguments.length<3&&(r=e,e=N().changedTouches),e)for(var n,i=0,a=e.length;i<a;++i)if((n=e[i]).identifier===r)return _t(t,n)},t.behavior.drag=function(){var e=j(a,\"drag\",\"dragstart\",\"dragend\"),r=null,n=s(D,t.mouse,o,\"mousemove\",\"mouseup\"),i=s(wt,t.touch,P,\"touchmove\",\"touchend\");function a(){this.on(\"mousedown.drag\",n).on(\"touchstart.drag\",i)}function s(n,i,a,o,s){return function(){var l,c=t.event.target.correspondingElement||t.event.target,u=this.parentNode,h=e.of(this,arguments),f=0,p=n(),d=\".drag\"+(null==p?\"\":\"-\"+p),g=t.select(a(c)).on(o+d,function(){var t,e,r=i(u,p);if(!r)return;t=r[0]-m[0],e=r[1]-m[1],f|=t|e,m=r,h({type:\"drag\",x:r[0]+l[0],y:r[1]+l[1],dx:t,dy:e})}).on(s+d,function(){if(!i(u,p))return;g.on(o+d,null).on(s+d,null),v(f),h({type:\"dragend\"})}),v=xt(c),m=i(u,p);l=r?[(l=r.apply(this,arguments)).x-m[0],l.y-m[1]]:[0,0],h({type:\"dragstart\"})}}return a.origin=function(t){return arguments.length?(r=t,a):r},t.rebind(a,e,\"on\")},t.touches=function(t,e){return arguments.length<2&&(e=N().touches),e?n(e).map(function(e){var r=_t(t,e);return r.identifier=e.identifier,r}):[]};var kt=1e-6,Tt=kt*kt,At=Math.PI,Mt=2*At,St=Mt-kt,Et=At/2,Ct=At/180,Lt=180/At;function Pt(t){return t>0?1:t<0?-1:0}function Ot(t,e,r){return(e[0]-t[0])*(r[1]-t[1])-(e[1]-t[1])*(r[0]-t[0])}function zt(t){return t>1?0:t<-1?At:Math.acos(t)}function It(t){return t>1?Et:t<-1?-Et:Math.asin(t)}function Dt(t){return((t=Math.exp(t))+1/t)/2}function Rt(t){return(t=Math.sin(t/2))*t}var Ft=Math.SQRT2;t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,h=l-a,f=u*u+h*h;if(f<Tt)n=Math.log(c/o)/Ft,r=function(t){return[i+t*u,a+t*h,o*Math.exp(Ft*t*n)]};else{var p=Math.sqrt(f),d=(c*c-o*o+4*f)/(2*o*2*p),g=(c*c-o*o-4*f)/(2*c*2*p),v=Math.log(Math.sqrt(d*d+1)-d),m=Math.log(Math.sqrt(g*g+1)-g);n=(m-v)/Ft,r=function(t){var e,r=t*n,s=Dt(v),l=o/(2*p)*(s*(e=Ft*r+v,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(v));return[i+l*u,a+l*h,o*s/Dt(Ft*r+v)]}}return r.duration=1e3*n,r},t.behavior.zoom=function(){var e,r,n,a,s,l,c,u,h,f={x:0,y:0,k:1},p=[960,500],d=jt,g=250,v=0,m=\"mousedown.zoom\",y=\"mousemove.zoom\",x=\"mouseup.zoom\",b=\"touchstart.zoom\",_=j(w,\"zoomstart\",\"zoom\",\"zoomend\");function w(t){t.on(m,P).on(Nt+\".zoom\",z).on(\"dblclick.zoom\",I).on(b,O)}function k(t){return[(t[0]-f.x)/f.k,(t[1]-f.y)/f.k]}function T(t){f.k=Math.max(d[0],Math.min(d[1],t))}function A(t,e){e=function(t){return[t[0]*f.k+f.x,t[1]*f.k+f.y]}(e),f.x+=t[0]-e[0],f.y+=t[1]-e[1]}function M(e,n,i,a){e.__chart__={x:f.x,y:f.y,k:f.k},T(Math.pow(2,a)),A(r=n,i),e=t.select(e),g>0&&(e=e.transition().duration(g)),e.call(w.event)}function S(){c&&c.domain(l.range().map(function(t){return(t-f.x)/f.k}).map(l.invert)),h&&h.domain(u.range().map(function(t){return(t-f.y)/f.k}).map(u.invert))}function E(t){v++||t({type:\"zoomstart\"})}function C(t){S(),t({type:\"zoom\",scale:f.k,translate:[f.x,f.y]})}function L(t){--v||(t({type:\"zoomend\"}),r=null)}function P(){var e=this,r=_.of(e,arguments),n=0,i=t.select(o(e)).on(y,function(){n=1,A(t.mouse(e),a),C(r)}).on(x,function(){i.on(y,null).on(x,null),s(n),L(r)}),a=k(t.mouse(e)),s=xt(e);hs.call(e),E(r)}function O(){var e,r=this,n=_.of(r,arguments),i={},a=0,o=\".zoom-\"+t.event.changedTouches[0].identifier,l=\"touchmove\"+o,c=\"touchend\"+o,u=[],h=t.select(r),p=xt(r);function d(){var n=t.touches(r);return e=f.k,n.forEach(function(t){t.identifier in i&&(i[t.identifier]=k(t))}),n}function g(){var e=t.event.target;t.select(e).on(l,v).on(c,y),u.push(e);for(var n=t.event.changedTouches,o=0,h=n.length;o<h;++o)i[n[o].identifier]=null;var p=d(),g=Date.now();if(1===p.length){if(g-s<500){var m=p[0];M(r,m,i[m.identifier],Math.floor(Math.log(f.k)/Math.LN2)+1),B()}s=g}else if(p.length>1){m=p[0];var x=p[1],b=m[0]-x[0],_=m[1]-x[1];a=b*b+_*_}}function v(){var o,l,c,u,h=t.touches(r);hs.call(r);for(var f=0,p=h.length;f<p;++f,u=null)if(c=h[f],u=i[c.identifier]){if(l)break;o=c,l=u}if(u){var d=(d=c[0]-o[0])*d+(d=c[1]-o[1])*d,g=a&&Math.sqrt(d/a);o=[(o[0]+c[0])/2,(o[1]+c[1])/2],l=[(l[0]+u[0])/2,(l[1]+u[1])/2],T(g*e)}s=null,A(o,l),C(n)}function y(){if(t.event.touches.length){for(var e=t.event.changedTouches,r=0,a=e.length;r<a;++r)delete i[e[r].identifier];for(var s in i)return void d()}t.selectAll(u).on(o,null),h.on(m,P).on(b,O),p(),L(n)}g(),E(n),h.on(m,null).on(b,g)}function z(){var i=_.of(this,arguments);a?clearTimeout(a):(hs.call(this),e=k(r=n||t.mouse(this)),E(i)),a=setTimeout(function(){a=null,L(i)},50),B(),T(Math.pow(2,.002*Bt())*f.k),A(r,e),C(i)}function I(){var e=t.mouse(this),r=Math.log(f.k)/Math.LN2;M(this,e,k(e),t.event.shiftKey?Math.ceil(r)-1:Math.floor(r)+1)}return Nt||(Nt=\"onwheel\"in i?(Bt=function(){return-t.event.deltaY*(t.event.deltaMode?120:1)},\"wheel\"):\"onmousewheel\"in i?(Bt=function(){return t.event.wheelDelta},\"mousewheel\"):(Bt=function(){return-t.event.detail},\"MozMousePixelScroll\")),w.event=function(e){e.each(function(){var e=_.of(this,arguments),n=f;ds?t.select(this).transition().each(\"start.zoom\",function(){f=this.__chart__||{x:0,y:0,k:1},E(e)}).tween(\"zoom:zoom\",function(){var i=p[0],a=p[1],o=r?r[0]:i/2,s=r?r[1]:a/2,l=t.interpolateZoom([(o-f.x)/f.k,(s-f.y)/f.k,i/f.k],[(o-n.x)/n.k,(s-n.y)/n.k,i/n.k]);return function(t){var r=l(t),n=i/r[2];this.__chart__=f={x:o-r[0]*n,y:s-r[1]*n,k:n},C(e)}}).each(\"interrupt.zoom\",function(){L(e)}).each(\"end.zoom\",function(){L(e)}):(this.__chart__=f,E(e),C(e),L(e))})},w.translate=function(t){return arguments.length?(f={x:+t[0],y:+t[1],k:f.k},S(),w):[f.x,f.y]},w.scale=function(t){return arguments.length?(f={x:f.x,y:f.y,k:null},T(+t),S(),w):f.k},w.scaleExtent=function(t){return arguments.length?(d=null==t?jt:[+t[0],+t[1]],w):d},w.center=function(t){return arguments.length?(n=t&&[+t[0],+t[1]],w):n},w.size=function(t){return arguments.length?(p=t&&[+t[0],+t[1]],w):p},w.duration=function(t){return arguments.length?(g=+t,w):g},w.x=function(t){return arguments.length?(c=t,l=t.copy(),f={x:0,y:0,k:1},w):c},w.y=function(t){return arguments.length?(h=t,u=t.copy(),f={x:0,y:0,k:1},w):h},t.rebind(w,_,\"on\")};var Bt,Nt,jt=[0,1/0];function Ut(){}function Vt(t,e,r){return this instanceof Vt?(this.h=+t,this.s=+e,void(this.l=+r)):arguments.length<2?t instanceof Vt?new Vt(t.h,t.s,t.l):ue(\"\"+t,he,Vt):new Vt(t,e,r)}t.color=Ut,Ut.prototype.toString=function(){return this.rgb()+\"\"},t.hsl=Vt;var qt=Vt.prototype=new Ut;function Ht(t,e,r){var n,i;function a(t){return Math.round(255*function(t){return t>360?t-=360:t<0&&(t+=360),t<60?n+(i-n)*t/60:t<180?i:t<240?n+(i-n)*(240-t)/60:n}(t))}return t=isNaN(t)?0:(t%=360)<0?t+360:t,e=isNaN(e)?0:e<0?0:e>1?1:e,n=2*(r=r<0?0:r>1?1:r)-(i=r<=.5?r*(1+e):r+e-r*e),new ae(a(t+120),a(t),a(t-120))}function Gt(e,r,n){return this instanceof Gt?(this.h=+e,this.c=+r,void(this.l=+n)):arguments.length<2?e instanceof Gt?new Gt(e.h,e.c,e.l):ee(e instanceof Xt?e.l:(e=fe((e=t.rgb(e)).r,e.g,e.b)).l,e.a,e.b):new Gt(e,r,n)}qt.brighter=function(t){return t=Math.pow(.7,arguments.length?t:1),new Vt(this.h,this.s,this.l/t)},qt.darker=function(t){return t=Math.pow(.7,arguments.length?t:1),new Vt(this.h,this.s,t*this.l)},qt.rgb=function(){return Ht(this.h,this.s,this.l)},t.hcl=Gt;var Yt=Gt.prototype=new Ut;function Wt(t,e,r){return isNaN(t)&&(t=0),isNaN(e)&&(e=0),new Xt(r,Math.cos(t*=Ct)*e,Math.sin(t)*e)}function Xt(t,e,r){return this instanceof Xt?(this.l=+t,this.a=+e,void(this.b=+r)):arguments.length<2?t instanceof Xt?new Xt(t.l,t.a,t.b):t instanceof Gt?Wt(t.h,t.c,t.l):fe((t=ae(t)).r,t.g,t.b):new Xt(t,e,r)}Yt.brighter=function(t){return new Gt(this.h,this.c,Math.min(100,this.l+Zt*(arguments.length?t:1)))},Yt.darker=function(t){return new Gt(this.h,this.c,Math.max(0,this.l-Zt*(arguments.length?t:1)))},Yt.rgb=function(){return Wt(this.h,this.c,this.l).rgb()},t.lab=Xt;var Zt=18,Jt=.95047,Kt=1,$t=1.08883,Qt=Xt.prototype=new Ut;function te(t,e,r){var n=(t+16)/116,i=n+e/500,a=n-r/200;return new ae(ie(3.2404542*(i=re(i)*Jt)-1.5371385*(n=re(n)*Kt)-.4985314*(a=re(a)*$t)),ie(-.969266*i+1.8760108*n+.041556*a),ie(.0556434*i-.2040259*n+1.0572252*a))}function ee(t,e,r){return t>0?new Gt(Math.atan2(r,e)*Lt,Math.sqrt(e*e+r*r),t):new Gt(NaN,NaN,t)}function re(t){return t>.206893034?t*t*t:(t-4/29)/7.787037}function ne(t){return t>.008856?Math.pow(t,1/3):7.787037*t+4/29}function ie(t){return Math.round(255*(t<=.00304?12.92*t:1.055*Math.pow(t,1/2.4)-.055))}function ae(t,e,r){return this instanceof ae?(this.r=~~t,this.g=~~e,void(this.b=~~r)):arguments.length<2?t instanceof ae?new ae(t.r,t.g,t.b):ue(\"\"+t,ae,Ht):new ae(t,e,r)}function oe(t){return new ae(t>>16,t>>8&255,255&t)}function se(t){return oe(t)+\"\"}Qt.brighter=function(t){return new Xt(Math.min(100,this.l+Zt*(arguments.length?t:1)),this.a,this.b)},Qt.darker=function(t){return new Xt(Math.max(0,this.l-Zt*(arguments.length?t:1)),this.a,this.b)},Qt.rgb=function(){return te(this.l,this.a,this.b)},t.rgb=ae;var le=ae.prototype=new Ut;function ce(t){return t<16?\"0\"+Math.max(0,t).toString(16):Math.min(255,t).toString(16)}function ue(t,e,r){var n,i,a,o=0,s=0,l=0;if(n=/([a-z]+)\\((.*)\\)/.exec(t=t.toLowerCase()))switch(i=n[2].split(\",\"),n[1]){case\"hsl\":return r(parseFloat(i[0]),parseFloat(i[1])/100,parseFloat(i[2])/100);case\"rgb\":return e(de(i[0]),de(i[1]),de(i[2]))}return(a=ge.get(t))?e(a.r,a.g,a.b):(null==t||\"#\"!==t.charAt(0)||isNaN(a=parseInt(t.slice(1),16))||(4===t.length?(o=(3840&a)>>4,o|=o>>4,s=240&a,s|=s>>4,l=15&a,l|=l<<4):7===t.length&&(o=(16711680&a)>>16,s=(65280&a)>>8,l=255&a)),e(o,s,l))}function he(t,e,r){var n,i,a=Math.min(t/=255,e/=255,r/=255),o=Math.max(t,e,r),s=o-a,l=(o+a)/2;return s?(i=l<.5?s/(o+a):s/(2-o-a),n=t==o?(e-r)/s+(e<r?6:0):e==o?(r-t)/s+2:(t-e)/s+4,n*=60):(n=NaN,i=l>0&&l<1?0:n),new Vt(n,i,l)}function fe(t,e,r){var n=ne((.4124564*(t=pe(t))+.3575761*(e=pe(e))+.1804375*(r=pe(r)))/Jt),i=ne((.2126729*t+.7151522*e+.072175*r)/Kt);return Xt(116*i-16,500*(n-i),200*(i-ne((.0193339*t+.119192*e+.9503041*r)/$t)))}function pe(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function de(t){var e=parseFloat(t);return\"%\"===t.charAt(t.length-1)?Math.round(2.55*e):e}le.brighter=function(t){t=Math.pow(.7,arguments.length?t:1);var e=this.r,r=this.g,n=this.b,i=30;return e||r||n?(e&&e<i&&(e=i),r&&r<i&&(r=i),n&&n<i&&(n=i),new ae(Math.min(255,e/t),Math.min(255,r/t),Math.min(255,n/t))):new ae(i,i,i)},le.darker=function(t){return new ae((t=Math.pow(.7,arguments.length?t:1))*this.r,t*this.g,t*this.b)},le.hsl=function(){return he(this.r,this.g,this.b)},le.toString=function(){return\"#\"+ce(this.r)+ce(this.g)+ce(this.b)};var ge=t.map({aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074});function ve(t){return\"function\"==typeof t?t:function(){return t}}function me(t){return function(e,r,n){return 2===arguments.length&&\"function\"==typeof r&&(n=r,r=null),ye(e,r,t,n)}}function ye(e,r,i,a){var o={},s=t.dispatch(\"beforesend\",\"progress\",\"load\",\"error\"),l={},c=new XMLHttpRequest,u=null;function h(){var t,e=c.status;if(!e&&function(t){var e=t.responseType;return e&&\"text\"!==e?t.response:t.responseText}(c)||e>=200&&e<300||304===e){try{t=i.call(o,c)}catch(t){return void s.error.call(o,t)}s.load.call(o,t)}else s.error.call(o,c)}return!this.XDomainRequest||\"withCredentials\"in c||!/^(http(s)?:)?\\/\\//.test(e)||(c=new XDomainRequest),\"onload\"in c?c.onload=c.onerror=h:c.onreadystatechange=function(){c.readyState>3&&h()},c.onprogress=function(e){var r=t.event;t.event=e;try{s.progress.call(o,c)}finally{t.event=r}},o.header=function(t,e){return t=(t+\"\").toLowerCase(),arguments.length<2?l[t]:(null==e?delete l[t]:l[t]=e+\"\",o)},o.mimeType=function(t){return arguments.length?(r=null==t?null:t+\"\",o):r},o.responseType=function(t){return arguments.length?(u=t,o):u},o.response=function(t){return i=t,o},[\"get\",\"post\"].forEach(function(t){o[t]=function(){return o.send.apply(o,[t].concat(n(arguments)))}}),o.send=function(t,n,i){if(2===arguments.length&&\"function\"==typeof n&&(i=n,n=null),c.open(t,e,!0),null==r||\"accept\"in l||(l.accept=r+\",*/*\"),c.setRequestHeader)for(var a in l)c.setRequestHeader(a,l[a]);return null!=r&&c.overrideMimeType&&c.overrideMimeType(r),null!=u&&(c.responseType=u),null!=i&&o.on(\"error\",i).on(\"load\",function(t){i(null,t)}),s.beforesend.call(o,c),c.send(null==n?null:n),o},o.abort=function(){return c.abort(),o},t.rebind(o,s,\"on\"),null==a?o:o.get(function(t){return 1===t.length?function(e,r){t(null==e?r:null)}:t}(a))}ge.forEach(function(t,e){ge.set(t,oe(e))}),t.functor=ve,t.xhr=me(P),t.dsv=function(t,e){var r=new RegExp('[\"'+t+\"\\n]\"),n=t.charCodeAt(0);function i(t,r,n){arguments.length<3&&(n=r,r=null);var i=ye(t,e,null==r?a:o(r),n);return i.row=function(t){return arguments.length?i.response(null==(r=t)?a:o(t)):r},i}function a(t){return i.parse(t.responseText)}function o(t){return function(e){return i.parse(e.responseText,t)}}function s(e){return e.map(l).join(t)}function l(t){return r.test(t)?'\"'+t.replace(/\\\"/g,'\"\"')+'\"':t}return i.parse=function(t,e){var r;return i.parseRows(t,function(t,n){if(r)return r(t,n-1);var i=new Function(\"d\",\"return {\"+t.map(function(t,e){return JSON.stringify(t)+\": d[\"+e+\"]\"}).join(\",\")+\"}\");r=e?function(t,r){return e(i(t),r)}:i})},i.parseRows=function(t,e){var r,i,a={},o={},s=[],l=t.length,c=0,u=0;function h(){if(c>=l)return o;if(i)return i=!1,a;var e=c;if(34===t.charCodeAt(e)){for(var r=e;r++<l;)if(34===t.charCodeAt(r)){if(34!==t.charCodeAt(r+1))break;++r}return c=r+2,13===(s=t.charCodeAt(r+1))?(i=!0,10===t.charCodeAt(r+2)&&++c):10===s&&(i=!0),t.slice(e+1,r).replace(/\"\"/g,'\"')}for(;c<l;){var s,u=1;if(10===(s=t.charCodeAt(c++)))i=!0;else if(13===s)i=!0,10===t.charCodeAt(c)&&(++c,++u);else if(s!==n)continue;return t.slice(e,c-u)}return t.slice(e)}for(;(r=h())!==o;){for(var f=[];r!==a&&r!==o;)f.push(r),r=h();e&&null==(f=e(f,u++))||s.push(f)}return s},i.format=function(e){if(Array.isArray(e[0]))return i.formatRows(e);var r=new L,n=[];return e.forEach(function(t){for(var e in t)r.has(e)||n.push(r.add(e))}),[n.map(l).join(t)].concat(e.map(function(e){return n.map(function(t){return l(e[t])}).join(t)})).join(\"\\n\")},i.formatRows=function(t){return t.map(s).join(\"\\n\")},i},t.csv=t.dsv(\",\",\"text/csv\"),t.tsv=t.dsv(\"\\t\",\"text/tab-separated-values\");var xe,be,_e,we,ke=this[z(this,\"requestAnimationFrame\")]||function(t){setTimeout(t,17)};function Te(t,e,r){var n=arguments.length;n<2&&(e=0),n<3&&(r=Date.now());var i={c:t,t:r+e,n:null};return be?be.n=i:xe=i,be=i,_e||(we=clearTimeout(we),_e=1,ke(Ae)),i}function Ae(){var t=Me(),e=Se()-t;e>24?(isFinite(e)&&(clearTimeout(we),we=setTimeout(Ae,e)),_e=0):(_e=1,ke(Ae))}function Me(){for(var t=Date.now(),e=xe;e;)t>=e.t&&e.c(t-e.t)&&(e.c=null),e=e.n;return t}function Se(){for(var t,e=xe,r=1/0;e;)e.c?(e.t<r&&(r=e.t),e=(t=e).n):e=t?t.n=e.n:xe=e.n;return be=t,r}function Ee(t,e){return e-(t?Math.ceil(Math.log(t)/Math.LN10):1)}t.timer=function(){Te.apply(this,arguments)},t.timer.flush=function(){Me(),Se()},t.round=function(t,e){return e?Math.round(t*(e=Math.pow(10,e)))/e:Math.round(t)};var Ce=[\"y\",\"z\",\"a\",\"f\",\"p\",\"n\",\"\\xb5\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\",\"P\",\"E\",\"Z\",\"Y\"].map(function(t,e){var r=Math.pow(10,3*y(8-e));return{scale:e>8?function(t){return t/r}:function(t){return t*r},symbol:t}});t.formatPrefix=function(e,r){var n=0;return(e=+e)&&(e<0&&(e*=-1),r&&(e=t.round(e,Ee(e,r))),n=1+Math.floor(1e-12+Math.log(e)/Math.LN10),n=Math.max(-24,Math.min(24,3*Math.floor((n-1)/3)))),Ce[8+n/3]};var Le=/(?:([^{])?([<>=^]))?([+\\- ])?([$#])?(0)?(\\d+)?(,)?(\\.-?\\d+)?([a-z%])?/i,Pe=t.map({b:function(t){return t.toString(2)},c:function(t){return String.fromCharCode(t)},o:function(t){return t.toString(8)},x:function(t){return t.toString(16)},X:function(t){return t.toString(16).toUpperCase()},g:function(t,e){return t.toPrecision(e)},e:function(t,e){return t.toExponential(e)},f:function(t,e){return t.toFixed(e)},r:function(e,r){return(e=t.round(e,Ee(e,r))).toFixed(Math.max(0,Math.min(20,Ee(e*(1+1e-15),r))))}});function Oe(t){return t+\"\"}var ze=t.time={},Ie=Date;function De(){this._=new Date(arguments.length>1?Date.UTC.apply(this,arguments):arguments[0])}De.prototype={getDate:function(){return this._.getUTCDate()},getDay:function(){return this._.getUTCDay()},getFullYear:function(){return this._.getUTCFullYear()},getHours:function(){return this._.getUTCHours()},getMilliseconds:function(){return this._.getUTCMilliseconds()},getMinutes:function(){return this._.getUTCMinutes()},getMonth:function(){return this._.getUTCMonth()},getSeconds:function(){return this._.getUTCSeconds()},getTime:function(){return this._.getTime()},getTimezoneOffset:function(){return 0},valueOf:function(){return this._.valueOf()},setDate:function(){Re.setUTCDate.apply(this._,arguments)},setDay:function(){Re.setUTCDay.apply(this._,arguments)},setFullYear:function(){Re.setUTCFullYear.apply(this._,arguments)},setHours:function(){Re.setUTCHours.apply(this._,arguments)},setMilliseconds:function(){Re.setUTCMilliseconds.apply(this._,arguments)},setMinutes:function(){Re.setUTCMinutes.apply(this._,arguments)},setMonth:function(){Re.setUTCMonth.apply(this._,arguments)},setSeconds:function(){Re.setUTCSeconds.apply(this._,arguments)},setTime:function(){Re.setTime.apply(this._,arguments)}};var Re=Date.prototype;function Fe(t,e,r){function n(e){var r=t(e),n=a(r,1);return e-r<n-e?r:n}function i(r){return e(r=t(new Ie(r-1)),1),r}function a(t,r){return e(t=new Ie(+t),r),t}function o(t,n,a){var o=i(t),s=[];if(a>1)for(;o<n;)r(o)%a||s.push(new Date(+o)),e(o,1);else for(;o<n;)s.push(new Date(+o)),e(o,1);return s}t.floor=t,t.round=n,t.ceil=i,t.offset=a,t.range=o;var s=t.utc=Be(t);return s.floor=s,s.round=Be(n),s.ceil=Be(i),s.offset=Be(a),s.range=function(t,e,r){try{Ie=De;var n=new De;return n._=t,o(n,e,r)}finally{Ie=Date}},t}function Be(t){return function(e,r){try{Ie=De;var n=new De;return n._=e,t(n,r)._}finally{Ie=Date}}}ze.year=Fe(function(t){return(t=ze.day(t)).setMonth(0,1),t},function(t,e){t.setFullYear(t.getFullYear()+e)},function(t){return t.getFullYear()}),ze.years=ze.year.range,ze.years.utc=ze.year.utc.range,ze.day=Fe(function(t){var e=new Ie(2e3,0);return e.setFullYear(t.getFullYear(),t.getMonth(),t.getDate()),e},function(t,e){t.setDate(t.getDate()+e)},function(t){return t.getDate()-1}),ze.days=ze.day.range,ze.days.utc=ze.day.utc.range,ze.dayOfYear=function(t){var e=ze.year(t);return Math.floor((t-e-6e4*(t.getTimezoneOffset()-e.getTimezoneOffset()))/864e5)},[\"sunday\",\"monday\",\"tuesday\",\"wednesday\",\"thursday\",\"friday\",\"saturday\"].forEach(function(t,e){e=7-e;var r=ze[t]=Fe(function(t){return(t=ze.day(t)).setDate(t.getDate()-(t.getDay()+e)%7),t},function(t,e){t.setDate(t.getDate()+7*Math.floor(e))},function(t){var r=ze.year(t).getDay();return Math.floor((ze.dayOfYear(t)+(r+e)%7)/7)-(r!==e)});ze[t+\"s\"]=r.range,ze[t+\"s\"].utc=r.utc.range,ze[t+\"OfYear\"]=function(t){var r=ze.year(t).getDay();return Math.floor((ze.dayOfYear(t)+(r+e)%7)/7)}}),ze.week=ze.sunday,ze.weeks=ze.sunday.range,ze.weeks.utc=ze.sunday.utc.range,ze.weekOfYear=ze.sundayOfYear;var Ne={\"-\":\"\",_:\" \",0:\"0\"},je=/^\\s*\\d+/,Ue=/^%/;function Ve(t,e,r){var n=t<0?\"-\":\"\",i=(n?-t:t)+\"\",a=i.length;return n+(a<r?new Array(r-a+1).join(e)+i:i)}function qe(e){return new RegExp(\"^(?:\"+e.map(t.requote).join(\"|\")+\")\",\"i\")}function He(t){for(var e=new b,r=-1,n=t.length;++r<n;)e.set(t[r].toLowerCase(),r);return e}function Ge(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+1));return n?(t.w=+n[0],r+n[0].length):-1}function Ye(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.U=+n[0],r+n[0].length):-1}function We(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.W=+n[0],r+n[0].length):-1}function Xe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+4));return n?(t.y=+n[0],r+n[0].length):-1}function Ze(t,e,r){je.lastIndex=0;var n,i=je.exec(e.slice(r,r+2));return i?(t.y=(n=+i[0])+(n>68?1900:2e3),r+i[0].length):-1}function Je(t,e,r){return/^[+-]\\d{4}$/.test(e=e.slice(r,r+5))?(t.Z=-e,r+5):-1}function Ke(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.m=n[0]-1,r+n[0].length):-1}function $e(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.d=+n[0],r+n[0].length):-1}function Qe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.j=+n[0],r+n[0].length):-1}function tr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.H=+n[0],r+n[0].length):-1}function er(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.M=+n[0],r+n[0].length):-1}function rr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.S=+n[0],r+n[0].length):-1}function nr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.L=+n[0],r+n[0].length):-1}function ir(t){var e=t.getTimezoneOffset(),r=e>0?\"-\":\"+\",n=y(e)/60|0,i=y(e)%60;return r+Ve(n,\"0\",2)+Ve(i,\"0\",2)}function ar(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r,r+1));return n?r+n[0].length:-1}function or(t){for(var e=t.length,r=-1;++r<e;)t[r][0]=this(t[r][0]);return function(e){for(var r=0,n=t[r];!n[1](e);)n=t[++r];return n[0](e)}}t.locale=function(e){return{numberFormat:function(e){var r=e.decimal,n=e.thousands,i=e.grouping,a=e.currency,o=i&&n?function(t,e){for(var r=t.length,a=[],o=0,s=i[0],l=0;r>0&&s>0&&(l+s+1>e&&(s=Math.max(1,e-l)),a.push(t.substring(r-=s,r+s)),!((l+=s+1)>e));)s=i[o=(o+1)%i.length];return a.reverse().join(n)}:P;return function(e){var n=Le.exec(e),i=n[1]||\" \",s=n[2]||\">\",l=n[3]||\"-\",c=n[4]||\"\",u=n[5],h=+n[6],f=n[7],p=n[8],d=n[9],g=1,v=\"\",m=\"\",y=!1,x=!0;switch(p&&(p=+p.substring(1)),(u||\"0\"===i&&\"=\"===s)&&(u=i=\"0\",s=\"=\"),d){case\"n\":f=!0,d=\"g\";break;case\"%\":g=100,m=\"%\",d=\"f\";break;case\"p\":g=100,m=\"%\",d=\"r\";break;case\"b\":case\"o\":case\"x\":case\"X\":\"#\"===c&&(v=\"0\"+d.toLowerCase());case\"c\":x=!1;case\"d\":y=!0,p=0;break;case\"s\":g=-1,d=\"r\"}\"$\"===c&&(v=a[0],m=a[1]),\"r\"!=d||p||(d=\"g\"),null!=p&&(\"g\"==d?p=Math.max(1,Math.min(21,p)):\"e\"!=d&&\"f\"!=d||(p=Math.max(0,Math.min(20,p)))),d=Pe.get(d)||Oe;var b=u&&f;return function(e){var n=m;if(y&&e%1)return\"\";var a=e<0||0===e&&1/e<0?(e=-e,\"-\"):\"-\"===l?\"\":l;if(g<0){var c=t.formatPrefix(e,p);e=c.scale(e),n=c.symbol+m}else e*=g;var _,w,k=(e=d(e,p)).lastIndexOf(\".\");if(k<0){var T=x?e.lastIndexOf(\"e\"):-1;T<0?(_=e,w=\"\"):(_=e.substring(0,T),w=e.substring(T))}else _=e.substring(0,k),w=r+e.substring(k+1);!u&&f&&(_=o(_,1/0));var A=v.length+_.length+w.length+(b?0:a.length),M=A<h?new Array(A=h-A+1).join(i):\"\";return b&&(_=o(M+_,M.length?h-w.length:1/0)),a+=v,e=_+w,(\"<\"===s?a+e+M:\">\"===s?M+a+e:\"^\"===s?M.substring(0,A>>=1)+a+e+M.substring(A):a+(b?e:M+e))+n}}}(e),timeFormat:function(e){var r=e.dateTime,n=e.date,i=e.time,a=e.periods,o=e.days,s=e.shortDays,l=e.months,c=e.shortMonths;function u(t){var e=t.length;function r(r){for(var n,i,a,o=[],s=-1,l=0;++s<e;)37===t.charCodeAt(s)&&(o.push(t.slice(l,s)),null!=(i=Ne[n=t.charAt(++s)])&&(n=t.charAt(++s)),(a=_[n])&&(n=a(r,null==i?\"e\"===n?\" \":\"0\":i)),o.push(n),l=s+1);return o.push(t.slice(l,s)),o.join(\"\")}return r.parse=function(e){var r={y:1900,m:0,d:1,H:0,M:0,S:0,L:0,Z:null};if(h(r,t,e,0)!=e.length)return null;\"p\"in r&&(r.H=r.H%12+12*r.p);var n=null!=r.Z&&Ie!==De,i=new(n?De:Ie);return\"j\"in r?i.setFullYear(r.y,0,r.j):\"W\"in r||\"U\"in r?(\"w\"in r||(r.w=\"W\"in r?1:0),i.setFullYear(r.y,0,1),i.setFullYear(r.y,0,\"W\"in r?(r.w+6)%7+7*r.W-(i.getDay()+5)%7:r.w+7*r.U-(i.getDay()+6)%7)):i.setFullYear(r.y,r.m,r.d),i.setHours(r.H+(r.Z/100|0),r.M+r.Z%100,r.S,r.L),n?i._:i},r.toString=function(){return t},r}function h(t,e,r,n){for(var i,a,o,s=0,l=e.length,c=r.length;s<l;){if(n>=c)return-1;if(37===(i=e.charCodeAt(s++))){if(o=e.charAt(s++),!(a=w[o in Ne?e.charAt(s++):o])||(n=a(t,r,n))<0)return-1}else if(i!=r.charCodeAt(n++))return-1}return n}u.utc=function(t){var e=u(t);function r(t){try{var r=new(Ie=De);return r._=t,e(r)}finally{Ie=Date}}return r.parse=function(t){try{Ie=De;var r=e.parse(t);return r&&r._}finally{Ie=Date}},r.toString=e.toString,r},u.multi=u.utc.multi=or;var f=t.map(),p=qe(o),d=He(o),g=qe(s),v=He(s),m=qe(l),y=He(l),x=qe(c),b=He(c);a.forEach(function(t,e){f.set(t.toLowerCase(),e)});var _={a:function(t){return s[t.getDay()]},A:function(t){return o[t.getDay()]},b:function(t){return c[t.getMonth()]},B:function(t){return l[t.getMonth()]},c:u(r),d:function(t,e){return Ve(t.getDate(),e,2)},e:function(t,e){return Ve(t.getDate(),e,2)},H:function(t,e){return Ve(t.getHours(),e,2)},I:function(t,e){return Ve(t.getHours()%12||12,e,2)},j:function(t,e){return Ve(1+ze.dayOfYear(t),e,3)},L:function(t,e){return Ve(t.getMilliseconds(),e,3)},m:function(t,e){return Ve(t.getMonth()+1,e,2)},M:function(t,e){return Ve(t.getMinutes(),e,2)},p:function(t){return a[+(t.getHours()>=12)]},S:function(t,e){return Ve(t.getSeconds(),e,2)},U:function(t,e){return Ve(ze.sundayOfYear(t),e,2)},w:function(t){return t.getDay()},W:function(t,e){return Ve(ze.mondayOfYear(t),e,2)},x:u(n),X:u(i),y:function(t,e){return Ve(t.getFullYear()%100,e,2)},Y:function(t,e){return Ve(t.getFullYear()%1e4,e,4)},Z:ir,\"%\":function(){return\"%\"}},w={a:function(t,e,r){g.lastIndex=0;var n=g.exec(e.slice(r));return n?(t.w=v.get(n[0].toLowerCase()),r+n[0].length):-1},A:function(t,e,r){p.lastIndex=0;var n=p.exec(e.slice(r));return n?(t.w=d.get(n[0].toLowerCase()),r+n[0].length):-1},b:function(t,e,r){x.lastIndex=0;var n=x.exec(e.slice(r));return n?(t.m=b.get(n[0].toLowerCase()),r+n[0].length):-1},B:function(t,e,r){m.lastIndex=0;var n=m.exec(e.slice(r));return n?(t.m=y.get(n[0].toLowerCase()),r+n[0].length):-1},c:function(t,e,r){return h(t,_.c.toString(),e,r)},d:$e,e:$e,H:tr,I:tr,j:Qe,L:nr,m:Ke,M:er,p:function(t,e,r){var n=f.get(e.slice(r,r+=2).toLowerCase());return null==n?-1:(t.p=n,r)},S:rr,U:Ye,w:Ge,W:We,x:function(t,e,r){return h(t,_.x.toString(),e,r)},X:function(t,e,r){return h(t,_.X.toString(),e,r)},y:Ze,Y:Xe,Z:Je,\"%\":ar};return u}(e)}};var sr=t.locale({decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],dateTime:\"%a %b %e %X %Y\",date:\"%m/%d/%Y\",time:\"%H:%M:%S\",periods:[\"AM\",\"PM\"],days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"]});function lr(){}t.format=sr.numberFormat,t.geo={},lr.prototype={s:0,t:0,add:function(t){ur(t,this.t,cr),ur(cr.s,this.s,this),this.s?this.t+=cr.t:this.s=cr.t},reset:function(){this.s=this.t=0},valueOf:function(){return this.s}};var cr=new lr;function ur(t,e,r){var n=r.s=t+e,i=n-t,a=n-i;r.t=t-a+(e-i)}function hr(t,e){t&&pr.hasOwnProperty(t.type)&&pr[t.type](t,e)}t.geo.stream=function(t,e){t&&fr.hasOwnProperty(t.type)?fr[t.type](t,e):hr(t,e)};var fr={Feature:function(t,e){hr(t.geometry,e)},FeatureCollection:function(t,e){for(var r=t.features,n=-1,i=r.length;++n<i;)hr(r[n].geometry,e)}},pr={Sphere:function(t,e){e.sphere()},Point:function(t,e){t=t.coordinates,e.point(t[0],t[1],t[2])},MultiPoint:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)t=r[n],e.point(t[0],t[1],t[2])},LineString:function(t,e){dr(t.coordinates,e,0)},MultiLineString:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)dr(r[n],e,0)},Polygon:function(t,e){gr(t.coordinates,e)},MultiPolygon:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)gr(r[n],e)},GeometryCollection:function(t,e){for(var r=t.geometries,n=-1,i=r.length;++n<i;)hr(r[n],e)}};function dr(t,e,r){var n,i=-1,a=t.length-r;for(e.lineStart();++i<a;)n=t[i],e.point(n[0],n[1],n[2]);e.lineEnd()}function gr(t,e){var r=-1,n=t.length;for(e.polygonStart();++r<n;)dr(t[r],e,1);e.polygonEnd()}t.geo.area=function(e){return vr=0,t.geo.stream(e,Cr),vr};var vr,mr,yr,xr,br,_r,wr,kr,Tr,Ar,Mr,Sr,Er=new lr,Cr={sphere:function(){vr+=4*At},point:D,lineStart:D,lineEnd:D,polygonStart:function(){Er.reset(),Cr.lineStart=Lr},polygonEnd:function(){var t=2*Er;vr+=t<0?4*At+t:t,Cr.lineStart=Cr.lineEnd=Cr.point=D}};function Lr(){var t,e,r,n,i;function a(t,e){e=e*Ct/2+At/4;var a=(t*=Ct)-r,o=a>=0?1:-1,s=o*a,l=Math.cos(e),c=Math.sin(e),u=i*c,h=n*l+u*Math.cos(s),f=u*o*Math.sin(s);Er.add(Math.atan2(f,h)),r=t,n=l,i=c}Cr.point=function(o,s){Cr.point=a,r=(t=o)*Ct,n=Math.cos(s=(e=s)*Ct/2+At/4),i=Math.sin(s)},Cr.lineEnd=function(){a(t,e)}}function Pr(t){var e=t[0],r=t[1],n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}function Or(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}function zr(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}function Ir(t,e){t[0]+=e[0],t[1]+=e[1],t[2]+=e[2]}function Dr(t,e){return[t[0]*e,t[1]*e,t[2]*e]}function Rr(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]+t[2]*t[2]);t[0]/=e,t[1]/=e,t[2]/=e}function Fr(t){return[Math.atan2(t[1],t[0]),It(t[2])]}function Br(t,e){return y(t[0]-e[0])<kt&&y(t[1]-e[1])<kt}t.geo.bounds=function(){var e,r,n,i,a,o,s,l,c,u,h,f={point:p,lineStart:g,lineEnd:v,polygonStart:function(){f.point=m,f.lineStart=x,f.lineEnd=b,c=0,Cr.polygonStart()},polygonEnd:function(){Cr.polygonEnd(),f.point=p,f.lineStart=g,f.lineEnd=v,Er<0?(e=-(n=180),r=-(i=90)):c>kt?i=90:c<-kt&&(r=-90),h[0]=e,h[1]=n}};function p(t,a){u.push(h=[e=t,n=t]),a<r&&(r=a),a>i&&(i=a)}function d(t,o){var s=Pr([t*Ct,o*Ct]);if(l){var c=zr(l,s),u=zr([c[1],-c[0],0],c);Rr(u),u=Fr(u);var h=t-a,f=h>0?1:-1,d=u[0]*Lt*f,g=y(h)>180;if(g^(f*a<d&&d<f*t))(v=u[1]*Lt)>i&&(i=v);else if(g^(f*a<(d=(d+360)%360-180)&&d<f*t)){var v;(v=-u[1]*Lt)<r&&(r=v)}else o<r&&(r=o),o>i&&(i=o);g?t<a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t):n>=e?(t<e&&(e=t),t>n&&(n=t)):t>a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t)}else p(t,o);l=s,a=t}function g(){f.point=d}function v(){h[0]=e,h[1]=n,f.point=p,l=null}function m(t,e){if(l){var r=t-a;c+=y(r)>180?r+(r>0?360:-360):r}else o=t,s=e;Cr.point(t,e),d(t,e)}function x(){Cr.lineStart()}function b(){m(o,s),Cr.lineEnd(),y(c)>kt&&(e=-(n=180)),h[0]=e,h[1]=n,l=null}function _(t,e){return(e-=t)<0?e+360:e}function w(t,e){return t[0]-e[0]}function k(t,e){return e[0]<=e[1]?e[0]<=t&&t<=e[1]:t<e[0]||e[1]<t}return function(a){if(i=n=-(e=r=1/0),u=[],t.geo.stream(a,f),c=u.length){u.sort(w);for(var o=1,s=[g=u[0]];o<c;++o)k((p=u[o])[0],g)||k(p[1],g)?(_(g[0],p[1])>_(g[0],g[1])&&(g[1]=p[1]),_(p[0],g[1])>_(g[0],g[1])&&(g[0]=p[0])):s.push(g=p);for(var l,c,p,d=-1/0,g=(o=0,s[c=s.length-1]);o<=c;g=p,++o)p=s[o],(l=_(g[1],p[0]))>d&&(d=l,e=p[0],n=g[1])}return u=h=null,e===1/0||r===1/0?[[NaN,NaN],[NaN,NaN]]:[[e,r],[n,i]]}}(),t.geo.centroid=function(e){mr=yr=xr=br=_r=wr=kr=Tr=Ar=Mr=Sr=0,t.geo.stream(e,Nr);var r=Ar,n=Mr,i=Sr,a=r*r+n*n+i*i;return a<Tt&&(r=wr,n=kr,i=Tr,yr<kt&&(r=xr,n=br,i=_r),(a=r*r+n*n+i*i)<Tt)?[NaN,NaN]:[Math.atan2(n,r)*Lt,It(i/Math.sqrt(a))*Lt]};var Nr={sphere:D,point:jr,lineStart:Vr,lineEnd:qr,polygonStart:function(){Nr.lineStart=Hr},polygonEnd:function(){Nr.lineStart=Vr}};function jr(t,e){t*=Ct;var r=Math.cos(e*=Ct);Ur(r*Math.cos(t),r*Math.sin(t),Math.sin(e))}function Ur(t,e,r){xr+=(t-xr)/++mr,br+=(e-br)/mr,_r+=(r-_r)/mr}function Vr(){var t,e,r;function n(n,i){n*=Ct;var a=Math.cos(i*=Ct),o=a*Math.cos(n),s=a*Math.sin(n),l=Math.sin(i),c=Math.atan2(Math.sqrt((c=e*l-r*s)*c+(c=r*o-t*l)*c+(c=t*s-e*o)*c),t*o+e*s+r*l);yr+=c,wr+=c*(t+(t=o)),kr+=c*(e+(e=s)),Tr+=c*(r+(r=l)),Ur(t,e,r)}Nr.point=function(i,a){i*=Ct;var o=Math.cos(a*=Ct);t=o*Math.cos(i),e=o*Math.sin(i),r=Math.sin(a),Nr.point=n,Ur(t,e,r)}}function qr(){Nr.point=jr}function Hr(){var t,e,r,n,i;function a(t,e){t*=Ct;var a=Math.cos(e*=Ct),o=a*Math.cos(t),s=a*Math.sin(t),l=Math.sin(e),c=n*l-i*s,u=i*o-r*l,h=r*s-n*o,f=Math.sqrt(c*c+u*u+h*h),p=r*o+n*s+i*l,d=f&&-zt(p)/f,g=Math.atan2(f,p);Ar+=d*c,Mr+=d*u,Sr+=d*h,yr+=g,wr+=g*(r+(r=o)),kr+=g*(n+(n=s)),Tr+=g*(i+(i=l)),Ur(r,n,i)}Nr.point=function(o,s){t=o,e=s,Nr.point=a,o*=Ct;var l=Math.cos(s*=Ct);r=l*Math.cos(o),n=l*Math.sin(o),i=Math.sin(s),Ur(r,n,i)},Nr.lineEnd=function(){a(t,e),Nr.lineEnd=qr,Nr.point=jr}}function Gr(t,e){function r(r,n){return r=t(r,n),e(r[0],r[1])}return t.invert&&e.invert&&(r.invert=function(r,n){return(r=e.invert(r,n))&&t.invert(r[0],r[1])}),r}function Yr(){return!0}function Wr(t,e,r,n,i){var a=[],o=[];if(t.forEach(function(t){if(!((e=t.length-1)<=0)){var e,r=t[0],n=t[e];if(Br(r,n)){i.lineStart();for(var s=0;s<e;++s)i.point((r=t[s])[0],r[1]);i.lineEnd()}else{var l=new Zr(r,t,null,!0),c=new Zr(r,null,l,!1);l.o=c,a.push(l),o.push(c),l=new Zr(n,t,null,!1),c=new Zr(n,null,l,!0),l.o=c,a.push(l),o.push(c)}}}),o.sort(e),Xr(a),Xr(o),a.length){for(var s=0,l=r,c=o.length;s<c;++s)o[s].e=l=!l;for(var u,h,f=a[0];;){for(var p=f,d=!0;p.v;)if((p=p.n)===f)return;u=p.z,i.lineStart();do{if(p.v=p.o.v=!0,p.e){if(d)for(s=0,c=u.length;s<c;++s)i.point((h=u[s])[0],h[1]);else n(p.x,p.n.x,1,i);p=p.n}else{if(d)for(s=(u=p.p.z).length-1;s>=0;--s)i.point((h=u[s])[0],h[1]);else n(p.x,p.p.x,-1,i);p=p.p}u=(p=p.o).z,d=!d}while(!p.v);i.lineEnd()}}}function Xr(t){if(e=t.length){for(var e,r,n=0,i=t[0];++n<e;)i.n=r=t[n],r.p=i,i=r;i.n=r=t[0],r.p=i}}function Zr(t,e,r,n){this.x=t,this.z=e,this.o=r,this.e=n,this.v=!1,this.n=this.p=null}function Jr(e,r,n,i){return function(a,o){var s,l=r(o),c=a.invert(i[0],i[1]),u={point:h,lineStart:p,lineEnd:d,polygonStart:function(){u.point=b,u.lineStart=_,u.lineEnd=w,s=[],g=[]},polygonEnd:function(){u.point=h,u.lineStart=p,u.lineEnd=d,s=t.merge(s);var e=function(t,e){var r=t[0],n=t[1],i=[Math.sin(r),-Math.cos(r),0],a=0,o=0;Er.reset();for(var s=0,l=e.length;s<l;++s){var c=e[s],u=c.length;if(u)for(var h=c[0],f=h[0],p=h[1]/2+At/4,d=Math.sin(p),g=Math.cos(p),v=1;;){v===u&&(v=0);var m=(t=c[v])[0],y=t[1]/2+At/4,x=Math.sin(y),b=Math.cos(y),_=m-f,w=_>=0?1:-1,k=w*_,T=k>At,A=d*x;if(Er.add(Math.atan2(A*w*Math.sin(k),g*b+A*Math.cos(k))),a+=T?_+w*Mt:_,T^f>=r^m>=r){var M=zr(Pr(h),Pr(t));Rr(M);var S=zr(i,M);Rr(S);var E=(T^_>=0?-1:1)*It(S[2]);(n>E||n===E&&(M[0]||M[1]))&&(o+=T^_>=0?1:-1)}if(!v++)break;f=m,d=x,g=b,h=t}}return(a<-kt||a<kt&&Er<-kt)^1&o}(c,g);s.length?(x||(o.polygonStart(),x=!0),Wr(s,Qr,e,n,o)):e&&(x||(o.polygonStart(),x=!0),o.lineStart(),n(null,null,1,o),o.lineEnd()),x&&(o.polygonEnd(),x=!1),s=g=null},sphere:function(){o.polygonStart(),o.lineStart(),n(null,null,1,o),o.lineEnd(),o.polygonEnd()}};function h(t,r){var n=a(t,r);e(t=n[0],r=n[1])&&o.point(t,r)}function f(t,e){var r=a(t,e);l.point(r[0],r[1])}function p(){u.point=f,l.lineStart()}function d(){u.point=h,l.lineEnd()}var g,v,m=$r(),y=r(m),x=!1;function b(t,e){v.push([t,e]);var r=a(t,e);y.point(r[0],r[1])}function _(){y.lineStart(),v=[]}function w(){b(v[0][0],v[0][1]),y.lineEnd();var t,e=y.clean(),r=m.buffer(),n=r.length;if(v.pop(),g.push(v),v=null,n)if(1&e){var i,a=-1;if((n=(t=r[0]).length-1)>0){for(x||(o.polygonStart(),x=!0),o.lineStart();++a<n;)o.point((i=t[a])[0],i[1]);o.lineEnd()}}else n>1&&2&e&&r.push(r.pop().concat(r.shift())),s.push(r.filter(Kr))}return u}}function Kr(t){return t.length>1}function $r(){var t,e=[];return{lineStart:function(){e.push(t=[])},point:function(e,r){t.push([e,r])},lineEnd:D,buffer:function(){var r=e;return e=[],t=null,r},rejoin:function(){e.length>1&&e.push(e.pop().concat(e.shift()))}}}function Qr(t,e){return((t=t.x)[0]<0?t[1]-Et-kt:Et-t[1])-((e=e.x)[0]<0?e[1]-Et-kt:Et-e[1])}var tn=Jr(Yr,function(t){var e,r=NaN,n=NaN,i=NaN;return{lineStart:function(){t.lineStart(),e=1},point:function(a,o){var s=a>0?At:-At,l=y(a-r);y(l-At)<kt?(t.point(r,n=(n+o)/2>0?Et:-Et),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),t.point(a,n),e=0):i!==s&&l>=At&&(y(r-i)<kt&&(r-=i*kt),y(a-s)<kt&&(a-=s*kt),n=function(t,e,r,n){var i,a,o=Math.sin(t-r);return y(o)>kt?Math.atan((Math.sin(e)*(a=Math.cos(n))*Math.sin(r)-Math.sin(n)*(i=Math.cos(e))*Math.sin(t))/(i*a*o)):(e+n)/2}(r,n,a,o),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),e=0),t.point(r=a,n=o),i=s},lineEnd:function(){t.lineEnd(),r=n=NaN},clean:function(){return 2-e}}},function(t,e,r,n){var i;if(null==t)i=r*Et,n.point(-At,i),n.point(0,i),n.point(At,i),n.point(At,0),n.point(At,-i),n.point(0,-i),n.point(-At,-i),n.point(-At,0),n.point(-At,i);else if(y(t[0]-e[0])>kt){var a=t[0]<e[0]?At:-At;i=r*a/2,n.point(-a,i),n.point(0,i),n.point(a,i)}else n.point(e[0],e[1])},[-At,-At/2]);function en(t,e,r,n){return function(i){var a,o=i.a,s=i.b,l=o.x,c=o.y,u=0,h=1,f=s.x-l,p=s.y-c;if(a=t-l,f||!(a>0)){if(a/=f,f<0){if(a<u)return;a<h&&(h=a)}else if(f>0){if(a>h)return;a>u&&(u=a)}if(a=r-l,f||!(a<0)){if(a/=f,f<0){if(a>h)return;a>u&&(u=a)}else if(f>0){if(a<u)return;a<h&&(h=a)}if(a=e-c,p||!(a>0)){if(a/=p,p<0){if(a<u)return;a<h&&(h=a)}else if(p>0){if(a>h)return;a>u&&(u=a)}if(a=n-c,p||!(a<0)){if(a/=p,p<0){if(a>h)return;a>u&&(u=a)}else if(p>0){if(a<u)return;a<h&&(h=a)}return u>0&&(i.a={x:l+u*f,y:c+u*p}),h<1&&(i.b={x:l+h*f,y:c+h*p}),i}}}}}}var rn=1e9;function nn(e,r,n,i){return function(l){var c,u,h,f,p,d,g,v,m,y,x,b=l,_=$r(),w=en(e,r,n,i),k={point:M,lineStart:function(){k.point=S,u&&u.push(h=[]);y=!0,m=!1,g=v=NaN},lineEnd:function(){c&&(S(f,p),d&&m&&_.rejoin(),c.push(_.buffer()));k.point=M,m&&l.lineEnd()},polygonStart:function(){l=_,c=[],u=[],x=!0},polygonEnd:function(){l=b,c=t.merge(c);var r=function(t){for(var e=0,r=u.length,n=t[1],i=0;i<r;++i)for(var a,o=1,s=u[i],l=s.length,c=s[0];o<l;++o)a=s[o],c[1]<=n?a[1]>n&&Ot(c,a,t)>0&&++e:a[1]<=n&&Ot(c,a,t)<0&&--e,c=a;return 0!==e}([e,i]),n=x&&r,a=c.length;(n||a)&&(l.polygonStart(),n&&(l.lineStart(),T(null,null,1,l),l.lineEnd()),a&&Wr(c,o,r,T,l),l.polygonEnd()),c=u=h=null}};function T(t,o,l,c){var u=0,h=0;if(null==t||(u=a(t,l))!==(h=a(o,l))||s(t,o)<0^l>0)do{c.point(0===u||3===u?e:n,u>1?i:r)}while((u=(u+l+4)%4)!==h);else c.point(o[0],o[1])}function A(t,a){return e<=t&&t<=n&&r<=a&&a<=i}function M(t,e){A(t,e)&&l.point(t,e)}function S(t,e){var r=A(t=Math.max(-rn,Math.min(rn,t)),e=Math.max(-rn,Math.min(rn,e)));if(u&&h.push([t,e]),y)f=t,p=e,d=r,y=!1,r&&(l.lineStart(),l.point(t,e));else if(r&&m)l.point(t,e);else{var n={a:{x:g,y:v},b:{x:t,y:e}};w(n)?(m||(l.lineStart(),l.point(n.a.x,n.a.y)),l.point(n.b.x,n.b.y),r||l.lineEnd(),x=!1):r&&(l.lineStart(),l.point(t,e),x=!1)}g=t,v=e,m=r}return k};function a(t,i){return y(t[0]-e)<kt?i>0?0:3:y(t[0]-n)<kt?i>0?2:1:y(t[1]-r)<kt?i>0?1:0:i>0?3:2}function o(t,e){return s(t.x,e.x)}function s(t,e){var r=a(t,1),n=a(e,1);return r!==n?r-n:0===r?e[1]-t[1]:1===r?t[0]-e[0]:2===r?t[1]-e[1]:e[0]-t[0]}}function an(t){var e=0,r=At/3,n=Cn(t),i=n(e,r);return i.parallels=function(t){return arguments.length?n(e=t[0]*At/180,r=t[1]*At/180):[e/At*180,r/At*180]},i}function on(t,e){var r=Math.sin(t),n=(r+Math.sin(e))/2,i=1+r*(2*n-r),a=Math.sqrt(i)/n;function o(t,e){var r=Math.sqrt(i-2*n*Math.sin(e))/n;return[r*Math.sin(t*=n),a-r*Math.cos(t)]}return o.invert=function(t,e){var r=a-e;return[Math.atan2(t,r)/n,It((i-(t*t+r*r)*n*n)/(2*n))]},o}t.geo.clipExtent=function(){var t,e,r,n,i,a,o={stream:function(t){return i&&(i.valid=!1),(i=a(t)).valid=!0,i},extent:function(s){return arguments.length?(a=nn(t=+s[0][0],e=+s[0][1],r=+s[1][0],n=+s[1][1]),i&&(i.valid=!1,i=null),o):[[t,e],[r,n]]}};return o.extent([[0,0],[960,500]])},(t.geo.conicEqualArea=function(){return an(on)}).raw=on,t.geo.albers=function(){return t.geo.conicEqualArea().rotate([96,0]).center([-.6,38.7]).parallels([29.5,45.5]).scale(1070)},t.geo.albersUsa=function(){var e,r,n,i,a=t.geo.albers(),o=t.geo.conicEqualArea().rotate([154,0]).center([-2,58.5]).parallels([55,65]),s=t.geo.conicEqualArea().rotate([157,0]).center([-3,19.9]).parallels([8,18]),l={point:function(t,r){e=[t,r]}};function c(t){var a=t[0],o=t[1];return e=null,r(a,o),e||(n(a,o),e)||i(a,o),e}return c.invert=function(t){var e=a.scale(),r=a.translate(),n=(t[0]-r[0])/e,i=(t[1]-r[1])/e;return(i>=.12&&i<.234&&n>=-.425&&n<-.214?o:i>=.166&&i<.234&&n>=-.214&&n<-.115?s:a).invert(t)},c.stream=function(t){var e=a.stream(t),r=o.stream(t),n=s.stream(t);return{point:function(t,i){e.point(t,i),r.point(t,i),n.point(t,i)},sphere:function(){e.sphere(),r.sphere(),n.sphere()},lineStart:function(){e.lineStart(),r.lineStart(),n.lineStart()},lineEnd:function(){e.lineEnd(),r.lineEnd(),n.lineEnd()},polygonStart:function(){e.polygonStart(),r.polygonStart(),n.polygonStart()},polygonEnd:function(){e.polygonEnd(),r.polygonEnd(),n.polygonEnd()}}},c.precision=function(t){return arguments.length?(a.precision(t),o.precision(t),s.precision(t),c):a.precision()},c.scale=function(t){return arguments.length?(a.scale(t),o.scale(.35*t),s.scale(t),c.translate(a.translate())):a.scale()},c.translate=function(t){if(!arguments.length)return a.translate();var e=a.scale(),u=+t[0],h=+t[1];return r=a.translate(t).clipExtent([[u-.455*e,h-.238*e],[u+.455*e,h+.238*e]]).stream(l).point,n=o.translate([u-.307*e,h+.201*e]).clipExtent([[u-.425*e+kt,h+.12*e+kt],[u-.214*e-kt,h+.234*e-kt]]).stream(l).point,i=s.translate([u-.205*e,h+.212*e]).clipExtent([[u-.214*e+kt,h+.166*e+kt],[u-.115*e-kt,h+.234*e-kt]]).stream(l).point,c},c.scale(1070)};var sn,ln,cn,un,hn,fn,pn={point:D,lineStart:D,lineEnd:D,polygonStart:function(){ln=0,pn.lineStart=dn},polygonEnd:function(){pn.lineStart=pn.lineEnd=pn.point=D,sn+=y(ln/2)}};function dn(){var t,e,r,n;function i(t,e){ln+=n*t-r*e,r=t,n=e}pn.point=function(a,o){pn.point=i,t=r=a,e=n=o},pn.lineEnd=function(){i(t,e)}}var gn={point:function(t,e){t<cn&&(cn=t);t>hn&&(hn=t);e<un&&(un=e);e>fn&&(fn=e)},lineStart:D,lineEnd:D,polygonStart:D,polygonEnd:D};function vn(){var t=mn(4.5),e=[],r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(e){return t=mn(e),r},result:function(){if(e.length){var t=e.join(\"\");return e=[],t}}};function n(r,n){e.push(\"M\",r,\",\",n,t)}function i(t,n){e.push(\"M\",t,\",\",n),r.point=a}function a(t,r){e.push(\"L\",t,\",\",r)}function o(){r.point=n}function s(){e.push(\"Z\")}return r}function mn(t){return\"m0,\"+t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+-2*t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+2*t+\"z\"}var yn,xn={point:bn,lineStart:_n,lineEnd:wn,polygonStart:function(){xn.lineStart=kn},polygonEnd:function(){xn.point=bn,xn.lineStart=_n,xn.lineEnd=wn}};function bn(t,e){xr+=t,br+=e,++_r}function _n(){var t,e;function r(r,n){var i=r-t,a=n-e,o=Math.sqrt(i*i+a*a);wr+=o*(t+r)/2,kr+=o*(e+n)/2,Tr+=o,bn(t=r,e=n)}xn.point=function(n,i){xn.point=r,bn(t=n,e=i)}}function wn(){xn.point=bn}function kn(){var t,e,r,n;function i(t,e){var i=t-r,a=e-n,o=Math.sqrt(i*i+a*a);wr+=o*(r+t)/2,kr+=o*(n+e)/2,Tr+=o,Ar+=(o=n*t-r*e)*(r+t),Mr+=o*(n+e),Sr+=3*o,bn(r=t,n=e)}xn.point=function(a,o){xn.point=i,bn(t=r=a,e=n=o)},xn.lineEnd=function(){i(t,e)}}function Tn(t){var e=4.5,r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(t){return e=t,r},result:D};function n(r,n){t.moveTo(r+e,n),t.arc(r,n,e,0,Mt)}function i(e,n){t.moveTo(e,n),r.point=a}function a(e,r){t.lineTo(e,r)}function o(){r.point=n}function s(){t.closePath()}return r}function An(t){var e=.5,r=Math.cos(30*Ct),n=16;function i(e){return(n?function(e){var r,i,o,s,l,c,u,h,f,p,d,g,v={point:m,lineStart:y,lineEnd:b,polygonStart:function(){e.polygonStart(),v.lineStart=_},polygonEnd:function(){e.polygonEnd(),v.lineStart=y}};function m(r,n){r=t(r,n),e.point(r[0],r[1])}function y(){h=NaN,v.point=x,e.lineStart()}function x(r,i){var o=Pr([r,i]),s=t(r,i);a(h,f,u,p,d,g,h=s[0],f=s[1],u=r,p=o[0],d=o[1],g=o[2],n,e),e.point(h,f)}function b(){v.point=m,e.lineEnd()}function _(){y(),v.point=w,v.lineEnd=k}function w(t,e){x(r=t,e),i=h,o=f,s=p,l=d,c=g,v.point=x}function k(){a(h,f,u,p,d,g,i,o,r,s,l,c,n,e),v.lineEnd=b,b()}return v}:function(e){return Sn(e,function(r,n){r=t(r,n),e.point(r[0],r[1])})})(e)}function a(n,i,o,s,l,c,u,h,f,p,d,g,v,m){var x=u-n,b=h-i,_=x*x+b*b;if(_>4*e&&v--){var w=s+p,k=l+d,T=c+g,A=Math.sqrt(w*w+k*k+T*T),M=Math.asin(T/=A),S=y(y(T)-1)<kt||y(o-f)<kt?(o+f)/2:Math.atan2(k,w),E=t(S,M),C=E[0],L=E[1],P=C-n,O=L-i,z=b*P-x*O;(z*z/_>e||y((x*P+b*O)/_-.5)>.3||s*p+l*d+c*g<r)&&(a(n,i,o,s,l,c,C,L,S,w/=A,k/=A,T,v,m),m.point(C,L),a(C,L,S,w,k,T,u,h,f,p,d,g,v,m))}}return i.precision=function(t){return arguments.length?(n=(e=t*t)>0&&16,i):Math.sqrt(e)},i}function Mn(t){this.stream=t}function Sn(t,e){return{point:e,sphere:function(){t.sphere()},lineStart:function(){t.lineStart()},lineEnd:function(){t.lineEnd()},polygonStart:function(){t.polygonStart()},polygonEnd:function(){t.polygonEnd()}}}function En(t){return Cn(function(){return t})()}function Cn(e){var r,n,i,a,o,s,l=An(function(t,e){return[(t=r(t,e))[0]*c+a,o-t[1]*c]}),c=150,u=480,h=250,f=0,p=0,d=0,g=0,v=0,m=tn,x=P,b=null,_=null;function w(t){return[(t=i(t[0]*Ct,t[1]*Ct))[0]*c+a,o-t[1]*c]}function k(t){return(t=i.invert((t[0]-a)/c,(o-t[1])/c))&&[t[0]*Lt,t[1]*Lt]}function T(){i=Gr(n=zn(d,g,v),r);var t=r(f,p);return a=u-t[0]*c,o=h+t[1]*c,A()}function A(){return s&&(s.valid=!1,s=null),w}return w.stream=function(t){return s&&(s.valid=!1),(s=Ln(m(n,l(x(t))))).valid=!0,s},w.clipAngle=function(t){return arguments.length?(m=null==t?(b=t,tn):function(t){var e=Math.cos(t),r=e>0,n=y(e)>kt;return Jr(i,function(t){var e,s,l,c,u;return{lineStart:function(){c=l=!1,u=1},point:function(h,f){var p,d=[h,f],g=i(h,f),v=r?g?0:o(h,f):g?o(h+(h<0?At:-At),f):0;if(!e&&(c=l=g)&&t.lineStart(),g!==l&&(p=a(e,d),(Br(e,p)||Br(d,p))&&(d[0]+=kt,d[1]+=kt,g=i(d[0],d[1]))),g!==l)u=0,g?(t.lineStart(),p=a(d,e),t.point(p[0],p[1])):(p=a(e,d),t.point(p[0],p[1]),t.lineEnd()),e=p;else if(n&&e&&r^g){var m;v&s||!(m=a(d,e,!0))||(u=0,r?(t.lineStart(),t.point(m[0][0],m[0][1]),t.point(m[1][0],m[1][1]),t.lineEnd()):(t.point(m[1][0],m[1][1]),t.lineEnd(),t.lineStart(),t.point(m[0][0],m[0][1])))}!g||e&&Br(e,d)||t.point(d[0],d[1]),e=d,l=g,s=v},lineEnd:function(){l&&t.lineEnd(),e=null},clean:function(){return u|(c&&l)<<1}}},Fn(t,6*Ct),r?[0,-t]:[-At,t-At]);function i(t,r){return Math.cos(t)*Math.cos(r)>e}function a(t,r,n){var i=[1,0,0],a=zr(Pr(t),Pr(r)),o=Or(a,a),s=a[0],l=o-s*s;if(!l)return!n&&t;var c=e*o/l,u=-e*s/l,h=zr(i,a),f=Dr(i,c);Ir(f,Dr(a,u));var p=h,d=Or(f,p),g=Or(p,p),v=d*d-g*(Or(f,f)-1);if(!(v<0)){var m=Math.sqrt(v),x=Dr(p,(-d-m)/g);if(Ir(x,f),x=Fr(x),!n)return x;var b,_=t[0],w=r[0],k=t[1],T=r[1];w<_&&(b=_,_=w,w=b);var A=w-_,M=y(A-At)<kt;if(!M&&T<k&&(b=k,k=T,T=b),M||A<kt?M?k+T>0^x[1]<(y(x[0]-_)<kt?k:T):k<=x[1]&&x[1]<=T:A>At^(_<=x[0]&&x[0]<=w)){var S=Dr(p,(-d+m)/g);return Ir(S,f),[x,Fr(S)]}}}function o(e,n){var i=r?t:At-t,a=0;return e<-i?a|=1:e>i&&(a|=2),n<-i?a|=4:n>i&&(a|=8),a}}((b=+t)*Ct),A()):b},w.clipExtent=function(t){return arguments.length?(_=t,x=t?nn(t[0][0],t[0][1],t[1][0],t[1][1]):P,A()):_},w.scale=function(t){return arguments.length?(c=+t,T()):c},w.translate=function(t){return arguments.length?(u=+t[0],h=+t[1],T()):[u,h]},w.center=function(t){return arguments.length?(f=t[0]%360*Ct,p=t[1]%360*Ct,T()):[f*Lt,p*Lt]},w.rotate=function(t){return arguments.length?(d=t[0]%360*Ct,g=t[1]%360*Ct,v=t.length>2?t[2]%360*Ct:0,T()):[d*Lt,g*Lt,v*Lt]},t.rebind(w,l,\"precision\"),function(){return r=e.apply(this,arguments),w.invert=r.invert&&k,T()}}function Ln(t){return Sn(t,function(e,r){t.point(e*Ct,r*Ct)})}function Pn(t,e){return[t,e]}function On(t,e){return[t>At?t-Mt:t<-At?t+Mt:t,e]}function zn(t,e,r){return t?e||r?Gr(Dn(t),Rn(e,r)):Dn(t):e||r?Rn(e,r):On}function In(t){return function(e,r){return[(e+=t)>At?e-Mt:e<-At?e+Mt:e,r]}}function Dn(t){var e=In(t);return e.invert=In(-t),e}function Rn(t,e){var r=Math.cos(t),n=Math.sin(t),i=Math.cos(e),a=Math.sin(e);function o(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*r+s*n;return[Math.atan2(l*i-u*a,s*r-c*n),It(u*i+l*a)]}return o.invert=function(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*i-l*a;return[Math.atan2(l*i+c*a,s*r+u*n),It(u*r-s*n)]},o}function Fn(t,e){var r=Math.cos(t),n=Math.sin(t);return function(i,a,o,s){var l=o*e;null!=i?(i=Bn(r,i),a=Bn(r,a),(o>0?i<a:i>a)&&(i+=o*Mt)):(i=t+o*Mt,a=t-.5*l);for(var c,u=i;o>0?u>a:u<a;u-=l)s.point((c=Fr([r,-n*Math.cos(u),-n*Math.sin(u)]))[0],c[1])}}function Bn(t,e){var r=Pr(e);r[0]-=t,Rr(r);var n=zt(-r[1]);return((-r[2]<0?-n:n)+2*Math.PI-kt)%(2*Math.PI)}function Nn(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map(function(e){return[t,e]})}}function jn(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map(function(e){return[e,t]})}}function Un(t){return t.source}function Vn(t){return t.target}t.geo.path=function(){var e,r,n,i,a,o=4.5;function s(e){return e&&(\"function\"==typeof o&&i.pointRadius(+o.apply(this,arguments)),a&&a.valid||(a=n(i)),t.geo.stream(e,a)),i.result()}function l(){return a=null,s}return s.area=function(e){return sn=0,t.geo.stream(e,n(pn)),sn},s.centroid=function(e){return xr=br=_r=wr=kr=Tr=Ar=Mr=Sr=0,t.geo.stream(e,n(xn)),Sr?[Ar/Sr,Mr/Sr]:Tr?[wr/Tr,kr/Tr]:_r?[xr/_r,br/_r]:[NaN,NaN]},s.bounds=function(e){return hn=fn=-(cn=un=1/0),t.geo.stream(e,n(gn)),[[cn,un],[hn,fn]]},s.projection=function(t){return arguments.length?(n=(e=t)?t.stream||(r=t,i=An(function(t,e){return r([t*Lt,e*Lt])}),function(t){return Ln(i(t))}):P,l()):e;var r,i},s.context=function(t){return arguments.length?(i=null==(r=t)?new vn:new Tn(t),\"function\"!=typeof o&&i.pointRadius(o),l()):r},s.pointRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:(i.pointRadius(+t),+t),s):o},s.projection(t.geo.albersUsa()).context(null)},t.geo.transform=function(t){return{stream:function(e){var r=new Mn(e);for(var n in t)r[n]=t[n];return r}}},Mn.prototype={point:function(t,e){this.stream.point(t,e)},sphere:function(){this.stream.sphere()},lineStart:function(){this.stream.lineStart()},lineEnd:function(){this.stream.lineEnd()},polygonStart:function(){this.stream.polygonStart()},polygonEnd:function(){this.stream.polygonEnd()}},t.geo.projection=En,t.geo.projectionMutator=Cn,(t.geo.equirectangular=function(){return En(Pn)}).raw=Pn.invert=Pn,t.geo.rotation=function(t){function e(e){return(e=t(e[0]*Ct,e[1]*Ct))[0]*=Lt,e[1]*=Lt,e}return t=zn(t[0]%360*Ct,t[1]*Ct,t.length>2?t[2]*Ct:0),e.invert=function(e){return(e=t.invert(e[0]*Ct,e[1]*Ct))[0]*=Lt,e[1]*=Lt,e},e},On.invert=Pn,t.geo.circle=function(){var t,e,r=[0,0],n=6;function i(){var t=\"function\"==typeof r?r.apply(this,arguments):r,n=zn(-t[0]*Ct,-t[1]*Ct,0).invert,i=[];return e(null,null,1,{point:function(t,e){i.push(t=n(t,e)),t[0]*=Lt,t[1]*=Lt}}),{type:\"Polygon\",coordinates:[i]}}return i.origin=function(t){return arguments.length?(r=t,i):r},i.angle=function(r){return arguments.length?(e=Fn((t=+r)*Ct,n*Ct),i):t},i.precision=function(r){return arguments.length?(e=Fn(t*Ct,(n=+r)*Ct),i):n},i.angle(90)},t.geo.distance=function(t,e){var r,n=(e[0]-t[0])*Ct,i=t[1]*Ct,a=e[1]*Ct,o=Math.sin(n),s=Math.cos(n),l=Math.sin(i),c=Math.cos(i),u=Math.sin(a),h=Math.cos(a);return Math.atan2(Math.sqrt((r=h*o)*r+(r=c*u-l*h*s)*r),l*u+c*h*s)},t.geo.graticule=function(){var e,r,n,i,a,o,s,l,c,u,h,f,p=10,d=p,g=90,v=360,m=2.5;function x(){return{type:\"MultiLineString\",coordinates:b()}}function b(){return t.range(Math.ceil(i/g)*g,n,g).map(h).concat(t.range(Math.ceil(l/v)*v,s,v).map(f)).concat(t.range(Math.ceil(r/p)*p,e,p).filter(function(t){return y(t%g)>kt}).map(c)).concat(t.range(Math.ceil(o/d)*d,a,d).filter(function(t){return y(t%v)>kt}).map(u))}return x.lines=function(){return b().map(function(t){return{type:\"LineString\",coordinates:t}})},x.outline=function(){return{type:\"Polygon\",coordinates:[h(i).concat(f(s).slice(1),h(n).reverse().slice(1),f(l).reverse().slice(1))]}},x.extent=function(t){return arguments.length?x.majorExtent(t).minorExtent(t):x.minorExtent()},x.majorExtent=function(t){return arguments.length?(i=+t[0][0],n=+t[1][0],l=+t[0][1],s=+t[1][1],i>n&&(t=i,i=n,n=t),l>s&&(t=l,l=s,s=t),x.precision(m)):[[i,l],[n,s]]},x.minorExtent=function(t){return arguments.length?(r=+t[0][0],e=+t[1][0],o=+t[0][1],a=+t[1][1],r>e&&(t=r,r=e,e=t),o>a&&(t=o,o=a,a=t),x.precision(m)):[[r,o],[e,a]]},x.step=function(t){return arguments.length?x.majorStep(t).minorStep(t):x.minorStep()},x.majorStep=function(t){return arguments.length?(g=+t[0],v=+t[1],x):[g,v]},x.minorStep=function(t){return arguments.length?(p=+t[0],d=+t[1],x):[p,d]},x.precision=function(t){return arguments.length?(m=+t,c=Nn(o,a,90),u=jn(r,e,m),h=Nn(l,s,90),f=jn(i,n,m),x):m},x.majorExtent([[-180,-90+kt],[180,90-kt]]).minorExtent([[-180,-80-kt],[180,80+kt]])},t.geo.greatArc=function(){var e,r,n=Un,i=Vn;function a(){return{type:\"LineString\",coordinates:[e||n.apply(this,arguments),r||i.apply(this,arguments)]}}return a.distance=function(){return t.geo.distance(e||n.apply(this,arguments),r||i.apply(this,arguments))},a.source=function(t){return arguments.length?(n=t,e=\"function\"==typeof t?null:t,a):n},a.target=function(t){return arguments.length?(i=t,r=\"function\"==typeof t?null:t,a):i},a.precision=function(){return arguments.length?a:0},a},t.geo.interpolate=function(t,e){return r=t[0]*Ct,n=t[1]*Ct,i=e[0]*Ct,a=e[1]*Ct,o=Math.cos(n),s=Math.sin(n),l=Math.cos(a),c=Math.sin(a),u=o*Math.cos(r),h=o*Math.sin(r),f=l*Math.cos(i),p=l*Math.sin(i),d=2*Math.asin(Math.sqrt(Rt(a-n)+o*l*Rt(i-r))),g=1/Math.sin(d),(v=d?function(t){var e=Math.sin(t*=d)*g,r=Math.sin(d-t)*g,n=r*u+e*f,i=r*h+e*p,a=r*s+e*c;return[Math.atan2(i,n)*Lt,Math.atan2(a,Math.sqrt(n*n+i*i))*Lt]}:function(){return[r*Lt,n*Lt]}).distance=d,v;var r,n,i,a,o,s,l,c,u,h,f,p,d,g,v},t.geo.length=function(e){return yn=0,t.geo.stream(e,qn),yn};var qn={sphere:D,point:D,lineStart:function(){var t,e,r;function n(n,i){var a=Math.sin(i*=Ct),o=Math.cos(i),s=y((n*=Ct)-t),l=Math.cos(s);yn+=Math.atan2(Math.sqrt((s=o*Math.sin(s))*s+(s=r*a-e*o*l)*s),e*a+r*o*l),t=n,e=a,r=o}qn.point=function(i,a){t=i*Ct,e=Math.sin(a*=Ct),r=Math.cos(a),qn.point=n},qn.lineEnd=function(){qn.point=qn.lineEnd=D}},lineEnd:D,polygonStart:D,polygonEnd:D};function Hn(t,e){function r(e,r){var n=Math.cos(e),i=Math.cos(r),a=t(n*i);return[a*i*Math.sin(e),a*Math.sin(r)]}return r.invert=function(t,r){var n=Math.sqrt(t*t+r*r),i=e(n),a=Math.sin(i),o=Math.cos(i);return[Math.atan2(t*a,n*o),Math.asin(n&&r*a/n)]},r}var Gn=Hn(function(t){return Math.sqrt(2/(1+t))},function(t){return 2*Math.asin(t/2)});(t.geo.azimuthalEqualArea=function(){return En(Gn)}).raw=Gn;var Yn=Hn(function(t){var e=Math.acos(t);return e&&e/Math.sin(e)},P);function Wn(t,e){var r=Math.cos(t),n=function(t){return Math.tan(At/4+t/2)},i=t===e?Math.sin(t):Math.log(r/Math.cos(e))/Math.log(n(e)/n(t)),a=r*Math.pow(n(t),i)/i;if(!i)return Jn;function o(t,e){a>0?e<-Et+kt&&(e=-Et+kt):e>Et-kt&&(e=Et-kt);var r=a/Math.pow(n(e),i);return[r*Math.sin(i*t),a-r*Math.cos(i*t)]}return o.invert=function(t,e){var r=a-e,n=Pt(i)*Math.sqrt(t*t+r*r);return[Math.atan2(t,r)/i,2*Math.atan(Math.pow(a/n,1/i))-Et]},o}function Xn(t,e){var r=Math.cos(t),n=t===e?Math.sin(t):(r-Math.cos(e))/(e-t),i=r/n+t;if(y(n)<kt)return Pn;function a(t,e){var r=i-e;return[r*Math.sin(n*t),i-r*Math.cos(n*t)]}return a.invert=function(t,e){var r=i-e;return[Math.atan2(t,r)/n,i-Pt(n)*Math.sqrt(t*t+r*r)]},a}(t.geo.azimuthalEquidistant=function(){return En(Yn)}).raw=Yn,(t.geo.conicConformal=function(){return an(Wn)}).raw=Wn,(t.geo.conicEquidistant=function(){return an(Xn)}).raw=Xn;var Zn=Hn(function(t){return 1/t},Math.atan);function Jn(t,e){return[t,Math.log(Math.tan(At/4+e/2))]}function Kn(t){var e,r=En(t),n=r.scale,i=r.translate,a=r.clipExtent;return r.scale=function(){var t=n.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.translate=function(){var t=i.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.clipExtent=function(t){var o=a.apply(r,arguments);if(o===r){if(e=null==t){var s=At*n(),l=i();a([[l[0]-s,l[1]-s],[l[0]+s,l[1]+s]])}}else e&&(o=null);return o},r.clipExtent(null)}(t.geo.gnomonic=function(){return En(Zn)}).raw=Zn,Jn.invert=function(t,e){return[t,2*Math.atan(Math.exp(e))-Et]},(t.geo.mercator=function(){return Kn(Jn)}).raw=Jn;var $n=Hn(function(){return 1},Math.asin);(t.geo.orthographic=function(){return En($n)}).raw=$n;var Qn=Hn(function(t){return 1/(1+t)},function(t){return 2*Math.atan(t)});function ti(t,e){return[Math.log(Math.tan(At/4+e/2)),-t]}function ei(t){return t[0]}function ri(t){return t[1]}function ni(t){for(var e=t.length,r=[0,1],n=2,i=2;i<e;i++){for(;n>1&&Ot(t[r[n-2]],t[r[n-1]],t[i])<=0;)--n;r[n++]=i}return r.slice(0,n)}function ii(t,e){return t[0]-e[0]||t[1]-e[1]}(t.geo.stereographic=function(){return En(Qn)}).raw=Qn,ti.invert=function(t,e){return[-e,2*Math.atan(Math.exp(t))-Et]},(t.geo.transverseMercator=function(){var t=Kn(ti),e=t.center,r=t.rotate;return t.center=function(t){return t?e([-t[1],t[0]]):[(t=e())[1],-t[0]]},t.rotate=function(t){return t?r([t[0],t[1],t.length>2?t[2]+90:90]):[(t=r())[0],t[1],t[2]-90]},r([0,0,90])}).raw=ti,t.geom={},t.geom.hull=function(t){var e=ei,r=ri;if(arguments.length)return n(t);function n(t){if(t.length<3)return[];var n,i=ve(e),a=ve(r),o=t.length,s=[],l=[];for(n=0;n<o;n++)s.push([+i.call(this,t[n],n),+a.call(this,t[n],n),n]);for(s.sort(ii),n=0;n<o;n++)l.push([s[n][0],-s[n][1]]);var c=ni(s),u=ni(l),h=u[0]===c[0],f=u[u.length-1]===c[c.length-1],p=[];for(n=c.length-1;n>=0;--n)p.push(t[s[c[n]][2]]);for(n=+h;n<u.length-f;++n)p.push(t[s[u[n]][2]]);return p}return n.x=function(t){return arguments.length?(e=t,n):e},n.y=function(t){return arguments.length?(r=t,n):r},n},t.geom.polygon=function(t){return V(t,ai),t};var ai=t.geom.polygon.prototype=[];function oi(t,e,r){return(r[0]-e[0])*(t[1]-e[1])<(r[1]-e[1])*(t[0]-e[0])}function si(t,e,r,n){var i=t[0],a=r[0],o=e[0]-i,s=n[0]-a,l=t[1],c=r[1],u=e[1]-l,h=n[1]-c,f=(s*(l-c)-h*(i-a))/(h*o-s*u);return[i+f*o,l+f*u]}function li(t){var e=t[0],r=t[t.length-1];return!(e[0]-r[0]||e[1]-r[1])}ai.area=function(){for(var t,e=-1,r=this.length,n=this[r-1],i=0;++e<r;)t=n,n=this[e],i+=t[1]*n[0]-t[0]*n[1];return.5*i},ai.centroid=function(t){var e,r,n=-1,i=this.length,a=0,o=0,s=this[i-1];for(arguments.length||(t=-1/(6*this.area()));++n<i;)e=s,s=this[n],r=e[0]*s[1]-s[0]*e[1],a+=(e[0]+s[0])*r,o+=(e[1]+s[1])*r;return[a*t,o*t]},ai.clip=function(t){for(var e,r,n,i,a,o,s=li(t),l=-1,c=this.length-li(this),u=this[c-1];++l<c;){for(e=t.slice(),t.length=0,i=this[l],a=e[(n=e.length-s)-1],r=-1;++r<n;)oi(o=e[r],u,i)?(oi(a,u,i)||t.push(si(a,o,u,i)),t.push(o)):oi(a,u,i)&&t.push(si(a,o,u,i)),a=o;s&&t.push(t[0]),u=i}return t};var ci,ui,hi,fi,pi,di=[],gi=[];function vi(){Ii(this),this.edge=this.site=this.circle=null}function mi(t){var e=di.pop()||new vi;return e.site=t,e}function yi(t){Si(t),hi.remove(t),di.push(t),Ii(t)}function xi(t){var e=t.circle,r=e.x,n=e.cy,i={x:r,y:n},a=t.P,o=t.N,s=[t];yi(t);for(var l=a;l.circle&&y(r-l.circle.x)<kt&&y(n-l.circle.cy)<kt;)a=l.P,s.unshift(l),yi(l),l=a;s.unshift(l),Si(l);for(var c=o;c.circle&&y(r-c.circle.x)<kt&&y(n-c.circle.cy)<kt;)o=c.N,s.push(c),yi(c),c=o;s.push(c),Si(c);var u,h=s.length;for(u=1;u<h;++u)c=s[u],l=s[u-1],Pi(c.edge,l.site,c.site,i);l=s[0],(c=s[h-1]).edge=Li(l.site,c.site,null,i),Mi(l),Mi(c)}function bi(t){for(var e,r,n,i,a=t.x,o=t.y,s=hi._;s;)if((n=_i(s,o)-a)>kt)s=s.L;else{if(!((i=a-wi(s,o))>kt)){n>-kt?(e=s.P,r=s):i>-kt?(e=s,r=s.N):e=r=s;break}if(!s.R){e=s;break}s=s.R}var l=mi(t);if(hi.insert(e,l),e||r){if(e===r)return Si(e),r=mi(e.site),hi.insert(l,r),l.edge=r.edge=Li(e.site,l.site),Mi(e),void Mi(r);if(r){Si(e),Si(r);var c=e.site,u=c.x,h=c.y,f=t.x-u,p=t.y-h,d=r.site,g=d.x-u,v=d.y-h,m=2*(f*v-p*g),y=f*f+p*p,x=g*g+v*v,b={x:(v*y-p*x)/m+u,y:(f*x-g*y)/m+h};Pi(r.edge,c,d,b),l.edge=Li(c,t,null,b),r.edge=Li(t,d,null,b),Mi(e),Mi(r)}else l.edge=Li(e.site,l.site)}}function _i(t,e){var r=t.site,n=r.x,i=r.y,a=i-e;if(!a)return n;var o=t.P;if(!o)return-1/0;var s=(r=o.site).x,l=r.y,c=l-e;if(!c)return s;var u=s-n,h=1/a-1/c,f=u/c;return h?(-f+Math.sqrt(f*f-2*h*(u*u/(-2*c)-l+c/2+i-a/2)))/h+n:(n+s)/2}function wi(t,e){var r=t.N;if(r)return _i(r,e);var n=t.site;return n.y===e?n.x:1/0}function ki(t){this.site=t,this.edges=[]}function Ti(t,e){return e.angle-t.angle}function Ai(){Ii(this),this.x=this.y=this.arc=this.site=this.cy=null}function Mi(t){var e=t.P,r=t.N;if(e&&r){var n=e.site,i=t.site,a=r.site;if(n!==a){var o=i.x,s=i.y,l=n.x-o,c=n.y-s,u=a.x-o,h=2*(l*(v=a.y-s)-c*u);if(!(h>=-Tt)){var f=l*l+c*c,p=u*u+v*v,d=(v*f-c*p)/h,g=(l*p-u*f)/h,v=g+s,m=gi.pop()||new Ai;m.arc=t,m.site=i,m.x=d+o,m.y=v+Math.sqrt(d*d+g*g),m.cy=v,t.circle=m;for(var y=null,x=pi._;x;)if(m.y<x.y||m.y===x.y&&m.x<=x.x){if(!x.L){y=x.P;break}x=x.L}else{if(!x.R){y=x;break}x=x.R}pi.insert(y,m),y||(fi=m)}}}}function Si(t){var e=t.circle;e&&(e.P||(fi=e.N),pi.remove(e),gi.push(e),Ii(e),t.circle=null)}function Ei(t,e){var r=t.b;if(r)return!0;var n,i,a=t.a,o=e[0][0],s=e[1][0],l=e[0][1],c=e[1][1],u=t.l,h=t.r,f=u.x,p=u.y,d=h.x,g=h.y,v=(f+d)/2,m=(p+g)/2;if(g===p){if(v<o||v>=s)return;if(f>d){if(a){if(a.y>=c)return}else a={x:v,y:l};r={x:v,y:c}}else{if(a){if(a.y<l)return}else a={x:v,y:c};r={x:v,y:l}}}else if(i=m-(n=(f-d)/(g-p))*v,n<-1||n>1)if(f>d){if(a){if(a.y>=c)return}else a={x:(l-i)/n,y:l};r={x:(c-i)/n,y:c}}else{if(a){if(a.y<l)return}else a={x:(c-i)/n,y:c};r={x:(l-i)/n,y:l}}else if(p<g){if(a){if(a.x>=s)return}else a={x:o,y:n*o+i};r={x:s,y:n*s+i}}else{if(a){if(a.x<o)return}else a={x:s,y:n*s+i};r={x:o,y:n*o+i}}return t.a=a,t.b=r,!0}function Ci(t,e){this.l=t,this.r=e,this.a=this.b=null}function Li(t,e,r,n){var i=new Ci(t,e);return ci.push(i),r&&Pi(i,t,e,r),n&&Pi(i,e,t,n),ui[t.i].edges.push(new Oi(i,t,e)),ui[e.i].edges.push(new Oi(i,e,t)),i}function Pi(t,e,r,n){t.a||t.b?t.l===r?t.b=n:t.a=n:(t.a=n,t.l=e,t.r=r)}function Oi(t,e,r){var n=t.a,i=t.b;this.edge=t,this.site=e,this.angle=r?Math.atan2(r.y-e.y,r.x-e.x):t.l===e?Math.atan2(i.x-n.x,n.y-i.y):Math.atan2(n.x-i.x,i.y-n.y)}function zi(){this._=null}function Ii(t){t.U=t.C=t.L=t.R=t.P=t.N=null}function Di(t,e){var r=e,n=e.R,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.R=n.L,r.R&&(r.R.U=r),n.L=r}function Ri(t,e){var r=e,n=e.L,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.L=n.R,r.L&&(r.L.U=r),n.R=r}function Fi(t){for(;t.L;)t=t.L;return t}function Bi(t,e){var r,n,i,a=t.sort(Ni).pop();for(ci=[],ui=new Array(t.length),hi=new zi,pi=new zi;;)if(i=fi,a&&(!i||a.y<i.y||a.y===i.y&&a.x<i.x))a.x===r&&a.y===n||(ui[a.i]=new ki(a),bi(a),r=a.x,n=a.y),a=t.pop();else{if(!i)break;xi(i.arc)}e&&(function(t){for(var e,r=ci,n=en(t[0][0],t[0][1],t[1][0],t[1][1]),i=r.length;i--;)(!Ei(e=r[i],t)||!n(e)||y(e.a.x-e.b.x)<kt&&y(e.a.y-e.b.y)<kt)&&(e.a=e.b=null,r.splice(i,1))}(e),function(t){for(var e,r,n,i,a,o,s,l,c,u,h=t[0][0],f=t[1][0],p=t[0][1],d=t[1][1],g=ui,v=g.length;v--;)if((a=g[v])&&a.prepare())for(l=(s=a.edges).length,o=0;o<l;)n=(u=s[o].end()).x,i=u.y,e=(c=s[++o%l].start()).x,r=c.y,(y(n-e)>kt||y(i-r)>kt)&&(s.splice(o,0,new Oi((m=a.site,x=u,b=y(n-h)<kt&&d-i>kt?{x:h,y:y(e-h)<kt?r:d}:y(i-d)<kt&&f-n>kt?{x:y(r-d)<kt?e:f,y:d}:y(n-f)<kt&&i-p>kt?{x:f,y:y(e-f)<kt?r:p}:y(i-p)<kt&&n-h>kt?{x:y(r-p)<kt?e:h,y:p}:null,_=void 0,_=new Ci(m,null),_.a=x,_.b=b,ci.push(_),_),a.site,null)),++l);var m,x,b,_}(e));var o={cells:ui,edges:ci};return hi=pi=ci=ui=null,o}function Ni(t,e){return e.y-t.y||e.x-t.x}ki.prototype.prepare=function(){for(var t,e=this.edges,r=e.length;r--;)(t=e[r].edge).b&&t.a||e.splice(r,1);return e.sort(Ti),e.length},Oi.prototype={start:function(){return this.edge.l===this.site?this.edge.a:this.edge.b},end:function(){return this.edge.l===this.site?this.edge.b:this.edge.a}},zi.prototype={insert:function(t,e){var r,n,i;if(t){if(e.P=t,e.N=t.N,t.N&&(t.N.P=e),t.N=e,t.R){for(t=t.R;t.L;)t=t.L;t.L=e}else t.R=e;r=t}else this._?(t=Fi(this._),e.P=null,e.N=t,t.P=t.L=e,r=t):(e.P=e.N=null,this._=e,r=null);for(e.L=e.R=null,e.U=r,e.C=!0,t=e;r&&r.C;)r===(n=r.U).L?(i=n.R)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.R&&(Di(this,r),r=(t=r).U),r.C=!1,n.C=!0,Ri(this,n)):(i=n.L)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.L&&(Ri(this,r),r=(t=r).U),r.C=!1,n.C=!0,Di(this,n)),r=t.U;this._.C=!1},remove:function(t){t.N&&(t.N.P=t.P),t.P&&(t.P.N=t.N),t.N=t.P=null;var e,r,n,i=t.U,a=t.L,o=t.R;if(r=a?o?Fi(o):a:o,i?i.L===t?i.L=r:i.R=r:this._=r,a&&o?(n=r.C,r.C=t.C,r.L=a,a.U=r,r!==o?(i=r.U,r.U=t.U,t=r.R,i.L=t,r.R=o,o.U=r):(r.U=i,i=r,t=r.R)):(n=t.C,t=r),t&&(t.U=i),!n)if(t&&t.C)t.C=!1;else{do{if(t===this._)break;if(t===i.L){if((e=i.R).C&&(e.C=!1,i.C=!0,Di(this,i),e=i.R),e.L&&e.L.C||e.R&&e.R.C){e.R&&e.R.C||(e.L.C=!1,e.C=!0,Ri(this,e),e=i.R),e.C=i.C,i.C=e.R.C=!1,Di(this,i),t=this._;break}}else if((e=i.L).C&&(e.C=!1,i.C=!0,Ri(this,i),e=i.L),e.L&&e.L.C||e.R&&e.R.C){e.L&&e.L.C||(e.R.C=!1,e.C=!0,Di(this,e),e=i.L),e.C=i.C,i.C=e.L.C=!1,Ri(this,i),t=this._;break}e.C=!0,t=i,i=i.U}while(!t.C);t&&(t.C=!1)}}},t.geom.voronoi=function(t){var e=ei,r=ri,n=e,i=r,a=ji;if(t)return o(t);function o(t){var e=new Array(t.length),r=a[0][0],n=a[0][1],i=a[1][0],o=a[1][1];return Bi(s(t),a).cells.forEach(function(a,s){var l=a.edges,c=a.site;(e[s]=l.length?l.map(function(t){var e=t.start();return[e.x,e.y]}):c.x>=r&&c.x<=i&&c.y>=n&&c.y<=o?[[r,o],[i,o],[i,n],[r,n]]:[]).point=t[s]}),e}function s(t){return t.map(function(t,e){return{x:Math.round(n(t,e)/kt)*kt,y:Math.round(i(t,e)/kt)*kt,i:e}})}return o.links=function(t){return Bi(s(t)).edges.filter(function(t){return t.l&&t.r}).map(function(e){return{source:t[e.l.i],target:t[e.r.i]}})},o.triangles=function(t){var e=[];return Bi(s(t)).cells.forEach(function(r,n){for(var i,a,o,s,l=r.site,c=r.edges.sort(Ti),u=-1,h=c.length,f=c[h-1].edge,p=f.l===l?f.r:f.l;++u<h;)f,i=p,p=(f=c[u].edge).l===l?f.r:f.l,n<i.i&&n<p.i&&(o=i,s=p,((a=l).x-s.x)*(o.y-a.y)-(a.x-o.x)*(s.y-a.y)<0)&&e.push([t[n],t[i.i],t[p.i]])}),e},o.x=function(t){return arguments.length?(n=ve(e=t),o):e},o.y=function(t){return arguments.length?(i=ve(r=t),o):r},o.clipExtent=function(t){return arguments.length?(a=null==t?ji:t,o):a===ji?null:a},o.size=function(t){return arguments.length?o.clipExtent(t&&[[0,0],t]):a===ji?null:a&&a[1]},o};var ji=[[-1e6,-1e6],[1e6,1e6]];function Ui(t){return t.x}function Vi(t){return t.y}function qi(e,r){e=t.rgb(e),r=t.rgb(r);var n=e.r,i=e.g,a=e.b,o=r.r-n,s=r.g-i,l=r.b-a;return function(t){return\"#\"+ce(Math.round(n+o*t))+ce(Math.round(i+s*t))+ce(Math.round(a+l*t))}}function Hi(t,e){var r,n={},i={};for(r in t)r in e?n[r]=Zi(t[r],e[r]):i[r]=t[r];for(r in e)r in t||(i[r]=e[r]);return function(t){for(r in n)i[r]=n[r](t);return i}}function Gi(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function Yi(t,e){var r,n,i,a=Wi.lastIndex=Xi.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=Wi.exec(t))&&(n=Xi.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:Gi(r,n)})),a=Xi.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?(e=l[0].x,function(t){return e(t)+\"\"}):function(){return e}:(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}t.geom.delaunay=function(e){return t.geom.voronoi().triangles(e)},t.geom.quadtree=function(t,e,r,n,i){var a,o=ei,s=ri;if(a=arguments.length)return o=Ui,s=Vi,3===a&&(i=r,n=e,r=e=0),l(t);function l(t){var l,c,u,h,f,p,d,g,v,m=ve(o),x=ve(s);if(null!=e)p=e,d=r,g=n,v=i;else if(g=v=-(p=d=1/0),c=[],u=[],f=t.length,a)for(h=0;h<f;++h)(l=t[h]).x<p&&(p=l.x),l.y<d&&(d=l.y),l.x>g&&(g=l.x),l.y>v&&(v=l.y),c.push(l.x),u.push(l.y);else for(h=0;h<f;++h){var b=+m(l=t[h],h),_=+x(l,h);b<p&&(p=b),_<d&&(d=_),b>g&&(g=b),_>v&&(v=_),c.push(b),u.push(_)}var w=g-p,k=v-d;function T(t,e,r,n,i,a,o,s){if(!isNaN(r)&&!isNaN(n))if(t.leaf){var l=t.x,c=t.y;if(null!=l)if(y(l-r)+y(c-n)<.01)A(t,e,r,n,i,a,o,s);else{var u=t.point;t.x=t.y=t.point=null,A(t,u,l,c,i,a,o,s),A(t,e,r,n,i,a,o,s)}else t.x=r,t.y=n,t.point=e}else A(t,e,r,n,i,a,o,s)}function A(t,e,r,n,i,a,o,s){var l=.5*(i+o),c=.5*(a+s),u=r>=l,h=n>=c,f=h<<1|u;t.leaf=!1,u?i=l:o=l,h?a=c:s=c,T(t=t.nodes[f]||(t.nodes[f]={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){T(M,t,+m(t,++h),+x(t,h),p,d,g,v)}}),e,r,n,i,a,o,s)}w>k?v=d+w:g=p+k;var M={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){T(M,t,+m(t,++h),+x(t,h),p,d,g,v)}};if(M.visit=function(t){!function t(e,r,n,i,a,o){if(!e(r,n,i,a,o)){var s=.5*(n+a),l=.5*(i+o),c=r.nodes;c[0]&&t(e,c[0],n,i,s,l),c[1]&&t(e,c[1],s,i,a,l),c[2]&&t(e,c[2],n,l,s,o),c[3]&&t(e,c[3],s,l,a,o)}}(t,M,p,d,g,v)},M.find=function(t){return function(t,e,r,n,i,a,o){var s,l=1/0;return function t(c,u,h,f,p){if(!(u>a||h>o||f<n||p<i)){if(d=c.point){var d,g=e-c.x,v=r-c.y,m=g*g+v*v;if(m<l){var y=Math.sqrt(l=m);n=e-y,i=r-y,a=e+y,o=r+y,s=d}}for(var x=c.nodes,b=.5*(u+f),_=.5*(h+p),w=(r>=_)<<1|e>=b,k=w+4;w<k;++w)if(c=x[3&w])switch(3&w){case 0:t(c,u,h,b,_);break;case 1:t(c,b,h,f,_);break;case 2:t(c,u,_,b,p);break;case 3:t(c,b,_,f,p)}}}(t,n,i,a,o),s}(M,t[0],t[1],p,d,g,v)},h=-1,null==e){for(;++h<f;)T(M,t[h],c[h],u[h],p,d,g,v);--h}else t.forEach(M.add);return c=u=t=l=null,M}return l.x=function(t){return arguments.length?(o=t,l):o},l.y=function(t){return arguments.length?(s=t,l):s},l.extent=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=+t[0][0],r=+t[0][1],n=+t[1][0],i=+t[1][1]),l):null==e?null:[[e,r],[n,i]]},l.size=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=r=0,n=+t[0],i=+t[1]),l):null==e?null:[n-e,i-r]},l},t.interpolateRgb=qi,t.interpolateObject=Hi,t.interpolateNumber=Gi,t.interpolateString=Yi;var Wi=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,Xi=new RegExp(Wi.source,\"g\");function Zi(e,r){for(var n,i=t.interpolators.length;--i>=0&&!(n=t.interpolators[i](e,r)););return n}function Ji(t,e){var r,n=[],i=[],a=t.length,o=e.length,s=Math.min(t.length,e.length);for(r=0;r<s;++r)n.push(Zi(t[r],e[r]));for(;r<a;++r)i[r]=t[r];for(;r<o;++r)i[r]=e[r];return function(t){for(r=0;r<s;++r)i[r]=n[r](t);return i}}t.interpolate=Zi,t.interpolators=[function(t,e){var r=typeof e;return(\"string\"===r?ge.has(e.toLowerCase())||/^(#|rgb\\(|hsl\\()/i.test(e)?qi:Yi:e instanceof Ut?qi:Array.isArray(e)?Ji:\"object\"===r&&isNaN(e)?Hi:Gi)(t,e)}],t.interpolateArray=Ji;var Ki=function(){return P},$i=t.map({linear:Ki,poly:function(t){return function(e){return Math.pow(e,t)}},quad:function(){return ra},cubic:function(){return na},sin:function(){return aa},exp:function(){return oa},circle:function(){return sa},elastic:function(t,e){var r;arguments.length<2&&(e=.45);arguments.length?r=e/Mt*Math.asin(1/t):(t=1,r=e/4);return function(n){return 1+t*Math.pow(2,-10*n)*Math.sin((n-r)*Mt/e)}},back:function(t){t||(t=1.70158);return function(e){return e*e*((t+1)*e-t)}},bounce:function(){return la}}),Qi=t.map({in:P,out:ta,\"in-out\":ea,\"out-in\":function(t){return ea(ta(t))}});function ta(t){return function(e){return 1-t(1-e)}}function ea(t){return function(e){return.5*(e<.5?t(2*e):2-t(2-2*e))}}function ra(t){return t*t}function na(t){return t*t*t}function ia(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}function aa(t){return 1-Math.cos(t*Et)}function oa(t){return Math.pow(2,10*(t-1))}function sa(t){return 1-Math.sqrt(1-t*t)}function la(t){return t<1/2.75?7.5625*t*t:t<2/2.75?7.5625*(t-=1.5/2.75)*t+.75:t<2.5/2.75?7.5625*(t-=2.25/2.75)*t+.9375:7.5625*(t-=2.625/2.75)*t+.984375}function ca(t,e){return e-=t,function(r){return Math.round(t+e*r)}}function ua(t){var e,r,n,i=[t.a,t.b],a=[t.c,t.d],o=fa(i),s=ha(i,a),l=fa(((e=a)[0]+=(n=-s)*(r=i)[0],e[1]+=n*r[1],e))||0;i[0]*a[1]<a[0]*i[1]&&(i[0]*=-1,i[1]*=-1,o*=-1,s*=-1),this.rotate=(o?Math.atan2(i[1],i[0]):Math.atan2(-a[0],a[1]))*Lt,this.translate=[t.e,t.f],this.scale=[o,l],this.skew=l?Math.atan2(s,l)*Lt:0}function ha(t,e){return t[0]*e[0]+t[1]*e[1]}function fa(t){var e=Math.sqrt(ha(t,t));return e&&(t[0]/=e,t[1]/=e),e}t.ease=function(t){var e,n=t.indexOf(\"-\"),i=n>=0?t.slice(0,n):t,a=n>=0?t.slice(n+1):\"in\";return i=$i.get(i)||Ki,a=Qi.get(a)||P,e=a(i.apply(null,r.call(arguments,1))),function(t){return t<=0?0:t>=1?1:e(t)}},t.interpolateHcl=function(e,r){e=t.hcl(e),r=t.hcl(r);var n=e.h,i=e.c,a=e.l,o=r.h-n,s=r.c-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.c:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Wt(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateHsl=function(e,r){e=t.hsl(e),r=t.hsl(r);var n=e.h,i=e.s,a=e.l,o=r.h-n,s=r.s-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.s:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Ht(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateLab=function(e,r){e=t.lab(e),r=t.lab(r);var n=e.l,i=e.a,a=e.b,o=r.l-n,s=r.a-i,l=r.b-a;return function(t){return te(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateRound=ca,t.transform=function(e){var r=i.createElementNS(t.ns.prefix.svg,\"g\");return(t.transform=function(t){if(null!=t){r.setAttribute(\"transform\",t);var e=r.transform.baseVal.consolidate()}return new ua(e?e.matrix:pa)})(e)},ua.prototype.toString=function(){return\"translate(\"+this.translate+\")rotate(\"+this.rotate+\")skewX(\"+this.skew+\")scale(\"+this.scale+\")\"};var pa={a:1,b:0,c:0,d:1,e:0,f:0};function da(t){return t.length?t.pop()+\",\":\"\"}function ga(e,r){var n=[],i=[];return e=t.transform(e),r=t.transform(r),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(\"translate(\",null,\",\",null,\")\");n.push({i:i-4,x:Gi(t[0],e[0])},{i:i-2,x:Gi(t[1],e[1])})}else(e[0]||e[1])&&r.push(\"translate(\"+e+\")\")}(e.translate,r.translate,n,i),function(t,e,r,n){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),n.push({i:r.push(da(r)+\"rotate(\",null,\")\")-2,x:Gi(t,e)})):e&&r.push(da(r)+\"rotate(\"+e+\")\")}(e.rotate,r.rotate,n,i),function(t,e,r,n){t!==e?n.push({i:r.push(da(r)+\"skewX(\",null,\")\")-2,x:Gi(t,e)}):e&&r.push(da(r)+\"skewX(\"+e+\")\")}(e.skew,r.skew,n,i),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(da(r)+\"scale(\",null,\",\",null,\")\");n.push({i:i-4,x:Gi(t[0],e[0])},{i:i-2,x:Gi(t[1],e[1])})}else 1===e[0]&&1===e[1]||r.push(da(r)+\"scale(\"+e+\")\")}(e.scale,r.scale,n,i),e=r=null,function(t){for(var e,r=-1,a=i.length;++r<a;)n[(e=i[r]).i]=e.x(t);return n.join(\"\")}}function va(t,e){return e=(e-=t=+t)||1/e,function(r){return(r-t)/e}}function ma(t,e){return e=(e-=t=+t)||1/e,function(r){return Math.max(0,Math.min(1,(r-t)/e))}}function ya(t){for(var e=t.source,r=t.target,n=function(t,e){if(t===e)return t;var r=xa(t),n=xa(e),i=r.pop(),a=n.pop(),o=null;for(;i===a;)o=i,i=r.pop(),a=n.pop();return o}(e,r),i=[e];e!==n;)e=e.parent,i.push(e);for(var a=i.length;r!==n;)i.splice(a,0,r),r=r.parent;return i}function xa(t){for(var e=[],r=t.parent;null!=r;)e.push(t),t=r,r=r.parent;return e.push(t),e}function ba(t){t.fixed|=2}function _a(t){t.fixed&=-7}function wa(t){t.fixed|=4,t.px=t.x,t.py=t.y}function ka(t){t.fixed&=-5}t.interpolateTransform=ga,t.layout={},t.layout.bundle=function(){return function(t){for(var e=[],r=-1,n=t.length;++r<n;)e.push(ya(t[r]));return e}},t.layout.chord=function(){var e,r,n,i,a,o,s,l={},c=0;function u(){var l,u,f,p,d,g={},v=[],m=t.range(i),y=[];for(e=[],r=[],l=0,p=-1;++p<i;){for(u=0,d=-1;++d<i;)u+=n[p][d];v.push(u),y.push(t.range(i)),l+=u}for(a&&m.sort(function(t,e){return a(v[t],v[e])}),o&&y.forEach(function(t,e){t.sort(function(t,r){return o(n[e][t],n[e][r])})}),l=(Mt-c*i)/l,u=0,p=-1;++p<i;){for(f=u,d=-1;++d<i;){var x=m[p],b=y[x][d],_=n[x][b],w=u,k=u+=_*l;g[x+\"-\"+b]={index:x,subindex:b,startAngle:w,endAngle:k,value:_}}r[x]={index:x,startAngle:f,endAngle:u,value:v[x]},u+=c}for(p=-1;++p<i;)for(d=p-1;++d<i;){var T=g[p+\"-\"+d],A=g[d+\"-\"+p];(T.value||A.value)&&e.push(T.value<A.value?{source:A,target:T}:{source:T,target:A})}s&&h()}function h(){e.sort(function(t,e){return s((t.source.value+t.target.value)/2,(e.source.value+e.target.value)/2)})}return l.matrix=function(t){return arguments.length?(i=(n=t)&&n.length,e=r=null,l):n},l.padding=function(t){return arguments.length?(c=t,e=r=null,l):c},l.sortGroups=function(t){return arguments.length?(a=t,e=r=null,l):a},l.sortSubgroups=function(t){return arguments.length?(o=t,e=null,l):o},l.sortChords=function(t){return arguments.length?(s=t,e&&h(),l):s},l.chords=function(){return e||u(),e},l.groups=function(){return r||u(),r},l},t.layout.force=function(){var e,r,n,i,a,o,s={},l=t.dispatch(\"start\",\"tick\",\"end\"),c=[1,1],u=.9,h=Ta,f=Aa,p=-30,d=Ma,g=.1,v=.64,m=[],y=[];function x(t){return function(e,r,n,i){if(e.point!==t){var a=e.cx-t.x,o=e.cy-t.y,s=i-r,l=a*a+o*o;if(s*s/v<l){if(l<d){var c=e.charge/l;t.px-=a*c,t.py-=o*c}return!0}if(e.point&&l&&l<d){c=e.pointCharge/l;t.px-=a*c,t.py-=o*c}}return!e.charge}}function b(e){e.px=t.event.x,e.py=t.event.y,s.resume()}return s.tick=function(){if((n*=.99)<.005)return e=null,l.end({type:\"end\",alpha:n=0}),!0;var r,s,h,f,d,v,b,_,w,k=m.length,T=y.length;for(s=0;s<T;++s)f=(h=y[s]).source,(v=(_=(d=h.target).x-f.x)*_+(w=d.y-f.y)*w)&&(_*=v=n*a[s]*((v=Math.sqrt(v))-i[s])/v,w*=v,d.x-=_*(b=f.weight+d.weight?f.weight/(f.weight+d.weight):.5),d.y-=w*b,f.x+=_*(b=1-b),f.y+=w*b);if((b=n*g)&&(_=c[0]/2,w=c[1]/2,s=-1,b))for(;++s<k;)(h=m[s]).x+=(_-h.x)*b,h.y+=(w-h.y)*b;if(p)for(!function t(e,r,n){var i=0,a=0;e.charge=0;if(!e.leaf)for(var o,s=e.nodes,l=s.length,c=-1;++c<l;)null!=(o=s[c])&&(t(o,r,n),e.charge+=o.charge,i+=o.charge*o.cx,a+=o.charge*o.cy);if(e.point){e.leaf||(e.point.x+=Math.random()-.5,e.point.y+=Math.random()-.5);var u=r*n[e.point.index];e.charge+=e.pointCharge=u,i+=u*e.point.x,a+=u*e.point.y}e.cx=i/e.charge;e.cy=a/e.charge}(r=t.geom.quadtree(m),n,o),s=-1;++s<k;)(h=m[s]).fixed||r.visit(x(h));for(s=-1;++s<k;)(h=m[s]).fixed?(h.x=h.px,h.y=h.py):(h.x-=(h.px-(h.px=h.x))*u,h.y-=(h.py-(h.py=h.y))*u);l.tick({type:\"tick\",alpha:n})},s.nodes=function(t){return arguments.length?(m=t,s):m},s.links=function(t){return arguments.length?(y=t,s):y},s.size=function(t){return arguments.length?(c=t,s):c},s.linkDistance=function(t){return arguments.length?(h=\"function\"==typeof t?t:+t,s):h},s.distance=s.linkDistance,s.linkStrength=function(t){return arguments.length?(f=\"function\"==typeof t?t:+t,s):f},s.friction=function(t){return arguments.length?(u=+t,s):u},s.charge=function(t){return arguments.length?(p=\"function\"==typeof t?t:+t,s):p},s.chargeDistance=function(t){return arguments.length?(d=t*t,s):Math.sqrt(d)},s.gravity=function(t){return arguments.length?(g=+t,s):g},s.theta=function(t){return arguments.length?(v=t*t,s):Math.sqrt(v)},s.alpha=function(t){return arguments.length?(t=+t,n?t>0?n=t:(e.c=null,e.t=NaN,e=null,l.end({type:\"end\",alpha:n=0})):t>0&&(l.start({type:\"start\",alpha:n=t}),e=Te(s.tick)),s):n},s.start=function(){var t,e,r,n=m.length,l=y.length,u=c[0],d=c[1];for(t=0;t<n;++t)(r=m[t]).index=t,r.weight=0;for(t=0;t<l;++t)\"number\"==typeof(r=y[t]).source&&(r.source=m[r.source]),\"number\"==typeof r.target&&(r.target=m[r.target]),++r.source.weight,++r.target.weight;for(t=0;t<n;++t)r=m[t],isNaN(r.x)&&(r.x=g(\"x\",u)),isNaN(r.y)&&(r.y=g(\"y\",d)),isNaN(r.px)&&(r.px=r.x),isNaN(r.py)&&(r.py=r.y);if(i=[],\"function\"==typeof h)for(t=0;t<l;++t)i[t]=+h.call(this,y[t],t);else for(t=0;t<l;++t)i[t]=h;if(a=[],\"function\"==typeof f)for(t=0;t<l;++t)a[t]=+f.call(this,y[t],t);else for(t=0;t<l;++t)a[t]=f;if(o=[],\"function\"==typeof p)for(t=0;t<n;++t)o[t]=+p.call(this,m[t],t);else for(t=0;t<n;++t)o[t]=p;function g(r,i){if(!e){for(e=new Array(n),c=0;c<n;++c)e[c]=[];for(c=0;c<l;++c){var a=y[c];e[a.source.index].push(a.target),e[a.target.index].push(a.source)}}for(var o,s=e[t],c=-1,u=s.length;++c<u;)if(!isNaN(o=s[c][r]))return o;return Math.random()*i}return s.resume()},s.resume=function(){return s.alpha(.1)},s.stop=function(){return s.alpha(0)},s.drag=function(){if(r||(r=t.behavior.drag().origin(P).on(\"dragstart.force\",ba).on(\"drag.force\",b).on(\"dragend.force\",_a)),!arguments.length)return r;this.on(\"mouseover.force\",wa).on(\"mouseout.force\",ka).call(r)},t.rebind(s,l,\"on\")};var Ta=20,Aa=1,Ma=1/0;function Sa(e,r){return t.rebind(e,r,\"sort\",\"children\",\"value\"),e.nodes=e,e.links=za,e}function Ea(t,e){for(var r=[t];null!=(t=r.pop());)if(e(t),(i=t.children)&&(n=i.length))for(var n,i;--n>=0;)r.push(i[n])}function Ca(t,e){for(var r=[t],n=[];null!=(t=r.pop());)if(n.push(t),(a=t.children)&&(i=a.length))for(var i,a,o=-1;++o<i;)r.push(a[o]);for(;null!=(t=n.pop());)e(t)}function La(t){return t.children}function Pa(t){return t.value}function Oa(t,e){return e.value-t.value}function za(e){return t.merge(e.map(function(t){return(t.children||[]).map(function(e){return{source:t,target:e}})}))}t.layout.hierarchy=function(){var t=Oa,e=La,r=Pa;function n(i){var a,o=[i],s=[];for(i.depth=0;null!=(a=o.pop());)if(s.push(a),(c=e.call(n,a,a.depth))&&(l=c.length)){for(var l,c,u;--l>=0;)o.push(u=c[l]),u.parent=a,u.depth=a.depth+1;r&&(a.value=0),a.children=c}else r&&(a.value=+r.call(n,a,a.depth)||0),delete a.children;return Ca(i,function(e){var n,i;t&&(n=e.children)&&n.sort(t),r&&(i=e.parent)&&(i.value+=e.value)}),s}return n.sort=function(e){return arguments.length?(t=e,n):t},n.children=function(t){return arguments.length?(e=t,n):e},n.value=function(t){return arguments.length?(r=t,n):r},n.revalue=function(t){return r&&(Ea(t,function(t){t.children&&(t.value=0)}),Ca(t,function(t){var e;t.children||(t.value=+r.call(n,t,t.depth)||0),(e=t.parent)&&(e.value+=t.value)})),t},n},t.layout.partition=function(){var e=t.layout.hierarchy(),r=[1,1];function n(t,n){var i=e.call(this,t,n);return function t(e,r,n,i){var a=e.children;if(e.x=r,e.y=e.depth*i,e.dx=n,e.dy=i,a&&(o=a.length)){var o,s,l,c=-1;for(n=e.value?n/e.value:0;++c<o;)t(s=a[c],r,l=s.value*n,i),r+=l}}(i[0],0,r[0],r[1]/function t(e){var r=e.children,n=0;if(r&&(i=r.length))for(var i,a=-1;++a<i;)n=Math.max(n,t(r[a]));return 1+n}(i[0])),i}return n.size=function(t){return arguments.length?(r=t,n):r},Sa(n,e)},t.layout.pie=function(){var e=Number,r=Ia,n=0,i=Mt,a=0;function o(s){var l,c=s.length,u=s.map(function(t,r){return+e.call(o,t,r)}),h=+(\"function\"==typeof n?n.apply(this,arguments):n),f=(\"function\"==typeof i?i.apply(this,arguments):i)-h,p=Math.min(Math.abs(f)/c,+(\"function\"==typeof a?a.apply(this,arguments):a)),d=p*(f<0?-1:1),g=t.sum(u),v=g?(f-c*d)/g:0,m=t.range(c),y=[];return null!=r&&m.sort(r===Ia?function(t,e){return u[e]-u[t]}:function(t,e){return r(s[t],s[e])}),m.forEach(function(t){y[t]={data:s[t],value:l=u[t],startAngle:h,endAngle:h+=l*v+d,padAngle:p}}),y}return o.value=function(t){return arguments.length?(e=t,o):e},o.sort=function(t){return arguments.length?(r=t,o):r},o.startAngle=function(t){return arguments.length?(n=t,o):n},o.endAngle=function(t){return arguments.length?(i=t,o):i},o.padAngle=function(t){return arguments.length?(a=t,o):a},o};var Ia={};function Da(t){return t.x}function Ra(t){return t.y}function Fa(t,e,r){t.y0=e,t.y=r}t.layout.stack=function(){var e=P,r=ja,n=Ua,i=Fa,a=Da,o=Ra;function s(l,c){if(!(p=l.length))return l;var u=l.map(function(t,r){return e.call(s,t,r)}),h=u.map(function(t){return t.map(function(t,e){return[a.call(s,t,e),o.call(s,t,e)]})}),f=r.call(s,h,c);u=t.permute(u,f),h=t.permute(h,f);var p,d,g,v,m=n.call(s,h,c),y=u[0].length;for(g=0;g<y;++g)for(i.call(s,u[0][g],v=m[g],h[0][g][1]),d=1;d<p;++d)i.call(s,u[d][g],v+=h[d-1][g][1],h[d][g][1]);return l}return s.values=function(t){return arguments.length?(e=t,s):e},s.order=function(t){return arguments.length?(r=\"function\"==typeof t?t:Ba.get(t)||ja,s):r},s.offset=function(t){return arguments.length?(n=\"function\"==typeof t?t:Na.get(t)||Ua,s):n},s.x=function(t){return arguments.length?(a=t,s):a},s.y=function(t){return arguments.length?(o=t,s):o},s.out=function(t){return arguments.length?(i=t,s):i},s};var Ba=t.map({\"inside-out\":function(e){var r,n,i=e.length,a=e.map(Va),o=e.map(qa),s=t.range(i).sort(function(t,e){return a[t]-a[e]}),l=0,c=0,u=[],h=[];for(r=0;r<i;++r)n=s[r],l<c?(l+=o[n],u.push(n)):(c+=o[n],h.push(n));return h.reverse().concat(u)},reverse:function(e){return t.range(e.length).reverse()},default:ja}),Na=t.map({silhouette:function(t){var e,r,n,i=t.length,a=t[0].length,o=[],s=0,l=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];n>s&&(s=n),o.push(n)}for(r=0;r<a;++r)l[r]=(s-o[r])/2;return l},wiggle:function(t){var e,r,n,i,a,o,s,l,c,u=t.length,h=t[0],f=h.length,p=[];for(p[0]=l=c=0,r=1;r<f;++r){for(e=0,i=0;e<u;++e)i+=t[e][r][1];for(e=0,a=0,s=h[r][0]-h[r-1][0];e<u;++e){for(n=0,o=(t[e][r][1]-t[e][r-1][1])/(2*s);n<e;++n)o+=(t[n][r][1]-t[n][r-1][1])/s;a+=o*t[e][r][1]}p[r]=l-=i?a/i*s:0,l<c&&(c=l)}for(r=0;r<f;++r)p[r]-=c;return p},expand:function(t){var e,r,n,i=t.length,a=t[0].length,o=1/i,s=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];if(n)for(e=0;e<i;e++)t[e][r][1]/=n;else for(e=0;e<i;e++)t[e][r][1]=o}for(r=0;r<a;++r)s[r]=0;return s},zero:Ua});function ja(e){return t.range(e.length)}function Ua(t){for(var e=-1,r=t[0].length,n=[];++e<r;)n[e]=0;return n}function Va(t){for(var e,r=1,n=0,i=t[0][1],a=t.length;r<a;++r)(e=t[r][1])>i&&(n=r,i=e);return n}function qa(t){return t.reduce(Ha,0)}function Ha(t,e){return t+e[1]}function Ga(t,e){return Ya(t,Math.ceil(Math.log(e.length)/Math.LN2+1))}function Ya(t,e){for(var r=-1,n=+t[0],i=(t[1]-n)/e,a=[];++r<=e;)a[r]=i*r+n;return a}function Wa(e){return[t.min(e),t.max(e)]}function Xa(t,e){return t.value-e.value}function Za(t,e){var r=t._pack_next;t._pack_next=e,e._pack_prev=t,e._pack_next=r,r._pack_prev=e}function Ja(t,e){t._pack_next=e,e._pack_prev=t}function Ka(t,e){var r=e.x-t.x,n=e.y-t.y,i=t.r+e.r;return.999*i*i>r*r+n*n}function $a(t){if((e=t.children)&&(l=e.length)){var e,r,n,i,a,o,s,l,c=1/0,u=-1/0,h=1/0,f=-1/0;if(e.forEach(Qa),(r=e[0]).x=-r.r,r.y=0,x(r),l>1&&((n=e[1]).x=n.r,n.y=0,x(n),l>2))for(eo(r,n,i=e[2]),x(i),Za(r,i),r._pack_prev=i,Za(i,n),n=r._pack_next,a=3;a<l;a++){eo(r,n,i=e[a]);var p=0,d=1,g=1;for(o=n._pack_next;o!==n;o=o._pack_next,d++)if(Ka(o,i)){p=1;break}if(1==p)for(s=r._pack_prev;s!==o._pack_prev&&!Ka(s,i);s=s._pack_prev,g++);p?(d<g||d==g&&n.r<r.r?Ja(r,n=o):Ja(r=s,n),a--):(Za(r,i),n=i,x(i))}var v=(c+u)/2,m=(h+f)/2,y=0;for(a=0;a<l;a++)(i=e[a]).x-=v,i.y-=m,y=Math.max(y,i.r+Math.sqrt(i.x*i.x+i.y*i.y));t.r=y,e.forEach(to)}function x(t){c=Math.min(t.x-t.r,c),u=Math.max(t.x+t.r,u),h=Math.min(t.y-t.r,h),f=Math.max(t.y+t.r,f)}}function Qa(t){t._pack_next=t._pack_prev=t}function to(t){delete t._pack_next,delete t._pack_prev}function eo(t,e,r){var n=t.r+r.r,i=e.x-t.x,a=e.y-t.y;if(n&&(i||a)){var o=e.r+r.r,s=i*i+a*a,l=.5+((n*=n)-(o*=o))/(2*s),c=Math.sqrt(Math.max(0,2*o*(n+s)-(n-=s)*n-o*o))/(2*s);r.x=t.x+l*i+c*a,r.y=t.y+l*a-c*i}else r.x=t.x+n,r.y=t.y}function ro(t,e){return t.parent==e.parent?1:2}function no(t){var e=t.children;return e.length?e[0]:t.t}function io(t){var e,r=t.children;return(e=r.length)?r[e-1]:t.t}function ao(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function oo(t,e,r){return t.a.parent===e.parent?t.a:r}function so(t){return{x:t.x,y:t.y,dx:t.dx,dy:t.dy}}function lo(t,e){var r=t.x+e[3],n=t.y+e[0],i=t.dx-e[1]-e[3],a=t.dy-e[0]-e[2];return i<0&&(r+=i/2,i=0),a<0&&(n+=a/2,a=0),{x:r,y:n,dx:i,dy:a}}function co(t){var e=t[0],r=t[t.length-1];return e<r?[e,r]:[r,e]}function uo(t){return t.rangeExtent?t.rangeExtent():co(t.range())}function ho(t,e,r,n){var i=r(t[0],t[1]),a=n(e[0],e[1]);return function(t){return a(i(t))}}function fo(t,e){var r,n=0,i=t.length-1,a=t[n],o=t[i];return o<a&&(r=n,n=i,i=r,r=a,a=o,o=r),t[n]=e.floor(a),t[i]=e.ceil(o),t}function po(t){return t?{floor:function(e){return Math.floor(e/t)*t},ceil:function(e){return Math.ceil(e/t)*t}}:go}t.layout.histogram=function(){var e=!0,r=Number,n=Wa,i=Ga;function a(a,o){for(var s,l,c=[],u=a.map(r,this),h=n.call(this,u,o),f=i.call(this,h,u,o),p=(o=-1,u.length),d=f.length-1,g=e?1:1/p;++o<d;)(s=c[o]=[]).dx=f[o+1]-(s.x=f[o]),s.y=0;if(d>0)for(o=-1;++o<p;)(l=u[o])>=h[0]&&l<=h[1]&&((s=c[t.bisect(f,l,1,d)-1]).y+=g,s.push(a[o]));return c}return a.value=function(t){return arguments.length?(r=t,a):r},a.range=function(t){return arguments.length?(n=ve(t),a):n},a.bins=function(t){return arguments.length?(i=\"number\"==typeof t?function(e){return Ya(e,t)}:ve(t),a):i},a.frequency=function(t){return arguments.length?(e=!!t,a):e},a},t.layout.pack=function(){var e,r=t.layout.hierarchy().sort(Xa),n=0,i=[1,1];function a(t,a){var o=r.call(this,t,a),s=o[0],l=i[0],c=i[1],u=null==e?Math.sqrt:\"function\"==typeof e?e:function(){return e};if(s.x=s.y=0,Ca(s,function(t){t.r=+u(t.value)}),Ca(s,$a),n){var h=n*(e?1:Math.max(2*s.r/l,2*s.r/c))/2;Ca(s,function(t){t.r+=h}),Ca(s,$a),Ca(s,function(t){t.r-=h})}return function t(e,r,n,i){var a=e.children;e.x=r+=i*e.x;e.y=n+=i*e.y;e.r*=i;if(a)for(var o=-1,s=a.length;++o<s;)t(a[o],r,n,i)}(s,l/2,c/2,e?1:1/Math.max(2*s.r/l,2*s.r/c)),o}return a.size=function(t){return arguments.length?(i=t,a):i},a.radius=function(t){return arguments.length?(e=null==t||\"function\"==typeof t?t:+t,a):e},a.padding=function(t){return arguments.length?(n=+t,a):n},Sa(a,r)},t.layout.tree=function(){var e=t.layout.hierarchy().sort(null).value(null),r=ro,n=[1,1],i=null;function a(t,a){var c=e.call(this,t,a),u=c[0],h=function(t){var e,r={A:null,children:[t]},n=[r];for(;null!=(e=n.pop());)for(var i,a=e.children,o=0,s=a.length;o<s;++o)n.push((a[o]=i={_:a[o],parent:e,children:(i=a[o].children)&&i.slice()||[],A:null,a:null,z:0,m:0,c:0,s:0,t:null,i:o}).a=i);return r.children[0]}(u);if(Ca(h,o),h.parent.m=-h.z,Ea(h,s),i)Ea(u,l);else{var f=u,p=u,d=u;Ea(u,function(t){t.x<f.x&&(f=t),t.x>p.x&&(p=t),t.depth>d.depth&&(d=t)});var g=r(f,p)/2-f.x,v=n[0]/(p.x+r(p,f)/2+g),m=n[1]/(d.depth||1);Ea(u,function(t){t.x=(t.x+g)*v,t.y=t.depth*m})}return c}function o(t){var e=t.children,n=t.parent.children,i=t.i?n[t.i-1]:null;if(e.length){!function(t){var e,r=0,n=0,i=t.children,a=i.length;for(;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(t);var a=(e[0].z+e[e.length-1].z)/2;i?(t.z=i.z+r(t._,i._),t.m=t.z-a):t.z=a}else i&&(t.z=i.z+r(t._,i._));t.parent.A=function(t,e,n){if(e){for(var i,a=t,o=t,s=e,l=a.parent.children[0],c=a.m,u=o.m,h=s.m,f=l.m;s=io(s),a=no(a),s&&a;)l=no(l),(o=io(o)).a=t,(i=s.z+h-a.z-c+r(s._,a._))>0&&(ao(oo(s,t,n),t,i),c+=i,u+=i),h+=s.m,c+=a.m,f+=l.m,u+=o.m;s&&!io(o)&&(o.t=s,o.m+=h-u),a&&!no(l)&&(l.t=a,l.m+=c-f,n=t)}return n}(t,i,t.parent.A||n[0])}function s(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function l(t){t.x*=n[0],t.y=t.depth*n[1]}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t)?l:null,a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null==(n=t)?null:l,a):i?n:null},Sa(a,e)},t.layout.cluster=function(){var e=t.layout.hierarchy().sort(null).value(null),r=ro,n=[1,1],i=!1;function a(a,o){var s,l=e.call(this,a,o),c=l[0],u=0;Ca(c,function(e){var n=e.children;n&&n.length?(e.x=function(t){return t.reduce(function(t,e){return t+e.x},0)/t.length}(n),e.y=function(e){return 1+t.max(e,function(t){return t.y})}(n)):(e.x=s?u+=r(e,s):0,e.y=0,s=e)});var h=function t(e){var r=e.children;return r&&r.length?t(r[0]):e}(c),f=function t(e){var r,n=e.children;return n&&(r=n.length)?t(n[r-1]):e}(c),p=h.x-r(h,f)/2,d=f.x+r(f,h)/2;return Ca(c,i?function(t){t.x=(t.x-c.x)*n[0],t.y=(c.y-t.y)*n[1]}:function(t){t.x=(t.x-p)/(d-p)*n[0],t.y=(1-(c.y?t.y/c.y:1))*n[1]}),l}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t),a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null!=(n=t),a):i?n:null},Sa(a,e)},t.layout.treemap=function(){var e,r=t.layout.hierarchy(),n=Math.round,i=[1,1],a=null,o=so,s=!1,l=\"squarify\",c=.5*(1+Math.sqrt(5));function u(t,e){for(var r,n,i=-1,a=t.length;++i<a;)n=(r=t[i]).value*(e<0?0:e),r.area=isNaN(n)||n<=0?0:n}function h(t){var e=t.children;if(e&&e.length){var r,n,i,a=o(t),s=[],c=e.slice(),f=1/0,g=\"slice\"===l?a.dx:\"dice\"===l?a.dy:\"slice-dice\"===l?1&t.depth?a.dy:a.dx:Math.min(a.dx,a.dy);for(u(c,a.dx*a.dy/t.value),s.area=0;(i=c.length)>0;)s.push(r=c[i-1]),s.area+=r.area,\"squarify\"!==l||(n=p(s,g))<=f?(c.pop(),f=n):(s.area-=s.pop().area,d(s,g,a,!1),g=Math.min(a.dx,a.dy),s.length=s.area=0,f=1/0);s.length&&(d(s,g,a,!0),s.length=s.area=0),e.forEach(h)}}function f(t){var e=t.children;if(e&&e.length){var r,n=o(t),i=e.slice(),a=[];for(u(i,n.dx*n.dy/t.value),a.area=0;r=i.pop();)a.push(r),a.area+=r.area,null!=r.z&&(d(a,r.z?n.dx:n.dy,n,!i.length),a.length=a.area=0);e.forEach(f)}}function p(t,e){for(var r,n=t.area,i=0,a=1/0,o=-1,s=t.length;++o<s;)(r=t[o].area)&&(r<a&&(a=r),r>i&&(i=r));return e*=e,(n*=n)?Math.max(e*i*c/n,n/(e*a*c)):1/0}function d(t,e,r,i){var a,o=-1,s=t.length,l=r.x,c=r.y,u=e?n(t.area/e):0;if(e==r.dx){for((i||u>r.dy)&&(u=r.dy);++o<s;)(a=t[o]).x=l,a.y=c,a.dy=u,l+=a.dx=Math.min(r.x+r.dx-l,u?n(a.area/u):0);a.z=!0,a.dx+=r.x+r.dx-l,r.y+=u,r.dy-=u}else{for((i||u>r.dx)&&(u=r.dx);++o<s;)(a=t[o]).x=l,a.y=c,a.dx=u,c+=a.dy=Math.min(r.y+r.dy-c,u?n(a.area/u):0);a.z=!1,a.dy+=r.y+r.dy-c,r.x+=u,r.dx-=u}}function g(t){var n=e||r(t),a=n[0];return a.x=a.y=0,a.value?(a.dx=i[0],a.dy=i[1]):a.dx=a.dy=0,e&&r.revalue(a),u([a],a.dx*a.dy/a.value),(e?f:h)(a),s&&(e=n),n}return g.size=function(t){return arguments.length?(i=t,g):i},g.padding=function(t){if(!arguments.length)return a;function e(e){return lo(e,t)}var r;return o=null==(a=t)?so:\"function\"==(r=typeof t)?function(e){var r=t.call(g,e,e.depth);return null==r?so(e):lo(e,\"number\"==typeof r?[r,r,r,r]:r)}:\"number\"===r?(t=[t,t,t,t],e):e,g},g.round=function(t){return arguments.length?(n=t?Math.round:Number,g):n!=Number},g.sticky=function(t){return arguments.length?(s=t,e=null,g):s},g.ratio=function(t){return arguments.length?(c=t,g):c},g.mode=function(t){return arguments.length?(l=t+\"\",g):l},Sa(g,r)},t.random={normal:function(t,e){var r=arguments.length;return r<2&&(e=1),r<1&&(t=0),function(){var r,n,i;do{i=(r=2*Math.random()-1)*r+(n=2*Math.random()-1)*n}while(!i||i>1);return t+e*r*Math.sqrt(-2*Math.log(i)/i)}},logNormal:function(){var e=t.random.normal.apply(t,arguments);return function(){return Math.exp(e())}},bates:function(e){var r=t.random.irwinHall(e);return function(){return r()/e}},irwinHall:function(t){return function(){for(var e=0,r=0;r<t;r++)e+=Math.random();return e}}},t.scale={};var go={floor:P,ceil:P};function vo(e,r,n,i){var a=[],o=[],s=0,l=Math.min(e.length,r.length)-1;for(e[l]<e[0]&&(e=e.slice().reverse(),r=r.slice().reverse());++s<=l;)a.push(n(e[s-1],e[s])),o.push(i(r[s-1],r[s]));return function(r){var n=t.bisect(e,r,1,l)-1;return o[n](a[n](r))}}function mo(e,r){return t.rebind(e,r,\"range\",\"rangeRound\",\"interpolate\",\"clamp\")}function yo(t,e){return fo(t,po(xo(t,e)[2])),fo(t,po(xo(t,e)[2])),t}function xo(t,e){null==e&&(e=10);var r=co(t),n=r[1]-r[0],i=Math.pow(10,Math.floor(Math.log(n/e)/Math.LN10)),a=e/n*i;return a<=.15?i*=10:a<=.35?i*=5:a<=.75&&(i*=2),r[0]=Math.ceil(r[0]/i)*i,r[1]=Math.floor(r[1]/i)*i+.5*i,r[2]=i,r}function bo(e,r){return t.range.apply(t,xo(e,r))}function _o(e,r,n){var i=xo(e,r);if(n){var a=Le.exec(n);if(a.shift(),\"s\"===a[8]){var o=t.formatPrefix(Math.max(y(i[0]),y(i[1])));return a[7]||(a[7]=\".\"+ko(o.scale(i[2]))),a[8]=\"f\",n=t.format(a.join(\"\")),function(t){return n(o.scale(t))+o.symbol}}a[7]||(a[7]=\".\"+function(t,e){var r=ko(e[2]);return t in wo?Math.abs(r-ko(Math.max(y(e[0]),y(e[1]))))+ +(\"e\"!==t):r-2*(\"%\"===t)}(a[8],i)),n=a.join(\"\")}else n=\",.\"+ko(i[2])+\"f\";return t.format(n)}t.scale.linear=function(){return function t(e,r,n,i){var a,o;function s(){var t=Math.min(e.length,r.length)>2?vo:ho,s=i?ma:va;return a=t(e,r,s,n),o=t(r,e,s,Zi),l}function l(t){return a(t)}l.invert=function(t){return o(t)};l.domain=function(t){return arguments.length?(e=t.map(Number),s()):e};l.range=function(t){return arguments.length?(r=t,s()):r};l.rangeRound=function(t){return l.range(t).interpolate(ca)};l.clamp=function(t){return arguments.length?(i=t,s()):i};l.interpolate=function(t){return arguments.length?(n=t,s()):n};l.ticks=function(t){return bo(e,t)};l.tickFormat=function(t,r){return _o(e,t,r)};l.nice=function(t){return yo(e,t),s()};l.copy=function(){return t(e,r,n,i)};return s()}([0,1],[0,1],Zi,!1)};var wo={s:1,g:1,p:1,r:1,e:1};function ko(t){return-Math.floor(Math.log(t)/Math.LN10+.01)}t.scale.log=function(){return function e(r,n,i,a){function o(t){return(i?Math.log(t<0?0:t):-Math.log(t>0?0:-t))/Math.log(n)}function s(t){return i?Math.pow(n,t):-Math.pow(n,-t)}function l(t){return r(o(t))}l.invert=function(t){return s(r.invert(t))};l.domain=function(t){return arguments.length?(i=t[0]>=0,r.domain((a=t.map(Number)).map(o)),l):a};l.base=function(t){return arguments.length?(n=+t,r.domain(a.map(o)),l):n};l.nice=function(){var t=fo(a.map(o),i?Math:Ao);return r.domain(t),a=t.map(s),l};l.ticks=function(){var t=co(a),e=[],r=t[0],l=t[1],c=Math.floor(o(r)),u=Math.ceil(o(l)),h=n%1?2:n;if(isFinite(u-c)){if(i){for(;c<u;c++)for(var f=1;f<h;f++)e.push(s(c)*f);e.push(s(c))}else for(e.push(s(c));c++<u;)for(var f=h-1;f>0;f--)e.push(s(c)*f);for(c=0;e[c]<r;c++);for(u=e.length;e[u-1]>l;u--);e=e.slice(c,u)}return e};l.tickFormat=function(e,r){if(!arguments.length)return To;arguments.length<2?r=To:\"function\"!=typeof r&&(r=t.format(r));var i=Math.max(1,n*e/l.ticks().length);return function(t){var e=t/s(Math.round(o(t)));return e*n<n-.5&&(e*=n),e<=i?r(t):\"\"}};l.copy=function(){return e(r.copy(),n,i,a)};return mo(l,r)}(t.scale.linear().domain([0,1]),10,!0,[1,10])};var To=t.format(\".0e\"),Ao={floor:function(t){return-Math.ceil(-t)},ceil:function(t){return-Math.floor(-t)}};function Mo(t){return function(e){return e<0?-Math.pow(-e,t):Math.pow(e,t)}}t.scale.pow=function(){return function t(e,r,n){var i=Mo(r),a=Mo(1/r);function o(t){return e(i(t))}o.invert=function(t){return a(e.invert(t))};o.domain=function(t){return arguments.length?(e.domain((n=t.map(Number)).map(i)),o):n};o.ticks=function(t){return bo(n,t)};o.tickFormat=function(t,e){return _o(n,t,e)};o.nice=function(t){return o.domain(yo(n,t))};o.exponent=function(t){return arguments.length?(i=Mo(r=t),a=Mo(1/r),e.domain(n.map(i)),o):r};o.copy=function(){return t(e.copy(),r,n)};return mo(o,e)}(t.scale.linear(),1,[0,1])},t.scale.sqrt=function(){return t.scale.pow().exponent(.5)},t.scale.ordinal=function(){return function e(r,n){var i,a,o;function s(t){return a[((i.get(t)||(\"range\"===n.t?i.set(t,r.push(t)):NaN))-1)%a.length]}function l(e,n){return t.range(r.length).map(function(t){return e+n*t})}s.domain=function(t){if(!arguments.length)return r;r=[],i=new b;for(var e,a=-1,o=t.length;++a<o;)i.has(e=t[a])||i.set(e,r.push(e));return s[n.t].apply(s,n.a)};s.range=function(t){return arguments.length?(a=t,o=0,n={t:\"range\",a:arguments},s):a};s.rangePoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=(i+c)/2,0):(c-i)/(r.length-1+e);return a=l(i+u*e/2,u),o=0,n={t:\"rangePoints\",a:arguments},s};s.rangeRoundPoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=c=Math.round((i+c)/2),0):(c-i)/(r.length-1+e)|0;return a=l(i+Math.round(u*e/2+(c-i-(r.length-1+e)*u)/2),u),o=0,n={t:\"rangeRoundPoints\",a:arguments},s};s.rangeBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],h=t[1-c],f=(h-u)/(r.length-e+2*i);return a=l(u+f*i,f),c&&a.reverse(),o=f*(1-e),n={t:\"rangeBands\",a:arguments},s};s.rangeRoundBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],h=t[1-c],f=Math.floor((h-u)/(r.length-e+2*i));return a=l(u+Math.round((h-u-(r.length-e)*f)/2),f),c&&a.reverse(),o=Math.round(f*(1-e)),n={t:\"rangeRoundBands\",a:arguments},s};s.rangeBand=function(){return o};s.rangeExtent=function(){return co(n.a[0])};s.copy=function(){return e(r,n)};return s.domain(r)}([],{t:\"range\",a:[[]]})},t.scale.category10=function(){return t.scale.ordinal().range(So)},t.scale.category20=function(){return t.scale.ordinal().range(Eo)},t.scale.category20b=function(){return t.scale.ordinal().range(Co)},t.scale.category20c=function(){return t.scale.ordinal().range(Lo)};var So=[2062260,16744206,2924588,14034728,9725885,9197131,14907330,8355711,12369186,1556175].map(se),Eo=[2062260,11454440,16744206,16759672,2924588,10018698,14034728,16750742,9725885,12955861,9197131,12885140,14907330,16234194,8355711,13092807,12369186,14408589,1556175,10410725].map(se),Co=[3750777,5395619,7040719,10264286,6519097,9216594,11915115,13556636,9202993,12426809,15186514,15190932,8666169,11356490,14049643,15177372,8077683,10834324,13528509,14589654].map(se),Lo=[3244733,7057110,10406625,13032431,15095053,16616764,16625259,16634018,3253076,7652470,10607003,13101504,7695281,10394312,12369372,14342891,6513507,9868950,12434877,14277081].map(se);function Po(){return 0}t.scale.quantile=function(){return function e(r,n){var i;function a(){var e=0,a=n.length;for(i=[];++e<a;)i[e-1]=t.quantile(r,e/a);return o}function o(e){if(!isNaN(e=+e))return n[t.bisect(i,e)]}o.domain=function(t){return arguments.length?(r=t.map(p).filter(d).sort(f),a()):r};o.range=function(t){return arguments.length?(n=t,a()):n};o.quantiles=function(){return i};o.invertExtent=function(t){return(t=n.indexOf(t))<0?[NaN,NaN]:[t>0?i[t-1]:r[0],t<i.length?i[t]:r[r.length-1]]};o.copy=function(){return e(r,n)};return a()}([],[])},t.scale.quantize=function(){return function t(e,r,n){var i,a;function o(t){return n[Math.max(0,Math.min(a,Math.floor(i*(t-e))))]}function s(){return i=n.length/(r-e),a=n.length-1,o}o.domain=function(t){return arguments.length?(e=+t[0],r=+t[t.length-1],s()):[e,r]};o.range=function(t){return arguments.length?(n=t,s()):n};o.invertExtent=function(t){return[t=(t=n.indexOf(t))<0?NaN:t/i+e,t+1/i]};o.copy=function(){return t(e,r,n)};return s()}(0,1,[0,1])},t.scale.threshold=function(){return function e(r,n){function i(e){if(e<=e)return n[t.bisect(r,e)]}i.domain=function(t){return arguments.length?(r=t,i):r};i.range=function(t){return arguments.length?(n=t,i):n};i.invertExtent=function(t){return t=n.indexOf(t),[r[t-1],r[t]]};i.copy=function(){return e(r,n)};return i}([.5],[0,1])},t.scale.identity=function(){return function t(e){function r(t){return+t}r.invert=r;r.domain=r.range=function(t){return arguments.length?(e=t.map(r),r):e};r.ticks=function(t){return bo(e,t)};r.tickFormat=function(t,r){return _o(e,t,r)};r.copy=function(){return t(e)};return r}([0,1])},t.svg={},t.svg.arc=function(){var t=zo,e=Io,r=Po,n=Oo,i=Do,a=Ro,o=Fo;function s(){var s=Math.max(0,+t.apply(this,arguments)),c=Math.max(0,+e.apply(this,arguments)),u=i.apply(this,arguments)-Et,h=a.apply(this,arguments)-Et,f=Math.abs(h-u),p=u>h?0:1;if(c<s&&(d=c,c=s,s=d),f>=St)return l(c,p)+(s?l(s,1-p):\"\")+\"Z\";var d,g,v,m,y,x,b,_,w,k,T,A,M=0,S=0,E=[];if((m=(+o.apply(this,arguments)||0)/2)&&(v=n===Oo?Math.sqrt(s*s+c*c):+n.apply(this,arguments),p||(S*=-1),c&&(S=It(v/c*Math.sin(m))),s&&(M=It(v/s*Math.sin(m)))),c){y=c*Math.cos(u+S),x=c*Math.sin(u+S),b=c*Math.cos(h-S),_=c*Math.sin(h-S);var C=Math.abs(h-u-2*S)<=At?0:1;if(S&&Bo(y,x,b,_)===p^C){var L=(u+h)/2;y=c*Math.cos(L),x=c*Math.sin(L),b=_=null}}else y=x=0;if(s){w=s*Math.cos(h-M),k=s*Math.sin(h-M),T=s*Math.cos(u+M),A=s*Math.sin(u+M);var P=Math.abs(u-h+2*M)<=At?0:1;if(M&&Bo(w,k,T,A)===1-p^P){var O=(u+h)/2;w=s*Math.cos(O),k=s*Math.sin(O),T=A=null}}else w=k=0;if(f>kt&&(d=Math.min(Math.abs(c-s)/2,+r.apply(this,arguments)))>.001){g=s<c^p?0:1;var z=d,I=d;if(f<At){var D=null==T?[w,k]:null==b?[y,x]:si([y,x],[T,A],[b,_],[w,k]),R=y-D[0],F=x-D[1],B=b-D[0],N=_-D[1],j=1/Math.sin(Math.acos((R*B+F*N)/(Math.sqrt(R*R+F*F)*Math.sqrt(B*B+N*N)))/2),U=Math.sqrt(D[0]*D[0]+D[1]*D[1]);I=Math.min(d,(s-U)/(j-1)),z=Math.min(d,(c-U)/(j+1))}if(null!=b){var V=No(null==T?[w,k]:[T,A],[y,x],c,z,p),q=No([b,_],[w,k],c,z,p);d===z?E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 0,\",g,\" \",V[1],\"A\",c,\",\",c,\" 0 \",1-p^Bo(V[1][0],V[1][1],q[1][0],q[1][1]),\",\",p,\" \",q[1],\"A\",z,\",\",z,\" 0 0,\",g,\" \",q[0]):E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 1,\",g,\" \",q[0])}else E.push(\"M\",y,\",\",x);if(null!=T){var H=No([y,x],[T,A],s,-I,p),G=No([w,k],null==b?[y,x]:[b,_],s,-I,p);d===I?E.push(\"L\",G[0],\"A\",I,\",\",I,\" 0 0,\",g,\" \",G[1],\"A\",s,\",\",s,\" 0 \",p^Bo(G[1][0],G[1][1],H[1][0],H[1][1]),\",\",1-p,\" \",H[1],\"A\",I,\",\",I,\" 0 0,\",g,\" \",H[0]):E.push(\"L\",G[0],\"A\",I,\",\",I,\" 0 0,\",g,\" \",H[0])}else E.push(\"L\",w,\",\",k)}else E.push(\"M\",y,\",\",x),null!=b&&E.push(\"A\",c,\",\",c,\" 0 \",C,\",\",p,\" \",b,\",\",_),E.push(\"L\",w,\",\",k),null!=T&&E.push(\"A\",s,\",\",s,\" 0 \",P,\",\",1-p,\" \",T,\",\",A);return E.push(\"Z\"),E.join(\"\")}function l(t,e){return\"M0,\"+t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+-t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+t}return s.innerRadius=function(e){return arguments.length?(t=ve(e),s):t},s.outerRadius=function(t){return arguments.length?(e=ve(t),s):e},s.cornerRadius=function(t){return arguments.length?(r=ve(t),s):r},s.padRadius=function(t){return arguments.length?(n=t==Oo?Oo:ve(t),s):n},s.startAngle=function(t){return arguments.length?(i=ve(t),s):i},s.endAngle=function(t){return arguments.length?(a=ve(t),s):a},s.padAngle=function(t){return arguments.length?(o=ve(t),s):o},s.centroid=function(){var r=(+t.apply(this,arguments)+ +e.apply(this,arguments))/2,n=(+i.apply(this,arguments)+ +a.apply(this,arguments))/2-Et;return[Math.cos(n)*r,Math.sin(n)*r]},s};var Oo=\"auto\";function zo(t){return t.innerRadius}function Io(t){return t.outerRadius}function Do(t){return t.startAngle}function Ro(t){return t.endAngle}function Fo(t){return t&&t.padAngle}function Bo(t,e,r,n){return(t-r)*e-(e-n)*t>0?0:1}function No(t,e,r,n,i){var a=t[0]-e[0],o=t[1]-e[1],s=(i?n:-n)/Math.sqrt(a*a+o*o),l=s*o,c=-s*a,u=t[0]+l,h=t[1]+c,f=e[0]+l,p=e[1]+c,d=(u+f)/2,g=(h+p)/2,v=f-u,m=p-h,y=v*v+m*m,x=r-n,b=u*p-f*h,_=(m<0?-1:1)*Math.sqrt(Math.max(0,x*x*y-b*b)),w=(b*m-v*_)/y,k=(-b*v-m*_)/y,T=(b*m+v*_)/y,A=(-b*v+m*_)/y,M=w-d,S=k-g,E=T-d,C=A-g;return M*M+S*S>E*E+C*C&&(w=T,k=A),[[w-l,k-c],[w*r/x,k*r/x]]}function jo(t){var e=ei,r=ri,n=Yr,i=Vo,a=i.key,o=.7;function s(a){var s,l=[],c=[],u=-1,h=a.length,f=ve(e),p=ve(r);function d(){l.push(\"M\",i(t(c),o))}for(;++u<h;)n.call(this,s=a[u],u)?c.push([+f.call(this,s,u),+p.call(this,s,u)]):c.length&&(d(),c=[]);return c.length&&d(),l.length?l.join(\"\"):null}return s.x=function(t){return arguments.length?(e=t,s):e},s.y=function(t){return arguments.length?(r=t,s):r},s.defined=function(t){return arguments.length?(n=t,s):n},s.interpolate=function(t){return arguments.length?(a=\"function\"==typeof t?i=t:(i=Uo.get(t)||Vo).key,s):a},s.tension=function(t){return arguments.length?(o=t,s):o},s}t.svg.line=function(){return jo(P)};var Uo=t.map({linear:Vo,\"linear-closed\":qo,step:function(t){var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];for(;++e<r;)i.push(\"H\",(n[0]+(n=t[e])[0])/2,\"V\",n[1]);r>1&&i.push(\"H\",n[0]);return i.join(\"\")},\"step-before\":Ho,\"step-after\":Go,basis:Xo,\"basis-open\":function(t){if(t.length<4)return Vo(t);var e,r=[],n=-1,i=t.length,a=[0],o=[0];for(;++n<3;)e=t[n],a.push(e[0]),o.push(e[1]);r.push(Zo($o,a)+\",\"+Zo($o,o)),--n;for(;++n<i;)e=t[n],a.shift(),a.push(e[0]),o.shift(),o.push(e[1]),Qo(r,a,o);return r.join(\"\")},\"basis-closed\":function(t){var e,r,n=-1,i=t.length,a=i+4,o=[],s=[];for(;++n<4;)r=t[n%i],o.push(r[0]),s.push(r[1]);e=[Zo($o,o),\",\",Zo($o,s)],--n;for(;++n<a;)r=t[n%i],o.shift(),o.push(r[0]),s.shift(),s.push(r[1]),Qo(e,o,s);return e.join(\"\")},bundle:function(t,e){var r=t.length-1;if(r)for(var n,i,a=t[0][0],o=t[0][1],s=t[r][0]-a,l=t[r][1]-o,c=-1;++c<=r;)n=t[c],i=c/r,n[0]=e*n[0]+(1-e)*(a+i*s),n[1]=e*n[1]+(1-e)*(o+i*l);return Xo(t)},cardinal:function(t,e){return t.length<3?Vo(t):t[0]+Yo(t,Wo(t,e))},\"cardinal-open\":function(t,e){return t.length<4?Vo(t):t[1]+Yo(t.slice(1,-1),Wo(t,e))},\"cardinal-closed\":function(t,e){return t.length<3?qo(t):t[0]+Yo((t.push(t[0]),t),Wo([t[t.length-2]].concat(t,[t[1]]),e))},monotone:function(t){return t.length<3?Vo(t):t[0]+Yo(t,function(t){var e,r,n,i,a=[],o=function(t){var e=0,r=t.length-1,n=[],i=t[0],a=t[1],o=n[0]=ts(i,a);for(;++e<r;)n[e]=(o+(o=ts(i=a,a=t[e+1])))/2;return n[e]=o,n}(t),s=-1,l=t.length-1;for(;++s<l;)e=ts(t[s],t[s+1]),y(e)<kt?o[s]=o[s+1]=0:(r=o[s]/e,n=o[s+1]/e,(i=r*r+n*n)>9&&(i=3*e/Math.sqrt(i),o[s]=i*r,o[s+1]=i*n));s=-1;for(;++s<=l;)i=(t[Math.min(l,s+1)][0]-t[Math.max(0,s-1)][0])/(6*(1+o[s]*o[s])),a.push([i||0,o[s]*i||0]);return a}(t))}});function Vo(t){return t.length>1?t.join(\"L\"):t+\"Z\"}function qo(t){return t.join(\"L\")+\"Z\"}function Ho(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"V\",(n=t[e])[1],\"H\",n[0]);return i.join(\"\")}function Go(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"H\",(n=t[e])[0],\"V\",n[1]);return i.join(\"\")}function Yo(t,e){if(e.length<1||t.length!=e.length&&t.length!=e.length+2)return Vo(t);var r=t.length!=e.length,n=\"\",i=t[0],a=t[1],o=e[0],s=o,l=1;if(r&&(n+=\"Q\"+(a[0]-2*o[0]/3)+\",\"+(a[1]-2*o[1]/3)+\",\"+a[0]+\",\"+a[1],i=t[1],l=2),e.length>1){s=e[1],a=t[l],l++,n+=\"C\"+(i[0]+o[0])+\",\"+(i[1]+o[1])+\",\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1];for(var c=2;c<e.length;c++,l++)a=t[l],s=e[c],n+=\"S\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1]}if(r){var u=t[l];n+=\"Q\"+(a[0]+2*s[0]/3)+\",\"+(a[1]+2*s[1]/3)+\",\"+u[0]+\",\"+u[1]}return n}function Wo(t,e){for(var r,n=[],i=(1-e)/2,a=t[0],o=t[1],s=1,l=t.length;++s<l;)r=a,a=o,o=t[s],n.push([i*(o[0]-r[0]),i*(o[1]-r[1])]);return n}function Xo(t){if(t.length<3)return Vo(t);var e=1,r=t.length,n=t[0],i=n[0],a=n[1],o=[i,i,i,(n=t[1])[0]],s=[a,a,a,n[1]],l=[i,\",\",a,\"L\",Zo($o,o),\",\",Zo($o,s)];for(t.push(t[r-1]);++e<=r;)n=t[e],o.shift(),o.push(n[0]),s.shift(),s.push(n[1]),Qo(l,o,s);return t.pop(),l.push(\"L\",n),l.join(\"\")}function Zo(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}Uo.forEach(function(t,e){e.key=t,e.closed=/-closed$/.test(t)});var Jo=[0,2/3,1/3,0],Ko=[0,1/3,2/3,0],$o=[0,1/6,2/3,1/6];function Qo(t,e,r){t.push(\"C\",Zo(Jo,e),\",\",Zo(Jo,r),\",\",Zo(Ko,e),\",\",Zo(Ko,r),\",\",Zo($o,e),\",\",Zo($o,r))}function ts(t,e){return(e[1]-t[1])/(e[0]-t[0])}function es(t){for(var e,r,n,i=-1,a=t.length;++i<a;)r=(e=t[i])[0],n=e[1]-Et,e[0]=r*Math.cos(n),e[1]=r*Math.sin(n);return t}function rs(t){var e=ei,r=ei,n=0,i=ri,a=Yr,o=Vo,s=o.key,l=o,c=\"L\",u=.7;function h(s){var h,f,p,d=[],g=[],v=[],m=-1,y=s.length,x=ve(e),b=ve(n),_=e===r?function(){return f}:ve(r),w=n===i?function(){return p}:ve(i);function k(){d.push(\"M\",o(t(v),u),c,l(t(g.reverse()),u),\"Z\")}for(;++m<y;)a.call(this,h=s[m],m)?(g.push([f=+x.call(this,h,m),p=+b.call(this,h,m)]),v.push([+_.call(this,h,m),+w.call(this,h,m)])):g.length&&(k(),g=[],v=[]);return g.length&&k(),d.length?d.join(\"\"):null}return h.x=function(t){return arguments.length?(e=r=t,h):r},h.x0=function(t){return arguments.length?(e=t,h):e},h.x1=function(t){return arguments.length?(r=t,h):r},h.y=function(t){return arguments.length?(n=i=t,h):i},h.y0=function(t){return arguments.length?(n=t,h):n},h.y1=function(t){return arguments.length?(i=t,h):i},h.defined=function(t){return arguments.length?(a=t,h):a},h.interpolate=function(t){return arguments.length?(s=\"function\"==typeof t?o=t:(o=Uo.get(t)||Vo).key,l=o.reverse||o,c=o.closed?\"M\":\"L\",h):s},h.tension=function(t){return arguments.length?(u=t,h):u},h}function ns(t){return t.radius}function is(t){return[t.x,t.y]}function as(){return 64}function os(){return\"circle\"}function ss(t){var e=Math.sqrt(t/At);return\"M0,\"+e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+-e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+e+\"Z\"}t.svg.line.radial=function(){var t=jo(es);return t.radius=t.x,delete t.x,t.angle=t.y,delete t.y,t},Ho.reverse=Go,Go.reverse=Ho,t.svg.area=function(){return rs(P)},t.svg.area.radial=function(){var t=rs(es);return t.radius=t.x,delete t.x,t.innerRadius=t.x0,delete t.x0,t.outerRadius=t.x1,delete t.x1,t.angle=t.y,delete t.y,t.startAngle=t.y0,delete t.y0,t.endAngle=t.y1,delete t.y1,t},t.svg.chord=function(){var t=Un,e=Vn,r=ns,n=Do,i=Ro;function a(r,n){var i,a,c=o(this,t,r,n),u=o(this,e,r,n);return\"M\"+c.p0+s(c.r,c.p1,c.a1-c.a0)+(a=u,(i=c).a0==a.a0&&i.a1==a.a1?l(c.r,c.p1,c.r,c.p0):l(c.r,c.p1,u.r,u.p0)+s(u.r,u.p1,u.a1-u.a0)+l(u.r,u.p1,c.r,c.p0))+\"Z\"}function o(t,e,a,o){var s=e.call(t,a,o),l=r.call(t,s,o),c=n.call(t,s,o)-Et,u=i.call(t,s,o)-Et;return{r:l,a0:c,a1:u,p0:[l*Math.cos(c),l*Math.sin(c)],p1:[l*Math.cos(u),l*Math.sin(u)]}}function s(t,e,r){return\"A\"+t+\",\"+t+\" 0 \"+ +(r>At)+\",1 \"+e}function l(t,e,r,n){return\"Q 0,0 \"+n}return a.radius=function(t){return arguments.length?(r=ve(t),a):r},a.source=function(e){return arguments.length?(t=ve(e),a):t},a.target=function(t){return arguments.length?(e=ve(t),a):e},a.startAngle=function(t){return arguments.length?(n=ve(t),a):n},a.endAngle=function(t){return arguments.length?(i=ve(t),a):i},a},t.svg.diagonal=function(){var t=Un,e=Vn,r=is;function n(n,i){var a=t.call(this,n,i),o=e.call(this,n,i),s=(a.y+o.y)/2,l=[a,{x:a.x,y:s},{x:o.x,y:s},o];return\"M\"+(l=l.map(r))[0]+\"C\"+l[1]+\" \"+l[2]+\" \"+l[3]}return n.source=function(e){return arguments.length?(t=ve(e),n):t},n.target=function(t){return arguments.length?(e=ve(t),n):e},n.projection=function(t){return arguments.length?(r=t,n):r},n},t.svg.diagonal.radial=function(){var e=t.svg.diagonal(),r=is,n=e.projection;return e.projection=function(t){return arguments.length?n(function(t){return function(){var e=t.apply(this,arguments),r=e[0],n=e[1]-Et;return[r*Math.cos(n),r*Math.sin(n)]}}(r=t)):r},e},t.svg.symbol=function(){var t=os,e=as;function r(r,n){return(ls.get(t.call(this,r,n))||ss)(e.call(this,r,n))}return r.type=function(e){return arguments.length?(t=ve(e),r):t},r.size=function(t){return arguments.length?(e=ve(t),r):e},r};var ls=t.map({circle:ss,cross:function(t){var e=Math.sqrt(t/5)/2;return\"M\"+-3*e+\",\"+-e+\"H\"+-e+\"V\"+-3*e+\"H\"+e+\"V\"+-e+\"H\"+3*e+\"V\"+e+\"H\"+e+\"V\"+3*e+\"H\"+-e+\"V\"+e+\"H\"+-3*e+\"Z\"},diamond:function(t){var e=Math.sqrt(t/(2*us)),r=e*us;return\"M0,\"+-e+\"L\"+r+\",0 0,\"+e+\" \"+-r+\",0Z\"},square:function(t){var e=Math.sqrt(t)/2;return\"M\"+-e+\",\"+-e+\"L\"+e+\",\"+-e+\" \"+e+\",\"+e+\" \"+-e+\",\"+e+\"Z\"},\"triangle-down\":function(t){var e=Math.sqrt(t/cs),r=e*cs/2;return\"M0,\"+r+\"L\"+e+\",\"+-r+\" \"+-e+\",\"+-r+\"Z\"},\"triangle-up\":function(t){var e=Math.sqrt(t/cs),r=e*cs/2;return\"M0,\"+-r+\"L\"+e+\",\"+r+\" \"+-e+\",\"+r+\"Z\"}});t.svg.symbolTypes=ls.keys();var cs=Math.sqrt(3),us=Math.tan(30*Ct);W.transition=function(t){for(var e,r,n=ds||++ms,i=bs(t),a=[],o=gs||{time:Date.now(),ease:ia,delay:0,duration:250},s=-1,l=this.length;++s<l;){a.push(e=[]);for(var c=this[s],u=-1,h=c.length;++u<h;)(r=c[u])&&_s(r,u,i,n,o),e.push(r)}return ps(a,i,n)},W.interrupt=function(t){return this.each(null==t?hs:fs(bs(t)))};var hs=fs(bs());function fs(t){return function(){var e,r,n;(e=this[t])&&(n=e[r=e.active])&&(n.timer.c=null,n.timer.t=NaN,--e.count?delete e[r]:delete this[t],e.active+=.5,n.event&&n.event.interrupt.call(this,this.__data__,n.index))}}function ps(t,e,r){return V(t,vs),t.namespace=e,t.id=r,t}var ds,gs,vs=[],ms=0;function ys(t,e,r,n){var i=t.id,a=t.namespace;return ut(t,\"function\"==typeof r?function(t,o,s){t[a][i].tween.set(e,n(r.call(t,t.__data__,o,s)))}:(r=n(r),function(t){t[a][i].tween.set(e,r)}))}function xs(t){return null==t&&(t=\"\"),function(){this.textContent=t}}function bs(t){return null==t?\"__transition__\":\"__transition_\"+t+\"__\"}function _s(t,e,r,n,i){var a,o,s,l,c,u=t[r]||(t[r]={active:0,count:0}),h=u[n];function f(r){var i=u.active,f=u[i];for(var d in f&&(f.timer.c=null,f.timer.t=NaN,--u.count,delete u[i],f.event&&f.event.interrupt.call(t,t.__data__,f.index)),u)if(+d<n){var g=u[d];g.timer.c=null,g.timer.t=NaN,--u.count,delete u[d]}o.c=p,Te(function(){return o.c&&p(r||1)&&(o.c=null,o.t=NaN),1},0,a),u.active=n,h.event&&h.event.start.call(t,t.__data__,e),c=[],h.tween.forEach(function(r,n){(n=n.call(t,t.__data__,e))&&c.push(n)}),l=h.ease,s=h.duration}function p(i){for(var a=i/s,o=l(a),f=c.length;f>0;)c[--f].call(t,o);if(a>=1)return h.event&&h.event.end.call(t,t.__data__,e),--u.count?delete u[n]:delete t[r],1}h||(a=i.time,o=Te(function(t){var e=h.delay;if(o.t=e+a,e<=t)return f(t-e);o.c=f},0,a),h=u[n]={tween:new b,time:a,timer:o,delay:i.delay,duration:i.duration,ease:i.ease,index:e},i=null,++u.count)}vs.call=W.call,vs.empty=W.empty,vs.node=W.node,vs.size=W.size,t.transition=function(e,r){return e&&e.transition?ds?e.transition(r):e:t.selection().transition(e)},t.transition.prototype=vs,vs.select=function(t){var e,r,n,i=this.id,a=this.namespace,o=[];t=X(t);for(var s=-1,l=this.length;++s<l;){o.push(e=[]);for(var c=this[s],u=-1,h=c.length;++u<h;)(n=c[u])&&(r=t.call(n,n.__data__,u,s))?(\"__data__\"in n&&(r.__data__=n.__data__),_s(r,u,a,i,n[a][i]),e.push(r)):e.push(null)}return ps(o,a,i)},vs.selectAll=function(t){var e,r,n,i,a,o=this.id,s=this.namespace,l=[];t=Z(t);for(var c=-1,u=this.length;++c<u;)for(var h=this[c],f=-1,p=h.length;++f<p;)if(n=h[f]){a=n[s][o],r=t.call(n,n.__data__,f,c),l.push(e=[]);for(var d=-1,g=r.length;++d<g;)(i=r[d])&&_s(i,d,s,o,a),e.push(i)}return ps(l,s,o)},vs.filter=function(t){var e,r,n=[];\"function\"!=typeof t&&(t=ct(t));for(var i=0,a=this.length;i<a;i++){n.push(e=[]);for(var o,s=0,l=(o=this[i]).length;s<l;s++)(r=o[s])&&t.call(r,r.__data__,s,i)&&e.push(r)}return ps(n,this.namespace,this.id)},vs.tween=function(t,e){var r=this.id,n=this.namespace;return arguments.length<2?this.node()[n][r].tween.get(t):ut(this,null==e?function(e){e[n][r].tween.remove(t)}:function(i){i[n][r].tween.set(t,e)})},vs.attr=function(e,r){if(arguments.length<2){for(r in e)this.attr(r,e[r]);return this}var n=\"transform\"==e?ga:Zi,i=t.ns.qualify(e);function a(){this.removeAttribute(i)}function o(){this.removeAttributeNS(i.space,i.local)}return ys(this,\"attr.\"+e,r,i.local?function(t){return null==t?o:(t+=\"\",function(){var e,r=this.getAttributeNS(i.space,i.local);return r!==t&&(e=n(r,t),function(t){this.setAttributeNS(i.space,i.local,e(t))})})}:function(t){return null==t?a:(t+=\"\",function(){var e,r=this.getAttribute(i);return r!==t&&(e=n(r,t),function(t){this.setAttribute(i,e(t))})})})},vs.attrTween=function(e,r){var n=t.ns.qualify(e);return this.tween(\"attr.\"+e,n.local?function(t,e){var i=r.call(this,t,e,this.getAttributeNS(n.space,n.local));return i&&function(t){this.setAttributeNS(n.space,n.local,i(t))}}:function(t,e){var i=r.call(this,t,e,this.getAttribute(n));return i&&function(t){this.setAttribute(n,i(t))}})},vs.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.style(r,t[r],e);return this}r=\"\"}function i(){this.style.removeProperty(t)}return ys(this,\"style.\"+t,e,function(e){return null==e?i:(e+=\"\",function(){var n,i=o(this).getComputedStyle(this,null).getPropertyValue(t);return i!==e&&(n=Zi(i,e),function(e){this.style.setProperty(t,n(e),r)})})})},vs.styleTween=function(t,e,r){return arguments.length<3&&(r=\"\"),this.tween(\"style.\"+t,function(n,i){var a=e.call(this,n,i,o(this).getComputedStyle(this,null).getPropertyValue(t));return a&&function(e){this.style.setProperty(t,a(e),r)}})},vs.text=function(t){return ys(this,\"text\",t,xs)},vs.remove=function(){var t=this.namespace;return this.each(\"end.transition\",function(){var e;this[t].count<2&&(e=this.parentNode)&&e.removeChild(this)})},vs.ease=function(e){var r=this.id,n=this.namespace;return arguments.length<1?this.node()[n][r].ease:(\"function\"!=typeof e&&(e=t.ease.apply(t,arguments)),ut(this,function(t){t[n][r].ease=e}))},vs.delay=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].delay:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].delay=+t.call(n,n.__data__,i,a)}:(t=+t,function(n){n[r][e].delay=t}))},vs.duration=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].duration:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].duration=Math.max(1,t.call(n,n.__data__,i,a))}:(t=Math.max(1,t),function(n){n[r][e].duration=t}))},vs.each=function(e,r){var n=this.id,i=this.namespace;if(arguments.length<2){var a=gs,o=ds;try{ds=n,ut(this,function(t,r,a){gs=t[i][n],e.call(t,t.__data__,r,a)})}finally{gs=a,ds=o}}else ut(this,function(a){var o=a[i][n];(o.event||(o.event=t.dispatch(\"start\",\"end\",\"interrupt\"))).on(e,r)});return this},vs.transition=function(){for(var t,e,r,n=this.id,i=++ms,a=this.namespace,o=[],s=0,l=this.length;s<l;s++){o.push(t=[]);for(var c,u=0,h=(c=this[s]).length;u<h;u++)(e=c[u])&&_s(e,u,a,i,{time:(r=e[a][n]).time,ease:r.ease,delay:r.delay+r.duration,duration:r.duration}),t.push(e)}return ps(o,a,i)},t.svg.axis=function(){var e,r=t.scale.linear(),i=ws,a=6,o=6,s=3,l=[10],c=null;function u(n){n.each(function(){var n,u=t.select(this),h=this.__chart__||r,f=this.__chart__=r.copy(),p=null==c?f.ticks?f.ticks.apply(f,l):f.domain():c,d=null==e?f.tickFormat?f.tickFormat.apply(f,l):P:e,g=u.selectAll(\".tick\").data(p,f),v=g.enter().insert(\"g\",\".domain\").attr(\"class\",\"tick\").style(\"opacity\",kt),m=t.transition(g.exit()).style(\"opacity\",kt).remove(),y=t.transition(g.order()).style(\"opacity\",1),x=Math.max(a,0)+s,b=uo(f),_=u.selectAll(\".domain\").data([0]),w=(_.enter().append(\"path\").attr(\"class\",\"domain\"),t.transition(_));v.append(\"line\"),v.append(\"text\");var k,T,A,M,S=v.select(\"line\"),E=y.select(\"line\"),C=g.select(\"text\").text(d),L=v.select(\"text\"),O=y.select(\"text\"),z=\"top\"===i||\"left\"===i?-1:1;if(\"bottom\"===i||\"top\"===i?(n=Ts,k=\"x\",A=\"y\",T=\"x2\",M=\"y2\",C.attr(\"dy\",z<0?\"0em\":\".71em\").style(\"text-anchor\",\"middle\"),w.attr(\"d\",\"M\"+b[0]+\",\"+z*o+\"V0H\"+b[1]+\"V\"+z*o)):(n=As,k=\"y\",A=\"x\",T=\"y2\",M=\"x2\",C.attr(\"dy\",\".32em\").style(\"text-anchor\",z<0?\"end\":\"start\"),w.attr(\"d\",\"M\"+z*o+\",\"+b[0]+\"H0V\"+b[1]+\"H\"+z*o)),S.attr(M,z*a),L.attr(A,z*x),E.attr(T,0).attr(M,z*a),O.attr(k,0).attr(A,z*x),f.rangeBand){var I=f,D=I.rangeBand()/2;h=f=function(t){return I(t)+D}}else h.rangeBand?h=f:m.call(n,f,h);v.call(n,h,f),y.call(n,f,f)})}return u.scale=function(t){return arguments.length?(r=t,u):r},u.orient=function(t){return arguments.length?(i=t in ks?t+\"\":ws,u):i},u.ticks=function(){return arguments.length?(l=n(arguments),u):l},u.tickValues=function(t){return arguments.length?(c=t,u):c},u.tickFormat=function(t){return arguments.length?(e=t,u):e},u.tickSize=function(t){var e=arguments.length;return e?(a=+t,o=+arguments[e-1],u):a},u.innerTickSize=function(t){return arguments.length?(a=+t,u):a},u.outerTickSize=function(t){return arguments.length?(o=+t,u):o},u.tickPadding=function(t){return arguments.length?(s=+t,u):s},u.tickSubdivide=function(){return arguments.length&&u},u};var ws=\"bottom\",ks={top:1,right:1,bottom:1,left:1};function Ts(t,e,r){t.attr(\"transform\",function(t){var n=e(t);return\"translate(\"+(isFinite(n)?n:r(t))+\",0)\"})}function As(t,e,r){t.attr(\"transform\",function(t){var n=e(t);return\"translate(0,\"+(isFinite(n)?n:r(t))+\")\"})}t.svg.brush=function(){var e,r,n=j(f,\"brushstart\",\"brush\",\"brushend\"),i=null,a=null,s=[0,0],l=[0,0],c=!0,u=!0,h=Ss[0];function f(e){e.each(function(){var e=t.select(this).style(\"pointer-events\",\"all\").style(\"-webkit-tap-highlight-color\",\"rgba(0,0,0,0)\").on(\"mousedown.brush\",v).on(\"touchstart.brush\",v),r=e.selectAll(\".background\").data([0]);r.enter().append(\"rect\").attr(\"class\",\"background\").style(\"visibility\",\"hidden\").style(\"cursor\",\"crosshair\"),e.selectAll(\".extent\").data([0]).enter().append(\"rect\").attr(\"class\",\"extent\").style(\"cursor\",\"move\");var n=e.selectAll(\".resize\").data(h,P);n.exit().remove(),n.enter().append(\"g\").attr(\"class\",function(t){return\"resize \"+t}).style(\"cursor\",function(t){return Ms[t]}).append(\"rect\").attr(\"x\",function(t){return/[ew]$/.test(t)?-3:null}).attr(\"y\",function(t){return/^[ns]/.test(t)?-3:null}).attr(\"width\",6).attr(\"height\",6).style(\"visibility\",\"hidden\"),n.style(\"display\",f.empty()?\"none\":null);var o,s=t.transition(e),l=t.transition(r);i&&(o=uo(i),l.attr(\"x\",o[0]).attr(\"width\",o[1]-o[0]),d(s)),a&&(o=uo(a),l.attr(\"y\",o[0]).attr(\"height\",o[1]-o[0]),g(s)),p(s)})}function p(t){t.selectAll(\".resize\").attr(\"transform\",function(t){return\"translate(\"+s[+/e$/.test(t)]+\",\"+l[+/^s/.test(t)]+\")\"})}function d(t){t.select(\".extent\").attr(\"x\",s[0]),t.selectAll(\".extent,.n>rect,.s>rect\").attr(\"width\",s[1]-s[0])}function g(t){t.select(\".extent\").attr(\"y\",l[0]),t.selectAll(\".extent,.e>rect,.w>rect\").attr(\"height\",l[1]-l[0])}function v(){var h,v,m=this,y=t.select(t.event.target),x=n.of(m,arguments),b=t.select(m),_=y.datum(),w=!/^(n|s)$/.test(_)&&i,k=!/^(e|w)$/.test(_)&&a,T=y.classed(\"extent\"),A=xt(m),M=t.mouse(m),S=t.select(o(m)).on(\"keydown.brush\",function(){32==t.event.keyCode&&(T||(h=null,M[0]-=s[1],M[1]-=l[1],T=2),B())}).on(\"keyup.brush\",function(){32==t.event.keyCode&&2==T&&(M[0]+=s[1],M[1]+=l[1],T=0,B())});if(t.event.changedTouches?S.on(\"touchmove.brush\",L).on(\"touchend.brush\",O):S.on(\"mousemove.brush\",L).on(\"mouseup.brush\",O),b.interrupt().selectAll(\"*\").interrupt(),T)M[0]=s[0]-M[0],M[1]=l[0]-M[1];else if(_){var E=+/w$/.test(_),C=+/^n/.test(_);v=[s[1-E]-M[0],l[1-C]-M[1]],M[0]=s[E],M[1]=l[C]}else t.event.altKey&&(h=M.slice());function L(){var e=t.mouse(m),r=!1;v&&(e[0]+=v[0],e[1]+=v[1]),T||(t.event.altKey?(h||(h=[(s[0]+s[1])/2,(l[0]+l[1])/2]),M[0]=s[+(e[0]<h[0])],M[1]=l[+(e[1]<h[1])]):h=null),w&&P(e,i,0)&&(d(b),r=!0),k&&P(e,a,1)&&(g(b),r=!0),r&&(p(b),x({type:\"brush\",mode:T?\"move\":\"resize\"}))}function P(t,n,i){var a,o,f=uo(n),p=f[0],d=f[1],g=M[i],v=i?l:s,m=v[1]-v[0];if(T&&(p-=g,d-=m+g),a=(i?u:c)?Math.max(p,Math.min(d,t[i])):t[i],T?o=(a+=g)+m:(h&&(g=Math.max(p,Math.min(d,2*h[i]-a))),g<a?(o=a,a=g):o=g),v[0]!=a||v[1]!=o)return i?r=null:e=null,v[0]=a,v[1]=o,!0}function O(){L(),b.style(\"pointer-events\",\"all\").selectAll(\".resize\").style(\"display\",f.empty()?\"none\":null),t.select(\"body\").style(\"cursor\",null),S.on(\"mousemove.brush\",null).on(\"mouseup.brush\",null).on(\"touchmove.brush\",null).on(\"touchend.brush\",null).on(\"keydown.brush\",null).on(\"keyup.brush\",null),A(),x({type:\"brushend\"})}b.style(\"pointer-events\",\"none\").selectAll(\".resize\").style(\"display\",null),t.select(\"body\").style(\"cursor\",y.style(\"cursor\")),x({type:\"brushstart\"}),L()}return f.event=function(i){i.each(function(){var i=n.of(this,arguments),a={x:s,y:l,i:e,j:r},o=this.__chart__||a;this.__chart__=a,ds?t.select(this).transition().each(\"start.brush\",function(){e=o.i,r=o.j,s=o.x,l=o.y,i({type:\"brushstart\"})}).tween(\"brush:brush\",function(){var t=Ji(s,a.x),n=Ji(l,a.y);return e=r=null,function(e){s=a.x=t(e),l=a.y=n(e),i({type:\"brush\",mode:\"resize\"})}}).each(\"end.brush\",function(){e=a.i,r=a.j,i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"})}):(i({type:\"brushstart\"}),i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"}))})},f.x=function(t){return arguments.length?(h=Ss[!(i=t)<<1|!a],f):i},f.y=function(t){return arguments.length?(h=Ss[!i<<1|!(a=t)],f):a},f.clamp=function(t){return arguments.length?(i&&a?(c=!!t[0],u=!!t[1]):i?c=!!t:a&&(u=!!t),f):i&&a?[c,u]:i?c:a?u:null},f.extent=function(t){var n,o,c,u,h;return arguments.length?(i&&(n=t[0],o=t[1],a&&(n=n[0],o=o[0]),e=[n,o],i.invert&&(n=i(n),o=i(o)),o<n&&(h=n,n=o,o=h),n==s[0]&&o==s[1]||(s=[n,o])),a&&(c=t[0],u=t[1],i&&(c=c[1],u=u[1]),r=[c,u],a.invert&&(c=a(c),u=a(u)),u<c&&(h=c,c=u,u=h),c==l[0]&&u==l[1]||(l=[c,u])),f):(i&&(e?(n=e[0],o=e[1]):(n=s[0],o=s[1],i.invert&&(n=i.invert(n),o=i.invert(o)),o<n&&(h=n,n=o,o=h))),a&&(r?(c=r[0],u=r[1]):(c=l[0],u=l[1],a.invert&&(c=a.invert(c),u=a.invert(u)),u<c&&(h=c,c=u,u=h))),i&&a?[[n,c],[o,u]]:i?[n,o]:a&&[c,u])},f.clear=function(){return f.empty()||(s=[0,0],l=[0,0],e=r=null),f},f.empty=function(){return!!i&&s[0]==s[1]||!!a&&l[0]==l[1]},t.rebind(f,n,\"on\")};var Ms={n:\"ns-resize\",e:\"ew-resize\",s:\"ns-resize\",w:\"ew-resize\",nw:\"nwse-resize\",ne:\"nesw-resize\",se:\"nwse-resize\",sw:\"nesw-resize\"},Ss=[[\"n\",\"e\",\"s\",\"w\",\"nw\",\"ne\",\"se\",\"sw\"],[\"e\",\"w\"],[\"n\",\"s\"],[]],Es=ze.format=sr.timeFormat,Cs=Es.utc,Ls=Cs(\"%Y-%m-%dT%H:%M:%S.%LZ\");function Ps(t){return t.toISOString()}function Os(e,r,n){function i(t){return e(t)}function a(e,n){var i=(e[1]-e[0])/n,a=t.bisect(Is,i);return a==Is.length?[r.year,xo(e.map(function(t){return t/31536e6}),n)[2]]:a?r[i/Is[a-1]<Is[a]/i?a-1:a]:[Fs,xo(e,n)[2]]}return i.invert=function(t){return zs(e.invert(t))},i.domain=function(t){return arguments.length?(e.domain(t),i):e.domain().map(zs)},i.nice=function(t,e){var r=i.domain(),n=co(r),o=null==t?a(n,10):\"number\"==typeof t&&a(n,t);function s(r){return!isNaN(r)&&!t.range(r,zs(+r+1),e).length}return o&&(t=o[0],e=o[1]),i.domain(fo(r,e>1?{floor:function(e){for(;s(e=t.floor(e));)e=zs(e-1);return e},ceil:function(e){for(;s(e=t.ceil(e));)e=zs(+e+1);return e}}:t))},i.ticks=function(t,e){var r=co(i.domain()),n=null==t?a(r,10):\"number\"==typeof t?a(r,t):!t.range&&[{range:t},e];return n&&(t=n[0],e=n[1]),t.range(r[0],zs(+r[1]+1),e<1?1:e)},i.tickFormat=function(){return n},i.copy=function(){return Os(e.copy(),r,n)},mo(i,e)}function zs(t){return new Date(t)}Es.iso=Date.prototype.toISOString&&+new Date(\"2000-01-01T00:00:00.000Z\")?Ps:Ls,Ps.parse=function(t){var e=new Date(t);return isNaN(e)?null:e},Ps.toString=Ls.toString,ze.second=Fe(function(t){return new Ie(1e3*Math.floor(t/1e3))},function(t,e){t.setTime(t.getTime()+1e3*Math.floor(e))},function(t){return t.getSeconds()}),ze.seconds=ze.second.range,ze.seconds.utc=ze.second.utc.range,ze.minute=Fe(function(t){return new Ie(6e4*Math.floor(t/6e4))},function(t,e){t.setTime(t.getTime()+6e4*Math.floor(e))},function(t){return t.getMinutes()}),ze.minutes=ze.minute.range,ze.minutes.utc=ze.minute.utc.range,ze.hour=Fe(function(t){var e=t.getTimezoneOffset()/60;return new Ie(36e5*(Math.floor(t/36e5-e)+e))},function(t,e){t.setTime(t.getTime()+36e5*Math.floor(e))},function(t){return t.getHours()}),ze.hours=ze.hour.range,ze.hours.utc=ze.hour.utc.range,ze.month=Fe(function(t){return(t=ze.day(t)).setDate(1),t},function(t,e){t.setMonth(t.getMonth()+e)},function(t){return t.getMonth()}),ze.months=ze.month.range,ze.months.utc=ze.month.utc.range;var Is=[1e3,5e3,15e3,3e4,6e4,3e5,9e5,18e5,36e5,108e5,216e5,432e5,864e5,1728e5,6048e5,2592e6,7776e6,31536e6],Ds=[[ze.second,1],[ze.second,5],[ze.second,15],[ze.second,30],[ze.minute,1],[ze.minute,5],[ze.minute,15],[ze.minute,30],[ze.hour,1],[ze.hour,3],[ze.hour,6],[ze.hour,12],[ze.day,1],[ze.day,2],[ze.week,1],[ze.month,1],[ze.month,3],[ze.year,1]],Rs=Es.multi([[\".%L\",function(t){return t.getMilliseconds()}],[\":%S\",function(t){return t.getSeconds()}],[\"%I:%M\",function(t){return t.getMinutes()}],[\"%I %p\",function(t){return t.getHours()}],[\"%a %d\",function(t){return t.getDay()&&1!=t.getDate()}],[\"%b %d\",function(t){return 1!=t.getDate()}],[\"%B\",function(t){return t.getMonth()}],[\"%Y\",Yr]]),Fs={range:function(e,r,n){return t.range(Math.ceil(e/n)*n,+r,n).map(zs)},floor:P,ceil:P};Ds.year=ze.year,ze.scale=function(){return Os(t.scale.linear(),Ds,Rs)};var Bs=Ds.map(function(t){return[t[0].utc,t[1]]}),Ns=Cs.multi([[\".%L\",function(t){return t.getUTCMilliseconds()}],[\":%S\",function(t){return t.getUTCSeconds()}],[\"%I:%M\",function(t){return t.getUTCMinutes()}],[\"%I %p\",function(t){return t.getUTCHours()}],[\"%a %d\",function(t){return t.getUTCDay()&&1!=t.getUTCDate()}],[\"%b %d\",function(t){return 1!=t.getUTCDate()}],[\"%B\",function(t){return t.getUTCMonth()}],[\"%Y\",Yr]]);function js(t){return JSON.parse(t.responseText)}function Us(t){var e=i.createRange();return e.selectNode(i.body),e.createContextualFragment(t.responseText)}Bs.year=ze.year.utc,ze.scale.utc=function(){return Os(t.scale.linear(),Bs,Ns)},t.text=me(function(t){return t.responseText}),t.json=function(t,e){return ye(t,\"application/json\",js,e)},t.html=function(t,e){return ye(t,\"text/html\",Us,e)},t.xml=me(function(t){return t.responseXML}),\"object\"==typeof e&&e.exports?e.exports=t:this.d3=t}()},{}],164:[function(t,e,r){e.exports=function(){for(var t=0;t<arguments.length;t++)if(void 0!==arguments[t])return arguments[t]}},{}],165:[function(t,e,r){\"use strict\";var n=t(\"incremental-convex-hull\"),i=t(\"uniq\");function a(t,e){this.point=t,this.index=e}function o(t,e){for(var r=t.point,n=e.point,i=r.length,a=0;a<i;++a){var o=n[a]-r[a];if(o)return o}return 0}e.exports=function(t,e){var r=t.length;if(0===r)return[];var s=t[0].length;if(s<1)return[];if(1===s)return function(t,e,r){if(1===t)return r?[[-1,0]]:[];var n=e.map(function(t,e){return[t[0],e]});n.sort(function(t,e){return t[0]-e[0]});for(var i=new Array(t-1),a=1;a<t;++a){var o=n[a-1],s=n[a];i[a-1]=[o[1],s[1]]}r&&i.push([-1,i[0][1]],[i[t-1][1],-1]);return i}(r,t,e);for(var l=new Array(r),c=1,u=0;u<r;++u){for(var h=t[u],f=new Array(s+1),p=0,d=0;d<s;++d){var g=h[d];f[d]=g,p+=g*g}f[s]=p,l[u]=new a(f,u),c=Math.max(p,c)}i(l,o),r=l.length;for(var v=new Array(r+s+1),m=new Array(r+s+1),y=(s+1)*(s+1)*c,x=new Array(s+1),u=0;u<=s;++u)x[u]=0;x[s]=y,v[0]=x.slice(),m[0]=-1;for(var u=0;u<=s;++u){var f=x.slice();f[u]=1,v[u+1]=f,m[u+1]=-1}for(var u=0;u<r;++u){var b=l[u];v[u+s+1]=b.point,m[u+s+1]=b.index}var _=n(v,!1);_=e?_.filter(function(t){for(var e=0,r=0;r<=s;++r){var n=m[t[r]];if(n<0&&++e>=2)return!1;t[r]=n}return!0}):_.filter(function(t){for(var e=0;e<=s;++e){var r=m[t[e]];if(r<0)return!1;t[e]=r}return!0});if(1&s)for(var u=0;u<_.length;++u){var b=_[u],f=b[0];b[0]=b[1],b[1]=f}return _}},{\"incremental-convex-hull\":413,uniq:547}],166:[function(t,e,r){\"use strict\";e.exports=a;var n=(a.canvas=document.createElement(\"canvas\")).getContext(\"2d\"),i=o([32,126]);function a(t,e){Array.isArray(t)&&(t=t.join(\", \"));var r,a={},s=16,l=.05;e&&(2===e.length&&\"number\"==typeof e[0]?r=o(e):Array.isArray(e)?r=e:(e.o?r=o(e.o):e.pairs&&(r=e.pairs),e.fontSize&&(s=e.fontSize),null!=e.threshold&&(l=e.threshold))),r||(r=i),n.font=s+\"px \"+t;for(var c=0;c<r.length;c++){var u=r[c],h=n.measureText(u[0]).width+n.measureText(u[1]).width,f=n.measureText(u).width;if(Math.abs(h-f)>s*l){var p=(f-h)/s;a[u]=1e3*p}}return a}function o(t){for(var e=[],r=t[0];r<=t[1];r++)for(var n=String.fromCharCode(r),i=t[0];i<t[1];i++){var a=n+String.fromCharCode(i);e.push(a)}return e}a.createPairs=o,a.ascii=i},{}],167:[function(t,e,r){(function(t){var r=!1;if(\"undefined\"!=typeof Float64Array){var n=new Float64Array(1),i=new Uint32Array(n.buffer);if(n[0]=1,r=!0,1072693248===i[1]){e.exports=function(t){return n[0]=t,[i[0],i[1]]},e.exports.pack=function(t,e){return i[0]=t,i[1]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[0]},e.exports.hi=function(t){return n[0]=t,i[1]}}else if(1072693248===i[0]){e.exports=function(t){return n[0]=t,[i[1],i[0]]},e.exports.pack=function(t,e){return i[1]=t,i[0]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[1]},e.exports.hi=function(t){return n[0]=t,i[0]}}else r=!1}if(!r){var a=new t(8);e.exports=function(t){return a.writeDoubleLE(t,0,!0),[a.readUInt32LE(0,!0),a.readUInt32LE(4,!0)]},e.exports.pack=function(t,e){return a.writeUInt32LE(t,0,!0),a.writeUInt32LE(e,4,!0),a.readDoubleLE(0,!0)},e.exports.lo=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(0,!0)},e.exports.hi=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(4,!0)}}e.exports.sign=function(t){return e.exports.hi(t)>>>31},e.exports.exponent=function(t){return(e.exports.hi(t)<<1>>>21)-1023},e.exports.fraction=function(t){var r=e.exports.lo(t),n=e.exports.hi(t),i=1048575&n;return 2146435072&n&&(i+=1<<20),[r,i]},e.exports.denormalized=function(t){return!(2146435072&e.exports.hi(t))}}).call(this,t(\"buffer\").Buffer)},{buffer:105}],168:[function(t,e,r){var n=t(\"abs-svg-path\"),i=t(\"normalize-svg-path\"),a={M:\"moveTo\",C:\"bezierCurveTo\"};e.exports=function(t,e){t.beginPath(),i(n(e)).forEach(function(e){var r=e[0],n=e.slice(1);t[a[r]].apply(t,n)}),t.closePath()}},{\"abs-svg-path\":60,\"normalize-svg-path\":452}],169:[function(t,e,r){e.exports=function(t){switch(t){case\"int8\":return Int8Array;case\"int16\":return Int16Array;case\"int32\":return Int32Array;case\"uint8\":return Uint8Array;case\"uint16\":return Uint16Array;case\"uint32\":return Uint32Array;case\"float32\":return Float32Array;case\"float64\":return Float64Array;case\"array\":return Array;case\"uint8_clamped\":return Uint8ClampedArray}}},{}],170:[function(t,e,r){\"use strict\";e.exports=function(t,e){switch(\"undefined\"==typeof e&&(e=0),typeof t){case\"number\":if(t>0)return function(t,e){var r,n;for(r=new Array(t),n=0;n<t;++n)r[n]=e;return r}(0|t,e);break;case\"object\":if(\"number\"==typeof t.length)return function t(e,r,n){var i=0|e[n];if(i<=0)return[];var a,o=new Array(i);if(n===e.length-1)for(a=0;a<i;++a)o[a]=r;else for(a=0;a<i;++a)o[a]=t(e,r,n+1);return o}(t,e,0)}return[]}},{}],171:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(\"number\"!=typeof e){e=0;for(var i=0;i<r;++i){var a=t[i];e=Math.max(e,a[0],a[1])}e=1+(0|e)}e|=0;for(var o=new Array(e),i=0;i<e;++i)o[i]=[];for(var i=0;i<r;++i){var a=t[i];o[a[0]].push(a[1]),o[a[1]].push(a[0])}for(var s=0;s<e;++s)n(o[s],function(t,e){return t-e});return o};var n=t(\"uniq\")},{uniq:547}],172:[function(t,e,r){var n=t(\"strongly-connected-components\");e.exports=function(t){var e,r=[],i=[],a=[],o={},s=[];function l(t){var r,n,u=!1;for(i.push(t),a[t]=!0,r=0;r<s[t].length;r++)(n=s[t][r])===e?(c(e,i),u=!0):a[n]||(u=l(n));if(u)!function t(e){a[e]=!1,o.hasOwnProperty(e)&&Object.keys(o[e]).forEach(function(r){delete o[e][r],a[r]&&t(r)})}(t);else for(r=0;r<s[t].length;r++){n=s[t][r];var h=o[n];h||(h={},o[n]=h),h[n]=!0}return i.pop(),u}function c(t,e){var n=[].concat(e).concat(t);r.push(n)}function u(e){!function(e){for(var r=0;r<t.length;r++)r<e&&(t[r]=[]),t[r]=t[r].filter(function(t){return t>=e})}(e);for(var r,i=n(t).components.filter(function(t){return t.length>1}),a=1/0,o=0;o<i.length;o++)for(var s=0;s<i[o].length;s++)i[o][s]<a&&(a=i[o][s],r=o);var l=i[r];return!!l&&{leastVertex:a,adjList:t.map(function(t,e){return-1===l.indexOf(e)?[]:t.filter(function(t){return-1!==l.indexOf(t)})})}}e=0;for(var h=t.length;e<h;){var f=u(e);if(e=f.leastVertex,s=f.adjList){for(var p=0;p<s.length;p++)for(var d=0;d<s[p].length;d++){var g=s[p][d];a[+g]=!1,o[g]={}}l(e),e+=1}else e=h}return r}},{\"strongly-connected-components\":530}],173:[function(t,e,r){\"use strict\";var n=t(\"../../object/valid-value\");e.exports=function(){return n(this).length=0,this}},{\"../../object/valid-value\":205}],174:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Array.from:t(\"./shim\")},{\"./is-implemented\":175,\"./shim\":176}],175:[function(t,e,r){\"use strict\";e.exports=function(){var t,e,r=Array.from;return\"function\"==typeof r&&(e=r(t=[\"raz\",\"dwa\"]),Boolean(e&&e!==t&&\"dwa\"===e[1]))}},{}],176:[function(t,e,r){\"use strict\";var n=t(\"es6-symbol\").iterator,i=t(\"../../function/is-arguments\"),a=t(\"../../function/is-function\"),o=t(\"../../number/to-pos-integer\"),s=t(\"../../object/valid-callable\"),l=t(\"../../object/valid-value\"),c=t(\"../../object/is-value\"),u=t(\"../../string/is-string\"),h=Array.isArray,f=Function.prototype.call,p={configurable:!0,enumerable:!0,writable:!0,value:null},d=Object.defineProperty;e.exports=function(t){var e,r,g,v,m,y,x,b,_,w,k=arguments[1],T=arguments[2];if(t=Object(l(t)),c(k)&&s(k),this&&this!==Array&&a(this))e=this;else{if(!k){if(i(t))return 1!==(m=t.length)?Array.apply(null,t):((v=new Array(1))[0]=t[0],v);if(h(t)){for(v=new Array(m=t.length),r=0;r<m;++r)v[r]=t[r];return v}}v=[]}if(!h(t))if(void 0!==(_=t[n])){for(x=s(_).call(t),e&&(v=new e),b=x.next(),r=0;!b.done;)w=k?f.call(k,T,b.value,r):b.value,e?(p.value=w,d(v,r,p)):v[r]=w,b=x.next(),++r;m=r}else if(u(t)){for(m=t.length,e&&(v=new e),r=0,g=0;r<m;++r)w=t[r],r+1<m&&(y=w.charCodeAt(0))>=55296&&y<=56319&&(w+=t[++r]),w=k?f.call(k,T,w,g):w,e?(p.value=w,d(v,g,p)):v[g]=w,++g;m=g}if(void 0===m)for(m=o(t.length),e&&(v=new e(m)),r=0;r<m;++r)w=k?f.call(k,T,t[r],r):t[r],e?(p.value=w,d(v,r,p)):v[r]=w;return e&&(p.value=null,v.length=m),v}},{\"../../function/is-arguments\":177,\"../../function/is-function\":178,\"../../number/to-pos-integer\":184,\"../../object/is-value\":194,\"../../object/valid-callable\":203,\"../../object/valid-value\":205,\"../../string/is-string\":209,\"es6-symbol\":219}],177:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(function(){return arguments}());e.exports=function(t){return n.call(t)===i}},{}],178:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(t(\"./noop\"));e.exports=function(t){return\"function\"==typeof t&&n.call(t)===i}},{\"./noop\":179}],179:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],180:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Math.sign:t(\"./shim\")},{\"./is-implemented\":181,\"./shim\":182}],181:[function(t,e,r){\"use strict\";e.exports=function(){var t=Math.sign;return\"function\"==typeof t&&(1===t(10)&&-1===t(-20))}},{}],182:[function(t,e,r){\"use strict\";e.exports=function(t){return t=Number(t),isNaN(t)||0===t?t:t>0?1:-1}},{}],183:[function(t,e,r){\"use strict\";var n=t(\"../math/sign\"),i=Math.abs,a=Math.floor;e.exports=function(t){return isNaN(t)?0:0!==(t=Number(t))&&isFinite(t)?n(t)*a(i(t)):t}},{\"../math/sign\":180}],184:[function(t,e,r){\"use strict\";var n=t(\"./to-integer\"),i=Math.max;e.exports=function(t){return i(0,n(t))}},{\"./to-integer\":183}],185:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./valid-value\"),a=Function.prototype.bind,o=Function.prototype.call,s=Object.keys,l=Object.prototype.propertyIsEnumerable;e.exports=function(t,e){return function(r,c){var u,h=arguments[2],f=arguments[3];return r=Object(i(r)),n(c),u=s(r),f&&u.sort(\"function\"==typeof f?a.call(f,r):void 0),\"function\"!=typeof t&&(t=u[t]),o.call(t,u,function(t,n){return l.call(r,t)?o.call(c,h,r[t],t,r,n):e})}}},{\"./valid-callable\":203,\"./valid-value\":205}],186:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.assign:t(\"./shim\")},{\"./is-implemented\":187,\"./shim\":188}],187:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=Object.assign;return\"function\"==typeof e&&(e(t={foo:\"raz\"},{bar:\"dwa\"},{trzy:\"trzy\"}),t.foo+t.bar+t.trzy===\"razdwatrzy\")}},{}],188:[function(t,e,r){\"use strict\";var n=t(\"../keys\"),i=t(\"../valid-value\"),a=Math.max;e.exports=function(t,e){var r,o,s,l=a(arguments.length,2);for(t=Object(i(t)),s=function(n){try{t[n]=e[n]}catch(t){r||(r=t)}},o=1;o<l;++o)e=arguments[o],n(e).forEach(s);if(void 0!==r)throw r;return t}},{\"../keys\":195,\"../valid-value\":205}],189:[function(t,e,r){\"use strict\";var n=t(\"../array/from\"),i=t(\"./assign\"),a=t(\"./valid-value\");e.exports=function(t){var e=Object(a(t)),r=arguments[1],o=Object(arguments[2]);if(e!==t&&!r)return e;var s={};return r?n(r,function(e){(o.ensure||e in t)&&(s[e]=t[e])}):i(s,t),s}},{\"../array/from\":174,\"./assign\":186,\"./valid-value\":205}],190:[function(t,e,r){\"use strict\";var n,i,a,o,s=Object.create;t(\"./set-prototype-of/is-implemented\")()||(n=t(\"./set-prototype-of/shim\")),e.exports=n?1!==n.level?s:(i={},a={},o={configurable:!1,enumerable:!1,writable:!0,value:void 0},Object.getOwnPropertyNames(Object.prototype).forEach(function(t){a[t]=\"__proto__\"!==t?o:{configurable:!0,enumerable:!1,writable:!0,value:void 0}}),Object.defineProperties(i,a),Object.defineProperty(n,\"nullPolyfill\",{configurable:!1,enumerable:!1,writable:!1,value:i}),function(t,e){return s(null===t?i:t,e)}):s},{\"./set-prototype-of/is-implemented\":201,\"./set-prototype-of/shim\":202}],191:[function(t,e,r){\"use strict\";e.exports=t(\"./_iterate\")(\"forEach\")},{\"./_iterate\":185}],192:[function(t,e,r){\"use strict\";e.exports=function(t){return\"function\"==typeof t}},{}],193:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i={function:!0,object:!0};e.exports=function(t){return n(t)&&i[typeof t]||!1}},{\"./is-value\":194}],194:[function(t,e,r){\"use strict\";var n=t(\"../function/noop\")();e.exports=function(t){return t!==n&&null!==t}},{\"../function/noop\":179}],195:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.keys:t(\"./shim\")},{\"./is-implemented\":196,\"./shim\":197}],196:[function(t,e,r){\"use strict\";e.exports=function(){try{return Object.keys(\"primitive\"),!0}catch(t){return!1}}},{}],197:[function(t,e,r){\"use strict\";var n=t(\"../is-value\"),i=Object.keys;e.exports=function(t){return i(n(t)?Object(t):t)}},{\"../is-value\":194}],198:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./for-each\"),a=Function.prototype.call;e.exports=function(t,e){var r={},o=arguments[2];return n(e),i(t,function(t,n,i,s){r[n]=a.call(e,o,t,n,i,s)}),r}},{\"./for-each\":191,\"./valid-callable\":203}],199:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i=Array.prototype.forEach,a=Object.create;e.exports=function(t){var e=a(null);return i.call(arguments,function(t){n(t)&&function(t,e){var r;for(r in t)e[r]=t[r]}(Object(t),e)}),e}},{\"./is-value\":194}],200:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.setPrototypeOf:t(\"./shim\")},{\"./is-implemented\":201,\"./shim\":202}],201:[function(t,e,r){\"use strict\";var n=Object.create,i=Object.getPrototypeOf,a={};e.exports=function(){var t=Object.setPrototypeOf,e=arguments[0]||n;return\"function\"==typeof t&&i(t(e(null),a))===a}},{}],202:[function(t,e,r){\"use strict\";var n,i,a,o,s=t(\"../is-object\"),l=t(\"../valid-value\"),c=Object.prototype.isPrototypeOf,u=Object.defineProperty,h={configurable:!0,enumerable:!1,writable:!0,value:void 0};n=function(t,e){if(l(t),null===e||s(e))return t;throw new TypeError(\"Prototype must be null or an object\")},e.exports=(i=function(){var t,e=Object.create(null),r={},n=Object.getOwnPropertyDescriptor(Object.prototype,\"__proto__\");if(n){try{(t=n.set).call(e,r)}catch(t){}if(Object.getPrototypeOf(e)===r)return{set:t,level:2}}return e.__proto__=r,Object.getPrototypeOf(e)===r?{level:2}:((e={}).__proto__=r,Object.getPrototypeOf(e)===r&&{level:1})}())?(2===i.level?i.set?(o=i.set,a=function(t,e){return o.call(n(t,e),e),t}):a=function(t,e){return n(t,e).__proto__=e,t}:a=function t(e,r){var i;return n(e,r),(i=c.call(t.nullPolyfill,e))&&delete t.nullPolyfill.__proto__,null===r&&(r=t.nullPolyfill),e.__proto__=r,i&&u(t.nullPolyfill,\"__proto__\",h),e},Object.defineProperty(a,\"level\",{configurable:!1,enumerable:!1,writable:!1,value:i.level})):null,t(\"../create\")},{\"../create\":190,\"../is-object\":193,\"../valid-value\":205}],203:[function(t,e,r){\"use strict\";e.exports=function(t){if(\"function\"!=typeof t)throw new TypeError(t+\" is not a function\");return t}},{}],204:[function(t,e,r){\"use strict\";var n=t(\"./is-object\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not an Object\");return t}},{\"./is-object\":193}],205:[function(t,e,r){\"use strict\";var n=t(\"./is-value\");e.exports=function(t){if(!n(t))throw new TypeError(\"Cannot use null or undefined\");return t}},{\"./is-value\":194}],206:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?String.prototype.contains:t(\"./shim\")},{\"./is-implemented\":207,\"./shim\":208}],207:[function(t,e,r){\"use strict\";var n=\"razdwatrzy\";e.exports=function(){return\"function\"==typeof n.contains&&(!0===n.contains(\"dwa\")&&!1===n.contains(\"foo\"))}},{}],208:[function(t,e,r){\"use strict\";var n=String.prototype.indexOf;e.exports=function(t){return n.call(this,t,arguments[1])>-1}},{}],209:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(\"\");e.exports=function(t){return\"string\"==typeof t||t&&\"object\"==typeof t&&(t instanceof String||n.call(t)===i)||!1}},{}],210:[function(t,e,r){\"use strict\";var n=Object.create(null),i=Math.random;e.exports=function(){var t;do{t=i().toString(36).slice(2)}while(n[t]);return t}},{}],211:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"es5-ext/string/#/contains\"),o=t(\"d\"),s=t(\"es6-symbol\"),l=t(\"./\"),c=Object.defineProperty;n=e.exports=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");l.call(this,t),e=e?a.call(e,\"key+value\")?\"key+value\":a.call(e,\"key\")?\"key\":\"value\":\"value\",c(this,\"__kind__\",o(\"\",e))},i&&i(n,l),delete n.prototype.constructor,n.prototype=Object.create(l.prototype,{_resolve:o(function(t){return\"value\"===this.__kind__?this.__list__[t]:\"key+value\"===this.__kind__?[t,this.__list__[t]]:t})}),c(n.prototype,s.toStringTag,o(\"c\",\"Array Iterator\"))},{\"./\":214,d:151,\"es5-ext/object/set-prototype-of\":200,\"es5-ext/string/#/contains\":206,\"es6-symbol\":219}],212:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/valid-callable\"),a=t(\"es5-ext/string/is-string\"),o=t(\"./get\"),s=Array.isArray,l=Function.prototype.call,c=Array.prototype.some;e.exports=function(t,e){var r,u,h,f,p,d,g,v,m=arguments[2];if(s(t)||n(t)?r=\"array\":a(t)?r=\"string\":t=o(t),i(e),h=function(){f=!0},\"array\"!==r)if(\"string\"!==r)for(u=t.next();!u.done;){if(l.call(e,m,u.value,h),f)return;u=t.next()}else for(d=t.length,p=0;p<d&&(g=t[p],p+1<d&&(v=g.charCodeAt(0))>=55296&&v<=56319&&(g+=t[++p]),l.call(e,m,g,h),!f);++p);else c.call(t,function(t){return l.call(e,m,t,h),f})}},{\"./get\":213,\"es5-ext/function/is-arguments\":177,\"es5-ext/object/valid-callable\":203,\"es5-ext/string/is-string\":209}],213:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/string/is-string\"),a=t(\"./array\"),o=t(\"./string\"),s=t(\"./valid-iterable\"),l=t(\"es6-symbol\").iterator;e.exports=function(t){return\"function\"==typeof s(t)[l]?t[l]():n(t)?new a(t):i(t)?new o(t):new a(t)}},{\"./array\":211,\"./string\":216,\"./valid-iterable\":217,\"es5-ext/function/is-arguments\":177,\"es5-ext/string/is-string\":209,\"es6-symbol\":219}],214:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/array/#/clear\"),a=t(\"es5-ext/object/assign\"),o=t(\"es5-ext/object/valid-callable\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"d\"),c=t(\"d/auto-bind\"),u=t(\"es6-symbol\"),h=Object.defineProperty,f=Object.defineProperties;e.exports=n=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");f(this,{__list__:l(\"w\",s(t)),__context__:l(\"w\",e),__nextIndex__:l(\"w\",0)}),e&&(o(e.on),e.on(\"_add\",this._onAdd),e.on(\"_delete\",this._onDelete),e.on(\"_clear\",this._onClear))},delete n.prototype.constructor,f(n.prototype,a({_next:l(function(){var t;if(this.__list__)return this.__redo__&&void 0!==(t=this.__redo__.shift())?t:this.__nextIndex__<this.__list__.length?this.__nextIndex__++:void this._unBind()}),next:l(function(){return this._createResult(this._next())}),_createResult:l(function(t){return void 0===t?{done:!0,value:void 0}:{done:!1,value:this._resolve(t)}}),_resolve:l(function(t){return this.__list__[t]}),_unBind:l(function(){this.__list__=null,delete this.__redo__,this.__context__&&(this.__context__.off(\"_add\",this._onAdd),this.__context__.off(\"_delete\",this._onDelete),this.__context__.off(\"_clear\",this._onClear),this.__context__=null)}),toString:l(function(){return\"[object \"+(this[u.toStringTag]||\"Object\")+\"]\"})},c({_onAdd:l(function(t){t>=this.__nextIndex__||(++this.__nextIndex__,this.__redo__?(this.__redo__.forEach(function(e,r){e>=t&&(this.__redo__[r]=++e)},this),this.__redo__.push(t)):h(this,\"__redo__\",l(\"c\",[t])))}),_onDelete:l(function(t){var e;t>=this.__nextIndex__||(--this.__nextIndex__,this.__redo__&&(-1!==(e=this.__redo__.indexOf(t))&&this.__redo__.splice(e,1),this.__redo__.forEach(function(e,r){e>t&&(this.__redo__[r]=--e)},this)))}),_onClear:l(function(){this.__redo__&&i.call(this.__redo__),this.__nextIndex__=0})}))),h(n.prototype,u.iterator,l(function(){return this}))},{d:151,\"d/auto-bind\":150,\"es5-ext/array/#/clear\":173,\"es5-ext/object/assign\":186,\"es5-ext/object/valid-callable\":203,\"es5-ext/object/valid-value\":205,\"es6-symbol\":219}],215:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/string/is-string\"),o=t(\"es6-symbol\").iterator,s=Array.isArray;e.exports=function(t){return!!i(t)&&(!!s(t)||(!!a(t)||(!!n(t)||\"function\"==typeof t[o])))}},{\"es5-ext/function/is-arguments\":177,\"es5-ext/object/is-value\":194,\"es5-ext/string/is-string\":209,\"es6-symbol\":219}],216:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"d\"),o=t(\"es6-symbol\"),s=t(\"./\"),l=Object.defineProperty;n=e.exports=function(t){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");t=String(t),s.call(this,t),l(this,\"__length__\",a(\"\",t.length))},i&&i(n,s),delete n.prototype.constructor,n.prototype=Object.create(s.prototype,{_next:a(function(){if(this.__list__)return this.__nextIndex__<this.__length__?this.__nextIndex__++:void this._unBind()}),_resolve:a(function(t){var e,r=this.__list__[t];return this.__nextIndex__===this.__length__?r:(e=r.charCodeAt(0))>=55296&&e<=56319?r+this.__list__[this.__nextIndex__++]:r})}),l(n.prototype,o.toStringTag,a(\"c\",\"String Iterator\"))},{\"./\":214,d:151,\"es5-ext/object/set-prototype-of\":200,\"es6-symbol\":219}],217:[function(t,e,r){\"use strict\";var n=t(\"./is-iterable\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not iterable\");return t}},{\"./is-iterable\":215}],218:[function(t,e,r){(function(n,i){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():t.ES6Promise=n()}(this,function(){\"use strict\";function e(t){return\"function\"==typeof t}var r=Array.isArray?Array.isArray:function(t){return\"[object Array]\"===Object.prototype.toString.call(t)},a=0,o=void 0,s=void 0,l=function(t,e){g[a]=t,g[a+1]=e,2===(a+=2)&&(s?s(v):_())};var c=\"undefined\"!=typeof window?window:void 0,u=c||{},h=u.MutationObserver||u.WebKitMutationObserver,f=\"undefined\"==typeof self&&\"undefined\"!=typeof n&&\"[object process]\"==={}.toString.call(n),p=\"undefined\"!=typeof Uint8ClampedArray&&\"undefined\"!=typeof importScripts&&\"undefined\"!=typeof MessageChannel;function d(){var t=setTimeout;return function(){return t(v,1)}}var g=new Array(1e3);function v(){for(var t=0;t<a;t+=2){(0,g[t])(g[t+1]),g[t]=void 0,g[t+1]=void 0}a=0}var m,y,x,b,_=void 0;function w(t,e){var r=arguments,n=this,i=new this.constructor(A);void 0===i[T]&&V(i);var a,o=n._state;return o?(a=r[o-1],l(function(){return j(o,i,a,n._result)})):R(n,i,t,e),i}function k(t){if(t&&\"object\"==typeof t&&t.constructor===this)return t;var e=new this(A);return O(e,t),e}f?_=function(){return n.nextTick(v)}:h?(y=0,x=new h(v),b=document.createTextNode(\"\"),x.observe(b,{characterData:!0}),_=function(){b.data=y=++y%2}):p?((m=new MessageChannel).port1.onmessage=v,_=function(){return m.port2.postMessage(0)}):_=void 0===c&&\"function\"==typeof t?function(){try{var e=t(\"vertx\");return o=e.runOnLoop||e.runOnContext,function(){o(v)}}catch(t){return d()}}():d();var T=Math.random().toString(36).substring(16);function A(){}var M=void 0,S=1,E=2,C=new B;function L(t){try{return t.then}catch(t){return C.error=t,C}}function P(t,r,n){r.constructor===t.constructor&&n===w&&r.constructor.resolve===k?function(t,e){e._state===S?I(t,e._result):e._state===E?D(t,e._result):R(e,void 0,function(e){return O(t,e)},function(e){return D(t,e)})}(t,r):n===C?D(t,C.error):void 0===n?I(t,r):e(n)?function(t,e,r){l(function(t){var n=!1,i=function(t,e,r,n){try{t.call(e,r,n)}catch(t){return t}}(r,e,function(r){n||(n=!0,e!==r?O(t,r):I(t,r))},function(e){n||(n=!0,D(t,e))},t._label);!n&&i&&(n=!0,D(t,i))},t)}(t,r,n):I(t,r)}function O(t,e){var r;t===e?D(t,new TypeError(\"You cannot resolve a promise with itself\")):\"function\"==typeof(r=e)||\"object\"==typeof r&&null!==r?P(t,e,L(e)):I(t,e)}function z(t){t._onerror&&t._onerror(t._result),F(t)}function I(t,e){t._state===M&&(t._result=e,t._state=S,0!==t._subscribers.length&&l(F,t))}function D(t,e){t._state===M&&(t._state=E,t._result=e,l(z,t))}function R(t,e,r,n){var i=t._subscribers,a=i.length;t._onerror=null,i[a]=e,i[a+S]=r,i[a+E]=n,0===a&&t._state&&l(F,t)}function F(t){var e=t._subscribers,r=t._state;if(0!==e.length){for(var n=void 0,i=void 0,a=t._result,o=0;o<e.length;o+=3)n=e[o],i=e[o+r],n?j(r,n,i,a):i(a);t._subscribers.length=0}}function B(){this.error=null}var N=new B;function j(t,r,n,i){var a=e(n),o=void 0,s=void 0,l=void 0,c=void 0;if(a){if((o=function(t,e){try{return t(e)}catch(t){return N.error=t,N}}(n,i))===N?(c=!0,s=o.error,o=null):l=!0,r===o)return void D(r,new TypeError(\"A promises callback cannot return that same promise.\"))}else o=i,l=!0;r._state!==M||(a&&l?O(r,o):c?D(r,s):t===S?I(r,o):t===E&&D(r,o))}var U=0;function V(t){t[T]=U++,t._state=void 0,t._result=void 0,t._subscribers=[]}function q(t,e){this._instanceConstructor=t,this.promise=new t(A),this.promise[T]||V(this.promise),r(e)?(this._input=e,this.length=e.length,this._remaining=e.length,this._result=new Array(this.length),0===this.length?I(this.promise,this._result):(this.length=this.length||0,this._enumerate(),0===this._remaining&&I(this.promise,this._result))):D(this.promise,new Error(\"Array Methods must be provided an Array\"))}function H(t){this[T]=U++,this._result=this._state=void 0,this._subscribers=[],A!==t&&(\"function\"!=typeof t&&function(){throw new TypeError(\"You must pass a resolver function as the first argument to the promise constructor\")}(),this instanceof H?function(t,e){try{e(function(e){O(t,e)},function(e){D(t,e)})}catch(e){D(t,e)}}(this,t):function(){throw new TypeError(\"Failed to construct 'Promise': Please use the 'new' operator, this object constructor cannot be called as a function.\")}())}function G(){var t=void 0;if(\"undefined\"!=typeof i)t=i;else if(\"undefined\"!=typeof self)t=self;else try{t=Function(\"return this\")()}catch(t){throw new Error(\"polyfill failed because global object is unavailable in this environment\")}var e=t.Promise;if(e){var r=null;try{r=Object.prototype.toString.call(e.resolve())}catch(t){}if(\"[object Promise]\"===r&&!e.cast)return}t.Promise=H}return q.prototype._enumerate=function(){for(var t=this.length,e=this._input,r=0;this._state===M&&r<t;r++)this._eachEntry(e[r],r)},q.prototype._eachEntry=function(t,e){var r=this._instanceConstructor,n=r.resolve;if(n===k){var i=L(t);if(i===w&&t._state!==M)this._settledAt(t._state,e,t._result);else if(\"function\"!=typeof i)this._remaining--,this._result[e]=t;else if(r===H){var a=new r(A);P(a,t,i),this._willSettleAt(a,e)}else this._willSettleAt(new r(function(e){return e(t)}),e)}else this._willSettleAt(n(t),e)},q.prototype._settledAt=function(t,e,r){var n=this.promise;n._state===M&&(this._remaining--,t===E?D(n,r):this._result[e]=r),0===this._remaining&&I(n,this._result)},q.prototype._willSettleAt=function(t,e){var r=this;R(t,void 0,function(t){return r._settledAt(S,e,t)},function(t){return r._settledAt(E,e,t)})},H.all=function(t){return new q(this,t).promise},H.race=function(t){var e=this;return r(t)?new e(function(r,n){for(var i=t.length,a=0;a<i;a++)e.resolve(t[a]).then(r,n)}):new e(function(t,e){return e(new TypeError(\"You must pass an array to race.\"))})},H.resolve=k,H.reject=function(t){var e=new this(A);return D(e,t),e},H._setScheduler=function(t){s=t},H._setAsap=function(t){l=t},H._asap=l,H.prototype={constructor:H,then:w,catch:function(t){return this.then(null,t)}},G(),H.polyfill=G,H.Promise=H,H})}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{_process:482}],219:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Symbol:t(\"./polyfill\")},{\"./is-implemented\":220,\"./polyfill\":222}],220:[function(t,e,r){\"use strict\";var n={object:!0,symbol:!0};e.exports=function(){var t;if(\"function\"!=typeof Symbol)return!1;t=Symbol(\"test symbol\");try{String(t)}catch(t){return!1}return!!n[typeof Symbol.iterator]&&(!!n[typeof Symbol.toPrimitive]&&!!n[typeof Symbol.toStringTag])}},{}],221:[function(t,e,r){\"use strict\";e.exports=function(t){return!!t&&(\"symbol\"==typeof t||!!t.constructor&&(\"Symbol\"===t.constructor.name&&\"Symbol\"===t[t.constructor.toStringTag]))}},{}],222:[function(t,e,r){\"use strict\";var n,i,a,o,s=t(\"d\"),l=t(\"./validate-symbol\"),c=Object.create,u=Object.defineProperties,h=Object.defineProperty,f=Object.prototype,p=c(null);if(\"function\"==typeof Symbol){n=Symbol;try{String(n()),o=!0}catch(t){}}var d,g=(d=c(null),function(t){for(var e,r,n=0;d[t+(n||\"\")];)++n;return d[t+=n||\"\"]=!0,h(f,e=\"@@\"+t,s.gs(null,function(t){r||(r=!0,h(this,e,s(t)),r=!1)})),e});a=function(t){if(this instanceof a)throw new TypeError(\"Symbol is not a constructor\");return i(t)},e.exports=i=function t(e){var r;if(this instanceof t)throw new TypeError(\"Symbol is not a constructor\");return o?n(e):(r=c(a.prototype),e=void 0===e?\"\":String(e),u(r,{__description__:s(\"\",e),__name__:s(\"\",g(e))}))},u(i,{for:s(function(t){return p[t]?p[t]:p[t]=i(String(t))}),keyFor:s(function(t){var e;for(e in l(t),p)if(p[e]===t)return e}),hasInstance:s(\"\",n&&n.hasInstance||i(\"hasInstance\")),isConcatSpreadable:s(\"\",n&&n.isConcatSpreadable||i(\"isConcatSpreadable\")),iterator:s(\"\",n&&n.iterator||i(\"iterator\")),match:s(\"\",n&&n.match||i(\"match\")),replace:s(\"\",n&&n.replace||i(\"replace\")),search:s(\"\",n&&n.search||i(\"search\")),species:s(\"\",n&&n.species||i(\"species\")),split:s(\"\",n&&n.split||i(\"split\")),toPrimitive:s(\"\",n&&n.toPrimitive||i(\"toPrimitive\")),toStringTag:s(\"\",n&&n.toStringTag||i(\"toStringTag\")),unscopables:s(\"\",n&&n.unscopables||i(\"unscopables\"))}),u(a.prototype,{constructor:s(i),toString:s(\"\",function(){return this.__name__})}),u(i.prototype,{toString:s(function(){return\"Symbol (\"+l(this).__description__+\")\"}),valueOf:s(function(){return l(this)})}),h(i.prototype,i.toPrimitive,s(\"\",function(){var t=l(this);return\"symbol\"==typeof t?t:t.toString()})),h(i.prototype,i.toStringTag,s(\"c\",\"Symbol\")),h(a.prototype,i.toStringTag,s(\"c\",i.prototype[i.toStringTag])),h(a.prototype,i.toPrimitive,s(\"c\",i.prototype[i.toPrimitive]))},{\"./validate-symbol\":223,d:151}],223:[function(t,e,r){\"use strict\";var n=t(\"./is-symbol\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not a symbol\");return t}},{\"./is-symbol\":221}],224:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=e||0,i=r||1;return[[t[12]+t[0],t[13]+t[1],t[14]+t[2],t[15]+t[3]],[t[12]-t[0],t[13]-t[1],t[14]-t[2],t[15]-t[3]],[t[12]+t[4],t[13]+t[5],t[14]+t[6],t[15]+t[7]],[t[12]-t[4],t[13]-t[5],t[14]-t[6],t[15]-t[7]],[n*t[12]+t[8],n*t[13]+t[9],n*t[14]+t[10],n*t[15]+t[11]],[i*t[12]-t[8],i*t[13]-t[9],i*t[14]-t[10],i*t[15]-t[11]]]}},{}],225:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\");e.exports=function(t){var e=typeof t;if(\"string\"===e){var r=t;if(0===(t=+t)&&n(r))return!1}else if(\"number\"!==e)return!1;return t-t<1}},{\"is-string-blank\":423}],226:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 0:return new o([0],[0],0);case 1:if(\"number\"==typeof t){var n=l(t);return new o(n,n,0)}return new o(t,l(t.length),0);case 2:if(\"number\"==typeof e){var n=l(t.length);return new o(t,n,+e)}r=0;case 3:if(t.length!==e.length)throw new Error(\"state and velocity lengths must match\");return new o(t,e,r)}};var n=t(\"cubic-hermite\"),i=t(\"binary-search-bounds\");function a(t,e,r){return Math.min(e,Math.max(t,r))}function o(t,e,r){this.dimension=t.length,this.bounds=[new Array(this.dimension),new Array(this.dimension)];for(var n=0;n<this.dimension;++n)this.bounds[0][n]=-1/0,this.bounds[1][n]=1/0;this._state=t.slice().reverse(),this._velocity=e.slice().reverse(),this._time=[r],this._scratch=[t.slice(),t.slice(),t.slice(),t.slice(),t.slice()]}var s=o.prototype;function l(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=0;return e}s.flush=function(t){var e=i.gt(this._time,t)-1;e<=0||(this._time.splice(0,e),this._state.splice(0,e*this.dimension),this._velocity.splice(0,e*this.dimension))},s.curve=function(t){var e=this._time,r=e.length,o=i.le(e,t),s=this._scratch[0],l=this._state,c=this._velocity,u=this.dimension,h=this.bounds;if(o<0)for(var f=u-1,p=0;p<u;++p,--f)s[p]=l[f];else if(o>=r-1){f=l.length-1;var d=t-e[r-1];for(p=0;p<u;++p,--f)s[p]=l[f]+d*c[f]}else{f=u*(o+1)-1;var g=e[o],v=e[o+1]-g||1,m=this._scratch[1],y=this._scratch[2],x=this._scratch[3],b=this._scratch[4],_=!0;for(p=0;p<u;++p,--f)m[p]=l[f],x[p]=c[f]*v,y[p]=l[f+u],b[p]=c[f+u]*v,_=_&&m[p]===y[p]&&x[p]===b[p]&&0===x[p];if(_)for(p=0;p<u;++p)s[p]=m[p];else n(m,x,y,b,(t-g)/v,s)}var w=h[0],k=h[1];for(p=0;p<u;++p)s[p]=a(w[p],k[p],s[p]);return s},s.dcurve=function(t){var e=this._time,r=e.length,a=i.le(e,t),o=this._scratch[0],s=this._state,l=this._velocity,c=this.dimension;if(a>=r-1)for(var u=s.length-1,h=(e[r-1],0);h<c;++h,--u)o[h]=l[u];else{u=c*(a+1)-1;var f=e[a],p=e[a+1]-f||1,d=this._scratch[1],g=this._scratch[2],v=this._scratch[3],m=this._scratch[4],y=!0;for(h=0;h<c;++h,--u)d[h]=s[u],v[h]=l[u]*p,g[h]=s[u+c],m[h]=l[u+c]*p,y=y&&d[h]===g[h]&&v[h]===m[h]&&0===v[h];if(y)for(h=0;h<c;++h)o[h]=0;else{n.derivative(d,v,g,m,(t-f)/p,o);for(h=0;h<c;++h)o[h]/=p}}return o},s.lastT=function(){var t=this._time;return t[t.length-1]},s.stable=function(){for(var t=this._velocity,e=t.length,r=this.dimension-1;r>=0;--r)if(t[--e])return!1;return!0},s.jump=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1];this._time.push(e,t);for(var u=0;u<2;++u)for(var h=0;h<r;++h)n.push(n[o++]),i.push(0);this._time.push(t);for(h=r;h>0;--h)n.push(a(l[h-1],c[h-1],arguments[h])),i.push(0)}},s.push=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=t-e,l=this.bounds,c=l[0],u=l[1],h=s>1e-6?1/s:0;this._time.push(t);for(var f=r;f>0;--f){var p=a(c[f-1],u[f-1],arguments[f]);n.push(p),i.push((p-n[o++])*h)}}},s.set=function(t){var e=this.dimension;if(!(t<this.lastT()||arguments.length!==e+1)){var r=this._state,n=this._velocity,i=this.bounds,o=i[0],s=i[1];this._time.push(t);for(var l=e;l>0;--l)r.push(a(o[l-1],s[l-1],arguments[l])),n.push(0)}},s.move=function(t){var e=this.lastT(),r=this.dimension;if(!(t<=e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1],u=t-e,h=u>1e-6?1/u:0;this._time.push(t);for(var f=r;f>0;--f){var p=arguments[f];n.push(a(l[f-1],c[f-1],n[o++]+p)),i.push(p*h)}}},s.idle=function(t){var e=this.lastT();if(!(t<e)){var r=this.dimension,n=this._state,i=this._velocity,o=n.length-r,s=this.bounds,l=s[0],c=s[1],u=t-e;this._time.push(t);for(var h=r-1;h>=0;--h)n.push(a(l[h],c[h],n[o]+u*i[o])),i.push(0),o+=1}}},{\"binary-search-bounds\":91,\"cubic-hermite\":145}],227:[function(t,e,r){var n=t(\"dtype\");e.exports=function(t,e,r){if(!t)throw new TypeError(\"must specify data as first parameter\");if(r=0|+(r||0),Array.isArray(t)&&t[0]&&\"number\"==typeof t[0][0]){var i,a,o,s,l=t[0].length,c=t.length*l;e&&\"string\"!=typeof e||(e=new(n(e||\"float32\"))(c+r));var u=e.length-r;if(c!==u)throw new Error(\"source length \"+c+\" (\"+l+\"x\"+t.length+\") does not match destination length \"+u);for(i=0,o=r;i<t.length;i++)for(a=0;a<l;a++)e[o++]=null===t[i][a]?NaN:t[i][a]}else if(e&&\"string\"!=typeof e)e.set(t,r);else{var h=n(e||\"float32\");if(Array.isArray(t)||\"array\"===e)for(e=new h(t.length+r),i=0,o=r,s=e.length;o<s;o++,i++)e[o]=null===t[i]?NaN:t[i];else 0===r?e=new h(t):(e=new h(t.length+r)).set(t,r)}return e}},{dtype:169}],228:[function(t,e,r){\"use strict\";var n=t(\"css-font/stringify\"),i=[32,126];e.exports=function(t){var e=(t=t||{}).shape?t.shape:t.canvas?[t.canvas.width,t.canvas.height]:[512,512],r=t.canvas||document.createElement(\"canvas\"),a=t.font,o=\"number\"==typeof t.step?[t.step,t.step]:t.step||[32,32],s=t.chars||i;a&&\"string\"!=typeof a&&(a=n(a));if(Array.isArray(s)){if(2===s.length&&\"number\"==typeof s[0]&&\"number\"==typeof s[1]){for(var l=[],c=s[0],u=0;c<=s[1];c++)l[u++]=String.fromCharCode(c);s=l}}else s=String(s).split(\"\");e=e.slice(),r.width=e[0],r.height=e[1];var h=r.getContext(\"2d\");h.fillStyle=\"#000\",h.fillRect(0,0,r.width,r.height),h.font=a,h.textAlign=\"center\",h.textBaseline=\"middle\",h.fillStyle=\"#fff\";for(var f=o[0]/2,p=o[1]/2,c=0;c<s.length;c++)h.fillText(s[c],f,p),(f+=o[0])>e[0]-o[0]/2&&(f=o[0]/2,p+=o[1]);return r}},{\"css-font/stringify\":142}],229:[function(t,e,r){\"use strict\";function n(t,e){e||(e={}),(\"string\"==typeof t||Array.isArray(t))&&(e.family=t);var r=Array.isArray(e.family)?e.family.join(\", \"):e.family;if(!r)throw Error(\"`family` must be defined\");var s=e.size||e.fontSize||e.em||48,l=e.weight||e.fontWeight||\"\",c=(t=[e.style||e.fontStyle||\"\",l,s].join(\" \")+\"px \"+r,e.origin||\"top\");if(n.cache[r]&&s<=n.cache[r].em)return i(n.cache[r],c);var u=e.canvas||n.canvas,h=u.getContext(\"2d\"),f={upper:void 0!==e.upper?e.upper:\"H\",lower:void 0!==e.lower?e.lower:\"x\",descent:void 0!==e.descent?e.descent:\"p\",ascent:void 0!==e.ascent?e.ascent:\"h\",tittle:void 0!==e.tittle?e.tittle:\"i\",overshoot:void 0!==e.overshoot?e.overshoot:\"O\"},p=Math.ceil(1.5*s);u.height=p,u.width=.5*p,h.font=t;var d={top:0};h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillStyle=\"black\",h.fillText(\"H\",0,0);var g=a(h.getImageData(0,0,p,p));h.clearRect(0,0,p,p),h.textBaseline=\"bottom\",h.fillText(\"H\",0,p);var v=a(h.getImageData(0,0,p,p));d.lineHeight=d.bottom=p-v+g,h.clearRect(0,0,p,p),h.textBaseline=\"alphabetic\",h.fillText(\"H\",0,p);var m=p-a(h.getImageData(0,0,p,p))-1+g;d.baseline=d.alphabetic=m,h.clearRect(0,0,p,p),h.textBaseline=\"middle\",h.fillText(\"H\",0,.5*p);var y=a(h.getImageData(0,0,p,p));d.median=d.middle=p-y-1+g-.5*p,h.clearRect(0,0,p,p),h.textBaseline=\"hanging\",h.fillText(\"H\",0,.5*p);var x=a(h.getImageData(0,0,p,p));d.hanging=p-x-1+g-.5*p,h.clearRect(0,0,p,p),h.textBaseline=\"ideographic\",h.fillText(\"H\",0,p);var b=a(h.getImageData(0,0,p,p));if(d.ideographic=p-b-1+g,f.upper&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.upper,0,0),d.upper=a(h.getImageData(0,0,p,p)),d.capHeight=d.baseline-d.upper),f.lower&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.lower,0,0),d.lower=a(h.getImageData(0,0,p,p)),d.xHeight=d.baseline-d.lower),f.tittle&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.tittle,0,0),d.tittle=a(h.getImageData(0,0,p,p))),f.ascent&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.ascent,0,0),d.ascent=a(h.getImageData(0,0,p,p))),f.descent&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.descent,0,0),d.descent=o(h.getImageData(0,0,p,p))),f.overshoot){h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.overshoot,0,0);var _=o(h.getImageData(0,0,p,p));d.overshoot=_-m}for(var w in d)d[w]/=s;return d.em=s,n.cache[r]=d,i(d,c)}function i(t,e){var r={};for(var n in\"string\"==typeof e&&(e=t[e]),t)\"em\"!==n&&(r[n]=t[n]-e);return r}function a(t){for(var e=t.height,r=t.data,n=3;n<r.length;n+=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}function o(t){for(var e=t.height,r=t.data,n=r.length-1;n>0;n-=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}e.exports=n,n.canvas=document.createElement(\"canvas\"),n.cache={}},{}],230:[function(t,e,r){\"use strict\";e.exports=function(t){return new c(t||d,null)};var n=0,i=1;function a(t,e,r,n,i,a){this._color=t,this.key=e,this.value=r,this.left=n,this.right=i,this._count=a}function o(t){return new a(t._color,t.key,t.value,t.left,t.right,t._count)}function s(t,e){return new a(t,e.key,e.value,e.left,e.right,e._count)}function l(t){t._count=1+(t.left?t.left._count:0)+(t.right?t.right._count:0)}function c(t,e){this._compare=t,this.root=e}var u=c.prototype;function h(t,e){this.tree=t,this._stack=e}Object.defineProperty(u,\"keys\",{get:function(){var t=[];return this.forEach(function(e,r){t.push(e)}),t}}),Object.defineProperty(u,\"values\",{get:function(){var t=[];return this.forEach(function(e,r){t.push(r)}),t}}),Object.defineProperty(u,\"length\",{get:function(){return this.root?this.root._count:0}}),u.insert=function(t,e){for(var r=this._compare,o=this.root,u=[],h=[];o;){var f=r(t,o.key);u.push(o),h.push(f),o=f<=0?o.left:o.right}u.push(new a(n,t,e,null,null,1));for(var p=u.length-2;p>=0;--p){o=u[p];h[p]<=0?u[p]=new a(o._color,o.key,o.value,u[p+1],o.right,o._count+1):u[p]=new a(o._color,o.key,o.value,o.left,u[p+1],o._count+1)}for(p=u.length-1;p>1;--p){var d=u[p-1];o=u[p];if(d._color===i||o._color===i)break;var g=u[p-2];if(g.left===d)if(d.left===o){if(!(v=g.right)||v._color!==n){if(g._color=n,g.left=d.right,d._color=i,d.right=g,u[p-2]=d,u[p-1]=o,l(g),l(d),p>=3)(m=u[p-3]).left===g?m.left=d:m.right=d;break}d._color=i,g.right=s(i,v),g._color=n,p-=1}else{if(!(v=g.right)||v._color!==n){if(d.right=o.left,g._color=n,g.left=o.right,o._color=i,o.left=d,o.right=g,u[p-2]=o,u[p-1]=d,l(g),l(d),l(o),p>=3)(m=u[p-3]).left===g?m.left=o:m.right=o;break}d._color=i,g.right=s(i,v),g._color=n,p-=1}else if(d.right===o){if(!(v=g.left)||v._color!==n){if(g._color=n,g.right=d.left,d._color=i,d.left=g,u[p-2]=d,u[p-1]=o,l(g),l(d),p>=3)(m=u[p-3]).right===g?m.right=d:m.left=d;break}d._color=i,g.left=s(i,v),g._color=n,p-=1}else{var v;if(!(v=g.left)||v._color!==n){var m;if(d.left=o.right,g._color=n,g.right=o.left,o._color=i,o.right=d,o.left=g,u[p-2]=o,u[p-1]=d,l(g),l(d),l(o),p>=3)(m=u[p-3]).right===g?m.right=o:m.left=o;break}d._color=i,g.left=s(i,v),g._color=n,p-=1}}return u[0]._color=i,new c(r,u[0])},u.forEach=function(t,e,r){if(this.root)switch(arguments.length){case 1:return function t(e,r){var n;if(r.left&&(n=t(e,r.left)))return n;return(n=e(r.key,r.value))||(r.right?t(e,r.right):void 0)}(t,this.root);case 2:return function t(e,r,n,i){if(r(e,i.key)<=0){var a;if(i.left&&(a=t(e,r,n,i.left)))return a;if(a=n(i.key,i.value))return a}if(i.right)return t(e,r,n,i.right)}(e,this._compare,t,this.root);case 3:if(this._compare(e,r)>=0)return;return function t(e,r,n,i,a){var o,s=n(e,a.key),l=n(r,a.key);if(s<=0){if(a.left&&(o=t(e,r,n,i,a.left)))return o;if(l>0&&(o=i(a.key,a.value)))return o}if(l>0&&a.right)return t(e,r,n,i,a.right)}(e,r,this._compare,t,this.root)}},Object.defineProperty(u,\"begin\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.left;return new h(this,t)}}),Object.defineProperty(u,\"end\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.right;return new h(this,t)}}),u.at=function(t){if(t<0)return new h(this,[]);for(var e=this.root,r=[];;){if(r.push(e),e.left){if(t<e.left._count){e=e.left;continue}t-=e.left._count}if(!t)return new h(this,r);if(t-=1,!e.right)break;if(t>=e.right._count)break;e=e.right}return new h(this,[])},u.ge=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<=0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},u.gt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},u.lt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},u.le=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>=0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},u.find=function(t){for(var e=this._compare,r=this.root,n=[];r;){var i=e(t,r.key);if(n.push(r),0===i)return new h(this,n);r=i<=0?r.left:r.right}return new h(this,[])},u.remove=function(t){var e=this.find(t);return e?e.remove():this},u.get=function(t){for(var e=this._compare,r=this.root;r;){var n=e(t,r.key);if(0===n)return r.value;r=n<=0?r.left:r.right}};var f=h.prototype;function p(t,e){t.key=e.key,t.value=e.value,t.left=e.left,t.right=e.right,t._color=e._color,t._count=e._count}function d(t,e){return t<e?-1:t>e?1:0}Object.defineProperty(f,\"valid\",{get:function(){return this._stack.length>0}}),Object.defineProperty(f,\"node\",{get:function(){return this._stack.length>0?this._stack[this._stack.length-1]:null},enumerable:!0}),f.clone=function(){return new h(this.tree,this._stack.slice())},f.remove=function(){var t=this._stack;if(0===t.length)return this.tree;var e=new Array(t.length),r=t[t.length-1];e[e.length-1]=new a(r._color,r.key,r.value,r.left,r.right,r._count);for(var u=t.length-2;u>=0;--u){(r=t[u]).left===t[u+1]?e[u]=new a(r._color,r.key,r.value,e[u+1],r.right,r._count):e[u]=new a(r._color,r.key,r.value,r.left,e[u+1],r._count)}if((r=e[e.length-1]).left&&r.right){var h=e.length;for(r=r.left;r.right;)e.push(r),r=r.right;var f=e[h-1];e.push(new a(r._color,f.key,f.value,r.left,r.right,r._count)),e[h-1].key=r.key,e[h-1].value=r.value;for(u=e.length-2;u>=h;--u)r=e[u],e[u]=new a(r._color,r.key,r.value,r.left,e[u+1],r._count);e[h-1].left=e[h]}if((r=e[e.length-1])._color===n){var d=e[e.length-2];d.left===r?d.left=null:d.right===r&&(d.right=null),e.pop();for(u=0;u<e.length;++u)e[u]._count--;return new c(this.tree._compare,e[0])}if(r.left||r.right){r.left?p(r,r.left):r.right&&p(r,r.right),r._color=i;for(u=0;u<e.length-1;++u)e[u]._count--;return new c(this.tree._compare,e[0])}if(1===e.length)return new c(this.tree._compare,null);for(u=0;u<e.length;++u)e[u]._count--;var g=e[e.length-2];return function(t){for(var e,r,a,c,u=t.length-1;u>=0;--u){if(e=t[u],0===u)return void(e._color=i);if((r=t[u-1]).left===e){if((a=r.right).right&&a.right._color===n)return c=(a=r.right=o(a)).right=o(a.right),r.right=a.left,a.left=r,a.right=c,a._color=r._color,e._color=i,r._color=i,c._color=i,l(r),l(a),u>1&&((h=t[u-2]).left===r?h.left=a:h.right=a),void(t[u-1]=a);if(a.left&&a.left._color===n)return c=(a=r.right=o(a)).left=o(a.left),r.right=c.left,a.left=c.right,c.left=r,c.right=a,c._color=r._color,r._color=i,a._color=i,e._color=i,l(r),l(a),l(c),u>1&&((h=t[u-2]).left===r?h.left=c:h.right=c),void(t[u-1]=c);if(a._color===i){if(r._color===n)return r._color=i,void(r.right=s(n,a));r.right=s(n,a);continue}a=o(a),r.right=a.left,a.left=r,a._color=r._color,r._color=n,l(r),l(a),u>1&&((h=t[u-2]).left===r?h.left=a:h.right=a),t[u-1]=a,t[u]=r,u+1<t.length?t[u+1]=e:t.push(e),u+=2}else{if((a=r.left).left&&a.left._color===n)return c=(a=r.left=o(a)).left=o(a.left),r.left=a.right,a.right=r,a.left=c,a._color=r._color,e._color=i,r._color=i,c._color=i,l(r),l(a),u>1&&((h=t[u-2]).right===r?h.right=a:h.left=a),void(t[u-1]=a);if(a.right&&a.right._color===n)return c=(a=r.left=o(a)).right=o(a.right),r.left=c.right,a.right=c.left,c.right=r,c.left=a,c._color=r._color,r._color=i,a._color=i,e._color=i,l(r),l(a),l(c),u>1&&((h=t[u-2]).right===r?h.right=c:h.left=c),void(t[u-1]=c);if(a._color===i){if(r._color===n)return r._color=i,void(r.left=s(n,a));r.left=s(n,a);continue}var h;a=o(a),r.left=a.right,a.right=r,a._color=r._color,r._color=n,l(r),l(a),u>1&&((h=t[u-2]).right===r?h.right=a:h.left=a),t[u-1]=a,t[u]=r,u+1<t.length?t[u+1]=e:t.push(e),u+=2}}}(e),g.left===r?g.left=null:g.right=null,new c(this.tree._compare,e[0])},Object.defineProperty(f,\"key\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].key},enumerable:!0}),Object.defineProperty(f,\"value\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].value},enumerable:!0}),Object.defineProperty(f,\"index\",{get:function(){var t=0,e=this._stack;if(0===e.length){var r=this.tree.root;return r?r._count:0}e[e.length-1].left&&(t=e[e.length-1].left._count);for(var n=e.length-2;n>=0;--n)e[n+1]===e[n].right&&(++t,e[n].left&&(t+=e[n].left._count));return t},enumerable:!0}),f.next=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.right)for(e=e.right;e;)t.push(e),e=e.left;else for(t.pop();t.length>0&&t[t.length-1].right===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(f,\"hasNext\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].right)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].left===t[e])return!0;return!1}}),f.update=function(t){var e=this._stack;if(0===e.length)throw new Error(\"Can't update empty node!\");var r=new Array(e.length),n=e[e.length-1];r[r.length-1]=new a(n._color,n.key,t,n.left,n.right,n._count);for(var i=e.length-2;i>=0;--i)(n=e[i]).left===e[i+1]?r[i]=new a(n._color,n.key,n.value,r[i+1],n.right,n._count):r[i]=new a(n._color,n.key,n.value,n.left,r[i+1],n._count);return new c(this.tree._compare,r[0])},f.prev=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.left)for(e=e.left;e;)t.push(e),e=e.right;else for(t.pop();t.length>0&&t[t.length-1].left===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(f,\"hasPrev\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].left)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].right===t[e])return!0;return!1}})},{}],231:[function(t,e,r){var n=[.9999999999998099,676.5203681218851,-1259.1392167224028,771.3234287776531,-176.6150291621406,12.507343278686905,-.13857109526572012,9984369578019572e-21,1.5056327351493116e-7],i=607/128,a=[.9999999999999971,57.15623566586292,-59.59796035547549,14.136097974741746,-.4919138160976202,3399464998481189e-20,4652362892704858e-20,-9837447530487956e-20,.0001580887032249125,-.00021026444172410488,.00021743961811521265,-.0001643181065367639,8441822398385275e-20,-26190838401581408e-21,36899182659531625e-22];function o(t){if(t<0)return Number(\"0/0\");for(var e=a[0],r=a.length-1;r>0;--r)e+=a[r]/(t+r);var n=t+i+.5;return.5*Math.log(2*Math.PI)+(t+.5)*Math.log(n)-n+Math.log(e)-Math.log(t)}e.exports=function t(e){if(e<.5)return Math.PI/(Math.sin(Math.PI*e)*t(1-e));if(e>100)return Math.exp(o(e));e-=1;for(var r=n[0],i=1;i<9;i++)r+=n[i]/(e+i);var a=e+7+.5;return Math.sqrt(2*Math.PI)*Math.pow(a,e+.5)*Math.exp(-a)*r},e.exports.log=o},{}],232:[function(t,e,r){e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"must specify type string\");if(e=e||{},\"undefined\"==typeof document&&!e.canvas)return null;var r=e.canvas||document.createElement(\"canvas\");\"number\"==typeof e.width&&(r.width=e.width);\"number\"==typeof e.height&&(r.height=e.height);var n,i=e;try{var a=[t];0===t.indexOf(\"webgl\")&&a.push(\"experimental-\"+t);for(var o=0;o<a.length;o++)if(n=r.getContext(a[o],i))return n}catch(t){n=null}return n||null}},{}],233:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=new u(t);return r.update(e),r};var n=t(\"./lib/text.js\"),i=t(\"./lib/lines.js\"),a=t(\"./lib/background.js\"),o=t(\"./lib/cube.js\"),s=t(\"./lib/ticks.js\"),l=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]);function c(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function u(t){this.gl=t,this.pixelRatio=1,this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.autoTicks=!0,this.tickSpacing=[1,1,1],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickAlign=[\"auto\",\"auto\",\"auto\"],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[10,10,10],this.lastCubeProps={cubeEdges:[0,0,0],axis:[0,0,0]},this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=\"sans-serif\",this.labelSize=[20,20,20],this.labelAngle=[0,0,0],this.labelAlign=[\"auto\",\"auto\",\"auto\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[10,10,10],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[0,0,0],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!1,!1,!1],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._firstInit=!0,this._text=null,this._lines=null,this._background=a(t)}var h=u.prototype;function f(){this.primalOffset=[0,0,0],this.primalMinor=[0,0,0],this.mirrorOffset=[0,0,0],this.mirrorMinor=[0,0,0]}h.update=function(t){function e(e,r,n){if(n in t){var i,a=t[n],o=this[n];(e?Array.isArray(a)&&Array.isArray(a[0]):Array.isArray(a))?this[n]=i=[r(a[0]),r(a[1]),r(a[2])]:this[n]=i=[r(a),r(a),r(a)];for(var s=0;s<3;++s)if(i[s]!==o[s])return!0}return!1}t=t||{};var r,a=e.bind(this,!1,Number),o=e.bind(this,!1,Boolean),l=e.bind(this,!1,String),c=e.bind(this,!0,function(t){if(Array.isArray(t)){if(3===t.length)return[+t[0],+t[1],+t[2],1];if(4===t.length)return[+t[0],+t[1],+t[2],+t[3]]}return[0,0,0,1]}),u=!1,h=!1;if(\"bounds\"in t)for(var f=t.bounds,p=0;p<2;++p)for(var d=0;d<3;++d)f[p][d]!==this.bounds[p][d]&&(h=!0),this.bounds[p][d]=f[p][d];if(\"ticks\"in t){r=t.ticks,u=!0,this.autoTicks=!1;for(p=0;p<3;++p)this.tickSpacing[p]=0}else a(\"tickSpacing\")&&(this.autoTicks=!0,h=!0);if(this._firstInit&&(\"ticks\"in t||\"tickSpacing\"in t||(this.autoTicks=!0),h=!0,u=!0,this._firstInit=!1),h&&this.autoTicks&&(r=s.create(this.bounds,this.tickSpacing),u=!0),u){for(p=0;p<3;++p)r[p].sort(function(t,e){return t.x-e.x});s.equal(r,this.ticks)?u=!1:this.ticks=r}o(\"tickEnable\"),l(\"tickFont\")&&(u=!0),a(\"tickSize\"),a(\"tickAngle\"),a(\"tickPad\"),c(\"tickColor\");var g=l(\"labels\");l(\"labelFont\")&&(g=!0),o(\"labelEnable\"),a(\"labelSize\"),a(\"labelPad\"),c(\"labelColor\"),o(\"lineEnable\"),o(\"lineMirror\"),a(\"lineWidth\"),c(\"lineColor\"),o(\"lineTickEnable\"),o(\"lineTickMirror\"),a(\"lineTickLength\"),a(\"lineTickWidth\"),c(\"lineTickColor\"),o(\"gridEnable\"),a(\"gridWidth\"),c(\"gridColor\"),o(\"zeroEnable\"),c(\"zeroLineColor\"),a(\"zeroLineWidth\"),o(\"backgroundEnable\"),c(\"backgroundColor\"),this._text?this._text&&(g||u)&&this._text.update(this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont):this._text=n(this.gl,this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont),this._lines&&u&&(this._lines.dispose(),this._lines=null),this._lines||(this._lines=i(this.gl,this.bounds,this.ticks))};var p=[new f,new f,new f];function d(t,e,r,n,i){for(var a=t.primalOffset,o=t.primalMinor,s=t.mirrorOffset,l=t.mirrorMinor,c=n[e],u=0;u<3;++u)if(e!==u){var h=a,f=s,p=o,d=l;c&1<<u&&(h=s,f=a,p=l,d=o),h[u]=r[0][u],f[u]=r[1][u],i[u]>0?(p[u]=-1,d[u]=0):(p[u]=0,d[u]=1)}}var g=[0,0,0],v={model:l,view:l,projection:l,_ortho:!1};h.isOpaque=function(){return!0},h.isTransparent=function(){return!1},h.drawTransparent=function(t){};var m=[0,0,0],y=[0,0,0],x=[0,0,0];h.draw=function(t){t=t||v;for(var e=this.gl,r=t.model||l,n=t.view||l,i=t.projection||l,a=this.bounds,s=t._ortho||!1,u=o(r,n,i,a,s),h=u.cubeEdges,f=u.axis,b=n[12],_=n[13],w=n[14],k=n[15],T=(s?2:1)*this.pixelRatio*(i[3]*b+i[7]*_+i[11]*w+i[15]*k)/e.drawingBufferHeight,A=0;A<3;++A)this.lastCubeProps.cubeEdges[A]=h[A],this.lastCubeProps.axis[A]=f[A];var M=p;for(A=0;A<3;++A)d(p[A],A,this.bounds,h,f);e=this.gl;var S,E=g;for(A=0;A<3;++A)this.backgroundEnable[A]?E[A]=f[A]:E[A]=0;this._background.draw(r,n,i,a,E,this.backgroundColor),this._lines.bind(r,n,i,this);for(A=0;A<3;++A){var C=[0,0,0];f[A]>0?C[A]=a[1][A]:C[A]=a[0][A];for(var L=0;L<2;++L){var P=(A+1+L)%3,O=(A+1+(1^L))%3;this.gridEnable[P]&&this._lines.drawGrid(P,O,this.bounds,C,this.gridColor[P],this.gridWidth[P]*this.pixelRatio)}for(L=0;L<2;++L){P=(A+1+L)%3,O=(A+1+(1^L))%3;this.zeroEnable[O]&&Math.min(a[0][O],a[1][O])<=0&&Math.max(a[0][O],a[1][O])>=0&&this._lines.drawZero(P,O,this.bounds,C,this.zeroLineColor[O],this.zeroLineWidth[O]*this.pixelRatio)}}for(A=0;A<3;++A){this.lineEnable[A]&&this._lines.drawAxisLine(A,this.bounds,M[A].primalOffset,this.lineColor[A],this.lineWidth[A]*this.pixelRatio),this.lineMirror[A]&&this._lines.drawAxisLine(A,this.bounds,M[A].mirrorOffset,this.lineColor[A],this.lineWidth[A]*this.pixelRatio);var z=c(m,M[A].primalMinor),I=c(y,M[A].mirrorMinor),D=this.lineTickLength;for(L=0;L<3;++L){var R=T/r[5*L];z[L]*=D[L]*R,I[L]*=D[L]*R}this.lineTickEnable[A]&&this._lines.drawAxisTicks(A,M[A].primalOffset,z,this.lineTickColor[A],this.lineTickWidth[A]*this.pixelRatio),this.lineTickMirror[A]&&this._lines.drawAxisTicks(A,M[A].mirrorOffset,I,this.lineTickColor[A],this.lineTickWidth[A]*this.pixelRatio)}this._lines.unbind(),this._text.bind(r,n,i,this.pixelRatio);var F,B;function N(t){(B=[0,0,0])[t]=1}function j(t,e,r){var n=(t+1)%3,i=(t+2)%3,a=e[n],o=e[i],s=r[n],l=r[i];a>0&&l>0?N(n):a>0&&l<0?N(n):a<0&&l>0?N(n):a<0&&l<0?N(n):o>0&&s>0?N(i):o>0&&s<0?N(i):o<0&&s>0?N(i):o<0&&s<0&&N(i)}for(A=0;A<3;++A){var U=M[A].primalMinor,V=M[A].mirrorMinor,q=c(x,M[A].primalOffset);for(L=0;L<3;++L)this.lineTickEnable[A]&&(q[L]+=T*U[L]*Math.max(this.lineTickLength[L],0)/r[5*L]);var H=[0,0,0];if(H[A]=1,this.tickEnable[A]){-3600===this.tickAngle[A]?(this.tickAngle[A]=0,this.tickAlign[A]=\"auto\"):this.tickAlign[A]=-1,F=1,\"auto\"===(S=[this.tickAlign[A],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]),B=[0,0,0],j(A,U,V);for(L=0;L<3;++L)q[L]+=T*U[L]*this.tickPad[L]/r[5*L];this._text.drawTicks(A,this.tickSize[A],this.tickAngle[A],q,this.tickColor[A],H,B,S)}if(this.labelEnable[A]){F=0,B=[0,0,0],this.labels[A].length>4&&(N(A),F=1),\"auto\"===(S=[this.labelAlign[A],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]);for(L=0;L<3;++L)q[L]+=T*U[L]*this.labelPad[L]/r[5*L];q[A]+=.5*(a[0][A]+a[1][A]),this._text.drawLabel(A,this.labelSize[A],this.labelAngle[A],q,this.labelColor[A],[0,0,0],B,S)}}this._text.unbind()},h.dispose=function(){this._text.dispose(),this._lines.dispose(),this._background.dispose(),this._lines=null,this._text=null,this._background=null,this.gl=null}},{\"./lib/background.js\":234,\"./lib/cube.js\":235,\"./lib/lines.js\":236,\"./lib/text.js\":238,\"./lib/ticks.js\":239}],234:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=[],r=[],s=0,l=0;l<3;++l)for(var c=(l+1)%3,u=(l+2)%3,h=[0,0,0],f=[0,0,0],p=-1;p<=1;p+=2){r.push(s,s+2,s+1,s+1,s+2,s+3),h[l]=p,f[l]=p;for(var d=-1;d<=1;d+=2){h[c]=d;for(var g=-1;g<=1;g+=2)h[u]=g,e.push(h[0],h[1],h[2],f[0],f[1],f[2]),s+=1}var v=c;c=u,u=v}var m=n(t,new Float32Array(e)),y=n(t,new Uint16Array(r),t.ELEMENT_ARRAY_BUFFER),x=i(t,[{buffer:m,type:t.FLOAT,size:3,offset:0,stride:24},{buffer:m,type:t.FLOAT,size:3,offset:12,stride:24}],y),b=a(t);return b.attributes.position.location=0,b.attributes.normal.location=1,new o(t,m,x,b)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").bg;function o(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n}var s=o.prototype;s.draw=function(t,e,r,n,i,a){for(var o=!1,s=0;s<3;++s)o=o||i[s];if(o){var l=this.gl;l.enable(l.POLYGON_OFFSET_FILL),l.polygonOffset(1,2),this.shader.bind(),this.shader.uniforms={model:t,view:e,projection:r,bounds:n,enable:i,colors:a},this.vao.bind(),this.vao.draw(this.gl.TRIANGLES,36),this.vao.unbind(),l.disable(l.POLYGON_OFFSET_FILL)}},s.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders\":237,\"gl-buffer\":241,\"gl-vao\":327}],235:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,p){i(s,e,t),i(s,r,s);for(var y=0,x=0;x<2;++x){u[2]=a[x][2];for(var b=0;b<2;++b){u[1]=a[b][1];for(var _=0;_<2;++_)u[0]=a[_][0],f(l[y],u,s),y+=1}}for(var w=-1,x=0;x<8;++x){for(var k=l[x][3],T=0;T<3;++T)c[x][T]=l[x][T]/k;p&&(c[x][2]*=-1),k<0&&(w<0?w=x:c[x][2]<c[w][2]&&(w=x))}if(w<0){w=0;for(var A=0;A<3;++A){for(var M=(A+2)%3,S=(A+1)%3,E=-1,C=-1,L=0;L<2;++L){var P=L<<A,O=P+(L<<M)+(1-L<<S),z=P+(1-L<<M)+(L<<S);o(c[P],c[O],c[z],h)<0||(L?E=1:C=1)}if(E<0||C<0)C>E&&(w|=1<<A);else{for(var L=0;L<2;++L){var P=L<<A,O=P+(L<<M)+(1-L<<S),z=P+(1-L<<M)+(L<<S),I=d([l[P],l[O],l[z],l[P+(1<<M)+(1<<S)]]);L?E=I:C=I}C>E&&(w|=1<<A)}}}for(var D=7^w,R=-1,x=0;x<8;++x)x!==w&&x!==D&&(R<0?R=x:c[R][1]>c[x][1]&&(R=x));for(var F=-1,x=0;x<3;++x){var B=R^1<<x;if(B!==w&&B!==D){F<0&&(F=B);var S=c[B];S[0]<c[F][0]&&(F=B)}}for(var N=-1,x=0;x<3;++x){var B=R^1<<x;if(B!==w&&B!==D&&B!==F){N<0&&(N=B);var S=c[B];S[0]>c[N][0]&&(N=B)}}var j=g;j[0]=j[1]=j[2]=0,j[n.log2(F^R)]=R&F,j[n.log2(R^N)]=R&N;var U=7^N;U===w||U===D?(U=7^F,j[n.log2(N^U)]=U&N):j[n.log2(F^U)]=U&F;for(var V=v,q=w,A=0;A<3;++A)V[A]=q&1<<A?-1:1;return m};var n=t(\"bit-twiddle\"),i=t(\"gl-mat4/multiply\"),a=t(\"split-polygon\"),o=t(\"robust-orientation\"),s=new Array(16),l=new Array(8),c=new Array(8),u=new Array(3),h=[0,0,0];function f(t,e,r){for(var n=0;n<4;++n){t[n]=r[12+n];for(var i=0;i<3;++i)t[n]+=e[i]*r[4*i+n]}}!function(){for(var t=0;t<8;++t)l[t]=[1,1,1,1],c[t]=[1,1,1]}();var p=[[0,0,1,0,0],[0,0,-1,1,0],[0,-1,0,1,0],[0,1,0,1,0],[-1,0,0,1,0],[1,0,0,1,0]];function d(t){for(var e=0;e<p.length;++e)if((t=a.positive(t,p[e])).length<3)return 0;var r=t[0],n=r[0]/r[3],i=r[1]/r[3],o=0;for(e=1;e+1<t.length;++e){var s=t[e],l=t[e+1],c=s[0]/s[3]-n,u=s[1]/s[3]-i,h=l[0]/l[3]-n,f=l[1]/l[3]-i;o+=Math.abs(c*f-u*h)}return o}var g=[1,1,1],v=[0,0,0],m={cubeEdges:g,axis:v}},{\"bit-twiddle\":92,\"gl-mat4/multiply\":267,\"robust-orientation\":510,\"split-polygon\":527}],236:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var o=[],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[0,0,0];o.push(0,0,1,0,1,1,0,0,-1,0,0,-1,0,1,1,0,1,-1);for(var h=0;h<3;++h){for(var f=o.length/3|0,d=0;d<r[h].length;++d){var g=+r[h][d].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var v=o.length/3|0;s[h]=f,l[h]=v-f;for(var f=o.length/3|0,m=0;m<r[h].length;++m){var g=+r[h][m].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var v=o.length/3|0;c[h]=f,u[h]=v-f}var y=n(t,new Float32Array(o)),x=i(t,[{buffer:y,type:t.FLOAT,size:3,stride:0,offset:0}]),b=a(t);return b.attributes.position.location=0,new p(t,y,x,b,l,s,u,c)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").line,o=[0,0,0],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[1,1];function h(t){return t[0]=t[1]=t[2]=0,t}function f(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function p(t,e,r,n,i,a,o,s){this.gl=t,this.vertBuffer=e,this.vao=r,this.shader=n,this.tickCount=i,this.tickOffset=a,this.gridCount=o,this.gridOffset=s}var d=p.prototype;d.bind=function(t,e,r){this.shader.bind(),this.shader.uniforms.model=t,this.shader.uniforms.view=e,this.shader.uniforms.projection=r,u[0]=this.gl.drawingBufferWidth,u[1]=this.gl.drawingBufferHeight,this.shader.uniforms.screenShape=u,this.vao.bind()},d.unbind=function(){this.vao.unbind()},d.drawAxisLine=function(t,e,r,n,i){var a=h(s);this.shader.uniforms.majorAxis=s,a[t]=e[1][t]-e[0][t],this.shader.uniforms.minorAxis=a;var o,u=f(c,r);u[t]+=e[0][t],this.shader.uniforms.offset=u,this.shader.uniforms.lineWidth=i,this.shader.uniforms.color=n,(o=h(l))[(t+2)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6),(o=h(l))[(t+1)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6)},d.drawAxisTicks=function(t,e,r,n,i){if(this.tickCount[t]){var a=h(o);a[t]=1,this.shader.uniforms.majorAxis=a,this.shader.uniforms.offset=e,this.shader.uniforms.minorAxis=r,this.shader.uniforms.color=n,this.shader.uniforms.lineWidth=i;var s=h(l);s[t]=1,this.shader.uniforms.screenAxis=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t])}},d.drawGrid=function(t,e,r,n,i,a){if(this.gridCount[t]){var u=h(s);u[e]=r[1][e]-r[0][e],this.shader.uniforms.minorAxis=u;var p=f(c,n);p[e]+=r[0][e],this.shader.uniforms.offset=p;var d=h(o);d[t]=1,this.shader.uniforms.majorAxis=d;var g=h(l);g[t]=1,this.shader.uniforms.screenAxis=g,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,this.gridCount[t],this.gridOffset[t])}},d.drawZero=function(t,e,r,n,i,a){var o=h(s);this.shader.uniforms.majorAxis=o,o[t]=r[1][t]-r[0][t],this.shader.uniforms.minorAxis=o;var u=f(c,n);u[t]+=r[0][t],this.shader.uniforms.offset=u;var p=h(l);p[e]=1,this.shader.uniforms.screenAxis=p,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,6)},d.dispose=function(){this.vao.dispose(),this.vertBuffer.dispose(),this.shader.dispose()}},{\"./shaders\":237,\"gl-buffer\":241,\"gl-vao\":327}],237:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, majorAxis, minorAxis, screenAxis;\\nuniform float lineWidth;\\nuniform vec2 screenShape;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nvoid main() {\\n  vec3 major = position.x * majorAxis;\\n  vec3 minor = position.y * minorAxis;\\n\\n  vec3 vPosition = major + minor + offset;\\n  vec3 pPosition = project(vPosition);\\n  vec3 offset = project(vPosition + screenAxis * position.z);\\n\\n  vec2 screen = normalize((offset - pPosition).xy * screenShape) / screenShape;\\n\\n  gl_Position = vec4(pPosition + vec3(0.5 * screen * lineWidth, 0), 1.0);\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.line=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"}])};var s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, axis, alignDir, alignOpt;\\nuniform float scale, angle, pixelScale;\\nuniform vec2 resolution;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nfloat computeViewAngle(vec3 a, vec3 b) {\\n  vec3 A = project(a);\\n  vec3 B = project(b);\\n\\n  return atan(\\n    (B.y - A.y) * resolution.y,\\n    (B.x - A.x) * resolution.x\\n  );\\n}\\n\\nconst float PI = 3.141592;\\nconst float TWO_PI = 2.0 * PI;\\nconst float HALF_PI = 0.5 * PI;\\nconst float ONE_AND_HALF_PI = 1.5 * PI;\\n\\nint option = int(floor(alignOpt.x + 0.001));\\nfloat hv_ratio =       alignOpt.y;\\nbool enableAlign =    (alignOpt.z != 0.0);\\n\\nfloat mod_angle(float a) {\\n  return mod(a, PI);\\n}\\n\\nfloat positive_angle(float a) {\\n  return mod_angle((a < 0.0) ?\\n    a + TWO_PI :\\n    a\\n  );\\n}\\n\\nfloat look_upwards(float a) {\\n  float b = positive_angle(a);\\n  return ((b > HALF_PI) && (b <= ONE_AND_HALF_PI)) ?\\n    b - PI :\\n    b;\\n}\\n\\nfloat look_horizontal_or_vertical(float a, float ratio) {\\n  // ratio controls the ratio between being horizontal to (vertical + horizontal)\\n  // if ratio is set to 0.5 then it is 50%, 50%.\\n  // when using a higher ratio e.g. 0.75 the result would\\n  // likely be more horizontal than vertical.\\n\\n  float b = positive_angle(a);\\n\\n  return\\n    (b < (      ratio) * HALF_PI) ? 0.0 :\\n    (b < (2.0 - ratio) * HALF_PI) ? -HALF_PI :\\n    (b < (2.0 + ratio) * HALF_PI) ? 0.0 :\\n    (b < (4.0 - ratio) * HALF_PI) ? HALF_PI :\\n                                    0.0;\\n}\\n\\nfloat roundTo(float a, float b) {\\n  return float(b * floor((a + 0.5 * b) / b));\\n}\\n\\nfloat look_round_n_directions(float a, int n) {\\n  float b = positive_angle(a);\\n  float div = TWO_PI / float(n);\\n  float c = roundTo(b, div);\\n  return look_upwards(c);\\n}\\n\\nfloat applyAlignOption(float rawAngle, float delta) {\\n  return\\n    (option >  2) ? look_round_n_directions(rawAngle + delta, option) :       // option 3-n: round to n directions\\n    (option == 2) ? look_horizontal_or_vertical(rawAngle + delta, hv_ratio) : // horizontal or vertical\\n    (option == 1) ? rawAngle + delta :       // use free angle, and flip to align with one direction of the axis\\n    (option == 0) ? look_upwards(rawAngle) : // use free angle, and stay upwards\\n    (option ==-1) ? 0.0 :                    // useful for backward compatibility, all texts remains horizontal\\n                    rawAngle;                // otherwise return back raw input angle\\n}\\n\\nbool isAxisTitle = (axis.x == 0.0) &&\\n                   (axis.y == 0.0) &&\\n                   (axis.z == 0.0);\\n\\nvoid main() {\\n  //Compute world offset\\n  float axisDistance = position.z;\\n  vec3 dataPosition = axisDistance * axis + offset;\\n\\n  float beta = angle; // i.e. user defined attributes for each tick\\n\\n  float axisAngle;\\n  float clipAngle;\\n  float flip;\\n\\n  if (enableAlign) {\\n    axisAngle = (isAxisTitle) ? HALF_PI :\\n                      computeViewAngle(dataPosition, dataPosition + axis);\\n    clipAngle = computeViewAngle(dataPosition, dataPosition + alignDir);\\n\\n    axisAngle += (sin(axisAngle) < 0.0) ? PI : 0.0;\\n    clipAngle += (sin(clipAngle) < 0.0) ? PI : 0.0;\\n\\n    flip = (dot(vec2(cos(axisAngle), sin(axisAngle)),\\n                vec2(sin(clipAngle),-cos(clipAngle))) > 0.0) ? 1.0 : 0.0;\\n\\n    beta += applyAlignOption(clipAngle, flip * PI);\\n  }\\n\\n  //Compute plane offset\\n  vec2 planeCoord = position.xy * pixelScale;\\n\\n  mat2 planeXform = scale * mat2(\\n     cos(beta), sin(beta),\\n    -sin(beta), cos(beta)\\n  );\\n\\n  vec2 viewOffset = 2.0 * planeXform * planeCoord / resolution;\\n\\n  //Compute clip position\\n  vec3 clipPosition = project(dataPosition);\\n\\n  //Apply text offset in clip coordinates\\n  clipPosition += vec3(viewOffset, 0.0);\\n\\n  //Done\\n  gl_Position = vec4(clipPosition, 1.0);\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.text=function(t){return i(t,s,l,null,[{name:\"position\",type:\"vec3\"}])};var c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec3 normal;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 enable;\\nuniform vec3 bounds[2];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n\\n  vec3 signAxis = sign(bounds[1] - bounds[0]);\\n\\n  vec3 realNormal = signAxis * normal;\\n\\n  if(dot(realNormal, enable) > 0.0) {\\n    vec3 minRange = min(bounds[0], bounds[1]);\\n    vec3 maxRange = max(bounds[0], bounds[1]);\\n    vec3 nPosition = mix(minRange, maxRange, 0.5 * (position + 1.0));\\n    gl_Position = projection * view * model * vec4(nPosition, 1.0);\\n  } else {\\n    gl_Position = vec4(0,0,0,0);\\n  }\\n\\n  colorChannel = abs(realNormal);\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 colors[3];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n  gl_FragColor = colorChannel.x * colors[0] +\\n                 colorChannel.y * colors[1] +\\n                 colorChannel.z * colors[2];\\n}\"]);r.bg=function(t){return i(t,c,u,null,[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}])}},{\"gl-shader\":301,glslify:409}],238:[function(t,e,r){(function(r){\"use strict\";e.exports=function(t,e,r,a,s,l){var u=n(t),h=i(t,[{buffer:u,size:3}]),f=o(t);f.attributes.position.location=0;var p=new c(t,f,u,h);return p.update(e,r,a,s,l),p};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"vectorize-text\"),o=t(\"./shaders\").text,s=window||r.global||{},l=s.__TEXT_CACHE||{};s.__TEXT_CACHE={};function c(t,e,r,n){this.gl=t,this.shader=e,this.buffer=r,this.vao=n,this.tickOffset=this.tickCount=this.labelOffset=this.labelCount=null}var u=c.prototype,h=[0,0];u.bind=function(t,e,r,n){this.vao.bind(),this.shader.bind();var i=this.shader.uniforms;i.model=t,i.view=e,i.projection=r,i.pixelScale=n,h[0]=this.gl.drawingBufferWidth,h[1]=this.gl.drawingBufferHeight,this.shader.uniforms.resolution=h},u.unbind=function(){this.vao.unbind()},u.update=function(t,e,r,n,i){var o=[];function s(t,e,r,n,i,s){var c=l[r];c||(c=l[r]={});var u=c[e];u||(u=c[e]=function(t,e){try{return a(t,e)}catch(e){return console.warn('error vectorizing text:\"'+t+'\" error:',e),{cells:[],positions:[]}}}(e,{triangles:!0,font:r,textAlign:\"center\",textBaseline:\"middle\",lineSpacing:i,styletags:s}));for(var h=(n||12)/12,f=u.positions,p=u.cells,d=0,g=p.length;d<g;++d)for(var v=p[d],m=2;m>=0;--m){var y=f[v[m]];o.push(h*y[0],-h*y[1],t)}}for(var c=[0,0,0],u=[0,0,0],h=[0,0,0],f=[0,0,0],p={breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},d=0;d<3;++d){h[d]=o.length/3|0,s(.5*(t[0][d]+t[1][d]),e[d],r[d],12,1.25,p),f[d]=(o.length/3|0)-h[d],c[d]=o.length/3|0;for(var g=0;g<n[d].length;++g)n[d][g].text&&s(n[d][g].x,n[d][g].text,n[d][g].font||i,n[d][g].fontSize||12,1.25,p);u[d]=(o.length/3|0)-c[d]}this.buffer.update(o),this.tickOffset=c,this.tickCount=u,this.labelOffset=h,this.labelCount=f},u.drawTicks=function(t,e,r,n,i,a,o,s){this.tickCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t]))},u.drawLabel=function(t,e,r,n,i,a,o,s){this.labelCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.labelCount[t],this.labelOffset[t]))},u.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()}}).call(this,t(\"_process\"))},{\"./shaders\":237,_process:482,\"gl-buffer\":241,\"gl-vao\":327,\"vectorize-text\":550}],239:[function(t,e,r){\"use strict\";function n(t,e){var r=t+\"\",n=r.indexOf(\".\"),i=0;n>=0&&(i=r.length-n-1);var a=Math.pow(10,i),o=Math.round(t*e*a),s=o+\"\";if(s.indexOf(\"e\")>=0)return s;var l=o/a,c=o%a;o<0?(l=0|-Math.ceil(l),c=0|-c):(l=0|Math.floor(l),c|=0);var u=\"\"+l;if(o<0&&(u=\"-\"+u),i){for(var h=\"\"+c;h.length<i;)h=\"0\"+h;return u+\".\"+h}return u}r.create=function(t,e){for(var r=[],i=0;i<3;++i){for(var a=[],o=(t[0][i],t[1][i],0);o*e[i]<=t[1][i];++o)a.push({x:o*e[i],text:n(e[i],o)});for(var o=-1;o*e[i]>=t[0][i];--o)a.push({x:o*e[i],text:n(e[i],o)});r.push(a)}return r},r.equal=function(t,e){for(var r=0;r<3;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;++n){var i=t[r][n],a=e[r][n];if(i.x!==a.x||i.text!==a.text||i.font!==a.font||i.fontColor!==a.fontColor||i.fontSize!==a.fontSize||i.dx!==a.dx||i.dy!==a.dy)return!1}}return!0}},{}],240:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,l,h){var f=e.model||c,p=e.view||c,m=e.projection||c,y=e._ortho||!1,x=t.bounds,b=(h=h||a(f,p,m,x,y)).axis;o(u,p,f),o(u,m,u);for(var _=g,w=0;w<3;++w)_[w].lo=1/0,_[w].hi=-1/0,_[w].pixelsPerDataUnit=1/0;var k=n(s(u,u));s(u,u);for(var T=0;T<3;++T){var A=(T+1)%3,M=(T+2)%3,S=v;t:for(var w=0;w<2;++w){var E=[];if(b[T]<0!=!!w){S[T]=x[w][T];for(var C=0;C<2;++C){S[A]=x[C^w][A];for(var L=0;L<2;++L)S[M]=x[L^C^w][M],E.push(S.slice())}for(var P=y?5:4,C=P;C===P;++C){if(0===E.length)continue t;E=i.positive(E,k[C])}for(var C=0;C<E.length;++C)for(var M=E[C],O=d(v,u,M,r,l),L=0;L<3;++L)_[L].lo=Math.min(_[L].lo,M[L]),_[L].hi=Math.max(_[L].hi,M[L]),L!==T&&(_[L].pixelsPerDataUnit=Math.min(_[L].pixelsPerDataUnit,Math.abs(O[L])))}}}return _};var n=t(\"extract-frustum-planes\"),i=t(\"split-polygon\"),a=t(\"./lib/cube.js\"),o=t(\"gl-mat4/multiply\"),s=t(\"gl-mat4/transpose\"),l=t(\"gl-vec4/transformMat4\"),c=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]),u=new Float32Array(16);function h(t,e,r){this.lo=t,this.hi=e,this.pixelsPerDataUnit=r}var f=[0,0,0,1],p=[0,0,0,1];function d(t,e,r,n,i){for(var a=0;a<3;++a){for(var o=f,s=p,c=0;c<3;++c)s[c]=o[c]=r[c];s[3]=o[3]=1,s[a]+=1,l(s,s,e),s[3]<0&&(t[a]=1/0),o[a]-=1,l(o,o,e),o[3]<0&&(t[a]=1/0);var u=(o[0]/o[3]-s[0]/s[3])*n,h=(o[1]/o[3]-s[1]/s[3])*i;t[a]=.25*Math.sqrt(u*u+h*h)}return t}var g=[new h(1/0,-1/0,1/0),new h(1/0,-1/0,1/0),new h(1/0,-1/0,1/0)],v=[0,0,0]},{\"./lib/cube.js\":235,\"extract-frustum-planes\":224,\"gl-mat4/multiply\":267,\"gl-mat4/transpose\":276,\"gl-vec4/transformMat4\":398,\"split-polygon\":527}],241:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"ndarray-ops\"),a=t(\"ndarray\"),o=[\"uint8\",\"uint8_clamped\",\"uint16\",\"uint32\",\"int8\",\"int16\",\"int32\",\"float32\"];function s(t,e,r,n,i){this.gl=t,this.type=e,this.handle=r,this.length=n,this.usage=i}var l=s.prototype;function c(t,e,r,n,i,a){var o=i.length*i.BYTES_PER_ELEMENT;if(a<0)return t.bufferData(e,i,n),o;if(o+a>r)throw new Error(\"gl-buffer: If resizing buffer, must not specify offset\");return t.bufferSubData(e,a,i),r}function u(t,e){for(var r=n.malloc(t.length,e),i=t.length,a=0;a<i;++a)r[a]=t[a];return r}l.bind=function(){this.gl.bindBuffer(this.type,this.handle)},l.unbind=function(){this.gl.bindBuffer(this.type,null)},l.dispose=function(){this.gl.deleteBuffer(this.handle)},l.update=function(t,e){if(\"number\"!=typeof e&&(e=-1),this.bind(),\"object\"==typeof t&&\"undefined\"!=typeof t.shape){var r=t.dtype;if(o.indexOf(r)<0&&(r=\"float32\"),this.type===this.gl.ELEMENT_ARRAY_BUFFER)r=gl.getExtension(\"OES_element_index_uint\")&&\"uint16\"!==r?\"uint32\":\"uint16\";if(r===t.dtype&&function(t,e){for(var r=1,n=e.length-1;n>=0;--n){if(e[n]!==r)return!1;r*=t[n]}return!0}(t.shape,t.stride))0===t.offset&&t.data.length===t.shape[0]?this.length=c(this.gl,this.type,this.length,this.usage,t.data,e):this.length=c(this.gl,this.type,this.length,this.usage,t.data.subarray(t.offset,t.shape[0]),e);else{var s=n.malloc(t.size,r),l=a(s,t.shape);i.assign(l,t),this.length=c(this.gl,this.type,this.length,this.usage,e<0?s:s.subarray(0,t.size),e),n.free(s)}}else if(Array.isArray(t)){var h;h=this.type===this.gl.ELEMENT_ARRAY_BUFFER?u(t,\"uint16\"):u(t,\"float32\"),this.length=c(this.gl,this.type,this.length,this.usage,e<0?h:h.subarray(0,t.length),e),n.free(h)}else if(\"object\"==typeof t&&\"number\"==typeof t.length)this.length=c(this.gl,this.type,this.length,this.usage,t,e);else{if(\"number\"!=typeof t&&void 0!==t)throw new Error(\"gl-buffer: Invalid data type\");if(e>=0)throw new Error(\"gl-buffer: Cannot specify offset when resizing buffer\");(t|=0)<=0&&(t=1),this.gl.bufferData(this.type,0|t,this.usage),this.length=t}},e.exports=function(t,e,r,n){if(r=r||t.ARRAY_BUFFER,n=n||t.DYNAMIC_DRAW,r!==t.ARRAY_BUFFER&&r!==t.ELEMENT_ARRAY_BUFFER)throw new Error(\"gl-buffer: Invalid type for webgl buffer, must be either gl.ARRAY_BUFFER or gl.ELEMENT_ARRAY_BUFFER\");if(n!==t.DYNAMIC_DRAW&&n!==t.STATIC_DRAW&&n!==t.STREAM_DRAW)throw new Error(\"gl-buffer: Invalid usage for buffer, must be either gl.DYNAMIC_DRAW, gl.STATIC_DRAW or gl.STREAM_DRAW\");var i=t.createBuffer(),a=new s(t,r,i,0,n);return a.update(e),a}},{ndarray:450,\"ndarray-ops\":444,\"typedarray-pool\":545}],242:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\"),i=function(t,e){for(var r=0;r<t.length;r++)if(t[r]>=e)return r-1;return r},a=n.create(),o=n.create(),s=function(t,e,r){return t<e?e:t>r?r:t},l=function(t,e,r,l){var c=t[0],u=t[1],h=t[2],f=r[0].length,p=r[1].length,d=r[2].length,g=i(r[0],c),v=i(r[1],u),m=i(r[2],h),y=g+1,x=v+1,b=m+1;if(l&&(g=s(g,0,f-1),y=s(y,0,f-1),v=s(v,0,p-1),x=s(x,0,p-1),m=s(m,0,d-1),b=s(b,0,d-1)),g<0||v<0||m<0||y>=f||x>=p||b>=d)return n.create();var _=(c-r[0][g])/(r[0][y]-r[0][g]),w=(u-r[1][v])/(r[1][x]-r[1][v]),k=(h-r[2][m])/(r[2][b]-r[2][m]);(_<0||_>1||isNaN(_))&&(_=0),(w<0||w>1||isNaN(w))&&(w=0),(k<0||k>1||isNaN(k))&&(k=0);var T=m*f*p,A=b*f*p,M=v*f,S=x*f,E=g,C=y,L=e[M+T+E],P=e[M+T+C],O=e[S+T+E],z=e[S+T+C],I=e[M+A+E],D=e[M+A+C],R=e[S+A+E],F=e[S+A+C],B=n.create();return n.lerp(B,L,P,_),n.lerp(a,O,z,_),n.lerp(B,B,a,w),n.lerp(a,I,D,_),n.lerp(o,R,F,_),n.lerp(a,a,o,w),n.lerp(B,B,a,k),B};e.exports=function(t,e){var r;r=t.positions?t.positions:function(t){for(var e=t[0],r=t[1],n=t[2],i=[],a=0;a<n.length;a++)for(var o=0;o<r.length;o++)for(var s=0;s<e.length;s++)i.push([n[a],r[o],e[s]]);return i}(t.meshgrid);var i=t.meshgrid,a=t.vectors,o={positions:[],vertexIntensity:[],vertexIntensityBounds:t.vertexIntensityBounds,vertexNormals:[],vectors:[],cells:[],coneOffset:t.coneOffset,colormap:t.colormap};if(0===t.positions.length)return e&&(e[0]=[0,0,0],e[1]=[0,0,0]),o;for(var s=0,c=1/0,u=-1/0,h=1/0,f=-1/0,p=1/0,d=-1/0,g=null,v=null,m=[],y=1/0,x=0;x<r.length;x++){var b,_=r[x];c=Math.min(_[0],c),u=Math.max(_[0],u),h=Math.min(_[1],h),f=Math.max(_[1],f),p=Math.min(_[2],p),d=Math.max(_[2],d),b=i?l(_,a,i,!0):a[x],n.length(b)>s&&(s=n.length(b)),x&&(y=Math.min(y,2*n.distance(g,_)/(n.length(v)+n.length(b)))),g=_,v=b,m.push(b)}var w=[c,h,p],k=[u,f,d];e&&(e[0]=w,e[1]=k),0===s&&(s=1);var T=1/s;isFinite(y)&&!isNaN(y)||(y=1),o.vectorScale=y;var A=function(t,e,r){var i=n.create();return void 0!==t&&n.set(i,t,e,r),i}(0,1,0),M=t.coneSize||.5;t.absoluteConeSize&&(M=t.absoluteConeSize*T),o.coneScale=M;x=0;for(var S=0;x<r.length;x++)for(var E=(_=r[x])[0],C=_[1],L=_[2],P=m[x],O=n.length(P)*T,z=0;z<8;z++){o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vertexIntensity.push(O,O,O),o.vertexIntensity.push(O,O,O),o.vertexNormals.push(A,A,A),o.vertexNormals.push(A,A,A);var I=o.positions.length;o.cells.push([I-6,I-5,I-4],[I-3,I-2,I-1])}return o},e.exports.createConeMesh=t(\"./lib/conemesh\")},{\"./lib/conemesh\":243,\"gl-vec3\":346}],243:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./shaders\"),g=d.meshShader,v=d.pickShader,m=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function y(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,y,x,b,_,w,k,T){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=i,this.triangleVectors=a,this.triangleColors=s,this.triangleNormals=c,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=u,this.triangleCount=0,this.lineWidth=1,this.edgePositions=h,this.edgeColors=p,this.edgeUVs=d,this.edgeIds=f,this.edgeVAO=g,this.edgeCount=0,this.pointPositions=v,this.pointColors=x,this.pointUVs=b,this.pointSizes=_,this.pointIds=y,this.pointVAO=w,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=k,this.contourVAO=T,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.coneScale=2,this.vectorScale=1,this.coneOffset=.25,this._model=m,this._view=m,this._projection=m,this._resolution=[1,1]}var x=y.prototype;function b(t){var e=n(t,v.vertex,v.fragment,null,v.attributes);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.vector.location=5,e}x.isOpaque=function(){return this.opacity>=1},x.isTransparent=function(){return this.opacity<1},x.pickSlots=1,x.setPickBase=function(t){this.pickId=t},x.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=i[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},x.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),void 0!==t.vectorScale&&(this.vectorScale=t.vectorScale),void 0!==t.coneScale&&(this.coneScale=t.coneScale),void 0!==t.coneOffset&&(this.coneOffset=t.coneOffset),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=h({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return u(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,i=t.vectors;if(n&&r&&i){var a=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[],w=[],k=[];this.cells=r,this.positions=n;var T=t.vertexNormals,A=t.cellNormals,M=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,S=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!A&&(A=s.faceNormals(r,n,S)),A||T||(T=s.vertexNormals(r,n,M));var E=t.vertexColors,C=t.cellColors,L=t.meshColor||[1,1,1,1],P=t.vertexUVs,O=t.vertexIntensity,z=t.cellUVs,I=t.cellIntensity,D=1/0,R=-1/0;if(!P&&!z)if(O)if(t.vertexIntensityBounds)D=+t.vertexIntensityBounds[0],R=+t.vertexIntensityBounds[1];else for(var F=0;F<O.length;++F){var B=O[F];D=Math.min(D,B),R=Math.max(R,B)}else if(I)for(F=0;F<I.length;++F){B=I[F];D=Math.min(D,B),R=Math.max(R,B)}else for(F=0;F<n.length;++F){B=n[F][2];D=Math.min(D,B),R=Math.max(R,B)}this.intensity=O||(I?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,I):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var N=t.pointSizes,j=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(F=0;F<n.length;++F)for(var U=n[F],V=0;V<3;++V)!isNaN(U[V])&&isFinite(U[V])&&(this.bounds[0][V]=Math.min(this.bounds[0][V],U[V]),this.bounds[1][V]=Math.max(this.bounds[1][V],U[V]));var q=0,H=0,G=0;t:for(F=0;F<r.length;++F){var Y=r[F];switch(Y.length){case 1:for(U=n[X=Y[0]],V=0;V<3;++V)if(isNaN(U[V])||!isFinite(U[V]))continue t;x.push(U[0],U[1],U[2],U[3]),3===(Z=E?E[X]:C?C[F]:L).length?b.push(Z[0],Z[1],Z[2],1):b.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],_.push(J[0],J[1]),N?w.push(N[X]):w.push(j),k.push(F),G+=1;break;case 2:for(V=0;V<2;++V){U=n[X=Y[V]];for(var W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t}for(V=0;V<2;++V){U=n[X=Y[V]];g.push(U[0],U[1],U[2]),3===(Z=E?E[X]:C?C[F]:L).length?v.push(Z[0],Z[1],Z[2],1):v.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],m.push(J[0],J[1]),y.push(F)}H+=1;break;case 3:for(V=0;V<3;++V)for(U=n[X=Y[V]],W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t;for(V=0;V<3;++V){var X;U=n[X=Y[2-V]];a.push(U[0],U[1],U[2],U[3]);var Z,J,K,$=i[X];l.push($[0],$[1],$[2]),3===(Z=E?E[X]:C?C[F]:L).length?c.push(Z[0],Z[1],Z[2],1):c.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],p.push(J[0],J[1]),K=T?T[X]:A[F],f.push(K[0],K[1],K[2]),d.push(F)}q+=1}}this.pointCount=G,this.edgeCount=H,this.triangleCount=q,this.pointPositions.update(x),this.pointColors.update(b),this.pointUVs.update(_),this.pointSizes.update(w),this.pointIds.update(new Uint32Array(k)),this.edgePositions.update(g),this.edgeColors.update(v),this.edgeUVs.update(m),this.edgeIds.update(new Uint32Array(y)),this.trianglePositions.update(a),this.triangleVectors.update(l),this.triangleColors.update(c),this.triangleUVs.update(p),this.triangleNormals.update(f),this.triangleIds.update(new Uint32Array(d))}},x.drawTransparent=x.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:m.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var f=u[12+o],p=0;p<3;++p)f+=u[4*p+o]*this.lightPosition[p];s.lightPosition[o]=f/h}if(this.triangleCount>0){var d=this.triShader;d.bind(),d.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},x.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:i,clipBounds:a,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind())},x.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3);return{index:Math.floor(r[1]/48),position:n,dataCoordinate:n}},x.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose()},e.exports=function(t,e){1===arguments.length&&(t=(e=t).gl);var r=e.triShader||function(t){var e=n(t,g.vertex,g.fragment,null,g.attributes);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.vector.location=5,e}(t),s=b(t),l=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));l.generateMipmap(),l.minFilter=t.LINEAR_MIPMAP_LINEAR,l.magFilter=t.LINEAR;var c=i(t),h=i(t),f=i(t),p=i(t),d=i(t),v=i(t),m=a(t,[{buffer:c,type:t.FLOAT,size:4},{buffer:v,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:f,type:t.FLOAT,size:4},{buffer:p,type:t.FLOAT,size:2},{buffer:d,type:t.FLOAT,size:3},{buffer:h,type:t.FLOAT,size:3}]),x=i(t),_=i(t),w=i(t),k=i(t),T=a(t,[{buffer:x,type:t.FLOAT,size:3},{buffer:k,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:_,type:t.FLOAT,size:4},{buffer:w,type:t.FLOAT,size:2}]),A=i(t),M=i(t),S=i(t),E=i(t),C=i(t),L=a(t,[{buffer:A,type:t.FLOAT,size:3},{buffer:C,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:M,type:t.FLOAT,size:4},{buffer:S,type:t.FLOAT,size:2},{buffer:E,type:t.FLOAT,size:1}]),P=i(t),O=new y(t,l,r,s,c,h,v,f,p,d,m,x,k,_,w,T,A,C,M,S,E,L,P,a(t,[{buffer:P,type:t.FLOAT,size:3}]));return O.update(e),O}},{\"./shaders\":244,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-shader\":301,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,normals:453,\"simplicial-complex-contour\":518,\"typedarray-pool\":545}],244:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\nuniform float vectorScale;\\nuniform float coneScale;\\n\\nuniform float coneOffset;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * conePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal,0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(conePosition, 1.0);\\n  vec4 t_position  = view * conePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = conePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular\\n            , opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nuniform float vectorScale;\\nuniform float coneScale;\\nuniform float coneOffset;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n  gl_Position = projection * view * conePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec3\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec3\"}]}},{glslify:409}],245:[function(t,e,r){e.exports={0:\"NONE\",1:\"ONE\",2:\"LINE_LOOP\",3:\"LINE_STRIP\",4:\"TRIANGLES\",5:\"TRIANGLE_STRIP\",6:\"TRIANGLE_FAN\",256:\"DEPTH_BUFFER_BIT\",512:\"NEVER\",513:\"LESS\",514:\"EQUAL\",515:\"LEQUAL\",516:\"GREATER\",517:\"NOTEQUAL\",518:\"GEQUAL\",519:\"ALWAYS\",768:\"SRC_COLOR\",769:\"ONE_MINUS_SRC_COLOR\",770:\"SRC_ALPHA\",771:\"ONE_MINUS_SRC_ALPHA\",772:\"DST_ALPHA\",773:\"ONE_MINUS_DST_ALPHA\",774:\"DST_COLOR\",775:\"ONE_MINUS_DST_COLOR\",776:\"SRC_ALPHA_SATURATE\",1024:\"STENCIL_BUFFER_BIT\",1028:\"FRONT\",1029:\"BACK\",1032:\"FRONT_AND_BACK\",1280:\"INVALID_ENUM\",1281:\"INVALID_VALUE\",1282:\"INVALID_OPERATION\",1285:\"OUT_OF_MEMORY\",1286:\"INVALID_FRAMEBUFFER_OPERATION\",2304:\"CW\",2305:\"CCW\",2849:\"LINE_WIDTH\",2884:\"CULL_FACE\",2885:\"CULL_FACE_MODE\",2886:\"FRONT_FACE\",2928:\"DEPTH_RANGE\",2929:\"DEPTH_TEST\",2930:\"DEPTH_WRITEMASK\",2931:\"DEPTH_CLEAR_VALUE\",2932:\"DEPTH_FUNC\",2960:\"STENCIL_TEST\",2961:\"STENCIL_CLEAR_VALUE\",2962:\"STENCIL_FUNC\",2963:\"STENCIL_VALUE_MASK\",2964:\"STENCIL_FAIL\",2965:\"STENCIL_PASS_DEPTH_FAIL\",2966:\"STENCIL_PASS_DEPTH_PASS\",2967:\"STENCIL_REF\",2968:\"STENCIL_WRITEMASK\",2978:\"VIEWPORT\",3024:\"DITHER\",3042:\"BLEND\",3088:\"SCISSOR_BOX\",3089:\"SCISSOR_TEST\",3106:\"COLOR_CLEAR_VALUE\",3107:\"COLOR_WRITEMASK\",3317:\"UNPACK_ALIGNMENT\",3333:\"PACK_ALIGNMENT\",3379:\"MAX_TEXTURE_SIZE\",3386:\"MAX_VIEWPORT_DIMS\",3408:\"SUBPIXEL_BITS\",3410:\"RED_BITS\",3411:\"GREEN_BITS\",3412:\"BLUE_BITS\",3413:\"ALPHA_BITS\",3414:\"DEPTH_BITS\",3415:\"STENCIL_BITS\",3553:\"TEXTURE_2D\",4352:\"DONT_CARE\",4353:\"FASTEST\",4354:\"NICEST\",5120:\"BYTE\",5121:\"UNSIGNED_BYTE\",5122:\"SHORT\",5123:\"UNSIGNED_SHORT\",5124:\"INT\",5125:\"UNSIGNED_INT\",5126:\"FLOAT\",5386:\"INVERT\",5890:\"TEXTURE\",6401:\"STENCIL_INDEX\",6402:\"DEPTH_COMPONENT\",6406:\"ALPHA\",6407:\"RGB\",6408:\"RGBA\",6409:\"LUMINANCE\",6410:\"LUMINANCE_ALPHA\",7680:\"KEEP\",7681:\"REPLACE\",7682:\"INCR\",7683:\"DECR\",7936:\"VENDOR\",7937:\"RENDERER\",7938:\"VERSION\",9728:\"NEAREST\",9729:\"LINEAR\",9984:\"NEAREST_MIPMAP_NEAREST\",9985:\"LINEAR_MIPMAP_NEAREST\",9986:\"NEAREST_MIPMAP_LINEAR\",9987:\"LINEAR_MIPMAP_LINEAR\",10240:\"TEXTURE_MAG_FILTER\",10241:\"TEXTURE_MIN_FILTER\",10242:\"TEXTURE_WRAP_S\",10243:\"TEXTURE_WRAP_T\",10497:\"REPEAT\",10752:\"POLYGON_OFFSET_UNITS\",16384:\"COLOR_BUFFER_BIT\",32769:\"CONSTANT_COLOR\",32770:\"ONE_MINUS_CONSTANT_COLOR\",32771:\"CONSTANT_ALPHA\",32772:\"ONE_MINUS_CONSTANT_ALPHA\",32773:\"BLEND_COLOR\",32774:\"FUNC_ADD\",32777:\"BLEND_EQUATION_RGB\",32778:\"FUNC_SUBTRACT\",32779:\"FUNC_REVERSE_SUBTRACT\",32819:\"UNSIGNED_SHORT_4_4_4_4\",32820:\"UNSIGNED_SHORT_5_5_5_1\",32823:\"POLYGON_OFFSET_FILL\",32824:\"POLYGON_OFFSET_FACTOR\",32854:\"RGBA4\",32855:\"RGB5_A1\",32873:\"TEXTURE_BINDING_2D\",32926:\"SAMPLE_ALPHA_TO_COVERAGE\",32928:\"SAMPLE_COVERAGE\",32936:\"SAMPLE_BUFFERS\",32937:\"SAMPLES\",32938:\"SAMPLE_COVERAGE_VALUE\",32939:\"SAMPLE_COVERAGE_INVERT\",32968:\"BLEND_DST_RGB\",32969:\"BLEND_SRC_RGB\",32970:\"BLEND_DST_ALPHA\",32971:\"BLEND_SRC_ALPHA\",33071:\"CLAMP_TO_EDGE\",33170:\"GENERATE_MIPMAP_HINT\",33189:\"DEPTH_COMPONENT16\",33306:\"DEPTH_STENCIL_ATTACHMENT\",33635:\"UNSIGNED_SHORT_5_6_5\",33648:\"MIRRORED_REPEAT\",33901:\"ALIASED_POINT_SIZE_RANGE\",33902:\"ALIASED_LINE_WIDTH_RANGE\",33984:\"TEXTURE0\",33985:\"TEXTURE1\",33986:\"TEXTURE2\",33987:\"TEXTURE3\",33988:\"TEXTURE4\",33989:\"TEXTURE5\",33990:\"TEXTURE6\",33991:\"TEXTURE7\",33992:\"TEXTURE8\",33993:\"TEXTURE9\",33994:\"TEXTURE10\",33995:\"TEXTURE11\",33996:\"TEXTURE12\",33997:\"TEXTURE13\",33998:\"TEXTURE14\",33999:\"TEXTURE15\",34000:\"TEXTURE16\",34001:\"TEXTURE17\",34002:\"TEXTURE18\",34003:\"TEXTURE19\",34004:\"TEXTURE20\",34005:\"TEXTURE21\",34006:\"TEXTURE22\",34007:\"TEXTURE23\",34008:\"TEXTURE24\",34009:\"TEXTURE25\",34010:\"TEXTURE26\",34011:\"TEXTURE27\",34012:\"TEXTURE28\",34013:\"TEXTURE29\",34014:\"TEXTURE30\",34015:\"TEXTURE31\",34016:\"ACTIVE_TEXTURE\",34024:\"MAX_RENDERBUFFER_SIZE\",34041:\"DEPTH_STENCIL\",34055:\"INCR_WRAP\",34056:\"DECR_WRAP\",34067:\"TEXTURE_CUBE_MAP\",34068:\"TEXTURE_BINDING_CUBE_MAP\",34069:\"TEXTURE_CUBE_MAP_POSITIVE_X\",34070:\"TEXTURE_CUBE_MAP_NEGATIVE_X\",34071:\"TEXTURE_CUBE_MAP_POSITIVE_Y\",34072:\"TEXTURE_CUBE_MAP_NEGATIVE_Y\",34073:\"TEXTURE_CUBE_MAP_POSITIVE_Z\",34074:\"TEXTURE_CUBE_MAP_NEGATIVE_Z\",34076:\"MAX_CUBE_MAP_TEXTURE_SIZE\",34338:\"VERTEX_ATTRIB_ARRAY_ENABLED\",34339:\"VERTEX_ATTRIB_ARRAY_SIZE\",34340:\"VERTEX_ATTRIB_ARRAY_STRIDE\",34341:\"VERTEX_ATTRIB_ARRAY_TYPE\",34342:\"CURRENT_VERTEX_ATTRIB\",34373:\"VERTEX_ATTRIB_ARRAY_POINTER\",34466:\"NUM_COMPRESSED_TEXTURE_FORMATS\",34467:\"COMPRESSED_TEXTURE_FORMATS\",34660:\"BUFFER_SIZE\",34661:\"BUFFER_USAGE\",34816:\"STENCIL_BACK_FUNC\",34817:\"STENCIL_BACK_FAIL\",34818:\"STENCIL_BACK_PASS_DEPTH_FAIL\",34819:\"STENCIL_BACK_PASS_DEPTH_PASS\",34877:\"BLEND_EQUATION_ALPHA\",34921:\"MAX_VERTEX_ATTRIBS\",34922:\"VERTEX_ATTRIB_ARRAY_NORMALIZED\",34930:\"MAX_TEXTURE_IMAGE_UNITS\",34962:\"ARRAY_BUFFER\",34963:\"ELEMENT_ARRAY_BUFFER\",34964:\"ARRAY_BUFFER_BINDING\",34965:\"ELEMENT_ARRAY_BUFFER_BINDING\",34975:\"VERTEX_ATTRIB_ARRAY_BUFFER_BINDING\",35040:\"STREAM_DRAW\",35044:\"STATIC_DRAW\",35048:\"DYNAMIC_DRAW\",35632:\"FRAGMENT_SHADER\",35633:\"VERTEX_SHADER\",35660:\"MAX_VERTEX_TEXTURE_IMAGE_UNITS\",35661:\"MAX_COMBINED_TEXTURE_IMAGE_UNITS\",35663:\"SHADER_TYPE\",35664:\"FLOAT_VEC2\",35665:\"FLOAT_VEC3\",35666:\"FLOAT_VEC4\",35667:\"INT_VEC2\",35668:\"INT_VEC3\",35669:\"INT_VEC4\",35670:\"BOOL\",35671:\"BOOL_VEC2\",35672:\"BOOL_VEC3\",35673:\"BOOL_VEC4\",35674:\"FLOAT_MAT2\",35675:\"FLOAT_MAT3\",35676:\"FLOAT_MAT4\",35678:\"SAMPLER_2D\",35680:\"SAMPLER_CUBE\",35712:\"DELETE_STATUS\",35713:\"COMPILE_STATUS\",35714:\"LINK_STATUS\",35715:\"VALIDATE_STATUS\",35716:\"INFO_LOG_LENGTH\",35717:\"ATTACHED_SHADERS\",35718:\"ACTIVE_UNIFORMS\",35719:\"ACTIVE_UNIFORM_MAX_LENGTH\",35720:\"SHADER_SOURCE_LENGTH\",35721:\"ACTIVE_ATTRIBUTES\",35722:\"ACTIVE_ATTRIBUTE_MAX_LENGTH\",35724:\"SHADING_LANGUAGE_VERSION\",35725:\"CURRENT_PROGRAM\",36003:\"STENCIL_BACK_REF\",36004:\"STENCIL_BACK_VALUE_MASK\",36005:\"STENCIL_BACK_WRITEMASK\",36006:\"FRAMEBUFFER_BINDING\",36007:\"RENDERBUFFER_BINDING\",36048:\"FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE\",36049:\"FRAMEBUFFER_ATTACHMENT_OBJECT_NAME\",36050:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL\",36051:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE\",36053:\"FRAMEBUFFER_COMPLETE\",36054:\"FRAMEBUFFER_INCOMPLETE_ATTACHMENT\",36055:\"FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT\",36057:\"FRAMEBUFFER_INCOMPLETE_DIMENSIONS\",36061:\"FRAMEBUFFER_UNSUPPORTED\",36064:\"COLOR_ATTACHMENT0\",36096:\"DEPTH_ATTACHMENT\",36128:\"STENCIL_ATTACHMENT\",36160:\"FRAMEBUFFER\",36161:\"RENDERBUFFER\",36162:\"RENDERBUFFER_WIDTH\",36163:\"RENDERBUFFER_HEIGHT\",36164:\"RENDERBUFFER_INTERNAL_FORMAT\",36168:\"STENCIL_INDEX8\",36176:\"RENDERBUFFER_RED_SIZE\",36177:\"RENDERBUFFER_GREEN_SIZE\",36178:\"RENDERBUFFER_BLUE_SIZE\",36179:\"RENDERBUFFER_ALPHA_SIZE\",36180:\"RENDERBUFFER_DEPTH_SIZE\",36181:\"RENDERBUFFER_STENCIL_SIZE\",36194:\"RGB565\",36336:\"LOW_FLOAT\",36337:\"MEDIUM_FLOAT\",36338:\"HIGH_FLOAT\",36339:\"LOW_INT\",36340:\"MEDIUM_INT\",36341:\"HIGH_INT\",36346:\"SHADER_COMPILER\",36347:\"MAX_VERTEX_UNIFORM_VECTORS\",36348:\"MAX_VARYING_VECTORS\",36349:\"MAX_FRAGMENT_UNIFORM_VECTORS\",37440:\"UNPACK_FLIP_Y_WEBGL\",37441:\"UNPACK_PREMULTIPLY_ALPHA_WEBGL\",37442:\"CONTEXT_LOST_WEBGL\",37443:\"UNPACK_COLORSPACE_CONVERSION_WEBGL\",37444:\"BROWSER_DEFAULT_WEBGL\"}},{}],246:[function(t,e,r){var n=t(\"./1.0/numbers\");e.exports=function(t){return n[t]}},{\"./1.0/numbers\":245}],247:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),o=i(e,[{buffer:r,type:e.FLOAT,size:3,offset:0,stride:40},{buffer:r,type:e.FLOAT,size:4,offset:12,stride:40},{buffer:r,type:e.FLOAT,size:3,offset:28,stride:40}]),l=a(e);l.attributes.position.location=0,l.attributes.color.location=1,l.attributes.offset.location=2;var c=new s(e,r,o,l);return c.update(t),c};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\"),o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.shader=n,this.buffer=e,this.vao=r,this.pixelRatio=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lineWidth=[1,1,1],this.capSize=[10,10,10],this.lineCount=[0,0,0],this.lineOffset=[0,0,0],this.opacity=1,this.hasAlpha=!1}var l=s.prototype;function c(t,e){for(var r=0;r<3;++r)t[0][r]=Math.min(t[0][r],e[r]),t[1][r]=Math.max(t[1][r],e[r])}l.isOpaque=function(){return!this.hasAlpha},l.isTransparent=function(){return this.hasAlpha},l.drawTransparent=l.draw=function(t){var e=this.gl,r=this.shader.uniforms;this.shader.bind();var n=r.view=t.view||o,i=r.projection=t.projection||o;r.model=t.model||o,r.clipBounds=this.clipBounds,r.opacity=this.opacity;var a=n[12],s=n[13],l=n[14],c=n[15],u=(t._ortho||!1?2:1)*this.pixelRatio*(i[3]*a+i[7]*s+i[11]*l+i[15]*c)/e.drawingBufferHeight;this.vao.bind();for(var h=0;h<3;++h)e.lineWidth(this.lineWidth[h]*this.pixelRatio),r.capSize=this.capSize[h]*u,this.lineCount[h]&&e.drawArrays(e.LINES,this.lineOffset[h],this.lineCount[h]);this.vao.unbind()};var u=function(){for(var t=new Array(3),e=0;e<3;++e){for(var r=[],n=1;n<=2;++n)for(var i=-1;i<=1;i+=2){var a=[0,0,0];a[(n+e)%3]=i,r.push(a)}t[e]=r}return t}();function h(t,e,r,n){for(var i=u[n],a=0;a<i.length;++a){var o=i[a];t.push(e[0],e[1],e[2],r[0],r[1],r[2],r[3],o[0],o[1],o[2])}return i.length}l.update=function(t){\"lineWidth\"in(t=t||{})&&(this.lineWidth=t.lineWidth,Array.isArray(this.lineWidth)||(this.lineWidth=[this.lineWidth,this.lineWidth,this.lineWidth])),\"capSize\"in t&&(this.capSize=t.capSize,Array.isArray(this.capSize)||(this.capSize=[this.capSize,this.capSize,this.capSize])),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var e=t.color||[[0,0,0],[0,0,0],[0,0,0]],r=t.position,n=t.error;if(Array.isArray(e[0])||(e=[e,e,e]),r&&n){var i=[],a=r.length,o=0;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.lineCount=[0,0,0];for(var s=0;s<3;++s){this.lineOffset[s]=o;t:for(var l=0;l<a;++l){for(var u=r[l],f=0;f<3;++f)if(isNaN(u[f])||!isFinite(u[f]))continue t;var p=n[l],d=e[s];if(Array.isArray(d[0])&&(d=e[l]),3===d.length?d=[d[0],d[1],d[2],1]:4===d.length&&(d=[d[0],d[1],d[2],d[3]],!this.hasAlpha&&d[3]<1&&(this.hasAlpha=!0)),!isNaN(p[0][s])&&!isNaN(p[1][s])){var g;if(p[0][s]<0)(g=u.slice())[s]+=p[0][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+h(i,g,d,s);if(p[1][s]>0)(g=u.slice())[s]+=p[1][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+h(i,g,d,s)}}this.lineCount[s]=o-this.lineOffset[s]}this.buffer.update(i)}},l.dispose=function(){this.shader.dispose(),this.buffer.dispose(),this.vao.dispose()}},{\"./shaders/index\":248,\"gl-buffer\":241,\"gl-vao\":327}],248:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, offset;\\nattribute vec4 color;\\nuniform mat4 model, view, projection;\\nuniform float capSize;\\nvarying vec4 fragColor;\\nvarying vec3 fragPosition;\\n\\nvoid main() {\\n  vec4 worldPosition  = model * vec4(position, 1.0);\\n  worldPosition       = (worldPosition / worldPosition.w) + vec4(capSize * offset, 0.0);\\n  gl_Position         = projection * view * worldPosition;\\n  fragColor           = color;\\n  fragPosition        = position;\\n}\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float opacity;\\nvarying vec3 fragPosition;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], fragPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  gl_FragColor = opacity * fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"offset\",type:\"vec3\"}])}},{\"gl-shader\":301,glslify:409}],249:[function(t,e,r){\"use strict\";var n=t(\"gl-texture2d\");e.exports=function(t,e,r,n){i||(i=t.FRAMEBUFFER_UNSUPPORTED,a=t.FRAMEBUFFER_INCOMPLETE_ATTACHMENT,o=t.FRAMEBUFFER_INCOMPLETE_DIMENSIONS,s=t.FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT);var c=t.getExtension(\"WEBGL_draw_buffers\");!l&&c&&function(t,e){var r=t.getParameter(e.MAX_COLOR_ATTACHMENTS_WEBGL);l=new Array(r+1);for(var n=0;n<=r;++n){for(var i=new Array(r),a=0;a<n;++a)i[a]=t.COLOR_ATTACHMENT0+a;for(var a=n;a<r;++a)i[a]=t.NONE;l[n]=i}}(t,c);Array.isArray(e)&&(n=r,r=0|e[1],e=0|e[0]);if(\"number\"!=typeof e)throw new Error(\"gl-fbo: Missing shape parameter\");var u=t.getParameter(t.MAX_RENDERBUFFER_SIZE);if(e<0||e>u||r<0||r>u)throw new Error(\"gl-fbo: Parameters are too large for FBO\");var h=1;if(\"color\"in(n=n||{})){if((h=Math.max(0|n.color,0))<0)throw new Error(\"gl-fbo: Must specify a nonnegative number of colors\");if(h>1){if(!c)throw new Error(\"gl-fbo: Multiple draw buffer extension not supported\");if(h>t.getParameter(c.MAX_COLOR_ATTACHMENTS_WEBGL))throw new Error(\"gl-fbo: Context does not support \"+h+\" draw buffers\")}}var f=t.UNSIGNED_BYTE,p=t.getExtension(\"OES_texture_float\");if(n.float&&h>0){if(!p)throw new Error(\"gl-fbo: Context does not support floating point textures\");f=t.FLOAT}else n.preferFloat&&h>0&&p&&(f=t.FLOAT);var g=!0;\"depth\"in n&&(g=!!n.depth);var v=!1;\"stencil\"in n&&(v=!!n.stencil);return new d(t,e,r,f,h,g,v,c)};var i,a,o,s,l=null;function c(t){return[t.getParameter(t.FRAMEBUFFER_BINDING),t.getParameter(t.RENDERBUFFER_BINDING),t.getParameter(t.TEXTURE_BINDING_2D)]}function u(t,e){t.bindFramebuffer(t.FRAMEBUFFER,e[0]),t.bindRenderbuffer(t.RENDERBUFFER,e[1]),t.bindTexture(t.TEXTURE_2D,e[2])}function h(t){switch(t){case i:throw new Error(\"gl-fbo: Framebuffer unsupported\");case a:throw new Error(\"gl-fbo: Framebuffer incomplete attachment\");case o:throw new Error(\"gl-fbo: Framebuffer incomplete dimensions\");case s:throw new Error(\"gl-fbo: Framebuffer incomplete missing attachment\");default:throw new Error(\"gl-fbo: Framebuffer failed for unspecified reason\")}}function f(t,e,r,i,a,o){if(!i)return null;var s=n(t,e,r,a,i);return s.magFilter=t.NEAREST,s.minFilter=t.NEAREST,s.mipSamples=1,s.bind(),t.framebufferTexture2D(t.FRAMEBUFFER,o,t.TEXTURE_2D,s.handle,0),s}function p(t,e,r,n,i){var a=t.createRenderbuffer();return t.bindRenderbuffer(t.RENDERBUFFER,a),t.renderbufferStorage(t.RENDERBUFFER,n,e,r),t.framebufferRenderbuffer(t.FRAMEBUFFER,i,t.RENDERBUFFER,a),a}function d(t,e,r,n,i,a,o,s){this.gl=t,this._shape=[0|e,0|r],this._destroyed=!1,this._ext=s,this.color=new Array(i);for(var d=0;d<i;++d)this.color[d]=null;this._color_rb=null,this.depth=null,this._depth_rb=null,this._colorType=n,this._useDepth=a,this._useStencil=o;var g=this,v=[0|e,0|r];Object.defineProperties(v,{0:{get:function(){return g._shape[0]},set:function(t){return g.width=t}},1:{get:function(){return g._shape[1]},set:function(t){return g.height=t}}}),this._shapeVector=v,function(t){var e=c(t.gl),r=t.gl,n=t.handle=r.createFramebuffer(),i=t._shape[0],a=t._shape[1],o=t.color.length,s=t._ext,d=t._useStencil,g=t._useDepth,v=t._colorType;r.bindFramebuffer(r.FRAMEBUFFER,n);for(var m=0;m<o;++m)t.color[m]=f(r,i,a,v,r.RGBA,r.COLOR_ATTACHMENT0+m);0===o?(t._color_rb=p(r,i,a,r.RGBA4,r.COLOR_ATTACHMENT0),s&&s.drawBuffersWEBGL(l[0])):o>1&&s.drawBuffersWEBGL(l[o]);var y=r.getExtension(\"WEBGL_depth_texture\");y?d?t.depth=f(r,i,a,y.UNSIGNED_INT_24_8_WEBGL,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g&&(t.depth=f(r,i,a,r.UNSIGNED_SHORT,r.DEPTH_COMPONENT,r.DEPTH_ATTACHMENT)):g&&d?t._depth_rb=p(r,i,a,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g?t._depth_rb=p(r,i,a,r.DEPTH_COMPONENT16,r.DEPTH_ATTACHMENT):d&&(t._depth_rb=p(r,i,a,r.STENCIL_INDEX,r.STENCIL_ATTACHMENT));var x=r.checkFramebufferStatus(r.FRAMEBUFFER);if(x!==r.FRAMEBUFFER_COMPLETE){for(t._destroyed=!0,r.bindFramebuffer(r.FRAMEBUFFER,null),r.deleteFramebuffer(t.handle),t.handle=null,t.depth&&(t.depth.dispose(),t.depth=null),t._depth_rb&&(r.deleteRenderbuffer(t._depth_rb),t._depth_rb=null),m=0;m<t.color.length;++m)t.color[m].dispose(),t.color[m]=null;t._color_rb&&(r.deleteRenderbuffer(t._color_rb),t._color_rb=null),u(r,e),h(x)}u(r,e)}(this)}var g=d.prototype;function v(t,e,r){if(t._destroyed)throw new Error(\"gl-fbo: Can't resize destroyed FBO\");if(t._shape[0]!==e||t._shape[1]!==r){var n=t.gl,i=n.getParameter(n.MAX_RENDERBUFFER_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-fbo: Can't resize FBO, invalid dimensions\");t._shape[0]=e,t._shape[1]=r;for(var a=c(n),o=0;o<t.color.length;++o)t.color[o].shape=t._shape;t._color_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._color_rb),n.renderbufferStorage(n.RENDERBUFFER,n.RGBA4,t._shape[0],t._shape[1])),t.depth&&(t.depth.shape=t._shape),t._depth_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._depth_rb),t._useDepth&&t._useStencil?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_STENCIL,t._shape[0],t._shape[1]):t._useDepth?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_COMPONENT16,t._shape[0],t._shape[1]):t._useStencil&&n.renderbufferStorage(n.RENDERBUFFER,n.STENCIL_INDEX,t._shape[0],t._shape[1])),n.bindFramebuffer(n.FRAMEBUFFER,t.handle);var s=n.checkFramebufferStatus(n.FRAMEBUFFER);s!==n.FRAMEBUFFER_COMPLETE&&(t.dispose(),u(n,a),h(s)),u(n,a)}}Object.defineProperties(g,{shape:{get:function(){return this._destroyed?[0,0]:this._shapeVector},set:function(t){if(Array.isArray(t)||(t=[0|t,0|t]),2!==t.length)throw new Error(\"gl-fbo: Shape vector must be length 2\");var e=0|t[0],r=0|t[1];return v(this,e,r),[e,r]},enumerable:!1},width:{get:function(){return this._destroyed?0:this._shape[0]},set:function(t){return v(this,t|=0,this._shape[1]),t},enumerable:!1},height:{get:function(){return this._destroyed?0:this._shape[1]},set:function(t){return t|=0,v(this,this._shape[0],t),t},enumerable:!1}}),g.bind=function(){if(!this._destroyed){var t=this.gl;t.bindFramebuffer(t.FRAMEBUFFER,this.handle),t.viewport(0,0,this._shape[0],this._shape[1])}},g.dispose=function(){if(!this._destroyed){this._destroyed=!0;var t=this.gl;t.deleteFramebuffer(this.handle),this.handle=null,this.depth&&(this.depth.dispose(),this.depth=null),this._depth_rb&&(t.deleteRenderbuffer(this._depth_rb),this._depth_rb=null);for(var e=0;e<this.color.length;++e)this.color[e].dispose(),this.color[e]=null;this._color_rb&&(t.deleteRenderbuffer(this._color_rb),this._color_rb=null)}}},{\"gl-texture2d\":322}],250:[function(t,e,r){var n=t(\"sprintf-js\").sprintf,i=t(\"gl-constants/lookup\"),a=t(\"glsl-shader-name\"),o=t(\"add-line-numbers\");e.exports=function(t,e,r){\"use strict\";var s=a(e)||\"of unknown name (see npm glsl-shader-name)\",l=\"unknown type\";void 0!==r&&(l=r===i.FRAGMENT_SHADER?\"fragment\":\"vertex\");for(var c=n(\"Error compiling %s shader %s:\\n\",l,s),u=n(\"%s%s\",c,t),h=t.split(\"\\n\"),f={},p=0;p<h.length;p++){var d=h[p];if(\"\"!==d&&\"\\0\"!==d){var g=parseInt(d.split(\":\")[2]);if(isNaN(g))throw new Error(n(\"Could not parse error: %s\",d));f[g]=d}}for(var v=o(e).split(\"\\n\"),p=0;p<v.length;p++)if(f[p+3]||f[p+2]||f[p+1]){var m=v[p];if(c+=m+\"\\n\",f[p+1]){var y=f[p+1];y=y.substr(y.split(\":\",3).join(\":\").length+1).trim(),c+=n(\"^^^ %s\\n\\n\",y)}}return{long:c.trim(),short:u.trim()}}},{\"add-line-numbers\":61,\"gl-constants/lookup\":246,\"glsl-shader-name\":401,\"sprintf-js\":528}],251:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.gl,n=o(r,l.vertex,l.fragment),i=o(r,l.pickVertex,l.pickFragment),a=s(r),u=s(r),h=s(r),f=s(r),p=new c(t,n,i,a,u,h,f);return p.update(e),t.addObject(p),p};var n=t(\"binary-search-bounds\"),i=t(\"iota-array\"),a=t(\"typedarray-pool\"),o=t(\"gl-shader\"),s=t(\"gl-buffer\"),l=t(\"./lib/shaders\");function c(t,e,r,n,i,a,o){this.plot=t,this.shader=e,this.pickShader=r,this.positionBuffer=n,this.weightBuffer=i,this.colorBuffer=a,this.idBuffer=o,this.xData=[],this.yData=[],this.shape=[0,0],this.bounds=[1/0,1/0,-1/0,-1/0],this.pickOffset=0}var u,h=c.prototype,f=[0,0,1,0,0,1,1,0,1,1,0,1];h.draw=(u=[1,0,0,0,1,0,0,0,1],function(){var t=this.plot,e=this.shader,r=this.bounds,n=this.numVertices;if(!(n<=0)){var i=t.gl,a=t.dataBox,o=r[2]-r[0],s=r[3]-r[1],l=a[2]-a[0],c=a[3]-a[1];u[0]=2*o/l,u[4]=2*s/c,u[6]=2*(r[0]-a[0])/l-1,u[7]=2*(r[1]-a[1])/c-1,e.bind();var h=e.uniforms;h.viewTransform=u,h.shape=this.shape;var f=e.attributes;this.positionBuffer.bind(),f.position.pointer(),this.weightBuffer.bind(),f.weight.pointer(i.UNSIGNED_BYTE,!1),this.colorBuffer.bind(),f.color.pointer(i.UNSIGNED_BYTE,!0),i.drawArrays(i.TRIANGLES,0,n)}}),h.drawPick=function(){var t=[1,0,0,0,1,0,0,0,1],e=[0,0,0,0];return function(r){var n=this.plot,i=this.pickShader,a=this.bounds,o=this.numVertices;if(!(o<=0)){var s=n.gl,l=n.dataBox,c=a[2]-a[0],u=a[3]-a[1],h=l[2]-l[0],f=l[3]-l[1];t[0]=2*c/h,t[4]=2*u/f,t[6]=2*(a[0]-l[0])/h-1,t[7]=2*(a[1]-l[1])/f-1;for(var p=0;p<4;++p)e[p]=r>>8*p&255;this.pickOffset=r,i.bind();var d=i.uniforms;d.viewTransform=t,d.pickOffset=e,d.shape=this.shape;var g=i.attributes;return this.positionBuffer.bind(),g.position.pointer(),this.weightBuffer.bind(),g.weight.pointer(s.UNSIGNED_BYTE,!1),this.idBuffer.bind(),g.pickId.pointer(s.UNSIGNED_BYTE,!1),s.drawArrays(s.TRIANGLES,0,o),r+this.shape[0]*this.shape[1]}}}(),h.pick=function(t,e,r){var n=this.pickOffset,i=this.shape[0]*this.shape[1];if(r<n||r>=n+i)return null;var a=r-n,o=this.xData,s=this.yData;return{object:this,pointId:a,dataCoord:[o[a%this.shape[0]],s[a/this.shape[0]|0]]}},h.update=function(t){var e=(t=t||{}).shape||[0,0],r=t.x||i(e[0]),o=t.y||i(e[1]),s=t.z||new Float32Array(e[0]*e[1]);this.xData=r,this.yData=o;var l=t.colorLevels||[0],c=t.colorValues||[0,0,0,1],u=l.length,h=this.bounds,p=h[0]=r[0],d=h[1]=o[0],g=1/((h[2]=r[r.length-1])-p),v=1/((h[3]=o[o.length-1])-d),m=e[0],y=e[1];this.shape=[m,y];var x=(m-1)*(y-1)*(f.length>>>1);this.numVertices=x;for(var b=a.mallocUint8(4*x),_=a.mallocFloat32(2*x),w=a.mallocUint8(2*x),k=a.mallocUint32(x),T=0,A=0;A<y-1;++A)for(var M=v*(o[A]-d),S=v*(o[A+1]-d),E=0;E<m-1;++E)for(var C=g*(r[E]-p),L=g*(r[E+1]-p),P=0;P<f.length;P+=2){var O,z,I,D,R=f[P],F=f[P+1],B=s[(A+F)*m+(E+R)],N=n.le(l,B);if(N<0)O=c[0],z=c[1],I=c[2],D=c[3];else if(N===u-1)O=c[4*u-4],z=c[4*u-3],I=c[4*u-2],D=c[4*u-1];else{var j=(B-l[N])/(l[N+1]-l[N]),U=1-j,V=4*N,q=4*(N+1);O=U*c[V]+j*c[q],z=U*c[V+1]+j*c[q+1],I=U*c[V+2]+j*c[q+2],D=U*c[V+3]+j*c[q+3]}b[4*T]=255*O,b[4*T+1]=255*z,b[4*T+2]=255*I,b[4*T+3]=255*D,_[2*T]=.5*C+.5*L,_[2*T+1]=.5*M+.5*S,w[2*T]=R,w[2*T+1]=F,k[T]=A*m+E,T+=1}this.positionBuffer.update(_),this.weightBuffer.update(w),this.colorBuffer.update(b),this.idBuffer.update(k),a.free(_),a.free(b),a.free(w),a.free(k)},h.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.positionBuffer.dispose(),this.weightBuffer.dispose(),this.colorBuffer.dispose(),this.idBuffer.dispose(),this.plot.removeObject(this)}},{\"./lib/shaders\":252,\"binary-search-bounds\":253,\"gl-buffer\":241,\"gl-shader\":301,\"iota-array\":416,\"typedarray-pool\":545}],252:[function(t,e,r){\"use strict\";var n=t(\"glslify\");e.exports={fragment:n([\"precision lowp float;\\n#define GLSLIFY 1\\nvarying vec4 fragColor;\\nvoid main() {\\n  gl_FragColor = vec4(fragColor.rgb * fragColor.a, fragColor.a);\\n}\\n\"]),vertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 color;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  fragColor = color;\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"]),pickFragment:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nuniform vec2 shape;\\nuniform vec4 pickOffset;\\n\\nvoid main() {\\n  vec2 d = step(.5, vWeight);\\n  vec4 id = fragId + pickOffset;\\n  id.x += d.x + d.y*shape.x;\\n\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  gl_FragColor = id/255.;\\n}\\n\"]),pickVertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nvoid main() {\\n  vWeight = weight;\\n\\n  fragId = pickId;\\n\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"])}},{glslify:409}],253:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],254:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, nextPosition;\\nattribute float arcLength, lineWidth;\\nattribute vec4 color;\\n\\nuniform vec2 screenShape;\\nuniform float pixelRatio;\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 fragColor;\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  vec4 startPoint = project(position);\\n  vec4 endPoint   = project(nextPosition);\\n\\n  vec2 A = startPoint.xy / startPoint.w;\\n  vec2 B =   endPoint.xy /   endPoint.w;\\n\\n  float clipAngle = atan(\\n    (B.y - A.y) * screenShape.y,\\n    (B.x - A.x) * screenShape.x\\n  );\\n\\n  vec2 offset = 0.5 * pixelRatio * lineWidth * vec2(\\n    sin(clipAngle),\\n    -cos(clipAngle)\\n  ) / screenShape;\\n\\n  gl_Position = vec4(startPoint.xy + startPoint.w * offset, startPoint.zw);\\n\\n  worldPosition = position;\\n  pixelArcLength = arcLength;\\n  fragColor = color;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3      clipBounds[2];\\nuniform sampler2D dashTexture;\\nuniform float     dashScale;\\nuniform float     opacity;\\n\\nvarying vec3    worldPosition;\\nvarying float   pixelArcLength;\\nvarying vec4    fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], worldPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  float dashWeight = texture2D(dashTexture, vec2(dashScale * pixelArcLength, 0)).r;\\n  if(dashWeight < 0.5) {\\n    discard;\\n  }\\n  gl_FragColor = fragColor * opacity;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\n#define FLOAT_MAX  1.70141184e38\\n#define FLOAT_MIN  1.17549435e-38\\n\\nlowp vec4 encode_float_1540259130(highp float v) {\\n  highp float av = abs(v);\\n\\n  //Handle special cases\\n  if(av < FLOAT_MIN) {\\n    return vec4(0.0, 0.0, 0.0, 0.0);\\n  } else if(v > FLOAT_MAX) {\\n    return vec4(127.0, 128.0, 0.0, 0.0) / 255.0;\\n  } else if(v < -FLOAT_MAX) {\\n    return vec4(255.0, 128.0, 0.0, 0.0) / 255.0;\\n  }\\n\\n  highp vec4 c = vec4(0,0,0,0);\\n\\n  //Compute exponent and mantissa\\n  highp float e = floor(log2(av));\\n  highp float m = av * pow(2.0, -e) - 1.0;\\n  \\n  //Unpack mantissa\\n  c[1] = floor(128.0 * m);\\n  m -= c[1] / 128.0;\\n  c[2] = floor(32768.0 * m);\\n  m -= c[2] / 32768.0;\\n  c[3] = floor(8388608.0 * m);\\n  \\n  //Unpack exponent\\n  highp float ebias = e + 127.0;\\n  c[0] = floor(ebias / 2.0);\\n  ebias -= c[0] * 2.0;\\n  c[1] += floor(ebias) * 128.0; \\n\\n  //Unpack sign bit\\n  c[0] += 128.0 * step(0.0, -v);\\n\\n  //Scale back to range\\n  return c / 255.0;\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform float pickId;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], worldPosition)) discard;\\n\\n  gl_FragColor = vec4(pickId/255.0, encode_float_1540259130(pixelArcLength).xyz);\\n}\"]),l=[{name:\"position\",type:\"vec3\"},{name:\"nextPosition\",type:\"vec3\"},{name:\"arcLength\",type:\"float\"},{name:\"lineWidth\",type:\"float\"},{name:\"color\",type:\"vec4\"}];r.createShader=function(t){return i(t,a,o,null,l)},r.createPickShader=function(t){return i(t,a,s,null,l)}},{\"gl-shader\":301,glslify:409}],255:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl||t.scene&&t.scene.gl,r=u(e);r.attributes.position.location=0,r.attributes.nextPosition.location=1,r.attributes.arcLength.location=2,r.attributes.lineWidth.location=3,r.attributes.color.location=4;var o=h(e);o.attributes.position.location=0,o.attributes.nextPosition.location=1,o.attributes.arcLength.location=2,o.attributes.lineWidth.location=3,o.attributes.color.location=4;for(var s=n(e),c=i(e,[{buffer:s,size:3,offset:0,stride:48},{buffer:s,size:3,offset:12,stride:48},{buffer:s,size:1,offset:24,stride:48},{buffer:s,size:1,offset:28,stride:48},{buffer:s,size:4,offset:32,stride:48}]),f=l(new Array(1024),[256,1,4]),p=0;p<1024;++p)f.data[p]=255;var d=a(e,f);d.wrap=e.REPEAT;var g=new v(e,r,o,s,c,d);return g.update(t),g};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"gl-texture2d\"),o=t(\"glsl-read-float\"),s=t(\"binary-search-bounds\"),l=t(\"ndarray\"),c=t(\"./lib/shaders\"),u=c.createShader,h=c.createPickShader,f=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function p(t,e){for(var r=0,n=0;n<3;++n){var i=t[n]-e[n];r+=i*i}return Math.sqrt(r)}function d(t){for(var e=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],r=0;r<3;++r)e[0][r]=Math.max(t[0][r],e[0][r]),e[1][r]=Math.min(t[1][r],e[1][r]);return e}function g(t,e,r,n){this.arcLength=t,this.position=e,this.index=r,this.dataCoordinate=n}function v(t,e,r,n,i,a){this.gl=t,this.shader=e,this.pickShader=r,this.buffer=n,this.vao=i,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.points=[],this.arcLength=[],this.vertexCount=0,this.bounds=[[0,0,0],[0,0,0]],this.pickId=0,this.lineWidth=1,this.texture=a,this.dashScale=1,this.opacity=1,this.hasAlpha=!1,this.dirty=!0,this.pixelRatio=1}var m=v.prototype;m.isTransparent=function(){return this.hasAlpha},m.isOpaque=function(){return!this.hasAlpha},m.pickSlots=1,m.setPickBase=function(t){this.pickId=t},m.drawTransparent=m.draw=function(t){if(this.vertexCount){var e=this.gl,r=this.shader,n=this.vao;r.bind(),r.uniforms={model:t.model||f,view:t.view||f,projection:t.projection||f,clipBounds:d(this.clipBounds),dashTexture:this.texture.bind(),dashScale:this.dashScale/this.arcLength[this.arcLength.length-1],opacity:this.opacity,screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},m.drawPick=function(t){if(this.vertexCount){var e=this.gl,r=this.pickShader,n=this.vao;r.bind(),r.uniforms={model:t.model||f,view:t.view||f,projection:t.projection||f,pickId:this.pickId,clipBounds:d(this.clipBounds),screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},m.update=function(t){var e,r;this.dirty=!0;var n=!!t.connectGaps;\"dashScale\"in t&&(this.dashScale=t.dashScale),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var i=[],a=[],o=[],c=0,u=0,h=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],f=t.position||t.positions;if(f){var d=t.color||t.colors||[0,0,0,1],g=t.lineWidth||1,v=!1;t:for(e=1;e<f.length;++e){var m,y,x,b=f[e-1],_=f[e];for(a.push(c),o.push(b.slice()),r=0;r<3;++r){if(isNaN(b[r])||isNaN(_[r])||!isFinite(b[r])||!isFinite(_[r])){if(!n&&i.length>0){for(var w=0;w<24;++w)i.push(i[i.length-12]);u+=2,v=!0}continue t}h[0][r]=Math.min(h[0][r],b[r],_[r]),h[1][r]=Math.max(h[1][r],b[r],_[r])}Array.isArray(d[0])?(m=d.length>e-1?d[e-1]:d.length>0?d[d.length-1]:[0,0,0,1],y=d.length>e?d[e]:d.length>0?d[d.length-1]:[0,0,0,1]):m=y=d,3===m.length&&(m=[m[0],m[1],m[2],1]),3===y.length&&(y=[y[0],y[1],y[2],1]),!this.hasAlpha&&m[3]<1&&(this.hasAlpha=!0),x=Array.isArray(g)?g.length>e-1?g[e-1]:g.length>0?g[g.length-1]:[0,0,0,1]:g;var k=c;if(c+=p(b,_),v){for(r=0;r<2;++r)i.push(b[0],b[1],b[2],_[0],_[1],_[2],k,x,m[0],m[1],m[2],m[3]);u+=2,v=!1}i.push(b[0],b[1],b[2],_[0],_[1],_[2],k,x,m[0],m[1],m[2],m[3],b[0],b[1],b[2],_[0],_[1],_[2],k,-x,m[0],m[1],m[2],m[3],_[0],_[1],_[2],b[0],b[1],b[2],c,-x,y[0],y[1],y[2],y[3],_[0],_[1],_[2],b[0],b[1],b[2],c,x,y[0],y[1],y[2],y[3]),u+=4}}if(this.buffer.update(i),a.push(c),o.push(f[f.length-1].slice()),this.bounds=h,this.vertexCount=u,this.points=o,this.arcLength=a,\"dashes\"in t){var T=t.dashes.slice();for(T.unshift(0),e=1;e<T.length;++e)T[e]=T[e-1]+T[e];var A=l(new Array(1024),[256,1,4]);for(e=0;e<256;++e){for(r=0;r<4;++r)A.set(e,0,r,0);1&s.le(T,T[T.length-1]*e/255)?A.set(e,0,0,0):A.set(e,0,0,255)}this.texture.setPixels(A)}},m.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()},m.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=o(t.value[0],t.value[1],t.value[2],0),r=s.le(this.arcLength,e);if(r<0)return null;if(r===this.arcLength.length-1)return new g(this.arcLength[this.arcLength.length-1],this.points[this.points.length-1].slice(),r);for(var n=this.points[r],i=this.points[Math.min(r+1,this.points.length-1)],a=(e-this.arcLength[r])/(this.arcLength[r+1]-this.arcLength[r]),l=1-a,c=[0,0,0],u=0;u<3;++u)c[u]=l*n[u]+a*i[u];var h=Math.min(a<.5?r:r+1,this.points.length-1);return new g(e,c,h,this.points[h])}},{\"./lib/shaders\":254,\"binary-search-bounds\":256,\"gl-buffer\":241,\"gl-texture2d\":322,\"gl-vao\":327,\"glsl-read-float\":400,ndarray:450}],256:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],257:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r*a-i*n;return o?(o=1/o,t[0]=a*o,t[1]=-n*o,t[2]=-i*o,t[3]=r*o,t):null}},{}],258:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=u*o-s*c,f=-u*a+s*l,p=c*a-o*l,d=r*h+n*f+i*p;return d?(d=1/d,t[0]=h*d,t[1]=(-u*n+i*c)*d,t[2]=(s*n-i*o)*d,t[3]=f*d,t[4]=(u*r-i*l)*d,t[5]=(-s*r+i*a)*d,t[6]=p*d,t[7]=(-c*r+n*l)*d,t[8]=(o*r-n*a)*d,t):null}},{}],259:[function(t,e,r){e.exports=function(t){var e=new Float32Array(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e}},{}],260:[function(t,e,r){e.exports=function(){var t=new Float32Array(16);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],261:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3],a=t[4],o=t[5],s=t[6],l=t[7],c=t[8],u=t[9],h=t[10],f=t[11],p=t[12],d=t[13],g=t[14],v=t[15];return(e*o-r*a)*(h*v-f*g)-(e*s-n*a)*(u*v-f*d)+(e*l-i*a)*(u*g-h*d)+(r*s-n*o)*(c*v-f*p)-(r*l-i*o)*(c*g-h*p)+(n*l-i*s)*(c*d-u*p)}},{}],262:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r+r,s=n+n,l=i+i,c=r*o,u=n*o,h=n*s,f=i*o,p=i*s,d=i*l,g=a*o,v=a*s,m=a*l;return t[0]=1-h-d,t[1]=u+m,t[2]=f-v,t[3]=0,t[4]=u-m,t[5]=1-c-d,t[6]=p+g,t[7]=0,t[8]=f+v,t[9]=p-g,t[10]=1-c-h,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],263:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=n+n,l=i+i,c=a+a,u=n*s,h=n*l,f=n*c,p=i*l,d=i*c,g=a*c,v=o*s,m=o*l,y=o*c;return t[0]=1-(p+g),t[1]=h+y,t[2]=f-m,t[3]=0,t[4]=h-y,t[5]=1-(u+g),t[6]=d+v,t[7]=0,t[8]=f+m,t[9]=d-v,t[10]=1-(u+p),t[11]=0,t[12]=r[0],t[13]=r[1],t[14]=r[2],t[15]=1,t}},{}],264:[function(t,e,r){e.exports=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],265:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],g=e[13],v=e[14],m=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,k=i*c-a*l,T=u*g-h*d,A=u*v-f*d,M=u*m-p*d,S=h*v-f*g,E=h*m-p*g,C=f*m-p*v,L=y*C-x*E+b*S+_*M-w*A+k*T;if(!L)return null;return L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(i*E-n*C-a*S)*L,t[2]=(g*k-v*w+m*_)*L,t[3]=(f*w-h*k-p*_)*L,t[4]=(l*M-o*C-c*A)*L,t[5]=(r*C-i*M+a*A)*L,t[6]=(v*b-d*k-m*x)*L,t[7]=(u*k-f*b+p*x)*L,t[8]=(o*E-s*M+c*T)*L,t[9]=(n*M-r*E-a*T)*L,t[10]=(d*w-g*b+m*y)*L,t[11]=(h*b-u*w-p*y)*L,t[12]=(s*A-o*S-l*T)*L,t[13]=(r*S-n*A+i*T)*L,t[14]=(g*x-d*_-v*y)*L,t[15]=(u*_-h*x+f*y)*L,t}},{}],266:[function(t,e,r){var n=t(\"./identity\");e.exports=function(t,e,r,i){var a,o,s,l,c,u,h,f,p,d,g=e[0],v=e[1],m=e[2],y=i[0],x=i[1],b=i[2],_=r[0],w=r[1],k=r[2];if(Math.abs(g-_)<1e-6&&Math.abs(v-w)<1e-6&&Math.abs(m-k)<1e-6)return n(t);h=g-_,f=v-w,p=m-k,d=1/Math.sqrt(h*h+f*f+p*p),a=x*(p*=d)-b*(f*=d),o=b*(h*=d)-y*p,s=y*f-x*h,(d=Math.sqrt(a*a+o*o+s*s))?(a*=d=1/d,o*=d,s*=d):(a=0,o=0,s=0);l=f*s-p*o,c=p*a-h*s,u=h*o-f*a,(d=Math.sqrt(l*l+c*c+u*u))?(l*=d=1/d,c*=d,u*=d):(l=0,c=0,u=0);return t[0]=a,t[1]=l,t[2]=h,t[3]=0,t[4]=o,t[5]=c,t[6]=f,t[7]=0,t[8]=s,t[9]=u,t[10]=p,t[11]=0,t[12]=-(a*g+o*v+s*m),t[13]=-(l*g+c*v+u*m),t[14]=-(h*g+f*v+p*m),t[15]=1,t}},{\"./identity\":264}],267:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],g=e[12],v=e[13],m=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*h+w*g,t[1]=x*i+b*l+_*f+w*v,t[2]=x*a+b*c+_*p+w*m,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*h+w*g,t[5]=x*i+b*l+_*f+w*v,t[6]=x*a+b*c+_*p+w*m,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*h+w*g,t[9]=x*i+b*l+_*f+w*v,t[10]=x*a+b*c+_*p+w*m,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*h+w*g,t[13]=x*i+b*l+_*f+w*v,t[14]=x*a+b*c+_*p+w*m,t[15]=x*o+b*u+_*d+w*y,t}},{}],268:[function(t,e,r){e.exports=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t}},{}],269:[function(t,e,r){e.exports=function(t,e,r,n,i){var a=1/Math.tan(e/2),o=1/(n-i);return t[0]=a/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=a,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=(i+n)*o,t[11]=-1,t[12]=0,t[13]=0,t[14]=2*i*n*o,t[15]=0,t}},{}],270:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_,w,k,T,A,M,S,E=n[0],C=n[1],L=n[2],P=Math.sqrt(E*E+C*C+L*L);if(Math.abs(P)<1e-6)return null;E*=P=1/P,C*=P,L*=P,i=Math.sin(r),a=Math.cos(r),o=1-a,s=e[0],l=e[1],c=e[2],u=e[3],h=e[4],f=e[5],p=e[6],d=e[7],g=e[8],v=e[9],m=e[10],y=e[11],x=E*E*o+a,b=C*E*o+L*i,_=L*E*o-C*i,w=E*C*o-L*i,k=C*C*o+a,T=L*C*o+E*i,A=E*L*o+C*i,M=C*L*o-E*i,S=L*L*o+a,t[0]=s*x+h*b+g*_,t[1]=l*x+f*b+v*_,t[2]=c*x+p*b+m*_,t[3]=u*x+d*b+y*_,t[4]=s*w+h*k+g*T,t[5]=l*w+f*k+v*T,t[6]=c*w+p*k+m*T,t[7]=u*w+d*k+y*T,t[8]=s*A+h*M+g*S,t[9]=l*A+f*M+v*S,t[10]=c*A+p*M+m*S,t[11]=u*A+d*M+y*S,e!==t&&(t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t}},{}],271:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+h*n,t[7]=l*i+f*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=h*i-s*n,t[11]=f*i-l*n,t}},{}],272:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[8],u=e[9],h=e[10],f=e[11];e!==t&&(t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i-c*n,t[1]=o*i-u*n,t[2]=s*i-h*n,t[3]=l*i-f*n,t[8]=a*n+c*i,t[9]=o*n+u*i,t[10]=s*n+h*i,t[11]=l*n+f*i,t}},{}],273:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+h*n,t[3]=l*i+f*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=h*i-s*n,t[7]=f*i-l*n,t}},{}],274:[function(t,e,r){e.exports=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},{}],275:[function(t,e,r){e.exports=function(t,e,r){var n,i,a,o,s,l,c,u,h,f,p,d,g=r[0],v=r[1],m=r[2];e===t?(t[12]=e[0]*g+e[4]*v+e[8]*m+e[12],t[13]=e[1]*g+e[5]*v+e[9]*m+e[13],t[14]=e[2]*g+e[6]*v+e[10]*m+e[14],t[15]=e[3]*g+e[7]*v+e[11]*m+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*g+s*v+h*m+e[12],t[13]=i*g+l*v+f*m+e[13],t[14]=a*g+c*v+p*m+e[14],t[15]=o*g+u*v+d*m+e[15]);return t}},{}],276:[function(t,e,r){e.exports=function(t,e){if(t===e){var r=e[1],n=e[2],i=e[3],a=e[6],o=e[7],s=e[11];t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=r,t[6]=e[9],t[7]=e[13],t[8]=n,t[9]=a,t[11]=e[14],t[12]=i,t[13]=o,t[14]=s}else t[0]=e[0],t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=e[1],t[5]=e[5],t[6]=e[9],t[7]=e[13],t[8]=e[2],t[9]=e[6],t[10]=e[10],t[11]=e[14],t[12]=e[3],t[13]=e[7],t[14]=e[11],t[15]=e[15];return t}},{}],277:[function(t,e,r){\"use strict\";e.exports=function(t,e){switch(e.length){case 0:break;case 1:t[0]=1/e[0];break;case 4:n(t,e);break;case 9:i(t,e);break;case 16:a(t,e);break;default:throw new Error(\"currently supports matrices up to 4x4\")}return t};var n=t(\"gl-mat2/invert\"),i=t(\"gl-mat3/invert\"),a=t(\"gl-mat4/invert\")},{\"gl-mat2/invert\":257,\"gl-mat3/invert\":258,\"gl-mat4/invert\":265}],278:[function(t,e,r){\"use strict\";var n=t(\"barycentric\"),i=t(\"polytope-closest-point/lib/closest_point_2d.js\");function a(t,e){for(var r=[0,0,0,0],n=0;n<4;++n)for(var i=0;i<4;++i)r[i]+=t[4*n+i]*e[n];return r}function o(t,e,r,n,i){for(var o=a(n,a(r,a(e,[t[0],t[1],t[2],1]))),s=0;s<3;++s)o[s]/=o[3];return[.5*i[0]*(1+o[0]),.5*i[1]*(1-o[1])]}e.exports=function(t,e,r,a,s,l){if(1===t.length)return[0,t[0].slice()];for(var c=new Array(t.length),u=0;u<t.length;++u)c[u]=o(t[u],r,a,s,l);for(var h=0,f=1/0,u=0;u<c.length;++u){for(var p=0,d=0;d<2;++d)p+=Math.pow(c[u][d]-e[d],2);p<f&&(f=p,h=u)}for(var g=function(t,e){if(2===t.length){for(var r=0,a=0,o=0;o<2;++o)r+=Math.pow(e[o]-t[0][o],2),a+=Math.pow(e[o]-t[1][o],2);return r=Math.sqrt(r),a=Math.sqrt(a),r+a<1e-6?[1,0]:[a/(r+a),r/(a+r)]}if(3===t.length){var s=[0,0];return i(t[0],t[1],t[2],e,s),n(t,s)}return[]}(c,e),v=0,u=0;u<3;++u){if(g[u]<-.001||g[u]>1.0001)return null;v+=g[u]}if(Math.abs(v-1)>.001)return null;return[h,function(t,e){for(var r=[0,0,0],n=0;n<t.length;++n)for(var i=t[n],a=e[n],o=0;o<3;++o)r[o]+=a*i[o];return r}(t,g),g]}},{barycentric:73,\"polytope-closest-point/lib/closest_point_2d.js\":481}],279:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, normal;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  gl_Position      = project(position);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * vec4(position , 1.0);\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal  = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  f_color          = color;\\n  f_data           = position;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\n//#pragma glslify: beckmann = require(glsl-specular-beckmann) // used in gl-surface3d\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (f_color.a == 0.0 ||\\n    outOfRange(clipBounds[0], clipBounds[1], f_data)\\n  ) discard;\\n\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  //float specular = max(0.0, beckmann(L, V, N, roughness)); // used in gl-surface3d\\n\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = vec4(f_color.rgb, 1.0) * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * f_color.a;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_color = color;\\n  f_data  = position;\\n  f_uv    = uv;\\n}\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_data)) discard;\\n\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\nattribute float pointSize;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0 ,0.0 ,0.0);\\n  } else {\\n    gl_Position = projection * view * model * vec4(position, 1.0);\\n  }\\n  gl_PointSize = pointSize;\\n  f_color = color;\\n  f_uv = uv;\\n}\"]),c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  vec2 pointR = gl_PointCoord.xy - vec2(0.5, 0.5);\\n  if(dot(pointR, pointR) > 0.25) {\\n    discard;\\n  }\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_id        = id;\\n  f_position  = position;\\n}\"]),h=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]),f=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3  position;\\nattribute float pointSize;\\nattribute vec4  id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0, 0.0, 0.0);\\n  } else {\\n    gl_Position  = projection * view * model * vec4(position, 1.0);\\n    gl_PointSize = pointSize;\\n  }\\n  f_id         = id;\\n  f_position   = position;\\n}\"]),p=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n}\"]),d=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec3 contourColor;\\n\\nvoid main() {\\n  gl_FragColor = vec4(contourColor, 1.0);\\n}\\n\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.wireShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.pointShader={vertex:l,fragment:c,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"pointSize\",type:\"float\"}]},r.pickShader={vertex:u,fragment:h,attributes:[{name:\"position\",type:\"vec3\"},{name:\"id\",type:\"vec4\"}]},r.pointPickShader={vertex:f,fragment:h,attributes:[{name:\"position\",type:\"vec3\"},{name:\"pointSize\",type:\"float\"},{name:\"id\",type:\"vec4\"}]},r.contourShader={vertex:p,fragment:d,attributes:[{name:\"position\",type:\"vec3\"}]}},{glslify:409}],280:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./lib/shaders\"),g=t(\"./lib/closest-point\"),v=d.meshShader,m=d.wireShader,y=d.pointShader,x=d.pickShader,b=d.pointPickShader,_=d.contourShader,w=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function k(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_,k,T,A,M,S){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.lineShader=n,this.pointShader=i,this.pickShader=a,this.pointPickShader=o,this.contourShader=s,this.trianglePositions=l,this.triangleColors=u,this.triangleNormals=f,this.triangleUVs=h,this.triangleIds=c,this.triangleVAO=p,this.triangleCount=0,this.lineWidth=1,this.edgePositions=d,this.edgeColors=v,this.edgeUVs=m,this.edgeIds=g,this.edgeVAO=y,this.edgeCount=0,this.pointPositions=x,this.pointColors=_,this.pointUVs=k,this.pointSizes=T,this.pointIds=b,this.pointVAO=A,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=M,this.contourVAO=S,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.hasAlpha=!1,this.opacityscale=!1,this._model=w,this._view=w,this._projection=w,this._resolution=[1,1]}var T=k.prototype;function A(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}function M(t){var e=n(t,y.vertex,y.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.pointSize.location=4,e}function S(t){var e=n(t,x.vertex,x.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e}function E(t){var e=n(t,b.vertex,b.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.pointSize.location=4,e}function C(t){var e=n(t,_.vertex,_.fragment);return e.attributes.position.location=0,e}T.isOpaque=function(){return!this.hasAlpha},T.isTransparent=function(){return this.hasAlpha},T.pickSlots=1,T.setPickBase=function(t){this.pickId=t},T.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=i[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},T.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=t.opacity,this.opacity<1&&(this.hasAlpha=!0)),\"opacityscale\"in t&&(this.opacityscale=t.opacityscale,this.hasAlpha=!0),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t,e){for(var r=h({colormap:t,nshades:256,format:\"rgba\"}),n=new Uint8Array(1024),i=0;i<256;++i){for(var a=r[i],o=0;o<3;++o)n[4*i+o]=a[o];n[4*i+3]=e?255*A(i/255,e):255*a[3]}return u(n,[256,256,4],[4,0,1])}(t.colormap,this.opacityscale)),this.texture.generateMipmap());var r=t.cells,n=t.positions;if(n&&r){var i=[],a=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[];this.cells=r,this.positions=n;var w=t.vertexNormals,k=t.cellNormals,T=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,M=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!k&&(k=s.faceNormals(r,n,M)),k||w||(w=s.vertexNormals(r,n,T));var S=t.vertexColors,E=t.cellColors,C=t.meshColor||[1,1,1,1],L=t.vertexUVs,P=t.vertexIntensity,O=t.cellUVs,z=t.cellIntensity,I=1/0,D=-1/0;if(!L&&!O)if(P)if(t.vertexIntensityBounds)I=+t.vertexIntensityBounds[0],D=+t.vertexIntensityBounds[1];else for(var R=0;R<P.length;++R){var F=P[R];I=Math.min(I,F),D=Math.max(D,F)}else if(z)for(R=0;R<z.length;++R){F=z[R];I=Math.min(I,F),D=Math.max(D,F)}else for(R=0;R<n.length;++R){F=n[R][2];I=Math.min(I,F),D=Math.max(D,F)}this.intensity=P||(z?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,z):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var B=t.pointSizes,N=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(R=0;R<n.length;++R)for(var j=n[R],U=0;U<3;++U)!isNaN(j[U])&&isFinite(j[U])&&(this.bounds[0][U]=Math.min(this.bounds[0][U],j[U]),this.bounds[1][U]=Math.max(this.bounds[1][U],j[U]));var V=0,q=0,H=0;t:for(R=0;R<r.length;++R){var G=r[R];switch(G.length){case 1:for(j=n[W=G[0]],U=0;U<3;++U)if(isNaN(j[U])||!isFinite(j[U]))continue t;m.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?y.push(X[0],X[1],X[2],this.opacity):(y.push(X[0],X[1],X[2],X[3]*this.opacity),!this.hasAlpha&&X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],x.push(Z[0],Z[1]),B?b.push(B[W]):b.push(N),_.push(R),H+=1;break;case 2:for(U=0;U<2;++U){j=n[W=G[U]];for(var Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t}for(U=0;U<2;++U){j=n[W=G[U]];p.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?d.push(X[0],X[1],X[2],this.opacity):(d.push(X[0],X[1],X[2],X[3]*this.opacity),!this.hasAlpha&&X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],g.push(Z[0],Z[1]),v.push(R)}q+=1;break;case 3:for(U=0;U<3;++U)for(j=n[W=G[U]],Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t;for(U=0;U<3;++U){var W,X,Z,J;j=n[W=G[2-U]];i.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?a.push(X[0],X[1],X[2],this.opacity):(a.push(X[0],X[1],X[2],X[3]*this.opacity),!this.hasAlpha&&X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],c.push(Z[0],Z[1]),J=w?w[W]:k[R],l.push(J[0],J[1],J[2]),f.push(R)}V+=1}}this.pointCount=H,this.edgeCount=q,this.triangleCount=V,this.pointPositions.update(m),this.pointColors.update(y),this.pointUVs.update(x),this.pointSizes.update(b),this.pointIds.update(new Uint32Array(_)),this.edgePositions.update(p),this.edgeColors.update(d),this.edgeUVs.update(g),this.edgeIds.update(new Uint32Array(v)),this.trianglePositions.update(i),this.triangleColors.update(a),this.triangleUVs.update(c),this.triangleNormals.update(l),this.triangleIds.update(new Uint32Array(f))}},T.drawTransparent=T.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:w.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h,f=u[15];for(o=0;o<3;++o)f+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];s.lightPosition[o]=p/f}this.triangleCount>0&&((h=this.triShader).bind(),h.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind());this.edgeCount>0&&this.lineWidth>0&&((h=this.lineShader).bind(),h.uniforms=s,this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind());this.pointCount>0&&((h=this.pointShader).bind(),h.uniforms=s,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind());this.contourEnable&&this.contourCount>0&&this.contourLineWidth>0&&((h=this.contourShader).bind(),h.uniforms=s,this.contourVAO.bind(),e.drawArrays(e.LINES,0,this.contourCount),this.contourVAO.unbind())},T.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s,l={model:r,view:n,projection:i,clipBounds:a,pickId:this.pickId/255};((s=this.pickShader).bind(),s.uniforms=l,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind()),this.pointCount>0)&&((s=this.pointPickShader).bind(),s.uniforms=l,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind())},T.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;for(var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions,i=new Array(r.length),a=0;a<r.length;++a)i[a]=n[r[a]];var o=g(i,[t.coord[0],this._resolution[1]-t.coord[1]],this._model,this._view,this._projection,this._resolution);if(!o)return null;var s=o[2],l=0;for(a=0;a<r.length;++a)l+=s[a]*this.intensity[r[a]];return{position:o[1],index:r[o[0]],cell:r,cellId:e,intensity:l,dataCoordinate:this.positions[r[o[0]]]}},T.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.lineShader.dispose(),this.pointShader.dispose(),this.pickShader.dispose(),this.pointPickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose(),this.contourShader.dispose()},e.exports=function(t,e){if(1===arguments.length&&(t=(e=t).gl),!(t.getExtension(\"OES_standard_derivatives\")||t.getExtension(\"MOZ_OES_standard_derivatives\")||t.getExtension(\"WEBKIT_OES_standard_derivatives\")))throw new Error(\"derivatives not supported\");var r=function(t){var e=n(t,v.vertex,v.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.normal.location=4,e}(t),s=function(t){var e=n(t,m.vertex,m.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e}(t),l=M(t),c=S(t),h=E(t),f=C(t),p=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));p.generateMipmap(),p.minFilter=t.LINEAR_MIPMAP_LINEAR,p.magFilter=t.LINEAR;var d=i(t),g=i(t),y=i(t),x=i(t),b=i(t),_=a(t,[{buffer:d,type:t.FLOAT,size:3},{buffer:b,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:g,type:t.FLOAT,size:4},{buffer:y,type:t.FLOAT,size:2},{buffer:x,type:t.FLOAT,size:3}]),w=i(t),T=i(t),A=i(t),L=i(t),P=a(t,[{buffer:w,type:t.FLOAT,size:3},{buffer:L,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:T,type:t.FLOAT,size:4},{buffer:A,type:t.FLOAT,size:2}]),O=i(t),z=i(t),I=i(t),D=i(t),R=i(t),F=a(t,[{buffer:O,type:t.FLOAT,size:3},{buffer:R,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:z,type:t.FLOAT,size:4},{buffer:I,type:t.FLOAT,size:2},{buffer:D,type:t.FLOAT,size:1}]),B=i(t),N=new k(t,p,r,s,l,c,h,f,d,b,g,y,x,_,w,L,T,A,P,O,R,z,I,D,F,B,a(t,[{buffer:B,type:t.FLOAT,size:3}]));return N.update(e),N}},{\"./lib/closest-point\":278,\"./lib/shaders\":279,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-shader\":301,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,normals:453,\"simplicial-complex-contour\":518,\"typedarray-pool\":545}],281:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[0,0,0,1,1,0,1,1]),s=i(e,a.boxVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawBox=(s=[0,0],l=[0,0],function(t,e,r,n,i){var a=this.plot,o=this.shader,c=a.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,o.uniforms.lo=s,o.uniforms.hi=l,o.uniforms.color=i,c.drawArrays(c.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":284,\"gl-buffer\":241,\"gl-shader\":301}],282:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,o.gridVert,o.gridFrag),l=i(e,o.tickVert,o.gridFrag);return new s(t,r,a,l)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"binary-search-bounds\"),o=t(\"./shaders\");function s(t,e,r,n){this.plot=t,this.vbo=e,this.shader=r,this.tickShader=n,this.ticks=[[],[]]}function l(t,e){return t-e}var c,u,h,f,p,d=s.prototype;d.draw=(c=[0,0],u=[0,0],h=[0,0],function(){for(var t=this.plot,e=this.vbo,r=this.shader,n=this.ticks,i=t.gl,a=t._tickBounds,o=t.dataBox,s=t.viewBox,l=t.gridLineWidth,f=t.gridLineColor,p=t.gridLineEnable,d=t.pixelRatio,g=0;g<2;++g){var v=a[g],m=a[g+2]-v,y=.5*(o[g+2]+o[g]),x=o[g+2]-o[g];u[g]=2*m/x,c[g]=2*(v-y)/x}r.bind(),e.bind(),r.attributes.dataCoord.pointer(),r.uniforms.dataShift=c,r.uniforms.dataScale=u;var b=0;for(g=0;g<2;++g){h[0]=h[1]=0,h[g]=1,r.uniforms.dataAxis=h,r.uniforms.lineWidth=l[g]/(s[g+2]-s[g])*d,r.uniforms.color=f[g];var _=6*n[g].length;p[g]&&_&&i.drawArrays(i.TRIANGLES,b,_),b+=_}}),d.drawTickMarks=function(){var t=[0,0],e=[0,0],r=[1,0],n=[0,1],i=[0,0],o=[0,0];return function(){for(var s=this.plot,c=this.vbo,u=this.tickShader,h=this.ticks,f=s.gl,p=s._tickBounds,d=s.dataBox,g=s.viewBox,v=s.pixelRatio,m=s.screenBox,y=m[2]-m[0],x=m[3]-m[1],b=g[2]-g[0],_=g[3]-g[1],w=0;w<2;++w){var k=p[w],T=p[w+2]-k,A=.5*(d[w+2]+d[w]),M=d[w+2]-d[w];e[w]=2*T/M,t[w]=2*(k-A)/M}e[0]*=b/y,t[0]*=b/y,e[1]*=_/x,t[1]*=_/x,u.bind(),c.bind(),u.attributes.dataCoord.pointer();var S=u.uniforms;S.dataShift=t,S.dataScale=e;var E=s.tickMarkLength,C=s.tickMarkWidth,L=s.tickMarkColor,P=6*h[0].length,O=Math.min(a.ge(h[0],(d[0]-p[0])/(p[2]-p[0]),l),h[0].length),z=Math.min(a.gt(h[0],(d[2]-p[0])/(p[2]-p[0]),l),h[0].length),I=0+6*O,D=6*Math.max(0,z-O),R=Math.min(a.ge(h[1],(d[1]-p[1])/(p[3]-p[1]),l),h[1].length),F=Math.min(a.gt(h[1],(d[3]-p[1])/(p[3]-p[1]),l),h[1].length),B=P+6*R,N=6*Math.max(0,F-R);i[0]=2*(g[0]-E[1])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=E[1]*v/y,o[1]=C[1]*v/x,N&&(S.color=L[1],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,f.drawArrays(f.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[1]-E[0])/x-1,o[0]=C[0]*v/y,o[1]=E[0]*v/x,D&&(S.color=L[0],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,f.drawArrays(f.TRIANGLES,I,D)),i[0]=2*(g[2]+E[3])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=E[3]*v/y,o[1]=C[3]*v/x,N&&(S.color=L[3],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,f.drawArrays(f.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[3]+E[2])/x-1,o[0]=C[2]*v/y,o[1]=E[2]*v/x,D&&(S.color=L[2],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,f.drawArrays(f.TRIANGLES,I,D))}}(),d.update=(f=[1,1,-1,-1,1,-1],p=[1,-1,1,1,-1,-1],function(t){for(var e=t.ticks,r=t.bounds,n=new Float32Array(18*(e[0].length+e[1].length)),i=(this.plot.zeroLineEnable,0),a=[[],[]],o=0;o<2;++o)for(var s=a[o],l=e[o],c=r[o],u=r[o+2],h=0;h<l.length;++h){var d=(l[h].x-c)/(u-c);s.push(d);for(var g=0;g<6;++g)n[i++]=d,n[i++]=f[g],n[i++]=p[g]}this.ticks=a,this.vbo.update(n)}),d.dispose=function(){this.vbo.dispose(),this.shader.dispose(),this.tickShader.dispose()}},{\"./shaders\":284,\"binary-search-bounds\":286,\"gl-buffer\":241,\"gl-shader\":301}],283:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[-1,-1,-1,1,1,-1,1,1]),s=i(e,a.lineVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawLine=(s=[0,0],l=[0,0],function(t,e,r,n,i,a){var o=this.plot,c=this.shader,u=o.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,c.uniforms.start=s,c.uniforms.end=l,c.uniforms.width=i*o.pixelRatio,c.uniforms.color=a,u.drawArrays(u.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":284,\"gl-buffer\":241,\"gl-shader\":301}],284:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision lowp float;\\n#define GLSLIFY 1\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = vec4(color.xyz * color.w, color.w);\\n}\\n\"]);e.exports={lineVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 start, end;\\nuniform float width;\\n\\nvec2 perp(vec2 v) {\\n  return vec2(v.y, -v.x);\\n}\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  vec2 delta = normalize(perp(start - end));\\n  vec2 offset = mix(start, end, 0.5 * (coord.y+1.0));\\n  gl_Position = vec4(screen(offset + 0.5 * width * delta * coord.x), 0, 1);\\n}\\n\"]),lineFrag:i,textVert:n([\"#define GLSLIFY 1\\nattribute vec3 textCoordinate;\\n\\nuniform vec2 dataScale, dataShift, dataAxis, screenOffset, textScale;\\nuniform float angle;\\n\\nvoid main() {\\n  float dataOffset  = textCoordinate.z;\\n  vec2 glyphOffset  = textCoordinate.xy;\\n  mat2 glyphMatrix = mat2(cos(angle), sin(angle), -sin(angle), cos(angle));\\n  vec2 screenCoordinate = dataAxis * (dataScale * dataOffset + dataShift) +\\n    glyphMatrix * glyphOffset * textScale + screenOffset;\\n  gl_Position = vec4(screenCoordinate, 0, 1);\\n}\\n\"]),textFrag:i,gridVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale;\\nuniform float lineWidth;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  pos += 10.0 * dataCoord.y * vec2(dataAxis.y, -dataAxis.x) + dataCoord.z * lineWidth;\\n  gl_Position = vec4(pos, 0, 1);\\n}\\n\"]),gridFrag:i,boxVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 lo, hi;\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  gl_Position = vec4(screen(mix(lo, hi, coord)), 0, 1);\\n}\\n\"]),tickVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale, screenOffset, tickScale;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  gl_Position = vec4(pos + tickScale*dataCoord.yz + screenOffset, 0, 1);\\n}\\n\"])}},{glslify:409}],285:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,s.textVert,s.textFrag);return new l(t,r,a)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"text-cache\"),o=t(\"binary-search-bounds\"),s=t(\"./shaders\");function l(t,e,r){this.plot=t,this.vbo=e,this.shader=r,this.tickOffset=[[],[]],this.tickX=[[],[]],this.labelOffset=[0,0],this.labelCount=[0,0]}var c,u,h,f,p,d,g=l.prototype;g.drawTicks=(c=[0,0],u=[0,0],h=[0,0],function(t){var e=this.plot,r=this.shader,n=this.tickX[t],i=this.tickOffset[t],a=e.gl,s=e.viewBox,l=e.dataBox,f=e.screenBox,p=e.pixelRatio,d=e.tickEnable,g=e.tickPad,v=e.tickColor,m=e.tickAngle,y=e.labelEnable,x=e.labelPad,b=e.labelColor,_=e.labelAngle,w=this.labelOffset[t],k=this.labelCount[t],T=o.lt(n,l[t]),A=o.le(n,l[t+2]);c[0]=c[1]=0,c[t]=1,u[t]=(s[2+t]+s[t])/(f[2+t]-f[t])-1;var M=2/f[2+(1^t)]-f[1^t];u[1^t]=M*s[1^t]-1,d[t]&&(u[1^t]-=M*p*g[t],T<A&&i[A]>i[T]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=v[t],r.uniforms.angle=m[t],a.drawArrays(a.TRIANGLES,i[T],i[A]-i[T]))),y[t]&&k&&(u[1^t]-=M*p*x[t],r.uniforms.dataAxis=h,r.uniforms.screenOffset=u,r.uniforms.color=b[t],r.uniforms.angle=_[t],a.drawArrays(a.TRIANGLES,w,k)),u[1^t]=M*s[2+(1^t)]-1,d[t+2]&&(u[1^t]+=M*p*g[t+2],T<A&&i[A]>i[T]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=v[t+2],r.uniforms.angle=m[t+2],a.drawArrays(a.TRIANGLES,i[T],i[A]-i[T]))),y[t+2]&&k&&(u[1^t]+=M*p*x[t+2],r.uniforms.dataAxis=h,r.uniforms.screenOffset=u,r.uniforms.color=b[t+2],r.uniforms.angle=_[t+2],a.drawArrays(a.TRIANGLES,w,k))}),g.drawTitle=function(){var t=[0,0],e=[0,0];return function(){var r=this.plot,n=this.shader,i=r.gl,a=r.screenBox,o=r.titleCenter,s=r.titleAngle,l=r.titleColor,c=r.pixelRatio;if(this.titleCount){for(var u=0;u<2;++u)e[u]=2*(o[u]*c-a[u])/(a[2+u]-a[u])-1;n.bind(),n.uniforms.dataAxis=t,n.uniforms.screenOffset=e,n.uniforms.angle=s,n.uniforms.color=l,i.drawArrays(i.TRIANGLES,this.titleOffset,this.titleCount)}}}(),g.bind=(f=[0,0],p=[0,0],d=[0,0],function(){var t=this.plot,e=this.shader,r=t._tickBounds,n=t.dataBox,i=t.screenBox,a=t.viewBox;e.bind();for(var o=0;o<2;++o){var s=r[o],l=r[o+2]-s,c=.5*(n[o+2]+n[o]),u=n[o+2]-n[o],h=a[o],g=a[o+2]-h,v=i[o],m=i[o+2]-v;p[o]=2*l/u*g/m,f[o]=2*(s-c)/u*g/m}d[1]=2*t.pixelRatio/(i[3]-i[1]),d[0]=d[1]*(i[3]-i[1])/(i[2]-i[0]),e.uniforms.dataScale=p,e.uniforms.dataShift=f,e.uniforms.textScale=d,this.vbo.bind(),e.attributes.textCoordinate.pointer()}),g.update=function(t){var e,r,n,i,o,s=[],l=t.ticks,c=t.bounds;for(o=0;o<2;++o){var u=[Math.floor(s.length/3)],h=[-1/0],f=l[o];for(e=0;e<f.length;++e){var p=f[e],d=p.x,g=p.text,v=p.font||\"sans-serif\";i=p.fontSize||12;for(var m=1/(c[o+2]-c[o]),y=c[o],x=g.split(\"\\n\"),b=0;b<x.length;b++)for(n=a(v,x[b]).data,r=0;r<n.length;r+=2)s.push(n[r]*i,-n[r+1]*i-b*i*1.2,(d-y)*m);u.push(Math.floor(s.length/3)),h.push(d)}this.tickOffset[o]=u,this.tickX[o]=h}for(o=0;o<2;++o){for(this.labelOffset[o]=Math.floor(s.length/3),n=a(t.labelFont[o],t.labels[o],{textAlign:\"center\"}).data,i=t.labelSize[o],e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.labelCount[o]=Math.floor(s.length/3)-this.labelOffset[o]}for(this.titleOffset=Math.floor(s.length/3),n=a(t.titleFont,t.title).data,i=t.titleSize,e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.titleCount=Math.floor(s.length/3)-this.titleOffset,this.vbo.update(s)},g.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":284,\"binary-search-bounds\":286,\"gl-buffer\":241,\"gl-shader\":301,\"text-cache\":536}],286:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],287:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[e.drawingBufferWidth,e.drawingBufferHeight]),c=new l(e,r);return c.grid=i(c),c.text=a(c),c.line=o(c),c.box=s(c),c.update(t),c};var n=t(\"gl-select-static\"),i=t(\"./lib/grid\"),a=t(\"./lib/text\"),o=t(\"./lib/line\"),s=t(\"./lib/box\");function l(t,e){this.gl=t,this.pickBuffer=e,this.screenBox=[0,0,t.drawingBufferWidth,t.drawingBufferHeight],this.viewBox=[0,0,0,0],this.dataBox=[-10,-10,10,10],this.gridLineEnable=[!0,!0],this.gridLineWidth=[1,1],this.gridLineColor=[[0,0,0,1],[0,0,0,1]],this.pixelRatio=1,this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickEnable=[!0,!0,!0,!0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[15,15,15,15],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelEnable=[!0,!0,!0,!0],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.titleCenter=[0,0],this.titleEnable=!0,this.titleAngle=0,this.titleColor=[0,0,0,1],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[4,4],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderLineEnable=[!0,!0,!0,!0],this.borderLineWidth=[2,2,2,2],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.grid=null,this.text=null,this.line=null,this.box=null,this.objects=[],this.overlays=[],this._tickBounds=[1/0,1/0,-1/0,-1/0],this.static=!1,this.dirty=!1,this.pickDirty=!1,this.pickDelay=120,this.pickRadius=10,this._pickTimeout=null,this._drawPick=this.drawPick.bind(this),this._depthCounter=0}var c=l.prototype;function u(t){for(var e=t.slice(),r=0;r<e.length;++r)e[r]=e[r].slice();return e}function h(t,e){return t.x-e.x}c.setDirty=function(){this.dirty=this.pickDirty=!0},c.setOverlayDirty=function(){this.dirty=!0},c.nextDepthValue=function(){return this._depthCounter++/65536},c.draw=function(){var t=this.gl,e=this.screenBox,r=this.viewBox,n=this.dataBox,i=this.pixelRatio,a=this.grid,o=this.line,s=this.text,l=this.objects;if(this._depthCounter=0,this.pickDirty&&(this._pickTimeout&&clearTimeout(this._pickTimeout),this.pickDirty=!1,this._pickTimeout=setTimeout(this._drawPick,this.pickDelay)),this.dirty){if(this.dirty=!1,t.bindFramebuffer(t.FRAMEBUFFER,null),t.enable(t.SCISSOR_TEST),t.disable(t.DEPTH_TEST),t.depthFunc(t.LESS),t.depthMask(!1),t.enable(t.BLEND),t.blendEquation(t.FUNC_ADD,t.FUNC_ADD),t.blendFunc(t.ONE,t.ONE_MINUS_SRC_ALPHA),this.borderColor){t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]);var c=this.borderColor;t.clearColor(c[0]*c[3],c[1]*c[3],c[2]*c[3],c[3]),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT)}t.scissor(r[0],r[1],r[2]-r[0],r[3]-r[1]),t.viewport(r[0],r[1],r[2]-r[0],r[3]-r[1]);var u=this.backgroundColor;t.clearColor(u[0]*u[3],u[1]*u[3],u[2]*u[3],u[3]),t.clear(t.COLOR_BUFFER_BIT),a.draw();var h=this.zeroLineEnable,f=this.zeroLineColor,p=this.zeroLineWidth;if(h[0]||h[1]){o.bind();for(var d=0;d<2;++d)if(h[d]&&n[d]<=0&&n[d+2]>=0){var g=e[d]-n[d]*(e[d+2]-e[d])/(n[d+2]-n[d]);0===d?o.drawLine(g,e[1],g,e[3],p[d],f[d]):o.drawLine(e[0],g,e[2],g,p[d],f[d])}}for(d=0;d<l.length;++d)l[d].draw();t.viewport(e[0],e[1],e[2]-e[0],e[3]-e[1]),t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]),this.grid.drawTickMarks(),o.bind();var v=this.borderLineEnable,m=this.borderLineWidth,y=this.borderLineColor;for(v[1]&&o.drawLine(r[0],r[1]-.5*m[1]*i,r[0],r[3]+.5*m[3]*i,m[1],y[1]),v[0]&&o.drawLine(r[0]-.5*m[0]*i,r[1],r[2]+.5*m[2]*i,r[1],m[0],y[0]),v[3]&&o.drawLine(r[2],r[1]-.5*m[1]*i,r[2],r[3]+.5*m[3]*i,m[3],y[3]),v[2]&&o.drawLine(r[0]-.5*m[0]*i,r[3],r[2]+.5*m[2]*i,r[3],m[2],y[2]),s.bind(),d=0;d<2;++d)s.drawTicks(d);this.titleEnable&&s.drawTitle();var x=this.overlays;for(d=0;d<x.length;++d)x[d].draw();t.disable(t.SCISSOR_TEST),t.disable(t.BLEND),t.depthMask(!0)}},c.drawPick=function(){if(!this.static){var t=this.pickBuffer;this.gl;this._pickTimeout=null,t.begin();for(var e=1,r=this.objects,n=0;n<r.length;++n)e=r[n].drawPick(e);t.end()}},c.pick=function(t,e){if(!this.static){var r=this.pixelRatio,n=this.pickPixelRatio,i=this.viewBox,a=0|Math.round((t-i[0]/r)*n),o=0|Math.round((e-i[1]/r)*n),s=this.pickBuffer.query(a,o,this.pickRadius);if(!s)return null;for(var l=s.id+(s.value[0]<<8)+(s.value[1]<<16)+(s.value[2]<<24),c=this.objects,u=0;u<c.length;++u){var h=c[u].pick(a,o,l);if(h)return h}return null}},c.setScreenBox=function(t){var e=this.screenBox,r=this.pixelRatio;e[0]=0|Math.round(t[0]*r),e[1]=0|Math.round(t[1]*r),e[2]=0|Math.round(t[2]*r),e[3]=0|Math.round(t[3]*r),this.setDirty()},c.setDataBox=function(t){var e=this.dataBox;(e[0]!==t[0]||e[1]!==t[1]||e[2]!==t[2]||e[3]!==t[3])&&(e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],this.setDirty())},c.setViewBox=function(t){var e=this.pixelRatio,r=this.viewBox;r[0]=0|Math.round(t[0]*e),r[1]=0|Math.round(t[1]*e),r[2]=0|Math.round(t[2]*e),r[3]=0|Math.round(t[3]*e);var n=this.pickPixelRatio;this.pickBuffer.shape=[0|Math.round((t[2]-t[0])*n),0|Math.round((t[3]-t[1])*n)],this.setDirty()},c.update=function(t){t=t||{};var e=this.gl;this.pixelRatio=t.pixelRatio||1;var r=this.pixelRatio;this.pickPixelRatio=Math.max(r,1),this.setScreenBox(t.screenBox||[0,0,e.drawingBufferWidth/r,e.drawingBufferHeight/r]);this.screenBox;this.setViewBox(t.viewBox||[.125*(this.screenBox[2]-this.screenBox[0])/r,.125*(this.screenBox[3]-this.screenBox[1])/r,.875*(this.screenBox[2]-this.screenBox[0])/r,.875*(this.screenBox[3]-this.screenBox[1])/r]);var n=this.viewBox,i=(n[2]-n[0])/(n[3]-n[1]);this.setDataBox(t.dataBox||[-10,-10/i,10,10/i]),this.borderColor=!1!==t.borderColor&&(t.borderColor||[0,0,0,0]).slice(),this.backgroundColor=(t.backgroundColor||[0,0,0,0]).slice(),this.gridLineEnable=(t.gridLineEnable||[!0,!0]).slice(),this.gridLineWidth=(t.gridLineWidth||[1,1]).slice(),this.gridLineColor=u(t.gridLineColor||[[.5,.5,.5,1],[.5,.5,.5,1]]),this.zeroLineEnable=(t.zeroLineEnable||[!0,!0]).slice(),this.zeroLineWidth=(t.zeroLineWidth||[4,4]).slice(),this.zeroLineColor=u(t.zeroLineColor||[[0,0,0,1],[0,0,0,1]]),this.tickMarkLength=(t.tickMarkLength||[0,0,0,0]).slice(),this.tickMarkWidth=(t.tickMarkWidth||[0,0,0,0]).slice(),this.tickMarkColor=u(t.tickMarkColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.titleCenter=(t.titleCenter||[.5*(n[0]+n[2])/r,(n[3]+120)/r]).slice(),this.titleEnable=!(\"titleEnable\"in t&&!t.titleEnable),this.titleAngle=t.titleAngle||0,this.titleColor=(t.titleColor||[0,0,0,1]).slice(),this.labelPad=(t.labelPad||[15,15,15,15]).slice(),this.labelAngle=(t.labelAngle||[0,Math.PI/2,0,3*Math.PI/2]).slice(),this.labelEnable=(t.labelEnable||[!0,!0,!0,!0]).slice(),this.labelColor=u(t.labelColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.tickPad=(t.tickPad||[15,15,15,15]).slice(),this.tickAngle=(t.tickAngle||[0,0,0,0]).slice(),this.tickEnable=(t.tickEnable||[!0,!0,!0,!0]).slice(),this.tickColor=u(t.tickColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.borderLineEnable=(t.borderLineEnable||[!0,!0,!0,!0]).slice(),this.borderLineWidth=(t.borderLineWidth||[2,2,2,2]).slice(),this.borderLineColor=u(t.borderLineColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]);var a=t.ticks||[[],[]],o=this._tickBounds;o[0]=o[1]=1/0,o[2]=o[3]=-1/0;for(var s=0;s<2;++s){var l=a[s].slice(0);0!==l.length&&(l.sort(h),o[s]=Math.min(o[s],l[0].x),o[s+2]=Math.max(o[s+2],l[l.length-1].x))}this.grid.update({bounds:o,ticks:a}),this.text.update({bounds:o,ticks:a,labels:t.labels||[\"x\",\"y\"],labelSize:t.labelSize||[12,12],labelFont:t.labelFont||[\"sans-serif\",\"sans-serif\"],title:t.title||\"\",titleSize:t.titleSize||18,titleFont:t.titleFont||\"sans-serif\"}),this.static=!!t.static,this.setDirty()},c.dispose=function(){this.box.dispose(),this.grid.dispose(),this.text.dispose(),this.line.dispose();for(var t=this.objects.length-1;t>=0;--t)this.objects[t].dispose();this.objects.length=0;for(t=this.overlays.length-1;t>=0;--t)this.overlays[t].dispose();this.overlays.length=0,this.gl=null},c.addObject=function(t){this.objects.indexOf(t)<0&&(this.objects.push(t),this.setDirty())},c.removeObject=function(t){for(var e=this.objects,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setDirty();break}},c.addOverlay=function(t){this.overlays.indexOf(t)<0&&(this.overlays.push(t),this.setOverlayDirty())},c.removeOverlay=function(t){for(var e=this.overlays,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setOverlayDirty();break}}},{\"./lib/box\":281,\"./lib/grid\":282,\"./lib/line\":283,\"./lib/text\":285,\"gl-select-static\":300}],288:[function(t,e,r){\"use strict\";e.exports=function(t,e){t=t||document.body,e=e||{};var r=[.01,1/0];\"distanceLimits\"in e&&(r[0]=e.distanceLimits[0],r[1]=e.distanceLimits[1]);\"zoomMin\"in e&&(r[0]=e.zoomMin);\"zoomMax\"in e&&(r[1]=e.zoomMax);var c=i({center:e.center||[0,0,0],up:e.up||[0,1,0],eye:e.eye||[0,0,10],mode:e.mode||\"orbit\",distanceLimits:r}),u=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],h=0,f=t.clientWidth,p=t.clientHeight,d={keyBindingMode:\"rotate\",enableWheel:!0,view:c,element:t,delay:e.delay||16,rotateSpeed:e.rotateSpeed||1,zoomSpeed:e.zoomSpeed||1,translateSpeed:e.translateSpeed||1,flipX:!!e.flipX,flipY:!!e.flipY,modes:c.modes,_ortho:e._ortho||e.projection&&\"orthographic\"===e.projection.type||!1,tick:function(){var e=n(),r=this.delay,i=e-2*r;c.idle(e-r),c.recalcMatrix(i),c.flush(e-(100+2*r));for(var a=!0,o=c.computedMatrix,s=0;s<16;++s)a=a&&u[s]===o[s],u[s]=o[s];var l=t.clientWidth===f&&t.clientHeight===p;return f=t.clientWidth,p=t.clientHeight,a?!l:(h=Math.exp(c.computedRadius[0]),!0)},lookAt:function(t,e,r){c.lookAt(c.lastT(),t,e,r)},rotate:function(t,e,r){c.rotate(c.lastT(),t,e,r)},pan:function(t,e,r){c.pan(c.lastT(),t,e,r)},translate:function(t,e,r){c.translate(c.lastT(),t,e,r)}};return Object.defineProperties(d,{matrix:{get:function(){return c.computedMatrix},set:function(t){return c.setMatrix(c.lastT(),t),c.computedMatrix},enumerable:!0},mode:{get:function(){return c.getMode()},set:function(t){var e=c.computedUp.slice(),r=c.computedEye.slice(),i=c.computedCenter.slice();if(c.setMode(t),\"turntable\"===t){var a=n();c._active.lookAt(a,r,i,e),c._active.lookAt(a+500,r,i,[0,0,1]),c._active.flush(a)}return c.getMode()},enumerable:!0},center:{get:function(){return c.computedCenter},set:function(t){return c.lookAt(c.lastT(),null,t),c.computedCenter},enumerable:!0},eye:{get:function(){return c.computedEye},set:function(t){return c.lookAt(c.lastT(),t),c.computedEye},enumerable:!0},up:{get:function(){return c.computedUp},set:function(t){return c.lookAt(c.lastT(),null,null,t),c.computedUp},enumerable:!0},distance:{get:function(){return h},set:function(t){return c.setDistance(c.lastT(),t),t},enumerable:!0},distanceLimits:{get:function(){return c.getDistanceLimits(r)},set:function(t){return c.setDistanceLimits(t),t},enumerable:!0}}),t.addEventListener(\"contextmenu\",function(t){return t.preventDefault(),!1}),d._lastX=-1,d._lastY=-1,d._lastMods={shift:!1,control:!1,alt:!1,meta:!1},d.enableMouseListeners=function(){function e(e,r,i,a){var o=d.keyBindingMode;if(!1!==o){var s=\"rotate\"===o,l=\"pan\"===o,u=\"zoom\"===o,f=!!a.control,p=!!a.alt,g=!!a.shift,v=!!(1&e),m=!!(2&e),y=!!(4&e),x=1/t.clientHeight,b=x*(r-d._lastX),_=x*(i-d._lastY),w=d.flipX?1:-1,k=d.flipY?1:-1,T=Math.PI*d.rotateSpeed,A=n();if(-1!==d._lastX&&-1!==d._lastY&&((s&&v&&!f&&!p&&!g||v&&!f&&!p&&g)&&c.rotate(A,w*T*b,-k*T*_,0),(l&&v&&!f&&!p&&!g||m||v&&f&&!p&&!g)&&c.pan(A,-d.translateSpeed*b*h,d.translateSpeed*_*h,0),u&&v&&!f&&!p&&!g||y||v&&!f&&p&&!g)){var M=-d.zoomSpeed*_/window.innerHeight*(A-c.lastT())*100;c.pan(A,0,0,h*(Math.exp(M)-1))}return d._lastX=r,d._lastY=i,d._lastMods=a,!0}}d.mouseListener=a(t,e),t.addEventListener(\"touchstart\",function(r){var n=s(r.changedTouches[0],t);e(0,n[0],n[1],d._lastMods),e(1,n[0],n[1],d._lastMods),r.preventDefault()},!!l&&{passive:!1}),t.addEventListener(\"touchmove\",function(r){var n=s(r.changedTouches[0],t);e(1,n[0],n[1],d._lastMods),r.preventDefault()},!!l&&{passive:!1}),t.addEventListener(\"touchend\",function(t){e(0,d._lastX,d._lastY,d._lastMods),t.preventDefault()},!!l&&{passive:!1}),d.wheelListener=o(t,function(t,e){if(!1!==d.keyBindingMode&&d.enableWheel){var r=d.flipX?1:-1,i=d.flipY?1:-1,a=n();if(Math.abs(t)>Math.abs(e))c.rotate(a,0,0,-t*r*Math.PI*d.rotateSpeed/window.innerWidth);else if(!d._ortho){var o=-d.zoomSpeed*i*e/window.innerHeight*(a-c.lastT())/20;c.pan(a,0,0,h*(Math.exp(o)-1))}}},!0)},d.enableMouseListeners(),d};var n=t(\"right-now\"),i=t(\"3d-view\"),a=t(\"mouse-change\"),o=t(\"mouse-wheel\"),s=t(\"mouse-event-offset\"),l=t(\"has-passive-events\")},{\"3d-view\":52,\"has-passive-events\":411,\"mouse-change\":435,\"mouse-event-offset\":436,\"mouse-wheel\":438,\"right-now\":504}],289:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\nattribute vec2 position;\\nvarying vec2 uv;\\nvoid main() {\\n  uv = position;\\n  gl_Position = vec4(position, 0, 1);\\n}\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D accumBuffer;\\nvarying vec2 uv;\\n\\nvoid main() {\\n  vec4 accum = texture2D(accumBuffer, 0.5 * (uv + 1.0));\\n  gl_FragColor = min(vec4(1,1,1,1), accum);\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec2\"}])}},{\"gl-shader\":301,glslify:409}],290:[function(t,e,r){\"use strict\";var n=t(\"./camera.js\"),i=t(\"gl-axes3d\"),a=t(\"gl-axes3d/properties\"),o=t(\"gl-spikes3d\"),s=t(\"gl-select-static\"),l=t(\"gl-fbo\"),c=t(\"a-big-triangle\"),u=t(\"mouse-change\"),h=t(\"mouse-wheel\"),f=t(\"gl-mat4/perspective\"),p=t(\"gl-mat4/ortho\"),d=t(\"./lib/shader\"),g=t(\"is-mobile\")({tablet:!0});function v(){this.mouse=[-1,-1],this.screen=null,this.distance=1/0,this.index=null,this.dataCoordinate=null,this.dataPosition=null,this.object=null,this.data=null}function m(t){var e=Math.round(Math.log(Math.abs(t))/Math.log(10));if(e<0){var r=Math.round(Math.pow(10,-e));return Math.ceil(t*r)/r}if(e>0){r=Math.round(Math.pow(10,e));return Math.ceil(t/r)*r}return Math.ceil(t)}function y(t){return\"boolean\"!=typeof t||t}e.exports={createScene:function(t){(t=t||{}).camera=t.camera||{};var e=t.canvas;if(!e)if(e=document.createElement(\"canvas\"),t.container){var r=t.container;r.appendChild(e)}else document.body.appendChild(e);var x=t.gl;x||(x=function(t,e){var r=null;try{(r=t.getContext(\"webgl\",e))||(r=t.getContext(\"experimental-webgl\",e))}catch(t){return null}return r}(e,t.glOptions||{premultipliedAlpha:!0,antialias:!0,preserveDrawingBuffer:g}));if(!x)throw new Error(\"webgl not supported\");var b=t.bounds||[[-10,-10,-10],[10,10,10]],_=new v,w=l(x,[x.drawingBufferWidth,x.drawingBufferHeight],{preferFloat:!g}),k=d(x),T=t.cameraObject&&!0===t.cameraObject._ortho||t.camera.projection&&\"orthographic\"===t.camera.projection.type||!1,A={eye:t.camera.eye||[2,0,0],center:t.camera.center||[0,0,0],up:t.camera.up||[0,1,0],zoomMin:t.camera.zoomMax||.1,zoomMax:t.camera.zoomMin||100,mode:t.camera.mode||\"turntable\",_ortho:T},M=t.axes||{},S=i(x,M);S.enable=!M.disable;var E=t.spikes||{},C=o(x,E),L=[],P=[],O=[],z=[],I=!0,D=!0,R=new Array(16),F=new Array(16),B={view:null,projection:R,model:F,_ortho:!1},D=!0,N=[x.drawingBufferWidth,x.drawingBufferHeight],j=t.cameraObject||n(e,A),U={gl:x,contextLost:!1,pixelRatio:t.pixelRatio||1,canvas:e,selection:_,camera:j,axes:S,axesPixels:null,spikes:C,bounds:b,objects:L,shape:N,aspect:t.aspectRatio||[1,1,1],pickRadius:t.pickRadius||10,zNear:t.zNear||.01,zFar:t.zFar||1e3,fovy:t.fovy||Math.PI/4,clearColor:t.clearColor||[0,0,0,0],autoResize:y(t.autoResize),autoBounds:y(t.autoBounds),autoScale:!!t.autoScale,autoCenter:y(t.autoCenter),clipToBounds:y(t.clipToBounds),snapToData:!!t.snapToData,onselect:t.onselect||null,onrender:t.onrender||null,onclick:t.onclick||null,cameraParams:B,oncontextloss:null,mouseListener:null,_stopped:!1},V=[x.drawingBufferWidth/U.pixelRatio|0,x.drawingBufferHeight/U.pixelRatio|0];function q(){if(!U._stopped&&U.autoResize){var t=e.parentNode,r=1,n=1;t&&t!==document.body?(r=t.clientWidth,n=t.clientHeight):(r=window.innerWidth,n=window.innerHeight);var i=0|Math.ceil(r*U.pixelRatio),a=0|Math.ceil(n*U.pixelRatio);if(i!==e.width||a!==e.height){e.width=i,e.height=a;var o=e.style;o.position=o.position||\"absolute\",o.left=\"0px\",o.top=\"0px\",o.width=r+\"px\",o.height=n+\"px\",I=!0}}}U.autoResize&&q();function H(){for(var t=L.length,e=z.length,r=0;r<e;++r)O[r]=0;t:for(var r=0;r<t;++r){var n=L[r],i=n.pickSlots;if(i){for(var a=0;a<e;++a)if(O[a]+i<255){P[r]=a,n.setPickBase(O[a]+1),O[a]+=i;continue t}var o=s(x,N);P[r]=e,z.push(o),O.push(i),n.setPickBase(1),e+=1}else P[r]=-1}for(;e>0&&0===O[e-1];)O.pop(),z.pop().dispose()}function G(){if(U.contextLost)return!0;x.isContextLost()&&(U.contextLost=!0,U.mouseListener.enabled=!1,U.selection.object=null,U.oncontextloss&&U.oncontextloss())}window.addEventListener(\"resize\",q),U.update=function(t){U._stopped||(t=t||{},I=!0,D=!0)},U.add=function(t){U._stopped||(t.axes=S,L.push(t),P.push(-1),I=!0,D=!0,H())},U.remove=function(t){if(!U._stopped){var e=L.indexOf(t);e<0||(L.splice(e,1),P.pop(),I=!0,D=!0,H())}},U.dispose=function(){if(!U._stopped&&(U._stopped=!0,window.removeEventListener(\"resize\",q),e.removeEventListener(\"webglcontextlost\",G),U.mouseListener.enabled=!1,!U.contextLost)){S.dispose(),C.dispose();for(var t=0;t<L.length;++t)L[t].dispose();w.dispose();for(var t=0;t<z.length;++t)z[t].dispose();k.dispose(),x=null,S=null,C=null,L=[]}},U.wheelListener=h(e,function(t,e){if(!1!==j.keyBindingMode&&j.enableWheel&&j._ortho){var r=t>e?1.1:1/1.1;U.aspect[0]*=r,U.aspect[1]*=r,U.aspect[2]*=r,U.redraw()}},!0),U._mouseRotating=!1,U._prevButtons=0,U.enableMouseListeners=function(){U.mouseListener=u(e,function(t,e,r){if(!U._stopped){var n=z.length,i=L.length,a=_.object;_.distance=1/0,_.mouse[0]=e,_.mouse[1]=r,_.object=null,_.screen=null,_.dataCoordinate=_.dataPosition=null;var o=!1;if(t&&U._prevButtons)U._mouseRotating=!0;else{U._mouseRotating&&(D=!0),U._mouseRotating=!1;for(var s=0;s<n;++s){var l=z[s].query(e,V[1]-r-1,U.pickRadius);if(l){if(l.distance>_.distance)continue;for(var c=0;c<i;++c){var u=L[c];if(P[c]===s){var h=u.pick(l);h&&(_.buttons=t,_.screen=l.coord,_.distance=l.distance,_.object=u,_.index=h.distance,_.dataPosition=h.position,_.dataCoordinate=h.dataCoordinate,_.data=h,o=!0)}}}}}a&&a!==_.object&&(a.highlight&&a.highlight(null),I=!0),_.object&&(_.object.highlight&&_.object.highlight(_.data),I=!0),(o=o||_.object!==a)&&U.onselect&&U.onselect(_),1&t&&!(1&U._prevButtons)&&U.onclick&&U.onclick(_),U._prevButtons=t}})},e.addEventListener(\"webglcontextlost\",G);var Y=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],W=[Y[0].slice(),Y[1].slice()];function X(){if(!G()){q();var t=U.camera.tick();B.view=U.camera.matrix,I=I||t,D=D||t,S.pixelRatio=U.pixelRatio,C.pixelRatio=U.pixelRatio;var e=L.length,r=Y[0],n=Y[1];r[0]=r[1]=r[2]=1/0,n[0]=n[1]=n[2]=-1/0;for(var i=0;i<e;++i){var o=L[i];o.pixelRatio=U.pixelRatio,o.axes=U.axes,I=I||!!o.dirty,D=D||!!o.dirty;var s=o.bounds;if(s)for(var l=s[0],u=s[1],h=0;h<3;++h)r[h]=Math.min(r[h],l[h]),n[h]=Math.max(n[h],u[h])}var d=U.bounds;if(U.autoBounds)for(var h=0;h<3;++h){if(n[h]<r[h])r[h]=-1,n[h]=1;else{r[h]===n[h]&&(r[h]-=1,n[h]+=1);var g=.05*(n[h]-r[h]);r[h]=r[h]-g,n[h]=n[h]+g}d[0][h]=r[h],d[1][h]=n[h]}for(var v=!1,h=0;h<3;++h)v=v||W[0][h]!==d[0][h]||W[1][h]!==d[1][h],W[0][h]=d[0][h],W[1][h]=d[1][h];if(D=D||v,I=I||v){if(v){for(var y=[0,0,0],i=0;i<3;++i)y[i]=m((d[1][i]-d[0][i])/10);S.autoTicks?S.update({bounds:d,tickSpacing:y}):S.update({bounds:d})}var b=x.drawingBufferWidth,A=x.drawingBufferHeight;N[0]=b,N[1]=A,V[0]=0|Math.max(b/U.pixelRatio,1),V[1]=0|Math.max(A/U.pixelRatio,1),T?(p(R,-b/A,b/A,-1,1,U.zNear,U.zFar),B._ortho=!0):(f(R,U.fovy,b/A,U.zNear,U.zFar),B._ortho=!1);for(var i=0;i<16;++i)F[i]=0;F[15]=1;for(var M=0,i=0;i<3;++i)M=Math.max(M,d[1][i]-d[0][i]);for(var i=0;i<3;++i)U.autoScale?F[5*i]=U.aspect[i]/(d[1][i]-d[0][i]):F[5*i]=1/M,U.autoCenter&&(F[12+i]=.5*-F[5*i]*(d[0][i]+d[1][i]));for(var i=0;i<e;++i){var o=L[i];o.axesBounds=d,U.clipToBounds&&(o.clipBounds=d)}_.object&&(U.snapToData?C.position=_.dataCoordinate:C.position=_.dataPosition,C.bounds=d),D&&(D=!1,function(){if(G())return;x.colorMask(!0,!0,!0,!0),x.depthMask(!0),x.disable(x.BLEND),x.enable(x.DEPTH_TEST);for(var t=L.length,e=z.length,r=0;r<e;++r){var n=z[r];n.shape=V,n.begin();for(var i=0;i<t;++i)if(P[i]===r){var a=L[i];a.drawPick&&(a.pixelRatio=1,a.drawPick(B))}n.end()}}()),U.axesPixels=a(U.axes,B,b,A),U.onrender&&U.onrender(),x.bindFramebuffer(x.FRAMEBUFFER,null),x.viewport(0,0,b,A);var E=U.clearColor;x.clearColor(E[0],E[1],E[2],E[3]),x.clear(x.COLOR_BUFFER_BIT|x.DEPTH_BUFFER_BIT),x.depthMask(!0),x.colorMask(!0,!0,!0,!0),x.enable(x.DEPTH_TEST),x.depthFunc(x.LEQUAL),x.disable(x.BLEND),x.disable(x.CULL_FACE);var O=!1;S.enable&&(O=O||S.isTransparent(),S.draw(B)),C.axes=S,_.object&&C.draw(B),x.disable(x.CULL_FACE);for(var i=0;i<e;++i){var o=L[i];o.axes=S,o.pixelRatio=U.pixelRatio,o.isOpaque&&o.isOpaque()&&o.draw(B),o.isTransparent&&o.isTransparent()&&(O=!0)}if(O){w.shape=N,w.bind(),x.clear(x.DEPTH_BUFFER_BIT),x.colorMask(!1,!1,!1,!1),x.depthMask(!0),x.depthFunc(x.LESS),S.enable&&S.isTransparent()&&S.drawTransparent(B);for(var i=0;i<e;++i){var o=L[i];o.isOpaque&&o.isOpaque()&&o.draw(B)}x.enable(x.BLEND),x.blendEquation(x.FUNC_ADD),x.blendFunc(x.ONE,x.ONE_MINUS_SRC_ALPHA),x.colorMask(!0,!0,!0,!0),x.depthMask(!1),x.clearColor(0,0,0,0),x.clear(x.COLOR_BUFFER_BIT),S.isTransparent()&&S.drawTransparent(B);for(var i=0;i<e;++i){var o=L[i];o.isTransparent&&o.isTransparent()&&o.drawTransparent(B)}x.bindFramebuffer(x.FRAMEBUFFER,null),x.blendFunc(x.ONE,x.ONE_MINUS_SRC_ALPHA),x.disable(x.DEPTH_TEST),k.bind(),w.color[0].bind(0),k.uniforms.accumBuffer=0,c(x),x.disable(x.BLEND)}I=!1;for(var i=0;i<e;++i)L[i].dirty=!1}}}return U.enableMouseListeners(),function t(){U._stopped||U.contextLost||(X(),requestAnimationFrame(t))}(),U.redraw=function(){U._stopped||(I=!0,X())},U},createCamera:n}},{\"./camera.js\":288,\"./lib/shader\":289,\"a-big-triangle\":59,\"gl-axes3d\":233,\"gl-axes3d/properties\":240,\"gl-fbo\":249,\"gl-mat4/ortho\":268,\"gl-mat4/perspective\":269,\"gl-select-static\":300,\"gl-spikes3d\":310,\"is-mobile\":420,\"mouse-change\":435,\"mouse-wheel\":438}],291:[function(t,e,r){var n=t(\"glslify\");r.pointVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform float pointCloud;\\n\\nhighp float rand(vec2 co) {\\n  highp float a = 12.9898;\\n  highp float b = 78.233;\\n  highp float c = 43758.5453;\\n  highp float d = dot(co.xy, vec2(a, b));\\n  highp float e = mod(d, 3.14);\\n  return fract(sin(e) * c);\\n}\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n    // if we don't jitter the point size a bit, overall point cloud\\n    // saturation 'jumps' on zooming, which is disturbing and confusing\\n  gl_PointSize = pointSize * ((19.5 + rand(position)) / 20.0);\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    // get the same square surface as circle would be\\n    gl_PointSize *= 0.886;\\n  }\\n}\"]),r.pointFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color, borderColor;\\nuniform float centerFraction;\\nuniform float pointCloud;\\n\\nvoid main() {\\n  float radius;\\n  vec4 baseColor;\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    if(centerFraction == 1.0) {\\n      gl_FragColor = color;\\n    } else {\\n      gl_FragColor = mix(borderColor, color, centerFraction);\\n    }\\n  } else {\\n    radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n    if(radius > 1.0) {\\n      discard;\\n    }\\n    baseColor = mix(borderColor, color, step(radius, centerFraction));\\n    gl_FragColor = vec4(baseColor.rgb * baseColor.a, baseColor.a);\\n  }\\n}\\n\"]),r.pickVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform vec4 pickOffset;\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n  gl_PointSize = pointSize;\\n\\n  vec4 id = pickId + pickOffset;\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  fragId = id;\\n}\\n\"]),r.pickFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  float radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n  if(radius > 1.0) {\\n    discard;\\n  }\\n  gl_FragColor = fragId / 255.0;\\n}\\n\"])},{glslify:409}],292:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"typedarray-pool\"),o=t(\"./lib/shader\");function s(t,e,r,n,i){this.plot=t,this.offsetBuffer=e,this.pickBuffer=r,this.shader=n,this.pickShader=i,this.sizeMin=.5,this.sizeMinCap=2,this.sizeMax=20,this.areaRatio=1,this.pointCount=0,this.color=[1,0,0,1],this.borderColor=[0,0,0,1],this.blend=!1,this.pickOffset=0,this.points=null}e.exports=function(t,e){var r=t.gl,a=i(r),l=i(r),c=n(r,o.pointVertex,o.pointFragment),u=n(r,o.pickVertex,o.pickFragment),h=new s(t,a,l,c,u);return h.update(e),t.addObject(h),h};var l,c,u=s.prototype;u.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.offsetBuffer.dispose(),this.pickBuffer.dispose(),this.plot.removeObject(this)},u.update=function(t){var e;function r(e,r){return e in t?t[e]:r}t=t||{},this.sizeMin=r(\"sizeMin\",.5),this.sizeMax=r(\"sizeMax\",20),this.color=r(\"color\",[1,0,0,1]).slice(),this.areaRatio=r(\"areaRatio\",1),this.borderColor=r(\"borderColor\",[0,0,0,1]).slice(),this.blend=r(\"blend\",!1);var n=t.positions.length>>>1,i=t.positions instanceof Float32Array,o=t.idToIndex instanceof Int32Array&&t.idToIndex.length>=n,s=t.positions,l=i?s:a.mallocFloat32(s.length),c=o?t.idToIndex:a.mallocInt32(n);if(i||l.set(s),!o)for(l.set(s),e=0;e<n;e++)c[e]=e;this.points=s,this.offsetBuffer.update(l),this.pickBuffer.update(c),i||a.free(l),o||a.free(c),this.pointCount=n,this.pickOffset=0},u.unifiedDraw=(l=[1,0,0,0,1,0,0,0,1],c=[0,0,0,0],function(t){var e=void 0!==t,r=e?this.pickShader:this.shader,n=this.plot.gl,i=this.plot.dataBox;if(0===this.pointCount)return t;var a=i[2]-i[0],o=i[3]-i[1],s=function(t,e){var r,n=0,i=t.length>>>1;for(r=0;r<i;r++){var a=t[2*r],o=t[2*r+1];a>=e[0]&&a<=e[2]&&o>=e[1]&&o<=e[3]&&n++}return n}(this.points,i),u=this.plot.pickPixelRatio*Math.max(Math.min(this.sizeMinCap,this.sizeMin),Math.min(this.sizeMax,this.sizeMax/Math.pow(s,.33333)));l[0]=2/a,l[4]=2/o,l[6]=-2*i[0]/a-1,l[7]=-2*i[1]/o-1,this.offsetBuffer.bind(),r.bind(),r.attributes.position.pointer(),r.uniforms.matrix=l,r.uniforms.color=this.color,r.uniforms.borderColor=this.borderColor,r.uniforms.pointCloud=u<5,r.uniforms.pointSize=u,r.uniforms.centerFraction=Math.min(1,Math.max(0,Math.sqrt(1-this.areaRatio))),e&&(c[0]=255&t,c[1]=t>>8&255,c[2]=t>>16&255,c[3]=t>>24&255,this.pickBuffer.bind(),r.attributes.pickId.pointer(n.UNSIGNED_BYTE),r.uniforms.pickOffset=c,this.pickOffset=t);var h=n.getParameter(n.BLEND),f=n.getParameter(n.DITHER);return h&&!this.blend&&n.disable(n.BLEND),f&&n.disable(n.DITHER),n.drawArrays(n.POINTS,0,this.pointCount),h&&!this.blend&&n.enable(n.BLEND),f&&n.enable(n.DITHER),t+this.pointCount}),u.draw=u.unifiedDraw,u.drawPick=u.unifiedDraw,u.pick=function(t,e,r){var n=this.pickOffset,i=this.pointCount;if(r<n||r>=n+i)return null;var a=r-n,o=this.points;return{object:this,pointId:a,dataCoord:[o[2*a],o[2*a+1]]}}},{\"./lib/shader\":291,\"gl-buffer\":241,\"gl-shader\":301,\"typedarray-pool\":545}],293:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c=e[0],u=e[1],h=e[2],f=e[3],p=r[0],d=r[1],g=r[2],v=r[3];(a=c*p+u*d+h*g+f*v)<0&&(a=-a,p=-p,d=-d,g=-g,v=-v);1-a>1e-6?(i=Math.acos(a),o=Math.sin(i),s=Math.sin((1-n)*i)/o,l=Math.sin(n*i)/o):(s=1-n,l=n);return t[0]=s*c+l*p,t[1]=s*u+l*d,t[2]=s*h+l*g,t[3]=s*f+l*v,t}},{}],294:[function(t,e,r){\"use strict\";e.exports=function(t){return t||0===t?t.toString():\"\"}},{}],295:[function(t,e,r){\"use strict\";var n=t(\"vectorize-text\");e.exports=function(t,e,r){var a=i[e];a||(a=i[e]={});if(t in a)return a[t];var o={textAlign:\"center\",textBaseline:\"middle\",lineHeight:1,font:e,lineSpacing:1.25,styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},triangles:!0},s=n(t,o);o.triangles=!1;var l,c,u=n(t,o);if(r&&1!==r){for(l=0;l<s.positions.length;++l)for(c=0;c<s.positions[l].length;++c)s.positions[l][c]/=r;for(l=0;l<u.positions.length;++l)for(c=0;c<u.positions[l].length;++c)u.positions[l][c]/=r}var h=[[1/0,1/0],[-1/0,-1/0]],f=u.positions.length;for(l=0;l<f;++l){var p=u.positions[l];for(c=0;c<2;++c)h[0][c]=Math.min(h[0][c],p[c]),h[1][c]=Math.max(h[1][c],p[c])}return a[t]=[s,u,h]};var i={}},{\"vectorize-text\":550}],296:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform vec4 highlightId;\\nuniform float highlightScale;\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = 1.0;\\n    if(distance(highlightId, id) < 0.0001) {\\n      scale = highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1);\\n    vec4 viewPosition = view * worldPosition;\\n    viewPosition = viewPosition / viewPosition.w;\\n    vec4 clipPosition = projection * (viewPosition + scale * vec4(glyph.x, -glyph.y, 0, 0));\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float highlightScale, pixelRatio;\\nuniform vec4 highlightId;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = pixelRatio;\\n    if(distance(highlightId.bgr, id.bgr) < 0.001) {\\n      scale *= highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1.0);\\n    vec4 viewPosition = view * worldPosition;\\n    vec4 clipPosition = projection * viewPosition;\\n    clipPosition /= clipPosition.w;\\n\\n    gl_Position = clipPosition + vec4(screenSize * scale * vec2(glyph.x, -glyph.y), 0.0, 0.0);\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform float highlightScale;\\nuniform vec4 highlightId;\\nuniform vec3 axes[2];\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float scale, pixelRatio;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float lscale = pixelRatio * scale;\\n    if(distance(highlightId, id) < 0.0001) {\\n      lscale *= highlightScale;\\n    }\\n\\n    vec4 clipCenter   = projection * view * model * vec4(position, 1);\\n    vec3 dataPosition = position + 0.5*lscale*(axes[0] * glyph.x + axes[1] * glyph.y) * clipCenter.w * screenSize.y;\\n    vec4 clipPosition = projection * view * model * vec4(dataPosition, 1);\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = dataPosition;\\n  }\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float opacity;\\n\\nvarying vec4 interpColor;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (\\n    outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate) ||\\n    interpColor.a * opacity == 0.\\n  ) discard;\\n  gl_FragColor = interpColor * opacity;\\n}\\n\"]),c=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float pickGroup;\\n\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate)) discard;\\n\\n  gl_FragColor = vec4(pickGroup, pickId.bgr);\\n}\"]),u=[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"glyph\",type:\"vec2\"},{name:\"id\",type:\"vec4\"}],h={vertex:a,fragment:l,attributes:u},f={vertex:o,fragment:l,attributes:u},p={vertex:s,fragment:l,attributes:u},d={vertex:a,fragment:c,attributes:u},g={vertex:o,fragment:c,attributes:u},v={vertex:s,fragment:c,attributes:u};function m(t,e){var r=n(t,e),i=r.attributes;return i.position.location=0,i.color.location=1,i.glyph.location=2,i.id.location=3,r}r.createPerspective=function(t){return m(t,h)},r.createOrtho=function(t){return m(t,f)},r.createProject=function(t){return m(t,p)},r.createPickPerspective=function(t){return m(t,d)},r.createPickOrtho=function(t){return m(t,g)},r.createPickProject=function(t){return m(t,v)}},{\"gl-shader\":301,glslify:409}],297:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"typedarray-pool\"),s=t(\"gl-mat4/multiply\"),l=t(\"./lib/shaders\"),c=t(\"./lib/glyphs\"),u=t(\"./lib/get-simple-string\"),h=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function f(t,e){var r=t[0],n=t[1],i=t[2],a=t[3];return t[0]=e[0]*r+e[4]*n+e[8]*i+e[12]*a,t[1]=e[1]*r+e[5]*n+e[9]*i+e[13]*a,t[2]=e[2]*r+e[6]*n+e[10]*i+e[14]*a,t[3]=e[3]*r+e[7]*n+e[11]*i+e[15]*a,t}function p(t,e,r,n){return f(n,n),f(n,n),f(n,n)}function d(t,e){this.index=t,this.dataCoordinate=this.position=e}function g(t){return!0===t?1:t>1?1:t}function v(t,e,r,n,i,a,o,s,l,c,u,h){this.gl=t,this.pixelRatio=1,this.shader=e,this.orthoShader=r,this.projectShader=n,this.pointBuffer=i,this.colorBuffer=a,this.glyphBuffer=o,this.idBuffer=s,this.vao=l,this.vertexCount=0,this.lineVertexCount=0,this.opacity=1,this.hasAlpha=!1,this.lineWidth=0,this.projectScale=[2/3,2/3,2/3],this.projectOpacity=[1,1,1],this.projectHasAlpha=!1,this.pickId=0,this.pickPerspectiveShader=c,this.pickOrthoShader=u,this.pickProjectShader=h,this.points=[],this._selectResult=new d(0,[0,0,0]),this.useOrtho=!0,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.axesProject=[!0,!0,!0],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.highlightId=[1,1,1,1],this.highlightScale=2,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.dirty=!0}e.exports=function(t){var e=t.gl,r=l.createPerspective(e),n=l.createOrtho(e),o=l.createProject(e),s=l.createPickPerspective(e),c=l.createPickOrtho(e),u=l.createPickProject(e),h=i(e),f=i(e),p=i(e),d=i(e),g=a(e,[{buffer:h,size:3,type:e.FLOAT},{buffer:f,size:4,type:e.FLOAT},{buffer:p,size:2,type:e.FLOAT},{buffer:d,size:4,type:e.UNSIGNED_BYTE,normalized:!0}]),m=new v(e,r,n,o,h,f,p,d,g,s,c,u);return m.update(t),m};var m=v.prototype;m.pickSlots=1,m.setPickBase=function(t){this.pickId=t},m.isTransparent=function(){if(this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&this.projectHasAlpha)return!0;return!1},m.isOpaque=function(){if(!this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&!this.projectHasAlpha)return!0;return!1};var y=[0,0],x=[0,0,0],b=[0,0,0],_=[0,0,0,1],w=[0,0,0,1],k=h.slice(),T=[0,0,0],A=[[0,0,0],[0,0,0]];function M(t){return t[0]=t[1]=t[2]=0,t}function S(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=1,t}function E(t,e,r,n){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[r]=n,t}function C(t,e,r,n){var i,a=e.axesProject,o=e.gl,l=t.uniforms,c=r.model||h,u=r.view||h,f=r.projection||h,d=e.axesBounds,g=function(t){for(var e=A,r=0;r<2;++r)for(var n=0;n<3;++n)e[r][n]=Math.max(Math.min(t[r][n],1e8),-1e8);return e}(e.clipBounds);i=e.axes&&e.axes.lastCubeProps?e.axes.lastCubeProps.axis:[1,1,1],y[0]=2/o.drawingBufferWidth,y[1]=2/o.drawingBufferHeight,t.bind(),l.view=u,l.projection=f,l.screenSize=y,l.highlightId=e.highlightId,l.highlightScale=e.highlightScale,l.clipBounds=g,l.pickGroup=e.pickId/255,l.pixelRatio=n;for(var v=0;v<3;++v)if(a[v]){l.scale=e.projectScale[v],l.opacity=e.projectOpacity[v];for(var m=k,C=0;C<16;++C)m[C]=0;for(C=0;C<4;++C)m[5*C]=1;m[5*v]=0,i[v]<0?m[12+v]=d[0][v]:m[12+v]=d[1][v],s(m,c,m),l.model=m;var L=(v+1)%3,P=(v+2)%3,O=M(x),z=M(b);O[L]=1,z[P]=1;var I=p(0,0,0,S(_,O)),D=p(0,0,0,S(w,z));if(Math.abs(I[1])>Math.abs(D[1])){var R=I;I=D,D=R,R=O,O=z,z=R;var F=L;L=P,P=F}I[0]<0&&(O[L]=-1),D[1]>0&&(z[P]=-1);var B=0,N=0;for(C=0;C<4;++C)B+=Math.pow(c[4*L+C],2),N+=Math.pow(c[4*P+C],2);O[L]/=Math.sqrt(B),z[P]/=Math.sqrt(N),l.axes[0]=O,l.axes[1]=z,l.fragClipBounds[0]=E(T,g[0],v,-1e8),l.fragClipBounds[1]=E(T,g[1],v,1e8),e.vao.bind(),e.vao.draw(o.TRIANGLES,e.vertexCount),e.lineWidth>0&&(o.lineWidth(e.lineWidth*n),e.vao.draw(o.LINES,e.lineVertexCount,e.vertexCount)),e.vao.unbind()}}var L=[[-1e8,-1e8,-1e8],[1e8,1e8,1e8]];function P(t,e,r,n,i,a,o){var s=r.gl;if((a===r.projectHasAlpha||o)&&C(e,r,n,i),a===r.hasAlpha||o){t.bind();var l=t.uniforms;l.model=n.model||h,l.view=n.view||h,l.projection=n.projection||h,y[0]=2/s.drawingBufferWidth,y[1]=2/s.drawingBufferHeight,l.screenSize=y,l.highlightId=r.highlightId,l.highlightScale=r.highlightScale,l.fragClipBounds=L,l.clipBounds=r.axes.bounds,l.opacity=r.opacity,l.pickGroup=r.pickId/255,l.pixelRatio=i,r.vao.bind(),r.vao.draw(s.TRIANGLES,r.vertexCount),r.lineWidth>0&&(s.lineWidth(r.lineWidth*i),r.vao.draw(s.LINES,r.lineVertexCount,r.vertexCount)),r.vao.unbind()}}function O(t,e,r,i){var a;a=Array.isArray(t)?e<t.length?t[e]:void 0:t,a=u(a);var o=!0;n(a)&&(a=\"\\u25bc\",o=!1);var s=c(a,r,i);return{mesh:s[0],lines:s[1],bounds:s[2],visible:o}}m.draw=function(t){P(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!1,!1)},m.drawTransparent=function(t){P(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!0,!1)},m.drawPick=function(t){P(this.useOrtho?this.pickOrthoShader:this.pickPerspectiveShader,this.pickProjectShader,this,t,1,!0,!0)},m.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[2]+(t.value[1]<<8)+(t.value[0]<<16);if(e>=this.pointCount||e<0)return null;var r=this.points[e],n=this._selectResult;n.index=e;for(var i=0;i<3;++i)n.position[i]=n.dataCoordinate[i]=r[i];return n},m.highlight=function(t){if(t){var e=t.index,r=255&e,n=e>>8&255,i=e>>16&255;this.highlightId=[r/255,n/255,i/255,0]}else this.highlightId=[1,1,1,1]},m.update=function(t){if(\"perspective\"in(t=t||{})&&(this.useOrtho=!t.perspective),\"orthographic\"in t&&(this.useOrtho=!!t.orthographic),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"project\"in t)if(Array.isArray(t.project))this.axesProject=t.project;else{var e=!!t.project;this.axesProject=[e,e,e]}if(\"projectScale\"in t)if(Array.isArray(t.projectScale))this.projectScale=t.projectScale.slice();else{var r=+t.projectScale;this.projectScale=[r,r,r]}if(this.projectHasAlpha=!1,\"projectOpacity\"in t){if(Array.isArray(t.projectOpacity))this.projectOpacity=t.projectOpacity.slice();else{r=+t.projectOpacity;this.projectOpacity=[r,r,r]}for(var n=0;n<3;++n)this.projectOpacity[n]=g(this.projectOpacity[n]),this.projectOpacity[n]<1&&(this.projectHasAlpha=!0)}this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=g(t.opacity),this.opacity<1&&(this.hasAlpha=!0)),this.dirty=!0;var i,a,s=t.position,l=t.font||\"normal\",c=t.alignment||[0,0];if(2===c.length)i=c[0],a=c[1];else{i=[],a=[];for(n=0;n<c.length;++n)i[n]=c[n][0],a[n]=c[n][1]}var u=[1/0,1/0,1/0],h=[-1/0,-1/0,-1/0],f=t.glyph,p=t.color,d=t.size,v=t.angle,m=t.lineColor,y=-1,x=0,b=0,_=0;if(s.length){_=s.length;t:for(n=0;n<_;++n){for(var w=s[n],k=0;k<3;++k)if(isNaN(w[k])||!isFinite(w[k]))continue t;var T=(N=O(f,n,l,this.pixelRatio)).mesh,A=N.lines,M=N.bounds;x+=3*T.cells.length,b+=2*A.edges.length}}var S=x+b,E=o.mallocFloat(3*S),C=o.mallocFloat(4*S),L=o.mallocFloat(2*S),P=o.mallocUint32(S);if(S>0){var z=0,I=x,D=[0,0,0,1],R=[0,0,0,1],F=Array.isArray(p)&&Array.isArray(p[0]),B=Array.isArray(m)&&Array.isArray(m[0]);t:for(n=0;n<_;++n){y+=1;for(w=s[n],k=0;k<3;++k){if(isNaN(w[k])||!isFinite(w[k]))continue t;h[k]=Math.max(h[k],w[k]),u[k]=Math.min(u[k],w[k])}T=(N=O(f,n,l,this.pixelRatio)).mesh,A=N.lines,M=N.bounds;var N,j=N.visible;if(j)if(Array.isArray(p)){if(3===(U=F?n<p.length?p[n]:[0,0,0,0]:p).length){for(k=0;k<3;++k)D[k]=U[k];D[3]=1}else if(4===U.length){for(k=0;k<4;++k)D[k]=U[k];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else D[0]=D[1]=D[2]=0,D[3]=1;else D=[1,1,1,0];if(j)if(Array.isArray(m)){var U;if(3===(U=B?n<m.length?m[n]:[0,0,0,0]:m).length){for(k=0;k<3;++k)R[k]=U[k];R[k]=1}else if(4===U.length){for(k=0;k<4;++k)R[k]=U[k];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else R[0]=R[1]=R[2]=0,R[3]=1;else R=[1,1,1,0];var V=.5;j?Array.isArray(d)?V=n<d.length?+d[n]:12:d?V=+d:this.useOrtho&&(V=12):V=0;var q=0;Array.isArray(v)?q=n<v.length?+v[n]:0:v&&(q=+v);var H=Math.cos(q),G=Math.sin(q);for(w=s[n],k=0;k<3;++k)h[k]=Math.max(h[k],w[k]),u[k]=Math.min(u[k],w[k]);var Y=i,W=a;Y=0;Array.isArray(i)?Y=n<i.length?i[n]:0:i&&(Y=i);W=0;Array.isArray(a)?W=n<a.length?a[n]:0:a&&(W=a);var X=[Y*=Y>0?1-M[0][0]:Y<0?1+M[1][0]:1,W*=W>0?1-M[0][1]:W<0?1+M[1][1]:1],Z=T.cells||[],J=T.positions||[];for(k=0;k<Z.length;++k)for(var K=Z[k],$=0;$<3;++$){for(var Q=0;Q<3;++Q)E[3*z+Q]=w[Q];for(Q=0;Q<4;++Q)C[4*z+Q]=D[Q];P[z]=y;var tt=J[K[$]];L[2*z]=V*(H*tt[0]-G*tt[1]+X[0]),L[2*z+1]=V*(G*tt[0]+H*tt[1]+X[1]),z+=1}for(Z=A.edges,J=A.positions,k=0;k<Z.length;++k)for(K=Z[k],$=0;$<2;++$){for(Q=0;Q<3;++Q)E[3*I+Q]=w[Q];for(Q=0;Q<4;++Q)C[4*I+Q]=R[Q];P[I]=y;tt=J[K[$]];L[2*I]=V*(H*tt[0]-G*tt[1]+X[0]),L[2*I+1]=V*(G*tt[0]+H*tt[1]+X[1]),I+=1}}}this.bounds=[u,h],this.points=s,this.pointCount=s.length,this.vertexCount=x,this.lineVertexCount=b,this.pointBuffer.update(E),this.colorBuffer.update(C),this.glyphBuffer.update(L),this.idBuffer.update(P),o.free(E),o.free(C),o.free(L),o.free(P)},m.dispose=function(){this.shader.dispose(),this.orthoShader.dispose(),this.pickPerspectiveShader.dispose(),this.pickOrthoShader.dispose(),this.vao.dispose(),this.pointBuffer.dispose(),this.colorBuffer.dispose(),this.glyphBuffer.dispose(),this.idBuffer.dispose()}},{\"./lib/get-simple-string\":294,\"./lib/glyphs\":295,\"./lib/shaders\":296,\"gl-buffer\":241,\"gl-mat4/multiply\":267,\"gl-vao\":327,\"is-string-blank\":423,\"typedarray-pool\":545}],298:[function(t,e,r){\"use strict\";var n=t(\"glslify\");r.boxVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 vertex;\\n\\nuniform vec2 cornerA, cornerB;\\n\\nvoid main() {\\n  gl_Position = vec4(mix(cornerA, cornerB, vertex), 0, 1);\\n}\\n\"]),r.boxFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\n\\nvoid main() {\\n  gl_FragColor = color;\\n}\\n\"])},{glslify:409}],299:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"./lib/shaders\");function o(t,e,r){this.plot=t,this.boxBuffer=e,this.boxShader=r,this.enabled=!0,this.selectBox=[1/0,1/0,-1/0,-1/0],this.borderColor=[0,0,0,1],this.innerFill=!1,this.innerColor=[0,0,0,.25],this.outerFill=!0,this.outerColor=[0,0,0,.5],this.borderWidth=10}e.exports=function(t,e){var r=t.gl,s=i(r,[0,0,0,1,1,0,1,1]),l=n(r,a.boxVertex,a.boxFragment),c=new o(t,s,l);return c.update(e),t.addOverlay(c),c};var s=o.prototype;s.draw=function(){if(this.enabled){var t=this.plot,e=this.selectBox,r=this.borderWidth,n=(this.innerFill,this.innerColor),i=(this.outerFill,this.outerColor),a=this.borderColor,o=t.box,s=t.screenBox,l=t.dataBox,c=t.viewBox,u=t.pixelRatio,h=(e[0]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],f=(e[1]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1],p=(e[2]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],d=(e[3]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1];if(h=Math.max(h,c[0]),f=Math.max(f,c[1]),p=Math.min(p,c[2]),d=Math.min(d,c[3]),!(p<h||d<f)){o.bind();var g=s[2]-s[0],v=s[3]-s[1];if(this.outerFill&&(o.drawBox(0,0,g,f,i),o.drawBox(0,f,h,d,i),o.drawBox(0,d,g,v,i),o.drawBox(p,f,g,d,i)),this.innerFill&&o.drawBox(h,f,p,d,n),r>0){var m=r*u;o.drawBox(h-m,f-m,p+m,f+m,a),o.drawBox(h-m,d-m,p+m,d+m,a),o.drawBox(h-m,f-m,h+m,d+m,a),o.drawBox(p-m,f-m,p+m,d+m,a)}}}},s.update=function(t){t=t||{},this.innerFill=!!t.innerFill,this.outerFill=!!t.outerFill,this.innerColor=(t.innerColor||[0,0,0,.5]).slice(),this.outerColor=(t.outerColor||[0,0,0,.5]).slice(),this.borderColor=(t.borderColor||[0,0,0,1]).slice(),this.borderWidth=t.borderWidth||0,this.selectBox=(t.selectBox||this.selectBox).slice()},s.dispose=function(){this.boxBuffer.dispose(),this.boxShader.dispose(),this.plot.removeOverlay(this)}},{\"./lib/shaders\":298,\"gl-buffer\":241,\"gl-shader\":301}],300:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=n(t,e),a=i.mallocUint8(e[0]*e[1]*4);return new c(t,r,a)};var n=t(\"gl-fbo\"),i=t(\"typedarray-pool\"),a=t(\"ndarray\"),o=t(\"bit-twiddle\").nextPow2,s=t(\"cwise/lib/wrapper\")({args:[\"array\",{offset:[0,0,1],array:0},{offset:[0,0,2],array:0},{offset:[0,0,3],array:0},\"scalar\",\"scalar\",\"index\"],pre:{body:\"{this_closestD2=1e8,this_closestX=-1,this_closestY=-1}\",args:[],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[]},body:{body:\"{if(_inline_16_arg0_<255||_inline_16_arg1_<255||_inline_16_arg2_<255||_inline_16_arg3_<255){var _inline_16_l=_inline_16_arg4_-_inline_16_arg6_[0],_inline_16_a=_inline_16_arg5_-_inline_16_arg6_[1],_inline_16_f=_inline_16_l*_inline_16_l+_inline_16_a*_inline_16_a;_inline_16_f<this_closestD2&&(this_closestD2=_inline_16_f,this_closestX=_inline_16_arg6_[0],this_closestY=_inline_16_arg6_[1])}}\",args:[{name:\"_inline_16_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg4_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg5_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg6_\",lvalue:!1,rvalue:!0,count:4}],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[\"_inline_16_a\",\"_inline_16_f\",\"_inline_16_l\"]},post:{body:\"{return[this_closestX,this_closestY,this_closestD2]}\",args:[],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[]},debug:!1,funcName:\"cwise\",blockSize:64});function l(t,e,r,n,i){this.coord=[t,e],this.id=r,this.value=n,this.distance=i}function c(t,e,r){this.gl=t,this.fbo=e,this.buffer=r,this._readTimeout=null;var n=this;this._readCallback=function(){n.gl&&(e.bind(),t.readPixels(0,0,e.shape[0],e.shape[1],t.RGBA,t.UNSIGNED_BYTE,n.buffer),n._readTimeout=null)}}var u=c.prototype;Object.defineProperty(u,\"shape\",{get:function(){return this.gl?this.fbo.shape.slice():[0,0]},set:function(t){if(this.gl){this.fbo.shape=t;var e=this.fbo.shape[0],r=this.fbo.shape[1];if(r*e*4>this.buffer.length){i.free(this.buffer);for(var n=this.buffer=i.mallocUint8(o(r*e*4)),a=0;a<r*e*4;++a)n[a]=255}return t}}}),u.begin=function(){var t=this.gl;this.shape;t&&(this.fbo.bind(),t.clearColor(1,1,1,1),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT))},u.end=function(){var t=this.gl;t&&(t.bindFramebuffer(t.FRAMEBUFFER,null),this._readTimeout||clearTimeout(this._readTimeout),this._readTimeout=setTimeout(this._readCallback,1))},u.query=function(t,e,r){if(!this.gl)return null;var n=this.fbo.shape.slice();t|=0,e|=0,\"number\"!=typeof r&&(r=1);var i=0|Math.min(Math.max(t-r,0),n[0]),o=0|Math.min(Math.max(t+r,0),n[0]),c=0|Math.min(Math.max(e-r,0),n[1]),u=0|Math.min(Math.max(e+r,0),n[1]);if(o<=i||u<=c)return null;var h=[o-i,u-c],f=a(this.buffer,[h[0],h[1],4],[4,4*n[0],1],4*(i+n[0]*c)),p=s(f.hi(h[0],h[1],1),r,r),d=p[0],g=p[1];return d<0||Math.pow(this.radius,2)<p[2]?null:new l(d+i|0,g+c|0,f.get(d,g,0),[f.get(d,g,1),f.get(d,g,2),f.get(d,g,3)],Math.sqrt(p[2]))},u.dispose=function(){this.gl&&(this.fbo.dispose(),i.free(this.buffer),this.gl=null,this._readTimeout&&clearTimeout(this._readTimeout))}},{\"bit-twiddle\":92,\"cwise/lib/wrapper\":149,\"gl-fbo\":249,ndarray:450,\"typedarray-pool\":545}],301:[function(t,e,r){\"use strict\";var n=t(\"./lib/create-uniforms\"),i=t(\"./lib/create-attributes\"),a=t(\"./lib/reflect\"),o=t(\"./lib/shader-cache\"),s=t(\"./lib/runtime-reflect\"),l=t(\"./lib/GLError\");function c(t){this.gl=t,this.gl.lastAttribCount=0,this._vref=this._fref=this._relink=this.vertShader=this.fragShader=this.program=this.attributes=this.uniforms=this.types=null}var u=c.prototype;function h(t,e){return t.name<e.name?-1:1}u.bind=function(){var t;this.program||this._relink();var e=this.gl.getProgramParameter(this.program,this.gl.ACTIVE_ATTRIBUTES),r=this.gl.lastAttribCount;if(e>r)for(t=r;t<e;t++)this.gl.enableVertexAttribArray(t);else if(r>e)for(t=e;t<r;t++)this.gl.disableVertexAttribArray(t);this.gl.lastAttribCount=e,this.gl.useProgram(this.program)},u.dispose=function(){for(var t=this.gl.lastAttribCount,e=0;e<t;e++)this.gl.disableVertexAttribArray(e);this.gl.lastAttribCount=0,this._fref&&this._fref.dispose(),this._vref&&this._vref.dispose(),this.attributes=this.types=this.vertShader=this.fragShader=this.program=this._relink=this._fref=this._vref=null},u.update=function(t,e,r,c){if(!e||1===arguments.length){var u=t;t=u.vertex,e=u.fragment,r=u.uniforms,c=u.attributes}var f=this,p=f.gl,d=f._vref;f._vref=o.shader(p,p.VERTEX_SHADER,t),d&&d.dispose(),f.vertShader=f._vref.shader;var g=this._fref;if(f._fref=o.shader(p,p.FRAGMENT_SHADER,e),g&&g.dispose(),f.fragShader=f._fref.shader,!r||!c){var v=p.createProgram();if(p.attachShader(v,f.fragShader),p.attachShader(v,f.vertShader),p.linkProgram(v),!p.getProgramParameter(v,p.LINK_STATUS)){var m=p.getProgramInfoLog(v);throw new l(m,\"Error linking program:\"+m)}r=r||s.uniforms(p,v),c=c||s.attributes(p,v),p.deleteProgram(v)}(c=c.slice()).sort(h);var y,x=[],b=[],_=[];for(y=0;y<c.length;++y){var w=c[y];if(w.type.indexOf(\"mat\")>=0){for(var k=0|w.type.charAt(w.type.length-1),T=new Array(k),A=0;A<k;++A)T[A]=_.length,b.push(w.name+\"[\"+A+\"]\"),\"number\"==typeof w.location?_.push(w.location+A):Array.isArray(w.location)&&w.location.length===k&&\"number\"==typeof w.location[A]?_.push(0|w.location[A]):_.push(-1);x.push({name:w.name,type:w.type,locations:T})}else x.push({name:w.name,type:w.type,locations:[_.length]}),b.push(w.name),\"number\"==typeof w.location?_.push(0|w.location):_.push(-1)}var M=0;for(y=0;y<_.length;++y)if(_[y]<0){for(;_.indexOf(M)>=0;)M+=1;_[y]=M}var S=new Array(r.length);function E(){f.program=o.program(p,f._vref,f._fref,b,_);for(var t=0;t<r.length;++t)S[t]=p.getUniformLocation(f.program,r[t].name)}E(),f._relink=E,f.types={uniforms:a(r),attributes:a(c)},f.attributes=i(p,f,x,_),Object.defineProperty(f,\"uniforms\",n(p,f,r,S))},e.exports=function(t,e,r,n,i){var a=new c(t);return a.update(e,r,n,i),a}},{\"./lib/GLError\":302,\"./lib/create-attributes\":303,\"./lib/create-uniforms\":304,\"./lib/reflect\":305,\"./lib/runtime-reflect\":306,\"./lib/shader-cache\":307}],302:[function(t,e,r){function n(t,e,r){this.shortMessage=e||\"\",this.longMessage=r||\"\",this.rawError=t||\"\",this.message=\"gl-shader: \"+(e||t||\"\")+(r?\"\\n\"+r:\"\"),this.stack=(new Error).stack}n.prototype=new Error,n.prototype.name=\"GLError\",n.prototype.constructor=n,e.exports=n},{}],303:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){for(var a={},l=0,c=r.length;l<c;++l){var u=r[l],h=u.name,f=u.type,p=u.locations;switch(f){case\"bool\":case\"int\":case\"float\":o(t,e,p[0],i,1,a,h);break;default:if(f.indexOf(\"vec\")>=0){var d=f.charCodeAt(f.length-1)-48;if(d<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+h+\": \"+f);o(t,e,p[0],i,d,a,h)}else{if(!(f.indexOf(\"mat\")>=0))throw new n(\"\",\"Unknown data type for attribute \"+h+\": \"+f);var d=f.charCodeAt(f.length-1)-48;if(d<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+h+\": \"+f);s(t,e,p,i,d,a,h)}}}return a};var n=t(\"./GLError\");function i(t,e,r,n,i,a){this._gl=t,this._wrapper=e,this._index=r,this._locations=n,this._dimension=i,this._constFunc=a}var a=i.prototype;function o(t,e,r,n,a,o,s){for(var l=[\"gl\",\"v\"],c=[],u=0;u<a;++u)l.push(\"x\"+u),c.push(\"x\"+u);l.push(\"if(x0.length===void 0){return gl.vertexAttrib\"+a+\"f(v,\"+c.join()+\")}else{return gl.vertexAttrib\"+a+\"fv(v,x0)}\");var h=Function.apply(null,l),f=new i(t,e,r,n,a,h);Object.defineProperty(o,s,{set:function(e){return t.disableVertexAttribArray(n[r]),h(t,n[r],e),e},get:function(){return f},enumerable:!0})}function s(t,e,r,n,i,a,s){for(var l=new Array(i),c=new Array(i),u=0;u<i;++u)o(t,e,r[u],n,i,l,u),c[u]=l[u];Object.defineProperty(l,\"location\",{set:function(t){if(Array.isArray(t))for(var e=0;e<i;++e)c[e].location=t[e];else for(e=0;e<i;++e)c[e].location=t+e;return t},get:function(){for(var t=new Array(i),e=0;e<i;++e)t[e]=n[r[e]];return t},enumerable:!0}),l.pointer=function(e,a,o,s){e=e||t.FLOAT,a=!!a,o=o||i*i,s=s||0;for(var l=0;l<i;++l){var c=n[r[l]];t.vertexAttribPointer(c,i,e,a,o,s+l*i),t.enableVertexAttribArray(c)}};var h=new Array(i),f=t[\"vertexAttrib\"+i+\"fv\"];Object.defineProperty(a,s,{set:function(e){for(var a=0;a<i;++a){var o=n[r[a]];if(t.disableVertexAttribArray(o),Array.isArray(e[0]))f.call(t,o,e[a]);else{for(var s=0;s<i;++s)h[s]=e[i*a+s];f.call(t,o,h)}}return e},get:function(){return l},enumerable:!0})}a.pointer=function(t,e,r,n){var i=this._gl,a=this._locations[this._index];i.vertexAttribPointer(a,this._dimension,t||i.FLOAT,!!e,r||0,n||0),i.enableVertexAttribArray(a)},a.set=function(t,e,r,n){return this._constFunc(this._locations[this._index],t,e,r,n)},Object.defineProperty(a,\"location\",{get:function(){return this._locations[this._index]},set:function(t){return t!==this._locations[this._index]&&(this._locations[this._index]=0|t,this._wrapper.program=null),0|t}})},{\"./GLError\":302}],304:[function(t,e,r){\"use strict\";var n=t(\"./reflect\"),i=t(\"./GLError\");function a(t){return new Function(\"y\",\"return function(){return y}\")(t)}function o(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}e.exports=function(t,e,r,s){function l(t,e,r){switch(r){case\"bool\":case\"int\":case\"sampler2D\":case\"samplerCube\":return\"gl.uniform1i(locations[\"+e+\"],obj\"+t+\")\";case\"float\":return\"gl.uniform1f(locations[\"+e+\"],obj\"+t+\")\";default:var n=r.indexOf(\"vec\");if(!(0<=n&&n<=1&&r.length===4+n)){if(0===r.indexOf(\"mat\")&&4===r.length){var a=r.charCodeAt(r.length-1)-48;if(a<2||a>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+r);return\"gl.uniformMatrix\"+a+\"fv(locations[\"+e+\"],false,obj\"+t+\")\"}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+r)}var a=r.charCodeAt(r.length-1)-48;if(a<2||a>4)throw new i(\"\",\"Invalid data type\");switch(r.charAt(0)){case\"b\":case\"i\":return\"gl.uniform\"+a+\"iv(locations[\"+e+\"],obj\"+t+\")\";case\"v\":return\"gl.uniform\"+a+\"fv(locations[\"+e+\"],obj\"+t+\")\";default:throw new i(\"\",\"Unrecognized data type for vector \"+name+\": \"+r)}}}function c(e){for(var n=[\"return function updateProperty(obj){\"],i=function t(e,r){if(\"object\"!=typeof r)return[[e,r]];var n=[];for(var i in r){var a=r[i],o=e;parseInt(i)+\"\"===i?o+=\"[\"+i+\"]\":o+=\".\"+i,\"object\"==typeof a?n.push.apply(n,t(o,a)):n.push([o,a])}return n}(\"\",e),a=0;a<i.length;++a){var o=i[a],c=o[0],u=o[1];s[u]&&n.push(l(c,u,r[u].type))}n.push(\"return obj}\");var h=new Function(\"gl\",\"locations\",n.join(\"\\n\"));return h(t,s)}function u(n,l,u){if(\"object\"==typeof u){var f=h(u);Object.defineProperty(n,l,{get:a(f),set:c(u),enumerable:!0,configurable:!1})}else s[u]?Object.defineProperty(n,l,{get:(p=u,new Function(\"gl\",\"wrapper\",\"locations\",\"return function(){return gl.getUniform(wrapper.program,locations[\"+p+\"])}\")(t,e,s)),set:c(u),enumerable:!0,configurable:!1}):n[l]=function(t){switch(t){case\"bool\":return!1;case\"int\":case\"sampler2D\":case\"samplerCube\":case\"float\":return 0;default:var e=t.indexOf(\"vec\");if(0<=e&&e<=1&&t.length===4+e){var r=t.charCodeAt(t.length-1)-48;if(r<2||r>4)throw new i(\"\",\"Invalid data type\");return\"b\"===t.charAt(0)?o(r,!1):o(r,0)}if(0===t.indexOf(\"mat\")&&4===t.length){var r=t.charCodeAt(t.length-1)-48;if(r<2||r>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+t);return o(r*r,0)}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+t)}}(r[u].type);var p}function h(t){var e;if(Array.isArray(t)){e=new Array(t.length);for(var r=0;r<t.length;++r)u(e,r,t[r])}else for(var n in e={},t)u(e,n,t[n]);return e}var f=n(r,!0);return{get:a(h(f)),set:c(f),enumerable:!0,configurable:!0}}},{\"./GLError\":302,\"./reflect\":305}],305:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r={},n=0;n<t.length;++n)for(var i=t[n].name,a=i.split(\".\"),o=r,s=0;s<a.length;++s){var l=a[s].split(\"[\");if(l.length>1){l[0]in o||(o[l[0]]=[]),o=o[l[0]];for(var c=1;c<l.length;++c){var u=parseInt(l[c]);c<l.length-1||s<a.length-1?(u in o||(c<l.length-1?o[u]=[]:o[u]={}),o=o[u]):o[u]=e?n:t[n].type}}else s<a.length-1?(l[0]in o||(o[l[0]]={}),o=o[l[0]]):o[l[0]]=e?n:t[n].type}return r}},{}],306:[function(t,e,r){\"use strict\";r.uniforms=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_UNIFORMS),n=[],i=0;i<r;++i){var o=t.getActiveUniform(e,i);if(o){var s=a(t,o.type);if(o.size>1)for(var l=0;l<o.size;++l)n.push({name:o.name.replace(\"[0]\",\"[\"+l+\"]\"),type:s});else n.push({name:o.name,type:s})}}return n},r.attributes=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_ATTRIBUTES),n=[],i=0;i<r;++i){var o=t.getActiveAttrib(e,i);o&&n.push({name:o.name,type:a(t,o.type)})}return n};var n={FLOAT:\"float\",FLOAT_VEC2:\"vec2\",FLOAT_VEC3:\"vec3\",FLOAT_VEC4:\"vec4\",INT:\"int\",INT_VEC2:\"ivec2\",INT_VEC3:\"ivec3\",INT_VEC4:\"ivec4\",BOOL:\"bool\",BOOL_VEC2:\"bvec2\",BOOL_VEC3:\"bvec3\",BOOL_VEC4:\"bvec4\",FLOAT_MAT2:\"mat2\",FLOAT_MAT3:\"mat3\",FLOAT_MAT4:\"mat4\",SAMPLER_2D:\"sampler2D\",SAMPLER_CUBE:\"samplerCube\"},i=null;function a(t,e){if(!i){var r=Object.keys(n);i={};for(var a=0;a<r.length;++a){var o=r[a];i[t[o]]=n[o]}}return i[e]}},{}],307:[function(t,e,r){\"use strict\";r.shader=function(t,e,r){return u(t).getShaderReference(e,r)},r.program=function(t,e,r,n,i){return u(t).getProgram(e,r,n,i)};var n=t(\"./GLError\"),i=t(\"gl-format-compiler-error\"),a=new(\"undefined\"==typeof WeakMap?t(\"weakmap-shim\"):WeakMap),o=0;function s(t,e,r,n,i,a,o){this.id=t,this.src=e,this.type=r,this.shader=n,this.count=a,this.programs=[],this.cache=o}function l(t){this.gl=t,this.shaders=[{},{}],this.programs={}}s.prototype.dispose=function(){if(0==--this.count){for(var t=this.cache,e=t.gl,r=this.programs,n=0,i=r.length;n<i;++n){var a=t.programs[r[n]];a&&(delete t.programs[n],e.deleteProgram(a))}e.deleteShader(this.shader),delete t.shaders[this.type===e.FRAGMENT_SHADER|0][this.src]}};var c=l.prototype;function u(t){var e=a.get(t);return e||(e=new l(t),a.set(t,e)),e}c.getShaderReference=function(t,e){var r=this.gl,a=this.shaders[t===r.FRAGMENT_SHADER|0],l=a[e];if(l&&r.isShader(l.shader))l.count+=1;else{var c=function(t,e,r){var a=t.createShader(e);if(t.shaderSource(a,r),t.compileShader(a),!t.getShaderParameter(a,t.COMPILE_STATUS)){var o=t.getShaderInfoLog(a);try{var s=i(o,r,e)}catch(t){throw console.warn(\"Failed to format compiler error: \"+t),new n(o,\"Error compiling shader:\\n\"+o)}throw new n(o,s.short,s.long)}return a}(r,t,e);l=a[e]=new s(o++,e,t,c,[],1,this)}return l},c.getProgram=function(t,e,r,i){var a=[t.id,e.id,r.join(\":\"),i.join(\":\")].join(\"@\"),o=this.programs[a];return o&&this.gl.isProgram(o)||(this.programs[a]=o=function(t,e,r,i,a){var o=t.createProgram();t.attachShader(o,e),t.attachShader(o,r);for(var s=0;s<i.length;++s)t.bindAttribLocation(o,a[s],i[s]);if(t.linkProgram(o),!t.getProgramParameter(o,t.LINK_STATUS)){var l=t.getProgramInfoLog(o);throw new n(l,\"Error linking program: \"+l)}return o}(this.gl,t.shader,e.shader,r,i),t.programs.push(a),e.programs.push(a)),o}},{\"./GLError\":302,\"gl-format-compiler-error\":250,\"weakmap-shim\":555}],308:[function(t,e,r){\"use strict\";function n(t){this.plot=t,this.enable=[!0,!0,!1,!1],this.width=[1,1,1,1],this.color=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.center=[1/0,1/0]}e.exports=function(t,e){var r=new n(t);return r.update(e),t.addOverlay(r),r};var i=n.prototype;i.update=function(t){t=t||{},this.enable=(t.enable||[!0,!0,!1,!1]).slice(),this.width=(t.width||[1,1,1,1]).slice(),this.color=(t.color||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]).map(function(t){return t.slice()}),this.center=(t.center||[1/0,1/0]).slice(),this.plot.setOverlayDirty()},i.draw=function(){var t=this.enable,e=this.width,r=this.color,n=this.center,i=this.plot,a=i.line,o=i.dataBox,s=i.viewBox;if(a.bind(),o[0]<=n[0]&&n[0]<=o[2]&&o[1]<=n[1]&&n[1]<=o[3]){var l=s[0]+(n[0]-o[0])/(o[2]-o[0])*(s[2]-s[0]),c=s[1]+(n[1]-o[1])/(o[3]-o[1])*(s[3]-s[1]);t[0]&&a.drawLine(l,c,s[0],c,e[0],r[0]),t[1]&&a.drawLine(l,c,l,s[1],e[1],r[1]),t[2]&&a.drawLine(l,c,s[2],c,e[2],r[2]),t[3]&&a.drawLine(l,c,l,s[3],e[3],r[3])}},i.dispose=function(){this.plot.removeOverlay(this)}},{}],309:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, color;\\nattribute float weight;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 coordinates[3];\\nuniform vec4 colors[3];\\nuniform vec2 screenShape;\\nuniform float lineWidth;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vertexPosition = mix(coordinates[0],\\n    mix(coordinates[2], coordinates[1], 0.5 * (position + 1.0)), abs(position));\\n\\n  vec4 clipPos = projection * view * model * vec4(vertexPosition, 1.0);\\n  vec2 clipOffset = (projection * view * model * vec4(color, 0.0)).xy;\\n  vec2 delta = weight * clipOffset * screenShape;\\n  vec2 lineOffset = normalize(vec2(delta.y, -delta.x)) / screenShape;\\n\\n  gl_Position   = vec4(clipPos.xy + clipPos.w * 0.5 * lineWidth * lineOffset, clipPos.z, clipPos.w);\\n  fragColor     = color.x * colors[0] + color.y * colors[1] + color.z * colors[2];\\n}\\n\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  gl_FragColor = fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec3\"},{name:\"weight\",type:\"float\"}])}},{\"gl-shader\":301,glslify:409}],310:[function(t,e,r){\"use strict\";var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\");e.exports=function(t,e){var r=[];function o(t,e,n,i,a,o){var s=[t,e,n,0,0,0,1];s[i+3]=1,s[i]=a,r.push.apply(r,s),s[6]=-1,r.push.apply(r,s),s[i]=o,r.push.apply(r,s),r.push.apply(r,s),s[6]=1,r.push.apply(r,s),s[i]=a,r.push.apply(r,s)}o(0,0,0,0,0,1),o(0,0,0,1,0,1),o(0,0,0,2,0,1),o(1,0,0,1,-1,1),o(1,0,0,2,-1,1),o(0,1,0,0,-1,1),o(0,1,0,2,-1,1),o(0,0,1,0,-1,1),o(0,0,1,1,-1,1);var l=n(t,r),c=i(t,[{type:t.FLOAT,buffer:l,size:3,offset:0,stride:28},{type:t.FLOAT,buffer:l,size:3,offset:12,stride:28},{type:t.FLOAT,buffer:l,size:1,offset:24,stride:28}]),u=a(t);u.attributes.position.location=0,u.attributes.color.location=1,u.attributes.weight.location=2;var h=new s(t,l,c,u);return h.update(e),h};var o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n,this.pixelRatio=1,this.bounds=[[-1e3,-1e3,-1e3],[1e3,1e3,1e3]],this.position=[0,0,0],this.lineWidth=[2,2,2],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.enabled=[!0,!0,!0],this.drawSides=[!0,!0,!0],this.axes=null}var l=s.prototype,c=[0,0,0],u=[0,0,0],h=[0,0];l.isTransparent=function(){return!1},l.drawTransparent=function(t){},l.draw=function(t){var e=this.gl,r=this.vao,n=this.shader;r.bind(),n.bind();var i,a=t.model||o,s=t.view||o,l=t.projection||o;this.axes&&(i=this.axes.lastCubeProps.axis);for(var f=c,p=u,d=0;d<3;++d)i&&i[d]<0?(f[d]=this.bounds[0][d],p[d]=this.bounds[1][d]):(f[d]=this.bounds[1][d],p[d]=this.bounds[0][d]);h[0]=e.drawingBufferWidth,h[1]=e.drawingBufferHeight,n.uniforms.model=a,n.uniforms.view=s,n.uniforms.projection=l,n.uniforms.coordinates=[this.position,f,p],n.uniforms.colors=this.colors,n.uniforms.screenShape=h;for(d=0;d<3;++d)n.uniforms.lineWidth=this.lineWidth[d]*this.pixelRatio,this.enabled[d]&&(r.draw(e.TRIANGLES,6,6*d),this.drawSides[d]&&r.draw(e.TRIANGLES,12,18+12*d));r.unbind()},l.update=function(t){t&&(\"bounds\"in t&&(this.bounds=t.bounds),\"position\"in t&&(this.position=t.position),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"colors\"in t&&(this.colors=t.colors),\"enabled\"in t&&(this.enabled=t.enabled),\"drawSides\"in t&&(this.drawSides=t.drawSides))},l.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders/index\":309,\"gl-buffer\":241,\"gl-vao\":327}],311:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\nuniform float vectorScale;\\nuniform float tubeScale;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * tubePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal,0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(tubePosition, 1.0);\\n  vec4 t_position  = view * tubePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = tubePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular\\n            , opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform float tubeScale;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  gl_Position = projection * view * tubePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec4\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec4\"}]}},{glslify:409}],312:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./shaders\"),g=d.meshShader,v=d.pickShader,m=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function y(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,y,x,b,_,w,k,T){this.gl=t,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=i,this.triangleVectors=a,this.triangleColors=s,this.triangleNormals=c,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=u,this.triangleCount=0,this.lineWidth=1,this.edgePositions=h,this.edgeColors=p,this.edgeUVs=d,this.edgeIds=f,this.edgeVAO=g,this.edgeCount=0,this.pointPositions=v,this.pointColors=x,this.pointUVs=b,this.pointSizes=_,this.pointIds=y,this.pointVAO=w,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=k,this.contourVAO=T,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!1,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.tubeScale=1,this._model=m,this._view=m,this._projection=m,this._resolution=[1,1],this.pixelRatio=1}var x=y.prototype;function b(t){var e=n(t,v.vertex,v.fragment,null,v.attributes);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.vector.location=5,e}x.isOpaque=function(){return this.opacity>=1},x.isTransparent=function(){return this.opacity<1},x.pickSlots=1,x.setPickBase=function(t){this.pickId=t},x.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=i[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},x.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=h({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return u(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,i=t.vectors;if(n&&r&&i){void 0!==t.tubeScale&&(this.tubeScale=t.tubeScale);var a=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[],w=[],k=[];this.cells=r,this.positions=n,this.vectors=i;var T=t.vertexNormals,A=t.cellNormals,M=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,S=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!A&&(A=s.faceNormals(r,n,S)),A||T||(T=s.vertexNormals(r,n,M));var E=t.vertexColors,C=t.cellColors,L=t.meshColor||[1,1,1,1],P=t.vertexUVs,O=t.vertexIntensity,z=t.cellUVs,I=t.cellIntensity,D=1/0,R=-1/0;if(!P&&!z)if(O)if(t.vertexIntensityBounds)D=+t.vertexIntensityBounds[0],R=+t.vertexIntensityBounds[1];else for(var F=0;F<O.length;++F){var B=O[F];D=Math.min(D,B),R=Math.max(R,B)}else if(I)for(F=0;F<I.length;++F){B=I[F];D=Math.min(D,B),R=Math.max(R,B)}else for(F=0;F<n.length;++F){B=n[F][2];D=Math.min(D,B),R=Math.max(R,B)}this.intensity=O||(I?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,I):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var N=t.pointSizes,j=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(F=0;F<n.length;++F)for(var U=n[F],V=0;V<3;++V)!isNaN(U[V])&&isFinite(U[V])&&(this.bounds[0][V]=Math.min(this.bounds[0][V],U[V]),this.bounds[1][V]=Math.max(this.bounds[1][V],U[V]));var q=0,H=0,G=0;t:for(F=0;F<r.length;++F){var Y=r[F];switch(Y.length){case 1:for(U=n[X=Y[0]],V=0;V<3;++V)if(isNaN(U[V])||!isFinite(U[V]))continue t;x.push(U[0],U[1],U[2],U[3]),3===(Z=E?E[X]:C?C[F]:L).length?b.push(Z[0],Z[1],Z[2],1):b.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],_.push(J[0],J[1]),N?w.push(N[X]):w.push(j),k.push(F),G+=1;break;case 2:for(V=0;V<2;++V){U=n[X=Y[V]];for(var W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t}for(V=0;V<2;++V){U=n[X=Y[V]];g.push(U[0],U[1],U[2]),3===(Z=E?E[X]:C?C[F]:L).length?v.push(Z[0],Z[1],Z[2],1):v.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],m.push(J[0],J[1]),y.push(F)}H+=1;break;case 3:for(V=0;V<3;++V)for(U=n[X=Y[V]],W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t;for(V=0;V<3;++V){var X;U=n[X=Y[2-V]];a.push(U[0],U[1],U[2],U[3]);var Z,J,K,$=i[X];l.push($[0],$[1],$[2],$[3]),3===(Z=E?E[X]:C?C[F]:L).length?c.push(Z[0],Z[1],Z[2],1):c.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],p.push(J[0],J[1]),K=T?T[X]:A[F],f.push(K[0],K[1],K[2]),d.push(F)}q+=1}}this.pointCount=G,this.edgeCount=H,this.triangleCount=q,this.pointPositions.update(x),this.pointColors.update(b),this.pointUVs.update(_),this.pointSizes.update(w),this.pointIds.update(new Uint32Array(k)),this.edgePositions.update(g),this.edgeColors.update(v),this.edgeUVs.update(m),this.edgeIds.update(new Uint32Array(y)),this.trianglePositions.update(a),this.triangleVectors.update(l),this.triangleColors.update(c),this.triangleUVs.update(p),this.triangleNormals.update(f),this.triangleIds.update(new Uint32Array(d))}},x.drawTransparent=x.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:m.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,tubeScale:this.tubeScale,contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var f=u[12+o],p=0;p<3;++p)f+=u[4*p+o]*this.lightPosition[p];s.lightPosition[o]=f/h}if(this.triangleCount>0){var d=this.triShader;d.bind(),d.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},x.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:i,clipBounds:a,tubeScale:this.tubeScale,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind())},x.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3);return{index:e,position:n,intensity:this.intensity[r[1]],velocity:this.vectors[r[1]].slice(0,3),divergence:this.vectors[r[1]][3],dataCoordinate:n}},x.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose()},e.exports=function(t,e){1===arguments.length&&(t=(e=t).gl);var r=e.triShader||function(t){var e=n(t,g.vertex,g.fragment,null,g.attributes);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.vector.location=5,e}(t),s=b(t),l=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));l.generateMipmap(),l.minFilter=t.LINEAR_MIPMAP_LINEAR,l.magFilter=t.LINEAR;var c=i(t),h=i(t),f=i(t),p=i(t),d=i(t),v=i(t),m=a(t,[{buffer:c,type:t.FLOAT,size:4},{buffer:v,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:f,type:t.FLOAT,size:4},{buffer:p,type:t.FLOAT,size:2},{buffer:d,type:t.FLOAT,size:3},{buffer:h,type:t.FLOAT,size:4}]),x=i(t),_=i(t),w=i(t),k=i(t),T=a(t,[{buffer:x,type:t.FLOAT,size:3},{buffer:k,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:_,type:t.FLOAT,size:4},{buffer:w,type:t.FLOAT,size:2}]),A=i(t),M=i(t),S=i(t),E=i(t),C=i(t),L=a(t,[{buffer:A,type:t.FLOAT,size:3},{buffer:C,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:M,type:t.FLOAT,size:4},{buffer:S,type:t.FLOAT,size:2},{buffer:E,type:t.FLOAT,size:1}]),P=i(t),O=new y(t,l,r,s,c,h,v,f,p,d,m,x,k,_,w,T,A,C,M,S,E,L,P,a(t,[{buffer:P,type:t.FLOAT,size:3}]));return O.update(e),O}},{\"./shaders\":311,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-shader\":301,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,normals:453,\"simplicial-complex-contour\":518,\"typedarray-pool\":545}],313:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\"),i=t(\"gl-vec4\"),a=function(t,e,r,a){for(var o=0,s=0;s<t.length;s++)for(var l=t[s].velocities,c=0;c<l.length;c++){var u=n.length(l[c]);u>o&&(o=u)}var h=t.map(function(t){return function(t,e,r,a){var o,s,l,c=t.points,u=t.velocities,h=t.divergences;n.set(n.create(),0,1,0),n.create(),n.create();n.create();for(var f=[],p=[],d=[],g=[],v=[],m=[],y=0,x=0,b=i.create(),_=i.create(),w=0;w<c.length;w++){o=c[w],s=u[w],l=h[w],0===e&&(l=.05*r),x=n.length(s)/a,b=i.create(),n.copy(b,s),b[3]=l;for(var k=0;k<8;k++)v[k]=[o[0],o[1],o[2],k];if(g.length>0)for(k=0;k<8;k++){var T=(k+1)%8;f.push(g[k],v[k],v[T],v[T],g[T],g[k]),d.push(_,b,b,b,_,_),m.push(y,x,x,x,y,y),p.push([f.length-6,f.length-5,f.length-4],[f.length-3,f.length-2,f.length-1])}var A=g;g=v,v=A,A=_,_=b,b=A,A=y,y=x,x=A}return{positions:f,cells:p,vectors:d,vertexIntensity:m}}(t,r,a,o)}),f=[],p=[],d=[],g=[];for(s=0;s<h.length;s++){var v=h[s],m=f.length;f=f.concat(v.positions),d=d.concat(v.vectors),g=g.concat(v.vertexIntensity);for(c=0;c<v.cells.length;c++){var y=v.cells[c],x=[];p.push(x);for(var b=0;b<y.length;b++)x.push(y[b]+m)}}return{positions:f,cells:p,vectors:d,vertexIntensity:g,colormap:e}},o=function(t,e){var r=n.create(),i=1e-4;n.add(r,t,[i,0,0]);var a=this.getVelocity(r);n.subtract(a,a,e),n.scale(a,a,1e4),n.add(r,t,[0,i,0]);var o=this.getVelocity(r);n.subtract(o,o,e),n.scale(o,o,1e4),n.add(r,t,[0,0,i]);var s=this.getVelocity(r);return n.subtract(s,s,e),n.scale(s,s,1e4),n.add(r,a,o),n.add(r,r,s),r},s=function(t){return f(t,this.vectors,this.meshgrid,this.clampBorders)},l=function(t,e){for(var r=0;r<t.length;r++){var n=t[r];if(n===e)return r;if(n>e)return r-1}return r},c=n.create(),u=n.create(),h=function(t,e,r){return t<e?e:t>r?r:t},f=function(t,e,r,i){var a=t[0],o=t[1],s=t[2],f=r[0].length,p=r[1].length,d=r[2].length,g=l(r[0],a),v=l(r[1],o),m=l(r[2],s),y=g+1,x=v+1,b=m+1;if(r[0][g]===a&&(y=g),r[1][v]===o&&(x=v),r[2][m]===s&&(b=m),i&&(g=h(g,0,f-1),y=h(y,0,f-1),v=h(v,0,p-1),x=h(x,0,p-1),m=h(m,0,d-1),b=h(b,0,d-1)),g<0||v<0||m<0||y>=f||x>=p||b>=d)return n.create();var _=(a-r[0][g])/(r[0][y]-r[0][g]),w=(o-r[1][v])/(r[1][x]-r[1][v]),k=(s-r[2][m])/(r[2][b]-r[2][m]);(_<0||_>1||isNaN(_))&&(_=0),(w<0||w>1||isNaN(w))&&(w=0),(k<0||k>1||isNaN(k))&&(k=0);var T=m*f*p,A=b*f*p,M=v*f,S=x*f,E=g,C=y,L=e[M+T+E],P=e[M+T+C],O=e[S+T+E],z=e[S+T+C],I=e[M+A+E],D=e[M+A+C],R=e[S+A+E],F=e[S+A+C],B=n.create();return n.lerp(B,L,P,_),n.lerp(c,O,z,_),n.lerp(B,B,c,w),n.lerp(c,I,D,_),n.lerp(u,R,F,_),n.lerp(c,c,u,w),n.lerp(B,B,c,k),B},p=function(t){var e=1/0;t.sort(function(t,e){return t-e});for(var r=1;r<t.length;r++){var n=Math.abs(t[r]-t[r-1]);n<e&&(e=n)}return e};e.exports=function(t,e){var r=t.startingPositions,i=t.maxLength||1e3,l=t.tubeSize||1,c=t.absoluteTubeSize;t.getDivergence||(t.getDivergence=o),t.getVelocity||(t.getVelocity=s),void 0===t.clampBorders&&(t.clampBorders=!0);var u=[],h=e[0][0],f=e[0][1],d=e[0][2],g=e[1][0],v=e[1][1],m=e[1][2],y=function(t,e){var r=e[0],n=e[1],i=e[2];return r>=h&&r<=g&&n>=f&&n<=v&&i>=d&&i<=m},x=10*n.distance(e[0],e[1])/i,b=x*x,_=1,w=0;n.create();r.length>=2&&(_=function(t){for(var e=[],r=[],n=[],i={},a={},o={},s=0;s<t.length;s++){var l=t[s],c=l[0],u=l[1],h=l[2];i[c]||(e.push(c),i[c]=!0),a[u]||(r.push(u),a[u]=!0),o[h]||(n.push(h),o[h]=!0)}var f=p(e),d=p(r),g=p(n),v=Math.min(f,d,g);return isFinite(v)?v:1}(r));for(var k=0;k<r.length;k++){var T=n.create();n.copy(T,r[k]);var A=[T],M=[],S=t.getVelocity(T),E=T;M.push(S);var C=[],L=t.getDivergence(T,S);(I=n.length(L))>w&&!isNaN(I)&&isFinite(I)&&(w=I),C.push(I),u.push({points:A,velocities:M,divergences:C});for(var P=0;P<100*i&&A.length<i&&y(0,T);){P++;var O=n.clone(S),z=n.squaredLength(O);if(0===z)break;if(z>b&&n.scale(O,O,x/Math.sqrt(z)),n.add(O,O,T),S=t.getVelocity(O),n.squaredDistance(E,O)-b>-1e-4*b){A.push(O),E=O,M.push(S);L=t.getDivergence(O,S);(I=n.length(L))>w&&!isNaN(I)&&isFinite(I)&&(w=I),C.push(I)}T=O}}for(k=0;k<C.length;k++){var I=C[k];!isNaN(I)&&isFinite(I)||(C[k]=w)}var D=a(u,t.colormap,w,_);return c?D.tubeScale=c:(0===w&&(w=1),D.tubeScale=.5*l*_/w),D},e.exports.createTubeMesh=t(\"./lib/tubemesh\")},{\"./lib/tubemesh\":312,\"gl-vec3\":346,\"gl-vec4\":382}],314:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute vec3 f;\\nattribute vec3 normal;\\n\\nuniform vec3 objectOffset;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 lightPosition, eyePosition;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 localCoordinate = vec3(uv.zw, f.x);\\n  worldCoordinate = objectOffset + localCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n  vec4 clipPosition = projection * view * worldPosition;\\n  gl_Position = clipPosition;\\n  kill = f.y;\\n  value = f.z;\\n  planeCoordinate = uv.xy;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * worldPosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  lightDirection = lightPosition - cameraCoordinate.xyz;\\n  eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  surfaceNormal  = normalize((vec4(normal,0) * inverseModel).xyz);\\n}\\n\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat beckmannSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness) {\\n  return beckmannDistribution(dot(surfaceNormal, normalize(lightDirection + viewDirection)), roughness);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 lowerBound, upperBound;\\nuniform float contourTint;\\nuniform vec4 contourColor;\\nuniform sampler2D colormap;\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform float vertexColor;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec3 N = normalize(surfaceNormal);\\n  vec3 V = normalize(eyeDirection);\\n  vec3 L = normalize(lightDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = max(beckmannSpecular(L, V, N, roughness), 0.);\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  //decide how to interpolate color \\u2014 in vertex or in fragment\\n  vec4 surfaceColor =\\n    step(vertexColor, .5) * texture2D(colormap, vec2(value, value)) +\\n    step(.5, vertexColor) * vColor;\\n\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = mix(litColor, contourColor, contourTint) * opacity;\\n}\\n\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute float f;\\n\\nuniform vec3 objectOffset;\\nuniform mat3 permutation;\\nuniform mat4 model, view, projection;\\nuniform float height, zOffset;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 dataCoordinate = permutation * vec3(uv.xy, height);\\n  worldCoordinate = objectOffset + dataCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n\\n  vec4 clipPosition = projection * view * worldPosition;\\n  clipPosition.z += zOffset;\\n\\n  gl_Position = clipPosition;\\n  value = f + objectOffset.z;\\n  kill = -1.0;\\n  planeCoordinate = uv.zw;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Don't do lighting for contours\\n  surfaceNormal   = vec3(1,0,0);\\n  eyeDirection    = vec3(0,1,0);\\n  lightDirection  = vec3(0,0,1);\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec2 shape;\\nuniform vec3 clipBounds[2];\\nuniform float pickId;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 surfaceNormal;\\n\\nvec2 splitFloat(float v) {\\n  float vh = 255.0 * v;\\n  float upper = floor(vh);\\n  float lower = fract(vh);\\n  return vec2(upper / 255.0, floor(lower * 16.0) / 16.0);\\n}\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec2 ux = splitFloat(planeCoordinate.x / shape.x);\\n  vec2 uy = splitFloat(planeCoordinate.y / shape.y);\\n  gl_FragColor = vec4(pickId, ux.x, uy.x, ux.y + (uy.y/16.0));\\n}\\n\"]);r.createShader=function(t){var e=n(t,a,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createPickShader=function(t){var e=n(t,a,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createContourShader=function(t){var e=n(t,s,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e},r.createPickContourShader=function(t){var e=n(t,s,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e}},{\"gl-shader\":301,glslify:409}],315:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],316:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=y(e),n=b(e),s=x(e),l=_(e),c=i(e),u=a(e,[{buffer:c,size:4,stride:w,offset:0},{buffer:c,size:3,stride:w,offset:16},{buffer:c,size:3,stride:w,offset:28}]),h=i(e),f=a(e,[{buffer:h,size:4,stride:20,offset:0},{buffer:h,size:1,stride:20,offset:16}]),p=i(e),d=a(e,[{buffer:p,size:2,type:e.FLOAT}]),g=o(e,1,S,e.RGBA,e.UNSIGNED_BYTE);g.minFilter=e.LINEAR,g.magFilter=e.LINEAR;var v=new E(e,[0,0],[[0,0,0],[0,0,0]],r,n,c,u,g,s,l,h,f,p,d,[0,0,0]),m={levels:[[],[],[]]};for(var k in t)m[k]=t[k];return m.colormap=m.colormap||\"jet\",v.update(m),v};var n=t(\"bit-twiddle\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"typedarray-pool\"),l=t(\"colormap\"),c=t(\"ndarray-ops\"),u=t(\"ndarray-pack\"),h=t(\"ndarray\"),f=t(\"surface-nets\"),p=t(\"gl-mat4/multiply\"),d=t(\"gl-mat4/invert\"),g=t(\"binary-search-bounds\"),v=t(\"ndarray-gradient\"),m=t(\"./lib/shaders\"),y=m.createShader,x=m.createContourShader,b=m.createPickShader,_=m.createPickContourShader,w=40,k=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1],T=[[0,0],[0,1],[1,0],[1,1],[1,0],[0,1]],A=[[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0]];function M(t,e,r,n,i){this.position=t,this.index=e,this.uv=r,this.level=n,this.dataCoordinate=i}!function(){for(var t=0;t<3;++t){var e=A[t],r=(t+2)%3;e[(t+1)%3+0]=1,e[r+3]=1,e[t+6]=1}}();var S=256;function E(t,e,r,n,i,a,o,l,c,u,f,p,d,g,v){this.gl=t,this.shape=e,this.bounds=r,this.objectOffset=v,this.intensityBounds=[],this._shader=n,this._pickShader=i,this._coordinateBuffer=a,this._vao=o,this._colorMap=l,this._contourShader=c,this._contourPickShader=u,this._contourBuffer=f,this._contourVAO=p,this._contourOffsets=[[],[],[]],this._contourCounts=[[],[],[]],this._vertexCount=0,this._pickResult=new M([0,0,0],[0,0],[0,0],[0,0,0],[0,0,0]),this._dynamicBuffer=d,this._dynamicVAO=g,this._dynamicOffsets=[0,0,0],this._dynamicCounts=[0,0,0],this.contourWidth=[1,1,1],this.contourLevels=[[1],[1],[1]],this.contourTint=[0,0,0],this.contourColor=[[.5,.5,.5,1],[.5,.5,.5,1],[.5,.5,.5,1]],this.showContour=!0,this.showSurface=!0,this.enableHighlight=[!0,!0,!0],this.highlightColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.highlightTint=[1,1,1],this.highlightLevel=[-1,-1,-1],this.enableDynamic=[!0,!0,!0],this.dynamicLevel=[NaN,NaN,NaN],this.dynamicColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.dynamicTint=[1,1,1],this.dynamicWidth=[1,1,1],this.axesBounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.surfaceProject=[!1,!1,!1],this.contourProject=[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],this.colorBounds=[!1,!1],this._field=[h(s.mallocFloat(1024),[0,0]),h(s.mallocFloat(1024),[0,0]),h(s.mallocFloat(1024),[0,0])],this.pickId=1,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.snapToData=!1,this.pixelRatio=1,this.opacity=1,this.lightPosition=[10,1e4,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.vertexColor=0,this.dirty=!0}var C=E.prototype;C.isTransparent=function(){return this.opacity<1},C.isOpaque=function(){if(this.opacity>=1)return!0;for(var t=0;t<3;++t)if(this._contourCounts[t].length>0||this._dynamicCounts[t]>0)return!0;return!1},C.pickSlots=1,C.setPickBase=function(t){this.pickId=t};var L=[0,0,0],P={showSurface:!1,showContour:!1,projections:[k.slice(),k.slice(),k.slice()],clipBounds:[[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]]]};function O(t,e){var r,n,i,a=e.axes&&e.axes.lastCubeProps.axis||L,o=e.showSurface,s=e.showContour;for(r=0;r<3;++r)for(o=o||e.surfaceProject[r],n=0;n<3;++n)s=s||e.contourProject[r][n];for(r=0;r<3;++r){var l=P.projections[r];for(n=0;n<16;++n)l[n]=0;for(n=0;n<4;++n)l[5*n]=1;l[5*r]=0,l[12+r]=e.axesBounds[+(a[r]>0)][r],p(l,t.model,l);var c=P.clipBounds[r];for(i=0;i<2;++i)for(n=0;n<3;++n)c[i][n]=t.clipBounds[i][n];c[0][r]=-1e8,c[1][r]=1e8}return P.showSurface=o,P.showContour=s,P}var z={model:k,view:k,projection:k,inverseModel:k.slice(),lowerBound:[0,0,0],upperBound:[0,0,0],colorMap:0,clipBounds:[[0,0,0],[0,0,0]],height:0,contourTint:0,contourColor:[0,0,0,1],permutation:[1,0,0,0,1,0,0,0,1],zOffset:-1e-4,objectOffset:[0,0,0],kambient:1,kdiffuse:1,kspecular:1,lightPosition:[1e3,1e3,1e3],eyePosition:[0,0,0],roughness:1,fresnel:1,opacity:1,vertexColor:0},I=k.slice(),D=[1,0,0,0,1,0,0,0,1];function R(t,e){t=t||{};var r=this.gl;r.disable(r.CULL_FACE),this._colorMap.bind(0);var n=z;n.model=t.model||k,n.view=t.view||k,n.projection=t.projection||k,n.lowerBound=[this.bounds[0][0],this.bounds[0][1],this.colorBounds[0]||this.bounds[0][2]],n.upperBound=[this.bounds[1][0],this.bounds[1][1],this.colorBounds[1]||this.bounds[1][2]],n.objectOffset=this.objectOffset,n.contourColor=this.contourColor[0],n.inverseModel=d(n.inverseModel,n.model);for(var i=0;i<2;++i)for(var a=n.clipBounds[i],o=0;o<3;++o)a[o]=Math.min(Math.max(this.clipBounds[i][o],-1e8),1e8);n.kambient=this.ambientLight,n.kdiffuse=this.diffuseLight,n.kspecular=this.specularLight,n.roughness=this.roughness,n.fresnel=this.fresnel,n.opacity=this.opacity,n.height=0,n.permutation=D,n.vertexColor=this.vertexColor;var s=I;for(p(s,n.view,n.model),p(s,n.projection,s),d(s,s),i=0;i<3;++i)n.eyePosition[i]=s[12+i]/s[15];var l=s[15];for(i=0;i<3;++i)l+=this.lightPosition[i]*s[4*i+3];for(i=0;i<3;++i){var c=s[12+i];for(o=0;o<3;++o)c+=s[4*o+i]*this.lightPosition[o];n.lightPosition[i]=c/l}var u=O(n,this);if(u.showSurface&&e===this.opacity<1){for(this._shader.bind(),this._shader.uniforms=n,this._vao.bind(),this.showSurface&&this._vertexCount&&this._vao.draw(r.TRIANGLES,this._vertexCount),i=0;i<3;++i)this.surfaceProject[i]&&this.vertexCount&&(this._shader.uniforms.model=u.projections[i],this._shader.uniforms.clipBounds=u.clipBounds[i],this._vao.draw(r.TRIANGLES,this._vertexCount));this._vao.unbind()}if(u.showContour&&!e){var h=this._contourShader;n.kambient=1,n.kdiffuse=0,n.kspecular=0,n.opacity=1,h.bind(),h.uniforms=n;var f=this._contourVAO;for(f.bind(),i=0;i<3;++i)for(h.uniforms.permutation=A[i],r.lineWidth(this.contourWidth[i]*this.pixelRatio),o=0;o<this.contourLevels[i].length;++o)o===this.highlightLevel[i]?(h.uniforms.contourColor=this.highlightColor[i],h.uniforms.contourTint=this.highlightTint[i]):0!==o&&o-1!==this.highlightLevel[i]||(h.uniforms.contourColor=this.contourColor[i],h.uniforms.contourTint=this.contourTint[i]),this._contourCounts[i][o]&&(h.uniforms.height=this.contourLevels[i][o],f.draw(r.LINES,this._contourCounts[i][o],this._contourOffsets[i][o]));for(i=0;i<3;++i)for(h.uniforms.model=u.projections[i],h.uniforms.clipBounds=u.clipBounds[i],o=0;o<3;++o)if(this.contourProject[i][o]){h.uniforms.permutation=A[o],r.lineWidth(this.contourWidth[o]*this.pixelRatio);for(var g=0;g<this.contourLevels[o].length;++g)g===this.highlightLevel[o]?(h.uniforms.contourColor=this.highlightColor[o],h.uniforms.contourTint=this.highlightTint[o]):0!==g&&g-1!==this.highlightLevel[o]||(h.uniforms.contourColor=this.contourColor[o],h.uniforms.contourTint=this.contourTint[o]),this._contourCounts[o][g]&&(h.uniforms.height=this.contourLevels[o][g],f.draw(r.LINES,this._contourCounts[o][g],this._contourOffsets[o][g]))}for(f.unbind(),(f=this._dynamicVAO).bind(),i=0;i<3;++i)if(0!==this._dynamicCounts[i])for(h.uniforms.model=n.model,h.uniforms.clipBounds=n.clipBounds,h.uniforms.permutation=A[i],r.lineWidth(this.dynamicWidth[i]*this.pixelRatio),h.uniforms.contourColor=this.dynamicColor[i],h.uniforms.contourTint=this.dynamicTint[i],h.uniforms.height=this.dynamicLevel[i],f.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]),o=0;o<3;++o)this.contourProject[o][i]&&(h.uniforms.model=u.projections[o],h.uniforms.clipBounds=u.clipBounds[o],f.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]));f.unbind()}}C.draw=function(t){return R.call(this,t,!1)},C.drawTransparent=function(t){return R.call(this,t,!0)};var F={model:k,view:k,projection:k,inverseModel:k,clipBounds:[[0,0,0],[0,0,0]],height:0,shape:[0,0],pickId:0,lowerBound:[0,0,0],upperBound:[0,0,0],zOffset:0,objectOffset:[0,0,0],permutation:[1,0,0,0,1,0,0,0,1],lightPosition:[0,0,0],eyePosition:[0,0,0]};function B(t,e){return Array.isArray(t)?[e(t[0]),e(t[1]),e(t[2])]:[e(t),e(t),e(t)]}function N(t){return Array.isArray(t)?3===t.length?[t[0],t[1],t[2],1]:[t[0],t[1],t[2],t[3]]:[0,0,0,1]}function j(t){if(Array.isArray(t)){if(Array.isArray(t))return[N(t[0]),N(t[1]),N(t[2])];var e=N(t);return[e.slice(),e.slice(),e.slice()]}}C.drawPick=function(t){t=t||{};var e=this.gl;e.disable(e.CULL_FACE);var r=F;r.model=t.model||k,r.view=t.view||k,r.projection=t.projection||k,r.shape=this._field[2].shape,r.pickId=this.pickId/255,r.lowerBound=this.bounds[0],r.upperBound=this.bounds[1],r.objectOffset=this.objectOffset,r.permutation=D;for(var n=0;n<2;++n)for(var i=r.clipBounds[n],a=0;a<3;++a)i[a]=Math.min(Math.max(this.clipBounds[n][a],-1e8),1e8);var o=O(r,this);if(o.showSurface){for(this._pickShader.bind(),this._pickShader.uniforms=r,this._vao.bind(),this._vao.draw(e.TRIANGLES,this._vertexCount),n=0;n<3;++n)this.surfaceProject[n]&&(this._pickShader.uniforms.model=o.projections[n],this._pickShader.uniforms.clipBounds=o.clipBounds[n],this._vao.draw(e.TRIANGLES,this._vertexCount));this._vao.unbind()}if(o.showContour){var s=this._contourPickShader;s.bind(),s.uniforms=r;var l=this._contourVAO;for(l.bind(),a=0;a<3;++a)for(e.lineWidth(this.contourWidth[a]*this.pixelRatio),s.uniforms.permutation=A[a],n=0;n<this.contourLevels[a].length;++n)this._contourCounts[a][n]&&(s.uniforms.height=this.contourLevels[a][n],l.draw(e.LINES,this._contourCounts[a][n],this._contourOffsets[a][n]));for(n=0;n<3;++n)for(s.uniforms.model=o.projections[n],s.uniforms.clipBounds=o.clipBounds[n],a=0;a<3;++a)if(this.contourProject[n][a]){s.uniforms.permutation=A[a],e.lineWidth(this.contourWidth[a]*this.pixelRatio);for(var c=0;c<this.contourLevels[a].length;++c)this._contourCounts[a][c]&&(s.uniforms.height=this.contourLevels[a][c],l.draw(e.LINES,this._contourCounts[a][c],this._contourOffsets[a][c]))}l.unbind()}},C.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=this._field[2].shape,r=this._pickResult,n=e[0]*(t.value[0]+(t.value[2]>>4)/16)/255,i=Math.floor(n),a=n-i,o=e[1]*(t.value[1]+(15&t.value[2])/16)/255,s=Math.floor(o),l=o-s;i+=1,s+=1;var c=r.position;c[0]=c[1]=c[2]=0;for(var u=0;u<2;++u)for(var h=u?a:1-a,f=0;f<2;++f)for(var p=i+u,d=s+f,v=h*(f?l:1-l),m=0;m<3;++m)c[m]+=this._field[m].get(p,d)*v;for(var y=this._pickResult.level,x=0;x<3;++x)if(y[x]=g.le(this.contourLevels[x],c[x]),y[x]<0)this.contourLevels[x].length>0&&(y[x]=0);else if(y[x]<this.contourLevels[x].length-1){var b=this.contourLevels[x][y[x]],_=this.contourLevels[x][y[x]+1];Math.abs(b-c[x])>Math.abs(_-c[x])&&(y[x]+=1)}for(r.index[0]=a<.5?i:i+1,r.index[1]=l<.5?s:s+1,r.uv[0]=n/e[0],r.uv[1]=o/e[1],m=0;m<3;++m)r.dataCoordinate[m]=this._field[m].get(r.index[0],r.index[1]);return r},C.padField=function(t,e){var r=e.shape.slice(),n=t.shape.slice();c.assign(t.lo(1,1).hi(r[0],r[1]),e),c.assign(t.lo(1).hi(r[0],1),e.hi(r[0],1)),c.assign(t.lo(1,n[1]-1).hi(r[0],1),e.lo(0,r[1]-1).hi(r[0],1)),c.assign(t.lo(0,1).hi(1,r[1]),e.hi(1)),c.assign(t.lo(n[0]-1,1).hi(1,r[1]),e.lo(r[0]-1)),t.set(0,0,e.get(0,0)),t.set(0,n[1]-1,e.get(0,r[1]-1)),t.set(n[0]-1,0,e.get(r[0]-1,0)),t.set(n[0]-1,n[1]-1,e.get(r[0]-1,r[1]-1))},C.update=function(t){t=t||{},this.objectOffset=t.objectOffset||this.objectOffset,this.dirty=!0,\"contourWidth\"in t&&(this.contourWidth=B(t.contourWidth,Number)),\"showContour\"in t&&(this.showContour=B(t.showContour,Boolean)),\"showSurface\"in t&&(this.showSurface=!!t.showSurface),\"contourTint\"in t&&(this.contourTint=B(t.contourTint,Boolean)),\"contourColor\"in t&&(this.contourColor=j(t.contourColor)),\"contourProject\"in t&&(this.contourProject=B(t.contourProject,function(t){return B(t,Boolean)})),\"surfaceProject\"in t&&(this.surfaceProject=t.surfaceProject),\"dynamicColor\"in t&&(this.dynamicColor=j(t.dynamicColor)),\"dynamicTint\"in t&&(this.dynamicTint=B(t.dynamicTint,Number)),\"dynamicWidth\"in t&&(this.dynamicWidth=B(t.dynamicWidth,Number)),\"opacity\"in t&&(this.opacity=t.opacity),\"colorBounds\"in t&&(this.colorBounds=t.colorBounds),\"vertexColor\"in t&&(this.vertexColor=t.vertexColor?1:0);var e=t.field||t.coords&&t.coords[2]||null,r=!1;if(e||(e=this._field[2].shape[0]||this._field[2].shape[2]?this._field[2].lo(1,1).hi(this._field[2].shape[0]-2,this._field[2].shape[1]-2):this._field[2].hi(0,0)),\"field\"in t||\"coords\"in t){var i=(e.shape[0]+2)*(e.shape[1]+2);i>this._field[2].data.length&&(s.freeFloat(this._field[2].data),this._field[2].data=s.mallocFloat(n.nextPow2(i))),this._field[2]=h(this._field[2].data,[e.shape[0]+2,e.shape[1]+2]),this.padField(this._field[2],e),this.shape=e.shape.slice();for(var a=this.shape,o=0;o<2;++o)this._field[2].size>this._field[o].data.length&&(s.freeFloat(this._field[o].data),this._field[o].data=s.mallocFloat(this._field[2].size)),this._field[o]=h(this._field[o].data,[a[0]+2,a[1]+2]);if(t.coords){var p=t.coords;if(!Array.isArray(p)||3!==p.length)throw new Error(\"gl-surface: invalid coordinates for x/y\");for(o=0;o<2;++o){var d=p[o];for(b=0;b<2;++b)if(d.shape[b]!==a[b])throw new Error(\"gl-surface: coords have incorrect shape\");this.padField(this._field[o],d)}}else if(t.ticks){var g=t.ticks;if(!Array.isArray(g)||2!==g.length)throw new Error(\"gl-surface: invalid ticks\");for(o=0;o<2;++o){var m=g[o];if((Array.isArray(m)||m.length)&&(m=h(m)),m.shape[0]!==a[o])throw new Error(\"gl-surface: invalid tick length\");var y=h(m.data,a);y.stride[o]=m.stride[0],y.stride[1^o]=0,this.padField(this._field[o],y)}}else{for(o=0;o<2;++o){var x=[0,0];x[o]=1,this._field[o]=h(this._field[o].data,[a[0]+2,a[1]+2],x,0)}this._field[0].set(0,0,0);for(var b=0;b<a[0];++b)this._field[0].set(b+1,0,b);for(this._field[0].set(a[0]+1,0,a[0]-1),this._field[1].set(0,0,0),b=0;b<a[1];++b)this._field[1].set(0,b+1,b);this._field[1].set(0,a[1]+1,a[1]-1)}var _=this._field,w=h(s.mallocFloat(3*_[2].size*2),[3,a[0]+2,a[1]+2,2]);for(o=0;o<3;++o)v(w.pick(o),_[o],\"mirror\");var k=h(s.mallocFloat(3*_[2].size),[a[0]+2,a[1]+2,3]);for(o=0;o<a[0]+2;++o)for(b=0;b<a[1]+2;++b){var A=w.get(0,o,b,0),M=w.get(0,o,b,1),E=w.get(1,o,b,0),C=w.get(1,o,b,1),L=w.get(2,o,b,0),P=w.get(2,o,b,1),O=E*P-C*L,z=L*M-P*A,I=A*C-M*E,D=Math.sqrt(O*O+z*z+I*I);D<1e-8?(D=Math.max(Math.abs(O),Math.abs(z),Math.abs(I)))<1e-8?(I=1,z=O=0,D=1):D=1/D:D=1/Math.sqrt(D),k.set(o,b,0,O*D),k.set(o,b,1,z*D),k.set(o,b,2,I*D)}s.free(w.data);var R=[1/0,1/0,1/0],F=[-1/0,-1/0,-1/0],N=1/0,U=-1/0,V=(a[0]-1)*(a[1]-1)*6,q=s.mallocFloat(n.nextPow2(10*V)),H=0,G=0;for(o=0;o<a[0]-1;++o)t:for(b=0;b<a[1]-1;++b){for(var Y=0;Y<2;++Y)for(var W=0;W<2;++W)for(var X=0;X<3;++X){var Z=this._field[X].get(1+o+Y,1+b+W);if(isNaN(Z)||!isFinite(Z))continue t}for(X=0;X<6;++X){var J=o+T[X][0],K=b+T[X][1],$=this._field[0].get(J+1,K+1),Q=this._field[1].get(J+1,K+1);Z=this._field[2].get(J+1,K+1),O=k.get(J+1,K+1,0),z=k.get(J+1,K+1,1),I=k.get(J+1,K+1,2),t.intensity&&(tt=t.intensity.get(J,K));var tt=t.intensity?t.intensity.get(J,K):Z+this.objectOffset[2];q[H++]=J,q[H++]=K,q[H++]=$,q[H++]=Q,q[H++]=Z,q[H++]=0,q[H++]=tt,q[H++]=O,q[H++]=z,q[H++]=I,R[0]=Math.min(R[0],$+this.objectOffset[0]),R[1]=Math.min(R[1],Q+this.objectOffset[1]),R[2]=Math.min(R[2],Z+this.objectOffset[2]),N=Math.min(N,tt),F[0]=Math.max(F[0],$+this.objectOffset[0]),F[1]=Math.max(F[1],Q+this.objectOffset[1]),F[2]=Math.max(F[2],Z+this.objectOffset[2]),U=Math.max(U,tt),G+=1}}for(t.intensityBounds&&(N=+t.intensityBounds[0],U=+t.intensityBounds[1]),o=6;o<H;o+=10)q[o]=(q[o]-N)/(U-N);this._vertexCount=G,this._coordinateBuffer.update(q.subarray(0,H)),s.freeFloat(q),s.free(k.data),this.bounds=[R,F],this.intensity=t.intensity||this._field[2],this.intensityBounds[0]===N&&this.intensityBounds[1]===U||(r=!0),this.intensityBounds=[N,U]}if(\"levels\"in t){var et=t.levels;for(et=Array.isArray(et[0])?et.slice():[[],[],et],o=0;o<3;++o)et[o]=et[o].slice(),et[o].sort(function(t,e){return t-e});for(o=0;o<3;++o)for(b=0;b<et[o].length;++b)et[o][b]-=this.objectOffset[o];t:for(o=0;o<3;++o){if(et[o].length!==this.contourLevels[o].length){r=!0;break}for(b=0;b<et[o].length;++b)if(et[o][b]!==this.contourLevels[o][b]){r=!0;break t}}this.contourLevels=et}if(r){_=this._field,a=this.shape;for(var rt=[],nt=0;nt<3;++nt){var it=this.contourLevels[nt],at=[],ot=[],st=[0,0,0];for(o=0;o<it.length;++o){var lt=f(this._field[nt],it[o]);at.push(rt.length/5|0),G=0;t:for(b=0;b<lt.cells.length;++b){var ct=lt.cells[b];for(X=0;X<2;++X){var ut=lt.positions[ct[X]],ht=ut[0],ft=0|Math.floor(ht),pt=ht-ft,dt=ut[1],gt=0|Math.floor(dt),vt=dt-gt,mt=!1;e:for(var yt=0;yt<3;++yt){st[yt]=0;var xt=(nt+yt+1)%3;for(Y=0;Y<2;++Y){var bt=Y?pt:1-pt;for(J=0|Math.min(Math.max(ft+Y,0),a[0]),W=0;W<2;++W){var _t=W?vt:1-vt;if(K=0|Math.min(Math.max(gt+W,0),a[1]),Z=yt<2?this._field[xt].get(J,K):(this.intensity.get(J,K)-this.intensityBounds[0])/(this.intensityBounds[1]-this.intensityBounds[0]),!isFinite(Z)||isNaN(Z)){mt=!0;break e}var wt=bt*_t;st[yt]+=wt*Z}}}if(mt){if(X>0){for(var kt=0;kt<5;++kt)rt.pop();G-=1}continue t}rt.push(st[0],st[1],ut[0],ut[1],st[2]),G+=1}}ot.push(G)}this._contourOffsets[nt]=at,this._contourCounts[nt]=ot}var Tt=s.mallocFloat(rt.length);for(o=0;o<rt.length;++o)Tt[o]=rt[o];this._contourBuffer.update(Tt),s.freeFloat(Tt)}t.colormap&&this._colorMap.setPixels(function(t){var e=u([l({colormap:t,nshades:S,format:\"rgba\"}).map(function(t){return[t[0],t[1],t[2],255*t[3]]})]);return c.divseq(e,255),e}(t.colormap))},C.dispose=function(){this._shader.dispose(),this._vao.dispose(),this._coordinateBuffer.dispose(),this._colorMap.dispose(),this._contourBuffer.dispose(),this._contourVAO.dispose(),this._contourShader.dispose(),this._contourPickShader.dispose(),this._dynamicBuffer.dispose(),this._dynamicVAO.dispose();for(var t=0;t<3;++t)s.freeFloat(this._field[t].data)},C.highlight=function(t){var e,r;if(!t)return this._dynamicCounts=[0,0,0],this.dyanamicLevel=[NaN,NaN,NaN],void(this.highlightLevel=[-1,-1,-1]);for(e=0;e<3;++e)this.enableHighlight[e]?this.highlightLevel[e]=t.level[e]:this.highlightLevel[e]=-1;for(r=this.snapToData?t.dataCoordinate:t.position,e=0;e<3;++e)r[e]-=this.objectOffset[e];if(this.enableDynamic[0]&&r[0]!==this.dynamicLevel[0]||this.enableDynamic[1]&&r[1]!==this.dynamicLevel[1]||this.enableDynamic[2]&&r[2]!==this.dynamicLevel[2]){for(var n=0,i=this.shape,a=s.mallocFloat(12*i[0]*i[1]),o=0;o<3;++o)if(this.enableDynamic[o]){this.dynamicLevel[o]=r[o];var l=(o+1)%3,c=(o+2)%3,u=this._field[o],h=this._field[l],p=this._field[c],d=f(u,r[o]),g=d.cells,v=d.positions;for(this._dynamicOffsets[o]=n,e=0;e<g.length;++e)for(var m=g[e],y=0;y<2;++y){var x=v[m[y]],b=+x[0],_=0|b,w=0|Math.min(_+1,i[0]),k=b-_,T=1-k,A=+x[1],M=0|A,S=0|Math.min(M+1,i[1]),E=A-M,C=1-E,L=T*C,P=T*E,O=k*C,z=k*E,I=L*h.get(_,M)+P*h.get(_,S)+O*h.get(w,M)+z*h.get(w,S),D=L*p.get(_,M)+P*p.get(_,S)+O*p.get(w,M)+z*p.get(w,S);if(isNaN(I)||isNaN(D)){y&&(n-=1);break}a[2*n+0]=I,a[2*n+1]=D,n+=1}this._dynamicCounts[o]=n-this._dynamicOffsets[o]}else this.dynamicLevel[o]=NaN,this._dynamicCounts[o]=0;this._dynamicBuffer.update(a.subarray(0,2*n)),s.freeFloat(a)}}},{\"./lib/shaders\":314,\"binary-search-bounds\":315,\"bit-twiddle\":92,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,\"ndarray-gradient\":441,\"ndarray-ops\":444,\"ndarray-pack\":445,\"surface-nets\":531,\"typedarray-pool\":545}],317:[function(t,e,r){\"use strict\";var n=t(\"css-font\"),i=t(\"pick-by-alias\"),a=t(\"regl\"),o=t(\"gl-util/context\"),s=t(\"es6-weak-map\"),l=t(\"color-normalize\"),c=t(\"font-atlas\"),u=t(\"typedarray-pool\"),h=t(\"parse-rect\"),f=t(\"is-plain-obj\"),p=t(\"parse-unit\"),d=t(\"to-px\"),g=t(\"detect-kerning\"),v=t(\"object-assign\"),m=t(\"font-measure\"),y=t(\"flatten-vertex-data\"),x=t(\"bit-twiddle\").nextPow2,b=new s,_=!1;if(document.body){var w=document.body.appendChild(document.createElement(\"div\"));w.style.font=\"italic small-caps bold condensed 16px/2 cursive\",getComputedStyle(w).fontStretch&&(_=!0),document.body.removeChild(w)}var k=function(t){!function(t){return\"function\"==typeof t&&t._gl&&t.prop&&t.texture&&t.buffer}(t)?this.gl=o(t):(t={regl:t},this.gl=t.regl._gl),this.shader=b.get(this.gl),this.shader?this.regl=this.shader.regl:this.regl=t.regl||a({gl:this.gl}),this.charBuffer=this.regl.buffer({type:\"uint8\",usage:\"stream\"}),this.sizeBuffer=this.regl.buffer({type:\"float\",usage:\"stream\"}),this.shader||(this.shader=this.createShader(),b.set(this.gl,this.shader)),this.batch=[],this.fontSize=[],this.font=[],this.fontAtlas=[],this.draw=this.shader.draw.bind(this),this.render=function(){this.regl._refresh(),this.draw(this.batch)},this.canvas=this.gl.canvas,this.update(f(t)?t:{})};k.prototype.createShader=function(){var t=this.regl,e=t({blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},stencil:{enable:!1},depth:{enable:!1},count:t.prop(\"count\"),offset:t.prop(\"offset\"),attributes:{charOffset:{offset:4,stride:8,buffer:t.this(\"sizeBuffer\")},width:{offset:0,stride:8,buffer:t.this(\"sizeBuffer\")},char:t.this(\"charBuffer\"),position:t.this(\"position\")},uniforms:{atlasSize:function(t,e){return[e.atlas.width,e.atlas.height]},atlasDim:function(t,e){return[e.atlas.cols,e.atlas.rows]},atlas:function(t,e){return e.atlas.texture},charStep:function(t,e){return e.atlas.step},em:function(t,e){return e.atlas.em},color:t.prop(\"color\"),opacity:t.prop(\"opacity\"),viewport:t.this(\"viewportArray\"),scale:t.this(\"scale\"),align:t.prop(\"align\"),baseline:t.prop(\"baseline\"),translate:t.this(\"translate\"),positionOffset:t.prop(\"positionOffset\")},primitive:\"points\",viewport:t.this(\"viewport\"),vert:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tattribute float width, charOffset, char;\\n\\t\\t\\tattribute vec2 position;\\n\\t\\t\\tuniform float fontSize, charStep, em, align, baseline;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tuniform vec4 color;\\n\\t\\t\\tuniform vec2 atlasSize, atlasDim, scale, translate, positionOffset;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\t\"+(k.normalViewport?\"\":\"vec2 positionOffset = vec2(positionOffset.x,- positionOffset.y);\")+\"\\n\\n\\t\\t\\t\\tvec2 offset = floor(em * (vec2(align + charOffset, baseline)\\n\\t\\t\\t\\t\\t+ positionOffset))\\n\\t\\t\\t\\t\\t/ (viewport.zw * scale.xy);\\n\\n\\t\\t\\t\\tvec2 position = (position + translate) * scale;\\n\\t\\t\\t\\tposition += offset * scale;\\n\\n\\t\\t\\t\\t\"+(k.normalViewport?\"position.y = 1. - position.y;\":\"\")+\"\\n\\n\\t\\t\\t\\tcharCoord = position * viewport.zw + viewport.xy;\\n\\n\\t\\t\\t\\tgl_Position = vec4(position * 2. - 1., 0, 1);\\n\\n\\t\\t\\t\\tgl_PointSize = charStep;\\n\\n\\t\\t\\t\\tcharId.x = mod(char, atlasDim.x);\\n\\t\\t\\t\\tcharId.y = floor(char / atlasDim.x);\\n\\n\\t\\t\\t\\tcharWidth = width * em;\\n\\n\\t\\t\\t\\tfontColor = color / 255.;\\n\\t\\t\\t}\",frag:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tuniform sampler2D atlas;\\n\\t\\t\\tuniform float fontSize, charStep, opacity;\\n\\t\\t\\tuniform vec2 atlasSize;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\n\\t\\t\\tfloat lightness(vec4 color) {\\n\\t\\t\\t\\treturn color.r * 0.299 + color.g * 0.587 + color.b * 0.114;\\n\\t\\t\\t}\\n\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\tvec2 uv = gl_FragCoord.xy - charCoord + charStep * .5;\\n\\t\\t\\t\\tfloat halfCharStep = floor(charStep * .5 + .5);\\n\\n\\t\\t\\t\\t// invert y and shift by 1px (FF expecially needs that)\\n\\t\\t\\t\\tuv.y = charStep - uv.y;\\n\\n\\t\\t\\t\\t// ignore points outside of character bounding box\\n\\t\\t\\t\\tfloat halfCharWidth = ceil(charWidth * .5);\\n\\t\\t\\t\\tif (floor(uv.x) > halfCharStep + halfCharWidth ||\\n\\t\\t\\t\\t\\tfloor(uv.x) < halfCharStep - halfCharWidth) return;\\n\\n\\t\\t\\t\\tuv += charId * charStep;\\n\\t\\t\\t\\tuv = uv / atlasSize;\\n\\n\\t\\t\\t\\tvec4 color = fontColor;\\n\\t\\t\\t\\tvec4 mask = texture2D(atlas, uv);\\n\\n\\t\\t\\t\\tfloat maskY = lightness(mask);\\n\\t\\t\\t\\t// float colorY = lightness(color);\\n\\t\\t\\t\\tcolor.a *= maskY;\\n\\t\\t\\t\\tcolor.a *= opacity;\\n\\n\\t\\t\\t\\t// color.a += .1;\\n\\n\\t\\t\\t\\t// antialiasing, see yiq color space y-channel formula\\n\\t\\t\\t\\t// color.rgb += (1. - color.rgb) * (1. - mask.rgb);\\n\\n\\t\\t\\t\\tgl_FragColor = color;\\n\\t\\t\\t}\"});return{regl:t,draw:e,atlas:{}}},k.prototype.update=function(t){var e=this;if(\"string\"==typeof t)t={text:t};else if(!t)return;null!=(t=i(t,{position:\"position positions coord coords coordinates\",font:\"font fontFace fontface typeface cssFont css-font family fontFamily\",fontSize:\"fontSize fontsize size font-size\",text:\"text texts chars characters value values symbols\",align:\"align alignment textAlign textbaseline\",baseline:\"baseline textBaseline textbaseline\",direction:\"dir direction textDirection\",color:\"color colour fill fill-color fillColor textColor textcolor\",kerning:\"kerning kern\",range:\"range dataBox\",viewport:\"vp viewport viewBox viewbox viewPort\",opacity:\"opacity alpha transparency visible visibility opaque\",offset:\"offset positionOffset padding shift indent indentation\"},!0)).opacity&&(Array.isArray(t.opacity)?this.opacity=t.opacity.map(function(t){return parseFloat(t)}):this.opacity=parseFloat(t.opacity)),null!=t.viewport&&(this.viewport=h(t.viewport),k.normalViewport&&(this.viewport.y=this.canvas.height-this.viewport.y-this.viewport.height),this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null==this.viewport&&(this.viewport={x:0,y:0,width:this.gl.drawingBufferWidth,height:this.gl.drawingBufferHeight},this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null!=t.kerning&&(this.kerning=t.kerning),null!=t.offset&&(\"number\"==typeof t.offset&&(t.offset=[t.offset,0]),this.positionOffset=y(t.offset)),t.direction&&(this.direction=t.direction),t.range&&(this.range=t.range,this.scale=[1/(t.range[2]-t.range[0]),1/(t.range[3]-t.range[1])],this.translate=[-t.range[0],-t.range[1]]),t.scale&&(this.scale=t.scale),t.translate&&(this.translate=t.translate),this.scale||(this.scale=[1/this.viewport.width,1/this.viewport.height]),this.translate||(this.translate=[0,0]),this.font.length||t.font||(t.font=k.baseFontSize+\"px sans-serif\");var r,a=!1,o=!1;if(t.font&&(Array.isArray(t.font)?t.font:[t.font]).forEach(function(t,r){if(\"string\"==typeof t)try{t=n.parse(t)}catch(e){t=n.parse(k.baseFontSize+\"px \"+t)}else t=n.parse(n.stringify(t));var i=n.stringify({size:k.baseFontSize,family:t.family,stretch:_?t.stretch:void 0,variant:t.variant,weight:t.weight,style:t.style}),s=p(t.size),l=Math.round(s[0]*d(s[1]));if(l!==e.fontSize[r]&&(o=!0,e.fontSize[r]=l),!(e.font[r]&&i==e.font[r].baseString||(a=!0,e.font[r]=k.fonts[i],e.font[r]))){var c=t.family.join(\", \"),u=[t.style];t.style!=t.variant&&u.push(t.variant),t.variant!=t.weight&&u.push(t.weight),_&&t.weight!=t.stretch&&u.push(t.stretch),e.font[r]={baseString:i,family:c,weight:t.weight,stretch:t.stretch,style:t.style,variant:t.variant,width:{},kerning:{},metrics:m(c,{origin:\"top\",fontSize:k.baseFontSize,fontStyle:u.join(\" \")})},k.fonts[i]=e.font[r]}}),(a||o)&&this.font.forEach(function(r,i){var a=n.stringify({size:e.fontSize[i],family:r.family,stretch:_?r.stretch:void 0,variant:r.variant,weight:r.weight,style:r.style});if(e.fontAtlas[i]=e.shader.atlas[a],!e.fontAtlas[i]){var o=r.metrics;e.shader.atlas[a]=e.fontAtlas[i]={fontString:a,step:2*Math.ceil(e.fontSize[i]*o.bottom*.5),em:e.fontSize[i],cols:0,rows:0,height:0,width:0,chars:[],ids:{},texture:e.regl.texture()}}null==t.text&&(t.text=e.text)}),\"string\"==typeof t.text&&t.position&&t.position.length>2){for(var s=Array(.5*t.position.length),f=0;f<s.length;f++)s[f]=t.text;t.text=s}if(null!=t.text||a){if(this.textOffsets=[0],Array.isArray(t.text)){this.count=t.text[0].length,this.counts=[this.count];for(var b=1;b<t.text.length;b++)this.textOffsets[b]=this.textOffsets[b-1]+t.text[b-1].length,this.count+=t.text[b].length,this.counts.push(t.text[b].length);this.text=t.text.join(\"\")}else this.text=t.text,this.count=this.text.length,this.counts=[this.count];r=[],this.font.forEach(function(t,n){k.atlasContext.font=t.baseString;for(var i=e.fontAtlas[n],a=0;a<e.text.length;a++){var o=e.text.charAt(a);if(null==i.ids[o]&&(i.ids[o]=i.chars.length,i.chars.push(o),r.push(o)),null==t.width[o]&&(t.width[o]=k.atlasContext.measureText(o).width/k.baseFontSize,e.kerning)){var s=[];for(var l in t.width)s.push(l+o,o+l);v(t.kerning,g(t.family,{pairs:s}))}}})}if(t.position)if(t.position.length>2){for(var w=!t.position[0].length,T=u.mallocFloat(2*this.count),A=0,M=0;A<this.counts.length;A++){var S=this.counts[A];if(w)for(var E=0;E<S;E++)T[M++]=t.position[2*A],T[M++]=t.position[2*A+1];else for(var C=0;C<S;C++)T[M++]=t.position[A][0],T[M++]=t.position[A][1]}this.position.call?this.position({type:\"float\",data:T}):this.position=this.regl.buffer({type:\"float\",data:T}),u.freeFloat(T)}else this.position.destroy&&this.position.destroy(),this.position={constant:t.position};if(t.text||a){var L=u.mallocUint8(this.count),P=u.mallocFloat(2*this.count);this.textWidth=[];for(var O=0,z=0;O<this.counts.length;O++){for(var I=this.counts[O],D=this.font[O]||this.font[0],R=this.fontAtlas[O]||this.fontAtlas[0],F=0;F<I;F++){var B=this.text.charAt(z),N=this.text.charAt(z-1);if(L[z]=R.ids[B],P[2*z]=D.width[B],F){var j=P[2*z-2],U=P[2*z],V=P[2*z-1]+.5*j+.5*U;if(this.kerning){var q=D.kerning[N+B];q&&(V+=.001*q)}P[2*z+1]=V}else P[2*z+1]=.5*P[2*z];z++}this.textWidth.push(P.length?.5*P[2*z-2]+P[2*z-1]:0)}t.align||(t.align=this.align),this.charBuffer({data:L,type:\"uint8\",usage:\"stream\"}),this.sizeBuffer({data:P,type:\"float\",usage:\"stream\"}),u.freeUint8(L),u.freeFloat(P),r.length&&this.font.forEach(function(t,r){var n=e.fontAtlas[r],i=n.step,a=Math.floor(k.maxAtlasSize/i),o=Math.min(a,n.chars.length),s=Math.ceil(n.chars.length/o),l=x(o*i),u=x(s*i);n.width=l,n.height=u,n.rows=s,n.cols=o,n.em&&n.texture({data:c({canvas:k.atlasCanvas,font:n.fontString,chars:n.chars,shape:[l,u],step:[i,i]})})})}if(t.align&&(this.align=t.align,this.alignOffset=this.textWidth.map(function(t,r){var n=Array.isArray(e.align)?e.align.length>1?e.align[r]:e.align[0]:e.align;if(\"number\"==typeof n)return n;switch(n){case\"right\":case\"end\":return-t;case\"center\":case\"centre\":case\"middle\":return.5*-t}return 0})),null==this.baseline&&null==t.baseline&&(t.baseline=0),null!=t.baseline&&(this.baseline=t.baseline,Array.isArray(this.baseline)||(this.baseline=[this.baseline]),this.baselineOffset=this.baseline.map(function(t,r){var n=(e.font[r]||e.font[0]).metrics,i=0;return i+=.5*n.bottom,i+=\"number\"==typeof t?t-n.baseline:-n[t],k.normalViewport||(i*=-1),i})),null!=t.color)if(t.color||(t.color=\"transparent\"),\"string\"!=typeof t.color&&isNaN(t.color)){var H;if(\"number\"==typeof t.color[0]&&t.color.length>this.counts.length){var G=t.color.length;H=u.mallocUint8(G);for(var Y=(t.color.subarray||t.color.slice).bind(t.color),W=0;W<G;W+=4)H.set(l(Y(W,W+4),\"uint8\"),W)}else{var X=t.color.length;H=u.mallocUint8(4*X);for(var Z=0;Z<X;Z++)H.set(l(t.color[Z]||0,\"uint8\"),4*Z)}this.color=H}else this.color=l(t.color,\"uint8\");if(t.position||t.text||t.color||t.baseline||t.align||t.font||t.offset||t.opacity)if(this.color.length>4||this.baselineOffset.length>1||this.align&&this.align.length>1||this.fontAtlas.length>1||this.positionOffset.length>2){var J=Math.max(.5*this.position.length||0,.25*this.color.length||0,this.baselineOffset.length||0,this.alignOffset.length||0,this.font.length||0,this.opacity.length||0,.5*this.positionOffset.length||0);this.batch=Array(J);for(var K=0;K<this.batch.length;K++)this.batch[K]={count:this.counts.length>1?this.counts[K]:this.counts[0],offset:this.textOffsets.length>1?this.textOffsets[K]:this.textOffsets[0],color:this.color?this.color.length<=4?this.color:this.color.subarray(4*K,4*K+4):[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[K]:this.opacity,baseline:null!=this.baselineOffset[K]?this.baselineOffset[K]:this.baselineOffset[0],align:this.align?null!=this.alignOffset[K]?this.alignOffset[K]:this.alignOffset[0]:0,atlas:this.fontAtlas[K]||this.fontAtlas[0],positionOffset:this.positionOffset.length>2?this.positionOffset.subarray(2*K,2*K+2):this.positionOffset}}else this.count?this.batch=[{count:this.count,offset:0,color:this.color||[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[0]:this.opacity,baseline:this.baselineOffset[0],align:this.alignOffset?this.alignOffset[0]:0,atlas:this.fontAtlas[0],positionOffset:this.positionOffset}]:this.batch=[]},k.prototype.destroy=function(){},k.prototype.kerning=!0,k.prototype.position={constant:new Float32Array(2)},k.prototype.translate=null,k.prototype.scale=null,k.prototype.font=null,k.prototype.text=\"\",k.prototype.positionOffset=[0,0],k.prototype.opacity=1,k.prototype.color=new Uint8Array([0,0,0,255]),k.prototype.alignOffset=[0,0],k.normalViewport=!1,k.maxAtlasSize=1024,k.atlasCanvas=document.createElement(\"canvas\"),k.atlasContext=k.atlasCanvas.getContext(\"2d\",{alpha:!1}),k.baseFontSize=64,k.fonts={},e.exports=k},{\"bit-twiddle\":92,\"color-normalize\":120,\"css-font\":139,\"detect-kerning\":166,\"es6-weak-map\":318,\"flatten-vertex-data\":227,\"font-atlas\":228,\"font-measure\":229,\"gl-util/context\":323,\"is-plain-obj\":422,\"object-assign\":454,\"parse-rect\":459,\"parse-unit\":461,\"pick-by-alias\":465,regl:502,\"to-px\":539,\"typedarray-pool\":545}],318:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?WeakMap:t(\"./polyfill\")},{\"./is-implemented\":319,\"./polyfill\":321}],319:[function(t,e,r){\"use strict\";e.exports=function(){var t,e;if(\"function\"!=typeof WeakMap)return!1;try{t=new WeakMap([[e={},\"one\"],[{},\"two\"],[{},\"three\"]])}catch(t){return!1}return\"[object WeakMap]\"===String(t)&&(\"function\"==typeof t.set&&(t.set({},1)===t&&(\"function\"==typeof t.delete&&(\"function\"==typeof t.has&&\"one\"===t.get(e)))))}},{}],320:[function(t,e,r){\"use strict\";e.exports=\"function\"==typeof WeakMap&&\"[object WeakMap]\"===Object.prototype.toString.call(new WeakMap)},{}],321:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/object/set-prototype-of\"),o=t(\"es5-ext/object/valid-object\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"es5-ext/string/random-uniq\"),c=t(\"d\"),u=t(\"es6-iterator/get\"),h=t(\"es6-iterator/for-of\"),f=t(\"es6-symbol\").toStringTag,p=t(\"./is-native-implemented\"),d=Array.isArray,g=Object.defineProperty,v=Object.prototype.hasOwnProperty,m=Object.getPrototypeOf;e.exports=n=function(){var t,e=arguments[0];if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");return t=p&&a&&WeakMap!==n?a(new WeakMap,m(this)):this,i(e)&&(d(e)||(e=u(e))),g(t,\"__weakMapData__\",c(\"c\",\"$weakMap$\"+l())),e?(h(e,function(e){s(e),t.set(e[0],e[1])}),t):t},p&&(a&&a(n,WeakMap),n.prototype=Object.create(WeakMap.prototype,{constructor:c(n)})),Object.defineProperties(n.prototype,{delete:c(function(t){return!!v.call(o(t),this.__weakMapData__)&&(delete t[this.__weakMapData__],!0)}),get:c(function(t){if(v.call(o(t),this.__weakMapData__))return t[this.__weakMapData__]}),has:c(function(t){return v.call(o(t),this.__weakMapData__)}),set:c(function(t,e){return g(o(t),this.__weakMapData__,c(\"c\",e)),this}),toString:c(function(){return\"[object WeakMap]\"})}),g(n.prototype,f,c(\"c\",\"WeakMap\"))},{\"./is-native-implemented\":320,d:151,\"es5-ext/object/is-value\":194,\"es5-ext/object/set-prototype-of\":200,\"es5-ext/object/valid-object\":204,\"es5-ext/object/valid-value\":205,\"es5-ext/string/random-uniq\":210,\"es6-iterator/for-of\":212,\"es6-iterator/get\":213,\"es6-symbol\":219}],322:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"ndarray-ops\"),a=t(\"typedarray-pool\");e.exports=function(t){if(arguments.length<=1)throw new Error(\"gl-texture2d: Missing arguments for texture2d constructor\");o||function(t){o=[t.LINEAR,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_NEAREST],s=[t.NEAREST,t.LINEAR,t.NEAREST_MIPMAP_NEAREST,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_LINEAR],l=[t.REPEAT,t.CLAMP_TO_EDGE,t.MIRRORED_REPEAT]}(t);if(\"number\"==typeof arguments[1])return v(t,arguments[1],arguments[2],arguments[3]||t.RGBA,arguments[4]||t.UNSIGNED_BYTE);if(Array.isArray(arguments[1]))return v(t,0|arguments[1][0],0|arguments[1][1],arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(\"object\"==typeof arguments[1]){var e=arguments[1],r=c(e)?e:e.raw;if(r)return function(t,e,r,n,i,a){var o=g(t);return t.texImage2D(t.TEXTURE_2D,0,i,i,a,e),new f(t,o,r,n,i,a)}(t,r,0|e.width,0|e.height,arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(e.shape&&e.data&&e.stride)return function(t,e){var r=e.dtype,o=e.shape.slice(),s=t.getParameter(t.MAX_TEXTURE_SIZE);if(o[0]<0||o[0]>s||o[1]<0||o[1]>s)throw new Error(\"gl-texture2d: Invalid texture size\");var l=d(o,e.stride.slice()),c=0;\"float32\"===r?c=t.FLOAT:\"float64\"===r?(c=t.FLOAT,l=!1,r=\"float32\"):\"uint8\"===r?c=t.UNSIGNED_BYTE:(c=t.UNSIGNED_BYTE,l=!1,r=\"uint8\");var h,p,v=0;if(2===o.length)v=t.LUMINANCE,o=[o[0],o[1],1],e=n(e.data,o,[e.stride[0],e.stride[1],1],e.offset);else{if(3!==o.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===o[2])v=t.ALPHA;else if(2===o[2])v=t.LUMINANCE_ALPHA;else if(3===o[2])v=t.RGB;else{if(4!==o[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");v=t.RGBA}}c!==t.FLOAT||t.getExtension(\"OES_texture_float\")||(c=t.UNSIGNED_BYTE,l=!1);var m=e.size;if(l)h=0===e.offset&&e.data.length===m?e.data:e.data.subarray(e.offset,e.offset+m);else{var y=[o[2],o[2]*o[0],1];p=a.malloc(m,r);var x=n(p,o,y,0);\"float32\"!==r&&\"float64\"!==r||c!==t.UNSIGNED_BYTE?i.assign(x,e):u(x,e),h=p.subarray(0,m)}var b=g(t);t.texImage2D(t.TEXTURE_2D,0,v,o[0],o[1],0,v,c,h),l||a.free(p);return new f(t,b,o[0],o[1],v,c)}(t,e)}throw new Error(\"gl-texture2d: Invalid arguments for texture2d constructor\")};var o=null,s=null,l=null;function c(t){return\"undefined\"!=typeof HTMLCanvasElement&&t instanceof HTMLCanvasElement||\"undefined\"!=typeof HTMLImageElement&&t instanceof HTMLImageElement||\"undefined\"!=typeof HTMLVideoElement&&t instanceof HTMLVideoElement||\"undefined\"!=typeof ImageData&&t instanceof ImageData}var u=function(t,e){i.muls(t,e,255)};function h(t,e,r){var n=t.gl,i=n.getParameter(n.MAX_TEXTURE_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-texture2d: Invalid texture size\");return t._shape=[e,r],t.bind(),n.texImage2D(n.TEXTURE_2D,0,t.format,e,r,0,t.format,t.type,null),t._mipLevels=[0],t}function f(t,e,r,n,i,a){this.gl=t,this.handle=e,this.format=i,this.type=a,this._shape=[r,n],this._mipLevels=[0],this._magFilter=t.NEAREST,this._minFilter=t.NEAREST,this._wrapS=t.CLAMP_TO_EDGE,this._wrapT=t.CLAMP_TO_EDGE,this._anisoSamples=1;var o=this,s=[this._wrapS,this._wrapT];Object.defineProperties(s,[{get:function(){return o._wrapS},set:function(t){return o.wrapS=t}},{get:function(){return o._wrapT},set:function(t){return o.wrapT=t}}]),this._wrapVector=s;var l=[this._shape[0],this._shape[1]];Object.defineProperties(l,[{get:function(){return o._shape[0]},set:function(t){return o.width=t}},{get:function(){return o._shape[1]},set:function(t){return o.height=t}}]),this._shapeVector=l}var p=f.prototype;function d(t,e){return 3===t.length?1===e[2]&&e[1]===t[0]*t[2]&&e[0]===t[2]:1===e[0]&&e[1]===t[0]}function g(t){var e=t.createTexture();return t.bindTexture(t.TEXTURE_2D,e),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MIN_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MAG_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_S,t.CLAMP_TO_EDGE),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_T,t.CLAMP_TO_EDGE),e}function v(t,e,r,n,i){var a=t.getParameter(t.MAX_TEXTURE_SIZE);if(e<0||e>a||r<0||r>a)throw new Error(\"gl-texture2d: Invalid texture shape\");if(i===t.FLOAT&&!t.getExtension(\"OES_texture_float\"))throw new Error(\"gl-texture2d: Floating point textures not supported on this platform\");var o=g(t);return t.texImage2D(t.TEXTURE_2D,0,n,e,r,0,n,i,null),new f(t,o,e,r,n,i)}Object.defineProperties(p,{minFilter:{get:function(){return this._minFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,t),this._minFilter=t}},magFilter:{get:function(){return this._magFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,t),this._magFilter=t}},mipSamples:{get:function(){return this._anisoSamples},set:function(t){var e=this._anisoSamples;if(this._anisoSamples=0|Math.max(t,1),e!==this._anisoSamples){var r=this.gl.getExtension(\"EXT_texture_filter_anisotropic\");r&&this.gl.texParameterf(this.gl.TEXTURE_2D,r.TEXTURE_MAX_ANISOTROPY_EXT,this._anisoSamples)}return this._anisoSamples}},wrapS:{get:function(){return this._wrapS},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_S,t),this._wrapS=t}},wrapT:{get:function(){return this._wrapT},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_T,t),this._wrapT=t}},wrap:{get:function(){return this._wrapVector},set:function(t){if(Array.isArray(t)||(t=[t,t]),2!==t.length)throw new Error(\"gl-texture2d: Must specify wrap mode for rows and columns\");for(var e=0;e<2;++e)if(l.indexOf(t[e])<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);this._wrapS=t[0],this._wrapT=t[1];var r=this.gl;return this.bind(),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_S,this._wrapS),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_T,this._wrapT),t}},shape:{get:function(){return this._shapeVector},set:function(t){if(Array.isArray(t)){if(2!==t.length)throw new Error(\"gl-texture2d: Invalid texture shape\")}else t=[0|t,0|t];return h(this,0|t[0],0|t[1]),[0|t[0],0|t[1]]}},width:{get:function(){return this._shape[0]},set:function(t){return h(this,t|=0,this._shape[1]),t}},height:{get:function(){return this._shape[1]},set:function(t){return t|=0,h(this,this._shape[0],t),t}}}),p.bind=function(t){var e=this.gl;return void 0!==t&&e.activeTexture(e.TEXTURE0+(0|t)),e.bindTexture(e.TEXTURE_2D,this.handle),void 0!==t?0|t:e.getParameter(e.ACTIVE_TEXTURE)-e.TEXTURE0},p.dispose=function(){this.gl.deleteTexture(this.handle)},p.generateMipmap=function(){this.bind(),this.gl.generateMipmap(this.gl.TEXTURE_2D);for(var t=Math.min(this._shape[0],this._shape[1]),e=0;t>0;++e,t>>>=1)this._mipLevels.indexOf(e)<0&&this._mipLevels.push(e)},p.setPixels=function(t,e,r,o){var s=this.gl;this.bind(),Array.isArray(e)?(o=r,r=0|e[1],e=0|e[0]):(e=e||0,r=r||0),o=o||0;var l=c(t)?t:t.raw;if(l){this._mipLevels.indexOf(o)<0?(s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,this.type,l),this._mipLevels.push(o)):s.texSubImage2D(s.TEXTURE_2D,o,e,r,this.format,this.type,l)}else{if(!(t.shape&&t.stride&&t.data))throw new Error(\"gl-texture2d: Unsupported data type\");if(t.shape.length<2||e+t.shape[1]>this._shape[1]>>>o||r+t.shape[0]>this._shape[0]>>>o||e<0||r<0)throw new Error(\"gl-texture2d: Texture dimensions are out of bounds\");!function(t,e,r,o,s,l,c,h){var f=h.dtype,p=h.shape.slice();if(p.length<2||p.length>3)throw new Error(\"gl-texture2d: Invalid ndarray, must be 2d or 3d\");var g=0,v=0,m=d(p,h.stride.slice());\"float32\"===f?g=t.FLOAT:\"float64\"===f?(g=t.FLOAT,m=!1,f=\"float32\"):\"uint8\"===f?g=t.UNSIGNED_BYTE:(g=t.UNSIGNED_BYTE,m=!1,f=\"uint8\");if(2===p.length)v=t.LUMINANCE,p=[p[0],p[1],1],h=n(h.data,p,[h.stride[0],h.stride[1],1],h.offset);else{if(3!==p.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===p[2])v=t.ALPHA;else if(2===p[2])v=t.LUMINANCE_ALPHA;else if(3===p[2])v=t.RGB;else{if(4!==p[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");v=t.RGBA}p[2]}v!==t.LUMINANCE&&v!==t.ALPHA||s!==t.LUMINANCE&&s!==t.ALPHA||(v=s);if(v!==s)throw new Error(\"gl-texture2d: Incompatible texture format for setPixels\");var y=h.size,x=c.indexOf(o)<0;x&&c.push(o);if(g===l&&m)0===h.offset&&h.data.length===y?x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,h.data):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,h.data):x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,h.data.subarray(h.offset,h.offset+y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,h.data.subarray(h.offset,h.offset+y));else{var b;b=l===t.FLOAT?a.mallocFloat32(y):a.mallocUint8(y);var _=n(b,p,[p[2],p[2]*p[0],1]);g===t.FLOAT&&l===t.UNSIGNED_BYTE?u(_,h):i.assign(_,h),x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,b.subarray(0,y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,b.subarray(0,y)),l===t.FLOAT?a.freeFloat32(b):a.freeUint8(b)}}(s,e,r,o,this.format,this.type,this._mipLevels,t)}}},{ndarray:450,\"ndarray-ops\":444,\"typedarray-pool\":545}],323:[function(t,e,r){(function(r){\"use strict\";var n=t(\"pick-by-alias\");function i(t){if(t.container)if(t.container==document.body)document.body.style.width||(t.canvas.width=t.width||t.pixelRatio*r.innerWidth),document.body.style.height||(t.canvas.height=t.height||t.pixelRatio*r.innerHeight);else{var e=t.container.getBoundingClientRect();t.canvas.width=t.width||e.right-e.left,t.canvas.height=t.height||e.bottom-e.top}}function a(t){return\"function\"==typeof t.getContext&&\"width\"in t&&\"height\"in t}function o(){var t=document.createElement(\"canvas\");return t.style.position=\"absolute\",t.style.top=0,t.style.left=0,t}e.exports=function(t){var e;if(t?\"string\"==typeof t&&(t={container:t}):t={},a(t)?t={container:t}:t=\"string\"==typeof(e=t).nodeName&&\"function\"==typeof e.appendChild&&\"function\"==typeof e.getBoundingClientRect?{container:t}:function(t){return\"function\"==typeof t.drawArrays||\"function\"==typeof t.drawElements}(t)?{gl:t}:n(t,{container:\"container target element el canvas holder parent parentNode wrapper use ref root node\",gl:\"gl context webgl glContext\",attrs:\"attributes attrs contextAttributes\",pixelRatio:\"pixelRatio pxRatio px ratio pxratio pixelratio\",width:\"w width\",height:\"h height\"},!0),t.pixelRatio||(t.pixelRatio=r.pixelRatio||1),t.gl)return t.gl;if(t.canvas&&(t.container=t.canvas.parentNode),t.container){if(\"string\"==typeof t.container){var s=document.querySelector(t.container);if(!s)throw Error(\"Element \"+t.container+\" is not found\");t.container=s}a(t.container)?(t.canvas=t.container,t.container=t.canvas.parentNode):t.canvas||(t.canvas=o(),t.container.appendChild(t.canvas),i(t))}else if(!t.canvas){if(\"undefined\"==typeof document)throw Error(\"Not DOM environment. Use headless-gl.\");t.container=document.body||document.documentElement,t.canvas=o(),t.container.appendChild(t.canvas),i(t)}if(!t.gl)try{t.gl=t.canvas.getContext(\"webgl\",t.attrs)}catch(e){try{t.gl=t.canvas.getContext(\"experimental-webgl\",t.attrs)}catch(e){t.gl=t.canvas.getContext(\"webgl-experimental\",t.attrs)}}return t.gl}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"pick-by-alias\":465}],324:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){e?e.bind():t.bindBuffer(t.ELEMENT_ARRAY_BUFFER,null);var n=0|t.getParameter(t.MAX_VERTEX_ATTRIBS);if(r){if(r.length>n)throw new Error(\"gl-vao: Too many vertex attributes\");for(var i=0;i<r.length;++i){var a=r[i];if(a.buffer){var o=a.buffer,s=a.size||4,l=a.type||t.FLOAT,c=!!a.normalized,u=a.stride||0,h=a.offset||0;o.bind(),t.enableVertexAttribArray(i),t.vertexAttribPointer(i,s,l,c,u,h)}else{if(\"number\"==typeof a)t.vertexAttrib1f(i,a);else if(1===a.length)t.vertexAttrib1f(i,a[0]);else if(2===a.length)t.vertexAttrib2f(i,a[0],a[1]);else if(3===a.length)t.vertexAttrib3f(i,a[0],a[1],a[2]);else{if(4!==a.length)throw new Error(\"gl-vao: Invalid vertex attribute\");t.vertexAttrib4f(i,a[0],a[1],a[2],a[3])}t.disableVertexAttribArray(i)}}for(;i<n;++i)t.disableVertexAttribArray(i)}else for(t.bindBuffer(t.ARRAY_BUFFER,null),i=0;i<n;++i)t.disableVertexAttribArray(i)}},{}],325:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t){this.gl=t,this._elements=null,this._attributes=null,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(){n(this.gl,this._elements,this._attributes)},i.prototype.update=function(t,e,r){this._elements=e,this._attributes=t,this._elementsType=r||this.gl.UNSIGNED_SHORT},i.prototype.dispose=function(){},i.prototype.unbind=function(){},i.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._elements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t){return new i(t)}},{\"./do-bind.js\":324}],326:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t,e,r,n,i,a){this.location=t,this.dimension=e,this.a=r,this.b=n,this.c=i,this.d=a}function a(t,e,r){this.gl=t,this._ext=e,this.handle=r,this._attribs=[],this._useElements=!1,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(t){switch(this.dimension){case 1:t.vertexAttrib1f(this.location,this.a);break;case 2:t.vertexAttrib2f(this.location,this.a,this.b);break;case 3:t.vertexAttrib3f(this.location,this.a,this.b,this.c);break;case 4:t.vertexAttrib4f(this.location,this.a,this.b,this.c,this.d)}},a.prototype.bind=function(){this._ext.bindVertexArrayOES(this.handle);for(var t=0;t<this._attribs.length;++t)this._attribs[t].bind(this.gl)},a.prototype.unbind=function(){this._ext.bindVertexArrayOES(null)},a.prototype.dispose=function(){this._ext.deleteVertexArrayOES(this.handle)},a.prototype.update=function(t,e,r){if(this.bind(),n(this.gl,e,t),this.unbind(),this._attribs.length=0,t)for(var a=0;a<t.length;++a){var o=t[a];\"number\"==typeof o?this._attribs.push(new i(a,1,o)):Array.isArray(o)&&this._attribs.push(new i(a,o.length,o[0],o[1],o[2],o[3]))}this._useElements=!!e,this._elementsType=r||this.gl.UNSIGNED_SHORT},a.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._useElements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t,e){return new a(t,e,e.createVertexArrayOES())}},{\"./do-bind.js\":324}],327:[function(t,e,r){\"use strict\";var n=t(\"./lib/vao-native.js\"),i=t(\"./lib/vao-emulated.js\");function a(t){this.bindVertexArrayOES=t.bindVertexArray.bind(t),this.createVertexArrayOES=t.createVertexArray.bind(t),this.deleteVertexArrayOES=t.deleteVertexArray.bind(t)}e.exports=function(t,e,r,o){var s,l=t.createVertexArray?new a(t):t.getExtension(\"OES_vertex_array_object\");return(s=l?n(t,l):i(t)).update(e,r,o),s}},{\"./lib/vao-emulated.js\":325,\"./lib/vao-native.js\":326}],328:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t}},{}],329:[function(t,e,r){e.exports=function(t,e){var r=n(t[0],t[1],t[2]),o=n(e[0],e[1],e[2]);i(r,r),i(o,o);var s=a(r,o);return s>1?0:Math.acos(s)};var n=t(\"./fromValues\"),i=t(\"./normalize\"),a=t(\"./dot\")},{\"./dot\":339,\"./fromValues\":345,\"./normalize\":356}],330:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.ceil(e[0]),t[1]=Math.ceil(e[1]),t[2]=Math.ceil(e[2]),t}},{}],331:[function(t,e,r){e.exports=function(t){var e=new Float32Array(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e}},{}],332:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}},{}],333:[function(t,e,r){e.exports=function(){var t=new Float32Array(3);return t[0]=0,t[1]=0,t[2]=0,t}},{}],334:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2];return t[0]=i*l-a*s,t[1]=a*o-n*l,t[2]=n*s-i*o,t}},{}],335:[function(t,e,r){e.exports=t(\"./distance\")},{\"./distance\":336}],336:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return Math.sqrt(r*r+n*n+i*i)}},{}],337:[function(t,e,r){e.exports=t(\"./divide\")},{\"./divide\":338}],338:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t}},{}],339:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}},{}],340:[function(t,e,r){e.exports=1e-6},{}],341:[function(t,e,r){e.exports=function(t,e){var r=t[0],i=t[1],a=t[2],o=e[0],s=e[1],l=e[2];return Math.abs(r-o)<=n*Math.max(1,Math.abs(r),Math.abs(o))&&Math.abs(i-s)<=n*Math.max(1,Math.abs(i),Math.abs(s))&&Math.abs(a-l)<=n*Math.max(1,Math.abs(a),Math.abs(l))};var n=t(\"./epsilon\")},{\"./epsilon\":340}],342:[function(t,e,r){e.exports=function(t,e){return t[0]===e[0]&&t[1]===e[1]&&t[2]===e[2]}},{}],343:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.floor(e[0]),t[1]=Math.floor(e[1]),t[2]=Math.floor(e[2]),t}},{}],344:[function(t,e,r){e.exports=function(t,e,r,i,a,o){var s,l;e||(e=3);r||(r=0);l=i?Math.min(i*e+r,t.length):t.length;for(s=r;s<l;s+=e)n[0]=t[s],n[1]=t[s+1],n[2]=t[s+2],a(n,n,o),t[s]=n[0],t[s+1]=n[1],t[s+2]=n[2];return t};var n=t(\"./create\")()},{\"./create\":333}],345:[function(t,e,r){e.exports=function(t,e,r){var n=new Float32Array(3);return n[0]=t,n[1]=e,n[2]=r,n}},{}],346:[function(t,e,r){e.exports={EPSILON:t(\"./epsilon\"),create:t(\"./create\"),clone:t(\"./clone\"),angle:t(\"./angle\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),equals:t(\"./equals\"),exactEquals:t(\"./exactEquals\"),add:t(\"./add\"),subtract:t(\"./subtract\"),sub:t(\"./sub\"),multiply:t(\"./multiply\"),mul:t(\"./mul\"),divide:t(\"./divide\"),div:t(\"./div\"),min:t(\"./min\"),max:t(\"./max\"),floor:t(\"./floor\"),ceil:t(\"./ceil\"),round:t(\"./round\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),dist:t(\"./dist\"),squaredDistance:t(\"./squaredDistance\"),sqrDist:t(\"./sqrDist\"),length:t(\"./length\"),len:t(\"./len\"),squaredLength:t(\"./squaredLength\"),sqrLen:t(\"./sqrLen\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),cross:t(\"./cross\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformMat3:t(\"./transformMat3\"),transformQuat:t(\"./transformQuat\"),rotateX:t(\"./rotateX\"),rotateY:t(\"./rotateY\"),rotateZ:t(\"./rotateZ\"),forEach:t(\"./forEach\")}},{\"./add\":328,\"./angle\":329,\"./ceil\":330,\"./clone\":331,\"./copy\":332,\"./create\":333,\"./cross\":334,\"./dist\":335,\"./distance\":336,\"./div\":337,\"./divide\":338,\"./dot\":339,\"./epsilon\":340,\"./equals\":341,\"./exactEquals\":342,\"./floor\":343,\"./forEach\":344,\"./fromValues\":345,\"./inverse\":347,\"./len\":348,\"./length\":349,\"./lerp\":350,\"./max\":351,\"./min\":352,\"./mul\":353,\"./multiply\":354,\"./negate\":355,\"./normalize\":356,\"./random\":357,\"./rotateX\":358,\"./rotateY\":359,\"./rotateZ\":360,\"./round\":361,\"./scale\":362,\"./scaleAndAdd\":363,\"./set\":364,\"./sqrDist\":365,\"./sqrLen\":366,\"./squaredDistance\":367,\"./squaredLength\":368,\"./sub\":369,\"./subtract\":370,\"./transformMat3\":371,\"./transformMat4\":372,\"./transformQuat\":373}],347:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t}},{}],348:[function(t,e,r){e.exports=t(\"./length\")},{\"./length\":349}],349:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return Math.sqrt(e*e+r*r+n*n)}},{}],350:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t}},{}],351:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t}},{}],352:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t}},{}],353:[function(t,e,r){e.exports=t(\"./multiply\")},{\"./multiply\":354}],354:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t}},{}],355:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t}},{}],356:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=r*r+n*n+i*i;a>0&&(a=1/Math.sqrt(a),t[0]=e[0]*a,t[1]=e[1]*a,t[2]=e[2]*a);return t}},{}],357:[function(t,e,r){e.exports=function(t,e){e=e||1;var r=2*Math.random()*Math.PI,n=2*Math.random()-1,i=Math.sqrt(1-n*n)*e;return t[0]=Math.cos(r)*i,t[1]=Math.sin(r)*i,t[2]=n*e,t}},{}],358:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[1],a=r[2],o=e[1]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=e[0],t[1]=i+o*c-s*l,t[2]=a+o*l+s*c,t}},{}],359:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[2],o=e[0]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+s*l+o*c,t[1]=e[1],t[2]=a+s*c-o*l,t}},{}],360:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[1],o=e[0]-i,s=e[1]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+o*c-s*l,t[1]=a+o*l+s*c,t[2]=e[2],t}},{}],361:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.round(e[0]),t[1]=Math.round(e[1]),t[2]=Math.round(e[2]),t}},{}],362:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t}},{}],363:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t}},{}],364:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e,t[1]=r,t[2]=n,t}},{}],365:[function(t,e,r){e.exports=t(\"./squaredDistance\")},{\"./squaredDistance\":367}],366:[function(t,e,r){e.exports=t(\"./squaredLength\")},{\"./squaredLength\":368}],367:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return r*r+n*n+i*i}},{}],368:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return e*e+r*r+n*n}},{}],369:[function(t,e,r){e.exports=t(\"./subtract\")},{\"./subtract\":370}],370:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t}},{}],371:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t}},{}],372:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[3]*n+r[7]*i+r[11]*a+r[15];return o=o||1,t[0]=(r[0]*n+r[4]*i+r[8]*a+r[12])/o,t[1]=(r[1]*n+r[5]*i+r[9]*a+r[13])/o,t[2]=(r[2]*n+r[6]*i+r[10]*a+r[14])/o,t}},{}],373:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,h=c*i+l*n-o*a,f=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+h*-l-f*-s,t[1]=h*c+p*-s+f*-o-u*-l,t[2]=f*c+p*-l+u*-s-h*-o,t}},{}],374:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t[3]=e[3]+r[3],t}},{}],375:[function(t,e,r){e.exports=function(t){var e=new Float32Array(4);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e}},{}],376:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t}},{}],377:[function(t,e,r){e.exports=function(){var t=new Float32Array(4);return t[0]=0,t[1]=0,t[2]=0,t[3]=0,t}},{}],378:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return Math.sqrt(r*r+n*n+i*i+a*a)}},{}],379:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t[3]=e[3]/r[3],t}},{}],380:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}},{}],381:[function(t,e,r){e.exports=function(t,e,r,n){var i=new Float32Array(4);return i[0]=t,i[1]=e,i[2]=r,i[3]=n,i}},{}],382:[function(t,e,r){e.exports={create:t(\"./create\"),clone:t(\"./clone\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),add:t(\"./add\"),subtract:t(\"./subtract\"),multiply:t(\"./multiply\"),divide:t(\"./divide\"),min:t(\"./min\"),max:t(\"./max\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),squaredDistance:t(\"./squaredDistance\"),length:t(\"./length\"),squaredLength:t(\"./squaredLength\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformQuat:t(\"./transformQuat\")}},{\"./add\":374,\"./clone\":375,\"./copy\":376,\"./create\":377,\"./distance\":378,\"./divide\":379,\"./dot\":380,\"./fromValues\":381,\"./inverse\":383,\"./length\":384,\"./lerp\":385,\"./max\":386,\"./min\":387,\"./multiply\":388,\"./negate\":389,\"./normalize\":390,\"./random\":391,\"./scale\":392,\"./scaleAndAdd\":393,\"./set\":394,\"./squaredDistance\":395,\"./squaredLength\":396,\"./subtract\":397,\"./transformMat4\":398,\"./transformQuat\":399}],383:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t[3]=1/e[3],t}},{}],384:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return Math.sqrt(e*e+r*r+n*n+i*i)}},{}],385:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2],s=e[3];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t[3]=s+n*(r[3]-s),t}},{}],386:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t[3]=Math.max(e[3],r[3]),t}},{}],387:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t[3]=Math.min(e[3],r[3]),t}},{}],388:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t[3]=e[3]*r[3],t}},{}],389:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t[3]=-e[3],t}},{}],390:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r*r+n*n+i*i+a*a;o>0&&(o=1/Math.sqrt(o),t[0]=r*o,t[1]=n*o,t[2]=i*o,t[3]=a*o);return t}},{}],391:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"./scale\");e.exports=function(t,e){return e=e||1,t[0]=Math.random(),t[1]=Math.random(),t[2]=Math.random(),t[3]=Math.random(),n(t,t),i(t,t,e),t}},{\"./normalize\":390,\"./scale\":392}],392:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t}},{}],393:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t[3]=e[3]+r[3]*n,t}},{}],394:[function(t,e,r){e.exports=function(t,e,r,n,i){return t[0]=e,t[1]=r,t[2]=n,t[3]=i,t}},{}],395:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return r*r+n*n+i*i+a*a}},{}],396:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return e*e+r*r+n*n+i*i}},{}],397:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t[3]=e[3]-r[3],t}},{}],398:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}},{}],399:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,h=c*i+l*n-o*a,f=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+h*-l-f*-s,t[1]=h*c+p*-s+f*-o-u*-l,t[2]=f*c+p*-l+u*-s-h*-o,t[3]=e[3],t}},{}],400:[function(t,e,r){e.exports=function(t,e,r,a){return n[0]=a,n[1]=r,n[2]=e,n[3]=t,i[0]};var n=new Uint8Array(4),i=new Float32Array(n.buffer)},{}],401:[function(t,e,r){var n=t(\"glsl-tokenizer\"),i=t(\"atob-lite\");e.exports=function(t){for(var e=Array.isArray(t)?t:n(t),r=0;r<e.length;r++){var a=e[r];if(\"preprocessor\"===a.type){var o=a.data.match(/\\#define\\s+SHADER_NAME(_B64)?\\s+(.+)$/);if(o&&o[2]){var s=o[1],l=o[2];return(s?i(l):l).trim()}}}}},{\"atob-lite\":72,\"glsl-tokenizer\":408}],402:[function(t,e,r){e.exports=function(t){var e,r,k,T=0,A=0,M=l,S=[],E=[],C=1,L=0,P=0,O=!1,z=!1,I=\"\",D=a,R=n;\"300 es\"===(t=t||{}).version&&(D=s,R=o);return function(t){return E=[],null!==t?function(t){var r;T=0,k=(I+=t).length;for(;e=I[T],T<k;){switch(r=T,M){case u:T=U();break;case h:case f:T=j();break;case p:T=V();break;case d:T=G();break;case _:T=H();break;case g:T=Y();break;case c:T=W();break;case x:T=N();break;case l:T=B()}if(r!==T)switch(I[r]){case\"\\n\":L=0,++C;break;default:++L}}return A+=T,I=I.slice(T),E}(t.replace?t.replace(/\\r\\n/g,\"\\n\"):t):function(t){S.length&&F(S.join(\"\"));return M=b,F(\"(eof)\"),E}()};function F(t){t.length&&E.push({type:w[M],data:t,position:P,line:C,column:L})}function B(){return S=S.length?[]:S,\"/\"===r&&\"*\"===e?(P=A+T-1,M=u,r=e,T+1):\"/\"===r&&\"/\"===e?(P=A+T-1,M=h,r=e,T+1):\"#\"===e?(M=f,P=A+T,T):/\\s/.test(e)?(M=x,P=A+T,T):(O=/\\d/.test(e),z=/[^\\w_]/.test(e),P=A+T,M=O?d:z?p:c,T)}function N(){return/[^\\s]/g.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function j(){return\"\\r\"!==e&&\"\\n\"!==e||\"\\\\\"===r?(S.push(e),r=e,T+1):(F(S.join(\"\")),M=l,T)}function U(){return\"/\"===e&&\"*\"===r?(S.push(e),F(S.join(\"\")),M=l,T+1):(S.push(e),r=e,T+1)}function V(){if(\".\"===r&&/\\d/.test(e))return M=g,T;if(\"/\"===r&&\"*\"===e)return M=u,T;if(\"/\"===r&&\"/\"===e)return M=h,T;if(\".\"===e&&S.length){for(;q(S););return M=g,T}if(\";\"===e||\")\"===e||\"(\"===e){if(S.length)for(;q(S););return F(e),M=l,T+1}var t=2===S.length&&\"=\"!==e;if(/[\\w_\\d\\s]/.test(e)||t){for(;q(S););return M=l,T}return S.push(e),r=e,T+1}function q(t){for(var e,r,n=0;;){if(e=i.indexOf(t.slice(0,t.length+n).join(\"\")),r=i[e],-1===e){if(n--+t.length>0)continue;r=t.slice(0,1).join(\"\")}return F(r),P+=r.length,(S=S.slice(r.length)).length}}function H(){return/[^a-fA-F0-9]/.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function G(){return\".\"===e?(S.push(e),M=g,r=e,T+1):/[eE]/.test(e)?(S.push(e),M=g,r=e,T+1):\"x\"===e&&1===S.length&&\"0\"===S[0]?(M=_,S.push(e),r=e,T+1):/[^\\d]/.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function Y(){return\"f\"===e&&(S.push(e),r=e,T+=1),/[eE]/.test(e)?(S.push(e),r=e,T+1):\"-\"===e&&/[eE]/.test(r)?(S.push(e),r=e,T+1):/[^\\d]/.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function W(){if(/[^\\d\\w_]/.test(e)){var t=S.join(\"\");return M=R.indexOf(t)>-1?y:D.indexOf(t)>-1?m:v,F(S.join(\"\")),M=l,T}return S.push(e),r=e,T+1}};var n=t(\"./lib/literals\"),i=t(\"./lib/operators\"),a=t(\"./lib/builtins\"),o=t(\"./lib/literals-300es\"),s=t(\"./lib/builtins-300es\"),l=999,c=9999,u=0,h=1,f=2,p=3,d=4,g=5,v=6,m=7,y=8,x=9,b=10,_=11,w=[\"block-comment\",\"line-comment\",\"preprocessor\",\"operator\",\"integer\",\"float\",\"ident\",\"builtin\",\"keyword\",\"whitespace\",\"eof\",\"integer\"]},{\"./lib/builtins\":404,\"./lib/builtins-300es\":403,\"./lib/literals\":406,\"./lib/literals-300es\":405,\"./lib/operators\":407}],403:[function(t,e,r){var n=t(\"./builtins\");n=n.slice().filter(function(t){return!/^(gl\\_|texture)/.test(t)}),e.exports=n.concat([\"gl_VertexID\",\"gl_InstanceID\",\"gl_Position\",\"gl_PointSize\",\"gl_FragCoord\",\"gl_FrontFacing\",\"gl_FragDepth\",\"gl_PointCoord\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexUniformVectors\",\"gl_MaxVertexOutputVectors\",\"gl_MaxFragmentInputVectors\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxTextureImageUnits\",\"gl_MaxFragmentUniformVectors\",\"gl_MaxDrawBuffers\",\"gl_MinProgramTexelOffset\",\"gl_MaxProgramTexelOffset\",\"gl_DepthRangeParameters\",\"gl_DepthRange\",\"trunc\",\"round\",\"roundEven\",\"isnan\",\"isinf\",\"floatBitsToInt\",\"floatBitsToUint\",\"intBitsToFloat\",\"uintBitsToFloat\",\"packSnorm2x16\",\"unpackSnorm2x16\",\"packUnorm2x16\",\"unpackUnorm2x16\",\"packHalf2x16\",\"unpackHalf2x16\",\"outerProduct\",\"transpose\",\"determinant\",\"inverse\",\"texture\",\"textureSize\",\"textureProj\",\"textureLod\",\"textureOffset\",\"texelFetch\",\"texelFetchOffset\",\"textureProjOffset\",\"textureLodOffset\",\"textureProjLod\",\"textureProjLodOffset\",\"textureGrad\",\"textureGradOffset\",\"textureProjGrad\",\"textureProjGradOffset\"])},{\"./builtins\":404}],404:[function(t,e,r){e.exports=[\"abs\",\"acos\",\"all\",\"any\",\"asin\",\"atan\",\"ceil\",\"clamp\",\"cos\",\"cross\",\"dFdx\",\"dFdy\",\"degrees\",\"distance\",\"dot\",\"equal\",\"exp\",\"exp2\",\"faceforward\",\"floor\",\"fract\",\"gl_BackColor\",\"gl_BackLightModelProduct\",\"gl_BackLightProduct\",\"gl_BackMaterial\",\"gl_BackSecondaryColor\",\"gl_ClipPlane\",\"gl_ClipVertex\",\"gl_Color\",\"gl_DepthRange\",\"gl_DepthRangeParameters\",\"gl_EyePlaneQ\",\"gl_EyePlaneR\",\"gl_EyePlaneS\",\"gl_EyePlaneT\",\"gl_Fog\",\"gl_FogCoord\",\"gl_FogFragCoord\",\"gl_FogParameters\",\"gl_FragColor\",\"gl_FragCoord\",\"gl_FragData\",\"gl_FragDepth\",\"gl_FragDepthEXT\",\"gl_FrontColor\",\"gl_FrontFacing\",\"gl_FrontLightModelProduct\",\"gl_FrontLightProduct\",\"gl_FrontMaterial\",\"gl_FrontSecondaryColor\",\"gl_LightModel\",\"gl_LightModelParameters\",\"gl_LightModelProducts\",\"gl_LightProducts\",\"gl_LightSource\",\"gl_LightSourceParameters\",\"gl_MaterialParameters\",\"gl_MaxClipPlanes\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxDrawBuffers\",\"gl_MaxFragmentUniformComponents\",\"gl_MaxLights\",\"gl_MaxTextureCoords\",\"gl_MaxTextureImageUnits\",\"gl_MaxTextureUnits\",\"gl_MaxVaryingFloats\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxVertexUniformComponents\",\"gl_ModelViewMatrix\",\"gl_ModelViewMatrixInverse\",\"gl_ModelViewMatrixInverseTranspose\",\"gl_ModelViewMatrixTranspose\",\"gl_ModelViewProjectionMatrix\",\"gl_ModelViewProjectionMatrixInverse\",\"gl_ModelViewProjectionMatrixInverseTranspose\",\"gl_ModelViewProjectionMatrixTranspose\",\"gl_MultiTexCoord0\",\"gl_MultiTexCoord1\",\"gl_MultiTexCoord2\",\"gl_MultiTexCoord3\",\"gl_MultiTexCoord4\",\"gl_MultiTexCoord5\",\"gl_MultiTexCoord6\",\"gl_MultiTexCoord7\",\"gl_Normal\",\"gl_NormalMatrix\",\"gl_NormalScale\",\"gl_ObjectPlaneQ\",\"gl_ObjectPlaneR\",\"gl_ObjectPlaneS\",\"gl_ObjectPlaneT\",\"gl_Point\",\"gl_PointCoord\",\"gl_PointParameters\",\"gl_PointSize\",\"gl_Position\",\"gl_ProjectionMatrix\",\"gl_ProjectionMatrixInverse\",\"gl_ProjectionMatrixInverseTranspose\",\"gl_ProjectionMatrixTranspose\",\"gl_SecondaryColor\",\"gl_TexCoord\",\"gl_TextureEnvColor\",\"gl_TextureMatrix\",\"gl_TextureMatrixInverse\",\"gl_TextureMatrixInverseTranspose\",\"gl_TextureMatrixTranspose\",\"gl_Vertex\",\"greaterThan\",\"greaterThanEqual\",\"inversesqrt\",\"length\",\"lessThan\",\"lessThanEqual\",\"log\",\"log2\",\"matrixCompMult\",\"max\",\"min\",\"mix\",\"mod\",\"normalize\",\"not\",\"notEqual\",\"pow\",\"radians\",\"reflect\",\"refract\",\"sign\",\"sin\",\"smoothstep\",\"sqrt\",\"step\",\"tan\",\"texture2D\",\"texture2DLod\",\"texture2DProj\",\"texture2DProjLod\",\"textureCube\",\"textureCubeLod\",\"texture2DLodEXT\",\"texture2DProjLodEXT\",\"textureCubeLodEXT\",\"texture2DGradEXT\",\"texture2DProjGradEXT\",\"textureCubeGradEXT\"]},{}],405:[function(t,e,r){var n=t(\"./literals\");e.exports=n.slice().concat([\"layout\",\"centroid\",\"smooth\",\"case\",\"mat2x2\",\"mat2x3\",\"mat2x4\",\"mat3x2\",\"mat3x3\",\"mat3x4\",\"mat4x2\",\"mat4x3\",\"mat4x4\",\"uint\",\"uvec2\",\"uvec3\",\"uvec4\",\"samplerCubeShadow\",\"sampler2DArray\",\"sampler2DArrayShadow\",\"isampler2D\",\"isampler3D\",\"isamplerCube\",\"isampler2DArray\",\"usampler2D\",\"usampler3D\",\"usamplerCube\",\"usampler2DArray\",\"coherent\",\"restrict\",\"readonly\",\"writeonly\",\"resource\",\"atomic_uint\",\"noperspective\",\"patch\",\"sample\",\"subroutine\",\"common\",\"partition\",\"active\",\"filter\",\"image1D\",\"image2D\",\"image3D\",\"imageCube\",\"iimage1D\",\"iimage2D\",\"iimage3D\",\"iimageCube\",\"uimage1D\",\"uimage2D\",\"uimage3D\",\"uimageCube\",\"image1DArray\",\"image2DArray\",\"iimage1DArray\",\"iimage2DArray\",\"uimage1DArray\",\"uimage2DArray\",\"image1DShadow\",\"image2DShadow\",\"image1DArrayShadow\",\"image2DArrayShadow\",\"imageBuffer\",\"iimageBuffer\",\"uimageBuffer\",\"sampler1DArray\",\"sampler1DArrayShadow\",\"isampler1D\",\"isampler1DArray\",\"usampler1D\",\"usampler1DArray\",\"isampler2DRect\",\"usampler2DRect\",\"samplerBuffer\",\"isamplerBuffer\",\"usamplerBuffer\",\"sampler2DMS\",\"isampler2DMS\",\"usampler2DMS\",\"sampler2DMSArray\",\"isampler2DMSArray\",\"usampler2DMSArray\"])},{\"./literals\":406}],406:[function(t,e,r){e.exports=[\"precision\",\"highp\",\"mediump\",\"lowp\",\"attribute\",\"const\",\"uniform\",\"varying\",\"break\",\"continue\",\"do\",\"for\",\"while\",\"if\",\"else\",\"in\",\"out\",\"inout\",\"float\",\"int\",\"void\",\"bool\",\"true\",\"false\",\"discard\",\"return\",\"mat2\",\"mat3\",\"mat4\",\"vec2\",\"vec3\",\"vec4\",\"ivec2\",\"ivec3\",\"ivec4\",\"bvec2\",\"bvec3\",\"bvec4\",\"sampler1D\",\"sampler2D\",\"sampler3D\",\"samplerCube\",\"sampler1DShadow\",\"sampler2DShadow\",\"struct\",\"asm\",\"class\",\"union\",\"enum\",\"typedef\",\"template\",\"this\",\"packed\",\"goto\",\"switch\",\"default\",\"inline\",\"noinline\",\"volatile\",\"public\",\"static\",\"extern\",\"external\",\"interface\",\"long\",\"short\",\"double\",\"half\",\"fixed\",\"unsigned\",\"input\",\"output\",\"hvec2\",\"hvec3\",\"hvec4\",\"dvec2\",\"dvec3\",\"dvec4\",\"fvec2\",\"fvec3\",\"fvec4\",\"sampler2DRect\",\"sampler3DRect\",\"sampler2DRectShadow\",\"sizeof\",\"cast\",\"namespace\",\"using\"]},{}],407:[function(t,e,r){e.exports=[\"<<=\",\">>=\",\"++\",\"--\",\"<<\",\">>\",\"<=\",\">=\",\"==\",\"!=\",\"&&\",\"||\",\"+=\",\"-=\",\"*=\",\"/=\",\"%=\",\"&=\",\"^^\",\"^=\",\"|=\",\"(\",\")\",\"[\",\"]\",\".\",\"!\",\"~\",\"*\",\"/\",\"%\",\"+\",\"-\",\"<\",\">\",\"&\",\"^\",\"|\",\"?\",\":\",\"=\",\",\",\";\",\"{\",\"}\"]},{}],408:[function(t,e,r){var n=t(\"./index\");e.exports=function(t,e){var r=n(e),i=[];return i=(i=i.concat(r(t))).concat(r(null))}},{\"./index\":402}],409:[function(t,e,r){e.exports=function(t){\"string\"==typeof t&&(t=[t]);for(var e=[].slice.call(arguments,1),r=[],n=0;n<t.length-1;n++)r.push(t[n],e[n]||\"\");return r.push(t[n]),r.join(\"\")}},{}],410:[function(t,e,r){(function(r){\"use strict\";var n,i=t(\"is-browser\");n=\"function\"==typeof r.matchMedia?!r.matchMedia(\"(hover: none)\").matches:i,e.exports=n}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"is-browser\":417}],411:[function(t,e,r){\"use strict\";var n=t(\"is-browser\");e.exports=n&&function(){var t=!1;try{var e=Object.defineProperty({},\"passive\",{get:function(){t=!0}});window.addEventListener(\"test\",null,e),window.removeEventListener(\"test\",null,e)}catch(e){t=!1}return t}()},{\"is-browser\":417}],412:[function(t,e,r){r.read=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?i-1:0,f=r?-1:1,p=t[e+h];for(h+=f,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+h],h+=f,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},r.write=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,h=u>>1,f=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,i),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g}},{}],413:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(0===r)throw new Error(\"Must have at least d+1 points\");var i=t[0].length;if(r<=i)throw new Error(\"Must input at least d+1 points\");var o=t.slice(0,i+1),s=n.apply(void 0,o);if(0===s)throw new Error(\"Input not in general position\");for(var l=new Array(i+1),u=0;u<=i;++u)l[u]=u;s<0&&(l[0]=1,l[1]=0);for(var h=new a(l,new Array(i+1),!1),f=h.adjacent,p=new Array(i+2),u=0;u<=i;++u){for(var d=l.slice(),g=0;g<=i;++g)g===u&&(d[g]=-1);var v=d[0];d[0]=d[1],d[1]=v;var m=new a(d,new Array(i+1),!0);f[u]=m,p[u]=m}p[i+1]=h;for(var u=0;u<=i;++u)for(var d=f[u].vertices,y=f[u].adjacent,g=0;g<=i;++g){var x=d[g];if(x<0)y[g]=h;else for(var b=0;b<=i;++b)f[b].vertices.indexOf(x)<0&&(y[g]=f[b])}for(var _=new c(i,o,p),w=!!e,u=i+1;u<r;++u)_.insert(t[u],w);return _.boundary()};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\").compareCells;function a(t,e,r){this.vertices=t,this.adjacent=e,this.boundary=r,this.lastVisited=-1}function o(t,e,r){this.vertices=t,this.cell=e,this.index=r}function s(t,e){return i(t.vertices,e.vertices)}a.prototype.flip=function(){var t=this.vertices[0];this.vertices[0]=this.vertices[1],this.vertices[1]=t;var e=this.adjacent[0];this.adjacent[0]=this.adjacent[1],this.adjacent[1]=e};var l=[];function c(t,e,r){this.dimension=t,this.vertices=e,this.simplices=r,this.interior=r.filter(function(t){return!t.boundary}),this.tuple=new Array(t+1);for(var i=0;i<=t;++i)this.tuple[i]=this.vertices[i];var a=l[t];a||(a=l[t]=function(t){for(var e=[\"function orient(){var tuple=this.tuple;return test(\"],r=0;r<=t;++r)r>0&&e.push(\",\"),e.push(\"tuple[\",r,\"]\");e.push(\")}return orient\");var i=new Function(\"test\",e.join(\"\")),a=n[t+1];return a||(a=n),i(a)}(t)),this.orient=a}var u=c.prototype;u.handleBoundaryDegeneracy=function(t,e){var r=this.dimension,n=this.vertices.length-1,i=this.tuple,a=this.vertices,o=[t];for(t.lastVisited=-n;o.length>0;){(t=o.pop()).vertices;for(var s=t.adjacent,l=0;l<=r;++l){var c=s[l];if(c.boundary&&!(c.lastVisited<=-n)){for(var u=c.vertices,h=0;h<=r;++h){var f=u[h];i[h]=f<0?e:a[f]}var p=this.orient();if(p>0)return c;c.lastVisited=-n,0===p&&o.push(c)}}}return null},u.walk=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,a=this.tuple,o=e?this.interior.length*Math.random()|0:this.interior.length-1,s=this.interior[o];t:for(;!s.boundary;){for(var l=s.vertices,c=s.adjacent,u=0;u<=n;++u)a[u]=i[l[u]];s.lastVisited=r;for(u=0;u<=n;++u){var h=c[u];if(!(h.lastVisited>=r)){var f=a[u];a[u]=t;var p=this.orient();if(a[u]=f,p<0){s=h;continue t}h.boundary?h.lastVisited=-r:h.lastVisited=r}}return}return s},u.addPeaks=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,l=this.tuple,c=this.interior,u=this.simplices,h=[e];e.lastVisited=r,e.vertices[e.vertices.indexOf(-1)]=r,e.boundary=!1,c.push(e);for(var f=[];h.length>0;){var p=(e=h.pop()).vertices,d=e.adjacent,g=p.indexOf(r);if(!(g<0))for(var v=0;v<=n;++v)if(v!==g){var m=d[v];if(m.boundary&&!(m.lastVisited>=r)){var y=m.vertices;if(m.lastVisited!==-r){for(var x=0,b=0;b<=n;++b)y[b]<0?(x=b,l[b]=t):l[b]=i[y[b]];if(this.orient()>0){y[x]=r,m.boundary=!1,c.push(m),h.push(m),m.lastVisited=r;continue}m.lastVisited=-r}var _=m.adjacent,w=p.slice(),k=d.slice(),T=new a(w,k,!0);u.push(T);var A=_.indexOf(e);if(!(A<0)){_[A]=T,k[g]=m,w[v]=-1,k[v]=e,d[v]=T,T.flip();for(b=0;b<=n;++b){var M=w[b];if(!(M<0||M===r)){for(var S=new Array(n-1),E=0,C=0;C<=n;++C){var L=w[C];L<0||C===b||(S[E++]=L)}f.push(new o(S,T,b))}}}}}}f.sort(s);for(v=0;v+1<f.length;v+=2){var P=f[v],O=f[v+1],z=P.index,I=O.index;z<0||I<0||(P.cell.adjacent[P.index]=O.cell,O.cell.adjacent[O.index]=P.cell)}},u.insert=function(t,e){var r=this.vertices;r.push(t);var n=this.walk(t,e);if(n){for(var i=this.dimension,a=this.tuple,o=0;o<=i;++o){var s=n.vertices[o];a[o]=s<0?t:r[s]}var l=this.orient(a);l<0||(0!==l||(n=this.handleBoundaryDegeneracy(n,t)))&&this.addPeaks(t,n)}},u.boundary=function(){for(var t=this.dimension,e=[],r=this.simplices,n=r.length,i=0;i<n;++i){var a=r[i];if(a.boundary){for(var o=new Array(t),s=a.vertices,l=0,c=0,u=0;u<=t;++u)s[u]>=0?o[l++]=s[u]:c=1&u;if(c===(1&t)){var h=o[0];o[0]=o[1],o[1]=h}e.push(o)}}return e}},{\"robust-orientation\":510,\"simplicial-complex\":520}],414:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=0,a=1;function o(t,e,r,n,i){this.mid=t,this.left=e,this.right=r,this.leftPoints=n,this.rightPoints=i,this.count=(e?e.count:0)+(r?r.count:0)+n.length}e.exports=function(t){if(!t||0===t.length)return new x(null);return new x(y(t))};var s=o.prototype;function l(t,e){t.mid=e.mid,t.left=e.left,t.right=e.right,t.leftPoints=e.leftPoints,t.rightPoints=e.rightPoints,t.count=e.count}function c(t,e){var r=y(e);t.mid=r.mid,t.left=r.left,t.right=r.right,t.leftPoints=r.leftPoints,t.rightPoints=r.rightPoints,t.count=r.count}function u(t,e){var r=t.intervals([]);r.push(e),c(t,r)}function h(t,e){var r=t.intervals([]),n=r.indexOf(e);return n<0?i:(r.splice(n,1),c(t,r),a)}function f(t,e,r){for(var n=0;n<t.length&&t[n][0]<=e;++n){var i=r(t[n]);if(i)return i}}function p(t,e,r){for(var n=t.length-1;n>=0&&t[n][1]>=e;--n){var i=r(t[n]);if(i)return i}}function d(t,e){for(var r=0;r<t.length;++r){var n=e(t[r]);if(n)return n}}function g(t,e){return t-e}function v(t,e){var r=t[0]-e[0];return r||t[1]-e[1]}function m(t,e){var r=t[1]-e[1];return r||t[0]-e[0]}function y(t){if(0===t.length)return null;for(var e=[],r=0;r<t.length;++r)e.push(t[r][0],t[r][1]);e.sort(g);var n=e[e.length>>1],i=[],a=[],s=[];for(r=0;r<t.length;++r){var l=t[r];l[1]<n?i.push(l):n<l[0]?a.push(l):s.push(l)}var c=s,u=s.slice();return c.sort(v),u.sort(m),new o(n,y(i),y(a),c,u)}function x(t){this.root=t}s.intervals=function(t){return t.push.apply(t,this.leftPoints),this.left&&this.left.intervals(t),this.right&&this.right.intervals(t),t},s.insert=function(t){var e=this.count-this.leftPoints.length;if(this.count+=1,t[1]<this.mid)this.left?4*(this.left.count+1)>3*(e+1)?u(this,t):this.left.insert(t):this.left=y([t]);else if(t[0]>this.mid)this.right?4*(this.right.count+1)>3*(e+1)?u(this,t):this.right.insert(t):this.right=y([t]);else{var r=n.ge(this.leftPoints,t,v),i=n.ge(this.rightPoints,t,m);this.leftPoints.splice(r,0,t),this.rightPoints.splice(i,0,t)}},s.remove=function(t){var e=this.count-this.leftPoints;if(t[1]<this.mid)return this.left?4*(this.right?this.right.count:0)>3*(e-1)?h(this,t):2===(c=this.left.remove(t))?(this.left=null,this.count-=1,a):(c===a&&(this.count-=1),c):i;if(t[0]>this.mid)return this.right?4*(this.left?this.left.count:0)>3*(e-1)?h(this,t):2===(c=this.right.remove(t))?(this.right=null,this.count-=1,a):(c===a&&(this.count-=1),c):i;if(1===this.count)return this.leftPoints[0]===t?2:i;if(1===this.leftPoints.length&&this.leftPoints[0]===t){if(this.left&&this.right){for(var r=this,o=this.left;o.right;)r=o,o=o.right;if(r===this)o.right=this.right;else{var s=this.left,c=this.right;r.count-=o.count,r.right=o.left,o.left=s,o.right=c}l(this,o),this.count=(this.left?this.left.count:0)+(this.right?this.right.count:0)+this.leftPoints.length}else this.left?l(this,this.left):l(this,this.right);return a}for(s=n.ge(this.leftPoints,t,v);s<this.leftPoints.length&&this.leftPoints[s][0]===t[0];++s)if(this.leftPoints[s]===t){this.count-=1,this.leftPoints.splice(s,1);for(c=n.ge(this.rightPoints,t,m);c<this.rightPoints.length&&this.rightPoints[c][1]===t[1];++c)if(this.rightPoints[c]===t)return this.rightPoints.splice(c,1),a}return i},s.queryPoint=function(t,e){if(t<this.mid){if(this.left)if(r=this.left.queryPoint(t,e))return r;return f(this.leftPoints,t,e)}if(t>this.mid){var r;if(this.right)if(r=this.right.queryPoint(t,e))return r;return p(this.rightPoints,t,e)}return d(this.leftPoints,e)},s.queryInterval=function(t,e,r){var n;if(t<this.mid&&this.left&&(n=this.left.queryInterval(t,e,r)))return n;if(e>this.mid&&this.right&&(n=this.right.queryInterval(t,e,r)))return n;return e<this.mid?f(this.leftPoints,e,r):t>this.mid?p(this.rightPoints,t,r):d(this.leftPoints,r)};var b=x.prototype;b.insert=function(t){this.root?this.root.insert(t):this.root=new o(t[0],null,null,[t],[t])},b.remove=function(t){if(this.root){var e=this.root.remove(t);return 2===e&&(this.root=null),e!==i}return!1},b.queryPoint=function(t,e){if(this.root)return this.root.queryPoint(t,e)},b.queryInterval=function(t,e,r){if(t<=e&&this.root)return this.root.queryInterval(t,e,r)},Object.defineProperty(b,\"count\",{get:function(){return this.root?this.root.count:0}}),Object.defineProperty(b,\"intervals\",{get:function(){return this.root?this.root.intervals([]):[]}})},{\"binary-search-bounds\":91}],415:[function(t,e,r){\"use strict\";e.exports=function(t,e){e=e||new Array(t.length);for(var r=0;r<t.length;++r)e[t[r]]=r;return e}},{}],416:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=r;return e}},{}],417:[function(t,e,r){e.exports=!0},{}],418:[function(t,e,r){function n(t){return!!t.constructor&&\"function\"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}e.exports=function(t){return null!=t&&(n(t)||function(t){return\"function\"==typeof t.readFloatLE&&\"function\"==typeof t.slice&&n(t.slice(0,0))}(t)||!!t._isBuffer)}},{}],419:[function(t,e,r){\"use strict\";e.exports=\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion))},{}],420:[function(t,e,r){\"use strict\";e.exports=a,e.exports.isMobile=a;var n=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i,i=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino|android|ipad|playbook|silk/i;function a(t){t||(t={});var e=t.ua;return e||\"undefined\"==typeof navigator||(e=navigator.userAgent),e&&e.headers&&\"string\"==typeof e.headers[\"user-agent\"]&&(e=e.headers[\"user-agent\"]),\"string\"==typeof e&&(t.tablet?i.test(e):n.test(e))}},{}],421:[function(t,e,r){\"use strict\";e.exports=function(t){var e=typeof t;return null!==t&&(\"object\"===e||\"function\"===e)}},{}],422:[function(t,e,r){\"use strict\";var n=Object.prototype.toString;e.exports=function(t){var e;return\"[object Object]\"===n.call(t)&&(null===(e=Object.getPrototypeOf(t))||e===Object.getPrototypeOf({}))}},{}],423:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=t.length,n=0;n<r;n++)if(((e=t.charCodeAt(n))<9||e>13)&&32!==e&&133!==e&&160!==e&&5760!==e&&6158!==e&&(e<8192||e>8205)&&8232!==e&&8233!==e&&8239!==e&&8287!==e&&8288!==e&&12288!==e&&65279!==e)return!1;return!0}},{}],424:[function(t,e,r){\"use strict\";e.exports=function(t){return\"string\"==typeof t&&(t=t.trim(),!!(/^[mzlhvcsqta]\\s*[-+.0-9][^mlhvzcsqta]+/i.test(t)&&/[\\dz]$/i.test(t)&&t.length>4))}},{}],425:[function(t,e,r){e.exports=function(t,e,r){return t*(1-r)+e*r}},{}],426:[function(t,e,r){var n,i;n=this,i=function(){\"use strict\";var t,e,r;function n(n,i){if(t)if(e){var a=\"var sharedChunk = {}; (\"+t+\")(sharedChunk); (\"+e+\")(sharedChunk);\",o={};t(o),(r=i(o)).workerUrl=window.URL.createObjectURL(new Blob([a],{type:\"text/javascript\"}))}else e=i;else t=i}return n(0,function(t){function e(t,e){return t(e={exports:{}},e.exports),e.exports}var r=n;function n(t,e,r,n){this.cx=3*t,this.bx=3*(r-t)-this.cx,this.ax=1-this.cx-this.bx,this.cy=3*e,this.by=3*(n-e)-this.cy,this.ay=1-this.cy-this.by,this.p1x=t,this.p1y=n,this.p2x=r,this.p2y=n}n.prototype.sampleCurveX=function(t){return((this.ax*t+this.bx)*t+this.cx)*t},n.prototype.sampleCurveY=function(t){return((this.ay*t+this.by)*t+this.cy)*t},n.prototype.sampleCurveDerivativeX=function(t){return(3*this.ax*t+2*this.bx)*t+this.cx},n.prototype.solveCurveX=function(t,e){var r,n,i,a,o;for(void 0===e&&(e=1e-6),i=t,o=0;o<8;o++){if(a=this.sampleCurveX(i)-t,Math.abs(a)<e)return i;var s=this.sampleCurveDerivativeX(i);if(Math.abs(s)<1e-6)break;i-=a/s}if((i=t)<(r=0))return r;if(i>(n=1))return n;for(;r<n;){if(a=this.sampleCurveX(i),Math.abs(a-t)<e)return i;t>a?r=i:n=i,i=.5*(n-r)+r}return i},n.prototype.solve=function(t,e){return this.sampleCurveY(this.solveCurveX(t,e))};var i=a;function a(t,e){this.x=t,this.y=e}function o(t,e){if(Array.isArray(t)){if(!Array.isArray(e)||t.length!==e.length)return!1;for(var r=0;r<t.length;r++)if(!o(t[r],e[r]))return!1;return!0}if(\"object\"==typeof t&&null!==t&&null!==e){if(\"object\"!=typeof e)return!1;if(Object.keys(t).length!==Object.keys(e).length)return!1;for(var n in t)if(!o(t[n],e[n]))return!1;return!0}return t===e}function s(t,e,n,i){var a=new r(t,e,n,i);return function(t){return a.solve(t)}}a.prototype={clone:function(){return new a(this.x,this.y)},add:function(t){return this.clone()._add(t)},sub:function(t){return this.clone()._sub(t)},multByPoint:function(t){return this.clone()._multByPoint(t)},divByPoint:function(t){return this.clone()._divByPoint(t)},mult:function(t){return this.clone()._mult(t)},div:function(t){return this.clone()._div(t)},rotate:function(t){return this.clone()._rotate(t)},rotateAround:function(t,e){return this.clone()._rotateAround(t,e)},matMult:function(t){return this.clone()._matMult(t)},unit:function(){return this.clone()._unit()},perp:function(){return this.clone()._perp()},round:function(){return this.clone()._round()},mag:function(){return Math.sqrt(this.x*this.x+this.y*this.y)},equals:function(t){return this.x===t.x&&this.y===t.y},dist:function(t){return Math.sqrt(this.distSqr(t))},distSqr:function(t){var e=t.x-this.x,r=t.y-this.y;return e*e+r*r},angle:function(){return Math.atan2(this.y,this.x)},angleTo:function(t){return Math.atan2(this.y-t.y,this.x-t.x)},angleWith:function(t){return this.angleWithSep(t.x,t.y)},angleWithSep:function(t,e){return Math.atan2(this.x*e-this.y*t,this.x*t+this.y*e)},_matMult:function(t){var e=t[0]*this.x+t[1]*this.y,r=t[2]*this.x+t[3]*this.y;return this.x=e,this.y=r,this},_add:function(t){return this.x+=t.x,this.y+=t.y,this},_sub:function(t){return this.x-=t.x,this.y-=t.y,this},_mult:function(t){return this.x*=t,this.y*=t,this},_div:function(t){return this.x/=t,this.y/=t,this},_multByPoint:function(t){return this.x*=t.x,this.y*=t.y,this},_divByPoint:function(t){return this.x/=t.x,this.y/=t.y,this},_unit:function(){return this._div(this.mag()),this},_perp:function(){var t=this.y;return this.y=this.x,this.x=-t,this},_rotate:function(t){var e=Math.cos(t),r=Math.sin(t),n=e*this.x-r*this.y,i=r*this.x+e*this.y;return this.x=n,this.y=i,this},_rotateAround:function(t,e){var r=Math.cos(t),n=Math.sin(t),i=e.x+r*(this.x-e.x)-n*(this.y-e.y),a=e.y+n*(this.x-e.x)+r*(this.y-e.y);return this.x=i,this.y=a,this},_round:function(){return this.x=Math.round(this.x),this.y=Math.round(this.y),this}},a.convert=function(t){return t instanceof a?t:Array.isArray(t)?new a(t[0],t[1]):t};var l=s(.25,.1,.25,1);function c(t,e,r){return Math.min(r,Math.max(e,t))}function u(t,e,r){var n=r-e,i=((t-e)%n+n)%n+e;return i===e?r:i}function h(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}var f=1;function p(){return f++}function d(){return function t(e){return e?(e^16*Math.random()>>e/4).toString(16):([1e7]+-[1e3]+-4e3+-8e3+-1e11).replace(/[018]/g,t)}()}function g(t){return!!t&&/^[0-9a-f]{8}-[0-9a-f]{4}-[4][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$/i.test(t)}function v(t,e){t.forEach(function(t){e[t]&&(e[t]=e[t].bind(e))})}function m(t,e){return-1!==t.indexOf(e,t.length-e.length)}function y(t,e,r){var n={};for(var i in t)n[i]=e.call(r||this,t[i],i,t);return n}function x(t,e,r){var n={};for(var i in t)e.call(r||this,t[i],i,t)&&(n[i]=t[i]);return n}function b(t){return Array.isArray(t)?t.map(b):\"object\"==typeof t&&t?y(t,b):t}var _={};function w(t){_[t]||(\"undefined\"!=typeof console&&console.warn(t),_[t]=!0)}function k(t,e,r){return(r.y-t.y)*(e.x-t.x)>(e.y-t.y)*(r.x-t.x)}function T(t){for(var e=0,r=0,n=t.length,i=n-1,a=void 0,o=void 0;r<n;i=r++)a=t[r],e+=((o=t[i]).x-a.x)*(a.y+o.y);return e}function A(t){var e={};if(t.replace(/(?:^|(?:\\s*\\,\\s*))([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)(?:\\=(?:([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)|(?:\\\"((?:[^\"\\\\]|\\\\.)*)\\\")))?/g,function(t,r,n,i){var a=n||i;return e[r]=!a||a.toLowerCase(),\"\"}),e[\"max-age\"]){var r=parseInt(e[\"max-age\"],10);isNaN(r)?delete e[\"max-age\"]:e[\"max-age\"]=r}return e}function M(t){try{var e=self[t];return e.setItem(\"_mapbox_test_\",1),e.removeItem(\"_mapbox_test_\"),!0}catch(t){return!1}}var S,E,C,L=self.performance&&self.performance.now?self.performance.now.bind(self.performance):Date.now.bind(Date),P=self.requestAnimationFrame||self.mozRequestAnimationFrame||self.webkitRequestAnimationFrame||self.msRequestAnimationFrame,O=self.cancelAnimationFrame||self.mozCancelAnimationFrame||self.webkitCancelAnimationFrame||self.msCancelAnimationFrame,z={now:L,frame:function(t){var e=P(t);return{cancel:function(){return O(e)}}},getImageData:function(t){var e=self.document.createElement(\"canvas\"),r=e.getContext(\"2d\");if(!r)throw new Error(\"failed to create canvas 2d context\");return e.width=t.width,e.height=t.height,r.drawImage(t,0,0,t.width,t.height),r.getImageData(0,0,t.width,t.height)},resolveURL:function(t){return S||(S=self.document.createElement(\"a\")),S.href=t,S.href},hardwareConcurrency:self.navigator.hardwareConcurrency||4,get devicePixelRatio(){return self.devicePixelRatio}},I={API_URL:\"https://api.mapbox.com\",get EVENTS_URL(){return this.API_URL?0===this.API_URL.indexOf(\"https://api.mapbox.cn\")?\"https://events.mapbox.cn/events/v2\":0===this.API_URL.indexOf(\"https://api.mapbox.com\")?\"https://events.mapbox.com/events/v2\":null:null},FEEDBACK_URL:\"https://apps.mapbox.com/feedback\",REQUIRE_ACCESS_TOKEN:!0,ACCESS_TOKEN:null,MAX_PARALLEL_IMAGE_REQUESTS:16},D={supported:!1,testSupport:function(t){!R&&C&&(F?B(t):E=t)}},R=!1,F=!1;function B(t){var e=t.createTexture();t.bindTexture(t.TEXTURE_2D,e);try{if(t.texImage2D(t.TEXTURE_2D,0,t.RGBA,t.RGBA,t.UNSIGNED_BYTE,C),t.isContextLost())return;D.supported=!0}catch(t){}t.deleteTexture(e),R=!0}self.document&&((C=self.document.createElement(\"img\")).onload=function(){E&&B(E),E=null,F=!0},C.onerror=function(){R=!0,E=null},C.src=\"data:image/webp;base64,UklGRh4AAABXRUJQVlA4TBEAAAAvAQAAAAfQ//73v/+BiOh/AAA=\");var N=\"01\",j=function(t){this._transformRequestFn=t,this._createSkuToken()};j.prototype._createSkuToken=function(){var t=function(){for(var t=\"\",e=0;e<10;e++)t+=\"0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ\"[Math.floor(62*Math.random())];return{token:[\"1\",N,t].join(\"\"),tokenExpiresAt:Date.now()+432e5}}();this._skuToken=t.token,this._skuTokenExpiresAt=t.tokenExpiresAt},j.prototype._isSkuTokenExpired=function(){return Date.now()>this._skuTokenExpiresAt},j.prototype.transformRequest=function(t,e){return this._transformRequestFn&&this._transformRequestFn(t,e)||{url:t}},j.prototype.normalizeStyleURL=function(t,e){return Y(t,e)},j.prototype.normalizeGlyphsURL=function(t,e){return W(t,e)},j.prototype.normalizeSourceURL=function(t,e){return X(t,e)},j.prototype.normalizeSpriteURL=function(t,e,r,n){return Z(t,e,r,n)},j.prototype.normalizeTileURL=function(t,e,r){return this._isSkuTokenExpired()&&this._createSkuToken(),K(t,e,r,this._skuToken)},j.prototype.canonicalizeTileURL=function(t){return Q(t)},j.prototype.canonicalizeTileset=function(t,e){return tt(t,e)};var U=\"See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\";function V(t,e){var r=rt(I.API_URL);if(t.protocol=r.protocol,t.authority=r.authority,\"/\"!==r.path&&(t.path=\"\"+r.path+t.path),!I.REQUIRE_ACCESS_TOKEN)return nt(t);if(!(e=e||I.ACCESS_TOKEN))throw new Error(\"An API access token is required to use Mapbox GL. \"+U);if(\"s\"===e[0])throw new Error(\"Use a public access token (pk.*) with Mapbox GL, not a secret access token (sk.*). \"+U);return t.params.push(\"access_token=\"+e),nt(t)}function q(t){return 0===t.indexOf(\"mapbox:\")}var H=/^((https?:)?\\/\\/)?([^\\/]+\\.)?mapbox\\.c(n|om)(\\/|\\?|$)/i;function G(t){return H.test(t)}var Y=function(t,e){if(!q(t))return t;var r=rt(t);return r.path=\"/styles/v1\"+r.path,V(r,e)},W=function(t,e){if(!q(t))return t;var r=rt(t);return r.path=\"/fonts/v1\"+r.path,V(r,e)},X=function(t,e){if(!q(t))return t;var r=rt(t);return r.path=\"/v4/\"+r.authority+\".json\",r.params.push(\"secure\"),V(r,e)},Z=function(t,e,r,n){var i=rt(t);return q(t)?(i.path=\"/styles/v1\"+i.path+\"/sprite\"+e+r,V(i,n)):(i.path+=\"\"+e+r,nt(i))},J=/(\\.(png|jpg)\\d*)(?=$)/,K=function(t,e,r,n){if(!e||!q(e))return t;var i=rt(t),a=z.devicePixelRatio>=2||512===r?\"@2x\":\"\",o=D.supported?\".webp\":\"$1\";return i.path=i.path.replace(J,\"\"+a+o),i.path=\"/v4\"+i.path,I.REQUIRE_ACCESS_TOKEN&&I.ACCESS_TOKEN&&n&&i.params.push(\"sku=\"+n),V(i)},$=/\\.[\\w]+$/,Q=function(t){var e=rt(t);if(!e.path.match(/(^\\/v4\\/)/)||!e.path.match($))return t;var r=\"mapbox://tiles/\";r+=e.path.replace(\"/v4/\",\"\");var n=e.params.filter(function(t){return!t.match(/^access_token=/)});return n.length&&(r+=\"?\"+n.join(\"&\")),r},tt=function(t,e){if(!q(e))return t.tiles||[];for(var r=[],n=0,i=t.tiles;n<i.length;n+=1){var a=i[n],o=Q(a);r.push(o)}return r},et=/^(\\w+):\\/\\/([^\\/?]*)(\\/[^?]+)?\\??(.+)?/;function rt(t){var e=t.match(et);if(!e)throw new Error(\"Unable to parse URL object\");return{protocol:e[1],authority:e[2],path:e[3]||\"/\",params:e[4]?e[4].split(\"&\"):[]}}function nt(t){var e=t.params.length?\"?\"+t.params.join(\"&\"):\"\";return t.protocol+\"://\"+t.authority+t.path+e}function it(t){if(!t)return null;var e,r=t.split(\".\");if(!r||3!==r.length)return null;try{return JSON.parse((e=r[1],decodeURIComponent(self.atob(e).split(\"\").map(function(t){return\"%\"+(\"00\"+t.charCodeAt(0).toString(16)).slice(-2)}).join(\"\"))))}catch(t){return null}}var at=function(t){this.type=t,this.anonId=null,this.eventData={},this.queue=[],this.pendingRequest=null};at.prototype.getStorageKey=function(t){var e,r=it(I.ACCESS_TOKEN),n=\"\";return r&&r.u?(e=r.u,n=self.btoa(encodeURIComponent(e).replace(/%([0-9A-F]{2})/g,function(t,e){return String.fromCharCode(Number(\"0x\"+e))}))):n=I.ACCESS_TOKEN||\"\",t?\"mapbox.eventData.\"+t+\":\"+n:\"mapbox.eventData:\"+n},at.prototype.fetchEventData=function(){var t=M(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{var n=self.localStorage.getItem(e);n&&(this.eventData=JSON.parse(n));var i=self.localStorage.getItem(r);i&&(this.anonId=i)}catch(t){w(\"Unable to read from LocalStorage\")}},at.prototype.saveEventData=function(){var t=M(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{self.localStorage.setItem(r,this.anonId),Object.keys(this.eventData).length>=1&&self.localStorage.setItem(e,JSON.stringify(this.eventData))}catch(t){w(\"Unable to write to LocalStorage\")}},at.prototype.processRequests=function(){},at.prototype.postEvent=function(t,e,r){var n=this;if(I.EVENTS_URL){var i=rt(I.EVENTS_URL);i.params.push(\"access_token=\"+(I.ACCESS_TOKEN||\"\"));var a={event:this.type,created:new Date(t).toISOString(),sdkIdentifier:\"mapbox-gl-js\",sdkVersion:\"1.1.1\",skuId:N,userId:this.anonId},o=e?h(a,e):a,s={url:nt(i),headers:{\"Content-Type\":\"text/plain\"},body:JSON.stringify([o])};this.pendingRequest=St(s,function(t){n.pendingRequest=null,r(t),n.saveEventData(),n.processRequests()})}},at.prototype.queueRequest=function(t){this.queue.push(t),this.processRequests()};var ot,st=function(t){function e(){t.call(this,\"map.load\"),this.success={},this.skuToken=\"\"}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.postMapLoadEvent=function(t,e,r){this.skuToken=r,I.EVENTS_URL&&I.ACCESS_TOKEN&&Array.isArray(t)&&t.some(function(t){return q(t)||G(t)})&&this.queueRequest({id:e,timestamp:Date.now()})},e.prototype.processRequests=function(){var t=this;if(!this.pendingRequest&&0!==this.queue.length){var e=this.queue.shift(),r=e.id,n=e.timestamp;r&&this.success[r]||(this.anonId||this.fetchEventData(),g(this.anonId)||(this.anonId=d()),this.postEvent(n,{skuToken:this.skuToken},function(e){e||r&&(t.success[r]=!0)}))}},e}(at),lt=new(function(t){function e(){t.call(this,\"appUserTurnstile\")}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.postTurnstileEvent=function(t){I.EVENTS_URL&&I.ACCESS_TOKEN&&Array.isArray(t)&&t.some(function(t){return q(t)||G(t)})&&this.queueRequest(Date.now())},e.prototype.processRequests=function(){var t=this;if(!this.pendingRequest&&0!==this.queue.length){this.anonId&&this.eventData.lastSuccess&&this.eventData.tokenU||this.fetchEventData();var e=it(I.ACCESS_TOKEN),r=e?e.u:I.ACCESS_TOKEN,n=r!==this.eventData.tokenU;g(this.anonId)||(this.anonId=d(),n=!0);var i=this.queue.shift();if(this.eventData.lastSuccess){var a=new Date(this.eventData.lastSuccess),o=new Date(i),s=(i-this.eventData.lastSuccess)/864e5;n=n||s>=1||s<-1||a.getDate()!==o.getDate()}else n=!0;if(!n)return this.processRequests();this.postEvent(i,{\"enabled.telemetry\":!1},function(e){e||(t.eventData.lastSuccess=i,t.eventData.tokenU=r)})}},e}(at)),ct=lt.postTurnstileEvent.bind(lt),ut=new st,ht=ut.postMapLoadEvent.bind(ut),ft=\"mapbox-tiles\",pt=500,dt=50,gt=42e4;function vt(t){var e=t.indexOf(\"?\");return e<0?t:t.slice(0,e)}var mt=1/0,yt={Unknown:\"Unknown\",Style:\"Style\",Source:\"Source\",Tile:\"Tile\",Glyphs:\"Glyphs\",SpriteImage:\"SpriteImage\",SpriteJSON:\"SpriteJSON\",Image:\"Image\"};\"function\"==typeof Object.freeze&&Object.freeze(yt);var xt=function(t){function e(e,r,n){401===r&&G(n)&&(e+=\": you may have provided an invalid Mapbox access token. See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\"),t.call(this,e),this.status=r,this.url=n,this.name=this.constructor.name,this.message=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.toString=function(){return this.name+\": \"+this.message+\" (\"+this.status+\"): \"+this.url},e}(Error);function bt(){return\"undefined\"!=typeof WorkerGlobalScope&&\"undefined\"!=typeof self&&self instanceof WorkerGlobalScope}var _t=bt()?function(){return self.worker&&self.worker.referrer}:function(){var t=self.location.origin;if(t&&\"null\"!==t&&\"file://\"!==t)return t+self.location.pathname};function wt(t,e){var r,n=new self.AbortController,i=new self.Request(t.url,{method:t.method||\"GET\",body:t.body,credentials:t.credentials,headers:t.headers,referrer:_t(),signal:n.signal}),a=!1,o=!1,s=(r=i.url).indexOf(\"sku=\")>0&&G(r);\"json\"===t.type&&i.headers.set(\"Accept\",\"application/json\");var l=function(r,n,a){if(!o){if(r&&\"SecurityError\"!==r.message&&w(r),n&&a)return c(n);var l=Date.now();self.fetch(i).then(function(r){if(r.ok){var n=s?r.clone():null;return c(r,n,l)}return e(new xt(r.statusText,r.status,t.url))}).catch(function(t){20!==t.code&&e(new Error(t.message))})}},c=function(r,n,s){(\"arrayBuffer\"===t.type?r.arrayBuffer():\"json\"===t.type?r.json():r.text()).then(function(t){o||(n&&s&&function(t,e,r){if(self.caches){var n={status:e.status,statusText:e.statusText,headers:new self.Headers};e.headers.forEach(function(t,e){return n.headers.set(e,t)});var i=A(e.headers.get(\"Cache-Control\")||\"\");i[\"no-store\"]||(i[\"max-age\"]&&n.headers.set(\"Expires\",new Date(r+1e3*i[\"max-age\"]).toUTCString()),new Date(n.headers.get(\"Expires\")).getTime()-r<gt||function(t,e){if(void 0===ot)try{new Response(new ReadableStream),ot=!0}catch(t){ot=!1}ot?e(t.body):t.blob().then(e)}(e,function(e){var r=new self.Response(e,n);self.caches.open(ft).then(function(e){return e.put(vt(t.url),r)})}))}}(i,n,s),a=!0,e(null,t,r.headers.get(\"Cache-Control\"),r.headers.get(\"Expires\")))}).catch(function(t){return e(new Error(t.message))})};return s?function(t,e){if(!self.caches)return e(null);var r=vt(t.url);self.caches.open(ft).catch(e).then(function(t){t.match(r).catch(e).then(function(n){var i=function(t){if(!t)return!1;var e=new Date(t.headers.get(\"Expires\")),r=A(t.headers.get(\"Cache-Control\")||\"\");return e>Date.now()&&!r[\"no-cache\"]}(n);t.delete(r),i&&t.put(r,n.clone()),e(null,n,i)})})}(i,l):l(null,null),{cancel:function(){o=!0,a||n.abort()}}}var kt,Tt,At=function(t,e){if(!/^file:/.test(t.url)){if(self.fetch&&self.Request&&self.AbortController&&self.Request.prototype.hasOwnProperty(\"signal\"))return wt(t,e);if(bt()&&self.worker&&self.worker.actor)return self.worker.actor.send(\"getResource\",t,e)}return function(t,e){var r=new self.XMLHttpRequest;for(var n in r.open(t.method||\"GET\",t.url,!0),\"arrayBuffer\"===t.type&&(r.responseType=\"arraybuffer\"),t.headers)r.setRequestHeader(n,t.headers[n]);return\"json\"===t.type&&r.setRequestHeader(\"Accept\",\"application/json\"),r.withCredentials=\"include\"===t.credentials,r.onerror=function(){e(new Error(r.statusText))},r.onload=function(){if((r.status>=200&&r.status<300||0===r.status)&&null!==r.response){var n=r.response;if(\"json\"===t.type)try{n=JSON.parse(r.response)}catch(t){return e(t)}e(null,n,r.getResponseHeader(\"Cache-Control\"),r.getResponseHeader(\"Expires\"))}else e(new xt(r.statusText,r.status,t.url))},r.send(t.body),{cancel:function(){return r.abort()}}}(t,e)},Mt=function(t,e){return At(h(t,{type:\"arrayBuffer\"}),e)},St=function(t,e){return At(h(t,{method:\"POST\"}),e)};kt=[],Tt=0;var Et=function(t,e){if(Tt>=I.MAX_PARALLEL_IMAGE_REQUESTS){var r={requestParameters:t,callback:e,cancelled:!1,cancel:function(){this.cancelled=!0}};return kt.push(r),r}Tt++;var n=!1,i=function(){if(!n)for(n=!0,Tt--;kt.length&&Tt<I.MAX_PARALLEL_IMAGE_REQUESTS;){var t=kt.shift(),e=t.requestParameters,r=t.callback;t.cancelled||(t.cancel=Et(e,r).cancel)}},a=Mt(t,function(t,r,n,a){if(i(),t)e(t);else if(r){var o=new self.Image,s=self.URL||self.webkitURL;o.onload=function(){e(null,o),s.revokeObjectURL(o.src)},o.onerror=function(){return e(new Error(\"Could not load image. Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.\"))};var l=new self.Blob([new Uint8Array(r)],{type:\"image/png\"});o.cacheControl=n,o.expires=a,o.src=r.byteLength?s.createObjectURL(l):\"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAC0lEQVQYV2NgAAIAAAUAAarVyFEAAAAASUVORK5CYII=\"}});return{cancel:function(){a.cancel(),i()}}};function Ct(t,e,r){r[t]&&-1!==r[t].indexOf(e)||(r[t]=r[t]||[],r[t].push(e))}function Lt(t,e,r){if(r&&r[t]){var n=r[t].indexOf(e);-1!==n&&r[t].splice(n,1)}}var Pt=function(t,e){void 0===e&&(e={}),h(this,e),this.type=t},Ot=function(t){function e(e,r){void 0===r&&(r={}),t.call(this,\"error\",h({error:e},r))}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Pt),zt=function(){};zt.prototype.on=function(t,e){return this._listeners=this._listeners||{},Ct(t,e,this._listeners),this},zt.prototype.off=function(t,e){return Lt(t,e,this._listeners),Lt(t,e,this._oneTimeListeners),this},zt.prototype.once=function(t,e){return this._oneTimeListeners=this._oneTimeListeners||{},Ct(t,e,this._oneTimeListeners),this},zt.prototype.fire=function(t,e){\"string\"==typeof t&&(t=new Pt(t,e||{}));var r=t.type;if(this.listens(r)){t.target=this;for(var n=0,i=this._listeners&&this._listeners[r]?this._listeners[r].slice():[];n<i.length;n+=1)i[n].call(this,t);for(var a=0,o=this._oneTimeListeners&&this._oneTimeListeners[r]?this._oneTimeListeners[r].slice():[];a<o.length;a+=1){var s=o[a];Lt(r,s,this._oneTimeListeners),s.call(this,t)}var l=this._eventedParent;l&&(h(t,\"function\"==typeof this._eventedParentData?this._eventedParentData():this._eventedParentData),l.fire(t))}else t instanceof Ot&&console.error(t.error);return this},zt.prototype.listens=function(t){return this._listeners&&this._listeners[t]&&this._listeners[t].length>0||this._oneTimeListeners&&this._oneTimeListeners[t]&&this._oneTimeListeners[t].length>0||this._eventedParent&&this._eventedParent.listens(t)},zt.prototype.setEventedParent=function(t,e){return this._eventedParent=t,this._eventedParentData=e,this};var It={$version:8,$root:{version:{required:!0,type:\"enum\",values:[8]},name:{type:\"string\"},metadata:{type:\"*\"},center:{type:\"array\",value:\"number\"},zoom:{type:\"number\"},bearing:{type:\"number\",default:0,period:360,units:\"degrees\"},pitch:{type:\"number\",default:0,units:\"degrees\"},light:{type:\"light\"},sources:{required:!0,type:\"sources\"},sprite:{type:\"string\"},glyphs:{type:\"string\"},transition:{type:\"transition\"},layers:{required:!0,type:\"array\",value:\"layer\"}},sources:{\"*\":{type:\"source\"}},source:[\"source_vector\",\"source_raster\",\"source_raster_dem\",\"source_geojson\",\"source_video\",\"source_image\"],source_vector:{type:{required:!0,type:\"enum\",values:{vector:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},attribution:{type:\"string\"},\"*\":{type:\"*\"}},source_raster:{type:{required:!0,type:\"enum\",values:{raster:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},attribution:{type:\"string\"},\"*\":{type:\"*\"}},source_raster_dem:{type:{required:!0,type:\"enum\",values:{\"raster-dem\":{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},attribution:{type:\"string\"},encoding:{type:\"enum\",values:{terrarium:{},mapbox:{}},default:\"mapbox\"},\"*\":{type:\"*\"}},source_geojson:{type:{required:!0,type:\"enum\",values:{geojson:{}}},data:{type:\"*\"},maxzoom:{type:\"number\",default:18},attribution:{type:\"string\"},buffer:{type:\"number\",default:128,maximum:512,minimum:0},tolerance:{type:\"number\",default:.375},cluster:{type:\"boolean\",default:!1},clusterRadius:{type:\"number\",default:50,minimum:0},clusterMaxZoom:{type:\"number\"},clusterProperties:{type:\"*\"},lineMetrics:{type:\"boolean\",default:!1},generateId:{type:\"boolean\",default:!1}},source_video:{type:{required:!0,type:\"enum\",values:{video:{}}},urls:{required:!0,type:\"array\",value:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},source_image:{type:{required:!0,type:\"enum\",values:{image:{}}},url:{required:!0,type:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},layer:{id:{type:\"string\",required:!0},type:{type:\"enum\",values:{fill:{},line:{},symbol:{},circle:{},heatmap:{},\"fill-extrusion\":{},raster:{},hillshade:{},background:{}},required:!0},metadata:{type:\"*\"},source:{type:\"string\"},\"source-layer\":{type:\"string\"},minzoom:{type:\"number\",minimum:0,maximum:24},maxzoom:{type:\"number\",minimum:0,maximum:24},filter:{type:\"filter\"},layout:{type:\"layout\"},paint:{type:\"paint\"}},layout:[\"layout_fill\",\"layout_line\",\"layout_circle\",\"layout_heatmap\",\"layout_fill-extrusion\",\"layout_symbol\",\"layout_raster\",\"layout_hillshade\",\"layout_background\"],layout_background:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_fill:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_circle:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_heatmap:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},\"layout_fill-extrusion\":{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_line:{\"line-cap\":{type:\"enum\",values:{butt:{},round:{},square:{}},default:\"butt\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-join\":{type:\"enum\",values:{bevel:{},round:{},miter:{}},default:\"miter\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"line-miter-limit\":{type:\"number\",default:2,requires:[{\"line-join\":\"miter\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-round-limit\":{type:\"number\",default:1.05,requires:[{\"line-join\":\"round\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_symbol:{\"symbol-placement\":{type:\"enum\",values:{point:{},line:{},\"line-center\":{}},default:\"point\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-spacing\":{type:\"number\",default:250,minimum:1,units:\"pixels\",requires:[{\"symbol-placement\":\"line\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-avoid-edges\":{type:\"boolean\",default:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"symbol-z-order\":{type:\"enum\",values:{auto:{},\"viewport-y\":{},source:{}},default:\"auto\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-optional\":{type:\"boolean\",default:!1,requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-size\":{type:\"number\",default:1,minimum:0,units:\"factor of the original icon size\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-text-fit\":{type:\"enum\",values:{none:{},width:{},height:{},both:{}},default:\"none\",requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-text-fit-padding\":{type:\"array\",value:\"number\",length:4,default:[0,0,0,0],units:\"pixels\",requires:[\"icon-image\",\"text-field\",{\"icon-text-fit\":[\"both\",\"width\",\"height\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-image\":{type:\"string\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-keep-upright\":{type:\"boolean\",default:!1,requires:[\"icon-image\",{\"icon-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-offset\":{type:\"array\",value:\"number\",length:2,default:[0,0],requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-anchor\":{type:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-field\":{type:\"formatted\",default:\"\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-font\":{type:\"array\",value:\"string\",default:[\"Open Sans Regular\",\"Arial Unicode MS Regular\"],requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-size\":{type:\"number\",default:16,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-width\":{type:\"number\",default:10,minimum:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-line-height\":{type:\"number\",default:1.2,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-letter-spacing\":{type:\"number\",default:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-justify\":{type:\"enum\",values:{auto:{},left:{},center:{},right:{}},default:\"center\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-radial-offset\":{type:\"number\",units:\"ems\",default:0,requires:[{\"!\":\"text-offset\"}],\"property-type\":\"data-driven\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]}},\"text-variable-anchor\":{type:\"array\",value:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},requires:[{\"!\":\"text-anchor\"},{\"!\":\"text-offset\"},{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-anchor\":{type:\"enum\",requires:[\"text-field\"],values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-angle\":{type:\"number\",default:45,units:\"degrees\",requires:[\"text-field\",{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-keep-upright\":{type:\"boolean\",default:!0,requires:[\"text-field\",{\"text-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-transform\":{type:\"enum\",values:{none:{},uppercase:{},lowercase:{}},default:\"none\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-offset\":{type:\"array\",value:\"number\",units:\"ems\",length:2,default:[0,0],requires:[\"text-field\",{\"!\":\"text-radial-offset\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-optional\":{type:\"boolean\",default:!1,requires:[\"text-field\",\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_raster:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_hillshade:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},filter:{type:\"array\",value:\"*\"},filter_operator:{type:\"enum\",values:{\"==\":{},\"!=\":{},\">\":{},\">=\":{},\"<\":{},\"<=\":{},in:{},\"!in\":{},all:{},any:{},none:{},has:{},\"!has\":{}}},geometry_type:{type:\"enum\",values:{Point:{},LineString:{},Polygon:{}}},function:{expression:{type:\"expression\"},stops:{type:\"array\",value:\"function_stop\"},base:{type:\"number\",default:1,minimum:0},property:{type:\"string\",default:\"$zoom\"},type:{type:\"enum\",values:{identity:{},exponential:{},interval:{},categorical:{}},default:\"exponential\"},colorSpace:{type:\"enum\",values:{rgb:{},lab:{},hcl:{}},default:\"rgb\"},default:{type:\"*\",required:!1}},function_stop:{type:\"array\",minimum:0,maximum:22,value:[\"number\",\"color\"],length:2},expression:{type:\"array\",value:\"*\",minimum:1},expression_name:{type:\"enum\",values:{let:{group:\"Variable binding\"},var:{group:\"Variable binding\"},literal:{group:\"Types\"},array:{group:\"Types\"},at:{group:\"Lookup\"},case:{group:\"Decision\"},match:{group:\"Decision\"},coalesce:{group:\"Decision\"},step:{group:\"Ramps, scales, curves\"},interpolate:{group:\"Ramps, scales, curves\"},\"interpolate-hcl\":{group:\"Ramps, scales, curves\"},\"interpolate-lab\":{group:\"Ramps, scales, curves\"},ln2:{group:\"Math\"},pi:{group:\"Math\"},e:{group:\"Math\"},typeof:{group:\"Types\"},string:{group:\"Types\"},number:{group:\"Types\"},boolean:{group:\"Types\"},object:{group:\"Types\"},collator:{group:\"Types\"},format:{group:\"Types\"},\"number-format\":{group:\"Types\"},\"to-string\":{group:\"Types\"},\"to-number\":{group:\"Types\"},\"to-boolean\":{group:\"Types\"},\"to-rgba\":{group:\"Color\"},\"to-color\":{group:\"Types\"},rgb:{group:\"Color\"},rgba:{group:\"Color\"},get:{group:\"Lookup\"},has:{group:\"Lookup\"},length:{group:\"Lookup\"},properties:{group:\"Feature data\"},\"feature-state\":{group:\"Feature data\"},\"geometry-type\":{group:\"Feature data\"},id:{group:\"Feature data\"},zoom:{group:\"Zoom\"},\"heatmap-density\":{group:\"Heatmap\"},\"line-progress\":{group:\"Feature data\"},accumulated:{group:\"Feature data\"},\"+\":{group:\"Math\"},\"*\":{group:\"Math\"},\"-\":{group:\"Math\"},\"/\":{group:\"Math\"},\"%\":{group:\"Math\"},\"^\":{group:\"Math\"},sqrt:{group:\"Math\"},log10:{group:\"Math\"},ln:{group:\"Math\"},log2:{group:\"Math\"},sin:{group:\"Math\"},cos:{group:\"Math\"},tan:{group:\"Math\"},asin:{group:\"Math\"},acos:{group:\"Math\"},atan:{group:\"Math\"},min:{group:\"Math\"},max:{group:\"Math\"},round:{group:\"Math\"},abs:{group:\"Math\"},ceil:{group:\"Math\"},floor:{group:\"Math\"},\"==\":{group:\"Decision\"},\"!=\":{group:\"Decision\"},\">\":{group:\"Decision\"},\"<\":{group:\"Decision\"},\">=\":{group:\"Decision\"},\"<=\":{group:\"Decision\"},all:{group:\"Decision\"},any:{group:\"Decision\"},\"!\":{group:\"Decision\"},\"is-supported-script\":{group:\"String\"},upcase:{group:\"String\"},downcase:{group:\"String\"},concat:{group:\"String\"},\"resolved-locale\":{group:\"String\"}}},light:{anchor:{type:\"enum\",default:\"viewport\",values:{map:{},viewport:{}},\"property-type\":\"data-constant\",transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]}},position:{type:\"array\",default:[1.15,210,30],length:3,value:\"number\",\"property-type\":\"data-constant\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]}},color:{type:\"color\",\"property-type\":\"data-constant\",default:\"#ffffff\",expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0},intensity:{type:\"number\",\"property-type\":\"data-constant\",default:.5,minimum:0,maximum:1,expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0}},paint:[\"paint_fill\",\"paint_line\",\"paint_circle\",\"paint_heatmap\",\"paint_fill-extrusion\",\"paint_symbol\",\"paint_raster\",\"paint_hillshade\",\"paint_background\"],paint_fill:{\"fill-antialias\":{type:\"boolean\",default:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-outline-color\":{type:\"color\",transition:!0,requires:[{\"!\":\"fill-pattern\"},{\"fill-antialias\":!0}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"}},\"paint_fill-extrusion\":{\"fill-extrusion-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-extrusion-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-extrusion-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"fill-extrusion-height\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-base\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,requires:[\"fill-extrusion-height\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-vertical-gradient\":{type:\"boolean\",default:!0,transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_line:{\"line-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"line-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-width\":{type:\"number\",default:1,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-gap-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-offset\":{type:\"number\",default:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-dasharray\":{type:\"array\",value:\"number\",minimum:0,transition:!0,units:\"line widths\",requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"line-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"line-gradient\":{type:\"color\",transition:!1,requires:[{\"!\":\"line-dasharray\"},{\"!\":\"line-pattern\"},{source:\"geojson\",has:{lineMetrics:!0}}],expression:{interpolated:!0,parameters:[\"line-progress\"]},\"property-type\":\"color-ramp\"}},paint_circle:{\"circle-radius\":{type:\"number\",default:5,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-blur\":{type:\"number\",default:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"circle-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-scale\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-stroke-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"}},paint_heatmap:{\"heatmap-radius\":{type:\"number\",default:30,minimum:1,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-weight\":{type:\"number\",default:1,minimum:0,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-intensity\":{type:\"number\",default:1,minimum:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"heatmap-color\":{type:\"color\",default:[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,\"rgba(0, 0, 255, 0)\",.1,\"royalblue\",.3,\"cyan\",.5,\"lime\",.7,\"yellow\",1,\"red\"],transition:!1,expression:{interpolated:!0,parameters:[\"heatmap-density\"]},\"property-type\":\"color-ramp\"},\"heatmap-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_symbol:{\"icon-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"icon-image\",\"icon-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"text-field\",\"text-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_raster:{\"raster-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-hue-rotate\":{type:\"number\",default:0,period:360,transition:!0,units:\"degrees\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-min\":{type:\"number\",default:0,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-max\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-saturation\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-contrast\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-resampling\":{type:\"enum\",values:{linear:{},nearest:{}},default:\"linear\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-fade-duration\":{type:\"number\",default:300,minimum:0,transition:!1,units:\"milliseconds\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_hillshade:{\"hillshade-illumination-direction\":{type:\"number\",default:335,minimum:0,maximum:359,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-illumination-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-exaggeration\":{type:\"number\",default:.5,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-shadow-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-highlight-color\":{type:\"color\",default:\"#FFFFFF\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-accent-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_background:{\"background-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"background-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"background-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"background-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},transition:{duration:{type:\"number\",default:300,minimum:0,units:\"milliseconds\"},delay:{type:\"number\",default:0,minimum:0,units:\"milliseconds\"}},\"property-type\":{\"data-driven\":{type:\"property-type\"},\"cross-faded\":{type:\"property-type\"},\"cross-faded-data-driven\":{type:\"property-type\"},\"color-ramp\":{type:\"property-type\"},\"data-constant\":{type:\"property-type\"},constant:{type:\"property-type\"}}},Dt=function(t,e,r,n){this.message=(t?t+\": \":\"\")+r,n&&(this.identifier=n),null!=e&&e.__line__&&(this.line=e.__line__)};function Rt(t){var e=t.key,r=t.value;return r?[new Dt(e,r,\"constants have been deprecated as of v8\")]:[]}function Ft(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}function Bt(t){return t instanceof Number||t instanceof String||t instanceof Boolean}function Nt(t){return Bt(t)?t.valueOf():t}function jt(t){if(Array.isArray(t))return t.map(jt);if(t instanceof Object&&!Bt(t)){var e={};for(var r in t)e[r]=jt(t[r]);return e}return Nt(t)}var Ut=function(t){function e(e,r){t.call(this,r),this.message=r,this.key=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Error),Vt=function(t,e){void 0===e&&(e=[]),this.parent=t,this.bindings={};for(var r=0,n=e;r<n.length;r+=1){var i=n[r],a=i[0],o=i[1];this.bindings[a]=o}};Vt.prototype.concat=function(t){return new Vt(this,t)},Vt.prototype.get=function(t){if(this.bindings[t])return this.bindings[t];if(this.parent)return this.parent.get(t);throw new Error(t+\" not found in scope.\")},Vt.prototype.has=function(t){return!!this.bindings[t]||!!this.parent&&this.parent.has(t)};var qt={kind:\"null\"},Ht={kind:\"number\"},Gt={kind:\"string\"},Yt={kind:\"boolean\"},Wt={kind:\"color\"},Xt={kind:\"object\"},Zt={kind:\"value\"},Jt={kind:\"collator\"},Kt={kind:\"formatted\"};function $t(t,e){return{kind:\"array\",itemType:t,N:e}}function Qt(t){if(\"array\"===t.kind){var e=Qt(t.itemType);return\"number\"==typeof t.N?\"array<\"+e+\", \"+t.N+\">\":\"value\"===t.itemType.kind?\"array\":\"array<\"+e+\">\"}return t.kind}var te=[qt,Ht,Gt,Yt,Wt,Kt,Xt,$t(Zt)];function ee(t,e){if(\"error\"===e.kind)return null;if(\"array\"===t.kind){if(\"array\"===e.kind&&(0===e.N&&\"value\"===e.itemType.kind||!ee(t.itemType,e.itemType))&&(\"number\"!=typeof t.N||t.N===e.N))return null}else{if(t.kind===e.kind)return null;if(\"value\"===t.kind)for(var r=0,n=te;r<n.length;r+=1)if(!ee(n[r],e))return null}return\"Expected \"+Qt(t)+\" but found \"+Qt(e)+\" instead.\"}var re=e(function(t,e){var r={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],rebeccapurple:[102,51,153,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function n(t){return(t=Math.round(t))<0?0:t>255?255:t}function i(t){return t<0?0:t>1?1:t}function a(t){return\"%\"===t[t.length-1]?n(parseFloat(t)/100*255):n(parseInt(t))}function o(t){return\"%\"===t[t.length-1]?i(parseFloat(t)/100):i(parseFloat(t))}function s(t,e,r){return r<0?r+=1:r>1&&(r-=1),6*r<1?t+(e-t)*r*6:2*r<1?e:3*r<2?t+(e-t)*(2/3-r)*6:t}try{e.parseCSSColor=function(t){var e,i=t.replace(/ /g,\"\").toLowerCase();if(i in r)return r[i].slice();if(\"#\"===i[0])return 4===i.length?(e=parseInt(i.substr(1),16))>=0&&e<=4095?[(3840&e)>>4|(3840&e)>>8,240&e|(240&e)>>4,15&e|(15&e)<<4,1]:null:7===i.length&&(e=parseInt(i.substr(1),16))>=0&&e<=16777215?[(16711680&e)>>16,(65280&e)>>8,255&e,1]:null;var l=i.indexOf(\"(\"),c=i.indexOf(\")\");if(-1!==l&&c+1===i.length){var u=i.substr(0,l),h=i.substr(l+1,c-(l+1)).split(\",\"),f=1;switch(u){case\"rgba\":if(4!==h.length)return null;f=o(h.pop());case\"rgb\":return 3!==h.length?null:[a(h[0]),a(h[1]),a(h[2]),f];case\"hsla\":if(4!==h.length)return null;f=o(h.pop());case\"hsl\":if(3!==h.length)return null;var p=(parseFloat(h[0])%360+360)%360/360,d=o(h[1]),g=o(h[2]),v=g<=.5?g*(d+1):g+d-g*d,m=2*g-v;return[n(255*s(m,v,p+1/3)),n(255*s(m,v,p)),n(255*s(m,v,p-1/3)),f];default:return null}}return null}}catch(t){}}).parseCSSColor,ne=function(t,e,r,n){void 0===n&&(n=1),this.r=t,this.g=e,this.b=r,this.a=n};ne.parse=function(t){if(t){if(t instanceof ne)return t;if(\"string\"==typeof t){var e=re(t);if(e)return new ne(e[0]/255*e[3],e[1]/255*e[3],e[2]/255*e[3],e[3])}}},ne.prototype.toString=function(){var t=this.toArray(),e=t[0],r=t[1],n=t[2],i=t[3];return\"rgba(\"+Math.round(e)+\",\"+Math.round(r)+\",\"+Math.round(n)+\",\"+i+\")\"},ne.prototype.toArray=function(){var t=this.r,e=this.g,r=this.b,n=this.a;return 0===n?[0,0,0,0]:[255*t/n,255*e/n,255*r/n,n]},ne.black=new ne(0,0,0,1),ne.white=new ne(1,1,1,1),ne.transparent=new ne(0,0,0,0),ne.red=new ne(1,0,0,1);var ie=function(t,e,r){this.sensitivity=t?e?\"variant\":\"case\":e?\"accent\":\"base\",this.locale=r,this.collator=new Intl.Collator(this.locale?this.locale:[],{sensitivity:this.sensitivity,usage:\"search\"})};ie.prototype.compare=function(t,e){return this.collator.compare(t,e)},ie.prototype.resolvedLocale=function(){return new Intl.Collator(this.locale?this.locale:[]).resolvedOptions().locale};var ae=function(t,e,r){this.text=t,this.scale=e,this.fontStack=r},oe=function(t){this.sections=t};function se(t,e,r,n){return\"number\"==typeof t&&t>=0&&t<=255&&\"number\"==typeof e&&e>=0&&e<=255&&\"number\"==typeof r&&r>=0&&r<=255?void 0===n||\"number\"==typeof n&&n>=0&&n<=1?null:\"Invalid rgba value [\"+[t,e,r,n].join(\", \")+\"]: 'a' must be between 0 and 1.\":\"Invalid rgba value [\"+(\"number\"==typeof n?[t,e,r,n]:[t,e,r]).join(\", \")+\"]: 'r', 'g', and 'b' must be between 0 and 255.\"}function le(t){if(null===t)return qt;if(\"string\"==typeof t)return Gt;if(\"boolean\"==typeof t)return Yt;if(\"number\"==typeof t)return Ht;if(t instanceof ne)return Wt;if(t instanceof ie)return Jt;if(t instanceof oe)return Kt;if(Array.isArray(t)){for(var e,r=t.length,n=0,i=t;n<i.length;n+=1){var a=le(i[n]);if(e){if(e===a)continue;e=Zt;break}e=a}return $t(e||Zt,r)}return Xt}function ce(t){var e=typeof t;return null===t?\"\":\"string\"===e||\"number\"===e||\"boolean\"===e?String(t):t instanceof ne||t instanceof oe?t.toString():JSON.stringify(t)}oe.fromString=function(t){return new oe([new ae(t,null,null)])},oe.prototype.toString=function(){return this.sections.map(function(t){return t.text}).join(\"\")},oe.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.text);var i={};n.fontStack&&(i[\"text-font\"]=[\"literal\",n.fontStack.split(\",\")]),n.scale&&(i[\"font-scale\"]=n.scale),t.push(i)}return t};var ue=function(t,e){this.type=t,this.value=e};ue.parse=function(t,e){if(2!==t.length)return e.error(\"'literal' expression requires exactly one argument, but found \"+(t.length-1)+\" instead.\");if(!function t(e){if(null===e)return!0;if(\"string\"==typeof e)return!0;if(\"boolean\"==typeof e)return!0;if(\"number\"==typeof e)return!0;if(e instanceof ne)return!0;if(e instanceof ie)return!0;if(e instanceof oe)return!0;if(Array.isArray(e)){for(var r=0,n=e;r<n.length;r+=1)if(!t(n[r]))return!1;return!0}if(\"object\"==typeof e){for(var i in e)if(!t(e[i]))return!1;return!0}return!1}(t[1]))return e.error(\"invalid value\");var r=t[1],n=le(r),i=e.expectedType;return\"array\"!==n.kind||0!==n.N||!i||\"array\"!==i.kind||\"number\"==typeof i.N&&0!==i.N||(n=i),new ue(n,r)},ue.prototype.evaluate=function(){return this.value},ue.prototype.eachChild=function(){},ue.prototype.possibleOutputs=function(){return[this.value]},ue.prototype.serialize=function(){return\"array\"===this.type.kind||\"object\"===this.type.kind?[\"literal\",this.value]:this.value instanceof ne?[\"rgba\"].concat(this.value.toArray()):this.value instanceof oe?this.value.serialize():this.value};var he=function(t){this.name=\"ExpressionEvaluationError\",this.message=t};he.prototype.toJSON=function(){return this.message};var fe={string:Gt,number:Ht,boolean:Yt,object:Xt},pe=function(t,e){this.type=t,this.args=e};pe.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r,n=1,i=t[0];if(\"array\"===i){var a,o;if(t.length>2){var s=t[1];if(\"string\"!=typeof s||!(s in fe)||\"object\"===s)return e.error('The item type argument of \"array\" must be one of string, number, boolean',1);a=fe[s],n++}else a=Zt;if(t.length>3){if(null!==t[2]&&(\"number\"!=typeof t[2]||t[2]<0||t[2]!==Math.floor(t[2])))return e.error('The length argument to \"array\" must be a positive integer literal',2);o=t[2],n++}r=$t(a,o)}else r=fe[i];for(var l=[];n<t.length;n++){var c=e.parse(t[n],n,Zt);if(!c)return null;l.push(c)}return new pe(r,l)},pe.prototype.evaluate=function(t){for(var e=0;e<this.args.length;e++){var r=this.args[e].evaluate(t);if(!ee(this.type,le(r)))return r;if(e===this.args.length-1)throw new he(\"Expected value to be of type \"+Qt(this.type)+\", but found \"+Qt(le(r))+\" instead.\")}return null},pe.prototype.eachChild=function(t){this.args.forEach(t)},pe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},pe.prototype.serialize=function(){var t=this.type,e=[t.kind];if(\"array\"===t.kind){var r=t.itemType;if(\"string\"===r.kind||\"number\"===r.kind||\"boolean\"===r.kind){e.push(r.kind);var n=t.N;(\"number\"==typeof n||this.args.length>1)&&e.push(n)}}return e.concat(this.args.map(function(t){return t.serialize()}))};var de=function(t){this.type=Kt,this.sections=t};de.parse=function(t,e){if(t.length<3)return e.error(\"Expected at least two arguments.\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");for(var r=[],n=1;n<t.length-1;n+=2){var i=e.parse(t[n],1,Zt);if(!i)return null;var a=i.type.kind;if(\"string\"!==a&&\"value\"!==a&&\"null\"!==a)return e.error(\"Formatted text type must be 'string', 'value', or 'null'.\");var o=t[n+1];if(\"object\"!=typeof o||Array.isArray(o))return e.error(\"Format options argument must be an object.\");var s=null;if(o[\"font-scale\"]&&!(s=e.parse(o[\"font-scale\"],1,Ht)))return null;var l=null;if(o[\"text-font\"]&&!(l=e.parse(o[\"text-font\"],1,$t(Gt))))return null;r.push({text:i,scale:s,font:l})}return new de(r)},de.prototype.evaluate=function(t){return new oe(this.sections.map(function(e){return new ae(ce(e.text.evaluate(t)),e.scale?e.scale.evaluate(t):null,e.font?e.font.evaluate(t).join(\",\"):null)}))},de.prototype.eachChild=function(t){for(var e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t(n.text),n.scale&&t(n.scale),n.font&&t(n.font)}},de.prototype.possibleOutputs=function(){return[void 0]},de.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.text.serialize());var i={};n.scale&&(i[\"font-scale\"]=n.scale.serialize()),n.font&&(i[\"text-font\"]=n.font.serialize()),t.push(i)}return t};var ge={\"to-boolean\":Yt,\"to-color\":Wt,\"to-number\":Ht,\"to-string\":Gt},ve=function(t,e){this.type=t,this.args=e};ve.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r=t[0];if((\"to-boolean\"===r||\"to-string\"===r)&&2!==t.length)return e.error(\"Expected one argument.\");for(var n=ge[r],i=[],a=1;a<t.length;a++){var o=e.parse(t[a],a,Zt);if(!o)return null;i.push(o)}return new ve(n,i)},ve.prototype.evaluate=function(t){if(\"boolean\"===this.type.kind)return Boolean(this.args[0].evaluate(t));if(\"color\"===this.type.kind){for(var e,r,n=0,i=this.args;n<i.length;n+=1){if(r=null,(e=i[n].evaluate(t))instanceof ne)return e;if(\"string\"==typeof e){var a=t.parseColor(e);if(a)return a}else if(Array.isArray(e)&&!(r=e.length<3||e.length>4?\"Invalid rbga value \"+JSON.stringify(e)+\": expected an array containing either three or four numeric values.\":se(e[0],e[1],e[2],e[3])))return new ne(e[0]/255,e[1]/255,e[2]/255,e[3])}throw new he(r||\"Could not parse color from value '\"+(\"string\"==typeof e?e:String(JSON.stringify(e)))+\"'\")}if(\"number\"===this.type.kind){for(var o=null,s=0,l=this.args;s<l.length;s+=1){if(null===(o=l[s].evaluate(t)))return 0;var c=Number(o);if(!isNaN(c))return c}throw new he(\"Could not convert \"+JSON.stringify(o)+\" to number.\")}return\"formatted\"===this.type.kind?oe.fromString(ce(this.args[0].evaluate(t))):ce(this.args[0].evaluate(t))},ve.prototype.eachChild=function(t){this.args.forEach(t)},ve.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},ve.prototype.serialize=function(){if(\"formatted\"===this.type.kind)return new de([{text:this.args[0],scale:null,font:null}]).serialize();var t=[\"to-\"+this.type.kind];return this.eachChild(function(e){t.push(e.serialize())}),t};var me=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],ye=function(){this.globals=null,this.feature=null,this.featureState=null,this._parseColorCache={}};ye.prototype.id=function(){return this.feature&&\"id\"in this.feature?this.feature.id:null},ye.prototype.geometryType=function(){return this.feature?\"number\"==typeof this.feature.type?me[this.feature.type]:this.feature.type:null},ye.prototype.properties=function(){return this.feature&&this.feature.properties||{}},ye.prototype.parseColor=function(t){var e=this._parseColorCache[t];return e||(e=this._parseColorCache[t]=ne.parse(t)),e};var xe=function(t,e,r,n){this.name=t,this.type=e,this._evaluate=r,this.args=n};xe.prototype.evaluate=function(t){return this._evaluate(t,this.args)},xe.prototype.eachChild=function(t){this.args.forEach(t)},xe.prototype.possibleOutputs=function(){return[void 0]},xe.prototype.serialize=function(){return[this.name].concat(this.args.map(function(t){return t.serialize()}))},xe.parse=function(t,e){var r,n=t[0],i=xe.definitions[n];if(!i)return e.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0);for(var a=Array.isArray(i)?i[0]:i.type,o=Array.isArray(i)?[[i[1],i[2]]]:i.overloads,s=o.filter(function(e){var r=e[0];return!Array.isArray(r)||r.length===t.length-1}),l=null,c=0,u=s;c<u.length;c+=1){var h=u[c],f=h[0],p=h[1];l=new Ae(e.registry,e.path,null,e.scope);for(var d=[],g=!1,v=1;v<t.length;v++){var m=t[v],y=Array.isArray(f)?f[v-1]:f.type,x=l.parse(m,1+d.length,y);if(!x){g=!0;break}d.push(x)}if(!g)if(Array.isArray(f)&&f.length!==d.length)l.error(\"Expected \"+f.length+\" arguments, but found \"+d.length+\" instead.\");else{for(var b=0;b<d.length;b++){var _=Array.isArray(f)?f[b]:f.type,w=d[b];l.concat(b+1).checkSubtype(_,w.type)}if(0===l.errors.length)return new xe(n,a,p,d)}}if(1===s.length)(r=e.errors).push.apply(r,l.errors);else{for(var k=(s.length?s:o).map(function(t){var e;return e=t[0],Array.isArray(e)?\"(\"+e.map(Qt).join(\", \")+\")\":\"(\"+Qt(e.type)+\"...)\"}).join(\" | \"),T=[],A=1;A<t.length;A++){var M=e.parse(t[A],1+T.length);if(!M)return null;T.push(Qt(M.type))}e.error(\"Expected arguments of type \"+k+\", but found (\"+T.join(\", \")+\") instead.\")}return null},xe.register=function(t,e){for(var r in xe.definitions=e,e)t[r]=xe};var be=function(t,e,r){this.type=Jt,this.locale=r,this.caseSensitive=t,this.diacriticSensitive=e};function _e(t){if(t instanceof xe){if(\"get\"===t.name&&1===t.args.length)return!1;if(\"feature-state\"===t.name)return!1;if(\"has\"===t.name&&1===t.args.length)return!1;if(\"properties\"===t.name||\"geometry-type\"===t.name||\"id\"===t.name)return!1;if(/^filter-/.test(t.name))return!1}var e=!0;return t.eachChild(function(t){e&&!_e(t)&&(e=!1)}),e}function we(t){if(t instanceof xe&&\"feature-state\"===t.name)return!1;var e=!0;return t.eachChild(function(t){e&&!we(t)&&(e=!1)}),e}function ke(t,e){if(t instanceof xe&&e.indexOf(t.name)>=0)return!1;var r=!0;return t.eachChild(function(t){r&&!ke(t,e)&&(r=!1)}),r}be.parse=function(t,e){if(2!==t.length)return e.error(\"Expected one argument.\");var r=t[1];if(\"object\"!=typeof r||Array.isArray(r))return e.error(\"Collator options argument must be an object.\");var n=e.parse(void 0!==r[\"case-sensitive\"]&&r[\"case-sensitive\"],1,Yt);if(!n)return null;var i=e.parse(void 0!==r[\"diacritic-sensitive\"]&&r[\"diacritic-sensitive\"],1,Yt);if(!i)return null;var a=null;return r.locale&&!(a=e.parse(r.locale,1,Gt))?null:new be(n,i,a)},be.prototype.evaluate=function(t){return new ie(this.caseSensitive.evaluate(t),this.diacriticSensitive.evaluate(t),this.locale?this.locale.evaluate(t):null)},be.prototype.eachChild=function(t){t(this.caseSensitive),t(this.diacriticSensitive),this.locale&&t(this.locale)},be.prototype.possibleOutputs=function(){return[void 0]},be.prototype.serialize=function(){var t={};return t[\"case-sensitive\"]=this.caseSensitive.serialize(),t[\"diacritic-sensitive\"]=this.diacriticSensitive.serialize(),this.locale&&(t.locale=this.locale.serialize()),[\"collator\",t]};var Te=function(t,e){this.type=e.type,this.name=t,this.boundExpression=e};Te.parse=function(t,e){if(2!==t.length||\"string\"!=typeof t[1])return e.error(\"'var' expression requires exactly one string literal argument.\");var r=t[1];return e.scope.has(r)?new Te(r,e.scope.get(r)):e.error('Unknown variable \"'+r+'\". Make sure \"'+r+'\" has been bound in an enclosing \"let\" expression before using it.',1)},Te.prototype.evaluate=function(t){return this.boundExpression.evaluate(t)},Te.prototype.eachChild=function(){},Te.prototype.possibleOutputs=function(){return[void 0]},Te.prototype.serialize=function(){return[\"var\",this.name]};var Ae=function(t,e,r,n,i){void 0===e&&(e=[]),void 0===n&&(n=new Vt),void 0===i&&(i=[]),this.registry=t,this.path=e,this.key=e.map(function(t){return\"[\"+t+\"]\"}).join(\"\"),this.scope=n,this.errors=i,this.expectedType=r};function Me(t,e){for(var r,n,i=t.length-1,a=0,o=i,s=0;a<=o;)if(r=t[s=Math.floor((a+o)/2)],n=t[s+1],r<=e){if(s===i||e<n)return s;a=s+1}else{if(!(r>e))throw new he(\"Input is not a number.\");o=s-1}return 0}Ae.prototype.parse=function(t,e,r,n,i){return void 0===i&&(i={}),e?this.concat(e,r,n)._parse(t,i):this._parse(t,i)},Ae.prototype._parse=function(t,e){function r(t,e,r){return\"assert\"===r?new pe(e,[t]):\"coerce\"===r?new ve(e,[t]):t}if(null!==t&&\"string\"!=typeof t&&\"boolean\"!=typeof t&&\"number\"!=typeof t||(t=[\"literal\",t]),Array.isArray(t)){if(0===t.length)return this.error('Expected an array with at least one element. If you wanted a literal array, use [\"literal\", []].');var n=t[0];if(\"string\"!=typeof n)return this.error(\"Expression name must be a string, but found \"+typeof n+' instead. If you wanted a literal array, use [\"literal\", [...]].',0),null;var i=this.registry[n];if(i){var a=i.parse(t,this);if(!a)return null;if(this.expectedType){var o=this.expectedType,s=a.type;if(\"string\"!==o.kind&&\"number\"!==o.kind&&\"boolean\"!==o.kind&&\"object\"!==o.kind&&\"array\"!==o.kind||\"value\"!==s.kind)if(\"color\"!==o.kind&&\"formatted\"!==o.kind||\"value\"!==s.kind&&\"string\"!==s.kind){if(this.checkSubtype(o,s))return null}else a=r(a,o,e.typeAnnotation||\"coerce\");else a=r(a,o,e.typeAnnotation||\"assert\")}if(!(a instanceof ue)&&function t(e){if(e instanceof Te)return t(e.boundExpression);if(e instanceof xe&&\"error\"===e.name)return!1;if(e instanceof be)return!1;var r=e instanceof ve||e instanceof pe,n=!0;return e.eachChild(function(e){n=r?n&&t(e):n&&e instanceof ue}),!!n&&(_e(e)&&ke(e,[\"zoom\",\"heatmap-density\",\"line-progress\",\"accumulated\",\"is-supported-script\"]))}(a)){var l=new ye;try{a=new ue(a.type,a.evaluate(l))}catch(t){return this.error(t.message),null}}return a}return this.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0)}return void 0===t?this.error(\"'undefined' value invalid. Use null instead.\"):\"object\"==typeof t?this.error('Bare objects invalid. Use [\"literal\", {...}] instead.'):this.error(\"Expected an array, but found \"+typeof t+\" instead.\")},Ae.prototype.concat=function(t,e,r){var n=\"number\"==typeof t?this.path.concat(t):this.path,i=r?this.scope.concat(r):this.scope;return new Ae(this.registry,n,e||null,i,this.errors)},Ae.prototype.error=function(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];var n=\"\"+this.key+e.map(function(t){return\"[\"+t+\"]\"}).join(\"\");this.errors.push(new Ut(n,t))},Ae.prototype.checkSubtype=function(t,e){var r=ee(t,e);return r&&this.error(r),r};var Se=function(t,e,r){this.type=t,this.input=e,this.labels=[],this.outputs=[];for(var n=0,i=r;n<i.length;n+=1){var a=i[n],o=a[0],s=a[1];this.labels.push(o),this.outputs.push(s)}};function Ee(t,e,r){return t*(1-r)+e*r}Se.parse=function(t,e){if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");var r=e.parse(t[1],1,Ht);if(!r)return null;var n=[],i=null;e.expectedType&&\"value\"!==e.expectedType.kind&&(i=e.expectedType);for(var a=1;a<t.length;a+=2){var o=1===a?-1/0:t[a],s=t[a+1],l=a,c=a+1;if(\"number\"!=typeof o)return e.error('Input/output pairs for \"step\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',l);if(n.length&&n[n.length-1][0]>=o)return e.error('Input/output pairs for \"step\" expressions must be arranged with input values in strictly ascending order.',l);var u=e.parse(s,c,i);if(!u)return null;i=i||u.type,n.push([o,u])}return new Se(i,r,n)},Se.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;return n>=e[i-1]?r[i-1].evaluate(t):r[Me(e,n)].evaluate(t)},Se.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},Se.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()}))},Se.prototype.serialize=function(){for(var t=[\"step\",this.input.serialize()],e=0;e<this.labels.length;e++)e>0&&t.push(this.labels[e]),t.push(this.outputs[e].serialize());return t};var Ce=Object.freeze({number:Ee,color:function(t,e,r){return new ne(Ee(t.r,e.r,r),Ee(t.g,e.g,r),Ee(t.b,e.b,r),Ee(t.a,e.a,r))},array:function(t,e,r){return t.map(function(t,n){return Ee(t,e[n],r)})}}),Le=.95047,Pe=1,Oe=1.08883,ze=4/29,Ie=6/29,De=3*Ie*Ie,Re=Ie*Ie*Ie,Fe=Math.PI/180,Be=180/Math.PI;function Ne(t){return t>Re?Math.pow(t,1/3):t/De+ze}function je(t){return t>Ie?t*t*t:De*(t-ze)}function Ue(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function Ve(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function qe(t){var e=Ve(t.r),r=Ve(t.g),n=Ve(t.b),i=Ne((.4124564*e+.3575761*r+.1804375*n)/Le),a=Ne((.2126729*e+.7151522*r+.072175*n)/Pe);return{l:116*a-16,a:500*(i-a),b:200*(a-Ne((.0193339*e+.119192*r+.9503041*n)/Oe)),alpha:t.a}}function He(t){var e=(t.l+16)/116,r=isNaN(t.a)?e:e+t.a/500,n=isNaN(t.b)?e:e-t.b/200;return e=Pe*je(e),r=Le*je(r),n=Oe*je(n),new ne(Ue(3.2404542*r-1.5371385*e-.4985314*n),Ue(-.969266*r+1.8760108*e+.041556*n),Ue(.0556434*r-.2040259*e+1.0572252*n),t.alpha)}var Ge={forward:qe,reverse:He,interpolate:function(t,e,r){return{l:Ee(t.l,e.l,r),a:Ee(t.a,e.a,r),b:Ee(t.b,e.b,r),alpha:Ee(t.alpha,e.alpha,r)}}},Ye={forward:function(t){var e=qe(t),r=e.l,n=e.a,i=e.b,a=Math.atan2(i,n)*Be;return{h:a<0?a+360:a,c:Math.sqrt(n*n+i*i),l:r,alpha:t.a}},reverse:function(t){var e=t.h*Fe,r=t.c;return He({l:t.l,a:Math.cos(e)*r,b:Math.sin(e)*r,alpha:t.alpha})},interpolate:function(t,e,r){return{h:function(t,e,r){var n=e-t;return t+r*(n>180||n<-180?n-360*Math.round(n/360):n)}(t.h,e.h,r),c:Ee(t.c,e.c,r),l:Ee(t.l,e.l,r),alpha:Ee(t.alpha,e.alpha,r)}}},We=Object.freeze({lab:Ge,hcl:Ye}),Xe=function(t,e,r,n,i){this.type=t,this.operator=e,this.interpolation=r,this.input=n,this.labels=[],this.outputs=[];for(var a=0,o=i;a<o.length;a+=1){var s=o[a],l=s[0],c=s[1];this.labels.push(l),this.outputs.push(c)}};function Ze(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}Xe.interpolationFactor=function(t,e,n,i){var a=0;if(\"exponential\"===t.name)a=Ze(e,t.base,n,i);else if(\"linear\"===t.name)a=Ze(e,1,n,i);else if(\"cubic-bezier\"===t.name){var o=t.controlPoints;a=new r(o[0],o[1],o[2],o[3]).solve(Ze(e,1,n,i))}return a},Xe.parse=function(t,e){var r=t[0],n=t[1],i=t[2],a=t.slice(3);if(!Array.isArray(n)||0===n.length)return e.error(\"Expected an interpolation type expression.\",1);if(\"linear\"===n[0])n={name:\"linear\"};else if(\"exponential\"===n[0]){var o=n[1];if(\"number\"!=typeof o)return e.error(\"Exponential interpolation requires a numeric base.\",1,1);n={name:\"exponential\",base:o}}else{if(\"cubic-bezier\"!==n[0])return e.error(\"Unknown interpolation type \"+String(n[0]),1,0);var s=n.slice(1);if(4!==s.length||s.some(function(t){return\"number\"!=typeof t||t<0||t>1}))return e.error(\"Cubic bezier interpolation requires four numeric arguments with values between 0 and 1.\",1);n={name:\"cubic-bezier\",controlPoints:s}}if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");if(!(i=e.parse(i,2,Ht)))return null;var l=[],c=null;\"interpolate-hcl\"===r||\"interpolate-lab\"===r?c=Wt:e.expectedType&&\"value\"!==e.expectedType.kind&&(c=e.expectedType);for(var u=0;u<a.length;u+=2){var h=a[u],f=a[u+1],p=u+3,d=u+4;if(\"number\"!=typeof h)return e.error('Input/output pairs for \"interpolate\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',p);if(l.length&&l[l.length-1][0]>=h)return e.error('Input/output pairs for \"interpolate\" expressions must be arranged with input values in strictly ascending order.',p);var g=e.parse(f,d,c);if(!g)return null;c=c||g.type,l.push([h,g])}return\"number\"===c.kind||\"color\"===c.kind||\"array\"===c.kind&&\"number\"===c.itemType.kind&&\"number\"==typeof c.N?new Xe(c,r,n,i,l):e.error(\"Type \"+Qt(c)+\" is not interpolatable.\")},Xe.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;if(n>=e[i-1])return r[i-1].evaluate(t);var a=Me(e,n),o=e[a],s=e[a+1],l=Xe.interpolationFactor(this.interpolation,n,o,s),c=r[a].evaluate(t),u=r[a+1].evaluate(t);return\"interpolate\"===this.operator?Ce[this.type.kind.toLowerCase()](c,u,l):\"interpolate-hcl\"===this.operator?Ye.reverse(Ye.interpolate(Ye.forward(c),Ye.forward(u),l)):Ge.reverse(Ge.interpolate(Ge.forward(c),Ge.forward(u),l))},Xe.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},Xe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()}))},Xe.prototype.serialize=function(){var t;t=\"linear\"===this.interpolation.name?[\"linear\"]:\"exponential\"===this.interpolation.name?1===this.interpolation.base?[\"linear\"]:[\"exponential\",this.interpolation.base]:[\"cubic-bezier\"].concat(this.interpolation.controlPoints);for(var e=[this.operator,t,this.input.serialize()],r=0;r<this.labels.length;r++)e.push(this.labels[r],this.outputs[r].serialize());return e};var Je=function(t,e){this.type=t,this.args=e};Je.parse=function(t,e){if(t.length<2)return e.error(\"Expectected at least one argument.\");var r=null,n=e.expectedType;n&&\"value\"!==n.kind&&(r=n);for(var i=[],a=0,o=t.slice(1);a<o.length;a+=1){var s=o[a],l=e.parse(s,1+i.length,r,void 0,{typeAnnotation:\"omit\"});if(!l)return null;r=r||l.type,i.push(l)}var c=n&&i.some(function(t){return ee(n,t.type)});return new Je(c?Zt:r,i)},Je.prototype.evaluate=function(t){for(var e=null,r=0,n=this.args;r<n.length&&null===(e=n[r].evaluate(t));r+=1);return e},Je.prototype.eachChild=function(t){this.args.forEach(t)},Je.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},Je.prototype.serialize=function(){var t=[\"coalesce\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var Ke=function(t,e){this.type=e.type,this.bindings=[].concat(t),this.result=e};Ke.prototype.evaluate=function(t){return this.result.evaluate(t)},Ke.prototype.eachChild=function(t){for(var e=0,r=this.bindings;e<r.length;e+=1)t(r[e][1]);t(this.result)},Ke.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found \"+(t.length-1)+\" instead.\");for(var r=[],n=1;n<t.length-1;n+=2){var i=t[n];if(\"string\"!=typeof i)return e.error(\"Expected string, but found \"+typeof i+\" instead.\",n);if(/[^a-zA-Z0-9_]/.test(i))return e.error(\"Variable names must contain only alphanumeric characters or '_'.\",n);var a=e.parse(t[n+1],n+1);if(!a)return null;r.push([i,a])}var o=e.parse(t[t.length-1],t.length-1,e.expectedType,r);return o?new Ke(r,o):null},Ke.prototype.possibleOutputs=function(){return this.result.possibleOutputs()},Ke.prototype.serialize=function(){for(var t=[\"let\"],e=0,r=this.bindings;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];t.push(i,a.serialize())}return t.push(this.result.serialize()),t};var $e=function(t,e,r){this.type=t,this.index=e,this.input=r};$e.parse=function(t,e){if(3!==t.length)return e.error(\"Expected 2 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,Ht),n=e.parse(t[2],2,$t(e.expectedType||Zt));if(!r||!n)return null;var i=n.type;return new $e(i.itemType,r,n)},$e.prototype.evaluate=function(t){var e=this.index.evaluate(t),r=this.input.evaluate(t);if(e<0)throw new he(\"Array index out of bounds: \"+e+\" < 0.\");if(e>=r.length)throw new he(\"Array index out of bounds: \"+e+\" > \"+(r.length-1)+\".\");if(e!==Math.floor(e))throw new he(\"Array index must be an integer, but found \"+e+\" instead.\");return r[e]},$e.prototype.eachChild=function(t){t(this.index),t(this.input)},$e.prototype.possibleOutputs=function(){return[void 0]},$e.prototype.serialize=function(){return[\"at\",this.index.serialize(),this.input.serialize()]};var Qe=function(t,e,r,n,i,a){this.inputType=t,this.type=e,this.input=r,this.cases=n,this.outputs=i,this.otherwise=a};Qe.parse=function(t,e){if(t.length<5)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=1)return e.error(\"Expected an even number of arguments.\");var r,n;e.expectedType&&\"value\"!==e.expectedType.kind&&(n=e.expectedType);for(var i={},a=[],o=2;o<t.length-1;o+=2){var s=t[o],l=t[o+1];Array.isArray(s)||(s=[s]);var c=e.concat(o);if(0===s.length)return c.error(\"Expected at least one branch label.\");for(var u=0,h=s;u<h.length;u+=1){var f=h[u];if(\"number\"!=typeof f&&\"string\"!=typeof f)return c.error(\"Branch labels must be numbers or strings.\");if(\"number\"==typeof f&&Math.abs(f)>Number.MAX_SAFE_INTEGER)return c.error(\"Branch labels must be integers no larger than \"+Number.MAX_SAFE_INTEGER+\".\");if(\"number\"==typeof f&&Math.floor(f)!==f)return c.error(\"Numeric branch labels must be integer values.\");if(r){if(c.checkSubtype(r,le(f)))return null}else r=le(f);if(void 0!==i[String(f)])return c.error(\"Branch labels must be unique.\");i[String(f)]=a.length}var p=e.parse(l,o,n);if(!p)return null;n=n||p.type,a.push(p)}var d=e.parse(t[1],1,Zt);if(!d)return null;var g=e.parse(t[t.length-1],t.length-1,n);return g?\"value\"!==d.type.kind&&e.concat(1).checkSubtype(r,d.type)?null:new Qe(r,n,d,i,a,g):null},Qe.prototype.evaluate=function(t){var e=this.input.evaluate(t);return(le(e)===this.inputType&&this.outputs[this.cases[e]]||this.otherwise).evaluate(t)},Qe.prototype.eachChild=function(t){t(this.input),this.outputs.forEach(t),t(this.otherwise)},Qe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()})).concat(this.otherwise.possibleOutputs())},Qe.prototype.serialize=function(){for(var t=this,e=[\"match\",this.input.serialize()],r=[],n={},i=0,a=Object.keys(this.cases).sort();i<a.length;i+=1){var o=a[i];void 0===(h=n[this.cases[o]])?(n[this.cases[o]]=r.length,r.push([this.cases[o],[o]])):r[h][1].push(o)}for(var s=function(e){return\"number\"===t.inputType.kind?Number(e):e},l=0,c=r;l<c.length;l+=1){var u=c[l],h=u[0],f=u[1];1===f.length?e.push(s(f[0])):e.push(f.map(s)),e.push(this.outputs[outputIndex$1].serialize())}return e.push(this.otherwise.serialize()),e};var tr=function(t,e,r){this.type=t,this.branches=e,this.otherwise=r};function er(t,e){return\"==\"===t||\"!=\"===t?\"boolean\"===e.kind||\"string\"===e.kind||\"number\"===e.kind||\"null\"===e.kind||\"value\"===e.kind:\"string\"===e.kind||\"number\"===e.kind||\"value\"===e.kind}function rr(t,e,r,n){return 0===n.compare(e,r)}function nr(t,e,r){var n=\"==\"!==t&&\"!=\"!==t;return function(){function i(t,e,r){this.type=Yt,this.lhs=t,this.rhs=e,this.collator=r,this.hasUntypedArgument=\"value\"===t.type.kind||\"value\"===e.type.kind}return i.parse=function(t,e){if(3!==t.length&&4!==t.length)return e.error(\"Expected two or three arguments.\");var r=t[0],a=e.parse(t[1],1,Zt);if(!a)return null;if(!er(r,a.type))return e.concat(1).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Qt(a.type)+\"'.\");var o=e.parse(t[2],2,Zt);if(!o)return null;if(!er(r,o.type))return e.concat(2).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Qt(o.type)+\"'.\");if(a.type.kind!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot compare types '\"+Qt(a.type)+\"' and '\"+Qt(o.type)+\"'.\");n&&(\"value\"===a.type.kind&&\"value\"!==o.type.kind?a=new pe(o.type,[a]):\"value\"!==a.type.kind&&\"value\"===o.type.kind&&(o=new pe(a.type,[o])));var s=null;if(4===t.length){if(\"string\"!==a.type.kind&&\"string\"!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot use collator to compare non-string types.\");if(!(s=e.parse(t[3],3,Jt)))return null}return new i(a,o,s)},i.prototype.evaluate=function(i){var a=this.lhs.evaluate(i),o=this.rhs.evaluate(i);if(n&&this.hasUntypedArgument){var s=le(a),l=le(o);if(s.kind!==l.kind||\"string\"!==s.kind&&\"number\"!==s.kind)throw new he('Expected arguments for \"'+t+'\" to be (string, string) or (number, number), but found ('+s.kind+\", \"+l.kind+\") instead.\")}if(this.collator&&!n&&this.hasUntypedArgument){var c=le(a),u=le(o);if(\"string\"!==c.kind||\"string\"!==u.kind)return e(i,a,o)}return this.collator?r(i,a,o,this.collator.evaluate(i)):e(i,a,o)},i.prototype.eachChild=function(t){t(this.lhs),t(this.rhs),this.collator&&t(this.collator)},i.prototype.possibleOutputs=function(){return[!0,!1]},i.prototype.serialize=function(){var e=[t];return this.eachChild(function(t){e.push(t.serialize())}),e},i}()}tr.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=0)return e.error(\"Expected an odd number of arguments.\");var r;e.expectedType&&\"value\"!==e.expectedType.kind&&(r=e.expectedType);for(var n=[],i=1;i<t.length-1;i+=2){var a=e.parse(t[i],i,Yt);if(!a)return null;var o=e.parse(t[i+1],i+1,r);if(!o)return null;n.push([a,o]),r=r||o.type}var s=e.parse(t[t.length-1],t.length-1,r);return s?new tr(r,n,s):null},tr.prototype.evaluate=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];if(i.evaluate(t))return a.evaluate(t)}return this.otherwise.evaluate(t)},tr.prototype.eachChild=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];t(i),t(a)}t(this.otherwise)},tr.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.branches.map(function(t){return t[0],t[1].possibleOutputs()})).concat(this.otherwise.possibleOutputs())},tr.prototype.serialize=function(){var t=[\"case\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var ir=nr(\"==\",function(t,e,r){return e===r},rr),ar=nr(\"!=\",function(t,e,r){return e!==r},function(t,e,r,n){return!rr(0,e,r,n)}),or=nr(\"<\",function(t,e,r){return e<r},function(t,e,r,n){return n.compare(e,r)<0}),sr=nr(\">\",function(t,e,r){return e>r},function(t,e,r,n){return n.compare(e,r)>0}),lr=nr(\"<=\",function(t,e,r){return e<=r},function(t,e,r,n){return n.compare(e,r)<=0}),cr=nr(\">=\",function(t,e,r){return e>=r},function(t,e,r,n){return n.compare(e,r)>=0}),ur=function(t,e,r,n,i){this.type=Gt,this.number=t,this.locale=e,this.currency=r,this.minFractionDigits=n,this.maxFractionDigits=i};ur.parse=function(t,e){if(3!==t.length)return e.error(\"Expected two arguments.\");var r=e.parse(t[1],1,Ht);if(!r)return null;var n=t[2];if(\"object\"!=typeof n||Array.isArray(n))return e.error(\"NumberFormat options argument must be an object.\");var i=null;if(n.locale&&!(i=e.parse(n.locale,1,Gt)))return null;var a=null;if(n.currency&&!(a=e.parse(n.currency,1,Gt)))return null;var o=null;if(n[\"min-fraction-digits\"]&&!(o=e.parse(n[\"min-fraction-digits\"],1,Ht)))return null;var s=null;return n[\"max-fraction-digits\"]&&!(s=e.parse(n[\"max-fraction-digits\"],1,Ht))?null:new ur(r,i,a,o,s)},ur.prototype.evaluate=function(t){return new Intl.NumberFormat(this.locale?this.locale.evaluate(t):[],{style:this.currency?\"currency\":\"decimal\",currency:this.currency?this.currency.evaluate(t):void 0,minimumFractionDigits:this.minFractionDigits?this.minFractionDigits.evaluate(t):void 0,maximumFractionDigits:this.maxFractionDigits?this.maxFractionDigits.evaluate(t):void 0}).format(this.number.evaluate(t))},ur.prototype.eachChild=function(t){t(this.number),this.locale&&t(this.locale),this.currency&&t(this.currency),this.minFractionDigits&&t(this.minFractionDigits),this.maxFractionDigits&&t(this.maxFractionDigits)},ur.prototype.possibleOutputs=function(){return[void 0]},ur.prototype.serialize=function(){var t={};return this.locale&&(t.locale=this.locale.serialize()),this.currency&&(t.currency=this.currency.serialize()),this.minFractionDigits&&(t[\"min-fraction-digits\"]=this.minFractionDigits.serialize()),this.maxFractionDigits&&(t[\"max-fraction-digits\"]=this.maxFractionDigits.serialize()),[\"number-format\",this.number.serialize(),t]};var hr=function(t){this.type=Ht,this.input=t};hr.parse=function(t,e){if(2!==t.length)return e.error(\"Expected 1 argument, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1);return r?\"array\"!==r.type.kind&&\"string\"!==r.type.kind&&\"value\"!==r.type.kind?e.error(\"Expected argument of type string or array, but found \"+Qt(r.type)+\" instead.\"):new hr(r):null},hr.prototype.evaluate=function(t){var e=this.input.evaluate(t);if(\"string\"==typeof e)return e.length;if(Array.isArray(e))return e.length;throw new he(\"Expected value to be of type string or array, but found \"+Qt(le(e))+\" instead.\")},hr.prototype.eachChild=function(t){t(this.input)},hr.prototype.possibleOutputs=function(){return[void 0]},hr.prototype.serialize=function(){var t=[\"length\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var fr={\"==\":ir,\"!=\":ar,\">\":sr,\"<\":or,\">=\":cr,\"<=\":lr,array:pe,at:$e,boolean:pe,case:tr,coalesce:Je,collator:be,format:de,interpolate:Xe,\"interpolate-hcl\":Xe,\"interpolate-lab\":Xe,length:hr,let:Ke,literal:ue,match:Qe,number:pe,\"number-format\":ur,object:pe,step:Se,string:pe,\"to-boolean\":ve,\"to-color\":ve,\"to-number\":ve,\"to-string\":ve,var:Te};function pr(t,e){var r=e[0],n=e[1],i=e[2],a=e[3];r=r.evaluate(t),n=n.evaluate(t),i=i.evaluate(t);var o=a?a.evaluate(t):1,s=se(r,n,i,o);if(s)throw new he(s);return new ne(r/255*o,n/255*o,i/255*o,o)}function dr(t,e){return t in e}function gr(t,e){var r=e[t];return void 0===r?null:r}function vr(t){return{type:t}}function mr(t){return{result:\"success\",value:t}}function yr(t){return{result:\"error\",value:t}}function xr(t){return\"data-driven\"===t[\"property-type\"]||\"cross-faded-data-driven\"===t[\"property-type\"]}function br(t){return!!t.expression&&t.expression.parameters.indexOf(\"zoom\")>-1}function _r(t){return!!t.expression&&t.expression.interpolated}function wr(t){return t instanceof Number?\"number\":t instanceof String?\"string\":t instanceof Boolean?\"boolean\":Array.isArray(t)?\"array\":null===t?\"null\":typeof t}function kr(t){return\"object\"==typeof t&&null!==t&&!Array.isArray(t)}function Tr(t){return t}function Ar(t,e,r){return void 0!==t?t:void 0!==e?e:void 0!==r?r:void 0}function Mr(t,e,r,n,i){return Ar(typeof r===i?n[r]:void 0,t.default,e.default)}function Sr(t,e,r){if(\"number\"!==wr(r))return Ar(t.default,e.default);var n=t.stops.length;if(1===n)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[n-1][0])return t.stops[n-1][1];var i=Me(t.stops.map(function(t){return t[0]}),r);return t.stops[i][1]}function Er(t,e,r){var n=void 0!==t.base?t.base:1;if(\"number\"!==wr(r))return Ar(t.default,e.default);var i=t.stops.length;if(1===i)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[i-1][0])return t.stops[i-1][1];var a=Me(t.stops.map(function(t){return t[0]}),r),o=function(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}(r,n,t.stops[a][0],t.stops[a+1][0]),s=t.stops[a][1],l=t.stops[a+1][1],c=Ce[e.type]||Tr;if(t.colorSpace&&\"rgb\"!==t.colorSpace){var u=We[t.colorSpace];c=function(t,e){return u.reverse(u.interpolate(u.forward(t),u.forward(e),o))}}return\"function\"==typeof s.evaluate?{evaluate:function(){for(var t=[],e=arguments.length;e--;)t[e]=arguments[e];var r=s.evaluate.apply(void 0,t),n=l.evaluate.apply(void 0,t);if(void 0!==r&&void 0!==n)return c(r,n,o)}}:c(s,l,o)}function Cr(t,e,r){return\"color\"===e.type?r=ne.parse(r):\"formatted\"===e.type?r=oe.fromString(r.toString()):wr(r)===e.type||\"enum\"===e.type&&e.values[r]||(r=void 0),Ar(r,t.default,e.default)}xe.register(fr,{error:[{kind:\"error\"},[Gt],function(t,e){var r=e[0];throw new he(r.evaluate(t))}],typeof:[Gt,[Zt],function(t,e){return Qt(le(e[0].evaluate(t)))}],\"to-rgba\":[$t(Ht,4),[Wt],function(t,e){return e[0].evaluate(t).toArray()}],rgb:[Wt,[Ht,Ht,Ht],pr],rgba:[Wt,[Ht,Ht,Ht,Ht],pr],has:{type:Yt,overloads:[[[Gt],function(t,e){return dr(e[0].evaluate(t),t.properties())}],[[Gt,Xt],function(t,e){var r=e[0],n=e[1];return dr(r.evaluate(t),n.evaluate(t))}]]},get:{type:Zt,overloads:[[[Gt],function(t,e){return gr(e[0].evaluate(t),t.properties())}],[[Gt,Xt],function(t,e){var r=e[0],n=e[1];return gr(r.evaluate(t),n.evaluate(t))}]]},\"feature-state\":[Zt,[Gt],function(t,e){return gr(e[0].evaluate(t),t.featureState||{})}],properties:[Xt,[],function(t){return t.properties()}],\"geometry-type\":[Gt,[],function(t){return t.geometryType()}],id:[Zt,[],function(t){return t.id()}],zoom:[Ht,[],function(t){return t.globals.zoom}],\"heatmap-density\":[Ht,[],function(t){return t.globals.heatmapDensity||0}],\"line-progress\":[Ht,[],function(t){return t.globals.lineProgress||0}],accumulated:[Zt,[],function(t){return void 0===t.globals.accumulated?null:t.globals.accumulated}],\"+\":[Ht,vr(Ht),function(t,e){for(var r=0,n=0,i=e;n<i.length;n+=1)r+=i[n].evaluate(t);return r}],\"*\":[Ht,vr(Ht),function(t,e){for(var r=1,n=0,i=e;n<i.length;n+=1)r*=i[n].evaluate(t);return r}],\"-\":{type:Ht,overloads:[[[Ht,Ht],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)-n.evaluate(t)}],[[Ht],function(t,e){return-e[0].evaluate(t)}]]},\"/\":[Ht,[Ht,Ht],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)/n.evaluate(t)}],\"%\":[Ht,[Ht,Ht],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)%n.evaluate(t)}],ln2:[Ht,[],function(){return Math.LN2}],pi:[Ht,[],function(){return Math.PI}],e:[Ht,[],function(){return Math.E}],\"^\":[Ht,[Ht,Ht],function(t,e){var r=e[0],n=e[1];return Math.pow(r.evaluate(t),n.evaluate(t))}],sqrt:[Ht,[Ht],function(t,e){var r=e[0];return Math.sqrt(r.evaluate(t))}],log10:[Ht,[Ht],function(t,e){var r=e[0];return Math.log(r.evaluate(t))/Math.LN10}],ln:[Ht,[Ht],function(t,e){var r=e[0];return Math.log(r.evaluate(t))}],log2:[Ht,[Ht],function(t,e){var r=e[0];return Math.log(r.evaluate(t))/Math.LN2}],sin:[Ht,[Ht],function(t,e){var r=e[0];return Math.sin(r.evaluate(t))}],cos:[Ht,[Ht],function(t,e){var r=e[0];return Math.cos(r.evaluate(t))}],tan:[Ht,[Ht],function(t,e){var r=e[0];return Math.tan(r.evaluate(t))}],asin:[Ht,[Ht],function(t,e){var r=e[0];return Math.asin(r.evaluate(t))}],acos:[Ht,[Ht],function(t,e){var r=e[0];return Math.acos(r.evaluate(t))}],atan:[Ht,[Ht],function(t,e){var r=e[0];return Math.atan(r.evaluate(t))}],min:[Ht,vr(Ht),function(t,e){return Math.min.apply(Math,e.map(function(e){return e.evaluate(t)}))}],max:[Ht,vr(Ht),function(t,e){return Math.max.apply(Math,e.map(function(e){return e.evaluate(t)}))}],abs:[Ht,[Ht],function(t,e){var r=e[0];return Math.abs(r.evaluate(t))}],round:[Ht,[Ht],function(t,e){var r=e[0].evaluate(t);return r<0?-Math.round(-r):Math.round(r)}],floor:[Ht,[Ht],function(t,e){var r=e[0];return Math.floor(r.evaluate(t))}],ceil:[Ht,[Ht],function(t,e){var r=e[0];return Math.ceil(r.evaluate(t))}],\"filter-==\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1];return t.properties()[r.value]===n.value}],\"filter-id-==\":[Yt,[Zt],function(t,e){var r=e[0];return t.id()===r.value}],\"filter-type-==\":[Yt,[Gt],function(t,e){var r=e[0];return t.geometryType()===r.value}],\"filter-<\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<a}],\"filter-id-<\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<i}],\"filter->\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>a}],\"filter-id->\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>i}],\"filter-<=\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<=a}],\"filter-id-<=\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<=i}],\"filter->=\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>=a}],\"filter-id->=\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>=i}],\"filter-has\":[Yt,[Zt],function(t,e){return e[0].value in t.properties()}],\"filter-has-id\":[Yt,[],function(t){return null!==t.id()}],\"filter-type-in\":[Yt,[$t(Gt)],function(t,e){return e[0].value.indexOf(t.geometryType())>=0}],\"filter-id-in\":[Yt,[$t(Zt)],function(t,e){return e[0].value.indexOf(t.id())>=0}],\"filter-in-small\":[Yt,[Gt,$t(Zt)],function(t,e){var r=e[0];return e[1].value.indexOf(t.properties()[r.value])>=0}],\"filter-in-large\":[Yt,[Gt,$t(Zt)],function(t,e){var r=e[0],n=e[1];return function(t,e,r,n){for(;r<=n;){var i=r+n>>1;if(e[i]===t)return!0;e[i]>t?n=i-1:r=i+1}return!1}(t.properties()[r.value],n.value,0,n.value.length-1)}],all:{type:Yt,overloads:[[[Yt,Yt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)&&n.evaluate(t)}],[vr(Yt),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(!n[r].evaluate(t))return!1;return!0}]]},any:{type:Yt,overloads:[[[Yt,Yt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)||n.evaluate(t)}],[vr(Yt),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(n[r].evaluate(t))return!0;return!1}]]},\"!\":[Yt,[Yt],function(t,e){return!e[0].evaluate(t)}],\"is-supported-script\":[Yt,[Gt],function(t,e){var r=e[0],n=t.globals&&t.globals.isSupportedScript;return!n||n(r.evaluate(t))}],upcase:[Gt,[Gt],function(t,e){return e[0].evaluate(t).toUpperCase()}],downcase:[Gt,[Gt],function(t,e){return e[0].evaluate(t).toLowerCase()}],concat:[Gt,vr(Zt),function(t,e){return e.map(function(e){return ce(e.evaluate(t))}).join(\"\")}],\"resolved-locale\":[Gt,[Jt],function(t,e){return e[0].evaluate(t).resolvedLocale()}]});var Lr=function(t,e){var r;this.expression=t,this._warningHistory={},this._evaluator=new ye,this._defaultValue=e?\"color\"===(r=e).type&&kr(r.default)?new ne(0,0,0,0):\"color\"===r.type?ne.parse(r.default)||null:void 0===r.default?null:r.default:null,this._enumValues=e&&\"enum\"===e.type?e.values:null};function Pr(t){return Array.isArray(t)&&t.length>0&&\"string\"==typeof t[0]&&t[0]in fr}function Or(t,e){var r=new Ae(fr,[],e?function(t){var e={color:Wt,string:Gt,number:Ht,enum:Gt,boolean:Yt,formatted:Kt};return\"array\"===t.type?$t(e[t.value]||Zt,t.length):e[t.type]}(e):void 0),n=r.parse(t,void 0,void 0,void 0,e&&\"string\"===e.type?{typeAnnotation:\"coerce\"}:void 0);return n?mr(new Lr(n,e)):yr(r.errors)}Lr.prototype.evaluateWithoutErrorHandling=function(t,e,r){return this._evaluator.globals=t,this._evaluator.feature=e,this._evaluator.featureState=r,this.expression.evaluate(this._evaluator)},Lr.prototype.evaluate=function(t,e,r){this._evaluator.globals=t,this._evaluator.feature=e||null,this._evaluator.featureState=r||null;try{var n=this.expression.evaluate(this._evaluator);if(null==n)return this._defaultValue;if(this._enumValues&&!(n in this._enumValues))throw new he(\"Expected value to be one of \"+Object.keys(this._enumValues).map(function(t){return JSON.stringify(t)}).join(\", \")+\", but found \"+JSON.stringify(n)+\" instead.\");return n}catch(t){return this._warningHistory[t.message]||(this._warningHistory[t.message]=!0,\"undefined\"!=typeof console&&console.warn(t.message)),this._defaultValue}};var zr=function(t,e){this.kind=t,this._styleExpression=e,this.isStateDependent=\"constant\"!==t&&!we(e.expression)};zr.prototype.evaluateWithoutErrorHandling=function(t,e,r){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r)},zr.prototype.evaluate=function(t,e,r){return this._styleExpression.evaluate(t,e,r)};var Ir=function(t,e,r){this.kind=t,this.zoomStops=r.labels,this._styleExpression=e,this.isStateDependent=\"camera\"!==t&&!we(e.expression),r instanceof Xe&&(this.interpolationType=r.interpolation)};function Dr(t,e){if(\"error\"===(t=Or(t,e)).result)return t;var r=t.value.expression,n=_e(r);if(!n&&!xr(e))return yr([new Ut(\"\",\"data expressions not supported\")]);var i=ke(r,[\"zoom\"]);if(!i&&!br(e))return yr([new Ut(\"\",\"zoom expressions not supported\")]);var a=function t(e){var r=null;if(e instanceof Ke)r=t(e.result);else if(e instanceof Je)for(var n=0,i=e.args;n<i.length;n+=1){var a=i[n];if(r=t(a))break}else(e instanceof Se||e instanceof Xe)&&e.input instanceof xe&&\"zoom\"===e.input.name&&(r=e);return r instanceof Ut?r:(e.eachChild(function(e){var n=t(e);n instanceof Ut?r=n:!r&&n?r=new Ut(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.'):r&&n&&r!==n&&(r=new Ut(\"\",'Only one zoom-based \"step\" or \"interpolate\" subexpression may be used in an expression.'))}),r)}(r);return a||i?a instanceof Ut?yr([a]):a instanceof Xe&&!_r(e)?yr([new Ut(\"\",'\"interpolate\" expressions cannot be used with this property')]):mr(a?new Ir(n?\"camera\":\"composite\",t.value,a):new zr(n?\"constant\":\"source\",t.value)):yr([new Ut(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.')])}Ir.prototype.evaluateWithoutErrorHandling=function(t,e,r){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r)},Ir.prototype.evaluate=function(t,e,r){return this._styleExpression.evaluate(t,e,r)},Ir.prototype.interpolationFactor=function(t,e,r){return this.interpolationType?Xe.interpolationFactor(this.interpolationType,t,e,r):0};var Rr=function(t,e){this._parameters=t,this._specification=e,Ft(this,function t(e,r){var n,i,a,o=\"color\"===r.type,s=e.stops&&\"object\"==typeof e.stops[0][0],l=s||void 0!==e.property,c=s||!l,u=e.type||(_r(r)?\"exponential\":\"interval\");if(o&&((e=Ft({},e)).stops&&(e.stops=e.stops.map(function(t){return[t[0],ne.parse(t[1])]})),e.default?e.default=ne.parse(e.default):e.default=ne.parse(r.default)),e.colorSpace&&\"rgb\"!==e.colorSpace&&!We[e.colorSpace])throw new Error(\"Unknown color space: \"+e.colorSpace);if(\"exponential\"===u)n=Er;else if(\"interval\"===u)n=Sr;else if(\"categorical\"===u){n=Mr,i=Object.create(null);for(var h=0,f=e.stops;h<f.length;h+=1){var p=f[h];i[p[0]]=p[1]}a=typeof e.stops[0][0]}else{if(\"identity\"!==u)throw new Error('Unknown function type \"'+u+'\"');n=Cr}if(s){for(var d={},g=[],v=0;v<e.stops.length;v++){var m=e.stops[v],y=m[0].zoom;void 0===d[y]&&(d[y]={zoom:y,type:e.type,property:e.property,default:e.default,stops:[]},g.push(y)),d[y].stops.push([m[0].value,m[1]])}for(var x=[],b=0,_=g;b<_.length;b+=1){var w=_[b];x.push([d[w].zoom,t(d[w],r)])}var k={name:\"linear\"};return{kind:\"composite\",interpolationType:k,interpolationFactor:Xe.interpolationFactor.bind(void 0,k),zoomStops:x.map(function(t){return t[0]}),evaluate:function(t,n){var i=t.zoom;return Er({stops:x,base:e.base},r,i).evaluate(i,n)}}}if(c){var T=\"exponential\"===u?{name:\"exponential\",base:void 0!==e.base?e.base:1}:null;return{kind:\"camera\",interpolationType:T,interpolationFactor:Xe.interpolationFactor.bind(void 0,T),zoomStops:e.stops.map(function(t){return t[0]}),evaluate:function(t){var o=t.zoom;return n(e,r,o,i,a)}}}return{kind:\"source\",evaluate:function(t,o){var s=o&&o.properties?o.properties[e.property]:void 0;return void 0===s?Ar(e.default,r.default):n(e,r,s,i,a)}}}(this._parameters,this._specification))};function Fr(t){var e=t.key,r=t.value,n=t.valueSpec||{},i=t.objectElementValidators||{},a=t.style,o=t.styleSpec,s=[],l=wr(r);if(\"object\"!==l)return[new Dt(e,r,\"object expected, \"+l+\" found\")];for(var c in r){var u=c.split(\".\")[0],h=n[u]||n[\"*\"],f=void 0;if(i[u])f=i[u];else if(n[u])f=ln;else if(i[\"*\"])f=i[\"*\"];else{if(!n[\"*\"]){s.push(new Dt(e,r[c],'unknown property \"'+c+'\"'));continue}f=ln}s=s.concat(f({key:(e?e+\".\":e)+c,value:r[c],valueSpec:h,style:a,styleSpec:o,object:r,objectKey:c},r))}for(var p in n)i[p]||n[p].required&&void 0===n[p].default&&void 0===r[p]&&s.push(new Dt(e,r,'missing required property \"'+p+'\"'));return s}function Br(t){var e=t.value,r=t.valueSpec,n=t.style,i=t.styleSpec,a=t.key,o=t.arrayElementValidator||ln;if(\"array\"!==wr(e))return[new Dt(a,e,\"array expected, \"+wr(e)+\" found\")];if(r.length&&e.length!==r.length)return[new Dt(a,e,\"array length \"+r.length+\" expected, length \"+e.length+\" found\")];if(r[\"min-length\"]&&e.length<r[\"min-length\"])return[new Dt(a,e,\"array length at least \"+r[\"min-length\"]+\" expected, length \"+e.length+\" found\")];var s={type:r.value,values:r.values};i.$version<7&&(s.function=r.function),\"object\"===wr(r.value)&&(s=r.value);for(var l=[],c=0;c<e.length;c++)l=l.concat(o({array:e,arrayIndex:c,value:e[c],valueSpec:s,style:n,styleSpec:i,key:a+\"[\"+c+\"]\"}));return l}function Nr(t){var e=t.key,r=t.value,n=t.valueSpec,i=wr(r);return\"number\"!==i?[new Dt(e,r,\"number expected, \"+i+\" found\")]:\"minimum\"in n&&r<n.minimum?[new Dt(e,r,r+\" is less than the minimum value \"+n.minimum)]:\"maximum\"in n&&r>n.maximum?[new Dt(e,r,r+\" is greater than the maximum value \"+n.maximum)]:[]}function jr(t){var e,r,n,i=t.valueSpec,a=Nt(t.value.type),o={},s=\"categorical\"!==a&&void 0===t.value.property,l=!s,c=\"array\"===wr(t.value.stops)&&\"array\"===wr(t.value.stops[0])&&\"object\"===wr(t.value.stops[0][0]),u=Fr({key:t.key,value:t.value,valueSpec:t.styleSpec.function,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{stops:function(t){if(\"identity\"===a)return[new Dt(t.key,t.value,'identity function may not have a \"stops\" property')];var e=[],r=t.value;return e=e.concat(Br({key:t.key,value:r,valueSpec:t.valueSpec,style:t.style,styleSpec:t.styleSpec,arrayElementValidator:h})),\"array\"===wr(r)&&0===r.length&&e.push(new Dt(t.key,r,\"array must have at least one stop\")),e},default:function(t){return ln({key:t.key,value:t.value,valueSpec:i,style:t.style,styleSpec:t.styleSpec})}}});return\"identity\"===a&&s&&u.push(new Dt(t.key,t.value,'missing required property \"property\"')),\"identity\"===a||t.value.stops||u.push(new Dt(t.key,t.value,'missing required property \"stops\"')),\"exponential\"===a&&t.valueSpec.expression&&!_r(t.valueSpec)&&u.push(new Dt(t.key,t.value,\"exponential functions not supported\")),t.styleSpec.$version>=8&&(l&&!xr(t.valueSpec)?u.push(new Dt(t.key,t.value,\"property functions not supported\")):s&&!br(t.valueSpec)&&u.push(new Dt(t.key,t.value,\"zoom functions not supported\"))),\"categorical\"!==a&&!c||void 0!==t.value.property||u.push(new Dt(t.key,t.value,'\"property\" property is required')),u;function h(t){var e=[],a=t.value,s=t.key;if(\"array\"!==wr(a))return[new Dt(s,a,\"array expected, \"+wr(a)+\" found\")];if(2!==a.length)return[new Dt(s,a,\"array length 2 expected, length \"+a.length+\" found\")];if(c){if(\"object\"!==wr(a[0]))return[new Dt(s,a,\"object expected, \"+wr(a[0])+\" found\")];if(void 0===a[0].zoom)return[new Dt(s,a,\"object stop key must have zoom\")];if(void 0===a[0].value)return[new Dt(s,a,\"object stop key must have value\")];if(n&&n>Nt(a[0].zoom))return[new Dt(s,a[0].zoom,\"stop zoom values must appear in ascending order\")];Nt(a[0].zoom)!==n&&(n=Nt(a[0].zoom),r=void 0,o={}),e=e.concat(Fr({key:s+\"[0]\",value:a[0],valueSpec:{zoom:{}},style:t.style,styleSpec:t.styleSpec,objectElementValidators:{zoom:Nr,value:f}}))}else e=e.concat(f({key:s+\"[0]\",value:a[0],valueSpec:{},style:t.style,styleSpec:t.styleSpec},a));return Pr(jt(a[1]))?e.concat([new Dt(s+\"[1]\",a[1],\"expressions are not allowed in function stops.\")]):e.concat(ln({key:s+\"[1]\",value:a[1],valueSpec:i,style:t.style,styleSpec:t.styleSpec}))}function f(t,n){var s=wr(t.value),l=Nt(t.value),c=null!==t.value?t.value:n;if(e){if(s!==e)return[new Dt(t.key,c,s+\" stop domain type must match previous stop domain type \"+e)]}else e=s;if(\"number\"!==s&&\"string\"!==s&&\"boolean\"!==s)return[new Dt(t.key,c,\"stop domain value must be a number, string, or boolean\")];if(\"number\"!==s&&\"categorical\"!==a){var u=\"number expected, \"+s+\" found\";return xr(i)&&void 0===a&&(u+='\\nIf you intended to use a categorical function, specify `\"type\": \"categorical\"`.'),[new Dt(t.key,c,u)]}return\"categorical\"!==a||\"number\"!==s||isFinite(l)&&Math.floor(l)===l?\"categorical\"!==a&&\"number\"===s&&void 0!==r&&l<r?[new Dt(t.key,c,\"stop domain values must appear in ascending order\")]:(r=l,\"categorical\"===a&&l in o?[new Dt(t.key,c,\"stop domain values must be unique\")]:(o[l]=!0,[])):[new Dt(t.key,c,\"integer expected, found \"+l)]}}function Ur(t){var e=(\"property\"===t.expressionContext?Dr:Or)(jt(t.value),t.valueSpec);if(\"error\"===e.result)return e.value.map(function(e){return new Dt(\"\"+t.key+e.key,t.value,e.message)});var r=e.value.expression||e.value._styleExpression.expression;if(\"property\"===t.expressionContext&&\"text-font\"===t.propertyKey&&-1!==r.possibleOutputs().indexOf(void 0))return[new Dt(t.key,t.value,'Invalid data expression for \"'+t.propertyKey+'\". Output values must be contained as literals within the expression.')];if(\"property\"===t.expressionContext&&\"layout\"===t.propertyType&&!we(r))return[new Dt(t.key,t.value,'\"feature-state\" data expressions are not supported with layout properties.')];if(\"filter\"===t.expressionContext&&!we(r))return[new Dt(t.key,t.value,'\"feature-state\" data expressions are not supported with filters.')];if(t.expressionContext&&0===t.expressionContext.indexOf(\"cluster\")){if(!ke(r,[\"zoom\",\"feature-state\"]))return[new Dt(t.key,t.value,'\"zoom\" and \"feature-state\" expressions are not supported with cluster properties.')];if(\"cluster-initial\"===t.expressionContext&&!_e(r))return[new Dt(t.key,t.value,\"Feature data expressions are not supported with initial expression part of cluster properties.\")]}return[]}function Vr(t){var e=t.key,r=t.value,n=t.valueSpec,i=[];return Array.isArray(n.values)?-1===n.values.indexOf(Nt(r))&&i.push(new Dt(e,r,\"expected one of [\"+n.values.join(\", \")+\"], \"+JSON.stringify(r)+\" found\")):-1===Object.keys(n.values).indexOf(Nt(r))&&i.push(new Dt(e,r,\"expected one of [\"+Object.keys(n.values).join(\", \")+\"], \"+JSON.stringify(r)+\" found\")),i}function qr(t){if(!0===t||!1===t)return!0;if(!Array.isArray(t)||0===t.length)return!1;switch(t[0]){case\"has\":return t.length>=2&&\"$id\"!==t[1]&&\"$type\"!==t[1];case\"in\":case\"!in\":case\"!has\":case\"none\":return!1;case\"==\":case\"!=\":case\">\":case\">=\":case\"<\":case\"<=\":return 3!==t.length||Array.isArray(t[1])||Array.isArray(t[2]);case\"any\":case\"all\":for(var e=0,r=t.slice(1);e<r.length;e+=1){var n=r[e];if(!qr(n)&&\"boolean\"!=typeof n)return!1}return!0;default:return!0}}Rr.deserialize=function(t){return new Rr(t._parameters,t._specification)},Rr.serialize=function(t){return{_parameters:t._parameters,_specification:t._specification}};var Hr={type:\"boolean\",default:!1,transition:!1,\"property-type\":\"data-driven\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]}};function Gr(t){if(null==t)return function(){return!0};qr(t)||(t=Wr(t));var e=Or(t,Hr);if(\"error\"===e.result)throw new Error(e.value.map(function(t){return t.key+\": \"+t.message}).join(\", \"));return function(t,r){return e.value.evaluate(t,r)}}function Yr(t,e){return t<e?-1:t>e?1:0}function Wr(t){if(!t)return!0;var e,r=t[0];return t.length<=1?\"any\"!==r:\"==\"===r?Xr(t[1],t[2],\"==\"):\"!=\"===r?Kr(Xr(t[1],t[2],\"==\")):\"<\"===r||\">\"===r||\"<=\"===r||\">=\"===r?Xr(t[1],t[2],r):\"any\"===r?(e=t.slice(1),[\"any\"].concat(e.map(Wr))):\"all\"===r?[\"all\"].concat(t.slice(1).map(Wr)):\"none\"===r?[\"all\"].concat(t.slice(1).map(Wr).map(Kr)):\"in\"===r?Zr(t[1],t.slice(2)):\"!in\"===r?Kr(Zr(t[1],t.slice(2))):\"has\"===r?Jr(t[1]):\"!has\"!==r||Kr(Jr(t[1]))}function Xr(t,e,r){switch(t){case\"$type\":return[\"filter-type-\"+r,e];case\"$id\":return[\"filter-id-\"+r,e];default:return[\"filter-\"+r,t,e]}}function Zr(t,e){if(0===e.length)return!1;switch(t){case\"$type\":return[\"filter-type-in\",[\"literal\",e]];case\"$id\":return[\"filter-id-in\",[\"literal\",e]];default:return e.length>200&&!e.some(function(t){return typeof t!=typeof e[0]})?[\"filter-in-large\",t,[\"literal\",e.sort(Yr)]]:[\"filter-in-small\",t,[\"literal\",e]]}}function Jr(t){switch(t){case\"$type\":return!0;case\"$id\":return[\"filter-has-id\"];default:return[\"filter-has\",t]}}function Kr(t){return[\"!\",t]}function $r(t){return qr(jt(t.value))?Ur(Ft({},t,{expressionContext:\"filter\",valueSpec:{value:\"boolean\"}})):function t(e){var r=e.value,n=e.key;if(\"array\"!==wr(r))return[new Dt(n,r,\"array expected, \"+wr(r)+\" found\")];var i,a=e.styleSpec,o=[];if(r.length<1)return[new Dt(n,r,\"filter array must have at least 1 element\")];switch(o=o.concat(Vr({key:n+\"[0]\",value:r[0],valueSpec:a.filter_operator,style:e.style,styleSpec:e.styleSpec})),Nt(r[0])){case\"<\":case\"<=\":case\">\":case\">=\":r.length>=2&&\"$type\"===Nt(r[1])&&o.push(new Dt(n,r,'\"$type\" cannot be use with operator \"'+r[0]+'\"'));case\"==\":case\"!=\":3!==r.length&&o.push(new Dt(n,r,'filter array for operator \"'+r[0]+'\" must have 3 elements'));case\"in\":case\"!in\":r.length>=2&&\"string\"!==(i=wr(r[1]))&&o.push(new Dt(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"));for(var s=2;s<r.length;s++)i=wr(r[s]),\"$type\"===Nt(r[1])?o=o.concat(Vr({key:n+\"[\"+s+\"]\",value:r[s],valueSpec:a.geometry_type,style:e.style,styleSpec:e.styleSpec})):\"string\"!==i&&\"number\"!==i&&\"boolean\"!==i&&o.push(new Dt(n+\"[\"+s+\"]\",r[s],\"string, number, or boolean expected, \"+i+\" found\"));break;case\"any\":case\"all\":case\"none\":for(var l=1;l<r.length;l++)o=o.concat(t({key:n+\"[\"+l+\"]\",value:r[l],style:e.style,styleSpec:e.styleSpec}));break;case\"has\":case\"!has\":i=wr(r[1]),2!==r.length?o.push(new Dt(n,r,'filter array for \"'+r[0]+'\" operator must have 2 elements')):\"string\"!==i&&o.push(new Dt(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"))}return o}(t)}function Qr(t,e){var r=t.key,n=t.style,i=t.styleSpec,a=t.value,o=t.objectKey,s=i[e+\"_\"+t.layerType];if(!s)return[];var l=o.match(/^(.*)-transition$/);if(\"paint\"===e&&l&&s[l[1]]&&s[l[1]].transition)return ln({key:r,value:a,valueSpec:i.transition,style:n,styleSpec:i});var c,u=t.valueSpec||s[o];if(!u)return[new Dt(r,a,'unknown property \"'+o+'\"')];if(\"string\"===wr(a)&&xr(u)&&!u.tokens&&(c=/^{([^}]+)}$/.exec(a)))return[new Dt(r,a,'\"'+o+'\" does not support interpolation syntax\\nUse an identity property function instead: `{ \"type\": \"identity\", \"property\": '+JSON.stringify(c[1])+\" }`.\")];var h=[];return\"symbol\"===t.layerType&&(\"text-field\"===o&&n&&!n.glyphs&&h.push(new Dt(r,a,'use of \"text-field\" requires a style \"glyphs\" property')),\"text-font\"===o&&kr(jt(a))&&\"identity\"===Nt(a.type)&&h.push(new Dt(r,a,'\"text-font\" does not support identity functions'))),h.concat(ln({key:t.key,value:a,valueSpec:u,style:n,styleSpec:i,expressionContext:\"property\",propertyType:e,propertyKey:o}))}function tn(t){return Qr(t,\"paint\")}function en(t){return Qr(t,\"layout\")}function rn(t){var e=[],r=t.value,n=t.key,i=t.style,a=t.styleSpec;r.type||r.ref||e.push(new Dt(n,r,'either \"type\" or \"ref\" is required'));var o,s=Nt(r.type),l=Nt(r.ref);if(r.id)for(var c=Nt(r.id),u=0;u<t.arrayIndex;u++){var h=i.layers[u];Nt(h.id)===c&&e.push(new Dt(n,r.id,'duplicate layer id \"'+r.id+'\", previously used at line '+h.id.__line__))}if(\"ref\"in r)[\"type\",\"source\",\"source-layer\",\"filter\",\"layout\"].forEach(function(t){t in r&&e.push(new Dt(n,r[t],'\"'+t+'\" is prohibited for ref layers'))}),i.layers.forEach(function(t){Nt(t.id)===l&&(o=t)}),o?o.ref?e.push(new Dt(n,r.ref,\"ref cannot reference another ref layer\")):s=Nt(o.type):e.push(new Dt(n,r.ref,'ref layer \"'+l+'\" not found'));else if(\"background\"!==s)if(r.source){var f=i.sources&&i.sources[r.source],p=f&&Nt(f.type);f?\"vector\"===p&&\"raster\"===s?e.push(new Dt(n,r.source,'layer \"'+r.id+'\" requires a raster source')):\"raster\"===p&&\"raster\"!==s?e.push(new Dt(n,r.source,'layer \"'+r.id+'\" requires a vector source')):\"vector\"!==p||r[\"source-layer\"]?\"raster-dem\"===p&&\"hillshade\"!==s?e.push(new Dt(n,r.source,\"raster-dem source can only be used with layer type 'hillshade'.\")):\"line\"!==s||!r.paint||!r.paint[\"line-gradient\"]||\"geojson\"===p&&f.lineMetrics||e.push(new Dt(n,r,'layer \"'+r.id+'\" specifies a line-gradient, which requires a GeoJSON source with `lineMetrics` enabled.')):e.push(new Dt(n,r,'layer \"'+r.id+'\" must specify a \"source-layer\"')):e.push(new Dt(n,r.source,'source \"'+r.source+'\" not found'))}else e.push(new Dt(n,r,'missing required property \"source\"'));return e=e.concat(Fr({key:n,value:r,valueSpec:a.layer,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(){return[]},type:function(){return ln({key:n+\".type\",value:r.type,valueSpec:a.layer.type,style:t.style,styleSpec:t.styleSpec,object:r,objectKey:\"type\"})},filter:$r,layout:function(t){return Fr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return en(Ft({layerType:s},t))}}})},paint:function(t){return Fr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return tn(Ft({layerType:s},t))}}})}}}))}function nn(t){var e=t.value,r=t.key,n=t.styleSpec,i=t.style;if(!e.type)return[new Dt(r,e,'\"type\" is required')];var a,o=Nt(e.type);switch(o){case\"vector\":case\"raster\":case\"raster-dem\":if(a=Fr({key:r,value:e,valueSpec:n[\"source_\"+o.replace(\"-\",\"_\")],style:t.style,styleSpec:n}),\"url\"in e)for(var s in e)[\"type\",\"url\",\"tileSize\"].indexOf(s)<0&&a.push(new Dt(r+\".\"+s,e[s],'a source with a \"url\" property may not include a \"'+s+'\" property'));return a;case\"geojson\":if(a=Fr({key:r,value:e,valueSpec:n.source_geojson,style:i,styleSpec:n}),e.cluster)for(var l in e.clusterProperties){var c=e.clusterProperties[l],u=c[0],h=c[1],f=\"string\"==typeof u?[u,[\"accumulated\"],[\"get\",l]]:u;a.push.apply(a,Ur({key:r+\".\"+l+\".map\",value:h,expressionContext:\"cluster-map\"})),a.push.apply(a,Ur({key:r+\".\"+l+\".reduce\",value:f,expressionContext:\"cluster-reduce\"}))}return a;case\"video\":return Fr({key:r,value:e,valueSpec:n.source_video,style:i,styleSpec:n});case\"image\":return Fr({key:r,value:e,valueSpec:n.source_image,style:i,styleSpec:n});case\"canvas\":return[new Dt(r,null,\"Please use runtime APIs to add canvas sources, rather than including them in stylesheets.\",\"source.canvas\")];default:return Vr({key:r+\".type\",value:e.type,valueSpec:{values:[\"vector\",\"raster\",\"raster-dem\",\"geojson\",\"video\",\"image\"]},style:i,styleSpec:n})}}function an(t){var e=t.value,r=t.styleSpec,n=r.light,i=t.style,a=[],o=wr(e);if(void 0===e)return a;if(\"object\"!==o)return a.concat([new Dt(\"light\",e,\"object expected, \"+o+\" found\")]);for(var s in e){var l=s.match(/^(.*)-transition$/);a=l&&n[l[1]]&&n[l[1]].transition?a.concat(ln({key:s,value:e[s],valueSpec:r.transition,style:i,styleSpec:r})):n[s]?a.concat(ln({key:s,value:e[s],valueSpec:n[s],style:i,styleSpec:r})):a.concat([new Dt(s,e[s],'unknown property \"'+s+'\"')])}return a}function on(t){var e=t.value,r=t.key,n=wr(e);return\"string\"!==n?[new Dt(r,e,\"string expected, \"+n+\" found\")]:[]}var sn={\"*\":function(){return[]},array:Br,boolean:function(t){var e=t.value,r=t.key,n=wr(e);return\"boolean\"!==n?[new Dt(r,e,\"boolean expected, \"+n+\" found\")]:[]},number:Nr,color:function(t){var e=t.key,r=t.value,n=wr(r);return\"string\"!==n?[new Dt(e,r,\"color expected, \"+n+\" found\")]:null===re(r)?[new Dt(e,r,'color expected, \"'+r+'\" found')]:[]},constants:Rt,enum:Vr,filter:$r,function:jr,layer:rn,object:Fr,source:nn,light:an,string:on,formatted:function(t){return 0===on(t).length?[]:Ur(t)}};function ln(t){var e=t.value,r=t.valueSpec,n=t.styleSpec;return r.expression&&kr(Nt(e))?jr(t):r.expression&&Pr(jt(e))?Ur(t):r.type&&sn[r.type]?sn[r.type](t):Fr(Ft({},t,{valueSpec:r.type?n[r.type]:r}))}function cn(t){var e=t.value,r=t.key,n=on(t);return n.length?n:(-1===e.indexOf(\"{fontstack}\")&&n.push(new Dt(r,e,'\"glyphs\" url must include a \"{fontstack}\" token')),-1===e.indexOf(\"{range}\")&&n.push(new Dt(r,e,'\"glyphs\" url must include a \"{range}\" token')),n)}function un(t,e){e=e||It;var r=[];return r=r.concat(ln({key:\"\",value:t,valueSpec:e.$root,styleSpec:e,style:t,objectElementValidators:{glyphs:cn,\"*\":function(){return[]}}})),t.constants&&(r=r.concat(Rt({key:\"constants\",value:t.constants,style:t,styleSpec:e}))),hn(r)}function hn(t){return[].concat(t).sort(function(t,e){return t.line-e.line})}function fn(t){return function(){for(var e=[],r=arguments.length;r--;)e[r]=arguments[r];return hn(t.apply(this,e))}}un.source=fn(nn),un.light=fn(an),un.layer=fn(rn),un.filter=fn($r),un.paintProperty=fn(tn),un.layoutProperty=fn(en);var pn=un,dn=pn.light,gn=pn.paintProperty,vn=pn.layoutProperty;function mn(t,e){var r=!1;if(e&&e.length)for(var n=0,i=e;n<i.length;n+=1){var a=i[n];t.fire(new Ot(new Error(a.message))),r=!0}return r}var yn=bn,xn=3;function bn(t,e,r){var n=this.cells=[];if(t instanceof ArrayBuffer){this.arrayBuffer=t;var i=new Int32Array(this.arrayBuffer);t=i[0],e=i[1],r=i[2],this.d=e+2*r;for(var a=0;a<this.d*this.d;a++){var o=i[xn+a],s=i[xn+a+1];n.push(o===s?null:i.subarray(o,s))}var l=i[xn+n.length],c=i[xn+n.length+1];this.keys=i.subarray(l,c),this.bboxes=i.subarray(c),this.insert=this._insertReadonly}else{this.d=e+2*r;for(var u=0;u<this.d*this.d;u++)n.push([]);this.keys=[],this.bboxes=[]}this.n=e,this.extent=t,this.padding=r,this.scale=e/t,this.uid=0;var h=r/e*t;this.min=-h,this.max=t+h}bn.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertCell,this.uid++),this.keys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},bn.prototype._insertReadonly=function(){throw\"Cannot insert into a GridIndex created from an ArrayBuffer.\"},bn.prototype._insertCell=function(t,e,r,n,i,a){this.cells[i].push(a)},bn.prototype.query=function(t,e,r,n,i){var a=this.min,o=this.max;if(t<=a&&e<=a&&o<=r&&o<=n&&!i)return Array.prototype.slice.call(this.keys);var s=[];return this._forEachCell(t,e,r,n,this._queryCell,s,{},i),s},bn.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=this.cells[i];if(null!==l)for(var c=this.keys,u=this.bboxes,h=0;h<l.length;h++){var f=l[h];if(void 0===o[f]){var p=4*f;(s?s(u[p+0],u[p+1],u[p+2],u[p+3]):t<=u[p+2]&&e<=u[p+3]&&r>=u[p+0]&&n>=u[p+1])?(o[f]=!0,a.push(c[f])):o[f]=!1}}},bn.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToCellCoord(t),c=this._convertToCellCoord(e),u=this._convertToCellCoord(r),h=this._convertToCellCoord(n),f=l;f<=u;f++)for(var p=c;p<=h;p++){var d=this.d*p+f;if((!s||s(this._convertFromCellCoord(f),this._convertFromCellCoord(p),this._convertFromCellCoord(f+1),this._convertFromCellCoord(p+1)))&&i.call(this,t,e,r,n,d,a,o,s))return}},bn.prototype._convertFromCellCoord=function(t){return(t-this.padding)/this.scale},bn.prototype._convertToCellCoord=function(t){return Math.max(0,Math.min(this.d-1,Math.floor(t*this.scale)+this.padding))},bn.prototype.toArrayBuffer=function(){if(this.arrayBuffer)return this.arrayBuffer;for(var t=this.cells,e=xn+this.cells.length+1+1,r=0,n=0;n<this.cells.length;n++)r+=this.cells[n].length;var i=new Int32Array(e+r+this.keys.length+this.bboxes.length);i[0]=this.extent,i[1]=this.n,i[2]=this.padding;for(var a=e,o=0;o<t.length;o++){var s=t[o];i[xn+o]=a,i.set(s,a),a+=s.length}return i[xn+t.length]=a,i.set(this.keys,a),a+=this.keys.length,i[xn+t.length+1]=a,i.set(this.bboxes,a),a+=this.bboxes.length,i.buffer};var _n=self.ImageData,wn={};function kn(t,e,r){void 0===r&&(r={}),Object.defineProperty(e,\"_classRegistryKey\",{value:t,writeable:!1}),wn[t]={klass:e,omit:r.omit||[],shallow:r.shallow||[]}}for(var Tn in kn(\"Object\",Object),yn.serialize=function(t,e){var r=t.toArrayBuffer();return e&&e.push(r),{buffer:r}},yn.deserialize=function(t){return new yn(t.buffer)},kn(\"Grid\",yn),kn(\"Color\",ne),kn(\"Error\",Error),kn(\"StylePropertyFunction\",Rr),kn(\"StyleExpression\",Lr,{omit:[\"_evaluator\"]}),kn(\"ZoomDependentExpression\",Ir),kn(\"ZoomConstantExpression\",zr),kn(\"CompoundExpression\",xe,{omit:[\"_evaluate\"]}),fr)fr[Tn]._classRegistryKey||kn(\"Expression_\"+Tn,fr[Tn]);function An(t,e){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp)return t;if(t instanceof ArrayBuffer)return e&&e.push(t),t;if(ArrayBuffer.isView(t)){var r=t;return e&&e.push(r.buffer),r}if(t instanceof _n)return e&&e.push(t.data.buffer),t;if(Array.isArray(t)){for(var n=[],i=0,a=t;i<a.length;i+=1){var o=a[i];n.push(An(o,e))}return n}if(\"object\"==typeof t){var s=t.constructor,l=s._classRegistryKey;if(!l)throw new Error(\"can't serialize object of unregistered class\");var c=s.serialize?s.serialize(t,e):{};if(!s.serialize){for(var u in t)if(t.hasOwnProperty(u)&&!(wn[l].omit.indexOf(u)>=0)){var h=t[u];c[u]=wn[l].shallow.indexOf(u)>=0?h:An(h,e)}t instanceof Error&&(c.message=t.message)}if(c.$name)throw new Error(\"$name property is reserved for worker serialization logic.\");return\"Object\"!==l&&(c.$name=l),c}throw new Error(\"can't serialize object of type \"+typeof t)}function Mn(t){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp||t instanceof ArrayBuffer||ArrayBuffer.isView(t)||t instanceof _n)return t;if(Array.isArray(t))return t.map(Mn);if(\"object\"==typeof t){var e=t.$name||\"Object\",r=wn[e].klass;if(!r)throw new Error(\"can't deserialize unregistered class \"+e);if(r.deserialize)return r.deserialize(t);for(var n=Object.create(r.prototype),i=0,a=Object.keys(t);i<a.length;i+=1){var o=a[i];if(\"$name\"!==o){var s=t[o];n[o]=wn[e].shallow.indexOf(o)>=0?s:Mn(s)}}return n}throw new Error(\"can't deserialize object of type \"+typeof t)}var Sn=function(){this.first=!0};Sn.prototype.update=function(t,e){var r=Math.floor(t);return this.first?(this.first=!1,this.lastIntegerZoom=r,this.lastIntegerZoomTime=0,this.lastZoom=t,this.lastFloorZoom=r,!0):(this.lastFloorZoom>r?(this.lastIntegerZoom=r+1,this.lastIntegerZoomTime=e):this.lastFloorZoom<r&&(this.lastIntegerZoom=r,this.lastIntegerZoomTime=e),t!==this.lastZoom&&(this.lastZoom=t,this.lastFloorZoom=r,!0))};var En={\"Latin-1 Supplement\":function(t){return t>=128&&t<=255},Arabic:function(t){return t>=1536&&t<=1791},\"Arabic Supplement\":function(t){return t>=1872&&t<=1919},\"Arabic Extended-A\":function(t){return t>=2208&&t<=2303},\"Hangul Jamo\":function(t){return t>=4352&&t<=4607},\"Unified Canadian Aboriginal Syllabics\":function(t){return t>=5120&&t<=5759},Khmer:function(t){return t>=6016&&t<=6143},\"Unified Canadian Aboriginal Syllabics Extended\":function(t){return t>=6320&&t<=6399},\"General Punctuation\":function(t){return t>=8192&&t<=8303},\"Letterlike Symbols\":function(t){return t>=8448&&t<=8527},\"Number Forms\":function(t){return t>=8528&&t<=8591},\"Miscellaneous Technical\":function(t){return t>=8960&&t<=9215},\"Control Pictures\":function(t){return t>=9216&&t<=9279},\"Optical Character Recognition\":function(t){return t>=9280&&t<=9311},\"Enclosed Alphanumerics\":function(t){return t>=9312&&t<=9471},\"Geometric Shapes\":function(t){return t>=9632&&t<=9727},\"Miscellaneous Symbols\":function(t){return t>=9728&&t<=9983},\"Miscellaneous Symbols and Arrows\":function(t){return t>=11008&&t<=11263},\"CJK Radicals Supplement\":function(t){return t>=11904&&t<=12031},\"Kangxi Radicals\":function(t){return t>=12032&&t<=12255},\"Ideographic Description Characters\":function(t){return t>=12272&&t<=12287},\"CJK Symbols and Punctuation\":function(t){return t>=12288&&t<=12351},Hiragana:function(t){return t>=12352&&t<=12447},Katakana:function(t){return t>=12448&&t<=12543},Bopomofo:function(t){return t>=12544&&t<=12591},\"Hangul Compatibility Jamo\":function(t){return t>=12592&&t<=12687},Kanbun:function(t){return t>=12688&&t<=12703},\"Bopomofo Extended\":function(t){return t>=12704&&t<=12735},\"CJK Strokes\":function(t){return t>=12736&&t<=12783},\"Katakana Phonetic Extensions\":function(t){return t>=12784&&t<=12799},\"Enclosed CJK Letters and Months\":function(t){return t>=12800&&t<=13055},\"CJK Compatibility\":function(t){return t>=13056&&t<=13311},\"CJK Unified Ideographs Extension A\":function(t){return t>=13312&&t<=19903},\"Yijing Hexagram Symbols\":function(t){return t>=19904&&t<=19967},\"CJK Unified Ideographs\":function(t){return t>=19968&&t<=40959},\"Yi Syllables\":function(t){return t>=40960&&t<=42127},\"Yi Radicals\":function(t){return t>=42128&&t<=42191},\"Hangul Jamo Extended-A\":function(t){return t>=43360&&t<=43391},\"Hangul Syllables\":function(t){return t>=44032&&t<=55215},\"Hangul Jamo Extended-B\":function(t){return t>=55216&&t<=55295},\"Private Use Area\":function(t){return t>=57344&&t<=63743},\"CJK Compatibility Ideographs\":function(t){return t>=63744&&t<=64255},\"Arabic Presentation Forms-A\":function(t){return t>=64336&&t<=65023},\"Vertical Forms\":function(t){return t>=65040&&t<=65055},\"CJK Compatibility Forms\":function(t){return t>=65072&&t<=65103},\"Small Form Variants\":function(t){return t>=65104&&t<=65135},\"Arabic Presentation Forms-B\":function(t){return t>=65136&&t<=65279},\"Halfwidth and Fullwidth Forms\":function(t){return t>=65280&&t<=65519}};function Cn(t){for(var e=0,r=t;e<r.length;e+=1)if(On(r[e].charCodeAt(0)))return!0;return!1}function Ln(t){for(var e=0,r=t;e<r.length;e+=1)if(!Pn(r[e].charCodeAt(0)))return!1;return!0}function Pn(t){return!(En.Arabic(t)||En[\"Arabic Supplement\"](t)||En[\"Arabic Extended-A\"](t)||En[\"Arabic Presentation Forms-A\"](t)||En[\"Arabic Presentation Forms-B\"](t))}function On(t){return!!(746===t||747===t||!(t<4352)&&(En[\"Bopomofo Extended\"](t)||En.Bopomofo(t)||En[\"CJK Compatibility Forms\"](t)&&!(t>=65097&&t<=65103)||En[\"CJK Compatibility Ideographs\"](t)||En[\"CJK Compatibility\"](t)||En[\"CJK Radicals Supplement\"](t)||En[\"CJK Strokes\"](t)||!(!En[\"CJK Symbols and Punctuation\"](t)||t>=12296&&t<=12305||t>=12308&&t<=12319||12336===t)||En[\"CJK Unified Ideographs Extension A\"](t)||En[\"CJK Unified Ideographs\"](t)||En[\"Enclosed CJK Letters and Months\"](t)||En[\"Hangul Compatibility Jamo\"](t)||En[\"Hangul Jamo Extended-A\"](t)||En[\"Hangul Jamo Extended-B\"](t)||En[\"Hangul Jamo\"](t)||En[\"Hangul Syllables\"](t)||En.Hiragana(t)||En[\"Ideographic Description Characters\"](t)||En.Kanbun(t)||En[\"Kangxi Radicals\"](t)||En[\"Katakana Phonetic Extensions\"](t)||En.Katakana(t)&&12540!==t||!(!En[\"Halfwidth and Fullwidth Forms\"](t)||65288===t||65289===t||65293===t||t>=65306&&t<=65310||65339===t||65341===t||65343===t||t>=65371&&t<=65503||65507===t||t>=65512&&t<=65519)||!(!En[\"Small Form Variants\"](t)||t>=65112&&t<=65118||t>=65123&&t<=65126)||En[\"Unified Canadian Aboriginal Syllabics\"](t)||En[\"Unified Canadian Aboriginal Syllabics Extended\"](t)||En[\"Vertical Forms\"](t)||En[\"Yijing Hexagram Symbols\"](t)||En[\"Yi Syllables\"](t)||En[\"Yi Radicals\"](t)))}function zn(t){return!(On(t)||function(t){return!!(En[\"Latin-1 Supplement\"](t)&&(167===t||169===t||174===t||177===t||188===t||189===t||190===t||215===t||247===t)||En[\"General Punctuation\"](t)&&(8214===t||8224===t||8225===t||8240===t||8241===t||8251===t||8252===t||8258===t||8263===t||8264===t||8265===t||8273===t)||En[\"Letterlike Symbols\"](t)||En[\"Number Forms\"](t)||En[\"Miscellaneous Technical\"](t)&&(t>=8960&&t<=8967||t>=8972&&t<=8991||t>=8996&&t<=9e3||9003===t||t>=9085&&t<=9114||t>=9150&&t<=9165||9167===t||t>=9169&&t<=9179||t>=9186&&t<=9215)||En[\"Control Pictures\"](t)&&9251!==t||En[\"Optical Character Recognition\"](t)||En[\"Enclosed Alphanumerics\"](t)||En[\"Geometric Shapes\"](t)||En[\"Miscellaneous Symbols\"](t)&&!(t>=9754&&t<=9759)||En[\"Miscellaneous Symbols and Arrows\"](t)&&(t>=11026&&t<=11055||t>=11088&&t<=11097||t>=11192&&t<=11243)||En[\"CJK Symbols and Punctuation\"](t)||En.Katakana(t)||En[\"Private Use Area\"](t)||En[\"CJK Compatibility Forms\"](t)||En[\"Small Form Variants\"](t)||En[\"Halfwidth and Fullwidth Forms\"](t)||8734===t||8756===t||8757===t||t>=9984&&t<=10087||t>=10102&&t<=10131||65532===t||65533===t)}(t))}function In(t,e){return!(!e&&(t>=1424&&t<=2303||En[\"Arabic Presentation Forms-A\"](t)||En[\"Arabic Presentation Forms-B\"](t))||t>=2304&&t<=3583||t>=3840&&t<=4255||En.Khmer(t))}var Dn,Rn=!1,Fn=null,Bn=!1,Nn=new zt,jn={applyArabicShaping:null,processBidirectionalText:null,processStyledBidirectionalText:null,isLoaded:function(){return Bn||null!=jn.applyArabicShaping}},Un=function(t,e){this.zoom=t,e?(this.now=e.now,this.fadeDuration=e.fadeDuration,this.zoomHistory=e.zoomHistory,this.transition=e.transition):(this.now=0,this.fadeDuration=0,this.zoomHistory=new Sn,this.transition={})};Un.prototype.isSupportedScript=function(t){return function(t,e){for(var r=0,n=t;r<n.length;r+=1)if(!In(n[r].charCodeAt(0),e))return!1;return!0}(t,jn.isLoaded())},Un.prototype.crossFadingFactor=function(){return 0===this.fadeDuration?1:Math.min((this.now-this.zoomHistory.lastIntegerZoomTime)/this.fadeDuration,1)},Un.prototype.getCrossfadeParameters=function(){var t=this.zoom,e=t-Math.floor(t),r=this.crossFadingFactor();return t>this.zoomHistory.lastIntegerZoom?{fromScale:2,toScale:1,t:e+(1-e)*r}:{fromScale:.5,toScale:1,t:1-(1-r)*e}};var Vn=function(t,e){this.property=t,this.value=e,this.expression=function(t,e){if(kr(t))return new Rr(t,e);if(Pr(t)){var r=Dr(t,e);if(\"error\"===r.result)throw new Error(r.value.map(function(t){return t.key+\": \"+t.message}).join(\", \"));return r.value}var n=t;return\"string\"==typeof t&&\"color\"===e.type&&(n=ne.parse(t)),{kind:\"constant\",evaluate:function(){return n}}}(void 0===e?t.specification.default:e,t.specification)};Vn.prototype.isDataDriven=function(){return\"source\"===this.expression.kind||\"composite\"===this.expression.kind},Vn.prototype.possiblyEvaluate=function(t){return this.property.possiblyEvaluate(this,t)};var qn=function(t){this.property=t,this.value=new Vn(t,void 0)};qn.prototype.transitioned=function(t,e){return new Gn(this.property,this.value,e,h({},t.transition,this.transition),t.now)},qn.prototype.untransitioned=function(){return new Gn(this.property,this.value,null,{},0)};var Hn=function(t){this._properties=t,this._values=Object.create(t.defaultTransitionablePropertyValues)};Hn.prototype.getValue=function(t){return b(this._values[t].value.value)},Hn.prototype.setValue=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new qn(this._values[t].property)),this._values[t].value=new Vn(this._values[t].property,null===e?void 0:b(e))},Hn.prototype.getTransition=function(t){return b(this._values[t].transition)},Hn.prototype.setTransition=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new qn(this._values[t].property)),this._values[t].transition=b(e)||void 0},Hn.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i);var a=this.getTransition(n);void 0!==a&&(t[n+\"-transition\"]=a)}return t},Hn.prototype.transitioned=function(t,e){for(var r=new Yn(this._properties),n=0,i=Object.keys(this._values);n<i.length;n+=1){var a=i[n];r._values[a]=this._values[a].transitioned(t,e._values[a])}return r},Hn.prototype.untransitioned=function(){for(var t=new Yn(this._properties),e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e];t._values[n]=this._values[n].untransitioned()}return t};var Gn=function(t,e,r,n,i){this.property=t,this.value=e,this.begin=i+n.delay||0,this.end=this.begin+n.duration||0,t.specification.transition&&(n.delay||n.duration)&&(this.prior=r)};Gn.prototype.possiblyEvaluate=function(t){var e=t.now||0,r=this.value.possiblyEvaluate(t),n=this.prior;if(n){if(e>this.end)return this.prior=null,r;if(this.value.isDataDriven())return this.prior=null,r;if(e<this.begin)return n.possiblyEvaluate(t);var i=(e-this.begin)/(this.end-this.begin);return this.property.interpolate(n.possiblyEvaluate(t),r,function(t){if(i<=0)return 0;if(i>=1)return 1;var e=i*i,r=e*i;return 4*(i<.5?r:3*(i-e)+r-.75)}())}return r};var Yn=function(t){this._properties=t,this._values=Object.create(t.defaultTransitioningPropertyValues)};Yn.prototype.possiblyEvaluate=function(t){for(var e=new Zn(this._properties),r=0,n=Object.keys(this._values);r<n.length;r+=1){var i=n[r];e._values[i]=this._values[i].possiblyEvaluate(t)}return e},Yn.prototype.hasTransition=function(){for(var t=0,e=Object.keys(this._values);t<e.length;t+=1){var r=e[t];if(this._values[r].prior)return!0}return!1};var Wn=function(t){this._properties=t,this._values=Object.create(t.defaultPropertyValues)};Wn.prototype.getValue=function(t){return b(this._values[t].value)},Wn.prototype.setValue=function(t,e){this._values[t]=new Vn(this._values[t].property,null===e?void 0:b(e))},Wn.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i)}return t},Wn.prototype.possiblyEvaluate=function(t){for(var e=new Zn(this._properties),r=0,n=Object.keys(this._values);r<n.length;r+=1){var i=n[r];e._values[i]=this._values[i].possiblyEvaluate(t)}return e};var Xn=function(t,e,r){this.property=t,this.value=e,this.parameters=r};Xn.prototype.isConstant=function(){return\"constant\"===this.value.kind},Xn.prototype.constantOr=function(t){return\"constant\"===this.value.kind?this.value.value:t},Xn.prototype.evaluate=function(t,e){return this.property.evaluate(this.value,this.parameters,t,e)};var Zn=function(t){this._properties=t,this._values=Object.create(t.defaultPossiblyEvaluatedValues)};Zn.prototype.get=function(t){return this._values[t]};var Jn=function(t){this.specification=t};Jn.prototype.possiblyEvaluate=function(t,e){return t.expression.evaluate(e)},Jn.prototype.interpolate=function(t,e,r){var n=Ce[this.specification.type];return n?n(t,e,r):t};var Kn=function(t){this.specification=t};Kn.prototype.possiblyEvaluate=function(t,e){return\"constant\"===t.expression.kind||\"camera\"===t.expression.kind?new Xn(this,{kind:\"constant\",value:t.expression.evaluate(e)},e):new Xn(this,t.expression,e)},Kn.prototype.interpolate=function(t,e,r){if(\"constant\"!==t.value.kind||\"constant\"!==e.value.kind)return t;if(void 0===t.value.value||void 0===e.value.value)return new Xn(this,{kind:\"constant\",value:void 0},t.parameters);var n=Ce[this.specification.type];return n?new Xn(this,{kind:\"constant\",value:n(t.value.value,e.value.value,r)},t.parameters):t},Kn.prototype.evaluate=function(t,e,r,n){return\"constant\"===t.kind?t.value:t.evaluate(e,r,n)};var $n=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(t,e){if(void 0===t.value)return new Xn(this,{kind:\"constant\",value:void 0},e);if(\"constant\"===t.expression.kind){var r=t.expression.evaluate(e),n=this._calculate(r,r,r,e);return new Xn(this,{kind:\"constant\",value:n},e)}if(\"camera\"===t.expression.kind){var i=this._calculate(t.expression.evaluate({zoom:e.zoom-1}),t.expression.evaluate({zoom:e.zoom}),t.expression.evaluate({zoom:e.zoom+1}),e);return new Xn(this,{kind:\"constant\",value:i},e)}return new Xn(this,t.expression,e)},e.prototype.evaluate=function(t,e,r,n){if(\"source\"===t.kind){var i=t.evaluate(e,r,n);return this._calculate(i,i,i,e)}return\"composite\"===t.kind?this._calculate(t.evaluate({zoom:Math.floor(e.zoom)-1},r,n),t.evaluate({zoom:Math.floor(e.zoom)},r,n),t.evaluate({zoom:Math.floor(e.zoom)+1},r,n),e):t.value},e.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},e.prototype.interpolate=function(t){return t},e}(Kn),Qn=function(t){this.specification=t};Qn.prototype.possiblyEvaluate=function(t,e){if(void 0!==t.value){if(\"constant\"===t.expression.kind){var r=t.expression.evaluate(e);return this._calculate(r,r,r,e)}return this._calculate(t.expression.evaluate(new Un(Math.floor(e.zoom-1),e)),t.expression.evaluate(new Un(Math.floor(e.zoom),e)),t.expression.evaluate(new Un(Math.floor(e.zoom+1),e)),e)}},Qn.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},Qn.prototype.interpolate=function(t){return t};var ti=function(t){this.specification=t};ti.prototype.possiblyEvaluate=function(t,e){return!!t.expression.evaluate(e)},ti.prototype.interpolate=function(){return!1};var ei=function(t){for(var e in this.properties=t,this.defaultPropertyValues={},this.defaultTransitionablePropertyValues={},this.defaultTransitioningPropertyValues={},this.defaultPossiblyEvaluatedValues={},t){var r=t[e],n=this.defaultPropertyValues[e]=new Vn(r,void 0),i=this.defaultTransitionablePropertyValues[e]=new qn(r);this.defaultTransitioningPropertyValues[e]=i.untransitioned(),this.defaultPossiblyEvaluatedValues[e]=n.possiblyEvaluate({})}};kn(\"DataDrivenProperty\",Kn),kn(\"DataConstantProperty\",Jn),kn(\"CrossFadedDataDrivenProperty\",$n),kn(\"CrossFadedProperty\",Qn),kn(\"ColorRampProperty\",ti);var ri=function(t){function e(e,r){if(t.call(this),this.id=e.id,this.type=e.type,this._featureFilter=function(){return!0},\"custom\"!==e.type&&(e=e,this.metadata=e.metadata,this.minzoom=e.minzoom,this.maxzoom=e.maxzoom,\"background\"!==e.type&&(this.source=e.source,this.sourceLayer=e[\"source-layer\"],this.filter=e.filter),r.layout&&(this._unevaluatedLayout=new Wn(r.layout)),r.paint)){for(var n in this._transitionablePaint=new Hn(r.paint),e.paint)this.setPaintProperty(n,e.paint[n],{validate:!1});for(var i in e.layout)this.setLayoutProperty(i,e.layout[i],{validate:!1});this._transitioningPaint=this._transitionablePaint.untransitioned()}}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getCrossfadeParameters=function(){return this._crossfadeParameters},e.prototype.getLayoutProperty=function(t){return\"visibility\"===t?this.visibility:this._unevaluatedLayout.getValue(t)},e.prototype.setLayoutProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e){var n=\"layers.\"+this.id+\".layout.\"+t;if(this._validate(vn,n,t,e,r))return}\"visibility\"!==t?this._unevaluatedLayout.setValue(t,e):this.visibility=e},e.prototype.getPaintProperty=function(t){return m(t,\"-transition\")?this._transitionablePaint.getTransition(t.slice(0,-\"-transition\".length)):this._transitionablePaint.getValue(t)},e.prototype.setPaintProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e){var n=\"layers.\"+this.id+\".paint.\"+t;if(this._validate(gn,n,t,e,r))return!1}if(m(t,\"-transition\"))return this._transitionablePaint.setTransition(t.slice(0,-\"-transition\".length),e||void 0),!1;var i=this._transitionablePaint._values[t],a=\"cross-faded-data-driven\"===i.property.specification[\"property-type\"],o=i.value.isDataDriven();return this._transitionablePaint.setValue(t,e),this._handleSpecialPaintPropertyUpdate(t),this._transitionablePaint._values[t].value.isDataDriven()||o||a},e.prototype._handleSpecialPaintPropertyUpdate=function(t){},e.prototype.isHidden=function(t){return!!(this.minzoom&&t<this.minzoom)||!!(this.maxzoom&&t>=this.maxzoom)||\"none\"===this.visibility},e.prototype.updateTransitions=function(t){this._transitioningPaint=this._transitionablePaint.transitioned(t,this._transitioningPaint)},e.prototype.hasTransition=function(){return this._transitioningPaint.hasTransition()},e.prototype.recalculate=function(t){t.getCrossfadeParameters&&(this._crossfadeParameters=t.getCrossfadeParameters()),this._unevaluatedLayout&&(this.layout=this._unevaluatedLayout.possiblyEvaluate(t)),this.paint=this._transitioningPaint.possiblyEvaluate(t)},e.prototype.serialize=function(){var t={id:this.id,type:this.type,source:this.source,\"source-layer\":this.sourceLayer,metadata:this.metadata,minzoom:this.minzoom,maxzoom:this.maxzoom,filter:this.filter,layout:this._unevaluatedLayout&&this._unevaluatedLayout.serialize(),paint:this._transitionablePaint&&this._transitionablePaint.serialize()};return this.visibility&&(t.layout=t.layout||{},t.layout.visibility=this.visibility),x(t,function(t,e){return!(void 0===t||\"layout\"===e&&!Object.keys(t).length||\"paint\"===e&&!Object.keys(t).length)})},e.prototype._validate=function(t,e,r,n,i){return void 0===i&&(i={}),(!i||!1!==i.validate)&&mn(this,t.call(pn,{key:e,layerType:this.type,objectKey:r,value:n,styleSpec:It,style:{glyphs:!0,sprite:!0}}))},e.prototype.is3D=function(){return!1},e.prototype.isTileClipped=function(){return!1},e.prototype.hasOffscreenPass=function(){return!1},e.prototype.resize=function(){},e.prototype.isStateDependent=function(){for(var t in this.paint._values){var e=this.paint.get(t);if(e instanceof Xn&&xr(e.property.specification)&&(\"source\"===e.value.kind||\"composite\"===e.value.kind)&&e.value.isStateDependent)return!0}return!1},e}(zt),ni={Int8:Int8Array,Uint8:Uint8Array,Int16:Int16Array,Uint16:Uint16Array,Int32:Int32Array,Uint32:Uint32Array,Float32:Float32Array},ii=function(t,e){this._structArray=t,this._pos1=e*this.size,this._pos2=this._pos1/2,this._pos4=this._pos1/4,this._pos8=this._pos1/8},ai=function(){this.isTransferred=!1,this.capacity=-1,this.resize(0)};function oi(t,e){void 0===e&&(e=1);var r=0,n=0;return{members:t.map(function(t){var i,a=(i=t.type,ni[i].BYTES_PER_ELEMENT),o=r=si(r,Math.max(e,a)),s=t.components||1;return n=Math.max(n,a),r+=a*s,{name:t.name,type:t.type,components:s,offset:o}}),size:si(r,Math.max(n,e)),alignment:e}}function si(t,e){return Math.ceil(t/e)*e}ai.serialize=function(t,e){return t._trim(),e&&(t.isTransferred=!0,e.push(t.arrayBuffer)),{length:t.length,arrayBuffer:t.arrayBuffer}},ai.deserialize=function(t){var e=Object.create(this.prototype);return e.arrayBuffer=t.arrayBuffer,e.length=t.length,e.capacity=t.arrayBuffer.byteLength/e.bytesPerElement,e._refreshViews(),e},ai.prototype._trim=function(){this.length!==this.capacity&&(this.capacity=this.length,this.arrayBuffer=this.arrayBuffer.slice(0,this.length*this.bytesPerElement),this._refreshViews())},ai.prototype.clear=function(){this.length=0},ai.prototype.resize=function(t){this.reserve(t),this.length=t},ai.prototype.reserve=function(t){if(t>this.capacity){this.capacity=Math.max(t,Math.floor(5*this.capacity),128),this.arrayBuffer=new ArrayBuffer(this.capacity*this.bytesPerElement);var e=this.uint8;this._refreshViews(),e&&this.uint8.set(e)}},ai.prototype._refreshViews=function(){throw new Error(\"_refreshViews() must be implemented by each concrete StructArray layout\")};var li=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.int16[n+0]=e,this.int16[n+1]=r,t},e}(ai);li.prototype.bytesPerElement=4,kn(\"StructArrayLayout2i4\",li);var ci=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.int16[a+0]=e,this.int16[a+1]=r,this.int16[a+2]=n,this.int16[a+3]=i,t},e}(ai);ci.prototype.bytesPerElement=8,kn(\"StructArrayLayout4i8\",ci);var ui=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(ai);ui.prototype.bytesPerElement=12,kn(\"StructArrayLayout2i4i12\",ui);var hi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=4*t,l=8*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.uint8[l+4]=n,this.uint8[l+5]=i,this.uint8[l+6]=a,this.uint8[l+7]=o,t},e}(ai);hi.prototype.bytesPerElement=8,kn(\"StructArrayLayout2i4ub8\",hi);var fi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s){var l=this.length;return this.resize(l+1),this.emplace(l,t,e,r,n,i,a,o,s)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l){var c=8*t;return this.uint16[c+0]=e,this.uint16[c+1]=r,this.uint16[c+2]=n,this.uint16[c+3]=i,this.uint16[c+4]=a,this.uint16[c+5]=o,this.uint16[c+6]=s,this.uint16[c+7]=l,t},e}(ai);fi.prototype.bytesPerElement=16,kn(\"StructArrayLayout8ui16\",fi);var pi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s){var l=this.length;return this.resize(l+1),this.emplace(l,t,e,r,n,i,a,o,s)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l){var c=8*t;return this.int16[c+0]=e,this.int16[c+1]=r,this.int16[c+2]=n,this.int16[c+3]=i,this.uint16[c+4]=a,this.uint16[c+5]=o,this.uint16[c+6]=s,this.uint16[c+7]=l,t},e}(ai);pi.prototype.bytesPerElement=16,kn(\"StructArrayLayout4i4ui16\",pi);var di=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.float32[i+0]=e,this.float32[i+1]=r,this.float32[i+2]=n,t},e}(ai);di.prototype.bytesPerElement=12,kn(\"StructArrayLayout3f12\",di);var gi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.uint32[r+0]=e,t},e}(ai);gi.prototype.bytesPerElement=4,kn(\"StructArrayLayout1ul4\",gi);var vi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u){var h=this.length;return this.resize(h+1),this.emplace(h,t,e,r,n,i,a,o,s,l,c,u)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h){var f=12*t,p=6*t;return this.int16[f+0]=e,this.int16[f+1]=r,this.int16[f+2]=n,this.int16[f+3]=i,this.int16[f+4]=a,this.int16[f+5]=o,this.uint32[p+3]=s,this.uint16[f+8]=l,this.uint16[f+9]=c,this.int16[f+10]=u,this.int16[f+11]=h,t},e}(ai);vi.prototype.bytesPerElement=24,kn(\"StructArrayLayout6i1ul2ui2i24\",vi);var mi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(ai);mi.prototype.bytesPerElement=12,kn(\"StructArrayLayout2i2i2i12\",mi);var yi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=12*t,o=3*t;return this.uint8[a+0]=e,this.uint8[a+1]=r,this.float32[o+1]=n,this.float32[o+2]=i,t},e}(ai);yi.prototype.bytesPerElement=12,kn(\"StructArrayLayout2ub2f12\",yi);var xi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d){var g=this.length;return this.resize(g+1),this.emplace(g,t,e,r,n,i,a,o,s,l,c,u,h,f,p,d)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g){var v=22*t,m=11*t,y=44*t;return this.int16[v+0]=e,this.int16[v+1]=r,this.uint16[v+2]=n,this.uint16[v+3]=i,this.uint32[m+2]=a,this.uint32[m+3]=o,this.uint32[m+4]=s,this.uint16[v+10]=l,this.uint16[v+11]=c,this.uint16[v+12]=u,this.float32[m+7]=h,this.float32[m+8]=f,this.uint8[y+36]=p,this.uint8[y+37]=d,this.uint32[m+10]=g,t},e}(ai);xi.prototype.bytesPerElement=44,kn(\"StructArrayLayout2i2ui3ul3ui2f2ub1ul44\",xi);var bi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m){var y=this.length;return this.resize(y+1),this.emplace(y,t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m,y){var x=22*t,b=11*t;return this.int16[x+0]=e,this.int16[x+1]=r,this.int16[x+2]=n,this.int16[x+3]=i,this.int16[x+4]=a,this.int16[x+5]=o,this.uint16[x+6]=s,this.uint16[x+7]=l,this.uint16[x+8]=c,this.uint16[x+9]=u,this.uint16[x+10]=h,this.uint16[x+11]=f,this.uint16[x+12]=p,this.uint16[x+13]=d,this.uint16[x+14]=g,this.uint32[b+8]=v,this.float32[b+9]=m,this.float32[b+10]=y,t},e}(ai);bi.prototype.bytesPerElement=44,kn(\"StructArrayLayout6i9ui1ul2f44\",bi);var _i=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.float32[r+0]=e,t},e}(ai);_i.prototype.bytesPerElement=4,kn(\"StructArrayLayout1f4\",_i);var wi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.int16[i+0]=e,this.int16[i+1]=r,this.int16[i+2]=n,t},e}(ai);wi.prototype.bytesPerElement=6,kn(\"StructArrayLayout3i6\",wi);var ki=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=2*t,a=4*t;return this.uint32[i+0]=e,this.uint16[a+2]=r,this.uint16[a+3]=n,t},e}(ai);ki.prototype.bytesPerElement=8,kn(\"StructArrayLayout1ul2ui8\",ki);var Ti=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.uint16[i+0]=e,this.uint16[i+1]=r,this.uint16[i+2]=n,t},e}(ai);Ti.prototype.bytesPerElement=6,kn(\"StructArrayLayout3ui6\",Ti);var Ai=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.uint16[n+0]=e,this.uint16[n+1]=r,t},e}(ai);Ai.prototype.bytesPerElement=4,kn(\"StructArrayLayout2ui4\",Ai);var Mi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.uint16[r+0]=e,t},e}(ai);Mi.prototype.bytesPerElement=2,kn(\"StructArrayLayout1ui2\",Mi);var Si=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.float32[n+0]=e,this.float32[n+1]=r,t},e}(ai);Si.prototype.bytesPerElement=8,kn(\"StructArrayLayout2f8\",Si);var Ei=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.float32[a+0]=e,this.float32[a+1]=r,this.float32[a+2]=n,this.float32[a+3]=i,t},e}(ai);Ei.prototype.bytesPerElement=16,kn(\"StructArrayLayout4f16\",Ei);var Ci=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorPointX:{configurable:!0},anchorPointY:{configurable:!0},x1:{configurable:!0},y1:{configurable:!0},x2:{configurable:!0},y2:{configurable:!0},featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0},radius:{configurable:!0},signedDistanceFromAnchor:{configurable:!0},anchorPoint:{configurable:!0}};return r.anchorPointX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorPointX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorPointY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorPointY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.x1.get=function(){return this._structArray.int16[this._pos2+2]},r.x1.set=function(t){this._structArray.int16[this._pos2+2]=t},r.y1.get=function(){return this._structArray.int16[this._pos2+3]},r.y1.set=function(t){this._structArray.int16[this._pos2+3]=t},r.x2.get=function(){return this._structArray.int16[this._pos2+4]},r.x2.set=function(t){this._structArray.int16[this._pos2+4]=t},r.y2.get=function(){return this._structArray.int16[this._pos2+5]},r.y2.set=function(t){this._structArray.int16[this._pos2+5]=t},r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.featureIndex.set=function(t){this._structArray.uint32[this._pos4+3]=t},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.sourceLayerIndex.set=function(t){this._structArray.uint16[this._pos2+8]=t},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.bucketIndex.set=function(t){this._structArray.uint16[this._pos2+9]=t},r.radius.get=function(){return this._structArray.int16[this._pos2+10]},r.radius.set=function(t){this._structArray.int16[this._pos2+10]=t},r.signedDistanceFromAnchor.get=function(){return this._structArray.int16[this._pos2+11]},r.signedDistanceFromAnchor.set=function(t){this._structArray.int16[this._pos2+11]=t},r.anchorPoint.get=function(){return new i(this.anchorPointX,this.anchorPointY)},Object.defineProperties(e.prototype,r),e}(ii);Ci.prototype.size=24;var Li=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Ci(this,t)},e}(vi);kn(\"CollisionBoxArray\",Li);var Pi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},glyphStartIndex:{configurable:!0},numGlyphs:{configurable:!0},vertexStartIndex:{configurable:!0},lineStartIndex:{configurable:!0},lineLength:{configurable:!0},segment:{configurable:!0},lowerSize:{configurable:!0},upperSize:{configurable:!0},lineOffsetX:{configurable:!0},lineOffsetY:{configurable:!0},writingMode:{configurable:!0},hidden:{configurable:!0},crossTileID:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.glyphStartIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.glyphStartIndex.set=function(t){this._structArray.uint16[this._pos2+2]=t},r.numGlyphs.get=function(){return this._structArray.uint16[this._pos2+3]},r.numGlyphs.set=function(t){this._structArray.uint16[this._pos2+3]=t},r.vertexStartIndex.get=function(){return this._structArray.uint32[this._pos4+2]},r.vertexStartIndex.set=function(t){this._structArray.uint32[this._pos4+2]=t},r.lineStartIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.lineStartIndex.set=function(t){this._structArray.uint32[this._pos4+3]=t},r.lineLength.get=function(){return this._structArray.uint32[this._pos4+4]},r.lineLength.set=function(t){this._structArray.uint32[this._pos4+4]=t},r.segment.get=function(){return this._structArray.uint16[this._pos2+10]},r.segment.set=function(t){this._structArray.uint16[this._pos2+10]=t},r.lowerSize.get=function(){return this._structArray.uint16[this._pos2+11]},r.lowerSize.set=function(t){this._structArray.uint16[this._pos2+11]=t},r.upperSize.get=function(){return this._structArray.uint16[this._pos2+12]},r.upperSize.set=function(t){this._structArray.uint16[this._pos2+12]=t},r.lineOffsetX.get=function(){return this._structArray.float32[this._pos4+7]},r.lineOffsetX.set=function(t){this._structArray.float32[this._pos4+7]=t},r.lineOffsetY.get=function(){return this._structArray.float32[this._pos4+8]},r.lineOffsetY.set=function(t){this._structArray.float32[this._pos4+8]=t},r.writingMode.get=function(){return this._structArray.uint8[this._pos1+36]},r.writingMode.set=function(t){this._structArray.uint8[this._pos1+36]=t},r.hidden.get=function(){return this._structArray.uint8[this._pos1+37]},r.hidden.set=function(t){this._structArray.uint8[this._pos1+37]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+10]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+10]=t},Object.defineProperties(e.prototype,r),e}(ii);Pi.prototype.size=44;var Oi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Pi(this,t)},e}(xi);kn(\"PlacedSymbolArray\",Oi);var zi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},rightJustifiedTextSymbolIndex:{configurable:!0},centerJustifiedTextSymbolIndex:{configurable:!0},leftJustifiedTextSymbolIndex:{configurable:!0},verticalPlacedTextSymbolIndex:{configurable:!0},key:{configurable:!0},textBoxStartIndex:{configurable:!0},textBoxEndIndex:{configurable:!0},iconBoxStartIndex:{configurable:!0},iconBoxEndIndex:{configurable:!0},featureIndex:{configurable:!0},numHorizontalGlyphVertices:{configurable:!0},numVerticalGlyphVertices:{configurable:!0},numIconVertices:{configurable:!0},crossTileID:{configurable:!0},textBoxScale:{configurable:!0},radialTextOffset:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.rightJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+2]},r.rightJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+2]=t},r.centerJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+3]},r.centerJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+3]=t},r.leftJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+4]},r.leftJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+4]=t},r.verticalPlacedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+5]},r.verticalPlacedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+5]=t},r.key.get=function(){return this._structArray.uint16[this._pos2+6]},r.key.set=function(t){this._structArray.uint16[this._pos2+6]=t},r.textBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+7]},r.textBoxStartIndex.set=function(t){this._structArray.uint16[this._pos2+7]=t},r.textBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.textBoxEndIndex.set=function(t){this._structArray.uint16[this._pos2+8]=t},r.iconBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.iconBoxStartIndex.set=function(t){this._structArray.uint16[this._pos2+9]=t},r.iconBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+10]},r.iconBoxEndIndex.set=function(t){this._structArray.uint16[this._pos2+10]=t},r.featureIndex.get=function(){return this._structArray.uint16[this._pos2+11]},r.featureIndex.set=function(t){this._structArray.uint16[this._pos2+11]=t},r.numHorizontalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+12]},r.numHorizontalGlyphVertices.set=function(t){this._structArray.uint16[this._pos2+12]=t},r.numVerticalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+13]},r.numVerticalGlyphVertices.set=function(t){this._structArray.uint16[this._pos2+13]=t},r.numIconVertices.get=function(){return this._structArray.uint16[this._pos2+14]},r.numIconVertices.set=function(t){this._structArray.uint16[this._pos2+14]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+8]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+8]=t},r.textBoxScale.get=function(){return this._structArray.float32[this._pos4+9]},r.textBoxScale.set=function(t){this._structArray.float32[this._pos4+9]=t},r.radialTextOffset.get=function(){return this._structArray.float32[this._pos4+10]},r.radialTextOffset.set=function(t){this._structArray.float32[this._pos4+10]=t},Object.defineProperties(e.prototype,r),e}(ii);zi.prototype.size=44;var Ii=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new zi(this,t)},e}(bi);kn(\"SymbolInstanceArray\",Ii);var Di=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={offsetX:{configurable:!0}};return r.offsetX.get=function(){return this._structArray.float32[this._pos4+0]},r.offsetX.set=function(t){this._structArray.float32[this._pos4+0]=t},Object.defineProperties(e.prototype,r),e}(ii);Di.prototype.size=4;var Ri=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getoffsetX=function(t){return this.float32[1*t+0]},e.prototype.get=function(t){return new Di(this,t)},e}(_i);kn(\"GlyphOffsetArray\",Ri);var Fi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={x:{configurable:!0},y:{configurable:!0},tileUnitDistanceFromAnchor:{configurable:!0}};return r.x.get=function(){return this._structArray.int16[this._pos2+0]},r.x.set=function(t){this._structArray.int16[this._pos2+0]=t},r.y.get=function(){return this._structArray.int16[this._pos2+1]},r.y.set=function(t){this._structArray.int16[this._pos2+1]=t},r.tileUnitDistanceFromAnchor.get=function(){return this._structArray.int16[this._pos2+2]},r.tileUnitDistanceFromAnchor.set=function(t){this._structArray.int16[this._pos2+2]=t},Object.defineProperties(e.prototype,r),e}(ii);Fi.prototype.size=6;var Bi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getx=function(t){return this.int16[3*t+0]},e.prototype.gety=function(t){return this.int16[3*t+1]},e.prototype.gettileUnitDistanceFromAnchor=function(t){return this.int16[3*t+2]},e.prototype.get=function(t){return new Fi(this,t)},e}(wi);kn(\"SymbolLineVertexArray\",Bi);var Ni=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0}};return r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+0]},r.featureIndex.set=function(t){this._structArray.uint32[this._pos4+0]=t},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.sourceLayerIndex.set=function(t){this._structArray.uint16[this._pos2+2]=t},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+3]},r.bucketIndex.set=function(t){this._structArray.uint16[this._pos2+3]=t},Object.defineProperties(e.prototype,r),e}(ii);Ni.prototype.size=8;var ji=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Ni(this,t)},e}(ki);kn(\"FeatureIndexArray\",ji);var Ui=oi([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,Vi=function(t){void 0===t&&(t=[]),this.segments=t};function qi(t,e){return 256*(t=c(Math.floor(t),0,255))+c(Math.floor(e),0,255)}Vi.prototype.prepareSegment=function(t,e,r,n){var i=this.segments[this.segments.length-1];return t>Vi.MAX_VERTEX_ARRAY_LENGTH&&w(\"Max vertices per segment is \"+Vi.MAX_VERTEX_ARRAY_LENGTH+\": bucket requested \"+t),(!i||i.vertexLength+t>Vi.MAX_VERTEX_ARRAY_LENGTH||i.sortKey!==n)&&(i={vertexOffset:e.length,primitiveOffset:r.length,vertexLength:0,primitiveLength:0},void 0!==n&&(i.sortKey=n),this.segments.push(i)),i},Vi.prototype.get=function(){return this.segments},Vi.prototype.destroy=function(){for(var t=0,e=this.segments;t<e.length;t+=1){var r=e[t];for(var n in r.vaos)r.vaos[n].destroy()}},Vi.simpleSegment=function(t,e,r,n){return new Vi([{vertexOffset:t,primitiveOffset:e,vertexLength:r,primitiveLength:n,vaos:{},sortKey:0}])},Vi.MAX_VERTEX_ARRAY_LENGTH=Math.pow(2,16)-1,kn(\"SegmentVector\",Vi);var Hi=function(){this.ids=[],this.positions=[],this.indexed=!1};function Gi(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}Hi.prototype.add=function(t,e,r,n){this.ids.push(t),this.positions.push(e,r,n)},Hi.prototype.getPositions=function(t){for(var e=0,r=this.ids.length-1;e<r;){var n=e+r>>1;this.ids[n]>=t?r=n:e=n+1}for(var i=[];this.ids[e]===t;){var a=this.positions[3*e],o=this.positions[3*e+1],s=this.positions[3*e+2];i.push({index:a,start:o,end:s}),e++}return i},Hi.serialize=function(t,e){var r=new Float64Array(t.ids),n=new Uint32Array(t.positions);return function t(e,r,n,i){if(!(n>=i)){for(var a=e[n+i>>1],o=n-1,s=i+1;;){do{o++}while(e[o]<a);do{s--}while(e[s]>a);if(o>=s)break;Gi(e,o,s),Gi(r,3*o,3*s),Gi(r,3*o+1,3*s+1),Gi(r,3*o+2,3*s+2)}t(e,r,n,s),t(e,r,s+1,i)}}(r,n,0,r.length-1),e.push(r.buffer,n.buffer),{ids:r,positions:n}},Hi.deserialize=function(t){var e=new Hi;return e.ids=t.ids,e.positions=t.positions,e.indexed=!0,e},kn(\"FeaturePositionMap\",Hi);var Yi=function(t,e){this.gl=t.gl,this.location=e},Wi=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1i(this.location,t))},e}(Yi),Xi=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1f(this.location,t))},e}(Yi),Zi=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]||(this.current=t,this.gl.uniform2f(this.location,t[0],t[1]))},e}(Yi),Ji=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]||(this.current=t,this.gl.uniform3f(this.location,t[0],t[1],t[2]))},e}(Yi),Ki=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]&&t[3]===this.current[3]||(this.current=t,this.gl.uniform4f(this.location,t[0],t[1],t[2],t[3]))},e}(Yi),$i=function(t){function e(e,r){t.call(this,e,r),this.current=ne.transparent}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t.r===this.current.r&&t.g===this.current.g&&t.b===this.current.b&&t.a===this.current.a||(this.current=t,this.gl.uniform4f(this.location,t.r,t.g,t.b,t.a))},e}(Yi),Qi=new Float32Array(16),ta=function(t){function e(e,r){t.call(this,e,r),this.current=Qi}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(t[12]!==this.current[12]||t[0]!==this.current[0])return this.current=t,void this.gl.uniformMatrix4fv(this.location,!1,t);for(var e=1;e<16;e++)if(t[e]!==this.current[e]){this.current=t,this.gl.uniformMatrix4fv(this.location,!1,t);break}},e}(Yi);function ea(t){return[qi(255*t.r,255*t.g),qi(255*t.b,255*t.a)]}var ra=function(t,e,r){this.value=t,this.names=e,this.uniformNames=this.names.map(function(t){return\"u_\"+t}),this.type=r,this.maxValue=-1/0};ra.prototype.defines=function(){return this.names.map(function(t){return\"#define HAS_UNIFORM_u_\"+t})},ra.prototype.setConstantPatternPositions=function(){},ra.prototype.populatePaintArray=function(){},ra.prototype.updatePaintArray=function(){},ra.prototype.upload=function(){},ra.prototype.destroy=function(){},ra.prototype.setUniforms=function(t,e,r,n){e.set(n.constantOr(this.value))},ra.prototype.getBinding=function(t,e){return\"color\"===this.type?new $i(t,e):new Xi(t,e)},ra.serialize=function(t){var e=t.value,r=t.names,n=t.type;return{value:An(e),names:r,type:n}},ra.deserialize=function(t){var e=t.value,r=t.names,n=t.type;return new ra(Mn(e),r,n)};var na=function(t,e,r){this.value=t,this.names=e,this.uniformNames=this.names.map(function(t){return\"u_\"+t}),this.type=r,this.maxValue=-1/0,this.patternPositions={patternTo:null,patternFrom:null}};na.prototype.defines=function(){return this.names.map(function(t){return\"#define HAS_UNIFORM_u_\"+t})},na.prototype.populatePaintArray=function(){},na.prototype.updatePaintArray=function(){},na.prototype.upload=function(){},na.prototype.destroy=function(){},na.prototype.setConstantPatternPositions=function(t,e){this.patternPositions.patternTo=t.tlbr,this.patternPositions.patternFrom=e.tlbr},na.prototype.setUniforms=function(t,e,r,n,i){var a=this.patternPositions;\"u_pattern_to\"===i&&a.patternTo&&e.set(a.patternTo),\"u_pattern_from\"===i&&a.patternFrom&&e.set(a.patternFrom)},na.prototype.getBinding=function(t,e){return new Ki(t,e)};var ia=function(t,e,r,n){this.expression=t,this.names=e,this.type=r,this.uniformNames=this.names.map(function(t){return\"a_\"+t}),this.maxValue=-1/0,this.paintVertexAttributes=e.map(function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?2:1,offset:0}}),this.paintVertexArray=new n};ia.prototype.defines=function(){return[]},ia.prototype.setConstantPatternPositions=function(){},ia.prototype.populatePaintArray=function(t,e){var r=this.paintVertexArray,n=r.length;r.reserve(t);var i=this.expression.evaluate(new Un(0),e,{});if(\"color\"===this.type)for(var a=ea(i),o=n;o<t;o++)r.emplaceBack(a[0],a[1]);else{for(var s=n;s<t;s++)r.emplaceBack(i);this.maxValue=Math.max(this.maxValue,i)}},ia.prototype.updatePaintArray=function(t,e,r,n){var i=this.paintVertexArray,a=this.expression.evaluate({zoom:0},r,n);if(\"color\"===this.type)for(var o=ea(a),s=t;s<e;s++)i.emplace(s,o[0],o[1]);else{for(var l=t;l<e;l++)i.emplace(l,a);this.maxValue=Math.max(this.maxValue,a)}},ia.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},ia.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},ia.prototype.setUniforms=function(t,e){e.set(0)},ia.prototype.getBinding=function(t,e){return new Xi(t,e)};var aa=function(t,e,r,n,i,a){this.expression=t,this.names=e,this.uniformNames=this.names.map(function(t){return\"u_\"+t+\"_t\"}),this.type=r,this.useIntegerZoom=n,this.zoom=i,this.maxValue=-1/0;var o=a;this.paintVertexAttributes=e.map(function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?4:2,offset:0}}),this.paintVertexArray=new o};aa.prototype.defines=function(){return[]},aa.prototype.setConstantPatternPositions=function(){},aa.prototype.populatePaintArray=function(t,e){var r=this.paintVertexArray,n=r.length;r.reserve(t);var i=this.expression.evaluate(new Un(this.zoom),e,{}),a=this.expression.evaluate(new Un(this.zoom+1),e,{});if(\"color\"===this.type)for(var o=ea(i),s=ea(a),l=n;l<t;l++)r.emplaceBack(o[0],o[1],s[0],s[1]);else{for(var c=n;c<t;c++)r.emplaceBack(i,a);this.maxValue=Math.max(this.maxValue,i,a)}},aa.prototype.updatePaintArray=function(t,e,r,n){var i=this.paintVertexArray,a=this.expression.evaluate({zoom:this.zoom},r,n),o=this.expression.evaluate({zoom:this.zoom+1},r,n);if(\"color\"===this.type)for(var s=ea(a),l=ea(o),c=t;c<e;c++)i.emplace(c,s[0],s[1],l[0],l[1]);else{for(var u=t;u<e;u++)i.emplace(u,a,o);this.maxValue=Math.max(this.maxValue,a,o)}},aa.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},aa.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},aa.prototype.interpolationFactor=function(t){return this.useIntegerZoom?this.expression.interpolationFactor(Math.floor(t),this.zoom,this.zoom+1):this.expression.interpolationFactor(t,this.zoom,this.zoom+1)},aa.prototype.setUniforms=function(t,e,r){e.set(this.interpolationFactor(r.zoom))},aa.prototype.getBinding=function(t,e){return new Xi(t,e)};var oa=function(t,e,r,n,i,a,o){this.expression=t,this.names=e,this.type=r,this.uniformNames=this.names.map(function(t){return\"u_\"+t+\"_t\"}),this.useIntegerZoom=n,this.zoom=i,this.maxValue=-1/0,this.layerId=o,this.paintVertexAttributes=e.map(function(t){return{name:\"a_\"+t,type:\"Uint16\",components:4,offset:0}}),this.zoomInPaintVertexArray=new a,this.zoomOutPaintVertexArray=new a};oa.prototype.defines=function(){return[]},oa.prototype.setConstantPatternPositions=function(){},oa.prototype.populatePaintArray=function(t,e,r){var n=this.zoomInPaintVertexArray,i=this.zoomOutPaintVertexArray,a=this.layerId,o=n.length;if(n.reserve(t),i.reserve(t),r&&e.patterns&&e.patterns[a]){var s=e.patterns[a],l=s.min,c=s.mid,u=s.max,h=r[l],f=r[c],p=r[u];if(!h||!f||!p)return;for(var d=o;d<t;d++)n.emplaceBack(f.tl[0],f.tl[1],f.br[0],f.br[1],h.tl[0],h.tl[1],h.br[0],h.br[1]),i.emplaceBack(f.tl[0],f.tl[1],f.br[0],f.br[1],p.tl[0],p.tl[1],p.br[0],p.br[1])}},oa.prototype.updatePaintArray=function(t,e,r,n,i){var a=this.zoomInPaintVertexArray,o=this.zoomOutPaintVertexArray,s=this.layerId;if(i&&r.patterns&&r.patterns[s]){var l=r.patterns[s],c=l.min,u=l.mid,h=l.max,f=i[c],p=i[u],d=i[h];if(!f||!p||!d)return;for(var g=t;g<e;g++)a.emplace(g,p.tl[0],p.tl[1],p.br[0],p.br[1],f.tl[0],f.tl[1],f.br[0],f.br[1]),o.emplace(g,p.tl[0],p.tl[1],p.br[0],p.br[1],d.tl[0],d.tl[1],d.br[0],d.br[1])}},oa.prototype.upload=function(t){this.zoomInPaintVertexArray&&this.zoomInPaintVertexArray.arrayBuffer&&this.zoomOutPaintVertexArray&&this.zoomOutPaintVertexArray.arrayBuffer&&(this.zoomInPaintVertexBuffer=t.createVertexBuffer(this.zoomInPaintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent),this.zoomOutPaintVertexBuffer=t.createVertexBuffer(this.zoomOutPaintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},oa.prototype.destroy=function(){this.zoomOutPaintVertexBuffer&&this.zoomOutPaintVertexBuffer.destroy(),this.zoomInPaintVertexBuffer&&this.zoomInPaintVertexBuffer.destroy()},oa.prototype.setUniforms=function(t,e){e.set(0)},oa.prototype.getBinding=function(t,e){return new Xi(t,e)};var sa=function(){this.binders={},this.cacheKey=\"\",this._buffers=[],this._featureMap=new Hi,this._bufferOffset=0};sa.createDynamic=function(t,e,r){var n=new sa,i=[];for(var a in t.paint._values)if(r(a)){var o=t.paint.get(a);if(o instanceof Xn&&xr(o.property.specification)){var s=ca(a,t.type),l=o.property.specification.type,c=o.property.useIntegerZoom;if(\"cross-faded\"===o.property.specification[\"property-type\"]||\"cross-faded-data-driven\"===o.property.specification[\"property-type\"])if(\"constant\"===o.value.kind)n.binders[a]=new na(o.value.value,s,l),i.push(\"/u_\"+a);else{var u=ua(a,l,\"source\");n.binders[a]=new oa(o.value,s,l,c,e,u,t.id),i.push(\"/a_\"+a)}else if(\"constant\"===o.value.kind)n.binders[a]=new ra(o.value.value,s,l),i.push(\"/u_\"+a);else if(\"source\"===o.value.kind){var h=ua(a,l,\"source\");n.binders[a]=new ia(o.value,s,l,h),i.push(\"/a_\"+a)}else{var f=ua(a,l,\"composite\");n.binders[a]=new aa(o.value,s,l,c,e,f),i.push(\"/z_\"+a)}}}return n.cacheKey=i.sort().join(\"\"),n},sa.prototype.populatePaintArrays=function(t,e,r,n){for(var i in this.binders)this.binders[i].populatePaintArray(t,e,n);void 0!==e.id&&this._featureMap.add(+e.id,r,this._bufferOffset,t),this._bufferOffset=t},sa.prototype.setConstantPatternPositions=function(t,e){for(var r in this.binders)this.binders[r].setConstantPatternPositions(t,e)},sa.prototype.updatePaintArrays=function(t,e,r,n){var i=!1;for(var a in t)for(var o=0,s=this._featureMap.getPositions(+a);o<s.length;o+=1){var l=s[o],c=e.feature(l.index);for(var u in this.binders){var h=this.binders[u];if(!(h instanceof ra||h instanceof na)&&!0===h.expression.isStateDependent){var f=r.paint.get(u);h.expression=f.value,h.updatePaintArray(l.start,l.end,c,t[a],n),i=!0}}}return i},sa.prototype.defines=function(){var t=[];for(var e in this.binders)t.push.apply(t,this.binders[e].defines());return t},sa.prototype.getPaintVertexBuffers=function(){return this._buffers},sa.prototype.getUniforms=function(t,e){var r=[];for(var n in this.binders)for(var i=this.binders[n],a=0,o=i.uniformNames;a<o.length;a+=1){var s=o[a];if(e[s]){var l=i.getBinding(t,e[s]);r.push({name:s,property:n,binding:l})}}return r},sa.prototype.setUniforms=function(t,e,r,n){for(var i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.name,l=o.property,c=o.binding;this.binders[l].setUniforms(t,c,n,r.get(l),s)}},sa.prototype.updatePatternPaintBuffers=function(t){var e=[];for(var r in this.binders){var n=this.binders[r];if(n instanceof oa){var i=2===t.fromScale?n.zoomInPaintVertexBuffer:n.zoomOutPaintVertexBuffer;i&&e.push(i)}else(n instanceof ia||n instanceof aa)&&n.paintVertexBuffer&&e.push(n.paintVertexBuffer)}this._buffers=e},sa.prototype.upload=function(t){for(var e in this.binders)this.binders[e].upload(t);var r=[];for(var n in this.binders){var i=this.binders[n];(i instanceof ia||i instanceof aa)&&i.paintVertexBuffer&&r.push(i.paintVertexBuffer)}this._buffers=r},sa.prototype.destroy=function(){for(var t in this.binders)this.binders[t].destroy()};var la=function(t,e,r,n){void 0===n&&(n=function(){return!0}),this.programConfigurations={};for(var i=0,a=e;i<a.length;i+=1){var o=a[i];this.programConfigurations[o.id]=sa.createDynamic(o,r,n),this.programConfigurations[o.id].layoutAttributes=t}this.needsUpload=!1};function ca(t,e){return{\"text-opacity\":[\"opacity\"],\"icon-opacity\":[\"opacity\"],\"text-color\":[\"fill_color\"],\"icon-color\":[\"fill_color\"],\"text-halo-color\":[\"halo_color\"],\"icon-halo-color\":[\"halo_color\"],\"text-halo-blur\":[\"halo_blur\"],\"icon-halo-blur\":[\"halo_blur\"],\"text-halo-width\":[\"halo_width\"],\"icon-halo-width\":[\"halo_width\"],\"line-gap-width\":[\"gapwidth\"],\"line-pattern\":[\"pattern_to\",\"pattern_from\"],\"fill-pattern\":[\"pattern_to\",\"pattern_from\"],\"fill-extrusion-pattern\":[\"pattern_to\",\"pattern_from\"]}[t]||[t.replace(e+\"-\",\"\").replace(/-/g,\"_\")]}function ua(t,e,r){var n={color:{source:Si,composite:Ei},number:{source:_i,composite:Si}},i=function(t){return{\"line-pattern\":{source:fi,composite:fi},\"fill-pattern\":{source:fi,composite:fi},\"fill-extrusion-pattern\":{source:fi,composite:fi}}[t]}(t);return i&&i[r]||n[e][r]}la.prototype.populatePaintArrays=function(t,e,r,n){for(var i in this.programConfigurations)this.programConfigurations[i].populatePaintArrays(t,e,r,n);this.needsUpload=!0},la.prototype.updatePaintArrays=function(t,e,r,n){for(var i=0,a=r;i<a.length;i+=1){var o=a[i];this.needsUpload=this.programConfigurations[o.id].updatePaintArrays(t,e,o,n)||this.needsUpload}},la.prototype.get=function(t){return this.programConfigurations[t]},la.prototype.upload=function(t){if(this.needsUpload){for(var e in this.programConfigurations)this.programConfigurations[e].upload(t);this.needsUpload=!1}},la.prototype.destroy=function(){for(var t in this.programConfigurations)this.programConfigurations[t].destroy()},kn(\"ConstantBinder\",ra),kn(\"CrossFadedConstantBinder\",na),kn(\"SourceExpressionBinder\",ia),kn(\"CrossFadedCompositeBinder\",oa),kn(\"CompositeExpressionBinder\",aa),kn(\"ProgramConfiguration\",sa,{omit:[\"_buffers\"]}),kn(\"ProgramConfigurationSet\",la);var ha=8192,fa=(16,{min:-1*Math.pow(2,15),max:Math.pow(2,15)-1});function pa(t){for(var e=ha/t.extent,r=t.loadGeometry(),n=0;n<r.length;n++)for(var i=r[n],a=0;a<i.length;a++){var o=i[a];o.x=Math.round(o.x*e),o.y=Math.round(o.y*e),(o.x<fa.min||o.x>fa.max||o.y<fa.min||o.y>fa.max)&&w(\"Geometry exceeds allowed extent, reduce your vector tile buffer size\")}return r}function da(t,e,r,n,i){t.emplaceBack(2*e+(n+1)/2,2*r+(i+1)/2)}var ga=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new li,this.indexArray=new Ti,this.segments=new Vi,this.programConfigurations=new la(Ui,t.layers,t.zoom),this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function va(t,e){for(var r=0;r<t.length;r++)if(Aa(e,t[r]))return!0;for(var n=0;n<e.length;n++)if(Aa(t,e[n]))return!0;return!!ba(t,e)}function ma(t,e,r){return!!Aa(t,e)||!!wa(e,t,r)}function ya(t,e){if(1===t.length)return Ta(e,t[0]);for(var r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++)if(Aa(t,n[i]))return!0;for(var a=0;a<t.length;a++)if(Ta(e,t[a]))return!0;for(var o=0;o<e.length;o++)if(ba(t,e[o]))return!0;return!1}function xa(t,e,r){if(t.length>1){if(ba(t,e))return!0;for(var n=0;n<e.length;n++)if(wa(e[n],t,r))return!0}for(var i=0;i<t.length;i++)if(wa(t[i],e,r))return!0;return!1}function ba(t,e){if(0===t.length||0===e.length)return!1;for(var r=0;r<t.length-1;r++)for(var n=t[r],i=t[r+1],a=0;a<e.length-1;a++)if(_a(n,i,e[a],e[a+1]))return!0;return!1}function _a(t,e,r,n){return k(t,r,n)!==k(e,r,n)&&k(t,e,r)!==k(t,e,n)}function wa(t,e,r){var n=r*r;if(1===e.length)return t.distSqr(e[0])<n;for(var i=1;i<e.length;i++)if(ka(t,e[i-1],e[i])<n)return!0;return!1}function ka(t,e,r){var n=e.distSqr(r);if(0===n)return t.distSqr(e);var i=((t.x-e.x)*(r.x-e.x)+(t.y-e.y)*(r.y-e.y))/n;return i<0?t.distSqr(e):i>1?t.distSqr(r):t.distSqr(r.sub(e)._mult(i)._add(e))}function Ta(t,e){for(var r,n,i,a=!1,o=0;o<t.length;o++)for(var s=0,l=(r=t[o]).length-1;s<r.length;l=s++)n=r[s],i=r[l],n.y>e.y!=i.y>e.y&&e.x<(i.x-n.x)*(e.y-n.y)/(i.y-n.y)+n.x&&(a=!a);return a}function Aa(t,e){for(var r=!1,n=0,i=t.length-1;n<t.length;i=n++){var a=t[n],o=t[i];a.y>e.y!=o.y>e.y&&e.x<(o.x-a.x)*(e.y-a.y)/(o.y-a.y)+a.x&&(r=!r)}return r}function Ma(t,e,r){var n=r[0],i=r[2];if(t.x<n.x&&e.x<n.x||t.x>i.x&&e.x>i.x||t.y<n.y&&e.y<n.y||t.y>i.y&&e.y>i.y)return!1;var a=k(t,e,r[0]);return a!==k(t,e,r[1])||a!==k(t,e,r[2])||a!==k(t,e,r[3])}function Sa(t,e,r){var n=e.paint.get(t).value;return\"constant\"===n.kind?n.value:r.programConfigurations.get(e.id).binders[t].maxValue}function Ea(t){return Math.sqrt(t[0]*t[0]+t[1]*t[1])}function Ca(t,e,r,n,a){if(!e[0]&&!e[1])return t;var o=i.convert(e)._mult(a);\"viewport\"===r&&o._rotate(-n);for(var s=[],l=0;l<t.length;l++){var c=t[l];s.push(c.sub(o))}return s}ga.prototype.populate=function(t,e){for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a);this.addFeature(a,l,o),e.featureIndex.insert(a,l,o,s,this.index)}}},ga.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},ga.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},ga.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},ga.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ui),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},ga.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},ga.prototype.addFeature=function(t,e,r){for(var n=0,i=e;n<i.length;n+=1)for(var a=0,o=i[n];a<o.length;a+=1){var s=o[a],l=s.x,c=s.y;if(!(l<0||l>=ha||c<0||c>=ha)){var u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),h=u.vertexLength;da(this.layoutVertexArray,l,c,-1,-1),da(this.layoutVertexArray,l,c,1,-1),da(this.layoutVertexArray,l,c,1,1),da(this.layoutVertexArray,l,c,-1,1),this.indexArray.emplaceBack(h,h+1,h+2),this.indexArray.emplaceBack(h,h+3,h+2),u.vertexLength+=4,u.primitiveLength+=2}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,{})},kn(\"CircleBucket\",ga,{omit:[\"layers\"]});var La={paint:new ei({\"circle-radius\":new Kn(It.paint_circle[\"circle-radius\"]),\"circle-color\":new Kn(It.paint_circle[\"circle-color\"]),\"circle-blur\":new Kn(It.paint_circle[\"circle-blur\"]),\"circle-opacity\":new Kn(It.paint_circle[\"circle-opacity\"]),\"circle-translate\":new Jn(It.paint_circle[\"circle-translate\"]),\"circle-translate-anchor\":new Jn(It.paint_circle[\"circle-translate-anchor\"]),\"circle-pitch-scale\":new Jn(It.paint_circle[\"circle-pitch-scale\"]),\"circle-pitch-alignment\":new Jn(It.paint_circle[\"circle-pitch-alignment\"]),\"circle-stroke-width\":new Kn(It.paint_circle[\"circle-stroke-width\"]),\"circle-stroke-color\":new Kn(It.paint_circle[\"circle-stroke-color\"]),\"circle-stroke-opacity\":new Kn(It.paint_circle[\"circle-stroke-opacity\"])})},Pa=\"undefined\"!=typeof Float32Array?Float32Array:Array;function Oa(){var t=new Pa(9);return Pa!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[5]=0,t[6]=0,t[7]=0),t[0]=1,t[4]=1,t[8]=1,t}function za(){var t=new Pa(3);return Pa!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0),t}function Ia(t,e,r){var n=new Pa(3);return n[0]=t,n[1]=e,n[2]=r,n}Math.PI;function Da(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}function Ra(){var t=new Pa(4);return Pa!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0),t[3]=1,t}za(),function(){var t;t=new Pa(4),Pa!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0,t[3]=0)}();za(),Ia(1,0,0),Ia(0,1,0),Ra(),Ra(),Oa(),function(){var t;t=new Pa(2),Pa!=Float32Array&&(t[0]=0,t[1]=0)}();var Fa=function(t){function e(e){t.call(this,e,La)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new ga(t)},e.prototype.queryRadius=function(t){var e=t;return Sa(\"circle-radius\",this,e)+Sa(\"circle-stroke-width\",this,e)+Ea(this.paint.get(\"circle-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o,s){for(var l=Ca(t,this.paint.get(\"circle-translate\"),this.paint.get(\"circle-translate-anchor\"),a.angle,o),c=this.paint.get(\"circle-radius\").evaluate(e,r)+this.paint.get(\"circle-stroke-width\").evaluate(e,r),u=\"map\"===this.paint.get(\"circle-pitch-alignment\"),h=u?l:function(t,e){return l.map(function(t){return Ba(t,e)})}(0,s),f=u?c*o:c,p=0,d=n;p<d.length;p+=1)for(var g=0,v=d[p];g<v.length;g+=1){var m=v[g],y=u?m:Ba(m,s),x=f,b=Da([],[m.x,m.y,0,1],s);if(\"viewport\"===this.paint.get(\"circle-pitch-scale\")&&\"map\"===this.paint.get(\"circle-pitch-alignment\")?x*=b[3]/a.cameraToCenterDistance:\"map\"===this.paint.get(\"circle-pitch-scale\")&&\"viewport\"===this.paint.get(\"circle-pitch-alignment\")&&(x*=a.cameraToCenterDistance/b[3]),ma(h,y,x))return!0}return!1},e}(ri);function Ba(t,e){var r=Da([],[t.x,t.y,0,1],e);return new i(r[0]/r[3],r[1]/r[3])}var Na=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ga);function ja(t,e,r,n){var i=e.width,a=e.height;if(n){if(n instanceof Uint8ClampedArray)n=new Uint8Array(n.buffer);else if(n.length!==i*a*r)throw new RangeError(\"mismatched image size\")}else n=new Uint8Array(i*a*r);return t.width=i,t.height=a,t.data=n,t}function Ua(t,e,r){var n=e.width,i=e.height;if(n!==t.width||i!==t.height){var a=ja({},{width:n,height:i},r);Va(t,a,{x:0,y:0},{x:0,y:0},{width:Math.min(t.width,n),height:Math.min(t.height,i)},r),t.width=n,t.height=i,t.data=a.data}}function Va(t,e,r,n,i,a){if(0===i.width||0===i.height)return e;if(i.width>t.width||i.height>t.height||r.x>t.width-i.width||r.y>t.height-i.height)throw new RangeError(\"out of range source coordinates for image copy\");if(i.width>e.width||i.height>e.height||n.x>e.width-i.width||n.y>e.height-i.height)throw new RangeError(\"out of range destination coordinates for image copy\");for(var o=t.data,s=e.data,l=0;l<i.height;l++)for(var c=((r.y+l)*t.width+r.x)*a,u=((n.y+l)*e.width+n.x)*a,h=0;h<i.width*a;h++)s[u+h]=o[c+h];return e}kn(\"HeatmapBucket\",Na,{omit:[\"layers\"]});var qa=function(t,e){ja(this,t,1,e)};qa.prototype.resize=function(t){Ua(this,t,1)},qa.prototype.clone=function(){return new qa({width:this.width,height:this.height},new Uint8Array(this.data))},qa.copy=function(t,e,r,n,i){Va(t,e,r,n,i,1)};var Ha=function(t,e){ja(this,t,4,e)};Ha.prototype.resize=function(t){Ua(this,t,4)},Ha.prototype.replace=function(t,e){e?this.data.set(t):t instanceof Uint8ClampedArray?this.data=new Uint8Array(t.buffer):this.data=t},Ha.prototype.clone=function(){return new Ha({width:this.width,height:this.height},new Uint8Array(this.data))},Ha.copy=function(t,e,r,n,i){Va(t,e,r,n,i,4)},kn(\"AlphaImage\",qa),kn(\"RGBAImage\",Ha);var Ga={paint:new ei({\"heatmap-radius\":new Kn(It.paint_heatmap[\"heatmap-radius\"]),\"heatmap-weight\":new Kn(It.paint_heatmap[\"heatmap-weight\"]),\"heatmap-intensity\":new Jn(It.paint_heatmap[\"heatmap-intensity\"]),\"heatmap-color\":new ti(It.paint_heatmap[\"heatmap-color\"]),\"heatmap-opacity\":new Jn(It.paint_heatmap[\"heatmap-opacity\"])})};function Ya(t,e){for(var r=new Uint8Array(1024),n={},i=0,a=0;i<256;i++,a+=4){n[e]=i/255;var o=t.evaluate(n);r[a+0]=Math.floor(255*o.r/o.a),r[a+1]=Math.floor(255*o.g/o.a),r[a+2]=Math.floor(255*o.b/o.a),r[a+3]=Math.floor(255*o.a)}return new Ha({width:256,height:1},r)}var Wa=function(t){function e(e){t.call(this,e,Ga),this._updateColorRamp()}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new Na(t)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"heatmap-color\"===t&&this._updateColorRamp()},e.prototype._updateColorRamp=function(){var t=this._transitionablePaint._values[\"heatmap-color\"].value.expression;this.colorRamp=Ya(t,\"heatmapDensity\"),this.colorRampTexture=null},e.prototype.resize=function(){this.heatmapFbo&&(this.heatmapFbo.destroy(),this.heatmapFbo=null)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"heatmap-opacity\")&&\"none\"!==this.visibility},e}(ri),Xa={paint:new ei({\"hillshade-illumination-direction\":new Jn(It.paint_hillshade[\"hillshade-illumination-direction\"]),\"hillshade-illumination-anchor\":new Jn(It.paint_hillshade[\"hillshade-illumination-anchor\"]),\"hillshade-exaggeration\":new Jn(It.paint_hillshade[\"hillshade-exaggeration\"]),\"hillshade-shadow-color\":new Jn(It.paint_hillshade[\"hillshade-shadow-color\"]),\"hillshade-highlight-color\":new Jn(It.paint_hillshade[\"hillshade-highlight-color\"]),\"hillshade-accent-color\":new Jn(It.paint_hillshade[\"hillshade-accent-color\"])})},Za=function(t){function e(e){t.call(this,e,Xa)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"hillshade-exaggeration\")&&\"none\"!==this.visibility},e}(ri),Ja=oi([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,Ka=Qa,$a=Qa;function Qa(t,e,r){r=r||2;var n,i,a,o,s,l,c,u=e&&e.length,h=u?e[0]*r:t.length,f=to(t,0,h,r,!0),p=[];if(!f||f.next===f.prev)return p;if(u&&(f=function(t,e,r,n){var i,a,o,s=[];for(i=0,a=e.length;i<a;i++)(o=to(t,e[i]*n,i<a-1?e[i+1]*n:t.length,n,!1))===o.next&&(o.steiner=!0),s.push(uo(o));for(s.sort(so),i=0;i<s.length;i++)lo(s[i],r),r=eo(r,r.next);return r}(t,e,f,r)),t.length>80*r){n=a=t[0],i=o=t[1];for(var d=r;d<h;d+=r)(s=t[d])<n&&(n=s),(l=t[d+1])<i&&(i=l),s>a&&(a=s),l>o&&(o=l);c=0!==(c=Math.max(a-n,o-i))?1/c:0}return ro(f,p,r,n,i,c),p}function to(t,e,r,n,i){var a,o;if(i===wo(t,e,r,n)>0)for(a=e;a<r;a+=n)o=xo(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=xo(a,t[a],t[a+1],o);return o&&go(o,o.next)&&(bo(o),o=o.next),o}function eo(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!go(n,n.next)&&0!==po(n.prev,n,n.next))n=n.next;else{if(bo(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function ro(t,e,r,n,i,a,o){if(t){!o&&a&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=co(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,a);for(var s,l,c=t;t.prev!==t.next;)if(s=t.prev,l=t.next,a?io(t,n,i,a):no(t))e.push(s.i/r),e.push(t.i/r),e.push(l.i/r),bo(t),t=l.next,c=l.next;else if((t=l)===c){o?1===o?ro(t=ao(t,e,r),e,r,n,i,a,2):2===o&&oo(t,e,r,n,i,a):ro(eo(t),e,r,n,i,a,1);break}}}function no(t){var e=t.prev,r=t,n=t.next;if(po(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(ho(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&po(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function io(t,e,r,n){var i=t.prev,a=t,o=t.next;if(po(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,h=co(s,l,e,r,n),f=co(c,u,e,r,n),p=t.prevZ,d=t.nextZ;p&&p.z>=h&&d&&d.z<=f;){if(p!==t.prev&&p!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&po(p.prev,p,p.next)>=0)return!1;if(p=p.prevZ,d!==t.prev&&d!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&po(d.prev,d,d.next)>=0)return!1;d=d.nextZ}for(;p&&p.z>=h;){if(p!==t.prev&&p!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&po(p.prev,p,p.next)>=0)return!1;p=p.prevZ}for(;d&&d.z<=f;){if(d!==t.prev&&d!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&po(d.prev,d,d.next)>=0)return!1;d=d.nextZ}return!0}function ao(t,e,r){var n=t;do{var i=n.prev,a=n.next.next;!go(i,a)&&vo(i,n,n.next,a)&&mo(i,a)&&mo(a,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(a.i/r),bo(n),bo(n.next),n=t=a),n=n.next}while(n!==t);return n}function oo(t,e,r,n,i,a){var o=t;do{for(var s=o.next.next;s!==o.prev;){if(o.i!==s.i&&fo(o,s)){var l=yo(o,s);return o=eo(o,o.next),l=eo(l,l.next),ro(o,e,r,n,i,a),void ro(l,e,r,n,i,a)}s=s.next}o=o.next}while(o!==t)}function so(t,e){return t.x-e.x}function lo(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r.prev;var l,c=r,u=r.x,h=r.y,f=1/0;for(n=r.next;n!==c;)i>=n.x&&n.x>=u&&i!==n.x&&ho(a<h?i:o,a,u,h,a<h?o:i,a,n.x,n.y)&&((l=Math.abs(a-n.y)/(i-n.x))<f||l===f&&n.x>r.x)&&mo(n,t)&&(r=n,f=l),n=n.next;return r}(t,e)){var r=yo(e,t);eo(r,r.next)}}function co(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function uo(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function ho(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function fo(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&vo(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&mo(t,e)&&mo(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)}function po(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function go(t,e){return t.x===e.x&&t.y===e.y}function vo(t,e,r,n){return!!(go(t,e)&&go(r,n)||go(t,n)&&go(r,e))||po(t,e,r)>0!=po(t,e,n)>0&&po(r,n,t)>0!=po(r,n,e)>0}function mo(t,e){return po(t.prev,t,t.next)<0?po(t,e,t.next)>=0&&po(t,t.prev,e)>=0:po(t,e,t.prev)<0||po(t,t.next,e)<0}function yo(t,e){var r=new _o(t.i,t.x,t.y),n=new _o(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function xo(t,e,r,n){var i=new _o(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function bo(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function _o(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function wo(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}function ko(t,e,r,n,i){!function t(e,r,n,i,a){for(;i>n;){if(i-n>600){var o=i-n+1,s=r-n+1,l=Math.log(o),c=.5*Math.exp(2*l/3),u=.5*Math.sqrt(l*c*(o-c)/o)*(s-o/2<0?-1:1);t(e,r,Math.max(n,Math.floor(r-s*c/o+u)),Math.min(i,Math.floor(r+(o-s)*c/o+u)),a)}var h=e[r],f=n,p=i;for(To(e,n,r),a(e[i],h)>0&&To(e,n,i);f<p;){for(To(e,f,p),f++,p--;a(e[f],h)<0;)f++;for(;a(e[p],h)>0;)p--}0===a(e[n],h)?To(e,n,p):To(e,++p,i),p<=r&&(n=p+1),r<=p&&(i=p-1)}}(t,e,r||0,n||t.length-1,i||Ao)}function To(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function Ao(t,e){return t<e?-1:t>e?1:0}function Mo(t,e){var r=t.length;if(r<=1)return[t];for(var n,i,a=[],o=0;o<r;o++){var s=T(t[o]);0!==s&&(t[o].area=Math.abs(s),void 0===i&&(i=s<0),i===s<0?(n&&a.push(n),n=[t[o]]):n.push(t[o]))}if(n&&a.push(n),e>1)for(var l=0;l<a.length;l++)a[l].length<=e||(ko(a[l],e,1,a[l].length-1,So),a[l]=a[l].slice(0,e));return a}function So(t,e){return e.area-t.area}function Eo(t,e,r){for(var n=r.patternDependencies,i=!1,a=0,o=e;a<o.length;a+=1){var s=o[a].paint.get(t+\"-pattern\");s.isConstant()||(i=!0);var l=s.constantOr(null);l&&(i=!0,n[l.to]=!0,n[l.from]=!0)}return i}function Co(t,e,r,n,i){for(var a=i.patternDependencies,o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.paint.get(t+\"-pattern\").value;if(\"constant\"!==c.kind){var u=c.evaluate({zoom:n-1},r,{}),h=c.evaluate({zoom:n},r,{}),f=c.evaluate({zoom:n+1},r,{});a[u]=!0,a[h]=!0,a[f]=!0,r.patterns[l.id]={min:u,mid:h,max:f}}}return r}Qa.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(wo(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(wo(t,c,u,r))}var h=0;for(s=0;s<n.length;s+=3){var f=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;h+=Math.abs((t[f]-t[d])*(t[p+1]-t[f+1])-(t[f]-t[p])*(t[d+1]-t[f+1]))}return 0===o&&0===h?0:Math.abs((h-o)/o)},Qa.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r},Ka.default=$a;var Lo=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new li,this.indexArray=new Ti,this.indexArray2=new Ai,this.programConfigurations=new la(Ja,t.layers,t.zoom),this.segments=new Vi,this.segments2=new Vi,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};Lo.prototype.populate=function(t,e){this.features=[],this.hasPattern=Eo(\"fill\",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a),c={sourceLayerIndex:s,index:o,geometry:l,properties:a.properties,type:a.type,patterns:{}};void 0!==a.id&&(c.id=a.id),this.hasPattern?this.features.push(Co(\"fill\",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(a,l,o,s,this.index)}}},Lo.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Lo.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var i=n[r],a=i.geometry;this.addFeature(i,a,i.index,e)}},Lo.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Lo.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Lo.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ja),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.indexBuffer2=t.createIndexBuffer(this.indexArray2)),this.programConfigurations.upload(t),this.uploaded=!0},Lo.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.indexBuffer2.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.segments2.destroy())},Lo.prototype.addFeature=function(t,e,r,n){for(var i=0,a=Mo(e,500);i<a.length;i+=1){for(var o=a[i],s=0,l=0,c=o;l<c.length;l+=1)s+=c[l].length;for(var u=this.segments.prepareSegment(s,this.layoutVertexArray,this.indexArray),h=u.vertexLength,f=[],p=[],d=0,g=o;d<g.length;d+=1){var v=g[d];if(0!==v.length){v!==o[0]&&p.push(f.length/2);var m=this.segments2.prepareSegment(v.length,this.layoutVertexArray,this.indexArray2),y=m.vertexLength;this.layoutVertexArray.emplaceBack(v[0].x,v[0].y),this.indexArray2.emplaceBack(y+v.length-1,y),f.push(v[0].x),f.push(v[0].y);for(var x=1;x<v.length;x++)this.layoutVertexArray.emplaceBack(v[x].x,v[x].y),this.indexArray2.emplaceBack(y+x-1,y+x),f.push(v[x].x),f.push(v[x].y);m.vertexLength+=v.length,m.primitiveLength+=v.length}}for(var b=Ka(f,p),_=0;_<b.length;_+=3)this.indexArray.emplaceBack(h+b[_],h+b[_+1],h+b[_+2]);u.vertexLength+=s,u.primitiveLength+=b.length/3}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,n)},kn(\"FillBucket\",Lo,{omit:[\"layers\",\"features\"]});var Po={paint:new ei({\"fill-antialias\":new Jn(It.paint_fill[\"fill-antialias\"]),\"fill-opacity\":new Kn(It.paint_fill[\"fill-opacity\"]),\"fill-color\":new Kn(It.paint_fill[\"fill-color\"]),\"fill-outline-color\":new Kn(It.paint_fill[\"fill-outline-color\"]),\"fill-translate\":new Jn(It.paint_fill[\"fill-translate\"]),\"fill-translate-anchor\":new Jn(It.paint_fill[\"fill-translate-anchor\"]),\"fill-pattern\":new $n(It.paint_fill[\"fill-pattern\"])})},Oo=function(t){function e(e){t.call(this,e,Po)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e);var r=this.paint._values[\"fill-outline-color\"];\"constant\"===r.value.kind&&void 0===r.value.value&&(this.paint._values[\"fill-outline-color\"]=this.paint._values[\"fill-color\"])},e.prototype.createBucket=function(t){return new Lo(t)},e.prototype.queryRadius=function(){return Ea(this.paint.get(\"fill-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o){return ya(Ca(t,this.paint.get(\"fill-translate\"),this.paint.get(\"fill-translate-anchor\"),a.angle,o),n)},e.prototype.isTileClipped=function(){return!0},e}(ri),zo=oi([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_normal_ed\",components:4,type:\"Int16\"}],4).members,Io=Do;function Do(t,e,r,n,i){this.properties={},this.extent=r,this.type=0,this._pbf=t,this._geometry=-1,this._keys=n,this._values=i,t.readFields(Ro,this,e)}function Ro(t,e,r){1==t?e.id=r.readVarint():2==t?function(t,e){for(var r=t.readVarint()+t.pos;t.pos<r;){var n=e._keys[t.readVarint()],i=e._values[t.readVarint()];e.properties[n]=i}}(r,e):3==t?e.type=r.readVarint():4==t&&(e._geometry=r.pos)}function Fo(t){for(var e,r,n=0,i=0,a=t.length,o=a-1;i<a;o=i++)e=t[i],n+=((r=t[o]).x-e.x)*(e.y+r.y);return n}Do.types=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],Do.prototype.loadGeometry=function(){var t=this._pbf;t.pos=this._geometry;for(var e,r=t.readVarint()+t.pos,n=1,a=0,o=0,s=0,l=[];t.pos<r;){if(a<=0){var c=t.readVarint();n=7&c,a=c>>3}if(a--,1===n||2===n)o+=t.readSVarint(),s+=t.readSVarint(),1===n&&(e&&l.push(e),e=[]),e.push(new i(o,s));else{if(7!==n)throw new Error(\"unknown command \"+n);e&&e.push(e[0].clone())}}return e&&l.push(e),l},Do.prototype.bbox=function(){var t=this._pbf;t.pos=this._geometry;for(var e=t.readVarint()+t.pos,r=1,n=0,i=0,a=0,o=1/0,s=-1/0,l=1/0,c=-1/0;t.pos<e;){if(n<=0){var u=t.readVarint();r=7&u,n=u>>3}if(n--,1===r||2===r)(i+=t.readSVarint())<o&&(o=i),i>s&&(s=i),(a+=t.readSVarint())<l&&(l=a),a>c&&(c=a);else if(7!==r)throw new Error(\"unknown command \"+r)}return[o,l,s,c]},Do.prototype.toGeoJSON=function(t,e,r){var n,i,a=this.extent*Math.pow(2,r),o=this.extent*t,s=this.extent*e,l=this.loadGeometry(),c=Do.types[this.type];function u(t){for(var e=0;e<t.length;e++){var r=t[e],n=180-360*(r.y+s)/a;t[e]=[360*(r.x+o)/a-180,360/Math.PI*Math.atan(Math.exp(n*Math.PI/180))-90]}}switch(this.type){case 1:var h=[];for(n=0;n<l.length;n++)h[n]=l[n][0];u(l=h);break;case 2:for(n=0;n<l.length;n++)u(l[n]);break;case 3:for(l=function(t){var e=t.length;if(e<=1)return[t];for(var r,n,i=[],a=0;a<e;a++){var o=Fo(t[a]);0!==o&&(void 0===n&&(n=o<0),n===o<0?(r&&i.push(r),r=[t[a]]):r.push(t[a]))}return r&&i.push(r),i}(l),n=0;n<l.length;n++)for(i=0;i<l[n].length;i++)u(l[n][i])}1===l.length?l=l[0]:c=\"Multi\"+c;var f={type:\"Feature\",geometry:{type:c,coordinates:l},properties:this.properties};return\"id\"in this&&(f.id=this.id),f};var Bo=No;function No(t,e){this.version=1,this.name=null,this.extent=4096,this.length=0,this._pbf=t,this._keys=[],this._values=[],this._features=[],t.readFields(jo,this,e),this.length=this._features.length}function jo(t,e,r){15===t?e.version=r.readVarint():1===t?e.name=r.readString():5===t?e.extent=r.readVarint():2===t?e._features.push(r.pos):3===t?e._keys.push(r.readString()):4===t&&e._values.push(function(t){for(var e=null,r=t.readVarint()+t.pos;t.pos<r;){var n=t.readVarint()>>3;e=1===n?t.readString():2===n?t.readFloat():3===n?t.readDouble():4===n?t.readVarint64():5===n?t.readVarint():6===n?t.readSVarint():7===n?t.readBoolean():null}return e}(r))}function Uo(t,e,r){if(3===t){var n=new Bo(r,r.readVarint()+r.pos);n.length&&(e[n.name]=n)}}No.prototype.feature=function(t){if(t<0||t>=this._features.length)throw new Error(\"feature index out of bounds\");this._pbf.pos=this._features[t];var e=this._pbf.readVarint()+this._pbf.pos;return new Io(this._pbf,e,this.extent,this._keys,this._values)};var Vo={VectorTile:function(t,e){this.layers=t.readFields(Uo,{},e)},VectorTileFeature:Io,VectorTileLayer:Bo},qo=Vo.VectorTileFeature.types,Ho=Math.pow(2,13);function Go(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,2*Math.floor(n*Ho)+o,i*Ho*2,a*Ho*2,Math.round(s))}var Yo=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new ui,this.indexArray=new Ti,this.programConfigurations=new la(zo,t.layers,t.zoom),this.segments=new Vi,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function Wo(t,e){return t.x===e.x&&(t.x<0||t.x>ha)||t.y===e.y&&(t.y<0||t.y>ha)}function Xo(t){return t.every(function(t){return t.x<0})||t.every(function(t){return t.x>ha})||t.every(function(t){return t.y<0})||t.every(function(t){return t.y>ha})}Yo.prototype.populate=function(t,e){this.features=[],this.hasPattern=Eo(\"fill-extrusion\",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a),c={sourceLayerIndex:s,index:o,geometry:l,properties:a.properties,type:a.type,patterns:{}};void 0!==a.id&&(c.id=a.id),this.hasPattern?this.features.push(Co(\"fill-extrusion\",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(a,l,o,s,this.index,!0)}}},Yo.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var i=n[r],a=i.geometry;this.addFeature(i,a,i.index,e)}},Yo.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Yo.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Yo.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Yo.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,zo),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Yo.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Yo.prototype.addFeature=function(t,e,r,n){for(var i=0,a=Mo(e,500);i<a.length;i+=1){for(var o=a[i],s=0,l=0,c=o;l<c.length;l+=1)s+=c[l].length;for(var u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),h=0,f=o;h<f.length;h+=1){var p=f[h];if(0!==p.length&&!Xo(p))for(var d=0,g=0;g<p.length;g++){var v=p[g];if(g>=1){var m=p[g-1];if(!Wo(v,m)){u.vertexLength+4>Vi.MAX_VERTEX_ARRAY_LENGTH&&(u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray));var y=v.sub(m)._perp()._unit(),x=m.dist(v);d+x>32768&&(d=0),Go(this.layoutVertexArray,v.x,v.y,y.x,y.y,0,0,d),Go(this.layoutVertexArray,v.x,v.y,y.x,y.y,0,1,d),d+=x,Go(this.layoutVertexArray,m.x,m.y,y.x,y.y,0,0,d),Go(this.layoutVertexArray,m.x,m.y,y.x,y.y,0,1,d);var b=u.vertexLength;this.indexArray.emplaceBack(b,b+2,b+1),this.indexArray.emplaceBack(b+1,b+2,b+3),u.vertexLength+=4,u.primitiveLength+=2}}}}if(u.vertexLength+s>Vi.MAX_VERTEX_ARRAY_LENGTH&&(u=this.segments.prepareSegment(s,this.layoutVertexArray,this.indexArray)),\"Polygon\"===qo[t.type]){for(var _=[],w=[],k=u.vertexLength,T=0,A=o;T<A.length;T+=1){var M=A[T];if(0!==M.length){M!==o[0]&&w.push(_.length/2);for(var S=0;S<M.length;S++){var E=M[S];Go(this.layoutVertexArray,E.x,E.y,0,0,1,1,0),_.push(E.x),_.push(E.y)}}}for(var C=Ka(_,w),L=0;L<C.length;L+=3)this.indexArray.emplaceBack(k+C[L],k+C[L+2],k+C[L+1]);u.primitiveLength+=C.length/3,u.vertexLength+=s}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,n)},kn(\"FillExtrusionBucket\",Yo,{omit:[\"layers\",\"features\"]});var Zo={paint:new ei({\"fill-extrusion-opacity\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-opacity\"]),\"fill-extrusion-color\":new Kn(It[\"paint_fill-extrusion\"][\"fill-extrusion-color\"]),\"fill-extrusion-translate\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-translate\"]),\"fill-extrusion-translate-anchor\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-translate-anchor\"]),\"fill-extrusion-pattern\":new $n(It[\"paint_fill-extrusion\"][\"fill-extrusion-pattern\"]),\"fill-extrusion-height\":new Kn(It[\"paint_fill-extrusion\"][\"fill-extrusion-height\"]),\"fill-extrusion-base\":new Kn(It[\"paint_fill-extrusion\"][\"fill-extrusion-base\"]),\"fill-extrusion-vertical-gradient\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-vertical-gradient\"])})},Jo=function(t){function e(e){t.call(this,e,Zo)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new Yo(t)},e.prototype.queryRadius=function(){return Ea(this.paint.get(\"fill-extrusion-translate\"))},e.prototype.is3D=function(){return!0},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s,l){var c=Ca(t,this.paint.get(\"fill-extrusion-translate\"),this.paint.get(\"fill-extrusion-translate-anchor\"),o.angle,s),u=this.paint.get(\"fill-extrusion-height\").evaluate(e,r),h=this.paint.get(\"fill-extrusion-base\").evaluate(e,r),f=function(t,e,r,n){for(var a=[],o=0,s=t;o<s.length;o+=1){var l=s[o],c=[l.x,l.y,0,1];Da(c,c,e),a.push(new i(c[0]/c[3],c[1]/c[3]))}return a}(c,l),p=function(t,e,r,n){for(var a=[],o=[],s=n[8]*e,l=n[9]*e,c=n[10]*e,u=n[11]*e,h=n[8]*r,f=n[9]*r,p=n[10]*r,d=n[11]*r,g=0,v=t;g<v.length;g+=1){for(var m=[],y=[],x=0,b=v[g];x<b.length;x+=1){var _=b[x],w=_.x,k=_.y,T=n[0]*w+n[4]*k+n[12],A=n[1]*w+n[5]*k+n[13],M=n[2]*w+n[6]*k+n[14],S=n[3]*w+n[7]*k+n[15],E=M+c,C=S+u,L=T+h,P=A+f,O=M+p,z=S+d,I=new i((T+s)/C,(A+l)/C);I.z=E/C,m.push(I);var D=new i(L/z,P/z);D.z=O/z,y.push(D)}a.push(m),o.push(y)}return[a,o]}(n,h,u,l);return function(t,e,r){var n=1/0;ya(r,e)&&(n=$o(r,e[0]));for(var i=0;i<e.length;i++)for(var a=e[i],o=t[i],s=0;s<a.length-1;s++){var l=a[s],c=a[s+1],u=o[s],h=[l,c,o[s+1],u,l];va(r,h)&&(n=Math.min(n,$o(r,h)))}return n!==1/0&&n}(p[0],p[1],f)},e}(ri);function Ko(t,e){return t.x*e.x+t.y*e.y}function $o(t,e){if(1===t.length){var r=e[0],n=e[1],i=e[3],a=t[0],o=n.sub(r),s=i.sub(r),l=a.sub(r),c=Ko(o,o),u=Ko(o,s),h=Ko(s,s),f=Ko(l,o),p=Ko(l,s),d=c*h-u*u,g=(h*f-u*p)/d,v=(c*p-u*f)/d,m=1-g-v;return r.z*m+n.z*g+i.z*v}for(var y=1/0,x=0,b=e;x<b.length;x+=1){var _=b[x];y=Math.min(y,_.z)}return y}var Qo=oi([{name:\"a_pos_normal\",components:2,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint8\"}],4).members,ts=Vo.VectorTileFeature.types,es=63,rs=Math.cos(Math.PI/180*37.5),ns=.5,is=Math.pow(2,14)/ns;function as(t,e,r,n,i,a,o){t.emplaceBack((e.x<<1)+(n?1:0),(e.y<<1)+(i?1:0),Math.round(es*r.x)+128,Math.round(es*r.y)+128,1+(0===a?0:a<0?-1:1)|(o*ns&63)<<2,o*ns>>6)}var os=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.features=[],this.hasPattern=!1,this.layoutVertexArray=new hi,this.indexArray=new Ti,this.programConfigurations=new la(Qo,t.layers,t.zoom),this.segments=new Vi,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function ss(t,e){return(t/e.tileTotal*(e.end-e.start)+e.start)*(is-1)}os.prototype.populate=function(t,e){this.features=[],this.hasPattern=Eo(\"line\",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a),c={sourceLayerIndex:s,index:o,geometry:l,properties:a.properties,type:a.type,patterns:{}};void 0!==a.id&&(c.id=a.id),this.hasPattern?this.features.push(Co(\"line\",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(a,l,o,s,this.index)}}},os.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},os.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var i=n[r],a=i.geometry;this.addFeature(i,a,i.index,e)}},os.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},os.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},os.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Qo),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},os.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},os.prototype.addFeature=function(t,e,r,n){for(var i=this.layers[0].layout,a=i.get(\"line-join\").evaluate(t,{}),o=i.get(\"line-cap\"),s=i.get(\"line-miter-limit\"),l=i.get(\"line-round-limit\"),c=0,u=e;c<u.length;c+=1){var h=u[c];this.addLine(h,t,a,o,s,l,r,n)}},os.prototype.addLine=function(t,e,r,n,i,a,o,s){var l=null;e.properties&&e.properties.hasOwnProperty(\"mapbox_clip_start\")&&e.properties.hasOwnProperty(\"mapbox_clip_end\")&&(l={start:e.properties.mapbox_clip_start,end:e.properties.mapbox_clip_end,tileTotal:void 0});for(var c=\"Polygon\"===ts[e.type],u=t.length;u>=2&&t[u-1].equals(t[u-2]);)u--;for(var h=0;h<u-1&&t[h].equals(t[h+1]);)h++;if(!(u<(c?3:2))){l&&(l.tileTotal=function(t,e,r){for(var n,i,a=0,o=h;o<r-1;o++)n=t[o],i=t[o+1],a+=n.dist(i);return a}(t,0,u)),\"bevel\"===r&&(i=1.05);var f=ha/(512*this.overscaling)*15,p=t[h],d=this.segments.prepareSegment(10*u,this.layoutVertexArray,this.indexArray);this.distance=0;var g,v,m,y=n,x=c?\"butt\":n,b=!0,_=void 0,w=void 0,k=void 0,T=void 0;this.e1=this.e2=this.e3=-1,c&&(g=t[u-2],T=p.sub(g)._unit()._perp());for(var A=h;A<u;A++)if(!(w=c&&A===u-1?t[h+1]:t[A+1])||!t[A].equals(w)){T&&(k=T),g&&(_=g),g=t[A],T=w?w.sub(g)._unit()._perp():k;var M=(k=k||T).add(T);0===M.x&&0===M.y||M._unit();var S=M.x*T.x+M.y*T.y,E=0!==S?1/S:1/0,C=S<rs&&_&&w;if(C&&A>h){var L=g.dist(_);if(L>2*f){var P=g.sub(g.sub(_)._mult(f/L)._round());this.distance+=P.dist(_),this.addCurrentVertex(P,this.distance,k.mult(1),0,0,!1,d,l),_=P}}var O=_&&w,z=O?r:w?y:x;if(O&&\"round\"===z&&(E<a?z=\"miter\":E<=2&&(z=\"fakeround\")),\"miter\"===z&&E>i&&(z=\"bevel\"),\"bevel\"===z&&(E>2&&(z=\"flipbevel\"),E<i&&(z=\"miter\")),_&&(this.distance+=g.dist(_)),\"miter\"===z)M._mult(E),this.addCurrentVertex(g,this.distance,M,0,0,!1,d,l);else if(\"flipbevel\"===z){if(E>100)M=T.clone().mult(-1);else{var I=k.x*T.y-k.y*T.x>0?-1:1,D=E*k.add(T).mag()/k.sub(T).mag();M._perp()._mult(D*I)}this.addCurrentVertex(g,this.distance,M,0,0,!1,d,l),this.addCurrentVertex(g,this.distance,M.mult(-1),0,0,!1,d,l)}else if(\"bevel\"===z||\"fakeround\"===z){var R=k.x*T.y-k.y*T.x>0,F=-Math.sqrt(E*E-1);if(R?(m=0,v=F):(v=0,m=F),b||this.addCurrentVertex(g,this.distance,k,v,m,!1,d,l),\"fakeround\"===z){for(var B=Math.floor(8*(.5-(S-.5))),N=void 0,j=0;j<B;j++)N=T.mult((j+1)/(B+1))._add(k)._unit(),this.addPieSliceVertex(g,this.distance,N,R,d,l);this.addPieSliceVertex(g,this.distance,M,R,d,l);for(var U=B-1;U>=0;U--)N=k.mult((U+1)/(B+1))._add(T)._unit(),this.addPieSliceVertex(g,this.distance,N,R,d,l)}w&&this.addCurrentVertex(g,this.distance,T,-v,-m,!1,d,l)}else\"butt\"===z?(b||this.addCurrentVertex(g,this.distance,k,0,0,!1,d,l),w&&this.addCurrentVertex(g,this.distance,T,0,0,!1,d,l)):\"square\"===z?(b||(this.addCurrentVertex(g,this.distance,k,1,1,!1,d,l),this.e1=this.e2=-1),w&&this.addCurrentVertex(g,this.distance,T,-1,-1,!1,d,l)):\"round\"===z&&(b||(this.addCurrentVertex(g,this.distance,k,0,0,!1,d,l),this.addCurrentVertex(g,this.distance,k,1,1,!0,d,l),this.e1=this.e2=-1),w&&(this.addCurrentVertex(g,this.distance,T,-1,-1,!0,d,l),this.addCurrentVertex(g,this.distance,T,0,0,!1,d,l)));if(C&&A<u-1){var V=g.dist(w);if(V>2*f){var q=g.add(w.sub(g)._mult(f/V)._round());this.distance+=q.dist(g),this.addCurrentVertex(q,this.distance,T.mult(1),0,0,!1,d,l),g=q}}b=!1}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,e,o,s)}},os.prototype.addCurrentVertex=function(t,e,r,n,i,a,o,s){var l,c=this.layoutVertexArray,u=this.indexArray;s&&(e=ss(e,s)),l=r.clone(),n&&l._sub(r.perp()._mult(n)),as(c,t,l,a,!1,n,e),this.e3=o.vertexLength++,this.e1>=0&&this.e2>=0&&(u.emplaceBack(this.e1,this.e2,this.e3),o.primitiveLength++),this.e1=this.e2,this.e2=this.e3,l=r.mult(-1),i&&l._sub(r.perp()._mult(i)),as(c,t,l,a,!0,-i,e),this.e3=o.vertexLength++,this.e1>=0&&this.e2>=0&&(u.emplaceBack(this.e1,this.e2,this.e3),o.primitiveLength++),this.e1=this.e2,this.e2=this.e3,e>is/2&&!s&&(this.distance=0,this.addCurrentVertex(t,this.distance,r,n,i,a,o))},os.prototype.addPieSliceVertex=function(t,e,r,n,i,a){r=r.mult(n?-1:1);var o=this.layoutVertexArray,s=this.indexArray;a&&(e=ss(e,a)),as(o,t,r,!1,n,0,e),this.e3=i.vertexLength++,this.e1>=0&&this.e2>=0&&(s.emplaceBack(this.e1,this.e2,this.e3),i.primitiveLength++),n?this.e2=this.e3:this.e1=this.e3},kn(\"LineBucket\",os,{omit:[\"layers\",\"features\"]});var ls=new ei({\"line-cap\":new Jn(It.layout_line[\"line-cap\"]),\"line-join\":new Kn(It.layout_line[\"line-join\"]),\"line-miter-limit\":new Jn(It.layout_line[\"line-miter-limit\"]),\"line-round-limit\":new Jn(It.layout_line[\"line-round-limit\"])}),cs={paint:new ei({\"line-opacity\":new Kn(It.paint_line[\"line-opacity\"]),\"line-color\":new Kn(It.paint_line[\"line-color\"]),\"line-translate\":new Jn(It.paint_line[\"line-translate\"]),\"line-translate-anchor\":new Jn(It.paint_line[\"line-translate-anchor\"]),\"line-width\":new Kn(It.paint_line[\"line-width\"]),\"line-gap-width\":new Kn(It.paint_line[\"line-gap-width\"]),\"line-offset\":new Kn(It.paint_line[\"line-offset\"]),\"line-blur\":new Kn(It.paint_line[\"line-blur\"]),\"line-dasharray\":new Qn(It.paint_line[\"line-dasharray\"]),\"line-pattern\":new $n(It.paint_line[\"line-pattern\"]),\"line-gradient\":new ti(It.paint_line[\"line-gradient\"])}),layout:ls},us=new(function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(e,r){return r=new Un(Math.floor(r.zoom),{now:r.now,fadeDuration:r.fadeDuration,zoomHistory:r.zoomHistory,transition:r.transition}),t.prototype.possiblyEvaluate.call(this,e,r)},e.prototype.evaluate=function(e,r,n,i){return r=h({},r,{zoom:Math.floor(r.zoom)}),t.prototype.evaluate.call(this,e,r,n,i)},e}(Kn))(cs.paint.properties[\"line-width\"].specification);us.useIntegerZoom=!0;var hs=function(t){function e(e){t.call(this,e,cs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"line-gradient\"===t&&this._updateGradient()},e.prototype._updateGradient=function(){var t=this._transitionablePaint._values[\"line-gradient\"].value.expression;this.gradient=Ya(t,\"lineProgress\"),this.gradientTexture=null},e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e),this.paint._values[\"line-floorwidth\"]=us.possiblyEvaluate(this._transitioningPaint._values[\"line-width\"].value,e)},e.prototype.createBucket=function(t){return new os(t)},e.prototype.queryRadius=function(t){var e=t,r=fs(Sa(\"line-width\",this,e),Sa(\"line-gap-width\",this,e)),n=Sa(\"line-offset\",this,e);return r/2+Math.abs(n)+Ea(this.paint.get(\"line-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s){var l=Ca(t,this.paint.get(\"line-translate\"),this.paint.get(\"line-translate-anchor\"),o.angle,s),c=s/2*fs(this.paint.get(\"line-width\").evaluate(e,r),this.paint.get(\"line-gap-width\").evaluate(e,r)),u=this.paint.get(\"line-offset\").evaluate(e,r);return u&&(n=function(t,e){for(var r=[],n=new i(0,0),a=0;a<t.length;a++){for(var o=t[a],s=[],l=0;l<o.length;l++){var c=o[l-1],u=o[l],h=o[l+1],f=0===l?n:u.sub(c)._unit()._perp(),p=l===o.length-1?n:h.sub(u)._unit()._perp(),d=f._add(p)._unit(),g=d.x*p.x+d.y*p.y;d._mult(1/g),s.push(d._mult(e)._add(u))}r.push(s)}return r}(n,u*s)),function(t,e,r){for(var n=0;n<e.length;n++){var i=e[n];if(t.length>=3)for(var a=0;a<i.length;a++)if(Aa(t,i[a]))return!0;if(xa(t,i,r))return!0}return!1}(l,n,c)},e.prototype.isTileClipped=function(){return!0},e}(ri);function fs(t,e){return e>0?e+2*t:t}var ps=oi([{name:\"a_pos_offset\",components:4,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint16\"}]),ds=oi([{name:\"a_projected_pos\",components:3,type:\"Float32\"}],4),gs=(oi([{name:\"a_fade_opacity\",components:1,type:\"Uint32\"}],4),oi([{name:\"a_placed\",components:2,type:\"Uint8\"},{name:\"a_shift\",components:2,type:\"Float32\"}])),vs=(oi([{type:\"Int16\",name:\"anchorPointX\"},{type:\"Int16\",name:\"anchorPointY\"},{type:\"Int16\",name:\"x1\"},{type:\"Int16\",name:\"y1\"},{type:\"Int16\",name:\"x2\"},{type:\"Int16\",name:\"y2\"},{type:\"Uint32\",name:\"featureIndex\"},{type:\"Uint16\",name:\"sourceLayerIndex\"},{type:\"Uint16\",name:\"bucketIndex\"},{type:\"Int16\",name:\"radius\"},{type:\"Int16\",name:\"signedDistanceFromAnchor\"}]),oi([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4)),ms=oi([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4);function ys(t,e,r){return t.sections.forEach(function(t){t.text=function(t,e,r){var n=e.layout.get(\"text-transform\").evaluate(r,{});return\"uppercase\"===n?t=t.toLocaleUpperCase():\"lowercase\"===n&&(t=t.toLocaleLowerCase()),jn.applyArabicShaping&&(t=jn.applyArabicShaping(t)),t}(t.text,e,r)}),t}oi([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Uint16\",name:\"glyphStartIndex\"},{type:\"Uint16\",name:\"numGlyphs\"},{type:\"Uint32\",name:\"vertexStartIndex\"},{type:\"Uint32\",name:\"lineStartIndex\"},{type:\"Uint32\",name:\"lineLength\"},{type:\"Uint16\",name:\"segment\"},{type:\"Uint16\",name:\"lowerSize\"},{type:\"Uint16\",name:\"upperSize\"},{type:\"Float32\",name:\"lineOffsetX\"},{type:\"Float32\",name:\"lineOffsetY\"},{type:\"Uint8\",name:\"writingMode\"},{type:\"Uint8\",name:\"hidden\"},{type:\"Uint32\",name:\"crossTileID\"}]),oi([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Int16\",name:\"rightJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"centerJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"leftJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"verticalPlacedTextSymbolIndex\"},{type:\"Uint16\",name:\"key\"},{type:\"Uint16\",name:\"textBoxStartIndex\"},{type:\"Uint16\",name:\"textBoxEndIndex\"},{type:\"Uint16\",name:\"iconBoxStartIndex\"},{type:\"Uint16\",name:\"iconBoxEndIndex\"},{type:\"Uint16\",name:\"featureIndex\"},{type:\"Uint16\",name:\"numHorizontalGlyphVertices\"},{type:\"Uint16\",name:\"numVerticalGlyphVertices\"},{type:\"Uint16\",name:\"numIconVertices\"},{type:\"Uint32\",name:\"crossTileID\"},{type:\"Float32\",name:\"textBoxScale\"},{type:\"Float32\",name:\"radialTextOffset\"}]),oi([{type:\"Float32\",name:\"offsetX\"}]),oi([{type:\"Int16\",name:\"x\"},{type:\"Int16\",name:\"y\"},{type:\"Int16\",name:\"tileUnitDistanceFromAnchor\"}]);var xs={\"!\":\"\\ufe15\",\"#\":\"\\uff03\",$:\"\\uff04\",\"%\":\"\\uff05\",\"&\":\"\\uff06\",\"(\":\"\\ufe35\",\")\":\"\\ufe36\",\"*\":\"\\uff0a\",\"+\":\"\\uff0b\",\",\":\"\\ufe10\",\"-\":\"\\ufe32\",\".\":\"\\u30fb\",\"/\":\"\\uff0f\",\":\":\"\\ufe13\",\";\":\"\\ufe14\",\"<\":\"\\ufe3f\",\"=\":\"\\uff1d\",\">\":\"\\ufe40\",\"?\":\"\\ufe16\",\"@\":\"\\uff20\",\"[\":\"\\ufe47\",\"\\\\\":\"\\uff3c\",\"]\":\"\\ufe48\",\"^\":\"\\uff3e\",_:\"\\ufe33\",\"`\":\"\\uff40\",\"{\":\"\\ufe37\",\"|\":\"\\u2015\",\"}\":\"\\ufe38\",\"~\":\"\\uff5e\",\"\\xa2\":\"\\uffe0\",\"\\xa3\":\"\\uffe1\",\"\\xa5\":\"\\uffe5\",\"\\xa6\":\"\\uffe4\",\"\\xac\":\"\\uffe2\",\"\\xaf\":\"\\uffe3\",\"\\u2013\":\"\\ufe32\",\"\\u2014\":\"\\ufe31\",\"\\u2018\":\"\\ufe43\",\"\\u2019\":\"\\ufe44\",\"\\u201c\":\"\\ufe41\",\"\\u201d\":\"\\ufe42\",\"\\u2026\":\"\\ufe19\",\"\\u2027\":\"\\u30fb\",\"\\u20a9\":\"\\uffe6\",\"\\u3001\":\"\\ufe11\",\"\\u3002\":\"\\ufe12\",\"\\u3008\":\"\\ufe3f\",\"\\u3009\":\"\\ufe40\",\"\\u300a\":\"\\ufe3d\",\"\\u300b\":\"\\ufe3e\",\"\\u300c\":\"\\ufe41\",\"\\u300d\":\"\\ufe42\",\"\\u300e\":\"\\ufe43\",\"\\u300f\":\"\\ufe44\",\"\\u3010\":\"\\ufe3b\",\"\\u3011\":\"\\ufe3c\",\"\\u3014\":\"\\ufe39\",\"\\u3015\":\"\\ufe3a\",\"\\u3016\":\"\\ufe17\",\"\\u3017\":\"\\ufe18\",\"\\uff01\":\"\\ufe15\",\"\\uff08\":\"\\ufe35\",\"\\uff09\":\"\\ufe36\",\"\\uff0c\":\"\\ufe10\",\"\\uff0d\":\"\\ufe32\",\"\\uff0e\":\"\\u30fb\",\"\\uff1a\":\"\\ufe13\",\"\\uff1b\":\"\\ufe14\",\"\\uff1c\":\"\\ufe3f\",\"\\uff1e\":\"\\ufe40\",\"\\uff1f\":\"\\ufe16\",\"\\uff3b\":\"\\ufe47\",\"\\uff3d\":\"\\ufe48\",\"\\uff3f\":\"\\ufe33\",\"\\uff5b\":\"\\ufe37\",\"\\uff5c\":\"\\u2015\",\"\\uff5d\":\"\\ufe38\",\"\\uff5f\":\"\\ufe35\",\"\\uff60\":\"\\ufe36\",\"\\uff61\":\"\\ufe12\",\"\\uff62\":\"\\ufe41\",\"\\uff63\":\"\\ufe42\"},bs=function(t){function e(e,r,n,i){t.call(this,e,r),this.angle=n,void 0!==i&&(this.segment=i)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.clone=function(){return new e(this.x,this.y,this.angle,this.segment)},e}(i);kn(\"Anchor\",bs);var _s=256;function ws(t,e){var r=e.expression;if(\"constant\"===r.kind)return{kind:\"constant\",layoutSize:r.evaluate(new Un(t+1))};if(\"source\"===r.kind)return{kind:\"source\"};for(var n=r.zoomStops,i=r.interpolationType,a=0;a<n.length&&n[a]<=t;)a++;for(var o=a=Math.max(0,a-1);o<n.length&&n[o]<t+1;)o++;o=Math.min(n.length-1,o);var s=n[a],l=n[o];return\"composite\"===r.kind?{kind:\"composite\",minZoom:s,maxZoom:l,interpolationType:i}:{kind:\"camera\",minZoom:s,maxZoom:l,minSize:r.evaluate(new Un(s)),maxSize:r.evaluate(new Un(l)),interpolationType:i}}function ks(t,e,r){var n=e.uSize,i=e.uSizeT,a=r.lowerSize,o=r.upperSize;return\"source\"===t.kind?a/_s:\"composite\"===t.kind?Ee(a/_s,o/_s,i):n}function Ts(t,e){var r=0,n=0;if(\"constant\"===t.kind)n=t.layoutSize;else if(\"source\"!==t.kind){var i=t.interpolationType,a=t.minZoom,o=t.maxZoom,s=i?c(Xe.interpolationFactor(i,e,a,o),0,1):0;\"camera\"===t.kind?n=Ee(t.minSize,t.maxSize,s):r=s}return{uSizeT:r,uSize:n}}var As=Object.freeze({getSizeData:ws,evaluateSizeForFeature:ks,evaluateSizeForZoom:Ts,SIZE_PACK_FACTOR:_s}),Ms=Vo.VectorTileFeature.types,Ss=[{name:\"a_fade_opacity\",components:1,type:\"Uint8\",offset:0}];function Es(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,Math.round(32*n),Math.round(32*i),a,o,s?s[0]:0,s?s[1]:0)}function Cs(t,e,r){t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r)}var Ls=function(t){this.layoutVertexArray=new pi,this.indexArray=new Ti,this.programConfigurations=t,this.segments=new Vi,this.dynamicLayoutVertexArray=new di,this.opacityVertexArray=new gi,this.placedSymbolArray=new Oi};Ls.prototype.upload=function(t,e,r,n){r&&(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,ps.members),this.indexBuffer=t.createIndexBuffer(this.indexArray,e),this.dynamicLayoutVertexBuffer=t.createVertexBuffer(this.dynamicLayoutVertexArray,ds.members,!0),this.opacityVertexBuffer=t.createVertexBuffer(this.opacityVertexArray,Ss,!0),this.opacityVertexBuffer.itemSize=1),(r||n)&&this.programConfigurations.upload(t)},Ls.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.dynamicLayoutVertexBuffer.destroy(),this.opacityVertexBuffer.destroy())},kn(\"SymbolBuffers\",Ls);var Ps=function(t,e,r){this.layoutVertexArray=new t,this.layoutAttributes=e,this.indexArray=new r,this.segments=new Vi,this.collisionVertexArray=new yi};Ps.prototype.upload=function(t){this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,this.layoutAttributes),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.collisionVertexBuffer=t.createVertexBuffer(this.collisionVertexArray,gs.members,!0)},Ps.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.segments.destroy(),this.collisionVertexBuffer.destroy())},kn(\"CollisionBuffers\",Ps);var Os=function(t){this.collisionBoxArray=t.collisionBoxArray,this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.pixelRatio=t.pixelRatio,this.sourceLayerIndex=t.sourceLayerIndex,this.hasPattern=!1;var e=this.layers[0]._unevaluatedLayout._values;this.textSizeData=ws(this.zoom,e[\"text-size\"]),this.iconSizeData=ws(this.zoom,e[\"icon-size\"]);var r=this.layers[0].layout,n=r.get(\"symbol-sort-key\"),i=r.get(\"symbol-z-order\");this.sortFeaturesByKey=\"viewport-y\"!==i&&void 0!==n.constantOr(1);var a=\"viewport-y\"===i||\"auto\"===i&&!this.sortFeaturesByKey;this.sortFeaturesByY=a&&(r.get(\"text-allow-overlap\")||r.get(\"icon-allow-overlap\")||r.get(\"text-ignore-placement\")||r.get(\"icon-ignore-placement\")),this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id}),this.sourceID=t.sourceID};Os.prototype.createArrays=function(){this.text=new Ls(new la(ps.members,this.layers,this.zoom,function(t){return/^text/.test(t)})),this.icon=new Ls(new la(ps.members,this.layers,this.zoom,function(t){return/^icon/.test(t)})),this.collisionBox=new Ps(mi,vs.members,Ai),this.collisionCircle=new Ps(mi,ms.members,Ti),this.glyphOffsetArray=new Ri,this.lineVertexArray=new Bi,this.symbolInstances=new Ii},Os.prototype.calculateGlyphDependencies=function(t,e,r,n){for(var i=0;i<t.length;i++)if(e[t.charCodeAt(i)]=!0,r&&n){var a=xs[t.charAt(i)];a&&(e[a.charCodeAt(0)]=!0)}},Os.prototype.populate=function(t,e){var r=this.layers[0],n=r.layout,i=n.get(\"text-font\"),a=n.get(\"text-field\"),o=n.get(\"icon-image\"),s=(\"constant\"!==a.value.kind||a.value.value.toString().length>0)&&(\"constant\"!==i.value.kind||i.value.value.length>0),l=\"constant\"!==o.value.kind||o.value.value&&o.value.value.length>0,c=n.get(\"symbol-sort-key\");if(this.features=[],s||l){for(var u=e.iconDependencies,h=e.glyphDependencies,f=new Un(this.zoom),p=0,d=t;p<d.length;p+=1){var g=d[p],v=g.feature,m=g.index,y=g.sourceLayerIndex;if(r._featureFilter(f,v)){var x=void 0;if(s){var b=r.getValueAndResolveTokens(\"text-field\",v);x=ys(b instanceof oe?b:oe.fromString(b),r,v)}var _=void 0;if(l&&(_=r.getValueAndResolveTokens(\"icon-image\",v)),x||_){var w=this.sortFeaturesByKey?c.evaluate(v,{}):void 0,k={text:x,icon:_,index:m,sourceLayerIndex:y,geometry:pa(v),properties:v.properties,type:Ms[v.type],sortKey:w};if(void 0!==v.id&&(k.id=v.id),this.features.push(k),_&&(u[_]=!0),x)for(var T=i.evaluate(v,{}).join(\",\"),A=\"map\"===n.get(\"text-rotation-alignment\")&&\"point\"!==n.get(\"symbol-placement\"),M=0,S=x.sections;M<S.length;M+=1){var E=S[M],C=Cn(x.toString()),L=E.fontStack||T,P=h[L]=h[L]||{};this.calculateGlyphDependencies(E.text,P,A,C)}}}}\"line\"===n.get(\"symbol-placement\")&&(this.features=function(t){var e={},r={},n=[],i=0;function a(e){n.push(t[e]),i++}function o(t,e,i){var a=r[t];return delete r[t],r[e]=a,n[a].geometry[0].pop(),n[a].geometry[0]=n[a].geometry[0].concat(i[0]),a}function s(t,r,i){var a=e[r];return delete e[r],e[t]=a,n[a].geometry[0].shift(),n[a].geometry[0]=i[0].concat(n[a].geometry[0]),a}function l(t,e,r){var n=r?e[0][e[0].length-1]:e[0][0];return t+\":\"+n.x+\":\"+n.y}for(var c=0;c<t.length;c++){var u=t[c],h=u.geometry,f=u.text?u.text.toString():null;if(f){var p=l(f,h),d=l(f,h,!0);if(p in r&&d in e&&r[p]!==e[d]){var g=s(p,d,h),v=o(p,d,n[g].geometry);delete e[p],delete r[d],r[l(f,n[v].geometry,!0)]=v,n[g].geometry=null}else p in r?o(p,d,h):d in e?s(p,d,h):(a(c),e[p]=i-1,r[d]=i-1)}else a(c)}return n.filter(function(t){return t.geometry})}(this.features)),this.sortFeaturesByKey&&this.features.sort(function(t,e){return t.sortKey-e.sortKey})}},Os.prototype.update=function(t,e,r){this.stateDependentLayers.length&&(this.text.programConfigurations.updatePaintArrays(t,e,this.layers,r),this.icon.programConfigurations.updatePaintArrays(t,e,this.layers,r))},Os.prototype.isEmpty=function(){return 0===this.symbolInstances.length},Os.prototype.uploadPending=function(){return!this.uploaded||this.text.programConfigurations.needsUpload||this.icon.programConfigurations.needsUpload},Os.prototype.upload=function(t){this.uploaded||(this.collisionBox.upload(t),this.collisionCircle.upload(t)),this.text.upload(t,this.sortFeaturesByY,!this.uploaded,this.text.programConfigurations.needsUpload),this.icon.upload(t,this.sortFeaturesByY,!this.uploaded,this.icon.programConfigurations.needsUpload),this.uploaded=!0},Os.prototype.destroy=function(){this.text.destroy(),this.icon.destroy(),this.collisionBox.destroy(),this.collisionCircle.destroy()},Os.prototype.addToLineVertexArray=function(t,e){var r=this.lineVertexArray.length;if(void 0!==t.segment){for(var n=t.dist(e[t.segment+1]),i=t.dist(e[t.segment]),a={},o=t.segment+1;o<e.length;o++)a[o]={x:e[o].x,y:e[o].y,tileUnitDistanceFromAnchor:n},o<e.length-1&&(n+=e[o+1].dist(e[o]));for(var s=t.segment||0;s>=0;s--)a[s]={x:e[s].x,y:e[s].y,tileUnitDistanceFromAnchor:i},s>0&&(i+=e[s-1].dist(e[s]));for(var l=0;l<e.length;l++){var c=a[l];this.lineVertexArray.emplaceBack(c.x,c.y,c.tileUnitDistanceFromAnchor)}}return{lineStartIndex:r,lineLength:this.lineVertexArray.length-r}},Os.prototype.addSymbols=function(t,e,r,n,i,a,o,s,l,c){for(var u=t.indexArray,h=t.layoutVertexArray,f=t.dynamicLayoutVertexArray,p=t.segments.prepareSegment(4*e.length,t.layoutVertexArray,t.indexArray,a.sortKey),d=this.glyphOffsetArray.length,g=p.vertexLength,v=0,m=e;v<m.length;v+=1){var y=m[v],x=y.tl,b=y.tr,_=y.bl,w=y.br,k=y.tex,T=p.vertexLength,A=y.glyphOffset[1];Es(h,s.x,s.y,x.x,A+x.y,k.x,k.y,r),Es(h,s.x,s.y,b.x,A+b.y,k.x+k.w,k.y,r),Es(h,s.x,s.y,_.x,A+_.y,k.x,k.y+k.h,r),Es(h,s.x,s.y,w.x,A+w.y,k.x+k.w,k.y+k.h,r),Cs(f,s,0),u.emplaceBack(T,T+1,T+2),u.emplaceBack(T+1,T+2,T+3),p.vertexLength+=4,p.primitiveLength+=2,this.glyphOffsetArray.emplaceBack(y.glyphOffset[0])}t.placedSymbolArray.emplaceBack(s.x,s.y,d,this.glyphOffsetArray.length-d,g,l,c,s.segment,r?r[0]:0,r?r[1]:0,n[0],n[1],o,!1,0),t.programConfigurations.populatePaintArrays(t.layoutVertexArray.length,a,a.index,{})},Os.prototype._addCollisionDebugVertex=function(t,e,r,n,i,a){return e.emplaceBack(0,0),t.emplaceBack(r.x,r.y,n,i,Math.round(a.x),Math.round(a.y))},Os.prototype.addCollisionDebugVertices=function(t,e,r,n,a,o,s,l){var c=a.segments.prepareSegment(4,a.layoutVertexArray,a.indexArray),u=c.vertexLength,h=a.layoutVertexArray,f=a.collisionVertexArray,p=s.anchorX,d=s.anchorY;if(this._addCollisionDebugVertex(h,f,o,p,d,new i(t,e)),this._addCollisionDebugVertex(h,f,o,p,d,new i(r,e)),this._addCollisionDebugVertex(h,f,o,p,d,new i(r,n)),this._addCollisionDebugVertex(h,f,o,p,d,new i(t,n)),c.vertexLength+=4,l){var g=a.indexArray;g.emplaceBack(u,u+1,u+2),g.emplaceBack(u,u+2,u+3),c.primitiveLength+=2}else{var v=a.indexArray;v.emplaceBack(u,u+1),v.emplaceBack(u+1,u+2),v.emplaceBack(u+2,u+3),v.emplaceBack(u+3,u),c.primitiveLength+=4}},Os.prototype.addDebugCollisionBoxes=function(t,e,r){for(var n=t;n<e;n++){var i=this.collisionBoxArray.get(n),a=i.x1,o=i.y1,s=i.x2,l=i.y2,c=i.radius>0;this.addCollisionDebugVertices(a,o,s,l,c?this.collisionCircle:this.collisionBox,i.anchorPoint,r,c)}},Os.prototype.generateCollisionDebugBuffers=function(){for(var t=0;t<this.symbolInstances.length;t++){var e=this.symbolInstances.get(t);this.addDebugCollisionBoxes(e.textBoxStartIndex,e.textBoxEndIndex,e),this.addDebugCollisionBoxes(e.iconBoxStartIndex,e.iconBoxEndIndex,e)}},Os.prototype._deserializeCollisionBoxesForSymbol=function(t,e,r,n,i){for(var a={},o=e;o<r;o++){var s=t.get(o);if(0===s.radius){a.textBox={x1:s.x1,y1:s.y1,x2:s.x2,y2:s.y2,anchorPointX:s.anchorPointX,anchorPointY:s.anchorPointY},a.textFeatureIndex=s.featureIndex;break}a.textCircles||(a.textCircles=[],a.textFeatureIndex=s.featureIndex),a.textCircles.push(s.anchorPointX,s.anchorPointY,s.radius,s.signedDistanceFromAnchor,1)}for(var l=n;l<i;l++){var c=t.get(l);if(0===c.radius){a.iconBox={x1:c.x1,y1:c.y1,x2:c.x2,y2:c.y2,anchorPointX:c.anchorPointX,anchorPointY:c.anchorPointY},a.iconFeatureIndex=c.featureIndex;break}}return a},Os.prototype.deserializeCollisionBoxes=function(t){this.collisionArrays=[];for(var e=0;e<this.symbolInstances.length;e++){var r=this.symbolInstances.get(e);this.collisionArrays.push(this._deserializeCollisionBoxesForSymbol(t,r.textBoxStartIndex,r.textBoxEndIndex,r.iconBoxStartIndex,r.iconBoxEndIndex))}},Os.prototype.hasTextData=function(){return this.text.segments.get().length>0},Os.prototype.hasIconData=function(){return this.icon.segments.get().length>0},Os.prototype.hasCollisionBoxData=function(){return this.collisionBox.segments.get().length>0},Os.prototype.hasCollisionCircleData=function(){return this.collisionCircle.segments.get().length>0},Os.prototype.addIndicesForPlacedTextSymbol=function(t){for(var e=this.text.placedSymbolArray.get(t),r=e.vertexStartIndex+4*e.numGlyphs,n=e.vertexStartIndex;n<r;n+=4)this.text.indexArray.emplaceBack(n,n+1,n+2),this.text.indexArray.emplaceBack(n+1,n+2,n+3)},Os.prototype.getSortedSymbolIndexes=function(t){if(this.sortedAngle===t&&void 0!==this.symbolInstanceIndexes)return this.symbolInstanceIndexes;for(var e=Math.sin(t),r=Math.cos(t),n=[],i=[],a=[],o=0;o<this.symbolInstances.length;++o){a.push(o);var s=this.symbolInstances.get(o);n.push(0|Math.round(e*s.anchorX+r*s.anchorY)),i.push(s.featureIndex)}return a.sort(function(t,e){return n[t]-n[e]||i[e]-i[t]}),a},Os.prototype.sortFeatures=function(t){var e=this;if(this.sortFeaturesByY&&this.sortedAngle!==t&&!(this.text.segments.get().length>1||this.icon.segments.get().length>1)){this.symbolInstanceIndexes=this.getSortedSymbolIndexes(t),this.sortedAngle=t,this.text.indexArray.clear(),this.icon.indexArray.clear(),this.featureSortOrder=[];for(var r=0,n=this.symbolInstanceIndexes;r<n.length;r+=1){var i=n[r],a=this.symbolInstances.get(i);this.featureSortOrder.push(a.featureIndex),[a.rightJustifiedTextSymbolIndex,a.centerJustifiedTextSymbolIndex,a.leftJustifiedTextSymbolIndex].forEach(function(t,r,n){t>=0&&n.indexOf(t)===r&&e.addIndicesForPlacedTextSymbol(t)}),a.verticalPlacedTextSymbolIndex>=0&&this.addIndicesForPlacedTextSymbol(a.verticalPlacedTextSymbolIndex);var o=this.icon.placedSymbolArray.get(i);if(o.numGlyphs){var s=o.vertexStartIndex;this.icon.indexArray.emplaceBack(s,s+1,s+2),this.icon.indexArray.emplaceBack(s+1,s+2,s+3)}}this.text.indexBuffer&&this.text.indexBuffer.updateData(this.text.indexArray),this.icon.indexBuffer&&this.icon.indexBuffer.updateData(this.icon.indexArray)}},kn(\"SymbolBucket\",Os,{omit:[\"layers\",\"collisionBoxArray\",\"features\",\"compareText\"]}),Os.MAX_GLYPHS=65535,Os.addDynamicAttributes=Cs;var zs=new ei({\"symbol-placement\":new Jn(It.layout_symbol[\"symbol-placement\"]),\"symbol-spacing\":new Jn(It.layout_symbol[\"symbol-spacing\"]),\"symbol-avoid-edges\":new Jn(It.layout_symbol[\"symbol-avoid-edges\"]),\"symbol-sort-key\":new Kn(It.layout_symbol[\"symbol-sort-key\"]),\"symbol-z-order\":new Jn(It.layout_symbol[\"symbol-z-order\"]),\"icon-allow-overlap\":new Jn(It.layout_symbol[\"icon-allow-overlap\"]),\"icon-ignore-placement\":new Jn(It.layout_symbol[\"icon-ignore-placement\"]),\"icon-optional\":new Jn(It.layout_symbol[\"icon-optional\"]),\"icon-rotation-alignment\":new Jn(It.layout_symbol[\"icon-rotation-alignment\"]),\"icon-size\":new Kn(It.layout_symbol[\"icon-size\"]),\"icon-text-fit\":new Jn(It.layout_symbol[\"icon-text-fit\"]),\"icon-text-fit-padding\":new Jn(It.layout_symbol[\"icon-text-fit-padding\"]),\"icon-image\":new Kn(It.layout_symbol[\"icon-image\"]),\"icon-rotate\":new Kn(It.layout_symbol[\"icon-rotate\"]),\"icon-padding\":new Jn(It.layout_symbol[\"icon-padding\"]),\"icon-keep-upright\":new Jn(It.layout_symbol[\"icon-keep-upright\"]),\"icon-offset\":new Kn(It.layout_symbol[\"icon-offset\"]),\"icon-anchor\":new Kn(It.layout_symbol[\"icon-anchor\"]),\"icon-pitch-alignment\":new Jn(It.layout_symbol[\"icon-pitch-alignment\"]),\"text-pitch-alignment\":new Jn(It.layout_symbol[\"text-pitch-alignment\"]),\"text-rotation-alignment\":new Jn(It.layout_symbol[\"text-rotation-alignment\"]),\"text-field\":new Kn(It.layout_symbol[\"text-field\"]),\"text-font\":new Kn(It.layout_symbol[\"text-font\"]),\"text-size\":new Kn(It.layout_symbol[\"text-size\"]),\"text-max-width\":new Kn(It.layout_symbol[\"text-max-width\"]),\"text-line-height\":new Jn(It.layout_symbol[\"text-line-height\"]),\"text-letter-spacing\":new Kn(It.layout_symbol[\"text-letter-spacing\"]),\"text-justify\":new Kn(It.layout_symbol[\"text-justify\"]),\"text-radial-offset\":new Kn(It.layout_symbol[\"text-radial-offset\"]),\"text-variable-anchor\":new Jn(It.layout_symbol[\"text-variable-anchor\"]),\"text-anchor\":new Kn(It.layout_symbol[\"text-anchor\"]),\"text-max-angle\":new Jn(It.layout_symbol[\"text-max-angle\"]),\"text-rotate\":new Kn(It.layout_symbol[\"text-rotate\"]),\"text-padding\":new Jn(It.layout_symbol[\"text-padding\"]),\"text-keep-upright\":new Jn(It.layout_symbol[\"text-keep-upright\"]),\"text-transform\":new Kn(It.layout_symbol[\"text-transform\"]),\"text-offset\":new Kn(It.layout_symbol[\"text-offset\"]),\"text-allow-overlap\":new Jn(It.layout_symbol[\"text-allow-overlap\"]),\"text-ignore-placement\":new Jn(It.layout_symbol[\"text-ignore-placement\"]),\"text-optional\":new Jn(It.layout_symbol[\"text-optional\"])}),Is={paint:new ei({\"icon-opacity\":new Kn(It.paint_symbol[\"icon-opacity\"]),\"icon-color\":new Kn(It.paint_symbol[\"icon-color\"]),\"icon-halo-color\":new Kn(It.paint_symbol[\"icon-halo-color\"]),\"icon-halo-width\":new Kn(It.paint_symbol[\"icon-halo-width\"]),\"icon-halo-blur\":new Kn(It.paint_symbol[\"icon-halo-blur\"]),\"icon-translate\":new Jn(It.paint_symbol[\"icon-translate\"]),\"icon-translate-anchor\":new Jn(It.paint_symbol[\"icon-translate-anchor\"]),\"text-opacity\":new Kn(It.paint_symbol[\"text-opacity\"]),\"text-color\":new Kn(It.paint_symbol[\"text-color\"]),\"text-halo-color\":new Kn(It.paint_symbol[\"text-halo-color\"]),\"text-halo-width\":new Kn(It.paint_symbol[\"text-halo-width\"]),\"text-halo-blur\":new Kn(It.paint_symbol[\"text-halo-blur\"]),\"text-translate\":new Jn(It.paint_symbol[\"text-translate\"]),\"text-translate-anchor\":new Jn(It.paint_symbol[\"text-translate-anchor\"])}),layout:zs},Ds=function(t){function e(e){t.call(this,e,Is)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e),\"auto\"===this.layout.get(\"icon-rotation-alignment\")&&(\"point\"!==this.layout.get(\"symbol-placement\")?this.layout._values[\"icon-rotation-alignment\"]=\"map\":this.layout._values[\"icon-rotation-alignment\"]=\"viewport\"),\"auto\"===this.layout.get(\"text-rotation-alignment\")&&(\"point\"!==this.layout.get(\"symbol-placement\")?this.layout._values[\"text-rotation-alignment\"]=\"map\":this.layout._values[\"text-rotation-alignment\"]=\"viewport\"),\"auto\"===this.layout.get(\"text-pitch-alignment\")&&(this.layout._values[\"text-pitch-alignment\"]=this.layout.get(\"text-rotation-alignment\")),\"auto\"===this.layout.get(\"icon-pitch-alignment\")&&(this.layout._values[\"icon-pitch-alignment\"]=this.layout.get(\"icon-rotation-alignment\"))},e.prototype.getValueAndResolveTokens=function(t,e){var r,n=this.layout.get(t).evaluate(e,{}),i=this._unevaluatedLayout._values[t];return i.isDataDriven()||Pr(i.value)?n:(r=e.properties,n.replace(/{([^{}]+)}/g,function(t,e){return e in r?String(r[e]):\"\"}))},e.prototype.createBucket=function(t){return new Os(t)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e}(ri),Rs={paint:new ei({\"background-color\":new Jn(It.paint_background[\"background-color\"]),\"background-pattern\":new Qn(It.paint_background[\"background-pattern\"]),\"background-opacity\":new Jn(It.paint_background[\"background-opacity\"])})},Fs=function(t){function e(e){t.call(this,e,Rs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ri),Bs={paint:new ei({\"raster-opacity\":new Jn(It.paint_raster[\"raster-opacity\"]),\"raster-hue-rotate\":new Jn(It.paint_raster[\"raster-hue-rotate\"]),\"raster-brightness-min\":new Jn(It.paint_raster[\"raster-brightness-min\"]),\"raster-brightness-max\":new Jn(It.paint_raster[\"raster-brightness-max\"]),\"raster-saturation\":new Jn(It.paint_raster[\"raster-saturation\"]),\"raster-contrast\":new Jn(It.paint_raster[\"raster-contrast\"]),\"raster-resampling\":new Jn(It.paint_raster[\"raster-resampling\"]),\"raster-fade-duration\":new Jn(It.paint_raster[\"raster-fade-duration\"])})},Ns=function(t){function e(e){t.call(this,e,Bs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ri),js=function(t){function e(e){t.call(this,e,{}),this.implementation=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.is3D=function(){return\"3d\"===this.implementation.renderingMode},e.prototype.hasOffscreenPass=function(){return void 0!==this.implementation.prerender},e.prototype.recalculate=function(){},e.prototype.updateTransitions=function(){},e.prototype.hasTransition=function(){},e.prototype.serialize=function(){},e.prototype.onAdd=function(t){this.implementation.onAdd&&this.implementation.onAdd(t,t.painter.context.gl)},e.prototype.onRemove=function(t){this.implementation.onRemove&&this.implementation.onRemove(t,t.painter.context.gl)},e}(ri),Us={circle:Fa,heatmap:Wa,hillshade:Za,fill:Oo,\"fill-extrusion\":Jo,line:hs,symbol:Ds,background:Fs,raster:Ns};function Vs(t){for(var e=0,r=0,n=0,i=t;n<i.length;n+=1){var a=i[n];e+=a.w*a.h,r=Math.max(r,a.w)}t.sort(function(t,e){return e.h-t.h});for(var o=[{x:0,y:0,w:Math.max(Math.ceil(Math.sqrt(e/.95)),r),h:1/0}],s=0,l=0,c=0,u=t;c<u.length;c+=1)for(var h=u[c],f=o.length-1;f>=0;f--){var p=o[f];if(!(h.w>p.w||h.h>p.h)){if(h.x=p.x,h.y=p.y,l=Math.max(l,h.y+h.h),s=Math.max(s,h.x+h.w),h.w===p.w&&h.h===p.h){var d=o.pop();f<o.length&&(o[f]=d)}else h.h===p.h?(p.x+=h.w,p.w-=h.w):h.w===p.w?(p.y+=h.h,p.h-=h.h):(o.push({x:p.x+h.w,y:p.y,w:p.w-h.w,h:h.h}),p.y+=h.h,p.h-=h.h);break}}return{w:s,h:l,fill:e/(s*l)||0}}var qs=function(t,e){var r=e.pixelRatio,n=e.version;this.paddedRect=t,this.pixelRatio=r,this.version=n},Hs={tl:{configurable:!0},br:{configurable:!0},tlbr:{configurable:!0},displaySize:{configurable:!0}};Hs.tl.get=function(){return[this.paddedRect.x+1,this.paddedRect.y+1]},Hs.br.get=function(){return[this.paddedRect.x+this.paddedRect.w-1,this.paddedRect.y+this.paddedRect.h-1]},Hs.tlbr.get=function(){return this.tl.concat(this.br)},Hs.displaySize.get=function(){return[(this.paddedRect.w-2)/this.pixelRatio,(this.paddedRect.h-2)/this.pixelRatio]},Object.defineProperties(qs.prototype,Hs);var Gs=function(t,e){var r={},n={};this.haveRenderCallbacks=[];var i=[];this.addImages(t,r,i),this.addImages(e,n,i);var a=Vs(i),o=a.w,s=a.h,l=new Ha({width:o||1,height:s||1});for(var c in t){var u=t[c],h=r[c].paddedRect;Ha.copy(u.data,l,{x:0,y:0},{x:h.x+1,y:h.y+1},u.data)}for(var f in e){var p=e[f],d=n[f].paddedRect,g=d.x+1,v=d.y+1,m=p.data.width,y=p.data.height;Ha.copy(p.data,l,{x:0,y:0},{x:g,y:v},p.data),Ha.copy(p.data,l,{x:0,y:y-1},{x:g,y:v-1},{width:m,height:1}),Ha.copy(p.data,l,{x:0,y:0},{x:g,y:v+y},{width:m,height:1}),Ha.copy(p.data,l,{x:m-1,y:0},{x:g-1,y:v},{width:1,height:y}),Ha.copy(p.data,l,{x:0,y:0},{x:g+m,y:v},{width:1,height:y})}this.image=l,this.iconPositions=r,this.patternPositions=n};Gs.prototype.addImages=function(t,e,r){for(var n in t){var i=t[n],a={x:0,y:0,w:i.data.width+2,h:i.data.height+2};r.push(a),e[n]=new qs(a,i),i.hasRenderCallback&&this.haveRenderCallbacks.push(n)}},Gs.prototype.patchUpdatedImages=function(t,e){for(var r in t.dispatchRenderCallbacks(this.haveRenderCallbacks),t.updatedImages)this.patchUpdatedImage(this.iconPositions[r],t.getImage(r),e),this.patchUpdatedImage(this.patternPositions[r],t.getImage(r),e)},Gs.prototype.patchUpdatedImage=function(t,e,r){if(t&&e&&t.version!==e.version){t.version=e.version;var n=t.tl,i=n[0],a=n[1];r.update(e.data,void 0,{x:i,y:a})}},kn(\"ImagePosition\",qs),kn(\"ImageAtlas\",Gs);var Ys=self.HTMLImageElement,Ws=self.HTMLCanvasElement,Xs=self.HTMLVideoElement,Zs=self.ImageData,Js=function(t,e,r,n){this.context=t,this.format=r,this.texture=t.gl.createTexture(),this.update(e,n)};Js.prototype.update=function(t,e,r){var n=t.width,i=t.height,a=!(this.size&&this.size[0]===n&&this.size[1]===i||r),o=this.context,s=o.gl;if(this.useMipmap=Boolean(e&&e.useMipmap),s.bindTexture(s.TEXTURE_2D,this.texture),o.pixelStoreUnpackFlipY.set(!1),o.pixelStoreUnpack.set(1),o.pixelStoreUnpackPremultiplyAlpha.set(this.format===s.RGBA&&(!e||!1!==e.premultiply)),a)this.size=[n,i],t instanceof Ys||t instanceof Ws||t instanceof Xs||t instanceof Zs?s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,s.UNSIGNED_BYTE,t):s.texImage2D(s.TEXTURE_2D,0,this.format,n,i,0,this.format,s.UNSIGNED_BYTE,t.data);else{var l=r||{x:0,y:0},c=l.x,u=l.y;t instanceof Ys||t instanceof Ws||t instanceof Xs||t instanceof Zs?s.texSubImage2D(s.TEXTURE_2D,0,c,u,s.RGBA,s.UNSIGNED_BYTE,t):s.texSubImage2D(s.TEXTURE_2D,0,c,u,n,i,s.RGBA,s.UNSIGNED_BYTE,t.data)}this.useMipmap&&this.isSizePowerOfTwo()&&s.generateMipmap(s.TEXTURE_2D)},Js.prototype.bind=function(t,e,r){var n=this.context.gl;n.bindTexture(n.TEXTURE_2D,this.texture),r!==n.LINEAR_MIPMAP_NEAREST||this.isSizePowerOfTwo()||(r=n.LINEAR),t!==this.filter&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,t),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,r||t),this.filter=t),e!==this.wrap&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,e),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,e),this.wrap=e)},Js.prototype.isSizePowerOfTwo=function(){return this.size[0]===this.size[1]&&Math.log(this.size[0])/Math.LN2%1==0},Js.prototype.destroy=function(){this.context.gl.deleteTexture(this.texture),this.texture=null};var Ks=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?i-1:0,f=r?-1:1,p=t[e+h];for(h+=f,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+h],h+=f,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},$s=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,h=u>>1,f=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,i),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g},Qs=tl;function tl(t){this.buf=ArrayBuffer.isView&&ArrayBuffer.isView(t)?t:new Uint8Array(t||0),this.pos=0,this.type=0,this.length=this.buf.length}function el(t){return t.type===tl.Bytes?t.readVarint()+t.pos:t.pos+1}function rl(t,e,r){return r?4294967296*e+(t>>>0):4294967296*(e>>>0)+(t>>>0)}function nl(t,e,r){var n=e<=16383?1:e<=2097151?2:e<=268435455?3:Math.floor(Math.log(e)/(7*Math.LN2));r.realloc(n);for(var i=r.pos-1;i>=t;i--)r.buf[i+n]=r.buf[i]}function il(t,e){for(var r=0;r<t.length;r++)e.writeVarint(t[r])}function al(t,e){for(var r=0;r<t.length;r++)e.writeSVarint(t[r])}function ol(t,e){for(var r=0;r<t.length;r++)e.writeFloat(t[r])}function sl(t,e){for(var r=0;r<t.length;r++)e.writeDouble(t[r])}function ll(t,e){for(var r=0;r<t.length;r++)e.writeBoolean(t[r])}function cl(t,e){for(var r=0;r<t.length;r++)e.writeFixed32(t[r])}function ul(t,e){for(var r=0;r<t.length;r++)e.writeSFixed32(t[r])}function hl(t,e){for(var r=0;r<t.length;r++)e.writeFixed64(t[r])}function fl(t,e){for(var r=0;r<t.length;r++)e.writeSFixed64(t[r])}function pl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+16777216*t[e+3]}function dl(t,e,r){t[r]=e,t[r+1]=e>>>8,t[r+2]=e>>>16,t[r+3]=e>>>24}function gl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+(t[e+3]<<24)}tl.Varint=0,tl.Fixed64=1,tl.Bytes=2,tl.Fixed32=5,tl.prototype={destroy:function(){this.buf=null},readFields:function(t,e,r){for(r=r||this.length;this.pos<r;){var n=this.readVarint(),i=n>>3,a=this.pos;this.type=7&n,t(i,e,this),this.pos===a&&this.skip(n)}return e},readMessage:function(t,e){return this.readFields(t,e,this.readVarint()+this.pos)},readFixed32:function(){var t=pl(this.buf,this.pos);return this.pos+=4,t},readSFixed32:function(){var t=gl(this.buf,this.pos);return this.pos+=4,t},readFixed64:function(){var t=pl(this.buf,this.pos)+4294967296*pl(this.buf,this.pos+4);return this.pos+=8,t},readSFixed64:function(){var t=pl(this.buf,this.pos)+4294967296*gl(this.buf,this.pos+4);return this.pos+=8,t},readFloat:function(){var t=Ks(this.buf,this.pos,!0,23,4);return this.pos+=4,t},readDouble:function(){var t=Ks(this.buf,this.pos,!0,52,8);return this.pos+=8,t},readVarint:function(t){var e,r,n=this.buf;return e=127&(r=n[this.pos++]),r<128?e:(e|=(127&(r=n[this.pos++]))<<7,r<128?e:(e|=(127&(r=n[this.pos++]))<<14,r<128?e:(e|=(127&(r=n[this.pos++]))<<21,r<128?e:function(t,e,r){var n,i,a=r.buf;if(n=(112&(i=a[r.pos++]))>>4,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<3,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<10,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<17,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<24,i<128)return rl(t,n,e);if(n|=(1&(i=a[r.pos++]))<<31,i<128)return rl(t,n,e);throw new Error(\"Expected varint not more than 10 bytes\")}(e|=(15&(r=n[this.pos]))<<28,t,this))))},readVarint64:function(){return this.readVarint(!0)},readSVarint:function(){var t=this.readVarint();return t%2==1?(t+1)/-2:t/2},readBoolean:function(){return Boolean(this.readVarint())},readString:function(){var t=this.readVarint()+this.pos,e=function(t,e,r){for(var n=\"\",i=e;i<r;){var a,o,s,l=t[i],c=null,u=l>239?4:l>223?3:l>191?2:1;if(i+u>r)break;1===u?l<128&&(c=l):2===u?128==(192&(a=t[i+1]))&&(c=(31&l)<<6|63&a)<=127&&(c=null):3===u?(a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&((c=(15&l)<<12|(63&a)<<6|63&o)<=2047||c>=55296&&c<=57343)&&(c=null)):4===u&&(a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&((c=(15&l)<<18|(63&a)<<12|(63&o)<<6|63&s)<=65535||c>=1114112)&&(c=null)),null===c?(c=65533,u=1):c>65535&&(c-=65536,n+=String.fromCharCode(c>>>10&1023|55296),c=56320|1023&c),n+=String.fromCharCode(c),i+=u}return n}(this.buf,this.pos,t);return this.pos=t,e},readBytes:function(){var t=this.readVarint()+this.pos,e=this.buf.subarray(this.pos,t);return this.pos=t,e},readPackedVarint:function(t,e){if(this.type!==tl.Bytes)return t.push(this.readVarint(e));var r=el(this);for(t=t||[];this.pos<r;)t.push(this.readVarint(e));return t},readPackedSVarint:function(t){if(this.type!==tl.Bytes)return t.push(this.readSVarint());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSVarint());return t},readPackedBoolean:function(t){if(this.type!==tl.Bytes)return t.push(this.readBoolean());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readBoolean());return t},readPackedFloat:function(t){if(this.type!==tl.Bytes)return t.push(this.readFloat());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFloat());return t},readPackedDouble:function(t){if(this.type!==tl.Bytes)return t.push(this.readDouble());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readDouble());return t},readPackedFixed32:function(t){if(this.type!==tl.Bytes)return t.push(this.readFixed32());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFixed32());return t},readPackedSFixed32:function(t){if(this.type!==tl.Bytes)return t.push(this.readSFixed32());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed32());return t},readPackedFixed64:function(t){if(this.type!==tl.Bytes)return t.push(this.readFixed64());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFixed64());return t},readPackedSFixed64:function(t){if(this.type!==tl.Bytes)return t.push(this.readSFixed64());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed64());return t},skip:function(t){var e=7&t;if(e===tl.Varint)for(;this.buf[this.pos++]>127;);else if(e===tl.Bytes)this.pos=this.readVarint()+this.pos;else if(e===tl.Fixed32)this.pos+=4;else{if(e!==tl.Fixed64)throw new Error(\"Unimplemented type: \"+e);this.pos+=8}},writeTag:function(t,e){this.writeVarint(t<<3|e)},realloc:function(t){for(var e=this.length||16;e<this.pos+t;)e*=2;if(e!==this.length){var r=new Uint8Array(e);r.set(this.buf),this.buf=r,this.length=e}},finish:function(){return this.length=this.pos,this.pos=0,this.buf.subarray(0,this.length)},writeFixed32:function(t){this.realloc(4),dl(this.buf,t,this.pos),this.pos+=4},writeSFixed32:function(t){this.realloc(4),dl(this.buf,t,this.pos),this.pos+=4},writeFixed64:function(t){this.realloc(8),dl(this.buf,-1&t,this.pos),dl(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeSFixed64:function(t){this.realloc(8),dl(this.buf,-1&t,this.pos),dl(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeVarint:function(t){(t=+t||0)>268435455||t<0?function(t,e){var r,n;if(t>=0?(r=t%4294967296|0,n=t/4294967296|0):(n=~(-t/4294967296),4294967295^(r=~(-t%4294967296))?r=r+1|0:(r=0,n=n+1|0)),t>=0x10000000000000000||t<-0x10000000000000000)throw new Error(\"Given varint doesn't fit into 10 bytes\");e.realloc(10),function(t,e,r){r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos]=127&t}(r,0,e),function(t,e){var r=(7&t)<<4;e.buf[e.pos++]|=r|((t>>>=3)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t)))))}(n,e)}(t,this):(this.realloc(4),this.buf[this.pos++]=127&t|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=t>>>7&127))))},writeSVarint:function(t){this.writeVarint(t<0?2*-t-1:2*t)},writeBoolean:function(t){this.writeVarint(Boolean(t))},writeString:function(t){t=String(t),this.realloc(4*t.length),this.pos++;var e=this.pos;this.pos=function(t,e,r){for(var n,i,a=0;a<e.length;a++){if((n=e.charCodeAt(a))>55295&&n<57344){if(!i){n>56319||a+1===e.length?(t[r++]=239,t[r++]=191,t[r++]=189):i=n;continue}if(n<56320){t[r++]=239,t[r++]=191,t[r++]=189,i=n;continue}n=i-55296<<10|n-56320|65536,i=null}else i&&(t[r++]=239,t[r++]=191,t[r++]=189,i=null);n<128?t[r++]=n:(n<2048?t[r++]=n>>6|192:(n<65536?t[r++]=n>>12|224:(t[r++]=n>>18|240,t[r++]=n>>12&63|128),t[r++]=n>>6&63|128),t[r++]=63&n|128)}return r}(this.buf,t,this.pos);var r=this.pos-e;r>=128&&nl(e,r,this),this.pos=e-1,this.writeVarint(r),this.pos+=r},writeFloat:function(t){this.realloc(4),$s(this.buf,t,this.pos,!0,23,4),this.pos+=4},writeDouble:function(t){this.realloc(8),$s(this.buf,t,this.pos,!0,52,8),this.pos+=8},writeBytes:function(t){var e=t.length;this.writeVarint(e),this.realloc(e);for(var r=0;r<e;r++)this.buf[this.pos++]=t[r]},writeRawMessage:function(t,e){this.pos++;var r=this.pos;t(e,this);var n=this.pos-r;n>=128&&nl(r,n,this),this.pos=r-1,this.writeVarint(n),this.pos+=n},writeMessage:function(t,e,r){this.writeTag(t,tl.Bytes),this.writeRawMessage(e,r)},writePackedVarint:function(t,e){e.length&&this.writeMessage(t,il,e)},writePackedSVarint:function(t,e){e.length&&this.writeMessage(t,al,e)},writePackedBoolean:function(t,e){e.length&&this.writeMessage(t,ll,e)},writePackedFloat:function(t,e){e.length&&this.writeMessage(t,ol,e)},writePackedDouble:function(t,e){e.length&&this.writeMessage(t,sl,e)},writePackedFixed32:function(t,e){e.length&&this.writeMessage(t,cl,e)},writePackedSFixed32:function(t,e){e.length&&this.writeMessage(t,ul,e)},writePackedFixed64:function(t,e){e.length&&this.writeMessage(t,hl,e)},writePackedSFixed64:function(t,e){e.length&&this.writeMessage(t,fl,e)},writeBytesField:function(t,e){this.writeTag(t,tl.Bytes),this.writeBytes(e)},writeFixed32Field:function(t,e){this.writeTag(t,tl.Fixed32),this.writeFixed32(e)},writeSFixed32Field:function(t,e){this.writeTag(t,tl.Fixed32),this.writeSFixed32(e)},writeFixed64Field:function(t,e){this.writeTag(t,tl.Fixed64),this.writeFixed64(e)},writeSFixed64Field:function(t,e){this.writeTag(t,tl.Fixed64),this.writeSFixed64(e)},writeVarintField:function(t,e){this.writeTag(t,tl.Varint),this.writeVarint(e)},writeSVarintField:function(t,e){this.writeTag(t,tl.Varint),this.writeSVarint(e)},writeStringField:function(t,e){this.writeTag(t,tl.Bytes),this.writeString(e)},writeFloatField:function(t,e){this.writeTag(t,tl.Fixed32),this.writeFloat(e)},writeDoubleField:function(t,e){this.writeTag(t,tl.Fixed64),this.writeDouble(e)},writeBooleanField:function(t,e){this.writeVarintField(t,Boolean(e))}};var vl=3;function ml(t,e,r){1===t&&r.readMessage(yl,e)}function yl(t,e,r){if(3===t){var n=r.readMessage(xl,{}),i=n.id,a=n.bitmap,o=n.width,s=n.height,l=n.left,c=n.top,u=n.advance;e.push({id:i,bitmap:new qa({width:o+2*vl,height:s+2*vl},a),metrics:{width:o,height:s,left:l,top:c,advance:u}})}}function xl(t,e,r){1===t?e.id=r.readVarint():2===t?e.bitmap=r.readBytes():3===t?e.width=r.readVarint():4===t?e.height=r.readVarint():5===t?e.left=r.readSVarint():6===t?e.top=r.readSVarint():7===t&&(e.advance=r.readVarint())}var bl=vl,_l=function(t,e,r){this.target=t,this.parent=e,this.mapId=r,this.callbacks={},this.callbackID=0,v([\"receive\"],this),this.target.addEventListener(\"message\",this.receive,!1)};function wl(t,e,r){var n=2*Math.PI*6378137/256/Math.pow(2,r);return[t*n-2*Math.PI*6378137/2,e*n-2*Math.PI*6378137/2]}_l.prototype.send=function(t,e,r,n){var i=this,a=r?this.mapId+\":\"+this.callbackID++:null;r&&(this.callbacks[a]=r);var o=[];if(this.target.postMessage({targetMapId:n,sourceMapId:this.mapId,type:t,id:String(a),data:An(e,o)},o),r)return{cancel:function(){i.callbacks[a]=null,i.target.postMessage({targetMapId:n,sourceMapId:i.mapId,type:\"<cancel>\",id:String(a)})}}},_l.prototype.receive=function(t){var e,r=this,n=t.data,i=n.id;if(!n.targetMapId||this.mapId===n.targetMapId){var a=function(t,e){delete r.callbacks[i];var n=[];r.target.postMessage({sourceMapId:r.mapId,type:\"<response>\",id:String(i),error:t?An(t):null,data:An(e,n)},n)};if(\"<response>\"===n.type||\"<cancel>\"===n.type)e=this.callbacks[n.id],delete this.callbacks[n.id],e&&n.error?e(Mn(n.error)):e&&e(null,Mn(n.data));else if(void 0!==n.id&&this.parent[n.type]){this.callbacks[n.id]=null;var o=this.parent[n.type](n.sourceMapId,Mn(n.data),a);o&&null===this.callbacks[n.id]&&(this.callbacks[n.id]=o.cancel)}else if(void 0!==n.id&&this.parent.getWorkerSource){var s=n.type.split(\".\"),l=Mn(n.data);this.parent.getWorkerSource(n.sourceMapId,s[0],l.source)[s[1]](l,a)}else this.parent[n.type](Mn(n.data))}},_l.prototype.remove=function(){this.target.removeEventListener(\"message\",this.receive,!1)};var kl=function(t,e){t&&(e?this.setSouthWest(t).setNorthEast(e):4===t.length?this.setSouthWest([t[0],t[1]]).setNorthEast([t[2],t[3]]):this.setSouthWest(t[0]).setNorthEast(t[1]))};kl.prototype.setNorthEast=function(t){return this._ne=t instanceof Tl?new Tl(t.lng,t.lat):Tl.convert(t),this},kl.prototype.setSouthWest=function(t){return this._sw=t instanceof Tl?new Tl(t.lng,t.lat):Tl.convert(t),this},kl.prototype.extend=function(t){var e,r,n=this._sw,i=this._ne;if(t instanceof Tl)e=t,r=t;else{if(!(t instanceof kl))return Array.isArray(t)?t.every(Array.isArray)?this.extend(kl.convert(t)):this.extend(Tl.convert(t)):this;if(e=t._sw,r=t._ne,!e||!r)return this}return n||i?(n.lng=Math.min(e.lng,n.lng),n.lat=Math.min(e.lat,n.lat),i.lng=Math.max(r.lng,i.lng),i.lat=Math.max(r.lat,i.lat)):(this._sw=new Tl(e.lng,e.lat),this._ne=new Tl(r.lng,r.lat)),this},kl.prototype.getCenter=function(){return new Tl((this._sw.lng+this._ne.lng)/2,(this._sw.lat+this._ne.lat)/2)},kl.prototype.getSouthWest=function(){return this._sw},kl.prototype.getNorthEast=function(){return this._ne},kl.prototype.getNorthWest=function(){return new Tl(this.getWest(),this.getNorth())},kl.prototype.getSouthEast=function(){return new Tl(this.getEast(),this.getSouth())},kl.prototype.getWest=function(){return this._sw.lng},kl.prototype.getSouth=function(){return this._sw.lat},kl.prototype.getEast=function(){return this._ne.lng},kl.prototype.getNorth=function(){return this._ne.lat},kl.prototype.toArray=function(){return[this._sw.toArray(),this._ne.toArray()]},kl.prototype.toString=function(){return\"LngLatBounds(\"+this._sw.toString()+\", \"+this._ne.toString()+\")\"},kl.prototype.isEmpty=function(){return!(this._sw&&this._ne)},kl.convert=function(t){return!t||t instanceof kl?t:new kl(t)};var Tl=function(t,e){if(isNaN(t)||isNaN(e))throw new Error(\"Invalid LngLat object: (\"+t+\", \"+e+\")\");if(this.lng=+t,this.lat=+e,this.lat>90||this.lat<-90)throw new Error(\"Invalid LngLat latitude value: must be between -90 and 90\")};function Al(t){return 2*Math.PI*6378137*Math.cos(t*Math.PI/180)}function Ml(t){return(180+t)/360}function Sl(t){return(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+t*Math.PI/360)))/360}function El(t,e){return t/Al(e)}function Cl(t){var e=180-360*t;return 360/Math.PI*Math.atan(Math.exp(e*Math.PI/180))-90}Tl.prototype.wrap=function(){return new Tl(u(this.lng,-180,180),this.lat)},Tl.prototype.toArray=function(){return[this.lng,this.lat]},Tl.prototype.toString=function(){return\"LngLat(\"+this.lng+\", \"+this.lat+\")\"},Tl.prototype.toBounds=function(t){void 0===t&&(t=0);var e=360*t/40075017,r=e/Math.cos(Math.PI/180*this.lat);return new kl(new Tl(this.lng-r,this.lat-e),new Tl(this.lng+r,this.lat+e))},Tl.convert=function(t){if(t instanceof Tl)return t;if(Array.isArray(t)&&(2===t.length||3===t.length))return new Tl(Number(t[0]),Number(t[1]));if(!Array.isArray(t)&&\"object\"==typeof t&&null!==t)return new Tl(Number(\"lng\"in t?t.lng:t.lon),Number(t.lat));throw new Error(\"`LngLatLike` argument must be specified as a LngLat instance, an object {lng: <lng>, lat: <lat>}, an object {lon: <lng>, lat: <lat>}, or an array of [<lng>, <lat>]\")};var Ll=function(t,e,r){void 0===r&&(r=0),this.x=+t,this.y=+e,this.z=+r};Ll.fromLngLat=function(t,e){void 0===e&&(e=0);var r=Tl.convert(t);return new Ll(Ml(r.lng),Sl(r.lat),El(e,r.lat))},Ll.prototype.toLngLat=function(){return new Tl(360*this.x-180,Cl(this.y))},Ll.prototype.toAltitude=function(){return this.z*Al(Cl(this.y))};var Pl=function(t,e,r){this.z=t,this.x=e,this.y=r,this.key=Il(0,t,e,r)};Pl.prototype.equals=function(t){return this.z===t.z&&this.x===t.x&&this.y===t.y},Pl.prototype.url=function(t,e){var r,n,i,a,o,s=(r=this.x,n=this.y,i=this.z,a=wl(256*r,256*(n=Math.pow(2,i)-n-1),i),o=wl(256*(r+1),256*(n+1),i),a[0]+\",\"+a[1]+\",\"+o[0]+\",\"+o[1]),l=function(t,e,r){for(var n,i=\"\",a=t;a>0;a--)i+=(e&(n=1<<a-1)?1:0)+(r&n?2:0);return i}(this.z,this.x,this.y);return t[(this.x+this.y)%t.length].replace(\"{prefix}\",(this.x%16).toString(16)+(this.y%16).toString(16)).replace(\"{z}\",String(this.z)).replace(\"{x}\",String(this.x)).replace(\"{y}\",String(\"tms\"===e?Math.pow(2,this.z)-this.y-1:this.y)).replace(\"{quadkey}\",l).replace(\"{bbox-epsg-3857}\",s)},Pl.prototype.getTilePoint=function(t){var e=Math.pow(2,this.z);return new i((t.x*e-this.x)*ha,(t.y*e-this.y)*ha)};var Ol=function(t,e){this.wrap=t,this.canonical=e,this.key=Il(t,e.z,e.x,e.y)},zl=function(t,e,r,n,i){this.overscaledZ=t,this.wrap=e,this.canonical=new Pl(r,+n,+i),this.key=Il(e,t,n,i)};function Il(t,e,r,n){(t*=2)<0&&(t=-1*t-1);var i=1<<e;return 32*(i*i*t+i*n+r)+e}zl.prototype.equals=function(t){return this.overscaledZ===t.overscaledZ&&this.wrap===t.wrap&&this.canonical.equals(t.canonical)},zl.prototype.scaledTo=function(t){var e=this.canonical.z-t;return t>this.canonical.z?new zl(t,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y):new zl(t,this.wrap,t,this.canonical.x>>e,this.canonical.y>>e)},zl.prototype.isChildOf=function(t){if(t.wrap!==this.wrap)return!1;var e=this.canonical.z-t.canonical.z;return 0===t.overscaledZ||t.overscaledZ<this.overscaledZ&&t.canonical.x===this.canonical.x>>e&&t.canonical.y===this.canonical.y>>e},zl.prototype.children=function(t){if(this.overscaledZ>=t)return[new zl(this.overscaledZ+1,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y)];var e=this.canonical.z+1,r=2*this.canonical.x,n=2*this.canonical.y;return[new zl(e,this.wrap,e,r,n),new zl(e,this.wrap,e,r+1,n),new zl(e,this.wrap,e,r,n+1),new zl(e,this.wrap,e,r+1,n+1)]},zl.prototype.isLessThan=function(t){return this.wrap<t.wrap||!(this.wrap>t.wrap)&&(this.overscaledZ<t.overscaledZ||!(this.overscaledZ>t.overscaledZ)&&(this.canonical.x<t.canonical.x||!(this.canonical.x>t.canonical.x)&&this.canonical.y<t.canonical.y))},zl.prototype.wrapped=function(){return new zl(this.overscaledZ,0,this.canonical.z,this.canonical.x,this.canonical.y)},zl.prototype.unwrapTo=function(t){return new zl(this.overscaledZ,t,this.canonical.z,this.canonical.x,this.canonical.y)},zl.prototype.overscaleFactor=function(){return Math.pow(2,this.overscaledZ-this.canonical.z)},zl.prototype.toUnwrapped=function(){return new Ol(this.wrap,this.canonical)},zl.prototype.toString=function(){return this.overscaledZ+\"/\"+this.canonical.x+\"/\"+this.canonical.y},zl.prototype.getTilePoint=function(t){return this.canonical.getTilePoint(new Ll(t.x-this.wrap,t.y))},kn(\"CanonicalTileID\",Pl),kn(\"OverscaledTileID\",zl,{omit:[\"posMatrix\"]});var Dl=function(t,e,r){if(this.uid=t,e.height!==e.width)throw new RangeError(\"DEM tiles must be square\");if(r&&\"mapbox\"!==r&&\"terrarium\"!==r)return w('\"'+r+'\" is not a valid encoding type. Valid types include \"mapbox\" and \"terrarium\".');var n=this.dim=e.height;this.stride=this.dim+2,this.data=new Int32Array(this.stride*this.stride);for(var i=e.data,a=\"terrarium\"===r?this._unpackTerrarium:this._unpackMapbox,o=0;o<n;o++)for(var s=0;s<n;s++){var l=4*(o*n+s);this.set(s,o,a(i[l],i[l+1],i[l+2]))}for(var c=0;c<n;c++)this.set(-1,c,this.get(0,c)),this.set(n,c,this.get(n-1,c)),this.set(c,-1,this.get(c,0)),this.set(c,n,this.get(c,n-1));this.set(-1,-1,this.get(0,0)),this.set(n,-1,this.get(n-1,0)),this.set(-1,n,this.get(0,n-1)),this.set(n,n,this.get(n-1,n-1))};Dl.prototype.set=function(t,e,r){this.data[this._idx(t,e)]=r+65536},Dl.prototype.get=function(t,e){return this.data[this._idx(t,e)]-65536},Dl.prototype._idx=function(t,e){if(t<-1||t>=this.dim+1||e<-1||e>=this.dim+1)throw new RangeError(\"out of range source coordinates for DEM data\");return(e+1)*this.stride+(t+1)},Dl.prototype._unpackMapbox=function(t,e,r){return(256*t*256+256*e+r)/10-1e4},Dl.prototype._unpackTerrarium=function(t,e,r){return 256*t+e+r/256-32768},Dl.prototype.getPixels=function(){return new Ha({width:this.stride,height:this.stride},new Uint8Array(this.data.buffer))},Dl.prototype.backfillBorder=function(t,e,r){if(this.dim!==t.dim)throw new Error(\"dem dimension mismatch\");var n=e*this.dim,i=e*this.dim+this.dim,a=r*this.dim,o=r*this.dim+this.dim;switch(e){case-1:n=i-1;break;case 1:i=n+1}switch(r){case-1:a=o-1;break;case 1:o=a+1}for(var s=-e*this.dim,l=-r*this.dim,c=a;c<o;c++)for(var u=n;u<i;u++)this.set(u,c,t.get(u+s,c+l))},kn(\"DEMData\",Dl);var Rl=oi([{name:\"a_pos\",type:\"Int16\",components:2},{name:\"a_texture_pos\",type:\"Int16\",components:2}]),Fl=function(t){this._stringToNumber={},this._numberToString=[];for(var e=0;e<t.length;e++){var r=t[e];this._stringToNumber[r]=e,this._numberToString[e]=r}};Fl.prototype.encode=function(t){return this._stringToNumber[t]},Fl.prototype.decode=function(t){return this._numberToString[t]};var Bl=function(t,e,r,n){this.type=\"Feature\",this._vectorTileFeature=t,t._z=e,t._x=r,t._y=n,this.properties=t.properties,null!=t.id&&(this.id=t.id)},Nl={geometry:{configurable:!0}};Nl.geometry.get=function(){return void 0===this._geometry&&(this._geometry=this._vectorTileFeature.toGeoJSON(this._vectorTileFeature._x,this._vectorTileFeature._y,this._vectorTileFeature._z).geometry),this._geometry},Nl.geometry.set=function(t){this._geometry=t},Bl.prototype.toJSON=function(){var t={geometry:this.geometry};for(var e in this)\"_geometry\"!==e&&\"_vectorTileFeature\"!==e&&(t[e]=this[e]);return t},Object.defineProperties(Bl.prototype,Nl);var jl=function(){this.state={},this.stateChanges={},this.deletedStates={}};jl.prototype.updateState=function(t,e,r){var n=String(e);if(this.stateChanges[t]=this.stateChanges[t]||{},this.stateChanges[t][n]=this.stateChanges[t][n]||{},h(this.stateChanges[t][n],r),null===this.deletedStates[t])for(var i in this.deletedStates[t]={},this.state[t])i!==n&&(this.deletedStates[t][i]=null);else if(this.deletedStates[t]&&null===this.deletedStates[t][n])for(var a in this.deletedStates[t][n]={},this.state[t][n])r[a]||(this.deletedStates[t][n][a]=null);else for(var o in r)this.deletedStates[t]&&this.deletedStates[t][n]&&null===this.deletedStates[t][n][o]&&delete this.deletedStates[t][n][o]},jl.prototype.removeFeatureState=function(t,e,r){if(null!==this.deletedStates[t]){var n=String(e);if(this.deletedStates[t]=this.deletedStates[t]||{},r&&void 0!==e&&e>=0)null!==this.deletedStates[t][n]&&(this.deletedStates[t][n]=this.deletedStates[t][n]||{},this.deletedStates[t][n][r]=null);else if(void 0!==e&&e>=0)if(this.stateChanges[t]&&this.stateChanges[t][n])for(r in this.deletedStates[t][n]={},this.stateChanges[t][n])this.deletedStates[t][n][r]=null;else this.deletedStates[t][n]=null;else this.deletedStates[t]=null}},jl.prototype.getState=function(t,e){var r=String(e),n=this.state[t]||{},i=this.stateChanges[t]||{},a=h({},n[r],i[r]);if(null===this.deletedStates[t])return{};if(this.deletedStates[t]){var o=this.deletedStates[t][e];if(null===o)return{};for(var s in o)delete a[s]}return a},jl.prototype.initializeTileState=function(t,e){t.setFeatureState(this.state,e)},jl.prototype.coalesceChanges=function(t,e){var r={};for(var n in this.stateChanges){this.state[n]=this.state[n]||{};var i={};for(var a in this.stateChanges[n])this.state[n][a]||(this.state[n][a]={}),h(this.state[n][a],this.stateChanges[n][a]),i[a]=this.state[n][a];r[n]=i}for(var o in this.deletedStates){this.state[o]=this.state[o]||{};var s={};if(null===this.deletedStates[o])for(var l in this.state[o])s[l]={},this.state[o][l]={};else for(var c in this.deletedStates[o]){if(null===this.deletedStates[o][c])this.state[o][c]={};else for(var u=0,f=Object.keys(this.deletedStates[o][c]);u<f.length;u+=1){var p=f[u];delete this.state[o][c][p]}s[c]=this.state[o][c]}r[o]=r[o]||{},h(r[o],s)}if(this.stateChanges={},this.deletedStates={},0!==Object.keys(r).length)for(var d in t)t[d].setFeatureState(r,e)};var Ul=function(t,e,r){this.tileID=t,this.x=t.canonical.x,this.y=t.canonical.y,this.z=t.canonical.z,this.grid=e||new yn(ha,16,0),this.grid3D=new yn(ha,16,0),this.featureIndexArray=r||new ji};function Vl(t){for(var e=1/0,r=1/0,n=-1/0,i=-1/0,a=0,o=t;a<o.length;a+=1){var s=o[a];e=Math.min(e,s.x),r=Math.min(r,s.y),n=Math.max(n,s.x),i=Math.max(i,s.y)}return{minX:e,minY:r,maxX:n,maxY:i}}function ql(t,e){return e-t}Ul.prototype.insert=function(t,e,r,n,i,a){var o=this.featureIndexArray.length;this.featureIndexArray.emplaceBack(r,n,i);for(var s=a?this.grid3D:this.grid,l=0;l<e.length;l++){for(var c=e[l],u=[1/0,1/0,-1/0,-1/0],h=0;h<c.length;h++){var f=c[h];u[0]=Math.min(u[0],f.x),u[1]=Math.min(u[1],f.y),u[2]=Math.max(u[2],f.x),u[3]=Math.max(u[3],f.y)}u[0]<ha&&u[1]<ha&&u[2]>=0&&u[3]>=0&&s.insert(o,u[0],u[1],u[2],u[3])}},Ul.prototype.loadVTLayers=function(){return this.vtLayers||(this.vtLayers=new Vo.VectorTile(new Qs(this.rawTileData)).layers,this.sourceLayerCoder=new Fl(this.vtLayers?Object.keys(this.vtLayers).sort():[\"_geojsonTileLayer\"])),this.vtLayers},Ul.prototype.query=function(t,e,r){var n=this;this.loadVTLayers();for(var a=t.params||{},o=ha/t.tileSize/t.scale,s=Gr(a.filter),l=t.queryGeometry,c=t.queryPadding*o,u=Vl(l),h=this.grid.query(u.minX-c,u.minY-c,u.maxX+c,u.maxY+c),f=Vl(t.cameraQueryGeometry),p=0,d=this.grid3D.query(f.minX-c,f.minY-c,f.maxX+c,f.maxY+c,function(e,r,n,a){return function(t,e,r,n,a){for(var o=0,s=t;o<s.length;o+=1){var l=s[o];if(e<=l.x&&r<=l.y&&n>=l.x&&a>=l.y)return!0}var c=[new i(e,r),new i(e,a),new i(n,a),new i(n,r)];if(t.length>2)for(var u=0,h=c;u<h.length;u+=1)if(Aa(t,h[u]))return!0;for(var f=0;f<t.length-1;f++)if(Ma(t[f],t[f+1],c))return!0;return!1}(t.cameraQueryGeometry,e-c,r-c,n+c,a+c)});p<d.length;p+=1){var g=d[p];h.push(g)}h.sort(ql);for(var v,m={},y=function(i){var c=h[i];if(c!==v){v=c;var u=n.featureIndexArray.get(c),f=null;n.loadMatchingFeature(m,u.bucketIndex,u.sourceLayerIndex,u.featureIndex,s,a.layers,e,function(e,i){f||(f=pa(e));var a={};return e.id&&(a=r.getState(i.sourceLayer||\"_geojsonTileLayer\",e.id)),i.queryIntersectsFeature(l,e,a,f,n.z,t.transform,o,t.pixelPosMatrix)})}},x=0;x<h.length;x++)y(x);return m},Ul.prototype.loadMatchingFeature=function(t,e,r,n,i,a,o,s){var l=this.bucketLayerIDs[e];if(!a||function(t,e){for(var r=0;r<t.length;r++)if(e.indexOf(t[r])>=0)return!0;return!1}(a,l)){var c=this.sourceLayerCoder.decode(r),u=this.vtLayers[c].feature(n);if(i(new Un(this.tileID.overscaledZ),u))for(var h=0;h<l.length;h++){var f=l[h];if(!(a&&a.indexOf(f)<0)){var p=o[f];if(p){var d=!s||s(u,p);if(d){var g=new Bl(u,this.z,this.x,this.y);g.layer=p.serialize();var v=t[f];void 0===v&&(v=t[f]=[]),v.push({featureIndex:n,feature:g,intersectionZ:d})}}}}}},Ul.prototype.lookupSymbolFeatures=function(t,e,r,n,i,a){var o={};this.loadVTLayers();for(var s=Gr(n),l=0,c=t;l<c.length;l+=1){var u=c[l];this.loadMatchingFeature(o,e,r,u,s,i,a)}return o},Ul.prototype.hasLayer=function(t){for(var e=0,r=this.bucketLayerIDs;e<r.length;e+=1)for(var n=0,i=r[e];n<i.length;n+=1)if(t===i[n])return!0;return!1},kn(\"FeatureIndex\",Ul,{omit:[\"rawTileData\",\"sourceLayerCoder\"]});var Hl=function(t,e){this.tileID=t,this.uid=p(),this.uses=0,this.tileSize=e,this.buckets={},this.expirationTime=null,this.queryPadding=0,this.hasSymbolBuckets=!1,this.expiredRequestCount=0,this.state=\"loading\"};Hl.prototype.registerFadeDuration=function(t){var e=t+this.timeAdded;e<z.now()||this.fadeEndTime&&e<this.fadeEndTime||(this.fadeEndTime=e)},Hl.prototype.wasRequested=function(){return\"errored\"===this.state||\"loaded\"===this.state||\"reloading\"===this.state},Hl.prototype.loadVectorData=function(t,e,r){if(this.hasData()&&this.unloadVectorData(),this.state=\"loaded\",t){for(var n in t.featureIndex&&(this.latestFeatureIndex=t.featureIndex,t.rawTileData?(this.latestRawTileData=t.rawTileData,this.latestFeatureIndex.rawTileData=t.rawTileData):this.latestRawTileData&&(this.latestFeatureIndex.rawTileData=this.latestRawTileData)),this.collisionBoxArray=t.collisionBoxArray,this.buckets=function(t,e){var r={};if(!e)return r;for(var n=function(){var t=a[i],n=t.layerIds.map(function(t){return e.getLayer(t)}).filter(Boolean);if(0!==n.length){t.layers=n,t.stateDependentLayerIds&&(t.stateDependentLayers=t.stateDependentLayerIds.map(function(t){return n.filter(function(e){return e.id===t})[0]}));for(var o=0,s=n;o<s.length;o+=1){var l=s[o];r[l.id]=t}}},i=0,a=t;i<a.length;i+=1)n();return r}(t.buckets,e.style),this.hasSymbolBuckets=!1,this.buckets){var i=this.buckets[n];if(i instanceof Os){if(this.hasSymbolBuckets=!0,!r)break;i.justReloaded=!0}}for(var a in this.queryPadding=0,this.buckets){var o=this.buckets[a];this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(a).queryRadius(o))}t.imageAtlas&&(this.imageAtlas=t.imageAtlas),t.glyphAtlasImage&&(this.glyphAtlasImage=t.glyphAtlasImage)}else this.collisionBoxArray=new Li},Hl.prototype.unloadVectorData=function(){for(var t in this.buckets)this.buckets[t].destroy();this.buckets={},this.imageAtlasTexture&&this.imageAtlasTexture.destroy(),this.imageAtlas&&(this.imageAtlas=null),this.glyphAtlasTexture&&this.glyphAtlasTexture.destroy(),this.latestFeatureIndex=null,this.state=\"unloaded\"},Hl.prototype.unloadDEMData=function(){this.dem=null,this.neighboringTiles=null,this.state=\"unloaded\"},Hl.prototype.getBucket=function(t){return this.buckets[t.id]},Hl.prototype.upload=function(t){for(var e in this.buckets){var r=this.buckets[e];r.uploadPending()&&r.upload(t)}var n=t.gl;this.imageAtlas&&!this.imageAtlas.uploaded&&(this.imageAtlasTexture=new Js(t,this.imageAtlas.image,n.RGBA),this.imageAtlas.uploaded=!0),this.glyphAtlasImage&&(this.glyphAtlasTexture=new Js(t,this.glyphAtlasImage,n.ALPHA),this.glyphAtlasImage=null)},Hl.prototype.prepare=function(t){this.imageAtlas&&this.imageAtlas.patchUpdatedImages(t,this.imageAtlasTexture)},Hl.prototype.queryRenderedFeatures=function(t,e,r,n,i,a,o,s,l){return this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData?this.latestFeatureIndex.query({queryGeometry:r,cameraQueryGeometry:n,scale:i,tileSize:this.tileSize,pixelPosMatrix:l,transform:o,params:a,queryPadding:this.queryPadding*s},t,e):{}},Hl.prototype.querySourceFeatures=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData){var r=this.latestFeatureIndex.loadVTLayers(),n=e?e.sourceLayer:\"\",i=r._geojsonTileLayer||r[n];if(i)for(var a=Gr(e&&e.filter),o=this.tileID.canonical,s=o.z,l=o.x,c=o.y,u={z:s,x:l,y:c},h=0;h<i.length;h++){var f=i.feature(h);if(a(new Un(this.tileID.overscaledZ),f)){var p=new Bl(f,s,l,c);p.tile=u,t.push(p)}}}},Hl.prototype.clearMask=function(){this.segments&&(this.segments.destroy(),delete this.segments),this.maskedBoundsBuffer&&(this.maskedBoundsBuffer.destroy(),delete this.maskedBoundsBuffer),this.maskedIndexBuffer&&(this.maskedIndexBuffer.destroy(),delete this.maskedIndexBuffer)},Hl.prototype.setMask=function(t,e){if(!o(this.mask,t)&&(this.mask=t,this.clearMask(),!o(t,{0:!0}))){var r=new ci,n=new Ti;this.segments=new Vi,this.segments.prepareSegment(0,r,n);for(var a=Object.keys(t),s=0;s<a.length;s++){var l=t[+a[s]],c=ha>>l.z,u=new i(l.x*c,l.y*c),h=new i(u.x+c,u.y+c),f=this.segments.prepareSegment(4,r,n);r.emplaceBack(u.x,u.y,u.x,u.y),r.emplaceBack(h.x,u.y,h.x,u.y),r.emplaceBack(u.x,h.y,u.x,h.y),r.emplaceBack(h.x,h.y,h.x,h.y);var p=f.vertexLength;n.emplaceBack(p,p+1,p+2),n.emplaceBack(p+1,p+2,p+3),f.vertexLength+=4,f.primitiveLength+=2}this.maskedBoundsBuffer=e.createVertexBuffer(r,Rl.members),this.maskedIndexBuffer=e.createIndexBuffer(n)}},Hl.prototype.hasData=function(){return\"loaded\"===this.state||\"reloading\"===this.state||\"expired\"===this.state},Hl.prototype.patternsLoaded=function(){return this.imageAtlas&&!!Object.keys(this.imageAtlas.patternPositions).length},Hl.prototype.setExpiryData=function(t){var e=this.expirationTime;if(t.cacheControl){var r=A(t.cacheControl);r[\"max-age\"]&&(this.expirationTime=Date.now()+1e3*r[\"max-age\"])}else t.expires&&(this.expirationTime=new Date(t.expires).getTime());if(this.expirationTime){var n=Date.now(),i=!1;if(this.expirationTime>n)i=!1;else if(e)if(this.expirationTime<e)i=!0;else{var a=this.expirationTime-e;a?this.expirationTime=n+Math.max(a,3e4):i=!0}else i=!0;i?(this.expiredRequestCount++,this.state=\"expired\"):this.expiredRequestCount=0}},Hl.prototype.getExpiryTimeout=function(){if(this.expirationTime)return this.expiredRequestCount?1e3*(1<<Math.min(this.expiredRequestCount-1,31)):Math.min(this.expirationTime-(new Date).getTime(),Math.pow(2,31)-1)},Hl.prototype.setFeatureState=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData&&0!==Object.keys(t).length){var r=this.latestFeatureIndex.loadVTLayers();for(var n in this.buckets){var i=this.buckets[n],a=i.layers[0].sourceLayer||\"_geojsonTileLayer\",o=r[a],s=t[a];o&&s&&0!==Object.keys(s).length&&(i.update(s,o,this.imageAtlas&&this.imageAtlas.patternPositions||{}),e&&e.style&&(this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(n).queryRadius(i))))}}},Hl.prototype.holdingForFade=function(){return void 0!==this.symbolFadeHoldUntil},Hl.prototype.symbolFadeFinished=function(){return!this.symbolFadeHoldUntil||this.symbolFadeHoldUntil<z.now()},Hl.prototype.clearFadeHold=function(){this.symbolFadeHoldUntil=void 0},Hl.prototype.setHoldDuration=function(t){this.symbolFadeHoldUntil=z.now()+t};var Gl=24,Yl={horizontal:1,vertical:2,horizontalOnly:3},Wl=function(){this.text=\"\",this.sectionIndex=[],this.sections=[]};function Xl(t,e,r,n,i,a,o,s,l,c){var u,h=Wl.fromFeature(t,r);c===Yl.vertical&&h.verticalizePunctuation();var f=jn.processBidirectionalText,p=jn.processStyledBidirectionalText;if(f&&1===h.sections.length){u=[];for(var d=0,g=f(h.toString(),tc(h,s,n,e));d<g.length;d+=1){var v=g[d],m=new Wl;m.text=v,m.sections=h.sections;for(var y=0;y<v.length;y++)m.sectionIndex.push(0);u.push(m)}}else if(p){u=[];for(var x=0,b=p(h.text,h.sectionIndex,tc(h,s,n,e));x<b.length;x+=1){var _=b[x],w=new Wl;w.text=_[0],w.sectionIndex=_[1],w.sections=h.sections,u.push(w)}}else u=function(t,e){for(var r=[],n=t.text,i=0,a=0,o=e;a<o.length;a+=1){var s=o[a];r.push(t.substring(i,s)),i=s}return i<n.length&&r.push(t.substring(i,n.length)),r}(h,tc(h,s,n,e));var k=[],T={positionedGlyphs:k,text:h.toString(),top:l[1],bottom:l[1],left:l[0],right:l[0],writingMode:c,lineCount:u.length};return function(t,e,r,n,i,a,o,s){for(var l=0,c=-17,u=0,h=t.positionedGlyphs,f=\"right\"===a?1:\"left\"===a?0:.5,p=0,d=r;p<d.length;p+=1){var g=d[p];g.trim();var v=g.getMaxScale();if(g.length()){for(var m=h.length,y=0;y<g.length();y++){var x=g.getSection(y),b=g.getCharCode(y),_=24*(v-x.scale),w=e[x.fontStack],k=w&&w[b];k&&(On(b)&&o!==Yl.horizontal?(h.push({glyph:b,x:l,y:_,vertical:!0,scale:x.scale,fontStack:x.fontStack}),l+=Gl*x.scale+s):(h.push({glyph:b,x:l,y:c+_,vertical:!1,scale:x.scale,fontStack:x.fontStack}),l+=k.metrics.advance*x.scale+s))}if(h.length!==m){var T=l-s;u=Math.max(T,u),rc(h,e,m,h.length-1,f)}l=0,c+=n*v}else c+=n}var A=ec(i),M=A.horizontalAlign,S=A.verticalAlign;!function(t,e,r,n,i,a,o){for(var s=(e-r)*i,l=(-n*o+.5)*a,c=0;c<t.length;c++)t[c].x+=s,t[c].y+=l}(h,f,M,S,u,n,r.length);var E=c- -17;t.top+=-S*E,t.bottom=t.top+E,t.left+=-M*u,t.right=t.left+u}(T,e,u,i,a,o,c,s),!!k.length&&T}Wl.fromFeature=function(t,e){for(var r=new Wl,n=0;n<t.sections.length;n++){var i=t.sections[n];r.sections.push({scale:i.scale||1,fontStack:i.fontStack||e}),r.text+=i.text;for(var a=0;a<i.text.length;a++)r.sectionIndex.push(n)}return r},Wl.prototype.length=function(){return this.text.length},Wl.prototype.getSection=function(t){return this.sections[this.sectionIndex[t]]},Wl.prototype.getCharCode=function(t){return this.text.charCodeAt(t)},Wl.prototype.verticalizePunctuation=function(){this.text=function(t){for(var e=\"\",r=0;r<t.length;r++){var n=t.charCodeAt(r+1)||null,i=t.charCodeAt(r-1)||null;n&&zn(n)&&!xs[t[r+1]]||i&&zn(i)&&!xs[t[r-1]]||!xs[t[r]]?e+=t[r]:e+=xs[t[r]]}return e}(this.text)},Wl.prototype.trim=function(){for(var t=0,e=0;e<this.text.length&&Zl[this.text.charCodeAt(e)];e++)t++;for(var r=this.text.length,n=this.text.length-1;n>=0&&n>=t&&Zl[this.text.charCodeAt(n)];n--)r--;this.text=this.text.substring(t,r),this.sectionIndex=this.sectionIndex.slice(t,r)},Wl.prototype.substring=function(t,e){var r=new Wl;return r.text=this.text.substring(t,e),r.sectionIndex=this.sectionIndex.slice(t,e),r.sections=this.sections,r},Wl.prototype.toString=function(){return this.text},Wl.prototype.getMaxScale=function(){var t=this;return this.sectionIndex.reduce(function(e,r){return Math.max(e,t.sections[r].scale)},0)};var Zl={9:!0,10:!0,11:!0,12:!0,13:!0,32:!0},Jl={};function Kl(t,e,r,n){var i=Math.pow(t-e,2);return n?t<e?i/2:2*i:i+Math.abs(r)*r}function $l(t,e,r){var n=0;return 10===t&&(n-=1e4),r&&(n+=150),40!==t&&65288!==t||(n+=50),41!==e&&65289!==e||(n+=50),n}function Ql(t,e,r,n,i,a){for(var o=null,s=Kl(e,r,i,a),l=0,c=n;l<c.length;l+=1){var u=c[l],h=Kl(e-u.x,r,i,a)+u.badness;h<=s&&(o=u,s=h)}return{index:t,x:e,priorBreak:o,badness:s}}function tc(t,e,r,n){if(!r)return[];if(!t)return[];for(var i,a=[],o=function(t,e,r,n){for(var i=0,a=0;a<t.length();a++){var o=t.getSection(a),s=n[o.fontStack],l=s&&s[t.getCharCode(a)];l&&(i+=l.metrics.advance*o.scale+e)}return i/Math.max(1,Math.ceil(i/r))}(t,e,r,n),s=t.text.indexOf(\"\\u200b\")>=0,l=0,c=0;c<t.length();c++){var u=t.getSection(c),h=t.getCharCode(c),f=n[u.fontStack],p=f&&f[h];if(p&&!Zl[h]&&(l+=p.metrics.advance*u.scale+e),c<t.length()-1){var d=!((i=h)<11904||!(En[\"Bopomofo Extended\"](i)||En.Bopomofo(i)||En[\"CJK Compatibility Forms\"](i)||En[\"CJK Compatibility Ideographs\"](i)||En[\"CJK Compatibility\"](i)||En[\"CJK Radicals Supplement\"](i)||En[\"CJK Strokes\"](i)||En[\"CJK Symbols and Punctuation\"](i)||En[\"CJK Unified Ideographs Extension A\"](i)||En[\"CJK Unified Ideographs\"](i)||En[\"Enclosed CJK Letters and Months\"](i)||En[\"Halfwidth and Fullwidth Forms\"](i)||En.Hiragana(i)||En[\"Ideographic Description Characters\"](i)||En[\"Kangxi Radicals\"](i)||En[\"Katakana Phonetic Extensions\"](i)||En.Katakana(i)||En[\"Vertical Forms\"](i)||En[\"Yi Radicals\"](i)||En[\"Yi Syllables\"](i)));(Jl[h]||d)&&a.push(Ql(c+1,l,o,a,$l(h,t.getCharCode(c+1),d&&s),!1))}}return function t(e){return e?t(e.priorBreak).concat(e.index):[]}(Ql(t.length(),l,o,a,0,!0))}function ec(t){var e=.5,r=.5;switch(t){case\"right\":case\"top-right\":case\"bottom-right\":e=1;break;case\"left\":case\"top-left\":case\"bottom-left\":e=0}switch(t){case\"bottom\":case\"bottom-right\":case\"bottom-left\":r=1;break;case\"top\":case\"top-right\":case\"top-left\":r=0}return{horizontalAlign:e,verticalAlign:r}}function rc(t,e,r,n,i){if(i){var a=t[n],o=e[a.fontStack],s=o&&o[a.glyph];if(s)for(var l=s.metrics.advance*a.scale,c=(t[n].x+l)*i,u=r;u<=n;u++)t[u].x-=c}}function nc(t,e,r){var n=ec(r),i=n.horizontalAlign,a=n.verticalAlign,o=e[0],s=e[1],l=o-t.displaySize[0]*i,c=l+t.displaySize[0],u=s-t.displaySize[1]*a;return{image:t,top:u,bottom:u+t.displaySize[1],left:l,right:c}}function ic(t,e,r,n,i){if(void 0===e.segment)return!0;for(var a=e,o=e.segment+1,s=0;s>-r/2;){if(--o<0)return!1;s-=t[o].dist(a),a=t[o]}s+=t[o].dist(t[o+1]),o++;for(var l=[],c=0;s<r/2;){var u=t[o-1],h=t[o],f=t[o+1];if(!f)return!1;var p=u.angleTo(h)-h.angleTo(f);for(p=Math.abs((p+3*Math.PI)%(2*Math.PI)-Math.PI),l.push({distance:s,angleDelta:p}),c+=p;s-l[0].distance>n;)c-=l.shift().angleDelta;if(c>i)return!1;o++,s+=h.dist(f)}return!0}function ac(t){for(var e=0,r=0;r<t.length-1;r++)e+=t[r].dist(t[r+1]);return e}function oc(t,e,r){return t?.6*e*r:0}function sc(t,e){return Math.max(t?t.right-t.left:0,e?e.right-e.left:0)}function lc(t,e,r,n,i,a){for(var o=oc(r,i,a),s=sc(r,n)*a,l=0,c=ac(t)/2,u=0;u<t.length-1;u++){var h=t[u],f=t[u+1],p=h.dist(f);if(l+p>c){var d=(c-l)/p,g=Ee(h.x,f.x,d),v=Ee(h.y,f.y,d),m=new bs(g,v,f.angleTo(h),u);return m._round(),!o||ic(t,m,s,o,e)?m:void 0}l+=p}}function cc(t,e,r,n,i,a,o,s,l){var c=oc(n,a,o),u=sc(n,i),h=u*o,f=0===t[0].x||t[0].x===l||0===t[0].y||t[0].y===l;return e-h<e/4&&(e=h+e/4),function t(e,r,n,i,a,o,s,l,c){for(var u=o/2,h=ac(e),f=0,p=r-n,d=[],g=0;g<e.length-1;g++){for(var v=e[g],m=e[g+1],y=v.dist(m),x=m.angleTo(v);p+n<f+y;){var b=((p+=n)-f)/y,_=Ee(v.x,m.x,b),w=Ee(v.y,m.y,b);if(_>=0&&_<c&&w>=0&&w<c&&p-u>=0&&p+u<=h){var k=new bs(_,w,x,g);k._round(),i&&!ic(e,k,o,i,a)||d.push(k)}}f+=y}return l||d.length||s||(d=t(e,f/2,n,i,a,o,s,!0,c)),d}(t,f?e/2*s%e:(u/2+2*a)*o*s%e,e,c,r,h,f,!1,l)}Jl[10]=!0,Jl[32]=!0,Jl[38]=!0,Jl[40]=!0,Jl[41]=!0,Jl[43]=!0,Jl[45]=!0,Jl[47]=!0,Jl[173]=!0,Jl[183]=!0,Jl[8203]=!0,Jl[8208]=!0,Jl[8211]=!0,Jl[8231]=!0;var uc=function(t,e,r,n,a,o,s,l,c,u,h,f){var p=s.top*l-c,d=s.bottom*l+c,g=s.left*l-c,v=s.right*l+c;if(this.boxStartIndex=t.length,u){var m=d-p,y=v-g;m>0&&(m=Math.max(10*l,m),this._addLineCollisionCircles(t,e,r,r.segment,y,m,n,a,o,h))}else{if(f){var x=new i(g,p),b=new i(v,p),_=new i(g,d),w=new i(v,d),k=f*Math.PI/180;x._rotate(k),b._rotate(k),_._rotate(k),w._rotate(k),g=Math.min(x.x,b.x,_.x,w.x),v=Math.max(x.x,b.x,_.x,w.x),p=Math.min(x.y,b.y,_.y,w.y),d=Math.max(x.y,b.y,_.y,w.y)}t.emplaceBack(r.x,r.y,g,p,v,d,n,a,o,0,0)}this.boxEndIndex=t.length};uc.prototype._addLineCollisionCircles=function(t,e,r,n,i,a,o,s,l,c){var u=a/2,h=Math.floor(i/u)||1,f=1+.4*Math.log(c)/Math.LN2,p=Math.floor(h*f/2),d=-a/2,g=r,v=n+1,m=d,y=-i/2,x=y-i/4;do{if(--v<0){if(m>y)return;v=0;break}m-=e[v].dist(g),g=e[v]}while(m>x);for(var b=e[v].dist(e[v+1]),_=-p;_<h+p;_++){var w=_*u,k=y+w;if(w<0&&(k+=w),w>i&&(k+=w-i),!(k<m)){for(;m+b<k;){if(m+=b,++v+1>=e.length)return;b=e[v].dist(e[v+1])}var T=k-m,A=e[v],M=e[v+1].sub(A)._unit()._mult(T)._add(A)._round(),S=Math.abs(k-d)<u?0:.8*(k-d);t.emplaceBack(M.x,M.y,-a/2,-a/2,a/2,a/2,o,s,l,a/2,S)}}};var hc=function(t,e){if(void 0===t&&(t=[]),void 0===e&&(e=fc),this.data=t,this.length=this.data.length,this.compare=e,this.length>0)for(var r=(this.length>>1)-1;r>=0;r--)this._down(r)};function fc(t,e){return t<e?-1:t>e?1:0}function pc(t,e,r){void 0===e&&(e=1),void 0===r&&(r=!1);for(var n=1/0,a=1/0,o=-1/0,s=-1/0,l=t[0],c=0;c<l.length;c++){var u=l[c];(!c||u.x<n)&&(n=u.x),(!c||u.y<a)&&(a=u.y),(!c||u.x>o)&&(o=u.x),(!c||u.y>s)&&(s=u.y)}var h=o-n,f=s-a,p=Math.min(h,f),d=p/2,g=new hc([],dc);if(0===p)return new i(n,a);for(var v=n;v<o;v+=p)for(var m=a;m<s;m+=p)g.push(new gc(v+d,m+d,d,t));for(var y=function(t){for(var e=0,r=0,n=0,i=t[0],a=0,o=i.length,s=o-1;a<o;s=a++){var l=i[a],c=i[s],u=l.x*c.y-c.x*l.y;r+=(l.x+c.x)*u,n+=(l.y+c.y)*u,e+=3*u}return new gc(r/e,n/e,0,t)}(t),x=g.length;g.length;){var b=g.pop();(b.d>y.d||!y.d)&&(y=b,r&&console.log(\"found best %d after %d probes\",Math.round(1e4*b.d)/1e4,x)),b.max-y.d<=e||(d=b.h/2,g.push(new gc(b.p.x-d,b.p.y-d,d,t)),g.push(new gc(b.p.x+d,b.p.y-d,d,t)),g.push(new gc(b.p.x-d,b.p.y+d,d,t)),g.push(new gc(b.p.x+d,b.p.y+d,d,t)),x+=4)}return r&&(console.log(\"num probes: \"+x),console.log(\"best distance: \"+y.d)),y.p}function dc(t,e){return e.max-t.max}function gc(t,e,r,n){this.p=new i(t,e),this.h=r,this.d=function(t,e){for(var r=!1,n=1/0,i=0;i<e.length;i++)for(var a=e[i],o=0,s=a.length,l=s-1;o<s;l=o++){var c=a[o],u=a[l];c.y>t.y!=u.y>t.y&&t.x<(u.x-c.x)*(t.y-c.y)/(u.y-c.y)+c.x&&(r=!r),n=Math.min(n,ka(t,c,u))}return(r?1:-1)*Math.sqrt(n)}(this.p,n),this.max=this.d+this.h*Math.SQRT2}hc.prototype.push=function(t){this.data.push(t),this.length++,this._up(this.length-1)},hc.prototype.pop=function(){if(0!==this.length){var t=this.data[0];return this.length--,this.length>0&&(this.data[0]=this.data[this.length],this._down(0)),this.data.pop(),t}},hc.prototype.peek=function(){return this.data[0]},hc.prototype._up=function(t){for(var e=this.data,r=this.compare,n=e[t];t>0;){var i=t-1>>1,a=e[i];if(r(n,a)>=0)break;e[t]=a,t=i}e[t]=n},hc.prototype._down=function(t){for(var e=this.data,r=this.compare,n=this.length>>1,i=e[t];t<n;){var a=1+(t<<1),o=e[a],s=a+1;if(s<this.length&&r(e[s],o)<0&&(a=s,o=e[s]),r(o,i)>=0)break;e[t]=o,t=a}e[t]=i};var vc=e(function(t){t.exports=function(t,e){var r,n,i,a,o,s,l,c;for(r=3&t.length,n=t.length-r,i=e,o=3432918353,s=461845907,c=0;c<n;)l=255&t.charCodeAt(c)|(255&t.charCodeAt(++c))<<8|(255&t.charCodeAt(++c))<<16|(255&t.charCodeAt(++c))<<24,++c,i=27492+(65535&(a=5*(65535&(i=(i^=l=(65535&(l=(l=(65535&l)*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295)<<13|i>>>19))+((5*(i>>>16)&65535)<<16)&4294967295))+((58964+(a>>>16)&65535)<<16);switch(l=0,r){case 3:l^=(255&t.charCodeAt(c+2))<<16;case 2:l^=(255&t.charCodeAt(c+1))<<8;case 1:i^=l=(65535&(l=(l=(65535&(l^=255&t.charCodeAt(c)))*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295}return i^=t.length,i=2246822507*(65535&(i^=i>>>16))+((2246822507*(i>>>16)&65535)<<16)&4294967295,i=3266489909*(65535&(i^=i>>>13))+((3266489909*(i>>>16)&65535)<<16)&4294967295,(i^=i>>>16)>>>0}}),mc=e(function(t){t.exports=function(t,e){for(var r,n=t.length,i=e^n,a=0;n>=4;)r=1540483477*(65535&(r=255&t.charCodeAt(a)|(255&t.charCodeAt(++a))<<8|(255&t.charCodeAt(++a))<<16|(255&t.charCodeAt(++a))<<24))+((1540483477*(r>>>16)&65535)<<16),i=1540483477*(65535&i)+((1540483477*(i>>>16)&65535)<<16)^(r=1540483477*(65535&(r^=r>>>24))+((1540483477*(r>>>16)&65535)<<16)),n-=4,++a;switch(n){case 3:i^=(255&t.charCodeAt(a+2))<<16;case 2:i^=(255&t.charCodeAt(a+1))<<8;case 1:i=1540483477*(65535&(i^=255&t.charCodeAt(a)))+((1540483477*(i>>>16)&65535)<<16)}return i=1540483477*(65535&(i^=i>>>13))+((1540483477*(i>>>16)&65535)<<16),(i^=i>>>15)>>>0}}),yc=vc,xc=vc,bc=mc;yc.murmur3=xc,yc.murmur2=bc;var _c=7;function wc(t,e){var r=0,n=0,i=e/Math.sqrt(2);switch(t){case\"top-right\":case\"top-left\":n=i-_c;break;case\"bottom-right\":case\"bottom-left\":n=-i+_c;break;case\"bottom\":n=-e+_c;break;case\"top\":n=e-_c}switch(t){case\"top-right\":case\"bottom-right\":r=-i;break;case\"top-left\":case\"bottom-left\":r=i;break;case\"left\":r=e;break;case\"right\":r=-e}return[r,n]}function kc(t){switch(t){case\"right\":case\"top-right\":case\"bottom-right\":return\"right\";case\"left\":case\"top-left\":case\"bottom-left\":return\"left\"}return\"center\"}function Tc(t,e,r,n,a,o,s){var l=o.layoutTextSize.evaluate(e,{}),c=o.layoutIconSize.evaluate(e,{}),u=o.textMaxSize.evaluate(e,{});void 0===u&&(u=l);var h=t.layers[0].layout,f=h.get(\"icon-offset\").evaluate(e,{}),p=Sc(r.horizontal),d=l/24,g=t.tilePixelRatio*d,v=t.tilePixelRatio*u/24,m=t.tilePixelRatio*c,y=t.tilePixelRatio*h.get(\"symbol-spacing\"),x=h.get(\"text-padding\")*t.tilePixelRatio,b=h.get(\"icon-padding\")*t.tilePixelRatio,_=h.get(\"text-max-angle\")/180*Math.PI,k=\"map\"===h.get(\"text-rotation-alignment\")&&\"point\"!==h.get(\"symbol-placement\"),T=\"map\"===h.get(\"icon-rotation-alignment\")&&\"point\"!==h.get(\"symbol-placement\"),A=h.get(\"symbol-placement\"),M=y/2,S=function(l,c){c.x<0||c.x>=ha||c.y<0||c.y>=ha||function(t,e,r,n,a,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_){var k,T,A=t.addToLineVertexArray(e,r),M=0,S=0,E=0,C={},L=yc(\"\"),P=(o.layout.get(\"text-radial-offset\").evaluate(x,{})||0)*Gl;for(var O in n.horizontal){var z=n.horizontal[O];if(!k){L=yc(z.text);var I=o.layout.get(\"text-rotate\").evaluate(x,{});k=new uc(s,r,e,l,c,u,z,h,f,p,t.overscaling,I)}var D=1===z.lineCount;if(S+=Mc(t,e,z,o,p,x,d,A,n.vertical?Yl.horizontal:Yl.horizontalOnly,D?Object.keys(n.horizontal):[O],C,b,_),D)break}n.vertical&&(E+=Mc(t,e,n.vertical,o,p,x,d,A,Yl.vertical,[\"vertical\"],C,b,_));var R=k?k.boxStartIndex:t.collisionBoxArray.length,F=k?k.boxEndIndex:t.collisionBoxArray.length;if(a){var B=function(t,e,r,n,a,o){var s,l,c,u,h=e.image,f=r.layout,p=e.top-1/h.pixelRatio,d=e.left-1/h.pixelRatio,g=e.bottom+1/h.pixelRatio,v=e.right+1/h.pixelRatio;if(\"none\"!==f.get(\"icon-text-fit\")&&a){var m=v-d,y=g-p,x=f.get(\"text-size\").evaluate(o,{})/24,b=a.left*x,_=a.right*x,w=a.top*x,k=_-b,T=a.bottom*x-w,A=f.get(\"icon-text-fit-padding\")[0],M=f.get(\"icon-text-fit-padding\")[1],S=f.get(\"icon-text-fit-padding\")[2],E=f.get(\"icon-text-fit-padding\")[3],C=\"width\"===f.get(\"icon-text-fit\")?.5*(T-y):0,L=\"height\"===f.get(\"icon-text-fit\")?.5*(k-m):0,P=\"width\"===f.get(\"icon-text-fit\")||\"both\"===f.get(\"icon-text-fit\")?k:m,O=\"height\"===f.get(\"icon-text-fit\")||\"both\"===f.get(\"icon-text-fit\")?T:y;s=new i(b+L-E,w+C-A),l=new i(b+L+M+P,w+C-A),c=new i(b+L+M+P,w+C+S+O),u=new i(b+L-E,w+C+S+O)}else s=new i(d,p),l=new i(v,p),c=new i(v,g),u=new i(d,g);var z=r.layout.get(\"icon-rotate\").evaluate(o,{})*Math.PI/180;if(z){var I=Math.sin(z),D=Math.cos(z),R=[D,-I,I,D];s._matMult(R),l._matMult(R),u._matMult(R),c._matMult(R)}return[{tl:s,tr:l,bl:u,br:c,tex:h.paddedRect,writingMode:void 0,glyphOffset:[0,0]}]}(0,a,o,0,Sc(n.horizontal),x),N=o.layout.get(\"icon-rotate\").evaluate(x,{});T=new uc(s,r,e,l,c,u,a,g,v,!1,t.overscaling,N),M=4*B.length;var j=t.iconSizeData,U=null;\"source\"===j.kind?(U=[_s*o.layout.get(\"icon-size\").evaluate(x,{})])[0]>Ac&&w(t.layerIds[0]+': Value for \"icon-size\" is >= 256. Reduce your \"icon-size\".'):\"composite\"===j.kind&&((U=[_s*_.compositeIconSizes[0].evaluate(x,{}),_s*_.compositeIconSizes[1].evaluate(x,{})])[0]>Ac||U[1]>Ac)&&w(t.layerIds[0]+': Value for \"icon-size\" is >= 256. Reduce your \"icon-size\".'),t.addSymbols(t.icon,B,U,y,m,x,!1,e,A.lineStartIndex,A.lineLength)}var V=T?T.boxStartIndex:t.collisionBoxArray.length,q=T?T.boxEndIndex:t.collisionBoxArray.length;t.glyphOffsetArray.length>=Os.MAX_GLYPHS&&w(\"Too many glyphs being rendered in a tile. See https://github.com/mapbox/mapbox-gl-js/issues/2907\"),t.symbolInstances.emplaceBack(e.x,e.y,C.right>=0?C.right:-1,C.center>=0?C.center:-1,C.left>=0?C.left:-1,C.vertical||-1,L,R,F,V,q,l,S,E,M,0,h,P)}(t,c,l,r,n,t.layers[0],t.collisionBoxArray,e.index,e.sourceLayerIndex,t.index,g,x,k,s,m,b,T,f,e,a,o)};if(\"line\"===A)for(var E=0,C=function(t,e,r,n,a){for(var o=[],s=0;s<t.length;s++)for(var l=t[s],c=void 0,u=0;u<l.length-1;u++){var h=l[u],f=l[u+1];h.x<0&&f.x<0||(h.x<0?h=new i(0,h.y+(f.y-h.y)*((0-h.x)/(f.x-h.x)))._round():f.x<0&&(f=new i(0,h.y+(f.y-h.y)*((0-h.x)/(f.x-h.x)))._round()),h.y<0&&f.y<0||(h.y<0?h=new i(h.x+(f.x-h.x)*((0-h.y)/(f.y-h.y)),0)._round():f.y<0&&(f=new i(h.x+(f.x-h.x)*((0-h.y)/(f.y-h.y)),0)._round()),h.x>=n&&f.x>=n||(h.x>=n?h=new i(n,h.y+(f.y-h.y)*((n-h.x)/(f.x-h.x)))._round():f.x>=n&&(f=new i(n,h.y+(f.y-h.y)*((n-h.x)/(f.x-h.x)))._round()),h.y>=a&&f.y>=a||(h.y>=a?h=new i(h.x+(f.x-h.x)*((a-h.y)/(f.y-h.y)),a)._round():f.y>=a&&(f=new i(h.x+(f.x-h.x)*((a-h.y)/(f.y-h.y)),a)._round()),c&&h.equals(c[c.length-1])||(c=[h],o.push(c)),c.push(f)))))}return o}(e.geometry,0,0,ha,ha);E<C.length;E+=1)for(var L=C[E],P=0,O=cc(L,y,_,r.vertical||p,n,24,v,t.overscaling,ha);P<O.length;P+=1){var z=O[P];p&&Ec(t,p.text,M,z)||S(L,z)}else if(\"line-center\"===A)for(var I=0,D=e.geometry;I<D.length;I+=1){var R=D[I];if(R.length>1){var F=lc(R,_,r.vertical||p,n,24,v);F&&S(R,F)}}else if(\"Polygon\"===e.type)for(var B=0,N=Mo(e.geometry,0);B<N.length;B+=1){var j=N[B],U=pc(j,16);S(j[0],new bs(U.x,U.y,0))}else if(\"LineString\"===e.type)for(var V=0,q=e.geometry;V<q.length;V+=1){var H=q[V];S(H,new bs(H[0].x,H[0].y,0))}else if(\"Point\"===e.type)for(var G=0,Y=e.geometry;G<Y.length;G+=1)for(var W=0,X=Y[G];W<X.length;W+=1){var Z=X[W];S([Z],new bs(Z.x,Z.y,0))}}var Ac=65535;function Mc(t,e,r,n,a,o,s,l,c,u,h,f,p){var d=function(t,e,r,n,a,o,s){for(var l=n.layout.get(\"text-rotate\").evaluate(o,{})*Math.PI/180,c=e.positionedGlyphs,u=[],h=0;h<c.length;h++){var f=c[h],p=s[f.fontStack],d=p&&p[f.glyph];if(d){var g=d.rect;if(g){var v=bl+1,m=d.metrics.advance*f.scale/2,y=a?[f.x+m,f.y]:[0,0],x=a?[0,0]:[f.x+m+r[0],f.y+r[1]],b=(d.metrics.left-v)*f.scale-m+x[0],_=(-d.metrics.top-v)*f.scale+x[1],w=b+g.w*f.scale,k=_+g.h*f.scale,T=new i(b,_),A=new i(w,_),M=new i(b,k),S=new i(w,k);if(a&&f.vertical){var E=new i(-m,m),C=-Math.PI/2,L=new i(5,0);T._rotateAround(C,E)._add(L),A._rotateAround(C,E)._add(L),M._rotateAround(C,E)._add(L),S._rotateAround(C,E)._add(L)}if(l){var P=Math.sin(l),O=Math.cos(l),z=[O,-P,P,O];T._matMult(z),A._matMult(z),M._matMult(z),S._matMult(z)}u.push({tl:T,tr:A,bl:M,br:S,tex:g,writingMode:e.writingMode,glyphOffset:y})}}}return u}(0,r,s,n,a,o,f),g=t.textSizeData,v=null;\"source\"===g.kind?(v=[_s*n.layout.get(\"text-size\").evaluate(o,{})])[0]>Ac&&w(t.layerIds[0]+': Value for \"text-size\" is >= 256. Reduce your \"text-size\".'):\"composite\"===g.kind&&((v=[_s*p.compositeTextSizes[0].evaluate(o,{}),_s*p.compositeTextSizes[1].evaluate(o,{})])[0]>Ac||v[1]>Ac)&&w(t.layerIds[0]+': Value for \"text-size\" is >= 256. Reduce your \"text-size\".'),t.addSymbols(t.text,d,v,s,a,o,c,e,l.lineStartIndex,l.lineLength);for(var m=0,y=u;m<y.length;m+=1)h[y[m]]=t.text.placedSymbolArray.length-1;return 4*d.length}function Sc(t){for(var e in t)return t[e];return null}function Ec(t,e,r,n){var i=t.compareText;if(e in i){for(var a=i[e],o=a.length-1;o>=0;o--)if(n.dist(a[o])<r)return!0}else i[e]=[];return i[e].push(n),!1}t.Actor=_l,t.AlphaImage=qa,t.CanonicalTileID=Pl,t.CollisionBoxArray=Li,t.Color=ne,t.DEMData=Dl,t.DataConstantProperty=Jn,t.DictionaryCoder=Fl,t.EXTENT=ha,t.ErrorEvent=Ot,t.EvaluationParameters=Un,t.Event=Pt,t.Evented=zt,t.FeatureIndex=Ul,t.FillBucket=Lo,t.FillExtrusionBucket=Yo,t.ImageAtlas=Gs,t.ImagePosition=qs,t.LineBucket=os,t.LngLat=Tl,t.LngLatBounds=kl,t.MercatorCoordinate=Ll,t.ONE_EM=Gl,t.OverscaledTileID=zl,t.Point=i,t.Point$1=i,t.ProgramConfiguration=sa,t.Properties=ei,t.Protobuf=Qs,t.RGBAImage=Ha,t.RequestManager=j,t.ResourceType=yt,t.SegmentVector=Vi,t.SourceFeatureState=jl,t.StructArrayLayout1ui2=Mi,t.StructArrayLayout2i4=li,t.StructArrayLayout2ui4=Ai,t.StructArrayLayout3ui6=Ti,t.StructArrayLayout4i8=ci,t.SymbolBucket=Os,t.Texture=Js,t.Tile=Hl,t.Transitionable=Hn,t.Uniform1f=Xi,t.Uniform1i=Wi,t.Uniform2f=Zi,t.Uniform3f=Ji,t.Uniform4f=Ki,t.UniformColor=$i,t.UniformMatrix4f=ta,t.UnwrappedTileID=Ol,t.ValidationError=Dt,t.WritingMode=Yl,t.ZoomHistory=Sn,t.addDynamicAttributes=Cs,t.asyncAll=function(t,e,r){if(!t.length)return r(null,[]);var n=t.length,i=new Array(t.length),a=null;t.forEach(function(t,o){e(t,function(t,e){t&&(a=t),i[o]=e,0==--n&&r(a,i)})})},t.bezier=s,t.bindAll=v,t.browser=z,t.cacheEntryPossiblyAdded=function(t){++mt>dt&&(t.send(\"enforceCacheSizeLimit\",pt),mt=0)},t.clamp=c,t.clearTileCache=function(t){var e=self.caches.delete(ft);t&&e.catch(t).then(function(){return t()})},t.clone=function(t){var e=new Pa(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e},t.clone$1=b,t.config=I,t.create=function(){var t=new Pa(16);return Pa!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=0,t[12]=0,t[13]=0,t[14]=0),t[0]=1,t[5]=1,t[10]=1,t[15]=1,t},t.create$1=Oa,t.create$2=function(){var t=new Pa(4);return Pa!=Float32Array&&(t[1]=0,t[2]=0),t[0]=1,t[3]=1,t},t.createCommonjsModule=e,t.createExpression=Or,t.createLayout=oi,t.createStyleLayer=function(t){return\"custom\"===t.type?new js(t):new Us[t.type](t)},t.deepEqual=o,t.ease=l,t.emitValidationErrors=mn,t.endsWith=m,t.enforceCacheSizeLimit=function(t){self.caches&&self.caches.open(ft).then(function(e){e.keys().then(function(r){for(var n=0;n<r.length-t;n++)e.delete(r[n])})})},t.evaluateRadialOffset=wc,t.evaluateSizeForFeature=ks,t.evaluateSizeForZoom=Ts,t.evented=Nn,t.extend=h,t.featureFilter=Gr,t.filterObject=x,t.fromRotation=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=r,t[2]=0,t[3]=-r,t[4]=n,t[5]=0,t[6]=0,t[7]=0,t[8]=1,t},t.getAnchorAlignment=ec,t.getAnchorJustification=kc,t.getArrayBuffer=Mt,t.getImage=Et,t.getJSON=function(t,e){return At(h(t,{type:\"json\"}),e)},t.getReferrer=_t,t.getVideo=function(t,e){var r,n,i=self.document.createElement(\"video\");i.muted=!0,i.onloadstart=function(){e(null,i)};for(var a=0;a<t.length;a++){var o=self.document.createElement(\"source\");r=t[a],n=void 0,(n=self.document.createElement(\"a\")).href=r,(n.protocol!==self.document.location.protocol||n.host!==self.document.location.host)&&(i.crossOrigin=\"Anonymous\"),o.src=t[a],i.appendChild(o)}return{cancel:function(){}}},t.identity=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t},t.invert=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],g=e[13],v=e[14],m=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,k=i*c-a*l,T=u*g-h*d,A=u*v-f*d,M=u*m-p*d,S=h*v-f*g,E=h*m-p*g,C=f*m-p*v,L=y*C-x*E+b*S+_*M-w*A+k*T;return L?(L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(i*E-n*C-a*S)*L,t[2]=(g*k-v*w+m*_)*L,t[3]=(f*w-h*k-p*_)*L,t[4]=(l*M-o*C-c*A)*L,t[5]=(r*C-i*M+a*A)*L,t[6]=(v*b-d*k-m*x)*L,t[7]=(u*k-f*b+p*x)*L,t[8]=(o*E-s*M+c*T)*L,t[9]=(n*M-r*E-a*T)*L,t[10]=(d*w-g*b+m*y)*L,t[11]=(h*b-u*w-p*y)*L,t[12]=(s*A-o*S-l*T)*L,t[13]=(r*S-n*A+i*T)*L,t[14]=(g*x-d*_-v*y)*L,t[15]=(u*_-h*x+f*y)*L,t):null},t.isChar=En,t.isMapboxURL=q,t.keysDifference=function(t,e){var r=[];for(var n in t)n in e||r.push(n);return r},t.makeRequest=At,t.mapObject=y,t.mercatorXfromLng=Ml,t.mercatorYfromLat=Sl,t.mercatorZfromAltitude=El,t.multiply=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],g=e[12],v=e[13],m=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*h+w*g,t[1]=x*i+b*l+_*f+w*v,t[2]=x*a+b*c+_*p+w*m,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*h+w*g,t[5]=x*i+b*l+_*f+w*v,t[6]=x*a+b*c+_*p+w*m,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*h+w*g,t[9]=x*i+b*l+_*f+w*v,t[10]=x*a+b*c+_*p+w*m,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*h+w*g,t[13]=x*i+b*l+_*f+w*v,t[14]=x*a+b*c+_*p+w*m,t[15]=x*o+b*u+_*d+w*y,t},t.mvt=Vo,t.number=Ee,t.ortho=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t},t.parseGlyphPBF=function(t){return new Qs(t).readFields(ml,[])},t.pbf=Qs,t.performSymbolLayout=function(t,e,r,n,i,a){t.createArrays();var o=512*t.overscaling;t.tilePixelRatio=ha/o,t.compareText={},t.iconsNeedLinear=!1;var s=t.layers[0].layout,l=t.layers[0]._unevaluatedLayout._values,c={};if(\"composite\"===t.textSizeData.kind){var u=t.textSizeData,h=u.minZoom,f=u.maxZoom;c.compositeTextSizes=[l[\"text-size\"].possiblyEvaluate(new Un(h)),l[\"text-size\"].possiblyEvaluate(new Un(f))]}if(\"composite\"===t.iconSizeData.kind){var p=t.iconSizeData,d=p.minZoom,g=p.maxZoom;c.compositeIconSizes=[l[\"icon-size\"].possiblyEvaluate(new Un(d)),l[\"icon-size\"].possiblyEvaluate(new Un(g))]}c.layoutTextSize=l[\"text-size\"].possiblyEvaluate(new Un(t.zoom+1)),c.layoutIconSize=l[\"icon-size\"].possiblyEvaluate(new Un(t.zoom+1)),c.textMaxSize=l[\"text-size\"].possiblyEvaluate(new Un(18));for(var v=s.get(\"text-line-height\")*Gl,m=\"map\"===s.get(\"text-rotation-alignment\")&&\"point\"!==s.get(\"symbol-placement\"),y=s.get(\"text-keep-upright\"),x=0,b=t.features;x<b.length;x+=1){var _=b[x],k=s.get(\"text-font\").evaluate(_,{}).join(\",\"),T=r,A={horizontal:{},vertical:void 0},M=_.text,S=[0,0];if(M){var E=M.toString(),C=s.get(\"text-letter-spacing\").evaluate(_,{})*Gl,L=Ln(E)?C:0,P=s.get(\"text-anchor\").evaluate(_,{}),O=s.get(\"text-variable-anchor\"),z=s.get(\"text-radial-offset\").evaluate(_,{});O||(S=z?wc(P,z*Gl):s.get(\"text-offset\").evaluate(_,{}).map(function(t){return t*Gl}));var I=m?\"center\":s.get(\"text-justify\").evaluate(_,{}),D=\"point\"===s.get(\"symbol-placement\")?s.get(\"text-max-width\").evaluate(_,{})*Gl:0;if(!m&&O)for(var R=\"auto\"===I?O.map(function(t){return kc(t)}):[I],F=!1,B=0;B<R.length;B++){var N=R[B];if(!A.horizontal[N])if(F)A.horizontal[N]=A.horizontal[0];else{var j=Xl(M,e,k,D,v,\"center\",N,L,S,Yl.horizontal);j&&(A.horizontal[N]=j,F=1===j.lineCount)}}else{\"auto\"===I&&(I=kc(P));var U=Xl(M,e,k,D,v,P,I,L,S,Yl.horizontal);U&&(A.horizontal[I]=U),Cn(E)&&m&&y&&(A.vertical=Xl(M,e,k,D,v,P,I,L,S,Yl.vertical))}}var V=void 0;if(_.icon){var q=n[_.icon];q&&(V=nc(i[_.icon],s.get(\"icon-offset\").evaluate(_,{}),s.get(\"icon-anchor\").evaluate(_,{})),void 0===t.sdfIcons?t.sdfIcons=q.sdf:t.sdfIcons!==q.sdf&&w(\"Style sheet warning: Cannot mix SDF and non-SDF icons in one buffer\"),q.pixelRatio!==t.pixelRatio?t.iconsNeedLinear=!0:0!==s.get(\"icon-rotate\").constantOr(1)&&(t.iconsNeedLinear=!0))}(Object.keys(A.horizontal).length||V)&&Tc(t,_,A,V,T,c,S)}a&&t.generateCollisionDebugBuffers()},t.perspective=function(t,e,r,n,i){var a,o=1/Math.tan(e/2);return t[0]=o/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=o,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=-1,t[12]=0,t[13]=0,t[15]=0,null!=i&&i!==1/0?(a=1/(n-i),t[10]=(i+n)*a,t[14]=2*i*n*a):(t[10]=-1,t[14]=-2*n),t},t.pick=function(t,e){for(var r={},n=0;n<e.length;n++){var i=e[n];i in t&&(r[i]=t[i])}return r},t.plugin=jn,t.polygonIntersectsPolygon=va,t.postMapLoadEvent=ht,t.postTurnstileEvent=ct,t.potpack=Vs,t.rasterBoundsAttributes=Rl,t.refProperties=[\"type\",\"source\",\"source-layer\",\"minzoom\",\"maxzoom\",\"filter\",\"layout\"],t.register=kn,t.registerForPluginAvailability=function(t){return Fn?t({pluginURL:Fn,completionCallback:Dn}):Nn.once(\"pluginAvailable\",t),t},t.rotate=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=Math.sin(r),l=Math.cos(r);return t[0]=n*l+a*s,t[1]=i*l+o*s,t[2]=n*-s+a*l,t[3]=i*-s+o*l,t},t.rotateX=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];return e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+h*n,t[7]=l*i+f*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=h*i-s*n,t[11]=f*i-l*n,t},t.rotateZ=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];return e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+h*n,t[3]=l*i+f*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=h*i-s*n,t[7]=f*i-l*n,t},t.scale=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t},t.setCacheLimits=function(t,e){pt=t,dt=e},t.setRTLTextPlugin=function(t,e){if(Rn)throw new Error(\"setRTLTextPlugin cannot be called multiple times.\");Rn=!0,Fn=z.resolveURL(t),Dn=function(t){t?(Rn=!1,Fn=null,e&&e(t)):Bn=!0},Nn.fire(new Pt(\"pluginAvailable\",{pluginURL:Fn,completionCallback:Dn}))},t.sphericalToCartesian=function(t){var e=t[0],r=t[1],n=t[2];return r+=90,r*=Math.PI/180,n*=Math.PI/180,{x:e*Math.cos(r)*Math.sin(n),y:e*Math.sin(r)*Math.sin(n),z:e*Math.cos(n)}},t.styleSpec=It,t.symbolSize=As,t.transformMat3=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t},t.transformMat4=Da,t.translate=function(t,e,r){var n,i,a,o,s,l,c,u,h,f,p,d,g=r[0],v=r[1],m=r[2];return e===t?(t[12]=e[0]*g+e[4]*v+e[8]*m+e[12],t[13]=e[1]*g+e[5]*v+e[9]*m+e[13],t[14]=e[2]*g+e[6]*v+e[10]*m+e[14],t[15]=e[3]*g+e[7]*v+e[11]*m+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*g+s*v+h*m+e[12],t[13]=i*g+l*v+f*m+e[13],t[14]=a*g+c*v+p*m+e[14],t[15]=o*g+u*v+d*m+e[15]),t},t.uniqueId=p,t.validateCustomStyleLayer=function(t){var e=[],r=t.id;return void 0===r&&e.push({message:\"layers.\"+r+': missing required property \"id\"'}),void 0===t.render&&e.push({message:\"layers.\"+r+': missing required method \"render\"'}),t.renderingMode&&\"2d\"!==t.renderingMode&&\"3d\"!==t.renderingMode&&e.push({message:\"layers.\"+r+': property \"renderingMode\" must be either \"2d\" or \"3d\"'}),e},t.validateLight=dn,t.validateStyle=pn,t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.vectorTile=Vo,t.version=\"1.1.1\",t.warnOnce=w,t.webpSupported=D,t.window=self,t.wrap=u}),n(0,function(t){function e(t){var r=typeof t;if(\"number\"===r||\"boolean\"===r||\"string\"===r||null==t)return JSON.stringify(t);if(Array.isArray(t)){for(var n=\"[\",i=0,a=t;i<a.length;i+=1)n+=e(a[i])+\",\";return n+\"]\"}for(var o=Object.keys(t).sort(),s=\"{\",l=0;l<o.length;l++)s+=JSON.stringify(o[l])+\":\"+e(t[o[l]])+\",\";return s+\"}\"}function r(r){for(var n=\"\",i=0,a=t.refProperties;i<a.length;i+=1)n+=\"/\"+e(r[a[i]]);return n}var n=function(t){this.keyCache={},t&&this.replace(t)};n.prototype.replace=function(t){this._layerConfigs={},this._layers={},this.update(t,[])},n.prototype.update=function(e,n){for(var i=this,a=0,o=e;a<o.length;a+=1){var s=o[a];this._layerConfigs[s.id]=s;var l=this._layers[s.id]=t.createStyleLayer(s);l._featureFilter=t.featureFilter(l.filter),this.keyCache[s.id]&&delete this.keyCache[s.id]}for(var c=0,u=n;c<u.length;c+=1){var h=u[c];delete this.keyCache[h],delete this._layerConfigs[h],delete this._layers[h]}this.familiesBySource={};for(var f=0,p=function(t,e){for(var n={},i=0;i<t.length;i++){var a=e&&e[t[i].id]||r(t[i]);e&&(e[t[i].id]=a);var o=n[a];o||(o=n[a]=[]),o.push(t[i])}var s=[];for(var l in n)s.push(n[l]);return s}(t.values(this._layerConfigs),this.keyCache);f<p.length;f+=1){var d=p[f].map(function(t){return i._layers[t.id]}),g=d[0];if(\"none\"!==g.visibility){var v=g.source||\"\",m=this.familiesBySource[v];m||(m=this.familiesBySource[v]={});var y=g.sourceLayer||\"_geojsonTileLayer\",x=m[y];x||(x=m[y]=[]),x.push(d)}}};var i=function(e){var r={},n=[];for(var i in e){var a=e[i],o=r[i]={};for(var s in a){var l=a[+s];if(l&&0!==l.bitmap.width&&0!==l.bitmap.height){var c={x:0,y:0,w:l.bitmap.width+2,h:l.bitmap.height+2};n.push(c),o[s]={rect:c,metrics:l.metrics}}}}var u=t.potpack(n),h=u.w,f=u.h,p=new t.AlphaImage({width:h||1,height:f||1});for(var d in e){var g=e[d];for(var v in g){var m=g[+v];if(m&&0!==m.bitmap.width&&0!==m.bitmap.height){var y=r[d][v].rect;t.AlphaImage.copy(m.bitmap,p,{x:0,y:0},{x:y.x+1,y:y.y+1},m.bitmap)}}}this.image=p,this.positions=r};t.register(\"GlyphAtlas\",i);var a=function(e){this.tileID=new t.OverscaledTileID(e.tileID.overscaledZ,e.tileID.wrap,e.tileID.canonical.z,e.tileID.canonical.x,e.tileID.canonical.y),this.uid=e.uid,this.zoom=e.zoom,this.pixelRatio=e.pixelRatio,this.tileSize=e.tileSize,this.source=e.source,this.overscaling=this.tileID.overscaleFactor(),this.showCollisionBoxes=e.showCollisionBoxes,this.collectResourceTiming=!!e.collectResourceTiming,this.returnDependencies=!!e.returnDependencies};function o(e,r){for(var n=new t.EvaluationParameters(r),i=0,a=e;i<a.length;i+=1)a[i].recalculate(n)}a.prototype.parse=function(e,r,n,a){var s=this;this.status=\"parsing\",this.data=e,this.collisionBoxArray=new t.CollisionBoxArray;var l=new t.DictionaryCoder(Object.keys(e.layers).sort()),c=new t.FeatureIndex(this.tileID);c.bucketLayerIDs=[];var u,h,f,p,d={},g={featureIndex:c,iconDependencies:{},patternDependencies:{},glyphDependencies:{}},v=r.familiesBySource[this.source];for(var m in v){var y=e.layers[m];if(y){1===y.version&&t.warnOnce('Vector tile source \"'+this.source+'\" layer \"'+m+'\" does not use vector tile spec v2 and therefore may have some rendering errors.');for(var x=l.encode(m),b=[],_=0;_<y.length;_++){var w=y.feature(_);b.push({feature:w,index:_,sourceLayerIndex:x})}for(var k=0,T=v[m];k<T.length;k+=1){var A=T[k],M=A[0];M.minzoom&&this.zoom<Math.floor(M.minzoom)||M.maxzoom&&this.zoom>=M.maxzoom||\"none\"!==M.visibility&&(o(A,this.zoom),(d[M.id]=M.createBucket({index:c.bucketLayerIDs.length,layers:A,zoom:this.zoom,pixelRatio:this.pixelRatio,overscaling:this.overscaling,collisionBoxArray:this.collisionBoxArray,sourceLayerIndex:x,sourceID:this.source})).populate(b,g),c.bucketLayerIDs.push(A.map(function(t){return t.id})))}}}var S=t.mapObject(g.glyphDependencies,function(t){return Object.keys(t).map(Number)});Object.keys(S).length?n.send(\"getGlyphs\",{uid:this.uid,stacks:S},function(t,e){u||(u=t,h=e,L.call(s))}):h={};var E=Object.keys(g.iconDependencies);E.length?n.send(\"getImages\",{icons:E},function(t,e){u||(u=t,f=e,L.call(s))}):f={};var C=Object.keys(g.patternDependencies);function L(){if(u)return a(u);if(h&&f&&p){var e=new i(h),r=new t.ImageAtlas(f,p);for(var n in d){var s=d[n];s instanceof t.SymbolBucket?(o(s.layers,this.zoom),t.performSymbolLayout(s,h,e.positions,f,r.iconPositions,this.showCollisionBoxes)):s.hasPattern&&(s instanceof t.LineBucket||s instanceof t.FillBucket||s instanceof t.FillExtrusionBucket)&&(o(s.layers,this.zoom),s.addFeatures(g,r.patternPositions))}this.status=\"done\",a(null,{buckets:t.values(d).filter(function(t){return!t.isEmpty()}),featureIndex:c,collisionBoxArray:this.collisionBoxArray,glyphAtlasImage:e.image,imageAtlas:r,glyphMap:this.returnDependencies?h:null,iconMap:this.returnDependencies?f:null,glyphPositions:this.returnDependencies?e.positions:null})}}C.length?n.send(\"getImages\",{icons:C},function(t,e){u||(u=t,p=e,L.call(s))}):p={},L.call(this)};var s=\"undefined\"!=typeof performance,l={getEntriesByName:function(t){return!!(s&&performance&&performance.getEntriesByName)&&performance.getEntriesByName(t)},mark:function(t){return!!(s&&performance&&performance.mark)&&performance.mark(t)},measure:function(t,e,r){return!!(s&&performance&&performance.measure)&&performance.measure(t,e,r)},clearMarks:function(t){return!!(s&&performance&&performance.clearMarks)&&performance.clearMarks(t)},clearMeasures:function(t){return!!(s&&performance&&performance.clearMeasures)&&performance.clearMeasures(t)}},c=function(t){this._marks={start:[t.url,\"start\"].join(\"#\"),end:[t.url,\"end\"].join(\"#\"),measure:t.url.toString()},l.mark(this._marks.start)};function u(e,r){var n=t.getArrayBuffer(e.request,function(e,n,i,a){e?r(e):n&&r(null,{vectorTile:new t.vectorTile.VectorTile(new t.pbf(n)),rawData:n,cacheControl:i,expires:a})});return function(){n.cancel(),r()}}c.prototype.finish=function(){l.mark(this._marks.end);var t=l.getEntriesByName(this._marks.measure);return 0===t.length&&(l.measure(this._marks.measure,this._marks.start,this._marks.end),t=l.getEntriesByName(this._marks.measure),l.clearMarks(this._marks.start),l.clearMarks(this._marks.end),l.clearMeasures(this._marks.measure)),t},l.Performance=c;var h=function(t,e,r){this.actor=t,this.layerIndex=e,this.loadVectorData=r||u,this.loading={},this.loaded={}};h.prototype.loadTile=function(e,r){var n=this,i=e.uid;this.loading||(this.loading={});var o=!!(e&&e.request&&e.request.collectResourceTiming)&&new l.Performance(e.request),s=this.loading[i]=new a(e);s.abort=this.loadVectorData(e,function(e,a){if(delete n.loading[i],e||!a)return s.status=\"done\",n.loaded[i]=s,r(e);var l=a.rawData,c={};a.expires&&(c.expires=a.expires),a.cacheControl&&(c.cacheControl=a.cacheControl);var u={};if(o){var h=o.finish();h&&(u.resourceTiming=JSON.parse(JSON.stringify(h)))}s.vectorTile=a.vectorTile,s.parse(a.vectorTile,n.layerIndex,n.actor,function(e,n){if(e||!n)return r(e);r(null,t.extend({rawTileData:l.slice(0)},n,c,u))}),n.loaded=n.loaded||{},n.loaded[i]=s})},h.prototype.reloadTile=function(t,e){var r=this.loaded,n=t.uid,i=this;if(r&&r[n]){var a=r[n];a.showCollisionBoxes=t.showCollisionBoxes;var o=function(t,r){var n=a.reloadCallback;n&&(delete a.reloadCallback,a.parse(a.vectorTile,i.layerIndex,i.actor,n)),e(t,r)};\"parsing\"===a.status?a.reloadCallback=o:\"done\"===a.status&&(a.vectorTile?a.parse(a.vectorTile,this.layerIndex,this.actor,o):o())}},h.prototype.abortTile=function(t,e){var r=this.loading,n=t.uid;r&&r[n]&&r[n].abort&&(r[n].abort(),delete r[n]),e()},h.prototype.removeTile=function(t,e){var r=this.loaded,n=t.uid;r&&r[n]&&delete r[n],e()};var f=function(){this.loaded={}};f.prototype.loadTile=function(e,r){var n=e.uid,i=e.encoding,a=e.rawImageData,o=new t.DEMData(n,a,i);this.loaded=this.loaded||{},this.loaded[n]=o,r(null,o)},f.prototype.removeTile=function(t){var e=this.loaded,r=t.uid;e&&e[r]&&delete e[r]};var p={RADIUS:6378137,FLATTENING:1/298.257223563,POLAR_RADIUS:6356752.3142};function d(t){var e=0;if(t&&t.length>0){e+=Math.abs(g(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(g(t[r]))}return e}function g(t){var e,r,n,i,a,o,s=0,l=t.length;if(l>2){for(o=0;o<l;o++)o===l-2?(n=l-2,i=l-1,a=0):o===l-1?(n=l-1,i=0,a=1):(n=o,i=o+1,a=o+2),e=t[n],r=t[i],s+=(v(t[a][0])-v(e[0]))*Math.sin(v(r[1]));s=s*p.RADIUS*p.RADIUS/2}return s}function v(t){return t*Math.PI/180}var m={geometry:function t(e){var r,n=0;switch(e.type){case\"Polygon\":return d(e.coordinates);case\"MultiPolygon\":for(r=0;r<e.coordinates.length;r++)n+=d(e.coordinates[r]);return n;case\"Point\":case\"MultiPoint\":case\"LineString\":case\"MultiLineString\":return 0;case\"GeometryCollection\":for(r=0;r<e.geometries.length;r++)n+=t(e.geometries[r]);return n}},ring:g};function y(t,e){return function(r){return t(r,e)}}function x(t,e){e=!!e,t[0]=b(t[0],e);for(var r=1;r<t.length;r++)t[r]=b(t[r],!e);return t}function b(t,e){return function(t){return m.ring(t)>=0}(t)===e?t:t.reverse()}var _=t.vectorTile.VectorTileFeature.prototype.toGeoJSON,w=function(e){this._feature=e,this.extent=t.EXTENT,this.type=e.type,this.properties=e.tags,\"id\"in e&&!isNaN(e.id)&&(this.id=parseInt(e.id,10))};w.prototype.loadGeometry=function(){if(1===this._feature.type){for(var e=[],r=0,n=this._feature.geometry;r<n.length;r+=1){var i=n[r];e.push([new t.Point$1(i[0],i[1])])}return e}for(var a=[],o=0,s=this._feature.geometry;o<s.length;o+=1){for(var l=[],c=0,u=s[o];c<u.length;c+=1){var h=u[c];l.push(new t.Point$1(h[0],h[1]))}a.push(l)}return a},w.prototype.toGeoJSON=function(t,e,r){return _.call(this,t,e,r)};var k=function(e){this.layers={_geojsonTileLayer:this},this.name=\"_geojsonTileLayer\",this.extent=t.EXTENT,this.length=e.length,this._features=e};k.prototype.feature=function(t){return new w(this._features[t])};var T=t.vectorTile.VectorTileFeature,A=M;function M(t,e){this.options=e||{},this.features=t,this.length=t.length}function S(t,e){this.id=\"number\"==typeof t.id?t.id:void 0,this.type=t.type,this.rawGeometry=1===t.type?[t.geometry]:t.geometry,this.properties=t.tags,this.extent=e||4096}M.prototype.feature=function(t){return new S(this.features[t],this.options.extent)},S.prototype.loadGeometry=function(){var e=this.rawGeometry;this.geometry=[];for(var r=0;r<e.length;r++){for(var n=e[r],i=[],a=0;a<n.length;a++)i.push(new t.Point$1(n[a][0],n[a][1]));this.geometry.push(i)}return this.geometry},S.prototype.bbox=function(){this.geometry||this.loadGeometry();for(var t=this.geometry,e=1/0,r=-1/0,n=1/0,i=-1/0,a=0;a<t.length;a++)for(var o=t[a],s=0;s<o.length;s++){var l=o[s];e=Math.min(e,l.x),r=Math.max(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.y)}return[e,n,r,i]},S.prototype.toGeoJSON=T.prototype.toGeoJSON;var E=P,C=P,L=A;function P(e){var r=new t.pbf;return function(t,e){for(var r in t.layers)e.writeMessage(3,O,t.layers[r])}(e,r),r.finish()}function O(t,e){var r;e.writeVarintField(15,t.version||1),e.writeStringField(1,t.name||\"\"),e.writeVarintField(5,t.extent||4096);var n={keys:[],values:[],keycache:{},valuecache:{}};for(r=0;r<t.length;r++)n.feature=t.feature(r),e.writeMessage(2,z,n);var i=n.keys;for(r=0;r<i.length;r++)e.writeStringField(3,i[r]);var a=n.values;for(r=0;r<a.length;r++)e.writeMessage(4,B,a[r])}function z(t,e){var r=t.feature;void 0!==r.id&&e.writeVarintField(1,r.id),e.writeMessage(2,I,t),e.writeVarintField(3,r.type),e.writeMessage(4,F,r)}function I(t,e){var r=t.feature,n=t.keys,i=t.values,a=t.keycache,o=t.valuecache;for(var s in r.properties){var l=a[s];void 0===l&&(n.push(s),l=n.length-1,a[s]=l),e.writeVarint(l);var c=r.properties[s],u=typeof c;\"string\"!==u&&\"boolean\"!==u&&\"number\"!==u&&(c=JSON.stringify(c));var h=u+\":\"+c,f=o[h];void 0===f&&(i.push(c),f=i.length-1,o[h]=f),e.writeVarint(f)}}function D(t,e){return(e<<3)+(7&t)}function R(t){return t<<1^t>>31}function F(t,e){for(var r=t.loadGeometry(),n=t.type,i=0,a=0,o=r.length,s=0;s<o;s++){var l=r[s],c=1;1===n&&(c=l.length),e.writeVarint(D(1,c));for(var u=3===n?l.length-1:l.length,h=0;h<u;h++){1===h&&1!==n&&e.writeVarint(D(2,u-1));var f=l[h].x-i,p=l[h].y-a;e.writeVarint(R(f)),e.writeVarint(R(p)),i+=f,a+=p}3===n&&e.writeVarint(D(7,1))}}function B(t,e){var r=typeof t;\"string\"===r?e.writeStringField(1,t):\"boolean\"===r?e.writeBooleanField(7,t):\"number\"===r&&(t%1!=0?e.writeDoubleField(3,t):t<0?e.writeSVarintField(6,t):e.writeVarintField(5,t))}function N(t,e,r,n){j(t,r,n),j(e,2*r,2*n),j(e,2*r+1,2*n+1)}function j(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function U(t,e,r,n){var i=t-r,a=e-n;return i*i+a*a}E.fromVectorTileJs=C,E.fromGeojsonVt=function(t,e){e=e||{};var r={};for(var n in t)r[n]=new A(t[n].features,e),r[n].name=n,r[n].version=e.version,r[n].extent=e.extent;return P({layers:r})},E.GeoJSONWrapper=L;var V=function(t){return t[0]},q=function(t){return t[1]},H=function(t,e,r,n,i){void 0===e&&(e=V),void 0===r&&(r=q),void 0===n&&(n=64),void 0===i&&(i=Float64Array),this.nodeSize=n,this.points=t;for(var a=t.length<65536?Uint16Array:Uint32Array,o=this.ids=new a(t.length),s=this.coords=new i(2*t.length),l=0;l<t.length;l++)o[l]=l,s[2*l]=e(t[l]),s[2*l+1]=r(t[l]);!function t(e,r,n,i,a,o){if(!(a-i<=n)){var s=i+a>>1;!function t(e,r,n,i,a,o){for(;a>i;){if(a-i>600){var s=a-i+1,l=n-i+1,c=Math.log(s),u=.5*Math.exp(2*c/3),h=.5*Math.sqrt(c*u*(s-u)/s)*(l-s/2<0?-1:1);t(e,r,n,Math.max(i,Math.floor(n-l*u/s+h)),Math.min(a,Math.floor(n+(s-l)*u/s+h)),o)}var f=r[2*n+o],p=i,d=a;for(N(e,r,i,n),r[2*a+o]>f&&N(e,r,i,a);p<d;){for(N(e,r,p,d),p++,d--;r[2*p+o]<f;)p++;for(;r[2*d+o]>f;)d--}r[2*i+o]===f?N(e,r,i,d):N(e,r,++d,a),d<=n&&(i=d+1),n<=d&&(a=d-1)}}(e,r,s,i,a,o%2),t(e,r,n,i,s-1,o+1),t(e,r,n,s+1,a,o+1)}}(o,s,n,0,o.length-1,0)};H.prototype.range=function(t,e,r,n){return function(t,e,r,n,i,a,o){for(var s,l,c=[0,t.length-1,0],u=[];c.length;){var h=c.pop(),f=c.pop(),p=c.pop();if(f-p<=o)for(var d=p;d<=f;d++)s=e[2*d],l=e[2*d+1],s>=r&&s<=i&&l>=n&&l<=a&&u.push(t[d]);else{var g=Math.floor((p+f)/2);s=e[2*g],l=e[2*g+1],s>=r&&s<=i&&l>=n&&l<=a&&u.push(t[g]);var v=(h+1)%2;(0===h?r<=s:n<=l)&&(c.push(p),c.push(g-1),c.push(v)),(0===h?i>=s:a>=l)&&(c.push(g+1),c.push(f),c.push(v))}}return u}(this.ids,this.coords,t,e,r,n,this.nodeSize)},H.prototype.within=function(t,e,r){return function(t,e,r,n,i,a){for(var o=[0,t.length-1,0],s=[],l=i*i;o.length;){var c=o.pop(),u=o.pop(),h=o.pop();if(u-h<=a)for(var f=h;f<=u;f++)U(e[2*f],e[2*f+1],r,n)<=l&&s.push(t[f]);else{var p=Math.floor((h+u)/2),d=e[2*p],g=e[2*p+1];U(d,g,r,n)<=l&&s.push(t[p]);var v=(c+1)%2;(0===c?r-i<=d:n-i<=g)&&(o.push(h),o.push(p-1),o.push(v)),(0===c?r+i>=d:n+i>=g)&&(o.push(p+1),o.push(u),o.push(v))}}return s}(this.ids,this.coords,t,e,r,this.nodeSize)};var G={minZoom:0,maxZoom:16,radius:40,extent:512,nodeSize:64,log:!1,reduce:null,map:function(t){return t}},Y=function(t){this.options=Q(Object.create(G),t),this.trees=new Array(this.options.maxZoom+1)};function W(t,e,r,n,i){return{x:t,y:e,zoom:1/0,id:r,parentId:-1,numPoints:n,properties:i}}function X(t,e){var r=t.geometry.coordinates,n=r[0],i=r[1];return{x:K(n),y:$(i),zoom:1/0,index:e,parentId:-1}}function Z(t){return{type:\"Feature\",id:t.id,properties:J(t),geometry:{type:\"Point\",coordinates:[(n=t.x,360*(n-.5)),(e=t.y,r=(180-360*e)*Math.PI/180,360*Math.atan(Math.exp(r))/Math.PI-90)]}};var e,r,n}function J(t){var e=t.numPoints,r=e>=1e4?Math.round(e/1e3)+\"k\":e>=1e3?Math.round(e/100)/10+\"k\":e;return Q(Q({},t.properties),{cluster:!0,cluster_id:t.id,point_count:e,point_count_abbreviated:r})}function K(t){return t/360+.5}function $(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function Q(t,e){for(var r in e)t[r]=e[r];return t}function tt(t){return t.x}function et(t){return t.y}function rt(t,e,r,n,i,a){var o=i-r,s=a-n;if(0!==o||0!==s){var l=((t-r)*o+(e-n)*s)/(o*o+s*s);l>1?(r=i,n=a):l>0&&(r+=o*l,n+=s*l)}return(o=t-r)*o+(s=e-n)*s}function nt(t,e,r,n){var i={id:void 0===t?null:t,type:e,geometry:r,tags:n,minX:1/0,minY:1/0,maxX:-1/0,maxY:-1/0};return function(t){var e=t.geometry,r=t.type;if(\"Point\"===r||\"MultiPoint\"===r||\"LineString\"===r)it(t,e);else if(\"Polygon\"===r||\"MultiLineString\"===r)for(var n=0;n<e.length;n++)it(t,e[n]);else if(\"MultiPolygon\"===r)for(n=0;n<e.length;n++)for(var i=0;i<e[n].length;i++)it(t,e[n][i])}(i),i}function it(t,e){for(var r=0;r<e.length;r+=3)t.minX=Math.min(t.minX,e[r]),t.minY=Math.min(t.minY,e[r+1]),t.maxX=Math.max(t.maxX,e[r]),t.maxY=Math.max(t.maxY,e[r+1])}function at(t,e,r,n){if(e.geometry){var i=e.geometry.coordinates,a=e.geometry.type,o=Math.pow(r.tolerance/((1<<r.maxZoom)*r.extent),2),s=[],l=e.id;if(r.promoteId?l=e.properties[r.promoteId]:r.generateId&&(l=n||0),\"Point\"===a)ot(i,s);else if(\"MultiPoint\"===a)for(var c=0;c<i.length;c++)ot(i[c],s);else if(\"LineString\"===a)st(i,s,o,!1);else if(\"MultiLineString\"===a){if(r.lineMetrics){for(c=0;c<i.length;c++)s=[],st(i[c],s,o,!1),t.push(nt(l,\"LineString\",s,e.properties));return}lt(i,s,o,!1)}else if(\"Polygon\"===a)lt(i,s,o,!0);else{if(\"MultiPolygon\"!==a){if(\"GeometryCollection\"===a){for(c=0;c<e.geometry.geometries.length;c++)at(t,{id:l,geometry:e.geometry.geometries[c],properties:e.properties},r,n);return}throw new Error(\"Input data is not a valid GeoJSON object.\")}for(c=0;c<i.length;c++){var u=[];lt(i[c],u,o,!0),s.push(u)}}t.push(nt(l,a,s,e.properties))}}function ot(t,e){e.push(ct(t[0])),e.push(ut(t[1])),e.push(0)}function st(t,e,r,n){for(var i,a,o=0,s=0;s<t.length;s++){var l=ct(t[s][0]),c=ut(t[s][1]);e.push(l),e.push(c),e.push(0),s>0&&(o+=n?(i*c-l*a)/2:Math.sqrt(Math.pow(l-i,2)+Math.pow(c-a,2))),i=l,a=c}var u=e.length-3;e[2]=1,function t(e,r,n,i){for(var a,o=i,s=n-r>>1,l=n-r,c=e[r],u=e[r+1],h=e[n],f=e[n+1],p=r+3;p<n;p+=3){var d=rt(e[p],e[p+1],c,u,h,f);if(d>o)a=p,o=d;else if(d===o){var g=Math.abs(p-s);g<l&&(a=p,l=g)}}o>i&&(a-r>3&&t(e,r,a,i),e[a+2]=o,n-a>3&&t(e,a,n,i))}(e,0,u,r),e[u+2]=1,e.size=Math.abs(o),e.start=0,e.end=e.size}function lt(t,e,r,n){for(var i=0;i<t.length;i++){var a=[];st(t[i],a,r,n),e.push(a)}}function ct(t){return t/360+.5}function ut(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function ht(t,e,r,n,i,a,o,s){if(n/=e,a>=(r/=e)&&o<n)return t;if(o<r||a>=n)return null;for(var l=[],c=0;c<t.length;c++){var u=t[c],h=u.geometry,f=u.type,p=0===i?u.minX:u.minY,d=0===i?u.maxX:u.maxY;if(p>=r&&d<n)l.push(u);else if(!(d<r||p>=n)){var g=[];if(\"Point\"===f||\"MultiPoint\"===f)ft(h,g,r,n,i);else if(\"LineString\"===f)pt(h,g,r,n,i,!1,s.lineMetrics);else if(\"MultiLineString\"===f)gt(h,g,r,n,i,!1);else if(\"Polygon\"===f)gt(h,g,r,n,i,!0);else if(\"MultiPolygon\"===f)for(var v=0;v<h.length;v++){var m=[];gt(h[v],m,r,n,i,!0),m.length&&g.push(m)}if(g.length){if(s.lineMetrics&&\"LineString\"===f){for(v=0;v<g.length;v++)l.push(nt(u.id,f,g[v],u.tags));continue}\"LineString\"!==f&&\"MultiLineString\"!==f||(1===g.length?(f=\"LineString\",g=g[0]):f=\"MultiLineString\"),\"Point\"!==f&&\"MultiPoint\"!==f||(f=3===g.length?\"Point\":\"MultiPoint\"),l.push(nt(u.id,f,g,u.tags))}}}return l.length?l:null}function ft(t,e,r,n,i){for(var a=0;a<t.length;a+=3){var o=t[a+i];o>=r&&o<=n&&(e.push(t[a]),e.push(t[a+1]),e.push(t[a+2]))}}function pt(t,e,r,n,i,a,o){for(var s,l,c=dt(t),u=0===i?mt:yt,h=t.start,f=0;f<t.length-3;f+=3){var p=t[f],d=t[f+1],g=t[f+2],v=t[f+3],m=t[f+4],y=0===i?p:d,x=0===i?v:m,b=!1;o&&(s=Math.sqrt(Math.pow(p-v,2)+Math.pow(d-m,2))),y<r?x>r&&(l=u(c,p,d,v,m,r),o&&(c.start=h+s*l)):y>n?x<n&&(l=u(c,p,d,v,m,n),o&&(c.start=h+s*l)):vt(c,p,d,g),x<r&&y>=r&&(l=u(c,p,d,v,m,r),b=!0),x>n&&y<=n&&(l=u(c,p,d,v,m,n),b=!0),!a&&b&&(o&&(c.end=h+s*l),e.push(c),c=dt(t)),o&&(h+=s)}var _=t.length-3;p=t[_],d=t[_+1],g=t[_+2],(y=0===i?p:d)>=r&&y<=n&&vt(c,p,d,g),_=c.length-3,a&&_>=3&&(c[_]!==c[0]||c[_+1]!==c[1])&&vt(c,c[0],c[1],c[2]),c.length&&e.push(c)}function dt(t){var e=[];return e.size=t.size,e.start=t.start,e.end=t.end,e}function gt(t,e,r,n,i,a){for(var o=0;o<t.length;o++)pt(t[o],e,r,n,i,a,!1)}function vt(t,e,r,n){t.push(e),t.push(r),t.push(n)}function mt(t,e,r,n,i,a){var o=(a-e)/(n-e);return t.push(a),t.push(r+(i-r)*o),t.push(1),o}function yt(t,e,r,n,i,a){var o=(a-r)/(i-r);return t.push(e+(n-e)*o),t.push(a),t.push(1),o}function xt(t,e){for(var r=[],n=0;n<t.length;n++){var i,a=t[n],o=a.type;if(\"Point\"===o||\"MultiPoint\"===o||\"LineString\"===o)i=bt(a.geometry,e);else if(\"MultiLineString\"===o||\"Polygon\"===o){i=[];for(var s=0;s<a.geometry.length;s++)i.push(bt(a.geometry[s],e))}else if(\"MultiPolygon\"===o)for(i=[],s=0;s<a.geometry.length;s++){for(var l=[],c=0;c<a.geometry[s].length;c++)l.push(bt(a.geometry[s][c],e));i.push(l)}r.push(nt(a.id,o,i,a.tags))}return r}function bt(t,e){var r=[];r.size=t.size,void 0!==t.start&&(r.start=t.start,r.end=t.end);for(var n=0;n<t.length;n+=3)r.push(t[n]+e,t[n+1],t[n+2]);return r}function _t(t,e){if(t.transformed)return t;var r,n,i,a=1<<t.z,o=t.x,s=t.y;for(r=0;r<t.features.length;r++){var l=t.features[r],c=l.geometry,u=l.type;if(l.geometry=[],1===u)for(n=0;n<c.length;n+=2)l.geometry.push(wt(c[n],c[n+1],e,a,o,s));else for(n=0;n<c.length;n++){var h=[];for(i=0;i<c[n].length;i+=2)h.push(wt(c[n][i],c[n][i+1],e,a,o,s));l.geometry.push(h)}}return t.transformed=!0,t}function wt(t,e,r,n,i,a){return[Math.round(r*(t*n-i)),Math.round(r*(e*n-a))]}function kt(t,e,r,n,i){for(var a=e===i.maxZoom?0:i.tolerance/((1<<e)*i.extent),o={features:[],numPoints:0,numSimplified:0,numFeatures:0,source:null,x:r,y:n,z:e,transformed:!1,minX:2,minY:1,maxX:-1,maxY:0},s=0;s<t.length;s++){o.numFeatures++,Tt(o,t[s],a,i);var l=t[s].minX,c=t[s].minY,u=t[s].maxX,h=t[s].maxY;l<o.minX&&(o.minX=l),c<o.minY&&(o.minY=c),u>o.maxX&&(o.maxX=u),h>o.maxY&&(o.maxY=h)}return o}function Tt(t,e,r,n){var i=e.geometry,a=e.type,o=[];if(\"Point\"===a||\"MultiPoint\"===a)for(var s=0;s<i.length;s+=3)o.push(i[s]),o.push(i[s+1]),t.numPoints++,t.numSimplified++;else if(\"LineString\"===a)At(o,i,t,r,!1,!1);else if(\"MultiLineString\"===a||\"Polygon\"===a)for(s=0;s<i.length;s++)At(o,i[s],t,r,\"Polygon\"===a,0===s);else if(\"MultiPolygon\"===a)for(var l=0;l<i.length;l++){var c=i[l];for(s=0;s<c.length;s++)At(o,c[s],t,r,!0,0===s)}if(o.length){var u=e.tags||null;if(\"LineString\"===a&&n.lineMetrics){for(var h in u={},e.tags)u[h]=e.tags[h];u.mapbox_clip_start=i.start/i.size,u.mapbox_clip_end=i.end/i.size}var f={geometry:o,type:\"Polygon\"===a||\"MultiPolygon\"===a?3:\"LineString\"===a||\"MultiLineString\"===a?2:1,tags:u};null!==e.id&&(f.id=e.id),t.features.push(f)}}function At(t,e,r,n,i,a){var o=n*n;if(n>0&&e.size<(i?o:n))r.numPoints+=e.length/3;else{for(var s=[],l=0;l<e.length;l+=3)(0===n||e[l+2]>o)&&(r.numSimplified++,s.push(e[l]),s.push(e[l+1])),r.numPoints++;i&&function(t,e){for(var r=0,n=0,i=t.length,a=i-2;n<i;a=n,n+=2)r+=(t[n]-t[a])*(t[n+1]+t[a+1]);if(r>0===e)for(n=0,i=t.length;n<i/2;n+=2){var o=t[n],s=t[n+1];t[n]=t[i-2-n],t[n+1]=t[i-1-n],t[i-2-n]=o,t[i-1-n]=s}}(s,a),t.push(s)}}function Mt(t,e){var r=(e=this.options=function(t,e){for(var r in e)t[r]=e[r];return t}(Object.create(this.options),e)).debug;if(r&&console.time(\"preprocess data\"),e.maxZoom<0||e.maxZoom>24)throw new Error(\"maxZoom should be in the 0-24 range\");if(e.promoteId&&e.generateId)throw new Error(\"promoteId and generateId cannot be used together.\");var n=function(t,e){var r=[];if(\"FeatureCollection\"===t.type)for(var n=0;n<t.features.length;n++)at(r,t.features[n],e,n);else\"Feature\"===t.type?at(r,t,e):at(r,{geometry:t},e);return r}(t,e);this.tiles={},this.tileCoords=[],r&&(console.timeEnd(\"preprocess data\"),console.log(\"index: maxZoom: %d, maxPoints: %d\",e.indexMaxZoom,e.indexMaxPoints),console.time(\"generate tiles\"),this.stats={},this.total=0),(n=function(t,e){var r=e.buffer/e.extent,n=t,i=ht(t,1,-1-r,r,0,-1,2,e),a=ht(t,1,1-r,2+r,0,-1,2,e);return(i||a)&&(n=ht(t,1,-r,1+r,0,-1,2,e)||[],i&&(n=xt(i,1).concat(n)),a&&(n=n.concat(xt(a,-1)))),n}(n,e)).length&&this.splitTile(n,0,0,0),r&&(n.length&&console.log(\"features: %d, points: %d\",this.tiles[0].numFeatures,this.tiles[0].numPoints),console.timeEnd(\"generate tiles\"),console.log(\"tiles generated:\",this.total,JSON.stringify(this.stats)))}function St(t,e,r){return 32*((1<<t)*r+e)+t}function Et(t,e){var r=t.tileID.canonical;if(!this._geoJSONIndex)return e(null,null);var n=this._geoJSONIndex.getTile(r.z,r.x,r.y);if(!n)return e(null,null);var i=new k(n.features),a=E(i);0===a.byteOffset&&a.byteLength===a.buffer.byteLength||(a=new Uint8Array(a)),e(null,{vectorTile:i,rawData:a.buffer})}Y.prototype.load=function(t){var e=this.options,r=e.log,n=e.minZoom,i=e.maxZoom,a=e.nodeSize;r&&console.time(\"total time\");var o=\"prepare \"+t.length+\" points\";r&&console.time(o),this.points=t;for(var s=[],l=0;l<t.length;l++)t[l].geometry&&s.push(X(t[l],l));this.trees[i+1]=new H(s,tt,et,a,Float32Array),r&&console.timeEnd(o);for(var c=i;c>=n;c--){var u=+Date.now();s=this._cluster(s,c),this.trees[c]=new H(s,tt,et,a,Float32Array),r&&console.log(\"z%d: %d clusters in %dms\",c,s.length,+Date.now()-u)}return r&&console.timeEnd(\"total time\"),this},Y.prototype.getClusters=function(t,e){var r=((t[0]+180)%360+360)%360-180,n=Math.max(-90,Math.min(90,t[1])),i=180===t[2]?180:((t[2]+180)%360+360)%360-180,a=Math.max(-90,Math.min(90,t[3]));if(t[2]-t[0]>=360)r=-180,i=180;else if(r>i){var o=this.getClusters([r,n,180,a],e),s=this.getClusters([-180,n,i,a],e);return o.concat(s)}for(var l=this.trees[this._limitZoom(e)],c=[],u=0,h=l.range(K(r),$(a),K(i),$(n));u<h.length;u+=1){var f=h[u],p=l.points[f];c.push(p.numPoints?Z(p):this.points[p.index])}return c},Y.prototype.getChildren=function(t){var e=t>>5,r=t%32,n=\"No cluster with the specified id.\",i=this.trees[r];if(!i)throw new Error(n);var a=i.points[e];if(!a)throw new Error(n);for(var o=this.options.radius/(this.options.extent*Math.pow(2,r-1)),s=[],l=0,c=i.within(a.x,a.y,o);l<c.length;l+=1){var u=c[l],h=i.points[u];h.parentId===t&&s.push(h.numPoints?Z(h):this.points[h.index])}if(0===s.length)throw new Error(n);return s},Y.prototype.getLeaves=function(t,e,r){e=e||10,r=r||0;var n=[];return this._appendLeaves(n,t,e,r,0),n},Y.prototype.getTile=function(t,e,r){var n=this.trees[this._limitZoom(t)],i=Math.pow(2,t),a=this.options,o=a.extent,s=a.radius/o,l=(r-s)/i,c=(r+1+s)/i,u={features:[]};return this._addTileFeatures(n.range((e-s)/i,l,(e+1+s)/i,c),n.points,e,r,i,u),0===e&&this._addTileFeatures(n.range(1-s/i,l,1,c),n.points,i,r,i,u),e===i-1&&this._addTileFeatures(n.range(0,l,s/i,c),n.points,-1,r,i,u),u.features.length?u:null},Y.prototype.getClusterExpansionZoom=function(t){for(var e=t%32-1;e<=this.options.maxZoom;){var r=this.getChildren(t);if(e++,1!==r.length)break;t=r[0].properties.cluster_id}return e},Y.prototype._appendLeaves=function(t,e,r,n,i){for(var a=0,o=this.getChildren(e);a<o.length;a+=1){var s=o[a],l=s.properties;if(l&&l.cluster?i+l.point_count<=n?i+=l.point_count:i=this._appendLeaves(t,l.cluster_id,r,n,i):i<n?i++:t.push(s),t.length===r)break}return i},Y.prototype._addTileFeatures=function(t,e,r,n,i,a){for(var o=0,s=t;o<s.length;o+=1){var l=e[s[o]],c={type:1,geometry:[[Math.round(this.options.extent*(l.x*i-r)),Math.round(this.options.extent*(l.y*i-n))]],tags:l.numPoints?J(l):this.points[l.index].properties},u=l.numPoints?l.id:this.points[l.index].id;void 0!==u&&(c.id=u),a.features.push(c)}},Y.prototype._limitZoom=function(t){return Math.max(this.options.minZoom,Math.min(t,this.options.maxZoom+1))},Y.prototype._cluster=function(t,e){for(var r=[],n=this.options,i=n.radius,a=n.extent,o=n.reduce,s=i/(a*Math.pow(2,e)),l=0;l<t.length;l++){var c=t[l];if(!(c.zoom<=e)){c.zoom=e;for(var u=this.trees[e+1],h=u.within(c.x,c.y,s),f=c.numPoints||1,p=c.x*f,d=c.y*f,g=o?this._map(c,!0):null,v=(l<<5)+(e+1),m=0,y=h;m<y.length;m+=1){var x=y[m],b=u.points[x];if(!(b.zoom<=e)){b.zoom=e;var _=b.numPoints||1;p+=b.x*_,d+=b.y*_,f+=_,b.parentId=v,o&&o(g,this._map(b))}}1===f?r.push(c):(c.parentId=v,r.push(W(p/f,d/f,v,f,g)))}}return r},Y.prototype._map=function(t,e){if(t.numPoints)return e?Q({},t.properties):t.properties;var r=this.points[t.index].properties,n=this.options.map(r);return e&&n===r?Q({},n):n},Mt.prototype.options={maxZoom:14,indexMaxZoom:5,indexMaxPoints:1e5,tolerance:3,extent:4096,buffer:64,lineMetrics:!1,promoteId:null,generateId:!1,debug:0},Mt.prototype.splitTile=function(t,e,r,n,i,a,o){for(var s=[t,e,r,n],l=this.options,c=l.debug;s.length;){n=s.pop(),r=s.pop(),e=s.pop(),t=s.pop();var u=1<<e,h=St(e,r,n),f=this.tiles[h];if(!f&&(c>1&&console.time(\"creation\"),f=this.tiles[h]=kt(t,e,r,n,l),this.tileCoords.push({z:e,x:r,y:n}),c)){c>1&&(console.log(\"tile z%d-%d-%d (features: %d, points: %d, simplified: %d)\",e,r,n,f.numFeatures,f.numPoints,f.numSimplified),console.timeEnd(\"creation\"));var p=\"z\"+e;this.stats[p]=(this.stats[p]||0)+1,this.total++}if(f.source=t,i){if(e===l.maxZoom||e===i)continue;var d=1<<i-e;if(r!==Math.floor(a/d)||n!==Math.floor(o/d))continue}else if(e===l.indexMaxZoom||f.numPoints<=l.indexMaxPoints)continue;if(f.source=null,0!==t.length){c>1&&console.time(\"clipping\");var g,v,m,y,x,b,_=.5*l.buffer/l.extent,w=.5-_,k=.5+_,T=1+_;g=v=m=y=null,x=ht(t,u,r-_,r+k,0,f.minX,f.maxX,l),b=ht(t,u,r+w,r+T,0,f.minX,f.maxX,l),t=null,x&&(g=ht(x,u,n-_,n+k,1,f.minY,f.maxY,l),v=ht(x,u,n+w,n+T,1,f.minY,f.maxY,l),x=null),b&&(m=ht(b,u,n-_,n+k,1,f.minY,f.maxY,l),y=ht(b,u,n+w,n+T,1,f.minY,f.maxY,l),b=null),c>1&&console.timeEnd(\"clipping\"),s.push(g||[],e+1,2*r,2*n),s.push(v||[],e+1,2*r,2*n+1),s.push(m||[],e+1,2*r+1,2*n),s.push(y||[],e+1,2*r+1,2*n+1)}}},Mt.prototype.getTile=function(t,e,r){var n=this.options,i=n.extent,a=n.debug;if(t<0||t>24)return null;var o=1<<t,s=St(t,e=(e%o+o)%o,r);if(this.tiles[s])return _t(this.tiles[s],i);a>1&&console.log(\"drilling down to z%d-%d-%d\",t,e,r);for(var l,c=t,u=e,h=r;!l&&c>0;)c--,u=Math.floor(u/2),h=Math.floor(h/2),l=this.tiles[St(c,u,h)];return l&&l.source?(a>1&&console.log(\"found parent tile z%d-%d-%d\",c,u,h),a>1&&console.time(\"drilling down\"),this.splitTile(l.source,c,u,h,t,e,r),a>1&&console.timeEnd(\"drilling down\"),this.tiles[s]?_t(this.tiles[s],i):null):null};var Ct=function(e){function r(t,r,n){e.call(this,t,r,Et),n&&(this.loadGeoJSON=n)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadData=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),this._pendingCallback=e,this._pendingLoadDataParams=t,this._state&&\"Idle\"!==this._state?this._state=\"NeedsLoadData\":(this._state=\"Coalescing\",this._loadData())},r.prototype._loadData=function(){var e=this;if(this._pendingCallback&&this._pendingLoadDataParams){var r=this._pendingCallback,n=this._pendingLoadDataParams;delete this._pendingCallback,delete this._pendingLoadDataParams;var i=!!(n&&n.request&&n.request.collectResourceTiming)&&new l.Performance(n.request);this.loadGeoJSON(n,function(a,o){if(a||!o)return r(a);if(\"object\"!=typeof o)return r(new Error(\"Input data given to '\"+n.source+\"' is not a valid GeoJSON object.\"));!function t(e,r){switch(e&&e.type||null){case\"FeatureCollection\":return e.features=e.features.map(y(t,r)),e;case\"GeometryCollection\":return e.geometries=e.geometries.map(y(t,r)),e;case\"Feature\":return e.geometry=t(e.geometry,r),e;case\"Polygon\":case\"MultiPolygon\":return function(t,e){return\"Polygon\"===t.type?t.coordinates=x(t.coordinates,e):\"MultiPolygon\"===t.type&&(t.coordinates=t.coordinates.map(y(x,e))),t}(e,r);default:return e}}(o,!0);try{e._geoJSONIndex=n.cluster?new Y(function(e){var r=e.superclusterOptions,n=e.clusterProperties;if(!n||!r)return r;for(var i={},a={},o={accumulated:null,zoom:0},s={properties:null},l=Object.keys(n),c=0,u=l;c<u.length;c+=1){var h=u[c],f=n[h],p=f[0],d=f[1],g=t.createExpression(d),v=t.createExpression(\"string\"==typeof p?[p,[\"accumulated\"],[\"get\",h]]:p);i[h]=g.value,a[h]=v.value}return r.map=function(t){s.properties=t;for(var e={},r=0,n=l;r<n.length;r+=1){var a=n[r];e[a]=i[a].evaluate(o,s)}return e},r.reduce=function(t,e){s.properties=e;for(var r=0,n=l;r<n.length;r+=1){var i=n[r];o.accumulated=t[i],t[i]=a[i].evaluate(o,s)}},r}(n)).load(o.features):new Mt(o,n.geojsonVtOptions)}catch(a){return r(a)}e.loaded={};var s={};if(i){var l=i.finish();l&&(s.resourceTiming={},s.resourceTiming[n.source]=JSON.parse(JSON.stringify(l)))}r(null,s)})}},r.prototype.coalesce=function(){\"Coalescing\"===this._state?this._state=\"Idle\":\"NeedsLoadData\"===this._state&&(this._state=\"Coalescing\",this._loadData())},r.prototype.reloadTile=function(t,r){var n=this.loaded,i=t.uid;return n&&n[i]?e.prototype.reloadTile.call(this,t,r):this.loadTile(t,r)},r.prototype.loadGeoJSON=function(e,r){if(e.request)t.getJSON(e.request,r);else{if(\"string\"!=typeof e.data)return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"));try{return r(null,JSON.parse(e.data))}catch(t){return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"))}}},r.prototype.removeSource=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),e()},r.prototype.getClusterExpansionZoom=function(t,e){e(null,this._geoJSONIndex.getClusterExpansionZoom(t.clusterId))},r.prototype.getClusterChildren=function(t,e){e(null,this._geoJSONIndex.getChildren(t.clusterId))},r.prototype.getClusterLeaves=function(t,e){e(null,this._geoJSONIndex.getLeaves(t.clusterId,t.limit,t.offset))},r}(h),Lt=function(e){var r=this;this.self=e,this.actor=new t.Actor(e,this),this.layerIndexes={},this.workerSourceTypes={vector:h,geojson:Ct},this.workerSources={},this.demWorkerSources={},this.self.registerWorkerSource=function(t,e){if(r.workerSourceTypes[t])throw new Error('Worker source with name \"'+t+'\" already registered.');r.workerSourceTypes[t]=e},this.self.registerRTLTextPlugin=function(e){if(t.plugin.isLoaded())throw new Error(\"RTL text plugin already registered.\");t.plugin.applyArabicShaping=e.applyArabicShaping,t.plugin.processBidirectionalText=e.processBidirectionalText,t.plugin.processStyledBidirectionalText=e.processStyledBidirectionalText}};return Lt.prototype.setReferrer=function(t,e){this.referrer=e},Lt.prototype.setLayers=function(t,e,r){this.getLayerIndex(t).replace(e),r()},Lt.prototype.updateLayers=function(t,e,r){this.getLayerIndex(t).update(e.layers,e.removedIds),r()},Lt.prototype.loadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).loadTile(e,r)},Lt.prototype.loadDEMTile=function(t,e,r){this.getDEMWorkerSource(t,e.source).loadTile(e,r)},Lt.prototype.reloadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).reloadTile(e,r)},Lt.prototype.abortTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).abortTile(e,r)},Lt.prototype.removeTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).removeTile(e,r)},Lt.prototype.removeDEMTile=function(t,e){this.getDEMWorkerSource(t,e.source).removeTile(e)},Lt.prototype.removeSource=function(t,e,r){if(this.workerSources[t]&&this.workerSources[t][e.type]&&this.workerSources[t][e.type][e.source]){var n=this.workerSources[t][e.type][e.source];delete this.workerSources[t][e.type][e.source],void 0!==n.removeSource?n.removeSource(e,r):r()}},Lt.prototype.loadWorkerSource=function(t,e,r){try{this.self.importScripts(e.url),r()}catch(t){r(t.toString())}},Lt.prototype.loadRTLTextPlugin=function(e,r,n){try{t.plugin.isLoaded()||(this.self.importScripts(r),n(t.plugin.isLoaded()?null:new Error(\"RTL Text Plugin failed to import scripts from \"+r)))}catch(t){n(t.toString())}},Lt.prototype.getLayerIndex=function(t){var e=this.layerIndexes[t];return e||(e=this.layerIndexes[t]=new n),e},Lt.prototype.getWorkerSource=function(t,e,r){var n=this;if(this.workerSources[t]||(this.workerSources[t]={}),this.workerSources[t][e]||(this.workerSources[t][e]={}),!this.workerSources[t][e][r]){var i={send:function(e,r,i){n.actor.send(e,r,i,t)}};this.workerSources[t][e][r]=new this.workerSourceTypes[e](i,this.getLayerIndex(t))}return this.workerSources[t][e][r]},Lt.prototype.getDEMWorkerSource=function(t,e){return this.demWorkerSources[t]||(this.demWorkerSources[t]={}),this.demWorkerSources[t][e]||(this.demWorkerSources[t][e]=new f),this.demWorkerSources[t][e]},Lt.prototype.enforceCacheSizeLimit=function(e,r){t.enforceCacheSizeLimit(r)},\"undefined\"!=typeof WorkerGlobalScope&&void 0!==t.window&&t.window instanceof WorkerGlobalScope&&(t.window.worker=new Lt(t.window)),Lt}),n(0,function(t){var e=t.createCommonjsModule(function(t){function e(t){return!!(\"undefined\"!=typeof window&&\"undefined\"!=typeof document&&Array.prototype&&Array.prototype.every&&Array.prototype.filter&&Array.prototype.forEach&&Array.prototype.indexOf&&Array.prototype.lastIndexOf&&Array.prototype.map&&Array.prototype.some&&Array.prototype.reduce&&Array.prototype.reduceRight&&Array.isArray&&Function.prototype&&Function.prototype.bind&&Object.keys&&Object.create&&Object.getPrototypeOf&&Object.getOwnPropertyNames&&Object.isSealed&&Object.isFrozen&&Object.isExtensible&&Object.getOwnPropertyDescriptor&&Object.defineProperty&&Object.defineProperties&&Object.seal&&Object.freeze&&Object.preventExtensions&&\"JSON\"in window&&\"parse\"in JSON&&\"stringify\"in JSON&&function(){if(!(\"Worker\"in window&&\"Blob\"in window&&\"URL\"in window))return!1;var t,e,r=new Blob([\"\"],{type:\"text/javascript\"}),n=URL.createObjectURL(r);try{e=new Worker(n),t=!0}catch(e){t=!1}return e&&e.terminate(),URL.revokeObjectURL(n),t}()&&\"Uint8ClampedArray\"in window&&ArrayBuffer.isView&&function(t){return void 0===r[t]&&(r[t]=function(t){var r=document.createElement(\"canvas\"),n=Object.create(e.webGLContextAttributes);return n.failIfMajorPerformanceCaveat=t,r.probablySupportsContext?r.probablySupportsContext(\"webgl\",n)||r.probablySupportsContext(\"experimental-webgl\",n):r.supportsContext?r.supportsContext(\"webgl\",n)||r.supportsContext(\"experimental-webgl\",n):r.getContext(\"webgl\",n)||r.getContext(\"experimental-webgl\",n)}(t)),r[t]}(t&&t.failIfMajorPerformanceCaveat))}t.exports?t.exports=e:window&&(window.mapboxgl=window.mapboxgl||{},window.mapboxgl.supported=e);var r={};e.webGLContextAttributes={antialias:!1,alpha:!0,stencil:!0,depth:!0}}),r={create:function(e,r,n){var i=t.window.document.createElement(e);return void 0!==r&&(i.className=r),n&&n.appendChild(i),i},createNS:function(e,r){return t.window.document.createElementNS(e,r)}},n=t.window.document.documentElement.style;function i(t){if(!n)return t[0];for(var e=0;e<t.length;e++)if(t[e]in n)return t[e];return t[0]}var a,o=i([\"userSelect\",\"MozUserSelect\",\"WebkitUserSelect\",\"msUserSelect\"]);r.disableDrag=function(){n&&o&&(a=n[o],n[o]=\"none\")},r.enableDrag=function(){n&&o&&(n[o]=a)};var s=i([\"transform\",\"WebkitTransform\"]);r.setTransform=function(t,e){t.style[s]=e};var l=!1;try{var c=Object.defineProperty({},\"passive\",{get:function(){l=!0}});t.window.addEventListener(\"test\",c,c),t.window.removeEventListener(\"test\",c,c)}catch(t){l=!1}r.addEventListener=function(t,e,r,n){void 0===n&&(n={}),\"passive\"in n&&l?t.addEventListener(e,r,n):t.addEventListener(e,r,n.capture)},r.removeEventListener=function(t,e,r,n){void 0===n&&(n={}),\"passive\"in n&&l?t.removeEventListener(e,r,n):t.removeEventListener(e,r,n.capture)};var u=function(e){e.preventDefault(),e.stopPropagation(),t.window.removeEventListener(\"click\",u,!0)};function h(t){var e=t.userImage;return!!(e&&e.render&&e.render())&&(t.data.replace(new Uint8Array(e.data.buffer)),!0)}r.suppressClick=function(){t.window.addEventListener(\"click\",u,!0),t.window.setTimeout(function(){t.window.removeEventListener(\"click\",u,!0)},0)},r.mousePos=function(e,r){var n=e.getBoundingClientRect(),i=t.window.TouchEvent&&r instanceof t.window.TouchEvent?r.touches[0]:r;return new t.Point(i.clientX-n.left-e.clientLeft,i.clientY-n.top-e.clientTop)},r.touchPos=function(e,r){for(var n=e.getBoundingClientRect(),i=[],a=\"touchend\"===r.type?r.changedTouches:r.touches,o=0;o<a.length;o++)i.push(new t.Point(a[o].clientX-n.left-e.clientLeft,a[o].clientY-n.top-e.clientTop));return i},r.mouseButton=function(e){return void 0!==t.window.InstallTrigger&&2===e.button&&e.ctrlKey&&t.window.navigator.platform.toUpperCase().indexOf(\"MAC\")>=0?0:e.button},r.remove=function(t){t.parentNode&&t.parentNode.removeChild(t)};var f=function(e){function r(){e.call(this),this.images={},this.updatedImages={},this.callbackDispatchedThisFrame={},this.loaded=!1,this.requestors=[],this.patterns={},this.atlasImage=new t.RGBAImage({width:1,height:1}),this.dirty=!0}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.isLoaded=function(){return this.loaded},r.prototype.setLoaded=function(t){if(this.loaded!==t&&(this.loaded=t,t)){for(var e=0,r=this.requestors;e<r.length;e+=1){var n=r[e],i=n.ids,a=n.callback;this._notify(i,a)}this.requestors=[]}},r.prototype.getImage=function(t){return this.images[t]},r.prototype.addImage=function(t,e){this.images[t]=e},r.prototype.updateImage=function(t,e){var r=this.images[t];e.version=r.version+1,this.images[t]=e,this.updatedImages[t]=!0},r.prototype.removeImage=function(t){var e=this.images[t];delete this.images[t],delete this.patterns[t],e.userImage&&e.userImage.onRemove&&e.userImage.onRemove()},r.prototype.listImages=function(){return Object.keys(this.images)},r.prototype.getImages=function(t,e){var r=!0;if(!this.isLoaded())for(var n=0,i=t;n<i.length;n+=1){var a=i[n];this.images[a]||(r=!1)}this.isLoaded()||r?this._notify(t,e):this.requestors.push({ids:t,callback:e})},r.prototype._notify=function(e,r){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i];this.images[o]||this.fire(new t.Event(\"styleimagemissing\",{id:o}));var s=this.images[o];s?n[o]={data:s.data.clone(),pixelRatio:s.pixelRatio,sdf:s.sdf,version:s.version,hasRenderCallback:Boolean(s.userImage&&s.userImage.render)}:t.warnOnce('Image \"'+o+'\" could not be loaded. Please make sure you have added the image with map.addImage() or a \"sprite\" property in your style. You can provide missing images by listening for the \"styleimagemissing\" map event.')}r(null,n)},r.prototype.getPixelSize=function(){var t=this.atlasImage;return{width:t.width,height:t.height}},r.prototype.getPattern=function(e){var r=this.patterns[e],n=this.getImage(e);if(!n)return null;if(r&&r.position.version===n.version)return r.position;if(r)r.position.version=n.version;else{var i={w:n.data.width+2,h:n.data.height+2,x:0,y:0},a=new t.ImagePosition(i,n);this.patterns[e]={bin:i,position:a}}return this._updatePatternAtlas(),this.patterns[e].position},r.prototype.bind=function(e){var r=e.gl;this.atlasTexture?this.dirty&&(this.atlasTexture.update(this.atlasImage),this.dirty=!1):this.atlasTexture=new t.Texture(e,this.atlasImage,r.RGBA),this.atlasTexture.bind(r.LINEAR,r.CLAMP_TO_EDGE)},r.prototype._updatePatternAtlas=function(){var e=[];for(var r in this.patterns)e.push(this.patterns[r].bin);var n=t.potpack(e),i=n.w,a=n.h,o=this.atlasImage;for(var s in o.resize({width:i||1,height:a||1}),this.patterns){var l=this.patterns[s].bin,c=l.x+1,u=l.y+1,h=this.images[s].data,f=h.width,p=h.height;t.RGBAImage.copy(h,o,{x:0,y:0},{x:c,y:u},{width:f,height:p}),t.RGBAImage.copy(h,o,{x:0,y:p-1},{x:c,y:u-1},{width:f,height:1}),t.RGBAImage.copy(h,o,{x:0,y:0},{x:c,y:u+p},{width:f,height:1}),t.RGBAImage.copy(h,o,{x:f-1,y:0},{x:c-1,y:u},{width:1,height:p}),t.RGBAImage.copy(h,o,{x:0,y:0},{x:c+f,y:u},{width:1,height:p})}this.dirty=!0},r.prototype.beginFrame=function(){this.callbackDispatchedThisFrame={}},r.prototype.dispatchRenderCallbacks=function(t){for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!this.callbackDispatchedThisFrame[n]){this.callbackDispatchedThisFrame[n]=!0;var i=this.images[n];h(i)&&this.updateImage(n,i)}}},r}(t.Evented),p=g,d=1e20;function g(t,e,r,n,i,a){this.fontSize=t||24,this.buffer=void 0===e?3:e,this.cutoff=n||.25,this.fontFamily=i||\"sans-serif\",this.fontWeight=a||\"normal\",this.radius=r||8;var o=this.size=this.fontSize+2*this.buffer;this.canvas=document.createElement(\"canvas\"),this.canvas.width=this.canvas.height=o,this.ctx=this.canvas.getContext(\"2d\"),this.ctx.font=this.fontWeight+\" \"+this.fontSize+\"px \"+this.fontFamily,this.ctx.textBaseline=\"middle\",this.ctx.fillStyle=\"black\",this.gridOuter=new Float64Array(o*o),this.gridInner=new Float64Array(o*o),this.f=new Float64Array(o),this.d=new Float64Array(o),this.z=new Float64Array(o+1),this.v=new Int16Array(o),this.middle=Math.round(o/2*(navigator.userAgent.indexOf(\"Gecko/\")>=0?1.2:1))}function v(t,e,r,n,i,a,o){for(var s=0;s<e;s++){for(var l=0;l<r;l++)n[l]=t[l*e+s];for(m(n,i,a,o,r),l=0;l<r;l++)t[l*e+s]=i[l]}for(l=0;l<r;l++){for(s=0;s<e;s++)n[s]=t[l*e+s];for(m(n,i,a,o,e),s=0;s<e;s++)t[l*e+s]=Math.sqrt(i[s])}}function m(t,e,r,n,i){r[0]=0,n[0]=-d,n[1]=+d;for(var a=1,o=0;a<i;a++){for(var s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);s<=n[o];)o--,s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);r[++o]=a,n[o]=s,n[o+1]=+d}for(a=0,o=0;a<i;a++){for(;n[o+1]<a;)o++;e[a]=(a-r[o])*(a-r[o])+t[r[o]]}}g.prototype.draw=function(t){this.ctx.clearRect(0,0,this.size,this.size),this.ctx.fillText(t,this.buffer,this.middle);for(var e=this.ctx.getImageData(0,0,this.size,this.size),r=new Uint8ClampedArray(this.size*this.size),n=0;n<this.size*this.size;n++){var i=e.data[4*n+3]/255;this.gridOuter[n]=1===i?0:0===i?d:Math.pow(Math.max(0,.5-i),2),this.gridInner[n]=1===i?d:0===i?0:Math.pow(Math.max(0,i-.5),2)}for(v(this.gridOuter,this.size,this.size,this.f,this.d,this.v,this.z),v(this.gridInner,this.size,this.size,this.f,this.d,this.v,this.z),n=0;n<this.size*this.size;n++){var a=this.gridOuter[n]-this.gridInner[n];r[n]=Math.max(0,Math.min(255,Math.round(255-255*(a/this.radius+this.cutoff))))}return r};var y=function(t,e){this.requestManager=t,this.localIdeographFontFamily=e,this.entries={}};y.prototype.setURL=function(t){this.url=t},y.prototype.getGlyphs=function(e,r){var n=this,i=[];for(var a in e)for(var o=0,s=e[a];o<s.length;o+=1){var l=s[o];i.push({stack:a,id:l})}t.asyncAll(i,function(t,e){var r=t.stack,i=t.id,a=n.entries[r];a||(a=n.entries[r]={glyphs:{},requests:{}});var o=a.glyphs[i];if(void 0===o)if(o=n._tinySDF(a,r,i))e(null,{stack:r,id:i,glyph:o});else{var s=Math.floor(i/256);if(256*s>65535)e(new Error(\"glyphs > 65535 not supported\"));else{var l=a.requests[s];l||(l=a.requests[s]=[],y.loadGlyphRange(r,s,n.url,n.requestManager,function(t,e){if(e)for(var r in e)a.glyphs[+r]=e[+r];for(var n=0,i=l;n<i.length;n+=1)(0,i[n])(t,e);delete a.requests[s]})),l.push(function(t,n){t?e(t):n&&e(null,{stack:r,id:i,glyph:n[i]||null})})}}else e(null,{stack:r,id:i,glyph:o})},function(t,e){if(t)r(t);else if(e){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.stack,l=o.id,c=o.glyph;(n[s]||(n[s]={}))[l]=c&&{id:c.id,bitmap:c.bitmap.clone(),metrics:c.metrics}}r(null,n)}})},y.prototype._tinySDF=function(e,r,n){var i=this.localIdeographFontFamily;if(i&&(t.isChar[\"CJK Unified Ideographs\"](n)||t.isChar[\"Hangul Syllables\"](n)||t.isChar.Hiragana(n)||t.isChar.Katakana(n))){var a=e.tinySDF;if(!a){var o=\"400\";/bold/i.test(r)?o=\"900\":/medium/i.test(r)?o=\"500\":/light/i.test(r)&&(o=\"200\"),a=e.tinySDF=new y.TinySDF(24,3,8,.25,i,o)}return{id:n,bitmap:new t.AlphaImage({width:30,height:30},a.draw(String.fromCharCode(n))),metrics:{width:24,height:24,left:0,top:-8,advance:24}}}},y.loadGlyphRange=function(e,r,n,i,a){var o=256*r,s=o+255,l=i.transformRequest(i.normalizeGlyphsURL(n).replace(\"{fontstack}\",e).replace(\"{range}\",o+\"-\"+s),t.ResourceType.Glyphs);t.getArrayBuffer(l,function(e,r){if(e)a(e);else if(r){for(var n={},i=0,o=t.parseGlyphPBF(r);i<o.length;i+=1){var s=o[i];n[s.id]=s}a(null,n)}})},y.TinySDF=p;var x=function(){this.specification=t.styleSpec.light.position};x.prototype.possiblyEvaluate=function(e,r){return t.sphericalToCartesian(e.expression.evaluate(r))},x.prototype.interpolate=function(e,r,n){return{x:t.number(e.x,r.x,n),y:t.number(e.y,r.y,n),z:t.number(e.z,r.z,n)}};var b=new t.Properties({anchor:new t.DataConstantProperty(t.styleSpec.light.anchor),position:new x,color:new t.DataConstantProperty(t.styleSpec.light.color),intensity:new t.DataConstantProperty(t.styleSpec.light.intensity)}),_=function(e){function r(r){e.call(this),this._transitionable=new t.Transitionable(b),this.setLight(r),this._transitioning=this._transitionable.untransitioned()}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getLight=function(){return this._transitionable.serialize()},r.prototype.setLight=function(e,r){if(void 0===r&&(r={}),!this._validate(t.validateLight,e,r))for(var n in e){var i=e[n];t.endsWith(n,\"-transition\")?this._transitionable.setTransition(n.slice(0,-\"-transition\".length),i):this._transitionable.setValue(n,i)}},r.prototype.updateTransitions=function(t){this._transitioning=this._transitionable.transitioned(t,this._transitioning)},r.prototype.hasTransition=function(){return this._transitioning.hasTransition()},r.prototype.recalculate=function(t){this.properties=this._transitioning.possiblyEvaluate(t)},r.prototype._validate=function(e,r,n){return(!n||!1!==n.validate)&&t.emitValidationErrors(this,e.call(t.validateStyle,t.extend({value:r,style:{glyphs:!0,sprite:!0},styleSpec:t.styleSpec})))},r}(t.Evented),w=function(t,e){this.width=t,this.height=e,this.nextRow=0,this.bytes=4,this.data=new Uint8Array(this.width*this.height*this.bytes),this.positions={}};w.prototype.getDash=function(t,e){var r=t.join(\",\")+String(e);return this.positions[r]||(this.positions[r]=this.addDash(t,e)),this.positions[r]},w.prototype.addDash=function(e,r){var n=r?7:0,i=2*n+1;if(this.nextRow+i>this.height)return t.warnOnce(\"LineAtlas out of space\"),null;for(var a=0,o=0;o<e.length;o++)a+=e[o];for(var s=this.width/a,l=s/2,c=e.length%2==1,u=-n;u<=n;u++)for(var h=this.nextRow+n+u,f=this.width*h,p=c?-e[e.length-1]:0,d=e[0],g=1,v=0;v<this.width;v++){for(;d<v/s;)p=d,d+=e[g],c&&g===e.length-1&&(d+=e[0]),g++;var m=Math.abs(v-p*s),y=Math.abs(v-d*s),x=Math.min(m,y),b=g%2==1,_=void 0;if(r){var w=n?u/n*(l+1):0;if(b){var k=l-Math.abs(w);_=Math.sqrt(x*x+k*k)}else _=l-Math.sqrt(x*x+w*w)}else _=(b?1:-1)*x;this.data[3+4*(f+v)]=Math.max(0,Math.min(255,_+128))}var T={y:(this.nextRow+n+.5)/this.height,height:2*n/this.height,width:a};return this.nextRow+=i,this.dirty=!0,T},w.prototype.bind=function(t){var e=t.gl;this.texture?(e.bindTexture(e.TEXTURE_2D,this.texture),this.dirty&&(this.dirty=!1,e.texSubImage2D(e.TEXTURE_2D,0,0,0,this.width,this.height,e.RGBA,e.UNSIGNED_BYTE,this.data))):(this.texture=e.createTexture(),e.bindTexture(e.TEXTURE_2D,this.texture),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_S,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_T,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,e.LINEAR),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,e.LINEAR),e.texImage2D(e.TEXTURE_2D,0,e.RGBA,this.width,this.height,0,e.RGBA,e.UNSIGNED_BYTE,this.data))};var k=function e(r,n){this.workerPool=r,this.actors=[],this.currentActor=0,this.id=t.uniqueId();for(var i=this.workerPool.acquire(this.id),a=0;a<i.length;a++){var o=i[a],s=new e.Actor(o,n,this.id);s.name=\"Worker \"+a,this.actors.push(s)}};function T(e,r,n){var i=function(i,a){if(i)return n(i);if(a){var o=t.pick(a,[\"tiles\",\"minzoom\",\"maxzoom\",\"attribution\",\"mapbox_logo\",\"bounds\"]);a.vector_layers&&(o.vectorLayers=a.vector_layers,o.vectorLayerIds=o.vectorLayers.map(function(t){return t.id})),e.url&&(o.tiles=r.canonicalizeTileset(o,e.url)),n(null,o)}};return e.url?t.getJSON(r.transformRequest(r.normalizeSourceURL(e.url),t.ResourceType.Source),i):t.browser.frame(function(){return i(null,e)})}k.prototype.broadcast=function(e,r,n){n=n||function(){},t.asyncAll(this.actors,function(t,n){t.send(e,r,n)},n)},k.prototype.send=function(t,e,r,n){return(\"number\"!=typeof n||isNaN(n))&&(n=this.currentActor=(this.currentActor+1)%this.actors.length),this.actors[n].send(t,e,r),n},k.prototype.remove=function(){this.actors.forEach(function(t){t.remove()}),this.actors=[],this.workerPool.release(this.id)},k.Actor=t.Actor;var A=function(e,r,n){this.bounds=t.LngLatBounds.convert(this.validateBounds(e)),this.minzoom=r||0,this.maxzoom=n||24};A.prototype.validateBounds=function(t){return Array.isArray(t)&&4===t.length?[Math.max(-180,t[0]),Math.max(-90,t[1]),Math.min(180,t[2]),Math.min(90,t[3])]:[-180,-90,180,90]},A.prototype.contains=function(e){var r=Math.pow(2,e.z),n=Math.floor(t.mercatorXfromLng(this.bounds.getWest())*r),i=Math.floor(t.mercatorYfromLat(this.bounds.getNorth())*r),a=Math.ceil(t.mercatorXfromLng(this.bounds.getEast())*r),o=Math.ceil(t.mercatorYfromLat(this.bounds.getSouth())*r);return e.x>=n&&e.x<a&&e.y>=i&&e.y<o};var M=function(e){function r(r,n,i,a){if(e.call(this),this.id=r,this.dispatcher=i,this.type=\"vector\",this.minzoom=0,this.maxzoom=22,this.scheme=\"xyz\",this.tileSize=512,this.reparseOverscaled=!0,this.isTileClipped=!0,t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"])),this._options=t.extend({type:\"vector\"},n),this._collectResourceTiming=n.collectResourceTiming,512!==this.tileSize)throw new Error(\"vector tile sources must have a tileSize of 512\");this.setEventedParent(a)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=T(this._options,this.map._requestManager,function(r,n){e._tileJSONRequest=null,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))})},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,null),i={request:this.map._requestManager.transformRequest(n,t.ResourceType.Tile),uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,tileSize:this.tileSize*e.tileID.overscaleFactor(),type:this.type,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes};function a(n,i){return e.aborted?r(null):n&&404!==n.status?r(n):(i&&i.resourceTiming&&(e.resourceTiming=i.resourceTiming),this.map._refreshExpiredTiles&&i&&e.setExpiryData(i),e.loadVectorData(i,this.map.painter),t.cacheEntryPossiblyAdded(this.dispatcher),r(null),void(e.reloadCallback&&(this.loadTile(e,e.reloadCallback),e.reloadCallback=null)))}i.request.collectResourceTiming=this._collectResourceTiming,void 0===e.workerID||\"expired\"===e.state?e.workerID=this.dispatcher.send(\"loadTile\",i,a.bind(this)):\"loading\"===e.state?e.reloadCallback=r:this.dispatcher.send(\"reloadTile\",i,a.bind(this),e.workerID)},r.prototype.abortTile=function(t){this.dispatcher.send(\"abortTile\",{uid:t.uid,type:this.type,source:this.id},void 0,t.workerID)},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.dispatcher.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},void 0,t.workerID)},r.prototype.hasTransition=function(){return!1},r}(t.Evented),S=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.dispatcher=i,this.setEventedParent(a),this.type=\"raster\",this.minzoom=0,this.maxzoom=22,this.roundZoom=!0,this.scheme=\"xyz\",this.tileSize=512,this._loaded=!1,this._options=t.extend({},n),t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"]))}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=T(this._options,this.map._requestManager,function(r,n){e._tileJSONRequest=null,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))})},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.loadTile=function(e,r){var n=this,i=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(i,t.ResourceType.Tile),function(i,a){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(i)e.state=\"errored\",r(i);else if(a){n.map._refreshExpiredTiles&&e.setExpiryData(a),delete a.cacheControl,delete a.expires;var o=n.map.painter.context,s=o.gl;e.texture=n.map.painter.getTileTexture(a.width),e.texture?e.texture.update(a,{useMipmap:!0}):(e.texture=new t.Texture(o,a,s.RGBA,{useMipmap:!0}),e.texture.bind(s.LINEAR,s.CLAMP_TO_EDGE,s.LINEAR_MIPMAP_NEAREST),o.extTextureFilterAnisotropic&&s.texParameterf(s.TEXTURE_2D,o.extTextureFilterAnisotropic.TEXTURE_MAX_ANISOTROPY_EXT,o.extTextureFilterAnisotropicMax)),e.state=\"loaded\",t.cacheEntryPossiblyAdded(n.dispatcher),r(null)}})},r.prototype.abortTile=function(t,e){t.request&&(t.request.cancel(),delete t.request),e()},r.prototype.unloadTile=function(t,e){t.texture&&this.map.painter.saveTileTexture(t.texture),e()},r.prototype.hasTransition=function(){return!1},r}(t.Evented),E=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),this.type=\"raster-dem\",this.maxzoom=22,this._options=t.extend({},n),this.encoding=n.encoding||\"mapbox\"}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.serialize=function(){return{type:\"raster-dem\",url:this.url,tileSize:this.tileSize,tiles:this.tiles,bounds:this.bounds,encoding:this.encoding}},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(n,t.ResourceType.Tile),function(n,i){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(n)e.state=\"errored\",r(n);else if(i){this.map._refreshExpiredTiles&&e.setExpiryData(i),delete i.cacheControl,delete i.expires;var a=t.browser.getImageData(i),o={uid:e.uid,coord:e.tileID,source:this.id,rawImageData:a,encoding:this.encoding};e.workerID&&\"expired\"!==e.state||(e.workerID=this.dispatcher.send(\"loadDEMTile\",o,function(t,n){t&&(e.state=\"errored\",r(t)),n&&(e.dem=n,e.needsHillshadePrepare=!0,e.state=\"loaded\",r(null))}.bind(this)))}}.bind(this)),e.neighboringTiles=this._getNeighboringTiles(e.tileID)},r.prototype._getNeighboringTiles=function(e){var r=e.canonical,n=Math.pow(2,r.z),i=(r.x-1+n)%n,a=0===r.x?e.wrap-1:e.wrap,o=(r.x+1+n)%n,s=r.x+1===n?e.wrap+1:e.wrap,l={};return l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y).key]={backfilled:!1},r.y>0&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y-1).key]={backfilled:!1}),r.y+1<n&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y+1).key]={backfilled:!1}),l},r.prototype.unloadTile=function(t){t.demTexture&&this.map.painter.saveTileTexture(t.demTexture),t.fbo&&(t.fbo.destroy(),delete t.fbo),t.dem&&delete t.dem,delete t.neighboringTiles,t.state=\"unloaded\",this.dispatcher.send(\"removeDEMTile\",{uid:t.uid,source:this.id},void 0,t.workerID)},r}(S),C=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.type=\"geojson\",this.minzoom=0,this.maxzoom=18,this.tileSize=512,this.isTileClipped=!0,this.reparseOverscaled=!0,this._removed=!1,this.dispatcher=i,this.setEventedParent(a),this._data=n.data,this._options=t.extend({},n),this._collectResourceTiming=n.collectResourceTiming,this._resourceTiming=[],void 0!==n.maxzoom&&(this.maxzoom=n.maxzoom),n.type&&(this.type=n.type),n.attribution&&(this.attribution=n.attribution);var o=t.EXTENT/this.tileSize;this.workerOptions=t.extend({source:this.id,cluster:n.cluster||!1,geojsonVtOptions:{buffer:(void 0!==n.buffer?n.buffer:128)*o,tolerance:(void 0!==n.tolerance?n.tolerance:.375)*o,extent:t.EXTENT,maxZoom:this.maxzoom,lineMetrics:n.lineMetrics||!1,generateId:n.generateId||!1},superclusterOptions:{maxZoom:void 0!==n.clusterMaxZoom?Math.min(n.clusterMaxZoom,this.maxzoom-1):this.maxzoom-1,extent:t.EXTENT,radius:(n.clusterRadius||50)*o,log:!1},clusterProperties:n.clusterProperties},n.workerOptions)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData(function(r){if(r)e.fire(new t.ErrorEvent(r));else{var n={dataType:\"source\",sourceDataType:\"metadata\"};e._collectResourceTiming&&e._resourceTiming&&e._resourceTiming.length>0&&(n.resourceTiming=e._resourceTiming,e._resourceTiming=[]),e.fire(new t.Event(\"data\",n))}})},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setData=function(e){var r=this;return this._data=e,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData(function(e){if(e)r.fire(new t.ErrorEvent(e));else{var n={dataType:\"source\",sourceDataType:\"content\"};r._collectResourceTiming&&r._resourceTiming&&r._resourceTiming.length>0&&(n.resourceTiming=r._resourceTiming,r._resourceTiming=[]),r.fire(new t.Event(\"data\",n))}}),this},r.prototype.getClusterExpansionZoom=function(t,e){return this.dispatcher.send(\"geojson.getClusterExpansionZoom\",{clusterId:t,source:this.id},e,this.workerID),this},r.prototype.getClusterChildren=function(t,e){return this.dispatcher.send(\"geojson.getClusterChildren\",{clusterId:t,source:this.id},e,this.workerID),this},r.prototype.getClusterLeaves=function(t,e,r,n){return this.dispatcher.send(\"geojson.getClusterLeaves\",{source:this.id,clusterId:t,limit:e,offset:r},n,this.workerID),this},r.prototype._updateWorkerData=function(e){var r=this,n=t.extend({},this.workerOptions),i=this._data;\"string\"==typeof i?(n.request=this.map._requestManager.transformRequest(t.browser.resolveURL(i),t.ResourceType.Source),n.request.collectResourceTiming=this._collectResourceTiming):n.data=JSON.stringify(i),this.workerID=this.dispatcher.send(this.type+\".loadData\",n,function(t,i){r._removed||i&&i.abandoned||(r._loaded=!0,i&&i.resourceTiming&&i.resourceTiming[r.id]&&(r._resourceTiming=i.resourceTiming[r.id].slice(0)),r.dispatcher.send(r.type+\".coalesce\",{source:n.source},null,r.workerID),e(t))},this.workerID)},r.prototype.loadTile=function(e,r){var n=this,i=void 0===e.workerID?\"loadTile\":\"reloadTile\",a={type:this.type,uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,maxZoom:this.maxzoom,tileSize:this.tileSize,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes};e.workerID=this.dispatcher.send(i,a,function(t,a){return e.unloadVectorData(),e.aborted?r(null):t?r(t):(e.loadVectorData(a,n.map.painter,\"reloadTile\"===i),r(null))},this.workerID)},r.prototype.abortTile=function(t){t.aborted=!0},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.dispatcher.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},null,t.workerID)},r.prototype.onRemove=function(){this._removed=!0,this.dispatcher.send(\"removeSource\",{type:this.type,source:this.id},null,this.workerID)},r.prototype.serialize=function(){return t.extend({},this._options,{type:this.type,data:this._data})},r.prototype.hasTransition=function(){return!1},r}(t.Evented),L=function(e){function r(t,r,n,i){e.call(this),this.id=t,this.dispatcher=n,this.coordinates=r.coordinates,this.type=\"image\",this.minzoom=0,this.maxzoom=22,this.tileSize=512,this.tiles={},this.setEventedParent(i),this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(e,r){var n=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this.url=this.options.url,t.getImage(this.map._requestManager.transformRequest(this.url,t.ResourceType.Image),function(i,a){i?n.fire(new t.ErrorEvent(i)):a&&(n.image=a,e&&(n.coordinates=e),r&&r(),n._finishLoading())})},r.prototype.updateImage=function(t){var e=this;return this.image&&t.url?(this.options.url=t.url,this.load(t.coordinates,function(){e.texture=null}),this):this},r.prototype._finishLoading=function(){this.map&&(this.setCoordinates(this.coordinates),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setCoordinates=function(e){var r=this;this.coordinates=e;var n=e.map(t.MercatorCoordinate.fromLngLat);this.tileID=function(e){for(var r=1/0,n=1/0,i=-1/0,a=-1/0,o=0,s=e;o<s.length;o+=1){var l=s[o];r=Math.min(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.x),a=Math.max(a,l.y)}var c=i-r,u=a-n,h=Math.max(c,u),f=Math.max(0,Math.floor(-Math.log(h)/Math.LN2)),p=Math.pow(2,f);return new t.CanonicalTileID(f,Math.floor((r+i)/2*p),Math.floor((n+a)/2*p))}(n),this.minzoom=this.maxzoom=this.tileID.z;var i=n.map(function(t){return r.tileID.getTilePoint(t)._round()});return this._boundsArray=new t.StructArrayLayout4i8,this._boundsArray.emplaceBack(i[0].x,i[0].y,0,0),this._boundsArray.emplaceBack(i[1].x,i[1].y,t.EXTENT,0),this._boundsArray.emplaceBack(i[3].x,i[3].y,0,t.EXTENT),this._boundsArray.emplaceBack(i[2].x,i[2].y,t.EXTENT,t.EXTENT),this.boundsBuffer&&(this.boundsBuffer.destroy(),delete this.boundsBuffer),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})),this},r.prototype.prepare=function(){if(0!==Object.keys(this.tiles).length&&this.image){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture||(this.texture=new t.Texture(e,this.image,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.loadTile=function(t,e){this.tileID&&this.tileID.equals(t.tileID.canonical)?(this.tiles[String(t.tileID.wrap)]=t,t.buckets={},e(null)):(t.state=\"errored\",e(null))},r.prototype.serialize=function(){return{type:\"image\",url:this.options.url,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return!1},r}(t.Evented),P=function(e){function r(t,r,n,i){e.call(this,t,r,n,i),this.roundZoom=!0,this.type=\"video\",this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this,r=this.options;this.urls=[];for(var n=0,i=r.urls;n<i.length;n+=1){var a=i[n];this.urls.push(this.map._requestManager.transformRequest(a,t.ResourceType.Source).url)}t.getVideo(this.urls,function(r,n){r?e.fire(new t.ErrorEvent(r)):n&&(e.video=n,e.video.loop=!0,e.video.addEventListener(\"playing\",function(){e.map.triggerRepaint()}),e.map&&e.video.play(),e._finishLoading())})},r.prototype.getVideo=function(){return this.video},r.prototype.onAdd=function(t){this.map||(this.map=t,this.load(),this.video&&(this.video.play(),this.setCoordinates(this.coordinates)))},r.prototype.prepare=function(){if(!(0===Object.keys(this.tiles).length||this.video.readyState<2)){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?this.video.paused||(this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE),r.texSubImage2D(r.TEXTURE_2D,0,0,0,r.RGBA,r.UNSIGNED_BYTE,this.video)):(this.texture=new t.Texture(e,this.video,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"video\",urls:this.urls,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this.video&&!this.video.paused},r}(L),O=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),n.coordinates?Array.isArray(n.coordinates)&&4===n.coordinates.length&&!n.coordinates.some(function(t){return!Array.isArray(t)||2!==t.length||t.some(function(t){return\"number\"!=typeof t})})||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"coordinates\" property must be an array of 4 longitude/latitude array pairs'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"coordinates\"'))),n.animate&&\"boolean\"!=typeof n.animate&&this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'optional \"animate\" property must be a boolean value'))),n.canvas?\"string\"==typeof n.canvas||n.canvas instanceof t.window.HTMLCanvasElement||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"canvas\" must be either a string representing the ID of the canvas element from which to read, or an HTMLCanvasElement instance'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"canvas\"'))),this.options=n,this.animate=void 0===n.animate||n.animate}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){this.canvas||(this.canvas=this.options.canvas instanceof t.window.HTMLCanvasElement?this.options.canvas:t.window.document.getElementById(this.options.canvas)),this.width=this.canvas.width,this.height=this.canvas.height,this._hasInvalidDimensions()?this.fire(new t.ErrorEvent(new Error(\"Canvas dimensions cannot be less than or equal to zero.\"))):(this.play=function(){this._playing=!0,this.map.triggerRepaint()},this.pause=function(){this._playing&&(this.prepare(),this._playing=!1)},this._finishLoading())},r.prototype.getCanvas=function(){return this.canvas},r.prototype.onAdd=function(t){this.map=t,this.load(),this.canvas&&this.animate&&this.play()},r.prototype.onRemove=function(){this.pause()},r.prototype.prepare=function(){var e=!1;if(this.canvas.width!==this.width&&(this.width=this.canvas.width,e=!0),this.canvas.height!==this.height&&(this.height=this.canvas.height,e=!0),!this._hasInvalidDimensions()&&0!==Object.keys(this.tiles).length){var r=this.map.painter.context,n=r.gl;for(var i in this.boundsBuffer||(this.boundsBuffer=r.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?(e||this._playing)&&this.texture.update(this.canvas,{premultiply:!0}):this.texture=new t.Texture(r,this.canvas,n.RGBA,{premultiply:!0}),this.tiles){var a=this.tiles[i];\"loaded\"!==a.state&&(a.state=\"loaded\",a.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"canvas\",coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this._playing},r.prototype._hasInvalidDimensions=function(){for(var t=0,e=[this.canvas.width,this.canvas.height];t<e.length;t+=1){var r=e[t];if(isNaN(r)||r<=0)return!0}return!1},r}(L),z={vector:M,raster:S,\"raster-dem\":E,geojson:C,video:P,image:L,canvas:O},I=function(e,r,n,i){var a=new z[r.type](e,r,n,i);if(a.id!==e)throw new Error(\"Expected Source id to be \"+e+\" instead of \"+a.id);return t.bindAll([\"load\",\"abort\",\"unload\",\"serialize\",\"prepare\"],a),a};function D(e,r){var n=t.identity([]);return t.translate(n,n,[1,1,0]),t.scale(n,n,[.5*e.width,.5*e.height,1]),t.multiply(n,n,e.calculatePosMatrix(r.toUnwrapped()))}function R(t,e,r,n,i){var a=function(t,e,r){if(t)for(var n=0,i=t;n<i.length;n+=1){var a=e[i[n]];if(a&&a.source===r&&\"fill-extrusion\"===a.type)return!0}else for(var o in e){var s=e[o];if(s.source===r&&\"fill-extrusion\"===s.type)return!0}return!1}(n&&n.layers,e,t.id),o=i.maxPitchScaleFactor(),s=t.tilesIn(r,o,a);s.sort(F);for(var l=[],c=0,u=s;c<u.length;c+=1){var h=u[c];l.push({wrappedTileID:h.tileID.wrapped().key,queryResults:h.tile.queryRenderedFeatures(e,t._state,h.queryGeometry,h.cameraQueryGeometry,h.scale,n,i,o,D(t.transform,h.tileID))})}var f=function(t){for(var e={},r={},n=0,i=t;n<i.length;n+=1){var a=i[n],o=a.queryResults,s=a.wrappedTileID,l=r[s]=r[s]||{};for(var c in o)for(var u=o[c],h=l[c]=l[c]||{},f=e[c]=e[c]||[],p=0,d=u;p<d.length;p+=1){var g=d[p];h[g.featureIndex]||(h[g.featureIndex]=!0,f.push(g))}}return e}(l);for(var p in f)f[p].forEach(function(e){var r=e.feature,n=t.getFeatureState(r.layer[\"source-layer\"],r.id);r.source=r.layer.source,r.layer[\"source-layer\"]&&(r.sourceLayer=r.layer[\"source-layer\"]),r.state=n});return f}function F(t,e){var r=t.tileID,n=e.tileID;return r.overscaledZ-n.overscaledZ||r.canonical.y-n.canonical.y||r.wrap-n.wrap||r.canonical.x-n.canonical.x}var B=function(t,e){this.max=t,this.onRemove=e,this.reset()};B.prototype.reset=function(){for(var t in this.data)for(var e=0,r=this.data[t];e<r.length;e+=1){var n=r[e];n.timeout&&clearTimeout(n.timeout),this.onRemove(n.value)}return this.data={},this.order=[],this},B.prototype.add=function(t,e,r){var n=this,i=t.wrapped().key;void 0===this.data[i]&&(this.data[i]=[]);var a={value:e,timeout:void 0};if(void 0!==r&&(a.timeout=setTimeout(function(){n.remove(t,a)},r)),this.data[i].push(a),this.order.push(i),this.order.length>this.max){var o=this._getAndRemoveByKey(this.order[0]);o&&this.onRemove(o)}return this},B.prototype.has=function(t){return t.wrapped().key in this.data},B.prototype.getAndRemove=function(t){return this.has(t)?this._getAndRemoveByKey(t.wrapped().key):null},B.prototype._getAndRemoveByKey=function(t){var e=this.data[t].shift();return e.timeout&&clearTimeout(e.timeout),0===this.data[t].length&&delete this.data[t],this.order.splice(this.order.indexOf(t),1),e.value},B.prototype.get=function(t){return this.has(t)?this.data[t.wrapped().key][0].value:null},B.prototype.remove=function(t,e){if(!this.has(t))return this;var r=t.wrapped().key,n=void 0===e?0:this.data[r].indexOf(e),i=this.data[r][n];return this.data[r].splice(n,1),i.timeout&&clearTimeout(i.timeout),0===this.data[r].length&&delete this.data[r],this.onRemove(i.value),this.order.splice(this.order.indexOf(r),1),this},B.prototype.setMaxSize=function(t){for(this.max=t;this.order.length>this.max;){var e=this._getAndRemoveByKey(this.order[0]);e&&this.onRemove(e)}return this};var N=function(t,e,r){this.context=t;var n=t.gl;this.buffer=n.createBuffer(),this.dynamicDraw=Boolean(r),this.context.unbindVAO(),t.bindElementBuffer.set(this.buffer),n.bufferData(n.ELEMENT_ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?n.DYNAMIC_DRAW:n.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};N.prototype.bind=function(){this.context.bindElementBuffer.set(this.buffer)},N.prototype.updateData=function(t){var e=this.context.gl;this.context.unbindVAO(),this.bind(),e.bufferSubData(e.ELEMENT_ARRAY_BUFFER,0,t.arrayBuffer)},N.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var j={Int8:\"BYTE\",Uint8:\"UNSIGNED_BYTE\",Int16:\"SHORT\",Uint16:\"UNSIGNED_SHORT\",Int32:\"INT\",Uint32:\"UNSIGNED_INT\",Float32:\"FLOAT\"},U=function(t,e,r,n){this.length=e.length,this.attributes=r,this.itemSize=e.bytesPerElement,this.dynamicDraw=n,this.context=t;var i=t.gl;this.buffer=i.createBuffer(),t.bindVertexBuffer.set(this.buffer),i.bufferData(i.ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?i.DYNAMIC_DRAW:i.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};U.prototype.bind=function(){this.context.bindVertexBuffer.set(this.buffer)},U.prototype.updateData=function(t){var e=this.context.gl;this.bind(),e.bufferSubData(e.ARRAY_BUFFER,0,t.arrayBuffer)},U.prototype.enableAttributes=function(t,e){for(var r=0;r<this.attributes.length;r++){var n=this.attributes[r],i=e.attributes[n.name];void 0!==i&&t.enableVertexAttribArray(i)}},U.prototype.setVertexAttribPointers=function(t,e,r){for(var n=0;n<this.attributes.length;n++){var i=this.attributes[n],a=e.attributes[i.name];void 0!==a&&t.vertexAttribPointer(a,i.components,t[j[i.type]],!1,this.itemSize,i.offset+this.itemSize*(r||0))}},U.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var V=function(t){this.gl=t.gl,this.default=this.getDefault(),this.current=this.default,this.dirty=!1};V.prototype.get=function(){return this.current},V.prototype.set=function(t){},V.prototype.getDefault=function(){return this.default},V.prototype.setDefault=function(){this.set(this.default)};var q=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.clearColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(V),H=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 1},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearDepth(t),this.current=t,this.dirty=!1)},e}(V),G=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearStencil(t),this.current=t,this.dirty=!1)},e}(V),Y=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return[!0,!0,!0,!0]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.colorMask(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(V),W=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthMask(t),this.current=t,this.dirty=!1)},e}(V),X=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 255},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.stencilMask(t),this.current=t,this.dirty=!1)},e}(V),Z=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return{func:this.gl.ALWAYS,ref:0,mask:255}},e.prototype.set=function(t){var e=this.current;(t.func!==e.func||t.ref!==e.ref||t.mask!==e.mask||this.dirty)&&(this.gl.stencilFunc(t.func,t.ref,t.mask),this.current=t,this.dirty=!1)},e}(V),J=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.KEEP,t.KEEP,t.KEEP]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||this.dirty)&&(this.gl.stencilOp(t[0],t[1],t[2]),this.current=t,this.dirty=!1)},e}(V),K=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.STENCIL_TEST):e.disable(e.STENCIL_TEST),this.current=t,this.dirty=!1}},e}(V),$=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return[0,1]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.depthRange(t[0],t[1]),this.current=t,this.dirty=!1)},e}(V),Q=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.DEPTH_TEST):e.disable(e.DEPTH_TEST),this.current=t,this.dirty=!1}},e}(V),tt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.LESS},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthFunc(t),this.current=t,this.dirty=!1)},e}(V),et=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.BLEND):e.disable(e.BLEND),this.current=t,this.dirty=!1}},e}(V),rt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.ONE,t.ZERO]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.blendFunc(t[0],t[1]),this.current=t,this.dirty=!1)},e}(V),nt=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.blendColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(V),it=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.FUNC_ADD},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.blendEquation(t),this.current=t,this.dirty=!1)},e}(V),at=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.CULL_FACE):e.disable(e.CULL_FACE),this.current=t,this.dirty=!1}},e}(V),ot=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.BACK},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.cullFace(t),this.current=t,this.dirty=!1)},e}(V),st=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.CCW},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.frontFace(t),this.current=t,this.dirty=!1)},e}(V),lt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.useProgram(t),this.current=t,this.dirty=!1)},e}(V),ct=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.TEXTURE0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.activeTexture(t),this.current=t,this.dirty=!1)},e}(V),ut=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[0,0,t.drawingBufferWidth,t.drawingBufferHeight]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.viewport(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(V),ht=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindFramebuffer(e.FRAMEBUFFER,t),this.current=t,this.dirty=!1}},e}(V),ft=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindRenderbuffer(e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(V),pt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindTexture(e.TEXTURE_2D,t),this.current=t,this.dirty=!1}},e}(V),dt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindBuffer(e.ARRAY_BUFFER,t),this.current=t,this.dirty=!1}},e}(V),gt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){var e=this.gl;e.bindBuffer(e.ELEMENT_ARRAY_BUFFER,t),this.current=t,this.dirty=!1},e}(V),vt=function(t){function e(e){t.call(this,e),this.vao=e.extVertexArrayObject}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){this.vao&&(t!==this.current||this.dirty)&&(this.vao.bindVertexArrayOES(t),this.current=t,this.dirty=!1)},e}(V),mt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 4},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_ALIGNMENT,t),this.current=t,this.dirty=!1}},e}(V),yt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_PREMULTIPLY_ALPHA_WEBGL,t),this.current=t,this.dirty=!1}},e}(V),xt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_FLIP_Y_WEBGL,t),this.current=t,this.dirty=!1}},e}(V),bt=function(t){function e(e,r){t.call(this,e),this.context=e,this.parent=r}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e}(V),_t=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.setDirty=function(){this.dirty=!0},e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferTexture2D(e.FRAMEBUFFER,e.COLOR_ATTACHMENT0,e.TEXTURE_2D,t,0),this.current=t,this.dirty=!1}},e}(bt),wt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferRenderbuffer(e.FRAMEBUFFER,e.DEPTH_ATTACHMENT,e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(bt),kt=function(t,e,r){this.context=t,this.width=e,this.height=r;var n=t.gl,i=this.framebuffer=n.createFramebuffer();this.colorAttachment=new _t(t,i),this.depthAttachment=new wt(t,i)};kt.prototype.destroy=function(){var t=this.context.gl,e=this.colorAttachment.get();e&&t.deleteTexture(e);var r=this.depthAttachment.get();r&&t.deleteRenderbuffer(r),t.deleteFramebuffer(this.framebuffer)};var Tt=function(t,e,r){this.func=t,this.mask=e,this.range=r};Tt.ReadOnly=!1,Tt.ReadWrite=!0,Tt.disabled=new Tt(519,Tt.ReadOnly,[0,1]);var At=function(t,e,r,n,i,a){this.test=t,this.ref=e,this.mask=r,this.fail=n,this.depthFail=i,this.pass=a};At.disabled=new At({func:519,mask:0},0,0,7680,7680,7680);var Mt=function(t,e,r){this.blendFunction=t,this.blendColor=e,this.mask=r};Mt.disabled=new Mt(Mt.Replace=[1,0],t.Color.transparent,[!1,!1,!1,!1]),Mt.unblended=new Mt(Mt.Replace,t.Color.transparent,[!0,!0,!0,!0]),Mt.alphaBlended=new Mt([1,771],t.Color.transparent,[!0,!0,!0,!0]);var St=function(t,e,r){this.enable=t,this.mode=e,this.frontFace=r};St.disabled=new St(!1,1029,2305),St.backCCW=new St(!0,1029,2305);var Et=function(t){this.gl=t,this.extVertexArrayObject=this.gl.getExtension(\"OES_vertex_array_object\"),this.clearColor=new q(this),this.clearDepth=new H(this),this.clearStencil=new G(this),this.colorMask=new Y(this),this.depthMask=new W(this),this.stencilMask=new X(this),this.stencilFunc=new Z(this),this.stencilOp=new J(this),this.stencilTest=new K(this),this.depthRange=new $(this),this.depthTest=new Q(this),this.depthFunc=new tt(this),this.blend=new et(this),this.blendFunc=new rt(this),this.blendColor=new nt(this),this.blendEquation=new it(this),this.cullFace=new at(this),this.cullFaceSide=new ot(this),this.frontFace=new st(this),this.program=new lt(this),this.activeTexture=new ct(this),this.viewport=new ut(this),this.bindFramebuffer=new ht(this),this.bindRenderbuffer=new ft(this),this.bindTexture=new pt(this),this.bindVertexBuffer=new dt(this),this.bindElementBuffer=new gt(this),this.bindVertexArrayOES=this.extVertexArrayObject&&new vt(this),this.pixelStoreUnpack=new mt(this),this.pixelStoreUnpackPremultiplyAlpha=new yt(this),this.pixelStoreUnpackFlipY=new xt(this),this.extTextureFilterAnisotropic=t.getExtension(\"EXT_texture_filter_anisotropic\")||t.getExtension(\"MOZ_EXT_texture_filter_anisotropic\")||t.getExtension(\"WEBKIT_EXT_texture_filter_anisotropic\"),this.extTextureFilterAnisotropic&&(this.extTextureFilterAnisotropicMax=t.getParameter(this.extTextureFilterAnisotropic.MAX_TEXTURE_MAX_ANISOTROPY_EXT)),this.extTextureHalfFloat=t.getExtension(\"OES_texture_half_float\"),this.extTextureHalfFloat&&t.getExtension(\"OES_texture_half_float_linear\")};Et.prototype.setDefault=function(){this.unbindVAO(),this.clearColor.setDefault(),this.clearDepth.setDefault(),this.clearStencil.setDefault(),this.colorMask.setDefault(),this.depthMask.setDefault(),this.stencilMask.setDefault(),this.stencilFunc.setDefault(),this.stencilOp.setDefault(),this.stencilTest.setDefault(),this.depthRange.setDefault(),this.depthTest.setDefault(),this.depthFunc.setDefault(),this.blend.setDefault(),this.blendFunc.setDefault(),this.blendColor.setDefault(),this.blendEquation.setDefault(),this.cullFace.setDefault(),this.cullFaceSide.setDefault(),this.frontFace.setDefault(),this.program.setDefault(),this.activeTexture.setDefault(),this.bindFramebuffer.setDefault(),this.pixelStoreUnpack.setDefault(),this.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.pixelStoreUnpackFlipY.setDefault()},Et.prototype.setDirty=function(){this.clearColor.dirty=!0,this.clearDepth.dirty=!0,this.clearStencil.dirty=!0,this.colorMask.dirty=!0,this.depthMask.dirty=!0,this.stencilMask.dirty=!0,this.stencilFunc.dirty=!0,this.stencilOp.dirty=!0,this.stencilTest.dirty=!0,this.depthRange.dirty=!0,this.depthTest.dirty=!0,this.depthFunc.dirty=!0,this.blend.dirty=!0,this.blendFunc.dirty=!0,this.blendColor.dirty=!0,this.blendEquation.dirty=!0,this.cullFace.dirty=!0,this.cullFaceSide.dirty=!0,this.frontFace.dirty=!0,this.program.dirty=!0,this.activeTexture.dirty=!0,this.viewport.dirty=!0,this.bindFramebuffer.dirty=!0,this.bindRenderbuffer.dirty=!0,this.bindTexture.dirty=!0,this.bindVertexBuffer.dirty=!0,this.bindElementBuffer.dirty=!0,this.extVertexArrayObject&&(this.bindVertexArrayOES.dirty=!0),this.pixelStoreUnpack.dirty=!0,this.pixelStoreUnpackPremultiplyAlpha.dirty=!0,this.pixelStoreUnpackFlipY.dirty=!0},Et.prototype.createIndexBuffer=function(t,e){return new N(this,t,e)},Et.prototype.createVertexBuffer=function(t,e,r){return new U(this,t,e,r)},Et.prototype.createRenderbuffer=function(t,e,r){var n=this.gl,i=n.createRenderbuffer();return this.bindRenderbuffer.set(i),n.renderbufferStorage(n.RENDERBUFFER,t,e,r),this.bindRenderbuffer.set(null),i},Et.prototype.createFramebuffer=function(t,e){return new kt(this,t,e)},Et.prototype.clear=function(t){var e=t.color,r=t.depth,n=this.gl,i=0;e&&(i|=n.COLOR_BUFFER_BIT,this.clearColor.set(e),this.colorMask.set([!0,!0,!0,!0])),void 0!==r&&(i|=n.DEPTH_BUFFER_BIT,this.depthRange.set([0,1]),this.clearDepth.set(r),this.depthMask.set(!0)),n.clear(i)},Et.prototype.setCullFace=function(t){!1===t.enable?this.cullFace.set(!1):(this.cullFace.set(!0),this.cullFaceSide.set(t.mode),this.frontFace.set(t.frontFace))},Et.prototype.setDepthMode=function(t){t.func!==this.gl.ALWAYS||t.mask?(this.depthTest.set(!0),this.depthFunc.set(t.func),this.depthMask.set(t.mask),this.depthRange.set(t.range)):this.depthTest.set(!1)},Et.prototype.setStencilMode=function(t){t.test.func!==this.gl.ALWAYS||t.mask?(this.stencilTest.set(!0),this.stencilMask.set(t.mask),this.stencilOp.set([t.fail,t.depthFail,t.pass]),this.stencilFunc.set({func:t.test.func,ref:t.ref,mask:t.test.mask})):this.stencilTest.set(!1)},Et.prototype.setColorMode=function(e){t.deepEqual(e.blendFunction,Mt.Replace)?this.blend.set(!1):(this.blend.set(!0),this.blendFunc.set(e.blendFunction),this.blendColor.set(e.blendColor)),this.colorMask.set(e.mask)},Et.prototype.unbindVAO=function(){this.extVertexArrayObject&&this.bindVertexArrayOES.set(null)};var Ct=function(e){function r(r,n,i){var a=this;e.call(this),this.id=r,this.dispatcher=i,this.on(\"data\",function(t){\"source\"===t.dataType&&\"metadata\"===t.sourceDataType&&(a._sourceLoaded=!0),a._sourceLoaded&&!a._paused&&\"source\"===t.dataType&&\"content\"===t.sourceDataType&&(a.reload(),a.transform&&a.update(a.transform))}),this.on(\"error\",function(){a._sourceErrored=!0}),this._source=I(r,n,i,this),this._tiles={},this._cache=new B(0,this._unloadTile.bind(this)),this._timers={},this._cacheTimers={},this._maxTileCacheSize=null,this._coveredTiles={},this._state=new t.SourceFeatureState}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.onAdd=function(t){this.map=t,this._maxTileCacheSize=t?t._maxTileCacheSize:null,this._source&&this._source.onAdd&&this._source.onAdd(t)},r.prototype.onRemove=function(t){this._source&&this._source.onRemove&&this._source.onRemove(t)},r.prototype.loaded=function(){if(this._sourceErrored)return!0;if(!this._sourceLoaded)return!1;for(var t in this._tiles){var e=this._tiles[t];if(\"loaded\"!==e.state&&\"errored\"!==e.state)return!1}return!0},r.prototype.getSource=function(){return this._source},r.prototype.pause=function(){this._paused=!0},r.prototype.resume=function(){if(this._paused){var t=this._shouldReloadOnResume;this._paused=!1,this._shouldReloadOnResume=!1,t&&this.reload(),this.transform&&this.update(this.transform)}},r.prototype._loadTile=function(t,e){return this._source.loadTile(t,e)},r.prototype._unloadTile=function(t){if(this._source.unloadTile)return this._source.unloadTile(t,function(){})},r.prototype._abortTile=function(t){if(this._source.abortTile)return this._source.abortTile(t,function(){})},r.prototype.serialize=function(){return this._source.serialize()},r.prototype.prepare=function(t){for(var e in this._source.prepare&&this._source.prepare(),this._state.coalesceChanges(this._tiles,this.map?this.map.painter:null),this._tiles){var r=this._tiles[e];r.upload(t),r.prepare(this.map.style.imageManager)}},r.prototype.getIds=function(){return Object.keys(this._tiles).map(Number).sort(Lt)},r.prototype.getRenderableIds=function(e){var r=this,n=[];for(var i in this._tiles)this._isIdRenderable(+i,e)&&n.push(+i);return e?n.sort(function(e,n){var i=r._tiles[e].tileID,a=r._tiles[n].tileID,o=new t.Point(i.canonical.x,i.canonical.y)._rotate(r.transform.angle),s=new t.Point(a.canonical.x,a.canonical.y)._rotate(r.transform.angle);return i.overscaledZ-a.overscaledZ||s.y-o.y||s.x-o.x}):n.sort(Lt)},r.prototype.hasRenderableParent=function(t){var e=this.findLoadedParent(t,0);return!!e&&this._isIdRenderable(e.tileID.key)},r.prototype._isIdRenderable=function(t,e){return this._tiles[t]&&this._tiles[t].hasData()&&!this._coveredTiles[t]&&(e||!this._tiles[t].holdingForFade())},r.prototype.reload=function(){if(this._paused)this._shouldReloadOnResume=!0;else for(var t in this._cache.reset(),this._tiles)\"errored\"!==this._tiles[t].state&&this._reloadTile(t,\"reloading\")},r.prototype._reloadTile=function(t,e){var r=this._tiles[t];r&&(\"loading\"!==r.state&&(r.state=e),this._loadTile(r,this._tileLoaded.bind(this,r,t,e)))},r.prototype._tileLoaded=function(e,r,n,i){if(i)return e.state=\"errored\",void(404!==i.status?this._source.fire(new t.ErrorEvent(i,{tile:e})):this.update(this.transform));e.timeAdded=t.browser.now(),\"expired\"===n&&(e.refreshedUponExpiration=!0),this._setTileReloadTimer(r,e),\"raster-dem\"===this.getSource().type&&e.dem&&this._backfillDEM(e),this._state.initializeTileState(e,this.map?this.map.painter:null),this._source.fire(new t.Event(\"data\",{dataType:\"source\",tile:e,coord:e.tileID}))},r.prototype._backfillDEM=function(t){for(var e=this.getRenderableIds(),r=0;r<e.length;r++){var n=e[r];if(t.neighboringTiles&&t.neighboringTiles[n]){var i=this.getTileByID(n);a(t,i),a(i,t)}}function a(t,e){t.needsHillshadePrepare=!0;var r=e.tileID.canonical.x-t.tileID.canonical.x,n=e.tileID.canonical.y-t.tileID.canonical.y,i=Math.pow(2,t.tileID.canonical.z),a=e.tileID.key;0===r&&0===n||Math.abs(n)>1||(Math.abs(r)>1&&(1===Math.abs(r+i)?r+=i:1===Math.abs(r-i)&&(r-=i)),e.dem&&t.dem&&(t.dem.backfillBorder(e.dem,r,n),t.neighboringTiles&&t.neighboringTiles[a]&&(t.neighboringTiles[a].backfilled=!0)))}},r.prototype.getTile=function(t){return this.getTileByID(t.key)},r.prototype.getTileByID=function(t){return this._tiles[t]},r.prototype.getZoom=function(t){return t.zoom+t.scaleZoom(t.tileSize/this._source.tileSize)},r.prototype._retainLoadedChildren=function(t,e,r,n){for(var i in this._tiles){var a=this._tiles[i];if(!(n[i]||!a.hasData()||a.tileID.overscaledZ<=e||a.tileID.overscaledZ>r)){for(var o=a.tileID;a&&a.tileID.overscaledZ>e+1;){var s=a.tileID.scaledTo(a.tileID.overscaledZ-1);(a=this._tiles[s.key])&&a.hasData()&&(o=s)}for(var l=o;l.overscaledZ>e;)if(t[(l=l.scaledTo(l.overscaledZ-1)).key]){n[o.key]=o;break}}}},r.prototype.findLoadedParent=function(t,e){for(var r=t.overscaledZ-1;r>=e;r--){var n=t.scaledTo(r);if(!n)return;var i=String(n.key),a=this._tiles[i];if(a&&a.hasData())return a;if(this._cache.has(n))return this._cache.get(n)}},r.prototype.updateCacheSize=function(t){var e=(Math.ceil(t.width/this._source.tileSize)+1)*(Math.ceil(t.height/this._source.tileSize)+1),r=Math.floor(5*e),n=\"number\"==typeof this._maxTileCacheSize?Math.min(this._maxTileCacheSize,r):r;this._cache.setMaxSize(n)},r.prototype.handleWrapJump=function(t){var e=(t-(void 0===this._prevLng?t:this._prevLng))/360,r=Math.round(e);if(this._prevLng=t,r){var n={};for(var i in this._tiles){var a=this._tiles[i];a.tileID=a.tileID.unwrapTo(a.tileID.wrap+r),n[a.tileID.key]=a}for(var o in this._tiles=n,this._timers)clearTimeout(this._timers[o]),delete this._timers[o];for(var s in this._tiles){var l=this._tiles[s];this._setTileReloadTimer(s,l)}}},r.prototype.update=function(e){var n=this;if(this.transform=e,this._sourceLoaded&&!this._paused){var i;this.updateCacheSize(e),this.handleWrapJump(this.transform.center.lng),this._coveredTiles={},this.used?this._source.tileID?i=e.getVisibleUnwrappedCoordinates(this._source.tileID).map(function(e){return new t.OverscaledTileID(e.canonical.z,e.wrap,e.canonical.z,e.canonical.x,e.canonical.y)}):(i=e.coveringTiles({tileSize:this._source.tileSize,minzoom:this._source.minzoom,maxzoom:this._source.maxzoom,roundZoom:this._source.roundZoom,reparseOverscaled:this._source.reparseOverscaled}),this._source.hasTile&&(i=i.filter(function(t){return n._source.hasTile(t)}))):i=[];var a=(this._source.roundZoom?Math.round:Math.floor)(this.getZoom(e)),o=Math.max(a-r.maxOverzooming,this._source.minzoom),s=Math.max(a+r.maxUnderzooming,this._source.minzoom),l=this._updateRetainedTiles(i,a);if(Pt(this._source.type)){for(var c={},u={},h=0,f=Object.keys(l);h<f.length;h+=1){var p=f[h],d=l[p],g=this._tiles[p];if(g&&!(g.fadeEndTime&&g.fadeEndTime<=t.browser.now())){var v=this.findLoadedParent(d,o);v&&(this._addTile(v.tileID),c[v.tileID.key]=v.tileID),u[p]=d}}for(var m in this._retainLoadedChildren(u,a,s,l),c)l[m]||(this._coveredTiles[m]=!0,l[m]=c[m])}for(var y in l)this._tiles[y].clearFadeHold();for(var x=0,b=t.keysDifference(this._tiles,l);x<b.length;x+=1){var _=b[x],w=this._tiles[_];w.hasSymbolBuckets&&!w.holdingForFade()?w.setHoldDuration(this.map._fadeDuration):w.hasSymbolBuckets&&!w.symbolFadeFinished()||this._removeTile(_)}}},r.prototype.releaseSymbolFadeTiles=function(){for(var t in this._tiles)this._tiles[t].holdingForFade()&&this._removeTile(t)},r.prototype._updateRetainedTiles=function(t,e){for(var n={},i={},a=Math.max(e-r.maxOverzooming,this._source.minzoom),o=Math.max(e+r.maxUnderzooming,this._source.minzoom),s={},l=0,c=t;l<c.length;l+=1){var u=c[l],h=this._addTile(u);n[u.key]=u,h.hasData()||e<this._source.maxzoom&&(s[u.key]=u)}this._retainLoadedChildren(s,e,o,n);for(var f=0,p=t;f<p.length;f+=1){var d=p[f],g=this._tiles[d.key];if(!g.hasData()){if(e+1>this._source.maxzoom){var v=d.children(this._source.maxzoom)[0],m=this.getTile(v);if(m&&m.hasData()){n[v.key]=v;continue}}else{var y=d.children(this._source.maxzoom);if(n[y[0].key]&&n[y[1].key]&&n[y[2].key]&&n[y[3].key])continue}for(var x=g.wasRequested(),b=d.overscaledZ-1;b>=a;--b){var _=d.scaledTo(b);if(i[_.key])break;if(i[_.key]=!0,!(g=this.getTile(_))&&x&&(g=this._addTile(_)),g&&(n[_.key]=_,x=g.wasRequested(),g.hasData()))break}}}return n},r.prototype._addTile=function(e){var r=this._tiles[e.key];if(r)return r;(r=this._cache.getAndRemove(e))&&(this._setTileReloadTimer(e.key,r),r.tileID=e,this._state.initializeTileState(r,this.map?this.map.painter:null),this._cacheTimers[e.key]&&(clearTimeout(this._cacheTimers[e.key]),delete this._cacheTimers[e.key],this._setTileReloadTimer(e.key,r)));var n=Boolean(r);return n||(r=new t.Tile(e,this._source.tileSize*e.overscaleFactor()),this._loadTile(r,this._tileLoaded.bind(this,r,e.key,r.state))),r?(r.uses++,this._tiles[e.key]=r,n||this._source.fire(new t.Event(\"dataloading\",{tile:r,coord:r.tileID,dataType:\"source\"})),r):null},r.prototype._setTileReloadTimer=function(t,e){var r=this;t in this._timers&&(clearTimeout(this._timers[t]),delete this._timers[t]);var n=e.getExpiryTimeout();n&&(this._timers[t]=setTimeout(function(){r._reloadTile(t,\"expired\"),delete r._timers[t]},n))},r.prototype._removeTile=function(t){var e=this._tiles[t];e&&(e.uses--,delete this._tiles[t],this._timers[t]&&(clearTimeout(this._timers[t]),delete this._timers[t]),e.uses>0||(e.hasData()?this._cache.add(e.tileID,e,e.getExpiryTimeout()):(e.aborted=!0,this._abortTile(e),this._unloadTile(e))))},r.prototype.clearTiles=function(){for(var t in this._shouldReloadOnResume=!1,this._paused=!1,this._tiles)this._removeTile(t);this._cache.reset()},r.prototype.tilesIn=function(e,r,n){var i=this,a=[],o=this.transform;if(!o)return a;for(var s=n?o.getCameraQueryGeometry(e):e,l=e.map(function(t){return o.pointCoordinate(t)}),c=s.map(function(t){return o.pointCoordinate(t)}),u=this.getIds(),h=1/0,f=1/0,p=-1/0,d=-1/0,g=0,v=c;g<v.length;g+=1){var m=v[g];h=Math.min(h,m.x),f=Math.min(f,m.y),p=Math.max(p,m.x),d=Math.max(d,m.y)}for(var y=function(e){var n=i._tiles[u[e]];if(!n.holdingForFade()){var s=n.tileID,g=Math.pow(2,o.zoom-n.tileID.overscaledZ),v=r*n.queryPadding*t.EXTENT/n.tileSize/g,m=[s.getTilePoint(new t.MercatorCoordinate(h,f)),s.getTilePoint(new t.MercatorCoordinate(p,d))];if(m[0].x-v<t.EXTENT&&m[0].y-v<t.EXTENT&&m[1].x+v>=0&&m[1].y+v>=0){var y=l.map(function(t){return s.getTilePoint(t)}),x=c.map(function(t){return s.getTilePoint(t)});a.push({tile:n,tileID:s,queryGeometry:y,cameraQueryGeometry:x,scale:g})}}},x=0;x<u.length;x++)y(x);return a},r.prototype.getVisibleCoordinates=function(t){for(var e=this,r=this.getRenderableIds(t).map(function(t){return e._tiles[t].tileID}),n=0,i=r;n<i.length;n+=1){var a=i[n];a.posMatrix=this.transform.calculatePosMatrix(a.toUnwrapped())}return r},r.prototype.hasTransition=function(){if(this._source.hasTransition())return!0;if(Pt(this._source.type))for(var e in this._tiles){var r=this._tiles[e];if(void 0!==r.fadeEndTime&&r.fadeEndTime>=t.browser.now())return!0}return!1},r.prototype.setFeatureState=function(t,e,r){t=t||\"_geojsonTileLayer\",this._state.updateState(t,e,r)},r.prototype.removeFeatureState=function(t,e,r){t=t||\"_geojsonTileLayer\",this._state.removeFeatureState(t,e,r)},r.prototype.getFeatureState=function(t,e){return t=t||\"_geojsonTileLayer\",this._state.getState(t,e)},r}(t.Evented);function Lt(t,e){return t%32-e%32||e-t}function Pt(t){return\"raster\"===t||\"image\"===t||\"video\"===t}function Ot(){return new t.window.Worker(Jn.workerUrl)}Ct.maxOverzooming=10,Ct.maxUnderzooming=3;var zt=function(){this.active={}};zt.prototype.acquire=function(t){if(!this.workers)for(this.workers=[];this.workers.length<zt.workerCount;)this.workers.push(new Ot);return this.active[t]=!0,this.workers.slice()},zt.prototype.release=function(t){delete this.active[t],0===Object.keys(this.active).length&&(this.workers.forEach(function(t){t.terminate()}),this.workers=null)};var It,Dt=Math.floor(t.browser.hardwareConcurrency/2);function Rt(e,r){var n={};for(var i in e)\"ref\"!==i&&(n[i]=e[i]);return t.refProperties.forEach(function(t){t in r&&(n[t]=r[t])}),n}function Ft(t){t=t.slice();for(var e=Object.create(null),r=0;r<t.length;r++)e[t[r].id]=t[r];for(var n=0;n<t.length;n++)\"ref\"in t[n]&&(t[n]=Rt(t[n],e[t[n].ref]));return t}zt.workerCount=Math.max(Math.min(Dt,6),1);var Bt={setStyle:\"setStyle\",addLayer:\"addLayer\",removeLayer:\"removeLayer\",setPaintProperty:\"setPaintProperty\",setLayoutProperty:\"setLayoutProperty\",setFilter:\"setFilter\",addSource:\"addSource\",removeSource:\"removeSource\",setGeoJSONSourceData:\"setGeoJSONSourceData\",setLayerZoomRange:\"setLayerZoomRange\",setLayerProperty:\"setLayerProperty\",setCenter:\"setCenter\",setZoom:\"setZoom\",setBearing:\"setBearing\",setPitch:\"setPitch\",setSprite:\"setSprite\",setGlyphs:\"setGlyphs\",setTransition:\"setTransition\",setLight:\"setLight\"};function Nt(t,e,r){r.push({command:Bt.addSource,args:[t,e[t]]})}function jt(t,e,r){e.push({command:Bt.removeSource,args:[t]}),r[t]=!0}function Ut(t,e,r,n){jt(t,r,n),Nt(t,e,r)}function Vt(e,r,n){var i;for(i in e[n])if(e[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;for(i in r[n])if(r[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;return!0}function qt(e,r,n,i,a,o){var s;for(s in r=r||{},e=e||{})e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}));for(s in r)r.hasOwnProperty(s)&&!e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}))}function Ht(t){return t.id}function Gt(t,e){return t[e.id]=e,t}var Yt=function(t,e,r){var n=this.boxCells=[],i=this.circleCells=[];this.xCellCount=Math.ceil(t/r),this.yCellCount=Math.ceil(e/r);for(var a=0;a<this.xCellCount*this.yCellCount;a++)n.push([]),i.push([]);this.circleKeys=[],this.boxKeys=[],this.bboxes=[],this.circles=[],this.width=t,this.height=e,this.xScale=this.xCellCount/t,this.yScale=this.yCellCount/e,this.boxUid=0,this.circleUid=0};function Wt(e,r,n,i,a){var o=t.create();return r?(t.scale(o,o,[1/a,1/a,1]),n||t.rotateZ(o,o,i.angle)):t.multiply(o,i.labelPlaneMatrix,e),o}function Xt(e,r,n,i,a){if(r){var o=t.clone(e);return t.scale(o,o,[a,a,1]),n||t.rotateZ(o,o,-i.angle),o}return i.glCoordMatrix}function Zt(e,r){var n=[e.x,e.y,0,1];ae(n,n,r);var i=n[3];return{point:new t.Point(n[0]/i,n[1]/i),signedDistanceFromCamera:i}}function Jt(t,e){var r=t[0]/t[3],n=t[1]/t[3];return r>=-e[0]&&r<=e[0]&&n>=-e[1]&&n<=e[1]}function Kt(e,r,n,i,a,o,s,l){var c=i?e.textSizeData:e.iconSizeData,u=t.evaluateSizeForZoom(c,n.transform.zoom),h=[256/n.width*2+1,256/n.height*2+1],f=i?e.text.dynamicLayoutVertexArray:e.icon.dynamicLayoutVertexArray;f.clear();for(var p=e.lineVertexArray,d=i?e.text.placedSymbolArray:e.icon.placedSymbolArray,g=n.transform.width/n.transform.height,v=!1,m=0;m<d.length;m++){var y=d.get(m);if(y.hidden||y.writingMode===t.WritingMode.vertical&&!v)ie(y.numGlyphs,f);else{v=!1;var x=[y.anchorX,y.anchorY,0,1];if(t.transformMat4(x,x,r),Jt(x,h)){var b=.5+x[3]/n.transform.cameraToCenterDistance*.5,_=t.evaluateSizeForFeature(c,u,y),w=s?_*b:_/b,k=new t.Point(y.anchorX,y.anchorY),T=Zt(k,a).point,A={},M=te(y,w,!1,l,r,a,o,e.glyphOffsetArray,p,f,T,k,A,g);v=M.useVertical,(M.notEnoughRoom||v||M.needsFlipping&&te(y,w,!0,l,r,a,o,e.glyphOffsetArray,p,f,T,k,A,g).notEnoughRoom)&&ie(y.numGlyphs,f)}else ie(y.numGlyphs,f)}}i?e.text.dynamicLayoutVertexBuffer.updateData(f):e.icon.dynamicLayoutVertexBuffer.updateData(f)}function $t(t,e,r,n,i,a,o,s,l,c,u,h){var f=s.glyphStartIndex+s.numGlyphs,p=s.lineStartIndex,d=s.lineStartIndex+s.lineLength,g=e.getoffsetX(s.glyphStartIndex),v=e.getoffsetX(f-1),m=re(t*g,r,n,i,a,o,s.segment,p,d,l,c,u,h);if(!m)return null;var y=re(t*v,r,n,i,a,o,s.segment,p,d,l,c,u,h);return y?{first:m,last:y}:null}function Qt(e,r,n,i){return e===t.WritingMode.horizontal&&Math.abs(n.y-r.y)>Math.abs(n.x-r.x)*i?{useVertical:!0}:(e===t.WritingMode.vertical?r.y<n.y:r.x>n.x)?{needsFlipping:!0}:null}function te(e,r,n,i,a,o,s,l,c,u,h,f,p,d){var g,v=r/24,m=e.lineOffsetX*v,y=e.lineOffsetY*v;if(e.numGlyphs>1){var x=e.glyphStartIndex+e.numGlyphs,b=e.lineStartIndex,_=e.lineStartIndex+e.lineLength,w=$t(v,l,m,y,n,h,f,e,c,o,p,!1);if(!w)return{notEnoughRoom:!0};var k=Zt(w.first.point,s).point,T=Zt(w.last.point,s).point;if(i&&!n){var A=Qt(e.writingMode,k,T,d);if(A)return A}g=[w.first];for(var M=e.glyphStartIndex+1;M<x-1;M++)g.push(re(v*l.getoffsetX(M),m,y,n,h,f,e.segment,b,_,c,o,p,!1));g.push(w.last)}else{if(i&&!n){var S=Zt(f,a).point,E=e.lineStartIndex+e.segment+1,C=new t.Point(c.getx(E),c.gety(E)),L=Zt(C,a),P=L.signedDistanceFromCamera>0?L.point:ee(f,C,S,1,a),O=Qt(e.writingMode,S,P,d);if(O)return O}var z=re(v*l.getoffsetX(e.glyphStartIndex),m,y,n,h,f,e.segment,e.lineStartIndex,e.lineStartIndex+e.lineLength,c,o,p,!1);if(!z)return{notEnoughRoom:!0};g=[z]}for(var I=0,D=g;I<D.length;I+=1){var R=D[I];t.addDynamicAttributes(u,R.point,R.angle)}return{}}function ee(t,e,r,n,i){var a=Zt(t.add(t.sub(e)._unit()),i).point,o=r.sub(a);return r.add(o._mult(n/o.mag()))}function re(e,r,n,i,a,o,s,l,c,u,h,f,p){var d=i?e-r:e+r,g=d>0?1:-1,v=0;i&&(g*=-1,v=Math.PI),g<0&&(v+=Math.PI);for(var m=g>0?l+s:l+s+1,y=m,x=a,b=a,_=0,w=0,k=Math.abs(d);_+w<=k;){if((m+=g)<l||m>=c)return null;if(b=x,void 0===(x=f[m])){var T=new t.Point(u.getx(m),u.gety(m)),A=Zt(T,h);if(A.signedDistanceFromCamera>0)x=f[m]=A.point;else{var M=m-g;x=ee(0===_?o:new t.Point(u.getx(M),u.gety(M)),T,b,k-_+1,h)}}_+=w,w=b.dist(x)}var S=(k-_)/w,E=x.sub(b),C=E.mult(S)._add(b);return C._add(E._unit()._perp()._mult(n*g)),{point:C,angle:v+Math.atan2(x.y-b.y,x.x-b.x),tileDistance:p?{prevTileDistance:m-g===y?0:u.gettileUnitDistanceFromAnchor(m-g),lastSegmentViewportDistance:k-_}:null}}Yt.prototype.keysLength=function(){return this.boxKeys.length+this.circleKeys.length},Yt.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertBoxCell,this.boxUid++),this.boxKeys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},Yt.prototype.insertCircle=function(t,e,r,n){this._forEachCell(e-n,r-n,e+n,r+n,this._insertCircleCell,this.circleUid++),this.circleKeys.push(t),this.circles.push(e),this.circles.push(r),this.circles.push(n)},Yt.prototype._insertBoxCell=function(t,e,r,n,i,a){this.boxCells[i].push(a)},Yt.prototype._insertCircleCell=function(t,e,r,n,i,a){this.circleCells[i].push(a)},Yt.prototype._query=function(t,e,r,n,i,a){if(r<0||t>this.width||n<0||e>this.height)return!i&&[];var o=[];if(t<=0&&e<=0&&this.width<=r&&this.height<=n){if(i)return!0;for(var s=0;s<this.boxKeys.length;s++)o.push({key:this.boxKeys[s],x1:this.bboxes[4*s],y1:this.bboxes[4*s+1],x2:this.bboxes[4*s+2],y2:this.bboxes[4*s+3]});for(var l=0;l<this.circleKeys.length;l++){var c=this.circles[3*l],u=this.circles[3*l+1],h=this.circles[3*l+2];o.push({key:this.circleKeys[l],x1:c-h,y1:u-h,x2:c+h,y2:u+h})}return a?o.filter(a):o}var f={hitTest:i,seenUids:{box:{},circle:{}}};return this._forEachCell(t,e,r,n,this._queryCell,o,f,a),i?o.length>0:o},Yt.prototype._queryCircle=function(t,e,r,n,i){var a=t-r,o=t+r,s=e-r,l=e+r;if(o<0||a>this.width||l<0||s>this.height)return!n&&[];var c=[],u={hitTest:n,circle:{x:t,y:e,radius:r},seenUids:{box:{},circle:{}}};return this._forEachCell(a,s,o,l,this._queryCellCircle,c,u,i),n?c.length>0:c},Yt.prototype.query=function(t,e,r,n,i){return this._query(t,e,r,n,!1,i)},Yt.prototype.hitTest=function(t,e,r,n,i){return this._query(t,e,r,n,!0,i)},Yt.prototype.hitTestCircle=function(t,e,r,n){return this._queryCircle(t,e,r,!0,n)},Yt.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=o.seenUids,c=this.boxCells[i];if(null!==c)for(var u=this.bboxes,h=0,f=c;h<f.length;h+=1){var p=f[h];if(!l.box[p]){l.box[p]=!0;var d=4*p;if(t<=u[d+2]&&e<=u[d+3]&&r>=u[d+0]&&n>=u[d+1]&&(!s||s(this.boxKeys[p]))){if(o.hitTest)return a.push(!0),!0;a.push({key:this.boxKeys[p],x1:u[d],y1:u[d+1],x2:u[d+2],y2:u[d+3]})}}}var g=this.circleCells[i];if(null!==g)for(var v=this.circles,m=0,y=g;m<y.length;m+=1){var x=y[m];if(!l.circle[x]){l.circle[x]=!0;var b=3*x;if(this._circleAndRectCollide(v[b],v[b+1],v[b+2],t,e,r,n)&&(!s||s(this.circleKeys[x]))){if(o.hitTest)return a.push(!0),!0;var _=v[b],w=v[b+1],k=v[b+2];a.push({key:this.circleKeys[x],x1:_-k,y1:w-k,x2:_+k,y2:w+k})}}}},Yt.prototype._queryCellCircle=function(t,e,r,n,i,a,o,s){var l=o.circle,c=o.seenUids,u=this.boxCells[i];if(null!==u)for(var h=this.bboxes,f=0,p=u;f<p.length;f+=1){var d=p[f];if(!c.box[d]){c.box[d]=!0;var g=4*d;if(this._circleAndRectCollide(l.x,l.y,l.radius,h[g+0],h[g+1],h[g+2],h[g+3])&&(!s||s(this.boxKeys[d])))return a.push(!0),!0}}var v=this.circleCells[i];if(null!==v)for(var m=this.circles,y=0,x=v;y<x.length;y+=1){var b=x[y];if(!c.circle[b]){c.circle[b]=!0;var _=3*b;if(this._circlesCollide(m[_],m[_+1],m[_+2],l.x,l.y,l.radius)&&(!s||s(this.circleKeys[b])))return a.push(!0),!0}}},Yt.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToXCellCoord(t),c=this._convertToYCellCoord(e),u=this._convertToXCellCoord(r),h=this._convertToYCellCoord(n),f=l;f<=u;f++)for(var p=c;p<=h;p++){var d=this.xCellCount*p+f;if(i.call(this,t,e,r,n,d,a,o,s))return}},Yt.prototype._convertToXCellCoord=function(t){return Math.max(0,Math.min(this.xCellCount-1,Math.floor(t*this.xScale)))},Yt.prototype._convertToYCellCoord=function(t){return Math.max(0,Math.min(this.yCellCount-1,Math.floor(t*this.yScale)))},Yt.prototype._circlesCollide=function(t,e,r,n,i,a){var o=n-t,s=i-e,l=r+a;return l*l>o*o+s*s},Yt.prototype._circleAndRectCollide=function(t,e,r,n,i,a,o){var s=(a-n)/2,l=Math.abs(t-(n+s));if(l>s+r)return!1;var c=(o-i)/2,u=Math.abs(e-(i+c));if(u>c+r)return!1;if(l<=s||u<=c)return!0;var h=l-s,f=u-c;return h*h+f*f<=r*r};var ne=new Float32Array([-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0]);function ie(t,e){for(var r=0;r<t;r++){var n=e.length;e.resize(n+4),e.float32.set(ne,3*n)}}function ae(t,e,r){var n=e[0],i=e[1];return t[0]=r[0]*n+r[4]*i+r[12],t[1]=r[1]*n+r[5]*i+r[13],t[3]=r[3]*n+r[7]*i+r[15],t}var oe=function(t,e,r){void 0===e&&(e=new Yt(t.width+200,t.height+200,25)),void 0===r&&(r=new Yt(t.width+200,t.height+200,25)),this.transform=t,this.grid=e,this.ignoredGrid=r,this.pitchfactor=Math.cos(t._pitch)*t.cameraToCenterDistance,this.screenRightBoundary=t.width+100,this.screenBottomBoundary=t.height+100,this.gridRightBoundary=t.width+200,this.gridBottomBoundary=t.height+200};function se(t,e,r){t[e+4]=r?1:0}function le(e,r,n){return r*(t.EXTENT/(e.tileSize*Math.pow(2,n-e.tileID.overscaledZ)))}oe.prototype.placeCollisionBox=function(t,e,r,n,i){var a=this.projectAndGetPerspectiveRatio(n,t.anchorPointX,t.anchorPointY),o=r*a.perspectiveRatio,s=t.x1*o+a.point.x,l=t.y1*o+a.point.y,c=t.x2*o+a.point.x,u=t.y2*o+a.point.y;return!this.isInsideGrid(s,l,c,u)||!e&&this.grid.hitTest(s,l,c,u,i)?{box:[],offscreen:!1}:{box:[s,l,c,u],offscreen:this.isOffscreen(s,l,c,u)}},oe.prototype.approximateTileDistance=function(t,e,r,n,i){var a=i?1:n/this.pitchfactor,o=t.lastSegmentViewportDistance*r;return t.prevTileDistance+o+(a-1)*o*Math.abs(Math.sin(e))},oe.prototype.placeCollisionCircles=function(e,r,n,i,a,o,s,l,c,u,h,f,p){var d=[],g=this.projectAnchor(c,a.anchorX,a.anchorY),v=l/24,m=a.lineOffsetX*l,y=a.lineOffsetY*l,x=new t.Point(a.anchorX,a.anchorY),b=$t(v,s,m,y,!1,Zt(x,u).point,x,a,o,u,{},!0),_=!1,w=!1,k=!0,T=g.perspectiveRatio*i,A=1/(i*n),M=0,S=0;b&&(M=this.approximateTileDistance(b.first.tileDistance,b.first.angle,A,g.cameraDistance,f),S=this.approximateTileDistance(b.last.tileDistance,b.last.angle,A,g.cameraDistance,f));for(var E=0;E<e.length;E+=5){var C=e[E],L=e[E+1],P=e[E+2],O=e[E+3];if(!b||O<-M||O>S)se(e,E,!1);else{var z=this.projectPoint(c,C,L),I=P*T;if(d.length>0){var D=z.x-d[d.length-4],R=z.y-d[d.length-3];if(I*I*2>D*D+R*R&&E+8<e.length){var F=e[E+8];if(F>-M&&F<S){se(e,E,!1);continue}}}var B=E/5;d.push(z.x,z.y,I,B),se(e,E,!0);var N=z.x-I,j=z.y-I,U=z.x+I,V=z.y+I;if(k=k&&this.isOffscreen(N,j,U,V),w=w||this.isInsideGrid(N,j,U,V),!r&&this.grid.hitTestCircle(z.x,z.y,I,p)){if(!h)return{circles:[],offscreen:!1};_=!0}}}return{circles:_||!w?[]:d,offscreen:k}},oe.prototype.queryRenderedSymbols=function(e){if(0===e.length||0===this.grid.keysLength()&&0===this.ignoredGrid.keysLength())return{};for(var r=[],n=1/0,i=1/0,a=-1/0,o=-1/0,s=0,l=e;s<l.length;s+=1){var c=l[s],u=new t.Point(c.x+100,c.y+100);n=Math.min(n,u.x),i=Math.min(i,u.y),a=Math.max(a,u.x),o=Math.max(o,u.y),r.push(u)}for(var h={},f={},p=0,d=this.grid.query(n,i,a,o).concat(this.ignoredGrid.query(n,i,a,o));p<d.length;p+=1){var g=d[p],v=g.key;if(void 0===h[v.bucketInstanceId]&&(h[v.bucketInstanceId]={}),!h[v.bucketInstanceId][v.featureIndex]){var m=[new t.Point(g.x1,g.y1),new t.Point(g.x2,g.y1),new t.Point(g.x2,g.y2),new t.Point(g.x1,g.y2)];t.polygonIntersectsPolygon(r,m)&&(h[v.bucketInstanceId][v.featureIndex]=!0,void 0===f[v.bucketInstanceId]&&(f[v.bucketInstanceId]=[]),f[v.bucketInstanceId].push(v.featureIndex))}}return f},oe.prototype.insertCollisionBox=function(t,e,r,n,i){var a={bucketInstanceId:r,featureIndex:n,collisionGroupID:i};(e?this.ignoredGrid:this.grid).insert(a,t[0],t[1],t[2],t[3])},oe.prototype.insertCollisionCircles=function(t,e,r,n,i){for(var a=e?this.ignoredGrid:this.grid,o={bucketInstanceId:r,featureIndex:n,collisionGroupID:i},s=0;s<t.length;s+=4)a.insertCircle(o,t[s],t[s+1],t[s+2])},oe.prototype.projectAnchor=function(t,e,r){var n=[e,r,0,1];return ae(n,n,t),{perspectiveRatio:.5+this.transform.cameraToCenterDistance/n[3]*.5,cameraDistance:n[3]}},oe.prototype.projectPoint=function(e,r,n){var i=[r,n,0,1];return ae(i,i,e),new t.Point((i[0]/i[3]+1)/2*this.transform.width+100,(-i[1]/i[3]+1)/2*this.transform.height+100)},oe.prototype.projectAndGetPerspectiveRatio=function(e,r,n){var i=[r,n,0,1];return ae(i,i,e),{point:new t.Point((i[0]/i[3]+1)/2*this.transform.width+100,(-i[1]/i[3]+1)/2*this.transform.height+100),perspectiveRatio:.5+this.transform.cameraToCenterDistance/i[3]*.5}},oe.prototype.isOffscreen=function(t,e,r,n){return r<100||t>=this.screenRightBoundary||n<100||e>this.screenBottomBoundary},oe.prototype.isInsideGrid=function(t,e,r,n){return r>=0&&t<this.gridRightBoundary&&n>=0&&e<this.gridBottomBoundary};var ce=function(t,e,r,n){this.opacity=t?Math.max(0,Math.min(1,t.opacity+(t.placed?e:-e))):n&&r?1:0,this.placed=r};ce.prototype.isHidden=function(){return 0===this.opacity&&!this.placed};var ue=function(t,e,r,n,i){this.text=new ce(t?t.text:null,e,r,i),this.icon=new ce(t?t.icon:null,e,n,i)};ue.prototype.isHidden=function(){return this.text.isHidden()&&this.icon.isHidden()};var he=function(t,e,r){this.text=t,this.icon=e,this.skipFade=r},fe=function(t,e,r,n,i){this.bucketInstanceId=t,this.featureIndex=e,this.sourceLayerIndex=r,this.bucketIndex=n,this.tileID=i},pe=function(t){this.crossSourceCollisions=t,this.maxGroupID=0,this.collisionGroups={}};function de(e,r,n,i,a){var o=t.getAnchorAlignment(e),s=-(o.horizontalAlign-.5)*r,l=-(o.verticalAlign-.5)*n,c=t.evaluateRadialOffset(e,i);return new t.Point(s+c[0]*a,l+c[1]*a)}pe.prototype.get=function(t){if(this.crossSourceCollisions)return{ID:0,predicate:null};if(!this.collisionGroups[t]){var e=++this.maxGroupID;this.collisionGroups[t]={ID:e,predicate:function(t){return t.collisionGroupID===e}}}return this.collisionGroups[t]};var ge=function(t,e,r,n){this.transform=t.clone(),this.collisionIndex=new oe(this.transform),this.placements={},this.opacities={},this.variableOffsets={},this.stale=!1,this.commitTime=0,this.fadeDuration=e,this.retainedQueryData={},this.collisionGroups=new pe(r),this.prevPlacement=n,n&&(n.prevPlacement=void 0)};function ve(t,e,r,n,i){t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0)}ge.prototype.placeLayerTile=function(e,r,n,i){var a=r.getBucket(e),o=r.latestFeatureIndex;if(a&&o&&e.id===a.layerIds[0]){var s=r.collisionBoxArray,l=a.layers[0].layout,c=Math.pow(2,this.transform.zoom-r.tileID.overscaledZ),u=r.tileSize/t.EXTENT,h=this.transform.calculatePosMatrix(r.tileID.toUnwrapped()),f=Wt(h,\"map\"===l.get(\"text-pitch-alignment\"),\"map\"===l.get(\"text-rotation-alignment\"),this.transform,le(r,1,this.transform.zoom)),p=Wt(h,\"map\"===l.get(\"icon-pitch-alignment\"),\"map\"===l.get(\"icon-rotation-alignment\"),this.transform,le(r,1,this.transform.zoom));this.retainedQueryData[a.bucketInstanceId]=new fe(a.bucketInstanceId,o,a.sourceLayerIndex,a.index,r.tileID),this.placeLayerBucket(a,h,f,p,c,u,n,r.holdingForFade(),i,s)}},ge.prototype.attemptAnchorPlacement=function(e,r,n,i,a,o,s,l,c,u,h,f,p,d){var g,v=de(e,n,i,a,o),m=this.collisionIndex.placeCollisionBox(function(e,r,n,i,a,o){var s=e.x1,l=e.x2,c=e.y1,u=e.y2,h=e.anchorPointX,f=e.anchorPointY,p=new t.Point(r,n);return i&&p._rotate(a?o:-o),{x1:s+p.x,y1:c+p.y,x2:l+p.x,y2:u+p.y,anchorPointX:h,anchorPointY:f}}(r,v.x,v.y,s,l,this.transform.angle),f,c,u,h.predicate);if(m.box.length>0)return this.prevPlacement&&this.prevPlacement.variableOffsets[p.crossTileID]&&this.prevPlacement.placements[p.crossTileID]&&this.prevPlacement.placements[p.crossTileID].text&&(g=this.prevPlacement.variableOffsets[p.crossTileID].anchor),this.variableOffsets[p.crossTileID]={radialOffset:a,width:n,height:i,anchor:e,textBoxScale:o,prevAnchor:g},this.markUsedJustification(d,e,p),m},ge.prototype.placeLayerBucket=function(e,r,n,i,a,o,s,l,c,u){var h=this,f=e.layers[0].layout,p=t.evaluateSizeForZoom(e.textSizeData,this.transform.zoom),d=f.get(\"text-optional\"),g=f.get(\"icon-optional\"),v=f.get(\"text-allow-overlap\"),m=f.get(\"icon-allow-overlap\"),y=v&&(m||!e.hasIconData()||g),x=m&&(v||!e.hasTextData()||d),b=this.collisionGroups.get(e.sourceID),_=\"map\"===f.get(\"text-rotation-alignment\"),w=\"map\"===f.get(\"text-pitch-alignment\"),k=\"viewport-y\"===f.get(\"symbol-z-order\");!e.collisionArrays&&u&&e.deserializeCollisionBoxes(u);var T=function(i,u){if(!c[i.crossTileID])if(l)h.placements[i.crossTileID]=new he(!1,!1,!1);else{var m=!1,k=!1,T=!0,A=null,M=null,S=null,E=0,C=0;u.textFeatureIndex&&(E=u.textFeatureIndex);var L=u.textBox;if(L)if(f.get(\"text-variable-anchor\")){var P=L.x2-L.x1,O=L.y2-L.y1,z=i.textBoxScale,I=f.get(\"text-variable-anchor\");if(h.prevPlacement&&h.prevPlacement.variableOffsets[i.crossTileID]){var D=h.prevPlacement.variableOffsets[i.crossTileID];I[0]!==D.anchor&&(I=I.filter(function(t){return t!==D.anchor})).unshift(D.anchor)}for(var R=0,F=I;R<F.length;R+=1){var B=F[R];if(A=h.attemptAnchorPlacement(B,L,P,O,i.radialTextOffset,z,_,w,o,r,b,v,i,e)){m=!0;break}}if(!h.variableOffsets[i.crossTileID]&&h.prevPlacement){var N=h.prevPlacement.variableOffsets[i.crossTileID];N&&(h.variableOffsets[i.crossTileID]=N,h.markUsedJustification(e,N.anchor,i))}}else m=(A=h.collisionIndex.placeCollisionBox(L,f.get(\"text-allow-overlap\"),o,r,b.predicate)).box.length>0;T=A&&A.offscreen;var j=u.textCircles;if(j){var U=e.text.placedSymbolArray.get(i.centerJustifiedTextSymbolIndex),V=t.evaluateSizeForFeature(e.textSizeData,p,U);M=h.collisionIndex.placeCollisionCircles(j,f.get(\"text-allow-overlap\"),a,o,U,e.lineVertexArray,e.glyphOffsetArray,V,r,n,s,w,b.predicate),m=f.get(\"text-allow-overlap\")||M.circles.length>0,T=T&&M.offscreen}u.iconFeatureIndex&&(C=u.iconFeatureIndex),u.iconBox&&(k=(S=h.collisionIndex.placeCollisionBox(u.iconBox,f.get(\"icon-allow-overlap\"),o,r,b.predicate)).box.length>0,T=T&&S.offscreen);var q=d||0===i.numHorizontalGlyphVertices&&0===i.numVerticalGlyphVertices,H=g||0===i.numIconVertices;q||H?H?q||(k=k&&m):m=k&&m:k=m=k&&m,m&&A&&h.collisionIndex.insertCollisionBox(A.box,f.get(\"text-ignore-placement\"),e.bucketInstanceId,E,b.ID),k&&S&&h.collisionIndex.insertCollisionBox(S.box,f.get(\"icon-ignore-placement\"),e.bucketInstanceId,C,b.ID),m&&M&&h.collisionIndex.insertCollisionCircles(M.circles,f.get(\"text-ignore-placement\"),e.bucketInstanceId,E,b.ID),h.placements[i.crossTileID]=new he(m||y,k||x,T||e.justReloaded),c[i.crossTileID]=!0}};if(k)for(var A=e.getSortedSymbolIndexes(this.transform.angle),M=A.length-1;M>=0;--M){var S=A[M];T(e.symbolInstances.get(S),e.collisionArrays[S])}else for(var E=0;E<e.symbolInstances.length;++E)T(e.symbolInstances.get(E),e.collisionArrays[E]);e.justReloaded=!1},ge.prototype.markUsedJustification=function(e,r,n){var i={left:n.leftJustifiedTextSymbolIndex,center:n.centerJustifiedTextSymbolIndex,right:n.rightJustifiedTextSymbolIndex},a=i[t.getAnchorJustification(r)];for(var o in i){var s=i[o];s>=0&&(e.text.placedSymbolArray.get(s).crossTileID=a>=0&&s!==a?0:n.crossTileID)}},ge.prototype.commit=function(t){this.commitTime=t;var e=this.prevPlacement,r=!1,n=e&&0!==this.fadeDuration?(this.commitTime-e.commitTime)/this.fadeDuration:1,i=e?e.opacities:{},a=e?e.variableOffsets:{};for(var o in this.placements){var s=this.placements[o],l=i[o];l?(this.opacities[o]=new ue(l,n,s.text,s.icon),r=r||s.text!==l.text.placed||s.icon!==l.icon.placed):(this.opacities[o]=new ue(null,n,s.text,s.icon,s.skipFade),r=r||s.text||s.icon)}for(var c in i){var u=i[c];if(!this.opacities[c]){var h=new ue(u,n,!1,!1);h.isHidden()||(this.opacities[c]=h,r=r||u.text.placed||u.icon.placed)}}for(var f in a)this.variableOffsets[f]||!this.opacities[f]||this.opacities[f].isHidden()||(this.variableOffsets[f]=a[f]);r?this.lastPlacementChangeTime=t:\"number\"!=typeof this.lastPlacementChangeTime&&(this.lastPlacementChangeTime=e?e.lastPlacementChangeTime:t)},ge.prototype.updateLayerOpacities=function(t,e){for(var r={},n=0,i=e;n<i.length;n+=1){var a=i[n],o=a.getBucket(t);o&&a.latestFeatureIndex&&t.id===o.layerIds[0]&&this.updateBucketOpacities(o,r,a.collisionBoxArray)}},ge.prototype.updateBucketOpacities=function(e,r,n){e.hasTextData()&&e.text.opacityVertexArray.clear(),e.hasIconData()&&e.icon.opacityVertexArray.clear(),e.hasCollisionBoxData()&&e.collisionBox.collisionVertexArray.clear(),e.hasCollisionCircleData()&&e.collisionCircle.collisionVertexArray.clear();var i=e.layers[0].layout,a=new ue(null,0,!1,!1,!0),o=i.get(\"text-allow-overlap\"),s=i.get(\"icon-allow-overlap\"),l=i.get(\"text-variable-anchor\"),c=\"map\"===i.get(\"text-rotation-alignment\"),u=\"map\"===i.get(\"text-pitch-alignment\"),h=new ue(null,0,o&&(s||!e.hasIconData()||i.get(\"icon-optional\")),s&&(o||!e.hasTextData()||i.get(\"text-optional\")),!0);!e.collisionArrays&&n&&(e.hasCollisionBoxData()||e.hasCollisionCircleData())&&e.deserializeCollisionBoxes(n);for(var f=0;f<e.symbolInstances.length;f++){var p=e.symbolInstances.get(f),d=p.numHorizontalGlyphVertices,g=p.numVerticalGlyphVertices,v=p.crossTileID,m=r[v],y=this.opacities[v];m?y=a:y||(y=h,this.opacities[v]=y),r[v]=!0;var x=d>0||g>0,b=p.numIconVertices>0;if(x){for(var _=Te(y.text),w=(d+g)/4,k=0;k<w;k++)e.text.opacityVertexArray.emplaceBack(_);var T=y.text.isHidden()?1:0;[p.rightJustifiedTextSymbolIndex,p.centerJustifiedTextSymbolIndex,p.leftJustifiedTextSymbolIndex,p.verticalPlacedTextSymbolIndex].forEach(function(t){t>=0&&(e.text.placedSymbolArray.get(t).hidden=T)});var A=this.variableOffsets[p.crossTileID];A&&this.markUsedJustification(e,A.anchor,p)}if(b){for(var M=Te(y.icon),S=0;S<p.numIconVertices/4;S++)e.icon.opacityVertexArray.emplaceBack(M);e.icon.placedSymbolArray.get(f).hidden=y.icon.isHidden()}if(e.hasCollisionBoxData()||e.hasCollisionCircleData()){var E=e.collisionArrays[f];if(E){if(E.textBox){var C=new t.Point(0,0),L=!0;if(l){var P=this.variableOffsets[v];P?(C=de(P.anchor,P.width,P.height,P.radialOffset,P.textBoxScale),c&&C._rotate(u?this.transform.angle:-this.transform.angle)):L=!1}ve(e.collisionBox.collisionVertexArray,y.text.placed,!L,C.x,C.y)}E.iconBox&&ve(e.collisionBox.collisionVertexArray,y.icon.placed,!1);var O=E.textCircles;if(O&&e.hasCollisionCircleData())for(var z=0;z<O.length;z+=5){var I=m||0===O[z+4];ve(e.collisionCircle.collisionVertexArray,y.text.placed,I)}}}}e.sortFeatures(this.transform.angle),this.retainedQueryData[e.bucketInstanceId]&&(this.retainedQueryData[e.bucketInstanceId].featureSortOrder=e.featureSortOrder),e.hasTextData()&&e.text.opacityVertexBuffer&&e.text.opacityVertexBuffer.updateData(e.text.opacityVertexArray),e.hasIconData()&&e.icon.opacityVertexBuffer&&e.icon.opacityVertexBuffer.updateData(e.icon.opacityVertexArray),e.hasCollisionBoxData()&&e.collisionBox.collisionVertexBuffer&&e.collisionBox.collisionVertexBuffer.updateData(e.collisionBox.collisionVertexArray),e.hasCollisionCircleData()&&e.collisionCircle.collisionVertexBuffer&&e.collisionCircle.collisionVertexBuffer.updateData(e.collisionCircle.collisionVertexArray)},ge.prototype.symbolFadeChange=function(t){return 0===this.fadeDuration?1:(t-this.commitTime)/this.fadeDuration},ge.prototype.hasTransitions=function(t){return this.stale||t-this.lastPlacementChangeTime<this.fadeDuration},ge.prototype.stillRecent=function(t){return this.commitTime+this.fadeDuration>t},ge.prototype.setStale=function(){this.stale=!0};var me=Math.pow(2,25),ye=Math.pow(2,24),xe=Math.pow(2,17),be=Math.pow(2,16),_e=Math.pow(2,9),we=Math.pow(2,8),ke=Math.pow(2,1);function Te(t){if(0===t.opacity&&!t.placed)return 0;if(1===t.opacity&&t.placed)return 4294967295;var e=t.placed?1:0,r=Math.floor(127*t.opacity);return r*me+e*ye+r*xe+e*be+r*_e+e*we+r*ke+e}var Ae=function(){this._currentTileIndex=0,this._seenCrossTileIDs={}};Ae.prototype.continuePlacement=function(t,e,r,n,i){for(;this._currentTileIndex<t.length;){var a=t[this._currentTileIndex];if(e.placeLayerTile(n,a,r,this._seenCrossTileIDs),this._currentTileIndex++,i())return!0}};var Me=function(t,e,r,n,i,a,o){this.placement=new ge(t,i,a,o),this._currentPlacementIndex=e.length-1,this._forceFullPlacement=r,this._showCollisionBoxes=n,this._done=!1};Me.prototype.isDone=function(){return this._done},Me.prototype.continuePlacement=function(e,r,n){for(var i=this,a=t.browser.now(),o=function(){var e=t.browser.now()-a;return!i._forceFullPlacement&&e>2};this._currentPlacementIndex>=0;){var s=r[e[this._currentPlacementIndex]],l=this.placement.collisionIndex.transform.zoom;if(\"symbol\"===s.type&&(!s.minzoom||s.minzoom<=l)&&(!s.maxzoom||s.maxzoom>l)){if(this._inProgressLayer||(this._inProgressLayer=new Ae),this._inProgressLayer.continuePlacement(n[s.source],this.placement,this._showCollisionBoxes,s,o))return;delete this._inProgressLayer}this._currentPlacementIndex--}this._done=!0},Me.prototype.commit=function(t){return this.placement.commit(t),this.placement};var Se=512/t.EXTENT/2,Ee=function(t,e,r){this.tileID=t,this.indexedSymbolInstances={},this.bucketInstanceId=r;for(var n=0;n<e.length;n++){var i=e.get(n),a=i.key;this.indexedSymbolInstances[a]||(this.indexedSymbolInstances[a]=[]),this.indexedSymbolInstances[a].push({crossTileID:i.crossTileID,coord:this.getScaledCoordinates(i,t)})}};Ee.prototype.getScaledCoordinates=function(e,r){var n=r.canonical.z-this.tileID.canonical.z,i=Se/Math.pow(2,n);return{x:Math.floor((r.canonical.x*t.EXTENT+e.anchorX)*i),y:Math.floor((r.canonical.y*t.EXTENT+e.anchorY)*i)}},Ee.prototype.findMatches=function(t,e,r){for(var n=this.tileID.canonical.z<e.canonical.z?1:Math.pow(2,this.tileID.canonical.z-e.canonical.z),i=0;i<t.length;i++){var a=t.get(i);if(!a.crossTileID){var o=this.indexedSymbolInstances[a.key];if(o)for(var s=this.getScaledCoordinates(a,e),l=0,c=o;l<c.length;l+=1){var u=c[l];if(Math.abs(u.coord.x-s.x)<=n&&Math.abs(u.coord.y-s.y)<=n&&!r[u.crossTileID]){r[u.crossTileID]=!0,a.crossTileID=u.crossTileID;break}}}}};var Ce=function(){this.maxCrossTileID=0};Ce.prototype.generate=function(){return++this.maxCrossTileID};var Le=function(){this.indexes={},this.usedCrossTileIDs={},this.lng=0};Le.prototype.handleWrapJump=function(t){var e=Math.round((t-this.lng)/360);if(0!==e)for(var r in this.indexes){var n=this.indexes[r],i={};for(var a in n){var o=n[a];o.tileID=o.tileID.unwrapTo(o.tileID.wrap+e),i[o.tileID.key]=o}this.indexes[r]=i}this.lng=t},Le.prototype.addBucket=function(t,e,r){if(this.indexes[t.overscaledZ]&&this.indexes[t.overscaledZ][t.key]){if(this.indexes[t.overscaledZ][t.key].bucketInstanceId===e.bucketInstanceId)return!1;this.removeBucketCrossTileIDs(t.overscaledZ,this.indexes[t.overscaledZ][t.key])}for(var n=0;n<e.symbolInstances.length;n++)e.symbolInstances.get(n).crossTileID=0;this.usedCrossTileIDs[t.overscaledZ]||(this.usedCrossTileIDs[t.overscaledZ]={});var i=this.usedCrossTileIDs[t.overscaledZ];for(var a in this.indexes){var o=this.indexes[a];if(Number(a)>t.overscaledZ)for(var s in o){var l=o[s];l.tileID.isChildOf(t)&&l.findMatches(e.symbolInstances,t,i)}else{var c=o[t.scaledTo(Number(a)).key];c&&c.findMatches(e.symbolInstances,t,i)}}for(var u=0;u<e.symbolInstances.length;u++){var h=e.symbolInstances.get(u);h.crossTileID||(h.crossTileID=r.generate(),i[h.crossTileID]=!0)}return void 0===this.indexes[t.overscaledZ]&&(this.indexes[t.overscaledZ]={}),this.indexes[t.overscaledZ][t.key]=new Ee(t,e.symbolInstances,e.bucketInstanceId),!0},Le.prototype.removeBucketCrossTileIDs=function(t,e){for(var r in e.indexedSymbolInstances)for(var n=0,i=e.indexedSymbolInstances[r];n<i.length;n+=1){var a=i[n];delete this.usedCrossTileIDs[t][a.crossTileID]}},Le.prototype.removeStaleBuckets=function(t){var e=!1;for(var r in this.indexes){var n=this.indexes[r];for(var i in n)t[n[i].bucketInstanceId]||(this.removeBucketCrossTileIDs(r,n[i]),delete n[i],e=!0)}return e};var Pe=function(){this.layerIndexes={},this.crossTileIDs=new Ce,this.maxBucketInstanceId=0,this.bucketsInCurrentPlacement={}};Pe.prototype.addLayer=function(t,e,r){var n=this.layerIndexes[t.id];void 0===n&&(n=this.layerIndexes[t.id]=new Le);var i=!1,a={};n.handleWrapJump(r);for(var o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.getBucket(t);c&&t.id===c.layerIds[0]&&(c.bucketInstanceId||(c.bucketInstanceId=++this.maxBucketInstanceId),n.addBucket(l.tileID,c,this.crossTileIDs)&&(i=!0),a[c.bucketInstanceId]=!0)}return n.removeStaleBuckets(a)&&(i=!0),i},Pe.prototype.pruneUnusedLayers=function(t){var e={};for(var r in t.forEach(function(t){e[t]=!0}),this.layerIndexes)e[r]||delete this.layerIndexes[r]};var Oe=function(e,r){return t.emitValidationErrors(e,r&&r.filter(function(t){return\"source.canvas\"!==t.identifier}))},ze=t.pick(Bt,[\"addLayer\",\"removeLayer\",\"setPaintProperty\",\"setLayoutProperty\",\"setFilter\",\"addSource\",\"removeSource\",\"setLayerZoomRange\",\"setLight\",\"setTransition\",\"setGeoJSONSourceData\"]),Ie=t.pick(Bt,[\"setCenter\",\"setZoom\",\"setBearing\",\"setPitch\"]),De=function(e){function r(n,i){var a=this;void 0===i&&(i={}),e.call(this),this.map=n,this.dispatcher=new k((It||(It=new zt),It),this),this.imageManager=new f,this.imageManager.setEventedParent(this),this.glyphManager=new y(n._requestManager,i.localIdeographFontFamily),this.lineAtlas=new w(256,512),this.crossTileSymbolIndex=new Pe,this._layers={},this._order=[],this.sourceCaches={},this.zoomHistory=new t.ZoomHistory,this._loaded=!1,this._resetUpdates(),this.dispatcher.broadcast(\"setReferrer\",t.getReferrer());var o=this;this._rtlTextPluginCallback=r.registerForPluginAvailability(function(t){for(var e in o.dispatcher.broadcast(\"loadRTLTextPlugin\",t.pluginURL,t.completionCallback),o.sourceCaches)o.sourceCaches[e].reload()}),this.on(\"data\",function(t){if(\"source\"===t.dataType&&\"metadata\"===t.sourceDataType){var e=a.sourceCaches[t.sourceId];if(e){var r=e.getSource();if(r&&r.vectorLayerIds)for(var n in a._layers){var i=a._layers[n];i.source===r.id&&a._validateLayer(i)}}}})}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadURL=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"}));var i=\"boolean\"==typeof r.validate?r.validate:!t.isMapboxURL(e);e=this.map._requestManager.normalizeStyleURL(e,r.accessToken);var a=this.map._requestManager.transformRequest(e,t.ResourceType.Style);this._request=t.getJSON(a,function(e,r){n._request=null,e?n.fire(new t.ErrorEvent(e)):r&&n._load(r,i)})},r.prototype.loadJSON=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"})),this._request=t.browser.frame(function(){n._request=null,n._load(e,!1!==r.validate)})},r.prototype._load=function(e,r){var n=this;if(!r||!Oe(this,t.validateStyle(e))){for(var i in this._loaded=!0,this.stylesheet=e,e.sources)this.addSource(i,e.sources[i],{validate:!1});e.sprite?this._spriteRequest=function(e,r,n){var i,a,o,s=t.browser.devicePixelRatio>1?\"@2x\":\"\",l=t.getJSON(r.transformRequest(r.normalizeSpriteURL(e,s,\".json\"),t.ResourceType.SpriteJSON),function(t,e){l=null,o||(o=t,i=e,u())}),c=t.getImage(r.transformRequest(r.normalizeSpriteURL(e,s,\".png\"),t.ResourceType.SpriteImage),function(t,e){c=null,o||(o=t,a=e,u())});function u(){if(o)n(o);else if(i&&a){var e=t.browser.getImageData(a),r={};for(var s in i){var l=i[s],c=l.width,u=l.height,h=l.x,f=l.y,p=l.sdf,d=l.pixelRatio,g=new t.RGBAImage({width:c,height:u});t.RGBAImage.copy(e,g,{x:h,y:f},{x:0,y:0},{width:c,height:u}),r[s]={data:g,pixelRatio:d,sdf:p}}n(null,r)}}return{cancel:function(){l&&(l.cancel(),l=null),c&&(c.cancel(),c=null)}}}(e.sprite,this.map._requestManager,function(e,r){if(n._spriteRequest=null,e)n.fire(new t.ErrorEvent(e));else if(r)for(var i in r)n.imageManager.addImage(i,r[i]);n.imageManager.setLoaded(!0),n.fire(new t.Event(\"data\",{dataType:\"style\"}))}):this.imageManager.setLoaded(!0),this.glyphManager.setURL(e.glyphs);var a=Ft(this.stylesheet.layers);this._order=a.map(function(t){return t.id}),this._layers={};for(var o=0,s=a;o<s.length;o+=1){var l=s[o];(l=t.createStyleLayer(l)).setEventedParent(this,{layer:{id:l.id}}),this._layers[l.id]=l}this.dispatcher.broadcast(\"setLayers\",this._serializeLayers(this._order)),this.light=new _(this.stylesheet.light),this.fire(new t.Event(\"data\",{dataType:\"style\"})),this.fire(new t.Event(\"style.load\"))}},r.prototype._validateLayer=function(e){var r=this.sourceCaches[e.source];if(r){var n=e.sourceLayer;if(n){var i=r.getSource();(\"geojson\"===i.type||i.vectorLayerIds&&-1===i.vectorLayerIds.indexOf(n))&&this.fire(new t.ErrorEvent(new Error('Source layer \"'+n+'\" does not exist on source \"'+i.id+'\" as specified by style layer \"'+e.id+'\"')))}}},r.prototype.loaded=function(){if(!this._loaded)return!1;if(Object.keys(this._updatedSources).length)return!1;for(var t in this.sourceCaches)if(!this.sourceCaches[t].loaded())return!1;return!!this.imageManager.isLoaded()},r.prototype._serializeLayers=function(t){for(var e=[],r=0,n=t;r<n.length;r+=1){var i=n[r],a=this._layers[i];\"custom\"!==a.type&&e.push(a.serialize())}return e},r.prototype.hasTransitions=function(){if(this.light&&this.light.hasTransition())return!0;for(var t in this.sourceCaches)if(this.sourceCaches[t].hasTransition())return!0;for(var e in this._layers)if(this._layers[e].hasTransition())return!0;return!1},r.prototype._checkLoaded=function(){if(!this._loaded)throw new Error(\"Style is not done loading\")},r.prototype.update=function(e){if(this._loaded){var r=this._changed;if(this._changed){var n=Object.keys(this._updatedLayers),i=Object.keys(this._removedLayers);for(var a in(n.length||i.length)&&this._updateWorkerLayers(n,i),this._updatedSources){var o=this._updatedSources[a];\"reload\"===o?this._reloadSource(a):\"clear\"===o&&this._clearSource(a)}for(var s in this._updatedPaintProps)this._layers[s].updateTransitions(e);this.light.updateTransitions(e),this._resetUpdates()}for(var l in this.sourceCaches)this.sourceCaches[l].used=!1;for(var c=0,u=this._order;c<u.length;c+=1){var h=u[c],f=this._layers[h];f.recalculate(e),!f.isHidden(e.zoom)&&f.source&&(this.sourceCaches[f.source].used=!0)}this.light.recalculate(e),this.z=e.zoom,r&&this.fire(new t.Event(\"data\",{dataType:\"style\"}))}},r.prototype._updateWorkerLayers=function(t,e){this.dispatcher.broadcast(\"updateLayers\",{layers:this._serializeLayers(t),removedIds:e})},r.prototype._resetUpdates=function(){this._changed=!1,this._updatedLayers={},this._removedLayers={},this._updatedSources={},this._updatedPaintProps={}},r.prototype.setState=function(e){var r=this;if(this._checkLoaded(),Oe(this,t.validateStyle(e)))return!1;(e=t.clone$1(e)).layers=Ft(e.layers);var n=function(e,r){if(!e)return[{command:Bt.setStyle,args:[r]}];var n=[];try{if(!t.deepEqual(e.version,r.version))return[{command:Bt.setStyle,args:[r]}];t.deepEqual(e.center,r.center)||n.push({command:Bt.setCenter,args:[r.center]}),t.deepEqual(e.zoom,r.zoom)||n.push({command:Bt.setZoom,args:[r.zoom]}),t.deepEqual(e.bearing,r.bearing)||n.push({command:Bt.setBearing,args:[r.bearing]}),t.deepEqual(e.pitch,r.pitch)||n.push({command:Bt.setPitch,args:[r.pitch]}),t.deepEqual(e.sprite,r.sprite)||n.push({command:Bt.setSprite,args:[r.sprite]}),t.deepEqual(e.glyphs,r.glyphs)||n.push({command:Bt.setGlyphs,args:[r.glyphs]}),t.deepEqual(e.transition,r.transition)||n.push({command:Bt.setTransition,args:[r.transition]}),t.deepEqual(e.light,r.light)||n.push({command:Bt.setLight,args:[r.light]});var i={},a=[];!function(e,r,n,i){var a;for(a in r=r||{},e=e||{})e.hasOwnProperty(a)&&(r.hasOwnProperty(a)||jt(a,n,i));for(a in r)r.hasOwnProperty(a)&&(e.hasOwnProperty(a)?t.deepEqual(e[a],r[a])||(\"geojson\"===e[a].type&&\"geojson\"===r[a].type&&Vt(e,r,a)?n.push({command:Bt.setGeoJSONSourceData,args:[a,r[a].data]}):Ut(a,r,n,i)):Nt(a,r,n))}(e.sources,r.sources,a,i);var o=[];e.layers&&e.layers.forEach(function(t){i[t.source]?n.push({command:Bt.removeLayer,args:[t.id]}):o.push(t)}),n=n.concat(a),function(e,r,n){r=r||[];var i,a,o,s,l,c,u,h=(e=e||[]).map(Ht),f=r.map(Ht),p=e.reduce(Gt,{}),d=r.reduce(Gt,{}),g=h.slice(),v=Object.create(null);for(i=0,a=0;i<h.length;i++)o=h[i],d.hasOwnProperty(o)?a++:(n.push({command:Bt.removeLayer,args:[o]}),g.splice(g.indexOf(o,a),1));for(i=0,a=0;i<f.length;i++)o=f[f.length-1-i],g[g.length-1-i]!==o&&(p.hasOwnProperty(o)?(n.push({command:Bt.removeLayer,args:[o]}),g.splice(g.lastIndexOf(o,g.length-a),1)):a++,c=g[g.length-i],n.push({command:Bt.addLayer,args:[d[o],c]}),g.splice(g.length-i,0,o),v[o]=!0);for(i=0;i<f.length;i++)if(s=p[o=f[i]],l=d[o],!v[o]&&!t.deepEqual(s,l))if(t.deepEqual(s.source,l.source)&&t.deepEqual(s[\"source-layer\"],l[\"source-layer\"])&&t.deepEqual(s.type,l.type)){for(u in qt(s.layout,l.layout,n,o,null,Bt.setLayoutProperty),qt(s.paint,l.paint,n,o,null,Bt.setPaintProperty),t.deepEqual(s.filter,l.filter)||n.push({command:Bt.setFilter,args:[o,l.filter]}),t.deepEqual(s.minzoom,l.minzoom)&&t.deepEqual(s.maxzoom,l.maxzoom)||n.push({command:Bt.setLayerZoomRange,args:[o,l.minzoom,l.maxzoom]}),s)s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?qt(s[u],l[u],n,o,u.slice(6),Bt.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Bt.setLayerProperty,args:[o,u,l[u]]}));for(u in l)l.hasOwnProperty(u)&&!s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?qt(s[u],l[u],n,o,u.slice(6),Bt.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Bt.setLayerProperty,args:[o,u,l[u]]}))}else n.push({command:Bt.removeLayer,args:[o]}),c=g[g.lastIndexOf(o)+1],n.push({command:Bt.addLayer,args:[l,c]})}(o,r.layers,n)}catch(t){console.warn(\"Unable to compute style diff:\",t),n=[{command:Bt.setStyle,args:[r]}]}return n}(this.serialize(),e).filter(function(t){return!(t.command in Ie)});if(0===n.length)return!1;var i=n.filter(function(t){return!(t.command in ze)});if(i.length>0)throw new Error(\"Unimplemented: \"+i.map(function(t){return t.command}).join(\", \")+\".\");return n.forEach(function(t){\"setTransition\"!==t.command&&r[t.command].apply(r,t.args)}),this.stylesheet=e,!0},r.prototype.addImage=function(e,r){if(this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"An image with this name already exists.\")));this.imageManager.addImage(e,r),this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.updateImage=function(t,e){this.imageManager.updateImage(t,e)},r.prototype.getImage=function(t){return this.imageManager.getImage(t)},r.prototype.removeImage=function(e){if(!this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"No image with this name exists.\")));this.imageManager.removeImage(e),this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.listImages=function(){return this._checkLoaded(),this.imageManager.listImages()},r.prototype.addSource=function(e,r,n){var i=this;if(void 0===n&&(n={}),this._checkLoaded(),void 0!==this.sourceCaches[e])throw new Error(\"There is already a source with this ID\");if(!r.type)throw new Error(\"The type property must be defined, but the only the following properties were given: \"+Object.keys(r).join(\", \")+\".\");if(!([\"vector\",\"raster\",\"geojson\",\"video\",\"image\"].indexOf(r.type)>=0&&this._validate(t.validateStyle.source,\"sources.\"+e,r,null,n))){this.map&&this.map._collectResourceTiming&&(r.collectResourceTiming=!0);var a=this.sourceCaches[e]=new Ct(e,r,this.dispatcher);a.style=this,a.setEventedParent(this,function(){return{isSourceLoaded:i.loaded(),source:a.serialize(),sourceId:e}}),a.onAdd(this.map),this._changed=!0}},r.prototype.removeSource=function(e){if(this._checkLoaded(),void 0===this.sourceCaches[e])throw new Error(\"There is no source with this ID\");for(var r in this._layers)if(this._layers[r].source===e)return this.fire(new t.ErrorEvent(new Error('Source \"'+e+'\" cannot be removed while layer \"'+r+'\" is using it.')));var n=this.sourceCaches[e];delete this.sourceCaches[e],delete this._updatedSources[e],n.fire(new t.Event(\"data\",{sourceDataType:\"metadata\",dataType:\"source\",sourceId:e})),n.setEventedParent(null),n.clearTiles(),n.onRemove&&n.onRemove(this.map),this._changed=!0},r.prototype.setGeoJSONSourceData=function(t,e){this._checkLoaded(),this.sourceCaches[t].getSource().setData(e),this._changed=!0},r.prototype.getSource=function(t){return this.sourceCaches[t]&&this.sourceCaches[t].getSource()},r.prototype.addLayer=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=e.id;if(this.getLayer(i))this.fire(new t.ErrorEvent(new Error('Layer with id \"'+i+'\" already exists on this map')));else{var a;if(\"custom\"===e.type){if(Oe(this,t.validateCustomStyleLayer(e)))return;a=t.createStyleLayer(e)}else{if(\"object\"==typeof e.source&&(this.addSource(i,e.source),e=t.clone$1(e),e=t.extend(e,{source:i})),this._validate(t.validateStyle.layer,\"layers.\"+i,e,{arrayIndex:-1},n))return;a=t.createStyleLayer(e),this._validateLayer(a),a.setEventedParent(this,{layer:{id:i}})}var o=r?this._order.indexOf(r):this._order.length;if(r&&-1===o)this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.')));else{if(this._order.splice(o,0,i),this._layerOrderChanged=!0,this._layers[i]=a,this._removedLayers[i]&&a.source&&\"custom\"!==a.type){var s=this._removedLayers[i];delete this._removedLayers[i],s.type!==a.type?this._updatedSources[a.source]=\"clear\":(this._updatedSources[a.source]=\"reload\",this.sourceCaches[a.source].pause())}this._updateLayer(a),a.onAdd&&a.onAdd(this.map)}}},r.prototype.moveLayer=function(e,r){if(this._checkLoaded(),this._changed=!0,this._layers[e]){if(e!==r){var n=this._order.indexOf(e);this._order.splice(n,1);var i=r?this._order.indexOf(r):this._order.length;r&&-1===i?this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.'))):(this._order.splice(i,0,e),this._layerOrderChanged=!0)}}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be moved.\")))},r.prototype.removeLayer=function(e){this._checkLoaded();var r=this._layers[e];if(r){r.setEventedParent(null);var n=this._order.indexOf(e);this._order.splice(n,1),this._layerOrderChanged=!0,this._changed=!0,this._removedLayers[e]=r,delete this._layers[e],delete this._updatedLayers[e],delete this._updatedPaintProps[e],r.onRemove&&r.onRemove(this.map)}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be removed.\")))},r.prototype.getLayer=function(t){return this._layers[t]},r.prototype.setLayerZoomRange=function(e,r,n){this._checkLoaded();var i=this.getLayer(e);i?i.minzoom===r&&i.maxzoom===n||(null!=r&&(i.minzoom=r),null!=n&&(i.maxzoom=n),this._updateLayer(i)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot have zoom extent.\")))},r.prototype.setFilter=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=this.getLayer(e);if(i){if(!t.deepEqual(i.filter,r))return null==r?(i.filter=void 0,void this._updateLayer(i)):void(this._validate(t.validateStyle.filter,\"layers.\"+i.id+\".filter\",r,null,n)||(i.filter=t.clone$1(r),this._updateLayer(i)))}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be filtered.\")))},r.prototype.getFilter=function(e){return t.clone$1(this.getLayer(e).filter)},r.prototype.setLayoutProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getLayoutProperty(r),n)||(a.setLayoutProperty(r,n,i),this._updateLayer(a)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getLayoutProperty=function(e,r){var n=this.getLayer(e);if(n)return n.getLayoutProperty(r);this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style.\")))},r.prototype.setPaintProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getPaintProperty(r),n)||(a.setPaintProperty(r,n,i)&&this._updateLayer(a),this._changed=!0,this._updatedPaintProps[e]=!0):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getPaintProperty=function(t,e){return this.getLayer(t).getPaintProperty(e)},r.prototype.setFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=e.sourceLayer,a=this.sourceCaches[n],o=parseInt(e.id,10);if(void 0!==a){var s=a.getSource().type;\"geojson\"===s&&i?this.fire(new t.ErrorEvent(new Error(\"GeoJSON sources cannot have a sourceLayer parameter.\"))):\"vector\"!==s||i?isNaN(o)||o<0?this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided and non-negative.\"))):a.setFeatureState(i,o,r):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.removeFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=this.sourceCaches[n];if(void 0!==i){var a=i.getSource().type,o=\"vector\"===a?e.sourceLayer:void 0,s=parseInt(e.id,10);\"vector\"!==a||o?void 0!==e.id&&isNaN(s)||s<0?this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be non-negative.\"))):r&&\"string\"!=typeof e.id&&\"number\"!=typeof e.id?this.fire(new t.ErrorEvent(new Error(\"A feature id is requred to remove its specific state property.\"))):i.removeFeatureState(o,s,r):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.getFeatureState=function(e){this._checkLoaded();var r=e.source,n=e.sourceLayer,i=this.sourceCaches[r],a=parseInt(e.id,10);if(void 0!==i)if(\"vector\"!==i.getSource().type||n){if(!(isNaN(a)||a<0))return i.getFeatureState(n,a);this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided and non-negative.\")))}else this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")));else this.fire(new t.ErrorEvent(new Error(\"The source '\"+r+\"' does not exist in the map's style.\")))},r.prototype.getTransition=function(){return t.extend({duration:300,delay:0},this.stylesheet&&this.stylesheet.transition)},r.prototype.serialize=function(){return t.filterObject({version:this.stylesheet.version,name:this.stylesheet.name,metadata:this.stylesheet.metadata,light:this.stylesheet.light,center:this.stylesheet.center,zoom:this.stylesheet.zoom,bearing:this.stylesheet.bearing,pitch:this.stylesheet.pitch,sprite:this.stylesheet.sprite,glyphs:this.stylesheet.glyphs,transition:this.stylesheet.transition,sources:t.mapObject(this.sourceCaches,function(t){return t.serialize()}),layers:this._serializeLayers(this._order)},function(t){return void 0!==t})},r.prototype._updateLayer=function(t){this._updatedLayers[t.id]=!0,t.source&&!this._updatedSources[t.source]&&(this._updatedSources[t.source]=\"reload\",this.sourceCaches[t.source].pause()),this._changed=!0},r.prototype._flattenAndSortRenderedFeatures=function(t){for(var e=this,r=function(t){return\"fill-extrusion\"===e._layers[t].type},n={},i=[],a=this._order.length-1;a>=0;a--){var o=this._order[a];if(r(o)){n[o]=a;for(var s=0,l=t;s<l.length;s+=1){var c=l[s][o];if(c)for(var u=0,h=c;u<h.length;u+=1){var f=h[u];i.push(f)}}}}i.sort(function(t,e){return e.intersectionZ-t.intersectionZ});for(var p=[],d=this._order.length-1;d>=0;d--){var g=this._order[d];if(r(g))for(var v=i.length-1;v>=0;v--){var m=i[v].feature;if(n[m.layer.id]<d)break;p.push(m),i.pop()}else for(var y=0,x=t;y<x.length;y+=1){var b=x[y][g];if(b)for(var _=0,w=b;_<w.length;_+=1){var k=w[_];p.push(k.feature)}}}return p},r.prototype.queryRenderedFeatures=function(e,r,n){r&&r.filter&&this._validate(t.validateStyle.filter,\"queryRenderedFeatures.filter\",r.filter,null,r);var i={};if(r&&r.layers){if(!Array.isArray(r.layers))return this.fire(new t.ErrorEvent(new Error(\"parameters.layers must be an Array.\"))),[];for(var a=0,o=r.layers;a<o.length;a+=1){var s=o[a],l=this._layers[s];if(!l)return this.fire(new t.ErrorEvent(new Error(\"The layer '\"+s+\"' does not exist in the map's style and cannot be queried for features.\"))),[];i[l.source]=!0}}var c=[];for(var u in this.sourceCaches)r.layers&&!i[u]||c.push(R(this.sourceCaches[u],this._layers,e,r,n));return this.placement&&c.push(function(t,e,r,n,i,a){for(var o={},s=i.queryRenderedSymbols(r),l=[],c=0,u=Object.keys(s).map(Number);c<u.length;c+=1){var h=u[c];l.push(a[h])}l.sort(F);for(var f=function(){var e=d[p],r=e.featureIndex.lookupSymbolFeatures(s[e.bucketInstanceId],e.bucketIndex,e.sourceLayerIndex,n.filter,n.layers,t);for(var i in r){var a=o[i]=o[i]||[],l=r[i];l.sort(function(t,r){var n=e.featureSortOrder;if(n){var i=n.indexOf(t.featureIndex);return n.indexOf(r.featureIndex)-i}return r.featureIndex-t.featureIndex});for(var c=0,u=l;c<u.length;c+=1){var h=u[c];a.push(h)}}},p=0,d=l;p<d.length;p+=1)f();var g=function(r){o[r].forEach(function(n){var i=n.feature,a=t[r],o=e[a.source].getFeatureState(i.layer[\"source-layer\"],i.id);i.source=i.layer.source,i.layer[\"source-layer\"]&&(i.sourceLayer=i.layer[\"source-layer\"]),i.state=o})};for(var v in o)g(v);return o}(this._layers,this.sourceCaches,e,r,this.placement.collisionIndex,this.placement.retainedQueryData)),this._flattenAndSortRenderedFeatures(c)},r.prototype.querySourceFeatures=function(e,r){r&&r.filter&&this._validate(t.validateStyle.filter,\"querySourceFeatures.filter\",r.filter,null,r);var n=this.sourceCaches[e];return n?function(t,e){for(var r=t.getRenderableIds().map(function(e){return t.getTileByID(e)}),n=[],i={},a=0;a<r.length;a++){var o=r[a],s=o.tileID.canonical.key;i[s]||(i[s]=!0,o.querySourceFeatures(n,e))}return n}(n,r):[]},r.prototype.addSourceType=function(t,e,n){return r.getSourceType(t)?n(new Error('A source type called \"'+t+'\" already exists.')):(r.setSourceType(t,e),e.workerSourceURL?void this.dispatcher.broadcast(\"loadWorkerSource\",{name:t,url:e.workerSourceURL},n):n(null,null))},r.prototype.getLight=function(){return this.light.getLight()},r.prototype.setLight=function(e,r){void 0===r&&(r={}),this._checkLoaded();var n=this.light.getLight(),i=!1;for(var a in e)if(!t.deepEqual(e[a],n[a])){i=!0;break}if(i){var o={now:t.browser.now(),transition:t.extend({duration:300,delay:0},this.stylesheet.transition)};this.light.setLight(e,r),this.light.updateTransitions(o)}},r.prototype._validate=function(e,r,n,i,a){return void 0===a&&(a={}),(!a||!1!==a.validate)&&Oe(this,e.call(t.validateStyle,t.extend({key:r,style:this.serialize(),value:n,styleSpec:t.styleSpec},i)))},r.prototype._remove=function(){for(var e in this._request&&(this._request.cancel(),this._request=null),this._spriteRequest&&(this._spriteRequest.cancel(),this._spriteRequest=null),t.evented.off(\"pluginAvailable\",this._rtlTextPluginCallback),this.sourceCaches)this.sourceCaches[e].clearTiles();this.dispatcher.remove()},r.prototype._clearSource=function(t){this.sourceCaches[t].clearTiles()},r.prototype._reloadSource=function(t){this.sourceCaches[t].resume(),this.sourceCaches[t].reload()},r.prototype._updateSources=function(t){for(var e in this.sourceCaches)this.sourceCaches[e].update(t)},r.prototype._generateCollisionBoxes=function(){for(var t in this.sourceCaches)this._reloadSource(t)},r.prototype._updatePlacement=function(e,r,n,i){for(var a=!1,o=!1,s={},l=0,c=this._order;l<c.length;l+=1){var u=c[l],h=this._layers[u];if(\"symbol\"===h.type){if(!s[h.source]){var f=this.sourceCaches[h.source];s[h.source]=f.getRenderableIds(!0).map(function(t){return f.getTileByID(t)}).sort(function(t,e){return e.tileID.overscaledZ-t.tileID.overscaledZ||(t.tileID.isLessThan(e.tileID)?-1:1)})}var p=this.crossTileSymbolIndex.addLayer(h,s[h.source],e.center.lng);a=a||p}}this.crossTileSymbolIndex.pruneUnusedLayers(this._order);var d=this._layerOrderChanged||0===n;if((d||!this.pauseablePlacement||this.pauseablePlacement.isDone()&&!this.placement.stillRecent(t.browser.now()))&&(this.pauseablePlacement=new Me(e,this._order,d,r,n,i,this.placement),this._layerOrderChanged=!1),this.pauseablePlacement.isDone()?this.placement.setStale():(this.pauseablePlacement.continuePlacement(this._order,this._layers,s),this.pauseablePlacement.isDone()&&(this.placement=this.pauseablePlacement.commit(t.browser.now()),o=!0),a&&this.pauseablePlacement.placement.setStale()),o||a)for(var g=0,v=this._order;g<v.length;g+=1){var m=v[g],y=this._layers[m];\"symbol\"===y.type&&this.placement.updateLayerOpacities(y,s[y.source])}return!this.pauseablePlacement.isDone()||this.placement.hasTransitions(t.browser.now())},r.prototype._releaseSymbolFadeTiles=function(){for(var t in this.sourceCaches)this.sourceCaches[t].releaseSymbolFadeTiles()},r.prototype.getImages=function(t,e,r){this.imageManager.getImages(e.icons,r)},r.prototype.getGlyphs=function(t,e,r){this.glyphManager.getGlyphs(e.stacks,r)},r.prototype.getResource=function(e,r,n){return t.makeRequest(r,n)},r}(t.Evented);De.getSourceType=function(t){return z[t]},De.setSourceType=function(t,e){z[t]=e},De.registerForPluginAvailability=t.registerForPluginAvailability;var Re=t.createLayout([{name:\"a_pos\",type:\"Int16\",components:2}]),Fe=lr(\"#ifdef GL_ES\\nprecision mediump float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\",\"#ifdef GL_ES\\nprecision highp float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\\nvec2 unpack_float(const float packedValue) {int packedIntValue=int(packedValue);int v0=packedIntValue/256;return vec2(v0,packedIntValue-v0*256);}vec2 unpack_opacity(const float packedOpacity) {int intOpacity=int(packedOpacity)/2;return vec2(float(intOpacity)/127.0,mod(packedOpacity,2.0));}vec4 decode_color(const vec2 encodedColor) {return vec4(unpack_float(encodedColor[0])/255.0,unpack_float(encodedColor[1])/255.0\\n);}float unpack_mix_vec2(const vec2 packedValue,const float t) {return mix(packedValue[0],packedValue[1],t);}vec4 unpack_mix_color(const vec4 packedColors,const float t) {vec4 minColor=decode_color(vec2(packedColors[0],packedColors[1]));vec4 maxColor=decode_color(vec2(packedColors[2],packedColors[3]));return mix(minColor,maxColor,t);}vec2 get_pattern_pos(const vec2 pixel_coord_upper,const vec2 pixel_coord_lower,const vec2 pattern_size,const float tile_units_to_pixels,const vec2 pos) {vec2 offset=mod(mod(mod(pixel_coord_upper,pattern_size)*256.0,pattern_size)*256.0+pixel_coord_lower,pattern_size);return (tile_units_to_pixels*pos+offset)/pattern_size;}\"),Be=lr(\"uniform vec4 u_color;uniform float u_opacity;void main() {gl_FragColor=u_color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),Ne=lr(\"uniform vec2 u_pattern_tl_a;uniform vec2 u_pattern_br_a;uniform vec2 u_pattern_tl_b;uniform vec2 u_pattern_br_b;uniform vec2 u_texsize;uniform float u_mix;uniform float u_opacity;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(u_pattern_tl_a/u_texsize,u_pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(u_pattern_tl_b/u_texsize,u_pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_mix)*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pattern_size_a;uniform vec2 u_pattern_size_b;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_scale_a;uniform float u_scale_b;uniform float u_tile_units_to_pixels;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_a*u_pattern_size_a,u_tile_units_to_pixels,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_b*u_pattern_size_b,u_tile_units_to_pixels,a_pos);}\"),je=lr(\"varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=v_data.xy;float extrude_length=length(extrude);lowp float antialiasblur=v_data.z;float antialiased_blur=-max(blur,antialiasblur);float opacity_t=smoothstep(0.0,antialiased_blur,extrude_length-1.0);float color_t=stroke_width < 0.01 ? 0.0 : smoothstep(antialiased_blur,0.0,extrude_length-radius/(radius+stroke_width));gl_FragColor=opacity_t*mix(color*opacity,stroke_color*stroke_opacity,color_t);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform bool u_scale_with_map;uniform bool u_pitch_with_map;uniform vec2 u_extrude_scale;uniform lowp float u_device_pixel_ratio;uniform highp float u_camera_to_center_distance;attribute vec2 a_pos;varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main(void) {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=vec2(mod(a_pos,2.0)*2.0-1.0);vec2 circle_center=floor(a_pos*0.5);if (u_pitch_with_map) {vec2 corner_position=circle_center;if (u_scale_with_map) {corner_position+=extrude*(radius+stroke_width)*u_extrude_scale;} else {vec4 projected_center=u_matrix*vec4(circle_center,0,1);corner_position+=extrude*(radius+stroke_width)*u_extrude_scale*(projected_center.w/u_camera_to_center_distance);}gl_Position=u_matrix*vec4(corner_position,0,1);} else {gl_Position=u_matrix*vec4(circle_center,0,1);if (u_scale_with_map) {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*u_camera_to_center_distance;} else {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*gl_Position.w;}}lowp float antialiasblur=1.0/u_device_pixel_ratio/(radius+stroke_width);v_data=vec3(extrude.x,extrude.y,antialiasblur);}\"),Ue=lr(\"void main() {gl_FragColor=vec4(1.0);}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),Ve=lr(\"uniform highp float u_intensity;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main() {\\n#pragma mapbox: initialize highp float weight\\nfloat d=-0.5*3.0*3.0*dot(v_extrude,v_extrude);float val=weight*u_intensity*GAUSS_COEF*exp(d);gl_FragColor=vec4(val,1.0,1.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform float u_extrude_scale;uniform float u_opacity;uniform float u_intensity;attribute vec2 a_pos;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#pragma mapbox: define mediump float radius\\nconst highp float ZERO=1.0/255.0/16.0;\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main(void) {\\n#pragma mapbox: initialize highp float weight\\n#pragma mapbox: initialize mediump float radius\\nvec2 unscaled_extrude=vec2(mod(a_pos,2.0)*2.0-1.0);float S=sqrt(-2.0*log(ZERO/weight/u_intensity/GAUSS_COEF))/3.0;v_extrude=S*unscaled_extrude;vec2 extrude=v_extrude*radius*u_extrude_scale;vec4 pos=vec4(floor(a_pos*0.5)+extrude,0,1);gl_Position=u_matrix*pos;}\"),qe=lr(\"uniform sampler2D u_image;uniform sampler2D u_color_ramp;uniform float u_opacity;varying vec2 v_pos;void main() {float t=texture2D(u_image,v_pos).r;vec4 color=texture2D(u_color_ramp,vec2(t,0.5));gl_FragColor=color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(0.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;attribute vec2 a_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos*u_world,0,1);v_pos.x=a_pos.x;v_pos.y=1.0-a_pos.y;}\"),He=lr(\"varying float v_placed;varying float v_notUsed;void main() {float alpha=0.5;gl_FragColor=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {gl_FragColor=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {gl_FragColor*=.1;}}\",\"attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;attribute vec2 a_shift;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);gl_Position.xy+=(a_extrude+a_shift)*u_extrude_scale*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;}\"),Ge=lr(\"uniform float u_overscale_factor;varying float v_placed;varying float v_notUsed;varying float v_radius;varying vec2 v_extrude;varying vec2 v_extrude_scale;void main() {float alpha=0.5;vec4 color=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {color=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {color*=.2;}float extrude_scale_length=length(v_extrude_scale);float extrude_length=length(v_extrude)*extrude_scale_length;float stroke_width=15.0*extrude_scale_length/u_overscale_factor;float radius=v_radius*extrude_scale_length;float distance_to_edge=abs(extrude_length-radius);float opacity_t=smoothstep(-stroke_width,0.0,-distance_to_edge);gl_FragColor=opacity_t*color;}\",\"attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;varying float v_radius;varying vec2 v_extrude;varying vec2 v_extrude_scale;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);highp float padding_factor=1.2;gl_Position.xy+=a_extrude*u_extrude_scale*padding_factor*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;v_radius=abs(a_extrude.y);v_extrude=a_extrude*padding_factor;v_extrude_scale=u_extrude_scale*u_camera_to_center_distance*collision_perspective_ratio;}\"),Ye=lr(\"uniform highp vec4 u_color;void main() {gl_FragColor=u_color;}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),We=lr(\"#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_FragColor=color*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);}\"),Xe=lr(\"varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=outline_color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;uniform vec2 u_world;varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),Ze=lr(\"uniform vec2 u_texsize;uniform sampler2D u_image;uniform float u_fade;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);float dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=mix(color1,color2,u_fade)*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec4 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;gl_Position=u_matrix*vec4(a_pos,0,1);vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,a_pos);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),Je=lr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_fade)*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec4 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileZoomRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileZoomRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileZoomRatio,a_pos);}\"),Ke=lr(\"varying vec4 v_color;void main() {gl_FragColor=v_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;uniform float u_vertical_gradient;uniform lowp float u_opacity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec4 v_color;\\n#pragma mapbox: define highp float base\\n#pragma mapbox: define highp float height\\n#pragma mapbox: define highp vec4 color\\nvoid main() {\\n#pragma mapbox: initialize highp float base\\n#pragma mapbox: initialize highp float height\\n#pragma mapbox: initialize highp vec4 color\\nvec3 normal=a_normal_ed.xyz;base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);gl_Position=u_matrix*vec4(a_pos,t > 0.0 ? height : base,1);float colorvalue=color.r*0.2126+color.g*0.7152+color.b*0.0722;v_color=vec4(0.0,0.0,0.0,1.0);vec4 ambientlight=vec4(0.03,0.03,0.03,1.0);color+=ambientlight;float directional=clamp(dot(normal/16384.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((1.0-colorvalue+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_color.r+=clamp(color.r*directional*u_lightcolor.r,mix(0.0,0.3,1.0-u_lightcolor.r),1.0);v_color.g+=clamp(color.g*directional*u_lightcolor.g,mix(0.0,0.3,1.0-u_lightcolor.g),1.0);v_color.b+=clamp(color.b*directional*u_lightcolor.b,mix(0.0,0.3,1.0-u_lightcolor.b),1.0);v_color*=u_opacity;}\"),$e=lr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);vec4 mixedColor=mix(color1,color2,u_fade);gl_FragColor=mixedColor*v_lighting;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_height_factor;uniform vec4 u_scale;uniform float u_vertical_gradient;uniform lowp float u_opacity;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec3 normal=a_normal_ed.xyz;float edgedistance=a_normal_ed.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);float z=t > 0.0 ? height : base;gl_Position=u_matrix*vec4(a_pos,z,1);vec2 pos=normal.x==1.0 && normal.y==0.0 && normal.z==16384.0\\n? a_pos\\n: vec2(edgedistance,z*u_height_factor);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,pos);v_lighting=vec4(0.0,0.0,0.0,1.0);float directional=clamp(dot(normal/16383.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((0.5+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_lighting.rgb+=clamp(directional*u_lightcolor,mix(vec3(0.0),vec3(0.3),1.0-u_lightcolor),vec3(1.0));v_lighting*=u_opacity;}\"),Qe=lr(\"#ifdef GL_ES\\nprecision highp float;\\n#endif\\nuniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_dimension;uniform float u_zoom;uniform float u_maxzoom;float getElevation(vec2 coord,float bias) {vec4 data=texture2D(u_image,coord)*255.0;return (data.r+data.g*256.0+data.b*256.0*256.0)/4.0;}void main() {vec2 epsilon=1.0/u_dimension;float a=getElevation(v_pos+vec2(-epsilon.x,-epsilon.y),0.0);float b=getElevation(v_pos+vec2(0,-epsilon.y),0.0);float c=getElevation(v_pos+vec2(epsilon.x,-epsilon.y),0.0);float d=getElevation(v_pos+vec2(-epsilon.x,0),0.0);float e=getElevation(v_pos,0.0);float f=getElevation(v_pos+vec2(epsilon.x,0),0.0);float g=getElevation(v_pos+vec2(-epsilon.x,epsilon.y),0.0);float h=getElevation(v_pos+vec2(0,epsilon.y),0.0);float i=getElevation(v_pos+vec2(epsilon.x,epsilon.y),0.0);float exaggeration=u_zoom < 2.0 ? 0.4 : u_zoom < 4.5 ? 0.35 : 0.3;vec2 deriv=vec2((c+f+f+i)-(a+d+d+g),(g+h+h+i)-(a+b+b+c))/ pow(2.0,(u_zoom-u_maxzoom)*exaggeration+19.2562-u_zoom);gl_FragColor=clamp(vec4(deriv.x/2.0+0.5,deriv.y/2.0+0.5,1.0,1.0),0.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_dimension;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);highp vec2 epsilon=1.0/u_dimension;float scale=(u_dimension.x-2.0)/u_dimension.x;v_pos=(a_texture_pos/8192.0)*scale+epsilon;}\"),tr=lr(\"uniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_latrange;uniform vec2 u_light;uniform vec4 u_shadow;uniform vec4 u_highlight;uniform vec4 u_accent;\\n#define PI 3.141592653589793\\nvoid main() {vec4 pixel=texture2D(u_image,v_pos);vec2 deriv=((pixel.rg*2.0)-1.0);float scaleFactor=cos(radians((u_latrange[0]-u_latrange[1])*(1.0-v_pos.y)+u_latrange[1]));float slope=atan(1.25*length(deriv)/scaleFactor);float aspect=deriv.x !=0.0 ? atan(deriv.y,-deriv.x) : PI/2.0*(deriv.y > 0.0 ? 1.0 :-1.0);float intensity=u_light.x;float azimuth=u_light.y+PI;float base=1.875-intensity*1.75;float maxValue=0.5*PI;float scaledSlope=intensity !=0.5 ? ((pow(base,slope)-1.0)/(pow(base,maxValue)-1.0))*maxValue : slope;float accent=cos(scaledSlope);vec4 accent_color=(1.0-accent)*u_accent*clamp(intensity*2.0,0.0,1.0);float shade=abs(mod((aspect+azimuth)/PI+0.5,2.0)-1.0);vec4 shade_color=mix(u_shadow,u_highlight,shade)*sin(scaledSlope)*clamp(intensity*2.0,0.0,1.0);gl_FragColor=accent_color*(1.0-shade_color.a)+shade_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos=a_texture_pos/8192.0;}\"),er=lr(\"uniform lowp float u_device_pixel_ratio;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform vec2 u_units_to_pixels;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_linesofar;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),rr=lr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);vec4 color=texture2D(u_image,vec2(v_lineprogress,0.5));gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define MAX_LINE_DISTANCE 32767.0\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_lineprogress=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0/MAX_LINE_DISTANCE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),nr=lr(\"uniform lowp float u_device_pixel_ratio;uniform vec2 u_texsize;uniform float u_fade;uniform mediump vec4 u_scale;uniform sampler2D u_image;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileZoomRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);vec2 pattern_size_a=vec2(display_size_a.x*fromScale/tileZoomRatio,display_size_a.y);vec2 pattern_size_b=vec2(display_size_b.x*toScale/tileZoomRatio,display_size_b.y);float dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float x_a=mod(v_linesofar/pattern_size_a.x,1.0);float x_b=mod(v_linesofar/pattern_size_b.x,1.0);float y_a=0.5+(v_normal.y*clamp(v_width2.s,0.0,(pattern_size_a.y+2.0)/2.0)/pattern_size_a.y);float y_b=0.5+(v_normal.y*clamp(v_width2.s,0.0,(pattern_size_b.y+2.0)/2.0)/pattern_size_b.y);vec2 pos_a=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,vec2(x_a,y_a));vec2 pos_b=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,vec2(x_b,y_b));vec4 color=mix(texture2D(u_image,pos_a),texture2D(u_image,pos_b),u_fade);gl_FragColor=color*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform vec2 u_units_to_pixels;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_linesofar=a_linesofar;v_width2=vec2(outset,inset);}\"),ir=lr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;uniform float u_sdfgamma;uniform float u_mix;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float sdfdist_a=texture2D(u_image,v_tex_a).a;float sdfdist_b=texture2D(u_image,v_tex_b).a;float sdfdist=mix(sdfdist_a,sdfdist_b,u_mix);alpha*=smoothstep(0.5-u_sdfgamma/floorwidth,0.5+u_sdfgamma/floorwidth,sdfdist);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_patternscale_a;uniform float u_tex_y_a;uniform vec2 u_patternscale_b;uniform float u_tex_y_b;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_tex_a=vec2(a_linesofar*u_patternscale_a.x/floorwidth,normal.y*u_patternscale_a.y+u_tex_y_a);v_tex_b=vec2(a_linesofar*u_patternscale_b.x/floorwidth,normal.y*u_patternscale_b.y+u_tex_y_b);v_width2=vec2(outset,inset);}\"),ar=lr(\"uniform float u_fade_t;uniform float u_opacity;uniform sampler2D u_image0;uniform sampler2D u_image1;varying vec2 v_pos0;varying vec2 v_pos1;uniform float u_brightness_low;uniform float u_brightness_high;uniform float u_saturation_factor;uniform float u_contrast_factor;uniform vec3 u_spin_weights;void main() {vec4 color0=texture2D(u_image0,v_pos0);vec4 color1=texture2D(u_image1,v_pos1);if (color0.a > 0.0) {color0.rgb=color0.rgb/color0.a;}if (color1.a > 0.0) {color1.rgb=color1.rgb/color1.a;}vec4 color=mix(color0,color1,u_fade_t);color.a*=u_opacity;vec3 rgb=color.rgb;rgb=vec3(dot(rgb,u_spin_weights.xyz),dot(rgb,u_spin_weights.zxy),dot(rgb,u_spin_weights.yzx));float average=(color.r+color.g+color.b)/3.0;rgb+=(average-rgb)*u_saturation_factor;rgb=(rgb-0.5)*u_contrast_factor+0.5;vec3 u_high_vec=vec3(u_brightness_low,u_brightness_low,u_brightness_low);vec3 u_low_vec=vec3(u_brightness_high,u_brightness_high,u_brightness_high);gl_FragColor=vec4(mix(u_high_vec,u_low_vec,rgb)*color.a,color.a);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_tl_parent;uniform float u_scale_parent;uniform float u_buffer_scale;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos0;varying vec2 v_pos1;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos0=(((a_texture_pos/8192.0)-0.5)/u_buffer_scale )+0.5;v_pos1=(v_pos0*u_scale_parent)+u_tl_parent;}\"),or=lr(\"uniform sampler2D u_texture;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nlowp float alpha=opacity*v_fade_opacity;gl_FragColor=texture2D(u_texture,v_tex)*alpha;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform highp float u_camera_to_center_distance;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform float u_fade_change;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform vec2 u_texsize;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size[0],a_size[1],u_size_t)/256.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size[0]/256.0;} else if (!u_is_size_zoom_constant && u_is_size_feature_constant) {size=u_size;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);v_tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;v_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));}\"),sr=lr(\"#define SDF_PX 8.0\\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;uniform bool u_is_text;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nfloat EDGE_GAMMA=0.105/u_device_pixel_ratio;vec2 tex=v_data0.xy;float gamma_scale=v_data1.x;float size=v_data1.y;float fade_opacity=v_data1[2];float fontScale=u_is_text ? size/24.0 : size;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size[0],a_size[1],u_size_t)/256.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size[0]/256.0;} else if (!u_is_size_zoom_constant && u_is_size_feature_constant) {size=u_size;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);float gamma_scale=gl_Position.w;vec2 tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));v_data0=vec2(tex.x,tex.y);v_data1=vec3(gamma_scale,size,interpolated_fade_opacity);}\");function lr(t,e){var r=/#pragma mapbox: ([\\w]+) ([\\w]+) ([\\w]+) ([\\w]+)/g,n={};return{fragmentSource:t=t.replace(r,function(t,e,r,i,a){return n[a]=!0,\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"\\n#ifdef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"}),vertexSource:e=e.replace(r,function(t,e,r,i,a){var o=\"float\"===i?\"vec2\":\"vec4\",s=a.match(/color/)?\"color\":o;return n[a]?\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"})}}var cr=Object.freeze({prelude:Fe,background:Be,backgroundPattern:Ne,circle:je,clippingMask:Ue,heatmap:Ve,heatmapTexture:qe,collisionBox:He,collisionCircle:Ge,debug:Ye,fill:We,fillOutline:Xe,fillOutlinePattern:Ze,fillPattern:Je,fillExtrusion:Ke,fillExtrusionPattern:$e,hillshadePrepare:Qe,hillshade:tr,line:er,lineGradient:rr,linePattern:nr,lineSDF:ir,raster:ar,symbolIcon:or,symbolSDF:sr}),ur=function(){this.boundProgram=null,this.boundLayoutVertexBuffer=null,this.boundPaintVertexBuffers=[],this.boundIndexBuffer=null,this.boundVertexOffset=null,this.boundDynamicVertexBuffer=null,this.vao=null};ur.prototype.bind=function(t,e,r,n,i,a,o,s){this.context=t;for(var l=this.boundPaintVertexBuffers.length!==n.length,c=0;!l&&c<n.length;c++)this.boundPaintVertexBuffers[c]!==n[c]&&(l=!0);var u=!this.vao||this.boundProgram!==e||this.boundLayoutVertexBuffer!==r||l||this.boundIndexBuffer!==i||this.boundVertexOffset!==a||this.boundDynamicVertexBuffer!==o||this.boundDynamicVertexBuffer2!==s;!t.extVertexArrayObject||u?this.freshBind(e,r,n,i,a,o,s):(t.bindVertexArrayOES.set(this.vao),o&&o.bind(),i&&i.dynamicDraw&&i.bind(),s&&s.bind())},ur.prototype.freshBind=function(t,e,r,n,i,a,o){var s,l=t.numAttributes,c=this.context,u=c.gl;if(c.extVertexArrayObject)this.vao&&this.destroy(),this.vao=c.extVertexArrayObject.createVertexArrayOES(),c.bindVertexArrayOES.set(this.vao),s=0,this.boundProgram=t,this.boundLayoutVertexBuffer=e,this.boundPaintVertexBuffers=r,this.boundIndexBuffer=n,this.boundVertexOffset=i,this.boundDynamicVertexBuffer=a,this.boundDynamicVertexBuffer2=o;else{s=c.currentNumAttributes||0;for(var h=l;h<s;h++)u.disableVertexAttribArray(h)}e.enableAttributes(u,t);for(var f=0,p=r;f<p.length;f+=1)p[f].enableAttributes(u,t);a&&a.enableAttributes(u,t),o&&o.enableAttributes(u,t),e.bind(),e.setVertexAttribPointers(u,t,i);for(var d=0,g=r;d<g.length;d+=1){var v=g[d];v.bind(),v.setVertexAttribPointers(u,t,i)}a&&(a.bind(),a.setVertexAttribPointers(u,t,i)),n&&n.bind(),o&&(o.bind(),o.setVertexAttribPointers(u,t,i)),c.currentNumAttributes=l},ur.prototype.destroy=function(){this.vao&&(this.context.extVertexArrayObject.deleteVertexArrayOES(this.vao),this.vao=null)};var hr=function(t,e,r,n,i){var a=t.gl;this.program=a.createProgram();var o=r.defines();i&&o.push(\"#define OVERDRAW_INSPECTOR;\");var s=o.concat(Fe.fragmentSource,e.fragmentSource).join(\"\\n\"),l=o.concat(Fe.vertexSource,e.vertexSource).join(\"\\n\"),c=a.createShader(a.FRAGMENT_SHADER);a.shaderSource(c,s),a.compileShader(c),a.attachShader(this.program,c);var u=a.createShader(a.VERTEX_SHADER);a.shaderSource(u,l),a.compileShader(u),a.attachShader(this.program,u);for(var h=r.layoutAttributes||[],f=0;f<h.length;f++)a.bindAttribLocation(this.program,f,h[f].name);a.linkProgram(this.program),this.numAttributes=a.getProgramParameter(this.program,a.ACTIVE_ATTRIBUTES),this.attributes={};for(var p={},d=0;d<this.numAttributes;d++){var g=a.getActiveAttrib(this.program,d);g&&(this.attributes[g.name]=a.getAttribLocation(this.program,g.name))}for(var v=a.getProgramParameter(this.program,a.ACTIVE_UNIFORMS),m=0;m<v;m++){var y=a.getActiveUniform(this.program,m);y&&(p[y.name]=a.getUniformLocation(this.program,y.name))}this.fixedUniforms=n(t,p),this.binderUniforms=r.getUniforms(t,p)};function fr(e,r,n){var i=1/le(n,1,r.transform.tileZoom),a=Math.pow(2,n.tileID.overscaledZ),o=n.tileSize*Math.pow(2,r.transform.tileZoom)/a,s=o*(n.tileID.canonical.x+n.tileID.wrap*a),l=o*n.tileID.canonical.y;return{u_image:0,u_texsize:n.imageAtlasTexture.size,u_scale:[t.browser.devicePixelRatio,i,e.fromScale,e.toScale],u_fade:e.t,u_pixel_coord_upper:[s>>16,l>>16],u_pixel_coord_lower:[65535&s,65535&l]}}hr.prototype.draw=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g){var v,m=t.gl;for(var y in t.program.set(this.program),t.setDepthMode(r),t.setStencilMode(n),t.setColorMode(i),t.setCullFace(a),this.fixedUniforms)this.fixedUniforms[y].set(o[y]);p&&p.setUniforms(t,this.binderUniforms,h,{zoom:f});for(var x=(v={},v[m.LINES]=2,v[m.TRIANGLES]=3,v[m.LINE_STRIP]=1,v)[e],b=0,_=u.get();b<_.length;b+=1){var w=_[b],k=w.vaos||(w.vaos={});(k[s]||(k[s]=new ur)).bind(t,this,l,p?p.getPaintVertexBuffers():[],c,w.vertexOffset,d,g),m.drawElements(e,w.primitiveLength*x,m.UNSIGNED_SHORT,w.primitiveOffset*x*2)}};var pr=function(e,r,n,i){var a=r.style.light,o=a.properties.get(\"position\"),s=[o.x,o.y,o.z],l=t.create$1();\"viewport\"===a.properties.get(\"anchor\")&&t.fromRotation(l,-r.transform.angle),t.transformMat3(s,s,l);var c=a.properties.get(\"color\");return{u_matrix:e,u_lightpos:s,u_lightintensity:a.properties.get(\"intensity\"),u_lightcolor:[c.r,c.g,c.b],u_vertical_gradient:+n,u_opacity:i}},dr=function(e,r,n,i,a,o,s){return t.extend(pr(e,r,n,i),fr(o,r,s),{u_height_factor:-Math.pow(2,a.overscaledZ)/s.tileSize/8})},gr=function(t){return{u_matrix:t}},vr=function(e,r,n,i){return t.extend(gr(e),fr(n,r,i))},mr=function(t,e){return{u_matrix:t,u_world:e}},yr=function(e,r,n,i,a){return t.extend(vr(e,r,n,i),{u_world:a})},xr=function(e,r,n,i){var a,o,s=e.transform;if(\"map\"===i.paint.get(\"circle-pitch-alignment\")){var l=le(n,1,s.zoom);a=!0,o=[l,l]}else a=!1,o=s.pixelsToGLUnits;return{u_camera_to_center_distance:s.cameraToCenterDistance,u_scale_with_map:+(\"map\"===i.paint.get(\"circle-pitch-scale\")),u_matrix:e.translatePosMatrix(r.posMatrix,n,i.paint.get(\"circle-translate\"),i.paint.get(\"circle-translate-anchor\")),u_pitch_with_map:+a,u_device_pixel_ratio:t.browser.devicePixelRatio,u_extrude_scale:o}},br=function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pixels_to_tile_units:new t.Uniform1f(e,r.u_pixels_to_tile_units),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_overscale_factor:new t.Uniform1f(e,r.u_overscale_factor)}},_r=function(t,e,r){var n=le(r,1,e.zoom),i=Math.pow(2,e.zoom-r.tileID.overscaledZ),a=r.tileID.overscaleFactor();return{u_matrix:t,u_camera_to_center_distance:e.cameraToCenterDistance,u_pixels_to_tile_units:n,u_extrude_scale:[e.pixelsToGLUnits[0]/(n*i),e.pixelsToGLUnits[1]/(n*i)],u_overscale_factor:a}},wr=function(t,e){return{u_matrix:t,u_color:e}},kr=function(t){return{u_matrix:t}},Tr=function(t,e,r,n){return{u_matrix:t,u_extrude_scale:le(e,1,r),u_intensity:n}},Ar=function(t,e,r){var n=r.paint.get(\"hillshade-shadow-color\"),i=r.paint.get(\"hillshade-highlight-color\"),a=r.paint.get(\"hillshade-accent-color\"),o=r.paint.get(\"hillshade-illumination-direction\")*(Math.PI/180);\"viewport\"===r.paint.get(\"hillshade-illumination-anchor\")&&(o-=t.transform.angle);var s=!t.options.moving;return{u_matrix:t.transform.calculatePosMatrix(e.tileID.toUnwrapped(),s),u_image:0,u_latrange:Sr(t,e.tileID),u_light:[r.paint.get(\"hillshade-exaggeration\"),o],u_shadow:n,u_highlight:i,u_accent:a}},Mr=function(e,r){var n=e.dem.stride,i=t.create();return t.ortho(i,0,t.EXTENT,-t.EXTENT,0,0,1),t.translate(i,i,[0,-t.EXTENT,0]),{u_matrix:i,u_image:1,u_dimension:[n,n],u_zoom:e.tileID.overscaledZ,u_maxzoom:r}};function Sr(e,r){var n=Math.pow(2,r.canonical.z),i=r.canonical.y;return[new t.MercatorCoordinate(0,i/n).toLngLat().lat,new t.MercatorCoordinate(0,(i+1)/n).toLngLat().lat]}var Er=function(e,r,n){var i=e.transform;return{u_matrix:zr(e,r,n),u_ratio:1/le(r,1,i.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_units_to_pixels:[1/i.pixelsToGLUnits[0],1/i.pixelsToGLUnits[1]]}},Cr=function(e,r,n){return t.extend(Er(e,r,n),{u_image:0})},Lr=function(e,r,n,i){var a=e.transform,o=Or(r,a);return{u_matrix:zr(e,r,n),u_texsize:r.imageAtlasTexture.size,u_ratio:1/le(r,1,a.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_image:0,u_scale:[t.browser.devicePixelRatio,o,i.fromScale,i.toScale],u_fade:i.t,u_units_to_pixels:[1/a.pixelsToGLUnits[0],1/a.pixelsToGLUnits[1]]}},Pr=function(e,r,n,i,a){var o=e.transform,s=e.lineAtlas,l=Or(r,o),c=\"round\"===n.layout.get(\"line-cap\"),u=s.getDash(i.from,c),h=s.getDash(i.to,c),f=u.width*a.fromScale,p=h.width*a.toScale;return t.extend(Er(e,r,n),{u_patternscale_a:[l/f,-u.height/2],u_patternscale_b:[l/p,-h.height/2],u_sdfgamma:s.width/(256*Math.min(f,p)*t.browser.devicePixelRatio)/2,u_image:0,u_tex_y_a:u.y,u_tex_y_b:h.y,u_mix:a.t})};function Or(t,e){return 1/le(t,1,e.tileZoom)}function zr(t,e,r){return t.translatePosMatrix(e.tileID.posMatrix,e,r.paint.get(\"line-translate\"),r.paint.get(\"line-translate-anchor\"))}var Ir=function(t,e,r,n,i){return{u_matrix:t,u_tl_parent:e,u_scale_parent:r,u_buffer_scale:1,u_fade_t:n.mix,u_opacity:n.opacity*i.paint.get(\"raster-opacity\"),u_image0:0,u_image1:1,u_brightness_low:i.paint.get(\"raster-brightness-min\"),u_brightness_high:i.paint.get(\"raster-brightness-max\"),u_saturation_factor:(o=i.paint.get(\"raster-saturation\"),o>0?1-1/(1.001-o):-o),u_contrast_factor:(a=i.paint.get(\"raster-contrast\"),a>0?1/(1-a):1+a),u_spin_weights:function(t){t*=Math.PI/180;var e=Math.sin(t),r=Math.cos(t);return[(2*r+1)/3,(-Math.sqrt(3)*e-r+1)/3,(Math.sqrt(3)*e-r+1)/3]}(i.paint.get(\"raster-hue-rotate\"))};var a,o};var Dr=function(t,e,r,n,i,a,o,s,l,c){var u=i.transform;return{u_is_size_zoom_constant:+(\"constant\"===t||\"source\"===t),u_is_size_feature_constant:+(\"constant\"===t||\"camera\"===t),u_size_t:e?e.uSizeT:0,u_size:e?e.uSize:0,u_camera_to_center_distance:u.cameraToCenterDistance,u_pitch:u.pitch/360*2*Math.PI,u_rotate_symbol:+r,u_aspect_ratio:u.width/u.height,u_fade_change:i.options.fadeDuration?i.symbolFadeChange:1,u_matrix:a,u_label_plane_matrix:o,u_coord_matrix:s,u_is_text:+l,u_pitch_with_map:+n,u_texsize:c,u_texture:0}},Rr=function(e,r,n,i,a,o,s,l,c,u,h){var f=a.transform;return t.extend(Dr(e,r,n,i,a,o,s,l,c,u),{u_gamma_scale:i?Math.cos(f._pitch)*f.cameraToCenterDistance:1,u_device_pixel_ratio:t.browser.devicePixelRatio,u_is_halo:+h})},Fr=function(t,e,r){return{u_matrix:t,u_opacity:e,u_color:r}},Br=function(e,r,n,i,a,o){return t.extend(function(t,e,r,n){var i=r.imageManager.getPattern(t.from),a=r.imageManager.getPattern(t.to),o=r.imageManager.getPixelSize(),s=o.width,l=o.height,c=Math.pow(2,n.tileID.overscaledZ),u=n.tileSize*Math.pow(2,r.transform.tileZoom)/c,h=u*(n.tileID.canonical.x+n.tileID.wrap*c),f=u*n.tileID.canonical.y;return{u_image:0,u_pattern_tl_a:i.tl,u_pattern_br_a:i.br,u_pattern_tl_b:a.tl,u_pattern_br_b:a.br,u_texsize:[s,l],u_mix:e.t,u_pattern_size_a:i.displaySize,u_pattern_size_b:a.displaySize,u_scale_a:e.fromScale,u_scale_b:e.toScale,u_tile_units_to_pixels:1/le(n,1,r.transform.tileZoom),u_pixel_coord_upper:[h>>16,f>>16],u_pixel_coord_lower:[65535&h,65535&f]}}(i,o,n,a),{u_matrix:e,u_opacity:r})},Nr={fillExtrusion:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fillExtrusionPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_height_factor:new t.Uniform1f(e,r.u_height_factor),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fill:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},fillPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},fillOutline:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world)}},fillOutlinePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},circle:function(e,r){return{u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_scale_with_map:new t.Uniform1i(e,r.u_scale_with_map),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},collisionBox:br,collisionCircle:br,debug:function(e,r){return{u_color:new t.UniformColor(e,r.u_color),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},clippingMask:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmap:function(e,r){return{u_extrude_scale:new t.Uniform1f(e,r.u_extrude_scale),u_intensity:new t.Uniform1f(e,r.u_intensity),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmapTexture:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_color_ramp:new t.Uniform1i(e,r.u_color_ramp),u_opacity:new t.Uniform1f(e,r.u_opacity)}},hillshade:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_latrange:new t.Uniform2f(e,r.u_latrange),u_light:new t.Uniform2f(e,r.u_light),u_shadow:new t.UniformColor(e,r.u_shadow),u_highlight:new t.UniformColor(e,r.u_highlight),u_accent:new t.UniformColor(e,r.u_accent)}},hillshadePrepare:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_dimension:new t.Uniform2f(e,r.u_dimension),u_zoom:new t.Uniform1f(e,r.u_zoom),u_maxzoom:new t.Uniform1f(e,r.u_maxzoom)}},line:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels)}},lineGradient:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_image:new t.Uniform1i(e,r.u_image)}},linePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_texsize:new t.Uniform2f(e,r.u_texsize),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_image:new t.Uniform1i(e,r.u_image),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},lineSDF:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_patternscale_a:new t.Uniform2f(e,r.u_patternscale_a),u_patternscale_b:new t.Uniform2f(e,r.u_patternscale_b),u_sdfgamma:new t.Uniform1f(e,r.u_sdfgamma),u_image:new t.Uniform1i(e,r.u_image),u_tex_y_a:new t.Uniform1f(e,r.u_tex_y_a),u_tex_y_b:new t.Uniform1f(e,r.u_tex_y_b),u_mix:new t.Uniform1f(e,r.u_mix)}},raster:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_tl_parent:new t.Uniform2f(e,r.u_tl_parent),u_scale_parent:new t.Uniform1f(e,r.u_scale_parent),u_buffer_scale:new t.Uniform1f(e,r.u_buffer_scale),u_fade_t:new t.Uniform1f(e,r.u_fade_t),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image0:new t.Uniform1i(e,r.u_image0),u_image1:new t.Uniform1i(e,r.u_image1),u_brightness_low:new t.Uniform1f(e,r.u_brightness_low),u_brightness_high:new t.Uniform1f(e,r.u_brightness_high),u_saturation_factor:new t.Uniform1f(e,r.u_saturation_factor),u_contrast_factor:new t.Uniform1f(e,r.u_contrast_factor),u_spin_weights:new t.Uniform3f(e,r.u_spin_weights)}},symbolIcon:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1f(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture)}},symbolSDF:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1f(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture),u_gamma_scale:new t.Uniform1f(e,r.u_gamma_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_is_halo:new t.Uniform1f(e,r.u_is_halo)}},background:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_color:new t.UniformColor(e,r.u_color)}},backgroundPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image:new t.Uniform1i(e,r.u_image),u_pattern_tl_a:new t.Uniform2f(e,r.u_pattern_tl_a),u_pattern_br_a:new t.Uniform2f(e,r.u_pattern_br_a),u_pattern_tl_b:new t.Uniform2f(e,r.u_pattern_tl_b),u_pattern_br_b:new t.Uniform2f(e,r.u_pattern_br_b),u_texsize:new t.Uniform2f(e,r.u_texsize),u_mix:new t.Uniform1f(e,r.u_mix),u_pattern_size_a:new t.Uniform2f(e,r.u_pattern_size_a),u_pattern_size_b:new t.Uniform2f(e,r.u_pattern_size_b),u_scale_a:new t.Uniform1f(e,r.u_scale_a),u_scale_b:new t.Uniform1f(e,r.u_scale_b),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_tile_units_to_pixels:new t.Uniform1f(e,r.u_tile_units_to_pixels)}}};function jr(e,r){for(var n=e.sort(function(t,e){return t.tileID.isLessThan(e.tileID)?-1:e.tileID.isLessThan(t.tileID)?1:0}),i=0;i<n.length;i++){var a={},o=n[i],s=n.slice(i+1);Ur(o.tileID.wrapped(),o.tileID,s,new t.OverscaledTileID(0,o.tileID.wrap+1,0,0,0),a),o.setMask(a,r)}}function Ur(e,r,n,i,a){for(var o=0;o<n.length;o++){var s=n[o];if(i.isLessThan(s.tileID))break;if(r.key===s.tileID.key)return;if(s.tileID.isChildOf(r)){for(var l=r.children(1/0),c=0;c<l.length;c++)Ur(e,l[c],n.slice(o),i,a);return}}var u=r.overscaledZ-e.overscaledZ,h=new t.CanonicalTileID(u,r.canonical.x-(e.canonical.x<<u),r.canonical.y-(e.canonical.y<<u));a[h.key]=a[h.key]||h}function Vr(t,e,r,n,i){for(var a=t.context,o=a.gl,s=i?t.useProgram(\"collisionCircle\"):t.useProgram(\"collisionBox\"),l=0;l<n.length;l++){var c=n[l],u=e.getTile(c),h=u.getBucket(r);if(h){var f=i?h.collisionCircle:h.collisionBox;f&&s.draw(a,i?o.TRIANGLES:o.LINES,Tt.disabled,At.disabled,t.colorModeForRenderPass(),St.disabled,_r(c.posMatrix,t.transform,u),r.id,f.layoutVertexBuffer,f.indexBuffer,f.segments,null,t.transform.zoom,null,null,f.collisionVertexBuffer)}}}var qr=t.identity(new Float32Array(16));function Hr(e,r,n,i,a,o){var s=t.getAnchorAlignment(e),l=-(s.horizontalAlign-.5)*r,c=-(s.verticalAlign-.5)*n,u=t.evaluateRadialOffset(e,i);return new t.Point((l/a+u[0])*o,(c/a+u[1])*o)}function Gr(e,r,n,i,a,o,s,l,c,u){var h=e.text.placedSymbolArray,f=e.text.dynamicLayoutVertexArray;f.clear();for(var p=0;p<h.length;p++){var d=h.get(p),g=!d.hidden&&d.crossTileID?i[d.crossTileID]:null;if(g){var v=new t.Point(d.anchorX,d.anchorY),m=Zt(v,n?l:s),y=.5+o.cameraToCenterDistance/m.signedDistanceFromCamera*.5,x=a.evaluateSizeForFeature(e.textSizeData,u,d)*y/t.ONE_EM;n&&(x*=e.tilePixelRatio/c);for(var b=g.width,_=g.height,w=g.radialOffset,k=g.textBoxScale,T=Hr(g.anchor,b,_,w,k,x),A=n?Zt(v.add(T),s).point:m.point.add(r?T.rotate(-o.angle):T),M=0;M<d.numGlyphs;M++)t.addDynamicAttributes(f,A,0)}else ie(d.numGlyphs,f)}e.text.dynamicLayoutVertexBuffer.updateData(f)}function Yr(e,r,n,i,a,o,s,l,c,u,h,f,p){for(var d,g,v=e.context,m=v.gl,y=e.transform,x=\"map\"===l,b=\"map\"===c,_=x&&\"point\"!==n.layout.get(\"symbol-placement\"),w=x&&!b&&!_,k=void 0!==n.layout.get(\"symbol-sort-key\").constantOr(1),T=e.depthModeForSublayer(0,Tt.ReadOnly),A=n.layout.get(\"text-variable-anchor\"),M=[],S=0,E=i;S<E.length;S+=1){var C=E[S],L=r.getTile(C),P=L.getBucket(n);if(P){var O=a?P.text:P.icon;if(O&&O.segments.get().length){var z=O.programConfigurations.get(n.id),I=a||P.sdfIcons,D=a?P.textSizeData:P.iconSizeData;d||(d=e.useProgram(I?\"symbolSDF\":\"symbolIcon\",z),g=t.evaluateSizeForZoom(D,y.zoom)),v.activeTexture.set(m.TEXTURE0);var R=void 0,F=void 0,B=void 0;if(a)F=L.glyphAtlasTexture,B=m.LINEAR,R=L.glyphAtlasTexture.size;else{var N=1!==n.layout.get(\"icon-size\").constantOr(0)||P.iconsNeedLinear,j=b||0!==y.pitch;F=L.imageAtlasTexture,B=I||e.options.rotating||e.options.zooming||N||j?m.LINEAR:m.NEAREST,R=L.imageAtlasTexture.size}var U=le(L,1,e.transform.zoom),V=Wt(C.posMatrix,b,x,e.transform,U),q=Xt(C.posMatrix,b,x,e.transform,U);if(_)Kt(P,C.posMatrix,e,a,V,q,b,u);else if(a&&g&&A){var H=Math.pow(2,y.zoom-L.tileID.overscaledZ);Gr(P,x,b,p,t.symbolSize,y,V,C.posMatrix,H,g)}var G=e.translatePosMatrix(C.posMatrix,L,o,s),Y=_||a&&A?qr:V,W=e.translatePosMatrix(q,L,o,s,!0),X=I&&0!==n.paint.get(a?\"text-halo-width\":\"icon-halo-width\").constantOr(1),Z={program:d,buffers:O,uniformValues:I?Rr(D.kind,g,w,b,e,G,Y,W,a,R,!0):Dr(D.kind,g,w,b,e,G,Y,W,a,R),atlasTexture:F,atlasInterpolation:B,isSDF:I,hasHalo:X};if(k)for(var J=0,K=O.segments.get();J<K.length;J+=1){var $=K[J];M.push({segments:new t.SegmentVector([$]),sortKey:$.sortKey,state:Z})}else M.push({segments:O.segments,sortKey:0,state:Z})}}}k&&M.sort(function(t,e){return t.sortKey-e.sortKey});for(var Q=0,tt=M;Q<tt.length;Q+=1){var et=tt[Q],rt=et.state;if(rt.atlasTexture.bind(rt.atlasInterpolation,m.CLAMP_TO_EDGE),rt.isSDF){var nt=rt.uniformValues;rt.hasHalo&&(nt.u_is_halo=1,Wr(rt.buffers,et.segments,n,e,rt.program,T,h,f,nt)),nt.u_is_halo=0}Wr(rt.buffers,et.segments,n,e,rt.program,T,h,f,rt.uniformValues)}}function Wr(t,e,r,n,i,a,o,s,l){var c=n.context,u=c.gl;i.draw(c,u.TRIANGLES,a,o,s,St.disabled,l,r.id,t.layoutVertexBuffer,t.indexBuffer,e,r.paint,n.transform.zoom,t.programConfigurations.get(r.id),t.dynamicLayoutVertexBuffer,t.opacityVertexBuffer)}function Xr(t,e,r,n,i,a,o){var s,l,c,u,h,f=t.context.gl,p=r.paint.get(\"fill-pattern\"),d=p&&p.constantOr(1),g=r.getCrossfadeParameters();o?(l=d&&!r.getPaintProperty(\"fill-outline-color\")?\"fillOutlinePattern\":\"fillOutline\",s=f.LINES):(l=d?\"fillPattern\":\"fill\",s=f.TRIANGLES);for(var v=0,m=n;v<m.length;v+=1){var y=m[v],x=e.getTile(y);if(!d||x.patternsLoaded()){var b=x.getBucket(r);if(b){var _=b.programConfigurations.get(r.id),w=t.useProgram(l,_);d&&(t.context.activeTexture.set(f.TEXTURE0),x.imageAtlasTexture.bind(f.LINEAR,f.CLAMP_TO_EDGE),_.updatePatternPaintBuffers(g));var k=p.constantOr(null);if(k&&x.imageAtlas){var T=x.imageAtlas.patternPositions[k.to],A=x.imageAtlas.patternPositions[k.from];T&&A&&_.setConstantPatternPositions(T,A)}var M=t.translatePosMatrix(y.posMatrix,x,r.paint.get(\"fill-translate\"),r.paint.get(\"fill-translate-anchor\"));if(o){u=b.indexBuffer2,h=b.segments2;var S=[f.drawingBufferWidth,f.drawingBufferHeight];c=\"fillOutlinePattern\"===l&&d?yr(M,t,g,x,S):mr(M,S)}else u=b.indexBuffer,h=b.segments,c=d?vr(M,t,g,x):gr(M);w.draw(t.context,s,i,t.stencilModeForClipping(y),a,St.disabled,c,r.id,b.layoutVertexBuffer,u,h,r.paint,t.transform.zoom,_)}}}}function Zr(t,e,r,n,i,a,o){for(var s=t.context,l=s.gl,c=r.paint.get(\"fill-extrusion-pattern\"),u=c.constantOr(1),h=r.getCrossfadeParameters(),f=r.paint.get(\"fill-extrusion-opacity\"),p=0,d=n;p<d.length;p+=1){var g=d[p],v=e.getTile(g),m=v.getBucket(r);if(m){var y=m.programConfigurations.get(r.id),x=t.useProgram(u?\"fillExtrusionPattern\":\"fillExtrusion\",y);u&&(t.context.activeTexture.set(l.TEXTURE0),v.imageAtlasTexture.bind(l.LINEAR,l.CLAMP_TO_EDGE),y.updatePatternPaintBuffers(h));var b=c.constantOr(null);if(b&&v.imageAtlas){var _=v.imageAtlas.patternPositions[b.to],w=v.imageAtlas.patternPositions[b.from];_&&w&&y.setConstantPatternPositions(_,w)}var k=t.translatePosMatrix(g.posMatrix,v,r.paint.get(\"fill-extrusion-translate\"),r.paint.get(\"fill-extrusion-translate-anchor\")),T=r.paint.get(\"fill-extrusion-vertical-gradient\"),A=u?dr(k,t,T,f,g,h,v):pr(k,t,T,f);x.draw(s,s.gl.TRIANGLES,i,a,o,St.backCCW,A,r.id,m.layoutVertexBuffer,m.indexBuffer,m.segments,r.paint,t.transform.zoom,y)}}}function Jr(t,e,r,n,i,a){var o=t.context,s=o.gl,l=e.fbo;if(l){var c=t.useProgram(\"hillshade\");o.activeTexture.set(s.TEXTURE0),s.bindTexture(s.TEXTURE_2D,l.colorAttachment.get());var u=Ar(t,e,r);e.maskedBoundsBuffer&&e.maskedIndexBuffer&&e.segments?c.draw(o,s.TRIANGLES,n,i,a,St.disabled,u,r.id,e.maskedBoundsBuffer,e.maskedIndexBuffer,e.segments):c.draw(o,s.TRIANGLES,n,i,a,St.disabled,u,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}}function Kr(e,r,n,i,a,o,s){var l=e.context,c=l.gl;if(r.dem&&r.dem.data){var u=r.dem.dim,h=r.dem.stride,f=r.dem.getPixels();if(l.activeTexture.set(c.TEXTURE1),l.pixelStoreUnpackPremultiplyAlpha.set(!1),r.demTexture=r.demTexture||e.getTileTexture(h),r.demTexture){var p=r.demTexture;p.update(f,{premultiply:!1}),p.bind(c.NEAREST,c.CLAMP_TO_EDGE)}else r.demTexture=new t.Texture(l,f,c.RGBA,{premultiply:!1}),r.demTexture.bind(c.NEAREST,c.CLAMP_TO_EDGE);l.activeTexture.set(c.TEXTURE0);var d=r.fbo;if(!d){var g=new t.Texture(l,{width:u,height:u,data:null},c.RGBA);g.bind(c.LINEAR,c.CLAMP_TO_EDGE),(d=r.fbo=l.createFramebuffer(u,u)).colorAttachment.set(g.texture)}l.bindFramebuffer.set(d.framebuffer),l.viewport.set([0,0,u,u]),e.useProgram(\"hillshadePrepare\").draw(l,c.TRIANGLES,a,o,s,St.disabled,Mr(r,i),n.id,e.rasterBoundsBuffer,e.quadTriangleIndexBuffer,e.rasterBoundsSegments),r.needsHillshadePrepare=!1}}function $r(e,r,n,i,a){var o=i.paint.get(\"raster-fade-duration\");if(o>0){var s=t.browser.now(),l=(s-e.timeAdded)/o,c=r?(s-r.timeAdded)/o:-1,u=n.getSource(),h=a.coveringZoomLevel({tileSize:u.tileSize,roundZoom:u.roundZoom}),f=!r||Math.abs(r.tileID.overscaledZ-h)>Math.abs(e.tileID.overscaledZ-h),p=f&&e.refreshedUponExpiration?1:t.clamp(f?l:1-c,0,1);return e.refreshedUponExpiration&&l>=1&&(e.refreshedUponExpiration=!1),r?{opacity:1,mix:1-p}:{opacity:p,mix:0}}return{opacity:1,mix:0}}function Qr(e,r,n){var i=e.context,a=i.gl,o=n.posMatrix,s=e.useProgram(\"debug\"),l=Tt.disabled,c=At.disabled,u=e.colorModeForRenderPass(),h=\"$debug\";s.draw(i,a.LINE_STRIP,l,c,u,St.disabled,wr(o,t.Color.red),h,e.debugBuffer,e.tileBorderIndexBuffer,e.debugSegments);for(var f=r.getTileByID(n.key).latestRawTileData,p=f&&f.byteLength||0,d=Math.floor(p/1024),g=function(t,e,r,n){n=n||1;var i,a,o,s,l,c,u,h,f=[];for(i=0,a=t.length;i<a;i++)if(l=tn[t[i]]){for(h=null,o=0,s=l[1].length;o<s;o+=2)-1===l[1][o]&&-1===l[1][o+1]?h=null:(c=e+l[1][o]*n,u=200-l[1][o+1]*n,h&&f.push(h.x,h.y,c,u),h={x:c,y:u});e+=l[0]*n}return f}(n.toString()+\" \"+d+\"kb\",50,0,5),v=new t.StructArrayLayout2i4,m=new t.StructArrayLayout2ui4,y=0;y<g.length;y+=2)v.emplaceBack(g[y],g[y+1]),m.emplaceBack(y,y+1);for(var x=i.createVertexBuffer(v,Re.members),b=i.createIndexBuffer(m),_=t.SegmentVector.simpleSegment(0,0,v.length/2,v.length/2),w=r.getTile(n).tileSize,k=t.EXTENT/(Math.pow(2,e.transform.zoom-n.overscaledZ)*w),T=[[-1,-1],[-1,1],[1,-1],[1,1]],A=0;A<T.length;A++){var M=T[A];s.draw(i,a.LINES,l,c,u,St.disabled,wr(t.translate([],o,[k*M[0],k*M[1],0]),t.Color.white),h,x,b,_)}s.draw(i,a.LINES,l,c,u,St.disabled,wr(o,t.Color.black),h,x,b,_)}var tn={\" \":[16,[]],\"!\":[10,[5,21,5,7,-1,-1,5,2,4,1,5,0,6,1,5,2]],'\"':[16,[4,21,4,14,-1,-1,12,21,12,14]],\"#\":[21,[11,25,4,-7,-1,-1,17,25,10,-7,-1,-1,4,12,18,12,-1,-1,3,6,17,6]],$:[20,[8,25,8,-4,-1,-1,12,25,12,-4,-1,-1,17,18,15,20,12,21,8,21,5,20,3,18,3,16,4,14,5,13,7,12,13,10,15,9,16,8,17,6,17,3,15,1,12,0,8,0,5,1,3,3]],\"%\":[24,[21,21,3,0,-1,-1,8,21,10,19,10,17,9,15,7,14,5,14,3,16,3,18,4,20,6,21,8,21,10,20,13,19,16,19,19,20,21,21,-1,-1,17,7,15,6,14,4,14,2,16,0,18,0,20,1,21,3,21,5,19,7,17,7]],\"&\":[26,[23,12,23,13,22,14,21,14,20,13,19,11,17,6,15,3,13,1,11,0,7,0,5,1,4,2,3,4,3,6,4,8,5,9,12,13,13,14,14,16,14,18,13,20,11,21,9,20,8,18,8,16,9,13,11,10,16,3,18,1,20,0,22,0,23,1,23,2]],\"'\":[10,[5,19,4,20,5,21,6,20,6,18,5,16,4,15]],\"(\":[14,[11,25,9,23,7,20,5,16,4,11,4,7,5,2,7,-2,9,-5,11,-7]],\")\":[14,[3,25,5,23,7,20,9,16,10,11,10,7,9,2,7,-2,5,-5,3,-7]],\"*\":[16,[8,21,8,9,-1,-1,3,18,13,12,-1,-1,13,18,3,12]],\"+\":[26,[13,18,13,0,-1,-1,4,9,22,9]],\",\":[10,[6,1,5,0,4,1,5,2,6,1,6,-1,5,-3,4,-4]],\"-\":[26,[4,9,22,9]],\".\":[10,[5,2,4,1,5,0,6,1,5,2]],\"/\":[22,[20,25,2,-7]],0:[20,[9,21,6,20,4,17,3,12,3,9,4,4,6,1,9,0,11,0,14,1,16,4,17,9,17,12,16,17,14,20,11,21,9,21]],1:[20,[6,17,8,18,11,21,11,0]],2:[20,[4,16,4,17,5,19,6,20,8,21,12,21,14,20,15,19,16,17,16,15,15,13,13,10,3,0,17,0]],3:[20,[5,21,16,21,10,13,13,13,15,12,16,11,17,8,17,6,16,3,14,1,11,0,8,0,5,1,4,2,3,4]],4:[20,[13,21,3,7,18,7,-1,-1,13,21,13,0]],5:[20,[15,21,5,21,4,12,5,13,8,14,11,14,14,13,16,11,17,8,17,6,16,3,14,1,11,0,8,0,5,1,4,2,3,4]],6:[20,[16,18,15,20,12,21,10,21,7,20,5,17,4,12,4,7,5,3,7,1,10,0,11,0,14,1,16,3,17,6,17,7,16,10,14,12,11,13,10,13,7,12,5,10,4,7]],7:[20,[17,21,7,0,-1,-1,3,21,17,21]],8:[20,[8,21,5,20,4,18,4,16,5,14,7,13,11,12,14,11,16,9,17,7,17,4,16,2,15,1,12,0,8,0,5,1,4,2,3,4,3,7,4,9,6,11,9,12,13,13,15,14,16,16,16,18,15,20,12,21,8,21]],9:[20,[16,14,15,11,13,9,10,8,9,8,6,9,4,11,3,14,3,15,4,18,6,20,9,21,10,21,13,20,15,18,16,14,16,9,15,4,13,1,10,0,8,0,5,1,4,3]],\":\":[10,[5,14,4,13,5,12,6,13,5,14,-1,-1,5,2,4,1,5,0,6,1,5,2]],\";\":[10,[5,14,4,13,5,12,6,13,5,14,-1,-1,6,1,5,0,4,1,5,2,6,1,6,-1,5,-3,4,-4]],\"<\":[24,[20,18,4,9,20,0]],\"=\":[26,[4,12,22,12,-1,-1,4,6,22,6]],\">\":[24,[4,18,20,9,4,0]],\"?\":[18,[3,16,3,17,4,19,5,20,7,21,11,21,13,20,14,19,15,17,15,15,14,13,13,12,9,10,9,7,-1,-1,9,2,8,1,9,0,10,1,9,2]],\"@\":[27,[18,13,17,15,15,16,12,16,10,15,9,14,8,11,8,8,9,6,11,5,14,5,16,6,17,8,-1,-1,12,16,10,14,9,11,9,8,10,6,11,5,-1,-1,18,16,17,8,17,6,19,5,21,5,23,7,24,10,24,12,23,15,22,17,20,19,18,20,15,21,12,21,9,20,7,19,5,17,4,15,3,12,3,9,4,6,5,4,7,2,9,1,12,0,15,0,18,1,20,2,21,3,-1,-1,19,16,18,8,18,6,19,5]],A:[18,[9,21,1,0,-1,-1,9,21,17,0,-1,-1,4,7,14,7]],B:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,15,17,13,16,12,13,11,-1,-1,4,11,13,11,16,10,17,9,18,7,18,4,17,2,16,1,13,0,4,0]],C:[21,[18,16,17,18,15,20,13,21,9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5]],D:[21,[4,21,4,0,-1,-1,4,21,11,21,14,20,16,18,17,16,18,13,18,8,17,5,16,3,14,1,11,0,4,0]],E:[19,[4,21,4,0,-1,-1,4,21,17,21,-1,-1,4,11,12,11,-1,-1,4,0,17,0]],F:[18,[4,21,4,0,-1,-1,4,21,17,21,-1,-1,4,11,12,11]],G:[21,[18,16,17,18,15,20,13,21,9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,18,8,-1,-1,13,8,18,8]],H:[22,[4,21,4,0,-1,-1,18,21,18,0,-1,-1,4,11,18,11]],I:[8,[4,21,4,0]],J:[16,[12,21,12,5,11,2,10,1,8,0,6,0,4,1,3,2,2,5,2,7]],K:[21,[4,21,4,0,-1,-1,18,21,4,7,-1,-1,9,12,18,0]],L:[17,[4,21,4,0,-1,-1,4,0,16,0]],M:[24,[4,21,4,0,-1,-1,4,21,12,0,-1,-1,20,21,12,0,-1,-1,20,21,20,0]],N:[22,[4,21,4,0,-1,-1,4,21,18,0,-1,-1,18,21,18,0]],O:[22,[9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,19,8,19,13,18,16,17,18,15,20,13,21,9,21]],P:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,14,17,12,16,11,13,10,4,10]],Q:[22,[9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,19,8,19,13,18,16,17,18,15,20,13,21,9,21,-1,-1,12,4,18,-2]],R:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,15,17,13,16,12,13,11,4,11,-1,-1,11,11,18,0]],S:[20,[17,18,15,20,12,21,8,21,5,20,3,18,3,16,4,14,5,13,7,12,13,10,15,9,16,8,17,6,17,3,15,1,12,0,8,0,5,1,3,3]],T:[16,[8,21,8,0,-1,-1,1,21,15,21]],U:[22,[4,21,4,6,5,3,7,1,10,0,12,0,15,1,17,3,18,6,18,21]],V:[18,[1,21,9,0,-1,-1,17,21,9,0]],W:[24,[2,21,7,0,-1,-1,12,21,7,0,-1,-1,12,21,17,0,-1,-1,22,21,17,0]],X:[20,[3,21,17,0,-1,-1,17,21,3,0]],Y:[18,[1,21,9,11,9,0,-1,-1,17,21,9,11]],Z:[20,[17,21,3,0,-1,-1,3,21,17,21,-1,-1,3,0,17,0]],\"[\":[14,[4,25,4,-7,-1,-1,5,25,5,-7,-1,-1,4,25,11,25,-1,-1,4,-7,11,-7]],\"\\\\\":[14,[0,21,14,-3]],\"]\":[14,[9,25,9,-7,-1,-1,10,25,10,-7,-1,-1,3,25,10,25,-1,-1,3,-7,10,-7]],\"^\":[16,[6,15,8,18,10,15,-1,-1,3,12,8,17,13,12,-1,-1,8,17,8,0]],_:[16,[0,-2,16,-2]],\"`\":[10,[6,21,5,20,4,18,4,16,5,15,6,16,5,17]],a:[19,[15,14,15,0,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],b:[19,[4,21,4,0,-1,-1,4,11,6,13,8,14,11,14,13,13,15,11,16,8,16,6,15,3,13,1,11,0,8,0,6,1,4,3]],c:[18,[15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],d:[19,[15,21,15,0,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],e:[18,[3,8,15,8,15,10,14,12,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],f:[12,[10,21,8,21,6,20,5,17,5,0,-1,-1,2,14,9,14]],g:[19,[15,14,15,-2,14,-5,13,-6,11,-7,8,-7,6,-6,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],h:[19,[4,21,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0]],i:[8,[3,21,4,20,5,21,4,22,3,21,-1,-1,4,14,4,0]],j:[10,[5,21,6,20,7,21,6,22,5,21,-1,-1,6,14,6,-3,5,-6,3,-7,1,-7]],k:[17,[4,21,4,0,-1,-1,14,14,4,4,-1,-1,8,8,15,0]],l:[8,[4,21,4,0]],m:[30,[4,14,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0,-1,-1,15,10,18,13,20,14,23,14,25,13,26,10,26,0]],n:[19,[4,14,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0]],o:[19,[8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3,16,6,16,8,15,11,13,13,11,14,8,14]],p:[19,[4,14,4,-7,-1,-1,4,11,6,13,8,14,11,14,13,13,15,11,16,8,16,6,15,3,13,1,11,0,8,0,6,1,4,3]],q:[19,[15,14,15,-7,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],r:[13,[4,14,4,0,-1,-1,4,8,5,11,7,13,9,14,12,14]],s:[17,[14,11,13,13,10,14,7,14,4,13,3,11,4,9,6,8,11,7,13,6,14,4,14,3,13,1,10,0,7,0,4,1,3,3]],t:[12,[5,21,5,4,6,1,8,0,10,0,-1,-1,2,14,9,14]],u:[19,[4,14,4,4,5,1,7,0,10,0,12,1,15,4,-1,-1,15,14,15,0]],v:[16,[2,14,8,0,-1,-1,14,14,8,0]],w:[22,[3,14,7,0,-1,-1,11,14,7,0,-1,-1,11,14,15,0,-1,-1,19,14,15,0]],x:[17,[3,14,14,0,-1,-1,14,14,3,0]],y:[16,[2,14,8,0,-1,-1,14,14,8,0,6,-4,4,-6,2,-7,1,-7]],z:[17,[14,14,3,0,-1,-1,3,14,14,14,-1,-1,3,0,14,0]],\"{\":[14,[9,25,7,24,6,23,5,21,5,19,6,17,7,16,8,14,8,12,6,10,-1,-1,7,24,6,22,6,20,7,18,8,17,9,15,9,13,8,11,4,9,8,7,9,5,9,3,8,1,7,0,6,-2,6,-4,7,-6,-1,-1,6,8,8,6,8,4,7,2,6,1,5,-1,5,-3,6,-5,7,-6,9,-7]],\"|\":[8,[4,25,4,-7]],\"}\":[14,[5,25,7,24,8,23,9,21,9,19,8,17,7,16,6,14,6,12,8,10,-1,-1,7,24,8,22,8,20,7,18,6,17,5,15,5,13,6,11,10,9,6,7,5,5,5,3,6,1,7,0,8,-2,8,-4,7,-6,-1,-1,8,8,6,6,6,4,7,2,8,1,9,-1,9,-3,8,-5,7,-6,5,-7]],\"~\":[24,[3,6,3,8,4,11,6,12,8,12,10,11,14,8,16,7,18,7,20,8,21,10,-1,-1,3,8,4,10,6,11,8,11,10,10,14,7,16,6,18,6,20,7,21,10,21,12]]},en={symbol:function(t,e,r,n,i){if(\"translucent\"===t.renderPass){var a=At.disabled,o=t.colorModeForRenderPass();0!==r.paint.get(\"icon-opacity\").constantOr(1)&&Yr(t,e,r,n,!1,r.paint.get(\"icon-translate\"),r.paint.get(\"icon-translate-anchor\"),r.layout.get(\"icon-rotation-alignment\"),r.layout.get(\"icon-pitch-alignment\"),r.layout.get(\"icon-keep-upright\"),a,o,i),0!==r.paint.get(\"text-opacity\").constantOr(1)&&Yr(t,e,r,n,!0,r.paint.get(\"text-translate\"),r.paint.get(\"text-translate-anchor\"),r.layout.get(\"text-rotation-alignment\"),r.layout.get(\"text-pitch-alignment\"),r.layout.get(\"text-keep-upright\"),a,o,i),e.map.showCollisionBoxes&&function(t,e,r,n){Vr(t,e,r,n,!1),Vr(t,e,r,n,!0)}(t,e,r,n)}},circle:function(t,e,r,n){if(\"translucent\"===t.renderPass){var i=r.paint.get(\"circle-opacity\"),a=r.paint.get(\"circle-stroke-width\"),o=r.paint.get(\"circle-stroke-opacity\");if(0!==i.constantOr(1)||0!==a.constantOr(1)&&0!==o.constantOr(1))for(var s=t.context,l=s.gl,c=t.depthModeForSublayer(0,Tt.ReadOnly),u=At.disabled,h=t.colorModeForRenderPass(),f=0;f<n.length;f++){var p=n[f],d=e.getTile(p),g=d.getBucket(r);if(g){var v=g.programConfigurations.get(r.id);t.useProgram(\"circle\",v).draw(s,l.TRIANGLES,c,u,h,St.disabled,xr(t,p,d,r),r.id,g.layoutVertexBuffer,g.indexBuffer,g.segments,r.paint,t.transform.zoom,v)}}}},heatmap:function(e,r,n,i){if(0!==n.paint.get(\"heatmap-opacity\"))if(\"offscreen\"===e.renderPass){var a=e.context,o=a.gl,s=e.depthModeForSublayer(0,Tt.ReadOnly),l=At.disabled,c=new Mt([o.ONE,o.ONE],t.Color.transparent,[!0,!0,!0,!0]);!function(t,e,r){var n=t.gl;t.activeTexture.set(n.TEXTURE1),t.viewport.set([0,0,e.width/4,e.height/4]);var i=r.heatmapFbo;if(i)n.bindTexture(n.TEXTURE_2D,i.colorAttachment.get()),t.bindFramebuffer.set(i.framebuffer);else{var a=n.createTexture();n.bindTexture(n.TEXTURE_2D,a),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,n.LINEAR),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,n.LINEAR),i=r.heatmapFbo=t.createFramebuffer(e.width/4,e.height/4),function t(e,r,n,i){var a=e.gl;a.texImage2D(a.TEXTURE_2D,0,a.RGBA,r.width/4,r.height/4,0,a.RGBA,e.extTextureHalfFloat?e.extTextureHalfFloat.HALF_FLOAT_OES:a.UNSIGNED_BYTE,null),i.colorAttachment.set(n),e.extTextureHalfFloat&&a.checkFramebufferStatus(a.FRAMEBUFFER)!==a.FRAMEBUFFER_COMPLETE&&(e.extTextureHalfFloat=null,i.colorAttachment.setDirty(),t(e,r,n,i))}(t,e,a,i)}}(a,e,n),a.clear({color:t.Color.transparent});for(var u=0;u<i.length;u++){var h=i[u];if(!r.hasRenderableParent(h)){var f=r.getTile(h),p=f.getBucket(n);if(p){var d=p.programConfigurations.get(n.id),g=e.useProgram(\"heatmap\",d),v=e.transform.zoom;g.draw(a,o.TRIANGLES,s,l,c,St.disabled,Tr(h.posMatrix,f,v,n.paint.get(\"heatmap-intensity\")),n.id,p.layoutVertexBuffer,p.indexBuffer,p.segments,n.paint,e.transform.zoom,d)}}}a.viewport.set([0,0,e.width,e.height])}else\"translucent\"===e.renderPass&&(e.context.setColorMode(e.colorModeForRenderPass()),function(e,r){var n=e.context,i=n.gl,a=r.heatmapFbo;if(a){n.activeTexture.set(i.TEXTURE0),i.bindTexture(i.TEXTURE_2D,a.colorAttachment.get()),n.activeTexture.set(i.TEXTURE1);var o=r.colorRampTexture;o||(o=r.colorRampTexture=new t.Texture(n,r.colorRamp,i.RGBA)),o.bind(i.LINEAR,i.CLAMP_TO_EDGE),e.useProgram(\"heatmapTexture\").draw(n,i.TRIANGLES,Tt.disabled,At.disabled,e.colorModeForRenderPass(),St.disabled,function(e,r,n,i){var a=t.create();t.ortho(a,0,e.width,e.height,0,0,1);var o=e.context.gl;return{u_matrix:a,u_world:[o.drawingBufferWidth,o.drawingBufferHeight],u_image:n,u_color_ramp:i,u_opacity:r.paint.get(\"heatmap-opacity\")}}(e,r,0,1),r.id,e.viewportBuffer,e.quadTriangleIndexBuffer,e.viewportSegments,r.paint,e.transform.zoom)}}(e,n))},line:function(e,r,n,i){if(\"translucent\"===e.renderPass){var a=n.paint.get(\"line-opacity\"),o=n.paint.get(\"line-width\");if(0!==a.constantOr(1)&&0!==o.constantOr(1)){var s=e.depthModeForSublayer(0,Tt.ReadOnly),l=e.colorModeForRenderPass(),c=n.paint.get(\"line-dasharray\"),u=n.paint.get(\"line-pattern\"),h=u.constantOr(1),f=n.paint.get(\"line-gradient\"),p=n.getCrossfadeParameters(),d=c?\"lineSDF\":h?\"linePattern\":f?\"lineGradient\":\"line\",g=e.context,v=g.gl,m=!0;if(f){g.activeTexture.set(v.TEXTURE0);var y=n.gradientTexture;if(!n.gradient)return;y||(y=n.gradientTexture=new t.Texture(g,n.gradient,v.RGBA)),y.bind(v.LINEAR,v.CLAMP_TO_EDGE)}for(var x=0,b=i;x<b.length;x+=1){var _=b[x],w=r.getTile(_);if(!h||w.patternsLoaded()){var k=w.getBucket(n);if(k){var T=k.programConfigurations.get(n.id),A=e.context.program.get(),M=e.useProgram(d,T),S=m||M.program!==A,E=u.constantOr(null);if(E&&w.imageAtlas){var C=w.imageAtlas.patternPositions[E.to],L=w.imageAtlas.patternPositions[E.from];C&&L&&T.setConstantPatternPositions(C,L)}var P=c?Pr(e,w,n,c,p):h?Lr(e,w,n,p):f?Cr(e,w,n):Er(e,w,n);c&&(S||e.lineAtlas.dirty)?(g.activeTexture.set(v.TEXTURE0),e.lineAtlas.bind(g)):h&&(g.activeTexture.set(v.TEXTURE0),w.imageAtlasTexture.bind(v.LINEAR,v.CLAMP_TO_EDGE),T.updatePatternPaintBuffers(p)),M.draw(g,v.TRIANGLES,s,e.stencilModeForClipping(_),l,St.disabled,P,n.id,k.layoutVertexBuffer,k.indexBuffer,k.segments,n.paint,e.transform.zoom,T),m=!1}}}}}},fill:function(e,r,n,i){var a=n.paint.get(\"fill-color\"),o=n.paint.get(\"fill-opacity\");if(0!==o.constantOr(1)){var s=e.colorModeForRenderPass(),l=n.paint.get(\"fill-pattern\"),c=e.opaquePassEnabledForLayer()&&!l.constantOr(1)&&1===a.constantOr(t.Color.transparent).a&&1===o.constantOr(0)?\"opaque\":\"translucent\";if(e.renderPass===c){var u=e.depthModeForSublayer(1,\"opaque\"===e.renderPass?Tt.ReadWrite:Tt.ReadOnly);Xr(e,r,n,i,u,s,!1)}if(\"translucent\"===e.renderPass&&n.paint.get(\"fill-antialias\")){var h=e.depthModeForSublayer(n.getPaintProperty(\"fill-outline-color\")?2:0,Tt.ReadOnly);Xr(e,r,n,i,h,s,!0)}}},\"fill-extrusion\":function(t,e,r,n){var i=r.paint.get(\"fill-extrusion-opacity\");if(0!==i&&\"translucent\"===t.renderPass){var a=new Tt(t.context.gl.LEQUAL,Tt.ReadWrite,t.depthRangeFor3D);if(1!==i||r.paint.get(\"fill-extrusion-pattern\").constantOr(1))Zr(t,e,r,n,a,At.disabled,Mt.disabled),Zr(t,e,r,n,a,t.stencilModeFor3D(),t.colorModeForRenderPass());else{var o=t.colorModeForRenderPass();Zr(t,e,r,n,a,At.disabled,o)}}},hillshade:function(t,e,r,n){if(\"offscreen\"===t.renderPass||\"translucent\"===t.renderPass){for(var i=t.context,a=e.getSource().maxzoom,o=t.depthModeForSublayer(0,Tt.ReadOnly),s=At.disabled,l=t.colorModeForRenderPass(),c=0,u=n;c<u.length;c+=1){var h=u[c],f=e.getTile(h);f.needsHillshadePrepare&&\"offscreen\"===t.renderPass?Kr(t,f,r,a,o,s,l):\"translucent\"===t.renderPass&&Jr(t,f,r,o,s,l)}i.viewport.set([0,0,t.width,t.height])}},raster:function(t,e,r,n){if(\"translucent\"===t.renderPass&&0!==r.paint.get(\"raster-opacity\"))for(var i=t.context,a=i.gl,o=e.getSource(),s=t.useProgram(\"raster\"),l=At.disabled,c=t.colorModeForRenderPass(),u=n.length&&n[0].overscaledZ,h=!t.options.moving,f=0,p=n;f<p.length;f+=1){var d=p[f],g=t.depthModeForSublayer(d.overscaledZ-u,1===r.paint.get(\"raster-opacity\")?Tt.ReadWrite:Tt.ReadOnly,a.LESS),v=e.getTile(d),m=t.transform.calculatePosMatrix(d.toUnwrapped(),h);v.registerFadeDuration(r.paint.get(\"raster-fade-duration\"));var y=e.findLoadedParent(d,0),x=$r(v,y,e,r,t.transform),b=void 0,_=void 0,w=\"nearest\"===r.paint.get(\"raster-resampling\")?a.NEAREST:a.LINEAR;i.activeTexture.set(a.TEXTURE0),v.texture.bind(w,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),i.activeTexture.set(a.TEXTURE1),y?(y.texture.bind(w,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),b=Math.pow(2,y.tileID.overscaledZ-v.tileID.overscaledZ),_=[v.tileID.canonical.x*b%1,v.tileID.canonical.y*b%1]):v.texture.bind(w,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST);var k=Ir(m,_||[0,0],b||1,x,r);o instanceof L?s.draw(i,a.TRIANGLES,g,l,c,St.disabled,k,r.id,o.boundsBuffer,t.quadTriangleIndexBuffer,o.boundsSegments):v.maskedBoundsBuffer&&v.maskedIndexBuffer&&v.segments?s.draw(i,a.TRIANGLES,g,l,c,St.disabled,k,r.id,v.maskedBoundsBuffer,v.maskedIndexBuffer,v.segments,r.paint,t.transform.zoom):s.draw(i,a.TRIANGLES,g,l,c,St.disabled,k,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}},background:function(t,e,r){var n=r.paint.get(\"background-color\"),i=r.paint.get(\"background-opacity\");if(0!==i){var a=t.context,o=a.gl,s=t.transform,l=s.tileSize,c=r.paint.get(\"background-pattern\");if(!t.isPatternMissing(c)){var u=c||1!==n.a||1!==i?\"translucent\":\"opaque\";if(t.renderPass===u){var h=At.disabled,f=t.depthModeForSublayer(0,\"opaque\"===u?Tt.ReadWrite:Tt.ReadOnly),p=t.colorModeForRenderPass(),d=t.useProgram(c?\"backgroundPattern\":\"background\"),g=s.coveringTiles({tileSize:l});c&&(a.activeTexture.set(o.TEXTURE0),t.imageManager.bind(t.context));for(var v=r.getCrossfadeParameters(),m=0,y=g;m<y.length;m+=1){var x=y[m],b=t.transform.calculatePosMatrix(x.toUnwrapped()),_=c?Br(b,i,t,c,{tileID:x,tileSize:l},v):Fr(b,i,n);d.draw(a,o.TRIANGLES,f,h,p,St.disabled,_,r.id,t.tileExtentBuffer,t.quadTriangleIndexBuffer,t.tileExtentSegments)}}}}},debug:function(t,e,r){for(var n=0;n<r.length;n++)Qr(t,e,r[n])},custom:function(t,e,r){var n=t.context,i=r.implementation;if(\"offscreen\"===t.renderPass){var a=i.prerender;a&&(t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),a.call(i,n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState())}else if(\"translucent\"===t.renderPass){t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),n.setStencilMode(At.disabled);var o=\"3d\"===i.renderingMode?new Tt(t.context.gl.LEQUAL,Tt.ReadWrite,t.depthRangeFor3D):t.depthModeForSublayer(0,Tt.ReadOnly);n.setDepthMode(o),i.render(n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState(),n.bindFramebuffer.set(null)}}},rn=function(e,r){this.context=new Et(e),this.transform=r,this._tileTextures={},this.setup(),this.numSublayers=Ct.maxUnderzooming+Ct.maxOverzooming+1,this.depthEpsilon=1/Math.pow(2,16),this.depthRboNeedsClear=!0,this.emptyProgramConfiguration=new t.ProgramConfiguration,this.crossTileSymbolIndex=new Pe};function nn(t,e){if(t.y>e.y){var r=t;t=e,e=r}return{x0:t.x,y0:t.y,x1:e.x,y1:e.y,dx:e.x-t.x,dy:e.y-t.y}}function an(t,e,r,n,i){var a=Math.max(r,Math.floor(e.y0)),o=Math.min(n,Math.ceil(e.y1));if(t.x0===e.x0&&t.y0===e.y0?t.x0+e.dy/t.dy*t.dx<e.x1:t.x1-e.dy/t.dy*t.dx<e.x0){var s=t;t=e,e=s}for(var l=t.dx/t.dy,c=e.dx/e.dy,u=t.dx>0,h=e.dx<0,f=a;f<o;f++){var p=l*Math.max(0,Math.min(t.dy,f+u-t.y0))+t.x0,d=c*Math.max(0,Math.min(e.dy,f+h-e.y0))+e.x0;i(Math.floor(d),Math.ceil(p),f)}}function on(t,e,r,n,i,a){var o,s=nn(t,e),l=nn(e,r),c=nn(r,t);s.dy>l.dy&&(o=s,s=l,l=o),s.dy>c.dy&&(o=s,s=c,c=o),l.dy>c.dy&&(o=l,l=c,c=o),s.dy&&an(c,s,n,i,a),l.dy&&an(c,l,n,i,a)}rn.prototype.resize=function(e,r){var n=this.context.gl;if(this.width=e*t.browser.devicePixelRatio,this.height=r*t.browser.devicePixelRatio,this.context.viewport.set([0,0,this.width,this.height]),this.style)for(var i=0,a=this.style._order;i<a.length;i+=1){var o=a[i];this.style._layers[o].resize()}this.depthRbo&&(n.deleteRenderbuffer(this.depthRbo),this.depthRbo=null)},rn.prototype.setup=function(){var e=this.context,r=new t.StructArrayLayout2i4;r.emplaceBack(0,0),r.emplaceBack(t.EXTENT,0),r.emplaceBack(0,t.EXTENT),r.emplaceBack(t.EXTENT,t.EXTENT),this.tileExtentBuffer=e.createVertexBuffer(r,Re.members),this.tileExtentSegments=t.SegmentVector.simpleSegment(0,0,4,2);var n=new t.StructArrayLayout2i4;n.emplaceBack(0,0),n.emplaceBack(t.EXTENT,0),n.emplaceBack(0,t.EXTENT),n.emplaceBack(t.EXTENT,t.EXTENT),this.debugBuffer=e.createVertexBuffer(n,Re.members),this.debugSegments=t.SegmentVector.simpleSegment(0,0,4,5);var i=new t.StructArrayLayout4i8;i.emplaceBack(0,0,0,0),i.emplaceBack(t.EXTENT,0,t.EXTENT,0),i.emplaceBack(0,t.EXTENT,0,t.EXTENT),i.emplaceBack(t.EXTENT,t.EXTENT,t.EXTENT,t.EXTENT),this.rasterBoundsBuffer=e.createVertexBuffer(i,t.rasterBoundsAttributes.members),this.rasterBoundsSegments=t.SegmentVector.simpleSegment(0,0,4,2);var a=new t.StructArrayLayout2i4;a.emplaceBack(0,0),a.emplaceBack(1,0),a.emplaceBack(0,1),a.emplaceBack(1,1),this.viewportBuffer=e.createVertexBuffer(a,Re.members),this.viewportSegments=t.SegmentVector.simpleSegment(0,0,4,2);var o=new t.StructArrayLayout1ui2;o.emplaceBack(0),o.emplaceBack(1),o.emplaceBack(3),o.emplaceBack(2),o.emplaceBack(0),this.tileBorderIndexBuffer=e.createIndexBuffer(o);var s=new t.StructArrayLayout3ui6;s.emplaceBack(0,1,2),s.emplaceBack(2,1,3),this.quadTriangleIndexBuffer=e.createIndexBuffer(s);var l=this.context.gl;this.stencilClearMode=new At({func:l.ALWAYS,mask:0},0,255,l.ZERO,l.ZERO,l.ZERO)},rn.prototype.clearStencil=function(){var e=this.context,r=e.gl;this.nextStencilID=1,this.currentStencilSource=void 0;var n=t.create();t.ortho(n,0,this.width,this.height,0,0,1),t.scale(n,n,[r.drawingBufferWidth,r.drawingBufferHeight,0]),this.useProgram(\"clippingMask\").draw(e,r.TRIANGLES,Tt.disabled,this.stencilClearMode,Mt.disabled,St.disabled,kr(n),\"$clipping\",this.viewportBuffer,this.quadTriangleIndexBuffer,this.viewportSegments)},rn.prototype._renderTileClippingMasks=function(t,e){if(this.currentStencilSource!==t.source&&t.isTileClipped()&&e&&e.length){this.currentStencilSource=t.source;var r=this.context,n=r.gl;this.nextStencilID+e.length>256&&this.clearStencil(),r.setColorMode(Mt.disabled),r.setDepthMode(Tt.disabled);var i=this.useProgram(\"clippingMask\");this._tileClippingMaskIDs={};for(var a=0,o=e;a<o.length;a+=1){var s=o[a],l=this._tileClippingMaskIDs[s.key]=this.nextStencilID++;i.draw(r,n.TRIANGLES,Tt.disabled,new At({func:n.ALWAYS,mask:0},l,255,n.KEEP,n.KEEP,n.REPLACE),Mt.disabled,St.disabled,kr(s.posMatrix),\"$clipping\",this.tileExtentBuffer,this.quadTriangleIndexBuffer,this.tileExtentSegments)}}},rn.prototype.stencilModeFor3D=function(){this.nextStencilID+1>256&&this.clearStencil();var t=this.nextStencilID++,e=this.context.gl;return new At({func:e.NOTEQUAL,mask:255},t,255,e.KEEP,e.KEEP,e.REPLACE)},rn.prototype.stencilModeForClipping=function(t){var e=this.context.gl;return new At({func:e.EQUAL,mask:255},this._tileClippingMaskIDs[t.key],0,e.KEEP,e.KEEP,e.REPLACE)},rn.prototype.colorModeForRenderPass=function(){var e=this.context.gl;return this._showOverdrawInspector?new Mt([e.CONSTANT_COLOR,e.ONE],new t.Color(1/8,1/8,1/8,0),[!0,!0,!0,!0]):\"opaque\"===this.renderPass?Mt.unblended:Mt.alphaBlended},rn.prototype.depthModeForSublayer=function(t,e,r){if(!this.opaquePassEnabledForLayer())return Tt.disabled;var n=1-((1+this.currentLayer)*this.numSublayers+t)*this.depthEpsilon;return new Tt(r||this.context.gl.LEQUAL,e,[n,n])},rn.prototype.opaquePassEnabledForLayer=function(){return this.currentLayer<this.opaquePassCutoff},rn.prototype.render=function(e,r){this.style=e,this.options=r,this.lineAtlas=e.lineAtlas,this.imageManager=e.imageManager,this.glyphManager=e.glyphManager,this.symbolFadeChange=e.placement.symbolFadeChange(t.browser.now()),this.imageManager.beginFrame();var n=this.style._order,i=this.style.sourceCaches;for(var a in i){var o=i[a];o.used&&o.prepare(this.context)}var s={},l={},c={};for(var u in i){var h=i[u];s[u]=h.getVisibleCoordinates(),l[u]=s[u].slice().reverse(),c[u]=h.getVisibleCoordinates(!0).reverse()}for(var f in i){var p=i[f],d=p.getSource();if(\"raster\"===d.type||\"raster-dem\"===d.type){for(var g=[],v=0,m=s[f];v<m.length;v+=1){var y=m[v];g.push(p.getTile(y))}jr(g,this.context)}}this.opaquePassCutoff=1/0;for(var x=0;x<n.length;x++){var b=n[x];if(this.style._layers[b].is3D()){this.opaquePassCutoff=x;break}}this.renderPass=\"offscreen\",this.depthRboNeedsClear=!0;for(var _=0,w=n;_<w.length;_+=1){var k=w[_],T=this.style._layers[k];if(T.hasOffscreenPass()&&!T.isHidden(this.transform.zoom)){var A=l[T.source];(\"custom\"===T.type||A.length)&&this.renderLayer(this,i[T.source],T,A)}}for(this.context.bindFramebuffer.set(null),this.context.clear({color:r.showOverdrawInspector?t.Color.black:t.Color.transparent,depth:1}),this.clearStencil(),this._showOverdrawInspector=r.showOverdrawInspector,this.depthRangeFor3D=[0,1-(e._order.length+2)*this.numSublayers*this.depthEpsilon],this.renderPass=\"opaque\",this.currentLayer=n.length-1;this.currentLayer>=0;this.currentLayer--){var M=this.style._layers[n[this.currentLayer]],S=i[M.source],E=s[M.source];this._renderTileClippingMasks(M,E),this.renderLayer(this,S,M,E)}for(this.renderPass=\"translucent\",this.currentLayer=0;this.currentLayer<n.length;this.currentLayer++){var C=this.style._layers[n[this.currentLayer]],L=i[C.source],P=(\"symbol\"===C.type?c:l)[C.source];this._renderTileClippingMasks(C,s[C.source]),this.renderLayer(this,L,C,P)}if(this.options.showTileBoundaries)for(var O in i){en.debug(this,i[O],s[O]);break}this.context.setDefault()},rn.prototype.setupOffscreenDepthRenderbuffer=function(){var t=this.context;this.depthRbo||(this.depthRbo=t.createRenderbuffer(t.gl.DEPTH_COMPONENT16,this.width,this.height))},rn.prototype.renderLayer=function(t,e,r,n){r.isHidden(this.transform.zoom)||(\"background\"===r.type||\"custom\"===r.type||n.length)&&(this.id=r.id,en[r.type](t,e,r,n,this.style.placement.variableOffsets))},rn.prototype.translatePosMatrix=function(e,r,n,i,a){if(!n[0]&&!n[1])return e;var o=a?\"map\"===i?this.transform.angle:0:\"viewport\"===i?-this.transform.angle:0;if(o){var s=Math.sin(o),l=Math.cos(o);n=[n[0]*l-n[1]*s,n[0]*s+n[1]*l]}var c=[a?n[0]:le(r,n[0],this.transform.zoom),a?n[1]:le(r,n[1],this.transform.zoom),0],u=new Float32Array(16);return t.translate(u,e,c),u},rn.prototype.saveTileTexture=function(t){var e=this._tileTextures[t.size[0]];e?e.push(t):this._tileTextures[t.size[0]]=[t]},rn.prototype.getTileTexture=function(t){var e=this._tileTextures[t];return e&&e.length>0?e.pop():null},rn.prototype.isPatternMissing=function(t){if(!t)return!1;var e=this.imageManager.getPattern(t.from),r=this.imageManager.getPattern(t.to);return!e||!r},rn.prototype.useProgram=function(t,e){void 0===e&&(e=this.emptyProgramConfiguration),this.cache=this.cache||{};var r=\"\"+t+(e.cacheKey||\"\")+(this._showOverdrawInspector?\"/overdraw\":\"\");return this.cache[r]||(this.cache[r]=new hr(this.context,cr[t],e,Nr[t],this._showOverdrawInspector)),this.cache[r]},rn.prototype.setCustomLayerDefaults=function(){this.context.unbindVAO(),this.context.cullFace.setDefault(),this.context.activeTexture.setDefault(),this.context.pixelStoreUnpack.setDefault(),this.context.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.context.pixelStoreUnpackFlipY.setDefault()},rn.prototype.setBaseState=function(){var t=this.context.gl;this.context.cullFace.set(!1),this.context.viewport.set([0,0,this.width,this.height]),this.context.blendEquation.set(t.FUNC_ADD)};var sn=function(e,r,n){this.tileSize=512,this.maxValidLatitude=85.051129,this._renderWorldCopies=void 0===n||n,this._minZoom=e||0,this._maxZoom=r||22,this.setMaxBounds(),this.width=0,this.height=0,this._center=new t.LngLat(0,0),this.zoom=0,this.angle=0,this._fov=.6435011087932844,this._pitch=0,this._unmodified=!0,this._posMatrixCache={},this._alignedPosMatrixCache={}},ln={minZoom:{configurable:!0},maxZoom:{configurable:!0},renderWorldCopies:{configurable:!0},worldSize:{configurable:!0},centerPoint:{configurable:!0},size:{configurable:!0},bearing:{configurable:!0},pitch:{configurable:!0},fov:{configurable:!0},zoom:{configurable:!0},center:{configurable:!0},unmodified:{configurable:!0},point:{configurable:!0}};sn.prototype.clone=function(){var t=new sn(this._minZoom,this._maxZoom,this._renderWorldCopies);return t.tileSize=this.tileSize,t.latRange=this.latRange,t.width=this.width,t.height=this.height,t._center=this._center,t.zoom=this.zoom,t.angle=this.angle,t._fov=this._fov,t._pitch=this._pitch,t._unmodified=this._unmodified,t._calcMatrices(),t},ln.minZoom.get=function(){return this._minZoom},ln.minZoom.set=function(t){this._minZoom!==t&&(this._minZoom=t,this.zoom=Math.max(this.zoom,t))},ln.maxZoom.get=function(){return this._maxZoom},ln.maxZoom.set=function(t){this._maxZoom!==t&&(this._maxZoom=t,this.zoom=Math.min(this.zoom,t))},ln.renderWorldCopies.get=function(){return this._renderWorldCopies},ln.renderWorldCopies.set=function(t){void 0===t?t=!0:null===t&&(t=!1),this._renderWorldCopies=t},ln.worldSize.get=function(){return this.tileSize*this.scale},ln.centerPoint.get=function(){return this.size._div(2)},ln.size.get=function(){return new t.Point(this.width,this.height)},ln.bearing.get=function(){return-this.angle/Math.PI*180},ln.bearing.set=function(e){var r=-t.wrap(e,-180,180)*Math.PI/180;this.angle!==r&&(this._unmodified=!1,this.angle=r,this._calcMatrices(),this.rotationMatrix=t.create$2(),t.rotate(this.rotationMatrix,this.rotationMatrix,this.angle))},ln.pitch.get=function(){return this._pitch/Math.PI*180},ln.pitch.set=function(e){var r=t.clamp(e,0,60)/180*Math.PI;this._pitch!==r&&(this._unmodified=!1,this._pitch=r,this._calcMatrices())},ln.fov.get=function(){return this._fov/Math.PI*180},ln.fov.set=function(t){t=Math.max(.01,Math.min(60,t)),this._fov!==t&&(this._unmodified=!1,this._fov=t/180*Math.PI,this._calcMatrices())},ln.zoom.get=function(){return this._zoom},ln.zoom.set=function(t){var e=Math.min(Math.max(t,this.minZoom),this.maxZoom);this._zoom!==e&&(this._unmodified=!1,this._zoom=e,this.scale=this.zoomScale(e),this.tileZoom=Math.floor(e),this.zoomFraction=e-this.tileZoom,this._constrain(),this._calcMatrices())},ln.center.get=function(){return this._center},ln.center.set=function(t){t.lat===this._center.lat&&t.lng===this._center.lng||(this._unmodified=!1,this._center=t,this._constrain(),this._calcMatrices())},sn.prototype.coveringZoomLevel=function(t){return(t.roundZoom?Math.round:Math.floor)(this.zoom+this.scaleZoom(this.tileSize/t.tileSize))},sn.prototype.getVisibleUnwrappedCoordinates=function(e){var r=[new t.UnwrappedTileID(0,e)];if(this._renderWorldCopies)for(var n=this.pointCoordinate(new t.Point(0,0)),i=this.pointCoordinate(new t.Point(this.width,0)),a=this.pointCoordinate(new t.Point(this.width,this.height)),o=this.pointCoordinate(new t.Point(0,this.height)),s=Math.floor(Math.min(n.x,i.x,a.x,o.x)),l=Math.floor(Math.max(n.x,i.x,a.x,o.x)),c=s-1;c<=l+1;c++)0!==c&&r.push(new t.UnwrappedTileID(c,e));return r},sn.prototype.coveringTiles=function(e){var r=this.coveringZoomLevel(e),n=r;if(void 0!==e.minzoom&&r<e.minzoom)return[];void 0!==e.maxzoom&&r>e.maxzoom&&(r=e.maxzoom);var i=t.MercatorCoordinate.fromLngLat(this.center),a=Math.pow(2,r),o=new t.Point(a*i.x-.5,a*i.y-.5);return function(e,r,n,i){void 0===i&&(i=!0);var a=1<<e,o={};function s(r,s,l){var c,u,h,f;if(l>=0&&l<=a)for(c=r;c<s;c++)u=Math.floor(c/a),h=(c%a+a)%a,0!==u&&!0!==i||(f=new t.OverscaledTileID(n,u,e,h,l),o[f.key]=f)}var l=r.map(function(e){return new t.Point(e.x,e.y)._mult(a)});return on(l[0],l[1],l[2],0,a,s),on(l[2],l[3],l[0],0,a,s),Object.keys(o).map(function(t){return o[t]})}(r,[this.pointCoordinate(new t.Point(0,0)),this.pointCoordinate(new t.Point(this.width,0)),this.pointCoordinate(new t.Point(this.width,this.height)),this.pointCoordinate(new t.Point(0,this.height))],e.reparseOverscaled?n:r,this._renderWorldCopies).sort(function(t,e){return o.dist(t.canonical)-o.dist(e.canonical)})},sn.prototype.resize=function(t,e){this.width=t,this.height=e,this.pixelsToGLUnits=[2/t,-2/e],this._constrain(),this._calcMatrices()},ln.unmodified.get=function(){return this._unmodified},sn.prototype.zoomScale=function(t){return Math.pow(2,t)},sn.prototype.scaleZoom=function(t){return Math.log(t)/Math.LN2},sn.prototype.project=function(e){var r=t.clamp(e.lat,-this.maxValidLatitude,this.maxValidLatitude);return new t.Point(t.mercatorXfromLng(e.lng)*this.worldSize,t.mercatorYfromLat(r)*this.worldSize)},sn.prototype.unproject=function(e){return new t.MercatorCoordinate(e.x/this.worldSize,e.y/this.worldSize).toLngLat()},ln.point.get=function(){return this.project(this.center)},sn.prototype.setLocationAtPoint=function(e,r){var n=this.pointCoordinate(r),i=this.pointCoordinate(this.centerPoint),a=this.locationCoordinate(e),o=new t.MercatorCoordinate(a.x-(n.x-i.x),a.y-(n.y-i.y));this.center=this.coordinateLocation(o),this._renderWorldCopies&&(this.center=this.center.wrap())},sn.prototype.locationPoint=function(t){return this.coordinatePoint(this.locationCoordinate(t))},sn.prototype.pointLocation=function(t){return this.coordinateLocation(this.pointCoordinate(t))},sn.prototype.locationCoordinate=function(e){return t.MercatorCoordinate.fromLngLat(e)},sn.prototype.coordinateLocation=function(t){return t.toLngLat()},sn.prototype.pointCoordinate=function(e){var r=[e.x,e.y,0,1],n=[e.x,e.y,1,1];t.transformMat4(r,r,this.pixelMatrixInverse),t.transformMat4(n,n,this.pixelMatrixInverse);var i=r[3],a=n[3],o=r[0]/i,s=n[0]/a,l=r[1]/i,c=n[1]/a,u=r[2]/i,h=n[2]/a,f=u===h?0:(0-u)/(h-u);return new t.MercatorCoordinate(t.number(o,s,f)/this.worldSize,t.number(l,c,f)/this.worldSize)},sn.prototype.coordinatePoint=function(e){var r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix),new t.Point(r[0]/r[3],r[1]/r[3])},sn.prototype.getBounds=function(){return(new t.LngLatBounds).extend(this.pointLocation(new t.Point(0,0))).extend(this.pointLocation(new t.Point(this.width,0))).extend(this.pointLocation(new t.Point(this.width,this.height))).extend(this.pointLocation(new t.Point(0,this.height)))},sn.prototype.getMaxBounds=function(){return this.latRange&&2===this.latRange.length&&this.lngRange&&2===this.lngRange.length?new t.LngLatBounds([this.lngRange[0],this.latRange[0]],[this.lngRange[1],this.latRange[1]]):null},sn.prototype.setMaxBounds=function(t){t?(this.lngRange=[t.getWest(),t.getEast()],this.latRange=[t.getSouth(),t.getNorth()],this._constrain()):(this.lngRange=null,this.latRange=[-this.maxValidLatitude,this.maxValidLatitude])},sn.prototype.calculatePosMatrix=function(e,r){void 0===r&&(r=!1);var n=e.key,i=r?this._alignedPosMatrixCache:this._posMatrixCache;if(i[n])return i[n];var a=e.canonical,o=this.worldSize/this.zoomScale(a.z),s=a.x+Math.pow(2,a.z)*e.wrap,l=t.identity(new Float64Array(16));return t.translate(l,l,[s*o,a.y*o,0]),t.scale(l,l,[o/t.EXTENT,o/t.EXTENT,1]),t.multiply(l,r?this.alignedProjMatrix:this.projMatrix,l),i[n]=new Float32Array(l),i[n]},sn.prototype.customLayerMatrix=function(){return this.mercatorMatrix.slice()},sn.prototype._constrain=function(){if(this.center&&this.width&&this.height&&!this._constraining){this._constraining=!0;var e,r,n,i,a=-90,o=90,s=-180,l=180,c=this.size,u=this._unmodified;if(this.latRange){var h=this.latRange;a=t.mercatorYfromLat(h[1])*this.worldSize,e=(o=t.mercatorYfromLat(h[0])*this.worldSize)-a<c.y?c.y/(o-a):0}if(this.lngRange){var f=this.lngRange;s=t.mercatorXfromLng(f[0])*this.worldSize,r=(l=t.mercatorXfromLng(f[1])*this.worldSize)-s<c.x?c.x/(l-s):0}var p=this.point,d=Math.max(r||0,e||0);if(d)return this.center=this.unproject(new t.Point(r?(l+s)/2:p.x,e?(o+a)/2:p.y)),this.zoom+=this.scaleZoom(d),this._unmodified=u,void(this._constraining=!1);if(this.latRange){var g=p.y,v=c.y/2;g-v<a&&(i=a+v),g+v>o&&(i=o-v)}if(this.lngRange){var m=p.x,y=c.x/2;m-y<s&&(n=s+y),m+y>l&&(n=l-y)}void 0===n&&void 0===i||(this.center=this.unproject(new t.Point(void 0!==n?n:p.x,void 0!==i?i:p.y))),this._unmodified=u,this._constraining=!1}},sn.prototype._calcMatrices=function(){if(this.height){this.cameraToCenterDistance=.5/Math.tan(this._fov/2)*this.height;var e=this._fov/2,r=Math.PI/2+this._pitch,n=Math.sin(e)*this.cameraToCenterDistance/Math.sin(Math.PI-r-e),i=this.point,a=i.x,o=i.y,s=1.01*(Math.cos(Math.PI/2-this._pitch)*n+this.cameraToCenterDistance),l=new Float64Array(16);t.perspective(l,this._fov,this.width/this.height,1,s),t.scale(l,l,[1,-1,1]),t.translate(l,l,[0,0,-this.cameraToCenterDistance]),t.rotateX(l,l,this._pitch),t.rotateZ(l,l,this.angle),t.translate(l,l,[-a,-o,0]),this.mercatorMatrix=t.scale([],l,[this.worldSize,this.worldSize,this.worldSize]),t.scale(l,l,[1,1,t.mercatorZfromAltitude(1,this.center.lat)*this.worldSize,1]),this.projMatrix=l;var c=this.width%2/2,u=this.height%2/2,h=Math.cos(this.angle),f=Math.sin(this.angle),p=a-Math.round(a)+h*c+f*u,d=o-Math.round(o)+h*u+f*c,g=new Float64Array(l);if(t.translate(g,g,[p>.5?p-1:p,d>.5?d-1:d,0]),this.alignedProjMatrix=g,l=t.create(),t.scale(l,l,[this.width/2,-this.height/2,1]),t.translate(l,l,[1,-1,0]),this.labelPlaneMatrix=l,l=t.create(),t.scale(l,l,[1,-1,1]),t.translate(l,l,[-1,-1,0]),t.scale(l,l,[2/this.width,2/this.height,1]),this.glCoordMatrix=l,this.pixelMatrix=t.multiply(new Float64Array(16),this.labelPlaneMatrix,this.projMatrix),!(l=t.invert(new Float64Array(16),this.pixelMatrix)))throw new Error(\"failed to invert matrix\");this.pixelMatrixInverse=l,this._posMatrixCache={},this._alignedPosMatrixCache={}}},sn.prototype.maxPitchScaleFactor=function(){if(!this.pixelMatrixInverse)return 1;var e=this.pointCoordinate(new t.Point(0,0)),r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix)[3]/this.cameraToCenterDistance},sn.prototype.getCameraPoint=function(){var e=this._pitch,r=Math.tan(e)*(this.cameraToCenterDistance||1);return this.centerPoint.add(new t.Point(0,r))},sn.prototype.getCameraQueryGeometry=function(e){var r=this.getCameraPoint();if(1===e.length)return[e[0],r];for(var n=r.x,i=r.y,a=r.x,o=r.y,s=0,l=e;s<l.length;s+=1){var c=l[s];n=Math.min(n,c.x),i=Math.min(i,c.y),a=Math.max(a,c.x),o=Math.max(o,c.y)}return[new t.Point(n,i),new t.Point(a,i),new t.Point(a,o),new t.Point(n,o),new t.Point(n,i)]},Object.defineProperties(sn.prototype,ln);var cn=function(){var e,r,n,i;t.bindAll([\"_onHashChange\",\"_updateHash\"],this),this._updateHash=(e=this._updateHashUnthrottled.bind(this),300,r=!1,n=null,i=function(){n=null,r&&(e(),n=setTimeout(i,300),r=!1)},function(){return r=!0,n||i(),n})};cn.prototype.addTo=function(e){return this._map=e,t.window.addEventListener(\"hashchange\",this._onHashChange,!1),this._map.on(\"moveend\",this._updateHash),this},cn.prototype.remove=function(){return t.window.removeEventListener(\"hashchange\",this._onHashChange,!1),this._map.off(\"moveend\",this._updateHash),clearTimeout(this._updateHash()),delete this._map,this},cn.prototype.getHashString=function(t){var e=this._map.getCenter(),r=Math.round(100*this._map.getZoom())/100,n=Math.ceil((r*Math.LN2+Math.log(512/360/.5))/Math.LN10),i=Math.pow(10,n),a=Math.round(e.lng*i)/i,o=Math.round(e.lat*i)/i,s=this._map.getBearing(),l=this._map.getPitch(),c=\"\";return c+=t?\"#/\"+a+\"/\"+o+\"/\"+r:\"#\"+r+\"/\"+o+\"/\"+a,(s||l)&&(c+=\"/\"+Math.round(10*s)/10),l&&(c+=\"/\"+Math.round(l)),c},cn.prototype._onHashChange=function(){var e=t.window.location.hash.replace(\"#\",\"\").split(\"/\");return e.length>=3&&(this._map.jumpTo({center:[+e[2],+e[1]],zoom:+e[0],bearing:+(e[3]||0),pitch:+(e[4]||0)}),!0)},cn.prototype._updateHashUnthrottled=function(){var e=this.getHashString();try{t.window.history.replaceState(t.window.history.state,\"\",e)}catch(t){}};var un=function(e){function n(n,i,a,o){void 0===o&&(o={});var s=r.mousePos(i.getCanvasContainer(),a),l=i.unproject(s);e.call(this,n,t.extend({point:s,lngLat:l,originalEvent:a},o)),this._defaultPrevented=!1,this.target=i}e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),hn=function(e){function n(n,i,a){var o=r.touchPos(i.getCanvasContainer(),a),s=o.map(function(t){return i.unproject(t)}),l=o.reduce(function(t,e,r,n){return t.add(e.div(n.length))},new t.Point(0,0)),c=i.unproject(l);e.call(this,n,{points:o,point:l,lngLats:s,lngLat:c,originalEvent:a}),this._defaultPrevented=!1}e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),fn=function(t){function e(e,r,n){t.call(this,e,{originalEvent:n}),this._defaultPrevented=!1}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={defaultPrevented:{configurable:!0}};return e.prototype.preventDefault=function(){this._defaultPrevented=!0},r.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(e.prototype,r),e}(t.Event),pn=function(e){this._map=e,this._el=e.getCanvasContainer(),this._delta=0,this._defaultZoomRate=.01,this._wheelZoomRate=1/450,t.bindAll([\"_onWheel\",\"_onTimeout\",\"_onScrollFrame\",\"_onScrollFinished\"],this)};pn.prototype.setZoomRate=function(t){this._defaultZoomRate=t},pn.prototype.setWheelZoomRate=function(t){this._wheelZoomRate=t},pn.prototype.isEnabled=function(){return!!this._enabled},pn.prototype.isActive=function(){return!!this._active},pn.prototype.isZooming=function(){return!!this._zooming},pn.prototype.enable=function(t){this.isEnabled()||(this._enabled=!0,this._aroundCenter=t&&\"center\"===t.around)},pn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},pn.prototype.onWheel=function(e){if(this.isEnabled()){var r=e.deltaMode===t.window.WheelEvent.DOM_DELTA_LINE?40*e.deltaY:e.deltaY,n=t.browser.now(),i=n-(this._lastWheelEventTime||0);this._lastWheelEventTime=n,0!==r&&r%4.000244140625==0?this._type=\"wheel\":0!==r&&Math.abs(r)<4?this._type=\"trackpad\":i>400?(this._type=null,this._lastValue=r,this._timeout=setTimeout(this._onTimeout,40,e)):this._type||(this._type=Math.abs(i*r)<200?\"trackpad\":\"wheel\",this._timeout&&(clearTimeout(this._timeout),this._timeout=null,r+=this._lastValue)),e.shiftKey&&r&&(r/=4),this._type&&(this._lastWheelEvent=e,this._delta-=r,this.isActive()||this._start(e)),e.preventDefault()}},pn.prototype._onTimeout=function(t){this._type=\"wheel\",this._delta-=this._lastValue,this.isActive()||this._start(t)},pn.prototype._start=function(e){if(this._delta){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),this._active=!0,this.isZooming()||(this._zooming=!0,this._map.fire(new t.Event(\"movestart\",{originalEvent:e})),this._map.fire(new t.Event(\"zoomstart\",{originalEvent:e}))),this._finishTimeout&&clearTimeout(this._finishTimeout);var n=r.mousePos(this._el,e);this._around=t.LngLat.convert(this._aroundCenter?this._map.getCenter():this._map.unproject(n)),this._aroundPoint=this._map.transform.locationPoint(this._around),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onScrollFrame))}},pn.prototype._onScrollFrame=function(){var e=this;if(this._frameId=null,this.isActive()){var r=this._map.transform;if(0!==this._delta){var n=\"wheel\"===this._type&&Math.abs(this._delta)>4.000244140625?this._wheelZoomRate:this._defaultZoomRate,i=2/(1+Math.exp(-Math.abs(this._delta*n)));this._delta<0&&0!==i&&(i=1/i);var a=\"number\"==typeof this._targetZoom?r.zoomScale(this._targetZoom):r.scale;this._targetZoom=Math.min(r.maxZoom,Math.max(r.minZoom,r.scaleZoom(a*i))),\"wheel\"===this._type&&(this._startZoom=r.zoom,this._easing=this._smoothOutEasing(200)),this._delta=0}var o=\"number\"==typeof this._targetZoom?this._targetZoom:r.zoom,s=this._startZoom,l=this._easing,c=!1;if(\"wheel\"===this._type&&s&&l){var u=Math.min((t.browser.now()-this._lastWheelEventTime)/200,1),h=l(u);r.zoom=t.number(s,o,h),u<1?this._frameId||(this._frameId=this._map._requestRenderFrame(this._onScrollFrame)):c=!0}else r.zoom=o,c=!0;r.setLocationAtPoint(this._around,this._aroundPoint),this._map.fire(new t.Event(\"move\",{originalEvent:this._lastWheelEvent})),this._map.fire(new t.Event(\"zoom\",{originalEvent:this._lastWheelEvent})),c&&(this._active=!1,this._finishTimeout=setTimeout(function(){e._zooming=!1,e._map.fire(new t.Event(\"zoomend\",{originalEvent:e._lastWheelEvent})),e._map.fire(new t.Event(\"moveend\",{originalEvent:e._lastWheelEvent})),delete e._targetZoom},200))}},pn.prototype._smoothOutEasing=function(e){var r=t.ease;if(this._prevEase){var n=this._prevEase,i=(t.browser.now()-n.start)/n.duration,a=n.easing(i+.01)-n.easing(i),o=.27/Math.sqrt(a*a+1e-4)*.01,s=Math.sqrt(.0729-o*o);r=t.bezier(o,s,.25,1)}return this._prevEase={start:t.browser.now(),duration:e,easing:r},r};var dn=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._container=e.getContainer(),this._clickTolerance=r.clickTolerance||1,t.bindAll([\"_onMouseMove\",\"_onMouseUp\",\"_onKeyDown\"],this)};dn.prototype.isEnabled=function(){return!!this._enabled},dn.prototype.isActive=function(){return!!this._active},dn.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},dn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},dn.prototype.onMouseDown=function(e){this.isEnabled()&&e.shiftKey&&0===e.button&&(t.window.document.addEventListener(\"mousemove\",this._onMouseMove,!1),t.window.document.addEventListener(\"keydown\",this._onKeyDown,!1),t.window.document.addEventListener(\"mouseup\",this._onMouseUp,!1),r.disableDrag(),this._startPos=this._lastPos=r.mousePos(this._el,e),this._active=!0)},dn.prototype._onMouseMove=function(t){var e=r.mousePos(this._el,t);if(!(this._lastPos.equals(e)||!this._box&&e.dist(this._startPos)<this._clickTolerance)){var n=this._startPos;this._lastPos=e,this._box||(this._box=r.create(\"div\",\"mapboxgl-boxzoom\",this._container),this._container.classList.add(\"mapboxgl-crosshair\"),this._fireEvent(\"boxzoomstart\",t));var i=Math.min(n.x,e.x),a=Math.max(n.x,e.x),o=Math.min(n.y,e.y),s=Math.max(n.y,e.y);r.setTransform(this._box,\"translate(\"+i+\"px,\"+o+\"px)\"),this._box.style.width=a-i+\"px\",this._box.style.height=s-o+\"px\"}},dn.prototype._onMouseUp=function(e){if(0===e.button){var n=this._startPos,i=r.mousePos(this._el,e);this._finish(),r.suppressClick(),n.x===i.x&&n.y===i.y?this._fireEvent(\"boxzoomcancel\",e):this._map.fitScreenCoordinates(n,i,this._map.getBearing(),{linear:!0}).fire(new t.Event(\"boxzoomend\",{originalEvent:e}))}},dn.prototype._onKeyDown=function(t){27===t.keyCode&&(this._finish(),this._fireEvent(\"boxzoomcancel\",t))},dn.prototype._finish=function(){this._active=!1,t.window.document.removeEventListener(\"mousemove\",this._onMouseMove,!1),t.window.document.removeEventListener(\"keydown\",this._onKeyDown,!1),t.window.document.removeEventListener(\"mouseup\",this._onMouseUp,!1),this._container.classList.remove(\"mapboxgl-crosshair\"),this._box&&(r.remove(this._box),this._box=null),r.enableDrag(),delete this._startPos,delete this._lastPos},dn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,{originalEvent:r}))};var gn=t.bezier(0,0,.25,1),vn=function(e,r){this._map=e,this._el=r.element||e.getCanvasContainer(),this._state=\"disabled\",this._button=r.button||\"right\",this._bearingSnap=r.bearingSnap||0,this._pitchWithRotate=!1!==r.pitchWithRotate,t.bindAll([\"onMouseDown\",\"_onMouseMove\",\"_onMouseUp\",\"_onBlur\",\"_onDragFrame\"],this)};vn.prototype.isEnabled=function(){return\"disabled\"!==this._state},vn.prototype.isActive=function(){return\"active\"===this._state},vn.prototype.enable=function(){this.isEnabled()||(this._state=\"enabled\")},vn.prototype.disable=function(){if(this.isEnabled())switch(this._state){case\"active\":this._state=\"disabled\",this._unbind(),this._deactivate(),this._fireEvent(\"rotateend\"),this._pitchWithRotate&&this._fireEvent(\"pitchend\"),this._fireEvent(\"moveend\");break;case\"pending\":this._state=\"disabled\",this._unbind();break;default:this._state=\"disabled\"}},vn.prototype.onMouseDown=function(e){if(\"enabled\"===this._state){if(\"right\"===this._button){if(this._eventButton=r.mouseButton(e),this._eventButton!==(e.ctrlKey?0:2))return}else{if(e.ctrlKey||0!==r.mouseButton(e))return;this._eventButton=0}r.disableDrag(),t.window.document.addEventListener(\"mousemove\",this._onMouseMove,{capture:!0}),t.window.document.addEventListener(\"mouseup\",this._onMouseUp),t.window.addEventListener(\"blur\",this._onBlur),this._state=\"pending\",this._inertia=[[t.browser.now(),this._map.getBearing()]],this._startPos=this._lastPos=r.mousePos(this._el,e),this._center=this._map.transform.centerPoint,e.preventDefault()}},vn.prototype._onMouseMove=function(t){var e=r.mousePos(this._el,t);this._lastPos.equals(e)||(this._lastMoveEvent=t,this._lastPos=e,\"pending\"===this._state&&(this._state=\"active\",this._fireEvent(\"rotatestart\",t),this._fireEvent(\"movestart\",t),this._pitchWithRotate&&this._fireEvent(\"pitchstart\",t)),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onDragFrame)))},vn.prototype._onDragFrame=function(){this._frameId=null;var e=this._lastMoveEvent;if(e){var r=this._map.transform,n=this._startPos,i=this._lastPos,a=.8*(n.x-i.x),o=-.5*(n.y-i.y),s=r.bearing-a,l=r.pitch-o,c=this._inertia,u=c[c.length-1];this._drainInertiaBuffer(),c.push([t.browser.now(),this._map._normalizeBearing(s,u[1])]),r.bearing=s,this._pitchWithRotate&&(this._fireEvent(\"pitch\",e),r.pitch=l),this._fireEvent(\"rotate\",e),this._fireEvent(\"move\",e),delete this._lastMoveEvent,this._startPos=this._lastPos}},vn.prototype._onMouseUp=function(t){if(r.mouseButton(t)===this._eventButton)switch(this._state){case\"active\":this._state=\"enabled\",r.suppressClick(),this._unbind(),this._deactivate(),this._inertialRotate(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},vn.prototype._onBlur=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._fireEvent(\"rotateend\",t),this._pitchWithRotate&&this._fireEvent(\"pitchend\",t),this._fireEvent(\"moveend\",t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},vn.prototype._unbind=function(){t.window.document.removeEventListener(\"mousemove\",this._onMouseMove,{capture:!0}),t.window.document.removeEventListener(\"mouseup\",this._onMouseUp),t.window.removeEventListener(\"blur\",this._onBlur),r.enableDrag()},vn.prototype._deactivate=function(){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._lastMoveEvent,delete this._startPos,delete this._lastPos},vn.prototype._inertialRotate=function(t){var e=this;this._fireEvent(\"rotateend\",t),this._drainInertiaBuffer();var r=this._map,n=r.getBearing(),i=this._inertia,a=function(){Math.abs(n)<e._bearingSnap?r.resetNorth({noMoveStart:!0},{originalEvent:t}):e._fireEvent(\"moveend\",t),e._pitchWithRotate&&e._fireEvent(\"pitchend\",t)};if(i.length<2)a();else{var o=i[0],s=i[i.length-1],l=i[i.length-2],c=r._normalizeBearing(n,l[1]),u=s[1]-o[1],h=u<0?-1:1,f=(s[0]-o[0])/1e3;if(0!==u&&0!==f){var p=Math.abs(u*(.25/f));p>180&&(p=180);var d=p/180;c+=h*p*(d/2),Math.abs(r._normalizeBearing(c,0))<this._bearingSnap&&(c=r._normalizeBearing(0,c)),r.rotateTo(c,{duration:1e3*d,easing:gn,noMoveStart:!0},{originalEvent:t})}else a()}},vn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},vn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>0&&r-e[0][0]>160;)e.shift()};var mn=t.bezier(0,0,.3,1),yn=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._state=\"disabled\",this._clickTolerance=r.clickTolerance||1,t.bindAll([\"_onMove\",\"_onMouseUp\",\"_onTouchEnd\",\"_onBlur\",\"_onDragFrame\"],this)};yn.prototype.isEnabled=function(){return\"disabled\"!==this._state},yn.prototype.isActive=function(){return\"active\"===this._state},yn.prototype.enable=function(){this.isEnabled()||(this._el.classList.add(\"mapboxgl-touch-drag-pan\"),this._state=\"enabled\")},yn.prototype.disable=function(){if(this.isEnabled())switch(this._el.classList.remove(\"mapboxgl-touch-drag-pan\"),this._state){case\"active\":this._state=\"disabled\",this._unbind(),this._deactivate(),this._fireEvent(\"dragend\"),this._fireEvent(\"moveend\");break;case\"pending\":this._state=\"disabled\",this._unbind();break;default:this._state=\"disabled\"}},yn.prototype.onMouseDown=function(e){\"enabled\"===this._state&&(e.ctrlKey||0!==r.mouseButton(e)||(r.addEventListener(t.window.document,\"mousemove\",this._onMove,{capture:!0}),r.addEventListener(t.window.document,\"mouseup\",this._onMouseUp),this._start(e)))},yn.prototype.onTouchStart=function(e){\"enabled\"===this._state&&(e.touches.length>1||(r.addEventListener(t.window.document,\"touchmove\",this._onMove,{capture:!0,passive:!1}),r.addEventListener(t.window.document,\"touchend\",this._onTouchEnd),this._start(e)))},yn.prototype._start=function(e){t.window.addEventListener(\"blur\",this._onBlur),this._state=\"pending\",this._startPos=this._mouseDownPos=this._lastPos=r.mousePos(this._el,e),this._inertia=[[t.browser.now(),this._startPos]]},yn.prototype._onMove=function(e){e.preventDefault();var n=r.mousePos(this._el,e);this._lastPos.equals(n)||\"pending\"===this._state&&n.dist(this._mouseDownPos)<this._clickTolerance||(this._lastMoveEvent=e,this._lastPos=n,this._drainInertiaBuffer(),this._inertia.push([t.browser.now(),this._lastPos]),\"pending\"===this._state&&(this._state=\"active\",this._fireEvent(\"dragstart\",e),this._fireEvent(\"movestart\",e)),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onDragFrame)))},yn.prototype._onDragFrame=function(){this._frameId=null;var t=this._lastMoveEvent;if(t){var e=this._map.transform;e.setLocationAtPoint(e.pointLocation(this._startPos),this._lastPos),this._fireEvent(\"drag\",t),this._fireEvent(\"move\",t),this._startPos=this._lastPos,delete this._lastMoveEvent}},yn.prototype._onMouseUp=function(t){if(0===r.mouseButton(t))switch(this._state){case\"active\":this._state=\"enabled\",r.suppressClick(),this._unbind(),this._deactivate(),this._inertialPan(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},yn.prototype._onTouchEnd=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._inertialPan(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},yn.prototype._onBlur=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._fireEvent(\"dragend\",t),this._fireEvent(\"moveend\",t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},yn.prototype._unbind=function(){r.removeEventListener(t.window.document,\"touchmove\",this._onMove,{capture:!0,passive:!1}),r.removeEventListener(t.window.document,\"touchend\",this._onTouchEnd),r.removeEventListener(t.window.document,\"mousemove\",this._onMove,{capture:!0}),r.removeEventListener(t.window.document,\"mouseup\",this._onMouseUp),r.removeEventListener(t.window,\"blur\",this._onBlur)},yn.prototype._deactivate=function(){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._lastMoveEvent,delete this._startPos,delete this._mouseDownPos,delete this._lastPos},yn.prototype._inertialPan=function(t){this._fireEvent(\"dragend\",t),this._drainInertiaBuffer();var e=this._inertia;if(e.length<2)this._fireEvent(\"moveend\",t);else{var r=e[e.length-1],n=e[0],i=r[1].sub(n[1]),a=(r[0]-n[0])/1e3;if(0===a||r[1].equals(n[1]))this._fireEvent(\"moveend\",t);else{var o=i.mult(.3/a),s=o.mag();s>1400&&(s=1400,o._unit()._mult(s));var l=s/750,c=o.mult(-l/2);this._map.panBy(c,{duration:1e3*l,easing:mn,noMoveStart:!0},{originalEvent:t})}}},yn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},yn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>0&&r-e[0][0]>160;)e.shift()};var xn=function(e){this._map=e,this._el=e.getCanvasContainer(),t.bindAll([\"_onKeyDown\"],this)};function bn(t){return t*(2-t)}xn.prototype.isEnabled=function(){return!!this._enabled},xn.prototype.enable=function(){this.isEnabled()||(this._el.addEventListener(\"keydown\",this._onKeyDown,!1),this._enabled=!0)},xn.prototype.disable=function(){this.isEnabled()&&(this._el.removeEventListener(\"keydown\",this._onKeyDown),this._enabled=!1)},xn.prototype._onKeyDown=function(t){if(!(t.altKey||t.ctrlKey||t.metaKey)){var e=0,r=0,n=0,i=0,a=0;switch(t.keyCode){case 61:case 107:case 171:case 187:e=1;break;case 189:case 109:case 173:e=-1;break;case 37:t.shiftKey?r=-1:(t.preventDefault(),i=-1);break;case 39:t.shiftKey?r=1:(t.preventDefault(),i=1);break;case 38:t.shiftKey?n=1:(t.preventDefault(),a=-1);break;case 40:t.shiftKey?n=-1:(a=1,t.preventDefault());break;default:return}var o=this._map,s=o.getZoom(),l={duration:300,delayEndEvents:500,easing:bn,zoom:e?Math.round(s)+e*(t.shiftKey?2:1):s,bearing:o.getBearing()+15*r,pitch:o.getPitch()+10*n,offset:[100*-i,100*-a],center:o.getCenter()};o.easeTo(l,{originalEvent:t})}};var _n=function(e){this._map=e,t.bindAll([\"_onDblClick\",\"_onZoomEnd\"],this)};_n.prototype.isEnabled=function(){return!!this._enabled},_n.prototype.isActive=function(){return!!this._active},_n.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},_n.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},_n.prototype.onTouchStart=function(t){var e=this;if(this.isEnabled()&&!(t.points.length>1))if(this._tapped){var r=t.points[0],n=this._tappedPoint;if(n&&n.dist(r)<=30){t.originalEvent.preventDefault();var i=function(){e._tapped&&e._zoom(t),e._map.off(\"touchcancel\",a),e._resetTapped()},a=function(){e._map.off(\"touchend\",i),e._resetTapped()};this._map.once(\"touchend\",i),this._map.once(\"touchcancel\",a)}else this._resetTapped()}else this._tappedPoint=t.points[0],this._tapped=setTimeout(function(){e._tapped=null,e._tappedPoint=null},300)},_n.prototype._resetTapped=function(){clearTimeout(this._tapped),this._tapped=null,this._tappedPoint=null},_n.prototype.onDblClick=function(t){this.isEnabled()&&(t.originalEvent.preventDefault(),this._zoom(t))},_n.prototype._zoom=function(t){this._active=!0,this._map.on(\"zoomend\",this._onZoomEnd),this._map.zoomTo(this._map.getZoom()+(t.originalEvent.shiftKey?-1:1),{around:t.lngLat},t)},_n.prototype._onZoomEnd=function(){this._active=!1,this._map.off(\"zoomend\",this._onZoomEnd)};var wn=t.bezier(0,0,.15,1),kn=function(e){this._map=e,this._el=e.getCanvasContainer(),t.bindAll([\"_onMove\",\"_onEnd\",\"_onTouchFrame\"],this)};kn.prototype.isEnabled=function(){return!!this._enabled},kn.prototype.enable=function(t){this.isEnabled()||(this._el.classList.add(\"mapboxgl-touch-zoom-rotate\"),this._enabled=!0,this._aroundCenter=!!t&&\"center\"===t.around)},kn.prototype.disable=function(){this.isEnabled()&&(this._el.classList.remove(\"mapboxgl-touch-zoom-rotate\"),this._enabled=!1)},kn.prototype.disableRotation=function(){this._rotationDisabled=!0},kn.prototype.enableRotation=function(){this._rotationDisabled=!1},kn.prototype.onStart=function(e){if(this.isEnabled()&&2===e.touches.length){var n=r.mousePos(this._el,e.touches[0]),i=r.mousePos(this._el,e.touches[1]),a=n.add(i).div(2);this._startVec=n.sub(i),this._startAround=this._map.transform.pointLocation(a),this._gestureIntent=void 0,this._inertia=[],r.addEventListener(t.window.document,\"touchmove\",this._onMove,{passive:!1}),r.addEventListener(t.window.document,\"touchend\",this._onEnd)}},kn.prototype._getTouchEventData=function(t){var e=r.mousePos(this._el,t.touches[0]),n=r.mousePos(this._el,t.touches[1]),i=e.sub(n);return{vec:i,center:e.add(n).div(2),scale:i.mag()/this._startVec.mag(),bearing:this._rotationDisabled?0:180*i.angleWith(this._startVec)/Math.PI}},kn.prototype._onMove=function(e){if(2===e.touches.length){var r=this._getTouchEventData(e),n=r.vec,i=r.scale,a=r.bearing;if(!this._gestureIntent){var o=this._rotationDisabled&&1!==i||Math.abs(1-i)>.15;Math.abs(a)>10?this._gestureIntent=\"rotate\":o&&(this._gestureIntent=\"zoom\"),this._gestureIntent&&(this._map.fire(new t.Event(this._gestureIntent+\"start\",{originalEvent:e})),this._map.fire(new t.Event(\"movestart\",{originalEvent:e})),this._startVec=n)}this._lastTouchEvent=e,this._frameId||(this._frameId=this._map._requestRenderFrame(this._onTouchFrame)),e.preventDefault()}},kn.prototype._onTouchFrame=function(){this._frameId=null;var e=this._gestureIntent;if(e){var r=this._map.transform;this._startScale||(this._startScale=r.scale,this._startBearing=r.bearing);var n=this._getTouchEventData(this._lastTouchEvent),i=n.center,a=n.bearing,o=n.scale,s=r.pointLocation(i),l=r.locationPoint(s);\"rotate\"===e&&(r.bearing=this._startBearing+a),r.zoom=r.scaleZoom(this._startScale*o),r.setLocationAtPoint(this._startAround,l),this._map.fire(new t.Event(e,{originalEvent:this._lastTouchEvent})),this._map.fire(new t.Event(\"move\",{originalEvent:this._lastTouchEvent})),this._drainInertiaBuffer(),this._inertia.push([t.browser.now(),o,i])}},kn.prototype._onEnd=function(e){r.removeEventListener(t.window.document,\"touchmove\",this._onMove,{passive:!1}),r.removeEventListener(t.window.document,\"touchend\",this._onEnd);var n=this._gestureIntent,i=this._startScale;if(this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._gestureIntent,delete this._startScale,delete this._startBearing,delete this._lastTouchEvent,n){this._map.fire(new t.Event(n+\"end\",{originalEvent:e})),this._drainInertiaBuffer();var a=this._inertia,o=this._map;if(a.length<2)o.snapToNorth({},{originalEvent:e});else{var s=a[a.length-1],l=a[0],c=o.transform.scaleZoom(i*s[1]),u=o.transform.scaleZoom(i*l[1]),h=c-u,f=(s[0]-l[0])/1e3,p=s[2];if(0!==f&&c!==u){var d=.15*h/f;Math.abs(d)>2.5&&(d=d>0?2.5:-2.5);var g=1e3*Math.abs(d/(12*.15)),v=c+d*g/2e3;v<0&&(v=0),o.easeTo({zoom:v,duration:g,easing:wn,around:this._aroundCenter?o.getCenter():o.unproject(p),noMoveStart:!0},{originalEvent:e})}else o.snapToNorth({},{originalEvent:e})}}},kn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>2&&r-e[0][0]>160;)e.shift()};var Tn={scrollZoom:pn,boxZoom:dn,dragRotate:vn,dragPan:yn,keyboard:xn,doubleClickZoom:_n,touchZoomRotate:kn},An=function(e){function r(r,n){e.call(this),this._moving=!1,this._zooming=!1,this.transform=r,this._bearingSnap=n.bearingSnap,t.bindAll([\"_renderFrameCallback\"],this)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getCenter=function(){return new t.LngLat(this.transform.center.lng,this.transform.center.lat)},r.prototype.setCenter=function(t,e){return this.jumpTo({center:t},e)},r.prototype.panBy=function(e,r,n){return e=t.Point.convert(e).mult(-1),this.panTo(this.transform.center,t.extend({offset:e},r),n)},r.prototype.panTo=function(e,r,n){return this.easeTo(t.extend({center:e},r),n)},r.prototype.getZoom=function(){return this.transform.zoom},r.prototype.setZoom=function(t,e){return this.jumpTo({zoom:t},e),this},r.prototype.zoomTo=function(e,r,n){return this.easeTo(t.extend({zoom:e},r),n)},r.prototype.zoomIn=function(t,e){return this.zoomTo(this.getZoom()+1,t,e),this},r.prototype.zoomOut=function(t,e){return this.zoomTo(this.getZoom()-1,t,e),this},r.prototype.getBearing=function(){return this.transform.bearing},r.prototype.setBearing=function(t,e){return this.jumpTo({bearing:t},e),this},r.prototype.rotateTo=function(e,r,n){return this.easeTo(t.extend({bearing:e},r),n)},r.prototype.resetNorth=function(e,r){return this.rotateTo(0,t.extend({duration:1e3},e),r),this},r.prototype.snapToNorth=function(t,e){return Math.abs(this.getBearing())<this._bearingSnap?this.resetNorth(t,e):this},r.prototype.getPitch=function(){return this.transform.pitch},r.prototype.setPitch=function(t,e){return this.jumpTo({pitch:t},e),this},r.prototype.cameraForBounds=function(e,r){return e=t.LngLatBounds.convert(e),this._cameraForBoxAndBearing(e.getNorthWest(),e.getSouthEast(),0,r)},r.prototype._cameraForBoxAndBearing=function(e,r,n,i){if(\"number\"==typeof(i=t.extend({padding:{top:0,bottom:0,right:0,left:0},offset:[0,0],maxZoom:this.transform.maxZoom},i)).padding){var a=i.padding;i.padding={top:a,bottom:a,right:a,left:a}}if(t.deepEqual(Object.keys(i.padding).sort(function(t,e){return t<e?-1:t>e?1:0}),[\"bottom\",\"left\",\"right\",\"top\"])){var o=this.transform,s=o.project(t.LngLat.convert(e)),l=o.project(t.LngLat.convert(r)),c=s.rotate(-n*Math.PI/180),u=l.rotate(-n*Math.PI/180),h=new t.Point(Math.max(c.x,u.x),Math.max(c.y,u.y)),f=new t.Point(Math.min(c.x,u.x),Math.min(c.y,u.y)),p=h.sub(f),d=(o.width-i.padding.left-i.padding.right)/p.x,g=(o.height-i.padding.top-i.padding.bottom)/p.y;if(!(g<0||d<0)){var v=Math.min(o.scaleZoom(o.scale*Math.min(d,g)),i.maxZoom),m=t.Point.convert(i.offset),y=(i.padding.left-i.padding.right)/2,x=(i.padding.top-i.padding.bottom)/2,b=new t.Point(m.x+y,m.y+x).mult(o.scale/o.zoomScale(v));return{center:o.unproject(s.add(l).div(2).sub(b)),zoom:v,bearing:n}}t.warnOnce(\"Map cannot fit within canvas with the given bounds, padding, and/or offset.\")}else t.warnOnce(\"options.padding must be a positive number, or an Object with keys 'bottom', 'left', 'right', 'top'\")},r.prototype.fitBounds=function(t,e,r){return this._fitInternal(this.cameraForBounds(t,e),e,r)},r.prototype.fitScreenCoordinates=function(e,r,n,i,a){return this._fitInternal(this._cameraForBoxAndBearing(this.transform.pointLocation(t.Point.convert(e)),this.transform.pointLocation(t.Point.convert(r)),n,i),i,a)},r.prototype._fitInternal=function(e,r,n){return e?(r=t.extend(e,r)).linear?this.easeTo(r,n):this.flyTo(r,n):this},r.prototype.jumpTo=function(e,r){this.stop();var n=this.transform,i=!1,a=!1,o=!1;return\"zoom\"in e&&n.zoom!==+e.zoom&&(i=!0,n.zoom=+e.zoom),void 0!==e.center&&(n.center=t.LngLat.convert(e.center)),\"bearing\"in e&&n.bearing!==+e.bearing&&(a=!0,n.bearing=+e.bearing),\"pitch\"in e&&n.pitch!==+e.pitch&&(o=!0,n.pitch=+e.pitch),this.fire(new t.Event(\"movestart\",r)).fire(new t.Event(\"move\",r)),i&&this.fire(new t.Event(\"zoomstart\",r)).fire(new t.Event(\"zoom\",r)).fire(new t.Event(\"zoomend\",r)),a&&this.fire(new t.Event(\"rotatestart\",r)).fire(new t.Event(\"rotate\",r)).fire(new t.Event(\"rotateend\",r)),o&&this.fire(new t.Event(\"pitchstart\",r)).fire(new t.Event(\"pitch\",r)).fire(new t.Event(\"pitchend\",r)),this.fire(new t.Event(\"moveend\",r))},r.prototype.easeTo=function(e,r){var n=this;this.stop(),!1===(e=t.extend({offset:[0,0],duration:500,easing:t.ease},e)).animate&&(e.duration=0);var i=this.transform,a=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=\"zoom\"in e?+e.zoom:a,c=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,u=\"pitch\"in e?+e.pitch:s,h=i.centerPoint.add(t.Point.convert(e.offset)),f=i.pointLocation(h),p=t.LngLat.convert(e.center||f);this._normalizeCenter(p);var d,g,v=i.project(f),m=i.project(p).sub(v),y=i.zoomScale(l-a);return e.around&&(d=t.LngLat.convert(e.around),g=i.locationPoint(d)),this._zooming=l!==a,this._rotating=o!==c,this._pitching=u!==s,this._prepareEase(r,e.noMoveStart),clearTimeout(this._easeEndTimeoutID),this._ease(function(e){if(n._zooming&&(i.zoom=t.number(a,l,e)),n._rotating&&(i.bearing=t.number(o,c,e)),n._pitching&&(i.pitch=t.number(s,u,e)),d)i.setLocationAtPoint(d,g);else{var f=i.zoomScale(i.zoom-a),p=l>a?Math.min(2,y):Math.max(.5,y),x=Math.pow(p,1-e),b=i.unproject(v.add(m.mult(e*x)).mult(f));i.setLocationAtPoint(i.renderWorldCopies?b.wrap():b,h)}n._fireMoveEvents(r)},function(){e.delayEndEvents?n._easeEndTimeoutID=setTimeout(function(){return n._afterEase(r)},e.delayEndEvents):n._afterEase(r)},e),this},r.prototype._prepareEase=function(e,r){this._moving=!0,r||this.fire(new t.Event(\"movestart\",e)),this._zooming&&this.fire(new t.Event(\"zoomstart\",e)),this._rotating&&this.fire(new t.Event(\"rotatestart\",e)),this._pitching&&this.fire(new t.Event(\"pitchstart\",e))},r.prototype._fireMoveEvents=function(e){this.fire(new t.Event(\"move\",e)),this._zooming&&this.fire(new t.Event(\"zoom\",e)),this._rotating&&this.fire(new t.Event(\"rotate\",e)),this._pitching&&this.fire(new t.Event(\"pitch\",e))},r.prototype._afterEase=function(e){var r=this._zooming,n=this._rotating,i=this._pitching;this._moving=!1,this._zooming=!1,this._rotating=!1,this._pitching=!1,r&&this.fire(new t.Event(\"zoomend\",e)),n&&this.fire(new t.Event(\"rotateend\",e)),i&&this.fire(new t.Event(\"pitchend\",e)),this.fire(new t.Event(\"moveend\",e))},r.prototype.flyTo=function(e,r){var n=this;this.stop(),e=t.extend({offset:[0,0],speed:1.2,curve:1.42,easing:t.ease},e);var i=this.transform,a=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=\"zoom\"in e?t.clamp(+e.zoom,i.minZoom,i.maxZoom):a,c=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,u=\"pitch\"in e?+e.pitch:s,h=i.zoomScale(l-a),f=i.centerPoint.add(t.Point.convert(e.offset)),p=i.pointLocation(f),d=t.LngLat.convert(e.center||p);this._normalizeCenter(d);var g=i.project(p),v=i.project(d).sub(g),m=e.curve,y=Math.max(i.width,i.height),x=y/h,b=v.mag();if(\"minZoom\"in e){var _=t.clamp(Math.min(e.minZoom,a,l),i.minZoom,i.maxZoom),w=y/i.zoomScale(_-a);m=Math.sqrt(w/b*2)}var k=m*m;function T(t){var e=(x*x-y*y+(t?-1:1)*k*k*b*b)/(2*(t?x:y)*k*b);return Math.log(Math.sqrt(e*e+1)-e)}function A(t){return(Math.exp(t)-Math.exp(-t))/2}function M(t){return(Math.exp(t)+Math.exp(-t))/2}var S=T(0),E=function(t){return M(S)/M(S+m*t)},C=function(t){return y*((M(S)*(A(e=S+m*t)/M(e))-A(S))/k)/b;var e},L=(T(1)-S)/m;if(Math.abs(b)<1e-6||!isFinite(L)){if(Math.abs(y-x)<1e-6)return this.easeTo(e,r);var P=x<y?-1:1;L=Math.abs(Math.log(x/y))/m,C=function(){return 0},E=function(t){return Math.exp(P*m*t)}}if(\"duration\"in e)e.duration=+e.duration;else{var O=\"screenSpeed\"in e?+e.screenSpeed/m:+e.speed;e.duration=1e3*L/O}return e.maxDuration&&e.duration>e.maxDuration&&(e.duration=0),this._zooming=!0,this._rotating=o!==c,this._pitching=u!==s,this._prepareEase(r,!1),this._ease(function(e){var h=e*L,p=1/E(h);i.zoom=1===e?l:a+i.scaleZoom(p),n._rotating&&(i.bearing=t.number(o,c,e)),n._pitching&&(i.pitch=t.number(s,u,e));var m=1===e?d:i.unproject(g.add(v.mult(C(h))).mult(p));i.setLocationAtPoint(i.renderWorldCopies?m.wrap():m,f),n._fireMoveEvents(r)},function(){return n._afterEase(r)},e),this},r.prototype.isEasing=function(){return!!this._easeFrameId},r.prototype.stop=function(){if(this._easeFrameId&&(this._cancelRenderFrame(this._easeFrameId),delete this._easeFrameId,delete this._onEaseFrame),this._onEaseEnd){var t=this._onEaseEnd;delete this._onEaseEnd,t.call(this)}return this},r.prototype._ease=function(e,r,n){!1===n.animate||0===n.duration?(e(1),r()):(this._easeStart=t.browser.now(),this._easeOptions=n,this._onEaseFrame=e,this._onEaseEnd=r,this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback))},r.prototype._renderFrameCallback=function(){var e=Math.min((t.browser.now()-this._easeStart)/this._easeOptions.duration,1);this._onEaseFrame(this._easeOptions.easing(e)),e<1?this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback):this.stop()},r.prototype._normalizeBearing=function(e,r){e=t.wrap(e,-180,180);var n=Math.abs(e-r);return Math.abs(e-360-r)<n&&(e-=360),Math.abs(e+360-r)<n&&(e+=360),e},r.prototype._normalizeCenter=function(t){var e=this.transform;if(e.renderWorldCopies&&!e.lngRange){var r=t.lng-e.center.lng;t.lng+=r>180?-360:r<-180?360:0}},r}(t.Evented),Mn=function(e){void 0===e&&(e={}),this.options=e,t.bindAll([\"_updateEditLink\",\"_updateData\",\"_updateCompact\"],this)};Mn.prototype.getDefaultPosition=function(){return\"bottom-right\"},Mn.prototype.onAdd=function(t){var e=this.options&&this.options.compact;return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-attrib\"),this._innerContainer=r.create(\"div\",\"mapboxgl-ctrl-attrib-inner\",this._container),e&&this._container.classList.add(\"mapboxgl-compact\"),this._updateAttributions(),this._updateEditLink(),this._map.on(\"styledata\",this._updateData),this._map.on(\"sourcedata\",this._updateData),this._map.on(\"moveend\",this._updateEditLink),void 0===e&&(this._map.on(\"resize\",this._updateCompact),this._updateCompact()),this._container},Mn.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"styledata\",this._updateData),this._map.off(\"sourcedata\",this._updateData),this._map.off(\"moveend\",this._updateEditLink),this._map.off(\"resize\",this._updateCompact),this._map=void 0},Mn.prototype._updateEditLink=function(){var e=this._editLink;e||(e=this._editLink=this._container.querySelector(\".mapbox-improve-map\"));var r=[{key:\"owner\",value:this.styleOwner},{key:\"id\",value:this.styleId},{key:\"access_token\",value:t.config.ACCESS_TOKEN}];if(e){var n=r.reduce(function(t,e,n){return e.value&&(t+=e.key+\"=\"+e.value+(n<r.length-1?\"&\":\"\")),t},\"?\");e.href=t.config.FEEDBACK_URL+\"/\"+n+(this._map._hash?this._map._hash.getHashString(!0):\"\"),e.rel=\"noopener nofollow\"}},Mn.prototype._updateData=function(t){!t||\"metadata\"!==t.sourceDataType&&\"style\"!==t.dataType||(this._updateAttributions(),this._updateEditLink())},Mn.prototype._updateAttributions=function(){if(this._map.style){var t=[];if(this.options.customAttribution&&(Array.isArray(this.options.customAttribution)?t=t.concat(this.options.customAttribution.map(function(t){return\"string\"!=typeof t?\"\":t})):\"string\"==typeof this.options.customAttribution&&t.push(this.options.customAttribution)),this._map.style.stylesheet){var e=this._map.style.stylesheet;this.styleOwner=e.owner,this.styleId=e.id}var r=this._map.style.sourceCaches;for(var n in r){var i=r[n];if(i.used){var a=i.getSource();a.attribution&&t.indexOf(a.attribution)<0&&t.push(a.attribution)}}t.sort(function(t,e){return t.length-e.length});var o=(t=t.filter(function(e,r){for(var n=r+1;n<t.length;n++)if(t[n].indexOf(e)>=0)return!1;return!0})).join(\" | \");o!==this._attribHTML&&(this._attribHTML=o,t.length?(this._innerContainer.innerHTML=o,this._container.classList.remove(\"mapboxgl-attrib-empty\")):this._container.classList.add(\"mapboxgl-attrib-empty\"),this._editLink=null)}},Mn.prototype._updateCompact=function(){this._map.getCanvasContainer().offsetWidth<=640?this._container.classList.add(\"mapboxgl-compact\"):this._container.classList.remove(\"mapboxgl-compact\")};var Sn=function(){t.bindAll([\"_updateLogo\"],this),t.bindAll([\"_updateCompact\"],this)};Sn.prototype.onAdd=function(t){this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl\");var e=r.create(\"a\",\"mapboxgl-ctrl-logo\");return e.target=\"_blank\",e.rel=\"noopener nofollow\",e.href=\"https://www.mapbox.com/\",e.setAttribute(\"aria-label\",\"Mapbox logo\"),e.setAttribute(\"rel\",\"noopener nofollow\"),this._container.appendChild(e),this._container.style.display=\"none\",this._map.on(\"sourcedata\",this._updateLogo),this._updateLogo(),this._map.on(\"resize\",this._updateCompact),this._updateCompact(),this._container},Sn.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"sourcedata\",this._updateLogo),this._map.off(\"resize\",this._updateCompact)},Sn.prototype.getDefaultPosition=function(){return\"bottom-left\"},Sn.prototype._updateLogo=function(t){t&&\"metadata\"!==t.sourceDataType||(this._container.style.display=this._logoRequired()?\"block\":\"none\")},Sn.prototype._logoRequired=function(){if(this._map.style){var t=this._map.style.sourceCaches;for(var e in t)if(t[e].getSource().mapbox_logo)return!0;return!1}},Sn.prototype._updateCompact=function(){var t=this._container.children;if(t.length){var e=t[0];this._map.getCanvasContainer().offsetWidth<250?e.classList.add(\"mapboxgl-compact\"):e.classList.remove(\"mapboxgl-compact\")}};var En=function(){this._queue=[],this._id=0,this._cleared=!1,this._currentlyRunning=!1};En.prototype.add=function(t){var e=++this._id;return this._queue.push({callback:t,id:e,cancelled:!1}),e},En.prototype.remove=function(t){for(var e=this._currentlyRunning,r=0,n=e?this._queue.concat(e):this._queue;r<n.length;r+=1){var i=n[r];if(i.id===t)return void(i.cancelled=!0)}},En.prototype.run=function(){var t=this._currentlyRunning=this._queue;this._queue=[];for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!n.cancelled&&(n.callback(),this._cleared))break}this._cleared=!1,this._currentlyRunning=!1},En.prototype.clear=function(){this._currentlyRunning&&(this._cleared=!0),this._queue=[]};var Cn=t.window.HTMLImageElement,Ln=t.window.HTMLElement,Pn={center:[0,0],zoom:0,bearing:0,pitch:0,minZoom:0,maxZoom:22,interactive:!0,scrollZoom:!0,boxZoom:!0,dragRotate:!0,dragPan:!0,keyboard:!0,doubleClickZoom:!0,touchZoomRotate:!0,bearingSnap:7,clickTolerance:3,hash:!1,attributionControl:!0,failIfMajorPerformanceCaveat:!1,preserveDrawingBuffer:!1,trackResize:!0,renderWorldCopies:!0,refreshExpiredTiles:!0,maxTileCacheSize:null,localIdeographFontFamily:\"sans-serif\",transformRequest:null,fadeDuration:300,crossSourceCollisions:!0},On=function(n){function i(e){var i=this;if(null!=(e=t.extend({},Pn,e)).minZoom&&null!=e.maxZoom&&e.minZoom>e.maxZoom)throw new Error(\"maxZoom must be greater than minZoom\");var a=new sn(e.minZoom,e.maxZoom,e.renderWorldCopies);if(n.call(this,a,e),this._interactive=e.interactive,this._maxTileCacheSize=e.maxTileCacheSize,this._failIfMajorPerformanceCaveat=e.failIfMajorPerformanceCaveat,this._preserveDrawingBuffer=e.preserveDrawingBuffer,this._antialias=e.antialias,this._trackResize=e.trackResize,this._bearingSnap=e.bearingSnap,this._refreshExpiredTiles=e.refreshExpiredTiles,this._fadeDuration=e.fadeDuration,this._crossSourceCollisions=e.crossSourceCollisions,this._crossFadingFactor=1,this._collectResourceTiming=e.collectResourceTiming,this._renderTaskQueue=new En,this._controls=[],this._mapId=t.uniqueId(),this._requestManager=new t.RequestManager(e.transformRequest),\"string\"==typeof e.container){if(this._container=t.window.document.getElementById(e.container),!this._container)throw new Error(\"Container '\"+e.container+\"' not found.\")}else{if(!(e.container instanceof Ln))throw new Error(\"Invalid type: 'container' must be a String or HTMLElement.\");this._container=e.container}if(e.maxBounds&&this.setMaxBounds(e.maxBounds),t.bindAll([\"_onWindowOnline\",\"_onWindowResize\",\"_contextLost\",\"_contextRestored\"],this),this._setupContainer(),this._setupPainter(),void 0===this.painter)throw new Error(\"Failed to initialize WebGL.\");this.on(\"move\",function(){return i._update(!1)}),this.on(\"moveend\",function(){return i._update(!1)}),this.on(\"zoom\",function(){return i._update(!0)}),void 0!==t.window&&(t.window.addEventListener(\"online\",this._onWindowOnline,!1),t.window.addEventListener(\"resize\",this._onWindowResize,!1)),function(t,e){var n=t.getCanvasContainer(),i=null,a=!1,o=null;for(var s in Tn)t[s]=new Tn[s](t,e),e.interactive&&e[s]&&t[s].enable(e[s]);r.addEventListener(n,\"mouseout\",function(e){t.fire(new un(\"mouseout\",t,e))}),r.addEventListener(n,\"mousedown\",function(i){a=!0,o=r.mousePos(n,i);var s=new un(\"mousedown\",t,i);t.fire(s),s.defaultPrevented||(e.interactive&&!t.doubleClickZoom.isActive()&&t.stop(),t.boxZoom.onMouseDown(i),t.boxZoom.isActive()||t.dragPan.isActive()||t.dragRotate.onMouseDown(i),t.boxZoom.isActive()||t.dragRotate.isActive()||t.dragPan.onMouseDown(i))}),r.addEventListener(n,\"mouseup\",function(e){var r=t.dragRotate.isActive();i&&!r&&t.fire(new un(\"contextmenu\",t,i)),i=null,a=!1,t.fire(new un(\"mouseup\",t,e))}),r.addEventListener(n,\"mousemove\",function(e){if(!t.dragPan.isActive()&&!t.dragRotate.isActive()){for(var r=e.target;r&&r!==n;)r=r.parentNode;r===n&&t.fire(new un(\"mousemove\",t,e))}}),r.addEventListener(n,\"mouseover\",function(e){for(var r=e.target;r&&r!==n;)r=r.parentNode;r===n&&t.fire(new un(\"mouseover\",t,e))}),r.addEventListener(n,\"touchstart\",function(r){var n=new hn(\"touchstart\",t,r);t.fire(n),n.defaultPrevented||(e.interactive&&t.stop(),t.boxZoom.isActive()||t.dragRotate.isActive()||t.dragPan.onTouchStart(r),t.touchZoomRotate.onStart(r),t.doubleClickZoom.onTouchStart(n))},{passive:!1}),r.addEventListener(n,\"touchmove\",function(e){t.fire(new hn(\"touchmove\",t,e))},{passive:!1}),r.addEventListener(n,\"touchend\",function(e){t.fire(new hn(\"touchend\",t,e))}),r.addEventListener(n,\"touchcancel\",function(e){t.fire(new hn(\"touchcancel\",t,e))}),r.addEventListener(n,\"click\",function(i){var a=r.mousePos(n,i);(a.equals(o)||a.dist(o)<e.clickTolerance)&&t.fire(new un(\"click\",t,i))}),r.addEventListener(n,\"dblclick\",function(e){var r=new un(\"dblclick\",t,e);t.fire(r),r.defaultPrevented||t.doubleClickZoom.onDblClick(r)}),r.addEventListener(n,\"contextmenu\",function(e){var r=t.dragRotate.isActive();a||r?a&&(i=e):t.fire(new un(\"contextmenu\",t,e)),(t.dragRotate.isEnabled()||t.listens(\"contextmenu\"))&&e.preventDefault()}),r.addEventListener(n,\"wheel\",function(r){e.interactive&&t.stop();var n=new fn(\"wheel\",t,r);t.fire(n),n.defaultPrevented||t.scrollZoom.onWheel(r)},{passive:!1})}(this,e),this._hash=e.hash&&(new cn).addTo(this),this._hash&&this._hash._onHashChange()||(this.jumpTo({center:e.center,zoom:e.zoom,bearing:e.bearing,pitch:e.pitch}),e.bounds&&(this.resize(),this.fitBounds(e.bounds,t.extend({},e.fitBoundsOptions,{duration:0})))),this.resize(),this._localIdeographFontFamily=e.localIdeographFontFamily,e.style&&this.setStyle(e.style,{localIdeographFontFamily:e.localIdeographFontFamily}),e.attributionControl&&this.addControl(new Mn({customAttribution:e.customAttribution})),this.addControl(new Sn,e.logoPosition),this.on(\"style.load\",function(){i.transform.unmodified&&i.jumpTo(i.style.stylesheet)}),this.on(\"data\",function(e){i._update(\"style\"===e.dataType),i.fire(new t.Event(e.dataType+\"data\",e))}),this.on(\"dataloading\",function(e){i.fire(new t.Event(e.dataType+\"dataloading\",e))})}n&&(i.__proto__=n),i.prototype=Object.create(n&&n.prototype),i.prototype.constructor=i;var a={showTileBoundaries:{configurable:!0},showCollisionBoxes:{configurable:!0},showOverdrawInspector:{configurable:!0},repaint:{configurable:!0},vertices:{configurable:!0}};return i.prototype._getMapId=function(){return this._mapId},i.prototype.addControl=function(e,r){if(void 0===r&&e.getDefaultPosition&&(r=e.getDefaultPosition()),void 0===r&&(r=\"top-right\"),!e||!e.onAdd)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.addControl(). Argument must be a control with onAdd and onRemove methods.\")));var n=e.onAdd(this);this._controls.push(e);var i=this._controlPositions[r];return-1!==r.indexOf(\"bottom\")?i.insertBefore(n,i.firstChild):i.appendChild(n),this},i.prototype.removeControl=function(e){if(!e||!e.onRemove)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.removeControl(). Argument must be a control with onAdd and onRemove methods.\")));var r=this._controls.indexOf(e);return r>-1&&this._controls.splice(r,1),e.onRemove(this),this},i.prototype.resize=function(e){var r=this._containerDimensions(),n=r[0],i=r[1];return this._resizeCanvas(n,i),this.transform.resize(n,i),this.painter.resize(n,i),this.fire(new t.Event(\"movestart\",e)).fire(new t.Event(\"move\",e)).fire(new t.Event(\"resize\",e)).fire(new t.Event(\"moveend\",e)),this},i.prototype.getBounds=function(){return this.transform.getBounds()},i.prototype.getMaxBounds=function(){return this.transform.getMaxBounds()},i.prototype.setMaxBounds=function(e){return this.transform.setMaxBounds(t.LngLatBounds.convert(e)),this._update()},i.prototype.setMinZoom=function(t){if((t=null==t?0:t)>=0&&t<=this.transform.maxZoom)return this.transform.minZoom=t,this._update(),this.getZoom()<t&&this.setZoom(t),this;throw new Error(\"minZoom must be between 0 and the current maxZoom, inclusive\")},i.prototype.getMinZoom=function(){return this.transform.minZoom},i.prototype.setMaxZoom=function(t){if((t=null==t?22:t)>=this.transform.minZoom)return this.transform.maxZoom=t,this._update(),this.getZoom()>t&&this.setZoom(t),this;throw new Error(\"maxZoom must be greater than the current minZoom\")},i.prototype.getRenderWorldCopies=function(){return this.transform.renderWorldCopies},i.prototype.setRenderWorldCopies=function(t){return this.transform.renderWorldCopies=t,this._update()},i.prototype.getMaxZoom=function(){return this.transform.maxZoom},i.prototype.project=function(e){return this.transform.locationPoint(t.LngLat.convert(e))},i.prototype.unproject=function(e){return this.transform.pointLocation(t.Point.convert(e))},i.prototype.isMoving=function(){return this._moving||this.dragPan.isActive()||this.dragRotate.isActive()||this.scrollZoom.isActive()},i.prototype.isZooming=function(){return this._zooming||this.scrollZoom.isZooming()},i.prototype.isRotating=function(){return this._rotating||this.dragRotate.isActive()},i.prototype.on=function(t,e,r){var i=this;if(void 0===r)return n.prototype.on.call(this,t,e);var a=function(){var n;if(\"mouseenter\"===t||\"mouseover\"===t){var a=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){var o=i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[];o.length?a||(a=!0,r.call(i,new un(t,i,n.originalEvent,{features:o}))):a=!1},mouseout:function(){a=!1}}}}if(\"mouseleave\"===t||\"mouseout\"===t){var o=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){(i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[]).length?o=!0:o&&(o=!1,r.call(i,new un(t,i,n.originalEvent)))},mouseout:function(e){o&&(o=!1,r.call(i,new un(t,i,e.originalEvent)))}}}}return{layer:e,listener:r,delegates:(n={},n[t]=function(t){var n=i.getLayer(e)?i.queryRenderedFeatures(t.point,{layers:[e]}):[];n.length&&(t.features=n,r.call(i,t),delete t.features)},n)}}();for(var o in this._delegatedListeners=this._delegatedListeners||{},this._delegatedListeners[t]=this._delegatedListeners[t]||[],this._delegatedListeners[t].push(a),a.delegates)this.on(o,a.delegates[o]);return this},i.prototype.off=function(t,e,r){if(void 0===r)return n.prototype.off.call(this,t,e);if(this._delegatedListeners&&this._delegatedListeners[t])for(var i=this._delegatedListeners[t],a=0;a<i.length;a++){var o=i[a];if(o.layer===e&&o.listener===r){for(var s in o.delegates)this.off(s,o.delegates[s]);return i.splice(a,1),this}}return this},i.prototype.queryRenderedFeatures=function(e,r){if(!this.style)return[];var n;if(void 0!==r||void 0===e||e instanceof t.Point||Array.isArray(e)||(r=e,e=void 0),r=r||{},(e=e||[[0,0],[this.transform.width,this.transform.height]])instanceof t.Point||\"number\"==typeof e[0])n=[t.Point.convert(e)];else{var i=t.Point.convert(e[0]),a=t.Point.convert(e[1]);n=[i,new t.Point(a.x,i.y),a,new t.Point(i.x,a.y),i]}return this.style.queryRenderedFeatures(n,r,this.transform)},i.prototype.querySourceFeatures=function(t,e){return this.style.querySourceFeatures(t,e)},i.prototype.setStyle=function(e,r){return!1!==(r=t.extend({},{localIdeographFontFamily:Pn.localIdeographFontFamily},r)).diff&&r.localIdeographFontFamily===this._localIdeographFontFamily&&this.style&&e?(this._diffStyle(e,r),this):(this._localIdeographFontFamily=r.localIdeographFontFamily,this._updateStyle(e,r))},i.prototype._updateStyle=function(t,e){return this.style&&(this.style.setEventedParent(null),this.style._remove()),t?(this.style=new De(this,e||{}),this.style.setEventedParent(this,{style:this.style}),\"string\"==typeof t?this.style.loadURL(t):this.style.loadJSON(t),this):(delete this.style,this)},i.prototype._diffStyle=function(e,r){var n=this;if(\"string\"==typeof e){var i=this._requestManager.normalizeStyleURL(e),a=this._requestManager.transformRequest(i,t.ResourceType.Style);t.getJSON(a,function(e,i){e?n.fire(new t.ErrorEvent(e)):i&&n._updateDiff(i,r)})}else\"object\"==typeof e&&this._updateDiff(e,r)},i.prototype._updateDiff=function(e,r){try{this.style.setState(e)&&this._update(!0)}catch(n){t.warnOnce(\"Unable to perform style diff: \"+(n.message||n.error||n)+\".  Rebuilding the style from scratch.\"),this._updateStyle(e,r)}},i.prototype.getStyle=function(){if(this.style)return this.style.serialize()},i.prototype.isStyleLoaded=function(){return this.style?this.style.loaded():t.warnOnce(\"There is no style added to the map.\")},i.prototype.addSource=function(t,e){return this.style.addSource(t,e),this._update(!0)},i.prototype.isSourceLoaded=function(e){var r=this.style&&this.style.sourceCaches[e];if(void 0!==r)return r.loaded();this.fire(new t.ErrorEvent(new Error(\"There is no source with ID '\"+e+\"'\")))},i.prototype.areTilesLoaded=function(){var t=this.style&&this.style.sourceCaches;for(var e in t){var r=t[e]._tiles;for(var n in r){var i=r[n];if(\"loaded\"!==i.state&&\"errored\"!==i.state)return!1}}return!0},i.prototype.addSourceType=function(t,e,r){return this.style.addSourceType(t,e,r)},i.prototype.removeSource=function(t){return this.style.removeSource(t),this._update(!0)},i.prototype.getSource=function(t){return this.style.getSource(t)},i.prototype.addImage=function(e,r,n){void 0===n&&(n={});var i=n.pixelRatio;void 0===i&&(i=1);var a=n.sdf;if(void 0===a&&(a=!1),r instanceof Cn){var o=t.browser.getImageData(r),s=o.width,l=o.height,c=o.data;this.style.addImage(e,{data:new t.RGBAImage({width:s,height:l},c),pixelRatio:i,sdf:a,version:0})}else{if(void 0===r.width||void 0===r.height)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.addImage(). The second argument must be an `HTMLImageElement`, `ImageData`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));var u=r.width,h=r.height,f=r.data,p=r;this.style.addImage(e,{data:new t.RGBAImage({width:u,height:h},new Uint8Array(f)),pixelRatio:i,sdf:a,version:0,userImage:p}),p.onAdd&&p.onAdd(this,e)}},i.prototype.updateImage=function(e,r){var n=this.style.getImage(e);if(!n)return this.fire(new t.ErrorEvent(new Error(\"The map has no image with that id. If you are adding a new image use `map.addImage(...)` instead.\")));var i=r instanceof Cn?t.browser.getImageData(r):r,a=i.width,o=i.height,s=i.data;if(void 0===a||void 0===o)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.updateImage(). The second argument must be an `HTMLImageElement`, `ImageData`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));if(a!==n.data.width||o!==n.data.height)return this.fire(new t.ErrorEvent(new Error(\"The width and height of the updated image must be that same as the previous version of the image\")));var l=!(r instanceof Cn);n.data.replace(s,l),this.style.updateImage(e,n)},i.prototype.hasImage=function(e){return e?!!this.style.getImage(e):(this.fire(new t.ErrorEvent(new Error(\"Missing required image id\"))),!1)},i.prototype.removeImage=function(t){this.style.removeImage(t)},i.prototype.loadImage=function(e,r){t.getImage(this._requestManager.transformRequest(e,t.ResourceType.Image),r)},i.prototype.listImages=function(){return this.style.listImages()},i.prototype.addLayer=function(t,e){return this.style.addLayer(t,e),this._update(!0)},i.prototype.moveLayer=function(t,e){return this.style.moveLayer(t,e),this._update(!0)},i.prototype.removeLayer=function(t){return this.style.removeLayer(t),this._update(!0)},i.prototype.getLayer=function(t){return this.style.getLayer(t)},i.prototype.setFilter=function(t,e,r){return void 0===r&&(r={}),this.style.setFilter(t,e,r),this._update(!0)},i.prototype.setLayerZoomRange=function(t,e,r){return this.style.setLayerZoomRange(t,e,r),this._update(!0)},i.prototype.getFilter=function(t){return this.style.getFilter(t)},i.prototype.setPaintProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setPaintProperty(t,e,r,n),this._update(!0)},i.prototype.getPaintProperty=function(t,e){return this.style.getPaintProperty(t,e)},i.prototype.setLayoutProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setLayoutProperty(t,e,r,n),this._update(!0)},i.prototype.getLayoutProperty=function(t,e){return this.style.getLayoutProperty(t,e)},i.prototype.setLight=function(t,e){return void 0===e&&(e={}),this.style.setLight(t,e),this._update(!0)},i.prototype.getLight=function(){return this.style.getLight()},i.prototype.setFeatureState=function(t,e){return this.style.setFeatureState(t,e),this._update()},i.prototype.removeFeatureState=function(t,e){return this.style.removeFeatureState(t,e),this._update()},i.prototype.getFeatureState=function(t){return this.style.getFeatureState(t)},i.prototype.getContainer=function(){return this._container},i.prototype.getCanvasContainer=function(){return this._canvasContainer},i.prototype.getCanvas=function(){return this._canvas},i.prototype._containerDimensions=function(){var t=0,e=0;return this._container&&(t=this._container.clientWidth||400,e=this._container.clientHeight||300),[t,e]},i.prototype._detectMissingCSS=function(){\"rgb(250, 128, 114)\"!==t.window.getComputedStyle(this._missingCSSCanary).getPropertyValue(\"background-color\")&&t.warnOnce(\"This page appears to be missing CSS declarations for Mapbox GL JS, which may cause the map to display incorrectly. Please ensure your page includes mapbox-gl.css, as described in https://www.mapbox.com/mapbox-gl-js/api/.\")},i.prototype._setupContainer=function(){var t=this._container;t.classList.add(\"mapboxgl-map\"),(this._missingCSSCanary=r.create(\"div\",\"mapboxgl-canary\",t)).style.visibility=\"hidden\",this._detectMissingCSS();var e=this._canvasContainer=r.create(\"div\",\"mapboxgl-canvas-container\",t);this._interactive&&e.classList.add(\"mapboxgl-interactive\"),this._canvas=r.create(\"canvas\",\"mapboxgl-canvas\",e),this._canvas.style.position=\"absolute\",this._canvas.addEventListener(\"webglcontextlost\",this._contextLost,!1),this._canvas.addEventListener(\"webglcontextrestored\",this._contextRestored,!1),this._canvas.setAttribute(\"tabindex\",\"0\"),this._canvas.setAttribute(\"aria-label\",\"Map\");var n=this._containerDimensions();this._resizeCanvas(n[0],n[1]);var i=this._controlContainer=r.create(\"div\",\"mapboxgl-control-container\",t),a=this._controlPositions={};[\"top-left\",\"top-right\",\"bottom-left\",\"bottom-right\"].forEach(function(t){a[t]=r.create(\"div\",\"mapboxgl-ctrl-\"+t,i)})},i.prototype._resizeCanvas=function(e,r){var n=t.window.devicePixelRatio||1;this._canvas.width=n*e,this._canvas.height=n*r,this._canvas.style.width=e+\"px\",this._canvas.style.height=r+\"px\"},i.prototype._setupPainter=function(){var r=t.extend({},e.webGLContextAttributes,{failIfMajorPerformanceCaveat:this._failIfMajorPerformanceCaveat,preserveDrawingBuffer:this._preserveDrawingBuffer,antialias:this._antialias||!1}),n=this._canvas.getContext(\"webgl\",r)||this._canvas.getContext(\"experimental-webgl\",r);n?(this.painter=new rn(n,this.transform),t.webpSupported.testSupport(n)):this.fire(new t.ErrorEvent(new Error(\"Failed to initialize WebGL\")))},i.prototype._contextLost=function(e){e.preventDefault(),this._frame&&(this._frame.cancel(),this._frame=null),this.fire(new t.Event(\"webglcontextlost\",{originalEvent:e}))},i.prototype._contextRestored=function(e){this._setupPainter(),this.resize(),this._update(),this.fire(new t.Event(\"webglcontextrestored\",{originalEvent:e}))},i.prototype.loaded=function(){return!this._styleDirty&&!this._sourcesDirty&&!!this.style&&this.style.loaded()},i.prototype._update=function(t){return this.style?(this._styleDirty=this._styleDirty||t,this._sourcesDirty=!0,this.triggerRepaint(),this):this},i.prototype._requestRenderFrame=function(t){return this._update(),this._renderTaskQueue.add(t)},i.prototype._cancelRenderFrame=function(t){this._renderTaskQueue.remove(t)},i.prototype._render=function(){this.painter.context.setDirty(),this.painter.setBaseState(),this._renderTaskQueue.run();var e=!1;if(this.style&&this._styleDirty){this._styleDirty=!1;var r=this.transform.zoom,n=t.browser.now();this.style.zoomHistory.update(r,n);var i=new t.EvaluationParameters(r,{now:n,fadeDuration:this._fadeDuration,zoomHistory:this.style.zoomHistory,transition:this.style.getTransition()}),a=i.crossFadingFactor();1===a&&a===this._crossFadingFactor||(e=!0,this._crossFadingFactor=a),this.style.update(i)}return this.style&&this._sourcesDirty&&(this._sourcesDirty=!1,this.style._updateSources(this.transform)),this._placementDirty=this.style&&this.style._updatePlacement(this.painter.transform,this.showCollisionBoxes,this._fadeDuration,this._crossSourceCollisions),this.painter.render(this.style,{showTileBoundaries:this.showTileBoundaries,showOverdrawInspector:this._showOverdrawInspector,rotating:this.isRotating(),zooming:this.isZooming(),moving:this.isMoving(),fadeDuration:this._fadeDuration}),this.fire(new t.Event(\"render\")),this.loaded()&&!this._loaded&&(this._loaded=!0,this.fire(new t.Event(\"load\"))),this.style&&(this.style.hasTransitions()||e)&&(this._styleDirty=!0),this.style&&!this._placementDirty&&this.style._releaseSymbolFadeTiles(),this._sourcesDirty||this._repaint||this._styleDirty||this._placementDirty?this.triggerRepaint():!this.isMoving()&&this.loaded()&&this.fire(new t.Event(\"idle\")),this},i.prototype.remove=function(){this._hash&&this._hash.remove();for(var e=0,r=this._controls;e<r.length;e+=1)r[e].onRemove(this);this._controls=[],this._frame&&(this._frame.cancel(),this._frame=null),this._renderTaskQueue.clear(),this.setStyle(null),void 0!==t.window&&(t.window.removeEventListener(\"resize\",this._onWindowResize,!1),t.window.removeEventListener(\"online\",this._onWindowOnline,!1));var n=this.painter.context.gl.getExtension(\"WEBGL_lose_context\");n&&n.loseContext(),zn(this._canvasContainer),zn(this._controlContainer),zn(this._missingCSSCanary),this._container.classList.remove(\"mapboxgl-map\"),this.fire(new t.Event(\"remove\"))},i.prototype.triggerRepaint=function(){var e=this;this.style&&!this._frame&&(this._frame=t.browser.frame(function(){e._frame=null,e._render()}))},i.prototype._onWindowOnline=function(){this._update()},i.prototype._onWindowResize=function(){this._trackResize&&this.resize()._update()},a.showTileBoundaries.get=function(){return!!this._showTileBoundaries},a.showTileBoundaries.set=function(t){this._showTileBoundaries!==t&&(this._showTileBoundaries=t,this._update())},a.showCollisionBoxes.get=function(){return!!this._showCollisionBoxes},a.showCollisionBoxes.set=function(t){this._showCollisionBoxes!==t&&(this._showCollisionBoxes=t,t?this.style._generateCollisionBoxes():this._update())},a.showOverdrawInspector.get=function(){return!!this._showOverdrawInspector},a.showOverdrawInspector.set=function(t){this._showOverdrawInspector!==t&&(this._showOverdrawInspector=t,this._update())},a.repaint.get=function(){return!!this._repaint},a.repaint.set=function(t){this._repaint!==t&&(this._repaint=t,this.triggerRepaint())},a.vertices.get=function(){return!!this._vertices},a.vertices.set=function(t){this._vertices=t,this._update()},i.prototype._setCacheLimits=function(e,r){t.setCacheLimits(e,r)},Object.defineProperties(i.prototype,a),i}(An);function zn(t){t.parentNode&&t.parentNode.removeChild(t)}var In={showCompass:!0,showZoom:!0},Dn=function(e){var n=this;this.options=t.extend({},In,e),this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),this._container.addEventListener(\"contextmenu\",function(t){return t.preventDefault()}),this.options.showZoom&&(t.bindAll([\"_updateZoomButtons\"],this),this._zoomInButton=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-zoom-in\",\"Zoom in\",function(){return n._map.zoomIn()}),this._zoomOutButton=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-zoom-out\",\"Zoom out\",function(){return n._map.zoomOut()})),this.options.showCompass&&(t.bindAll([\"_rotateCompassArrow\"],this),this._compass=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-compass\",\"Reset bearing to north\",function(){return n._map.resetNorth()}),this._compassArrow=r.create(\"span\",\"mapboxgl-ctrl-compass-arrow\",this._compass))};function Rn(e,r,n){if(e=new t.LngLat(e.lng,e.lat),r){var i=new t.LngLat(e.lng-360,e.lat),a=new t.LngLat(e.lng+360,e.lat),o=n.locationPoint(e).distSqr(r);n.locationPoint(i).distSqr(r)<o?e=i:n.locationPoint(a).distSqr(r)<o&&(e=a)}for(;Math.abs(e.lng-n.center.lng)>180;){var s=n.locationPoint(e);if(s.x>=0&&s.y>=0&&s.x<=n.width&&s.y<=n.height)break;e.lng>n.center.lng?e.lng-=360:e.lng+=360}return e}Dn.prototype._updateZoomButtons=function(){var t=this._map.getZoom();this._zoomInButton.classList.toggle(\"mapboxgl-ctrl-icon-disabled\",t===this._map.getMaxZoom()),this._zoomOutButton.classList.toggle(\"mapboxgl-ctrl-icon-disabled\",t===this._map.getMinZoom())},Dn.prototype._rotateCompassArrow=function(){var t=\"rotate(\"+this._map.transform.angle*(180/Math.PI)+\"deg)\";this._compassArrow.style.transform=t},Dn.prototype.onAdd=function(t){return this._map=t,this.options.showZoom&&(this._map.on(\"zoom\",this._updateZoomButtons),this._updateZoomButtons()),this.options.showCompass&&(this._map.on(\"rotate\",this._rotateCompassArrow),this._rotateCompassArrow(),this._handler=new vn(t,{button:\"left\",element:this._compass}),r.addEventListener(this._compass,\"mousedown\",this._handler.onMouseDown),this._handler.enable()),this._container},Dn.prototype.onRemove=function(){r.remove(this._container),this.options.showZoom&&this._map.off(\"zoom\",this._updateZoomButtons),this.options.showCompass&&(this._map.off(\"rotate\",this._rotateCompassArrow),r.removeEventListener(this._compass,\"mousedown\",this._handler.onMouseDown),this._handler.disable(),delete this._handler),delete this._map},Dn.prototype._createButton=function(t,e,n){var i=r.create(\"button\",t,this._container);return i.type=\"button\",i.title=e,i.setAttribute(\"aria-label\",e),i.addEventListener(\"click\",n),i};var Fn={center:\"translate(-50%,-50%)\",top:\"translate(-50%,0)\",\"top-left\":\"translate(0,0)\",\"top-right\":\"translate(-100%,0)\",bottom:\"translate(-50%,-100%)\",\"bottom-left\":\"translate(0,-100%)\",\"bottom-right\":\"translate(-100%,-100%)\",left:\"translate(0,-50%)\",right:\"translate(-100%,-50%)\"};function Bn(t,e,r){var n=t.classList;for(var i in Fn)n.remove(\"mapboxgl-\"+r+\"-anchor-\"+i);n.add(\"mapboxgl-\"+r+\"-anchor-\"+e)}var Nn,jn=function(e){function n(n,i){if(e.call(this),(n instanceof t.window.HTMLElement||i)&&(n=t.extend({element:n},i)),t.bindAll([\"_update\",\"_onMove\",\"_onUp\",\"_addDragHandler\",\"_onMapClick\"],this),this._anchor=n&&n.anchor||\"center\",this._color=n&&n.color||\"#3FB1CE\",this._draggable=n&&n.draggable||!1,this._state=\"inactive\",n&&n.element)this._element=n.element,this._offset=t.Point.convert(n&&n.offset||[0,0]);else{this._defaultMarker=!0,this._element=r.create(\"div\");var a=r.createNS(\"http://www.w3.org/2000/svg\",\"svg\");a.setAttributeNS(null,\"display\",\"block\"),a.setAttributeNS(null,\"height\",\"41px\"),a.setAttributeNS(null,\"width\",\"27px\"),a.setAttributeNS(null,\"viewBox\",\"0 0 27 41\");var o=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");o.setAttributeNS(null,\"stroke\",\"none\"),o.setAttributeNS(null,\"stroke-width\",\"1\"),o.setAttributeNS(null,\"fill\",\"none\"),o.setAttributeNS(null,\"fill-rule\",\"evenodd\");var s=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");s.setAttributeNS(null,\"fill-rule\",\"nonzero\");var l=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");l.setAttributeNS(null,\"transform\",\"translate(3.0, 29.0)\"),l.setAttributeNS(null,\"fill\",\"#000000\");for(var c=0,u=[{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"9.5\",ry:\"4.77275007\"},{rx:\"8.5\",ry:\"4.29549936\"},{rx:\"7.5\",ry:\"3.81822308\"},{rx:\"6.5\",ry:\"3.34094679\"},{rx:\"5.5\",ry:\"2.86367051\"},{rx:\"4.5\",ry:\"2.38636864\"}];c<u.length;c+=1){var h=u[c],f=r.createNS(\"http://www.w3.org/2000/svg\",\"ellipse\");f.setAttributeNS(null,\"opacity\",\"0.04\"),f.setAttributeNS(null,\"cx\",\"10.5\"),f.setAttributeNS(null,\"cy\",\"5.80029008\"),f.setAttributeNS(null,\"rx\",h.rx),f.setAttributeNS(null,\"ry\",h.ry),l.appendChild(f)}var p=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");p.setAttributeNS(null,\"fill\",this._color);var d=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");d.setAttributeNS(null,\"d\",\"M27,13.5 C27,19.074644 20.250001,27.000002 14.75,34.500002 C14.016665,35.500004 12.983335,35.500004 12.25,34.500002 C6.7499993,27.000002 0,19.222562 0,13.5 C0,6.0441559 6.0441559,0 13.5,0 C20.955844,0 27,6.0441559 27,13.5 Z\"),p.appendChild(d);var g=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");g.setAttributeNS(null,\"opacity\",\"0.25\"),g.setAttributeNS(null,\"fill\",\"#000000\");var v=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");v.setAttributeNS(null,\"d\",\"M13.5,0 C6.0441559,0 0,6.0441559 0,13.5 C0,19.222562 6.7499993,27 12.25,34.5 C13,35.522727 14.016664,35.500004 14.75,34.5 C20.250001,27 27,19.074644 27,13.5 C27,6.0441559 20.955844,0 13.5,0 Z M13.5,1 C20.415404,1 26,6.584596 26,13.5 C26,15.898657 24.495584,19.181431 22.220703,22.738281 C19.945823,26.295132 16.705119,30.142167 13.943359,33.908203 C13.743445,34.180814 13.612715,34.322738 13.5,34.441406 C13.387285,34.322738 13.256555,34.180814 13.056641,33.908203 C10.284481,30.127985 7.4148684,26.314159 5.015625,22.773438 C2.6163816,19.232715 1,15.953538 1,13.5 C1,6.584596 6.584596,1 13.5,1 Z\"),g.appendChild(v);var m=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");m.setAttributeNS(null,\"transform\",\"translate(6.0, 7.0)\"),m.setAttributeNS(null,\"fill\",\"#FFFFFF\");var y=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");y.setAttributeNS(null,\"transform\",\"translate(8.0, 8.0)\");var x=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");x.setAttributeNS(null,\"fill\",\"#000000\"),x.setAttributeNS(null,\"opacity\",\"0.25\"),x.setAttributeNS(null,\"cx\",\"5.5\"),x.setAttributeNS(null,\"cy\",\"5.5\"),x.setAttributeNS(null,\"r\",\"5.4999962\");var b=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");b.setAttributeNS(null,\"fill\",\"#FFFFFF\"),b.setAttributeNS(null,\"cx\",\"5.5\"),b.setAttributeNS(null,\"cy\",\"5.5\"),b.setAttributeNS(null,\"r\",\"5.4999962\"),y.appendChild(x),y.appendChild(b),s.appendChild(l),s.appendChild(p),s.appendChild(g),s.appendChild(m),s.appendChild(y),a.appendChild(s),this._element.appendChild(a),this._offset=t.Point.convert(n&&n.offset||[0,-14])}this._element.classList.add(\"mapboxgl-marker\"),this._element.addEventListener(\"dragstart\",function(t){t.preventDefault()}),Bn(this._element,this._anchor,\"marker\"),this._popup=null}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.addTo=function(t){return this.remove(),this._map=t,t.getCanvasContainer().appendChild(this._element),t.on(\"move\",this._update),t.on(\"moveend\",this._update),this.setDraggable(this._draggable),this._update(),this._map.on(\"click\",this._onMapClick),this},n.prototype.remove=function(){return this._map&&(this._map.off(\"click\",this._onMapClick),this._map.off(\"move\",this._update),this._map.off(\"moveend\",this._update),this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler),this._map.off(\"mouseup\",this._onUp),this._map.off(\"touchend\",this._onUp),delete this._map),r.remove(this._element),this._popup&&this._popup.remove(),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._popup&&this._popup.setLngLat(this._lngLat),this._update(),this},n.prototype.getElement=function(){return this._element},n.prototype.setPopup=function(t){if(this._popup&&(this._popup.remove(),this._popup=null),t){if(!(\"offset\"in t.options)){var e=Math.sqrt(Math.pow(13.5,2)/2);t.options.offset=this._defaultMarker?{top:[0,0],\"top-left\":[0,0],\"top-right\":[0,0],bottom:[0,-38.1],\"bottom-left\":[e,-1*(24.6+e)],\"bottom-right\":[-e,-1*(24.6+e)],left:[13.5,-24.6],right:[-13.5,-24.6]}:this._offset}this._popup=t,this._lngLat&&this._popup.setLngLat(this._lngLat)}return this},n.prototype._onMapClick=function(t){var e=t.originalEvent.target,r=this._element;this._popup&&(e===r||r.contains(e))&&this.togglePopup()},n.prototype.getPopup=function(){return this._popup},n.prototype.togglePopup=function(){var t=this._popup;return t?(t.isOpen()?t.remove():t.addTo(this._map),this):this},n.prototype._update=function(t){this._map&&(this._map.transform.renderWorldCopies&&(this._lngLat=Rn(this._lngLat,this._pos,this._map.transform)),this._pos=this._map.project(this._lngLat)._add(this._offset),t&&\"moveend\"!==t.type||(this._pos=this._pos.round()),r.setTransform(this._element,Fn[this._anchor]+\" translate(\"+this._pos.x+\"px, \"+this._pos.y+\"px)\"))},n.prototype.getOffset=function(){return this._offset},n.prototype.setOffset=function(e){return this._offset=t.Point.convert(e),this._update(),this},n.prototype._onMove=function(e){this._pos=e.point.sub(this._positionDelta),this._lngLat=this._map.unproject(this._pos),this.setLngLat(this._lngLat),this._element.style.pointerEvents=\"none\",\"pending\"===this._state&&(this._state=\"active\",this.fire(new t.Event(\"dragstart\"))),this.fire(new t.Event(\"drag\"))},n.prototype._onUp=function(){this._element.style.pointerEvents=\"auto\",this._positionDelta=null,this._map.off(\"mousemove\",this._onMove),this._map.off(\"touchmove\",this._onMove),\"active\"===this._state&&this.fire(new t.Event(\"dragend\")),this._state=\"inactive\"},n.prototype._addDragHandler=function(t){this._element.contains(t.originalEvent.target)&&(t.preventDefault(),this._positionDelta=t.point.sub(this._pos).add(this._offset),this._state=\"pending\",this._map.on(\"mousemove\",this._onMove),this._map.on(\"touchmove\",this._onMove),this._map.once(\"mouseup\",this._onUp),this._map.once(\"touchend\",this._onUp))},n.prototype.setDraggable=function(t){return this._draggable=!!t,this._map&&(t?(this._map.on(\"mousedown\",this._addDragHandler),this._map.on(\"touchstart\",this._addDragHandler)):(this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler))),this},n.prototype.isDraggable=function(){return this._draggable},n}(t.Evented),Un={positionOptions:{enableHighAccuracy:!1,maximumAge:0,timeout:6e3},fitBoundsOptions:{maxZoom:15},trackUserLocation:!1,showUserLocation:!0},Vn=function(e){function n(r){e.call(this),this.options=t.extend({},Un,r),t.bindAll([\"_onSuccess\",\"_onError\",\"_finish\",\"_setupUI\",\"_updateCamera\",\"_updateMarker\"],this)}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.onAdd=function(e){var n;return this._map=e,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),n=this._setupUI,void 0!==Nn?n(Nn):void 0!==t.window.navigator.permissions?t.window.navigator.permissions.query({name:\"geolocation\"}).then(function(t){Nn=\"denied\"!==t.state,n(Nn)}):(Nn=!!t.window.navigator.geolocation,n(Nn)),this._container},n.prototype.onRemove=function(){void 0!==this._geolocationWatchID&&(t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0),this.options.showUserLocation&&this._userLocationDotMarker&&this._userLocationDotMarker.remove(),r.remove(this._container),this._map=void 0},n.prototype._onSuccess=function(e){if(this.options.trackUserLocation)switch(this._lastKnownPosition=e,this._watchState){case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"BACKGROUND\":case\"BACKGROUND_ERROR\":this._watchState=\"BACKGROUND\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\")}this.options.showUserLocation&&\"OFF\"!==this._watchState&&this._updateMarker(e),this.options.trackUserLocation&&\"ACTIVE_LOCK\"!==this._watchState||this._updateCamera(e),this.options.showUserLocation&&this._dotElement.classList.remove(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"geolocate\",e)),this._finish()},n.prototype._updateCamera=function(e){var r=new t.LngLat(e.coords.longitude,e.coords.latitude),n=e.coords.accuracy,i=this._map.getBearing(),a=t.extend({bearing:i},this.options.fitBoundsOptions);this._map.fitBounds(r.toBounds(n),a,{geolocateSource:!0})},n.prototype._updateMarker=function(t){t?this._userLocationDotMarker.setLngLat([t.coords.longitude,t.coords.latitude]).addTo(this._map):this._userLocationDotMarker.remove()},n.prototype._onError=function(e){if(this.options.trackUserLocation)if(1===e.code)this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),void 0!==this._geolocationWatchID&&this._clearWatch();else switch(this._watchState){case\"WAITING_ACTIVE\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"ACTIVE_LOCK\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\");break;case\"BACKGROUND\":this._watchState=\"BACKGROUND_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\")}\"OFF\"!==this._watchState&&this.options.showUserLocation&&this._dotElement.classList.add(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"error\",e)),this._finish()},n.prototype._finish=function(){this._timeoutId&&clearTimeout(this._timeoutId),this._timeoutId=void 0},n.prototype._setupUI=function(e){var n=this;!1!==e?(this._container.addEventListener(\"contextmenu\",function(t){return t.preventDefault()}),this._geolocateButton=r.create(\"button\",\"mapboxgl-ctrl-icon mapboxgl-ctrl-geolocate\",this._container),this._geolocateButton.type=\"button\",this._geolocateButton.setAttribute(\"aria-label\",\"Geolocate\"),this.options.trackUserLocation&&(this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this._watchState=\"OFF\"),this.options.showUserLocation&&(this._dotElement=r.create(\"div\",\"mapboxgl-user-location-dot\"),this._userLocationDotMarker=new jn(this._dotElement),this.options.trackUserLocation&&(this._watchState=\"OFF\")),this._geolocateButton.addEventListener(\"click\",this.trigger.bind(this)),this._setup=!0,this.options.trackUserLocation&&this._map.on(\"movestart\",function(e){e.geolocateSource||\"ACTIVE_LOCK\"!==n._watchState||(n._watchState=\"BACKGROUND\",n._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\"),n._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),n.fire(new t.Event(\"trackuserlocationend\")))})):t.warnOnce(\"Geolocation support is not available, the GeolocateControl will not be visible.\")},n.prototype.trigger=function(){if(!this._setup)return t.warnOnce(\"Geolocate control triggered before added to a map\"),!1;if(this.options.trackUserLocation){switch(this._watchState){case\"OFF\":this._watchState=\"WAITING_ACTIVE\",this.fire(new t.Event(\"trackuserlocationstart\"));break;case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":case\"BACKGROUND_ERROR\":this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this.fire(new t.Event(\"trackuserlocationend\"));break;case\"BACKGROUND\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._lastKnownPosition&&this._updateCamera(this._lastKnownPosition),this.fire(new t.Event(\"trackuserlocationstart\"))}switch(this._watchState){case\"WAITING_ACTIVE\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_LOCK\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"BACKGROUND\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\");break;case\"BACKGROUND_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\")}\"OFF\"===this._watchState&&void 0!==this._geolocationWatchID?this._clearWatch():void 0===this._geolocationWatchID&&(this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"true\"),this._geolocationWatchID=t.window.navigator.geolocation.watchPosition(this._onSuccess,this._onError,this.options.positionOptions))}else t.window.navigator.geolocation.getCurrentPosition(this._onSuccess,this._onError,this.options.positionOptions),this._timeoutId=setTimeout(this._finish,1e4);return!0},n.prototype._clearWatch=function(){t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0,this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this.options.showUserLocation&&this._updateMarker(null)},n}(t.Evented),qn={maxWidth:100,unit:\"metric\"},Hn=function(e){this.options=t.extend({},qn,e),t.bindAll([\"_onMove\",\"setUnit\"],this)};function Gn(t,e,r){var n,i,a,o,s,l,c=r&&r.maxWidth||100,u=t._container.clientHeight/2,h=(n=t.unproject([0,u]),i=t.unproject([c,u]),a=Math.PI/180,o=n.lat*a,s=i.lat*a,l=Math.sin(o)*Math.sin(s)+Math.cos(o)*Math.cos(s)*Math.cos((i.lng-n.lng)*a),6371e3*Math.acos(Math.min(l,1)));if(r&&\"imperial\"===r.unit){var f=3.2808*h;f>5280?Yn(e,c,f/5280,\"mi\"):Yn(e,c,f,\"ft\")}else r&&\"nautical\"===r.unit?Yn(e,c,h/1852,\"nm\"):Yn(e,c,h,\"m\")}function Yn(t,e,r,n){var i,a,o,s=(i=r,(a=Math.pow(10,(\"\"+Math.floor(i)).length-1))*(o=(o=i/a)>=10?10:o>=5?5:o>=3?3:o>=2?2:o>=1?1:function(t){var e=Math.pow(10,Math.ceil(-Math.log(t)/Math.LN10));return Math.round(t*e)/e}(o))),l=s/r;\"m\"===n&&s>=1e3&&(s/=1e3,n=\"km\"),t.style.width=e*l+\"px\",t.innerHTML=s+n}Hn.prototype.getDefaultPosition=function(){return\"bottom-left\"},Hn.prototype._onMove=function(){Gn(this._map,this._container,this.options)},Hn.prototype.onAdd=function(t){return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-scale\",t.getContainer()),this._map.on(\"move\",this._onMove),this._onMove(),this._container},Hn.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"move\",this._onMove),this._map=void 0},Hn.prototype.setUnit=function(t){this.options.unit=t,Gn(this._map,this._container,this.options)};var Wn=function(e){this._fullscreen=!1,e&&e.container&&(e.container instanceof t.window.HTMLElement?this._container=e.container:t.warnOnce(\"Full screen control 'container' must be a DOM element.\")),t.bindAll([\"_onClickFullscreen\",\"_changeIcon\"],this),\"onfullscreenchange\"in t.window.document?this._fullscreenchange=\"fullscreenchange\":\"onmozfullscreenchange\"in t.window.document?this._fullscreenchange=\"mozfullscreenchange\":\"onwebkitfullscreenchange\"in t.window.document?this._fullscreenchange=\"webkitfullscreenchange\":\"onmsfullscreenchange\"in t.window.document&&(this._fullscreenchange=\"MSFullscreenChange\"),this._className=\"mapboxgl-ctrl\"};Wn.prototype.onAdd=function(e){return this._map=e,this._container||(this._container=this._map.getContainer()),this._controlContainer=r.create(\"div\",this._className+\" mapboxgl-ctrl-group\"),this._checkFullscreenSupport()?this._setupUI():(this._controlContainer.style.display=\"none\",t.warnOnce(\"This device does not support fullscreen mode.\")),this._controlContainer},Wn.prototype.onRemove=function(){r.remove(this._controlContainer),this._map=null,t.window.document.removeEventListener(this._fullscreenchange,this._changeIcon)},Wn.prototype._checkFullscreenSupport=function(){return!!(t.window.document.fullscreenEnabled||t.window.document.mozFullScreenEnabled||t.window.document.msFullscreenEnabled||t.window.document.webkitFullscreenEnabled)},Wn.prototype._setupUI=function(){(this._fullscreenButton=r.create(\"button\",this._className+\"-icon \"+this._className+\"-fullscreen\",this._controlContainer)).type=\"button\",this._updateTitle(),this._fullscreenButton.addEventListener(\"click\",this._onClickFullscreen),t.window.document.addEventListener(this._fullscreenchange,this._changeIcon)},Wn.prototype._updateTitle=function(){var t=this._isFullscreen()?\"Exit fullscreen\":\"Enter fullscreen\";this._fullscreenButton.setAttribute(\"aria-label\",t),this._fullscreenButton.title=t},Wn.prototype._isFullscreen=function(){return this._fullscreen},Wn.prototype._changeIcon=function(){(t.window.document.fullscreenElement||t.window.document.mozFullScreenElement||t.window.document.webkitFullscreenElement||t.window.document.msFullscreenElement)===this._container!==this._fullscreen&&(this._fullscreen=!this._fullscreen,this._fullscreenButton.classList.toggle(this._className+\"-shrink\"),this._fullscreenButton.classList.toggle(this._className+\"-fullscreen\"),this._updateTitle())},Wn.prototype._onClickFullscreen=function(){this._isFullscreen()?t.window.document.exitFullscreen?t.window.document.exitFullscreen():t.window.document.mozCancelFullScreen?t.window.document.mozCancelFullScreen():t.window.document.msExitFullscreen?t.window.document.msExitFullscreen():t.window.document.webkitCancelFullScreen&&t.window.document.webkitCancelFullScreen():this._container.requestFullscreen?this._container.requestFullscreen():this._container.mozRequestFullScreen?this._container.mozRequestFullScreen():this._container.msRequestFullscreen?this._container.msRequestFullscreen():this._container.webkitRequestFullscreen&&this._container.webkitRequestFullscreen()};var Xn={closeButton:!0,closeOnClick:!0,className:\"\",maxWidth:\"240px\"},Zn=function(e){function n(r){e.call(this),this.options=t.extend(Object.create(Xn),r),t.bindAll([\"_update\",\"_onClickClose\",\"remove\"],this)}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.addTo=function(e){var r=this;return this._map=e,this.options.closeOnClick&&this._map.on(\"click\",this._onClickClose),this._map.on(\"remove\",this.remove),this._update(),this._trackPointer?(this._map.on(\"mousemove\",function(t){r._update(t.point)}),this._map.on(\"mouseup\",function(t){r._update(t.point)}),this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")):this._map.on(\"move\",this._update),this.fire(new t.Event(\"open\")),this},n.prototype.isOpen=function(){return!!this._map},n.prototype.remove=function(){return this._content&&r.remove(this._content),this._container&&(r.remove(this._container),delete this._container),this._map&&(this._map.off(\"move\",this._update),this._map.off(\"click\",this._onClickClose),this._map.off(\"remove\",this.remove),this._map.off(\"mousemove\"),delete this._map),this.fire(new t.Event(\"close\")),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._map&&(this._map.on(\"move\",this._update),this._map.off(\"mousemove\"),this._container.classList.remove(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.remove(\"mapboxgl-track-pointer\")),this._trackPointer=!1,this._update(),this},n.prototype.trackPointer=function(){var t=this;return this._trackPointer=!0,this._pos=null,this._map&&(this._map.off(\"move\",this._update),this._map.on(\"mousemove\",function(e){t._update(e.point)}),this._map.on(\"drag\",function(e){t._update(e.point)}),this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")),this},n.prototype.getElement=function(){return this._container},n.prototype.setText=function(e){return this.setDOMContent(t.window.document.createTextNode(e))},n.prototype.setHTML=function(e){var r,n=t.window.document.createDocumentFragment(),i=t.window.document.createElement(\"body\");for(i.innerHTML=e;r=i.firstChild;)n.appendChild(r);return this.setDOMContent(n)},n.prototype.getMaxWidth=function(){return this._container.style.maxWidth},n.prototype.setMaxWidth=function(t){return this.options.maxWidth=t,this._update(),this},n.prototype.setDOMContent=function(t){return this._createContent(),this._content.appendChild(t),this._update(),this},n.prototype._createContent=function(){this._content&&r.remove(this._content),this._content=r.create(\"div\",\"mapboxgl-popup-content\",this._container),this.options.closeButton&&(this._closeButton=r.create(\"button\",\"mapboxgl-popup-close-button\",this._content),this._closeButton.type=\"button\",this._closeButton.setAttribute(\"aria-label\",\"Close popup\"),this._closeButton.innerHTML=\"&#215;\",this._closeButton.addEventListener(\"click\",this._onClickClose))},n.prototype._update=function(e){var n=this,i=this._lngLat||this._trackPointer;if(this._map&&i&&this._content&&(this._container||(this._container=r.create(\"div\",\"mapboxgl-popup\",this._map.getContainer()),this._tip=r.create(\"div\",\"mapboxgl-popup-tip\",this._container),this._container.appendChild(this._content),this.options.className&&this.options.className.split(\" \").forEach(function(t){return n._container.classList.add(t)})),this.options.maxWidth&&this._container.style.maxWidth!==this.options.maxWidth&&(this._container.style.maxWidth=this.options.maxWidth),this._map.transform.renderWorldCopies&&!this._trackPointer&&(this._lngLat=Rn(this._lngLat,this._pos,this._map.transform)),!this._trackPointer||e)){var a=this._pos=this._trackPointer&&e?e:this._map.project(this._lngLat),o=this.options.anchor,s=function e(r){if(r){if(\"number\"==typeof r){var n=Math.round(Math.sqrt(.5*Math.pow(r,2)));return{center:new t.Point(0,0),top:new t.Point(0,r),\"top-left\":new t.Point(n,n),\"top-right\":new t.Point(-n,n),bottom:new t.Point(0,-r),\"bottom-left\":new t.Point(n,-n),\"bottom-right\":new t.Point(-n,-n),left:new t.Point(r,0),right:new t.Point(-r,0)}}if(r instanceof t.Point||Array.isArray(r)){var i=t.Point.convert(r);return{center:i,top:i,\"top-left\":i,\"top-right\":i,bottom:i,\"bottom-left\":i,\"bottom-right\":i,left:i,right:i}}return{center:t.Point.convert(r.center||[0,0]),top:t.Point.convert(r.top||[0,0]),\"top-left\":t.Point.convert(r[\"top-left\"]||[0,0]),\"top-right\":t.Point.convert(r[\"top-right\"]||[0,0]),bottom:t.Point.convert(r.bottom||[0,0]),\"bottom-left\":t.Point.convert(r[\"bottom-left\"]||[0,0]),\"bottom-right\":t.Point.convert(r[\"bottom-right\"]||[0,0]),left:t.Point.convert(r.left||[0,0]),right:t.Point.convert(r.right||[0,0])}}return e(new t.Point(0,0))}(this.options.offset);if(!o){var l,c=this._container.offsetWidth,u=this._container.offsetHeight;l=a.y+s.bottom.y<u?[\"top\"]:a.y>this._map.transform.height-u?[\"bottom\"]:[],a.x<c/2?l.push(\"left\"):a.x>this._map.transform.width-c/2&&l.push(\"right\"),o=0===l.length?\"bottom\":l.join(\"-\")}var h=a.add(s[o]).round();r.setTransform(this._container,Fn[o]+\" translate(\"+h.x+\"px,\"+h.y+\"px)\"),Bn(this._container,o,\"popup\")}},n.prototype._onClickClose=function(){this.remove()},n}(t.Evented),Jn={version:t.version,supported:e,setRTLTextPlugin:t.setRTLTextPlugin,Map:On,NavigationControl:Dn,GeolocateControl:Vn,AttributionControl:Mn,ScaleControl:Hn,FullscreenControl:Wn,Popup:Zn,Marker:jn,Style:De,LngLat:t.LngLat,LngLatBounds:t.LngLatBounds,Point:t.Point,MercatorCoordinate:t.MercatorCoordinate,Evented:t.Evented,config:t.config,get accessToken(){return t.config.ACCESS_TOKEN},set accessToken(e){t.config.ACCESS_TOKEN=e},get baseApiUrl(){return t.config.API_URL},set baseApiUrl(e){t.config.API_URL=e},get workerCount(){return zt.workerCount},set workerCount(t){zt.workerCount=t},get maxParallelImageRequests(){return t.config.MAX_PARALLEL_IMAGE_REQUESTS},set maxParallelImageRequests(e){t.config.MAX_PARALLEL_IMAGE_REQUESTS=e},clearStorage:function(e){t.clearTileCache(e)},workerUrl:\"\"};return Jn}),r},\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=i():(n=n||self).mapboxgl=i()},{}],427:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1<<t+1,r=new Array(e),n=0;n<e;++n)r[n]=a(t,n);return r};var n=t(\"convex-hull\");function i(t,e,r){for(var n=new Array(t),i=0;i<t;++i)n[i]=0,i===e&&(n[i]+=.5),i===r&&(n[i]+=.5);return n}function a(t,e){if(0===e||e===(1<<t+1)-1)return[];for(var r=[],a=[],o=0;o<=t;++o)if(e&1<<o){r.push(i(t,o-1,o-1)),a.push(null);for(var s=0;s<=t;++s)~e&1<<s&&(r.push(i(t,o-1,s-1)),a.push([o,s]))}var l=n(r),c=[];t:for(o=0;o<l.length;++o){var u=l[o],h=[];for(s=0;s<u.length;++s){if(!a[u[s]])continue t;h.push(a[u[s]].slice())}c.push(h)}return c}},{\"convex-hull\":130}],428:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"gl-mat4/create\"),a=t(\"gl-mat4/clone\"),o=t(\"gl-mat4/determinant\"),s=t(\"gl-mat4/invert\"),l=t(\"gl-mat4/transpose\"),c={length:t(\"gl-vec3/length\"),normalize:t(\"gl-vec3/normalize\"),dot:t(\"gl-vec3/dot\"),cross:t(\"gl-vec3/cross\")},u=i(),h=i(),f=[0,0,0,0],p=[[0,0,0],[0,0,0],[0,0,0]],d=[0,0,0];function g(t,e,r,n,i){t[0]=e[0]*n+r[0]*i,t[1]=e[1]*n+r[1]*i,t[2]=e[2]*n+r[2]*i}e.exports=function(t,e,r,i,v,m){if(e||(e=[0,0,0]),r||(r=[0,0,0]),i||(i=[0,0,0]),v||(v=[0,0,0,1]),m||(m=[0,0,0,1]),!n(u,t))return!1;if(a(h,u),h[3]=0,h[7]=0,h[11]=0,h[15]=1,Math.abs(o(h)<1e-8))return!1;var y,x,b,_,w,k,T,A=u[3],M=u[7],S=u[11],E=u[12],C=u[13],L=u[14],P=u[15];if(0!==A||0!==M||0!==S){if(f[0]=A,f[1]=M,f[2]=S,f[3]=P,!s(h,h))return!1;l(h,h),y=v,b=h,_=(x=f)[0],w=x[1],k=x[2],T=x[3],y[0]=b[0]*_+b[4]*w+b[8]*k+b[12]*T,y[1]=b[1]*_+b[5]*w+b[9]*k+b[13]*T,y[2]=b[2]*_+b[6]*w+b[10]*k+b[14]*T,y[3]=b[3]*_+b[7]*w+b[11]*k+b[15]*T}else v[0]=v[1]=v[2]=0,v[3]=1;if(e[0]=E,e[1]=C,e[2]=L,function(t,e){t[0][0]=e[0],t[0][1]=e[1],t[0][2]=e[2],t[1][0]=e[4],t[1][1]=e[5],t[1][2]=e[6],t[2][0]=e[8],t[2][1]=e[9],t[2][2]=e[10]}(p,u),r[0]=c.length(p[0]),c.normalize(p[0],p[0]),i[0]=c.dot(p[0],p[1]),g(p[1],p[1],p[0],1,-i[0]),r[1]=c.length(p[1]),c.normalize(p[1],p[1]),i[0]/=r[1],i[1]=c.dot(p[0],p[2]),g(p[2],p[2],p[0],1,-i[1]),i[2]=c.dot(p[1],p[2]),g(p[2],p[2],p[1],1,-i[2]),r[2]=c.length(p[2]),c.normalize(p[2],p[2]),i[1]/=r[2],i[2]/=r[2],c.cross(d,p[1],p[2]),c.dot(p[0],d)<0)for(var O=0;O<3;O++)r[O]*=-1,p[O][0]*=-1,p[O][1]*=-1,p[O][2]*=-1;return m[0]=.5*Math.sqrt(Math.max(1+p[0][0]-p[1][1]-p[2][2],0)),m[1]=.5*Math.sqrt(Math.max(1-p[0][0]+p[1][1]-p[2][2],0)),m[2]=.5*Math.sqrt(Math.max(1-p[0][0]-p[1][1]+p[2][2],0)),m[3]=.5*Math.sqrt(Math.max(1+p[0][0]+p[1][1]+p[2][2],0)),p[2][1]>p[1][2]&&(m[0]=-m[0]),p[0][2]>p[2][0]&&(m[1]=-m[1]),p[1][0]>p[0][1]&&(m[2]=-m[2]),!0}},{\"./normalize\":429,\"gl-mat4/clone\":259,\"gl-mat4/create\":260,\"gl-mat4/determinant\":261,\"gl-mat4/invert\":265,\"gl-mat4/transpose\":276,\"gl-vec3/cross\":334,\"gl-vec3/dot\":339,\"gl-vec3/length\":349,\"gl-vec3/normalize\":356}],429:[function(t,e,r){e.exports=function(t,e){var r=e[15];if(0===r)return!1;for(var n=1/r,i=0;i<16;i++)t[i]=e[i]*n;return!0}},{}],430:[function(t,e,r){var n=t(\"gl-vec3/lerp\"),i=t(\"mat4-recompose\"),a=t(\"mat4-decompose\"),o=t(\"gl-mat4/determinant\"),s=t(\"quat-slerp\"),l=h(),c=h(),u=h();function h(){return{translate:f(),scale:f(1),skew:f(),perspective:[0,0,0,1],quaternion:[0,0,0,1]}}function f(t){return[t||0,t||0,t||0]}e.exports=function(t,e,r,h){if(0===o(e)||0===o(r))return!1;var f=a(e,l.translate,l.scale,l.skew,l.perspective,l.quaternion),p=a(r,c.translate,c.scale,c.skew,c.perspective,c.quaternion);return!(!f||!p||(n(u.translate,l.translate,c.translate,h),n(u.skew,l.skew,c.skew,h),n(u.scale,l.scale,c.scale,h),n(u.perspective,l.perspective,c.perspective,h),s(u.quaternion,l.quaternion,c.quaternion,h),i(t,u.translate,u.scale,u.skew,u.perspective,u.quaternion),0))}},{\"gl-mat4/determinant\":261,\"gl-vec3/lerp\":350,\"mat4-decompose\":428,\"mat4-recompose\":431,\"quat-slerp\":483}],431:[function(t,e,r){var n={identity:t(\"gl-mat4/identity\"),translate:t(\"gl-mat4/translate\"),multiply:t(\"gl-mat4/multiply\"),create:t(\"gl-mat4/create\"),scale:t(\"gl-mat4/scale\"),fromRotationTranslation:t(\"gl-mat4/fromRotationTranslation\")},i=(n.create(),n.create());e.exports=function(t,e,r,a,o,s){return n.identity(t),n.fromRotationTranslation(t,s,e),t[3]=o[0],t[7]=o[1],t[11]=o[2],t[15]=o[3],n.identity(i),0!==a[2]&&(i[9]=a[2],n.multiply(t,t,i)),0!==a[1]&&(i[9]=0,i[8]=a[1],n.multiply(t,t,i)),0!==a[0]&&(i[8]=0,i[4]=a[0],n.multiply(t,t,i)),n.scale(t,t,r),t}},{\"gl-mat4/create\":260,\"gl-mat4/fromRotationTranslation\":263,\"gl-mat4/identity\":264,\"gl-mat4/multiply\":267,\"gl-mat4/scale\":274,\"gl-mat4/translate\":275}],432:[function(t,e,r){\"use strict\";e.exports=Math.log2||function(t){return Math.log(t)*Math.LOG2E}},{}],433:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"mat4-interpolate\"),a=t(\"gl-mat4/invert\"),o=t(\"gl-mat4/rotateX\"),s=t(\"gl-mat4/rotateY\"),l=t(\"gl-mat4/rotateZ\"),c=t(\"gl-mat4/lookAt\"),u=t(\"gl-mat4/translate\"),h=(t(\"gl-mat4/scale\"),t(\"gl-vec3/normalize\")),f=[0,0,0];function p(t){this._components=t.slice(),this._time=[0],this.prevMatrix=t.slice(),this.nextMatrix=t.slice(),this.computedMatrix=t.slice(),this.computedInverse=t.slice(),this.computedEye=[0,0,0],this.computedUp=[0,0,0],this.computedCenter=[0,0,0],this.computedRadius=[0],this._limits=[-1/0,1/0]}e.exports=function(t){return new p((t=t||{}).matrix||[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1])};var d=p.prototype;d.recalcMatrix=function(t){var e=this._time,r=n.le(e,t),o=this.computedMatrix;if(!(r<0)){var s=this._components;if(r===e.length-1)for(var l=16*r,c=0;c<16;++c)o[c]=s[l++];else{var u=e[r+1]-e[r],f=(l=16*r,this.prevMatrix),p=!0;for(c=0;c<16;++c)f[c]=s[l++];var d=this.nextMatrix;for(c=0;c<16;++c)d[c]=s[l++],p=p&&f[c]===d[c];if(u<1e-6||p)for(c=0;c<16;++c)o[c]=f[c];else i(o,f,d,(t-e[r])/u)}var g=this.computedUp;g[0]=o[1],g[1]=o[5],g[2]=o[9],h(g,g);var v=this.computedInverse;a(v,o);var m=this.computedEye,y=v[15];m[0]=v[12]/y,m[1]=v[13]/y,m[2]=v[14]/y;var x=this.computedCenter,b=Math.exp(this.computedRadius[0]);for(c=0;c<3;++c)x[c]=m[c]-o[2+4*c]*b}},d.idle=function(t){if(!(t<this.lastT())){for(var e=this._components,r=e.length-16,n=0;n<16;++n)e.push(e[r++]);this._time.push(t)}},d.flush=function(t){var e=n.gt(this._time,t)-2;e<0||(this._time.splice(0,e),this._components.splice(0,16*e))},d.lastT=function(){return this._time[this._time.length-1]},d.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||f,n=n||this.computedUp,this.setMatrix(t,c(this.computedMatrix,e,r,n));for(var i=0,a=0;a<3;++a)i+=Math.pow(r[a]-e[a],2);i=Math.log(Math.sqrt(i)),this.computedRadius[0]=i},d.rotate=function(t,e,r,n){this.recalcMatrix(t);var i=this.computedInverse;e&&s(i,i,e),r&&o(i,i,r),n&&l(i,i,n),this.setMatrix(t,a(this.computedMatrix,i))};var g=[0,0,0];d.pan=function(t,e,r,n){g[0]=-(e||0),g[1]=-(r||0),g[2]=-(n||0),this.recalcMatrix(t);var i=this.computedInverse;u(i,i,g),this.setMatrix(t,a(i,i))},d.translate=function(t,e,r,n){g[0]=e||0,g[1]=r||0,g[2]=n||0,this.recalcMatrix(t);var i=this.computedMatrix;u(i,i,g),this.setMatrix(t,i)},d.setMatrix=function(t,e){if(!(t<this.lastT())){this._time.push(t);for(var r=0;r<16;++r)this._components.push(e[r])}},d.setDistance=function(t,e){this.computedRadius[0]=e},d.setDistanceLimits=function(t,e){var r=this._limits;r[0]=t,r[1]=e},d.getDistanceLimits=function(t){var e=this._limits;return t?(t[0]=e[0],t[1]=e[1],t):e}},{\"binary-search-bounds\":91,\"gl-mat4/invert\":265,\"gl-mat4/lookAt\":266,\"gl-mat4/rotateX\":271,\"gl-mat4/rotateY\":272,\"gl-mat4/rotateZ\":273,\"gl-mat4/scale\":274,\"gl-mat4/translate\":275,\"gl-vec3/normalize\":356,\"mat4-interpolate\":430}],434:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<3){for(var r=new Array(e),i=0;i<e;++i)r[i]=i;return 2===e&&t[0][0]===t[1][0]&&t[0][1]===t[1][1]?[0]:r}for(var a=new Array(e),i=0;i<e;++i)a[i]=i;a.sort(function(e,r){var n=t[e][0]-t[r][0];return n||t[e][1]-t[r][1]});for(var o=[a[0],a[1]],s=[a[0],a[1]],i=2;i<e;++i){for(var l=a[i],c=t[l],u=o.length;u>1&&n(t[o[u-2]],t[o[u-1]],c)<=0;)u-=1,o.pop();for(o.push(l),u=s.length;u>1&&n(t[s[u-2]],t[s[u-1]],c)>=0;)u-=1,s.pop();s.push(l)}for(var r=new Array(s.length+o.length-2),h=0,i=0,f=o.length;i<f;++i)r[h++]=o[i];for(var p=s.length-2;p>0;--p)r[h++]=s[p];return r};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":510}],435:[function(t,e,r){\"use strict\";e.exports=function(t,e){e||(e=t,t=window);var r=0,i=0,a=0,o={shift:!1,alt:!1,control:!1,meta:!1},s=!1;function l(t){var e=!1;return\"altKey\"in t&&(e=e||t.altKey!==o.alt,o.alt=!!t.altKey),\"shiftKey\"in t&&(e=e||t.shiftKey!==o.shift,o.shift=!!t.shiftKey),\"ctrlKey\"in t&&(e=e||t.ctrlKey!==o.control,o.control=!!t.ctrlKey),\"metaKey\"in t&&(e=e||t.metaKey!==o.meta,o.meta=!!t.metaKey),e}function c(t,s){var c=n.x(s),u=n.y(s);\"buttons\"in s&&(t=0|s.buttons),(t!==r||c!==i||u!==a||l(s))&&(r=0|t,i=c||0,a=u||0,e&&e(r,i,a,o))}function u(t){c(0,t)}function h(){(r||i||a||o.shift||o.alt||o.meta||o.control)&&(i=a=0,r=0,o.shift=o.alt=o.control=o.meta=!1,e&&e(0,0,0,o))}function f(t){l(t)&&e&&e(r,i,a,o)}function p(t){0===n.buttons(t)?c(0,t):c(r,t)}function d(t){c(r|n.buttons(t),t)}function g(t){c(r&~n.buttons(t),t)}function v(){s||(s=!0,t.addEventListener(\"mousemove\",p),t.addEventListener(\"mousedown\",d),t.addEventListener(\"mouseup\",g),t.addEventListener(\"mouseleave\",u),t.addEventListener(\"mouseenter\",u),t.addEventListener(\"mouseout\",u),t.addEventListener(\"mouseover\",u),t.addEventListener(\"blur\",h),t.addEventListener(\"keyup\",f),t.addEventListener(\"keydown\",f),t.addEventListener(\"keypress\",f),t!==window&&(window.addEventListener(\"blur\",h),window.addEventListener(\"keyup\",f),window.addEventListener(\"keydown\",f),window.addEventListener(\"keypress\",f)))}v();var m={element:t};return Object.defineProperties(m,{enabled:{get:function(){return s},set:function(e){e?v():s&&(s=!1,t.removeEventListener(\"mousemove\",p),t.removeEventListener(\"mousedown\",d),t.removeEventListener(\"mouseup\",g),t.removeEventListener(\"mouseleave\",u),t.removeEventListener(\"mouseenter\",u),t.removeEventListener(\"mouseout\",u),t.removeEventListener(\"mouseover\",u),t.removeEventListener(\"blur\",h),t.removeEventListener(\"keyup\",f),t.removeEventListener(\"keydown\",f),t.removeEventListener(\"keypress\",f),t!==window&&(window.removeEventListener(\"blur\",h),window.removeEventListener(\"keyup\",f),window.removeEventListener(\"keydown\",f),window.removeEventListener(\"keypress\",f)))},enumerable:!0},buttons:{get:function(){return r},enumerable:!0},x:{get:function(){return i},enumerable:!0},y:{get:function(){return a},enumerable:!0},mods:{get:function(){return o},enumerable:!0}}),m};var n=t(\"mouse-event\")},{\"mouse-event\":437}],436:[function(t,e,r){var n={left:0,top:0};e.exports=function(t,e,r){e=e||t.currentTarget||t.srcElement,Array.isArray(r)||(r=[0,0]);var i=t.clientX||0,a=t.clientY||0,o=(s=e,s===window||s===document||s===document.body?n:s.getBoundingClientRect());var s;return r[0]=i-o.left,r[1]=a-o.top,r}},{}],437:[function(t,e,r){\"use strict\";function n(t){return t.target||t.srcElement||window}r.buttons=function(t){if(\"object\"==typeof t){if(\"buttons\"in t)return t.buttons;if(\"which\"in t){if(2===(e=t.which))return 4;if(3===e)return 2;if(e>0)return 1<<e-1}else if(\"button\"in t){var e;if(1===(e=t.button))return 4;if(2===e)return 2;if(e>=0)return 1<<e}}return 0},r.element=n,r.x=function(t){if(\"object\"==typeof t){if(\"offsetX\"in t)return t.offsetX;var e=n(t).getBoundingClientRect();return t.clientX-e.left}return 0},r.y=function(t){if(\"object\"==typeof t){if(\"offsetY\"in t)return t.offsetY;var e=n(t).getBoundingClientRect();return t.clientY-e.top}return 0}},{}],438:[function(t,e,r){\"use strict\";var n=t(\"to-px\");e.exports=function(t,e,r){\"function\"==typeof t&&(r=!!e,e=t,t=window);var i=n(\"ex\",t),a=function(t){r&&t.preventDefault();var n=t.deltaX||0,a=t.deltaY||0,o=t.deltaZ||0,s=t.deltaMode,l=1;switch(s){case 1:l=i;break;case 2:l=window.innerHeight}if(a*=l,o*=l,(n*=l)||a||o)return e(n,a,o,t)};return t.addEventListener(\"wheel\",a),a}},{\"to-px\":539}],439:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\");function i(t){return\"a\"+t}function a(t){return\"d\"+t}function o(t,e){return\"c\"+t+\"_\"+e}function s(t){return\"s\"+t}function l(t,e){return\"t\"+t+\"_\"+e}function c(t){return\"o\"+t}function u(t){return\"x\"+t}function h(t){return\"p\"+t}function f(t,e){return\"d\"+t+\"_\"+e}function p(t){return\"i\"+t}function d(t,e){return\"u\"+t+\"_\"+e}function g(t){return\"b\"+t}function v(t){return\"y\"+t}function m(t){return\"e\"+t}function y(t){return\"v\"+t}e.exports=function(t){function e(t){throw new Error(\"ndarray-extract-contour: \"+t)}\"object\"!=typeof t&&e(\"Must specify arguments\");var r=t.order;Array.isArray(r)||e(\"Must specify order\");var M=t.arrayArguments||1;M<1&&e(\"Must have at least one array argument\");var S=t.scalarArguments||0;S<0&&e(\"Scalar arg count must be > 0\");\"function\"!=typeof t.vertex&&e(\"Must specify vertex creation function\");\"function\"!=typeof t.cell&&e(\"Must specify cell creation function\");\"function\"!=typeof t.phase&&e(\"Must specify phase function\");for(var E=t.getters||[],C=new Array(M),L=0;L<M;++L)E.indexOf(L)>=0?C[L]=!0:C[L]=!1;return function(t,e,r,M,S,E){var C=E.length,L=S.length;if(L<2)throw new Error(\"ndarray-extract-contour: Dimension must be at least 2\");for(var P=\"extractContour\"+S.join(\"_\"),O=[],z=[],I=[],D=0;D<C;++D)I.push(i(D));for(var D=0;D<M;++D)I.push(u(D));for(var D=0;D<L;++D)z.push(s(D)+\"=\"+i(0)+\".shape[\"+D+\"]|0\");for(var D=0;D<C;++D){z.push(a(D)+\"=\"+i(D)+\".data\",c(D)+\"=\"+i(D)+\".offset|0\");for(var R=0;R<L;++R)z.push(l(D,R)+\"=\"+i(D)+\".stride[\"+R+\"]|0\")}for(var D=0;D<C;++D){z.push(h(D)+\"=\"+c(D)),z.push(o(D,0));for(var R=1;R<1<<L;++R){for(var F=[],B=0;B<L;++B)R&1<<B&&F.push(\"-\"+l(D,B));z.push(f(D,R)+\"=(\"+F.join(\"\")+\")|0\"),z.push(o(D,R)+\"=0\")}}for(var D=0;D<C;++D)for(var R=0;R<L;++R){var N=[l(D,S[R])];R>0&&N.push(l(D,S[R-1])+\"*\"+s(S[R-1])),z.push(d(D,S[R])+\"=(\"+N.join(\"-\")+\")|0\")}for(var D=0;D<L;++D)z.push(p(D)+\"=0\");z.push(_+\"=0\");for(var j=[\"2\"],D=L-2;D>=0;--D)j.push(s(S[D]));z.push(w+\"=(\"+j.join(\"*\")+\")|0\",b+\"=mallocUint32(\"+w+\")\",x+\"=mallocUint32(\"+w+\")\",k+\"=0\"),z.push(g(0)+\"=0\");for(var R=1;R<1<<L;++R){for(var U=[],V=[],B=0;B<L;++B)R&1<<B&&(0===V.length?U.push(\"1\"):U.unshift(V.join(\"*\"))),V.push(s(S[B]));var q=\"\";U[0].indexOf(s(S[L-2]))<0&&(q=\"-\");var H=A(L,R,S);z.push(m(H)+\"=(-\"+U.join(\"-\")+\")|0\",v(H)+\"=(\"+q+U.join(\"-\")+\")|0\",g(H)+\"=0\")}function G(t,e){O.push(\"for(\",p(S[t]),\"=\",e,\";\",p(S[t]),\"<\",s(S[t]),\";\",\"++\",p(S[t]),\"){\")}function Y(t){for(var e=0;e<C;++e)O.push(h(e),\"+=\",d(e,S[t]),\";\");O.push(\"}\")}function W(){for(var t=1;t<1<<L;++t)O.push(T,\"=\",m(t),\";\",m(t),\"=\",v(t),\";\",v(t),\"=\",T,\";\")}z.push(y(0)+\"=0\",T+\"=0\"),function t(e,r){if(e<0)return void function(t){for(var e=0;e<C;++e)E[e]?O.push(o(e,0),\"=\",a(e),\".get(\",h(e),\");\"):O.push(o(e,0),\"=\",a(e),\"[\",h(e),\"];\");for(var r=[],e=0;e<C;++e)r.push(o(e,0));for(var e=0;e<M;++e)r.push(u(e));O.push(g(0),\"=\",b,\"[\",k,\"]=phase(\",r.join(),\");\");for(var n=1;n<1<<L;++n)O.push(g(n),\"=\",b,\"[\",k,\"+\",m(n),\"];\");for(var i=[],n=1;n<1<<L;++n)i.push(\"(\"+g(0)+\"!==\"+g(n)+\")\");O.push(\"if(\",i.join(\"||\"),\"){\");for(var s=[],e=0;e<L;++e)s.push(p(e));for(var e=0;e<C;++e){s.push(o(e,0));for(var n=1;n<1<<L;++n)E[e]?O.push(o(e,n),\"=\",a(e),\".get(\",h(e),\"+\",f(e,n),\");\"):O.push(o(e,n),\"=\",a(e),\"[\",h(e),\"+\",f(e,n),\"];\"),s.push(o(e,n))}for(var e=0;e<1<<L;++e)s.push(g(e));for(var e=0;e<M;++e)s.push(u(e));O.push(\"vertex(\",s.join(),\");\",y(0),\"=\",x,\"[\",k,\"]=\",_,\"++;\");for(var l=(1<<L)-1,c=g(l),n=0;n<L;++n)if(0==(t&~(1<<n))){for(var d=l^1<<n,v=g(d),w=[],T=d;T>0;T=T-1&d)w.push(x+\"[\"+k+\"+\"+m(T)+\"]\");w.push(y(0));for(var T=0;T<C;++T)1&n?w.push(o(T,l),o(T,d)):w.push(o(T,d),o(T,l));1&n?w.push(c,v):w.push(v,c);for(var T=0;T<M;++T)w.push(u(T));O.push(\"if(\",c,\"!==\",v,\"){\",\"face(\",w.join(),\")}\")}O.push(\"}\",k,\"+=1;\")}(r);!function(t){for(var e=t-1;e>=0;--e)G(e,0);for(var r=[],e=0;e<C;++e)E[e]?r.push(a(e)+\".get(\"+h(e)+\")\"):r.push(a(e)+\"[\"+h(e)+\"]\");for(var e=0;e<M;++e)r.push(u(e));O.push(b,\"[\",k,\"++]=phase(\",r.join(),\");\");for(var e=0;e<t;++e)Y(e);for(var n=0;n<C;++n)O.push(h(n),\"+=\",d(n,S[t]),\";\")}(e);O.push(\"if(\",s(S[e]),\">0){\",p(S[e]),\"=1;\");t(e-1,r|1<<S[e]);for(var n=0;n<C;++n)O.push(h(n),\"+=\",d(n,S[e]),\";\");e===L-1&&(O.push(k,\"=0;\"),W());G(e,2);t(e-1,r);e===L-1&&(O.push(\"if(\",p(S[L-1]),\"&1){\",k,\"=0;}\"),W());Y(e);O.push(\"}\")}(L-1,0),O.push(\"freeUint32(\",x,\");freeUint32(\",b,\");\");var X=[\"'use strict';\",\"function \",P,\"(\",I.join(),\"){\",\"var \",z.join(),\";\",O.join(\"\"),\"}\",\"return \",P].join(\"\");return new Function(\"vertex\",\"face\",\"phase\",\"mallocUint32\",\"freeUint32\",X)(t,e,r,n.mallocUint32,n.freeUint32)}(t.vertex,t.cell,t.phase,S,r,C)};var x=\"V\",b=\"P\",_=\"N\",w=\"Q\",k=\"X\",T=\"T\";function A(t,e,r){for(var n=0,i=0;i<t;++i)e&1<<i&&(n|=1<<r[i]);return n}},{\"typedarray-pool\":545}],440:[function(t,e,r){\"use strict\";var n=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{_inline_1_arg1_=_inline_1_arg2_.apply(void 0,_inline_1_arg0_)}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"cwise\",blockSize:64});e.exports=function(t,e){return n(t,e),t}},{\"cwise/lib/wrapper\":149}],441:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(Array.isArray(r)){if(r.length!==e.dimension)throw new Error(\"ndarray-gradient: invalid boundary conditions\")}else r=n(e.dimension,\"string\"==typeof r?r:\"clamp\");if(t.dimension!==e.dimension+1)throw new Error(\"ndarray-gradient: output dimension must be +1 input dimension\");if(t.shape[e.dimension]!==e.dimension)throw new Error(\"ndarray-gradient: output shape must match input shape\");for(var i=0;i<e.dimension;++i)if(t.shape[i]!==e.shape[i])throw new Error(\"ndarray-gradient: shape mismatch\");if(0===e.size)return t;if(e.dimension<=0)return t.set(0),t;return function(t){var e=t.join();if(m=o[e])return m;var r=t.length,n=[\"function gradient(dst,src){var s=src.shape.slice();\"];function i(e){for(var i=r-e.length,a=[],o=[],s=[],l=0;l<r;++l)e.indexOf(l+1)>=0?s.push(\"0\"):e.indexOf(-(l+1))>=0?s.push(\"s[\"+l+\"]-1\"):(s.push(\"-1\"),a.push(\"1\"),o.push(\"s[\"+l+\"]-2\"));var c=\".lo(\"+a.join()+\").hi(\"+o.join()+\")\";if(0===a.length&&(c=\"\"),i>0){n.push(\"if(1\");for(var l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\"&&s[\",l,\"]>2\");n.push(\"){grad\",i,\"(src.pick(\",s.join(),\")\",c);for(var l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\",dst.pick(\",s.join(),\",\",l,\")\",c);n.push(\");\")}for(var l=0;l<e.length;++l){var u=Math.abs(e[l])-1,h=\"dst.pick(\"+s.join()+\",\"+u+\")\"+c;switch(t[u]){case\"clamp\":var f=s.slice(),p=s.slice();e[l]<0?f[u]=\"s[\"+u+\"]-2\":p[u]=\"1\",0===i?n.push(\"if(s[\",u,\"]>1){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",f.join(),\")-src.get(\",p.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>1){diff(\",h,\",src.pick(\",f.join(),\")\",c,\",src.pick(\",p.join(),\")\",c,\");}else{zero(\",h,\");};\");break;case\"mirror\":0===i?n.push(\"dst.set(\",s.join(),\",\",u,\",0);\"):n.push(\"zero(\",h,\");\");break;case\"wrap\":var d=s.slice(),g=s.slice();e[l]<0?(d[u]=\"s[\"+u+\"]-2\",g[u]=\"0\"):(d[u]=\"s[\"+u+\"]-1\",g[u]=\"1\"),0===i?n.push(\"if(s[\",u,\"]>2){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",d.join(),\")-src.get(\",g.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>2){diff(\",h,\",src.pick(\",d.join(),\")\",c,\",src.pick(\",g.join(),\")\",c,\");}else{zero(\",h,\");};\");break;default:throw new Error(\"ndarray-gradient: Invalid boundary condition\")}}i>0&&n.push(\"};\")}for(var s=0;s<1<<r;++s){for(var h=[],f=0;f<r;++f)s&1<<f&&h.push(f+1);for(var p=0;p<1<<h.length;++p){for(var d=h.slice(),f=0;f<h.length;++f)p&1<<f&&(d[f]=-d[f]);i(d)}}n.push(\"return dst;};return gradient\");for(var g=[\"diff\",\"zero\"],v=[l,c],s=1;s<=r;++s)g.push(\"grad\"+s),v.push(u(s));g.push(n.join(\"\"));var m=Function.apply(void 0,g).apply(void 0,v);return a[e]=m,m}(r)(t,e)};var n=t(\"dup\"),i=t(\"cwise-compiler\"),a={},o={},s={body:\"\",args:[],thisVars:[],localVars:[]},l=i({args:[\"array\",\"array\",\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1},{name:\"left\",lvalue:!1,rvalue:!0,count:1},{name:\"right\",lvalue:!1,rvalue:!0,count:1}],body:\"out=0.5*(left-right)\",thisVars:[],localVars:[]},funcName:\"cdiff\"}),c=i({args:[\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1}],body:\"out=0\",thisVars:[],localVars:[]},funcName:\"zero\"});function u(t){if(t in a)return a[t];for(var e=[],r=0;r<t;++r)e.push(\"out\",r,\"s=0.5*(inp\",r,\"l-inp\",r,\"r);\");var o=[\"array\"],l=[\"junk\"];for(r=0;r<t;++r){o.push(\"array\"),l.push(\"out\"+r+\"s\");var c=n(t);c[r]=-1,o.push({array:0,offset:c.slice()}),c[r]=1,o.push({array:0,offset:c.slice()}),l.push(\"inp\"+r+\"l\",\"inp\"+r+\"r\")}return a[t]=i({args:o,pre:s,post:s,body:{body:e.join(\"\"),args:l.map(function(t){return{name:t,lvalue:0===t.indexOf(\"out\"),rvalue:0===t.indexOf(\"inp\"),count:\"junk\"!==t|0}}),thisVars:[],localVars:[]},funcName:\"fdTemplate\"+t})}},{\"cwise-compiler\":146,dup:170}],442:[function(t,e,r){\"use strict\";var n=t(\"ndarray-warp\"),i=t(\"gl-matrix-invert\");e.exports=function(t,e,r){var a=e.dimension,o=i([],r);return n(t,e,function(t,e){for(var r=0;r<a;++r){t[r]=o[(a+1)*a+r];for(var n=0;n<a;++n)t[r]+=o[(a+1)*n+r]*e[n]}var i=o[(a+1)*(a+1)-1];for(n=0;n<a;++n)i+=o[(a+1)*n+a]*e[n];var s=1/i;for(r=0;r<a;++r)t[r]*=s;return t}),t}},{\"gl-matrix-invert\":277,\"ndarray-warp\":449}],443:[function(t,e,r){\"use strict\";function n(t,e){var r=Math.floor(e),n=e-r,i=0<=r&&r<t.shape[0],a=0<=r+1&&r+1<t.shape[0];return(1-n)*(i?+t.get(r):0)+n*(a?+t.get(r+1):0)}function i(t,e,r){var n=Math.floor(e),i=e-n,a=0<=n&&n<t.shape[0],o=0<=n+1&&n+1<t.shape[0],s=Math.floor(r),l=r-s,c=0<=s&&s<t.shape[1],u=0<=s+1&&s+1<t.shape[1],h=a&&c?t.get(n,s):0,f=a&&u?t.get(n,s+1):0;return(1-l)*((1-i)*h+i*(o&&c?t.get(n+1,s):0))+l*((1-i)*f+i*(o&&u?t.get(n+1,s+1):0))}function a(t,e,r,n){var i=Math.floor(e),a=e-i,o=0<=i&&i<t.shape[0],s=0<=i+1&&i+1<t.shape[0],l=Math.floor(r),c=r-l,u=0<=l&&l<t.shape[1],h=0<=l+1&&l+1<t.shape[1],f=Math.floor(n),p=n-f,d=0<=f&&f<t.shape[2],g=0<=f+1&&f+1<t.shape[2],v=o&&u&&d?t.get(i,l,f):0,m=o&&h&&d?t.get(i,l+1,f):0,y=s&&u&&d?t.get(i+1,l,f):0,x=s&&h&&d?t.get(i+1,l+1,f):0,b=o&&u&&g?t.get(i,l,f+1):0,_=o&&h&&g?t.get(i,l+1,f+1):0;return(1-p)*((1-c)*((1-a)*v+a*y)+c*((1-a)*m+a*x))+p*((1-c)*((1-a)*b+a*(s&&u&&g?t.get(i+1,l,f+1):0))+c*((1-a)*_+a*(s&&h&&g?t.get(i+1,l+1,f+1):0)))}e.exports=function(t,e,r,o){switch(t.shape.length){case 0:return 0;case 1:return n(t,e);case 2:return i(t,e,r);case 3:return a(t,e,r,o);default:return function(t){var e,r,n=0|t.shape.length,i=new Array(n),a=new Array(n),o=new Array(n),s=new Array(n);for(e=0;e<n;++e)r=+arguments[e+1],i[e]=Math.floor(r),a[e]=r-i[e],o[e]=0<=i[e]&&i[e]<t.shape[e],s[e]=0<=i[e]+1&&i[e]+1<t.shape[e];var l,c,u,h=0;t:for(e=0;e<1<<n;++e){for(c=1,u=t.offset,l=0;l<n;++l)if(e&1<<l){if(!s[l])continue t;c*=a[l],u+=t.stride[l]*(i[l]+1)}else{if(!o[l])continue t;c*=1-a[l],u+=t.stride[l]*i[l]}h+=c*t.data[u]}return h}.apply(void 0,arguments)}},e.exports.d1=n,e.exports.d2=i,e.exports.d3=a},{}],444:[function(t,e,r){\"use strict\";var n=t(\"cwise-compiler\"),i={body:\"\",args:[],thisVars:[],localVars:[]};function a(t){if(!t)return i;for(var e=0;e<t.args.length;++e){var r=t.args[e];t.args[e]=0===e?{name:r,lvalue:!0,rvalue:!!t.rvalue,count:t.count||1}:{name:r,lvalue:!1,rvalue:!0,count:1}}return t.thisVars||(t.thisVars=[]),t.localVars||(t.localVars=[]),t}function o(t){for(var e=[],r=0;r<t.args.length;++r)e.push(\"a\"+r);return new Function(\"P\",[\"return function \",t.funcName,\"_ndarrayops(\",e.join(\",\"),\") {P(\",e.join(\",\"),\");return a0}\"].join(\"\"))(function(t){return n({args:t.args,pre:a(t.pre),body:a(t.body),post:a(t.proc),funcName:t.funcName})}(t))}var s={add:\"+\",sub:\"-\",mul:\"*\",div:\"/\",mod:\"%\",band:\"&\",bor:\"|\",bxor:\"^\",lshift:\"<<\",rshift:\">>\",rrshift:\">>>\"};!function(){for(var t in s){var e=s[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a\"+e+\"=b\"},rvalue:!0,funcName:t+\"eq\"}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a\"+e+\"=s\"},rvalue:!0,funcName:t+\"seq\"})}}();var l={not:\"!\",bnot:\"~\",neg:\"-\",recip:\"1.0/\"};!function(){for(var t in l){var e=l[t];r[t]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=\"+e+\"b\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\"],body:{args:[\"a\"],body:\"a=\"+e+\"a\"},rvalue:!0,count:2,funcName:t+\"eq\"})}}();var c={and:\"&&\",or:\"||\",eq:\"===\",neq:\"!==\",lt:\"<\",gt:\">\",leq:\"<=\",geq:\">=\"};!function(){for(var t in c){var e=c[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=a\"+e+\"b\"},rvalue:!0,count:2,funcName:t+\"eq\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a=a\"+e+\"s\"},rvalue:!0,count:2,funcName:t+\"seq\"})}}();var u=[\"abs\",\"acos\",\"asin\",\"atan\",\"ceil\",\"cos\",\"exp\",\"floor\",\"log\",\"round\",\"sin\",\"sqrt\",\"tan\"];!function(){for(var t=0;t<u.length;++t){var e=u[t];r[e]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"eq\"]=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f(a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"})}}();var h=[\"max\",\"min\",\"atan2\",\"pow\"];!function(){for(var t=0;t<h.length;++t){var e=h[t];r[e]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e+\"s\"}),r[e+\"eq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"}),r[e+\"seq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"seq\"})}}();var f=[\"atan2\",\"pow\"];!function(){for(var t=0;t<f.length;++t){var e=f[t];r[e+\"op\"]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"op\"}),r[e+\"ops\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"ops\"}),r[e+\"opeq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opeq\"}),r[e+\"opseq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opseq\"})}}(),r.any=n({args:[\"array\"],pre:i,body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"if(a){return true}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return false\"},funcName:\"any\"}),r.all=n({args:[\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1}],body:\"if(!x){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"all\"}),r.sum=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s+=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"sum\"}),r.prod=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=1\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s*=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"prod\"}),r.norm2squared=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm2squared\"}),r.norm2=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return Math.sqrt(this_s)\"},funcName:\"norm2\"}),r.norminf=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:4}],body:\"if(-a>this_s){this_s=-a}else if(a>this_s){this_s=a}\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norminf\"}),r.norm1=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:3}],body:\"this_s+=a<0?-a:a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm1\"}),r.sup=n({args:[\"array\"],pre:{body:\"this_h=-Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_>this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.inf=n({args:[\"array\"],pre:{body:\"this_h=Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_<this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.argmin=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_<this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.argmax=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=-Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_>this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.random=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.random\",thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f()\",thisVars:[\"this_f\"]},funcName:\"random\"}),r.assign=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assign\"}),r.assigns=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assigns\"}),r.equals=n({args:[\"array\",\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1},{name:\"y\",lvalue:!1,rvalue:!0,count:1}],body:\"if(x!==y){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"equals\"})},{\"cwise-compiler\":146}],445:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"./doConvert.js\");e.exports=function(t,e){for(var r=[],a=t,o=1;Array.isArray(a);)r.push(a.length),o*=a.length,a=a[0];return 0===r.length?n():(e||(e=n(new Float64Array(o),r)),i(e,t),e)}},{\"./doConvert.js\":446,ndarray:450}],446:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\nvar _inline_1_v=_inline_1_arg1_,_inline_1_i\\nfor(_inline_1_i=0;_inline_1_i<_inline_1_arg2_.length-1;++_inline_1_i) {\\n_inline_1_v=_inline_1_v[_inline_1_arg2_[_inline_1_i]]\\n}\\n_inline_1_arg0_=_inline_1_v[_inline_1_arg2_[_inline_1_arg2_.length-1]]\\n}\",args:[{name:\"_inline_1_arg0_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:4}],thisVars:[],localVars:[\"_inline_1_i\",\"_inline_1_v\"]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},funcName:\"convert\",blockSize:64})},{\"cwise-compiler\":146}],447:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=32;function a(t){switch(t){case\"uint8\":return[n.mallocUint8,n.freeUint8];case\"uint16\":return[n.mallocUint16,n.freeUint16];case\"uint32\":return[n.mallocUint32,n.freeUint32];case\"int8\":return[n.mallocInt8,n.freeInt8];case\"int16\":return[n.mallocInt16,n.freeInt16];case\"int32\":return[n.mallocInt32,n.freeInt32];case\"float32\":return[n.mallocFloat,n.freeFloat];case\"float64\":return[n.mallocDouble,n.freeDouble];default:return null}}function o(t){for(var e=[],r=0;r<t;++r)e.push(\"s\"+r);for(r=0;r<t;++r)e.push(\"n\"+r);for(r=1;r<t;++r)e.push(\"d\"+r);for(r=1;r<t;++r)e.push(\"e\"+r);for(r=1;r<t;++r)e.push(\"f\"+r);return e}e.exports=function(t,e){var r=[\"'use strict'\"],n=[\"ndarraySortWrapper\",t.join(\"d\"),e].join(\"\");r.push([\"function \",n,\"(\",[\"array\"].join(\",\"),\"){\"].join(\"\"));for(var s=[\"data=array.data,offset=array.offset|0,shape=array.shape,stride=array.stride\"],l=0;l<t.length;++l)s.push([\"s\",l,\"=stride[\",l,\"]|0,n\",l,\"=shape[\",l,\"]|0\"].join(\"\"));var c=new Array(t.length),u=[];for(l=0;l<t.length;++l)0!==(p=t[l])&&(0===u.length?c[p]=\"1\":c[p]=u.join(\"*\"),u.push(\"n\"+p));var h=-1,f=-1;for(l=0;l<t.length;++l){var p,d=t[l];0!==d&&(h>0?s.push([\"d\",d,\"=s\",d,\"-d\",h,\"*n\",h].join(\"\")):s.push([\"d\",d,\"=s\",d].join(\"\")),h=d),0!=(p=t.length-1-l)&&(f>0?s.push([\"e\",p,\"=s\",p,\"-e\",f,\"*n\",f,\",f\",p,\"=\",c[p],\"-f\",f,\"*n\",f].join(\"\")):s.push([\"e\",p,\"=s\",p,\",f\",p,\"=\",c[p]].join(\"\")),f=p)}r.push(\"var \"+s.join(\",\"));var g=[\"0\",\"n0-1\",\"data\",\"offset\"].concat(o(t.length));r.push([\"if(n0<=\",i,\"){\",\"insertionSort(\",g.join(\",\"),\")}else{\",\"quickSort(\",g.join(\",\"),\")}\"].join(\"\")),r.push(\"}return \"+n);var v=new Function(\"insertionSort\",\"quickSort\",r.join(\"\\n\")),m=function(t,e){var r=[\"'use strict'\"],n=[\"ndarrayInsertionSort\",t.join(\"d\"),e].join(\"\"),i=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),s=a(e),l=[\"i,j,cptr,ptr=left*s0+offset\"];if(t.length>1){for(var c=[],u=1;u<t.length;++u)l.push(\"i\"+u),c.push(\"n\"+u);s?l.push(\"scratch=malloc(\"+c.join(\"*\")+\")\"):l.push(\"scratch=new Array(\"+c.join(\"*\")+\")\"),l.push(\"dptr\",\"sptr\",\"a\",\"b\")}else l.push(\"scratch\");function h(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function f(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}if(r.push([\"function \",n,\"(\",i.join(\",\"),\"){var \",l.join(\",\")].join(\"\"),\"for(i=left+1;i<=right;++i){\",\"j=i;ptr+=s0\",\"cptr=ptr\"),t.length>1){for(r.push(\"dptr=0;sptr=ptr\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(\"scratch[dptr++]=\",h(\"sptr\")),u=0;u<t.length;++u)0!==(p=t[u])&&r.push(\"sptr+=d\"+p,\"}\");for(r.push(\"__g:while(j--\\x3eleft){\",\"dptr=0\",\"sptr=cptr-s0\"),u=1;u<t.length;++u)1===u&&r.push(\"__l:\"),r.push([\"for(i\",u,\"=0;i\",u,\"<n\",u,\";++i\",u,\"){\"].join(\"\"));for(r.push([\"a=\",h(\"sptr\"),\"\\nb=scratch[dptr]\\nif(a<b){break __g}\\nif(a>b){break __l}\"].join(\"\")),u=t.length-1;u>=1;--u)r.push(\"sptr+=e\"+u,\"dptr+=f\"+u,\"}\");for(r.push(\"dptr=cptr;sptr=cptr-s0\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(f(\"dptr\",h(\"sptr\"))),u=0;u<t.length;++u)0!==(p=t[u])&&r.push([\"dptr+=d\",p,\";sptr+=d\",p].join(\"\"),\"}\");for(r.push(\"cptr-=s0\\n}\"),r.push(\"dptr=cptr;sptr=0\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(f(\"dptr\",\"scratch[sptr++]\")),u=0;u<t.length;++u){var p;0!==(p=t[u])&&r.push(\"dptr+=d\"+p,\"}\")}}else r.push(\"scratch=\"+h(\"ptr\"),\"while((j--\\x3eleft)&&(\"+h(\"cptr-s0\")+\">scratch)){\",f(\"cptr\",h(\"cptr-s0\")),\"cptr-=s0\",\"}\",f(\"cptr\",\"scratch\"));return r.push(\"}\"),t.length>1&&s&&r.push(\"free(scratch)\"),r.push(\"} return \"+n),s?new Function(\"malloc\",\"free\",r.join(\"\\n\"))(s[0],s[1]):new Function(r.join(\"\\n\"))()}(t,e),y=function(t,e,r){var n=[\"'use strict'\"],s=[\"ndarrayQuickSort\",t.join(\"d\"),e].join(\"\"),l=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),c=a(e),u=0;n.push([\"function \",s,\"(\",l.join(\",\"),\"){\"].join(\"\"));var h=[\"sixth=((right-left+1)/6)|0\",\"index1=left+sixth\",\"index5=right-sixth\",\"index3=(left+right)>>1\",\"index2=index3-sixth\",\"index4=index3+sixth\",\"el1=index1\",\"el2=index2\",\"el3=index3\",\"el4=index4\",\"el5=index5\",\"less=left+1\",\"great=right-1\",\"pivots_are_equal=true\",\"tmp\",\"tmp0\",\"x\",\"y\",\"z\",\"k\",\"ptr0\",\"ptr1\",\"ptr2\",\"comp_pivot1=0\",\"comp_pivot2=0\",\"comp=0\"];if(t.length>1){for(var f=[],p=1;p<t.length;++p)f.push(\"n\"+p),h.push(\"i\"+p);for(p=0;p<8;++p)h.push(\"b_ptr\"+p);h.push(\"ptr3\",\"ptr4\",\"ptr5\",\"ptr6\",\"ptr7\",\"pivot_ptr\",\"ptr_shift\",\"elementSize=\"+f.join(\"*\")),c?h.push(\"pivot1=malloc(elementSize)\",\"pivot2=malloc(elementSize)\"):h.push(\"pivot1=new Array(elementSize),pivot2=new Array(elementSize)\")}else h.push(\"pivot1\",\"pivot2\");function d(t){return[\"(offset+\",t,\"*s0)\"].join(\"\")}function g(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function v(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}function m(e,r,i){if(1===e.length)n.push(\"ptr0=\"+d(e[0]));else for(var a=0;a<e.length;++a)n.push([\"b_ptr\",a,\"=s0*\",e[a]].join(\"\"));for(r&&n.push(\"pivot_ptr=0\"),n.push(\"ptr_shift=offset\"),a=t.length-1;a>=0;--a)0!==(o=t[a])&&n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"));if(e.length>1)for(a=0;a<e.length;++a)n.push([\"ptr\",a,\"=b_ptr\",a,\"+ptr_shift\"].join(\"\"));for(n.push(i),r&&n.push(\"++pivot_ptr\"),a=0;a<t.length;++a){var o;0!==(o=t[a])&&(e.length>1?n.push(\"ptr_shift+=d\"+o):n.push(\"ptr0+=d\"+o),n.push(\"}\"))}}function y(e,r,i,a){if(1===r.length)n.push(\"ptr0=\"+d(r[0]));else{for(var o=0;o<r.length;++o)n.push([\"b_ptr\",o,\"=s0*\",r[o]].join(\"\"));n.push(\"ptr_shift=offset\")}for(i&&n.push(\"pivot_ptr=0\"),e&&n.push(e+\":\"),o=1;o<t.length;++o)n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"));if(r.length>1)for(o=0;o<r.length;++o)n.push([\"ptr\",o,\"=b_ptr\",o,\"+ptr_shift\"].join(\"\"));for(n.push(a),o=t.length-1;o>=1;--o)i&&n.push(\"pivot_ptr+=f\"+o),r.length>1?n.push(\"ptr_shift+=e\"+o):n.push(\"ptr0+=e\"+o),n.push(\"}\")}function x(){t.length>1&&c&&n.push(\"free(pivot1)\",\"free(pivot2)\")}function b(e,r){var i=\"el\"+e,a=\"el\"+r;if(t.length>1){var o=\"__l\"+ ++u;y(o,[i,a],!1,[\"comp=\",g(\"ptr0\"),\"-\",g(\"ptr1\"),\"\\n\",\"if(comp>0){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0;break \",o,\"}\\n\",\"if(comp<0){break \",o,\"}\"].join(\"\"))}else n.push([\"if(\",g(d(i)),\">\",g(d(a)),\"){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0}\"].join(\"\"))}function _(e,r){t.length>1?m([e,r],!1,v(\"ptr0\",g(\"ptr1\"))):n.push(v(d(e),g(d(r))))}function w(e,r,i){if(t.length>1){var a=\"__l\"+ ++u;y(a,[r],!0,[e,\"=\",g(\"ptr0\"),\"-pivot\",i,\"[pivot_ptr]\\n\",\"if(\",e,\"!==0){break \",a,\"}\"].join(\"\"))}else n.push([e,\"=\",g(d(r)),\"-pivot\",i].join(\"\"))}function k(e,r){t.length>1?m([e,r],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",\"tmp\")].join(\"\")):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",\"tmp\")].join(\"\"))}function T(e,r,i){t.length>1?(m([e,r,i],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",g(\"ptr2\")),\"\\n\",v(\"ptr2\",\"tmp\")].join(\"\")),n.push(\"++\"+r,\"--\"+i)):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"ptr2=\",d(i),\"\\n\",\"++\",r,\"\\n\",\"--\",i,\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",g(\"ptr2\")),\"\\n\",v(\"ptr2\",\"tmp\")].join(\"\"))}function A(t,e){k(t,e),n.push(\"--\"+e)}function M(e,r,i){t.length>1?m([e,r],!0,[v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",[\"pivot\",i,\"[pivot_ptr]\"].join(\"\"))].join(\"\")):n.push(v(d(e),g(d(r))),v(d(r),\"pivot\"+i))}function S(e,r){n.push([\"if((\",r,\"-\",e,\")<=\",i,\"){\\n\",\"insertionSort(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}else{\\n\",s,\"(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}\"].join(\"\"))}function E(e,r,i){t.length>1?(n.push([\"__l\",++u,\":while(true){\"].join(\"\")),m([e],!0,[\"if(\",g(\"ptr0\"),\"!==pivot\",r,\"[pivot_ptr]){break __l\",u,\"}\"].join(\"\")),n.push(i,\"}\")):n.push([\"while(\",g(d(e)),\"===pivot\",r,\"){\",i,\"}\"].join(\"\"))}return n.push(\"var \"+h.join(\",\")),b(1,2),b(4,5),b(1,3),b(2,3),b(1,4),b(3,4),b(2,5),b(2,3),b(4,5),t.length>1?m([\"el1\",\"el2\",\"el3\",\"el4\",\"el5\",\"index1\",\"index3\",\"index5\"],!0,[\"pivot1[pivot_ptr]=\",g(\"ptr1\"),\"\\n\",\"pivot2[pivot_ptr]=\",g(\"ptr3\"),\"\\n\",\"pivots_are_equal=pivots_are_equal&&(pivot1[pivot_ptr]===pivot2[pivot_ptr])\\n\",\"x=\",g(\"ptr0\"),\"\\n\",\"y=\",g(\"ptr2\"),\"\\n\",\"z=\",g(\"ptr4\"),\"\\n\",v(\"ptr5\",\"x\"),\"\\n\",v(\"ptr6\",\"y\"),\"\\n\",v(\"ptr7\",\"z\")].join(\"\")):n.push([\"pivot1=\",g(d(\"el2\")),\"\\n\",\"pivot2=\",g(d(\"el4\")),\"\\n\",\"pivots_are_equal=pivot1===pivot2\\n\",\"x=\",g(d(\"el1\")),\"\\n\",\"y=\",g(d(\"el3\")),\"\\n\",\"z=\",g(d(\"el5\")),\"\\n\",v(d(\"index1\"),\"x\"),\"\\n\",v(d(\"index3\"),\"y\"),\"\\n\",v(d(\"index5\"),\"z\")].join(\"\")),_(\"index2\",\"left\"),_(\"index4\",\"right\"),n.push(\"if(pivots_are_equal){\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp\",\"k\",1),n.push(\"if(comp===0){continue}\"),n.push(\"if(comp<0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),n.push(\"while(true){\"),w(\"comp\",\"great\",1),n.push(\"if(comp>0){\"),n.push(\"great--\"),n.push(\"}else if(comp<0){\"),T(\"k\",\"less\",\"great\"),n.push(\"break\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}else{\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1<0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2>0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp>0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),T(\"k\",\"less\",\"great\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),M(\"left\",\"(less-1)\",1),M(\"right\",\"(great+1)\",2),S(\"left\",\"(less-2)\"),S(\"(great+2)\",\"right\"),n.push(\"if(pivots_are_equal){\"),x(),n.push(\"return\"),n.push(\"}\"),n.push(\"if(less<index1&&great>index5){\"),E(\"less\",1,\"++less\"),E(\"great\",2,\"--great\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1===0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2===0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp===0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),T(\"k\",\"less\",\"great\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),x(),S(\"less\",\"great\"),n.push(\"}return \"+s),t.length>1&&c?new Function(\"insertionSort\",\"malloc\",\"free\",n.join(\"\\n\"))(r,c[0],c[1]):new Function(\"insertionSort\",n.join(\"\\n\"))(r)}(t,e,m);return v(m,y)}},{\"typedarray-pool\":545}],448:[function(t,e,r){\"use strict\";var n=t(\"./lib/compile_sort.js\"),i={};e.exports=function(t){var e=t.order,r=t.dtype,a=[e,r].join(\":\"),o=i[a];return o||(i[a]=o=n(e,r)),o(t),t}},{\"./lib/compile_sort.js\":447}],449:[function(t,e,r){\"use strict\";var n=t(\"ndarray-linear-interpolate\"),i=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=new Array(_inline_3_arg4_)}\",args:[{name:\"_inline_3_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg2_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg3_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_4_arg2_(this_warped,_inline_4_arg0_),_inline_4_arg1_=_inline_4_arg3_.apply(void 0,this_warped)}\",args:[{name:\"_inline_4_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_4_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg4_\",lvalue:!1,rvalue:!1,count:0}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warpND\",blockSize:64}),a=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_7_arg2_(this_warped,_inline_7_arg0_),_inline_7_arg1_=_inline_7_arg3_(_inline_7_arg4_,this_warped[0])}\",args:[{name:\"_inline_7_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_7_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp1D\",blockSize:64}),o=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0,0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_10_arg2_(this_warped,_inline_10_arg0_),_inline_10_arg1_=_inline_10_arg3_(_inline_10_arg4_,this_warped[0],this_warped[1])}\",args:[{name:\"_inline_10_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_10_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp2D\",blockSize:64}),s=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0,0,0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_13_arg2_(this_warped,_inline_13_arg0_),_inline_13_arg1_=_inline_13_arg3_(_inline_13_arg4_,this_warped[0],this_warped[1],this_warped[2])}\",args:[{name:\"_inline_13_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_13_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp3D\",blockSize:64});e.exports=function(t,e,r){switch(e.shape.length){case 1:a(t,r,n.d1,e);break;case 2:o(t,r,n.d2,e);break;case 3:s(t,r,n.d3,e);break;default:i(t,r,n.bind(void 0,e),e.shape.length)}return t}},{\"cwise/lib/wrapper\":149,\"ndarray-linear-interpolate\":443}],450:[function(t,e,r){var n=t(\"iota-array\"),i=t(\"is-buffer\"),a=\"undefined\"!=typeof Float64Array;function o(t,e){return t[0]-e[0]}function s(){var t,e=this.stride,r=new Array(e.length);for(t=0;t<r.length;++t)r[t]=[Math.abs(e[t]),t];r.sort(o);var n=new Array(r.length);for(t=0;t<n.length;++t)n[t]=r[t][1];return n}function l(t,e){var r=[\"View\",e,\"d\",t].join(\"\");e<0&&(r=\"View_Nil\"+t);var i=\"generic\"===t;if(-1===e){var a=\"function \"+r+\"(a){this.data=a;};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return -1};proto.size=0;proto.dimension=-1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function(){return new \"+r+\"(this.data);};proto.get=proto.set=function(){};proto.pick=function(){return null};return function construct_\"+r+\"(a){return new \"+r+\"(a);}\";return new Function(a)()}if(0===e){a=\"function \"+r+\"(a,d) {this.data = a;this.offset = d};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return this.offset};proto.dimension=0;proto.size=1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function \"+r+\"_copy() {return new \"+r+\"(this.data,this.offset)};proto.pick=function \"+r+\"_pick(){return TrivialArray(this.data);};proto.valueOf=proto.get=function \"+r+\"_get(){return \"+(i?\"this.data.get(this.offset)\":\"this.data[this.offset]\")+\"};proto.set=function \"+r+\"_set(v){return \"+(i?\"this.data.set(this.offset,v)\":\"this.data[this.offset]=v\")+\"};return function construct_\"+r+\"(a,b,c,d){return new \"+r+\"(a,d)}\";return new Function(\"TrivialArray\",a)(c[t][0])}a=[\"'use strict'\"];var o=n(e),l=o.map(function(t){return\"i\"+t}),u=\"this.offset+\"+o.map(function(t){return\"this.stride[\"+t+\"]*i\"+t}).join(\"+\"),h=o.map(function(t){return\"b\"+t}).join(\",\"),f=o.map(function(t){return\"c\"+t}).join(\",\");a.push(\"function \"+r+\"(a,\"+h+\",\"+f+\",d){this.data=a\",\"this.shape=[\"+h+\"]\",\"this.stride=[\"+f+\"]\",\"this.offset=d|0}\",\"var proto=\"+r+\".prototype\",\"proto.dtype='\"+t+\"'\",\"proto.dimension=\"+e),a.push(\"Object.defineProperty(proto,'size',{get:function \"+r+\"_size(){return \"+o.map(function(t){return\"this.shape[\"+t+\"]\"}).join(\"*\"),\"}})\"),1===e?a.push(\"proto.order=[0]\"):(a.push(\"Object.defineProperty(proto,'order',{get:\"),e<4?(a.push(\"function \"+r+\"_order(){\"),2===e?a.push(\"return (Math.abs(this.stride[0])>Math.abs(this.stride[1]))?[1,0]:[0,1]}})\"):3===e&&a.push(\"var s0=Math.abs(this.stride[0]),s1=Math.abs(this.stride[1]),s2=Math.abs(this.stride[2]);if(s0>s1){if(s1>s2){return [2,1,0];}else if(s0>s2){return [1,2,0];}else{return [1,0,2];}}else if(s0>s2){return [2,0,1];}else if(s2>s1){return [0,1,2];}else{return [0,2,1];}}})\")):a.push(\"ORDER})\")),a.push(\"proto.set=function \"+r+\"_set(\"+l.join(\",\")+\",v){\"),i?a.push(\"return this.data.set(\"+u+\",v)}\"):a.push(\"return this.data[\"+u+\"]=v}\"),a.push(\"proto.get=function \"+r+\"_get(\"+l.join(\",\")+\"){\"),i?a.push(\"return this.data.get(\"+u+\")}\"):a.push(\"return this.data[\"+u+\"]}\"),a.push(\"proto.index=function \"+r+\"_index(\",l.join(),\"){return \"+u+\"}\"),a.push(\"proto.hi=function \"+r+\"_hi(\"+l.join(\",\")+\"){return new \"+r+\"(this.data,\"+o.map(function(t){return[\"(typeof i\",t,\"!=='number'||i\",t,\"<0)?this.shape[\",t,\"]:i\",t,\"|0\"].join(\"\")}).join(\",\")+\",\"+o.map(function(t){return\"this.stride[\"+t+\"]\"}).join(\",\")+\",this.offset)}\");var p=o.map(function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"}),d=o.map(function(t){return\"c\"+t+\"=this.stride[\"+t+\"]\"});a.push(\"proto.lo=function \"+r+\"_lo(\"+l.join(\",\")+\"){var b=this.offset,d=0,\"+p.join(\",\")+\",\"+d.join(\",\"));for(var g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){d=i\"+g+\"|0;b+=c\"+g+\"*d;a\"+g+\"-=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map(function(t){return\"a\"+t}).join(\",\")+\",\"+o.map(function(t){return\"c\"+t}).join(\",\")+\",b)}\"),a.push(\"proto.step=function \"+r+\"_step(\"+l.join(\",\")+\"){var \"+o.map(function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"}).join(\",\")+\",\"+o.map(function(t){return\"b\"+t+\"=this.stride[\"+t+\"]\"}).join(\",\")+\",c=this.offset,d=0,ceil=Math.ceil\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'){d=i\"+g+\"|0;if(d<0){c+=b\"+g+\"*(a\"+g+\"-1);a\"+g+\"=ceil(-a\"+g+\"/d)}else{a\"+g+\"=ceil(a\"+g+\"/d)}b\"+g+\"*=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map(function(t){return\"a\"+t}).join(\",\")+\",\"+o.map(function(t){return\"b\"+t}).join(\",\")+\",c)}\");var v=new Array(e),m=new Array(e);for(g=0;g<e;++g)v[g]=\"a[i\"+g+\"]\",m[g]=\"b[i\"+g+\"]\";a.push(\"proto.transpose=function \"+r+\"_transpose(\"+l+\"){\"+l.map(function(t,e){return t+\"=(\"+t+\"===undefined?\"+e+\":\"+t+\"|0)\"}).join(\";\"),\"var a=this.shape,b=this.stride;return new \"+r+\"(this.data,\"+v.join(\",\")+\",\"+m.join(\",\")+\",this.offset)}\"),a.push(\"proto.pick=function \"+r+\"_pick(\"+l+\"){var a=[],b=[],c=this.offset\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){c=(c+this.stride[\"+g+\"]*i\"+g+\")|0}else{a.push(this.shape[\"+g+\"]);b.push(this.stride[\"+g+\"])}\");return a.push(\"var ctor=CTOR_LIST[a.length+1];return ctor(this.data,a,b,c)}\"),a.push(\"return function construct_\"+r+\"(data,shape,stride,offset){return new \"+r+\"(data,\"+o.map(function(t){return\"shape[\"+t+\"]\"}).join(\",\")+\",\"+o.map(function(t){return\"stride[\"+t+\"]\"}).join(\",\")+\",offset)}\"),new Function(\"CTOR_LIST\",\"ORDER\",a.join(\"\\n\"))(c[t],s)}var c={float32:[],float64:[],int8:[],int16:[],int32:[],uint8:[],uint16:[],uint32:[],array:[],uint8_clamped:[],buffer:[],generic:[]};e.exports=function(t,e,r,n){if(void 0===t)return(0,c.array[0])([]);\"number\"==typeof t&&(t=[t]),void 0===e&&(e=[t.length]);var o=e.length;if(void 0===r){r=new Array(o);for(var s=o-1,u=1;s>=0;--s)r[s]=u,u*=e[s]}if(void 0===n)for(n=0,s=0;s<o;++s)r[s]<0&&(n-=(e[s]-1)*r[s]);for(var h=function(t){if(i(t))return\"buffer\";if(a)switch(Object.prototype.toString.call(t)){case\"[object Float64Array]\":return\"float64\";case\"[object Float32Array]\":return\"float32\";case\"[object Int8Array]\":return\"int8\";case\"[object Int16Array]\":return\"int16\";case\"[object Int32Array]\":return\"int32\";case\"[object Uint8Array]\":return\"uint8\";case\"[object Uint16Array]\":return\"uint16\";case\"[object Uint32Array]\":return\"uint32\";case\"[object Uint8ClampedArray]\":return\"uint8_clamped\"}return Array.isArray(t)?\"array\":\"generic\"}(t),f=c[h];f.length<=o+1;)f.push(l(h,f.length-1));return(0,f[o+1])(t,e,r,n)}},{\"iota-array\":416,\"is-buffer\":418}],451:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=Math.pow(2,-1074),a=-1>>>0;e.exports=function(t,e){if(isNaN(t)||isNaN(e))return NaN;if(t===e)return t;if(0===t)return e<0?-i:i;var r=n.hi(t),o=n.lo(t);e>t==t>0?o===a?(r+=1,o=0):o+=1:0===o?(o=a,r-=1):o-=1;return n.pack(o,r)}},{\"double-bits\":167}],452:[function(t,e,r){var n=Math.PI,i=c(120);function a(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function o(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}function s(t,e,r,a,o,c,u,h,f,p){if(p)k=p[0],T=p[1],_=p[2],w=p[3];else{var d=l(t,e,-o);t=d.x,e=d.y;var g=(t-(h=(d=l(h,f,-o)).x))/2,v=(e-(f=d.y))/2,m=g*g/(r*r)+v*v/(a*a);m>1&&(r*=m=Math.sqrt(m),a*=m);var y=r*r,x=a*a,b=(c==u?-1:1)*Math.sqrt(Math.abs((y*x-y*v*v-x*g*g)/(y*v*v+x*g*g)));b==1/0&&(b=1);var _=b*r*v/a+(t+h)/2,w=b*-a*g/r+(e+f)/2,k=Math.asin(((e-w)/a).toFixed(9)),T=Math.asin(((f-w)/a).toFixed(9));(k=t<_?n-k:k)<0&&(k=2*n+k),(T=h<_?n-T:T)<0&&(T=2*n+T),u&&k>T&&(k-=2*n),!u&&T>k&&(T-=2*n)}if(Math.abs(T-k)>i){var A=T,M=h,S=f;T=k+i*(u&&T>k?1:-1);var E=s(h=_+r*Math.cos(T),f=w+a*Math.sin(T),r,a,o,0,u,M,S,[T,A,_,w])}var C=Math.tan((T-k)/4),L=4/3*r*C,P=4/3*a*C,O=[2*t-(t+L*Math.sin(k)),2*e-(e-P*Math.cos(k)),h+L*Math.sin(T),f-P*Math.cos(T),h,f];if(p)return O;E&&(O=O.concat(E));for(var z=0;z<O.length;){var I=l(O[z],O[z+1],o);O[z++]=I.x,O[z++]=I.y}return O}function l(t,e,r){return{x:t*Math.cos(r)-e*Math.sin(r),y:t*Math.sin(r)+e*Math.cos(r)}}function c(t){return t*(n/180)}e.exports=function(t){for(var e,r=[],n=0,i=0,l=0,u=0,h=null,f=null,p=0,d=0,g=0,v=t.length;g<v;g++){var m=t[g],y=m[0];switch(y){case\"M\":l=m[1],u=m[2];break;case\"A\":(m=s(p,d,m[1],m[2],c(m[3]),m[4],m[5],m[6],m[7])).unshift(\"C\"),m.length>7&&(r.push(m.splice(0,7)),m.unshift(\"C\"));break;case\"S\":var x=p,b=d;\"C\"!=e&&\"S\"!=e||(x+=x-n,b+=b-i),m=[\"C\",x,b,m[1],m[2],m[3],m[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(h=2*p-h,f=2*d-f):(h=p,f=d),m=o(p,d,h,f,m[1],m[2]);break;case\"Q\":h=m[1],f=m[2],m=o(p,d,m[1],m[2],m[3],m[4]);break;case\"L\":m=a(p,d,m[1],m[2]);break;case\"H\":m=a(p,d,m[1],d);break;case\"V\":m=a(p,d,p,m[1]);break;case\"Z\":m=a(p,d,l,u)}e=y,p=m[m.length-2],d=m[m.length-1],m.length>4?(n=m[m.length-4],i=m[m.length-3]):(n=p,i=d),r.push(m)}return r}},{}],453:[function(t,e,r){r.vertexNormals=function(t,e,r){for(var n=e.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o)i[o]=[0,0,0];for(o=0;o<t.length;++o)for(var s=t[o],l=0,c=s[s.length-1],u=s[0],h=0;h<s.length;++h){l=c,c=u,u=s[(h+1)%s.length];for(var f=e[l],p=e[c],d=e[u],g=new Array(3),v=0,m=new Array(3),y=0,x=0;x<3;++x)g[x]=f[x]-p[x],v+=g[x]*g[x],m[x]=d[x]-p[x],y+=m[x]*m[x];if(v*y>a){var b=i[c],_=1/Math.sqrt(v*y);for(x=0;x<3;++x){var w=(x+1)%3,k=(x+2)%3;b[x]+=_*(m[w]*g[k]-m[k]*g[w])}}}for(o=0;o<n;++o){b=i[o];var T=0;for(x=0;x<3;++x)T+=b[x]*b[x];if(T>a)for(_=1/Math.sqrt(T),x=0;x<3;++x)b[x]*=_;else for(x=0;x<3;++x)b[x]=0}return i},r.faceNormals=function(t,e,r){for(var n=t.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o){for(var s=t[o],l=new Array(3),c=0;c<3;++c)l[c]=e[s[c]];var u=new Array(3),h=new Array(3);for(c=0;c<3;++c)u[c]=l[1][c]-l[0][c],h[c]=l[2][c]-l[0][c];var f=new Array(3),p=0;for(c=0;c<3;++c){var d=(c+1)%3,g=(c+2)%3;f[c]=u[d]*h[g]-u[g]*h[d],p+=f[c]*f[c]}p=p>a?1/Math.sqrt(p):0;for(c=0;c<3;++c)f[c]*=p;i[o]=f}return i}},{}],454:[function(t,e,r){\"use strict\";var n=Object.getOwnPropertySymbols,i=Object.prototype.hasOwnProperty,a=Object.prototype.propertyIsEnumerable;e.exports=function(){try{if(!Object.assign)return!1;var t=new String(\"abc\");if(t[5]=\"de\",\"5\"===Object.getOwnPropertyNames(t)[0])return!1;for(var e={},r=0;r<10;r++)e[\"_\"+String.fromCharCode(r)]=r;if(\"0123456789\"!==Object.getOwnPropertyNames(e).map(function(t){return e[t]}).join(\"\"))return!1;var n={};return\"abcdefghijklmnopqrst\".split(\"\").forEach(function(t){n[t]=t}),\"abcdefghijklmnopqrst\"===Object.keys(Object.assign({},n)).join(\"\")}catch(t){return!1}}()?Object.assign:function(t,e){for(var r,o,s=function(t){if(null==t)throw new TypeError(\"Object.assign cannot be called with null or undefined\");return Object(t)}(t),l=1;l<arguments.length;l++){for(var c in r=Object(arguments[l]))i.call(r,c)&&(s[c]=r[c]);if(n){o=n(r);for(var u=0;u<o.length;u++)a.call(r,o[u])&&(s[o[u]]=r[o[u]])}}return s}},{}],455:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a,o,s,l,c){var u=e+a+c;if(h>0){var h=Math.sqrt(u+1);t[0]=.5*(o-l)/h,t[1]=.5*(s-n)/h,t[2]=.5*(r-a)/h,t[3]=.5*h}else{var f=Math.max(e,a,c),h=Math.sqrt(2*f-u+1);e>=f?(t[0]=.5*h,t[1]=.5*(i+r)/h,t[2]=.5*(s+n)/h,t[3]=.5*(o-l)/h):a>=f?(t[0]=.5*(r+i)/h,t[1]=.5*h,t[2]=.5*(l+o)/h,t[3]=.5*(s-n)/h):(t[0]=.5*(n+s)/h,t[1]=.5*(o+l)/h,t[2]=.5*h,t[3]=.5*(r-i)/h)}return t}},{}],456:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.rotation||[0,0,0,1],n=t.radius||1;e=[].slice.call(e,0,3),u(r=[].slice.call(r,0,4),r);var i=new h(r,e,Math.log(n));i.setDistanceLimits(t.zoomMin,t.zoomMax),(\"eye\"in t||\"up\"in t)&&i.lookAt(0,t.eye,t.center,t.up);return i};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/lookAt\"),a=t(\"gl-mat4/fromQuat\"),o=t(\"gl-mat4/invert\"),s=t(\"./lib/quatFromFrame\");function l(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function c(t,e,r,n){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2)+Math.pow(n,2))}function u(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=c(r,n,i,a);o>1e-6?(t[0]=r/o,t[1]=n/o,t[2]=i/o,t[3]=a/o):(t[0]=t[1]=t[2]=0,t[3]=1)}function h(t,e,r){this.radius=n([r]),this.center=n(e),this.rotation=n(t),this.computedRadius=this.radius.curve(0),this.computedCenter=this.center.curve(0),this.computedRotation=this.rotation.curve(0),this.computedUp=[.1,0,0],this.computedEye=[.1,0,0],this.computedMatrix=[.1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],this.recalcMatrix(0)}var f=h.prototype;f.lastT=function(){return Math.max(this.radius.lastT(),this.center.lastT(),this.rotation.lastT())},f.recalcMatrix=function(t){this.radius.curve(t),this.center.curve(t),this.rotation.curve(t);var e=this.computedRotation;u(e,e);var r=this.computedMatrix;a(r,e);var n=this.computedCenter,i=this.computedEye,o=this.computedUp,s=Math.exp(this.computedRadius[0]);i[0]=n[0]+s*r[2],i[1]=n[1]+s*r[6],i[2]=n[2]+s*r[10],o[0]=r[1],o[1]=r[5],o[2]=r[9];for(var l=0;l<3;++l){for(var c=0,h=0;h<3;++h)c+=r[l+4*h]*i[h];r[12+l]=-c}},f.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r},f.idle=function(t){this.center.idle(t),this.radius.idle(t),this.rotation.idle(t)},f.flush=function(t){this.center.flush(t),this.radius.flush(t),this.rotation.flush(t)},f.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=i[1],o=i[5],s=i[9],c=l(a,o,s);a/=c,o/=c,s/=c;var u=i[0],h=i[4],f=i[8],p=u*a+h*o+f*s,d=l(u-=a*p,h-=o*p,f-=s*p);u/=d,h/=d,f/=d;var g=i[2],v=i[6],m=i[10],y=g*a+v*o+m*s,x=g*u+v*h+m*f,b=l(g-=y*a+x*u,v-=y*o+x*h,m-=y*s+x*f);g/=b,v/=b,m/=b;var _=u*e+a*r,w=h*e+o*r,k=f*e+s*r;this.center.move(t,_,w,k);var T=Math.exp(this.computedRadius[0]);T=Math.max(1e-4,T+n),this.radius.set(t,Math.log(T))},f.rotate=function(t,e,r,n){this.recalcMatrix(t),e=e||0,r=r||0;var i=this.computedMatrix,a=i[0],o=i[4],s=i[8],u=i[1],h=i[5],f=i[9],p=i[2],d=i[6],g=i[10],v=e*a+r*u,m=e*o+r*h,y=e*s+r*f,x=-(d*y-g*m),b=-(g*v-p*y),_=-(p*m-d*v),w=Math.sqrt(Math.max(0,1-Math.pow(x,2)-Math.pow(b,2)-Math.pow(_,2))),k=c(x,b,_,w);k>1e-6?(x/=k,b/=k,_/=k,w/=k):(x=b=_=0,w=1);var T=this.computedRotation,A=T[0],M=T[1],S=T[2],E=T[3],C=A*w+E*x+M*_-S*b,L=M*w+E*b+S*x-A*_,P=S*w+E*_+A*b-M*x,O=E*w-A*x-M*b-S*_;if(n){x=p,b=d,_=g;var z=Math.sin(n)/l(x,b,_);x*=z,b*=z,_*=z,O=O*(w=Math.cos(e))-(C=C*w+O*x+L*_-P*b)*x-(L=L*w+O*b+P*x-C*_)*b-(P=P*w+O*_+C*b-L*x)*_}var I=c(C,L,P,O);I>1e-6?(C/=I,L/=I,P/=I,O/=I):(C=L=P=0,O=1),this.rotation.set(t,C,L,P,O)},f.lookAt=function(t,e,r,n){this.recalcMatrix(t),r=r||this.computedCenter,e=e||this.computedEye,n=n||this.computedUp;var a=this.computedMatrix;i(a,e,r,n);var o=this.computedRotation;s(o,a[0],a[1],a[2],a[4],a[5],a[6],a[8],a[9],a[10]),u(o,o),this.rotation.set(t,o[0],o[1],o[2],o[3]);for(var l=0,c=0;c<3;++c)l+=Math.pow(r[c]-e[c],2);this.radius.set(t,.5*Math.log(Math.max(l,1e-6))),this.center.set(t,r[0],r[1],r[2])},f.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},f.setMatrix=function(t,e){var r=this.computedRotation;s(r,e[0],e[1],e[2],e[4],e[5],e[6],e[8],e[9],e[10]),u(r,r),this.rotation.set(t,r[0],r[1],r[2],r[3]);var n=this.computedMatrix;o(n,e);var i=n[15];if(Math.abs(i)>1e-6){var a=n[12]/i,l=n[13]/i,c=n[14]/i;this.recalcMatrix(t);var h=Math.exp(this.computedRadius[0]);this.center.set(t,a-n[2]*h,l-n[6]*h,c-n[10]*h),this.radius.idle(t)}else this.center.idle(t),this.radius.idle(t)},f.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},f.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},f.getDistanceLimits=function(t){var e=this.radius.bounds;return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},f.toJSON=function(){return this.recalcMatrix(this.lastT()),{center:this.computedCenter.slice(),rotation:this.computedRotation.slice(),distance:Math.log(this.computedRadius[0]),zoomMin:this.radius.bounds[0][0],zoomMax:this.radius.bounds[1][0]}},f.fromJSON=function(t){var e=this.lastT(),r=t.center;r&&this.center.set(e,r[0],r[1],r[2]);var n=t.rotation;n&&this.rotation.set(e,n[0],n[1],n[2],n[3]);var i=t.distance;i&&i>0&&this.radius.set(e,Math.log(i)),this.setDistanceLimits(t.zoomMin,t.zoomMax)}},{\"./lib/quatFromFrame\":455,\"filtered-vector\":226,\"gl-mat4/fromQuat\":262,\"gl-mat4/invert\":265,\"gl-mat4/lookAt\":266}],457:[function(t,e,r){\"use strict\";var n=t(\"repeat-string\");e.exports=function(t,e,r){return n(r=\"undefined\"!=typeof r?r+\"\":\" \",e)+t}},{\"repeat-string\":503}],458:[function(t,e,r){\"use strict\";function n(t,e){if(\"string\"!=typeof t)return[t];var r=[t];\"string\"==typeof e||Array.isArray(e)?e={brackets:e}:e||(e={});var n=e.brackets?Array.isArray(e.brackets)?e.brackets:[e.brackets]:[\"{}\",\"[]\",\"()\"],i=e.escape||\"___\",a=!!e.flat;n.forEach(function(t){var e=new RegExp([\"\\\\\",t[0],\"[^\\\\\",t[0],\"\\\\\",t[1],\"]*\\\\\",t[1]].join(\"\")),n=[];function a(e,a,o){var s=r.push(e.slice(t[0].length,-t[1].length))-1;return n.push(s),i+s+i}r.forEach(function(t,n){for(var i,o=0;t!=i;)if(i=t,t=t.replace(e,a),o++>1e4)throw Error(\"References have circular dependency. Please, check them.\");r[n]=t}),n=n.reverse(),r=r.map(function(e){return n.forEach(function(r){e=e.replace(new RegExp(\"(\\\\\"+i+r+\"\\\\\"+i+\")\",\"g\"),t[0]+\"$1\"+t[1])}),e})});var o=new RegExp(\"\\\\\"+i+\"([0-9]+)\\\\\"+i);return a?r:function t(e,r,n){for(var i,a=[],s=0;i=o.exec(e);){if(s++>1e4)throw Error(\"Circular references in parenthesis\");a.push(e.slice(0,i.index)),a.push(t(r[i[1]],r)),e=e.slice(i.index+i[0].length)}return a.push(e),a}(r[0],r)}function i(t,e){if(e&&e.flat){var r,n=e&&e.escape||\"___\",i=t[0];if(!i)return\"\";for(var a=new RegExp(\"\\\\\"+n+\"([0-9]+)\\\\\"+n),o=0;i!=r;){if(o++>1e4)throw Error(\"Circular references in \"+t);r=i,i=i.replace(a,s)}return i}return t.reduce(function t(e,r){return Array.isArray(r)&&(r=r.reduce(t,\"\")),e+r},\"\");function s(e,r){if(null==t[r])throw Error(\"Reference \"+r+\"is undefined\");return t[r]}}function a(t,e){return Array.isArray(t)?i(t,e):n(t,e)}a.parse=n,a.stringify=i,e.exports=a},{}],459:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\");e.exports=function(t){var e;arguments.length>1&&(t=arguments);\"string\"==typeof t?t=t.split(/\\s/).map(parseFloat):\"number\"==typeof t&&(t=[t]);t.length&&\"number\"==typeof t[0]?e=1===t.length?{width:t[0],height:t[0],x:0,y:0}:2===t.length?{width:t[0],height:t[1],x:0,y:0}:{x:t[0],y:t[1],width:t[2]-t[0]||0,height:t[3]-t[1]||0}:t&&(t=n(t,{left:\"x l left Left\",top:\"y t top Top\",width:\"w width W Width\",height:\"h height W Width\",bottom:\"b bottom Bottom\",right:\"r right Right\"}),e={x:t.left||0,y:t.top||0},null==t.width?t.right?e.width=t.right-e.x:e.width=0:e.width=t.width,null==t.height?t.bottom?e.height=t.bottom-e.y:e.height=0:e.height=t.height);return e}},{\"pick-by-alias\":465}],460:[function(t,e,r){e.exports=function(t){var e=[];return t.replace(i,function(t,r,i){var o=r.toLowerCase();for(i=function(t){var e=t.match(a);return e?e.map(Number):[]}(i),\"m\"==o&&i.length>2&&(e.push([r].concat(i.splice(0,2))),o=\"l\",r=\"m\"==r?\"l\":\"L\");;){if(i.length==n[o])return i.unshift(r),e.push(i);if(i.length<n[o])throw new Error(\"malformed path data\");e.push([r].concat(i.splice(0,n[o])))}}),e};var n={a:7,c:6,h:1,l:2,m:2,q:4,s:4,t:2,v:1,z:0},i=/([astvzqmhlc])([^astvzqmhlc]*)/gi;var a=/-?[0-9]*\\.?[0-9]+(?:e[-+]?\\d+)?/gi},{}],461:[function(t,e,r){e.exports=function(t,e){e||(e=[0,\"\"]),t=String(t);var r=parseFloat(t,10);return e[0]=r,e[1]=t.match(/[\\d.\\-\\+]*\\s*(.*)/)[1]||\"\",e}},{}],462:[function(t,e,r){(function(t){(function(){var r,n,i,a,o,s;\"undefined\"!=typeof performance&&null!==performance&&performance.now?e.exports=function(){return performance.now()}:\"undefined\"!=typeof t&&null!==t&&t.hrtime?(e.exports=function(){return(r()-o)/1e6},n=t.hrtime,a=(r=function(){var t;return 1e9*(t=n())[0]+t[1]})(),s=1e9*t.uptime(),o=a-s):Date.now?(e.exports=function(){return Date.now()-i},i=Date.now()):(e.exports=function(){return(new Date).getTime()-i},i=(new Date).getTime())}).call(this)}).call(this,t(\"_process\"))},{_process:482}],463:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<n){for(var r=1,a=0;a<e;++a)for(var o=0;o<a;++o)if(t[a]<t[o])r=-r;else if(t[a]===t[o])return 0;return r}for(var s=i.mallocUint8(e),a=0;a<e;++a)s[a]=0;for(var r=1,a=0;a<e;++a)if(!s[a]){var l=1;s[a]=1;for(var o=t[a];o!==a;o=t[o]){if(s[o])return i.freeUint8(s),0;l+=1,s[o]=1}1&l||(r=-r)}return i.freeUint8(s),r};var n=32,i=t(\"typedarray-pool\")},{\"typedarray-pool\":545}],464:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"invert-permutation\");r.rank=function(t){var e=t.length;switch(e){case 0:case 1:return 0;case 2:return t[1]}var r,a,o,s=n.mallocUint32(e),l=n.mallocUint32(e),c=0;for(i(t,l),o=0;o<e;++o)s[o]=t[o];for(o=e-1;o>0;--o)a=l[o],r=s[o],s[o]=s[a],s[a]=r,l[o]=l[r],l[r]=a,c=(c+r)*o;return n.freeUint32(l),n.freeUint32(s),c},r.unrank=function(t,e,r){switch(t){case 0:return r||[];case 1:return r?(r[0]=0,r):[0];case 2:return r?(e?(r[0]=0,r[1]=1):(r[0]=1,r[1]=0),r):e?[0,1]:[1,0]}var n,i,a,o=1;for((r=r||new Array(t))[0]=0,a=1;a<t;++a)r[a]=a,o=o*a|0;for(a=t-1;a>0;--a)e=e-(n=e/o|0)*o|0,o=o/a|0,i=0|r[a],r[a]=0|r[n],r[n]=0|i;return r}},{\"invert-permutation\":415,\"typedarray-pool\":545}],465:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n,a,o={};if(\"string\"==typeof e&&(e=i(e)),Array.isArray(e)){var s={};for(a=0;a<e.length;a++)s[e[a]]=!0;e=s}for(n in e)e[n]=i(e[n]);var l={};for(n in e){var c=e[n];if(Array.isArray(c))for(a=0;a<c.length;a++){var u=c[a];if(r&&(l[u]=!0),u in t){if(o[n]=t[u],r)for(var h=a;h<c.length;h++)l[c[h]]=!0;break}}else n in t&&(e[n]&&(o[n]=t[n]),r&&(l[n]=!0))}if(r)for(n in t)l[n]||(o[n]=t[n]);return o};var n={};function i(t){return n[t]?n[t]:(\"string\"==typeof t&&(t=n[t]=t.split(/\\s*,\\s*|\\s+/)),t)}},{}],466:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=0|e.length,i=t.length,a=[new Array(r),new Array(r)],o=0;o<r;++o)a[0][o]=[],a[1][o]=[];for(var o=0;o<i;++o){var s=t[o];a[0][s[0]].push(s),a[1][s[1]].push(s)}for(var l=[],o=0;o<r;++o)a[0][o].length+a[1][o].length===0&&l.push([o]);function c(t,e){var r=a[e][t[e]];r.splice(r.indexOf(t),1)}function u(t,r,i){for(var o,s,l,u=0;u<2;++u)if(a[u][r].length>0){o=a[u][r][0],l=u;break}s=o[1^l];for(var h=0;h<2;++h)for(var f=a[h][r],p=0;p<f.length;++p){var d=f[p],g=d[1^h],v=n(e[t],e[r],e[s],e[g]);v>0&&(o=d,s=g,l=h)}return i?s:(o&&c(o,l),s)}function h(t,r){var i=a[r][t][0],o=[t];c(i,r);for(var s=i[1^r];;){for(;s!==t;)o.push(s),s=u(o[o.length-2],s,!1);if(a[0][t].length+a[1][t].length===0)break;var l=o[o.length-1],h=t,f=o[1],p=u(l,h,!0);if(n(e[l],e[h],e[f],e[p])<0)break;o.push(t),s=u(l,h)}return o}function f(t,e){return e[1]===e[e.length-1]}for(var o=0;o<r;++o)for(var p=0;p<2;++p){for(var d=[];a[p][o].length>0;){a[0][o].length;var g=h(o,p);f(d,g)?d.push.apply(d,g):(d.length>0&&l.push(d),d=g)}d.length>0&&l.push(d)}return l};var n=t(\"compare-angle\")},{\"compare-angle\":127}],467:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=n(t,e.length),i=new Array(e.length),a=new Array(e.length),o=[],s=0;s<e.length;++s){var l=r[s].length;a[s]=l,i[s]=!0,l<=1&&o.push(s)}for(;o.length>0;){var c=o.pop();i[c]=!1;for(var u=r[c],s=0;s<u.length;++s){var h=u[s];0==--a[h]&&o.push(h)}}for(var f=new Array(e.length),p=[],s=0;s<e.length;++s)if(i[s]){var c=p.length;f[s]=c,p.push(e[s])}else f[s]=-1;for(var d=[],s=0;s<t.length;++s){var g=t[s];i[g[0]]&&i[g[1]]&&d.push([f[g[0]],f[g[1]]])}return[d,p]};var n=t(\"edges-to-adjacency-list\")},{\"edges-to-adjacency-list\":171}],468:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=c(t,e);t=r[0];for(var h=(e=r[1]).length,f=(t.length,n(t,e.length)),p=0;p<h;++p)if(f[p].length%2==1)throw new Error(\"planar-graph-to-polyline: graph must be manifold\");var d=i(t,e);for(var g=(d=d.filter(function(t){for(var r=t.length,n=[0],i=0;i<r;++i){var a=e[t[i]],l=e[t[(i+1)%r]],c=o(-a[0],a[1]),u=o(-a[0],l[1]),h=o(l[0],a[1]),f=o(l[0],l[1]);n=s(n,s(s(c,u),s(h,f)))}return n[n.length-1]>0})).length,v=new Array(g),m=new Array(g),p=0;p<g;++p){v[p]=p;var y=new Array(g),x=d[p].map(function(t){return e[t]}),b=a([x]),_=0;t:for(var w=0;w<g;++w)if(y[w]=0,p!==w){for(var k=d[w],T=k.length,A=0;A<T;++A){var M=b(e[k[A]]);if(0!==M){M<0&&(y[w]=1,_+=1);continue t}}y[w]=1,_+=1}m[p]=[_,p,y]}m.sort(function(t,e){return e[0]-t[0]});for(var p=0;p<g;++p)for(var y=m[p],S=y[1],E=y[2],w=0;w<g;++w)E[w]&&(v[w]=S);for(var C=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=[];return e}(g),p=0;p<g;++p)C[p].push(v[p]),C[v[p]].push(p);for(var L={},P=u(h,!1),p=0;p<g;++p)for(var k=d[p],T=k.length,w=0;w<T;++w){var O=k[w],z=k[(w+1)%T],I=Math.min(O,z)+\":\"+Math.max(O,z);if(I in L){var D=L[I];C[D].push(p),C[p].push(D),P[O]=P[z]=!0}else L[I]=p}function R(t){for(var e=t.length,r=0;r<e;++r)if(!P[t[r]])return!1;return!0}for(var F=[],B=u(g,-1),p=0;p<g;++p)v[p]!==p||R(d[p])?B[p]=-1:(F.push(p),B[p]=0);var r=[];for(;F.length>0;){var N=F.pop(),j=C[N];l(j,function(t,e){return t-e});var U,V=j.length,q=B[N];if(0===q){var k=d[N];U=[k]}for(var p=0;p<V;++p){var H=j[p];if(!(B[H]>=0)&&(B[H]=1^q,F.push(H),0===q)){var k=d[H];R(k)||(k.reverse(),U.push(k))}}0===q&&r.push(U)}return r};var n=t(\"edges-to-adjacency-list\"),i=t(\"planar-dual\"),a=t(\"point-in-big-polygon\"),o=t(\"two-product\"),s=t(\"robust-sum\"),l=t(\"uniq\"),c=t(\"./lib/trim-leaves\");function u(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}},{\"./lib/trim-leaves\":467,\"edges-to-adjacency-list\":171,\"planar-dual\":466,\"point-in-big-polygon\":472,\"robust-sum\":515,\"two-product\":543,uniq:547}],469:[function(t,e,r){\"use strict\";e.exports=t(\"./quad\")},{\"./quad\":471}],470:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],471:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"clamp\"),a=t(\"parse-rect\"),o=t(\"array-bounds\"),s=t(\"pick-by-alias\"),l=t(\"defined\"),c=t(\"flatten-vertex-data\"),u=t(\"is-obj\"),h=t(\"dtype\"),f=t(\"math-log2\");function p(t,e){for(var r=e[0],n=e[1],a=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=i((t[2*l]-r)*a,0,1),s[2*l+1]=i((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,\"float64\"),e=s(e,{bounds:\"range bounds dataBox databox\",maxDepth:\"depth maxDepth maxdepth level maxLevel maxlevel levels\",dtype:\"type dtype format out dst output destination\"});var r=l(e.maxDepth,255),i=l(e.bounds,o(t,2));i[0]===i[2]&&i[2]++,i[1]===i[3]&&i[3]++;var d,g=p(t,i),v=t.length>>>1;e.dtype||(e.dtype=\"array\"),\"string\"==typeof e.dtype?d=new(h(e.dtype))(v):e.dtype&&(d=e.dtype,Array.isArray(d)&&(d.length=v));for(var m=0;m<v;++m)d[m]=m;var y=[],x=[],b=[],_=[];!function t(e,n,i,a,o,s){if(!a.length)return null;var l=y[o]||(y[o]=[]);var c=b[o]||(b[o]=[]);var u=x[o]||(x[o]=[]);var h=l.length;o++;if(o>r){for(var f=0;f<a.length;f++)l.push(a[f]),c.push(s),u.push(null,null,null,null);return h}l.push(a[0]);c.push(s);if(a.length<=1)return u.push(null,null,null,null),h;var p=.5*i;var d=e+p,v=n+p;var m=[],_=[],w=[],k=[];for(var T=1,A=a.length;T<A;T++){var M=a[T],S=g[2*M],E=g[2*M+1];S<d?E<v?m.push(M):_.push(M):E<v?w.push(M):k.push(M)}s<<=2;u.push(t(e,n,p,m,o,s),t(e,v,p,_,o,s+1),t(d,n,p,w,o,s+2),t(d,v,p,k,o,s+3));return h}(0,0,1,d,0,1);for(var w=0,k=0;k<y.length;k++){var T=y[k];if(d.set)d.set(T,w);else for(var A=0,M=T.length;A<M;A++)d[A+w]=T[A];var S=w+y[k].length;_[k]=[w,S],w=S}return d.range=function(){var e,r=[],o=arguments.length;for(;o--;)r[o]=arguments[o];if(u(r[r.length-1])){var c=r.pop();r.length||null==c.x&&null==c.l&&null==c.left||(r=[c],e={}),e=s(c,{level:\"level maxLevel\",d:\"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize\",lod:\"lod details ranges offsets\"})}else e={};r.length||(r=i);var h=a.apply(void 0,r),d=[Math.min(h.x,h.x+h.width),Math.min(h.y,h.y+h.height),Math.max(h.x,h.x+h.width),Math.max(h.y,h.y+h.height)],g=d[0],v=d[1],m=d[2],w=d[3],k=p([g,v,m,w],i),T=k[0],A=k[1],M=k[2],S=k[3],C=l(e.level,y.length);if(null!=e.d){var L;\"number\"==typeof e.d?L=[e.d,e.d]:e.d.length&&(L=e.d),C=Math.min(Math.max(Math.ceil(-f(Math.abs(L[0])/(i[2]-i[0]))),Math.ceil(-f(Math.abs(L[1])/(i[3]-i[1])))),C)}if(C=Math.min(C,y.length),e.lod)return function(t,e,r,i,a){for(var o=[],s=0;s<a;s++){var l=b[s],c=_[s][0],u=E(t,e,s),h=E(r,i,s),f=n.ge(l,u),p=n.gt(l,h,f,l.length-1);o[s]=[f+c,p+c]}return o}(T,A,M,S,C);var P=[];return function e(r,n,i,a,o,s){if(null!==o&&null!==s){var l=r+i,c=n+i;if(!(T>l||A>c||M<r||S<n||a>=C||o===s)){var u=y[a];void 0===s&&(s=u.length);for(var h=o;h<s;h++){var f=u[h],p=t[2*f],d=t[2*f+1];p>=g&&p<=m&&d>=v&&d<=w&&P.push(f)}var b=x[a],_=b[4*o+0],k=b[4*o+1],E=b[4*o+2],L=b[4*o+3],O=function(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}(b,o+1),z=.5*i,I=a+1;e(r,n,z,I,_,k||E||L||O),e(r,n+z,z,I,k,E||L||O),e(r+z,n,z,I,E,L||O),e(r+z,n+z,z,I,L,O)}}}(0,0,1,0,0,1),P},d;function E(t,e,r){for(var n=1,i=.5,a=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<i?e<a?0:1:e<a?2:3,o*=.5,i+=t<i?-o:o,a+=e<a?-o:o;return n}}},{\"array-bounds\":65,\"binary-search-bounds\":470,clamp:115,defined:164,dtype:169,\"flatten-vertex-data\":227,\"is-obj\":421,\"math-log2\":432,\"parse-rect\":459,\"pick-by-alias\":465}],472:[function(t,e,r){e.exports=function(t){for(var e=t.length,r=[],a=[],s=0;s<e;++s)for(var u=t[s],h=u.length,f=h-1,p=0;p<h;f=p++){var d=u[f],g=u[p];d[0]===g[0]?a.push([d,g]):r.push([d,g])}if(0===r.length)return 0===a.length?c:(v=l(a),function(t){return v(t[0],t[1])?0:1});var v;var m=i(r),y=function(t,e){return function(r){var i=o.le(e,r[0]);if(i<0)return 1;var a=t[i];if(!a){if(!(i>0&&e[i]===r[0]))return 1;a=t[i-1]}for(var s=1;a;){var l=a.key,c=n(r,l[0],l[1]);if(l[0][0]<l[1][0])if(c<0)a=a.left;else{if(!(c>0))return 0;s=-1,a=a.right}else if(c>0)a=a.left;else{if(!(c<0))return 0;s=1,a=a.right}}return s}}(m.slabs,m.coordinates);return 0===a.length?y:function(t,e){return function(r){return t(r[0],r[1])?0:e(r)}}(l(a),y)};var n=t(\"robust-orientation\")[3],i=t(\"slab-decomposition\"),a=t(\"interval-tree-1d\"),o=t(\"binary-search-bounds\");function s(){return!0}function l(t){for(var e={},r=0;r<t.length;++r){var n=t[r],i=n[0][0],o=n[0][1],l=n[1][1],c=[Math.min(o,l),Math.max(o,l)];i in e?e[i].push(c):e[i]=[c]}var u={},h=Object.keys(e);for(r=0;r<h.length;++r){var f=e[h[r]];u[h[r]]=a(f)}return function(t){return function(e,r){var n=t[e];return!!n&&!!n.queryPoint(r,s)}}(u)}function c(t){return 1}},{\"binary-search-bounds\":91,\"interval-tree-1d\":414,\"robust-orientation\":510,\"slab-decomposition\":526}],473:[function(t,e,r){var n,i=t(\"./lib/build-log\"),a=t(\"./lib/epsilon\"),o=t(\"./lib/intersecter\"),s=t(\"./lib/segment-chainer\"),l=t(\"./lib/segment-selector\"),c=t(\"./lib/geojson\"),u=!1,h=a();function f(t,e,r){var i=n.segments(t),a=n.segments(e),o=r(n.combine(i,a));return n.polygon(o)}n={buildLog:function(t){return!0===t?u=i():!1===t&&(u=!1),!1!==u&&u.list},epsilon:function(t){return h.epsilon(t)},segments:function(t){var e=o(!0,h,u);return t.regions.forEach(e.addRegion),{segments:e.calculate(t.inverted),inverted:t.inverted}},combine:function(t,e){return{combined:o(!1,h,u).calculate(t.segments,t.inverted,e.segments,e.inverted),inverted1:t.inverted,inverted2:e.inverted}},selectUnion:function(t){return{segments:l.union(t.combined,u),inverted:t.inverted1||t.inverted2}},selectIntersect:function(t){return{segments:l.intersect(t.combined,u),inverted:t.inverted1&&t.inverted2}},selectDifference:function(t){return{segments:l.difference(t.combined,u),inverted:t.inverted1&&!t.inverted2}},selectDifferenceRev:function(t){return{segments:l.differenceRev(t.combined,u),inverted:!t.inverted1&&t.inverted2}},selectXor:function(t){return{segments:l.xor(t.combined,u),inverted:t.inverted1!==t.inverted2}},polygon:function(t){return{regions:s(t.segments,h,u),inverted:t.inverted}},polygonFromGeoJSON:function(t){return c.toPolygon(n,t)},polygonToGeoJSON:function(t){return c.fromPolygon(n,h,t)},union:function(t,e){return f(t,e,n.selectUnion)},intersect:function(t,e){return f(t,e,n.selectIntersect)},difference:function(t,e){return f(t,e,n.selectDifference)},differenceRev:function(t,e){return f(t,e,n.selectDifferenceRev)},xor:function(t,e){return f(t,e,n.selectXor)}},\"object\"==typeof window&&(window.PolyBool=n),e.exports=n},{\"./lib/build-log\":474,\"./lib/epsilon\":475,\"./lib/geojson\":476,\"./lib/intersecter\":477,\"./lib/segment-chainer\":479,\"./lib/segment-selector\":480}],474:[function(t,e,r){e.exports=function(){var t,e=0,r=!1;function n(e,r){return t.list.push({type:e,data:r?JSON.parse(JSON.stringify(r)):void 0}),t}return t={list:[],segmentId:function(){return e++},checkIntersection:function(t,e){return n(\"check\",{seg1:t,seg2:e})},segmentChop:function(t,e){return n(\"div_seg\",{seg:t,pt:e}),n(\"chop\",{seg:t,pt:e})},statusRemove:function(t){return n(\"pop_seg\",{seg:t})},segmentUpdate:function(t){return n(\"seg_update\",{seg:t})},segmentNew:function(t,e){return n(\"new_seg\",{seg:t,primary:e})},segmentRemove:function(t){return n(\"rem_seg\",{seg:t})},tempStatus:function(t,e,r){return n(\"temp_status\",{seg:t,above:e,below:r})},rewind:function(t){return n(\"rewind\",{seg:t})},status:function(t,e,r){return n(\"status\",{seg:t,above:e,below:r})},vert:function(e){return e===r?t:(r=e,n(\"vert\",{x:e}))},log:function(t){return\"string\"!=typeof t&&(t=JSON.stringify(t,!1,\"  \")),n(\"log\",{txt:t})},reset:function(){return n(\"reset\")},selected:function(t){return n(\"selected\",{segs:t})},chainStart:function(t){return n(\"chain_start\",{seg:t})},chainRemoveHead:function(t,e){return n(\"chain_rem_head\",{index:t,pt:e})},chainRemoveTail:function(t,e){return n(\"chain_rem_tail\",{index:t,pt:e})},chainNew:function(t,e){return n(\"chain_new\",{pt1:t,pt2:e})},chainMatch:function(t){return n(\"chain_match\",{index:t})},chainClose:function(t){return n(\"chain_close\",{index:t})},chainAddHead:function(t,e){return n(\"chain_add_head\",{index:t,pt:e})},chainAddTail:function(t,e){return n(\"chain_add_tail\",{index:t,pt:e})},chainConnect:function(t,e){return n(\"chain_con\",{index1:t,index2:e})},chainReverse:function(t){return n(\"chain_rev\",{index:t})},chainJoin:function(t,e){return n(\"chain_join\",{index1:t,index2:e})},done:function(){return n(\"done\")}}}},{}],475:[function(t,e,r){e.exports=function(t){\"number\"!=typeof t&&(t=1e-10);var e={epsilon:function(e){return\"number\"==typeof e&&(t=e),t},pointAboveOrOnLine:function(e,r,n){var i=r[0],a=r[1],o=n[0],s=n[1],l=e[0];return(o-i)*(e[1]-a)-(s-a)*(l-i)>=-t},pointBetween:function(e,r,n){var i=e[1]-r[1],a=n[0]-r[0],o=e[0]-r[0],s=n[1]-r[1],l=o*a+i*s;return!(l<t||l-(a*a+s*s)>-t)},pointsSameX:function(e,r){return Math.abs(e[0]-r[0])<t},pointsSameY:function(e,r){return Math.abs(e[1]-r[1])<t},pointsSame:function(t,r){return e.pointsSameX(t,r)&&e.pointsSameY(t,r)},pointsCompare:function(t,r){return e.pointsSameX(t,r)?e.pointsSameY(t,r)?0:t[1]<r[1]?-1:1:t[0]<r[0]?-1:1},pointsCollinear:function(e,r,n){var i=e[0]-r[0],a=e[1]-r[1],o=r[0]-n[0],s=r[1]-n[1];return Math.abs(i*s-o*a)<t},linesIntersect:function(e,r,n,i){var a=r[0]-e[0],o=r[1]-e[1],s=i[0]-n[0],l=i[1]-n[1],c=a*l-o*s;if(Math.abs(c)<t)return!1;var u=e[0]-n[0],h=e[1]-n[1],f=(s*h-l*u)/c,p=(a*h-o*u)/c,d={alongA:0,alongB:0,pt:[e[0]+f*a,e[1]+f*o]};return d.alongA=f<=-t?-2:f<t?-1:f-1<=-t?0:f-1<t?1:2,d.alongB=p<=-t?-2:p<t?-1:p-1<=-t?0:p-1<t?1:2,d},pointInsideRegion:function(e,r){for(var n=e[0],i=e[1],a=r[r.length-1][0],o=r[r.length-1][1],s=!1,l=0;l<r.length;l++){var c=r[l][0],u=r[l][1];u-i>t!=o-i>t&&(a-c)*(i-u)/(o-u)+c-n>t&&(s=!s),a=c,o=u}return s}};return e}},{}],476:[function(t,e,r){var n={toPolygon:function(t,e){function r(e){if(e.length<=0)return t.segments({inverted:!1,regions:[]});function r(e){var r=e.slice(0,e.length-1);return t.segments({inverted:!1,regions:[r]})}for(var n=r(e[0]),i=1;i<e.length;i++)n=t.selectDifference(t.combine(n,r(e[i])));return n}if(\"Polygon\"===e.type)return t.polygon(r(e.coordinates));if(\"MultiPolygon\"===e.type){for(var n=t.segments({inverted:!1,regions:[]}),i=0;i<e.coordinates.length;i++)n=t.selectUnion(t.combine(n,r(e.coordinates[i])));return t.polygon(n)}throw new Error(\"PolyBool: Cannot convert GeoJSON object to PolyBool polygon\")},fromPolygon:function(t,e,r){function n(t,r){return e.pointInsideRegion([.5*(t[0][0]+t[1][0]),.5*(t[0][1]+t[1][1])],r)}function i(t){return{region:t,children:[]}}r=t.polygon(t.segments(r));var a=i(null);function o(t,e){for(var r=0;r<t.children.length;r++){if(n(e,(s=t.children[r]).region))return void o(s,e)}var a=i(e);for(r=0;r<t.children.length;r++){var s;n((s=t.children[r]).region,e)&&(a.children.push(s),t.children.splice(r,1),r--)}t.children.push(a)}for(var s=0;s<r.regions.length;s++){var l=r.regions[s];l.length<3||o(a,l)}function c(t,e){for(var r=0,n=t[t.length-1][0],i=t[t.length-1][1],a=[],o=0;o<t.length;o++){var s=t[o][0],l=t[o][1];a.push([s,l]),r+=l*n-s*i,n=s,i=l}return r<0!==e&&a.reverse(),a.push([a[0][0],a[0][1]]),a}var u=[];function h(t){var e=[c(t.region,!1)];u.push(e);for(var r=0;r<t.children.length;r++)e.push(f(t.children[r]))}function f(t){for(var e=0;e<t.children.length;e++)h(t.children[e]);return c(t.region,!0)}for(s=0;s<a.children.length;s++)h(a.children[s]);return u.length<=0?{type:\"Polygon\",coordinates:[]}:1==u.length?{type:\"Polygon\",coordinates:u[0]}:{type:\"MultiPolygon\",coordinates:u}}};e.exports=n},{}],477:[function(t,e,r){var n=t(\"./linked-list\");e.exports=function(t,e,r){function i(t,e,n){return{id:r?r.segmentId():-1,start:t,end:e,myFill:{above:n.myFill.above,below:n.myFill.below},otherFill:null}}var a=n.create();function o(t,r){a.insertBefore(t,function(n){return function(t,r,n,i,a,o){var s=e.pointsCompare(r,a);return 0!==s?s:e.pointsSame(n,o)?0:t!==i?t?1:-1:e.pointAboveOrOnLine(n,i?a:o,i?o:a)?1:-1}(t.isStart,t.pt,r,n.isStart,n.pt,n.other.pt)<0})}function s(t,e){var r=function(t,e){var r=n.node({isStart:!0,pt:t.start,seg:t,primary:e,other:null,status:null});return o(r,t.end),r}(t,e);return function(t,e,r){var i=n.node({isStart:!1,pt:e.end,seg:e,primary:r,other:t,status:null});t.other=i,o(i,t.pt)}(r,t,e),r}function l(t,e){var n=i(e,t.seg.end,t.seg);return function(t,e){r&&r.segmentChop(t.seg,e),t.other.remove(),t.seg.end=e,t.other.pt=e,o(t.other,t.pt)}(t,e),s(n,t.primary)}function c(i,o){var s=n.create();function c(t){return s.findTransition(function(r){var n,i,a,o,s,l;return n=t,i=r.ev,a=n.seg.start,o=n.seg.end,s=i.seg.start,l=i.seg.end,(e.pointsCollinear(a,s,l)?e.pointsCollinear(o,s,l)?1:e.pointAboveOrOnLine(o,s,l)?1:-1:e.pointAboveOrOnLine(a,s,l)?1:-1)>0})}function u(t,n){var i=t.seg,a=n.seg,o=i.start,s=i.end,c=a.start,u=a.end;r&&r.checkIntersection(i,a);var h=e.linesIntersect(o,s,c,u);if(!1===h){if(!e.pointsCollinear(o,s,c))return!1;if(e.pointsSame(o,u)||e.pointsSame(s,c))return!1;var f=e.pointsSame(o,c),p=e.pointsSame(s,u);if(f&&p)return n;var d=!f&&e.pointBetween(o,c,u),g=!p&&e.pointBetween(s,c,u);if(f)return g?l(n,s):l(t,u),n;d&&(p||(g?l(n,s):l(t,u)),l(n,o))}else 0===h.alongA&&(-1===h.alongB?l(t,c):0===h.alongB?l(t,h.pt):1===h.alongB&&l(t,u)),0===h.alongB&&(-1===h.alongA?l(n,o):0===h.alongA?l(n,h.pt):1===h.alongA&&l(n,s));return!1}for(var h=[];!a.isEmpty();){var f=a.getHead();if(r&&r.vert(f.pt[0]),f.isStart){r&&r.segmentNew(f.seg,f.primary);var p=c(f),d=p.before?p.before.ev:null,g=p.after?p.after.ev:null;function v(){if(d){var t=u(f,d);if(t)return t}return!!g&&u(f,g)}r&&r.tempStatus(f.seg,!!d&&d.seg,!!g&&g.seg);var m,y,x=v();if(x)t?(y=null===f.seg.myFill.below||f.seg.myFill.above!==f.seg.myFill.below)&&(x.seg.myFill.above=!x.seg.myFill.above):x.seg.otherFill=f.seg.myFill,r&&r.segmentUpdate(x.seg),f.other.remove(),f.remove();if(a.getHead()!==f){r&&r.rewind(f.seg);continue}t?(y=null===f.seg.myFill.below||f.seg.myFill.above!==f.seg.myFill.below,f.seg.myFill.below=g?g.seg.myFill.above:i,f.seg.myFill.above=y?!f.seg.myFill.below:f.seg.myFill.below):null===f.seg.otherFill&&(m=g?f.primary===g.primary?g.seg.otherFill.above:g.seg.myFill.above:f.primary?o:i,f.seg.otherFill={above:m,below:m}),r&&r.status(f.seg,!!d&&d.seg,!!g&&g.seg),f.other.status=p.insert(n.node({ev:f}))}else{var b=f.status;if(null===b)throw new Error(\"PolyBool: Zero-length segment detected; your epsilon is probably too small or too large\");if(s.exists(b.prev)&&s.exists(b.next)&&u(b.prev.ev,b.next.ev),r&&r.statusRemove(b.ev.seg),b.remove(),!f.primary){var _=f.seg.myFill;f.seg.myFill=f.seg.otherFill,f.seg.otherFill=_}h.push(f.seg)}a.getHead().remove()}return r&&r.done(),h}return t?{addRegion:function(t){for(var n,i,a,o=t[t.length-1],l=0;l<t.length;l++){n=o,o=t[l];var c=e.pointsCompare(n,o);0!==c&&s((i=c<0?n:o,a=c<0?o:n,{id:r?r.segmentId():-1,start:i,end:a,myFill:{above:null,below:null},otherFill:null}),!0)}},calculate:function(t){return c(t,!1)}}:{calculate:function(t,e,r,n){return t.forEach(function(t){s(i(t.start,t.end,t),!0)}),r.forEach(function(t){s(i(t.start,t.end,t),!1)}),c(e,n)}}}},{\"./linked-list\":478}],478:[function(t,e,r){e.exports={create:function(){var t={root:{root:!0,next:null},exists:function(e){return null!==e&&e!==t.root},isEmpty:function(){return null===t.root.next},getHead:function(){return t.root.next},insertBefore:function(e,r){for(var n=t.root,i=t.root.next;null!==i;){if(r(i))return e.prev=i.prev,e.next=i,i.prev.next=e,void(i.prev=e);n=i,i=i.next}n.next=e,e.prev=n,e.next=null},findTransition:function(e){for(var r=t.root,n=t.root.next;null!==n&&!e(n);)r=n,n=n.next;return{before:r===t.root?null:r,after:n,insert:function(t){return t.prev=r,t.next=n,r.next=t,null!==n&&(n.prev=t),t}}}};return t},node:function(t){return t.prev=null,t.next=null,t.remove=function(){t.prev.next=t.next,t.next&&(t.next.prev=t.prev),t.prev=null,t.next=null},t}}},{}],479:[function(t,e,r){e.exports=function(t,e,r){var n=[],i=[];return t.forEach(function(t){var a=t.start,o=t.end;if(e.pointsSame(a,o))console.warn(\"PolyBool: Warning: Zero-length segment detected; your epsilon is probably too small or too large\");else{r&&r.chainStart(t);for(var s={index:0,matches_head:!1,matches_pt1:!1},l={index:0,matches_head:!1,matches_pt1:!1},c=s,u=0;u<n.length;u++){var h=(v=n[u])[0],f=(v[1],v[v.length-1]);if(v[v.length-2],e.pointsSame(h,a)){if(T(u,!0,!0))break}else if(e.pointsSame(h,o)){if(T(u,!0,!1))break}else if(e.pointsSame(f,a)){if(T(u,!1,!0))break}else if(e.pointsSame(f,o)&&T(u,!1,!1))break}if(c===s)return n.push([a,o]),void(r&&r.chainNew(a,o));if(c===l){r&&r.chainMatch(s.index);var p=s.index,d=s.matches_pt1?o:a,g=s.matches_head,v=n[p],m=g?v[0]:v[v.length-1],y=g?v[1]:v[v.length-2],x=g?v[v.length-1]:v[0],b=g?v[v.length-2]:v[1];return e.pointsCollinear(y,m,d)&&(g?(r&&r.chainRemoveHead(s.index,d),v.shift()):(r&&r.chainRemoveTail(s.index,d),v.pop()),m=y),e.pointsSame(x,d)?(n.splice(p,1),e.pointsCollinear(b,x,m)&&(g?(r&&r.chainRemoveTail(s.index,m),v.pop()):(r&&r.chainRemoveHead(s.index,m),v.shift())),r&&r.chainClose(s.index),void i.push(v)):void(g?(r&&r.chainAddHead(s.index,d),v.unshift(d)):(r&&r.chainAddTail(s.index,d),v.push(d)))}var _=s.index,w=l.index;r&&r.chainConnect(_,w);var k=n[_].length<n[w].length;s.matches_head?l.matches_head?k?(A(_),M(_,w)):(A(w),M(w,_)):M(w,_):l.matches_head?M(_,w):k?(A(_),M(w,_)):(A(w),M(_,w))}function T(t,e,r){return c.index=t,c.matches_head=e,c.matches_pt1=r,c===s?(c=l,!1):(c=null,!0)}function A(t){r&&r.chainReverse(t),n[t].reverse()}function M(t,i){var a=n[t],o=n[i],s=a[a.length-1],l=a[a.length-2],c=o[0],u=o[1];e.pointsCollinear(l,s,c)&&(r&&r.chainRemoveTail(t,s),a.pop(),s=l),e.pointsCollinear(s,c,u)&&(r&&r.chainRemoveHead(i,c),o.shift()),r&&r.chainJoin(t,i),n[t]=a.concat(o),n.splice(i,1)}}),i}},{}],480:[function(t,e,r){function n(t,e,r){var n=[];return t.forEach(function(t){var i=(t.myFill.above?8:0)+(t.myFill.below?4:0)+(t.otherFill&&t.otherFill.above?2:0)+(t.otherFill&&t.otherFill.below?1:0);0!==e[i]&&n.push({id:r?r.segmentId():-1,start:t.start,end:t.end,myFill:{above:1===e[i],below:2===e[i]},otherFill:null})}),r&&r.selected(n),n}var i={union:function(t,e){return n(t,[0,2,1,0,2,2,0,0,1,0,1,0,0,0,0,0],e)},intersect:function(t,e){return n(t,[0,0,0,0,0,2,0,2,0,0,1,1,0,2,1,0],e)},difference:function(t,e){return n(t,[0,0,0,0,2,0,2,0,1,1,0,0,0,1,2,0],e)},differenceRev:function(t,e){return n(t,[0,2,1,0,0,0,1,1,0,2,0,2,0,0,0,0],e)},xor:function(t,e){return n(t,[0,2,1,0,2,0,0,1,1,0,0,2,0,1,2,0],e)}};e.exports=i},{}],481:[function(t,e,r){\"use strict\";var n=new Float64Array(4),i=new Float64Array(4),a=new Float64Array(4);e.exports=function(t,e,r,o,s){n.length<o.length&&(n=new Float64Array(o.length),i=new Float64Array(o.length),a=new Float64Array(o.length));for(var l=0;l<o.length;++l)n[l]=t[l]-o[l],i[l]=e[l]-t[l],a[l]=r[l]-t[l];var c=0,u=0,h=0,f=0,p=0,d=0;for(l=0;l<o.length;++l){var g=i[l],v=a[l],m=n[l];c+=g*g,u+=g*v,h+=v*v,f+=m*g,p+=m*v,d+=m*m}var y,x,b,_,w,k=Math.abs(c*h-u*u),T=u*p-h*f,A=u*f-c*p;if(T+A<=k)if(T<0)A<0&&f<0?(A=0,-f>=c?(T=1,y=c+2*f+d):y=f*(T=-f/c)+d):(T=0,p>=0?(A=0,y=d):-p>=h?(A=1,y=h+2*p+d):y=p*(A=-p/h)+d);else if(A<0)A=0,f>=0?(T=0,y=d):-f>=c?(T=1,y=c+2*f+d):y=f*(T=-f/c)+d;else{var M=1/k;y=(T*=M)*(c*T+u*(A*=M)+2*f)+A*(u*T+h*A+2*p)+d}else T<0?(b=h+p)>(x=u+f)?(_=b-x)>=(w=c-2*u+h)?(T=1,A=0,y=c+2*f+d):y=(T=_/w)*(c*T+u*(A=1-T)+2*f)+A*(u*T+h*A+2*p)+d:(T=0,b<=0?(A=1,y=h+2*p+d):p>=0?(A=0,y=d):y=p*(A=-p/h)+d):A<0?(b=c+f)>(x=u+p)?(_=b-x)>=(w=c-2*u+h)?(A=1,T=0,y=h+2*p+d):y=(T=1-(A=_/w))*(c*T+u*A+2*f)+A*(u*T+h*A+2*p)+d:(A=0,b<=0?(T=1,y=c+2*f+d):f>=0?(T=0,y=d):y=f*(T=-f/c)+d):(_=h+p-u-f)<=0?(T=0,A=1,y=h+2*p+d):_>=(w=c-2*u+h)?(T=1,A=0,y=c+2*f+d):y=(T=_/w)*(c*T+u*(A=1-T)+2*f)+A*(u*T+h*A+2*p)+d;var S=1-T-A;for(l=0;l<o.length;++l)s[l]=S*t[l]+T*e[l]+A*r[l];return y<0?0:y}},{}],482:[function(t,e,r){var n,i,a=e.exports={};function o(){throw new Error(\"setTimeout has not been defined\")}function s(){throw new Error(\"clearTimeout has not been defined\")}function l(t){if(n===setTimeout)return setTimeout(t,0);if((n===o||!n)&&setTimeout)return n=setTimeout,setTimeout(t,0);try{return n(t,0)}catch(e){try{return n.call(null,t,0)}catch(e){return n.call(this,t,0)}}}!function(){try{n=\"function\"==typeof setTimeout?setTimeout:o}catch(t){n=o}try{i=\"function\"==typeof clearTimeout?clearTimeout:s}catch(t){i=s}}();var c,u=[],h=!1,f=-1;function p(){h&&c&&(h=!1,c.length?u=c.concat(u):f=-1,u.length&&d())}function d(){if(!h){var t=l(p);h=!0;for(var e=u.length;e;){for(c=u,u=[];++f<e;)c&&c[f].run();f=-1,e=u.length}c=null,h=!1,function(t){if(i===clearTimeout)return clearTimeout(t);if((i===s||!i)&&clearTimeout)return i=clearTimeout,clearTimeout(t);try{i(t)}catch(e){try{return i.call(null,t)}catch(e){return i.call(this,t)}}}(t)}}function g(t,e){this.fun=t,this.array=e}function v(){}a.nextTick=function(t){var e=new Array(arguments.length-1);if(arguments.length>1)for(var r=1;r<arguments.length;r++)e[r-1]=arguments[r];u.push(new g(t,e)),1!==u.length||h||l(d)},g.prototype.run=function(){this.fun.apply(null,this.array)},a.title=\"browser\",a.browser=!0,a.env={},a.argv=[],a.version=\"\",a.versions={},a.on=v,a.addListener=v,a.once=v,a.off=v,a.removeListener=v,a.removeAllListeners=v,a.emit=v,a.prependListener=v,a.prependOnceListener=v,a.listeners=function(t){return[]},a.binding=function(t){throw new Error(\"process.binding is not supported\")},a.cwd=function(){return\"/\"},a.chdir=function(t){throw new Error(\"process.chdir is not supported\")},a.umask=function(){return 0}},{}],483:[function(t,e,r){e.exports=t(\"gl-quat/slerp\")},{\"gl-quat/slerp\":293}],484:[function(t,e,r){(function(r){for(var n=t(\"performance-now\"),i=\"undefined\"==typeof window?r:window,a=[\"moz\",\"webkit\"],o=\"AnimationFrame\",s=i[\"request\"+o],l=i[\"cancel\"+o]||i[\"cancelRequest\"+o],c=0;!s&&c<a.length;c++)s=i[a[c]+\"Request\"+o],l=i[a[c]+\"Cancel\"+o]||i[a[c]+\"CancelRequest\"+o];if(!s||!l){var u=0,h=0,f=[];s=function(t){if(0===f.length){var e=n(),r=Math.max(0,1e3/60-(e-u));u=r+e,setTimeout(function(){var t=f.slice(0);f.length=0;for(var e=0;e<t.length;e++)if(!t[e].cancelled)try{t[e].callback(u)}catch(t){setTimeout(function(){throw t},0)}},Math.round(r))}return f.push({handle:++h,callback:t,cancelled:!1}),h},l=function(t){for(var e=0;e<f.length;e++)f[e].handle===t&&(f[e].cancelled=!0)}}e.exports=function(t){return s.call(i,t)},e.exports.cancel=function(){l.apply(i,arguments)},e.exports.polyfill=function(t){t||(t=i),t.requestAnimationFrame=s,t.cancelAnimationFrame=l}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"performance-now\":462}],485:[function(t,e,r){\"use strict\";var n=t(\"big-rat/add\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/add\":75}],486:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t.length),r=0;r<t.length;++r)e[r]=n(t[r]);return e};var n=t(\"big-rat\")},{\"big-rat\":78}],487:[function(t,e,r){\"use strict\";var n=t(\"big-rat\"),i=t(\"big-rat/mul\");e.exports=function(t,e){for(var r=n(e),a=t.length,o=new Array(a),s=0;s<a;++s)o[s]=i(t[s],r);return o}},{\"big-rat\":78,\"big-rat/mul\":87}],488:[function(t,e,r){\"use strict\";var n=t(\"big-rat/sub\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/sub\":89}],489:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"compare-oriented-cell\"),a=t(\"cell-orientation\");e.exports=function(t){t.sort(i);for(var e=t.length,r=0,o=0;o<e;++o){var s=t[o],l=a(s);if(0!==l){if(r>0){var c=t[r-1];if(0===n(s,c)&&a(c)!==l){r-=1;continue}}t[r++]=s}}return t.length=r,t}},{\"cell-orientation\":112,\"compare-cell\":128,\"compare-oriented-cell\":129}],490:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\"),i=t(\"color-normalize\"),a=t(\"update-diff\"),o=t(\"pick-by-alias\"),s=t(\"object-assign\"),l=t(\"flatten-vertex-data\"),c=t(\"to-float32\"),u=c.float32,h=c.fract32;e.exports=function(t,e){\"function\"==typeof t?(e||(e={}),e.regl=t):e=t;e.length&&(e.positions=e);if(!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");var r,c,p,d,g,v,m=t._gl,y={color:\"black\",capSize:5,lineWidth:1,opacity:1,viewport:null,range:null,offset:0,count:0,bounds:null,positions:[],errors:[]},x=[];return d=t.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array(0)}),c=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),p=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),g=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),v=t.buffer({usage:\"static\",type:\"float\",data:f}),k(e),r=t({vert:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tattribute vec2 position, positionFract;\\n\\t\\tattribute vec4 error;\\n\\t\\tattribute vec4 color;\\n\\n\\t\\tattribute vec2 direction, lineOffset, capOffset;\\n\\n\\t\\tuniform vec4 viewport;\\n\\t\\tuniform float lineWidth, capSize;\\n\\t\\tuniform vec2 scale, scaleFract, translate, translateFract;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tfragColor = color / 255.;\\n\\n\\t\\t\\tvec2 pixelOffset = lineWidth * lineOffset + (capSize + lineWidth) * capOffset;\\n\\n\\t\\t\\tvec2 dxy = -step(.5, direction.xy) * error.xz + step(direction.xy, vec2(-.5)) * error.yw;\\n\\n\\t\\t\\tvec2 position = position + dxy;\\n\\n\\t\\t\\tvec2 pos = (position + translate) * scale\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scale\\n\\t\\t\\t\\t+ (position + translate) * scaleFract\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scaleFract;\\n\\n\\t\\t\\tpos += pixelOffset / viewport.zw;\\n\\n\\t\\t\\tgl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\t\\t}\\n\\t\\t\",frag:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tuniform float opacity;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tgl_FragColor = fragColor;\\n\\t\\t\\tgl_FragColor.a *= opacity;\\n\\t\\t}\\n\\t\\t\",uniforms:{range:t.prop(\"range\"),lineWidth:t.prop(\"lineWidth\"),capSize:t.prop(\"capSize\"),opacity:t.prop(\"opacity\"),scale:t.prop(\"scale\"),translate:t.prop(\"translate\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{color:{buffer:d,offset:function(t,e){return 4*e.offset},divisor:1},position:{buffer:c,offset:function(t,e){return 8*e.offset},divisor:1},positionFract:{buffer:p,offset:function(t,e){return 8*e.offset},divisor:1},error:{buffer:g,offset:function(t,e){return 16*e.offset},divisor:1},direction:{buffer:v,stride:24,offset:0},lineOffset:{buffer:v,stride:24,offset:8},capOffset:{buffer:v,stride:24,offset:16}},primitive:\"triangles\",blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:!1,instances:t.prop(\"count\"),count:f.length}),s(b,{update:k,draw:_,destroy:T,regl:t,gl:m,canvas:m.canvas,groups:x}),b;function b(t){t?k(t):null===t&&T(),_()}function _(e){if(\"number\"==typeof e)return w(e);e&&!Array.isArray(e)&&(e=[e]),t._refresh(),x.forEach(function(t,r){t&&(e&&(e[r]?t.draw=!0:t.draw=!1),t.draw?w(r):t.draw=!0)})}function w(t){\"number\"==typeof t&&(t=x[t]),null!=t&&t&&t.count&&t.color&&t.opacity&&t.positions&&t.positions.length>1&&(t.scaleRatio=[t.scale[0]*t.viewport.width,t.scale[1]*t.viewport.height],r(t),t.after&&t.after(t))}function k(t){if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var e=0,r=0;if(b.groups=x=t.map(function(t,c){var u=x[c];return t?(\"function\"==typeof t?t={after:t}:\"number\"==typeof t[0]&&(t={positions:t}),t=o(t,{color:\"color colors fill\",capSize:\"capSize cap capsize cap-size\",lineWidth:\"lineWidth line-width width line thickness\",opacity:\"opacity alpha\",range:\"range dataBox\",viewport:\"viewport viewBox\",errors:\"errors error\",positions:\"positions position data points\"}),u||(x[c]=u={id:c,scale:null,translate:null,scaleFract:null,translateFract:null,draw:!0},t=s({},y,t)),a(u,t,[{lineWidth:function(t){return.5*+t},capSize:function(t){return.5*+t},opacity:parseFloat,errors:function(t){return t=l(t),r+=t.length,t},positions:function(t,r){return t=l(t,\"float64\"),r.count=Math.floor(t.length/2),r.bounds=n(t,2),r.offset=e,e+=r.count,t}},{color:function(t,e){var r=e.count;if(t||(t=\"transparent\"),!Array.isArray(t)||\"number\"==typeof t[0]){var n=t;t=Array(r);for(var a=0;a<r;a++)t[a]=n}if(t.length<r)throw Error(\"Not enough colors\");for(var o=new Uint8Array(4*r),s=0;s<r;s++){var l=i(t[s],\"uint8\");o.set(l,4*s)}return o},range:function(t,e,r){var n=e.bounds;return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=h(e.scale),e.translateFract=h(e.translate),t},viewport:function(t){var e;return Array.isArray(t)?e={x:t[0],y:t[1],width:t[2]-t[0],height:t[3]-t[1]}:t?(e={x:t.x||t.left||0,y:t.y||t.top||0},t.right?e.width=t.right-e.x:e.width=t.w||t.width||0,t.bottom?e.height=t.bottom-e.y:e.height=t.h||t.height||0):e={x:0,y:0,width:m.drawingBufferWidth,height:m.drawingBufferHeight},e}}]),u):u}),e||r){var f=x.reduce(function(t,e,r){return t+(e?e.count:0)},0),v=new Float64Array(2*f),_=new Uint8Array(4*f),w=new Float32Array(4*f);x.forEach(function(t,e){if(t){var r=t.positions,n=t.count,i=t.offset,a=t.color,o=t.errors;n&&(_.set(a,4*i),w.set(o,4*i),v.set(r,2*i))}}),c(u(v)),p(h(v)),d(_),g(w)}}}function T(){c.destroy(),p.destroy(),d.destroy(),g.destroy(),v.destroy()}};var f=[[1,0,0,1,0,0],[1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,1,0,0],[1,0,0,1,0,0],[1,0,-1,0,0,1],[1,0,-1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,1],[1,0,-1,0,0,1],[-1,0,-1,0,0,1],[-1,0,-1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,1],[-1,0,-1,0,0,1],[0,1,1,0,0,0],[0,1,-1,0,0,0],[0,-1,-1,0,0,0],[0,-1,-1,0,0,0],[0,1,1,0,0,0],[0,-1,1,0,0,0],[0,1,0,-1,1,0],[0,1,0,-1,-1,0],[0,1,0,1,-1,0],[0,1,0,1,1,0],[0,1,0,-1,1,0],[0,1,0,1,-1,0],[0,-1,0,-1,1,0],[0,-1,0,-1,-1,0],[0,-1,0,1,-1,0],[0,-1,0,1,1,0],[0,-1,0,-1,1,0],[0,-1,0,1,-1,0]]},{\"array-bounds\":65,\"color-normalize\":120,\"flatten-vertex-data\":227,\"object-assign\":454,\"pick-by-alias\":465,\"to-float32\":538,\"update-diff\":549}],491:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\"),i=t(\"array-bounds\"),a=t(\"object-assign\"),o=t(\"glslify\"),s=t(\"pick-by-alias\"),l=t(\"flatten-vertex-data\"),c=t(\"earcut\"),u=t(\"array-normalize\"),h=t(\"to-float32\"),f=h.float32,p=h.fract32,d=t(\"es6-weak-map\"),g=t(\"parse-rect\");function v(t,e){if(!(this instanceof v))return new v(t,e);if(\"function\"==typeof t?(e||(e={}),e.regl=t):e=t,e.length&&(e.positions=e),!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");this.gl=t._gl,this.regl=t,this.passes=[],this.shaders=v.shaders.has(t)?v.shaders.get(t):v.shaders.set(t,v.createShaders(t)).get(t),this.update(e)}e.exports=v,v.dashMult=2,v.maxPatternLength=256,v.precisionThreshold=3e6,v.maxPoints=1e4,v.maxLines=2048,v.shaders=new d,v.createShaders=function(t){var e,r=t.buffer({usage:\"static\",type:\"float\",data:[0,1,0,0,1,1,1,0]}),n={primitive:\"triangle strip\",instances:t.prop(\"count\"),count:4,offset:0,uniforms:{miterMode:function(t,e){return\"round\"===e.join?2:1},miterLimit:t.prop(\"miterLimit\"),scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),thickness:t.prop(\"thickness\"),dashPattern:t.prop(\"dashTexture\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),dashSize:t.prop(\"dashLength\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]},depth:t.prop(\"depth\")},blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:function(t,e){return!e.overlay}},stencil:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\")},i=t(a({vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, aCoordFract, bCoordFract;\\nattribute vec4 color;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvec2 project(vec2 position, vec2 positionFract, vec2 scale, vec2 scaleFract, vec2 translate, vec2 translateFract) {\\n\\t// the order is important\\n\\treturn position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n}\\n\\nvoid main() {\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineOffset = lineTop * 2. - 1.;\\n\\n\\tvec2 diff = (bCoord + bCoordFract - aCoord - aCoordFract);\\n\\ttangent = normalize(diff * scale * viewport.zw);\\n\\tvec2 normal = vec2(-tangent.y, tangent.x);\\n\\n\\tvec2 position = project(aCoord, aCoordFract, scale, scaleFract, translate, translateFract) * lineStart\\n\\t\\t+ project(bCoord, bCoordFract, scale, scaleFract, translate, translateFract) * lineEnd\\n\\n\\t\\t+ thickness * normal * .5 * lineOffset / viewport.zw;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\n\\nuniform float dashSize, pixelRatio, thickness, opacity, id;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvoid main() {\\n\\tfloat alpha = 1.;\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},aCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8,divisor:1},bCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:16,divisor:1},color:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1}}},n));try{e=t(a({cull:{enable:!0,face:\"back\"},vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, nextCoord, prevCoord;\\nattribute vec4 aColor, bColor;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, translate;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\nuniform float miterLimit, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 tangent;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nconst float REVERSE_THRESHOLD = -.875;\\nconst float MIN_DIFF = 1e-6;\\n\\n// TODO: possible optimizations: avoid overcalculating all for vertices and calc just one instead\\n// TODO: precalculate dot products, normalize things beforehead etc.\\n// TODO: refactor to rectangular algorithm\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nbool isNaN( float val ){\\n  return ( val < 0.0 || 0.0 < val || val == 0.0 ) ? false : true;\\n}\\n\\nvoid main() {\\n\\tvec2 aCoord = aCoord, bCoord = bCoord, prevCoord = prevCoord, nextCoord = nextCoord;\\n\\n  vec2 adjustedScale;\\n  adjustedScale.x = (abs(scale.x) < MIN_DIFF) ? MIN_DIFF : scale.x;\\n  adjustedScale.y = (abs(scale.y) < MIN_DIFF) ? MIN_DIFF : scale.y;\\n\\n  vec2 scaleRatio = adjustedScale * viewport.zw;\\n\\tvec2 normalWidth = thickness / scaleRatio;\\n\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineBot = 1. - lineTop;\\n\\n\\tfragColor = (lineStart * aColor + lineEnd * bColor) / 255.;\\n\\n\\tif (isNaN(aCoord.x) || isNaN(aCoord.y) || isNaN(bCoord.x) || isNaN(bCoord.y)) return;\\n\\n\\tif (aCoord == prevCoord) prevCoord = aCoord + normalize(bCoord - aCoord);\\n\\tif (bCoord == nextCoord) nextCoord = bCoord - normalize(bCoord - aCoord);\\n\\n\\tvec2 prevDiff = aCoord - prevCoord;\\n\\tvec2 currDiff = bCoord - aCoord;\\n\\tvec2 nextDiff = nextCoord - bCoord;\\n\\n\\tvec2 prevTangent = normalize(prevDiff * scaleRatio);\\n\\tvec2 currTangent = normalize(currDiff * scaleRatio);\\n\\tvec2 nextTangent = normalize(nextDiff * scaleRatio);\\n\\n\\tvec2 prevNormal = vec2(-prevTangent.y, prevTangent.x);\\n\\tvec2 currNormal = vec2(-currTangent.y, currTangent.x);\\n\\tvec2 nextNormal = vec2(-nextTangent.y, nextTangent.x);\\n\\n\\tvec2 startJoinDirection = normalize(prevTangent - currTangent);\\n\\tvec2 endJoinDirection = normalize(currTangent - nextTangent);\\n\\n\\t// collapsed/unidirectional segment cases\\n\\t// FIXME: there should be more elegant solution\\n\\tvec2 prevTanDiff = abs(prevTangent - currTangent);\\n\\tvec2 nextTanDiff = abs(nextTangent - currTangent);\\n\\tif (max(prevTanDiff.x, prevTanDiff.y) < MIN_DIFF) {\\n\\t\\tstartJoinDirection = currNormal;\\n\\t}\\n\\tif (max(nextTanDiff.x, nextTanDiff.y) < MIN_DIFF) {\\n\\t\\tendJoinDirection = currNormal;\\n\\t}\\n\\tif (aCoord == bCoord) {\\n\\t\\tendJoinDirection = startJoinDirection;\\n\\t\\tcurrNormal = prevNormal;\\n\\t\\tcurrTangent = prevTangent;\\n\\t}\\n\\n\\ttangent = currTangent;\\n\\n\\t//calculate join shifts relative to normals\\n\\tfloat startJoinShift = dot(currNormal, startJoinDirection);\\n\\tfloat endJoinShift = dot(currNormal, endJoinDirection);\\n\\n\\tfloat startMiterRatio = abs(1. / startJoinShift);\\n\\tfloat endMiterRatio = abs(1. / endJoinShift);\\n\\n\\tvec2 startJoin = startJoinDirection * startMiterRatio;\\n\\tvec2 endJoin = endJoinDirection * endMiterRatio;\\n\\n\\tvec2 startTopJoin, startBotJoin, endTopJoin, endBotJoin;\\n\\tstartTopJoin = sign(startJoinShift) * startJoin * .5;\\n\\tstartBotJoin = -startTopJoin;\\n\\n\\tendTopJoin = sign(endJoinShift) * endJoin * .5;\\n\\tendBotJoin = -endTopJoin;\\n\\n\\tvec2 aTopCoord = aCoord + normalWidth * startTopJoin;\\n\\tvec2 bTopCoord = bCoord + normalWidth * endTopJoin;\\n\\tvec2 aBotCoord = aCoord + normalWidth * startBotJoin;\\n\\tvec2 bBotCoord = bCoord + normalWidth * endBotJoin;\\n\\n\\t//miter anti-clipping\\n\\tfloat baClipping = distToLine(bCoord, aCoord, aBotCoord) / dot(normalize(normalWidth * endBotJoin), normalize(normalWidth.yx * vec2(-startBotJoin.y, startBotJoin.x)));\\n\\tfloat abClipping = distToLine(aCoord, bCoord, bTopCoord) / dot(normalize(normalWidth * startBotJoin), normalize(normalWidth.yx * vec2(-endBotJoin.y, endBotJoin.x)));\\n\\n\\t//prevent close to reverse direction switch\\n\\tbool prevReverse = dot(currTangent, prevTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, prevNormal)) * min(length(prevDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\tbool nextReverse = dot(currTangent, nextTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, nextNormal)) * min(length(nextDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\n\\tif (prevReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * startJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / startMiterRatio, 1.);\\n\\t\\taBotCoord = aCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\taTopCoord = aCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!nextReverse && baClipping > 0. && baClipping < length(normalWidth * endBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\tbTopCoord -= normalWidth * endTopJoin;\\n\\t\\tbTopCoord += normalize(endTopJoin * normalWidth) * baClipping;\\n\\t}\\n\\n\\tif (nextReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * endJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / endMiterRatio, 1.);\\n\\t\\tbBotCoord = bCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\tbTopCoord = bCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!prevReverse && abClipping > 0. && abClipping < length(normalWidth * startBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\taBotCoord -= normalWidth * startBotJoin;\\n\\t\\taBotCoord += normalize(startBotJoin * normalWidth) * abClipping;\\n\\t}\\n\\n\\tvec2 aTopPosition = (aTopCoord) * adjustedScale + translate;\\n\\tvec2 aBotPosition = (aBotCoord) * adjustedScale + translate;\\n\\n\\tvec2 bTopPosition = (bTopCoord) * adjustedScale + translate;\\n\\tvec2 bBotPosition = (bBotCoord) * adjustedScale + translate;\\n\\n\\t//position is normalized 0..1 coord on the screen\\n\\tvec2 position = (aTopPosition * lineTop + aBotPosition * lineBot) * lineStart + (bTopPosition * lineTop + bBotPosition * lineBot) * lineEnd;\\n\\n\\tstartCoord = aCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\tendCoord = bCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\n\\tgl_Position = vec4(position  * 2.0 - 1.0, depth, 1);\\n\\n\\tenableStartMiter = step(dot(currTangent, prevTangent), .5);\\n\\tenableEndMiter = step(dot(currTangent, nextTangent), .5);\\n\\n\\t//bevel miter cutoffs\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n\\n\\t//round miter cutoffs\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * abs(dot(startJoinDirection, currNormal)) * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * abs(dot(endJoinDirection, currNormal)) * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\nuniform float dashSize, pixelRatio, thickness, opacity, id, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nvoid main() {\\n\\tfloat alpha = 1., distToStart, distToEnd;\\n\\tfloat cutoff = thickness * .5;\\n\\n\\t//bevel miter\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToStart + 1., 0.), 1.);\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToEnd + 1., 0.), 1.);\\n\\t\\t}\\n\\t}\\n\\n\\t// round miter\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - startCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - endCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\t}\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1},bColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:4,divisor:1},prevCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:0,divisor:1},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},nextCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:24,divisor:1}}},n))}catch(t){e=i}return{fill:t({primitive:\"triangle\",elements:function(t,e){return e.triangles},offset:0,vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position, positionFract;\\n\\nuniform vec4 color;\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio, id;\\nuniform vec4 viewport;\\nuniform float opacity;\\n\\nvarying vec4 fragColor;\\n\\nconst float MAX_LINES = 256.;\\n\\nvoid main() {\\n\\tfloat depth = (MAX_LINES - 4. - id) / (MAX_LINES);\\n\\n\\tvec2 position = position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n\\tfragColor.a *= opacity;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n\\tgl_FragColor = fragColor;\\n}\\n\"]),uniforms:{scale:t.prop(\"scale\"),color:t.prop(\"fill\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{position:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8},positionFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8}},blend:n.blend,depth:{enable:!1},scissor:n.scissor,stencil:n.stencil,viewport:n.viewport}),rect:i,miter:e}},v.defaults={dashes:null,join:\"miter\",miterLimit:1,thickness:10,cap:\"square\",color:\"black\",opacity:1,overlay:!1,viewport:null,range:null,close:!1,fill:null},v.prototype.render=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];e.length&&(t=this).update.apply(t,e),this.draw()},v.prototype.draw=function(){for(var t=this,e=[],r=arguments.length;r--;)e[r]=arguments[r];return(e.length?e:this.passes).forEach(function(e,r){var n;if(e&&Array.isArray(e))return(n=t).draw.apply(n,e);\"number\"==typeof e&&(e=t.passes[e]),e&&e.count>1&&e.opacity&&(t.regl._refresh(),e.fill&&e.triangles&&e.triangles.length>2&&t.shaders.fill(e),e.thickness&&(e.scale[0]*e.viewport.width>v.precisionThreshold||e.scale[1]*e.viewport.height>v.precisionThreshold?t.shaders.rect(e):\"rect\"===e.join||!e.join&&(e.thickness<=2||e.count>=v.maxPoints)?t.shaders.rect(e):t.shaders.miter(e)))}),this},v.prototype.update=function(t){var e=this;if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var r=this.regl,o=this.gl;if(t.forEach(function(t,h){var d=e.passes[h];if(void 0!==t)if(null!==t){if(\"number\"==typeof t[0]&&(t={positions:t}),t=s(t,{positions:\"positions points data coords\",thickness:\"thickness lineWidth lineWidths line-width linewidth width stroke-width strokewidth strokeWidth\",join:\"lineJoin linejoin join type mode\",miterLimit:\"miterlimit miterLimit\",dashes:\"dash dashes dasharray dash-array dashArray\",color:\"color colour stroke colors colours stroke-color strokeColor\",fill:\"fill fill-color fillColor\",opacity:\"alpha opacity\",overlay:\"overlay crease overlap intersect\",close:\"closed close closed-path closePath\",range:\"range dataBox\",viewport:\"viewport viewBox\",hole:\"holes hole hollow\"}),d||(e.passes[h]=d={id:h,scale:null,scaleFract:null,translate:null,translateFract:null,count:0,hole:[],depth:0,dashLength:1,dashTexture:r.texture({channels:1,data:new Uint8Array([255]),width:1,height:1,mag:\"linear\",min:\"linear\"}),colorBuffer:r.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array}),positionBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),positionFractBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array})},t=a({},v.defaults,t)),null!=t.thickness&&(d.thickness=parseFloat(t.thickness)),null!=t.opacity&&(d.opacity=parseFloat(t.opacity)),null!=t.miterLimit&&(d.miterLimit=parseFloat(t.miterLimit)),null!=t.overlay&&(d.overlay=!!t.overlay,h<v.maxLines&&(d.depth=2*(v.maxLines-1-h%v.maxLines)/v.maxLines-1)),null!=t.join&&(d.join=t.join),null!=t.hole&&(d.hole=t.hole),null!=t.fill&&(d.fill=t.fill?n(t.fill,\"uint8\"):null),null!=t.viewport&&(d.viewport=g(t.viewport)),d.viewport||(d.viewport=g([o.drawingBufferWidth,o.drawingBufferHeight])),null!=t.close&&(d.close=t.close),null===t.positions&&(t.positions=[]),t.positions){var m,y;if(t.positions.x&&t.positions.y){var x=t.positions.x,b=t.positions.y;y=d.count=Math.max(x.length,b.length),m=new Float64Array(2*y);for(var _=0;_<y;_++)m[2*_]=x[_],m[2*_+1]=b[_]}else m=l(t.positions,\"float64\"),y=d.count=Math.floor(m.length/2);var w=d.bounds=i(m,2);if(d.fill){for(var k=[],T={},A=0,M=0,S=0,E=d.count;M<E;M++){var C=m[2*M],L=m[2*M+1];isNaN(C)||isNaN(L)||null==C||null==L?(C=m[2*A],L=m[2*A+1],T[M]=A):A=M,k[S++]=C,k[S++]=L}for(var P=c(k,d.hole||[]),O=0,z=P.length;O<z;O++)null!=T[P[O]]&&(P[O]=T[P[O]]);d.triangles=P}var I=new Float64Array(m);u(I,2,w);var D=new Float64Array(2*y+6);d.close?m[0]===m[2*y-2]&&m[1]===m[2*y-1]?(D[0]=I[2*y-4],D[1]=I[2*y-3]):(D[0]=I[2*y-2],D[1]=I[2*y-1]):(D[0]=I[0],D[1]=I[1]),D.set(I,2),d.close?m[0]===m[2*y-2]&&m[1]===m[2*y-1]?(D[2*y+2]=I[2],D[2*y+3]=I[3],d.count-=1):(D[2*y+2]=I[0],D[2*y+3]=I[1],D[2*y+4]=I[2],D[2*y+5]=I[3]):(D[2*y+2]=I[2*y-2],D[2*y+3]=I[2*y-1],D[2*y+4]=I[2*y-2],D[2*y+5]=I[2*y-1]),d.positionBuffer(f(D)),d.positionFractBuffer(p(D))}if(t.range?d.range=t.range:d.range||(d.range=d.bounds),(t.range||t.positions)&&d.count){var R=d.bounds,F=R[2]-R[0],B=R[3]-R[1],N=d.range[2]-d.range[0],j=d.range[3]-d.range[1];d.scale=[F/N,B/j],d.translate=[-d.range[0]/N+R[0]/N||0,-d.range[1]/j+R[1]/j||0],d.scaleFract=p(d.scale),d.translateFract=p(d.translate)}if(t.dashes){var U,V=0;if(!t.dashes||t.dashes.length<2)V=1,U=new Uint8Array([255,255,255,255,255,255,255,255]);else{V=0;for(var q=0;q<t.dashes.length;++q)V+=t.dashes[q];U=new Uint8Array(V*v.dashMult);for(var H=0,G=255,Y=0;Y<2;Y++)for(var W=0;W<t.dashes.length;++W){for(var X=0,Z=t.dashes[W]*v.dashMult*.5;X<Z;++X)U[H++]=G;G^=255}}d.dashLength=V,d.dashTexture({channels:1,data:U,width:U.length,height:1,mag:\"linear\",min:\"linear\"},0,0)}if(t.color){var J=d.count,K=t.color;K||(K=\"transparent\");var $=new Uint8Array(4*J+4);if(Array.isArray(K)&&\"number\"!=typeof K[0]){for(var Q=0;Q<J;Q++){var tt=n(K[Q],\"uint8\");$.set(tt,4*Q)}$.set(n(K[0],\"uint8\"),4*J)}else for(var et=n(K,\"uint8\"),rt=0;rt<J+1;rt++)$.set(et,4*rt);d.colorBuffer({usage:\"dynamic\",type:\"uint8\",data:$})}}else e.passes[h]=null}),t.length<this.passes.length){for(var h=t.length;h<this.passes.length;h++){var d=e.passes[h];d&&(d.colorBuffer.destroy(),d.positionBuffer.destroy(),d.dashTexture.destroy())}this.passes.length=t.length}for(var m=[],y=0;y<this.passes.length;y++)null!==e.passes[y]&&m.push(e.passes[y]);return this.passes=m,this}},v.prototype.destroy=function(){return this.passes.forEach(function(t){t.colorBuffer.destroy(),t.positionBuffer.destroy(),t.dashTexture.destroy()}),this.passes.length=0,this}},{\"array-bounds\":65,\"array-normalize\":66,\"color-normalize\":120,earcut:492,\"es6-weak-map\":493,\"flatten-vertex-data\":227,glslify:409,\"object-assign\":454,\"parse-rect\":459,\"pick-by-alias\":465,\"to-float32\":538}],492:[function(t,e,r){\"use strict\";function n(t,e,r){r=r||2;var n,s,l,c,u,p,g,v=e&&e.length,m=v?e[0]*r:t.length,y=i(t,0,m,r,!0),x=[];if(!y||y.next===y.prev)return x;if(v&&(y=function(t,e,r,n){var o,s,l,c,u,p=[];for(o=0,s=e.length;o<s;o++)l=e[o]*n,c=o<s-1?e[o+1]*n:t.length,(u=i(t,l,c,n,!1))===u.next&&(u.steiner=!0),p.push(d(u));for(p.sort(h),o=0;o<p.length;o++)f(p[o],r),r=a(r,r.next);return r}(t,e,y,r)),t.length>80*r){n=l=t[0],s=c=t[1];for(var b=r;b<m;b+=r)(u=t[b])<n&&(n=u),(p=t[b+1])<s&&(s=p),u>l&&(l=u),p>c&&(c=p);g=0!==(g=Math.max(l-n,c-s))?1/g:0}return o(y,x,r,n,s,g),x}function i(t,e,r,n,i){var a,o;if(i===A(t,e,r,n)>0)for(a=e;a<r;a+=n)o=w(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=w(a,t[a],t[a+1],o);return o&&y(o,o.next)&&(k(o),o=o.next),o}function a(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!y(n,n.next)&&0!==m(n.prev,n,n.next))n=n.next;else{if(k(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function o(t,e,r,n,i,h,f){if(t){!f&&h&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=p(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,h);for(var d,g,v=t;t.prev!==t.next;)if(d=t.prev,g=t.next,h?l(t,n,i,h):s(t))e.push(d.i/r),e.push(t.i/r),e.push(g.i/r),k(t),t=g.next,v=g.next;else if((t=g)===v){f?1===f?o(t=c(t,e,r),e,r,n,i,h,2):2===f&&u(t,e,r,n,i,h):o(a(t),e,r,n,i,h,1);break}}}function s(t){var e=t.prev,r=t,n=t.next;if(m(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(g(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&m(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function l(t,e,r,n){var i=t.prev,a=t,o=t.next;if(m(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,h=p(s,l,e,r,n),f=p(c,u,e,r,n),d=t.prevZ,v=t.nextZ;d&&d.z>=h&&v&&v.z<=f;){if(d!==t.prev&&d!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&m(d.prev,d,d.next)>=0)return!1;if(d=d.prevZ,v!==t.prev&&v!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,v.x,v.y)&&m(v.prev,v,v.next)>=0)return!1;v=v.nextZ}for(;d&&d.z>=h;){if(d!==t.prev&&d!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&m(d.prev,d,d.next)>=0)return!1;d=d.prevZ}for(;v&&v.z<=f;){if(v!==t.prev&&v!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,v.x,v.y)&&m(v.prev,v,v.next)>=0)return!1;v=v.nextZ}return!0}function c(t,e,r){var n=t;do{var i=n.prev,a=n.next.next;!y(i,a)&&x(i,n,n.next,a)&&b(i,a)&&b(a,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(a.i/r),k(n),k(n.next),n=t=a),n=n.next}while(n!==t);return n}function u(t,e,r,n,i,s){var l=t;do{for(var c=l.next.next;c!==l.prev;){if(l.i!==c.i&&v(l,c)){var u=_(l,c);return l=a(l,l.next),u=a(u,u.next),o(l,e,r,n,i,s),void o(u,e,r,n,i,s)}c=c.next}l=l.next}while(l!==t)}function h(t,e){return t.x-e.x}function f(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r.prev;var l,c=r,u=r.x,h=r.y,f=1/0;n=r.next;for(;n!==c;)i>=n.x&&n.x>=u&&i!==n.x&&g(a<h?i:o,a,u,h,a<h?o:i,a,n.x,n.y)&&((l=Math.abs(a-n.y)/(i-n.x))<f||l===f&&n.x>r.x)&&b(n,t)&&(r=n,f=l),n=n.next;return r}(t,e)){var r=_(e,t);a(r,r.next)}}function p(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function d(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function g(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function v(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&x(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&b(t,e)&&b(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)}function m(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function y(t,e){return t.x===e.x&&t.y===e.y}function x(t,e,r,n){return!!(y(t,e)&&y(r,n)||y(t,n)&&y(r,e))||m(t,e,r)>0!=m(t,e,n)>0&&m(r,n,t)>0!=m(r,n,e)>0}function b(t,e){return m(t.prev,t,t.next)<0?m(t,e,t.next)>=0&&m(t,t.prev,e)>=0:m(t,e,t.prev)<0||m(t,t.next,e)<0}function _(t,e){var r=new T(t.i,t.x,t.y),n=new T(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function w(t,e,r,n){var i=new T(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function k(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function T(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function A(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}e.exports=n,e.exports.default=n,n.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(A(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(A(t,c,u,r))}var h=0;for(s=0;s<n.length;s+=3){var f=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;h+=Math.abs((t[f]-t[d])*(t[p+1]-t[f+1])-(t[f]-t[p])*(t[d+1]-t[f+1]))}return 0===o&&0===h?0:Math.abs((h-o)/o)},n.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r}},{}],493:[function(t,e,r){arguments[4][318][0].apply(r,arguments)},{\"./is-implemented\":494,\"./polyfill\":496,dup:318}],494:[function(t,e,r){arguments[4][319][0].apply(r,arguments)},{dup:319}],495:[function(t,e,r){arguments[4][320][0].apply(r,arguments)},{dup:320}],496:[function(t,e,r){arguments[4][321][0].apply(r,arguments)},{\"./is-native-implemented\":495,d:151,dup:321,\"es5-ext/object/is-value\":194,\"es5-ext/object/set-prototype-of\":200,\"es5-ext/object/valid-object\":204,\"es5-ext/object/valid-value\":205,\"es5-ext/string/random-uniq\":210,\"es6-iterator/for-of\":212,\"es6-iterator/get\":213,\"es6-symbol\":219}],497:[function(t,e,r){\"use strict\";function n(t,e){return function(t){if(Array.isArray(t))return t}(t)||function(t,e){var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{n||null==s.return||s.return()}finally{if(i)throw a}}return r}(t,e)||function(){throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")}()}function i(t){return function(t){if(Array.isArray(t)){for(var e=0,r=new Array(t.length);e<t.length;e++)r[e]=t[e];return r}}(t)||function(t){if(Symbol.iterator in Object(t)||\"[object Arguments]\"===Object.prototype.toString.call(t))return Array.from(t)}(t)||function(){throw new TypeError(\"Invalid attempt to spread non-iterable instance\")}()}var a=t(\"color-normalize\"),o=t(\"array-bounds\"),s=t(\"color-id\"),l=t(\"point-cluster\"),c=t(\"object-assign\"),u=t(\"glslify\"),h=t(\"pick-by-alias\"),f=t(\"update-diff\"),p=t(\"flatten-vertex-data\"),d=t(\"is-iexplorer\"),g=t(\"to-float32\"),v=t(\"parse-rect\"),m=y;function y(t,e){var r=this;if(!(this instanceof y))return new y(t,e);\"function\"==typeof t?(e||(e={}),e.regl=t):(e=t,t=null),e&&e.length&&(e.positions=e);var n,i=(t=e.regl)._gl,a=[];this.tooManyColors=d,n=t.texture({data:new Uint8Array(1020),width:255,height:1,type:\"uint8\",format:\"rgba\",wrapS:\"clamp\",wrapT:\"clamp\",mag:\"nearest\",min:\"nearest\"}),c(this,{regl:t,gl:i,groups:[],markerCache:[null],markerTextures:[null],palette:a,paletteIds:{},paletteTexture:n,maxColors:255,maxSize:100,canvas:i.canvas}),this.update(e);var o={uniforms:{pixelRatio:t.context(\"pixelRatio\"),palette:n,paletteSize:function(t,e){return[r.tooManyColors?0:255,n.height]},scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translate:t.prop(\"translate\"),translateFract:t.prop(\"translateFract\"),opacity:t.prop(\"opacity\"),marker:t.prop(\"markerTexture\")},attributes:{x:function(t,e){return e.xAttr||{buffer:e.positionBuffer,stride:8,offset:0}},y:function(t,e){return e.yAttr||{buffer:e.positionBuffer,stride:8,offset:4}},xFract:function(t,e){return e.xAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:0}},yFract:function(t,e){return e.yAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:4}},size:function(t,e){return e.size.length?{buffer:e.sizeBuffer,stride:2,offset:0}:{constant:[Math.round(255*e.size/r.maxSize)]}},borderSize:function(t,e){return e.borderSize.length?{buffer:e.sizeBuffer,stride:2,offset:1}:{constant:[Math.round(255*e.borderSize/r.maxSize)]}},colorId:function(t,e){return e.color.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:0}:{constant:r.tooManyColors?a.slice(4*e.color,4*e.color+4):[e.color]}},borderColorId:function(t,e){return e.borderColor.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:r.tooManyColors?4:2}:{constant:r.tooManyColors?a.slice(4*e.borderColor,4*e.borderColor+4):[e.borderColor]}},isActive:function(t,e){return!0===e.activation?{constant:[1]}:e.activation?e.activation:{constant:[0]}}},blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:{enable:!1},depth:{enable:!1},elements:t.prop(\"elements\"),count:t.prop(\"count\"),offset:t.prop(\"offset\"),primitive:\"points\"},s=c({},o);s.frag=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nuniform sampler2D marker;\\nuniform float pixelRatio, opacity;\\n\\nfloat smoothStep(float x, float y) {\\n  return 1.0 / (1.0 + exp(50.0*(x - y)));\\n}\\n\\nvoid main() {\\n  float dist = texture2D(marker, gl_PointCoord).r, delta = fragWidth;\\n\\n  // max-distance alpha\\n  if (dist < 0.003) discard;\\n\\n  // null-border case\\n  if (fragBorderColorLevel == fragColorLevel || fragBorderColor.a == 0.) {\\n    float colorAmt = smoothstep(.5 - delta, .5 + delta, dist);\\n    gl_FragColor = vec4(fragColor.rgb, colorAmt * fragColor.a * opacity);\\n  }\\n  else {\\n    float borderColorAmt = smoothstep(fragBorderColorLevel - delta, fragBorderColorLevel + delta, dist);\\n    float colorAmt = smoothstep(fragColorLevel - delta, fragColorLevel + delta, dist);\\n\\n    vec4 color = fragBorderColor;\\n    color.a *= borderColorAmt;\\n    color = mix(color, fragColor, colorAmt);\\n    color.a *= opacity;\\n\\n    gl_FragColor = color;\\n  }\\n\\n}\\n\"]),s.vert=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract, paletteSize;\\nuniform float pixelRatio;\\nuniform sampler2D palette;\\n\\nconst float maxSize = 100.;\\nconst float borderLevel = .5;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragPointSize, fragBorderRadius, fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = 2. * size * pixelRatio;\\n  fragPointSize = size * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\n  fragColor = color;\\n  fragBorderColor = borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n\\n  fragBorderColorLevel = clamp(borderLevel - borderLevel * borderSize / size, 0., 1.);\\n  fragColorLevel = clamp(borderLevel + (1. - borderLevel) * borderSize / size, 0., 1.);\\n}\"]),this.drawMarker=t(s);var l=c({},o);l.frag=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\n\\nuniform float opacity;\\nvarying float fragBorderRadius, fragWidth;\\n\\nfloat smoothStep(float edge0, float edge1, float x) {\\n\\tfloat t;\\n\\tt = clamp((x - edge0) / (edge1 - edge0), 0.0, 1.0);\\n\\treturn t * t * (3.0 - 2.0 * t);\\n}\\n\\nvoid main() {\\n\\tfloat radius, alpha = 1.0, delta = fragWidth;\\n\\n\\tradius = length(2.0 * gl_PointCoord.xy - 1.0);\\n\\n\\tif (radius > 1.0 + delta) {\\n\\t\\tdiscard;\\n\\t}\\n\\n\\talpha -= smoothstep(1.0 - delta, 1.0 + delta, radius);\\n\\n\\tfloat borderRadius = fragBorderRadius;\\n\\tfloat ratio = smoothstep(borderRadius - delta, borderRadius + delta, radius);\\n\\tvec4 color = mix(fragColor, fragBorderColor, ratio);\\n\\tcolor.a *= alpha * opacity;\\n\\tgl_FragColor = color;\\n}\\n\"]),l.vert=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio;\\nuniform sampler2D palette;\\nuniform vec2 paletteSize;\\n\\nconst float maxSize = 100.;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragBorderRadius, fragWidth;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  // ignore inactive points\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = (size + borderSize) * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\n  fragBorderRadius = 1. - 2. * borderSize / (size + borderSize);\\n  fragColor = color;\\n  fragBorderColor = borderColor.a == 0. || borderSize == 0. ? vec4(color.rgb, 0.) : borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n}\\n\"]),d&&(l.frag=l.frag.replace(\"smoothstep\",\"smoothStep\"),s.frag=s.frag.replace(\"smoothstep\",\"smoothStep\")),this.drawCircle=t(l)}y.defaults={color:\"black\",borderColor:\"transparent\",borderSize:0,size:12,opacity:1,marker:void 0,viewport:null,range:null,pixelSize:null,count:0,offset:0,bounds:null,positions:[],snap:1e4},y.prototype.render=function(){return arguments.length&&this.update.apply(this,arguments),this.draw(),this},y.prototype.draw=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var i=this.groups;if(1===r.length&&Array.isArray(r[0])&&(null===r[0][0]||Array.isArray(r[0][0]))&&(r=r[0]),this.regl._refresh(),r.length)for(var a=0;a<r.length;a++)this.drawItem(a,r[a]);else i.forEach(function(e,r){t.drawItem(r)});return this},y.prototype.drawItem=function(t,e){var r=this.groups,n=r[t];if(\"number\"==typeof e&&(t=e,n=r[e],e=null),n&&n.count&&n.opacity){n.activation[0]&&this.drawCircle(this.getMarkerDrawOptions(0,n,e));for(var a=[],o=1;o<n.activation.length;o++)n.activation[o]&&(!0===n.activation[o]||n.activation[o].data.length)&&a.push.apply(a,i(this.getMarkerDrawOptions(o,n,e)));a.length&&this.drawMarker(a)}},y.prototype.getMarkerDrawOptions=function(t,e,r){var i=e.range,a=e.tree,o=e.viewport,s=e.activation,l=e.selectionBuffer,u=e.count;this.regl;if(!a)return r?[c({},e,{markerTexture:this.markerTextures[t],activation:s[t],count:r.length,elements:r,offset:0})]:[c({},e,{markerTexture:this.markerTextures[t],activation:s[t],offset:0})];var h=[],f=a.range(i,{lod:!0,px:[(i[2]-i[0])/o.width,(i[3]-i[1])/o.height]});if(r){for(var p=s[t].data,d=new Uint8Array(u),g=0;g<r.length;g++){var v=r[g];d[v]=p?p[v]:1}l.subdata(d)}for(var m=f.length;m--;){var y=n(f[m],2),x=y[0],b=y[1];h.push(c({},e,{markerTexture:this.markerTextures[t],activation:r?l:s[t],offset:x,count:b-x}))}return h},y.prototype.update=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];if(r.length){1===r.length&&Array.isArray(r[0])&&(r=r[0]);var i=this.groups,a=this.gl,s=this.regl,u=this.maxSize,d=this.maxColors,m=this.palette;this.groups=i=r.map(function(e,r){var n=i[r];if(void 0===e)return n;null===e?e={positions:null}:\"function\"==typeof e?e={ondraw:e}:\"number\"==typeof e[0]&&(e={positions:e}),null===(e=h(e,{positions:\"positions data points\",snap:\"snap cluster lod tree\",size:\"sizes size radius\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",color:\"colors color fill fill-color fillColor\",borderColor:\"borderColors borderColor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range dataBox databox\",viewport:\"viewport viewPort viewBox viewbox\",opacity:\"opacity alpha transparency\",bounds:\"bound bounds boundaries limits\",tooManyColors:\"tooManyColors palette paletteMode optimizePalette enablePalette\"})).positions&&(e.positions=[]),null!=e.tooManyColors&&(t.tooManyColors=e.tooManyColors),n||(i[r]=n={id:r,scale:null,translate:null,scaleFract:null,translateFract:null,activation:[],selectionBuffer:s.buffer({data:new Uint8Array(0),usage:\"stream\",type:\"uint8\"}),sizeBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),colorBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),positionBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"}),positionFractBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"})},e=c({},y.defaults,e)),!e.positions||\"marker\"in e||(e.marker=n.marker,delete n.marker),!e.marker||\"positions\"in e||(e.positions=n.positions,delete n.positions);var x=0,b=0;if(f(n,e,[{snap:!0,size:function(t,e){return null==t&&(t=y.defaults.size),x+=t&&t.length?1:0,t},borderSize:function(t,e){return null==t&&(t=y.defaults.borderSize),x+=t&&t.length?1:0,t},opacity:parseFloat,color:function(e,r){return null==e&&(e=y.defaults.color),e=t.updateColor(e),b++,e},borderColor:function(e,r){return null==e&&(e=y.defaults.borderColor),e=t.updateColor(e),b++,e},bounds:function(t,e,r){return\"range\"in r||(r.range=null),t},positions:function(t,e,r){var n=e.snap,i=e.positionBuffer,a=e.positionFractBuffer,c=e.selectionBuffer;if(t.x||t.y)return t.x.length?e.xAttr={buffer:s.buffer(t.x),offset:0,stride:4,count:t.x.length}:e.xAttr={buffer:t.x.buffer,offset:4*t.x.offset||0,stride:4*(t.x.stride||1),count:t.x.count},t.y.length?e.yAttr={buffer:s.buffer(t.y),offset:0,stride:4,count:t.y.length}:e.yAttr={buffer:t.y.buffer,offset:4*t.y.offset||0,stride:4*(t.y.stride||1),count:t.y.count},e.count=Math.max(e.xAttr.count,e.yAttr.count),t;t=p(t,\"float64\");var u=e.count=Math.floor(t.length/2),h=e.bounds=u?o(t,2):null;if(r.range||e.range||(delete e.range,r.range=h),r.marker||e.marker||(delete e.marker,r.marker=null),n&&(!0===n||u>n)?e.tree=l(t,{bounds:h}):n&&n.length&&(e.tree=n),e.tree){var f={primitive:\"points\",usage:\"static\",data:e.tree,type:\"uint32\"};e.elements?e.elements(f):e.elements=s.elements(f)}return i({data:g.float(t),usage:\"dynamic\"}),a({data:g.fract(t),usage:\"dynamic\"}),c({data:new Uint8Array(u),type:\"uint8\",usage:\"stream\"}),t}},{marker:function(e,r,n){var i=r.activation;if(i.forEach(function(t){return t&&t.destroy&&t.destroy()}),i.length=0,e&&\"number\"!=typeof e[0]){for(var a=[],o=0,l=Math.min(e.length,r.count);o<l;o++){var c=t.addMarker(e[o]);a[c]||(a[c]=new Uint8Array(r.count)),a[c][o]=1}for(var u=0;u<a.length;u++)if(a[u]){var h={data:a[u],type:\"uint8\",usage:\"static\"};i[u]?i[u](h):i[u]=s.buffer(h),i[u].data=a[u]}}else{i[t.addMarker(e)]=!0}return e},range:function(t,e,r){var n=e.bounds;if(n)return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=g.fract(e.scale),e.translateFract=g.fract(e.translate),t},viewport:function(t){return v(t||[a.drawingBufferWidth,a.drawingBufferHeight])}}]),x){var _=n,w=_.count,k=_.size,T=_.borderSize,A=_.sizeBuffer,M=new Uint8Array(2*w);if(k.length||T.length)for(var S=0;S<w;S++)M[2*S]=Math.round(255*(null==k[S]?k:k[S])/u),M[2*S+1]=Math.round(255*(null==T[S]?T:T[S])/u);A({data:M,usage:\"dynamic\"})}if(b){var E,C=n,L=C.count,P=C.color,O=C.borderColor,z=C.colorBuffer;if(t.tooManyColors){if(P.length||O.length){E=new Uint8Array(8*L);for(var I=0;I<L;I++){var D=P[I];E[8*I]=m[4*D],E[8*I+1]=m[4*D+1],E[8*I+2]=m[4*D+2],E[8*I+3]=m[4*D+3];var R=O[I];E[8*I+4]=m[4*R],E[8*I+5]=m[4*R+1],E[8*I+6]=m[4*R+2],E[8*I+7]=m[4*R+3]}}}else if(P.length||O.length){E=new Uint8Array(4*L+2);for(var F=0;F<L;F++)null!=P[F]&&(E[4*F]=P[F]%d,E[4*F+1]=Math.floor(P[F]/d)),null!=O[F]&&(E[4*F+2]=O[F]%d,E[4*F+3]=Math.floor(O[F]/d))}z({data:E||new Uint8Array(0),type:\"uint8\",usage:\"dynamic\"})}return n})}},y.prototype.addMarker=function(t){var e,r=this.markerTextures,n=this.regl,i=this.markerCache,a=null==t?0:i.indexOf(t);if(a>=0)return a;if(t instanceof Uint8Array||t instanceof Uint8ClampedArray)e=t;else{e=new Uint8Array(t.length);for(var o=0,s=t.length;o<s;o++)e[o]=255*t[o]}var l=Math.floor(Math.sqrt(e.length));return a=r.length,i.push(t),r.push(n.texture({channels:1,data:e,radius:l,mag:\"linear\",min:\"linear\"})),a},y.prototype.updateColor=function(t){var e=this.paletteIds,r=this.palette,n=this.maxColors;Array.isArray(t)||(t=[t]);var i=[];if(\"number\"==typeof t[0]){var o=[];if(Array.isArray(t))for(var l=0;l<t.length;l+=4)o.push(t.slice(l,l+4));else for(var c=0;c<t.length;c+=4)o.push(t.subarray(c,c+4));t=o}for(var u=0;u<t.length;u++){var h=t[u];h=a(h,\"uint8\");var f=s(h,!1);if(null==e[f]){var p=r.length;e[f]=Math.floor(p/4),r[p]=h[0],r[p+1]=h[1],r[p+2]=h[2],r[p+3]=h[3]}i[u]=e[f]}return!this.tooManyColors&&r.length>4*n&&(this.tooManyColors=!0),this.updatePalette(r),1===i.length?i[0]:i},y.prototype.updatePalette=function(t){if(!this.tooManyColors){var e=this.maxColors,r=this.paletteTexture,n=Math.ceil(.25*t.length/e);if(n>1)for(var i=.25*(t=t.slice()).length%e;i<n*e;i++)t.push(0,0,0,0);r.height<n&&r.resize(e,n),r.subimage({width:Math.min(.25*t.length,e),height:n,data:t},0,0)}},y.prototype.destroy=function(){return this.groups.forEach(function(t){t.sizeBuffer.destroy(),t.positionBuffer.destroy(),t.positionFractBuffer.destroy(),t.colorBuffer.destroy(),t.activation.forEach(function(t){return t&&t.destroy&&t.destroy()}),t.selectionBuffer.destroy(),t.elements&&t.elements.destroy()}),this.groups.length=0,this.paletteTexture.destroy(),this.markerTextures.forEach(function(t){return t&&t.destroy&&t.destroy()}),this};var x=t(\"object-assign\");e.exports=function(t,e){var r=new m(t,e),n=r.render.bind(r);return x(n,{render:n,update:r.update.bind(r),draw:r.draw.bind(r),destroy:r.destroy.bind(r),regl:r.regl,gl:r.gl,canvas:r.gl.canvas,groups:r.groups,markers:r.markerCache,palette:r.palette}),n}},{\"array-bounds\":65,\"color-id\":118,\"color-normalize\":120,\"flatten-vertex-data\":227,glslify:409,\"is-iexplorer\":419,\"object-assign\":454,\"parse-rect\":459,\"pick-by-alias\":465,\"point-cluster\":499,\"to-float32\":538,\"update-diff\":549}],498:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],499:[function(t,e,r){\"use strict\";e.exports=t(\"./quad\")},{\"./quad\":500}],500:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"clamp\"),a=t(\"parse-rect\"),o=t(\"array-bounds\"),s=t(\"pick-by-alias\"),l=t(\"defined\"),c=t(\"flatten-vertex-data\"),u=t(\"is-obj\"),h=t(\"dtype\"),f=t(\"math-log2\"),p=1073741824;function d(t,e){for(var r=e[0],n=e[1],a=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=i((t[2*l]-r)*a,0,1),s[2*l+1]=i((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,\"float64\"),e=s(e,{bounds:\"range bounds dataBox databox\",maxDepth:\"depth maxDepth maxdepth level maxLevel maxlevel levels\",dtype:\"type dtype format out dst output destination\"});var r=l(e.maxDepth,255),i=l(e.bounds,o(t,2));i[0]===i[2]&&i[2]++,i[1]===i[3]&&i[3]++;var g,v=d(t,i),m=t.length>>>1;e.dtype||(e.dtype=\"array\"),\"string\"==typeof e.dtype?g=new(h(e.dtype))(m):e.dtype&&(g=e.dtype,Array.isArray(g)&&(g.length=m));for(var y=0;y<m;++y)g[y]=y;var x=[],b=[],_=[],w=[];!function t(e,n,i,a,o,s){if(!a.length)return null;var l=x[o]||(x[o]=[]);var c=_[o]||(_[o]=[]);var u=b[o]||(b[o]=[]);var h=l.length;o++;if(o>r||s>p){for(var f=0;f<a.length;f++)l.push(a[f]),c.push(s),u.push(null,null,null,null);return h}l.push(a[0]);c.push(s);if(a.length<=1)return u.push(null,null,null,null),h;var d=.5*i;var g=e+d,m=n+d;var y=[],w=[],k=[],T=[];for(var A=1,M=a.length;A<M;A++){var S=a[A],E=v[2*S],C=v[2*S+1];E<g?C<m?y.push(S):w.push(S):C<m?k.push(S):T.push(S)}s<<=2;u.push(t(e,n,d,y,o,s),t(e,m,d,w,o,s+1),t(g,n,d,k,o,s+2),t(g,m,d,T,o,s+3));return h}(0,0,1,g,0,1);for(var k=0,T=0;T<x.length;T++){var A=x[T];if(g.set)g.set(A,k);else for(var M=0,S=A.length;M<S;M++)g[M+k]=A[M];var E=k+x[T].length;w[T]=[k,E],k=E}return g.range=function(){var e,r=[],o=arguments.length;for(;o--;)r[o]=arguments[o];if(u(r[r.length-1])){var c=r.pop();r.length||null==c.x&&null==c.l&&null==c.left||(r=[c],e={}),e=s(c,{level:\"level maxLevel\",d:\"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize\",lod:\"lod details ranges offsets\"})}else e={};r.length||(r=i);var h=a.apply(void 0,r),p=[Math.min(h.x,h.x+h.width),Math.min(h.y,h.y+h.height),Math.max(h.x,h.x+h.width),Math.max(h.y,h.y+h.height)],g=p[0],v=p[1],m=p[2],y=p[3],k=d([g,v,m,y],i),T=k[0],A=k[1],M=k[2],S=k[3],E=l(e.level,x.length);if(null!=e.d){var L;\"number\"==typeof e.d?L=[e.d,e.d]:e.d.length&&(L=e.d),E=Math.min(Math.max(Math.ceil(-f(Math.abs(L[0])/(i[2]-i[0]))),Math.ceil(-f(Math.abs(L[1])/(i[3]-i[1])))),E)}if(E=Math.min(E,x.length),e.lod)return function(t,e,r,i,a){for(var o=[],s=0;s<a;s++){var l=_[s],c=w[s][0],u=C(t,e,s),h=C(r,i,s),f=n.ge(l,u),p=n.gt(l,h,f,l.length-1);o[s]=[f+c,p+c]}return o}(T,A,M,S,E);var P=[];return function e(r,n,i,a,o,s){if(null!==o&&null!==s){var l=r+i,c=n+i;if(!(T>l||A>c||M<r||S<n||a>=E||o===s)){var u=x[a];void 0===s&&(s=u.length);for(var h=o;h<s;h++){var f=u[h],p=t[2*f],d=t[2*f+1];p>=g&&p<=m&&d>=v&&d<=y&&P.push(f)}var _=b[a],w=_[4*o+0],k=_[4*o+1],C=_[4*o+2],L=_[4*o+3],O=function(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}(_,o+1),z=.5*i,I=a+1;e(r,n,z,I,w,k||C||L||O),e(r,n+z,z,I,k,C||L||O),e(r+z,n,z,I,C,L||O),e(r+z,n+z,z,I,L,O)}}}(0,0,1,0,0,1),P},g;function C(t,e,r){for(var n=1,i=.5,a=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<i?e<a?0:1:e<a?2:3,o*=.5,i+=t<i?-o:o,a+=e<a?-o:o;return n}}},{\"array-bounds\":65,\"binary-search-bounds\":498,clamp:115,defined:164,dtype:169,\"flatten-vertex-data\":227,\"is-obj\":421,\"math-log2\":432,\"parse-rect\":459,\"pick-by-alias\":465}],501:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"pick-by-alias\"),a=t(\"array-bounds\"),o=t(\"raf\"),s=t(\"array-range\"),l=t(\"parse-rect\"),c=t(\"flatten-vertex-data\");function u(t,e){if(!(this instanceof u))return new u(t,e);this.traces=[],this.passes={},this.regl=t,this.scatter=n(t),this.canvas=this.scatter.canvas}function h(t,e,r){return(null!=t.id?t.id:t)<<16|(255&e)<<8|255&r}function f(t,e,r){var n,i,a,o,s=t[e],l=t[r];return s.length>2?(s[0],s[2],n=s[1],i=s[3]):s.length?(n=s[0],i=s[1]):(s.x,n=s.y,s.x+s.width,i=s.y+s.height),l.length>2?(a=l[0],o=l[2],l[1],l[3]):l.length?(a=l[0],o=l[1]):(a=l.x,l.y,o=l.x+l.width,l.y+l.height),[a,n,o,i]}function p(t){if(\"number\"==typeof t)return[t,t,t,t];if(2===t.length)return[t[0],t[1],t[0],t[1]];var e=l(t);return[e.x,e.y,e.x+e.width,e.y+e.height]}e.exports=u,u.prototype.render=function(){for(var t,e=this,r=[],n=arguments.length;n--;)r[n]=arguments[n];return r.length&&(t=this).update.apply(t,r),this.regl.attributes.preserveDrawingBuffer?this.draw():(this.dirty?null==this.planned&&(this.planned=o(function(){e.draw(),e.dirty=!0,e.planned=null})):(this.draw(),this.dirty=!0,o(function(){e.dirty=!1})),this)},u.prototype.update=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=0;n<e.length;n++)this.updateItem(n,e[n]);this.traces=this.traces.filter(Boolean);for(var i=[],a=0,o=0;o<this.traces.length;o++){for(var s=this.traces[o],l=this.traces[o].passes,c=0;c<l.length;c++)i.push(this.passes[l[c]]);s.passOffset=a,a+=s.passes.length}return(t=this.scatter).update.apply(t,i),this}},u.prototype.updateItem=function(t,e){var r=this.regl;if(null===e)return this.traces[t]=null,this;if(!e)return this;var n,o=i(e,{data:\"data items columns rows values dimensions samples x\",snap:\"snap cluster\",size:\"sizes size radius\",color:\"colors color fill fill-color fillColor\",opacity:\"opacity alpha transparency opaque\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",borderColor:\"borderColors borderColor bordercolor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range ranges databox dataBox\",viewport:\"viewport viewBox viewbox\",domain:\"domain domains area areas\",padding:\"pad padding paddings pads margin margins\",transpose:\"transpose transposed\",diagonal:\"diagonal diag showDiagonal\",upper:\"upper up top upperhalf upperHalf showupperhalf showUpper showUpperHalf\",lower:\"lower low bottom lowerhalf lowerHalf showlowerhalf showLowerHalf showLower\"}),s=this.traces[t]||(this.traces[t]={id:t,buffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),color:\"black\",marker:null,size:12,borderColor:\"transparent\",borderSize:1,viewport:l([r._gl.drawingBufferWidth,r._gl.drawingBufferHeight]),padding:[0,0,0,0],opacity:1,diagonal:!0,upper:!0,lower:!0});if(null!=o.color&&(s.color=o.color),null!=o.size&&(s.size=o.size),null!=o.marker&&(s.marker=o.marker),null!=o.borderColor&&(s.borderColor=o.borderColor),null!=o.borderSize&&(s.borderSize=o.borderSize),null!=o.opacity&&(s.opacity=o.opacity),o.viewport&&(s.viewport=l(o.viewport)),null!=o.diagonal&&(s.diagonal=o.diagonal),null!=o.upper&&(s.upper=o.upper),null!=o.lower&&(s.lower=o.lower),o.data){s.buffer(c(o.data)),s.columns=o.data.length,s.count=o.data[0].length,s.bounds=[];for(var u=0;u<s.columns;u++)s.bounds[u]=a(o.data[u],1)}o.range&&(s.range=o.range,n=s.range&&\"number\"!=typeof s.range[0]),o.domain&&(s.domain=o.domain);var d=!1;null!=o.padding&&(Array.isArray(o.padding)&&o.padding.length===s.columns&&\"number\"==typeof o.padding[o.padding.length-1]?(s.padding=o.padding.map(p),d=!0):s.padding=p(o.padding));var g=s.columns,v=s.count,m=s.viewport.width,y=s.viewport.height,x=s.viewport.x,b=s.viewport.y,_=m/g,w=y/g;s.passes=[];for(var k=0;k<g;k++)for(var T=0;T<g;T++)if((s.diagonal||T!==k)&&(s.upper||!(k>T))&&(s.lower||!(k<T))){var A=h(s.id,k,T),M=this.passes[A]||(this.passes[A]={});if(o.data&&(o.transpose?M.positions={x:{buffer:s.buffer,offset:T,count:v,stride:g},y:{buffer:s.buffer,offset:k,count:v,stride:g}}:M.positions={x:{buffer:s.buffer,offset:T*v,count:v},y:{buffer:s.buffer,offset:k*v,count:v}},M.bounds=f(s.bounds,k,T)),o.domain||o.viewport||o.data){var S=d?f(s.padding,k,T):s.padding;if(s.domain){var E=f(s.domain,k,T),C=E[0],L=E[1],P=E[2],O=E[3];M.viewport=[x+C*m+S[0],b+L*y+S[1],x+P*m-S[2],b+O*y-S[3]]}else M.viewport=[x+T*_+_*S[0],b+k*w+w*S[1],x+(T+1)*_-_*S[2],b+(k+1)*w-w*S[3]]}o.color&&(M.color=s.color),o.size&&(M.size=s.size),o.marker&&(M.marker=s.marker),o.borderSize&&(M.borderSize=s.borderSize),o.borderColor&&(M.borderColor=s.borderColor),o.opacity&&(M.opacity=s.opacity),o.range&&(M.range=n?f(s.range,k,T):s.range||M.bounds),s.passes.push(A)}return this},u.prototype.draw=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=[],i=0;i<e.length;i++)if(\"number\"==typeof e[i]){var a=this.traces[e[i]],o=a.passes,l=a.passOffset;n.push.apply(n,s(l,l+o.length))}else if(e[i].length){var c=e[i],u=this.traces[i],h=u.passes,f=u.passOffset;h=h.map(function(t,e){n[f+e]=c})}(t=this.scatter).draw.apply(t,n)}else this.scatter.draw();return this},u.prototype.destroy=function(){return this.traces.forEach(function(t){t.buffer&&t.buffer.destroy&&t.buffer.destroy()}),this.traces=null,this.passes=null,this.scatter.destroy(),this}},{\"array-bounds\":65,\"array-range\":67,\"flatten-vertex-data\":227,\"parse-rect\":459,\"pick-by-alias\":465,raf:484,\"regl-scatter2d\":497}],502:[function(t,e,r){var n,i;n=this,i=function(){function t(t,e){this.id=U++,this.type=t,this.data=e}function e(t){return\"[\"+function t(e){if(0===e.length)return[];var r=e.charAt(0),n=e.charAt(e.length-1);if(1<e.length&&r===n&&('\"'===r||\"'\"===r))return['\"'+e.substr(1,e.length-2).replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];if(r=/\\[(false|true|null|\\d+|'[^']*'|\"[^\"]*\")\\]/.exec(e))return t(e.substr(0,r.index)).concat(t(r[1])).concat(t(e.substr(r.index+r[0].length)));if(1===(r=e.split(\".\")).length)return['\"'+e.replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];for(e=[],n=0;n<r.length;++n)e=e.concat(t(r[n]));return e}(t).join(\"][\")+\"]\"}function r(t){return\"string\"==typeof t?t.split():t}function n(t){return\"string\"==typeof t?document.querySelector(t):t}function i(t){var e,i,a,o,s=t||{};t={};var l=[],c=[],u=\"undefined\"==typeof window?1:window.devicePixelRatio,h=!1,f=function(t){},p=function(){};if(\"string\"==typeof s?e=document.querySelector(s):\"object\"==typeof s&&(\"string\"==typeof s.nodeName&&\"function\"==typeof s.appendChild&&\"function\"==typeof s.getBoundingClientRect?e=s:\"function\"==typeof s.drawArrays||\"function\"==typeof s.drawElements?a=(o=s).canvas:(\"gl\"in s?o=s.gl:\"canvas\"in s?a=n(s.canvas):\"container\"in s&&(i=n(s.container)),\"attributes\"in s&&(t=s.attributes),\"extensions\"in s&&(l=r(s.extensions)),\"optionalExtensions\"in s&&(c=r(s.optionalExtensions)),\"onDone\"in s&&(f=s.onDone),\"profile\"in s&&(h=!!s.profile),\"pixelRatio\"in s&&(u=+s.pixelRatio))),e&&(\"canvas\"===e.nodeName.toLowerCase()?a=e:i=e),!o){if(!a){if(!(e=function(t,e,r){function n(){var e=window.innerWidth,n=window.innerHeight;t!==document.body&&(e=(n=t.getBoundingClientRect()).right-n.left,n=n.bottom-n.top),i.width=r*e,i.height=r*n,j(i.style,{width:e+\"px\",height:n+\"px\"})}var i=document.createElement(\"canvas\");return j(i.style,{border:0,margin:0,padding:0,top:0,left:0}),t.appendChild(i),t===document.body&&(i.style.position=\"absolute\",j(t.style,{margin:0,padding:0})),window.addEventListener(\"resize\",n,!1),n(),{canvas:i,onDestroy:function(){window.removeEventListener(\"resize\",n),t.removeChild(i)}}}(i||document.body,0,u)))return null;a=e.canvas,p=e.onDestroy}o=function(t,e){function r(r){try{return t.getContext(r,e)}catch(t){return null}}return r(\"webgl\")||r(\"experimental-webgl\")||r(\"webgl-experimental\")}(a,t)}return o?{gl:o,canvas:a,container:i,extensions:l,optionalExtensions:c,pixelRatio:u,profile:h,onDone:f,onDestroy:p}:(p(),f(\"webgl not supported, try upgrading your browser or graphics drivers http://get.webgl.org\"),null)}function a(t,e){for(var r=Array(t),n=0;n<t;++n)r[n]=e(n);return r}function o(t){var e,r;return e=(65535<t)<<4,e|=r=(255<(t>>>=e))<<3,(e|=r=(15<(t>>>=r))<<2)|(r=(3<(t>>>=r))<<1)|t>>>r>>1}function s(){function t(t){t:{for(var e=16;268435456>=e;e*=16)if(t<=e){t=e;break t}t=0}return 0<(e=r[o(t)>>2]).length?e.pop():new ArrayBuffer(t)}function e(t){r[o(t.byteLength)>>2].push(t)}var r=a(8,function(){return[]});return{alloc:t,free:e,allocType:function(e,r){var n=null;switch(e){case 5120:n=new Int8Array(t(r),0,r);break;case 5121:n=new Uint8Array(t(r),0,r);break;case 5122:n=new Int16Array(t(2*r),0,r);break;case 5123:n=new Uint16Array(t(2*r),0,r);break;case 5124:n=new Int32Array(t(4*r),0,r);break;case 5125:n=new Uint32Array(t(4*r),0,r);break;case 5126:n=new Float32Array(t(4*r),0,r);break;default:return null}return n.length!==r?n.subarray(0,r):n},freeType:function(t){e(t.buffer)}}}function l(t){return!!t&&\"object\"==typeof t&&Array.isArray(t.shape)&&Array.isArray(t.stride)&&\"number\"==typeof t.offset&&t.shape.length===t.stride.length&&(Array.isArray(t.data)||W(t.data))}function c(t,e,r,n,i,a){for(var o=0;o<e;++o)for(var s=t[o],l=0;l<r;++l)for(var c=s[l],u=0;u<n;++u)i[a++]=c[u]}function u(t){return 0|J[Object.prototype.toString.call(t)]}function h(t,e){for(var r=0;r<e.length;++r)t[r]=e[r]}function f(t,e,r,n,i,a,o){for(var s=0,l=0;l<r;++l)for(var c=0;c<n;++c)t[s++]=e[i*l+a*c+o]}function p(t,e,r,n){function i(e){this.id=c++,this.buffer=t.createBuffer(),this.type=e,this.usage=35044,this.byteLength=0,this.dimension=1,this.dtype=5121,this.persistentData=null,r.profile&&(this.stats={size:0})}function a(e,r,n){e.byteLength=r.byteLength,t.bufferData(e.type,r,n)}function o(t,e,r,n,i,o){if(t.usage=r,Array.isArray(e)){if(t.dtype=n||5126,0<e.length)if(Array.isArray(e[0])){i=tt(e);for(var s=n=1;s<i.length;++s)n*=i[s];t.dimension=n,a(t,e=Q(e,i,t.dtype),r),o?t.persistentData=e:G.freeType(e)}else\"number\"==typeof e[0]?(t.dimension=i,h(i=G.allocType(t.dtype,e.length),e),a(t,i,r),o?t.persistentData=i:G.freeType(i)):W(e[0])&&(t.dimension=e[0].length,t.dtype=n||u(e[0])||5126,a(t,e=Q(e,[e.length,e[0].length],t.dtype),r),o?t.persistentData=e:G.freeType(e))}else if(W(e))t.dtype=n||u(e),t.dimension=i,a(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e.buffer)));else if(l(e)){i=e.shape;var c=e.stride,p=(s=e.offset,0),d=0,g=0,v=0;1===i.length?(p=i[0],d=1,g=c[0],v=0):2===i.length&&(p=i[0],d=i[1],g=c[0],v=c[1]),t.dtype=n||u(e.data)||5126,t.dimension=d,f(i=G.allocType(t.dtype,p*d),e.data,p,d,g,v,s),a(t,i,r),o?t.persistentData=i:G.freeType(i)}}function s(r){e.bufferCount--;for(var i=0;i<n.state.length;++i){var a=n.state[i];a.buffer===r&&(t.disableVertexAttribArray(i),a.buffer=null)}t.deleteBuffer(r.buffer),r.buffer=null,delete p[r.id]}var c=0,p={};i.prototype.bind=function(){t.bindBuffer(this.type,this.buffer)},i.prototype.destroy=function(){s(this)};var d=[];return r.profile&&(e.getTotalBufferSize=function(){var t=0;return Object.keys(p).forEach(function(e){t+=p[e].stats.size}),t}),{create:function(n,a,c,d){function g(e){var n=35044,i=null,a=0,s=0,c=1;return Array.isArray(e)||W(e)||l(e)?i=e:\"number\"==typeof e?a=0|e:e&&(\"data\"in e&&(i=e.data),\"usage\"in e&&(n=$[e.usage]),\"type\"in e&&(s=K[e.type]),\"dimension\"in e&&(c=0|e.dimension),\"length\"in e&&(a=0|e.length)),v.bind(),i?o(v,i,n,s,c,d):(a&&t.bufferData(v.type,a,n),v.dtype=s||5121,v.usage=n,v.dimension=c,v.byteLength=a),r.profile&&(v.stats.size=v.byteLength*et[v.dtype]),g}e.bufferCount++;var v=new i(a);return p[v.id]=v,c||g(n),g._reglType=\"buffer\",g._buffer=v,g.subdata=function(e,r){var n,i=0|(r||0);if(v.bind(),W(e))t.bufferSubData(v.type,i,e);else if(Array.isArray(e)){if(0<e.length)if(\"number\"==typeof e[0]){var a=G.allocType(v.dtype,e.length);h(a,e),t.bufferSubData(v.type,i,a),G.freeType(a)}else(Array.isArray(e[0])||W(e[0]))&&(n=tt(e),a=Q(e,n,v.dtype),t.bufferSubData(v.type,i,a),G.freeType(a))}else if(l(e)){n=e.shape;var o=e.stride,s=a=0,c=0,p=0;1===n.length?(a=n[0],s=1,c=o[0],p=0):2===n.length&&(a=n[0],s=n[1],c=o[0],p=o[1]),n=Array.isArray(e.data)?v.dtype:u(e.data),f(n=G.allocType(n,a*s),e.data,a,s,c,p,e.offset),t.bufferSubData(v.type,i,n),G.freeType(n)}return g},r.profile&&(g.stats=v.stats),g.destroy=function(){s(v)},g},createStream:function(t,e){var r=d.pop();return r||(r=new i(t)),r.bind(),o(r,e,35040,0,1,!1),r},destroyStream:function(t){d.push(t)},clear:function(){X(p).forEach(s),d.forEach(s)},getBuffer:function(t){return t&&t._buffer instanceof i?t._buffer:null},restore:function(){X(p).forEach(function(e){e.buffer=t.createBuffer(),t.bindBuffer(e.type,e.buffer),t.bufferData(e.type,e.persistentData||e.byteLength,e.usage)})},_initBuffer:o}}function d(t,e,r,n){function i(t){this.id=c++,s[this.id]=this,this.buffer=t,this.primType=4,this.type=this.vertCount=0}function a(n,i,a,o,s,c,u){if(n.buffer.bind(),i){var h=u;u||W(i)&&(!l(i)||W(i.data))||(h=e.oes_element_index_uint?5125:5123),r._initBuffer(n.buffer,i,a,h,3)}else t.bufferData(34963,c,a),n.buffer.dtype=h||5121,n.buffer.usage=a,n.buffer.dimension=3,n.buffer.byteLength=c;if(h=u,!u){switch(n.buffer.dtype){case 5121:case 5120:h=5121;break;case 5123:case 5122:h=5123;break;case 5125:case 5124:h=5125}n.buffer.dtype=h}n.type=h,0>(i=s)&&(i=n.buffer.byteLength,5123===h?i>>=1:5125===h&&(i>>=2)),n.vertCount=i,i=o,0>o&&(i=4,1===(o=n.buffer.dimension)&&(i=0),2===o&&(i=1),3===o&&(i=4)),n.primType=i}function o(t){n.elementsCount--,delete s[t.id],t.buffer.destroy(),t.buffer=null}var s={},c=0,u={uint8:5121,uint16:5123};e.oes_element_index_uint&&(u.uint32=5125),i.prototype.bind=function(){this.buffer.bind()};var h=[];return{create:function(t,e){function s(t){if(t)if(\"number\"==typeof t)c(t),h.primType=4,h.vertCount=0|t,h.type=5121;else{var e=null,r=35044,n=-1,i=-1,o=0,f=0;Array.isArray(t)||W(t)||l(t)?e=t:(\"data\"in t&&(e=t.data),\"usage\"in t&&(r=$[t.usage]),\"primitive\"in t&&(n=rt[t.primitive]),\"count\"in t&&(i=0|t.count),\"type\"in t&&(f=u[t.type]),\"length\"in t?o=0|t.length:(o=i,5123===f||5122===f?o*=2:5125!==f&&5124!==f||(o*=4))),a(h,e,r,n,i,o,f)}else c(),h.primType=4,h.vertCount=0,h.type=5121;return s}var c=r.create(null,34963,!0),h=new i(c._buffer);return n.elementsCount++,s(t),s._reglType=\"elements\",s._elements=h,s.subdata=function(t,e){return c.subdata(t,e),s},s.destroy=function(){o(h)},s},createStream:function(t){var e=h.pop();return e||(e=new i(r.create(null,34963,!0,!1)._buffer)),a(e,t,35040,-1,-1,0,0),e},destroyStream:function(t){h.push(t)},getElements:function(t){return\"function\"==typeof t&&t._elements instanceof i?t._elements:null},clear:function(){X(s).forEach(o)}}}function g(t){for(var e=G.allocType(5123,t.length),r=0;r<t.length;++r)if(isNaN(t[r]))e[r]=65535;else if(1/0===t[r])e[r]=31744;else if(-1/0===t[r])e[r]=64512;else{nt[0]=t[r];var n=(a=it[0])>>>31<<15,i=(a<<1>>>24)-127,a=a>>13&1023;e[r]=-24>i?n:-14>i?n+(a+1024>>-14-i):15<i?n+31744:n+(i+15<<10)+a}return e}function v(t){return Array.isArray(t)||W(t)}function m(t){return\"[object \"+t+\"]\"}function y(t){return Array.isArray(t)&&(0===t.length||\"number\"==typeof t[0])}function x(t){return!(!Array.isArray(t)||0===t.length||!v(t[0]))}function b(t){return Object.prototype.toString.call(t)}function _(t){if(!t)return!1;var e=b(t);return 0<=pt.indexOf(e)||(y(t)||x(t)||l(t))}function w(t,e){36193===t.type?(t.data=g(e),G.freeType(e)):t.data=e}function k(t,e,r,n,i,a){if(t=\"undefined\"!=typeof gt[t]?gt[t]:st[t]*dt[e],a&&(t*=6),i){for(n=0;1<=r;)n+=t*r*r,r/=2;return n}return t*r*n}function T(t,e,r,n,i,a,o){function s(){this.format=this.internalformat=6408,this.type=5121,this.flipY=this.premultiplyAlpha=this.compressed=!1,this.unpackAlignment=1,this.colorSpace=37444,this.channels=this.height=this.width=0}function c(t,e){t.internalformat=e.internalformat,t.format=e.format,t.type=e.type,t.compressed=e.compressed,t.premultiplyAlpha=e.premultiplyAlpha,t.flipY=e.flipY,t.unpackAlignment=e.unpackAlignment,t.colorSpace=e.colorSpace,t.width=e.width,t.height=e.height,t.channels=e.channels}function u(t,e){if(\"object\"==typeof e&&e){\"premultiplyAlpha\"in e&&(t.premultiplyAlpha=e.premultiplyAlpha),\"flipY\"in e&&(t.flipY=e.flipY),\"alignment\"in e&&(t.unpackAlignment=e.alignment),\"colorSpace\"in e&&(t.colorSpace=q[e.colorSpace]),\"type\"in e&&(t.type=H[e.type]);var r=t.width,n=t.height,i=t.channels,a=!1;\"shape\"in e?(r=e.shape[0],n=e.shape[1],3===e.shape.length&&(i=e.shape[2],a=!0)):(\"radius\"in e&&(r=n=e.radius),\"width\"in e&&(r=e.width),\"height\"in e&&(n=e.height),\"channels\"in e&&(i=e.channels,a=!0)),t.width=0|r,t.height=0|n,t.channels=0|i,r=!1,\"format\"in e&&(r=e.format,n=t.internalformat=Y[r],t.format=pt[n],r in H&&!(\"type\"in e)&&(t.type=H[r]),r in K&&(t.compressed=!0),r=!0),!a&&r?t.channels=st[t.format]:a&&!r&&t.channels!==ot[t.format]&&(t.format=t.internalformat=ot[t.channels])}}function h(e){t.pixelStorei(37440,e.flipY),t.pixelStorei(37441,e.premultiplyAlpha),t.pixelStorei(37443,e.colorSpace),t.pixelStorei(3317,e.unpackAlignment)}function f(){s.call(this),this.yOffset=this.xOffset=0,this.data=null,this.needsFree=!1,this.element=null,this.needsCopy=!1}function p(t,e){var r=null;if(_(e)?r=e:e&&(u(t,e),\"x\"in e&&(t.xOffset=0|e.x),\"y\"in e&&(t.yOffset=0|e.y),_(e.data)&&(r=e.data)),e.copy){var n=i.viewportWidth,a=i.viewportHeight;t.width=t.width||n-t.xOffset,t.height=t.height||a-t.yOffset,t.needsCopy=!0}else if(r){if(W(r))t.channels=t.channels||4,t.data=r,\"type\"in e||5121!==t.type||(t.type=0|J[Object.prototype.toString.call(r)]);else if(y(r)){switch(t.channels=t.channels||4,a=(n=r).length,t.type){case 5121:case 5123:case 5125:case 5126:(a=G.allocType(t.type,a)).set(n),t.data=a;break;case 36193:t.data=g(n)}t.alignment=1,t.needsFree=!0}else if(l(r)){n=r.data,Array.isArray(n)||5121!==t.type||(t.type=0|J[Object.prototype.toString.call(n)]);a=r.shape;var o,s,c,h,f=r.stride;3===a.length?(c=a[2],h=f[2]):h=c=1,o=a[0],s=a[1],a=f[0],f=f[1],t.alignment=1,t.width=o,t.height=s,t.channels=c,t.format=t.internalformat=ot[c],t.needsFree=!0,o=h,r=r.offset,c=t.width,h=t.height,s=t.channels;for(var p=G.allocType(36193===t.type?5126:t.type,c*h*s),d=0,m=0;m<h;++m)for(var k=0;k<c;++k)for(var T=0;T<s;++T)p[d++]=n[a*k+f*m+o*T+r];w(t,p)}else if(b(r)===lt||b(r)===ct)b(r)===lt?t.element=r:t.element=r.canvas,t.width=t.element.width,t.height=t.element.height,t.channels=4;else if(b(r)===ut)t.element=r,t.width=r.width,t.height=r.height,t.channels=4;else if(b(r)===ht)t.element=r,t.width=r.naturalWidth,t.height=r.naturalHeight,t.channels=4;else if(b(r)===ft)t.element=r,t.width=r.videoWidth,t.height=r.videoHeight,t.channels=4;else if(x(r)){for(n=t.width||r[0].length,a=t.height||r.length,f=t.channels,f=v(r[0][0])?f||r[0][0].length:f||1,o=Z.shape(r),c=1,h=0;h<o.length;++h)c*=o[h];c=G.allocType(36193===t.type?5126:t.type,c),Z.flatten(r,o,\"\",c),w(t,c),t.alignment=1,t.width=n,t.height=a,t.channels=f,t.format=t.internalformat=ot[f],t.needsFree=!0}}else t.width=t.width||1,t.height=t.height||1,t.channels=t.channels||4}function d(e,r,i,a,o){var s=e.element,l=e.data,c=e.internalformat,u=e.format,f=e.type,p=e.width,d=e.height;h(e),s?t.texSubImage2D(r,o,i,a,u,f,s):e.compressed?t.compressedTexSubImage2D(r,o,i,a,c,p,d,l):e.needsCopy?(n(),t.copyTexSubImage2D(r,o,i,a,e.xOffset,e.yOffset,p,d)):t.texSubImage2D(r,o,i,a,p,d,u,f,l)}function m(){return dt.pop()||new f}function T(t){t.needsFree&&G.freeType(t.data),f.call(t),dt.push(t)}function A(){s.call(this),this.genMipmaps=!1,this.mipmapHint=4352,this.mipmask=0,this.images=Array(16)}function M(t,e,r){var n=t.images[0]=m();t.mipmask=1,n.width=t.width=e,n.height=t.height=r,n.channels=t.channels=4}function S(t,e){var r=null;if(_(e))c(r=t.images[0]=m(),t),p(r,e),t.mipmask=1;else if(u(t,e),Array.isArray(e.mipmap))for(var n=e.mipmap,i=0;i<n.length;++i)c(r=t.images[i]=m(),t),r.width>>=i,r.height>>=i,p(r,n[i]),t.mipmask|=1<<i;else c(r=t.images[0]=m(),t),p(r,e),t.mipmask=1;c(t,t.images[0])}function E(e,r){for(var i=e.images,a=0;a<i.length&&i[a];++a){var o=i[a],s=r,l=a,c=o.element,u=o.data,f=o.internalformat,p=o.format,d=o.type,g=o.width,v=o.height,m=o.channels;h(o),c?t.texImage2D(s,l,p,p,d,c):o.compressed?t.compressedTexImage2D(s,l,f,g,v,0,u):o.needsCopy?(n(),t.copyTexImage2D(s,l,p,o.xOffset,o.yOffset,g,v,0)):((o=!u)&&(u=G.zero.allocType(d,g*v*m)),t.texImage2D(s,l,p,g,v,0,p,d,u),o&&u&&G.zero.freeType(u))}}function C(){var t=gt.pop()||new A;s.call(t);for(var e=t.mipmask=0;16>e;++e)t.images[e]=null;return t}function L(t){for(var e=t.images,r=0;r<e.length;++r)e[r]&&T(e[r]),e[r]=null;gt.push(t)}function P(){this.magFilter=this.minFilter=9728,this.wrapT=this.wrapS=33071,this.anisotropic=1,this.genMipmaps=!1,this.mipmapHint=4352}function O(t,e){\"min\"in e&&(t.minFilter=V[e.min],0<=at.indexOf(t.minFilter)&&!(\"faces\"in e)&&(t.genMipmaps=!0)),\"mag\"in e&&(t.magFilter=U[e.mag]);var r=t.wrapS,n=t.wrapT;if(\"wrap\"in e){var i=e.wrap;\"string\"==typeof i?r=n=N[i]:Array.isArray(i)&&(r=N[i[0]],n=N[i[1]])}else\"wrapS\"in e&&(r=N[e.wrapS]),\"wrapT\"in e&&(n=N[e.wrapT]);if(t.wrapS=r,t.wrapT=n,\"anisotropic\"in e&&(t.anisotropic=e.anisotropic),\"mipmap\"in e){switch(r=!1,typeof e.mipmap){case\"string\":t.mipmapHint=B[e.mipmap],r=t.genMipmaps=!0;break;case\"boolean\":r=t.genMipmaps=e.mipmap;break;case\"object\":t.genMipmaps=!1,r=!0}!r||\"min\"in e||(t.minFilter=9984)}}function z(r,n){t.texParameteri(n,10241,r.minFilter),t.texParameteri(n,10240,r.magFilter),t.texParameteri(n,10242,r.wrapS),t.texParameteri(n,10243,r.wrapT),e.ext_texture_filter_anisotropic&&t.texParameteri(n,34046,r.anisotropic),r.genMipmaps&&(t.hint(33170,r.mipmapHint),t.generateMipmap(n))}function I(e){s.call(this),this.mipmask=0,this.internalformat=6408,this.id=vt++,this.refCount=1,this.target=e,this.texture=t.createTexture(),this.unit=-1,this.bindCount=0,this.texInfo=new P,o.profile&&(this.stats={size:0})}function D(e){t.activeTexture(33984),t.bindTexture(e.target,e.texture)}function R(){var e=xt[0];e?t.bindTexture(e.target,e.texture):t.bindTexture(3553,null)}function F(e){var r=e.texture,n=e.unit,i=e.target;0<=n&&(t.activeTexture(33984+n),t.bindTexture(i,null),xt[n]=null),t.deleteTexture(r),e.texture=null,e.params=null,e.pixels=null,e.refCount=0,delete mt[e.id],a.textureCount--}var B={\"don't care\":4352,\"dont care\":4352,nice:4354,fast:4353},N={repeat:10497,clamp:33071,mirror:33648},U={nearest:9728,linear:9729},V=j({mipmap:9987,\"nearest mipmap nearest\":9984,\"linear mipmap nearest\":9985,\"nearest mipmap linear\":9986,\"linear mipmap linear\":9987},U),q={none:0,browser:37444},H={uint8:5121,rgba4:32819,rgb565:33635,\"rgb5 a1\":32820},Y={alpha:6406,luminance:6409,\"luminance alpha\":6410,rgb:6407,rgba:6408,rgba4:32854,\"rgb5 a1\":32855,rgb565:36194},K={};e.ext_srgb&&(Y.srgb=35904,Y.srgba=35906),e.oes_texture_float&&(H.float32=H.float=5126),e.oes_texture_half_float&&(H.float16=H[\"half float\"]=36193),e.webgl_depth_texture&&(j(Y,{depth:6402,\"depth stencil\":34041}),j(H,{uint16:5123,uint32:5125,\"depth stencil\":34042})),e.webgl_compressed_texture_s3tc&&j(K,{\"rgb s3tc dxt1\":33776,\"rgba s3tc dxt1\":33777,\"rgba s3tc dxt3\":33778,\"rgba s3tc dxt5\":33779}),e.webgl_compressed_texture_atc&&j(K,{\"rgb atc\":35986,\"rgba atc explicit alpha\":35987,\"rgba atc interpolated alpha\":34798}),e.webgl_compressed_texture_pvrtc&&j(K,{\"rgb pvrtc 4bppv1\":35840,\"rgb pvrtc 2bppv1\":35841,\"rgba pvrtc 4bppv1\":35842,\"rgba pvrtc 2bppv1\":35843}),e.webgl_compressed_texture_etc1&&(K[\"rgb etc1\"]=36196);var $=Array.prototype.slice.call(t.getParameter(34467));Object.keys(K).forEach(function(t){var e=K[t];0<=$.indexOf(e)&&(Y[t]=e)});var Q=Object.keys(Y);r.textureFormats=Q;var tt=[];Object.keys(Y).forEach(function(t){tt[Y[t]]=t});var et=[];Object.keys(H).forEach(function(t){et[H[t]]=t});var rt=[];Object.keys(U).forEach(function(t){rt[U[t]]=t});var nt=[];Object.keys(V).forEach(function(t){nt[V[t]]=t});var it=[];Object.keys(N).forEach(function(t){it[N[t]]=t});var pt=Q.reduce(function(t,e){var r=Y[e];return 6409===r||6406===r||6409===r||6410===r||6402===r||34041===r?t[r]=r:32855===r||0<=e.indexOf(\"rgba\")?t[r]=6408:t[r]=6407,t},{}),dt=[],gt=[],vt=0,mt={},yt=r.maxTextureUnits,xt=Array(yt).map(function(){return null});return j(I.prototype,{bind:function(){this.bindCount+=1;var e=this.unit;if(0>e){for(var r=0;r<yt;++r){var n=xt[r];if(n){if(0<n.bindCount)continue;n.unit=-1}xt[r]=this,e=r;break}o.profile&&a.maxTextureUnits<e+1&&(a.maxTextureUnits=e+1),this.unit=e,t.activeTexture(33984+e),t.bindTexture(this.target,this.texture)}return e},unbind:function(){--this.bindCount},decRef:function(){0>=--this.refCount&&F(this)}}),o.profile&&(a.getTotalTextureSize=function(){var t=0;return Object.keys(mt).forEach(function(e){t+=mt[e].stats.size}),t}),{create2D:function(e,r){function n(t,e){var r=i.texInfo;P.call(r);var a=C();return\"number\"==typeof t?M(a,0|t,\"number\"==typeof e?0|e:0|t):t?(O(r,t),S(a,t)):M(a,1,1),r.genMipmaps&&(a.mipmask=(a.width<<1)-1),i.mipmask=a.mipmask,c(i,a),i.internalformat=a.internalformat,n.width=a.width,n.height=a.height,D(i),E(a,3553),z(r,3553),R(),L(a),o.profile&&(i.stats.size=k(i.internalformat,i.type,a.width,a.height,r.genMipmaps,!1)),n.format=tt[i.internalformat],n.type=et[i.type],n.mag=rt[r.magFilter],n.min=nt[r.minFilter],n.wrapS=it[r.wrapS],n.wrapT=it[r.wrapT],n}var i=new I(3553);return mt[i.id]=i,a.textureCount++,n(e,r),n.subimage=function(t,e,r,a){e|=0,r|=0,a|=0;var o=m();return c(o,i),o.width=0,o.height=0,p(o,t),o.width=o.width||(i.width>>a)-e,o.height=o.height||(i.height>>a)-r,D(i),d(o,3553,e,r,a),R(),T(o),n},n.resize=function(e,r){var a=0|e,s=0|r||a;if(a===i.width&&s===i.height)return n;n.width=i.width=a,n.height=i.height=s,D(i);for(var l,c=i.channels,u=i.type,h=0;i.mipmask>>h;++h){var f=a>>h,p=s>>h;if(!f||!p)break;l=G.zero.allocType(u,f*p*c),t.texImage2D(3553,h,i.format,f,p,0,i.format,i.type,l),l&&G.zero.freeType(l)}return R(),o.profile&&(i.stats.size=k(i.internalformat,i.type,a,s,!1,!1)),n},n._reglType=\"texture2d\",n._texture=i,o.profile&&(n.stats=i.stats),n.destroy=function(){i.decRef()},n},createCube:function(e,r,n,i,s,l){function h(t,e,r,n,i,a){var s,l=f.texInfo;for(P.call(l),s=0;6>s;++s)g[s]=C();if(\"number\"!=typeof t&&t){if(\"object\"==typeof t)if(e)S(g[0],t),S(g[1],e),S(g[2],r),S(g[3],n),S(g[4],i),S(g[5],a);else if(O(l,t),u(f,t),\"faces\"in t)for(t=t.faces,s=0;6>s;++s)c(g[s],f),S(g[s],t[s]);else for(s=0;6>s;++s)S(g[s],t)}else for(t=0|t||1,s=0;6>s;++s)M(g[s],t,t);for(c(f,g[0]),f.mipmask=l.genMipmaps?(g[0].width<<1)-1:g[0].mipmask,f.internalformat=g[0].internalformat,h.width=g[0].width,h.height=g[0].height,D(f),s=0;6>s;++s)E(g[s],34069+s);for(z(l,34067),R(),o.profile&&(f.stats.size=k(f.internalformat,f.type,h.width,h.height,l.genMipmaps,!0)),h.format=tt[f.internalformat],h.type=et[f.type],h.mag=rt[l.magFilter],h.min=nt[l.minFilter],h.wrapS=it[l.wrapS],h.wrapT=it[l.wrapT],s=0;6>s;++s)L(g[s]);return h}var f=new I(34067);mt[f.id]=f,a.cubeCount++;var g=Array(6);return h(e,r,n,i,s,l),h.subimage=function(t,e,r,n,i){r|=0,n|=0,i|=0;var a=m();return c(a,f),a.width=0,a.height=0,p(a,e),a.width=a.width||(f.width>>i)-r,a.height=a.height||(f.height>>i)-n,D(f),d(a,34069+t,r,n,i),R(),T(a),h},h.resize=function(e){if((e|=0)!==f.width){h.width=f.width=e,h.height=f.height=e,D(f);for(var r=0;6>r;++r)for(var n=0;f.mipmask>>n;++n)t.texImage2D(34069+r,n,f.format,e>>n,e>>n,0,f.format,f.type,null);return R(),o.profile&&(f.stats.size=k(f.internalformat,f.type,h.width,h.height,!1,!0)),h}},h._reglType=\"textureCube\",h._texture=f,o.profile&&(h.stats=f.stats),h.destroy=function(){f.decRef()},h},clear:function(){for(var e=0;e<yt;++e)t.activeTexture(33984+e),t.bindTexture(3553,null),xt[e]=null;X(mt).forEach(F),a.cubeCount=0,a.textureCount=0},getTexture:function(t){return null},restore:function(){for(var e=0;e<yt;++e){var r=xt[e];r&&(r.bindCount=0,r.unit=-1,xt[e]=null)}X(mt).forEach(function(e){e.texture=t.createTexture(),t.bindTexture(e.target,e.texture);for(var r=0;32>r;++r)if(0!=(e.mipmask&1<<r))if(3553===e.target)t.texImage2D(3553,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);else for(var n=0;6>n;++n)t.texImage2D(34069+n,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);z(e.texInfo,e.target)})}}}function A(t,e,r,n,i,a){function o(t,e,r){this.target=t,this.texture=e,this.renderbuffer=r;var n=t=0;e?(t=e.width,n=e.height):r&&(t=r.width,n=r.height),this.width=t,this.height=n}function s(t){t&&(t.texture&&t.texture._texture.decRef(),t.renderbuffer&&t.renderbuffer._renderbuffer.decRef())}function l(t,e,r){t&&(t.texture?t.texture._texture.refCount+=1:t.renderbuffer._renderbuffer.refCount+=1)}function c(e,r){r&&(r.texture?t.framebufferTexture2D(36160,e,r.target,r.texture._texture.texture,0):t.framebufferRenderbuffer(36160,e,36161,r.renderbuffer._renderbuffer.renderbuffer))}function u(t){var e=3553,r=null,n=null,i=t;return\"object\"==typeof t&&(i=t.data,\"target\"in t&&(e=0|t.target)),\"texture2d\"===(t=i._reglType)?r=i:\"textureCube\"===t?r=i:\"renderbuffer\"===t&&(n=i,e=36161),new o(e,r,n)}function h(t,e,r,a,s){return r?((t=n.create2D({width:t,height:e,format:a,type:s}))._texture.refCount=0,new o(3553,t,null)):((t=i.create({width:t,height:e,format:a}))._renderbuffer.refCount=0,new o(36161,null,t))}function f(t){return t&&(t.texture||t.renderbuffer)}function p(t,e,r){t&&(t.texture?t.texture.resize(e,r):t.renderbuffer&&t.renderbuffer.resize(e,r),t.width=e,t.height=r)}function d(){this.id=k++,T[this.id]=this,this.framebuffer=t.createFramebuffer(),this.height=this.width=0,this.colorAttachments=[],this.depthStencilAttachment=this.stencilAttachment=this.depthAttachment=null}function g(t){t.colorAttachments.forEach(s),s(t.depthAttachment),s(t.stencilAttachment),s(t.depthStencilAttachment)}function v(e){t.deleteFramebuffer(e.framebuffer),e.framebuffer=null,a.framebufferCount--,delete T[e.id]}function m(e){var n;t.bindFramebuffer(36160,e.framebuffer);var i=e.colorAttachments;for(n=0;n<i.length;++n)c(36064+n,i[n]);for(n=i.length;n<r.maxColorAttachments;++n)t.framebufferTexture2D(36160,36064+n,3553,null,0);t.framebufferTexture2D(36160,33306,3553,null,0),t.framebufferTexture2D(36160,36096,3553,null,0),t.framebufferTexture2D(36160,36128,3553,null,0),c(36096,e.depthAttachment),c(36128,e.stencilAttachment),c(33306,e.depthStencilAttachment),t.checkFramebufferStatus(36160),t.isContextLost(),t.bindFramebuffer(36160,x.next?x.next.framebuffer:null),x.cur=x.next,t.getError()}function y(t,e){function r(t,e){var i,a=0,o=0,s=!0,c=!0;i=null;var p=!0,d=\"rgba\",v=\"uint8\",y=1,x=null,w=null,k=null,T=!1;\"number\"==typeof t?(a=0|t,o=0|e||a):t?(\"shape\"in t?(a=(o=t.shape)[0],o=o[1]):(\"radius\"in t&&(a=o=t.radius),\"width\"in t&&(a=t.width),\"height\"in t&&(o=t.height)),(\"color\"in t||\"colors\"in t)&&(i=t.color||t.colors,Array.isArray(i)),i||(\"colorCount\"in t&&(y=0|t.colorCount),\"colorTexture\"in t&&(p=!!t.colorTexture,d=\"rgba4\"),\"colorType\"in t&&(v=t.colorType,!p)&&(\"half float\"===v||\"float16\"===v?d=\"rgba16f\":\"float\"!==v&&\"float32\"!==v||(d=\"rgba32f\")),\"colorFormat\"in t&&(d=t.colorFormat,0<=b.indexOf(d)?p=!0:0<=_.indexOf(d)&&(p=!1))),(\"depthTexture\"in t||\"depthStencilTexture\"in t)&&(T=!(!t.depthTexture&&!t.depthStencilTexture)),\"depth\"in t&&(\"boolean\"==typeof t.depth?s=t.depth:(x=t.depth,c=!1)),\"stencil\"in t&&(\"boolean\"==typeof t.stencil?c=t.stencil:(w=t.stencil,s=!1)),\"depthStencil\"in t&&(\"boolean\"==typeof t.depthStencil?s=c=t.depthStencil:(k=t.depthStencil,c=s=!1))):a=o=1;var A=null,M=null,S=null,E=null;if(Array.isArray(i))A=i.map(u);else if(i)A=[u(i)];else for(A=Array(y),i=0;i<y;++i)A[i]=h(a,o,p,d,v);for(a=a||A[0].width,o=o||A[0].height,x?M=u(x):s&&!c&&(M=h(a,o,T,\"depth\",\"uint32\")),w?S=u(w):c&&!s&&(S=h(a,o,!1,\"stencil\",\"uint8\")),k?E=u(k):!x&&!w&&c&&s&&(E=h(a,o,T,\"depth stencil\",\"depth stencil\")),s=null,i=0;i<A.length;++i)l(A[i]),A[i]&&A[i].texture&&(c=yt[A[i].texture._texture.format]*xt[A[i].texture._texture.type],null===s&&(s=c));return l(M),l(S),l(E),g(n),n.width=a,n.height=o,n.colorAttachments=A,n.depthAttachment=M,n.stencilAttachment=S,n.depthStencilAttachment=E,r.color=A.map(f),r.depth=f(M),r.stencil=f(S),r.depthStencil=f(E),r.width=n.width,r.height=n.height,m(n),r}var n=new d;return a.framebufferCount++,r(t,e),j(r,{resize:function(t,e){var i=Math.max(0|t,1),a=Math.max(0|e||i,1);if(i===n.width&&a===n.height)return r;for(var o=n.colorAttachments,s=0;s<o.length;++s)p(o[s],i,a);return p(n.depthAttachment,i,a),p(n.stencilAttachment,i,a),p(n.depthStencilAttachment,i,a),n.width=r.width=i,n.height=r.height=a,m(n),r},_reglType:\"framebuffer\",_framebuffer:n,destroy:function(){v(n),g(n)},use:function(t){x.setFBO({framebuffer:r},t)}})}var x={cur:null,next:null,dirty:!1,setFBO:null},b=[\"rgba\"],_=[\"rgba4\",\"rgb565\",\"rgb5 a1\"];e.ext_srgb&&_.push(\"srgba\"),e.ext_color_buffer_half_float&&_.push(\"rgba16f\",\"rgb16f\"),e.webgl_color_buffer_float&&_.push(\"rgba32f\");var w=[\"uint8\"];e.oes_texture_half_float&&w.push(\"half float\",\"float16\"),e.oes_texture_float&&w.push(\"float\",\"float32\");var k=0,T={};return j(x,{getFramebuffer:function(t){return\"function\"==typeof t&&\"framebuffer\"===t._reglType&&(t=t._framebuffer)instanceof d?t:null},create:y,createCube:function(t){function e(t){var i,a={color:null},o=0,s=null;i=\"rgba\";var l=\"uint8\",c=1;if(\"number\"==typeof t?o=0|t:t?(\"shape\"in t?o=t.shape[0]:(\"radius\"in t&&(o=0|t.radius),\"width\"in t?o=0|t.width:\"height\"in t&&(o=0|t.height)),(\"color\"in t||\"colors\"in t)&&(s=t.color||t.colors,Array.isArray(s)),s||(\"colorCount\"in t&&(c=0|t.colorCount),\"colorType\"in t&&(l=t.colorType),\"colorFormat\"in t&&(i=t.colorFormat)),\"depth\"in t&&(a.depth=t.depth),\"stencil\"in t&&(a.stencil=t.stencil),\"depthStencil\"in t&&(a.depthStencil=t.depthStencil)):o=1,s)if(Array.isArray(s))for(t=[],i=0;i<s.length;++i)t[i]=s[i];else t=[s];else for(t=Array(c),s={radius:o,format:i,type:l},i=0;i<c;++i)t[i]=n.createCube(s);for(a.color=Array(t.length),i=0;i<t.length;++i)c=t[i],o=o||c.width,a.color[i]={target:34069,data:t[i]};for(i=0;6>i;++i){for(c=0;c<t.length;++c)a.color[c].target=34069+i;0<i&&(a.depth=r[0].depth,a.stencil=r[0].stencil,a.depthStencil=r[0].depthStencil),r[i]?r[i](a):r[i]=y(a)}return j(e,{width:o,height:o,color:t})}var r=Array(6);return e(t),j(e,{faces:r,resize:function(t){var n=0|t;if(n===e.width)return e;var i=e.color;for(t=0;t<i.length;++t)i[t].resize(n);for(t=0;6>t;++t)r[t].resize(n);return e.width=e.height=n,e},_reglType:\"framebufferCube\",destroy:function(){r.forEach(function(t){t.destroy()})}})},clear:function(){X(T).forEach(v)},restore:function(){x.cur=null,x.next=null,x.dirty=!0,X(T).forEach(function(e){e.framebuffer=t.createFramebuffer(),m(e)})}})}function M(){this.w=this.z=this.y=this.x=this.state=0,this.buffer=null,this.size=0,this.normalized=!1,this.type=5126,this.divisor=this.stride=this.offset=0}function S(t,e,r,n){function i(t,e,r,n){this.name=t,this.id=e,this.location=r,this.info=n}function a(t,e){for(var r=0;r<t.length;++r)if(t[r].id===e.id)return void(t[r].location=e.location);t.push(e)}function o(r,n,i){if(!(o=(i=35632===r?c:u)[n])){var a=e.str(n),o=t.createShader(r);t.shaderSource(o,a),t.compileShader(o),i[n]=o}return o}function s(t,e){this.id=p++,this.fragId=t,this.vertId=e,this.program=null,this.uniforms=[],this.attributes=[],n.profile&&(this.stats={uniformsCount:0,attributesCount:0})}function l(r,s){var l,c;l=o(35632,r.fragId),c=o(35633,r.vertId);var u=r.program=t.createProgram();t.attachShader(u,l),t.attachShader(u,c),t.linkProgram(u);var h=t.getProgramParameter(u,35718);n.profile&&(r.stats.uniformsCount=h);var f=r.uniforms;for(l=0;l<h;++l)if(c=t.getActiveUniform(u,l))if(1<c.size)for(var p=0;p<c.size;++p){var d=c.name.replace(\"[0]\",\"[\"+p+\"]\");a(f,new i(d,e.id(d),t.getUniformLocation(u,d),c))}else a(f,new i(c.name,e.id(c.name),t.getUniformLocation(u,c.name),c));for(h=t.getProgramParameter(u,35721),n.profile&&(r.stats.attributesCount=h),f=r.attributes,l=0;l<h;++l)(c=t.getActiveAttrib(u,l))&&a(f,new i(c.name,e.id(c.name),t.getAttribLocation(u,c.name),c))}var c={},u={},h={},f=[],p=0;return n.profile&&(r.getMaxUniformsCount=function(){var t=0;return f.forEach(function(e){e.stats.uniformsCount>t&&(t=e.stats.uniformsCount)}),t},r.getMaxAttributesCount=function(){var t=0;return f.forEach(function(e){e.stats.attributesCount>t&&(t=e.stats.attributesCount)}),t}),{clear:function(){var e=t.deleteShader.bind(t);X(c).forEach(e),c={},X(u).forEach(e),u={},f.forEach(function(e){t.deleteProgram(e.program)}),f.length=0,h={},r.shaderCount=0},program:function(t,e,n){var i=h[e];i||(i=h[e]={});var a=i[t];return a||(a=new s(e,t),r.shaderCount++,l(a),i[t]=a,f.push(a)),a},restore:function(){c={},u={};for(var t=0;t<f.length;++t)l(f[t])},shader:o,frag:-1,vert:-1}}function E(t,e,r,n,i,a,o){function s(i){var a;a=null===e.next?5121:e.next.colorAttachments[0].texture._texture.type;var o=0,s=0,l=n.framebufferWidth,c=n.framebufferHeight,u=null;return W(i)?u=i:i&&(o=0|i.x,s=0|i.y,l=0|(i.width||n.framebufferWidth-o),c=0|(i.height||n.framebufferHeight-s),u=i.data||null),r(),i=l*c*4,u||(5121===a?u=new Uint8Array(i):5126===a&&(u=u||new Float32Array(i))),t.pixelStorei(3333,4),t.readPixels(o,s,l,c,6408,a,u),u}return function(t){return t&&\"framebuffer\"in t?function(t){var r;return e.setFBO({framebuffer:t.framebuffer},function(){r=s(t)}),r}(t):s(t)}}function C(t){return Array.prototype.slice.call(t)}function L(t){return C(t).join(\"\")}function P(){function t(){var t=[],e=[];return j(function(){t.push.apply(t,C(arguments))},{def:function(){var n=\"v\"+r++;return e.push(n),0<arguments.length&&(t.push(n,\"=\"),t.push.apply(t,C(arguments)),t.push(\";\")),n},toString:function(){return L([0<e.length?\"var \"+e+\";\":\"\",L(t)])}})}function e(){function e(t,e){n(t,e,\"=\",r.def(t,e),\";\")}var r=t(),n=t(),i=r.toString,a=n.toString;return j(function(){r.apply(r,C(arguments))},{def:r.def,entry:r,exit:n,save:e,set:function(t,n,i){e(t,n),r(t,n,\"=\",i,\";\")},toString:function(){return i()+a()}})}var r=0,n=[],i=[],a=t(),o={};return{global:a,link:function(t){for(var e=0;e<i.length;++e)if(i[e]===t)return n[e];return e=\"g\"+r++,n.push(e),i.push(t),e},block:t,proc:function(t,r){function n(){var t=\"a\"+i.length;return i.push(t),t}var i=[];r=r||0;for(var a=0;a<r;++a)n();var s=(a=e()).toString;return o[t]=j(a,{arg:n,toString:function(){return L([\"function(\",i.join(),\"){\",s(),\"}\"])}})},scope:e,cond:function(){var t=L(arguments),r=e(),n=e(),i=r.toString,a=n.toString;return j(r,{then:function(){return r.apply(r,C(arguments)),this},else:function(){return n.apply(n,C(arguments)),this},toString:function(){var e=a();return e&&(e=\"else{\"+e+\"}\"),L([\"if(\",t,\"){\",i(),\"}\",e])}})},compile:function(){var t=['\"use strict\";',a,\"return {\"];Object.keys(o).forEach(function(e){t.push('\"',e,'\":',o[e].toString(),\",\")}),t.push(\"}\");var e=L(t).replace(/;/g,\";\\n\").replace(/}/g,\"}\\n\").replace(/{/g,\"{\\n\");return Function.apply(null,n.concat(e)).apply(null,i)}}}function O(t){return Array.isArray(t)||W(t)||l(t)}function z(t){return t.sort(function(t,e){return\"viewport\"===t?-1:\"viewport\"===e?1:t<e?-1:1})}function I(t,e,r,n){this.thisDep=t,this.contextDep=e,this.propDep=r,this.append=n}function D(t){return t&&!(t.thisDep||t.contextDep||t.propDep)}function R(t){return new I(!1,!1,!1,t)}function F(t,e){var r=t.type;return 0===r?new I(!0,1<=(r=t.data.length),2<=r,e):4===r?new I((r=t.data).thisDep,r.contextDep,r.propDep,e):new I(3===r,2===r,1===r,e)}function B(t,e,r,n,i,o,s,l,c,u,h,f,p,d,g){function m(t){return t.replace(\".\",\"_\")}function y(t,e,r){var n=m(t);nt.push(t),et[n]=tt[n]=!!r,it[n]=e}function x(t,e,r){var n=m(t);nt.push(t),Array.isArray(r)?(tt[n]=r.slice(),et[n]=r.slice()):tt[n]=et[n]=r,at[n]=e}function b(){var t=P(),r=t.link,n=t.global;t.id=lt++,t.batchId=\"0\";var i=r(ot),a=t.shared={props:\"a0\"};Object.keys(ot).forEach(function(t){a[t]=n.def(i,\".\",t)});var o=t.next={},s=t.current={};Object.keys(at).forEach(function(t){Array.isArray(tt[t])&&(o[t]=n.def(a.next,\".\",t),s[t]=n.def(a.current,\".\",t))});var l=t.constants={};Object.keys(st).forEach(function(t){l[t]=n.def(JSON.stringify(st[t]))}),t.invoke=function(e,n){switch(n.type){case 0:var i=[\"this\",a.context,a.props,t.batchId];return e.def(r(n.data),\".call(\",i.slice(0,Math.max(n.data.length+1,4)),\")\");case 1:return e.def(a.props,n.data);case 2:return e.def(a.context,n.data);case 3:return e.def(\"this\",n.data);case 4:return n.data.append(t,e),n.data.ref}},t.attribCache={};var c={};return t.scopeAttrib=function(t){if((t=e.id(t))in c)return c[t];var n=u.scope[t];return n||(n=u.scope[t]=new Z),c[t]=r(n)},t}function _(t,e){var r=t.static,n=t.dynamic;if(\"framebuffer\"in r){var i=r.framebuffer;return i?(i=l.getFramebuffer(i),R(function(t,e){var r=t.link(i),n=t.shared;return e.set(n.framebuffer,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\".width\"),e.set(n,\".framebufferHeight\",r+\".height\"),r})):R(function(t,e){var r=t.shared;return e.set(r.framebuffer,\".next\",\"null\"),r=r.context,e.set(r,\".framebufferWidth\",r+\".drawingBufferWidth\"),e.set(r,\".framebufferHeight\",r+\".drawingBufferHeight\"),\"null\"})}if(\"framebuffer\"in n){var a=n.framebuffer;return F(a,function(t,e){var r=t.invoke(e,a),n=t.shared,i=n.framebuffer;r=e.def(i,\".getFramebuffer(\",r,\")\");return e.set(i,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\"?\"+r+\".width:\"+n+\".drawingBufferWidth\"),e.set(n,\".framebufferHeight\",r+\"?\"+r+\".height:\"+n+\".drawingBufferHeight\"),r})}return null}function w(t){function r(t){if(t in n){var r=e.id(n[t]);return(t=R(function(){return r})).id=r,t}if(t in i){var a=i[t];return F(a,function(t,e){var r=t.invoke(e,a);return e.def(t.shared.strings,\".id(\",r,\")\")})}return null}var n=t.static,i=t.dynamic,a=r(\"frag\"),o=r(\"vert\"),s=null;return D(a)&&D(o)?(s=h.program(o.id,a.id),t=R(function(t,e){return t.link(s)})):t=new I(a&&a.thisDep||o&&o.thisDep,a&&a.contextDep||o&&o.contextDep,a&&a.propDep||o&&o.propDep,function(t,e){var r,n,i=t.shared.shader;return r=a?a.append(t,e):e.def(i,\".\",\"frag\"),n=o?o.append(t,e):e.def(i,\".\",\"vert\"),e.def(i+\".program(\"+n+\",\"+r+\")\")}),{frag:a,vert:o,progVar:t,program:s}}function k(t,e){function r(t,e){if(t in n){var r=0|n[t];return R(function(t,n){return e&&(t.OFFSET=r),r})}if(t in i){var o=i[t];return F(o,function(t,r){var n=t.invoke(r,o);return e&&(t.OFFSET=n),n})}return e&&a?R(function(t,e){return t.OFFSET=\"0\",0}):null}var n=t.static,i=t.dynamic,a=function(){if(\"elements\"in n){var t=n.elements;O(t)?t=o.getElements(o.create(t,!0)):t&&(t=o.getElements(t));var e=R(function(e,r){if(t){var n=e.link(t);return e.ELEMENTS=n}return e.ELEMENTS=null});return e.value=t,e}if(\"elements\"in i){var r=i.elements;return F(r,function(t,e){var n=(i=t.shared).isBufferArgs,i=i.elements,a=t.invoke(e,r),o=e.def(\"null\");n=e.def(n,\"(\",a,\")\"),a=t.cond(n).then(o,\"=\",i,\".createStream(\",a,\");\").else(o,\"=\",i,\".getElements(\",a,\");\");return e.entry(a),e.exit(t.cond(n).then(i,\".destroyStream(\",o,\");\")),t.ELEMENTS=o})}return null}(),s=r(\"offset\",!0);return{elements:a,primitive:function(){if(\"primitive\"in n){var t=n.primitive;return R(function(e,r){return rt[t]})}if(\"primitive\"in i){var e=i.primitive;return F(e,function(t,r){var n=t.constants.primTypes,i=t.invoke(r,e);return r.def(n,\"[\",i,\"]\")})}return a?D(a)?a.value?R(function(t,e){return e.def(t.ELEMENTS,\".primType\")}):R(function(){return 4}):new I(a.thisDep,a.contextDep,a.propDep,function(t,e){var r=t.ELEMENTS;return e.def(r,\"?\",r,\".primType:\",4)}):null}(),count:function(){if(\"count\"in n){var t=0|n.count;return R(function(){return t})}if(\"count\"in i){var e=i.count;return F(e,function(t,r){return t.invoke(r,e)})}return a?D(a)?a?s?new I(s.thisDep,s.contextDep,s.propDep,function(t,e){return e.def(t.ELEMENTS,\".vertCount-\",t.OFFSET)}):R(function(t,e){return e.def(t.ELEMENTS,\".vertCount\")}):R(function(){return-1}):new I(a.thisDep||s.thisDep,a.contextDep||s.contextDep,a.propDep||s.propDep,function(t,e){var r=t.ELEMENTS;return t.OFFSET?e.def(r,\"?\",r,\".vertCount-\",t.OFFSET,\":-1\"):e.def(r,\"?\",r,\".vertCount:-1\")}):null}(),instances:r(\"instances\",!1),offset:s}}function T(t,r){var n=t.static,a=t.dynamic,o={};return Object.keys(n).forEach(function(t){var r=n[t],a=e.id(t),s=new Z;if(O(r))s.state=1,s.buffer=i.getBuffer(i.create(r,34962,!1,!0)),s.type=0;else if(c=i.getBuffer(r))s.state=1,s.buffer=c,s.type=0;else if(\"constant\"in r){var l=r.constant;s.buffer=\"null\",s.state=2,\"number\"==typeof l?s.x=l:bt.forEach(function(t,e){e<l.length&&(s[t]=l[e])})}else{var c=O(r.buffer)?i.getBuffer(i.create(r.buffer,34962,!1,!0)):i.getBuffer(r.buffer),u=0|r.offset,h=0|r.stride,f=0|r.size,p=!!r.normalized,d=0;\"type\"in r&&(d=K[r.type]),r=0|r.divisor,s.buffer=c,s.state=1,s.size=f,s.normalized=p,s.type=d||c.dtype,s.offset=u,s.stride=h,s.divisor=r}o[t]=R(function(t,e){var r=t.attribCache;if(a in r)return r[a];var n={isStream:!1};return Object.keys(s).forEach(function(t){n[t]=s[t]}),s.buffer&&(n.buffer=t.link(s.buffer),n.type=n.type||n.buffer+\".dtype\"),r[a]=n})}),Object.keys(a).forEach(function(t){var e=a[t];o[t]=F(e,function(t,r){function n(t){r(l[t],\"=\",i,\".\",t,\"|0;\")}var i=t.invoke(r,e),a=t.shared,o=a.isBufferArgs,s=a.buffer,l={isStream:r.def(!1)},c=new Z;c.state=1,Object.keys(c).forEach(function(t){l[t]=r.def(\"\"+c[t])});var u=l.buffer,h=l.type;return r(\"if(\",o,\"(\",i,\")){\",l.isStream,\"=true;\",u,\"=\",s,\".createStream(\",34962,\",\",i,\");\",h,\"=\",u,\".dtype;\",\"}else{\",u,\"=\",s,\".getBuffer(\",i,\");\",\"if(\",u,\"){\",h,\"=\",u,\".dtype;\",'}else if(\"constant\" in ',i,\"){\",l.state,\"=\",2,\";\",\"if(typeof \"+i+'.constant === \"number\"){',l[bt[0]],\"=\",i,\".constant;\",bt.slice(1).map(function(t){return l[t]}).join(\"=\"),\"=0;\",\"}else{\",bt.map(function(t,e){return l[t]+\"=\"+i+\".constant.length>\"+e+\"?\"+i+\".constant[\"+e+\"]:0;\"}).join(\"\"),\"}}else{\",\"if(\",o,\"(\",i,\".buffer)){\",u,\"=\",s,\".createStream(\",34962,\",\",i,\".buffer);\",\"}else{\",u,\"=\",s,\".getBuffer(\",i,\".buffer);\",\"}\",h,'=\"type\" in ',i,\"?\",a.glTypes,\"[\",i,\".type]:\",u,\".dtype;\",l.normalized,\"=!!\",i,\".normalized;\"),n(\"size\"),n(\"offset\"),n(\"stride\"),n(\"divisor\"),r(\"}}\"),r.exit(\"if(\",l.isStream,\"){\",s,\".destroyStream(\",u,\");\",\"}\"),l})}),o}function A(t,e,r,n,i){var o=_(t),s=function(t,e,r){function n(t){if(t in i){var r=i[t];t=!0;var n,o,s=0|r.x,l=0|r.y;return\"width\"in r?n=0|r.width:t=!1,\"height\"in r?o=0|r.height:t=!1,new I(!t&&e&&e.thisDep,!t&&e&&e.contextDep,!t&&e&&e.propDep,function(t,e){var i=t.shared.context,a=n;\"width\"in r||(a=e.def(i,\".\",\"framebufferWidth\",\"-\",s));var c=o;return\"height\"in r||(c=e.def(i,\".\",\"framebufferHeight\",\"-\",l)),[s,l,a,c]})}if(t in a){var c=a[t];return t=F(c,function(t,e){var r=t.invoke(e,c),n=t.shared.context,i=e.def(r,\".x|0\"),a=e.def(r,\".y|0\");return[i,a,e.def('\"width\" in ',r,\"?\",r,\".width|0:\",\"(\",n,\".\",\"framebufferWidth\",\"-\",i,\")\"),r=e.def('\"height\" in ',r,\"?\",r,\".height|0:\",\"(\",n,\".\",\"framebufferHeight\",\"-\",a,\")\")]}),e&&(t.thisDep=t.thisDep||e.thisDep,t.contextDep=t.contextDep||e.contextDep,t.propDep=t.propDep||e.propDep),t}return e?new I(e.thisDep,e.contextDep,e.propDep,function(t,e){var r=t.shared.context;return[0,0,e.def(r,\".\",\"framebufferWidth\"),e.def(r,\".\",\"framebufferHeight\")]}):null}var i=t.static,a=t.dynamic;if(t=n(\"viewport\")){var o=t;t=new I(t.thisDep,t.contextDep,t.propDep,function(t,e){var r=o.append(t,e),n=t.shared.context;return e.set(n,\".viewportWidth\",r[2]),e.set(n,\".viewportHeight\",r[3]),r})}return{viewport:t,scissor_box:n(\"scissor.box\")}}(t,o),l=k(t),c=function(t,e){var r=t.static,n=t.dynamic,i={};return nt.forEach(function(t){function e(e,a){if(t in r){var s=e(r[t]);i[o]=R(function(){return s})}else if(t in n){var l=n[t];i[o]=F(l,function(t,e){return a(t,e,t.invoke(e,l))})}}var o=m(t);switch(t){case\"cull.enable\":case\"blend.enable\":case\"dither\":case\"stencil.enable\":case\"depth.enable\":case\"scissor.enable\":case\"polygonOffset.enable\":case\"sample.alpha\":case\"sample.enable\":case\"depth.mask\":return e(function(t){return t},function(t,e,r){return r});case\"depth.func\":return e(function(t){return kt[t]},function(t,e,r){return e.def(t.constants.compareFuncs,\"[\",r,\"]\")});case\"depth.range\":return e(function(t){return t},function(t,e,r){return[e.def(\"+\",r,\"[0]\"),e=e.def(\"+\",r,\"[1]\")]});case\"blend.func\":return e(function(t){return[wt[\"srcRGB\"in t?t.srcRGB:t.src],wt[\"dstRGB\"in t?t.dstRGB:t.dst],wt[\"srcAlpha\"in t?t.srcAlpha:t.src],wt[\"dstAlpha\"in t?t.dstAlpha:t.dst]]},function(t,e,r){function n(t,n){return e.def('\"',t,n,'\" in ',r,\"?\",r,\".\",t,n,\":\",r,\".\",t)}t=t.constants.blendFuncs;var i=n(\"src\",\"RGB\"),a=n(\"dst\",\"RGB\"),o=(i=e.def(t,\"[\",i,\"]\"),e.def(t,\"[\",n(\"src\",\"Alpha\"),\"]\"));return[i,a=e.def(t,\"[\",a,\"]\"),o,t=e.def(t,\"[\",n(\"dst\",\"Alpha\"),\"]\")]});case\"blend.equation\":return e(function(t){return\"string\"==typeof t?[J[t],J[t]]:\"object\"==typeof t?[J[t.rgb],J[t.alpha]]:void 0},function(t,e,r){var n=t.constants.blendEquations,i=e.def(),a=e.def();return(t=t.cond(\"typeof \",r,'===\"string\"')).then(i,\"=\",a,\"=\",n,\"[\",r,\"];\"),t.else(i,\"=\",n,\"[\",r,\".rgb];\",a,\"=\",n,\"[\",r,\".alpha];\"),e(t),[i,a]});case\"blend.color\":return e(function(t){return a(4,function(e){return+t[e]})},function(t,e,r){return a(4,function(t){return e.def(\"+\",r,\"[\",t,\"]\")})});case\"stencil.mask\":return e(function(t){return 0|t},function(t,e,r){return e.def(r,\"|0\")});case\"stencil.func\":return e(function(t){return[kt[t.cmp||\"keep\"],t.ref||0,\"mask\"in t?t.mask:-1]},function(t,e,r){return[t=e.def('\"cmp\" in ',r,\"?\",t.constants.compareFuncs,\"[\",r,\".cmp]\",\":\",7680),e.def(r,\".ref|0\"),e=e.def('\"mask\" in ',r,\"?\",r,\".mask|0:-1\")]});case\"stencil.opFront\":case\"stencil.opBack\":return e(function(e){return[\"stencil.opBack\"===t?1029:1028,Tt[e.fail||\"keep\"],Tt[e.zfail||\"keep\"],Tt[e.zpass||\"keep\"]]},function(e,r,n){function i(t){return r.def('\"',t,'\" in ',n,\"?\",a,\"[\",n,\".\",t,\"]:\",7680)}var a=e.constants.stencilOps;return[\"stencil.opBack\"===t?1029:1028,i(\"fail\"),i(\"zfail\"),i(\"zpass\")]});case\"polygonOffset.offset\":return e(function(t){return[0|t.factor,0|t.units]},function(t,e,r){return[e.def(r,\".factor|0\"),e=e.def(r,\".units|0\")]});case\"cull.face\":return e(function(t){var e=0;return\"front\"===t?e=1028:\"back\"===t&&(e=1029),e},function(t,e,r){return e.def(r,'===\"front\"?',1028,\":\",1029)});case\"lineWidth\":return e(function(t){return t},function(t,e,r){return r});case\"frontFace\":return e(function(t){return At[t]},function(t,e,r){return e.def(r+'===\"cw\"?2304:2305')});case\"colorMask\":return e(function(t){return t.map(function(t){return!!t})},function(t,e,r){return a(4,function(t){return\"!!\"+r+\"[\"+t+\"]\"})});case\"sample.coverage\":return e(function(t){return[\"value\"in t?t.value:1,!!t.invert]},function(t,e,r){return[e.def('\"value\" in ',r,\"?+\",r,\".value:1\"),e=e.def(\"!!\",r,\".invert\")]})}}),i}(t),u=w(t),h=s.viewport;return h&&(c.viewport=h),(s=s[h=m(\"scissor.box\")])&&(c[h]=s),(o={framebuffer:o,draw:l,shader:u,state:c,dirty:s=0<Object.keys(c).length}).profile=function(t){var e,r=t.static;if(t=t.dynamic,\"profile\"in r){var n=!!r.profile;(e=R(function(t,e){return n})).enable=n}else if(\"profile\"in t){var i=t.profile;e=F(i,function(t,e){return t.invoke(e,i)})}return e}(t),o.uniforms=function(t,e){var r=t.static,n=t.dynamic,i={};return Object.keys(r).forEach(function(t){var e,n=r[t];if(\"number\"==typeof n||\"boolean\"==typeof n)e=R(function(){return n});else if(\"function\"==typeof n){var o=n._reglType;\"texture2d\"===o||\"textureCube\"===o?e=R(function(t){return t.link(n)}):\"framebuffer\"!==o&&\"framebufferCube\"!==o||(e=R(function(t){return t.link(n.color[0])}))}else v(n)&&(e=R(function(t){return t.global.def(\"[\",a(n.length,function(t){return n[t]}),\"]\")}));e.value=n,i[t]=e}),Object.keys(n).forEach(function(t){var e=n[t];i[t]=F(e,function(t,r){return t.invoke(r,e)})}),i}(r),o.attributes=T(e),o.context=function(t){var e=t.static,r=t.dynamic,n={};return Object.keys(e).forEach(function(t){var r=e[t];n[t]=R(function(t,e){return\"number\"==typeof r||\"boolean\"==typeof r?\"\"+r:t.link(r)})}),Object.keys(r).forEach(function(t){var e=r[t];n[t]=F(e,function(t,r){return t.invoke(r,e)})}),n}(n),o}function M(t,e,r){var n=t.shared.context,i=t.scope();Object.keys(r).forEach(function(a){e.save(n,\".\"+a),i(n,\".\",a,\"=\",r[a].append(t,e),\";\")}),e(i)}function S(t,e,r,n){var i,a=(s=t.shared).gl,o=s.framebuffer;Q&&(i=e.def(s.extensions,\".webgl_draw_buffers\"));var s=(l=t.constants).drawBuffer,l=l.backBuffer;t=r?r.append(t,e):e.def(o,\".next\"),n||e(\"if(\",t,\"!==\",o,\".cur){\"),e(\"if(\",t,\"){\",a,\".bindFramebuffer(\",36160,\",\",t,\".framebuffer);\"),Q&&e(i,\".drawBuffersWEBGL(\",s,\"[\",t,\".colorAttachments.length]);\"),e(\"}else{\",a,\".bindFramebuffer(\",36160,\",null);\"),Q&&e(i,\".drawBuffersWEBGL(\",l,\");\"),e(\"}\",o,\".cur=\",t,\";\"),n||e(\"}\")}function E(t,e,r){var n=t.shared,i=n.gl,o=t.current,s=t.next,l=n.current,c=n.next,u=t.cond(l,\".dirty\");nt.forEach(function(e){var n,h;if(!((e=m(e))in r.state))if(e in s){n=s[e],h=o[e];var f=a(tt[e].length,function(t){return u.def(n,\"[\",t,\"]\")});u(t.cond(f.map(function(t,e){return t+\"!==\"+h+\"[\"+e+\"]\"}).join(\"||\")).then(i,\".\",at[e],\"(\",f,\");\",f.map(function(t,e){return h+\"[\"+e+\"]=\"+t}).join(\";\"),\";\"))}else n=u.def(c,\".\",e),f=t.cond(n,\"!==\",l,\".\",e),u(f),e in it?f(t.cond(n).then(i,\".enable(\",it[e],\");\").else(i,\".disable(\",it[e],\");\"),l,\".\",e,\"=\",n,\";\"):f(i,\".\",at[e],\"(\",n,\");\",l,\".\",e,\"=\",n,\";\")}),0===Object.keys(r.state).length&&u(l,\".dirty=false;\"),e(u)}function C(t,e,r,n){var i=t.shared,a=t.current,o=i.current,s=i.gl;z(Object.keys(r)).forEach(function(i){var l=r[i];if(!n||n(l)){var c=l.append(t,e);if(it[i]){var u=it[i];D(l)?e(s,c?\".enable(\":\".disable(\",u,\");\"):e(t.cond(c).then(s,\".enable(\",u,\");\").else(s,\".disable(\",u,\");\")),e(o,\".\",i,\"=\",c,\";\")}else if(v(c)){var h=a[i];e(s,\".\",at[i],\"(\",c,\");\",c.map(function(t,e){return h+\"[\"+e+\"]=\"+t}).join(\";\"),\";\")}else e(s,\".\",at[i],\"(\",c,\");\",o,\".\",i,\"=\",c,\";\")}})}function L(t,e){$&&(t.instancing=e.def(t.shared.extensions,\".angle_instanced_arrays\"))}function B(t,e,r,n,i){function a(){return\"undefined\"==typeof performance?\"Date.now()\":\"performance.now()\"}function o(t){t(c=e.def(),\"=\",a(),\";\"),\"string\"==typeof i?t(f,\".count+=\",i,\";\"):t(f,\".count++;\"),d&&(n?t(u=e.def(),\"=\",g,\".getNumPendingQueries();\"):t(g,\".beginQuery(\",f,\");\"))}function s(t){t(f,\".cpuTime+=\",a(),\"-\",c,\";\"),d&&(n?t(g,\".pushScopeStats(\",u,\",\",g,\".getNumPendingQueries(),\",f,\");\"):t(g,\".endQuery();\"))}function l(t){var r=e.def(p,\".profile\");e(p,\".profile=\",t,\";\"),e.exit(p,\".profile=\",r,\";\")}var c,u,h=t.shared,f=t.stats,p=h.current,g=h.timer;if(r=r.profile){if(D(r))return void(r.enable?(o(e),s(e.exit),l(\"true\")):l(\"false\"));l(r=r.append(t,e))}else r=e.def(p,\".profile\");o(h=t.block()),e(\"if(\",r,\"){\",h,\"}\"),s(t=t.block()),e.exit(\"if(\",r,\"){\",t,\"}\")}function N(t,e,r,n,i){function a(r,n,i){function a(){e(\"if(!\",u,\".buffer){\",l,\".enableVertexAttribArray(\",c,\");}\");var r,a=i.type;r=i.size?e.def(i.size,\"||\",n):n,e(\"if(\",u,\".type!==\",a,\"||\",u,\".size!==\",r,\"||\",p.map(function(t){return u+\".\"+t+\"!==\"+i[t]}).join(\"||\"),\"){\",l,\".bindBuffer(\",34962,\",\",h,\".buffer);\",l,\".vertexAttribPointer(\",[c,r,a,i.normalized,i.stride,i.offset],\");\",u,\".type=\",a,\";\",u,\".size=\",r,\";\",p.map(function(t){return u+\".\"+t+\"=\"+i[t]+\";\"}).join(\"\"),\"}\"),$&&(a=i.divisor,e(\"if(\",u,\".divisor!==\",a,\"){\",t.instancing,\".vertexAttribDivisorANGLE(\",[c,a],\");\",u,\".divisor=\",a,\";}\"))}function s(){e(\"if(\",u,\".buffer){\",l,\".disableVertexAttribArray(\",c,\");\",\"}if(\",bt.map(function(t,e){return u+\".\"+t+\"!==\"+f[e]}).join(\"||\"),\"){\",l,\".vertexAttrib4f(\",c,\",\",f,\");\",bt.map(function(t,e){return u+\".\"+t+\"=\"+f[e]+\";\"}).join(\"\"),\"}\")}var l=o.gl,c=e.def(r,\".location\"),u=e.def(o.attributes,\"[\",c,\"]\");r=i.state;var h=i.buffer,f=[i.x,i.y,i.z,i.w],p=[\"buffer\",\"normalized\",\"offset\",\"stride\"];1===r?a():2===r?s():(e(\"if(\",r,\"===\",1,\"){\"),a(),e(\"}else{\"),s(),e(\"}\"))}var o=t.shared;n.forEach(function(n){var o,s=n.name,l=r.attributes[s];if(l){if(!i(l))return;o=l.append(t,e)}else{if(!i(Mt))return;var c=t.scopeAttrib(s);o={},Object.keys(new Z).forEach(function(t){o[t]=e.def(c,\".\",t)})}a(t.link(n),function(t){switch(t){case 35664:case 35667:case 35671:return 2;case 35665:case 35668:case 35672:return 3;case 35666:case 35669:case 35673:return 4;default:return 1}}(n.info.type),o)})}function j(t,r,n,i,o){for(var s,l=t.shared,c=l.gl,u=0;u<i.length;++u){var h,f=(g=i[u]).name,p=g.info.type,d=n.uniforms[f],g=t.link(g)+\".location\";if(d){if(!o(d))continue;if(D(d)){if(f=d.value,35678===p||35680===p)r(c,\".uniform1i(\",g,\",\",(p=t.link(f._texture||f.color[0]._texture))+\".bind());\"),r.exit(p,\".unbind();\");else if(35674===p||35675===p||35676===p)d=2,35675===p?d=3:35676===p&&(d=4),r(c,\".uniformMatrix\",d,\"fv(\",g,\",false,\",f=t.global.def(\"new Float32Array([\"+Array.prototype.slice.call(f)+\"])\"),\");\");else{switch(p){case 5126:s=\"1f\";break;case 35664:s=\"2f\";break;case 35665:s=\"3f\";break;case 35666:s=\"4f\";break;case 35670:case 5124:s=\"1i\";break;case 35671:case 35667:s=\"2i\";break;case 35672:case 35668:s=\"3i\";break;case 35673:s=\"4i\";break;case 35669:s=\"4i\"}r(c,\".uniform\",s,\"(\",g,\",\",v(f)?Array.prototype.slice.call(f):f,\");\")}continue}h=d.append(t,r)}else{if(!o(Mt))continue;h=r.def(l.uniforms,\"[\",e.id(f),\"]\")}switch(35678===p?r(\"if(\",h,\"&&\",h,'._reglType===\"framebuffer\"){',h,\"=\",h,\".color[0];\",\"}\"):35680===p&&r(\"if(\",h,\"&&\",h,'._reglType===\"framebufferCube\"){',h,\"=\",h,\".color[0];\",\"}\"),f=1,p){case 35678:case 35680:p=r.def(h,\"._texture\"),r(c,\".uniform1i(\",g,\",\",p,\".bind());\"),r.exit(p,\".unbind();\");continue;case 5124:case 35670:s=\"1i\";break;case 35667:case 35671:s=\"2i\",f=2;break;case 35668:case 35672:s=\"3i\",f=3;break;case 35669:case 35673:s=\"4i\",f=4;break;case 5126:s=\"1f\";break;case 35664:s=\"2f\",f=2;break;case 35665:s=\"3f\",f=3;break;case 35666:s=\"4f\",f=4;break;case 35674:s=\"Matrix2fv\";break;case 35675:s=\"Matrix3fv\";break;case 35676:s=\"Matrix4fv\"}if(r(c,\".uniform\",s,\"(\",g,\",\"),\"M\"===s.charAt(0)){g=Math.pow(p-35674+2,2);var m=t.global.def(\"new Float32Array(\",g,\")\");r(\"false,(Array.isArray(\",h,\")||\",h,\" instanceof Float32Array)?\",h,\":(\",a(g,function(t){return m+\"[\"+t+\"]=\"+h+\"[\"+t+\"]\"}),\",\",m,\")\")}else r(1<f?a(f,function(t){return h+\"[\"+t+\"]\"}):h);r(\");\")}}function U(t,e,r,n){function i(i){var a=f[i];return a?a.contextDep&&n.contextDynamic||a.propDep?a.append(t,r):a.append(t,e):e.def(h,\".\",i)}function a(){function t(){r(l,\".drawElementsInstancedANGLE(\",[d,v,m,g+\"<<((\"+m+\"-5121)>>1)\",s],\");\")}function e(){r(l,\".drawArraysInstancedANGLE(\",[d,g,v,s],\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}function o(){function t(){r(u+\".drawElements(\"+[d,v,m,g+\"<<((\"+m+\"-5121)>>1)\"]+\");\")}function e(){r(u+\".drawArrays(\"+[d,g,v]+\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}var s,l,c=t.shared,u=c.gl,h=c.draw,f=n.draw,p=function(){var i=f.elements,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(h,\".\",\"elements\"),i&&a(\"if(\"+i+\")\"+u+\".bindBuffer(34963,\"+i+\".buffer.buffer);\"),i}(),d=i(\"primitive\"),g=i(\"offset\"),v=function(){var i=f.count,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(h,\".\",\"count\"),i}();if(\"number\"==typeof v){if(0===v)return}else r(\"if(\",v,\"){\"),r.exit(\"}\");$&&(s=i(\"instances\"),l=t.instancing);var m=p+\".type\",y=f.elements&&D(f.elements);$&&(\"number\"!=typeof s||0<=s)?\"string\"==typeof s?(r(\"if(\",s,\">0){\"),a(),r(\"}else if(\",s,\"<0){\"),o(),r(\"}\")):a():o()}function q(t,e,r,n,i){return i=(e=b()).proc(\"body\",i),$&&(e.instancing=i.def(e.shared.extensions,\".angle_instanced_arrays\")),t(e,i,r,n),e.compile().body}function H(t,e,r,n){L(t,e),N(t,e,r,n.attributes,function(){return!0}),j(t,e,r,n.uniforms,function(){return!0}),U(t,e,e,r)}function G(t,e,r,n){function i(){return!0}t.batchId=\"a1\",L(t,e),N(t,e,r,n.attributes,i),j(t,e,r,n.uniforms,i),U(t,e,e,r)}function Y(t,e,r,n){function i(t){return t.contextDep&&o||t.propDep}function a(t){return!i(t)}L(t,e);var o=r.contextDep,s=e.def(),l=e.def();t.shared.props=l,t.batchId=s;var c=t.scope(),u=t.scope();e(c.entry,\"for(\",s,\"=0;\",s,\"<\",\"a1\",\";++\",s,\"){\",l,\"=\",\"a0\",\"[\",s,\"];\",u,\"}\",c.exit),r.needsContext&&M(t,u,r.context),r.needsFramebuffer&&S(t,u,r.framebuffer),C(t,u,r.state,i),r.profile&&i(r.profile)&&B(t,u,r,!1,!0),n?(N(t,c,r,n.attributes,a),N(t,u,r,n.attributes,i),j(t,c,r,n.uniforms,a),j(t,u,r,n.uniforms,i),U(t,c,u,r)):(e=t.global.def(\"{}\"),n=r.shader.progVar.append(t,u),l=u.def(n,\".id\"),c=u.def(e,\"[\",l,\"]\"),u(t.shared.gl,\".useProgram(\",n,\".program);\",\"if(!\",c,\"){\",c,\"=\",e,\"[\",l,\"]=\",t.link(function(e){return q(G,t,r,e,2)}),\"(\",n,\");}\",c,\".call(this,a0[\",s,\"],\",s,\");\"))}function W(t,r){function n(e){var n=r.shader[e];n&&i.set(a.shader,\".\"+e,n.append(t,i))}var i=t.proc(\"scope\",3);t.batchId=\"a2\";var a=t.shared,o=a.current;M(t,i,r.context),r.framebuffer&&r.framebuffer.append(t,i),z(Object.keys(r.state)).forEach(function(e){var n=r.state[e].append(t,i);v(n)?n.forEach(function(r,n){i.set(t.next[e],\"[\"+n+\"]\",r)}):i.set(a.next,\".\"+e,n)}),B(t,i,r,!0,!0),[\"elements\",\"offset\",\"count\",\"instances\",\"primitive\"].forEach(function(e){var n=r.draw[e];n&&i.set(a.draw,\".\"+e,\"\"+n.append(t,i))}),Object.keys(r.uniforms).forEach(function(n){i.set(a.uniforms,\"[\"+e.id(n)+\"]\",r.uniforms[n].append(t,i))}),Object.keys(r.attributes).forEach(function(e){var n=r.attributes[e].append(t,i),a=t.scopeAttrib(e);Object.keys(new Z).forEach(function(t){i.set(a,\".\"+t,n[t])})}),n(\"vert\"),n(\"frag\"),0<Object.keys(r.state).length&&(i(o,\".dirty=true;\"),i.exit(o,\".dirty=true;\")),i(\"a1(\",t.shared.context,\",a0,\",t.batchId,\");\")}function X(t,e,r){var n=e.static[r];if(n&&function(t){if(\"object\"==typeof t&&!v(t)){for(var e=Object.keys(t),r=0;r<e.length;++r)if(V.isDynamic(t[e[r]]))return!0;return!1}}(n)){var i=t.global,a=Object.keys(n),o=!1,s=!1,l=!1,c=t.global.def(\"{}\");a.forEach(function(e){var r=n[e];if(V.isDynamic(r))\"function\"==typeof r&&(r=n[e]=V.unbox(r)),e=F(r,null),o=o||e.thisDep,l=l||e.propDep,s=s||e.contextDep;else{switch(i(c,\".\",e,\"=\"),typeof r){case\"number\":i(r);break;case\"string\":i('\"',r,'\"');break;case\"object\":Array.isArray(r)&&i(\"[\",r.join(),\"]\");break;default:i(t.link(r))}i(\";\")}}),e.dynamic[r]=new V.DynamicVariable(4,{thisDep:o,contextDep:s,propDep:l,ref:c,append:function(t,e){a.forEach(function(r){var i=n[r];V.isDynamic(i)&&(i=t.invoke(e,i),e(c,\".\",r,\"=\",i,\";\"))})}}),delete e.static[r]}}var Z=u.Record,J={add:32774,subtract:32778,\"reverse subtract\":32779};r.ext_blend_minmax&&(J.min=32775,J.max=32776);var $=r.angle_instanced_arrays,Q=r.webgl_draw_buffers,tt={dirty:!0,profile:g.profile},et={},nt=[],it={},at={};y(\"dither\",3024),y(\"blend.enable\",3042),x(\"blend.color\",\"blendColor\",[0,0,0,0]),x(\"blend.equation\",\"blendEquationSeparate\",[32774,32774]),x(\"blend.func\",\"blendFuncSeparate\",[1,0,1,0]),y(\"depth.enable\",2929,!0),x(\"depth.func\",\"depthFunc\",513),x(\"depth.range\",\"depthRange\",[0,1]),x(\"depth.mask\",\"depthMask\",!0),x(\"colorMask\",\"colorMask\",[!0,!0,!0,!0]),y(\"cull.enable\",2884),x(\"cull.face\",\"cullFace\",1029),x(\"frontFace\",\"frontFace\",2305),x(\"lineWidth\",\"lineWidth\",1),y(\"polygonOffset.enable\",32823),x(\"polygonOffset.offset\",\"polygonOffset\",[0,0]),y(\"sample.alpha\",32926),y(\"sample.enable\",32928),x(\"sample.coverage\",\"sampleCoverage\",[1,!1]),y(\"stencil.enable\",2960),x(\"stencil.mask\",\"stencilMask\",-1),x(\"stencil.func\",\"stencilFunc\",[519,0,-1]),x(\"stencil.opFront\",\"stencilOpSeparate\",[1028,7680,7680,7680]),x(\"stencil.opBack\",\"stencilOpSeparate\",[1029,7680,7680,7680]),y(\"scissor.enable\",3089),x(\"scissor.box\",\"scissor\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]),x(\"viewport\",\"viewport\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]);var ot={gl:t,context:p,strings:e,next:et,current:tt,draw:f,elements:o,buffer:i,shader:h,attributes:u.state,uniforms:c,framebuffer:l,extensions:r,timer:d,isBufferArgs:O},st={primTypes:rt,compareFuncs:kt,blendFuncs:wt,blendEquations:J,stencilOps:Tt,glTypes:K,orientationType:At};Q&&(st.backBuffer=[1029],st.drawBuffer=a(n.maxDrawbuffers,function(t){return 0===t?[0]:a(t,function(t){return 36064+t})}));var lt=0;return{next:et,current:tt,procs:function(){var t=b(),e=t.proc(\"poll\"),r=t.proc(\"refresh\"),i=t.block();e(i),r(i);var o,s=t.shared,l=s.gl,c=s.next,u=s.current;i(u,\".dirty=false;\"),S(t,e),S(t,r,null,!0),$&&(o=t.link($));for(var h=0;h<n.maxAttributes;++h){var f=r.def(s.attributes,\"[\",h,\"]\"),p=t.cond(f,\".buffer\");p.then(l,\".enableVertexAttribArray(\",h,\");\",l,\".bindBuffer(\",34962,\",\",f,\".buffer.buffer);\",l,\".vertexAttribPointer(\",h,\",\",f,\".size,\",f,\".type,\",f,\".normalized,\",f,\".stride,\",f,\".offset);\").else(l,\".disableVertexAttribArray(\",h,\");\",l,\".vertexAttrib4f(\",h,\",\",f,\".x,\",f,\".y,\",f,\".z,\",f,\".w);\",f,\".buffer=null;\"),r(p),$&&r(o,\".vertexAttribDivisorANGLE(\",h,\",\",f,\".divisor);\")}return Object.keys(it).forEach(function(n){var a=it[n],o=i.def(c,\".\",n),s=t.block();s(\"if(\",o,\"){\",l,\".enable(\",a,\")}else{\",l,\".disable(\",a,\")}\",u,\".\",n,\"=\",o,\";\"),r(s),e(\"if(\",o,\"!==\",u,\".\",n,\"){\",s,\"}\")}),Object.keys(at).forEach(function(n){var o,s,h=at[n],f=tt[n],p=t.block();p(l,\".\",h,\"(\"),v(f)?(h=f.length,o=t.global.def(c,\".\",n),s=t.global.def(u,\".\",n),p(a(h,function(t){return o+\"[\"+t+\"]\"}),\");\",a(h,function(t){return s+\"[\"+t+\"]=\"+o+\"[\"+t+\"];\"}).join(\"\")),e(\"if(\",a(h,function(t){return o+\"[\"+t+\"]!==\"+s+\"[\"+t+\"]\"}).join(\"||\"),\"){\",p,\"}\")):(o=i.def(c,\".\",n),s=i.def(u,\".\",n),p(o,\");\",u,\".\",n,\"=\",o,\";\"),e(\"if(\",o,\"!==\",s,\"){\",p,\"}\")),r(p)}),t.compile()}(),compile:function(t,e,r,n,i){var a=b();return a.stats=a.link(i),Object.keys(e.static).forEach(function(t){X(a,e,t)}),_t.forEach(function(e){X(a,t,e)}),r=A(t,e,r,n),function(t,e){var r=t.proc(\"draw\",1);L(t,r),M(t,r,e.context),S(t,r,e.framebuffer),E(t,r,e),C(t,r,e.state),B(t,r,e,!1,!0);var n=e.shader.progVar.append(t,r);if(r(t.shared.gl,\".useProgram(\",n,\".program);\"),e.shader.program)H(t,r,e,e.shader.program);else{var i=t.global.def(\"{}\"),a=r.def(n,\".id\"),o=r.def(i,\"[\",a,\"]\");r(t.cond(o).then(o,\".call(this,a0);\").else(o,\"=\",i,\"[\",a,\"]=\",t.link(function(r){return q(H,t,e,r,1)}),\"(\",n,\");\",o,\".call(this,a0);\"))}0<Object.keys(e.state).length&&r(t.shared.current,\".dirty=true;\")}(a,r),W(a,r),function(t,e){function r(t){return t.contextDep&&i||t.propDep}var n=t.proc(\"batch\",2);t.batchId=\"0\",L(t,n);var i=!1,a=!0;Object.keys(e.context).forEach(function(t){i=i||e.context[t].propDep}),i||(M(t,n,e.context),a=!1);var o=!1;if((s=e.framebuffer)?(s.propDep?i=o=!0:s.contextDep&&i&&(o=!0),o||S(t,n,s)):S(t,n,null),e.state.viewport&&e.state.viewport.propDep&&(i=!0),E(t,n,e),C(t,n,e.state,function(t){return!r(t)}),e.profile&&r(e.profile)||B(t,n,e,!1,\"a1\"),e.contextDep=i,e.needsContext=a,e.needsFramebuffer=o,(a=e.shader.progVar).contextDep&&i||a.propDep)Y(t,n,e,null);else if(a=a.append(t,n),n(t.shared.gl,\".useProgram(\",a,\".program);\"),e.shader.program)Y(t,n,e,e.shader.program);else{var s=t.global.def(\"{}\"),l=(o=n.def(a,\".id\"),n.def(s,\"[\",o,\"]\"));n(t.cond(l).then(l,\".call(this,a0,a1);\").else(l,\"=\",s,\"[\",o,\"]=\",t.link(function(r){return q(Y,t,e,r,2)}),\"(\",a,\");\",l,\".call(this,a0,a1);\"))}0<Object.keys(e.state).length&&n(t.shared.current,\".dirty=true;\")}(a,r),a.compile()}}}function N(t,e){for(var r=0;r<t.length;++r)if(t[r]===e)return r;return-1}var j=function(t,e){for(var r=Object.keys(e),n=0;n<r.length;++n)t[r[n]]=e[r[n]];return t},U=0,V={DynamicVariable:t,define:function(r,n){return new t(r,e(n+\"\"))},isDynamic:function(e){return\"function\"==typeof e&&!e._reglType||e instanceof t},unbox:function(e,r){return\"function\"==typeof e?new t(0,e):e},accessor:e},q={next:\"function\"==typeof requestAnimationFrame?function(t){return requestAnimationFrame(t)}:function(t){return setTimeout(t,16)},cancel:\"function\"==typeof cancelAnimationFrame?function(t){return cancelAnimationFrame(t)}:clearTimeout},H=\"undefined\"!=typeof performance&&performance.now?function(){return performance.now()}:function(){return+new Date},G=s();G.zero=s();var Y=function(t,e){var r=1;e.ext_texture_filter_anisotropic&&(r=t.getParameter(34047));var n=1,i=1;e.webgl_draw_buffers&&(n=t.getParameter(34852),i=t.getParameter(36063));var a=!!e.oes_texture_float;if(a){a=t.createTexture(),t.bindTexture(3553,a),t.texImage2D(3553,0,6408,1,1,0,6408,5126,null);var o=t.createFramebuffer();if(t.bindFramebuffer(36160,o),t.framebufferTexture2D(36160,36064,3553,a,0),t.bindTexture(3553,null),36053!==t.checkFramebufferStatus(36160))a=!1;else{t.viewport(0,0,1,1),t.clearColor(1,0,0,1),t.clear(16384);var s=G.allocType(5126,4);t.readPixels(0,0,1,1,6408,5126,s),t.getError()?a=!1:(t.deleteFramebuffer(o),t.deleteTexture(a),a=1===s[0]),G.freeType(s)}}return s=!0,\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion)||/Edge/.test(navigator.userAgent))||(s=t.createTexture(),o=G.allocType(5121,36),t.activeTexture(33984),t.bindTexture(34067,s),t.texImage2D(34069,0,6408,3,3,0,6408,5121,o),G.freeType(o),t.bindTexture(34067,null),t.deleteTexture(s),s=!t.getError()),{colorBits:[t.getParameter(3410),t.getParameter(3411),t.getParameter(3412),t.getParameter(3413)],depthBits:t.getParameter(3414),stencilBits:t.getParameter(3415),subpixelBits:t.getParameter(3408),extensions:Object.keys(e).filter(function(t){return!!e[t]}),maxAnisotropic:r,maxDrawbuffers:n,maxColorAttachments:i,pointSizeDims:t.getParameter(33901),lineWidthDims:t.getParameter(33902),maxViewportDims:t.getParameter(3386),maxCombinedTextureUnits:t.getParameter(35661),maxCubeMapSize:t.getParameter(34076),maxRenderbufferSize:t.getParameter(34024),maxTextureUnits:t.getParameter(34930),maxTextureSize:t.getParameter(3379),maxAttributes:t.getParameter(34921),maxVertexUniforms:t.getParameter(36347),maxVertexTextureUnits:t.getParameter(35660),maxVaryingVectors:t.getParameter(36348),maxFragmentUniforms:t.getParameter(36349),glsl:t.getParameter(35724),renderer:t.getParameter(7937),vendor:t.getParameter(7936),version:t.getParameter(7938),readFloat:a,npotTextureCube:s}},W=function(t){return t instanceof Uint8Array||t instanceof Uint16Array||t instanceof Uint32Array||t instanceof Int8Array||t instanceof Int16Array||t instanceof Int32Array||t instanceof Float32Array||t instanceof Float64Array||t instanceof Uint8ClampedArray},X=function(t){return Object.keys(t).map(function(e){return t[e]})},Z={shape:function(t){for(var e=[];t.length;t=t[0])e.push(t.length);return e},flatten:function(t,e,r,n){var i=1;if(e.length)for(var a=0;a<e.length;++a)i*=e[a];else i=0;switch(r=n||G.allocType(r,i),e.length){case 0:break;case 1:for(n=e[0],e=0;e<n;++e)r[e]=t[e];break;case 2:for(n=e[0],e=e[1],a=i=0;a<n;++a)for(var o=t[a],s=0;s<e;++s)r[i++]=o[s];break;case 3:c(t,e[0],e[1],e[2],r,0);break;default:!function t(e,r,n,i,a){for(var o=1,s=n+1;s<r.length;++s)o*=r[s];var l=r[n];if(4==r.length-n){var u=r[n+1],h=r[n+2];for(r=r[n+3],s=0;s<l;++s)c(e[s],u,h,r,i,a),a+=o}else for(s=0;s<l;++s)t(e[s],r,n+1,i,a),a+=o}(t,e,0,r,0)}return r}},J={\"[object Int8Array]\":5120,\"[object Int16Array]\":5122,\"[object Int32Array]\":5124,\"[object Uint8Array]\":5121,\"[object Uint8ClampedArray]\":5121,\"[object Uint16Array]\":5123,\"[object Uint32Array]\":5125,\"[object Float32Array]\":5126,\"[object Float64Array]\":5121,\"[object ArrayBuffer]\":5121},K={int8:5120,int16:5122,int32:5124,uint8:5121,uint16:5123,uint32:5125,float:5126,float32:5126},$={dynamic:35048,stream:35040,static:35044},Q=Z.flatten,tt=Z.shape,et=[];et[5120]=1,et[5122]=2,et[5124]=4,et[5121]=1,et[5123]=2,et[5125]=4,et[5126]=4;var rt={points:0,point:0,lines:1,line:1,triangles:4,triangle:4,\"line loop\":2,\"line strip\":3,\"triangle strip\":5,\"triangle fan\":6},nt=new Float32Array(1),it=new Uint32Array(nt.buffer),at=[9984,9986,9985,9987],ot=[0,6409,6410,6407,6408],st={};st[6409]=st[6406]=st[6402]=1,st[34041]=st[6410]=2,st[6407]=st[35904]=3,st[6408]=st[35906]=4;var lt=m(\"HTMLCanvasElement\"),ct=m(\"CanvasRenderingContext2D\"),ut=m(\"ImageBitmap\"),ht=m(\"HTMLImageElement\"),ft=m(\"HTMLVideoElement\"),pt=Object.keys(J).concat([lt,ct,ut,ht,ft]),dt=[];dt[5121]=1,dt[5126]=4,dt[36193]=2,dt[5123]=2,dt[5125]=4;var gt=[];gt[32854]=2,gt[32855]=2,gt[36194]=2,gt[34041]=4,gt[33776]=.5,gt[33777]=.5,gt[33778]=1,gt[33779]=1,gt[35986]=.5,gt[35987]=1,gt[34798]=1,gt[35840]=.5,gt[35841]=.25,gt[35842]=.5,gt[35843]=.25,gt[36196]=.5;var vt=[];vt[32854]=2,vt[32855]=2,vt[36194]=2,vt[33189]=2,vt[36168]=1,vt[34041]=4,vt[35907]=4,vt[34836]=16,vt[34842]=8,vt[34843]=6;var mt=function(t,e,r,n,i){function a(t){this.id=c++,this.refCount=1,this.renderbuffer=t,this.format=32854,this.height=this.width=0,i.profile&&(this.stats={size:0})}function o(e){var r=e.renderbuffer;t.bindRenderbuffer(36161,null),t.deleteRenderbuffer(r),e.renderbuffer=null,e.refCount=0,delete u[e.id],n.renderbufferCount--}var s={rgba4:32854,rgb565:36194,\"rgb5 a1\":32855,depth:33189,stencil:36168,\"depth stencil\":34041};e.ext_srgb&&(s.srgba=35907),e.ext_color_buffer_half_float&&(s.rgba16f=34842,s.rgb16f=34843),e.webgl_color_buffer_float&&(s.rgba32f=34836);var l=[];Object.keys(s).forEach(function(t){l[s[t]]=t});var c=0,u={};return a.prototype.decRef=function(){0>=--this.refCount&&o(this)},i.profile&&(n.getTotalRenderbufferSize=function(){var t=0;return Object.keys(u).forEach(function(e){t+=u[e].stats.size}),t}),{create:function(e,r){function o(e,r){var n=0,a=0,u=32854;if(\"object\"==typeof e&&e?(\"shape\"in e?(n=0|(a=e.shape)[0],a=0|a[1]):(\"radius\"in e&&(n=a=0|e.radius),\"width\"in e&&(n=0|e.width),\"height\"in e&&(a=0|e.height)),\"format\"in e&&(u=s[e.format])):\"number\"==typeof e?(n=0|e,a=\"number\"==typeof r?0|r:n):e||(n=a=1),n!==c.width||a!==c.height||u!==c.format)return o.width=c.width=n,o.height=c.height=a,c.format=u,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,u,n,a),i.profile&&(c.stats.size=vt[c.format]*c.width*c.height),o.format=l[c.format],o}var c=new a(t.createRenderbuffer());return u[c.id]=c,n.renderbufferCount++,o(e,r),o.resize=function(e,r){var n=0|e,a=0|r||n;return n===c.width&&a===c.height?o:(o.width=c.width=n,o.height=c.height=a,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,c.format,n,a),i.profile&&(c.stats.size=vt[c.format]*c.width*c.height),o)},o._reglType=\"renderbuffer\",o._renderbuffer=c,i.profile&&(o.stats=c.stats),o.destroy=function(){c.decRef()},o},clear:function(){X(u).forEach(o)},restore:function(){X(u).forEach(function(e){e.renderbuffer=t.createRenderbuffer(),t.bindRenderbuffer(36161,e.renderbuffer),t.renderbufferStorage(36161,e.format,e.width,e.height)}),t.bindRenderbuffer(36161,null)}}},yt=[];yt[6408]=4,yt[6407]=3;var xt=[];xt[5121]=1,xt[5126]=4,xt[36193]=2;var bt=[\"x\",\"y\",\"z\",\"w\"],_t=\"blend.func blend.equation stencil.func stencil.opFront stencil.opBack sample.coverage viewport scissor.box polygonOffset.offset\".split(\" \"),wt={0:0,1:1,zero:0,one:1,\"src color\":768,\"one minus src color\":769,\"src alpha\":770,\"one minus src alpha\":771,\"dst color\":774,\"one minus dst color\":775,\"dst alpha\":772,\"one minus dst alpha\":773,\"constant color\":32769,\"one minus constant color\":32770,\"constant alpha\":32771,\"one minus constant alpha\":32772,\"src alpha saturate\":776},kt={never:512,less:513,\"<\":513,equal:514,\"=\":514,\"==\":514,\"===\":514,lequal:515,\"<=\":515,greater:516,\">\":516,notequal:517,\"!=\":517,\"!==\":517,gequal:518,\">=\":518,always:519},Tt={0:0,zero:0,keep:7680,replace:7681,increment:7682,decrement:7683,\"increment wrap\":34055,\"decrement wrap\":34056,invert:5386},At={cw:2304,ccw:2305},Mt=new I(!1,!1,!1,function(){});return function(t){function e(){if(0===Z.length)w&&w.update(),Q=null;else{Q=q.next(e),h();for(var t=Z.length-1;0<=t;--t){var r=Z[t];r&&r(P,null,0)}v.flush(),w&&w.update()}}function r(){!Q&&0<Z.length&&(Q=q.next(e))}function n(){Q&&(q.cancel(e),Q=null)}function a(t){t.preventDefault(),n(),J.forEach(function(t){t()})}function o(t){v.getError(),y.restore(),D.restore(),z.restore(),R.restore(),F.restore(),U.restore(),w&&w.restore(),G.procs.refresh(),r(),K.forEach(function(t){t()})}function s(t){function e(t){var e={},r={};return Object.keys(t).forEach(function(n){var i=t[n];V.isDynamic(i)?r[n]=V.unbox(i,n):e[n]=i}),{dynamic:r,static:e}}var r=e(t.context||{}),n=e(t.uniforms||{}),i=e(t.attributes||{}),a=e(function(t){function e(t){if(t in r){var e=r[t];delete r[t],Object.keys(e).forEach(function(n){r[t+\".\"+n]=e[n]})}}var r=j({},t);return delete r.uniforms,delete r.attributes,delete r.context,\"stencil\"in r&&r.stencil.op&&(r.stencil.opBack=r.stencil.opFront=r.stencil.op,delete r.stencil.op),e(\"blend\"),e(\"depth\"),e(\"cull\"),e(\"stencil\"),e(\"polygonOffset\"),e(\"scissor\"),e(\"sample\"),r}(t));t={gpuTime:0,cpuTime:0,count:0};var o=(r=G.compile(a,i,n,r,t)).draw,s=r.batch,l=r.scope,c=[];return j(function(t,e){var r;if(\"function\"==typeof t)return l.call(this,null,t,0);if(\"function\"==typeof e)if(\"number\"==typeof t)for(r=0;r<t;++r)l.call(this,null,e,r);else{if(!Array.isArray(t))return l.call(this,t,e,0);for(r=0;r<t.length;++r)l.call(this,t[r],e,r)}else if(\"number\"==typeof t){if(0<t)return s.call(this,function(t){for(;c.length<t;)c.push(null);return c}(0|t),0|t)}else{if(!Array.isArray(t))return o.call(this,t);if(t.length)return s.call(this,t,t.length)}},{stats:t})}function l(t,e){var r=0;G.procs.poll();var n=e.color;n&&(v.clearColor(+n[0]||0,+n[1]||0,+n[2]||0,+n[3]||0),r|=16384),\"depth\"in e&&(v.clearDepth(+e.depth),r|=256),\"stencil\"in e&&(v.clearStencil(0|e.stencil),r|=1024),v.clear(r)}function c(t){return Z.push(t),r(),{cancel:function(){var e=N(Z,t);Z[e]=function t(){var e=N(Z,t);Z[e]=Z[Z.length-1],--Z.length,0>=Z.length&&n()}}}}function u(){var t=W.viewport,e=W.scissor_box;t[0]=t[1]=e[0]=e[1]=0,P.viewportWidth=P.framebufferWidth=P.drawingBufferWidth=t[2]=e[2]=v.drawingBufferWidth,P.viewportHeight=P.framebufferHeight=P.drawingBufferHeight=t[3]=e[3]=v.drawingBufferHeight}function h(){P.tick+=1,P.time=g(),u(),G.procs.poll()}function f(){u(),G.procs.refresh(),w&&w.update()}function g(){return(H()-k)/1e3}if(!(t=i(t)))return null;var v=t.gl,m=v.getContextAttributes();v.isContextLost();var y=function(t,e){function r(e){var r;e=e.toLowerCase();try{r=n[e]=t.getExtension(e)}catch(t){}return!!r}for(var n={},i=0;i<e.extensions.length;++i){var a=e.extensions[i];if(!r(a))return e.onDestroy(),e.onDone('\"'+a+'\" extension is not supported by the current WebGL context, try upgrading your system or a different browser'),null}return e.optionalExtensions.forEach(r),{extensions:n,restore:function(){Object.keys(n).forEach(function(t){if(n[t]&&!r(t))throw Error(\"(regl): error restoring extension \"+t)})}}}(v,t);if(!y)return null;var x=function(){var t={\"\":0},e=[\"\"];return{id:function(r){var n=t[r];return n||(n=t[r]=e.length,e.push(r),n)},str:function(t){return e[t]}}}(),b={bufferCount:0,elementsCount:0,framebufferCount:0,shaderCount:0,textureCount:0,cubeCount:0,renderbufferCount:0,maxTextureUnits:0},_=y.extensions,w=function(t,e){function r(){this.endQueryIndex=this.startQueryIndex=-1,this.sum=0,this.stats=null}function n(t,e,n){var i=o.pop()||new r;i.startQueryIndex=t,i.endQueryIndex=e,i.sum=0,i.stats=n,s.push(i)}if(!e.ext_disjoint_timer_query)return null;var i=[],a=[],o=[],s=[],l=[],c=[];return{beginQuery:function(t){var r=i.pop()||e.ext_disjoint_timer_query.createQueryEXT();e.ext_disjoint_timer_query.beginQueryEXT(35007,r),a.push(r),n(a.length-1,a.length,t)},endQuery:function(){e.ext_disjoint_timer_query.endQueryEXT(35007)},pushScopeStats:n,update:function(){var t,r;if(0!==(t=a.length)){c.length=Math.max(c.length,t+1),l.length=Math.max(l.length,t+1),l[0]=0;var n=c[0]=0;for(r=t=0;r<a.length;++r){var u=a[r];e.ext_disjoint_timer_query.getQueryObjectEXT(u,34919)?(n+=e.ext_disjoint_timer_query.getQueryObjectEXT(u,34918),i.push(u)):a[t++]=u,l[r+1]=n,c[r+1]=t}for(a.length=t,r=t=0;r<s.length;++r){var h=(n=s[r]).startQueryIndex;u=n.endQueryIndex,n.sum+=l[u]-l[h],h=c[h],(u=c[u])===h?(n.stats.gpuTime+=n.sum/1e6,o.push(n)):(n.startQueryIndex=h,n.endQueryIndex=u,s[t++]=n)}s.length=t}},getNumPendingQueries:function(){return a.length},clear:function(){i.push.apply(i,a);for(var t=0;t<i.length;t++)e.ext_disjoint_timer_query.deleteQueryEXT(i[t]);a.length=0,i.length=0},restore:function(){a.length=0,i.length=0}}}(0,_),k=H(),C=v.drawingBufferWidth,L=v.drawingBufferHeight,P={tick:0,time:0,viewportWidth:C,viewportHeight:L,framebufferWidth:C,framebufferHeight:L,drawingBufferWidth:C,drawingBufferHeight:L,pixelRatio:t.pixelRatio},O=Y(v,_),z=(C=function(t,e,r,n){for(t=r.maxAttributes,e=Array(t),r=0;r<t;++r)e[r]=new M;return{Record:M,scope:{},state:e}}(v,_,O),p(v,b,t,C)),I=d(v,_,z,b),D=S(v,x,b,t),R=T(v,_,O,function(){G.procs.poll()},P,b,t),F=mt(v,_,0,b,t),U=A(v,_,O,R,F,b),G=B(v,x,_,O,z,I,0,U,{},C,D,{elements:null,primitive:4,count:-1,offset:0,instances:-1},P,w,t),W=(x=E(v,U,G.procs.poll,P),G.next),X=v.canvas,Z=[],J=[],K=[],$=[t.onDestroy],Q=null;X&&(X.addEventListener(\"webglcontextlost\",a,!1),X.addEventListener(\"webglcontextrestored\",o,!1));var tt=U.setFBO=s({framebuffer:V.define.call(null,1,\"framebuffer\")});return f(),m=j(s,{clear:function(t){if(\"framebuffer\"in t)if(t.framebuffer&&\"framebufferCube\"===t.framebuffer_reglType)for(var e=0;6>e;++e)tt(j({framebuffer:t.framebuffer.faces[e]},t),l);else tt(t,l);else l(0,t)},prop:V.define.bind(null,1),context:V.define.bind(null,2),this:V.define.bind(null,3),draw:s({}),buffer:function(t){return z.create(t,34962,!1,!1)},elements:function(t){return I.create(t,!1)},texture:R.create2D,cube:R.createCube,renderbuffer:F.create,framebuffer:U.create,framebufferCube:U.createCube,attributes:m,frame:c,on:function(t,e){var r;switch(t){case\"frame\":return c(e);case\"lost\":r=J;break;case\"restore\":r=K;break;case\"destroy\":r=$}return r.push(e),{cancel:function(){for(var t=0;t<r.length;++t)if(r[t]===e){r[t]=r[r.length-1],r.pop();break}}}},limits:O,hasExtension:function(t){return 0<=O.extensions.indexOf(t.toLowerCase())},read:x,destroy:function(){Z.length=0,n(),X&&(X.removeEventListener(\"webglcontextlost\",a),X.removeEventListener(\"webglcontextrestored\",o)),D.clear(),U.clear(),F.clear(),R.clear(),I.clear(),z.clear(),w&&w.clear(),$.forEach(function(t){t()})},_gl:v,_refresh:f,poll:function(){h(),w&&w.update()},now:g,stats:b}),t.onDone(null,m),m}},\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=i():n.createREGL=i()},{}],503:[function(t,e,r){\"use strict\";var n,i=\"\";e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"expected a string\");if(1===e)return t;if(2===e)return t+t;var r=t.length*e;if(n!==t||\"undefined\"==typeof n)n=t,i=\"\";else if(i.length>=r)return i.substr(0,r);for(;r>i.length&&e>1;)1&e&&(i+=t),e>>=1,t+=t;return i=(i+=t).substr(0,r)}},{}],504:[function(t,e,r){(function(t){e.exports=t.performance&&t.performance.now?function(){return performance.now()}:Date.now||function(){return+new Date}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{}],505:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=t[t.length-1],n=e,i=e-2;i>=0;--i){var a=r,o=t[i],s=(r=a+o)-a,l=o-s;l&&(t[--n]=r,r=l)}for(var c=0,i=n;i<e;++i){var a=t[i],o=r,s=(r=a+o)-a,l=o-s;l&&(t[c++]=l)}return t[c++]=r,t.length=c,t}},{}],506:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-compress\"),s=6;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(2===t.length)return[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\");for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(l(t,r)),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return function t(e){if(1===e.length)return e[0];if(2===e.length)return[\"sum(\",e[0],\",\",e[1],\")\"].join(\"\");var r=e.length>>1;return[\"sum(\",t(e.slice(0,r)),\",\",t(e.slice(r)),\")\"].join(\"\")}(e);var n}function u(t){return new Function(\"sum\",\"scale\",\"prod\",\"compress\",[\"function robustDeterminant\",t,\"(m){return compress(\",c(function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m[\",r,\"][\",n,\"]\"].join(\"\")}return e}(t)),\")};return robustDeterminant\",t].join(\"\"))(i,a,n,o)}var h=[function(){return[0]},function(t){return[t[0][0]]}];!function(){for(;h.length<s;)h.push(u(h.length));for(var t=[],r=[\"function robustDeterminant(m){switch(m.length){\"],n=0;n<s;++n)t.push(\"det\"+n),r.push(\"case \",n,\":return det\",n,\"(m);\");r.push(\"}var det=CACHE[m.length];if(!det)det=CACHE[m.length]=gen(m.length);return det(m);}return robustDeterminant\"),t.push(\"CACHE\",\"gen\",r.join(\"\"));var i=Function.apply(void 0,t);for(e.exports=i.apply(void 0,h.concat([h,u])),n=0;n<h.length;++n)e.exports[n]=h[n]}()},{\"robust-compress\":505,\"robust-scale\":512,\"robust-sum\":515,\"two-product\":543}],507:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\");e.exports=function(t,e){for(var r=n(t[0],e[0]),a=1;a<t.length;++a)r=i(r,n(t[a],e[a]));return r}},{\"robust-sum\":515,\"two-product\":543}],508:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-subtract\"),o=t(\"robust-scale\"),s=6;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",c(t.slice(0,e)),\",\",c(t.slice(e)),\")\"].join(\"\")}function u(t,e){if(\"m\"===t.charAt(0)){if(\"w\"===e.charAt(0)){var r=t.split(\"[\");return[\"w\",e.substr(1),\"m\",r[0].substr(1)].join(\"\")}return[\"prod(\",t,\",\",e,\")\"].join(\"\")}return u(e,t)}function h(t){if(2===t.length)return[[\"diff(\",u(t[0][0],t[1][1]),\",\",u(t[1][0],t[0][1]),\")\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(h(l(t,r))),\",\",(n=r,!0&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function f(t,e){for(var r=[],n=0;n<e-2;++n)r.push([\"prod(m\",t,\"[\",n,\"],m\",t,\"[\",n,\"])\"].join(\"\"));return c(r)}function p(t){for(var e=[],r=[],s=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-2,\"]\"].join(\"\")}return e}(t),u=0;u<t;++u)s[0][u]=\"1\",s[t-1][u]=\"w\"+u;for(u=0;u<t;++u)0==(1&u)?e.push.apply(e,h(l(s,u))):r.push.apply(r,h(l(s,u)));var p=c(e),d=c(r),g=\"exactInSphere\"+t,v=[];for(u=0;u<t;++u)v.push(\"m\"+u);var m=[\"function \",g,\"(\",v.join(),\"){\"];for(u=0;u<t;++u){m.push(\"var w\",u,\"=\",f(u,t),\";\");for(var y=0;y<t;++y)y!==u&&m.push(\"var w\",u,\"m\",y,\"=scale(w\",u,\",m\",y,\"[0]);\")}return m.push(\"var p=\",p,\",n=\",d,\",d=diff(p,n);return d[d.length-1];}return \",g),new Function(\"sum\",\"diff\",\"prod\",\"scale\",m.join(\"\"))(i,a,n,o)}var d=[function(){return 0},function(){return 0},function(){return 0}];!function(){for(;d.length<=s;)d.push(p(d.length));for(var t=[],r=[\"slow\"],n=0;n<=s;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function testInSphere(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=s;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return testInSphere\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[function(t){var e=d[t.length];return e||(e=d[t.length]=p(t.length)),e.apply(void 0,t)}].concat(d)),n=0;n<=s;++n)e.exports[n]=d[n]}()},{\"robust-scale\":512,\"robust-subtract\":514,\"robust-sum\":515,\"two-product\":543}],509:[function(t,e,r){\"use strict\";var n=t(\"robust-determinant\"),i=6;function a(t){for(var e=\"robustLinearSolve\"+t+\"d\",r=[\"function \",e,\"(A,b){return [\"],i=0;i<t;++i){r.push(\"det([\");for(var a=0;a<t;++a){a>0&&r.push(\",\"),r.push(\"[\");for(var o=0;o<t;++o)o>0&&r.push(\",\"),o===i?r.push(\"+b[\",a,\"]\"):r.push(\"+A[\",a,\"][\",o,\"]\");r.push(\"]\")}r.push(\"]),\")}r.push(\"det(A)]}return \",e);var s=new Function(\"det\",r.join(\"\"));return s(t<6?n[t]:n)}var o=[function(){return[0]},function(t,e){return[[e[0]],[t[0][0]]]}];!function(){for(;o.length<i;)o.push(a(o.length));for(var t=[],r=[\"function dispatchLinearSolve(A,b){switch(A.length){\"],n=0;n<i;++n)t.push(\"s\"+n),r.push(\"case \",n,\":return s\",n,\"(A,b);\");r.push(\"}var s=CACHE[A.length];if(!s)s=CACHE[A.length]=g(A.length);return s(A,b)}return dispatchLinearSolve\"),t.push(\"CACHE\",\"g\",r.join(\"\"));var s=Function.apply(void 0,t);for(e.exports=s.apply(void 0,o.concat([o,a])),n=0;n<i;++n)e.exports[n]=o[n]}()},{\"robust-determinant\":506}],510:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-subtract\"),s=5;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",c(t.slice(0,e)),\",\",c(t.slice(e)),\")\"].join(\"\")}function u(t){if(2===t.length)return[[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(u(l(t,r))),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function h(t){for(var e=[],r=[],s=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-1,\"]\"].join(\"\")}return e}(t),h=[],f=0;f<t;++f)0==(1&f)?e.push.apply(e,u(l(s,f))):r.push.apply(r,u(l(s,f))),h.push(\"m\"+f);var p=c(e),d=c(r),g=\"orientation\"+t+\"Exact\",v=[\"function \",g,\"(\",h.join(),\"){var p=\",p,\",n=\",d,\",d=sub(p,n);return d[d.length-1];};return \",g].join(\"\");return new Function(\"sum\",\"prod\",\"scale\",\"sub\",v)(i,n,a,o)}var f=h(3),p=h(4),d=[function(){return 0},function(){return 0},function(t,e){return e[0]-t[0]},function(t,e,r){var n,i=(t[1]-r[1])*(e[0]-r[0]),a=(t[0]-r[0])*(e[1]-r[1]),o=i-a;if(i>0){if(a<=0)return o;n=i+a}else{if(!(i<0))return o;if(a>=0)return o;n=-(i+a)}var s=3.3306690738754716e-16*n;return o>=s||o<=-s?o:f(t,e,r)},function(t,e,r,n){var i=t[0]-n[0],a=e[0]-n[0],o=r[0]-n[0],s=t[1]-n[1],l=e[1]-n[1],c=r[1]-n[1],u=t[2]-n[2],h=e[2]-n[2],f=r[2]-n[2],d=a*c,g=o*l,v=o*s,m=i*c,y=i*l,x=a*s,b=u*(d-g)+h*(v-m)+f*(y-x),_=7.771561172376103e-16*((Math.abs(d)+Math.abs(g))*Math.abs(u)+(Math.abs(v)+Math.abs(m))*Math.abs(h)+(Math.abs(y)+Math.abs(x))*Math.abs(f));return b>_||-b>_?b:p(t,e,r,n)}];!function(){for(;d.length<=s;)d.push(h(d.length));for(var t=[],r=[\"slow\"],n=0;n<=s;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function getOrientation(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=s;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return getOrientation\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[function(t){var e=d[t.length];return e||(e=d[t.length]=h(t.length)),e.apply(void 0,t)}].concat(d)),n=0;n<=s;++n)e.exports[n]=d[n]}()},{\"robust-scale\":512,\"robust-subtract\":514,\"robust-sum\":515,\"two-product\":543}],511:[function(t,e,r){\"use strict\";var n=t(\"robust-sum\"),i=t(\"robust-scale\");e.exports=function(t,e){if(1===t.length)return i(e,t[0]);if(1===e.length)return i(t,e[0]);if(0===t.length||0===e.length)return[0];var r=[0];if(t.length<e.length)for(var a=0;a<t.length;++a)r=n(r,i(e,t[a]));else for(var a=0;a<e.length;++a)r=n(r,i(t,e[a]));return r}},{\"robust-scale\":512,\"robust-sum\":515}],512:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"two-sum\");e.exports=function(t,e){var r=t.length;if(1===r){var a=n(t[0],e);return a[0]?a:[a[1]]}var o=new Array(2*r),s=[.1,.1],l=[.1,.1],c=0;n(t[0],e,s),s[0]&&(o[c++]=s[0]);for(var u=1;u<r;++u){n(t[u],e,l);var h=s[1];i(h,l[0],s),s[0]&&(o[c++]=s[0]);var f=l[1],p=s[1],d=f+p,g=d-f,v=p-g;s[1]=d,v&&(o[c++]=v)}s[1]&&(o[c++]=s[1]);0===c&&(o[c++]=0);return o.length=c,o}},{\"two-product\":543,\"two-sum\":544}],513:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){var a=n(t,r,i),o=n(e,r,i);if(a>0&&o>0||a<0&&o<0)return!1;var s=n(r,t,e),l=n(i,t,e);if(s>0&&l>0||s<0&&l<0)return!1;if(0===a&&0===o&&0===s&&0===l)return function(t,e,r,n){for(var i=0;i<2;++i){var a=t[i],o=e[i],s=Math.min(a,o),l=Math.max(a,o),c=r[i],u=n[i],h=Math.min(c,u),f=Math.max(c,u);if(f<s||l<h)return!1}return!0}(t,e,r,i);return!0};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":510}],514:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],-e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,h=t[l],f=u(h),p=-e[c],d=u(p);f<d?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=-e[c],d=u(p)));l<r&&f<d||c>=n?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p)));var g,v,m=i+a,y=m-i,x=a-y,b=x,_=m;for(;l<r&&c<n;)f<d?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p))),(x=(a=b)-(y=(m=i+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g;for(;l<r;)(x=(a=b)-(y=(m=(i=h)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(l+=1)<r&&(h=t[l]);for(;c<n;)(x=(a=b)-(y=(m=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(c+=1)<n&&(p=-e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],515:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,h=t[l],f=u(h),p=e[c],d=u(p);f<d?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=e[c],d=u(p)));l<r&&f<d||c>=n?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=e[c],d=u(p)));var g,v,m=i+a,y=m-i,x=a-y,b=x,_=m;for(;l<r&&c<n;)f<d?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=e[c],d=u(p))),(x=(a=b)-(y=(m=i+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g;for(;l<r;)(x=(a=b)-(y=(m=(i=h)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(l+=1)<r&&(h=t[l]);for(;c<n;)(x=(a=b)-(y=(m=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(c+=1)<n&&(p=e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],516:[function(t,e,r){\"use strict\";e.exports=function(t){return t<0?-1:t>0?1:0}},{}],517:[function(t,e,r){\"use strict\";e.exports=function(t){return i(n(t))};var n=t(\"boundary-cells\"),i=t(\"reduce-simplicial-complex\")},{\"boundary-cells\":95,\"reduce-simplicial-complex\":489}],518:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,s){r=r||0,\"undefined\"==typeof s&&(s=function(t){for(var e=t.length,r=0,n=0;n<e;++n)r=0|Math.max(r,t[n].length);return r-1}(t));if(0===t.length||s<1)return{cells:[],vertexIds:[],vertexWeights:[]};var l=function(t,e){for(var r=t.length,n=i.mallocUint8(r),a=0;a<r;++a)n[a]=t[a]<e|0;return n}(e,+r),c=function(t,e){for(var r=t.length,o=e*(e+1)/2*r|0,s=i.mallocUint32(2*o),l=0,c=0;c<r;++c)for(var u=t[c],e=u.length,h=0;h<e;++h)for(var f=0;f<h;++f){var p=u[f],d=u[h];s[l++]=0|Math.min(p,d),s[l++]=0|Math.max(p,d)}a(n(s,[l/2|0,2]));for(var g=2,c=2;c<l;c+=2)s[c-2]===s[c]&&s[c-1]===s[c+1]||(s[g++]=s[c],s[g++]=s[c+1]);return n(s,[g/2|0,2])}(t,s),u=function(t,e,r,a){for(var o=t.data,s=t.shape[0],l=i.mallocDouble(s),c=0,u=0;u<s;++u){var h=o[2*u],f=o[2*u+1];if(r[h]!==r[f]){var p=e[h],d=e[f];o[2*c]=h,o[2*c+1]=f,l[c++]=(d-a)/(d-p)}}return t.shape[0]=c,n(l,[c])}(c,e,l,+r),h=function(t,e){var r=i.mallocInt32(2*e),n=t.shape[0],a=t.data;r[0]=0;for(var o=0,s=0;s<n;++s){var l=a[2*s];if(l!==o){for(r[2*o+1]=s;++o<l;)r[2*o]=s,r[2*o+1]=s;r[2*o]=s}}r[2*o+1]=n;for(;++o<e;)r[2*o]=r[2*o+1]=n;return r}(c,0|e.length),f=o(s)(t,c.data,h,l),p=function(t){for(var e=0|t.shape[0],r=t.data,n=new Array(e),i=0;i<e;++i)n[i]=[r[2*i],r[2*i+1]];return n}(c),d=[].slice.call(u.data,0,u.shape[0]);return i.free(l),i.free(c.data),i.free(u.data),i.free(h),{cells:f,vertexIds:p,vertexWeights:d}};var n=t(\"ndarray\"),i=t(\"typedarray-pool\"),a=t(\"ndarray-sort\"),o=t(\"./lib/codegen\")},{\"./lib/codegen\":519,ndarray:450,\"ndarray-sort\":448,\"typedarray-pool\":545}],519:[function(t,e,r){\"use strict\";e.exports=function(t){var e=a[t];e||(e=a[t]=function(t){var e=0,r=new Array(t+1);r[0]=[[]];for(var a=1;a<=t;++a)for(var o=r[a]=i(a),s=0;s<o.length;++s)e=Math.max(e,o[a].length);var l=[\"function B(C,E,i,j){\",\"var a=Math.min(i,j)|0,b=Math.max(i,j)|0,l=C[2*a],h=C[2*a+1];\",\"while(l<h){\",\"var m=(l+h)>>1,v=E[2*m+1];\",\"if(v===b){return m}\",\"if(b<v){h=m}else{l=m+1}\",\"}\",\"return l;\",\"};\",\"function getContour\",t,\"d(F,E,C,S){\",\"var n=F.length,R=[];\",\"for(var i=0;i<n;++i){var c=F[i],l=c.length;\"];function c(t){if(!(t.length<=0)){l.push(\"R.push(\");for(var e=0;e<t.length;++e){var r=t[e];e>0&&l.push(\",\"),l.push(\"[\");for(var n=0;n<r.length;++n){var i=r[n];n>0&&l.push(\",\"),l.push(\"B(C,E,c[\",i[0],\"],c[\",i[1],\"])\")}l.push(\"]\")}l.push(\");\")}}for(var a=t+1;a>1;--a){a<t+1&&l.push(\"else \"),l.push(\"if(l===\",a,\"){\");for(var u=[],s=0;s<a;++s)u.push(\"(S[c[\"+s+\"]]<<\"+s+\")\");l.push(\"var M=\",u.join(\"+\"),\";if(M===0||M===\",(1<<a)-1,\"){continue}switch(M){\");for(var o=r[a-1],s=0;s<o.length;++s)l.push(\"case \",s,\":\"),c(o[s]),l.push(\"break;\");l.push(\"}}\")}return l.push(\"}return R;};return getContour\",t,\"d\"),new Function(\"pool\",l.join(\"\"))(n)}(t));return e};var n=t(\"typedarray-pool\"),i=t(\"marching-simplex-table\"),a={}},{\"marching-simplex-table\":427,\"typedarray-pool\":545}],520:[function(t,e,r){\"use strict\";var n=t(\"bit-twiddle\"),i=t(\"union-find\");function a(t,e){var r=t.length,n=t.length-e.length,i=Math.min;if(n)return n;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return(s=t[0]+t[1]-e[0]-e[1])||i(t[0],t[1])-i(e[0],e[1]);case 3:var a=t[0]+t[1],o=e[0]+e[1];if(s=a+t[2]-(o+e[2]))return s;var s,l=i(t[0],t[1]),c=i(e[0],e[1]);return(s=i(l,t[2])-i(c,e[2]))||i(l+t[2],a)-i(c+e[2],o);default:var u=t.slice(0);u.sort();var h=e.slice(0);h.sort();for(var f=0;f<r;++f)if(n=u[f]-h[f])return n;return 0}}function o(t,e){return a(t[0],e[0])}function s(t,e){if(e){for(var r=t.length,n=new Array(r),i=0;i<r;++i)n[i]=[t[i],e[i]];n.sort(o);for(i=0;i<r;++i)t[i]=n[i][0],e[i]=n[i][1];return t}return t.sort(a),t}function l(t){if(0===t.length)return[];for(var e=1,r=t.length,n=1;n<r;++n){var i=t[n];if(a(i,t[n-1])){if(n===e){e++;continue}t[e++]=i}}return t.length=e,t}function c(t,e){for(var r=0,n=t.length-1,i=-1;r<=n;){var o=r+n>>1,s=a(t[o],e);s<=0?(0===s&&(i=o),r=o+1):s>0&&(n=o-1)}return i}function u(t,e){for(var r=new Array(t.length),i=0,o=r.length;i<o;++i)r[i]=[];for(var s=[],l=(i=0,e.length);i<l;++i)for(var u=e[i],h=u.length,f=1,p=1<<h;f<p;++f){s.length=n.popCount(f);for(var d=0,g=0;g<h;++g)f&1<<g&&(s[d++]=u[g]);var v=c(t,s);if(!(v<0))for(;r[v++].push(i),!(v>=t.length||0!==a(t[v],s)););}return r}function h(t,e){if(e<0)return[];for(var r=[],i=(1<<e+1)-1,a=0;a<t.length;++a)for(var o=t[a],l=i;l<1<<o.length;l=n.nextCombination(l)){for(var c=new Array(e+1),u=0,h=0;h<o.length;++h)l&1<<h&&(c[u++]=o[h]);r.push(c)}return s(r)}r.dimension=function(t){for(var e=0,r=Math.max,n=0,i=t.length;n<i;++n)e=r(e,t[n].length);return e-1},r.countVertices=function(t){for(var e=-1,r=Math.max,n=0,i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)e=r(e,a[o]);return e+1},r.cloneCells=function(t){for(var e=new Array(t.length),r=0,n=t.length;r<n;++r)e[r]=t[r].slice(0);return e},r.compareCells=a,r.normalize=s,r.unique=l,r.findCell=c,r.incidence=u,r.dual=function(t,e){if(!e)return u(l(h(t,0)),t);for(var r=new Array(e),n=0;n<e;++n)r[n]=[];n=0;for(var i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)r[a[o]].push(n);return r},r.explode=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0|i.length,o=1,l=1<<a;o<l;++o){for(var c=[],u=0;u<a;++u)o>>>u&1&&c.push(i[u]);e.push(c)}return s(e)},r.skeleton=h,r.boundary=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;++a){for(var l=new Array(i.length-1),c=0,u=0;c<o;++c)c!==a&&(l[u++]=i[c]);e.push(l)}return s(e)},r.connectedComponents=function(t,e){return e?function(t,e){for(var r=new i(e),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var s=o+1;s<a.length;++s)r.link(a[o],a[s]);var l=[],c=r.ranks;for(n=0;n<c.length;++n)c[n]=-1;for(n=0;n<t.length;++n){var u=r.find(t[n][0]);c[u]<0?(c[u]=l.length,l.push([t[n].slice(0)])):l[c[u]].push(t[n].slice(0))}return l}(t,e):function(t){for(var e=l(s(h(t,0))),r=new i(e.length),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var u=c(e,[a[o]]),f=o+1;f<a.length;++f)r.link(u,c(e,[a[f]]));var p=[],d=r.ranks;for(n=0;n<d.length;++n)d[n]=-1;for(n=0;n<t.length;++n){var g=r.find(c(e,[t[n][0]]));d[g]<0?(d[g]=p.length,p.push([t[n].slice(0)])):p[d[g]].push(t[n].slice(0))}return p}(t)}},{\"bit-twiddle\":92,\"union-find\":546}],521:[function(t,e,r){arguments[4][92][0].apply(r,arguments)},{dup:92}],522:[function(t,e,r){arguments[4][520][0].apply(r,arguments)},{\"bit-twiddle\":521,dup:520,\"union-find\":523}],523:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n,n.prototype.length=function(){return this.roots.length},n.prototype.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},n.prototype.find=function(t){for(var e=this.roots;e[t]!==t;){var r=e[t];e[t]=e[r],t=r}return t},n.prototype.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],524:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){for(var a=e.length,o=t.length,s=new Array(a),l=new Array(a),c=new Array(a),u=new Array(a),h=0;h<a;++h)s[h]=l[h]=-1,c[h]=1/0,u[h]=!1;for(var h=0;h<o;++h){var f=t[h];if(2!==f.length)throw new Error(\"Input must be a graph\");var p=f[1],d=f[0];-1!==l[d]?l[d]=-2:l[d]=p,-1!==s[p]?s[p]=-2:s[p]=d}function g(t){if(u[t])return 1/0;var r,i,a,o,c,h=s[t],f=l[t];return h<0||f<0?1/0:(r=e[t],i=e[h],a=e[f],o=Math.abs(n(r,i,a)),c=Math.sqrt(Math.pow(i[0]-a[0],2)+Math.pow(i[1]-a[1],2)),o/c)}function v(t,e){var r=T[t],n=T[e];T[t]=n,T[e]=r,A[r]=e,A[n]=t}function m(t){return c[T[t]]}function y(t){return 1&t?t-1>>1:(t>>1)-1}function x(t){for(var e=m(t);;){var r=e,n=2*t+1,i=2*(t+1),a=t;if(n<S){var o=m(n);o<r&&(a=n,r=o)}if(i<S){var s=m(i);s<r&&(a=i)}if(a===t)return t;v(t,a),t=a}}function b(t){for(var e=m(t);t>0;){var r=y(t);if(r>=0){var n=m(r);if(e<n){v(t,r),t=r;continue}}return t}}function _(){if(S>0){var t=T[0];return v(0,S-1),S-=1,x(0),t}return-1}function w(t,e){var r=T[t];return c[r]===e?t:(c[r]=-1/0,b(t),_(),c[r]=e,b((S+=1)-1))}function k(t){if(!u[t]){u[t]=!0;var e=s[t],r=l[t];s[r]>=0&&(s[r]=e),l[e]>=0&&(l[e]=r),A[e]>=0&&w(A[e],g(e)),A[r]>=0&&w(A[r],g(r))}}for(var T=[],A=new Array(a),h=0;h<a;++h){var M=c[h]=g(h);M<1/0?(A[h]=T.length,T.push(h)):A[h]=-1}for(var S=T.length,h=S>>1;h>=0;--h)x(h);for(;;){var E=_();if(E<0||c[E]>r)break;k(E)}for(var C=[],h=0;h<a;++h)u[h]||(A[h]=C.length,C.push(e[h].slice()));C.length;function L(t,e){if(t[e]<0)return e;var r=e,n=e;do{var i=t[n];if(!u[n]||i<0||i===n)break;if(i=t[n=i],!u[n]||i<0||i===n)break;n=i,r=t[r]}while(r!==n);for(var a=e;a!==n;a=t[a])t[a]=n;return n}var P=[];return t.forEach(function(t){var e=L(s,t[0]),r=L(l,t[1]);if(e>=0&&r>=0&&e!==r){var n=A[e],i=A[r];n!==i&&P.push([n,i])}}),i.unique(i.normalize(P)),{positions:C,edges:P}};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\")},{\"robust-orientation\":510,\"simplicial-complex\":522}],525:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,a,o,s;if(e[0][0]<e[1][0])r=e[0],a=e[1];else{if(!(e[0][0]>e[1][0]))return i(e,t);r=e[1],a=e[0]}if(t[0][0]<t[1][0])o=t[0],s=t[1];else{if(!(t[0][0]>t[1][0]))return-i(t,e);o=t[1],s=t[0]}var l=n(r,a,s),c=n(r,a,o);if(l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;if(l=n(s,o,a),c=n(s,o,r),l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;return a[0]-s[0]};var n=t(\"robust-orientation\");function i(t,e){var r,i,a,o;if(e[0][0]<e[1][0])r=e[0],i=e[1];else{if(!(e[0][0]>e[1][0])){var s=Math.min(t[0][1],t[1][1]),l=Math.max(t[0][1],t[1][1]),c=Math.min(e[0][1],e[1][1]),u=Math.max(e[0][1],e[1][1]);return l<c?l-c:s>u?s-u:l-u}r=e[1],i=e[0]}t[0][1]<t[1][1]?(a=t[0],o=t[1]):(a=t[1],o=t[0]);var h=n(i,r,a);return h||((h=n(i,r,o))||o-i)}},{\"robust-orientation\":510}],526:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=2*e,n=new Array(r),a=0;a<e;++a){var l=t[a],c=l[0][0]<l[1][0];n[2*a]=new h(l[0][0],l,c,a),n[2*a+1]=new h(l[1][0],l,!c,a)}n.sort(function(t,e){var r=t.x-e.x;return r||((r=t.create-e.create)||Math.min(t.segment[0][1],t.segment[1][1])-Math.min(e.segment[0][1],e.segment[1][1]))});for(var f=i(o),p=[],d=[],g=[],a=0;a<r;){for(var v=n[a].x,m=[];a<r;){var y=n[a];if(y.x!==v)break;a+=1,y.segment[0][0]===y.x&&y.segment[1][0]===y.x?y.create&&(y.segment[0][1]<y.segment[1][1]?(m.push(new u(y.segment[0][1],y.index,!0,!0)),m.push(new u(y.segment[1][1],y.index,!1,!1))):(m.push(new u(y.segment[1][1],y.index,!0,!1)),m.push(new u(y.segment[0][1],y.index,!1,!0)))):f=y.create?f.insert(y.segment,y.index):f.remove(y.segment)}p.push(f.root),d.push(v),g.push(m)}return new s(p,d,g)};var n=t(\"binary-search-bounds\"),i=t(\"functional-red-black-tree\"),a=t(\"robust-orientation\"),o=t(\"./lib/order-segments\");function s(t,e,r){this.slabs=t,this.coordinates=e,this.horizontal=r}function l(t,e){return t.y-e}function c(t,e){for(var r=null;t;){var n,i,o=t.key;o[0][0]<o[1][0]?(n=o[0],i=o[1]):(n=o[1],i=o[0]);var s=a(n,i,e);if(s<0)t=t.left;else if(s>0)if(e[0]!==o[1][0])r=t,t=t.right;else{if(l=c(t.right,e))return l;t=t.left}else{if(e[0]!==o[1][0])return t;var l;if(l=c(t.right,e))return l;t=t.left}}return r}function u(t,e,r,n){this.y=t,this.index=e,this.start=r,this.closed=n}function h(t,e,r,n){this.x=t,this.segment=e,this.create=r,this.index=n}s.prototype.castUp=function(t){var e=n.le(this.coordinates,t[0]);if(e<0)return-1;this.slabs[e];var r=c(this.slabs[e],t),i=-1;if(r&&(i=r.value),this.coordinates[e]===t[0]){var s=null;if(r&&(s=r.key),e>0){var u=c(this.slabs[e-1],t);u&&(s?o(u.key,s)>0&&(s=u.key,i=u.value):(i=u.value,s=u.key))}var h=this.horizontal[e];if(h.length>0){var f=n.ge(h,t[1],l);if(f<h.length){var p=h[f];if(t[1]===p.y){if(p.closed)return p.index;for(;f<h.length-1&&h[f+1].y===t[1];)if((p=h[f+=1]).closed)return p.index;if(p.y===t[1]&&!p.start){if((f+=1)>=h.length)return i;p=h[f]}}if(p.start)if(s){var d=a(s[0],s[1],[t[0],p.y]);s[0][0]>s[1][0]&&(d=-d),d>0&&(i=p.index)}else i=p.index;else p.y!==t[1]&&(i=p.index)}}}return i}},{\"./lib/order-segments\":525,\"binary-search-bounds\":91,\"functional-red-black-tree\":230,\"robust-orientation\":510}],527:[function(t,e,r){\"use strict\";var n=t(\"robust-dot-product\"),i=t(\"robust-sum\");function a(t,e){var r=i(n(t,e),[e[e.length-1]]);return r[r.length-1]}function o(t,e,r,n){var i=-e/(n-e);i<0?i=0:i>1&&(i=1);for(var a=1-i,o=t.length,s=new Array(o),l=0;l<o;++l)s[l]=i*t[l]+a*r[l];return s}e.exports=function(t,e){for(var r=[],n=[],i=a(t[t.length-1],e),s=t[t.length-1],l=t[0],c=0;c<t.length;++c,s=l){var u=a(l=t[c],e);if(i<0&&u>0||i>0&&u<0){var h=o(s,u,l,i);r.push(h),n.push(h.slice())}u<0?n.push(l.slice()):u>0?r.push(l.slice()):(r.push(l.slice()),n.push(l.slice())),i=u}return{positive:r,negative:n}},e.exports.positive=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c>=0&&r.push(s.slice()),n=c}return r},e.exports.negative=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c<=0&&r.push(s.slice()),n=c}return r}},{\"robust-dot-product\":507,\"robust-sum\":515}],528:[function(t,e,r){!function(){\"use strict\";var t={not_string:/[^s]/,not_bool:/[^t]/,not_type:/[^T]/,not_primitive:/[^v]/,number:/[diefg]/,numeric_arg:/[bcdiefguxX]/,json:/[j]/,not_json:/[^j]/,text:/^[^\\x25]+/,modulo:/^\\x25{2}/,placeholder:/^\\x25(?:([1-9]\\d*)\\$|\\(([^)]+)\\))?(\\+)?(0|'[^$])?(-)?(\\d+)?(?:\\.(\\d+))?([b-gijostTuvxX])/,key:/^([a-z_][a-z_\\d]*)/i,key_access:/^\\.([a-z_][a-z_\\d]*)/i,index_access:/^\\[(\\d+)\\]/,sign:/^[+-]/};function e(r){return function(r,n){var i,a,o,s,l,c,u,h,f,p=1,d=r.length,g=\"\";for(a=0;a<d;a++)if(\"string\"==typeof r[a])g+=r[a];else if(\"object\"==typeof r[a]){if((s=r[a]).keys)for(i=n[p],o=0;o<s.keys.length;o++){if(null==i)throw new Error(e('[sprintf] Cannot access property \"%s\" of undefined value \"%s\"',s.keys[o],s.keys[o-1]));i=i[s.keys[o]]}else i=s.param_no?n[s.param_no]:n[p++];if(t.not_type.test(s.type)&&t.not_primitive.test(s.type)&&i instanceof Function&&(i=i()),t.numeric_arg.test(s.type)&&\"number\"!=typeof i&&isNaN(i))throw new TypeError(e(\"[sprintf] expecting number but found %T\",i));switch(t.number.test(s.type)&&(h=i>=0),s.type){case\"b\":i=parseInt(i,10).toString(2);break;case\"c\":i=String.fromCharCode(parseInt(i,10));break;case\"d\":case\"i\":i=parseInt(i,10);break;case\"j\":i=JSON.stringify(i,null,s.width?parseInt(s.width):0);break;case\"e\":i=s.precision?parseFloat(i).toExponential(s.precision):parseFloat(i).toExponential();break;case\"f\":i=s.precision?parseFloat(i).toFixed(s.precision):parseFloat(i);break;case\"g\":i=s.precision?String(Number(i.toPrecision(s.precision))):parseFloat(i);break;case\"o\":i=(parseInt(i,10)>>>0).toString(8);break;case\"s\":i=String(i),i=s.precision?i.substring(0,s.precision):i;break;case\"t\":i=String(!!i),i=s.precision?i.substring(0,s.precision):i;break;case\"T\":i=Object.prototype.toString.call(i).slice(8,-1).toLowerCase(),i=s.precision?i.substring(0,s.precision):i;break;case\"u\":i=parseInt(i,10)>>>0;break;case\"v\":i=i.valueOf(),i=s.precision?i.substring(0,s.precision):i;break;case\"x\":i=(parseInt(i,10)>>>0).toString(16);break;case\"X\":i=(parseInt(i,10)>>>0).toString(16).toUpperCase()}t.json.test(s.type)?g+=i:(!t.number.test(s.type)||h&&!s.sign?f=\"\":(f=h?\"+\":\"-\",i=i.toString().replace(t.sign,\"\")),c=s.pad_char?\"0\"===s.pad_char?\"0\":s.pad_char.charAt(1):\" \",u=s.width-(f+i).length,l=s.width&&u>0?c.repeat(u):\"\",g+=s.align?f+i+l:\"0\"===c?f+l+i:l+f+i)}return g}(function(e){if(i[e])return i[e];var r,n=e,a=[],o=0;for(;n;){if(null!==(r=t.text.exec(n)))a.push(r[0]);else if(null!==(r=t.modulo.exec(n)))a.push(\"%\");else{if(null===(r=t.placeholder.exec(n)))throw new SyntaxError(\"[sprintf] unexpected placeholder\");if(r[2]){o|=1;var s=[],l=r[2],c=[];if(null===(c=t.key.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");for(s.push(c[1]);\"\"!==(l=l.substring(c[0].length));)if(null!==(c=t.key_access.exec(l)))s.push(c[1]);else{if(null===(c=t.index_access.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");s.push(c[1])}r[2]=s}else o|=2;if(3===o)throw new Error(\"[sprintf] mixing positional and named placeholders is not (yet) supported\");a.push({placeholder:r[0],param_no:r[1],keys:r[2],sign:r[3],pad_char:r[4],align:r[5],width:r[6],precision:r[7],type:r[8]})}n=n.substring(r[0].length)}return i[e]=a}(r),arguments)}function n(t,r){return e.apply(null,[t].concat(r||[]))}var i=Object.create(null);\"undefined\"!=typeof r&&(r.sprintf=e,r.vsprintf=n),\"undefined\"!=typeof window&&(window.sprintf=e,window.vsprintf=n)}()},{}],529:[function(t,e,r){\"use strict\";var n=t(\"parenthesis\");e.exports=function(t,e,r){if(null==t)throw Error(\"First argument should be a string\");if(null==e)throw Error(\"Separator should be a string or a RegExp\");r?(\"string\"==typeof r||Array.isArray(r))&&(r={ignore:r}):r={},null==r.escape&&(r.escape=!0),null==r.ignore?r.ignore=[\"[]\",\"()\",\"{}\",\"<>\",'\"\"',\"''\",\"``\",\"\\u201c\\u201d\",\"\\xab\\xbb\"]:(\"string\"==typeof r.ignore&&(r.ignore=[r.ignore]),r.ignore=r.ignore.map(function(t){return 1===t.length&&(t+=t),t}));var i=n.parse(t,{flat:!0,brackets:r.ignore}),a=i[0].split(e);if(r.escape){for(var o=[],s=0;s<a.length;s++){var l=a[s],c=a[s+1];\"\\\\\"===l[l.length-1]&&\"\\\\\"!==l[l.length-2]?(o.push(l+e+c),s++):o.push(l)}a=o}for(s=0;s<a.length;s++)i[0]=a[s],a[s]=n.stringify(i,{flat:!0});return a}},{parenthesis:458}],530:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=new Array(e),n=new Array(e),i=new Array(e),a=new Array(e),o=new Array(e),s=new Array(e),l=0;l<e;++l)r[l]=-1,n[l]=0,i[l]=!1,a[l]=0,o[l]=-1,s[l]=[];var c,u=0,h=[],f=[];function p(e){var l=[e],c=[e];for(r[e]=n[e]=u,i[e]=!0,u+=1;c.length>0;){e=c[c.length-1];var p=t[e];if(a[e]<p.length){for(var d=a[e];d<p.length;++d){var g=p[d];if(r[g]<0){r[g]=n[g]=u,i[g]=!0,u+=1,l.push(g),c.push(g);break}i[g]&&(n[e]=0|Math.min(n[e],n[g])),o[g]>=0&&s[e].push(o[g])}a[e]=d}else{if(n[e]===r[e]){for(var v=[],m=[],y=0,d=l.length-1;d>=0;--d){var x=l[d];if(i[x]=!1,v.push(x),m.push(s[x]),y+=s[x].length,o[x]=h.length,x===e){l.length=d;break}}h.push(v);for(var b=new Array(y),d=0;d<m.length;d++)for(var _=0;_<m[d].length;_++)b[--y]=m[d][_];f.push(b)}c.pop()}}}for(var l=0;l<e;++l)r[l]<0&&p(l);for(var l=0;l<f.length;l++){var d=f[l];if(0!==d.length){d.sort(function(t,e){return t-e}),c=[d[0]];for(var g=1;g<d.length;g++)d[g]!==d[g-1]&&c.push(d[g]);f[l]=c}}return{components:h,adjacencyList:f}}},{}],531:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(t.dimension<=0)return{positions:[],cells:[]};if(1===t.dimension)return function(t,e){for(var r=a(t,e),n=r.length,i=new Array(n),o=new Array(n),s=0;s<n;++s)i[s]=[r[s]],o[s]=[s];return{positions:i,cells:o}}(t,e);var r=t.order.join()+\"-\"+t.dtype,s=o[r],e=+e||0;s||(s=o[r]=function(t,e){var r=t.length,a=[\"'use strict';\"],o=\"surfaceNets\"+t.join(\"_\")+\"d\"+e;a.push(\"var contour=genContour({\",\"order:[\",t.join(),\"],\",\"scalarArguments: 3,\",\"phase:function phaseFunc(p,a,b,c) { return (p > c)|0 },\"),\"generic\"===e&&a.push(\"getters:[0],\");for(var s=[],l=[],c=0;c<r;++c)s.push(\"d\"+c),l.push(\"d\"+c);for(var c=0;c<1<<r;++c)s.push(\"v\"+c),l.push(\"v\"+c);for(var c=0;c<1<<r;++c)s.push(\"p\"+c),l.push(\"p\"+c);s.push(\"a\",\"b\",\"c\"),l.push(\"a\",\"c\"),a.push(\"vertex:function vertexFunc(\",s.join(),\"){\");for(var u=[],c=0;c<1<<r;++c)u.push(\"(p\"+c+\"<<\"+c+\")\");a.push(\"var m=(\",u.join(\"+\"),\")|0;if(m===0||m===\",(1<<(1<<r))-1,\"){return}\");var h=[],f=[];1<<(1<<r)<=128?(a.push(\"switch(m){\"),f=a):a.push(\"switch(m>>>7){\");for(var c=0;c<1<<(1<<r);++c){if(1<<(1<<r)>128&&c%128==0){h.length>0&&f.push(\"}}\");var p=\"vExtra\"+h.length;a.push(\"case \",c>>>7,\":\",p,\"(m&0x7f,\",l.join(),\");break;\"),f=[\"function \",p,\"(m,\",l.join(),\"){switch(m){\"],h.push(f)}f.push(\"case \",127&c,\":\");for(var d=new Array(r),g=new Array(r),v=new Array(r),m=new Array(r),y=0,x=0;x<r;++x)d[x]=[],g[x]=[],v[x]=0,m[x]=0;for(var x=0;x<1<<r;++x)for(var b=0;b<r;++b){var _=x^1<<b;if(!(_>x)&&!(c&1<<_)!=!(c&1<<x)){var w=1;c&1<<_?g[b].push(\"v\"+_+\"-v\"+x):(g[b].push(\"v\"+x+\"-v\"+_),w=-w),w<0?(d[b].push(\"-v\"+x+\"-v\"+_),v[b]+=2):(d[b].push(\"v\"+x+\"+v\"+_),v[b]-=2),y+=1;for(var k=0;k<r;++k)k!==b&&(_&1<<k?m[k]+=1:m[k]-=1)}}for(var T=[],b=0;b<r;++b)if(0===d[b].length)T.push(\"d\"+b+\"-0.5\");else{var A=\"\";v[b]<0?A=v[b]+\"*c\":v[b]>0&&(A=\"+\"+v[b]+\"*c\");var M=d[b].length/y*.5,S=.5+m[b]/y*.5;T.push(\"d\"+b+\"-\"+S+\"-\"+M+\"*(\"+d[b].join(\"+\")+A+\")/(\"+g[b].join(\"+\")+\")\")}f.push(\"a.push([\",T.join(),\"]);\",\"break;\")}a.push(\"}},\"),h.length>0&&f.push(\"}}\");for(var E=[],c=0;c<1<<r-1;++c)E.push(\"v\"+c);E.push(\"c0\",\"c1\",\"p0\",\"p1\",\"a\",\"b\",\"c\"),a.push(\"cell:function cellFunc(\",E.join(),\"){\");var C=i(r-1);a.push(\"if(p0){b.push(\",C.map(function(t){return\"[\"+t.map(function(t){return\"v\"+t})+\"]\"}).join(),\")}else{b.push(\",C.map(function(t){var e=t.slice();return e.reverse(),\"[\"+e.map(function(t){return\"v\"+t})+\"]\"}).join(),\")}}});function \",o,\"(array,level){var verts=[],cells=[];contour(array,verts,cells,level);return {positions:verts,cells:cells};} return \",o,\";\");for(var c=0;c<h.length;++c)a.push(h[c].join(\"\"));return new Function(\"genContour\",a.join(\"\"))(n)}(t.order,t.dtype));return s(t,e)};var n=t(\"ndarray-extract-contour\"),i=t(\"triangulate-hypercube\"),a=t(\"zero-crossings\");var o={}},{\"ndarray-extract-contour\":439,\"triangulate-hypercube\":541,\"zero-crossings\":574}],532:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=function(){return function(t,e){if(Array.isArray(t))return t;if(Symbol.iterator in Object(t))return function(t,e){var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{!n&&s.return&&s.return()}finally{if(i)throw a}}return r}(t,e);throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")}}(),i=2*Math.PI,a=function(t,e,r,n,i,a,o){var s=t.x,l=t.y;return{x:n*(s*=e)-i*(l*=r)+a,y:i*s+n*l+o}},o=function(t,e){var r=.551915024494*(e<0?-1:1),n=Math.cos(t),i=Math.sin(t),a=Math.cos(t+e),o=Math.sin(t+e);return[{x:n-i*r,y:i+n*r},{x:a+o*r,y:o-a*r},{x:a,y:o}]},s=function(t,e,r,n){var i=t*n-e*r<0?-1:1,a=(t*r+e*n)/(Math.sqrt(t*t+e*e)*Math.sqrt(t*t+e*e));return a>1&&(a=1),a<-1&&(a=-1),i*Math.acos(a)};r.default=function(t){var e=t.px,r=t.py,l=t.cx,c=t.cy,u=t.rx,h=t.ry,f=t.xAxisRotation,p=void 0===f?0:f,d=t.largeArcFlag,g=void 0===d?0:d,v=t.sweepFlag,m=void 0===v?0:v,y=[];if(0===u||0===h)return[];var x=Math.sin(p*i/360),b=Math.cos(p*i/360),_=b*(e-l)/2+x*(r-c)/2,w=-x*(e-l)/2+b*(r-c)/2;if(0===_&&0===w)return[];u=Math.abs(u),h=Math.abs(h);var k=Math.pow(_,2)/Math.pow(u,2)+Math.pow(w,2)/Math.pow(h,2);k>1&&(u*=Math.sqrt(k),h*=Math.sqrt(k));var T=function(t,e,r,n,a,o,l,c,u,h,f,p){var d=Math.pow(a,2),g=Math.pow(o,2),v=Math.pow(f,2),m=Math.pow(p,2),y=d*g-d*m-g*v;y<0&&(y=0),y/=d*m+g*v;var x=(y=Math.sqrt(y)*(l===c?-1:1))*a/o*p,b=y*-o/a*f,_=h*x-u*b+(t+r)/2,w=u*x+h*b+(e+n)/2,k=(f-x)/a,T=(p-b)/o,A=(-f-x)/a,M=(-p-b)/o,S=s(1,0,k,T),E=s(k,T,A,M);return 0===c&&E>0&&(E-=i),1===c&&E<0&&(E+=i),[_,w,S,E]}(e,r,l,c,u,h,g,m,x,b,_,w),A=n(T,4),M=A[0],S=A[1],E=A[2],C=A[3],L=Math.abs(C)/(i/4);Math.abs(1-L)<1e-7&&(L=1);var P=Math.max(Math.ceil(L),1);C/=P;for(var O=0;O<P;O++)y.push(o(E,C)),E+=C;return y.map(function(t){var e=a(t[0],u,h,b,x,M,S),r=e.x,n=e.y,i=a(t[1],u,h,b,x,M,S),o=i.x,s=i.y,l=a(t[2],u,h,b,x,M,S);return{x1:r,y1:n,x2:o,y2:s,x:l.x,y:l.y}})},e.exports=r.default},{}],533:[function(t,e,r){\"use strict\";var n=t(\"parse-svg-path\"),i=t(\"abs-svg-path\"),a=t(\"normalize-svg-path\"),o=t(\"is-svg-path\"),s=t(\"assert\");e.exports=function(t){Array.isArray(t)&&1===t.length&&\"string\"==typeof t[0]&&(t=t[0]);\"string\"==typeof t&&(s(o(t),\"String is not an SVG path.\"),t=n(t));if(s(Array.isArray(t),\"Argument should be a string or an array of path segments.\"),t=i(t),!(t=a(t)).length)return[0,0,0,0];for(var e=[1/0,1/0,-1/0,-1/0],r=0,l=t.length;r<l;r++)for(var c=t[r].slice(1),u=0;u<c.length;u+=2)c[u+0]<e[0]&&(e[0]=c[u+0]),c[u+1]<e[1]&&(e[1]=c[u+1]),c[u+0]>e[2]&&(e[2]=c[u+0]),c[u+1]>e[3]&&(e[3]=c[u+1]);return e}},{\"abs-svg-path\":60,assert:68,\"is-svg-path\":424,\"normalize-svg-path\":534,\"parse-svg-path\":460}],534:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=[],o=0,s=0,l=0,c=0,u=null,h=null,f=0,p=0,d=0,g=t.length;d<g;d++){var v=t[d],m=v[0];switch(m){case\"M\":l=v[1],c=v[2];break;case\"A\":var y=n({px:f,py:p,cx:v[6],cy:v[7],rx:v[1],ry:v[2],xAxisRotation:v[3],largeArcFlag:v[4],sweepFlag:v[5]});if(!y.length)continue;for(var x,b=0;b<y.length;b++)x=y[b],v=[\"C\",x.x1,x.y1,x.x2,x.y2,x.x,x.y],b<y.length-1&&r.push(v);break;case\"S\":var _=f,w=p;\"C\"!=e&&\"S\"!=e||(_+=_-o,w+=w-s),v=[\"C\",_,w,v[1],v[2],v[3],v[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(u=2*f-u,h=2*p-h):(u=f,h=p),v=a(f,p,u,h,v[1],v[2]);break;case\"Q\":u=v[1],h=v[2],v=a(f,p,v[1],v[2],v[3],v[4]);break;case\"L\":v=i(f,p,v[1],v[2]);break;case\"H\":v=i(f,p,v[1],p);break;case\"V\":v=i(f,p,f,v[1]);break;case\"Z\":v=i(f,p,l,c)}e=m,f=v[v.length-2],p=v[v.length-1],v.length>4?(o=v[v.length-4],s=v[v.length-3]):(o=f,s=p),r.push(v)}return r};var n=t(\"svg-arc-to-cubic-bezier\");function i(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function a(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}},{\"svg-arc-to-cubic-bezier\":532}],535:[function(t,e,r){\"use strict\";var n,i=t(\"svg-path-bounds\"),a=t(\"parse-svg-path\"),o=t(\"draw-svg-path\"),s=t(\"is-svg-path\"),l=t(\"bitmap-sdf\"),c=document.createElement(\"canvas\"),u=c.getContext(\"2d\");e.exports=function(t,e){if(!s(t))throw Error(\"Argument should be valid svg path string\");e||(e={});var r,h;e.shape?(r=e.shape[0],h=e.shape[1]):(r=c.width=e.w||e.width||200,h=c.height=e.h||e.height||200);var f=Math.min(r,h),p=e.stroke||0,d=e.viewbox||e.viewBox||i(t),g=[r/(d[2]-d[0]),h/(d[3]-d[1])],v=Math.min(g[0]||0,g[1]||0)/2;u.fillStyle=\"black\",u.fillRect(0,0,r,h),u.fillStyle=\"white\",p&&(\"number\"!=typeof p&&(p=1),u.strokeStyle=p>0?\"white\":\"black\",u.lineWidth=Math.abs(p));if(u.translate(.5*r,.5*h),u.scale(v,v),function(){if(null!=n)return n;var t=document.createElement(\"canvas\").getContext(\"2d\");if(t.canvas.width=t.canvas.height=1,!window.Path2D)return n=!1;var e=new Path2D(\"M0,0h1v1h-1v-1Z\");t.fillStyle=\"black\",t.fill(e);var r=t.getImageData(0,0,1,1);return n=r&&r.data&&255===r.data[3]}()){var m=new Path2D(t);u.fill(m),p&&u.stroke(m)}else{var y=a(t);o(u,y),u.fill(),p&&u.stroke()}return u.setTransform(1,0,0,1,0,0),l(u,{cutoff:null!=e.cutoff?e.cutoff:.5,radius:null!=e.radius?e.radius:.5*f})}},{\"bitmap-sdf\":93,\"draw-svg-path\":168,\"is-svg-path\":424,\"parse-svg-path\":460,\"svg-path-bounds\":533}],536:[function(t,e,r){(function(r){\"use strict\";e.exports=function t(e,r,i){var i=i||{};var o=a[e];o||(o=a[e]={\" \":{data:new Float32Array(0),shape:.2}});var s=o[r];if(!s)if(r.length<=1||!/\\d/.test(r))s=o[r]=function(t){for(var e=t.cells,r=t.positions,n=new Float32Array(6*e.length),i=0,a=0,o=0;o<e.length;++o)for(var s=e[o],l=0;l<3;++l){var c=r[s[l]];n[i++]=c[0],n[i++]=c[1]+1.4,a=Math.max(c[0],a)}return{data:n,shape:a}}(n(r,{triangles:!0,font:e,textAlign:i.textAlign||\"left\",textBaseline:\"alphabetic\",styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0}}));else{for(var l=r.split(/(\\d|\\s)/),c=new Array(l.length),u=0,h=0,f=0;f<l.length;++f)c[f]=t(e,l[f]),u+=c[f].data.length,h+=c[f].shape,f>0&&(h+=.02);for(var p=new Float32Array(u),d=0,g=-.5*h,f=0;f<c.length;++f){for(var v=c[f].data,m=0;m<v.length;m+=2)p[d++]=v[m]+g,p[d++]=v[m+1];g+=c[f].shape+.02}s=o[r]={data:p,shape:h}}return s};var n=t(\"vectorize-text\"),i=window||r.global||{},a=i.__TEXT_CACHE||{};i.__TEXT_CACHE={}}).call(this,t(\"_process\"))},{_process:482,\"vectorize-text\":550}],537:[function(t,e,r){!function(t){var r=/^\\s+/,n=/\\s+$/,i=0,a=t.round,o=t.min,s=t.max,l=t.random;function c(e,l){if(l=l||{},(e=e||\"\")instanceof c)return e;if(!(this instanceof c))return new c(e,l);var u=function(e){var i={r:0,g:0,b:0},a=1,l=null,c=null,u=null,h=!1,f=!1;\"string\"==typeof e&&(e=function(t){t=t.replace(r,\"\").replace(n,\"\").toLowerCase();var e,i=!1;if(S[t])t=S[t],i=!0;else if(\"transparent\"==t)return{r:0,g:0,b:0,a:0,format:\"name\"};if(e=j.rgb.exec(t))return{r:e[1],g:e[2],b:e[3]};if(e=j.rgba.exec(t))return{r:e[1],g:e[2],b:e[3],a:e[4]};if(e=j.hsl.exec(t))return{h:e[1],s:e[2],l:e[3]};if(e=j.hsla.exec(t))return{h:e[1],s:e[2],l:e[3],a:e[4]};if(e=j.hsv.exec(t))return{h:e[1],s:e[2],v:e[3]};if(e=j.hsva.exec(t))return{h:e[1],s:e[2],v:e[3],a:e[4]};if(e=j.hex8.exec(t))return{r:O(e[1]),g:O(e[2]),b:O(e[3]),a:R(e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex6.exec(t))return{r:O(e[1]),g:O(e[2]),b:O(e[3]),format:i?\"name\":\"hex\"};if(e=j.hex4.exec(t))return{r:O(e[1]+\"\"+e[1]),g:O(e[2]+\"\"+e[2]),b:O(e[3]+\"\"+e[3]),a:R(e[4]+\"\"+e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex3.exec(t))return{r:O(e[1]+\"\"+e[1]),g:O(e[2]+\"\"+e[2]),b:O(e[3]+\"\"+e[3]),format:i?\"name\":\"hex\"};return!1}(e));\"object\"==typeof e&&(U(e.r)&&U(e.g)&&U(e.b)?(p=e.r,d=e.g,g=e.b,i={r:255*L(p,255),g:255*L(d,255),b:255*L(g,255)},h=!0,f=\"%\"===String(e.r).substr(-1)?\"prgb\":\"rgb\"):U(e.h)&&U(e.s)&&U(e.v)?(l=I(e.s),c=I(e.v),i=function(e,r,n){e=6*L(e,360),r=L(r,100),n=L(n,100);var i=t.floor(e),a=e-i,o=n*(1-r),s=n*(1-a*r),l=n*(1-(1-a)*r),c=i%6;return{r:255*[n,s,o,o,l,n][c],g:255*[l,n,n,s,o,o][c],b:255*[o,o,l,n,n,s][c]}}(e.h,l,c),h=!0,f=\"hsv\"):U(e.h)&&U(e.s)&&U(e.l)&&(l=I(e.s),u=I(e.l),i=function(t,e,r){var n,i,a;function o(t,e,r){return r<0&&(r+=1),r>1&&(r-=1),r<1/6?t+6*(e-t)*r:r<.5?e:r<2/3?t+(e-t)*(2/3-r)*6:t}if(t=L(t,360),e=L(e,100),r=L(r,100),0===e)n=i=a=r;else{var s=r<.5?r*(1+e):r+e-r*e,l=2*r-s;n=o(l,s,t+1/3),i=o(l,s,t),a=o(l,s,t-1/3)}return{r:255*n,g:255*i,b:255*a}}(e.h,l,u),h=!0,f=\"hsl\"),e.hasOwnProperty(\"a\")&&(a=e.a));var p,d,g;return a=C(a),{ok:h,format:e.format||f,r:o(255,s(i.r,0)),g:o(255,s(i.g,0)),b:o(255,s(i.b,0)),a:a}}(e);this._originalInput=e,this._r=u.r,this._g=u.g,this._b=u.b,this._a=u.a,this._roundA=a(100*this._a)/100,this._format=l.format||u.format,this._gradientType=l.gradientType,this._r<1&&(this._r=a(this._r)),this._g<1&&(this._g=a(this._g)),this._b<1&&(this._b=a(this._b)),this._ok=u.ok,this._tc_id=i++}function u(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=(a+l)/2;if(a==l)n=i=0;else{var u=a-l;switch(i=c>.5?u/(2-a-l):u/(a+l),a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,l:c}}function h(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=a,u=a-l;if(i=0===a?0:u/a,a==l)n=0;else{switch(a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,v:c}}function f(t,e,r,n){var i=[z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16))];return n&&i[0].charAt(0)==i[0].charAt(1)&&i[1].charAt(0)==i[1].charAt(1)&&i[2].charAt(0)==i[2].charAt(1)?i[0].charAt(0)+i[1].charAt(0)+i[2].charAt(0):i.join(\"\")}function p(t,e,r,n){return[z(D(n)),z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16))].join(\"\")}function d(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s-=e/100,r.s=P(r.s),c(r)}function g(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s+=e/100,r.s=P(r.s),c(r)}function v(t){return c(t).desaturate(100)}function m(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l+=e/100,r.l=P(r.l),c(r)}function y(t,e){e=0===e?0:e||10;var r=c(t).toRgb();return r.r=s(0,o(255,r.r-a(-e/100*255))),r.g=s(0,o(255,r.g-a(-e/100*255))),r.b=s(0,o(255,r.b-a(-e/100*255))),c(r)}function x(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l-=e/100,r.l=P(r.l),c(r)}function b(t,e){var r=c(t).toHsl(),n=(r.h+e)%360;return r.h=n<0?360+n:n,c(r)}function _(t){var e=c(t).toHsl();return e.h=(e.h+180)%360,c(e)}function w(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+120)%360,s:e.s,l:e.l}),c({h:(r+240)%360,s:e.s,l:e.l})]}function k(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+90)%360,s:e.s,l:e.l}),c({h:(r+180)%360,s:e.s,l:e.l}),c({h:(r+270)%360,s:e.s,l:e.l})]}function T(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+72)%360,s:e.s,l:e.l}),c({h:(r+216)%360,s:e.s,l:e.l})]}function A(t,e,r){e=e||6,r=r||30;var n=c(t).toHsl(),i=360/r,a=[c(t)];for(n.h=(n.h-(i*e>>1)+720)%360;--e;)n.h=(n.h+i)%360,a.push(c(n));return a}function M(t,e){e=e||6;for(var r=c(t).toHsv(),n=r.h,i=r.s,a=r.v,o=[],s=1/e;e--;)o.push(c({h:n,s:i,v:a})),a=(a+s)%1;return o}c.prototype={isDark:function(){return this.getBrightness()<128},isLight:function(){return!this.isDark()},isValid:function(){return this._ok},getOriginalInput:function(){return this._originalInput},getFormat:function(){return this._format},getAlpha:function(){return this._a},getBrightness:function(){var t=this.toRgb();return(299*t.r+587*t.g+114*t.b)/1e3},getLuminance:function(){var e,r,n,i=this.toRgb();return e=i.r/255,r=i.g/255,n=i.b/255,.2126*(e<=.03928?e/12.92:t.pow((e+.055)/1.055,2.4))+.7152*(r<=.03928?r/12.92:t.pow((r+.055)/1.055,2.4))+.0722*(n<=.03928?n/12.92:t.pow((n+.055)/1.055,2.4))},setAlpha:function(t){return this._a=C(t),this._roundA=a(100*this._a)/100,this},toHsv:function(){var t=h(this._r,this._g,this._b);return{h:360*t.h,s:t.s,v:t.v,a:this._a}},toHsvString:function(){var t=h(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.v);return 1==this._a?\"hsv(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsva(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHsl:function(){var t=u(this._r,this._g,this._b);return{h:360*t.h,s:t.s,l:t.l,a:this._a}},toHslString:function(){var t=u(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.l);return 1==this._a?\"hsl(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsla(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHex:function(t){return f(this._r,this._g,this._b,t)},toHexString:function(t){return\"#\"+this.toHex(t)},toHex8:function(t){return function(t,e,r,n,i){var o=[z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16)),z(D(n))];if(i&&o[0].charAt(0)==o[0].charAt(1)&&o[1].charAt(0)==o[1].charAt(1)&&o[2].charAt(0)==o[2].charAt(1)&&o[3].charAt(0)==o[3].charAt(1))return o[0].charAt(0)+o[1].charAt(0)+o[2].charAt(0)+o[3].charAt(0);return o.join(\"\")}(this._r,this._g,this._b,this._a,t)},toHex8String:function(t){return\"#\"+this.toHex8(t)},toRgb:function(){return{r:a(this._r),g:a(this._g),b:a(this._b),a:this._a}},toRgbString:function(){return 1==this._a?\"rgb(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\")\":\"rgba(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\", \"+this._roundA+\")\"},toPercentageRgb:function(){return{r:a(100*L(this._r,255))+\"%\",g:a(100*L(this._g,255))+\"%\",b:a(100*L(this._b,255))+\"%\",a:this._a}},toPercentageRgbString:function(){return 1==this._a?\"rgb(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%)\":\"rgba(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%, \"+this._roundA+\")\"},toName:function(){return 0===this._a?\"transparent\":!(this._a<1)&&(E[f(this._r,this._g,this._b,!0)]||!1)},toFilter:function(t){var e=\"#\"+p(this._r,this._g,this._b,this._a),r=e,n=this._gradientType?\"GradientType = 1, \":\"\";if(t){var i=c(t);r=\"#\"+p(i._r,i._g,i._b,i._a)}return\"progid:DXImageTransform.Microsoft.gradient(\"+n+\"startColorstr=\"+e+\",endColorstr=\"+r+\")\"},toString:function(t){var e=!!t;t=t||this._format;var r=!1,n=this._a<1&&this._a>=0;return e||!n||\"hex\"!==t&&\"hex6\"!==t&&\"hex3\"!==t&&\"hex4\"!==t&&\"hex8\"!==t&&\"name\"!==t?(\"rgb\"===t&&(r=this.toRgbString()),\"prgb\"===t&&(r=this.toPercentageRgbString()),\"hex\"!==t&&\"hex6\"!==t||(r=this.toHexString()),\"hex3\"===t&&(r=this.toHexString(!0)),\"hex4\"===t&&(r=this.toHex8String(!0)),\"hex8\"===t&&(r=this.toHex8String()),\"name\"===t&&(r=this.toName()),\"hsl\"===t&&(r=this.toHslString()),\"hsv\"===t&&(r=this.toHsvString()),r||this.toHexString()):\"name\"===t&&0===this._a?this.toName():this.toRgbString()},clone:function(){return c(this.toString())},_applyModification:function(t,e){var r=t.apply(null,[this].concat([].slice.call(e)));return this._r=r._r,this._g=r._g,this._b=r._b,this.setAlpha(r._a),this},lighten:function(){return this._applyModification(m,arguments)},brighten:function(){return this._applyModification(y,arguments)},darken:function(){return this._applyModification(x,arguments)},desaturate:function(){return this._applyModification(d,arguments)},saturate:function(){return this._applyModification(g,arguments)},greyscale:function(){return this._applyModification(v,arguments)},spin:function(){return this._applyModification(b,arguments)},_applyCombination:function(t,e){return t.apply(null,[this].concat([].slice.call(e)))},analogous:function(){return this._applyCombination(A,arguments)},complement:function(){return this._applyCombination(_,arguments)},monochromatic:function(){return this._applyCombination(M,arguments)},splitcomplement:function(){return this._applyCombination(T,arguments)},triad:function(){return this._applyCombination(w,arguments)},tetrad:function(){return this._applyCombination(k,arguments)}},c.fromRatio=function(t,e){if(\"object\"==typeof t){var r={};for(var n in t)t.hasOwnProperty(n)&&(r[n]=\"a\"===n?t[n]:I(t[n]));t=r}return c(t,e)},c.equals=function(t,e){return!(!t||!e)&&c(t).toRgbString()==c(e).toRgbString()},c.random=function(){return c.fromRatio({r:l(),g:l(),b:l()})},c.mix=function(t,e,r){r=0===r?0:r||50;var n=c(t).toRgb(),i=c(e).toRgb(),a=r/100;return c({r:(i.r-n.r)*a+n.r,g:(i.g-n.g)*a+n.g,b:(i.b-n.b)*a+n.b,a:(i.a-n.a)*a+n.a})},c.readability=function(e,r){var n=c(e),i=c(r);return(t.max(n.getLuminance(),i.getLuminance())+.05)/(t.min(n.getLuminance(),i.getLuminance())+.05)},c.isReadable=function(t,e,r){var n,i,a=c.readability(t,e);switch(i=!1,(n=function(t){var e,r;e=((t=t||{level:\"AA\",size:\"small\"}).level||\"AA\").toUpperCase(),r=(t.size||\"small\").toLowerCase(),\"AA\"!==e&&\"AAA\"!==e&&(e=\"AA\");\"small\"!==r&&\"large\"!==r&&(r=\"small\");return{level:e,size:r}}(r)).level+n.size){case\"AAsmall\":case\"AAAlarge\":i=a>=4.5;break;case\"AAlarge\":i=a>=3;break;case\"AAAsmall\":i=a>=7}return i},c.mostReadable=function(t,e,r){var n,i,a,o,s=null,l=0;i=(r=r||{}).includeFallbackColors,a=r.level,o=r.size;for(var u=0;u<e.length;u++)(n=c.readability(t,e[u]))>l&&(l=n,s=c(e[u]));return c.isReadable(t,s,{level:a,size:o})||!i?s:(r.includeFallbackColors=!1,c.mostReadable(t,[\"#fff\",\"#000\"],r))};var S=c.names={aliceblue:\"f0f8ff\",antiquewhite:\"faebd7\",aqua:\"0ff\",aquamarine:\"7fffd4\",azure:\"f0ffff\",beige:\"f5f5dc\",bisque:\"ffe4c4\",black:\"000\",blanchedalmond:\"ffebcd\",blue:\"00f\",blueviolet:\"8a2be2\",brown:\"a52a2a\",burlywood:\"deb887\",burntsienna:\"ea7e5d\",cadetblue:\"5f9ea0\",chartreuse:\"7fff00\",chocolate:\"d2691e\",coral:\"ff7f50\",cornflowerblue:\"6495ed\",cornsilk:\"fff8dc\",crimson:\"dc143c\",cyan:\"0ff\",darkblue:\"00008b\",darkcyan:\"008b8b\",darkgoldenrod:\"b8860b\",darkgray:\"a9a9a9\",darkgreen:\"006400\",darkgrey:\"a9a9a9\",darkkhaki:\"bdb76b\",darkmagenta:\"8b008b\",darkolivegreen:\"556b2f\",darkorange:\"ff8c00\",darkorchid:\"9932cc\",darkred:\"8b0000\",darksalmon:\"e9967a\",darkseagreen:\"8fbc8f\",darkslateblue:\"483d8b\",darkslategray:\"2f4f4f\",darkslategrey:\"2f4f4f\",darkturquoise:\"00ced1\",darkviolet:\"9400d3\",deeppink:\"ff1493\",deepskyblue:\"00bfff\",dimgray:\"696969\",dimgrey:\"696969\",dodgerblue:\"1e90ff\",firebrick:\"b22222\",floralwhite:\"fffaf0\",forestgreen:\"228b22\",fuchsia:\"f0f\",gainsboro:\"dcdcdc\",ghostwhite:\"f8f8ff\",gold:\"ffd700\",goldenrod:\"daa520\",gray:\"808080\",green:\"008000\",greenyellow:\"adff2f\",grey:\"808080\",honeydew:\"f0fff0\",hotpink:\"ff69b4\",indianred:\"cd5c5c\",indigo:\"4b0082\",ivory:\"fffff0\",khaki:\"f0e68c\",lavender:\"e6e6fa\",lavenderblush:\"fff0f5\",lawngreen:\"7cfc00\",lemonchiffon:\"fffacd\",lightblue:\"add8e6\",lightcoral:\"f08080\",lightcyan:\"e0ffff\",lightgoldenrodyellow:\"fafad2\",lightgray:\"d3d3d3\",lightgreen:\"90ee90\",lightgrey:\"d3d3d3\",lightpink:\"ffb6c1\",lightsalmon:\"ffa07a\",lightseagreen:\"20b2aa\",lightskyblue:\"87cefa\",lightslategray:\"789\",lightslategrey:\"789\",lightsteelblue:\"b0c4de\",lightyellow:\"ffffe0\",lime:\"0f0\",limegreen:\"32cd32\",linen:\"faf0e6\",magenta:\"f0f\",maroon:\"800000\",mediumaquamarine:\"66cdaa\",mediumblue:\"0000cd\",mediumorchid:\"ba55d3\",mediumpurple:\"9370db\",mediumseagreen:\"3cb371\",mediumslateblue:\"7b68ee\",mediumspringgreen:\"00fa9a\",mediumturquoise:\"48d1cc\",mediumvioletred:\"c71585\",midnightblue:\"191970\",mintcream:\"f5fffa\",mistyrose:\"ffe4e1\",moccasin:\"ffe4b5\",navajowhite:\"ffdead\",navy:\"000080\",oldlace:\"fdf5e6\",olive:\"808000\",olivedrab:\"6b8e23\",orange:\"ffa500\",orangered:\"ff4500\",orchid:\"da70d6\",palegoldenrod:\"eee8aa\",palegreen:\"98fb98\",paleturquoise:\"afeeee\",palevioletred:\"db7093\",papayawhip:\"ffefd5\",peachpuff:\"ffdab9\",peru:\"cd853f\",pink:\"ffc0cb\",plum:\"dda0dd\",powderblue:\"b0e0e6\",purple:\"800080\",rebeccapurple:\"663399\",red:\"f00\",rosybrown:\"bc8f8f\",royalblue:\"4169e1\",saddlebrown:\"8b4513\",salmon:\"fa8072\",sandybrown:\"f4a460\",seagreen:\"2e8b57\",seashell:\"fff5ee\",sienna:\"a0522d\",silver:\"c0c0c0\",skyblue:\"87ceeb\",slateblue:\"6a5acd\",slategray:\"708090\",slategrey:\"708090\",snow:\"fffafa\",springgreen:\"00ff7f\",steelblue:\"4682b4\",tan:\"d2b48c\",teal:\"008080\",thistle:\"d8bfd8\",tomato:\"ff6347\",turquoise:\"40e0d0\",violet:\"ee82ee\",wheat:\"f5deb3\",white:\"fff\",whitesmoke:\"f5f5f5\",yellow:\"ff0\",yellowgreen:\"9acd32\"},E=c.hexNames=function(t){var e={};for(var r in t)t.hasOwnProperty(r)&&(e[t[r]]=r);return e}(S);function C(t){return t=parseFloat(t),(isNaN(t)||t<0||t>1)&&(t=1),t}function L(e,r){(function(t){return\"string\"==typeof t&&-1!=t.indexOf(\".\")&&1===parseFloat(t)})(e)&&(e=\"100%\");var n=function(t){return\"string\"==typeof t&&-1!=t.indexOf(\"%\")}(e);return e=o(r,s(0,parseFloat(e))),n&&(e=parseInt(e*r,10)/100),t.abs(e-r)<1e-6?1:e%r/parseFloat(r)}function P(t){return o(1,s(0,t))}function O(t){return parseInt(t,16)}function z(t){return 1==t.length?\"0\"+t:\"\"+t}function I(t){return t<=1&&(t=100*t+\"%\"),t}function D(e){return t.round(255*parseFloat(e)).toString(16)}function R(t){return O(t)/255}var F,B,N,j=(B=\"[\\\\s|\\\\(]+(\"+(F=\"(?:[-\\\\+]?\\\\d*\\\\.\\\\d+%?)|(?:[-\\\\+]?\\\\d+%?)\")+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",N=\"[\\\\s|\\\\(]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",{CSS_UNIT:new RegExp(F),rgb:new RegExp(\"rgb\"+B),rgba:new RegExp(\"rgba\"+N),hsl:new RegExp(\"hsl\"+B),hsla:new RegExp(\"hsla\"+N),hsv:new RegExp(\"hsv\"+B),hsva:new RegExp(\"hsva\"+N),hex3:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex6:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/,hex4:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex8:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/});function U(t){return!!j.CSS_UNIT.exec(t)}\"undefined\"!=typeof e&&e.exports?e.exports=c:window.tinycolor=c}(Math)},{}],538:[function(t,e,r){\"use strict\";e.exports=i,e.exports.float32=e.exports.float=i,e.exports.fract32=e.exports.fract=function(t){if(t.length){for(var e=i(t),r=0,n=e.length;r<n;r++)e[r]=t[r]-e[r];return e}return i(t-i(t))};var n=new Float32Array(1);function i(t){if(t.length){if(t instanceof Float32Array)return t;var e=new Float32Array(t);return e.set(t),e}return n[0]=t,n[0]}},{}],539:[function(t,e,r){\"use strict\";var n=t(\"parse-unit\");e.exports=o;var i=96;function a(t,e){var r=n(getComputedStyle(t).getPropertyValue(e));return r[0]*o(r[1],t)}function o(t,e){switch(e=e||document.body,t=(t||\"px\").trim().toLowerCase(),e!==window&&e!==document||(e=document.body),t){case\"%\":return e.clientHeight/100;case\"ch\":case\"ex\":return function(t,e){var r=document.createElement(\"div\");r.style[\"font-size\"]=\"128\"+t,e.appendChild(r);var n=a(r,\"font-size\")/128;return e.removeChild(r),n}(t,e);case\"em\":return a(e,\"font-size\");case\"rem\":return a(document.body,\"font-size\");case\"vw\":return window.innerWidth/100;case\"vh\":return window.innerHeight/100;case\"vmin\":return Math.min(window.innerWidth,window.innerHeight)/100;case\"vmax\":return Math.max(window.innerWidth,window.innerHeight)/100;case\"in\":return i;case\"cm\":return i/2.54;case\"mm\":return i/25.4;case\"pt\":return i/72;case\"pc\":return i/6}return 1}},{\"parse-unit\":461}],540:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e=function(t){return t},r=function(t){if(null==(r=t.transform))return e;var r,n,i,a=r.scale[0],o=r.scale[1],s=r.translate[0],l=r.translate[1];return function(t,e){return e||(n=i=0),t[0]=(n+=t[0])*a+s,t[1]=(i+=t[1])*o+l,t}},n=function(t){var e=t.bbox;function n(t){l[0]=t[0],l[1]=t[1],s(l),l[0]<c&&(c=l[0]),l[0]>h&&(h=l[0]),l[1]<u&&(u=l[1]),l[1]>f&&(f=l[1])}function i(t){switch(t.type){case\"GeometryCollection\":t.geometries.forEach(i);break;case\"Point\":n(t.coordinates);break;case\"MultiPoint\":t.coordinates.forEach(n)}}if(!e){var a,o,s=r(t),l=new Array(2),c=1/0,u=c,h=-c,f=-c;for(o in t.arcs.forEach(function(t){for(var e=-1,r=t.length;++e<r;)a=t[e],l[0]=a[0],l[1]=a[1],s(l,e),l[0]<c&&(c=l[0]),l[0]>h&&(h=l[0]),l[1]<u&&(u=l[1]),l[1]>f&&(f=l[1])}),t.objects)i(t.objects[o]);e=t.bbox=[c,u,h,f]}return e},i=function(t,e){for(var r,n=t.length,i=n-e;i<--n;)r=t[i],t[i++]=t[n],t[n]=r};function a(t,e){var r=e.id,n=e.bbox,i=null==e.properties?{}:e.properties,a=o(t,e);return null==r&&null==n?{type:\"Feature\",properties:i,geometry:a}:null==n?{type:\"Feature\",id:r,properties:i,geometry:a}:{type:\"Feature\",id:r,bbox:n,properties:i,geometry:a}}function o(t,e){var n=r(t),a=t.arcs;function o(t,e){e.length&&e.pop();for(var r=a[t<0?~t:t],o=0,s=r.length;o<s;++o)e.push(n(r[o].slice(),o));t<0&&i(e,s)}function s(t){return n(t.slice())}function l(t){for(var e=[],r=0,n=t.length;r<n;++r)o(t[r],e);return e.length<2&&e.push(e[0].slice()),e}function c(t){for(var e=l(t);e.length<4;)e.push(e[0].slice());return e}function u(t){return t.map(c)}return function t(e){var r,n=e.type;switch(n){case\"GeometryCollection\":return{type:n,geometries:e.geometries.map(t)};case\"Point\":r=s(e.coordinates);break;case\"MultiPoint\":r=e.coordinates.map(s);break;case\"LineString\":r=l(e.arcs);break;case\"MultiLineString\":r=e.arcs.map(l);break;case\"Polygon\":r=u(e.arcs);break;case\"MultiPolygon\":r=e.arcs.map(u);break;default:return null}return{type:n,coordinates:r}}(e)}var s=function(t,e){var r={},n={},i={},a=[],o=-1;function s(t,e){for(var n in t){var i=t[n];delete e[i.start],delete i.start,delete i.end,i.forEach(function(t){r[t<0?~t:t]=1}),a.push(i)}}return e.forEach(function(r,n){var i,a=t.arcs[r<0?~r:r];a.length<3&&!a[1][0]&&!a[1][1]&&(i=e[++o],e[o]=r,e[n]=i)}),e.forEach(function(e){var r,a,o=function(e){var r,n=t.arcs[e<0?~e:e],i=n[0];t.transform?(r=[0,0],n.forEach(function(t){r[0]+=t[0],r[1]+=t[1]})):r=n[n.length-1];return e<0?[r,i]:[i,r]}(e),s=o[0],l=o[1];if(r=i[s])if(delete i[r.end],r.push(e),r.end=l,a=n[l]){delete n[a.start];var c=a===r?r:r.concat(a);n[c.start=r.start]=i[c.end=a.end]=c}else n[r.start]=i[r.end]=r;else if(r=n[l])if(delete n[r.start],r.unshift(e),r.start=s,a=i[s]){delete i[a.end];var u=a===r?r:a.concat(r);n[u.start=a.start]=i[u.end=r.end]=u}else n[r.start]=i[r.end]=r;else n[(r=[e]).start=s]=i[r.end=l]=r}),s(i,n),s(n,i),e.forEach(function(t){r[t<0?~t:t]||a.push([t])}),a};function l(t,e,r){var n,i,a;if(arguments.length>1)n=function(t,e,r){var n,i=[],a=[];function o(t){var e=t<0?~t:t;(a[e]||(a[e]=[])).push({i:t,g:n})}function s(t){t.forEach(o)}function l(t){t.forEach(s)}return function t(e){switch(n=e,e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"LineString\":s(e.arcs);break;case\"MultiLineString\":case\"Polygon\":l(e.arcs);break;case\"MultiPolygon\":e.arcs.forEach(l)}}(e),a.forEach(null==r?function(t){i.push(t[0].i)}:function(t){r(t[0].g,t[t.length-1].g)&&i.push(t[0].i)}),i}(0,e,r);else for(i=0,n=new Array(a=t.arcs.length);i<a;++i)n[i]=i;return{type:\"MultiLineString\",arcs:s(t,n)}}function c(t,e){var r={},n=[],i=[];function a(t){t.forEach(function(e){e.forEach(function(e){(r[e=e<0?~e:e]||(r[e]=[])).push(t)})}),n.push(t)}function l(e){return function(t){for(var e,r=-1,n=t.length,i=t[n-1],a=0;++r<n;)e=i,i=t[r],a+=e[0]*i[1]-e[1]*i[0];return Math.abs(a)}(o(t,{type:\"Polygon\",arcs:[e]}).coordinates[0])}return e.forEach(function t(e){switch(e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"Polygon\":a(e.arcs);break;case\"MultiPolygon\":e.arcs.forEach(a)}}),n.forEach(function(t){if(!t._){var e=[],n=[t];for(t._=1,i.push(e);t=n.pop();)e.push(t),t.forEach(function(t){t.forEach(function(t){r[t<0?~t:t].forEach(function(t){t._||(t._=1,n.push(t))})})})}}),n.forEach(function(t){delete t._}),{type:\"MultiPolygon\",arcs:i.map(function(e){var n,i=[];if(e.forEach(function(t){t.forEach(function(t){t.forEach(function(t){r[t<0?~t:t].length<2&&i.push(t)})})}),(n=(i=s(t,i)).length)>1)for(var a,o,c=1,u=l(i[0]);c<n;++c)(a=l(i[c]))>u&&(o=i[0],i[0]=i[c],i[c]=o,u=a);return i})}}var u=function(t,e){for(var r=0,n=t.length;r<n;){var i=r+n>>>1;t[i]<e?r=i+1:n=i}return r};t.bbox=n,t.feature=function(t,e){return\"GeometryCollection\"===e.type?{type:\"FeatureCollection\",features:e.geometries.map(function(e){return a(t,e)})}:a(t,e)},t.mesh=function(t){return o(t,l.apply(this,arguments))},t.meshArcs=l,t.merge=function(t){return o(t,c.apply(this,arguments))},t.mergeArcs=c,t.neighbors=function(t){var e={},r=t.map(function(){return[]});function n(t,r){t.forEach(function(t){t<0&&(t=~t);var n=e[t];n?n.push(r):e[t]=[r]})}function i(t,e){t.forEach(function(t){n(t,e)})}var a={LineString:n,MultiLineString:i,Polygon:i,MultiPolygon:function(t,e){t.forEach(function(t){i(t,e)})}};for(var o in t.forEach(function t(e,r){\"GeometryCollection\"===e.type?e.geometries.forEach(function(e){t(e,r)}):e.type in a&&a[e.type](e.arcs,r)}),e)for(var s=e[o],l=s.length,c=0;c<l;++c)for(var h=c+1;h<l;++h){var f,p=s[c],d=s[h];(f=r[p])[o=u(f,d)]!==d&&f.splice(o,0,d),(f=r[d])[o=u(f,p)]!==p&&f.splice(o,0,p)}return r},t.quantize=function(t,e){if(!((e=Math.floor(e))>=2))throw new Error(\"n must be \\u22652\");if(t.transform)throw new Error(\"already quantized\");var r,i=n(t),a=i[0],o=(i[2]-a)/(e-1)||1,s=i[1],l=(i[3]-s)/(e-1)||1;function c(t){t[0]=Math.round((t[0]-a)/o),t[1]=Math.round((t[1]-s)/l)}function u(t){switch(t.type){case\"GeometryCollection\":t.geometries.forEach(u);break;case\"Point\":c(t.coordinates);break;case\"MultiPoint\":t.coordinates.forEach(c)}}for(r in t.arcs.forEach(function(t){for(var e,r,n,i=1,c=1,u=t.length,h=t[0],f=h[0]=Math.round((h[0]-a)/o),p=h[1]=Math.round((h[1]-s)/l);i<u;++i)h=t[i],r=Math.round((h[0]-a)/o),n=Math.round((h[1]-s)/l),r===f&&n===p||((e=t[c++])[0]=r-f,f=r,e[1]=n-p,p=n);c<2&&((e=t[c++])[0]=0,e[1]=0),t.length=c}),t.objects)u(t.objects[r]);return t.transform={scale:[o,l],translate:[a,s]},t},t.transform=r,t.untransform=function(t){if(null==(r=t.transform))return e;var r,n,i,a=r.scale[0],o=r.scale[1],s=r.translate[0],l=r.translate[1];return function(t,e){e||(n=i=0);var r=Math.round((t[0]-s)/a),c=Math.round((t[1]-l)/o);return t[0]=r-n,n=r,t[1]=c-i,i=c,t}},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.topojson=n.topojson||{})},{}],541:[function(t,e,r){\"use strict\";e.exports=function(t){if(t<0)return[];if(0===t)return[[0]];for(var e=0|Math.round(a(t+1)),r=[],o=0;o<e;++o){for(var s=n.unrank(t,o),l=[0],c=0,u=0;u<s.length;++u)c+=1<<s[u],l.push(c);i(s)<1&&(l[0]=c,l[t]=0),r.push(l)}return r};var n=t(\"permutation-rank\"),i=t(\"permutation-parity\"),a=t(\"gamma\")},{gamma:231,\"permutation-parity\":463,\"permutation-rank\":464}],542:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.up||[0,1,0],n=t.right||h(r),i=t.radius||1,a=t.theta||0,u=t.phi||0;if(e=[].slice.call(e,0,3),r=[].slice.call(r,0,3),s(r,r),n=[].slice.call(n,0,3),s(n,n),\"eye\"in t){var p=t.eye,d=[p[0]-e[0],p[1]-e[1],p[2]-e[2]];o(n,d,r),c(n[0],n[1],n[2])<1e-6?n=h(r):s(n,n),i=c(d[0],d[1],d[2]);var g=l(r,d)/i,v=l(n,d)/i;u=Math.acos(g),a=Math.acos(v)}return i=Math.log(i),new f(t.zoomMin,t.zoomMax,e,r,n,i,a,u)};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/invert\"),a=t(\"gl-mat4/rotate\"),o=t(\"gl-vec3/cross\"),s=t(\"gl-vec3/normalize\"),l=t(\"gl-vec3/dot\");function c(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function u(t){return Math.min(1,Math.max(-1,t))}function h(t){var e=Math.abs(t[0]),r=Math.abs(t[1]),n=Math.abs(t[2]),i=[0,0,0];e>Math.max(r,n)?i[2]=1:r>Math.max(e,n)?i[0]=1:i[1]=1;for(var a=0,o=0,l=0;l<3;++l)a+=t[l]*t[l],o+=i[l]*t[l];for(l=0;l<3;++l)i[l]-=o/a*t[l];return s(i,i),i}function f(t,e,r,i,a,o,s,l){this.center=n(r),this.up=n(i),this.right=n(a),this.radius=n([o]),this.angle=n([s,l]),this.angle.bounds=[[-1/0,-Math.PI/2],[1/0,Math.PI/2]],this.setDistanceLimits(t,e),this.computedCenter=this.center.curve(0),this.computedUp=this.up.curve(0),this.computedRight=this.right.curve(0),this.computedRadius=this.radius.curve(0),this.computedAngle=this.angle.curve(0),this.computedToward=[0,0,0],this.computedEye=[0,0,0],this.computedMatrix=new Array(16);for(var c=0;c<16;++c)this.computedMatrix[c]=.5;this.recalcMatrix(0)}var p=f.prototype;p.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},p.getDistanceLimits=function(t){var e=this.radius.bounds[0];return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},p.recalcMatrix=function(t){this.center.curve(t),this.up.curve(t),this.right.curve(t),this.radius.curve(t),this.angle.curve(t);for(var e=this.computedUp,r=this.computedRight,n=0,i=0,a=0;a<3;++a)i+=e[a]*r[a],n+=e[a]*e[a];var l=Math.sqrt(n),u=0;for(a=0;a<3;++a)r[a]-=e[a]*i/n,u+=r[a]*r[a],e[a]/=l;var h=Math.sqrt(u);for(a=0;a<3;++a)r[a]/=h;var f=this.computedToward;o(f,e,r),s(f,f);var p=Math.exp(this.computedRadius[0]),d=this.computedAngle[0],g=this.computedAngle[1],v=Math.cos(d),m=Math.sin(d),y=Math.cos(g),x=Math.sin(g),b=this.computedCenter,_=v*y,w=m*y,k=x,T=-v*x,A=-m*x,M=y,S=this.computedEye,E=this.computedMatrix;for(a=0;a<3;++a){var C=_*r[a]+w*f[a]+k*e[a];E[4*a+1]=T*r[a]+A*f[a]+M*e[a],E[4*a+2]=C,E[4*a+3]=0}var L=E[1],P=E[5],O=E[9],z=E[2],I=E[6],D=E[10],R=P*D-O*I,F=O*z-L*D,B=L*I-P*z,N=c(R,F,B);R/=N,F/=N,B/=N,E[0]=R,E[4]=F,E[8]=B;for(a=0;a<3;++a)S[a]=b[a]+E[2+4*a]*p;for(a=0;a<3;++a){u=0;for(var j=0;j<3;++j)u+=E[a+4*j]*S[j];E[12+a]=-u}E[15]=1},p.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r};var d=[0,0,0];p.rotate=function(t,e,r,n){if(this.angle.move(t,e,r),n){this.recalcMatrix(t);var i=this.computedMatrix;d[0]=i[2],d[1]=i[6],d[2]=i[10];for(var o=this.computedUp,s=this.computedRight,l=this.computedToward,c=0;c<3;++c)i[4*c]=o[c],i[4*c+1]=s[c],i[4*c+2]=l[c];a(i,i,n,d);for(c=0;c<3;++c)o[c]=i[4*c],s[c]=i[4*c+1];this.up.set(t,o[0],o[1],o[2]),this.right.set(t,s[0],s[1],s[2])}},p.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=(Math.exp(this.computedRadius[0]),i[1]),o=i[5],s=i[9],l=c(a,o,s);a/=l,o/=l,s/=l;var u=i[0],h=i[4],f=i[8],p=u*a+h*o+f*s,d=c(u-=a*p,h-=o*p,f-=s*p),g=(u/=d)*e+a*r,v=(h/=d)*e+o*r,m=(f/=d)*e+s*r;this.center.move(t,g,v,m);var y=Math.exp(this.computedRadius[0]);y=Math.max(1e-4,y+n),this.radius.set(t,Math.log(y))},p.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},p.setMatrix=function(t,e,r,n){var a=1;\"number\"==typeof r&&(a=0|r),(a<0||a>3)&&(a=1);var o=(a+2)%3;e||(this.recalcMatrix(t),e=this.computedMatrix);var s=e[a],l=e[a+4],h=e[a+8];if(n){var f=Math.abs(s),p=Math.abs(l),d=Math.abs(h),g=Math.max(f,p,d);f===g?(s=s<0?-1:1,l=h=0):d===g?(h=h<0?-1:1,s=l=0):(l=l<0?-1:1,s=h=0)}else{var v=c(s,l,h);s/=v,l/=v,h/=v}var m,y,x=e[o],b=e[o+4],_=e[o+8],w=x*s+b*l+_*h,k=c(x-=s*w,b-=l*w,_-=h*w),T=l*(_/=k)-h*(b/=k),A=h*(x/=k)-s*_,M=s*b-l*x,S=c(T,A,M);if(T/=S,A/=S,M/=S,this.center.jump(t,H,G,Y),this.radius.idle(t),this.up.jump(t,s,l,h),this.right.jump(t,x,b,_),2===a){var E=e[1],C=e[5],L=e[9],P=E*x+C*b+L*_,O=E*T+C*A+L*M;m=R<0?-Math.PI/2:Math.PI/2,y=Math.atan2(O,P)}else{var z=e[2],I=e[6],D=e[10],R=z*s+I*l+D*h,F=z*x+I*b+D*_,B=z*T+I*A+D*M;m=Math.asin(u(R)),y=Math.atan2(B,F)}this.angle.jump(t,y,m),this.recalcMatrix(t);var N=e[2],j=e[6],U=e[10],V=this.computedMatrix;i(V,e);var q=V[15],H=V[12]/q,G=V[13]/q,Y=V[14]/q,W=Math.exp(this.computedRadius[0]);this.center.jump(t,H-N*W,G-j*W,Y-U*W)},p.lastT=function(){return Math.max(this.center.lastT(),this.up.lastT(),this.right.lastT(),this.radius.lastT(),this.angle.lastT())},p.idle=function(t){this.center.idle(t),this.up.idle(t),this.right.idle(t),this.radius.idle(t),this.angle.idle(t)},p.flush=function(t){this.center.flush(t),this.up.flush(t),this.right.flush(t),this.radius.flush(t),this.angle.flush(t)},p.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},p.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||this.computedCenter;var i=(n=n||this.computedUp)[0],a=n[1],o=n[2],s=c(i,a,o);if(!(s<1e-6)){i/=s,a/=s,o/=s;var l=e[0]-r[0],h=e[1]-r[1],f=e[2]-r[2],p=c(l,h,f);if(!(p<1e-6)){l/=p,h/=p,f/=p;var d=this.computedRight,g=d[0],v=d[1],m=d[2],y=i*g+a*v+o*m,x=c(g-=y*i,v-=y*a,m-=y*o);if(!(x<.01&&(x=c(g=a*f-o*h,v=o*l-i*f,m=i*h-a*l))<1e-6)){g/=x,v/=x,m/=x,this.up.set(t,i,a,o),this.right.set(t,g,v,m),this.center.set(t,r[0],r[1],r[2]),this.radius.set(t,Math.log(p));var b=a*m-o*v,_=o*g-i*m,w=i*v-a*g,k=c(b,_,w),T=i*l+a*h+o*f,A=g*l+v*h+m*f,M=(b/=k)*l+(_/=k)*h+(w/=k)*f,S=Math.asin(u(T)),E=Math.atan2(M,A),C=this.angle._state,L=C[C.length-1],P=C[C.length-2];L%=2*Math.PI;var O=Math.abs(L+2*Math.PI-E),z=Math.abs(L-E),I=Math.abs(L-2*Math.PI-E);O<z&&(L+=2*Math.PI),I<z&&(L-=2*Math.PI),this.angle.jump(this.angle.lastT(),L,P),this.angle.set(t,E,S)}}}}},{\"filtered-vector\":226,\"gl-mat4/invert\":265,\"gl-mat4/rotate\":270,\"gl-vec3/cross\":334,\"gl-vec3/dot\":339,\"gl-vec3/normalize\":356}],543:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var i=t*e,a=n*t,o=a-(a-t),s=t-o,l=n*e,c=l-(l-e),u=e-c,h=s*u-(i-o*c-s*c-o*u);if(r)return r[0]=h,r[1]=i,r;return[h,i]};var n=+(Math.pow(2,27)+1)},{}],544:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=t+e,i=n-t,a=e-i,o=t-(n-i);if(r)return r[0]=o+a,r[1]=n,r;return[o+a,n]}},{}],545:[function(t,e,r){(function(e,n){\"use strict\";var i=t(\"bit-twiddle\"),a=t(\"dup\");e.__TYPEDARRAY_POOL||(e.__TYPEDARRAY_POOL={UINT8:a([32,0]),UINT16:a([32,0]),UINT32:a([32,0]),INT8:a([32,0]),INT16:a([32,0]),INT32:a([32,0]),FLOAT:a([32,0]),DOUBLE:a([32,0]),DATA:a([32,0]),UINT8C:a([32,0]),BUFFER:a([32,0])});var o=\"undefined\"!=typeof Uint8ClampedArray,s=e.__TYPEDARRAY_POOL;s.UINT8C||(s.UINT8C=a([32,0])),s.BUFFER||(s.BUFFER=a([32,0]));var l=s.DATA,c=s.BUFFER;function u(t){if(t){var e=t.length||t.byteLength,r=i.log2(e);l[r].push(t)}}function h(t){t=i.nextPow2(t);var e=i.log2(t),r=l[e];return r.length>0?r.pop():new ArrayBuffer(t)}function f(t){return new Uint8Array(h(t),0,t)}function p(t){return new Uint16Array(h(2*t),0,t)}function d(t){return new Uint32Array(h(4*t),0,t)}function g(t){return new Int8Array(h(t),0,t)}function v(t){return new Int16Array(h(2*t),0,t)}function m(t){return new Int32Array(h(4*t),0,t)}function y(t){return new Float32Array(h(4*t),0,t)}function x(t){return new Float64Array(h(8*t),0,t)}function b(t){return o?new Uint8ClampedArray(h(t),0,t):f(t)}function _(t){return new DataView(h(t),0,t)}function w(t){t=i.nextPow2(t);var e=i.log2(t),r=c[e];return r.length>0?r.pop():new n(t)}r.free=function(t){if(n.isBuffer(t))c[i.log2(t.length)].push(t);else{if(\"[object ArrayBuffer]\"!==Object.prototype.toString.call(t)&&(t=t.buffer),!t)return;var e=t.length||t.byteLength,r=0|i.log2(e);l[r].push(t)}},r.freeUint8=r.freeUint16=r.freeUint32=r.freeInt8=r.freeInt16=r.freeInt32=r.freeFloat32=r.freeFloat=r.freeFloat64=r.freeDouble=r.freeUint8Clamped=r.freeDataView=function(t){u(t.buffer)},r.freeArrayBuffer=u,r.freeBuffer=function(t){c[i.log2(t.length)].push(t)},r.malloc=function(t,e){if(void 0===e||\"arraybuffer\"===e)return h(t);switch(e){case\"uint8\":return f(t);case\"uint16\":return p(t);case\"uint32\":return d(t);case\"int8\":return g(t);case\"int16\":return v(t);case\"int32\":return m(t);case\"float\":case\"float32\":return y(t);case\"double\":case\"float64\":return x(t);case\"uint8_clamped\":return b(t);case\"buffer\":return w(t);case\"data\":case\"dataview\":return _(t);default:return null}return null},r.mallocArrayBuffer=h,r.mallocUint8=f,r.mallocUint16=p,r.mallocUint32=d,r.mallocInt8=g,r.mallocInt16=v,r.mallocInt32=m,r.mallocFloat32=r.mallocFloat=y,r.mallocFloat64=r.mallocDouble=x,r.mallocUint8Clamped=b,r.mallocDataView=_,r.mallocBuffer=w,r.clearCache=function(){for(var t=0;t<32;++t)s.UINT8[t].length=0,s.UINT16[t].length=0,s.UINT32[t].length=0,s.INT8[t].length=0,s.INT16[t].length=0,s.INT32[t].length=0,s.FLOAT[t].length=0,s.DOUBLE[t].length=0,s.UINT8C[t].length=0,l[t].length=0,c[t].length=0}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{},t(\"buffer\").Buffer)},{\"bit-twiddle\":92,buffer:105,dup:170}],546:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n;var i=n.prototype;Object.defineProperty(i,\"length\",{get:function(){return this.roots.length}}),i.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},i.find=function(t){for(var e=t,r=this.roots;r[t]!==t;)t=r[t];for(;r[e]!==t;){var n=r[e];r[e]=t,e=n}return t},i.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],547:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return 0===t.length?t:e?(r||t.sort(e),function(t,e){for(var r=1,n=t.length,i=t[0],a=t[0],o=1;o<n;++o)if(a=i,e(i=t[o],a)){if(o===r){r++;continue}t[r++]=i}return t.length=r,t}(t,e)):(r||t.sort(),function(t){for(var e=1,r=t.length,n=t[0],i=t[0],a=1;a<r;++a,i=n)if(i=n,(n=t[a])!==i){if(a===e){e++;continue}t[e++]=n}return t.length=e,t}(t))}},{}],548:[function(t,e,r){var n=/[\\'\\\"]/;e.exports=function(t){return t?(n.test(t.charAt(0))&&(t=t.substr(1)),n.test(t.charAt(t.length-1))&&(t=t.substr(0,t.length-1)),t):\"\"}},{}],549:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){Array.isArray(r)||(r=[].slice.call(arguments,2));for(var n=0,i=r.length;n<i;n++){var a=r[n];for(var o in a)if((void 0===e[o]||Array.isArray(e[o])||t[o]!==e[o])&&o in e){var s;if(!0===a[o])s=e[o];else{if(!1===a[o])continue;if(\"function\"==typeof a[o]&&void 0===(s=a[o](e[o],t,e)))continue}t[o]=s}}return t}},{}],550:[function(t,e,r){\"use strict\";e.exports=function(t,e){\"object\"==typeof e&&null!==e||(e={});return n(t,e.canvas||i,e.context||a,e)};var n=t(\"./lib/vtext\"),i=null,a=null;\"undefined\"!=typeof document&&((i=document.createElement(\"canvas\")).width=8192,i.height=1024,a=i.getContext(\"2d\"))},{\"./lib/vtext\":551}],551:[function(t,e,r){e.exports=function(t,e,r,n){var a=64,o=1.25,s={breaklines:!1,bolds:!1,italics:!1,subscripts:!1,superscripts:!1};n&&(n.size&&n.size>0&&(a=n.size),n.lineSpacing&&n.lineSpacing>0&&(o=n.lineSpacing),n.styletags&&n.styletags.breaklines&&(s.breaklines=!!n.styletags.breaklines),n.styletags&&n.styletags.bolds&&(s.bolds=!!n.styletags.bolds),n.styletags&&n.styletags.italics&&(s.italics=!!n.styletags.italics),n.styletags&&n.styletags.subscripts&&(s.subscripts=!!n.styletags.subscripts),n.styletags&&n.styletags.superscripts&&(s.superscripts=!!n.styletags.superscripts));return r.font=[n.fontStyle,n.fontVariant,n.fontWeight,a+\"px\",n.font].filter(function(t){return t}).join(\" \"),r.textAlign=\"start\",r.textBaseline=\"alphabetic\",r.direction=\"ltr\",w(function(t,e,r,n,a,o){r=r.replace(/\\n/g,\"\"),r=!0===o.breaklines?r.replace(/\\<br\\>/g,\"\\n\"):r.replace(/\\<br\\>/g,\" \");var s=\"\",l=[];for(k=0;k<r.length;++k)l[k]=s;!0===o.bolds&&(l=x(c,u,r,l)),!0===o.italics&&(l=x(h,f,r,l)),!0===o.superscripts&&(l=x(p,g,r,l)),!0===o.subscripts&&(l=x(v,y,r,l));var b=[],_=\"\";for(k=0;k<r.length;++k)null!==l[k]&&(_+=r[k],b.push(l[k]));var w,k,T,A,M,S=_.split(\"\\n\"),E=S.length,C=Math.round(a*n),L=n,P=2*n,O=0,z=E*C+P;t.height<z&&(t.height=z),e.fillStyle=\"#000\",e.fillRect(0,0,t.width,t.height),e.fillStyle=\"#fff\";var I=0,D=\"\";function R(){if(\"\"!==D){var t=e.measureText(D).width;e.fillText(D,L+T,P+A),T+=t}}function F(){return Math.round(M)+\"px \"}function B(t,r){var n=\"\"+e.font;if(!0===o.subscripts){var i=t.indexOf(m),a=r.indexOf(m),s=i>-1?parseInt(t[1+i]):0,l=a>-1?parseInt(r[1+a]):0;s!==l&&(n=n.replace(F(),\"?px \"),M*=Math.pow(.75,l-s),n=n.replace(\"?px \",F())),A+=.25*C*(l-s)}if(!0===o.superscripts){var c=t.indexOf(d),h=r.indexOf(d),p=c>-1?parseInt(t[1+c]):0,g=h>-1?parseInt(r[1+h]):0;p!==g&&(n=n.replace(F(),\"?px \"),M*=Math.pow(.75,g-p),n=n.replace(\"?px \",F())),A-=.25*C*(g-p)}if(!0===o.bolds){var v=t.indexOf(u)>-1,y=r.indexOf(u)>-1;!v&&y&&(n=x?n.replace(\"italic \",\"italic bold \"):\"bold \"+n),v&&!y&&(n=n.replace(\"bold \",\"\"))}if(!0===o.italics){var x=t.indexOf(f)>-1,b=r.indexOf(f)>-1;!x&&b&&(n=\"italic \"+n),x&&!b&&(n=n.replace(\"italic \",\"\"))}e.font=n}for(w=0;w<E;++w){var N=S[w]+\"\\n\";for(T=0,A=w*C,M=n,D=\"\",k=0;k<N.length;++k){var j=k+I<b.length?b[k+I]:b[b.length-1];s===j?D+=N[k]:(R(),D=N[k],void 0!==j&&(B(s,j),s=j))}R(),I+=N.length;var U=0|Math.round(T+2*L);O<U&&(O=U)}var V=O,q=P+C*E;return i(e.getImageData(0,0,V,q).data,[q,V,4]).pick(-1,-1,0).transpose(1,0)}(e,r,t,a,o,s),n,a)},e.exports.processPixels=w;var n=t(\"surface-nets\"),i=t(\"ndarray\"),a=t(\"simplify-planar-graph\"),o=t(\"clean-pslg\"),s=t(\"cdt2d\"),l=t(\"planar-graph-to-polyline\"),c=\"b\",u=\"b|\",h=\"i\",f=\"i|\",p=\"sup\",d=\"+\",g=\"+1\",v=\"sub\",m=\"-\",y=\"-1\";function x(t,e,r,n){for(var i=\"<\"+t+\">\",a=\"</\"+t+\">\",o=i.length,s=a.length,l=e[0]===d||e[0]===m,c=0,u=-s;c>-1&&-1!==(c=r.indexOf(i,c))&&-1!==(u=r.indexOf(a,c+o))&&!(u<=c);){for(var h=c;h<u+s;++h)if(h<c+o||h>=u)n[h]=null,r=r.substr(0,h)+\" \"+r.substr(h+1);else if(null!==n[h]){var f=n[h].indexOf(e[0]);-1===f?n[h]+=e:l&&(n[h]=n[h].substr(0,f+1)+(1+parseInt(n[h][f+1]))+n[h].substr(f+2))}var p=c+o,g=r.substr(p,u-p).indexOf(i);c=-1!==g?g:u+s}return n}function b(t,e){var r=n(t,128);return e?a(r.cells,r.positions,.25):{edges:r.cells,positions:r.positions}}function _(t,e,r,n){var i=b(t,n),a=function(t,e,r){for(var n=e.textAlign||\"start\",i=e.textBaseline||\"alphabetic\",a=[1<<30,1<<30],o=[0,0],s=t.length,l=0;l<s;++l)for(var c=t[l],u=0;u<2;++u)a[u]=0|Math.min(a[u],c[u]),o[u]=0|Math.max(o[u],c[u]);var h=0;switch(n){case\"center\":h=-.5*(a[0]+o[0]);break;case\"right\":case\"end\":h=-o[0];break;case\"left\":case\"start\":h=-a[0];break;default:throw new Error(\"vectorize-text: Unrecognized textAlign: '\"+n+\"'\")}var f=0;switch(i){case\"hanging\":case\"top\":f=-a[1];break;case\"middle\":f=-.5*(a[1]+o[1]);break;case\"alphabetic\":case\"ideographic\":f=-3*r;break;case\"bottom\":f=-o[1];break;default:throw new Error(\"vectorize-text: Unrecoginized textBaseline: '\"+i+\"'\")}var p=1/r;return\"lineHeight\"in e?p*=+e.lineHeight:\"width\"in e?p=e.width/(o[0]-a[0]):\"height\"in e&&(p=e.height/(o[1]-a[1])),t.map(function(t){return[p*(t[0]+h),p*(t[1]+f)]})}(i.positions,e,r),c=i.edges,u=\"ccw\"===e.orientation;if(o(a,c),e.polygons||e.polygon||e.polyline){for(var h=l(c,a),f=new Array(h.length),p=0;p<h.length;++p){for(var d=h[p],g=new Array(d.length),v=0;v<d.length;++v){for(var m=d[v],y=new Array(m.length),x=0;x<m.length;++x)y[x]=a[m[x]].slice();u&&y.reverse(),g[v]=y}f[p]=g}return f}return e.triangles||e.triangulate||e.triangle?{cells:s(a,c,{delaunay:!1,exterior:!1,interior:!0}),positions:a}:{edges:c,positions:a}}function w(t,e,r){try{return _(t,e,r,!0)}catch(t){}try{return _(t,e,r,!1)}catch(t){}return e.polygons||e.polyline||e.polygon?[]:e.triangles||e.triangulate||e.triangle?{cells:[],positions:[]}:{edges:[],positions:[]}}},{cdt2d:106,\"clean-pslg\":116,ndarray:450,\"planar-graph-to-polyline\":468,\"simplify-planar-graph\":524,\"surface-nets\":531}],552:[function(t,e,r){!function(){\"use strict\";if(\"undefined\"==typeof ses||!ses.ok||ses.ok()){\"undefined\"!=typeof ses&&(ses.weakMapPermitHostObjects=v);var t=!1;if(\"function\"==typeof WeakMap){var r=WeakMap;if(\"undefined\"!=typeof navigator&&/Firefox/.test(navigator.userAgent));else{var n=new r,i=Object.freeze({});if(n.set(i,1),1===n.get(i))return void(e.exports=WeakMap);t=!0}}Object.prototype.hasOwnProperty;var a=Object.getOwnPropertyNames,o=Object.defineProperty,s=Object.isExtensible,l=\"weakmap:\",c=l+\"ident:\"+Math.random()+\"___\";if(\"undefined\"!=typeof crypto&&\"function\"==typeof crypto.getRandomValues&&\"function\"==typeof ArrayBuffer&&\"function\"==typeof Uint8Array){var u=new ArrayBuffer(25),h=new Uint8Array(u);crypto.getRandomValues(h),c=l+\"rand:\"+Array.prototype.map.call(h,function(t){return(t%36).toString(36)}).join(\"\")+\"___\"}if(o(Object,\"getOwnPropertyNames\",{value:function(t){return a(t).filter(m)}}),\"getPropertyNames\"in Object){var f=Object.getPropertyNames;o(Object,\"getPropertyNames\",{value:function(t){return f(t).filter(m)}})}!function(){var t=Object.freeze;o(Object,\"freeze\",{value:function(e){return y(e),t(e)}});var e=Object.seal;o(Object,\"seal\",{value:function(t){return y(t),e(t)}});var r=Object.preventExtensions;o(Object,\"preventExtensions\",{value:function(t){return y(t),r(t)}})}();var p=!1,d=0,g=function(){this instanceof g||b();var t=[],e=[],r=d++;return Object.create(g.prototype,{get___:{value:x(function(n,i){var a,o=y(n);return o?r in o?o[r]:i:(a=t.indexOf(n))>=0?e[a]:i})},has___:{value:x(function(e){var n=y(e);return n?r in n:t.indexOf(e)>=0})},set___:{value:x(function(n,i){var a,o=y(n);return o?o[r]=i:(a=t.indexOf(n))>=0?e[a]=i:(a=t.length,e[a]=i,t[a]=n),this})},delete___:{value:x(function(n){var i,a,o=y(n);return o?r in o&&delete o[r]:!((i=t.indexOf(n))<0||(a=t.length-1,t[i]=void 0,e[i]=e[a],t[i]=t[a],t.length=a,e.length=a,0))})}})};g.prototype=Object.create(Object.prototype,{get:{value:function(t,e){return this.get___(t,e)},writable:!0,configurable:!0},has:{value:function(t){return this.has___(t)},writable:!0,configurable:!0},set:{value:function(t,e){return this.set___(t,e)},writable:!0,configurable:!0},delete:{value:function(t){return this.delete___(t)},writable:!0,configurable:!0}}),\"function\"==typeof r?function(){function n(){this instanceof g||b();var e,n=new r,i=void 0,a=!1;return e=t?function(t,e){return n.set(t,e),n.has(t)||(i||(i=new g),i.set(t,e)),this}:function(t,e){if(a)try{n.set(t,e)}catch(r){i||(i=new g),i.set___(t,e)}else n.set(t,e);return this},Object.create(g.prototype,{get___:{value:x(function(t,e){return i?n.has(t)?n.get(t):i.get___(t,e):n.get(t,e)})},has___:{value:x(function(t){return n.has(t)||!!i&&i.has___(t)})},set___:{value:x(e)},delete___:{value:x(function(t){var e=!!n.delete(t);return i&&i.delete___(t)||e})},permitHostObjects___:{value:x(function(t){if(t!==v)throw new Error(\"bogus call to permitHostObjects___\");a=!0})}})}t&&\"undefined\"!=typeof Proxy&&(Proxy=void 0),n.prototype=g.prototype,e.exports=n,Object.defineProperty(WeakMap.prototype,\"constructor\",{value:WeakMap,enumerable:!1,configurable:!0,writable:!0})}():(\"undefined\"!=typeof Proxy&&(Proxy=void 0),e.exports=g)}function v(t){t.permitHostObjects___&&t.permitHostObjects___(v)}function m(t){return!(t.substr(0,l.length)==l&&\"___\"===t.substr(t.length-3))}function y(t){if(t!==Object(t))throw new TypeError(\"Not an object: \"+t);var e=t[c];if(e&&e.key===t)return e;if(s(t)){e={key:t};try{return o(t,c,{value:e,writable:!1,enumerable:!1,configurable:!1}),e}catch(t){return}}}function x(t){return t.prototype=null,Object.freeze(t)}function b(){p||\"undefined\"==typeof console||(p=!0,console.warn(\"WeakMap should be invoked as new WeakMap(), not WeakMap(). This will be an error in the future.\"))}}()},{}],553:[function(t,e,r){var n=t(\"./hidden-store.js\");e.exports=function(){var t={};return function(e){if((\"object\"!=typeof e||null===e)&&\"function\"!=typeof e)throw new Error(\"Weakmap-shim: Key must be object\");var r=e.valueOf(t);return r&&r.identity===t?r:n(e,t)}}},{\"./hidden-store.js\":554}],554:[function(t,e,r){e.exports=function(t,e){var r={identity:e},n=t.valueOf;return Object.defineProperty(t,\"valueOf\",{value:function(t){return t!==e?n.apply(this,arguments):r},writable:!0}),r}},{}],555:[function(t,e,r){var n=t(\"./create-store.js\");e.exports=function(){var t=n();return{get:function(e,r){var n=t(e);return n.hasOwnProperty(\"value\")?n.value:r},set:function(e,r){return t(e).value=r,this},has:function(e){return\"value\"in t(e)},delete:function(e){return delete t(e).value}}}},{\"./create-store.js\":553}],556:[function(t,e,r){var n=t(\"get-canvas-context\");e.exports=function(t){return n(\"webgl\",t)}},{\"get-canvas-context\":232}],557:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Chinese\",jdEpoch:1721425.5,hasYearZero:!1,minMonth:0,firstMonth:0,minDay:1,regionalOptions:{\"\":{name:\"Chinese\",epochs:[\"BEC\",\"EC\"],monthNumbers:function(t,e){if(\"string\"==typeof t){var r=t.match(l);return r?r[0]:\"\"}var n=this._validateYear(t),i=t.month(),a=\"\"+this.toChineseMonth(n,i);return e&&a.length<2&&(a=\"0\"+a),this.isIntercalaryMonth(n,i)&&(a+=\"i\"),a},monthNames:function(t){if(\"string\"==typeof t){var e=t.match(c);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\\u6708\",\"\\u4e8c\\u6708\",\"\\u4e09\\u6708\",\"\\u56db\\u6708\",\"\\u4e94\\u6708\",\"\\u516d\\u6708\",\"\\u4e03\\u6708\",\"\\u516b\\u6708\",\"\\u4e5d\\u6708\",\"\\u5341\\u6708\",\"\\u5341\\u4e00\\u6708\",\"\\u5341\\u4e8c\\u6708\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},monthNamesShort:function(t){if(\"string\"==typeof t){var e=t.match(u);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},parseMonth:function(t,e){t=this._validateYear(t);var r,n=parseInt(e);if(isNaN(n))\"\\u95f0\"===e[0]&&(r=!0,e=e.substring(1)),\"\\u6708\"===e[e.length-1]&&(e=e.substring(0,e.length-1)),n=1+[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"].indexOf(e);else{var i=e[e.length-1];r=\"i\"===i||\"I\"===i}return this.toMonthIndex(t,n,r)},dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},_validateYear:function(t,e){if(t.year&&(t=t.year()),\"number\"!=typeof t||t<1888||t>2111)throw e.replace(/\\{0\\}/,this.local.name);return t},toMonthIndex:function(t,e,r){var i=this.intercalaryMonth(t);if(r&&e!==i||e<1||e>12)throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return i?!r&&e<=i?e-1:e:e-1},toChineseMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);if(e<0||e>(r?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r?e<r?e+1:e:e+1},intercalaryMonth:function(t){return t=this._validateYear(t),h[t-h[0]]>>13},isIntercalaryMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);return!!r&&r===e},leapYear:function(t){return 0!==this.intercalaryMonth(t)},weekOfYear:function(t,e,r){var i,o=this._validateYear(t,n.local.invalidyear),s=f[o-f[0]],l=s>>9&4095,c=s>>5&15,u=31&s;(i=a.newDate(l,c,u)).add(4-(i.dayOfWeek()||7),\"d\");var h=this.toJD(t,e,r)-i.toJD();return 1+Math.floor(h/7)},monthsInYear:function(t){return this.leapYear(t)?13:12},daysInMonth:function(t,e){t.year&&(e=t.month(),t=t.year()),t=this._validateYear(t);var r=h[t-h[0]];if(e>(r>>13?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r&1<<12-e?30:29},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,s,r,n.local.invalidDate);t=this._validateYear(i.year()),e=i.month(),r=i.day();var o=this.isIntercalaryMonth(t,e),s=this.toChineseMonth(t,e),l=function(t,e,r,n,i){var a,o,s;if(\"object\"==typeof t)o=t,a=e||{};else{var l=\"number\"==typeof t&&t>=1888&&t<=2111;if(!l)throw new Error(\"Lunar year outside range 1888-2111\");var c=\"number\"==typeof e&&e>=1&&e<=12;if(!c)throw new Error(\"Lunar month outside range 1 - 12\");var u,p=\"number\"==typeof r&&r>=1&&r<=30;if(!p)throw new Error(\"Lunar day outside range 1 - 30\");\"object\"==typeof n?(u=!1,a=n):(u=!!n,a=i||{}),o={year:t,month:e,day:r,isIntercalary:u}}s=o.day-1;var d,g=h[o.year-h[0]],v=g>>13;d=v?o.month>v?o.month:o.isIntercalary?o.month:o.month-1:o.month-1;for(var m=0;m<d;m++){var y=g&1<<12-m?30:29;s+=y}var x=f[o.year-f[0]],b=new Date(x>>9&4095,(x>>5&15)-1,(31&x)+s);return a.year=b.getFullYear(),a.month=1+b.getMonth(),a.day=b.getDate(),a}(t,s,r,o);return a.toJD(l.year,l.month,l.day)},fromJD:function(t){var e=a.fromJD(t),r=function(t,e,r,n){var i,a;if(\"object\"==typeof t)i=t,a=e||{};else{var o=\"number\"==typeof t&&t>=1888&&t<=2111;if(!o)throw new Error(\"Solar year outside range 1888-2111\");var s=\"number\"==typeof e&&e>=1&&e<=12;if(!s)throw new Error(\"Solar month outside range 1 - 12\");var l=\"number\"==typeof r&&r>=1&&r<=31;if(!l)throw new Error(\"Solar day outside range 1 - 31\");i={year:t,month:e,day:r},a=n||{}}var c=f[i.year-f[0]],u=i.year<<9|i.month<<5|i.day;a.year=u>=c?i.year:i.year-1,c=f[a.year-f[0]];var p,d=new Date(c>>9&4095,(c>>5&15)-1,31&c),g=new Date(i.year,i.month-1,i.day);p=Math.round((g-d)/864e5);var v,m=h[a.year-h[0]];for(v=0;v<13;v++){var y=m&1<<12-v?30:29;if(p<y)break;p-=y}var x=m>>13;!x||v<x?(a.isIntercalary=!1,a.month=1+v):v===x?(a.isIntercalary=!0,a.month=v):(a.isIntercalary=!1,a.month=v);return a.day=1+p,a}(e.year(),e.month(),e.day()),n=this.toMonthIndex(r.year,r.month,r.isIntercalary);return this.newDate(r.year,n,r.day)},fromString:function(t){var e=t.match(s),r=this._validateYear(+e[1]),n=+e[2],i=!!e[3],a=this.toMonthIndex(r,n,i),o=+e[4];return this.newDate(r,a,o)},add:function(t,e,r){var n=t.year(),i=t.month(),a=this.isIntercalaryMonth(n,i),s=this.toChineseMonth(n,i),l=Object.getPrototypeOf(o.prototype).add.call(this,t,e,r);if(\"y\"===r){var c=l.year(),u=l.month(),h=this.isIntercalaryMonth(c,s),f=a&&h?this.toMonthIndex(c,s,!0):this.toMonthIndex(c,s,!1);f!==u&&l.month(f)}return l}});var s=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)[-\\/](\\d?\\d)([iI]?)[-\\/](\\d?\\d)/m,l=/^\\d?\\d[iI]?/m,c=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?\\u6708/m,u=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?/m;n.calendars.chinese=o;var h=[1887,5780,5802,19157,2742,50359,1198,2646,46378,7466,3412,30122,5482,67949,2396,5294,43597,6732,6954,36181,2772,4954,18781,2396,54427,5274,6730,47781,5800,6868,21210,4790,59703,2350,5270,46667,3402,3496,38325,1388,4782,18735,2350,52374,6804,7498,44457,2906,1388,29294,4700,63789,6442,6804,56138,5802,2772,38235,1210,4698,22827,5418,63125,3476,5802,43701,2484,5302,27223,2646,70954,7466,3412,54698,5482,2412,38062,5294,2636,32038,6954,60245,2772,4826,43357,2394,5274,39501,6730,72357,5800,5844,53978,4790,2358,38039,5270,87627,3402,3496,54708,5484,4782,43311,2350,3222,27978,7498,68965,2904,5484,45677,4700,6444,39573,6804,6986,19285,2772,62811,1210,4698,47403,5418,5780,38570,5546,76469,2420,5302,51799,2646,5414,36501,3412,5546,18869,2412,54446,5276,6732,48422,6822,2900,28010,4826,92509,2394,5274,55883,6730,6820,47956,5812,2778,18779,2358,62615,5270,5450,46757,3492,5556,27318,4718,67887,2350,3222,52554,7498,3428,38252,5468,4700,31022,6444,64149,6804,6986,43861,2772,5338,35421,2650,70955,5418,5780,54954,5546,2740,38074,5302,2646,29991,3366,61011,3412,5546,43445,2412,5294,35406,6732,72998,6820,6996,52586,2778,2396,38045,5274,6698,23333,6820,64338,5812,2746,43355,2358,5270,39499,5450,79525,3492,5548],f=[1887,966732,967231,967733,968265,968766,969297,969798,970298,970829,971330,971830,972362,972863,973395,973896,974397,974928,975428,975929,976461,976962,977462,977994,978494,979026,979526,980026,980558,981059,981559,982091,982593,983124,983624,984124,984656,985157,985656,986189,986690,987191,987722,988222,988753,989254,989754,990286,990788,991288,991819,992319,992851,993352,993851,994383,994885,995385,995917,996418,996918,997450,997949,998481,998982,999483,1000014,1000515,1001016,1001548,1002047,1002578,1003080,1003580,1004111,1004613,1005113,1005645,1006146,1006645,1007177,1007678,1008209,1008710,1009211,1009743,1010243,1010743,1011275,1011775,1012306,1012807,1013308,1013840,1014341,1014841,1015373,1015874,1016404,1016905,1017405,1017937,1018438,1018939,1019471,1019972,1020471,1021002,1021503,1022035,1022535,1023036,1023568,1024069,1024568,1025100,1025601,1026102,1026633,1027133,1027666,1028167,1028666,1029198,1029699,1030199,1030730,1031231,1031763,1032264,1032764,1033296,1033797,1034297,1034828,1035329,1035830,1036362,1036861,1037393,1037894,1038394,1038925,1039427,1039927,1040459,1040959,1041491,1041992,1042492,1043023,1043524,1044024,1044556,1045057,1045558,1046090,1046590,1047121,1047622,1048122,1048654,1049154,1049655,1050187,1050689,1051219,1051720,1052220,1052751,1053252,1053752,1054284,1054786,1055285,1055817,1056317,1056849,1057349,1057850,1058382,1058883,1059383,1059915,1060415,1060947,1061447,1061947,1062479,1062981,1063480,1064012,1064514,1065014,1065545,1066045,1066577,1067078,1067578,1068110,1068611,1069112,1069642,1070142,1070674,1071175,1071675,1072207,1072709,1073209,1073740,1074241,1074741,1075273,1075773,1076305,1076807,1077308,1077839,1078340,1078840,1079372,1079871,1080403,1080904]},{\"../main\":571,\"object-assign\":454}],558:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Coptic\",jdEpoch:1825029.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Coptic\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Thout\",\"Paopi\",\"Hathor\",\"Koiak\",\"Tobi\",\"Meshir\",\"Paremhat\",\"Paremoude\",\"Pashons\",\"Paoni\",\"Epip\",\"Mesori\",\"Pi Kogi Enavot\"],monthNamesShort:[\"Tho\",\"Pao\",\"Hath\",\"Koi\",\"Tob\",\"Mesh\",\"Pat\",\"Pad\",\"Pash\",\"Pao\",\"Epi\",\"Meso\",\"PiK\"],dayNames:[\"Tkyriaka\",\"Pesnau\",\"Pshoment\",\"Peftoou\",\"Ptiou\",\"Psoou\",\"Psabbaton\"],dayNamesShort:[\"Tky\",\"Pes\",\"Psh\",\"Pef\",\"Pti\",\"Pso\",\"Psa\"],dayNamesMin:[\"Tk\",\"Pes\",\"Psh\",\"Pef\",\"Pt\",\"Pso\",\"Psa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.coptic=a},{\"../main\":571,\"object-assign\":454}],559:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Discworld\",jdEpoch:1721425.5,daysPerMonth:[16,32,32,32,32,32,32,32,32,32,32,32,32],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Discworld\",epochs:[\"BUC\",\"UC\"],monthNames:[\"Ick\",\"Offle\",\"February\",\"March\",\"April\",\"May\",\"June\",\"Grune\",\"August\",\"Spune\",\"Sektober\",\"Ember\",\"December\"],monthNamesShort:[\"Ick\",\"Off\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Gru\",\"Aug\",\"Spu\",\"Sek\",\"Emb\",\"Dec\"],dayNames:[\"Sunday\",\"Octeday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Oct\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Oc\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:2,isRTL:!1}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),13},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),400},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/8)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]},daysInWeek:function(){return 8},dayOfWeek:function(t,e,r){return(this._validate(t,e,r,n.local.invalidDate).day()+1)%8},weekDay:function(t,e,r){var n=this.dayOfWeek(t,e,r);return n>=2&&n<=6},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{century:o[Math.floor((i.year()-1)/100)+1]||\"\"}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year()+(i.year()<0?1:0),e=i.month(),(r=i.day())+(e>1?16:0)+(e>2?32*(e-2):0)+400*(t-1)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t+.5)-Math.floor(this.jdEpoch)-1;var e=Math.floor(t/400)+1;t-=400*(e-1),t+=t>15?16:0;var r=Math.floor(t/32)+1,n=t-32*(r-1)+1;return this.newDate(e<=0?e-1:e,r,n)}});var o={20:\"Fruitbat\",21:\"Anchovy\"};n.calendars.discworld=a},{\"../main\":571,\"object-assign\":454}],560:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Ethiopian\",jdEpoch:1724220.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Ethiopian\",epochs:[\"BEE\",\"EE\"],monthNames:[\"Meskerem\",\"Tikemet\",\"Hidar\",\"Tahesas\",\"Tir\",\"Yekatit\",\"Megabit\",\"Miazia\",\"Genbot\",\"Sene\",\"Hamle\",\"Nehase\",\"Pagume\"],monthNamesShort:[\"Mes\",\"Tik\",\"Hid\",\"Tah\",\"Tir\",\"Yek\",\"Meg\",\"Mia\",\"Gen\",\"Sen\",\"Ham\",\"Neh\",\"Pag\"],dayNames:[\"Ehud\",\"Segno\",\"Maksegno\",\"Irob\",\"Hamus\",\"Arb\",\"Kidame\"],dayNamesShort:[\"Ehu\",\"Seg\",\"Mak\",\"Iro\",\"Ham\",\"Arb\",\"Kid\"],dayNamesMin:[\"Eh\",\"Se\",\"Ma\",\"Ir\",\"Ha\",\"Ar\",\"Ki\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.ethiopian=a},{\"../main\":571,\"object-assign\":454}],561:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Hebrew\",jdEpoch:347995.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29,29],hasYearZero:!1,minMonth:1,firstMonth:7,minDay:1,regionalOptions:{\"\":{name:\"Hebrew\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Nisan\",\"Iyar\",\"Sivan\",\"Tammuz\",\"Av\",\"Elul\",\"Tishrei\",\"Cheshvan\",\"Kislev\",\"Tevet\",\"Shevat\",\"Adar\",\"Adar II\"],monthNamesShort:[\"Nis\",\"Iya\",\"Siv\",\"Tam\",\"Av\",\"Elu\",\"Tis\",\"Che\",\"Kis\",\"Tev\",\"She\",\"Ada\",\"Ad2\"],dayNames:[\"Yom Rishon\",\"Yom Sheni\",\"Yom Shlishi\",\"Yom Revi'i\",\"Yom Chamishi\",\"Yom Shishi\",\"Yom Shabbat\"],dayNamesShort:[\"Ris\",\"She\",\"Shl\",\"Rev\",\"Cha\",\"Shi\",\"Sha\"],dayNamesMin:[\"Ri\",\"She\",\"Shl\",\"Re\",\"Ch\",\"Shi\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return this._leapYear(e.year())},_leapYear:function(t){return o(7*(t=t<0?t+1:t)+1,19)<7},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),this._leapYear(t.year?t.year():t)?13:12},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),this.toJD(-1===t?1:t+1,7,1)-this.toJD(t,7,1)},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),12===e&&this.leapYear(t)?30:8===e&&5===o(this.daysInYear(t),10)?30:9===e&&3===o(this.daysInYear(t),10)?29:this.daysPerMonth[e-1]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{yearType:(this.leapYear(i)?\"embolismic\":\"common\")+\" \"+[\"deficient\",\"regular\",\"complete\"][this.daysInYear(i)%10-3]}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t<=0?t+1:t,o=this.jdEpoch+this._delay1(a)+this._delay2(a)+r+1;if(e<7){for(var s=7;s<=this.monthsInYear(t);s++)o+=this.daysInMonth(t,s);for(s=1;s<e;s++)o+=this.daysInMonth(t,s)}else for(s=7;s<e;s++)o+=this.daysInMonth(t,s);return o},_delay1:function(t){var e=Math.floor((235*t-234)/19),r=12084+13753*e,n=29*e+Math.floor(r/25920);return o(3*(n+1),7)<3&&n++,n},_delay2:function(t){var e=this._delay1(t-1),r=this._delay1(t);return this._delay1(t+1)-r==356?2:r-e==382?1:0},fromJD:function(t){t=Math.floor(t)+.5;for(var e=Math.floor(98496*(t-this.jdEpoch)/35975351)-1;t>=this.toJD(-1===e?1:e+1,7,1);)e++;for(var r=t<this.toJD(e,1,1)?7:1;t>this.toJD(e,r,this.daysInMonth(e,r));)r++;var n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.hebrew=a},{\"../main\":571,\"object-assign\":454}],562:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Islamic\",jdEpoch:1948439.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Islamic\",epochs:[\"BH\",\"AH\"],monthNames:[\"Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' al-thani\",\"Jumada al-awwal\",\"Jumada al-thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-ahad\",\"Yawm al-ithnayn\",\"Yawm ath-thulaathaa'\",\"Yawm al-arbi'aa'\",\"Yawm al-kham\\u012bs\",\"Yawm al-jum'a\",\"Yawm as-sabt\"],dayNamesShort:[\"Aha\",\"Ith\",\"Thu\",\"Arb\",\"Kha\",\"Jum\",\"Sab\"],dayNamesMin:[\"Ah\",\"It\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){return(11*this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year()+14)%30<11},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return this.leapYear(t)?355:354},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),t=t<=0?t+1:t,(r=i.day())+Math.ceil(29.5*(e-1))+354*(t-1)+Math.floor((3+11*t)/30)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t)+.5;var e=Math.floor((30*(t-this.jdEpoch)+10646)/10631);e=e<=0?e-1:e;var r=Math.min(12,Math.ceil((t-29-this.toJD(e,1,1))/29.5)+1),n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.islamic=a},{\"../main\":571,\"object-assign\":454}],563:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Julian\",jdEpoch:1721423.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Julian\",epochs:[\"BC\",\"AD\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()<0?e.year()+1:e.year())%4==0},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),r=i.day(),t<0&&t++,e<=2&&(t--,e+=12),Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r-1524.5},fromJD:function(t){var e=Math.floor(t+.5)+1524,r=Math.floor((e-122.1)/365.25),n=Math.floor(365.25*r),i=Math.floor((e-n)/30.6001),a=i-Math.floor(i<14?1:13),o=r-Math.floor(a>2?4716:4715),s=e-n-Math.floor(30.6001*i);return o<=0&&o--,this.newDate(o,a,s)}}),n.calendars.julian=a},{\"../main\":571,\"object-assign\":454}],564:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}function s(t,e){return o(t-1,e)+1}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Mayan\",jdEpoch:584282.5,hasYearZero:!0,minMonth:0,firstMonth:0,minDay:0,regionalOptions:{\"\":{name:\"Mayan\",epochs:[\"\",\"\"],monthNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],monthNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],dayNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesMin:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],digits:null,dateFormat:\"YYYY.m.d\",firstDay:0,isRTL:!1,haabMonths:[\"Pop\",\"Uo\",\"Zip\",\"Zotz\",\"Tzec\",\"Xul\",\"Yaxkin\",\"Mol\",\"Chen\",\"Yax\",\"Zac\",\"Ceh\",\"Mac\",\"Kankin\",\"Muan\",\"Pax\",\"Kayab\",\"Cumku\",\"Uayeb\"],tzolkinMonths:[\"Imix\",\"Ik\",\"Akbal\",\"Kan\",\"Chicchan\",\"Cimi\",\"Manik\",\"Lamat\",\"Muluc\",\"Oc\",\"Chuen\",\"Eb\",\"Ben\",\"Ix\",\"Men\",\"Cib\",\"Caban\",\"Etznab\",\"Cauac\",\"Ahau\"]}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},formatYear:function(t){t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year();var e=Math.floor(t/400);return t%=400,t+=t<0?400:0,e+\".\"+Math.floor(t/20)+\".\"+t%20},forYear:function(t){if((t=t.split(\".\")).length<3)throw\"Invalid Mayan year\";for(var e=0,r=0;r<t.length;r++){var n=parseInt(t[r],10);if(Math.abs(n)>19||r>0&&n<0)throw\"Invalid Mayan year\";e=20*e+n}return e},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),18},weekOfYear:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),0},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),360},daysInMonth:function(t,e){return this._validate(t,e,this.minDay,n.local.invalidMonth),20},daysInWeek:function(){return 5},dayOfWeek:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate).day()},weekDay:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),!0},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate).toJD(),a=this._toHaab(i),o=this._toTzolkin(i);return{haabMonthName:this.local.haabMonths[a[0]-1],haabMonth:a[0],haabDay:a[1],tzolkinDayName:this.local.tzolkinMonths[o[0]-1],tzolkinDay:o[0],tzolkinTrecena:o[1]}},_toHaab:function(t){var e=o((t-=this.jdEpoch)+8+340,365);return[Math.floor(e/20)+1,o(e,20)]},_toTzolkin:function(t){return[s((t-=this.jdEpoch)+20,20),s(t+4,13)]},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return i.day()+20*i.month()+360*i.year()+this.jdEpoch},fromJD:function(t){t=Math.floor(t)+.5-this.jdEpoch;var e=Math.floor(t/360);t%=360,t+=t<0?360:0;var r=Math.floor(t/20),n=t%20;return this.newDate(e,r,n)}}),n.calendars.mayan=a},{\"../main\":571,\"object-assign\":454}],565:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar;var o=n.instance(\"gregorian\");i(a.prototype,{name:\"Nanakshahi\",jdEpoch:2257673.5,daysPerMonth:[31,31,31,31,31,30,30,30,30,30,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Nanakshahi\",epochs:[\"BN\",\"AN\"],monthNames:[\"Chet\",\"Vaisakh\",\"Jeth\",\"Harh\",\"Sawan\",\"Bhadon\",\"Assu\",\"Katak\",\"Maghar\",\"Poh\",\"Magh\",\"Phagun\"],monthNamesShort:[\"Che\",\"Vai\",\"Jet\",\"Har\",\"Saw\",\"Bha\",\"Ass\",\"Kat\",\"Mgr\",\"Poh\",\"Mgh\",\"Pha\"],dayNames:[\"Somvaar\",\"Mangalvar\",\"Budhvaar\",\"Veervaar\",\"Shukarvaar\",\"Sanicharvaar\",\"Etvaar\"],dayNamesShort:[\"Som\",\"Mangal\",\"Budh\",\"Veer\",\"Shukar\",\"Sanichar\",\"Et\"],dayNamesMin:[\"So\",\"Ma\",\"Bu\",\"Ve\",\"Sh\",\"Sa\",\"Et\"],digits:null,dateFormat:\"dd-mm-yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear);return o.leapYear(e.year()+(e.year()<1?1:0)+1469)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(1-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidMonth);(t=i.year())<0&&t++;for(var a=i.day(),s=1;s<i.month();s++)a+=this.daysPerMonth[s-1];return a+o.toJD(t+1468,3,13)},fromJD:function(t){t=Math.floor(t+.5);for(var e=Math.floor((t-(this.jdEpoch-1))/366);t>=this.toJD(e+1,1,1);)e++;for(var r=t-Math.floor(this.toJD(e,1,1)+.5)+1,n=1;r>this.daysInMonth(e,n);)r-=this.daysInMonth(e,n),n++;return this.newDate(e,n,r)}}),n.calendars.nanakshahi=a},{\"../main\":571,\"object-assign\":454}],566:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Nepali\",jdEpoch:1700709.5,daysPerMonth:[31,31,32,32,31,30,30,29,30,29,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,daysPerYear:365,regionalOptions:{\"\":{name:\"Nepali\",epochs:[\"BBS\",\"ABS\"],monthNames:[\"Baisakh\",\"Jestha\",\"Ashadh\",\"Shrawan\",\"Bhadra\",\"Ashwin\",\"Kartik\",\"Mangsir\",\"Paush\",\"Mangh\",\"Falgun\",\"Chaitra\"],monthNamesShort:[\"Bai\",\"Je\",\"As\",\"Shra\",\"Bha\",\"Ash\",\"Kar\",\"Mang\",\"Pau\",\"Ma\",\"Fal\",\"Chai\"],dayNames:[\"Aaitabaar\",\"Sombaar\",\"Manglbaar\",\"Budhabaar\",\"Bihibaar\",\"Shukrabaar\",\"Shanibaar\"],dayNamesShort:[\"Aaita\",\"Som\",\"Mangl\",\"Budha\",\"Bihi\",\"Shukra\",\"Shani\"],dayNamesMin:[\"Aai\",\"So\",\"Man\",\"Bu\",\"Bi\",\"Shu\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:1,isRTL:!1}},leapYear:function(t){return this.daysInYear(t)!==this.daysPerYear},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){if(t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t])return this.daysPerYear;for(var e=0,r=this.minMonth;r<=12;r++)e+=this.NEPALI_CALENDAR_DATA[t][r];return e},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t]?this.daysPerMonth[e-1]:this.NEPALI_CALENDAR_DATA[t][e]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=n.instance(),o=0,s=e,l=t;this._createMissingCalendarData(t);var c=t-(s>9||9===s&&r>=this.NEPALI_CALENDAR_DATA[l][0]?56:57);for(9!==e&&(o=r,s--);9!==s;)s<=0&&(s=12,l--),o+=this.NEPALI_CALENDAR_DATA[l][s],s--;return 9===e?(o+=r-this.NEPALI_CALENDAR_DATA[l][0])<0&&(o+=a.daysInYear(c)):o+=this.NEPALI_CALENDAR_DATA[l][9]-this.NEPALI_CALENDAR_DATA[l][0],a.newDate(c,1,1).add(o,\"d\").toJD()},fromJD:function(t){var e=n.instance().fromJD(t),r=e.year(),i=e.dayOfYear(),a=r+56;this._createMissingCalendarData(a);for(var o=9,s=this.NEPALI_CALENDAR_DATA[a][0],l=this.NEPALI_CALENDAR_DATA[a][o]-s+1;i>l;)++o>12&&(o=1,a++),l+=this.NEPALI_CALENDAR_DATA[a][o];var c=this.NEPALI_CALENDAR_DATA[a][o]-(l-i);return this.newDate(a,o,c)},_createMissingCalendarData:function(t){var e=this.daysPerMonth.slice(0);e.unshift(17);for(var r=t-1;r<t+2;r++)\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[r]&&(this.NEPALI_CALENDAR_DATA[r]=e)},NEPALI_CALENDAR_DATA:{1970:[18,31,31,32,31,31,31,30,29,30,29,30,30],1971:[18,31,31,32,31,32,30,30,29,30,29,30,30],1972:[17,31,32,31,32,31,30,30,30,29,29,30,30],1973:[19,30,32,31,32,31,30,30,30,29,30,29,31],1974:[19,31,31,32,30,31,31,30,29,30,29,30,30],1975:[18,31,31,32,32,30,31,30,29,30,29,30,30],1976:[17,31,32,31,32,31,30,30,30,29,29,30,31],1977:[18,31,32,31,32,31,31,29,30,29,30,29,31],1978:[18,31,31,32,31,31,31,30,29,30,29,30,30],1979:[18,31,31,32,32,31,30,30,29,30,29,30,30],1980:[17,31,32,31,32,31,30,30,30,29,29,30,31],1981:[18,31,31,31,32,31,31,29,30,30,29,30,30],1982:[18,31,31,32,31,31,31,30,29,30,29,30,30],1983:[18,31,31,32,32,31,30,30,29,30,29,30,30],1984:[17,31,32,31,32,31,30,30,30,29,29,30,31],1985:[18,31,31,31,32,31,31,29,30,30,29,30,30],1986:[18,31,31,32,31,31,31,30,29,30,29,30,30],1987:[18,31,32,31,32,31,30,30,29,30,29,30,30],1988:[17,31,32,31,32,31,30,30,30,29,29,30,31],1989:[18,31,31,31,32,31,31,30,29,30,29,30,30],1990:[18,31,31,32,31,31,31,30,29,30,29,30,30],1991:[18,31,32,31,32,31,30,30,29,30,29,30,30],1992:[17,31,32,31,32,31,30,30,30,29,30,29,31],1993:[18,31,31,31,32,31,31,30,29,30,29,30,30],1994:[18,31,31,32,31,31,31,30,29,30,29,30,30],1995:[17,31,32,31,32,31,30,30,30,29,29,30,30],1996:[17,31,32,31,32,31,30,30,30,29,30,29,31],1997:[18,31,31,32,31,31,31,30,29,30,29,30,30],1998:[18,31,31,32,31,31,31,30,29,30,29,30,30],1999:[17,31,32,31,32,31,30,30,30,29,29,30,31],2000:[17,30,32,31,32,31,30,30,30,29,30,29,31],2001:[18,31,31,32,31,31,31,30,29,30,29,30,30],2002:[18,31,31,32,32,31,30,30,29,30,29,30,30],2003:[17,31,32,31,32,31,30,30,30,29,29,30,31],2004:[17,30,32,31,32,31,30,30,30,29,30,29,31],2005:[18,31,31,32,31,31,31,30,29,30,29,30,30],2006:[18,31,31,32,32,31,30,30,29,30,29,30,30],2007:[17,31,32,31,32,31,30,30,30,29,29,30,31],2008:[17,31,31,31,32,31,31,29,30,30,29,29,31],2009:[18,31,31,32,31,31,31,30,29,30,29,30,30],2010:[18,31,31,32,32,31,30,30,29,30,29,30,30],2011:[17,31,32,31,32,31,30,30,30,29,29,30,31],2012:[17,31,31,31,32,31,31,29,30,30,29,30,30],2013:[18,31,31,32,31,31,31,30,29,30,29,30,30],2014:[18,31,31,32,32,31,30,30,29,30,29,30,30],2015:[17,31,32,31,32,31,30,30,30,29,29,30,31],2016:[17,31,31,31,32,31,31,29,30,30,29,30,30],2017:[18,31,31,32,31,31,31,30,29,30,29,30,30],2018:[18,31,32,31,32,31,30,30,29,30,29,30,30],2019:[17,31,32,31,32,31,30,30,30,29,30,29,31],2020:[17,31,31,31,32,31,31,30,29,30,29,30,30],2021:[18,31,31,32,31,31,31,30,29,30,29,30,30],2022:[17,31,32,31,32,31,30,30,30,29,29,30,30],2023:[17,31,32,31,32,31,30,30,30,29,30,29,31],2024:[17,31,31,31,32,31,31,30,29,30,29,30,30],2025:[18,31,31,32,31,31,31,30,29,30,29,30,30],2026:[17,31,32,31,32,31,30,30,30,29,29,30,31],2027:[17,30,32,31,32,31,30,30,30,29,30,29,31],2028:[17,31,31,32,31,31,31,30,29,30,29,30,30],2029:[18,31,31,32,31,32,30,30,29,30,29,30,30],2030:[17,31,32,31,32,31,30,30,30,30,30,30,31],2031:[17,31,32,31,32,31,31,31,31,31,31,31,31],2032:[17,32,32,32,32,32,32,32,32,32,32,32,32],2033:[18,31,31,32,32,31,30,30,29,30,29,30,30],2034:[17,31,32,31,32,31,30,30,30,29,29,30,31],2035:[17,30,32,31,32,31,31,29,30,30,29,29,31],2036:[17,31,31,32,31,31,31,30,29,30,29,30,30],2037:[18,31,31,32,32,31,30,30,29,30,29,30,30],2038:[17,31,32,31,32,31,30,30,30,29,29,30,31],2039:[17,31,31,31,32,31,31,29,30,30,29,30,30],2040:[17,31,31,32,31,31,31,30,29,30,29,30,30],2041:[18,31,31,32,32,31,30,30,29,30,29,30,30],2042:[17,31,32,31,32,31,30,30,30,29,29,30,31],2043:[17,31,31,31,32,31,31,29,30,30,29,30,30],2044:[17,31,31,32,31,31,31,30,29,30,29,30,30],2045:[18,31,32,31,32,31,30,30,29,30,29,30,30],2046:[17,31,32,31,32,31,30,30,30,29,29,30,31],2047:[17,31,31,31,32,31,31,30,29,30,29,30,30],2048:[17,31,31,32,31,31,31,30,29,30,29,30,30],2049:[17,31,32,31,32,31,30,30,30,29,29,30,30],2050:[17,31,32,31,32,31,30,30,30,29,30,29,31],2051:[17,31,31,31,32,31,31,30,29,30,29,30,30],2052:[17,31,31,32,31,31,31,30,29,30,29,30,30],2053:[17,31,32,31,32,31,30,30,30,29,29,30,30],2054:[17,31,32,31,32,31,30,30,30,29,30,29,31],2055:[17,31,31,32,31,31,31,30,29,30,30,29,30],2056:[17,31,31,32,31,32,30,30,29,30,29,30,30],2057:[17,31,32,31,32,31,30,30,30,29,29,30,31],2058:[17,30,32,31,32,31,30,30,30,29,30,29,31],2059:[17,31,31,32,31,31,31,30,29,30,29,30,30],2060:[17,31,31,32,32,31,30,30,29,30,29,30,30],2061:[17,31,32,31,32,31,30,30,30,29,29,30,31],2062:[17,30,32,31,32,31,31,29,30,29,30,29,31],2063:[17,31,31,32,31,31,31,30,29,30,29,30,30],2064:[17,31,31,32,32,31,30,30,29,30,29,30,30],2065:[17,31,32,31,32,31,30,30,30,29,29,30,31],2066:[17,31,31,31,32,31,31,29,30,30,29,29,31],2067:[17,31,31,32,31,31,31,30,29,30,29,30,30],2068:[17,31,31,32,32,31,30,30,29,30,29,30,30],2069:[17,31,32,31,32,31,30,30,30,29,29,30,31],2070:[17,31,31,31,32,31,31,29,30,30,29,30,30],2071:[17,31,31,32,31,31,31,30,29,30,29,30,30],2072:[17,31,32,31,32,31,30,30,29,30,29,30,30],2073:[17,31,32,31,32,31,30,30,30,29,29,30,31],2074:[17,31,31,31,32,31,31,30,29,30,29,30,30],2075:[17,31,31,32,31,31,31,30,29,30,29,30,30],2076:[16,31,32,31,32,31,30,30,30,29,29,30,30],2077:[17,31,32,31,32,31,30,30,30,29,30,29,31],2078:[17,31,31,31,32,31,31,30,29,30,29,30,30],2079:[17,31,31,32,31,31,31,30,29,30,29,30,30],2080:[16,31,32,31,32,31,30,30,30,29,29,30,30],2081:[17,31,31,32,32,31,30,30,30,29,30,30,30],2082:[17,31,32,31,32,31,30,30,30,29,30,30,30],2083:[17,31,31,32,31,31,30,30,30,29,30,30,30],2084:[17,31,31,32,31,31,30,30,30,29,30,30,30],2085:[17,31,32,31,32,31,31,30,30,29,30,30,30],2086:[17,31,32,31,32,31,30,30,30,29,30,30,30],2087:[16,31,31,32,31,31,31,30,30,29,30,30,30],2088:[16,30,31,32,32,30,31,30,30,29,30,30,30],2089:[17,31,32,31,32,31,30,30,30,29,30,30,30],2090:[17,31,32,31,32,31,30,30,30,29,30,30,30],2091:[16,31,31,32,31,31,31,30,30,29,30,30,30],2092:[16,31,31,32,32,31,30,30,30,29,30,30,30],2093:[17,31,32,31,32,31,30,30,30,29,30,30,30],2094:[17,31,31,32,31,31,30,30,30,29,30,30,30],2095:[17,31,31,32,31,31,31,30,29,30,30,30,30],2096:[17,30,31,32,32,31,30,30,29,30,29,30,30],2097:[17,31,32,31,32,31,30,30,30,29,30,30,30],2098:[17,31,31,32,31,31,31,29,30,29,30,30,31],2099:[17,31,31,32,31,31,31,30,29,29,30,30,30],2100:[17,31,32,31,32,30,31,30,29,30,29,30,30]}}),n.calendars.nepali=a},{\"../main\":571,\"object-assign\":454}],567:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Persian\",jdEpoch:1948320.5,daysPerMonth:[31,31,31,31,31,31,30,30,30,30,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Persian\",epochs:[\"BP\",\"AP\"],monthNames:[\"Farvardin\",\"Ordibehesht\",\"Khordad\",\"Tir\",\"Mordad\",\"Shahrivar\",\"Mehr\",\"Aban\",\"Azar\",\"Day\",\"Bahman\",\"Esfand\"],monthNamesShort:[\"Far\",\"Ord\",\"Kho\",\"Tir\",\"Mor\",\"Sha\",\"Meh\",\"Aba\",\"Aza\",\"Day\",\"Bah\",\"Esf\"],dayNames:[\"Yekshambe\",\"Doshambe\",\"Seshambe\",\"Ch\\xe6harshambe\",\"Panjshambe\",\"Jom'e\",\"Shambe\"],dayNamesShort:[\"Yek\",\"Do\",\"Se\",\"Ch\\xe6\",\"Panj\",\"Jom\",\"Sha\"],dayNamesMin:[\"Ye\",\"Do\",\"Se\",\"Ch\",\"Pa\",\"Jo\",\"Sh\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 682*((e.year()-(e.year()>0?474:473))%2820+474+38)%2816<682},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-(n.dayOfWeek()+1)%7,\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t-(t>=0?474:473),s=474+o(a,2820);return r+(e<=7?31*(e-1):30*(e-1)+6)+Math.floor((682*s-110)/2816)+365*(s-1)+1029983*Math.floor(a/2820)+this.jdEpoch-1},fromJD:function(t){var e=(t=Math.floor(t)+.5)-this.toJD(475,1,1),r=Math.floor(e/1029983),n=o(e,1029983),i=2820;if(1029982!==n){var a=Math.floor(n/366),s=o(n,366);i=Math.floor((2134*a+2816*s+2815)/1028522)+a+1}var l=i+2820*r+474;l=l<=0?l-1:l;var c=t-this.toJD(l,1,1)+1,u=c<=186?Math.ceil(c/31):Math.ceil((c-6)/30),h=t-this.toJD(l,u,1)+1;return this.newDate(l,u,h)}}),n.calendars.persian=a,n.calendars.jalali=a},{\"../main\":571,\"object-assign\":454}],568:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Taiwan\",jdEpoch:2419402.5,yearsOffset:1911,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Taiwan\",epochs:[\"BROC\",\"ROC\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)},_g2tYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)}}),n.calendars.taiwan=o},{\"../main\":571,\"object-assign\":454}],569:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Thai\",jdEpoch:1523098.5,yearsOffset:543,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Thai\",epochs:[\"BBE\",\"BE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)},_g2tYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)}}),n.calendars.thai=o},{\"../main\":571,\"object-assign\":454}],570:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"UmmAlQura\",hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Umm al-Qura\",epochs:[\"BH\",\"AH\"],monthNames:[\"Al-Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' Al-Thani\",\"Jumada Al-Awwal\",\"Jumada Al-Thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-Ahad\",\"Yawm al-Ithnain\",\"Yawm al-Thal\\u0101th\\u0101\\u2019\",\"Yawm al-Arba\\u2018\\u0101\\u2019\",\"Yawm al-Kham\\u012bs\",\"Yawm al-Jum\\u2018a\",\"Yawm al-Sabt\"],dayNamesMin:[\"Ah\",\"Ith\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!0}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 355===this.daysInYear(e.year())},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){for(var e=0,r=1;r<=12;r++)e+=this.daysInMonth(t,r);return e},daysInMonth:function(t,e){for(var r=this._validate(t,e,this.minDay,n.local.invalidMonth).toJD()-24e5+.5,i=0,a=0;a<o.length;a++){if(o[a]>r)return o[i]-o[i-1];i++}return 30},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate),a=12*(i.year()-1)+i.month()-15292;return i.day()+o[a-1]-1+24e5-.5},fromJD:function(t){for(var e=t-24e5+.5,r=0,n=0;n<o.length&&!(o[n]>e);n++)r++;var i=r+15292,a=Math.floor((i-1)/12),s=a+1,l=i-12*a,c=e-o[r-1]+1;return this.newDate(s,l,c)},isValid:function(t,e,r){var i=n.baseCalendar.prototype.isValid.apply(this,arguments);return i&&(i=(t=null!=t.year?t.year:t)>=1276&&t<=1500),i},_validate:function(t,e,r,i){var a=n.baseCalendar.prototype._validate.apply(this,arguments);if(a.year<1276||a.year>1500)throw i.replace(/\\{0\\}/,this.local.name);return a}}),n.calendars.ummalqura=a;var o=[20,50,79,109,138,168,197,227,256,286,315,345,374,404,433,463,492,522,551,581,611,641,670,700,729,759,788,818,847,877,906,936,965,995,1024,1054,1083,1113,1142,1172,1201,1231,1260,1290,1320,1350,1379,1409,1438,1468,1497,1527,1556,1586,1615,1645,1674,1704,1733,1763,1792,1822,1851,1881,1910,1940,1969,1999,2028,2058,2087,2117,2146,2176,2205,2235,2264,2294,2323,2353,2383,2413,2442,2472,2501,2531,2560,2590,2619,2649,2678,2708,2737,2767,2796,2826,2855,2885,2914,2944,2973,3003,3032,3062,3091,3121,3150,3180,3209,3239,3268,3298,3327,3357,3386,3416,3446,3476,3505,3535,3564,3594,3623,3653,3682,3712,3741,3771,3800,3830,3859,3889,3918,3948,3977,4007,4036,4066,4095,4125,4155,4185,4214,4244,4273,4303,4332,4362,4391,4421,4450,4480,4509,4539,4568,4598,4627,4657,4686,4716,4745,4775,4804,4834,4863,4893,4922,4952,4981,5011,5040,5070,5099,5129,5158,5188,5218,5248,5277,5307,5336,5366,5395,5425,5454,5484,5513,5543,5572,5602,5631,5661,5690,5720,5749,5779,5808,5838,5867,5897,5926,5956,5985,6015,6044,6074,6103,6133,6162,6192,6221,6251,6281,6311,6340,6370,6399,6429,6458,6488,6517,6547,6576,6606,6635,6665,6694,6724,6753,6783,6812,6842,6871,6901,6930,6960,6989,7019,7048,7078,7107,7137,7166,7196,7225,7255,7284,7314,7344,7374,7403,7433,7462,7492,7521,7551,7580,7610,7639,7669,7698,7728,7757,7787,7816,7846,7875,7905,7934,7964,7993,8023,8053,8083,8112,8142,8171,8201,8230,8260,8289,8319,8348,8378,8407,8437,8466,8496,8525,8555,8584,8614,8643,8673,8702,8732,8761,8791,8821,8850,8880,8909,8938,8968,8997,9027,9056,9086,9115,9145,9175,9205,9234,9264,9293,9322,9352,9381,9410,9440,9470,9499,9529,9559,9589,9618,9648,9677,9706,9736,9765,9794,9824,9853,9883,9913,9943,9972,10002,10032,10061,10090,10120,10149,10178,10208,10237,10267,10297,10326,10356,10386,10415,10445,10474,10504,10533,10562,10592,10621,10651,10680,10710,10740,10770,10799,10829,10858,10888,10917,10947,10976,11005,11035,11064,11094,11124,11153,11183,11213,11242,11272,11301,11331,11360,11389,11419,11448,11478,11507,11537,11567,11596,11626,11655,11685,11715,11744,11774,11803,11832,11862,11891,11921,11950,11980,12010,12039,12069,12099,12128,12158,12187,12216,12246,12275,12304,12334,12364,12393,12423,12453,12483,12512,12542,12571,12600,12630,12659,12688,12718,12747,12777,12807,12837,12866,12896,12926,12955,12984,13014,13043,13072,13102,13131,13161,13191,13220,13250,13280,13310,13339,13368,13398,13427,13456,13486,13515,13545,13574,13604,13634,13664,13693,13723,13752,13782,13811,13840,13870,13899,13929,13958,13988,14018,14047,14077,14107,14136,14166,14195,14224,14254,14283,14313,14342,14372,14401,14431,14461,14490,14520,14550,14579,14609,14638,14667,14697,14726,14756,14785,14815,14844,14874,14904,14933,14963,14993,15021,15051,15081,15110,15140,15169,15199,15228,15258,15287,15317,15347,15377,15406,15436,15465,15494,15524,15553,15582,15612,15641,15671,15701,15731,15760,15790,15820,15849,15878,15908,15937,15966,15996,16025,16055,16085,16114,16144,16174,16204,16233,16262,16292,16321,16350,16380,16409,16439,16468,16498,16528,16558,16587,16617,16646,16676,16705,16734,16764,16793,16823,16852,16882,16912,16941,16971,17001,17030,17060,17089,17118,17148,17177,17207,17236,17266,17295,17325,17355,17384,17414,17444,17473,17502,17532,17561,17591,17620,17650,17679,17709,17738,17768,17798,17827,17857,17886,17916,17945,17975,18004,18034,18063,18093,18122,18152,18181,18211,18241,18270,18300,18330,18359,18388,18418,18447,18476,18506,18535,18565,18595,18625,18654,18684,18714,18743,18772,18802,18831,18860,18890,18919,18949,18979,19008,19038,19068,19098,19127,19156,19186,19215,19244,19274,19303,19333,19362,19392,19422,19452,19481,19511,19540,19570,19599,19628,19658,19687,19717,19746,19776,19806,19836,19865,19895,19924,19954,19983,20012,20042,20071,20101,20130,20160,20190,20219,20249,20279,20308,20338,20367,20396,20426,20455,20485,20514,20544,20573,20603,20633,20662,20692,20721,20751,20780,20810,20839,20869,20898,20928,20957,20987,21016,21046,21076,21105,21135,21164,21194,21223,21253,21282,21312,21341,21371,21400,21430,21459,21489,21519,21548,21578,21607,21637,21666,21696,21725,21754,21784,21813,21843,21873,21902,21932,21962,21991,22021,22050,22080,22109,22138,22168,22197,22227,22256,22286,22316,22346,22375,22405,22434,22464,22493,22522,22552,22581,22611,22640,22670,22700,22730,22759,22789,22818,22848,22877,22906,22936,22965,22994,23024,23054,23083,23113,23143,23173,23202,23232,23261,23290,23320,23349,23379,23408,23438,23467,23497,23527,23556,23586,23616,23645,23674,23704,23733,23763,23792,23822,23851,23881,23910,23940,23970,23999,24029,24058,24088,24117,24147,24176,24206,24235,24265,24294,24324,24353,24383,24413,24442,24472,24501,24531,24560,24590,24619,24648,24678,24707,24737,24767,24796,24826,24856,24885,24915,24944,24974,25003,25032,25062,25091,25121,25150,25180,25210,25240,25269,25299,25328,25358,25387,25416,25446,25475,25505,25534,25564,25594,25624,25653,25683,25712,25742,25771,25800,25830,25859,25888,25918,25948,25977,26007,26037,26067,26096,26126,26155,26184,26214,26243,26272,26302,26332,26361,26391,26421,26451,26480,26510,26539,26568,26598,26627,26656,26686,26715,26745,26775,26805,26834,26864,26893,26923,26952,26982,27011,27041,27070,27099,27129,27159,27188,27218,27248,27277,27307,27336,27366,27395,27425,27454,27484,27513,27542,27572,27602,27631,27661,27691,27720,27750,27779,27809,27838,27868,27897,27926,27956,27985,28015,28045,28074,28104,28134,28163,28193,28222,28252,28281,28310,28340,28369,28399,28428,28458,28488,28517,28547,28577,28607,28636,28665,28695,28724,28754,28783,28813,28843,28872,28901,28931,28960,28990,29019,29049,29078,29108,29137,29167,29196,29226,29255,29285,29315,29345,29375,29404,29434,29463,29492,29522,29551,29580,29610,29640,29669,29699,29729,29759,29788,29818,29847,29876,29906,29935,29964,29994,30023,30053,30082,30112,30141,30171,30200,30230,30259,30289,30318,30348,30378,30408,30437,30467,30496,30526,30555,30585,30614,30644,30673,30703,30732,30762,30791,30821,30850,30880,30909,30939,30968,30998,31027,31057,31086,31116,31145,31175,31204,31234,31263,31293,31322,31352,31381,31411,31441,31471,31500,31530,31559,31589,31618,31648,31676,31706,31736,31766,31795,31825,31854,31884,31913,31943,31972,32002,32031,32061,32090,32120,32150,32180,32209,32239,32268,32298,32327,32357,32386,32416,32445,32475,32504,32534,32563,32593,32622,32652,32681,32711,32740,32770,32799,32829,32858,32888,32917,32947,32976,33006,33035,33065,33094,33124,33153,33183,33213,33243,33272,33302,33331,33361,33390,33420,33450,33479,33509,33539,33568,33598,33627,33657,33686,33716,33745,33775,33804,33834,33863,33893,33922,33952,33981,34011,34040,34069,34099,34128,34158,34187,34217,34247,34277,34306,34336,34365,34395,34424,34454,34483,34512,34542,34571,34601,34631,34660,34690,34719,34749,34778,34808,34837,34867,34896,34926,34955,34985,35015,35044,35074,35103,35133,35162,35192,35222,35251,35280,35310,35340,35370,35399,35429,35458,35488,35517,35547,35576,35605,35635,35665,35694,35723,35753,35782,35811,35841,35871,35901,35930,35960,35989,36019,36048,36078,36107,36136,36166,36195,36225,36254,36284,36314,36343,36373,36403,36433,36462,36492,36521,36551,36580,36610,36639,36669,36698,36728,36757,36786,36816,36845,36875,36904,36934,36963,36993,37022,37052,37081,37111,37141,37170,37200,37229,37259,37288,37318,37347,37377,37406,37436,37465,37495,37524,37554,37584,37613,37643,37672,37701,37731,37760,37790,37819,37849,37878,37908,37938,37967,37997,38027,38056,38085,38115,38144,38174,38203,38233,38262,38292,38322,38351,38381,38410,38440,38469,38499,38528,38558,38587,38617,38646,38676,38705,38735,38764,38794,38823,38853,38882,38912,38941,38971,39001,39030,39059,39089,39118,39148,39178,39208,39237,39267,39297,39326,39355,39385,39414,39444,39473,39503,39532,39562,39592,39621,39650,39680,39709,39739,39768,39798,39827,39857,39886,39916,39946,39975,40005,40035,40064,40094,40123,40153,40182,40212,40241,40271,40300,40330,40359,40389,40418,40448,40477,40507,40536,40566,40595,40625,40655,40685,40714,40744,40773,40803,40832,40862,40892,40921,40951,40980,41009,41039,41068,41098,41127,41157,41186,41216,41245,41275,41304,41334,41364,41393,41422,41452,41481,41511,41540,41570,41599,41629,41658,41688,41718,41748,41777,41807,41836,41865,41894,41924,41953,41983,42012,42042,42072,42102,42131,42161,42190,42220,42249,42279,42308,42337,42367,42397,42426,42456,42485,42515,42545,42574,42604,42633,42662,42692,42721,42751,42780,42810,42839,42869,42899,42929,42958,42988,43017,43046,43076,43105,43135,43164,43194,43223,43253,43283,43312,43342,43371,43401,43430,43460,43489,43519,43548,43578,43607,43637,43666,43696,43726,43755,43785,43814,43844,43873,43903,43932,43962,43991,44021,44050,44080,44109,44139,44169,44198,44228,44258,44287,44317,44346,44375,44405,44434,44464,44493,44523,44553,44582,44612,44641,44671,44700,44730,44759,44788,44818,44847,44877,44906,44936,44966,44996,45025,45055,45084,45114,45143,45172,45202,45231,45261,45290,45320,45350,45380,45409,45439,45468,45498,45527,45556,45586,45615,45644,45674,45704,45733,45763,45793,45823,45852,45882,45911,45940,45970,45999,46028,46058,46088,46117,46147,46177,46206,46236,46265,46295,46324,46354,46383,46413,46442,46472,46501,46531,46560,46590,46620,46649,46679,46708,46738,46767,46797,46826,46856,46885,46915,46944,46974,47003,47033,47063,47092,47122,47151,47181,47210,47240,47269,47298,47328,47357,47387,47417,47446,47476,47506,47535,47565,47594,47624,47653,47682,47712,47741,47771,47800,47830,47860,47890,47919,47949,47978,48008,48037,48066,48096,48125,48155,48184,48214,48244,48273,48303,48333,48362,48392,48421,48450,48480,48509,48538,48568,48598,48627,48657,48687,48717,48746,48776,48805,48834,48864,48893,48922,48952,48982,49011,49041,49071,49100,49130,49160,49189,49218,49248,49277,49306,49336,49365,49395,49425,49455,49484,49514,49543,49573,49602,49632,49661,49690,49720,49749,49779,49809,49838,49868,49898,49927,49957,49986,50016,50045,50075,50104,50133,50163,50192,50222,50252,50281,50311,50340,50370,50400,50429,50459,50488,50518,50547,50576,50606,50635,50665,50694,50724,50754,50784,50813,50843,50872,50902,50931,50960,50990,51019,51049,51078,51108,51138,51167,51197,51227,51256,51286,51315,51345,51374,51403,51433,51462,51492,51522,51552,51582,51611,51641,51670,51699,51729,51758,51787,51816,51846,51876,51906,51936,51965,51995,52025,52054,52083,52113,52142,52171,52200,52230,52260,52290,52319,52349,52379,52408,52438,52467,52497,52526,52555,52585,52614,52644,52673,52703,52733,52762,52792,52822,52851,52881,52910,52939,52969,52998,53028,53057,53087,53116,53146,53176,53205,53235,53264,53294,53324,53353,53383,53412,53441,53471,53500,53530,53559,53589,53619,53648,53678,53708,53737,53767,53796,53825,53855,53884,53913,53943,53973,54003,54032,54062,54092,54121,54151,54180,54209,54239,54268,54297,54327,54357,54387,54416,54446,54476,54505,54535,54564,54593,54623,54652,54681,54711,54741,54770,54800,54830,54859,54889,54919,54948,54977,55007,55036,55066,55095,55125,55154,55184,55213,55243,55273,55302,55332,55361,55391,55420,55450,55479,55508,55538,55567,55597,55627,55657,55686,55716,55745,55775,55804,55834,55863,55892,55922,55951,55981,56011,56040,56070,56100,56129,56159,56188,56218,56247,56276,56306,56335,56365,56394,56424,56454,56483,56513,56543,56572,56601,56631,56660,56690,56719,56749,56778,56808,56837,56867,56897,56926,56956,56985,57015,57044,57074,57103,57133,57162,57192,57221,57251,57280,57310,57340,57369,57399,57429,57458,57487,57517,57546,57576,57605,57634,57664,57694,57723,57753,57783,57813,57842,57871,57901,57930,57959,57989,58018,58048,58077,58107,58137,58167,58196,58226,58255,58285,58314,58343,58373,58402,58432,58461,58491,58521,58551,58580,58610,58639,58669,58698,58727,58757,58786,58816,58845,58875,58905,58934,58964,58994,59023,59053,59082,59111,59141,59170,59200,59229,59259,59288,59318,59348,59377,59407,59436,59466,59495,59525,59554,59584,59613,59643,59672,59702,59731,59761,59791,59820,59850,59879,59909,59939,59968,59997,60027,60056,60086,60115,60145,60174,60204,60234,60264,60293,60323,60352,60381,60411,60440,60469,60499,60528,60558,60588,60618,60648,60677,60707,60736,60765,60795,60824,60853,60883,60912,60942,60972,61002,61031,61061,61090,61120,61149,61179,61208,61237,61267,61296,61326,61356,61385,61415,61445,61474,61504,61533,61563,61592,61621,61651,61680,61710,61739,61769,61799,61828,61858,61888,61917,61947,61976,62006,62035,62064,62094,62123,62153,62182,62212,62242,62271,62301,62331,62360,62390,62419,62448,62478,62507,62537,62566,62596,62625,62655,62685,62715,62744,62774,62803,62832,62862,62891,62921,62950,62980,63009,63039,63069,63099,63128,63157,63187,63216,63246,63275,63305,63334,63363,63393,63423,63453,63482,63512,63541,63571,63600,63630,63659,63689,63718,63747,63777,63807,63836,63866,63895,63925,63955,63984,64014,64043,64073,64102,64131,64161,64190,64220,64249,64279,64309,64339,64368,64398,64427,64457,64486,64515,64545,64574,64603,64633,64663,64692,64722,64752,64782,64811,64841,64870,64899,64929,64958,64987,65017,65047,65076,65106,65136,65166,65195,65225,65254,65283,65313,65342,65371,65401,65431,65460,65490,65520,65549,65579,65608,65638,65667,65697,65726,65755,65785,65815,65844,65874,65903,65933,65963,65992,66022,66051,66081,66110,66140,66169,66199,66228,66258,66287,66317,66346,66376,66405,66435,66465,66494,66524,66553,66583,66612,66641,66671,66700,66730,66760,66789,66819,66849,66878,66908,66937,66967,66996,67025,67055,67084,67114,67143,67173,67203,67233,67262,67292,67321,67351,67380,67409,67439,67468,67497,67527,67557,67587,67617,67646,67676,67705,67735,67764,67793,67823,67852,67882,67911,67941,67971,68e3,68030,68060,68089,68119,68148,68177,68207,68236,68266,68295,68325,68354,68384,68414,68443,68473,68502,68532,68561,68591,68620,68650,68679,68708,68738,68768,68797,68827,68857,68886,68916,68946,68975,69004,69034,69063,69092,69122,69152,69181,69211,69240,69270,69300,69330,69359,69388,69418,69447,69476,69506,69535,69565,69595,69624,69654,69684,69713,69743,69772,69802,69831,69861,69890,69919,69949,69978,70008,70038,70067,70097,70126,70156,70186,70215,70245,70274,70303,70333,70362,70392,70421,70451,70481,70510,70540,70570,70599,70629,70658,70687,70717,70746,70776,70805,70835,70864,70894,70924,70954,70983,71013,71042,71071,71101,71130,71159,71189,71218,71248,71278,71308,71337,71367,71397,71426,71455,71485,71514,71543,71573,71602,71632,71662,71691,71721,71751,71781,71810,71839,71869,71898,71927,71957,71986,72016,72046,72075,72105,72135,72164,72194,72223,72253,72282,72311,72341,72370,72400,72429,72459,72489,72518,72548,72577,72607,72637,72666,72695,72725,72754,72784,72813,72843,72872,72902,72931,72961,72991,73020,73050,73080,73109,73139,73168,73197,73227,73256,73286,73315,73345,73375,73404,73434,73464,73493,73523,73552,73581,73611,73640,73669,73699,73729,73758,73788,73818,73848,73877,73907,73936,73965,73995,74024,74053,74083,74113,74142,74172,74202,74231,74261,74291,74320,74349,74379,74408,74437,74467,74497,74526,74556,74586,74615,74645,74675,74704,74733,74763,74792,74822,74851,74881,74910,74940,74969,74999,75029,75058,75088,75117,75147,75176,75206,75235,75264,75294,75323,75353,75383,75412,75442,75472,75501,75531,75560,75590,75619,75648,75678,75707,75737,75766,75796,75826,75856,75885,75915,75944,75974,76003,76032,76062,76091,76121,76150,76180,76210,76239,76269,76299,76328,76358,76387,76416,76446,76475,76505,76534,76564,76593,76623,76653,76682,76712,76741,76771,76801,76830,76859,76889,76918,76948,76977,77007,77036,77066,77096,77125,77155,77185,77214,77243,77273,77302,77332,77361,77390,77420,77450,77479,77509,77539,77569,77598,77627,77657,77686,77715,77745,77774,77804,77833,77863,77893,77923,77952,77982,78011,78041,78070,78099,78129,78158,78188,78217,78247,78277,78307,78336,78366,78395,78425,78454,78483,78513,78542,78572,78601,78631,78661,78690,78720,78750,78779,78808,78838,78867,78897,78926,78956,78985,79015,79044,79074,79104,79133,79163,79192,79222,79251,79281,79310,79340,79369,79399,79428,79458,79487,79517,79546,79576,79606,79635,79665,79695,79724,79753,79783,79812,79841,79871,79900,79930,79960,79990]},{\"../main\":571,\"object-assign\":454}],571:[function(t,e,r){var n=t(\"object-assign\");function i(){this.regionalOptions=[],this.regionalOptions[\"\"]={invalidCalendar:\"Calendar {0} not found\",invalidDate:\"Invalid {0} date\",invalidMonth:\"Invalid {0} month\",invalidYear:\"Invalid {0} year\",differentCalendars:\"Cannot mix {0} and {1} dates\"},this.local=this.regionalOptions[\"\"],this.calendars={},this._localCals={}}function a(t,e,r,n){if(this._calendar=t,this._year=e,this._month=r,this._day=n,0===this._calendar._validateLevel&&!this._calendar.isValid(this._year,this._month,this._day))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name)}function o(t,e){return\"000000\".substring(0,e-(t=\"\"+t).length)+t}function s(){this.shortYearCutoff=\"+10\"}function l(t){this.local=this.regionalOptions[t]||this.regionalOptions[\"\"]}n(i.prototype,{instance:function(t,e){t=(t||\"gregorian\").toLowerCase(),e=e||\"\";var r=this._localCals[t+\"-\"+e];if(!r&&this.calendars[t]&&(r=new this.calendars[t](e),this._localCals[t+\"-\"+e]=r),!r)throw(this.local.invalidCalendar||this.regionalOptions[\"\"].invalidCalendar).replace(/\\{0\\}/,t);return r},newDate:function(t,e,r,n,i){return(n=(null!=t&&t.year?t.calendar():\"string\"==typeof n?this.instance(n,i):n)||this.instance()).newDate(t,e,r)},substituteDigits:function(t){return function(e){return(e+\"\").replace(/[0-9]/g,function(e){return t[e]})}},substituteChineseDigits:function(t,e){return function(r){for(var n=\"\",i=0;r>0;){var a=r%10;n=(0===a?\"\":t[a]+e[i])+n,i++,r=Math.floor(r/10)}return 0===n.indexOf(t[1]+e[1])&&(n=n.substr(1)),n||t[0]}}}),n(a.prototype,{newDate:function(t,e,r){return this._calendar.newDate(null==t?this:t,e,r)},year:function(t){return 0===arguments.length?this._year:this.set(t,\"y\")},month:function(t){return 0===arguments.length?this._month:this.set(t,\"m\")},day:function(t){return 0===arguments.length?this._day:this.set(t,\"d\")},date:function(t,e,r){if(!this._calendar.isValid(t,e,r))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name);return this._year=t,this._month=e,this._day=r,this},leapYear:function(){return this._calendar.leapYear(this)},epoch:function(){return this._calendar.epoch(this)},formatYear:function(){return this._calendar.formatYear(this)},monthOfYear:function(){return this._calendar.monthOfYear(this)},weekOfYear:function(){return this._calendar.weekOfYear(this)},daysInYear:function(){return this._calendar.daysInYear(this)},dayOfYear:function(){return this._calendar.dayOfYear(this)},daysInMonth:function(){return this._calendar.daysInMonth(this)},dayOfWeek:function(){return this._calendar.dayOfWeek(this)},weekDay:function(){return this._calendar.weekDay(this)},extraInfo:function(){return this._calendar.extraInfo(this)},add:function(t,e){return this._calendar.add(this,t,e)},set:function(t,e){return this._calendar.set(this,t,e)},compareTo:function(t){if(this._calendar.name!==t._calendar.name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this._calendar.local.name).replace(/\\{1\\}/,t._calendar.local.name);var e=this._year!==t._year?this._year-t._year:this._month!==t._month?this.monthOfYear()-t.monthOfYear():this._day-t._day;return 0===e?0:e<0?-1:1},calendar:function(){return this._calendar},toJD:function(){return this._calendar.toJD(this)},fromJD:function(t){return this._calendar.fromJD(t)},toJSDate:function(){return this._calendar.toJSDate(this)},fromJSDate:function(t){return this._calendar.fromJSDate(t)},toString:function(){return(this.year()<0?\"-\":\"\")+o(Math.abs(this.year()),4)+\"-\"+o(this.month(),2)+\"-\"+o(this.day(),2)}}),n(s.prototype,{_validateLevel:0,newDate:function(t,e,r){return null==t?this.today():(t.year&&(this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),r=t.day(),e=t.month(),t=t.year()),new a(this,t,e,r))},today:function(){return this.fromJSDate(new Date)},epoch:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear).year()<0?this.local.epochs[0]:this.local.epochs[1]},formatYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(e.year()<0?\"-\":\"\")+o(Math.abs(e.year()),4)},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear),12},monthOfYear:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return(r.month()+this.monthsInYear(r)-this.firstMonth)%this.monthsInYear(r)+this.minMonth},fromMonthOfYear:function(t,e){var r=(e+this.firstMonth-2*this.minMonth)%this.monthsInYear(t)+this.minMonth;return this._validate(t,r,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth),r},daysInYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return this.leapYear(e)?366:365},dayOfYear:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return n.toJD()-this.newDate(n.year(),this.fromMonthOfYear(n.year(),this.minMonth),this.minDay).toJD()+1},daysInWeek:function(){return 7},dayOfWeek:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return(Math.floor(this.toJD(n))+2)%this.daysInWeek()},extraInfo:function(t,e,r){return this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),{}},add:function(t,e,r){return this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),this._correctAdd(t,this._add(t,e,r),e,r)},_add:function(t,e,r){if(this._validateLevel++,\"d\"===r||\"w\"===r){var n=t.toJD()+e*(\"w\"===r?this.daysInWeek():1),i=t.calendar().fromJD(n);return this._validateLevel--,[i.year(),i.month(),i.day()]}try{var a=t.year()+(\"y\"===r?e:0),o=t.monthOfYear()+(\"m\"===r?e:0);i=t.day();\"y\"===r?(t.month()!==this.fromMonthOfYear(a,o)&&(o=this.newDate(a,t.month(),this.minDay).monthOfYear()),o=Math.min(o,this.monthsInYear(a)),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o)))):\"m\"===r&&(!function(t){for(;o<t.minMonth;)a--,o+=t.monthsInYear(a);for(var e=t.monthsInYear(a);o>e-1+t.minMonth;)a++,o-=e,e=t.monthsInYear(a)}(this),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o))));var s=[a,this.fromMonthOfYear(a,o),i];return this._validateLevel--,s}catch(t){throw this._validateLevel--,t}},_correctAdd:function(t,e,r,n){if(!(this.hasYearZero||\"y\"!==n&&\"m\"!==n||0!==e[0]&&t.year()>0==e[0]>0)){var i={y:[1,1,\"y\"],m:[1,this.monthsInYear(-1),\"m\"],w:[this.daysInWeek(),this.daysInYear(-1),\"d\"],d:[1,this.daysInYear(-1),\"d\"]}[n],a=r<0?-1:1;e=this._add(t,r*i[0]+a*i[1],i[2])}return t.date(e[0],e[1],e[2])},set:function(t,e,r){this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);var n=\"y\"===r?e:t.year(),i=\"m\"===r?e:t.month(),a=\"d\"===r?e:t.day();return\"y\"!==r&&\"m\"!==r||(a=Math.min(a,this.daysInMonth(n,i))),t.date(n,i,a)},isValid:function(t,e,r){this._validateLevel++;var n=this.hasYearZero||0!==t;if(n){var i=this.newDate(t,e,this.minDay);n=e>=this.minMonth&&e-this.minMonth<this.monthsInYear(i)&&r>=this.minDay&&r-this.minDay<this.daysInMonth(i)}return this._validateLevel--,n},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return c.instance().fromJD(this.toJD(n)).toJSDate()},fromJSDate:function(t){return this.fromJD(c.instance().fromJSDate(t).toJD())},_validate:function(t,e,r,n){if(t.year){if(0===this._validateLevel&&this.name!==t.calendar().name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this.local.name).replace(/\\{1\\}/,t.calendar().local.name);return t}try{if(this._validateLevel++,1===this._validateLevel&&!this.isValid(t,e,r))throw n.replace(/\\{0\\}/,this.local.name);var i=this.newDate(t,e,r);return this._validateLevel--,i}catch(t){throw this._validateLevel--,t}}}),l.prototype=new s,n(l.prototype,{name:\"Gregorian\",jdEpoch:1721425.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Gregorian\",epochs:[\"BCE\",\"CE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==0&&(t%100!=0||t%400==0)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);t=n.year(),e=n.month(),r=n.day(),t<0&&t++,e<3&&(e+=12,t--);var i=Math.floor(t/100),a=2-i+Math.floor(i/4);return Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r+a-1524.5},fromJD:function(t){var e=Math.floor(t+.5),r=Math.floor((e-1867216.25)/36524.25),n=(r=e+1+r-Math.floor(r/4))+1524,i=Math.floor((n-122.1)/365.25),a=Math.floor(365.25*i),o=Math.floor((n-a)/30.6001),s=n-a-Math.floor(30.6001*o),l=o-(o>13.5?13:1),c=i-(l>2.5?4716:4715);return c<=0&&c--,this.newDate(c,l,s)},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),i=new Date(n.year(),n.month()-1,n.day());return i.setHours(0),i.setMinutes(0),i.setSeconds(0),i.setMilliseconds(0),i.setHours(i.getHours()>12?i.getHours()+2:0),i},fromJSDate:function(t){return this.newDate(t.getFullYear(),t.getMonth()+1,t.getDate())}});var c=e.exports=new i;c.cdate=a,c.baseCalendar=s,c.calendars.gregorian=l},{\"object-assign\":454}],572:[function(t,e,r){var n=t(\"object-assign\"),i=t(\"./main\");n(i.regionalOptions[\"\"],{invalidArguments:\"Invalid arguments\",invalidFormat:\"Cannot format a date from another calendar\",missingNumberAt:\"Missing number at position {0}\",unknownNameAt:\"Unknown name at position {0}\",unexpectedLiteralAt:\"Unexpected literal at position {0}\",unexpectedText:\"Additional text found at end\"}),i.local=i.regionalOptions[\"\"],n(i.cdate.prototype,{formatDate:function(t,e){return\"string\"!=typeof t&&(e=t,t=\"\"),this._calendar.formatDate(t||\"\",this,e)}}),n(i.baseCalendar.prototype,{UNIX_EPOCH:i.instance().newDate(1970,1,1).toJD(),SECS_PER_DAY:86400,TICKS_EPOCH:i.instance().jdEpoch,TICKS_PER_DAY:864e9,ATOM:\"yyyy-mm-dd\",COOKIE:\"D, dd M yyyy\",FULL:\"DD, MM d, yyyy\",ISO_8601:\"yyyy-mm-dd\",JULIAN:\"J\",RFC_822:\"D, d M yy\",RFC_850:\"DD, dd-M-yy\",RFC_1036:\"D, d M yy\",RFC_1123:\"D, d M yyyy\",RFC_2822:\"D, d M yyyy\",RSS:\"D, d M yy\",TICKS:\"!\",TIMESTAMP:\"@\",W3C:\"yyyy-mm-dd\",formatDate:function(t,e,r){if(\"string\"!=typeof t&&(r=e,e=t,t=\"\"),!e)return\"\";if(e.calendar()!==this)throw i.local.invalidFormat||i.regionalOptions[\"\"].invalidFormat;t=t||this.local.dateFormat;for(var n,a,o,s,l=(r=r||{}).dayNamesShort||this.local.dayNamesShort,c=r.dayNames||this.local.dayNames,u=r.monthNumbers||this.local.monthNumbers,h=r.monthNamesShort||this.local.monthNamesShort,f=r.monthNames||this.local.monthNames,p=(r.calculateWeek||this.local.calculateWeek,function(e,r){for(var n=1;w+n<t.length&&t.charAt(w+n)===e;)n++;return w+=n-1,Math.floor(n/(r||1))>1}),d=function(t,e,r,n){var i=\"\"+e;if(p(t,n))for(;i.length<r;)i=\"0\"+i;return i},g=this,v=function(t){return\"function\"==typeof u?u.call(g,t,p(\"m\")):x(d(\"m\",t.month(),2))},m=function(t,e){return e?\"function\"==typeof f?f.call(g,t):f[t.month()-g.minMonth]:\"function\"==typeof h?h.call(g,t):h[t.month()-g.minMonth]},y=this.local.digits,x=function(t){return r.localNumbers&&y?y(t):t},b=\"\",_=!1,w=0;w<t.length;w++)if(_)\"'\"!==t.charAt(w)||p(\"'\")?b+=t.charAt(w):_=!1;else switch(t.charAt(w)){case\"d\":b+=x(d(\"d\",e.day(),2));break;case\"D\":b+=(n=\"D\",a=e.dayOfWeek(),o=l,s=c,p(n)?s[a]:o[a]);break;case\"o\":b+=d(\"o\",e.dayOfYear(),3);break;case\"w\":b+=d(\"w\",e.weekOfYear(),2);break;case\"m\":b+=v(e);break;case\"M\":b+=m(e,p(\"M\"));break;case\"y\":b+=p(\"y\",2)?e.year():(e.year()%100<10?\"0\":\"\")+e.year()%100;break;case\"Y\":p(\"Y\",2),b+=e.formatYear();break;case\"J\":b+=e.toJD();break;case\"@\":b+=(e.toJD()-this.UNIX_EPOCH)*this.SECS_PER_DAY;break;case\"!\":b+=(e.toJD()-this.TICKS_EPOCH)*this.TICKS_PER_DAY;break;case\"'\":p(\"'\")?b+=\"'\":_=!0;break;default:b+=t.charAt(w)}return b},parseDate:function(t,e,r){if(null==e)throw i.local.invalidArguments||i.regionalOptions[\"\"].invalidArguments;if(\"\"===(e=\"object\"==typeof e?e.toString():e+\"\"))return null;t=t||this.local.dateFormat;var n=(r=r||{}).shortYearCutoff||this.shortYearCutoff;n=\"string\"!=typeof n?n:this.today().year()%100+parseInt(n,10);for(var a=r.dayNamesShort||this.local.dayNamesShort,o=r.dayNames||this.local.dayNames,s=r.parseMonth||this.local.parseMonth,l=r.monthNumbers||this.local.monthNumbers,c=r.monthNamesShort||this.local.monthNamesShort,u=r.monthNames||this.local.monthNames,h=-1,f=-1,p=-1,d=-1,g=-1,v=!1,m=!1,y=function(e,r){for(var n=1;M+n<t.length&&t.charAt(M+n)===e;)n++;return M+=n-1,Math.floor(n/(r||1))>1},x=function(t,r){var n=y(t,r),a=[2,3,n?4:2,n?4:2,10,11,20][\"oyYJ@!\".indexOf(t)+1],o=new RegExp(\"^-?\\\\d{1,\"+a+\"}\"),s=e.substring(A).match(o);if(!s)throw(i.local.missingNumberAt||i.regionalOptions[\"\"].missingNumberAt).replace(/\\{0\\}/,A);return A+=s[0].length,parseInt(s[0],10)},b=this,_=function(){if(\"function\"==typeof l){y(\"m\");var t=l.call(b,e.substring(A));return A+=t.length,t}return x(\"m\")},w=function(t,r,n,a){for(var o=y(t,a)?n:r,s=0;s<o.length;s++)if(e.substr(A,o[s].length).toLowerCase()===o[s].toLowerCase())return A+=o[s].length,s+b.minMonth;throw(i.local.unknownNameAt||i.regionalOptions[\"\"].unknownNameAt).replace(/\\{0\\}/,A)},k=function(){if(\"function\"==typeof u){var t=y(\"M\")?u.call(b,e.substring(A)):c.call(b,e.substring(A));return A+=t.length,t}return w(\"M\",c,u)},T=function(){if(e.charAt(A)!==t.charAt(M))throw(i.local.unexpectedLiteralAt||i.regionalOptions[\"\"].unexpectedLiteralAt).replace(/\\{0\\}/,A);A++},A=0,M=0;M<t.length;M++)if(m)\"'\"!==t.charAt(M)||y(\"'\")?T():m=!1;else switch(t.charAt(M)){case\"d\":d=x(\"d\");break;case\"D\":w(\"D\",a,o);break;case\"o\":g=x(\"o\");break;case\"w\":x(\"w\");break;case\"m\":p=_();break;case\"M\":p=k();break;case\"y\":var S=M;v=!y(\"y\",2),M=S,f=x(\"y\",2);break;case\"Y\":f=x(\"Y\",2);break;case\"J\":h=x(\"J\")+.5,\".\"===e.charAt(A)&&(A++,x(\"J\"));break;case\"@\":h=x(\"@\")/this.SECS_PER_DAY+this.UNIX_EPOCH;break;case\"!\":h=x(\"!\")/this.TICKS_PER_DAY+this.TICKS_EPOCH;break;case\"*\":A=e.length;break;case\"'\":y(\"'\")?T():m=!0;break;default:T()}if(A<e.length)throw i.local.unexpectedText||i.regionalOptions[\"\"].unexpectedText;if(-1===f?f=this.today().year():f<100&&v&&(f+=-1===n?1900:this.today().year()-this.today().year()%100-(f<=n?0:100)),\"string\"==typeof p&&(p=s.call(this,f,p)),g>-1){p=1,d=g;for(var E=this.daysInMonth(f,p);d>E;E=this.daysInMonth(f,p))p++,d-=E}return h>-1?this.fromJD(h):this.newDate(f,p,d)},determineDate:function(t,e,r,n,i){r&&\"object\"!=typeof r&&(i=n,n=r,r=null),\"string\"!=typeof n&&(i=n,n=\"\");var a=this;return e=e?e.newDate():null,t=null==t?e:\"string\"==typeof t?function(t){try{return a.parseDate(n,t,i)}catch(t){}for(var e=((t=t.toLowerCase()).match(/^c/)&&r?r.newDate():null)||a.today(),o=/([+-]?[0-9]+)\\s*(d|w|m|y)?/g,s=o.exec(t);s;)e.add(parseInt(s[1],10),s[2]||\"d\"),s=o.exec(t);return e}(t):\"number\"==typeof t?isNaN(t)||t===1/0||t===-1/0?e:a.today().add(t,\"d\"):a.newDate(t)}})},{\"./main\":571,\"object-assign\":454}],573:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",{offset:[1],array:0},\"scalar\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\n        var _inline_1_da = _inline_1_arg0_ - _inline_1_arg3_\\n        var _inline_1_db = _inline_1_arg1_ - _inline_1_arg3_\\n        if((_inline_1_da >= 0) !== (_inline_1_db >= 0)) {\\n          _inline_1_arg2_.push(_inline_1_arg4_[0] + 0.5 + 0.5 * (_inline_1_da + _inline_1_db) / (_inline_1_da - _inline_1_db))\\n        }\\n      }\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg3_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[\"_inline_1_da\",\"_inline_1_db\"]},funcName:\"zeroCrossings\"})},{\"cwise-compiler\":146}],574:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=[];return e=+e||0,n(t.hi(t.shape[0]-1),r,e),r};var n=t(\"./lib/zc-core\")},{\"./lib/zc-core\":573}],575:[function(t,e,r){\"use strict\";e.exports=[{path:\"\",backoff:0},{path:\"M-2.4,-3V3L0.6,0Z\",backoff:.6},{path:\"M-3.7,-2.5V2.5L1.3,0Z\",backoff:1.3},{path:\"M-4.45,-3L-1.65,-0.2V0.2L-4.45,3L1.55,0Z\",backoff:1.55},{path:\"M-2.2,-2.2L-0.2,-0.2V0.2L-2.2,2.2L-1.4,3L1.6,0L-1.4,-3Z\",backoff:1.6},{path:\"M-4.4,-2.1L-0.6,-0.2V0.2L-4.4,2.1L-4,3L2,0L-4,-3Z\",backoff:2},{path:\"M2,0A2,2 0 1,1 0,-2A2,2 0 0,1 2,0Z\",backoff:0,noRotate:!0},{path:\"M2,2V-2H-2V2Z\",backoff:0,noRotate:!0}]},{}],576:[function(t,e,r){\"use strict\";var n=t(\"./arrow_paths\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../plots/cartesian/constants\"),o=t(\"../../plot_api/plot_template\").templatedArray;e.exports=o(\"annotation\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},text:{valType:\"string\",editType:\"calc+arraydraw\"},textangle:{valType:\"angle\",dflt:0,editType:\"calc+arraydraw\"},font:i({editType:\"calc+arraydraw\",colorEditType:\"arraydraw\"}),width:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},height:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"center\",editType:\"arraydraw\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"arraydraw\"},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},borderpad:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},showarrow:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},arrowcolor:{valType:\"color\",editType:\"arraydraw\"},arrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},startarrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},arrowside:{valType:\"flaglist\",flags:[\"end\",\"start\"],extras:[\"none\"],dflt:\"end\",editType:\"arraydraw\"},arrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},startarrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},arrowwidth:{valType:\"number\",min:.1,editType:\"calc+arraydraw\"},standoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},startstandoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},ax:{valType:\"any\",editType:\"calc+arraydraw\"},ay:{valType:\"any\",editType:\"calc+arraydraw\"},axref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.x.toString()],editType:\"calc\"},ayref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.y.toString()],editType:\"calc\"},xref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.x.toString()],editType:\"calc\"},x:{valType:\"any\",editType:\"calc+arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"auto\",editType:\"calc+arraydraw\"},xshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.y.toString()],editType:\"calc\"},y:{valType:\"any\",editType:\"calc+arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"calc+arraydraw\"},yshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},clicktoshow:{valType:\"enumerated\",values:[!1,\"onoff\",\"onout\"],dflt:!1,editType:\"arraydraw\"},xclick:{valType:\"any\",editType:\"arraydraw\"},yclick:{valType:\"any\",editType:\"arraydraw\"},hovertext:{valType:\"string\",editType:\"arraydraw\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",editType:\"arraydraw\"},font:i({editType:\"arraydraw\"}),editType:\"arraydraw\"},captureevents:{valType:\"boolean\",editType:\"arraydraw\"},editType:\"calc\",_deprecated:{ref:{valType:\"string\",editType:\"calc\"}}})},{\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773,\"../../plots/font_attributes\":793,\"./arrow_paths\":575}],577:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./draw\").draw;function o(t){var e=t._fullLayout;n.filterVisible(e.annotations).forEach(function(e){var r=i.getFromId(t,e.xref),n=i.getFromId(t,e.yref);e._extremes={},r&&s(e,r),n&&s(e,n)})}function s(t,e){var r,n=e._id,a=n.charAt(0),o=t[a],s=t[\"a\"+a],l=t[a+\"ref\"],c=t[\"a\"+a+\"ref\"],u=t[\"_\"+a+\"padplus\"],h=t[\"_\"+a+\"padminus\"],f={x:1,y:-1}[a]*t[a+\"shift\"],p=3*t.arrowsize*t.arrowwidth||0,d=p+f,g=p-f,v=3*t.startarrowsize*t.arrowwidth||0,m=v+f,y=v-f;if(c===l){var x=i.findExtremes(e,[e.r2c(o)],{ppadplus:d,ppadminus:g}),b=i.findExtremes(e,[e.r2c(s)],{ppadplus:Math.max(u,m),ppadminus:Math.max(h,y)});r={min:[x.min[0],b.min[0]],max:[x.max[0],b.max[0]]}}else m=s?m+s:m,y=s?y-s:y,r=i.findExtremes(e,[e.r2c(o)],{ppadplus:Math.max(u,d,m),ppadminus:Math.max(h,g,y)});t._extremes[n]=r}e.exports=function(t){var e=t._fullLayout;if(n.filterVisible(e.annotations).length&&t._fullData.length)return n.syncOrAsync([a,o],t)}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./draw\":582}],578:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../plot_api/plot_template\").arrayEditor;function o(t,e){var r,n,i,a,o,l,c,u=t._fullLayout.annotations,h=[],f=[],p=[],d=(e||[]).length;for(r=0;r<u.length;r++)if(a=(i=u[r]).clicktoshow){for(n=0;n<d;n++)if(l=(o=e[n]).xaxis,c=o.yaxis,l._id===i.xref&&c._id===i.yref&&l.d2r(o.x)===s(i._xclick,l)&&c.d2r(o.y)===s(i._yclick,c)){(i.visible?\"onout\"===a?f:p:h).push(r);break}n===d&&i.visible&&\"onout\"===a&&f.push(r)}return{on:h,off:f,explicitOff:p}}function s(t,e){return\"log\"===e.type?e.l2r(t):e.d2r(t)}e.exports={hasClickToShow:function(t,e){var r=o(t,e);return r.on.length>0||r.explicitOff.length>0},onClick:function(t,e){var r,s,l=o(t,e),c=l.on,u=l.off.concat(l.explicitOff),h={},f=t._fullLayout.annotations;if(!c.length&&!u.length)return;for(r=0;r<c.length;r++)(s=a(t.layout,\"annotations\",f[c[r]])).modifyItem(\"visible\",!0),n.extendFlat(h,s.getUpdateObj());for(r=0;r<u.length;r++)(s=a(t.layout,\"annotations\",f[u[r]])).modifyItem(\"visible\",!1),n.extendFlat(h,s.getUpdateObj());return i.call(\"update\",t,{},h)}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../registry\":847}],579:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\");e.exports=function(t,e,r,a){a(\"opacity\");var o=a(\"bgcolor\"),s=a(\"bordercolor\"),l=i.opacity(s);a(\"borderpad\");var c=a(\"borderwidth\"),u=a(\"showarrow\");if(a(\"text\",u?\" \":r._dfltTitle.annotation),a(\"textangle\"),n.coerceFont(a,\"font\",r.font),a(\"width\"),a(\"align\"),a(\"height\")&&a(\"valign\"),u){var h,f,p=a(\"arrowside\");-1!==p.indexOf(\"end\")&&(h=a(\"arrowhead\"),f=a(\"arrowsize\")),-1!==p.indexOf(\"start\")&&(a(\"startarrowhead\",h),a(\"startarrowsize\",f)),a(\"arrowcolor\",l?e.bordercolor:i.defaultLine),a(\"arrowwidth\",2*(l&&c||1)),a(\"standoff\"),a(\"startstandoff\")}var d=a(\"hovertext\"),g=r.hoverlabel||{};if(d){var v=a(\"hoverlabel.bgcolor\",g.bgcolor||(i.opacity(o)?i.rgb(o):i.defaultLine)),m=a(\"hoverlabel.bordercolor\",g.bordercolor||i.contrast(v));n.coerceFont(a,\"hoverlabel.font\",{family:g.font.family,size:g.font.size,color:g.font.color||m})}a(\"captureevents\",!!d)}},{\"../../lib\":719,\"../color\":593}],580:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.annotations,h=e._id.charAt(0),f=0;f<u.length;f++)l=u[f],c=\"annotations[\"+f+\"].\",l[h+\"ref\"]===e._id&&p(h),l[\"a\"+h+\"ref\"]===e._id&&p(\"a\"+h);function p(t){var r=l[t],s=null;s=o?i(r,e.range):Math.pow(10,r),n(s)||(s=null),a(c+t,s)}}},{\"../../lib/to_log_range\":745,\"fast-isnumeric\":225}],581:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./common_defaults\"),s=t(\"./attributes\");function l(t,e,r){function a(r,i){return n.coerce(t,e,s,r,i)}var l=a(\"visible\"),c=a(\"clicktoshow\");if(l||c){o(t,e,r,a);for(var u=e.showarrow,h=[\"x\",\"y\"],f=[-10,-30],p={_fullLayout:r},d=0;d<2;d++){var g=h[d],v=i.coerceRef(t,e,p,g,\"\",\"paper\");if(\"paper\"!==v)i.getFromId(p,v)._annIndices.push(e._index);if(i.coercePosition(e,p,a,v,g,.5),u){var m=\"a\"+g,y=i.coerceRef(t,e,p,m,\"pixel\");\"pixel\"!==y&&y!==v&&(y=e[m]=\"pixel\");var x=\"pixel\"===y?f[d]:.4;i.coercePosition(e,p,a,y,m,x)}a(g+\"anchor\"),a(g+\"shift\")}if(n.noneOrAll(t,e,[\"x\",\"y\"]),u&&n.noneOrAll(t,e,[\"ax\",\"ay\"]),c){var b=a(\"xclick\"),_=a(\"yclick\");e._xclick=void 0===b?e.x:i.cleanPosition(b,p,e.xref),e._yclick=void 0===_?e.y:i.cleanPosition(_,p,e.yref)}}}e.exports=function(t,e){a(t,e,{name:\"annotations\",handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"./attributes\":576,\"./common_defaults\":579}],582:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../color\"),c=t(\"../drawing\"),u=t(\"../fx\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"../../lib/setcursor\"),p=t(\"../dragelement\"),d=t(\"../../plot_api/plot_template\").arrayEditor,g=t(\"./draw_arrow_head\");function v(t,e){var r=t._fullLayout.annotations[e]||{},n=s.getFromId(t,r.xref),i=s.getFromId(t,r.yref);n&&n.setScale(),i&&i.setScale(),m(t,r,e,!1,n,i)}function m(t,e,r,a,s,v){var m,y,x=t._fullLayout,b=t._fullLayout._size,_=t._context.edits;a?(m=\"annotation-\"+a,y=a+\".annotations\"):(m=\"annotation\",y=\"annotations\");var w=d(t.layout,y,e),k=w.modifyBase,T=w.modifyItem,A=w.getUpdateObj;x._infolayer.selectAll(\".\"+m+'[data-index=\"'+r+'\"]').remove();var M=\"clip\"+x._uid+\"_ann\"+r;if(e._input&&!1!==e.visible){var S={x:{},y:{}},E=+e.textangle||0,C=x._infolayer.append(\"g\").classed(m,!0).attr(\"data-index\",String(r)).style(\"opacity\",e.opacity),L=C.append(\"g\").classed(\"annotation-text-g\",!0),P=_[e.showarrow?\"annotationTail\":\"annotationPosition\"],O=e.captureevents||_.annotationText||P,z=L.append(\"g\").style(\"pointer-events\",O?\"all\":null).call(f,\"pointer\").on(\"click\",function(){t._dragging=!1,t.emit(\"plotly_clickannotation\",q(n.event))});e.hovertext&&z.on(\"mouseover\",function(){var r=e.hoverlabel,n=r.font,i=this.getBoundingClientRect(),a=t.getBoundingClientRect();u.loneHover({x0:i.left-a.left,x1:i.right-a.left,y:(i.top+i.bottom)/2-a.top,text:e.hovertext,color:r.bgcolor,borderColor:r.bordercolor,fontFamily:n.family,fontSize:n.size,fontColor:n.color},{container:x._hoverlayer.node(),outerContainer:x._paper.node(),gd:t})}).on(\"mouseout\",function(){u.loneUnhover(x._hoverlayer.node())});var I=e.borderwidth,D=e.borderpad,R=I+D,F=z.append(\"rect\").attr(\"class\",\"bg\").style(\"stroke-width\",I+\"px\").call(l.stroke,e.bordercolor).call(l.fill,e.bgcolor),B=e.width||e.height,N=x._topclips.selectAll(\"#\"+M).data(B?[0]:[]);N.enter().append(\"clipPath\").classed(\"annclip\",!0).attr(\"id\",M).append(\"rect\"),N.exit().remove();var j=e.font,U=x._meta?o.templateString(e.text,x._meta):e.text,V=z.append(\"text\").classed(\"annotation-text\",!0).text(U);_.annotationText?V.call(h.makeEditable,{delegate:z,gd:t}).call(H).on(\"edit\",function(r){e.text=r,this.call(H),T(\"text\",r),s&&s.autorange&&k(s._name+\".autorange\",!0),v&&v.autorange&&k(v._name+\".autorange\",!0),i.call(\"_guiRelayout\",t,A())}):V.call(H)}else n.selectAll(\"#\"+M).remove();function q(t){var n={index:r,annotation:e._input,fullAnnotation:e,event:t};return a&&(n.subplotId=a),n}function H(r){return r.call(c.font,j).attr({\"text-anchor\":{left:\"start\",right:\"end\"}[e.align]||\"middle\"}),h.convertToTspans(r,t,G),r}function G(){var r=V.selectAll(\"a\");1===r.size()&&r.text()===V.text()&&z.insert(\"a\",\":first-child\").attr({\"xlink:xlink:href\":r.attr(\"xlink:href\"),\"xlink:xlink:show\":r.attr(\"xlink:show\")}).style({cursor:\"pointer\"}).node().appendChild(F.node());var n=z.select(\".annotation-text-math-group\"),u=!n.empty(),d=c.bBox((u?n:V).node()),m=d.width,y=d.height,w=e.width||m,O=e.height||y,D=Math.round(w+2*R),j=Math.round(O+2*R);function U(t,e){return\"auto\"===e&&(e=t<1/3?\"left\":t>2/3?\"right\":\"center\"),{center:0,middle:0,left:.5,bottom:-.5,right:-.5,top:.5}[e]}for(var H=!1,G=[\"x\",\"y\"],Y=0;Y<G.length;Y++){var W,X,Z,J,K,$=G[Y],Q=e[$+\"ref\"]||$,tt=e[\"a\"+$+\"ref\"],et={x:s,y:v}[$],rt=(E+(\"x\"===$?0:-90))*Math.PI/180,nt=D*Math.cos(rt),it=j*Math.sin(rt),at=Math.abs(nt)+Math.abs(it),ot=e[$+\"anchor\"],st=e[$+\"shift\"]*(\"x\"===$?1:-1),lt=S[$];if(et){var ct=et.r2fraction(e[$]);(ct<0||ct>1)&&(tt===Q?((ct=et.r2fraction(e[\"a\"+$]))<0||ct>1)&&(H=!0):H=!0),W=et._offset+et.r2p(e[$]),J=.5}else\"x\"===$?(Z=e[$],W=b.l+b.w*Z):(Z=1-e[$],W=b.t+b.h*Z),J=e.showarrow?.5:Z;if(e.showarrow){lt.head=W;var ut=e[\"a\"+$];K=nt*U(.5,e.xanchor)-it*U(.5,e.yanchor),tt===Q?(lt.tail=et._offset+et.r2p(ut),X=K):(lt.tail=W+ut,X=K+ut),lt.text=lt.tail+K;var ht=x[\"x\"===$?\"width\":\"height\"];if(\"paper\"===Q&&(lt.head=o.constrain(lt.head,1,ht-1)),\"pixel\"===tt){var ft=-Math.max(lt.tail-3,lt.text),pt=Math.min(lt.tail+3,lt.text)-ht;ft>0?(lt.tail+=ft,lt.text+=ft):pt>0&&(lt.tail-=pt,lt.text-=pt)}lt.tail+=st,lt.head+=st}else X=K=at*U(J,ot),lt.text=W+K;lt.text+=st,K+=st,X+=st,e[\"_\"+$+\"padplus\"]=at/2+X,e[\"_\"+$+\"padminus\"]=at/2-X,e[\"_\"+$+\"size\"]=at,e[\"_\"+$+\"shift\"]=K}if(t._dragging||!H){var dt=0,gt=0;if(\"left\"!==e.align&&(dt=(w-m)*(\"center\"===e.align?.5:1)),\"top\"!==e.valign&&(gt=(O-y)*(\"middle\"===e.valign?.5:1)),u)n.select(\"svg\").attr({x:R+dt-1,y:R+gt}).call(c.setClipUrl,B?M:null,t);else{var vt=R+gt-d.top,mt=R+dt-d.left;V.call(h.positionText,mt,vt).call(c.setClipUrl,B?M:null,t)}N.select(\"rect\").call(c.setRect,R,R,w,O),F.call(c.setRect,I/2,I/2,D-I,j-I),z.call(c.setTranslate,Math.round(S.x.text-D/2),Math.round(S.y.text-j/2)),L.attr({transform:\"rotate(\"+E+\",\"+S.x.text+\",\"+S.y.text+\")\"});var yt,xt=function(r,n){C.selectAll(\".annotation-arrow-g\").remove();var u=S.x.head,h=S.y.head,f=S.x.tail+r,d=S.y.tail+n,m=S.x.text+r,y=S.y.text+n,x=o.rotationXYMatrix(E,m,y),w=o.apply2DTransform(x),M=o.apply2DTransform2(x),P=+F.attr(\"width\"),O=+F.attr(\"height\"),I=m-.5*P,D=I+P,R=y-.5*O,B=R+O,N=[[I,R,I,B],[I,B,D,B],[D,B,D,R],[D,R,I,R]].map(M);if(!N.reduce(function(t,e){return t^!!o.segmentsIntersect(u,h,u+1e6,h+1e6,e[0],e[1],e[2],e[3])},!1)){N.forEach(function(t){var e=o.segmentsIntersect(f,d,u,h,t[0],t[1],t[2],t[3]);e&&(f=e.x,d=e.y)});var j=e.arrowwidth,U=e.arrowcolor,V=e.arrowside,q=C.append(\"g\").style({opacity:l.opacity(U)}).classed(\"annotation-arrow-g\",!0),H=q.append(\"path\").attr(\"d\",\"M\"+f+\",\"+d+\"L\"+u+\",\"+h).style(\"stroke-width\",j+\"px\").call(l.stroke,l.rgb(U));if(g(H,V,e),_.annotationPosition&&H.node().parentNode&&!a){var G=u,Y=h;if(e.standoff){var W=Math.sqrt(Math.pow(u-f,2)+Math.pow(h-d,2));G+=e.standoff*(f-u)/W,Y+=e.standoff*(d-h)/W}var X,Z,J=q.append(\"path\").classed(\"annotation-arrow\",!0).classed(\"anndrag\",!0).classed(\"cursor-move\",!0).attr({d:\"M3,3H-3V-3H3ZM0,0L\"+(f-G)+\",\"+(d-Y),transform:\"translate(\"+G+\",\"+Y+\")\"}).style(\"stroke-width\",j+6+\"px\").call(l.stroke,\"rgba(0,0,0,0)\").call(l.fill,\"rgba(0,0,0,0)\");p.init({element:J.node(),gd:t,prepFn:function(){var t=c.getTranslate(z);X=t.x,Z=t.y,s&&s.autorange&&k(s._name+\".autorange\",!0),v&&v.autorange&&k(v._name+\".autorange\",!0)},moveFn:function(t,r){var n=w(X,Z),i=n[0]+t,a=n[1]+r;z.call(c.setTranslate,i,a),T(\"x\",s?s.p2r(s.r2p(e.x)+t):e.x+t/b.w),T(\"y\",v?v.p2r(v.r2p(e.y)+r):e.y-r/b.h),e.axref===e.xref&&T(\"ax\",s.p2r(s.r2p(e.ax)+t)),e.ayref===e.yref&&T(\"ay\",v.p2r(v.r2p(e.ay)+r)),q.attr(\"transform\",\"translate(\"+t+\",\"+r+\")\"),L.attr({transform:\"rotate(\"+E+\",\"+i+\",\"+a+\")\"})},doneFn:function(){i.call(\"_guiRelayout\",t,A());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}}};if(e.showarrow&&xt(0,0),P)p.init({element:z.node(),gd:t,prepFn:function(){yt=L.attr(\"transform\")},moveFn:function(t,r){var n=\"pointer\";if(e.showarrow)e.axref===e.xref?T(\"ax\",s.p2r(s.r2p(e.ax)+t)):T(\"ax\",e.ax+t),e.ayref===e.yref?T(\"ay\",v.p2r(v.r2p(e.ay)+r)):T(\"ay\",e.ay+r),xt(t,r);else{if(a)return;var i,o;if(s)i=s.p2r(s.r2p(e.x)+t);else{var l=e._xsize/b.w,c=e.x+(e._xshift-e.xshift)/b.w-l/2;i=p.align(c+t/b.w,l,0,1,e.xanchor)}if(v)o=v.p2r(v.r2p(e.y)+r);else{var u=e._ysize/b.h,h=e.y-(e._yshift+e.yshift)/b.h-u/2;o=p.align(h-r/b.h,u,0,1,e.yanchor)}T(\"x\",i),T(\"y\",o),s&&v||(n=p.getCursor(s?.5:i,v?.5:o,e.xanchor,e.yanchor))}L.attr({transform:\"translate(\"+t+\",\"+r+\")\"+yt}),f(z,n)},clickFn:function(r,n){e.captureevents&&t.emit(\"plotly_clickannotation\",q(n))},doneFn:function(){f(z),i.call(\"_guiRelayout\",t,A());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}else z.remove()}}e.exports={draw:function(t){var e=t._fullLayout;e._infolayer.selectAll(\".annotation\").remove();for(var r=0;r<e.annotations.length;r++)e.annotations[r].visible&&v(t,r);return a.previousPromises(t)},drawOne:v,drawRaw:m}},{\"../../lib\":719,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/axes\":767,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"../fx\":632,\"./draw_arrow_head\":583,d3:163}],583:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\"),a=t(\"./arrow_paths\");e.exports=function(t,e,r){var o,s,l,c,u=t.node(),h=a[r.arrowhead||0],f=a[r.startarrowhead||0],p=(r.arrowwidth||1)*(r.arrowsize||1),d=(r.arrowwidth||1)*(r.startarrowsize||1),g=e.indexOf(\"start\")>=0,v=e.indexOf(\"end\")>=0,m=h.backoff*p+r.standoff,y=f.backoff*d+r.startstandoff;if(\"line\"===u.nodeName){o={x:+t.attr(\"x1\"),y:+t.attr(\"y1\")},s={x:+t.attr(\"x2\"),y:+t.attr(\"y2\")};var x=o.x-s.x,b=o.y-s.y;if(c=(l=Math.atan2(b,x))+Math.PI,m&&y&&m+y>Math.sqrt(x*x+b*b))return void P();if(m){if(m*m>x*x+b*b)return void P();var _=m*Math.cos(l),w=m*Math.sin(l);s.x+=_,s.y+=w,t.attr({x2:s.x,y2:s.y})}if(y){if(y*y>x*x+b*b)return void P();var k=y*Math.cos(l),T=y*Math.sin(l);o.x-=k,o.y-=T,t.attr({x1:o.x,y1:o.y})}}else if(\"path\"===u.nodeName){var A=u.getTotalLength(),M=\"\";if(A<m+y)return void P();var S=u.getPointAtLength(0),E=u.getPointAtLength(.1);l=Math.atan2(S.y-E.y,S.x-E.x),o=u.getPointAtLength(Math.min(y,A)),M=\"0px,\"+y+\"px,\";var C=u.getPointAtLength(A),L=u.getPointAtLength(A-.1);c=Math.atan2(C.y-L.y,C.x-L.x),s=u.getPointAtLength(Math.max(0,A-m)),M+=A-(M?y+m:m)+\"px,\"+A+\"px\",t.style(\"stroke-dasharray\",M)}function P(){t.style(\"stroke-dasharray\",\"0px,100px\")}function O(e,a,o,s){e.path&&(e.noRotate&&(o=0),n.select(u.parentNode).append(\"path\").attr({class:t.attr(\"class\"),d:e.path,transform:\"translate(\"+a.x+\",\"+a.y+\")\"+(o?\"rotate(\"+180*o/Math.PI+\")\":\"\")+\"scale(\"+s+\")\"}).style({fill:i.rgb(r.arrowcolor),\"stroke-width\":0}))}g&&O(f,o,l,d),v&&O(h,s,c,p)}},{\"../color\":593,\"./arrow_paths\":575,d3:163}],584:[function(t,e,r){\"use strict\";var n=t(\"./draw\"),i=t(\"./click\");e.exports={moduleType:\"component\",name:\"annotations\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"annotations\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne,drawRaw:n.drawRaw,hasClickToShow:i.hasClickToShow,onClick:i.onClick,convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":777,\"./attributes\":576,\"./calc_autorange\":577,\"./click\":578,\"./convert_coords\":580,\"./defaults\":581,\"./draw\":582}],585:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"../../plot_api/plot_template\").templatedArray;e.exports=i(a(\"annotation\",{visible:n.visible,x:{valType:\"any\"},y:{valType:\"any\"},z:{valType:\"any\"},ax:{valType:\"number\"},ay:{valType:\"number\"},xanchor:n.xanchor,xshift:n.xshift,yanchor:n.yanchor,yshift:n.yshift,text:n.text,textangle:n.textangle,font:n.font,width:n.width,height:n.height,opacity:n.opacity,align:n.align,valign:n.valign,bgcolor:n.bgcolor,bordercolor:n.bordercolor,borderpad:n.borderpad,borderwidth:n.borderwidth,showarrow:n.showarrow,arrowcolor:n.arrowcolor,arrowhead:n.arrowhead,startarrowhead:n.startarrowhead,arrowside:n.arrowside,arrowsize:n.arrowsize,startarrowsize:n.startarrowsize,arrowwidth:n.arrowwidth,standoff:n.standoff,startstandoff:n.startstandoff,hovertext:n.hovertext,hoverlabel:n.hoverlabel,captureevents:n.captureevents}),\"calc\",\"from-root\")},{\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../annotations/attributes\":576}],586:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\");function a(t,e){var r=e.fullSceneLayout.domain,a=e.fullLayout._size,o={pdata:null,type:\"linear\",autorange:!1,range:[-1/0,1/0]};t._xa={},n.extendFlat(t._xa,o),i.setConvert(t._xa),t._xa._offset=a.l+r.x[0]*a.w,t._xa.l2p=function(){return.5*(1+t._pdata[0]/t._pdata[3])*a.w*(r.x[1]-r.x[0])},t._ya={},n.extendFlat(t._ya,o),i.setConvert(t._ya),t._ya._offset=a.t+(1-r.y[1])*a.h,t._ya.l2p=function(){return.5*(1-t._pdata[1]/t._pdata[3])*a.h*(r.y[1]-r.y[0])}}e.exports=function(t){for(var e=t.fullSceneLayout.annotations,r=0;r<e.length;r++)a(e[r],t);t.fullLayout._infolayer.selectAll(\".annotation-\"+t.id).remove()}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767}],587:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"../annotations/common_defaults\"),s=t(\"./attributes\");function l(t,e,r,a){function l(r,i){return n.coerce(t,e,s,r,i)}function c(t){var n=t+\"axis\",a={_fullLayout:{}};return a._fullLayout[n]=r[n],i.coercePosition(e,a,l,t,t,.5)}l(\"visible\")&&(o(t,e,a.fullLayout,l),c(\"x\"),c(\"y\"),c(\"z\"),n.noneOrAll(t,e,[\"x\",\"y\",\"z\"]),e.xref=\"x\",e.yref=\"y\",e.zref=\"z\",l(\"xanchor\"),l(\"yanchor\"),l(\"xshift\"),l(\"yshift\"),e.showarrow&&(e.axref=\"pixel\",e.ayref=\"pixel\",l(\"ax\",-10),l(\"ay\",-30),n.noneOrAll(t,e,[\"ax\",\"ay\"])))}e.exports=function(t,e,r){a(t,e,{name:\"annotations\",handleItemDefaults:l,fullLayout:r.fullLayout})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"../annotations/common_defaults\":579,\"./attributes\":585}],588:[function(t,e,r){\"use strict\";var n=t(\"../annotations/draw\").drawRaw,i=t(\"../../plots/gl3d/project\"),a=[\"x\",\"y\",\"z\"];e.exports=function(t){for(var e=t.fullSceneLayout,r=t.dataScale,o=e.annotations,s=0;s<o.length;s++){for(var l=o[s],c=!1,u=0;u<3;u++){var h=a[u],f=l[h],p=e[h+\"axis\"].r2fraction(f);if(p<0||p>1){c=!0;break}}c?t.fullLayout._infolayer.select(\".annotation-\"+t.id+'[data-index=\"'+s+'\"]').remove():(l._pdata=i(t.glplot.cameraParams,[e.xaxis.r2l(l.x)*r[0],e.yaxis.r2l(l.y)*r[1],e.zaxis.r2l(l.z)*r[2]]),n(t.graphDiv,l,s,t.id,l._xa,l._ya))}}},{\"../../plots/gl3d/project\":816,\"../annotations/draw\":582}],589:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports={moduleType:\"component\",name:\"annotations3d\",schema:{subplots:{scene:{annotations:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),includeBasePlot:function(t,e){var r=n.subplotsRegistry.gl3d;if(!r)return;for(var a=r.attrRegex,o=Object.keys(t),s=0;s<o.length;s++){var l=o[s];a.test(l)&&(t[l].annotations||[]).length&&(i.pushUnique(e._basePlotModules,r),i.pushUnique(e._subplots.gl3d,l))}},convert:t(\"./convert\"),draw:t(\"./draw\")}},{\"../../lib\":719,\"../../registry\":847,\"./attributes\":585,\"./convert\":586,\"./defaults\":587,\"./draw\":588}],590:[function(t,e,r){\"use strict\";e.exports=t(\"world-calendars/dist/main\"),t(\"world-calendars/dist/plus\"),t(\"world-calendars/dist/calendars/chinese\"),t(\"world-calendars/dist/calendars/coptic\"),t(\"world-calendars/dist/calendars/discworld\"),t(\"world-calendars/dist/calendars/ethiopian\"),t(\"world-calendars/dist/calendars/hebrew\"),t(\"world-calendars/dist/calendars/islamic\"),t(\"world-calendars/dist/calendars/julian\"),t(\"world-calendars/dist/calendars/mayan\"),t(\"world-calendars/dist/calendars/nanakshahi\"),t(\"world-calendars/dist/calendars/nepali\"),t(\"world-calendars/dist/calendars/persian\"),t(\"world-calendars/dist/calendars/taiwan\"),t(\"world-calendars/dist/calendars/thai\"),t(\"world-calendars/dist/calendars/ummalqura\")},{\"world-calendars/dist/calendars/chinese\":557,\"world-calendars/dist/calendars/coptic\":558,\"world-calendars/dist/calendars/discworld\":559,\"world-calendars/dist/calendars/ethiopian\":560,\"world-calendars/dist/calendars/hebrew\":561,\"world-calendars/dist/calendars/islamic\":562,\"world-calendars/dist/calendars/julian\":563,\"world-calendars/dist/calendars/mayan\":564,\"world-calendars/dist/calendars/nanakshahi\":565,\"world-calendars/dist/calendars/nepali\":566,\"world-calendars/dist/calendars/persian\":567,\"world-calendars/dist/calendars/taiwan\":568,\"world-calendars/dist/calendars/thai\":569,\"world-calendars/dist/calendars/ummalqura\":570,\"world-calendars/dist/main\":571,\"world-calendars/dist/plus\":572}],591:[function(t,e,r){\"use strict\";var n=t(\"./calendars\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\"),o=a.EPOCHJD,s=a.ONEDAY,l={valType:\"enumerated\",values:Object.keys(n.calendars),editType:\"calc\",dflt:\"gregorian\"},c=function(t,e,r,n){var a={};return a[r]=l,i.coerce(t,e,a,r,n)},u=\"##\",h={d:{0:\"dd\",\"-\":\"d\"},e:{0:\"d\",\"-\":\"d\"},a:{0:\"D\",\"-\":\"D\"},A:{0:\"DD\",\"-\":\"DD\"},j:{0:\"oo\",\"-\":\"o\"},W:{0:\"ww\",\"-\":\"w\"},m:{0:\"mm\",\"-\":\"m\"},b:{0:\"M\",\"-\":\"M\"},B:{0:\"MM\",\"-\":\"MM\"},y:{0:\"yy\",\"-\":\"yy\"},Y:{0:\"yyyy\",\"-\":\"yyyy\"},U:u,w:u,c:{0:\"D M d %X yyyy\",\"-\":\"D M d %X yyyy\"},x:{0:\"mm/dd/yyyy\",\"-\":\"mm/dd/yyyy\"}};var f={};function p(t){var e=f[t];return e||(e=f[t]=n.instance(t))}function d(t){return i.extendFlat({},l,{description:t})}function g(t){return\"Sets the calendar system to use with `\"+t+\"` date data.\"}var v={xcalendar:d(g(\"x\"))},m=i.extendFlat({},v,{ycalendar:d(g(\"y\"))}),y=i.extendFlat({},m,{zcalendar:d(g(\"z\"))}),x=d([\"Sets the calendar system to use for `range` and `tick0`\",\"if this is a date axis. This does not set the calendar for\",\"interpreting data on this axis, that's specified in the trace\",\"or via the global `layout.calendar`\"].join(\" \"));e.exports={moduleType:\"component\",name:\"calendars\",schema:{traces:{scatter:m,bar:m,box:m,heatmap:m,contour:m,histogram:m,histogram2d:m,histogram2dcontour:m,scatter3d:y,surface:y,mesh3d:y,scattergl:m,ohlc:v,candlestick:v},layout:{calendar:d([\"Sets the default calendar system to use for interpreting and\",\"displaying dates throughout the plot.\"].join(\" \"))},subplots:{xaxis:{calendar:x},yaxis:{calendar:x},scene:{xaxis:{calendar:x},yaxis:{calendar:x},zaxis:{calendar:x}},polar:{radialaxis:{calendar:x}}},transforms:{filter:{valuecalendar:d([\"Sets the calendar system to use for `value`, if it is a date.\"].join(\" \")),targetcalendar:d([\"Sets the calendar system to use for `target`, if it is an\",\"array of dates. If `target` is a string (eg *x*) we use the\",\"corresponding trace attribute (eg `xcalendar`) if it exists,\",\"even if `targetcalendar` is provided.\"].join(\" \"))}}},layoutAttributes:l,handleDefaults:c,handleTraceDefaults:function(t,e,r,n){for(var i=0;i<r.length;i++)c(t,e,r[i]+\"calendar\",n.calendar)},CANONICAL_SUNDAY:{chinese:\"2000-01-02\",coptic:\"2000-01-03\",discworld:\"2000-01-03\",ethiopian:\"2000-01-05\",hebrew:\"5000-01-01\",islamic:\"1000-01-02\",julian:\"2000-01-03\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-05\",nepali:\"2000-01-05\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-04\",thai:\"2000-01-04\",ummalqura:\"1400-01-06\"},CANONICAL_TICK:{chinese:\"2000-01-01\",coptic:\"2000-01-01\",discworld:\"2000-01-01\",ethiopian:\"2000-01-01\",hebrew:\"5000-01-01\",islamic:\"1000-01-01\",julian:\"2000-01-01\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-01\",nepali:\"2000-01-01\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-01\",thai:\"2000-01-01\",ummalqura:\"1400-01-01\"},DFLTRANGE:{chinese:[\"2000-01-01\",\"2001-01-01\"],coptic:[\"1700-01-01\",\"1701-01-01\"],discworld:[\"1800-01-01\",\"1801-01-01\"],ethiopian:[\"2000-01-01\",\"2001-01-01\"],hebrew:[\"5700-01-01\",\"5701-01-01\"],islamic:[\"1400-01-01\",\"1401-01-01\"],julian:[\"2000-01-01\",\"2001-01-01\"],mayan:[\"5200-01-01\",\"5201-01-01\"],nanakshahi:[\"0500-01-01\",\"0501-01-01\"],nepali:[\"2000-01-01\",\"2001-01-01\"],persian:[\"1400-01-01\",\"1401-01-01\"],jalali:[\"1400-01-01\",\"1401-01-01\"],taiwan:[\"0100-01-01\",\"0101-01-01\"],thai:[\"2500-01-01\",\"2501-01-01\"],ummalqura:[\"1400-01-01\",\"1401-01-01\"]},getCal:p,worldCalFmt:function(t,e,r){for(var n,i,a,l,c,f=Math.floor((e+.05)/s)+o,d=p(r).fromJD(f),g=0;-1!==(g=t.indexOf(\"%\",g));)\"0\"===(n=t.charAt(g+1))||\"-\"===n||\"_\"===n?(a=3,i=t.charAt(g+2),\"_\"===n&&(n=\"-\")):(i=n,n=\"0\",a=2),(l=h[i])?(c=l===u?u:d.formatDate(l[n]),t=t.substr(0,g)+c+t.substr(g+a),g+=c.length):g+=a;return t}}},{\"../../constants/numerical\":695,\"../../lib\":719,\"./calendars\":590}],592:[function(t,e,r){\"use strict\";r.defaults=[\"#1f77b4\",\"#ff7f0e\",\"#2ca02c\",\"#d62728\",\"#9467bd\",\"#8c564b\",\"#e377c2\",\"#7f7f7f\",\"#bcbd22\",\"#17becf\"],r.defaultLine=\"#444\",r.lightLine=\"#eee\",r.background=\"#fff\",r.borderLine=\"#BEC8D9\",r.lightFraction=1e3/11},{}],593:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i=t(\"fast-isnumeric\"),a=e.exports={},o=t(\"./attributes\");a.defaults=o.defaults;var s=a.defaultLine=o.defaultLine;a.lightLine=o.lightLine;var l=a.background=o.background;function c(t){if(i(t)||\"string\"!=typeof t)return t;var e=t.trim();if(\"rgb\"!==e.substr(0,3))return t;var r=e.match(/^rgba?\\s*\\(([^()]*)\\)$/);if(!r)return t;var n=r[1].trim().split(/\\s*[\\s,]\\s*/),a=\"a\"===e.charAt(3)&&4===n.length;if(!a&&3!==n.length)return t;for(var o=0;o<n.length;o++){if(!n[o].length)return t;if(n[o]=Number(n[o]),!(n[o]>=0))return t;if(3===o)n[o]>1&&(n[o]=1);else if(n[o]>=1)return t}var s=Math.round(255*n[0])+\", \"+Math.round(255*n[1])+\", \"+Math.round(255*n[2]);return a?\"rgba(\"+s+\", \"+n[3]+\")\":\"rgb(\"+s+\")\"}a.tinyRGB=function(t){var e=t.toRgb();return\"rgb(\"+Math.round(e.r)+\", \"+Math.round(e.g)+\", \"+Math.round(e.b)+\")\"},a.rgb=function(t){return a.tinyRGB(n(t))},a.opacity=function(t){return t?n(t).getAlpha():0},a.addOpacity=function(t,e){var r=n(t).toRgb();return\"rgba(\"+Math.round(r.r)+\", \"+Math.round(r.g)+\", \"+Math.round(r.b)+\", \"+e+\")\"},a.combine=function(t,e){var r=n(t).toRgb();if(1===r.a)return n(t).toRgbString();var i=n(e||l).toRgb(),a=1===i.a?i:{r:255*(1-i.a)+i.r*i.a,g:255*(1-i.a)+i.g*i.a,b:255*(1-i.a)+i.b*i.a},o={r:a.r*(1-r.a)+r.r*r.a,g:a.g*(1-r.a)+r.g*r.a,b:a.b*(1-r.a)+r.b*r.a};return n(o).toRgbString()},a.contrast=function(t,e,r){var i=n(t);return 1!==i.getAlpha()&&(i=n(a.combine(t,l))),(i.isDark()?e?i.lighten(e):l:r?i.darken(r):s).toString()},a.stroke=function(t,e){var r=n(e);t.style({stroke:a.tinyRGB(r),\"stroke-opacity\":r.getAlpha()})},a.fill=function(t,e){var r=n(e);t.style({fill:a.tinyRGB(r),\"fill-opacity\":r.getAlpha()})},a.clean=function(t){if(t&&\"object\"==typeof t){var e,r,n,i,o=Object.keys(t);for(e=0;e<o.length;e++)if(i=t[n=o[e]],\"color\"===n.substr(n.length-5))if(Array.isArray(i))for(r=0;r<i.length;r++)i[r]=c(i[r]);else t[n]=c(i);else if(\"colorscale\"===n.substr(n.length-10)&&Array.isArray(i))for(r=0;r<i.length;r++)Array.isArray(i[r])&&(i[r][1]=c(i[r][1]));else if(Array.isArray(i)){var s=i[0];if(!Array.isArray(s)&&s&&\"object\"==typeof s)for(r=0;r<i.length;r++)a.clean(i[r])}else i&&\"object\"==typeof i&&a.clean(i)}}},{\"./attributes\":592,\"fast-isnumeric\":225,tinycolor2:537}],594:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/layout_attributes\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll;e.exports=o({thicknessmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"pixels\"},thickness:{valType:\"number\",min:0,dflt:30},lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",dflt:1.02,min:-2,max:3},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},xpad:{valType:\"number\",min:0,dflt:10},y:{valType:\"number\",dflt:.5,min:-2,max:3},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\"},ypad:{valType:\"number\",min:0,dflt:10},outlinecolor:n.linecolor,outlinewidth:n.linewidth,bordercolor:n.linecolor,borderwidth:{valType:\"number\",min:0,dflt:0},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\"},tickmode:n.tickmode,nticks:n.nticks,tick0:n.tick0,dtick:n.dtick,tickvals:n.tickvals,ticktext:n.ticktext,ticks:a({},n.ticks,{dflt:\"\"}),ticklen:n.ticklen,tickwidth:n.tickwidth,tickcolor:n.tickcolor,showticklabels:n.showticklabels,tickfont:i({}),tickangle:n.tickangle,tickformat:n.tickformat,tickformatstops:n.tickformatstops,tickprefix:n.tickprefix,showtickprefix:n.showtickprefix,ticksuffix:n.ticksuffix,showticksuffix:n.showticksuffix,separatethousands:n.separatethousands,exponentformat:n.exponentformat,showexponent:n.showexponent,title:{text:{valType:\"string\"},font:i({}),side:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}},_deprecated:{title:{valType:\"string\"},titlefont:i({}),titleside:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}}},\"colorbars\",\"from-root\")},{\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/font_attributes\":793}],595:[function(t,e,r){\"use strict\";e.exports={cn:{colorbar:\"colorbar\",cbbg:\"cbbg\",cbfill:\"cbfill\",cbfills:\"cbfills\",cbline:\"cbline\",cblines:\"cblines\",cbaxis:\"cbaxis\",cbtitleunshift:\"cbtitleunshift\",cbtitle:\"cbtitle\",cboutline:\"cboutline\",crisp:\"crisp\",jsPlaceholder:\"js-placeholder\"}}},{}],596:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/tick_value_defaults\"),o=t(\"../../plots/cartesian/tick_mark_defaults\"),s=t(\"../../plots/cartesian/tick_label_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r){var c=i.newContainer(e,\"colorbar\"),u=t.colorbar||{};function h(t,e){return n.coerce(u,c,l,t,e)}var f=h(\"thicknessmode\");h(\"thickness\",\"fraction\"===f?30/(r.width-r.margin.l-r.margin.r):30);var p=h(\"lenmode\");h(\"len\",\"fraction\"===p?1:r.height-r.margin.t-r.margin.b),h(\"x\"),h(\"xanchor\"),h(\"xpad\"),h(\"y\"),h(\"yanchor\"),h(\"ypad\"),n.noneOrAll(u,c,[\"x\",\"y\"]),h(\"outlinecolor\"),h(\"outlinewidth\"),h(\"bordercolor\"),h(\"borderwidth\"),h(\"bgcolor\"),a(u,c,h,\"linear\");var d={outerTicks:!1,font:r.font};s(u,c,h,\"linear\",d),o(u,c,h,\"linear\",d),h(\"title.text\",r._dfltTitle.colorbar),n.coerceFont(h,\"title.font\",r.font),h(\"title.side\")}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/tick_label_defaults\":786,\"../../plots/cartesian/tick_mark_defaults\":787,\"../../plots/cartesian/tick_value_defaults\":788,\"./attributes\":594}],597:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../dragelement\"),c=t(\"../../lib\"),u=t(\"../../lib/extend\").extendFlat,h=t(\"../../lib/setcursor\"),f=t(\"../drawing\"),p=t(\"../color\"),d=t(\"../titles\"),g=t(\"../../lib/svg_text_utils\"),v=t(\"../colorscale/helpers\").flipScale,m=t(\"../../plots/cartesian/axis_defaults\"),y=t(\"../../plots/cartesian/position_defaults\"),x=t(\"../../plots/cartesian/layout_attributes\"),b=t(\"../../constants/alignment\"),_=b.LINE_SPACING,w=b.FROM_TL,k=b.FROM_BR,T=t(\"./constants\").cn;e.exports={draw:function(t){var e=t._fullLayout._infolayer.selectAll(\"g.\"+T.colorbar).data(function(t){var e,r,n,i,a=t._fullLayout,o=t.calcdata,s=[];function l(t){return u(t,{_fillcolor:null,_line:{color:null,width:null,dash:null},_levels:{start:null,end:null,size:null},_filllevels:null,_fillgradient:null,_zrange:null})}function c(){\"function\"==typeof i.calc?i.calc(t,n,e):(e._fillgradient=r.reversescale?v(r.colorscale):r.colorscale,e._zrange=[r[i.min],r[i.max]])}for(var h=0;h<o.length;h++){var f=o[h],p=(n=f[0].trace)._module.colorbar;if(!0===n.visible&&p)for(var d=Array.isArray(p),g=d?p:[p],m=0;m<g.length;m++){var y=(i=g[m]).container;(r=y?n[y]:n)&&r.showscale&&((e=l(r.colorbar))._id=\"cb\"+n.uid+(d&&y?\"-\"+y:\"\"),e._traceIndex=n.index,e._propPrefix=(y?y+\".\":\"\")+\"colorbar.\",e._meta=n._meta,c(),s.push(e))}}for(var x in a._colorAxes)if((r=a[x]).showscale){var b=a._colorAxes[x];(e=l(r.colorbar))._id=\"cb\"+x,e._propPrefix=x+\".colorbar.\",e._meta=a._meta,i={min:\"cmin\",max:\"cmax\"},\"heatmap\"!==b[0]&&(n=b[1],i.calc=n._module.colorbar.calc),c(),s.push(e)}return s}(t),function(t){return t._id});e.enter().append(\"g\").attr(\"class\",function(t){return t._id}).classed(T.colorbar,!0),e.each(function(e){var r=n.select(this);c.ensureSingle(r,\"rect\",T.cbbg),c.ensureSingle(r,\"g\",T.cbfills),c.ensureSingle(r,\"g\",T.cblines),c.ensureSingle(r,\"g\",T.cbaxis,function(t){t.classed(T.crisp,!0)}),c.ensureSingle(r,\"g\",T.cbtitleunshift,function(t){t.append(\"g\").classed(T.cbtitle,!0)}),c.ensureSingle(r,\"rect\",T.cboutline);var v=function(t,e,r){var o=r._fullLayout,l=o._size,h=e._fillcolor,v=e._line,b=e.title,A=b.side,M=e._zrange||n.extent((\"function\"==typeof h?h:v.color).domain()),S=\"function\"==typeof v.color?v.color:function(){return v.color},E=\"function\"==typeof h?h:function(){return h},C=e._levels,L=function(t,e,r){var n,i,a=e._levels,o=[],s=[],l=a.end+a.size/100,c=a.size,u=1.001*r[0]-.001*r[1],h=1.001*r[1]-.001*r[0];for(i=0;i<1e5&&(n=a.start+i*c,!(c>0?n>=l:n<=l));i++)n>u&&n<h&&o.push(n);if(e._fillgradient)s=[0];else if(\"function\"==typeof e._fillcolor){var f=e._filllevels;if(f)for(l=f.end+f.size/100,c=f.size,i=0;i<1e5&&(n=f.start+i*c,!(c>0?n>=l:n<=l));i++)n>r[0]&&n<r[1]&&s.push(n);else(s=o.map(function(t){return t-a.size/2})).push(s[s.length-1]+a.size)}else e._fillcolor&&\"string\"==typeof e._fillcolor&&(s=[0]);return a.size<0&&(o.reverse(),s.reverse()),{line:o,fill:s}}(0,e,M),P=L.fill,O=L.line,z=Math.round(e.thickness*(\"fraction\"===e.thicknessmode?l.w:1)),I=z/l.w,D=Math.round(e.len*(\"fraction\"===e.lenmode?l.h:1)),R=D/l.h,F=e.xpad/l.w,B=(e.borderwidth+e.outlinewidth)/2,N=e.ypad/l.h,j=Math.round(e.x*l.w+e.xpad),U=e.x-I*({middle:.5,right:1}[e.xanchor]||0),V=e.y+R*(({top:-.5,bottom:.5}[e.yanchor]||0)-.5),q=Math.round(l.h*(1-V)),H=q-D;e._lenFrac=R,e._thickFrac=I,e._xLeftFrac=U,e._yBottomFrac=V;var G=function(t,e,r){var n=t._fullLayout,i={type:\"linear\",range:r,tickmode:e.tickmode,nticks:e.nticks,tick0:e.tick0,dtick:e.dtick,tickvals:e.tickvals,ticktext:e.ticktext,ticks:e.ticks,ticklen:e.ticklen,tickwidth:e.tickwidth,tickcolor:e.tickcolor,showticklabels:e.showticklabels,tickfont:e.tickfont,tickangle:e.tickangle,tickformat:e.tickformat,exponentformat:e.exponentformat,separatethousands:e.separatethousands,showexponent:e.showexponent,showtickprefix:e.showtickprefix,tickprefix:e.tickprefix,showticksuffix:e.showticksuffix,ticksuffix:e.ticksuffix,title:e.title,showline:!0,anchor:\"free\",side:\"right\",position:1},a={type:\"linear\",_id:\"y\"+e._id},o={letter:\"y\",font:n.font,noHover:!0,noTickson:!0,calendar:n.calendar};function s(t,e){return c.coerce(i,a,x,t,e)}return m(i,a,s,o,n),y(i,a,s,o),a}(r,e,M);if(G.position=e.x+F+I,-1!==[\"top\",\"bottom\"].indexOf(A)&&(G.title.side=A,G.titlex=e.x+F,G.titley=V+(\"top\"===b.side?R-N:N)),v.color&&\"auto\"===e.tickmode){G.tickmode=\"linear\",G.tick0=C.start;var Y=C.size,W=c.constrain((q-H)/50,4,15)+1,X=(M[1]-M[0])/((e.nticks||W)*Y);if(X>1){var Z=Math.pow(10,Math.floor(Math.log(X)/Math.LN10));Y*=Z*c.roundUp(X/Z,[2,5,10]),(Math.abs(C.start)/C.size+1e-6)%1<2e-6&&(G.tick0=0)}G.dtick=Y}G.domain=[V+N,V+R-N],G.setScale(),t.attr(\"transform\",\"translate(\"+Math.round(l.l)+\",\"+Math.round(l.t)+\")\");var J,K=t.select(\".\"+T.cbtitleunshift).attr(\"transform\",\"translate(-\"+Math.round(l.l)+\",-\"+Math.round(l.t)+\")\"),$=t.select(\".\"+T.cbaxis),Q=0;function tt(n,i){var a={propContainer:G,propName:e._propPrefix+\"title\",traceIndex:e._traceIndex,_meta:e._meta,placeholder:o._dfltTitle.colorbar,containerGroup:t.select(\".\"+T.cbtitle)},s=\"h\"===n.charAt(0)?n.substr(1):\"h\"+n;t.selectAll(\".\"+s+\",.\"+s+\"-math-group\").remove(),d.draw(r,n,u(a,i||{}))}return c.syncOrAsync([a.previousPromises,function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var t,r=l.l+(e.x+F)*l.w,n=G.title.font.size;t=\"top\"===A?(1-(V+R-N))*l.h+l.t+3+.75*n:(1-(V+N))*l.h+l.t-3-.25*n,tt(G._id+\"title\",{attributes:{x:r,y:t,\"text-anchor\":\"start\"}})}},function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var a=t.select(\".\"+T.cbtitle),o=a.select(\"text\"),u=[-e.outlinewidth/2,e.outlinewidth/2],h=a.select(\".h\"+G._id+\"title-math-group\").node(),p=15.6;if(o.node()&&(p=parseInt(o.node().style.fontSize,10)*_),h?(Q=f.bBox(h).height)>p&&(u[1]-=(Q-p)/2):o.node()&&!o.classed(T.jsPlaceholder)&&(Q=f.bBox(o.node()).height),Q){if(Q+=5,\"top\"===A)G.domain[1]-=Q/l.h,u[1]*=-1;else{G.domain[0]+=Q/l.h;var d=g.lineCount(o);u[1]+=(1-d)*p}a.attr(\"transform\",\"translate(\"+u+\")\"),G.setScale()}}t.selectAll(\".\"+T.cbfills+\",.\"+T.cblines).attr(\"transform\",\"translate(0,\"+Math.round(l.h*(1-G.domain[1]))+\")\"),$.attr(\"transform\",\"translate(0,\"+Math.round(-l.t)+\")\");var m=t.select(\".\"+T.cbfills).selectAll(\"rect.\"+T.cbfill).data(P);m.enter().append(\"rect\").classed(T.cbfill,!0).style(\"stroke\",\"none\"),m.exit().remove();var y=M.map(G.c2p).map(Math.round).sort(function(t,e){return t-e});m.each(function(t,a){var o=[0===a?M[0]:(P[a]+P[a-1])/2,a===P.length-1?M[1]:(P[a]+P[a+1])/2].map(G.c2p).map(Math.round);o[1]=c.constrain(o[1]+(o[1]>o[0])?1:-1,y[0],y[1]);var s=n.select(this).attr({x:j,width:Math.max(z,2),y:n.min(o),height:Math.max(n.max(o)-n.min(o),2)});if(e._fillgradient)f.gradient(s,r,e._id,\"vertical\",e._fillgradient,\"fill\");else{var l=E(t).replace(\"e-\",\"\");s.attr(\"fill\",i(l).toHexString())}});var x=t.select(\".\"+T.cblines).selectAll(\"path.\"+T.cbline).data(v.color&&v.width?O:[]);x.enter().append(\"path\").classed(T.cbline,!0),x.exit().remove(),x.each(function(t){n.select(this).attr(\"d\",\"M\"+j+\",\"+(Math.round(G.c2p(t))+v.width/2%1)+\"h\"+z).call(f.lineGroupStyle,v.width,S(t),v.dash)}),$.selectAll(\"g.\"+G._id+\"tick,path\").remove();var b=j+z+(e.outlinewidth||0)/2-(\"outside\"===e.ticks?1:0),w=s.calcTicks(G),k=s.makeTransFn(G),C=s.getTickSigns(G)[2];return s.drawTicks(r,G,{vals:\"inside\"===G.ticks?s.clipEnds(G,w):w,layer:$,path:s.makeTickPath(G,b,C),transFn:k}),s.drawLabels(r,G,{vals:w,layer:$,transFn:k,labelFns:s.makeLabelFns(G,b)})},function(){if(-1===[\"top\",\"bottom\"].indexOf(A)){var t=G.title.font.size,e=G._offset+G._length/2,i=l.l+(G.position||0)*l.w+(\"right\"===G.side?10+t*(G.showticklabels?1:.5):-10-t*(G.showticklabels?.5:0));tt(\"h\"+G._id+\"title\",{avoid:{selection:n.select(r).selectAll(\"g.\"+G._id+\"tick\"),side:A,offsetLeft:l.l,offsetTop:0,maxShift:o.width},attributes:{x:i,y:e,\"text-anchor\":\"middle\"},transform:{rotate:\"-90\",offset:0}})}},a.previousPromises,function(){var n=z+e.outlinewidth/2+f.bBox($.node()).width;if((J=K.select(\"text\")).node()&&!J.classed(T.jsPlaceholder)){var i,o=K.select(\".h\"+G._id+\"title-math-group\").node();i=o&&-1!==[\"top\",\"bottom\"].indexOf(A)?f.bBox(o).width:f.bBox(K.node()).right-j-l.l,n=Math.max(n,i)}var s=2*e.xpad+n+e.borderwidth+e.outlinewidth/2,c=q-H;t.select(\".\"+T.cbbg).attr({x:j-e.xpad-(e.borderwidth+e.outlinewidth)/2,y:H-B,width:Math.max(s,2),height:Math.max(c+2*B,2)}).call(p.fill,e.bgcolor).call(p.stroke,e.bordercolor).style(\"stroke-width\",e.borderwidth),t.selectAll(\".\"+T.cboutline).attr({x:j,y:H+e.ypad+(\"top\"===A?Q:0),width:Math.max(z,2),height:Math.max(c-2*e.ypad-Q,2)}).call(p.stroke,e.outlinecolor).style({fill:\"none\",\"stroke-width\":e.outlinewidth});var u=({center:.5,right:1}[e.xanchor]||0)*s;t.attr(\"transform\",\"translate(\"+(l.l-u)+\",\"+l.t+\")\");var h={},d=w[e.yanchor],g=k[e.yanchor];\"pixels\"===e.lenmode?(h.y=e.y,h.t=c*d,h.b=c*g):(h.t=h.b=0,h.yt=e.y+e.len*d,h.yb=e.y-e.len*g);var v=w[e.xanchor],m=k[e.xanchor];if(\"pixels\"===e.thicknessmode)h.x=e.x,h.l=s*v,h.r=s*m;else{var y=s-z;h.l=y*v,h.r=y*m,h.xl=e.x-e.thickness*v,h.xr=e.x+e.thickness*m}a.autoMargin(r,e._id,h)}],r)}(r,e,t);v&&v.then&&(t._promises||[]).push(v),t._context.edits.colorbarPosition&&function(t,e,r){var n,i,a,s=r._fullLayout._size;l.init({element:t.node(),gd:r,prepFn:function(){n=t.attr(\"transform\"),h(t)},moveFn:function(r,o){t.attr(\"transform\",n+\" translate(\"+r+\",\"+o+\")\"),i=l.align(e._xLeftFrac+r/s.w,e._thickFrac,0,1,e.xanchor),a=l.align(e._yBottomFrac-o/s.h,e._lenFrac,0,1,e.yanchor);var c=l.getCursor(i,a,e.xanchor,e.yanchor);h(t,c)},doneFn:function(){if(h(t),void 0!==i&&void 0!==a){var n={};n[e._propPrefix+\"x\"]=i,n[e._propPrefix+\"y\"]=a,void 0!==e._traceIndex?o.call(\"_guiRestyle\",r,n,e._traceIndex):o.call(\"_guiRelayout\",r,n)}}})}(r,e,t)}),e.exit().each(function(e){a.autoMargin(t,e._id)}).remove(),e.order()}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/extend\":710,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_defaults\":769,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/cartesian/position_defaults\":782,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../colorscale/helpers\":604,\"../dragelement\":611,\"../drawing\":614,\"../titles\":681,\"./constants\":595,d3:163,tinycolor2:537}],598:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t){return n.isPlainObject(t.colorbar)}},{\"../../lib\":719}],599:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"colorbar\",attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),draw:t(\"./draw\").draw,hasColorbar:t(\"./has_colorbar\")}},{\"./attributes\":594,\"./defaults\":596,\"./draw\":597,\"./has_colorbar\":598}],600:[function(t,e,r){\"use strict\";var n=t(\"../colorbar/attributes\"),i=t(\"../../lib/regex\").counter,a=t(\"./scales.js\").scales;Object.keys(a);function o(t){return\"`\"+t+\"`\"}e.exports=function(t,e){t=t||\"\";var r,s=(e=e||{}).cLetter||\"c\",l=(\"onlyIfNumerical\"in e?e.onlyIfNumerical:Boolean(t),\"noScale\"in e?e.noScale:\"marker.line\"===t),c=\"showScaleDflt\"in e?e.showScaleDflt:\"z\"===s,u=\"string\"==typeof e.colorscaleDflt?a[e.colorscaleDflt]:null,h=e.editTypeOverride||\"\",f=t?t+\".\":\"\";\"colorAttr\"in e?(r=e.colorAttr,e.colorAttr):o(f+(r={z:\"z\",c:\"color\"}[s]));var p=s+\"auto\",d=s+\"min\",g=s+\"max\",v=s+\"mid\",m=(o(f+p),o(f+d),o(f+g),{});m[d]=m[g]=void 0;var y={};y[p]=!1;var x={};return\"color\"===r&&(x.color={valType:\"color\",arrayOk:!0,editType:h||\"style\"},e.anim&&(x.color.anim=!0)),x[p]={valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:m},x[d]={valType:\"number\",dflt:null,editType:h||\"plot\",impliedEdits:y},x[g]={valType:\"number\",dflt:null,editType:h||\"plot\",impliedEdits:y},x[v]={valType:\"number\",dflt:null,editType:\"calc\",impliedEdits:m},x.colorscale={valType:\"colorscale\",editType:\"calc\",dflt:u,impliedEdits:{autocolorscale:!1}},x.autocolorscale={valType:\"boolean\",dflt:!1!==e.autoColorDflt,editType:\"calc\",impliedEdits:{colorscale:void 0}},x.reversescale={valType:\"boolean\",dflt:!1,editType:\"plot\"},l||(x.showscale={valType:\"boolean\",dflt:c,editType:\"calc\"},x.colorbar=n),e.noColorAxis||(x.coloraxis={valType:\"subplotid\",regex:i(\"coloraxis\"),dflt:null,editType:\"calc\"}),x}},{\"../../lib/regex\":735,\"../colorbar/attributes\":594,\"./scales.js\":608}],601:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"./helpers\").extractOpts;e.exports=function(t,e,r){var o,s=t._fullLayout,l=r.vals,c=r.containerStr,u=c?i.nestedProperty(e,c).get():e,h=a(u),f=!1!==h.auto,p=h.min,d=h.max,g=h.mid,v=function(){return i.aggNums(Math.min,null,l)},m=function(){return i.aggNums(Math.max,null,l)};(void 0===p?p=v():f&&(p=u._colorAx&&n(p)?Math.min(p,v()):v()),void 0===d?d=m():f&&(d=u._colorAx&&n(d)?Math.max(d,m()):m()),f&&void 0!==g&&(d-g>g-p?p=g-(d-g):d-g<g-p&&(d=g+(g-p))),p===d&&(p-=.5,d+=.5),h._sync(\"min\",p),h._sync(\"max\",d),h.autocolorscale)&&(o=p*d<0?s.colorscale.diverging:p>=0?s.colorscale.sequential:s.colorscale.sequentialminus,h._sync(\"colorscale\",o))}},{\"../../lib\":719,\"./helpers\":604,\"fast-isnumeric\":225}],602:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./helpers\").hasColorscale,a=t(\"./helpers\").extractOpts;e.exports=function(t,e){function r(t,e){var r=t[\"_\"+e];void 0!==r&&(t[e]=r)}function o(t,i){var o=i.container?n.nestedProperty(t,i.container).get():t;if(o)if(o.coloraxis)o._colorAx=e[o.coloraxis];else{var s=a(o),l=s.auto;(l||void 0===s.min)&&r(o,i.min),(l||void 0===s.max)&&r(o,i.max),s.autocolorscale&&r(o,\"colorscale\")}}for(var s=0;s<t.length;s++){var l=t[s],c=l._module.colorbar;if(c)if(Array.isArray(c))for(var u=0;u<c.length;u++)o(l,c[u]);else o(l,c);i(l,\"marker.line\")&&o(l,{container:\"marker.line\",min:\"cmin\",max:\"cmax\"})}for(var h in e._colorAxes)o(e[h],{min:\"cmin\",max:\"cmax\"})}},{\"../../lib\":719,\"./helpers\":604}],603:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../colorbar/has_colorbar\"),o=t(\"../colorbar/defaults\"),s=t(\"./scales\").isValid,l=t(\"../../registry\").traceIs;function c(t,e){var r=e.slice(0,e.length-1);return e?i.nestedProperty(t,r).get()||{}:t}e.exports=function t(e,r,u,h,f){var p=f.prefix,d=f.cLetter,g=\"_module\"in r,v=c(e,p),m=c(r,p),y=c(r._template||{},p)||{},x=function(){return delete e.coloraxis,delete r.coloraxis,t(e,r,u,h,f)};if(g){var b=u._colorAxes||{},_=h(p+\"coloraxis\");if(_){var w=l(r,\"contour\")&&i.nestedProperty(r,\"contours.coloring\").get()||\"heatmap\",k=b[_];return void(k?(k[2].push(x),k[0]!==w&&(k[0]=!1,i.warn([\"Ignoring coloraxis:\",_,\"setting\",\"as it is linked to incompatible colorscales.\"].join(\" \")))):b[_]=[w,r,[x]])}}var T=v[d+\"min\"],A=v[d+\"max\"],M=n(T)&&n(A)&&T<A;h(p+d+\"auto\",!M)?h(p+d+\"mid\"):(h(p+d+\"min\"),h(p+d+\"max\"));var S,E,C=v.colorscale,L=y.colorscale;(void 0!==C&&(S=!s(C)),void 0!==L&&(S=!s(L)),h(p+\"autocolorscale\",S),h(p+\"colorscale\"),h(p+\"reversescale\"),\"marker.line.\"!==p)&&(p&&g&&(E=a(v)),h(p+\"showscale\",E)&&o(v,m,u))}},{\"../../lib\":719,\"../../registry\":847,\"../colorbar/defaults\":596,\"../colorbar/has_colorbar\":598,\"./scales\":608,\"fast-isnumeric\":225}],604:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"fast-isnumeric\"),o=t(\"../../lib\"),s=t(\"../color\"),l=t(\"./scales\").isValid;var c=[\"showscale\",\"autocolorscale\",\"colorscale\",\"reversescale\",\"colorbar\"],u=[\"min\",\"max\",\"mid\",\"auto\"];function h(t){var e,r,n,i=t._colorAx,a=i||t,o={};for(r=0;r<c.length;r++)o[n=c[r]]=a[n];if(i)for(e=\"c\",r=0;r<u.length;r++)o[n=u[r]]=a[\"c\"+n];else{var s;for(r=0;r<u.length;r++)(s=\"c\"+(n=u[r]))in a?o[n]=a[s]:(s=\"z\"+n)in a&&(o[n]=a[s]);e=s.charAt(0)}return o._sync=function(t,r){var n=-1!==u.indexOf(t)?e+t:t;a[n]=a[\"_\"+n]=r},o}function f(t){for(var e=h(t),r=e.min,n=e.max,i=e.reversescale?p(e.colorscale):e.colorscale,a=i.length,o=new Array(a),s=new Array(a),l=0;l<a;l++){var c=i[l];o[l]=r+c[0]*(n-r),s[l]=c[1]}return{domain:o,range:s}}function p(t){for(var e=t.length,r=new Array(e),n=e-1,i=0;n>=0;n--,i++){var a=t[n];r[i]=[1-a[0],a[1]]}return r}function d(t,e){e=e||{};for(var r=t.domain,o=t.range,l=o.length,c=new Array(l),u=0;u<l;u++){var h=i(o[u]).toRgb();c[u]=[h.r,h.g,h.b,h.a]}var f,p=n.scale.linear().domain(r).range(c).clamp(!0),d=e.noNumericCheck,v=e.returnArray;return(f=d&&v?p:d?function(t){return g(p(t))}:v?function(t){return a(t)?p(t):i(t).isValid()?t:s.defaultLine}:function(t){return a(t)?g(p(t)):i(t).isValid()?t:s.defaultLine}).domain=p.domain,f.range=function(){return o},f}function g(t){var e={r:t[0],g:t[1],b:t[2],a:t[3]};return i(e).toRgbString()}e.exports={hasColorscale:function(t,e){var r=e?o.nestedProperty(t,e).get()||{}:t,n=r.color,i=!1;if(o.isArrayOrTypedArray(n))for(var s=0;s<n.length;s++)if(a(n[s])){i=!0;break}return o.isPlainObject(r)&&(i||!0===r.showscale||a(r.cmin)&&a(r.cmax)||l(r.colorscale)||o.isPlainObject(r.colorbar))},extractOpts:h,extractScale:f,flipScale:p,makeColorScaleFunc:d,makeColorScaleFuncFromTrace:function(t,e){return d(f(t),e)}}},{\"../../lib\":719,\"../color\":593,\"./scales\":608,d3:163,\"fast-isnumeric\":225,tinycolor2:537}],605:[function(t,e,r){\"use strict\";var n=t(\"./scales\"),i=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"colorscale\",attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),handleDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\"),scales:n.scales,defaultScale:n.defaultScale,getScale:n.get,isValidScale:n.isValid,hasColorscale:i.hasColorscale,extractOpts:i.extractOpts,extractScale:i.extractScale,flipScale:i.flipScale,makeColorScaleFunc:i.makeColorScaleFunc,makeColorScaleFuncFromTrace:i.makeColorScaleFuncFromTrace}},{\"./attributes\":600,\"./calc\":601,\"./cross_trace_defaults\":602,\"./defaults\":603,\"./helpers\":604,\"./layout_attributes\":606,\"./layout_defaults\":607,\"./scales\":608}],606:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"./attributes\"),a=t(\"./scales\").scales;e.exports={editType:\"calc\",colorscale:{editType:\"calc\",sequential:{valType:\"colorscale\",dflt:a.Reds,editType:\"calc\"},sequentialminus:{valType:\"colorscale\",dflt:a.Blues,editType:\"calc\"},diverging:{valType:\"colorscale\",dflt:a.RdBu,editType:\"calc\"}},coloraxis:n({_isSubplotObj:!0,editType:\"calc\"},i(\"\",{colorAttr:\"corresponding trace color array(s)\",noColorAxis:!0,showScaleDflt:!0}))}},{\"../../lib/extend\":710,\"./attributes\":600,\"./scales\":608}],607:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"./layout_attributes\"),o=t(\"./defaults\");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r(\"colorscale.sequential\"),r(\"colorscale.sequentialminus\"),r(\"colorscale.diverging\");var s,l,c=e._colorAxes;function u(t,e){return n.coerce(s,l,a.coloraxis,t,e)}for(var h in c){var f=c[h];if(f[0])s=t[h]||{},(l=i.newContainer(e,h,\"coloraxis\"))._name=h,o(s,l,e,u,{prefix:\"\",cLetter:\"c\"});else{for(var p=0;p<f[2].length;p++)f[2][p]();delete e._colorAxes[h]}}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"./defaults\":603,\"./layout_attributes\":606}],608:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i={Greys:[[0,\"rgb(0,0,0)\"],[1,\"rgb(255,255,255)\"]],YlGnBu:[[0,\"rgb(8,29,88)\"],[.125,\"rgb(37,52,148)\"],[.25,\"rgb(34,94,168)\"],[.375,\"rgb(29,145,192)\"],[.5,\"rgb(65,182,196)\"],[.625,\"rgb(127,205,187)\"],[.75,\"rgb(199,233,180)\"],[.875,\"rgb(237,248,217)\"],[1,\"rgb(255,255,217)\"]],Greens:[[0,\"rgb(0,68,27)\"],[.125,\"rgb(0,109,44)\"],[.25,\"rgb(35,139,69)\"],[.375,\"rgb(65,171,93)\"],[.5,\"rgb(116,196,118)\"],[.625,\"rgb(161,217,155)\"],[.75,\"rgb(199,233,192)\"],[.875,\"rgb(229,245,224)\"],[1,\"rgb(247,252,245)\"]],YlOrRd:[[0,\"rgb(128,0,38)\"],[.125,\"rgb(189,0,38)\"],[.25,\"rgb(227,26,28)\"],[.375,\"rgb(252,78,42)\"],[.5,\"rgb(253,141,60)\"],[.625,\"rgb(254,178,76)\"],[.75,\"rgb(254,217,118)\"],[.875,\"rgb(255,237,160)\"],[1,\"rgb(255,255,204)\"]],Bluered:[[0,\"rgb(0,0,255)\"],[1,\"rgb(255,0,0)\"]],RdBu:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(106,137,247)\"],[.5,\"rgb(190,190,190)\"],[.6,\"rgb(220,170,132)\"],[.7,\"rgb(230,145,90)\"],[1,\"rgb(178,10,28)\"]],Reds:[[0,\"rgb(220,220,220)\"],[.2,\"rgb(245,195,157)\"],[.4,\"rgb(245,160,105)\"],[1,\"rgb(178,10,28)\"]],Blues:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(40,60,190)\"],[.5,\"rgb(70,100,245)\"],[.6,\"rgb(90,120,245)\"],[.7,\"rgb(106,137,247)\"],[1,\"rgb(220,220,220)\"]],Picnic:[[0,\"rgb(0,0,255)\"],[.1,\"rgb(51,153,255)\"],[.2,\"rgb(102,204,255)\"],[.3,\"rgb(153,204,255)\"],[.4,\"rgb(204,204,255)\"],[.5,\"rgb(255,255,255)\"],[.6,\"rgb(255,204,255)\"],[.7,\"rgb(255,153,255)\"],[.8,\"rgb(255,102,204)\"],[.9,\"rgb(255,102,102)\"],[1,\"rgb(255,0,0)\"]],Rainbow:[[0,\"rgb(150,0,90)\"],[.125,\"rgb(0,0,200)\"],[.25,\"rgb(0,25,255)\"],[.375,\"rgb(0,152,255)\"],[.5,\"rgb(44,255,150)\"],[.625,\"rgb(151,255,0)\"],[.75,\"rgb(255,234,0)\"],[.875,\"rgb(255,111,0)\"],[1,\"rgb(255,0,0)\"]],Portland:[[0,\"rgb(12,51,131)\"],[.25,\"rgb(10,136,186)\"],[.5,\"rgb(242,211,56)\"],[.75,\"rgb(242,143,56)\"],[1,\"rgb(217,30,30)\"]],Jet:[[0,\"rgb(0,0,131)\"],[.125,\"rgb(0,60,170)\"],[.375,\"rgb(5,255,255)\"],[.625,\"rgb(255,255,0)\"],[.875,\"rgb(250,0,0)\"],[1,\"rgb(128,0,0)\"]],Hot:[[0,\"rgb(0,0,0)\"],[.3,\"rgb(230,0,0)\"],[.6,\"rgb(255,210,0)\"],[1,\"rgb(255,255,255)\"]],Blackbody:[[0,\"rgb(0,0,0)\"],[.2,\"rgb(230,0,0)\"],[.4,\"rgb(230,210,0)\"],[.7,\"rgb(255,255,255)\"],[1,\"rgb(160,200,255)\"]],Earth:[[0,\"rgb(0,0,130)\"],[.1,\"rgb(0,180,180)\"],[.2,\"rgb(40,210,40)\"],[.4,\"rgb(230,230,50)\"],[.6,\"rgb(120,70,20)\"],[1,\"rgb(255,255,255)\"]],Electric:[[0,\"rgb(0,0,0)\"],[.15,\"rgb(30,0,100)\"],[.4,\"rgb(120,0,100)\"],[.6,\"rgb(160,90,0)\"],[.8,\"rgb(230,200,0)\"],[1,\"rgb(255,250,220)\"]],Viridis:[[0,\"#440154\"],[.06274509803921569,\"#48186a\"],[.12549019607843137,\"#472d7b\"],[.18823529411764706,\"#424086\"],[.25098039215686274,\"#3b528b\"],[.3137254901960784,\"#33638d\"],[.3764705882352941,\"#2c728e\"],[.4392156862745098,\"#26828e\"],[.5019607843137255,\"#21918c\"],[.5647058823529412,\"#1fa088\"],[.6274509803921569,\"#28ae80\"],[.6901960784313725,\"#3fbc73\"],[.7529411764705882,\"#5ec962\"],[.8156862745098039,\"#84d44b\"],[.8784313725490196,\"#addc30\"],[.9411764705882353,\"#d8e219\"],[1,\"#fde725\"]],Cividis:[[0,\"rgb(0,32,76)\"],[.058824,\"rgb(0,42,102)\"],[.117647,\"rgb(0,52,110)\"],[.176471,\"rgb(39,63,108)\"],[.235294,\"rgb(60,74,107)\"],[.294118,\"rgb(76,85,107)\"],[.352941,\"rgb(91,95,109)\"],[.411765,\"rgb(104,106,112)\"],[.470588,\"rgb(117,117,117)\"],[.529412,\"rgb(131,129,120)\"],[.588235,\"rgb(146,140,120)\"],[.647059,\"rgb(161,152,118)\"],[.705882,\"rgb(176,165,114)\"],[.764706,\"rgb(192,177,109)\"],[.823529,\"rgb(209,191,102)\"],[.882353,\"rgb(225,204,92)\"],[.941176,\"rgb(243,219,79)\"],[1,\"rgb(255,233,69)\"]]},a=i.RdBu;function o(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var i=t[r];if(2!==i.length||+i[0]<e||!n(i[1]).isValid())return!1;e=+i[0]}return!0}e.exports={scales:i,defaultScale:a,get:function(t,e){if(e||(e=a),!t)return e;function r(){try{t=i[t]||JSON.parse(t)}catch(r){t=e}}return\"string\"==typeof t&&(r(),\"string\"==typeof t&&r()),o(t)?t:e},isValid:function(t){return void 0!==i[t]||o(t)}}},{tinycolor2:537}],609:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=(t-r)/(n-r),o=a+e/(n-r),s=(a+o)/2;return\"left\"===i||\"bottom\"===i?a:\"center\"===i||\"middle\"===i?s:\"right\"===i||\"top\"===i?o:a<2/3-s?a:o>4/3-s?o:s}},{}],610:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[\"sw-resize\",\"s-resize\",\"se-resize\"],[\"w-resize\",\"move\",\"e-resize\"],[\"nw-resize\",\"n-resize\",\"ne-resize\"]];e.exports=function(t,e,r,a){return t=\"left\"===r?0:\"center\"===r?1:\"right\"===r?2:n.constrain(Math.floor(3*t),0,2),e=\"bottom\"===a?0:\"middle\"===a?1:\"top\"===a?2:n.constrain(Math.floor(3*e),0,2),i[e][t]}},{\"../../lib\":719}],611:[function(t,e,r){\"use strict\";var n=t(\"mouse-event-offset\"),i=t(\"has-hover\"),a=t(\"has-passive-events\"),o=t(\"../../lib\").removeElement,s=t(\"../../plots/cartesian/constants\"),l=e.exports={};l.align=t(\"./align\"),l.getCursor=t(\"./cursor\");var c=t(\"./unhover\");function u(){var t=document.createElement(\"div\");t.className=\"dragcover\";var e=t.style;return e.position=\"fixed\",e.left=0,e.right=0,e.top=0,e.bottom=0,e.zIndex=999999999,e.background=\"none\",document.body.appendChild(t),t}function h(t){return n(t.changedTouches?t.changedTouches[0]:t,document.body)}l.unhover=c.wrapped,l.unhoverRaw=c.raw,l.init=function(t){var e,r,n,c,f,p,d,g,v=t.gd,m=1,y=v._context.doubleClickDelay,x=t.element;v._mouseDownTime||(v._mouseDownTime=0),x.style.pointerEvents=\"all\",x.onmousedown=_,a?(x._ontouchstart&&x.removeEventListener(\"touchstart\",x._ontouchstart),x._ontouchstart=_,x.addEventListener(\"touchstart\",_,{passive:!1})):x.ontouchstart=_;var b=t.clampFn||function(t,e,r){return Math.abs(t)<r&&(t=0),Math.abs(e)<r&&(e=0),[t,e]};function _(a){v._dragged=!1,v._dragging=!0;var o=h(a);e=o[0],r=o[1],d=a.target,p=a,g=2===a.buttons||a.ctrlKey,\"undefined\"==typeof a.clientX&&\"undefined\"==typeof a.clientY&&(a.clientX=e,a.clientY=r),(n=(new Date).getTime())-v._mouseDownTime<y?m+=1:(m=1,v._mouseDownTime=n),t.prepFn&&t.prepFn(a,e,r),i&&!g?(f=u()).style.cursor=window.getComputedStyle(x).cursor:i||(f=document,c=window.getComputedStyle(document.documentElement).cursor,document.documentElement.style.cursor=window.getComputedStyle(x).cursor),document.addEventListener(\"mouseup\",k),document.addEventListener(\"touchend\",k),!1!==t.dragmode&&(a.preventDefault(),document.addEventListener(\"mousemove\",w),document.addEventListener(\"touchmove\",w))}function w(n){n.preventDefault();var i=h(n),a=t.minDrag||s.MINDRAG,o=b(i[0]-e,i[1]-r,a),c=o[0],u=o[1];(c||u)&&(v._dragged=!0,l.unhover(v)),v._dragged&&t.moveFn&&!g&&(v._dragdata={element:x,dx:c,dy:u},t.moveFn(c,u))}function k(e){if(delete v._dragdata,!1!==t.dragmode&&(e.preventDefault(),document.removeEventListener(\"mousemove\",w),document.removeEventListener(\"touchmove\",w)),document.removeEventListener(\"mouseup\",k),document.removeEventListener(\"touchend\",k),i?o(f):c&&(f.documentElement.style.cursor=c,c=null),v._dragging){if(v._dragging=!1,(new Date).getTime()-v._mouseDownTime>y&&(m=Math.max(m-1,1)),v._dragged)t.doneFn&&t.doneFn();else if(t.clickFn&&t.clickFn(m,p),!g){var r;try{r=new MouseEvent(\"click\",e)}catch(t){var n=h(e);(r=document.createEvent(\"MouseEvents\")).initMouseEvent(\"click\",e.bubbles,e.cancelable,e.view,e.detail,e.screenX,e.screenY,n[0],n[1],e.ctrlKey,e.altKey,e.shiftKey,e.metaKey,e.button,e.relatedTarget)}d.dispatchEvent(r)}v._dragging=!1,v._dragged=!1}else v._dragged=!1}},l.coverSlip=u},{\"../../lib\":719,\"../../plots/cartesian/constants\":773,\"./align\":609,\"./cursor\":610,\"./unhover\":612,\"has-hover\":410,\"has-passive-events\":411,\"mouse-event-offset\":436}],612:[function(t,e,r){\"use strict\";var n=t(\"../../lib/events\"),i=t(\"../../lib/throttle\"),a=t(\"../../lib/dom\").getGraphDiv,o=t(\"../fx/constants\"),s=e.exports={};s.wrapped=function(t,e,r){(t=a(t))._fullLayout&&i.clear(t._fullLayout._uid+o.HOVERID),s.raw(t,e,r)},s.raw=function(t,e){var r=t._fullLayout,i=t._hoverdata;e||(e={}),e.target&&!1===n.triggerHandler(t,\"plotly_beforehover\",e)||(r._hoverlayer.selectAll(\"g\").remove(),r._hoverlayer.selectAll(\"line\").remove(),r._hoverlayer.selectAll(\"circle\").remove(),t._hoverdata=void 0,e.target&&i&&t.emit(\"plotly_unhover\",{event:e,points:i}))}},{\"../../lib/dom\":708,\"../../lib/events\":709,\"../../lib/throttle\":744,\"../fx/constants\":626}],613:[function(t,e,r){\"use strict\";r.dash={valType:\"string\",values:[\"solid\",\"dot\",\"dash\",\"longdash\",\"dashdot\",\"longdashdot\"],dflt:\"solid\",editType:\"style\"}},{}],614:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../registry\"),s=t(\"../color\"),l=t(\"../colorscale\"),c=t(\"../../lib\"),u=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/xmlns_namespaces\"),f=t(\"../../constants/alignment\").LINE_SPACING,p=t(\"../../constants/interactions\").DESELECTDIM,d=t(\"../../traces/scatter/subtypes\"),g=t(\"../../traces/scatter/make_bubble_size_func\"),v=e.exports={};v.font=function(t,e,r,n){c.isPlainObject(e)&&(n=e.color,r=e.size,e=e.family),e&&t.style(\"font-family\",e),r+1&&t.style(\"font-size\",r+\"px\"),n&&t.call(s.fill,n)},v.setPosition=function(t,e,r){t.attr(\"x\",e).attr(\"y\",r)},v.setSize=function(t,e,r){t.attr(\"width\",e).attr(\"height\",r)},v.setRect=function(t,e,r,n,i){t.call(v.setPosition,e,r).call(v.setSize,n,i)},v.translatePoint=function(t,e,r,n){var a=r.c2p(t.x),o=n.c2p(t.y);return!!(i(a)&&i(o)&&e.node())&&(\"text\"===e.node().nodeName?e.attr(\"x\",a).attr(\"y\",o):e.attr(\"transform\",\"translate(\"+a+\",\"+o+\")\"),!0)},v.translatePoints=function(t,e,r){t.each(function(t){var i=n.select(this);v.translatePoint(t,i,e,r)})},v.hideOutsideRangePoint=function(t,e,r,n,i,a){e.attr(\"display\",r.isPtWithinRange(t,i)&&n.isPtWithinRange(t,a)?null:\"none\")},v.hideOutsideRangePoints=function(t,e){if(e._hasClipOnAxisFalse){var r=e.xaxis,i=e.yaxis;t.each(function(e){var a=e[0].trace,s=a.xcalendar,l=a.ycalendar,c=o.traceIs(a,\"bar-like\")?\".bartext\":\".point,.textpoint\";t.selectAll(c).each(function(t){v.hideOutsideRangePoint(t,n.select(this),r,i,s,l)})})}},v.crispRound=function(t,e,r){return e&&i(e)?t._context.staticPlot?e:e<1?1:Math.round(e):r||0},v.singleLineStyle=function(t,e,r,n,i){e.style(\"fill\",\"none\");var a=(((t||[])[0]||{}).trace||{}).line||{},o=r||a.width||0,l=i||a.dash||\"\";s.stroke(e,n||a.color),v.dashLine(e,l,o)},v.lineGroupStyle=function(t,e,r,i){t.style(\"fill\",\"none\").each(function(t){var a=(((t||[])[0]||{}).trace||{}).line||{},o=e||a.width||0,l=i||a.dash||\"\";n.select(this).call(s.stroke,r||a.color).call(v.dashLine,l,o)})},v.dashLine=function(t,e,r){r=+r||0,e=v.dashStyle(e,r),t.style({\"stroke-dasharray\":e,\"stroke-width\":r+\"px\"})},v.dashStyle=function(t,e){e=+e||1;var r=Math.max(e,3);return\"solid\"===t?t=\"\":\"dot\"===t?t=r+\"px,\"+r+\"px\":\"dash\"===t?t=3*r+\"px,\"+3*r+\"px\":\"longdash\"===t?t=5*r+\"px,\"+5*r+\"px\":\"dashdot\"===t?t=3*r+\"px,\"+r+\"px,\"+r+\"px,\"+r+\"px\":\"longdashdot\"===t&&(t=5*r+\"px,\"+2*r+\"px,\"+r+\"px,\"+2*r+\"px\"),t},v.singleFillStyle=function(t){var e=(((n.select(t.node()).data()[0]||[])[0]||{}).trace||{}).fillcolor;e&&t.call(s.fill,e)},v.fillGroupStyle=function(t){t.style(\"stroke-width\",0).each(function(t){var e=n.select(this);t[0].trace&&e.call(s.fill,t[0].trace.fillcolor)})};var m=t(\"./symbol_defs\");v.symbolNames=[],v.symbolFuncs=[],v.symbolNeedLines={},v.symbolNoDot={},v.symbolNoFill={},v.symbolList=[],Object.keys(m).forEach(function(t){var e=m[t];v.symbolList=v.symbolList.concat([e.n,t,e.n+100,t+\"-open\"]),v.symbolNames[e.n]=t,v.symbolFuncs[e.n]=e.f,e.needLine&&(v.symbolNeedLines[e.n]=!0),e.noDot?v.symbolNoDot[e.n]=!0:v.symbolList=v.symbolList.concat([e.n+200,t+\"-dot\",e.n+300,t+\"-open-dot\"]),e.noFill&&(v.symbolNoFill[e.n]=!0)});var y=v.symbolNames.length,x=\"M0,0.5L0.5,0L0,-0.5L-0.5,0Z\";function b(t,e){var r=t%100;return v.symbolFuncs[r](e)+(t>=200?x:\"\")}v.symbolNumber=function(t){if(\"string\"==typeof t){var e=0;t.indexOf(\"-open\")>0&&(e=100,t=t.replace(\"-open\",\"\")),t.indexOf(\"-dot\")>0&&(e+=200,t=t.replace(\"-dot\",\"\")),(t=v.symbolNames.indexOf(t))>=0&&(t+=e)}return t%100>=y||t>=400?0:Math.floor(Math.max(t,0))};var _={x1:1,x2:0,y1:0,y2:0},w={x1:0,x2:0,y1:1,y2:0},k=n.format(\"~.1f\"),T={radial:{node:\"radialGradient\"},radialreversed:{node:\"radialGradient\",reversed:!0},horizontal:{node:\"linearGradient\",attrs:_},horizontalreversed:{node:\"linearGradient\",attrs:_,reversed:!0},vertical:{node:\"linearGradient\",attrs:w},verticalreversed:{node:\"linearGradient\",attrs:w,reversed:!0}};v.gradient=function(t,e,r,i,o,l){for(var u=o.length,h=T[i],f=new Array(u),p=0;p<u;p++)h.reversed?f[u-1-p]=[k(100*(1-o[p][0])),o[p][1]]:f[p]=[k(100*o[p][0]),o[p][1]];var d=\"g\"+e._fullLayout._uid+\"-\"+r,g=e._fullLayout._defs.select(\".gradients\").selectAll(\"#\"+d).data([i+f.join(\";\")],c.identity);g.exit().remove(),g.enter().append(h.node).each(function(){var t=n.select(this);h.attrs&&t.attr(h.attrs),t.attr(\"id\",d);var e=t.selectAll(\"stop\").data(f);e.exit().remove(),e.enter().append(\"stop\"),e.each(function(t){var e=a(t[1]);n.select(this).attr({offset:t[0]+\"%\",\"stop-color\":s.tinyRGB(e),\"stop-opacity\":e.getAlpha()})})}),t.style(l,I(d,e)).style(l+\"-opacity\",null)},v.initGradients=function(t){c.ensureSingle(t._fullLayout._defs,\"g\",\"gradients\").selectAll(\"linearGradient,radialGradient\").remove()},v.pointStyle=function(t,e,r){if(t.size()){var i=v.makePointStyleFns(e);t.each(function(t){v.singlePointStyle(t,n.select(this),e,i,r)})}},v.singlePointStyle=function(t,e,r,n,i){var a=r.marker,o=a.line;if(e.style(\"opacity\",n.selectedOpacityFn?n.selectedOpacityFn(t):void 0===t.mo?a.opacity:t.mo),n.ms2mrc){var l;l=\"various\"===t.ms||\"various\"===a.size?3:n.ms2mrc(t.ms),t.mrc=l,n.selectedSizeFn&&(l=t.mrc=n.selectedSizeFn(t));var u=v.symbolNumber(t.mx||a.symbol)||0;t.om=u%200>=100,e.attr(\"d\",b(u,l))}var h,f,p,d=!1;if(t.so)p=o.outlierwidth,f=o.outliercolor,h=a.outliercolor;else{var g=(o||{}).width;p=(t.mlw+1||g+1||(t.trace?(t.trace.marker.line||{}).width:0)+1)-1||0,f=\"mlc\"in t?t.mlcc=n.lineScale(t.mlc):c.isArrayOrTypedArray(o.color)?s.defaultLine:o.color,c.isArrayOrTypedArray(a.color)&&(h=s.defaultLine,d=!0),h=\"mc\"in t?t.mcc=n.markerScale(t.mc):a.color||\"rgba(0,0,0,0)\",n.selectedColorFn&&(h=n.selectedColorFn(t))}if(t.om)e.call(s.stroke,h).style({\"stroke-width\":(p||1)+\"px\",fill:\"none\"});else{e.style(\"stroke-width\",p+\"px\");var m=a.gradient,y=t.mgt;if(y?d=!0:y=m&&m.type,Array.isArray(y)&&(y=y[0],T[y]||(y=0)),y&&\"none\"!==y){var x=t.mgc;x?d=!0:x=m.color;var _=r.uid;d&&(_+=\"-\"+t.i),v.gradient(e,i,_,y,[[0,x],[1,h]],\"fill\")}else s.fill(e,h);p&&s.stroke(e,f)}},v.makePointStyleFns=function(t){var e={},r=t.marker;return e.markerScale=v.tryColorscale(r,\"\"),e.lineScale=v.tryColorscale(r,\"line\"),o.traceIs(t,\"symbols\")&&(e.ms2mrc=d.isBubble(t)?g(t):function(){return(r.size||6)/2}),t.selectedpoints&&c.extendFlat(e,v.makeSelectedPointStyleFns(t)),e},v.makeSelectedPointStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.marker||{},a=r.marker||{},s=n.marker||{},l=i.opacity,u=a.opacity,h=s.opacity,f=void 0!==u,d=void 0!==h;(c.isArrayOrTypedArray(l)||f||d)&&(e.selectedOpacityFn=function(t){var e=void 0===t.mo?i.opacity:t.mo;return t.selected?f?u:e:d?h:p*e});var g=i.color,v=a.color,m=s.color;(v||m)&&(e.selectedColorFn=function(t){var e=t.mcc||g;return t.selected?v||e:m||e});var y=i.size,x=a.size,b=s.size,_=void 0!==x,w=void 0!==b;return o.traceIs(t,\"symbols\")&&(_||w)&&(e.selectedSizeFn=function(t){var e=t.mrc||y/2;return t.selected?_?x/2:e:w?b/2:e}),e},v.makeSelectedTextStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.textfont||{},a=r.textfont||{},o=n.textfont||{},l=i.color,c=a.color,u=o.color;return e.selectedTextColorFn=function(t){var e=t.tc||l;return t.selected?c||e:u||(c?e:s.addOpacity(e,p))},e},v.selectedPointStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=v.makeSelectedPointStyleFns(e),i=e.marker||{},a=[];r.selectedOpacityFn&&a.push(function(t,e){t.style(\"opacity\",r.selectedOpacityFn(e))}),r.selectedColorFn&&a.push(function(t,e){s.fill(t,r.selectedColorFn(e))}),r.selectedSizeFn&&a.push(function(t,e){var n=e.mx||i.symbol||0,a=r.selectedSizeFn(e);t.attr(\"d\",b(v.symbolNumber(n),a)),e.mrc2=a}),a.length&&t.each(function(t){for(var e=n.select(this),r=0;r<a.length;r++)a[r](e,t)})}},v.tryColorscale=function(t,e){var r=e?c.nestedProperty(t,e).get():t;if(r){var n=r.color;if((r.colorscale||r._colorAx)&&c.isArrayOrTypedArray(n))return l.makeColorScaleFuncFromTrace(r)}return c.identity};var A={start:1,end:-1,middle:0,bottom:1,top:-1};function M(t,e,r,i){var a=n.select(t.node().parentNode),o=-1!==e.indexOf(\"top\")?\"top\":-1!==e.indexOf(\"bottom\")?\"bottom\":\"middle\",s=-1!==e.indexOf(\"left\")?\"end\":-1!==e.indexOf(\"right\")?\"start\":\"middle\",l=i?i/.8+1:0,c=(u.lineCount(t)-1)*f+1,h=A[s]*l,p=.75*r+A[o]*l+(A[o]-1)*c*r/2;t.attr(\"text-anchor\",s),a.attr(\"transform\",\"translate(\"+h+\",\"+p+\")\")}function S(t,e){var r=t.ts||e.textfont.size;return i(r)&&r>0?r:0}v.textPointStyle=function(t,e,r){if(t.size()){var i;if(e.selectedpoints){var a=v.makeSelectedTextStyleFns(e);i=a.selectedTextColorFn}t.each(function(t){var a=n.select(this),o=c.extractOption(t,e,\"tx\",\"text\");if(o||0===o){var s=t.tp||e.textposition,l=S(t,e),h=i?i(t):t.tc||e.textfont.color;a.call(v.font,t.tf||e.textfont.family,l,h).text(o).call(u.convertToTspans,r).call(M,s,l,t.mrc)}else a.remove()})}},v.selectedTextStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=v.makeSelectedTextStyleFns(e);t.each(function(t){var i=n.select(this),a=r.selectedTextColorFn(t),o=t.tp||e.textposition,l=S(t,e);s.fill(i,a),M(i,o,l,t.mrc2||t.mrc)})}};var E=.5;function C(t,e,r,i){var a=t[0]-e[0],o=t[1]-e[1],s=r[0]-e[0],l=r[1]-e[1],c=Math.pow(a*a+o*o,E/2),u=Math.pow(s*s+l*l,E/2),h=(u*u*a-c*c*s)*i,f=(u*u*o-c*c*l)*i,p=3*u*(c+u),d=3*c*(c+u);return[[n.round(e[0]+(p&&h/p),2),n.round(e[1]+(p&&f/p),2)],[n.round(e[0]-(d&&h/d),2),n.round(e[1]-(d&&f/d),2)]]}v.smoothopen=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\");var r,n=\"M\"+t[0],i=[];for(r=1;r<t.length-1;r++)i.push(C(t[r-1],t[r],t[r+1],e));for(n+=\"Q\"+i[0][0]+\" \"+t[1],r=2;r<t.length-1;r++)n+=\"C\"+i[r-2][1]+\" \"+i[r-1][0]+\" \"+t[r];return n+=\"Q\"+i[t.length-3][1]+\" \"+t[t.length-1]},v.smoothclosed=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\")+\"Z\";var r,n=\"M\"+t[0],i=t.length-1,a=[C(t[i],t[0],t[1],e)];for(r=1;r<i;r++)a.push(C(t[r-1],t[r],t[r+1],e));for(a.push(C(t[i-1],t[i],t[0],e)),r=1;r<=i;r++)n+=\"C\"+a[r-1][1]+\" \"+a[r][0]+\" \"+t[r];return n+=\"C\"+a[i][1]+\" \"+a[0][0]+\" \"+t[0]+\"Z\"};var L={hv:function(t,e){return\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)},vh:function(t,e){return\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},hvh:function(t,e){return\"H\"+n.round((t[0]+e[0])/2,2)+\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},vhv:function(t,e){return\"V\"+n.round((t[1]+e[1])/2,2)+\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)}},P=function(t,e){return\"L\"+n.round(e[0],2)+\",\"+n.round(e[1],2)};v.steps=function(t){var e=L[t]||P;return function(t){for(var r=\"M\"+n.round(t[0][0],2)+\",\"+n.round(t[0][1],2),i=1;i<t.length;i++)r+=e(t[i-1],t[i]);return r}},v.makeTester=function(){var t=c.ensureSingleById(n.select(\"body\"),\"svg\",\"js-plotly-tester\",function(t){t.attr(h.svgAttrs).style({position:\"absolute\",left:\"-10000px\",top:\"-10000px\",width:\"9000px\",height:\"9000px\",\"z-index\":\"1\"})}),e=c.ensureSingle(t,\"path\",\"js-reference-point\",function(t){t.attr(\"d\",\"M0,0H1V1H0Z\").style({\"stroke-width\":0,fill:\"black\"})});v.tester=t,v.testref=e},v.savedBBoxes={};var O=0;function z(t){var e=t.getAttribute(\"data-unformatted\");if(null!==e)return e+t.getAttribute(\"data-math\")+t.getAttribute(\"text-anchor\")+t.getAttribute(\"style\")}function I(t,e){if(!t)return null;var r=e._context;return\"url('\"+(r._exportedPlot?\"\":r._baseUrl||\"\")+\"#\"+t+\"')\"}v.bBox=function(t,e,r){var i,a,o;if(r||(r=z(t)),r){if(i=v.savedBBoxes[r])return c.extendFlat({},i)}else if(1===t.childNodes.length){var s=t.childNodes[0];if(r=z(s)){var l=+s.getAttribute(\"x\")||0,h=+s.getAttribute(\"y\")||0,f=s.getAttribute(\"transform\");if(!f){var p=v.bBox(s,!1,r);return l&&(p.left+=l,p.right+=l),h&&(p.top+=h,p.bottom+=h),p}if(r+=\"~\"+l+\"~\"+h+\"~\"+f,i=v.savedBBoxes[r])return c.extendFlat({},i)}}e?a=t:(o=v.tester.node(),a=t.cloneNode(!0),o.appendChild(a)),n.select(a).attr(\"transform\",null).call(u.positionText,0,0);var d=a.getBoundingClientRect(),g=v.testref.node().getBoundingClientRect();e||o.removeChild(a);var m={height:d.height,width:d.width,left:d.left-g.left,top:d.top-g.top,right:d.right-g.left,bottom:d.bottom-g.top};return O>=1e4&&(v.savedBBoxes={},O=0),r&&(v.savedBBoxes[r]=m),O++,c.extendFlat({},m)},v.setClipUrl=function(t,e,r){t.attr(\"clip-path\",I(e,r))},v.getTranslate=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\btranslate\\((-?\\d*\\.?\\d*)[^-\\d]*(-?\\d*\\.?\\d*)[^\\d].*/,function(t,e,r){return[e,r].join(\" \")}).split(\" \");return{x:+e[0]||0,y:+e[1]||0}},v.setTranslate=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||0,r=r||0,a=a.replace(/(\\btranslate\\(.*?\\);?)/,\"\").trim(),a=(a+=\" translate(\"+e+\", \"+r+\")\").trim(),t[i](\"transform\",a),a},v.getScale=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\bscale\\((\\d*\\.?\\d*)[^\\d]*(\\d*\\.?\\d*)[^\\d].*/,function(t,e,r){return[e,r].join(\" \")}).split(\" \");return{x:+e[0]||1,y:+e[1]||1}},v.setScale=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||1,r=r||1,a=a.replace(/(\\bscale\\(.*?\\);?)/,\"\").trim(),a=(a+=\" scale(\"+e+\", \"+r+\")\").trim(),t[i](\"transform\",a),a};var D=/\\s*sc.*/;v.setPointGroupScale=function(t,e,r){if(e=e||1,r=r||1,t){var n=1===e&&1===r?\"\":\" scale(\"+e+\",\"+r+\")\";t.each(function(){var t=(this.getAttribute(\"transform\")||\"\").replace(D,\"\");t=(t+=n).trim(),this.setAttribute(\"transform\",t)})}};var R=/translate\\([^)]*\\)\\s*$/;v.setTextPointsScale=function(t,e,r){t&&t.each(function(){var t,i=n.select(this),a=i.select(\"text\");if(a.node()){var o=parseFloat(a.attr(\"x\")||0),s=parseFloat(a.attr(\"y\")||0),l=(i.attr(\"transform\")||\"\").match(R);t=1===e&&1===r?[]:[\"translate(\"+o+\",\"+s+\")\",\"scale(\"+e+\",\"+r+\")\",\"translate(\"+-o+\",\"+-s+\")\"],l&&t.push(l),i.attr(\"transform\",t.join(\" \"))}})}},{\"../../constants/alignment\":688,\"../../constants/interactions\":694,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../registry\":847,\"../../traces/scatter/make_bubble_size_func\":1128,\"../../traces/scatter/subtypes\":1135,\"../color\":593,\"../colorscale\":605,\"./symbol_defs\":615,d3:163,\"fast-isnumeric\":225,tinycolor2:537}],615:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports={circle:{n:0,f:function(t){var e=n.round(t,2);return\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"}},square:{n:1,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"}},diamond:{n:2,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"Z\"}},cross:{n:3,f:function(t){var e=n.round(.4*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H\"+e+\"V\"+r+\"H-\"+e+\"V\"+e+\"H-\"+r+\"V-\"+e+\"H-\"+e+\"V-\"+r+\"H\"+e+\"V-\"+e+\"H\"+r+\"Z\"}},x:{n:4,f:function(t){var e=n.round(.8*t/Math.sqrt(2),2),r=\"l\"+e+\",\"+e,i=\"l\"+e+\",-\"+e,a=\"l-\"+e+\",-\"+e,o=\"l-\"+e+\",\"+e;return\"M0,\"+e+r+i+a+i+a+o+a+o+r+o+r+\"Z\"}},\"triangle-up\":{n:5,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",\"+n.round(t/2,2)+\"H\"+e+\"L0,-\"+n.round(t,2)+\"Z\"}},\"triangle-down\":{n:6,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",-\"+n.round(t/2,2)+\"H\"+e+\"L0,\"+n.round(t,2)+\"Z\"}},\"triangle-left\":{n:7,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L-\"+n.round(t,2)+\",0Z\"}},\"triangle-right\":{n:8,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L\"+n.round(t,2)+\",0Z\"}},\"triangle-ne\":{n:9,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+r+\",-\"+e+\"H\"+e+\"V\"+r+\"Z\"}},\"triangle-se\":{n:10,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+e+\",-\"+r+\"V\"+e+\"H-\"+r+\"Z\"}},\"triangle-sw\":{n:11,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H-\"+e+\"V-\"+r+\"Z\"}},\"triangle-nw\":{n:12,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+e+\",\"+r+\"V-\"+e+\"H\"+r+\"Z\"}},pentagon:{n:13,f:function(t){var e=n.round(.951*t,2),r=n.round(.588*t,2),i=n.round(-t,2),a=n.round(-.309*t,2);return\"M\"+e+\",\"+a+\"L\"+r+\",\"+n.round(.809*t,2)+\"H-\"+r+\"L-\"+e+\",\"+a+\"L0,\"+i+\"Z\"}},hexagon:{n:14,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M\"+i+\",-\"+r+\"V\"+r+\"L0,\"+e+\"L-\"+i+\",\"+r+\"V-\"+r+\"L0,-\"+e+\"Z\"}},hexagon2:{n:15,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M-\"+r+\",\"+i+\"H\"+r+\"L\"+e+\",0L\"+r+\",-\"+i+\"H-\"+r+\"L-\"+e+\",0Z\"}},octagon:{n:16,f:function(t){var e=n.round(.924*t,2),r=n.round(.383*t,2);return\"M-\"+r+\",-\"+e+\"H\"+r+\"L\"+e+\",-\"+r+\"V\"+r+\"L\"+r+\",\"+e+\"H-\"+r+\"L-\"+e+\",\"+r+\"V-\"+r+\"Z\"}},star:{n:17,f:function(t){var e=1.4*t,r=n.round(.225*e,2),i=n.round(.951*e,2),a=n.round(.363*e,2),o=n.round(.588*e,2),s=n.round(-e,2),l=n.round(-.309*e,2),c=n.round(.118*e,2),u=n.round(.809*e,2);return\"M\"+r+\",\"+l+\"H\"+i+\"L\"+a+\",\"+c+\"L\"+o+\",\"+u+\"L0,\"+n.round(.382*e,2)+\"L-\"+o+\",\"+u+\"L-\"+a+\",\"+c+\"L-\"+i+\",\"+l+\"H-\"+r+\"L0,\"+s+\"Z\"}},hexagram:{n:18,f:function(t){var e=n.round(.66*t,2),r=n.round(.38*t,2),i=n.round(.76*t,2);return\"M-\"+i+\",0l-\"+r+\",-\"+e+\"h\"+i+\"l\"+r+\",-\"+e+\"l\"+r+\",\"+e+\"h\"+i+\"l-\"+r+\",\"+e+\"l\"+r+\",\"+e+\"h-\"+i+\"l-\"+r+\",\"+e+\"l-\"+r+\",-\"+e+\"h-\"+i+\"Z\"}},\"star-triangle-up\":{n:19,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M-\"+e+\",\"+r+o+e+\",\"+r+o+\"0,-\"+i+o+\"-\"+e+\",\"+r+\"Z\"}},\"star-triangle-down\":{n:20,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M\"+e+\",-\"+r+o+\"-\"+e+\",-\"+r+o+\"0,\"+i+o+e+\",-\"+r+\"Z\"}},\"star-square\":{n:21,f:function(t){var e=n.round(1.1*t,2),r=n.round(2*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",-\"+e+i+\"-\"+e+\",\"+e+i+e+\",\"+e+i+e+\",-\"+e+i+\"-\"+e+\",-\"+e+\"Z\"}},\"star-diamond\":{n:22,f:function(t){var e=n.round(1.4*t,2),r=n.round(1.9*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",0\"+i+\"0,\"+e+i+e+\",0\"+i+\"0,-\"+e+i+\"-\"+e+\",0Z\"}},\"diamond-tall\":{n:23,f:function(t){var e=n.round(.7*t,2),r=n.round(1.4*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},\"diamond-wide\":{n:24,f:function(t){var e=n.round(1.4*t,2),r=n.round(.7*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},hourglass:{n:25,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"L\"+e+\",-\"+e+\"H-\"+e+\"Z\"},noDot:!0},bowtie:{n:26,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"V-\"+e+\"L-\"+e+\",\"+e+\"V-\"+e+\"Z\"},noDot:!0},\"circle-cross\":{n:27,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"circle-x\":{n:28,f:function(t){var e=n.round(t,2),r=n.round(t/Math.sqrt(2),2);return\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"square-cross\":{n:29,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"square-x\":{n:30,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"diamond-cross\":{n:31,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM0,-\"+e+\"V\"+e+\"M-\"+e+\",0H\"+e},needLine:!0,noDot:!0},\"diamond-x\":{n:32,f:function(t){var e=n.round(1.3*t,2),r=n.round(.65*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM-\"+r+\",-\"+r+\"L\"+r+\",\"+r+\"M-\"+r+\",\"+r+\"L\"+r+\",-\"+r},needLine:!0,noDot:!0},\"cross-thin\":{n:33,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"x-thin\":{n:34,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},asterisk:{n:35,f:function(t){var e=n.round(1.2*t,2),r=n.round(.85*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r},needLine:!0,noDot:!0,noFill:!0},hash:{n:36,f:function(t){var e=n.round(t/2,2),r=n.round(t,2);return\"M\"+e+\",\"+r+\"V-\"+r+\"m-\"+r+\",0V\"+r+\"M\"+r+\",\"+e+\"H-\"+r+\"m0,-\"+r+\"H\"+r},needLine:!0,noFill:!0},\"y-up\":{n:37,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",\"+i+\"L0,0M\"+e+\",\"+i+\"L0,0M0,-\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-down\":{n:38,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",-\"+i+\"L0,0M\"+e+\",-\"+i+\"L0,0M0,\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-left\":{n:39,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M\"+i+\",\"+e+\"L0,0M\"+i+\",-\"+e+\"L0,0M-\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-right\":{n:40,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+i+\",\"+e+\"L0,0M-\"+i+\",-\"+e+\"L0,0M\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"line-ew\":{n:41,f:function(t){var e=n.round(1.4*t,2);return\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ns\":{n:42,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ne\":{n:43,f:function(t){var e=n.round(t,2);return\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-nw\":{n:44,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e},needLine:!0,noDot:!0,noFill:!0}}},{d3:163}],616:[function(t,e,r){\"use strict\";e.exports={visible:{valType:\"boolean\",editType:\"calc\"},type:{valType:\"enumerated\",values:[\"percent\",\"constant\",\"sqrt\",\"data\"],editType:\"calc\"},symmetric:{valType:\"boolean\",editType:\"calc\"},array:{valType:\"data_array\",editType:\"calc\"},arrayminus:{valType:\"data_array\",editType:\"calc\"},value:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},valueminus:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},traceref:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},tracerefminus:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},copy_ystyle:{valType:\"boolean\",editType:\"plot\"},copy_zstyle:{valType:\"boolean\",editType:\"style\"},color:{valType:\"color\",editType:\"style\"},thickness:{valType:\"number\",min:0,dflt:2,editType:\"style\"},width:{valType:\"number\",min:0,editType:\"plot\"},editType:\"calc\",_deprecated:{opacity:{valType:\"number\",editType:\"style\"}}}},{}],617:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=t(\"./compute_error\");function l(t,e,r,i){var l=e[\"error_\"+i]||{},c=[];if(l.visible&&-1!==[\"linear\",\"log\"].indexOf(r.type)){for(var u=s(l),h=0;h<t.length;h++){var f=t[h],p=f.i;if(void 0===p)p=h;else if(null===p)continue;var d=f[i];if(n(r.c2l(d))){var g=u(d,p);if(n(g[0])&&n(g[1])){var v=f[i+\"s\"]=d-g[0],m=f[i+\"h\"]=d+g[1];c.push(v,m)}}}var y=r._id,x=e._extremes[y],b=a.findExtremes(r,c,o.extendFlat({tozero:x.opts.tozero},{padded:!0}));x.min=x.min.concat(b.min),x.max=x.max.concat(b.max)}}e.exports=function(t){for(var e=t.calcdata,r=0;r<e.length;r++){var n=e[r],o=n[0].trace;if(!0===o.visible&&i.traceIs(o,\"errorBarsOK\")){var s=a.getFromId(t,o.xaxis),c=a.getFromId(t,o.yaxis);l(n,o,s,\"x\"),l(n,o,c,\"y\")}}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./compute_error\":618,\"fast-isnumeric\":225}],618:[function(t,e,r){\"use strict\";function n(t,e){return\"percent\"===t?function(t){return Math.abs(t*e/100)}:\"constant\"===t?function(){return Math.abs(e)}:\"sqrt\"===t?function(t){return Math.sqrt(Math.abs(t))}:void 0}e.exports=function(t){var e=t.type,r=t.symmetric;if(\"data\"===e){var i=t.array||[];if(r)return function(t,e){var r=+i[e];return[r,r]};var a=t.arrayminus||[];return function(t,e){var r=+i[e],n=+a[e];return isNaN(r)&&isNaN(n)?[NaN,NaN]:[n||0,r||0]}}var o=n(e,t.value),s=n(e,t.valueminus);return r||void 0===t.valueminus?function(t){var e=o(t);return[e,e]}:function(t){return[s(t),o(t)]}}},{}],619:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../plot_api/plot_template\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){var c=\"error_\"+l.axis,u=o.newContainer(e,c),h=t[c]||{};function f(t,e){return a.coerce(h,u,s,t,e)}if(!1!==f(\"visible\",void 0!==h.array||void 0!==h.value||\"sqrt\"===h.type)){var p=f(\"type\",\"array\"in h?\"data\":\"percent\"),d=!0;\"sqrt\"!==p&&(d=f(\"symmetric\",!((\"data\"===p?\"arrayminus\":\"valueminus\")in h))),\"data\"===p?(f(\"array\"),f(\"traceref\"),d||(f(\"arrayminus\"),f(\"tracerefminus\"))):\"percent\"!==p&&\"constant\"!==p||(f(\"value\"),d||f(\"valueminus\"));var g=\"copy_\"+l.inherit+\"style\";if(l.inherit)(e[\"error_\"+l.inherit]||{}).visible&&f(g,!(h.color||n(h.thickness)||n(h.width)));l.inherit&&u[g]||(f(\"color\",r),f(\"thickness\"),f(\"width\",i.traceIs(e,\"gl3d\")?0:4))}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../registry\":847,\"./attributes\":616,\"fast-isnumeric\":225}],620:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"./attributes\"),o={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a)};delete o.error_x.copy_zstyle,delete o.error_y.copy_zstyle,delete o.error_y.copy_ystyle;var s={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a),error_z:n.extendFlat({},a)};delete s.error_x.copy_ystyle,delete s.error_y.copy_ystyle,delete s.error_z.copy_ystyle,delete s.error_z.copy_zstyle,e.exports={moduleType:\"component\",name:\"errorbars\",schema:{traces:{scatter:o,bar:o,histogram:o,scatter3d:i(s,\"calc\",\"nested\"),scattergl:i(o,\"calc\",\"nested\")}},supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),makeComputeError:t(\"./compute_error\"),plot:t(\"./plot\"),style:t(\"./style\"),hoverInfo:function(t,e,r){(e.error_y||{}).visible&&(r.yerr=t.yh-t.y,e.error_y.symmetric||(r.yerrneg=t.y-t.ys));(e.error_x||{}).visible&&(r.xerr=t.xh-t.x,e.error_x.symmetric||(r.xerrneg=t.x-t.xs))}}},{\"../../lib\":719,\"../../plot_api/edit_types\":750,\"./attributes\":616,\"./calc\":617,\"./compute_error\":618,\"./defaults\":619,\"./plot\":621,\"./style\":622}],621:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../drawing\"),o=t(\"../../traces/scatter/subtypes\");e.exports=function(t,e,r,s){var l=r.xaxis,c=r.yaxis,u=s&&s.duration>0;e.each(function(e){var h,f=e[0].trace,p=f.error_x||{},d=f.error_y||{};f.ids&&(h=function(t){return t.id});var g=o.hasMarkers(f)&&f.marker.maxdisplayed>0;d.visible||p.visible||(e=[]);var v=n.select(this).selectAll(\"g.errorbar\").data(e,h);if(v.exit().remove(),e.length){p.visible||v.selectAll(\"path.xerror\").remove(),d.visible||v.selectAll(\"path.yerror\").remove(),v.style(\"opacity\",1);var m=v.enter().append(\"g\").classed(\"errorbar\",!0);u&&m.style(\"opacity\",0).transition().duration(s.duration).style(\"opacity\",1),a.setClipUrl(v,r.layerClipId,t),v.each(function(t){var e=n.select(this),r=function(t,e,r){var n={x:e.c2p(t.x),y:r.c2p(t.y)};void 0!==t.yh&&(n.yh=r.c2p(t.yh),n.ys=r.c2p(t.ys),i(n.ys)||(n.noYS=!0,n.ys=r.c2p(t.ys,!0)));void 0!==t.xh&&(n.xh=e.c2p(t.xh),n.xs=e.c2p(t.xs),i(n.xs)||(n.noXS=!0,n.xs=e.c2p(t.xs,!0)));return n}(t,l,c);if(!g||t.vis){var a,o=e.select(\"path.yerror\");if(d.visible&&i(r.x)&&i(r.yh)&&i(r.ys)){var h=d.width;a=\"M\"+(r.x-h)+\",\"+r.yh+\"h\"+2*h+\"m-\"+h+\",0V\"+r.ys,r.noYS||(a+=\"m-\"+h+\",0h\"+2*h),!o.size()?o=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"yerror\",!0):u&&(o=o.transition().duration(s.duration).ease(s.easing)),o.attr(\"d\",a)}else o.remove();var f=e.select(\"path.xerror\");if(p.visible&&i(r.y)&&i(r.xh)&&i(r.xs)){var v=(p.copy_ystyle?d:p).width;a=\"M\"+r.xh+\",\"+(r.y-v)+\"v\"+2*v+\"m0,-\"+v+\"H\"+r.xs,r.noXS||(a+=\"m0,-\"+v+\"v\"+2*v),!f.size()?f=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"xerror\",!0):u&&(f=f.transition().duration(s.duration).ease(s.easing)),f.attr(\"d\",a)}else f.remove()}})}})}},{\"../../traces/scatter/subtypes\":1135,\"../drawing\":614,d3:163,\"fast-isnumeric\":225}],622:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\");e.exports=function(t){t.each(function(t){var e=t[0].trace,r=e.error_y||{},a=e.error_x||{},o=n.select(this);o.selectAll(\"path.yerror\").style(\"stroke-width\",r.thickness+\"px\").call(i.stroke,r.color),a.copy_ystyle&&(a=r),o.selectAll(\"path.xerror\").style(\"stroke-width\",a.thickness+\"px\").call(i.stroke,a.color)})}},{\"../color\":593,d3:163}],623:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./layout_attributes\").hoverlabel,a=t(\"../../lib/extend\").extendFlat;e.exports={hoverlabel:{bgcolor:a({},i.bgcolor,{arrayOk:!0}),bordercolor:a({},i.bordercolor,{arrayOk:!0}),font:n({arrayOk:!0,editType:\"none\"}),align:a({},i.align,{arrayOk:!0}),namelength:a({},i.namelength,{arrayOk:!0}),editType:\"none\"}}},{\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"./layout_attributes\":633}],624:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");function a(t,e,r,i){i=i||n.identity,Array.isArray(t)&&(e[0][r]=i(t))}e.exports=function(t){var e=t.calcdata,r=t._fullLayout;function o(t){return function(e){return n.coerceHoverinfo({hoverinfo:e},{_module:t._module},r)}}for(var s=0;s<e.length;s++){var l=e[s],c=l[0].trace;if(!i.traceIs(c,\"pie-like\")){var u=i.traceIs(c,\"2dMap\")?a:n.fillArray;u(c.hoverinfo,l,\"hi\",o(c)),c.hovertemplate&&u(c.hovertemplate,l,\"ht\"),c.hoverlabel&&(u(c.hoverlabel.bgcolor,l,\"hbg\"),u(c.hoverlabel.bordercolor,l,\"hbc\"),u(c.hoverlabel.font.size,l,\"hts\"),u(c.hoverlabel.font.color,l,\"htc\"),u(c.hoverlabel.font.family,l,\"htf\"),u(c.hoverlabel.namelength,l,\"hnl\"),u(c.hoverlabel.align,l,\"hta\"))}}}},{\"../../lib\":719,\"../../registry\":847}],625:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./hover\").hover;e.exports=function(t,e,r){var a=n.getComponentMethod(\"annotations\",\"onClick\")(t,t._hoverdata);function o(){t.emit(\"plotly_click\",{points:t._hoverdata,event:e})}void 0!==r&&i(t,e,r,!0),t._hoverdata&&e&&e.target&&(a&&a.then?a.then(o):o(),e.stopImmediatePropagation&&e.stopImmediatePropagation())}},{\"../../registry\":847,\"./hover\":629}],626:[function(t,e,r){\"use strict\";e.exports={YANGLE:60,HOVERARROWSIZE:6,HOVERTEXTPAD:3,HOVERFONTSIZE:13,HOVERFONT:\"Arial, sans-serif\",HOVERMINTIME:50,HOVERID:\"-hover\"}},{}],627:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./hoverlabel_defaults\");e.exports=function(t,e,r,o){var s=n.extendFlat({},o.hoverlabel);e.hovertemplate&&(s.namelength=-1),a(t,e,function(r,a){return n.coerce(t,e,i,r,a)},s)}},{\"../../lib\":719,\"./attributes\":623,\"./hoverlabel_defaults\":630}],628:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");r.getSubplot=function(t){return t.subplot||t.xaxis+t.yaxis||t.geo},r.isTraceInSubplots=function(t,e){if(\"splom\"===t.type){for(var n=t.xaxes||[],i=t.yaxes||[],a=0;a<n.length;a++)for(var o=0;o<i.length;o++)if(-1!==e.indexOf(n[a]+i[o]))return!0;return!1}return-1!==e.indexOf(r.getSubplot(t))},r.flat=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=e;return r},r.p2c=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=t[n].p2c(e);return r},r.getDistanceFunction=function(t,e,n,i){return\"closest\"===t?i||r.quadrature(e,n):\"x\"===t?e:n},r.getClosest=function(t,e,r){if(!1!==r.index)r.index>=0&&r.index<t.length?r.distance=0:r.index=!1;else for(var n=0;n<t.length;n++){var i=e(t[n]);i<=r.distance&&(r.index=n,r.distance=i)}return r},r.inbox=function(t,e,r){return t*e<0||0===t?r:1/0},r.quadrature=function(t,e){return function(r){var n=t(r),i=e(r);return Math.sqrt(n*n+i*i)}},r.makeEventData=function(t,e,n){var i=\"index\"in t?t.index:t.pointNumber,a={data:e._input,fullData:e,curveNumber:e.index,pointNumber:i};if(e._indexToPoints){var o=e._indexToPoints[i];1===o.length?a.pointIndex=o[0]:a.pointIndices=o}else a.pointIndex=i;return e._module.eventData?a=e._module.eventData(a,t,e,n,i):(\"xVal\"in t?a.x=t.xVal:\"x\"in t&&(a.x=t.x),\"yVal\"in t?a.y=t.yVal:\"y\"in t&&(a.y=t.y),t.xa&&(a.xaxis=t.xa),t.ya&&(a.yaxis=t.ya),void 0!==t.zLabelVal&&(a.z=t.zLabelVal)),r.appendArrayPointValue(a,e,i),a},r.appendArrayPointValue=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){var u=o(n.nestedProperty(e,l).get(),r);void 0!==u&&(t[c]=u)}}},r.appendArrayMultiPointValues=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){for(var u=n.nestedProperty(e,l).get(),h=new Array(r.length),f=0;f<r.length;f++)h[f]=o(u,r[f]);t[c]=h}}};var i={ids:\"id\",locations:\"location\",labels:\"label\",values:\"value\",\"marker.colors\":\"color\",parents:\"parent\"};function a(t){return i[t]||t}function o(t,e){return Array.isArray(e)?Array.isArray(t)&&Array.isArray(t[e[0]])?t[e[0]][e[1]]:void 0:t[e]}},{\"../../lib\":719}],629:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../lib\"),s=t(\"../../lib/events\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib/override_cursor\"),u=t(\"../drawing\"),h=t(\"../color\"),f=t(\"../dragelement\"),p=t(\"../../plots/cartesian/axes\"),d=t(\"../../registry\"),g=t(\"./helpers\"),v=t(\"./constants\"),m=v.YANGLE,y=Math.PI*m/180,x=1/Math.sin(y),b=Math.cos(y),_=Math.sin(y),w=v.HOVERARROWSIZE,k=v.HOVERTEXTPAD;r.hover=function(t,e,r,a){t=o.getGraphDiv(t),o.throttle(t._fullLayout._uid+v.HOVERID,v.HOVERMINTIME,function(){!function(t,e,r,a){r||(r=\"xy\");var l=Array.isArray(r)?r:[r],u=t._fullLayout,v=u._plots||[],m=v[r],y=u._has(\"cartesian\");if(m){var b=m.overlays.map(function(t){return t.id});l=l.concat(b)}for(var _=l.length,w=new Array(_),k=new Array(_),T=!1,L=0;L<_;L++){var P=l[L],O=v[P];if(O)T=!0,w[L]=p.getFromId(t,O.xaxis._id),k[L]=p.getFromId(t,O.yaxis._id);else{var z=u[P]._subplot;w[L]=z.xaxis,k[L]=z.yaxis}}var I=e.hovermode||u.hovermode;I&&!T&&(I=\"closest\");if(-1===[\"x\",\"y\",\"closest\"].indexOf(I)||!t.calcdata||t.querySelector(\".zoombox\")||t._dragging)return f.unhoverRaw(t,e);var D,R,F,B,N,j,U,V,q,H,G,Y,W,X=-1===u.hoverdistance?1/0:u.hoverdistance,Z=-1===u.spikedistance?1/0:u.spikedistance,J=[],K=[],$={hLinePoint:null,vLinePoint:null},Q=!1;if(Array.isArray(e))for(I=\"array\",F=0;F<e.length;F++)(N=t.calcdata[e[F].curveNumber||0])&&(j=N[0].trace,\"skip\"!==N[0].trace.hoverinfo&&(K.push(N),\"h\"===j.orientation&&(Q=!0)));else{for(B=0;B<t.calcdata.length;B++)N=t.calcdata[B],\"skip\"!==(j=N[0].trace).hoverinfo&&g.isTraceInSubplots(j,l)&&(K.push(N),\"h\"===j.orientation&&(Q=!0));var tt,et,rt=!e.target;if(rt)tt=\"xpx\"in e?e.xpx:w[0]._length/2,et=\"ypx\"in e?e.ypx:k[0]._length/2;else{if(!1===s.triggerHandler(t,\"plotly_beforehover\",e))return;var nt=e.target.getBoundingClientRect();if(tt=e.clientX-nt.left,et=e.clientY-nt.top,tt<0||tt>w[0]._length||et<0||et>k[0]._length)return f.unhoverRaw(t,e)}if(e.pointerX=tt+w[0]._offset,e.pointerY=et+k[0]._offset,D=\"xval\"in e?g.flat(l,e.xval):g.p2c(w,tt),R=\"yval\"in e?g.flat(l,e.yval):g.p2c(k,et),!i(D[0])||!i(R[0]))return o.warn(\"Fx.hover failed\",e,t),f.unhoverRaw(t,e)}var it=1/0;for(B=0;B<K.length;B++)if((N=K[B])&&N[0]&&N[0].trace&&!0===(j=N[0].trace).visible&&0!==j._length&&-1===[\"carpet\",\"contourcarpet\"].indexOf(j._module.name)){if(\"splom\"===j.type?U=l[V=0]:(U=g.getSubplot(j),V=l.indexOf(U)),q=I,Y={cd:N,trace:j,xa:w[V],ya:k[V],maxHoverDistance:X,maxSpikeDistance:Z,index:!1,distance:Math.min(it,X),spikeDistance:1/0,xSpike:void 0,ySpike:void 0,color:h.defaultLine,name:j.name,x0:void 0,x1:void 0,y0:void 0,y1:void 0,xLabelVal:void 0,yLabelVal:void 0,zLabelVal:void 0,text:void 0},u[U]&&(Y.subplot=u[U]._subplot),u._splomScenes&&u._splomScenes[j.uid]&&(Y.scene=u._splomScenes[j.uid]),W=J.length,\"array\"===q){var at=e[B];\"pointNumber\"in at?(Y.index=at.pointNumber,q=\"closest\"):(q=\"\",\"xval\"in at&&(H=at.xval,q=\"x\"),\"yval\"in at&&(G=at.yval,q=q?\"closest\":\"y\"))}else H=D[V],G=R[V];if(0!==X)if(j._module&&j._module.hoverPoints){var ot=j._module.hoverPoints(Y,H,G,q,u._hoverlayer);if(ot)for(var st,lt=0;lt<ot.length;lt++)st=ot[lt],i(st.x0)&&i(st.y0)&&J.push(S(st,I))}else o.log(\"Unrecognized trace type in hover:\",j);if(\"closest\"===I&&J.length>W&&(J.splice(0,W),it=J[0].distance),y&&0!==Z&&0===J.length){Y.distance=Z,Y.index=!1;var ct=j._module.hoverPoints(Y,H,G,\"closest\",u._hoverlayer);if(ct&&(ct=ct.filter(function(t){return t.spikeDistance<=Z})),ct&&ct.length){var ut,ht=ct.filter(function(t){return t.xa.showspikes});if(ht.length){var ft=ht[0];i(ft.x0)&&i(ft.y0)&&(ut=vt(ft),(!$.vLinePoint||$.vLinePoint.spikeDistance>ut.spikeDistance)&&($.vLinePoint=ut))}var pt=ct.filter(function(t){return t.ya.showspikes});if(pt.length){var dt=pt[0];i(dt.x0)&&i(dt.y0)&&(ut=vt(dt),(!$.hLinePoint||$.hLinePoint.spikeDistance>ut.spikeDistance)&&($.hLinePoint=ut))}}}}function gt(t,e){for(var r,n=null,i=1/0,a=0;a<t.length;a++)(r=t[a].spikeDistance)<i&&r<=e&&(n=t[a],i=r);return n}function vt(t){return t?{xa:t.xa,ya:t.ya,x:void 0!==t.xSpike?t.xSpike:(t.x0+t.x1)/2,y:void 0!==t.ySpike?t.ySpike:(t.y0+t.y1)/2,distance:t.distance,spikeDistance:t.spikeDistance,curveNumber:t.trace.index,color:t.color,pointNumber:t.index}:null}var mt={fullLayout:u,container:u._hoverlayer,outerContainer:u._paperdiv,event:e},yt=t._spikepoints,xt={vLinePoint:$.vLinePoint,hLinePoint:$.hLinePoint};if(t._spikepoints=xt,y&&0!==Z&&0!==J.length){var bt=J.filter(function(t){return t.ya.showspikes}),_t=gt(bt,Z);$.hLinePoint=vt(_t);var wt=J.filter(function(t){return t.xa.showspikes}),kt=gt(wt,Z);$.vLinePoint=vt(kt)}if(0===J.length){var Tt=f.unhoverRaw(t,e);return!y||null===$.hLinePoint&&null===$.vLinePoint||C(yt)&&E($,mt),Tt}y&&C(yt)&&E($,mt);J.sort(function(t,e){return t.distance-e.distance});var At=t._hoverdata,Mt=[];for(F=0;F<J.length;F++){var St=J[F],Et=g.makeEventData(St,St.trace,St.cd);if(!1!==St.hovertemplate){var Ct=!1;St.cd[St.index]&&St.cd[St.index].ht&&(Ct=St.cd[St.index].ht),St.hovertemplate=Ct||St.trace.hovertemplate||!1}St.eventData=[Et],Mt.push(Et)}t._hoverdata=Mt;var Lt=\"y\"===I&&(K.length>1||J.length>1)||\"closest\"===I&&Q&&J.length>1,Pt=h.combine(u.plot_bgcolor||h.background,u.paper_bgcolor),Ot={hovermode:I,rotateLabels:Lt,bgColor:Pt,container:u._hoverlayer,outerContainer:u._paperdiv,commonLabelOpts:u.hoverlabel,hoverdistance:u.hoverdistance},zt=A(J,Ot,t);if(function(t,e,r){var n,i,a,o,s,l,c,u=0,h=1,f=t.size(),p=new Array(f),d=0;function g(t){var e=t[0],r=t[t.length-1];if(i=e.pmin-e.pos-e.dp+e.size,a=r.pos+r.dp+r.size-e.pmax,i>.01){for(s=t.length-1;s>=0;s--)t[s].dp+=i;n=!1}if(!(a<.01)){if(i<-.01){for(s=t.length-1;s>=0;s--)t[s].dp-=a;n=!1}if(n){var c=0;for(o=0;o<t.length;o++)(l=t[o]).pos+l.dp+l.size>e.pmax&&c++;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos>e.pmax-1&&(l.del=!0,c--);for(o=0;o<t.length&&!(c<=0);o++)if((l=t[o]).pos<e.pmin+1)for(l.del=!0,c--,a=2*l.size,s=t.length-1;s>=0;s--)t[s].dp-=a;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos+l.dp+l.size>e.pmax&&(l.del=!0,c--)}}}for(t.each(function(t){var n=t[e],i=\"x\"===n._id.charAt(0),a=n.range;0===d&&a&&a[0]>a[1]!==i&&(h=-1),p[d++]=[{datum:t,traceIndex:t.trace.index,dp:0,pos:t.pos,posref:t.posref,size:t.by*(i?x:1)/2,pmin:0,pmax:i?r.width:r.height}]}),p.sort(function(t,e){return t[0].posref-e[0].posref||h*(e[0].traceIndex-t[0].traceIndex)});!n&&u<=f;){for(u++,n=!0,o=0;o<p.length-1;){var v=p[o],m=p[o+1],y=v[v.length-1],b=m[0];if((i=y.pos+y.dp+y.size-b.pos-b.dp+b.size)>.01&&y.pmin===b.pmin&&y.pmax===b.pmax){for(s=m.length-1;s>=0;s--)m[s].dp+=i;for(v.push.apply(v,m),p.splice(o+1,1),c=0,s=v.length-1;s>=0;s--)c+=v[s].dp;for(a=c/v.length,s=v.length-1;s>=0;s--)v[s].dp-=a;n=!1}else o++}p.forEach(g)}for(o=p.length-1;o>=0;o--){var _=p[o];for(s=_.length-1;s>=0;s--){var w=_[s],k=w.datum;k.offset=w.dp,k.del=w.del}}}(zt,Lt?\"xa\":\"ya\",u),M(zt,Lt),e.target&&e.target.tagName){var It=d.getComponentMethod(\"annotations\",\"hasClickToShow\")(t,Mt);c(n.select(e.target),It?\"pointer\":\"\")}if(!e.target||a||!function(t,e,r){if(!r||r.length!==t._hoverdata.length)return!0;for(var n=r.length-1;n>=0;n--){var i=r[n],a=t._hoverdata[n];if(i.curveNumber!==a.curveNumber||String(i.pointNumber)!==String(a.pointNumber)||String(i.pointNumbers)!==String(a.pointNumbers))return!0}return!1}(t,0,At))return;At&&t.emit(\"plotly_unhover\",{event:e,points:At});t.emit(\"plotly_hover\",{event:e,points:t._hoverdata,xaxes:w,yaxes:k,xvals:D,yvals:R})}(t,e,r,a)})},r.loneHover=function(t,e){var r=!0;Array.isArray(t)||(r=!1,t=[t]);var i=t.map(function(t){return{color:t.color||h.defaultLine,x0:t.x0||t.x||0,x1:t.x1||t.x||0,y0:t.y0||t.y||0,y1:t.y1||t.y||0,xLabel:t.xLabel,yLabel:t.yLabel,zLabel:t.zLabel,text:t.text,name:t.name,idealAlign:t.idealAlign,borderColor:t.borderColor,fontFamily:t.fontFamily,fontSize:t.fontSize,fontColor:t.fontColor,nameLength:t.nameLength,textAlign:t.textAlign,trace:t.trace||{index:0,hoverinfo:\"\"},xa:{_offset:0},ya:{_offset:0},index:0,hovertemplate:t.hovertemplate||!1,eventData:t.eventData||!1,hovertemplateLabels:t.hovertemplateLabels||!1}}),a=n.select(e.container),o=e.outerContainer?n.select(e.outerContainer):a,s={hovermode:\"closest\",rotateLabels:!1,bgColor:e.bgColor||h.background,container:a,outerContainer:o},l=A(i,s,e.gd),c=0,u=0;return l.sort(function(t,e){return t.y0-e.y0}).each(function(t,r){var n=t.y0-t.by/2;t.offset=n-5<c?c-n+5:0,c=n+t.by+t.offset,r===e.anchorIndex&&(u=t.offset)}).each(function(t){t.offset-=u}),M(l,s.rotateLabels),r?l:l.node()};var T=/<extra>([\\s\\S]*)<\\/extra>/;function A(t,e,r){var i=r._fullLayout,a=e.hovermode,s=e.rotateLabels,c=e.bgColor,f=e.container,p=e.outerContainer,d=e.commonLabelOpts||{},g=e.fontFamily||v.HOVERFONT,y=e.fontSize||v.HOVERFONTSIZE,x=t[0],b=x.xa,_=x.ya,A=\"y\"===a?\"yLabel\":\"xLabel\",M=x[A],S=(String(M)||\"\").split(\" \")[0],E=p.node().getBoundingClientRect(),C=E.top,P=E.width,O=E.height,z=void 0!==M&&x.distance<=e.hoverdistance&&(\"x\"===a||\"y\"===a);if(z){var I,D,R=!0;for(I=0;I<t.length;I++)if(R&&void 0===t[I].zLabel&&(R=!1),D=t[I].hoverinfo||t[I].trace.hoverinfo){var F=Array.isArray(D)?D:D.split(\"+\");if(-1===F.indexOf(\"all\")&&-1===F.indexOf(a)){z=!1;break}}R&&(z=!1)}var B=f.selectAll(\"g.axistext\").data(z?[0]:[]);B.enter().append(\"g\").classed(\"axistext\",!0),B.exit().remove(),B.each(function(){var e=n.select(this),i=o.ensureSingle(e,\"path\",\"\",function(t){t.style({\"stroke-width\":\"1px\"})}),s=o.ensureSingle(e,\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),c=d.bgcolor||h.defaultLine,f=d.bordercolor||h.contrast(c),p=h.contrast(c);i.style({fill:c,stroke:f}),s.text(M).call(u.font,d.font.family||g,d.font.size||y,d.font.color||p).call(l.positionText,0,0).call(l.convertToTspans,r),e.attr(\"transform\",\"\");var v=s.node().getBoundingClientRect();if(\"x\"===a){s.attr(\"text-anchor\",\"middle\").call(l.positionText,0,\"top\"===b.side?C-v.bottom-w-k:C-v.top+w+k);var m=\"top\"===b.side?\"-\":\"\";i.attr(\"d\",\"M0,0L\"+w+\",\"+m+w+\"H\"+(k+v.width/2)+\"v\"+m+(2*k+v.height)+\"H-\"+(k+v.width/2)+\"V\"+m+w+\"H-\"+w+\"Z\"),e.attr(\"transform\",\"translate(\"+(b._offset+(x.x0+x.x1)/2)+\",\"+(_._offset+(\"top\"===b.side?0:_._length))+\")\")}else{s.attr(\"text-anchor\",\"right\"===_.side?\"start\":\"end\").call(l.positionText,(\"right\"===_.side?1:-1)*(k+w),C-v.top-v.height/2);var T=\"right\"===_.side?\"\":\"-\";i.attr(\"d\",\"M0,0L\"+T+w+\",\"+w+\"V\"+(k+v.height/2)+\"h\"+T+(2*k+v.width)+\"V-\"+(k+v.height/2)+\"H\"+T+w+\"V-\"+w+\"Z\"),e.attr(\"transform\",\"translate(\"+(b._offset+(\"right\"===_.side?b._length:0))+\",\"+(_._offset+(x.y0+x.y1)/2)+\")\")}t=t.filter(function(t){return void 0!==t.zLabelVal||(t[A]||\"\").split(\" \")[0]===S})});var N=f.selectAll(\"g.hovertext\").data(t,function(t){return[t.trace.index,t.index,t.x0,t.y0,t.name,t.attr,t.xa,t.ya||\"\"].join(\",\")});return N.enter().append(\"g\").classed(\"hovertext\",!0).each(function(){var t=n.select(this);t.append(\"rect\").call(h.fill,h.addOpacity(c,.8)),t.append(\"text\").classed(\"name\",!0),t.append(\"path\").style(\"stroke-width\",\"1px\"),t.append(\"text\").classed(\"nums\",!0).call(u.font,g,y)}),N.exit().remove(),N.each(function(t){var e=n.select(this).attr(\"transform\",\"\"),f=\"\",p=\"\",d=t.bgcolor||t.color,v=h.combine(h.opacity(d)?d:h.defaultLine,c),x=h.combine(h.opacity(t.color)?t.color:h.defaultLine,c),b=t.borderColor||h.contrast(v);void 0!==t.nameOverride&&(t.name=t.nameOverride),t.name&&(t.trace._meta&&(t.name=o.templateString(t.name,t.trace._meta)),f=L(t.name,t.nameLength)),void 0!==t.zLabel?(void 0!==t.xLabel&&(p+=\"x: \"+t.xLabel+\"<br>\"),void 0!==t.yLabel&&(p+=\"y: \"+t.yLabel+\"<br>\"),\"choropleth\"!==t.trace.type&&\"choroplethmapbox\"!==t.trace.type&&(p+=(p?\"z: \":\"\")+t.zLabel)):z&&t[a+\"Label\"]===M?p=t[(\"x\"===a?\"y\":\"x\")+\"Label\"]||\"\":void 0===t.xLabel?void 0!==t.yLabel&&\"scattercarpet\"!==t.trace.type&&(p=t.yLabel):p=void 0===t.yLabel?t.xLabel:\"(\"+t.xLabel+\", \"+t.yLabel+\")\",!t.text&&0!==t.text||Array.isArray(t.text)||(p+=(p?\"<br>\":\"\")+t.text),void 0!==t.extraText&&(p+=(p?\"<br>\":\"\")+t.extraText),\"\"!==p||t.hovertemplate||(\"\"===f&&e.remove(),p=f);var _=i._d3locale,A=t.hovertemplate||!1,S=t.hovertemplateLabels||t,E=t.eventData[0]||{};A&&(p=(p=o.hovertemplateString(A,S,_,E,t.trace._meta)).replace(T,function(e,r){return f=L(r,t.nameLength),\"\"}));var I=e.select(\"text.nums\").call(u.font,t.fontFamily||g,t.fontSize||y,t.fontColor||b).text(p).attr(\"data-notex\",1).call(l.positionText,0,0).call(l.convertToTspans,r),D=e.select(\"text.name\"),R=0,F=0;if(f&&f!==p){D.call(u.font,t.fontFamily||g,t.fontSize||y,x).text(f).attr(\"data-notex\",1).call(l.positionText,0,0).call(l.convertToTspans,r);var B=D.node().getBoundingClientRect();R=B.width+2*k,F=B.height+2*k}else D.remove(),e.select(\"rect\").remove();e.select(\"path\").style({fill:v,stroke:b});var N,j,U=I.node().getBoundingClientRect(),V=t.xa._offset+(t.x0+t.x1)/2,q=t.ya._offset+(t.y0+t.y1)/2,H=Math.abs(t.x1-t.x0),G=Math.abs(t.y1-t.y0),Y=U.width+w+k+R;if(t.ty0=C-U.top,t.bx=U.width+2*k,t.by=Math.max(U.height+2*k,F),t.anchor=\"start\",t.txwidth=U.width,t.tx2width=R,t.offset=0,s)t.pos=V,N=q+G/2+Y<=O,j=q-G/2-Y>=0,\"top\"!==t.idealAlign&&N||!j?N?(q+=G/2,t.anchor=\"start\"):t.anchor=\"middle\":(q-=G/2,t.anchor=\"end\");else if(t.pos=q,N=V+H/2+Y<=P,j=V-H/2-Y>=0,\"left\"!==t.idealAlign&&N||!j)if(N)V+=H/2,t.anchor=\"start\";else{t.anchor=\"middle\";var W=Y/2,X=V+W-P,Z=V-W;X>0&&(V-=X),Z<0&&(V+=-Z)}else V-=H/2,t.anchor=\"end\";I.attr(\"text-anchor\",t.anchor),R&&D.attr(\"text-anchor\",t.anchor),e.attr(\"transform\",\"translate(\"+V+\",\"+q+\")\"+(s?\"rotate(\"+m+\")\":\"\"))}),N}function M(t,e){t.each(function(t){var r=n.select(this);if(t.del)return r.remove();var i=r.select(\"text.nums\"),a=t.anchor,o=\"end\"===a?-1:1,s={start:1,end:-1,middle:0}[a],c=s*(w+k),h=c+s*(t.txwidth+k),f=0,p=t.offset;\"middle\"===a&&(c-=t.tx2width/2,h+=t.txwidth/2+k),e&&(p*=-_,f=t.offset*b),r.select(\"path\").attr(\"d\",\"middle\"===a?\"M-\"+(t.bx/2+t.tx2width/2)+\",\"+(p-t.by/2)+\"h\"+t.bx+\"v\"+t.by+\"h-\"+t.bx+\"Z\":\"M0,0L\"+(o*w+f)+\",\"+(w+p)+\"v\"+(t.by/2-w)+\"h\"+o*t.bx+\"v-\"+t.by+\"H\"+(o*w+f)+\"V\"+(p-w)+\"Z\");var d=c+f,g=p+t.ty0-t.by/2+k,v=t.textAlign||\"auto\";\"auto\"!==v&&(\"left\"===v&&\"start\"!==a?(i.attr(\"text-anchor\",\"start\"),d=\"middle\"===a?-t.bx/2-t.tx2width/2+k:-t.bx-k):\"right\"===v&&\"end\"!==a&&(i.attr(\"text-anchor\",\"end\"),d=\"middle\"===a?t.bx/2-t.tx2width/2-k:t.bx+k)),i.call(l.positionText,d,g),t.tx2width&&(r.select(\"text.name\").call(l.positionText,h+s*k+f,p+t.ty0-t.by/2+k),r.select(\"rect\").call(u.setRect,h+(s-1)*t.tx2width/2+f,p-t.by/2-1,t.tx2width,t.by+2))})}function S(t,e){var r=t.index,n=t.trace||{},a=t.cd[0],s=t.cd[r]||{};function l(t){return t||i(t)&&0===t}var c=Array.isArray(r)?function(t,e){var i=o.castOption(a,r,t);return l(i)?i:o.extractOption({},n,\"\",e)}:function(t,e){return o.extractOption(s,n,t,e)};function u(e,r,n){var i=c(r,n);l(i)&&(t[e]=i)}if(u(\"hoverinfo\",\"hi\",\"hoverinfo\"),u(\"bgcolor\",\"hbg\",\"hoverlabel.bgcolor\"),u(\"borderColor\",\"hbc\",\"hoverlabel.bordercolor\"),u(\"fontFamily\",\"htf\",\"hoverlabel.font.family\"),u(\"fontSize\",\"hts\",\"hoverlabel.font.size\"),u(\"fontColor\",\"htc\",\"hoverlabel.font.color\"),u(\"nameLength\",\"hnl\",\"hoverlabel.namelength\"),u(\"textAlign\",\"hta\",\"hoverlabel.align\"),t.posref=\"y\"===e||\"closest\"===e&&\"h\"===n.orientation?t.xa._offset+(t.x0+t.x1)/2:t.ya._offset+(t.y0+t.y1)/2,t.x0=o.constrain(t.x0,0,t.xa._length),t.x1=o.constrain(t.x1,0,t.xa._length),t.y0=o.constrain(t.y0,0,t.ya._length),t.y1=o.constrain(t.y1,0,t.ya._length),void 0!==t.xLabelVal&&(t.xLabel=\"xLabel\"in t?t.xLabel:p.hoverLabelText(t.xa,t.xLabelVal),t.xVal=t.xa.c2d(t.xLabelVal)),void 0!==t.yLabelVal&&(t.yLabel=\"yLabel\"in t?t.yLabel:p.hoverLabelText(t.ya,t.yLabelVal),t.yVal=t.ya.c2d(t.yLabelVal)),void 0!==t.zLabelVal&&void 0===t.zLabel&&(t.zLabel=String(t.zLabelVal)),!(isNaN(t.xerr)||\"log\"===t.xa.type&&t.xerr<=0)){var h=p.tickText(t.xa,t.xa.c2l(t.xerr),\"hover\").text;void 0!==t.xerrneg?t.xLabel+=\" +\"+h+\" / -\"+p.tickText(t.xa,t.xa.c2l(t.xerrneg),\"hover\").text:t.xLabel+=\" \\xb1 \"+h,\"x\"===e&&(t.distance+=1)}if(!(isNaN(t.yerr)||\"log\"===t.ya.type&&t.yerr<=0)){var f=p.tickText(t.ya,t.ya.c2l(t.yerr),\"hover\").text;void 0!==t.yerrneg?t.yLabel+=\" +\"+f+\" / -\"+p.tickText(t.ya,t.ya.c2l(t.yerrneg),\"hover\").text:t.yLabel+=\" \\xb1 \"+f,\"y\"===e&&(t.distance+=1)}var d=t.hoverinfo||t.trace.hoverinfo;return d&&\"all\"!==d&&(-1===(d=Array.isArray(d)?d:d.split(\"+\")).indexOf(\"x\")&&(t.xLabel=void 0),-1===d.indexOf(\"y\")&&(t.yLabel=void 0),-1===d.indexOf(\"z\")&&(t.zLabel=void 0),-1===d.indexOf(\"text\")&&(t.text=void 0),-1===d.indexOf(\"name\")&&(t.name=void 0)),t}function E(t,e){var r,n,i=e.container,o=e.fullLayout,s=e.event,l=!!t.hLinePoint,c=!!t.vLinePoint;if(i.selectAll(\".spikeline\").remove(),c||l){var f=h.combine(o.plot_bgcolor,o.paper_bgcolor);if(l){var p,d,g=t.hLinePoint;r=g&&g.xa,\"cursor\"===(n=g&&g.ya).spikesnap?(p=s.pointerX,d=s.pointerY):(p=r._offset+g.x,d=n._offset+g.y);var v,m,y=a.readability(g.color,f)<1.5?h.contrast(f):g.color,x=n.spikemode,b=n.spikethickness,_=n.spikecolor||y,w=n._boundingBox,k=(w.left+w.right)/2<p?w.right:w.left;-1===x.indexOf(\"toaxis\")&&-1===x.indexOf(\"across\")||(-1!==x.indexOf(\"toaxis\")&&(v=k,m=p),-1!==x.indexOf(\"across\")&&(v=n._counterSpan[0],m=n._counterSpan[1]),i.insert(\"line\",\":first-child\").attr({x1:v,x2:m,y1:d,y2:d,\"stroke-width\":b,stroke:_,\"stroke-dasharray\":u.dashStyle(n.spikedash,b)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),i.insert(\"line\",\":first-child\").attr({x1:v,x2:m,y1:d,y2:d,\"stroke-width\":b+2,stroke:f}).classed(\"spikeline\",!0).classed(\"crisp\",!0)),-1!==x.indexOf(\"marker\")&&i.insert(\"circle\",\":first-child\").attr({cx:k+(\"right\"!==n.side?b:-b),cy:d,r:b,fill:_}).classed(\"spikeline\",!0)}if(c){var T,A,M=t.vLinePoint;r=M&&M.xa,n=M&&M.ya,\"cursor\"===r.spikesnap?(T=s.pointerX,A=s.pointerY):(T=r._offset+M.x,A=n._offset+M.y);var S,E,C=a.readability(M.color,f)<1.5?h.contrast(f):M.color,L=r.spikemode,P=r.spikethickness,O=r.spikecolor||C,z=r._boundingBox,I=(z.top+z.bottom)/2<A?z.bottom:z.top;-1===L.indexOf(\"toaxis\")&&-1===L.indexOf(\"across\")||(-1!==L.indexOf(\"toaxis\")&&(S=I,E=A),-1!==L.indexOf(\"across\")&&(S=r._counterSpan[0],E=r._counterSpan[1]),i.insert(\"line\",\":first-child\").attr({x1:T,x2:T,y1:S,y2:E,\"stroke-width\":P,stroke:O,\"stroke-dasharray\":u.dashStyle(r.spikedash,P)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),i.insert(\"line\",\":first-child\").attr({x1:T,x2:T,y1:S,y2:E,\"stroke-width\":P+2,stroke:f}).classed(\"spikeline\",!0).classed(\"crisp\",!0)),-1!==L.indexOf(\"marker\")&&i.insert(\"circle\",\":first-child\").attr({cx:T,cy:I-(\"top\"!==r.side?P:-P),r:P,fill:O}).classed(\"spikeline\",!0)}}}function C(t,e){return!e||(e.vLinePoint!==t._spikepoints.vLinePoint||e.hLinePoint!==t._spikepoints.hLinePoint)}function L(t,e){return l.plainText(t||\"\",{len:e,allowedTags:[\"br\",\"sub\",\"sup\",\"b\",\"i\",\"em\"]})}},{\"../../lib\":719,\"../../lib/events\":709,\"../../lib/override_cursor\":730,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"./constants\":626,\"./helpers\":628,d3:163,\"fast-isnumeric\":225,tinycolor2:537}],630:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i){r(\"hoverlabel.bgcolor\",(i=i||{}).bgcolor),r(\"hoverlabel.bordercolor\",i.bordercolor),r(\"hoverlabel.namelength\",i.namelength),n.coerceFont(r,\"hoverlabel.font\",i.font),r(\"hoverlabel.align\",i.align)}},{\"../../lib\":719}],631:[function(t,e,r){\"use strict\";t(\"../../constants/docs\").FORMAT_LINK;e.exports=function(t,e){t=t||{};(e=e||{}).description&&e.description;var r=e.keys||[];if(r.length>0){for(var n=[],i=0;i<r.length;i++)n[i]=\"`\"+r[i]+\"`\";\"Finally, the template string has access to \",1===r.length?\"variable \"+n[0]:\"variables \"+n.slice(0,-1).join(\", \")+\" and \"+n.slice(-1)+\".\"}var a={valType:\"string\",dflt:\"\",editType:t.editType||\"none\"};return!1!==t.arrayOk&&(a.arrayOk=!0),a}},{\"../../constants/docs\":690}],632:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../dragelement\"),o=t(\"./helpers\"),s=t(\"./layout_attributes\"),l=t(\"./hover\");e.exports={moduleType:\"component\",name:\"fx\",constants:t(\"./constants\"),schema:{layout:s},attributes:t(\"./attributes\"),layoutAttributes:s,supplyLayoutGlobalDefaults:t(\"./layout_global_defaults\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),getDistanceFunction:o.getDistanceFunction,getClosest:o.getClosest,inbox:o.inbox,quadrature:o.quadrature,appendArrayPointValue:o.appendArrayPointValue,castHoverOption:function(t,e,r){return i.castOption(t,e,\"hoverlabel.\"+r)},castHoverinfo:function(t,e,r){return i.castOption(t,r,\"hoverinfo\",function(r){return i.coerceHoverinfo({hoverinfo:r},{_module:t._module},e)})},hover:l.hover,unhover:a.unhover,loneHover:l.loneHover,loneUnhover:function(t){var e=i.isD3Selection(t)?t:n.select(t);e.selectAll(\"g.hovertext\").remove(),e.selectAll(\".spikeline\").remove()},click:t(\"./click\")}},{\"../../lib\":719,\"../dragelement\":611,\"./attributes\":623,\"./calc\":624,\"./click\":625,\"./constants\":626,\"./defaults\":627,\"./helpers\":628,\"./hover\":629,\"./layout_attributes\":633,\"./layout_defaults\":634,\"./layout_global_defaults\":635,d3:163}],633:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../plots/font_attributes\")({editType:\"none\"});i.family.dflt=n.HOVERFONT,i.size.dflt=n.HOVERFONTSIZE,e.exports={clickmode:{valType:\"flaglist\",flags:[\"event\",\"select\"],dflt:\"event\",editType:\"plot\",extras:[\"none\"]},dragmode:{valType:\"enumerated\",values:[\"zoom\",\"pan\",\"select\",\"lasso\",\"orbit\",\"turntable\",!1],dflt:\"zoom\",editType:\"modebar\"},hovermode:{valType:\"enumerated\",values:[\"x\",\"y\",\"closest\",!1],editType:\"modebar\"},hoverdistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},spikedistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"none\"},bordercolor:{valType:\"color\",editType:\"none\"},font:i,align:{valType:\"enumerated\",values:[\"left\",\"right\",\"auto\"],dflt:\"auto\",editType:\"none\"},namelength:{valType:\"integer\",min:-1,dflt:15,editType:\"none\"},editType:\"none\"},selectdirection:{valType:\"enumerated\",values:[\"h\",\"v\",\"d\",\"any\"],dflt:\"any\",editType:\"none\"}}},{\"../../plots/font_attributes\":793,\"./constants\":626}],634:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){function a(r,a){return n.coerce(t,e,i,r,a)}var o,s=a(\"clickmode\");\"select\"===a(\"dragmode\")&&a(\"selectdirection\"),e._has(\"cartesian\")?s.indexOf(\"select\")>-1?o=\"closest\":(e._isHoriz=function(t,e){for(var r=e._scatterStackOpts||{},n=0;n<t.length;n++){var i=t[n],a=i.xaxis+i.yaxis,o=r[a]||{},s=o[i.stackgroup]||{};if(\"h\"!==i.orientation&&\"h\"!==s.orientation)return!1}return!0}(r,e),o=e._isHoriz?\"y\":\"x\"):o=\"closest\",a(\"hovermode\",o)&&(a(\"hoverdistance\"),a(\"spikedistance\"));var l=e._has(\"mapbox\"),c=e._has(\"geo\"),u=e._basePlotModules.length;\"zoom\"===e.dragmode&&((l||c)&&1===u||l&&c&&2===u)&&(e.dragmode=\"pan\")}},{\"../../lib\":719,\"./layout_attributes\":633}],635:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./hoverlabel_defaults\"),a=t(\"./layout_attributes\");e.exports=function(t,e){i(t,e,function(r,i){return n.coerce(t,e,a,r,i)})}},{\"../../lib\":719,\"./hoverlabel_defaults\":630,\"./layout_attributes\":633}],636:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/regex\").counter,a=t(\"../../plots/domain\").attributes,o=t(\"../../plots/cartesian/constants\").idRegex,s=t(\"../../plot_api/plot_template\"),l={rows:{valType:\"integer\",min:1,editType:\"plot\"},roworder:{valType:\"enumerated\",values:[\"top to bottom\",\"bottom to top\"],dflt:\"top to bottom\",editType:\"plot\"},columns:{valType:\"integer\",min:1,editType:\"plot\"},subplots:{valType:\"info_array\",freeLength:!0,dimensions:2,items:{valType:\"enumerated\",values:[i(\"xy\").toString(),\"\"],editType:\"plot\"},editType:\"plot\"},xaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.x.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},yaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.y.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},pattern:{valType:\"enumerated\",values:[\"independent\",\"coupled\"],dflt:\"coupled\",editType:\"plot\"},xgap:{valType:\"number\",min:0,max:1,editType:\"plot\"},ygap:{valType:\"number\",min:0,max:1,editType:\"plot\"},domain:a({name:\"grid\",editType:\"plot\",noGridCell:!0},{}),xside:{valType:\"enumerated\",values:[\"bottom\",\"bottom plot\",\"top plot\",\"top\"],dflt:\"bottom plot\",editType:\"plot\"},yside:{valType:\"enumerated\",values:[\"left\",\"left plot\",\"right plot\",\"right\"],dflt:\"left plot\",editType:\"plot\"},editType:\"plot\"};function c(t,e,r){var n=e[r+\"axes\"],i=Object.keys((t._splomAxes||{})[r]||{});return Array.isArray(n)?n:i.length?i:void 0}function u(t,e,r,n,i,a){var o=e(t+\"gap\",r),s=e(\"domain.\"+t);e(t+\"side\",n);for(var l=new Array(i),c=s[0],u=(s[1]-c)/(i-o),h=u*(1-o),f=0;f<i;f++){var p=c+u*f;l[a?i-1-f:f]=[p,p+h]}return l}function h(t,e,r,n,i){var a,o=new Array(r);function s(t,r){-1!==e.indexOf(r)&&void 0===n[r]?(o[t]=r,n[r]=t):o[t]=\"\"}if(Array.isArray(t))for(a=0;a<r;a++)s(a,t[a]);else for(s(0,i),a=1;a<r;a++)s(a,i+(a+1));return o}e.exports={moduleType:\"component\",name:\"grid\",schema:{layout:{grid:l}},layoutAttributes:l,sizeDefaults:function(t,e){var r=t.grid||{},i=c(e,r,\"x\"),a=c(e,r,\"y\");if(t.grid||i||a){var o,h,f=Array.isArray(r.subplots)&&Array.isArray(r.subplots[0]),p=Array.isArray(i),d=Array.isArray(a),g=p&&i!==r.xaxes&&d&&a!==r.yaxes;f?(o=r.subplots.length,h=r.subplots[0].length):(d&&(o=a.length),p&&(h=i.length));var v=s.newContainer(e,\"grid\"),m=T(\"rows\",o),y=T(\"columns\",h);if(m*y>1){f||p||d||\"independent\"===T(\"pattern\")&&(f=!0),v._hasSubplotGrid=f;var x,b,_=\"top to bottom\"===T(\"roworder\"),w=f?.2:.1,k=f?.3:.1;g&&e._splomGridDflt&&(x=e._splomGridDflt.xside,b=e._splomGridDflt.yside),v._domains={x:u(\"x\",T,w,x,y),y:u(\"y\",T,k,b,m,_)}}else delete e.grid}function T(t,e){return n.coerce(r,v,l,t,e)}},contentDefaults:function(t,e){var r=e.grid;if(r&&r._domains){var n,i,a,o,s,l,u,f=t.grid||{},p=e._subplots,d=r._hasSubplotGrid,g=r.rows,v=r.columns,m=\"independent\"===r.pattern,y=r._axisMap={};if(d){var x=f.subplots||[];l=r.subplots=new Array(g);var b=1;for(n=0;n<g;n++){var _=l[n]=new Array(v),w=x[n]||[];for(i=0;i<v;i++)if(m?(s=1===b?\"xy\":\"x\"+b+\"y\"+b,b++):s=w[i],_[i]=\"\",-1!==p.cartesian.indexOf(s)){if(u=s.indexOf(\"y\"),a=s.slice(0,u),o=s.slice(u),void 0!==y[a]&&y[a]!==i||void 0!==y[o]&&y[o]!==n)continue;_[i]=s,y[a]=i,y[o]=n}}}else{var k=c(e,f,\"x\"),T=c(e,f,\"y\");r.xaxes=h(k,p.xaxis,v,y,\"x\"),r.yaxes=h(T,p.yaxis,g,y,\"y\")}var A=r._anchors={},M=\"top to bottom\"===r.roworder;for(var S in y){var E,C,L,P=S.charAt(0),O=r[P+\"side\"];if(O.length<8)A[S]=\"free\";else if(\"x\"===P){if(\"t\"===O.charAt(0)===M?(E=0,C=1,L=g):(E=g-1,C=-1,L=-1),d){var z=y[S];for(n=E;n!==L;n+=C)if((s=l[n][z])&&(u=s.indexOf(\"y\"),s.slice(0,u)===S)){A[S]=s.slice(u);break}}else for(n=E;n!==L;n+=C)if(o=r.yaxes[n],-1!==p.cartesian.indexOf(S+o)){A[S]=o;break}}else if(\"l\"===O.charAt(0)?(E=0,C=1,L=v):(E=v-1,C=-1,L=-1),d){var I=y[S];for(n=E;n!==L;n+=C)if((s=l[I][n])&&(u=s.indexOf(\"y\"),s.slice(u)===S)){A[S]=s.slice(0,u);break}}else for(n=E;n!==L;n+=C)if(a=r.xaxes[n],-1!==p.cartesian.indexOf(a+S)){A[S]=a;break}}}}}},{\"../../lib\":719,\"../../lib/regex\":735,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773,\"../../plots/domain\":792}],637:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/constants\"),i=t(\"../../plot_api/plot_template\").templatedArray;e.exports=i(\"image\",{visible:{valType:\"boolean\",dflt:!0,editType:\"arraydraw\"},source:{valType:\"string\",editType:\"arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},sizex:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizey:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizing:{valType:\"enumerated\",values:[\"fill\",\"contain\",\"stretch\"],dflt:\"contain\",editType:\"arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},x:{valType:\"any\",dflt:0,editType:\"arraydraw\"},y:{valType:\"any\",dflt:0,editType:\"arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"top\",editType:\"arraydraw\"},xref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.x.toString()],dflt:\"paper\",editType:\"arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.y.toString()],dflt:\"paper\",editType:\"arraydraw\"},editType:\"arraydraw\"})},{\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773}],638:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.images,h=e._id.charAt(0),f=0;f<u.length;f++)if(c=\"images[\"+f+\"].\",(l=u[f])[h+\"ref\"]===e._id){var p=l[h],d=l[\"size\"+h],g=null,v=null;if(o){g=i(p,e.range);var m=d/Math.pow(10,g)/2;v=2*Math.log(m+Math.sqrt(1+m*m))/Math.LN10}else v=(g=Math.pow(10,p))*(Math.pow(10,d/2)-Math.pow(10,-d/2));n(g)?n(v)||(v=null):(g=null,v=null),a(c+h,g),a(c+\"size\"+h,v)}}},{\"../../lib/to_log_range\":745,\"fast-isnumeric\":225}],639:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\");function s(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}var s=a(\"source\");if(!a(\"visible\",!!s))return e;a(\"layer\"),a(\"xanchor\"),a(\"yanchor\"),a(\"sizex\"),a(\"sizey\"),a(\"sizing\"),a(\"opacity\");for(var l={_fullLayout:r},c=[\"x\",\"y\"],u=0;u<2;u++){var h=c[u],f=i.coerceRef(t,e,l,h,\"paper\");if(\"paper\"!==f)i.getFromId(l,f)._imgIndices.push(e._index);i.coercePosition(e,l,a,f,h,0)}return e}e.exports=function(t,e){a(t,e,{name:\"images\",handleItemDefaults:s})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"./attributes\":637}],640:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../drawing\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/xmlns_namespaces\");e.exports=function(t){var e,r,s=t._fullLayout,l=[],c={},u=[];for(r=0;r<s.images.length;r++){var h=s.images[r];if(h.visible)if(\"below\"===h.layer&&\"paper\"!==h.xref&&\"paper\"!==h.yref){e=h.xref+h.yref;var f=s._plots[e];if(!f){u.push(h);continue}f.mainplot&&(e=f.mainplot.id),c[e]||(c[e]=[]),c[e].push(h)}else\"above\"===h.layer?l.push(h):u.push(h)}var p={x:{left:{sizing:\"xMin\",offset:0},center:{sizing:\"xMid\",offset:-.5},right:{sizing:\"xMax\",offset:-1}},y:{top:{sizing:\"YMin\",offset:0},middle:{sizing:\"YMid\",offset:-.5},bottom:{sizing:\"YMax\",offset:-1}}};function d(e){var r=n.select(this);if(!this.img||this.img.src!==e.source){r.attr(\"xmlns\",o.svg);var i=new Promise(function(t){var n=new Image;function i(){r.remove(),t()}this.img=n,n.setAttribute(\"crossOrigin\",\"anonymous\"),n.onerror=i,n.onload=function(){var e=document.createElement(\"canvas\");e.width=this.width,e.height=this.height,e.getContext(\"2d\").drawImage(this,0,0);var n=e.toDataURL(\"image/png\");r.attr(\"xlink:href\",n),t()},r.on(\"error\",i),n.src=e.source}.bind(this));t._promises.push(i)}}function g(e){var r=n.select(this),o=a.getFromId(t,e.xref),l=a.getFromId(t,e.yref),c=s._size,u=o?Math.abs(o.l2p(e.sizex)-o.l2p(0)):e.sizex*c.w,h=l?Math.abs(l.l2p(e.sizey)-l.l2p(0)):e.sizey*c.h,f=u*p.x[e.xanchor].offset,d=h*p.y[e.yanchor].offset,g=p.x[e.xanchor].sizing+p.y[e.yanchor].sizing,v=(o?o.r2p(e.x)+o._offset:e.x*c.w+c.l)+f,m=(l?l.r2p(e.y)+l._offset:c.h-e.y*c.h+c.t)+d;switch(e.sizing){case\"fill\":g+=\" slice\";break;case\"stretch\":g=\"none\"}r.attr({x:v,y:m,width:u,height:h,preserveAspectRatio:g,opacity:e.opacity});var y=(o?o._id:\"\")+(l?l._id:\"\");i.setClipUrl(r,y?\"clip\"+s._uid+y:null,t)}var v=s._imageLowerLayer.selectAll(\"image\").data(u),m=s._imageUpperLayer.selectAll(\"image\").data(l);v.enter().append(\"image\"),m.enter().append(\"image\"),v.exit().remove(),m.exit().remove(),v.each(function(t){d.bind(this)(t),g.bind(this)(t)}),m.each(function(t){d.bind(this)(t),g.bind(this)(t)});var y=Object.keys(s._plots);for(r=0;r<y.length;r++){e=y[r];var x=s._plots[e];if(x.imagelayer){var b=x.imagelayer.selectAll(\"image\").data(c[e]||[]);b.enter().append(\"image\"),b.exit().remove(),b.each(function(t){d.bind(this)(t),g.bind(this)(t)})}}}},{\"../../constants/xmlns_namespaces\":696,\"../../plots/cartesian/axes\":767,\"../drawing\":614,d3:163}],641:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"images\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"images\"),draw:t(\"./draw\"),convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":777,\"./attributes\":637,\"./convert_coords\":638,\"./defaults\":639,\"./draw\":640}],642:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",editType:\"legend\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"legend\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"legend\"},font:n({editType:\"legend\"}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"v\",editType:\"legend\"},traceorder:{valType:\"flaglist\",flags:[\"reversed\",\"grouped\"],extras:[\"normal\"],editType:\"legend\"},tracegroupgap:{valType:\"number\",min:0,dflt:10,editType:\"legend\"},itemsizing:{valType:\"enumerated\",values:[\"trace\",\"constant\"],dflt:\"trace\",editType:\"legend\"},itemclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggle\",editType:\"legend\"},itemdoubleclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggleothers\",editType:\"legend\"},x:{valType:\"number\",min:-2,max:3,dflt:1.02,editType:\"legend\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"legend\"},y:{valType:\"number\",min:-2,max:3,dflt:1,editType:\"legend\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"legend\"},uirevision:{valType:\"any\",editType:\"none\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"legend\"},editType:\"legend\"}},{\"../../plots/font_attributes\":793,\"../color/attributes\":592}],643:[function(t,e,r){\"use strict\";e.exports={scrollBarWidth:6,scrollBarMinHeight:20,scrollBarColor:\"#808BA4\",scrollBarMargin:4,textOffsetX:40}},{}],644:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plot_api/plot_template\"),o=t(\"./attributes\"),s=t(\"../../plots/layout_attributes\"),l=t(\"./helpers\");e.exports=function(t,e,r){for(var c,u,h,f,p=t.legend||{},d=0,g=!1,v=\"normal\",m=0;m<r.length;m++){var y=r[m];y.visible&&((y.showlegend||y._dfltShowLegend)&&(d++,y.showlegend&&(g=!0,(n.traceIs(y,\"pie-like\")||!0===y._input.showlegend)&&d++)),(n.traceIs(y,\"bar\")&&\"stack\"===e.barmode||-1!==[\"tonextx\",\"tonexty\"].indexOf(y.fill))&&(v=l.isGrouped({traceorder:v})?\"grouped+reversed\":\"reversed\"),void 0!==y.legendgroup&&\"\"!==y.legendgroup&&(v=l.isReversed({traceorder:v})?\"reversed+grouped\":\"grouped\"))}var x=i.coerce(t,e,s,\"showlegend\",g&&d>1);if(!1!==x||p.uirevision){var b=a.newContainer(e,\"legend\");if(w(\"uirevision\",e.uirevision),!1!==x){if(w(\"bgcolor\",e.paper_bgcolor),w(\"bordercolor\"),w(\"borderwidth\"),i.coerceFont(w,\"font\",e.font),w(\"orientation\"),\"h\"===b.orientation){var _=t.xaxis;n.getComponentMethod(\"rangeslider\",\"isVisible\")(_)?(c=0,h=\"left\",u=1.1,f=\"bottom\"):(c=0,h=\"left\",u=-.1,f=\"top\")}w(\"traceorder\",v),l.isGrouped(e.legend)&&w(\"tracegroupgap\"),w(\"itemsizing\"),w(\"itemclick\"),w(\"itemdoubleclick\"),w(\"x\",c),w(\"xanchor\",h),w(\"y\",u),w(\"yanchor\",f),w(\"valign\"),i.noneOrAll(p,b,[\"x\",\"y\"])}}function w(t,e){return i.coerce(p,b,o,t,e)}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/layout_attributes\":819,\"../../registry\":847,\"./attributes\":642,\"./helpers\":648}],645:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib/events\"),l=t(\"../dragelement\"),c=t(\"../drawing\"),u=t(\"../color\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"./handle_click\"),p=t(\"./constants\"),d=t(\"../../constants/alignment\"),g=d.LINE_SPACING,v=d.FROM_TL,m=d.FROM_BR,y=t(\"./get_legend_data\"),x=t(\"./style\"),b=t(\"./helpers\");function _(t,e,r,n,i){var a=r.data()[0][0].trace,l={event:i,node:r.node(),curveNumber:a.index,expandedIndex:a._expandedIndex,data:t.data,layout:t.layout,frames:t._transitionData._frames,config:t._context,fullData:t._fullData,fullLayout:t._fullLayout};if(a._group&&(l.group=a._group),o.traceIs(a,\"pie-like\")&&(l.label=r.datum()[0].label),!1!==s.triggerHandler(t,\"plotly_legendclick\",l))if(1===n)e._clickTimeout=setTimeout(function(){f(r,t,n)},t._context.doubleClickDelay);else if(2===n){e._clickTimeout&&clearTimeout(e._clickTimeout),t._legendMouseDownTime=0,!1!==s.triggerHandler(t,\"plotly_legenddoubleclick\",l)&&f(r,t,n)}}function w(t,e,r){var n=t.data()[0][0],a=e._fullLayout,s=n.trace,l=o.traceIs(s,\"pie-like\"),u=s.index,f=e._context.edits.legendText&&!l,d=l?n.label:s.name;s._meta&&(d=i.templateString(d,s._meta));var v=i.ensureSingle(t,\"text\",\"legendtext\");function m(r){h.convertToTspans(r,e,function(){!function(t,e){var r=t.data()[0][0];if(!r.trace.showlegend)return void t.remove();var n,i,a=t.select(\"g[class*=math-group]\"),o=a.node(),s=e._fullLayout.legend.font.size*g;if(o){var l=c.bBox(o);n=l.height,i=l.width,c.setTranslate(a,0,n/4)}else{var u=t.select(\".legendtext\"),f=h.lineCount(u),d=u.node();n=s*f,i=d?c.bBox(d).width:0;var v=s*(.3+(1-f)/2);h.positionText(u,p.textOffsetX,v)}r.lineHeight=s,r.height=Math.max(n,16)+3,r.width=i}(t,e)})}v.attr(\"text-anchor\",\"start\").classed(\"user-select-none\",!0).call(c.font,a.legend.font).text(f?k(d,r):d),h.positionText(v,p.textOffsetX,0),f?v.call(h.makeEditable,{gd:e,text:d}).call(m).on(\"edit\",function(t){this.text(k(t,r)).call(m);var a=n.trace._fullInput||{},s={};if(o.hasTransform(a,\"groupby\")){var l=o.getTransformIndices(a,\"groupby\"),c=l[l.length-1],h=i.keyedContainer(a,\"transforms[\"+c+\"].styles\",\"target\",\"value.name\");h.set(n.trace._group,t),s=h.constructUpdate()}else s.name=t;return o.call(\"_guiRestyle\",e,s,u)}):m(v)}function k(t,e){var r=Math.max(4,e);if(t&&t.trim().length>=r/2)return t;for(var n=r-(t=t||\"\").length;n>0;n--)t+=\" \";return t}function T(t,e){var r,a=e._context.doubleClickDelay,o=1,s=i.ensureSingle(t,\"rect\",\"legendtoggle\",function(t){t.style(\"cursor\",\"pointer\").attr(\"pointer-events\",\"all\").call(u.fill,\"rgba(0,0,0,0)\")});s.on(\"mousedown\",function(){(r=(new Date).getTime())-e._legendMouseDownTime<a?o+=1:(o=1,e._legendMouseDownTime=r)}),s.on(\"mouseup\",function(){if(!e._dragged&&!e._editing){var r=e._fullLayout.legend;(new Date).getTime()-e._legendMouseDownTime>a&&(o=Math.max(o-1,1)),_(e,r,t,o,n.event)}})}function A(t,e,r){var a=t._fullLayout,o=a.legend,s=o.borderwidth,l=b.isGrouped(o),u=0;if(o._width=0,o._height=0,b.isVertical(o))l&&e.each(function(t,e){c.setTranslate(this,0,e*o.tracegroupgap)}),r.each(function(t){var e=t[0],r=e.height,n=e.width;c.setTranslate(this,s,5+s+o._height+r/2),o._height+=r,o._width=Math.max(o._width,n)}),o._width+=45+2*s,o._height+=10+2*s,l&&(o._height+=(o._lgroupsLength-1)*o.tracegroupgap),u=40;else if(l){var h,f=0,p=0,d=e.data(),g=0;for(h=0;h<d.length;h++){var v=d[h],m=v.map(function(t){return t[0].width}),y=i.aggNums(Math.max,null,m),x=v.reduce(function(t,e){return t+e[0].height},0);p=Math.max(p,y),f=Math.max(f,x),g=Math.max(g,v.length)}p+=5,p+=40;var _=[o._width],w=[],k=0;for(h=0;h<d.length;h++){a._size.w<s+o._width+5+p?(_[_.length-1]=_[0],o._width=p,k++):o._width+=p+s;var T=k*f;T+=k>0?o.tracegroupgap:0,w.push(T),_.push(o._width)}e.each(function(t,e){c.setTranslate(this,_[e],w[e])}),e.each(function(){var t=n.select(this).selectAll(\"g.traces\"),e=0;t.each(function(t){var r=t[0].height;c.setTranslate(this,0,5+s+e+r/2),e+=r})});var A=w[w.length-1]+f;o._height=10+2*s+A;var M=Math.max.apply(null,_);o._width=M+p+40,o._width+=2*s}else{var S=0,E=0,C=0,L=0,P=0;r.each(function(t){C=Math.max(40+t[0].width,C),P+=40+t[0].width+5});var O=a._size.w>s+P-5;r.each(function(t){var e=t[0],r=O?40+t[0].width:C;s+L+5+r>a._size.w&&(L=0,S+=E,o._height+=E,E=0),c.setTranslate(this,s+L,5+s+e.height/2+S),o._width+=5+r,L+=5+r,E=Math.max(e.height,E)}),O?o._height=E:o._height+=E,o._width+=2*s,o._height+=10+2*s}o._width=Math.ceil(o._width),o._height=Math.ceil(o._height);var z=t._context.edits.legendText||t._context.edits.legendPosition;r.each(function(t){var e=t[0],r=n.select(this).select(\".legendtoggle\");c.setRect(r,0,-e.height/2,(z?0:o._width)+u,e.height)})}function M(t){var e=t._fullLayout.legend,r=\"left\";i.isRightAnchor(e)?r=\"right\":i.isCenterAnchor(e)&&(r=\"center\");var n=\"top\";i.isBottomAnchor(e)?n=\"bottom\":i.isMiddleAnchor(e)&&(n=\"middle\"),a.autoMargin(t,\"legend\",{x:e.x,y:e.y,l:e._width*v[r],r:e._width*m[r],b:e._height*m[n],t:e._height*v[n]})}e.exports=function(t){var e=t._fullLayout,r=\"legend\"+e._uid;if(e._infolayer&&t.calcdata){t._legendMouseDownTime||(t._legendMouseDownTime=0);var s=e.legend,h=e.showlegend&&y(t.calcdata,s),f=e.hiddenlabels||[];if(!e.showlegend||!h.length)return e._infolayer.selectAll(\".legend\").remove(),e._topdefs.select(\"#\"+r).remove(),void a.autoMargin(t,\"legend\");for(var d=0,g=0;g<h.length;g++)for(var b=0;b<h[g].length;b++){var k=h[g][b][0],S=k.trace,E=o.traceIs(S,\"pie-like\")?k.label:S.name;d=Math.max(d,E&&E.length||0)}var C=!1,L=i.ensureSingle(e._infolayer,\"g\",\"legend\",function(t){t.attr(\"pointer-events\",\"all\"),C=!0}),P=i.ensureSingleById(e._topdefs,\"clipPath\",r,function(t){t.append(\"rect\")}),O=i.ensureSingle(L,\"rect\",\"bg\",function(t){t.attr(\"shape-rendering\",\"crispEdges\")});O.call(u.stroke,s.bordercolor).call(u.fill,s.bgcolor).style(\"stroke-width\",s.borderwidth+\"px\");var z=i.ensureSingle(L,\"g\",\"scrollbox\"),I=i.ensureSingle(L,\"rect\",\"scrollbar\",function(t){t.attr({rx:20,ry:3,width:0,height:0}).call(u.fill,\"#808BA4\")}),D=z.selectAll(\"g.groups\").data(h);D.enter().append(\"g\").attr(\"class\",\"groups\"),D.exit().remove();var R=D.selectAll(\"g.traces\").data(i.identity);R.enter().append(\"g\").attr(\"class\",\"traces\"),R.exit().remove(),R.style(\"opacity\",function(t){var e=t[0].trace;return o.traceIs(e,\"pie-like\")?-1!==f.indexOf(t[0].label)?.5:1:\"legendonly\"===e.visible?.5:1}).each(function(){n.select(this).call(w,t,d)}).call(x,t).each(function(){n.select(this).call(T,t)}),i.syncOrAsync([a.previousPromises,function(){C&&(A(t,D,R),M(t));var u=e.width,h=e.height;A(t,D,R),s._height>h?function(t){var e=t._fullLayout.legend,r=\"left\";i.isRightAnchor(e)?r=\"right\":i.isCenterAnchor(e)&&(r=\"center\");a.autoMargin(t,\"legend\",{x:e.x,y:.5,l:e._width*v[r],r:e._width*m[r],b:0,t:0})}(t):M(t);var f=e._size,d=f.l+f.w*s.x,g=f.t+f.h*(1-s.y);i.isRightAnchor(s)?d-=s._width:i.isCenterAnchor(s)&&(d-=s._width/2),i.isBottomAnchor(s)?g-=s._height:i.isMiddleAnchor(s)&&(g-=s._height/2);var y=s._width,x=f.w;y>x?(d=f.l,y=x):(d+y>u&&(d=u-y),d<0&&(d=0),y=Math.min(u-d,s._width));var b,w,k,T,S=s._height,E=f.h;if(S>E?(g=f.t,S=E):(g+S>h&&(g=h-S),g<0&&(g=0),S=Math.min(h-g,s._height)),c.setTranslate(L,d,g),I.on(\".drag\",null),L.on(\"wheel\",null),s._height<=S||t._context.staticPlot)O.attr({width:y-s.borderwidth,height:S-s.borderwidth,x:s.borderwidth/2,y:s.borderwidth/2}),c.setTranslate(z,0,0),P.select(\"rect\").attr({width:y-2*s.borderwidth,height:S-2*s.borderwidth,x:s.borderwidth,y:s.borderwidth}),c.setClipUrl(z,r,t),c.setRect(I,0,0,0,0),delete s._scrollY;else{var F,B,N=Math.max(p.scrollBarMinHeight,S*S/s._height),j=S-N-2*p.scrollBarMargin,U=s._height-S,V=j/U,q=Math.min(s._scrollY||0,U);O.attr({width:y-2*s.borderwidth+p.scrollBarWidth+p.scrollBarMargin,height:S-s.borderwidth,x:s.borderwidth/2,y:s.borderwidth/2}),P.select(\"rect\").attr({width:y-2*s.borderwidth+p.scrollBarWidth+p.scrollBarMargin,height:S-2*s.borderwidth,x:s.borderwidth,y:s.borderwidth+q}),c.setClipUrl(z,r,t),G(q,N,V),L.on(\"wheel\",function(){G(q=i.constrain(s._scrollY+n.event.deltaY/j*U,0,U),N,V),0!==q&&q!==U&&n.event.preventDefault()});var H=n.behavior.drag().on(\"dragstart\",function(){F=n.event.sourceEvent.clientY,B=q}).on(\"drag\",function(){var t=n.event.sourceEvent;2===t.buttons||t.ctrlKey||G(q=i.constrain((t.clientY-F)/V+B,0,U),N,V)});I.call(H)}function G(e,r,n){s._scrollY=t._fullLayout.legend._scrollY=e,c.setTranslate(z,0,-e),c.setRect(I,y,p.scrollBarMargin+e*n,p.scrollBarWidth,r),P.select(\"rect\").attr({y:s.borderwidth+e})}t._context.edits.legendPosition&&(L.classed(\"cursor-move\",!0),l.init({element:L.node(),gd:t,prepFn:function(){var t=c.getTranslate(L);k=t.x,T=t.y},moveFn:function(t,e){var r=k+t,n=T+e;c.setTranslate(L,r,n),b=l.align(r,0,f.l,f.l+f.w,s.xanchor),w=l.align(n,0,f.t+f.h,f.t,s.yanchor)},doneFn:function(){void 0!==b&&void 0!==w&&o.call(\"_guiRelayout\",t,{\"legend.x\":b,\"legend.y\":w})},clickFn:function(r,n){var i=e._infolayer.selectAll(\"g.traces\").filter(function(){var t=this.getBoundingClientRect();return n.clientX>=t.left&&n.clientX<=t.right&&n.clientY>=t.top&&n.clientY<=t.bottom});i.size()>0&&_(t,L,i,r,n)}}))}],t)}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/events\":709,\"../../lib/svg_text_utils\":743,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"./constants\":643,\"./get_legend_data\":646,\"./handle_click\":647,\"./helpers\":648,\"./style\":650,d3:163}],646:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./helpers\");e.exports=function(t,e){var r,a,o={},s=[],l=!1,c={},u=0;function h(t,r){if(\"\"!==t&&i.isGrouped(e))-1===s.indexOf(t)?(s.push(t),l=!0,o[t]=[[r]]):o[t].push([r]);else{var n=\"~~i\"+u;s.push(n),o[n]=[[r]],u++}}for(r=0;r<t.length;r++){var f=t[r],p=f[0],d=p.trace,g=d.legendgroup;if(d.visible&&d.showlegend)if(n.traceIs(d,\"pie-like\"))for(c[g]||(c[g]={}),a=0;a<f.length;a++){var v=f[a].label;c[g][v]||(h(g,{label:v,color:f[a].color,i:f[a].i,trace:d,pts:f[a].pts}),c[g][v]=!0)}else h(g,p)}if(!s.length)return[];var m,y,x=s.length;if(l&&i.isGrouped(e))for(y=new Array(x),r=0;r<x;r++)m=o[s[r]],y[r]=i.isReversed(e)?m.reverse():m;else{for(y=[new Array(x)],r=0;r<x;r++)m=o[s[r]][0],y[0][i.isReversed(e)?x-r-1:r]=m;x=1}return e._lgroupsLength=x,y}},{\"../../registry\":847,\"./helpers\":648}],647:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=!0;e.exports=function(t,e,r){var o=e._fullLayout;if(!e._dragged&&!e._editing){var s,l=o.legend.itemclick,c=o.legend.itemdoubleclick;if(1===r&&\"toggle\"===l&&\"toggleothers\"===c&&a&&e.data&&e._context.showTips?(n.notifier(n._(e,\"Double-click on legend to isolate one trace\"),\"long\"),a=!1):a=!1,1===r?s=l:2===r&&(s=c),s){var u,h,f,p,d,g=o.hiddenlabels?o.hiddenlabels.slice():[],v=t.data()[0][0],m=e._fullData,y=v.trace,x=y.legendgroup,b={},_=[],w=[],k=[];if(i.traceIs(y,\"pie-like\")){var T=v.label,A=g.indexOf(T);\"toggle\"===s?-1===A?g.push(T):g.splice(A,1):\"toggleothers\"===s&&(g=[],e.calcdata[0].forEach(function(t){T!==t.label&&g.push(t.label)}),e._fullLayout.hiddenlabels&&e._fullLayout.hiddenlabels.length===g.length&&-1===A&&(g=[])),i.call(\"_guiRelayout\",e,\"hiddenlabels\",g)}else{var M,S=x&&x.length,E=[];if(S)for(u=0;u<m.length;u++)(M=m[u]).visible&&M.legendgroup===x&&E.push(u);if(\"toggle\"===s){var C;switch(y.visible){case!0:C=\"legendonly\";break;case!1:C=!1;break;case\"legendonly\":C=!0}if(S)for(u=0;u<m.length;u++)!1!==m[u].visible&&m[u].legendgroup===x&&R(m[u],C);else R(y,C)}else if(\"toggleothers\"===s){var L,P,O=!0;for(u=0;u<m.length;u++)if(!(m[u]===y)&&!(L=S&&m[u].legendgroup===x)&&!0===m[u].visible&&!i.traceIs(m[u],\"notLegendIsolatable\")){O=!1;break}for(u=0;u<m.length;u++)if(!1!==m[u].visible&&!i.traceIs(m[u],\"notLegendIsolatable\"))switch(y.visible){case\"legendonly\":R(m[u],!0);break;case!0:P=!!O||\"legendonly\",L=m[u]===y||S&&m[u].legendgroup===x,R(m[u],!!L||P)}}for(u=0;u<w.length;u++)if(f=w[u]){var z=f.constructUpdate(),I=Object.keys(z);for(h=0;h<I.length;h++)p=I[h],(b[p]=b[p]||[])[k[u]]=z[p]}for(d=Object.keys(b),u=0;u<d.length;u++)for(p=d[u],h=0;h<_.length;h++)b[p].hasOwnProperty(h)||(b[p][h]=void 0);i.call(\"_guiRestyle\",e,b,_)}}}function D(t,e,r){var n=_.indexOf(t),i=b[e];return i||(i=b[e]=[]),-1===_.indexOf(t)&&(_.push(t),n=_.length-1),i[n]=r,n}function R(t,e){var r=t._fullInput;if(i.hasTransform(r,\"groupby\")){var a=w[r.index];if(!a){var o=i.getTransformIndices(r,\"groupby\"),s=o[o.length-1];a=n.keyedContainer(r,\"transforms[\"+s+\"].styles\",\"target\",\"value.visible\"),w[r.index]=a}var l=a.get(t._group);void 0===l&&(l=!0),!1!==l&&a.set(t._group,e),k[r.index]=D(r.index,\"visible\",!1!==r.visible)}else{var c=!1!==r.visible&&e;D(r.index,\"visible\",c)}}}},{\"../../lib\":719,\"../../registry\":847}],648:[function(t,e,r){\"use strict\";r.isGrouped=function(t){return-1!==(t.traceorder||\"\").indexOf(\"grouped\")},r.isVertical=function(t){return\"h\"!==t.orientation},r.isReversed=function(t){return-1!==(t.traceorder||\"\").indexOf(\"reversed\")}},{}],649:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"legend\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\"),style:t(\"./style\")}},{\"./attributes\":642,\"./defaults\":644,\"./draw\":645,\"./style\":650}],650:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../drawing\"),s=t(\"../color\"),l=t(\"../../traces/scatter/subtypes\"),c=t(\"../../traces/pie/style_one\"),u=t(\"../../traces/pie/helpers\").castOption,h=12,f=5,p=2,d=10,g=5;e.exports=function(t,e){var r=e._fullLayout.legend,v=\"constant\"===r.itemsizing;function m(t,e,r,n){var i;if(t+1)i=t;else{if(!(e&&e.width>0))return 0;i=e.width}return v?n:Math.min(i,r)}function y(t,e,r){var a=t[0].trace,o=a.marker||{},l=o.line||{},c=r?a.type===r&&a.visible:i.traceIs(a,\"bar\"),u=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(c?[t]:[]);u.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),u.exit().remove(),u.each(function(t){var e=n.select(this),r=t[0],i=m(r.mlw,o.line,g,p);e.style(\"stroke-width\",i+\"px\").call(s.fill,r.mc||o.color),i&&s.stroke(e,r.mlc||l.color)})}function x(t,e,r){var o=t[0],s=o.trace,l=r?s.type===r&&s.visible:i.traceIs(s,r),h=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(l?[t]:[]);if(h.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),h.exit().remove(),h.size()){var f=(s.marker||{}).line,d=m(u(f.width,o.pts),f,g,p),v=a.minExtend(s,{marker:{line:{width:d}}});v.marker.line.color=f.color;var y=a.minExtend(o,{trace:v});c(h,y,v)}}t.each(function(t){var e=n.select(this),i=a.ensureSingle(e,\"g\",\"layers\");i.style(\"opacity\",t[0].trace.opacity);var o=r.valign,s=t[0].lineHeight,l=t[0].height;if(\"middle\"!==o&&s&&l){var c={top:1,bottom:-1}[o]*(.5*(s-l+3));i.attr(\"transform\",\"translate(0,\"+c+\")\")}else i.attr(\"transform\",null);i.selectAll(\"g.legendfill\").data([t]).enter().append(\"g\").classed(\"legendfill\",!0),i.selectAll(\"g.legendlines\").data([t]).enter().append(\"g\").classed(\"legendlines\",!0);var u=i.selectAll(\"g.legendsymbols\").data([t]);u.enter().append(\"g\").classed(\"legendsymbols\",!0),u.selectAll(\"g.legendpoints\").data([t]).enter().append(\"g\").classed(\"legendpoints\",!0)}).each(function(t){var e=t[0].trace,r=[];\"waterfall\"===e.type&&e.visible&&(r=t[0].hasTotals?[[\"increasing\",\"M-6,-6V6H0Z\"],[\"totals\",\"M6,6H0L-6,-6H-0Z\"],[\"decreasing\",\"M6,6V-6H0Z\"]]:[[\"increasing\",\"M-6,-6V6H6Z\"],[\"decreasing\",\"M6,6V-6H-6Z\"]]);var i=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendwaterfall\").data(r);i.enter().append(\"path\").classed(\"legendwaterfall\",!0).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),i.exit().remove(),i.each(function(t){var r=n.select(this),i=e[t[0]].marker,a=m(void 0,i.line,g,p);r.attr(\"d\",t[1]).style(\"stroke-width\",a+\"px\").call(s.fill,i.color),a&&r.call(s.stroke,i.line.color)})}).each(function(t){y(t,this,\"funnel\")}).each(function(t){y(t,this)}).each(function(t){var r=t[0].trace,l=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendbox\").data(i.traceIs(r,\"box-violin\")&&r.visible?[t]:[]);l.enter().append(\"path\").classed(\"legendbox\",!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),l.exit().remove(),l.each(function(){var t=n.select(this);if(\"all\"!==r.boxpoints&&\"all\"!==r.points||0!==s.opacity(r.fillcolor)||0!==s.opacity((r.line||{}).color)){var i=m(void 0,r.line,g,p);t.style(\"stroke-width\",i+\"px\").call(s.fill,r.fillcolor),i&&s.stroke(t,r.line.color)}else{var c=a.minExtend(r,{marker:{size:v?h:a.constrain(r.marker.size,2,16),sizeref:1,sizemin:1,sizemode:\"diameter\"}});l.call(o.pointStyle,c,e)}})}).each(function(t){x(t,this,\"funnelarea\")}).each(function(t){x(t,this,\"pie\")}).each(function(t){var r,i,s=t[0],c=s.trace,u=c.visible&&c.fill&&\"none\"!==c.fill,h=l.hasLines(c),p=c.contours,g=!1,v=!1;if(p){var y=p.coloring;\"lines\"===y?g=!0:h=\"none\"===y||\"heatmap\"===y||p.showlines,\"constraint\"===p.type?u=\"=\"!==p._operation:\"fill\"!==y&&\"heatmap\"!==y||(v=!0)}var x=l.hasMarkers(c)||l.hasText(c),b=u||v,_=h||g,w=x||!b?\"M5,0\":_?\"M5,-2\":\"M5,-3\",k=n.select(this),T=k.select(\".legendfill\").selectAll(\"path\").data(u||v?[t]:[]);if(T.enter().append(\"path\").classed(\"js-fill\",!0),T.exit().remove(),T.attr(\"d\",w+\"h30v6h-30z\").call(u?o.fillGroupStyle:function(t){if(t.size()){var r=\"legendfill-\"+c.uid;o.gradient(t,e,r,\"horizontalreversed\",c.colorscale,\"fill\")}}),h||g){var A=m(void 0,c.line,d,f);i=a.minExtend(c,{line:{width:A}}),r=[a.minExtend(s,{trace:i})]}var M=k.select(\".legendlines\").selectAll(\"path\").data(h||g?[r]:[]);M.enter().append(\"path\").classed(\"js-line\",!0),M.exit().remove(),M.attr(\"d\",w+(g?\"l30,0.0001\":\"h30\")).call(h?o.lineGroupStyle:function(t){if(t.size()){var r=\"legendline-\"+c.uid;o.lineGroupStyle(t),o.gradient(t,e,r,\"horizontalreversed\",c.colorscale,\"stroke\")}})}).each(function(t){var r,i,s=t[0],c=s.trace,u=l.hasMarkers(c),d=l.hasText(c),g=l.hasLines(c);function m(t,e,r,n){var i=a.nestedProperty(c,t).get(),o=a.isArrayOrTypedArray(i)&&e?e(i):i;if(v&&o&&void 0!==n&&(o=n),r){if(o<r[0])return r[0];if(o>r[1])return r[1]}return o}function y(t){return t[0]}if(u||d||g){var x={},b={};if(u){x.mc=m(\"marker.color\",y),x.mx=m(\"marker.symbol\",y),x.mo=m(\"marker.opacity\",a.mean,[.2,1]),x.mlc=m(\"marker.line.color\",y),x.mlw=m(\"marker.line.width\",a.mean,[0,5],p),b.marker={sizeref:1,sizemin:1,sizemode:\"diameter\"};var _=m(\"marker.size\",a.mean,[2,16],h);x.ms=_,b.marker.size=_}g&&(b.line={width:m(\"line.width\",y,[0,10],f)}),d&&(x.tx=\"Aa\",x.tp=m(\"textposition\",y),x.ts=10,x.tc=m(\"textfont.color\",y),x.tf=m(\"textfont.family\",y)),r=[a.minExtend(s,x)],(i=a.minExtend(c,b)).selectedpoints=null}var w=n.select(this).select(\"g.legendpoints\"),k=w.selectAll(\"path.scatterpts\").data(u?r:[]);k.enter().insert(\"path\",\":first-child\").classed(\"scatterpts\",!0).attr(\"transform\",\"translate(20,0)\"),k.exit().remove(),k.call(o.pointStyle,i,e),u&&(r[0].mrc=3);var T=w.selectAll(\"g.pointtext\").data(d?r:[]);T.enter().append(\"g\").classed(\"pointtext\",!0).append(\"text\").attr(\"transform\",\"translate(20,0)\"),T.exit().remove(),T.selectAll(\"text\").call(o.textPointStyle,i,e)}).each(function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendcandle\").data(\"candlestick\"===e.type&&e.visible?[t,t]:[]);r.enter().append(\"path\").classed(\"legendcandle\",!0).attr(\"d\",function(t,e){return e?\"M-15,0H-8M-8,6V-6H8Z\":\"M15,0H8M8,-6V6H-8Z\"}).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),r.exit().remove(),r.each(function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],o=m(void 0,a.line,g,p);i.style(\"stroke-width\",o+\"px\").call(s.fill,a.fillcolor),o&&s.stroke(i,a.line.color)})}).each(function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendohlc\").data(\"ohlc\"===e.type&&e.visible?[t,t]:[]);r.enter().append(\"path\").classed(\"legendohlc\",!0).attr(\"d\",function(t,e){return e?\"M-15,0H0M-8,-6V0\":\"M15,0H0M8,6V0\"}).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),r.exit().remove(),r.each(function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],l=m(void 0,a.line,g,p);i.style(\"fill\",\"none\").call(o.dashLine,a.line.dash,l),l&&s.stroke(i,a.line.color)})})}},{\"../../lib\":719,\"../../registry\":847,\"../../traces/pie/helpers\":1091,\"../../traces/pie/style_one\":1097,\"../../traces/scatter/subtypes\":1135,\"../color\":593,\"../drawing\":614,d3:163}],651:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/plots\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../lib\"),s=t(\"../../fonts/ploticon\"),l=o._,c=e.exports={};function u(t,e){var r,i,o=e.currentTarget,s=o.getAttribute(\"data-attr\"),l=o.getAttribute(\"data-val\")||!0,c=t._fullLayout,u={},h=a.list(t,null,!0),f=\"on\";if(\"zoom\"===s){var p,d=\"in\"===l?.5:2,g=(1+d)/2,v=(1-d)/2;for(i=0;i<h.length;i++)if(!(r=h[i]).fixedrange)if(p=r._name,\"auto\"===l)u[p+\".autorange\"]=!0;else if(\"reset\"===l){if(void 0===r._rangeInitial)u[p+\".autorange\"]=!0;else{var m=r._rangeInitial.slice();u[p+\".range[0]\"]=m[0],u[p+\".range[1]\"]=m[1]}void 0!==r._showSpikeInitial&&(u[p+\".showspikes\"]=r._showSpikeInitial,\"on\"!==f||r._showSpikeInitial||(f=\"off\"))}else{var y=[r.r2l(r.range[0]),r.r2l(r.range[1])],x=[g*y[0]+v*y[1],g*y[1]+v*y[0]];u[p+\".range[0]\"]=r.l2r(x[0]),u[p+\".range[1]\"]=r.l2r(x[1])}c._cartesianSpikesEnabled=f}else{if(\"hovermode\"!==s||\"x\"!==l&&\"y\"!==l){if(\"hovermode\"===s&&\"closest\"===l){for(i=0;i<h.length;i++)r=h[i],\"on\"!==f||r.showspikes||(f=\"off\");c._cartesianSpikesEnabled=f}}else l=c._isHoriz?\"y\":\"x\",o.setAttribute(\"data-val\",l);u[s]=l}n.call(\"_guiRelayout\",t,u)}function h(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout._subplots.gl3d,s={},l=i.split(\".\"),c=0;c<o.length;c++)s[o[c]+\".\"+l[1]]=a;var u=\"pan\"===a?a:\"zoom\";s.dragmode=u,n.call(\"_guiRelayout\",t,s)}function f(t,e){for(var r=e.currentTarget.getAttribute(\"data-attr\"),i=t._fullLayout,a=i._subplots.gl3d,o={},s=0;s<a.length;s++){var l=a[s],c=l+\".camera\",u=i[l]._scene;\"resetLastSave\"===r?(o[c+\".up\"]=u.viewInitial.up,o[c+\".eye\"]=u.viewInitial.eye,o[c+\".center\"]=u.viewInitial.center):\"resetDefault\"===r&&(o[c+\".up\"]=null,o[c+\".eye\"]=null,o[c+\".center\"]=null)}n.call(\"_guiRelayout\",t,o)}function p(t,e){var r=e.currentTarget,n=r._previousVal,i=t._fullLayout,a=i._subplots.gl3d,o=[\"xaxis\",\"yaxis\",\"zaxis\"],s={},l={};if(n)l=n,r._previousVal=null;else{for(var c=0;c<a.length;c++){var u=a[c],h=i[u],f=u+\".hovermode\";s[f]=h.hovermode,l[f]=!1;for(var p=0;p<3;p++){var d=o[p],g=u+\".\"+d+\".showspikes\";l[g]=!1,s[g]=h[d].showspikes}}r._previousVal=s}return l}function d(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout,s=o._subplots.geo,l=0;l<s.length;l++){var c=s[l],u=o[c];if(\"zoom\"===i){var h=u.projection.scale,f=\"in\"===a?2*h:.5*h;n.call(\"_guiRelayout\",t,c+\".projection.scale\",f)}else\"reset\"===i&&m(t,\"geo\")}}function g(t){var e=t._fullLayout;return!e.hovermode&&(e._has(\"cartesian\")?e._isHoriz?\"y\":\"x\":\"closest\")}function v(t){var e=g(t);n.call(\"_guiRelayout\",t,\"hovermode\",e)}function m(t,e){for(var r=t._fullLayout,i=r._subplots[e],a={},o=0;o<i.length;o++)for(var s=i[o],l=r[s]._subplot.viewInitial,c=Object.keys(l),u=0;u<c.length;u++){var h=c[u];a[s+\".\"+h]=l[h]}n.call(\"_guiRelayout\",t,a)}c.toImage={name:\"toImage\",title:function(t){var e=(t._context.toImageButtonOptions||{}).format||\"png\";return l(t,\"png\"===e?\"Download plot as a png\":\"Download plot\")},icon:s.camera,click:function(t){var e=t._context.toImageButtonOptions,r={format:e.format||\"png\"};o.notifier(l(t,\"Taking snapshot - this may take a few seconds\"),\"long\"),\"svg\"!==r.format&&o.isIE()&&(o.notifier(l(t,\"IE only supports svg.  Changing format to svg.\"),\"long\"),r.format=\"svg\"),[\"filename\",\"width\",\"height\",\"scale\"].forEach(function(t){t in e&&(r[t]=e[t])}),n.call(\"downloadImage\",t,r).then(function(e){o.notifier(l(t,\"Snapshot succeeded\")+\" - \"+e,\"long\")}).catch(function(){o.notifier(l(t,\"Sorry, there was a problem downloading your snapshot!\"),\"long\")})}},c.sendDataToCloud={name:\"sendDataToCloud\",title:function(t){return l(t,\"Edit in Chart Studio\")},icon:s.disk,click:function(t){i.sendDataToCloud(t)}},c.editInChartStudio={name:\"editInChartStudio\",title:function(t){return l(t,\"Edit in Chart Studio\")},icon:s.pencil,click:function(t){i.sendDataToCloud(t)}},c.zoom2d={name:\"zoom2d\",title:function(t){return l(t,\"Zoom\")},attr:\"dragmode\",val:\"zoom\",icon:s.zoombox,click:u},c.pan2d={name:\"pan2d\",title:function(t){return l(t,\"Pan\")},attr:\"dragmode\",val:\"pan\",icon:s.pan,click:u},c.select2d={name:\"select2d\",title:function(t){return l(t,\"Box Select\")},attr:\"dragmode\",val:\"select\",icon:s.selectbox,click:u},c.lasso2d={name:\"lasso2d\",title:function(t){return l(t,\"Lasso Select\")},attr:\"dragmode\",val:\"lasso\",icon:s.lasso,click:u},c.zoomIn2d={name:\"zoomIn2d\",title:function(t){return l(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:s.zoom_plus,click:u},c.zoomOut2d={name:\"zoomOut2d\",title:function(t){return l(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:s.zoom_minus,click:u},c.autoScale2d={name:\"autoScale2d\",title:function(t){return l(t,\"Autoscale\")},attr:\"zoom\",val:\"auto\",icon:s.autoscale,click:u},c.resetScale2d={name:\"resetScale2d\",title:function(t){return l(t,\"Reset axes\")},attr:\"zoom\",val:\"reset\",icon:s.home,click:u},c.hoverClosestCartesian={name:\"hoverClosestCartesian\",title:function(t){return l(t,\"Show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:s.tooltip_basic,gravity:\"ne\",click:u},c.hoverCompareCartesian={name:\"hoverCompareCartesian\",title:function(t){return l(t,\"Compare data on hover\")},attr:\"hovermode\",val:function(t){return t._fullLayout._isHoriz?\"y\":\"x\"},icon:s.tooltip_compare,gravity:\"ne\",click:u},c.zoom3d={name:\"zoom3d\",title:function(t){return l(t,\"Zoom\")},attr:\"scene.dragmode\",val:\"zoom\",icon:s.zoombox,click:h},c.pan3d={name:\"pan3d\",title:function(t){return l(t,\"Pan\")},attr:\"scene.dragmode\",val:\"pan\",icon:s.pan,click:h},c.orbitRotation={name:\"orbitRotation\",title:function(t){return l(t,\"Orbital rotation\")},attr:\"scene.dragmode\",val:\"orbit\",icon:s[\"3d_rotate\"],click:h},c.tableRotation={name:\"tableRotation\",title:function(t){return l(t,\"Turntable rotation\")},attr:\"scene.dragmode\",val:\"turntable\",icon:s[\"z-axis\"],click:h},c.resetCameraDefault3d={name:\"resetCameraDefault3d\",title:function(t){return l(t,\"Reset camera to default\")},attr:\"resetDefault\",icon:s.home,click:f},c.resetCameraLastSave3d={name:\"resetCameraLastSave3d\",title:function(t){return l(t,\"Reset camera to last save\")},attr:\"resetLastSave\",icon:s.movie,click:f},c.hoverClosest3d={name:\"hoverClosest3d\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=p(t,e);n.call(\"_guiRelayout\",t,r)}},c.zoomInGeo={name:\"zoomInGeo\",title:function(t){return l(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:s.zoom_plus,click:d},c.zoomOutGeo={name:\"zoomOutGeo\",title:function(t){return l(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:s.zoom_minus,click:d},c.resetGeo={name:\"resetGeo\",title:function(t){return l(t,\"Reset\")},attr:\"reset\",val:null,icon:s.autoscale,click:d},c.hoverClosestGeo={name:\"hoverClosestGeo\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:v},c.hoverClosestGl2d={name:\"hoverClosestGl2d\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:v},c.hoverClosestPie={name:\"hoverClosestPie\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:s.tooltip_basic,gravity:\"ne\",click:v},c.resetViewSankey={name:\"resetSankeyGroup\",title:function(t){return l(t,\"Reset view\")},icon:s.home,click:function(t){for(var e={\"node.groups\":[],\"node.x\":[],\"node.y\":[]},r=0;r<t._fullData.length;r++){var i=t._fullData[r]._viewInitial;e[\"node.groups\"].push(i.node.groups.slice()),e[\"node.x\"].push(i.node.x.slice()),e[\"node.y\"].push(i.node.y.slice())}n.call(\"restyle\",t,e)}},c.toggleHover={name:\"toggleHover\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=p(t,e);r.hovermode=g(t),n.call(\"_guiRelayout\",t,r)}},c.resetViews={name:\"resetViews\",title:function(t){return l(t,\"Reset views\")},icon:s.home,click:function(t,e){var r=e.currentTarget;r.setAttribute(\"data-attr\",\"zoom\"),r.setAttribute(\"data-val\",\"reset\"),u(t,e),r.setAttribute(\"data-attr\",\"resetLastSave\"),f(t,e),m(t,\"geo\"),m(t,\"mapbox\")}},c.toggleSpikelines={name:\"toggleSpikelines\",title:function(t){return l(t,\"Toggle Spike Lines\")},icon:s.spikeline,attr:\"_cartesianSpikesEnabled\",val:\"on\",click:function(t){var e=t._fullLayout;e._cartesianSpikesEnabled=\"on\"===e._cartesianSpikesEnabled?\"off\":\"on\";var r=function(t){for(var e,r,n=t._fullLayout,i=a.list(t,null,!0),o={},s=0;s<i.length;s++)e=i[s],r=e._name,o[r+\".showspikes\"]=\"on\"===n._cartesianSpikesEnabled||e._showSpikeInitial;return o}(t);n.call(\"_guiRelayout\",t,r)}},c.resetViewMapbox={name:\"resetViewMapbox\",title:function(t){return l(t,\"Reset view\")},attr:\"reset\",icon:s.home,click:function(t){m(t,\"mapbox\")}}},{\"../../fonts/ploticon\":699,\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../../plots/plots\":828,\"../../registry\":847}],652:[function(t,e,r){\"use strict\";r.manage=t(\"./manage\")},{\"./manage\":653}],653:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"../../traces/scatter/subtypes\"),a=t(\"../../registry\"),o=t(\"./modebar\"),s=t(\"./buttons\");e.exports=function(t){var e=t._fullLayout,r=t._context,l=e._modeBar;if(r.displayModeBar||r.watermark){if(!Array.isArray(r.modeBarButtonsToRemove))throw new Error([\"*modeBarButtonsToRemove* configuration options\",\"must be an array.\"].join(\" \"));if(!Array.isArray(r.modeBarButtonsToAdd))throw new Error([\"*modeBarButtonsToAdd* configuration options\",\"must be an array.\"].join(\" \"));var c,u=r.modeBarButtons;c=Array.isArray(u)&&u.length?function(t){for(var e=0;e<t.length;e++)for(var r=t[e],n=0;n<r.length;n++){var i=r[n];if(\"string\"==typeof i){if(void 0===s[i])throw new Error([\"*modeBarButtons* configuration options\",\"invalid button name\"].join(\" \"));t[e][n]=s[i]}}return t}(u):!r.displayModeBar&&r.watermark?[]:function(t){var e=t._fullLayout,r=t._fullData,o=t._context,l=o.modeBarButtonsToRemove,c=o.modeBarButtonsToAdd,u=e._has(\"cartesian\"),h=e._has(\"gl3d\"),f=e._has(\"geo\"),p=e._has(\"pie\"),d=e._has(\"funnelarea\"),g=e._has(\"gl2d\"),v=e._has(\"ternary\"),m=e._has(\"mapbox\"),y=e._has(\"polar\"),x=e._has(\"sankey\"),b=function(t){for(var e=n.list({_fullLayout:t},null,!0),r=0;r<e.length;r++)if(!e[r].fixedrange)return!1;return!0}(e),_=[];function w(t){if(t.length){for(var e=[],r=0;r<t.length;r++){var n=t[r];-1===l.indexOf(n)&&e.push(s[n])}_.push(e)}}var k=[\"toImage\"];o.showEditInChartStudio?k.push(\"editInChartStudio\"):o.showSendToCloud&&k.push(\"sendDataToCloud\");w(k);var T=[],A=[],M=[],S=[];(u||g||p||d||v)+f+h+m+y>1?(A=[\"toggleHover\"],M=[\"resetViews\"]):f?(T=[\"zoomInGeo\",\"zoomOutGeo\"],A=[\"hoverClosestGeo\"],M=[\"resetGeo\"]):h?(A=[\"hoverClosest3d\"],M=[\"resetCameraDefault3d\",\"resetCameraLastSave3d\"]):m?(A=[\"toggleHover\"],M=[\"resetViewMapbox\"]):g?A=[\"hoverClosestGl2d\"]:p?A=[\"hoverClosestPie\"]:x?(A=[\"hoverClosestCartesian\",\"hoverCompareCartesian\"],M=[\"resetViewSankey\"]):A=[\"toggleHover\"];u&&(A=[\"toggleSpikelines\",\"hoverClosestCartesian\",\"hoverCompareCartesian\"]);(function(t){for(var e=0;e<t.length;e++)if(!a.traceIs(t[e],\"noHover\"))return!1;return!0})(r)&&(A=[]);!u&&!g||b||(T=[\"zoomIn2d\",\"zoomOut2d\",\"autoScale2d\"],\"resetViews\"!==M[0]&&(M=[\"resetScale2d\"]));h?S=[\"zoom3d\",\"pan3d\",\"orbitRotation\",\"tableRotation\"]:(u||g)&&!b||v?S=[\"zoom2d\",\"pan2d\"]:m||f?S=[\"pan2d\"]:y&&(S=[\"zoom2d\"]);(function(t){for(var e=!1,r=0;r<t.length&&!e;r++){var n=t[r];n._module&&n._module.selectPoints&&(a.traceIs(n,\"scatter-like\")?(i.hasMarkers(n)||i.hasText(n))&&(e=!0):a.traceIs(n,\"box-violin\")&&\"all\"!==n.boxpoints&&\"all\"!==n.points||(e=!0))}return e})(r)&&S.push(\"select2d\",\"lasso2d\");return w(S),w(T.concat(M)),w(A),function(t,e){if(e.length)if(Array.isArray(e[0]))for(var r=0;r<e.length;r++)t.push(e[r]);else t.push(e);return t}(_,c)}(t),l?l.update(t,c):e._modeBar=o(t,c)}else l&&(l.destroy(),delete e._modeBar)}},{\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../../traces/scatter/subtypes\":1135,\"./buttons\":651,\"./modebar\":654}],654:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../fonts/ploticon\"),s=new DOMParser;function l(t){this.container=t.container,this.element=document.createElement(\"div\"),this.update(t.graphInfo,t.buttons),this.container.appendChild(this.element)}var c=l.prototype;c.update=function(t,e){this.graphInfo=t;var r=this.graphInfo._context,n=this.graphInfo._fullLayout,i=\"modebar-\"+n._uid;this.element.setAttribute(\"id\",i),this._uid=i,this.element.className=\"modebar\",\"hover\"===r.displayModeBar&&(this.element.className+=\" modebar--hover ease-bg\"),\"v\"===n.modebar.orientation&&(this.element.className+=\" vertical\",e=e.reverse());var o=n.modebar,s=\"hover\"===r.displayModeBar?\".js-plotly-plot .plotly:hover \":\"\";a.deleteRelatedStyleRule(i),a.addRelatedStyleRule(i,s+\"#\"+i+\" .modebar-group\",\"background-color: \"+o.bgcolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn .icon path\",\"fill: \"+o.color),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn:hover .icon path\",\"fill: \"+o.activecolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn.active .icon path\",\"fill: \"+o.activecolor);var l=!this.hasButtons(e),c=this.hasLogo!==r.displaylogo,u=this.locale!==r.locale;if(this.locale=r.locale,(l||c||u)&&(this.removeAllButtons(),this.updateButtons(e),r.watermark||r.displaylogo)){var h=this.getLogo();r.watermark&&(h.className=h.className+\" watermark\"),\"v\"===n.modebar.orientation?this.element.insertBefore(h,this.element.childNodes[0]):this.element.appendChild(h),this.hasLogo=!0}this.updateActiveButton()},c.updateButtons=function(t){var e=this;this.buttons=t,this.buttonElements=[],this.buttonsNames=[],this.buttons.forEach(function(t){var r=e.createGroup();t.forEach(function(t){var n=t.name;if(!n)throw new Error(\"must provide button 'name' in button config\");if(-1!==e.buttonsNames.indexOf(n))throw new Error(\"button name '\"+n+\"' is taken\");e.buttonsNames.push(n);var i=e.createButton(t);e.buttonElements.push(i),r.appendChild(i)}),e.element.appendChild(r)})},c.createGroup=function(){var t=document.createElement(\"div\");return t.className=\"modebar-group\",t},c.createButton=function(t){var e=this,r=document.createElement(\"a\");r.setAttribute(\"rel\",\"tooltip\"),r.className=\"modebar-btn\";var i=t.title;void 0===i?i=t.name:\"function\"==typeof i&&(i=i(this.graphInfo)),(i||0===i)&&r.setAttribute(\"data-title\",i),void 0!==t.attr&&r.setAttribute(\"data-attr\",t.attr);var a=t.val;if(void 0!==a&&(\"function\"==typeof a&&(a=a(this.graphInfo)),r.setAttribute(\"data-val\",a)),\"function\"!=typeof t.click)throw new Error(\"must provide button 'click' function in button config\");r.addEventListener(\"click\",function(r){t.click(e.graphInfo,r),e.updateActiveButton(r.currentTarget)}),r.setAttribute(\"data-toggle\",t.toggle||!1),t.toggle&&n.select(r).classed(\"active\",!0);var s=t.icon;return\"function\"==typeof s?r.appendChild(s()):r.appendChild(this.createIcon(s||o.question)),r.setAttribute(\"data-gravity\",t.gravity||\"n\"),r},c.createIcon=function(t){var e,r=i(t.height)?Number(t.height):t.ascent-t.descent,n=\"http://www.w3.org/2000/svg\";if(t.path){(e=document.createElementNS(n,\"svg\")).setAttribute(\"viewBox\",[0,0,t.width,r].join(\" \")),e.setAttribute(\"class\",\"icon\");var a=document.createElementNS(n,\"path\");a.setAttribute(\"d\",t.path),t.transform?a.setAttribute(\"transform\",t.transform):void 0!==t.ascent&&a.setAttribute(\"transform\",\"matrix(1 0 0 -1 0 \"+t.ascent+\")\"),e.appendChild(a)}t.svg&&(e=s.parseFromString(t.svg,\"application/xml\").childNodes[0]);return e.setAttribute(\"height\",\"1em\"),e.setAttribute(\"width\",\"1em\"),e},c.updateActiveButton=function(t){var e=this.graphInfo._fullLayout,r=void 0!==t?t.getAttribute(\"data-attr\"):null;this.buttonElements.forEach(function(t){var i=t.getAttribute(\"data-val\")||!0,o=t.getAttribute(\"data-attr\"),s=\"true\"===t.getAttribute(\"data-toggle\"),l=n.select(t);if(s)o===r&&l.classed(\"active\",!l.classed(\"active\"));else{var c=null===o?o:a.nestedProperty(e,o).get();l.classed(\"active\",c===i)}})},c.hasButtons=function(t){var e=this.buttons;if(!e)return!1;if(t.length!==e.length)return!1;for(var r=0;r<t.length;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;n++)if(t[r][n].name!==e[r][n].name)return!1}return!0},c.getLogo=function(){var t=this.createGroup(),e=document.createElement(\"a\");return e.href=\"https://plot.ly/\",e.target=\"_blank\",e.setAttribute(\"data-title\",a._(this.graphInfo,\"Produced with Plotly\")),e.className=\"modebar-btn plotlyjsicon modebar-btn--logo\",e.appendChild(this.createIcon(o.newplotlylogo)),t.appendChild(e),t},c.removeAllButtons=function(){for(;this.element.firstChild;)this.element.removeChild(this.element.firstChild);this.hasLogo=!1},c.destroy=function(){a.removeElement(this.container.querySelector(\".modebar\")),a.deleteRelatedStyleRule(this._uid)},e.exports=function(t,e){var r=t._fullLayout,i=new l({graphInfo:t,container:r._modebardiv.node(),buttons:e});return r._privateplot&&n.select(i.element).append(\"span\").classed(\"badge-private float--left\",!0).text(\"PRIVATE\"),i}},{\"../../fonts/ploticon\":699,\"../../lib\":719,d3:163,\"fast-isnumeric\":225}],655:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=(0,t(\"../../plot_api/plot_template\").templatedArray)(\"button\",{visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},step:{valType:\"enumerated\",values:[\"month\",\"year\",\"day\",\"hour\",\"minute\",\"second\",\"all\"],dflt:\"month\",editType:\"plot\"},stepmode:{valType:\"enumerated\",values:[\"backward\",\"todate\"],dflt:\"backward\",editType:\"plot\"},count:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},label:{valType:\"string\",editType:\"plot\"},editType:\"plot\"});e.exports={visible:{valType:\"boolean\",editType:\"plot\"},buttons:a,x:{valType:\"number\",min:-2,max:3,editType:\"plot\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"plot\"},y:{valType:\"number\",min:-2,max:3,editType:\"plot\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"bottom\",editType:\"plot\"},font:n({editType:\"plot\"}),bgcolor:{valType:\"color\",dflt:i.lightLine,editType:\"plot\"},activecolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"plot\"}},{\"../../plot_api/plot_template\":757,\"../../plots/font_attributes\":793,\"../color/attributes\":592}],656:[function(t,e,r){\"use strict\";e.exports={yPad:.02,minButtonWidth:30,rx:3,ry:3,lightAmount:25,darkAmount:10}},{}],657:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../../plots/array_container_defaults\"),s=t(\"./attributes\"),l=t(\"./constants\");function c(t,e,r,i){var a=i.calendar;function o(r,i){return n.coerce(t,e,s.buttons,r,i)}if(o(\"visible\")){var l=o(\"step\");\"all\"!==l&&(!a||\"gregorian\"===a||\"month\"!==l&&\"year\"!==l?o(\"stepmode\"):e.stepmode=\"backward\",o(\"count\")),o(\"label\")}}e.exports=function(t,e,r,u,h){var f=t.rangeselector||{},p=a.newContainer(e,\"rangeselector\");function d(t,e){return n.coerce(f,p,s,t,e)}if(d(\"visible\",o(f,p,{name:\"buttons\",handleItemDefaults:c,calendar:h}).length>0)){var g=function(t,e,r){for(var n=r.filter(function(r){return e[r].anchor===t._id}),i=0,a=0;a<n.length;a++){var o=e[n[a]].domain;o&&(i=Math.max(o[1],i))}return[t.domain[0],i+l.yPad]}(e,r,u);d(\"x\",g[0]),d(\"y\",g[1]),n.noneOrAll(t,e,[\"x\",\"y\"]),d(\"xanchor\"),d(\"yanchor\"),n.coerceFont(d,\"font\",r.font);var v=d(\"bgcolor\");d(\"activecolor\",i.contrast(v,l.lightAmount,l.darkAmount)),d(\"bordercolor\"),d(\"borderwidth\")}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/array_container_defaults\":763,\"../color\":593,\"./attributes\":655,\"./constants\":656}],658:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../color\"),s=t(\"../drawing\"),l=t(\"../../lib\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"../../plots/cartesian/axis_ids\"),h=t(\"../../constants/alignment\"),f=h.LINE_SPACING,p=h.FROM_TL,d=h.FROM_BR,g=t(\"./constants\"),v=t(\"./get_update_object\");function m(t){return t._id}function y(t,e,r){var n=l.ensureSingle(t,\"rect\",\"selector-rect\",function(t){t.attr(\"shape-rendering\",\"crispEdges\")});n.attr({rx:g.rx,ry:g.ry}),n.call(o.stroke,e.bordercolor).call(o.fill,function(t,e){return e._isActive||e._isHovered?t.activecolor:t.bgcolor}(e,r)).style(\"stroke-width\",e.borderwidth+\"px\")}function x(t,e,r,n){l.ensureSingle(t,\"text\",\"selector-text\",function(t){t.classed(\"user-select-none\",!0).attr(\"text-anchor\",\"middle\")}).call(s.font,e.font).text(function(t,e){if(t.label)return e?l.templateString(t.label,e):t.label;return\"all\"===t.step?\"all\":t.count+t.step.charAt(0)}(r,n._fullLayout._meta)).call(function(t){c.convertToTspans(t,n)})}e.exports=function(t){var e=t._fullLayout._infolayer.selectAll(\".rangeselector\").data(function(t){for(var e=u.list(t,\"x\",!0),r=[],n=0;n<e.length;n++){var i=e[n];i.rangeselector&&i.rangeselector.visible&&r.push(i)}return r}(t),m);e.enter().append(\"g\").classed(\"rangeselector\",!0),e.exit().remove(),e.style({cursor:\"pointer\",\"pointer-events\":\"all\"}),e.each(function(e){var r=n.select(this),o=e,u=o.rangeselector,h=r.selectAll(\"g.button\").data(l.filterVisible(u.buttons));h.enter().append(\"g\").classed(\"button\",!0),h.exit().remove(),h.each(function(e){var r=n.select(this),a=v(o,e);e._isActive=function(t,e,r){if(\"all\"===e.step)return!0===t.autorange;var n=Object.keys(r);return t.range[0]===r[n[0]]&&t.range[1]===r[n[1]]}(o,e,a),r.call(y,u,e),r.call(x,u,e,t),r.on(\"click\",function(){t._dragged||i.call(\"_guiRelayout\",t,a)}),r.on(\"mouseover\",function(){e._isHovered=!0,r.call(y,u,e)}),r.on(\"mouseout\",function(){e._isHovered=!1,r.call(y,u,e)})}),function(t,e,r,i,o){var u=0,h=0,v=r.borderwidth;e.each(function(){var t=n.select(this),e=t.select(\".selector-text\"),i=r.font.size*f,a=Math.max(i*c.lineCount(e),16)+3;h=Math.max(h,a)}),e.each(function(){var t=n.select(this),e=t.select(\".selector-rect\"),i=t.select(\".selector-text\"),a=i.node()&&s.bBox(i.node()).width,o=r.font.size*f,l=c.lineCount(i),p=Math.max(a+10,g.minButtonWidth);t.attr(\"transform\",\"translate(\"+(v+u)+\",\"+v+\")\"),e.attr({x:0,y:0,width:p,height:h}),c.positionText(i,p/2,h/2-(l-1)*o/2+3),u+=p+5});var m=t._fullLayout._size,y=m.l+m.w*r.x,x=m.t+m.h*(1-r.y),b=\"left\";l.isRightAnchor(r)&&(y-=u,b=\"right\");l.isCenterAnchor(r)&&(y-=u/2,b=\"center\");var _=\"top\";l.isBottomAnchor(r)&&(x-=h,_=\"bottom\");l.isMiddleAnchor(r)&&(x-=h/2,_=\"middle\");u=Math.ceil(u),h=Math.ceil(h),y=Math.round(y),x=Math.round(x),a.autoMargin(t,i+\"-range-selector\",{x:r.x,y:r.y,l:u*p[b],r:u*d[b],b:h*d[_],t:h*p[_]}),o.attr(\"transform\",\"translate(\"+y+\",\"+x+\")\")}(t,h,u,o._name,r)})}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axis_ids\":770,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../drawing\":614,\"./constants\":656,\"./get_update_object\":659,d3:163}],659:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e){var r=t._name,i={};if(\"all\"===e.step)i[r+\".autorange\"]=!0;else{var a=function(t,e){var r,i=t.range,a=new Date(t.r2l(i[1])),o=e.step,s=e.count;switch(e.stepmode){case\"backward\":r=t.l2r(+n.time[o].utc.offset(a,-s));break;case\"todate\":var l=n.time[o].utc.offset(a,-s);r=t.l2r(+n.time[o].utc.ceil(l))}var c=i[1];return[r,c]}(t,e);i[r+\".range[0]\"]=a[0],i[r+\".range[1]\"]=a[1]}return i}},{d3:163}],660:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"rangeselector\",schema:{subplots:{xaxis:{rangeselector:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":655,\"./defaults\":657,\"./draw\":658}],661:[function(t,e,r){\"use strict\";var n=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",dflt:n.background,editType:\"plot\"},bordercolor:{valType:\"color\",dflt:n.defaultLine,editType:\"plot\"},borderwidth:{valType:\"integer\",dflt:0,min:0,editType:\"plot\"},autorange:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}}],editType:\"calc\",impliedEdits:{autorange:!1}},thickness:{valType:\"number\",dflt:.15,min:0,max:1,editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"}},{\"../color/attributes\":592}],662:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\").list,i=t(\"../../plots/cartesian/autorange\").getAutoRange,a=t(\"./constants\");e.exports=function(t){for(var e=n(t,\"x\",!0),r=0;r<e.length;r++){var o=e[r],s=o[a.name];s&&s.visible&&s.autorange&&(s._input.autorange=!0,s._input.range=s.range=i(t,o))}}},{\"../../plots/cartesian/autorange\":766,\"../../plots/cartesian/axis_ids\":770,\"./constants\":663}],663:[function(t,e,r){\"use strict\";e.exports={name:\"rangeslider\",containerClassName:\"rangeslider-container\",bgClassName:\"rangeslider-bg\",rangePlotClassName:\"rangeslider-rangeplot\",maskMinClassName:\"rangeslider-mask-min\",maskMaxClassName:\"rangeslider-mask-max\",slideBoxClassName:\"rangeslider-slidebox\",grabberMinClassName:\"rangeslider-grabber-min\",grabAreaMinClassName:\"rangeslider-grabarea-min\",handleMinClassName:\"rangeslider-handle-min\",grabberMaxClassName:\"rangeslider-grabber-max\",grabAreaMaxClassName:\"rangeslider-grabarea-max\",handleMaxClassName:\"rangeslider-handle-max\",maskMinOppAxisClassName:\"rangeslider-mask-min-opp-axis\",maskMaxOppAxisClassName:\"rangeslider-mask-max-opp-axis\",maskColor:\"rgba(0,0,0,0.4)\",maskOppAxisColor:\"rgba(0,0,0,0.2)\",slideBoxFill:\"transparent\",slideBoxCursor:\"ew-resize\",grabAreaFill:\"transparent\",grabAreaCursor:\"col-resize\",grabAreaWidth:10,handleWidth:4,handleRadius:1,handleStrokeWidth:1,extraPad:15}},{}],664:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"./attributes\"),s=t(\"./oppaxis_attributes\");e.exports=function(t,e,r){var l=t[r],c=e[r];if(l.rangeslider||e._requestRangeslider[c._id]){n.isPlainObject(l.rangeslider)||(l.rangeslider={});var u,h,f=l.rangeslider,p=i.newContainer(c,\"rangeslider\");if(_(\"visible\")){_(\"bgcolor\",e.plot_bgcolor),_(\"bordercolor\"),_(\"borderwidth\"),_(\"thickness\"),_(\"autorange\",!c.isValidRange(f.range)),_(\"range\");var d=e._subplots;if(d)for(var g=d.cartesian.filter(function(t){return t.substr(0,t.indexOf(\"y\"))===a.name2id(r)}).map(function(t){return t.substr(t.indexOf(\"y\"),t.length)}),v=n.simpleMap(g,a.id2name),m=0;m<v.length;m++){var y=v[m];u=f[y]||{},h=i.newContainer(p,y,\"yaxis\");var x,b=e[y];u.range&&b.isValidRange(u.range)&&(x=\"fixed\"),\"match\"!==w(\"rangemode\",x)&&w(\"range\",b.range.slice())}p._input=f}}function _(t,e){return n.coerce(f,p,o,t,e)}function w(t,e){return n.coerce(u,h,s,t,e)}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/axis_ids\":770,\"./attributes\":661,\"./oppaxis_attributes\":668}],665:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=t(\"../drawing\"),l=t(\"../color\"),c=t(\"../titles\"),u=t(\"../../plots/cartesian\"),h=t(\"../../plots/cartesian/axis_ids\"),f=t(\"../dragelement\"),p=t(\"../../lib/setcursor\"),d=t(\"./constants\");function g(t,e,r,n){var i=o.ensureSingle(t,\"rect\",d.bgClassName,function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})}),a=n.borderwidth%2==0?n.borderwidth:n.borderwidth-1,l=-n._offsetShift,c=s.crispRound(e,n.borderwidth);i.attr({width:n._width+a,height:n._height+a,transform:\"translate(\"+l+\",\"+l+\")\",fill:n.bgcolor,stroke:n.bordercolor,\"stroke-width\":c})}function v(t,e,r,n){var i=e._fullLayout;o.ensureSingleById(i._topdefs,\"clipPath\",n._clipId,function(t){t.append(\"rect\").attr({x:0,y:0})}).select(\"rect\").attr({width:n._width,height:n._height})}function m(t,e,r,i){var l,c=e.calcdata,f=t.selectAll(\"g.\"+d.rangePlotClassName).data(r._subplotsWith,o.identity);f.enter().append(\"g\").attr(\"class\",function(t){return d.rangePlotClassName+\" \"+t}).call(s.setClipUrl,i._clipId,e),f.order(),f.exit().remove(),f.each(function(t,o){var s=n.select(this),f=0===o,p=h.getFromId(e,t,\"y\"),d=p._name,g=i[d],v={data:[],layout:{xaxis:{type:r.type,domain:[0,1],range:i.range.slice(),calendar:r.calendar},width:i._width,height:i._height,margin:{t:0,b:0,l:0,r:0}},_context:e._context};v.layout[d]={type:p.type,domain:[0,1],range:\"match\"!==g.rangemode?g.range.slice():p.range.slice(),calendar:p.calendar},a.supplyDefaults(v);var m=v._fullLayout.xaxis,y=v._fullLayout[d];m.clearCalc(),m.setScale(),y.clearCalc(),y.setScale();var x={id:t,plotgroup:s,xaxis:m,yaxis:y,isRangePlot:!0};f?l=x:(x.mainplot=\"xy\",x.mainplotinfo=l),u.rangePlot(e,x,function(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n],a=i[0].trace;a.xaxis+a.yaxis===e&&r.push(i)}return r}(c,t))})}function y(t,e,r,n,i){(o.ensureSingle(t,\"rect\",d.maskMinClassName,function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"height\",n._height).call(l.fill,d.maskColor),o.ensureSingle(t,\"rect\",d.maskMaxClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"height\",n._height).call(l.fill,d.maskColor),\"match\"!==i.rangemode)&&(o.ensureSingle(t,\"rect\",d.maskMinOppAxisClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"width\",n._width).call(l.fill,d.maskOppAxisColor),o.ensureSingle(t,\"rect\",d.maskMaxOppAxisClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"width\",n._width).style(\"border-top\",d.maskOppBorder).call(l.fill,d.maskOppAxisColor))}function x(t,e,r,n){e._context.staticPlot||o.ensureSingle(t,\"rect\",d.slideBoxClassName,function(t){t.attr({y:0,cursor:d.slideBoxCursor,\"shape-rendering\":\"crispEdges\"})}).attr({height:n._height,fill:d.slideBoxFill})}function b(t,e,r,n){var i=o.ensureSingle(t,\"g\",d.grabberMinClassName),a=o.ensureSingle(t,\"g\",d.grabberMaxClassName),s={x:0,width:d.handleWidth,rx:d.handleRadius,fill:l.background,stroke:l.defaultLine,\"stroke-width\":d.handleStrokeWidth,\"shape-rendering\":\"crispEdges\"},c={y:Math.round(n._height/4),height:Math.round(n._height/2)};if(o.ensureSingle(i,\"rect\",d.handleMinClassName,function(t){t.attr(s)}).attr(c),o.ensureSingle(a,\"rect\",d.handleMaxClassName,function(t){t.attr(s)}).attr(c),!e._context.staticPlot){var u={width:d.grabAreaWidth,x:0,y:0,fill:d.grabAreaFill,cursor:d.grabAreaCursor};o.ensureSingle(i,\"rect\",d.grabAreaMinClassName,function(t){t.attr(u)}).attr(\"height\",n._height),o.ensureSingle(a,\"rect\",d.grabAreaMaxClassName,function(t){t.attr(u)}).attr(\"height\",n._height)}}e.exports=function(t){for(var e=t._fullLayout,r=e._rangeSliderData,a=0;a<r.length;a++){var s=r[a][d.name];s._clipId=s._id+\"-\"+e._uid}var l=e._infolayer.selectAll(\"g.\"+d.containerClassName).data(r,function(t){return t._name});l.exit().each(function(t){var r=t[d.name];e._topdefs.select(\"#\"+r._clipId).remove()}).remove(),0!==r.length&&(l.enter().append(\"g\").classed(d.containerClassName,!0).attr(\"pointer-events\",\"all\"),l.each(function(r){var a=n.select(this),s=r[d.name],l=e[h.id2name(r.anchor)],u=s[h.id2name(r.anchor)];if(s.range){var _,w=o.simpleMap(s.range,r.r2l),k=o.simpleMap(r.range,r.r2l);_=k[0]<k[1]?[Math.min(w[0],k[0]),Math.max(w[1],k[1])]:[Math.max(w[0],k[0]),Math.min(w[1],k[1])],s.range=s._input.range=o.simpleMap(_,r.l2r)}r.cleanRange(\"rangeslider.range\");var T=e.margin,A=e._size,M=r.domain,S=s._tickHeight,E=s._oppBottom;s._width=A.w*(M[1]-M[0]);var C=Math.round(T.l+A.w*M[0]),L=Math.round(A.t+A.h*(1-E)+S+s._offsetShift+d.extraPad);a.attr(\"transform\",\"translate(\"+C+\",\"+L+\")\");var P=r.r2l(s.range[0]),O=r.r2l(s.range[1]),z=O-P;if(s.p2d=function(t){return t/s._width*z+P},s.d2p=function(t){return(t-P)/z*s._width},s._rl=[P,O],\"match\"!==u.rangemode){var I=l.r2l(u.range[0]),D=l.r2l(u.range[1])-I;s.d2pOppAxis=function(t){return(t-I)/D*s._height}}a.call(g,t,r,s).call(v,t,r,s).call(m,t,r,s).call(y,t,r,s,u).call(x,t,r,s).call(b,t,r,s),function(t,e,r,a){var s=t.select(\"rect.\"+d.slideBoxClassName).node(),l=t.select(\"rect.\"+d.grabAreaMinClassName).node(),c=t.select(\"rect.\"+d.grabAreaMaxClassName).node();t.on(\"mousedown\",function(){var u=n.event,h=u.target,d=u.clientX,g=d-t.node().getBoundingClientRect().left,v=a.d2p(r._rl[0]),m=a.d2p(r._rl[1]),y=f.coverSlip();function x(t){var u,f,x,b=+t.clientX-d;switch(h){case s:x=\"ew-resize\",u=v+b,f=m+b;break;case l:x=\"col-resize\",u=v+b,f=m;break;case c:x=\"col-resize\",u=v,f=m+b;break;default:x=\"ew-resize\",u=g,f=g+b}if(f<u){var _=f;f=u,u=_}a._pixelMin=u,a._pixelMax=f,p(n.select(y),x),function(t,e,r,n){function a(t){return r.l2r(o.constrain(t,n._rl[0],n._rl[1]))}var s=a(n.p2d(n._pixelMin)),l=a(n.p2d(n._pixelMax));window.requestAnimationFrame(function(){i.call(\"_guiRelayout\",e,r._name+\".range\",[s,l])})}(0,e,r,a)}y.addEventListener(\"mousemove\",x),y.addEventListener(\"mouseup\",function t(){y.removeEventListener(\"mousemove\",x);y.removeEventListener(\"mouseup\",t);o.removeElement(y)})})}(a,t,r,s),function(t,e,r,n,i,a){var s=d.handleWidth/2;function l(t){return o.constrain(t,0,n._width)}function c(t){return o.constrain(t,0,n._height)}function u(t){return o.constrain(t,-s,n._width+s)}var h=l(n.d2p(r._rl[0])),f=l(n.d2p(r._rl[1]));if(t.select(\"rect.\"+d.slideBoxClassName).attr(\"x\",h).attr(\"width\",f-h),t.select(\"rect.\"+d.maskMinClassName).attr(\"width\",h),t.select(\"rect.\"+d.maskMaxClassName).attr(\"x\",f).attr(\"width\",n._width-f),\"match\"!==a.rangemode){var p=n._height-c(n.d2pOppAxis(i._rl[1])),g=n._height-c(n.d2pOppAxis(i._rl[0]));t.select(\"rect.\"+d.maskMinOppAxisClassName).attr(\"x\",h).attr(\"height\",p).attr(\"width\",f-h),t.select(\"rect.\"+d.maskMaxOppAxisClassName).attr(\"x\",h).attr(\"y\",g).attr(\"height\",n._height-g).attr(\"width\",f-h),t.select(\"rect.\"+d.slideBoxClassName).attr(\"y\",p).attr(\"height\",g-p)}var v=Math.round(u(h-s))-.5,m=Math.round(u(f-s))+.5;t.select(\"g.\"+d.grabberMinClassName).attr(\"transform\",\"translate(\"+v+\",0.5)\"),t.select(\"g.\"+d.grabberMaxClassName).attr(\"transform\",\"translate(\"+m+\",0.5)\")}(a,0,r,s,l,u),\"bottom\"===r.side&&c.draw(t,r._id+\"title\",{propContainer:r,propName:r._name+\".title\",placeholder:e._dfltTitle.x,attributes:{x:r._offset+r._length/2,y:L+s._height+s._offsetShift+10+1.5*r.title.font.size,\"text-anchor\":\"middle\"}})}))}},{\"../../lib\":719,\"../../lib/setcursor\":739,\"../../plots/cartesian\":778,\"../../plots/cartesian/axis_ids\":770,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"../titles\":681,\"./constants\":663,d3:163}],666:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"./constants\"),a=i.name;function o(t){var e=t&&t[a];return e&&e.visible}r.isVisible=o,r.makeData=function(t){var e=n.list({_fullLayout:t},\"x\",!0),r=t.margin,i=[];if(!t._has(\"gl2d\"))for(var s=0;s<e.length;s++){var l=e[s];if(o(l)){i.push(l);var c=l[a];c._id=a+l._id,c._height=(t.height-r.b-r.t)*c.thickness,c._offsetShift=Math.floor(c.borderwidth/2)}}t._rangeSliderData=i},r.autoMarginOpts=function(t,e){for(var r=e[a],o=1/0,s=e._counterAxes,l=0;l<s.length;l++){var c=s[l],u=n.getFromId(t,c);o=Math.min(o,u.domain[0])}r._oppBottom=o;var h=\"bottom\"===e.side&&e._boundingBox.height||0;return r._tickHeight=h,{x:0,y:o,l:0,r:0,t:0,b:r._height+t._fullLayout.margin.b+h,pad:i.extraPad+2*r._offsetShift}}},{\"../../plots/cartesian/axis_ids\":770,\"./constants\":663}],667:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./oppaxis_attributes\"),o=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"rangeslider\",schema:{subplots:{xaxis:{rangeslider:n.extendFlat({},i,{yaxis:a})}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),calcAutorange:t(\"./calc_autorange\"),draw:t(\"./draw\"),isVisible:o.isVisible,makeData:o.makeData,autoMarginOpts:o.autoMarginOpts}},{\"../../lib\":719,\"./attributes\":661,\"./calc_autorange\":662,\"./defaults\":664,\"./draw\":665,\"./helpers\":666,\"./oppaxis_attributes\":668}],668:[function(t,e,r){\"use strict\";e.exports={_isSubplotObj:!0,rangemode:{valType:\"enumerated\",values:[\"auto\",\"fixed\",\"match\"],dflt:\"match\",editType:\"calc\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"plot\"},{valType:\"any\",editType:\"plot\"}],editType:\"plot\"},editType:\"calc\"}},{}],669:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../traces/scatter/attributes\").line,a=t(\"../drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray;e.exports=s(\"shape\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},type:{valType:\"enumerated\",values:[\"circle\",\"rect\",\"path\",\"line\"],editType:\"calc+arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},xref:o({},n.xref,{}),xsizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},xanchor:{valType:\"any\",editType:\"calc+arraydraw\"},x0:{valType:\"any\",editType:\"calc+arraydraw\"},x1:{valType:\"any\",editType:\"calc+arraydraw\"},yref:o({},n.yref,{}),ysizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},yanchor:{valType:\"any\",editType:\"calc+arraydraw\"},y0:{valType:\"any\",editType:\"calc+arraydraw\"},y1:{valType:\"any\",editType:\"calc+arraydraw\"},path:{valType:\"string\",editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},line:{color:o({},i.color,{editType:\"arraydraw\"}),width:o({},i.width,{editType:\"calc+arraydraw\"}),dash:o({},a,{editType:\"arraydraw\"}),editType:\"calc+arraydraw\"},fillcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},editType:\"arraydraw\"})},{\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../../traces/scatter/attributes\":1112,\"../annotations/attributes\":576,\"../drawing/attributes\":613}],670:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./constants\"),o=t(\"./helpers\");function s(t){return c(t.line.width,t.xsizemode,t.x0,t.x1,t.path,!1)}function l(t){return c(t.line.width,t.ysizemode,t.y0,t.y1,t.path,!0)}function c(t,e,r,i,s,l){var c=t/2,u=l;if(\"pixel\"===e){var h=s?o.extractPathCoords(s,l?a.paramIsY:a.paramIsX):[r,i],f=n.aggNums(Math.max,null,h),p=n.aggNums(Math.min,null,h),d=p<0?Math.abs(p)+c:c,g=f>0?f+c:c;return{ppad:c,ppadplus:u?d:g,ppadminus:u?g:d}}return{ppad:c}}function u(t,e,r,n,i){var s=\"category\"===t.type||\"multicategory\"===t.type?t.r2c:t.d2c;if(void 0!==e)return[s(e),s(r)];if(n){var l,c,u,h,f=1/0,p=-1/0,d=n.match(a.segmentRE);for(\"date\"===t.type&&(s=o.decodeDate(s)),l=0;l<d.length;l++)void 0!==(c=i[d[l].charAt(0)].drawn)&&(!(u=d[l].substr(1).match(a.paramRE))||u.length<c||((h=s(u[c]))<f&&(f=h),h>p&&(p=h)));return p>=f?[f,p]:void 0}}e.exports=function(t){var e=t._fullLayout,r=n.filterVisible(e.shapes);if(r.length&&t._fullData.length)for(var o=0;o<r.length;o++){var c,h,f=r[o];if(f._extremes={},\"paper\"!==f.xref){var p=\"pixel\"===f.xsizemode?f.xanchor:f.x0,d=\"pixel\"===f.xsizemode?f.xanchor:f.x1;(h=u(c=i.getFromId(t,f.xref),p,d,f.path,a.paramIsX))&&(f._extremes[c._id]=i.findExtremes(c,h,s(f)))}if(\"paper\"!==f.yref){var g=\"pixel\"===f.ysizemode?f.yanchor:f.y0,v=\"pixel\"===f.ysizemode?f.yanchor:f.y1;(h=u(c=i.getFromId(t,f.yref),g,v,f.path,a.paramIsY))&&(f._extremes[c._id]=i.findExtremes(c,h,l(f)))}}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./constants\":671,\"./helpers\":674}],671:[function(t,e,r){\"use strict\";e.exports={segmentRE:/[MLHVQCTSZ][^MLHVQCTSZ]*/g,paramRE:/[^\\s,]+/g,paramIsX:{M:{0:!0,drawn:0},L:{0:!0,drawn:0},H:{0:!0,drawn:0},V:{},Q:{0:!0,2:!0,drawn:2},C:{0:!0,2:!0,4:!0,drawn:4},T:{0:!0,drawn:0},S:{0:!0,2:!0,drawn:2},Z:{}},paramIsY:{M:{1:!0,drawn:1},L:{1:!0,drawn:1},H:{},V:{0:!0,drawn:0},Q:{1:!0,3:!0,drawn:3},C:{1:!0,3:!0,5:!0,drawn:5},T:{1:!0,drawn:1},S:{1:!0,3:!0,drawn:5},Z:{}},numParams:{M:2,L:2,H:1,V:1,Q:4,C:6,T:2,S:4,Z:0}}},{}],672:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\"),s=t(\"./helpers\");function l(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}if(a(\"visible\")){a(\"layer\"),a(\"opacity\"),a(\"fillcolor\"),a(\"line.color\"),a(\"line.width\"),a(\"line.dash\");for(var l=a(\"type\",t.path?\"path\":\"rect\"),c=a(\"xsizemode\"),u=a(\"ysizemode\"),h=[\"x\",\"y\"],f=0;f<2;f++){var p,d,g,v=h[f],m=v+\"anchor\",y=\"x\"===v?c:u,x={_fullLayout:r},b=i.coerceRef(t,e,x,v,\"\",\"paper\");if(\"paper\"!==b?((p=i.getFromId(x,b))._shapeIndices.push(e._index),g=s.rangeToShapePosition(p),d=s.shapePositionToRange(p)):d=g=n.identity,\"path\"!==l){var _=v+\"0\",w=v+\"1\",k=t[_],T=t[w];t[_]=d(t[_],!0),t[w]=d(t[w],!0),\"pixel\"===y?(a(_,0),a(w,10)):(i.coercePosition(e,x,a,b,_,.25),i.coercePosition(e,x,a,b,w,.75)),e[_]=g(e[_]),e[w]=g(e[w]),t[_]=k,t[w]=T}if(\"pixel\"===y){var A=t[m];t[m]=d(t[m],!0),i.coercePosition(e,x,a,b,m,.25),e[m]=g(e[m]),t[m]=A}}\"path\"===l?a(\"path\"):n.noneOrAll(t,e,[\"x0\",\"x1\",\"y0\",\"y1\"])}}e.exports=function(t,e){a(t,e,{name:\"shapes\",handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"./attributes\":669,\"./helpers\":674}],673:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../color\"),s=t(\"../drawing\"),l=t(\"../../plot_api/plot_template\").arrayEditor,c=t(\"../dragelement\"),u=t(\"../../lib/setcursor\"),h=t(\"./constants\"),f=t(\"./helpers\");function p(t,e){t._fullLayout._paperdiv.selectAll('.shapelayer [data-index=\"'+e+'\"]').remove();var r=t._fullLayout.shapes[e]||{};if(r._input&&!1!==r.visible)if(\"below\"!==r.layer)m(t._fullLayout._shapeUpperLayer);else if(\"paper\"===r.xref||\"paper\"===r.yref)m(t._fullLayout._shapeLowerLayer);else{var p=t._fullLayout._plots[r.xref+r.yref];if(p)m((p.mainplotinfo||p).shapelayer);else m(t._fullLayout._shapeLowerLayer)}function m(p){var m={\"data-index\":e,\"fill-rule\":\"evenodd\",d:g(t,r)},y=r.line.width?r.line.color:\"rgba(0,0,0,0)\",x=p.append(\"path\").attr(m).style(\"opacity\",r.opacity).call(o.stroke,y).call(o.fill,r.fillcolor).call(s.dashLine,r.line.dash,r.line.width);d(x,t,r),t._context.edits.shapePosition&&function(t,e,r,o,p){var m,y,x,b,_,w,k,T,A,M,S,E,C,L,P,O,z=10,I=10,D=\"pixel\"===r.xsizemode,R=\"pixel\"===r.ysizemode,F=\"line\"===r.type,B=\"path\"===r.type,N=l(t.layout,\"shapes\",r),j=N.modifyItem,U=a.getFromId(t,r.xref),V=a.getFromId(t,r.yref),q=f.getDataToPixel(t,U),H=f.getDataToPixel(t,V,!0),G=f.getPixelToData(t,U),Y=f.getPixelToData(t,V,!0),W=F?function(){var t=Math.max(r.line.width,10),n=p.append(\"g\").attr(\"data-index\",o);n.append(\"path\").attr(\"d\",e.attr(\"d\")).style({cursor:\"move\",\"stroke-width\":t,\"stroke-opacity\":\"0\"});var i={\"fill-opacity\":\"0\"},a=t/2>10?t/2:10;return n.append(\"circle\").attr({\"data-line-point\":\"start-point\",cx:D?q(r.xanchor)+r.x0:q(r.x0),cy:R?H(r.yanchor)-r.y0:H(r.y0),r:a}).style(i).classed(\"cursor-grab\",!0),n.append(\"circle\").attr({\"data-line-point\":\"end-point\",cx:D?q(r.xanchor)+r.x1:q(r.x1),cy:R?H(r.yanchor)-r.y1:H(r.y1),r:a}).style(i).classed(\"cursor-grab\",!0),n}():e,X={element:W.node(),gd:t,prepFn:function(n){D&&(_=q(r.xanchor));R&&(w=H(r.yanchor));\"path\"===r.type?P=r.path:(m=D?r.x0:q(r.x0),y=R?r.y0:H(r.y0),x=D?r.x1:q(r.x1),b=R?r.y1:H(r.y1));m<x?(A=m,C=\"x0\",M=x,L=\"x1\"):(A=x,C=\"x1\",M=m,L=\"x0\");!R&&y<b||R&&y>b?(k=y,S=\"y0\",T=b,E=\"y1\"):(k=b,S=\"y1\",T=y,E=\"y0\");Z(n),$(p,r),function(t,e,r){var n=e.xref,i=e.yref,o=a.getFromId(r,n),l=a.getFromId(r,i),c=\"\";\"paper\"===n||o.autorange||(c+=n);\"paper\"===i||l.autorange||(c+=i);s.setClipUrl(t,c?\"clip\"+r._fullLayout._uid+c:null,r)}(e,r,t),X.moveFn=\"move\"===O?J:K},doneFn:function(){u(e),Q(p),d(e,t,r),n.call(\"_guiRelayout\",t,N.getUpdateObj())},clickFn:function(){Q(p)}};function Z(t){if(F)O=\"path\"===t.target.tagName?\"move\":\"start-point\"===t.target.attributes[\"data-line-point\"].value?\"resize-over-start-point\":\"resize-over-end-point\";else{var r=X.element.getBoundingClientRect(),n=r.right-r.left,i=r.bottom-r.top,a=t.clientX-r.left,o=t.clientY-r.top,s=!B&&n>z&&i>I&&!t.shiftKey?c.getCursor(a/n,1-o/i):\"move\";u(e,s),O=s.split(\"-\")[0]}}function J(n,i){if(\"path\"===r.type){var a=function(t){return t},o=a,s=a;D?j(\"xanchor\",r.xanchor=G(_+n)):(o=function(t){return G(q(t)+n)},U&&\"date\"===U.type&&(o=f.encodeDate(o))),R?j(\"yanchor\",r.yanchor=Y(w+i)):(s=function(t){return Y(H(t)+i)},V&&\"date\"===V.type&&(s=f.encodeDate(s))),j(\"path\",r.path=v(P,o,s))}else D?j(\"xanchor\",r.xanchor=G(_+n)):(j(\"x0\",r.x0=G(m+n)),j(\"x1\",r.x1=G(x+n))),R?j(\"yanchor\",r.yanchor=Y(w+i)):(j(\"y0\",r.y0=Y(y+i)),j(\"y1\",r.y1=Y(b+i)));e.attr(\"d\",g(t,r)),$(p,r)}function K(n,i){if(B){var a=function(t){return t},o=a,s=a;D?j(\"xanchor\",r.xanchor=G(_+n)):(o=function(t){return G(q(t)+n)},U&&\"date\"===U.type&&(o=f.encodeDate(o))),R?j(\"yanchor\",r.yanchor=Y(w+i)):(s=function(t){return Y(H(t)+i)},V&&\"date\"===V.type&&(s=f.encodeDate(s))),j(\"path\",r.path=v(P,o,s))}else if(F){if(\"resize-over-start-point\"===O){var l=m+n,c=R?y-i:y+i;j(\"x0\",r.x0=D?l:G(l)),j(\"y0\",r.y0=R?c:Y(c))}else if(\"resize-over-end-point\"===O){var u=x+n,h=R?b-i:b+i;j(\"x1\",r.x1=D?u:G(u)),j(\"y1\",r.y1=R?h:Y(h))}}else{var d=~O.indexOf(\"n\")?k+i:k,N=~O.indexOf(\"s\")?T+i:T,W=~O.indexOf(\"w\")?A+n:A,X=~O.indexOf(\"e\")?M+n:M;~O.indexOf(\"n\")&&R&&(d=k-i),~O.indexOf(\"s\")&&R&&(N=T-i),(!R&&N-d>I||R&&d-N>I)&&(j(S,r[S]=R?d:Y(d)),j(E,r[E]=R?N:Y(N))),X-W>z&&(j(C,r[C]=D?W:G(W)),j(L,r[L]=D?X:G(X)))}e.attr(\"d\",g(t,r)),$(p,r)}function $(t,e){(D||R)&&function(){var r=\"path\"!==e.type,n=t.selectAll(\".visual-cue\").data([0]);n.enter().append(\"path\").attr({fill:\"#fff\",\"fill-rule\":\"evenodd\",stroke:\"#000\",\"stroke-width\":1}).classed(\"visual-cue\",!0);var a=q(D?e.xanchor:i.midRange(r?[e.x0,e.x1]:f.extractPathCoords(e.path,h.paramIsX))),o=H(R?e.yanchor:i.midRange(r?[e.y0,e.y1]:f.extractPathCoords(e.path,h.paramIsY)));if(a=f.roundPositionForSharpStrokeRendering(a,1),o=f.roundPositionForSharpStrokeRendering(o,1),D&&R){var s=\"M\"+(a-1-1)+\",\"+(o-1-1)+\"h-8v2h8 v8h2v-8 h8v-2h-8 v-8h-2 Z\";n.attr(\"d\",s)}else if(D){var l=\"M\"+(a-1-1)+\",\"+(o-9-1)+\"v18 h2 v-18 Z\";n.attr(\"d\",l)}else{var c=\"M\"+(a-9-1)+\",\"+(o-1-1)+\"h18 v2 h-18 Z\";n.attr(\"d\",c)}}()}function Q(t){t.selectAll(\".visual-cue\").remove()}c.init(X),W.node().onmousemove=Z}(t,x,r,e,p)}}function d(t,e,r){var n=(r.xref+r.yref).replace(/paper/g,\"\");s.setClipUrl(t,n?\"clip\"+e._fullLayout._uid+n:null,e)}function g(t,e){var r,n,o,s,l,c,u,p,d=e.type,g=a.getFromId(t,e.xref),v=a.getFromId(t,e.yref),m=t._fullLayout._size;if(g?(r=f.shapePositionToRange(g),n=function(t){return g._offset+g.r2p(r(t,!0))}):n=function(t){return m.l+m.w*t},v?(o=f.shapePositionToRange(v),s=function(t){return v._offset+v.r2p(o(t,!0))}):s=function(t){return m.t+m.h*(1-t)},\"path\"===d)return g&&\"date\"===g.type&&(n=f.decodeDate(n)),v&&\"date\"===v.type&&(s=f.decodeDate(s)),function(t,e,r){var n=t.path,a=t.xsizemode,o=t.ysizemode,s=t.xanchor,l=t.yanchor;return n.replace(h.segmentRE,function(t){var n=0,c=t.charAt(0),u=h.paramIsX[c],f=h.paramIsY[c],p=h.numParams[c],d=t.substr(1).replace(h.paramRE,function(t){return u[n]?t=\"pixel\"===a?e(s)+Number(t):e(t):f[n]&&(t=\"pixel\"===o?r(l)-Number(t):r(t)),++n>p&&(t=\"X\"),t});return n>p&&(d=d.replace(/[\\s,]*X.*/,\"\"),i.log(\"Ignoring extra params in segment \"+t)),c+d})}(e,n,s);if(\"pixel\"===e.xsizemode){var y=n(e.xanchor);l=y+e.x0,c=y+e.x1}else l=n(e.x0),c=n(e.x1);if(\"pixel\"===e.ysizemode){var x=s(e.yanchor);u=x-e.y0,p=x-e.y1}else u=s(e.y0),p=s(e.y1);if(\"line\"===d)return\"M\"+l+\",\"+u+\"L\"+c+\",\"+p;if(\"rect\"===d)return\"M\"+l+\",\"+u+\"H\"+c+\"V\"+p+\"H\"+l+\"Z\";var b=(l+c)/2,_=(u+p)/2,w=Math.abs(b-l),k=Math.abs(_-u),T=\"A\"+w+\",\"+k,A=b+w+\",\"+_;return\"M\"+A+T+\" 0 1,1 \"+(b+\",\"+(_-k))+T+\" 0 0,1 \"+A+\"Z\"}function v(t,e,r){return t.replace(h.segmentRE,function(t){var n=0,i=t.charAt(0),a=h.paramIsX[i],o=h.paramIsY[i],s=h.numParams[i];return i+t.substr(1).replace(h.paramRE,function(t){return n>=s?t:(a[n]?t=e(t):o[n]&&(t=r(t)),n++,t)})})}e.exports={draw:function(t){var e=t._fullLayout;for(var r in e._shapeUpperLayer.selectAll(\"path\").remove(),e._shapeLowerLayer.selectAll(\"path\").remove(),e._plots){var n=e._plots[r].shapelayer;n&&n.selectAll(\"path\").remove()}for(var i=0;i<e.shapes.length;i++)e.shapes[i].visible&&p(t,i)},drawOne:p}},{\"../../lib\":719,\"../../lib/setcursor\":739,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"./constants\":671,\"./helpers\":674}],674:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib\");r.rangeToShapePosition=function(t){return\"log\"===t.type?t.r2d:function(t){return t}},r.shapePositionToRange=function(t){return\"log\"===t.type?t.d2r:function(t){return t}},r.decodeDate=function(t){return function(e){return e.replace&&(e=e.replace(\"_\",\" \")),t(e)}},r.encodeDate=function(t){return function(e){return t(e).replace(\" \",\"_\")}},r.extractPathCoords=function(t,e){var r=[];return t.match(n.segmentRE).forEach(function(t){var a=e[t.charAt(0)].drawn;if(void 0!==a){var o=t.substr(1).match(n.paramRE);!o||o.length<a||r.push(i.cleanNumber(o[a]))}}),r},r.getDataToPixel=function(t,e,n){var i,a=t._fullLayout._size;if(e){var o=r.shapePositionToRange(e);i=function(t){return e._offset+e.r2p(o(t,!0))},\"date\"===e.type&&(i=r.decodeDate(i))}else i=n?function(t){return a.t+a.h*(1-t)}:function(t){return a.l+a.w*t};return i},r.getPixelToData=function(t,e,n){var i,a=t._fullLayout._size;if(e){var o=r.rangeToShapePosition(e);i=function(t){return o(e.p2r(t-e._offset))}}else i=n?function(t){return 1-(t-a.t)/a.h}:function(t){return(t-a.l)/a.w};return i},r.roundPositionForSharpStrokeRendering=function(t,e){var r=1===Math.round(e%2),n=Math.round(t);return r?n+.5:n}},{\"../../lib\":719,\"./constants\":671}],675:[function(t,e,r){\"use strict\";var n=t(\"./draw\");e.exports={moduleType:\"component\",name:\"shapes\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"shapes\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne}},{\"../../plots/cartesian/include_components\":777,\"./attributes\":669,\"./calc_autorange\":670,\"./defaults\":672,\"./draw\":673}],676:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/pad_attributes\"),a=t(\"../../lib/extend\").extendDeepAll,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/animation_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"./constants\"),u=l(\"step\",{visible:{valType:\"boolean\",dflt:!0},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\"},value:{valType:\"string\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"slider\",{visible:{valType:\"boolean\",dflt:!0},active:{valType:\"number\",min:0,dflt:0},steps:u,lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",min:-2,max:3,dflt:0},pad:a(i({editType:\"arraydraw\"}),{},{t:{dflt:20}}),xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\"},y:{valType:\"number\",min:-2,max:3,dflt:0},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},transition:{duration:{valType:\"number\",min:0,dflt:150},easing:{valType:\"enumerated\",values:s.transition.easing.values,dflt:\"cubic-in-out\"}},currentvalue:{visible:{valType:\"boolean\",dflt:!0},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},offset:{valType:\"number\",dflt:10},prefix:{valType:\"string\"},suffix:{valType:\"string\"},font:n({})},font:n({}),activebgcolor:{valType:\"color\",dflt:c.gripBgActiveColor},bgcolor:{valType:\"color\",dflt:c.railBgColor},bordercolor:{valType:\"color\",dflt:c.railBorderColor},borderwidth:{valType:\"number\",min:0,dflt:c.railBorderWidth},ticklen:{valType:\"number\",min:0,dflt:c.tickLength},tickcolor:{valType:\"color\",dflt:c.tickColor},tickwidth:{valType:\"number\",min:0,dflt:1},minorticklen:{valType:\"number\",min:0,dflt:c.minorTickLength}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/animation_attributes\":762,\"../../plots/font_attributes\":793,\"../../plots/pad_attributes\":827,\"./constants\":677}],677:[function(t,e,r){\"use strict\";e.exports={name:\"sliders\",containerClassName:\"slider-container\",groupClassName:\"slider-group\",inputAreaClass:\"slider-input-area\",railRectClass:\"slider-rail-rect\",railTouchRectClass:\"slider-rail-touch-rect\",gripRectClass:\"slider-grip-rect\",tickRectClass:\"slider-tick-rect\",inputProxyClass:\"slider-input-proxy\",labelsClass:\"slider-labels\",labelGroupClass:\"slider-label-group\",labelClass:\"slider-label\",currentValueClass:\"slider-current-value\",railHeight:5,menuIndexAttrName:\"slider-active-index\",autoMarginIdRoot:\"slider-\",minWidth:30,minHeight:30,textPadX:40,arrowOffsetX:4,railRadius:2,railWidth:5,railBorder:4,railBorderWidth:1,railBorderColor:\"#bec8d9\",railBgColor:\"#f8fafc\",railInset:8,stepInset:10,gripRadius:10,gripWidth:20,gripHeight:20,gripBorder:20,gripBorderWidth:1,gripBorderColor:\"#bec8d9\",gripBgColor:\"#f6f8fa\",gripBgActiveColor:\"#dbdde0\",labelPadding:8,labelOffset:0,tickWidth:1,tickColor:\"#333\",tickOffset:25,tickLength:7,minorTickOffset:25,minorTickColor:\"#333\",minorTickLength:4,currentValuePadding:8,currentValueInset:0}},{}],678:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.steps;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}for(var s=i(t,e,{name:\"steps\",handleItemDefaults:c}),l=0,u=0;u<s.length;u++)s[u].visible&&l++;if(l<2?e.visible=!1:o(\"visible\")){e._stepCount=l;var h=e._visibleSteps=n.filterVisible(s);(s[o(\"active\")]||{}).visible||(e.active=h[0]._index),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"len\"),o(\"lenmode\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"currentvalue.visible\")&&(o(\"currentvalue.xanchor\"),o(\"currentvalue.prefix\"),o(\"currentvalue.suffix\"),o(\"currentvalue.offset\"),n.coerceFont(o,\"currentvalue.font\",e.font)),o(\"transition.duration\"),o(\"transition.easing\"),o(\"bgcolor\"),o(\"activebgcolor\"),o(\"bordercolor\"),o(\"borderwidth\"),o(\"ticklen\"),o(\"tickwidth\"),o(\"tickcolor\"),o(\"minorticklen\")}}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}if(\"skip\"===t.method||Array.isArray(t.args)?r(\"visible\"):e.visible=!1){r(\"method\"),r(\"args\");var i=r(\"label\",\"step-\"+e._index);r(\"value\",i),r(\"execute\")}}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"./attributes\":676,\"./constants\":677}],679:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"./constants\"),h=t(\"../../constants/alignment\"),f=h.LINE_SPACING,p=h.FROM_TL,d=h.FROM_BR;function g(t){return u.autoMarginIdRoot+t._index}function v(t){return t._index}function m(t,e){var r=o.tester.selectAll(\"g.\"+u.labelGroupClass).data(e._visibleSteps);r.enter().append(\"g\").classed(u.labelGroupClass,!0);var a=0,c=0;r.each(function(t){var r=b(n.select(this),{step:t},e).node();if(r){var i=o.bBox(r);c=Math.max(c,i.height),a=Math.max(a,i.width)}}),r.remove();var h=e._dims={};h.inputAreaWidth=Math.max(u.railWidth,u.gripHeight);var f=t._fullLayout._size;h.lx=f.l+f.w*e.x,h.ly=f.t+f.h*(1-e.y),\"fraction\"===e.lenmode?h.outerLength=Math.round(f.w*e.len):h.outerLength=e.len,h.inputAreaStart=0,h.inputAreaLength=Math.round(h.outerLength-e.pad.l-e.pad.r);var v=(h.inputAreaLength-2*u.stepInset)/(e._stepCount-1),m=a+u.labelPadding;if(h.labelStride=Math.max(1,Math.ceil(m/v)),h.labelHeight=c,h.currentValueMaxWidth=0,h.currentValueHeight=0,h.currentValueTotalHeight=0,h.currentValueMaxLines=1,e.currentvalue.visible){var x=o.tester.append(\"g\");r.each(function(t){var r=y(x,e,t.label),n=r.node()&&o.bBox(r.node())||{width:0,height:0},i=l.lineCount(r);h.currentValueMaxWidth=Math.max(h.currentValueMaxWidth,Math.ceil(n.width)),h.currentValueHeight=Math.max(h.currentValueHeight,Math.ceil(n.height)),h.currentValueMaxLines=Math.max(h.currentValueMaxLines,i)}),h.currentValueTotalHeight=h.currentValueHeight+e.currentvalue.offset,x.remove()}h.height=h.currentValueTotalHeight+u.tickOffset+e.ticklen+u.labelOffset+h.labelHeight+e.pad.t+e.pad.b;var _=\"left\";s.isRightAnchor(e)&&(h.lx-=h.outerLength,_=\"right\"),s.isCenterAnchor(e)&&(h.lx-=h.outerLength/2,_=\"center\");var w=\"top\";s.isBottomAnchor(e)&&(h.ly-=h.height,w=\"bottom\"),s.isMiddleAnchor(e)&&(h.ly-=h.height/2,w=\"middle\"),h.outerLength=Math.ceil(h.outerLength),h.height=Math.ceil(h.height),h.lx=Math.round(h.lx),h.ly=Math.round(h.ly);var k={y:e.y,b:h.height*d[w],t:h.height*p[w]};\"fraction\"===e.lenmode?(k.l=0,k.xl=e.x-e.len*p[_],k.r=0,k.xr=e.x+e.len*d[_]):(k.x=e.x,k.l=h.outerLength*p[_],k.r=h.outerLength*d[_]),i.autoMargin(t,g(e),k)}function y(t,e,r){if(e.currentvalue.visible){var n,i,a=e._dims;switch(e.currentvalue.xanchor){case\"right\":n=a.inputAreaLength-u.currentValueInset-a.currentValueMaxWidth,i=\"left\";break;case\"center\":n=.5*a.inputAreaLength,i=\"middle\";break;default:n=u.currentValueInset,i=\"left\"}var c=s.ensureSingle(t,\"text\",u.labelClass,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":i,\"data-notex\":1})}),h=e.currentvalue.prefix?e.currentvalue.prefix:\"\";if(\"string\"==typeof r)h+=r;else{var p=e.steps[e.active].label,d=e._gd._fullLayout._meta;d&&(p=s.templateString(p,d)),h+=p}e.currentvalue.suffix&&(h+=e.currentvalue.suffix),c.call(o.font,e.currentvalue.font).text(h).call(l.convertToTspans,e._gd);var g=l.lineCount(c),v=(a.currentValueMaxLines+1-g)*e.currentvalue.font.size*f;return l.positionText(c,n,v),c}}function x(t,e,r){s.ensureSingle(t,\"rect\",u.gripRectClass,function(n){n.call(T,e,t,r).style(\"pointer-events\",\"all\")}).attr({width:u.gripWidth,height:u.gripHeight,rx:u.gripRadius,ry:u.gripRadius}).call(a.stroke,r.bordercolor).call(a.fill,r.bgcolor).style(\"stroke-width\",r.borderwidth+\"px\")}function b(t,e,r){var n=s.ensureSingle(t,\"text\",u.labelClass,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":\"middle\",\"data-notex\":1})}),i=e.step.label,a=r._gd._fullLayout._meta;return a&&(i=s.templateString(i,a)),n.call(o.font,r.font).text(i).call(l.convertToTspans,r._gd),n}function _(t,e){var r=s.ensureSingle(t,\"g\",u.labelsClass),i=e._dims,a=r.selectAll(\"g.\"+u.labelGroupClass).data(i.labelSteps);a.enter().append(\"g\").classed(u.labelGroupClass,!0),a.exit().remove(),a.each(function(t){var r=n.select(this);r.call(b,t,e),o.setTranslate(r,S(e,t.fraction),u.tickOffset+e.ticklen+e.font.size*f+u.labelOffset+i.currentValueTotalHeight)})}function w(t,e,r,n,i){var a=Math.round(n*(r._stepCount-1)),o=r._visibleSteps[a]._index;o!==r.active&&k(t,e,r,o,!0,i)}function k(t,e,r,n,a,o){var s=r.active;r.active=n,c(t.layout,u.name,r).applyUpdate(\"active\",n);var l=r.steps[r.active];e.call(M,r,o),e.call(y,r),t.emit(\"plotly_sliderchange\",{slider:r,step:r.steps[r.active],interaction:a,previousActive:s}),l&&l.method&&a&&(e._nextMethod?(e._nextMethod.step=l,e._nextMethod.doCallback=a,e._nextMethod.doTransition=o):(e._nextMethod={step:l,doCallback:a,doTransition:o},e._nextMethodRaf=window.requestAnimationFrame(function(){var r=e._nextMethod.step;r.method&&(r.execute&&i.executeAPICommand(t,r.method,r.args),e._nextMethod=null,e._nextMethodRaf=null)})))}function T(t,e,r){var i=r.node(),o=n.select(e);function s(){return r.data()[0]}t.on(\"mousedown\",function(){var t=s();e.emit(\"plotly_sliderstart\",{slider:t});var l=r.select(\".\"+u.gripRectClass);n.event.stopPropagation(),n.event.preventDefault(),l.call(a.fill,t.activebgcolor);var c=E(t,n.mouse(i)[0]);w(e,r,t,c,!0),t._dragging=!0,o.on(\"mousemove\",function(){var t=s(),a=E(t,n.mouse(i)[0]);w(e,r,t,a,!1)}),o.on(\"mouseup\",function(){var t=s();t._dragging=!1,l.call(a.fill,t.bgcolor),o.on(\"mouseup\",null),o.on(\"mousemove\",null),e.emit(\"plotly_sliderend\",{slider:t,step:t.steps[t.active]})})})}function A(t,e){var r=t.selectAll(\"rect.\"+u.tickRectClass).data(e._visibleSteps),i=e._dims;r.enter().append(\"rect\").classed(u.tickRectClass,!0),r.exit().remove(),r.attr({width:e.tickwidth+\"px\",\"shape-rendering\":\"crispEdges\"}),r.each(function(t,r){var s=r%i.labelStride==0,l=n.select(this);l.attr({height:s?e.ticklen:e.minorticklen}).call(a.fill,e.tickcolor),o.setTranslate(l,S(e,r/(e._stepCount-1))-.5*e.tickwidth,(s?u.tickOffset:u.minorTickOffset)+i.currentValueTotalHeight)})}function M(t,e,r){for(var n=t.select(\"rect.\"+u.gripRectClass),i=0,a=0;a<e._stepCount;a++)if(e._visibleSteps[a]._index===e.active){i=a;break}var o=S(e,i/(e._stepCount-1));if(!e._invokingCommand){var s=n;r&&e.transition.duration>0&&(s=s.transition().duration(e.transition.duration).ease(e.transition.easing)),s.attr(\"transform\",\"translate(\"+(o-.5*u.gripWidth)+\",\"+e._dims.currentValueTotalHeight+\")\")}}function S(t,e){var r=t._dims;return r.inputAreaStart+u.stepInset+(r.inputAreaLength-2*u.stepInset)*Math.min(1,Math.max(0,e))}function E(t,e){var r=t._dims;return Math.min(1,Math.max(0,(e-u.stepInset-r.inputAreaStart)/(r.inputAreaLength-2*u.stepInset-2*r.inputAreaStart)))}function C(t,e,r){var n=r._dims,i=s.ensureSingle(t,\"rect\",u.railTouchRectClass,function(n){n.call(T,e,t,r).style(\"pointer-events\",\"all\")});i.attr({width:n.inputAreaLength,height:Math.max(n.inputAreaWidth,u.tickOffset+r.ticklen+n.labelHeight)}).call(a.fill,r.bgcolor).attr(\"opacity\",0),o.setTranslate(i,0,n.currentValueTotalHeight)}function L(t,e){var r=e._dims,n=r.inputAreaLength-2*u.railInset,i=s.ensureSingle(t,\"rect\",u.railRectClass);i.attr({width:n,height:u.railWidth,rx:u.railRadius,ry:u.railRadius,\"shape-rendering\":\"crispEdges\"}).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\"),o.setTranslate(i,u.railInset,.5*(r.inputAreaWidth-u.railWidth)+r.currentValueTotalHeight)}e.exports=function(t){var e=t._fullLayout,r=function(t,e){for(var r=t[u.name],n=[],i=0;i<r.length;i++){var a=r[i];a.visible&&(a._gd=e,n.push(a))}return n}(e,t),a=e._infolayer.selectAll(\"g.\"+u.containerClassName).data(r.length>0?[0]:[]);function s(e){e._commandObserver&&(e._commandObserver.remove(),delete e._commandObserver),i.autoMargin(t,g(e))}if(a.enter().append(\"g\").classed(u.containerClassName,!0).style(\"cursor\",\"ew-resize\"),a.exit().each(function(){n.select(this).selectAll(\"g.\"+u.groupClassName).each(s)}).remove(),0!==r.length){var l=a.selectAll(\"g.\"+u.groupClassName).data(r,v);l.enter().append(\"g\").classed(u.groupClassName,!0),l.exit().each(s).remove();for(var c=0;c<r.length;c++){var h=r[c];m(t,h)}l.each(function(e){var r=n.select(this);!function(t){var e=t._dims;e.labelSteps=[];for(var r=t._stepCount,n=0;n<r;n+=e.labelStride)e.labelSteps.push({fraction:n/(r-1),step:t._visibleSteps[n]})}(e),i.manageCommandObserver(t,e,e._visibleSteps,function(e){var n=r.data()[0];n.active!==e.index&&(n._dragging||k(t,r,n,e.index,!1,!0))}),function(t,e,r){(r.steps[r.active]||{}).visible||(r.active=r._visibleSteps[0]._index);e.call(y,r).call(L,r).call(_,r).call(A,r).call(C,t,r).call(x,t,r);var n=r._dims;o.setTranslate(e,n.lx+r.pad.l,n.ly+r.pad.t),e.call(M,r,!1),e.call(y,r)}(t,n.select(this),e)})}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_template\":757,\"../../plots/plots\":828,\"../color\":593,\"../drawing\":614,\"./constants\":677,d3:163}],680:[function(t,e,r){\"use strict\";var n=t(\"./constants\");e.exports={moduleType:\"component\",name:n.name,layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":676,\"./constants\":677,\"./defaults\":678,\"./draw\":679}],681:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../drawing\"),c=t(\"../color\"),u=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/interactions\");e.exports={draw:function(t,e,r){var p,d=r.propContainer,g=r.propName,v=r.placeholder,m=r.traceIndex,y=r.avoid||{},x=r.attributes,b=r.transform,_=r.containerGroup,w=t._fullLayout,k=1,T=!1,A=d.title,M=(A&&A.text?A.text:\"\").trim(),S=A&&A.font?A.font:{},E=S.family,C=S.size,L=S.color;\"title.text\"===g?p=\"titleText\":-1!==g.indexOf(\"axis\")?p=\"axisTitleText\":g.indexOf(!0)&&(p=\"colorbarTitleText\");var P=t._context.edits[p];\"\"===M?k=0:M.replace(f,\" % \")===v.replace(f,\" % \")&&(k=.2,T=!0,P||(M=\"\"));r._meta?M=s.templateString(M,r._meta):w._meta&&(M=s.templateString(M,w._meta));var O=M||P;_||(_=s.ensureSingle(w._infolayer,\"g\",\"g-\"+e));var z=_.selectAll(\"text\").data(O?[0]:[]);if(z.enter().append(\"text\"),z.text(M).attr(\"class\",e),z.exit().remove(),!O)return _;function I(t){s.syncOrAsync([D,R],t)}function D(e){var r;return b?(r=\"\",b.rotate&&(r+=\"rotate(\"+[b.rotate,x.x,x.y]+\")\"),b.offset&&(r+=\"translate(0, \"+b.offset+\")\")):r=null,e.attr(\"transform\",r),e.style({\"font-family\":E,\"font-size\":n.round(C,2)+\"px\",fill:c.rgb(L),opacity:k*c.opacity(L),\"font-weight\":a.fontWeight}).attr(x).call(u.convertToTspans,t),a.previousPromises(t)}function R(t){var e=n.select(t.node().parentNode);if(y&&y.selection&&y.side&&M){e.attr(\"transform\",null);var r=0,a={left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}[y.side],o=-1!==[\"left\",\"top\"].indexOf(y.side)?-1:1,c=i(y.pad)?y.pad:2,u=l.bBox(e.node()),h={left:0,top:0,right:w.width,bottom:w.height},f=y.maxShift||(h[y.side]-u[y.side])*(\"left\"===y.side||\"top\"===y.side?-1:1);if(f<0)r=f;else{var p=y.offsetLeft||0,d=y.offsetTop||0;u.left-=p,u.right-=p,u.top-=d,u.bottom-=d,y.selection.each(function(){var t=l.bBox(this);s.bBoxIntersect(u,t,c)&&(r=Math.max(r,o*(t[y.side]-u[a])+c))}),r=Math.min(f,r)}if(r>0||f<0){var g={left:[-r,0],right:[r,0],top:[0,-r],bottom:[0,r]}[y.side];e.attr(\"transform\",\"translate(\"+g+\")\")}}}z.call(I),P&&(M?z.on(\".opacity\",null):(k=0,T=!0,z.text(v).on(\"mouseover.opacity\",function(){n.select(this).transition().duration(h.SHOW_PLACEHOLDER).style(\"opacity\",1)}).on(\"mouseout.opacity\",function(){n.select(this).transition().duration(h.HIDE_PLACEHOLDER).style(\"opacity\",0)})),z.call(u.makeEditable,{gd:t}).on(\"edit\",function(e){void 0!==m?o.call(\"_guiRestyle\",t,g,e,m):o.call(\"_guiRelayout\",t,g,e)}).on(\"cancel\",function(){this.text(this.attr(\"data-unformatted\")).call(I)}).on(\"input\",function(t){this.text(t||\" \").call(u.positionText,x.x,x.y)}));return z.classed(\"js-placeholder\",T),_}};var f=/ [XY][0-9]* /},{\"../../constants/interactions\":694,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../drawing\":614,d3:163,\"fast-isnumeric\":225}],682:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/pad_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=l(\"button\",{visible:{valType:\"boolean\"},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\",dflt:\"\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"updatemenu\",{_arrayAttrRegexps:[/^updatemenus\\[(0|[1-9][0-9]+)\\]\\.buttons/],visible:{valType:\"boolean\"},type:{valType:\"enumerated\",values:[\"dropdown\",\"buttons\"],dflt:\"dropdown\"},direction:{valType:\"enumerated\",values:[\"left\",\"right\",\"up\",\"down\"],dflt:\"down\"},active:{valType:\"integer\",min:-1,dflt:0},showactive:{valType:\"boolean\",dflt:!0},buttons:c,x:{valType:\"number\",min:-2,max:3,dflt:-.05},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"right\"},y:{valType:\"number\",min:-2,max:3,dflt:1},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},pad:a(s({editType:\"arraydraw\"}),{}),font:n({}),bgcolor:{valType:\"color\"},bordercolor:{valType:\"color\",dflt:i.borderLine},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"arraydraw\"}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/font_attributes\":793,\"../../plots/pad_attributes\":827,\"../color/attributes\":592}],683:[function(t,e,r){\"use strict\";e.exports={name:\"updatemenus\",containerClassName:\"updatemenu-container\",headerGroupClassName:\"updatemenu-header-group\",headerClassName:\"updatemenu-header\",headerArrowClassName:\"updatemenu-header-arrow\",dropdownButtonGroupClassName:\"updatemenu-dropdown-button-group\",dropdownButtonClassName:\"updatemenu-dropdown-button\",buttonClassName:\"updatemenu-button\",itemRectClassName:\"updatemenu-item-rect\",itemTextClassName:\"updatemenu-item-text\",menuIndexAttrName:\"updatemenu-active-index\",autoMarginIdRoot:\"updatemenu-\",blankHeaderOpts:{label:\"  \"},minWidth:30,minHeight:30,textPadX:24,arrowPadX:16,rx:2,ry:2,textOffsetX:12,textOffsetY:3,arrowOffsetX:4,gapButtonHeader:5,gapButton:2,activeColor:\"#F4FAFF\",hoverColor:\"#F4FAFF\",arrowSymbol:{left:\"\\u25c4\",right:\"\\u25ba\",up:\"\\u25b2\",down:\"\\u25bc\"}}},{}],684:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.buttons;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}o(\"visible\",i(t,e,{name:\"buttons\",handleItemDefaults:c}).length>0)&&(o(\"active\"),o(\"direction\"),o(\"type\"),o(\"showactive\"),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"bgcolor\",r.paper_bgcolor),o(\"bordercolor\"),o(\"borderwidth\"))}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}r(\"visible\",\"skip\"===t.method||Array.isArray(t.args))&&(r(\"method\"),r(\"args\"),r(\"label\"),r(\"execute\"))}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"./attributes\":682,\"./constants\":683}],685:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"../../constants/alignment\").LINE_SPACING,h=t(\"./constants\"),f=t(\"./scrollbox\");function p(t){return t._index}function d(t,e){return+t.attr(h.menuIndexAttrName)===e._index}function g(t,e,r,n,i,a,o,s){e.active=o,c(t.layout,h.name,e).applyUpdate(\"active\",o),\"buttons\"===e.type?m(t,n,null,null,e):\"dropdown\"===e.type&&(i.attr(h.menuIndexAttrName,\"-1\"),v(t,n,i,a,e),s||m(t,n,i,a,e))}function v(t,e,r,n,i){var a=s.ensureSingle(e,\"g\",h.headerClassName,function(t){t.style(\"pointer-events\",\"all\")}),l=i._dims,c=i.active,u=i.buttons[c]||h.blankHeaderOpts,f={y:i.pad.t,yPad:0,x:i.pad.l,xPad:0,index:0},p={width:l.headerWidth,height:l.headerHeight};a.call(y,i,u,t).call(M,i,f,p),s.ensureSingle(e,\"text\",h.headerArrowClassName,function(t){t.classed(\"user-select-none\",!0).attr(\"text-anchor\",\"end\").call(o.font,i.font).text(h.arrowSymbol[i.direction])}).attr({x:l.headerWidth-h.arrowOffsetX+i.pad.l,y:l.headerHeight/2+h.textOffsetY+i.pad.t}),a.on(\"click\",function(){r.call(S,String(d(r,i)?-1:i._index)),m(t,e,r,n,i)}),a.on(\"mouseover\",function(){a.call(w)}),a.on(\"mouseout\",function(){a.call(k,i)}),o.setTranslate(e,l.lx,l.ly)}function m(t,e,r,a,o){r||(r=e).attr(\"pointer-events\",\"all\");var l=function(t){return-1==+t.attr(h.menuIndexAttrName)}(r)&&\"buttons\"!==o.type?[]:o.buttons,c=\"dropdown\"===o.type?h.dropdownButtonClassName:h.buttonClassName,u=r.selectAll(\"g.\"+c).data(s.filterVisible(l)),f=u.enter().append(\"g\").classed(c,!0),p=u.exit();\"dropdown\"===o.type?(f.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\"),p.transition().attr(\"opacity\",\"0\").remove()):p.remove();var d=0,v=0,m=o._dims,x=-1!==[\"up\",\"down\"].indexOf(o.direction);\"dropdown\"===o.type&&(x?v=m.headerHeight+h.gapButtonHeader:d=m.headerWidth+h.gapButtonHeader),\"dropdown\"===o.type&&\"up\"===o.direction&&(v=-h.gapButtonHeader+h.gapButton-m.openHeight),\"dropdown\"===o.type&&\"left\"===o.direction&&(d=-h.gapButtonHeader+h.gapButton-m.openWidth);var b={x:m.lx+d+o.pad.l,y:m.ly+v+o.pad.t,yPad:h.gapButton,xPad:h.gapButton,index:0},T={l:b.x+o.borderwidth,t:b.y+o.borderwidth};u.each(function(s,l){var c=n.select(this);c.call(y,o,s,t).call(M,o,b),c.on(\"click\",function(){n.event.defaultPrevented||(g(t,o,0,e,r,a,l),s.execute&&i.executeAPICommand(t,s.method,s.args),t.emit(\"plotly_buttonclicked\",{menu:o,button:s,active:o.active}))}),c.on(\"mouseover\",function(){c.call(w)}),c.on(\"mouseout\",function(){c.call(k,o),u.call(_,o)})}),u.call(_,o),x?(T.w=Math.max(m.openWidth,m.headerWidth),T.h=b.y-T.t):(T.w=b.x-T.l,T.h=Math.max(m.openHeight,m.headerHeight)),T.direction=o.direction,a&&(u.size()?function(t,e,r,n,i,a){var o,s,l,c=i.direction,u=\"up\"===c||\"down\"===c,f=i._dims,p=i.active;if(u)for(s=0,l=0;l<p;l++)s+=f.heights[l]+h.gapButton;else for(o=0,l=0;l<p;l++)o+=f.widths[l]+h.gapButton;n.enable(a,o,s),n.hbar&&n.hbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\");n.vbar&&n.vbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\")}(0,0,0,a,o,T):function(t){var e=!!t.hbar,r=!!t.vbar;e&&t.hbar.transition().attr(\"opacity\",\"0\").each(\"end\",function(){e=!1,r||t.disable()});r&&t.vbar.transition().attr(\"opacity\",\"0\").each(\"end\",function(){r=!1,e||t.disable()})}(a))}function y(t,e,r,n){t.call(x,e).call(b,e,r,n)}function x(t,e){s.ensureSingle(t,\"rect\",h.itemRectClassName,function(t){t.attr({rx:h.rx,ry:h.ry,\"shape-rendering\":\"crispEdges\"})}).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\")}function b(t,e,r,n){var i=s.ensureSingle(t,\"text\",h.itemTextClassName,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":\"start\",\"data-notex\":1})}),a=r.label,c=n._fullLayout._meta;c&&(a=s.templateString(a,c)),i.call(o.font,e.font).text(a).call(l.convertToTspans,n)}function _(t,e){var r=e.active;t.each(function(t,i){var o=n.select(this);i===r&&e.showactive&&o.select(\"rect.\"+h.itemRectClassName).call(a.fill,h.activeColor)})}function w(t){t.select(\"rect.\"+h.itemRectClassName).call(a.fill,h.hoverColor)}function k(t,e){t.select(\"rect.\"+h.itemRectClassName).call(a.fill,e.bgcolor)}function T(t,e){var r=e._dims={width1:0,height1:0,heights:[],widths:[],totalWidth:0,totalHeight:0,openWidth:0,openHeight:0,lx:0,ly:0},a=o.tester.selectAll(\"g.\"+h.dropdownButtonClassName).data(s.filterVisible(e.buttons));a.enter().append(\"g\").classed(h.dropdownButtonClassName,!0);var c=-1!==[\"up\",\"down\"].indexOf(e.direction);a.each(function(i,a){var s=n.select(this);s.call(y,e,i,t);var f=s.select(\".\"+h.itemTextClassName),p=f.node()&&o.bBox(f.node()).width,d=Math.max(p+h.textPadX,h.minWidth),g=e.font.size*u,v=l.lineCount(f),m=Math.max(g*v,h.minHeight)+h.textOffsetY;m=Math.ceil(m),d=Math.ceil(d),r.widths[a]=d,r.heights[a]=m,r.height1=Math.max(r.height1,m),r.width1=Math.max(r.width1,d),c?(r.totalWidth=Math.max(r.totalWidth,d),r.openWidth=r.totalWidth,r.totalHeight+=m+h.gapButton,r.openHeight+=m+h.gapButton):(r.totalWidth+=d+h.gapButton,r.openWidth+=d+h.gapButton,r.totalHeight=Math.max(r.totalHeight,m),r.openHeight=r.totalHeight)}),c?r.totalHeight-=h.gapButton:r.totalWidth-=h.gapButton,r.headerWidth=r.width1+h.arrowPadX,r.headerHeight=r.height1,\"dropdown\"===e.type&&(c?(r.width1+=h.arrowPadX,r.totalHeight=r.height1):r.totalWidth=r.width1,r.totalWidth+=h.arrowPadX),a.remove();var f=r.totalWidth+e.pad.l+e.pad.r,p=r.totalHeight+e.pad.t+e.pad.b,d=t._fullLayout._size;r.lx=d.l+d.w*e.x,r.ly=d.t+d.h*(1-e.y);var g=\"left\";s.isRightAnchor(e)&&(r.lx-=f,g=\"right\"),s.isCenterAnchor(e)&&(r.lx-=f/2,g=\"center\");var v=\"top\";s.isBottomAnchor(e)&&(r.ly-=p,v=\"bottom\"),s.isMiddleAnchor(e)&&(r.ly-=p/2,v=\"middle\"),r.totalWidth=Math.ceil(r.totalWidth),r.totalHeight=Math.ceil(r.totalHeight),r.lx=Math.round(r.lx),r.ly=Math.round(r.ly),i.autoMargin(t,A(e),{x:e.x,y:e.y,l:f*({right:1,center:.5}[g]||0),r:f*({left:1,center:.5}[g]||0),b:p*({top:1,middle:.5}[v]||0),t:p*({bottom:1,middle:.5}[v]||0)})}function A(t){return h.autoMarginIdRoot+t._index}function M(t,e,r,n){n=n||{};var i=t.select(\".\"+h.itemRectClassName),a=t.select(\".\"+h.itemTextClassName),s=e.borderwidth,c=r.index,f=e._dims;o.setTranslate(t,s+r.x,s+r.y);var p=-1!==[\"up\",\"down\"].indexOf(e.direction),d=n.height||(p?f.heights[c]:f.height1);i.attr({x:0,y:0,width:n.width||(p?f.width1:f.widths[c]),height:d});var g=e.font.size*u,v=(l.lineCount(a)-1)*g/2;l.positionText(a,h.textOffsetX,d/2-v+h.textOffsetY),p?r.y+=f.heights[c]+r.yPad:r.x+=f.widths[c]+r.xPad,r.index++}function S(t,e){t.attr(h.menuIndexAttrName,e||\"-1\").selectAll(\"g.\"+h.dropdownButtonClassName).remove()}e.exports=function(t){var e=t._fullLayout,r=s.filterVisible(e[h.name]);function a(e){i.autoMargin(t,A(e))}var o=e._menulayer.selectAll(\"g.\"+h.containerClassName).data(r.length>0?[0]:[]);if(o.enter().append(\"g\").classed(h.containerClassName,!0).style(\"cursor\",\"pointer\"),o.exit().each(function(){n.select(this).selectAll(\"g.\"+h.headerGroupClassName).each(a)}).remove(),0!==r.length){var l=o.selectAll(\"g.\"+h.headerGroupClassName).data(r,p);l.enter().append(\"g\").classed(h.headerGroupClassName,!0);for(var c=s.ensureSingle(o,\"g\",h.dropdownButtonGroupClassName,function(t){t.style(\"pointer-events\",\"all\")}),u=0;u<r.length;u++){var y=r[u];T(t,y)}var x=\"updatemenus\"+e._uid,b=new f(t,c,x);l.enter().size()&&(c.node().parentNode.appendChild(c.node()),c.call(S)),l.exit().each(function(t){c.call(S),a(t)}).remove(),l.each(function(e){var r=n.select(this),a=\"dropdown\"===e.type?c:null;i.manageCommandObserver(t,e,e.buttons,function(n){g(t,e,e.buttons[n.index],r,a,b,n.index,!0)}),\"dropdown\"===e.type?(v(t,r,c,b,e),d(c,e)&&m(t,r,c,b,e)):m(t,r,null,null,e)})}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_template\":757,\"../../plots/plots\":828,\"../color\":593,\"../drawing\":614,\"./constants\":683,\"./scrollbox\":687,d3:163}],686:[function(t,e,r){arguments[4][680][0].apply(r,arguments)},{\"./attributes\":682,\"./constants\":683,\"./defaults\":684,\"./draw\":685,dup:680}],687:[function(t,e,r){\"use strict\";e.exports=s;var n=t(\"d3\"),i=t(\"../color\"),a=t(\"../drawing\"),o=t(\"../../lib\");function s(t,e,r){this.gd=t,this.container=e,this.id=r,this.position=null,this.translateX=null,this.translateY=null,this.hbar=null,this.vbar=null,this.bg=this.container.selectAll(\"rect.scrollbox-bg\").data([0]),this.bg.exit().on(\".drag\",null).on(\"wheel\",null).remove(),this.bg.enter().append(\"rect\").classed(\"scrollbox-bg\",!0).style(\"pointer-events\",\"all\").attr({opacity:0,x:0,y:0,width:0,height:0})}s.barWidth=2,s.barLength=20,s.barRadius=2,s.barPad=1,s.barColor=\"#808BA4\",s.prototype.enable=function(t,e,r){var o=this.gd._fullLayout,l=o.width,c=o.height;this.position=t;var u,h,f,p,d=this.position.l,g=this.position.w,v=this.position.t,m=this.position.h,y=this.position.direction,x=\"down\"===y,b=\"left\"===y,_=\"up\"===y,w=g,k=m;x||b||\"right\"===y||_||(this.position.direction=\"down\",x=!0),x||_?(h=(u=d)+w,x?(f=v,k=(p=Math.min(f+k,c))-f):k=(p=v+k)-(f=Math.max(p-k,0))):(p=(f=v)+k,b?w=(h=d+w)-(u=Math.max(h-w,0)):(u=d,w=(h=Math.min(u+w,l))-u)),this._box={l:u,t:f,w:w,h:k};var T=g>w,A=s.barLength+2*s.barPad,M=s.barWidth+2*s.barPad,S=d,E=v+m;E+M>c&&(E=c-M);var C=this.container.selectAll(\"rect.scrollbar-horizontal\").data(T?[0]:[]);C.exit().on(\".drag\",null).remove(),C.enter().append(\"rect\").classed(\"scrollbar-horizontal\",!0).call(i.fill,s.barColor),T?(this.hbar=C.attr({rx:s.barRadius,ry:s.barRadius,x:S,y:E,width:A,height:M}),this._hbarXMin=S+A/2,this._hbarTranslateMax=w-A):(delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax);var L=m>k,P=s.barWidth+2*s.barPad,O=s.barLength+2*s.barPad,z=d+g,I=v;z+P>l&&(z=l-P);var D=this.container.selectAll(\"rect.scrollbar-vertical\").data(L?[0]:[]);D.exit().on(\".drag\",null).remove(),D.enter().append(\"rect\").classed(\"scrollbar-vertical\",!0).call(i.fill,s.barColor),L?(this.vbar=D.attr({rx:s.barRadius,ry:s.barRadius,x:z,y:I,width:P,height:O}),this._vbarYMin=I+O/2,this._vbarTranslateMax=k-O):(delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax);var R=this.id,F=u-.5,B=L?h+P+.5:h+.5,N=f-.5,j=T?p+M+.5:p+.5,U=o._topdefs.selectAll(\"#\"+R).data(T||L?[0]:[]);if(U.exit().remove(),U.enter().append(\"clipPath\").attr(\"id\",R).append(\"rect\"),T||L?(this._clipRect=U.select(\"rect\").attr({x:Math.floor(F),y:Math.floor(N),width:Math.ceil(B)-Math.floor(F),height:Math.ceil(j)-Math.floor(N)}),this.container.call(a.setClipUrl,R,this.gd),this.bg.attr({x:d,y:v,width:g,height:m})):(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),T||L){var V=n.behavior.drag().on(\"dragstart\",function(){n.event.sourceEvent.preventDefault()}).on(\"drag\",this._onBoxDrag.bind(this));this.container.on(\"wheel\",null).on(\"wheel\",this._onBoxWheel.bind(this)).on(\".drag\",null).call(V);var q=n.behavior.drag().on(\"dragstart\",function(){n.event.sourceEvent.preventDefault(),n.event.sourceEvent.stopPropagation()}).on(\"drag\",this._onBarDrag.bind(this));T&&this.hbar.on(\".drag\",null).call(q),L&&this.vbar.on(\".drag\",null).call(q)}this.setTranslate(e,r)},s.prototype.disable=function(){(this.hbar||this.vbar)&&(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),this.hbar&&(this.hbar.on(\".drag\",null),this.hbar.remove(),delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax),this.vbar&&(this.vbar.on(\".drag\",null),this.vbar.remove(),delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax)},s.prototype._onBoxDrag=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t-=n.event.dx),this.vbar&&(e-=n.event.dy),this.setTranslate(t,e)},s.prototype._onBoxWheel=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t+=n.event.deltaY),this.vbar&&(e+=n.event.deltaY),this.setTranslate(t,e)},s.prototype._onBarDrag=function(){var t=this.translateX,e=this.translateY;if(this.hbar){var r=t+this._hbarXMin,i=r+this._hbarTranslateMax;t=(o.constrain(n.event.x,r,i)-r)/(i-r)*(this.position.w-this._box.w)}if(this.vbar){var a=e+this._vbarYMin,s=a+this._vbarTranslateMax;e=(o.constrain(n.event.y,a,s)-a)/(s-a)*(this.position.h-this._box.h)}this.setTranslate(t,e)},s.prototype.setTranslate=function(t,e){var r=this.position.w-this._box.w,n=this.position.h-this._box.h;if(t=o.constrain(t||0,0,r),e=o.constrain(e||0,0,n),this.translateX=t,this.translateY=e,this.container.call(a.setTranslate,this._box.l-this.position.l-t,this._box.t-this.position.t-e),this._clipRect&&this._clipRect.attr({x:Math.floor(this.position.l+t-.5),y:Math.floor(this.position.t+e-.5)}),this.hbar){var i=t/r;this.hbar.call(a.setTranslate,t+i*this._hbarTranslateMax,e)}if(this.vbar){var s=e/n;this.vbar.call(a.setTranslate,t,e+s*this._vbarTranslateMax)}}},{\"../../lib\":719,\"../color\":593,\"../drawing\":614,d3:163}],688:[function(t,e,r){\"use strict\";e.exports={FROM_BL:{left:0,center:.5,right:1,bottom:0,middle:.5,top:1},FROM_TL:{left:0,center:.5,right:1,bottom:1,middle:.5,top:0},FROM_BR:{left:1,center:.5,right:0,bottom:0,middle:.5,top:1},LINE_SPACING:1.3,CAP_SHIFT:.7,MID_SHIFT:.35,OPPOSITE_SIDE:{left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}}},{}],689:[function(t,e,r){\"use strict\";e.exports={INCREASING:{COLOR:\"#3D9970\",SYMBOL:\"\\u25b2\"},DECREASING:{COLOR:\"#FF4136\",SYMBOL:\"\\u25bc\"}}},{}],690:[function(t,e,r){\"use strict\";e.exports={FORMAT_LINK:\"https://github.com/d3/d3-3.x-api-reference/blob/master/Formatting.md#d3_format\",DATE_FORMAT_LINK:\"https://github.com/d3/d3-3.x-api-reference/blob/master/Time-Formatting.md#format\"}},{}],691:[function(t,e,r){\"use strict\";e.exports={COMPARISON_OPS:[\"=\",\"!=\",\"<\",\">=\",\">\",\"<=\"],COMPARISON_OPS2:[\"=\",\"<\",\">=\",\">\",\"<=\"],INTERVAL_OPS:[\"[]\",\"()\",\"[)\",\"(]\",\"][\",\")(\",\"](\",\")[\"],SET_OPS:[\"{}\",\"}{\"],CONSTRAINT_REDUCTION:{\"=\":\"=\",\"<\":\"<\",\"<=\":\"<\",\">\":\">\",\">=\":\">\",\"[]\":\"[]\",\"()\":\"[]\",\"[)\":\"[]\",\"(]\":\"[]\",\"][\":\"][\",\")(\":\"][\",\"](\":\"][\",\")[\":\"][\"}}},{}],692:[function(t,e,r){\"use strict\";e.exports={solid:[[],0],dot:[[.5,1],200],dash:[[.5,1],50],longdash:[[.5,1],10],dashdot:[[.5,.625,.875,1],50],longdashdot:[[.5,.7,.8,1],10]}},{}],693:[function(t,e,r){\"use strict\";e.exports={circle:\"\\u25cf\",\"circle-open\":\"\\u25cb\",square:\"\\u25a0\",\"square-open\":\"\\u25a1\",diamond:\"\\u25c6\",\"diamond-open\":\"\\u25c7\",cross:\"+\",x:\"\\u274c\"}},{}],694:[function(t,e,r){\"use strict\";e.exports={SHOW_PLACEHOLDER:100,HIDE_PLACEHOLDER:1e3,DESELECTDIM:.2}},{}],695:[function(t,e,r){\"use strict\";e.exports={BADNUM:void 0,FP_SAFE:Number.MAX_VALUE/1e4,ONEAVGYEAR:315576e5,ONEAVGMONTH:26298e5,ONEDAY:864e5,ONEHOUR:36e5,ONEMIN:6e4,ONESEC:1e3,EPOCHJD:2440587.5,ALMOST_EQUAL:1-1e-6,LOG_CLIP:10,MINUS_SIGN:\"\\u2212\"}},{}],696:[function(t,e,r){\"use strict\";r.xmlns=\"http://www.w3.org/2000/xmlns/\",r.svg=\"http://www.w3.org/2000/svg\",r.xlink=\"http://www.w3.org/1999/xlink\",r.svgAttrs={xmlns:r.svg,\"xmlns:xlink\":r.xlink}},{}],697:[function(t,e,r){\"use strict\";r.version=\"1.49.1\",t(\"es6-promise\").polyfill(),t(\"../build/plotcss\"),t(\"./fonts/mathjax_config\")();for(var n=t(\"./registry\"),i=r.register=n.register,a=t(\"./plot_api\"),o=Object.keys(a),s=0;s<o.length;s++){var l=o[s];\"_\"!==l.charAt(0)&&(r[l]=a[l]),i({moduleType:\"apiMethod\",name:l,fn:a[l]})}i(t(\"./traces/scatter\")),i([t(\"./components/fx\"),t(\"./components/legend\"),t(\"./components/annotations\"),t(\"./components/annotations3d\"),t(\"./components/shapes\"),t(\"./components/images\"),t(\"./components/updatemenus\"),t(\"./components/sliders\"),t(\"./components/rangeslider\"),t(\"./components/rangeselector\"),t(\"./components/grid\"),t(\"./components/errorbars\"),t(\"./components/colorscale\"),t(\"./components/colorbar\")]),i([t(\"./locale-en\"),t(\"./locale-en-us\")]),r.Icons=t(\"./fonts/ploticon\"),r.Plots=t(\"./plots/plots\"),r.Fx=t(\"./components/fx\"),r.Snapshot=t(\"./snapshot\"),r.PlotSchema=t(\"./plot_api/plot_schema\"),r.Queue=t(\"./lib/queue\"),r.d3=t(\"d3\")},{\"../build/plotcss\":1,\"./components/annotations\":584,\"./components/annotations3d\":589,\"./components/colorbar\":599,\"./components/colorscale\":605,\"./components/errorbars\":620,\"./components/fx\":632,\"./components/grid\":636,\"./components/images\":641,\"./components/legend\":649,\"./components/rangeselector\":660,\"./components/rangeslider\":667,\"./components/shapes\":675,\"./components/sliders\":680,\"./components/updatemenus\":686,\"./fonts/mathjax_config\":698,\"./fonts/ploticon\":699,\"./lib/queue\":734,\"./locale-en\":748,\"./locale-en-us\":747,\"./plot_api\":752,\"./plot_api/plot_schema\":756,\"./plots/plots\":828,\"./registry\":847,\"./snapshot\":852,\"./traces/scatter\":1123,d3:163,\"es6-promise\":218}],698:[function(t,e,r){\"use strict\";e.exports=function(){\"undefined\"!=typeof MathJax&&(\"local\"!==(window.PlotlyConfig||{}).MathJaxConfig&&(MathJax.Hub.Config({messageStyle:\"none\",skipStartupTypeset:!0,displayAlign:\"left\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]}}),MathJax.Hub.Configured()))}},{}],699:[function(t,e,r){\"use strict\";e.exports={undo:{width:857.1,height:1e3,path:\"m857 350q0-87-34-166t-91-137-137-92-166-34q-96 0-183 41t-147 114q-4 6-4 13t5 11l76 77q6 5 14 5 9-1 13-7 41-53 100-82t126-29q58 0 110 23t92 61 61 91 22 111-22 111-61 91-92 61-110 23q-55 0-105-20t-90-57l77-77q17-16 8-38-10-23-33-23h-250q-15 0-25 11t-11 25v250q0 24 22 33 22 10 39-8l72-72q60 57 137 88t159 31q87 0 166-34t137-92 91-137 34-166z\",transform:\"matrix(1 0 0 -1 0 850)\"},home:{width:928.6,height:1e3,path:\"m786 296v-267q0-15-11-26t-25-10h-214v214h-143v-214h-214q-15 0-25 10t-11 26v267q0 1 0 2t0 2l321 264 321-264q1-1 1-4z m124 39l-34-41q-5-5-12-6h-2q-7 0-12 3l-386 322-386-322q-7-4-13-4-7 2-12 7l-35 41q-4 5-3 13t6 12l401 334q18 15 42 15t43-15l136-114v109q0 8 5 13t13 5h107q8 0 13-5t5-13v-227l122-102q5-5 6-12t-4-13z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"camera-retro\":{width:1e3,height:1e3,path:\"m518 386q0 8-5 13t-13 5q-37 0-63-27t-26-63q0-8 5-13t13-5 12 5 5 13q0 23 16 38t38 16q8 0 13 5t5 13z m125-73q0-59-42-101t-101-42-101 42-42 101 42 101 101 42 101-42 42-101z m-572-320h858v71h-858v-71z m643 320q0 89-62 152t-152 62-151-62-63-152 63-151 151-63 152 63 62 151z m-571 358h214v72h-214v-72z m-72-107h858v143h-462l-36-71h-360v-72z m929 143v-714q0-30-21-51t-50-21h-858q-29 0-50 21t-21 51v714q0 30 21 51t50 21h858q29 0 50-21t21-51z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoombox:{width:1e3,height:1e3,path:\"m1000-25l-250 251c40 63 63 138 63 218 0 224-182 406-407 406-224 0-406-182-406-406s183-406 407-406c80 0 155 22 218 62l250-250 125 125z m-812 250l0 438 437 0 0-438-437 0z m62 375l313 0 0-312-313 0 0 312z\",transform:\"matrix(1 0 0 -1 0 850)\"},pan:{width:1e3,height:1e3,path:\"m1000 350l-187 188 0-125-250 0 0 250 125 0-188 187-187-187 125 0 0-250-250 0 0 125-188-188 186-187 0 125 252 0 0-250-125 0 187-188 188 188-125 0 0 250 250 0 0-126 187 188z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_plus:{width:875,height:1e3,path:\"m1 787l0-875 875 0 0 875-875 0z m687-500l-187 0 0-187-125 0 0 187-188 0 0 125 188 0 0 187 125 0 0-187 187 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_minus:{width:875,height:1e3,path:\"m0 788l0-876 875 0 0 876-875 0z m688-500l-500 0 0 125 500 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},autoscale:{width:1e3,height:1e3,path:\"m250 850l-187 0-63 0 0-62 0-188 63 0 0 188 187 0 0 62z m688 0l-188 0 0-62 188 0 0-188 62 0 0 188 0 62-62 0z m-875-938l0 188-63 0 0-188 0-62 63 0 187 0 0 62-187 0z m875 188l0-188-188 0 0-62 188 0 62 0 0 62 0 188-62 0z m-125 188l-1 0-93-94-156 156 156 156 92-93 2 0 0 250-250 0 0-2 93-92-156-156-156 156 94 92 0 2-250 0 0-250 0 0 93 93 157-156-157-156-93 94 0 0 0-250 250 0 0 0-94 93 156 157 156-157-93-93 0 0 250 0 0 250z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_basic:{width:1500,height:1e3,path:\"m375 725l0 0-375-375 375-374 0-1 1125 0 0 750-1125 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_compare:{width:1125,height:1e3,path:\"m187 786l0 2-187-188 188-187 0 0 937 0 0 373-938 0z m0-499l0 1-187-188 188-188 0 0 937 0 0 376-938-1z\",transform:\"matrix(1 0 0 -1 0 850)\"},plotlylogo:{width:1542,height:1e3,path:\"m0-10h182v-140h-182v140z m228 146h183v-286h-183v286z m225 714h182v-1000h-182v1000z m225-285h182v-715h-182v715z m225 142h183v-857h-183v857z m231-428h182v-429h-182v429z m225-291h183v-138h-183v138z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"z-axis\":{width:1e3,height:1e3,path:\"m833 5l-17 108v41l-130-65 130-66c0 0 0 38 0 39 0-1 36-14 39-25 4-15-6-22-16-30-15-12-39-16-56-20-90-22-187-23-279-23-261 0-341 34-353 59 3 60 228 110 228 110-140-8-351-35-351-116 0-120 293-142 474-142 155 0 477 22 477 142 0 50-74 79-163 96z m-374 94c-58-5-99-21-99-40 0-24 65-43 144-43 79 0 143 19 143 43 0 19-42 34-98 40v216h87l-132 135-133-135h88v-216z m167 515h-136v1c16 16 31 34 46 52l84 109v54h-230v-71h124v-1c-16-17-28-32-44-51l-89-114v-51h245v72z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"3d_rotate\":{width:1e3,height:1e3,path:\"m922 660c-5 4-9 7-14 11-359 263-580-31-580-31l-102 28 58-400c0 1 1 1 2 2 118 108 351 249 351 249s-62 27-100 42c88 83 222 183 347 122 16-8 30-17 44-27-2 1-4 2-6 4z m36-329c0 0 64 229-88 296-62 27-124 14-175-11 157-78 225-208 249-266 8-19 11-31 11-31 2 5 6 15 11 32-5-13-8-20-8-20z m-775-239c70-31 117-50 198-32-121 80-199 346-199 346l-96-15-58-12c0 0 55-226 155-287z m603 133l-317-139c0 0 4-4 19-14 7-5 24-15 24-15s-177-147-389 4c235-287 536-112 536-112l31-22 100 299-4-1z m-298-153c6-4 14-9 24-15 0 0-17 10-24 15z\",transform:\"matrix(1 0 0 -1 0 850)\"},camera:{width:1e3,height:1e3,path:\"m500 450c-83 0-150-67-150-150 0-83 67-150 150-150 83 0 150 67 150 150 0 83-67 150-150 150z m400 150h-120c-16 0-34 13-39 29l-31 93c-6 15-23 28-40 28h-340c-16 0-34-13-39-28l-31-94c-6-15-23-28-40-28h-120c-55 0-100-45-100-100v-450c0-55 45-100 100-100h800c55 0 100 45 100 100v450c0 55-45 100-100 100z m-400-550c-138 0-250 112-250 250 0 138 112 250 250 250 138 0 250-112 250-250 0-138-112-250-250-250z m365 380c-19 0-35 16-35 35 0 19 16 35 35 35 19 0 35-16 35-35 0-19-16-35-35-35z\",transform:\"matrix(1 0 0 -1 0 850)\"},movie:{width:1e3,height:1e3,path:\"m938 413l-188-125c0 37-17 71-44 94 64 38 107 107 107 187 0 121-98 219-219 219-121 0-219-98-219-219 0-61 25-117 66-156h-115c30 33 49 76 49 125 0 103-84 187-187 187s-188-84-188-187c0-57 26-107 65-141-38-22-65-62-65-109v-250c0-70 56-126 125-126h500c69 0 125 56 125 126l188-126c34 0 62 28 62 63v375c0 35-28 63-62 63z m-750 0c-69 0-125 56-125 125s56 125 125 125 125-56 125-125-56-125-125-125z m406-1c-87 0-157 70-157 157 0 86 70 156 157 156s156-70 156-156-70-157-156-157z\",transform:\"matrix(1 0 0 -1 0 850)\"},question:{width:857.1,height:1e3,path:\"m500 82v107q0 8-5 13t-13 5h-107q-8 0-13-5t-5-13v-107q0-8 5-13t13-5h107q8 0 13 5t5 13z m143 375q0 49-31 91t-77 65-95 23q-136 0-207-119-9-14 4-24l74-55q4-4 10-4 9 0 14 7 30 38 48 51 19 14 48 14 27 0 48-15t21-33q0-21-11-34t-38-25q-35-16-65-48t-29-70v-20q0-8 5-13t13-5h107q8 0 13 5t5 13q0 10 12 27t30 28q18 10 28 16t25 19 25 27 16 34 7 45z m214-107q0-117-57-215t-156-156-215-58-216 58-155 156-58 215 58 215 155 156 216 58 215-58 156-156 57-215z\",transform:\"matrix(1 0 0 -1 0 850)\"},disk:{width:857.1,height:1e3,path:\"m214-7h429v214h-429v-214z m500 0h72v500q0 8-6 21t-11 20l-157 156q-5 6-19 12t-22 5v-232q0-22-15-38t-38-16h-322q-22 0-37 16t-16 38v232h-72v-714h72v232q0 22 16 38t37 16h465q22 0 38-16t15-38v-232z m-214 518v178q0 8-5 13t-13 5h-107q-7 0-13-5t-5-13v-178q0-8 5-13t13-5h107q7 0 13 5t5 13z m357-18v-518q0-22-15-38t-38-16h-750q-23 0-38 16t-16 38v750q0 22 16 38t38 16h517q23 0 50-12t42-26l156-157q16-15 27-42t11-49z\",transform:\"matrix(1 0 0 -1 0 850)\"},lasso:{width:1031,height:1e3,path:\"m1018 538c-36 207-290 336-568 286-277-48-473-256-436-463 10-57 36-108 76-151-13-66 11-137 68-183 34-28 75-41 114-42l-55-70 0 0c-2-1-3-2-4-3-10-14-8-34 5-45 14-11 34-8 45 4 1 1 2 3 2 5l0 0 113 140c16 11 31 24 45 40 4 3 6 7 8 11 48-3 100 0 151 9 278 48 473 255 436 462z m-624-379c-80 14-149 48-197 96 42 42 109 47 156 9 33-26 47-66 41-105z m-187-74c-19 16-33 37-39 60 50-32 109-55 174-68-42-25-95-24-135 8z m360 75c-34-7-69-9-102-8 8 62-16 128-68 170-73 59-175 54-244-5-9 20-16 40-20 61-28 159 121 317 333 354s407-60 434-217c28-159-121-318-333-355z\",transform:\"matrix(1 0 0 -1 0 850)\"},selectbox:{width:1e3,height:1e3,path:\"m0 850l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-285l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},spikeline:{width:1e3,height:1e3,path:\"M512 409c0-57-46-104-103-104-57 0-104 47-104 104 0 57 47 103 104 103 57 0 103-46 103-103z m-327-39l92 0 0 92-92 0z m-185 0l92 0 0 92-92 0z m370-186l92 0 0 93-92 0z m0-184l92 0 0 92-92 0z\",transform:\"matrix(1.5 0 0 -1.5 0 850)\"},pencil:{width:1792,height:1792,path:\"M491 1536l91-91-235-235-91 91v107h128v128h107zm523-928q0-22-22-22-10 0-17 7l-542 542q-7 7-7 17 0 22 22 22 10 0 17-7l542-542q7-7 7-17zm-54-192l416 416-832 832h-416v-416zm683 96q0 53-37 90l-166 166-416-416 166-165q36-38 90-38 53 0 91 38l235 234q37 39 37 91z\",transform:\"matrix(1 0 0 1 0 1)\"},newplotlylogo:{name:\"newplotlylogo\",svg:\"<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 132 132'><defs><style>.cls-1 {fill: #119dff;} .cls-2 {fill: #25fefd;} .cls-3 {fill: #fff;}</style></defs><title>plotly-logomark</title><g id='symbol'><rect class='cls-1' width='132' height='132' rx='6' ry='6'/><circle class='cls-2' cx='78' cy='54' r='6'/><circle class='cls-2' cx='102' cy='30' r='6'/><circle class='cls-2' cx='78' cy='30' r='6'/><circle class='cls-2' cx='54' cy='30' r='6'/><circle class='cls-2' cx='30' cy='30' r='6'/><circle class='cls-2' cx='30' cy='54' r='6'/><path class='cls-3' d='M30,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,30,72Z'/><path class='cls-3' d='M78,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,78,72Z'/><path class='cls-3' d='M54,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,54,48Z'/><path class='cls-3' d='M102,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,102,48Z'/></g></svg>\"}}},{}],700:[function(t,e,r){\"use strict\";r.isLeftAnchor=function(t){return\"left\"===t.xanchor||\"auto\"===t.xanchor&&t.x<=1/3},r.isCenterAnchor=function(t){return\"center\"===t.xanchor||\"auto\"===t.xanchor&&t.x>1/3&&t.x<2/3},r.isRightAnchor=function(t){return\"right\"===t.xanchor||\"auto\"===t.xanchor&&t.x>=2/3},r.isTopAnchor=function(t){return\"top\"===t.yanchor||\"auto\"===t.yanchor&&t.y>=2/3},r.isMiddleAnchor=function(t){return\"middle\"===t.yanchor||\"auto\"===t.yanchor&&t.y>1/3&&t.y<2/3},r.isBottomAnchor=function(t){return\"bottom\"===t.yanchor||\"auto\"===t.yanchor&&t.y<=1/3}},{}],701:[function(t,e,r){\"use strict\";var n=t(\"./mod\"),i=n.mod,a=n.modHalf,o=Math.PI,s=2*o;function l(t){return Math.abs(t[1]-t[0])>s-1e-14}function c(t,e){return a(e-t,s)}function u(t,e){if(l(e))return!0;var r,n;e[0]<e[1]?(r=e[0],n=e[1]):(r=e[1],n=e[0]),(r=i(r,s))>(n=i(n,s))&&(n+=s);var a=i(t,s),o=a+s;return a>=r&&a<=n||o>=r&&o<=n}function h(t,e,r,n,i,a,c){i=i||0,a=a||0;var u,h,f,p,d,g=l([r,n]);function v(t,e){return[t*Math.cos(e)+i,a-t*Math.sin(e)]}g?(u=0,h=o,f=s):r<n?(u=r,f=n):(u=n,f=r),t<e?(p=t,d=e):(p=e,d=t);var m,y=Math.abs(f-u)<=o?0:1;function x(t,e,r){return\"A\"+[t,t]+\" \"+[0,y,r]+\" \"+v(t,e)}return g?m=null===p?\"M\"+v(d,u)+x(d,h,0)+x(d,f,0)+\"Z\":\"M\"+v(p,u)+x(p,h,0)+x(p,f,0)+\"ZM\"+v(d,u)+x(d,h,1)+x(d,f,1)+\"Z\":null===p?(m=\"M\"+v(d,u)+x(d,f,0),c&&(m+=\"L0,0Z\")):m=\"M\"+v(p,u)+\"L\"+v(d,u)+x(d,f,0)+\"L\"+v(p,f)+x(p,u,1)+\"Z\",m}e.exports={deg2rad:function(t){return t/180*o},rad2deg:function(t){return t/o*180},angleDelta:c,angleDist:function(t,e){return Math.abs(c(t,e))},isFullCircle:l,isAngleInsideSector:u,isPtInsideSector:function(t,e,r,n){return!!u(e,n)&&(r[0]<r[1]?(i=r[0],a=r[1]):(i=r[1],a=r[0]),t>=i&&t<=a);var i,a},pathArc:function(t,e,r,n,i){return h(null,t,e,r,n,i,0)},pathSector:function(t,e,r,n,i){return h(null,t,e,r,n,i,1)},pathAnnulus:function(t,e,r,n,i,a){return h(t,e,r,n,i,a,1)}}},{\"./mod\":726}],702:[function(t,e,r){\"use strict\";var n=Array.isArray,i=\"undefined\"!=typeof ArrayBuffer&&ArrayBuffer.isView?ArrayBuffer:{isView:function(){return!1}},a=\"undefined\"==typeof DataView?function(){}:DataView;function o(t){return i.isView(t)&&!(t instanceof a)}function s(t){return n(t)||o(t)}function l(t,e,r){if(s(t)){if(s(t[0])){for(var n=r,i=0;i<t.length;i++)n=e(n,t[i].length);return n}return t.length}return 0}r.isTypedArray=o,r.isArrayOrTypedArray=s,r.isArray1D=function(t){return!s(t[0])},r.ensureArray=function(t,e){return n(t)||(t=[]),t.length=e,t},r.concat=function(){var t,e,r,i,a,o,s,l,c=[],u=!0,h=0;for(r=0;r<arguments.length;r++)(o=(i=arguments[r]).length)&&(e?c.push(i):(e=i,a=o),n(i)?t=!1:(u=!1,h?t!==i.constructor&&(t=!1):t=i.constructor),h+=o);if(!h)return[];if(!c.length)return e;if(u)return e.concat.apply(e,c);if(t){for((s=new t(h)).set(e),r=0;r<c.length;r++)i=c[r],s.set(i,a),a+=i.length;return s}for(s=new Array(h),l=0;l<e.length;l++)s[l]=e[l];for(r=0;r<c.length;r++){for(i=c[r],l=0;l<i.length;l++)s[a+l]=i[l];a+=l}return s},r.maxRowLength=function(t){return l(t,Math.max,0)},r.minRowLength=function(t){return l(t,Math.min,1/0)}},{}],703:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../constants/numerical\").BADNUM,a=/^['\"%,$#\\s']+|[, ]|['\"%,$#\\s']+$/g;e.exports=function(t){return\"string\"==typeof t&&(t=t.replace(a,\"\")),n(t)?Number(t):i}},{\"../constants/numerical\":695,\"fast-isnumeric\":225}],704:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t._fullLayout;e._glcanvas&&e._glcanvas.size()&&e._glcanvas.each(function(t){t.regl&&t.regl.clear({color:!0,depth:!0})})}},{}],705:[function(t,e,r){\"use strict\";e.exports=function(t){t._responsiveChartHandler&&(window.removeEventListener(\"resize\",t._responsiveChartHandler),delete t._responsiveChartHandler)}},{}],706:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../plots/attributes\"),o=t(\"../components/colorscale/scales\"),s=t(\"../constants/interactions\").DESELECTDIM,l=t(\"./nested_property\"),c=t(\"./regex\").counter,u=t(\"./mod\").modHalf,h=t(\"./array\").isArrayOrTypedArray;function f(t,e){var n=r.valObjectMeta[e.valType];if(e.arrayOk&&h(t))return!0;if(n.validateFunction)return n.validateFunction(t,e);var i={},a=i,o={set:function(t){a=t}};return n.coerceFunction(t,o,i,e),a!==i}r.valObjectMeta={data_array:{coerceFunction:function(t,e,r){h(t)?e.set(t):void 0!==r&&e.set(r)}},enumerated:{coerceFunction:function(t,e,r,n){n.coerceNumber&&(t=+t),-1===n.values.indexOf(t)?e.set(r):e.set(t)},validateFunction:function(t,e){e.coerceNumber&&(t=+t);for(var r=e.values,n=0;n<r.length;n++){var i=String(r[n]);if(\"/\"===i.charAt(0)&&\"/\"===i.charAt(i.length-1)){if(new RegExp(i.substr(1,i.length-2)).test(t))return!0}else if(t===r[n])return!0}return!1}},boolean:{coerceFunction:function(t,e,r){!0===t||!1===t?e.set(t):e.set(r)}},number:{coerceFunction:function(t,e,r,i){!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},integer:{coerceFunction:function(t,e,r,i){t%1||!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},string:{coerceFunction:function(t,e,r,n){if(\"string\"!=typeof t){var i=\"number\"==typeof t;!0!==n.strict&&i?e.set(String(t)):e.set(r)}else n.noBlank&&!t?e.set(r):e.set(t)}},color:{coerceFunction:function(t,e,r){i(t).isValid()?e.set(t):e.set(r)}},colorlist:{coerceFunction:function(t,e,r){Array.isArray(t)&&t.length&&t.every(function(t){return i(t).isValid()})?e.set(t):e.set(r)}},colorscale:{coerceFunction:function(t,e,r){e.set(o.get(t,r))}},angle:{coerceFunction:function(t,e,r){\"auto\"===t?e.set(\"auto\"):n(t)?e.set(u(+t,360)):e.set(r)}},subplotid:{coerceFunction:function(t,e,r,n){var i=n.regex||c(r);\"string\"==typeof t&&i.test(t)?e.set(t):e.set(r)},validateFunction:function(t,e){var r=e.dflt;return t===r||\"string\"==typeof t&&!!c(r).test(t)}},flaglist:{coerceFunction:function(t,e,r,n){if(\"string\"==typeof t)if(-1===(n.extras||[]).indexOf(t)){for(var i=t.split(\"+\"),a=0;a<i.length;){var o=i[a];-1===n.flags.indexOf(o)||i.indexOf(o)<a?i.splice(a,1):a++}i.length?e.set(i.join(\"+\")):e.set(r)}else e.set(t);else e.set(r)}},any:{coerceFunction:function(t,e,r){void 0===t?e.set(r):e.set(t)}},info_array:{coerceFunction:function(t,e,n,i){function a(t,e,n){var i,a={set:function(t){i=t}};return void 0===n&&(n=e.dflt),r.valObjectMeta[e.valType].coerceFunction(t,a,n,e),i}var o=2===i.dimensions||\"1-2\"===i.dimensions&&Array.isArray(t)&&Array.isArray(t[0]);if(Array.isArray(t)){var s,l,c,u,h,f,p=i.items,d=[],g=Array.isArray(p),v=g&&o&&Array.isArray(p[0]),m=o&&g&&!v,y=g&&!m?p.length:t.length;if(n=Array.isArray(n)?n:[],o)for(s=0;s<y;s++)for(d[s]=[],c=Array.isArray(t[s])?t[s]:[],h=m?p.length:g?p[s].length:c.length,l=0;l<h;l++)u=m?p[l]:g?p[s][l]:p,void 0!==(f=a(c[l],u,(n[s]||[])[l]))&&(d[s][l]=f);else for(s=0;s<y;s++)void 0!==(f=a(t[s],g?p[s]:p,n[s]))&&(d[s]=f);e.set(d)}else e.set(n)},validateFunction:function(t,e){if(!Array.isArray(t))return!1;var r=e.items,n=Array.isArray(r),i=2===e.dimensions;if(!e.freeLength&&t.length!==r.length)return!1;for(var a=0;a<t.length;a++)if(i){if(!Array.isArray(t[a])||!e.freeLength&&t[a].length!==r[a].length)return!1;for(var o=0;o<t[a].length;o++)if(!f(t[a][o],n?r[a][o]:r))return!1}else if(!f(t[a],n?r[a]:r))return!1;return!0}}},r.coerce=function(t,e,n,i,a){var o=l(n,i).get(),s=l(t,i),c=l(e,i),u=s.get(),p=e._template;if(void 0===u&&p&&(u=l(p,i).get(),p=0),void 0===a&&(a=o.dflt),o.arrayOk&&h(u))return c.set(u),u;var d=r.valObjectMeta[o.valType].coerceFunction;d(u,c,a,o);var g=c.get();return p&&g===a&&!f(u,o)&&(d(u=l(p,i).get(),c,a,o),g=c.get()),g},r.coerce2=function(t,e,n,i,a){var o=l(t,i),s=r.coerce(t,e,n,i,a),c=o.get();return null!=c&&s},r.coerceFont=function(t,e,r){var n={};return r=r||{},n.family=t(e+\".family\",r.family),n.size=t(e+\".size\",r.size),n.color=t(e+\".color\",r.color),n},r.coerceHoverinfo=function(t,e,n){var i,o=e._module.attributes,s=o.hoverinfo?o:a,l=s.hoverinfo;if(1===n._dataLength){var c=\"all\"===l.dflt?l.flags.slice():l.dflt.split(\"+\");c.splice(c.indexOf(\"name\"),1),i=c.join(\"+\")}return r.coerce(t,e,s,\"hoverinfo\",i)},r.coerceSelectionMarkerOpacity=function(t,e){if(t.marker){var r,n,i=t.marker.opacity;if(void 0!==i)h(i)||t.selected||t.unselected||(r=i,n=s*i),e(\"selected.marker.opacity\",r),e(\"unselected.marker.opacity\",n)}},r.validate=f},{\"../components/colorscale/scales\":608,\"../constants/interactions\":694,\"../plots/attributes\":764,\"./array\":702,\"./mod\":726,\"./nested_property\":727,\"./regex\":735,\"fast-isnumeric\":225,tinycolor2:537}],707:[function(t,e,r){\"use strict\";var n,i,a=t(\"d3\"),o=t(\"fast-isnumeric\"),s=t(\"./loggers\"),l=t(\"./mod\").mod,c=t(\"../constants/numerical\"),u=c.BADNUM,h=c.ONEDAY,f=c.ONEHOUR,p=c.ONEMIN,d=c.ONESEC,g=c.EPOCHJD,v=t(\"../registry\"),m=a.time.format.utc,y=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\d)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d:?\\d\\d)?)?)?)?)?\\s*$/m,x=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\di?)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d:?\\d\\d)?)?)?)?)?\\s*$/m,b=(new Date).getFullYear()-70;function _(t){return t&&v.componentsRegistry.calendars&&\"string\"==typeof t&&\"gregorian\"!==t}function w(t,e){return String(t+Math.pow(10,e)).substr(1)}r.dateTick0=function(t,e){return _(t)?e?v.getComponentMethod(\"calendars\",\"CANONICAL_SUNDAY\")[t]:v.getComponentMethod(\"calendars\",\"CANONICAL_TICK\")[t]:e?\"2000-01-02\":\"2000-01-01\"},r.dfltRange=function(t){return _(t)?v.getComponentMethod(\"calendars\",\"DFLTRANGE\")[t]:[\"2000-01-01\",\"2001-01-01\"]},r.isJSDate=function(t){return\"object\"==typeof t&&null!==t&&\"function\"==typeof t.getTime},r.dateTime2ms=function(t,e){if(r.isJSDate(t)){var a=t.getTimezoneOffset()*p,o=(t.getUTCMinutes()-t.getMinutes())*p+(t.getUTCSeconds()-t.getSeconds())*d+(t.getUTCMilliseconds()-t.getMilliseconds());if(o){var s=3*p;a=a-s/2+l(o-a+s/2,s)}return(t=Number(t)-a)>=n&&t<=i?t:u}if(\"string\"!=typeof t&&\"number\"!=typeof t)return u;t=String(t);var c=_(e),m=t.charAt(0);!c||\"G\"!==m&&\"g\"!==m||(t=t.substr(1),e=\"\");var w=c&&\"chinese\"===e.substr(0,7),k=t.match(w?x:y);if(!k)return u;var T=k[1],A=k[3]||\"1\",M=Number(k[5]||1),S=Number(k[7]||0),E=Number(k[9]||0),C=Number(k[11]||0);if(c){if(2===T.length)return u;var L;T=Number(T);try{var P=v.getComponentMethod(\"calendars\",\"getCal\")(e);if(w){var O=\"i\"===A.charAt(A.length-1);A=parseInt(A,10),L=P.newDate(T,P.toMonthIndex(T,A,O),M)}else L=P.newDate(T,Number(A),M)}catch(t){return u}return L?(L.toJD()-g)*h+S*f+E*p+C*d:u}T=2===T.length?(Number(T)+2e3-b)%100+b:Number(T),A-=1;var z=new Date(Date.UTC(2e3,A,M,S,E));return z.setUTCFullYear(T),z.getUTCMonth()!==A?u:z.getUTCDate()!==M?u:z.getTime()+C*d},n=r.MIN_MS=r.dateTime2ms(\"-9999\"),i=r.MAX_MS=r.dateTime2ms(\"9999-12-31 23:59:59.9999\"),r.isDateTime=function(t,e){return r.dateTime2ms(t,e)!==u};var k=90*h,T=3*f,A=5*p;function M(t,e,r,n,i){if((e||r||n||i)&&(t+=\" \"+w(e,2)+\":\"+w(r,2),(n||i)&&(t+=\":\"+w(n,2),i))){for(var a=4;i%10==0;)a-=1,i/=10;t+=\".\"+w(i,a)}return t}r.ms2DateTime=function(t,e,r){if(\"number\"!=typeof t||!(t>=n&&t<=i))return u;e||(e=0);var a,o,s,c,y,x,b=Math.floor(10*l(t+.05,1)),w=Math.round(t-b/10);if(_(r)){var S=Math.floor(w/h)+g,E=Math.floor(l(t,h));try{a=v.getComponentMethod(\"calendars\",\"getCal\")(r).fromJD(S).formatDate(\"yyyy-mm-dd\")}catch(t){a=m(\"G%Y-%m-%d\")(new Date(w))}if(\"-\"===a.charAt(0))for(;a.length<11;)a=\"-0\"+a.substr(1);else for(;a.length<10;)a=\"0\"+a;o=e<k?Math.floor(E/f):0,s=e<k?Math.floor(E%f/p):0,c=e<T?Math.floor(E%p/d):0,y=e<A?E%d*10+b:0}else x=new Date(w),a=m(\"%Y-%m-%d\")(x),o=e<k?x.getUTCHours():0,s=e<k?x.getUTCMinutes():0,c=e<T?x.getUTCSeconds():0,y=e<A?10*x.getUTCMilliseconds()+b:0;return M(a,o,s,c,y)},r.ms2DateTimeLocal=function(t){if(!(t>=n+h&&t<=i-h))return u;var e=Math.floor(10*l(t+.05,1)),r=new Date(Math.round(t-e/10));return M(a.time.format(\"%Y-%m-%d\")(r),r.getHours(),r.getMinutes(),r.getSeconds(),10*r.getUTCMilliseconds()+e)},r.cleanDate=function(t,e,n){if(t===u)return e;if(r.isJSDate(t)||\"number\"==typeof t&&isFinite(t)){if(_(n))return s.error(\"JS Dates and milliseconds are incompatible with world calendars\",t),e;if(!(t=r.ms2DateTimeLocal(+t))&&void 0!==e)return e}else if(!r.isDateTime(t,n))return s.error(\"unrecognized date\",t),e;return t};var S=/%\\d?f/g;function E(t,e,r,n){t=t.replace(S,function(t){var r=Math.min(+t.charAt(1)||6,6);return(e/1e3%1+2).toFixed(r).substr(2).replace(/0+$/,\"\")||\"0\"});var i=new Date(Math.floor(e+.05));if(_(n))try{t=v.getComponentMethod(\"calendars\",\"worldCalFmt\")(t,e,n)}catch(t){return\"Invalid\"}return r(t)(i)}var C=[59,59.9,59.99,59.999,59.9999];r.formatDate=function(t,e,r,n,i,a){if(i=_(i)&&i,!e)if(\"y\"===r)e=a.year;else if(\"m\"===r)e=a.month;else{if(\"d\"!==r)return function(t,e){var r=l(t+.05,h),n=w(Math.floor(r/f),2)+\":\"+w(l(Math.floor(r/p),60),2);if(\"M\"!==e){o(e)||(e=0);var i=(100+Math.min(l(t/d,60),C[e])).toFixed(e).substr(1);e>0&&(i=i.replace(/0+$/,\"\").replace(/[\\.]$/,\"\")),n+=\":\"+i}return n}(t,r)+\"\\n\"+E(a.dayMonthYear,t,n,i);e=a.dayMonth+\"\\n\"+a.year}return E(e,t,n,i)};var L=3*h;r.incrementMonth=function(t,e,r){r=_(r)&&r;var n=l(t,h);if(t=Math.round(t-n),r)try{var i=Math.round(t/h)+g,a=v.getComponentMethod(\"calendars\",\"getCal\")(r),o=a.fromJD(i);return e%12?a.add(o,e,\"m\"):a.add(o,e/12,\"y\"),(o.toJD()-g)*h+n}catch(e){s.error(\"invalid ms \"+t+\" in calendar \"+r)}var c=new Date(t+L);return c.setUTCMonth(c.getUTCMonth()+e)+n-L},r.findExactDates=function(t,e){for(var r,n,i=0,a=0,s=0,l=0,c=_(e)&&v.getComponentMethod(\"calendars\",\"getCal\")(e),u=0;u<t.length;u++)if(n=t[u],o(n)){if(!(n%h))if(c)try{1===(r=c.fromJD(n/h+g)).day()?1===r.month()?i++:a++:s++}catch(t){}else 1===(r=new Date(n)).getUTCDate()?0===r.getUTCMonth()?i++:a++:s++}else l++;s+=a+=i;var f=t.length-l;return{exactYears:i/f,exactMonths:a/f,exactDays:s/f}}},{\"../constants/numerical\":695,\"../registry\":847,\"./loggers\":723,\"./mod\":726,d3:163,\"fast-isnumeric\":225}],708:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./loggers\");function a(t){var e=t&&t.parentNode;e&&e.removeChild(t)}function o(t,e,r){var n=\"plotly.js-style-\"+t,a=document.getElementById(n);a||((a=document.createElement(\"style\")).setAttribute(\"id\",n),a.appendChild(document.createTextNode(\"\")),document.head.appendChild(a));var o=a.sheet;o.insertRule?o.insertRule(e+\"{\"+r+\"}\",0):o.addRule?o.addRule(e,r,0):i.warn(\"addStyleRule failed\")}e.exports={getGraphDiv:function(t){var e;if(\"string\"==typeof t){if(null===(e=document.getElementById(t)))throw new Error(\"No DOM element with id '\"+t+\"' exists on the page.\");return e}if(null==t)throw new Error(\"DOM element provided is null or undefined\");return t},isPlotDiv:function(t){var e=n.select(t);return e.node()instanceof HTMLElement&&e.size()&&e.classed(\"js-plotly-plot\")},removeElement:a,addStyleRule:function(t,e){o(\"global\",t,e)},addRelatedStyleRule:o,deleteRelatedStyleRule:function(t){var e=\"plotly.js-style-\"+t,r=document.getElementById(e);r&&a(r)}}},{\"./loggers\":723,d3:163}],709:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i={init:function(t){if(t._ev instanceof n)return t;var e=new n,r=new n;return t._ev=e,t._internalEv=r,t.on=e.on.bind(e),t.once=e.once.bind(e),t.removeListener=e.removeListener.bind(e),t.removeAllListeners=e.removeAllListeners.bind(e),t._internalOn=r.on.bind(r),t._internalOnce=r.once.bind(r),t._removeInternalListener=r.removeListener.bind(r),t._removeAllInternalListeners=r.removeAllListeners.bind(r),t.emit=function(n,i){\"undefined\"!=typeof jQuery&&jQuery(t).trigger(n,i),e.emit(n,i),r.emit(n,i)},t},triggerHandler:function(t,e,r){var n,i;\"undefined\"!=typeof jQuery&&(n=jQuery(t).triggerHandler(e,r));var a=t._ev;if(!a)return n;var o,s=a._events[e];if(!s)return n;function l(t){return t.listener?(a.removeListener(e,t.listener),t.fired?void 0:(t.fired=!0,t.listener.apply(a,[r]))):t.apply(a,[r])}for(s=Array.isArray(s)?s:[s],o=0;o<s.length-1;o++)l(s[o]);return i=l(s[o]),void 0!==n?n:i},purge:function(t){return delete t._ev,delete t.on,delete t.once,delete t.removeListener,delete t.removeAllListeners,delete t.emit,delete t._ev,delete t._internalEv,delete t._internalOn,delete t._internalOnce,delete t._removeInternalListener,delete t._removeAllInternalListeners,t}};e.exports=i},{events:104}],710:[function(t,e,r){\"use strict\";var n=t(\"./is_plain_object.js\"),i=Array.isArray;function a(t,e,r,o){var s,l,c,u,h,f,p=t[0],d=t.length;if(2===d&&i(p)&&i(t[1])&&0===p.length){if(function(t,e){var r,n;for(r=0;r<t.length;r++){if(null!==(n=t[r])&&\"object\"==typeof n)return!1;void 0!==n&&(e[r]=n)}return!0}(t[1],p))return p;p.splice(0,p.length)}for(var g=1;g<d;g++)for(l in s=t[g])c=p[l],u=s[l],o&&i(u)?p[l]=u:e&&u&&(n(u)||(h=i(u)))?(h?(h=!1,f=c&&i(c)?c:[]):f=c&&n(c)?c:{},p[l]=a([f,u],e,r,o)):(\"undefined\"!=typeof u||r)&&(p[l]=u);return p}r.extendFlat=function(){return a(arguments,!1,!1,!1)},r.extendDeep=function(){return a(arguments,!0,!1,!1)},r.extendDeepAll=function(){return a(arguments,!0,!0,!1)},r.extendDeepNoArrays=function(){return a(arguments,!0,!1,!0)}},{\"./is_plain_object.js\":720}],711:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e={},r=[],n=0,i=0;i<t.length;i++){var a=t[i];1!==e[a]&&(e[a]=1,r[n++]=a)}return r}},{}],712:[function(t,e,r){\"use strict\";function n(t){return!0===t.visible}function i(t){var e=t[0].trace;return!0===e.visible&&0!==e._length}e.exports=function(t){for(var e,r=(e=t,Array.isArray(e)&&Array.isArray(e[0])&&e[0][0]&&e[0][0].trace?i:n),a=[],o=0;o<t.length;o++){var s=t[o];r(s)&&a.push(s)}return a}},{}],713:[function(t,e,r){\"use strict\";var n=t(\"country-regex\"),i=t(\"../lib\"),a=Object.keys(n),o={\"ISO-3\":i.identity,\"USA-states\":i.identity,\"country names\":function(t){for(var e=0;e<a.length;e++){var r=a[e],o=new RegExp(n[r]);if(o.test(t.trim().toLowerCase()))return r}return i.log(\"Unrecognized country name: \"+t+\".\"),!1}};e.exports={locationToFeature:function(t,e,r){if(!e||\"string\"!=typeof e)return!1;var n,a,s,l=o[t](e);if(l){if(\"USA-states\"===t)for(n=[],s=0;s<r.length;s++)(a=r[s]).properties&&a.properties.gu&&\"USA\"===a.properties.gu&&n.push(a);else n=r;for(s=0;s<n.length;s++)if((a=n[s]).id===l)return a;i.log([\"Location with id\",l,\"does not have a matching topojson feature at this resolution.\"].join(\" \"))}return!1}}},{\"../lib\":719,\"country-regex\":134}],714:[function(t,e,r){\"use strict\";var n=t(\"../constants/numerical\").BADNUM;r.calcTraceToLineCoords=function(t){for(var e=t[0].trace.connectgaps,r=[],i=[],a=0;a<t.length;a++){var o=t[a].lonlat;o[0]!==n?i.push(o):!e&&i.length>0&&(r.push(i),i=[])}return i.length>0&&r.push(i),r},r.makeLine=function(t){return 1===t.length?{type:\"LineString\",coordinates:t[0]}:{type:\"MultiLineString\",coordinates:t}},r.makePolygon=function(t){if(1===t.length)return{type:\"Polygon\",coordinates:t};for(var e=new Array(t.length),r=0;r<t.length;r++)e[r]=[t[r]];return{type:\"MultiPolygon\",coordinates:e}},r.makeBlank=function(){return{type:\"Point\",coordinates:[]}}},{\"../constants/numerical\":695}],715:[function(t,e,r){\"use strict\";var n,i,a,o=t(\"./mod\").mod;function s(t,e,r,n,i,a,o,s){var l=r-t,c=i-t,u=o-i,h=n-e,f=a-e,p=s-a,d=l*p-u*h;if(0===d)return null;var g=(c*p-u*f)/d,v=(c*h-l*f)/d;return v<0||v>1||g<0||g>1?null:{x:t+l*g,y:e+h*g}}function l(t,e,r,n,i){var a=n*t+i*e;if(a<0)return n*n+i*i;if(a>r){var o=n-t,s=i-e;return o*o+s*s}var l=n*e-i*t;return l*l/r}r.segmentsIntersect=s,r.segmentDistance=function(t,e,r,n,i,a,o,c){if(s(t,e,r,n,i,a,o,c))return 0;var u=r-t,h=n-e,f=o-i,p=c-a,d=u*u+h*h,g=f*f+p*p,v=Math.min(l(u,h,d,i-t,a-e),l(u,h,d,o-t,c-e),l(f,p,g,t-i,e-a),l(f,p,g,r-i,n-a));return Math.sqrt(v)},r.getTextLocation=function(t,e,r,s){if(t===i&&s===a||(n={},i=t,a=s),n[r])return n[r];var l=t.getPointAtLength(o(r-s/2,e)),c=t.getPointAtLength(o(r+s/2,e)),u=Math.atan((c.y-l.y)/(c.x-l.x)),h=t.getPointAtLength(o(r,e)),f={x:(4*h.x+l.x+c.x)/6,y:(4*h.y+l.y+c.y)/6,theta:u};return n[r]=f,f},r.clearLocationCache=function(){i=null},r.getVisibleSegment=function(t,e,r){var n,i,a=e.left,o=e.right,s=e.top,l=e.bottom,c=0,u=t.getTotalLength(),h=u;function f(e){var r=t.getPointAtLength(e);0===e?n=r:e===u&&(i=r);var c=r.x<a?a-r.x:r.x>o?r.x-o:0,h=r.y<s?s-r.y:r.y>l?r.y-l:0;return Math.sqrt(c*c+h*h)}for(var p=f(c);p;){if((c+=p+r)>h)return;p=f(c)}for(p=f(h);p;){if(c>(h-=p+r))return;p=f(h)}return{min:c,max:h,len:h-c,total:u,isClosed:0===c&&h===u&&Math.abs(n.x-i.x)<.1&&Math.abs(n.y-i.y)<.1}},r.findPointOnPath=function(t,e,r,n){for(var i,a,o,s=(n=n||{}).pathLength||t.getTotalLength(),l=n.tolerance||.001,c=n.iterationLimit||30,u=t.getPointAtLength(0)[r]>t.getPointAtLength(s)[r]?-1:1,h=0,f=0,p=s;h<c;){if(i=(f+p)/2,o=(a=t.getPointAtLength(i))[r]-e,Math.abs(o)<l)return a;u*o>0?p=i:f=i,h++}return a}},{\"./mod\":726}],716:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"color-normalize\"),o=t(\"../components/colorscale\"),s=t(\"../components/color/attributes\").defaultLine,l=t(\"./array\").isArrayOrTypedArray,c=a(s),u=1;function h(t,e){var r=t;return r[3]*=e,r}function f(t){if(n(t))return c;var e=a(t);return e.length?e:c}function p(t){return n(t)?t:u}e.exports={formatColor:function(t,e,r){var n,i,s,d,g,v=t.color,m=l(v),y=l(e),x=o.extractOpts(t),b=[];if(n=void 0!==x.colorscale?o.makeColorScaleFuncFromTrace(t):f,i=m?function(t,e){return void 0===t[e]?c:a(n(t[e]))}:f,s=y?function(t,e){return void 0===t[e]?u:p(t[e])}:p,m||y)for(var _=0;_<r;_++)d=i(v,_),g=s(e,_),b[_]=h(d,g);else b=h(a(v),e);return b},parseColorScale:function(t,e){void 0===e&&(e=1);var r=o.extractOpts(t);return(r.reversescale?o.flipScale(r.colorscale):r.colorscale).map(function(t){var r=t[0],n=i(t[1]).toRgb();return{index:r,rgb:[n.r,n.g,n.b,e]}})}}},{\"../components/color/attributes\":592,\"../components/colorscale\":605,\"./array\":702,\"color-normalize\":120,\"fast-isnumeric\":225,tinycolor2:537}],717:[function(t,e,r){\"use strict\";var n=t(\"./identity\");function i(t){return[t]}e.exports={keyFun:function(t){return t.key},repeat:i,descend:n,wrap:i,unwrap:function(t){return t[0]}}},{\"./identity\":718}],718:[function(t,e,r){\"use strict\";e.exports=function(t){return t}},{}],719:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../constants/numerical\"),o=a.FP_SAFE,s=a.BADNUM,l=e.exports={};l.nestedProperty=t(\"./nested_property\"),l.keyedContainer=t(\"./keyed_container\"),l.relativeAttr=t(\"./relative_attr\"),l.isPlainObject=t(\"./is_plain_object\"),l.toLogRange=t(\"./to_log_range\"),l.relinkPrivateKeys=t(\"./relink_private\");var c=t(\"./array\");l.isTypedArray=c.isTypedArray,l.isArrayOrTypedArray=c.isArrayOrTypedArray,l.isArray1D=c.isArray1D,l.ensureArray=c.ensureArray,l.concat=c.concat,l.maxRowLength=c.maxRowLength,l.minRowLength=c.minRowLength;var u=t(\"./mod\");l.mod=u.mod,l.modHalf=u.modHalf;var h=t(\"./coerce\");l.valObjectMeta=h.valObjectMeta,l.coerce=h.coerce,l.coerce2=h.coerce2,l.coerceFont=h.coerceFont,l.coerceHoverinfo=h.coerceHoverinfo,l.coerceSelectionMarkerOpacity=h.coerceSelectionMarkerOpacity,l.validate=h.validate;var f=t(\"./dates\");l.dateTime2ms=f.dateTime2ms,l.isDateTime=f.isDateTime,l.ms2DateTime=f.ms2DateTime,l.ms2DateTimeLocal=f.ms2DateTimeLocal,l.cleanDate=f.cleanDate,l.isJSDate=f.isJSDate,l.formatDate=f.formatDate,l.incrementMonth=f.incrementMonth,l.dateTick0=f.dateTick0,l.dfltRange=f.dfltRange,l.findExactDates=f.findExactDates,l.MIN_MS=f.MIN_MS,l.MAX_MS=f.MAX_MS;var p=t(\"./search\");l.findBin=p.findBin,l.sorterAsc=p.sorterAsc,l.sorterDes=p.sorterDes,l.distinctVals=p.distinctVals,l.roundUp=p.roundUp,l.sort=p.sort,l.findIndexOfMin=p.findIndexOfMin;var d=t(\"./stats\");l.aggNums=d.aggNums,l.len=d.len,l.mean=d.mean,l.median=d.median,l.midRange=d.midRange,l.variance=d.variance,l.stdev=d.stdev,l.interp=d.interp;var g=t(\"./matrix\");l.init2dArray=g.init2dArray,l.transposeRagged=g.transposeRagged,l.dot=g.dot,l.translationMatrix=g.translationMatrix,l.rotationMatrix=g.rotationMatrix,l.rotationXYMatrix=g.rotationXYMatrix,l.apply2DTransform=g.apply2DTransform,l.apply2DTransform2=g.apply2DTransform2;var v=t(\"./angles\");l.deg2rad=v.deg2rad,l.rad2deg=v.rad2deg,l.angleDelta=v.angleDelta,l.angleDist=v.angleDist,l.isFullCircle=v.isFullCircle,l.isAngleInsideSector=v.isAngleInsideSector,l.isPtInsideSector=v.isPtInsideSector,l.pathArc=v.pathArc,l.pathSector=v.pathSector,l.pathAnnulus=v.pathAnnulus;var m=t(\"./anchor_utils\");l.isLeftAnchor=m.isLeftAnchor,l.isCenterAnchor=m.isCenterAnchor,l.isRightAnchor=m.isRightAnchor,l.isTopAnchor=m.isTopAnchor,l.isMiddleAnchor=m.isMiddleAnchor,l.isBottomAnchor=m.isBottomAnchor;var y=t(\"./geometry2d\");l.segmentsIntersect=y.segmentsIntersect,l.segmentDistance=y.segmentDistance,l.getTextLocation=y.getTextLocation,l.clearLocationCache=y.clearLocationCache,l.getVisibleSegment=y.getVisibleSegment,l.findPointOnPath=y.findPointOnPath;var x=t(\"./extend\");l.extendFlat=x.extendFlat,l.extendDeep=x.extendDeep,l.extendDeepAll=x.extendDeepAll,l.extendDeepNoArrays=x.extendDeepNoArrays;var b=t(\"./loggers\");l.log=b.log,l.warn=b.warn,l.error=b.error;var _=t(\"./regex\");l.counterRegex=_.counter;var w=t(\"./throttle\");l.throttle=w.throttle,l.throttleDone=w.done,l.clearThrottle=w.clear;var k=t(\"./dom\");function T(t){var e={};for(var r in t)for(var n=t[r],i=0;i<n.length;i++)e[n[i]]=+r;return e}l.getGraphDiv=k.getGraphDiv,l.isPlotDiv=k.isPlotDiv,l.removeElement=k.removeElement,l.addStyleRule=k.addStyleRule,l.addRelatedStyleRule=k.addRelatedStyleRule,l.deleteRelatedStyleRule=k.deleteRelatedStyleRule,l.clearResponsive=t(\"./clear_responsive\"),l.makeTraceGroups=t(\"./make_trace_groups\"),l._=t(\"./localize\"),l.notifier=t(\"./notifier\"),l.filterUnique=t(\"./filter_unique\"),l.filterVisible=t(\"./filter_visible\"),l.pushUnique=t(\"./push_unique\"),l.cleanNumber=t(\"./clean_number\"),l.ensureNumber=function(t){return i(t)?(t=Number(t))<-o||t>o?s:i(t)?Number(t):s:s},l.isIndex=function(t,e){return!(void 0!==e&&t>=e)&&(i(t)&&t>=0&&t%1==0)},l.noop=t(\"./noop\"),l.identity=t(\"./identity\"),l.repeat=function(t,e){for(var r=new Array(e),n=0;n<e;n++)r[n]=t;return r},l.swapAttrs=function(t,e,r,n){r||(r=\"x\"),n||(n=\"y\");for(var i=0;i<e.length;i++){var a=e[i],o=l.nestedProperty(t,a.replace(\"?\",r)),s=l.nestedProperty(t,a.replace(\"?\",n)),c=o.get();o.set(s.get()),s.set(c)}},l.raiseToTop=function(t){t.parentNode.appendChild(t)},l.cancelTransition=function(t){return t.transition().duration(0)},l.constrain=function(t,e,r){return e>r?Math.max(r,Math.min(e,t)):Math.max(e,Math.min(r,t))},l.bBoxIntersect=function(t,e,r){return r=r||0,t.left<=e.right+r&&e.left<=t.right+r&&t.top<=e.bottom+r&&e.top<=t.bottom+r},l.simpleMap=function(t,e,r,n){for(var i=t.length,a=new Array(i),o=0;o<i;o++)a[o]=e(t[o],r,n);return a},l.randstr=function t(e,r,n,i){if(n||(n=16),void 0===r&&(r=24),r<=0)return\"0\";var a,o,s=Math.log(Math.pow(2,r))/Math.log(n),c=\"\";for(a=2;s===1/0;a*=2)s=Math.log(Math.pow(2,r/a))/Math.log(n)*a;var u=s-Math.floor(s);for(a=0;a<Math.floor(s);a++)c=Math.floor(Math.random()*n).toString(n)+c;u&&(o=Math.pow(n,u),c=Math.floor(Math.random()*o).toString(n)+c);var h=parseInt(c,n);return e&&e[c]||h!==1/0&&h>=Math.pow(2,r)?i>10?(l.warn(\"randstr failed uniqueness\"),c):t(e,r,n,(i||0)+1):c},l.OptionControl=function(t,e){t||(t={}),e||(e=\"opt\");var r={optionList:[],_newoption:function(n){n[e]=t,r[n.name]=n,r.optionList.push(n)}};return r[\"_\"+e]=t,r},l.smooth=function(t,e){if((e=Math.round(e)||0)<2)return t;var r,n,i,a,o=t.length,s=2*o,l=2*e-1,c=new Array(l),u=new Array(o);for(r=0;r<l;r++)c[r]=(1-Math.cos(Math.PI*(r+1)/e))/(2*e);for(r=0;r<o;r++){for(a=0,n=0;n<l;n++)(i=r+n+1-e)<-o?i-=s*Math.round(i/s):i>=s&&(i-=s*Math.floor(i/s)),i<0?i=-1-i:i>=o&&(i=s-1-i),a+=t[i]*c[n];u[r]=a}return u},l.syncOrAsync=function(t,e,r){var n;function i(){return l.syncOrAsync(t,e,r)}for(;t.length;)if((n=(0,t.splice(0,1)[0])(e))&&n.then)return n.then(i).then(void 0,l.promiseError);return r&&r(e)},l.stripTrailingSlash=function(t){return\"/\"===t.substr(-1)?t.substr(0,t.length-1):t},l.noneOrAll=function(t,e,r){if(t){var n,i=!1,a=!0;for(n=0;n<r.length;n++)null!=t[r[n]]?i=!0:a=!1;if(i&&!a)for(n=0;n<r.length;n++)t[r[n]]=e[r[n]]}},l.mergeArray=function(t,e,r,n){var i=\"function\"==typeof n;if(l.isArrayOrTypedArray(t))for(var a=Math.min(t.length,e.length),o=0;o<a;o++){var s=t[o];e[o][r]=i?n(s):s}},l.mergeArrayCastPositive=function(t,e,r){return l.mergeArray(t,e,r,function(t){var e=+t;return isFinite(e)&&e>0?e:0})},l.fillArray=function(t,e,r,n){if(n=n||l.identity,l.isArrayOrTypedArray(t))for(var i=0;i<e.length;i++)e[i][r]=n(t[i])},l.castOption=function(t,e,r,n){n=n||l.identity;var i=l.nestedProperty(t,r).get();return l.isArrayOrTypedArray(i)?Array.isArray(e)&&l.isArrayOrTypedArray(i[e[0]])?n(i[e[0]][e[1]]):n(i[e]):i},l.extractOption=function(t,e,r,n){if(r in t)return t[r];var i=l.nestedProperty(e,n).get();return Array.isArray(i)?void 0:i},l.tagSelected=function(t,e,r){var n,i,a=e.selectedpoints,o=e._indexToPoints;o&&(n=T(o));for(var s=0;s<a.length;s++){var c=a[s];if(l.isIndex(c)){var u=n?n[c]:c,h=r?r[u]:u;void 0!==(i=h)&&i<t.length&&(t[h].selected=1)}}},l.selIndices2selPoints=function(t){var e=t.selectedpoints,r=t._indexToPoints;if(r){for(var n=T(r),i=[],a=0;a<e.length;a++){var o=e[a];if(l.isIndex(o)){var s=n[o];l.isIndex(s)&&i.push(s)}}return i}return e},l.getTargetArray=function(t,e){var r=e.target;if(\"string\"==typeof r&&r){var n=l.nestedProperty(t,r).get();return!!Array.isArray(n)&&n}return!!Array.isArray(r)&&r},l.minExtend=function(t,e){var r={};\"object\"!=typeof e&&(e={});var n,i,a,o=Object.keys(t);for(n=0;n<o.length;n++)a=t[i=o[n]],\"_\"!==i.charAt(0)&&\"function\"!=typeof a&&(\"module\"===i?r[i]=a:Array.isArray(a)?r[i]=\"colorscale\"===i?a.slice():a.slice(0,3):r[i]=a&&\"object\"==typeof a?l.minExtend(t[i],e[i]):a);for(o=Object.keys(e),n=0;n<o.length;n++)\"object\"==typeof(a=e[i=o[n]])&&i in r&&\"object\"==typeof r[i]||(r[i]=a);return r},l.titleCase=function(t){return t.charAt(0).toUpperCase()+t.substr(1)},l.containsAny=function(t,e){for(var r=0;r<e.length;r++)if(-1!==t.indexOf(e[r]))return!0;return!1},l.isIE=function(){return\"undefined\"!=typeof window.navigator.msSaveBlob};var A=/MSIE [1-9]\\./;l.isIE9orBelow=function(){return l.isIE()&&A.test(window.navigator.userAgent)};var M=/Version\\/[\\d\\.]+.*Safari/;l.isSafari=function(){return M.test(window.navigator.userAgent)},l.isD3Selection=function(t){return t&&\"function\"==typeof t.classed},l.ensureSingle=function(t,e,r,n){var i=t.select(e+(r?\".\"+r:\"\"));if(i.size())return i;var a=t.append(e);return r&&a.classed(r,!0),n&&a.call(n),a},l.ensureSingleById=function(t,e,r,n){var i=t.select(e+\"#\"+r);if(i.size())return i;var a=t.append(e).attr(\"id\",r);return n&&a.call(n),a},l.objectFromPath=function(t,e){for(var r,n=t.split(\".\"),i=r={},a=0;a<n.length;a++){var o=n[a],s=null,l=n[a].match(/(.*)\\[([0-9]+)\\]/);l?(o=l[1],s=l[2],r=r[o]=[],a===n.length-1?r[s]=e:r[s]={},r=r[s]):(a===n.length-1?r[o]=e:r[o]={},r=r[o])}return i};var S=/^([^\\[\\.]+)\\.(.+)?/,E=/^([^\\.]+)\\[([0-9]+)\\](\\.)?(.+)?/;l.expandObjectPaths=function(t){var e,r,n,i,a,o,s;if(\"object\"==typeof t&&!Array.isArray(t))for(r in t)t.hasOwnProperty(r)&&((e=r.match(S))?(i=t[r],n=e[1],delete t[r],t[n]=l.extendDeepNoArrays(t[n]||{},l.objectFromPath(r,l.expandObjectPaths(i))[n])):(e=r.match(E))?(i=t[r],n=e[1],a=parseInt(e[2]),delete t[r],t[n]=t[n]||[],\".\"===e[3]?(s=e[4],o=t[n][a]=t[n][a]||{},l.extendDeepNoArrays(o,l.objectFromPath(s,l.expandObjectPaths(i)))):t[n][a]=l.expandObjectPaths(i)):t[r]=l.expandObjectPaths(t[r]));return t},l.numSeparate=function(t,e,r){if(r||(r=!1),\"string\"!=typeof e||0===e.length)throw new Error(\"Separator string required for formatting!\");\"number\"==typeof t&&(t=String(t));var n=/(\\d+)(\\d{3})/,i=e.charAt(0),a=e.charAt(1),o=t.split(\".\"),s=o[0],l=o.length>1?i+o[1]:\"\";if(a&&(o.length>1||s.length>4||r))for(;n.test(s);)s=s.replace(n,\"$1\"+a+\"$2\");return s+l},l.TEMPLATE_STRING_REGEX=/%{([^\\s%{}:]*)(:[^}]*)?}/g;var C=/^\\w*$/;l.templateString=function(t,e){var r={};return t.replace(l.TEMPLATE_STRING_REGEX,function(t,n){return C.test(n)?e[n]||\"\":(r[n]=r[n]||l.nestedProperty(e,n).get,r[n]()||\"\")})};var L=/^:/,P=0;l.hovertemplateString=function(t,e,r){var i=arguments,a={};return t.replace(l.TEMPLATE_STRING_REGEX,function(t,o,s){var c,u,h;for(h=3;h<i.length;h++){if((c=i[h]).hasOwnProperty(o)){u=c[o];break}if(C.test(o)||(u=a[o]||l.nestedProperty(c,o).get())&&(a[o]=u),void 0!==u)break}(void 0===u&&(P<10&&(l.warn(\"Variable '\"+o+\"' in hovertemplate could not be found!\"),u=t),10===P&&l.warn(\"Too many hovertemplate warnings - additional warnings will be suppressed\"),P++),s)?u=(r?r.numberFormat:n.format)(s.replace(L,\"\"))(u):e.hasOwnProperty(o+\"Label\")&&(u=e[o+\"Label\"]);return u})};l.subplotSort=function(t,e){for(var r=Math.min(t.length,e.length)+1,n=0,i=0,a=0;a<r;a++){var o=t.charCodeAt(a)||0,s=e.charCodeAt(a)||0,l=o>=48&&o<=57,c=s>=48&&s<=57;if(l&&(n=10*n+o-48),c&&(i=10*i+s-48),!l||!c){if(n!==i)return n-i;if(o!==s)return o-s}}return i-n};var O=2e9;l.seedPseudoRandom=function(){O=2e9},l.pseudoRandom=function(){var t=O;return O=(69069*O+1)%4294967296,Math.abs(O-t)<429496729?l.pseudoRandom():O/4294967296},l.fillText=function(t,e,r){var n=Array.isArray(r)?function(t){r.push(t)}:function(t){r.text=t},i=l.extractOption(t,e,\"htx\",\"hovertext\");if(l.isValidTextValue(i))return n(i);var a=l.extractOption(t,e,\"tx\",\"text\");return l.isValidTextValue(a)?n(a):void 0},l.isValidTextValue=function(t){return t||0===t},l.formatPercent=function(t,e){e=e||0;for(var r=(Math.round(100*t*Math.pow(10,e))*Math.pow(.1,e)).toFixed(e)+\"%\",n=0;n<e;n++)-1!==r.indexOf(\".\")&&(r=(r=r.replace(\"0%\",\"%\")).replace(\".%\",\"%\"));return r},l.isHidden=function(t){var e=window.getComputedStyle(t).display;return!e||\"none\"===e}},{\"../constants/numerical\":695,\"./anchor_utils\":700,\"./angles\":701,\"./array\":702,\"./clean_number\":703,\"./clear_responsive\":705,\"./coerce\":706,\"./dates\":707,\"./dom\":708,\"./extend\":710,\"./filter_unique\":711,\"./filter_visible\":712,\"./geometry2d\":715,\"./identity\":718,\"./is_plain_object\":720,\"./keyed_container\":721,\"./localize\":722,\"./loggers\":723,\"./make_trace_groups\":724,\"./matrix\":725,\"./mod\":726,\"./nested_property\":727,\"./noop\":728,\"./notifier\":729,\"./push_unique\":733,\"./regex\":735,\"./relative_attr\":736,\"./relink_private\":737,\"./search\":738,\"./stats\":741,\"./throttle\":744,\"./to_log_range\":745,d3:163,\"fast-isnumeric\":225}],720:[function(t,e,r){\"use strict\";e.exports=function(t){return window&&window.process&&window.process.versions?\"[object Object]\"===Object.prototype.toString.call(t):\"[object Object]\"===Object.prototype.toString.call(t)&&Object.getPrototypeOf(t)===Object.prototype}},{}],721:[function(t,e,r){\"use strict\";var n=t(\"./nested_property\"),i=/^\\w*$/;e.exports=function(t,e,r,a){var o,s,l;r=r||\"name\",a=a||\"value\";var c={};e&&e.length?(l=n(t,e),s=l.get()):s=t,e=e||\"\";var u={};if(s)for(o=0;o<s.length;o++)u[s[o][r]]=o;var h=i.test(a),f={set:function(t,e){var i=null===e?4:0;if(!s){if(!l||4===i)return;s=[],l.set(s)}var o=u[t];if(void 0===o){if(4===i)return;i|=3,o=s.length,u[t]=o}else e!==(h?s[o][a]:n(s[o],a).get())&&(i|=2);var p=s[o]=s[o]||{};return p[r]=t,h?p[a]=e:n(p,a).set(e),null!==e&&(i&=-5),c[o]=c[o]|i,f},get:function(t){if(s){var e=u[t];return void 0===e?void 0:h?s[e][a]:n(s[e],a).get()}},rename:function(t,e){var n=u[t];return void 0===n?f:(c[n]=1|c[n],u[e]=n,delete u[t],s[n][r]=e,f)},remove:function(t){var e=u[t];if(void 0===e)return f;var i=s[e];if(Object.keys(i).length>2)return c[e]=2|c[e],f.set(t,null);if(h){for(o=e;o<s.length;o++)c[o]=3|c[o];for(o=e;o<s.length;o++)u[s[o][r]]--;s.splice(e,1),delete u[t]}else n(i,a).set(null),c[e]=6|c[e];return f},constructUpdate:function(){for(var t,i,o={},l=Object.keys(c),u=0;u<l.length;u++)i=l[u],t=e+\"[\"+i+\"]\",s[i]?(1&c[i]&&(o[t+\".\"+r]=s[i][r]),2&c[i]&&(o[t+\".\"+a]=h?4&c[i]?null:s[i][a]:4&c[i]?null:n(s[i],a).get())):o[t]=null;return o}};return f}},{\"./nested_property\":727}],722:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t,e){for(var r=t._context.locale,i=0;i<2;i++){for(var a=t._context.locales,o=0;o<2;o++){var s=(a[r]||{}).dictionary;if(s){var l=s[e];if(l)return l}a=n.localeRegistry}var c=r.split(\"-\")[0];if(c===r)break;r=c}return e}},{\"../registry\":847}],723:[function(t,e,r){\"use strict\";var n=t(\"../plot_api/plot_config\").dfltConfig,i=e.exports={};function a(t,e){if(t&&t.apply)try{return void t.apply(console,e)}catch(t){}for(var r=0;r<e.length;r++)try{t(e[r])}catch(t){console.log(e[r])}}i.log=function(){if(n.logging>1){for(var t=[\"LOG:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.trace||console.log,t)}},i.warn=function(){if(n.logging>0){for(var t=[\"WARN:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.trace||console.log,t)}},i.error=function(){if(n.logging>0){for(var t=[\"ERROR:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.error,t)}}},{\"../plot_api/plot_config\":755}],724:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e,r){var i=t.selectAll(\"g.\"+r.replace(/\\s/g,\".\")).data(e,function(t){return t[0].trace.uid});i.exit().remove(),i.enter().append(\"g\").attr(\"class\",r),i.order();var a=t.classed(\"rangeplot\")?\"nodeRangePlot3\":\"node3\";return i.each(function(t){t[0][a]=n.select(this)}),i}},{d3:163}],725:[function(t,e,r){\"use strict\";r.init2dArray=function(t,e){for(var r=new Array(t),n=0;n<t;n++)r[n]=new Array(e);return r},r.transposeRagged=function(t){var e,r,n=0,i=t.length;for(e=0;e<i;e++)n=Math.max(n,t[e].length);var a=new Array(n);for(e=0;e<n;e++)for(a[e]=new Array(i),r=0;r<i;r++)a[e][r]=t[r][e];return a},r.dot=function(t,e){if(!t.length||!e.length||t.length!==e.length)return null;var n,i,a=t.length;if(t[0].length)for(n=new Array(a),i=0;i<a;i++)n[i]=r.dot(t[i],e);else if(e[0].length){var o=r.transposeRagged(e);for(n=new Array(o.length),i=0;i<o.length;i++)n[i]=r.dot(t,o[i])}else for(n=0,i=0;i<a;i++)n+=t[i]*e[i];return n},r.translationMatrix=function(t,e){return[[1,0,t],[0,1,e],[0,0,1]]},r.rotationMatrix=function(t){var e=t*Math.PI/180;return[[Math.cos(e),-Math.sin(e),0],[Math.sin(e),Math.cos(e),0],[0,0,1]]},r.rotationXYMatrix=function(t,e,n){return r.dot(r.dot(r.translationMatrix(e,n),r.rotationMatrix(t)),r.translationMatrix(-e,-n))},r.apply2DTransform=function(t){return function(){var e=arguments;3===e.length&&(e=e[0]);var n=1===arguments.length?e[0]:[e[0],e[1]];return r.dot(t,[n[0],n[1],1]).slice(0,2)}},r.apply2DTransform2=function(t){var e=r.apply2DTransform(t);return function(t){return e(t.slice(0,2)).concat(e(t.slice(2,4)))}}},{}],726:[function(t,e,r){\"use strict\";e.exports={mod:function(t,e){var r=t%e;return r<0?r+e:r},modHalf:function(t,e){return Math.abs(t)>e/2?t-Math.round(t/e)*e:t}}},{}],727:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;e.exports=function(t,e){if(n(e))e=String(e);else if(\"string\"!=typeof e||\"[-1]\"===e.substr(e.length-4))throw\"bad property string\";for(var r,a,o,l=0,c=e.split(\".\");l<c.length;){if(r=String(c[l]).match(/^([^\\[\\]]*)((\\[\\-?[0-9]*\\])+)$/)){if(r[1])c[l]=r[1];else{if(0!==l)throw\"bad property string\";c.splice(0,1)}for(a=r[2].substr(1,r[2].length-2).split(\"][\"),o=0;o<a.length;o++)l++,c.splice(l,0,Number(a[o]))}l++}return\"object\"!=typeof t?function(t,e,r){return{set:function(){throw\"bad container\"},get:function(){},astr:e,parts:r,obj:t}}(t,e,c):{set:s(t,c,e),get:function t(e,r){return function(){var n,a,o,s,l,c=e;for(s=0;s<r.length-1;s++){if(-1===(n=r[s])){for(a=!0,o=[],l=0;l<c.length;l++)o[l]=t(c[l],r.slice(s+1))(),o[l]!==o[0]&&(a=!1);return a?o[0]:o}if(\"number\"==typeof n&&!i(c))return;if(\"object\"!=typeof(c=c[n])||null===c)return}if(\"object\"==typeof c&&null!==c&&null!==(o=c[r[s]]))return o}}(t,c),astr:e,parts:c,obj:t}};var a=/(^|\\.)args\\[/;function o(t,e){return void 0===t||null===t&&!e.match(a)}function s(t,e,r){return function(n){var a,s,h=t,f=\"\",p=[[t,f]],d=o(n,r);for(s=0;s<e.length-1;s++){if(\"number\"==typeof(a=e[s])&&!i(h))throw\"array index but container is not an array\";if(-1===a){if(d=!c(h,e.slice(s+1),n,r))break;return}if(!u(h,a,e[s+1],d))break;if(\"object\"!=typeof(h=h[a])||null===h)throw\"container is not an object\";f=l(f,a),p.push([h,f])}if(d){if(s===e.length-1&&(delete h[e[s]],Array.isArray(h)&&+e[s]==h.length-1))for(;h.length&&void 0===h[h.length-1];)h.pop()}else h[e[s]]=n}}function l(t,e){var r=e;return n(e)?r=\"[\"+e+\"]\":t&&(r=\".\"+e),t+r}function c(t,e,r,n){var a,l=i(r),c=!0,h=r,f=n.replace(\"-1\",0),p=!l&&o(r,f),d=e[0];for(a=0;a<t.length;a++)f=n.replace(\"-1\",a),l&&(p=o(h=r[a%r.length],f)),p&&(c=!1),u(t,a,d,p)&&s(t[a],e,n.replace(\"-1\",a))(h);return c}function u(t,e,r,n){if(void 0===t[e]){if(n)return!1;t[e]=\"number\"==typeof r?[]:{}}return!0}},{\"./array\":702,\"fast-isnumeric\":225}],728:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],729:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=[];e.exports=function(t,e){if(-1===a.indexOf(t)){a.push(t);var r=1e3;i(e)?r=e:\"long\"===e&&(r=3e3);var o=n.select(\"body\").selectAll(\".plotly-notifier\").data([0]);o.enter().append(\"div\").classed(\"plotly-notifier\",!0),o.selectAll(\".notifier-note\").data(a).enter().append(\"div\").classed(\"notifier-note\",!0).style(\"opacity\",0).each(function(t){var e=n.select(this);e.append(\"button\").classed(\"notifier-close\",!0).html(\"&times;\").on(\"click\",function(){e.transition().call(s)});for(var i=e.append(\"p\"),a=t.split(/<br\\s*\\/?>/g),o=0;o<a.length;o++)o&&i.append(\"br\"),i.append(\"span\").text(a[o]);e.transition().duration(700).style(\"opacity\",1).transition().delay(r).call(s)})}function s(t){t.duration(700).style(\"opacity\",0).each(\"end\",function(t){var e=a.indexOf(t);-1!==e&&a.splice(e,1),n.select(this).remove()})}}},{d3:163,\"fast-isnumeric\":225}],730:[function(t,e,r){\"use strict\";var n=t(\"./setcursor\"),i=\"data-savedcursor\";e.exports=function(t,e){var r=t.attr(i);if(e){if(!r){for(var a=(t.attr(\"class\")||\"\").split(\" \"),o=0;o<a.length;o++){var s=a[o];0===s.indexOf(\"cursor-\")&&t.attr(i,s.substr(7)).classed(s,!1)}t.attr(i)||t.attr(i,\"!!\")}n(t,e)}else r&&(t.attr(i,null),\"!!\"===r?n(t):n(t,r))}},{\"./setcursor\":739}],731:[function(t,e,r){\"use strict\";var n=t(\"./matrix\").dot,i=t(\"../constants/numerical\").BADNUM,a=e.exports={};a.tester=function(t){var e,r=t.slice(),n=r[0][0],a=n,o=r[0][1],s=o;for(r.push(r[0]),e=1;e<r.length;e++)n=Math.min(n,r[e][0]),a=Math.max(a,r[e][0]),o=Math.min(o,r[e][1]),s=Math.max(s,r[e][1]);var l,c=!1;5===r.length&&(r[0][0]===r[1][0]?r[2][0]===r[3][0]&&r[0][1]===r[3][1]&&r[1][1]===r[2][1]&&(c=!0,l=function(t){return t[0]===r[0][0]}):r[0][1]===r[1][1]&&r[2][1]===r[3][1]&&r[0][0]===r[3][0]&&r[1][0]===r[2][0]&&(c=!0,l=function(t){return t[1]===r[0][1]}));var u=!0,h=r[0];for(e=1;e<r.length;e++)if(h[0]!==r[e][0]||h[1]!==r[e][1]){u=!1;break}return{xmin:n,xmax:a,ymin:o,ymax:s,pts:r,contains:c?function(t,e){var r=t[0],c=t[1];return!(r===i||r<n||r>a||c===i||c<o||c>s||e&&l(t))}:function(t,e){var l=t[0],c=t[1];if(l===i||l<n||l>a||c===i||c<o||c>s)return!1;var u,h,f,p,d,g=r.length,v=r[0][0],m=r[0][1],y=0;for(u=1;u<g;u++)if(h=v,f=m,v=r[u][0],m=r[u][1],!(l<(p=Math.min(h,v))||l>Math.max(h,v)||c>Math.max(f,m)))if(c<Math.min(f,m))l!==p&&y++;else{if(c===(d=v===h?c:f+(l-h)*(m-f)/(v-h)))return 1!==u||!e;c<=d&&l!==p&&y++}return y%2==1},isRect:c,degenerate:u}},a.isSegmentBent=function(t,e,r,i){var a,o,s,l=t[e],c=[t[r][0]-l[0],t[r][1]-l[1]],u=n(c,c),h=Math.sqrt(u),f=[-c[1]/h,c[0]/h];for(a=e+1;a<r;a++)if(o=[t[a][0]-l[0],t[a][1]-l[1]],(s=n(o,c))<0||s>u||Math.abs(n(o,f))>i)return!0;return!1},a.filter=function(t,e){var r=[t[0]],n=0,i=0;function o(o){t.push(o);var s=r.length,l=n;r.splice(i+1);for(var c=l+1;c<t.length;c++)(c===t.length-1||a.isSegmentBent(t,l,c+1,e))&&(r.push(t[c]),r.length<s-2&&(n=c,i=r.length-1),l=c)}t.length>1&&o(t.pop());return{addPt:o,raw:t,filtered:r}}},{\"../constants/numerical\":695,\"./matrix\":725}],732:[function(t,e,r){(function(r){\"use strict\";var n=t(\"./show_no_webgl_msg\"),i=t(\"regl\");e.exports=function(t,e){var a=t._fullLayout,o=!0;return a._glcanvas.each(function(n){if(!n.regl&&(!n.pick||a._has(\"parcoords\"))){try{n.regl=i({canvas:this,attributes:{antialias:!n.pick,preserveDrawingBuffer:!0},pixelRatio:t._context.plotGlPixelRatio||r.devicePixelRatio,extensions:e||[]})}catch(t){o=!1}o&&this.addEventListener(\"webglcontextlost\",function(e){t&&t.emit&&t.emit(\"plotly_webglcontextlost\",{event:e,layer:n.key})},!1)}}),o||n({container:a._glcontainer.node()}),o}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./show_no_webgl_msg\":740,regl:502}],733:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(e instanceof RegExp){for(var r=e.toString(),n=0;n<t.length;n++)if(t[n]instanceof RegExp&&t[n].toString()===r)return t;t.push(e)}else!e&&0!==e||-1!==t.indexOf(e)||t.push(e);return t}},{}],734:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_config\").dfltConfig;var a={add:function(t,e,r,n,a){var o,s;t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},s=t.undoQueue.index,t.autoplay?t.undoQueue.inSequence||(t.autoplay=!1):(!t.undoQueue.sequence||t.undoQueue.beginSequence?(o={undo:{calls:[],args:[]},redo:{calls:[],args:[]}},t.undoQueue.queue.splice(s,t.undoQueue.queue.length-s,o),t.undoQueue.index+=1):o=t.undoQueue.queue[s-1],t.undoQueue.beginSequence=!1,o&&(o.undo.calls.unshift(e),o.undo.args.unshift(r),o.redo.calls.push(n),o.redo.args.push(a)),t.undoQueue.queue.length>i.queueLength&&(t.undoQueue.queue.shift(),t.undoQueue.index--))},startSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!0,t.undoQueue.beginSequence=!0},stopSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!1,t.undoQueue.beginSequence=!1},undo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.undo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index<=0)){for(t.undoQueue.index--,e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.undo.calls.length;r++)a.plotDo(t,e.undo.calls[r],e.undo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1}},redo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.redo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index>=t.undoQueue.queue.length)){for(e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.redo.calls.length;r++)a.plotDo(t,e.redo.calls[r],e.redo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1,t.undoQueue.index++}}};a.plotDo=function(t,e,r){t.autoplay=!0,r=function(t,e){for(var r,i=[],a=0;a<e.length;a++)r=e[a],i[a]=r===t?r:\"object\"==typeof r?Array.isArray(r)?n.extendDeep([],r):n.extendDeepAll({},r):r;return i}(t,r),e.apply(null,r)},e.exports=a},{\"../lib\":719,\"../plot_api/plot_config\":755}],735:[function(t,e,r){\"use strict\";r.counter=function(t,e,r,n){var i=(e||\"\")+(r?\"\":\"$\"),a=!1===n?\"\":\"^\";return\"xy\"===t?new RegExp(a+\"x([2-9]|[1-9][0-9]+)?y([2-9]|[1-9][0-9]+)?\"+i):new RegExp(a+t+\"([2-9]|[1-9][0-9]+)?\"+i)}},{}],736:[function(t,e,r){\"use strict\";var n=/^(.*)(\\.[^\\.\\[\\]]+|\\[\\d\\])$/,i=/^[^\\.\\[\\]]+$/;e.exports=function(t,e){for(;e;){var r=t.match(n);if(r)t=r[1];else{if(!t.match(i))throw new Error(\"bad relativeAttr call:\"+[t,e]);t=\"\"}if(\"^\"!==e.charAt(0))break;e=e.slice(1)}return t&&\"[\"!==e.charAt(0)?t+\".\"+e:t+e}},{}],737:[function(t,e,r){\"use strict\";var n=t(\"./array\").isArrayOrTypedArray,i=t(\"./is_plain_object\");e.exports=function t(e,r){for(var a in r){var o=r[a],s=e[a];if(s!==o)if(\"_\"===a.charAt(0)||\"function\"==typeof o){if(a in e)continue;e[a]=o}else if(n(o)&&n(s)&&i(o[0])){if(\"customdata\"===a||\"ids\"===a)continue;for(var l=Math.min(o.length,s.length),c=0;c<l;c++)s[c]!==o[c]&&i(o[c])&&i(s[c])&&t(s[c],o[c])}else i(o)&&i(s)&&(t(s,o),Object.keys(s).length||delete e[a])}}},{\"./array\":702,\"./is_plain_object\":720}],738:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./loggers\"),a=t(\"./identity\");function o(t,e){return t<e}function s(t,e){return t<=e}function l(t,e){return t>e}function c(t,e){return t>=e}r.findBin=function(t,e,r){if(n(e.start))return r?Math.ceil((t-e.start)/e.size-1e-9)-1:Math.floor((t-e.start)/e.size+1e-9);var a,u,h=0,f=e.length,p=0,d=f>1?(e[f-1]-e[0])/(f-1):1;for(u=d>=0?r?o:s:r?c:l,t+=1e-9*d*(r?-1:1)*(d>=0?1:-1);h<f&&p++<100;)u(e[a=Math.floor((h+f)/2)],t)?h=a+1:f=a;return p>90&&i.log(\"Long binary search...\"),h-1},r.sorterAsc=function(t,e){return t-e},r.sorterDes=function(t,e){return e-t},r.distinctVals=function(t){var e=t.slice();e.sort(r.sorterAsc);for(var n=e.length-1,i=e[n]-e[0]||1,a=i/(n||1)/1e4,o=[e[0]],s=0;s<n;s++)e[s+1]>e[s]+a&&(i=Math.min(i,e[s+1]-e[s]),o.push(e[s+1]));return{vals:o,minDiff:i}},r.roundUp=function(t,e,r){for(var n,i=0,a=e.length-1,o=0,s=r?0:1,l=r?1:0,c=r?Math.ceil:Math.floor;i<a&&o++<100;)e[n=c((i+a)/2)]<=t?i=n+s:a=n-l;return e[i]},r.sort=function(t,e){for(var r=0,n=0,i=1;i<t.length;i++){var a=e(t[i],t[i-1]);if(a<0?r=1:a>0&&(n=1),r&&n)return t.sort(e)}return n?t:t.reverse()},r.findIndexOfMin=function(t,e){e=e||a;for(var r,n=1/0,i=0;i<t.length;i++){var o=e(t[i]);o<n&&(n=o,r=i)}return r}},{\"./identity\":718,\"./loggers\":723,\"fast-isnumeric\":225}],739:[function(t,e,r){\"use strict\";e.exports=function(t,e){(t.attr(\"class\")||\"\").split(\" \").forEach(function(e){0===e.indexOf(\"cursor-\")&&t.classed(e,!1)}),e&&t.classed(\"cursor-\"+e,!0)}},{}],740:[function(t,e,r){\"use strict\";var n=t(\"../components/color\"),i=function(){};e.exports=function(t){for(var e in t)\"function\"==typeof t[e]&&(t[e]=i);t.destroy=function(){t.container.parentNode.removeChild(t.container)};var r=document.createElement(\"div\");r.className=\"no-webgl\",r.style.cursor=\"pointer\",r.style.fontSize=\"24px\",r.style.color=n.defaults[0],r.style.position=\"absolute\",r.style.left=r.style.top=\"0px\",r.style.width=r.style.height=\"100%\",r.style[\"background-color\"]=n.lightLine,r.style[\"z-index\"]=30;var a=document.createElement(\"p\");return a.textContent=\"WebGL is not supported by your browser - visit https://get.webgl.org for more info\",a.style.position=\"relative\",a.style.top=\"50%\",a.style.left=\"50%\",a.style.height=\"30%\",a.style.width=\"50%\",a.style.margin=\"-15% 0 0 -25%\",r.appendChild(a),t.container.appendChild(r),t.container.style.background=\"#FFFFFF\",t.container.onclick=function(){window.open(\"https://get.webgl.org\")},!1}},{\"../components/color\":593}],741:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;r.aggNums=function(t,e,a,o){var s,l;if((!o||o>a.length)&&(o=a.length),n(e)||(e=!1),i(a[0])){for(l=new Array(o),s=0;s<o;s++)l[s]=r.aggNums(t,e,a[s]);a=l}for(s=0;s<o;s++)n(e)?n(a[s])&&(e=t(+e,+a[s])):e=a[s];return e},r.len=function(t){return r.aggNums(function(t){return t+1},0,t)},r.mean=function(t,e){return e||(e=r.len(t)),r.aggNums(function(t,e){return t+e},0,t)/e},r.midRange=function(t){if(void 0!==t&&0!==t.length)return(r.aggNums(Math.max,null,t)+r.aggNums(Math.min,null,t))/2},r.variance=function(t,e,i){return e||(e=r.len(t)),n(i)||(i=r.mean(t,e)),r.aggNums(function(t,e){return t+Math.pow(e-i,2)},0,t)/e},r.stdev=function(t,e,n){return Math.sqrt(r.variance(t,e,n))},r.median=function(t){var e=t.slice().sort();return r.interp(e,.5)},r.interp=function(t,e){if(!n(e))throw\"n should be a finite number\";if((e=e*t.length-.5)<0)return t[0];if(e>t.length-1)return t[t.length-1];var r=e%1;return r*t[Math.ceil(e)]+(1-r)*t[Math.floor(e)]}},{\"./array\":702,\"fast-isnumeric\":225}],742:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\");e.exports=function(t){return t?n(t):[0,0,0,1]}},{\"color-normalize\":120}],743:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=t(\"../constants/xmlns_namespaces\"),o=t(\"../constants/alignment\").LINE_SPACING;function s(t,e){return t.node().getBoundingClientRect()[e]}var l=/([^$]*)([$]+[^$]*[$]+)([^$]*)/;r.convertToTspans=function(t,e,M){var S=t.text(),C=!t.attr(\"data-notex\")&&\"undefined\"!=typeof MathJax&&S.match(l),L=n.select(t.node().parentNode);if(!L.empty()){var P=t.attr(\"class\")?t.attr(\"class\").split(\" \")[0]:\"text\";return P+=\"-math\",L.selectAll(\"svg.\"+P).remove(),L.selectAll(\"g.\"+P+\"-group\").remove(),t.style(\"display\",null).attr({\"data-unformatted\":S,\"data-math\":\"N\"}),C?(e&&e._promises||[]).push(new Promise(function(e){t.style(\"display\",\"none\");var r=parseInt(t.node().style.fontSize,10),a={fontSize:r};!function(t,e,r){var a,o,s,l;MathJax.Hub.Queue(function(){return o=i.extendDeepAll({},MathJax.Hub.config),s=MathJax.Hub.processSectionDelay,void 0!==MathJax.Hub.processSectionDelay&&(MathJax.Hub.processSectionDelay=0),MathJax.Hub.Config({messageStyle:\"none\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]},displayAlign:\"left\"})},function(){if(\"SVG\"!==(a=MathJax.Hub.config.menuSettings.renderer))return MathJax.Hub.setRenderer(\"SVG\")},function(){var r=\"math-output-\"+i.randstr({},64);return l=n.select(\"body\").append(\"div\").attr({id:r}).style({visibility:\"hidden\",position:\"absolute\"}).style({\"font-size\":e.fontSize+\"px\"}).text(t.replace(c,\"\\\\lt \").replace(u,\"\\\\gt \")),MathJax.Hub.Typeset(l.node())},function(){var e=n.select(\"body\").select(\"#MathJax_SVG_glyphs\");if(l.select(\".MathJax_SVG\").empty()||!l.select(\"svg\").node())i.log(\"There was an error in the tex syntax.\",t),r();else{var o=l.select(\"svg\").node().getBoundingClientRect();r(l.select(\".MathJax_SVG\"),e,o)}if(l.remove(),\"SVG\"!==a)return MathJax.Hub.setRenderer(a)},function(){return void 0!==s&&(MathJax.Hub.processSectionDelay=s),MathJax.Hub.Config(o)})}(C[2],a,function(n,i,a){L.selectAll(\"svg.\"+P).remove(),L.selectAll(\"g.\"+P+\"-group\").remove();var o=n&&n.select(\"svg\");if(!o||!o.node())return O(),void e();var l=L.append(\"g\").classed(P+\"-group\",!0).attr({\"pointer-events\":\"none\",\"data-unformatted\":S,\"data-math\":\"Y\"});l.node().appendChild(o.node()),i&&i.node()&&o.node().insertBefore(i.node().cloneNode(!0),o.node().firstChild),o.attr({class:P,height:a.height,preserveAspectRatio:\"xMinYMin meet\"}).style({overflow:\"visible\",\"pointer-events\":\"none\"});var c=t.node().style.fill||\"black\",u=o.select(\"g\");u.attr({fill:c,stroke:c});var h=s(u,\"width\"),f=s(u,\"height\"),p=+t.attr(\"x\")-h*{start:0,middle:.5,end:1}[t.attr(\"text-anchor\")||\"start\"],d=-(r||s(t,\"height\"))/4;\"y\"===P[0]?(l.attr({transform:\"rotate(\"+[-90,+t.attr(\"x\"),+t.attr(\"y\")]+\") translate(\"+[-h/2,d-f/2]+\")\"}),o.attr({x:+t.attr(\"x\"),y:+t.attr(\"y\")})):\"l\"===P[0]?o.attr({x:t.attr(\"x\"),y:d-f/2}):\"a\"===P[0]&&0!==P.indexOf(\"atitle\")?o.attr({x:0,y:d}):o.attr({x:p,y:+t.attr(\"y\")+d-f/2}),M&&M.call(t,l),e(l)})})):O(),t}function O(){L.empty()||(P=t.attr(\"class\")+\"-math\",L.select(\"svg.\"+P).remove()),t.text(\"\").style(\"white-space\",\"pre\"),function(t,e){e=e.replace(v,\" \");var r,s=!1,l=[],c=-1;function u(){c++;var e=document.createElementNS(a.svg,\"tspan\");n.select(e).attr({class:\"line\",dy:c*o+\"em\"}),t.appendChild(e),r=e;var i=l;if(l=[{node:e}],i.length>1)for(var s=1;s<i.length;s++)M(i[s])}function M(t){var e,i=t.type,o={};if(\"a\"===i){e=\"a\";var s=t.target,c=t.href,u=t.popup;c&&(o={\"xlink:xlink:show\":\"_blank\"===s||\"_\"!==s.charAt(0)?\"new\":\"replace\",target:s,\"xlink:xlink:href\":c},u&&(o.onclick='window.open(this.href.baseVal,this.target.baseVal,\"'+u+'\");return false;'))}else e=\"tspan\";t.style&&(o.style=t.style);var h=document.createElementNS(a.svg,e);if(\"sup\"===i||\"sub\"===i){S(r,d),r.appendChild(h);var g=document.createElementNS(a.svg,\"tspan\");S(g,d),n.select(g).attr(\"dy\",p[i]),o.dy=f[i],r.appendChild(h),r.appendChild(g)}else r.appendChild(h);n.select(h).attr(o),r=t.node=h,l.push(t)}function S(t,e){t.appendChild(document.createTextNode(e))}function C(t){if(1!==l.length){var n=l.pop();t!==n.type&&i.log(\"Start tag <\"+n.type+\"> doesnt match end tag <\"+t+\">. Pretending it did match.\",e),r=l[l.length-1].node}else i.log(\"Ignoring unexpected end tag </\"+t+\">.\",e)}x.test(e)?u():(r=t,l=[{node:t}]);for(var L=e.split(m),P=0;P<L.length;P++){var O=L[P],z=O.match(y),I=z&&z[2].toLowerCase(),D=h[I];if(\"br\"===I)u();else if(void 0===D)S(r,E(O));else if(z[1])C(I);else{var R=z[4],F={type:I},B=T(R,b);if(B?(B=B.replace(A,\"$1 fill:\"),D&&(B+=\";\"+D)):D&&(B=D),B&&(F.style=B),\"a\"===I){s=!0;var N=T(R,_);if(N){var j=document.createElement(\"a\");j.href=N,-1!==g.indexOf(j.protocol)&&(F.href=encodeURI(decodeURI(N)),F.target=T(R,w)||\"_blank\",F.popup=T(R,k))}}M(F)}}return s}(t.node(),S)&&t.style(\"pointer-events\",\"all\"),r.positionText(t),M&&M.call(t)}};var c=/(<|&lt;|&#60;)/g,u=/(>|&gt;|&#62;)/g;var h={sup:\"font-size:70%\",sub:\"font-size:70%\",b:\"font-weight:bold\",i:\"font-style:italic\",a:\"cursor:pointer\",span:\"\",em:\"font-style:italic;font-weight:bold\"},f={sub:\"0.3em\",sup:\"-0.6em\"},p={sub:\"-0.21em\",sup:\"0.42em\"},d=\"\\u200b\",g=[\"http:\",\"https:\",\"mailto:\",\"\",void 0,\":\"],v=/(\\r\\n?|\\n)/g,m=/(<[^<>]*>)/,y=/<(\\/?)([^ >]*)(\\s+(.*))?>/i,x=/<br(\\s+.*)?>/i,b=/(^|[\\s\"'])style\\s*=\\s*(\"([^\"]*);?\"|'([^']*);?')/i,_=/(^|[\\s\"'])href\\s*=\\s*(\"([^\"]*)\"|'([^']*)')/i,w=/(^|[\\s\"'])target\\s*=\\s*(\"([^\"\\s]*)\"|'([^'\\s]*)')/i,k=/(^|[\\s\"'])popup\\s*=\\s*(\"([\\w=,]*)\"|'([\\w=,]*)')/i;function T(t,e){if(!t)return null;var r=t.match(e),n=r&&(r[3]||r[4]);return n&&E(n)}var A=/(^|;)\\s*color:/;r.plainText=function(t,e){for(var r=void 0!==(e=e||{}).len&&-1!==e.len?e.len:1/0,n=void 0!==e.allowedTags?e.allowedTags:[\"br\"],i=\"...\".length,a=t.split(m),o=[],s=\"\",l=0,c=0;c<a.length;c++){var u=a[c],h=u.match(y),f=h&&h[2].toLowerCase();if(f)-1!==n.indexOf(f)&&(o.push(u),s=f);else{var p=u.length;if(l+p<r)o.push(u),l+=p;else if(l<r){var d=r-l;s&&(\"br\"!==s||d<=i||p<=i)&&o.pop(),r>i?o.push(u.substr(0,d-i)+\"...\"):o.push(u.substr(0,d));break}s=\"\"}}return o.join(\"\")};var M={mu:\"\\u03bc\",amp:\"&\",lt:\"<\",gt:\">\",nbsp:\"\\xa0\",times:\"\\xd7\",plusmn:\"\\xb1\",deg:\"\\xb0\"},S=/&(#\\d+|#x[\\da-fA-F]+|[a-z]+);/g;function E(t){return t.replace(S,function(t,e){return(\"#\"===e.charAt(0)?function(t){if(t>1114111)return;var e=String.fromCodePoint;if(e)return e(t);var r=String.fromCharCode;return t<=65535?r(t):r(55232+(t>>10),t%1024+56320)}(\"x\"===e.charAt(1)?parseInt(e.substr(2),16):parseInt(e.substr(1),10)):M[e])||t})}function C(t,e,r){var n,i,a,o=r.horizontalAlign,s=r.verticalAlign||\"top\",l=t.node().getBoundingClientRect(),c=e.node().getBoundingClientRect();return i=\"bottom\"===s?function(){return l.bottom-n.height}:\"middle\"===s?function(){return l.top+(l.height-n.height)/2}:function(){return l.top},a=\"right\"===o?function(){return l.right-n.width}:\"center\"===o?function(){return l.left+(l.width-n.width)/2}:function(){return l.left},function(){return n=this.node().getBoundingClientRect(),this.style({top:i()-c.top+\"px\",left:a()-c.left+\"px\",\"z-index\":1e3}),this}}r.convertEntities=E,r.lineCount=function(t){return t.selectAll(\"tspan.line\").size()||1},r.positionText=function(t,e,r){return t.each(function(){var t=n.select(this);function i(e,r){return void 0===r?null===(r=t.attr(e))&&(t.attr(e,0),r=0):t.attr(e,r),r}var a=i(\"x\",e),o=i(\"y\",r);\"text\"===this.nodeName&&t.selectAll(\"tspan.line\").attr({x:a,y:o})})},r.makeEditable=function(t,e){var r=e.gd,i=e.delegate,a=n.dispatch(\"edit\",\"input\",\"cancel\"),o=i||t;if(t.style({\"pointer-events\":i?\"none\":\"all\"}),1!==t.size())throw new Error(\"boo\");function s(){!function(){var i=n.select(r).select(\".svg-container\"),o=i.append(\"div\"),s=t.node().style,c=parseFloat(s.fontSize||12),u=e.text;void 0===u&&(u=t.attr(\"data-unformatted\"));o.classed(\"plugin-editable editable\",!0).style({position:\"absolute\",\"font-family\":s.fontFamily||\"Arial\",\"font-size\":c,color:e.fill||s.fill||\"black\",opacity:1,\"background-color\":e.background||\"transparent\",outline:\"#ffffff33 1px solid\",margin:[-c/8+1,0,0,-1].join(\"px \")+\"px\",padding:\"0\",\"box-sizing\":\"border-box\"}).attr({contenteditable:!0}).text(u).call(C(t,i,e)).on(\"blur\",function(){r._editing=!1,t.text(this.textContent).style({opacity:1});var e,i=n.select(this).attr(\"class\");(e=i?\".\"+i.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(e).style({opacity:0});var o=this.textContent;n.select(this).transition().duration(0).remove(),n.select(document).on(\"mouseup\",null),a.edit.call(t,o)}).on(\"focus\",function(){var t=this;r._editing=!0,n.select(document).on(\"mouseup\",function(){if(n.event.target===t)return!1;document.activeElement===o.node()&&o.node().blur()})}).on(\"keyup\",function(){27===n.event.which?(r._editing=!1,t.style({opacity:1}),n.select(this).style({opacity:0}).on(\"blur\",function(){return!1}).transition().remove(),a.cancel.call(t,this.textContent)):(a.input.call(t,this.textContent),n.select(this).call(C(t,i,e)))}).on(\"keydown\",function(){13===n.event.which&&this.blur()}).call(l)}(),t.style({opacity:0});var i,s=o.attr(\"class\");(i=s?\".\"+s.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(i).style({opacity:0})}function l(t){var e=t.node(),r=document.createRange();r.selectNodeContents(e);var n=window.getSelection();n.removeAllRanges(),n.addRange(r),e.focus()}return e.immediate?s():o.on(\"click\",s),n.rebind(t,a,\"on\")}},{\"../constants/alignment\":688,\"../constants/xmlns_namespaces\":696,\"../lib\":719,d3:163}],744:[function(t,e,r){\"use strict\";var n={};function i(t){t&&null!==t.timer&&(clearTimeout(t.timer),t.timer=null)}r.throttle=function(t,e,r){var a=n[t],o=Date.now();if(!a){for(var s in n)n[s].ts<o-6e4&&delete n[s];a=n[t]={ts:0,timer:null}}function l(){r(),a.ts=Date.now(),a.onDone&&(a.onDone(),a.onDone=null)}i(a),o>a.ts+e?l():a.timer=setTimeout(function(){l(),a.timer=null},e)},r.done=function(t){var e=n[t];return e&&e.timer?new Promise(function(t){var r=e.onDone;e.onDone=function(){r&&r(),t(),e.onDone=null}}):Promise.resolve()},r.clear=function(t){if(t)i(n[t]),delete n[t];else for(var e in n)r.clear(e)}},{}],745:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t,e){if(t>0)return Math.log(t)/Math.LN10;var r=Math.log(Math.min(e[0],e[1]))/Math.LN10;return n(r)||(r=Math.log(Math.max(e[0],e[1]))/Math.LN10-6),r}},{\"fast-isnumeric\":225}],746:[function(t,e,r){\"use strict\";var n=e.exports={},i=t(\"../plots/geo/constants\").locationmodeToLayer,a=t(\"topojson-client\").feature;n.getTopojsonName=function(t){return[t.scope.replace(/ /g,\"-\"),\"_\",t.resolution.toString(),\"m\"].join(\"\")},n.getTopojsonPath=function(t,e){return t+e+\".json\"},n.getTopojsonFeatures=function(t,e){var r=i[t.locationmode],n=e.objects[r];return a(e,n).features}},{\"../plots/geo/constants\":795,\"topojson-client\":540}],747:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en-US\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colorscale title\"},format:{date:\"%m/%d/%Y\"}}},{}],748:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colourscale title\"},format:{days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],periods:[\"AM\",\"PM\"],dateTime:\"%a %b %e %X %Y\",date:\"%d/%m/%Y\",time:\"%H:%M:%S\",decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],year:\"%Y\",month:\"%b %Y\",dayMonth:\"%b %-d\",dayMonthYear:\"%b %-d, %Y\"}}},{}],749:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t){for(var e,r,i=n.layoutArrayContainers,a=n.layoutArrayRegexes,o=t.split(\"[\")[0],s=0;s<a.length;s++)if((r=t.match(a[s]))&&0===r.index){e=r[0];break}if(e||(e=i[i.indexOf(o)]),!e)return!1;var l=t.substr(e.length);return l?!!(r=l.match(/^\\[(0|[1-9][0-9]*)\\](\\.(.+))?$/))&&{array:e,index:Number(r[1]),property:r[3]||\"\"}:{array:e,index:\"\",property:\"\"}}},{\"../registry\":847}],750:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.extendFlat,a=n.isPlainObject,o={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"clearAxisTypes\",\"plot\",\"style\",\"markerSize\",\"colorbars\"]},s={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"plot\",\"legend\",\"ticks\",\"axrange\",\"layoutstyle\",\"modebar\",\"camera\",\"arraydraw\",\"colorbars\"]},l=o.flags.slice().concat([\"fullReplot\"]),c=s.flags.slice().concat(\"layoutReplot\");function u(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=!1;return e}function h(t,e,r){var n=i({},t);for(var o in n){var s=n[o];a(s)&&(n[o]=f(s,e,r,o))}return\"from-root\"===r&&(n.editType=e),n}function f(t,e,r,n){if(t.valType){var a=i({},t);if(a.editType=e,Array.isArray(t.items)){a.items=new Array(t.items.length);for(var o=0;o<t.items.length;o++)a.items[o]=f(t.items[o],e,\"from-root\")}return a}return h(t,e,\"_\"===n.charAt(0)?\"nested\":\"from-root\")}e.exports={traces:o,layout:s,traceFlags:function(){return u(l)},layoutFlags:function(){return u(c)},update:function(t,e){var r=e.editType;if(r&&\"none\"!==r)for(var n=r.split(\"+\"),i=0;i<n.length;i++)t[n[i]]=!0},overrideAll:h}},{\"../lib\":719}],751:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"gl-mat4/fromQuat\"),a=t(\"../registry\"),o=t(\"../lib\"),s=t(\"../plots/plots\"),l=t(\"../plots/cartesian/axis_ids\"),c=t(\"../components/color\"),u=l.cleanId,h=l.getFromTrace,f=a.traceIs;function p(t,e){var r=t[e],n=e.charAt(0);r&&\"paper\"!==r&&(t[e]=u(r,n))}function d(t){function e(e,r){var n=t[e],i=t.title&&t.title[r];n&&!i&&(t.title||(t.title={}),t.title[r]=t[e],delete t[e])}t&&(\"string\"!=typeof t.title&&\"number\"!=typeof t.title||(t.title={text:t.title}),e(\"titlefont\",\"font\"),e(\"titleposition\",\"position\"),e(\"titleside\",\"side\"),e(\"titleoffset\",\"offset\"))}function g(t){if(!o.isPlainObject(t))return!1;var e=t.name;return delete t.name,delete t.showlegend,(\"string\"==typeof e||\"number\"==typeof e)&&String(e)}function v(t,e,r,n){if(r&&!n)return t;if(n&&!r)return e;if(!t.trim())return e;if(!e.trim())return t;var i,a=Math.min(t.length,e.length);for(i=0;i<a&&t.charAt(i)===e.charAt(i);i++);return t.substr(0,i).trim()}function m(t){var e=\"middle\",r=\"center\";return\"string\"==typeof t&&(-1!==t.indexOf(\"top\")?e=\"top\":-1!==t.indexOf(\"bottom\")&&(e=\"bottom\"),-1!==t.indexOf(\"left\")?r=\"left\":-1!==t.indexOf(\"right\")&&(r=\"right\")),e+\" \"+r}function y(t,e){return e in t&&\"object\"==typeof t[e]&&0===Object.keys(t[e]).length}r.clearPromiseQueue=function(t){Array.isArray(t._promises)&&t._promises.length>0&&o.log(\"Clearing previous rejected promises from queue.\"),t._promises=[]},r.cleanLayout=function(t){var e,n;t||(t={}),t.xaxis1&&(t.xaxis||(t.xaxis=t.xaxis1),delete t.xaxis1),t.yaxis1&&(t.yaxis||(t.yaxis=t.yaxis1),delete t.yaxis1),t.scene1&&(t.scene||(t.scene=t.scene1),delete t.scene1);var a=(s.subplotsRegistry.cartesian||{}).attrRegex,l=(s.subplotsRegistry.polar||{}).attrRegex,h=(s.subplotsRegistry.ternary||{}).attrRegex,f=(s.subplotsRegistry.gl3d||{}).attrRegex,g=Object.keys(t);for(e=0;e<g.length;e++){var v=g[e];if(a&&a.test(v)){var m=t[v];m.anchor&&\"free\"!==m.anchor&&(m.anchor=u(m.anchor)),m.overlaying&&(m.overlaying=u(m.overlaying)),m.type||(m.isdate?m.type=\"date\":m.islog?m.type=\"log\":!1===m.isdate&&!1===m.islog&&(m.type=\"linear\")),\"withzero\"!==m.autorange&&\"tozero\"!==m.autorange||(m.autorange=!0,m.rangemode=\"tozero\"),delete m.islog,delete m.isdate,delete m.categories,y(m,\"domain\")&&delete m.domain,void 0!==m.autotick&&(void 0===m.tickmode&&(m.tickmode=m.autotick?\"auto\":\"linear\"),delete m.autotick),d(m)}else if(l&&l.test(v)){d(t[v].radialaxis)}else if(h&&h.test(v)){var x=t[v];d(x.aaxis),d(x.baxis),d(x.caxis)}else if(f&&f.test(v)){var b=t[v],_=b.cameraposition;if(Array.isArray(_)&&4===_[0].length){var w=_[0],k=_[1],T=_[2],A=i([],w),M=[];for(n=0;n<3;++n)M[n]=k[n]+T*A[2+4*n];b.camera={eye:{x:M[0],y:M[1],z:M[2]},center:{x:k[0],y:k[1],z:k[2]},up:{x:0,y:0,z:1}},delete b.cameraposition}d(b.xaxis),d(b.yaxis),d(b.zaxis)}}var S=Array.isArray(t.annotations)?t.annotations.length:0;for(e=0;e<S;e++){var E=t.annotations[e];o.isPlainObject(E)&&(E.ref&&(\"paper\"===E.ref?(E.xref=\"paper\",E.yref=\"paper\"):\"data\"===E.ref&&(E.xref=\"x\",E.yref=\"y\"),delete E.ref),p(E,\"xref\"),p(E,\"yref\"))}var C=Array.isArray(t.shapes)?t.shapes.length:0;for(e=0;e<C;e++){var L=t.shapes[e];o.isPlainObject(L)&&(p(L,\"xref\"),p(L,\"yref\"))}var P=t.legend;return P&&(P.x>3?(P.x=1.02,P.xanchor=\"left\"):P.x<-2&&(P.x=-.02,P.xanchor=\"right\"),P.y>3?(P.y=1.02,P.yanchor=\"bottom\"):P.y<-2&&(P.y=-.02,P.yanchor=\"top\")),d(t),\"rotate\"===t.dragmode&&(t.dragmode=\"orbit\"),c.clean(t),t.template&&t.template.layout&&r.cleanLayout(t.template.layout),t},r.cleanData=function(t){for(var e=0;e<t.length;e++){var n,i=t[e];if(\"histogramy\"===i.type&&\"xbins\"in i&&!(\"ybins\"in i)&&(i.ybins=i.xbins,delete i.xbins),i.error_y&&\"opacity\"in i.error_y){var l=c.defaults,h=i.error_y.color||(f(i,\"bar\")?c.defaultLine:l[e%l.length]);i.error_y.color=c.addOpacity(c.rgb(h),c.opacity(h)*i.error_y.opacity),delete i.error_y.opacity}if(\"bardir\"in i&&(\"h\"!==i.bardir||!f(i,\"bar\")&&\"histogram\"!==i.type.substr(0,9)||(i.orientation=\"h\",r.swapXYData(i)),delete i.bardir),\"histogramy\"===i.type&&r.swapXYData(i),\"histogramx\"!==i.type&&\"histogramy\"!==i.type||(i.type=\"histogram\"),\"scl\"in i&&!(\"colorscale\"in i)&&(i.colorscale=i.scl,delete i.scl),\"reversescl\"in i&&!(\"reversescale\"in i)&&(i.reversescale=i.reversescl,delete i.reversescl),i.xaxis&&(i.xaxis=u(i.xaxis,\"x\")),i.yaxis&&(i.yaxis=u(i.yaxis,\"y\")),f(i,\"gl3d\")&&i.scene&&(i.scene=s.subplotsRegistry.gl3d.cleanId(i.scene)),!f(i,\"pie-like\")&&!f(i,\"bar-like\"))if(Array.isArray(i.textposition))for(n=0;n<i.textposition.length;n++)i.textposition[n]=m(i.textposition[n]);else i.textposition&&(i.textposition=m(i.textposition));var p=a.getModule(i);if(p&&p.colorbar){var x=p.colorbar.container,b=x?i[x]:i;b&&b.colorscale&&(\"YIGnBu\"===b.colorscale&&(b.colorscale=\"YlGnBu\"),\"YIOrRd\"===b.colorscale&&(b.colorscale=\"YlOrRd\"))}if(\"surface\"===i.type&&o.isPlainObject(i.contours)){var _=[\"x\",\"y\",\"z\"];for(n=0;n<_.length;n++){var w=i.contours[_[n]];o.isPlainObject(w)&&(w.highlightColor&&(w.highlightcolor=w.highlightColor,delete w.highlightColor),w.highlightWidth&&(w.highlightwidth=w.highlightWidth,delete w.highlightWidth))}}if(\"candlestick\"===i.type||\"ohlc\"===i.type){var k=!1!==(i.increasing||{}).showlegend,T=!1!==(i.decreasing||{}).showlegend,A=g(i.increasing),M=g(i.decreasing);if(!1!==A&&!1!==M){var S=v(A,M,k,T);S&&(i.name=S)}else!A&&!M||i.name||(i.name=A||M)}if(Array.isArray(i.transforms)){var E=i.transforms;for(n=0;n<E.length;n++){var C=E[n];if(o.isPlainObject(C))switch(C.type){case\"filter\":C.filtersrc&&(C.target=C.filtersrc,delete C.filtersrc),C.calendar&&(C.valuecalendar||(C.valuecalendar=C.calendar),delete C.calendar);break;case\"groupby\":if(C.styles=C.styles||C.style,C.styles&&!Array.isArray(C.styles)){var L=C.styles,P=Object.keys(L);C.styles=[];for(var O=0;O<P.length;O++)C.styles.push({target:P[O],value:L[P[O]]})}}}}y(i,\"line\")&&delete i.line,\"marker\"in i&&(y(i.marker,\"line\")&&delete i.marker.line,y(i,\"marker\")&&delete i.marker),c.clean(i),i.autobinx&&(delete i.autobinx,delete i.xbins),i.autobiny&&(delete i.autobiny,delete i.ybins),d(i),i.colorbar&&d(i.colorbar),i.marker&&i.marker.colorbar&&d(i.marker.colorbar),i.line&&i.line.colorbar&&d(i.line.colorbar),i.aaxis&&d(i.aaxis),i.baxis&&d(i.baxis)}},r.swapXYData=function(t){var e;if(o.swapAttrs(t,[\"?\",\"?0\",\"d?\",\"?bins\",\"nbins?\",\"autobin?\",\"?src\",\"error_?\"]),Array.isArray(t.z)&&Array.isArray(t.z[0])&&(t.transpose?delete t.transpose:t.transpose=!0),t.error_x&&t.error_y){var r=t.error_y,n=\"copy_ystyle\"in r?r.copy_ystyle:!(r.color||r.thickness||r.width);o.swapAttrs(t,[\"error_?.copy_ystyle\"]),n&&o.swapAttrs(t,[\"error_?.color\",\"error_?.thickness\",\"error_?.width\"])}if(\"string\"==typeof t.hoverinfo){var i=t.hoverinfo.split(\"+\");for(e=0;e<i.length;e++)\"x\"===i[e]?i[e]=\"y\":\"y\"===i[e]&&(i[e]=\"x\");t.hoverinfo=i.join(\"+\")}},r.coerceTraceIndices=function(t,e){if(n(e))return[e];if(!Array.isArray(e)||!e.length)return t.data.map(function(t,e){return e});if(Array.isArray(e)){for(var r=[],i=0;i<e.length;i++)o.isIndex(e[i],t.data.length)?r.push(e[i]):o.warn(\"trace index (\",e[i],\") is not a number or is out of bounds\");return r}return e},r.manageArrayContainers=function(t,e,r){var i=t.obj,a=t.parts,s=a.length,l=a[s-1],c=n(l);if(c&&null===e){var u=a.slice(0,s-1).join(\".\");o.nestedProperty(i,u).get().splice(l,1)}else c&&void 0===t.get()?(void 0===t.get()&&(r[t.astr]=null),t.set(e)):t.set(e)};var x=/(\\.[^\\[\\]\\.]+|\\[[^\\[\\]\\.]+\\])$/;function b(t){var e=t.search(x);if(e>0)return t.substr(0,e)}r.hasParent=function(t,e){for(var r=b(e);r;){if(r in t)return!0;r=b(r)}return!1};var _=[\"x\",\"y\",\"z\"];r.clearAxisTypes=function(t,e,r){for(var n=0;n<e.length;n++)for(var i=t._fullData[n],a=0;a<3;a++){var s=h(t,i,_[a]);if(s&&\"log\"!==s.type){var l=s._name,c=s._id.substr(1);if(\"scene\"===c.substr(0,5)){if(void 0!==r[c])continue;l=c+\".\"+l}var u=l+\".type\";void 0===r[l]&&void 0===r[u]&&o.nestedProperty(t.layout,u).set(null)}}}},{\"../components/color\":593,\"../lib\":719,\"../plots/cartesian/axis_ids\":770,\"../plots/plots\":828,\"../registry\":847,\"fast-isnumeric\":225,\"gl-mat4/fromQuat\":262}],752:[function(t,e,r){\"use strict\";var n=t(\"./plot_api\");r.plot=n.plot,r.newPlot=n.newPlot,r.restyle=n.restyle,r.relayout=n.relayout,r.redraw=n.redraw,r.update=n.update,r._guiRestyle=n._guiRestyle,r._guiRelayout=n._guiRelayout,r._guiUpdate=n._guiUpdate,r._storeDirectGUIEdit=n._storeDirectGUIEdit,r.react=n.react,r.extendTraces=n.extendTraces,r.prependTraces=n.prependTraces,r.addTraces=n.addTraces,r.deleteTraces=n.deleteTraces,r.moveTraces=n.moveTraces,r.purge=n.purge,r.addFrames=n.addFrames,r.deleteFrames=n.deleteFrames,r.animate=n.animate,r.setPlotConfig=n.setPlotConfig,r.toImage=t(\"./to_image\"),r.validate=t(\"./validate\"),r.downloadImage=t(\"../snapshot/download\");var i=t(\"./template_api\");r.makeTemplate=i.makeTemplate,r.validateTemplate=i.validateTemplate},{\"../snapshot/download\":849,\"./plot_api\":754,\"./template_api\":759,\"./to_image\":760,\"./validate\":761}],753:[function(t,e,r){\"use strict\";var n=t(\"../lib/is_plain_object\"),i=t(\"../lib/noop\"),a=t(\"../lib/loggers\"),o=t(\"../lib/search\").sorterAsc,s=t(\"../registry\");r.containerArrayMatch=t(\"./container_array_match\");var l=r.isAddVal=function(t){return\"add\"===t||n(t)},c=r.isRemoveVal=function(t){return null===t||\"remove\"===t};r.applyContainerArrayChanges=function(t,e,r,n,u){var h=e.astr,f=s.getComponentMethod(h,\"supplyLayoutDefaults\"),p=s.getComponentMethod(h,\"draw\"),d=s.getComponentMethod(h,\"drawOne\"),g=n.replot||n.recalc||f===i||p===i,v=t.layout,m=t._fullLayout;if(r[\"\"]){Object.keys(r).length>1&&a.warn(\"Full array edits are incompatible with other edits\",h);var y=r[\"\"][\"\"];if(c(y))e.set(null);else{if(!Array.isArray(y))return a.warn(\"Unrecognized full array edit value\",h,y),!0;e.set(y)}return!g&&(f(v,m),p(t),!0)}var x,b,_,w,k,T,A,M,S=Object.keys(r).map(Number).sort(o),E=e.get(),C=E||[],L=u(m,h).get(),P=[],O=-1,z=C.length;for(x=0;x<S.length;x++)if(w=r[_=S[x]],k=Object.keys(w),T=w[\"\"],A=l(T),_<0||_>C.length-(A?0:1))a.warn(\"index out of range\",h,_);else if(void 0!==T)k.length>1&&a.warn(\"Insertion & removal are incompatible with edits to the same index.\",h,_),c(T)?P.push(_):A?(\"add\"===T&&(T={}),C.splice(_,0,T),L&&L.splice(_,0,{})):a.warn(\"Unrecognized full object edit value\",h,_,T),-1===O&&(O=_);else for(b=0;b<k.length;b++)M=h+\"[\"+_+\"].\",u(C[_],k[b],M).set(w[k[b]]);for(x=P.length-1;x>=0;x--)C.splice(P[x],1),L&&L.splice(P[x],1);if(C.length?E||e.set(C):e.set(null),g)return!1;if(f(v,m),d!==i){var I;if(-1===O)I=S;else{for(z=Math.max(C.length,z),I=[],x=0;x<S.length&&!((_=S[x])>=O);x++)I.push(_);for(x=O;x<z;x++)I.push(x)}for(x=0;x<I.length;x++)d(t,I[x])}else p(t);return!0}},{\"../lib/is_plain_object\":720,\"../lib/loggers\":723,\"../lib/noop\":728,\"../lib/search\":738,\"../registry\":847,\"./container_array_match\":749}],754:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"has-hover\"),o=t(\"../lib\"),s=o.nestedProperty,l=t(\"../lib/events\"),c=t(\"../lib/queue\"),u=t(\"../registry\"),h=t(\"./plot_schema\"),f=t(\"../plots/plots\"),p=t(\"../plots/polar/legacy\"),d=t(\"../plots/cartesian/axes\"),g=t(\"../components/drawing\"),v=t(\"../components/color\"),m=t(\"../plots/cartesian/graph_interact\").initInteractions,y=t(\"../constants/xmlns_namespaces\"),x=t(\"../lib/svg_text_utils\"),b=t(\"../plots/cartesian/select\").clearSelect,_=t(\"./plot_config\").dfltConfig,w=t(\"./manage_arrays\"),k=t(\"./helpers\"),T=t(\"./subroutines\"),A=t(\"./edit_types\"),M=t(\"../plots/cartesian/constants\").AX_NAME_PATTERN,S=0,E=5;function C(t){var e=t._fullLayout;e._redrawFromAutoMarginCount?e._redrawFromAutoMarginCount--:t.emit(\"plotly_afterplot\")}function L(t,e){try{t._fullLayout._paper.style(\"background\",e)}catch(t){o.error(t)}}function P(t,e){L(t,v.combine(e,\"white\"))}function O(t,e){if(!t._context){t._context=o.extendDeep({},_);var r=n.select(\"base\");t._context._baseUrl=r.size()&&r.attr(\"href\")?window.location.href.split(\"#\")[0]:\"\"}var i,s,l,c=t._context;if(e){for(s=Object.keys(e),i=0;i<s.length;i++)\"editable\"!==(l=s[i])&&\"edits\"!==l&&l in c&&(\"setBackground\"===l&&\"opaque\"===e[l]?c[l]=P:c[l]=e[l]);e.plot3dPixelRatio&&!c.plotGlPixelRatio&&(c.plotGlPixelRatio=c.plot3dPixelRatio);var u=e.editable;if(void 0!==u)for(c.editable=u,s=Object.keys(c.edits),i=0;i<s.length;i++)c.edits[s[i]]=u;if(e.edits)for(s=Object.keys(e.edits),i=0;i<s.length;i++)(l=s[i])in c.edits&&(c.edits[l]=e.edits[l]);c._exportedPlot=e._exportedPlot}c.staticPlot&&(c.editable=!1,c.edits={},c.autosizable=!1,c.scrollZoom=!1,c.doubleClick=!1,c.showTips=!1,c.showLink=!1,c.displayModeBar=!1),\"hover\"!==c.displayModeBar||a||(c.displayModeBar=!0),\"transparent\"!==c.setBackground&&\"function\"==typeof c.setBackground||(c.setBackground=L),c._hasZeroHeight=c._hasZeroHeight||0===t.clientHeight,c._hasZeroWidth=c._hasZeroWidth||0===t.clientWidth;var h=c.scrollZoom,f=c._scrollZoom={};if(!0===h)f.cartesian=1,f.gl3d=1,f.geo=1,f.mapbox=1;else if(\"string\"==typeof h){var p=h.split(\"+\");for(i=0;i<p.length;i++)f[p[i]]=1}else!1!==h&&(f.gl3d=1,f.geo=1,f.mapbox=1)}function z(t,e){var r,n,i=e+1,a=[];for(r=0;r<t.length;r++)(n=t[r])<0?a.push(i+n):a.push(n);return a}function I(t,e,r){var n,i;for(n=0;n<e.length;n++){if((i=e[n])!==parseInt(i,10))throw new Error(\"all values in \"+r+\" must be integers\");if(i>=t.data.length||i<-t.data.length)throw new Error(r+\" must be valid indices for gd.data.\");if(e.indexOf(i,n+1)>-1||i>=0&&e.indexOf(-t.data.length+i)>-1||i<0&&e.indexOf(t.data.length+i)>-1)throw new Error(\"each index in \"+r+\" must be unique.\")}}function D(t,e,r){if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"currentIndices is a required argument.\");if(Array.isArray(e)||(e=[e]),I(t,e,\"currentIndices\"),\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&I(t,r,\"newIndices\"),\"undefined\"!=typeof r&&e.length!==r.length)throw new Error(\"current and new indices must be of equal length.\")}function R(t,e,r,n,a){!function(t,e,r,n){var i=o.isPlainObject(n);if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array\");if(!o.isPlainObject(e))throw new Error(\"update must be a key:value object\");if(\"undefined\"==typeof r)throw new Error(\"indices must be an integer or array of integers\");for(var a in I(t,r,\"indices\"),e){if(!Array.isArray(e[a])||e[a].length!==r.length)throw new Error(\"attribute \"+a+\" must be an array of length equal to indices array length\");if(i&&(!(a in n)||!Array.isArray(n[a])||n[a].length!==e[a].length))throw new Error(\"when maxPoints is set as a key:value object it must contain a 1:1 corrispondence with the keys and number of traces in the update object\")}}(t,e,r,n);for(var l=function(t,e,r,n){var a,l,c,u,h,f=o.isPlainObject(n),p=[];for(var d in Array.isArray(r)||(r=[r]),r=z(r,t.data.length-1),e)for(var g=0;g<r.length;g++){if(a=t.data[r[g]],l=(c=s(a,d)).get(),u=e[d][g],!o.isArrayOrTypedArray(u))throw new Error(\"attribute: \"+d+\" index: \"+g+\" must be an array\");if(!o.isArrayOrTypedArray(l))throw new Error(\"cannot extend missing or non-array attribute: \"+d);if(l.constructor!==u.constructor)throw new Error(\"cannot extend array with an array of a different type: \"+d);h=f?n[d][g]:n,i(h)||(h=-1),p.push({prop:c,target:l,insert:u,maxp:Math.floor(h)})}return p}(t,e,r,n),c={},u={},h=0;h<l.length;h++){var f=l[h].prop,p=l[h].maxp,d=a(l[h].target,l[h].insert,p);f.set(d[0]),Array.isArray(c[f.astr])||(c[f.astr]=[]),c[f.astr].push(d[1]),Array.isArray(u[f.astr])||(u[f.astr]=[]),u[f.astr].push(l[h].target.length)}return{update:c,maxPoints:u}}function F(t,e){var r=new t.constructor(t.length+e.length);return r.set(t),r.set(e,t.length),r}function B(t,e,n,i){t=o.getGraphDiv(t),k.clearPromiseQueue(t);var a={};if(\"string\"==typeof e)a[e]=n;else{if(!o.isPlainObject(e))return o.warn(\"Restyle fail.\",e,n,i),Promise.reject();a=o.extendFlat({},e),void 0===i&&(i=n)}Object.keys(a).length&&(t.changed=!0);var s=k.coerceTraceIndices(t,i),l=V(t,a,s),u=l.flags;u.calc&&(t.calcdata=void 0),u.clearAxisTypes&&k.clearAxisTypes(t,s,{});var h=[];u.fullReplot?h.push(r.plot):(h.push(f.previousPromises),f.supplyDefaults(t),u.markerSize&&(f.doCalcdata(t),Y(h)),u.style&&h.push(T.doTraceStyle),u.colorbars&&h.push(T.doColorBars),h.push(C)),h.push(f.rehover,f.redrag),c.add(t,B,[t,l.undoit,l.traces],B,[t,l.redoit,l.traces]);var p=o.syncOrAsync(h,t);return p&&p.then||(p=Promise.resolve()),p.then(function(){return t.emit(\"plotly_restyle\",l.eventData),t})}function N(t){return void 0===t?null:t}function j(t,e){return e?function(e,r,n){var i=s(e,r),a=i.set;return i.set=function(e){U((n||\"\")+r,i.get(),e,t),a(e)},i}:s}function U(t,e,r,n){if(Array.isArray(e)||Array.isArray(r))for(var i=Array.isArray(e)?e:[],a=Array.isArray(r)?r:[],s=Math.max(i.length,a.length),l=0;l<s;l++)U(t+\"[\"+l+\"]\",i[l],a[l],n);else if(o.isPlainObject(e)||o.isPlainObject(r)){var c=o.isPlainObject(e)?e:{},u=o.isPlainObject(r)?r:{},h=o.extendFlat({},c,u);for(var f in h)U(t+\".\"+f,c[f],u[f],n)}else void 0===n[t]&&(n[t]=N(e))}function V(t,e,r){var n,i=t._fullLayout,a=t._fullData,l=t.data,c=i._guiEditing,p=j(i._preGUI,c),g=o.extendDeepAll({},e);q(e);var v,m=A.traceFlags(),y={},x={};function b(){return r.map(function(){})}function _(t){var e=d.id2name(t);-1===v.indexOf(e)&&v.push(e)}function w(t){return\"LAYOUT\"+t+\".autorange\"}function T(t){return\"LAYOUT\"+t+\".range\"}function M(t){for(var e=t;e<a.length;e++)if(a[e]._input===l[t])return a[e]}function S(n,a,o){if(Array.isArray(n))n.forEach(function(t){S(t,a,o)});else if(!(n in e||k.hasParent(e,n))){var s;if(\"LAYOUT\"===n.substr(0,6))s=p(t.layout,n.replace(\"LAYOUT\",\"\"));else{var u=r[o];s=j(i._tracePreGUI[M(u)._fullInput.uid],c)(l[u],n)}n in x||(x[n]=b()),void 0===x[n][o]&&(x[n][o]=N(s.get())),void 0!==a&&s.set(a)}}function E(t){return function(e){return a[e][t]}}function C(t){return function(e,n){return!1===e?a[r[n]][t]:null}}for(var L in e){if(k.hasParent(e,L))throw new Error(\"cannot set \"+L+\" and a parent attribute simultaneously\");var P,O,z,I,D,R,F=e[L];if(\"autobinx\"!==L&&\"autobiny\"!==L||(L=L.charAt(L.length-1)+\"bins\",F=Array.isArray(F)?F.map(C(L)):!1===F?r.map(E(L)):null),y[L]=F,\"LAYOUT\"!==L.substr(0,6)){for(x[L]=b(),n=0;n<r.length;n++){if(P=l[r[n]],O=M(r[n]),I=(z=j(i._tracePreGUI[O._fullInput.uid],c)(P,L)).get(),void 0!==(D=Array.isArray(F)?F[n%F.length]:F)){var B=z.parts[z.parts.length-1],U=L.substr(0,L.length-B.length-1),V=U?U+\".\":\"\",H=U?s(O,U).get():O;if((R=h.getTraceValObject(O,z.parts))&&R.impliedEdits&&null!==D)for(var G in R.impliedEdits)S(o.relativeAttr(L,G),R.impliedEdits[G],n);else if(\"thicknessmode\"!==B&&\"lenmode\"!==B||I===D||\"fraction\"!==D&&\"pixels\"!==D||!H){if(\"type\"===L&&(\"pie\"===D!=(\"pie\"===I)||\"funnelarea\"===D!=(\"funnelarea\"===I))){var Y=\"x\",W=\"y\";\"bar\"!==D&&\"bar\"!==I||\"h\"!==P.orientation||(Y=\"y\",W=\"x\"),o.swapAttrs(P,[\"?\",\"?src\"],\"labels\",Y),o.swapAttrs(P,[\"d?\",\"?0\"],\"label\",Y),o.swapAttrs(P,[\"?\",\"?src\"],\"values\",W),\"pie\"===I||\"funnelarea\"===I?(s(P,\"marker.color\").set(s(P,\"marker.colors\").get()),i._pielayer.selectAll(\"g.trace\").remove()):u.traceIs(P,\"cartesian\")&&s(P,\"marker.colors\").set(s(P,\"marker.color\").get())}}else{var X=i._size,Z=H.orient,J=\"top\"===Z||\"bottom\"===Z;if(\"thicknessmode\"===B){var K=J?X.h:X.w;S(V+\"thickness\",H.thickness*(\"fraction\"===D?1/K:K),n)}else{var $=J?X.w:X.h;S(V+\"len\",H.len*(\"fraction\"===D?1/$:$),n)}}x[L][n]=N(I);if(-1!==[\"swapxy\",\"swapxyaxes\",\"orientation\",\"orientationaxes\"].indexOf(L)){if(\"orientation\"===L){z.set(D);var Q=P.x&&!P.y?\"h\":\"v\";if((z.get()||Q)===O.orientation)continue}else\"orientationaxes\"===L&&(P.orientation={v:\"h\",h:\"v\"}[O.orientation]);k.swapXYData(P),m.calc=m.clearAxisTypes=!0}else-1!==f.dataArrayContainers.indexOf(z.parts[0])?(k.manageArrayContainers(z,D,x),m.calc=!0):(R?R.arrayOk&&!u.traceIs(O,\"regl\")&&(o.isArrayOrTypedArray(D)||o.isArrayOrTypedArray(I))?m.calc=!0:A.update(m,R):m.calc=!0,z.set(D))}}if(-1!==[\"swapxyaxes\",\"orientationaxes\"].indexOf(L)&&d.swap(t,r),\"orientationaxes\"===L){var tt=s(t.layout,\"hovermode\");\"x\"===tt.get()?tt.set(\"y\"):\"y\"===tt.get()&&tt.set(\"x\")}if(-1!==[\"orientation\",\"type\"].indexOf(L)){for(v=[],n=0;n<r.length;n++){var et=l[r[n]];u.traceIs(et,\"cartesian\")&&(_(et.xaxis||\"x\"),_(et.yaxis||\"y\"))}S(v.map(w),!0,0),S(v.map(T),[0,1],0)}}else z=p(t.layout,L.replace(\"LAYOUT\",\"\")),x[L]=[N(z.get())],z.set(Array.isArray(F)?F[0]:F),m.calc=!0}return(m.calc||m.plot)&&(m.fullReplot=!0),{flags:m,undoit:x,redoit:y,traces:r,eventData:o.extendDeepNoArrays([],[g,r])}}function q(t){var e,r,n,i=o.counterRegex(\"axis\",\".title\",!1,!1),a=/colorbar\\.title$/,s=Object.keys(t);for(e=0;e<s.length;e++)r=s[e],n=t[r],\"title\"!==r&&!i.test(r)&&!a.test(r)||\"string\"!=typeof n&&\"number\"!=typeof n?r.indexOf(\"titlefont\")>-1?l(r,r.replace(\"titlefont\",\"title.font\")):r.indexOf(\"titleposition\")>-1?l(r,r.replace(\"titleposition\",\"title.position\")):r.indexOf(\"titleside\")>-1?l(r,r.replace(\"titleside\",\"title.side\")):r.indexOf(\"titleoffset\")>-1&&l(r,r.replace(\"titleoffset\",\"title.offset\")):l(r,r.replace(\"title\",\"title.text\"));function l(e,r){t[r]=t[e],delete t[e]}}function H(t,e,r){if(t=o.getGraphDiv(t),k.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);var n={};if(\"string\"==typeof e)n[e]=r;else{if(!o.isPlainObject(e))return o.warn(\"Relayout fail.\",e,r),Promise.reject();n=o.extendFlat({},e)}Object.keys(n).length&&(t.changed=!0);var i=J(t,n),a=i.flags;a.calc&&(t.calcdata=void 0);var s=[f.previousPromises];a.layoutReplot?s.push(T.layoutReplot):Object.keys(n).length&&(G(t,a,i)||f.supplyDefaults(t),a.legend&&s.push(T.doLegend),a.layoutstyle&&s.push(T.layoutStyles),a.axrange&&Y(s,i.rangesAltered),a.ticks&&s.push(T.doTicksRelayout),a.modebar&&s.push(T.doModeBar),a.camera&&s.push(T.doCamera),a.colorbars&&s.push(T.doColorBars),s.push(C)),s.push(f.rehover,f.redrag),c.add(t,H,[t,i.undoit],H,[t,i.redoit]);var l=o.syncOrAsync(s,t);return l&&l.then||(l=Promise.resolve(t)),l.then(function(){return t.emit(\"plotly_relayout\",i.eventData),t})}function G(t,e,r){var n=t._fullLayout;if(!e.axrange)return!1;for(var i in e)if(\"axrange\"!==i&&e[i])return!1;for(var a in r.rangesAltered){var o=d.id2name(a),s=t.layout[o],l=n[o];if(l.autorange=s.autorange,l.range=s.range.slice(),l.cleanRange(),l._matchGroup)for(var c in l._matchGroup)if(c!==a){var u=n[d.id2name(c)];u.autorange=l.autorange,u.range=l.range.slice(),u._input.range=l.range.slice()}}return!0}function Y(t,e){var r=e?function(t){var r=[],n=!0;for(var i in e){var a=d.getFromId(t,i);if(r.push(i),a._matchGroup)for(var o in a._matchGroup)e[o]||r.push(o);a.automargin&&(n=!1)}return d.draw(t,r,{skipTitle:n})}:function(t){return d.draw(t,\"redraw\")};t.push(b,T.doAutoRangeAndConstraints,r,T.drawData,T.finalDraw)}var W=/^[xyz]axis[0-9]*\\.range(\\[[0|1]\\])?$/,X=/^[xyz]axis[0-9]*\\.autorange$/,Z=/^[xyz]axis[0-9]*\\.domain(\\[[0|1]\\])?$/;function J(t,e){var r,n,i,a=t.layout,l=t._fullLayout,c=l._guiEditing,f=j(l._preGUI,c),p=Object.keys(e),g=d.list(t),v=o.extendDeepAll({},e),m={};for(q(e),p=Object.keys(e),n=0;n<p.length;n++)if(0===p[n].indexOf(\"allaxes\")){for(i=0;i<g.length;i++){var y=g[i]._id.substr(1),x=-1!==y.indexOf(\"scene\")?y+\".\":\"\",b=p[n].replace(\"allaxes\",x+g[i]._name);e[b]||(e[b]=e[p[n]])}delete e[p[n]]}var _=A.layoutFlags(),T={},S={};function E(t,r){if(Array.isArray(t))t.forEach(function(t){E(t,r)});else if(!(t in e||k.hasParent(e,t))){var n=f(a,t);t in S||(S[t]=N(n.get())),void 0!==r&&n.set(r)}}var C,L={};function P(t){var e=d.name2id(t.split(\".\")[0]);return L[e]=1,e}for(var O in e){if(k.hasParent(e,O))throw new Error(\"cannot set \"+O+\" and a parent attribute simultaneously\");for(var z=f(a,O),I=e[O],D=z.parts.length-1;D>0&&\"string\"!=typeof z.parts[D];)D--;var R=z.parts[D],F=z.parts[D-1]+\".\"+R,B=z.parts.slice(0,D).join(\".\"),U=s(t.layout,B).get(),V=s(l,B).get(),H=z.get();if(void 0!==I){T[O]=I,S[O]=\"reverse\"===R?I:N(H);var G=h.getLayoutValObject(l,z.parts);if(G&&G.impliedEdits&&null!==I)for(var Y in G.impliedEdits)E(o.relativeAttr(O,Y),G.impliedEdits[Y]);if(-1!==[\"width\",\"height\"].indexOf(O))if(I){E(\"autosize\",null);var J=\"height\"===O?\"width\":\"height\";E(J,l[J])}else l[O]=t._initialAutoSize[O];else if(\"autosize\"===O)E(\"width\",I?null:l.width),E(\"height\",I?null:l.height);else if(F.match(W))P(F),s(l,B+\"._inputRange\").set(null);else if(F.match(X)){P(F),s(l,B+\"._inputRange\").set(null);var $=s(l,B).get();$._inputDomain&&($._input.domain=$._inputDomain.slice())}else F.match(Z)&&s(l,B+\"._inputDomain\").set(null);if(\"type\"===R){var Q=U,tt=\"linear\"===V.type&&\"log\"===I,et=\"log\"===V.type&&\"linear\"===I;if(tt||et){if(Q&&Q.range)if(V.autorange)tt&&(Q.range=Q.range[1]>Q.range[0]?[1,2]:[2,1]);else{var rt=Q.range[0],nt=Q.range[1];tt?(rt<=0&&nt<=0&&E(B+\".autorange\",!0),rt<=0?rt=nt/1e6:nt<=0&&(nt=rt/1e6),E(B+\".range[0]\",Math.log(rt)/Math.LN10),E(B+\".range[1]\",Math.log(nt)/Math.LN10)):(E(B+\".range[0]\",Math.pow(10,rt)),E(B+\".range[1]\",Math.pow(10,nt)))}else E(B+\".autorange\",!0);Array.isArray(l._subplots.polar)&&l._subplots.polar.length&&l[z.parts[0]]&&\"radialaxis\"===z.parts[1]&&delete l[z.parts[0]]._subplot.viewInitial[\"radialaxis.range\"],u.getComponentMethod(\"annotations\",\"convertCoords\")(t,V,I,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,V,I,E)}else E(B+\".autorange\",!0),E(B+\".range\",null);s(l,B+\"._inputRange\").set(null)}else if(R.match(M)){var it=s(l,O).get(),at=(I||{}).type;at&&\"-\"!==at||(at=\"linear\"),u.getComponentMethod(\"annotations\",\"convertCoords\")(t,it,at,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,it,at,E)}var ot=w.containerArrayMatch(O);if(ot){r=ot.array,n=ot.index;var st=ot.property,lt=G||{editType:\"calc\"};\"\"!==n&&\"\"===st&&(w.isAddVal(I)?S[O]=null:w.isRemoveVal(I)?S[O]=(s(a,r).get()||[])[n]:o.warn(\"unrecognized full object value\",e)),A.update(_,lt),m[r]||(m[r]={});var ct=m[r][n];ct||(ct=m[r][n]={}),ct[st]=I,delete e[O]}else\"reverse\"===R?(U.range?U.range.reverse():(E(B+\".autorange\",!0),U.range=[1,0]),V.autorange?_.calc=!0:_.plot=!0):(l._has(\"scatter-like\")&&l._has(\"regl\")&&\"dragmode\"===O&&(\"lasso\"===I||\"select\"===I)&&\"lasso\"!==H&&\"select\"!==H?_.plot=!0:l._has(\"gl2d\")?_.plot=!0:G?A.update(_,G):_.calc=!0,z.set(I))}}for(r in m){w.applyContainerArrayChanges(t,f(a,r),m[r],_,f)||(_.plot=!0)}var ut=l._axisConstraintGroups||[];for(C in L)for(n=0;n<ut.length;n++){var ht=ut[n];if(ht[C])for(var ft in _.calc=!0,ht)L[ft]||(d.getFromId(t,ft)._constraintShrinkable=!0)}return(K(t)||e.height||e.width)&&(_.plot=!0),(_.plot||_.calc)&&(_.layoutReplot=!0),{flags:_,rangesAltered:L,undoit:S,redoit:T,eventData:v}}function K(t){var e=t._fullLayout,r=e.width,n=e.height;return t.layout.autosize&&f.plotAutoSize(t,t.layout,e),e.width!==r||e.height!==n}function $(t,e,n,i){if(t=o.getGraphDiv(t),k.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);o.isPlainObject(e)||(e={}),o.isPlainObject(n)||(n={}),Object.keys(e).length&&(t.changed=!0),Object.keys(n).length&&(t.changed=!0);var a=k.coerceTraceIndices(t,i),s=V(t,o.extendFlat({},e),a),l=s.flags,u=J(t,o.extendFlat({},n)),h=u.flags;(l.calc||h.calc)&&(t.calcdata=void 0),l.clearAxisTypes&&k.clearAxisTypes(t,a,n);var p=[];h.layoutReplot?p.push(T.layoutReplot):l.fullReplot?p.push(r.plot):(p.push(f.previousPromises),G(t,h,u)||f.supplyDefaults(t),l.style&&p.push(T.doTraceStyle),(l.colorbars||h.colorbars)&&p.push(T.doColorBars),h.legend&&p.push(T.doLegend),h.layoutstyle&&p.push(T.layoutStyles),h.axrange&&Y(p,u.rangesAltered),h.ticks&&p.push(T.doTicksRelayout),h.modebar&&p.push(T.doModeBar),h.camera&&p.push(T.doCamera),p.push(C)),p.push(f.rehover,f.redrag),c.add(t,$,[t,s.undoit,u.undoit,s.traces],$,[t,s.redoit,u.redoit,s.traces]);var d=o.syncOrAsync(p,t);return d&&d.then||(d=Promise.resolve(t)),d.then(function(){return t.emit(\"plotly_update\",{data:s.eventData,layout:u.eventData}),t})}function Q(t){return function(e){e._fullLayout._guiEditing=!0;var r=t.apply(null,arguments);return e._fullLayout._guiEditing=!1,r}}var tt=[{pattern:/^hiddenlabels/,attr:\"legend.uirevision\"},{pattern:/^((x|y)axis\\d*)\\.((auto)?range|title\\.text)/},{pattern:/axis\\d*\\.showspikes$/,attr:\"modebar.uirevision\"},{pattern:/(hover|drag)mode$/,attr:\"modebar.uirevision\"},{pattern:/^(scene\\d*)\\.camera/},{pattern:/^(geo\\d*)\\.(projection|center)/},{pattern:/^(ternary\\d*\\.[abc]axis)\\.(min|title\\.text)$/},{pattern:/^(polar\\d*\\.radialaxis)\\.((auto)?range|angle|title\\.text)/},{pattern:/^(polar\\d*\\.angularaxis)\\.rotation/},{pattern:/^(mapbox\\d*)\\.(center|zoom|bearing|pitch)/},{pattern:/^legend\\.(x|y)$/,attr:\"editrevision\"},{pattern:/^(shapes|annotations)/,attr:\"editrevision\"},{pattern:/^title\\.text$/,attr:\"editrevision\"}],et=[{pattern:/^selectedpoints$/,attr:\"selectionrevision\"},{pattern:/(^|value\\.)visible$/,attr:\"legend.uirevision\"},{pattern:/^dimensions\\[\\d+\\]\\.constraintrange/},{pattern:/^node\\.(x|y|groups)/},{pattern:/^level$/},{pattern:/(^|value\\.)name$/},{pattern:/colorbar\\.title\\.text$/},{pattern:/colorbar\\.(x|y)$/,attr:\"editrevision\"}];function rt(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=t.match(n.pattern);if(i)return{head:i[1],attr:n.attr}}}function nt(t,e){var r=s(e,t).get();if(void 0!==r)return r;var n=t.split(\".\");for(n.pop();n.length>1;)if(n.pop(),void 0!==(r=s(e,n.join(\".\")+\".uirevision\").get()))return r;return e.uirevision}function it(t,e){for(var r=0;r<e.length;r++)if(e[r]._fullInput.uid===t)return r;return-1}function at(t,e,r){for(var n=0;n<e.length;n++)if(e[n].uid===t)return n;return!e[r]||e[r].uid?-1:r}function ot(t,e){var r=o.isPlainObject(t),n=Array.isArray(t);return r||n?(r&&o.isPlainObject(e)||n&&Array.isArray(e))&&JSON.stringify(t)===JSON.stringify(e):t===e}function st(t,e,r,n){var i,a,l,c=n.getValObject,u=n.flags,h=n.immutable,f=n.inArray,p=n.arrayIndex;function d(){var t=i.editType;f&&-1!==t.indexOf(\"arraydraw\")?o.pushUnique(u.arrays[f],p):(A.update(u,i),\"none\"!==t&&u.nChanges++,n.transition&&i.anim&&u.nChangesAnim++,(W.test(l)||X.test(l))&&(u.rangesAltered[r[0]]=1),Z.test(l)&&s(e,\"_inputDomain\").set(null),\"datarevision\"===a&&(u.newDataRevision=1))}function g(t){return\"data_array\"===t.valType||t.arrayOk}for(a in t){if(u.calc&&!n.transition)return;var v=t[a],m=e[a],y=r.concat(a);if(l=y.join(\".\"),\"_\"!==a.charAt(0)&&\"function\"!=typeof v&&v!==m){if((\"tick0\"===a||\"dtick\"===a)&&\"geo\"!==r[0]){var x=e.tickmode;if(\"auto\"===x||\"array\"===x||!x)continue}if((\"range\"!==a||!e.autorange)&&(\"zmin\"!==a&&\"zmax\"!==a||\"contourcarpet\"!==e.type)&&(i=c(y))&&(!i._compareAsJSON||JSON.stringify(v)!==JSON.stringify(m))){var b,_=i.valType,w=g(i),k=Array.isArray(v),T=Array.isArray(m);if(k&&T){var M=\"_input_\"+a,S=t[M],E=e[M];if(Array.isArray(S)&&S===E)continue}if(void 0===m)w&&k?u.calc=!0:d();else if(i._isLinkedToArray){var C=[],L=!1;f||(u.arrays[a]=C);var P=Math.min(v.length,m.length),O=Math.max(v.length,m.length);if(P!==O){if(\"arraydraw\"!==i.editType){d();continue}L=!0}for(b=0;b<P;b++)st(v[b],m[b],y.concat(b),o.extendFlat({inArray:a,arrayIndex:b},n));if(L)for(b=P;b<O;b++)C.push(b)}else!_&&o.isPlainObject(v)?st(v,m,y,n):w?k&&T?(h&&(u.calc=!0),(h||n.newDataRevision)&&d()):k!==T?u.calc=!0:d():k&&T&&v.length===m.length&&String(v)===String(m)||d()}}}for(a in e)if(!(a in t||\"_\"===a.charAt(0)||\"function\"==typeof e[a])){if(g(i=c(r.concat(a)))&&Array.isArray(e[a]))return void(u.calc=!0);d()}}function lt(t){var e=n.select(t),r=t._fullLayout;if(r._container=e.selectAll(\".plot-container\").data([0]),r._container.enter().insert(\"div\",\":first-child\").classed(\"plot-container\",!0).classed(\"plotly\",!0),r._paperdiv=r._container.selectAll(\".svg-container\").data([0]),r._paperdiv.enter().append(\"div\").classed(\"svg-container\",!0).style(\"position\",\"relative\"),r._glcontainer=r._paperdiv.selectAll(\".gl-container\").data([{}]),r._glcontainer.enter().append(\"div\").classed(\"gl-container\",!0),r._paperdiv.selectAll(\".main-svg\").remove(),r._paperdiv.select(\".modebar-container\").remove(),r._paper=r._paperdiv.insert(\"svg\",\":first-child\").classed(\"main-svg\",!0),r._toppaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),r._modebardiv=r._paperdiv.append(\"div\"),r._hoverpaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),!r._uid){var i={};n.selectAll(\"defs\").each(function(){this.id&&(i[this.id.split(\"-\")[1]]=1)}),r._uid=o.randstr(i)}r._paperdiv.selectAll(\".main-svg\").attr(y.svgAttrs),r._defs=r._paper.append(\"defs\").attr(\"id\",\"defs-\"+r._uid),r._clips=r._defs.append(\"g\").classed(\"clips\",!0),r._topdefs=r._toppaper.append(\"defs\").attr(\"id\",\"topdefs-\"+r._uid),r._topclips=r._topdefs.append(\"g\").classed(\"clips\",!0),r._bgLayer=r._paper.append(\"g\").classed(\"bglayer\",!0),r._draggers=r._paper.append(\"g\").classed(\"draglayer\",!0);var a=r._paper.append(\"g\").classed(\"layer-below\",!0);r._imageLowerLayer=a.append(\"g\").classed(\"imagelayer\",!0),r._shapeLowerLayer=a.append(\"g\").classed(\"shapelayer\",!0),r._cartesianlayer=r._paper.append(\"g\").classed(\"cartesianlayer\",!0),r._polarlayer=r._paper.append(\"g\").classed(\"polarlayer\",!0),r._ternarylayer=r._paper.append(\"g\").classed(\"ternarylayer\",!0),r._geolayer=r._paper.append(\"g\").classed(\"geolayer\",!0),r._funnelarealayer=r._paper.append(\"g\").classed(\"funnelarealayer\",!0),r._pielayer=r._paper.append(\"g\").classed(\"pielayer\",!0),r._sunburstlayer=r._paper.append(\"g\").classed(\"sunburstlayer\",!0),r._indicatorlayer=r._toppaper.append(\"g\").classed(\"indicatorlayer\",!0),r._glimages=r._paper.append(\"g\").classed(\"glimages\",!0);var s=r._toppaper.append(\"g\").classed(\"layer-above\",!0);r._imageUpperLayer=s.append(\"g\").classed(\"imagelayer\",!0),r._shapeUpperLayer=s.append(\"g\").classed(\"shapelayer\",!0),r._infolayer=r._toppaper.append(\"g\").classed(\"infolayer\",!0),r._menulayer=r._toppaper.append(\"g\").classed(\"menulayer\",!0),r._zoomlayer=r._toppaper.append(\"g\").classed(\"zoomlayer\",!0),r._hoverlayer=r._hoverpaper.append(\"g\").classed(\"hoverlayer\",!0),r._modebardiv.classed(\"modebar-container\",!0).style(\"position\",\"absolute\").style(\"top\",\"0px\").style(\"right\",\"0px\"),t.emit(\"plotly_framework\")}r.animate=function(t,e,r){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before animating it. For more details, see https://plot.ly/javascript/animations/\");var n=t._transitionData;n._frameQueue||(n._frameQueue=[]);var i=(r=f.supplyAnimationDefaults(r)).transition,a=r.frame;function s(t){return Array.isArray(i)?t>=i.length?i[0]:i[t]:i}function l(t){return Array.isArray(a)?t>=a.length?a[0]:a[t]:a}function c(t,e){var r=0;return function(){if(t&&++r===e)return t()}}return void 0===n._frameWaitingCnt&&(n._frameWaitingCnt=0),new Promise(function(a,u){function h(){n._currentFrame&&n._currentFrame.onComplete&&n._currentFrame.onComplete();var e=n._currentFrame=n._frameQueue.shift();if(e){var r=e.name?e.name.toString():null;t._fullLayout._currentFrame=r,n._lastFrameAt=Date.now(),n._timeToNext=e.frameOpts.duration,f.transition(t,e.frame.data,e.frame.layout,k.coerceTraceIndices(t,e.frame.traces),e.frameOpts,e.transitionOpts).then(function(){e.onComplete&&e.onComplete()}),t.emit(\"plotly_animatingframe\",{name:r,frame:e.frame,animation:{frame:e.frameOpts,transition:e.transitionOpts}})}else t.emit(\"plotly_animated\"),window.cancelAnimationFrame(n._animationRaf),n._animationRaf=null}function p(){t.emit(\"plotly_animating\"),n._lastFrameAt=-1/0,n._timeToNext=0,n._runningTransitions=0,n._currentFrame=null;var e=function(){n._animationRaf=window.requestAnimationFrame(e),Date.now()-n._lastFrameAt>n._timeToNext&&h()};e()}var d,g,v=0;function m(t){return Array.isArray(i)?v>=i.length?t.transitionOpts=i[v]:t.transitionOpts=i[0]:t.transitionOpts=i,v++,t}var y=[],x=null==e,b=Array.isArray(e);if(x||b||!o.isPlainObject(e)){if(x||-1!==[\"string\",\"number\"].indexOf(typeof e))for(d=0;d<n._frames.length;d++)(g=n._frames[d])&&(x||String(g.group)===String(e))&&y.push({type:\"byname\",name:String(g.name),data:m({name:g.name})});else if(b)for(d=0;d<e.length;d++){var _=e[d];-1!==[\"number\",\"string\"].indexOf(typeof _)?(_=String(_),y.push({type:\"byname\",name:_,data:m({name:_})})):o.isPlainObject(_)&&y.push({type:\"object\",data:m(o.extendFlat({},_))})}}else y.push({type:\"object\",data:m(o.extendFlat({},e))});for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&!n._frameHash[g.data.name])return o.warn('animate failure: frame not found: \"'+g.data.name+'\"'),void u();-1!==[\"next\",\"immediate\"].indexOf(r.mode)&&function(){if(0!==n._frameQueue.length){for(;n._frameQueue.length;){var e=n._frameQueue.pop();e.onInterrupt&&e.onInterrupt()}t.emit(\"plotly_animationinterrupted\",[])}}(),\"reverse\"===r.direction&&y.reverse();var w=t._fullLayout._currentFrame;if(w&&r.fromcurrent){var T=-1;for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&g.name===w){T=d;break}if(T>0&&T<y.length-1){var A=[];for(d=0;d<y.length;d++)g=y[d],(\"byname\"!==y[d].type||d>T)&&A.push(g);y=A}}y.length>0?function(e){if(0!==e.length){for(var i=0;i<e.length;i++){var o;o=\"byname\"===e[i].type?f.computeFrame(t,e[i].name):e[i].data;var h=l(i),d=s(i);d.duration=Math.min(d.duration,h.duration);var g={frame:o,name:e[i].name,frameOpts:h,transitionOpts:d};i===e.length-1&&(g.onComplete=c(a,2),g.onInterrupt=u),n._frameQueue.push(g)}\"immediate\"===r.mode&&(n._lastFrameAt=-1/0),n._animationRaf||p()}}(y):(t.emit(\"plotly_animated\"),a())})},r.addFrames=function(t,e,r){if(t=o.getGraphDiv(t),null==e)return Promise.resolve();if(!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before adding frames. For more details, see https://plot.ly/javascript/animations/\");var n,i,a,s,l=t._transitionData._frames,u=t._transitionData._frameHash;if(!Array.isArray(e))throw new Error(\"addFrames failure: frameList must be an Array of frame definitions\"+e);var h=l.length+2*e.length,p=[],d={};for(n=e.length-1;n>=0;n--)if(o.isPlainObject(e[n])){var g=e[n].name,v=(u[g]||d[g]||{}).name,m=e[n].name,y=u[v]||d[v];v&&m&&\"number\"==typeof m&&y&&S<E&&(S++,o.warn('addFrames: overwriting frame \"'+(u[v]||d[v]).name+'\" with a frame whose name of type \"number\" also equates to \"'+v+'\". This is valid but may potentially lead to unexpected behavior since all plotly.js frame names are stored internally as strings.'),S===E&&o.warn(\"addFrames: This API call has yielded too many of these warnings. For the rest of this call, further warnings about numeric frame names will be suppressed.\")),d[g]={name:g},p.push({frame:f.supplyFrameDefaults(e[n]),index:r&&void 0!==r[n]&&null!==r[n]?r[n]:h+n})}p.sort(function(t,e){return t.index>e.index?-1:t.index<e.index?1:0});var x=[],b=[],_=l.length;for(n=p.length-1;n>=0;n--){if(\"number\"==typeof(i=p[n].frame).name&&o.warn(\"Warning: addFrames accepts frames with numeric names, but the numbers areimplicitly cast to strings\"),!i.name)for(;u[i.name=\"frame \"+t._transitionData._counter++];);if(u[i.name]){for(a=0;a<l.length&&(l[a]||{}).name!==i.name;a++);x.push({type:\"replace\",index:a,value:i}),b.unshift({type:\"replace\",index:a,value:l[a]})}else s=Math.max(0,Math.min(p[n].index,_)),x.push({type:\"insert\",index:s,value:i}),b.unshift({type:\"delete\",index:s}),_++}var w=f.modifyFrames,k=f.modifyFrames,T=[t,b],A=[t,x];return c&&c.add(t,w,T,k,A),f.modifyFrames(t,x)},r.deleteFrames=function(t,e){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);var r,n,i=t._transitionData._frames,a=[],s=[];if(!e)for(e=[],r=0;r<i.length;r++)e.push(r);for((e=e.slice()).sort(),r=e.length-1;r>=0;r--)n=e[r],a.push({type:\"delete\",index:n}),s.unshift({type:\"insert\",index:n,value:i[n]});var l=f.modifyFrames,u=f.modifyFrames,h=[t,s],p=[t,a];return c&&c.add(t,l,h,u,p),f.modifyFrames(t,a)},r.addTraces=function t(e,n,i){e=o.getGraphDiv(e);var a,s,l=[],u=r.deleteTraces,h=t,f=[e,l],p=[e,n];for(function(t,e,r){var n,i;if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"traces must be defined.\");for(Array.isArray(e)||(e=[e]),n=0;n<e.length;n++)if(\"object\"!=typeof(i=e[n])||Array.isArray(i)||null===i)throw new Error(\"all values in traces array must be non-array objects\");if(\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&r.length!==e.length)throw new Error(\"if indices is specified, traces.length must equal indices.length\")}(e,n,i),Array.isArray(n)||(n=[n]),n=n.map(function(t){return o.extendFlat({},t)}),k.cleanData(n),a=0;a<n.length;a++)e.data.push(n[a]);for(a=0;a<n.length;a++)l.push(-n.length+a);if(\"undefined\"==typeof i)return s=r.redraw(e),c.add(e,u,f,h,p),s;Array.isArray(i)||(i=[i]);try{D(e,l,i)}catch(t){throw e.data.splice(e.data.length-n.length,n.length),t}return c.startSequence(e),c.add(e,u,f,h,p),s=r.moveTraces(e,l,i),c.stopSequence(e),s},r.deleteTraces=function t(e,n){e=o.getGraphDiv(e);var i,a,s=[],l=r.addTraces,u=t,h=[e,s,n],f=[e,n];if(\"undefined\"==typeof n)throw new Error(\"indices must be an integer or array of integers.\");for(Array.isArray(n)||(n=[n]),I(e,n,\"indices\"),(n=z(n,e.data.length-1)).sort(o.sorterDes),i=0;i<n.length;i+=1)a=e.data.splice(n[i],1)[0],s.push(a);var p=r.redraw(e);return c.add(e,l,h,u,f),p},r.extendTraces=function t(e,n,i,a){var s=R(e=o.getGraphDiv(e),n,i,a,function(t,e,r){var n,i;if(o.isTypedArray(t))if(r<0){var a=new t.constructor(0),s=F(t,e);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(l)),i.set(t),i.set(e.subarray(0,l),t.length)}else{var c=r-e.length,u=t.length-c;n.set(t.subarray(u)),n.set(e,c),i.set(t.subarray(0,u))}else n=t.concat(e),i=r>=0&&r<n.length?n.splice(0,n.length-r):[];return[n,i]}),l=r.redraw(e),u=[e,s.update,i,s.maxPoints];return c.add(e,r.prependTraces,u,t,arguments),l},r.moveTraces=function t(e,n,i){var a,s=[],l=[],u=t,h=t,f=[e=o.getGraphDiv(e),i,n],p=[e,n,i];if(D(e,n,i),n=Array.isArray(n)?n:[n],\"undefined\"==typeof i)for(i=[],a=0;a<n.length;a++)i.push(-n.length+a);for(i=Array.isArray(i)?i:[i],n=z(n,e.data.length-1),i=z(i,e.data.length-1),a=0;a<e.data.length;a++)-1===n.indexOf(a)&&s.push(e.data[a]);for(a=0;a<n.length;a++)l.push({newIndex:i[a],trace:e.data[n[a]]});for(l.sort(function(t,e){return t.newIndex-e.newIndex}),a=0;a<l.length;a+=1)s.splice(l[a].newIndex,0,l[a].trace);e.data=s;var d=r.redraw(e);return c.add(e,u,f,h,p),d},r.prependTraces=function t(e,n,i,a){var s=R(e=o.getGraphDiv(e),n,i,a,function(t,e,r){var n,i;if(o.isTypedArray(t))if(r<=0){var a=new t.constructor(0),s=F(e,t);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(0,l)),i.set(e.subarray(l)),i.set(t,l)}else{var c=r-e.length;n.set(e),n.set(t.subarray(0,c),e.length),i.set(t.subarray(c))}else n=e.concat(t),i=r>=0&&r<n.length?n.splice(r,n.length):[];return[n,i]}),l=r.redraw(e),u=[e,s.update,i,s.maxPoints];return c.add(e,r.extendTraces,u,t,arguments),l},r.newPlot=function(t,e,n,i){return t=o.getGraphDiv(t),f.cleanPlot([],{},t._fullData||[],t._fullLayout||{}),f.purge(t),r.plot(t,e,n,i)},r.plot=function(t,e,i,a){var s;if(t=o.getGraphDiv(t),l.init(t),o.isPlainObject(e)){var c=e;e=c.data,i=c.layout,a=c.config,s=c.frames}if(!1===l.triggerHandler(t,\"plotly_beforeplot\",[e,i,a]))return Promise.reject();e||i||o.isPlotDiv(t)||o.warn(\"Calling Plotly.plot as if redrawing but this container doesn't yet have a plot.\",t),O(t,a),i||(i={}),n.select(t).classed(\"js-plotly-plot\",!0),g.makeTester(),Array.isArray(t._promises)||(t._promises=[]);var h=0===(t.data||[]).length&&Array.isArray(e);Array.isArray(e)&&(k.cleanData(e),h?t.data=e:t.data.push.apply(t.data,e),t.empty=!1),t.layout&&!h||(t.layout=k.cleanLayout(i)),f.supplyDefaults(t);var v=t._fullLayout,y=v._has(\"cartesian\");if(!v._has(\"polar\")&&e&&e[0]&&e[0].r)return o.log(\"Legacy polar charts are deprecated!\"),function(t,e,r){var i=n.select(t).selectAll(\".plot-container\").data([0]);i.enter().insert(\"div\",\":first-child\").classed(\"plot-container plotly\",!0);var a=i.selectAll(\".svg-container\").data([0]);a.enter().append(\"div\").classed(\"svg-container\",!0).style(\"position\",\"relative\"),a.html(\"\"),e&&(t.data=e),r&&(t.layout=r),p.manager.fillLayout(t),a.style({width:t._fullLayout.width+\"px\",height:t._fullLayout.height+\"px\"}),t.framework=p.manager.framework(t),t.framework({data:t.data,layout:t.layout},a.node()),t.framework.setUndoPoint();var s=t.framework.svg(),l=1,c=t._fullLayout.title?t._fullLayout.title.text:\"\";\"\"!==c&&c||(l=0);var u=function(){this.call(x.convertToTspans,t)},h=s.select(\".title-group text\").call(u);if(t._context.edits.titleText){var d=o._(t,\"Click to enter Plot title\");c&&c!==d||(l=.2,h.attr({\"data-unformatted\":d}).text(d).style({opacity:l}).on(\"mouseover.opacity\",function(){n.select(this).transition().duration(100).style(\"opacity\",1)}).on(\"mouseout.opacity\",function(){n.select(this).transition().duration(1e3).style(\"opacity\",0)}));var g=function(){this.call(x.makeEditable,{gd:t}).on(\"edit\",function(e){t.framework({layout:{title:{text:e}}}),this.text(e).call(u),this.call(g)}).on(\"cancel\",function(){var t=this.attr(\"data-unformatted\");this.text(t).call(u)})};h.call(g)}return t._context.setBackground(t,t._fullLayout.paper_bgcolor),f.addLinks(t),Promise.resolve()}(t,e,i);v._replotting=!0,h&&lt(t),t.framework!==lt&&(t.framework=lt,lt(t)),g.initGradients(t),h&&d.saveShowSpikeInitial(t);var b=!t.calcdata||t.calcdata.length!==(t._fullData||[]).length;b&&f.doCalcdata(t);for(var _=0;_<t.calcdata.length;_++)t.calcdata[_][0].trace=t._fullData[_];t._context.responsive?t._responsiveChartHandler||(t._responsiveChartHandler=function(){o.isHidden(t)||f.resize(t)},window.addEventListener(\"resize\",t._responsiveChartHandler)):o.clearResponsive(t);var w=o.extendFlat({},v._size),A=0;function M(){return f.clearAutoMarginIds(t),T.drawMarginPushers(t),d.allowAutoMargin(t),f.doAutoMargin(t),f.previousPromises(t)}function S(){t._transitioning||(T.doAutoRangeAndConstraints(t),h&&d.saveRangeInitial(t),u.getComponentMethod(\"rangeslider\",\"calcAutorange\")(t))}var E=[f.previousPromises,function(){if(s)return r.addFrames(t,s)},function e(){for(var r=v._basePlotModules,n=0;n<r.length;n++)r[n].drawFramework&&r[n].drawFramework(t);if(!v._glcanvas&&v._has(\"gl\")&&(v._glcanvas=v._glcontainer.selectAll(\".gl-canvas\").data([{key:\"contextLayer\",context:!0,pick:!1},{key:\"focusLayer\",context:!1,pick:!1},{key:\"pickLayer\",context:!1,pick:!0}],function(t){return t.key}),v._glcanvas.enter().append(\"canvas\").attr(\"class\",function(t){return\"gl-canvas gl-canvas-\"+t.key.replace(\"Layer\",\"\")}).style({position:\"absolute\",top:0,left:0,overflow:\"visible\",\"pointer-events\":\"none\"})),v._glcanvas){v._glcanvas.attr(\"width\",v.width).attr(\"height\",v.height);var i=v._glcanvas.data()[0].regl;if(i&&(Math.floor(v.width)!==i._gl.drawingBufferWidth||Math.floor(v.height)!==i._gl.drawingBufferHeight)){var a=\"WebGL context buffer and canvas dimensions do not match due to browser/WebGL bug.\";if(!A)return o.log(a+\" Clearing graph and plotting again.\"),f.cleanPlot([],{},t._fullData,v),f.supplyDefaults(t),v=t._fullLayout,f.doCalcdata(t),A++,e();o.error(a)}}return\"h\"===v.modebar.orientation?v._modebardiv.style(\"height\",null).style(\"width\",\"100%\"):v._modebardiv.style(\"width\",null).style(\"height\",v.height+\"px\"),f.previousPromises(t)},M,function(){if(f.didMarginChange(w,v._size))return o.syncOrAsync([M,T.layoutStyles],t)}];y&&E.push(function(){if(b)return o.syncOrAsync([u.getComponentMethod(\"shapes\",\"calcAutorange\"),u.getComponentMethod(\"annotations\",\"calcAutorange\"),S],t);S()}),E.push(T.layoutStyles),y&&E.push(function(){return d.draw(t,h?\"\":\"redraw\")}),E.push(T.drawData,T.finalDraw,m,f.addLinks,f.rehover,f.redrag,f.doAutoMargin,f.previousPromises);var L=o.syncOrAsync(E,t);return L&&L.then||(L=Promise.resolve()),L.then(function(){return C(t),t})},r.purge=function(t){var e=(t=o.getGraphDiv(t))._fullLayout||{},r=t._fullData||[];return f.cleanPlot([],{},r,e),f.purge(t),l.purge(t),e._container&&e._container.remove(),delete t._context,t},r.react=function(t,e,n,i){var a,l,c=(t=o.getGraphDiv(t))._fullData,p=t._fullLayout;if(o.isPlotDiv(t)&&c&&p){if(o.isPlainObject(e)){var d=e;e=d.data,n=d.layout,i=d.config,a=d.frames}var g=!1;if(i){var v=o.extendDeep({},t._context);t._context=void 0,O(t,i),g=function t(e,r){var n;for(n in e)if(\"_\"!==n.charAt(0)){var i=e[n],a=r[n];if(i!==a)if(o.isPlainObject(i)&&o.isPlainObject(a)){if(t(i,a))return!0}else{if(!Array.isArray(i)||!Array.isArray(a))return!0;if(i.length!==a.length)return!0;for(var s=0;s<i.length;s++)if(i[s]!==a[s]){if(!o.isPlainObject(i[s])||!o.isPlainObject(a[s]))return!0;if(t(i[s],a[s]))return!0}}}}(v,t._context)}t.data=e||[],k.cleanData(t.data),t.layout=n||{},k.cleanLayout(t.layout),function(t,e,r,n){var i,a,l,c,u,h,f,p,d=n._preGUI,g=[],v={};for(i in d){if(u=rt(i,tt)){if(a=u.attr||u.head+\".uirevision\",(c=(l=s(n,a).get())&&nt(a,e))&&c===l&&(null===(h=d[i])&&(h=void 0),ot(p=(f=s(e,i)).get(),h))){void 0===p&&\"autorange\"===i.substr(i.length-9)&&g.push(i.substr(0,i.length-10)),f.set(N(s(n,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i);delete d[i],\"range[\"===i.substr(i.length-8,6)&&(v[i.substr(0,i.length-9)]=1)}for(var m=0;m<g.length;m++){var y=g[m];if(v[y]){var x=s(e,y).get();x&&delete x.autorange}}var b=n._tracePreGUI;for(var _ in b){var w,k=b[_],T=null;for(i in k){if(!T){var A=it(_,r);if(A<0){delete b[_];break}var M=at(_,t,(w=r[A]._fullInput).index);if(M<0){delete b[_];break}T=t[M]}if(u=rt(i,et)){if(u.attr?c=(l=s(n,u.attr).get())&&nt(u.attr,e):(l=w.uirevision,void 0===(c=T.uirevision)&&(c=e.uirevision)),c&&c===l&&(null===(h=k[i])&&(h=void 0),ot(p=(f=s(T,i)).get(),h))){f.set(N(s(w,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i+\" in trace uid \"+_);delete k[i]}}}(t.data,t.layout,c,p),f.supplyDefaults(t,{skipUpdateCalc:!0});var m=t._fullData,y=t._fullLayout,x=void 0===y.datarevision,b=y.transition,_=function(t,e,r,n,i){var a=A.layoutFlags();return a.arrays={},a.rangesAltered={},a.nChanges=0,a.nChangesAnim=0,st(e,r,[],{getValObject:function(t){return h.getLayoutValObject(r,t)},flags:a,immutable:n,transition:i,gd:t}),(a.plot||a.calc)&&(a.layoutReplot=!0),i&&a.nChanges&&a.nChangesAnim&&(a.anim=a.nChanges===a.nChangesAnim?\"all\":\"some\"),a}(t,p,y,x,b),w=_.newDataRevision,M=function(t,e,r,n,i,a){var o=e.length===r.length;if(!i&&!o)return{fullReplot:!0,calc:!0};var s,l,c=A.traceFlags();c.arrays={},c.nChanges=0,c.nChangesAnim=0;var u={getValObject:function(t){var e=h.getTraceValObject(l,t);return!l._module.animatable&&e.anim&&(e.anim=!1),e},flags:c,immutable:n,transition:i,newDataRevision:a,gd:t},p={};for(s=0;s<e.length;s++)if(r[s]){if(l=r[s]._fullInput,f.hasMakesDataTransform(l)&&(l=r[s]),p[l.uid])continue;p[l.uid]=1,st(e[s]._fullInput,l,[],u)}return(c.calc||c.plot)&&(c.fullReplot=!0),i&&c.nChanges&&c.nChangesAnim&&(c.anim=c.nChanges===c.nChangesAnim&&o?\"all\":\"some\"),c}(t,c,m,x,b,w);K(t)&&(_.layoutReplot=!0),M.calc||_.calc?t.calcdata=void 0:f.supplyDefaultsUpdateCalc(t.calcdata,m);var S=[];if(a&&(t._transitionData={},f.createTransitionData(t),S.push(function(){return r.addFrames(t,a)})),y.transition&&!g&&(M.anim||_.anim))f.doCalcdata(t),T.doAutoRangeAndConstraints(t),S.push(function(){return f.transitionFromReact(t,M,_,p)});else if(M.fullReplot||_.layoutReplot||g)t._fullLayout._skipDefaults=!0,S.push(r.plot);else{for(var E in _.arrays){var L=_.arrays[E];if(L.length){var P=u.getComponentMethod(E,\"drawOne\");if(P!==o.noop)for(var z=0;z<L.length;z++)P(t,L[z]);else{var I=u.getComponentMethod(E,\"draw\");if(I===o.noop)throw new Error(\"cannot draw components: \"+E);I(t)}}}S.push(f.previousPromises),M.style&&S.push(T.doTraceStyle),(M.colorbars||_.colorbars)&&S.push(T.doColorBars),_.legend&&S.push(T.doLegend),_.layoutstyle&&S.push(T.layoutStyles),_.axrange&&Y(S),_.ticks&&S.push(T.doTicksRelayout),_.modebar&&S.push(T.doModeBar),_.camera&&S.push(T.doCamera),S.push(C)}S.push(f.rehover,f.redrag),(l=o.syncOrAsync(S,t))&&l.then||(l=Promise.resolve(t))}else l=r.newPlot(t,e,n,i);return l.then(function(){return t.emit(\"plotly_react\",{data:e,layout:n}),t})},r.redraw=function(t){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);return k.cleanData(t.data),k.cleanLayout(t.layout),t.calcdata=void 0,r.plot(t).then(function(){return t.emit(\"plotly_redraw\"),t})},r.relayout=H,r.restyle=B,r.setPlotConfig=function(t){return o.extendFlat(_,t)},r.update=$,r._guiRelayout=Q(H),r._guiRestyle=Q(B),r._guiUpdate=Q($),r._storeDirectGUIEdit=function(t,e,r){for(var n in r)U(n,s(t,n).get(),r[n],e)}},{\"../components/color\":593,\"../components/drawing\":614,\"../constants/xmlns_namespaces\":696,\"../lib\":719,\"../lib/events\":709,\"../lib/queue\":734,\"../lib/svg_text_utils\":743,\"../plots/cartesian/axes\":767,\"../plots/cartesian/constants\":773,\"../plots/cartesian/graph_interact\":776,\"../plots/cartesian/select\":784,\"../plots/plots\":828,\"../plots/polar/legacy\":836,\"../registry\":847,\"./edit_types\":750,\"./helpers\":751,\"./manage_arrays\":753,\"./plot_config\":755,\"./plot_schema\":756,\"./subroutines\":758,d3:163,\"fast-isnumeric\":225,\"has-hover\":410}],755:[function(t,e,r){\"use strict\";var n={staticPlot:{valType:\"boolean\",dflt:!1},plotlyServerURL:{valType:\"string\",dflt:\"https://plot.ly\"},editable:{valType:\"boolean\",dflt:!1},edits:{annotationPosition:{valType:\"boolean\",dflt:!1},annotationTail:{valType:\"boolean\",dflt:!1},annotationText:{valType:\"boolean\",dflt:!1},axisTitleText:{valType:\"boolean\",dflt:!1},colorbarPosition:{valType:\"boolean\",dflt:!1},colorbarTitleText:{valType:\"boolean\",dflt:!1},legendPosition:{valType:\"boolean\",dflt:!1},legendText:{valType:\"boolean\",dflt:!1},shapePosition:{valType:\"boolean\",dflt:!1},titleText:{valType:\"boolean\",dflt:!1}},autosizable:{valType:\"boolean\",dflt:!1},responsive:{valType:\"boolean\",dflt:!1},fillFrame:{valType:\"boolean\",dflt:!1},frameMargins:{valType:\"number\",dflt:0,min:0,max:.5},scrollZoom:{valType:\"flaglist\",flags:[\"cartesian\",\"gl3d\",\"geo\",\"mapbox\"],extras:[!0,!1],dflt:\"gl3d+geo+mapbox\"},doubleClick:{valType:\"enumerated\",values:[!1,\"reset\",\"autosize\",\"reset+autosize\"],dflt:\"reset+autosize\"},doubleClickDelay:{valType:\"number\",dflt:300,min:0},showAxisDragHandles:{valType:\"boolean\",dflt:!0},showAxisRangeEntryBoxes:{valType:\"boolean\",dflt:!0},showTips:{valType:\"boolean\",dflt:!0},showLink:{valType:\"boolean\",dflt:!1},linkText:{valType:\"string\",dflt:\"Edit chart\",noBlank:!0},sendData:{valType:\"boolean\",dflt:!0},showSources:{valType:\"any\",dflt:!1},displayModeBar:{valType:\"enumerated\",values:[\"hover\",!0,!1],dflt:\"hover\"},showSendToCloud:{valType:\"boolean\",dflt:!1},showEditInChartStudio:{valType:\"boolean\",dflt:!1},modeBarButtonsToRemove:{valType:\"any\",dflt:[]},modeBarButtonsToAdd:{valType:\"any\",dflt:[]},modeBarButtons:{valType:\"any\",dflt:!1},toImageButtonOptions:{valType:\"any\",dflt:{}},displaylogo:{valType:\"boolean\",dflt:!0},watermark:{valType:\"boolean\",dflt:!1},plotGlPixelRatio:{valType:\"number\",dflt:2,min:1,max:4},setBackground:{valType:\"any\",dflt:\"transparent\"},topojsonURL:{valType:\"string\",noBlank:!0,dflt:\"https://cdn.plot.ly/\"},mapboxAccessToken:{valType:\"string\",dflt:null},logging:{valType:\"boolean\",dflt:1},queueLength:{valType:\"integer\",min:0,dflt:0},globalTransforms:{valType:\"any\",dflt:[]},locale:{valType:\"string\",dflt:\"en-US\"},locales:{valType:\"any\",dflt:{}}},i={};!function t(e,r){for(var n in e){var i=e[n];i.valType?r[n]=i.dflt:(r[n]||(r[n]={}),t(i,r[n]))}}(n,i),e.exports={configAttributes:n,dfltConfig:i}},{}],756:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=t(\"../plots/attributes\"),o=t(\"../plots/layout_attributes\"),s=t(\"../plots/frame_attributes\"),l=t(\"../plots/animation_attributes\"),c=t(\"./plot_config\").configAttributes,u=t(\"../plots/polar/legacy/area_attributes\"),h=t(\"../plots/polar/legacy/axis_attributes\"),f=t(\"./edit_types\"),p=i.extendFlat,d=i.extendDeepAll,g=i.isPlainObject,v=i.isArrayOrTypedArray,m=i.nestedProperty,y=i.valObjectMeta,x=\"_isSubplotObj\",b=\"_isLinkedToArray\",_=[x,b,\"_arrayAttrRegexps\",\"_deprecated\"];function w(t,e,r){if(!t)return!1;if(t._isLinkedToArray)if(k(e[r]))r++;else if(r<e.length)return!1;for(;r<e.length;r++){var n=t[e[r]];if(!g(n))break;if(t=n,r===e.length-1)break;if(t._isLinkedToArray){if(!k(e[++r]))return!1}else if(\"info_array\"===t.valType){var i=e[++r];if(!k(i))return!1;var a=t.items;if(Array.isArray(a)){if(i>=a.length)return!1;if(2===t.dimensions){if(r++,e.length===r)return t;var o=e[r];if(!k(o))return!1;t=a[i][o]}else t=a[i]}else t=a}}return t}function k(t){return t===Math.round(t)&&t>=0}function T(t){return function(t){r.crawl(t,function(t,e,n){r.isValObject(t)?\"data_array\"===t.valType?(t.role=\"data\",n[e+\"src\"]={valType:\"string\",editType:\"none\"}):!0===t.arrayOk&&(n[e+\"src\"]={valType:\"string\",editType:\"none\"}):g(t)&&(t.role=\"object\")})}(t),function(t){r.crawl(t,function(t,e,r){if(!t)return;var n=t[b];if(!n)return;delete t[b],r[e]={items:{}},r[e].items[n]=t,r[e].role=\"object\"})}(t),function(t){!function t(e){for(var r in e)if(g(e[r]))t(e[r]);else if(Array.isArray(e[r]))for(var n=0;n<e[r].length;n++)t(e[r][n]);else e[r]instanceof RegExp&&(e[r]=e[r].toString())}(t)}(t),t}function A(t,e,r){var n=m(t,r),i=d({},e.layoutAttributes);i[x]=!0,n.set(i)}function M(t,e,r){var n=m(t,r);n.set(d(n.get()||{},e))}r.IS_SUBPLOT_OBJ=x,r.IS_LINKED_TO_ARRAY=b,r.DEPRECATED=\"_deprecated\",r.UNDERSCORE_ATTRS=_,r.get=function(){var t={};n.allTypes.concat(\"area\").forEach(function(e){t[e]=function(t){var e,i;\"area\"===t?(e={attributes:u},i={}):(e=n.modules[t]._module,i=e.basePlotModule);var o={type:null},s=d({},a),l=d({},e.attributes);r.crawl(l,function(t,e,r,n,i){m(s,i).set(void 0),void 0===t&&m(l,i).set(void 0)}),d(o,s),n.traceIs(t,\"noOpacity\")&&delete o.opacity;n.traceIs(t,\"showLegend\")||(delete o.showlegend,delete o.legendgroup);n.traceIs(t,\"noHover\")&&(delete o.hoverinfo,delete o.hoverlabel);e.selectPoints||delete o.selectedpoints;d(o,l),i.attributes&&d(o,i.attributes);o.type=t;var c={meta:e.meta||{},categories:e.categories||{},animatable:Boolean(e.animatable),type:t,attributes:T(o)};if(e.layoutAttributes){var h={};d(h,e.layoutAttributes),c.layoutAttributes=T(h)}e.animatable||r.crawl(c,function(t){r.isValObject(t)&&\"anim\"in t&&delete t.anim});return c}(e)});var e,i={};return Object.keys(n.transformsRegistry).forEach(function(t){i[t]=function(t){var e=n.transformsRegistry[t],r=d({},e.attributes);return Object.keys(n.componentsRegistry).forEach(function(e){var i=n.componentsRegistry[e];i.schema&&i.schema.transforms&&i.schema.transforms[t]&&Object.keys(i.schema.transforms[t]).forEach(function(e){M(r,i.schema.transforms[t][e],e)})}),{attributes:T(r)}}(t)}),{defs:{valObjects:y,metaKeys:_.concat([\"description\",\"role\",\"editType\",\"impliedEdits\"]),editType:{traces:f.traces,layout:f.layout},impliedEdits:{}},traces:t,layout:function(){var t,e,r={};for(t in d(r,o),n.subplotsRegistry)if((e=n.subplotsRegistry[t]).layoutAttributes)if(Array.isArray(e.attr))for(var i=0;i<e.attr.length;i++)A(r,e,e.attr[i]);else{var a=\"subplot\"===e.attr?e.name:e.attr;A(r,e,a)}for(t in r=function(t){return p(t,{radialaxis:h.radialaxis,angularaxis:h.angularaxis}),p(t,h.layout),t}(r),n.componentsRegistry){var s=(e=n.componentsRegistry[t]).schema;if(s&&(s.subplots||s.layout)){var l=s.subplots;if(l&&l.xaxis&&!l.yaxis)for(var c in l.xaxis)delete r.yaxis[c]}else\"colorscale\"===e.name?d(r,e.layoutAttributes):e.layoutAttributes&&M(r,e.layoutAttributes,e.name)}return{layoutAttributes:T(r)}}(),transforms:i,frames:(e={frames:d({},s)},T(e),e.frames),animation:T(l),config:T(c)}},r.crawl=function(t,e,n,i){var a=n||0;i=i||\"\",Object.keys(t).forEach(function(n){var o=t[n];if(-1===_.indexOf(n)){var s=(i?i+\".\":\"\")+n;e(o,n,t,a,s),r.isValObject(o)||g(o)&&\"impliedEdits\"!==n&&r.crawl(o,e,a+1,s)}})},r.isValObject=function(t){return t&&void 0!==t.valType},r.findArrayAttributes=function(t){var e,n,i=[],o=[],s=[];function l(t,r,a,l){o=o.slice(0,l).concat([r]),s=s.slice(0,l).concat([t&&t._isLinkedToArray]),t&&(\"data_array\"===t.valType||!0===t.arrayOk)&&!(\"colorbar\"===o[l-1]&&(\"ticktext\"===r||\"tickvals\"===r))&&function t(e,r,a){var l=e[o[r]];var c=a+o[r];if(r===o.length-1)v(l)&&i.push(n+c);else if(s[r]){if(Array.isArray(l))for(var u=0;u<l.length;u++)g(l[u])&&t(l[u],r+1,c+\"[\"+u+\"].\")}else g(l)&&t(l,r+1,c+\".\")}(e,0,\"\")}e=t,n=\"\",r.crawl(a,l),t._module&&t._module.attributes&&r.crawl(t._module.attributes,l);var c=t.transforms;if(c)for(var u=0;u<c.length;u++){var h=c[u],f=h._module;f&&(n=\"transforms[\"+u+\"].\",e=h,r.crawl(f.attributes,l))}return i},r.getTraceValObject=function(t,e){var r,i,o=e[0],s=1;if(\"transforms\"===o){if(1===e.length)return a.transforms;var l=t.transforms;if(!Array.isArray(l)||!l.length)return!1;var c=e[1];if(!k(c)||c>=l.length)return!1;i=(r=(n.transformsRegistry[l[c].type]||{}).attributes)&&r[e[2]],s=3}else if(\"area\"===t.type)i=u[o];else{var h=t._module;if(h||(h=(n.modules[t.type||a.type.dflt]||{})._module),!h)return!1;if(!(i=(r=h.attributes)&&r[o])){var f=h.basePlotModule;f&&f.attributes&&(i=f.attributes[o])}i||(i=a[o])}return w(i,e,s)},r.getLayoutValObject=function(t,e){return w(function(t,e){var r,i,a,s,l=t._basePlotModules;if(l){var c;for(r=0;r<l.length;r++){if((a=l[r]).attrRegex&&a.attrRegex.test(e)){if(a.layoutAttrOverrides)return a.layoutAttrOverrides;!c&&a.layoutAttributes&&(c=a.layoutAttributes)}var u=a.baseLayoutAttrOverrides;if(u&&e in u)return u[e]}if(c)return c}var f=t._modules;if(f)for(r=0;r<f.length;r++)if((s=f[r].layoutAttributes)&&e in s)return s[e];for(i in n.componentsRegistry){if(\"colorscale\"===(a=n.componentsRegistry[i]).name&&0===e.indexOf(\"coloraxis\"))return a.layoutAttributes[e];if(!a.schema&&e===a.name)return a.layoutAttributes}if(e in o)return o[e];if(\"radialaxis\"===e||\"angularaxis\"===e)return h[e];return h.layout[e]||!1}(t,e[0]),e,1)}},{\"../lib\":719,\"../plots/animation_attributes\":762,\"../plots/attributes\":764,\"../plots/frame_attributes\":794,\"../plots/layout_attributes\":819,\"../plots/polar/legacy/area_attributes\":834,\"../plots/polar/legacy/axis_attributes\":835,\"../registry\":847,\"./edit_types\":750,\"./plot_config\":755}],757:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/attributes\"),a=\"templateitemname\",o={name:{valType:\"string\",editType:\"none\"}};function s(t){return t&&\"string\"==typeof t}function l(t){var e=t.length-1;return\"s\"!==t.charAt(e)&&n.warn(\"bad argument to arrayDefaultKey: \"+t),t.substr(0,t.length-1)+\"defaults\"}o[a]={valType:\"string\",editType:\"calc\"},r.templatedArray=function(t,e){return e._isLinkedToArray=t,e.name=o.name,e[a]=o[a],e},r.traceTemplater=function(t){var e,r,a={};for(e in t)r=t[e],Array.isArray(r)&&r.length&&(a[e]=0);return{newTrace:function(o){var s={type:e=n.coerce(o,{},i,\"type\"),_template:null};if(e in a){r=t[e];var l=a[e]%r.length;a[e]++,s._template=r[l]}return s}}},r.newContainer=function(t,e,r){var i=t._template,a=i&&(i[e]||r&&i[r]);return n.isPlainObject(a)||(a=null),t[e]={_template:a}},r.arrayTemplater=function(t,e,r){var n=t._template,i=n&&n[l(e)],o=n&&n[e];Array.isArray(o)&&o.length||(o=[]);var c={};return{newItem:function(t){var e={name:t.name,_input:t},n=e[a]=t[a];if(!s(n))return e._template=i,e;for(var l=0;l<o.length;l++){var u=o[l];if(u.name===n)return c[n]=1,e._template=u,e}return e[r]=t[r]||!1,e._template=!1,e},defaultItems:function(){for(var t=[],e=0;e<o.length;e++){var r=o[e],n=r.name;if(s(n)&&!c[n]){var i={_template:r,name:n,_input:{_templateitemname:n}};i[a]=r[a],t.push(i),c[n]=1}}return t}}},r.arrayDefaultKey=l,r.arrayEditor=function(t,e,r){var i=(n.nestedProperty(t,e).get()||[]).length,o=r._index,s=o>=i&&(r._input||{})._templateitemname;s&&(o=i);var l,c=e+\"[\"+o+\"]\";function u(){l={},s&&(l[c]={},l[c][a]=s)}function h(t,e){s?n.nestedProperty(l[c],t).set(e):l[c+\".\"+t]=e}function f(){var t=l;return u(),t}return u(),{modifyBase:function(t,e){l[t]=e},modifyItem:h,getUpdateObj:f,applyUpdate:function(e,r){e&&h(e,r);var i=f();for(var a in i)n.nestedProperty(t,a).set(i[a])}}}},{\"../lib\":719,\"../plots/attributes\":764}],758:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../registry\"),a=t(\"../plots/plots\"),o=t(\"../lib\"),s=t(\"../lib/clear_gl_canvases\"),l=t(\"../components/color\"),c=t(\"../components/drawing\"),u=t(\"../components/titles\"),h=t(\"../components/modebar\"),f=t(\"../plots/cartesian/axes\"),p=t(\"../constants/alignment\"),d=t(\"../plots/cartesian/constraints\"),g=d.enforce,v=d.clean,m=t(\"../plots/cartesian/autorange\").doAutoRange,y=\"start\",x=\"middle\",b=\"end\";function _(t,e,r){for(var n=0;n<r.length;n++){var i=r[n][0],a=r[n][1];if(!(i[0]>=t[1]||i[1]<=t[0])&&(a[0]<e[1]&&a[1]>e[0]))return!0}return!1}function w(t){var e,i,a,s,u,d,g=t._fullLayout,v=g._size,m=v.p,y=f.list(t,\"\",!0);if(g._paperdiv.style({width:t._context.responsive&&g.autosize&&!t._context._hasZeroWidth&&!t.layout.width?\"100%\":g.width+\"px\",height:t._context.responsive&&g.autosize&&!t._context._hasZeroHeight&&!t.layout.height?\"100%\":g.height+\"px\"}).selectAll(\".main-svg\").call(c.setSize,g.width,g.height),t._context.setBackground(t,g.paper_bgcolor),r.drawMainTitle(t),h.manage(t),!g._has(\"cartesian\"))return t._promises.length&&Promise.all(t._promises);function x(t,e,r){var n=t._lw/2;return\"x\"===t._id.charAt(0)?e?\"top\"===r?e._offset-m-n:e._offset+e._length+m+n:v.t+v.h*(1-(t.position||0))+n%1:e?\"right\"===r?e._offset+e._length+m+n:e._offset-m-n:v.l+v.w*(t.position||0)+n%1}for(e=0;e<y.length;e++){var b=(s=y[e])._anchorAxis;s._linepositions={},s._lw=c.crispRound(t,s.linewidth,1),s._mainLinePosition=x(s,b,s.side),s._mainMirrorPosition=s.mirror&&b?x(s,b,p.OPPOSITE_SIDE[s.side]):null}var w=[],T=[],M=[],S=1===l.opacity(g.paper_bgcolor)&&1===l.opacity(g.plot_bgcolor)&&g.paper_bgcolor===g.plot_bgcolor;for(i in g._plots)if((a=g._plots[i]).mainplot)a.bg&&a.bg.remove(),a.bg=void 0;else{var E=a.xaxis.domain,C=a.yaxis.domain,L=a.plotgroup;if(_(E,C,M)){var P=L.node(),O=a.bg=o.ensureSingle(L,\"rect\",\"bg\");P.insertBefore(O.node(),P.childNodes[0]),T.push(i)}else L.select(\"rect.bg\").remove(),M.push([E,C]),S||(w.push(i),T.push(i))}var z,I,D,R,F,B,N,j,U,V,q,H,G,Y=g._bgLayer.selectAll(\".bg\").data(w);for(Y.enter().append(\"rect\").classed(\"bg\",!0),Y.exit().remove(),Y.each(function(t){g._plots[t].bg=n.select(this)}),e=0;e<T.length;e++)a=g._plots[T[e]],u=a.xaxis,d=a.yaxis,a.bg&&a.bg.call(c.setRect,u._offset-m,d._offset-m,u._length+2*m,d._length+2*m).call(l.fill,g.plot_bgcolor).style(\"stroke-width\",0);if(!g._hasOnlyLargeSploms)for(i in g._plots){a=g._plots[i],u=a.xaxis,d=a.yaxis;var W,X,Z=a.clipId=\"clip\"+g._uid+i+\"plot\",J=o.ensureSingleById(g._clips,\"clipPath\",Z,function(t){t.classed(\"plotclip\",!0).append(\"rect\")});a.clipRect=J.select(\"rect\").attr({width:u._length,height:d._length}),c.setTranslate(a.plot,u._offset,d._offset),a._hasClipOnAxisFalse?(W=null,X=Z):(W=Z,X=null),c.setClipUrl(a.plot,W,t),a.layerClipId=X}function K(t){return\"M\"+z+\",\"+t+\"H\"+I}function $(t){return\"M\"+u._offset+\",\"+t+\"h\"+u._length}function Q(t){return\"M\"+t+\",\"+j+\"V\"+N}function tt(t){return\"M\"+t+\",\"+d._offset+\"v\"+d._length}function et(t,e,r){if(!t.showline||i!==t._mainSubplot)return\"\";if(!t._anchorAxis)return r(t._mainLinePosition);var n=e(t._mainLinePosition);return t.mirror&&(n+=e(t._mainMirrorPosition)),n}for(i in g._plots){a=g._plots[i],u=a.xaxis,d=a.yaxis;var rt=\"M0,0\";k(u,i)&&(F=A(u,\"left\",d,y),z=u._offset-(F?m+F:0),B=A(u,\"right\",d,y),I=u._offset+u._length+(B?m+B:0),D=x(u,d,\"bottom\"),R=x(u,d,\"top\"),!(G=!u._anchorAxis||i!==u._mainSubplot)||\"allticks\"!==u.mirror&&\"all\"!==u.mirror||(u._linepositions[i]=[D,R]),rt=et(u,K,$),G&&u.showline&&(\"all\"===u.mirror||\"allticks\"===u.mirror)&&(rt+=K(D)+K(R)),a.xlines.style(\"stroke-width\",u._lw+\"px\").call(l.stroke,u.showline?u.linecolor:\"rgba(0,0,0,0)\")),a.xlines.attr(\"d\",rt);var nt=\"M0,0\";k(d,i)&&(q=A(d,\"bottom\",u,y),N=d._offset+d._length+(q?m:0),H=A(d,\"top\",u,y),j=d._offset-(H?m:0),U=x(d,u,\"left\"),V=x(d,u,\"right\"),!(G=!d._anchorAxis||i!==d._mainSubplot)||\"allticks\"!==d.mirror&&\"all\"!==d.mirror||(d._linepositions[i]=[U,V]),nt=et(d,Q,tt),G&&d.showline&&(\"all\"===d.mirror||\"allticks\"===d.mirror)&&(nt+=Q(U)+Q(V)),a.ylines.style(\"stroke-width\",d._lw+\"px\").call(l.stroke,d.showline?d.linecolor:\"rgba(0,0,0,0)\")),a.ylines.attr(\"d\",nt)}return f.makeClipPaths(t),t._promises.length&&Promise.all(t._promises)}function k(t,e){return(t.ticks||t.showline)&&(e===t._mainSubplot||\"all\"===t.mirror||\"allticks\"===t.mirror)}function T(t,e,r){if(!r.showline||!r._lw)return!1;if(\"all\"===r.mirror||\"allticks\"===r.mirror)return!0;var n=r._anchorAxis;if(!n)return!1;var i=p.FROM_BL[e];return r.side===e?n.domain[i]===t.domain[i]:r.mirror&&n.domain[1-i]===t.domain[1-i]}function A(t,e,r,n){if(T(t,e,r))return r._lw;for(var i=0;i<n.length;i++){var a=n[i];if(a._mainAxis===r._mainAxis&&T(t,e,a))return a._lw}return 0}r.layoutStyles=function(t){return o.syncOrAsync([a.doAutoMargin,w],t)},r.drawMainTitle=function(t){var e=t._fullLayout,r=function(t){var e=t.title,r=x;o.isRightAnchor(e)?r=b:o.isLeftAnchor(e)&&(r=y);return r}(e),n=function(t){var e=t.title,r=\"0em\";o.isTopAnchor(e)?r=p.CAP_SHIFT+\"em\":o.isMiddleAnchor(e)&&(r=p.MID_SHIFT+\"em\");return r}(e);u.draw(t,\"gtitle\",{propContainer:e,propName:\"title.text\",placeholder:e._dfltTitle.plot,attributes:{x:function(t,e){var r=t.title,n=t._size,i=0;e===y?i=r.pad.l:e===b&&(i=-r.pad.r);switch(r.xref){case\"paper\":return n.l+n.w*r.x+i;case\"container\":default:return t.width*r.x+i}}(e,r),y:function(t,e){var r=t.title,n=t._size,i=0;\"0em\"!==e&&e?e===p.CAP_SHIFT+\"em\"&&(i=r.pad.t):i=-r.pad.b;if(\"auto\"===r.y)return n.t/2;switch(r.yref){case\"paper\":return n.t+n.h-n.h*r.y+i;case\"container\":default:return t.height-t.height*r.y+i}}(e,n),\"text-anchor\":r,dy:n}})},r.doTraceStyle=function(t){var e,n=t.calcdata,o=[];for(e=0;e<n.length;e++){var l=n[e],c=l[0]||{},u=c.trace||{},h=u._module||{},f=h.arraysToCalcdata;f&&f(l,u);var p=h.editStyle;p&&o.push({fn:p,cd0:c})}if(o.length){for(e=0;e<o.length;e++){var d=o[e];d.fn(t,d.cd0)}s(t),r.redrawReglTraces(t)}return a.style(t),i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doColorBars=function(t){return i.getComponentMethod(\"colorbar\",\"draw\")(t),a.previousPromises(t)},r.layoutReplot=function(t){var e=t.layout;return t.layout=void 0,i.call(\"plot\",t,\"\",e)},r.doLegend=function(t){return i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doTicksRelayout=function(t){return f.draw(t,\"redraw\"),t._fullLayout._hasOnlyLargeSploms&&(i.subplotsRegistry.splom.updateGrid(t),s(t),r.redrawReglTraces(t)),r.drawMainTitle(t),a.previousPromises(t)},r.doModeBar=function(t){var e=t._fullLayout;h.manage(t);for(var r=0;r<e._basePlotModules.length;r++){var n=e._basePlotModules[r].updateFx;n&&n(t)}return a.previousPromises(t)},r.doCamera=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){var i=e[r[n]],a=i._scene,o=i.camera;a.setCamera(o)}},r.drawData=function(t){var e=t._fullLayout;s(t);for(var n=e._basePlotModules,o=0;o<n.length;o++)n[o].plot(t);return r.redrawReglTraces(t),a.style(t),i.getComponentMethod(\"shapes\",\"draw\")(t),i.getComponentMethod(\"annotations\",\"draw\")(t),e._replotting=!1,a.previousPromises(t)},r.redrawReglTraces=function(t){var e=t._fullLayout;if(e._has(\"regl\")){var r,n,i=t._fullData,a=[],s=[];for(e._hasOnlyLargeSploms&&e._splomGrid.draw(),r=0;r<i.length;r++){var l=i[r];!0===l.visible&&0!==l._length&&(\"splom\"===l.type?e._splomScenes[l.uid].draw():\"scattergl\"===l.type?o.pushUnique(a,l.xaxis+l.yaxis):\"scatterpolargl\"===l.type&&o.pushUnique(s,l.subplot))}for(r=0;r<a.length;r++)(n=e._plots[a[r]])._scene&&n._scene.draw();for(r=0;r<s.length;r++)(n=e[s[r]]._subplot)._scene&&n._scene.draw()}},r.doAutoRangeAndConstraints=function(t){for(var e,r,n=t._fullLayout,i=f.list(t,\"\",!0),a=n._axisMatchGroups||[],s=0;s<i.length;s++)e=i[s],v(t,e),m(t,e);g(t);t:for(var l=0;l<a.length;l++){var c,u=a[l],h=null;for(c in u){if(!1===(e=f.getFromId(t,c)).autorange)continue t;r=o.simpleMap(e.range,e.r2l),h?h[0]<h[1]?(h[0]=Math.min(h[0],r[0]),h[1]=Math.max(h[1],r[1])):(h[0]=Math.max(h[0],r[0]),h[1]=Math.min(h[1],r[1])):h=r}for(c in u)(e=f.getFromId(t,c)).range=o.simpleMap(h,e.l2r),e._input.range=e.range.slice(),e.setScale()}},r.finalDraw=function(t){i.getComponentMethod(\"shapes\",\"draw\")(t),i.getComponentMethod(\"images\",\"draw\")(t),i.getComponentMethod(\"annotations\",\"draw\")(t),i.getComponentMethod(\"rangeslider\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t)},r.drawMarginPushers=function(t){i.getComponentMethod(\"legend\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t),i.getComponentMethod(\"sliders\",\"draw\")(t),i.getComponentMethod(\"updatemenus\",\"draw\")(t),i.getComponentMethod(\"colorbar\",\"draw\")(t)}},{\"../components/color\":593,\"../components/drawing\":614,\"../components/modebar\":652,\"../components/titles\":681,\"../constants/alignment\":688,\"../lib\":719,\"../lib/clear_gl_canvases\":704,\"../plots/cartesian/autorange\":766,\"../plots/cartesian/axes\":767,\"../plots/cartesian/constraints\":774,\"../plots/plots\":828,\"../registry\":847,d3:163}],759:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.isPlainObject,a=t(\"./plot_schema\"),o=t(\"../plots/plots\"),s=t(\"../plots/attributes\"),l=t(\"./plot_template\"),c=t(\"./plot_config\").dfltConfig;function u(t,e){t=n.extendDeep({},t);var r,a,o=Object.keys(t).sort();function s(e,r,n){if(i(r)&&i(e))u(e,r);else if(Array.isArray(r)&&Array.isArray(e)){var o=l.arrayTemplater({_template:t},n);for(a=0;a<r.length;a++){var s=r[a],c=o.newItem(s)._template;c&&u(c,s)}var h=o.defaultItems();for(a=0;a<h.length;a++)r.push(h[a]._template);for(a=0;a<r.length;a++)delete r[a].templateitemname}}for(r=0;r<o.length;r++){var c=o[r],f=t[c];if(c in e?s(f,e[c],c):e[c]=f,h(c)===c)for(var p in e){var d=h(p);p===d||d!==c||p in t||s(f,e[p],c)}}}function h(t){return t.replace(/[0-9]+$/,\"\")}function f(t,e,r,a,o){var s=o&&r(o);for(var c in t){var u=t[c],d=p(t,c,a),g=p(t,c,o),v=r(g);if(!v){var m=h(c);m!==c&&(v=r(g=p(t,m,o)))}if((!s||s!==v)&&!(!v||v._noTemplating||\"data_array\"===v.valType||v.arrayOk&&Array.isArray(u)))if(!v.valType&&i(u))f(u,e,r,d,g);else if(v._isLinkedToArray&&Array.isArray(u))for(var y=!1,x=0,b={},_=0;_<u.length;_++){var w=u[_];if(i(w)){var k=w.name;if(k)b[k]||(f(w,e,r,p(u,x,d),p(u,x,g)),x++,b[k]=1);else if(!y){var T=p(t,l.arrayDefaultKey(c),a),A=p(u,x,d);f(w,e,r,A,p(u,x,g));var M=n.nestedProperty(e,A);n.nestedProperty(e,T).set(M.get()),M.set(null),y=!0}}}else{n.nestedProperty(e,d).set(u)}}}function p(t,e,r){return r?Array.isArray(t)?r+\"[\"+e+\"]\":r+\".\"+e:e}function d(t){for(var e=0;e<t.length;e++)if(i(t[e]))return!0}function g(t){var e;switch(t.code){case\"data\":e=\"The template has no key data.\";break;case\"layout\":e=\"The template has no key layout.\";break;case\"missing\":e=t.path?\"There are no templates for item \"+t.path+\" with name \"+t.templateitemname:\"There are no templates for trace \"+t.index+\", of type \"+t.traceType+\".\";break;case\"unused\":e=t.path?\"The template item at \"+t.path+\" was not used in constructing the plot.\":t.dataCount?\"Some of the templates of type \"+t.traceType+\" were not used. The template has \"+t.templateCount+\" traces, the data only has \"+t.dataCount+\" of this type.\":\"The template has \"+t.templateCount+\" traces of type \"+t.traceType+\" but there are none in the data.\";break;case\"reused\":e=\"Some of the templates of type \"+t.traceType+\" were used more than once. The template has \"+t.templateCount+\" traces, the data has \"+t.dataCount+\" of this type.\"}return t.msg=e,t}r.makeTemplate=function(t){t=n.isPlainObject(t)?t:n.getGraphDiv(t),t=n.extendDeep({_context:c},{data:t.data,layout:t.layout}),o.supplyDefaults(t);var e=t.data||[],r=t.layout||{};r._basePlotModules=t._fullLayout._basePlotModules,r._modules=t._fullLayout._modules;var l={data:{},layout:{}};e.forEach(function(t){var e={};f(t,e,function(t,e){return a.getTraceValObject(t,n.nestedProperty({},e).parts)}.bind(null,t));var r=n.coerce(t,{},s,\"type\"),i=l.data[r];i||(i=l.data[r]=[]),i.push(e)}),f(r,l.layout,function(t,e){return a.getLayoutValObject(t,n.nestedProperty({},e).parts)}.bind(null,r)),delete l.layout.template;var h=r.template;if(i(h)){var p,d,g,v,m,y,x=h.layout;i(x)&&u(x,l.layout);var b=h.data;if(i(b)){for(d in l.data)if(g=b[d],Array.isArray(g)){for(y=(m=l.data[d]).length,v=g.length,p=0;p<y;p++)u(g[p%v],m[p]);for(p=y;p<v;p++)m.push(n.extendDeep({},g[p]))}for(d in b)d in l.data||(l.data[d]=n.extendDeep([],b[d]))}}return l},r.validateTemplate=function(t,e){var r=n.extendDeep({},{_context:c,data:t.data,layout:t.layout}),a=r.layout||{};i(e)||(e=a.template||{});var s=e.layout,l=e.data,u=[];r.layout=a,r.layout.template=e,o.supplyDefaults(r);var f=r._fullLayout,v=r._fullData,m={};if(i(s)?(!function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)&&i(e[n])){var a,o=h(n),s=[];for(a=0;a<r.length;a++)s.push(p(e,n,r[a])),o!==n&&s.push(p(e,o,r[a]));for(a=0;a<s.length;a++)m[s[a]]=1;t(e[n],s)}}(f,[\"layout\"]),function t(e,r){for(var n in e)if(-1===n.indexOf(\"defaults\")&&i(e[n])){var a=p(e,n,r);m[a]?t(e[n],a):u.push({code:\"unused\",path:a})}}(s,\"layout\")):u.push({code:\"layout\"}),i(l)){for(var y,x={},b=0;b<v.length;b++){var _=v[b];x[y=_.type]=(x[y]||0)+1,_._fullInput._template||u.push({code:\"missing\",index:_._fullInput.index,traceType:y})}for(y in l){var w=l[y].length,k=x[y]||0;w>k?u.push({code:\"unused\",traceType:y,templateCount:w,dataCount:k}):k>w&&u.push({code:\"reused\",traceType:y,templateCount:w,dataCount:k})}}else u.push({code:\"data\"});if(function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)){var a=e[n],o=p(e,n,r);i(a)?(Array.isArray(e)&&!1===a._template&&a.templateitemname&&u.push({code:\"missing\",path:o,templateitemname:a.templateitemname}),t(a,o)):Array.isArray(a)&&d(a)&&t(a,o)}}({data:v,layout:f},\"\"),u.length)return u.map(g)}},{\"../lib\":719,\"../plots/attributes\":764,\"../plots/plots\":828,\"./plot_config\":755,\"./plot_schema\":756,\"./plot_template\":757}],760:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./plot_api\"),a=t(\"../lib\"),o=t(\"../snapshot/helpers\"),s=t(\"../snapshot/tosvg\"),l=t(\"../snapshot/svgtoimg\"),c={format:{valType:\"enumerated\",values:[\"png\",\"jpeg\",\"webp\",\"svg\"],dflt:\"png\"},width:{valType:\"number\",min:1},height:{valType:\"number\",min:1},scale:{valType:\"number\",min:0,dflt:1},setBackground:{valType:\"any\",dflt:!1},imageDataOnly:{valType:\"boolean\",dflt:!1}};e.exports=function(t,e){var r,u,h,f;function p(t){return!(t in e)||a.validate(e[t],c[t])}if(e=e||{},a.isPlainObject(t)?(r=t.data||[],u=t.layout||{},h=t.config||{},f={}):(t=a.getGraphDiv(t),r=a.extendDeep([],t.data),u=a.extendDeep({},t.layout),h=t._context,f=t._fullLayout||{}),!p(\"width\")&&null!==e.width||!p(\"height\")&&null!==e.height)throw new Error(\"Height and width should be pixel values.\");if(!p(\"format\"))throw new Error(\"Image format is not jpeg, png, svg or webp.\");var d={};function g(t,r){return a.coerce(e,d,c,t,r)}var v=g(\"format\"),m=g(\"width\"),y=g(\"height\"),x=g(\"scale\"),b=g(\"setBackground\"),_=g(\"imageDataOnly\"),w=document.createElement(\"div\");w.style.position=\"absolute\",w.style.left=\"-5000px\",document.body.appendChild(w);var k=a.extendFlat({},u);m?k.width=m:null===e.width&&n(f.width)&&(k.width=f.width),y?k.height=y:null===e.height&&n(f.height)&&(k.height=f.height);var T=a.extendFlat({},h,{_exportedPlot:!0,staticPlot:!0,setBackground:b}),A=o.getRedrawFunc(w);function M(){return new Promise(function(t){setTimeout(t,o.getDelay(w._fullLayout))})}function S(){return new Promise(function(t,e){var r=s(w,v,x),n=w._fullLayout.width,c=w._fullLayout.height;if(i.purge(w),document.body.removeChild(w),\"svg\"===v)return t(_?r:o.encodeSVG(r));var u=document.createElement(\"canvas\");u.id=a.randstr(),l({format:v,width:n,height:c,scale:x,canvas:u,svg:r,promise:!0}).then(t).catch(e)})}return new Promise(function(t,e){i.plot(w,r,k,T).then(A).then(M).then(S).then(function(e){t(function(t){return _?t.replace(o.IMAGE_URL_PREFIX,\"\"):t}(e))}).catch(function(t){e(t)})})}},{\"../lib\":719,\"../snapshot/helpers\":851,\"../snapshot/svgtoimg\":853,\"../snapshot/tosvg\":855,\"./plot_api\":754,\"fast-isnumeric\":225}],761:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/plots\"),a=t(\"./plot_schema\"),o=t(\"./plot_config\").dfltConfig,s=n.isPlainObject,l=Array.isArray,c=n.isArrayOrTypedArray;function u(t,e,r,i,a,o){o=o||[];for(var h=Object.keys(t),f=0;f<h.length;f++){var v=h[f];if(\"transforms\"!==v){var m=o.slice();m.push(v);var y=t[v],x=e[v],b=g(r,v),_=\"info_array\"===(b||{}).valType,w=\"colorscale\"===(b||{}).valType,k=(b||{}).items;if(d(r,v))if(s(y)&&s(x))u(y,x,b,i,a,m);else if(_&&l(y)){y.length>x.length&&i.push(p(\"unused\",a,m.concat(x.length)));var T,A,M,S,E,C=x.length,L=Array.isArray(k);if(L&&(C=Math.min(C,k.length)),2===b.dimensions)for(A=0;A<C;A++)if(l(y[A])){y[A].length>x[A].length&&i.push(p(\"unused\",a,m.concat(A,x[A].length)));var P=x[A].length;for(T=0;T<(L?Math.min(P,k[A].length):P);T++)M=L?k[A][T]:k,S=y[A][T],E=x[A][T],n.validate(S,M)?E!==S&&E!==+S&&i.push(p(\"dynamic\",a,m.concat(A,T),S,E)):i.push(p(\"value\",a,m.concat(A,T),S))}else i.push(p(\"array\",a,m.concat(A),y[A]));else for(A=0;A<C;A++)M=L?k[A]:k,S=y[A],E=x[A],n.validate(S,M)?E!==S&&E!==+S&&i.push(p(\"dynamic\",a,m.concat(A),S,E)):i.push(p(\"value\",a,m.concat(A),S))}else if(b.items&&!_&&l(y)){var O,z,I=k[Object.keys(k)[0]],D=[];for(O=0;O<x.length;O++){var R=x[O]._index||O;if((z=m.slice()).push(R),s(y[R])&&s(x[O])){D.push(R);var F=y[R],B=x[O];s(F)&&!1!==F.visible&&!1===B.visible?i.push(p(\"invisible\",a,z)):u(F,B,I,i,a,z)}}for(O=0;O<y.length;O++)(z=m.slice()).push(O),s(y[O])?-1===D.indexOf(O)&&i.push(p(\"unused\",a,z)):i.push(p(\"object\",a,z,y[O]))}else!s(y)&&s(x)?i.push(p(\"object\",a,m,y)):c(y)||!c(x)||_||w?v in e?n.validate(y,b)?\"enumerated\"===b.valType&&(b.coerceNumber&&y!==+x||y!==x)&&i.push(p(\"dynamic\",a,m,y,x)):i.push(p(\"value\",a,m,y)):i.push(p(\"unused\",a,m,y)):i.push(p(\"array\",a,m,y));else i.push(p(\"schema\",a,m))}}return i}e.exports=function(t,e){var r,c,h=a.get(),f=[],d={_context:n.extendFlat({},o)};l(t)?(d.data=n.extendDeep([],t),r=t):(d.data=[],r=[],f.push(p(\"array\",\"data\"))),s(e)?(d.layout=n.extendDeep({},e),c=e):(d.layout={},c={},arguments.length>1&&f.push(p(\"object\",\"layout\"))),i.supplyDefaults(d);for(var g=d._fullData,v=r.length,m=0;m<v;m++){var y=r[m],x=[\"data\",m];if(s(y)){var b=g[m],_=b.type,w=h.traces[_].attributes;w.type={valType:\"enumerated\",values:[_]},!1===b.visible&&!1!==y.visible&&f.push(p(\"invisible\",x)),u(y,b,w,f,x);var k=y.transforms,T=b.transforms;if(k){l(k)||f.push(p(\"array\",x,[\"transforms\"])),x.push(\"transforms\");for(var A=0;A<k.length;A++){var M=[\"transforms\",A],S=k[A].type;if(s(k[A])){var E=h.transforms[S]?h.transforms[S].attributes:{};E.type={valType:\"enumerated\",values:Object.keys(h.transforms)},u(k[A],T[A],E,f,x,M)}else f.push(p(\"object\",x,M))}}}else f.push(p(\"object\",x))}return u(c,d._fullLayout,function(t,e){for(var r=t.layout.layoutAttributes,i=0;i<e.length;i++){var a=e[i],o=t.traces[a.type],s=o.layoutAttributes;s&&(a.subplot?n.extendFlat(r[o.attributes.subplot.dflt],s):n.extendFlat(r,s))}return r}(h,g),f,\"layout\"),0===f.length?void 0:f};var h={object:function(t,e){return(\"layout\"===t&&\"\"===e?\"The layout argument\":\"data\"===t[0]&&\"\"===e?\"Trace \"+t[1]+\" in the data argument\":f(t)+\"key \"+e)+\" must be linked to an object container\"},array:function(t,e){return(\"data\"===t?\"The data argument\":f(t)+\"key \"+e)+\" must be linked to an array container\"},schema:function(t,e){return f(t)+\"key \"+e+\" is not part of the schema\"},unused:function(t,e,r){var n=s(r)?\"container\":\"key\";return f(t)+n+\" \"+e+\" did not get coerced\"},dynamic:function(t,e,r,n){return[f(t)+\"key\",e,\"(set to '\"+r+\"')\",\"got reset to\",\"'\"+n+\"'\",\"during defaults.\"].join(\" \")},invisible:function(t,e){return(e?f(t)+\"item \"+e:\"Trace \"+t[1])+\" got defaulted to be not visible\"},value:function(t,e,r){return[f(t)+\"key \"+e,\"is set to an invalid value (\"+r+\")\"].join(\" \")}};function f(t){return l(t)?\"In data trace \"+t[1]+\", \":\"In \"+t+\", \"}function p(t,e,r,i,a){var o,s;r=r||\"\",l(e)?(o=e[0],s=e[1]):(o=e,s=null);var c=function(t){if(!l(t))return String(t);for(var e=\"\",r=0;r<t.length;r++){var n=t[r];\"number\"==typeof n?e=e.substr(0,e.length-1)+\"[\"+n+\"]\":e+=n,r<t.length-1&&(e+=\".\")}return e}(r),u=h[t](e,c,i,a);return n.log(u),{code:t,container:o,trace:s,path:r,astr:c,msg:u}}function d(t,e){var r=m(e),n=r.keyMinusId,i=r.id;return!!(n in t&&t[n]._isSubplotObj&&i)||e in t}function g(t,e){return e in t?t[e]:t[m(e).keyMinusId]}var v=n.counterRegex(\"([a-z]+)\");function m(t){var e=t.match(v);return{keyMinusId:e&&e[1],id:e&&e[2]}}},{\"../lib\":719,\"../plots/plots\":828,\"./plot_config\":755,\"./plot_schema\":756}],762:[function(t,e,r){\"use strict\";e.exports={mode:{valType:\"enumerated\",dflt:\"afterall\",values:[\"immediate\",\"next\",\"afterall\"]},direction:{valType:\"enumerated\",values:[\"forward\",\"reverse\"],dflt:\"forward\"},fromcurrent:{valType:\"boolean\",dflt:!1},frame:{duration:{valType:\"number\",min:0,dflt:500},redraw:{valType:\"boolean\",dflt:!0}},transition:{duration:{valType:\"number\",min:0,dflt:500,editType:\"none\"},easing:{valType:\"enumerated\",dflt:\"cubic-in-out\",values:[\"linear\",\"quad\",\"cubic\",\"sin\",\"exp\",\"circle\",\"elastic\",\"back\",\"bounce\",\"linear-in\",\"quad-in\",\"cubic-in\",\"sin-in\",\"exp-in\",\"circle-in\",\"elastic-in\",\"back-in\",\"bounce-in\",\"linear-out\",\"quad-out\",\"cubic-out\",\"sin-out\",\"exp-out\",\"circle-out\",\"elastic-out\",\"back-out\",\"bounce-out\",\"linear-in-out\",\"quad-in-out\",\"cubic-in-out\",\"sin-in-out\",\"exp-in-out\",\"circle-in-out\",\"elastic-in-out\",\"back-in-out\",\"bounce-in-out\"],editType:\"none\"},ordering:{valType:\"enumerated\",values:[\"layout first\",\"traces first\"],dflt:\"layout first\",editType:\"none\"}}}},{}],763:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\");e.exports=function(t,e,r){var a,o,s=r.name,l=r.inclusionAttr||\"visible\",c=e[s],u=n.isArrayOrTypedArray(t[s])?t[s]:[],h=e[s]=[],f=i.arrayTemplater(e,s,l);for(a=0;a<u.length;a++){var p=u[a];n.isPlainObject(p)?o=f.newItem(p):(o=f.newItem({}))[l]=!1,o._index=a,!1!==o[l]&&r.handleItemDefaults(p,o,e,r),h.push(o)}var d=f.defaultItems();for(a=0;a<d.length;a++)(o=d[a])._index=h.length,r.handleItemDefaults({},o,e,r,{}),h.push(o);if(n.isArrayOrTypedArray(c)){var g=Math.min(c.length,h.length);for(a=0;a<g;a++)n.relinkPrivateKeys(h[a],c[a])}return h}},{\"../lib\":719,\"../plot_api/plot_template\":757}],764:[function(t,e,r){\"use strict\";var n=t(\"../components/fx/attributes\");e.exports={type:{valType:\"enumerated\",values:[],dflt:\"scatter\",editType:\"calc+clearAxisTypes\",_noTemplating:!0},visible:{valType:\"enumerated\",values:[!0,!1,\"legendonly\"],dflt:!0,editType:\"calc\"},showlegend:{valType:\"boolean\",dflt:!0,editType:\"style\"},legendgroup:{valType:\"string\",dflt:\"\",editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"style\"},name:{valType:\"string\",editType:\"style\"},uid:{valType:\"string\",editType:\"plot\",anim:!0},ids:{valType:\"data_array\",editType:\"calc\",anim:!0},customdata:{valType:\"data_array\",editType:\"calc\"},meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},selectedpoints:{valType:\"any\",editType:\"calc\"},hoverinfo:{valType:\"flaglist\",flags:[\"x\",\"y\",\"z\",\"text\",\"name\"],extras:[\"all\",\"none\",\"skip\"],arrayOk:!0,dflt:\"all\",editType:\"none\"},hoverlabel:n.hoverlabel,stream:{token:{valType:\"string\",noBlank:!0,strict:!0,editType:\"calc\"},maxpoints:{valType:\"number\",min:0,max:1e4,dflt:500,editType:\"calc\"},editType:\"calc\"},transforms:{_isLinkedToArray:\"transform\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"}}},{\"../components/fx/attributes\":623}],765:[function(t,e,r){\"use strict\";e.exports={xaxis:{valType:\"subplotid\",dflt:\"x\",editType:\"calc+clearAxisTypes\"},yaxis:{valType:\"subplotid\",dflt:\"y\",editType:\"calc+clearAxisTypes\"}}},{}],766:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").FP_SAFE,o=t(\"../../registry\");function s(t,e){var r,n,a=[],o=l(e),s=c(t,e),u=s.min,h=s.max;if(0===u.length||0===h.length)return i.simpleMap(e.range,e.r2l);var f=u[0].val,p=h[0].val;for(r=1;r<u.length&&f===p;r++)f=Math.min(f,u[r].val);for(r=1;r<h.length&&f===p;r++)p=Math.max(p,h[r].val);var d=!1;if(e.range){var g=i.simpleMap(e.range,e.r2l);d=g[1]<g[0]}\"reversed\"===e.autorange&&(d=!0,e.autorange=!0);var v,m,y,x,b,_,w=e.rangemode,k=\"tozero\"===w,T=\"nonnegative\"===w,A=e._length,M=A/10,S=0;for(r=0;r<u.length;r++)for(v=u[r],n=0;n<h.length;n++)(_=(m=h[n]).val-v.val)>0&&((b=A-o(v)-o(m))>M?_/b>S&&(y=v,x=m,S=_/b):_/A>S&&(y={val:v.val,pad:0},x={val:m.val,pad:0},S=_/A));if(f===p){var E=f-1,C=f+1;if(k)if(0===f)a=[0,1];else{var L=(f>0?h:u).reduce(function(t,e){return Math.max(t,o(e))},0),P=f/(1-Math.min(.5,L/A));a=f>0?[0,P]:[P,0]}else a=T?[Math.max(0,E),Math.max(1,C)]:[E,C]}else k?(y.val>=0&&(y={val:0,pad:0}),x.val<=0&&(x={val:0,pad:0})):T&&(y.val-S*o(y)<0&&(y={val:0,pad:0}),x.val<=0&&(x={val:1,pad:0})),S=(x.val-y.val)/(A-o(y)-o(x)),a=[y.val-S*o(y),x.val+S*o(x)];return d&&a.reverse(),i.simpleMap(a,e.l2r||Number)}function l(t){var e=t._length/20;return\"domain\"===t.constrain&&t._inputDomain&&(e*=(t._inputDomain[1]-t._inputDomain[0])/(t.domain[1]-t.domain[0])),function(t){return t.pad+(t.extrapad?e:0)}}function c(t,e){var r,n,i,a=e._id,o=t._fullData,s=t._fullLayout,l=[],c=[];function f(t,e){for(r=0;r<e.length;r++){var o=t[e[r]],s=(o._extremes||{})[a];if(!0===o.visible&&s){for(n=0;n<s.min.length;n++)i=s.min[n],u(l,i.val,i.pad,{extrapad:i.extrapad});for(n=0;n<s.max.length;n++)i=s.max[n],h(c,i.val,i.pad,{extrapad:i.extrapad})}}}return f(o,e._traceIndices),f(s.annotations||[],e._annIndices||[]),f(s.shapes||[],e._shapeIndices||[]),{min:l,max:c}}function u(t,e,r,n){f(t,e,r,n,d)}function h(t,e,r,n){f(t,e,r,n,g)}function f(t,e,r,n,i){for(var a=n.tozero,o=n.extrapad,s=!0,l=0;l<t.length&&s;l++){var c=t[l];if(i(c.val,e)&&c.pad>=r&&(c.extrapad||!o)){s=!1;break}i(e,c.val)&&c.pad<=r&&(o||!c.extrapad)&&(t.splice(l,1),l--)}if(s){var u=a&&0===e;t.push({val:e,pad:u?0:r,extrapad:!u&&o})}}function p(t){return n(t)&&Math.abs(t)<a}function d(t,e){return t<=e}function g(t,e){return t>=e}e.exports={getAutoRange:s,makePadFn:l,doAutoRange:function(t,e){if(e.setScale(),e.autorange){e.range=s(t,e),e._r=e.range.slice(),e._rl=i.simpleMap(e._r,e.r2l);var r=e._input,n={};n[e._attr+\".range\"]=e.range,n[e._attr+\".autorange\"]=e.autorange,o.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,n),r.range=e.range.slice(),r.autorange=e.autorange}var a=e._anchorAxis;if(a&&a.rangeslider){var l=a.rangeslider[e._name];l&&\"auto\"===l.rangemode&&(l.range=s(t,e)),a._input.rangeslider[e._name]=i.extendFlat({},l)}},findExtremes:function(t,e,r){r||(r={});t._m||t.setScale();var i,o,s,l,c,f,d,g,v,m=[],y=[],x=e.length,b=r.padded||!1,_=r.tozero&&(\"linear\"===t.type||\"-\"===t.type),w=\"log\"===t.type,k=!1;function T(t){if(Array.isArray(t))return k=!0,function(e){return Math.max(Number(t[e]||0),0)};var e=Math.max(Number(t||0),0);return function(){return e}}var A=T((t._m>0?r.ppadplus:r.ppadminus)||r.ppad||0),M=T((t._m>0?r.ppadminus:r.ppadplus)||r.ppad||0),S=T(r.vpadplus||r.vpad),E=T(r.vpadminus||r.vpad);if(!k){if(g=1/0,v=-1/0,w)for(i=0;i<x;i++)(o=e[i])<g&&o>0&&(g=o),o>v&&o<a&&(v=o);else for(i=0;i<x;i++)(o=e[i])<g&&o>-a&&(g=o),o>v&&o<a&&(v=o);e=[g,v],x=2}var C={tozero:_,extrapad:b};function L(r){s=e[r],n(s)&&(f=A(r),d=M(r),g=s-E(r),v=s+S(r),w&&g<v/10&&(g=v/10),l=t.c2l(g),c=t.c2l(v),_&&(l=Math.min(0,l),c=Math.max(0,c)),p(l)&&u(m,l,d,C),p(c)&&h(y,c,f,C))}var P=Math.min(6,x);for(i=0;i<P;i++)L(i);for(i=x-1;i>=P;i--)L(i);return{min:m,max:y,opts:r}},concatExtremes:c}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../registry\":847,\"fast-isnumeric\":225}],767:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../components/titles\"),u=t(\"../../components/color\"),h=t(\"../../components/drawing\"),f=t(\"./layout_attributes\"),p=t(\"./clean_ticks\"),d=t(\"../../constants/numerical\"),g=d.ONEAVGYEAR,v=d.ONEAVGMONTH,m=d.ONEDAY,y=d.ONEHOUR,x=d.ONEMIN,b=d.ONESEC,_=d.MINUS_SIGN,w=d.BADNUM,k=t(\"../../constants/alignment\").MID_SHIFT,T=t(\"../../constants/alignment\").LINE_SPACING,A=e.exports={};A.setConvert=t(\"./set_convert\");var M=t(\"./axis_autotype\"),S=t(\"./axis_ids\");A.id2name=S.id2name,A.name2id=S.name2id,A.cleanId=S.cleanId,A.list=S.list,A.listIds=S.listIds,A.getFromId=S.getFromId,A.getFromTrace=S.getFromTrace;var E=t(\"./autorange\");A.getAutoRange=E.getAutoRange,A.findExtremes=E.findExtremes,A.coerceRef=function(t,e,r,n,i,a){var o=n.charAt(n.length-1),l=r._fullLayout._subplots[o+\"axis\"],c=n+\"ref\",u={};return i||(i=l[0]||a),a||(a=i),u[c]={valType:\"enumerated\",values:l.concat(a?[a]:[]),dflt:i},s.coerce(t,e,u,c)},A.coercePosition=function(t,e,r,n,i,a){var o,l;if(\"paper\"===n||\"pixel\"===n)o=s.ensureNumber,l=r(i,a);else{var c=A.getFromId(e,n);l=r(i,a=c.fraction2r(a)),o=c.cleanPos}t[i]=o(l)},A.cleanPosition=function(t,e,r){return(\"paper\"===r||\"pixel\"===r?s.ensureNumber:A.getFromId(e,r).cleanPos)(t)},A.redrawComponents=function(t,e){e=e||A.listIds(t);var r=t._fullLayout;function n(n,i,a,s){for(var l=o.getComponentMethod(n,i),c={},u=0;u<e.length;u++)for(var h=r[A.id2name(e[u])][a],f=0;f<h.length;f++){var p=h[f];if(!c[p]&&(l(t,p),c[p]=1,s))return}}n(\"annotations\",\"drawOne\",\"_annIndices\"),n(\"shapes\",\"drawOne\",\"_shapeIndices\"),n(\"images\",\"draw\",\"_imgIndices\",!0)};var C=A.getDataConversions=function(t,e,r,n){var i,a=\"x\"===r||\"y\"===r||\"z\"===r?r:n;if(Array.isArray(a)){if(i={type:M(n),_categories:[]},A.setConvert(i),\"category\"===i.type)for(var o=0;o<n.length;o++)i.d2c(n[o])}else i=A.getFromTrace(t,e,a);return i?{d2c:i.d2c,c2d:i.c2d}:\"ids\"===a?{d2c:P,c2d:P}:{d2c:L,c2d:L}};function L(t){return+t}function P(t){return String(t)}A.getDataToCoordFunc=function(t,e,r,n){return C(t,e,r,n).d2c},A.counterLetter=function(t){var e=t.charAt(0);return\"x\"===e?\"y\":\"y\"===e?\"x\":void 0},A.minDtick=function(t,e,r,n){-1===[\"log\",\"category\",\"multicategory\"].indexOf(t.type)&&n?void 0===t._minDtick?(t._minDtick=e,t._forceTick0=r):t._minDtick&&((t._minDtick/e+1e-6)%1<2e-6&&((r-t._forceTick0)/e%1+1.000001)%1<2e-6?(t._minDtick=e,t._forceTick0=r):((e/t._minDtick+1e-6)%1>2e-6||((r-t._forceTick0)/t._minDtick%1+1.000001)%1>2e-6)&&(t._minDtick=0)):t._minDtick=0},A.saveRangeInitial=function(t,e){for(var r=A.list(t,\"\",!0),n=!1,i=0;i<r.length;i++){var a=r[i],o=void 0===a._rangeInitial,s=o||!(a.range[0]===a._rangeInitial[0]&&a.range[1]===a._rangeInitial[1]);(o&&!1===a.autorange||e&&s)&&(a._rangeInitial=a.range.slice(),n=!0)}return n},A.saveShowSpikeInitial=function(t,e){for(var r=A.list(t,\"\",!0),n=!1,i=\"on\",a=0;a<r.length;a++){var o=r[a],s=void 0===o._showSpikeInitial,l=s||!(o.showspikes===o._showspikes);(s||e&&l)&&(o._showSpikeInitial=o.showspikes,n=!0),\"on\"!==i||o.showspikes||(i=\"off\")}return t._fullLayout._cartesianSpikesEnabled=i,n},A.autoBin=function(t,e,r,n,a,o){var l,c=s.aggNums(Math.min,null,t),u=s.aggNums(Math.max,null,t);if(\"category\"===e.type||\"multicategory\"===e.type)return{start:c-.5,end:u+.5,size:Math.max(1,Math.round(o)||1),_dataSpan:u-c};if(a||(a=e.calendar),l=\"log\"===e.type?{type:\"linear\",range:[c,u]}:{type:e.type,range:s.simpleMap([c,u],e.c2r,0,a),calendar:a},A.setConvert(l),o=o&&p.dtick(o,l.type))l.dtick=o,l.tick0=p.tick0(void 0,l.type,a);else{var h;if(r)h=(u-c)/r;else{var f=s.distinctVals(t),d=Math.pow(10,Math.floor(Math.log(f.minDiff)/Math.LN10)),g=d*s.roundUp(f.minDiff/d,[.9,1.9,4.9,9.9],!0);h=Math.max(g,2*s.stdev(t)/Math.pow(t.length,n?.25:.4)),i(h)||(h=1)}A.autoTicks(l,h)}var v,y=l.dtick,x=A.tickIncrement(A.tickFirst(l),y,\"reverse\",a);if(\"number\"==typeof y)v=(x=function(t,e,r,n,a){var o=0,s=0,l=0,c=0;function u(e){return(1+100*(e-t)/r.dtick)%100<2}for(var h=0;h<e.length;h++)e[h]%1==0?l++:i(e[h])||c++,u(e[h])&&o++,u(e[h]+r.dtick/2)&&s++;var f=e.length-c;if(l===f&&\"date\"!==r.type)r.dtick<1?t=n-.5*r.dtick:(t-=.5)+r.dtick<n&&(t+=r.dtick);else if(s<.1*f&&(o>.3*f||u(n)||u(a))){var p=r.dtick/2;t+=t+p<n?p:-p}return t}(x,t,l,c,u))+(1+Math.floor((u-x)/y))*y;else for(\"M\"===l.dtick.charAt(0)&&(x=function(t,e,r,n,i){var a=s.findExactDates(e,i);if(a.exactDays>.8){var o=Number(r.substr(1));a.exactYears>.8&&o%12==0?t=A.tickIncrement(t,\"M6\",\"reverse\")+1.5*m:a.exactMonths>.8?t=A.tickIncrement(t,\"M1\",\"reverse\")+15.5*m:t-=m/2;var l=A.tickIncrement(t,r);if(l<=n)return l}return t}(x,t,y,c,a)),v=x,0;v<=u;)v=A.tickIncrement(v,y,!1,a),0;return{start:e.c2r(x,0,a),end:e.c2r(v,0,a),size:y,_dataSpan:u-c}},A.prepTicks=function(t){var e=s.simpleMap(t.range,t.r2l);if(\"auto\"===t.tickmode||!t.dtick){var r,n=t.nticks;n||(\"category\"===t.type||\"multicategory\"===t.type?(r=t.tickfont?1.2*(t.tickfont.size||12):15,n=t._length/r):(r=\"y\"===t._id.charAt(0)?40:80,n=s.constrain(t._length/r,4,9)+1),\"radialaxis\"===t._name&&(n*=2)),\"array\"===t.tickmode&&(n*=100),A.autoTicks(t,Math.abs(e[1]-e[0])/n),t._minDtick>0&&t.dtick<2*t._minDtick&&(t.dtick=t._minDtick,t.tick0=t.l2r(t._forceTick0))}t.tick0||(t.tick0=\"date\"===t.type?\"2000-01-01\":0),\"date\"===t.type&&t.dtick<.1&&(t.dtick=.1),j(t)},A.calcTicks=function(t){A.prepTicks(t);var e=s.simpleMap(t.range,t.r2l);if(\"array\"===t.tickmode)return function(t){var e=t.tickvals,r=t.ticktext,n=new Array(e.length),i=s.simpleMap(t.range,t.r2l),a=1.0001*i[0]-1e-4*i[1],o=1.0001*i[1]-1e-4*i[0],l=Math.min(a,o),c=Math.max(a,o),u=0;Array.isArray(r)||(r=[]);var h=\"category\"===t.type?t.d2l_noadd:t.d2l;\"log\"===t.type&&\"L\"!==String(t.dtick).charAt(0)&&(t.dtick=\"L\"+Math.pow(10,Math.floor(Math.min(t.range[0],t.range[1]))-1));for(var f=0;f<e.length;f++){var p=h(e[f]);p>l&&p<c&&(void 0===r[f]?n[u]=A.tickText(t,p):n[u]=U(t,p,String(r[f])),u++)}u<e.length&&n.splice(u,e.length-u);return n}(t);t._tmin=A.tickFirst(t);var r=1.0001*e[0]-1e-4*e[1],n=1.0001*e[1]-1e-4*e[0],a=e[1]<e[0];if(t._tmin<r!==a)return[];var o=[];\"category\"!==t.type&&\"multicategory\"!==t.type||(n=a?Math.max(-.5,n):Math.min(t._categories.length-.5,n));for(var l=\"log\"===t.type&&!(i(t.dtick)||\"L\"===t.dtick.charAt(0)),c=null,u=Math.max(1e3,t._length||0),h=t._tmin;(a?h>=n:h<=n)&&!(o.length>u||h===c);h=A.tickIncrement(h,t.dtick,a,t.calendar)){c=h;var f=!1;l&&h!==(0|h)&&(f=!0),o.push({minor:f,value:h})}rt(t)&&360===Math.abs(e[1]-e[0])&&o.pop(),t._tmax=(o[o.length-1]||{}).value,t._prevDateHead=\"\",t._inCalcTicks=!0;for(var p=new Array(o.length),d=0;d<o.length;d++)p[d]=A.tickText(t,o[d].value,!1,o[d].minor);return t._inCalcTicks=!1,p};var O=[2,5,10],z=[1,2,3,6,12],I=[1,2,5,10,15,30],D=[1,2,3,7,14],R=[-.046,0,.301,.477,.602,.699,.778,.845,.903,.954,1],F=[-.301,0,.301,.699,1],B=[15,30,45,90,180];function N(t,e,r){return e*s.roundUp(t/e,r)}function j(t){var e=t.dtick;if(t._tickexponent=0,i(e)||\"string\"==typeof e||(e=1),\"category\"!==t.type&&\"multicategory\"!==t.type||(t._tickround=null),\"date\"===t.type){var r=t.r2l(t.tick0),n=t.l2r(r).replace(/(^-|i)/g,\"\"),a=n.length;if(\"M\"===String(e).charAt(0))a>10||\"01-01\"!==n.substr(5)?t._tickround=\"d\":t._tickround=+e.substr(1)%12==0?\"y\":\"m\";else if(e>=m&&a<=10||e>=15*m)t._tickround=\"d\";else if(e>=x&&a<=16||e>=y)t._tickround=\"M\";else if(e>=b&&a<=19||e>=x)t._tickround=\"S\";else{var o=t.l2r(r+e).replace(/^-/,\"\").length;t._tickround=Math.max(a,o)-20,t._tickround<0&&(t._tickround=4)}}else if(i(e)||\"L\"===e.charAt(0)){var s=t.range.map(t.r2d||Number);i(e)||(e=Number(e.substr(1))),t._tickround=2-Math.floor(Math.log(e)/Math.LN10+.01);var l=Math.max(Math.abs(s[0]),Math.abs(s[1])),c=Math.floor(Math.log(l)/Math.LN10+.01);Math.abs(c)>3&&(q(t.exponentformat)&&!H(c)?t._tickexponent=3*Math.round((c-1)/3):t._tickexponent=c)}else t._tickround=null}function U(t,e,r){var n=t.tickfont||{};return{x:e,dx:0,dy:0,text:r||\"\",fontSize:n.size,font:n.family,fontColor:n.color}}A.autoTicks=function(t,e){var r;function n(t){return Math.pow(t,Math.floor(Math.log(e)/Math.LN10))}if(\"date\"===t.type){t.tick0=s.dateTick0(t.calendar);var a=2*e;a>g?(e/=g,r=n(10),t.dtick=\"M\"+12*N(e,r,O)):a>v?(e/=v,t.dtick=\"M\"+N(e,1,z)):a>m?(t.dtick=N(e,m,D),t.tick0=s.dateTick0(t.calendar,!0)):a>y?t.dtick=N(e,y,z):a>x?t.dtick=N(e,x,I):a>b?t.dtick=N(e,b,I):(r=n(10),t.dtick=N(e,r,O))}else if(\"log\"===t.type){t.tick0=0;var o=s.simpleMap(t.range,t.r2l);if(e>.7)t.dtick=Math.ceil(e);else if(Math.abs(o[1]-o[0])<1){var l=1.5*Math.abs((o[1]-o[0])/e);e=Math.abs(Math.pow(10,o[1])-Math.pow(10,o[0]))/l,r=n(10),t.dtick=\"L\"+N(e,r,O)}else t.dtick=e>.3?\"D2\":\"D1\"}else\"category\"===t.type||\"multicategory\"===t.type?(t.tick0=0,t.dtick=Math.ceil(Math.max(e,1))):rt(t)?(t.tick0=0,r=1,t.dtick=N(e,r,B)):(t.tick0=0,r=n(10),t.dtick=N(e,r,O));if(0===t.dtick&&(t.dtick=1),!i(t.dtick)&&\"string\"!=typeof t.dtick){var c=t.dtick;throw t.dtick=1,\"ax.dtick error: \"+String(c)}},A.tickIncrement=function(t,e,r,a){var o=r?-1:1;if(i(e))return t+o*e;var l=e.charAt(0),c=o*Number(e.substr(1));if(\"M\"===l)return s.incrementMonth(t,c,a);if(\"L\"===l)return Math.log(Math.pow(10,t)+c)/Math.LN10;if(\"D\"===l){var u=\"D2\"===e?F:R,h=t+.01*o,f=s.roundUp(s.mod(h,1),u,r);return Math.floor(h)+Math.log(n.round(Math.pow(10,f),1))/Math.LN10}throw\"unrecognized dtick \"+String(e)},A.tickFirst=function(t){var e=t.r2l||Number,r=s.simpleMap(t.range,e),a=r[1]<r[0],o=a?Math.floor:Math.ceil,l=1.0001*r[0]-1e-4*r[1],c=t.dtick,u=e(t.tick0);if(i(c)){var h=o((l-u)/c)*c+u;return\"category\"!==t.type&&\"multicategory\"!==t.type||(h=s.constrain(h,0,t._categories.length-1)),h}var f=c.charAt(0),p=Number(c.substr(1));if(\"M\"===f){for(var d,g,v,m=0,y=u;m<10;){if(((d=A.tickIncrement(y,c,a,t.calendar))-l)*(y-l)<=0)return a?Math.min(y,d):Math.max(y,d);g=(l-(y+d)/2)/(d-y),v=f+(Math.abs(Math.round(g))||1)*p,y=A.tickIncrement(y,v,g<0?!a:a,t.calendar),m++}return s.error(\"tickFirst did not converge\",t),y}if(\"L\"===f)return Math.log(o((Math.pow(10,l)-u)/p)*p+u)/Math.LN10;if(\"D\"===f){var x=\"D2\"===c?F:R,b=s.roundUp(s.mod(l,1),x,a);return Math.floor(l)+Math.log(n.round(Math.pow(10,b),1))/Math.LN10}throw\"unrecognized dtick \"+String(c)},A.tickText=function(t,e,r,n){var a,o=U(t,e),l=\"array\"===t.tickmode,c=r||l,u=t.type,h=\"category\"===u?t.d2l_noadd:t.d2l;if(l&&Array.isArray(t.ticktext)){var f=s.simpleMap(t.range,t.r2l),p=Math.abs(f[1]-f[0])/1e4;for(a=0;a<t.ticktext.length&&!(Math.abs(e-h(t.tickvals[a]))<p);a++);if(a<t.ticktext.length)return o.text=String(t.ticktext[a]),o}function d(n){if(void 0===n)return!0;if(r)return\"none\"===n;var i={first:t._tmin,last:t._tmax}[n];return\"all\"!==n&&e!==i}var g=r?\"never\":\"none\"!==t.exponentformat&&d(t.showexponent)?\"hide\":\"\";if(\"date\"===u?function(t,e,r,n){var a=t._tickround,o=r&&t.hoverformat||A.getTickFormat(t);n&&(a=i(a)?4:{y:\"m\",m:\"d\",d:\"M\",M:\"S\",S:4}[a]);var l,c=s.formatDate(e.x,o,a,t._dateFormat,t.calendar,t._extraFormat),u=c.indexOf(\"\\n\");-1!==u&&(l=c.substr(u+1),c=c.substr(0,u));n&&(\"00:00:00\"===c||\"00:00\"===c?(c=l,l=\"\"):8===c.length&&(c=c.replace(/:00$/,\"\")));l&&(r?\"d\"===a?c+=\", \"+l:c=l+(c?\", \"+c:\"\"):t._inCalcTicks&&l===t._prevDateHead||(c+=\"<br>\"+l,t._prevDateHead=l));e.text=c}(t,o,r,c):\"log\"===u?function(t,e,r,n,a){var o=t.dtick,l=e.x,c=t.tickformat,u=\"string\"==typeof o&&o.charAt(0);\"never\"===a&&(a=\"\");n&&\"L\"!==u&&(o=\"L3\",u=\"L\");if(c||\"L\"===u)e.text=G(Math.pow(10,l),t,a,n);else if(i(o)||\"D\"===u&&s.mod(l+.01,1)<.1){var h=Math.round(l),f=Math.abs(h),p=t.exponentformat;\"power\"===p||q(p)&&H(h)?(e.text=0===h?1:1===h?\"10\":\"10<sup>\"+(h>1?\"\":_)+f+\"</sup>\",e.fontSize*=1.25):(\"e\"===p||\"E\"===p)&&f>2?e.text=\"1\"+p+(h>0?\"+\":_)+f:(e.text=G(Math.pow(10,l),t,\"\",\"fakehover\"),\"D1\"===o&&\"y\"===t._id.charAt(0)&&(e.dy-=e.fontSize/6))}else{if(\"D\"!==u)throw\"unrecognized dtick \"+String(o);e.text=String(Math.round(Math.pow(10,s.mod(l,1)))),e.fontSize*=.75}if(\"D1\"===t.dtick){var d=String(e.text).charAt(0);\"0\"!==d&&\"1\"!==d||(\"y\"===t._id.charAt(0)?e.dx-=e.fontSize/4:(e.dy+=e.fontSize/2,e.dx+=(t.range[1]>t.range[0]?1:-1)*e.fontSize*(l<0?.5:.25)))}}(t,o,0,c,g):\"category\"===u?function(t,e){var r=t._categories[Math.round(e.x)];void 0===r&&(r=\"\");e.text=String(r)}(t,o):\"multicategory\"===u?function(t,e,r){var n=Math.round(e.x),i=t._categories[n]||[],a=void 0===i[1]?\"\":String(i[1]),o=void 0===i[0]?\"\":String(i[0]);r?e.text=o+\" - \"+a:(e.text=a,e.text2=o)}(t,o,r):rt(t)?function(t,e,r,n,i){if(\"radians\"!==t.thetaunit||r)e.text=G(e.x,t,i,n);else{var a=e.x/180;if(0===a)e.text=\"0\";else{var o=function(t){function e(t,e){return Math.abs(t-e)<=1e-6}var r=function(t){var r=1;for(;!e(Math.round(t*r)/r,t);)r*=10;return r}(t),n=t*r,i=Math.abs(function t(r,n){return e(n,0)?r:t(n,r%n)}(n,r));return[Math.round(n/i),Math.round(r/i)]}(a);if(o[1]>=100)e.text=G(s.deg2rad(e.x),t,i,n);else{var l=e.x<0;1===o[1]?1===o[0]?e.text=\"\\u03c0\":e.text=o[0]+\"\\u03c0\":e.text=[\"<sup>\",o[0],\"</sup>\",\"\\u2044\",\"<sub>\",o[1],\"</sub>\",\"\\u03c0\"].join(\"\"),l&&(e.text=_+e.text)}}}}(t,o,r,c,g):function(t,e,r,n,i){\"never\"===i?i=\"\":\"all\"===t.showexponent&&Math.abs(e.x/t.dtick)<1e-6&&(i=\"hide\");e.text=G(e.x,t,i,n)}(t,o,0,c,g),n||(t.tickprefix&&!d(t.showtickprefix)&&(o.text=t.tickprefix+o.text),t.ticksuffix&&!d(t.showticksuffix)&&(o.text+=t.ticksuffix)),\"boundaries\"===t.tickson||t.showdividers){var v=function(e){var r=t.l2p(e);return r>=0&&r<=t._length?e:null};o.xbnd=[v(o.x-.5),v(o.x+t.dtick-.5)]}return o},A.hoverLabelText=function(t,e,r){if(r!==w&&r!==e)return A.hoverLabelText(t,e)+\" - \"+A.hoverLabelText(t,r);var n=\"log\"===t.type&&e<=0,i=A.tickText(t,t.c2l(n?-e:e),\"hover\").text;return n?0===e?\"0\":_+i:i};var V=[\"f\",\"p\",\"n\",\"\\u03bc\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\"];function q(t){return\"SI\"===t||\"B\"===t}function H(t){return t>14||t<-15}function G(t,e,r,n){var a=t<0,o=e._tickround,l=r||e.exponentformat||\"B\",c=e._tickexponent,u=A.getTickFormat(e),h=e.separatethousands;if(n){var f={exponentformat:l,dtick:\"none\"===e.showexponent?e.dtick:i(t)&&Math.abs(t)||1,range:\"none\"===e.showexponent?e.range.map(e.r2d):[0,t||1]};j(f),o=(Number(f._tickround)||0)+4,c=f._tickexponent,e.hoverformat&&(u=e.hoverformat)}if(u)return e._numFormat(u)(t).replace(/-/g,_);var p,d=Math.pow(10,-o)/2;if(\"none\"===l&&(c=0),(t=Math.abs(t))<d)t=\"0\",a=!1;else{if(t+=d,c&&(t*=Math.pow(10,-c),o+=c),0===o)t=String(Math.floor(t));else if(o<0){t=(t=String(Math.round(t))).substr(0,t.length+o);for(var g=o;g<0;g++)t+=\"0\"}else{var v=(t=String(t)).indexOf(\".\")+1;v&&(t=t.substr(0,v+o).replace(/\\.?0+$/,\"\"))}t=s.numSeparate(t,e._separators,h)}c&&\"hide\"!==l&&(q(l)&&H(c)&&(l=\"power\"),p=c<0?_+-c:\"power\"!==l?\"+\"+c:String(c),\"e\"===l||\"E\"===l?t+=l+p:\"power\"===l?t+=\"\\xd710<sup>\"+p+\"</sup>\":\"B\"===l&&9===c?t+=\"B\":q(l)&&(t+=V[c/3+5]));return a?_+t:t}function Y(t,e){var r=t._id.charAt(0),n=t._tickAngles[e]||0,i=s.deg2rad(n),a=Math.sin(i),o=Math.cos(i),l=0,c=0;return t._selections[e].each(function(){var t=J(this),e=h.bBox(t.node()),r=e.width,n=e.height;l=Math.max(l,o*r,a*n),c=Math.max(c,a*r,o*n)}),{x:c,y:l}[r]}function W(t){return[t.text,t.x,t.axInfo,t.font,t.fontSize,t.fontColor].join(\"_\")}function X(t,e){var r,n=t._fullLayout._size,i=e._id.charAt(0),a=e.side;return\"free\"!==e.anchor?r=S.getFromId(t,e.anchor):\"x\"===i?r={_offset:n.t+(1-(e.position||0))*n.h,_length:0}:\"y\"===i&&(r={_offset:n.l+(e.position||0)*n.w,_length:0}),\"top\"===a||\"left\"===a?r._offset:\"bottom\"===a||\"right\"===a?r._offset+r._length:void 0}function Z(t,e){var r=t.l2p(e);return r>1&&r<t._length-1}function J(t){var e=n.select(t),r=e.select(\".text-math-group\");return r.empty()?e.select(\"text\"):r}function K(t){return t._id+\".automargin\"}function $(t){return t._id+\".rangeslider\"}function Q(t,e){for(var r=0;r<e.length;r++)-1===t.indexOf(e[r])&&t.push(e[r])}function tt(t,e,r){var n,i,a=[],o=[],l=t.layout;for(n=0;n<e.length;n++)a.push(A.getFromId(t,e[n]));for(n=0;n<r.length;n++)o.push(A.getFromId(t,r[n]));var c=Object.keys(f),u=[\"anchor\",\"domain\",\"overlaying\",\"position\",\"side\",\"tickangle\",\"editType\"],h=[\"linear\",\"log\"];for(n=0;n<c.length;n++){var p=c[n],d=a[0][p],g=o[0][p],v=!0,m=!1,y=!1;if(\"_\"!==p.charAt(0)&&\"function\"!=typeof d&&-1===u.indexOf(p)){for(i=1;i<a.length&&v;i++){var x=a[i][p];\"type\"===p&&-1!==h.indexOf(d)&&-1!==h.indexOf(x)&&d!==x?m=!0:x!==d&&(v=!1)}for(i=1;i<o.length&&v;i++){var b=o[i][p];\"type\"===p&&-1!==h.indexOf(g)&&-1!==h.indexOf(b)&&g!==b?y=!0:o[i][p]!==g&&(v=!1)}v&&(m&&(l[a[0]._name].type=\"linear\"),y&&(l[o[0]._name].type=\"linear\"),et(l,p,a,o,t._fullLayout._dfltTitle))}}for(n=0;n<t._fullLayout.annotations.length;n++){var _=t._fullLayout.annotations[n];-1!==e.indexOf(_.xref)&&-1!==r.indexOf(_.yref)&&s.swapAttrs(l.annotations[n],[\"?\"])}}function et(t,e,r,n,i){var a,o=s.nestedProperty,l=o(t[r[0]._name],e).get(),c=o(t[n[0]._name],e).get();for(\"title\"===e&&(l&&l.text===i.x&&(l.text=i.y),c&&c.text===i.y&&(c.text=i.x)),a=0;a<r.length;a++)o(t,r[a]._name+\".\"+e).set(c);for(a=0;a<n.length;a++)o(t,n[a]._name+\".\"+e).set(l)}function rt(t){return\"angularaxis\"===t._id}A.getTickFormat=function(t){var e,r,n,i,a,o,s,l;function c(t){return\"string\"!=typeof t?t:Number(t.replace(\"M\",\"\"))*v}function u(t,e){var r=[\"L\",\"D\"];if(typeof t==typeof e){if(\"number\"==typeof t)return t-e;var n=r.indexOf(t.charAt(0)),i=r.indexOf(e.charAt(0));return n===i?Number(t.replace(/(L|D)/g,\"\"))-Number(e.replace(/(L|D)/g,\"\")):n-i}return\"number\"==typeof t?1:-1}function h(t,e){var r=null===e[0],n=null===e[1],i=u(t,e[0])>=0,a=u(t,e[1])<=0;return(r||i)&&(n||a)}if(t.tickformatstops&&t.tickformatstops.length>0)switch(t.type){case\"date\":case\"linear\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&(i=t.dtick,a=n.dtickrange,o=void 0,void 0,void 0,o=c||function(t){return t},s=a[0],l=a[1],(!s&&\"number\"!=typeof s||o(s)<=o(i))&&(!l&&\"number\"!=typeof l||o(l)>=o(i)))){r=n;break}break;case\"log\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&h(t.dtick,n.dtickrange)){r=n;break}}return r?r.value:t.tickformat},A.getSubplots=function(t,e){var r=t._fullLayout._subplots,n=r.cartesian.concat(r.gl2d||[]),i=e?A.findSubplotsWithAxis(n,e):n;return i.sort(function(t,e){var r=t.substr(1).split(\"y\"),n=e.substr(1).split(\"y\");return r[0]===n[0]?+r[1]-+n[1]:+r[0]-+n[0]}),i},A.findSubplotsWithAxis=function(t,e){for(var r=new RegExp(\"x\"===e._id.charAt(0)?\"^\"+e._id+\"y\":e._id+\"$\"),n=[],i=0;i<t.length;i++){var a=t[i];r.test(a)&&n.push(a)}return n},A.makeClipPaths=function(t){var e=t._fullLayout;if(!e._hasOnlyLargeSploms){var r,i,a={_offset:0,_length:e.width,_id:\"\"},o={_offset:0,_length:e.height,_id:\"\"},s=A.list(t,\"x\",!0),l=A.list(t,\"y\",!0),c=[];for(r=0;r<s.length;r++)for(c.push({x:s[r],y:o}),i=0;i<l.length;i++)0===r&&c.push({x:a,y:l[i]}),c.push({x:s[r],y:l[i]});var u=e._clips.selectAll(\".axesclip\").data(c,function(t){return t.x._id+t.y._id});u.enter().append(\"clipPath\").classed(\"axesclip\",!0).attr(\"id\",function(t){return\"clip\"+e._uid+t.x._id+t.y._id}).append(\"rect\"),u.exit().remove(),u.each(function(t){n.select(this).select(\"rect\").attr({x:t.x._offset||0,y:t.y._offset||0,width:t.x._length||1,height:t.y._length||1})})}},A.draw=function(t,e,r){var n=t._fullLayout;\"redraw\"===e&&n._paper.selectAll(\"g.subplot\").each(function(t){var e=t[0],r=n._plots[e],i=r.xaxis,a=r.yaxis;r.xaxislayer.selectAll(\".\"+i._id+\"tick\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"tick2\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick2\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"divider\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"divider\").remove(),r.gridlayer&&r.gridlayer.selectAll(\"path\").remove(),r.zerolinelayer&&r.zerolinelayer.selectAll(\"path\").remove(),n._infolayer.select(\".g-\"+i._id+\"title\").remove(),n._infolayer.select(\".g-\"+a._id+\"title\").remove()});var i=e&&\"redraw\"!==e?e:A.listIds(t);return s.syncOrAsync(i.map(function(e){return function(){if(e){var n=A.getFromId(t,e),i=A.drawOne(t,n,r);return n._r=n.range.slice(),n._rl=s.simpleMap(n._r,n.r2l),i}}}))},A.drawOne=function(t,e,r){var n,i,l;r=r||{},e.setScale();var f=t._fullLayout,p=e._id,d=p.charAt(0),g=A.counterLetter(p),v=e._mainSubplot,m=e._mainLinePosition,y=e._mainMirrorPosition,x=f._plots[v][d+\"axislayer\"],b=e._subplotsWith,_=e._vals=A.calcTicks(e),w=[e.mirror,m,y].join(\"_\");for(n=0;n<_.length;n++)_[n].axInfo=w;if(e.visible){e._selections={},e._tickAngles={};var k,M,S=A.makeTransFn(e);if(\"boundaries\"===e.tickson){var E=function(t,e){var r,n=[],i=function(t,e){var r=t.xbnd[e];null!==r&&n.push(s.extendFlat({},t,{x:r}))};if(e.length){for(r=0;r<e.length;r++)i(e[r],0);i(e[r-1],1)}return n}(0,_);M=A.clipEnds(e,E),k=\"inside\"===e.ticks?M:E}else M=A.clipEnds(e,_),k=\"inside\"===e.ticks?M:_;var C=e._gridVals=M,L=function(t,e){var r,n,i=[],a=function(t,e){var r=t.xbnd[e];null!==r&&i.push(s.extendFlat({},t,{x:r}))};if(t.showdividers&&e.length){for(r=0;r<e.length;r++){var o=e[r];o.text2!==n&&a(o,0),n=o.text2}a(e[r-1],1)}return i}(e,_);if(!f._hasOnlyLargeSploms){var P={};for(n=0;n<b.length;n++){i=b[n];var O=(l=f._plots[i])[g+\"axis\"],z=O._mainAxis._id;if(!P[z]){P[z]=1;var I=\"x\"===d?\"M0,\"+O._offset+\"v\"+O._length:\"M\"+O._offset+\",0h\"+O._length;A.drawGrid(t,e,{vals:C,counterAxis:O,layer:l.gridlayer.select(\".\"+p),path:I,transFn:S}),A.drawZeroLine(t,e,{counterAxis:O,layer:l.zerolinelayer,path:I,transFn:S})}}}var D=A.getTickSigns(e),R=[];if(e.ticks){var F,B,N,j=A.makeTickPath(e,m,D[2]);if(e._anchorAxis&&e.mirror&&!0!==e.mirror?(F=A.makeTickPath(e,y,D[3]),B=j+F):(F=\"\",B=j),e.showdividers&&\"outside\"===e.ticks&&\"boundaries\"===e.tickson){var V={};for(n=0;n<L.length;n++)V[L[n].x]=1;N=function(t){return V[t.x]?F:B}}else N=B;A.drawTicks(t,e,{vals:k,layer:x,path:N,transFn:S}),R=Object.keys(e._linepositions||{})}for(n=0;n<R.length;n++){i=R[n],l=f._plots[i];var q=e._linepositions[i]||[],H=A.makeTickPath(e,q[0],D[0])+A.makeTickPath(e,q[1],D[1]);A.drawTicks(t,e,{vals:k,layer:l[d+\"axislayer\"],path:H,transFn:S})}var G=[];if(G.push(function(){return A.drawLabels(t,e,{vals:_,layer:x,transFn:S,labelFns:A.makeLabelFns(e,m)})}),\"multicategory\"===e.type){var Z=0,J={x:2,y:10}[d],Q=D[2]*(\"inside\"===e.ticks?-1:1);G.push(function(){return Z+=Y(e,p+\"tick\")+J,Z+=e._tickAngles[p+\"tick\"]?e.tickfont.size*T:0,A.drawLabels(t,e,{vals:function(t,e){for(var r=[],n={},i=0;i<e.length;i++){var a=e[i];n[a.text2]?n[a.text2].push(a.x):n[a.text2]=[a.x]}for(var o in n)r.push(U(t,s.interp(n[o],.5),o));return r}(e,_),layer:x,cls:p+\"tick2\",repositionOnUpdate:!0,secondary:!0,transFn:S,labelFns:A.makeLabelFns(e,m+Z*Q)})}),G.push(function(){return Z+=Y(e,p+\"tick2\"),e._labelLength=Z,function(t,e,r){var n=e._id+\"divider\",i=r.vals,a=r.layer.selectAll(\"path.\"+n).data(i,W);a.exit().remove(),a.enter().insert(\"path\",\":first-child\").classed(n,1).classed(\"crisp\",1).call(u.stroke,e.dividercolor).style(\"stroke-width\",h.crispRound(t,e.dividerwidth,1)+\"px\"),a.attr(\"transform\",r.transFn).attr(\"d\",r.path)}(t,e,{vals:L,layer:x,path:A.makeTickPath(e,m,Q,Z),transFn:S})})}var tt=o.getComponentMethod(\"rangeslider\",\"isVisible\")(e);return G.push(function(){if(e.showticklabels){var r=t.getBoundingClientRect(),n=x.node().getBoundingClientRect();e._boundingBox={width:n.width,height:n.height,left:n.left-r.left,right:n.right-r.left,top:n.top-r.top,bottom:n.bottom-r.top}}else{var i,a=f._size;\"x\"===d?(i=\"free\"===e.anchor?a.t+a.h*(1-e.position):a.t+a.h*(1-e._anchorAxis.domain[{bottom:0,top:1}[e.side]]),e._boundingBox={top:i,bottom:i,left:e._offset,right:e._offset+e._length,width:e._length,height:0}):(i=\"free\"===e.anchor?a.l+a.w*e.position:a.l+a.w*e._anchorAxis.domain[{left:0,right:1}[e.side]],e._boundingBox={left:i,right:i,bottom:e._offset+e._length,top:e._offset,height:e._length,width:0})}if(b){for(var o=e._counterSpan=[1/0,-1/0],s=0;s<b.length;s++){var l=f._plots[b[s]][\"x\"===d?\"yaxis\":\"xaxis\"];et(o,[l._offset,l._offset+l._length])}\"free\"===e.anchor&&et(o,\"x\"===d?[e._boundingBox.bottom,e._boundingBox.top]:[e._boundingBox.right,e._boundingBox.left])}},function(){var r,n,i=e.side.charAt(0);if(tt&&(n=o.getComponentMethod(\"rangeslider\",\"autoMarginOpts\")(t,e)),a.autoMargin(t,$(e),n),e.automargin&&(!tt||\"b\"!==i)){r={x:0,y:0,r:0,l:0,t:0,b:0};var s,l,c=e._boundingBox,u=X(t,e);switch(d+i){case\"xb\":s=0,l=c.top-u,r[i]=c.height;break;case\"xt\":s=1,l=u-c.bottom,r[i]=c.height;break;case\"yl\":s=0,l=u-c.right,r[i]=c.width;break;case\"yr\":s=1,l=c.left-u,r[i]=c.width}if(r[g]=\"free\"===e.anchor?e.position:e._anchorAxis.domain[s],r[i]>0&&(r[i]+=l),e.title.text!==f._dfltTitle[d]&&(r[i]+=e.title.font.size),\"x\"===d&&c.width>0){var h=c.right-(e._offset+e._length);h>0&&(r.x=1,r.r=h);var p=e._offset-c.left;p>0&&(r.x=0,r.l=p)}else if(\"y\"===d&&c.height>0){var v=c.bottom-(e._offset+e._length);v>0&&(r.y=0,r.b=v);var m=e._offset-c.top;m>0&&(r.y=1,r.t=m)}}a.autoMargin(t,K(e),r)}),r.skipTitle||tt&&e._boundingBox&&\"bottom\"===e.side||G.push(function(){return function(t,e){var r,n=t._fullLayout,i=e._id,a=i.charAt(0),o=e.title.font.size;if(\"multicategory\"===e.type)r=e._labelLength;else{r=10+1.5*o+(e.linewidth?e.linewidth-1:0)}var s,l,u,f,p=X(t,e);\"x\"===a?(l=e._offset+e._length/2,u=\"top\"===e.side?-r-o*(e.showticklabels?1:0):r+o*(e.showticklabels?1.5:.5),u+=p):(u=e._offset+e._length/2,l=\"right\"===e.side?r+o*(e.showticklabels?1:.5):-r-o*(e.showticklabels?.5:0),l+=p,s={rotate:\"-90\",offset:0});if(\"multicategory\"!==e.type){var d=e._selections[e._id+\"tick\"];if(f={selection:d,side:e.side},d&&d.node()&&d.node().parentNode){var g=h.getTranslate(d.node().parentNode);f.offsetLeft=g.x,f.offsetTop=g.y}}return c.draw(t,i+\"title\",{propContainer:e,propName:e._name+\".title.text\",placeholder:n._dfltTitle[a],avoid:f,transform:s,attributes:{x:l,y:u,\"text-anchor\":\"middle\"}})}(t,e)}),s.syncOrAsync(G)}function et(t,e){t[0]=Math.min(t[0],e[0]),t[1]=Math.max(t[1],e[1])}},A.getTickSigns=function(t){var e=t._id.charAt(0),r={x:\"top\",y:\"right\"}[e],n=t.side===r?1:-1,i=[-1,1,n,-n];return\"inside\"!==t.ticks==(\"x\"===e)&&(i=i.map(function(t){return-t})),i},A.makeTransFn=function(t){var e=t._id.charAt(0),r=t._offset;return\"x\"===e?function(e){return\"translate(\"+(r+t.l2p(e.x))+\",0)\"}:function(e){return\"translate(0,\"+(r+t.l2p(e.x))+\")\"}},A.makeTickPath=function(t,e,r,n){n=void 0!==n?n:t.ticklen;var i=t._id.charAt(0),a=(t.linewidth||1)/2;return\"x\"===i?\"M0,\"+(e+a*r)+\"v\"+n*r:\"M\"+(e+a*r)+\",0h\"+n*r},A.makeLabelFns=function(t,e,r){var n=t._id.charAt(0),a=\"boundaries\"!==t.tickson&&\"outside\"===t.ticks,o=0,l=0;if(a&&(o+=t.ticklen),r&&\"outside\"===t.ticks){var c=s.deg2rad(r);o=t.ticklen*Math.cos(c)+1,l=t.ticklen*Math.sin(c)}t.showticklabels&&(a||t.showline)&&(o+=.2*t.tickfont.size);var u,h,f,p,d={labelStandoff:o+=(t.linewidth||1)/2,labelShift:l};return\"x\"===n?(p=\"bottom\"===t.side?1:-1,u=l*p,h=e+o*p,f=\"bottom\"===t.side?1:-.2,d.xFn=function(t){return t.dx+u},d.yFn=function(t){return t.dy+h+t.fontSize*f},d.anchorFn=function(t,e){return i(e)&&0!==e&&180!==e?e*p<0?\"end\":\"start\":\"middle\"},d.heightFn=function(e,r,n){return r<-60||r>60?-.5*n:\"top\"===t.side?-n:0}):\"y\"===n&&(p=\"right\"===t.side?1:-1,u=o,h=-l*p,f=90===Math.abs(t.tickangle)?.5:0,d.xFn=function(t){return t.dx+e+(u+t.fontSize*f)*p},d.yFn=function(t){return t.dy+h+t.fontSize*k},d.anchorFn=function(e,r){return i(r)&&90===Math.abs(r)?\"middle\":\"right\"===t.side?\"start\":\"end\"},d.heightFn=function(e,r,n){return(r*=\"left\"===t.side?1:-1)<-30?-n:r<30?-.5*n:0}),d},A.drawTicks=function(t,e,r){r=r||{};var n=e._id+\"tick\",i=r.layer.selectAll(\"path.\"+n).data(e.ticks?r.vals:[],W);i.exit().remove(),i.enter().append(\"path\").classed(n,1).classed(\"ticks\",1).classed(\"crisp\",!1!==r.crisp).call(u.stroke,e.tickcolor).style(\"stroke-width\",h.crispRound(t,e.tickwidth,1)+\"px\").attr(\"d\",r.path),i.attr(\"transform\",r.transFn)},A.drawGrid=function(t,e,r){r=r||{};var n=e._id+\"grid\",i=r.vals,a=r.counterAxis;if(!1===e.showgrid)i=[];else if(a&&A.shouldShowZeroLine(t,e,a))for(var o=\"array\"===e.tickmode,s=0;s<i.length;s++){var l=i[s].x;if(o?!l:Math.abs(l)<e.dtick/100){if(i=i.slice(0,s).concat(i.slice(s+1)),!o)break;s--}}var c=r.layer.selectAll(\"path.\"+n).data(i,W);c.exit().remove(),c.enter().append(\"path\").classed(n,1).classed(\"crisp\",!1!==r.crisp),e._gw=h.crispRound(t,e.gridwidth,1),c.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(u.stroke,e.gridcolor||\"#ddd\").style(\"stroke-width\",e._gw+\"px\"),\"function\"==typeof r.path&&c.attr(\"d\",r.path)},A.drawZeroLine=function(t,e,r){r=r||r;var n=e._id+\"zl\",i=A.shouldShowZeroLine(t,e,r.counterAxis),a=r.layer.selectAll(\"path.\"+n).data(i?[{x:0,id:e._id}]:[]);a.exit().remove(),a.enter().append(\"path\").classed(n,1).classed(\"zl\",1).classed(\"crisp\",!1!==r.crisp).each(function(){r.layer.selectAll(\"path\").sort(function(t,e){return S.idSort(t.id,e.id)})}),a.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(u.stroke,e.zerolinecolor||u.defaultLine).style(\"stroke-width\",h.crispRound(t,e.zerolinewidth,e._gw||1)+\"px\")},A.drawLabels=function(t,e,r){r=r||{};var a=e._id,o=a.charAt(0),c=r.cls||a+\"tick\",u=r.vals,f=r.labelFns,p=r.secondary?0:e.tickangle,d=(e._tickAngles||{})[c],g=r.layer.selectAll(\"g.\"+c).data(e.showticklabels?u:[],W),v=[];function m(t,e){t.each(function(t){var a=n.select(this),o=a.select(\".text-math-group\"),s=f.anchorFn(t,e),c=r.transFn.call(a.node(),t)+(i(e)&&0!=+e?\" rotate(\"+e+\",\"+f.xFn(t)+\",\"+(f.yFn(t)-t.fontSize/2)+\")\":\"\"),u=l.lineCount(a),p=T*t.fontSize,d=f.heightFn(t,i(e)?+e:0,(u-1)*p);if(d&&(c+=\" translate(0, \"+d+\")\"),o.empty())a.select(\"text\").attr({transform:c,\"text-anchor\":s});else{var g=h.bBox(o.node()).width*{end:-.5,start:.5}[s];o.attr(\"transform\",c+(g?\"translate(\"+g+\",0)\":\"\"))}})}g.enter().append(\"g\").classed(c,1).append(\"text\").attr(\"text-anchor\",\"middle\").each(function(e){var r=n.select(this),i=t._promises.length;r.call(l.positionText,f.xFn(e),f.yFn(e)).call(h.font,e.font,e.fontSize,e.fontColor).text(e.text).call(l.convertToTspans,t),t._promises[i]?v.push(t._promises.pop().then(function(){m(r,p)})):m(r,p)}),g.exit().remove(),r.repositionOnUpdate&&g.each(function(t){n.select(this).select(\"text\").call(l.positionText,f.xFn(t),f.yFn(t))}),m(g,d||p),e._selections&&(e._selections[c]=g);var y=s.syncOrAsync([function(){return v.length&&Promise.all(v)},function(){m(g,p);var t=null;if(u.length&&\"x\"===o&&!i(p)&&(\"log\"!==e.type||\"D\"!==String(e.dtick).charAt(0))){t=0;var n,a=0,l=[];if(g.each(function(t){a=Math.max(a,t.fontSize);var r=e.l2p(t.x),n=J(this),i=h.bBox(n.node());l.push({top:0,bottom:10,height:10,left:r-i.width/2,right:r+i.width/2+2,width:i.width+2})}),\"boundaries\"!==e.tickson&&!e.showdividers||r.secondary){var f=u.length,d=Math.abs((u[f-1].x-u[0].x)*e._m)/(f-1)<2.5*a||\"multicategory\"===e.type;for(n=0;n<l.length-1;n++)if(s.bBoxIntersect(l[n],l[n+1])){t=d?90:30;break}}else{var v=2;for(e.ticks&&(v+=e.tickwidth/2),n=0;n<l.length;n++){var y=u[n].xbnd,x=l[n];if(null!==y[0]&&x.left-e.l2p(y[0])<v||null!==y[1]&&e.l2p(y[1])-x.right<v){t=90;break}}}t&&m(g,t)}e._tickAngles&&(e._tickAngles[c]=null===t?i(p)?p:0:t)}]);return y&&y.then&&t._promises.push(y),y},A.shouldShowZeroLine=function(t,e,r){var n=s.simpleMap(e.range,e.r2l);return n[0]*n[1]<=0&&e.zeroline&&(\"linear\"===e.type||\"-\"===e.type)&&e._gridVals.length&&(Z(e,0)||!function(t,e,r,n){var i=r._mainAxis;if(!i)return;var a=t._fullLayout,o=e._id.charAt(0),s=A.counterLetter(e._id),l=e._offset+(Math.abs(n[0])<Math.abs(n[1])==(\"x\"===o)?0:e._length);function c(t){if(!t.showline||!t.linewidth)return!1;var r=Math.max((t.linewidth+e.zerolinewidth)/2,1);function n(t){return\"number\"==typeof t&&Math.abs(t-l)<r}if(n(t._mainLinePosition)||n(t._mainMirrorPosition))return!0;var i=t._linepositions||{};for(var a in i)if(n(i[a][0])||n(i[a][1]))return!0}var u=a._plots[r._mainSubplot];if(!(u.mainplotinfo||u).overlays.length)return c(r);for(var h=A.list(t,s),f=0;f<h.length;f++){var p=h[f];if(p._mainAxis===i&&c(p))return!0}}(t,e,r,n)||function(t,e){for(var r=t._fullData,n=e._mainSubplot,i=e._id.charAt(0),a=0;a<r.length;a++){var s=r[a];if(!0===s.visible&&s.xaxis+s.yaxis===n){if(o.traceIs(s,\"bar-like\")&&s.orientation==={x:\"h\",y:\"v\"}[i])return!0;if(s.fill&&s.fill.charAt(s.fill.length-1)===i)return!0}}return!1}(t,e))},A.clipEnds=function(t,e){return e.filter(function(e){return Z(t,e.x)})},A.allowAutoMargin=function(t){for(var e=A.list(t,\"\",!0),r=0;r<e.length;r++){var n=e[r];n.automargin&&a.allowAutoMargin(t,K(n)),o.getComponentMethod(\"rangeslider\",\"isVisible\")(n)&&a.allowAutoMargin(t,$(n))}},A.swap=function(t,e){for(var r=function(t,e){var r,n,i=[];for(r=0;r<e.length;r++){var a=[],o=t._fullData[e[r]].xaxis,s=t._fullData[e[r]].yaxis;if(o&&s){for(n=0;n<i.length;n++)-1===i[n].x.indexOf(o)&&-1===i[n].y.indexOf(s)||a.push(n);if(a.length){var l,c=i[a[0]];if(a.length>1)for(n=1;n<a.length;n++)l=i[a[n]],Q(c.x,l.x),Q(c.y,l.y);Q(c.x,[o]),Q(c.y,[s])}else i.push({x:[o],y:[s]})}}return i}(t,e),n=0;n<r.length;n++)tt(t,r[n].x,r[n].y)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../components/titles\":681,\"../../constants/alignment\":688,\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/plots\":828,\"../../registry\":847,\"./autorange\":766,\"./axis_autotype\":768,\"./axis_ids\":770,\"./clean_ticks\":772,\"./layout_attributes\":779,\"./set_convert\":785,d3:163,\"fast-isnumeric\":225}],768:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){return!(r=r||{}).noMultiCategory&&(o=t,i.isArrayOrTypedArray(o[0])&&i.isArrayOrTypedArray(o[1]))?\"multicategory\":function(t,e){for(var r=Math.max(1,(t.length-1)/1e3),a=0,o=0,s={},l=0;l<t.length;l+=r){var c=t[Math.round(l)],u=String(c);s[u]||(s[u]=1,i.isDateTime(c,e)&&(a+=1),n(c)&&(o+=1))}return a>2*o}(t,e)?\"date\":function(t){for(var e=Math.max(1,(t.length-1)/1e3),r=0,n=0,o={},s=0;s<t.length;s+=e){var l=t[Math.round(s)],c=String(l);o[c]||(o[c]=1,\"boolean\"==typeof l?n++:i.cleanNumber(l)!==a?r++:\"string\"==typeof l&&n++)}return n>2*r}(t)?\"category\":function(t){if(!t)return!1;for(var e=0;e<t.length;e++)if(n(t[e]))return!0;return!1}(t)?\"linear\":\"-\";var o}},{\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],769:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./layout_attributes\"),o=t(\"./tick_value_defaults\"),s=t(\"./tick_mark_defaults\"),l=t(\"./tick_label_defaults\"),c=t(\"./category_order_defaults\"),u=t(\"./line_grid_defaults\"),h=t(\"./set_convert\");e.exports=function(t,e,r,f,p){var d=f.letter,g=f.font||{},v=f.splomStash||{},m=r(\"visible\",!f.visibleDflt),y=e.type;\"date\"===y&&n.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",f.calendar);h(e,p);var x=!e.isValidRange(t.range);x&&f.reverseDflt&&(x=\"reversed\"),!r(\"autorange\",x)||\"linear\"!==y&&\"-\"!==y||r(\"rangemode\"),r(\"range\"),e.cleanRange(),c(t,e,r,f),\"category\"===y||f.noHover||r(\"hoverformat\");var b=r(\"color\"),_=b!==a.color.dflt?b:g.color,w=v.label||p._dfltTitle[d];if(l(t,e,r,y,f,{pass:1}),!m)return e;r(\"title.text\",w),i.coerceFont(r,\"title.font\",{family:g.family,size:Math.round(1.2*g.size),color:_}),o(t,e,r,y),l(t,e,r,y,f,{pass:2}),s(t,e,r,f),u(t,e,r,{dfltColor:b,bgColor:f.bgColor,showGrid:f.showGrid,attributes:a}),(e.showline||e.ticks)&&r(\"mirror\"),f.automargin&&r(\"automargin\");var k,T=\"multicategory\"===e.type;f.noTickson||\"category\"!==e.type&&!T||!e.ticks&&!e.showgrid||(T&&(k=\"boundaries\"),r(\"tickson\",k));T&&(r(\"showdividers\")&&(r(\"dividercolor\"),r(\"dividerwidth\")));return e}},{\"../../lib\":719,\"../../registry\":847,\"./category_order_defaults\":771,\"./layout_attributes\":779,\"./line_grid_defaults\":781,\"./set_convert\":785,\"./tick_label_defaults\":786,\"./tick_mark_defaults\":787,\"./tick_value_defaults\":788}],770:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./constants\");r.id2name=function(t){if(\"string\"==typeof t&&t.match(i.AX_ID_PATTERN)){var e=t.substr(1);return\"1\"===e&&(e=\"\"),t.charAt(0)+\"axis\"+e}},r.name2id=function(t){if(t.match(i.AX_NAME_PATTERN)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),t.charAt(0)+e}},r.cleanId=function(t,e){if(t.match(i.AX_ID_PATTERN)&&(!e||t.charAt(0)===e)){var r=t.substr(1).replace(/^0+/,\"\");return\"1\"===r&&(r=\"\"),t.charAt(0)+r}},r.list=function(t,e,n){var i=t._fullLayout;if(!i)return[];var a,o=r.listIds(t,e),s=new Array(o.length);for(a=0;a<o.length;a++){var l=o[a];s[a]=i[l.charAt(0)+\"axis\"+l.substr(1)]}if(!n){var c=i._subplots.gl3d||[];for(a=0;a<c.length;a++){var u=i[c[a]];e?s.push(u[e+\"axis\"]):s.push(u.xaxis,u.yaxis,u.zaxis)}}return s},r.listIds=function(t,e){var r=t._fullLayout;if(!r)return[];var n=r._subplots;return e?n[e+\"axis\"]:n.xaxis.concat(n.yaxis)},r.getFromId=function(t,e,n){var i=t._fullLayout;return\"x\"===n?e=e.replace(/y[0-9]*/,\"\"):\"y\"===n&&(e=e.replace(/x[0-9]*/,\"\")),i[r.id2name(e)]},r.getFromTrace=function(t,e,i){var a=t._fullLayout,o=null;if(n.traceIs(e,\"gl3d\")){var s=e.scene;\"scene\"===s.substr(0,5)&&(o=a[s][i+\"axis\"])}else o=r.getFromId(t,e[i+\"axis\"]||i);return o},r.idSort=function(t,e){var r=t.charAt(0),n=e.charAt(0);return r!==n?r>n?1:-1:+(t.substr(1)||1)-+(e.substr(1)||1)},r.getAxisGroup=function(t,e){for(var r=t._axisMatchGroups,n=0;n<r.length;n++){if(r[n][e])return\"g\"+n}return e}},{\"../../registry\":847,\"./constants\":773}],771:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){if(\"category\"===e.type){var i,a=t.categoryarray,o=Array.isArray(a)&&a.length>0;o&&(i=\"array\");var s,l=r(\"categoryorder\",i);\"array\"===l&&(s=r(\"categoryarray\")),o||\"array\"!==l||(l=e.categoryorder=\"trace\"),\"trace\"===l?e._initialCategories=[]:\"array\"===l?e._initialCategories=s.slice():(s=function(t,e){var r,n,i,a=e.dataAttr||t._id.charAt(0),o={};if(e.axData)r=e.axData;else for(r=[],n=0;n<e.data.length;n++){var s=e.data[n];s[a+\"axis\"]===t._id&&r.push(s)}for(n=0;n<r.length;n++){var l=r[n][a];for(i=0;i<l.length;i++){var c=l[i];null!=c&&(o[c]=1)}}return Object.keys(o)}(e,n).sort(),\"category ascending\"===l?e._initialCategories=s:\"category descending\"===l&&(e._initialCategories=s.reverse()))}}},{}],772:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").ONEDAY;r.dtick=function(t,e){var r=\"log\"===e,i=\"date\"===e,o=\"category\"===e,s=i?a:1;if(!t)return s;if(n(t))return(t=Number(t))<=0?s:o?Math.max(1,Math.round(t)):i?Math.max(.1,t):t;if(\"string\"!=typeof t||!i&&!r)return s;var l=t.charAt(0),c=t.substr(1);return(c=n(c)?Number(c):0)<=0||!(i&&\"M\"===l&&c===Math.round(c)||r&&\"L\"===l||r&&\"D\"===l&&(1===c||2===c))?s:t},r.tick0=function(t,e,r,a){return\"date\"===e?i.cleanDate(t,i.dateTick0(r)):\"D1\"!==a&&\"D2\"!==a?n(t)?Number(t):0:void 0}},{\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],773:[function(t,e,r){\"use strict\";var n=t(\"../../lib/regex\").counter;e.exports={idRegex:{x:n(\"x\"),y:n(\"y\")},attrRegex:n(\"[xy]axis\"),xAxisMatch:n(\"xaxis\"),yAxisMatch:n(\"yaxis\"),AX_ID_PATTERN:/^[xyz][0-9]*$/,AX_NAME_PATTERN:/^[xyz]axis[0-9]*$/,SUBPLOT_PATTERN:/^x([0-9]*)y([0-9]*)$/,MINDRAG:8,MINSELECT:12,MINZOOM:20,DRAGGERSIZE:20,BENDPX:1.5,REDRAWDELAY:50,SELECTDELAY:100,SELECTID:\"-select\",DFLTRANGEX:[-1,6],DFLTRANGEY:[-1,4],traceLayerClasses:[\"heatmaplayer\",\"contourcarpetlayer\",\"contourlayer\",\"funnellayer\",\"waterfalllayer\",\"barlayer\",\"carpetlayer\",\"violinlayer\",\"boxlayer\",\"ohlclayer\",\"scattercarpetlayer\",\"scatterlayer\"],clipOnAxisFalseQuery:[\".scatterlayer\",\".barlayer\",\".funnellayer\",\".waterfalllayer\"],layerValue2layerClass:{\"above traces\":\"above\",\"below traces\":\"below\"}}},{\"../../lib/regex\":735}],774:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./axis_ids\").id2name,a=t(\"./scale_zoom\"),o=t(\"./autorange\").makePadFn,s=t(\"./autorange\").concatExtremes,l=t(\"../../constants/numerical\").ALMOST_EQUAL,c=t(\"../../constants/alignment\").FROM_BL;function u(t,e,r,n,a){var o,s,l,c,u=\"range\"!==a,h=n[i(e)].type,f=[];for(s=0;s<r.length;s++)if((l=r[s])!==e&&(c=n[i(l)]).type===h)if(c.fixedrange){if(u&&c.anchor){n[i(c.anchor)].fixedrange&&f.push(l)}}else f.push(l);for(o=0;o<t.length;o++)if(t[o][e]){var p=t[o],d=[];for(s=0;s<f.length;s++)p[l=f[s]]||d.push(l);return{linkableAxes:d,thisGroup:p}}return{linkableAxes:f,thisGroup:null}}function h(t,e,r,n,i){var a,o,s,l,c;null===e?((e={})[r]=1,c=t.length,t.push(e)):c=t.indexOf(e);var u=Object.keys(e);for(a=0;a<t.length;a++)if(s=t[a],a!==c&&s[n]){var h=s[n];for(o=0;o<u.length;o++)s[l=u[o]]=h*i*e[l];return void t.splice(c,1)}if(1!==i)for(o=0;o<u.length;o++)e[u[o]]*=i;e[n]=1}function f(t,e){var r=t._inputDomain,n=c[t.constraintoward],i=r[0]+(r[1]-r[0])*n;t.domain=t._input.domain=[i+(r[0]-i)/e,i+(r[1]-i)/e],t.setScale()}r.handleConstraintDefaults=function(t,e,r,i,a){var o,s,l,c,f=a._axisConstraintGroups,p=a._axisMatchGroups,d=e._id,g=d.charAt(0),v=((a._splomAxes||{})[g]||{})[d]||{},m=e._id,y=m.charAt(0),x=r(\"constrain\");if(n.coerce(t,e,{constraintoward:{valType:\"enumerated\",values:\"x\"===y?[\"left\",\"center\",\"right\"]:[\"bottom\",\"middle\",\"top\"],dflt:\"x\"===y?\"center\":\"middle\"}},\"constraintoward\"),!t.matches&&!v.matches||e.fixedrange||(s=u(p,m,i,a),o=n.coerce(t,e,{matches:{valType:\"enumerated\",values:s.linkableAxes||[],dflt:v.matches}},\"matches\")),o||!t.scaleanchor||e.fixedrange&&\"domain\"!==x||(c=u(f,m,i,a,x),l=n.coerce(t,e,{scaleanchor:{valType:\"enumerated\",values:c.linkableAxes||[]}},\"scaleanchor\")),o?(delete e.constrain,h(p,s.thisGroup,m,o,1)):-1!==i.indexOf(t.matches)&&n.warn(\"ignored \"+e._name+'.matches: \"'+t.matches+'\" to avoid either an infinite loop or because the target axis has fixed range.'),l){var b=r(\"scaleratio\");b||(b=e.scaleratio=1),h(f,c.thisGroup,m,l,b)}else-1!==i.indexOf(t.scaleanchor)&&n.warn(\"ignored \"+e._name+'.scaleanchor: \"'+t.scaleanchor+'\" to avoid either an infinite loop and possibly inconsistent scaleratios, or because the target axis has fixed range or this axis declares a *matches* constraint.')},r.enforce=function(t){var e,r,n,c,u,h,p,d=t._fullLayout,g=d._axisConstraintGroups||[];for(e=0;e<g.length;e++){var v=g[e],m=Object.keys(v),y=1/0,x=0,b=1/0,_={},w={},k=!1;for(r=0;r<m.length;r++)w[n=m[r]]=c=d[i(n)],c._inputDomain?c.domain=c._inputDomain.slice():c._inputDomain=c.domain.slice(),c._inputRange||(c._inputRange=c.range.slice()),c.setScale(),_[n]=u=Math.abs(c._m)/v[n],y=Math.min(y,u),\"domain\"!==c.constrain&&c._constraintShrinkable||(b=Math.min(b,u)),delete c._constraintShrinkable,x=Math.max(x,u),\"domain\"===c.constrain&&(k=!0);if(!(y>l*x)||k)for(r=0;r<m.length;r++)if(u=_[n=m[r]],h=(c=w[n]).constrain,u!==b||\"domain\"===h)if(p=u/b,\"range\"===h)a(c,p);else{var T=c._inputDomain,A=(c.domain[1]-c.domain[0])/(T[1]-T[0]),M=(c.r2l(c.range[1])-c.r2l(c.range[0]))/(c.r2l(c._inputRange[1])-c.r2l(c._inputRange[0]));if((p/=A)*M<1){c.domain=c._input.domain=T.slice(),a(c,p);continue}if(M<1&&(c.range=c._input.range=c._inputRange.slice(),p*=M),c.autorange){var S=c.r2l(c.range[0]),E=c.r2l(c.range[1]),C=(S+E)/2,L=C,P=C,O=Math.abs(E-C),z=C-O*p*1.0001,I=C+O*p*1.0001,D=o(c);f(c,p);var R,F,B=Math.abs(c._m),N=s(t,c),j=N.min,U=N.max;for(F=0;F<j.length;F++)(R=j[F].val-D(j[F])/B)>z&&R<L&&(L=R);for(F=0;F<U.length;F++)(R=U[F].val+D(U[F])/B)<I&&R>P&&(P=R);p/=(P-L)/(2*O),L=c.l2r(L),P=c.l2r(P),c.range=c._input.range=S<E?[L,P]:[P,L]}f(c,p)}}},r.clean=function(t,e){if(e._inputDomain){for(var r=!1,n=e._id,i=t._fullLayout._axisConstraintGroups,a=0;a<i.length;a++)if(i[a][n]){r=!0;break}r&&\"domain\"===e.constrain||(e._input.domain=e.domain=e._inputDomain,delete e._inputDomain)}}},{\"../../constants/alignment\":688,\"../../constants/numerical\":695,\"../../lib\":719,\"./autorange\":766,\"./axis_ids\":770,\"./scale_zoom\":783}],775:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"has-passive-events\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../components/color\"),u=t(\"../../components/drawing\"),h=t(\"../../components/fx\"),f=t(\"./axes\"),p=t(\"../../lib/setcursor\"),d=t(\"../../components/dragelement\"),g=t(\"../../constants/alignment\").FROM_TL,v=t(\"../../lib/clear_gl_canvases\"),m=t(\"../../plot_api/subroutines\").redrawReglTraces,y=t(\"../plots\"),x=t(\"./axis_ids\").getFromId,b=t(\"./select\").prepSelect,_=t(\"./select\").clearSelect,w=t(\"./select\").selectOnClick,k=t(\"./scale_zoom\"),T=t(\"./constants\"),A=T.MINDRAG,M=T.MINZOOM,S=!0;function E(t,e,r,n){var i=s.ensureSingle(t.draglayer,e,r,function(e){e.classed(\"drag\",!0).style({fill:\"transparent\",\"stroke-width\":0}).attr(\"data-subplot\",t.id)});return i.call(p,n),i.node()}function C(t,e,r,i,a,o,s){var l=E(t,\"rect\",e,r);return n.select(l).call(u.setRect,i,a,o,s),l}function L(t,e){for(var r=0;r<t.length;r++)if(!t[r].fixedrange)return e;return\"\"}function P(t,e,r,n,i){for(var a=0;a<t.length;a++){var o=t[a];if(!o.fixedrange){var s=o._rl[0],l=o._rl[1]-s;n[o._name+\".range[0]\"]=o.l2r(s+l*e),n[o._name+\".range[1]\"]=o.l2r(s+l*r)}}if(i&&i.length){var c=(e+(1-r))/2;P(i,c,1-c,n,[])}}function O(t,e){for(var r=0;r<t.length;r++){var n=t[r];n.fixedrange||(n.range=[n.l2r(n._rl[0]-e/n._m),n.l2r(n._rl[1]-e/n._m)])}}function z(t){return 1-(t>=0?Math.min(t,.9):1/(1/Math.max(t,-.3)+3.222))}function I(t,e,r,n,i){return t.append(\"path\").attr(\"class\",\"zoombox\").style({fill:e>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"transform\",\"translate(\"+r+\", \"+n+\")\").attr(\"d\",i+\"Z\")}function D(t,e,r){return t.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:c.background,stroke:c.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"transform\",\"translate(\"+e+\", \"+r+\")\").attr(\"d\",\"M0,0Z\")}function R(t,e,r,n,i,a){t.attr(\"d\",n+\"M\"+r.l+\",\"+r.t+\"v\"+r.h+\"h\"+r.w+\"v-\"+r.h+\"h-\"+r.w+\"Z\"),F(t,e,i,a)}function F(t,e,r,n){r||(t.transition().style(\"fill\",n>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),e.transition().style(\"opacity\",1).duration(200))}function B(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}function N(t){S&&t.data&&t._context.showTips&&(s.notifier(s._(t,\"Double-click to zoom back out\"),\"long\"),S=!1)}function j(t){return\"lasso\"===t||\"select\"===t}function U(t){var e=Math.floor(Math.min(t.b-t.t,t.r-t.l,M)/2);return\"M\"+(t.l-3.5)+\",\"+(t.t-.5+e)+\"h3v\"+-e+\"h\"+e+\"v-3h-\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.t-.5+e)+\"h-3v\"+-e+\"h\"+-e+\"v-3h\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.b+.5-e)+\"h-3v\"+e+\"h\"+-e+\"v3h\"+(e+3)+\"ZM\"+(t.l-3.5)+\",\"+(t.b+.5-e)+\"h3v\"+e+\"h\"+e+\"v3h-\"+(e+3)+\"Z\"}function V(t,e,r,n){for(var i,a,o,l,c=!1,u={},h={},f=0;f<e.length;f++){var p=e[f];for(i in r)if(p[i]){for(o in p)(\"x\"===o.charAt(0)?r:n)[o]||(u[o]=i);for(a in n)p[a]&&(c=!0)}for(a in n)if(p[a])for(l in p)(\"x\"===l.charAt(0)?r:n)[l]||(h[l]=a)}c&&(s.extendFlat(u,h),h={});var d={},g=[];for(o in u){var v=x(t,o);g.push(v),d[v._id]=v}var m={},y=[];for(l in h){var b=x(t,l);y.push(b),m[b._id]=b}return{xaHash:d,yaHash:m,xaxes:g,yaxes:y,xLinks:u,yLinks:h,isSubplotConstrained:c}}function q(t,e){if(a){var r=void 0!==t.onwheel?\"wheel\":\"mousewheel\";t._onwheel&&t.removeEventListener(r,t._onwheel),t._onwheel=e,t.addEventListener(r,e,{passive:!1})}else void 0!==t.onwheel?t.onwheel=e:void 0!==t.onmousewheel&&(t.onmousewheel=e)}function H(t){var e=[];for(var r in t)e.push(t[r]);return e}e.exports={makeDragBox:function(t,e,r,a,c,p,S,E){var F,G,Y,W,X,Z,J,K,$,Q,tt,et,rt,nt,it,at,ot,st,lt,ct,ut,ht=t._fullLayout._zoomlayer,ft=S+E===\"nsew\",pt=1===(S+E).length;function dt(){if(F=e.xaxis,G=e.yaxis,$=F._length,Q=G._length,J=F._offset,K=G._offset,(Y={})[F._id]=F,(W={})[G._id]=G,S&&E)for(var r=e.overlays,n=0;n<r.length;n++){var i=r[n].xaxis;Y[i._id]=i;var a=r[n].yaxis;W[a._id]=a}X=H(Y),Z=H(W),rt=L(X,E),nt=L(Z,S),it=!nt&&!rt,tt=V(t,t._fullLayout._axisConstraintGroups,Y,W),et=V(t,t._fullLayout._axisMatchGroups,Y,W),at=E||tt.isSubplotConstrained||et.isSubplotConstrained,ot=S||tt.isSubplotConstrained||et.isSubplotConstrained;var o=t._fullLayout;st=o._has(\"scattergl\"),lt=o._has(\"splom\"),ct=o._has(\"svg\")}dt();var gt=function(t,e,r){return t?\"nsew\"===t?r?\"\":\"pan\"===e?\"move\":\"crosshair\":t.toLowerCase()+\"-resize\":\"pointer\"}(nt+rt,t._fullLayout.dragmode,ft),vt=C(e,S+E+\"drag\",gt,r,a,c,p);if(it&&!ft)return vt.onmousedown=null,vt.style.pointerEvents=\"none\",vt;var mt,yt,xt,bt,_t,wt,kt,Tt,At,Mt,St={element:vt,gd:t,plotinfo:e};function Et(){St.plotinfo.selection=!1,_(t)}function Ct(r,i){var a=t._fullLayout.clickmode;if(B(t),2!==r||pt||function(){if(!t._transitioningWithDuration){var e=t._context.doubleClick,r=[];rt&&(r=r.concat(X)),nt&&(r=r.concat(Z)),et.xaxes&&(r=r.concat(et.xaxes)),et.yaxes&&(r=r.concat(et.yaxes));var n,i,a,s={};if(\"reset+autosize\"===e)for(e=\"autosize\",i=0;i<r.length;i++)if((n=r[i])._rangeInitial&&(n.range[0]!==n._rangeInitial[0]||n.range[1]!==n._rangeInitial[1])||!n._rangeInitial&&!n.autorange){e=\"reset\";break}if(\"autosize\"===e)for(i=0;i<r.length;i++)(n=r[i]).fixedrange||(s[n._name+\".autorange\"]=!0);else if(\"reset\"===e)for((rt||tt.isSubplotConstrained)&&(r=r.concat(tt.xaxes)),nt&&!tt.isSubplotConstrained&&(r=r.concat(tt.yaxes)),tt.isSubplotConstrained&&(rt?nt||(r=r.concat(Z)):r=r.concat(X)),i=0;i<r.length;i++)(n=r[i]).fixedrange||(n._rangeInitial?(a=n._rangeInitial,s[n._name+\".range[0]\"]=a[0],s[n._name+\".range[1]\"]=a[1]):s[n._name+\".autorange\"]=!0);t.emit(\"plotly_doubleclick\",null),o.call(\"_guiRelayout\",t,s)}}(),ft)a.indexOf(\"select\")>-1&&w(i,t,X,Z,e.id,St),a.indexOf(\"event\")>-1&&h.click(t,i,e.id);else if(1===r&&pt){var s=S?G:F,c=\"s\"===S||\"w\"===E?0:1,u=s._name+\".range[\"+c+\"]\",f=function(t,e){var r,i=t.range[e],a=Math.abs(i-t.range[1-e]);return\"date\"===t.type?i:\"log\"===t.type?(r=Math.ceil(Math.max(0,-Math.log(a)/Math.LN10))+3,n.format(\".\"+r+\"g\")(Math.pow(10,i))):(r=Math.floor(Math.log(Math.abs(i))/Math.LN10)-Math.floor(Math.log(a)/Math.LN10)+4,n.format(\".\"+String(r)+\"g\")(i))}(s,c),p=\"left\",d=\"middle\";if(s.fixedrange)return;S?(d=\"n\"===S?\"top\":\"bottom\",\"right\"===s.side&&(p=\"right\")):\"e\"===E&&(p=\"right\"),t._context.showAxisRangeEntryBoxes&&n.select(vt).call(l.makeEditable,{gd:t,immediate:!0,background:t._fullLayout.paper_bgcolor,text:String(f),fill:s.tickfont?s.tickfont.color:\"#444\",horizontalAlign:p,verticalAlign:d}).on(\"edit\",function(e){var r=s.d2r(e);void 0!==r&&o.call(\"_guiRelayout\",t,u,r)})}}function Lt(e,r){if(t._transitioningWithDuration)return!1;var n=Math.max(0,Math.min($,e+mt)),i=Math.max(0,Math.min(Q,r+yt)),a=Math.abs(n-mt),o=Math.abs(i-yt);function s(){kt=\"\",xt.r=xt.l,xt.t=xt.b,At.attr(\"d\",\"M0,0Z\")}if(xt.l=Math.min(mt,n),xt.r=Math.max(mt,n),xt.t=Math.min(yt,i),xt.b=Math.max(yt,i),tt.isSubplotConstrained)a>M||o>M?(kt=\"xy\",a/$>o/Q?(o=a*Q/$,yt>i?xt.t=yt-o:xt.b=yt+o):(a=o*$/Q,mt>n?xt.l=mt-a:xt.r=mt+a),At.attr(\"d\",U(xt))):s();else if(et.isSubplotConstrained)if(a>M||o>M){kt=\"xy\";var l=Math.min(xt.l/$,(Q-xt.b)/Q),c=Math.max(xt.r/$,(Q-xt.t)/Q);xt.l=l*$,xt.r=c*$,xt.b=(1-l)*Q,xt.t=(1-c)*Q,At.attr(\"d\",U(xt))}else s();else!nt||o<Math.min(Math.max(.6*a,A),M)?a<A||!rt?s():(xt.t=0,xt.b=Q,kt=\"x\",At.attr(\"d\",function(t,e){return\"M\"+(t.l-.5)+\",\"+(e-M-.5)+\"h-3v\"+(2*M+1)+\"h3ZM\"+(t.r+.5)+\",\"+(e-M-.5)+\"h3v\"+(2*M+1)+\"h-3Z\"}(xt,yt))):!rt||a<Math.min(.6*o,M)?(xt.l=0,xt.r=$,kt=\"y\",At.attr(\"d\",function(t,e){return\"M\"+(e-M-.5)+\",\"+(t.t-.5)+\"v-3h\"+(2*M+1)+\"v3ZM\"+(e-M-.5)+\",\"+(t.b+.5)+\"v3h\"+(2*M+1)+\"v-3Z\"}(xt,mt))):(kt=\"xy\",At.attr(\"d\",U(xt)));xt.w=xt.r-xt.l,xt.h=xt.b-xt.t,kt&&(Mt=!0),t._dragged=Mt,R(Tt,At,xt,_t,wt,bt),Pt(),t.emit(\"plotly_relayouting\",ut),wt=!0}function Pt(){ut={},\"xy\"!==kt&&\"x\"!==kt||(P(X,xt.l/$,xt.r/$,ut,tt.xaxes),Bt(\"x\",ut)),\"xy\"!==kt&&\"y\"!==kt||(P(Z,(Q-xt.b)/Q,(Q-xt.t)/Q,ut,tt.yaxes),Bt(\"y\",ut))}function Ot(){if(Math.min(xt.h,xt.w)<2*A)return B(t);Pt(),B(t),jt(),N(t)}St.prepFn=function(e,r,n){var a=St.dragmode,o=t._fullLayout.dragmode;o!==a&&(St.dragmode=o),dt(),it||(ft?e.shiftKey?\"pan\"===o?o=\"zoom\":j(o)||(o=\"pan\"):e.ctrlKey&&(o=\"pan\"):o=\"pan\"),St.minDrag=\"lasso\"===o?1:void 0,j(o)?(St.xaxes=X,St.yaxes=Z,b(e,r,n,St,o)):(St.clickFn=Ct,j(a)&&Et(),it||(\"zoom\"===o?(St.moveFn=Lt,St.doneFn=Ot,St.minDrag=1,function(e,r,n){var a=vt.getBoundingClientRect();mt=r-a.left,yt=n-a.top,xt={l:mt,r:mt,w:0,t:yt,b:yt,h:0},bt=t._hmpixcount?t._hmlumcount/t._hmpixcount:i(t._fullLayout.plot_bgcolor).getLuminance(),wt=!1,kt=\"xy\",Mt=!1,Tt=I(ht,bt,J,K,_t=\"M0,0H\"+$+\"V\"+Q+\"H0V0\"),At=D(ht,J,K)}(0,r,n)):\"pan\"===o&&(St.moveFn=Ft,St.doneFn=jt))),t._fullLayout._redrag=function(){var e=t._dragdata;e&&e.element===vt&&(j(t._fullLayout.dragmode)||(dt(),Ut([0,0,$,Q]),St.moveFn(e.dx,e.dy)))}},d.init(St);var zt=[0,0,$,Q],It=null,Dt=T.REDRAWDELAY,Rt=e.mainplot?t._fullLayout._plots[e.mainplot]:e;function Ft(e,r){if(!t._transitioningWithDuration){if(t._fullLayout._replotting=!0,\"ew\"===rt||\"ns\"===nt)return rt&&(O(X,e),Bt(\"x\")),nt&&(O(Z,r),Bt(\"y\")),Ut([rt?-e:0,nt?-r:0,$,Q]),Nt(),void t.emit(\"plotly_relayouting\",ut);if(tt.isSubplotConstrained&&rt&&nt){var n=\"w\"===rt==(\"n\"===nt)?1:-1,i=(e/$+n*r/Q)/2;e=i*$,r=n*i*Q}\"w\"===rt?e=l(X,0,e):\"e\"===rt?e=l(X,1,-e):rt||(e=0),\"n\"===nt?r=l(Z,1,r):\"s\"===nt?r=l(Z,0,-r):nt||(r=0);var a=\"w\"===rt?e:0,o=\"n\"===nt?r:0;if(tt.isSubplotConstrained){var s;if(!rt&&1===nt.length){for(s=0;s<X.length;s++)X[s].range=X[s]._r.slice(),k(X[s],1-r/Q);a=(e=r*$/Q)/2}if(!nt&&1===rt.length){for(s=0;s<Z.length;s++)Z[s].range=Z[s]._r.slice(),k(Z[s],1-e/$);o=(r=e*Q/$)/2}}Bt(\"x\"),Bt(\"y\"),Ut([a,o,$-e,Q-r]),Nt(),t.emit(\"plotly_relayouting\",ut)}function l(t,e,r){for(var n,i,a=1-e,o=0;o<t.length;o++){var s=t[o];if(!s.fixedrange){n=s,i=s._rl[a]+(s._rl[e]-s._rl[a])/z(r/s._length);var l=s.l2r(i);!1!==l&&void 0!==l&&(s.range[e]=l)}}return n._length*(n._rl[e]-i)/(n._rl[e]-n._rl[a])}}function Bt(t,e){for(var r=et.isSubplotConstrained?{x:Z,y:X}[t]:et[t+\"axes\"],n=et.isSubplotConstrained?{x:X,y:Z}[t]:[],i=0;i<r.length;i++){var a=r[i],o=a._id,s=et.xLinks[o]||et.yLinks[o],l=n[0]||Y[s]||W[s];l&&(e?(e[a._name+\".range[0]\"]=e[l._name+\".range[0]\"],e[a._name+\".range[1]\"]=e[l._name+\".range[1]\"]):a.range=l.range.slice())}}function Nt(){var e,r=[];function n(t){for(e=0;e<t.length;e++)t[e].fixedrange||r.push(t[e]._id)}for(at&&(n(X),n(tt.xaxes),n(et.xaxes)),ot&&(n(Z),n(tt.yaxes),n(et.yaxes)),ut={},e=0;e<r.length;e++){var i=r[e],a=x(t,i);f.drawOne(t,a,{skipTitle:!0}),ut[a._name+\".range[0]\"]=a.range[0],ut[a._name+\".range[1]\"]=a.range[1]}f.redrawComponents(t,r)}function jt(){Ut([0,0,$,Q]),s.syncOrAsync([y.previousPromises,function(){t._fullLayout._replotting=!1,o.call(\"_guiRelayout\",t,ut)}],t)}function Ut(e){var r,n,i,a,l=t._fullLayout,c=l._plots,h=l._subplots.cartesian;if(lt&&o.subplotsRegistry.splom.drag(t),st)for(r=0;r<h.length;r++)if(i=(n=c[h[r]]).xaxis,a=n.yaxis,n._scene){var f=s.simpleMap(i.range,i.r2l),p=s.simpleMap(a.range,a.r2l);n._scene.update({range:[f[0],p[0],f[1],p[1]]})}if((lt||st)&&(v(t),m(t)),ct){var d=e[2]/F._length,g=e[3]/G._length;for(r=0;r<h.length;r++){i=(n=c[h[r]]).xaxis,a=n.yaxis;var y,x,b,_,w=at&&!i.fixedrange&&Y[i._id],k=ot&&!a.fixedrange&&W[a._id];if(w?(y=d,b=E?e[0]:Ht(i,y)):et.xaHash[i._id]?(y=d,b=e[0]*i._length/F._length):et.yaHash[i._id]?(y=g,b=\"ns\"===nt?-e[1]*i._length/G._length:Ht(i,y,{n:\"top\",s:\"bottom\"}[nt])):b=qt(i,y=Vt(i,d,g)),k?(x=g,_=S?e[1]:Ht(a,x)):et.yaHash[a._id]?(x=g,_=e[1]*a._length/G._length):et.xaHash[a._id]?(x=d,_=\"ew\"===rt?-e[0]*a._length/F._length:Ht(a,x,{e:\"right\",w:\"left\"}[rt])):_=qt(a,x=Vt(a,d,g)),y||x){y||(y=1),x||(x=1);var T=i._offset-b/y,A=a._offset-_/x;n.clipRect.call(u.setTranslate,b,_).call(u.setScale,y,x),n.plot.call(u.setTranslate,T,A).call(u.setScale,1/y,1/x),y===n.xScaleFactor&&x===n.yScaleFactor||(u.setPointGroupScale(n.zoomScalePts,y,x),u.setTextPointsScale(n.zoomScaleTxt,y,x)),u.hideOutsideRangePoints(n.clipOnAxisFalseTraces,n),n.xScaleFactor=y,n.yScaleFactor=x}}}}function Vt(t,e,r){return t.fixedrange?0:at&&tt.xaHash[t._id]?e:ot&&(tt.isSubplotConstrained?tt.xaHash:tt.yaHash)[t._id]?r:0}function qt(t,e){return e?(t.range=t._r.slice(),k(t,e),Ht(t,e)):0}function Ht(t,e,r){return t._length*(1-e)*g[r||t.constraintoward||\"middle\"]}return S.length*E.length!=1&&q(vt,function(e){if(t._context._scrollZoom.cartesian||t._fullLayout._enablescrollzoom){if(Et(),t._transitioningWithDuration)return e.preventDefault(),void e.stopPropagation();dt(),clearTimeout(It);var r=-e.deltaY;if(isFinite(r)||(r=e.wheelDelta/10),isFinite(r)){var n,i=Math.exp(-Math.min(Math.max(r,-20),20)/200),a=Rt.draglayer.select(\".nsewdrag\").node().getBoundingClientRect(),o=(e.clientX-a.left)/a.width,l=(a.bottom-e.clientY)/a.height;if(at){for(E||(o=.5),n=0;n<X.length;n++)c(X[n],o,i);Bt(\"x\"),zt[2]*=i,zt[0]+=zt[2]*o*(1/i-1)}if(ot){for(S||(l=.5),n=0;n<Z.length;n++)c(Z[n],l,i);Bt(\"y\"),zt[3]*=i,zt[1]+=zt[3]*(1-l)*(1/i-1)}Ut(zt),Nt(),t.emit(\"plotly_relayouting\",ut),It=setTimeout(function(){zt=[0,0,$,Q],jt()},Dt),e.preventDefault()}else s.log(\"Did not find wheel motion attributes: \",e)}function c(t,e,r){if(!t.fixedrange){var n=s.simpleMap(t.range,t.r2l),i=n[0]+(n[1]-n[0])*e;t.range=n.map(function(e){return t.l2r(i+(e-i)*r)})}}}),vt},makeDragger:E,makeRectDragger:C,makeZoombox:I,makeCorners:D,updateZoombox:R,xyCorners:U,transitionZoombox:F,removeZoombox:B,showDoubleClickNotifier:N,attachWheelEventHandler:q}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/clear_gl_canvases\":704,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../plot_api/subroutines\":758,\"../../registry\":847,\"../plots\":828,\"./axes\":767,\"./axis_ids\":770,\"./constants\":773,\"./scale_zoom\":783,\"./select\":784,d3:163,\"has-passive-events\":411,tinycolor2:537}],776:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/fx\"),a=t(\"../../components/dragelement\"),o=t(\"../../lib/setcursor\"),s=t(\"./dragbox\").makeDragBox,l=t(\"./constants\").DRAGGERSIZE;r.initInteractions=function(t){var e=t._fullLayout;if(t._context.staticPlot)n.select(t).selectAll(\".drag\").remove();else if(e._has(\"cartesian\")||e._has(\"splom\")){Object.keys(e._plots||{}).sort(function(t,r){if((e._plots[t].mainplot&&!0)===(e._plots[r].mainplot&&!0)){var n=t.split(\"y\"),i=r.split(\"y\");return n[0]===i[0]?Number(n[1]||1)-Number(i[1]||1):Number(n[0]||1)-Number(i[0]||1)}return e._plots[t].mainplot?1:-1}).forEach(function(r){var n=e._plots[r],o=n.xaxis,c=n.yaxis;if(!n.mainplot){var u=s(t,n,o._offset,c._offset,o._length,c._length,\"ns\",\"ew\");u.onmousemove=function(e){t._fullLayout._rehover=function(){t._fullLayout._hoversubplot===r&&i.hover(t,e,r)},i.hover(t,e,r),t._fullLayout._lasthover=u,t._fullLayout._hoversubplot=r},u.onmouseout=function(e){t._dragging||(t._fullLayout._hoversubplot=null,a.unhover(t,e))},t._context.showAxisDragHandles&&(s(t,n,o._offset-l,c._offset-l,l,l,\"n\",\"w\"),s(t,n,o._offset+o._length,c._offset-l,l,l,\"n\",\"e\"),s(t,n,o._offset-l,c._offset+c._length,l,l,\"s\",\"w\"),s(t,n,o._offset+o._length,c._offset+c._length,l,l,\"s\",\"e\"))}if(t._context.showAxisDragHandles){if(r===o._mainSubplot){var h=o._mainLinePosition;\"top\"===o.side&&(h-=l),s(t,n,o._offset+.1*o._length,h,.8*o._length,l,\"\",\"ew\"),s(t,n,o._offset,h,.1*o._length,l,\"\",\"w\"),s(t,n,o._offset+.9*o._length,h,.1*o._length,l,\"\",\"e\")}if(r===c._mainSubplot){var f=c._mainLinePosition;\"right\"!==c.side&&(f-=l),s(t,n,f,c._offset+.1*c._length,l,.8*c._length,\"ns\",\"\"),s(t,n,f,c._offset+.9*c._length,l,.1*c._length,\"s\",\"\"),s(t,n,f,c._offset,l,.1*c._length,\"n\",\"\")}}});var o=e._hoverlayer.node();o.onmousemove=function(r){r.target=t._fullLayout._lasthover,i.hover(t,r,e._hoversubplot)},o.onclick=function(e){e.target=t._fullLayout._lasthover,i.click(t,e)},o.onmousedown=function(e){t._fullLayout._lasthover.onmousedown(e)},r.updateFx(t)}},r.updateFx=function(t){var e=t._fullLayout,r=\"pan\"===e.dragmode?\"move\":\"crosshair\";o(e._draggers,r)}},{\"../../components/dragelement\":611,\"../../components/fx\":632,\"../../lib/setcursor\":739,\"./constants\":773,\"./dragbox\":775,d3:163}],777:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t){return function(e,r){var a=e[t];if(Array.isArray(a))for(var o=n.subplotsRegistry.cartesian,s=o.idRegex,l=r._subplots,c=l.xaxis,u=l.yaxis,h=l.cartesian,f=r._has(\"cartesian\")||r._has(\"gl2d\"),p=0;p<a.length;p++){var d=a[p];if(i.isPlainObject(d)){var g=d.xref,v=d.yref,m=s.x.test(g),y=s.y.test(v);if(m||y){f||i.pushUnique(r._basePlotModules,o);var x=!1;m&&-1===c.indexOf(g)&&(c.push(g),x=!0),y&&-1===u.indexOf(v)&&(u.push(v),x=!0),x&&m&&y&&h.push(g+v)}}}}}},{\"../../lib\":719,\"../../registry\":847}],778:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../plots\"),s=t(\"../../components/drawing\"),l=t(\"../get_data\").getModuleCalcData,c=t(\"./axis_ids\"),u=t(\"./constants\"),h=t(\"../../constants/xmlns_namespaces\"),f=a.ensureSingle;function p(t,e,r){return a.ensureSingle(t,e,r,function(t){t.datum(r)})}function d(t,e,r,a,o){for(var c,h,f,p=u.traceLayerClasses,d=t._fullLayout,g=d._modules,v=[],m=[],y=0;y<g.length;y++){var x=(c=g[y]).name,b=i.modules[x].categories;if(b.svg){var _=c.layerName||x+\"layer\",w=c.plot;f=(h=l(r,w))[0],r=h[1],f.length&&v.push({i:p.indexOf(_),className:_,plotMethod:w,cdModule:f}),b.zoomScale&&m.push(\".\"+_)}}v.sort(function(t,e){return t.i-e.i});var k=e.plot.selectAll(\"g.mlayer\").data(v,function(t){return t.className});if(k.enter().append(\"g\").attr(\"class\",function(t){return t.className}).classed(\"mlayer\",!0).classed(\"rangeplot\",e.isRangePlot),k.exit().remove(),k.order(),k.each(function(r){var i=n.select(this),l=r.className;r.plotMethod(t,e,r.cdModule,i,a,o),-1===u.clipOnAxisFalseQuery.indexOf(\".\"+l)&&s.setClipUrl(i,e.layerClipId,t)}),d._has(\"scattergl\")&&(c=i.getModule(\"scattergl\"),f=l(r,c)[0],c.plot(t,e,f)),!t._context.staticPlot&&(e._hasClipOnAxisFalse&&(e.clipOnAxisFalseTraces=e.plot.selectAll(u.clipOnAxisFalseQuery.join(\",\")).selectAll(\".trace\")),m.length)){var T=e.plot.selectAll(m.join(\",\")).selectAll(\".trace\");e.zoomScalePts=T.selectAll(\"path.point\"),e.zoomScaleTxt=T.selectAll(\".textpoint\")}}function g(t,e){var r=e.plotgroup,n=e.id,i=u.layerValue2layerClass[e.xaxis.layer],a=u.layerValue2layerClass[e.yaxis.layer],o=t._fullLayout._hasOnlyLargeSploms;if(e.mainplot){var s=e.mainplotinfo,l=s.plotgroup,h=n+\"-x\",d=n+\"-y\";e.gridlayer=s.gridlayer,e.zerolinelayer=s.zerolinelayer,f(s.overlinesBelow,\"path\",h),f(s.overlinesBelow,\"path\",d),f(s.overaxesBelow,\"g\",h),f(s.overaxesBelow,\"g\",d),e.plot=f(s.overplot,\"g\",n),f(s.overlinesAbove,\"path\",h),f(s.overlinesAbove,\"path\",d),f(s.overaxesAbove,\"g\",h),f(s.overaxesAbove,\"g\",d),e.xlines=l.select(\".overlines-\"+i).select(\".\"+h),e.ylines=l.select(\".overlines-\"+a).select(\".\"+d),e.xaxislayer=l.select(\".overaxes-\"+i).select(\".\"+h),e.yaxislayer=l.select(\".overaxes-\"+a).select(\".\"+d)}else if(o)e.xlines=f(r,\"path\",\"xlines-above\"),e.ylines=f(r,\"path\",\"ylines-above\"),e.xaxislayer=f(r,\"g\",\"xaxislayer-above\"),e.yaxislayer=f(r,\"g\",\"yaxislayer-above\");else{var g=f(r,\"g\",\"layer-subplot\");e.shapelayer=f(g,\"g\",\"shapelayer\"),e.imagelayer=f(g,\"g\",\"imagelayer\"),e.gridlayer=f(r,\"g\",\"gridlayer\"),e.zerolinelayer=f(r,\"g\",\"zerolinelayer\"),f(r,\"path\",\"xlines-below\"),f(r,\"path\",\"ylines-below\"),e.overlinesBelow=f(r,\"g\",\"overlines-below\"),f(r,\"g\",\"xaxislayer-below\"),f(r,\"g\",\"yaxislayer-below\"),e.overaxesBelow=f(r,\"g\",\"overaxes-below\"),e.plot=f(r,\"g\",\"plot\"),e.overplot=f(r,\"g\",\"overplot\"),e.xlines=f(r,\"path\",\"xlines-above\"),e.ylines=f(r,\"path\",\"ylines-above\"),e.overlinesAbove=f(r,\"g\",\"overlines-above\"),f(r,\"g\",\"xaxislayer-above\"),f(r,\"g\",\"yaxislayer-above\"),e.overaxesAbove=f(r,\"g\",\"overaxes-above\"),e.xlines=r.select(\".xlines-\"+i),e.ylines=r.select(\".ylines-\"+a),e.xaxislayer=r.select(\".xaxislayer-\"+i),e.yaxislayer=r.select(\".yaxislayer-\"+a)}o||(p(e.gridlayer,\"g\",e.xaxis._id),p(e.gridlayer,\"g\",e.yaxis._id),e.gridlayer.selectAll(\"g\").map(function(t){return t[0]}).sort(c.idSort)),e.xlines.style(\"fill\",\"none\").classed(\"crisp\",!0),e.ylines.style(\"fill\",\"none\").classed(\"crisp\",!0)}function v(t,e){if(t){var r={};for(var i in t.each(function(t){var i=t[0];n.select(this).remove(),m(i,e),r[i]=!0}),e._plots)for(var a=e._plots[i].overlays||[],o=0;o<a.length;o++){var s=a[o];r[s.id]&&s.plot.selectAll(\".trace\").remove()}}}function m(t,e){e._draggers.selectAll(\"g.\"+t).remove(),e._defs.select(\"#clip\"+e._uid+t+\"plot\").remove()}r.name=\"cartesian\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=u.idRegex,r.attrRegex=u.attrRegex,r.attributes=t(\"./attributes\"),r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.transitionAxes=t(\"./transition_axes\"),r.finalizeSubplots=function(t,e){var r,n,i,o=e._subplots,s=o.xaxis,l=o.yaxis,h=o.cartesian,f=h.concat(o.gl2d||[]),p={},d={};for(r=0;r<f.length;r++){var g=f[r].split(\"y\");p[g[0]]=1,d[\"y\"+g[1]]=1}for(r=0;r<s.length;r++)p[n=s[r]]||(i=(t[c.id2name(n)]||{}).anchor,u.idRegex.y.test(i)||(i=\"y\"),h.push(n+i),f.push(n+i),d[i]||(d[i]=1,a.pushUnique(l,i)));for(r=0;r<l.length;r++)d[i=l[r]]||(n=(t[c.id2name(i)]||{}).anchor,u.idRegex.x.test(n)||(n=\"x\"),h.push(n+i),f.push(n+i),p[n]||(p[n]=1,a.pushUnique(s,n)));if(!f.length){for(var v in n=\"\",i=\"\",t){if(u.attrRegex.test(v))\"x\"===v.charAt(0)?(!n||+v.substr(5)<+n.substr(5))&&(n=v):(!i||+v.substr(5)<+i.substr(5))&&(i=v)}n=n?c.name2id(n):\"x\",i=i?c.name2id(i):\"y\",s.push(n),l.push(i),h.push(n+i)}},r.plot=function(t,e,r,n){var i,a=t._fullLayout,o=a._subplots.cartesian,s=t.calcdata;if(!Array.isArray(e))for(e=[],i=0;i<s.length;i++)e.push(i);for(i=0;i<o.length;i++){for(var l,c=o[i],u=a._plots[c],h=[],f=0;f<s.length;f++){var p=s[f],g=p[0].trace;g.xaxis+g.yaxis===c&&((-1!==e.indexOf(g.index)||g.carpet)&&(l&&l[0].trace.xaxis+l[0].trace.yaxis===c&&-1!==[\"tonextx\",\"tonexty\",\"tonext\"].indexOf(g.fill)&&-1===h.indexOf(l)&&h.push(l),h.push(p)),l=p)}d(t,u,h,r,n)}},r.clean=function(t,e,r,n){var i,a,o,s=n._plots||{},l=e._plots||{},u=n._subplots||{};if(n._hasOnlyLargeSploms&&!e._hasOnlyLargeSploms)for(o in s)(i=s[o]).plotgroup&&i.plotgroup.remove();var h=n._has&&n._has(\"gl\"),f=e._has&&e._has(\"gl\");if(h&&!f)for(o in s)(i=s[o])._scene&&i._scene.destroy();if(u.xaxis&&u.yaxis){var p=c.listIds({_fullLayout:n});for(a=0;a<p.length;a++){var d=p[a];e[c.id2name(d)]||n._infolayer.selectAll(\".g-\"+d+\"title\").remove()}}var g=n._has&&n._has(\"cartesian\"),y=e._has&&e._has(\"cartesian\");if(g&&!y)v(n._cartesianlayer.selectAll(\".subplot\"),n),n._defs.selectAll(\".axesclip\").remove(),delete n._axisConstraintGroups;else if(u.cartesian)for(a=0;a<u.cartesian.length;a++){var x=u.cartesian[a];if(!l[x]){var b=\".\"+x+\",.\"+x+\"-x,.\"+x+\"-y\";n._cartesianlayer.selectAll(b).remove(),m(x,n)}}},r.drawFramework=function(t){var e=t._fullLayout,r=function(t){var e,r,n,i,a,o,s=t._fullLayout,l=s._subplots.cartesian,c=l.length,u=[],h=[];for(e=0;e<c;e++){n=l[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var f=a._mainAxis,p=o._mainAxis,d=f._id+p._id,g=s._plots[d];i.overlays=[],d!==n&&g?(i.mainplot=d,i.mainplotinfo=g,h.push(n)):(i.mainplot=void 0,i.mainPlotinfo=void 0,u.push(n))}for(e=0;e<h.length;e++)n=h[e],(i=s._plots[n]).mainplotinfo.overlays.push(i);var v=u.concat(h),m=new Array(c);for(e=0;e<c;e++){n=v[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var y=[n,a.layer,o.layer,a.overlaying||\"\",o.overlaying||\"\"];for(r=0;r<i.overlays.length;r++)y.push(i.overlays[r].id);m[e]=y}return m}(t),i=e._cartesianlayer.selectAll(\".subplot\").data(r,String);i.enter().append(\"g\").attr(\"class\",function(t){return\"subplot \"+t[0]}),i.order(),i.exit().call(v,e),i.each(function(r){var i=r[0],a=e._plots[i];a.plotgroup=n.select(this),g(t,a),a.draglayer=f(e._draggers,\"g\",i)})},r.rangePlot=function(t,e,r){g(t,e),d(t,e,r),o.style(t)},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter(function(t,e){return e===r.size()-1}).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each(function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:h.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})})},r.updateFx=t(\"./graph_interact\").updateFx},{\"../../components/drawing\":614,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../registry\":847,\"../get_data\":802,\"../plots\":828,\"./attributes\":765,\"./axis_ids\":770,\"./constants\":773,\"./graph_interact\":776,\"./layout_attributes\":779,\"./layout_defaults\":780,\"./transition_axes\":789,d3:163}],779:[function(t,e,r){\"use strict\";var n=t(\"../font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray,l=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").DATE_FORMAT_LINK,t(\"./constants\"));e.exports={visible:{valType:\"boolean\",editType:\"plot\"},color:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},title:{text:{valType:\"string\",editType:\"ticks\"},font:n({editType:\"ticks\"}),editType:\"ticks\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"log\",\"date\",\"category\",\"multicategory\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"axrange\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0},{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0}],editType:\"axrange\",impliedEdits:{autorange:!1},anim:!0},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},scaleanchor:{valType:\"enumerated\",values:[l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},scaleratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},constrain:{valType:\"enumerated\",values:[\"range\",\"domain\"],dflt:\"range\",editType:\"plot\"},constraintoward:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\",\"top\",\"middle\",\"bottom\"],editType:\"plot\"},matches:{valType:\"enumerated\",values:[l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"calc\"},tickmode:{valType:\"enumerated\",values:[\"auto\",\"linear\",\"array\"],editType:\"ticks\",impliedEdits:{tick0:void 0,dtick:void 0}},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"ticks\"},tick0:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},dtick:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},tickvals:{valType:\"data_array\",editType:\"ticks\"},ticktext:{valType:\"data_array\",editType:\"ticks\"},ticks:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"\"],editType:\"ticks\"},tickson:{valType:\"enumerated\",values:[\"labels\",\"boundaries\"],dflt:\"labels\",editType:\"ticks\"},mirror:{valType:\"enumerated\",values:[!0,\"ticks\",!1,\"all\",\"allticks\"],dflt:!1,editType:\"ticks+layoutstyle\"},ticklen:{valType:\"number\",min:0,dflt:5,editType:\"ticks\"},tickwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},tickcolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},showticklabels:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},automargin:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},showspikes:{valType:\"boolean\",dflt:!1,editType:\"modebar\"},spikecolor:{valType:\"color\",dflt:null,editType:\"none\"},spikethickness:{valType:\"number\",dflt:3,editType:\"none\"},spikedash:o({},a,{dflt:\"dash\",editType:\"none\"}),spikemode:{valType:\"flaglist\",flags:[\"toaxis\",\"across\",\"marker\"],dflt:\"toaxis\",editType:\"none\"},spikesnap:{valType:\"enumerated\",values:[\"data\",\"cursor\"],dflt:\"data\",editType:\"none\"},tickfont:n({editType:\"ticks\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"ticks\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"ticks\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"ticks\"},tickformatstops:s(\"tickformatstop\",{enabled:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dtickrange:{valType:\"info_array\",items:[{valType:\"any\",editType:\"ticks\"},{valType:\"any\",editType:\"ticks\"}],editType:\"ticks\"},value:{valType:\"string\",dflt:\"\",editType:\"ticks\"},editType:\"ticks\"}),hoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},showline:{valType:\"boolean\",dflt:!1,editType:\"ticks+layoutstyle\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"layoutstyle\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks+layoutstyle\"},showgrid:{valType:\"boolean\",editType:\"ticks\"},gridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"ticks\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},zeroline:{valType:\"boolean\",editType:\"ticks\"},zerolinecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},zerolinewidth:{valType:\"number\",dflt:1,editType:\"ticks\"},showdividers:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dividercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},dividerwidth:{valType:\"number\",dflt:1,editType:\"ticks\"},anchor:{valType:\"enumerated\",values:[\"free\",l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},side:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],editType:\"plot\"},overlaying:{valType:\"enumerated\",values:[\"free\",l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},layer:{valType:\"enumerated\",values:[\"above traces\",\"below traces\"],dflt:\"above traces\",editType:\"plot\"},domain:{valType:\"info_array\",items:[{valType:\"number\",min:0,max:1,editType:\"plot\"},{valType:\"number\",min:0,max:1,editType:\"plot\"}],dflt:[0,1],editType:\"plot\"},position:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\",\"total ascending\",\"total descending\",\"min ascending\",\"min descending\",\"max ascending\",\"max descending\",\"sum ascending\",\"sum descending\",\"mean ascending\",\"mean descending\",\"median ascending\",\"median descending\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{autotick:{valType:\"boolean\",editType:\"ticks\"},title:{valType:\"string\",editType:\"ticks\"},titlefont:n({editType:\"ticks\"})}}},{\"../../components/color/attributes\":592,\"../../components/drawing/attributes\":613,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../font_attributes\":793,\"./constants\":773}],780:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../layout_attributes\"),s=t(\"./layout_attributes\"),l=t(\"./type_defaults\"),c=t(\"./axis_defaults\"),u=t(\"./constraints\").handleConstraintDefaults,h=t(\"./position_defaults\"),f=t(\"./axis_ids\"),p=f.id2name,d=f.name2id,g=t(\"../../registry\"),v=g.traceIs,m=g.getComponentMethod;function y(t,e,r){Array.isArray(t[e])?t[e].push(r):t[e]=[r]}e.exports=function(t,e,r){var f,g,x={},b={},_={},w={},k={},T={},A={},M={},S={};for(f=0;f<r.length;f++){var E=r[f];if(v(E,\"cartesian\")||v(E,\"gl2d\")){var C,L;if(E.xaxis)y(x,C=p(E.xaxis),E);else if(E.xaxes)for(g=0;g<E.xaxes.length;g++)y(x,p(E.xaxes[g]),E);if(E.yaxis)y(x,L=p(E.yaxis),E);else if(E.yaxes)for(g=0;g<E.yaxes.length;g++)y(x,p(E.yaxes[g]),E);if(\"funnel\"===E.type?\"h\"===E.orientation?(C&&(b[C]=!0),L&&(A[L]=!0)):L&&(_[L]=!0):(L&&(k[L]=!0,T[L]=!0),v(E,\"carpet\")&&(\"carpet\"!==E.type||E._cheater)||C&&(w[C]=!0)),\"carpet\"===E.type&&E._cheater&&C&&(b[C]=!0),v(E,\"2dMap\")&&(M[C]=!0,M[L]=!0),v(E,\"oriented\"))S[\"h\"===E.orientation?L:C]=!0}}var P=e._subplots,O=P.xaxis,z=P.yaxis,I=n.simpleMap(O,p),D=n.simpleMap(z,p),R=I.concat(D),F=i.background;O.length&&z.length&&(F=n.coerce(t,e,o,\"plot_bgcolor\"));var B,N,j,U,V=i.combine(F,e.paper_bgcolor);function q(t,e){return n.coerce(j,U,s,t,e)}function H(t,e){return n.coerce2(j,U,s,t,e)}function G(t){return\"x\"===t?z:O}var Y={x:G(\"x\"),y:G(\"y\")},W=Y.x.concat(Y.y);function X(e,r){for(var n=\"x\"===e?I:D,i=[],a=0;a<n.length;a++){var o=n[a];o===r||(t[o]||{}).overlaying||i.push(d(o))}return i}for(f=0;f<R.length;f++){N=(B=R[f]).charAt(0),n.isPlainObject(t[B])||(t[B]={}),j=t[B],U=a.newContainer(e,B,N+\"axis\");var Z=x[B]||[];U._traceIndices=Z.map(function(t){return t._expandedIndex}),U._annIndices=[],U._shapeIndices=[],U._imgIndices=[],U._subplotsWith=[],U._counterAxes=[],U._name=U._attr=B;var J=U._id=d(B),K=X(N,B),$=\"x\"===N&&!w[B]&&b[B]||\"y\"===N&&!k[B]&&_[B],Q=\"y\"===N&&!T[B]&&A[B],tt={letter:N,font:e.font,outerTicks:M[B],showGrid:!S[B],data:Z,bgColor:V,calendar:e.calendar,automargin:!0,visibleDflt:$,reverseDflt:Q,splomStash:((e._splomAxes||{})[N]||{})[J]};q(\"uirevision\",e.uirevision),l(j,U,q,tt),c(j,U,q,tt,e);var et=H(\"spikecolor\"),rt=H(\"spikethickness\"),nt=H(\"spikedash\"),it=H(\"spikemode\"),at=H(\"spikesnap\");q(\"showspikes\",!!(et||rt||nt||it||at))||(delete U.spikecolor,delete U.spikethickness,delete U.spikedash,delete U.spikemode,delete U.spikesnap),h(j,U,q,{letter:N,counterAxes:Y[N],overlayableAxes:K,grid:e.grid}),U._input=j}var ot=m(\"rangeslider\",\"handleDefaults\"),st=m(\"rangeselector\",\"handleDefaults\");for(f=0;f<I.length;f++)B=I[f],j=t[B],U=e[B],ot(t,e,B),\"date\"===U.type&&st(j,U,e,D,U.calendar),q(\"fixedrange\");for(f=0;f<D.length;f++){B=D[f],j=t[B],U=e[B];var lt=e[p(U.anchor)];q(\"fixedrange\",m(\"rangeslider\",\"isVisible\")(lt))}var ct=e._axisConstraintGroups=[],ut=e._axisMatchGroups=[];for(f=0;f<R.length;f++)N=(B=R[f]).charAt(0),j=t[B],U=e[B],u(j,U,q,W,e);for(f=0;f<ut.length;f++){var ht,ft=ut[f],pt=null,dt=null;for(ht in ft)(U=e[p(ht)]).matches||(pt=U.range,dt=U.autorange);if(null===pt||null===dt)for(ht in ft){pt=(U=e[p(ht)]).range,dt=U.autorange;break}for(ht in ft)(U=e[p(ht)]).matches&&(U.range=pt.slice(),U.autorange=dt),U._matchGroup=ft;if(ct.length)for(ht in ft)for(g=0;g<ct.length;g++){var gt=ct[g];for(var vt in gt)ht===vt&&(n.warn(\"Axis \"+vt+\" is set with both a *scaleanchor* and *matches* constraint; ignoring the scale constraint.\"),delete gt[vt],Object.keys(gt).length<2&&ct.splice(g,1))}}}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../registry\":847,\"../layout_attributes\":819,\"./axis_defaults\":769,\"./axis_ids\":770,\"./constraints\":774,\"./layout_attributes\":779,\"./position_defaults\":782,\"./type_defaults\":790}],781:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../components/color/attributes\").lightFraction,a=t(\"../../lib\");e.exports=function(t,e,r,o){var s=(o=o||{}).dfltColor;function l(r,n){return a.coerce2(t,e,o.attributes,r,n)}var c=l(\"linecolor\",s),u=l(\"linewidth\");r(\"showline\",o.showLine||!!c||!!u)||(delete e.linecolor,delete e.linewidth);var h=l(\"gridcolor\",n(s,o.bgColor,o.blend||i).toRgbString()),f=l(\"gridwidth\");if(r(\"showgrid\",o.showGrid||!!h||!!f)||(delete e.gridcolor,delete e.gridwidth),!o.noZeroLine){var p=l(\"zerolinecolor\",s),d=l(\"zerolinewidth\");r(\"zeroline\",o.showGrid||!!p||!!d)||(delete e.zerolinecolor,delete e.zerolinewidth)}}},{\"../../components/color/attributes\":592,\"../../lib\":719,tinycolor2:537}],782:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o,s,l,c,u=a.counterAxes||[],h=a.overlayableAxes||[],f=a.letter,p=a.grid;p&&(s=p._domains[f][p._axisMap[e._id]],o=p._anchors[e._id],s&&(l=p[f+\"side\"].split(\" \")[0],c=p.domain[f][\"right\"===l||\"top\"===l?1:0])),s=s||[0,1],o=o||(n(t.position)?\"free\":u[0]||\"free\"),l=l||(\"x\"===f?\"bottom\":\"left\"),c=c||0,\"free\"===i.coerce(t,e,{anchor:{valType:\"enumerated\",values:[\"free\"].concat(u),dflt:o}},\"anchor\")&&r(\"position\",c),i.coerce(t,e,{side:{valType:\"enumerated\",values:\"x\"===f?[\"bottom\",\"top\"]:[\"left\",\"right\"],dflt:l}},\"side\");var d=!1;if(h.length&&(d=i.coerce(t,e,{overlaying:{valType:\"enumerated\",values:[!1].concat(h),dflt:!1}},\"overlaying\")),!d){var g=r(\"domain\",s);g[0]>g[1]-1/4096&&(e.domain=s),i.noneOrAll(t.domain,e.domain,s)}return r(\"layer\"),e}},{\"../../lib\":719,\"fast-isnumeric\":225}],783:[function(t,e,r){\"use strict\";var n=t(\"../../constants/alignment\").FROM_BL;e.exports=function(t,e,r){void 0===r&&(r=n[t.constraintoward||\"center\"]);var i=[t.r2l(t.range[0]),t.r2l(t.range[1])],a=i[0]+(i[1]-i[0])*r;t.range=t._input.range=[t.l2r(a+(i[0]-a)*e),t.l2r(a+(i[1]-a)*e)]}},{\"../../constants/alignment\":688}],784:[function(t,e,r){\"use strict\";var n=t(\"polybooljs\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../../components/fx\"),s=t(\"../../lib\"),l=t(\"../../lib/polygon\"),c=t(\"../../lib/throttle\"),u=t(\"../../components/fx/helpers\").makeEventData,h=t(\"./axis_ids\").getFromId,f=t(\"../../lib/clear_gl_canvases\"),p=t(\"../../plot_api/subroutines\").redrawReglTraces,d=t(\"./constants\"),g=d.MINSELECT,v=l.filter,m=l.tester;function y(t){return t._id}function x(t,e,r,n,i,a,o){var s,l,c,u,h,f,p,d,g,v=e._hoverdata,m=e._fullLayout.clickmode.indexOf(\"event\")>-1,y=[];if(function(t){return t&&Array.isArray(t)&&!0!==t[0].hoverOnBox}(v)){k(t,e,a);var x=function(t,e){var r,n,i=t[0],a=-1,o=[];for(n=0;n<e.length;n++)if(r=e[n],i.fullData._expandedIndex===r.cd[0].trace._expandedIndex){if(!0===i.hoverOnBox)break;void 0!==i.pointNumber?a=i.pointNumber:void 0!==i.binNumber&&(a=i.binNumber,o=i.pointNumbers);break}return{pointNumber:a,pointNumbers:o,searchInfo:r}}(v,s=A(e,r,n,i));if(x.pointNumbers.length>0?function(t,e){var r,n,i,a=[];for(i=0;i<t.length;i++)(r=t[i]).cd[0].trace.selectedpoints&&r.cd[0].trace.selectedpoints.length>0&&a.push(r);if(1===a.length&&a[0]===e.searchInfo&&(n=e.searchInfo.cd[0].trace).selectedpoints.length===e.pointNumbers.length){for(i=0;i<e.pointNumbers.length;i++)if(n.selectedpoints.indexOf(e.pointNumbers[i])<0)return!1;return!0}return!1}(s,x):function(t){var e,r,n,i=0;for(n=0;n<t.length;n++)if(e=t[n],(r=e.cd[0].trace).selectedpoints){if(r.selectedpoints.length>1)return!1;if((i+=r.selectedpoints.length)>1)return!1}return 1===i}(s)&&(f=S(x))){for(o&&o.remove(),g=0;g<s.length;g++)(l=s[g])._module.selectPoints(l,!1);E(e,s),T(a),m&&e.emit(\"plotly_deselect\",null)}else{for(p=t.shiftKey&&(void 0!==f?f:S(x)),c=function(t,e,r){return{pointNumber:t,searchInfo:e,subtract:r}}(x.pointNumber,x.searchInfo,p),u=w(a.selectionDefs.concat([c])),g=0;g<s.length;g++)if(h=C(s[g]._module.selectPoints(s[g],u),s[g]),y.length)for(var b=0;b<h.length;b++)y.push(h[b]);else y=h;E(e,s,d={points:y}),c&&a&&a.selectionDefs.push(c),o&&M(a.mergedPolygons,o),m&&e.emit(\"plotly_selected\",d)}}}function b(t){return\"pointNumber\"in t&&\"searchInfo\"in t}function _(t){return{xmin:0,xmax:0,ymin:0,ymax:0,pts:[],contains:function(e,r,n,i){var a=t.searchInfo.cd[0].trace._expandedIndex;return i.cd[0].trace._expandedIndex===a&&n===t.pointNumber},isRect:!1,degenerate:!1,subtract:t.subtract}}function w(t){for(var e=[],r=b(t[0])?0:t[0][0][0],n=r,i=b(t[0])?0:t[0][0][1],a=i,o=0;o<t.length;o++)if(b(t[o]))e.push(_(t[o]));else{var s=l.tester(t[o]);s.subtract=t[o].subtract,e.push(s),r=Math.min(r,s.xmin),n=Math.max(n,s.xmax),i=Math.min(i,s.ymin),a=Math.max(a,s.ymax)}return{xmin:r,xmax:n,ymin:i,ymax:a,pts:[],contains:function(t,r,n,i){for(var a=!1,o=0;o<e.length;o++)e[o].contains(t,r,n,i)&&(a=!1===e[o].subtract);return a},isRect:!1,degenerate:!1}}function k(t,e,r){var n=e._fullLayout,i=r.plotinfo,a=n._lastSelectedSubplot&&n._lastSelectedSubplot===i.id,o=t.shiftKey||t.altKey;a&&o&&i.selection&&i.selection.selectionDefs&&!r.selectionDefs?(r.selectionDefs=i.selection.selectionDefs,r.mergedPolygons=i.selection.mergedPolygons):o&&i.selection||T(r),a||(L(e),n._lastSelectedSubplot=i.id)}function T(t){var e=t.plotinfo;e.selection={},e.selection.selectionDefs=t.selectionDefs=[],e.selection.mergedPolygons=t.mergedPolygons=[]}function A(t,e,r,n){var i,a,o,s=[],l=e.map(y),c=r.map(y);for(o=0;o<t.calcdata.length;o++)if(!0===(a=(i=t.calcdata[o])[0].trace).visible&&a._module&&a._module.selectPoints)if(!n||a.subplot!==n&&a.geo!==n)if(\"splom\"===a.type&&a._xaxes[l[0]]&&a._yaxes[c[0]]){var u=p(a._module,i,e[0],r[0]);u.scene=t._fullLayout._splomScenes[a.uid],s.push(u)}else if(\"sankey\"===a.type){var f=p(a._module,i,e[0],r[0]);s.push(f)}else{if(-1===l.indexOf(a.xaxis))continue;if(-1===c.indexOf(a.yaxis))continue;s.push(p(a._module,i,h(t,a.xaxis),h(t,a.yaxis)))}else s.push(p(a._module,i,e[0],r[0]));return s;function p(t,e,r,n){return{_module:t,cd:e,xaxis:r,yaxis:n}}}function M(t,e){var r,n,i=[];for(r=0;r<t.length;r++){var a=t[r];i.push(a.join(\"L\")+\"L\"+a[0])}n=t.length>0?\"M\"+i.join(\"M\")+\"Z\":\"M0,0Z\",e.attr(\"d\",n)}function S(t){var e=t.searchInfo.cd[0].trace,r=t.pointNumber,n=t.pointNumbers,i=n.length>0?n[0]:r;return!!e.selectedpoints&&e.selectedpoints.indexOf(i)>-1}function E(t,e,r){var n,a,o,s;for(n=0;n<e.length;n++){var l=e[n].cd[0].trace._fullInput,c=t._fullLayout._tracePreGUI[l.uid]||{};void 0===c.selectedpoints&&(c.selectedpoints=l._input.selectedpoints||null)}if(r){var u=r.points||[];for(n=0;n<e.length;n++)(s=e[n].cd[0].trace)._input.selectedpoints=s._fullInput.selectedpoints=[],s._fullInput!==s&&(s.selectedpoints=[]);for(n=0;n<u.length;n++){var h=u[n],d=h.data,g=h.fullData;h.pointIndices?([].push.apply(d.selectedpoints,h.pointIndices),s._fullInput!==s&&[].push.apply(g.selectedpoints,h.pointIndices)):(d.selectedpoints.push(h.pointIndex),s._fullInput!==s&&g.selectedpoints.push(h.pointIndex))}}else for(n=0;n<e.length;n++)delete(s=e[n].cd[0].trace).selectedpoints,delete s._input.selectedpoints,s._fullInput!==s&&delete s._fullInput.selectedpoints;var v=!1;for(n=0;n<e.length;n++){s=(o=(a=e[n]).cd)[0].trace,i.traceIs(s,\"regl\")&&(v=!0);var m=a._module,y=m.styleOnSelect||m.style;y&&(y(t,o,o[0].node3),o[0].nodeRangePlot3&&y(t,o,o[0].nodeRangePlot3))}v&&(f(t),p(t))}function C(t,e){if(Array.isArray(t))for(var r=e.cd,n=e.cd[0].trace,i=0;i<t.length;i++)t[i]=u(t[i],n,r);return t}function L(t){var e=(t._fullLayout||{})._zoomlayer;e&&e.selectAll(\".select-outline\").remove()}e.exports={prepSelect:function(t,e,r,i,l){var u,h,f,p,y,b,_,S=i.gd,L=S._fullLayout,P=L._zoomlayer,O=i.element.getBoundingClientRect(),z=i.plotinfo,I=z.xaxis._offset,D=z.yaxis._offset,R=e-O.left,F=r-O.top,B=R,N=F,j=\"M\"+R+\",\"+F,U=i.xaxes[0]._length,V=i.yaxes[0]._length,q=i.xaxes.concat(i.yaxes),H=t.altKey;k(t,S,i),\"lasso\"===l&&(u=v([[R,F]],d.BENDPX));var G=P.selectAll(\"path.select-outline-\"+z.id).data([1,2]);G.enter().append(\"path\").attr(\"class\",function(t){return\"select-outline select-outline-\"+t+\" select-outline-\"+z.id}).attr(\"transform\",\"translate(\"+I+\", \"+D+\")\").attr(\"d\",j+\"Z\");var Y,W=P.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:a.background,stroke:a.defaultLine,\"stroke-width\":1}).attr(\"transform\",\"translate(\"+I+\", \"+D+\")\").attr(\"d\",\"M0,0Z\"),X=L._uid+d.SELECTID,Z=[],J=A(S,i.xaxes,i.yaxes,i.subplot);function K(t,e){return\"log\"===t.type?t.p2d(e):t.p2r(e)}function $(t){var e=\"y\"===t._id.charAt(0)?1:0;return function(r){return K(t,r[e])}}function Q(t,e){return t-e}Y=z.fillRangeItems?z.fillRangeItems:\"select\"===l?function(t,e){var r=t.range={};for(y=0;y<q.length;y++){var n=q[y],i=n._id.charAt(0);r[n._id]=[K(n,e[i+\"min\"]),K(n,e[i+\"max\"])].sort(Q)}}:function(t,e,r){var n=t.lassoPoints={};for(y=0;y<q.length;y++){var i=q[y];n[i._id]=r.filtered.map($(i))}},i.moveFn=function(t,e){B=Math.max(0,Math.min(U,t+R)),N=Math.max(0,Math.min(V,e+F));var r=Math.abs(B-R),a=Math.abs(N-F);if(\"select\"===l){var o=L.selectdirection;\"h\"===(o=\"any\"===L.selectdirection?a<Math.min(.6*r,g)?\"h\":r<Math.min(.6*a,g)?\"v\":\"d\":L.selectdirection)?((p=[[R,0],[R,V],[B,V],[B,0]]).xmin=Math.min(R,B),p.xmax=Math.max(R,B),p.ymin=Math.min(0,V),p.ymax=Math.max(0,V),W.attr(\"d\",\"M\"+p.xmin+\",\"+(F-g)+\"h-4v\"+2*g+\"h4ZM\"+(p.xmax-1)+\",\"+(F-g)+\"h4v\"+2*g+\"h-4Z\")):\"v\"===o?((p=[[0,F],[0,N],[U,N],[U,F]]).xmin=Math.min(0,U),p.xmax=Math.max(0,U),p.ymin=Math.min(F,N),p.ymax=Math.max(F,N),W.attr(\"d\",\"M\"+(R-g)+\",\"+p.ymin+\"v-4h\"+2*g+\"v4ZM\"+(R-g)+\",\"+(p.ymax-1)+\"v4h\"+2*g+\"v-4Z\")):\"d\"===o&&((p=[[R,F],[R,N],[B,N],[B,F]]).xmin=Math.min(R,B),p.xmax=Math.max(R,B),p.ymin=Math.min(F,N),p.ymax=Math.max(F,N),W.attr(\"d\",\"M0,0Z\"))}else\"lasso\"===l&&(u.addPt([B,N]),p=u.filtered);i.selectionDefs&&i.selectionDefs.length?(f=function(t,e,r){return r?n.difference({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions:n.union({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions}(i.mergedPolygons,p,H),p.subtract=H,h=w(i.selectionDefs.concat([p]))):(f=[p],h=m(p)),M(f,G),c.throttle(X,d.SELECTDELAY,function(){var t;Z=[];var e,r=[];for(y=0;y<J.length;y++)if(e=(b=J[y])._module.selectPoints(b,h),r.push(e),t=C(e,b),Z.length)for(var n=0;n<t.length;n++)Z.push(t[n]);else Z=t;E(S,J,_={points:Z}),Y(_,p,u),i.gd.emit(\"plotly_selecting\",_)})},i.clickFn=function(t,e){var r=L.clickmode;W.remove(),c.done(X).then(function(){if(c.clear(X),2===t){for(G.remove(),y=0;y<J.length;y++)(b=J[y])._module.selectPoints(b,!1);E(S,J),T(i),S.emit(\"plotly_deselect\",null)}else r.indexOf(\"select\")>-1&&x(e,S,i.xaxes,i.yaxes,i.subplot,i,G),\"event\"===r&&S.emit(\"plotly_selected\",void 0);o.click(S,e)}).catch(s.error)},i.doneFn=function(){W.remove(),c.done(X).then(function(){c.clear(X),i.gd.emit(\"plotly_selected\",_),p&&i.selectionDefs&&(p.subtract=H,i.selectionDefs.push(p),i.mergedPolygons.length=0,[].push.apply(i.mergedPolygons,f)),i.doneFnCompleted&&i.doneFnCompleted(Z)}).catch(s.error)}},clearSelect:L,selectOnClick:x}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../components/fx/helpers\":628,\"../../lib\":719,\"../../lib/clear_gl_canvases\":704,\"../../lib/polygon\":731,\"../../lib/throttle\":744,\"../../plot_api/subroutines\":758,\"../../registry\":847,\"./axis_ids\":770,\"./constants\":773,polybooljs:473}],785:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=a.cleanNumber,s=a.ms2DateTime,l=a.dateTime2ms,c=a.ensureNumber,u=a.isArrayOrTypedArray,h=t(\"../../constants/numerical\"),f=h.FP_SAFE,p=h.BADNUM,d=h.LOG_CLIP,g=t(\"./constants\"),v=t(\"./axis_ids\");function m(t){return Math.pow(10,t)}function y(t){return null!=t}e.exports=function(t,e){e=e||{};var r=t._id||\"x\",h=r.charAt(0);function x(e,r){if(e>0)return Math.log(e)/Math.LN10;if(e<=0&&r&&t.range&&2===t.range.length){var n=t.range[0],i=t.range[1];return.5*(n+i-2*d*Math.abs(n-i))}return p}function b(e,r,n){var o=l(e,n||t.calendar);if(o===p){if(!i(e))return p;e=+e;var s=Math.floor(10*a.mod(e+.05,1)),c=Math.round(e-s/10);o=l(new Date(c))+s/10}return o}function _(e,r,n){return s(e,r,n||t.calendar)}function w(e){return t._categories[Math.round(e)]}function k(e){if(y(e)){if(void 0===t._categoriesMap&&(t._categoriesMap={}),void 0!==t._categoriesMap[e])return t._categoriesMap[e];t._categories.push(\"number\"==typeof e?String(e):e);var r=t._categories.length-1;return t._categoriesMap[e]=r,r}return p}function T(e){if(t._categoriesMap)return t._categoriesMap[e]}function A(t){var e=T(t);return void 0!==e?e:i(t)?+t:void 0}function M(e){return i(e)?n.round(t._b+t._m*e,2):p}function S(e){return(e-t._b)/t._m}t.c2l=\"log\"===t.type?x:c,t.l2c=\"log\"===t.type?m:c,t.l2p=M,t.p2l=S,t.c2p=\"log\"===t.type?function(t,e){return M(x(t,e))}:M,t.p2c=\"log\"===t.type?function(t){return m(S(t))}:S,-1!==[\"linear\",\"-\"].indexOf(t.type)?(t.d2r=t.r2d=t.d2c=t.r2c=t.d2l=t.r2l=o,t.c2d=t.c2r=t.l2d=t.l2r=c,t.d2p=t.r2p=function(e){return t.l2p(o(e))},t.p2d=t.p2r=S,t.cleanPos=c):\"log\"===t.type?(t.d2r=t.d2l=function(t,e){return x(o(t),e)},t.r2d=t.r2c=function(t){return m(o(t))},t.d2c=t.r2l=o,t.c2d=t.l2r=c,t.c2r=x,t.l2d=m,t.d2p=function(e,r){return t.l2p(t.d2r(e,r))},t.p2d=function(t){return m(S(t))},t.r2p=function(e){return t.l2p(o(e))},t.p2r=S,t.cleanPos=c):\"date\"===t.type?(t.d2r=t.r2d=a.identity,t.d2c=t.r2c=t.d2l=t.r2l=b,t.c2d=t.c2r=t.l2d=t.l2r=_,t.d2p=t.r2p=function(e,r,n){return t.l2p(b(e,0,n))},t.p2d=t.p2r=function(t,e,r){return _(S(t),e,r)},t.cleanPos=function(e){return a.cleanDate(e,p,t.calendar)}):\"category\"===t.type?(t.d2c=t.d2l=k,t.r2d=t.c2d=t.l2d=w,t.d2r=t.d2l_noadd=A,t.r2c=function(e){var r=A(e);return void 0!==r?r:t.fraction2r(.5)},t.l2r=t.c2r=c,t.r2l=A,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return w(S(t))},t.r2p=t.d2p,t.p2r=S,t.cleanPos=function(t){return\"string\"==typeof t&&\"\"!==t?t:c(t)}):\"multicategory\"===t.type&&(t.r2d=t.c2d=t.l2d=w,t.d2r=t.d2l_noadd=A,t.r2c=function(e){var r=A(e);return void 0!==r?r:t.fraction2r(.5)},t.r2c_just_indices=T,t.l2r=t.c2r=c,t.r2l=A,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return w(S(t))},t.r2p=t.d2p,t.p2r=S,t.cleanPos=function(t){return Array.isArray(t)||\"string\"==typeof t&&\"\"!==t?t:c(t)},t.setupMultiCategory=function(n){var i,o,s=t._traceIndices,l=e._axisMatchGroups;if(l&&l.length&&0===t._categories.length)for(i=0;i<l.length;i++){var c=l[i];if(c[r])for(var f in c)if(f!==r){var p=e[v.id2name(f)];s=s.concat(p._traceIndices)}}var d=[[0,{}],[0,{}]],g=[];for(i=0;i<s.length;i++){var m=n[s[i]];if(h in m){var x=m[h],b=m._length||a.minRowLength(x);if(u(x[0])&&u(x[1]))for(o=0;o<b;o++){var _=x[0][o],w=x[1][o];y(_)&&y(w)&&(g.push([_,w]),_ in d[0][1]||(d[0][1][_]=d[0][0]++),w in d[1][1]||(d[1][1][w]=d[1][0]++))}}}for(g.sort(function(t,e){var r=d[0][1],n=r[t[0]]-r[e[0]];if(n)return n;var i=d[1][1];return i[t[1]]-i[e[1]]}),i=0;i<g.length;i++)k(g[i])}),t.fraction2r=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return t.l2r(r+e*(n-r))},t.r2fraction=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return(t.r2l(e)-r)/(n-r)},t.cleanRange=function(e,r){r||(r={}),e||(e=\"range\");var n,o,s=a.nestedProperty(t,e).get();if(o=(o=\"date\"===t.type?a.dfltRange(t.calendar):\"y\"===h?g.DFLTRANGEY:r.dfltRange||g.DFLTRANGEX).slice(),s&&2===s.length)for(\"date\"!==t.type||t.autorange||(s[0]=a.cleanDate(s[0],p,t.calendar),s[1]=a.cleanDate(s[1],p,t.calendar)),n=0;n<2;n++)if(\"date\"===t.type){if(!a.isDateTime(s[n],t.calendar)){t[e]=o;break}if(t.r2l(s[0])===t.r2l(s[1])){var l=a.constrain(t.r2l(s[0]),a.MIN_MS+1e3,a.MAX_MS-1e3);s[0]=t.l2r(l-1e3),s[1]=t.l2r(l+1e3);break}}else{if(!i(s[n])){if(!i(s[1-n])){t[e]=o;break}s[n]=s[1-n]*(n?10:.1)}if(s[n]<-f?s[n]=-f:s[n]>f&&(s[n]=f),s[0]===s[1]){var c=Math.max(1,Math.abs(1e-6*s[0]));s[0]-=c,s[1]+=c}}else a.nestedProperty(t,e).set(o)},t.setScale=function(r){var n=e._size;if(t.overlaying){var i=v.getFromId({_fullLayout:e},t.overlaying);t.domain=i.domain}var a=r&&t._r?\"_r\":\"range\",o=t.calendar;t.cleanRange(a);var s=t.r2l(t[a][0],o),l=t.r2l(t[a][1],o);if(\"y\"===h?(t._offset=n.t+(1-t.domain[1])*n.h,t._length=n.h*(t.domain[1]-t.domain[0]),t._m=t._length/(s-l),t._b=-t._m*l):(t._offset=n.l+t.domain[0]*n.w,t._length=n.w*(t.domain[1]-t.domain[0]),t._m=t._length/(l-s),t._b=-t._m*s),!isFinite(t._m)||!isFinite(t._b)||t._length<0)throw e._replotting=!1,new Error(\"Something went wrong with axis scaling\")},t.makeCalcdata=function(e,r){var n,i,o,s,l=t.type,c=\"date\"===l&&e[r+\"calendar\"];if(r in e){if(n=e[r],s=e._length||a.minRowLength(n),a.isTypedArray(n)&&(\"linear\"===l||\"log\"===l)){if(s===n.length)return n;if(n.subarray)return n.subarray(0,s)}if(\"multicategory\"===l)return function(t,e){for(var r=new Array(e),n=0;n<e;n++){var i=(t[0]||[])[n],a=(t[1]||[])[n];r[n]=T([i,a])}return r}(n,s);for(i=new Array(s),o=0;o<s;o++)i[o]=t.d2c(n[o],0,c)}else{var u=r+\"0\"in e?t.d2c(e[r+\"0\"],0,c):0,h=e[\"d\"+r]?Number(e[\"d\"+r]):1;for(n=e[{x:\"y\",y:\"x\"}[r]],s=e._length||n.length,i=new Array(s),o=0;o<s;o++)i[o]=u+o*h}return i},t.isValidRange=function(e){return Array.isArray(e)&&2===e.length&&i(t.r2l(e[0]))&&i(t.r2l(e[1]))},t.isPtWithinRange=function(e,r){var n=t.c2l(e[h],null,r),i=t.r2l(t.range[0]),a=t.r2l(t.range[1]);return i<a?i<=n&&n<=a:a<=n&&n<=i},t.clearCalc=function(){var n=function(){t._categories=[],t._categoriesMap={}},i=e._axisMatchGroups;if(i&&i.length){for(var a=!1,o=0;o<i.length;o++){var s=i[o];if(s[r]){a=!0;var l=null,c=null;for(var u in s){var h=e[v.id2name(u)];if(h._categories){l=h._categories,c=h._categoriesMap;break}}l&&c?(t._categories=l,t._categoriesMap=c):n();break}}a||n()}else n();if(t._initialCategories)for(var f=0;f<t._initialCategories.length;f++)k(t._initialCategories[f])},t.sortByInitialCategories=function(){var n=[];if(t._categories=[],t._categoriesMap={},t._initialCategories)for(var i=0;i<t._initialCategories.length;i++)k(t._initialCategories[i]);n=n.concat(t._traceIndices);var a=t._matchGroup;for(var o in a)if(r!==o){var s=e[v.id2name(o)];s._categories=t._categories,s._categoriesMap=t._categoriesMap,n=n.concat(s._traceIndices)}return n};var E=e._d3locale;\"date\"===t.type&&(t._dateFormat=E?E.timeFormat.utc:n.time.format.utc,t._extraFormat=e._extraFormat),t._separators=e.separators,t._numFormat=E?E.numberFormat:n.format,delete t._minDtick,delete t._forceTick0}},{\"../../constants/numerical\":695,\"../../lib\":719,\"./axis_ids\":770,\"./constants\":773,d3:163,\"fast-isnumeric\":225}],786:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"../array_container_defaults\");function o(t){var e=[\"showexponent\",\"showtickprefix\",\"showticksuffix\"].filter(function(e){return void 0!==t[e]});if(e.every(function(r){return t[r]===t[e[0]]})||1===e.length)return t[e[0]]}function s(t,e){function r(r,a){return n.coerce(t,e,i.tickformatstops,r,a)}r(\"enabled\")&&(r(\"dtickrange\"),r(\"value\"))}e.exports=function(t,e,r,l,c,u){u&&1!==u.pass||function(t,e,r,n,i){var a=o(t);r(\"tickprefix\")&&r(\"showtickprefix\",a);r(\"ticksuffix\",i.tickSuffixDflt)&&r(\"showticksuffix\",a)}(t,0,r,0,c),u&&2!==u.pass||function(t,e,r,l,c){var u=o(t);r(\"tickprefix\")&&r(\"showtickprefix\",u);r(\"ticksuffix\",c.tickSuffixDflt)&&r(\"showticksuffix\",u);if(r(\"showticklabels\")){var h=c.font||{},f=e.color,p=f&&f!==i.color.dflt?f:h.color;if(n.coerceFont(r,\"tickfont\",{family:h.family,size:h.size,color:p}),r(\"tickangle\"),\"category\"!==l){var d=r(\"tickformat\"),g=t.tickformatstops;Array.isArray(g)&&g.length&&a(t,e,{name:\"tickformatstops\",inclusionAttr:\"enabled\",handleItemDefaults:s}),d||\"date\"===l||(r(\"showexponent\",u),r(\"exponentformat\"),r(\"separatethousands\"))}}}(t,e,r,l,c)}},{\"../../lib\":719,\"../array_container_defaults\":763,\"./layout_attributes\":779}],787:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r,a){var o=n.coerce2(t,e,i,\"ticklen\"),s=n.coerce2(t,e,i,\"tickwidth\"),l=n.coerce2(t,e,i,\"tickcolor\",e.color);r(\"ticks\",a.outerTicks||o||s||l?\"outside\":\"\")||(delete e.ticklen,delete e.tickwidth,delete e.tickcolor)}},{\"../../lib\":719,\"./layout_attributes\":779}],788:[function(t,e,r){\"use strict\";var n=t(\"./clean_ticks\");e.exports=function(t,e,r,i){var a;\"array\"!==t.tickmode||\"log\"!==i&&\"date\"!==i?a=r(\"tickmode\",Array.isArray(t.tickvals)?\"array\":t.dtick?\"linear\":\"auto\"):a=e.tickmode=\"auto\";if(\"auto\"===a)r(\"nticks\");else if(\"linear\"===a){var o=e.dtick=n.dtick(t.dtick,i);e.tick0=n.tick0(t.tick0,i,e.calendar,o)}else if(\"multicategory\"!==i){void 0===r(\"tickvals\")?e.tickmode=\"auto\":r(\"ticktext\")}}},{\"./clean_ticks\":772}],789:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../components/drawing\"),o=t(\"./axes\");e.exports=function(t,e,r,s){var l=t._fullLayout;if(0!==e.length){var c,u,h,f;s&&(c=s());var p=n.ease(r.easing);return t._transitionData._interruptCallbacks.push(function(){return window.cancelAnimationFrame(f),f=null,function(){for(var r={},n=0;n<e.length;n++){var a=e[n];a.xr0&&(r[a.plotinfo.xaxis._name+\".range\"]=a.xr0.slice()),a.yr0&&(r[a.plotinfo.yaxis._name+\".range\"]=a.yr0.slice())}return i.call(\"relayout\",t,r).then(function(){for(var t=0;t<e.length;t++)d(e[t].plotinfo)})}()}),u=Date.now(),f=window.requestAnimationFrame(function n(){h=Date.now();for(var a=Math.min(1,(h-u)/r.duration),o=p(a),s=0;s<e.length;s++)g(e[s],o);h-u>r.duration?(function(){for(var r={},n=0;n<e.length;n++){var a=e[n];a.xr1&&(r[a.plotinfo.xaxis._name+\".range\"]=a.xr1.slice()),a.yr1&&(r[a.plotinfo.yaxis._name+\".range\"]=a.yr1.slice())}c&&c(),i.call(\"relayout\",t,r).then(function(){for(var t=0;t<e.length;t++)d(e[t].plotinfo)})}(),f=window.cancelAnimationFrame(n)):f=window.requestAnimationFrame(n)}),Promise.resolve()}function d(t){var e=t.xaxis,r=t.yaxis;l._defs.select(\"#\"+t.clipId+\"> rect\").call(a.setTranslate,0,0).call(a.setScale,1,1),t.plot.call(a.setTranslate,e._offset,r._offset).call(a.setScale,1,1);var n=t.plot.selectAll(\".scatterlayer .trace\");n.selectAll(\".point\").call(a.setPointGroupScale,1,1),n.selectAll(\".textpoint\").call(a.setTextPointsScale,1,1),n.call(a.hideOutsideRangePoints,t)}function g(e,r){var n=e.plotinfo,i=n.xaxis,s=n.yaxis,l=e.xr0,c=e.xr1,u=i._length,h=e.yr0,f=e.yr1,p=s._length,d=!!c,g=!!f,v=[];if(d){var m=l[1]-l[0],y=c[1]-c[0];v[0]=(l[0]*(1-r)+r*c[0]-l[0])/(l[1]-l[0])*u,v[2]=u*(1-r+r*y/m),i.range[0]=l[0]*(1-r)+r*c[0],i.range[1]=l[1]*(1-r)+r*c[1]}else v[0]=0,v[2]=u;if(g){var x=h[1]-h[0],b=f[1]-f[0];v[1]=(h[1]*(1-r)+r*f[1]-h[1])/(h[0]-h[1])*p,v[3]=p*(1-r+r*b/x),s.range[0]=h[0]*(1-r)+r*f[0],s.range[1]=h[1]*(1-r)+r*f[1]}else v[1]=0,v[3]=p;o.drawOne(t,i,{skipTitle:!0}),o.drawOne(t,s,{skipTitle:!0}),o.redrawComponents(t,[i._id,s._id]);var _=d?u/v[2]:1,w=g?p/v[3]:1,k=d?v[0]:0,T=g?v[1]:0,A=d?v[0]/v[2]*u:0,M=g?v[1]/v[3]*p:0,S=i._offset-A,E=s._offset-M;n.clipRect.call(a.setTranslate,k,T).call(a.setScale,1/_,1/w),n.plot.call(a.setTranslate,S,E).call(a.setScale,_,w),a.setPointGroupScale(n.zoomScalePts,1/_,1/w),a.setTextPointsScale(n.zoomScaleTxt,1/_,1/w)}o.redrawComponents(t)}},{\"../../components/drawing\":614,\"../../registry\":847,\"./axes\":767,d3:163}],790:[function(t,e,r){\"use strict\";var n=t(\"../../registry\").traceIs,i=t(\"./axis_autotype\");function a(t){return{v:\"x\",h:\"y\"}[t.orientation||\"v\"]}function o(t,e){var r=a(t),i=n(t,\"box-violin\"),o=n(t._fullInput||{},\"candlestick\");return i&&!o&&e===r&&void 0===t[r]&&void 0===t[r+\"0\"]}e.exports=function(t,e,r,s){\"-\"===r(\"type\",(s.splomStash||{}).type)&&(!function(t,e){if(\"-\"!==t.type)return;var r=t._id,s=r.charAt(0);-1!==r.indexOf(\"scene\")&&(r=s);var l=function(t,e,r){for(var n=0;n<t.length;n++){var i=t[n];if(\"splom\"===i.type&&i._length>0&&(i[\"_\"+r+\"axes\"]||{})[e])return i;if((i[r+\"axis\"]||r)===e){if(o(i,r))return i;if((i[r]||[]).length||i[r+\"0\"])return i}}}(e,r,s);if(!l)return;if(\"histogram\"===l.type&&s==={v:\"y\",h:\"x\"}[l.orientation||\"v\"])return void(t.type=\"linear\");var c,u=s+\"calendar\",h=l[u],f={noMultiCategory:!n(l,\"cartesian\")||n(l,\"noMultiCategory\")};if(o(l,s)){var p=a(l),d=[];for(c=0;c<e.length;c++){var g=e[c];n(g,\"box-violin\")&&(g[s+\"axis\"]||s)===r&&(void 0!==g[p]?d.push(g[p][0]):void 0!==g.name?d.push(g.name):d.push(\"text\"),g[u]!==h&&(h=void 0))}t.type=i(d,h,f)}else if(\"splom\"===l.type){var v=l.dimensions,m=v[l._axesDim[r]];m.visible&&(t.type=i(m.values,h,f))}else t.type=i(l[s]||[l[s+\"0\"]],h,f)}(e,s.data),\"-\"===e.type?e.type=\"linear\":t.type=e.type)}},{\"../../registry\":847,\"./axis_autotype\":768}],791:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\");function a(t,e,r){var n,a,o,s=!1;if(\"data\"===e.type)n=t._fullData[null!==e.traces?e.traces[0]:0];else{if(\"layout\"!==e.type)return!1;n=t._fullLayout}return a=i.nestedProperty(n,e.prop).get(),(o=r[e.type]=r[e.type]||{}).hasOwnProperty(e.prop)&&o[e.prop]!==a&&(s=!0),o[e.prop]=a,{changed:s,value:a}}function o(t,e){var r=[],n=e[0],a={};if(\"string\"==typeof n)a[n]=e[1];else{if(!i.isPlainObject(n))return r;a=n}return l(a,function(t,e,n){r.push({type:\"layout\",prop:t,value:n})},\"\",0),r}function s(t,e){var r,n,a,o,s=[];if(n=e[0],a=e[1],r=e[2],o={},\"string\"==typeof n)o[n]=a;else{if(!i.isPlainObject(n))return s;o=n,void 0===r&&(r=a)}return void 0===r&&(r=null),l(o,function(e,n,i){var a,o;if(Array.isArray(i)){o=i.slice();var l=Math.min(o.length,t.data.length);r&&(l=Math.min(l,r.length)),a=[];for(var c=0;c<l;c++)a[c]=r?r[c]:c}else o=i,a=r?r.slice():null;if(null===a)Array.isArray(o)&&(o=o[0]);else if(Array.isArray(a)){if(!Array.isArray(o)){var u=o;o=[];for(var h=0;h<a.length;h++)o[h]=u}o.length=Math.min(a.length,o.length)}s.push({type:\"data\",prop:e,traces:a,value:o})},\"\",0),s}function l(t,e,r,n){Object.keys(t).forEach(function(a){var o=t[a];if(\"_\"!==a[0]){var s=r+(n>0?\".\":\"\")+a;i.isPlainObject(o)?l(o,e,s,n+1):e(s,a,o)}})}r.manageCommandObserver=function(t,e,n,o){var s={},l=!0;e&&e._commandObserver&&(s=e._commandObserver),s.cache||(s.cache={}),s.lookupTable={};var c=r.hasSimpleAPICommandBindings(t,n,s.lookupTable);if(e&&e._commandObserver){if(c)return s;if(e._commandObserver.remove)return e._commandObserver.remove(),e._commandObserver=null,s}if(c){a(t,c,s.cache),s.check=function(){if(l){var e=a(t,c,s.cache);return e.changed&&o&&void 0!==s.lookupTable[e.value]&&(s.disable(),Promise.resolve(o({value:e.value,type:c.type,prop:c.prop,traces:c.traces,index:s.lookupTable[e.value]})).then(s.enable,s.enable)),e.changed}};for(var u=[\"plotly_relayout\",\"plotly_redraw\",\"plotly_restyle\",\"plotly_update\",\"plotly_animatingframe\",\"plotly_afterplot\"],h=0;h<u.length;h++)t._internalOn(u[h],s.check);s.remove=function(){for(var e=0;e<u.length;e++)t._removeInternalListener(u[e],s.check)}}else i.log(\"Unable to automatically bind plot updates to API command\"),s.lookupTable={},s.remove=function(){};return s.disable=function(){l=!1},s.enable=function(){l=!0},e&&(e._commandObserver=s),s},r.hasSimpleAPICommandBindings=function(t,e,n){var i,a,o=e.length;for(i=0;i<o;i++){var s,l=e[i],c=l.method,u=l.args;if(Array.isArray(u)||(u=[]),!c)return!1;var h=r.computeAPICommandBindings(t,c,u);if(1!==h.length)return!1;if(a){if((s=h[0]).type!==a.type)return!1;if(s.prop!==a.prop)return!1;if(Array.isArray(a.traces)){if(!Array.isArray(s.traces))return!1;s.traces.sort();for(var f=0;f<a.traces.length;f++)if(a.traces[f]!==s.traces[f])return!1}else if(s.prop!==a.prop)return!1}else a=h[0],Array.isArray(a.traces)&&a.traces.sort();var p=(s=h[0]).value;if(Array.isArray(p)){if(1!==p.length)return!1;p=p[0]}n&&(n[p]=i)}return a},r.executeAPICommand=function(t,e,r){if(\"skip\"===e)return Promise.resolve();var a=n.apiMethodRegistry[e],o=[t];Array.isArray(r)||(r=[]);for(var s=0;s<r.length;s++)o.push(r[s]);return a.apply(null,o).catch(function(t){return i.warn(\"API call to Plotly.\"+e+\" rejected.\",t),Promise.reject(t)})},r.computeAPICommandBindings=function(t,e,r){var n;switch(Array.isArray(r)||(r=[]),e){case\"restyle\":n=s(t,r);break;case\"relayout\":n=o(t,r);break;case\"update\":n=s(t,[r[0],r[2]]).concat(o(t,[r[1]]));break;case\"animate\":n=function(t,e){return Array.isArray(e[0])&&1===e[0].length&&-1!==[\"string\",\"number\"].indexOf(typeof e[0][0])?[{type:\"layout\",prop:\"_currentFrame\",value:e[0][0].toString()}]:[]}(0,r);break;default:n=[]}return n}},{\"../lib\":719,\"../registry\":847}],792:[function(t,e,r){\"use strict\";var n=t(\"../lib/extend\").extendFlat;r.attributes=function(t,e){e=e||{};var r={valType:\"info_array\",editType:(t=t||{}).editType,items:[{valType:\"number\",min:0,max:1,editType:t.editType},{valType:\"number\",min:0,max:1,editType:t.editType}],dflt:[0,1]},i=(t.name&&t.name,t.trace,e.description&&e.description,{x:n({},r,{}),y:n({},r,{}),editType:t.editType});return t.noGridCell||(i.row={valType:\"integer\",min:0,dflt:0,editType:t.editType},i.column={valType:\"integer\",min:0,dflt:0,editType:t.editType}),i},r.defaults=function(t,e,r,n){var i=n&&n.x||[0,1],a=n&&n.y||[0,1],o=e.grid;if(o){var s=r(\"domain.column\");void 0!==s&&(s<o.columns?i=o._domains.x[s]:delete t.domain.column);var l=r(\"domain.row\");void 0!==l&&(l<o.rows?a=o._domains.y[l]:delete t.domain.row)}r(\"domain.x\",i),r(\"domain.y\",a)}},{\"../lib/extend\":710}],793:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType,r=t.colorEditType;void 0===r&&(r=e);var n={family:{valType:\"string\",noBlank:!0,strict:!0,editType:e},size:{valType:\"number\",min:1,editType:e},color:{valType:\"color\",editType:r},editType:e};return t.arrayOk&&(n.family.arrayOk=!0,n.size.arrayOk=!0,n.color.arrayOk=!0),n}},{}],794:[function(t,e,r){\"use strict\";e.exports={_isLinkedToArray:\"frames_entry\",group:{valType:\"string\"},name:{valType:\"string\"},traces:{valType:\"any\"},baseframe:{valType:\"string\"},data:{valType:\"any\"},layout:{valType:\"any\"}}},{}],795:[function(t,e,r){\"use strict\";r.projNames={equirectangular:\"equirectangular\",mercator:\"mercator\",orthographic:\"orthographic\",\"natural earth\":\"naturalEarth\",kavrayskiy7:\"kavrayskiy7\",miller:\"miller\",robinson:\"robinson\",eckert4:\"eckert4\",\"azimuthal equal area\":\"azimuthalEqualArea\",\"azimuthal equidistant\":\"azimuthalEquidistant\",\"conic equal area\":\"conicEqualArea\",\"conic conformal\":\"conicConformal\",\"conic equidistant\":\"conicEquidistant\",gnomonic:\"gnomonic\",stereographic:\"stereographic\",mollweide:\"mollweide\",hammer:\"hammer\",\"transverse mercator\":\"transverseMercator\",\"albers usa\":\"albersUsa\",\"winkel tripel\":\"winkel3\",aitoff:\"aitoff\",sinusoidal:\"sinusoidal\"},r.axesNames=[\"lonaxis\",\"lataxis\"],r.lonaxisSpan={orthographic:180,\"azimuthal equal area\":360,\"azimuthal equidistant\":360,\"conic conformal\":180,gnomonic:160,stereographic:180,\"transverse mercator\":180,\"*\":360},r.lataxisSpan={\"conic conformal\":150,stereographic:179.5,\"*\":180},r.scopeDefaults={world:{lonaxisRange:[-180,180],lataxisRange:[-90,90],projType:\"equirectangular\",projRotate:[0,0,0]},usa:{lonaxisRange:[-180,-50],lataxisRange:[15,80],projType:\"albers usa\"},europe:{lonaxisRange:[-30,60],lataxisRange:[30,85],projType:\"conic conformal\",projRotate:[15,0,0],projParallels:[0,60]},asia:{lonaxisRange:[22,160],lataxisRange:[-15,55],projType:\"mercator\",projRotate:[0,0,0]},africa:{lonaxisRange:[-30,60],lataxisRange:[-40,40],projType:\"mercator\",projRotate:[0,0,0]},\"north america\":{lonaxisRange:[-180,-45],lataxisRange:[5,85],projType:\"conic conformal\",projRotate:[-100,0,0],projParallels:[29.5,45.5]},\"south america\":{lonaxisRange:[-100,-30],lataxisRange:[-60,15],projType:\"mercator\",projRotate:[0,0,0]}},r.clipPad=.001,r.precision=.1,r.landColor=\"#F0DC82\",r.waterColor=\"#3399FF\",r.locationmodeToLayer={\"ISO-3\":\"countries\",\"USA-states\":\"subunits\",\"country names\":\"countries\"},r.sphereSVG={type:\"Sphere\"},r.fillLayers={ocean:1,land:1,lakes:1},r.lineLayers={subunits:1,countries:1,coastlines:1,rivers:1,frame:1},r.layers=[\"bg\",\"ocean\",\"land\",\"lakes\",\"subunits\",\"countries\",\"coastlines\",\"rivers\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"frontplot\"],r.layersForChoropleth=[\"bg\",\"ocean\",\"land\",\"subunits\",\"countries\",\"coastlines\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"rivers\",\"lakes\",\"frontplot\"],r.layerNameToAdjective={ocean:\"ocean\",land:\"land\",lakes:\"lake\",subunits:\"subunit\",countries:\"country\",coastlines:\"coastline\",rivers:\"river\",frame:\"frame\"}},{}],796:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"../../components/fx\"),c=t(\"../plots\"),u=t(\"../cartesian/axes\"),h=t(\"../../components/dragelement\"),f=t(\"../cartesian/select\").prepSelect,p=t(\"../cartesian/select\").selectOnClick,d=t(\"./zoom\"),g=t(\"./constants\"),v=t(\"../../lib/topojson_utils\"),m=t(\"topojson-client\").feature;function y(t){this.id=t.id,this.graphDiv=t.graphDiv,this.container=t.container,this.topojsonURL=t.topojsonURL,this.isStatic=t.staticPlot,this.topojsonName=null,this.topojson=null,this.projection=null,this.scope=null,this.viewInitial=null,this.fitScale=null,this.bounds=null,this.midPt=null,this.hasChoropleth=!1,this.traceHash={},this.layers={},this.basePaths={},this.dataPaths={},this.dataPoints={},this.clipDef=null,this.clipRect=null,this.bgRect=null,this.makeFramework()}t(\"./projections\")(n);var x=y.prototype;e.exports=function(t){return new y(t)},x.plot=function(t,e,r){var n=this,i=e[this.id],a=!1;for(var o in g.layerNameToAdjective)if(\"frame\"!==o&&i[\"show\"+o]){a=!0;break}for(var s=0;s<t.length;s++)if(t[0][0].trace.locationmode){a=!0;break}if(!a)return n.update(t,e);var l=v.getTopojsonName(i);null===n.topojson||l!==n.topojsonName?(n.topojsonName=l,void 0===PlotlyGeoAssets.topojson[n.topojsonName]?r.push(n.fetchTopojson().then(function(r){PlotlyGeoAssets.topojson[n.topojsonName]=r,n.topojson=r,n.update(t,e)})):(n.topojson=PlotlyGeoAssets.topojson[n.topojsonName],n.update(t,e))):n.update(t,e)},x.fetchTopojson=function(){var t=v.getTopojsonPath(this.topojsonURL,this.topojsonName);return new Promise(function(e,r){n.json(t,function(n,i){if(n)return 404===n.status?r(new Error([\"plotly.js could not find topojson file at\",t,\".\",\"Make sure the *topojsonURL* plot config option\",\"is set properly.\"].join(\" \"))):r(new Error([\"unexpected error while fetching topojson file at\",t].join(\" \")));e(i)})})},x.update=function(t,e){var r=e[this.id];if(!this.updateProjection(e,r)){this.hasChoropleth=!1;for(var n=0;n<t.length;n++)if(\"choropleth\"===t[n][0].trace.type){this.hasChoropleth=!0;break}this.viewInitial&&this.scope===r.scope||this.saveViewInitial(r),this.scope=r.scope,this.updateBaseLayers(e,r),this.updateDims(e,r),this.updateFx(e,r),c.generalUpdatePerTraceModule(this.graphDiv,this,t,r);var i=this.layers.frontplot.select(\".scatterlayer\");this.dataPoints.point=i.selectAll(\".point\"),this.dataPoints.text=i.selectAll(\"text\"),this.dataPaths.line=i.selectAll(\".js-line\");var a=this.layers.backplot.select(\".choroplethlayer\");this.dataPaths.choropleth=a.selectAll(\"path\"),this.render()}},x.updateProjection=function(t,e){var r=t._size,o=e.domain,s=e.projection,l=s.rotation||{},c=e.center||{},u=this.projection=function(t){for(var e=t.projection.type,r=n.geo[g.projNames[e]](),i=t._isClipped?g.lonaxisSpan[e]/2:null,a=[\"center\",\"rotate\",\"parallels\",\"clipExtent\"],o=function(t){return t?r:[]},s=0;s<a.length;s++){var l=a[s];\"function\"!=typeof r[l]&&(r[l]=o)}r.isLonLatOverEdges=function(t){if(null===r(t))return!0;if(i){var e=r.rotate();return n.geo.distance(t,[-e[0],-e[1]])>i*Math.PI/180}return!1},r.getPath=function(){return n.geo.path().projection(r)},r.getBounds=function(t){return r.getPath().bounds(t)},r.fitExtent=function(t,e){var n=t[1][0]-t[0][0],i=t[1][1]-t[0][1],a=r.clipExtent&&r.clipExtent();r.scale(150).translate([0,0]),a&&r.clipExtent(null);var o=r.getBounds(e),s=Math.min(n/(o[1][0]-o[0][0]),i/(o[1][1]-o[0][1])),l=+t[0][0]+(n-s*(o[1][0]+o[0][0]))/2,c=+t[0][1]+(i-s*(o[1][1]+o[0][1]))/2;return a&&r.clipExtent(a),r.scale(150*s).translate([l,c])},r.precision(g.precision),i&&r.clipAngle(i-g.clipPad);return r}(e);u.center([c.lon-l.lon,c.lat-l.lat]).rotate([-l.lon,-l.lat,l.roll]).parallels(s.parallels);var h=[[r.l+r.w*o.x[0],r.t+r.h*(1-o.y[1])],[r.l+r.w*o.x[1],r.t+r.h*(1-o.y[0])]],f=e.lonaxis,p=e.lataxis,d=function(t,e){var r=g.clipPad,n=t[0]+r,i=t[1]-r,a=e[0]+r,o=e[1]-r;n>0&&i<0&&(i+=360);var s=(i-n)/4;return{type:\"Polygon\",coordinates:[[[n,a],[n,o],[n+s,o],[n+2*s,o],[n+3*s,o],[i,o],[i,a],[i-s,a],[i-2*s,a],[i-3*s,a],[n,a]]]}}(f.range,p.range);u.fitExtent(h,d);var v=this.bounds=u.getBounds(d),m=this.fitScale=u.scale(),y=u.translate();if(!isFinite(v[0][0])||!isFinite(v[0][1])||!isFinite(v[1][0])||!isFinite(v[1][1])||isNaN(y[0])||isNaN(y[0])){for(var x=this.graphDiv,b=[\"projection.rotation\",\"center\",\"lonaxis.range\",\"lataxis.range\"],_=\"Invalid geo settings, relayout'ing to default view.\",w={},k=0;k<b.length;k++)w[this.id+\".\"+b[k]]=null;return this.viewInitial=null,a.warn(_),x._promises.push(i.call(\"relayout\",x,w)),_}var T=this.midPt=[(v[0][0]+v[1][0])/2,(v[0][1]+v[1][1])/2];if(u.scale(s.scale*m).translate([y[0]+(T[0]-y[0]),y[1]+(T[1]-y[1])]).clipExtent(v),e._isAlbersUsa){var A=u([c.lon,c.lat]),M=u.translate();u.translate([M[0]-(A[0]-M[0]),M[1]-(A[1]-M[1])])}},x.updateBaseLayers=function(t,e){var r=this,i=r.topojson,a=r.layers,l=r.basePaths;function c(t){return\"lonaxis\"===t||\"lataxis\"===t}function h(t){return Boolean(g.lineLayers[t])}function f(t){return Boolean(g.fillLayers[t])}var p=(this.hasChoropleth?g.layersForChoropleth:g.layers).filter(function(t){return h(t)||f(t)?e[\"show\"+t]:!c(t)||e[t].showgrid}),d=r.framework.selectAll(\".layer\").data(p,String);d.exit().each(function(t){delete a[t],delete l[t],n.select(this).remove()}),d.enter().append(\"g\").attr(\"class\",function(t){return\"layer \"+t}).each(function(t){var e=a[t]=n.select(this);\"bg\"===t?r.bgRect=e.append(\"rect\").style(\"pointer-events\",\"all\"):c(t)?l[t]=e.append(\"path\").style(\"fill\",\"none\"):\"backplot\"===t?e.append(\"g\").classed(\"choroplethlayer\",!0):\"frontplot\"===t?e.append(\"g\").classed(\"scatterlayer\",!0):h(t)?l[t]=e.append(\"path\").style(\"fill\",\"none\").style(\"stroke-miterlimit\",2):f(t)&&(l[t]=e.append(\"path\").style(\"stroke\",\"none\"))}),d.order(),d.each(function(r){var n=l[r],a=g.layerNameToAdjective[r];\"frame\"===r?n.datum(g.sphereSVG):h(r)||f(r)?n.datum(m(i,i.objects[r])):c(r)&&n.datum(function(t,e,r){var n,i,a,o=e[t],s=g.scopeDefaults[e.scope];\"lonaxis\"===t?(n=s.lonaxisRange,i=s.lataxisRange,a=function(t,e){return[t,e]}):\"lataxis\"===t&&(n=s.lataxisRange,i=s.lonaxisRange,a=function(t,e){return[e,t]});var l={type:\"linear\",range:[n[0],n[1]-1e-6],tick0:o.tick0,dtick:o.dtick};u.setConvert(l,r);var c=u.calcTicks(l);e.isScoped||\"lonaxis\"!==t||c.pop();for(var h=c.length,f=new Array(h),p=0;p<h;p++)for(var d=c[p].x,v=f[p]=[],m=i[0];m<i[1]+2.5;m+=2.5)v.push(a(d,m));return{type:\"MultiLineString\",coordinates:f}}(r,e,t)).call(o.stroke,e[r].gridcolor).call(s.dashLine,\"\",e[r].gridwidth),h(r)?n.call(o.stroke,e[a+\"color\"]).call(s.dashLine,\"\",e[a+\"width\"]):f(r)&&n.call(o.fill,e[a+\"color\"])})},x.updateDims=function(t,e){var r=this.bounds,n=(e.framewidth||0)/2,i=r[0][0]-n,a=r[0][1]-n,l=r[1][0]-i+n,c=r[1][1]-a+n;s.setRect(this.clipRect,i,a,l,c),this.bgRect.call(s.setRect,i,a,l,c).call(o.fill,e.bgcolor),this.xaxis._offset=i,this.xaxis._length=l,this.yaxis._offset=a,this.yaxis._length=c},x.updateFx=function(t,e){var r=this,a=r.graphDiv,o=r.bgRect,s=t.dragmode,c=t.clickmode;if(!r.isStatic){var u;\"select\"===s?u=function(t,e){(t.range={})[r.id]=[v([e.xmin,e.ymin]),v([e.xmax,e.ymax])]}:\"lasso\"===s&&(u=function(t,e,n){(t.lassoPoints={})[r.id]=n.filtered.map(v)});var g={element:r.bgRect.node(),gd:a,plotinfo:{id:r.id,xaxis:r.xaxis,yaxis:r.yaxis,fillRangeItems:u},xaxes:[r.xaxis],yaxes:[r.yaxis],subplot:r.id,clickFn:function(e){2===e&&t._zoomlayer.selectAll(\".select-outline\").remove()}};\"pan\"===s?(o.node().onmousedown=null,o.call(d(r,e)),o.on(\"dblclick.zoom\",function(){var t=r.viewInitial,e={};for(var n in t)e[r.id+\".\"+n]=t[n];i.call(\"_guiRelayout\",a,e),a.emit(\"plotly_doubleclick\",null)}),a._context._scrollZoom.geo||o.on(\"wheel.zoom\",null)):\"select\"!==s&&\"lasso\"!==s||(o.on(\".zoom\",null),g.prepFn=function(t,e,r){f(t,e,r,g,s)},h.init(g)),o.on(\"mousemove\",function(){var t=r.projection.invert(n.mouse(this));if(!t||isNaN(t[0])||isNaN(t[1]))return h.unhover(a,n.event);r.xaxis.p2c=function(){return t[0]},r.yaxis.p2c=function(){return t[1]},l.hover(a,n.event,r.id)}),o.on(\"mouseout\",function(){a._dragging||h.unhover(a,n.event)}),o.on(\"click\",function(){\"select\"!==s&&\"lasso\"!==s&&(c.indexOf(\"select\")>-1&&p(n.event,a,[r.xaxis],[r.yaxis],r.id,g),c.indexOf(\"event\")>-1&&l.click(a,n.event))})}function v(t){return r.projection.invert([t[0]+r.xaxis._offset,t[1]+r.yaxis._offset])}},x.makeFramework=function(){var t=this,e=t.graphDiv,r=e._fullLayout,i=\"clip\"+r._uid+t.id;t.clipDef=r._clips.append(\"clipPath\").attr(\"id\",i),t.clipRect=t.clipDef.append(\"rect\"),t.framework=n.select(t.container).append(\"g\").attr(\"class\",\"geo \"+t.id).call(s.setClipUrl,i,e),t.project=function(e){var r=t.projection(e);return r?[r[0]-t.xaxis._offset,r[1]-t.yaxis._offset]:[null,null]},t.xaxis={_id:\"x\",c2p:function(e){return t.project(e)[0]}},t.yaxis={_id:\"y\",c2p:function(e){return t.project(e)[1]}},t.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},u.setConvert(t.mockAxis,r)},x.saveViewInitial=function(t){var e=t.center||{},r=t.projection,n=r.rotation||{};t._isScoped?this.viewInitial={\"center.lon\":e.lon,\"center.lat\":e.lat,\"projection.scale\":r.scale}:t._isClipped?this.viewInitial={\"projection.scale\":r.scale,\"projection.rotation.lon\":n.lon,\"projection.rotation.lat\":n.lat}:this.viewInitial={\"center.lon\":e.lon,\"center.lat\":e.lat,\"projection.scale\":r.scale,\"projection.rotation.lon\":n.lon}},x.render=function(){var t,e=this.projection,r=e.getPath();function n(t){var r=e(t.lonlat);return r?\"translate(\"+r[0]+\",\"+r[1]+\")\":null}function i(t){return e.isLonLatOverEdges(t.lonlat)?\"none\":null}for(t in this.basePaths)this.basePaths[t].attr(\"d\",r);for(t in this.dataPaths)this.dataPaths[t].attr(\"d\",function(t){return r(t.geojson)});for(t in this.dataPoints)this.dataPoints[t].attr(\"display\",i).attr(\"transform\",n)}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../lib\":719,\"../../lib/topojson_utils\":746,\"../../registry\":847,\"../cartesian/axes\":767,\"../cartesian/select\":784,\"../plots\":828,\"./constants\":795,\"./projections\":800,\"./zoom\":801,d3:163,\"topojson-client\":540}],797:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./geo\"),o=\"geo\",s=i(o),l={};l[o]={valType:\"subplotid\",dflt:o,editType:\"calc\"},e.exports={attr:o,name:o,idRoot:o,idRegex:s,attrRegex:s,attributes:l,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[o],s=0;s<i.length;s++){var l=i[s],c=n(r,o,l),u=e[l]._subplot;u||(u=a({id:l,graphDiv:t,container:e._geolayer.node(),topojsonURL:t._context.topojsonURL,staticPlot:t._context.staticPlot}),e[l]._subplot=u),u.plot(c,e,t._promises)}},updateFx:function(t){for(var e=t._fullLayout,r=e._subplots[o],n=0;n<r.length;n++){var i=e[r[n]];i._subplot.updateFx(e,i)}},clean:function(t,e,r,n){for(var i=n._subplots[o]||[],a=0;a<i.length;a++){var s=i[a],l=n[s]._subplot;!e[s]&&l&&(l.framework.remove(),l.clipDef.remove())}}}},{\"../../lib\":719,\"../../plots/get_data\":802,\"./geo\":796,\"./layout_attributes\":798,\"./layout_defaults\":799}],798:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"./constants\"),o=t(\"../../plot_api/edit_types\").overrideAll,s={range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},showgrid:{valType:\"boolean\",dflt:!1},tick0:{valType:\"number\",dflt:0},dtick:{valType:\"number\"},gridcolor:{valType:\"color\",dflt:n.lightLine},gridwidth:{valType:\"number\",min:0,dflt:1}};(e.exports=o({domain:i({name:\"geo\"},{}),resolution:{valType:\"enumerated\",values:[110,50],dflt:110,coerceNumber:!0},scope:{valType:\"enumerated\",values:Object.keys(a.scopeDefaults),dflt:\"world\"},projection:{type:{valType:\"enumerated\",values:Object.keys(a.projNames)},rotation:{lon:{valType:\"number\"},lat:{valType:\"number\"},roll:{valType:\"number\"}},parallels:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},scale:{valType:\"number\",min:0,dflt:1}},center:{lon:{valType:\"number\"},lat:{valType:\"number\"}},showcoastlines:{valType:\"boolean\"},coastlinecolor:{valType:\"color\",dflt:n.defaultLine},coastlinewidth:{valType:\"number\",min:0,dflt:1},showland:{valType:\"boolean\",dflt:!1},landcolor:{valType:\"color\",dflt:a.landColor},showocean:{valType:\"boolean\",dflt:!1},oceancolor:{valType:\"color\",dflt:a.waterColor},showlakes:{valType:\"boolean\",dflt:!1},lakecolor:{valType:\"color\",dflt:a.waterColor},showrivers:{valType:\"boolean\",dflt:!1},rivercolor:{valType:\"color\",dflt:a.waterColor},riverwidth:{valType:\"number\",min:0,dflt:1},showcountries:{valType:\"boolean\"},countrycolor:{valType:\"color\",dflt:n.defaultLine},countrywidth:{valType:\"number\",min:0,dflt:1},showsubunits:{valType:\"boolean\"},subunitcolor:{valType:\"color\",dflt:n.defaultLine},subunitwidth:{valType:\"number\",min:0,dflt:1},showframe:{valType:\"boolean\"},framecolor:{valType:\"color\",dflt:n.defaultLine},framewidth:{valType:\"number\",min:0,dflt:1},bgcolor:{valType:\"color\",dflt:n.background},lonaxis:s,lataxis:s},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":592,\"../../plot_api/edit_types\":750,\"../domain\":792,\"./constants\":795}],799:[function(t,e,r){\"use strict\";var n=t(\"../subplot_defaults\"),i=t(\"./constants\"),a=t(\"./layout_attributes\"),o=i.axesNames;function s(t,e,r){var n=r(\"resolution\"),a=r(\"scope\"),s=i.scopeDefaults[a],l=r(\"projection.type\",s.projType),c=e._isAlbersUsa=\"albers usa\"===l;c&&(a=e.scope=\"usa\");var u=e._isScoped=\"world\"!==a,h=e._isConic=-1!==l.indexOf(\"conic\");e._isClipped=!!i.lonaxisSpan[l];for(var f=0;f<o.length;f++){var p,d=o[f],g=[30,10][f];if(u)p=s[d+\"Range\"];else{var v=i[d+\"Span\"],m=(v[l]||v[\"*\"])/2,y=r(\"projection.rotation.\"+d.substr(0,3),s.projRotate[f]);p=[y-m,y+m]}r(d+\".range\",p),r(d+\".tick0\"),r(d+\".dtick\",g),r(d+\".showgrid\")&&(r(d+\".gridcolor\"),r(d+\".gridwidth\"))}var x=e.lonaxis.range,b=e.lataxis.range,_=x[0],w=x[1];_>0&&w<0&&(w+=360);var k,T,A,M=(_+w)/2;if(!c){var S=u?s.projRotate:[M,0,0];k=r(\"projection.rotation.lon\",S[0]),r(\"projection.rotation.lat\",S[1]),r(\"projection.rotation.roll\",S[2]),r(\"showcoastlines\",!u)&&(r(\"coastlinecolor\"),r(\"coastlinewidth\")),r(\"showocean\")&&r(\"oceancolor\")}(c?(T=-96.6,A=38.7):(T=u?M:k,A=(b[0]+b[1])/2),r(\"center.lon\",T),r(\"center.lat\",A),h)&&r(\"projection.parallels\",s.projParallels||[0,60]);r(\"projection.scale\"),r(\"showland\")&&r(\"landcolor\"),r(\"showlakes\")&&r(\"lakecolor\"),r(\"showrivers\")&&(r(\"rivercolor\"),r(\"riverwidth\")),r(\"showcountries\",u&&\"usa\"!==a)&&(r(\"countrycolor\"),r(\"countrywidth\")),(\"usa\"===a||\"north america\"===a&&50===n)&&(r(\"showsubunits\",!0),r(\"subunitcolor\"),r(\"subunitwidth\")),u||r(\"showframe\",!0)&&(r(\"framecolor\"),r(\"framewidth\")),r(\"bgcolor\")}e.exports=function(t,e,r){n(t,e,r,{type:\"geo\",attributes:a,handleDefaults:s,partition:\"y\"})}},{\"../subplot_defaults\":842,\"./constants\":795,\"./layout_attributes\":798}],800:[function(t,e,r){\"use strict\";e.exports=function(t){function e(t,e){return{type:\"Feature\",id:t.id,properties:t.properties,geometry:r(t.geometry,e)}}function r(e,n){if(!e)return null;if(\"GeometryCollection\"===e.type)return{type:\"GeometryCollection\",geometries:object.geometries.map(function(t){return r(t,n)})};if(!c.hasOwnProperty(e.type))return null;var i=c[e.type];return t.geo.stream(e,n(i)),i.result()}t.geo.project=function(t,e){var i=e.stream;if(!i)throw new Error(\"not yet supported\");return(t&&n.hasOwnProperty(t.type)?n[t.type]:r)(t,i)};var n={Feature:e,FeatureCollection:function(t,r){return{type:\"FeatureCollection\",features:t.features.map(function(t){return e(t,r)})}}},i=[],a=[],o={point:function(t,e){i.push([t,e])},result:function(){var t=i.length?i.length<2?{type:\"Point\",coordinates:i[0]}:{type:\"MultiPoint\",coordinates:i}:null;return i=[],t}},s={lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){i.length&&(a.push(i),i=[])},result:function(){var t=a.length?a.length<2?{type:\"LineString\",coordinates:a[0]}:{type:\"MultiLineString\",coordinates:a}:null;return a=[],t}},l={polygonStart:u,lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){var t=i.length;if(t){do{i.push(i[0].slice())}while(++t<4);a.push(i),i=[]}},polygonEnd:u,result:function(){if(!a.length)return null;var t=[],e=[];return a.forEach(function(r){!function(t){if((e=t.length)<4)return!1;for(var e,r=0,n=t[e-1][1]*t[0][0]-t[e-1][0]*t[0][1];++r<e;)n+=t[r-1][1]*t[r][0]-t[r-1][0]*t[r][1];return n<=0}(r)?e.push(r):t.push([r])}),e.forEach(function(e){var r=e[0];t.some(function(t){if(function(t,e){for(var r=e[0],n=e[1],i=!1,a=0,o=t.length,s=o-1;a<o;s=a++){var l=t[a],c=l[0],u=l[1],h=t[s],f=h[0],p=h[1];u>n^p>n&&r<(f-c)*(n-u)/(p-u)+c&&(i=!i)}return i}(t[0],r))return t.push(e),!0})||t.push([e])}),a=[],t.length?t.length>1?{type:\"MultiPolygon\",coordinates:t}:{type:\"Polygon\",coordinates:t[0]}:null}},c={Point:o,MultiPoint:o,LineString:s,MultiLineString:s,Polygon:l,MultiPolygon:l,Sphere:l};function u(){}var h=1e-6,f=h*h,p=Math.PI,d=p/2,g=(Math.sqrt(p),p/180),v=180/p;function m(t){return t>1?d:t<-1?-d:Math.asin(t)}function y(t){return t>1?0:t<-1?p:Math.acos(t)}var x=t.geo.projection,b=t.geo.projectionMutator;function _(t,e){var r=(2+d)*Math.sin(e);e/=2;for(var n=0,i=1/0;n<10&&Math.abs(i)>h;n++){var a=Math.cos(e);e-=i=(e+Math.sin(e)*(a+2)-r)/(2*a*(1+a))}return[2/Math.sqrt(p*(4+p))*t*(1+Math.cos(e)),2*Math.sqrt(p/(4+p))*Math.sin(e)]}t.geo.interrupt=function(e){var r,n=[[[[-p,0],[0,d],[p,0]]],[[[-p,0],[0,-d],[p,0]]]];function i(t,r){for(var i=r<0?-1:1,a=n[+(r<0)],o=0,s=a.length-1;o<s&&t>a[o][2][0];++o);var l=e(t-a[o][1][0],r);return l[0]+=e(a[o][1][0],i*r>i*a[o][0][1]?a[o][0][1]:r)[0],l}e.invert&&(i.invert=function(t,a){for(var o=r[+(a<0)],s=n[+(a<0)],c=0,u=o.length;c<u;++c){var h=o[c];if(h[0][0]<=t&&t<h[1][0]&&h[0][1]<=a&&a<h[1][1]){var f=e.invert(t-e(s[c][1][0],0)[0],a);return f[0]+=s[c][1][0],l(i(f[0],f[1]),[t,a])?f:null}}});var a=t.geo.projection(i),o=a.stream;function s(t,e){for(var r,n,i,a=-1,o=t.length,s=t[0],l=[];++a<o;){n=((r=t[a])[0]-s[0])/e,i=(r[1]-s[1])/e;for(var c=0;c<e;++c)l.push([s[0]+c*n,s[1]+c*i]);s=r}return l.push(r),l}function l(t,e){return Math.abs(t[0]-e[0])<h&&Math.abs(t[1]-e[1])<h}return a.stream=function(e){var r=a.rotate(),i=o(e),l=(a.rotate([0,0]),o(e));return a.rotate(r),i.sphere=function(){t.geo.stream(function(){for(var e=1e-6,r=[],i=0,a=n[0].length;i<a;++i){var o=n[0][i],l=180*o[0][0]/p,c=180*o[0][1]/p,u=180*o[1][1]/p,h=180*o[2][0]/p,f=180*o[2][1]/p;r.push(s([[l+e,c+e],[l+e,u-e],[h-e,u-e],[h-e,f+e]],30))}for(var i=n[1].length-1;i>=0;--i){var o=n[1][i],l=180*o[0][0]/p,c=180*o[0][1]/p,u=180*o[1][1]/p,h=180*o[2][0]/p,f=180*o[2][1]/p;r.push(s([[h-e,f-e],[h-e,u+e],[l+e,u+e],[l+e,c-e]],30))}return{type:\"Polygon\",coordinates:[t.merge(r)]}}(),l)},i},a.lobes=function(t){return arguments.length?(n=t.map(function(t){return t.map(function(t){return[[t[0][0]*p/180,t[0][1]*p/180],[t[1][0]*p/180,t[1][1]*p/180],[t[2][0]*p/180,t[2][1]*p/180]]})}),r=n.map(function(t){return t.map(function(t){var r,n=e(t[0][0],t[0][1])[0],i=e(t[2][0],t[2][1])[0],a=e(t[1][0],t[0][1])[1],o=e(t[1][0],t[1][1])[1];return a>o&&(r=a,a=o,o=r),[[n,a],[i,o]]})}),a):n.map(function(t){return t.map(function(t){return[[180*t[0][0]/p,180*t[0][1]/p],[180*t[1][0]/p,180*t[1][1]/p],[180*t[2][0]/p,180*t[2][1]/p]]})})},a},_.invert=function(t,e){var r=.5*e*Math.sqrt((4+p)/p),n=m(r),i=Math.cos(n);return[t/(2/Math.sqrt(p*(4+p))*(1+i)),m((n+r*(i+2))/(2+d))]},(t.geo.eckert4=function(){return x(_)}).raw=_;var w=t.geo.azimuthalEqualArea.raw;function k(t,e){if(arguments.length<2&&(e=t),1===e)return w;if(e===1/0)return T;function r(r,n){var i=w(r/e,n);return i[0]*=t,i}return r.invert=function(r,n){var i=w.invert(r/t,n);return i[0]*=e,i},r}function T(t,e){return[t*Math.cos(e)/Math.cos(e/=2),2*Math.sin(e)]}function A(t,e){return[3*t/(2*p)*Math.sqrt(p*p/3-e*e),e]}function M(t,e){return[t,1.25*Math.log(Math.tan(p/4+.4*e))]}function S(t){return function(e){var r,n=t*Math.sin(e),i=30;do{e-=r=(e+Math.sin(e)-n)/(1+Math.cos(e))}while(Math.abs(r)>h&&--i>0);return e/2}}T.invert=function(t,e){var r=2*m(e/2);return[t*Math.cos(r/2)/Math.cos(r),r]},(t.geo.hammer=function(){var t=2,e=b(k),r=e(t);return r.coefficient=function(r){return arguments.length?e(t=+r):t},r}).raw=k,A.invert=function(t,e){return[2/3*p*t/Math.sqrt(p*p/3-e*e),e]},(t.geo.kavrayskiy7=function(){return x(A)}).raw=A,M.invert=function(t,e){return[t,2.5*Math.atan(Math.exp(.8*e))-.625*p]},(t.geo.miller=function(){return x(M)}).raw=M,S(p);var E=function(t,e,r){var n=S(r);function i(r,i){return[t*r*Math.cos(i=n(i)),e*Math.sin(i)]}return i.invert=function(n,i){var a=m(i/e);return[n/(t*Math.cos(a)),m((2*a+Math.sin(2*a))/r)]},i}(Math.SQRT2/d,Math.SQRT2,p);function C(t,e){var r=e*e,n=r*r;return[t*(.8707-.131979*r+n*(n*(.003971*r-.001529*n)-.013791)),e*(1.007226+r*(.015085+n*(.028874*r-.044475-.005916*n)))]}(t.geo.mollweide=function(){return x(E)}).raw=E,C.invert=function(t,e){var r,n=e,i=25;do{var a=n*n,o=a*a;n-=r=(n*(1.007226+a*(.015085+o*(.028874*a-.044475-.005916*o)))-e)/(1.007226+a*(.045255+o*(.259866*a-.311325-.005916*11*o)))}while(Math.abs(r)>h&&--i>0);return[t/(.8707+(a=n*n)*(a*(a*a*a*(.003971-.001529*a)-.013791)-.131979)),n]},(t.geo.naturalEarth=function(){return x(C)}).raw=C;var L=[[.9986,-.062],[1,0],[.9986,.062],[.9954,.124],[.99,.186],[.9822,.248],[.973,.31],[.96,.372],[.9427,.434],[.9216,.4958],[.8962,.5571],[.8679,.6176],[.835,.6769],[.7986,.7346],[.7597,.7903],[.7186,.8435],[.6732,.8936],[.6213,.9394],[.5722,.9761],[.5322,1]];function P(t,e){var r,n=Math.min(18,36*Math.abs(e)/p),i=Math.floor(n),a=n-i,o=(r=L[i])[0],s=r[1],l=(r=L[++i])[0],c=r[1],u=(r=L[Math.min(19,++i)])[0],h=r[1];return[t*(l+a*(u-o)/2+a*a*(u-2*l+o)/2),(e>0?d:-d)*(c+a*(h-s)/2+a*a*(h-2*c+s)/2)]}function O(t,e){return[t*Math.cos(e),e]}function z(t,e){var r,n=Math.cos(e),i=(r=y(n*Math.cos(t/=2)))?r/Math.sin(r):1;return[2*n*Math.sin(t)*i,Math.sin(e)*i]}function I(t,e){var r=z(t,e);return[(r[0]+t/d)/2,(r[1]+e)/2]}L.forEach(function(t){t[1]*=1.0144}),P.invert=function(t,e){var r=e/d,n=90*r,i=Math.min(18,Math.abs(n/5)),a=Math.max(0,Math.floor(i));do{var o=L[a][1],s=L[a+1][1],l=L[Math.min(19,a+2)][1],c=l-o,u=l-2*s+o,h=2*(Math.abs(r)-s)/c,p=u/c,m=h*(1-p*h*(1-2*p*h));if(m>=0||1===a){n=(e>=0?5:-5)*(m+i);var y,x=50;do{m=(i=Math.min(18,Math.abs(n)/5))-(a=Math.floor(i)),o=L[a][1],s=L[a+1][1],l=L[Math.min(19,a+2)][1],n-=(y=(e>=0?d:-d)*(s+m*(l-o)/2+m*m*(l-2*s+o)/2)-e)*v}while(Math.abs(y)>f&&--x>0);break}}while(--a>=0);var b=L[a][0],_=L[a+1][0],w=L[Math.min(19,a+2)][0];return[t/(_+m*(w-b)/2+m*m*(w-2*_+b)/2),n*g]},(t.geo.robinson=function(){return x(P)}).raw=P,O.invert=function(t,e){return[t/Math.cos(e),e]},(t.geo.sinusoidal=function(){return x(O)}).raw=O,z.invert=function(t,e){if(!(t*t+4*e*e>p*p+h)){var r=t,n=e,i=25;do{var a,o=Math.sin(r),s=Math.sin(r/2),l=Math.cos(r/2),c=Math.sin(n),u=Math.cos(n),f=Math.sin(2*n),d=c*c,g=u*u,v=s*s,m=1-g*l*l,x=m?y(u*l)*Math.sqrt(a=1/m):a=0,b=2*x*u*s-t,_=x*c-e,w=a*(g*v+x*u*l*d),k=a*(.5*o*f-2*x*c*s),T=.25*a*(f*s-x*c*g*o),A=a*(d*l+x*v*u),M=k*T-A*w;if(!M)break;var S=(_*k-b*A)/M,E=(b*T-_*w)/M;r-=S,n-=E}while((Math.abs(S)>h||Math.abs(E)>h)&&--i>0);return[r,n]}},(t.geo.aitoff=function(){return x(z)}).raw=z,I.invert=function(t,e){var r=t,n=e,i=25;do{var a,o=Math.cos(n),s=Math.sin(n),l=Math.sin(2*n),c=s*s,u=o*o,f=Math.sin(r),p=Math.cos(r/2),g=Math.sin(r/2),v=g*g,m=1-u*p*p,x=m?y(o*p)*Math.sqrt(a=1/m):a=0,b=.5*(2*x*o*g+r/d)-t,_=.5*(x*s+n)-e,w=.5*a*(u*v+x*o*p*c)+.5/d,k=a*(f*l/4-x*s*g),T=.125*a*(l*g-x*s*u*f),A=.5*a*(c*p+x*v*o)+.5,M=k*T-A*w,S=(_*k-b*A)/M,E=(b*T-_*w)/M;r-=S,n-=E}while((Math.abs(S)>h||Math.abs(E)>h)&&--i>0);return[r,n]},(t.geo.winkel3=function(){return x(I)}).raw=I}},{}],801:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=Math.PI/180,s=180/Math.PI,l={cursor:\"pointer\"},c={cursor:\"auto\"};function u(t,e){return n.behavior.zoom().translate(e.translate()).scale(e.scale())}function h(t,e,r){var n=t.id,o=t.graphDiv,s=o.layout,l=s[n],c=o._fullLayout,u=c[n],h={},f={};function p(t,e){h[n+\".\"+t]=i.nestedProperty(l,t).get(),a.call(\"_storeDirectGUIEdit\",s,c._preGUI,h);var r=i.nestedProperty(u,t);r.get()!==e&&(r.set(e),i.nestedProperty(l,t).set(e),f[n+\".\"+t]=e)}r(p),p(\"projection.scale\",e.scale()/t.fitScale),o.emit(\"plotly_relayout\",f)}function f(t,e){var r=u(0,e);function i(r){var n=e.invert(t.midPt);r(\"center.lon\",n[0]),r(\"center.lat\",n[1])}return r.on(\"zoomstart\",function(){n.select(this).style(l)}).on(\"zoom\",function(){e.scale(n.event.scale).translate(n.event.translate),t.render();var r=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":r[0],\"geo.center.lat\":r[1]})}).on(\"zoomend\",function(){n.select(this).style(c),h(t,e,i)}),r}function p(t,e){var r,i,a,o,s,f,p,d,g,v=u(0,e),m=2;function y(t){return e.invert(t)}function x(r){var n=e.rotate(),i=e.invert(t.midPt);r(\"projection.rotation.lon\",-n[0]),r(\"center.lon\",i[0]),r(\"center.lat\",i[1])}return v.on(\"zoomstart\",function(){n.select(this).style(l),r=n.mouse(this),i=e.rotate(),a=e.translate(),o=i,s=y(r)}).on(\"zoom\",function(){if(f=n.mouse(this),function(t){var r=y(t);if(!r)return!0;var n=e(r);return Math.abs(n[0]-t[0])>m||Math.abs(n[1]-t[1])>m}(r))return v.scale(e.scale()),void v.translate(e.translate());e.scale(n.event.scale),e.translate([a[0],n.event.translate[1]]),s?y(f)&&(d=y(f),p=[o[0]+(d[0]-s[0]),i[1],i[2]],e.rotate(p),o=p):s=y(r=f),g=!0,t.render();var l=e.rotate(),c=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":c[0],\"geo.center.lat\":c[1],\"geo.projection.rotation.lon\":-l[0]})}).on(\"zoomend\",function(){n.select(this).style(c),g&&h(t,e,x)}),v}function d(t,e){var r,i={r:e.rotate(),k:e.scale()},a=u(0,e),f=function(t){var e=0,r=arguments.length,i=[];for(;++e<r;)i.push(arguments[e]);var a=n.dispatch.apply(null,i);return a.of=function(e,r){return function(i){var o;try{o=i.sourceEvent=n.event,i.target=t,n.event=i,a[i.type].apply(e,r)}finally{n.event=o}}},a}(a,\"zoomstart\",\"zoom\",\"zoomend\"),p=0,d=a.on;function m(t){var r=e.rotate();t(\"projection.rotation.lon\",-r[0]),t(\"projection.rotation.lat\",-r[1])}return a.on(\"zoomstart\",function(){n.select(this).style(l);var t,c,u,h,m,b,_,w,k,T,A,M=n.mouse(this),S=e.rotate(),E=S,C=e.translate(),L=(c=.5*(t=S)[0]*o,u=.5*t[1]*o,h=.5*t[2]*o,m=Math.sin(c),b=Math.cos(c),_=Math.sin(u),w=Math.cos(u),k=Math.sin(h),T=Math.cos(h),[b*w*T+m*_*k,m*w*T-b*_*k,b*_*T+m*w*k,b*w*k-m*_*T]);r=g(e,M),d.call(a,\"zoom\",function(){var t,a,o,l,c,u,h,p,d,m,b=n.mouse(this);if(e.scale(i.k=n.event.scale),r){if(g(e,b)){e.rotate(S).translate(C);var _=g(e,b),w=function(t,e){if(!t||!e)return;var r=function(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}(t,e),n=Math.sqrt(x(r,r)),i=.5*Math.acos(Math.max(-1,Math.min(1,x(t,e)))),a=Math.sin(i)/n;return n&&[Math.cos(i),r[2]*a,-r[1]*a,r[0]*a]}(r,_),k=function(t){return[Math.atan2(2*(t[0]*t[1]+t[2]*t[3]),1-2*(t[1]*t[1]+t[2]*t[2]))*s,Math.asin(Math.max(-1,Math.min(1,2*(t[0]*t[2]-t[3]*t[1]))))*s,Math.atan2(2*(t[0]*t[3]+t[1]*t[2]),1-2*(t[2]*t[2]+t[3]*t[3]))*s]}((a=w,o=(t=L)[0],l=t[1],c=t[2],u=t[3],h=a[0],p=a[1],d=a[2],m=a[3],[o*h-l*p-c*d-u*m,o*p+l*h+c*m-u*d,o*d-l*m+c*h+u*p,o*m+l*d-c*p+u*h])),T=i.r=function(t,e,r){var n=y(e,2,t[0]);n=y(n,1,t[1]),n=y(n,0,t[2]-r[2]);var i,a,o=e[0],l=e[1],c=e[2],u=n[0],h=n[1],f=n[2],p=Math.atan2(l,o)*s,d=Math.sqrt(o*o+l*l);Math.abs(h)>d?(a=(h>0?90:-90)-p,i=0):(a=Math.asin(h/d)*s-p,i=Math.sqrt(d*d-h*h));var g=180-a-2*p,m=(Math.atan2(f,u)-Math.atan2(c,i))*s,x=(Math.atan2(f,u)-Math.atan2(c,-i))*s,b=v(r[0],r[1],a,m),_=v(r[0],r[1],g,x);return b<=_?[a,m,r[2]]:[g,x,r[2]]}(k,r,E);isFinite(T[0])&&isFinite(T[1])&&isFinite(T[2])||(T=E),e.rotate(T),E=T}}else r=g(e,M=b);f.of(this,arguments)({type:\"zoom\"})}),A=f.of(this,arguments),p++||A({type:\"zoomstart\"})}).on(\"zoomend\",function(){var r;n.select(this).style(c),d.call(a,\"zoom\",null),r=f.of(this,arguments),--p||r({type:\"zoomend\"}),h(t,e,m)}).on(\"zoom.redraw\",function(){t.render();var r=e.rotate();t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.projection.rotation.lon\":-r[0],\"geo.projection.rotation.lat\":-r[1]})}),n.rebind(a,f,\"on\")}function g(t,e){var r=t.invert(e);return r&&isFinite(r[0])&&isFinite(r[1])&&function(t){var e=t[0]*o,r=t[1]*o,n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}(r)}function v(t,e,r,n){var i=m(r-t),a=m(n-e);return Math.sqrt(i*i+a*a)}function m(t){return(t%360+540)%360-180}function y(t,e,r){var n=r*o,i=t.slice(),a=0===e?1:0,s=2===e?1:2,l=Math.cos(n),c=Math.sin(n);return i[a]=t[a]*l-t[s]*c,i[s]=t[s]*l+t[a]*c,i}function x(t,e){for(var r=0,n=0,i=t.length;n<i;++n)r+=t[n]*e[n];return r}e.exports=function(t,e){var r=t.projection;return(e._isScoped?f:e._isClipped?d:p)(t,r)}},{\"../../lib\":719,\"../../registry\":847,d3:163}],802:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"./cartesian/constants\").SUBPLOT_PATTERN;r.getSubplotCalcData=function(t,e,r){var i=n.subplotsRegistry[e];if(!i)return[];for(var a=i.attr,o=[],s=0;s<t.length;s++){var l=t[s];l[0].trace[a]===r&&o.push(l)}return o},r.getModuleCalcData=function(t,e){var r,i=[],a=[];if(!(r=\"string\"==typeof e?n.getModule(e).plot:\"function\"==typeof e?e:e.plot))return[i,t];for(var o=0;o<t.length;o++){var s=t[o],l=s[0].trace;!0===l.visible&&0!==l._length&&(l._module.plot===r?i.push(s):a.push(s))}return[i,a]},r.getSubplotData=function(t,e,r){if(!n.subplotsRegistry[e])return[];var a,o,s,l=n.subplotsRegistry[e].attr,c=[];if(\"gl2d\"===e){var u=r.match(i);o=\"x\"+u[1],s=\"y\"+u[2]}for(var h=0;h<t.length;h++)a=t[h],\"gl2d\"===e&&n.traceIs(a,\"gl2d\")?a[l[0]]===o&&a[l[1]]===s&&c.push(a):a[l]===r&&c.push(a);return c}},{\"../registry\":847,\"./cartesian/constants\":773}],803:[function(t,e,r){\"use strict\";var n=t(\"mouse-change\"),i=t(\"mouse-wheel\"),a=t(\"mouse-event-offset\"),o=t(\"../cartesian/constants\"),s=t(\"has-passive-events\");function l(t,e){this.element=t,this.plot=e,this.mouseListener=null,this.wheelListener=null,this.lastInputTime=Date.now(),this.lastPos=[0,0],this.boxEnabled=!1,this.boxInited=!1,this.boxStart=[0,0],this.boxEnd=[0,0],this.dragStart=[0,0]}e.exports=function(t){var e=t.mouseContainer,r=t.glplot,c=new l(e,r);function u(){t.xaxis.autorange=!1,t.yaxis.autorange=!1}function h(e,n,i){var a,s,l=t.calcDataBox(),h=r.viewBox,f=c.lastPos[0],p=c.lastPos[1],d=o.MINDRAG*r.pixelRatio,g=o.MINZOOM*r.pixelRatio;function v(e,r,n){var i=Math.min(r,n),a=Math.max(r,n);i!==a?(l[e]=i,l[e+2]=a,c.dataBox=l,t.setRanges(l)):(t.selectBox.selectBox=[0,0,1,1],t.glplot.setDirty())}switch(n*=r.pixelRatio,i*=r.pixelRatio,i=h[3]-h[1]-i,t.fullLayout.dragmode){case\"zoom\":if(e){var m=n/(h[2]-h[0])*(l[2]-l[0])+l[0],y=i/(h[3]-h[1])*(l[3]-l[1])+l[1];c.boxInited||(c.boxStart[0]=m,c.boxStart[1]=y,c.dragStart[0]=n,c.dragStart[1]=i),c.boxEnd[0]=m,c.boxEnd[1]=y,c.boxInited=!0,c.boxEnabled||c.boxStart[0]===c.boxEnd[0]&&c.boxStart[1]===c.boxEnd[1]||(c.boxEnabled=!0);var x=Math.abs(c.dragStart[0]-n)<g,b=Math.abs(c.dragStart[1]-i)<g;if(!function(){for(var e=t.graphDiv._fullLayout._axisConstraintGroups,r=t.xaxis._id,n=t.yaxis._id,i=0;i<e.length;i++)if(-1!==e[i][r]){if(-1!==e[i][n])return!0;break}return!1}()||x&&b)x&&(c.boxEnd[0]=c.boxStart[0]),b&&(c.boxEnd[1]=c.boxStart[1]);else{a=c.boxEnd[0]-c.boxStart[0],s=c.boxEnd[1]-c.boxStart[1];var _=(l[3]-l[1])/(l[2]-l[0]);Math.abs(a*_)>Math.abs(s)?(c.boxEnd[1]=c.boxStart[1]+Math.abs(a)*_*(s>=0?1:-1),c.boxEnd[1]<l[1]?(c.boxEnd[1]=l[1],c.boxEnd[0]=c.boxStart[0]+(l[1]-c.boxStart[1])/Math.abs(_)):c.boxEnd[1]>l[3]&&(c.boxEnd[1]=l[3],c.boxEnd[0]=c.boxStart[0]+(l[3]-c.boxStart[1])/Math.abs(_))):(c.boxEnd[0]=c.boxStart[0]+Math.abs(s)/_*(a>=0?1:-1),c.boxEnd[0]<l[0]?(c.boxEnd[0]=l[0],c.boxEnd[1]=c.boxStart[1]+(l[0]-c.boxStart[0])*Math.abs(_)):c.boxEnd[0]>l[2]&&(c.boxEnd[0]=l[2],c.boxEnd[1]=c.boxStart[1]+(l[2]-c.boxStart[0])*Math.abs(_)))}}else c.boxEnabled?(a=c.boxStart[0]!==c.boxEnd[0],s=c.boxStart[1]!==c.boxEnd[1],a||s?(a&&(v(0,c.boxStart[0],c.boxEnd[0]),t.xaxis.autorange=!1),s&&(v(1,c.boxStart[1],c.boxEnd[1]),t.yaxis.autorange=!1),t.relayoutCallback()):t.glplot.setDirty(),c.boxEnabled=!1,c.boxInited=!1):c.boxInited&&(c.boxInited=!1);break;case\"pan\":c.boxEnabled=!1,c.boxInited=!1,e?(c.panning||(c.dragStart[0]=n,c.dragStart[1]=i),Math.abs(c.dragStart[0]-n)<d&&(n=c.dragStart[0]),Math.abs(c.dragStart[1]-i)<d&&(i=c.dragStart[1]),a=(f-n)*(l[2]-l[0])/(r.viewBox[2]-r.viewBox[0]),s=(p-i)*(l[3]-l[1])/(r.viewBox[3]-r.viewBox[1]),l[0]+=a,l[2]+=a,l[1]+=s,l[3]+=s,t.setRanges(l),c.panning=!0,c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations()):c.panning&&(c.panning=!1,t.relayoutCallback())}c.lastPos[0]=n,c.lastPos[1]=i}return c.mouseListener=n(e,h),e.addEventListener(\"touchstart\",function(t){var r=a(t.changedTouches[0],e);h(0,r[0],r[1]),h(1,r[0],r[1]),t.preventDefault()},!!s&&{passive:!1}),e.addEventListener(\"touchmove\",function(t){t.preventDefault();var r=a(t.changedTouches[0],e);h(1,r[0],r[1]),t.preventDefault()},!!s&&{passive:!1}),e.addEventListener(\"touchend\",function(t){h(0,c.lastPos[0],c.lastPos[1]),t.preventDefault()},!!s&&{passive:!1}),c.wheelListener=i(e,function(e,n){if(!t.scrollZoom)return!1;var i=t.calcDataBox(),a=r.viewBox,o=c.lastPos[0],s=c.lastPos[1],l=Math.exp(5*n/(a[3]-a[1])),h=o/(a[2]-a[0])*(i[2]-i[0])+i[0],f=s/(a[3]-a[1])*(i[3]-i[1])+i[1];return i[0]=(i[0]-h)*l+h,i[2]=(i[2]-h)*l+h,i[1]=(i[1]-f)*l+f,i[3]=(i[3]-f)*l+f,t.setRanges(i),c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations(),t.relayoutCallback(),!0},!0),c}},{\"../cartesian/constants\":773,\"has-passive-events\":411,\"mouse-change\":435,\"mouse-event-offset\":436,\"mouse-wheel\":438}],804:[function(t,e,r){\"use strict\";var n=t(\"../cartesian/axes\"),i=t(\"../../lib/str2rgbarray\");function a(t){this.scene=t,this.gl=t.gl,this.pixelRatio=t.pixelRatio,this.screenBox=[0,0,1,1],this.viewBox=[0,0,1,1],this.dataBox=[-1,-1,1,1],this.borderLineEnable=[!1,!1,!1,!1],this.borderLineWidth=[1,1,1,1],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.ticks=[[],[]],this.tickEnable=[!0,!0,!1,!1],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labels=[\"x\",\"y\"],this.labelEnable=[!0,!0,!1,!1],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelPad=[15,15,15,15],this.labelSize=[12,12],this.labelFont=[\"sans-serif\",\"sans-serif\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.title=\"\",this.titleEnable=!0,this.titleCenter=[0,0,0,0],this.titleAngle=0,this.titleColor=[0,0,0,1],this.titleFont=\"sans-serif\",this.titleSize=18,this.gridLineEnable=[!0,!0],this.gridLineColor=[[0,0,0,.5],[0,0,0,.5]],this.gridLineWidth=[1,1],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[1,1],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.static=this.scene.staticPlot}var o=a.prototype,s=[\"xaxis\",\"yaxis\"];o.merge=function(t){var e,r,n,a,o,l,c,u,h,f,p;for(this.titleEnable=!1,this.backgroundColor=i(t.plot_bgcolor),f=0;f<2;++f){var d=(e=s[f]).charAt(0);for(n=(r=t[this.scene[e]._name]).title.text===this.scene.fullLayout._dfltTitle[d]?\"\":r.title.text,p=0;p<=2;p+=2)this.labelEnable[f+p]=!1,this.labels[f+p]=n,this.labelColor[f+p]=i(r.title.font.color),this.labelFont[f+p]=r.title.font.family,this.labelSize[f+p]=r.title.font.size,this.labelPad[f+p]=this.getLabelPad(e,r),this.tickEnable[f+p]=!1,this.tickColor[f+p]=i((r.tickfont||{}).color),this.tickAngle[f+p]=\"auto\"===r.tickangle?0:Math.PI*-r.tickangle/180,this.tickPad[f+p]=this.getTickPad(r),this.tickMarkLength[f+p]=0,this.tickMarkWidth[f+p]=r.tickwidth||0,this.tickMarkColor[f+p]=i(r.tickcolor),this.borderLineEnable[f+p]=!1,this.borderLineColor[f+p]=i(r.linecolor),this.borderLineWidth[f+p]=r.linewidth||0;c=this.hasSharedAxis(r),o=this.hasAxisInDfltPos(e,r)&&!c,l=this.hasAxisInAltrPos(e,r)&&!c,a=r.mirror||!1,u=c?-1!==String(a).indexOf(\"all\"):!!a,h=c?\"allticks\"===a:-1!==String(a).indexOf(\"ticks\"),o?this.labelEnable[f]=!0:l&&(this.labelEnable[f+2]=!0),o?this.tickEnable[f]=r.showticklabels:l&&(this.tickEnable[f+2]=r.showticklabels),(o||u)&&(this.borderLineEnable[f]=r.showline),(l||u)&&(this.borderLineEnable[f+2]=r.showline),(o||h)&&(this.tickMarkLength[f]=this.getTickMarkLength(r)),(l||h)&&(this.tickMarkLength[f+2]=this.getTickMarkLength(r)),this.gridLineEnable[f]=r.showgrid,this.gridLineColor[f]=i(r.gridcolor),this.gridLineWidth[f]=r.gridwidth,this.zeroLineEnable[f]=r.zeroline,this.zeroLineColor[f]=i(r.zerolinecolor),this.zeroLineWidth[f]=r.zerolinewidth}},o.hasSharedAxis=function(t){var e=this.scene,r=e.fullLayout._subplots.gl2d;return 0!==n.findSubplotsWithAxis(r,t).indexOf(e.id)},o.hasAxisInDfltPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"bottom\"===r:\"yaxis\"===t?\"left\"===r:void 0},o.hasAxisInAltrPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"top\"===r:\"yaxis\"===t?\"right\"===r:void 0},o.getLabelPad=function(t,e){var r=e.title.font.size,n=e.showticklabels;return\"xaxis\"===t?\"top\"===e.side?r*(1.5+(n?1:0))-10:r*(1.5+(n?.5:0))-10:\"yaxis\"===t?\"right\"===e.side?10+r*(1.5+(n?1:.5)):10+r*(1.5+(n?.5:0)):void 0},o.getTickPad=function(t){return\"outside\"===t.ticks?10+t.ticklen:15},o.getTickMarkLength=function(t){if(!t.ticks)return 0;var e=t.ticklen;return\"inside\"===t.ticks?-e:e},e.exports=function(t){return new a(t)}},{\"../../lib/str2rgbarray\":742,\"../cartesian/axes\":767}],805:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"./scene2d\"),a=t(\"../layout_attributes\"),o=t(\"../../constants/xmlns_namespaces\"),s=t(\"../cartesian/constants\"),l=t(\"../cartesian\"),c=t(\"../../components/fx/layout_attributes\"),u=t(\"../get_data\").getSubplotData;r.name=\"gl2d\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=s.idRegex,r.attrRegex=s.attrRegex,r.attributes=t(\"../cartesian/attributes\"),r.supplyLayoutDefaults=function(t,e,r){e._has(\"cartesian\")||l.supplyLayoutDefaults(t,e,r)},r.layoutAttrOverrides=n(l.layoutAttributes,\"plot\",\"from-root\"),r.baseLayoutAttrOverrides=n({plot_bgcolor:a.plot_bgcolor,hoverlabel:c.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl2d,a=0;a<n.length;a++){var o=n[a],s=e._plots[o],l=u(r,\"gl2d\",o),c=s._scene2d;void 0===c&&(c=new i({id:o,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio},e),s._scene2d=c),c.plot(l,t.calcdata,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl2d||[],a=0;a<i.length;a++){var o=i[a],s=n._plots[o];if(s._scene2d)0===u(t,\"gl2d\",o).length&&(s._scene2d.destroy(),delete n._plots[o])}l.clean.apply(this,arguments)},r.drawFramework=function(t){t._context.staticPlot||l.drawFramework(t)},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){var i=e._plots[r[n]]._scene2d,a=i.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":a,x:0,y:0,width:\"100%\",height:\"100%\",preserveAspectRatio:\"none\"}),i.destroy()}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){e._plots[r[n]]._scene2d.updateFx(e.dragmode)}}},{\"../../components/fx/layout_attributes\":633,\"../../constants/xmlns_namespaces\":696,\"../../plot_api/edit_types\":750,\"../cartesian\":778,\"../cartesian/attributes\":765,\"../cartesian/constants\":773,\"../get_data\":802,\"../layout_attributes\":819,\"./scene2d\":806}],806:[function(t,e,r){\"use strict\";var n,i,a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../../components/fx\"),l=t(\"gl-plot2d\"),c=t(\"gl-spikes2d\"),u=t(\"gl-select-box\"),h=t(\"webgl-context\"),f=t(\"./convert\"),p=t(\"./camera\"),d=t(\"../../lib/show_no_webgl_msg\"),g=t(\"../cartesian/constraints\"),v=g.enforce,m=g.clean,y=t(\"../cartesian/autorange\").doAutoRange,x=[\"xaxis\",\"yaxis\"],b=t(\"../cartesian/constants\").SUBPLOT_PATTERN;function _(t,e){this.container=t.container,this.graphDiv=t.graphDiv,this.pixelRatio=t.plotGlPixelRatio||window.devicePixelRatio,this.id=t.id,this.staticPlot=!!t.staticPlot,this.scrollZoom=this.graphDiv._context._scrollZoom.cartesian,this.fullData=null,this.updateRefs(e),this.makeFramework(),this.stopped||(this.glplotOptions=f(this),this.glplotOptions.merge(e),this.glplot=l(this.glplotOptions),this.camera=p(this),this.traces={},this.spikes=c(this.glplot),this.selectBox=u(this.glplot,{innerFill:!1,outerFill:!0}),this.lastButtonState=0,this.pickResult=null,this.isMouseOver=!0,this.stopped=!1,this.redraw=this.draw.bind(this),this.redraw())}e.exports=_;var w=_.prototype;w.makeFramework=function(){if(this.staticPlot){if(!(i||(n=document.createElement(\"canvas\"),i=h({canvas:n,preserveDrawingBuffer:!1,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"Error creating static canvas/context for image server\");this.canvas=n,this.gl=i}else{var t=this.container.querySelector(\".gl-canvas-focus\"),e=h({canvas:t,preserveDrawingBuffer:!0,premultipliedAlpha:!0});if(!e)return d(this),void(this.stopped=!0);this.canvas=t,this.gl=e}var r=this.canvas;r.style.width=\"100%\",r.style.height=\"100%\",r.style.position=\"absolute\",r.style.top=\"0px\",r.style.left=\"0px\",r.style[\"pointer-events\"]=\"none\",this.updateSize(r),r.className+=\" user-select-none\";var a=this.svgContainer=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");a.style.position=\"absolute\",a.style.top=a.style.left=\"0px\",a.style.width=a.style.height=\"100%\",a.style[\"z-index\"]=20,a.style[\"pointer-events\"]=\"none\";var o=this.mouseContainer=document.createElement(\"div\");o.style.position=\"absolute\",o.style[\"pointer-events\"]=\"auto\",this.pickCanvas=this.container.querySelector(\".gl-canvas-pick\");var s=this.container;s.appendChild(a),s.appendChild(o);var l=this;o.addEventListener(\"mouseout\",function(){l.isMouseOver=!1,l.unhover()}),o.addEventListener(\"mouseover\",function(){l.isMouseOver=!0})},w.toImage=function(t){t||(t=\"png\"),this.stopped=!0,this.staticPlot&&this.container.appendChild(n),this.updateSize(this.canvas);var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.clearColor(1,1,1,0),e.clear(e.COLOR_BUFFER_BIT|e.DEPTH_BUFFER_BIT),this.glplot.setDirty(),this.glplot.draw(),e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a);for(var o=0,s=i-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=a[4*(r*o+l)+c];a[4*(r*o+l)+c]=a[4*(r*s+l)+c],a[4*(r*s+l)+c]=u}var h=document.createElement(\"canvas\");h.width=r,h.height=i;var f,p=h.getContext(\"2d\"),d=p.createImageData(r,i);switch(d.data.set(a),p.putImageData(d,0,0),t){case\"jpeg\":f=h.toDataURL(\"image/jpeg\");break;case\"webp\":f=h.toDataURL(\"image/webp\");break;default:f=h.toDataURL(\"image/png\")}return this.staticPlot&&this.container.removeChild(n),f},w.updateSize=function(t){t||(t=this.canvas);var e=this.pixelRatio,r=this.fullLayout,n=r.width,i=r.height,a=0|Math.ceil(e*n),o=0|Math.ceil(e*i);return t.width===a&&t.height===o||(t.width=a,t.height=o),t},w.computeTickMarks=function(){this.xaxis.setScale(),this.yaxis.setScale();for(var t=[o.calcTicks(this.xaxis),o.calcTicks(this.yaxis)],e=0;e<2;++e)for(var r=0;r<t[e].length;++r)t[e][r].text=t[e][r].text+\"\";return t},w.updateRefs=function(t){this.fullLayout=t;var e=this.id.match(b),r=\"xaxis\"+e[1],n=\"yaxis\"+e[2];this.xaxis=this.fullLayout[r],this.yaxis=this.fullLayout[n]},w.relayoutCallback=function(){var t=this.graphDiv,e=this.xaxis,r=this.yaxis,n=t.layout,i={},o=i[e._name+\".range\"]=e.range.slice(),s=i[r._name+\".range\"]=r.range.slice();i[e._name+\".autorange\"]=e.autorange,i[r._name+\".autorange\"]=r.autorange,a.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,i);var l=n[e._name];l.range=o,l.autorange=e.autorange;var c=n[r._name];c.range=s,c.autorange=r.autorange,i.lastInputTime=this.camera.lastInputTime,t.emit(\"plotly_relayout\",i)},w.cameraChanged=function(){var t=this.camera;this.glplot.setDataBox(this.calcDataBox());var e=this.computeTickMarks();(function(t,e){for(var r=0;r<2;++r){var n=t[r],i=e[r];if(n.length!==i.length)return!0;for(var a=0;a<n.length;++a)if(n[a].x!==i[a].x)return!0}return!1})(e,this.glplotOptions.ticks)&&(this.glplotOptions.ticks=e,this.glplotOptions.dataBox=t.dataBox,this.glplot.update(this.glplotOptions),this.handleAnnotations())},w.handleAnnotations=function(){for(var t=this.graphDiv,e=this.fullLayout.annotations,r=0;r<e.length;r++){var n=e[r];n.xref===this.xaxis._id&&n.yref===this.yaxis._id&&a.getComponentMethod(\"annotations\",\"drawOne\")(t,r)}},w.destroy=function(){if(this.glplot){var t=this.traces;t&&Object.keys(t).map(function(e){t[e].dispose(),delete t[e]}),this.glplot.dispose(),this.container.removeChild(this.svgContainer),this.container.removeChild(this.mouseContainer),this.fullData=null,this.glplot=null,this.stopped=!0,this.camera.mouseListener.enabled=!1,this.mouseContainer.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=null}},w.plot=function(t,e,r){var n=this.glplot;this.updateRefs(r),this.xaxis.clearCalc(),this.yaxis.clearCalc(),this.updateTraces(t,e),this.updateFx(r.dragmode);var i=r.width,a=r.height;this.updateSize(this.canvas);var o=this.glplotOptions;o.merge(r),o.screenBox=[0,0,i,a];var s={_fullLayout:{_axisConstraintGroups:this.graphDiv._fullLayout._axisConstraintGroups,xaxis:this.xaxis,yaxis:this.yaxis}};m(s,this.xaxis),m(s,this.yaxis);var l,c,u=r._size,h=this.xaxis.domain,f=this.yaxis.domain;for(o.viewBox=[u.l+h[0]*u.w,u.b+f[0]*u.h,i-u.r-(1-h[1])*u.w,a-u.t-(1-f[1])*u.h],this.mouseContainer.style.width=u.w*(h[1]-h[0])+\"px\",this.mouseContainer.style.height=u.h*(f[1]-f[0])+\"px\",this.mouseContainer.height=u.h*(f[1]-f[0]),this.mouseContainer.style.left=u.l+h[0]*u.w+\"px\",this.mouseContainer.style.top=u.t+(1-f[1])*u.h+\"px\",c=0;c<2;++c)(l=this[x[c]])._length=o.viewBox[c+2]-o.viewBox[c],y(this.graphDiv,l),l.setScale();v(s),o.ticks=this.computeTickMarks(),o.dataBox=this.calcDataBox(),o.merge(r),n.update(o),this.glplot.draw()},w.calcDataBox=function(){var t=this.xaxis,e=this.yaxis,r=t.range,n=e.range,i=t.r2l,a=e.r2l;return[i(r[0]),a(n[0]),i(r[1]),a(n[1])]},w.setRanges=function(t){var e=this.xaxis,r=this.yaxis,n=e.l2r,i=r.l2r;e.range=[n(t[0]),n(t[2])],r.range=[i(t[1]),i(t[3])]},w.updateTraces=function(t,e){var r,n,i,a=Object.keys(this.traces);this.fullData=t;t:for(r=0;r<a.length;r++){var o=a[r],s=this.traces[o];for(n=0;n<t.length;n++)if((i=t[n]).uid===o&&i.type===s.type)continue t;s.dispose(),delete this.traces[o]}for(r=0;r<t.length;r++){i=t[r];var l=e[r],c=this.traces[i.uid];c?c.update(i,l):(c=i._module.plot(this,i,l),this.traces[i.uid]=c)}this.glplot.objects.sort(function(t,e){return t._trace.index-e._trace.index})},w.updateFx=function(t){\"lasso\"===t||\"select\"===t?(this.pickCanvas.style[\"pointer-events\"]=\"none\",this.mouseContainer.style[\"pointer-events\"]=\"none\"):(this.pickCanvas.style[\"pointer-events\"]=\"auto\",this.mouseContainer.style[\"pointer-events\"]=\"auto\"),this.mouseContainer.style.cursor=\"pan\"===t?\"move\":\"zoom\"===t?\"crosshair\":null},w.emitPointAction=function(t,e){for(var r,n=t.trace.uid,i=t.pointIndex,a=0;a<this.fullData.length;a++)this.fullData[a].uid===n&&(r=this.fullData[a]);var o={x:t.traceCoord[0],y:t.traceCoord[1],curveNumber:r.index,pointNumber:i,data:r._input,fullData:this.fullData,xaxis:this.xaxis,yaxis:this.yaxis};s.appendArrayPointValue(o,r,i),this.graphDiv.emit(e,{points:[o]})},w.draw=function(){if(!this.stopped){requestAnimationFrame(this.redraw);var t=this.glplot,e=this.camera,r=e.mouseListener,n=1===this.lastButtonState&&0===r.buttons,i=this.fullLayout;this.lastButtonState=r.buttons,this.cameraChanged();var a,o=r.x*t.pixelRatio,l=this.canvas.height-t.pixelRatio*r.y;if(e.boxEnabled&&\"zoom\"===i.dragmode){this.selectBox.enabled=!0;for(var c=this.selectBox.selectBox=[Math.min(e.boxStart[0],e.boxEnd[0]),Math.min(e.boxStart[1],e.boxEnd[1]),Math.max(e.boxStart[0],e.boxEnd[0]),Math.max(e.boxStart[1],e.boxEnd[1])],u=0;u<2;u++)e.boxStart[u]===e.boxEnd[u]&&(c[u]=t.dataBox[u],c[u+2]=t.dataBox[u+2]);t.setDirty()}else if(!e.panning&&this.isMouseOver){this.selectBox.enabled=!1;var h=i._size,f=this.xaxis.domain,p=this.yaxis.domain,d=(a=t.pick(o/t.pixelRatio+h.l+f[0]*h.w,l/t.pixelRatio-(h.t+(1-p[1])*h.h)))&&a.object._trace.handlePick(a);if(d&&n&&this.emitPointAction(d,\"plotly_click\"),a&&\"skip\"!==a.object._trace.hoverinfo&&i.hovermode&&d&&(!this.lastPickResult||this.lastPickResult.traceUid!==d.trace.uid||this.lastPickResult.dataCoord[0]!==d.dataCoord[0]||this.lastPickResult.dataCoord[1]!==d.dataCoord[1])){var g=d;this.lastPickResult={traceUid:d.trace?d.trace.uid:null,dataCoord:d.dataCoord.slice()},this.spikes.update({center:a.dataCoord}),g.screenCoord=[((t.viewBox[2]-t.viewBox[0])*(a.dataCoord[0]-t.dataBox[0])/(t.dataBox[2]-t.dataBox[0])+t.viewBox[0])/t.pixelRatio,(this.canvas.height-(t.viewBox[3]-t.viewBox[1])*(a.dataCoord[1]-t.dataBox[1])/(t.dataBox[3]-t.dataBox[1])-t.viewBox[1])/t.pixelRatio],this.emitPointAction(d,\"plotly_hover\");var v=this.fullData[g.trace.index]||{},m=g.pointIndex,y=s.castHoverinfo(v,i,m);if(y&&\"all\"!==y){var x=y.split(\"+\");-1===x.indexOf(\"x\")&&(g.traceCoord[0]=void 0),-1===x.indexOf(\"y\")&&(g.traceCoord[1]=void 0),-1===x.indexOf(\"z\")&&(g.traceCoord[2]=void 0),-1===x.indexOf(\"text\")&&(g.textLabel=void 0),-1===x.indexOf(\"name\")&&(g.name=void 0)}s.loneHover({x:g.screenCoord[0],y:g.screenCoord[1],xLabel:this.hoverFormatter(\"xaxis\",g.traceCoord[0]),yLabel:this.hoverFormatter(\"yaxis\",g.traceCoord[1]),zLabel:g.traceCoord[2],text:g.textLabel,name:g.name,color:s.castHoverOption(v,m,\"bgcolor\")||g.color,borderColor:s.castHoverOption(v,m,\"bordercolor\"),fontFamily:s.castHoverOption(v,m,\"font.family\"),fontSize:s.castHoverOption(v,m,\"font.size\"),fontColor:s.castHoverOption(v,m,\"font.color\"),nameLength:s.castHoverOption(v,m,\"namelength\"),textAlign:s.castHoverOption(v,m,\"align\")},{container:this.svgContainer,gd:this.graphDiv})}}a||this.unhover(),t.draw()}},w.unhover=function(){this.lastPickResult&&(this.spikes.update({}),this.lastPickResult=null,this.graphDiv.emit(\"plotly_unhover\"),s.loneUnhover(this.svgContainer))},w.hoverFormatter=function(t,e){if(void 0!==e){var r=this[t];return o.tickText(r,r.c2l(e),\"hover\").text}}},{\"../../components/fx\":632,\"../../lib/show_no_webgl_msg\":740,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../cartesian/autorange\":766,\"../cartesian/constants\":773,\"../cartesian/constraints\":774,\"./camera\":803,\"./convert\":804,\"gl-plot2d\":287,\"gl-select-box\":299,\"gl-spikes2d\":308,\"webgl-context\":556}],807:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../components/fx/layout_attributes\"),a=t(\"./scene\"),o=t(\"../get_data\").getSubplotData,s=t(\"../../lib\"),l=t(\"../../constants/xmlns_namespaces\");r.name=\"gl3d\",r.attr=\"scene\",r.idRoot=\"scene\",r.idRegex=r.attrRegex=s.counterRegex(\"scene\"),r.attributes=t(\"./layout/attributes\"),r.layoutAttributes=t(\"./layout/layout_attributes\"),r.baseLayoutAttrOverrides=n({hoverlabel:i.hoverlabel},\"plot\",\"nested\"),r.supplyLayoutDefaults=t(\"./layout/defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl3d,i=0;i<n.length;i++){var s=n[i],l=o(r,\"gl3d\",s),c=e[s],u=c.camera,h=c._scene;h||(h=new a({id:s,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio,camera:u},e),c._scene=h),h.viewInitial||(h.viewInitial={up:{x:u.up.x,y:u.up.y,z:u.up.z},eye:{x:u.eye.x,y:u.eye.y,z:u.eye.z},center:{x:u.center.x,y:u.center.y,z:u.center.z}}),h.plot(l,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl3d||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._scene&&(n[o]._scene.destroy(),n._infolayer&&n._infolayer.selectAll(\".annotation-\"+o).remove())}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=e._size,i=0;i<r.length;i++){var a=e[r[i]],o=a.domain,s=a._scene,c=s.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:l.svg,\"xlink:href\":c,x:n.l+n.w*o.x[0],y:n.t+n.h*(1-o.y[1]),width:n.w*(o.x[1]-o.x[0]),height:n.h*(o.y[1]-o.y[0]),preserveAspectRatio:\"none\"}),s.destroy()}},r.cleanId=function(t){if(t.match(/^scene[0-9]*$/)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),\"scene\"+e}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){e[r[n]]._scene.updateFx(e.dragmode,e.hovermode)}}},{\"../../components/fx/layout_attributes\":633,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../plot_api/edit_types\":750,\"../get_data\":802,\"./layout/attributes\":808,\"./layout/defaults\":812,\"./layout/layout_attributes\":813,\"./scene\":817}],808:[function(t,e,r){\"use strict\";e.exports={scene:{valType:\"subplotid\",dflt:\"scene\",editType:\"calc+clearAxisTypes\"}}},{}],809:[function(t,e,r){\"use strict\";var n=t(\"../../../components/color\"),i=t(\"../../cartesian/layout_attributes\"),a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../plot_api/edit_types\").overrideAll;e.exports=o({visible:i.visible,showspikes:{valType:\"boolean\",dflt:!0},spikesides:{valType:\"boolean\",dflt:!0},spikethickness:{valType:\"number\",min:0,dflt:2},spikecolor:{valType:\"color\",dflt:n.defaultLine},showbackground:{valType:\"boolean\",dflt:!1},backgroundcolor:{valType:\"color\",dflt:\"rgba(204, 204, 204, 0.5)\"},showaxeslabels:{valType:\"boolean\",dflt:!0},color:i.color,categoryorder:i.categoryorder,categoryarray:i.categoryarray,title:i.title,type:a({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autorange:i.autorange,rangemode:i.rangemode,range:a({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],anim:!1}),tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,mirror:i.mirror,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,tickfont:i.tickfont,tickangle:i.tickangle,tickprefix:i.tickprefix,showtickprefix:i.showtickprefix,ticksuffix:i.ticksuffix,showticksuffix:i.showticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,separatethousands:i.separatethousands,tickformat:i.tickformat,tickformatstops:i.tickformatstops,hoverformat:i.hoverformat,showline:i.showline,linecolor:i.linecolor,linewidth:i.linewidth,showgrid:i.showgrid,gridcolor:a({},i.gridcolor,{dflt:\"rgb(204, 204, 204)\"}),gridwidth:i.gridwidth,zeroline:i.zeroline,zerolinecolor:i.zerolinecolor,zerolinewidth:i.zerolinewidth,_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}},\"plot\",\"from-root\")},{\"../../../components/color\":593,\"../../../lib/extend\":710,\"../../../plot_api/edit_types\":750,\"../../cartesian/layout_attributes\":779}],810:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../../lib\"),a=t(\"../../../plot_api/plot_template\"),o=t(\"./axis_attributes\"),s=t(\"../../cartesian/type_defaults\"),l=t(\"../../cartesian/axis_defaults\"),c=[\"xaxis\",\"yaxis\",\"zaxis\"];e.exports=function(t,e,r){var u,h;function f(t,e){return i.coerce(u,h,o,t,e)}for(var p=0;p<c.length;p++){var d=c[p];u=t[d]||{},(h=a.newContainer(e,d))._id=d[0]+r.scene,h._name=d,s(u,h,f,r),l(u,h,f,{font:r.font,letter:d[0],data:r.data,showGrid:!0,noTickson:!0,bgColor:r.bgColor,calendar:r.calendar},r.fullLayout),f(\"gridcolor\",n(h.color,r.bgColor,13600/187).toRgbString()),f(\"title.text\",d[0]),h.setScale=i.noop,f(\"showspikes\")&&(f(\"spikesides\"),f(\"spikethickness\"),f(\"spikecolor\",h.color)),f(\"showaxeslabels\"),f(\"showbackground\")&&f(\"backgroundcolor\")}}},{\"../../../lib\":719,\"../../../plot_api/plot_template\":757,\"../../cartesian/axis_defaults\":769,\"../../cartesian/type_defaults\":790,\"./axis_attributes\":809,tinycolor2:537}],811:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"];function o(){this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[18,18,18],this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=[\"Open Sans\",\"Open Sans\",\"Open Sans\"],this.labelSize=[20,20,20],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[30,30,30],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[10,10,10],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!0,!0,!0],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._defaultTickPad=this.tickPad.slice(),this._defaultLabelPad=this.labelPad.slice(),this._defaultLineTickLength=this.lineTickLength.slice()}o.prototype.merge=function(t,e){for(var r=0;r<3;++r){var o=e[a[r]];o.visible?(this.labels[r]=t._meta?i.templateString(o.title.text,t._meta):o.title.text,\"font\"in o.title&&(o.title.font.color&&(this.labelColor[r]=n(o.title.font.color)),o.title.font.family&&(this.labelFont[r]=o.title.font.family),o.title.font.size&&(this.labelSize[r]=o.title.font.size)),\"showline\"in o&&(this.lineEnable[r]=o.showline),\"linecolor\"in o&&(this.lineColor[r]=n(o.linecolor)),\"linewidth\"in o&&(this.lineWidth[r]=o.linewidth),\"showgrid\"in o&&(this.gridEnable[r]=o.showgrid),\"gridcolor\"in o&&(this.gridColor[r]=n(o.gridcolor)),\"gridwidth\"in o&&(this.gridWidth[r]=o.gridwidth),\"log\"===o.type?this.zeroEnable[r]=!1:\"zeroline\"in o&&(this.zeroEnable[r]=o.zeroline),\"zerolinecolor\"in o&&(this.zeroLineColor[r]=n(o.zerolinecolor)),\"zerolinewidth\"in o&&(this.zeroLineWidth[r]=o.zerolinewidth),\"ticks\"in o&&o.ticks?this.lineTickEnable[r]=!0:this.lineTickEnable[r]=!1,\"ticklen\"in o&&(this.lineTickLength[r]=this._defaultLineTickLength[r]=o.ticklen),\"tickcolor\"in o&&(this.lineTickColor[r]=n(o.tickcolor)),\"tickwidth\"in o&&(this.lineTickWidth[r]=o.tickwidth),\"tickangle\"in o&&(this.tickAngle[r]=\"auto\"===o.tickangle?-3600:Math.PI*-o.tickangle/180),\"showticklabels\"in o&&(this.tickEnable[r]=o.showticklabels),\"tickfont\"in o&&(o.tickfont.color&&(this.tickColor[r]=n(o.tickfont.color)),o.tickfont.family&&(this.tickFont[r]=o.tickfont.family),o.tickfont.size&&(this.tickSize[r]=o.tickfont.size)),\"mirror\"in o?-1!==[\"ticks\",\"all\",\"allticks\"].indexOf(o.mirror)?(this.lineTickMirror[r]=!0,this.lineMirror[r]=!0):!0===o.mirror?(this.lineTickMirror[r]=!1,this.lineMirror[r]=!0):(this.lineTickMirror[r]=!1,this.lineMirror[r]=!1):this.lineMirror[r]=!1,\"showbackground\"in o&&!1!==o.showbackground?(this.backgroundEnable[r]=!0,this.backgroundColor[r]=n(o.backgroundcolor)):this.backgroundEnable[r]=!1):(this.tickEnable[r]=!1,this.labelEnable[r]=!1,this.lineEnable[r]=!1,this.lineTickEnable[r]=!1,this.gridEnable[r]=!1,this.zeroEnable[r]=!1,this.backgroundEnable[r]=!1)}},e.exports=function(t,e){var r=new o;return r.merge(t,e),r}},{\"../../../lib\":719,\"../../../lib/str2rgbarray\":742}],812:[function(t,e,r){\"use strict\";var n=t(\"../../../lib\"),i=t(\"../../../components/color\"),a=t(\"../../../registry\"),o=t(\"../../subplot_defaults\"),s=t(\"./axis_defaults\"),l=t(\"./layout_attributes\"),c=t(\"../../get_data\").getSubplotData,u=\"gl3d\";function h(t,e,r,n){for(var o=r(\"bgcolor\"),l=i.combine(o,n.paper_bgcolor),h=[\"up\",\"center\",\"eye\"],f=0;f<h.length;f++)r(\"camera.\"+h[f]+\".x\"),r(\"camera.\"+h[f]+\".y\"),r(\"camera.\"+h[f]+\".z\");r(\"camera.projection.type\");var p=!!r(\"aspectratio.x\")&&!!r(\"aspectratio.y\")&&!!r(\"aspectratio.z\"),d=r(\"aspectmode\",p?\"manual\":\"auto\");p||(t.aspectratio=e.aspectratio={x:1,y:1,z:1},\"manual\"===d&&(e.aspectmode=\"auto\"),t.aspectmode=e.aspectmode);var g=c(n.fullData,u,n.id);s(t,e,{font:n.font,scene:n.id,data:g,bgColor:l,calendar:n.calendar,fullLayout:n.fullLayout}),a.getComponentMethod(\"annotations3d\",\"handleDefaults\")(t,e,n);var v=n.getDfltFromLayout(\"dragmode\");if(!1!==v&&!v)if(v=\"orbit\",t.camera&&t.camera.up){var m=t.camera.up.x,y=t.camera.up.y,x=t.camera.up.z;0!==x&&(m&&y&&x?x/Math.sqrt(m*m+y*y+x*x)>.999&&(v=\"turntable\"):v=\"turntable\")}else v=\"turntable\";r(\"dragmode\",v),r(\"hovermode\",n.getDfltFromLayout(\"hovermode\"))}e.exports=function(t,e,r){var i=e._basePlotModules.length>1;o(t,e,r,{type:u,attributes:l,handleDefaults:h,fullLayout:e,font:e.font,fullData:r,getDfltFromLayout:function(e){if(!i)return n.validate(t[e],l[e])?t[e]:void 0},paper_bgcolor:e.paper_bgcolor,calendar:e.calendar})}},{\"../../../components/color\":593,\"../../../lib\":719,\"../../../registry\":847,\"../../get_data\":802,\"../../subplot_defaults\":842,\"./axis_defaults\":810,\"./layout_attributes\":813}],813:[function(t,e,r){\"use strict\";var n=t(\"./axis_attributes\"),i=t(\"../../domain\").attributes,a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../lib\").counterRegex;function s(t,e,r){return{x:{valType:\"number\",dflt:t,editType:\"camera\"},y:{valType:\"number\",dflt:e,editType:\"camera\"},z:{valType:\"number\",dflt:r,editType:\"camera\"},editType:\"camera\"}}e.exports={_arrayAttrRegexps:[o(\"scene\",\".annotations\",!0)],bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"plot\"},camera:{up:a(s(0,0,1),{}),center:a(s(0,0,0),{}),eye:a(s(1.25,1.25,1.25),{}),projection:{type:{valType:\"enumerated\",values:[\"perspective\",\"orthographic\"],dflt:\"perspective\",editType:\"calc\"},editType:\"calc\"},editType:\"camera\"},domain:i({name:\"scene\",editType:\"plot\"}),aspectmode:{valType:\"enumerated\",values:[\"auto\",\"cube\",\"data\",\"manual\"],dflt:\"auto\",editType:\"plot\",impliedEdits:{\"aspectratio.x\":void 0,\"aspectratio.y\":void 0,\"aspectratio.z\":void 0}},aspectratio:{x:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},y:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},z:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},editType:\"plot\",impliedEdits:{aspectmode:\"manual\"}},xaxis:n,yaxis:n,zaxis:n,dragmode:{valType:\"enumerated\",values:[\"orbit\",\"turntable\",\"zoom\",\"pan\",!1],editType:\"plot\"},hovermode:{valType:\"enumerated\",values:[\"closest\",!1],dflt:\"closest\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"plot\",_deprecated:{cameraposition:{valType:\"info_array\",editType:\"camera\"}}}},{\"../../../lib\":719,\"../../../lib/extend\":710,\"../../domain\":792,\"./axis_attributes\":809}],814:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=[\"xaxis\",\"yaxis\",\"zaxis\"];function a(){this.enabled=[!0,!0,!0],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.drawSides=[!0,!0,!0],this.lineWidth=[1,1,1]}a.prototype.merge=function(t){for(var e=0;e<3;++e){var r=t[i[e]];r.visible?(this.enabled[e]=r.showspikes,this.colors[e]=n(r.spikecolor),this.drawSides[e]=r.spikesides,this.lineWidth[e]=r.spikethickness):(this.enabled[e]=!1,this.drawSides[e]=!1)}},e.exports=function(t){var e=new a;return e.merge(t),e}},{\"../../../lib/str2rgbarray\":742}],815:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.axesOptions,r=t.glplot.axesPixels,s=t.fullSceneLayout,l=[[],[],[]],c=0;c<3;++c){var u=s[a[c]];if(u._length=(r[c].hi-r[c].lo)*r[c].pixelsPerDataUnit/t.dataScale[c],Math.abs(u._length)===1/0||isNaN(u._length))l[c]=[];else{u._input_range=u.range.slice(),u.range[0]=r[c].lo/t.dataScale[c],u.range[1]=r[c].hi/t.dataScale[c],u._m=1/(t.dataScale[c]*r[c].pixelsPerDataUnit),u.range[0]===u.range[1]&&(u.range[0]-=1,u.range[1]+=1);var h=u.tickmode;if(\"auto\"===u.tickmode){u.tickmode=\"linear\";var f=u.nticks||i.constrain(u._length/40,4,9);n.autoTicks(u,Math.abs(u.range[1]-u.range[0])/f)}for(var p=n.calcTicks(u),d=0;d<p.length;++d)p[d].x=p[d].x*t.dataScale[c],\"date\"===u.type&&(p[d].text=p[d].text.replace(/\\<br\\>/g,\" \"));l[c]=p,u.tickmode=h}}e.ticks=l;for(var c=0;c<3;++c){o[c]=.5*(t.glplot.bounds[0][c]+t.glplot.bounds[1][c]);for(var d=0;d<2;++d)e.bounds[d][c]=t.glplot.bounds[d][c]}t.contourLevels=function(t){for(var e=new Array(3),r=0;r<3;++r){for(var n=t[r],i=new Array(n.length),a=0;a<n.length;++a)i[a]=n[a].x;e[r]=i}return e}(l)};var n=t(\"../../cartesian/axes\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"],o=[0,0,0]},{\"../../../lib\":719,\"../../cartesian/axes\":767}],816:[function(t,e,r){\"use strict\";function n(t,e){var r,n,i=[0,0,0,0];for(r=0;r<4;++r)for(n=0;n<4;++n)i[n]+=t[4*r+n]*e[r];return i}e.exports=function(t,e){return n(t.projection,n(t.view,n(t.model,[e[0],e[1],e[2],1])))}},{}],817:[function(t,e,r){\"use strict\";var n,i,a=t(\"gl-plot3d\").createCamera,o=t(\"gl-plot3d\").createScene,s=t(\"webgl-context\"),l=t(\"has-passive-events\"),c=t(\"../../registry\"),u=t(\"../../lib\"),h=t(\"../../plots/cartesian/axes\"),f=t(\"../../components/fx\"),p=t(\"../../lib/str2rgbarray\"),d=t(\"../../lib/show_no_webgl_msg\"),g=t(\"./project\"),v=t(\"./layout/convert\"),m=t(\"./layout/spikes\"),y=t(\"./layout/tick_marks\");function x(t,e,r,a){if(t.initializeGLCamera(),!function(t,e,r,a,l){var c={canvas:a,gl:l,container:t.container,axes:t.axesOptions,spikes:t.spikeOptions,pickRadius:10,snapToData:!0,autoScale:!0,autoBounds:!1,cameraObject:e,pixelRatio:r};if(t.staticMode){if(!(i||(n=document.createElement(\"canvas\"),i=s({canvas:n,preserveDrawingBuffer:!0,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"error creating static canvas/context for image server\");c.pixelRatio=t.pixelRatio,c.gl=i,c.canvas=n}try{t.glplot=o(c)}catch(t){return!1}return!0}(t,t.camera,e,r,a))return d(t);var c=t.graphDiv,p=function(t){if(!1!==t.fullSceneLayout.dragmode){var e={};e[t.id+\".camera\"]=T(t.camera),t.saveCamera(c.layout),t.graphDiv.emit(\"plotly_relayout\",e)}};return t.glplot.canvas.addEventListener(\"mouseup\",function(){p(t)}),t.glplot.canvas.addEventListener(\"wheel\",function(){c._context._scrollZoom.gl3d&&p(t)},!!l&&{passive:!1}),t.glplot.canvas.addEventListener(\"mousemove\",function(){if(!1!==t.fullSceneLayout.dragmode&&0!==t.camera.mouseListener.buttons){var e={};e[t.id+\".camera\"]=T(t.camera),t.graphDiv.emit(\"plotly_relayouting\",e)}}),t.staticMode||t.glplot.canvas.addEventListener(\"webglcontextlost\",function(e){c&&c.emit&&c.emit(\"plotly_webglcontextlost\",{event:e,layer:t.id})},!1),t.glplot.camera=t.camera,t.glplot.oncontextloss=function(){t.recoverContext()},t.glplot.onrender=function(t){var e,r=t.graphDiv,n=t.svgContainer,i=t.container.getBoundingClientRect(),a=i.width,o=i.height;n.setAttributeNS(null,\"viewBox\",\"0 0 \"+a+\" \"+o),n.setAttributeNS(null,\"width\",a),n.setAttributeNS(null,\"height\",o),y(t),t.glplot.axes.update(t.axesOptions);for(var s,l=Object.keys(t.traces),c=null,p=t.glplot.selection,d=0;d<l.length;++d)\"skip\"!==(e=t.traces[l[d]]).data.hoverinfo&&e.handlePick(p)&&(c=e),e.setContourLevels&&e.setContourLevels();function v(e,r){var n=t.fullSceneLayout[e];return h.tickText(n,n.d2l(r),\"hover\").text}if(null!==c){var m=g(t.glplot.cameraParams,p.dataCoordinate);e=c.data;var x,b=r._fullData[e.index],_=p.index,w={xLabel:v(\"xaxis\",p.traceCoordinate[0]),yLabel:v(\"yaxis\",p.traceCoordinate[1]),zLabel:v(\"zaxis\",p.traceCoordinate[2])},k=f.castHoverinfo(b,t.fullLayout,_),T=(k||\"\").split(\"+\"),A=k&&\"all\"===k;b.hovertemplate||A||(-1===T.indexOf(\"x\")&&(w.xLabel=void 0),-1===T.indexOf(\"y\")&&(w.yLabel=void 0),-1===T.indexOf(\"z\")&&(w.zLabel=void 0),-1===T.indexOf(\"text\")&&(p.textLabel=void 0),-1===T.indexOf(\"name\")&&(c.name=void 0));var M=[];\"cone\"===e.type||\"streamtube\"===e.type?(w.uLabel=v(\"xaxis\",p.traceCoordinate[3]),(A||-1!==T.indexOf(\"u\"))&&M.push(\"u: \"+w.uLabel),w.vLabel=v(\"yaxis\",p.traceCoordinate[4]),(A||-1!==T.indexOf(\"v\"))&&M.push(\"v: \"+w.vLabel),w.wLabel=v(\"zaxis\",p.traceCoordinate[5]),(A||-1!==T.indexOf(\"w\"))&&M.push(\"w: \"+w.wLabel),w.normLabel=p.traceCoordinate[6].toPrecision(3),(A||-1!==T.indexOf(\"norm\"))&&M.push(\"norm: \"+w.normLabel),\"streamtube\"===e.type&&(w.divergenceLabel=p.traceCoordinate[7].toPrecision(3),(A||-1!==T.indexOf(\"divergence\"))&&M.push(\"divergence: \"+w.divergenceLabel)),p.textLabel&&M.push(p.textLabel),x=M.join(\"<br>\")):\"isosurface\"===e.type||\"volume\"===e.type?(w.valueLabel=h.tickText(t.mockAxis,t.mockAxis.d2l(p.traceCoordinate[3]),\"hover\").text,M.push(\"value: \"+w.valueLabel),p.textLabel&&M.push(p.textLabel),x=M.join(\"<br>\")):x=p.textLabel;var S={x:p.traceCoordinate[0],y:p.traceCoordinate[1],z:p.traceCoordinate[2],data:b._input,fullData:b,curveNumber:b.index,pointNumber:_};f.appendArrayPointValue(S,b,_),e._module.eventData&&(S=b._module.eventData(S,p,b,{},_));var E={points:[S]};t.fullSceneLayout.hovermode&&f.loneHover({trace:b,x:(.5+.5*m[0]/m[3])*a,y:(.5-.5*m[1]/m[3])*o,xLabel:w.xLabel,yLabel:w.yLabel,zLabel:w.zLabel,text:x,name:c.name,color:f.castHoverOption(b,_,\"bgcolor\")||c.color,borderColor:f.castHoverOption(b,_,\"bordercolor\"),fontFamily:f.castHoverOption(b,_,\"font.family\"),fontSize:f.castHoverOption(b,_,\"font.size\"),fontColor:f.castHoverOption(b,_,\"font.color\"),nameLength:f.castHoverOption(b,_,\"namelength\"),textAlign:f.castHoverOption(b,_,\"align\"),hovertemplate:u.castOption(b,_,\"hovertemplate\"),hovertemplateLabels:u.extendFlat({},S,w),eventData:[S]},{container:n,gd:r}),p.buttons&&p.distance<5?r.emit(\"plotly_click\",E):r.emit(\"plotly_hover\",E),s=E}else f.loneUnhover(n),r.emit(\"plotly_unhover\",s);t.drawAnnotations(t)}.bind(null,t),t.traces={},t.make4thDimension(),!0}function b(t,e){var r=document.createElement(\"div\"),n=t.container;this.graphDiv=t.graphDiv;var i=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");i.style.position=\"absolute\",i.style.top=i.style.left=\"0px\",i.style.width=i.style.height=\"100%\",i.style[\"z-index\"]=20,i.style[\"pointer-events\"]=\"none\",r.appendChild(i),this.svgContainer=i,r.id=t.id,r.style.position=\"absolute\",r.style.top=r.style.left=\"0px\",r.style.width=r.style.height=\"100%\",n.appendChild(r),this.fullLayout=e,this.id=t.id||\"scene\",this.fullSceneLayout=e[this.id],this.plotArgs=[[],{},{}],this.axesOptions=v(e,e[this.id]),this.spikeOptions=m(e[this.id]),this.container=r,this.staticMode=!!t.staticPlot,this.pixelRatio=this.pixelRatio||t.plotGlPixelRatio||2,this.dataScale=[1,1,1],this.contourLevels=[[],[],[]],this.convertAnnotations=c.getComponentMethod(\"annotations3d\",\"convert\"),this.drawAnnotations=c.getComponentMethod(\"annotations3d\",\"draw\"),x(this,this.pixelRatio)}var _=b.prototype;_.initializeGLCamera=function(){var t=this.fullSceneLayout.camera,e=\"orthographic\"===t.projection.type;this.camera=a(this.container,{center:[t.center.x,t.center.y,t.center.z],eye:[t.eye.x,t.eye.y,t.eye.z],up:[t.up.x,t.up.y,t.up.z],_ortho:e,zoomMin:.01,zoomMax:100,mode:\"orbit\"})},_.recoverContext=function(){var t=this,e=this.glplot.gl,r=this.glplot.canvas,n=this.glplot.camera,i=this.glplot.pixelRatio;this.glplot.dispose(),requestAnimationFrame(function a(){e.isContextLost()?requestAnimationFrame(a):x(t,n,i,r)?t.plot.apply(t,t.plotArgs):u.error(\"Catastrophic and unrecoverable WebGL error. Context lost.\")})};var w=[\"xaxis\",\"yaxis\",\"zaxis\"];function k(t,e,r){for(var n=t.fullSceneLayout,i=0;i<3;i++){var a=w[i],o=a.charAt(0),s=n[a],l=e[o],c=e[o+\"calendar\"],h=e[\"_\"+o+\"length\"];if(u.isArrayOrTypedArray(l))for(var f,p=0;p<(h||l.length);p++)if(u.isArrayOrTypedArray(l[p]))for(var d=0;d<l[p].length;++d)f=s.d2l(l[p][d],0,c),!isNaN(f)&&isFinite(f)&&(r[0][i]=Math.min(r[0][i],f),r[1][i]=Math.max(r[1][i],f));else f=s.d2l(l[p],0,c),!isNaN(f)&&isFinite(f)&&(r[0][i]=Math.min(r[0][i],f),r[1][i]=Math.max(r[1][i],f));else r[0][i]=Math.min(r[0][i],0),r[1][i]=Math.max(r[1][i],h-1)}}function T(t){return{up:{x:t.up[0],y:t.up[1],z:t.up[2]},center:{x:t.center[0],y:t.center[1],z:t.center[2]},eye:{x:t.eye[0],y:t.eye[1],z:t.eye[2]},projection:{type:!0===t._ortho?\"orthographic\":\"perspective\"}}}_.plot=function(t,e,r){if(this.plotArgs=[t,e,r],!this.glplot.contextLost){var n,i,a,o,s,l,c=e[this.id],u=r[this.id];c.bgcolor?this.glplot.clearColor=p(c.bgcolor):this.glplot.clearColor=[0,0,0,0],this.glplot.snapToData=!0,this.fullLayout=e,this.fullSceneLayout=c,this.glplotLayout=c,this.axesOptions.merge(e,c),this.spikeOptions.merge(c),this.setCamera(c.camera),this.updateFx(c.dragmode,c.hovermode),this.camera.enableWheel=this.graphDiv._context._scrollZoom.gl3d,this.glplot.update({}),this.setConvert(s),t?Array.isArray(t)||(t=[t]):t=[];var h=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&k(this,n,h);!function(t,e){for(var r=t.fullSceneLayout,n=r.annotations||[],i=0;i<3;i++)for(var a=w[i],o=a.charAt(0),s=r[a],l=0;l<n.length;l++){var c=n[l];if(c.visible){var u=s.r2l(c[o]);!isNaN(u)&&isFinite(u)&&(e[0][i]=Math.min(e[0][i],u),e[1][i]=Math.max(e[1][i],u))}}}(this,h);var f=[1,1,1];for(o=0;o<3;++o)h[1][o]===h[0][o]?f[o]=1:f[o]=1/(h[1][o]-h[0][o]);for(this.dataScale=f,this.convertAnnotations(this),a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&((i=this.traces[n.uid])?i.data.type===n.type?i.update(n):(i.dispose(),i=n._module.plot(this,n),this.traces[n.uid]=i):(i=n._module.plot(this,n),this.traces[n.uid]=i),i.name=n.name);var d=Object.keys(this.traces);t:for(a=0;a<d.length;++a){for(o=0;o<t.length;++o)if(t[o].uid===d[a]&&!0===t[o].visible&&0!==t[o]._length)continue t;(i=this.traces[d[a]]).dispose(),delete this.traces[d[a]]}this.glplot.objects.sort(function(t,e){return t._trace.data.index-e._trace.data.index});var g=[[0,0,0],[0,0,0]],v=[],m={};for(a=0;a<3;++a){if((l=(s=c[w[a]]).type)in m?(m[l].acc*=f[a],m[l].count+=1):m[l]={acc:f[a],count:1},s.autorange){g[0][a]=1/0,g[1][a]=-1/0;var y=this.glplot.objects,x=this.fullSceneLayout.annotations||[],b=s._name.charAt(0);for(o=0;o<y.length;o++){var _=y[o],T=_.bounds,A=_._trace.data._pad||0;\"ErrorBars\"===_.constructor.name&&s._lowerLogErrorBound?g[0][a]=Math.min(g[0][a],s._lowerLogErrorBound):g[0][a]=Math.min(g[0][a],T[0][a]/f[a]-A),g[1][a]=Math.max(g[1][a],T[1][a]/f[a]+A)}for(o=0;o<x.length;o++){var M=x[o];if(M.visible){var S=s.r2l(M[b]);g[0][a]=Math.min(g[0][a],S),g[1][a]=Math.max(g[1][a],S)}}if(\"rangemode\"in s&&\"tozero\"===s.rangemode&&(g[0][a]=Math.min(g[0][a],0),g[1][a]=Math.max(g[1][a],0)),g[0][a]>g[1][a])g[0][a]=-1,g[1][a]=1;else{var E=g[1][a]-g[0][a];g[0][a]-=E/32,g[1][a]+=E/32}if(\"reversed\"===s.autorange){var C=g[0][a];g[0][a]=g[1][a],g[1][a]=C}}else{var L=s.range;g[0][a]=s.r2l(L[0]),g[1][a]=s.r2l(L[1])}g[0][a]===g[1][a]&&(g[0][a]-=1,g[1][a]+=1),v[a]=g[1][a]-g[0][a],this.glplot.bounds[0][a]=g[0][a]*f[a],this.glplot.bounds[1][a]=g[1][a]*f[a]}var P=[1,1,1];for(a=0;a<3;++a){var O=m[l=(s=c[w[a]]).type];P[a]=Math.pow(O.acc,1/O.count)/f[a]}var z;if(\"auto\"===c.aspectmode)z=Math.max.apply(null,P)/Math.min.apply(null,P)<=4?P:[1,1,1];else if(\"cube\"===c.aspectmode)z=[1,1,1];else if(\"data\"===c.aspectmode)z=P;else{if(\"manual\"!==c.aspectmode)throw new Error(\"scene.js aspectRatio was not one of the enumerated types\");var I=c.aspectratio;z=[I.x,I.y,I.z]}c.aspectratio.x=u.aspectratio.x=z[0],c.aspectratio.y=u.aspectratio.y=z[1],c.aspectratio.z=u.aspectratio.z=z[2],this.glplot.aspect=z;var D=c.domain||null,R=e._size||null;if(D&&R){var F=this.container.style;F.position=\"absolute\",F.left=R.l+D.x[0]*R.w+\"px\",F.top=R.t+(1-D.y[1])*R.h+\"px\",F.width=R.w*(D.x[1]-D.x[0])+\"px\",F.height=R.h*(D.y[1]-D.y[0])+\"px\"}this.glplot.redraw()}},_.destroy=function(){this.glplot&&(this.camera.mouseListener.enabled=!1,this.container.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=this.glplot.camera=null,this.glplot.dispose(),this.container.parentNode.removeChild(this.container),this.glplot=null)},_.getCamera=function(){return this.glplot.camera.view.recalcMatrix(this.camera.view.lastT()),T(this.glplot.camera)},_.setCamera=function(t){var e;this.glplot.camera.lookAt.apply(this,[[(e=t).eye.x,e.eye.y,e.eye.z],[e.center.x,e.center.y,e.center.z],[e.up.x,e.up.y,e.up.z]]);var r=\"orthographic\"===t.projection.type;if(r!==this.glplot.camera._ortho){this.glplot.redraw();var n=this.glplot.pixelRatio,i=this.glplot.clearColor;this.glplot.gl.clearColor(i[0],i[1],i[2],i[3]),this.glplot.gl.clear(this.glplot.gl.DEPTH_BUFFER_BIT|this.glplot.gl.COLOR_BUFFER_BIT),this.glplot.dispose(),x(this,n),this.glplot.camera._ortho=r}},_.saveCamera=function(t){var e=this.fullLayout,r=this.getCamera(),n=u.nestedProperty(t,this.id+\".camera\"),i=n.get(),a=!1;function o(t,e,r,n){var i=[\"up\",\"center\",\"eye\"],a=[\"x\",\"y\",\"z\"];return e[i[r]]&&t[i[r]][a[n]]===e[i[r]][a[n]]}if(void 0===i)a=!0;else{for(var s=0;s<3;s++)for(var l=0;l<3;l++)if(!o(r,i,s,l)){a=!0;break}(!i.projection||r.projection&&r.projection.type!==i.projection.type)&&(a=!0)}if(a){var h={};h[this.id+\".camera\"]=i,c.call(\"_storeDirectGUIEdit\",t,e._preGUI,h),n.set(r),u.nestedProperty(e,this.id+\".camera\").set(r)}return a},_.updateFx=function(t,e){var r=this.camera;if(r)if(\"orbit\"===t)r.mode=\"orbit\",r.keyBindingMode=\"rotate\";else if(\"turntable\"===t){r.up=[0,0,1],r.mode=\"turntable\",r.keyBindingMode=\"rotate\";var n=this.graphDiv,i=n._fullLayout,a=this.fullSceneLayout.camera,o=a.up.x,s=a.up.y,l=a.up.z;if(l/Math.sqrt(o*o+s*s+l*l)<.999){var h=this.id+\".camera.up\",f={x:0,y:0,z:1},p={};p[h]=f;var d=n.layout;c.call(\"_storeDirectGUIEdit\",d,i._preGUI,p),a.up=f,u.nestedProperty(d,h).set(f)}}else r.keyBindingMode=t;this.fullSceneLayout.hovermode=e},_.toImage=function(t){t||(t=\"png\"),this.staticMode&&this.container.appendChild(n),this.glplot.redraw();var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a);for(var o=0,s=i-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=a[4*(r*o+l)+c];a[4*(r*o+l)+c]=a[4*(r*s+l)+c],a[4*(r*s+l)+c]=u}var h=document.createElement(\"canvas\");h.width=r,h.height=i;var f,p=h.getContext(\"2d\"),d=p.createImageData(r,i);switch(d.data.set(a),p.putImageData(d,0,0),t){case\"jpeg\":f=h.toDataURL(\"image/jpeg\");break;case\"webp\":f=h.toDataURL(\"image/webp\");break;default:f=h.toDataURL(\"image/png\")}return this.staticMode&&this.container.removeChild(n),f},_.setConvert=function(){for(var t=0;t<3;t++){var e=this.fullSceneLayout[w[t]];h.setConvert(e,this.fullLayout),e.setScale=u.noop}},_.make4thDimension=function(){var t=this.graphDiv._fullLayout;this.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},h.setConvert(this.mockAxis,t)},e.exports=b},{\"../../components/fx\":632,\"../../lib\":719,\"../../lib/show_no_webgl_msg\":740,\"../../lib/str2rgbarray\":742,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./layout/convert\":811,\"./layout/spikes\":814,\"./layout/tick_marks\":815,\"./project\":816,\"gl-plot3d\":290,\"has-passive-events\":411,\"webgl-context\":556}],818:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){n=n||t.length;for(var i=new Array(n),a=0;a<n;a++)i[a]=[t[a],e[a],r[a]];return i}},{}],819:[function(t,e,r){\"use strict\";var n=t(\"./font_attributes\"),i=t(\"./animation_attributes\"),a=t(\"../components/color/attributes\"),o=t(\"./pad_attributes\"),s=t(\"../lib/extend\").extendFlat,l=n({editType:\"calc\"});l.family.dflt='\"Open Sans\", verdana, arial, sans-serif',l.size.dflt=12,l.color.dflt=a.defaultLine,e.exports={font:l,title:{text:{valType:\"string\",editType:\"layoutstyle\"},font:n({editType:\"layoutstyle\"}),xref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},yref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},x:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"layoutstyle\"},y:{valType:\"number\",min:0,max:1,dflt:\"auto\",editType:\"layoutstyle\"},xanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"left\",\"center\",\"right\"],editType:\"layoutstyle\"},yanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],editType:\"layoutstyle\"},pad:s(o({editType:\"layoutstyle\"}),{}),editType:\"layoutstyle\"},autosize:{valType:\"boolean\",dflt:!1,editType:\"none\"},width:{valType:\"number\",min:10,dflt:700,editType:\"plot\"},height:{valType:\"number\",min:10,dflt:450,editType:\"plot\"},margin:{l:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},r:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},t:{valType:\"number\",min:0,dflt:100,editType:\"plot\"},b:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},pad:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},autoexpand:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},paper_bgcolor:{valType:\"color\",dflt:a.background,editType:\"plot\"},plot_bgcolor:{valType:\"color\",dflt:a.background,editType:\"layoutstyle\"},separators:{valType:\"string\",editType:\"plot\"},hidesources:{valType:\"boolean\",dflt:!1,editType:\"plot\"},showlegend:{valType:\"boolean\",editType:\"legend\"},colorway:{valType:\"colorlist\",dflt:a.defaults,editType:\"calc\"},datarevision:{valType:\"any\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editrevision:{valType:\"any\",editType:\"none\"},selectionrevision:{valType:\"any\",editType:\"none\"},template:{valType:\"any\",editType:\"calc\"},modebar:{orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\",editType:\"modebar\"},bgcolor:{valType:\"color\",editType:\"modebar\"},color:{valType:\"color\",editType:\"modebar\"},activecolor:{valType:\"color\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"modebar\"},meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},transition:s({},i.transition,{editType:\"none\"}),_deprecated:{title:{valType:\"string\",editType:\"layoutstyle\"},titlefont:n({editType:\"layoutstyle\"})}}},{\"../components/color/attributes\":592,\"../lib/extend\":710,\"./animation_attributes\":762,\"./font_attributes\":793,\"./pad_attributes\":827}],820:[function(t,e,r){\"use strict\";var n={\"open-street-map\":{id:\"osm\",version:8,sources:{\"plotly-osm-tiles\":{type:\"raster\",attribution:'<a href=\"http://www.openstreetmap.org/about/\" target=\"_blank\">\\xa9 OpenStreetMap</a>',tiles:[\"https://a.tile.openstreetmap.org/{z}/{x}/{y}.png\",\"https://b.tile.openstreetmap.org/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-osm-tiles\",type:\"raster\",source:\"plotly-osm-tiles\",minzoom:0,maxzoom:22}]},\"white-bg\":{id:\"white-bg\",version:8,sources:{},layers:[{id:\"white-bg\",type:\"background\",paint:{\"background-color\":\"#FFFFFF\"},minzoom:0,maxzoom:22}]},\"carto-positron\":{id:\"carto-positron\",version:8,sources:{\"plotly-carto-positron\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/light_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-positron\",type:\"raster\",source:\"plotly-carto-positron\",minzoom:0,maxzoom:22}]},\"carto-darkmatter\":{id:\"carto-darkmatter\",version:8,sources:{\"plotly-carto-darkmatter\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/dark_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-darkmatter\",type:\"raster\",source:\"plotly-carto-darkmatter\",minzoom:0,maxzoom:22}]},\"stamen-terrain\":{id:\"stamen-terrain\",version:8,sources:{\"plotly-stamen-terrain\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/terrain/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-terrain\",type:\"raster\",source:\"plotly-stamen-terrain\",minzoom:0,maxzoom:22}]},\"stamen-toner\":{id:\"stamen-toner\",version:8,sources:{\"plotly-stamen-toner\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/toner/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-toner\",type:\"raster\",source:\"plotly-stamen-toner\",minzoom:0,maxzoom:22}]},\"stamen-watercolor\":{id:\"stamen-watercolor\",version:8,sources:{\"plotly-stamen-watercolor\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://creativecommons.org/licenses/by-sa/3.0\">CC BY SA</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/watercolor/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-watercolor\",type:\"raster\",source:\"plotly-stamen-watercolor\",minzoom:0,maxzoom:22}]}},i=Object.keys(n);e.exports={requiredVersion:\"1.1.1\",styleUrlPrefix:\"mapbox://styles/mapbox/\",styleUrlSuffix:\"v9\",styleValuesMapbox:[\"basic\",\"streets\",\"outdoors\",\"light\",\"dark\",\"satellite\",\"satellite-streets\"],styleValueDflt:\"basic\",stylesNonMapbox:n,styleValuesNonMapbox:i,traceLayerPrefix:\"plotly-trace-layer-\",layoutLayerPrefix:\"plotly-layout-layer-\",wrongVersionErrorMsg:[\"Your custom plotly.js bundle is not using the correct mapbox-gl version\",\"Please install mapbox-gl@1.1.1.\"].join(\"\\n\"),noAccessTokenErrorMsg:[\"Missing Mapbox access token.\",\"Mapbox trace type require a Mapbox access token to be registered.\",\"For example:\",\"  Plotly.plot(gd, data, layout, { mapboxAccessToken: 'my-access-token' });\",\"More info here: https://www.mapbox.com/help/define-access-token/\"].join(\"\\n\"),missingStyleErrorMsg:[\"No valid mapbox style found, please set `mapbox.style` to one of:\",i.join(\", \"),\"or register a Mapbox access token to use a Mapbox-served style.\"].join(\"\\n\"),multipleTokensErrorMsg:[\"Set multiple mapbox access token across different mapbox subplot,\",\"using first token found as mapbox-gl does not allow multipleaccess tokens on the same page.\"].join(\"\\n\"),mapOnErrorMsg:\"Mapbox error.\",mapboxLogo:{path0:\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\",path1:\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\",path2:\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\",polygon:\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34\"},styleRules:{map:\"overflow:hidden;position:relative;\",\"missing-css\":\"display:none;\",canary:\"background-color:salmon;\",\"ctrl-bottom-left\":\"position: absolute; pointer-events: none; z-index: 2; bottom: 0; left: 0;\",\"ctrl-bottom-right\":\"position: absolute; pointer-events: none; z-index: 2; right: 0; bottom: 0;\",ctrl:\"clear: both; pointer-events: auto; transform: translate(0, 0);\",\"ctrl-attrib.mapboxgl-compact .mapboxgl-ctrl-attrib-inner\":\"display: none;\",\"ctrl-attrib.mapboxgl-compact:hover .mapboxgl-ctrl-attrib-inner\":\"display: block; margin-top:2px\",\"ctrl-attrib.mapboxgl-compact:hover\":\"padding: 2px 24px 2px 4px; visibility: visible; margin-top: 6px;\",\"ctrl-attrib.mapboxgl-compact::after\":'content: \"\"; cursor: pointer; position: absolute; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3Csvg viewBox=\"0 0 20 20\" xmlns=\"http://www.w3.org/2000/svg\"%3E %3Cpath fill=\"%23333333\" fill-rule=\"evenodd\" d=\"M4,10a6,6 0 1,0 12,0a6,6 0 1,0 -12,0 M9,7a1,1 0 1,0 2,0a1,1 0 1,0 -2,0 M9,10a1,1 0 1,1 2,0l0,3a1,1 0 1,1 -2,0\"/%3E %3C/svg%3E\\'); background-color: rgba(255, 255, 255, 0.5); width: 24px; height: 24px; box-sizing: border-box; border-radius: 12px;',\"ctrl-attrib.mapboxgl-compact\":\"min-height: 20px; padding: 0; margin: 10px; position: relative; background-color: #fff; border-radius: 3px 12px 12px 3px;\",\"ctrl-bottom-right > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; right: 0\",\"ctrl-bottom-left > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; left: 0\",\"ctrl-bottom-left .mapboxgl-ctrl\":\"margin: 0 0 10px 10px; float: left;\",\"ctrl-bottom-right .mapboxgl-ctrl\":\"margin: 0 10px 10px 0; float: right;\",\"ctrl-attrib\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a:hover\":\"color: inherit; text-decoration: underline;\",\"ctrl-attrib .mapbox-improve-map\":\"font-weight: bold; margin-left: 2px;\",\"attrib-empty\":\"display: none;\",\"ctrl-logo\":'display:block; width: 21px; height: 21px; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3C?xml version=\"1.0\" encoding=\"utf-8\"?%3E %3Csvg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\" viewBox=\"0 0 21 21\" style=\"enable-background:new 0 0 21 21;\" xml:space=\"preserve\"%3E%3Cg transform=\"translate(0,0.01)\"%3E%3Cpath d=\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3Cpath d=\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpath d=\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpolygon points=\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34 \" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3C/g%3E%3C/svg%3E\\')'}}},{}],821:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t.split(\" \"),i=r[0],a=r[1],o=n.isArrayOrTypedArray(e)?n.mean(e):e,s=.5+o/100,l=1.5+o/100,c=[\"\",\"\"],u=[0,0];switch(i){case\"top\":c[0]=\"top\",u[1]=-l;break;case\"bottom\":c[0]=\"bottom\",u[1]=l}switch(a){case\"left\":c[1]=\"right\",u[0]=-s;break;case\"right\":c[1]=\"left\",u[0]=s}return{anchor:c[0]&&c[1]?c.join(\"-\"):c[0]?c[0]:c[1]?c[1]:\"center\",offset:u}}},{\"../../lib\":719}],822:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"../../lib\"),a=t(\"../../plots/get_data\").getSubplotCalcData,o=t(\"../../constants/xmlns_namespaces\"),s=t(\"d3\"),l=t(\"../../components/drawing\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"./mapbox\"),h=r.constants=t(\"./constants\");function f(t){return\"string\"==typeof t&&-1!==h.styleValuesMapbox.indexOf(t)}r.name=\"mapbox\",r.attr=\"subplot\",r.idRoot=\"mapbox\",r.idRegex=r.attrRegex=i.counterRegex(\"mapbox\"),r.attributes={subplot:{valType:\"subplotid\",dflt:\"mapbox\",editType:\"calc\"}},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){var e=t._fullLayout,r=t.calcdata,o=e._subplots.mapbox;if(n.version!==h.requiredVersion)throw new Error(h.wrongVersionErrorMsg);var s=function(t,e){var r=t._fullLayout;if(\"\"===t._context.mapboxAccessToken)return\"\";for(var n=[],a=[],o=!1,s=!1,l=0;l<e.length;l++){var c=r[e[l]],u=c.accesstoken;f(c.style)&&(u?i.pushUnique(n,u):(f(c._input.style)&&(i.error(\"Uses Mapbox map style, but did not set an access token.\"),o=!0),s=!0)),u&&i.pushUnique(a,u)}if(s){var p=o?h.noAccessTokenErrorMsg:h.missingStyleErrorMsg;throw new Error(p)}return n.length?(n.length>1&&i.warn(h.multipleTokensErrorMsg),n[0]):(a.length&&i.log([\"Listed mapbox access token(s)\",a.join(\",\"),\"but did not use a Mapbox map style, ignoring token(s).\"].join(\" \")),\"\")}(t,o);n.accessToken=s;for(var l=0;l<o.length;l++){var c=o[l],p=a(r,\"mapbox\",c),d=e[c],g=d._subplot;g||(g=new u(t,c),e[c]._subplot=g),g.viewInitial||(g.viewInitial={center:i.extendFlat({},d.center),zoom:d.zoom,bearing:d.bearing,pitch:d.pitch}),g.plot(p,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.mapbox||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._subplot&&n[o]._subplot.destroy()}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=e._size,i=0;i<r.length;i++){var a=e[r[i]],u=a.domain,f=a._subplot.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":f,x:n.l+n.w*u.x[0],y:n.t+n.h*(1-u.y[1]),width:n.w*(u.x[1]-u.x[0]),height:n.h*(u.y[1]-u.y[0]),preserveAspectRatio:\"none\"});var p=s.select(a._subplot.div);if(!(null===p.select(\".mapboxgl-ctrl-logo\").node().offsetParent)){var d=e._glimages.append(\"g\");d.attr(\"transform\",\"translate(\"+(n.l+n.w*u.x[0]+10)+\", \"+(n.t+n.h*(1-u.y[0])-31)+\")\"),d.append(\"path\").attr(\"d\",h.mapboxLogo.path0).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"}),d.append(\"path\").attr(\"d\",h.mapboxLogo.path1).style(\"opacity\",.35).style(\"enable-background\",\"new\"),d.append(\"path\").attr(\"d\",h.mapboxLogo.path2).style(\"opacity\",.35).style(\"enable-background\",\"new\"),d.append(\"polygon\").attr(\"points\",h.mapboxLogo.polygon).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"})}var g=p.select(\".mapboxgl-ctrl-attrib\").text().replace(\"Improve this map\",\"\"),v=e._glimages.append(\"g\"),m=v.append(\"text\");m.text(g).classed(\"static-attribution\",!0).attr({\"font-size\":12,\"font-family\":\"Arial\",color:\"rgba(0, 0, 0, 0.75)\",\"text-anchor\":\"end\",\"data-unformatted\":g});var y=l.bBox(m.node()),x=n.w*(u.x[1]-u.x[0]);if(y.width>x/2){var b=g.split(\"|\").join(\"<br>\");m.text(b).attr(\"data-unformatted\",b).call(c.convertToTspans,t),y=l.bBox(m.node())}m.attr(\"transform\",\"translate(-3, \"+(8-y.height)+\")\"),v.insert(\"rect\",\".static-attribution\").attr({x:-y.width-6,y:-y.height-3,width:y.width+6,height:y.height+3,fill:\"rgba(255, 255, 255, 0.75)\"});var _=1;y.width+6>x&&(_=x/(y.width+6));var w=[n.l+n.w*u.x[1],n.t+n.h*(1-u.y[0])];v.attr(\"transform\",\"translate(\"+w[0]+\",\"+w[1]+\") scale(\"+_+\")\")}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=0;n<r.length;n++){e[r[n]]._subplot.updateFx(e)}}},{\"../../components/drawing\":614,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/get_data\":802,\"./constants\":820,\"./layout_attributes\":824,\"./layout_defaults\":825,\"./mapbox\":826,d3:163,\"mapbox-gl\":426}],823:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./convert_text_opts\"),a=t(\"./constants\");function o(t,e){this.subplot=t,this.uid=t.uid+\"-\"+e,this.index=e,this.idSource=\"source-\"+this.uid,this.idLayer=a.layoutLayerPrefix+this.uid,this.sourceType=null,this.source=null,this.layerType=null,this.below=null,this.visible=!1}var s=o.prototype;function l(t){var e=t.source;return t.visible&&(n.isPlainObject(e)||(\"string\"==typeof e||Array.isArray(e))&&e.length>0)}function c(t){var e={},r={};switch(t.type){case\"circle\":n.extendFlat(r,{\"circle-radius\":t.circle.radius,\"circle-color\":t.color,\"circle-opacity\":t.opacity});break;case\"line\":n.extendFlat(r,{\"line-width\":t.line.width,\"line-color\":t.color,\"line-opacity\":t.opacity,\"line-dasharray\":t.line.dash});break;case\"fill\":n.extendFlat(r,{\"fill-color\":t.color,\"fill-outline-color\":t.fill.outlinecolor,\"fill-opacity\":t.opacity});break;case\"symbol\":var a=t.symbol,o=i(a.textposition,a.iconsize);n.extendFlat(e,{\"icon-image\":a.icon+\"-15\",\"icon-size\":a.iconsize/10,\"text-field\":a.text,\"text-size\":a.textfont.size,\"text-anchor\":o.anchor,\"text-offset\":o.offset,\"symbol-placement\":a.placement}),n.extendFlat(r,{\"icon-color\":t.color,\"text-color\":a.textfont.color,\"text-opacity\":t.opacity})}return{layout:e,paint:r}}s.update=function(t){this.visible?this.needsNewSource(t)?(this.removeLayer(),this.updateSource(t),this.updateLayer(t)):this.needsNewLayer(t)?this.updateLayer(t):this.updateStyle(t):(this.updateSource(t),this.updateLayer(t)),this.visible=l(t)},s.needsNewSource=function(t){return this.sourceType!==t.sourcetype||this.source!==t.source||this.layerType!==t.type},s.needsNewLayer=function(t){return this.layerType!==t.type||this.below!==this.subplot.belowLookup[\"layout-\"+this.index]},s.updateSource=function(t){var e=this.subplot.map;if(e.getSource(this.idSource)&&e.removeSource(this.idSource),this.sourceType=t.sourcetype,this.source=t.source,l(t)){var r=function(t){var e,r=t.sourcetype,n=t.source,i={type:r};\"geojson\"===r?e=\"data\":\"vector\"===r?e=\"string\"==typeof n?\"url\":\"tiles\":\"raster\"===r?(e=\"tiles\",i.tileSize=256):\"image\"===r&&(e=\"url\",i.coordinates=t.coordinates);i[e]=n,t.sourceattribution&&(i.attribution=t.sourceattribution);return i}(t);e.addSource(this.idSource,r)}},s.updateLayer=function(t){var e,r=this.subplot,n=c(t),i=this.subplot.belowLookup[\"layout-\"+this.index];if(\"traces\"===i)for(var o=r.getMapLayers(),s=0;s<o.length;s++){var u=o[s].id;if(\"string\"==typeof u&&0===u.indexOf(a.traceLayerPrefix)){e=u;break}}else e=i;this.removeLayer(),l(t)&&r.addLayer({id:this.idLayer,source:this.idSource,\"source-layer\":t.sourcelayer||\"\",type:t.type,minzoom:t.minzoom,maxzoom:t.maxzoom,layout:n.layout,paint:n.paint},e),this.layerType=t.type,this.below=i},s.updateStyle=function(t){if(l(t)){var e=c(t);this.subplot.setOptions(this.idLayer,\"setLayoutProperty\",e.layout),this.subplot.setOptions(this.idLayer,\"setPaintProperty\",e.paint)}},s.removeLayer=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer)},s.dispose=function(){var t=this.subplot.map;t.removeLayer(this.idLayer),t.removeSource(this.idSource)},e.exports=function(t,e,r){var n=new o(t,e);return n.update(r),n}},{\"../../lib\":719,\"./constants\":820,\"./convert_text_opts\":821}],824:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\").defaultLine,a=t(\"../domain\").attributes,o=t(\"../font_attributes\"),s=t(\"../../traces/scatter/attributes\").textposition,l=t(\"../../plot_api/edit_types\").overrideAll,c=t(\"../../plot_api/plot_template\").templatedArray,u=t(\"./constants\"),h=o({});h.family.dflt=\"Open Sans Regular, Arial Unicode MS Regular\",(e.exports=l({_arrayAttrRegexps:[n.counterRegex(\"mapbox\",\".layers\",!0)],domain:a({name:\"mapbox\"}),accesstoken:{valType:\"string\",noBlank:!0,strict:!0},style:{valType:\"any\",values:u.styleValuesMapbox.concat(u.styleValuesNonMapbox),dflt:u.styleValueDflt},center:{lon:{valType:\"number\",dflt:0},lat:{valType:\"number\",dflt:0}},zoom:{valType:\"number\",dflt:1},bearing:{valType:\"number\",dflt:0},pitch:{valType:\"number\",dflt:0},layers:c(\"layer\",{visible:{valType:\"boolean\",dflt:!0},sourcetype:{valType:\"enumerated\",values:[\"geojson\",\"vector\",\"raster\",\"image\"],dflt:\"geojson\"},source:{valType:\"any\"},sourcelayer:{valType:\"string\",dflt:\"\"},sourceattribution:{valType:\"string\"},type:{valType:\"enumerated\",values:[\"circle\",\"line\",\"fill\",\"symbol\",\"raster\"],dflt:\"circle\"},coordinates:{valType:\"any\"},below:{valType:\"string\"},color:{valType:\"color\",dflt:i},opacity:{valType:\"number\",min:0,max:1,dflt:1},minzoom:{valType:\"number\",min:0,max:24,dflt:0},maxzoom:{valType:\"number\",min:0,max:24,dflt:24},circle:{radius:{valType:\"number\",dflt:15}},line:{width:{valType:\"number\",dflt:2},dash:{valType:\"data_array\"}},fill:{outlinecolor:{valType:\"color\",dflt:i}},symbol:{icon:{valType:\"string\",dflt:\"marker\"},iconsize:{valType:\"number\",dflt:10},text:{valType:\"string\",dflt:\"\"},placement:{valType:\"enumerated\",values:[\"point\",\"line\",\"line-center\"],dflt:\"point\"},textfont:h,textposition:n.extendFlat({},s,{arrayOk:!1})}})},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../traces/scatter/attributes\":1112,\"../domain\":792,\"../font_attributes\":793,\"./constants\":820}],825:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../subplot_defaults\"),a=t(\"../array_container_defaults\"),o=t(\"./layout_attributes\");function s(t,e,r,n){r(\"accesstoken\",n.accessToken),r(\"style\"),r(\"center.lon\"),r(\"center.lat\"),r(\"zoom\"),r(\"bearing\"),r(\"pitch\"),a(t,e,{name:\"layers\",handleItemDefaults:l}),e._input=t}function l(t,e){function r(r,i){return n.coerce(t,e,o.layers,r,i)}if(r(\"visible\")){var i,a=r(\"sourcetype\"),s=\"raster\"===a||\"image\"===a;r(\"source\"),r(\"sourceattribution\"),\"vector\"===a&&r(\"sourcelayer\"),\"image\"===a&&r(\"coordinates\"),s&&(i=\"raster\");var l=r(\"type\",i);s&&\"raster\"!==l&&(l=e.type=\"raster\",n.log(\"Source types *raster* and *image* must drawn *raster* layer type.\")),r(\"below\"),r(\"color\"),r(\"opacity\"),r(\"minzoom\"),r(\"maxzoom\"),\"circle\"===l&&r(\"circle.radius\"),\"line\"===l&&(r(\"line.width\"),r(\"line.dash\")),\"fill\"===l&&r(\"fill.outlinecolor\"),\"symbol\"===l&&(r(\"symbol.icon\"),r(\"symbol.iconsize\"),r(\"symbol.text\"),n.coerceFont(r,\"symbol.textfont\"),r(\"symbol.textposition\"),r(\"symbol.placement\"))}}e.exports=function(t,e,r){i(t,e,r,{type:\"mapbox\",attributes:o,handleDefaults:s,partition:\"y\",accessToken:e._mapboxAccessToken})}},{\"../../lib\":719,\"../array_container_defaults\":763,\"../subplot_defaults\":842,\"./layout_attributes\":824}],826:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"d3\"),a=t(\"../../components/fx\"),o=t(\"../../lib\"),s=t(\"../../registry\"),l=t(\"../cartesian/axes\"),c=t(\"../../components/dragelement\"),u=t(\"../cartesian/select\").prepSelect,h=t(\"../cartesian/select\").selectOnClick,f=t(\"./constants\"),p=t(\"./layers\");function d(t,e){this.id=e,this.gd=t;var r=t._fullLayout,n=t._context;this.container=r._glcontainer.node(),this.isStatic=n.staticPlot,this.uid=r._uid+\"-\"+this.id,this.div=null,this.xaxis=null,this.yaxis=null,this.createFramework(r),this.map=null,this.accessToken=null,this.styleObj=null,this.traceHash={},this.layerList=[],this.belowLookup={}}var g=d.prototype;g.plot=function(t,e,r){var n,i=this,a=e[i.id];i.map&&a.accesstoken!==i.accessToken&&(i.map.remove(),i.map=null,i.styleObj=null,i.traceHash=[],i.layerList={}),n=i.map?new Promise(function(r,n){i.updateMap(t,e,r,n)}):new Promise(function(r,n){i.createMap(t,e,r,n)}),r.push(n)},g.createMap=function(t,e,r,i){var a=this,o=e[a.id],s=a.styleObj=m(o.style);a.accessToken=o.accesstoken;var l=a.map=new n.Map({container:a.div,style:s.style,center:x(o.center),zoom:o.zoom,bearing:o.bearing,pitch:o.pitch,interactive:!a.isStatic,preserveDrawingBuffer:a.isStatic,doubleClickZoom:!1,boxZoom:!1,attributionControl:!1}).addControl(new n.AttributionControl({compact:!0}));l._canvas.style.left=\"0px\",l._canvas.style.top=\"0px\",a.rejectOnError(i),a.isStatic||a.initFx(t,e);var c=[];c.push(new Promise(function(t){l.once(\"load\",t)})),c=c.concat(a.fetchMapData(t,e)),Promise.all(c).then(function(){a.fillBelowLookup(t,e),a.updateData(t),a.updateLayout(e),a.resolveOnRender(r)}).catch(i)},g.fetchMapData=function(t){var e=[];function r(t){return new Promise(function(e,r){i.json(t,function(n,i){if(n){delete PlotlyGeoAssets[t];var a=404===n.status?'GeoJSON at URL \"'+t+'\" does not exist.':\"Unexpected error while fetching from \"+t;return r(new Error(a))}PlotlyGeoAssets[t]=i,e(i)})})}for(var n=0;n<t.length;n++){var a=t[n][0].trace.geojson;\"string\"!=typeof a||PlotlyGeoAssets[a]||(PlotlyGeoAssets[a]=\"pending\",e.push(r(a)))}return e},g.updateMap=function(t,e,r,n){var i=this,a=i.map,o=e[this.id];i.rejectOnError(n);var s=[],l=m(o.style);i.styleObj.id!==l.id&&(i.styleObj=l,a.setStyle(l.style),i.traceHash={},s.push(new Promise(function(t){a.once(\"styledata\",t)}))),s=s.concat(i.fetchMapData(t,e)),Promise.all(s).then(function(){i.fillBelowLookup(t,e),i.updateData(t),i.updateLayout(e),i.resolveOnRender(r)}).catch(n)},g.fillBelowLookup=function(t,e){var r,n,i=e[this.id].layers,a=this.belowLookup={},o=!1;for(r=0;r<t.length;r++){var s=t[r][0].trace,l=s._module;\"string\"==typeof s.below?n=s.below:l.getBelow&&(n=l.getBelow(s,this)),\"\"===n&&(o=!0),a[\"trace-\"+s.uid]=n||\"\"}for(r=0;r<i.length;r++){var c=i[r];n=\"string\"==typeof c.below?c.below:o?\"traces\":\"\",a[\"layout-\"+r]=n}var u,h,f={};for(u in a)f[n=a[u]]?f[n].push(u):f[n]=[u];for(n in f){var p=f[n];if(p.length>1)for(r=0;r<p.length;r++)0===(u=p[r]).indexOf(\"trace-\")?(h=u.split(\"trace-\")[1],this.traceHash[h]&&(this.traceHash[h].below=null)):0===u.indexOf(\"layout-\")&&(h=u.split(\"layout-\")[1],this.layerList[h]&&(this.layerList[h].below=null))}};var v={choroplethmapbox:0,densitymapbox:1,scattermapbox:2};function m(t){var e={};return o.isPlainObject(t)?(e.id=t.id,e.style=t):\"string\"==typeof t?(e.id=t,-1!==f.styleValuesMapbox.indexOf(t)?e.style=y(t):f.stylesNonMapbox[t]?e.style=f.stylesNonMapbox[t]:e.style=t):(e.id=f.styleValueDflt,e.style=y(f.styleValueDflt)),e.transition={duration:0,delay:0},e}function y(t){return f.styleUrlPrefix+t+\"-\"+f.styleUrlSuffix}function x(t){return[t.lon,t.lat]}g.updateData=function(t){var e,r,n,i,a=this.traceHash,o=t.slice().sort(function(t,e){return v[t[0].trace.type]-v[e[0].trace.type]});for(n=0;n<o.length;n++){var s=o[n];(e=a[(r=s[0].trace).uid])?e.update(s):r._module&&(a[r.uid]=r._module.plot(this,s))}var l=Object.keys(a);t:for(n=0;n<l.length;n++){var c=l[n];for(i=0;i<t.length;i++)if(c===(r=t[i][0].trace).uid)continue t;(e=a[c]).dispose(),delete a[c]}},g.updateLayout=function(t){var e=this.map,r=t[this.id];e.setCenter(x(r.center)),e.setZoom(r.zoom),e.setBearing(r.bearing),e.setPitch(r.pitch),this.updateLayers(t),this.updateFramework(t),this.updateFx(t),this.map.resize(),this.gd._context._scrollZoom.mapbox?e.scrollZoom.enable():e.scrollZoom.disable()},g.resolveOnRender=function(t){var e=this.map;e.on(\"render\",function r(){e.loaded()&&(e.off(\"render\",r),setTimeout(t,0))})},g.rejectOnError=function(t){var e=this.map;function r(){t(new Error(f.mapOnErrorMsg))}e.once(\"error\",r),e.once(\"style.error\",r),e.once(\"source.error\",r),e.once(\"tile.error\",r),e.once(\"layer.error\",r)},g.createFramework=function(t){var e=this,r=e.div=document.createElement(\"div\");r.id=e.uid,r.style.position=\"absolute\",e.container.appendChild(r),e.xaxis={_id:\"x\",c2p:function(t){return e.project(t).x}},e.yaxis={_id:\"y\",c2p:function(t){return e.project(t).y}},e.updateFramework(t),e.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},l.setConvert(e.mockAxis,t)},g.initFx=function(t,e){var r=this,n=r.gd,i=r.map,o=!1;function l(){a.loneUnhover(e._hoverlayer)}function c(){var t=r.getView();n.emit(\"plotly_relayouting\",r.getViewEdits(t))}i.on(\"moveend\",function(t){if(r.map){var e=n._fullLayout;if(t.originalEvent||o){var i=e[r.id];s.call(\"_storeDirectGUIEdit\",n.layout,e._preGUI,r.getViewEdits(i));var a=r.getView();i._input.center=i.center=a.center,i._input.zoom=i.zoom=a.zoom,i._input.bearing=i.bearing=a.bearing,i._input.pitch=i.pitch=a.pitch,n.emit(\"plotly_relayout\",r.getViewEdits(a))}o=!1,e._rehover&&e._rehover()}}),i.on(\"wheel\",function(){o=!0}),i.on(\"mousemove\",function(t){var e=r.div.getBoundingClientRect();t.clientX=t.point.x+e.left,t.clientY=t.point.y+e.top,t.target.getBoundingClientRect=function(){return e},r.xaxis.p2c=function(){return t.lngLat.lng},r.yaxis.p2c=function(){return t.lngLat.lat},n._fullLayout._rehover=function(){n._fullLayout._hoversubplot===r.id&&a.hover(n,t,r.id)},a.hover(n,t,r.id),n._fullLayout._hoversubplot=r.id}),i.on(\"dragstart\",l),i.on(\"zoomstart\",l),i.on(\"mouseout\",function(){n._fullLayout._hoversubplot=null}),i.on(\"drag\",c),i.on(\"zoom\",c),i.on(\"dblclick\",function(){var t=n._fullLayout[r.id];s.call(\"_storeDirectGUIEdit\",n.layout,n._fullLayout._preGUI,r.getViewEdits(t));var e=r.viewInitial;i.setCenter(x(e.center)),i.setZoom(e.zoom),i.setBearing(e.bearing),i.setPitch(e.pitch);var a=r.getView();t._input.center=t.center=a.center,t._input.zoom=t.zoom=a.zoom,t._input.bearing=t.bearing=a.bearing,t._input.pitch=t.pitch=a.pitch,n.emit(\"plotly_doubleclick\",null),n.emit(\"plotly_relayout\",r.getViewEdits(a))}),r.clearSelect=function(){n._fullLayout._zoomlayer.selectAll(\".select-outline\").remove()},r.onClickInPanFn=function(t){return function(e){var i=n._fullLayout.clickmode;i.indexOf(\"select\")>-1&&h(e.originalEvent,n,[r.xaxis],[r.yaxis],r.id,t),i.indexOf(\"event\")>-1&&a.click(n,e.originalEvent)}}},g.updateFx=function(t){var e=this,r=e.map,n=e.gd;if(!e.isStatic){var i,a=t.dragmode;i=\"select\"===a?function(t,r){(t.range={})[e.id]=[l([r.xmin,r.ymin]),l([r.xmax,r.ymax])]}:function(t,r,n){(t.lassoPoints={})[e.id]=n.filtered.map(l)};var s=e.dragOptions;e.dragOptions=o.extendDeep(s||{},{element:e.div,gd:n,plotinfo:{id:e.id,xaxis:e.xaxis,yaxis:e.yaxis,fillRangeItems:i},xaxes:[e.xaxis],yaxes:[e.yaxis],subplot:e.id}),r.off(\"click\",e.onClickInPanHandler),\"select\"===a||\"lasso\"===a?(r.dragPan.disable(),r.on(\"zoomstart\",e.clearSelect),e.dragOptions.prepFn=function(t,r,n){u(t,r,n,e.dragOptions,a)},c.init(e.dragOptions)):(r.dragPan.enable(),r.off(\"zoomstart\",e.clearSelect),e.div.onmousedown=null,e.onClickInPanHandler=e.onClickInPanFn(e.dragOptions),r.on(\"click\",e.onClickInPanHandler))}function l(t){var r=e.map.unproject(t);return[r.lng,r.lat]}},g.updateFramework=function(t){var e=t[this.id].domain,r=t._size,n=this.div.style;n.width=r.w*(e.x[1]-e.x[0])+\"px\",n.height=r.h*(e.y[1]-e.y[0])+\"px\",n.left=r.l+e.x[0]*r.w+\"px\",n.top=r.t+(1-e.y[1])*r.h+\"px\",this.xaxis._offset=r.l+e.x[0]*r.w,this.xaxis._length=r.w*(e.x[1]-e.x[0]),this.yaxis._offset=r.t+(1-e.y[1])*r.h,this.yaxis._length=r.h*(e.y[1]-e.y[0])},g.updateLayers=function(t){var e,r=t[this.id].layers,n=this.layerList;if(r.length!==n.length){for(e=0;e<n.length;e++)n[e].dispose();for(n=this.layerList=[],e=0;e<r.length;e++)n.push(p(this,e,r[e]))}else for(e=0;e<r.length;e++)n[e].update(r[e])},g.destroy=function(){this.map&&(this.map.remove(),this.map=null,this.container.removeChild(this.div))},g.toImage=function(){return this.map.stop(),this.map.getCanvas().toDataURL()},g.setOptions=function(t,e,r){for(var n in r)this.map[e](t,n,r[n])},g.getMapLayers=function(){return this.map.getStyle().layers},g.addLayer=function(t,e){var r=this.map;if(\"string\"==typeof e){if(\"\"===e)return void r.addLayer(t,e);for(var n=this.getMapLayers(),i=0;i<n.length;i++)if(e===n[i].id)return void r.addLayer(t,e);o.warn([\"Trying to add layer with *below* value\",e,\"referencing a layer that does not exist\",\"or that does not yet exist.\"].join(\" \"))}r.addLayer(t)},g.project=function(t){return this.map.project(new n.LngLat(t[0],t[1]))},g.getView=function(){var t=this.map,e=t.getCenter();return{center:{lon:e.lng,lat:e.lat},zoom:t.getZoom(),bearing:t.getBearing(),pitch:t.getPitch()}},g.getViewEdits=function(t){for(var e=this.id,r=[\"center\",\"zoom\",\"bearing\",\"pitch\"],n={},i=0;i<r.length;i++){var a=r[i];n[e+\".\"+a]=t[a]}return n},e.exports=d},{\"../../components/dragelement\":611,\"../../components/fx\":632,\"../../lib\":719,\"../../registry\":847,\"../cartesian/axes\":767,\"../cartesian/select\":784,\"./constants\":820,\"./layers\":823,d3:163,\"mapbox-gl\":426}],827:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType;return{t:{valType:\"number\",dflt:0,editType:e},r:{valType:\"number\",dflt:0,editType:e},b:{valType:\"number\",dflt:0,editType:e},l:{valType:\"number\",dflt:0,editType:e},editType:e}}},{}],828:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../registry\"),o=t(\"../plot_api/plot_schema\"),s=t(\"../plot_api/plot_template\"),l=t(\"../lib\"),c=t(\"../components/color\"),u=t(\"../constants/numerical\").BADNUM,h=t(\"./cartesian/axis_ids\"),f=t(\"./animation_attributes\"),p=t(\"./frame_attributes\"),d=l.relinkPrivateKeys,g=l._,v=e.exports={};l.extendFlat(v,a),v.attributes=t(\"./attributes\"),v.attributes.type.values=v.allTypes,v.fontAttrs=t(\"./font_attributes\"),v.layoutAttributes=t(\"./layout_attributes\"),v.fontWeight=\"normal\";var m=v.transformsRegistry,y=t(\"./command\");v.executeAPICommand=y.executeAPICommand,v.computeAPICommandBindings=y.computeAPICommandBindings,v.manageCommandObserver=y.manageCommandObserver,v.hasSimpleAPICommandBindings=y.hasSimpleAPICommandBindings,v.redrawText=function(t){var e=(t=l.getGraphDiv(t))._fullLayout||{};if(!(!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r))return new Promise(function(e){setTimeout(function(){a.getComponentMethod(\"annotations\",\"draw\")(t),a.getComponentMethod(\"legend\",\"draw\")(t),a.getComponentMethod(\"colorbar\",\"draw\")(t),e(v.previousPromises(t))},300)})},v.resize=function(t){return t=l.getGraphDiv(t),new Promise(function(e,r){t&&!l.isHidden(t)||r(new Error(\"Resize must be passed a displayed plot div element.\")),t._redrawTimer&&clearTimeout(t._redrawTimer),t._redrawTimer=setTimeout(function(){if(!t.layout||t.layout.width&&t.layout.height||l.isHidden(t))e(t);else{delete t.layout.width,delete t.layout.height;var r=t.changed;t.autoplay=!0,a.call(\"relayout\",t,{autosize:!0}).then(function(){t.changed=r,e(t)})}},100)})},v.previousPromises=function(t){if((t._promises||[]).length)return Promise.all(t._promises).then(function(){t._promises=[]})},v.addLinks=function(t){if(t._context.showLink||t._context.showSources){var e=t._fullLayout,r=l.ensureSingle(e._paper,\"text\",\"js-plot-link-container\",function(t){t.style({\"font-family\":'\"Open Sans\", Arial, sans-serif',\"font-size\":\"12px\",fill:c.defaultLine,\"pointer-events\":\"all\"}).each(function(){var t=n.select(this);t.append(\"tspan\").classed(\"js-link-to-tool\",!0),t.append(\"tspan\").classed(\"js-link-spacer\",!0),t.append(\"tspan\").classed(\"js-sourcelinks\",!0)})}),i=r.node(),a={y:e._paper.attr(\"height\")-9};document.body.contains(i)&&i.getComputedTextLength()>=e.width-20?(a[\"text-anchor\"]=\"start\",a.x=5):(a[\"text-anchor\"]=\"end\",a.x=e._paper.attr(\"width\")-7),r.attr(a);var o=r.select(\".js-link-to-tool\"),s=r.select(\".js-link-spacer\"),u=r.select(\".js-sourcelinks\");t._context.showSources&&t._context.showSources(t),t._context.showLink&&function(t,e){e.text(\"\");var r=e.append(\"a\").attr({\"xlink:xlink:href\":\"#\",class:\"link--impt link--embedview\",\"font-weight\":\"bold\"}).text(t._context.linkText+\" \"+String.fromCharCode(187));if(t._context.sendData)r.on(\"click\",function(){v.sendDataToCloud(t)});else{var n=window.location.pathname.split(\"/\"),i=window.location.search;r.attr({\"xlink:xlink:show\":\"new\",\"xlink:xlink:href\":\"/\"+n[2].split(\".\")[0]+\"/\"+n[1]+i})}}(t,o),s.text(o.text()&&u.text()?\" - \":\"\")}},v.sendDataToCloud=function(t){t.emit(\"plotly_beforeexport\");var e=(window.PLOTLYENV||{}).BASE_URL||t._context.plotlyServerURL,r=n.select(t).append(\"div\").attr(\"id\",\"hiddenform\").style(\"display\",\"none\"),i=r.append(\"form\").attr({action:e+\"/external\",method:\"post\",target:\"_blank\"});return i.append(\"input\").attr({type:\"text\",name:\"data\"}).node().value=v.graphJson(t,!1,\"keepdata\"),i.node().submit(),r.remove(),t.emit(\"plotly_afterexport\"),!1};var x=[\"days\",\"shortDays\",\"months\",\"shortMonths\",\"periods\",\"dateTime\",\"date\",\"time\",\"decimal\",\"thousands\",\"grouping\",\"currency\"],b=[\"year\",\"month\",\"dayMonth\",\"dayMonthYear\"];function _(t,e){var r=t._context.locale,n=!1,i={};function o(t){for(var r=!0,a=0;a<e.length;a++){var o=e[a];i[o]||(t[o]?i[o]=t[o]:r=!1)}r&&(n=!0)}for(var s=0;s<2;s++){for(var l=t._context.locales,c=0;c<2;c++){var u=(l[r]||{}).format;if(u&&(o(u),n))break;l=a.localeRegistry}var h=r.split(\"-\")[0];if(n||h===r)break;r=h}return n||o(a.localeRegistry.en.format),i}function w(t,e){var r={_fullLayout:e},n=\"x\"===t._id.charAt(0),i=t._mainAxis._anchorAxis,a=\"\",o=\"\",s=\"\";if(i&&(s=i._mainAxis._id,a=n?t._id+s:s+t._id),!a||!e._plots[a]){a=\"\";for(var l=t._counterAxes,c=0;c<l.length;c++){var u=l[c],f=n?t._id+u:u+t._id;o||(o=f);var p=h.getFromId(r,u);if(s&&p.overlaying===s){a=f;break}}}return a||o}function k(t){var e=t.transforms;if(Array.isArray(e)&&e.length)for(var r=0;r<e.length;r++){var n=e[r],i=n._module||m[n.type];if(i&&i.makesData)return!0}return!1}function T(t,e,r,n){for(var i=t.transforms,a=[t],o=0;o<i.length;o++){var s=i[o],l=m[s.type];l&&l.transform&&(a=l.transform(a,{transform:s,fullTrace:t,fullData:e,layout:r,fullLayout:n,transformIndex:o}))}return a}function A(t){var e=t.margin;if(!t._size){var r=t._size={l:Math.round(e.l),r:Math.round(e.r),t:Math.round(e.t),b:Math.round(e.b),p:Math.round(e.pad)};r.w=Math.round(t.width)-r.l-r.r,r.h=Math.round(t.height)-r.t-r.b}t._pushmargin||(t._pushmargin={}),t._pushmarginIds||(t._pushmarginIds={})}v.supplyDefaults=function(t,e){var r=e&&e.skipUpdateCalc,i=t._fullLayout||{};if(i._skipDefaults)delete i._skipDefaults;else{var o,s=t._fullLayout={},c=t.layout||{},u=t._fullData||[],h=t._fullData=[],f=t.data||[],p=t.calcdata||[],m=t._context||{};t._transitionData||v.createTransitionData(t),s._dfltTitle={plot:g(t,\"Click to enter Plot title\"),x:g(t,\"Click to enter X axis title\"),y:g(t,\"Click to enter Y axis title\"),colorbar:g(t,\"Click to enter Colorscale title\"),annotation:g(t,\"new text\")},s._traceWord=g(t,\"trace\");var y=_(t,x);if(s._mapboxAccessToken=m.mapboxAccessToken,i._initialAutoSizeIsDone){var w=i.width,k=i.height;v.supplyLayoutGlobalDefaults(c,s,y),c.width||(s.width=w),c.height||(s.height=k),v.sanitizeMargins(s)}else{v.supplyLayoutGlobalDefaults(c,s,y);var T=!c.width||!c.height,M=s.autosize,S=m.autosizable;T&&(M||S)?v.plotAutoSize(t,c,s):T&&v.sanitizeMargins(s),!M&&T&&(c.width=s.width,c.height=s.height)}s._d3locale=function(t,e){return t.decimal=e.charAt(0),t.thousands=e.charAt(1),n.locale(t)}(y,s.separators),s._extraFormat=_(t,b),s._initialAutoSizeIsDone=!0,s._dataLength=f.length,s._modules=[],s._visibleModules=[],s._basePlotModules=[];var E=s._subplots=function(){var t,e,r=a.collectableSubplotTypes,n={};if(!r){r=[];var i=a.subplotsRegistry;for(var o in i){var s=i[o],c=s.attr;if(c&&(r.push(o),Array.isArray(c)))for(e=0;e<c.length;e++)l.pushUnique(r,c[e])}}for(t=0;t<r.length;t++)n[r[t]]=[];return n}(),C=s._splomAxes={x:{},y:{}},L=s._splomSubplots={};s._splomGridDflt={},s._scatterStackOpts={},s._firstScatter={},s._alignmentOpts={},s._colorAxes={},s._requestRangeslider={},s._traceUids=function(t,e){var r,n,i=e.length,a=[];for(r=0;r<t.length;r++){var o=t[r]._fullInput;o!==n&&a.push(o),n=o}var s=a.length,c=new Array(i),u={};function h(t,e){c[e]=t,u[t]=1}function f(t,e){if(t&&\"string\"==typeof t&&!u[t])return h(t,e),!0}for(r=0;r<i;r++){var p=e[r].uid;\"number\"==typeof p&&(p=String(p)),f(p,r)||(r<s&&f(a[r].uid,r)||h(l.randstr(u),r))}return c}(u,f),s._globalTransforms=(t._context||{}).globalTransforms,v.supplyDataDefaults(f,h,c,s);var P=Object.keys(C.x),O=Object.keys(C.y);if(P.length>1&&O.length>1){for(a.getComponentMethod(\"grid\",\"sizeDefaults\")(c,s),o=0;o<P.length;o++)l.pushUnique(E.xaxis,P[o]);for(o=0;o<O.length;o++)l.pushUnique(E.yaxis,O[o]);for(var z in L)l.pushUnique(E.cartesian,z)}if(s._has=v._hasPlotType.bind(s),u.length===h.length)for(o=0;o<h.length;o++)d(h[o],u[o]);v.supplyLayoutModuleDefaults(c,s,h,t._transitionData);var I=s._visibleModules,D=[];for(o=0;o<I.length;o++){var R=I[o].crossTraceDefaults;R&&l.pushUnique(D,R)}for(o=0;o<D.length;o++)D[o](h,s);s._hasOnlyLargeSploms=1===s._basePlotModules.length&&\"splom\"===s._basePlotModules[0].name&&P.length>15&&O.length>15&&0===s.shapes.length&&0===s.images.length,s._hasCartesian=s._has(\"cartesian\"),s._hasGeo=s._has(\"geo\"),s._hasGL3D=s._has(\"gl3d\"),s._hasGL2D=s._has(\"gl2d\"),s._hasTernary=s._has(\"ternary\"),s._hasPie=s._has(\"pie\"),v.linkSubplots(h,s,u,i),v.cleanPlot(h,s,u,i),i._zoomlayer&&!t._dragging&&i._zoomlayer.selectAll(\".select-outline\").remove(),function(t,e){var r,n=[];e.meta&&(r=e._meta={meta:e.meta,layout:{meta:e.meta}});for(var i=0;i<t.length;i++){var a=t[i];a.meta?n[a.index]=a._meta={meta:a.meta}:e.meta&&(a._meta={meta:e.meta}),e.meta&&(a._meta.layout={meta:e.meta})}n.length&&(r||(r=e._meta={}),r.data=n)}(h,s),d(s,i),a.getComponentMethod(\"colorscale\",\"crossTraceDefaults\")(h,s),s._preGUI||(s._preGUI={}),s._tracePreGUI||(s._tracePreGUI={});var F,B=s._tracePreGUI,N={};for(F in B)N[F]=\"old\";for(o=0;o<h.length;o++)N[F=h[o]._fullInput.uid]||(B[F]={}),N[F]=\"new\";for(F in N)\"old\"===N[F]&&delete B[F];A(s),a.getComponentMethod(\"rangeslider\",\"makeData\")(s),r||p.length!==h.length||v.supplyDefaultsUpdateCalc(p,h)}},v.supplyDefaultsUpdateCalc=function(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=(t[r]||[])[0];if(i&&i.trace){var a=i.trace;if(a._hasCalcTransform){var o,s,c,u=a._arrayAttrs;for(o=0;o<u.length;o++)s=u[o],c=l.nestedProperty(a,s).get().slice(),l.nestedProperty(n,s).set(c)}i.trace=n}}},v.createTransitionData=function(t){t._transitionData||(t._transitionData={}),t._transitionData._frames||(t._transitionData._frames=[]),t._transitionData._frameHash||(t._transitionData._frameHash={}),t._transitionData._counter||(t._transitionData._counter=0),t._transitionData._interruptCallbacks||(t._transitionData._interruptCallbacks=[])},v._hasPlotType=function(t){var e,r=this._basePlotModules||[];for(e=0;e<r.length;e++)if(r[e].name===t)return!0;var n=this._modules||[];for(e=0;e<n.length;e++){var i=n[e].name;if(i===t)return!0;var o=a.modules[i];if(o&&o.categories[t])return!0}return!1},v.cleanPlot=function(t,e,r,n){var i,a,o=n._basePlotModules||[];for(i=0;i<o.length;i++){var s=o[i];s.clean&&s.clean(t,e,r,n)}var l=n._has&&n._has(\"gl\"),c=e._has&&e._has(\"gl\");l&&!c&&void 0!==n._glcontainer&&(n._glcontainer.selectAll(\".gl-canvas\").remove(),n._glcontainer.selectAll(\".no-webgl\").remove(),n._glcanvas=null);var u=!!n._infolayer;t:for(i=0;i<r.length;i++){var h=r[i].uid;for(a=0;a<t.length;a++){if(h===t[a].uid)continue t}u&&n._infolayer.select(\".cb\"+h).remove()}},v.linkSubplots=function(t,e,r,n){var i,a,o=n._plots||{},s=e._plots={},c=e._subplots,u={_fullData:t,_fullLayout:e},f=c.cartesian.concat(c.gl2d||[]);for(i=0;i<f.length;i++){var p,d=f[i],g=o[d],v=h.getFromId(u,d,\"x\"),m=h.getFromId(u,d,\"y\");for(g?p=s[d]=g:(p=s[d]={}).id=d,v._counterAxes.push(m._id),m._counterAxes.push(v._id),v._subplotsWith.push(d),m._subplotsWith.push(d),p.xaxis=v,p.yaxis=m,p._hasClipOnAxisFalse=!1,a=0;a<t.length;a++){var y=t[a];if(y.xaxis===p.xaxis._id&&y.yaxis===p.yaxis._id&&!1===y.cliponaxis){p._hasClipOnAxisFalse=!0;break}}}var x,b=h.list(u,null,!0);for(i=0;i<b.length;i++){var _=null;(x=b[i]).overlaying&&(_=h.getFromId(u,x.overlaying))&&_.overlaying&&(x.overlaying=!1,_=null),x._mainAxis=_||x,_&&(x.domain=_.domain.slice()),x._anchorAxis=\"free\"===x.anchor?null:h.getFromId(u,x.anchor)}for(i=0;i<b.length;i++)(x=b[i])._counterAxes.sort(h.idSort),x._subplotsWith.sort(l.subplotSort),x._mainSubplot=w(x,e)},v.clearExpandedTraceDefaultColors=function(t){var e,r,n;for(r=[],(e=t._module._colorAttrs)||(t._module._colorAttrs=e=[],o.crawl(t._module.attributes,function(t,n,i,a){r[a]=n,r.length=a+1,\"color\"===t.valType&&void 0===t.dflt&&e.push(r.join(\".\"))})),n=0;n<e.length;n++){l.nestedProperty(t,\"_input.\"+e[n]).get()||l.nestedProperty(t,e[n]).set(null)}},v.supplyDataDefaults=function(t,e,r,n){var i,o,c,u=n._modules,h=n._visibleModules,f=n._basePlotModules,p=0,g=0;function m(t){e.push(t);var r=t._module;r&&(l.pushUnique(u,r),!0===t.visible&&l.pushUnique(h,r),l.pushUnique(f,t._module.basePlotModule),p++,!1!==t._input.visible&&g++)}n._transformModules=[];var y={},x=[],b=(r.template||{}).data||{},_=s.traceTemplater(b);for(i=0;i<t.length;i++){if(c=t[i],(o=_.newTrace(c)).uid=n._traceUids[i],v.supplyTraceDefaults(c,o,g,n,i),o.index=i,o._input=c,o._expandedIndex=p,o.transforms&&o.transforms.length)for(var w=!1!==c.visible&&!1===o.visible,k=T(o,e,r,n),A=0;A<k.length;A++){var M=k[A],S={_template:o._template,type:o.type,uid:o.uid+A};w&&!1===M.visible&&delete M.visible,v.supplyTraceDefaults(M,S,p,n,i),d(S,M),S.index=i,S._input=c,S._fullInput=o,S._expandedIndex=p,S._expandedInput=M,m(S)}else o._fullInput=o,o._expandedInput=o,m(o);a.traceIs(o,\"carpetAxis\")&&(y[o.carpet]=o),a.traceIs(o,\"carpetDependent\")&&x.push(i)}for(i=0;i<x.length;i++)if((o=e[x[i]]).visible){var E=y[o.carpet];o._carpet=E,E&&E.visible?(o.xaxis=E.xaxis,o.yaxis=E.yaxis):o.visible=!1}},v.supplyAnimationDefaults=function(t){var e;t=t||{};var r={};function n(e,n){return l.coerce(t||{},r,f,e,n)}if(n(\"mode\"),n(\"direction\"),n(\"fromcurrent\"),Array.isArray(t.frame))for(r.frame=[],e=0;e<t.frame.length;e++)r.frame[e]=v.supplyAnimationFrameDefaults(t.frame[e]||{});else r.frame=v.supplyAnimationFrameDefaults(t.frame||{});if(Array.isArray(t.transition))for(r.transition=[],e=0;e<t.transition.length;e++)r.transition[e]=v.supplyAnimationTransitionDefaults(t.transition[e]||{});else r.transition=v.supplyAnimationTransitionDefaults(t.transition||{});return r},v.supplyAnimationFrameDefaults=function(t){var e={};function r(r,n){return l.coerce(t||{},e,f.frame,r,n)}return r(\"duration\"),r(\"redraw\"),e},v.supplyAnimationTransitionDefaults=function(t){var e={};function r(r,n){return l.coerce(t||{},e,f.transition,r,n)}return r(\"duration\"),r(\"easing\"),e},v.supplyFrameDefaults=function(t){var e={};function r(r,n){return l.coerce(t,e,p,r,n)}return r(\"group\"),r(\"name\"),r(\"traces\"),r(\"baseframe\"),r(\"data\"),r(\"layout\"),e},v.supplyTraceDefaults=function(t,e,r,n,i){var o,s=n.colorway||c.defaults,u=s[r%s.length];function h(r,n){return l.coerce(t,e,v.attributes,r,n)}var f=h(\"visible\");h(\"type\"),h(\"name\",n._traceWord+\" \"+i),h(\"uirevision\",n.uirevision);var p=v.getModule(e);if(e._module=p,p){var d=p.basePlotModule,g=d.attr,m=d.attributes;if(g&&m){var y=n._subplots,x=\"\";if(\"gl2d\"!==d.name||f){if(Array.isArray(g))for(o=0;o<g.length;o++){var b=g[o],_=l.coerce(t,e,m,b);y[b]&&l.pushUnique(y[b],_),x+=_}else x=l.coerce(t,e,m,g);y[d.name]&&l.pushUnique(y[d.name],x)}}}return f&&(h(\"customdata\"),h(\"ids\"),h(\"meta\"),a.traceIs(e,\"showLegend\")?(e._dfltShowLegend=!0,h(\"showlegend\"),h(\"legendgroup\")):e._dfltShowLegend=!1,p&&p.supplyDefaults(t,e,u,n),a.traceIs(e,\"noOpacity\")||h(\"opacity\"),a.traceIs(e,\"notLegendIsolatable\")&&(e.visible=!!e.visible),a.traceIs(e,\"noHover\")||(e.hovertemplate||l.coerceHoverinfo(t,e,n),\"parcats\"!==e.type&&a.getComponentMethod(\"fx\",\"supplyDefaults\")(t,e,u,n)),p&&p.selectPoints&&h(\"selectedpoints\"),v.supplyTransformDefaults(t,e,n)),e},v.hasMakesDataTransform=k,v.supplyTransformDefaults=function(t,e,r){if(e._length||k(t)){var n=r._globalTransforms||[],i=r._transformModules||[];if(Array.isArray(t.transforms)||0!==n.length)for(var a=t.transforms||[],o=n.concat(a),s=e.transforms=[],c=0;c<o.length;c++){var u,h=o[c],f=h.type,p=m[f],d=!(h._module&&h._module===p),g=p&&\"function\"==typeof p.transform;p||l.warn(\"Unrecognized transform type \"+f+\".\"),p&&p.supplyDefaults&&(d||g)?((u=p.supplyDefaults(h,e,r,t)).type=f,u._module=p,l.pushUnique(i,p)):u=l.extendFlat({},h),s.push(u)}}},v.supplyLayoutGlobalDefaults=function(t,e,r){function n(r,n){return l.coerce(t,e,v.layoutAttributes,r,n)}var i=t.template;l.isPlainObject(i)&&(e.template=i,e._template=i.layout,e._dataTemplate=i.data);var o=l.coerceFont(n,\"font\");n(\"title.text\",e._dfltTitle.plot),l.coerceFont(n,\"title.font\",{family:o.family,size:Math.round(1.4*o.size),color:o.color}),n(\"title.xref\"),n(\"title.yref\"),n(\"title.x\"),n(\"title.y\"),n(\"title.xanchor\"),n(\"title.yanchor\"),n(\"title.pad.t\"),n(\"title.pad.r\"),n(\"title.pad.b\"),n(\"title.pad.l\"),n(\"autosize\",!(t.width&&t.height)),n(\"width\"),n(\"height\"),n(\"margin.l\"),n(\"margin.r\"),n(\"margin.t\"),n(\"margin.b\"),n(\"margin.pad\"),n(\"margin.autoexpand\"),t.width&&t.height&&v.sanitizeMargins(e),a.getComponentMethod(\"grid\",\"sizeDefaults\")(t,e),n(\"paper_bgcolor\"),n(\"separators\",r.decimal+r.thousands),n(\"hidesources\"),n(\"colorway\"),n(\"datarevision\");var s=n(\"uirevision\");n(\"editrevision\",s),n(\"selectionrevision\",s),n(\"modebar.orientation\"),n(\"modebar.bgcolor\",c.addOpacity(e.paper_bgcolor,.5));var u=c.contrast(c.rgb(e.modebar.bgcolor));n(\"modebar.color\",c.addOpacity(u,.3)),n(\"modebar.activecolor\",c.addOpacity(u,.7)),n(\"modebar.uirevision\",s),n(\"meta\"),l.isPlainObject(t.transition)&&(n(\"transition.duration\"),n(\"transition.easing\"),n(\"transition.ordering\")),a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\"),a.getComponentMethod(\"fx\",\"supplyLayoutGlobalDefaults\")(t,e,n)},v.plotAutoSize=function(t,e,r){var n,a,o=t._context||{},s=o.frameMargins,c=l.isPlotDiv(t);if(c&&t.emit(\"plotly_autosize\"),o.fillFrame)n=window.innerWidth,a=window.innerHeight,document.body.style.overflow=\"hidden\";else{var u=c?window.getComputedStyle(t):{};if(n=parseFloat(u.width)||parseFloat(u.maxWidth)||r.width,a=parseFloat(u.height)||parseFloat(u.maxHeight)||r.height,i(s)&&s>0){var h=1-2*s;n=Math.round(h*n),a=Math.round(h*a)}}var f=v.layoutAttributes.width.min,p=v.layoutAttributes.height.min;n<f&&(n=f),a<p&&(a=p);var d=!e.width&&Math.abs(r.width-n)>1,g=!e.height&&Math.abs(r.height-a)>1;(g||d)&&(d&&(r.width=n),g&&(r.height=a)),t._initialAutoSize||(t._initialAutoSize={width:n,height:a}),v.sanitizeMargins(r)},v.supplyLayoutModuleDefaults=function(t,e,r,n){var i,o,s,c=a.componentsRegistry,u=e._basePlotModules,h=a.subplotsRegistry.cartesian;for(i in c)(s=c[i]).includeBasePlot&&s.includeBasePlot(t,e);for(var f in u.length||u.push(h),e._has(\"cartesian\")&&(a.getComponentMethod(\"grid\",\"contentDefaults\")(t,e),h.finalizeSubplots(t,e)),e._subplots)e._subplots[f].sort(l.subplotSort);for(o=0;o<u.length;o++)(s=u[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var p=e._modules;for(o=0;o<p.length;o++)(s=p[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var d=e._transformModules;for(o=0;o<d.length;o++)(s=d[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r,n);for(i in c)(s=c[i]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r)},v.purge=function(t){var e=t._fullLayout||{};void 0!==e._glcontainer&&(e._glcontainer.selectAll(\".gl-canvas\").remove(),e._glcontainer.remove(),e._glcanvas=null),void 0!==e._geocontainer&&e._geocontainer.remove(),e._modeBar&&e._modeBar.destroy(),t._transitionData&&(t._transitionData._interruptCallbacks&&(t._transitionData._interruptCallbacks.length=0),t._transitionData._animationRaf&&window.cancelAnimationFrame(t._transitionData._animationRaf)),l.clearThrottle(),l.clearResponsive(t),delete t.data,delete t.layout,delete t._fullData,delete t._fullLayout,delete t.calcdata,delete t.framework,delete t.empty,delete t.fid,delete t.undoqueue,delete t.undonum,delete t.autoplay,delete t.changed,delete t._promises,delete t._redrawTimer,delete t._hmlumcount,delete t._hmpixcount,delete t._transitionData,delete t._transitioning,delete t._initialAutoSize,delete t._transitioningWithDuration,delete t._dragging,delete t._dragged,delete t._dragdata,delete t._hoverdata,delete t._snapshotInProgress,delete t._editing,delete t._mouseDownTime,delete t._legendMouseDownTime,t.removeAllListeners&&t.removeAllListeners()},v.style=function(t){var e,r=t._fullLayout._visibleModules,n=[];for(e=0;e<r.length;e++){var i=r[e];i.style&&l.pushUnique(n,i.style)}for(e=0;e<n.length;e++)n[e](t)},v.sanitizeMargins=function(t){if(t&&t.margin){var e,r=t.width,n=t.height,i=t.margin,a=r-(i.l+i.r),o=n-(i.t+i.b);a<0&&(e=(r-1)/(i.l+i.r),i.l=Math.floor(e*i.l),i.r=Math.floor(e*i.r)),o<0&&(e=(n-1)/(i.t+i.b),i.t=Math.floor(e*i.t),i.b=Math.floor(e*i.b))}},v.clearAutoMarginIds=function(t){t._fullLayout._pushmarginIds={}},v.allowAutoMargin=function(t,e){t._fullLayout._pushmarginIds[e]=1},v.autoMargin=function(t,e,r){var n=t._fullLayout,i=n._pushmargin,a=n._pushmarginIds;if(!1!==n.margin.autoexpand){if(r){var o=r.pad;if(void 0===o){var s=n.margin;o=Math.min(12,s.l,s.r,s.t,s.b)}r.l+r.r>.5*n.width&&(r.l=r.r=0),r.b+r.t>.5*n.height&&(r.b=r.t=0);var l=void 0!==r.xl?r.xl:r.x,c=void 0!==r.xr?r.xr:r.x,u=void 0!==r.yt?r.yt:r.y,h=void 0!==r.yb?r.yb:r.y;i[e]={l:{val:l,size:r.l+o},r:{val:c,size:r.r+o},b:{val:h,size:r.b+o},t:{val:u,size:r.t+o}},a[e]=1}else delete i[e],delete a[e];n._replotting||v.doAutoMargin(t)}},v.doAutoMargin=function(t){var e=t._fullLayout;e._size||(e._size={}),A(e);var r=e._size,n=e.margin,o=l.extendFlat({},r),s=n.l,c=n.r,u=n.t,h=n.b,f=e.width,p=e.height,d=e._pushmargin,g=e._pushmarginIds;if(!1!==e.margin.autoexpand){for(var m in d)g[m]||delete d[m];for(var y in d.base={l:{val:0,size:s},r:{val:1,size:c},t:{val:1,size:u},b:{val:0,size:h}},d){var x=d[y].l||{},b=d[y].b||{},_=x.val,w=x.size,k=b.val,T=b.size;for(var M in d){if(i(w)&&d[M].r){var S=d[M].r.val,E=d[M].r.size;if(S>_){var C=(w*S+(E-f)*_)/(S-_),L=(E*(1-_)+(w-f)*(1-S))/(S-_);C>=0&&L>=0&&f-(C+L)>0&&C+L>s+c&&(s=C,c=L)}}if(i(T)&&d[M].t){var P=d[M].t.val,O=d[M].t.size;if(P>k){var z=(T*P+(O-p)*k)/(P-k),I=(O*(1-k)+(T-p)*(1-P))/(P-k);z>=0&&I>=0&&p-(I+z)>0&&z+I>h+u&&(h=z,u=I)}}}}}if(r.l=Math.round(s),r.r=Math.round(c),r.t=Math.round(u),r.b=Math.round(h),r.p=Math.round(n.pad),r.w=Math.round(f)-r.l-r.r,r.h=Math.round(p)-r.t-r.b,!e._replotting&&v.didMarginChange(o,r))return\"_redrawFromAutoMarginCount\"in e?e._redrawFromAutoMarginCount++:e._redrawFromAutoMarginCount=1,a.call(\"plot\",t)};var M=[\"l\",\"r\",\"t\",\"b\",\"p\",\"w\",\"h\"];function S(t,e,r){var n=!1;var i=[v.previousPromises,function(){if(t._transitionData)return t._transitioning=!1,function(t){var e=Promise.resolve();if(!t)return e;for(;t.length;)e=e.then(t.shift());return e}(t._transitionData._interruptCallbacks)},r.prepareFn,v.rehover,function(){return t.emit(\"plotly_transitioning\",[]),new Promise(function(i){t._transitioning=!0,e.duration>0&&(t._transitioningWithDuration=!0),t._transitionData._interruptCallbacks.push(function(){n=!0}),r.redraw&&t._transitionData._interruptCallbacks.push(function(){return a.call(\"redraw\",t)}),t._transitionData._interruptCallbacks.push(function(){t.emit(\"plotly_transitioninterrupted\",[])});var o=0,s=0;function l(){return o++,function(){var e;s++,n||s!==o||(e=i,t._transitionData&&(function(t){if(t)for(;t.length;)t.shift()}(t._transitionData._interruptCallbacks),Promise.resolve().then(function(){if(r.redraw)return a.call(\"redraw\",t)}).then(function(){t._transitioning=!1,t._transitioningWithDuration=!1,t.emit(\"plotly_transitioned\",[])}).then(e)))}}r.runFn(l),setTimeout(l())})}],o=l.syncOrAsync(i,t);return o&&o.then||(o=Promise.resolve()),o.then(function(){return t})}v.didMarginChange=function(t,e){for(var r=0;r<M.length;r++){var n=M[r],a=t[n],o=e[n];if(!i(a)||Math.abs(o-a)>1)return!0}return!1},v.graphJson=function(t,e,r,n,i){(i&&e&&!t._fullData||i&&!e&&!t._fullLayout)&&v.supplyDefaults(t);var a=i?t._fullData:t.data,o=i?t._fullLayout:t.layout,s=(t._transitionData||{})._frames;function c(t){if(\"function\"==typeof t)return null;if(l.isPlainObject(t)){var e,n,i={};for(e in t)if(\"function\"!=typeof t[e]&&-1===[\"_\",\"[\"].indexOf(e.charAt(0))){if(\"keepdata\"===r){if(\"src\"===e.substr(e.length-3))continue}else if(\"keepstream\"===r){if(\"string\"==typeof(n=t[e+\"src\"])&&n.indexOf(\":\")>0&&!l.isPlainObject(t.stream))continue}else if(\"keepall\"!==r&&\"string\"==typeof(n=t[e+\"src\"])&&n.indexOf(\":\")>0)continue;i[e]=c(t[e])}return i}return Array.isArray(t)?t.map(c):l.isTypedArray(t)?l.simpleMap(t,l.identity):l.isJSDate(t)?l.ms2DateTimeLocal(+t):t}var u={data:(a||[]).map(function(t){var r=c(t);return e&&delete r.fit,r})};return e||(u.layout=c(o)),t.framework&&t.framework.isPolar&&(u=t.framework.getConfig()),s&&(u.frames=c(s)),\"object\"===n?u:JSON.stringify(u)},v.modifyFrames=function(t,e){var r,n,i,a=t._transitionData._frames,o=t._transitionData._frameHash;for(r=0;r<e.length;r++)switch((n=e[r]).type){case\"replace\":i=n.value;var s=(a[n.index]||{}).name,l=i.name;a[n.index]=o[l]=i,l!==s&&(delete o[s],o[l]=i);break;case\"insert\":o[(i=n.value).name]=i,a.splice(n.index,0,i);break;case\"delete\":delete o[(i=a[n.index]).name],a.splice(n.index,1)}return Promise.resolve()},v.computeFrame=function(t,e){var r,n,i,a,o=t._transitionData._frameHash;if(!e)throw new Error(\"computeFrame must be given a string frame name\");var s=o[e.toString()];if(!s)return!1;for(var l=[s],c=[s.name];s.baseframe&&(s=o[s.baseframe.toString()])&&-1===c.indexOf(s.name);)l.push(s),c.push(s.name);for(var u={};s=l.pop();)if(s.layout&&(u.layout=v.extendLayout(u.layout,s.layout)),s.data){if(u.data||(u.data=[]),!(n=s.traces))for(n=[],r=0;r<s.data.length;r++)n[r]=r;for(u.traces||(u.traces=[]),r=0;r<s.data.length;r++)null!=(i=n[r])&&(-1===(a=u.traces.indexOf(i))&&(a=u.data.length,u.traces[a]=i),u.data[a]=v.extendTrace(u.data[a],s.data[r]))}return u},v.recomputeFrameHash=function(t){for(var e=t._transitionData._frameHash={},r=t._transitionData._frames,n=0;n<r.length;n++){var i=r[n];i&&i.name&&(e[i.name]=i)}},v.extendObjectWithContainers=function(t,e,r){var n,i,a,o,s,c,u,h=l.extendDeepNoArrays({},e||{}),f=l.expandObjectPaths(h),p={};if(r&&r.length)for(a=0;a<r.length;a++)void 0===(i=(n=l.nestedProperty(f,r[a])).get())?l.nestedProperty(p,r[a]).set(null):(n.set(null),l.nestedProperty(p,r[a]).set(i));if(t=l.extendDeepNoArrays(t||{},f),r&&r.length)for(a=0;a<r.length;a++)if(c=l.nestedProperty(p,r[a]).get()){for(u=(s=l.nestedProperty(t,r[a])).get(),Array.isArray(u)||(u=[],s.set(u)),o=0;o<c.length;o++){var d=c[o];u[o]=null===d?null:v.extendObjectWithContainers(u[o],d)}s.set(u)}return t},v.dataArrayContainers=[\"transforms\",\"dimensions\"],v.layoutArrayContainers=a.layoutArrayContainers,v.extendTrace=function(t,e){return v.extendObjectWithContainers(t,e,v.dataArrayContainers)},v.extendLayout=function(t,e){return v.extendObjectWithContainers(t,e,v.layoutArrayContainers)},v.transition=function(t,e,r,n,i,a){var o={redraw:i.redraw},s={},c=[];return o.prepareFn=function(){for(var i=Array.isArray(e)?e.length:0,a=n.slice(0,i),o=0;o<a.length;o++){var u=a[o],h=t._fullData[u]._module;if(h){if(h.animatable){var f=h.basePlotModule.name;s[f]||(s[f]=[]),s[f].push(u)}t.data[a[o]]=v.extendTrace(t.data[a[o]],e[o])}}var p=l.expandObjectPaths(l.extendDeepNoArrays({},r)),d=/^[xy]axis[0-9]*$/;for(var g in p)d.test(g)&&delete p[g].range;v.extendLayout(t.layout,p),delete t.calcdata,v.supplyDefaults(t),v.doCalcdata(t);var m=l.expandObjectPaths(r);if(m){var y=t._fullLayout._plots;for(var x in y){var b,_,w,k,T=y[x],A=T.xaxis,M=T.yaxis,S=A.range.slice(),E=M.range.slice();Array.isArray(m[A._name+\".range\"])?b=m[A._name+\".range\"].slice():Array.isArray((m[A._name]||{}).range)&&(b=m[A._name].range.slice()),Array.isArray(m[M._name+\".range\"])?_=m[M._name+\".range\"].slice():Array.isArray((m[M._name]||{}).range)&&(_=m[M._name].range.slice()),S&&b&&(S[0]!==b[0]||S[1]!==b[1])&&(w={xr0:S,xr1:b}),E&&_&&(E[0]!==_[0]||E[1]!==_[1])&&(k={yr0:E,yr1:_}),(w||k)&&c.push(l.extendFlat({plotinfo:T},w,k))}}return Promise.resolve()},o.runFn=function(e){var n,i,o=t._fullLayout._basePlotModules,u=c.length;if(r)for(i=0;i<o.length;i++)o[i].transitionAxes&&o[i].transitionAxes(t,c,a,e);for(var h in u?((n=l.extendFlat({},a)).duration=0,delete s.cartesian):n=a,s){var f=s[h];t._fullData[f[0]]._module.basePlotModule.plot(t,f,n,e)}},S(t,a,o)},v.transitionFromReact=function(t,e,r,n){var i=t._fullLayout,a=i.transition,o={},s=[];return o.prepareFn=function(){var t=i._plots;for(var a in o.redraw=!1,\"some\"===e.anim&&(o.redraw=!0),\"some\"===r.anim&&(o.redraw=!0),t){var c,u,h=t[a],f=h.xaxis,p=h.yaxis,d=n[f._name].range.slice(),g=n[p._name].range.slice(),v=f.range.slice(),m=p.range.slice();f.setScale(),p.setScale(),d[0]===v[0]&&d[1]===v[1]||(c={xr0:d,xr1:v}),g[0]===m[0]&&g[1]===m[1]||(u={yr0:g,yr1:m}),(c||u)&&s.push(l.extendFlat({plotinfo:h},c,u))}return Promise.resolve()},o.runFn=function(r){for(var n,i,o,c=t._fullData,u=t._fullLayout._basePlotModules,h=[],f=0;f<c.length;f++)h.push(f);function p(){for(var e=0;e<u.length;e++)u[e].transitionAxes&&u[e].transitionAxes(t,s,n,r)}function d(){for(var e=0;e<u.length;e++)u[e].plot(t,o,i,r)}s.length&&e.anim?\"traces first\"===a.ordering?(n=l.extendFlat({},a,{duration:0}),o=h,i=a,d(),setTimeout(p,a.duration)):(n=a,o=null,i=l.extendFlat({},a,{duration:0}),p(),d()):s.length?(n=a,p()):e.anim&&(o=h,i=a,d())},S(t,a,o)},v.doCalcdata=function(t,e){var r,n,i,s,c=h.list(t),f=t._fullData,p=t._fullLayout,d=new Array(f.length),g=(t.calcdata||[]).slice();for(t.calcdata=d,p._numBoxes=0,p._numViolins=0,p._violinScaleGroupStats={},t._hmpixcount=0,t._hmlumcount=0,p._piecolormap={},p._sunburstcolormap={},p._funnelareacolormap={},i=0;i<f.length;i++)Array.isArray(e)&&-1===e.indexOf(i)&&(d[i]=g[i]);for(i=0;i<f.length;i++)(r=f[i])._arrayAttrs=o.findArrayAttributes(r),r._extremes={};var v=p._subplots.polar||[];for(i=0;i<v.length;i++)c.push(p[v[i]].radialaxis,p[v[i]].angularaxis);var y=!1;function x(e){if(r=f[e],n=r._module,!0===r.visible&&r.transforms){if(n&&n.calc){var i=n.calc(t,r);i[0]&&i[0].t&&i[0].t._scene&&delete i[0].t._scene.dirty}for(s=0;s<r.transforms.length;s++){var a=r.transforms[s];(n=m[a.type])&&n.calcTransform&&(r._hasCalcTransform=!0,y=!0,n.calcTransform(t,r,a))}}}function b(e,i){if(r=f[e],!!(n=r._module).isContainer===i){var a=[];if(!0===r.visible&&0!==r._length){delete r._indexToPoints;var o=r.transforms||[];for(s=o.length-1;s>=0;s--)if(o[s].enabled){r._indexToPoints=o[s]._indexToPoints;break}n&&n.calc&&(a=n.calc(t,r))}Array.isArray(a)&&a[0]||(a=[{x:u,y:u}]),a[0].t||(a[0].t={}),a[0].trace=r,d[e]=a}}for(C(c,f),i=0;i<f.length;i++)b(i,!0);for(i=0;i<f.length;i++)x(i);for(y&&C(c,f),i=0;i<f.length;i++)b(i,!0);for(i=0;i<f.length;i++)b(i,!1);L(t);var _=function(t,e){var r,n,i,o,s,c=[];function u(t,r,n){var i=r._id.charAt(0);if(\"histogram2dcontour\"===t){var a=r._counterAxes[0],o=h.getFromId(e,a),s=\"x\"===i||\"x\"===a&&\"category\"===o.type,l=\"y\"===i||\"y\"===a&&\"category\"===o.type;return function(t,e){return 0===t||0===e?-1:s&&t===n[e].length-1?-1:l&&e===n.length-1?-1:(\"y\"===i?e:t)-1}}return function(t,e){return\"y\"===i?e:t}}var f={min:function(t){return l.aggNums(Math.min,null,t)},max:function(t){return l.aggNums(Math.max,null,t)},sum:function(t){return l.aggNums(function(t,e){return t+e},null,t)},total:function(t){return l.aggNums(function(t,e){return t+e},null,t)},mean:function(t){return l.mean(t)},median:function(t){return l.median(t)}};for(r=0;r<t.length;r++){var p=t[r];if(\"category\"===p.type){var d=p.categoryorder.match(E);if(d){var g=d[1],v=d[2],m=[];for(n=0;n<p._categories.length;n++)m.push([p._categories[n],[]]);for(n=0;n<p._traceIndices.length;n++){var y=p._traceIndices[n],x=e._fullData[y],b=p._id.charAt(0);if(!0===x.visible){var _=x.type;a.traceIs(x,\"histogram\")&&(delete x._xautoBinFinished,delete x._yautoBinFinished);var w=e.calcdata[y];for(i=0;i<w.length;i++){var k,T,A,M=w[i];if(\"splom\"===_){var S=x._axesDim[p._id];if(\"y\"===b){var C=x._diag[S][0];C&&(p=e._fullLayout[h.id2name(C)])}var L=M.trace.dimensions[S].values;for(o=0;o<L.length;o++)for(k=L[o],T=p._categoriesMap[k],s=0;s<M.trace.dimensions.length;s++)if(s!==S){var P=M.trace.dimensions[s];m[T][1].push(P.values[o])}}else if(\"scattergl\"===_){for(o=0;o<M.t.x.length;o++)\"x\"===b&&(k=M.t.x[o],T=k,A=M.t.y[o]),\"y\"===b&&(k=M.t.y[o],T=k,A=M.t.x[o]),m[T][1].push(A);M.t&&M.t._scene&&delete M.t._scene.dirty}else if(M.hasOwnProperty(\"z\")){A=M.z;var O=u(x.type,p,A);for(o=0;o<A.length;o++)for(s=0;s<A[o].length;s++)(T=O(s,o))+1&&m[T][1].push(A[o][s])}else for(\"x\"===b?(k=M.p+1?M.p:M.x,A=M.s||M.v||M.y):\"y\"===b&&(k=M.p+1?M.p:M.y,A=M.s||M.v||M.x),Array.isArray(A)||(A=[A]),o=0;o<A.length;o++)m[k][1].push(A[o])}}}p._categoriesValue=m;var z=[];for(n=0;n<m.length;n++)z.push([m[n][0],f[g](m[n][1])]);z.sort(function(t,e){return t[1]-e[1]}),p._categoriesAggregatedValue=z,p._initialCategories=z.map(function(t){return t[0]}),\"descending\"===v&&p._initialCategories.reverse(),c=c.concat(p.sortByInitialCategories())}}}return c}(c,t);if(_.length){for(p._numBoxes=0,p._numViolins=0,i=0;i<_.length;i++)b(_[i],!0);for(i=0;i<_.length;i++)b(_[i],!1);L(t)}a.getComponentMethod(\"fx\",\"calc\")(t),a.getComponentMethod(\"errorbars\",\"calc\")(t)};var E=/(total|sum|min|max|mean|median) (ascending|descending)/;function C(t,e){for(var r=0;r<t.length;r++){var n=t[r];n.clearCalc(),\"multicategory\"===n.type&&n.setupMultiCategory(e)}}function L(t){var e,r,n,i=t._fullLayout,a=i._visibleModules,o={};for(r=0;r<a.length;r++){var s=a[r],c=s.crossTraceCalc;if(c){var u=s.basePlotModule.name;o[u]?l.pushUnique(o[u],c):o[u]=[c]}}for(n in o){var h=o[n],f=i._subplots[n];if(Array.isArray(f))for(e=0;e<f.length;e++){var p=f[e],d=\"cartesian\"===n?i._plots[p]:i[p];for(r=0;r<h.length;r++)h[r](t,d,p)}else for(r=0;r<h.length;r++)h[r](t)}}v.rehover=function(t){t._fullLayout._rehover&&t._fullLayout._rehover()},v.redrag=function(t){t._fullLayout._redrag&&t._fullLayout._redrag()},v.generalUpdatePerTraceModule=function(t,e,r,n){var i,a=e.traceHash,o={};for(i=0;i<r.length;i++){var s=r[i],c=s[0].trace;c.visible&&(o[c.type]=o[c.type]||[],o[c.type].push(s))}for(var u in a)if(!o[u]){var h=a[u][0];h[0].trace.visible=!1,o[u]=[h]}for(var f in o){var p=o[f];p[0][0].trace._module.plot(t,e,l.filterVisible(p),n)}e.traceHash=o}},{\"../components/color\":593,\"../constants/numerical\":695,\"../lib\":719,\"../plot_api/plot_schema\":756,\"../plot_api/plot_template\":757,\"../registry\":847,\"./animation_attributes\":762,\"./attributes\":764,\"./cartesian/axis_ids\":770,\"./command\":791,\"./font_attributes\":793,\"./frame_attributes\":794,\"./layout_attributes\":819,d3:163,\"fast-isnumeric\":225}],829:[function(t,e,r){\"use strict\";e.exports={attr:\"subplot\",name:\"polar\",axisNames:[\"angularaxis\",\"radialaxis\"],axisName2dataArray:{angularaxis:\"theta\",radialaxis:\"r\"},layerNames:[\"draglayer\",\"plotbg\",\"backplot\",\"angular-grid\",\"radial-grid\",\"frontplot\",\"angular-line\",\"radial-line\",\"angular-axis\",\"radial-axis\"],radialDragBoxSize:50,angularDragBoxSize:30,cornerLen:25,cornerHalfWidth:2,MINDRAG:8,MINZOOM:20,OFFEDGE:20}},{}],830:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/polygon\").tester,a=n.findIndexOfMin,o=n.isAngleInsideSector,s=n.angleDelta,l=n.angleDist;function c(t,e,r,n){var i,a,o=n[0],s=n[1],l=h(Math.sin(e)-Math.sin(t)),c=h(Math.cos(e)-Math.cos(t)),u=Math.tan(r),f=h(1/u),p=l/c,d=s-p*o;return f?l&&c?a=u*(i=d/(u-p)):c?(i=s*f,a=s):(i=o,a=o*u):l&&c?(i=0,a=d):c?(i=0,a=s):i=a=NaN,[i,a]}function u(t,e,r,i){return n.isFullCircle([e,r])?function(t,e){var r,n=e.length,i=new Array(n+1);for(r=0;r<n;r++){var a=e[r];i[r]=[t*Math.cos(a),t*Math.sin(a)]}return i[r]=i[0].slice(),i}(t,i):function(t,e,r,i){var s,u,h=i.length,f=[];function p(e){return[t*Math.cos(e),t*Math.sin(e)]}function d(t,e,r){return c(t,e,r,p(t))}function g(t){return n.mod(t,h)}function v(t){return o(t,[e,r])}var m=a(i,function(t){return v(t)?l(t,e):1/0}),y=d(i[m],i[g(m-1)],e);for(f.push(y),s=m,u=0;u<h;s++,u++){var x=i[g(s)];if(!v(x))break;f.push(p(x))}var b=a(i,function(t){return v(t)?l(t,r):1/0}),_=d(i[b],i[g(b+1)],r);return f.push(_),f.push([0,0]),f.push(f[0].slice()),f}(t,e,r,i)}function h(t){return Math.abs(t)>1e-10?t:0}function f(t,e,r){e=e||0,r=r||0;for(var n=t.length,i=new Array(n),a=0;a<n;a++){var o=t[a];i[a]=[e+o[0],r-o[1]]}return i}e.exports={isPtInsidePolygon:function(t,e,r,n,a){if(!o(e,n))return!1;var s,l;r[0]<r[1]?(s=r[0],l=r[1]):(s=r[1],l=r[0]);var c=i(u(s,n[0],n[1],a)),h=i(u(l,n[0],n[1],a)),f=[t*Math.cos(e),t*Math.sin(e)];return h.contains(f)&&!c.contains(f)},findPolygonOffset:function(t,e,r,n){for(var i=1/0,a=1/0,o=u(t,e,r,n),s=0;s<o.length;s++){var l=o[s];i=Math.min(i,l[0]),a=Math.min(a,-l[1])}return[i,a]},findEnclosingVertexAngles:function(t,e){var r=a(e,function(e){var r=s(e,t);return r>0?r:1/0}),i=n.mod(r+1,e.length);return[e[r],e[i]]},findIntersectionXY:c,findXYatLength:function(t,e,r,n){var i=-e*r,a=e*e+1,o=2*(e*i-r),s=i*i+r*r-t*t,l=Math.sqrt(o*o-4*a*s),c=(-o+l)/(2*a),u=(-o-l)/(2*a);return[[c,e*c+i+n],[u,e*u+i+n]]},clampTiny:h,pathPolygon:function(t,e,r,n,i,a){return\"M\"+f(u(t,e,r,n),i,a).join(\"L\")},pathPolygonAnnulus:function(t,e,r,n,i,a,o){var s,l;t<e?(s=t,l=e):(s=e,l=t);var c=f(u(s,r,n,i),a,o);return\"M\"+f(u(l,r,n,i),a,o).reverse().join(\"L\")+\"M\"+c.join(\"L\")}}},{\"../../lib\":719,\"../../lib/polygon\":731}],831:[function(t,e,r){\"use strict\";var n=t(\"../get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./polar\"),o=t(\"./constants\"),s=o.attr,l=o.name,c=i(l),u={};u[s]={valType:\"subplotid\",dflt:l,editType:\"calc\"},e.exports={attr:s,name:l,idRoot:l,idRegex:c,attrRegex:c,attributes:u,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[l],o=0;o<i.length;o++){var s=i[o],c=n(r,l,s),u=e[s]._subplot;u||(u=a(t,s),e[s]._subplot=u),u.plot(c,e,t._promises)}},clean:function(t,e,r,n){for(var i=n._subplots[l]||[],a=n._has&&n._has(\"gl\"),o=e._has&&e._has(\"gl\"),s=a&&!o,c=0;c<i.length;c++){var u=i[c],h=n[u]._subplot;if(!e[u]&&h)for(var f in h.framework.remove(),h.layers[\"radial-axis-title\"].remove(),h.clipPaths)h.clipPaths[f].remove();s&&h._scene&&(h._scene.destroy(),h._scene=null)}},toSVG:t(\"../cartesian\").toSVG}},{\"../../lib\":719,\"../cartesian\":778,\"../get_data\":802,\"./constants\":829,\"./layout_attributes\":832,\"./layout_defaults\":833,\"./polar\":840}],832:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../cartesian/layout_attributes\"),a=t(\"../domain\").attributes,o=t(\"../../lib\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=s({color:i.color,showline:o({},i.showline,{dflt:!0}),linecolor:i.linecolor,linewidth:i.linewidth,showgrid:o({},i.showgrid,{dflt:!0}),gridcolor:i.gridcolor,gridwidth:i.gridwidth},\"plot\",\"from-root\"),c=s({tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,showtickprefix:i.showtickprefix,tickprefix:i.tickprefix,showticksuffix:i.showticksuffix,ticksuffix:i.ticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,separatethousands:i.separatethousands,tickfont:i.tickfont,tickangle:i.tickangle,tickformat:i.tickformat,tickformatstops:i.tickformatstops,layer:i.layer},\"plot\",\"from-root\"),u={visible:o({},i.visible,{dflt:!0}),type:o({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autorange:o({},i.autorange,{editType:\"plot\"}),rangemode:{valType:\"enumerated\",values:[\"tozero\",\"nonnegative\",\"normal\"],dflt:\"tozero\",editType:\"calc\"},range:o({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],editType:\"plot\"}),categoryorder:i.categoryorder,categoryarray:i.categoryarray,angle:{valType:\"angle\",editType:\"plot\"},side:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"clockwise\",editType:\"plot\"},title:s(i.title,\"plot\",\"from-root\"),hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}};u.title.text.dflt=\"\",o(u,l,c);var h={visible:o({},i.visible,{dflt:!0}),type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"category\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},categoryorder:i.categoryorder,categoryarray:i.categoryarray,thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\"],dflt:\"degrees\",editType:\"calc\"},period:{valType:\"number\",editType:\"calc\",min:0},direction:{valType:\"enumerated\",values:[\"counterclockwise\",\"clockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"angle\",editType:\"calc\"},hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"};o(h,l,c),e.exports={domain:a({name:\"polar\",editType:\"plot\"}),sector:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],dflt:[0,360],editType:\"plot\"},hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},bgcolor:{valType:\"color\",editType:\"plot\",dflt:n.background},radialaxis:u,angularaxis:h,gridshape:{valType:\"enumerated\",values:[\"circular\",\"linear\"],dflt:\"circular\",editType:\"plot\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"}},{\"../../components/color/attributes\":592,\"../../lib\":719,\"../../plot_api/edit_types\":750,\"../cartesian/layout_attributes\":779,\"../domain\":792}],833:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../subplot_defaults\"),s=t(\"../get_data\").getSubplotData,l=t(\"../cartesian/tick_value_defaults\"),c=t(\"../cartesian/tick_mark_defaults\"),u=t(\"../cartesian/tick_label_defaults\"),h=t(\"../cartesian/category_order_defaults\"),f=t(\"../cartesian/line_grid_defaults\"),p=t(\"../cartesian/axis_autotype\"),d=t(\"./layout_attributes\"),g=t(\"./set_convert\"),v=t(\"./constants\"),m=v.axisNames;function y(t,e,r,o){var p=r(\"bgcolor\");o.bgColor=i.combine(p,o.paper_bgcolor);var y=r(\"sector\");r(\"hole\");var b,_=s(o.fullData,v.name,o.id),w=o.layoutOut;function k(t,e){return r(b+\".\"+t,e)}for(var T=0;T<m.length;T++){b=m[T],n.isPlainObject(t[b])||(t[b]={});var A=t[b],M=a.newContainer(e,b);M._id=M._name=b,M._attr=o.id+\".\"+b,M._traceIndices=_.map(function(t){return t._expandedIndex});var S=v.axisName2dataArray[b],E=x(A,M,k,_,S);h(A,M,k,{axData:_,dataAttr:S});var C,L,P=k(\"visible\");switch(g(M,e,w),k(\"uirevision\",e.uirevision),P&&(L=(C=k(\"color\"))===A.color?C:o.font.color),M._m=1,b){case\"radialaxis\":var O=k(\"autorange\",!M.isValidRange(A.range));A.autorange=O,!O||\"linear\"!==E&&\"-\"!==E||k(\"rangemode\"),\"reversed\"===O&&(M._m=-1),k(\"range\"),M.cleanRange(\"range\",{dfltRange:[0,1]}),P&&(k(\"side\"),k(\"angle\",y[0]),k(\"title.text\"),n.coerceFont(k,\"title.font\",{family:o.font.family,size:Math.round(1.2*o.font.size),color:L}));break;case\"angularaxis\":if(\"date\"===E){n.log(\"Polar plots do not support date angular axes yet.\");for(var z=0;z<_.length;z++)_[z].visible=!1;E=A.type=M.type=\"linear\"}k(\"linear\"===E?\"thetaunit\":\"period\");var I=k(\"direction\");k(\"rotation\",{counterclockwise:0,clockwise:90}[I])}if(P)l(A,M,k,M.type),u(A,M,k,M.type,{tickSuffixDflt:\"degrees\"===M.thetaunit?\"\\xb0\":void 0}),c(A,M,k,{outerTicks:!0}),k(\"showticklabels\")&&(n.coerceFont(k,\"tickfont\",{family:o.font.family,size:o.font.size,color:L}),k(\"tickangle\"),k(\"tickformat\")),f(A,M,k,{dfltColor:C,bgColor:o.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:d[b]}),k(\"layer\");\"category\"!==E&&k(\"hoverformat\"),M._input=A}\"category\"===e.angularaxis.type&&r(\"gridshape\")}function x(t,e,r,n,i){if(\"-\"===r(\"type\")){for(var a,o=0;o<n.length;o++)if(n[o].visible){a=n[o];break}a&&a[i]&&(e.type=p(a[i],\"gregorian\")),\"-\"===e.type?e.type=\"linear\":t.type=e.type}return e.type}e.exports=function(t,e,r){o(t,e,r,{type:v.name,attributes:d,handleDefaults:y,font:e.font,paper_bgcolor:e.paper_bgcolor,fullData:r,layoutOut:e})}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../cartesian/axis_autotype\":768,\"../cartesian/category_order_defaults\":771,\"../cartesian/line_grid_defaults\":781,\"../cartesian/tick_label_defaults\":786,\"../cartesian/tick_mark_defaults\":787,\"../cartesian/tick_value_defaults\":788,\"../get_data\":802,\"../subplot_defaults\":842,\"./constants\":829,\"./layout_attributes\":832,\"./set_convert\":841}],834:[function(t,e,r){\"use strict\";var n=t(\"../../../traces/scatter/attributes\"),i=n.marker,a=t(\"../../../lib/extend\").extendFlat;[\"Area traces are deprecated!\",\"Please switch to the *barpolar* trace type.\"].join(\" \");e.exports={r:a({},n.r,{}),t:a({},n.t,{}),marker:{color:a({},i.color,{}),size:a({},i.size,{}),symbol:a({},i.symbol,{}),opacity:a({},i.opacity,{}),editType:\"calc\"}}},{\"../../../lib/extend\":710,\"../../../traces/scatter/attributes\":1112}],835:[function(t,e,r){\"use strict\";var n=t(\"../../cartesian/layout_attributes\"),i=t(\"../../../lib/extend\").extendFlat,a=t(\"../../../plot_api/edit_types\").overrideAll,o=[\"Legacy polar charts are deprecated!\",\"Please switch to *polar* subplots.\"].join(\" \"),s=i({},n.domain,{});function l(t,e){return i({},e,{showline:{valType:\"boolean\"},showticklabels:{valType:\"boolean\"},tickorientation:{valType:\"enumerated\",values:[\"horizontal\",\"vertical\"]},ticklen:{valType:\"number\",min:0},tickcolor:{valType:\"color\"},ticksuffix:{valType:\"string\"},endpadding:{valType:\"number\",description:o},visible:{valType:\"boolean\"}})}e.exports=a({radialaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},domain:s,orientation:{valType:\"number\"}}),angularaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\",dflt:0},{valType:\"number\",dflt:360}]},domain:s}),layout:{direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"]},orientation:{valType:\"angle\"}}},\"plot\",\"nested\")},{\"../../../lib/extend\":710,\"../../../plot_api/edit_types\":750,\"../../cartesian/layout_attributes\":779}],836:[function(t,e,r){\"use strict\";(e.exports=t(\"./micropolar\")).manager=t(\"./micropolar_manager\")},{\"./micropolar\":837,\"./micropolar_manager\":838}],837:[function(t,e,r){var n=t(\"d3\"),i=t(\"../../../lib\").extendDeepAll,a=t(\"../../../constants/alignment\").MID_SHIFT,o=e.exports={version:\"0.2.2\"};o.Axis=function(){var t,e,r,s,l={data:[],layout:{}},c={},u={},h=n.dispatch(\"hover\"),f={};return f.render=function(c){return function(c){e=c||e;var h=l.data,f=l.layout;(\"string\"==typeof e||e.nodeName)&&(e=n.select(e)),e.datum(h).each(function(e,l){var c=e.slice();u={data:o.util.cloneJson(c),layout:o.util.cloneJson(f)};var h=0;c.forEach(function(t,e){t.color||(t.color=f.defaultColorRange[h],h=(h+1)%f.defaultColorRange.length),t.strokeColor||(t.strokeColor=\"LinePlot\"===t.geometry?t.color:n.rgb(t.color).darker().toString()),u.data[e].color=t.color,u.data[e].strokeColor=t.strokeColor,u.data[e].strokeDash=t.strokeDash,u.data[e].strokeSize=t.strokeSize});var p=c.filter(function(t,e){var r=t.visible;return\"undefined\"==typeof r||!0===r}),d=!1,g=p.map(function(t,e){return d=d||\"undefined\"!=typeof t.groupId,t});if(d){var v=n.nest().key(function(t,e){return\"undefined\"!=typeof t.groupId?t.groupId:\"unstacked\"}).entries(g),m=[],y=v.map(function(t,e){if(\"unstacked\"===t.key)return t.values;var r=t.values[0].r.map(function(t,e){return 0});return t.values.forEach(function(t,e,n){t.yStack=[r],m.push(r),r=o.util.sumArrays(t.r,r)}),t.values});p=n.merge(y)}p.forEach(function(t,e){t.t=Array.isArray(t.t[0])?t.t:[t.t],t.r=Array.isArray(t.r[0])?t.r:[t.r]});var x=Math.min(f.width-f.margin.left-f.margin.right,f.height-f.margin.top-f.margin.bottom)/2;x=Math.max(10,x);var b,_=[f.margin.left+x,f.margin.top+x];b=d?[0,n.max(o.util.sumArrays(o.util.arrayLast(p).r[0],o.util.arrayLast(m)))]:n.extent(o.util.flattenArray(p.map(function(t,e){return t.r}))),f.radialAxis.domain!=o.DATAEXTENT&&(b[0]=0),r=n.scale.linear().domain(f.radialAxis.domain!=o.DATAEXTENT&&f.radialAxis.domain?f.radialAxis.domain:b).range([0,x]),u.layout.radialAxis.domain=r.domain();var w,k=o.util.flattenArray(p.map(function(t,e){return t.t})),T=\"string\"==typeof k[0];T&&(k=o.util.deduplicate(k),w=k.slice(),k=n.range(k.length),p=p.map(function(t,e){var r=t;return t.t=[k],d&&(r.yStack=t.yStack),r}));var A=p.filter(function(t,e){return\"LinePlot\"===t.geometry||\"DotPlot\"===t.geometry}).length===p.length,M=null===f.needsEndSpacing?T||!A:f.needsEndSpacing,S=f.angularAxis.domain&&f.angularAxis.domain!=o.DATAEXTENT&&!T&&f.angularAxis.domain[0]>=0?f.angularAxis.domain:n.extent(k),E=Math.abs(k[1]-k[0]);A&&!T&&(E=0);var C=S.slice();M&&T&&(C[1]+=E);var L=f.angularAxis.ticksCount||4;L>8&&(L=L/(L/8)+L%8),f.angularAxis.ticksStep&&(L=(C[1]-C[0])/L);var P=f.angularAxis.ticksStep||(C[1]-C[0])/(L*(f.minorTicks+1));w&&(P=Math.max(Math.round(P),1)),C[2]||(C[2]=P);var O=n.range.apply(this,C);if(O=O.map(function(t,e){return parseFloat(t.toPrecision(12))}),s=n.scale.linear().domain(C.slice(0,2)).range(\"clockwise\"===f.direction?[0,360]:[360,0]),u.layout.angularAxis.domain=s.domain(),u.layout.angularAxis.endPadding=M?E:0,\"undefined\"==typeof(t=n.select(this).select(\"svg.chart-root\"))||t.empty()){var z=(new DOMParser).parseFromString(\"<svg xmlns='http://www.w3.org/2000/svg' class='chart-root'>' + '<g class='outer-group'>' + '<g class='chart-group'>' + '<circle class='background-circle'></circle>' + '<g class='geometry-group'></g>' + '<g class='radial axis-group'>' + '<circle class='outside-circle'></circle>' + '</g>' + '<g class='angular axis-group'></g>' + '<g class='guides-group'><line></line><circle r='0'></circle></g>' + '</g>' + '<g class='legend-group'></g>' + '<g class='tooltips-group'></g>' + '<g class='title-group'><text></text></g>' + '</g>' + '</svg>\",\"application/xml\"),I=this.appendChild(this.ownerDocument.importNode(z.documentElement,!0));t=n.select(I)}t.select(\".guides-group\").style({\"pointer-events\":\"none\"}),t.select(\".angular.axis-group\").style({\"pointer-events\":\"none\"}),t.select(\".radial.axis-group\").style({\"pointer-events\":\"none\"});var D,R=t.select(\".chart-group\"),F={fill:\"none\",stroke:f.tickColor},B={\"font-size\":f.font.size,\"font-family\":f.font.family,fill:f.font.color,\"text-shadow\":[\"-1px 0px\",\"1px -1px\",\"-1px 1px\",\"1px 1px\"].map(function(t,e){return\" \"+t+\" 0 \"+f.font.outlineColor}).join(\",\")};if(f.showLegend){D=t.select(\".legend-group\").attr({transform:\"translate(\"+[x,f.margin.top]+\")\"}).style({display:\"block\"});var N=p.map(function(t,e){var r=o.util.cloneJson(t);return r.symbol=\"DotPlot\"===t.geometry?t.dotType||\"circle\":\"LinePlot\"!=t.geometry?\"square\":\"line\",r.visibleInLegend=\"undefined\"==typeof t.visibleInLegend||t.visibleInLegend,r.color=\"LinePlot\"===t.geometry?t.strokeColor:t.color,r});o.Legend().config({data:p.map(function(t,e){return t.name||\"Element\"+e}),legendConfig:i({},o.Legend.defaultConfig().legendConfig,{container:D,elements:N,reverseOrder:f.legend.reverseOrder})})();var j=D.node().getBBox();x=Math.min(f.width-j.width-f.margin.left-f.margin.right,f.height-f.margin.top-f.margin.bottom)/2,x=Math.max(10,x),_=[f.margin.left+x,f.margin.top+x],r.range([0,x]),u.layout.radialAxis.domain=r.domain(),D.attr(\"transform\",\"translate(\"+[_[0]+x,_[1]-x]+\")\")}else D=t.select(\".legend-group\").style({display:\"none\"});t.attr({width:f.width,height:f.height}).style({opacity:f.opacity}),R.attr(\"transform\",\"translate(\"+_+\")\").style({cursor:\"crosshair\"});var U=[(f.width-(f.margin.left+f.margin.right+2*x+(j?j.width:0)))/2,(f.height-(f.margin.top+f.margin.bottom+2*x))/2];if(U[0]=Math.max(0,U[0]),U[1]=Math.max(0,U[1]),t.select(\".outer-group\").attr(\"transform\",\"translate(\"+U+\")\"),f.title&&f.title.text){var V=t.select(\"g.title-group text\").style(B).text(f.title.text),q=V.node().getBBox();V.attr({x:_[0]-q.width/2,y:_[1]-x-20})}var H=t.select(\".radial.axis-group\");if(f.radialAxis.gridLinesVisible){var G=H.selectAll(\"circle.grid-circle\").data(r.ticks(5));G.enter().append(\"circle\").attr({class:\"grid-circle\"}).style(F),G.attr(\"r\",r),G.exit().remove()}H.select(\"circle.outside-circle\").attr({r:x}).style(F);var Y=t.select(\"circle.background-circle\").attr({r:x}).style({fill:f.backgroundColor,stroke:f.stroke});function W(t,e){return s(t)%360+f.orientation}if(f.radialAxis.visible){var X=n.svg.axis().scale(r).ticks(5).tickSize(5);H.call(X).attr({transform:\"rotate(\"+f.radialAxis.orientation+\")\"}),H.selectAll(\".domain\").style(F),H.selectAll(\"g>text\").text(function(t,e){return this.textContent+f.radialAxis.ticksSuffix}).style(B).style({\"text-anchor\":\"start\"}).attr({x:0,y:0,dx:0,dy:0,transform:function(t,e){return\"horizontal\"===f.radialAxis.tickOrientation?\"rotate(\"+-f.radialAxis.orientation+\") translate(\"+[0,B[\"font-size\"]]+\")\":\"translate(\"+[0,B[\"font-size\"]]+\")\"}}),H.selectAll(\"g>line\").style({stroke:\"black\"})}var Z=t.select(\".angular.axis-group\").selectAll(\"g.angular-tick\").data(O),J=Z.enter().append(\"g\").classed(\"angular-tick\",!0);Z.attr({transform:function(t,e){return\"rotate(\"+W(t)+\")\"}}).style({display:f.angularAxis.visible?\"block\":\"none\"}),Z.exit().remove(),J.append(\"line\").classed(\"grid-line\",!0).classed(\"major\",function(t,e){return e%(f.minorTicks+1)==0}).classed(\"minor\",function(t,e){return!(e%(f.minorTicks+1)==0)}).style(F),J.selectAll(\".minor\").style({stroke:f.minorTickColor}),Z.select(\"line.grid-line\").attr({x1:f.tickLength?x-f.tickLength:0,x2:x}).style({display:f.angularAxis.gridLinesVisible?\"block\":\"none\"}),J.append(\"text\").classed(\"axis-text\",!0).style(B);var K=Z.select(\"text.axis-text\").attr({x:x+f.labelOffset,dy:a+\"em\",transform:function(t,e){var r=W(t),n=x+f.labelOffset,i=f.angularAxis.tickOrientation;return\"horizontal\"==i?\"rotate(\"+-r+\" \"+n+\" 0)\":\"radial\"==i?r<270&&r>90?\"rotate(180 \"+n+\" 0)\":null:\"rotate(\"+(r<=180&&r>0?-90:90)+\" \"+n+\" 0)\"}}).style({\"text-anchor\":\"middle\",display:f.angularAxis.labelsVisible?\"block\":\"none\"}).text(function(t,e){return e%(f.minorTicks+1)!=0?\"\":w?w[t]+f.angularAxis.ticksSuffix:t+f.angularAxis.ticksSuffix}).style(B);f.angularAxis.rewriteTicks&&K.text(function(t,e){return e%(f.minorTicks+1)!=0?\"\":f.angularAxis.rewriteTicks(this.textContent,e)});var $=n.max(R.selectAll(\".angular-tick text\")[0].map(function(t,e){return t.getCTM().e+t.getBBox().width}));D.attr({transform:\"translate(\"+[x+$,f.margin.top]+\")\"});var Q=t.select(\"g.geometry-group\").selectAll(\"g\").size()>0,tt=t.select(\"g.geometry-group\").selectAll(\"g.geometry\").data(p);if(tt.enter().append(\"g\").attr({class:function(t,e){return\"geometry geometry\"+e}}),tt.exit().remove(),p[0]||Q){var et=[];p.forEach(function(t,e){var n={};n.radialScale=r,n.angularScale=s,n.container=tt.filter(function(t,r){return r==e}),n.geometry=t.geometry,n.orientation=f.orientation,n.direction=f.direction,n.index=e,et.push({data:t,geometryConfig:n})});var rt=n.nest().key(function(t,e){return\"undefined\"!=typeof t.data.groupId||\"unstacked\"}).entries(et),nt=[];rt.forEach(function(t,e){\"unstacked\"===t.key?nt=nt.concat(t.values.map(function(t,e){return[t]})):nt.push(t.values)}),nt.forEach(function(t,e){var r;r=Array.isArray(t)?t[0].geometryConfig.geometry:t.geometryConfig.geometry;var n=t.map(function(t,e){return i(o[r].defaultConfig(),t)});o[r]().config(n)()})}var it,at,ot=t.select(\".guides-group\"),st=t.select(\".tooltips-group\"),lt=o.tooltipPanel().config({container:st,fontSize:8})(),ct=o.tooltipPanel().config({container:st,fontSize:8})(),ut=o.tooltipPanel().config({container:st,hasTick:!0})();if(!T){var ht=ot.select(\"line\").attr({x1:0,y1:0,y2:0}).style({stroke:\"grey\",\"pointer-events\":\"none\"});R.on(\"mousemove.angular-guide\",function(t,e){var r=o.util.getMousePos(Y).angle;ht.attr({x2:-x,transform:\"rotate(\"+r+\")\"}).style({opacity:.5});var n=(r+180+360-f.orientation)%360;it=s.invert(n);var i=o.util.convertToCartesian(x+12,r+180);lt.text(o.util.round(it)).move([i[0]+_[0],i[1]+_[1]])}).on(\"mouseout.angular-guide\",function(t,e){ot.select(\"line\").style({opacity:0})})}var ft=ot.select(\"circle\").style({stroke:\"grey\",fill:\"none\"});R.on(\"mousemove.radial-guide\",function(t,e){var n=o.util.getMousePos(Y).radius;ft.attr({r:n}).style({opacity:.5}),at=r.invert(o.util.getMousePos(Y).radius);var i=o.util.convertToCartesian(n,f.radialAxis.orientation);ct.text(o.util.round(at)).move([i[0]+_[0],i[1]+_[1]])}).on(\"mouseout.radial-guide\",function(t,e){ft.style({opacity:0}),ut.hide(),lt.hide(),ct.hide()}),t.selectAll(\".geometry-group .mark\").on(\"mouseover.tooltip\",function(e,r){var i=n.select(this),a=this.style.fill,s=\"black\",l=this.style.opacity||1;if(i.attr({\"data-opacity\":l}),a&&\"none\"!==a){i.attr({\"data-fill\":a}),s=n.hsl(a).darker().toString(),i.style({fill:s,opacity:1});var c={t:o.util.round(e[0]),r:o.util.round(e[1])};T&&(c.t=w[e[0]]);var u=\"t: \"+c.t+\", r: \"+c.r,h=this.getBoundingClientRect(),f=t.node().getBoundingClientRect(),p=[h.left+h.width/2-U[0]-f.left,h.top+h.height/2-U[1]-f.top];ut.config({color:s}).text(u),ut.move(p)}else a=this.style.stroke||\"black\",i.attr({\"data-stroke\":a}),s=n.hsl(a).darker().toString(),i.style({stroke:s,opacity:1})}).on(\"mousemove.tooltip\",function(t,e){if(0!=n.event.which)return!1;n.select(this).attr(\"data-fill\")&&ut.show()}).on(\"mouseout.tooltip\",function(t,e){ut.hide();var r=n.select(this),i=r.attr(\"data-fill\");i?r.style({fill:i,opacity:r.attr(\"data-opacity\")}):r.style({stroke:r.attr(\"data-stroke\"),opacity:r.attr(\"data-opacity\")})})})}(c),this},f.config=function(t){if(!arguments.length)return l;var e=o.util.cloneJson(t);return e.data.forEach(function(t,e){l.data[e]||(l.data[e]={}),i(l.data[e],o.Axis.defaultConfig().data[0]),i(l.data[e],t)}),i(l.layout,o.Axis.defaultConfig().layout),i(l.layout,e.layout),this},f.getLiveConfig=function(){return u},f.getinputConfig=function(){return c},f.radialScale=function(t){return r},f.angularScale=function(t){return s},f.svg=function(){return t},n.rebind(f,h,\"on\"),f},o.Axis.defaultConfig=function(t,e){return{data:[{t:[1,2,3,4],r:[10,11,12,13],name:\"Line1\",geometry:\"LinePlot\",color:null,strokeDash:\"solid\",strokeColor:null,strokeSize:\"1\",visibleInLegend:!0,opacity:1}],layout:{defaultColorRange:n.scale.category10().range(),title:null,height:450,width:500,margin:{top:40,right:40,bottom:40,left:40},font:{size:12,color:\"gray\",outlineColor:\"white\",family:\"Tahoma, sans-serif\"},direction:\"clockwise\",orientation:0,labelOffset:10,radialAxis:{domain:null,orientation:-45,ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null},angularAxis:{domain:[0,360],ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,labelsVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null,ticksCount:null,ticksStep:null},minorTicks:0,tickLength:null,tickColor:\"silver\",minorTickColor:\"#eee\",backgroundColor:\"none\",needsEndSpacing:null,showLegend:!0,legend:{reverseOrder:!1},opacity:1}}},o.util={},o.DATAEXTENT=\"dataExtent\",o.AREA=\"AreaChart\",o.LINE=\"LinePlot\",o.DOT=\"DotPlot\",o.BAR=\"BarChart\",o.util._override=function(t,e){for(var r in t)r in e&&(e[r]=t[r])},o.util._extend=function(t,e){for(var r in t)e[r]=t[r]},o.util._rndSnd=function(){return 2*Math.random()-1+(2*Math.random()-1)+(2*Math.random()-1)},o.util.dataFromEquation2=function(t,e){var r=e||6;return n.range(0,360+r,r).map(function(e,r){var n=e*Math.PI/180;return[e,t(n)]})},o.util.dataFromEquation=function(t,e,r){var i=e||6,a=[],o=[];n.range(0,360+i,i).forEach(function(e,r){var n=e*Math.PI/180,i=t(n);a.push(e),o.push(i)});var s={t:a,r:o};return r&&(s.name=r),s},o.util.ensureArray=function(t,e){if(\"undefined\"==typeof t)return null;var r=[].concat(t);return n.range(e).map(function(t,e){return r[e]||r[0]})},o.util.fillArrays=function(t,e,r){return e.forEach(function(e,n){t[e]=o.util.ensureArray(t[e],r)}),t},o.util.cloneJson=function(t){return JSON.parse(JSON.stringify(t))},o.util.validateKeys=function(t,e){\"string\"==typeof e&&(e=e.split(\".\"));var r=e.shift();return t[r]&&(!e.length||objHasKeys(t[r],e))},o.util.sumArrays=function(t,e){return n.zip(t,e).map(function(t,e){return n.sum(t)})},o.util.arrayLast=function(t){return t[t.length-1]},o.util.arrayEqual=function(t,e){for(var r=Math.max(t.length,e.length,1);r-- >=0&&t[r]===e[r];);return-2===r},o.util.flattenArray=function(t){for(var e=[];!o.util.arrayEqual(e,t);)e=t,t=[].concat.apply([],t);return t},o.util.deduplicate=function(t){return t.filter(function(t,e,r){return r.indexOf(t)==e})},o.util.convertToCartesian=function(t,e){var r=e*Math.PI/180;return[t*Math.cos(r),t*Math.sin(r)]},o.util.round=function(t,e){var r=e||2,n=Math.pow(10,r);return Math.round(t*n)/n},o.util.getMousePos=function(t){var e=n.mouse(t.node()),r=e[0],i=e[1],a={};return a.x=r,a.y=i,a.pos=e,a.angle=180*(Math.atan2(i,r)+Math.PI)/Math.PI,a.radius=Math.sqrt(r*r+i*i),a},o.util.duplicatesCount=function(t){for(var e,r={},n={},i=0,a=t.length;i<a;i++)(e=t[i])in r?(r[e]++,n[e]=r[e]):r[e]=1;return n},o.util.duplicates=function(t){return Object.keys(o.util.duplicatesCount(t))},o.util.translator=function(t,e,r,n){if(n){var i=r.slice();r=e,e=i}var a=e.reduce(function(t,e){if(\"undefined\"!=typeof t)return t[e]},t);\"undefined\"!=typeof a&&(e.reduce(function(t,r,n){if(\"undefined\"!=typeof t)return n===e.length-1&&delete t[r],t[r]},t),r.reduce(function(t,e,n){return\"undefined\"==typeof t[e]&&(t[e]={}),n===r.length-1&&(t[e]=a),t[e]},t))},o.PolyChart=function(){var t=[o.PolyChart.defaultConfig()],e=n.dispatch(\"hover\"),r={solid:\"none\",dash:[5,2],dot:[2,5]};function a(){var e=t[0].geometryConfig,i=e.container;\"string\"==typeof i&&(i=n.select(i)),i.datum(t).each(function(t,i){var a=!!t[0].data.yStack,o=t.map(function(t,e){return a?n.zip(t.data.t[0],t.data.r[0],t.data.yStack[0]):n.zip(t.data.t[0],t.data.r[0])}),s=e.angularScale,l=e.radialScale.domain()[0],c={bar:function(r,i,a){var o=t[a].data,l=e.radialScale(r[1])-e.radialScale(0),c=e.radialScale(r[2]||0),u=o.barWidth;n.select(this).attr({class:\"mark bar\",d:\"M\"+[[l+c,-u/2],[l+c,u/2],[c,u/2],[c,-u/2]].join(\"L\")+\"Z\",transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0]))+\")\"}})}};c.dot=function(r,i,a){var o=r[2]?[r[0],r[1]+r[2]]:r,s=n.svg.symbol().size(t[a].data.dotSize).type(t[a].data.dotType)(r,i);n.select(this).attr({class:\"mark dot\",d:s,transform:function(t,r){var n,i,a,s=(n=function(t,r){var n=e.radialScale(t[1]),i=(e.angularScale(t[0])+e.orientation)*Math.PI/180;return{r:n,t:i}}(o),i=n.r*Math.cos(n.t),a=n.r*Math.sin(n.t),{x:i,y:a});return\"translate(\"+[s.x,s.y]+\")\"}})};var u=n.svg.line.radial().interpolate(t[0].data.lineInterpolation).radius(function(t){return e.radialScale(t[1])}).angle(function(t){return e.angularScale(t[0])*Math.PI/180});c.line=function(r,i,a){var s=r[2]?o[a].map(function(t,e){return[t[0],t[1]+t[2]]}):o[a];if(n.select(this).each(c.dot).style({opacity:function(e,r){return+t[a].data.dotVisible},fill:d.stroke(r,i,a)}).attr({class:\"mark dot\"}),!(i>0)){var l=n.select(this.parentNode).selectAll(\"path.line\").data([0]);l.enter().insert(\"path\"),l.attr({class:\"line\",d:u(s),transform:function(t,r){return\"rotate(\"+(e.orientation+90)+\")\"},\"pointer-events\":\"none\"}).style({fill:function(t,e){return d.fill(r,i,a)},\"fill-opacity\":0,stroke:function(t,e){return d.stroke(r,i,a)},\"stroke-width\":function(t,e){return d[\"stroke-width\"](r,i,a)},\"stroke-dasharray\":function(t,e){return d[\"stroke-dasharray\"](r,i,a)},opacity:function(t,e){return d.opacity(r,i,a)},display:function(t,e){return d.display(r,i,a)}})}};var h=e.angularScale.range(),f=Math.abs(h[1]-h[0])/o[0].length*Math.PI/180,p=n.svg.arc().startAngle(function(t){return-f/2}).endAngle(function(t){return f/2}).innerRadius(function(t){return e.radialScale(l+(t[2]||0))}).outerRadius(function(t){return e.radialScale(l+(t[2]||0))+e.radialScale(t[1])});c.arc=function(t,r,i){n.select(this).attr({class:\"mark arc\",d:p,transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0])+90)+\")\"}})};var d={fill:function(e,r,n){return t[n].data.color},stroke:function(e,r,n){return t[n].data.strokeColor},\"stroke-width\":function(e,r,n){return t[n].data.strokeSize+\"px\"},\"stroke-dasharray\":function(e,n,i){return r[t[i].data.strokeDash]},opacity:function(e,r,n){return t[n].data.opacity},display:function(e,r,n){return\"undefined\"==typeof t[n].data.visible||t[n].data.visible?\"block\":\"none\"}},g=n.select(this).selectAll(\"g.layer\").data(o);g.enter().append(\"g\").attr({class:\"layer\"});var v=g.selectAll(\"path.mark\").data(function(t,e){return t});v.enter().append(\"path\").attr({class:\"mark\"}),v.style(d).each(c[e.geometryType]),v.exit().remove(),g.exit().remove()})}return a.config=function(e){return arguments.length?(e.forEach(function(e,r){t[r]||(t[r]={}),i(t[r],o.PolyChart.defaultConfig()),i(t[r],e)}),this):t},a.getColorScale=function(){},n.rebind(a,e,\"on\"),a},o.PolyChart.defaultConfig=function(){return{data:{name:\"geom1\",t:[[1,2,3,4]],r:[[1,2,3,4]],dotType:\"circle\",dotSize:64,dotVisible:!1,barWidth:20,color:\"#ffa500\",strokeSize:1,strokeColor:\"silver\",strokeDash:\"solid\",opacity:1,index:0,visible:!0,visibleInLegend:!0},geometryConfig:{geometry:\"LinePlot\",geometryType:\"arc\",direction:\"clockwise\",orientation:0,container:\"body\",radialScale:null,angularScale:null,colorScale:n.scale.category20()}}},o.BarChart=function(){return o.PolyChart()},o.BarChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"bar\"}}},o.AreaChart=function(){return o.PolyChart()},o.AreaChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"arc\"}}},o.DotPlot=function(){return o.PolyChart()},o.DotPlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"dot\",dotType:\"circle\"}}},o.LinePlot=function(){return o.PolyChart()},o.LinePlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"line\"}}},o.Legend=function(){var t=o.Legend.defaultConfig(),e=n.dispatch(\"hover\");function r(){var e=t.legendConfig,a=t.data.map(function(t,r){return[].concat(t).map(function(t,n){var a=i({},e.elements[r]);return a.name=t,a.color=[].concat(e.elements[r].color)[n],a})}),o=n.merge(a);o=o.filter(function(t,r){return e.elements[r]&&(e.elements[r].visibleInLegend||\"undefined\"==typeof e.elements[r].visibleInLegend)}),e.reverseOrder&&(o=o.reverse());var s=e.container;(\"string\"==typeof s||s.nodeName)&&(s=n.select(s));var l=o.map(function(t,e){return t.color}),c=e.fontSize,u=null==e.isContinuous?\"number\"==typeof o[0]:e.isContinuous,h=u?e.height:c*o.length,f=s.classed(\"legend-group\",!0).selectAll(\"svg\").data([0]),p=f.enter().append(\"svg\").attr({width:300,height:h+c,xmlns:\"http://www.w3.org/2000/svg\",\"xmlns:xlink\":\"http://www.w3.org/1999/xlink\",version:\"1.1\"});p.append(\"g\").classed(\"legend-axis\",!0),p.append(\"g\").classed(\"legend-marks\",!0);var d=n.range(o.length),g=n.scale[u?\"linear\":\"ordinal\"]().domain(d).range(l),v=n.scale[u?\"linear\":\"ordinal\"]().domain(d)[u?\"range\":\"rangePoints\"]([0,h]);if(u){var m=f.select(\".legend-marks\").append(\"defs\").append(\"linearGradient\").attr({id:\"grad1\",x1:\"0%\",y1:\"0%\",x2:\"0%\",y2:\"100%\"}).selectAll(\"stop\").data(l);m.enter().append(\"stop\"),m.attr({offset:function(t,e){return e/(l.length-1)*100+\"%\"}}).style({\"stop-color\":function(t,e){return t}}),f.append(\"rect\").classed(\"legend-mark\",!0).attr({height:e.height,width:e.colorBandWidth,fill:\"url(#grad1)\"})}else{var y=f.select(\".legend-marks\").selectAll(\"path.legend-mark\").data(o);y.enter().append(\"path\").classed(\"legend-mark\",!0),y.attr({transform:function(t,e){return\"translate(\"+[c/2,v(e)+c/2]+\")\"},d:function(t,e){var r,i,a,o=t.symbol;return a=3*(i=c),\"line\"===(r=o)?\"M\"+[[-i/2,-i/12],[i/2,-i/12],[i/2,i/12],[-i/2,i/12]]+\"Z\":-1!=n.svg.symbolTypes.indexOf(r)?n.svg.symbol().type(r).size(a)():n.svg.symbol().type(\"square\").size(a)()},fill:function(t,e){return g(e)}}),y.exit().remove()}var x=n.svg.axis().scale(v).orient(\"right\"),b=f.select(\"g.legend-axis\").attr({transform:\"translate(\"+[u?e.colorBandWidth:c,c/2]+\")\"}).call(x);return b.selectAll(\".domain\").style({fill:\"none\",stroke:\"none\"}),b.selectAll(\"line\").style({fill:\"none\",stroke:u?e.textColor:\"none\"}),b.selectAll(\"text\").style({fill:e.textColor,\"font-size\":e.fontSize}).text(function(t,e){return o[e].name}),r}return r.config=function(e){return arguments.length?(i(t,e),this):t},n.rebind(r,e,\"on\"),r},o.Legend.defaultConfig=function(t,e){return{data:[\"a\",\"b\",\"c\"],legendConfig:{elements:[{symbol:\"line\",color:\"red\"},{symbol:\"square\",color:\"yellow\"},{symbol:\"diamond\",color:\"limegreen\"}],height:150,colorBandWidth:30,fontSize:12,container:\"body\",isContinuous:null,textColor:\"grey\",reverseOrder:!1}}},o.tooltipPanel=function(){var t,e,r,a={container:null,hasTick:!1,fontSize:12,color:\"white\",padding:5},s=\"tooltip-\"+o.tooltipPanel.uid++,l=10,c=function(){var n=(t=a.container.selectAll(\"g.\"+s).data([0])).enter().append(\"g\").classed(s,!0).style({\"pointer-events\":\"none\",display:\"none\"});return r=n.append(\"path\").style({fill:\"white\",\"fill-opacity\":.9}).attr({d:\"M0 0\"}),e=n.append(\"text\").attr({dx:a.padding+l,dy:.3*+a.fontSize}),c};return c.text=function(i){var o=n.hsl(a.color).l,s=o>=.5?\"#aaa\":\"white\",u=o>=.5?\"black\":\"white\",h=i||\"\";e.style({fill:u,\"font-size\":a.fontSize+\"px\"}).text(h);var f=a.padding,p=e.node().getBBox(),d={fill:a.color,stroke:s,\"stroke-width\":\"2px\"},g=p.width+2*f+l,v=p.height+2*f;return r.attr({d:\"M\"+[[l,-v/2],[l,-v/4],[a.hasTick?0:l,0],[l,v/4],[l,v/2],[g,v/2],[g,-v/2]].join(\"L\")+\"Z\"}).style(d),t.attr({transform:\"translate(\"+[l,-v/2+2*f]+\")\"}),t.style({display:\"block\"}),c},c.move=function(e){if(t)return t.attr({transform:\"translate(\"+[e[0],e[1]]+\")\"}).style({display:\"block\"}),c},c.hide=function(){if(t)return t.style({display:\"none\"}),c},c.show=function(){if(t)return t.style({display:\"block\"}),c},c.config=function(t){return i(a,t),c},c},o.tooltipPanel.uid=1,o.adapter={},o.adapter.plotly=function(){var t={convert:function(t,e){var r={};if(t.data&&(r.data=t.data.map(function(t,r){var n=i({},t);return[[n,[\"marker\",\"color\"],[\"color\"]],[n,[\"marker\",\"opacity\"],[\"opacity\"]],[n,[\"marker\",\"line\",\"color\"],[\"strokeColor\"]],[n,[\"marker\",\"line\",\"dash\"],[\"strokeDash\"]],[n,[\"marker\",\"line\",\"width\"],[\"strokeSize\"]],[n,[\"marker\",\"symbol\"],[\"dotType\"]],[n,[\"marker\",\"size\"],[\"dotSize\"]],[n,[\"marker\",\"barWidth\"],[\"barWidth\"]],[n,[\"line\",\"interpolation\"],[\"lineInterpolation\"]],[n,[\"showlegend\"],[\"visibleInLegend\"]]].forEach(function(t,r){o.util.translator.apply(null,t.concat(e))}),e||delete n.marker,e&&delete n.groupId,e?(\"LinePlot\"===n.geometry?(n.type=\"scatter\",!0===n.dotVisible?(delete n.dotVisible,n.mode=\"lines+markers\"):n.mode=\"lines\"):\"DotPlot\"===n.geometry?(n.type=\"scatter\",n.mode=\"markers\"):\"AreaChart\"===n.geometry?n.type=\"area\":\"BarChart\"===n.geometry&&(n.type=\"bar\"),delete n.geometry):(\"scatter\"===n.type?\"lines\"===n.mode?n.geometry=\"LinePlot\":\"markers\"===n.mode?n.geometry=\"DotPlot\":\"lines+markers\"===n.mode&&(n.geometry=\"LinePlot\",n.dotVisible=!0):\"area\"===n.type?n.geometry=\"AreaChart\":\"bar\"===n.type&&(n.geometry=\"BarChart\"),delete n.mode,delete n.type),n}),!e&&t.layout&&\"stack\"===t.layout.barmode)){var a=o.util.duplicates(r.data.map(function(t,e){return t.geometry}));r.data.forEach(function(t,e){var n=a.indexOf(t.geometry);-1!=n&&(r.data[e].groupId=n)})}if(t.layout){var s=i({},t.layout);if([[s,[\"plot_bgcolor\"],[\"backgroundColor\"]],[s,[\"showlegend\"],[\"showLegend\"]],[s,[\"radialaxis\"],[\"radialAxis\"]],[s,[\"angularaxis\"],[\"angularAxis\"]],[s.angularaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularaxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularaxis,[\"nticks\"],[\"ticksCount\"]],[s.angularaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularaxis,[\"range\"],[\"domain\"]],[s.angularaxis,[\"endpadding\"],[\"endPadding\"]],[s.radialaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialaxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularAxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularAxis,[\"nticks\"],[\"ticksCount\"]],[s.angularAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularAxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"endpadding\"],[\"endPadding\"]],[s.radialAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialAxis,[\"range\"],[\"domain\"]],[s.font,[\"outlinecolor\"],[\"outlineColor\"]],[s.legend,[\"traceorder\"],[\"reverseOrder\"]],[s,[\"labeloffset\"],[\"labelOffset\"]],[s,[\"defaultcolorrange\"],[\"defaultColorRange\"]]].forEach(function(t,r){o.util.translator.apply(null,t.concat(e))}),e?(\"undefined\"!=typeof s.tickLength&&(s.angularaxis.ticklen=s.tickLength,delete s.tickLength),s.tickColor&&(s.angularaxis.tickcolor=s.tickColor,delete s.tickColor)):(s.angularAxis&&\"undefined\"!=typeof s.angularAxis.ticklen&&(s.tickLength=s.angularAxis.ticklen),s.angularAxis&&\"undefined\"!=typeof s.angularAxis.tickcolor&&(s.tickColor=s.angularAxis.tickcolor)),s.legend&&\"boolean\"!=typeof s.legend.reverseOrder&&(s.legend.reverseOrder=\"normal\"!=s.legend.reverseOrder),s.legend&&\"boolean\"==typeof s.legend.traceorder&&(s.legend.traceorder=s.legend.traceorder?\"reversed\":\"normal\",delete s.legend.reverseOrder),s.margin&&\"undefined\"!=typeof s.margin.t){var l=[\"t\",\"r\",\"b\",\"l\",\"pad\"],c=[\"top\",\"right\",\"bottom\",\"left\",\"pad\"],u={};n.entries(s.margin).forEach(function(t,e){u[c[l.indexOf(t.key)]]=t.value}),s.margin=u}e&&(delete s.needsEndSpacing,delete s.minorTickColor,delete s.minorTicks,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksStep,delete s.angularaxis.rewriteTicks,delete s.angularaxis.nticks,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksStep,delete s.radialaxis.rewriteTicks,delete s.radialaxis.nticks),r.layout=s}return r}};return t}},{\"../../../constants/alignment\":688,\"../../../lib\":719,d3:163}],838:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../../lib\"),a=t(\"../../../components/color\"),o=t(\"./micropolar\"),s=t(\"./undo_manager\"),l=i.extendDeepAll,c=e.exports={};c.framework=function(t){var e,r,i,a,u,h=new s;function f(r,s){return s&&(u=s),n.select(n.select(u).node().parentNode).selectAll(\".svg-container>*:not(.chart-root)\").remove(),e=e?l(e,r):r,i||(i=o.Axis()),a=o.adapter.plotly().convert(e),i.config(a).render(u),t.data=e.data,t.layout=e.layout,c.fillLayout(t),e}return f.isPolar=!0,f.svg=function(){return i.svg()},f.getConfig=function(){return e},f.getLiveConfig=function(){return o.adapter.plotly().convert(i.getLiveConfig(),!0)},f.getLiveScales=function(){return{t:i.angularScale(),r:i.radialScale()}},f.setUndoPoint=function(){var t,n,i=this,a=o.util.cloneJson(e);t=a,n=r,h.add({undo:function(){n&&i(n)},redo:function(){i(t)}}),r=o.util.cloneJson(a)},f.undo=function(){h.undo()},f.redo=function(){h.redo()},f},c.fillLayout=function(t){var e=n.select(t).selectAll(\".plot-container\"),r=e.selectAll(\".svg-container\"),i=t.framework&&t.framework.svg&&t.framework.svg(),o={width:800,height:600,paper_bgcolor:a.background,_container:e,_paperdiv:r,_paper:i};t._fullLayout=l(o,t.layout)}},{\"../../../components/color\":593,\"../../../lib\":719,\"./micropolar\":837,\"./undo_manager\":839,d3:163}],839:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=[],r=-1,n=!1;function i(t,e){return t?(n=!0,t[e](),n=!1,this):this}return{add:function(t){return n?this:(e.splice(r+1,e.length-r),e.push(t),r=e.length-1,this)},setCallback:function(e){t=e},undo:function(){var n=e[r];return n?(i(n,\"undo\"),r-=1,t&&t(n.undo),this):this},redo:function(){var n=e[r+1];return n?(i(n,\"redo\"),r+=1,t&&t(n.redo),this):this},clear:function(){e=[],r=-1},hasUndo:function(){return-1!==r},hasRedo:function(){return r<e.length-1},getCommands:function(){return e},getPreviousCommand:function(){return e[r-1]},getIndex:function(){return r}}}},{}],840:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../plots\"),u=t(\"../../plots/cartesian/axes\"),h=t(\"../cartesian/set_convert\"),f=t(\"./set_convert\"),p=t(\"../cartesian/autorange\").doAutoRange,d=t(\"../cartesian/dragbox\"),g=t(\"../../components/dragelement\"),v=t(\"../../components/fx\"),m=t(\"../../components/titles\"),y=t(\"../cartesian/select\").prepSelect,x=t(\"../cartesian/select\").selectOnClick,b=t(\"../cartesian/select\").clearSelect,_=t(\"../../lib/setcursor\"),w=t(\"../../lib/clear_gl_canvases\"),k=t(\"../../plot_api/subroutines\").redrawReglTraces,T=t(\"../../constants/alignment\").MID_SHIFT,A=t(\"./constants\"),M=t(\"./helpers\"),S=o._,E=o.mod,C=o.deg2rad,L=o.rad2deg;function P(t,e){this.id=e,this.gd=t,this._hasClipOnAxisFalse=null,this.vangles=null,this.radialAxisAngle=null,this.traceHash={},this.layers={},this.clipPaths={},this.clipIds={},this.viewInitial={};var r=t._fullLayout,n=\"clip\"+r._uid+e;this.clipIds.forTraces=n+\"-for-traces\",this.clipPaths.forTraces=r._clips.append(\"clipPath\").attr(\"id\",this.clipIds.forTraces),this.clipPaths.forTraces.append(\"path\"),this.framework=r._polarlayer.append(\"g\").attr(\"class\",e),this.radialTickLayout=null,this.angularTickLayout=null}var O=P.prototype;function z(t){var e=t.ticks+String(t.ticklen)+String(t.showticklabels);return\"side\"in t&&(e+=t.side),e}function I(t,e){return e[o.findIndexOfMin(e,function(e){return o.angleDist(t,e)})]}function D(t,e,r){return e?(t.attr(\"display\",null),t.attr(r)):t&&t.attr(\"display\",\"none\"),t}function R(t,e){return\"translate(\"+t+\",\"+e+\")\"}function F(t){return\"rotate(\"+t+\")\"}e.exports=function(t,e){return new P(t,e)},O.plot=function(t,e){var r=e[this.id];this._hasClipOnAxisFalse=!1;for(var n=0;n<t.length;n++){if(!1===t[n][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(e,r),this.updateLayout(e,r),c.generalUpdatePerTraceModule(this.gd,this,t,r),this.updateFx(e,r)},O.updateLayers=function(t,e){var r=this.layers,i=e.radialaxis,a=e.angularaxis,o=A.layerNames,s=o.indexOf(\"frontplot\"),l=o.slice(0,s),c=\"below traces\"===a.layer,u=\"below traces\"===i.layer;c&&l.push(\"angular-line\"),u&&l.push(\"radial-line\"),c&&l.push(\"angular-axis\"),u&&l.push(\"radial-axis\"),l.push(\"frontplot\"),c||l.push(\"angular-line\"),u||l.push(\"radial-line\"),c||l.push(\"angular-axis\"),u||l.push(\"radial-axis\");var h=this.framework.selectAll(\".polarsublayer\").data(l,String);h.enter().append(\"g\").attr(\"class\",function(t){return\"polarsublayer \"+t}).each(function(t){var e=r[t]=n.select(this);switch(t){case\"frontplot\":e.append(\"g\").classed(\"barlayer\",!0),e.append(\"g\").classed(\"scatterlayer\",!0);break;case\"backplot\":e.append(\"g\").classed(\"maplayer\",!0);break;case\"plotbg\":r.bg=e.append(\"path\");break;case\"radial-grid\":case\"angular-grid\":e.style(\"fill\",\"none\");break;case\"radial-line\":e.append(\"line\").style(\"fill\",\"none\");break;case\"angular-line\":e.append(\"path\").style(\"fill\",\"none\")}}),h.order()},O.updateLayout=function(t,e){var r=this.layers,n=t._size,i=e.radialaxis,a=e.angularaxis,o=e.domain.x,c=e.domain.y;this.xOffset=n.l+n.w*o[0],this.yOffset=n.t+n.h*(1-c[1]);var u=this.xLength=n.w*(o[1]-o[0]),h=this.yLength=n.h*(c[1]-c[0]),f=e.sector;this.sectorInRad=f.map(C);var p,d,g,v,m,y=this.sectorBBox=function(t){var e,r,n,i,a=t[0],o=t[1]-a,s=E(a,360),l=s+o,c=Math.cos(C(s)),u=Math.sin(C(s)),h=Math.cos(C(l)),f=Math.sin(C(l));i=s<=90&&l>=90||s>90&&l>=450?1:u<=0&&f<=0?0:Math.max(u,f);e=s<=180&&l>=180||s>180&&l>=540?-1:c>=0&&h>=0?0:Math.min(c,h);r=s<=270&&l>=270||s>270&&l>=630?-1:u>=0&&f>=0?0:Math.min(u,f);n=l>=360?1:c<=0&&h<=0?0:Math.max(c,h);return[e,r,n,i]}(f),x=y[2]-y[0],b=y[3]-y[1],_=h/u,w=Math.abs(b/x);_>w?(p=u,m=(h-(d=u*w))/n.h/2,g=[o[0],o[1]],v=[c[0]+m,c[1]-m]):(d=h,m=(u-(p=h/w))/n.w/2,g=[o[0]+m,o[1]-m],v=[c[0],c[1]]),this.xLength2=p,this.yLength2=d,this.xDomain2=g,this.yDomain2=v;var k=this.xOffset2=n.l+n.w*g[0],T=this.yOffset2=n.t+n.h*(1-v[1]),A=this.radius=p/x,M=this.innerRadius=e.hole*A,S=this.cx=k-A*y[0],L=this.cy=T+A*y[3],P=this.cxx=S-k,O=this.cyy=L-T;this.radialAxis=this.mockAxis(t,e,i,{_id:\"x\",side:{counterclockwise:\"top\",clockwise:\"bottom\"}[i.side],domain:[M/n.w,A/n.w]}),this.angularAxis=this.mockAxis(t,e,a,{side:\"right\",domain:[0,Math.PI],autorange:!1}),this.doAutoRange(t,e),this.updateAngularAxis(t,e),this.updateRadialAxis(t,e),this.updateRadialAxisTitle(t,e),this.xaxis=this.mockCartesianAxis(t,e,{_id:\"x\",domain:g}),this.yaxis=this.mockCartesianAxis(t,e,{_id:\"y\",domain:v});var z=this.pathSubplot();this.clipPaths.forTraces.select(\"path\").attr(\"d\",z).attr(\"transform\",R(P,O)),r.frontplot.attr(\"transform\",R(k,T)).call(l.setClipUrl,this._hasClipOnAxisFalse?null:this.clipIds.forTraces,this.gd),r.bg.attr(\"d\",z).attr(\"transform\",R(S,L)).call(s.fill,e.bgcolor)},O.mockAxis=function(t,e,r,n){var i=o.extendFlat({anchor:\"free\",position:0},r,n);return f(i,e,t),i},O.mockCartesianAxis=function(t,e,r){var n=this,i=r._id,a=o.extendFlat({type:\"linear\"},r);h(a,t);var s={x:[0,2],y:[1,3]};return a.setRange=function(){var t=n.sectorBBox,r=s[i],o=n.radialAxis._rl,l=(o[1]-o[0])/(1-e.hole);a.range=[t[r[0]]*l,t[r[1]]*l]},a.isPtWithinRange=\"x\"===i?function(t){return n.isPtInside(t)}:function(){return!0},a.setRange(),a.setScale(),a},O.doAutoRange=function(t,e){var r=this.gd,n=this.radialAxis,i=e.radialaxis;n.setScale(),p(r,n);var a=n.range;i.range=a.slice(),i._input.range=a.slice(),n._rl=[n.r2l(a[0],null,\"gregorian\"),n.r2l(a[1],null,\"gregorian\")]},O.updateRadialAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,l=r.innerRadius,c=r.cx,h=r.cy,f=e.radialaxis,p=E(e.sector[0],360),d=r.radialAxis,g=l<a;r.fillViewInitialKey(\"radialaxis.angle\",f.angle),r.fillViewInitialKey(\"radialaxis.range\",d.range.slice()),d.setGeometry(),\"auto\"===d.tickangle&&p>90&&p<=270&&(d.tickangle=180);var v=function(t){return\"translate(\"+(d.l2p(t.x)+l)+\",0)\"},m=z(f);if(r.radialTickLayout!==m&&(i[\"radial-axis\"].selectAll(\".xtick\").remove(),r.radialTickLayout=m),g){d.setScale();var y=u.calcTicks(d),x=u.clipEnds(d,y),b=u.getTickSigns(d)[2];u.drawTicks(n,d,{vals:y,layer:i[\"radial-axis\"],path:u.makeTickPath(d,0,b),transFn:v,crisp:!1}),u.drawGrid(n,d,{vals:x,layer:i[\"radial-grid\"],path:function(t){return r.pathArc(d.r2p(t.x)+l)},transFn:o.noop,crisp:!1}),u.drawLabels(n,d,{vals:y,layer:i[\"radial-axis\"],transFn:v,labelFns:u.makeLabelFns(d,0)})}var _=r.radialAxisAngle=r.vangles?L(I(C(f.angle),r.vangles)):f.angle,w=R(c,h),k=w+F(-_);D(i[\"radial-axis\"],g&&(f.showticklabels||f.ticks),{transform:k}),D(i[\"radial-grid\"],g&&f.showgrid,{transform:w}),D(i[\"radial-line\"].select(\"line\"),g&&f.showline,{x1:l,y1:0,x2:a,y2:0,transform:k}).attr(\"stroke-width\",f.linewidth).call(s.stroke,f.linecolor)},O.updateRadialAxisTitle=function(t,e,r){var n=this.gd,i=this.radius,a=this.cx,o=this.cy,s=e.radialaxis,c=this.id+\"title\",u=void 0!==r?r:this.radialAxisAngle,h=C(u),f=Math.cos(h),p=Math.sin(h),d=0;if(s.title){var g=l.bBox(this.layers[\"radial-axis\"].node()).height,v=s.title.font.size;d=\"counterclockwise\"===s.side?-g-.4*v:g+.8*v}this.layers[\"radial-axis-title\"]=m.draw(n,c,{propContainer:s,propName:this.id+\".radialaxis.title\",placeholder:S(n,\"Click to enter radial axis title\"),attributes:{x:a+i/2*f+d*p,y:o-i/2*p+d*f,\"text-anchor\":\"middle\"},transform:{rotate:-u}})},O.updateAngularAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,l=r.innerRadius,c=r.cx,h=r.cy,f=e.angularaxis,p=r.angularAxis;r.fillViewInitialKey(\"angularaxis.rotation\",f.rotation),p.setGeometry(),p.setScale();var d=function(t){return p.t2g(t.x)};\"linear\"===p.type&&\"radians\"===p.thetaunit&&(p.tick0=L(p.tick0),p.dtick=L(p.dtick));var g=function(t){return R(c+a*Math.cos(t),h-a*Math.sin(t))},v=u.makeLabelFns(p,0).labelStandoff,m={xFn:function(t){var e=d(t);return Math.cos(e)*v},yFn:function(t){var e=d(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(v+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*T)},anchorFn:function(t){var e=d(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},heightFn:function(t,e,r){var n=d(t);return-.5*(1+Math.sin(n))*r}},y=z(f);r.angularTickLayout!==y&&(i[\"angular-axis\"].selectAll(\".\"+p._id+\"tick\").remove(),r.angularTickLayout=y);var x,b=u.calcTicks(p);if(\"linear\"===e.gridshape?(x=b.map(d),o.angleDelta(x[0],x[1])<0&&(x=x.slice().reverse())):x=null,r.vangles=x,\"category\"===p.type&&(b=b.filter(function(t){return o.isAngleInsideSector(d(t),r.sectorInRad)})),p.visible){var _=\"inside\"===p.ticks?-1:1,w=(p.linewidth||1)/2;u.drawTicks(n,p,{vals:b,layer:i[\"angular-axis\"],path:\"M\"+_*w+\",0h\"+_*p.ticklen,transFn:function(t){var e=d(t);return g(e)+F(-L(e))},crisp:!1}),u.drawGrid(n,p,{vals:b,layer:i[\"angular-grid\"],path:function(t){var e=d(t),r=Math.cos(e),n=Math.sin(e);return\"M\"+[c+l*r,h-l*n]+\"L\"+[c+a*r,h-a*n]},transFn:o.noop,crisp:!1}),u.drawLabels(n,p,{vals:b,layer:i[\"angular-axis\"],repositionOnUpdate:!0,transFn:function(t){return g(d(t))},labelFns:m})}D(i[\"angular-line\"].select(\"path\"),f.showline,{d:r.pathSubplot(),transform:R(c,h)}).attr(\"stroke-width\",f.linewidth).call(s.stroke,f.linecolor)},O.updateFx=function(t,e){this.gd._context.staticPlot||(this.updateAngularDrag(t),this.updateRadialDrag(t,e,0),this.updateRadialDrag(t,e,1),this.updateMainDrag(t))},O.updateMainDrag=function(t){var e=this,r=e.gd,o=e.layers,s=t._zoomlayer,l=A.MINZOOM,c=A.OFFEDGE,u=e.radius,h=e.innerRadius,f=e.cx,p=e.cy,m=e.cxx,_=e.cyy,w=e.sectorInRad,k=e.vangles,T=e.radialAxis,S=M.clampTiny,E=M.findXYatLength,C=M.findEnclosingVertexAngles,L=A.cornerHalfWidth,P=A.cornerLen/2,O=d.makeDragger(o,\"path\",\"maindrag\",\"crosshair\");n.select(O).attr(\"d\",e.pathSubplot()).attr(\"transform\",R(f,p));var z,I,D,F,B,N,j,U,V,q={element:O,gd:r,subplot:e.id,plotinfo:{id:e.id,xaxis:e.xaxis,yaxis:e.yaxis},xaxes:[e.xaxis],yaxes:[e.yaxis]};function H(t,e){return Math.sqrt(t*t+e*e)}function G(t,e){return H(t-m,e-_)}function Y(t,e){return Math.atan2(_-e,t-m)}function W(t,e){return[t*Math.cos(e),t*Math.sin(-e)]}function X(t,r){if(0===t)return e.pathSector(2*L);var n=P/t,i=r-n,a=r+n,o=Math.max(0,Math.min(t,u)),s=o-L,l=o+L;return\"M\"+W(s,i)+\"A\"+[s,s]+\" 0,0,0 \"+W(s,a)+\"L\"+W(l,a)+\"A\"+[l,l]+\" 0,0,1 \"+W(l,i)+\"Z\"}function Z(t,r,n){if(0===t)return e.pathSector(2*L);var i,a,o=W(t,r),s=W(t,n),l=S((o[0]+s[0])/2),c=S((o[1]+s[1])/2);if(l&&c){var u=c/l,h=-1/u,f=E(L,u,l,c);i=E(P,h,f[0][0],f[0][1]),a=E(P,h,f[1][0],f[1][1])}else{var p,d;c?(p=P,d=L):(p=L,d=P),i=[[l-p,c-d],[l+p,c-d]],a=[[l-p,c+d],[l+p,c+d]]}return\"M\"+i.join(\"L\")+\"L\"+a.reverse().join(\"L\")+\"Z\"}function J(t,e){return e=Math.max(Math.min(e,u),h),t<c?t=0:u-t<c?t=u:e<c?e=0:u-e<c&&(e=u),Math.abs(e-t)>l?(t<e?(D=t,F=e):(D=e,F=t),!0):(D=null,F=null,!1)}function K(t,e){t=t||B,e=e||\"M0,0Z\",U.attr(\"d\",t),V.attr(\"d\",e),d.transitionZoombox(U,V,N,j),N=!0;var n={};rt(n),r.emit(\"plotly_relayouting\",n)}function $(t,r){var n,i,a=z+t,o=I+r,s=G(z,I),l=Math.min(G(a,o),u),c=Y(z,I);J(s,l)&&(n=B+e.pathSector(F),D&&(n+=e.pathSector(D)),i=X(D,c)+X(F,c)),K(n,i)}function Q(t,e,r,n){var i=M.findIntersectionXY(r,n,r,[t-m,_-e]);return H(i[0],i[1])}function tt(t,r){var n,i,a=z+t,o=I+r,s=Y(z,I),l=Y(a,o),c=C(s,k),h=C(l,k);J(Q(z,I,c[0],c[1]),Math.min(Q(a,o,h[0],h[1]),u))&&(n=B+e.pathSector(F),D&&(n+=e.pathSector(D)),i=[Z(D,c[0],c[1]),Z(F,c[0],c[1])].join(\" \")),K(n,i)}function et(){if(d.removeZoombox(r),null!==D&&null!==F){var t={};rt(t),d.showDoubleClickNotifier(r),a.call(\"_guiRelayout\",r,t)}}function rt(t){var r=T._rl,n=(r[1]-r[0])/(1-h/u)/u,i=[r[0]+(D-h)*n,r[0]+(F-h)*n];t[e.id+\".radialaxis.range\"]=i}function nt(t,n){var i=r._fullLayout.clickmode;if(d.removeZoombox(r),2===t){var o={};for(var s in e.viewInitial)o[e.id+\".\"+s]=e.viewInitial[s];r.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",r,o)}i.indexOf(\"select\")>-1&&1===t&&x(n,r,[e.xaxis],[e.yaxis],e.id,q),i.indexOf(\"event\")>-1&&v.click(r,n,e.id)}q.prepFn=function(t,n,a){var o=r._fullLayout.dragmode,l=O.getBoundingClientRect();if(z=n-l.left,I=a-l.top,k){var c=M.findPolygonOffset(u,w[0],w[1],k);z+=m+c[0],I+=_+c[1]}switch(o){case\"zoom\":q.moveFn=k?tt:$,q.clickFn=nt,q.doneFn=et,function(){D=null,F=null,B=e.pathSubplot(),N=!1;var t=r._fullLayout[e.id];j=i(t.bgcolor).getLuminance(),(U=d.makeZoombox(s,j,f,p,B)).attr(\"fill-rule\",\"evenodd\"),V=d.makeCorners(s,f,p),b(r)}();break;case\"select\":case\"lasso\":y(t,n,a,q,o)}},O.onmousemove=function(t){v.hover(r,t,e.id),r._fullLayout._lasthover=O,r._fullLayout._hoversubplot=e.id},O.onmouseout=function(t){r._dragging||g.unhover(r,t)},g.init(q)},O.updateRadialDrag=function(t,e,r){var i=this,s=i.gd,l=i.layers,c=i.radius,u=i.innerRadius,h=i.cx,f=i.cy,p=i.radialAxis,v=A.radialDragBoxSize,m=v/2;if(p.visible){var y,x,_,T=C(i.radialAxisAngle),M=p._rl,S=M[0],E=M[1],P=M[r],O=.75*(M[1]-M[0])/(1-e.hole)/c;r?(y=h+(c+m)*Math.cos(T),x=f-(c+m)*Math.sin(T),_=\"radialdrag\"):(y=h+(u-m)*Math.cos(T),x=f-(u-m)*Math.sin(T),_=\"radialdrag-inner\");var z,B,N,j=d.makeRectDragger(l,_,\"crosshair\",-m,-m,v,v),U={element:j,gd:s};D(n.select(j),p.visible&&u<c,{transform:R(y,x)}),U.prepFn=function(){z=null,B=null,N=null,U.moveFn=V,U.doneFn=q,b(s)},U.clampFn=function(t,e){return Math.sqrt(t*t+e*e)<A.MINDRAG&&(t=0,e=0),[t,e]},g.init(U)}function V(t,e){if(z)z(t,e);else{var n=[t,-e],a=[Math.cos(T),Math.sin(T)],l=Math.abs(o.dot(n,a)/Math.sqrt(o.dot(n,n)));isNaN(l)||(z=l<.5?H:G)}var c={};!function(t){null!==B?t[i.id+\".radialaxis.angle\"]=B:null!==N&&(t[i.id+\".radialaxis.range[\"+r+\"]\"]=N)}(c),s.emit(\"plotly_relayouting\",c)}function q(){null!==B?a.call(\"_guiRelayout\",s,i.id+\".radialaxis.angle\",B):null!==N&&a.call(\"_guiRelayout\",s,i.id+\".radialaxis.range[\"+r+\"]\",N)}function H(t,e){if(0!==r){var n=y+t,a=x+e;B=Math.atan2(f-a,n-h),i.vangles&&(B=I(B,i.vangles)),B=L(B);var o=R(h,f)+F(-B);l[\"radial-axis\"].attr(\"transform\",o),l[\"radial-line\"].select(\"line\").attr(\"transform\",o);var s=i.gd._fullLayout,c=s[i.id];i.updateRadialAxisTitle(s,c,B)}}function G(t,e){var n=o.dot([t,-e],[Math.cos(T),Math.sin(T)]);if(N=P-O*n,O>0==(r?N>S:N<E)){var l=s._fullLayout,c=l[i.id];p.range[r]=N,p._rl[r]=N,i.updateRadialAxis(l,c),i.xaxis.setRange(),i.xaxis.setScale(),i.yaxis.setRange(),i.yaxis.setScale();var u=!1;for(var h in i.traceHash){var f=i.traceHash[h],d=o.filterVisible(f);f[0][0].trace._module.plot(s,i,d,c),a.traceIs(h,\"gl\")&&d.length&&(u=!0)}u&&(w(s),k(s))}else N=null}},O.updateAngularDrag=function(t){var e=this,r=e.gd,i=e.layers,s=e.radius,c=e.angularAxis,u=e.cx,h=e.cy,f=e.cxx,p=e.cyy,v=A.angularDragBoxSize,m=d.makeDragger(i,\"path\",\"angulardrag\",\"move\"),y={element:m,gd:r};function x(t,e){return Math.atan2(p+v-e,t-f-v)}n.select(m).attr(\"d\",e.pathAnnulus(s,s+v)).attr(\"transform\",R(u,h)).call(_,\"move\");var T,M,S,E,C,P,O=i.frontplot.select(\".scatterlayer\").selectAll(\".trace\"),z=O.selectAll(\".point\"),I=O.selectAll(\".textpoint\");function D(t,s){var d=e.gd._fullLayout,g=d[e.id],v=x(T+t,M+s),m=L(v-P);if(E=S+m,i.frontplot.attr(\"transform\",R(e.xOffset2,e.yOffset2)+F([-m,f,p])),e.vangles){C=e.radialAxisAngle+m;var y=R(u,h)+F(-m),b=R(u,h)+F(-C);i.bg.attr(\"transform\",y),i[\"radial-grid\"].attr(\"transform\",y),i[\"radial-axis\"].attr(\"transform\",b),i[\"radial-line\"].select(\"line\").attr(\"transform\",b),e.updateRadialAxisTitle(d,g,C)}else e.clipPaths.forTraces.select(\"path\").attr(\"transform\",R(f,p)+F(m));z.each(function(){var t=n.select(this),e=l.getTranslate(t);t.attr(\"transform\",R(e.x,e.y)+F([m]))}),I.each(function(){var t=n.select(this),e=t.select(\"text\"),r=l.getTranslate(t);t.attr(\"transform\",F([m,e.attr(\"x\"),e.attr(\"y\")])+R(r.x,r.y))}),c.rotation=o.modHalf(E,360),e.updateAngularAxis(d,g),e._hasClipOnAxisFalse&&!o.isFullCircle(e.sectorInRad)&&O.call(l.hideOutsideRangePoints,e);var _=!1;for(var A in e.traceHash)if(a.traceIs(A,\"gl\")){var D=e.traceHash[A],N=o.filterVisible(D);D[0][0].trace._module.plot(r,e,N,g),N.length&&(_=!0)}_&&(w(r),k(r));var j={};B(j),r.emit(\"plotly_relayouting\",j)}function B(t){t[e.id+\".angularaxis.rotation\"]=E,e.vangles&&(t[e.id+\".radialaxis.angle\"]=C)}function N(){I.select(\"text\").attr(\"transform\",null);var t={};B(t),a.call(\"_guiRelayout\",r,t)}y.prepFn=function(n,i,a){var o=t[e.id];S=o.angularaxis.rotation;var s=m.getBoundingClientRect();T=i-s.left,M=a-s.top,P=x(T,M),y.moveFn=D,y.doneFn=N,b(r)},e.vangles&&!o.isFullCircle(e.sectorInRad)&&(y.prepFn=o.noop,_(n.select(m),null)),g.init(y)},O.isPtInside=function(t){var e=this.sectorInRad,r=this.vangles,n=this.angularAxis.c2g(t.theta),i=this.radialAxis,a=i.c2l(t.r),s=i._rl;return(r?M.isPtInsidePolygon:o.isPtInsideSector)(a,n,s,e,r)},O.pathArc=function(t){var e=this.sectorInRad,r=this.vangles;return(r?M.pathPolygon:o.pathArc)(t,e[0],e[1],r)},O.pathSector=function(t){var e=this.sectorInRad,r=this.vangles;return(r?M.pathPolygon:o.pathSector)(t,e[0],e[1],r)},O.pathAnnulus=function(t,e){var r=this.sectorInRad,n=this.vangles;return(n?M.pathPolygonAnnulus:o.pathAnnulus)(t,e,r[0],r[1],n)},O.pathSubplot=function(){var t=this.innerRadius,e=this.radius;return t?this.pathAnnulus(t,e):this.pathSector(e)},O.fillViewInitialKey=function(t,e){t in this.viewInitial||(this.viewInitial[t]=e)}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../components/titles\":681,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/clear_gl_canvases\":704,\"../../lib/setcursor\":739,\"../../plot_api/subroutines\":758,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../cartesian/autorange\":766,\"../cartesian/dragbox\":775,\"../cartesian/select\":784,\"../cartesian/set_convert\":785,\"../plots\":828,\"./constants\":829,\"./helpers\":830,\"./set_convert\":841,d3:163,tinycolor2:537}],841:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../cartesian/set_convert\"),a=n.deg2rad,o=n.rad2deg;e.exports=function(t,e,r){switch(i(t,r),t._id){case\"x\":case\"radialaxis\":!function(t,e){var r=e._subplot;t.setGeometry=function(){var e=t._rl[0],n=t._rl[1],i=r.innerRadius,a=(r.radius-i)/(n-e),o=i/a,s=e>n?function(t){return t<=0}:function(t){return t>=0};t.c2g=function(r){var n=t.c2l(r)-e;return(s(n)?n:0)+o},t.g2c=function(r){return t.l2c(r+e-o)},t.g2p=function(t){return t*a},t.c2p=function(e){return t.g2p(t.c2g(e))}}}(t,e);break;case\"angularaxis\":!function(t,e){var r=t.type;if(\"linear\"===r){var i=t.d2c,s=t.c2d;t.d2c=function(t,e){return function(t,e){return\"degrees\"===e?a(t):t}(i(t),e)},t.c2d=function(t,e){return s(function(t,e){return\"degrees\"===e?o(t):t}(t,e))}}t.makeCalcdata=function(e,i){var a,o,s=e[i],l=e._length,c=function(r){return t.d2c(r,e.thetaunit)};if(s){if(n.isTypedArray(s)&&\"linear\"===r){if(l===s.length)return s;if(s.subarray)return s.subarray(0,l)}for(a=new Array(l),o=0;o<l;o++)a[o]=c(s[o])}else{var u=i+\"0\",h=\"d\"+i,f=u in e?c(e[u]):0,p=e[h]?c(e[h]):(t.period||2*Math.PI)/l;for(a=new Array(l),o=0;o<l;o++)a[o]=f+o*p}return a},t.setGeometry=function(){var i,s,l,c,u=e.sector,h=u.map(a),f={clockwise:-1,counterclockwise:1}[t.direction],p=a(t.rotation),d=function(t){return f*t+p},g=function(t){return(t-p)/f};switch(r){case\"linear\":s=i=n.identity,c=a,l=o,t.range=n.isFullCircle(h)?[u[0],u[0]+360]:h.map(g).map(o);break;case\"category\":var v=t._categories.length,m=t.period?Math.max(t.period,v):v;0===m&&(m=1),s=c=function(t){return 2*t*Math.PI/m},i=l=function(t){return t*m/Math.PI/2},t.range=[0,m]}t.c2g=function(t){return d(s(t))},t.g2c=function(t){return i(g(t))},t.t2g=function(t){return d(c(t))},t.g2t=function(t){return l(g(t))}}}(t,e)}}},{\"../../lib\":719,\"../cartesian/set_convert\":785}],842:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\"),a=t(\"./domain\").defaults;e.exports=function(t,e,r,o){var s,l,c=o.type,u=o.attributes,h=o.handleDefaults,f=o.partition||\"x\",p=e._subplots[c],d=p.length,g=d&&p[0].replace(/\\d+$/,\"\");function v(t,e){return n.coerce(s,l,u,t,e)}for(var m=0;m<d;m++){var y=p[m];s=t[y]?t[y]:t[y]={},l=i.newContainer(e,y,g),v(\"uirevision\",e.uirevision);var x={};x[f]=[m/d,(m+1)/d],a(l,e,v,x),o.id=y,h(s,l,v,o)}}},{\"../lib\":719,\"../plot_api/plot_template\":757,\"./domain\":792}],843:[function(t,e,r){\"use strict\";var n=t(\"./ternary\"),i=t(\"../../plots/get_data\").getSubplotCalcData,a=t(\"../../lib\").counterRegex;r.name=\"ternary\";var o=r.attr=\"subplot\";r.idRoot=\"ternary\",r.idRegex=r.attrRegex=a(\"ternary\"),(r.attributes={})[o]={valType:\"subplotid\",dflt:\"ternary\",editType:\"calc\"},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t.calcdata,a=e._subplots.ternary,o=0;o<a.length;o++){var s=a[o],l=i(r,\"ternary\",s),c=e[s]._subplot;c||(c=new n({id:s,graphDiv:t,container:e._ternarylayer.node()},e),e[s]._subplot=c),c.plot(l,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.ternary||[],a=0;a<i.length;a++){var o=i[a],s=n[o]._subplot;!e[o]&&s&&(s.plotContainer.remove(),s.clipDef.remove(),s.clipDefRelative.remove(),s.layers[\"a-title\"].remove(),s.layers[\"b-title\"].remove(),s.layers[\"c-title\"].remove())}}},{\"../../lib\":719,\"../../plots/get_data\":802,\"./layout_attributes\":844,\"./layout_defaults\":845,\"./ternary\":846}],844:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"../cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../lib/extend\").extendFlat,l={title:a.title,color:a.color,tickmode:a.tickmode,nticks:s({},a.nticks,{dflt:6,min:1}),tick0:a.tick0,dtick:a.dtick,tickvals:a.tickvals,ticktext:a.ticktext,ticks:a.ticks,ticklen:a.ticklen,tickwidth:a.tickwidth,tickcolor:a.tickcolor,showticklabels:a.showticklabels,showtickprefix:a.showtickprefix,tickprefix:a.tickprefix,showticksuffix:a.showticksuffix,ticksuffix:a.ticksuffix,showexponent:a.showexponent,exponentformat:a.exponentformat,separatethousands:a.separatethousands,tickfont:a.tickfont,tickangle:a.tickangle,tickformat:a.tickformat,tickformatstops:a.tickformatstops,hoverformat:a.hoverformat,showline:s({},a.showline,{dflt:!0}),linecolor:a.linecolor,linewidth:a.linewidth,showgrid:s({},a.showgrid,{dflt:!0}),gridcolor:a.gridcolor,gridwidth:a.gridwidth,layer:a.layer,min:{valType:\"number\",dflt:0,min:0},_deprecated:{title:a._deprecated.title,titlefont:a._deprecated.titlefont}},c=e.exports=o({domain:i({name:\"ternary\"}),bgcolor:{valType:\"color\",dflt:n.background},sum:{valType:\"number\",dflt:1,min:0},aaxis:l,baxis:l,caxis:l},\"plot\",\"from-root\");c.uirevision={valType:\"any\",editType:\"none\"},c.aaxis.uirevision=c.baxis.uirevision=c.caxis.uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":592,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../cartesian/layout_attributes\":779,\"../domain\":792}],845:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../lib\"),o=t(\"../subplot_defaults\"),s=t(\"../cartesian/tick_label_defaults\"),l=t(\"../cartesian/tick_mark_defaults\"),c=t(\"../cartesian/tick_value_defaults\"),u=t(\"../cartesian/line_grid_defaults\"),h=t(\"./layout_attributes\"),f=[\"aaxis\",\"baxis\",\"caxis\"];function p(t,e,r,a){var o,s,l,c=r(\"bgcolor\"),u=r(\"sum\");a.bgColor=n.combine(c,a.paper_bgcolor);for(var h=0;h<f.length;h++)s=t[o=f[h]]||{},(l=i.newContainer(e,o))._name=o,d(s,l,a,e);var p=e.aaxis,g=e.baxis,v=e.caxis;p.min+g.min+v.min>=u&&(p.min=0,g.min=0,v.min=0,t.aaxis&&delete t.aaxis.min,t.baxis&&delete t.baxis.min,t.caxis&&delete t.caxis.min)}function d(t,e,r,n){var i=h[e._name];function o(r,n){return a.coerce(t,e,i,r,n)}o(\"uirevision\",n.uirevision),e.type=\"linear\";var f=o(\"color\"),p=f!==i.color.dflt?f:r.font.color,d=e._name.charAt(0).toUpperCase(),g=\"Component \"+d,v=o(\"title.text\",g);e._hovertitle=v===g?v:d,a.coerceFont(o,\"title.font\",{family:r.font.family,size:Math.round(1.2*r.font.size),color:p}),o(\"min\"),c(t,e,o,\"linear\"),s(t,e,o,\"linear\",{}),l(t,e,o,{outerTicks:!0}),o(\"showticklabels\")&&(a.coerceFont(o,\"tickfont\",{family:r.font.family,size:r.font.size,color:p}),o(\"tickangle\"),o(\"tickformat\")),u(t,e,o,{dfltColor:f,bgColor:r.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:i}),o(\"hoverformat\"),o(\"layer\")}e.exports=function(t,e,r){o(t,e,r,{type:\"ternary\",attributes:h,handleDefaults:p,font:e.font,paper_bgcolor:e.paper_bgcolor})}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../cartesian/line_grid_defaults\":781,\"../cartesian/tick_label_defaults\":786,\"../cartesian/tick_mark_defaults\":787,\"../cartesian/tick_value_defaults\":788,\"../subplot_defaults\":842,\"./layout_attributes\":844}],846:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=o._,l=t(\"../../components/color\"),c=t(\"../../components/drawing\"),u=t(\"../cartesian/set_convert\"),h=t(\"../../lib/extend\").extendFlat,f=t(\"../plots\"),p=t(\"../cartesian/axes\"),d=t(\"../../components/dragelement\"),g=t(\"../../components/fx\"),v=t(\"../../components/titles\"),m=t(\"../cartesian/select\").prepSelect,y=t(\"../cartesian/select\").selectOnClick,x=t(\"../cartesian/select\").clearSelect,b=t(\"../cartesian/constants\");function _(t,e){this.id=t.id,this.graphDiv=t.graphDiv,this.init(e),this.makeFramework(e),this.aTickLayout=null,this.bTickLayout=null,this.cTickLayout=null}e.exports=_;var w=_.prototype;w.init=function(t){this.container=t._ternarylayer,this.defs=t._defs,this.layoutId=t._uid,this.traceHash={},this.layers={}},w.plot=function(t,e){var r=e[this.id],n=e._size;this._hasClipOnAxisFalse=!1;for(var i=0;i<t.length;i++){if(!1===t[i][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(r),this.adjustLayout(r,n),f.generalUpdatePerTraceModule(this.graphDiv,this,t,r),this.layers.plotbg.select(\"path\").call(l.fill,r.bgcolor)},w.makeFramework=function(t){var e=this.graphDiv,r=t[this.id],n=this.clipId=\"clip\"+this.layoutId+this.id,i=this.clipIdRelative=\"clip-relative\"+this.layoutId+this.id;this.clipDef=o.ensureSingleById(t._clips,\"clipPath\",n,function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")}),this.clipDefRelative=o.ensureSingleById(t._clips,\"clipPath\",i,function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")}),this.plotContainer=o.ensureSingle(this.container,\"g\",this.id),this.updateLayers(r),c.setClipUrl(this.layers.backplot,n,e),c.setClipUrl(this.layers.grids,n,e)},w.updateLayers=function(t){var e=this.layers,r=[\"draglayer\",\"plotbg\",\"backplot\",\"grids\"];\"below traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"below traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"below traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\"),r.push(\"frontplot\"),\"above traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"above traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"above traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\");var i=this.plotContainer.selectAll(\"g.toplevel\").data(r,String),a=[\"agrid\",\"bgrid\",\"cgrid\"];i.enter().append(\"g\").attr(\"class\",function(t){return\"toplevel \"+t}).each(function(t){var r=n.select(this);e[t]=r,\"frontplot\"===t?r.append(\"g\").classed(\"scatterlayer\",!0):\"backplot\"===t?r.append(\"g\").classed(\"maplayer\",!0):\"plotbg\"===t?r.append(\"path\").attr(\"d\",\"M0,0Z\"):\"aline\"===t||\"bline\"===t||\"cline\"===t?r.append(\"path\"):\"grids\"===t&&a.forEach(function(t){e[t]=r.append(\"g\").classed(\"grid \"+t,!0)})}),i.order()};var k=Math.sqrt(4/3);w.adjustLayout=function(t,e){var r,n,i,a,o,s,f=this,p=t.domain,d=(p.x[0]+p.x[1])/2,g=(p.y[0]+p.y[1])/2,v=p.x[1]-p.x[0],m=p.y[1]-p.y[0],y=v*e.w,x=m*e.h,b=t.sum,_=t.aaxis.min,w=t.baxis.min,T=t.caxis.min;y>k*x?i=(a=x)*k:a=(i=y)/k,o=v*i/y,s=m*a/x,r=e.l+e.w*d-i/2,n=e.t+e.h*(1-g)-a/2,f.x0=r,f.y0=n,f.w=i,f.h=a,f.sum=b,f.xaxis={type:\"linear\",range:[_+2*T-b,b-_-2*w],domain:[d-o/2,d+o/2],_id:\"x\"},u(f.xaxis,f.graphDiv._fullLayout),f.xaxis.setScale(),f.xaxis.isPtWithinRange=function(t){return t.a>=f.aaxis.range[0]&&t.a<=f.aaxis.range[1]&&t.b>=f.baxis.range[1]&&t.b<=f.baxis.range[0]&&t.c>=f.caxis.range[1]&&t.c<=f.caxis.range[0]},f.yaxis={type:\"linear\",range:[_,b-w-T],domain:[g-s/2,g+s/2],_id:\"y\"},u(f.yaxis,f.graphDiv._fullLayout),f.yaxis.setScale(),f.yaxis.isPtWithinRange=function(){return!0};var A=f.yaxis.domain[0],M=f.aaxis=h({},t.aaxis,{range:[_,b-w-T],side:\"left\",tickangle:(+t.aaxis.tickangle||0)-30,domain:[A,A+s*k],anchor:\"free\",position:0,_id:\"y\",_length:i});u(M,f.graphDiv._fullLayout),M.setScale();var S=f.baxis=h({},t.baxis,{range:[b-_-T,w],side:\"bottom\",domain:f.xaxis.domain,anchor:\"free\",position:0,_id:\"x\",_length:i});u(S,f.graphDiv._fullLayout),S.setScale();var E=f.caxis=h({},t.caxis,{range:[b-_-w,T],side:\"right\",tickangle:(+t.caxis.tickangle||0)+30,domain:[A,A+s*k],anchor:\"free\",position:0,_id:\"y\",_length:i});u(E,f.graphDiv._fullLayout),E.setScale();var C=\"M\"+r+\",\"+(n+a)+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";f.clipDef.select(\"path\").attr(\"d\",C),f.layers.plotbg.select(\"path\").attr(\"d\",C);var L=\"M0,\"+a+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";f.clipDefRelative.select(\"path\").attr(\"d\",L);var P=\"translate(\"+r+\",\"+n+\")\";f.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",P),f.clipDefRelative.select(\"path\").attr(\"transform\",null);var O=\"translate(\"+(r-S._offset)+\",\"+(n+a)+\")\";f.layers.baxis.attr(\"transform\",O),f.layers.bgrid.attr(\"transform\",O);var z=\"translate(\"+(r+i/2)+\",\"+n+\")rotate(30)translate(0,\"+-M._offset+\")\";f.layers.aaxis.attr(\"transform\",z),f.layers.agrid.attr(\"transform\",z);var I=\"translate(\"+(r+i/2)+\",\"+n+\")rotate(-30)translate(0,\"+-E._offset+\")\";f.layers.caxis.attr(\"transform\",I),f.layers.cgrid.attr(\"transform\",I),f.drawAxes(!0),f.layers.aline.select(\"path\").attr(\"d\",M.showline?\"M\"+r+\",\"+(n+a)+\"l\"+i/2+\",-\"+a:\"M0,0\").call(l.stroke,M.linecolor||\"#000\").style(\"stroke-width\",(M.linewidth||0)+\"px\"),f.layers.bline.select(\"path\").attr(\"d\",S.showline?\"M\"+r+\",\"+(n+a)+\"h\"+i:\"M0,0\").call(l.stroke,S.linecolor||\"#000\").style(\"stroke-width\",(S.linewidth||0)+\"px\"),f.layers.cline.select(\"path\").attr(\"d\",E.showline?\"M\"+(r+i/2)+\",\"+n+\"l\"+i/2+\",\"+a:\"M0,0\").call(l.stroke,E.linecolor||\"#000\").style(\"stroke-width\",(E.linewidth||0)+\"px\"),f.graphDiv._context.staticPlot||f.initInteractions(),c.setClipUrl(f.layers.frontplot,f._hasClipOnAxisFalse?null:f.clipId,f.graphDiv)},w.drawAxes=function(t){var e=this.graphDiv,r=this.id.substr(7)+\"title\",n=this.layers,i=this.aaxis,a=this.baxis,o=this.caxis;if(this.drawAx(i),this.drawAx(a),this.drawAx(o),t){var l=Math.max(i.showticklabels?i.tickfont.size/2:0,(o.showticklabels?.75*o.tickfont.size:0)+(\"outside\"===o.ticks?.87*o.ticklen:0)),c=(a.showticklabels?a.tickfont.size:0)+(\"outside\"===a.ticks?a.ticklen:0)+3;n[\"a-title\"]=v.draw(e,\"a\"+r,{propContainer:i,propName:this.id+\".aaxis.title\",placeholder:s(e,\"Click to enter Component A title\"),attributes:{x:this.x0+this.w/2,y:this.y0-i.title.font.size/3-l,\"text-anchor\":\"middle\"}}),n[\"b-title\"]=v.draw(e,\"b\"+r,{propContainer:a,propName:this.id+\".baxis.title\",placeholder:s(e,\"Click to enter Component B title\"),attributes:{x:this.x0-c,y:this.y0+this.h+.83*a.title.font.size+c,\"text-anchor\":\"middle\"}}),n[\"c-title\"]=v.draw(e,\"c\"+r,{propContainer:o,propName:this.id+\".caxis.title\",placeholder:s(e,\"Click to enter Component C title\"),attributes:{x:this.x0+this.w+c,y:this.y0+this.h+.83*o.title.font.size+c,\"text-anchor\":\"middle\"}})}},w.drawAx=function(t){var e,r=this.graphDiv,n=t._name,i=n.charAt(0),a=t._id,s=this.layers[n],l=i+\"tickLayout\",c=(e=t).ticks+String(e.ticklen)+String(e.showticklabels);this[l]!==c&&(s.selectAll(\".\"+a+\"tick\").remove(),this[l]=c),t.setScale();var u=p.calcTicks(t),h=p.clipEnds(t,u),f=p.makeTransFn(t),d=p.getTickSigns(t)[2],g=o.deg2rad(30),v=d*(t.linewidth||1)/2,m=d*t.ticklen,y=this.w,x=this.h,b=\"b\"===i?\"M0,\"+v+\"l\"+Math.sin(g)*m+\",\"+Math.cos(g)*m:\"M\"+v+\",0l\"+Math.cos(g)*m+\",\"+-Math.sin(g)*m,_={a:\"M0,0l\"+x+\",-\"+y/2,b:\"M0,0l-\"+y/2+\",-\"+x,c:\"M0,0l-\"+x+\",\"+y/2}[i];p.drawTicks(r,t,{vals:\"inside\"===t.ticks?h:u,layer:s,path:b,transFn:f,crisp:!1}),p.drawGrid(r,t,{vals:h,layer:this.layers[i+\"grid\"],path:_,transFn:f,crisp:!1}),p.drawLabels(r,t,{vals:u,layer:s,transFn:f,labelFns:p.makeLabelFns(t,0,30)})};var T=b.MINZOOM/2+.87,A=\"m-0.87,.5h\"+T+\"v3h-\"+(T+5.2)+\"l\"+(T/2+2.6)+\",-\"+(.87*T+4.5)+\"l2.6,1.5l-\"+T/2+\",\"+.87*T+\"Z\",M=\"m0.87,.5h-\"+T+\"v3h\"+(T+5.2)+\"l-\"+(T/2+2.6)+\",-\"+(.87*T+4.5)+\"l-2.6,1.5l\"+T/2+\",\"+.87*T+\"Z\",S=\"m0,1l\"+T/2+\",\"+.87*T+\"l2.6,-1.5l-\"+(T/2+2.6)+\",-\"+(.87*T+4.5)+\"l-\"+(T/2+2.6)+\",\"+(.87*T+4.5)+\"l2.6,1.5l\"+T/2+\",-\"+.87*T+\"Z\",E=\"m0.5,0.5h5v-2h-5v-5h-2v5h-5v2h5v5h2Z\",C=!0;function L(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}w.initInteractions=function(){var t,e,r,n,u,h,f,p,v,_,w=this,T=w.layers.plotbg.select(\"path\").node(),P=w.graphDiv,O=P._fullLayout._zoomlayer,z={element:T,gd:P,plotinfo:{id:w.id,xaxis:w.xaxis,yaxis:w.yaxis},subplot:w.id,prepFn:function(a,o,s){z.xaxes=[w.xaxis],z.yaxes=[w.yaxis];var c=P._fullLayout.dragmode;z.minDrag=\"lasso\"===c?1:void 0,\"zoom\"===c?(z.moveFn=N,z.clickFn=D,z.doneFn=j,function(a,o,s){var c=T.getBoundingClientRect();t=o-c.left,e=s-c.top,r={a:w.aaxis.range[0],b:w.baxis.range[1],c:w.caxis.range[1]},u=r,n=w.aaxis.range[1]-r.a,h=i(w.graphDiv._fullLayout[w.id].bgcolor).getLuminance(),f=\"M0,\"+w.h+\"L\"+w.w/2+\", 0L\"+w.w+\",\"+w.h+\"Z\",p=!1,v=O.append(\"path\").attr(\"class\",\"zoombox\").attr(\"transform\",\"translate(\"+w.x0+\", \"+w.y0+\")\").style({fill:h>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"d\",f),_=O.append(\"path\").attr(\"class\",\"zoombox-corners\").attr(\"transform\",\"translate(\"+w.x0+\", \"+w.y0+\")\").style({fill:l.background,stroke:l.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"d\",\"M0,0Z\"),x(P)}(0,o,s)):\"pan\"===c?(z.moveFn=U,z.clickFn=D,z.doneFn=V,r={a:w.aaxis.range[0],b:w.baxis.range[1],c:w.caxis.range[1]},u=r,x(P)):\"select\"!==c&&\"lasso\"!==c||m(a,o,s,z,c)}};function I(t){var e={};return e[w.id+\".aaxis.min\"]=t.a,e[w.id+\".baxis.min\"]=t.b,e[w.id+\".caxis.min\"]=t.c,e}function D(t,e){var r=P._fullLayout.clickmode;L(P),2===t&&(P.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",P,I({a:0,b:0,c:0}))),r.indexOf(\"select\")>-1&&1===t&&y(e,P,[w.xaxis],[w.yaxis],w.id,z),r.indexOf(\"event\")>-1&&g.click(P,e,w.id)}function R(t,e){return 1-e/w.h}function F(t,e){return 1-(t+(w.h-e)/Math.sqrt(3))/w.w}function B(t,e){return(t-(w.h-e)/Math.sqrt(3))/w.w}function N(i,a){var o=t+i,s=e+a,l=Math.max(0,Math.min(1,R(0,e),R(0,s))),c=Math.max(0,Math.min(1,F(t,e),F(o,s))),d=Math.max(0,Math.min(1,B(t,e),B(o,s))),g=(l/2+d)*w.w,m=(1-l/2-c)*w.w,y=(g+m)/2,x=m-g,T=(1-l)*w.h,C=T-x/k;x<b.MINZOOM?(u=r,v.attr(\"d\",f),_.attr(\"d\",\"M0,0Z\")):(u={a:r.a+l*n,b:r.b+c*n,c:r.c+d*n},v.attr(\"d\",f+\"M\"+g+\",\"+T+\"H\"+m+\"L\"+y+\",\"+C+\"L\"+g+\",\"+T+\"Z\"),_.attr(\"d\",\"M\"+t+\",\"+e+E+\"M\"+g+\",\"+T+A+\"M\"+m+\",\"+T+M+\"M\"+y+\",\"+C+S)),p||(v.transition().style(\"fill\",h>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),_.transition().style(\"opacity\",1).duration(200),p=!0),P.emit(\"plotly_relayouting\",I(u))}function j(){L(P),u!==r&&(a.call(\"_guiRelayout\",P,I(u)),C&&P.data&&P._context.showTips&&(o.notifier(s(P,\"Double-click to zoom back out\"),\"long\"),C=!1))}function U(t,e){var n=t/w.xaxis._m,i=e/w.yaxis._m,a=[(u={a:r.a-i,b:r.b+(n+i)/2,c:r.c-(n-i)/2}).a,u.b,u.c].sort(),o=a.indexOf(u.a),s=a.indexOf(u.b),l=a.indexOf(u.c);a[0]<0&&(a[1]+a[0]/2<0?(a[2]+=a[0]+a[1],a[0]=a[1]=0):(a[2]+=a[0]/2,a[1]+=a[0]/2,a[0]=0),u={a:a[o],b:a[s],c:a[l]},e=(r.a-u.a)*w.yaxis._m,t=(r.c-u.c-r.b+u.b)*w.xaxis._m);var h=\"translate(\"+(w.x0+t)+\",\"+(w.y0+e)+\")\";w.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",h);var f=\"translate(\"+-t+\",\"+-e+\")\";w.clipDefRelative.select(\"path\").attr(\"transform\",f),w.aaxis.range=[u.a,w.sum-u.b-u.c],w.baxis.range=[w.sum-u.a-u.c,u.b],w.caxis.range=[w.sum-u.a-u.b,u.c],w.drawAxes(!1),w._hasClipOnAxisFalse&&w.plotContainer.select(\".scatterlayer\").selectAll(\".trace\").call(c.hideOutsideRangePoints,w),P.emit(\"plotly_relayouting\",I(u))}function V(){a.call(\"_guiRelayout\",P,I(u))}T.onmousemove=function(t){g.hover(P,t,w.id),P._fullLayout._lasthover=T,P._fullLayout._hoversubplot=w.id},T.onmouseout=function(t){P._dragging||d.unhover(P,t)},d.init(z)}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../components/titles\":681,\"../../lib\":719,\"../../lib/extend\":710,\"../../registry\":847,\"../cartesian/axes\":767,\"../cartesian/constants\":773,\"../cartesian/select\":784,\"../cartesian/set_convert\":785,\"../plots\":828,d3:163,tinycolor2:537}],847:[function(t,e,r){\"use strict\";var n=t(\"./lib/loggers\"),i=t(\"./lib/noop\"),a=t(\"./lib/push_unique\"),o=t(\"./lib/is_plain_object\"),s=t(\"./lib/dom\").addStyleRule,l=t(\"./lib/extend\"),c=t(\"./plots/attributes\"),u=t(\"./plots/layout_attributes\"),h=l.extendFlat,f=l.extendDeepAll;function p(t){var e=t.name,i=t.categories,a=t.meta;if(r.modules[e])n.log(\"Type \"+e+\" already registered\");else{r.subplotsRegistry[t.basePlotModule.name]||function(t){var e=t.name;if(r.subplotsRegistry[e])return void n.log(\"Plot type \"+e+\" already registered.\");for(var i in m(t),r.subplotsRegistry[e]=t,r.componentsRegistry)b(i,t.name)}(t.basePlotModule);for(var o={},l=0;l<i.length;l++)o[i[l]]=!0,r.allCategories[i[l]]=!0;for(var c in r.modules[e]={_module:t,categories:o},a&&Object.keys(a).length&&(r.modules[e].meta=a),r.allTypes.push(e),r.componentsRegistry)y(c,e);t.layoutAttributes&&h(r.traceLayoutAttributes,t.layoutAttributes);var u=t.basePlotModule,f=u.name;if(\"mapbox\"===f){var p=u.constants.styleRules;for(var d in p)s(\".js-plotly-plot .plotly .mapboxgl-\"+d,p[d])}\"geo\"!==f&&\"mapbox\"!==f||void 0===typeof window||void 0!==window.PlotlyGeoAssets||(window.PlotlyGeoAssets={topojson:{}})}}function d(t){if(\"string\"!=typeof t.name)throw new Error(\"Component module *name* must be a string.\");var e=t.name;for(var n in r.componentsRegistry[e]=t,t.layoutAttributes&&(t.layoutAttributes._isLinkedToArray&&a(r.layoutArrayContainers,e),m(t)),r.modules)y(e,n);for(var i in r.subplotsRegistry)b(e,i);for(var o in r.transformsRegistry)x(e,o);t.schema&&t.schema.layout&&f(u,t.schema.layout)}function g(t){if(\"string\"!=typeof t.name)throw new Error(\"Transform module *name* must be a string.\");var e=\"Transform module \"+t.name,i=\"function\"==typeof t.transform,a=\"function\"==typeof t.calcTransform;if(!i&&!a)throw new Error(e+\" is missing a *transform* or *calcTransform* method.\");for(var s in i&&a&&n.log([e+\" has both a *transform* and *calcTransform* methods.\",\"Please note that all *transform* methods are executed\",\"before all *calcTransform* methods.\"].join(\" \")),o(t.attributes)||n.log(e+\" registered without an *attributes* object.\"),\"function\"!=typeof t.supplyDefaults&&n.log(e+\" registered without a *supplyDefaults* method.\"),r.transformsRegistry[t.name]=t,r.componentsRegistry)x(s,t.name)}function v(t){var e=t.name,n=e.split(\"-\")[0],i=t.dictionary,a=t.format,o=i&&Object.keys(i).length,s=a&&Object.keys(a).length,l=r.localeRegistry,c=l[e];if(c||(l[e]=c={}),n!==e){var u=l[n];u||(l[n]=u={}),o&&u.dictionary===c.dictionary&&(u.dictionary=i),s&&u.format===c.format&&(u.format=a)}o&&(c.dictionary=i),s&&(c.format=a)}function m(t){if(t.layoutAttributes){var e=t.layoutAttributes._arrayAttrRegexps;if(e)for(var n=0;n<e.length;n++)a(r.layoutArrayRegexes,e[n])}}function y(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.traces){var i=n.traces[e];i&&f(r.modules[e]._module.attributes,i)}}function x(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.transforms){var i=n.transforms[e];i&&f(r.transformsRegistry[e].attributes,i)}}function b(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.subplots){var i=r.subplotsRegistry[e],a=i.layoutAttributes,o=\"subplot\"===i.attr?i.name:i.attr;Array.isArray(o)&&(o=o[0]);var s=n.subplots[o];a&&s&&f(a,s)}}function _(t){return\"object\"==typeof t&&(t=t.type),t}r.modules={},r.allCategories={},r.allTypes=[],r.subplotsRegistry={},r.transformsRegistry={},r.componentsRegistry={},r.layoutArrayContainers=[],r.layoutArrayRegexes=[],r.traceLayoutAttributes={},r.localeRegistry={},r.apiMethodRegistry={},r.collectableSubplotTypes=null,r.register=function(t){if(r.collectableSubplotTypes=null,!t)throw new Error(\"No argument passed to Plotly.register.\");t&&!Array.isArray(t)&&(t=[t]);for(var e=0;e<t.length;e++){var n=t[e];if(!n)throw new Error(\"Invalid module was attempted to be registered!\");switch(n.moduleType){case\"trace\":p(n);break;case\"transform\":g(n);break;case\"component\":d(n);break;case\"locale\":v(n);break;case\"apiMethod\":var i=n.name;r.apiMethodRegistry[i]=n.fn;break;default:throw new Error(\"Invalid module was attempted to be registered!\")}}},r.getModule=function(t){var e=r.modules[_(t)];return!!e&&e._module},r.traceIs=function(t,e){if(\"various\"===(t=_(t)))return!1;var i=r.modules[t];return i||(t&&\"area\"!==t&&n.log(\"Unrecognized trace type \"+t+\".\"),i=r.modules[c.type.dflt]),!!i.categories[e]},r.getTransformIndices=function(t,e){for(var r=[],n=t.transforms||[],i=0;i<n.length;i++)n[i].type===e&&r.push(i);return r},r.hasTransform=function(t,e){for(var r=t.transforms||[],n=0;n<r.length;n++)if(r[n].type===e)return!0;return!1},r.getComponentMethod=function(t,e){var n=r.componentsRegistry[t];return n&&n[e]||i},r.call=function(){var t=arguments[0],e=[].slice.call(arguments,1);return r.apiMethodRegistry[t].apply(null,e)}},{\"./lib/dom\":708,\"./lib/extend\":710,\"./lib/is_plain_object\":720,\"./lib/loggers\":723,\"./lib/noop\":728,\"./lib/push_unique\":733,\"./plots/attributes\":764,\"./plots/layout_attributes\":819}],848:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=i.extendFlat,o=i.extendDeep;function s(t){var e;switch(t){case\"themes__thumb\":e={autosize:!0,width:150,height:150,title:{text:\"\"},showlegend:!1,margin:{l:5,r:5,t:5,b:5,pad:0},annotations:[]};break;case\"thumbnail\":e={title:{text:\"\"},hidesources:!0,showlegend:!1,borderwidth:0,bordercolor:\"\",margin:{l:1,r:1,t:1,b:1,pad:0},annotations:[]};break;default:e={}}return e}e.exports=function(t,e){var r;t.framework&&t.framework.isPolar&&(t=t.framework.getConfig());var i,l=t.data,c=t.layout,u=o([],l),h=o({},c,s(e.tileClass)),f=t._context||{};if(e.width&&(h.width=e.width),e.height&&(h.height=e.height),\"thumbnail\"===e.tileClass||\"themes__thumb\"===e.tileClass){h.annotations=[];var p=Object.keys(h);for(r=0;r<p.length;r++)i=p[r],[\"xaxis\",\"yaxis\",\"zaxis\"].indexOf(i.slice(0,5))>-1&&(h[p[r]].title={text:\"\"});for(r=0;r<u.length;r++){var d=u[r];d.showscale=!1,d.marker&&(d.marker.showscale=!1),n.traceIs(d,\"pie-like\")&&(d.textposition=\"none\")}}if(Array.isArray(e.annotations))for(r=0;r<e.annotations.length;r++)h.annotations.push(e.annotations[r]);var g=Object.keys(h).filter(function(t){return t.match(/^scene\\d*$/)});if(g.length){var v={};for(\"thumbnail\"===e.tileClass&&(v={title:{text:\"\"},showaxeslabels:!1,showticklabels:!1,linetickenable:!1}),r=0;r<g.length;r++){var m=h[g[r]];m.xaxis||(m.xaxis={}),m.yaxis||(m.yaxis={}),m.zaxis||(m.zaxis={}),a(m.xaxis,v),a(m.yaxis,v),a(m.zaxis,v),m._scene=null}}var y=document.createElement(\"div\");e.tileClass&&(y.className=e.tileClass);var x={gd:y,td:y,layout:h,data:u,config:{staticPlot:void 0===e.staticPlot||e.staticPlot,plotGlPixelRatio:void 0===e.plotGlPixelRatio?2:e.plotGlPixelRatio,displaylogo:e.displaylogo||!1,showLink:e.showLink||!1,showTips:e.showTips||!1,mapboxAccessToken:f.mapboxAccessToken}};return\"transparent\"!==e.setBackground&&(x.config.setBackground=e.setBackground||\"opaque\"),x.gd.defaultLayout=s(e.tileClass),x}},{\"../lib\":719,\"../registry\":847}],849:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/to_image\"),a=t(\"./filesaver\"),o=t(\"./helpers\");e.exports=function(t,e){var r;return n.isPlainObject(t)||(r=n.getGraphDiv(t)),(e=e||{}).format=e.format||\"png\",e.imageDataOnly=!0,new Promise(function(s,l){r&&r._snapshotInProgress&&l(new Error(\"Snapshotting already in progress.\")),n.isIE()&&\"svg\"!==e.format&&l(new Error(o.MSG_IE_BAD_FORMAT)),r&&(r._snapshotInProgress=!0);var c=i(t,e),u=e.filename||t.fn||\"newplot\";u+=\".\"+e.format,c.then(function(t){return r&&(r._snapshotInProgress=!1),a(t,u,e.format)}).then(function(t){s(t)}).catch(function(t){r&&(r._snapshotInProgress=!1),l(t)})})}},{\"../lib\":719,\"../plot_api/to_image\":760,\"./filesaver\":850,\"./helpers\":851}],850:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"./helpers\");e.exports=function(t,e,r){var a=document.createElement(\"a\"),o=\"download\"in a;return new Promise(function(s,l){var c,u;if(n.isIE9orBelow()&&l(new Error(\"IE < 10 unsupported\")),n.isSafari()){var h=\"svg\"===r?\",\":\";base64,\";return i.octetStream(h+encodeURIComponent(t)),s(e)}return n.isIE()?(c=i.createBlob(t,\"svg\"),window.navigator.msSaveBlob(c,e),c=null,s(e)):o?(c=i.createBlob(t,r),u=i.createObjectURL(c),a.href=u,a.download=e,document.body.appendChild(a),a.click(),document.body.removeChild(a),i.revokeObjectURL(u),c=null,s(e)):void l(new Error(\"download error\"))})}},{\"../lib\":719,\"./helpers\":851}],851:[function(t,e,r){\"use strict\";var n=t(\"../registry\");r.getDelay=function(t){return t._has&&(t._has(\"gl3d\")||t._has(\"gl2d\")||t._has(\"mapbox\"))?500:0},r.getRedrawFunc=function(t){return function(){var e=t._fullLayout||{};!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r||n.getComponentMethod(\"colorbar\",\"draw\")(t)}},r.encodeSVG=function(t){return\"data:image/svg+xml,\"+encodeURIComponent(t)};var i=window.URL||window.webkitURL;r.createObjectURL=function(t){return i.createObjectURL(t)},r.revokeObjectURL=function(t){return i.revokeObjectURL(t)},r.createBlob=function(t,e){if(\"svg\"===e)return new window.Blob([t],{type:\"image/svg+xml;charset=utf-8\"});var r=function(t){for(var e=t.length,r=new ArrayBuffer(e),n=new Uint8Array(r),i=0;i<e;i++)n[i]=t.charCodeAt(i);return r}(window.atob(t));return new window.Blob([r],{type:\"image/\"+e})},r.octetStream=function(t){document.location.href=\"data:application/octet-stream\"+t},r.IMAGE_URL_PREFIX=/^data:image\\/\\w+;base64,/,r.MSG_IE_BAD_FORMAT=\"Sorry IE does not support downloading from canvas. Try {format:'svg'} instead.\"},{\"../registry\":847}],852:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i={getDelay:n.getDelay,getRedrawFunc:n.getRedrawFunc,clone:t(\"./cloneplot\"),toSVG:t(\"./tosvg\"),svgToImg:t(\"./svgtoimg\"),toImage:t(\"./toimage\"),downloadImage:t(\"./download\")};e.exports=i},{\"./cloneplot\":848,\"./download\":849,\"./helpers\":851,\"./svgtoimg\":853,\"./toimage\":854,\"./tosvg\":855}],853:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"events\").EventEmitter,a=t(\"./helpers\");e.exports=function(t){var e=t.emitter||new i,r=new Promise(function(i,o){var s=window.Image,l=t.svg,c=t.format||\"png\";if(n.isIE()&&\"svg\"!==c){var u=new Error(a.MSG_IE_BAD_FORMAT);return o(u),t.promise?r:e.emit(\"error\",u)}var h,f,p=t.canvas,d=t.scale||1,g=t.width||300,v=t.height||150,m=d*g,y=d*v,x=p.getContext(\"2d\"),b=new s;\"svg\"===c||n.isIE9orBelow()||n.isSafari()?f=a.encodeSVG(l):(h=a.createBlob(l,\"svg\"),f=a.createObjectURL(h)),p.width=m,p.height=y,b.onload=function(){var r;switch(h=null,a.revokeObjectURL(f),\"svg\"!==c&&x.drawImage(b,0,0,m,y),c){case\"jpeg\":r=p.toDataURL(\"image/jpeg\");break;case\"png\":r=p.toDataURL(\"image/png\");break;case\"webp\":r=p.toDataURL(\"image/webp\");break;case\"svg\":r=f;break;default:var n=\"Image format is not jpeg, png, svg or webp.\";if(o(new Error(n)),!t.promise)return e.emit(\"error\",n)}i(r),t.promise||e.emit(\"success\",r)},b.onerror=function(r){if(h=null,a.revokeObjectURL(f),o(r),!t.promise)return e.emit(\"error\",r)},b.src=f});return t.promise?r:e}},{\"../lib\":719,\"./helpers\":851,events:104}],854:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i=t(\"../registry\"),a=t(\"../lib\"),o=t(\"./helpers\"),s=t(\"./cloneplot\"),l=t(\"./tosvg\"),c=t(\"./svgtoimg\");e.exports=function(t,e){var r=new n,u=s(t,{format:\"png\"}),h=u.gd;h.style.position=\"absolute\",h.style.left=\"-5000px\",document.body.appendChild(h);var f=o.getRedrawFunc(h);return i.call(\"plot\",h,u.data,u.layout,u.config).then(f).then(function(){var t=o.getDelay(h._fullLayout);setTimeout(function(){var t=l(h),n=document.createElement(\"canvas\");n.id=a.randstr(),(r=c({format:e.format,width:h._fullLayout.width,height:h._fullLayout.height,canvas:n,emitter:r,svg:t})).clean=function(){h&&document.body.removeChild(h)}},t)}).catch(function(t){r.emit(\"error\",t)}),r}},{\"../lib\":719,\"../registry\":847,\"./cloneplot\":848,\"./helpers\":851,\"./svgtoimg\":853,\"./tosvg\":855,events:104}],855:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=t(\"../components/drawing\"),o=t(\"../components/color\"),s=t(\"../constants/xmlns_namespaces\"),l=/\"/g,c=new RegExp('(\"TOBESTRIPPED)|(TOBESTRIPPED\")',\"g\");e.exports=function(t,e,r){var u,h=t._fullLayout,f=h._paper,p=h._toppaper,d=h.width,g=h.height;f.insert(\"rect\",\":first-child\").call(a.setRect,0,0,d,g).call(o.fill,h.paper_bgcolor);var v=h._basePlotModules||[];for(u=0;u<v.length;u++){var m=v[u];m.toSVG&&m.toSVG(t)}if(p){var y=p.node().childNodes,x=Array.prototype.slice.call(y);for(u=0;u<x.length;u++){var b=x[u];b.childNodes.length&&f.node().appendChild(b)}}h._draggers&&h._draggers.remove(),f.node().style.background=\"\",f.selectAll(\"text\").attr({\"data-unformatted\":null,\"data-math\":null}).each(function(){var t=n.select(this);if(\"hidden\"!==this.style.visibility&&\"none\"!==this.style.display){t.style({visibility:null,display:null});var e=this.style.fontFamily;e&&-1!==e.indexOf('\"')&&t.style(\"font-family\",e.replace(l,\"TOBESTRIPPED\"))}else t.remove()}),f.selectAll(\".point, .scatterpts, .legendfill>path, .legendlines>path, .cbfill\").each(function(){var t=n.select(this),e=this.style.fill;e&&-1!==e.indexOf(\"url(\")&&t.style(\"fill\",e.replace(l,\"TOBESTRIPPED\"));var r=this.style.stroke;r&&-1!==r.indexOf(\"url(\")&&t.style(\"stroke\",r.replace(l,\"TOBESTRIPPED\"))}),\"pdf\"!==e&&\"eps\"!==e||f.selectAll(\"#MathJax_SVG_glyphs path\").attr(\"stroke-width\",0),f.node().setAttributeNS(s.xmlns,\"xmlns\",s.svg),f.node().setAttributeNS(s.xmlns,\"xmlns:xlink\",s.xlink),\"svg\"===e&&r&&(f.attr(\"width\",r*d),f.attr(\"height\",r*g),f.attr(\"viewBox\",\"0 0 \"+d+\" \"+g));var _=(new window.XMLSerializer).serializeToString(f.node());return _=function(t){var e=n.select(\"body\").append(\"div\").style({display:\"none\"}).html(\"\"),r=t.replace(/(&[^;]*;)/gi,function(t){return\"&lt;\"===t?\"&#60;\":\"&rt;\"===t?\"&#62;\":-1!==t.indexOf(\"<\")||-1!==t.indexOf(\">\")?\"\":e.html(t).text()});return e.remove(),r}(_),_=(_=_.replace(/&(?!\\w+;|\\#[0-9]+;| \\#x[0-9A-F]+;)/g,\"&amp;\")).replace(c,\"'\"),i.isIE()&&(_=(_=(_=_.replace(/\"/gi,\"'\")).replace(/(\\('#)([^']*)('\\))/gi,'(\"#$2\")')).replace(/(\\\\')/gi,'\"')),_}},{\"../components/color\":593,\"../components/drawing\":614,\"../constants/xmlns_namespaces\":696,\"../lib\":719,d3:163}],856:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\",!0),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":719}],857:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/font_attributes\"),s=t(\"./constants.js\"),l=t(\"../../lib/extend\").extendFlat,c=o({editType:\"calc\",arrayOk:!0,colorEditType:\"style\"}),u=l({},n.marker.line.width,{dflt:0}),h=l({width:u,editType:\"calc\"},a(\"marker.line\")),f=l({line:h,editType:\"calc\"},a(\"marker\"),{opacity:{valType:\"number\",arrayOk:!0,dflt:1,min:0,max:1,editType:\"style\"}});e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,text:n.text,hovertext:n.hovertext,hovertemplate:i({},{keys:s.eventDataKeys}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"none\",arrayOk:!0,editType:\"calc\"},insidetextanchor:{valType:\"enumerated\",values:[\"end\",\"middle\",\"start\"],dflt:\"end\",editType:\"plot\"},textangle:{valType:\"angle\",dflt:\"auto\",editType:\"plot\"},textfont:l({},c,{}),insidetextfont:l({},c,{}),outsidetextfont:l({},c,{}),constraintext:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"both\",\"none\"],dflt:\"both\",editType:\"calc\"},cliponaxis:l({},n.cliponaxis,{}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},base:{valType:\"any\",dflt:null,arrayOk:!0,editType:\"calc\"},offset:{valType:\"number\",dflt:null,arrayOk:!0,editType:\"calc\"},width:{valType:\"number\",dflt:null,min:0,arrayOk:!0,editType:\"calc\"},marker:f,offsetgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},alignmentgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},selected:{marker:{opacity:n.selected.marker.opacity,color:n.selected.marker.color,editType:\"style\"},textfont:n.selected.textfont,editType:\"style\"},unselected:{marker:{opacity:n.unselected.marker.opacity,color:n.unselected.marker.color,editType:\"style\"},textfont:n.unselected.textfont,editType:\"style\"},r:n.r,t:n.t,_deprecated:{bardir:{valType:\"enumerated\",editType:\"calc\",values:[\"v\",\"h\"]}}}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"../scatter/attributes\":1112,\"./constants.js\":859}],858:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),o=t(\"./arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\");e.exports=function(t,e){var r,l,c=n.getFromId(t,e.xaxis||\"x\"),u=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=c.makeCalcdata(e,\"x\"),l=u.makeCalcdata(e,\"y\")):(r=u.makeCalcdata(e,\"y\"),l=c.makeCalcdata(e,\"x\"));for(var h=Math.min(l.length,r.length),f=new Array(h),p=0;p<h;p++)f[p]={p:l[p],s:r[p]},e.ids&&(f[p].id=String(e.ids[p]));return i(e,\"marker\")&&a(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),i(e,\"marker.line\")&&a(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),o(f,e),s(f,e),f}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"../../plots/cartesian/axes\":767,\"../scatter/calc_selection\":1114,\"./arrays_to_calcdata\":856}],859:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[]}},{}],860:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,c=t(\"./sieve.js\");function u(t,e,r,o,u){if(o.length){var b,_,w,k;switch(function(t,e){var r,a;for(r=0;r<e.length;r++){var o,s=e[r],l=s[0].trace,c=\"funnel\"===l.type?l._base:l.base,u=\"h\"===l.orientation?l.xcalendar:l.ycalendar,h=\"category\"===t.type||\"multicategory\"===t.type?function(){return null}:t.d2c;if(i(c)){for(a=0;a<Math.min(c.length,s.length);a++)o=h(c[a],0,u),n(o)?(s[a].b=+o,s[a].hasB=1):s[a].b=0;for(;a<s.length;a++)s[a].b=0}else{o=h(c,0,u);var f=n(o);for(o=f?o:0,a=0;a<s.length;a++)s[a].b=o,f&&(s[a].hasB=1)}}}(r,o),u.mode){case\"overlay\":h(e,r,o,u);break;case\"group\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(k=o[w])[0].trace.offset?_.push(k):b.push(k);_.length&&function(t,e,r,n,i){var o=new c(n,{sepNegVal:!1,overlapNoMerge:!i.norm});(function(t,e,r,n){for(var i=t._fullLayout,a=r.positions,o=r.distinctPositions,s=r.minDiff,c=r.traces,u=c.length,h=a.length!==o.length,f=s*(1-n.gap),v=l(i,e._id)+c[0][0].trace.orientation,m=i._alignmentOpts[v]||{},y=0;y<u;y++){var x,b,_=c[y],w=_[0].trace,k=m[w.alignmentgroup]||{},T=Object.keys(k.offsetGroups||{}).length,A=(x=T?f/T:h?f/u:f)*(1-(n.groupgap||0));b=T?((2*w._offsetIndex+1-T)*x-A)/2:h?((2*y+1-u)*x-A)/2:-A/2;var M=_[0].t;M.barwidth=A,M.poffset=b,M.bargroupwidth=f,M.bardelta=s}r.binWidth=c[0][0].t.barwidth/100,p(r),d(e,r),g(e,r,h)})(t,e,o,i),function(t){for(var e=t.traces,r=0;r<e.length;r++){var n=e[r],i=n[0].trace;if(void 0===i.base)for(var o=new c([n],{sepNegVal:!0,overlapNoMerge:!0}),s=0;s<n.length;s++){var l=n[s];if(l.p!==a){var u=o.put(l.p,l.b+l.s);u&&(l.b=u)}}}}(o),i.norm?(m(o),y(r,o,i)):v(r,o)}(t,e,r,_,u),b.length&&h(e,r,b,u);break;case\"stack\":case\"relative\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(k=o[w])[0].trace.base?_.push(k):b.push(k);_.length&&function(t,e,r,n,i){var o=new c(n,{sepNegVal:\"relative\"===i.mode,overlapNoMerge:!(i.norm||\"stack\"===i.mode||\"relative\"===i.mode)});f(e,o,i),function(t,e,r){var n,i,o,l,c,u,h=x(t),f=e.traces;for(l=0;l<f.length;l++)if(n=f[l],\"funnel\"===(i=n[0].trace).type)for(c=0;c<n.length;c++)(u=n[c]).s!==a&&e.put(u.p,-.5*u.s);for(l=0;l<f.length;l++){n=f[l],i=n[0].trace,o=\"funnel\"===i.type;var p=[];for(c=0;c<n.length;c++)if((u=n[c]).s!==a){var d;d=o?u.s:u.s+u.b;var g=e.put(u.p,d),v=g+d;u.b=g,u[h]=v,r.norm||(p.push(v),u.hasB&&p.push(g))}r.norm||(i._extremes[t._id]=s.findExtremes(t,p,{tozero:!0,padded:!0}))}}(r,o,i);for(var l=0;l<n.length;l++)for(var u=n[l],h=0;h<u.length;h++){var p=u[h];if(p.s!==a){var d=p.b+p.s===o.get(p.p,p.s);d&&(p._outmost=!0)}}i.norm&&y(r,o,i)}(0,e,r,_,u),b.length&&h(e,r,b,u)}!function(t,e){var r,i,a,o=x(e),s={},l=1/0,c=-1/0;for(r=0;r<t.length;r++)for(a=t[r],i=0;i<a.length;i++){var u=a[i].p;n(u)&&(l=Math.min(l,u),c=Math.max(c,u))}var h=1e4/(c-l),f=s.round=function(t){return String(Math.round(h*(t-l)))};for(r=0;r<t.length;r++){(a=t[r])[0].t.extents=s;var p=a[0].t.poffset,d=Array.isArray(p);for(i=0;i<a.length;i++){var g=a[i],v=g[o]-g.w/2;if(n(v)){var m=g[o]+g.w/2,y=f(g.p);s[y]?s[y]=[Math.min(v,s[y][0]),Math.max(m,s[y][1])]:s[y]=[v,m]}g.p0=g.p+(d?p[i]:p),g.p1=g.p0+g.w,g.s0=g.b,g.s1=g.s0+g.s}}}(o,e)}}function h(t,e,r,n){for(var i=0;i<r.length;i++){var a=r[i],o=new c([a],{sepNegVal:!1,overlapNoMerge:!n.norm});f(t,o,n),n.norm?(m(o),y(e,o,n)):v(e,o)}}function f(t,e,r){for(var n=e.minDiff,i=e.traces,a=n*(1-r.gap),o=a*(1-(r.groupgap||0)),s=-o/2,l=0;l<i.length;l++){var c=i[l][0].t;c.barwidth=o,c.poffset=s,c.bargroupwidth=a,c.bardelta=n}e.binWidth=i[0][0].t.barwidth/100,p(e),d(t,e),g(t,e)}function p(t){var e,r,a=t.traces;for(e=0;e<a.length;e++){var o,s=a[e],l=s[0],c=l.trace,u=l.t,h=c._offset||c.offset,f=u.poffset;if(i(h)){for(o=Array.prototype.slice.call(h,0,s.length),r=0;r<o.length;r++)n(o[r])||(o[r]=f);for(r=o.length;r<s.length;r++)o.push(f);u.poffset=o}else void 0!==h&&(u.poffset=h);var p=c._width||c.width,d=u.barwidth;if(i(p)){var g=Array.prototype.slice.call(p,0,s.length);for(r=0;r<g.length;r++)n(g[r])||(g[r]=d);for(r=g.length;r<s.length;r++)g.push(d);if(u.barwidth=g,void 0===h){for(o=[],r=0;r<s.length;r++)o.push(f+(d-g[r])/2);u.poffset=o}}else void 0!==p&&(u.barwidth=p,void 0===h&&(u.poffset=f+(d-p)/2))}}function d(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++)for(var a=r[i],o=a[0].t,s=o.poffset,l=Array.isArray(s),c=o.barwidth,u=Array.isArray(c),h=0;h<a.length;h++){var f=a[h],p=f.w=u?c[h]:c;f[n]=f.p+(l?s[h]:s)+p/2}}function g(t,e,r){var n=e.traces,i=e.minDiff/2;s.minDtick(t,e.minDiff,e.distinctPositions[0],r);for(var a=0;a<n.length;a++){var o,l,c,u,h=n[a],f=h[0],p=f.trace,d=[];for(u=0;u<h.length;u++)l=(o=h[u]).p-i,c=o.p+i,d.push(l,c);if(p.width||p.offset){var g=f.t,v=g.poffset,m=g.barwidth,y=Array.isArray(v),x=Array.isArray(m);for(u=0;u<h.length;u++){o=h[u];var b=y?v[u]:v,_=x?m[u]:m;c=(l=o.p+b)+_,d.push(l,c)}}p._extremes[t._id]=s.findExtremes(t,d,{padded:!1})}}function v(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++){for(var a=r[i],o=a[0].trace,l=[],c=!0,u=0;u<a.length;u++){var h=a[u],f=h.b,p=f+h.s;h[n]=p,l.push(p),h.hasB&&l.push(f),h.hasB&&h.b>0&&h.s>0||(c=!1)}o._extremes[t._id]=s.findExtremes(t,l,{tozero:!c,padded:!0})}}function m(t){for(var e=t.traces,r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++){var o=n[i];o.s!==a&&t.put(o.p,o.b+o.s)}}function y(t,e,r){var i=e.traces,o=x(t),l=\"fraction\"===r.norm?1:100,c=l/1e9,u=t.l2c(t.c2l(0)),h=\"stack\"===r.mode?l:u;function f(e){return n(t.c2l(e))&&(e<u-c||e>h+c||!n(u))}for(var p=0;p<i.length;p++){for(var d=i[p],g=d[0].trace,v=[],m=!0,y=!1,b=0;b<d.length;b++){var _=d[b];if(_.s!==a){var w=Math.abs(l/e.get(_.p,_.s));_.b*=w,_.s*=w;var k=_.b,T=k+_.s;_[o]=T,v.push(T),y=y||f(T),_.hasB&&(v.push(k),y=y||f(k)),_.hasB&&_.b>0&&_.s>0||(m=!1)}}g._extremes[t._id]=s.findExtremes(t,v,{tozero:!m,padded:y})}}function x(t){return t._id.charAt(0)}e.exports={crossTraceCalc:function(t,e){for(var r=e.xaxis,n=e.yaxis,i=t._fullLayout,a=t._fullData,s=t.calcdata,l=[],c=[],h=0;h<a.length;h++){var f=a[h];!0===f.visible&&o.traceIs(f,\"bar\")&&f.xaxis===r._id&&f.yaxis===n._id&&(\"h\"===f.orientation?l.push(s[h]):c.push(s[h]))}var p={mode:i.barmode,norm:i.barnorm,gap:i.bargap,groupgap:i.bargroupgap};u(t,r,n,c,p),u(t,n,r,l,p)},setGroupPositions:u}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"./sieve.js\":869,\"fast-isnumeric\":225}],861:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../registry\"),o=t(\"../scatter/xy_defaults\"),s=t(\"./style_defaults\"),l=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,c=t(\"./attributes\"),u=n.coerceFont;function h(t,e,r,n){var i=e.orientation,a=e[{v:\"x\",h:\"y\"}[i]+\"axis\"],o=l(r,a)+i,s=r._alignmentOpts||{},c=n(\"alignmentgroup\"),u=s[o];u||(u=s[o]={});var h=u[c];h?h.traces.push(e):h=u[c]={traces:[e],alignmentIndex:Object.keys(u).length,offsetGroups:{}};var f=n(\"offsetgroup\"),p=h.offsetGroups,d=p[f];f&&(d||(d=p[f]={offsetIndex:Object.keys(p).length}),e._offsetIndex=d.offsetIndex)}function f(t,e,r,i,a,o){var s=!(!1===(o=o||{}).moduleHasSelected),l=!(!1===o.moduleHasUnselected),c=!(!1===o.moduleHasConstrain),h=!(!1===o.moduleHasCliponaxis),f=!(!1===o.moduleHasTextangle),p=!(!1===o.moduleHasInsideanchor),d=Array.isArray(a)||\"auto\"===a,g=d||\"inside\"===a,v=d||\"outside\"===a;if(g||v){var m=u(i,\"textfont\",r.font),y=n.extendFlat({},m);!(t.textfont&&t.textfont.color)&&delete y.color,u(i,\"insidetextfont\",y),v&&u(i,\"outsidetextfont\",m),s&&i(\"selected.textfont.color\"),l&&i(\"unselected.textfont.color\"),c&&i(\"constraintext\"),h&&i(\"cliponaxis\"),f&&i(\"textangle\")}g&&p&&i(\"insidetextanchor\")}e.exports={supplyDefaults:function(t,e,r,l){function u(r,i){return n.coerce(t,e,c,r,i)}if(o(t,e,l,u)){u(\"orientation\",e.x&&!e.y?\"h\":\"v\"),u(\"base\"),u(\"offset\"),u(\"width\"),u(\"text\"),u(\"hovertext\"),u(\"hovertemplate\");var h=u(\"textposition\");f(t,0,l,u,h,{moduleHasSelected:!0,moduleHasUnselected:!0,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),s(t,e,u,r,l);var p=(e.marker.line||{}).color,d=a.getComponentMethod(\"errorbars\",\"supplyDefaults\");d(t,e,p||i.defaultLine,{axis:\"y\"}),d(t,e,p||i.defaultLine,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,u)}else e.visible=!1},crossTraceDefaults:function(t,e){var r;function i(t){return n.coerce(r._input,r,c,t)}if(\"group\"===e.barmode)for(var a=0;a<t.length;a++)\"bar\"===(r=t[a]).type&&(r._input,h(0,r,e,i))},handleGroupingDefaults:h,handleText:f}},{\"../../components/color\":593,\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../scatter/xy_defaults\":1137,\"./attributes\":857,\"./style_defaults\":871}],862:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../../lib\").isArrayOrTypedArray;r.coerceString=function(t,e,r){if(\"string\"==typeof e){if(e||!t.noBlank)return e}else if((\"number\"==typeof e||!0===e)&&!t.strict)return String(e);return void 0!==r?r:t.dflt},r.coerceNumber=function(t,e,r){if(n(e)){e=+e;var i=t.min,a=t.max;if(!(void 0!==i&&e<i||void 0!==a&&e>a))return e}return void 0!==r?r:t.dflt},r.coerceColor=function(t,e,r){return i(e).isValid()?e:void 0!==r?r:t.dflt},r.coerceEnumerated=function(t,e,r){return t.coerceNumber&&(e=+e),-1!==t.values.indexOf(e)?e:void 0!==r?r:t.dflt},r.getValue=function(t,e){var r;return Array.isArray(t)?e<t.length&&(r=t[e]):r=t,r},r.getLineWidth=function(t,e){return 0<e.mlw?e.mlw:a(t.marker.line.width)?0:t.marker.line.width}},{\"../../lib\":719,\"fast-isnumeric\":225,tinycolor2:537}],863:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../../lib\").fillText,s=t(\"./helpers\").getLineWidth;function l(t,e,r,i){var a,s,l,c,u,h,f,p=t.cd,d=p[0].trace,g=p[0].t,v=\"closest\"===i,m=\"waterfall\"===d.type,y=t.maxHoverDistance,x=t.maxSpikeDistance;function b(t){return t[l]-t.w/2}function _(t){return t[l]+t.w/2}var w=v?b:function(t){return Math.min(b(t),t.p-g.bardelta/2)},k=v?_:function(t){return Math.max(_(t),t.p+g.bardelta/2)};function T(t,e){return n.inbox(t-a,e-a,y+Math.min(1,Math.abs(e-t)/f)-1)}function A(t){return T(w(t),k(t))}function M(t){var e=s,r=t.b,i=t[c];return m&&(i+=Math.abs(t.rawS||0)),n.inbox(r-e,i-e,y+(i-e)/(i-r)-1)}\"h\"===d.orientation?(a=r,s=e,l=\"y\",c=\"x\",u=M,h=A):(a=e,s=r,l=\"x\",c=\"y\",h=M,u=A);var S=t[l+\"a\"],E=t[c+\"a\"];f=Math.abs(S.r2c(S.range[1])-S.r2c(S.range[0]));var C=n.getDistanceFunction(i,u,h,function(t){return(u(t)+h(t))/2});if(n.getClosest(p,C,t),!1!==t.index){v||(w=function(t){return Math.min(b(t),t.p-g.bargroupwidth/2)},k=function(t){return Math.max(_(t),t.p+g.bargroupwidth/2)});var L=p[t.index],P=d.base?L.b+L.s:L.s;t[c+\"0\"]=t[c+\"1\"]=E.c2p(L[c],!0),t[c+\"LabelVal\"]=P;var O=g.extents[g.extents.round(L.p)];return t[l+\"0\"]=S.c2p(v?w(L):O[0],!0),t[l+\"1\"]=S.c2p(v?k(L):O[1],!0),t[l+\"LabelVal\"]=L.p,t.spikeDistance=(M(L)+function(t){return T(b(t),_(t))}(L))/2+x-y,t[l+\"Spike\"]=S.c2p(L.p,!0),o(L,d,t),t.hovertemplate=d.hovertemplate,t}}function c(t,e){var r=e.mcc||t.marker.color,n=e.mlcc||t.marker.line.color,i=s(t,e);return a.opacity(r)?r:a.opacity(n)&&i?n:void 0}e.exports={hoverPoints:function(t,e,r,n){var a=l(t,e,r,n);if(a){var o=a.cd,s=o[0].trace,u=o[a.index];return a.color=c(s,u),i.getComponentMethod(\"errorbars\",\"hoverInfo\")(u,s,a),[a]}},hoverOnBars:l,getTraceColor:c}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"../../registry\":847,\"./helpers\":862}],864:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,colorbar:t(\"../scatter/marker_colorbar\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"bar\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"oriented\",\"errorBarsOK\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../scatter/marker_colorbar\":1129,\"./arrays_to_calcdata\":856,\"./attributes\":857,\"./calc\":858,\"./cross_trace_calc\":860,\"./defaults\":861,\"./hover\":863,\"./layout_attributes\":865,\"./layout_defaults\":866,\"./plot\":867,\"./select\":868,\"./style\":870}],865:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\",\"relative\"],dflt:\"group\",editType:\"calc\"},barnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},bargap:{valType:\"number\",min:0,max:1,editType:\"calc\"},bargroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],866:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\"),o=t(\"./layout_attributes\");e.exports=function(t,e,r){function s(r,n){return a.coerce(t,e,o,r,n)}for(var l=!1,c=!1,u=!1,h={},f=s(\"barmode\"),p=0;p<r.length;p++){var d=r[p];if(n.traceIs(d,\"bar\")&&d.visible){if(l=!0,\"group\"===f){var g=d.xaxis+d.yaxis;h[g]&&(u=!0),h[g]=!0}if(d.visible&&\"histogram\"===d.type)\"category\"!==i.getFromId({_fullLayout:e},d[\"v\"===d.orientation?\"xaxis\":\"yaxis\"]).type&&(c=!0)}}l?(\"overlay\"!==f&&s(\"barnorm\"),s(\"bargap\",c&&!u?0:.2),s(\"bargroupgap\")):delete e.barmode}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./layout_attributes\":865}],867:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../registry\"),u=t(\"../../plots/cartesian/axes\").tickText,h=t(\"./style\"),f=t(\"./helpers\"),p=t(\"./attributes\"),d=p.text,g=p.textposition,v=3;function m(t,e){return t<e?1:-1}function y(t){return\"auto\"===t?0:t}function x(t,e,r,n,i,a){var o=!!a.isHorizontal,s=!!a.constrained,l=a.angle||0,c=a.anchor||0,u=i.width,h=i.height,f=Math.abs(e-t),p=Math.abs(n-r),d=f>2*v&&p>2*v?v:0;f-=2*d,p-=2*d;var g=!1;if(!(\"auto\"===l)||u<=f&&h<=p||!(u>f||h>p)||(u>p||h>f)&&u<h==f<p||(g=!0),g){var x=p;p=f,f=x}var b=y(l),_=Math.abs(Math.sin(Math.PI/180*b)),w=Math.abs(Math.cos(Math.PI/180*b)),k=Math.max(f*w,p*_),T=Math.max(f*_,p*w),A=s?Math.min(k/u,T/h):Math.max(w,_);A=Math.min(1,A);var M=(t+e)/2,S=(r+n)/2;\"middle\"!==c&&(d+=.5*(A*(o!==g?h:u)*_+A*(o!==g?u:h)*w),o?(d*=m(t,e),M=\"start\"===c?t+d:e-d):(d*=m(r,n),S=\"start\"===c?r+d:n-d));return g&&(b+=90),{textX:(i.left+i.right)/2,textY:(i.top+i.bottom)/2,targetX:M,targetY:S,scale:A,rotate:b}}function b(t,e,r,n,i,a){var o,s=!!a.isHorizontal,l=!!a.constrained,c=a.angle||0,u=i.width,h=i.height,f=Math.abs(e-t),p=Math.abs(n-r);o=s?p>2*v?v:0:f>2*v?v:0;var d=1;l&&(d=s?Math.min(1,p/h):Math.min(1,f/u));var g=y(c);o+=.5*(d*(s?h:u)*Math.abs(Math.sin(Math.PI/180*g))+d*(s?u:h)*Math.abs(Math.cos(Math.PI/180*g)));var x=(t+e)/2,b=(r+n)/2;return s?x=e-o*m(e,t):b=n+o*m(r,n),{textX:(i.left+i.right)/2,textY:(i.top+i.bottom)/2,targetX:x,targetY:b,scale:d,rotate:g}}function _(t){var e,r=t.textX,n=t.textY,i=t.targetX,a=t.targetY,o=t.scale,s=t.rotate;return o<1?e=\"scale(\"+o+\") \":(o=1,e=\"\"),\"translate(\"+(i-o*r)+\" \"+(a-o*n)+\")\"+e+(s?\"rotate(\"+s+\" \"+r+\" \"+n+\") \":\"\")}e.exports={plot:function(t,e,r,p,y){var w=e.xaxis,k=e.yaxis,T=t._fullLayout;y||(y={mode:T.barmode,norm:T.barmode,gap:T.bargap,groupgap:T.bargroupgap});var A=a.makeTraceGroups(p,r,\"trace bars\").each(function(r){var c=n.select(this),p=r[0].trace,T=\"waterfall\"===p.type,A=\"funnel\"===p.type,M=\"bar\"===p.type||A,S=0;T&&p.connector.visible&&\"between\"===p.connector.mode&&(S=p.connector.line.width/2);var E=\"h\"===p.orientation,C=a.ensureSingle(c,\"g\",\"points\").selectAll(\"g.point\").data(a.identity);C.enter().append(\"g\").classed(\"point\",!0),C.exit().remove(),C.each(function(c,T){var A,C,L=n.select(this),P=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),n?[i,a]:[a,i]}(c,w,k,E),O=P[0][0],z=P[0][1],I=P[1][0],D=P[1][1],R=!(O!==z&&I!==D&&i(O)&&i(z)&&i(I)&&i(D));if(R&&M&&f.getLineWidth(p,c)&&(E?z-O==0:D-I==0)&&(R=!1),c.isBlank=R,S&&(E?(O-=m(O,z)*S,z+=m(O,z)*S):(I-=m(I,D)*S,D+=m(I,D)*S)),\"waterfall\"===p.type){if(!R){var F=p[c.dir].marker;A=F.line.width,C=F.color}}else A=f.getLineWidth(p,c),C=c.mc||p.marker.color;var B=n.round(A/2%1,2);function N(t){return 0===y.gap&&0===y.groupgap?n.round(Math.round(t)-B,2):t}if(!t._context.staticPlot){var j=s.opacity(C)<1||A>.01?N:function(t,e){return Math.abs(t-e)>=2?N(t):t>e?Math.ceil(t):Math.floor(t)};O=j(O,z),z=j(z,O),I=j(I,D),D=j(D,I)}a.ensureSingle(L,\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"d\",R?\"M0,0Z\":\"M\"+O+\",\"+I+\"V\"+D+\"H\"+z+\"V\"+I+\"Z\").call(l.setClipUrl,e.layerClipId,t),function(t,e,r,n,i,s,c,p,m,y){var w,k=e.xaxis,T=e.yaxis,A=t._fullLayout;function M(e,r,n){var i=a.ensureSingle(e,\"text\").text(r).attr({class:\"bartext bartext-\"+w,transform:\"\",\"text-anchor\":\"middle\",\"data-notex\":1}).call(l.font,n).call(o.convertToTspans,t);return i}var S=n[0].trace,E=\"h\"===S.orientation,C=function(t,e,r,n){var i,o=t[0].trace;return i=o.textinfo?function(t,e,r,n){var i=t[0].trace,o=\"h\"===i.orientation,s=\"waterfall\"===i.type,l=\"funnel\"===i.type;function c(t){var e=o?r:n;return u(e,+t,!0).text}var h,f,p=i.textinfo,d=t[e],g=p.split(\"+\"),v=[],m=function(t){return-1!==g.indexOf(t)};if(m(\"label\")&&v.push((f=t[e].p,u(o?n:r,f,!0).text)),m(\"text\")&&(0===(h=a.castOption(i,d.i,\"text\"))||h)&&v.push(h),s){var y=+d.rawS||d.s,x=d.v,b=x-y;m(\"initial\")&&v.push(c(b)),m(\"delta\")&&v.push(c(y)),m(\"final\")&&v.push(c(x))}if(l){m(\"value\")&&v.push(c(d.s));var _=0;m(\"percent initial\")&&_++,m(\"percent previous\")&&_++,m(\"percent total\")&&_++;var w=_>1;m(\"percent initial\")&&(h=a.formatPercent(d.begR),w&&(h+=\" of initial\"),v.push(h)),m(\"percent previous\")&&(h=a.formatPercent(d.difR),w&&(h+=\" of previous\"),v.push(h)),m(\"percent total\")&&(h=a.formatPercent(d.sumR),w&&(h+=\" of total\"),v.push(h))}return v.join(\"<br>\")}(t,e,r,n):f.getValue(o.text,e),f.coerceString(d,i)}(n,i,k,T);w=function(t,e){var r=f.getValue(t.textposition,e);return f.coerceEnumerated(g,r)}(S,i);var L=\"stack\"===y.mode||\"relative\"===y.mode,P=n[i],O=!L||P._outmost;if(C&&\"none\"!==w&&(!P.isBlank&&s!==c&&p!==m||\"auto\"!==w&&\"inside\"!==w)){var z=A.font,I=h.getBarColor(n[i],S),D=h.getInsideTextFont(S,i,z,I),R=h.getOutsideTextFont(S,i,z),F=r.datum();E?\"log\"===k.type&&F.s0<=0&&(s=k.range[0]<k.range[1]?0:k._length):\"log\"===T.type&&F.s0<=0&&(p=T.range[0]<T.range[1]?T._length:0);var B,N,j,U,V,q,H=Math.abs(c-s)-2*v,G=Math.abs(m-p)-2*v;if(\"outside\"===w&&(O||P.hasB||(w=\"inside\")),\"auto\"===w)if(O){w=\"inside\",B=M(r,C,D),N=l.bBox(B.node()),j=N.width,U=N.height;var Y=j>0&&U>0,W=j<=H&&U<=G,X=j<=G&&U<=H,Z=E?H>=j*(G/U):G>=U*(H/j);Y&&(W||X||Z)?w=\"inside\":(w=\"outside\",B.remove(),B=null)}else w=\"inside\";!B&&(B=M(r,C,\"outside\"===w?R:D),N=l.bBox(B.node()),j=N.width,U=N.height,j<=0||U<=0)?B.remove():(\"outside\"===w?(q=\"both\"===S.constraintext||\"outside\"===S.constraintext,V=_(b(s,c,p,m,N,{isHorizontal:E,constrained:q,angle:S.textangle}))):(q=\"both\"===S.constraintext||\"inside\"===S.constraintext,V=_(x(s,c,p,m,N,{isHorizontal:E,constrained:q,angle:S.textangle,anchor:S.insidetextanchor}))),B.attr(\"transform\",V))}else r.select(\"text\").remove()}(t,e,L,r,T,O,z,I,D,y),e.layerClipId&&l.hideOutsideRangePoint(c,L.select(\"text\"),w,k,p.xcalendar,p.ycalendar)});var L=!1===p.cliponaxis;l.setClipUrl(c,L?null:e.layerClipId,t)});c.getComponentMethod(\"errorbars\",\"plot\")(t,A,e)},getTransform:_,toMoveInsideBar:x,toMoveOutsideBar:b}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./attributes\":857,\"./helpers\":862,\"./style\":870,d3:163,\"fast-isnumeric\":225}],868:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=e.c2p(n?t.s0:t.p0,!0),o=e.c2p(n?t.s1:t.p1,!0),s=r.c2p(n?t.p0:t.s0,!0),l=r.c2p(n?t.p1:t.s1,!0);return i?[(a+o)/2,(s+l)/2]:n?[o,(s+l)/2]:[(a+o)/2,l]}e.exports=function(t,e){var r,i=t.cd,a=t.xaxis,o=t.yaxis,s=i[0].trace,l=\"funnel\"===s.type,c=\"h\"===s.orientation,u=[];if(!1===e)for(r=0;r<i.length;r++)i[r].selected=0;else for(r=0;r<i.length;r++){var h=i[r],f=\"ct\"in h?h.ct:n(h,a,o,c,l);e.contains(f,!1,r,t)?(u.push({pointNumber:r,x:a.c2d(h.x),y:o.c2d(h.y)}),h.selected=1):h.selected=0}return u}},{}],869:[function(t,e,r){\"use strict\";e.exports=a;var n=t(\"../../lib\").distinctVals,i=t(\"../../constants/numerical\").BADNUM;function a(t,e){this.traces=t,this.sepNegVal=e.sepNegVal,this.overlapNoMerge=e.overlapNoMerge;for(var r=1/0,a=[],o=0;o<t.length;o++){for(var s=t[o],l=0;l<s.length;l++){var c=s[l];c.p!==i&&a.push(c.p)}s[0]&&s[0].width1&&(r=Math.min(s[0].width1,r))}this.positions=a;var u=n(a);this.distinctPositions=u.vals,1===u.vals.length&&r!==1/0?this.minDiff=r:this.minDiff=Math.min(u.minDiff,r),this.binWidth=this.minDiff,this.bins={}}a.prototype.put=function(t,e){var r=this.getLabel(t,e),n=this.bins[r]||0;return this.bins[r]=n+e,n},a.prototype.get=function(t,e){var r=this.getLabel(t,e);return this.bins[r]||0},a.prototype.getLabel=function(t,e){return(e<0&&this.sepNegVal?\"v\":\"^\")+(this.overlapNoMerge?t:Math.round(t/this.binWidth))}},{\"../../constants/numerical\":695,\"../../lib\":719}],870:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../lib\"),s=t(\"../../registry\"),l=t(\"./attributes\"),c=l.textfont,u=l.insidetextfont,h=l.outsidetextfont,f=t(\"./helpers\");function p(t,e,r){a.pointStyle(t.selectAll(\"path\"),e,r),d(t,e,r)}function d(t,e,r){t.selectAll(\"text\").each(function(t){var i=n.select(this),o=g(i,t,e,r);a.font(i,o)})}function g(t,e,r,n){var i=n._fullLayout.font,a=r.textfont;if(t.classed(\"bartext-inside\")){var o=b(e,r);a=m(r,e.i,i,o)}else t.classed(\"bartext-outside\")&&(a=y(r,e.i,i));return a}function v(t,e,r){return x(c,t.textfont,e,r)}function m(t,e,r,n){var a=v(t,e,r);return(void 0===t._input.textfont||void 0===t._input.textfont.color||Array.isArray(t.textfont.color)&&void 0===t.textfont.color[e])&&(a={color:i.contrast(n),family:a.family,size:a.size}),x(u,t.insidetextfont,e,a)}function y(t,e,r){var n=v(t,e,r);return x(h,t.outsidetextfont,e,n)}function x(t,e,r,n){e=e||{};var i=f.getValue(e.family,r),a=f.getValue(e.size,r),o=f.getValue(e.color,r);return{family:f.coerceString(t.family,i,n.family),size:f.coerceNumber(t.size,a,n.size),color:f.coerceColor(t.color,o,n.color)}}function b(t,e){return\"waterfall\"===e.type?e[t.dir].marker.color:t.mc||e.marker.color}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.barlayer\").selectAll(\"g.trace\"),r=e.size(),i=t._fullLayout;e.style(\"opacity\",function(t){return t[0].trace.opacity}).each(function(t){(\"stack\"===i.barmode&&r>1||0===i.bargap&&0===i.bargroupgap&&!t[0].trace.marker.line.width)&&n.select(this).attr(\"shape-rendering\",\"crispEdges\")}),e.selectAll(\"g.points\").each(function(e){p(n.select(this),e[0].trace,t)}),s.getComponentMethod(\"errorbars\",\"style\")(e)},styleTextPoints:d,styleOnSelect:function(t,e,r){var i=e[0].trace;i.selectedpoints?function(t,e,r){a.selectedPointStyle(t.selectAll(\"path\"),e),function(t,e,r){t.each(function(t){var i,s=n.select(this);if(t.selected){i=o.extendFlat({},g(s,t,e,r));var l=e.selected.textfont&&e.selected.textfont.color;l&&(i.color=l),a.font(s,i)}else a.selectedTextStyle(s,e)})}(t.selectAll(\"text\"),e,r)}(r,i,t):(p(r,i,t),s.getComponentMethod(\"errorbars\",\"style\")(r))},getInsideTextFont:m,getOutsideTextFont:y,getBarColor:b}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../registry\":847,\"./attributes\":857,\"./helpers\":862,d3:163}],871:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s){r(\"marker.color\",o),i(t,\"marker\")&&a(t,e,s,r,{prefix:\"marker.\",cLetter:\"c\"}),r(\"marker.line.color\",n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,r,{prefix:\"marker.line.\",cLetter:\"c\"}),r(\"marker.line.width\"),r(\"marker.opacity\"),r(\"selected.marker.color\"),r(\"unselected.marker.color\")}},{\"../../components/color\":593,\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604}],872:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../scatterpolar/attributes\"),o=t(\"../bar/attributes\");e.exports={r:a.r,theta:a.theta,r0:a.r0,dr:a.dr,theta0:a.theta0,dtheta:a.dtheta,thetaunit:a.thetaunit,base:i({},o.base,{}),offset:i({},o.offset,{}),width:i({},o.width,{}),text:i({},o.text,{}),hovertext:i({},o.hovertext,{}),marker:o.marker,hoverinfo:a.hoverinfo,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../bar/attributes\":857,\"../scatterpolar/attributes\":1179}],873:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"../bar/arrays_to_calcdata\"),o=t(\"../bar/cross_trace_calc\").setGroupPositions,s=t(\"../scatter/calc_selection\"),l=t(\"../../registry\").traceIs,c=t(\"../../lib\").extendFlat;e.exports={calc:function(t,e){for(var r=t._fullLayout,o=e.subplot,l=r[o].radialaxis,c=r[o].angularaxis,u=l.makeCalcdata(e,\"r\"),h=c.makeCalcdata(e,\"theta\"),f=e._length,p=new Array(f),d=u,g=h,v=0;v<f;v++)p[v]={p:g[v],s:d[v]};function m(t){var r=e[t];void 0!==r&&(e[\"_\"+t]=Array.isArray(r)?c.makeCalcdata(e,t):c.d2c(r,e.thetaunit))}return\"linear\"===c.type&&(m(\"width\"),m(\"offset\")),n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),a(p,e),s(p,e),p},crossTraceCalc:function(t,e,r){for(var n=t.calcdata,i=[],a=0;a<n.length;a++){var s=n[a],u=s[0].trace;!0===u.visible&&l(u,\"bar\")&&u.subplot===r&&i.push(s)}var h=c({},e.radialaxis,{_id:\"x\"}),f=e.angularaxis;o(t,f,h,i,{mode:e.barmode,norm:e.barnorm,gap:e.bargap,groupgap:e.bargroupgap})}}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"../../lib\":719,\"../../registry\":847,\"../bar/arrays_to_calcdata\":856,\"../bar/cross_trace_calc\":860,\"../scatter/calc_selection\":1114}],874:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatterpolar/defaults\").handleRThetaDefaults,a=t(\"../bar/style_defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}i(t,e,s,l)?(l(\"thetaunit\"),l(\"base\"),l(\"offset\"),l(\"width\"),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),a(t,e,l,r,s),n.coerceSelectionMarkerOpacity(e,l)):e.visible=!1}},{\"../../lib\":719,\"../bar/style_defaults\":871,\"../scatterpolar/defaults\":1181,\"./attributes\":872}],875:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../bar/hover\").getTraceColor,o=i.fillText,s=t(\"../scatterpolar/hover\").makeHoverPointText,l=t(\"../../plots/polar/helpers\").isPtInsidePolygon;e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,h=t.subplot,f=h.radialAxis,p=h.angularAxis,d=h.vangles,g=d?l:i.isPtInsideSector,v=t.maxHoverDistance,m=p._period||2*Math.PI,y=Math.abs(f.g2p(Math.sqrt(e*e+r*r))),x=Math.atan2(r,e);f.range[0]>f.range[1]&&(x+=Math.PI);if(n.getClosest(c,function(t){return g(y,x,[t.rp0,t.rp1],[t.thetag0,t.thetag1],d)?v+Math.min(1,Math.abs(t.thetag1-t.thetag0)/m)-1+(t.rp1-y)/(t.rp1-t.rp0)-1:1/0},t),!1!==t.index){var b=c[t.index];t.x0=t.x1=b.ct[0],t.y0=t.y1=b.ct[1];var _=i.extendFlat({},b,{r:b.s,theta:b.p});return o(b,u,t),s(_,u,h,t),t.hovertemplate=u.hovertemplate,t.color=a(u,b),t.xLabelVal=t.yLabelVal=void 0,b.s<0&&(t.idealAlign=\"left\"),[t]}}},{\"../../components/fx\":632,\"../../lib\":719,\"../../plots/polar/helpers\":830,\"../bar/hover\":863,\"../scatterpolar/hover\":1182}],876:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"barpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"bar\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),colorbar:t(\"../scatter/marker_colorbar\"),style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),meta:{}}},{\"../../plots/polar\":831,\"../bar/select\":868,\"../bar/style\":870,\"../scatter/marker_colorbar\":1129,\"./attributes\":872,\"./calc\":873,\"./defaults\":874,\"./hover\":875,\"./layout_attributes\":877,\"./layout_defaults\":878,\"./plot\":879}],877:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},bargap:{valType:\"number\",dflt:.1,min:0,max:1,editType:\"calc\"}}},{}],878:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a,o={};function s(r,o){return n.coerce(t[a]||{},e[a],i,r,o)}for(var l=0;l<r.length;l++){var c=r[l];\"barpolar\"===c.type&&!0===c.visible&&(o[a=c.subplot]||(s(\"barmode\"),s(\"bargap\"),o[a]=1))}}},{\"../../lib\":719,\"./layout_attributes\":877}],879:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../components/drawing\"),s=t(\"../../plots/polar/helpers\");e.exports=function(t,e,r){var l=e.xaxis,c=e.yaxis,u=e.radialAxis,h=e.angularAxis,f=function(t){var e=t.cxx,r=t.cyy;if(t.vangles)return function(n,i,o,l){var c,u;a.angleDelta(o,l)>0?(c=o,u=l):(c=l,u=o);var h=s.findEnclosingVertexAngles(c,t.vangles)[0],f=s.findEnclosingVertexAngles(u,t.vangles)[1],p=[h,(c+u)/2,f];return s.pathPolygonAnnulus(n,i,c,u,p,e,r)};return function(t,n,i,o){return a.pathAnnulus(t,n,i,o,e,r)}}(e),p=e.layers.frontplot.select(\"g.barlayer\");a.makeTraceGroups(p,r,\"trace bars\").each(function(){var r=n.select(this),s=a.ensureSingle(r,\"g\",\"points\").selectAll(\"g.point\").data(a.identity);s.enter().append(\"g\").style(\"vector-effect\",\"non-scaling-stroke\").style(\"stroke-miterlimit\",2).classed(\"point\",!0),s.exit().remove(),s.each(function(t){var e,r=n.select(this),o=t.rp0=u.c2p(t.s0),s=t.rp1=u.c2p(t.s1),p=t.thetag0=h.c2g(t.p0),d=t.thetag1=h.c2g(t.p1);if(i(o)&&i(s)&&i(p)&&i(d)&&o!==s&&p!==d){var g=u.c2g(t.s1),v=(p+d)/2;t.ct=[l.c2p(g*Math.cos(v)),c.c2p(g*Math.sin(v))],e=f(o,s,p,d)}else e=\"M0,0Z\";a.ensureSingle(r,\"path\").attr(\"d\",e)}),o.setClipUrl(r,e._hasClipOnAxisFalse?e.clipIds.forTraces:null,t)})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../plots/polar/helpers\":830,d3:163,\"fast-isnumeric\":225}],880:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../bar/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../lib/extend\").extendFlat,l=n.marker,c=l.line;e.exports={y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},y0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},name:{valType:\"string\",editType:\"calc+clearAxisTypes\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),hovertemplate:o({}),whiskerwidth:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"calc\"},notched:{valType:\"boolean\",editType:\"calc\"},notchwidth:{valType:\"number\",min:0,max:.5,dflt:.25,editType:\"calc\"},boxpoints:{valType:\"enumerated\",values:[\"all\",\"outliers\",\"suspectedoutliers\",!1],dflt:\"outliers\",editType:\"calc\"},boxmean:{valType:\"enumerated\",values:[!0,\"sd\",!1],dflt:!1,editType:\"calc\"},jitter:{valType:\"number\",min:0,max:1,editType:\"calc\"},pointpos:{valType:\"number\",min:-2,max:2,editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},width:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},marker:{outliercolor:{valType:\"color\",dflt:\"rgba(0, 0, 0, 0)\",editType:\"style\"},symbol:s({},l.symbol,{arrayOk:!1,editType:\"plot\"}),opacity:s({},l.opacity,{arrayOk:!1,dflt:1,editType:\"style\"}),size:s({},l.size,{arrayOk:!1,editType:\"calc\"}),color:s({},l.color,{arrayOk:!1,editType:\"style\"}),line:{color:s({},c.color,{arrayOk:!1,dflt:a.defaultLine,editType:\"style\"}),width:s({},c.width,{arrayOk:!1,dflt:0,editType:\"style\"}),outliercolor:{valType:\"color\",editType:\"style\"},outlierwidth:{valType:\"number\",min:0,dflt:1,editType:\"style\"},editType:\"style\"},editType:\"plot\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,offsetgroup:i.offsetgroup,alignmentgroup:i.alignmentgroup,selected:{marker:n.selected.marker,editType:\"style\"},unselected:{marker:n.unselected.marker,editType:\"style\"},hoveron:{valType:\"flaglist\",flags:[\"boxes\",\"points\"],dflt:\"boxes+points\",editType:\"style\"}}},{\"../../components/color/attributes\":592,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../bar/attributes\":857,\"../scatter/attributes\":1112}],881:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=i._,o=t(\"../../plots/cartesian/axes\");function s(t,e,r){var n={text:\"tx\",hovertext:\"htx\"};for(var i in n)Array.isArray(e[i])&&(t[n[i]]=e[i][r])}function l(t,e){return t.v-e.v}function c(t){return t.v}e.exports=function(t,e){var r,u,h,f,p,d=t._fullLayout,g=o.getFromId(t,e.xaxis||\"x\"),v=o.getFromId(t,e.yaxis||\"y\"),m=[],y=\"violin\"===e.type?\"_numViolins\":\"_numBoxes\";\"h\"===e.orientation?(u=g,h=\"x\",f=v,p=\"y\"):(u=v,h=\"y\",f=g,p=\"x\");var x,b=u.makeCalcdata(e,h),_=function(t,e,r,a,o){if(e in t)return r.makeCalcdata(t,e);var s;s=e+\"0\"in t?t[e+\"0\"]:\"name\"in t&&(\"category\"===r.type||n(t.name)&&-1!==[\"linear\",\"log\"].indexOf(r.type)||i.isDateTime(t.name)&&\"date\"===r.type)?t.name:o;var l=\"multicategory\"===r.type?r.r2c_just_indices(s):r.d2c(s,0,t[e+\"calendar\"]);return a.map(function(){return l})}(e,p,f,b,d[y]),w=i.distinctVals(_),k=w.vals,T=w.minDiff/2,A=function(t,e){for(var r=t.length,n=new Array(r+1),i=0;i<r;i++)n[i]=t[i]-e;return n[r]=t[r-1]+e,n}(k,T),M=k.length,S=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=[];return e}(M);for(r=0;r<e._length;r++){var E=b[r];if(n(E)){var C=i.findBin(_[r],A);if(C>=0&&C<M){var L={v:E,i:r};s(L,e,r),S[C].push(L)}}}var P=\"all\"===(e.boxpoints||e.points)?i.identity:function(t){return t.v<x.lf||t.v>x.uf};for(r=0;r<M;r++)if(S[r].length>0){var O=S[r].sort(l),z=O.map(c),I=z.length;(x={}).pos=k[r],x.pts=O,x[p]=x.pos,x[h]=x.pts.map(function(t){return t.v}),x.min=z[0],x.max=z[I-1],x.mean=i.mean(z,I),x.sd=i.stdev(z,I,x.mean),x.q1=i.interp(z,.25),x.med=i.interp(z,.5),x.q3=i.interp(z,.75),x.lf=Math.min(x.q1,z[Math.min(i.findBin(2.5*x.q1-1.5*x.q3,z,!0)+1,I-1)]),x.uf=Math.max(x.q3,z[Math.max(i.findBin(2.5*x.q3-1.5*x.q1,z),0)]),x.lo=4*x.q1-3*x.q3,x.uo=4*x.q3-3*x.q1;var D=1.57*(x.q3-x.q1)/Math.sqrt(I);x.ln=x.med-D,x.un=x.med+D,x.pts2=O.filter(P),m.push(x)}!function(t,e){if(i.isArrayOrTypedArray(e.selectedpoints))for(var r=0;r<t.length;r++){for(var n=t[r].pts||[],a={},o=0;o<n.length;o++)a[n[o].i]=o;i.tagSelected(n,e,a)}}(m,e);var R=o.findExtremes(u,b,{padded:!0});return e._extremes[u._id]=R,m.length>0?(m[0].t={num:d[y],dPos:T,posLetter:p,valLetter:h,labels:{med:a(t,\"median:\"),min:a(t,\"min:\"),q1:a(t,\"q1:\"),q3:a(t,\"q3:\"),max:a(t,\"max:\"),mean:\"sd\"===e.boxmean?a(t,\"mean \\xb1 \\u03c3:\"):a(t,\"mean:\"),lf:a(t,\"lower fence:\"),uf:a(t,\"upper fence:\")}},d[y]++,m):[{t:{empty:!0}}]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"fast-isnumeric\":225}],882:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,o=[\"v\",\"h\"];function s(t,e,r,o){var s,l,c,u=e.calcdata,h=e._fullLayout,f=o._id,p=f.charAt(0),d=[],g=0;for(s=0;s<r.length;s++)for(c=u[r[s]],l=0;l<c.length;l++)d.push(c[l].pos),g+=(c[l].pts2||[]).length;if(d.length){var v=i.distinctVals(d),m=v.minDiff/2;n.minDtick(o,v.minDiff,v.vals[0],!0);var y=h[\"violin\"===t?\"_numViolins\":\"_numBoxes\"],x=\"group\"===h[t+\"mode\"]&&y>1,b=1-h[t+\"gap\"],_=1-h[t+\"groupgap\"];for(s=0;s<r.length;s++){var w,k,T,A,M,S,E=(c=u[r[s]])[0].trace,C=c[0].t,L=E.width,P=E.side;if(L)w=k=A=L/2,T=0;else if(w=m,x){var O=a(h,o._id)+E.orientation,z=(h._alignmentOpts[O]||{})[E.alignmentgroup]||{},I=Object.keys(z.offsetGroups||{}).length,D=I||y;k=w*b*_/D,T=2*w*(((I?E._offsetIndex:C.num)+.5)/D-.5)*b,A=w*b/D}else k=w*b*_,T=0,A=w;C.dPos=w,C.bPos=T,C.bdPos=k,C.wHover=A;var R,F,B,N,j,U,V=T+k,q=Boolean(L);if(\"positive\"===P?(M=w*(L?1:.5),R=V,S=R=T):\"negative\"===P?(M=R=T,S=w*(L?1:.5),F=V):(M=S=w,R=F=V),(E.boxpoints||E.points)&&g>0){var H=E.pointpos,G=E.jitter,Y=E.marker.size/2,W=0;H+G>=0&&((W=V*(H+G))>M?(q=!0,j=Y,B=W):W>R&&(j=Y,B=M)),W<=M&&(B=M);var X=0;H-G<=0&&((X=-V*(H-G))>S?(q=!0,U=Y,N=X):X>F&&(U=Y,N=S)),X<=S&&(N=S)}else B=M,N=S;var Z=new Array(c.length);for(l=0;l<c.length;l++)Z[l]=c[l].pos;E._extremes[f]=n.findExtremes(o,Z,{padded:q,vpadminus:N,vpadplus:B,ppadminus:{x:U,y:j}[p],ppadplus:{x:j,y:U}[p]})}}}e.exports={crossTraceCalc:function(t,e){for(var r=t.calcdata,n=e.xaxis,i=e.yaxis,a=0;a<o.length;a++){for(var l=o[a],c=\"h\"===l?i:n,u=[],h=0;h<r.length;h++){var f=r[h],p=f[0].t,d=f[0].trace;!0!==d.visible||\"box\"!==d.type&&\"candlestick\"!==d.type||p.empty||(d.orientation||\"v\")!==l||d.xaxis!==n._id||d.yaxis!==i._id||u.push(h)}s(\"box\",t,u,c)}},setPositionOffset:s}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_ids\":770}],883:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../bar/defaults\").handleGroupingDefaults,s=t(\"./attributes\");function l(t,e,r,a){var o,s,l=r(\"y\"),c=r(\"x\"),u=c&&c.length;if(l&&l.length)o=\"v\",u?s=Math.min(n.minRowLength(c),n.minRowLength(l)):(r(\"x0\"),s=n.minRowLength(l));else{if(!u)return void(e.visible=!1);o=\"h\",r(\"y0\"),s=n.minRowLength(c)}e._length=s,i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a),r(\"orientation\",o)}function c(t,e,r,i){var a=i.prefix,o=n.coerce2(t,e,s,\"marker.outliercolor\"),l=r(\"marker.line.outliercolor\"),c=r(a+\"points\",o||l?\"suspectedoutliers\":void 0);c?(r(\"jitter\",\"all\"===c?.3:0),r(\"pointpos\",\"all\"===c?-1.5:0),r(\"marker.symbol\"),r(\"marker.opacity\"),r(\"marker.size\"),r(\"marker.color\",e.line.color),r(\"marker.line.color\"),r(\"marker.line.width\"),\"suspectedoutliers\"===c&&(r(\"marker.line.outliercolor\",e.marker.color),r(\"marker.line.outlierwidth\")),r(\"selected.marker.color\"),r(\"unselected.marker.color\"),r(\"selected.marker.size\"),r(\"unselected.marker.size\"),r(\"text\"),r(\"hovertext\")):delete e.marker;var u=r(\"hoveron\");\"all\"!==u&&-1===u.indexOf(\"points\")||r(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,r)}e.exports={supplyDefaults:function(t,e,r,i){function o(r,i){return n.coerce(t,e,s,r,i)}l(t,e,o,i),!1!==e.visible&&(o(\"line.color\",(t.marker||{}).color||r),o(\"line.width\"),o(\"fillcolor\",a.addOpacity(e.line.color,.5)),o(\"whiskerwidth\"),o(\"boxmean\"),o(\"width\"),o(\"notched\",void 0!==t.notchwidth)&&o(\"notchwidth\"),c(t,e,o,{prefix:\"box\"}))},crossTraceDefaults:function(t,e){var r,i;function a(t){return n.coerce(i._input,i,s,t)}for(var l=0;l<t.length;l++){var c=(i=t[l]).type;\"box\"!==c&&\"violin\"!==c||(r=i._input,\"group\"===e[c+\"mode\"]&&o(r,i,e,a))}},handleSampleDefaults:l,handlePointsDefaults:c}},{\"../../components/color\":593,\"../../lib\":719,\"../../registry\":847,\"../bar/defaults\":861,\"./attributes\":880}],884:[function(t,e,r){\"use strict\";e.exports=function(t,e){return e.hoverOnBox&&(t.hoverOnBox=e.hoverOnBox),\"xVal\"in e&&(t.x=e.xVal),\"yVal\"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],885:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=i.fillText;function l(t,e,r,s){var l,c,u,h,f,p,d,g,v,m,y,x,b,_,w=t.cd,k=t.xa,T=t.ya,A=w[0].trace,M=w[0].t,S=\"violin\"===A.type,E=[],C=M.bdPos,L=M.wHover,P=function(t){return t.pos+M.bPos-p};S&&\"both\"!==A.side?(\"positive\"===A.side&&(v=function(t){var e=P(t);return a.inbox(e,e+L,m)},x=C,b=0),\"negative\"===A.side&&(v=function(t){var e=P(t);return a.inbox(e-L,e,m)},x=0,b=C)):(v=function(t){var e=P(t);return a.inbox(e-L,e+L,m)},x=b=C),_=S?function(t){return a.inbox(t.span[0]-f,t.span[1]-f,m)}:function(t){return a.inbox(t.min-f,t.max-f,m)},\"h\"===A.orientation?(f=e,p=r,d=_,g=v,l=\"y\",u=T,c=\"x\",h=k):(f=r,p=e,d=v,g=_,l=\"x\",u=k,c=\"y\",h=T);var O=Math.min(1,C/Math.abs(u.r2c(u.range[1])-u.r2c(u.range[0])));function z(t){return(d(t)+g(t))/2}m=t.maxHoverDistance-O,y=t.maxSpikeDistance-O;var I=a.getDistanceFunction(s,d,g,z);if(a.getClosest(w,I,t),!1===t.index)return[];var D=w[t.index],R=A.line.color,F=(A.marker||{}).color;o.opacity(R)&&A.line.width?t.color=R:o.opacity(F)&&A.boxpoints?t.color=F:t.color=A.fillcolor,t[l+\"0\"]=u.c2p(D.pos+M.bPos-b,!0),t[l+\"1\"]=u.c2p(D.pos+M.bPos+x,!0),t[l+\"LabelVal\"]=D.pos;var B=l+\"Spike\";t.spikeDistance=z(D)*y/m,t[B]=u.c2p(D.pos,!0);var N={},j=[\"med\",\"q1\",\"q3\",\"min\",\"max\"];(A.boxmean||(A.meanline||{}).visible)&&j.push(\"mean\"),(A.boxpoints||A.points)&&j.push(\"lf\",\"uf\");for(var U=0;U<j.length;U++){var V=j[U];if(V in D&&!(D[V]in N)){N[D[V]]=!0;var q=D[V],H=h.c2p(q,!0),G=i.extendFlat({},t);G.attr=V,G[c+\"0\"]=G[c+\"1\"]=H,G[c+\"LabelVal\"]=q,G[c+\"Label\"]=(M.labels?M.labels[V]+\" \":\"\")+n.hoverLabelText(h,q),G.hoverOnBox=!0,\"mean\"===V&&\"sd\"in D&&\"sd\"===A.boxmean&&(G[c+\"err\"]=D.sd),t.name=\"\",t.spikeDistance=void 0,t[B]=void 0,G.hovertemplate=!1,E.push(G)}}return E}function c(t,e,r){for(var n,o,l,c=t.cd,u=t.xa,h=t.ya,f=c[0].trace,p=u.c2p(e),d=h.c2p(r),g=a.quadrature(function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(u.c2p(t.x)-p)-e,1-3/e)},function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(h.c2p(t.y)-d)-e,1-3/e)}),v=!1,m=0;m<c.length;m++){o=c[m];for(var y=0;y<(o.pts||[]).length;y++){var x=g(l=o.pts[y]);x<=t.distance&&(t.distance=x,v=[m,y])}}if(!v)return!1;l=(o=c[v[0]]).pts[v[1]];var b,_=u.c2p(l.x,!0),w=h.c2p(l.y,!0),k=l.mrc||1;return n=i.extendFlat({},t,{index:l.i,color:(f.marker||{}).color,name:f.name,x0:_-k,x1:_+k,y0:w-k,y1:w+k,spikeDistance:t.distance,hovertemplate:f.hovertemplate}),\"h\"===f.orientation?(b=h,n.xLabelVal=l.x,n.yLabelVal=o.pos):(b=u,n.xLabelVal=o.pos,n.yLabelVal=l.y),n[b._id.charAt(0)+\"Spike\"]=b.c2p(o.pos,!0),s(l,f,n),n}e.exports={hoverPoints:function(t,e,r,n){var i,a=t.cd[0].trace.hoveron,o=[];return-1!==a.indexOf(\"boxes\")&&(o=o.concat(l(t,e,r,n))),-1!==a.indexOf(\"points\")&&(i=c(t,e,r)),\"closest\"===n?i?[i]:o:i?(o.push(i),o):o},hoverOnBoxes:l,hoverOnPoints:c}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],886:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\").supplyLayoutDefaults,calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"box\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"boxLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":880,\"./calc\":881,\"./cross_trace_calc\":882,\"./defaults\":883,\"./event_data\":884,\"./hover\":885,\"./layout_attributes\":887,\"./layout_defaults\":888,\"./plot\":889,\"./select\":890,\"./style\":891}],887:[function(t,e,r){\"use strict\";e.exports={boxmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"overlay\",editType:\"calc\"},boxgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"},boxgroupgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"}}},{}],888:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./layout_attributes\");function o(t,e,r,i,a){for(var o=a+\"Layout\",s=!1,l=0;l<r.length;l++){var c=r[l];if(n.traceIs(c,o)){s=!0;break}}s&&(i(a+\"mode\"),i(a+\"gap\"),i(a+\"groupgap\"))}e.exports={supplyLayoutDefaults:function(t,e,r){o(0,0,r,function(r,n){return i.coerce(t,e,a,r,n)},\"box\")},_supply:o}},{\"../../lib\":719,\"../../registry\":847,\"./layout_attributes\":887}],889:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=5,s=.01;function l(t,e,r,a){var o,s,l=e.pos,c=e.val,u=a.bPos,h=a.wdPos||0,f=a.bPosPxOffset||0,p=r.whiskerwidth||0,d=r.notched||!1,g=d?1-2*r.notchwidth:1;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var v=t.selectAll(\"path.box\").data(\"violin\"!==r.type||r.box.visible?i.identity:[]);v.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"box\"),v.exit().remove(),v.each(function(t){if(t.empty)return\"M0,0Z\";var e=t.pos,a=l.c2p(e+u,!0)+f,v=l.c2p(e+u-o,!0)+f,m=l.c2p(e+u+s,!0)+f,y=l.c2p(e+u-h,!0)+f,x=l.c2p(e+u+h,!0)+f,b=l.c2p(e+u-o*g,!0)+f,_=l.c2p(e+u+s*g,!0)+f,w=c.c2p(t.q1,!0),k=c.c2p(t.q3,!0),T=i.constrain(c.c2p(t.med,!0),Math.min(w,k)+1,Math.max(w,k)-1),A=void 0===t.lf||!1===r.boxpoints,M=c.c2p(A?t.min:t.lf,!0),S=c.c2p(A?t.max:t.uf,!0),E=c.c2p(t.ln,!0),C=c.c2p(t.un,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+T+\",\"+b+\"V\"+_+\"M\"+w+\",\"+v+\"V\"+m+(d?\"H\"+E+\"L\"+T+\",\"+_+\"L\"+C+\",\"+m:\"\")+\"H\"+k+\"V\"+v+(d?\"H\"+C+\"L\"+T+\",\"+b+\"L\"+E+\",\"+v:\"\")+\"ZM\"+w+\",\"+a+\"H\"+M+\"M\"+k+\",\"+a+\"H\"+S+(0===p?\"\":\"M\"+M+\",\"+y+\"V\"+x+\"M\"+S+\",\"+y+\"V\"+x)):n.select(this).attr(\"d\",\"M\"+b+\",\"+T+\"H\"+_+\"M\"+v+\",\"+w+\"H\"+m+(d?\"V\"+E+\"L\"+_+\",\"+T+\"L\"+m+\",\"+C:\"\")+\"V\"+k+\"H\"+v+(d?\"V\"+C+\"L\"+b+\",\"+T+\"L\"+v+\",\"+E:\"\")+\"ZM\"+a+\",\"+w+\"V\"+M+\"M\"+a+\",\"+k+\"V\"+S+(0===p?\"\":\"M\"+y+\",\"+M+\"H\"+x+\"M\"+y+\",\"+S+\"H\"+x))})}function c(t,e,r,n){var l=e.x,c=e.y,u=n.bdPos,h=n.bPos,f=r.boxpoints||r.points;i.seedPseudoRandom();var p=t.selectAll(\"g.points\").data(f?function(t){return t.forEach(function(t){t.t=n,t.trace=r}),t}:[]);p.enter().append(\"g\").attr(\"class\",\"points\"),p.exit().remove();var d=p.selectAll(\"path\").data(function(t){var e,n,a=t.pts2,l=Math.max((t.max-t.min)/10,t.q3-t.q1),c=1e-9*l,p=l*s,d=[],g=0;if(r.jitter){if(0===l)for(g=1,d=new Array(a.length),e=0;e<a.length;e++)d[e]=1;else for(e=0;e<a.length;e++){var v=Math.max(0,e-o),m=a[v].v,y=Math.min(a.length-1,e+o),x=a[y].v;\"all\"!==f&&(a[e].v<t.lf?x=Math.min(x,t.lf):m=Math.max(m,t.uf));var b=Math.sqrt(p*(y-v)/(x-m+c))||0;b=i.constrain(Math.abs(b),0,1),d.push(b),g=Math.max(b,g)}n=2*r.jitter/(g||1)}for(e=0;e<a.length;e++){var _=a[e],w=_.v,k=r.jitter?n*d[e]*(i.pseudoRandom()-.5):0,T=t.pos+h+u*(r.pointpos+k);\"h\"===r.orientation?(_.y=T,_.x=w):(_.x=T,_.y=w),\"suspectedoutliers\"===f&&w<t.uo&&w>t.lo&&(_.so=!0)}return a});d.enter().append(\"path\").classed(\"point\",!0),d.exit().remove(),d.call(a.translatePoints,l,c)}function u(t,e,r,a){var o,s,l=e.pos,c=e.val,u=a.bPos,h=a.bPosPxOffset||0,f=r.boxmean||(r.meanline||{}).visible;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var p=t.selectAll(\"path.mean\").data(\"box\"===r.type&&r.boxmean||\"violin\"===r.type&&r.box.visible&&r.meanline.visible?i.identity:[]);p.enter().append(\"path\").attr(\"class\",\"mean\").style({fill:\"none\",\"vector-effect\":\"non-scaling-stroke\"}),p.exit().remove(),p.each(function(t){var e=l.c2p(t.pos+u,!0)+h,i=l.c2p(t.pos+u-o,!0)+h,a=l.c2p(t.pos+u+s,!0)+h,p=c.c2p(t.mean,!0),d=c.c2p(t.mean-t.sd,!0),g=c.c2p(t.mean+t.sd,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+p+\",\"+i+\"V\"+a+(\"sd\"===f?\"m0,0L\"+d+\",\"+e+\"L\"+p+\",\"+i+\"L\"+g+\",\"+e+\"Z\":\"\")):n.select(this).attr(\"d\",\"M\"+i+\",\"+p+\"H\"+a+(\"sd\"===f?\"m0,0L\"+e+\",\"+d+\"L\"+i+\",\"+p+\"L\"+e+\",\"+g+\"Z\":\"\"))})}e.exports={plot:function(t,e,r,a){var o=e.xaxis,s=e.yaxis;i.makeTraceGroups(a,r,\"trace boxes\").each(function(t){var e,r,i=n.select(this),a=t[0],h=a.t,f=a.trace;h.wdPos=h.bdPos*f.whiskerwidth,!0!==f.visible||h.empty?i.remove():(\"h\"===f.orientation?(e=s,r=o):(e=o,r=s),l(i,{pos:e,val:r},f,h),c(i,{x:o,y:s},f,h),u(i,{pos:e,val:r},f,h))})},plotBoxAndWhiskers:l,plotPoints:c,plotBoxMean:u}},{\"../../components/drawing\":614,\"../../lib\":719,d3:163}],890:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i=t.cd,a=t.xaxis,o=t.yaxis,s=[];if(!1===e)for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++)i[r].pts[n].selected=0;else for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++){var l=i[r].pts[n],c=a.c2p(l.x),u=o.c2p(l.y);e.contains([c,u],null,l.i,t)?(s.push({pointNumber:l.i,x:a.c2d(l.x),y:o.c2d(l.y)}),l.selected=1):l.selected=0}return s}},{}],891:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\");e.exports={style:function(t,e,r){var o=r||n.select(t).selectAll(\"g.trace.boxes\");o.style(\"opacity\",function(t){return t[0].trace.opacity}),o.each(function(e){var r=n.select(this),o=e[0].trace,s=o.line.width;function l(t,e,r,n){t.style(\"stroke-width\",e+\"px\").call(i.stroke,r).call(i.fill,n)}var c=r.selectAll(\"path.box\");if(\"candlestick\"===o.type)c.each(function(t){if(!t.empty){var e=n.select(this),r=o[t.dir];l(e,r.line.width,r.line.color,r.fillcolor),e.style(\"opacity\",o.selectedpoints&&!t.selected?.3:1)}});else{l(c,s,o.line.color,o.fillcolor),r.selectAll(\"path.mean\").style({\"stroke-width\":s,\"stroke-dasharray\":2*s+\"px,\"+s+\"px\"}).call(i.stroke,o.line.color);var u=r.selectAll(\"path.point\");a.pointStyle(u,o,t)}})},styleOnSelect:function(t,e,r){var n=e[0].trace,i=r.selectAll(\"path.point\");n.selectedpoints?a.selectedPointStyle(i,n):a.pointStyle(i,n,t)}}},{\"../../components/color\":593,\"../../components/drawing\":614,d3:163}],892:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../ohlc/attributes\"),a=t(\"../box/attributes\");function o(t){return{line:{color:n({},a.line.color,{dflt:t}),width:a.line.width,editType:\"style\"},fillcolor:a.fillcolor,editType:\"style\"}}e.exports={x:i.x,open:i.open,high:i.high,low:i.low,close:i.close,line:{width:n({},a.line.width,{}),editType:\"style\"},increasing:o(i.increasing.line.color.dflt),decreasing:o(i.decreasing.line.color.dflt),text:i.text,hovertext:i.hovertext,whiskerwidth:n({},a.whiskerwidth,{dflt:0}),hoverlabel:i.hoverlabel}},{\"../../lib\":719,\"../box/attributes\":880,\"../ohlc/attributes\":1058}],893:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../ohlc/calc\").calcCommon;function o(t,e,r,n){return{min:r,q1:Math.min(t,n),med:n,q3:Math.max(t,n),max:e}}e.exports=function(t,e){var r=t._fullLayout,s=i.getFromId(t,e.xaxis),l=i.getFromId(t,e.yaxis),c=s.makeCalcdata(e,\"x\"),u=a(t,e,c,l,o);return u.length?(n.extendFlat(u[0].t,{num:r._numBoxes,dPos:n.distinctVals(c).minDiff/2,posLetter:\"x\",valLetter:\"y\"}),r._numBoxes++,u):[{t:{empty:!0}}]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../ohlc/calc\":1059}],894:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../ohlc/ohlc_defaults\"),o=t(\"./attributes\");function s(t,e,r,n){var a=r(n+\".line.color\");r(n+\".line.width\",e.line.width),r(n+\".fillcolor\",i.addOpacity(a,.5))}e.exports=function(t,e,r,i){function l(r,i){return n.coerce(t,e,o,r,i)}a(t,e,l,i)?(l(\"line.width\"),s(t,e,l,\"increasing\"),s(t,e,l,\"decreasing\"),l(\"text\"),l(\"hovertext\"),l(\"whiskerwidth\"),i._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../components/color\":593,\"../../lib\":719,\"../ohlc/ohlc_defaults\":1063,\"./attributes\":892}],895:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"candlestick\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\",\"candlestick\",\"boxLayout\"],meta:{},attributes:t(\"./attributes\"),layoutAttributes:t(\"../box/layout_attributes\"),supplyLayoutDefaults:t(\"../box/layout_defaults\").supplyLayoutDefaults,crossTraceCalc:t(\"../box/cross_trace_calc\").crossTraceCalc,supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"../box/plot\").plot,layerName:\"boxlayer\",style:t(\"../box/style\").style,hoverPoints:t(\"../ohlc/hover\").hoverPoints,selectPoints:t(\"../ohlc/select\")}},{\"../../plots/cartesian\":778,\"../box/cross_trace_calc\":882,\"../box/layout_attributes\":887,\"../box/layout_defaults\":888,\"../box/plot\":889,\"../box/style\":891,\"../ohlc/hover\":1061,\"../ohlc/select\":1065,\"./attributes\":892,\"./calc\":893,\"./defaults\":894}],896:[function(t,e,r){\"use strict\";var n=t(\"./axis_defaults\"),i=t(\"../../plot_api/plot_template\");e.exports=function(t,e,r,a,o){a(\"a\")||(a(\"da\"),a(\"a0\")),a(\"b\")||(a(\"db\"),a(\"b0\")),function(t,e,r,a){[\"aaxis\",\"baxis\"].forEach(function(o){var s=o.charAt(0),l=t[o]||{},c=i.newContainer(e,o),u={tickfont:\"x\",id:s+\"axis\",letter:s,font:e.font,name:o,data:t[s],calendar:e.calendar,dfltColor:a,bgColor:r.paper_bgcolor,fullLayout:r};n(l,c,u),c._categories=c._categories||[],t[o]||\"-\"===l.type||(t[o]={type:l.type})})}(t,e,r,o)}},{\"../../plot_api/plot_template\":757,\"./axis_defaults\":901}],897:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t){return function t(e,r){if(!n(e)||r>=10)return null;var i=1/0;var a=-1/0;var o=e.length;for(var s=0;s<o;s++){var l=e[s];if(n(l)){var c=t(l,r+1);c&&(i=Math.min(c[0],i),a=Math.max(c[1],a))}else i=Math.min(l,i),a=Math.max(l,a)}return[i,a]}(t,0)}},{\"../../lib\":719}],898:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./axis_attributes\"),a=t(\"../../components/color/attributes\"),o=n({editType:\"calc\"});o.family.dflt='\"Open Sans\", verdana, arial, sans-serif',o.size.dflt=12,o.color.dflt=a.defaultLine,e.exports={carpet:{valType:\"string\",editType:\"calc\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},a:{valType:\"data_array\",editType:\"calc\"},a0:{valType:\"number\",dflt:0,editType:\"calc\"},da:{valType:\"number\",dflt:1,editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},b0:{valType:\"number\",dflt:0,editType:\"calc\"},db:{valType:\"number\",dflt:1,editType:\"calc\"},cheaterslope:{valType:\"number\",dflt:1,editType:\"calc\"},aaxis:i,baxis:i,font:o,color:{valType:\"color\",dflt:a.defaultLine,editType:\"plot\"},transforms:void 0}},{\"../../components/color/attributes\":592,\"../../plots/font_attributes\":793,\"./axis_attributes\":900}],899:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,i){var a,o,s,l,c,u,h,f,p,d,g,v,m,y=n(r)?\"a\":\"b\",x=(\"a\"===y?t.aaxis:t.baxis).smoothing,b=\"a\"===y?t.a2i:t.b2j,_=\"a\"===y?r:i,w=\"a\"===y?i:r,k=\"a\"===y?e.a.length:e.b.length,T=\"a\"===y?e.b.length:e.a.length,A=Math.floor(\"a\"===y?t.b2j(w):t.a2i(w)),M=\"a\"===y?function(e){return t.evalxy([],e,A)}:function(e){return t.evalxy([],A,e)};x&&(s=Math.max(0,Math.min(T-2,A)),l=A-s,o=\"a\"===y?function(e,r){return t.dxydi([],e,s,r,l)}:function(e,r){return t.dxydj([],s,e,l,r)});var S=b(_[0]),E=b(_[1]),C=S<E?1:-1,L=1e-8*(E-S),P=C>0?Math.floor:Math.ceil,O=C>0?Math.ceil:Math.floor,z=C>0?Math.min:Math.max,I=C>0?Math.max:Math.min,D=P(S+L),R=O(E-L),F=[[h=M(S)]];for(a=D;a*C<R*C;a+=C)c=[],g=I(S,a),m=(v=z(E,a+C))-g,u=Math.max(0,Math.min(k-2,Math.floor(.5*(g+v)))),f=M(v),x&&(p=o(u,g-u),d=o(u,v-u),c.push([h[0]+p[0]/3*m,h[1]+p[1]/3*m]),c.push([f[0]-d[0]/3*m,f[1]-d[1]/3*m])),c.push(f),F.push(c),h=f;return F}},{\"../../lib\":719}],900:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../plots/cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").TIME_FORMAT_LINK;e.exports={color:{valType:\"color\",editType:\"calc\"},smoothing:{valType:\"number\",dflt:1,min:0,max:1.3,editType:\"calc\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"calc\"},font:n({editType:\"calc\"}),offset:{valType:\"number\",dflt:10,editType:\"calc\"},editType:\"calc\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"date\",\"category\"],dflt:\"-\",editType:\"calc\"},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"calc\"},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"calc\"},range:{valType:\"info_array\",editType:\"calc\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}]},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cheatertype:{valType:\"enumerated\",values:[\"index\",\"value\"],dflt:\"value\",editType:\"calc\"},tickmode:{valType:\"enumerated\",values:[\"linear\",\"array\"],dflt:\"array\",editType:\"calc\"},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},tickvals:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},showticklabels:{valType:\"enumerated\",values:[\"start\",\"end\",\"both\",\"none\"],dflt:\"start\",editType:\"calc\"},tickfont:n({editType:\"calc\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"calc\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"calc\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"calc\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"calc\"},tickformatstops:o(a.tickformatstops,\"calc\",\"from-root\"),categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},labelpadding:{valType:\"integer\",dflt:10,editType:\"calc\"},labelprefix:{valType:\"string\",editType:\"calc\"},labelsuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showline:{valType:\"boolean\",dflt:!1,editType:\"calc\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"calc\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},gridcolor:{valType:\"color\",editType:\"calc\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},showgrid:{valType:\"boolean\",dflt:!0,editType:\"calc\"},minorgridcount:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},minorgridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},minorgridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"calc\"},startline:{valType:\"boolean\",editType:\"calc\"},startlinecolor:{valType:\"color\",editType:\"calc\"},startlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endline:{valType:\"boolean\",editType:\"calc\"},endlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endlinecolor:{valType:\"color\",editType:\"calc\"},tick0:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},dtick:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},arraytick0:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},arraydtick:{valType:\"integer\",min:1,dflt:1,editType:\"calc\"},_deprecated:{title:{valType:\"string\",editType:\"calc\"},titlefont:n({editType:\"calc\"}),titleoffset:{valType:\"number\",dflt:10,editType:\"calc\"}},editType:\"calc\"}},{\"../../components/color/attributes\":592,\"../../constants/docs\":690,\"../../plot_api/edit_types\":750,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/font_attributes\":793}],901:[function(t,e,r){\"use strict\";var n=t(\"./attributes\"),i=t(\"../../components/color\").addOpacity,a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/tick_value_defaults\"),l=t(\"../../plots/cartesian/tick_label_defaults\"),c=t(\"../../plots/cartesian/category_order_defaults\"),u=t(\"../../plots/cartesian/set_convert\"),h=t(\"../../plots/cartesian/axis_autotype\");e.exports=function(t,e,r){var f=r.letter,p=r.font||{},d=n[f+\"axis\"];function g(r,n){return o.coerce(t,e,d,r,n)}function v(r,n){return o.coerce2(t,e,d,r,n)}r.name&&(e._name=r.name,e._id=r.name);var m=g(\"type\");(\"-\"===m&&(r.data&&function(t,e){if(\"-\"!==t.type)return;var r=t._id.charAt(0),n=t[r+\"calendar\"];t.type=h(e,n)}(e,r.data),\"-\"===e.type?e.type=\"linear\":m=t.type=e.type),g(\"smoothing\"),g(\"cheatertype\"),g(\"showticklabels\"),g(\"labelprefix\",f+\" = \"),g(\"labelsuffix\"),g(\"showtickprefix\"),g(\"showticksuffix\"),g(\"separatethousands\"),g(\"tickformat\"),g(\"exponentformat\"),g(\"showexponent\"),g(\"categoryorder\"),g(\"tickmode\"),g(\"tickvals\"),g(\"ticktext\"),g(\"tick0\"),g(\"dtick\"),\"array\"===e.tickmode&&(g(\"arraytick0\"),g(\"arraydtick\")),g(\"labelpadding\"),e._hovertitle=f,\"date\"===m)&&a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",r.calendar);u(e,r.fullLayout),e.c2p=o.identity;var y=g(\"color\",r.dfltColor),x=y===t.color?y:p.color;g(\"title.text\")&&(o.coerceFont(g,\"title.font\",{family:p.family,size:Math.round(1.2*p.size),color:x}),g(\"title.offset\")),g(\"tickangle\"),g(\"autorange\",!e.isValidRange(t.range))&&g(\"rangemode\"),g(\"range\"),e.cleanRange(),g(\"fixedrange\"),s(t,e,g,m),l(t,e,g,m,r),c(t,e,g,{data:r.data,dataAttr:f});var b=v(\"gridcolor\",i(y,.3)),_=v(\"gridwidth\"),w=g(\"showgrid\");w||(delete e.gridcolor,delete e.gridwidth);var k=v(\"startlinecolor\",y),T=v(\"startlinewidth\",_);g(\"startline\",e.showgrid||!!k||!!T)||(delete e.startlinecolor,delete e.startlinewidth);var A=v(\"endlinecolor\",y),M=v(\"endlinewidth\",_);return g(\"endline\",e.showgrid||!!A||!!M)||(delete e.endlinecolor,delete e.endlinewidth),w?(g(\"minorgridcount\"),g(\"minorgridwidth\",_),g(\"minorgridcolor\",i(b,.06)),e.minorgridcount||(delete e.minorgridwidth,delete e.minorgridcolor)):(delete e.gridcolor,delete e.gridWidth),\"none\"===e.showticklabels&&(delete e.tickfont,delete e.tickangle,delete e.showexponent,delete e.exponentformat,delete e.tickformat,delete e.showticksuffix,delete e.showtickprefix),e.showticksuffix||delete e.ticksuffix,e.showtickprefix||delete e.tickprefix,g(\"tickmode\"),e}},{\"../../components/color\":593,\"../../lib\":719,\"../../plots/cartesian/axis_autotype\":768,\"../../plots/cartesian/category_order_defaults\":771,\"../../plots/cartesian/set_convert\":785,\"../../plots/cartesian/tick_label_defaults\":786,\"../../plots/cartesian/tick_value_defaults\":788,\"../../registry\":847,\"./attributes\":898}],902:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\").isArray1D,a=t(\"./cheater_basis\"),o=t(\"./array_minmax\"),s=t(\"./calc_gridlines\"),l=t(\"./calc_labels\"),c=t(\"./calc_clippath\"),u=t(\"../heatmap/clean_2d_array\"),h=t(\"./smooth_fill_2d_array\"),f=t(\"../heatmap/convert_column_xyz\"),p=t(\"./set_convert\");e.exports=function(t,e){var r=n.getFromId(t,e.xaxis),d=n.getFromId(t,e.yaxis),g=e.aaxis,v=e.baxis,m=e.x,y=e.y,x=[];m&&i(m)&&x.push(\"x\"),y&&i(y)&&x.push(\"y\"),x.length&&f(e,g,v,\"a\",\"b\",x);var b=e._a=e._a||e.a,_=e._b=e._b||e.b;m=e._x||e.x,y=e._y||e.y;var w={};if(e._cheater){var k=\"index\"===g.cheatertype?b.length:b,T=\"index\"===v.cheatertype?_.length:_;m=a(k,T,e.cheaterslope)}e._x=m=u(m),e._y=y=u(y),h(m,b,_),h(y,b,_),p(e),e.setScale();var A=o(m),M=o(y),S=.5*(A[1]-A[0]),E=.5*(A[1]+A[0]),C=.5*(M[1]-M[0]),L=.5*(M[1]+M[0]);return A=[E-1.3*S,E+1.3*S],M=[L-1.3*C,L+1.3*C],e._extremes[r._id]=n.findExtremes(r,A,{padded:!0}),e._extremes[d._id]=n.findExtremes(d,M,{padded:!0}),s(e,\"a\",\"b\"),s(e,\"b\",\"a\"),l(e,g),l(e,v),w.clipsegments=c(e._xctrl,e._yctrl,g,v),w.x=m,w.y=y,w.a=b,w.b=_,[w]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../heatmap/clean_2d_array\":1003,\"../heatmap/convert_column_xyz\":1005,\"./array_minmax\":897,\"./calc_clippath\":903,\"./calc_gridlines\":904,\"./calc_labels\":905,\"./cheater_basis\":907,\"./set_convert\":920,\"./smooth_fill_2d_array\":921}],903:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a,o,s=[],l=!!r.smoothing,c=!!n.smoothing,u=t[0].length-1,h=t.length-1;for(i=0,a=[],o=[];i<=u;i++)a[i]=t[0][i],o[i]=e[0][i];for(s.push({x:a,y:o,bicubic:l}),i=0,a=[],o=[];i<=h;i++)a[i]=t[i][u],o[i]=e[i][u];for(s.push({x:a,y:o,bicubic:c}),i=u,a=[],o=[];i>=0;i--)a[u-i]=t[h][i],o[u-i]=e[h][i];for(s.push({x:a,y:o,bicubic:l}),i=h,a=[],o=[];i>=0;i--)a[h-i]=t[i][0],o[h-i]=e[i][0];return s.push({x:a,y:o,bicubic:c}),s}},{}],904:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e,r){var a,o,s,l,c,u,h,f,p,d,g,v,m,y,x=t[\"_\"+e],b=t[e+\"axis\"],_=b._gridlines=[],w=b._minorgridlines=[],k=b._boundarylines=[],T=t[\"_\"+r],A=t[r+\"axis\"];\"array\"===b.tickmode&&(b.tickvals=x.slice());var M=t._xctrl,S=t._yctrl,E=M[0].length,C=M.length,L=t._a.length,P=t._b.length;n.prepTicks(b),\"array\"===b.tickmode&&delete b.tickvals;var O=b.smoothing?3:1;function z(n){var i,a,o,s,l,c,u,h,p,d,g,v,m=[],y=[],x={};if(\"b\"===e)for(a=t.b2j(n),o=Math.floor(Math.max(0,Math.min(P-2,a))),s=a-o,x.length=P,x.crossLength=L,x.xy=function(e){return t.evalxy([],e,a)},x.dxy=function(e,r){return t.dxydi([],e,o,r,s)},i=0;i<L;i++)c=Math.min(L-2,i),u=i-c,h=t.evalxy([],i,a),A.smoothing&&i>0&&(p=t.dxydi([],i-1,o,0,s),m.push(l[0]+p[0]/3),y.push(l[1]+p[1]/3),d=t.dxydi([],i-1,o,1,s),m.push(h[0]-d[0]/3),y.push(h[1]-d[1]/3)),m.push(h[0]),y.push(h[1]),l=h;else for(i=t.a2i(n),c=Math.floor(Math.max(0,Math.min(L-2,i))),u=i-c,x.length=L,x.crossLength=P,x.xy=function(e){return t.evalxy([],i,e)},x.dxy=function(e,r){return t.dxydj([],c,e,u,r)},a=0;a<P;a++)o=Math.min(P-2,a),s=a-o,h=t.evalxy([],i,a),A.smoothing&&a>0&&(g=t.dxydj([],c,a-1,u,0),m.push(l[0]+g[0]/3),y.push(l[1]+g[1]/3),v=t.dxydj([],c,a-1,u,1),m.push(h[0]-v[0]/3),y.push(h[1]-v[1]/3)),m.push(h[0]),y.push(h[1]),l=h;return x.axisLetter=e,x.axis=b,x.crossAxis=A,x.value=n,x.constvar=r,x.index=f,x.x=m,x.y=y,x.smoothing=A.smoothing,x}function I(n){var i,a,o,s,l,c=[],u=[],h={};if(h.length=x.length,h.crossLength=T.length,\"b\"===e)for(o=Math.max(0,Math.min(P-2,n)),l=Math.min(1,Math.max(0,n-o)),h.xy=function(e){return t.evalxy([],e,n)},h.dxy=function(e,r){return t.dxydi([],e,o,r,l)},i=0;i<E;i++)c[i]=M[n*O][i],u[i]=S[n*O][i];else for(a=Math.max(0,Math.min(L-2,n)),s=Math.min(1,Math.max(0,n-a)),h.xy=function(e){return t.evalxy([],n,e)},h.dxy=function(e,r){return t.dxydj([],a,e,s,r)},i=0;i<C;i++)c[i]=M[i][n*O],u[i]=S[i][n*O];return h.axisLetter=e,h.axis=b,h.crossAxis=A,h.value=x[n],h.constvar=r,h.index=n,h.x=c,h.y=u,h.smoothing=A.smoothing,h}if(\"array\"===b.tickmode){for(l=5e-15,u=(c=[Math.floor((x.length-1-b.arraytick0)/b.arraydtick*(1+l)),Math.ceil(-b.arraytick0/b.arraydtick/(1+l))].sort(function(t,e){return t-e}))[0]-1,h=c[1]+1,f=u;f<h;f++)(o=b.arraytick0+b.arraydtick*f)<0||o>x.length-1||_.push(i(I(o),{color:b.gridcolor,width:b.gridwidth}));for(f=u;f<h;f++)if(s=b.arraytick0+b.arraydtick*f,g=Math.min(s+b.arraydtick,x.length-1),!(s<0||s>x.length-1||g<0||g>x.length-1))for(v=x[s],m=x[g],a=0;a<b.minorgridcount;a++)(y=g-s)<=0||(d=v+(m-v)*(a+1)/(b.minorgridcount+1)*(b.arraydtick/y))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&k.push(i(I(0),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&k.push(i(I(x.length-1),{color:b.endlinecolor,width:b.endlinewidth}))}else{for(l=5e-15,u=(c=[Math.floor((x[x.length-1]-b.tick0)/b.dtick*(1+l)),Math.ceil((x[0]-b.tick0)/b.dtick/(1+l))].sort(function(t,e){return t-e}))[0],h=c[1],f=u;f<=h;f++)p=b.tick0+b.dtick*f,_.push(i(z(p),{color:b.gridcolor,width:b.gridwidth}));for(f=u-1;f<h+1;f++)for(p=b.tick0+b.dtick*f,a=0;a<b.minorgridcount;a++)(d=p+b.dtick*(a+1)/(b.minorgridcount+1))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&k.push(i(z(x[0]),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&k.push(i(z(x[x.length-1]),{color:b.endlinecolor,width:b.endlinewidth}))}}},{\"../../lib/extend\":710,\"../../plots/cartesian/axes\":767}],905:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e){var r,a,o,s=e._labels=[],l=e._gridlines;for(r=0;r<l.length;r++)o=l[r],-1!==[\"start\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{prefix:void 0,suffix:void 0,endAnchor:!0,xy:o.xy(0),dxy:o.dxy(0,0),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a)),-1!==[\"end\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{endAnchor:!1,xy:o.xy(o.crossLength-1),dxy:o.dxy(o.crossLength-2,1),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a))}},{\"../../lib/extend\":710,\"../../plots/cartesian/axes\":767}],906:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=t[0]-e[0],a=t[1]-e[1],o=r[0]-e[0],s=r[1]-e[1],l=Math.pow(i*i+a*a,.25),c=Math.pow(o*o+s*s,.25),u=(c*c*i-l*l*o)*n,h=(c*c*a-l*l*s)*n,f=c*(l+c)*3,p=l*(l+c)*3;return[[e[0]+(f&&u/f),e[1]+(f&&h/f)],[e[0]-(p&&u/p),e[1]-(p&&h/p)]]}},{}],907:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i,a,o,s,l,c,u=[],h=n(t)?t.length:t,f=n(e)?e.length:e,p=n(t)?t:null,d=n(e)?e:null;p&&(o=(p.length-1)/(p[p.length-1]-p[0])/(h-1)),d&&(s=(d.length-1)/(d[d.length-1]-d[0])/(f-1));var g=1/0,v=-1/0;for(a=0;a<f;a++)for(u[a]=[],l=d?(d[a]-d[0])*s:a/(f-1),i=0;i<h;i++)c=(p?(p[i]-p[0])*o:i/(h-1))-l*r,g=Math.min(c,g),v=Math.max(c,v),u[a][i]=c;var m=1/(v-g),y=-g*m;for(a=0;a<f;a++)for(i=0;i<h;i++)u[a][i]=m*u[a][i]+y;return u}},{\"../../lib\":719}],908:[function(t,e,r){\"use strict\";var n=t(\"./catmull_rom\"),i=t(\"../../lib\").ensureArray;function a(t,e,r){var n=-.5*r[0]+1.5*e[0],i=-.5*r[1]+1.5*e[1];return[(2*n+t[0])/3,(2*i+t[1])/3]}e.exports=function(t,e,r,o,s,l){var c,u,h,f,p,d,g,v,m,y,x=r[0].length,b=r.length,_=s?3*x-2:x,w=l?3*b-2:b;for(t=i(t,w),e=i(e,w),h=0;h<w;h++)t[h]=i(t[h],_),e[h]=i(e[h],_);for(u=0,f=0;u<b;u++,f+=l?3:1)for(p=t[f],d=e[f],g=r[u],v=o[u],c=0,h=0;c<x;c++,h+=s?3:1)p[h]=g[c],d[h]=v[c];if(s)for(u=0,f=0;u<b;u++,f+=l?3:1){for(c=1,h=3;c<x-1;c++,h+=3)m=n([r[u][c-1],o[u][c-1]],[r[u][c],o[u][c]],[r[u][c+1],o[u][c+1]],s),t[f][h-1]=m[0][0],e[f][h-1]=m[0][1],t[f][h+1]=m[1][0],e[f][h+1]=m[1][1];y=a([t[f][0],e[f][0]],[t[f][2],e[f][2]],[t[f][3],e[f][3]]),t[f][1]=y[0],e[f][1]=y[1],y=a([t[f][_-1],e[f][_-1]],[t[f][_-3],e[f][_-3]],[t[f][_-4],e[f][_-4]]),t[f][_-2]=y[0],e[f][_-2]=y[1]}if(l)for(h=0;h<_;h++){for(f=3;f<w-3;f+=3)m=n([t[f-3][h],e[f-3][h]],[t[f][h],e[f][h]],[t[f+3][h],e[f+3][h]],l),t[f-1][h]=m[0][0],e[f-1][h]=m[0][1],t[f+1][h]=m[1][0],e[f+1][h]=m[1][1];y=a([t[0][h],e[0][h]],[t[2][h],e[2][h]],[t[3][h],e[3][h]]),t[1][h]=y[0],e[1][h]=y[1],y=a([t[w-1][h],e[w-1][h]],[t[w-3][h],e[w-3][h]],[t[w-4][h],e[w-4][h]]),t[w-2][h]=y[0],e[w-2][h]=y[1]}if(s&&l)for(f=1;f<w;f+=(f+1)%3==0?2:1){for(h=3;h<_-3;h+=3)m=n([t[f][h-3],e[f][h-3]],[t[f][h],e[f][h]],[t[f][h+3],e[f][h+3]],s),t[f][h-1]=.5*(t[f][h-1]+m[0][0]),e[f][h-1]=.5*(e[f][h-1]+m[0][1]),t[f][h+1]=.5*(t[f][h+1]+m[1][0]),e[f][h+1]=.5*(e[f][h+1]+m[1][1]);y=a([t[f][0],e[f][0]],[t[f][2],e[f][2]],[t[f][3],e[f][3]]),t[f][1]=.5*(t[f][1]+y[0]),e[f][1]=.5*(e[f][1]+y[1]),y=a([t[f][_-1],e[f][_-1]],[t[f][_-3],e[f][_-3]],[t[f][_-4],e[f][_-4]]),t[f][_-2]=.5*(t[f][_-2]+y[0]),e[f][_-2]=.5*(e[f][_-2]+y[1])}return[t,e]}},{\"../../lib\":719,\"./catmull_rom\":906}],909:[function(t,e,r){\"use strict\";e.exports={RELATIVE_CULL_TOLERANCE:1e-6}},{}],910:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3,n*=3;var f=i*i,p=1-i,d=p*p,g=p*i*2,v=-3*d,m=3*(d-g),y=3*(g-f),x=3*f,b=a*a,_=b*a,w=1-a,k=w*w,T=k*w;for(h=0;h<t.length;h++)o=v*(u=t[h])[n][r]+m*u[n][r+1]+y*u[n][r+2]+x*u[n][r+3],s=v*u[n+1][r]+m*u[n+1][r+1]+y*u[n+1][r+2]+x*u[n+1][r+3],l=v*u[n+2][r]+m*u[n+2][r+1]+y*u[n+2][r+2]+x*u[n+2][r+3],c=v*u[n+3][r]+m*u[n+3][r+1]+y*u[n+3][r+2]+x*u[n+3][r+3],e[h]=T*o+3*(k*a*s+w*b*l)+_*c;return e}:e?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),r*=3;var u=i*i,h=1-i,f=h*h,p=h*i*2,d=-3*f,g=3*(f-p),v=3*(p-u),m=3*u,y=1-a;for(l=0;l<t.length;l++)o=d*(c=t[l])[n][r]+g*c[n][r+1]+v*c[n][r+2]+m*c[n][r+3],s=d*c[n+1][r]+g*c[n+1][r+1]+v*c[n+1][r+2]+m*c[n+1][r+3],e[l]=y*o+a*s;return e}:r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),n*=3;var f=a*a,p=f*a,d=1-a,g=d*d,v=g*d;for(u=0;u<t.length;u++)o=(h=t[u])[n][r+1]-h[n][r],s=h[n+1][r+1]-h[n+1][r],l=h[n+2][r+1]-h[n+2][r],c=h[n+3][r+1]-h[n+3][r],e[u]=v*o+3*(g*a*s+d*f*l)+p*c;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-a;for(l=0;l<t.length;l++)o=(c=t[l])[n][r+1]-c[n][r],s=c[n+1][r+1]-c[n+1][r],e[l]=u*o+a*s;return e}}},{}],911:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3,n*=3;var f=i*i,p=f*i,d=1-i,g=d*d,v=g*d,m=a*a,y=1-a,x=y*y,b=y*a*2,_=-3*x,w=3*(x-b),k=3*(b-m),T=3*m;for(h=0;h<t.length;h++)o=_*(u=t[h])[n][r]+w*u[n+1][r]+k*u[n+2][r]+T*u[n+3][r],s=_*u[n][r+1]+w*u[n+1][r+1]+k*u[n+2][r+1]+T*u[n+3][r+1],l=_*u[n][r+2]+w*u[n+1][r+2]+k*u[n+2][r+2]+T*u[n+3][r+2],c=_*u[n][r+3]+w*u[n+1][r+3]+k*u[n+2][r+3]+T*u[n+3][r+3],e[h]=v*o+3*(g*i*s+d*f*l)+p*c;return e}:e?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3;var f=a*a,p=f*a,d=1-a,g=d*d,v=g*d;for(u=0;u<t.length;u++)o=(h=t[u])[n+1][r]-h[n][r],s=h[n+1][r+1]-h[n][r+1],l=h[n+1][r+2]-h[n][r+2],c=h[n+1][r+3]-h[n][r+3],e[u]=v*o+3*(g*a*s+d*f*l)+p*c;return e}:r?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),n*=3;var u=1-i,h=a*a,f=1-a,p=f*f,d=f*a*2,g=-3*p,v=3*(p-d),m=3*(d-h),y=3*h;for(l=0;l<t.length;l++)o=g*(c=t[l])[n][r]+v*c[n+1][r]+m*c[n+2][r]+y*c[n+3][r],s=g*c[n][r+1]+v*c[n+1][r+1]+m*c[n+2][r+1]+y*c[n+3][r+1],e[l]=u*o+i*s;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-i;for(l=0;l<t.length;l++)o=(c=t[l])[n+1][r]-c[n][r],s=c[n+1][r+1]-c[n][r+1],e[l]=u*o+i*s;return e}}},{}],912:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=e-2,o=r-2;return n&&i?function(e,r,n){var i,s,l,c,u,h;e||(e=[]);var f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));f*=3,p*=3;var v=d*d,m=v*d,y=1-d,x=y*y,b=x*y,_=g*g,w=_*g,k=1-g,T=k*k,A=T*k;for(h=0;h<t.length;h++)i=b*(u=t[h])[p][f]+3*(x*d*u[p][f+1]+y*v*u[p][f+2])+m*u[p][f+3],s=b*u[p+1][f]+3*(x*d*u[p+1][f+1]+y*v*u[p+1][f+2])+m*u[p+1][f+3],l=b*u[p+2][f]+3*(x*d*u[p+2][f+1]+y*v*u[p+2][f+2])+m*u[p+2][f+3],c=b*u[p+3][f]+3*(x*d*u[p+3][f+1]+y*v*u[p+3][f+2])+m*u[p+3][f+3],e[h]=A*i+3*(T*g*s+k*_*l)+w*c;return e}:n?function(e,r,n){e||(e=[]);var i,s,l,c,u,h,f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));f*=3;var v=d*d,m=v*d,y=1-d,x=y*y,b=x*y,_=1-g;for(u=0;u<t.length;u++)i=_*(h=t[u])[p][f]+g*h[p+1][f],s=_*h[p][f+1]+g*h[p+1][f+1],l=_*h[p][f+2]+g*h[p+1][f+1],c=_*h[p][f+3]+g*h[p+1][f+1],e[u]=b*i+3*(x*d*s+y*v*l)+m*c;return e}:i?function(e,r,n){e||(e=[]);var i,s,l,c,u,h,f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));p*=3;var v=g*g,m=v*g,y=1-g,x=y*y,b=x*y,_=1-d;for(u=0;u<t.length;u++)i=_*(h=t[u])[p][f]+d*h[p][f+1],s=_*h[p+1][f]+d*h[p+1][f+1],l=_*h[p+2][f]+d*h[p+2][f+1],c=_*h[p+3][f]+d*h[p+3][f+1],e[u]=b*i+3*(x*g*s+y*v*l)+m*c;return e}:function(e,r,n){e||(e=[]);var i,s,l,c,u=Math.max(0,Math.min(Math.floor(r),a)),h=Math.max(0,Math.min(Math.floor(n),o)),f=Math.max(0,Math.min(1,r-u)),p=Math.max(0,Math.min(1,n-h)),d=1-p,g=1-f;for(l=0;l<t.length;l++)i=g*(c=t[l])[h][u]+f*c[h][u+1],s=g*c[h+1][u]+f*c[h+1][u+1],e[l]=d*i+p*s;return e}}},{}],913:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xy_defaults\"),a=t(\"./ab_defaults\"),o=t(\"./attributes\"),s=t(\"../../components/color/attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,o,r,i)}e._clipPathId=\"clip\"+e.uid+\"carpet\";var u=c(\"color\",s.defaultLine);(n.coerceFont(c,\"font\"),c(\"carpet\"),a(t,e,l,c,u),e.a&&e.b)?(e.a.length<3&&(e.aaxis.smoothing=0),e.b.length<3&&(e.baxis.smoothing=0),i(t,e,c)||(e.visible=!1),e._cheater&&c(\"cheaterslope\")):e.visible=!1}},{\"../../components/color/attributes\":592,\"../../lib\":719,\"./ab_defaults\":896,\"./attributes\":898,\"./xy_defaults\":922}],914:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),plot:t(\"./plot\"),calc:t(\"./calc\"),animatable:!0,isContainer:!0,moduleType:\"trace\",name:\"carpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"carpetAxis\",\"notLegendIsolatable\",\"noMultiCategory\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":898,\"./calc\":902,\"./defaults\":913,\"./plot\":919}],915:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r,n=t._fullData.length,i=0;i<n;i++){var a=t._fullData[i];if(a.index!==e.index&&(\"carpet\"===a.type&&(r||(r=a),a.carpet===e.carpet)))return a}return r}},{}],916:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(0===t.length)return\"\";var n,i=[],a=r?3:1;for(n=0;n<t.length;n+=a)i.push(t[n]+\",\"+e[n]),r&&n<t.length-a&&(i.push(\"C\"),i.push([t[n+1]+\",\"+e[n+1],t[n+2]+\",\"+e[n+2]+\" \"].join(\" \")));return i.join(r?\"\":\"L\")}},{}],917:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i;for(n(t)?t.length>e.length&&(t=t.slice(0,e.length)):t=[],i=0;i<e.length;i++)t[i]=r(e[i]);return t}},{\"../../lib\":719}],918:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i[0]*t.dpdx(e),s=i[1]*t.dpdy(r),l=1,c=1;if(a){var u=Math.sqrt(i[0]*i[0]+i[1]*i[1]),h=Math.sqrt(a[0]*a[0]+a[1]*a[1]),f=(i[0]*a[0]+i[1]*a[1])/u/h;c=Math.max(0,f)}var p=180*Math.atan2(s,o)/Math.PI;return p<-90?(p+=180,l=-l):p>90&&(p-=180,l=-l),{angle:p,flip:l,p:t.c2p(n,e,r),offsetMultplier:c}}},{}],919:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"./map_1d_array\"),o=t(\"./makepath\"),s=t(\"./orient_text\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib\"),u=t(\"../../constants/alignment\");function h(t,e,r,i,s,l){var c=\"const-\"+s+\"-lines\",u=r.selectAll(\".\"+c).data(l);u.enter().append(\"path\").classed(c,!0).style(\"vector-effect\",\"non-scaling-stroke\"),u.each(function(r){var i=r,s=i.x,l=i.y,c=a([],s,t.c2p),u=a([],l,e.c2p),h=\"M\"+o(c,u,i.smoothing);n.select(this).attr(\"d\",h).style(\"stroke-width\",i.width).style(\"stroke\",i.color).style(\"fill\",\"none\")}),u.exit().remove()}function f(t,e,r,a,o,c,u,h){var f=c.selectAll(\"text.\"+h).data(u);f.enter().append(\"text\").classed(h,!0);var p=0,d={};return f.each(function(o,c){var u;if(\"auto\"===o.axis.tickangle)u=s(a,e,r,o.xy,o.dxy);else{var h=(o.axis.tickangle+180)*Math.PI/180;u=s(a,e,r,o.xy,[Math.cos(h),Math.sin(h)])}c||(d={angle:u.angle,flip:u.flip});var f=(o.endAnchor?-1:1)*u.flip,g=n.select(this).attr({\"text-anchor\":f>0?\"start\":\"end\",\"data-notex\":1}).call(i.font,o.font).text(o.text).call(l.convertToTspans,t),v=i.bBox(this);g.attr(\"transform\",\"translate(\"+u.p[0]+\",\"+u.p[1]+\") rotate(\"+u.angle+\")translate(\"+o.axis.labelpadding*f+\",\"+.3*v.height+\")\"),p=Math.max(p,v.width+o.axis.labelpadding)}),f.exit().remove(),d.maxExtent=p,d}e.exports=function(t,e,r,i){var l=e.xaxis,u=e.yaxis,p=t._fullLayout._clips;c.makeTraceGroups(i,r,\"trace\").each(function(e){var r=n.select(this),i=e[0],d=i.trace,v=d.aaxis,m=d.baxis,y=c.ensureSingle(r,\"g\",\"minorlayer\"),x=c.ensureSingle(r,\"g\",\"majorlayer\"),b=c.ensureSingle(r,\"g\",\"boundarylayer\"),_=c.ensureSingle(r,\"g\",\"labellayer\");r.style(\"opacity\",d.opacity),h(l,u,x,v,\"a\",v._gridlines),h(l,u,x,m,\"b\",m._gridlines),h(l,u,y,v,\"a\",v._minorgridlines),h(l,u,y,m,\"b\",m._minorgridlines),h(l,u,b,v,\"a-boundary\",v._boundarylines),h(l,u,b,m,\"b-boundary\",m._boundarylines);var w=f(t,l,u,d,i,_,v._labels,\"a-label\"),k=f(t,l,u,d,i,_,m._labels,\"b-label\");!function(t,e,r,n,i,a,o,l){var u,h,f,p,d=c.aggNums(Math.min,null,r.a),v=c.aggNums(Math.max,null,r.a),m=c.aggNums(Math.min,null,r.b),y=c.aggNums(Math.max,null,r.b);u=.5*(d+v),h=m,f=r.ab2xy(u,h,!0),p=r.dxyda_rough(u,h),void 0===o.angle&&c.extendFlat(o,s(r,i,a,f,r.dxydb_rough(u,h)));g(t,e,r,n,f,p,r.aaxis,i,a,o,\"a-title\"),u=d,h=.5*(m+y),f=r.ab2xy(u,h,!0),p=r.dxydb_rough(u,h),void 0===l.angle&&c.extendFlat(l,s(r,i,a,f,r.dxyda_rough(u,h)));g(t,e,r,n,f,p,r.baxis,i,a,l,\"b-title\")}(t,_,d,i,l,u,w,k),function(t,e,r,n,i){var s,l,u,h,f=r.select(\"#\"+t._clipPathId);f.size()||(f=r.append(\"clipPath\").classed(\"carpetclip\",!0));var p=c.ensureSingle(f,\"path\",\"carpetboundary\"),d=e.clipsegments,g=[];for(h=0;h<d.length;h++)s=d[h],l=a([],s.x,n.c2p),u=a([],s.y,i.c2p),g.push(o(l,u,s.bicubic));var v=\"M\"+g.join(\"L\")+\"Z\";f.attr(\"id\",t._clipPathId),p.attr(\"d\",v)}(d,i,p,l,u)})};var p=u.LINE_SPACING,d=(1-u.MID_SHIFT)/p+1;function g(t,e,r,a,o,c,u,h,f,g,v){var m=[];u.title.text&&m.push(u.title.text);var y=e.selectAll(\"text.\"+v).data(m),x=g.maxExtent;y.enter().append(\"text\").classed(v,!0),y.each(function(){var e=s(r,h,f,o,c);-1===[\"start\",\"both\"].indexOf(u.showticklabels)&&(x=0);var a=u.title.font.size;x+=a+u.title.offset;var v=(g.angle+(g.flip<0?180:0)-e.angle+450)%360,m=v>90&&v<270,y=n.select(this);y.text(u.title.text).call(l.convertToTspans,t),m&&(x=(-l.lineCount(y)+d)*p*a-x),y.attr(\"transform\",\"translate(\"+e.p[0]+\",\"+e.p[1]+\") rotate(\"+e.angle+\") translate(0,\"+x+\")\").classed(\"user-select-none\",!0).attr(\"text-anchor\",\"middle\").call(i.font,u.title.font)}),y.exit().remove()}},{\"../../components/drawing\":614,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"./makepath\":916,\"./map_1d_array\":917,\"./orient_text\":918,d3:163}],920:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/search\").findBin,a=t(\"./compute_control_points\"),o=t(\"./create_spline_evaluator\"),s=t(\"./create_i_derivative_evaluator\"),l=t(\"./create_j_derivative_evaluator\");e.exports=function(t){var e=t._a,r=t._b,c=e.length,u=r.length,h=t.aaxis,f=t.baxis,p=e[0],d=e[c-1],g=r[0],v=r[u-1],m=e[e.length-1]-e[0],y=r[r.length-1]-r[0],x=m*n.RELATIVE_CULL_TOLERANCE,b=y*n.RELATIVE_CULL_TOLERANCE;p-=x,d+=x,g-=b,v+=b,t.isVisible=function(t,e){return t>p&&t<d&&e>g&&e<v},t.isOccluded=function(t,e){return t<p||t>d||e<g||e>v},t.setScale=function(){var e=t._x,r=t._y,n=a(t._xctrl,t._yctrl,e,r,h.smoothing,f.smoothing);t._xctrl=n[0],t._yctrl=n[1],t.evalxy=o([t._xctrl,t._yctrl],c,u,h.smoothing,f.smoothing),t.dxydi=s([t._xctrl,t._yctrl],h.smoothing,f.smoothing),t.dxydj=l([t._xctrl,t._yctrl],h.smoothing,f.smoothing)},t.i2a=function(t){var r=Math.max(0,Math.floor(t[0]),c-2),n=t[0]-r;return(1-n)*e[r]+n*e[r+1]},t.j2b=function(t){var e=Math.max(0,Math.floor(t[1]),c-2),n=t[1]-e;return(1-n)*r[e]+n*r[e+1]},t.ij2ab=function(e){return[t.i2a(e[0]),t.j2b(e[1])]},t.a2i=function(t){var r=Math.max(0,Math.min(i(t,e),c-2)),n=e[r],a=e[r+1];return Math.max(0,Math.min(c-1,r+(t-n)/(a-n)))},t.b2j=function(t){var e=Math.max(0,Math.min(i(t,r),u-2)),n=r[e],a=r[e+1];return Math.max(0,Math.min(u-1,e+(t-n)/(a-n)))},t.ab2ij=function(e){return[t.a2i(e[0]),t.b2j(e[1])]},t.i2c=function(e,r){return t.evalxy([],e,r)},t.ab2xy=function(n,i,a){if(!a&&(n<e[0]||n>e[c-1]|i<r[0]||i>r[u-1]))return[!1,!1];var o=t.a2i(n),s=t.b2j(i),l=t.evalxy([],o,s);if(a){var h,f,p,d,g=0,v=0,m=[];n<e[0]?(h=0,f=0,g=(n-e[0])/(e[1]-e[0])):n>e[c-1]?(h=c-2,f=1,g=(n-e[c-1])/(e[c-1]-e[c-2])):f=o-(h=Math.max(0,Math.min(c-2,Math.floor(o)))),i<r[0]?(p=0,d=0,v=(i-r[0])/(r[1]-r[0])):i>r[u-1]?(p=u-2,d=1,v=(i-r[u-1])/(r[u-1]-r[u-2])):d=s-(p=Math.max(0,Math.min(u-2,Math.floor(s)))),g&&(t.dxydi(m,h,p,f,d),l[0]+=m[0]*g,l[1]+=m[1]*g),v&&(t.dxydj(m,h,p,f,d),l[0]+=m[0]*v,l[1]+=m[1]*v)}return l},t.c2p=function(t,e,r){return[e.c2p(t[0]),r.c2p(t[1])]},t.p2x=function(t,e,r){return[e.p2c(t[0]),r.p2c(t[1])]},t.dadi=function(t){var r=Math.max(0,Math.min(e.length-2,t));return e[r+1]-e[r]},t.dbdj=function(t){var e=Math.max(0,Math.min(r.length-2,t));return r[e+1]-r[e]},t.dxyda=function(e,r,n,i){var a=t.dxydi(null,e,r,n,i),o=t.dadi(e,n);return[a[0]/o,a[1]/o]},t.dxydb=function(e,r,n,i){var a=t.dxydj(null,e,r,n,i),o=t.dbdj(r,i);return[a[0]/o,a[1]/o]},t.dxyda_rough=function(e,r,n){var i=m*(n||.1),a=t.ab2xy(e+i,r,!0),o=t.ab2xy(e-i,r,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dxydb_rough=function(e,r,n){var i=y*(n||.1),a=t.ab2xy(e,r+i,!0),o=t.ab2xy(e,r-i,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dpdx=function(t){return t._m},t.dpdy=function(t){return t._m}}},{\"../../lib/search\":738,\"./compute_control_points\":908,\"./constants\":909,\"./create_i_derivative_evaluator\":910,\"./create_j_derivative_evaluator\":911,\"./create_spline_evaluator\":912}],921:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r){var i,a,o,s=[],l=[],c=t[0].length,u=t.length;function h(e,r){var n,i=0,a=0;return e>0&&void 0!==(n=t[r][e-1])&&(a++,i+=n),e<c-1&&void 0!==(n=t[r][e+1])&&(a++,i+=n),r>0&&void 0!==(n=t[r-1][e])&&(a++,i+=n),r<u-1&&void 0!==(n=t[r+1][e])&&(a++,i+=n),i/Math.max(1,a)}var f,p,d,g,v,m,y,x,b,_,w,k=0;for(i=0;i<c;i++)for(a=0;a<u;a++)void 0===t[a][i]&&(s.push(i),l.push(a),t[a][i]=h(i,a)),k=Math.max(k,Math.abs(t[a][i]));if(!s.length)return t;var T=0,A=0,M=s.length;do{for(T=0,o=0;o<M;o++){i=s[o],a=l[o];var S,E,C,L,P,O,z=0,I=0;0===i?(C=e[P=Math.min(c-1,2)],L=e[1],S=t[a][P],I+=(E=t[a][1])+(E-S)*(e[0]-L)/(L-C),z++):i===c-1&&(C=e[P=Math.max(0,c-3)],L=e[c-2],S=t[a][P],I+=(E=t[a][c-2])+(E-S)*(e[c-1]-L)/(L-C),z++),(0===i||i===c-1)&&a>0&&a<u-1&&(f=r[a+1]-r[a],I+=((p=r[a]-r[a-1])*t[a+1][i]+f*t[a-1][i])/(p+f),z++),0===a?(C=r[O=Math.min(u-1,2)],L=r[1],S=t[O][i],I+=(E=t[1][i])+(E-S)*(r[0]-L)/(L-C),z++):a===u-1&&(C=r[O=Math.max(0,u-3)],L=r[u-2],S=t[O][i],I+=(E=t[u-2][i])+(E-S)*(r[u-1]-L)/(L-C),z++),(0===a||a===u-1)&&i>0&&i<c-1&&(f=e[i+1]-e[i],I+=((p=e[i]-e[i-1])*t[a][i+1]+f*t[a][i-1])/(p+f),z++),z?I/=z:(d=e[i+1]-e[i],g=e[i]-e[i-1],x=(v=r[a+1]-r[a])*(m=r[a]-r[a-1])*(v+m),I=((y=d*g*(d+g))*(m*t[a+1][i]+v*t[a-1][i])+x*(g*t[a][i+1]+d*t[a][i-1]))/(x*(g+d)+y*(m+v))),T+=(_=(b=I-t[a][i])/k)*_,w=z?0:.85,t[a][i]+=b*(1+w)}T=Math.sqrt(T)}while(A++<100&&T>1e-5);return n.log(\"Smoother converged to\",T,\"after\",A,\"iterations\"),t}},{\"../../lib\":719}],922:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArray1D;e.exports=function(t,e,r){var i=r(\"x\"),a=i&&i.length,o=r(\"y\"),s=o&&o.length;if(!a&&!s)return!1;if(e._cheater=!i,a&&!n(i)||s&&!n(o))e._length=null;else{var l=a?i.length:1/0;s&&(l=Math.min(l,o.length)),e.a&&e.a.length&&(l=Math.min(l,e.a.length)),e.b&&e.b.length&&(l=Math.min(l,e.b.length)),e._length=l}return!0}},{\"../../lib\":719}],923:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scattergeo/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/color/attributes\").defaultLine,l=t(\"../../lib/extend\").extendFlat,c=i.marker.line;e.exports=l({locations:{valType:\"data_array\",editType:\"calc\"},locationmode:i.locationmode,z:{valType:\"data_array\",editType:\"calc\"},text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),marker:{line:{color:l({},c.color,{dflt:s}),width:l({},c.width,{dflt:1}),editType:\"calc\"},opacity:{valType:\"number\",arrayOk:!0,min:0,max:1,dflt:1,editType:\"style\"},editType:\"calc\"},selected:{marker:{opacity:i.selected.marker.opacity,editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:i.unselected.marker.opacity,editType:\"plot\"},editType:\"plot\"},hoverinfo:l({},o.hoverinfo,{editType:\"calc\",flags:[\"location\",\"z\",\"text\",\"name\"]}),hovertemplate:n()},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/color/attributes\":592,\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scattergeo/attributes\":1151}],924:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../components/colorscale/calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\");function l(t){return t&&\"string\"==typeof t}e.exports=function(t,e){var r,c=e._length,u=new Array(c);r=e.geojson?function(t){return l(t)||n(t)}:l;for(var h=0;h<c;h++){var f=u[h]={},p=e.locations[h],d=e.z[h];r(p)&&n(d)?(f.loc=p,f.z=d):(f.loc=null,f.z=i),f.index=h}return o(u,e),a(t,e,{vals:e.z,containerStr:\"\",cLetter:\"z\"}),s(u,e),u}},{\"../../components/colorscale/calc\":601,\"../../constants/numerical\":695,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc_selection\":1114,\"fast-isnumeric\":225}],925:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\");l&&l.length&&n.isArrayOrTypedArray(c)&&c.length?(e._length=Math.min(l.length,c.length),s(\"locationmode\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":923}],926:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){t.location=e.location,t.z=e.z;var a=n[i];return a.fIn&&(t.properties=a.fIn.properties),t}},{}],927:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"./attributes\"),a=t(\"../../lib\").fillText;e.exports=function(t,e,r){var o,s,l,c,u=t.cd,h=u[0].trace,f=t.subplot;for(s=0;s<u.length;s++)if(c=!1,(o=u[s])._polygons){for(l=0;l<o._polygons.length;l++)o._polygons[l].contains([e,r])&&(c=!c),o._polygons[l].contains([e+360,r])&&(c=!c);if(c)break}if(c&&o)return t.x0=t.x1=t.xa.c2p(o.ct),t.y0=t.y1=t.ya.c2p(o.ct),t.index=o.index,t.location=o.loc,t.z=o.z,t.zLabel=n.tickText(f.mockAxis,f.mockAxis.c2l(o.z),\"hover\").text,t.hovertemplate=o.hovertemplate,function(t,e,r){if(e.hovertemplate)return;var n=r.hi||e.hoverinfo,o=\"all\"===n?i.hoverinfo.flags:n.split(\"+\"),s=-1!==o.indexOf(\"name\"),l=-1!==o.indexOf(\"location\"),c=-1!==o.indexOf(\"z\"),u=-1!==o.indexOf(\"text\"),h=[];!s&&l?t.nameOverride=r.loc:(s&&(t.nameOverride=e.name),l&&h.push(r.loc));c&&h.push(t.zLabel);u&&a(r,e,h);t.extraText=h.join(\"<br>\")}(t,h,o,f.mockAxis),[t]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./attributes\":923}],928:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"choropleth\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"noOpacity\"],meta:{}}},{\"../../plots/geo\":797,\"../heatmap/colorbar\":1004,\"./attributes\":923,\"./calc\":924,\"./defaults\":925,\"./event_data\":926,\"./hover\":927,\"./plot\":929,\"./select\":930,\"./style\":931}],929:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../lib/polygon\"),o=t(\"../../lib/topojson_utils\").getTopojsonFeatures,s=t(\"../../lib/geo_location_utils\").locationToFeature,l=t(\"./style\").style;function c(t,e){for(var r=t[0].trace,n=t.length,i=o(r,e),a=0;a<n;a++){var l=t[a],c=s(r.locationmode,l.loc,i);c?(l.geojson=c,l.ct=c.properties.ct,l._polygons=u(c)):l.geojson=null}}function u(t){var e,r,n,i,o=t.geometry,s=o.coordinates,l=t.id,c=[];function u(t){for(var e=0;e<t.length-1;e++)if(t[e][0]>0&&t[e+1][0]<0)return e;return null}switch(e=\"RUS\"===l||\"FJI\"===l?function(t){var e;if(null===u(t))e=t;else for(e=new Array(t.length),i=0;i<t.length;i++)e[i]=[t[i][0]<0?t[i][0]+360:t[i][0],t[i][1]];c.push(a.tester(e))}:\"ATA\"===l?function(t){var e=u(t);if(null===e)return c.push(a.tester(t));var r=new Array(t.length+1),n=0;for(i=0;i<t.length;i++)i>e?r[n++]=[t[i][0]+360,t[i][1]]:i===e?(r[n++]=t[i],r[n++]=[t[i][0],-90]):r[n++]=t[i];var o=a.tester(r);o.pts.pop(),c.push(o)}:function(t){c.push(a.tester(t))},o.type){case\"MultiPolygon\":for(r=0;r<s.length;r++)for(n=0;n<s[r].length;n++)e(s[r][n]);break;case\"Polygon\":for(r=0;r<s.length;r++)e(s[r])}return c}e.exports={plot:function(t,e,r){for(var a=0;a<r.length;a++)c(r[a],e.topojson);var o=e.layers.backplot.select(\".choroplethlayer\");i.makeTraceGroups(o,r,\"trace choropleth\").each(function(e){var r=n.select(this).selectAll(\"path.choroplethlocation\").data(i.identity);r.enter().append(\"path\").classed(\"choroplethlocation\",!0),r.exit().remove(),l(t,e)})},feature2polygons:u}},{\"../../lib\":719,\"../../lib/geo_location_utils\":713,\"../../lib/polygon\":731,\"../../lib/topojson_utils\":746,\"./style\":931,d3:163}],930:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)(i=(n=s[r]).ct)&&(a=l.c2p(i),o=c.c2p(i),e.contains([a,o],null,r,t)?(u.push({pointNumber:r,lon:i[0],lat:i[1]}),n.selected=1):n.selected=0);return u}},{}],931:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../components/colorscale\");function s(t,e){var r=e[0].trace,s=e[0].node3.selectAll(\".choroplethlocation\"),l=r.marker||{},c=l.line||{},u=o.makeColorScaleFuncFromTrace(r);s.each(function(t){n.select(this).attr(\"fill\",u(t.z)).call(i.stroke,t.mlc||c.color).call(a.dashLine,\"\",t.mlw||c.width||0).style(\"opacity\",l.opacity)}),a.selectedPointStyle(s,r,t)}e.exports={style:function(t,e){e&&s(t,e)},styleOnSelect:function(t,e){var r=e[0].node3,n=e[0].trace;n.selectedpoints?a.selectedPointStyle(r.selectAll(\".choroplethlocation\"),n,t):s(t,e)}}},{\"../../components/color\":593,\"../../components/colorscale\":605,\"../../components/drawing\":614,d3:163}],932:[function(t,e,r){\"use strict\";var n=t(\"../choropleth/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../lib/extend\").extendFlat;e.exports=o({locations:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},geojson:{valType:\"any\",editType:\"calc\"},below:{valType:\"string\",editType:\"plot\"},text:n.text,hovertext:n.hovertext,marker:{line:{color:o({},n.marker.line.color,{editType:\"plot\"}),width:o({},n.marker.line.width,{editType:\"plot\"}),editType:\"calc\"},opacity:o({},n.marker.opacity,{editType:\"plot\"}),editType:\"calc\"},selected:{marker:{opacity:o({},n.selected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:o({},n.unselected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},hoverinfo:n.hoverinfo,hovertemplate:a({},{keys:[\"properties\"]})},i(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../choropleth/attributes\":923}],933:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"@turf/area\"),a=t(\"@turf/centroid\"),o=t(\"../../lib\"),s=t(\"../../components/colorscale\"),l=t(\"../../components/drawing\"),c=t(\"../../lib/geojson_utils\").makeBlank,u=t(\"../choropleth/plot\").feature2polygons;function h(t){var e,r=t[0].trace,n=r._opts;if(r.selectedpoints){for(var i=l.makeSelectedPointStyleFns(r),a=0;a<t.length;a++){var s=t[a];s.fOut&&(s.fOut.properties.mo2=i.selectedOpacityFn(s))}e={type:\"identity\",property:\"mo2\"}}else e=o.isArrayOrTypedArray(r.marker.opacity)?{type:\"identity\",property:\"mo\"}:r.marker.opacity;return o.extendFlat(n.fill.paint,{\"fill-opacity\":e}),o.extendFlat(n.line.paint,{\"line-opacity\":e}),n}e.exports={convert:function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,l={layout:{visibility:\"none\"},paint:{}},f={layout:{visibility:\"none\"},paint:{}},p=e._opts={fill:l,line:f,geojson:c()};if(!r)return p;var d=\"string\"==typeof e.geojson?(window.PlotlyGeoAssets||{})[e.geojson]:e.geojson;if(!o.isPlainObject(d))return o.error(\"Oops ... something when wrong when fetching \"+e.geojson),p;var g,v={},m=[];for(g=0;g<t.length;g++){var y=t[g];y.loc&&(v[y.loc]=y)}var x,b,_,w=s.makeColorScaleFuncFromTrace(e),k=e.marker,T=k.line||{};function A(t){var e=v[t.id];if(e){var r=t.geometry;if(\"Polygon\"===r.type||\"MultiPolygon\"===r.type){var n={fc:w(e.z)};x&&(n.mo=x(e)),b&&(n.mlc=b(e)),_&&(n.mlw=_(e));var s={type:\"Feature\",geometry:r,properties:n};e._polygons=u(s),e.ct=function(t){var e,r=t.geometry;if(\"MultiPolygon\"===r.type)for(var n=r.coordinates,o=0,s=0;s<n.length;s++){var l={type:\"Polygon\",coordinates:n[s]},c=i.default(l);c>o&&(o=c,e=l)}else e=r;return a.default(e).geometry.coordinates}(s),e.fIn=t,e.fOut=s,m.push(s)}else o.log([\"Location with id\",e.loc,\"does not have a valid GeoJSON geometry,\",\"choroplethmapbox traces only support *Polygon* and *MultiPolygon* geometries.\"].join(\" \"))}delete v[t.id]}switch(o.isArrayOrTypedArray(k.opacity)&&(x=function(t){var e=t.mo;return n(e)?+o.constrain(e,0,1):0}),o.isArrayOrTypedArray(T.color)&&(b=function(t){return t.mlc}),o.isArrayOrTypedArray(T.width)&&(_=function(t){return t.mlw}),d.type){case\"FeatureCollection\":var M=d.features;for(g=0;g<M.length;g++)A(M[g]);break;case\"Feature\":A(d);break;default:return o.warn([\"Invalid GeoJSON type\",(d.type||\"none\")+\",\",\"choroplethmapbox traces only support *FeatureCollection* and *Feature* types.\"].join(\" \")),p}for(var S in v)o.log(\"Location with id \"+S+\" does not have a matching feature\");var E=x?{type:\"identity\",property:\"mo\"}:k.opacity;return o.extendFlat(l.paint,{\"fill-color\":{type:\"identity\",property:\"fc\"},\"fill-opacity\":E}),o.extendFlat(f.paint,{\"line-color\":b?{type:\"identity\",property:\"mlc\"}:T.color,\"line-width\":_?{type:\"identity\",property:\"mlw\"}:T.width,\"line-opacity\":E}),l.layout.visibility=\"visible\",f.layout.visibility=\"visible\",p.geojson={type:\"FeatureCollection\",features:m},h(t),p},convertOnSelect:h}},{\"../../components/colorscale\":605,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/geojson_utils\":714,\"../choropleth/plot\":929,\"@turf/area\":55,\"@turf/centroid\":56,\"fast-isnumeric\":225}],934:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\"),u=s(\"geojson\");n.isArrayOrTypedArray(l)&&l.length&&n.isArrayOrTypedArray(c)&&c.length&&(\"string\"==typeof u&&\"\"!==u||n.isPlainObject(u))?(e._length=Math.min(l.length,c.length),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":932}],935:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../choropleth/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"../choropleth/hover\"),eventData:t(\"../choropleth/event_data\"),selectPoints:t(\"../choropleth/select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.updateOnSelect(e)},getBelow:function(t,e){for(var r=e.getMapLayers(),n=r.length-2;n>=0;n--){var i=r[n].id;if(\"string\"==typeof i&&0===i.indexOf(\"water\"))for(var a=n+1;a<r.length;a++)if(\"string\"==typeof(i=r[a].id)&&-1===i.indexOf(\"plotly-\"))return i}},moduleType:\"trace\",name:\"choroplethmapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"noOpacity\"],meta:{hr_name:\"choropleth_mapbox\"}}},{\"../../plots/mapbox\":822,\"../choropleth/calc\":924,\"../choropleth/event_data\":926,\"../choropleth/hover\":927,\"../choropleth/select\":930,\"../heatmap/colorbar\":1004,\"./attributes\":932,\"./defaults\":934,\"./plot\":936}],936:[function(t,e,r){\"use strict\";var n=t(\"./convert\").convert,i=t(\"./convert\").convertOnSelect,a=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function o(t,e){this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"fill\",a+e+\"-fill\"],[\"line\",a+e+\"-line\"]],this.below=null}var s=o.prototype;s.update=function(t){this._update(n(t))},s.updateOnSelect=function(t){this._update(i(t))},s._update=function(t){var e=this.subplot,r=this.layerList,n=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(t.geojson),n!==this.below&&(this._removeLayers(),this._addLayers(t,n),this.below=n);for(var i=0;i<r.length;i++){var a=r[i],o=a[0],s=a[1],l=t[o];e.setOptions(s,\"setLayoutProperty\",l.layout),\"visible\"===l.layout.visibility&&e.setOptions(s,\"setPaintProperty\",l.paint)}},s._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},s._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},s.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new o(t,r.uid),a=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(a,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":820,\"./convert\":933}],937:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"scaled\",\"absolute\"],editType:\"calc\",dflt:\"scaled\"},sizeref:{valType:\"number\",editType:\"calc\",min:0},anchor:{valType:\"enumerated\",editType:\"calc\",values:[\"tip\",\"tail\",\"cm\",\"center\"],dflt:\"cm\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:i({editType:\"calc\"},{keys:[\"norm\"]})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach(function(t){l[t]=a[t]}),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../mesh3d/attributes\":1053}],938:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){for(var r=e.u,i=e.v,a=e.w,o=Math.min(e.x.length,e.y.length,e.z.length,r.length,i.length,a.length),s=-1/0,l=1/0,c=0;c<o;c++){var u=r[c],h=i[c],f=a[c],p=Math.sqrt(u*u+h*h+f*f);s=Math.max(s,p),l=Math.min(l,p)}e._len=o,e._normMax=s,n(t,e,{vals:[l,s],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],939:[function(t,e,r){\"use strict\";var n=t(\"gl-cone3d\"),i=t(\"gl-cone3d\").createConeMesh,a=t(\"../../lib\").simpleMap,o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\");function c(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var u=c.prototype;u.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index,r=this.data.x[e],n=this.data.y[e],i=this.data.z[e],a=this.data.u[e],o=this.data.v[e],s=this.data.w[e];t.traceCoordinate=[r,n,i,a,o,s,Math.sqrt(a*a+o*o+s*s)];var l=this.data.hovertext||this.data.text;return Array.isArray(l)&&void 0!==l[e]?t.textLabel=l[e]:l&&(t.textLabel=l),!0}};var h={xaxis:0,yaxis:1,zaxis:2},f={tip:1,tail:0,cm:.25,center:.5},p={tip:1,tail:1,cm:.75,center:.5};function d(t,e){var r=t.fullSceneLayout,i=t.dataScale,c={};function u(t,e){var n=r[e],o=i[h[e]];return a(t,function(t){return n.d2l(t)*o})}c.vectors=l(u(e.u,\"xaxis\"),u(e.v,\"yaxis\"),u(e.w,\"zaxis\"),e._len),c.positions=l(u(e.x,\"xaxis\"),u(e.y,\"yaxis\"),u(e.z,\"zaxis\"),e._len);var d=s(e);c.colormap=o(e),c.vertexIntensityBounds=[d.min/e._normMax,d.max/e._normMax],c.coneOffset=f[e.anchor],\"scaled\"===e.sizemode?c.coneSize=e.sizeref||.5:c.coneSize=e.sizeref&&e._normMax?e.sizeref/e._normMax:.5;var g=n(c),v=e.lightposition;return g.lightPosition=[v.x,v.y,v.z],g.ambient=e.lighting.ambient,g.diffuse=e.lighting.diffuse,g.specular=e.lighting.specular,g.roughness=e.lighting.roughness,g.fresnel=e.lighting.fresnel,g.opacity=e.opacity,e._pad=p[e.anchor]*g.vectorScale*g.coneScale*e._normMax,g}u.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),a=i(r,n),o=new c(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../plots/gl3d/zip3\":818,\"gl-cone3d\":242}],940:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),h=s(\"x\"),f=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length&&p&&p.length?(s(\"sizeref\"),s(\"sizemode\"),s(\"anchor\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":937}],941:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"cone\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),eventData:function(t,e){return t.norm=e.traceCoordinate[6],t},meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":937,\"./calc\":938,\"./convert\":939,\"./defaults\":940}],942:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../components/drawing/attributes\").dash,s=t(\"../../plots/font_attributes\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../constants/filter_ops\"),u=c.COMPARISON_OPS2,h=c.INTERVAL_OPS,f=(t(\"../../constants/docs\").FORMAT_LINK,i.line);e.exports=l({z:n.z,x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,xtype:n.xtype,ytype:n.ytype,zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate,connectgaps:n.connectgaps,fillcolor:{valType:\"color\",editType:\"calc\"},autocontour:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"contours.start\":void 0,\"contours.end\":void 0,\"contours.size\":void 0}},ncontours:{valType:\"integer\",dflt:15,min:1,editType:\"calc\"},contours:{type:{valType:\"enumerated\",values:[\"levels\",\"constraint\"],dflt:\"levels\",editType:\"calc\"},start:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},end:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},coloring:{valType:\"enumerated\",values:[\"fill\",\"heatmap\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:{valType:\"boolean\",dflt:!0,editType:\"plot\"},showlabels:{valType:\"boolean\",dflt:!1,editType:\"plot\"},labelfont:s({editType:\"plot\",colorEditType:\"style\"}),labelformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},operation:{valType:\"enumerated\",values:[].concat(u).concat(h),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:l({},f.color,{editType:\"style+colorbars\"}),width:l({},f.width,{editType:\"style+colorbars\"}),dash:o,smoothing:l({},f.smoothing,{}),editType:\"plot\"}},a(\"\",{cLetter:\"z\",autoColorDflt:!1,editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../components/drawing/attributes\":613,\"../../constants/docs\":690,\"../../constants/filter_ops\":691,\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"../heatmap/attributes\":1001,\"../scatter/attributes\":1112}],943:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\"),i=t(\"../heatmap/calc\"),a=t(\"./set_contours\"),o=t(\"./end_plus\");e.exports=function(t,e){var r=i(t,e),s=r[0].z;a(e,s);var l,c=e.contours,u=n.extractOpts(e);if(\"heatmap\"===c.coloring&&u.auto&&!1===e.autocontour){var h=c.start,f=o(c),p=c.size||1,d=Math.floor((f-h)/p)+1;isFinite(p)||(p=1,d=1);var g=h-p/2;l=[g,g+d*p]}else l=s;return n.calc(t,e,{vals:l,cLetter:\"z\"}),r}},{\"../../components/colorscale\":605,\"../heatmap/calc\":1002,\"./end_plus\":953,\"./set_contours\":961}],944:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a,o,s=t[0],l=s.x.length,c=s.y.length,u=s.z,h=n.contours,f=-1/0,p=1/0;for(i=0;i<c;i++)p=Math.min(p,u[i][0]),p=Math.min(p,u[i][l-1]),f=Math.max(f,u[i][0]),f=Math.max(f,u[i][l-1]);for(i=1;i<l-1;i++)p=Math.min(p,u[0][i]),p=Math.min(p,u[c-1][i]),f=Math.max(f,u[0][i]),f=Math.max(f,u[c-1][i]);switch(s.prefixBoundary=!1,e){case\">\":h.value>f&&(s.prefixBoundary=!0);break;case\"<\":h.value<p&&(s.prefixBoundary=!0);break;case\"[]\":a=Math.min.apply(null,h.value),((o=Math.max.apply(null,h.value))<p||a>f)&&(s.prefixBoundary=!0);break;case\"][\":a=Math.min.apply(null,h.value),o=Math.max.apply(null,h.value),a<p&&o>f&&(s.prefixBoundary=!0)}}},{}],945:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\").extractOpts,i=t(\"./make_color_map\"),a=t(\"./end_plus\");e.exports={min:\"zmin\",max:\"zmax\",calc:function(t,e,r){var o=e.contours,s=e.line,l=o.size||1,c=o.coloring,u=i(e,{isColorbar:!0});if(\"heatmap\"===c){var h=n(e);r._fillgradient=e.colorscale,r._zrange=[h.min,h.max]}else\"fill\"===c&&(r._fillcolor=u);r._line={color:\"lines\"===c?u:s.color,width:!1!==o.showlines?s.width:0,dash:s.dash},r._levels={start:o.start,end:a(o),size:l}}}},{\"../../components/colorscale\":605,\"./end_plus\":953,\"./make_color_map\":958}],946:[function(t,e,r){\"use strict\";e.exports={BOTTOMSTART:[1,9,13,104,713],TOPSTART:[4,6,7,104,713],LEFTSTART:[8,12,14,208,1114],RIGHTSTART:[2,3,11,208,1114],NEWDELTA:[null,[-1,0],[0,-1],[-1,0],[1,0],null,[0,-1],[-1,0],[0,1],[0,1],null,[0,1],[1,0],[1,0],[0,-1]],CHOOSESADDLE:{104:[4,1],208:[2,8],713:[7,13],1114:[11,14]},SADDLEREMAINDER:{1:4,2:8,4:1,7:13,8:2,11:14,13:7,14:11},LABELDISTANCE:2,LABELINCREASE:10,LABELMIN:3,LABELMAX:10,LABELOPTIMIZER:{EDGECOST:1,ANGLECOST:1,NEIGHBORCOST:5,SAMELEVELFACTOR:10,SAMELEVELDISTANCE:5,MAXCOST:100,INITIALSEARCHPOINTS:10,ITERATIONS:5}}},{}],947:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./label_defaults\"),a=t(\"../../components/color\"),o=a.addOpacity,s=a.opacity,l=t(\"../../constants/filter_ops\"),c=l.CONSTRAINT_REDUCTION,u=l.COMPARISON_OPS2;e.exports=function(t,e,r,a,l,h){var f,p,d,g=e.contours,v=r(\"contours.operation\");(g._operation=c[v],function(t,e){var r;-1===u.indexOf(e.operation)?(t(\"contours.value\",[0,1]),Array.isArray(e.value)?e.value.length>2?e.value=e.value.slice(2):0===e.length?e.value=[0,1]:e.length<2?(r=parseFloat(e.value[0]),e.value=[r,r+1]):e.value=[parseFloat(e.value[0]),parseFloat(e.value[1])]:n(e.value)&&(r=parseFloat(e.value),e.value=[r,r+1])):(t(\"contours.value\",0),n(e.value)||(Array.isArray(e.value)?e.value=parseFloat(e.value[0]):e.value=0))}(r,g),\"=\"===v?f=g.showlines=!0:(f=r(\"contours.showlines\"),d=r(\"fillcolor\",o((t.line||{}).color||l,.5))),f)&&(p=r(\"line.color\",d&&s(d)?o(e.fillcolor,1):l),r(\"line.width\",2),r(\"line.dash\"));r(\"line.smoothing\"),i(r,a,p,h)}},{\"../../components/color\":593,\"../../constants/filter_ops\":691,\"./label_defaults\":957,\"fast-isnumeric\":225}],948:[function(t,e,r){\"use strict\";var n=t(\"../../constants/filter_ops\"),i=t(\"fast-isnumeric\");function a(t,e){var r,a=Array.isArray(e);function o(t){return i(t)?+t:null}return-1!==n.COMPARISON_OPS2.indexOf(t)?r=o(a?e[0]:e):-1!==n.INTERVAL_OPS.indexOf(t)?r=a?[o(e[0]),o(e[1])]:[o(e),o(e)]:-1!==n.SET_OPS.indexOf(t)&&(r=a?e.map(o):[o(e)]),r}function o(t){return function(e){e=a(t,e);var r=Math.min(e[0],e[1]),n=Math.max(e[0],e[1]);return{start:r,end:n,size:n-r}}}function s(t){return function(e){return{start:e=a(t,e),end:1/0,size:1/0}}}e.exports={\"[]\":o(\"[]\"),\"][\":o(\"][\"),\">\":s(\">\"),\"<\":s(\"<\"),\"=\":s(\"=\")}},{\"../../constants/filter_ops\":691,\"fast-isnumeric\":225}],949:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=n(\"contours.start\"),a=n(\"contours.end\"),o=!1===i||!1===a,s=r(\"contours.size\");!(o?e.autocontour=!0:r(\"autocontour\",!1))&&s||r(\"ncontours\")}},{}],950:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");function i(t){return n.extendFlat({},t,{edgepaths:n.extendDeep([],t.edgepaths),paths:n.extendDeep([],t.paths)})}e.exports=function(t,e){var r,a,o,s=function(t){return t.reverse()},l=function(t){return t};switch(e){case\"=\":case\"<\":return t;case\">\":for(1!==t.length&&n.warn(\"Contour data invalid for the specified inequality operation.\"),a=t[0],r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);return t;case\"][\":var c=s;s=l,l=c;case\"[]\":for(2!==t.length&&n.warn(\"Contour data invalid for the specified inequality range operation.\"),a=i(t[0]),o=i(t[1]),r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);for(;o.edgepaths.length;)a.edgepaths.push(l(o.edgepaths.shift()));for(;o.paths.length;)a.paths.push(l(o.paths.shift()));return[a]}}},{\"../../lib\":719}],951:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"./constraint_defaults\"),o=t(\"./contours_defaults\"),s=t(\"./style_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,l,r,i)}if(i(t,e,u,c)){u(\"text\"),u(\"hovertext\"),u(\"hovertemplate\");var h=\"constraint\"===u(\"contours.type\");u(\"connectgaps\",n.isArray1D(e.z)),h?a(t,e,u,c,r):(o(t,e,u,function(r){return n.coerce2(t,e,l,r)}),s(t,e,u,c))}else e.visible=!1}},{\"../../lib\":719,\"../heatmap/xyz_defaults\":1015,\"./attributes\":942,\"./constraint_defaults\":947,\"./contours_defaults\":949,\"./style_defaults\":963}],952:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constraint_mapping\"),a=t(\"./end_plus\");e.exports=function(t,e,r){for(var o=\"constraint\"===t.type?i[t._operation](t.value):t,s=o.size,l=[],c=a(o),u=r.trace._carpetTrace,h=u?{xaxis:u.aaxis,yaxis:u.baxis,x:r.a,y:r.b}:{xaxis:e.xaxis,yaxis:e.yaxis,x:r.x,y:r.y},f=o.start;f<c;f+=s)if(l.push(n.extendFlat({level:f,crossings:{},starts:[],edgepaths:[],paths:[],z:r.z,smoothing:r.trace.line.smoothing},h)),l.length>1e3){n.warn(\"Too many contours, clipping at 1000\",t);break}return l}},{\"../../lib\":719,\"./constraint_mapping\":948,\"./end_plus\":953}],953:[function(t,e,r){\"use strict\";e.exports=function(t){return t.end+t.size/1e6}},{}],954:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constants\");function a(t,e,r,n){return Math.abs(t[0]-e[0])<r&&Math.abs(t[1]-e[1])<n}function o(t,e,r,o,l){var c,u=e.join(\",\"),h=u,f=t.crossings[h],p=function(t,e,r){var n=0,a=0;t>20&&e?208===t||1114===t?n=0===r[0]?1:-1:a=0===r[1]?1:-1:-1!==i.BOTTOMSTART.indexOf(t)?a=1:-1!==i.LEFTSTART.indexOf(t)?n=1:-1!==i.TOPSTART.indexOf(t)?a=-1:n=-1;return[n,a]}(f,r,e),d=[s(t,e,[-p[0],-p[1]])],g=p.join(\",\"),v=t.z.length,m=t.z[0].length;for(c=0;c<1e4;c++){if(f>20?(f=i.CHOOSESADDLE[f][(p[0]||p[1])<0?0:1],t.crossings[h]=i.SADDLEREMAINDER[f]):delete t.crossings[h],!(p=i.NEWDELTA[f])){n.log(\"Found bad marching index:\",f,e,t.level);break}d.push(s(t,e,p)),e[0]+=p[0],e[1]+=p[1],a(d[d.length-1],d[d.length-2],o,l)&&d.pop(),h=e.join(\",\");var y=p[0]&&(e[0]<0||e[0]>m-2)||p[1]&&(e[1]<0||e[1]>v-2);if(h===u&&p.join(\",\")===g||r&&y)break;f=t.crossings[h]}1e4===c&&n.log(\"Infinite loop in contour?\");var x,b,_,w,k,T,A,M,S,E,C,L,P,O,z,I=a(d[0],d[d.length-1],o,l),D=0,R=.2*t.smoothing,F=[],B=0;for(c=1;c<d.length;c++)L=d[c],P=d[c-1],void 0,void 0,O=L[2]-P[2],z=L[3]-P[3],D+=A=Math.sqrt(O*O+z*z),F.push(A);var N=D/F.length*R;function j(t){return d[t%d.length]}for(c=d.length-2;c>=B;c--)if((x=F[c])<N){for(_=0,b=c-1;b>=B&&x+F[b]<N;b--)x+=F[b];if(I&&c===d.length-2)for(_=0;_<b&&x+F[_]<N;_++)x+=F[_];k=c-b+_+1,T=Math.floor((c+b+_+2)/2),w=I||c!==d.length-2?I||-1!==b?k%2?j(T):[(j(T)[0]+j(T+1)[0])/2,(j(T)[1]+j(T+1)[1])/2]:d[0]:d[d.length-1],d.splice(b+1,c-b+1,w),c=b+1,_&&(B=_),I&&(c===d.length-2?d[_]=d[d.length-1]:0===c&&(d[d.length-1]=d[0]))}for(d.splice(0,B),c=0;c<d.length;c++)d[c].length=2;if(!(d.length<2))if(I)d.pop(),t.paths.push(d);else{r||n.log(\"Unclosed interior contour?\",t.level,u,d.join(\"L\"));var U=!1;for(M=0;M<t.edgepaths.length;M++)if(E=t.edgepaths[M],!U&&a(E[0],d[d.length-1],o,l)){d.pop(),U=!0;var V=!1;for(S=0;S<t.edgepaths.length;S++)if(a((C=t.edgepaths[S])[C.length-1],d[0],o,l)){V=!0,d.shift(),t.edgepaths.splice(M,1),S===M?t.paths.push(d.concat(C)):(S>M&&S--,t.edgepaths[S]=C.concat(d,E));break}V||(t.edgepaths[M]=d.concat(E))}for(M=0;M<t.edgepaths.length&&!U;M++)a((E=t.edgepaths[M])[E.length-1],d[0],o,l)&&(d.shift(),t.edgepaths[M]=E.concat(d),U=!0);U||t.edgepaths.push(d)}}function s(t,e,r){var n=e[0]+Math.max(r[0],0),i=e[1]+Math.max(r[1],0),a=t.z[i][n],o=t.xaxis,s=t.yaxis;if(r[1]){var l=(t.level-a)/(t.z[i][n+1]-a);return[o.c2p((1-l)*t.x[n]+l*t.x[n+1],!0),s.c2p(t.y[i],!0),n+l,i]}var c=(t.level-a)/(t.z[i+1][n]-a);return[o.c2p(t.x[n],!0),s.c2p((1-c)*t.y[i]+c*t.y[i+1],!0),n,i+c]}e.exports=function(t,e,r){var i,a,s,l;for(e=e||.01,r=r||.01,a=0;a<t.length;a++){for(s=t[a],l=0;l<s.starts.length;l++)o(s,s.starts[l],\"edge\",e,r);for(i=0;Object.keys(s.crossings).length&&i<1e4;)i++,o(s,Object.keys(s.crossings)[0].split(\",\").map(Number),void 0,e,r);1e4===i&&n.log(\"Infinite loop in contour?\")}}},{\"../../lib\":719,\"./constants\":946}],955:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../heatmap/hover\");e.exports=function(t,e,r,a,o){var s=i(t,e,r,a,o,!0);return s&&s.forEach(function(t){var e=t.trace;\"constraint\"===e.contours.type&&(e.fillcolor&&n.opacity(e.fillcolor)?t.color=n.addOpacity(e.fillcolor,1):e.contours.showlines&&n.opacity(e.line.color)&&(t.color=n.addOpacity(e.line.color,1)))}),s}},{\"../../components/color\":593,\"../heatmap/hover\":1008}],956:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\").plot,style:t(\"./style\"),colorbar:t(\"./colorbar\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"contour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":942,\"./calc\":943,\"./colorbar\":945,\"./defaults\":951,\"./hover\":955,\"./plot\":960,\"./style\":962}],957:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i){if(i||(i={}),t(\"contours.showlabels\")){var a=e.font;n.coerceFont(t,\"contours.labelfont\",{family:a.family,size:a.size,color:r}),t(\"contours.labelformat\")}!1!==i.hasHover&&t(\"zhoverformat\")}},{\"../../lib\":719}],958:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/colorscale\"),a=t(\"./end_plus\");e.exports=function(t){var e=t.contours,r=e.start,o=a(e),s=e.size||1,l=Math.floor((o-r)/s)+1,c=\"lines\"===e.coloring?0:1,u=i.extractOpts(t);isFinite(s)||(s=1,l=1);var h,f,p=u.reversescale?i.flipScale(u.colorscale):u.colorscale,d=p.length,g=new Array(d),v=new Array(d);if(\"heatmap\"===e.coloring){var m=u.min,y=u.max;for(f=0;f<d;f++)h=p[f],g[f]=h[0]*(y-m)+m,v[f]=h[1];var x=n.extent([m,y,e.start,e.start+s*(l-1)]),b=x[m<y?0:1],_=x[m<y?1:0];b!==m&&(g.splice(0,0,b),v.splice(0,0,v[0])),_!==y&&(g.push(_),v.push(v[v.length-1]))}else for(f=0;f<d;f++)h=p[f],g[f]=(h[0]*(l+c-1)-c/2)*s+r,v[f]=h[1];return i.makeColorScaleFunc({domain:g,range:v},{noNumericCheck:!0})}},{\"../../components/colorscale\":605,\"./end_plus\":953,d3:163}],959:[function(t,e,r){\"use strict\";var n=t(\"./constants\");function i(t,e){var r=(e[0][0]>t?0:1)+(e[0][1]>t?0:2)+(e[1][1]>t?0:4)+(e[1][0]>t?0:8);return 5===r||10===r?t>(e[0][0]+e[0][1]+e[1][0]+e[1][1])/4?5===r?713:1114:5===r?104:208:15===r?0:r}e.exports=function(t){var e,r,a,o,s,l,c,u,h,f=t[0].z,p=f.length,d=f[0].length,g=2===p||2===d;for(r=0;r<p-1;r++)for(o=[],0===r&&(o=o.concat(n.BOTTOMSTART)),r===p-2&&(o=o.concat(n.TOPSTART)),e=0;e<d-1;e++)for(a=o.slice(),0===e&&(a=a.concat(n.LEFTSTART)),e===d-2&&(a=a.concat(n.RIGHTSTART)),s=e+\",\"+r,l=[[f[r][e],f[r][e+1]],[f[r+1][e],f[r+1][e+1]]],h=0;h<t.length;h++)(c=i((u=t[h]).level,l))&&(u.crossings[s]=c,-1!==a.indexOf(c)&&(u.starts.push([e,r]),g&&-1!==a.indexOf(c,a.indexOf(c)+1)&&u.starts.push([e,r])))}},{\"./constants\":946}],960:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../../plots/cartesian/set_convert\"),c=t(\"../heatmap/plot\"),u=t(\"./make_crossings\"),h=t(\"./find_all_paths\"),f=t(\"./empty_pathinfo\"),p=t(\"./convert_to_constraints\"),d=t(\"./close_boundaries\"),g=t(\"./constants\"),v=g.LABELOPTIMIZER;function m(t,e){var r,n,o,s,l,c,u,h=function(t,e){var r=t.prefixBoundary;if(void 0===r){var n=Math.min(t.z[0][0],t.z[0][1]);r=!t.edgepaths.length&&n>t.level}return r?\"M\"+e.join(\"L\")+\"Z\":\"\"}(t,e),f=0,p=t.edgepaths.map(function(t,e){return e}),d=!0;function g(t){return Math.abs(t[1]-e[2][1])<.01}function v(t){return Math.abs(t[0]-e[0][0])<.01}function m(t){return Math.abs(t[0]-e[2][0])<.01}for(;p.length;){for(c=a.smoothopen(t.edgepaths[f],t.smoothing),h+=d?c:c.replace(/^M/,\"L\"),p.splice(p.indexOf(f),1),r=t.edgepaths[f][t.edgepaths[f].length-1],s=-1,o=0;o<4;o++){if(!r){i.log(\"Missing end?\",f,t);break}for(u=r,Math.abs(u[1]-e[0][1])<.01&&!m(r)?n=e[1]:v(r)?n=e[0]:g(r)?n=e[3]:m(r)&&(n=e[2]),l=0;l<t.edgepaths.length;l++){var y=t.edgepaths[l][0];Math.abs(r[0]-n[0])<.01?Math.abs(r[0]-y[0])<.01&&(y[1]-r[1])*(n[1]-y[1])>=0&&(n=y,s=l):Math.abs(r[1]-n[1])<.01?Math.abs(r[1]-y[1])<.01&&(y[0]-r[0])*(n[0]-y[0])>=0&&(n=y,s=l):i.log(\"endpt to newendpt is not vert. or horz.\",r,n,y)}if(r=n,s>=0)break;h+=\"L\"+n}if(s===t.edgepaths.length){i.log(\"unclosed perimeter path\");break}f=s,(d=-1===p.indexOf(f))&&(f=p[0],h+=\"Z\")}for(f=0;f<t.paths.length;f++)h+=a.smoothclosed(t.paths[f],t.smoothing);return h}function y(t,e,r,n){var a=e.width/2,o=e.height/2,s=t.x,l=t.y,c=t.theta,u=Math.cos(c)*a,h=Math.sin(c)*a,f=(s>n.center?n.right-s:s-n.left)/(u+Math.abs(Math.sin(c)*o)),p=(l>n.middle?n.bottom-l:l-n.top)/(Math.abs(h)+Math.cos(c)*o);if(f<1||p<1)return 1/0;var d=v.EDGECOST*(1/(f-1)+1/(p-1));d+=v.ANGLECOST*c*c;for(var g=s-u,m=l-h,y=s+u,x=l+h,b=0;b<r.length;b++){var _=r[b],w=Math.cos(_.theta)*_.width/2,k=Math.sin(_.theta)*_.width/2,T=2*i.segmentDistance(g,m,y,x,_.x-w,_.y-k,_.x+w,_.y+k)/(e.height+_.height),A=_.level===e.level,M=A?v.SAMELEVELDISTANCE:1;if(T<=M)return 1/0;d+=v.NEIGHBORCOST*(A?v.SAMELEVELFACTOR:1)/(T-M)}return d}r.plot=function(t,e,o,s){var l=e.xaxis,v=e.yaxis;i.makeTraceGroups(s,o,\"contour\").each(function(o){var s=n.select(this),y=o[0],x=y.trace,b=y.x,_=y.y,w=x.contours,k=f(w,e,y),T=i.ensureSingle(s,\"g\",\"heatmapcoloring\"),A=[];\"heatmap\"===w.coloring&&(A=[o]),c(t,e,A,T),u(k),h(k);var M=l.c2p(b[0],!0),S=l.c2p(b[b.length-1],!0),E=v.c2p(_[0],!0),C=v.c2p(_[_.length-1],!0),L=[[M,C],[S,C],[S,E],[M,E]],P=k;\"constraint\"===w.type&&(P=p(k,w._operation),d(P,w._operation,L,x)),function(t,e,r){var n=i.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"===r.coloring?[0]:[]);n.enter().append(\"path\"),n.exit().remove(),n.attr(\"d\",\"M\"+e.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(s,L,w),function(t,e,r,a){var o=i.ensureSingle(t,\"g\",\"contourfill\").selectAll(\"path\").data(\"fill\"===a.coloring||\"constraint\"===a.type&&\"=\"!==a._operation?e:[]);o.enter().append(\"path\"),o.exit().remove(),o.each(function(t){var e=m(t,r);e?n.select(this).attr(\"d\",e).style(\"stroke\",\"none\"):n.select(this).remove()})}(s,P,L,w),function(t,e,o,s,l){var c=i.ensureSingle(t,\"g\",\"contourlines\"),u=!1!==l.showlines,h=l.showlabels,f=u&&h,p=r.createLines(c,u||h,e),d=r.createLineClip(c,f,o,s.trace.uid),v=t.selectAll(\"g.contourlabels\").data(h?[0]:[]);if(v.exit().remove(),v.enter().append(\"g\").classed(\"contourlabels\",!0),h){var m=[],y=[];i.clearLocationCache();var x=r.labelFormatter(l,s.t.cb,o._fullLayout),b=a.tester.append(\"text\").attr(\"data-notex\",1).call(a.font,l.labelfont),_=e[0].xaxis,w=e[0].yaxis,k=_._length,T=w._length,A=_.range,M=w.range,S=i.aggNums(Math.min,null,s.x),E=i.aggNums(Math.max,null,s.x),C=i.aggNums(Math.min,null,s.y),L=i.aggNums(Math.max,null,s.y),P=Math.max(_.c2p(S,!0),0),O=Math.min(_.c2p(E,!0),k),z=Math.max(w.c2p(L,!0),0),I=Math.min(w.c2p(C,!0),T),D={};A[0]<A[1]?(D.left=P,D.right=O):(D.left=O,D.right=P),M[0]<M[1]?(D.top=z,D.bottom=I):(D.top=I,D.bottom=z),D.middle=(D.top+D.bottom)/2,D.center=(D.left+D.right)/2,m.push([[D.left,D.top],[D.right,D.top],[D.right,D.bottom],[D.left,D.bottom]]);var R=Math.sqrt(k*k+T*T),F=g.LABELDISTANCE*R/Math.max(1,e.length/g.LABELINCREASE);p.each(function(t){var e=r.calcTextOpts(t.level,x,b,o);n.select(this).selectAll(\"path\").each(function(){var t=i.getVisibleSegment(this,D,e.height/2);if(t&&!(t.len<(e.width+e.height)*g.LABELMIN))for(var n=Math.min(Math.ceil(t.len/F),g.LABELMAX),a=0;a<n;a++){var o=r.findBestTextLocation(this,t,e,y,D);if(!o)break;r.addLabelData(o,e,y,m)}})}),b.remove(),r.drawLabels(v,y,o,d,f?m:null)}h&&!u&&p.remove()}(s,k,t,y,w),function(t,e,r,n,o){var s=r._fullLayout._clips,l=\"clip\"+n.trace.uid,c=s.selectAll(\"#\"+l).data(n.trace.connectgaps?[]:[0]);if(c.enter().append(\"clipPath\").classed(\"contourclip\",!0).attr(\"id\",l),c.exit().remove(),!1===n.trace.connectgaps){var f={level:.9,crossings:{},starts:[],edgepaths:[],paths:[],xaxis:e.xaxis,yaxis:e.yaxis,x:n.x,y:n.y,z:function(t){var e,r,n=t.trace._emptypoints,i=[],a=t.z.length,o=t.z[0].length,s=[];for(e=0;e<o;e++)s.push(1);for(e=0;e<a;e++)i.push(s.slice());for(e=0;e<n.length;e++)r=n[e],i[r[0]][r[1]]=0;return t.zmask=i,i}(n),smoothing:0};u([f]),h([f]);var p=m(f,o),d=i.ensureSingle(c,\"path\",\"\");d.attr(\"d\",p)}else l=null;a.setClipUrl(t,l,r)}(s,e,t,y,L)})},r.createLines=function(t,e,r){var n=r[0].smoothing,i=t.selectAll(\"g.contourlevel\").data(e?r:[]);if(i.exit().remove(),i.enter().append(\"g\").classed(\"contourlevel\",!0),e){var o=i.selectAll(\"path.openline\").data(function(t){return t.pedgepaths||t.edgepaths});o.exit().remove(),o.enter().append(\"path\").classed(\"openline\",!0),o.attr(\"d\",function(t){return a.smoothopen(t,n)}).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\");var s=i.selectAll(\"path.closedline\").data(function(t){return t.ppaths||t.paths});s.exit().remove(),s.enter().append(\"path\").classed(\"closedline\",!0),s.attr(\"d\",function(t){return a.smoothclosed(t,n)}).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\")}return i},r.createLineClip=function(t,e,r,n){var i=e?\"clipline\"+n:null,o=r._fullLayout._clips.selectAll(\"#\"+i).data(e?[0]:[]);return o.exit().remove(),o.enter().append(\"clipPath\").classed(\"contourlineclip\",!0).attr(\"id\",i),a.setClipUrl(t,i,r),o},r.labelFormatter=function(t,e,r){if(t.labelformat)return r._d3locale.numberFormat(t.labelformat);var n;if(e)n=e.axis;else{if(n={type:\"linear\",_id:\"ycontour\",showexponent:\"all\",exponentformat:\"B\"},\"constraint\"===t.type){var i=t.value;Array.isArray(i)?n.range=[i[0],i[i.length-1]]:n.range=[i,i]}else n.range=[t.start,t.end],n.nticks=(t.end-t.start)/t.size;n.range[0]===n.range[1]&&(n.range[1]+=n.range[0]||1),n.nticks||(n.nticks=1e3),l(n,r),s.prepTicks(n),n._tmin=null,n._tmax=null}return function(t){return s.tickText(n,t).text}},r.calcTextOpts=function(t,e,r,n){var i=e(t);r.text(i).call(o.convertToTspans,n);var s=a.bBox(r.node(),!0);return{text:i,width:s.width,height:s.height,level:t,dy:(s.top+s.bottom)/2}},r.findBestTextLocation=function(t,e,r,n,a){var o,s,l,c,u,h=r.width;e.isClosed?(s=e.len/v.INITIALSEARCHPOINTS,o=e.min+s/2,l=e.max):(s=(e.len-h)/(v.INITIALSEARCHPOINTS+1),o=e.min+s+h/2,l=e.max-(s+h)/2);for(var f=1/0,p=0;p<v.ITERATIONS;p++){for(var d=o;d<l;d+=s){var g=i.getTextLocation(t,e.total,d,h),m=y(g,r,n,a);m<f&&(f=m,u=g,c=d)}if(f>2*v.MAXCOST)break;p&&(s/=2),l=(o=c-s/2)+1.5*s}if(f<=v.MAXCOST)return u},r.addLabelData=function(t,e,r,n){var i=e.width/2,a=e.height/2,o=t.x,s=t.y,l=t.theta,c=Math.sin(l),u=Math.cos(l),h=i*u,f=a*c,p=i*c,d=-a*u,g=[[o-h-f,s-p-d],[o+h-f,s+p-d],[o+h+f,s+p+d],[o-h+f,s-p+d]];r.push({text:e.text,x:o,y:s,dy:e.dy,theta:l,level:e.level,width:e.width,height:e.height}),n.push(g)},r.drawLabels=function(t,e,r,a,s){var l=t.selectAll(\"text\").data(e,function(t){return t.text+\",\"+t.x+\",\"+t.y+\",\"+t.theta});if(l.exit().remove(),l.enter().append(\"text\").attr({\"data-notex\":1,\"text-anchor\":\"middle\"}).each(function(t){var e=t.x+Math.sin(t.theta)*t.dy,i=t.y-Math.cos(t.theta)*t.dy;n.select(this).text(t.text).attr({x:e,y:i,transform:\"rotate(\"+180*t.theta/Math.PI+\" \"+e+\" \"+i+\")\"}).call(o.convertToTspans,r)}),s){for(var c=\"\",u=0;u<s.length;u++)c+=\"M\"+s[u].join(\"L\")+\"Z\";i.ensureSingle(a,\"path\",\"\").attr(\"d\",c)}}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/set_convert\":785,\"../heatmap/plot\":1012,\"./close_boundaries\":944,\"./constants\":946,\"./convert_to_constraints\":950,\"./empty_pathinfo\":952,\"./find_all_paths\":954,\"./make_crossings\":959,d3:163}],961:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\");function a(t,e,r){var i={type:\"linear\",range:[t,e]};return n.autoTicks(i,(e-t)/(r||15)),i}e.exports=function(t,e){var r=t.contours;if(t.autocontour){var o=t.zmin,s=t.zmax;(t.zauto||void 0===o)&&(o=i.aggNums(Math.min,null,e)),(t.zauto||void 0===s)&&(s=i.aggNums(Math.max,null,e));var l=a(o,s,t.ncontours);r.size=l.dtick,r.start=n.tickFirst(l),l.range.reverse(),r.end=n.tickFirst(l),r.start===o&&(r.start+=r.size),r.end===s&&(r.end-=r.size),r.start>r.end&&(r.start=r.end=(r.start+r.end)/2),t._input.contours||(t._input.contours={}),i.extendFlat(t._input.contours,{start:r.start,end:r.end,size:r.size}),t._input.autocontour=!0}else if(\"constraint\"!==r.type){var c,u=r.start,h=r.end,f=t._input.contours;if(u>h&&(r.start=f.start=h,h=r.end=f.end=u,u=r.start),!(r.size>0))c=u===h?1:a(u,h,t.ncontours).dtick,f.size=r.size=c}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767}],962:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../heatmap/style\"),o=t(\"./make_color_map\");e.exports=function(t){var e=n.select(t).selectAll(\"g.contour\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.each(function(t){var e=n.select(this),r=t[0].trace,a=r.contours,s=r.line,l=a.size||1,c=a.start,u=\"constraint\"===a.type,h=!u&&\"lines\"===a.coloring,f=!u&&\"fill\"===a.coloring,p=h||f?o(r):null;e.selectAll(\"g.contourlevel\").each(function(t){n.select(this).selectAll(\"path\").call(i.lineGroupStyle,s.width,h?p(t.level):s.color,s.dash)});var d=a.labelfont;if(e.selectAll(\"g.contourlabels text\").each(function(t){i.font(n.select(this),{family:d.family,size:d.size,color:d.color||(h?p(t.level):s.color)})}),u)e.selectAll(\"g.contourfill path\").style(\"fill\",r.fillcolor);else if(f){var g;e.selectAll(\"g.contourfill path\").style(\"fill\",function(t){return void 0===g&&(g=t.level),p(t.level+.5*l)}),void 0===g&&(g=c),e.selectAll(\"g.contourbg path\").style(\"fill\",p(g-.5*l))}}),a(t)}},{\"../../components/drawing\":614,\"../heatmap/style\":1013,\"./make_color_map\":958,d3:163}],963:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/defaults\"),i=t(\"./label_defaults\");e.exports=function(t,e,r,a,o){var s,l=r(\"contours.coloring\"),c=\"\";\"fill\"===l&&(s=r(\"contours.showlines\")),!1!==s&&(\"lines\"!==l&&(c=r(\"line.color\",\"#000\")),r(\"line.width\",.5),r(\"line.dash\")),\"none\"!==l&&(!0!==t.showlegend&&(e.showlegend=!1),e._dfltShowLegend=!1,n(t,e,a,r,{prefix:\"\",cLetter:\"z\"})),r(\"line.smoothing\"),i(r,a,c,o)}},{\"../../components/colorscale/defaults\":603,\"./label_defaults\":957}],964:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../contour/attributes\"),a=i.contours,o=t(\"../scatter/attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../lib/extend\").extendFlat,c=o.line;e.exports=l({carpet:{valType:\"string\",editType:\"calc\"},z:n.z,a:n.x,a0:n.x0,da:n.dx,b:n.y,b0:n.y0,db:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,atype:n.xtype,btype:n.ytype,fillcolor:i.fillcolor,autocontour:i.autocontour,ncontours:i.ncontours,contours:{type:a.type,start:a.start,end:a.end,size:a.size,coloring:{valType:\"enumerated\",values:[\"fill\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:a.showlines,showlabels:a.showlabels,labelfont:a.labelfont,labelformat:a.labelformat,operation:a.operation,value:a.value,editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:l({},c.color,{}),width:c.width,dash:c.dash,smoothing:l({},c.smoothing,{}),editType:\"plot\"},transforms:void 0},s(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../contour/attributes\":942,\"../heatmap/attributes\":1001,\"../scatter/attributes\":1112}],965:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\"),i=t(\"../../lib\"),a=t(\"../heatmap/convert_column_xyz\"),o=t(\"../heatmap/clean_2d_array\"),s=t(\"../heatmap/interp2d\"),l=t(\"../heatmap/find_empties\"),c=t(\"../heatmap/make_bound_array\"),u=t(\"./defaults\"),h=t(\"../carpet/lookup_carpetid\"),f=t(\"../contour/set_contours\");e.exports=function(t,e){var r=e._carpetTrace=h(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){if(!e.a||!e.b){var p=t.data[r.index],d=t.data[e.index];d.a||(d.a=p.a),d.b||(d.b=p.b),u(d,e,e._defaultColor,t._fullLayout)}var g=function(t,e){var r,u,h,f,p,d,g,v=e._carpetTrace,m=v.aaxis,y=v.baxis;m._minDtick=0,y._minDtick=0,i.isArray1D(e.z)&&a(e,m,y,\"a\",\"b\",[\"z\"]);r=e._a=e._a||e.a,f=e._b=e._b||e.b,r=r?m.makeCalcdata(e,\"_a\"):[],f=f?y.makeCalcdata(e,\"_b\"):[],u=e.a0||0,h=e.da||1,p=e.b0||0,d=e.db||1,g=e._z=o(e._z||e.z,e.transpose),e._emptypoints=l(g),s(g,e._emptypoints);var x=i.maxRowLength(g),b=\"scaled\"===e.xtype?\"\":r,_=c(e,b,u,h,x,m),w=\"scaled\"===e.ytype?\"\":f,k=c(e,w,p,d,g.length,y),T={a:_,b:k,z:g};\"levels\"===e.contours.type&&\"none\"!==e.contours.coloring&&n(t,e,{vals:g,containerStr:\"\",cLetter:\"z\"});return[T]}(t,e);return f(e,e._z),g}}},{\"../../components/colorscale/calc\":601,\"../../lib\":719,\"../carpet/lookup_carpetid\":915,\"../contour/set_contours\":961,\"../heatmap/clean_2d_array\":1003,\"../heatmap/convert_column_xyz\":1005,\"../heatmap/find_empties\":1007,\"../heatmap/interp2d\":1010,\"../heatmap/make_bound_array\":1011,\"./defaults\":966}],966:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"./attributes\"),o=t(\"../contour/constraint_defaults\"),s=t(\"../contour/contours_defaults\"),l=t(\"../contour/style_defaults\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,a,r,i)}if(u(\"carpet\"),t.a&&t.b){if(!i(t,e,u,c,\"a\",\"b\"))return void(e.visible=!1);u(\"text\"),\"constraint\"===u(\"contours.type\")?o(t,e,u,c,r,{hasHover:!1}):(s(t,e,u,function(r){return n.coerce2(t,e,a,r)}),l(t,e,u,c,{hasHover:!1}))}else e._defaultColor=r,e._length=null}},{\"../../lib\":719,\"../contour/constraint_defaults\":947,\"../contour/contours_defaults\":949,\"../contour/style_defaults\":963,\"../heatmap/xyz_defaults\":1015,\"./attributes\":964}],967:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../contour/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../contour/style\"),moduleType:\"trace\",name:\"contourcarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"contour\",\"symbols\",\"showLegend\",\"hasLines\",\"carpetDependent\"],meta:{}}},{\"../../plots/cartesian\":778,\"../contour/colorbar\":945,\"../contour/style\":962,\"./attributes\":964,\"./calc\":965,\"./defaults\":966,\"./plot\":970}],968:[function(t,e,r){\"use strict\";var n=t(\"../../components/drawing\"),i=t(\"../carpet/axis_aligned_line\"),a=t(\"../../lib\");e.exports=function(t,e,r,o,s,l,c,u){var h,f,p,d,g,v,m,y=\"\",x=e.edgepaths.map(function(t,e){return e}),b=!0,_=1e-4*Math.abs(r[0][0]-r[2][0]),w=1e-4*Math.abs(r[0][1]-r[2][1]);function k(t){return Math.abs(t[1]-r[0][1])<w}function T(t){return Math.abs(t[1]-r[2][1])<w}function A(t){return Math.abs(t[0]-r[0][0])<_}function M(t){return Math.abs(t[0]-r[2][0])<_}function S(t,e){var r,n,a,o,h=\"\";for(k(t)&&!M(t)||T(t)&&!A(t)?(o=s.aaxis,a=i(s,l,[t[0],e[0]],.5*(t[1]+e[1]))):(o=s.baxis,a=i(s,l,.5*(t[0]+e[0]),[t[1],e[1]])),r=1;r<a.length;r++)for(h+=o.smoothing?\"C\":\"L\",n=0;n<a[r].length;n++){var f=a[r][n];h+=[c.c2p(f[0]),u.c2p(f[1])]+\" \"}return h}for(h=0,f=null;x.length;){var E=e.edgepaths[h][0];for(f&&(y+=S(f,E)),m=n.smoothopen(e.edgepaths[h].map(o),e.smoothing),y+=b?m:m.replace(/^M/,\"L\"),x.splice(x.indexOf(h),1),f=e.edgepaths[h][e.edgepaths[h].length-1],g=-1,d=0;d<4;d++){if(!f){a.log(\"Missing end?\",h,e);break}for(k(f)&&!M(f)?p=r[1]:A(f)?p=r[0]:T(f)?p=r[3]:M(f)&&(p=r[2]),v=0;v<e.edgepaths.length;v++){var C=e.edgepaths[v][0];Math.abs(f[0]-p[0])<_?Math.abs(f[0]-C[0])<_&&(C[1]-f[1])*(p[1]-C[1])>=0&&(p=C,g=v):Math.abs(f[1]-p[1])<w?Math.abs(f[1]-C[1])<w&&(C[0]-f[0])*(p[0]-C[0])>=0&&(p=C,g=v):a.log(\"endpt to newendpt is not vert. or horz.\",f,p,C)}if(g>=0)break;y+=S(f,p),f=p}if(g===e.edgepaths.length){a.log(\"unclosed perimeter path\");break}h=g,(b=-1===x.indexOf(h))&&(h=x[0],y+=S(f,p)+\"Z\",f=null)}for(h=0;h<e.paths.length;h++)y+=n.smoothclosed(e.paths[h].map(o),e.smoothing);return y}},{\"../../components/drawing\":614,\"../../lib\":719,\"../carpet/axis_aligned_line\":899}],969:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i,a,o,s,l,c,u;for(r=0;r<t.length;r++){for(o=(a=t[r]).pedgepaths=[],s=a.ppaths=[],n=0;n<a.edgepaths.length;n++){for(u=a.edgepaths[n],l=[],i=0;i<u.length;i++)l[i]=e(u[i]);o.push(l)}for(n=0;n<a.paths.length;n++){for(u=a.paths[n],c=[],i=0;i<u.length;i++)c[i]=e(u[i]);s.push(c)}}}},{}],970:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../carpet/map_1d_array\"),a=t(\"../carpet/makepath\"),o=t(\"../../components/drawing\"),s=t(\"../../lib\"),l=t(\"../contour/make_crossings\"),c=t(\"../contour/find_all_paths\"),u=t(\"../contour/plot\"),h=t(\"../contour/constants\"),f=t(\"../contour/convert_to_constraints\"),p=t(\"./join_all_paths\"),d=t(\"../contour/empty_pathinfo\"),g=t(\"./map_pathinfo\"),v=t(\"../carpet/lookup_carpetid\"),m=t(\"../contour/close_boundaries\");function y(t,e,r){var n=t.getPointAtLength(e),i=t.getPointAtLength(r),a=i.x-n.x,o=i.y-n.y,s=Math.sqrt(a*a+o*o);return[a/s,o/s]}function x(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]);return[t[0]/e,t[1]/e]}function b(t,e){var r=Math.abs(t[0]*e[0]+t[1]*e[1]);return Math.sqrt(1-r*r)/r}e.exports=function(t,e,r,_){var w=e.xaxis,k=e.yaxis;s.makeTraceGroups(_,r,\"contour\").each(function(r){var _=n.select(this),T=r[0],A=T.trace,M=A._carpetTrace=v(t,A),S=t.calcdata[M.index][0];if(M.visible&&\"legendonly\"!==M.visible){var E=T.a,C=T.b,L=A.contours,P=d(L,e,T),O=\"constraint\"===L.type,z=L._operation,I=O?\"=\"===z?\"lines\":\"fill\":L.coloring,D=[[E[0],C[C.length-1]],[E[E.length-1],C[C.length-1]],[E[E.length-1],C[0]],[E[0],C[0]]];l(P);var R=1e-8*(E[E.length-1]-E[0]),F=1e-8*(C[C.length-1]-C[0]);c(P,R,F);var B,N,j,U,V=P;\"constraint\"===L.type&&(V=f(P,z),m(V,z,D,A)),g(P,G);var q=[];for(U=S.clipsegments.length-1;U>=0;U--)B=S.clipsegments[U],N=i([],B.x,w.c2p),j=i([],B.y,k.c2p),N.reverse(),j.reverse(),q.push(a(N,j,B.bicubic));var H=\"M\"+q.join(\"L\")+\"Z\";!function(t,e,r,n,o,l){var c,u,h,f,p=s.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"!==l||o?[]:[0]);p.enter().append(\"path\"),p.exit().remove();var d=[];for(f=0;f<e.length;f++)c=e[f],u=i([],c.x,r.c2p),h=i([],c.y,n.c2p),d.push(a(u,h,c.bicubic));p.attr(\"d\",\"M\"+d.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(_,S.clipsegments,w,k,O,I),function(t,e,r,i,a,o,l,c,u,h,f){var d=s.ensureSingle(e,\"g\",\"contourfill\").selectAll(\"path\").data(\"fill\"===h?a:[]);d.enter().append(\"path\"),d.exit().remove(),d.each(function(e){var a=p(t,e,o,l,c,u,r,i);e.prefixBoundary&&(a=f+a),a?n.select(this).attr(\"d\",a).style(\"stroke\",\"none\"):n.select(this).remove()})}(A,_,w,k,V,D,G,M,S,I,H),function(t,e,r,i,a,l,c){var f=s.ensureSingle(t,\"g\",\"contourlines\"),p=!1!==a.showlines,d=a.showlabels,g=p&&d,v=u.createLines(f,p||d,e),m=u.createLineClip(f,g,r,i.trace.uid),_=t.selectAll(\"g.contourlabels\").data(d?[0]:[]);if(_.exit().remove(),_.enter().append(\"g\").classed(\"contourlabels\",!0),d){var w=l.xaxis,k=l.yaxis,T=w._length,A=k._length,M=[[[0,0],[T,0],[T,A],[0,A]]],S=[];s.clearLocationCache();var E=u.labelFormatter(a,i.t.cb,r._fullLayout),C=o.tester.append(\"text\").attr(\"data-notex\",1).call(o.font,a.labelfont),L={left:0,right:T,center:T/2,top:0,bottom:A,middle:A/2},P=Math.sqrt(T*T+A*A),O=h.LABELDISTANCE*P/Math.max(1,e.length/h.LABELINCREASE);v.each(function(t){var e=u.calcTextOpts(t.level,E,C,r);n.select(this).selectAll(\"path\").each(function(r){var n=s.getVisibleSegment(this,L,e.height/2);if(n&&(function(t,e,r,n,i,a){for(var o,s=0;s<r.pedgepaths.length;s++)e===r.pedgepaths[s]&&(o=r.edgepaths[s]);if(!o)return;var l=i.a[0],c=i.a[i.a.length-1],u=i.b[0],h=i.b[i.b.length-1];function f(t,e){var r,n=0;return(Math.abs(t[0]-l)<.1||Math.abs(t[0]-c)<.1)&&(r=x(i.dxydb_rough(t[0],t[1],.1)),n=Math.max(n,a*b(e,r)/2)),(Math.abs(t[1]-u)<.1||Math.abs(t[1]-h)<.1)&&(r=x(i.dxyda_rough(t[0],t[1],.1)),n=Math.max(n,a*b(e,r)/2)),n}var p=y(t,0,1),d=y(t,n.total,n.total-1),g=f(o[0],p),v=n.total-f(o[o.length-1],d);n.min<g&&(n.min=g);n.max>v&&(n.max=v);n.len=n.max-n.min}(this,r,t,n,c,e.height),!(n.len<(e.width+e.height)*h.LABELMIN)))for(var i=Math.min(Math.ceil(n.len/O),h.LABELMAX),a=0;a<i;a++){var o=u.findBestTextLocation(this,n,e,S,L);if(!o)break;u.addLabelData(o,e,S,M)}})}),C.remove(),u.drawLabels(_,S,r,m,g?M:null)}d&&!p&&v.remove()}(_,P,t,T,L,e,M),o.setClipUrl(_,M._clipPathId,t)}function G(t){var e=M.ab2xy(t[0],t[1],!0);return[w.c2p(e[0]),k.c2p(e[1])]}})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../carpet/lookup_carpetid\":915,\"../carpet/makepath\":916,\"../carpet/map_1d_array\":917,\"../contour/close_boundaries\":944,\"../contour/constants\":946,\"../contour/convert_to_constraints\":950,\"../contour/empty_pathinfo\":952,\"../contour/find_all_paths\":954,\"../contour/make_crossings\":959,\"../contour/plot\":960,\"./join_all_paths\":968,\"./map_pathinfo\":969,d3:163}],971:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../scattermapbox/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({lon:o.lon,lat:o.lat,z:{valType:\"data_array\",editType:\"calc\"},radius:{valType:\"number\",editType:\"plot\",arrayOk:!0,min:1,dflt:30},below:{valType:\"string\",editType:\"plot\"},text:o.text,hovertext:o.hovertext,hoverinfo:s({},a.hoverinfo,{flags:[\"lon\",\"lat\",\"z\",\"text\",\"name\"]}),hovertemplate:i()},n(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scattermapbox/attributes\":1171}],972:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../components/colorscale/calc\"),s=t(\"../../lib\")._;e.exports=function(t,e){for(var r=e._length,l=new Array(r),c=e.z,u=i(c)&&c.length,h=0;h<r;h++){var f=l[h]={},p=e.lon[h],d=e.lat[h];if(f.lonlat=n(p)&&n(d)?[+p,+d]:[a,a],u){var g=c[h];f.z=n(g)?g:a}}return o(t,e,{vals:u?c:[0,1],containerStr:\"\",cLetter:\"z\"}),r&&(l[0].t={labels:{lat:s(t,\"lat:\")+\" \",lon:s(t,\"lon:\")+\" \"}}),l}},{\"../../components/colorscale/calc\":601,\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],973:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../../components/colorscale\"),s=t(\"../../constants/numerical\").BADNUM,l=t(\"../../lib/geojson_utils\").makeBlank;e.exports=function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,c=e._opts={heatmap:{layout:{visibility:\"none\"},paint:{}},geojson:l()};if(!r)return c;var u,h=[],f=e.z,p=e.radius,d=i.isArrayOrTypedArray(f)&&f.length,g=i.isArrayOrTypedArray(p);for(u=0;u<t.length;u++){var v=t[u],m=v.lonlat;if(m[0]!==s){var y={};if(d){var x=v.z;y.z=x!==s?x:0}g&&(y.r=n(p[u])&&p[u]>0?+p[u]:0),h.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:m},properties:y})}}var b=o.extractOpts(e),_=b.reversescale?o.flipScale(b.colorscale):b.colorscale,w=_[0][1],k=[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,a.opacity(w)<1?w:a.addOpacity(w,0)];for(u=1;u<_.length;u++)k.push(_[u][0],_[u][1]);var T=[\"interpolate\",[\"linear\"],[\"get\",\"z\"],b.min,0,b.max,1];return i.extendFlat(c.heatmap.paint,{\"heatmap-weight\":d?T:1/(b.max-b.min),\"heatmap-color\":k,\"heatmap-radius\":g?{type:\"identity\",property:\"r\"}:e.radius,\"heatmap-opacity\":e.opacity}),c.geojson={type:\"FeatureCollection\",features:h},c.heatmap.layout.visibility=\"visible\",c}},{\"../../components/color\":593,\"../../components/colorscale\":605,\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/geojson_utils\":714,\"fast-isnumeric\":225}],974:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"lon\")||[],c=s(\"lat\")||[],u=Math.min(l.length,c.length);u?(e._length=u,s(\"z\"),s(\"radius\"),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":971}],975:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.z=e.z,t}},{}],976:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../scattermapbox/hover\");e.exports=function(t,e,r){var o=a(t,e,r);if(o){var s=o[0],l=s.cd,c=l[0].trace,u=l[s.index];if(delete s.color,\"z\"in u){var h=s.subplot.mockAxis;s.z=u.z,s.zLabel=i.tickText(h,h.c2l(u.z),\"hover\").text}return s.extraText=function(t,e,r){if(t.hovertemplate)return;var i=(e.hi||t.hoverinfo).split(\"+\"),a=-1!==i.indexOf(\"all\"),o=-1!==i.indexOf(\"lon\"),s=-1!==i.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}a||o&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):o?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(a||-1!==i.indexOf(\"text\"))&&n.fillText(e,t,c);return c.join(\"<br>\")}(c,u,l[0].t.labels),[s]}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scattermapbox/hover\":1175}],977:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),getBelow:function(t,e){for(var r=e.getMapLayers(),n=0;n<r.length;n++){var i=r[n],a=i.id;if(\"symbol\"===i.type&&\"string\"==typeof a&&-1===a.indexOf(\"plotly-\"))return a}},moduleType:\"trace\",name:\"densitymapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\"],meta:{hr_name:\"density_mapbox\"}}},{\"../../plots/mapbox\":822,\"../heatmap/colorbar\":1004,\"./attributes\":971,\"./calc\":972,\"./defaults\":974,\"./event_data\":975,\"./hover\":976,\"./plot\":978}],978:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function a(t,e){this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"heatmap\",i+e+\"-heatmap\"]],this.below=null}var o=a.prototype;o.update=function(t){var e=this.subplot,r=this.layerList,i=n(t),a=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(i.geojson),a!==this.below&&(this._removeLayers(),this._addLayers(i,a),this.below=a);for(var o=0;o<r.length;o++){var s=r[o],l=s[0],c=s[1],u=i[l];e.setOptions(c,\"setLayoutProperty\",u.layout),\"visible\"===u.layout.visibility&&e.setOptions(c,\"setPaintProperty\",u.paint)}},o._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},o._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},o.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new a(t,r.uid),o=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(o,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),i}},{\"../../plots/mapbox/constants\":820,\"./convert\":973}],979:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":719}],980:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"./constants\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../components/color\");e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,hovertext:n.hovertext,hovertemplate:o({},{keys:s.eventDataKeys}),hoverinfo:l({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"percent initial\",\"percent previous\",\"percent total\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"percent initial\",\"percent previous\",\"percent total\",\"value\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},text:n.text,textposition:l({},n.textposition,{dflt:\"auto\"}),insidetextanchor:l({},n.insidetextanchor,{dflt:\"middle\"}),textangle:l({},n.textangle,{dflt:0}),textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:l({},n.orientation,{}),offset:l({},n.offset,{arrayOk:!1}),width:l({},n.width,{arrayOk:!1}),marker:n.marker,connector:{fillcolor:{valType:\"color\",editType:\"style\"},line:{color:l({},i.color,{dflt:c.defaultLine}),width:l({},i.width,{dflt:0,editType:\"plot\"}),dash:i.dash,editType:\"style\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":593,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../bar/attributes\":857,\"../scatter/attributes\":1112,\"./constants\":982}],981:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"./arrays_to_calcdata\"),a=t(\"../scatter/calc_selection\"),o=t(\"../../constants/numerical\").BADNUM;function s(t){return t===o?0:t}e.exports=function(t,e){var r,l,c,u,h=n.getFromId(t,e.xaxis||\"x\"),f=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=h.makeCalcdata(e,\"x\"),l=f.makeCalcdata(e,\"y\")):(r=f.makeCalcdata(e,\"y\"),l=h.makeCalcdata(e,\"x\"));var p,d=Math.min(l.length,r.length),g=new Array(d);for(e._base=[],c=0;c<d;c++){r[c]<0&&(r[c]=o);var v=!1;r[c]!==o&&c+1<d&&r[c+1]!==o&&(v=!0),u=g[c]={p:l[c],s:r[c],cNext:v},e._base[c]=-.5*u.s,e.ids&&(u.id=String(e.ids[c])),0===c&&(g[0].vTotal=0),g[0].vTotal+=s(u.s),u.begR=s(u.s)/s(g[0].s)}for(c=0;c<d;c++)(u=g[c]).s!==o&&(u.sumR=u.s/g[0].vTotal,u.difR=void 0!==p?u.s/p:1,p=u.s);return i(g,e),a(g,e),g}},{\"../../constants/numerical\":695,\"../../plots/cartesian/axes\":767,\"../scatter/calc_selection\":1114,\"./arrays_to_calcdata\":979}],982:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"percentInitial\",\"percentPrevious\",\"percentTotal\"]}},{}],983:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],h=[],f=[];for(i=0;i<o.length;i++){var p=o[i],d=\"h\"===p.orientation;!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"funnel\"===p.type&&(r=s[i],d?f.push(r):h.push(r),u.push(r))}var g={mode:a.funnelmode,norm:a.funnelnorm,gap:a.funnelgap,groupgap:a.funnelgroupgap};for(n(t,l,c,h,g),n(t,c,l,f,g),i=0;i<u.length;i++){r=u[i];for(var v=0;v<r.length;v++)v+1<r.length&&(r[v].nextP0=r[v+1].p0,r[v].nextS0=r[v+1].s0,r[v].nextP1=r[v+1].p1,r[v].nextS1=r[v+1].s1)}}},{\"../bar/cross_trace_calc\":860}],984:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"./attributes\"),l=t(\"../../components/color\");e.exports={supplyDefaults:function(t,e,r,i){function c(r,i){return n.coerce(t,e,s,r,i)}if(o(t,e,i,c)){c(\"orientation\",e.y&&!e.x?\"v\":\"h\"),c(\"offset\"),c(\"width\");var u=c(\"text\");c(\"hovertext\"),c(\"hovertemplate\");var h=c(\"textposition\");a(t,e,i,c,h,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"!==e.textposition&&c(\"textinfo\",Array.isArray(u)?\"text+value\":\"value\");var f=c(\"marker.color\",r);c(\"marker.line.color\",l.defaultLine),c(\"marker.line.width\"),c(\"connector.visible\")&&(c(\"connector.fillcolor\",function(t){var e=n.isArrayOrTypedArray(t)?\"#000\":t;return l.addOpacity(e,.5*l.opacity(e))}(f)),c(\"connector.line.width\")&&(c(\"connector.line.color\"),c(\"connector.line.dash\")))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,s,t)}if(\"group\"===e.funnelmode)for(var l=0;l<t.length;l++)r=(a=t[l])._input,i(r,a,e,o)}}},{\"../../components/color\":593,\"../../lib\":719,\"../bar/defaults\":861,\"../scatter/xy_defaults\":1137,\"./attributes\":980}],985:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"percentInitial\"in e&&(t.percentInitial=e.percentInitial),\"percentPrevious\"in e&&(t.percentPrevious=e.percentPrevious),\"percentTotal\"in e&&(t.percentTotal=e.percentTotal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],986:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\").opacity,i=t(\"../bar/hover\").hoverOnBars,a=t(\"../../lib\").formatPercent;e.exports=function(t,e,r,o){var s=i(t,e,r,o);if(s){var l=s.cd,c=l[0].trace,u=\"h\"===c.orientation,h=l[s.index];s[(u?\"x\":\"y\")+\"LabelVal\"]=h.s,s.percentInitial=h.begR,s.percentInitialLabel=a(h.begR,1),s.percentPrevious=h.difR,s.percentPreviousLabel=a(h.difR,1),s.percentTotal=h.sumR,s.percentTotalLabel=a(h.sumR,1);var f=h.hi||c.hoverinfo,p=[];if(f&&\"none\"!==f&&\"skip\"!==f){var d=\"all\"===f,g=f.split(\"+\"),v=function(t){return d||-1!==g.indexOf(t)};v(\"percent initial\")&&p.push(s.percentInitialLabel+\" of initial\"),v(\"percent previous\")&&p.push(s.percentPreviousLabel+\" of previous\"),v(\"percent total\")&&p.push(s.percentTotalLabel+\" of total\")}return s.extraText=p.join(\"<br>\"),s.color=function(t,e){var r=t.marker,i=e.mc||r.color,a=e.mlc||r.line.color,o=e.mlw||r.line.width;if(n(i))return i;if(n(a)&&o)return a}(c,h),[s]}}},{\"../../components/color\":593,\"../../lib\":719,\"../bar/hover\":863}],987:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"funnel\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../bar/select\":868,\"./attributes\":980,\"./calc\":981,\"./cross_trace_calc\":983,\"./defaults\":984,\"./event_data\":985,\"./hover\":986,\"./layout_attributes\":988,\"./layout_defaults\":989,\"./plot\":990,\"./style\":991}],988:[function(t,e,r){\"use strict\";e.exports={funnelmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},funnelgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},funnelgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],989:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"funnel\"===l.type){a=!0;break}}a&&(o(\"funnelmode\"),o(\"funnelgap\",.2),o(\"funnelgroupgap\"))}},{\"../../lib\":719,\"./layout_attributes\":988}],990:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../bar/plot\").plot;function s(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),i[3]=o.c2p(t.nextS1,!0),a[3]=s.c2p(t.nextP1,!0),n?[i,a]:[a,i]}e.exports=function(t,e,r,l){var c=t._fullLayout;!function(t,e,r,o){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each(function(r){var o=n.select(this),u=r[0].trace,h=i.ensureSingle(o,\"g\",\"regions\");if(u.connector&&u.connector.visible){var f=\"h\"===u.orientation,p=h.selectAll(\"g.region\").data(i.identity);p.enter().append(\"g\").classed(\"region\",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var u=s(r,l,c,f),h=u[0],p=u[1],g=\"\";void 0!==h[3]&&void 0!==p[3]&&(g+=f?\"M\"+h[0]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[2]+\"H\"+h[3]+\"L\"+h[1]+\",\"+p[1]+\"Z\":\"M\"+h[1]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[3]+\"V\"+p[2]+\"L\"+h[1]+\",\"+p[0]+\"Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}})}else h.remove()})}(t,e,r,l),function(t,e,r,o){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each(function(r){var o=n.select(this),u=r[0].trace,h=i.ensureSingle(o,\"g\",\"lines\");if(u.connector&&u.connector.visible&&u.connector.line.width){var f=\"h\"===u.orientation,p=h.selectAll(\"g.line\").data(i.identity);p.enter().append(\"g\").classed(\"line\",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var u=s(r,l,c,f),h=u[0],p=u[1],g=\"\";void 0!==h[3]&&void 0!==p[3]&&(f?(g+=\"M\"+h[0]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[2],g+=\"M\"+h[1]+\",\"+p[1]+\"L\"+h[3]+\",\"+p[2]):(g+=\"M\"+h[1]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[3],g+=\"M\"+h[1]+\",\"+p[0]+\"L\"+h[2]+\",\"+p[2])),\"\"===g&&(g=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}})}else h.remove()})}(t,e,r,l),o(t,e,r,l,{mode:c.funnelmode,norm:c.funnelmode,gap:c.funnelgap,groupgap:c.funnelgroupgap})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../bar/plot\":867,d3:163}],991:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\").styleTextPoints;e.exports={style:function(t,e,r){var l=r||n.select(t).selectAll(\"g.funnellayer\").selectAll(\"g.trace\");l.style(\"opacity\",function(t){return t[0].trace.opacity}),l.each(function(e){var r=n.select(this),l=e[0].trace;r.selectAll(\".point > path\").each(function(t){if(!t.isBlank){var e=l.marker;n.select(this).call(a.fill,t.mc||e.color).call(a.stroke,t.mlc||e.line.color).call(i.dashLine,e.line.dash,t.mlw||e.line.width).style(\"opacity\",l.selectedpoints&&!t.selected?o:1)}}),s(r,l,t),r.selectAll(\".regions\").each(function(){n.select(this).selectAll(\"path\").style(\"stroke-width\",0).call(a.fill,l.connector.fillcolor)}),r.selectAll(\".lines\").each(function(){var t=l.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)})})}}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../constants/interactions\":694,\"../bar/style\":870,d3:163}],992:[function(t,e,r){\"use strict\";var n=t(\"../pie/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../plots/domain\").attributes,o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports={labels:n.labels,label0:n.label0,dlabel:n.dlabel,values:n.values,marker:{colors:n.marker.colors,line:{color:s({},n.marker.line.color,{dflt:null}),width:s({},n.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},text:n.text,hovertext:n.hovertext,scalegroup:s({},n.scalegroup,{}),textinfo:s({},n.textinfo,{flags:[\"label\",\"text\",\"value\",\"percent\"]}),hoverinfo:s({},i.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:o({},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),textposition:s({},n.textposition,{values:[\"inside\",\"none\"],dflt:\"inside\"}),textfont:n.textfont,insidetextfont:n.insidetextfont,title:{text:n.title.text,font:n.title.font,position:s({},n.title.position,{values:[\"top left\",\"top center\",\"top right\"],dflt:\"top center\"}),editType:\"plot\"},domain:a({name:\"funnelarea\",trace:!0,editType:\"calc\"}),aspectratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},baseratio:{valType:\"number\",min:0,max:1,dflt:.333,editType:\"plot\"}}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../pie/attributes\":1086}],993:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData;r.name=\"funnelarea\",r.plot=function(t){var e=n.getModule(\"funnelarea\"),r=i(t.calcdata,e)[0];e.plot(t,r)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"funnelarea\"),a=e._has&&e._has(\"funnelarea\");i&&!a&&n._funnelarealayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],994:[function(t,e,r){\"use strict\";var n=t(\"../pie/calc\");e.exports={calc:function(t,e){return n.calc(t,e)},crossTraceCalc:function(t){n.crossTraceCalc(t,{type:\"funnelarea\"})}}},{\"../pie/calc\":1088}],995:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}var c,u=l(\"values\"),h=n.isArrayOrTypedArray(u),f=l(\"labels\");if(Array.isArray(f)?(c=f.length,h&&(c=Math.min(c,u.length))):h&&(c=u.length,l(\"label0\"),l(\"dlabel\")),c){e._length=c,l(\"marker.line.width\")&&l(\"marker.line.color\",s.paper_bgcolor),l(\"marker.colors\"),l(\"scalegroup\");var p=l(\"text\"),d=l(\"textinfo\",Array.isArray(p)?\"text+percent\":\"percent\");if(l(\"hovertext\"),l(\"hovertemplate\"),d&&\"none\"!==d){var g=l(\"textposition\");o(t,e,s,l,g,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}a(e,s,l),l(\"title.text\")&&(l(\"title.position\"),n.coerceFont(l,\"title.font\",s.font)),l(\"aspectratio\"),l(\"baseratio\")}else e.visible=!1}},{\"../../lib\":719,\"../../plots/domain\":792,\"../bar/defaults\":861,\"./attributes\":992}],996:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"funnelarea\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"funnelarea\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\"),styleOne:t(\"../pie/style_one\"),meta:{}}},{\"../pie/style_one\":1097,\"./attributes\":992,\"./base_plot\":993,\"./calc\":994,\"./defaults\":995,\"./layout_attributes\":997,\"./layout_defaults\":998,\"./plot\":999,\"./style\":1e3}],997:[function(t,e,r){\"use strict\";var n=t(\"../pie/layout_attributes\").hiddenlabels;e.exports={hiddenlabels:n,funnelareacolorway:{valType:\"colorlist\",editType:\"calc\"},extendfunnelareacolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{\"../pie/layout_attributes\":1093}],998:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"funnelareacolorway\",e.colorway),r(\"extendfunnelareacolors\")}},{\"../../lib\":719,\"./layout_attributes\":997}],999:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../lib\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../bar/plot\"),l=s.getTransform,c=s.toMoveInsideBar,u=t(\"../pie/helpers\"),h=t(\"../pie/plot\"),f=h.attachFxHandlers,p=h.determineInsideTextFont,d=h.layoutAreas,g=h.prerenderTitles,v=h.positionTitleOutside;function m(t,e){return\"l\"+(e[0]-t[0])+\",\"+(e[1]-t[1])}e.exports=function(t,e){var r=t._fullLayout;g(e,t),d(e,r._size),a.makeTraceGroups(r._funnelarealayer,e,\"trace\").each(function(e){var s=n.select(this),h=e[0],d=h.trace;!function(t){if(!t.length)return;var e=t[0],r=e.trace,n=r.aspectratio,i=r.baseratio;i>.999&&(i=.999);var a,o=Math.pow(i,2),s=e.vTotal,l=s,c=s*o/(1-o)/s;function u(){var t,e={x:t=Math.sqrt(c),y:-t};return[e.x,e.y]}var h,f,p=[];for(p.push(u()),h=t.length-1;h>-1;h--)if(!(f=t[h]).hidden){var d=f.v/l;c+=d,p.push(u())}var g=1/0,v=-1/0;for(h=0;h<p.length;h++)a=p[h],g=Math.min(g,a[1]),v=Math.max(v,a[1]);for(h=0;h<p.length;h++)p[h][1]-=(v+g)/2;var m=p[p.length-1][0],y=e.r,x=(v-g)/2,b=y/m,_=y/x*n;for(e.r=_*x,h=0;h<p.length;h++)p[h][0]*=b,p[h][1]*=_;var w=[-(a=p[0])[0],a[1]],k=[a[0],a[1]],T=0;for(h=t.length-1;h>-1;h--)if(!(f=t[h]).hidden){var A=p[T+=1][0],M=p[T][1];f.TL=[-A,M],f.TR=[A,M],f.BL=w,f.BR=k,f.pxmid=(S=f.TR,E=f.BR,[.5*(S[0]+E[0]),.5*(S[1]+E[1])]),w=f.TL,k=f.TR}var S,E}(e),s.each(function(){var s=n.select(this).selectAll(\"g.slice\").data(e);s.enter().append(\"g\").classed(\"slice\",!0),s.exit().remove(),s.each(function(r){if(r.hidden)n.select(this).selectAll(\"path,g\").remove();else{r.pointNumber=r.i,r.curveNumber=d.index;var s=h.cx,g=h.cy,v=n.select(this),y=v.selectAll(\"path.surface\").data([r]);y.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),v.call(f,t,e);var x=\"M\"+(s+r.TR[0])+\",\"+(g+r.TR[1])+m(r.TR,r.BR)+m(r.BR,r.BL)+m(r.BL,r.TL)+\"Z\";y.attr(\"d\",x);var b=u.castOption(d.textposition,r.pts),_=v.selectAll(\"g.slicetext\").data(r.text&&\"none\"!==b?[0]:[]);_.enter().append(\"g\").classed(\"slicetext\",!0),_.exit().remove(),_.each(function(){var e=a.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)});e.text(r.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,p(d,r,t._fullLayout.font)).call(o.convertToTspans,t);var u,h,f,v=i.bBox(e.node()),m=Math.min(r.BL[1],r.BR[1]),y=Math.max(r.TL[1],r.TR[1]);h=Math.max(r.TL[0],r.BL[0]),f=Math.min(r.TR[0],r.BR[0]),u=l(c(h,f,m,y,v,{isHorizontal:!0,constrained:!0,angle:0,anchor:\"middle\"})),e.attr(\"transform\",\"translate(\"+s+\",\"+g+\")\"+u)})}});var g=n.select(this).selectAll(\"g.titletext\").data(d.title.text?[0]:[]);g.enter().append(\"g\").classed(\"titletext\",!0),g.exit().remove(),g.each(function(){var e=a.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),s=d.title.text;d._meta&&(s=a.templateString(s,d._meta)),e.text(s).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,d.title.font).call(o.convertToTspans,t);var l=v(h,r._size);e.attr(\"transform\",\"translate(\"+l.x+\",\"+l.y+\")\"+(l.scale<1?\"scale(\"+l.scale+\")\":\"\")+\"translate(\"+l.tx+\",\"+l.ty+\")\")})})})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../bar/plot\":867,\"../pie/helpers\":1091,\"../pie/plot\":1095,d3:163}],1000:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../pie/style_one\");e.exports=function(t){t._fullLayout._funnelarealayer.selectAll(\".trace\").each(function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each(function(t){n.select(this).call(i,t,e)})})}},{\"../pie/style_one\":1097,d3:163}],1001:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../components/colorscale/attributes\"),o=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../lib/extend\").extendFlat);e.exports=o({z:{valType:\"data_array\",editType:\"calc\"},x:o({},n.x,{impliedEdits:{xtype:\"array\"}}),x0:o({},n.x0,{impliedEdits:{xtype:\"scaled\"}}),dx:o({},n.dx,{impliedEdits:{xtype:\"scaled\"}}),y:o({},n.y,{impliedEdits:{ytype:\"array\"}}),y0:o({},n.y0,{impliedEdits:{ytype:\"scaled\"}}),dy:o({},n.dy,{impliedEdits:{ytype:\"scaled\"}}),text:{valType:\"data_array\",editType:\"calc\"},hovertext:{valType:\"data_array\",editType:\"calc\"},transpose:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xtype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},ytype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},zsmooth:{valType:\"enumerated\",values:[\"fast\",\"best\",!1],dflt:!1,editType:\"calc\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xgap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},ygap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},zhoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},hovertemplate:i()},{transforms:void 0},a(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../scatter/attributes\":1112}],1002:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../histogram2d/calc\"),s=t(\"../../components/colorscale/calc\"),l=t(\"./convert_column_xyz\"),c=t(\"./clean_2d_array\"),u=t(\"./interp2d\"),h=t(\"./find_empties\"),f=t(\"./make_bound_array\");e.exports=function(t,e){var r,p,d,g,v,m,y,x,b,_=a.getFromId(t,e.xaxis||\"x\"),w=a.getFromId(t,e.yaxis||\"y\"),k=n.traceIs(e,\"contour\"),T=n.traceIs(e,\"histogram\"),A=n.traceIs(e,\"gl2d\"),M=k?\"best\":e.zsmooth;if(_._minDtick=0,w._minDtick=0,T)r=(b=o(t,e)).x,p=b.x0,d=b.dx,g=b.y,v=b.y0,m=b.dy,y=b.z;else{var S=e.z;i.isArray1D(S)?(l(e,_,w,\"x\",\"y\",[\"z\"]),r=e._x,g=e._y,S=e._z):(r=e._x=e.x?_.makeCalcdata(e,\"x\"):[],g=e._y=e.y?w.makeCalcdata(e,\"y\"):[]),p=e.x0,d=e.dx,v=e.y0,m=e.dy,y=c(S,e,_,w),(k||e.connectgaps)&&(e._emptypoints=h(y),u(y,e._emptypoints))}function E(t){M=e._input.zsmooth=e.zsmooth=!1,i.warn('cannot use zsmooth: \"fast\": '+t)}if(\"fast\"===M)if(\"log\"===_.type||\"log\"===w.type)E(\"log axis found\");else if(!T){if(r.length){var C=(r[r.length-1]-r[0])/(r.length-1),L=Math.abs(C/100);for(x=0;x<r.length-1;x++)if(Math.abs(r[x+1]-r[x]-C)>L){E(\"x scale is not linear\");break}}if(g.length&&\"fast\"===M){var P=(g[g.length-1]-g[0])/(g.length-1),O=Math.abs(P/100);for(x=0;x<g.length-1;x++)if(Math.abs(g[x+1]-g[x]-P)>O){E(\"y scale is not linear\");break}}}var z=i.maxRowLength(y),I=\"scaled\"===e.xtype?\"\":r,D=f(e,I,p,d,z,_),R=\"scaled\"===e.ytype?\"\":g,F=f(e,R,v,m,y.length,w);A||(e._extremes[_._id]=a.findExtremes(_,D),e._extremes[w._id]=a.findExtremes(w,F));var B={x:D,y:F,z:y,text:e._text||e.text,hovertext:e._hovertext||e.hovertext};if(I&&I.length===D.length-1&&(B.xCenter=I),R&&R.length===F.length-1&&(B.yCenter=R),T&&(B.xRanges=b.xRanges,B.yRanges=b.yRanges,B.pts=b.pts),k||s(t,e,{vals:y,cLetter:\"z\"}),k&&e.contours&&\"heatmap\"===e.contours.coloring){var N={type:\"contour\"===e.type?\"heatmap\":\"histogram2d\",xcalendar:e.xcalendar,ycalendar:e.ycalendar};B.xfill=f(N,I,p,d,z,_),B.yfill=f(N,R,v,m,y.length,w)}return[B]}},{\"../../components/colorscale/calc\":601,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../histogram2d/calc\":1033,\"./clean_2d_array\":1003,\"./convert_column_xyz\":1005,\"./find_empties\":1007,\"./interp2d\":1010,\"./make_bound_array\":1011}],1003:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r,o){var s,l,c,u,h,f;function p(t){if(n(t))return+t}if(e&&e.transpose){for(s=0,h=0;h<t.length;h++)s=Math.max(s,t[h].length);if(0===s)return!1;c=function(t){return t.length},u=function(t,e,r){return(t[r]||[])[e]}}else s=t.length,c=function(t,e){return t[e].length},u=function(t,e,r){return(t[e]||[])[r]};var d=function(t,e,r){return e===a||r===a?a:u(t,e,r)};function g(t){if(e&&\"carpet\"!==e.type&&\"contourcarpet\"!==e.type&&t&&\"category\"===t.type&&e[\"_\"+t._id.charAt(0)].length){var r=t._id.charAt(0),n={},o=e[\"_\"+r+\"CategoryMap\"]||e[r];for(h=0;h<o.length;h++)n[o[h]]=h;return function(e){var r=n[t._categories[e]];return r+1?r:a}}return i.identity}var v=g(r),m=g(o);o&&\"category\"===o.type&&(s=o._categories.length);var y=new Array(s);for(h=0;h<s;h++)for(l=r&&\"category\"===r.type?r._categories.length:c(t,h),y[h]=new Array(l),f=0;f<l;f++)y[h][f]=p(d(t,m(h),v(f)));return y}},{\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],1004:[function(t,e,r){\"use strict\";e.exports={min:\"zmin\",max:\"zmax\"}},{}],1005:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r,a,o,s){var l,c,u,h,f=t._length,p=e.makeCalcdata(t,a),d=r.makeCalcdata(t,o),g=t.text,v=void 0!==g&&n.isArray1D(g),m=t.hovertext,y=void 0!==m&&n.isArray1D(m),x=n.distinctVals(p),b=x.vals,_=n.distinctVals(d),w=_.vals,k=[];for(l=0;l<s.length;l++)k[l]=n.init2dArray(w.length,b.length);for(v&&(u=n.init2dArray(w.length,b.length)),y&&(h=n.init2dArray(w.length,b.length)),l=0;l<f;l++)if(p[l]!==i&&d[l]!==i){var T=n.findBin(p[l]+x.minDiff/2,b),A=n.findBin(d[l]+_.minDiff/2,w);for(c=0;c<s.length;c++){var M=t[s[c]];k[c][A][T]=M[l]}v&&(u[A][T]=g[l]),y&&(h[A][T]=m[l])}for(t[\"_\"+a]=b,t[\"_\"+o]=w,c=0;c<s.length;c++)t[\"_\"+s[c]]=k[c];v&&(t._text=u),y&&(t._hovertext=h),e&&\"category\"===e.type&&(t[\"_\"+a+\"CategoryMap\"]=b.map(function(t){return e._categories[t]})),r&&\"category\"===r.type&&(t[\"_\"+o+\"CategoryMap\"]=w.map(function(t){return r._categories[t]}))}},{\"../../constants/numerical\":695,\"../../lib\":719}],1006:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xyz_defaults\"),a=t(\"./style_defaults\"),o=t(\"../../components/colorscale/defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l)?(c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\"),a(t,e,c,l),c(\"connectgaps\",n.isArray1D(e.z)&&!1!==e.zsmooth),o(t,e,l,c,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":1001,\"./style_defaults\":1014,\"./xyz_defaults\":1015}],1007:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").maxRowLength;e.exports=function(t){var e,r,i,a,o,s,l,c,u=[],h={},f=[],p=t[0],d=[],g=[0,0,0],v=n(t);for(r=0;r<t.length;r++)for(e=d,d=p,p=t[r+1]||[],i=0;i<v;i++)void 0===d[i]&&((s=(void 0!==d[i-1]?1:0)+(void 0!==d[i+1]?1:0)+(void 0!==e[i]?1:0)+(void 0!==p[i]?1:0))?(0===r&&s++,0===i&&s++,r===t.length-1&&s++,i===d.length-1&&s++,s<4&&(h[[r,i]]=[r,i,s]),u.push([r,i,s])):f.push([r,i]));for(;f.length;){for(l={},c=!1,o=f.length-1;o>=0;o--)(s=((h[[(r=(a=f[o])[0])-1,i=a[1]]]||g)[2]+(h[[r+1,i]]||g)[2]+(h[[r,i-1]]||g)[2]+(h[[r,i+1]]||g)[2])/20)&&(l[a]=[r,i,s],f.splice(o,1),c=!0);if(!c)throw\"findEmpties iterated with no new neighbors\";for(a in l)h[a]=l[a],u.push(l[a])}return u.sort(function(t,e){return e[2]-t[2]})}},{\"../../lib\":719}],1008:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../components/colorscale\").extractOpts;e.exports=function(t,e,r,s,l,c){var u,h,f,p,d=t.cd[0],g=d.trace,v=t.xa,m=t.ya,y=d.x,x=d.y,b=d.z,_=d.xCenter,w=d.yCenter,k=d.zmask,T=g.zhoverformat,A=y,M=x;if(!1!==t.index){try{f=Math.round(t.index[1]),p=Math.round(t.index[0])}catch(e){return void i.error(\"Error hovering on heatmap, pointNumber must be [row,col], found:\",t.index)}if(f<0||f>=b[0].length||p<0||p>b.length)return}else{if(n.inbox(e-y[0],e-y[y.length-1],0)>0||n.inbox(r-x[0],r-x[x.length-1],0)>0)return;if(c){var S;for(A=[2*y[0]-y[1]],S=1;S<y.length;S++)A.push((y[S]+y[S-1])/2);for(A.push([2*y[y.length-1]-y[y.length-2]]),M=[2*x[0]-x[1]],S=1;S<x.length;S++)M.push((x[S]+x[S-1])/2);M.push([2*x[x.length-1]-x[x.length-2]])}f=Math.max(0,Math.min(A.length-2,i.findBin(e,A))),p=Math.max(0,Math.min(M.length-2,i.findBin(r,M)))}var E=v.c2p(y[f]),C=v.c2p(y[f+1]),L=m.c2p(x[p]),P=m.c2p(x[p+1]);c?(C=E,u=y[f],P=L,h=x[p]):(u=_?_[f]:(y[f]+y[f+1])/2,h=w?w[p]:(x[p]+x[p+1])/2,v&&\"category\"===v.type&&(u=y[f]),m&&\"category\"===m.type&&(h=x[p]),g.zsmooth&&(E=C=v.c2p(u),L=P=m.c2p(h)));var O,z=b[p][f];k&&!k[p][f]&&(z=void 0),Array.isArray(d.hovertext)&&Array.isArray(d.hovertext[p])?O=d.hovertext[p][f]:Array.isArray(d.text)&&Array.isArray(d.text[p])&&(O=d.text[p][f]);var I=o(g),D={type:\"linear\",range:[I.min,I.max],hoverformat:T,_separators:v._separators,_numFormat:v._numFormat},R=a.tickText(D,z,\"hover\").text;return[i.extendFlat(t,{index:[p,f],distance:t.maxHoverDistance,spikeDistance:t.maxSpikeDistance,x0:E,x1:C,y0:L,y1:P,xLabelVal:u,yLabelVal:h,zLabelVal:z,zLabel:R,text:O})]}},{\"../../components/colorscale\":605,\"../../components/fx\":632,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],1009:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:t(\"./colorbar\"),style:t(\"./style\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"heatmap\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":1001,\"./calc\":1002,\"./colorbar\":1004,\"./defaults\":1006,\"./hover\":1008,\"./plot\":1012,\"./style\":1013}],1010:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[-1,0],[1,0],[0,-1],[0,1]];function a(t){return.5-.25*Math.min(1,.5*t)}function o(t,e,r){var n,a,o,s,l,c,u,h,f,p,d,g,v,m=0;for(s=0;s<e.length;s++){for(a=(n=e[s])[0],o=n[1],d=t[a][o],p=0,f=0,l=0;l<4;l++)(u=t[a+(c=i[l])[0]])&&void 0!==(h=u[o+c[1]])&&(0===p?g=v=h:(g=Math.min(g,h),v=Math.max(v,h)),f++,p+=h);if(0===f)throw\"iterateInterp2d order is wrong: no defined neighbors\";t[a][o]=p/f,void 0===d?f<4&&(m=1):(t[a][o]=(1+r)*t[a][o]-r*d,v>g&&(m=Math.max(m,Math.abs(t[a][o]-d)/(v-g))))}return m}e.exports=function(t,e){var r,i=1;for(o(t,e),r=0;r<e.length&&!(e[r][2]<4);r++);for(e=e.slice(r),r=0;r<100&&i>.01;r++)i=o(t,e,a(i));return i>.01&&n.log(\"interp2d didn't converge quickly\",i),t}},{\"../../lib\":719}],1011:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a,o,s){var l,c,u,h=[],f=n.traceIs(t,\"contour\"),p=n.traceIs(t,\"histogram\"),d=n.traceIs(t,\"gl2d\");if(i(e)&&e.length>1&&!p&&\"category\"!==s.type){var g=e.length;if(!(g<=o))return f?e.slice(0,o):e.slice(0,o+1);if(f||d)h=e.slice(0,o);else if(1===o)h=[e[0]-.5,e[0]+.5];else{for(h=[1.5*e[0]-.5*e[1]],u=1;u<g;u++)h.push(.5*(e[u-1]+e[u]));h.push(1.5*e[g-1]-.5*e[g-2])}if(g<o){var v=h[h.length-1],m=v-h[h.length-2];for(u=g;u<o;u++)v+=m,h.push(v)}}else{var y=t[s._id.charAt(0)+\"calendar\"];if(p)l=s.r2c(r,0,y);else if(i(e)&&1===e.length)l=e[0];else if(void 0===r)l=0;else{l=(\"log\"===s.type?s.d2c:s.r2c)(r,0,y)}for(c=a||1,u=f||d?0:-.5;u<o;u++)h.push(l+c*u)}return h}},{\"../../lib\":719,\"../../registry\":847}],1012:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/colorscale\").makeColorScaleFuncFromTrace,l=t(\"../../constants/xmlns_namespaces\");function c(t,e){var r=e.length-2,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=e[n+1],s=o.constrain(n+(t-i)/(a-i)-.5,0,r),l=Math.round(s),c=Math.abs(s-l);return s&&s!==r&&c?{bin0:l,frac:c,bin1:Math.round(l+c/(s-l))}:{bin0:l,bin1:l,frac:0}}function u(t,e){var r=e.length-1,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=(t-i)/(e[n+1]-i)||0;return a<=0?{bin0:n,bin1:n,frac:0}:a<.5?{bin0:n,bin1:n+1,frac:a}:{bin0:n+1,bin1:n,frac:1-a}}function h(t,e,r){t[e]=r[0],t[e+1]=r[1],t[e+2]=r[2],t[e+3]=Math.round(255*r[3])}e.exports=function(t,e,r,f){var p=e.xaxis,d=e.yaxis;o.makeTraceGroups(f,r,\"hm\").each(function(e){var r,f,g,v,m,y,x=n.select(this),b=e[0],_=b.trace,w=b.z,k=b.x,T=b.y,A=b.xCenter,M=b.yCenter,S=a.traceIs(_,\"contour\"),E=S?\"best\":_.zsmooth,C=w.length,L=o.maxRowLength(w),P=!1,O=!1;for(y=0;void 0===r&&y<k.length-1;)r=p.c2p(k[y]),y++;for(y=k.length-1;void 0===f&&y>0;)f=p.c2p(k[y]),y--;for(f<r&&(g=f,f=r,r=g,P=!0),y=0;void 0===v&&y<T.length-1;)v=d.c2p(T[y]),y++;for(y=T.length-1;void 0===m&&y>0;)m=d.c2p(T[y]),y--;if(m<v&&(g=v,v=m,m=g,O=!0),S&&(A=k,M=T,k=b.xfill,T=b.yfill),\"fast\"!==E){var z=\"best\"===E?0:.5;r=Math.max(-z*p._length,r),f=Math.min((1+z)*p._length,f),v=Math.max(-z*d._length,v),m=Math.min((1+z)*d._length,m)}var I=Math.round(f-r),D=Math.round(m-v);if(I<=0||D<=0){x.selectAll(\"image\").data([]).exit().remove()}else{var R,F;\"fast\"===E?(R=L,F=C):(R=I,F=D);var B=document.createElement(\"canvas\");B.width=R,B.height=F;var N,j,U=B.getContext(\"2d\"),V=s(_,{noNumericCheck:!0,returnArray:!0});\"fast\"===E?(N=P?function(t){return L-1-t}:o.identity,j=O?function(t){return C-1-t}:o.identity):(N=function(t){return o.constrain(Math.round(p.c2p(k[t])-r),0,I)},j=function(t){return o.constrain(Math.round(d.c2p(T[t])-v),0,D)});var q,H,G,Y,W,X=j(0),Z=[X,X],J=P?0:1,K=O?0:1,$=0,Q=0,tt=0,et=0;if(E){var rt,nt=0;try{rt=new Uint8Array(I*D*4)}catch(t){rt=new Array(I*D*4)}if(\"best\"===E){var it,at,ot,st=A||k,lt=M||T,ct=new Array(st.length),ut=new Array(lt.length),ht=new Array(I),ft=A?u:c,pt=M?u:c;for(y=0;y<st.length;y++)ct[y]=Math.round(p.c2p(st[y])-r);for(y=0;y<lt.length;y++)ut[y]=Math.round(d.c2p(lt[y])-v);for(y=0;y<I;y++)ht[y]=ft(y,ct);for(H=0;H<D;H++)for(at=w[(it=pt(H,ut)).bin0],ot=w[it.bin1],y=0;y<I;y++,nt+=4)h(rt,nt,W=Tt(at,ot,ht[y],it))}else for(H=0;H<C;H++)for(Y=w[H],Z=j(H),y=0;y<I;y++)W=kt(Y[y],1),h(rt,nt=4*(Z*I+N(y)),W);var dt=U.createImageData(I,D);try{dt.data.set(rt)}catch(t){var gt=dt.data,vt=gt.length;for(H=0;H<vt;H++)gt[H]=rt[H]}U.putImageData(dt,0,0)}else{var mt=_.xgap,yt=_.ygap,xt=Math.floor(mt/2),bt=Math.floor(yt/2);for(H=0;H<C;H++)if(Y=w[H],Z.reverse(),Z[K]=j(H+1),Z[0]!==Z[1]&&void 0!==Z[0]&&void 0!==Z[1])for(q=[G=N(0),G],y=0;y<L;y++)q.reverse(),q[J]=N(y+1),q[0]!==q[1]&&void 0!==q[0]&&void 0!==q[1]&&(W=kt(Y[y],(q[1]-q[0])*(Z[1]-Z[0])),U.fillStyle=\"rgba(\"+W.join(\",\")+\")\",U.fillRect(q[0]+xt,Z[0]+bt,q[1]-q[0]-mt,Z[1]-Z[0]-yt))}Q=Math.round(Q/$),tt=Math.round(tt/$),et=Math.round(et/$);var _t=i(\"rgb(\"+Q+\",\"+tt+\",\"+et+\")\");t._hmpixcount=(t._hmpixcount||0)+$,t._hmlumcount=(t._hmlumcount||0)+$*_t.getLuminance();var wt=x.selectAll(\"image\").data(e);wt.enter().append(\"svg:image\").attr({xmlns:l.svg,preserveAspectRatio:\"none\"}),wt.attr({height:D,width:I,x:r,y:v,\"xlink:href\":B.toDataURL(\"image/png\")})}function kt(t,e){if(void 0!==t){var r=V(t);return r[0]=Math.round(r[0]),r[1]=Math.round(r[1]),r[2]=Math.round(r[2]),$+=e,Q+=r[0]*e,tt+=r[1]*e,et+=r[2]*e,r}return[0,0,0,0]}function Tt(t,e,r,n){var i=t[r.bin0];if(void 0===i)return kt(void 0,1);var a,o=t[r.bin1],s=e[r.bin0],l=e[r.bin1],c=o-i||0,u=s-i||0;return a=void 0===o?void 0===l?0:void 0===s?2*(l-i):2*(2*l-s-i)/3:void 0===l?void 0===s?0:2*(2*i-o-s)/3:void 0===s?2*(2*l-o-i)/3:l+i-o-s,kt(i+r.frac*c+n.frac*(u+r.frac*a))}})}},{\"../../components/colorscale\":605,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../registry\":847,d3:163,tinycolor2:537}],1013:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t){n.select(t).selectAll(\".hm image\").style(\"opacity\",function(t){return t.trace.opacity})}},{d3:163}],1014:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){!1===r(\"zsmooth\")&&(r(\"xgap\"),r(\"ygap\")),r(\"zhoverformat\")}},{}],1015:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\");function o(t,e){var r=e(t);return\"scaled\"===(r?e(t+\"type\",\"array\"):\"scaled\")&&(e(t+\"0\"),e(\"d\"+t)),r}e.exports=function(t,e,r,s,l,c){var u,h,f=r(\"z\");if(l=l||\"x\",c=c||\"y\",void 0===f||!f.length)return 0;if(i.isArray1D(t.z)){u=r(l),h=r(c);var p=i.minRowLength(u),d=i.minRowLength(h);if(0===p||0===d)return 0;e._length=Math.min(p,d,f.length)}else{if(u=o(l,r),h=o(c,r),!function(t){for(var e,r=!0,a=!1,o=!1,s=0;s<t.length;s++){if(e=t[s],!i.isArrayOrTypedArray(e)){r=!1;break}e.length>0&&(a=!0);for(var l=0;l<e.length;l++)if(n(e[l])){o=!0;break}}return r&&a&&o}(f))return 0;r(\"transpose\"),e._length=null}return a.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[l,c],s),!0}},{\"../../lib\":719,\"../../registry\":847,\"fast-isnumeric\":225}],1016:[function(t,e,r){\"use strict\";for(var n=t(\"../heatmap/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=[\"z\",\"x\",\"x0\",\"dx\",\"y\",\"y0\",\"dy\",\"text\",\"transpose\",\"xtype\",\"ytype\"],l={},c=0;c<s.length;c++){var u=s[c];l[u]=n[u]}a(l,i(\"\",{cLetter:\"z\",autoColorDflt:!1})),e.exports=o(l,\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../heatmap/attributes\":1001}],1017:[function(t,e,r){\"use strict\";var n=t(\"gl-heatmap2d\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib/str2rgbarray\");function o(t,e){this.scene=t,this.uid=e,this.type=\"heatmapgl\",this.name=\"\",this.hoverinfo=\"all\",this.xData=[],this.yData=[],this.zData=[],this.textLabels=[],this.idToIndex=[],this.bounds=[0,0,0,0],this.options={z:[],x:[],y:[],shape:[0,0],colorLevels:[0],colorValues:[0,0,0,1]},this.heatmap=n(t.glplot,this.options),this.heatmap._trace=this}var s=o.prototype;s.handlePick=function(t){var e=this.options,r=e.shape,n=t.pointId,i=n%r[0],a=Math.floor(n/r[0]),o=n;return{trace:this,dataCoord:t.dataCoord,traceCoord:[e.x[i],e.y[a],e.z[o]],textLabel:this.textLabels[n],name:this.name,pointIndex:[a,i],hoverinfo:this.hoverinfo}},s.update=function(t,e){var r=e[0];this.index=t.index,this.name=t.name,this.hoverinfo=t.hoverinfo;var n=r.z;this.options.z=[].concat.apply([],n);var o=n[0].length,s=n.length;this.options.shape=[o,s],this.options.x=r.x,this.options.y=r.y;var l=function(t){for(var e=t.colorscale,r=t.zmin,n=t.zmax,i=e.length,o=new Array(i),s=new Array(4*i),l=0;l<i;l++){var c=e[l],u=a(c[1]);o[l]=r+c[0]*(n-r);for(var h=0;h<4;h++)s[4*l+h]=u[h]}return{colorLevels:o,colorValues:s}}(t);this.options.colorLevels=l.colorLevels,this.options.colorValues=l.colorValues,this.textLabels=[].concat.apply([],t.text),this.heatmap.update(this.options);var c=this.scene.xaxis,u=this.scene.yaxis;t._extremes[c._id]=i.findExtremes(c,r.x),t._extremes[u._id]=i.findExtremes(u,r.y)},s.dispose=function(){this.heatmap.dispose()},e.exports=function(t,e,r){var n=new o(t,e.uid);return n.update(e,r),n}},{\"../../lib/str2rgbarray\":742,\"../../plots/cartesian/axes\":767,\"gl-heatmap2d\":251}],1018:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"../heatmap/defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../heatmap/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"heatmapgl\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"2dMap\"],meta:{}}},{\"../../plots/gl2d\":805,\"../heatmap/calc\":1002,\"../heatmap/colorbar\":1004,\"../heatmap/defaults\":1006,\"./attributes\":1016,\"./convert\":1017}],1019:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"./bin_attributes\"),o=t(\"./constants\"),s=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),orientation:n.orientation,histfunc:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"min\",\"max\"],dflt:\"count\",editType:\"calc\"},histnorm:{valType:\"enumerated\",values:[\"\",\"percent\",\"probability\",\"density\",\"probability density\"],dflt:\"\",editType:\"calc\"},cumulative:{enabled:{valType:\"boolean\",dflt:!1,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"increasing\",\"decreasing\"],dflt:\"increasing\",editType:\"calc\"},currentbin:{valType:\"enumerated\",values:[\"include\",\"exclude\",\"half\"],dflt:\"include\",editType:\"calc\"},editType:\"calc\"},nbinsx:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},xbins:a(\"x\",!0),nbinsy:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},ybins:a(\"y\",!0),autobinx:{valType:\"boolean\",dflt:null,editType:\"calc\"},autobiny:{valType:\"boolean\",dflt:null,editType:\"calc\"},bingroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:i({},{keys:o.eventDataKeys}),marker:n.marker,offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,_deprecated:{bardir:n._deprecated.bardir}}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../bar/attributes\":857,\"./bin_attributes\":1021,\"./constants\":1025}],1020:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=t.length,n=0,i=0;i<r;i++)e[i]?(t[i]/=e[i],n+=t[i]):t[i]=null;return n}},{}],1021:[function(t,e,r){\"use strict\";e.exports=function(t,e){return{start:{valType:\"any\",editType:\"calc\"},end:{valType:\"any\",editType:\"calc\"},size:{valType:\"any\",editType:\"calc\"},editType:\"calc\"}}},{}],1022:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports={count:function(t,e,r){return r[t]++,1},sum:function(t,e,r,i){var a=i[e];return n(a)?(a=Number(a),r[t]+=a,a):0},avg:function(t,e,r,i,a){var o=i[e];return n(o)&&(o=Number(o),r[t]+=o,a[t]++),0},min:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]>a){var o=a-r[t];return r[t]=a,o}}return 0},max:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]<a){var o=a-r[t];return r[t]=a,o}}return 0}}},{\"fast-isnumeric\":225}],1023:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.ONEAVGYEAR,a=n.ONEAVGMONTH,o=n.ONEDAY,s=n.ONEHOUR,l=n.ONEMIN,c=n.ONESEC,u=t(\"../../plots/cartesian/axes\").tickIncrement;function h(t,e,r,n){if(t*e<=0)return 1/0;for(var i=Math.abs(e-t),a=\"date\"===r.type,o=f(i,a),s=0;s<10;s++){var l=f(80*o,a);if(o===l)break;if(!p(l,t,e,a,r,n))break;o=l}return o}function f(t,e){return e&&t>c?t>o?t>1.1*i?i:t>1.1*a?a:o:t>s?s:t>l?l:c:Math.pow(10,Math.floor(Math.log(t)/Math.LN10))}function p(t,e,r,n,a,s){if(n&&t>o){var l=d(e,a,s),c=d(r,a,s),u=t===i?0:1;return l[u]!==c[u]}return Math.floor(r/t)-Math.floor(e/t)>.1}function d(t,e,r){var n=e.c2d(t,i,r).split(\"-\");return\"\"===n[0]&&(n.unshift(),n[0]=\"-\"+n[0]),n}e.exports=function(t,e,r,n,a){var s,l,c=-1.1*e,f=-.1*e,p=t-f,d=r[0],g=r[1],v=Math.min(h(d+f,d+p,n,a),h(g+f,g+p,n,a)),m=Math.min(h(d+c,d+f,n,a),h(g+c,g+f,n,a));if(v>m&&m<Math.abs(g-d)/4e3?(s=v,l=!1):(s=Math.min(v,m),l=!0),\"date\"===n.type&&s>o){var y=s===i?1:6,x=s===i?\"M12\":\"M1\";return function(e,r){var o=n.c2d(e,i,a),s=o.indexOf(\"-\",y);s>0&&(o=o.substr(0,s));var c=n.d2c(o,0,a);if(c<e){var h=u(c,x,!1,a);(c+h)/2<e+t&&(c=h)}return r&&l?u(c,x,!0,a):c}}return function(e,r){var n=s*Math.round(e/s);return n+s/10<e&&n+.9*s<e+t&&(n+=s),r&&l&&(n-=s),n}}},{\"../../constants/numerical\":695,\"../../plots/cartesian/axes\":767}],1024:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../bar/arrays_to_calcdata\"),l=t(\"./bin_functions\"),c=t(\"./norm_functions\"),u=t(\"./average\"),h=t(\"./bin_label_vals\");function f(t,e,r,s,l){var c,u,h,p,d,g,v,m=s+\"bins\",y=t._fullLayout,x=e[\"_\"+s+\"bingroup\"],b=y._histogramBinOpts[x],_=\"overlay\"===y.barmode,w=function(t){return r.r2c(t,0,p)},k=function(t){return r.c2r(t,0,p)},T=\"date\"===r.type?function(t){return t||0===t?i.cleanDate(t,null,p):null}:function(t){return n(t)?Number(t):null};function A(t,e,r){e[t+\"Found\"]?(e[t]=T(e[t]),null===e[t]&&(e[t]=r[t])):(g[t]=e[t]=r[t],i.nestedProperty(u[0],m+\".\"+t).set(r[t]))}if(e[\"_\"+s+\"autoBinFinished\"])delete e[\"_\"+s+\"autoBinFinished\"];else{u=b.traces;var M=[],S=!0,E=!1,C=!1;for(c=0;c<u.length;c++)if((h=u[c]).visible){var L=b.dirs[c];d=h[\"_\"+L+\"pos0\"]=r.makeCalcdata(h,L),M=i.concat(M,d),delete h[\"_\"+s+\"autoBinFinished\"],!0===e.visible&&(S?S=!1:(delete h._autoBin,h[\"_\"+s+\"autoBinFinished\"]=1),a.traceIs(h,\"2dMap\")&&(E=!0),\"histogram2dcontour\"===h.type&&(C=!0))}p=u[0][s+\"calendar\"];var P=o.autoBin(M,r,b.nbins,E,p,b.sizeFound&&b.size),O=u[0]._autoBin={};if(g=O[b.dirs[0]]={},C&&(b.size||(P.start=k(o.tickIncrement(w(P.start),P.size,!0,p))),void 0===b.end&&(P.end=k(o.tickIncrement(w(P.end),P.size,!1,p)))),_&&!a.traceIs(e,\"2dMap\")&&0===P._dataSpan&&\"category\"!==r.type&&\"multicategory\"!==r.type){if(l)return[P,d,!0];P=function(t,e,r,n,a){var o,s,l,c=t._fullLayout,u=function(t,e){for(var r=e.xaxis,n=e.yaxis,i=e.orientation,a=[],o=t._fullData,s=0;s<o.length;s++){var l=o[s];\"histogram\"===l.type&&!0===l.visible&&l.orientation===i&&l.xaxis===r&&l.yaxis===n&&a.push(l)}return a}(t,e),h=!1,p=1/0,d=[e];for(o=0;o<u.length;o++)if((s=u[o])===e)h=!0;else if(h){var g=f(t,s,r,n,!0),v=g[0],m=g[2];s[\"_\"+n+\"autoBinFinished\"]=1,s[\"_\"+n+\"pos0\"]=g[1],m?d.push(s):p=Math.min(p,v.size)}else l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]],p=Math.min(p,l.size||s[a].size);var y=new Array(d.length);for(o=0;o<d.length;o++)for(var x=d[o][\"_\"+n+\"pos0\"],b=0;b<x.length;b++)if(void 0!==x[b]){y[o]=x[b];break}isFinite(p)||(p=i.distinctVals(y).minDiff);for(o=0;o<d.length;o++){var _=(s=d[o])[n+\"calendar\"],w={start:r.c2r(y[o]-p/2,0,_),end:r.c2r(y[o]+p/2,0,_),size:p};s._input[a]=s[a]=w,(l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]])&&i.extendFlat(l,w)}return e[a]}(t,e,r,s,m)}(v=h.cumulative||{}).enabled&&\"include\"!==v.currentbin&&(\"decreasing\"===v.direction?P.start=k(o.tickIncrement(w(P.start),P.size,!0,p)):P.end=k(o.tickIncrement(w(P.end),P.size,!1,p))),b.size=P.size,b.sizeFound||(g.size=P.size,i.nestedProperty(u[0],m+\".size\").set(P.size)),A(\"start\",b,P),A(\"end\",b,P)}d=e[\"_\"+s+\"pos0\"],delete e[\"_\"+s+\"pos0\"];var z=e._input[m]||{},I=i.extendFlat({},b),D=b.start,R=r.r2l(z.start),F=void 0!==R;if((b.startFound||F)&&R!==r.r2l(D)){var B=F?R:i.aggNums(Math.min,null,d),N={type:\"category\"===r.type||\"multicategory\"===r.type?\"linear\":r.type,r2l:r.r2l,dtick:b.size,tick0:D,calendar:p,range:[B,o.tickIncrement(B,b.size,!1,p)].map(r.l2r)},j=o.tickFirst(N);j>r.r2l(B)&&(j=o.tickIncrement(j,b.size,!0,p)),I.start=r.l2r(j),F||i.nestedProperty(e,m+\".start\").set(I.start)}var U=b.end,V=r.r2l(z.end),q=void 0!==V;if((b.endFound||q)&&V!==r.r2l(U)){var H=q?V:i.aggNums(Math.max,null,d);I.end=r.l2r(H),q||i.nestedProperty(e,m+\".start\").set(I.end)}var G=\"autobin\"+s;return!1===e._input[G]&&(e._input[m]=i.extendFlat({},e[m]||{}),delete e._input[G],delete e[G]),[I,d]}e.exports={calc:function(t,e){var r,a,p,d,g=[],v=[],m=o.getFromId(t,\"h\"===e.orientation?e.yaxis:e.xaxis),y=\"h\"===e.orientation?\"y\":\"x\",x={x:\"y\",y:\"x\"}[y],b=e[y+\"calendar\"],_=e.cumulative,w=f(t,e,m,y),k=w[0],T=w[1],A=\"string\"==typeof k.size,M=[],S=A?M:k,E=[],C=[],L=[],P=0,O=e.histnorm,z=e.histfunc,I=-1!==O.indexOf(\"density\");_.enabled&&I&&(O=O.replace(/ ?density$/,\"\"),I=!1);var D,R=\"max\"===z||\"min\"===z?null:0,F=l.count,B=c[O],N=!1,j=function(t){return m.r2c(t,0,b)};for(i.isArrayOrTypedArray(e[x])&&\"count\"!==z&&(D=e[x],N=\"avg\"===z,F=l[z]),r=j(k.start),p=j(k.end)+(r-o.tickIncrement(r,k.size,!1,b))/1e6;r<p&&g.length<1e6&&(a=o.tickIncrement(r,k.size,!1,b),g.push((r+a)/2),v.push(R),L.push([]),M.push(r),I&&E.push(1/(a-r)),N&&C.push(0),!(a<=r));)r=a;M.push(r),A||\"date\"!==m.type||(S={start:j(S.start),end:j(S.end),size:S.size});var U,V=v.length,q=!0,H=1/0,G=1/0,Y={};for(r=0;r<T.length;r++){var W=T[r];(d=i.findBin(W,S))>=0&&d<V&&(P+=F(d,r,v,D,C),q&&L[d].length&&W!==T[L[d][0]]&&(q=!1),L[d].push(r),Y[r]=d,H=Math.min(H,W-M[d]),G=Math.min(G,M[d+1]-W))}q||(U=h(H,G,M,m,b)),N&&(P=u(v,C)),B&&B(v,P,E),_.enabled&&function(t,e,r){var n,i,a;function o(e){a=t[e],t[e]/=2}function s(e){i=t[e],t[e]=a+i/2,a+=i}if(\"half\"===r)if(\"increasing\"===e)for(o(0),n=1;n<t.length;n++)s(n);else for(o(t.length-1),n=t.length-2;n>=0;n--)s(n);else if(\"increasing\"===e){for(n=1;n<t.length;n++)t[n]+=t[n-1];\"exclude\"===r&&(t.unshift(0),t.pop())}else{for(n=t.length-2;n>=0;n--)t[n]+=t[n+1];\"exclude\"===r&&(t.push(0),t.shift())}}(v,_.direction,_.currentbin);var X=Math.min(g.length,v.length),Z=[],J=0,K=X-1;for(r=0;r<X;r++)if(v[r]){J=r;break}for(r=X-1;r>=J;r--)if(v[r]){K=r;break}for(r=J;r<=K;r++)if(n(g[r])&&n(v[r])){var $={p:g[r],s:v[r],b:0};_.enabled||($.pts=L[r],q?$.ph0=$.ph1=L[r].length?T[L[r][0]]:g[r]:($.ph0=U(M[r]),$.ph1=U(M[r+1],!0))),Z.push($)}return 1===Z.length&&(Z[0].width1=o.tickIncrement(Z[0].p,k.size,!1,b)-Z[0].p),s(Z,e),i.isArrayOrTypedArray(e.selectedpoints)&&i.tagSelected(Z,e,Y),Z},calcAllAutoBins:f}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../bar/arrays_to_calcdata\":856,\"./average\":1020,\"./bin_functions\":1022,\"./bin_label_vals\":1023,\"./norm_functions\":1031,\"fast-isnumeric\":225}],1025:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"binNumber\"]}},{}],1026:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../../registry\").traceIs,o=t(\"../bar/defaults\").handleGroupingDefaults,s=n.nestedProperty,l=i.getAxisGroup,c=[{aStr:{x:\"xbins.start\",y:\"ybins.start\"},name:\"start\"},{aStr:{x:\"xbins.end\",y:\"ybins.end\"},name:\"end\"},{aStr:{x:\"xbins.size\",y:\"ybins.size\"},name:\"size\"},{aStr:{x:\"nbinsx\",y:\"nbinsy\"},name:\"nbins\"}],u=[\"x\",\"y\"];e.exports=function(t,e){var r,h,f,p,d,g,v,m=e._histogramBinOpts={},y=[],x={},b=[];function _(t,e){return n.coerce(r._input,r,r._module.attributes,t,e)}function w(t){return\"v\"===t.orientation?\"x\":\"y\"}function k(t,r,a){var o=t.uid+\"__\"+a;r||(r=o);var s=function(t,r){return i.getFromTrace({_fullLayout:e},t,r).type}(t,a),l=t[a+\"calendar\"],c=m[r],u=!0;c&&(s===c.axType&&l===c.calendar?(u=!1,c.traces.push(t),c.dirs.push(a)):(r=o,s!==c.axType&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set on a\",\"type:\"+s,\"axis\",\"with bins on\",\"type:\"+c.axType,\"axis.\"].join(\" \")),l!==c.calendar&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set with a\",l,\"calendar\",\"with bins\",c.calendar?\"on a \"+c.calendar+\" calendar\":\"w/o a set calendar\"].join(\" \")))),u&&(m[r]={traces:[t],dirs:[a],axType:s,calendar:t[a+\"calendar\"]||\"\"}),t[\"_\"+a+\"bingroup\"]=r}for(d=0;d<t.length;d++)r=t[d],a(r,\"histogram\")&&(y.push(r),delete r._xautoBinFinished,delete r._yautoBinFinished,a(r,\"2dMap\")||o(r._input,r,e,_));var T=e._alignmentOpts||{};for(d=0;d<y.length;d++){if(r=y[d],f=\"\",!a(r,\"2dMap\")){if(p=w(r),\"group\"===e.barmode&&r.alignmentgroup){var A=r[p+\"axis\"],M=l(e,A)+r.orientation;(T[M]||{})[r.alignmentgroup]&&(f=M)}f||\"overlay\"===e.barmode||(f=l(e,r.xaxis)+l(e,r.yaxis)+w(r))}f?(x[f]||(x[f]=[]),x[f].push(r)):b.push(r)}for(f in x)if(1!==(h=x[f]).length){var S=!1;for(d=0;d<h.length;d++){r=h[d],S=_(\"bingroup\");break}for(f=S||f,d=0;d<h.length;d++){var E=(r=h[d])._input.bingroup;E&&E!==f&&n.warn([\"Trace\",r.index,\"must match\",\"within bingroup\",f+\".\",\"Ignoring its bingroup:\",E,\"setting.\"].join(\" \")),r.bingroup=f,k(r,f,w(r))}}else b.push(h[0]);for(d=0;d<b.length;d++){r=b[d];var C=_(\"bingroup\");if(a(r,\"2dMap\"))for(v=0;v<2;v++){var L=_((p=u[v])+\"bingroup\",C?C+\"__\"+p:null);k(r,L,p)}else k(r,C,w(r))}for(f in m){var P=m[f];for(h=P.traces,g=0;g<c.length;g++){var O,z,I=c[g],D=I.name;if(\"nbins\"!==D||!P.sizeFound){for(d=0;d<h.length;d++){if(r=h[d],p=P.dirs[d],O=I.aStr[p],void 0!==s(r._input,O).get()){P[D]=_(O),P[D+\"Found\"]=!0;break}(z=(r._autoBin||{})[p]||{})[D]&&s(r,O).set(z[D])}if(\"start\"===D||\"end\"===D)for(;d<h.length;d++)(r=h[d])[\"_\"+p+\"bingroup\"]&&_(O,(z=(r._autoBin||{})[p]||{})[D]);\"nbins\"!==D||P.sizeFound||P.nbinsFound||(r=h[0],P[D]=_(O))}}}}},{\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../bar/defaults\":861}],1027:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../bar/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,n){return i.coerce(t,e,s,r,n)}var u=c(\"x\"),h=c(\"y\");c(\"cumulative.enabled\")&&(c(\"cumulative.direction\"),c(\"cumulative.currentbin\")),c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\");var f=c(\"orientation\",h&&!u?\"h\":\"v\"),p=\"v\"===f?\"x\":\"y\",d=\"v\"===f?\"y\":\"x\",g=u&&h?Math.min(i.minRowLength(u)&&i.minRowLength(h)):i.minRowLength(e[p]||[]);if(g){e._length=g,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],l),e[d]&&c(\"histfunc\"),c(\"histnorm\"),c(\"autobin\"+p),o(t,e,c,r,l),i.coerceSelectionMarkerOpacity(e,c);var v=(e.marker.line||{}).color,m=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");m(t,e,v||a.defaultLine,{axis:\"y\"}),m(t,e,v||a.defaultLine,{axis:\"x\",inherit:\"y\"})}else e.visible=!1}},{\"../../components/color\":593,\"../../lib\":719,\"../../registry\":847,\"../bar/style_defaults\":871,\"./attributes\":1019}],1028:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"zLabelVal\"in e&&(t.z=e.zLabelVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),!(r.cumulative||{}).enabled){var a,o=Array.isArray(i)?n[0].pts[i[0]][i[1]]:n[i].pts;if(t.pointNumbers=o,t.binNumber=t.pointNumber,delete t.pointNumber,delete t.pointIndex,r._indexToPoints){a=[];for(var s=0;s<o.length;s++)a=a.concat(r._indexToPoints[o[s]])}else a=o;t.pointIndices=a}return t}},{}],1029:[function(t,e,r){\"use strict\";var n=t(\"../bar/hover\").hoverPoints,i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o){var s=(t=o[0]).cd[t.index],l=t.cd[0].trace;if(!l.cumulative.enabled){var c=\"h\"===l.orientation?\"y\":\"x\";t[c+\"Label\"]=i(t[c+\"a\"],s.ph0,s.ph1)}return l.hovermplate&&(t.hovertemplate=l.hovertemplate),o}}},{\"../../plots/cartesian/axes\":767,\"../bar/hover\":863}],1030:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"../bar/layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),supplyLayoutDefaults:t(\"../bar/layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"../bar/cross_trace_calc\").crossTraceCalc,plot:t(\"../bar/plot\").plot,layerName:\"barlayer\",style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,colorbar:t(\"../scatter/marker_colorbar\"),hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"histogram\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"histogram\",\"oriented\",\"errorBarsOK\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":778,\"../bar/cross_trace_calc\":860,\"../bar/layout_attributes\":865,\"../bar/layout_defaults\":866,\"../bar/plot\":867,\"../bar/select\":868,\"../bar/style\":870,\"../scatter/marker_colorbar\":1129,\"./attributes\":1019,\"./calc\":1024,\"./cross_trace_defaults\":1026,\"./defaults\":1027,\"./event_data\":1028,\"./hover\":1029}],1031:[function(t,e,r){\"use strict\";e.exports={percent:function(t,e){for(var r=t.length,n=100/e,i=0;i<r;i++)t[i]*=n},probability:function(t,e){for(var r=t.length,n=0;n<r;n++)t[n]/=e},density:function(t,e,r,n){var i=t.length;n=n||1;for(var a=0;a<i;a++)t[a]*=r[a]*n},\"probability density\":function(t,e,r,n){var i=t.length;n&&(e/=n);for(var a=0;a<i;a++)t[a]*=r[a]/e}}},{}],1032:[function(t,e,r){\"use strict\";var n=t(\"../histogram/attributes\"),i=t(\"../histogram/bin_attributes\"),a=t(\"../heatmap/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../lib/extend\").extendFlat;e.exports=l({x:n.x,y:n.y,z:{valType:\"data_array\",editType:\"calc\"},marker:{color:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:i(\"x\"),nbinsy:n.nbinsy,ybins:i(\"y\"),autobinx:n.autobinx,autobiny:n.autobiny,bingroup:l({},n.bingroup,{}),xbingroup:l({},n.bingroup,{}),ybingroup:l({},n.bingroup,{}),xgap:a.xgap,ygap:a.ygap,zsmooth:a.zsmooth,zhoverformat:a.zhoverformat,hovertemplate:o({},{keys:\"z\"})},s(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../heatmap/attributes\":1001,\"../histogram/attributes\":1019,\"../histogram/bin_attributes\":1021}],1033:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../histogram/bin_functions\"),o=t(\"../histogram/norm_functions\"),s=t(\"../histogram/average\"),l=t(\"../histogram/bin_label_vals\"),c=t(\"../histogram/calc\").calcAllAutoBins;function u(t,e,r,n){var i,a=new Array(t);if(n)for(i=0;i<t;i++)a[i]=1/(e[i+1]-e[i]);else{var o=1/r;for(i=0;i<t;i++)a[i]=o}return a}function h(t,e){return{start:t(e.start),end:t(e.end),size:e.size}}function f(t,e,r,n,i,a){var o,s=t.length-1,c=new Array(s),u=l(r,n,t,i,a);for(o=0;o<s;o++){var h=(e||[])[o];c[o]=void 0===h?[u(t[o]),u(t[o+1],!0)]:[h,h]}return c}e.exports=function(t,e){var r,l,p,d,g=i.getFromId(t,e.xaxis),v=i.getFromId(t,e.yaxis),m=e.xcalendar,y=e.ycalendar,x=function(t){return g.r2c(t,0,m)},b=function(t){return v.r2c(t,0,y)},_=c(t,e,g,\"x\"),w=_[0],k=_[1],T=c(t,e,v,\"y\"),A=T[0],M=T[1],S=e._length;k.length>S&&k.splice(S,k.length-S),M.length>S&&M.splice(S,M.length-S);var E=[],C=[],L=[],P=\"string\"==typeof w.size,O=\"string\"==typeof A.size,z=[],I=[],D=P?z:w,R=O?I:A,F=0,B=[],N=[],j=e.histnorm,U=e.histfunc,V=-1!==j.indexOf(\"density\"),q=\"max\"===U||\"min\"===U?null:0,H=a.count,G=o[j],Y=!1,W=[],X=[],Z=\"z\"in e?e.z:\"marker\"in e&&Array.isArray(e.marker.color)?e.marker.color:\"\";Z&&\"count\"!==U&&(Y=\"avg\"===U,H=a[U]);var J=w.size,K=x(w.start),$=x(w.end)+(K-i.tickIncrement(K,J,!1,m))/1e6;for(r=K;r<$;r=i.tickIncrement(r,J,!1,m))C.push(q),z.push(r),Y&&L.push(0);z.push(r);var Q,tt=C.length,et=(r-K)/tt,rt=(Q=K+et/2,g.c2r(Q,0,m)),nt=A.size,it=b(A.start),at=b(A.end)+(it-i.tickIncrement(it,nt,!1,y))/1e6;for(r=it;r<at;r=i.tickIncrement(r,nt,!1,y)){E.push(C.slice()),I.push(r);var ot=new Array(tt);for(l=0;l<tt;l++)ot[l]=[];N.push(ot),Y&&B.push(L.slice())}I.push(r);var st=E.length,lt=(r-it)/st,ct=function(t){return v.c2r(t,0,y)}(it+lt/2);V&&(W=u(C.length,D,et,P),X=u(E.length,R,lt,O)),P||\"date\"!==g.type||(D=h(x,D)),O||\"date\"!==v.type||(R=h(b,R));var ut=!0,ht=!0,ft=new Array(tt),pt=new Array(st),dt=1/0,gt=1/0,vt=1/0,mt=1/0;for(r=0;r<S;r++){var yt=k[r],xt=M[r];p=n.findBin(yt,D),d=n.findBin(xt,R),p>=0&&p<tt&&d>=0&&d<st&&(F+=H(p,r,E[d],Z,B[d]),N[d][p].push(r),ut&&(void 0===ft[p]?ft[p]=yt:ft[p]!==yt&&(ut=!1)),ht&&(void 0===pt[d]?pt[d]=xt:pt[d]!==xt&&(ht=!1)),dt=Math.min(dt,yt-z[p]),gt=Math.min(gt,z[p+1]-yt),vt=Math.min(vt,xt-I[d]),mt=Math.min(mt,I[d+1]-xt))}if(Y)for(d=0;d<st;d++)F+=s(E[d],B[d]);if(G)for(d=0;d<st;d++)G(E[d],F,W,X[d]);return{x:k,xRanges:f(z,ut&&ft,dt,gt,g,m),x0:rt,dx:et,y:M,yRanges:f(I,ht&&pt,vt,mt,v,y),y0:ct,dy:lt,z:E,pts:N}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../histogram/average\":1020,\"../histogram/bin_functions\":1022,\"../histogram/bin_label_vals\":1023,\"../histogram/calc\":1024,\"../histogram/norm_functions\":1031}],1034:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./sample_defaults\"),a=t(\"../heatmap/style_defaults\"),o=t(\"../../components/colorscale/defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,l),o(t,e,l,c,{prefix:\"\",cLetter:\"z\"}),c(\"hovertemplate\"))}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../heatmap/style_defaults\":1014,\"./attributes\":1032,\"./sample_defaults\":1037}],1035:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/hover\"),i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a,o,s){var l=n(t,e,r,a,o,s);if(l){var c=(t=l[0]).index,u=c[0],h=c[1],f=t.cd[0],p=f.xRanges[h],d=f.yRanges[u];return t.xLabel=i(t.xa,p[0],p[1]),t.yLabel=i(t.ya,d[0],d[1]),l}}},{\"../../plots/cartesian/axes\":767,\"../heatmap/hover\":1008}],1036:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../heatmap/calc\"),plot:t(\"../heatmap/plot\"),layerName:\"heatmaplayer\",colorbar:t(\"../heatmap/colorbar\"),style:t(\"../heatmap/style\"),hoverPoints:t(\"./hover\"),eventData:t(\"../histogram/event_data\"),moduleType:\"trace\",name:\"histogram2d\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"histogram\"],meta:{}}},{\"../../plots/cartesian\":778,\"../heatmap/calc\":1002,\"../heatmap/colorbar\":1004,\"../heatmap/plot\":1012,\"../heatmap/style\":1013,\"../histogram/cross_trace_defaults\":1026,\"../histogram/event_data\":1028,\"./attributes\":1032,\"./defaults\":1034,\"./hover\":1035}],1037:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"y\"),l=i.minRowLength(o),c=i.minRowLength(s);l&&c?(e._length=Math.min(l,c),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a),(r(\"z\")||r(\"marker.color\"))&&r(\"histfunc\"),r(\"histnorm\"),r(\"autobinx\"),r(\"autobiny\")):e.visible=!1}},{\"../../lib\":719,\"../../registry\":847}],1038:[function(t,e,r){\"use strict\";var n=t(\"../histogram2d/attributes\"),i=t(\"../contour/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat;e.exports=o({x:n.x,y:n.y,z:n.z,marker:n.marker,histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:n.xbins,nbinsy:n.nbinsy,ybins:n.ybins,autobinx:n.autobinx,autobiny:n.autobiny,bingroup:n.bingroup,xbingroup:n.xbingroup,ybingroup:n.ybingroup,autocontour:i.autocontour,ncontours:i.ncontours,contours:i.contours,line:i.line,zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../contour/attributes\":942,\"../histogram2d/attributes\":1032}],1039:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../histogram2d/sample_defaults\"),a=t(\"../contour/contours_defaults\"),o=t(\"../contour/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,function(r){return n.coerce2(t,e,s,r)}),o(t,e,c,l),c(\"hovertemplate\"))}},{\"../../lib\":719,\"../contour/contours_defaults\":949,\"../contour/style_defaults\":963,\"../histogram2d/sample_defaults\":1037,\"./attributes\":1038}],1040:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../contour/calc\"),plot:t(\"../contour/plot\").plot,layerName:\"contourlayer\",style:t(\"../contour/style\"),colorbar:t(\"../contour/colorbar\"),hoverPoints:t(\"../contour/hover\"),moduleType:\"trace\",name:\"histogram2dcontour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"histogram\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":778,\"../contour/calc\":943,\"../contour/colorbar\":945,\"../contour/hover\":955,\"../contour/plot\":960,\"../contour/style\":962,\"../histogram/cross_trace_defaults\":1026,\"./attributes\":1038,\"./defaults\":1039}],1041:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../lib/extend\").extendDeep,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../components/color/attributes\"),l=t(\"../../plots/domain\").attributes,c=t(\"../../plots/cartesian/layout_attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,h=t(\"../../constants/delta.js\"),f=(t(\"../../constants/docs\").FORMAT_LINK,o({editType:\"plot\",colorEditType:\"plot\"})),p={color:{valType:\"color\",editType:\"plot\"},line:{color:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},width:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"calc\"},thickness:{valType:\"number\",min:0,max:1,dflt:1,editType:\"plot\"},editType:\"calc\"},d={valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},g=u(\"steps\",i({},p,{range:d}));e.exports={mode:{valType:\"flaglist\",editType:\"calc\",flags:[\"number\",\"delta\",\"gauge\"],dflt:\"number\"},value:{valType:\"number\",editType:\"calc\",anim:!0},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},domain:l({name:\"indicator\",trace:!0,editType:\"calc\"}),title:{text:{valType:\"string\",editType:\"plot\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},font:n({},f,{}),editType:\"plot\"},number:{valueformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:n({},f,{}),prefix:{valType:\"string\",dflt:\"\",editType:\"plot\"},suffix:{valType:\"string\",dflt:\"\",editType:\"plot\"},editType:\"plot\"},delta:{reference:{valType:\"number\",editType:\"calc\"},position:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],dflt:\"bottom\",editType:\"plot\"},relative:{valType:\"boolean\",editType:\"plot\",dflt:!1},valueformat:{valType:\"string\",editType:\"plot\"},increasing:{symbol:{valType:\"string\",dflt:h.INCREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:h.INCREASING.COLOR,editType:\"plot\"},editType:\"plot\"},decreasing:{symbol:{valType:\"string\",dflt:h.DECREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:h.DECREASING.COLOR,editType:\"plot\"},editType:\"plot\"},font:n({},f,{}),editType:\"calc\"},gauge:{shape:{valType:\"enumerated\",editType:\"plot\",dflt:\"angular\",values:[\"angular\",\"bullet\"]},bar:i({},p,{color:{dflt:\"green\"}}),bgcolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},axis:a({range:d,visible:n({},c.visible,{dflt:!0}),tickmode:c.tickmode,nticks:c.nticks,tick0:c.tick0,dtick:c.dtick,tickvals:c.tickvals,ticktext:c.ticktext,ticks:n({},c.ticks,{dflt:\"outside\"}),ticklen:c.ticklen,tickwidth:c.tickwidth,tickcolor:c.tickcolor,showticklabels:c.showticklabels,tickfont:o({}),tickangle:c.tickangle,tickformat:c.tickformat,tickformatstops:c.tickformatstops,tickprefix:c.tickprefix,showtickprefix:c.showtickprefix,ticksuffix:c.ticksuffix,showticksuffix:c.showticksuffix,separatethousands:c.separatethousands,exponentformat:c.exponentformat,showexponent:c.showexponent,editType:\"plot\"},\"plot\"),steps:g,threshold:{line:{color:n({},p.line.color,{}),width:n({},p.line.width,{dflt:1}),editType:\"plot\"},thickness:n({},p.thickness,{dflt:.85}),value:{valType:\"number\",editType:\"calc\",dflt:!1},editType:\"plot\"},editType:\"plot\"}}},{\"../../components/color/attributes\":592,\"../../constants/delta.js\":689,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1042:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=r.name=\"indicator\";r.plot=function(t,e,r,o){var s=n.getModule(a),l=i(t.calcdata,s)[0];s.plot(t,l,r,o)},r.clean=function(t,e,r,n){var i=n._has&&n._has(a),o=e._has&&e._has(a);i&&!o&&n._indicatorlayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],1043:[function(t,e,r){\"use strict\";e.exports={calc:function(t,e){var r=[],n=e.value;\"number\"!=typeof e._lastValue&&(e._lastValue=e.value);var i=e._lastValue,a=i;return e._hasDelta&&\"number\"==typeof e.delta.reference&&(a=e.delta.reference),r[0]={y:n,lastY:i,delta:n-a,relativeDelta:(n-a)/a},r}}},{}],1044:[function(t,e,r){\"use strict\";e.exports={defaultNumberFontSize:80,bulletNumberDomainSize:.25,bulletPadding:.025,innerRadius:.75,valueThickness:.5,titlePadding:5,horizontalPadding:10}},{}],1045:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../../plot_api/plot_template\"),s=t(\"../../plots/array_container_defaults\"),l=t(\"./constants.js\"),c=t(\"../../plots/cartesian/tick_value_defaults\"),u=t(\"../../plots/cartesian/tick_mark_defaults\"),h=t(\"../../plots/cartesian/tick_label_defaults\");function f(t,e){function r(r,a){return n.coerce(t,e,i.gauge.steps,r,a)}r(\"color\"),r(\"line.color\"),r(\"line.width\"),r(\"range\"),r(\"thickness\")}e.exports={supplyDefaults:function(t,e,r,p){function d(r,a){return n.coerce(t,e,i,r,a)}a(e,p,d),d(\"mode\"),e._hasNumber=-1!==e.mode.indexOf(\"number\"),e._hasDelta=-1!==e.mode.indexOf(\"delta\"),e._hasGauge=-1!==e.mode.indexOf(\"gauge\");var g=d(\"value\");e._range=[0,\"number\"==typeof g?1.5*g:1];var v,m,y,x,b,_,w=new Array(2);function k(t,e){return n.coerce(y,x,i.gauge,t,e)}function T(t,e){return n.coerce(b,_,i.gauge.axis,t,e)}if(e._hasNumber&&(d(\"number.valueformat\"),d(\"number.font.color\",p.font.color),d(\"number.font.family\",p.font.family),d(\"number.font.size\"),void 0===e.number.font.size&&(e.number.font.size=l.defaultNumberFontSize,w[0]=!0),d(\"number.prefix\"),d(\"number.suffix\"),v=e.number.font.size),e._hasDelta&&(d(\"delta.font.color\",p.font.color),d(\"delta.font.family\",p.font.family),d(\"delta.font.size\"),void 0===e.delta.font.size&&(e.delta.font.size=(e._hasNumber?.5:1)*(v||l.defaultNumberFontSize),w[1]=!0),d(\"delta.reference\",e.value),d(\"delta.relative\"),d(\"delta.valueformat\",e.delta.relative?\"2%\":\"\"),d(\"delta.increasing.symbol\"),d(\"delta.increasing.color\"),d(\"delta.decreasing.symbol\"),d(\"delta.decreasing.color\"),d(\"delta.position\"),m=e.delta.font.size),e._scaleNumbers=(!e._hasNumber||w[0])&&(!e._hasDelta||w[1])||!1,d(\"title.font.color\",p.font.color),d(\"title.font.family\",p.font.family),d(\"title.font.size\",.25*(v||m||l.defaultNumberFontSize)),d(\"title.text\"),e._hasGauge){(y=t.gauge)||(y={}),x=o.newContainer(e,\"gauge\"),k(\"shape\"),(e._isBullet=\"bullet\"===e.gauge.shape)||d(\"title.align\",\"center\"),(e._isAngular=\"angular\"===e.gauge.shape)||d(\"align\",\"center\"),k(\"bgcolor\",p.paper_bgcolor),k(\"borderwidth\"),k(\"bordercolor\"),k(\"bar.color\"),k(\"bar.line.color\"),k(\"bar.line.width\"),k(\"bar.thickness\",l.valueThickness*(\"bullet\"===e.gauge.shape?.5:1)),s(y,x,{name:\"steps\",handleItemDefaults:f}),k(\"threshold.value\"),k(\"threshold.thickness\"),k(\"threshold.line.width\"),k(\"threshold.line.color\"),b={},y&&(b=y.axis||{}),_=o.newContainer(x,\"axis\"),T(\"visible\"),e._range=T(\"range\",e._range);var A={outerTicks:!0};c(b,_,T,\"linear\"),h(b,_,T,\"linear\",A),u(b,_,T,A)}else d(\"title.align\",\"center\"),d(\"align\",\"center\"),e._isAngular=e._isBullet=!1;e._length=null}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/tick_label_defaults\":786,\"../../plots/cartesian/tick_mark_defaults\":787,\"../../plots/cartesian/tick_value_defaults\":788,\"../../plots/domain\":792,\"./attributes\":1041,\"./constants.js\":1044}],1046:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"indicator\",basePlotModule:t(\"./base_plot\"),categories:[\"svg\",\"noOpacity\",\"noHover\"],animatable:!0,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\").calc,plot:t(\"./plot\"),meta:{}}},{\"./attributes\":1041,\"./base_plot\":1042,\"./calc\":1043,\"./defaults\":1045,\"./plot\":1047}],1047:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=i.rad2deg,o=t(\"../../constants/alignment\").MID_SHIFT,s=t(\"../../components/drawing\"),l=t(\"./constants\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"../../plots/cartesian/axes\"),h=t(\"../../plots/cartesian/axis_defaults\"),f=t(\"../../plots/cartesian/position_defaults\"),p=t(\"../../plots/cartesian/layout_attributes\"),d=t(\"../../components/color\"),g={left:\"start\",center:\"middle\",right:\"end\"},v={left:0,center:.5,right:1},m=/[yzafpn\\xb5mkMGTPEZY]/;function y(t){return t&&t.duration>0}function x(t){t.each(function(t){d.stroke(n.select(this),t.line.color)}).each(function(t){d.fill(n.select(this),t.color)}).style(\"stroke-width\",function(t){return t.line.width})}function b(t,e,r){var n=t._fullLayout,a=i.extendFlat({type:\"linear\",ticks:\"outside\",range:r,showline:!0},e),o={type:\"linear\",_id:\"x\"+e._id},s={letter:\"x\",font:n.font,noHover:!0,noTickson:!0};function l(t,e){return i.coerce(a,o,p,t,e)}return h(a,o,l,s,n),f(a,o,l,s),o}function _(t,e){return\"translate(\"+t+\",\"+e+\")\"}function w(t,e,r){return[Math.min(e/t.width,r/t.height),t,e+\"x\"+r]}function k(t,e,r,i){var a=document.createElementNS(\"http://www.w3.org/2000/svg\",\"text\"),o=n.select(a);return o.text(t).attr(\"x\",0).attr(\"y\",0).attr(\"text-anchor\",r).attr(\"data-unformatted\",t).call(c.convertToTspans,i).call(s.font,e),s.bBox(o.node())}function T(t,e,r,n,a,o){var s=\"_cache\"+e;t[s]&&t[s].key===a||(t[s]={key:a,value:r});var l=i.aggNums(o,null,[t[s].value,n],2);return t[s].value=l,l}e.exports=function(t,e,r,h){var f,p=t._fullLayout;y(r)&&h&&(f=h()),i.makeTraceGroups(p._indicatorlayer,e,\"trace\").each(function(e){var h,A,M,S,E,C=e[0].trace,L=n.select(this),P=C._hasGauge,O=C._isAngular,z=C._isBullet,I=C.domain,D={w:p._size.w*(I.x[1]-I.x[0]),h:p._size.h*(I.y[1]-I.y[0]),l:p._size.l+p._size.w*I.x[0],r:p._size.r+p._size.w*(1-I.x[1]),t:p._size.t+p._size.h*(1-I.y[1]),b:p._size.b+p._size.h*I.y[0]},R=D.l+D.w/2,F=D.t+D.h/2,B=Math.min(D.w/2,D.h),N=l.innerRadius*B,j=C.align||\"center\";if(A=F,P){if(O&&(h=R,A=F+B/2,M=function(t){return e=t,r=.9*N,n=Math.sqrt(e.width/2*(e.width/2)+e.height*e.height),[r/n,e,r];var e,r,n}),z){var U=l.bulletPadding,V=1-l.bulletNumberDomainSize+U;h=D.l+(V+(1-V)*v[j])*D.w,M=function(t){return w(t,(l.bulletNumberDomainSize-U)*D.w,D.h)}}}else h=D.l+v[j]*D.w,M=function(t){return w(t,D.w,D.h)};!function(t,e,r,a){var o,l,h,f=r[0].trace,p=a.numbersX,x=a.numbersY,w=f.align||\"center\",A=g[w],M=a.transitionOpts,S=a.onComplete,E=i.ensureSingle(e,\"g\",\"numbers\"),C=[];f._hasNumber&&C.push(\"number\");f._hasDelta&&(C.push(\"delta\"),\"left\"===f.delta.position&&C.reverse());var L=E.selectAll(\"text\").data(C);function P(e,r,n,i){if(!e.match(\"s\")||n>=0==i>=0||r(n).slice(-1).match(m)||r(i).slice(-1).match(m))return r;var a=e.slice().replace(\"s\",\"f\").replace(/\\d+/,function(t){return parseInt(t)-1}),o=b(t,{tickformat:a});return function(t){return Math.abs(t)<1?u.tickText(o,t).text:r(t)}}L.enter().append(\"text\"),L.attr(\"text-anchor\",function(){return A}).attr(\"class\",function(t){return t}).attr(\"x\",null).attr(\"y\",null).attr(\"dx\",null).attr(\"dy\",null),L.exit().remove();var O,z=f.mode+f.align;f._hasDelta&&(O=function(){var e=b(t,{tickformat:f.delta.valueformat},f._range);e.setScale(),u.calcTicks(e);var i=function(t){return u.tickText(e,t).text},a=function(t){var e=f.delta.relative?t.relativeDelta:t.delta;return e},o=function(t,e){return 0===t||\"number\"!=typeof t||isNaN(t)?\"-\":(t>0?f.delta.increasing.symbol:f.delta.decreasing.symbol)+e(t)},h=function(t){return t.delta>=0?f.delta.increasing.color:f.delta.decreasing.color};void 0===f._deltaLastValue&&(f._deltaLastValue=a(r[0]));var p=E.select(\"text.delta\");function g(){p.text(o(a(r[0]),i)).call(d.fill,h(r[0])).call(c.convertToTspans,t)}p.call(s.font,f.delta.font).call(d.fill,h({delta:f._deltaLastValue})),y(M)?p.transition().duration(M.duration).ease(M.easing).tween(\"text\",function(){var t=n.select(this),e=a(r[0]),s=f._deltaLastValue,l=P(f.delta.valueformat,i,s,e),c=n.interpolateNumber(s,e);return f._deltaLastValue=e,function(e){t.text(o(c(e),l)),t.call(d.fill,h({delta:c(e)}))}}).each(\"end\",function(){g(),S&&S()}).each(\"interrupt\",function(){g(),S&&S()}):g();return l=k(o(a(r[0]),i),f.delta.font,A,t),p}(),z+=f.delta.position+f.delta.font.size+f.delta.font.family+f.delta.valueformat,z+=f.delta.increasing.symbol+f.delta.decreasing.symbol,h=l);f._hasNumber&&(!function(){var e=b(t,{tickformat:f.number.valueformat},f._range);e.setScale(),u.calcTicks(e);var i=function(t){return u.tickText(e,t).text},a=f.number.suffix,l=f.number.prefix,h=E.select(\"text.number\");function p(){var e=\"number\"==typeof r[0].y?l+i(r[0].y)+a:\"-\";h.text(e).call(s.font,f.number.font).call(c.convertToTspans,t)}y(M)?h.transition().duration(M.duration).ease(M.easing).each(\"end\",function(){p(),S&&S()}).each(\"interrupt\",function(){p(),S&&S()}).attrTween(\"text\",function(){var t=n.select(this),e=n.interpolateNumber(r[0].lastY,r[0].y);f._lastValue=r[0].y;var o=P(f.number.valueformat,i,r[0].lastY,r[0].y);return function(r){t.text(l+o(e(r))+a)}}):p();o=k(l+i(r[0].y)+a,f.number.font,A,t)}(),z+=f.number.font.size+f.number.font.family+f.number.valueformat+f.number.suffix+f.number.prefix,h=o);if(f._hasDelta&&f._hasNumber){var I,D,R=[(o.left+o.right)/2,(o.top+o.bottom)/2],F=[(l.left+l.right)/2,(l.top+l.bottom)/2],B=.75*f.delta.font.size;\"left\"===f.delta.position&&(I=T(f,\"deltaPos\",0,-1*(o.width*v[f.align]+l.width*(1-v[f.align])+B),z,Math.min),D=R[1]-F[1],h={width:o.width+l.width+B,height:Math.max(o.height,l.height),left:l.left+I,right:o.right,top:Math.min(o.top,l.top+D),bottom:Math.max(o.bottom,l.bottom+D)}),\"right\"===f.delta.position&&(I=T(f,\"deltaPos\",0,o.width*(1-v[f.align])+l.width*v[f.align]+B,z,Math.max),D=R[1]-F[1],h={width:o.width+l.width+B,height:Math.max(o.height,l.height),left:o.left,right:l.right+I,top:Math.min(o.top,l.top+D),bottom:Math.max(o.bottom,l.bottom+D)}),\"bottom\"===f.delta.position&&(I=null,D=l.height,h={width:Math.max(o.width,l.width),height:o.height+l.height,left:Math.min(o.left,l.left),right:Math.max(o.right,l.right),top:o.bottom-o.height,bottom:o.bottom+l.height}),\"top\"===f.delta.position&&(I=null,D=o.top,h={width:Math.max(o.width,l.width),height:o.height+l.height,left:Math.min(o.left,l.left),right:Math.max(o.right,l.right),top:o.bottom-o.height-l.height,bottom:o.bottom}),O.attr({dx:I,dy:D})}(f._hasNumber||f._hasDelta)&&E.attr(\"transform\",function(){var t=a.numbersScaler(h);z+=t[2];var e,r=T(f,\"numbersScale\",1,t[0],z,Math.min);f._scaleNumbers||(r=1),e=f._isAngular?x-r*h.bottom:x-r*(h.top+h.bottom)/2,f._numbersTop=r*h.top+e;var n=h[w];\"center\"===w&&(n=(h.left+h.right)/2);var i=p-r*n;return _(i=T(f,\"numbersTranslate\",0,i,z,Math.max),e)+\" scale(\"+r+\")\"})}(t,L,e,{numbersX:h,numbersY:A,numbersScaler:M,transitionOpts:r,onComplete:f}),P&&(S={range:C.gauge.axis.range,color:C.gauge.bgcolor,line:{color:C.gauge.bordercolor,width:0},thickness:1},E={range:C.gauge.axis.range,color:\"rgba(0, 0, 0, 0)\",line:{color:C.gauge.bordercolor,width:C.gauge.borderwidth},thickness:1});var q=L.selectAll(\"g.angular\").data(O?e:[]);q.exit().remove();var H=L.selectAll(\"g.angularaxis\").data(O?e:[]);H.exit().remove(),O&&function(t,e,r,i){var s,l,c,h,f=r[0].trace,p=i.size,d=i.radius,g=i.innerRadius,v=i.gaugeBg,m=i.gaugeOutline,w=[p.l+p.w/2,p.t+p.h/2+d/2],k=i.gauge,T=i.layer,A=i.transitionOpts,M=i.onComplete,S=Math.PI/2;function E(t){var e=f.gauge.axis.range[0],r=f.gauge.axis.range[1],n=(t-e)/(r-e)*Math.PI-S;return n<-S?-S:n>S?S:n}function C(t){return n.svg.arc().innerRadius((g+d)/2-t/2*(d-g)).outerRadius((g+d)/2+t/2*(d-g)).startAngle(-S)}function L(t){t.attr(\"d\",function(t){return C(t.thickness).startAngle(E(t.range[0])).endAngle(E(t.range[1]))()})}k.enter().append(\"g\").classed(\"angular\",!0),k.attr(\"transform\",_(w[0],w[1])),T.enter().append(\"g\").classed(\"angularaxis\",!0).classed(\"crisp\",!0),T.selectAll(\"g.xangularaxistick,path,text\").remove(),(s=b(t,f.gauge.axis)).type=\"linear\",s.range=f.gauge.axis.range,s._id=\"xangularaxis\",s.setScale();var P=function(t){return(s.range[0]-t.x)/(s.range[1]-s.range[0])*Math.PI+Math.PI},O={},z=u.makeLabelFns(s,0).labelStandoff;O.xFn=function(t){var e=P(t);return Math.cos(e)*z},O.yFn=function(t){var e=P(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(z+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*o)},O.anchorFn=function(t){var e=P(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},O.heightFn=function(t,e,r){var n=P(t);return-.5*(1+Math.sin(n))*r};var I=function(t){return _(w[0]+d*Math.cos(t),w[1]-d*Math.sin(t))};c=function(t){return I(P(t))};if(l=u.calcTicks(s),h=u.getTickSigns(s)[2],s.visible){h=\"inside\"===s.ticks?-1:1;var D=(s.linewidth||1)/2;u.drawTicks(t,s,{vals:l,layer:T,path:\"M\"+h*D+\",0h\"+h*s.ticklen,transFn:function(t){var e=P(t);return I(e)+\"rotate(\"+-a(e)+\")\"}}),u.drawLabels(t,s,{vals:l,layer:T,transFn:c,labelFns:O})}var R=[v].concat(f.gauge.steps),F=k.selectAll(\"g.bg-arc\").data(R);F.enter().append(\"g\").classed(\"bg-arc\",!0).append(\"path\"),F.select(\"path\").call(L).call(x),F.exit().remove();var B=C(f.gauge.bar.thickness),N=k.selectAll(\"g.value-arc\").data([f.gauge.bar]);N.enter().append(\"g\").classed(\"value-arc\",!0).append(\"path\");var j=N.select(\"path\");y(A)?(j.transition().duration(A.duration).ease(A.easing).each(\"end\",function(){M&&M()}).each(\"interrupt\",function(){M&&M()}).attrTween(\"d\",(U=B,V=E(r[0].lastY),q=E(r[0].y),function(){var t=n.interpolate(V,q);return function(e){return U.endAngle(t(e))()}})),f._lastValue=r[0].y):j.attr(\"d\",\"number\"==typeof r[0].y?B.endAngle(E(r[0].y)):\"M0,0Z\");var U,V,q;j.call(x),N.exit().remove(),R=[];var H=f.gauge.threshold.value;H&&R.push({range:[H,H],color:f.gauge.threshold.color,line:{color:f.gauge.threshold.line.color,width:f.gauge.threshold.line.width},thickness:f.gauge.threshold.thickness});var G=k.selectAll(\"g.threshold-arc\").data(R);G.enter().append(\"g\").classed(\"threshold-arc\",!0).append(\"path\"),G.select(\"path\").call(L).call(x),G.exit().remove();var Y=k.selectAll(\"g.gauge-outline\").data([m]);Y.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"path\"),Y.select(\"path\").call(L).call(x),Y.exit().remove()}(t,0,e,{radius:B,innerRadius:N,gauge:q,layer:H,size:D,gaugeBg:S,gaugeOutline:E,transitionOpts:r,onComplete:f});var G=L.selectAll(\"g.bullet\").data(z?e:[]);G.exit().remove();var Y=L.selectAll(\"g.bulletaxis\").data(z?e:[]);Y.exit().remove(),z&&function(t,e,r,n){var i,a,o,s,c,h=r[0].trace,f=n.gauge,p=n.layer,g=n.gaugeBg,v=n.gaugeOutline,m=n.size,_=h.domain,w=n.transitionOpts,k=n.onComplete;f.enter().append(\"g\").classed(\"bullet\",!0),f.attr(\"transform\",\"translate(\"+m.l+\", \"+m.t+\")\"),p.enter().append(\"g\").classed(\"bulletaxis\",!0).classed(\"crisp\",!0),p.selectAll(\"g.xbulletaxistick,path,text\").remove();var T=m.h,A=h.gauge.bar.thickness*T,M=_.x[0],S=_.x[0]+(_.x[1]-_.x[0])*(h._hasNumber||h._hasDelta?1-l.bulletNumberDomainSize:1);(i=b(t,h.gauge.axis))._id=\"xbulletaxis\",i.domain=[M,S],i.setScale(),a=u.calcTicks(i),o=u.makeTransFn(i),s=u.getTickSigns(i)[2],c=m.t+m.h,i.visible&&(u.drawTicks(t,i,{vals:\"inside\"===i.ticks?u.clipEnds(i,a):a,layer:p,path:u.makeTickPath(i,c,s),transFn:o}),u.drawLabels(t,i,{vals:a,layer:p,transFn:o,labelFns:u.makeLabelFns(i,c)}));function E(t){t.attr(\"width\",function(t){return Math.max(0,i.c2p(t.range[1])-i.c2p(t.range[0]))}).attr(\"x\",function(t){return i.c2p(t.range[0])}).attr(\"y\",function(t){return.5*(1-t.thickness)*T}).attr(\"height\",function(t){return t.thickness*T})}var C=[g].concat(h.gauge.steps),L=f.selectAll(\"g.bg-bullet\").data(C);L.enter().append(\"g\").classed(\"bg-bullet\",!0).append(\"rect\"),L.select(\"rect\").call(E).call(x),L.exit().remove();var P=f.selectAll(\"g.value-bullet\").data([h.gauge.bar]);P.enter().append(\"g\").classed(\"value-bullet\",!0).append(\"rect\"),P.select(\"rect\").attr(\"height\",A).attr(\"y\",(T-A)/2).call(x),y(w)?P.select(\"rect\").transition().duration(w.duration).ease(w.easing).each(\"end\",function(){k&&k()}).each(\"interrupt\",function(){k&&k()}).attr(\"width\",Math.max(0,i.c2p(Math.min(h.gauge.axis.range[1],r[0].y)))):P.select(\"rect\").attr(\"width\",\"number\"==typeof r[0].y?Math.max(0,i.c2p(Math.min(h.gauge.axis.range[1],r[0].y))):0);P.exit().remove();var O=r.filter(function(){return h.gauge.threshold.value}),z=f.selectAll(\"g.threshold-bullet\").data(O);z.enter().append(\"g\").classed(\"threshold-bullet\",!0).append(\"line\"),z.select(\"line\").attr(\"x1\",i.c2p(h.gauge.threshold.value)).attr(\"x2\",i.c2p(h.gauge.threshold.value)).attr(\"y1\",(1-h.gauge.threshold.thickness)/2*T).attr(\"y2\",(1-(1-h.gauge.threshold.thickness)/2)*T).call(d.stroke,h.gauge.threshold.line.color).style(\"stroke-width\",h.gauge.threshold.line.width),z.exit().remove();var I=f.selectAll(\"g.gauge-outline\").data([v]);I.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"rect\"),I.select(\"rect\").call(E).call(x),I.exit().remove()}(t,0,e,{gauge:G,layer:Y,size:D,gaugeBg:S,gaugeOutline:E,transitionOpts:r,onComplete:f});var W=L.selectAll(\"text.title\").data(e);W.exit().remove(),W.enter().append(\"text\").classed(\"title\",!0),W.attr(\"text-anchor\",function(){return z?g.right:g[C.title.align]}).text(C.title.text).call(s.font,C.title.font).call(c.convertToTspans,t),W.attr(\"transform\",function(){var t,e=D.l+D.w*v[C.title.align],r=l.titlePadding,n=s.bBox(W.node());if(P){if(O)if(C.gauge.axis.visible)t=s.bBox(H.node()).top-r-n.bottom;else t=D.t+D.h/2-B/2-n.bottom-r;z&&(t=A-(n.top+n.bottom)/2,e=D.l-l.bulletPadding*D.w)}else t=C._numbersTop-r-n.bottom;return _(e,t)})})}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_defaults\":769,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/cartesian/position_defaults\":782,\"./constants\":1044,d3:163}],1048:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;var c=e.exports=l(s({x:{valType:\"data_array\"},y:{valType:\"data_array\"},z:{valType:\"data_array\"},value:{valType:\"data_array\"},isomin:{valType:\"number\"},isomax:{valType:\"number\"},surface:{show:{valType:\"boolean\",dflt:!0},count:{valType:\"integer\",dflt:2,min:1},fill:{valType:\"number\",min:0,max:1,dflt:1},pattern:{valType:\"flaglist\",flags:[\"A\",\"B\",\"C\",\"D\",\"E\"],extras:[\"all\",\"odd\",\"even\"],dflt:\"all\"}},spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:.15}},slices:{x:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}}},caps:{x:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}}},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:i()},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:a.opacity,lightposition:a.lightposition,lighting:a.lighting,flatshading:a.flatshading,contour:a.contour,hoverinfo:s({},o.hoverinfo)}),\"calc\",\"nested\");c.flatshading.dflt=!0,c.lighting.facenormalsepsilon.dflt=0,c.x.editType=c.y.editType=c.z.editType=c.value.editType=\"calc+clearAxisTypes\",c.transforms=void 0},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../mesh3d/attributes\":1053}],1049:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e._len=Math.min(e.x.length,e.y.length,e.z.length,e.value.length);for(var r=1/0,i=-1/0,a=e.value.length,o=0;o<a;o++){var s=e.value[o];r=Math.min(r,s),i=Math.max(i,s)}e._minValues=r,e._maxValues=i,e._vMin=void 0===e.isomin||null===e.isomin?r:e.isomin,e._vMax=void 0===e.isomax||null===e.isomin?i:e.isomax,n(t,e,{vals:[e._vMin,e._vMax],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],1050:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib\"),a=t(\"../../lib/gl_format_color\").parseColorScale,o=t(\"../../lib/str2rgbarray\"),s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\");function c(t){return i.distinctVals(t).vals}var u=function(t,e){for(var r=e.length-1;r>0;r--){var n=Math.min(e[r],e[r-1]),i=Math.max(e[r],e[r-1]);if(i>n&&n<t&&t<=i)return{id:r,distRatio:(i-t)/(i-n)}}return{id:0,distRatio:0}};function h(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var f=h.prototype;function p(t){t._i=[],t._j=[],t._k=[];var e,r,n=t.surface.show,i=t.spaceframe.show,a=t.surface.fill,o=t.spaceframe.fill,s=!1,l=!1,h=0,f=c(t.x.slice(0,t._len)),p=c(t.y.slice(0,t._len)),d=c(t.z.slice(0,t._len)),g=f.length,v=p.length,m=d.length;function y(t,e,r){return r+m*e+m*v*t}var x,b,_,w,k,T=t._minValues,A=t._maxValues,M=t._vMin,S=t._vMax;function E(t,e,n){for(var i=w.length,a=r;a<i;a++)if(t===x[a]&&e===b[a]&&n===_[a])return a;return-1}function C(){r=e}function L(){x=[],b=[],_=[],w=[],e=0,C()}function P(t,r,n,i){return x.push(t),b.push(r),_.push(n),w.push(i),++e-1}function O(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=t[i]*(1-r)+r*e[i];return n}function z(t){k=t}function I(t,e){return\"all\"===t||null===t||t.indexOf(e)>-1}function D(t,e){return null===t?e:t}function R(e,r,n){C();var i,a,o,s=[r],l=[n];if(k>=1)s=[r],l=[n];else if(k>0){var c=function(t,e){var r=t[0],n=t[1],i=t[2],a=function(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=(t[i]+e[i]+r[i])/3;return n}(r,n,i),o=Math.sqrt(1-k),s=O(a,r,o),l=O(a,n,o),c=O(a,i,o),u=e[0],h=e[1],f=e[2];return{xyzv:[[r,n,l],[l,s,r],[n,i,c],[c,l,n],[i,r,s],[s,c,i]],abc:[[u,h,-1],[-1,-1,u],[h,f,-1],[-1,-1,h],[f,u,-1],[-1,-1,f]]}}(r,n);s=c.xyzv,l=c.abc}for(var u=0;u<s.length;u++){r=s[u],n=l[u];for(var f=[],p=0;p<3;p++){var d=r[p][0],g=r[p][1],v=r[p][2],m=r[p][3],y=n[p]>-1?n[p]:E(d,g,v);f[p]=y>-1?y:P(d,g,v,D(e,m))}i=f[0],a=f[1],o=f[2],t._i.push(i),t._j.push(a),t._k.push(o),++h}}function F(t,e,r,n){var i=t[3];i<r&&(i=r),i>n&&(i=n);for(var a=(t[3]-i)/(t[3]-e[3]+1e-9),o=[],s=0;s<4;s++)o[s]=(1-a)*t[s]+a*e[s];return o}function B(t,e,r){return t>=e&&t<=r}function N(t){var e=.001*(S-M);return t>=M-e&&t<=S+e}function j(e){for(var r=[],n=0;n<4;n++){var i=e[n];r.push([t.x[i],t.y[i],t.z[i],t.value[i]])}return r}var U=3;function V(t,e,r,n,i,a){a||(a=1),r=[-1,-1,-1];var o=!1,s=[B(e[0][3],n,i),B(e[1][3],n,i),B(e[2][3],n,i)];if(!s[0]&&!s[1]&&!s[2])return!1;var l=function(t,e,r){return N(e[0][3])&&N(e[1][3])&&N(e[2][3])?(R(t,e,r),!0):a<U&&V(t,e,r,M,S,++a)};if(s[0]&&s[1]&&s[2])return l(t,e,r)||o;var c=!1;return[[0,1,2],[2,0,1],[1,2,0]].forEach(function(a){if(s[a[0]]&&s[a[1]]&&!s[a[2]]){var u=e[a[0]],h=e[a[1]],f=e[a[2]],p=F(f,u,n,i),d=F(f,h,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,o=l(t,[u,h,d],[r[a[0]],r[a[1]],-1])||o,c=!0}}),c?o:([[0,1,2],[1,2,0],[2,0,1]].forEach(function(a){if(s[a[0]]&&!s[a[1]]&&!s[a[2]]){var u=e[a[0]],h=e[a[1]],f=e[a[2]],p=F(h,u,n,i),d=F(f,u,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,c=!0}}),o)}function q(t,e,r,n){var i=!1,a=j(e),o=[B(a[0][3],r,n),B(a[1][3],r,n),B(a[2][3],r,n),B(a[3][3],r,n)];if(!(o[0]||o[1]||o[2]||o[3]))return i;if(o[0]&&o[1]&&o[2]&&o[3])return l&&(i=function(t,e,r){var n=function(n,i,a){R(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(3,0,1),n(2,3,0),n(1,2,3)}(t,a,e)||i),i;var s=!1;return[[0,1,2,3],[3,0,1,2],[2,3,0,1],[1,2,3,0]].forEach(function(c){if(o[c[0]]&&o[c[1]]&&o[c[2]]&&!o[c[3]]){var u=a[c[0]],h=a[c[1]],f=a[c[2]],p=a[c[3]];if(l)i=R(t,[u,h,f],[e[c[0]],e[c[1]],e[c[2]]])||i;else{var d=F(p,u,r,n),g=F(p,h,r,n),v=F(p,f,r,n);i=R(null,[d,g,v],[-1,-1,-1])||i}s=!0}}),s?i:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2],[0,2,3,1],[1,3,2,0]].forEach(function(c){if(o[c[0]]&&o[c[1]]&&!o[c[2]]&&!o[c[3]]){var u=a[c[0]],h=a[c[1]],f=a[c[2]],p=a[c[3]],d=F(f,u,r,n),g=F(f,h,r,n),v=F(p,h,r,n),m=F(p,u,r,n);l?(i=R(t,[u,m,d],[e[c[0]],-1,-1])||i,i=R(t,[h,g,v],[e[c[1]],-1,-1])||i):i=function(t,e,r){var n=function(n,i,a){R(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(2,3,0)}(null,[d,g,v,m],[-1,-1,-1,-1])||i,s=!0}}),s?i:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2]].forEach(function(c){if(o[c[0]]&&!o[c[1]]&&!o[c[2]]&&!o[c[3]]){var u=a[c[0]],h=a[c[1]],f=a[c[2]],p=a[c[3]],d=F(h,u,r,n),g=F(f,u,r,n),v=F(p,u,r,n);l?(i=R(t,[u,d,g],[e[c[0]],-1,-1])||i,i=R(t,[u,g,v],[e[c[0]],-1,-1])||i,i=R(t,[u,v,d],[e[c[0]],-1,-1])||i):i=R(null,[d,g,v],[-1,-1,-1])||i,s=!0}}),i))}function H(t,e,r,n,i,a,o,c,u,h,f){var p=!1;return s&&(I(t,\"A\")&&(p=q(null,[e,r,n,a],h,f)||p),I(t,\"B\")&&(p=q(null,[r,n,i,u],h,f)||p),I(t,\"C\")&&(p=q(null,[r,a,o,u],h,f)||p),I(t,\"D\")&&(p=q(null,[n,a,c,u],h,f)||p),I(t,\"E\")&&(p=q(null,[r,n,a,u],h,f)||p)),l&&(p=q(t,[r,n,a,u],h,f)||p),p}function G(t,e,r,n,i,a,o,s){return[!0===s[0]||V(t,j([e,r,n]),[e,r,n],a,o),!0===s[1]||V(t,j([n,i,e]),[n,i,e],a,o)]}function Y(t,e,r,n,i,a,o,s,l){return s?G(t,e,r,i,n,a,o,l):G(t,r,i,n,e,a,o,l)}function W(t,e,r,n,i,a,o){var s,l,c,u,h=!1,f=function(){h=V(t,[s,l,c],[-1,-1,-1],i,a)||h,h=V(t,[c,u,s],[-1,-1,-1],i,a)||h},p=o[0],d=o[1],g=o[2];return p&&(s=O(j([y(e,r-0,n-0)])[0],j([y(e-1,r-0,n-0)])[0],p),l=O(j([y(e,r-0,n-1)])[0],j([y(e-1,r-0,n-1)])[0],p),c=O(j([y(e,r-1,n-1)])[0],j([y(e-1,r-1,n-1)])[0],p),u=O(j([y(e,r-1,n-0)])[0],j([y(e-1,r-1,n-0)])[0],p),f()),d&&(s=O(j([y(e-0,r,n-0)])[0],j([y(e-0,r-1,n-0)])[0],d),l=O(j([y(e-0,r,n-1)])[0],j([y(e-0,r-1,n-1)])[0],d),c=O(j([y(e-1,r,n-1)])[0],j([y(e-1,r-1,n-1)])[0],d),u=O(j([y(e-1,r,n-0)])[0],j([y(e-1,r-1,n-0)])[0],d),f()),g&&(s=O(j([y(e-0,r-0,n)])[0],j([y(e-0,r-0,n-1)])[0],g),l=O(j([y(e-0,r-1,n)])[0],j([y(e-0,r-1,n-1)])[0],g),c=O(j([y(e-1,r-1,n)])[0],j([y(e-1,r-1,n-1)])[0],g),u=O(j([y(e-1,r-0,n)])[0],j([y(e-1,r-0,n-1)])[0],g),f()),h}function X(t,e,r,n,i,a,o,l,c,u,h,f){var p=t;return f?(s&&\"even\"===t&&(p=null),H(p,e,r,n,i,a,o,l,c,u,h)):(s&&\"odd\"===t&&(p=null),H(p,c,l,o,a,i,n,r,e,u,h))}function Z(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<m;c++)for(var u=1;u<v;u++)a.push(Y(t,y(l,u-1,c-1),y(l,u-1,c),y(l,u,c-1),y(l,u,c),r,n,(l+u+c)%2,i&&i[o]?i[o]:[])),o++;return a}function J(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<g;c++)for(var u=1;u<m;u++)a.push(Y(t,y(c-1,l,u-1),y(c,l,u-1),y(c-1,l,u),y(c,l,u),r,n,(c+l+u)%2,i&&i[o]?i[o]:[])),o++;return a}function K(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<v;c++)for(var u=1;u<g;u++)a.push(Y(t,y(u-1,c-1,l),y(u-1,c,l),y(u,c-1,l),y(u,c,l),r,n,(u+c+l)%2,i&&i[o]?i[o]:[])),o++;return a}function $(t,e,r){for(var n=1;n<m;n++)for(var i=1;i<v;i++)for(var a=1;a<g;a++)X(t,y(a-1,i-1,n-1),y(a-1,i-1,n),y(a-1,i,n-1),y(a-1,i,n),y(a,i-1,n-1),y(a,i-1,n),y(a,i,n-1),y(a,i,n),e,r,(a+i+n)%2)}function Q(t,e,r){s=!0,$(t,e,r),s=!1}function tt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<m;u++)for(var h=1;h<v;h++)o.push(W(t,c,h,u,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function et(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<g;u++)for(var h=1;h<m;h++)o.push(W(t,u,c,h,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function rt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<v;u++)for(var h=1;h<g;h++)o.push(W(t,h,u,c,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function nt(t,e){for(var r=[],n=t;n<e;n++)r.push(n);return r}return function(){if(L(),function(){for(var e=0;e<g;e++)for(var r=0;r<v;r++)for(var n=0;n<m;n++){var i=y(e,r,n);P(t.x[i],t.y[i],t.z[i],t.value[i])}}(),i&&o&&(z(o),l=!0,$(null,M,S),l=!1),n&&a){z(a);for(var e=t.surface.pattern,r=t.surface.count,s=0;s<r;s++){var c=1===r?.5:s/(r-1),k=(1-c)*M+c*S,E=Math.abs(k-T)>Math.abs(k-A)?[T,k]:[k,A];Q(e,E[0],E[1])}}var C=[[Math.min(M,A),Math.max(M,A)],[Math.min(T,S),Math.max(T,S)]];[\"x\",\"y\",\"z\"].forEach(function(e){for(var r=[],n=0;n<C.length;n++){var i=0,a=C[n][0],o=C[n][1],s=t.slices[e];if(s.show&&s.fill){z(s.fill);var l=[],c=[],h=[];if(s.locations.length)for(var y=0;y<s.locations.length;y++){var x=u(s.locations[y],\"x\"===e?f:\"y\"===e?p:d);0===x.distRatio?l.push(x.id):x.id>0&&(c.push(x.id),\"x\"===e?h.push([x.distRatio,0,0]):\"y\"===e?h.push([0,x.distRatio,0]):h.push([0,0,x.distRatio]))}else l=nt(1,\"x\"===e?g-1:\"y\"===e?v-1:m-1);c.length>0&&(r[i]=\"x\"===e?tt(null,c,a,o,h,r[i]):\"y\"===e?et(null,c,a,o,h,r[i]):rt(null,c,a,o,h,r[i]),i++),l.length>0&&(r[i]=\"x\"===e?Z(null,l,a,o,r[i]):\"y\"===e?J(null,l,a,o,r[i]):K(null,l,a,o,r[i]),i++)}var b=t.caps[e];b.show&&b.fill&&(z(b.fill),r[i]=\"x\"===e?Z(null,[0,g-1],a,o,r[i]):\"y\"===e?J(null,[0,v-1],a,o,r[i]):K(null,[0,m-1],a,o,r[i]),i++)}}),0===h&&L(),t._x=x,t._y=b,t._z=_,t._intensity=w,t._Xs=f,t._Ys=p,t._Zs=d}(),t}f.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._x[e],n=this.data._y[e],i=this.data._z[e],a=this.data._Ys.length,o=this.data._Zs.length,s=u(r,this.data._Xs).id,l=u(n,this.data._Ys).id,c=u(i,this.data._Zs).id,h=t.index=c+o*l+o*a*s;t.traceCoordinate=[this.data._x[h],this.data._y[h],this.data._z[h],this.data.value[h]];var f=this.data.hovertext||this.data.text;return Array.isArray(f)&&void 0!==f[h]?t.textLabel=f[h]:f&&(t.textLabel=f),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map(function(e){return t.d2l(e,0,n)*r})}this.data=p(t);var i={positions:l(n(r.xaxis,t._x,e.dataScale[0],t.xcalendar),n(r.yaxis,t._y,e.dataScale[1],t.ycalendar),n(r.zaxis,t._z,e.dataScale[2],t.zcalendar)),cells:l(t._i,t._j,t._k),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:o(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},c=s(t);i.vertexIntensity=t._intensity,i.vertexIntensityBounds=[c.min,c.max],i.colormap=a(t),this.mesh.update(i)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports={findNearestOnAxis:u,generateIsoMeshes:p,createIsosurfaceTrace:function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new h(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../../plots/gl3d/zip3\":818,\"gl-mesh3d\":280}],1051:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"../../components/colorscale/defaults\");function s(t,e,r,n,a){var s=a(\"isomin\"),l=a(\"isomax\");null!=l&&null!=s&&s>l&&(e.isomin=null,e.isomax=null);var c=a(\"x\"),u=a(\"y\"),h=a(\"z\"),f=a(\"value\");c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length?(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],n),[\"x\",\"y\",\"z\"].forEach(function(t){var e=\"caps.\"+t;a(e+\".show\")&&a(e+\".fill\");var r=\"slices.\"+t;a(r+\".show\")&&(a(r+\".fill\"),a(r+\".locations\"))}),a(\"spaceframe.show\")&&a(\"spaceframe.fill\"),a(\"surface.show\")&&(a(\"surface.count\"),a(\"surface.fill\"),a(\"surface.pattern\")),a(\"contour.show\")&&(a(\"contour.color\"),a(\"contour.width\")),[\"text\",\"hovertext\",\"hovertemplate\",\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"flatshading\",\"opacity\"].forEach(function(t){a(t)}),o(t,e,n,a,{prefix:\"\",cLetter:\"c\"}),e._length=null):e.visible=!1}e.exports={supplyDefaults:function(t,e,r,i){s(t,e,0,i,function(r,i){return n.coerce(t,e,a,r,i)})},supplyIsoDefaults:s}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../../registry\":847,\"./attributes\":1048}],1052:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\").createIsosurfaceTrace,moduleType:\"trace\",name:\"isosurface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1048,\"./calc\":1049,\"./convert\":1050,\"./defaults\":1051}],1053:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../surface/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},i:{valType:\"data_array\",editType:\"calc\"},j:{valType:\"data_array\",editType:\"calc\"},k:{valType:\"data_array\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:i({editType:\"calc\"}),delaunayaxis:{valType:\"enumerated\",values:[\"x\",\"y\",\"z\"],dflt:\"z\",editType:\"calc\"},alphahull:{valType:\"number\",dflt:-1,editType:\"calc\"},intensity:{valType:\"data_array\",editType:\"calc\"},color:{valType:\"color\",editType:\"calc\"},vertexcolor:{valType:\"data_array\",editType:\"calc\"},facecolor:{valType:\"data_array\",editType:\"calc\"},transforms:void 0},n(\"\",{colorAttr:\"`intensity`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:a.opacity,flatshading:{valType:\"boolean\",dflt:!1,editType:\"calc\"},contour:{show:s({},a.contours.x.show,{}),color:a.contours.x.color,width:a.contours.x.width,editType:\"calc\"},lightposition:{x:s({},a.lightposition.x,{dflt:1e5}),y:s({},a.lightposition.y,{dflt:1e5}),z:s({},a.lightposition.z,{dflt:0}),editType:\"calc\"},lighting:s({vertexnormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-12,editType:\"calc\"},facenormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-6,editType:\"calc\"},editType:\"calc\"},a.lighting),hoverinfo:s({},o.hoverinfo,{editType:\"calc\"})})},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../surface/attributes\":1224}],1054:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.intensity&&n(t,e,{vals:e.intensity,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],1055:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"delaunay-triangulate\"),a=t(\"alpha-shape\"),o=t(\"convex-hull\"),s=t(\"../../lib/gl_format_color\").parseColorScale,l=t(\"../../lib/str2rgbarray\"),c=t(\"../../components/colorscale\").extractOpts,u=t(\"../../plots/gl3d/zip3\");function h(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.color=\"#fff\",this.data=null,this.showContour=!1}var f=h.prototype;function p(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=l(t[n]);return e}function d(t,e,r,n){for(var i=[],a=e.length,o=0;o<a;o++)i[o]=t.d2l(e[o],0,n)*r;return i}function g(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=Math.round(t[n]);return e}function v(t,e){for(var r=t.length,n=0;n<r;n++)if(t[n]<=-.5||t[n]>=e-.5)return!1;return!0}f.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index;t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]];var r=this.data.hovertext||this.data.text;return Array.isArray(r)&&void 0!==r[e]?t.textLabel=r[e]:r&&(t.textLabel=r),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;this.data=t;var n,h=t.x.length,f=u(d(r.xaxis,t.x,e.dataScale[0],t.xcalendar),d(r.yaxis,t.y,e.dataScale[1],t.ycalendar),d(r.zaxis,t.z,e.dataScale[2],t.zcalendar));if(t.i&&t.j&&t.k){if(t.i.length!==t.j.length||t.j.length!==t.k.length||!v(t.i,h)||!v(t.j,h)||!v(t.k,h))return;n=u(g(t.i),g(t.j),g(t.k))}else n=0===t.alphahull?o(f):t.alphahull>0?a(t.alphahull,f):function(t,e){for(var r=[\"x\",\"y\",\"z\"].indexOf(t),n=[],a=e.length,o=0;o<a;o++)n[o]=[e[o][(r+1)%3],e[o][(r+2)%3]];return i(n)}(t.delaunayaxis,f);var m={positions:f,cells:n,lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:l(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading};if(t.intensity){var y=c(t);this.color=\"#fff\",m.vertexIntensity=t.intensity,m.vertexIntensityBounds=[y.min,y.max],m.colormap=s(t)}else t.vertexcolor?(this.color=t.vertexcolor[0],m.vertexColors=p(t.vertexcolor)):t.facecolor?(this.color=t.facecolor[0],m.cellColors=p(t.facecolor)):(this.color=t.color,m.meshColor=l(t.color));this.mesh.update(m)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new h(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":605,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../../plots/gl3d/zip3\":818,\"alpha-shape\":64,\"convex-hull\":130,\"delaunay-triangulate\":165,\"gl-mesh3d\":280}],1056:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,n){return i.coerce(t,e,o,r,n)}function c(t){var e=t.map(function(t){var e=l(t);return e&&i.isArrayOrTypedArray(e)?e:null});return e.every(function(t){return t&&t.length===e[0].length})&&e}c([\"x\",\"y\",\"z\"])?(c([\"i\",\"j\",\"k\"]),(!e.i||e.j&&e.k)&&(!e.j||e.k&&e.i)&&(!e.k||e.i&&e.j)?(n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],s),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"contour.show\",\"contour.color\",\"contour.width\",\"colorscale\",\"reversescale\",\"flatshading\",\"alphahull\",\"delaunayaxis\",\"opacity\"].forEach(function(t){l(t)}),\"intensity\"in t?(l(\"intensity\"),a(t,e,s,l,{prefix:\"\",cLetter:\"c\"})):(e.showscale=!1,\"facecolor\"in t?l(\"facecolor\"):\"vertexcolor\"in t?l(\"vertexcolor\"):l(\"color\",r)),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),e._length=null):e.visible=!1):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../../registry\":847,\"./attributes\":1053}],1057:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"mesh3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1053,\"./calc\":1054,\"./convert\":1055,\"./defaults\":1056}],1058:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../scatter/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../components/fx/attributes\"),s=t(\"../../constants/delta.js\"),l=s.INCREASING.COLOR,c=s.DECREASING.COLOR,u=i.line;function h(t){return{line:{color:n({},u.color,{dflt:t}),width:u.width,dash:a,editType:\"style\"},editType:\"style\"}}e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},open:{valType:\"data_array\",editType:\"calc\"},high:{valType:\"data_array\",editType:\"calc\"},low:{valType:\"data_array\",editType:\"calc\"},close:{valType:\"data_array\",editType:\"calc\"},line:{width:n({},u.width,{}),dash:n({},a,{}),editType:\"style\"},increasing:h(l),decreasing:h(c),text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},tickwidth:{valType:\"number\",min:0,max:.5,dflt:.3,editType:\"calc\"},hoverlabel:n({},o.hoverlabel,{split:{valType:\"boolean\",dflt:!1,editType:\"style\"}})}},{\"../../components/drawing/attributes\":613,\"../../components/fx/attributes\":623,\"../../constants/delta.js\":689,\"../../lib\":719,\"../scatter/attributes\":1112}],1059:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=n._,a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/numerical\").BADNUM;function s(t,e,r,n){return{o:t,h:e,l:r,c:n}}function l(t,e,r,s,l){for(var c=s.makeCalcdata(e,\"open\"),u=s.makeCalcdata(e,\"high\"),h=s.makeCalcdata(e,\"low\"),f=s.makeCalcdata(e,\"close\"),p=Array.isArray(e.text),d=Array.isArray(e.hovertext),g=!0,v=null,m=[],y=0;y<r.length;y++){var x=r[y],b=c[y],_=u[y],w=h[y],k=f[y];if(x!==o&&b!==o&&_!==o&&w!==o&&k!==o){k===b?null!==v&&k!==v&&(g=k>v):g=k>b,v=k;var T=l(b,_,w,k);T.pos=x,T.yc=(b+k)/2,T.i=y,T.dir=g?\"increasing\":\"decreasing\",T.x=T.pos,T.y=[w,_],p&&(T.tx=e.text[y]),d&&(T.htx=e.hovertext[y]),m.push(T)}else m.push({pos:x,empty:!0})}return e._extremes[s._id]=a.findExtremes(s,n.concat(h,u),{padded:!0}),m.length&&(m[0].t={labels:{open:i(t,\"open:\")+\" \",high:i(t,\"high:\")+\" \",low:i(t,\"low:\")+\" \",close:i(t,\"close:\")+\" \"}}),m}e.exports={calc:function(t,e){var r=a.getFromId(t,e.xaxis),i=a.getFromId(t,e.yaxis),o=function(t,e,r){var i=r._minDiff;if(!i){var a,o=t._fullData,s=[];for(i=1/0,a=0;a<o.length;a++){var l=o[a];if(\"ohlc\"===l.type&&!0===l.visible&&l.xaxis===e._id){s.push(l);var c=e.makeCalcdata(l,\"x\");l._xcalc=c;var u=n.distinctVals(c).minDiff;u&&isFinite(u)&&(i=Math.min(i,u))}}for(i===1/0&&(i=1),a=0;a<s.length;a++)s[a]._minDiff=i}return i*r.tickwidth}(t,r,e),c=e._minDiff;e._minDiff=null;var u=e._xcalc;e._xcalc=null;var h=l(t,e,u,i,s);return e._extremes[r._id]=a.findExtremes(r,u,{vpad:c/2}),h.length?(n.extendFlat(h[0].t,{wHover:c/2,tickLen:o}),h):[{t:{empty:!0}}]},calcCommon:l}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],1060:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./ohlc_defaults\"),a=t(\"./attributes\");function o(t,e,r,n){r(n+\".line.color\"),r(n+\".line.width\",e.line.width),r(n+\".line.dash\",e.line.dash)}e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,a,r,i)}i(t,e,l,s)?(l(\"line.width\"),l(\"line.dash\"),o(t,e,l,\"increasing\"),o(t,e,l,\"decreasing\"),l(\"text\"),l(\"hovertext\"),l(\"tickwidth\"),s._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../lib\":719,\"./attributes\":1058,\"./ohlc_defaults\":1063}],1061:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\").fillText,l=t(\"../../constants/delta.js\"),c={increasing:l.INCREASING.SYMBOL,decreasing:l.DECREASING.SYMBOL};function u(t,e,r,n){var i,s,l=t.cd,c=t.xa,u=l[0].trace,h=l[0].t,f=u.type,p=\"ohlc\"===f?\"l\":\"min\",d=\"ohlc\"===f?\"h\":\"max\",g=h.bPos||0,v=function(t){return t.pos+g-e},m=h.bdPos||h.tickLen,y=h.wHover,x=Math.min(1,m/Math.abs(c.r2c(c.range[1])-c.r2c(c.range[0])));function b(t){var e=v(t);return a.inbox(e-y,e+y,i)}function _(t){var e=t[p],n=t[d];return e===n||a.inbox(e-r,n-r,i)}function w(t){return(b(t)+_(t))/2}i=t.maxHoverDistance-x,s=t.maxSpikeDistance-x;var k=a.getDistanceFunction(n,b,_,w);if(a.getClosest(l,k,t),!1===t.index)return null;var T=l[t.index];if(T.empty)return null;var A=u[T.dir],M=A.line.color;return o.opacity(M)&&A.line.width?t.color=M:t.color=A.fillcolor,t.x0=c.c2p(T.pos+g-m,!0),t.x1=c.c2p(T.pos+g+m,!0),t.xLabelVal=T.pos,t.spikeDistance=w(T)*s/i,t.xSpike=c.c2p(T.pos,!0),t}function h(t,e,r,a){var o=t.cd,s=t.ya,l=o[0].trace,c=o[0].t,h=[],f=u(t,e,r,a);if(!f)return[];var p=o[f.index].hi||l.hoverinfo,d=p.split(\"+\");if(!(\"all\"===p||-1!==d.indexOf(\"y\")))return[];for(var g=[\"high\",\"open\",\"close\",\"low\"],v={},m=0;m<g.length;m++){var y,x=g[m],b=l[x][f.index],_=s.c2p(b,!0);b in v?(y=v[b]).yLabel+=\"<br>\"+c.labels[x]+n.hoverLabelText(s,b):((y=i.extendFlat({},f)).y0=y.y1=_,y.yLabelVal=b,y.yLabel=c.labels[x]+n.hoverLabelText(s,b),y.name=\"\",h.push(y),v[b]=y)}return h}function f(t,e,r,i){var a=t.cd,o=t.ya,l=a[0].trace,h=a[0].t,f=u(t,e,r,i);if(!f)return[];var p=a[f.index],d=f.index=p.i,g=p.dir;function v(t){return h.labels[t]+n.hoverLabelText(o,l[t][d])}var m=p.hi||l.hoverinfo,y=m.split(\"+\"),x=\"all\"===m,b=x||-1!==y.indexOf(\"y\"),_=x||-1!==y.indexOf(\"text\"),w=b?[v(\"open\"),v(\"high\"),v(\"low\"),v(\"close\")+\"  \"+c[g]]:[];return _&&s(p,l,w),f.extraText=w.join(\"<br>\"),f.y0=f.y1=o.c2p(p.yc,!0),[f]}e.exports={hoverPoints:function(t,e,r,n){return t.cd[0].trace.hoverlabel.split?h(t,e,r,n):f(t,e,r,n)},hoverSplit:h,hoverOnPoints:f}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../constants/delta.js\":689,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],1062:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"ohlc\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\"],meta:{},attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\").calc,plot:t(\"./plot\"),style:t(\"./style\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\")}},{\"../../plots/cartesian\":778,\"./attributes\":1058,\"./calc\":1059,\"./defaults\":1060,\"./hover\":1061,\"./plot\":1064,\"./select\":1065,\"./style\":1066}],1063:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"open\"),l=r(\"high\"),c=r(\"low\"),u=r(\"close\");if(r(\"hoverlabel.split\"),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\"],a),s&&l&&c&&u){var h=Math.min(s.length,l.length,c.length,u.length);return o&&(h=Math.min(h,i.minRowLength(o))),e._length=h,h}}},{\"../../lib\":719,\"../../registry\":847}],1064:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=e.xaxis,s=e.yaxis;i.makeTraceGroups(a,r,\"trace ohlc\").each(function(t){var e=n.select(this),r=t[0],a=r.t;if(!0!==r.trace.visible||a.empty)e.remove();else{var l=a.tickLen,c=e.selectAll(\"path\").data(i.identity);c.enter().append(\"path\"),c.exit().remove(),c.attr(\"d\",function(t){if(t.empty)return\"M0,0Z\";var e=o.c2p(t.pos,!0),r=o.c2p(t.pos-l,!0),n=o.c2p(t.pos+l,!0);return\"M\"+r+\",\"+s.c2p(t.o,!0)+\"H\"+e+\"M\"+e+\",\"+s.c2p(t.h,!0)+\"V\"+s.c2p(t.l,!0)+\"M\"+n+\",\"+s.c2p(t.c,!0)+\"H\"+e})}})}},{\"../../lib\":719,d3:163}],1065:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n=t.cd,i=t.xaxis,a=t.yaxis,o=[],s=n[0].t.bPos||0;if(!1===e)for(r=0;r<n.length;r++)n[r].selected=0;else for(r=0;r<n.length;r++){var l=n[r];e.contains([i.c2p(l.pos+s),a.c2p(l.yc)],null,l.i,t)?(o.push({pointNumber:l.i,x:i.c2d(l.pos),y:a.c2d(l.yc)}),l.selected=1):l.selected=0}return o}},{}],1066:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\");e.exports=function(t,e,r){var o=r||n.select(t).selectAll(\"g.ohlclayer\").selectAll(\"g.trace\");o.style(\"opacity\",function(t){return t[0].trace.opacity}),o.each(function(t){var e=t[0].trace;n.select(this).selectAll(\"path\").each(function(t){if(!t.empty){var r=e[t.dir].line;n.select(this).style(\"fill\",\"none\").call(a.stroke,r.color).call(i.dashLine,r.dash,r.width).style(\"opacity\",e.selectedpoints&&!t.selected?.3:1)}})})}},{\"../../components/color\":593,\"../../components/drawing\":614,d3:163}],1067:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../plots/attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/fx/hovertemplate_attributes\"),l=t(\"../../plots/domain\").attributes,c=n({editType:\"calc\"},o(\"line\",{editTypeOverride:\"calc\"}),{shape:{valType:\"enumerated\",values:[\"linear\",\"hspline\"],dflt:\"linear\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\"]})});e.exports={domain:l({name:\"parcats\",trace:!0,editType:\"calc\"}),hoverinfo:n({},i.hoverinfo,{flags:[\"count\",\"probability\"],editType:\"plot\",arrayOk:!1}),hoveron:{valType:\"enumerated\",values:[\"category\",\"color\",\"dimension\"],dflt:\"category\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\",\"category\",\"categorycount\",\"colorcount\",\"bandcolorcount\"]}),arrangement:{valType:\"enumerated\",values:[\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"perpendicular\",editType:\"plot\"},bundlecolors:{valType:\"boolean\",dflt:!0,editType:\"plot\"},sortpaths:{valType:\"enumerated\",values:[\"forward\",\"backward\"],dflt:\"forward\",editType:\"plot\"},labelfont:a({editType:\"calc\"}),tickfont:a({editType:\"calc\"}),dimensions:{_isLinkedToArray:\"dimension\",label:{valType:\"string\",editType:\"calc\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",dflt:[],editType:\"calc\"},displayindex:{valType:\"integer\",editType:\"calc\"},editType:\"calc\",visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"}},line:c,counts:{valType:\"number\",min:0,dflt:1,arrayOk:!0,editType:\"calc\"},customdata:void 0,hoverlabel:void 0,ids:void 0,legendgroup:void 0,opacity:void 0,selectedpoints:void 0,showlegend:void 0}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1068:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"parcats\",r.plot=function(t,e,r,a){var o=n(t.calcdata,\"parcats\");if(o.length){var s=o[0];i(t,s,r,a)}},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcats\"),a=e._has&&e._has(\"parcats\");i&&!a&&n._paperdiv.selectAll(\".parcats\").remove()}},{\"../../plots/get_data\":802,\"./plot\":1073}],1069:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),o=t(\"../../lib/filter_unique.js\"),s=t(\"../../components/drawing\"),l=t(\"../../lib\");function c(t,e,r){t.valueInds.push(e),t.count+=r}function u(t,e,r){t.valueInds.push(e),t.count+=r}e.exports=function(t,e){var r=l.filterVisible(e.dimensions);if(0===r.length)return[];var h,f,p,d=r.map(function(t){var e;return\"trace\"===t.categoryorder?e=null:\"array\"===t.categoryorder?e=t.categoryarray:(e=o(t.values).sort(),\"category descending\"===t.categoryorder&&(e=e.reverse())),function(t,e){e=null==e?[]:e.map(function(t){return t});var r={},n={},i=[];e.forEach(function(t,e){r[t]=0,n[t]=e});for(var a=0;a<t.length;a++){var o,s=t[a];void 0===r[s]?(r[s]=1,o=e.push(s)-1,n[s]=o):(r[s]++,o=n[s]),i.push(o)}var l=e.map(function(t){return r[t]});return{uniqueValues:e,uniqueCounts:l,inds:i}}(t.values,e)});h=l.isArrayOrTypedArray(e.counts)?e.counts:[e.counts],function(t){var e;if(function(t){for(var e=new Array(t.length),r=0;r<t.length;r++){if(t[r]<0||t[r]>=t.length)return!1;if(void 0!==e[t[r]])return!1;e[t[r]]=!0}return!0}(t.map(function(t){return t.displayindex})))for(e=0;e<t.length;e++)t[e]._displayindex=t[e].displayindex;else for(e=0;e<t.length;e++)t[e]._displayindex=e}(r),r.forEach(function(t,e){!function(t,e){t._categoryarray=e.uniqueValues,null===t.ticktext||void 0===t.ticktext?t._ticktext=[]:t._ticktext=t.ticktext.slice();for(var r=t._ticktext.length;r<e.uniqueValues.length;r++)t._ticktext.push(e.uniqueValues[r])}(t,d[e])});var g,v=e.line;v?(i(e,\"line\")&&a(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),g=s.tryColorscale(v)):g=l.identity;var m,y,x,b,_=r[0].values.length,w={},k=d.map(function(t){return t.inds});for(p=0,m=0;m<_;m++){var T=[];for(y=0;y<k.length;y++)T.push(k[y][m]);f=h[m%h.length],p+=f;var A=(x=m,b=void 0,b=l.isArrayOrTypedArray(v.color)?v.color[x%v.color.length]:v.color,{color:g(b),rawColor:b}),M=T+\"-\"+A.rawColor;void 0===w[M]&&(w[M]={categoryInds:T,color:A.color,rawColor:A.rawColor,valueInds:[],count:0}),u(w[M],m,f)}var S,E=r.map(function(t,e){return r=e,n=t._index,i=t._displayindex,a=t.label,{dimensionInd:r,containerInd:n,displayInd:i,dimensionLabel:a,count:p,categories:[],dragX:null};var r,n,i,a});for(m=0;m<_;m++)for(f=h[m%h.length],y=0;y<E.length;y++){var C=E[y].containerInd,L=d[y].inds[m],P=E[y].categories;if(void 0===P[L]){var O=e.dimensions[C]._categoryarray[L],z=e.dimensions[C]._ticktext[L];P[L]={dimensionInd:y,categoryInd:S=L,categoryValue:O,displayInd:S,categoryLabel:z,valueInds:[],count:0,dragY:null}}c(P[L],m,f)}return n(function(t,e,r){var n=t.map(function(t){return t.categories.length}).reduce(function(t,e){return Math.max(t,e)});return{dimensions:t,paths:e,trace:void 0,maxCats:n,count:r}}(E,w,p))}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/filter_unique.js\":711,\"../../lib/gup\":717}],1070:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"./attributes\"),c=t(\"../parcoords/merge_length\");function u(t,e){function r(r,i){return n.coerce(t,e,l.dimensions,r,i)}var i=r(\"values\"),a=r(\"visible\");if(i&&i.length||(a=e.visible=!1),a){r(\"label\"),r(\"displayindex\",e._index);var o,s=t.categoryarray,c=Array.isArray(s)&&s.length>0;c&&(o=\"array\");var u=r(\"categoryorder\",o);\"array\"===u?(r(\"categoryarray\"),r(\"ticktext\")):(delete t.categoryarray,delete t.ticktext),c||\"array\"!==u||(e.categoryorder=\"trace\")}}e.exports=function(t,e,r,h){function f(r,i){return n.coerce(t,e,l,r,i)}var p=s(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=function(t,e,r,o,s){s(\"line.shape\"),s(\"line.hovertemplate\");var l=s(\"line.color\",o.colorway[0]);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,h,f);o(e,h,f),Array.isArray(p)&&p.length||(e.visible=!1),c(e,p,\"values\",d),f(\"hoveron\"),f(\"hovertemplate\"),f(\"arrangement\"),f(\"bundlecolors\"),f(\"sortpaths\"),f(\"counts\");var g={family:h.font.family,size:Math.round(h.font.size),color:h.font.color};n.coerceFont(f,\"labelfont\",g);var v={family:h.font.family,size:Math.round(h.font.size/1.2),color:h.font.color};n.coerceFont(f,\"tickfont\",v)}},{\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/domain\":792,\"../parcoords/merge_length\":1083,\"./attributes\":1067}],1071:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcats\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1067,\"./base_plot\":1068,\"./calc\":1069,\"./defaults\":1070,\"./plot\":1073}],1072:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plot_api/plot_api\"),a=t(\"../../components/fx\"),o=t(\"../../lib\"),s=t(\"../../components/drawing\"),l=t(\"tinycolor2\"),c=t(\"../../lib/svg_text_utils\");function u(t,e,r,i){var a=t.map(function(t,e,r){var n,i=r[0],a=e.margin||{l:80,r:80,t:100,b:80},o=i.trace,s=o.domain,l=e.width,c=e.height,u=Math.floor(l*(s.x[1]-s.x[0])),h=Math.floor(c*(s.y[1]-s.y[0])),f=s.x[0]*l+a.l,p=e.height-s.y[1]*e.height+a.t,d=o.line.shape;n=\"all\"===o.hoverinfo?[\"count\",\"probability\"]:(o.hoverinfo||\"\").split(\"+\");var g={trace:o,key:o.uid,model:i,x:f,y:p,width:u,height:h,hoveron:o.hoveron,hoverinfoItems:n,arrangement:o.arrangement,bundlecolors:o.bundlecolors,sortpaths:o.sortpaths,labelfont:o.labelfont,categorylabelfont:o.tickfont,pathShape:d,dragDimension:null,margin:a,paths:[],dimensions:[],graphDiv:t,traceSelection:null,pathSelection:null,dimensionSelection:null};i.dimensions&&(R(g),D(g));return g}.bind(0,e,r)),l=i.selectAll(\"g.parcatslayer\").data([null]);l.enter().append(\"g\").attr(\"class\",\"parcatslayer\").style(\"pointer-events\",\"all\");var u=l.selectAll(\"g.trace.parcats\").data(a,h),v=u.enter().append(\"g\").attr(\"class\",\"trace parcats\");u.attr(\"transform\",function(t){return\"translate(\"+t.x+\", \"+t.y+\")\"}),v.append(\"g\").attr(\"class\",\"paths\");var x=u.select(\"g.paths\").selectAll(\"path.path\").data(function(t){return t.paths},h);x.attr(\"fill\",function(t){return t.model.color});var w=x.enter().append(\"path\").attr(\"class\",\"path\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.model.color}).attr(\"fill-opacity\",0);y(w),x.attr(\"d\",function(t){return t.svgD}),w.empty()||x.sort(p),x.exit().remove(),x.on(\"mouseover\",d).on(\"mouseout\",g).on(\"click\",m),v.append(\"g\").attr(\"class\",\"dimensions\");var k=u.select(\"g.dimensions\").selectAll(\"g.dimension\").data(function(t){return t.dimensions},h);k.enter().append(\"g\").attr(\"class\",\"dimension\"),k.attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),k.exit().remove();var T=k.selectAll(\"g.category\").data(function(t){return t.categories},h),A=T.enter().append(\"g\").attr(\"class\",\"category\");T.attr(\"transform\",function(t){return\"translate(0, \"+t.y+\")\"}),A.append(\"rect\").attr(\"class\",\"catrect\").attr(\"pointer-events\",\"none\"),T.select(\"rect.catrect\").attr(\"fill\",\"none\").attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}),b(A);var P=T.selectAll(\"rect.bandrect\").data(function(t){return t.bands},h);P.each(function(){o.raiseToTop(this)}),P.attr(\"fill\",function(t){return t.color});var O=P.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.color}).attr(\"fill-opacity\",0);P.attr(\"fill\",function(t){return t.color}).attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}).attr(\"y\",function(t){return t.y}).attr(\"cursor\",function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"perpendicular\"===t.parcatsViewModel.arrangement?\"ns-resize\":\"move\"}),_(O),P.exit().remove(),A.append(\"text\").attr(\"class\",\"catlabel\").attr(\"pointer-events\",\"none\");var z=e._fullLayout.paper_bgcolor;T.select(\"text.catlabel\").attr(\"text-anchor\",function(t){return f(t)?\"start\":\"end\"}).attr(\"alignment-baseline\",\"middle\").style(\"text-shadow\",z+\" -1px  1px 2px, \"+z+\" 1px  1px 2px, \"+z+\"  1px -1px 2px, \"+z+\" -1px -1px 2px\").style(\"fill\",\"rgb(0, 0, 0)\").attr(\"x\",function(t){return f(t)?t.width+5:-5}).attr(\"y\",function(t){return t.height/2}).text(function(t){return t.model.categoryLabel}).each(function(t){s.font(n.select(this),t.parcatsViewModel.categorylabelfont),c.convertToTspans(n.select(this),e)}),A.append(\"text\").attr(\"class\",\"dimlabel\"),T.select(\"text.dimlabel\").attr(\"text-anchor\",\"middle\").attr(\"alignment-baseline\",\"baseline\").attr(\"cursor\",function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"ew-resize\"}).attr(\"x\",function(t){return t.width/2}).attr(\"y\",-5).text(function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null}).each(function(t){s.font(n.select(this),t.parcatsViewModel.labelfont)}),T.selectAll(\"rect.bandrect\").on(\"mouseover\",M).on(\"mouseout\",S),T.exit().remove(),k.call(n.behavior.drag().origin(function(t){return{x:t.x,y:0}}).on(\"dragstart\",E).on(\"drag\",C).on(\"dragend\",L)),u.each(function(t){t.traceSelection=n.select(this),t.pathSelection=n.select(this).selectAll(\"g.paths\").selectAll(\"path.path\"),t.dimensionSelection=n.select(this).selectAll(\"g.dimensions\").selectAll(\"g.dimension\")}),u.exit().remove()}function h(t){return t.key}function f(t){var e=t.parcatsViewModel.dimensions.length,r=t.parcatsViewModel.dimensions[e-1].model.dimensionInd;return t.model.dimensionInd===r}function p(t,e){return t.model.rawColor>e.model.rawColor?1:t.model.rawColor<e.model.rawColor?-1:0}function d(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){o.raiseToTop(this),x(n.select(this));var e=v(t);if(t.parcatsViewModel.graphDiv.emit(\"plotly_hover\",{points:e,event:n.event}),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\")){var r,i,s,c=n.mouse(this)[0],u=t.parcatsViewModel.graphDiv,h=t.parcatsViewModel.trace,f=u._fullLayout,p=f._paperdiv.node().getBoundingClientRect(),d=t.parcatsViewModel.graphDiv.getBoundingClientRect();for(s=0;s<t.leftXs.length-1;s++)if(t.leftXs[s]+t.dimWidths[s]-2<=c&&c<=t.leftXs[s+1]+2){var g=t.parcatsViewModel.dimensions[s],m=t.parcatsViewModel.dimensions[s+1];r=(g.x+g.width+m.x)/2,i=(t.topYs[s]+t.topYs[s+1]+t.height)/2;break}var y=t.parcatsViewModel.x+r,b=t.parcatsViewModel.y+i,_=l.mostReadable(t.model.color,[\"black\",\"white\"]),w=t.model.count,k=w/t.parcatsViewModel.model.count,T={countLabel:w,probabilityLabel:k.toFixed(3)},A=[];-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&A.push([\"Count:\",T.countLabel].join(\" \")),-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&A.push([\"P:\",T.probabilityLabel].join(\" \"));var M=A.join(\"<br>\"),S=n.mouse(u)[0];a.loneHover({trace:h,x:y-p.left+d.left,y:b-p.top+d.top,text:M,color:t.model.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:10,fontColor:_,idealAlign:S<y?\"right\":\"left\",hovertemplate:(h.line||{}).hovertemplate,hovertemplateLabels:T,eventData:[{data:h._input,fullData:h,count:w,probability:k}]},{container:f._hoverlayer.node(),outerContainer:f._paper.node(),gd:u})}}}function g(t){if(!t.parcatsViewModel.dragDimension&&(y(n.select(this)),a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()),t.parcatsViewModel.pathSelection.sort(p),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\"))){var e=v(t);t.parcatsViewModel.graphDiv.emit(\"plotly_unhover\",{points:e,event:n.event})}}function v(t){for(var e=[],r=P(t.parcatsViewModel),n=0;n<t.model.valueInds.length;n++){var i=t.model.valueInds[n];e.push({curveNumber:r,pointNumber:i})}return e}function m(t){if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){var e=v(t);t.parcatsViewModel.graphDiv.emit(\"plotly_click\",{points:e,event:n.event})}}function y(t){t.attr(\"fill\",function(t){return t.model.color}).attr(\"fill-opacity\",.6).attr(\"stroke\",\"lightgray\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1)}function x(t){t.attr(\"fill-opacity\",.8).attr(\"stroke\",function(t){return l.mostReadable(t.model.color,[\"black\",\"white\"])}).attr(\"stroke-width\",.3)}function b(t){t.select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",1).attr(\"stroke-opacity\",1)}function _(t){t.attr(\"stroke\",\"black\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1).attr(\"fill-opacity\",1)}function w(t){var e=t.parcatsViewModel.pathSelection,r=t.categoryViewModel.model.dimensionInd,n=t.categoryViewModel.model.categoryInd;return e.filter(function(e){return e.model.categoryInds[r]===n&&e.model.color===t.color})}function k(t,e,r){var i=n.select(t).datum().parcatsViewModel.graphDiv,a=n.select(t.parentNode).selectAll(\"rect.bandrect\"),o=[];a.each(function(t){w(t).each(function(t){Array.prototype.push.apply(o,v(t))})}),i.emit(e,{points:o,event:r})}function T(t,e,r){var i=n.select(t).datum(),a=i.parcatsViewModel.graphDiv,o=w(i),s=[];o.each(function(t){Array.prototype.push.apply(s,v(t))}),a.emit(e,{points:s,event:r})}function A(t,e){var r,i,a=n.select(e.parentNode).select(\"rect.catrect\"),o=a.node().getBoundingClientRect(),s=a.datum(),l=s.parcatsViewModel,c=l.model.dimensions[s.model.dimensionInd],u=l.trace,h=o.top+o.height/2;l.dimensions.length>1&&c.displayInd===l.dimensions.length-1?(r=o.left,i=\"left\"):(r=o.left+o.width,i=\"right\");var f=s.model.count,p=s.model.categoryLabel,d=f/s.parcatsViewModel.model.count,g={countLabel:f,categoryLabel:p,probabilityLabel:d.toFixed(3)},v=[];-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&v.push([\"Count:\",g.countLabel].join(\" \")),-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&v.push([\"P(\"+g.categoryLabel+\"):\",g.probabilityLabel].join(\" \"));var m=v.join(\"<br>\");return{trace:u,x:r-t.left,y:h-t.top,text:m,color:\"lightgray\",borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:12,fontColor:\"black\",idealAlign:i,hovertemplate:u.hovertemplate,hovertemplateLabels:g,eventData:[{data:u._input,fullData:u,count:f,category:p,probability:d}]}}function M(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){if(n.mouse(this)[1]<-1)return;var e,r=t.parcatsViewModel.graphDiv,i=r._fullLayout,s=i._paperdiv.node().getBoundingClientRect(),c=t.parcatsViewModel.hoveron;if(\"color\"===c?(!function(t){var e=n.select(t).datum(),r=w(e);x(r),r.each(function(){o.raiseToTop(this)}),n.select(t.parentNode).selectAll(\"rect.bandrect\").filter(function(t){return t.color===e.color}).each(function(){o.raiseToTop(this),n.select(this).attr(\"stroke\",\"black\").attr(\"stroke-width\",1.5)})}(this),T(this,\"plotly_hover\",n.event)):(!function(t){n.select(t.parentNode).selectAll(\"rect.bandrect\").each(function(t){var e=w(t);x(e),e.each(function(){o.raiseToTop(this)})}),n.select(t.parentNode).select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",2.5)}(this),k(this,\"plotly_hover\",n.event)),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\"))\"category\"===c?e=A(s,this):\"color\"===c?e=function(t,e){var r,i,a=e.getBoundingClientRect(),o=n.select(e).datum(),s=o.categoryViewModel,c=s.parcatsViewModel,u=c.model.dimensions[s.model.dimensionInd],h=c.trace,f=a.y+a.height/2;c.dimensions.length>1&&u.displayInd===c.dimensions.length-1?(r=a.left,i=\"left\"):(r=a.left+a.width,i=\"right\");var p=s.model.categoryLabel,d=o.parcatsViewModel.model.count,g=0;o.categoryViewModel.bands.forEach(function(t){t.color===o.color&&(g+=t.count)});var v=s.model.count,m=0;c.pathSelection.each(function(t){t.model.color===o.color&&(m+=t.model.count)});var y=g/d,x=g/m,b=g/v,_={countLabel:d,categoryLabel:p,probabilityLabel:y.toFixed(3)},w=[];-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&w.push([\"Count:\",_.countLabel].join(\" \")),-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&(w.push(\"P(color \\u2229 \"+p+\"): \"+_.probabilityLabel),w.push(\"P(\"+p+\" | color): \"+x.toFixed(3)),w.push(\"P(color | \"+p+\"): \"+b.toFixed(3)));var k=w.join(\"<br>\"),T=l.mostReadable(o.color,[\"black\",\"white\"]);return{trace:h,x:r-t.left,y:f-t.top,text:k,color:o.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontColor:T,fontSize:10,idealAlign:i,hovertemplate:h.hovertemplate,hovertemplateLabels:_,eventData:[{data:h._input,fullData:h,category:p,count:d,probability:y,categorycount:v,colorcount:m,bandcolorcount:g}]}}(s,this):\"dimension\"===c&&(e=function(t,e){var r=[];return n.select(e.parentNode.parentNode).selectAll(\"g.category\").select(\"rect.catrect\").each(function(){r.push(A(t,this))}),r}(s,this)),e&&a.loneHover(e,{container:i._hoverlayer.node(),outerContainer:i._paper.node(),gd:r})}}function S(t){var e=t.parcatsViewModel;if(!e.dragDimension&&(y(e.pathSelection),b(e.dimensionSelection.selectAll(\"g.category\")),_(e.dimensionSelection.selectAll(\"g.category\").selectAll(\"rect.bandrect\")),a.loneUnhover(e.graphDiv._fullLayout._hoverlayer.node()),e.pathSelection.sort(p),-1===e.hoverinfoItems.indexOf(\"skip\"))){\"color\"===t.parcatsViewModel.hoveron?T(this,\"plotly_unhover\",n.event):k(this,\"plotly_unhover\",n.event)}}function E(t){\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragDimensionDisplayInd=t.model.displayInd,t.initialDragDimensionDisplayInds=t.parcatsViewModel.model.dimensions.map(function(t){return t.displayInd}),t.dragHasMoved=!1,t.dragCategoryDisplayInd=null,n.select(this).selectAll(\"g.category\").select(\"rect.catrect\").each(function(e){var r=n.mouse(this)[0],i=n.mouse(this)[1];-2<=r&&r<=e.width+2&&-2<=i&&i<=e.height+2&&(t.dragCategoryDisplayInd=e.model.displayInd,t.initialDragCategoryDisplayInds=t.model.categories.map(function(t){return t.displayInd}),e.model.dragY=e.y,o.raiseToTop(this.parentNode),n.select(this.parentNode).selectAll(\"rect.bandrect\").each(function(e){e.y<i&&i<=e.y+e.height&&(t.potentialClickBand=this)}))}),t.parcatsViewModel.dragDimension=t,a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()))}function C(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragHasMoved=!0,null!==t.dragDimensionDisplayInd)){var e=t.dragDimensionDisplayInd,r=e-1,i=e+1,a=t.parcatsViewModel.dimensions[e];if(null!==t.dragCategoryDisplayInd){var o=a.categories[t.dragCategoryDisplayInd];o.model.dragY+=n.event.dy;var s=o.model.dragY,l=o.model.displayInd,c=a.categories,u=c[l-1],h=c[l+1];void 0!==u&&s<u.y+u.height/2&&(o.model.displayInd=u.model.displayInd,u.model.displayInd=l),void 0!==h&&s+o.height>h.y+h.height/2&&(o.model.displayInd=h.model.displayInd,h.model.displayInd=l),t.dragCategoryDisplayInd=o.model.displayInd}if(null===t.dragCategoryDisplayInd||\"freeform\"===t.parcatsViewModel.arrangement){a.model.dragX=n.event.x;var f=t.parcatsViewModel.dimensions[r],p=t.parcatsViewModel.dimensions[i];void 0!==f&&a.model.dragX<f.x+f.width&&(a.model.displayInd=f.model.displayInd,f.model.displayInd=e),void 0!==p&&a.model.dragX+a.width>p.x&&(a.model.displayInd=p.model.displayInd,p.model.displayInd=t.dragDimensionDisplayInd),t.dragDimensionDisplayInd=a.model.displayInd}R(t.parcatsViewModel),D(t.parcatsViewModel),z(t.parcatsViewModel),O(t.parcatsViewModel)}}function L(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&null!==t.dragDimensionDisplayInd){n.select(this).selectAll(\"text\").attr(\"font-weight\",\"normal\");var e={},r=P(t.parcatsViewModel),a=t.parcatsViewModel.model.dimensions.map(function(t){return t.displayInd}),o=t.initialDragDimensionDisplayInds.some(function(t,e){return t!==a[e]});o&&a.forEach(function(r,n){var i=t.parcatsViewModel.model.dimensions[n].containerInd;e[\"dimensions[\"+i+\"].displayindex\"]=r});var s=!1;if(null!==t.dragCategoryDisplayInd){var l=t.model.categories.map(function(t){return t.displayInd});if(s=t.initialDragCategoryDisplayInds.some(function(t,e){return t!==l[e]})){var c=t.model.categories.slice().sort(function(t,e){return t.displayInd-e.displayInd}),u=c.map(function(t){return t.categoryValue}),h=c.map(function(t){return t.categoryLabel});e[\"dimensions[\"+t.model.containerInd+\"].categoryarray\"]=[u],e[\"dimensions[\"+t.model.containerInd+\"].ticktext\"]=[h],e[\"dimensions[\"+t.model.containerInd+\"].categoryorder\"]=\"array\"}}if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")&&!t.dragHasMoved&&t.potentialClickBand&&(\"color\"===t.parcatsViewModel.hoveron?T(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent):k(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent)),t.model.dragX=null,null!==t.dragCategoryDisplayInd)t.parcatsViewModel.dimensions[t.dragDimensionDisplayInd].categories[t.dragCategoryDisplayInd].model.dragY=null,t.dragCategoryDisplayInd=null;t.dragDimensionDisplayInd=null,t.parcatsViewModel.dragDimension=null,t.dragHasMoved=null,t.potentialClickBand=null,R(t.parcatsViewModel),D(t.parcatsViewModel),n.transition().duration(300).ease(\"cubic-in-out\").each(function(){z(t.parcatsViewModel,!0),O(t.parcatsViewModel,!0)}).each(\"end\",function(){(o||s)&&i.restyle(t.parcatsViewModel.graphDiv,e,[r])})}}function P(t){for(var e,r=t.graphDiv._fullData,n=0;n<r.length;n++)if(t.key===r[n].uid){e=n;break}return e}function O(t,e){var r;void 0===e&&(e=!1),t.pathSelection.data(function(t){return t.paths},h),(r=t.pathSelection,e?r.transition():r).attr(\"d\",function(t){return t.svgD})}function z(t,e){function r(t){return e?t.transition():t}void 0===e&&(e=!1),t.dimensionSelection.data(function(t){return t.dimensions},h);var i=t.dimensionSelection.selectAll(\"g.category\").data(function(t){return t.categories},h);r(t.dimensionSelection).attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),r(i).attr(\"transform\",function(t){return\"translate(0, \"+t.y+\")\"}),i.select(\".dimlabel\").text(function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null}),i.select(\".catlabel\").attr(\"text-anchor\",function(t){return f(t)?\"start\":\"end\"}).attr(\"x\",function(t){return f(t)?t.width+5:-5}).each(function(t){var e,r;f(t)?(e=t.width+5,r=\"start\"):(e=-5,r=\"end\"),n.select(this).selectAll(\"tspan\").attr(\"x\",e).attr(\"text-anchor\",r)});var a=i.selectAll(\"rect.bandrect\").data(function(t){return t.bands},h),s=a.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"cursor\",\"move\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.color}).attr(\"fill-opacity\",0);a.attr(\"fill\",function(t){return t.color}).attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}).attr(\"y\",function(t){return t.y}),_(s),a.each(function(){o.raiseToTop(this)}),a.exit().remove()}function I(t,e,r,i,a){var o,s,l=[],c=[];for(s=0;s<r.length-1;s++)o=n.interpolateNumber(r[s]+t[s],t[s+1]),l.push(o(a)),c.push(o(1-a));var u=\"M \"+t[0]+\",\"+e[0];for(u+=\"l\"+r[0]+\",0 \",s=1;s<r.length;s++)u+=\"C\"+l[s-1]+\",\"+e[s-1]+\" \"+c[s-1]+\",\"+e[s]+\" \"+t[s]+\",\"+e[s],u+=\"l\"+r[s]+\",0 \";for(u+=\"l0,\"+i+\" \",u+=\"l -\"+r[r.length-1]+\",0 \",s=r.length-2;s>=0;s--)u+=\"C\"+c[s]+\",\"+(e[s+1]+i)+\" \"+l[s]+\",\"+(e[s]+i)+\" \"+(t[s]+r[s])+\",\"+(e[s]+i),u+=\"l-\"+r[s]+\",0 \";return u+=\"Z\"}function D(t){var e=t.dimensions,r=t.model,n=e.map(function(t){return t.categories.map(function(t){return t.y})}),i=t.model.dimensions.map(function(t){return t.categories.map(function(t){return t.displayInd})}),a=t.model.dimensions.map(function(t){return t.displayInd}),o=t.dimensions.map(function(t){return t.model.dimensionInd}),s=e.map(function(t){return t.x}),l=e.map(function(t){return t.width}),c=[];for(var u in r.paths)r.paths.hasOwnProperty(u)&&c.push(r.paths[u]);function h(t){var e=t.categoryInds.map(function(t,e){return i[e][t]});return o.map(function(t){return e[t]})}c.sort(function(e,r){var n=h(e),i=h(r);return\"backward\"===t.sortpaths&&(n.reverse(),i.reverse()),n.push(e.valueInds[0]),i.push(r.valueInds[0]),t.bundlecolors&&(n.unshift(e.rawColor),i.unshift(r.rawColor)),n<i?-1:n>i?1:0});for(var f=new Array(c.length),p=e[0].model.count,d=e[0].categories.map(function(t){return t.height}).reduce(function(t,e){return t+e}),g=0;g<c.length;g++){var v,m=c[g];v=p>0?d*(m.count/p):0;for(var y,x=new Array(n.length),b=0;b<m.categoryInds.length;b++){var _=m.categoryInds[b],w=i[b][_],k=a[b];x[k]=n[k][w],n[k][w]+=v;var T=t.dimensions[k].categories[w],A=T.bands.length,M=T.bands[A-1];if(void 0===M||m.rawColor!==M.rawColor){var S=void 0===M?0:M.y+M.height;T.bands.push({key:S,color:m.color,rawColor:m.rawColor,height:v,width:T.width,count:m.count,y:S,categoryViewModel:T,parcatsViewModel:t})}else{var E=T.bands[A-1];E.height+=v,E.count+=m.count}}y=\"hspline\"===t.pathShape?I(s,x,l,v,.5):I(s,x,l,v,0),f[g]={key:m.valueInds[0],model:m,height:v,leftXs:s,topYs:x,dimWidths:l,svgD:y,parcatsViewModel:t}}t.paths=f}function R(t){var e=t.model.dimensions.map(function(t){return{displayInd:t.displayInd,dimensionInd:t.dimensionInd}});e.sort(function(t,e){return t.displayInd-e.displayInd});var r=[];for(var n in e){var i=e[n].dimensionInd,a=t.model.dimensions[i];r.push(F(t,a))}t.dimensions=r}function F(t,e){var r,n=t.model.dimensions.length,i=e.displayInd;r=40+(n>1?(t.width-80-16)/(n-1):0)*i;var a,o,s,l,c,u=[],h=t.model.maxCats,f=e.categories.length,p=e.count,d=t.height-8*(h-1),g=8*(h-f)/2,v=e.categories.map(function(t){return{displayInd:t.displayInd,categoryInd:t.categoryInd}});for(v.sort(function(t,e){return t.displayInd-e.displayInd}),c=0;c<f;c++)l=v[c].categoryInd,o=e.categories[l],a=p>0?o.count/p*d:0,s={key:o.valueInds[0],model:o,width:16,height:a,y:null!==o.dragY?o.dragY:g,bands:[],parcatsViewModel:t},g=g+a+8,u.push(s);return{key:e.dimensionInd,x:null!==e.dragX?e.dragX:r,y:0,width:16,model:e,categories:u,parcatsViewModel:t,dragCategoryDisplayInd:null,dragDimensionDisplayInd:null,initialDragDimensionDisplayInds:null,initialDragCategoryDisplayInds:null,dragHasMoved:null,potentialClickBand:null}}e.exports=function(t,e,r,n){u(r,t,n,e)}},{\"../../components/drawing\":614,\"../../components/fx\":632,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_api\":754,d3:163,tinycolor2:537}],1073:[function(t,e,r){\"use strict\";var n=t(\"./parcats\");e.exports=function(t,e,r,i){var a=t._fullLayout,o=a._paper,s=a._size;n(t,o,e,{width:s.w,height:s.h,margin:{t:s.t,r:s.r,b:s.b,l:s.l}},r,i)}},{\"./parcats\":1072}],1074:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/cartesian/layout_attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../plots/domain\").attributes,s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/plot_template\").templatedArray;e.exports={domain:o({name:\"parcoords\",trace:!0,editType:\"plot\"}),labelangle:{valType:\"angle\",dflt:0,editType:\"plot\"},labelside:{valType:\"enumerated\",values:[\"top\",\"bottom\"],dflt:\"top\",editType:\"plot\"},labelfont:a({editType:\"plot\"}),tickfont:a({editType:\"plot\"}),rangefont:a({editType:\"plot\"}),dimensions:l(\"dimension\",{label:{valType:\"string\",editType:\"plot\"},tickvals:s({},i.tickvals,{editType:\"plot\"}),ticktext:s({},i.ticktext,{editType:\"plot\"}),tickformat:s({},i.tickformat,{editType:\"plot\"}),visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},constraintrange:{valType:\"info_array\",freeLength:!0,dimensions:\"1-2\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},multiselect:{valType:\"boolean\",dflt:!0,editType:\"plot\"},values:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"}),line:s({editType:\"calc\"},n(\"line\",{colorscaleDflt:\"Viridis\",autoColorDflt:!1,editTypeOverride:\"calc\"}))}},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1075:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\").keyFun,o=t(\"../../lib/gup\").repeat,s=t(\"../../lib\").sorterAsc,l=n.bar.snapRatio;function c(t,e){return t*(1-l)+e*l}var u=n.bar.snapClose;function h(t,e){return t*(1-u)+e*u}function f(t,e,r,n){if(function(t,e){for(var r=0;r<e.length;r++)if(t>=e[r][0]&&t<=e[r][1])return!0;return!1}(r,n))return r;var i=t?-1:1,a=0,o=e.length-1;if(i<0){var s=a;a=o,o=s}for(var l=e[a],u=l,f=a;i*f<i*o;f+=i){var p=f+i,d=e[p];if(i*r<i*h(l,d))return c(l,u);if(i*r<i*d||p===o)return c(d,l);u=l,l=d}}function p(t){t.attr(\"x\",-n.bar.captureWidth/2).attr(\"width\",n.bar.captureWidth)}function d(t){t.attr(\"visibility\",\"visible\").style(\"visibility\",\"visible\").attr(\"fill\",\"yellow\").attr(\"opacity\",0)}function g(t){if(!t.brush.filterSpecified)return\"0,\"+t.height;for(var e,r,n,i=v(t.brush.filter.getConsolidated(),t.height),a=[0],o=i.length?i[0][0]:null,s=0;s<i.length;s++)r=(e=i[s])[1]-e[0],a.push(o),a.push(r),(n=s+1)<i.length&&(o=i[n][0]-e[1]);return a.push(t.height),a}function v(t,e){return t.map(function(t){return t.map(function(t){return Math.max(0,t*e)}).sort(s)})}function m(){i.select(document.body).style(\"cursor\",null)}function y(t){t.attr(\"stroke-dasharray\",g)}function x(t,e){var r=i.select(t).selectAll(\".highlight, .highlight-shadow\");y(e?r.transition().duration(n.bar.snapDuration).each(\"end\",e):r)}function b(t,e){var r,i=t.brush,a=NaN,o={};if(i.filterSpecified){var s=t.height,l=i.filter.getConsolidated(),c=v(l,s),u=NaN,h=NaN,f=NaN;for(r=0;r<=c.length;r++){var p=c[r];if(p&&p[0]<=e&&e<=p[1]){u=r;break}if(h=r?r-1:NaN,p&&p[0]>e){f=r;break}}if(a=u,isNaN(a)&&(a=isNaN(h)||isNaN(f)?isNaN(h)?f:h:e-c[h][1]<c[f][0]-e?h:f),!isNaN(a)){var d=c[a],g=function(t,e){var r=n.bar.handleHeight;if(!(e>t[1]+r||e<t[0]-r))return e>=.9*t[1]+.1*t[0]?\"n\":e<=.9*t[0]+.1*t[1]?\"s\":\"ns\"}(d,e);g&&(o.interval=l[a],o.intervalPix=d,o.region=g)}}if(t.ordinal&&!o.region){var m=t.unitTickvals,y=t.unitToPaddedPx.invert(e);for(r=0;r<m.length;r++){var x=[.25*m[Math.max(r-1,0)]+.75*m[r],.25*m[Math.min(r+1,m.length-1)]+.75*m[r]];if(y>=x[0]&&y<=x[1]){o.clickableOrdinalRange=x;break}}}return o}function _(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.brush.svgBrush;a.wasDragged=!0,a._dragging=!0,a.grabbingBar?a.newExtent=[r-a.grabPoint,r+a.barLength-a.grabPoint].map(e.unitToPaddedPx.invert):a.newExtent=[a.startExtent,e.unitToPaddedPx.invert(r)].sort(s),e.brush.filterSpecified=!0,a.extent=a.stayingIntervals.concat([a.newExtent]),a.brushCallback(e),x(t.parentNode)}function w(t,e){var r=b(e,e.height-i.mouse(t)[1]-2*n.verticalPadding),a=\"crosshair\";r.clickableOrdinalRange?a=\"pointer\":r.region&&(a=r.region+\"-resize\"),i.select(document.body).style(\"cursor\",a)}function k(t){t.on(\"mousemove\",function(t){i.event.preventDefault(),t.parent.inBrushDrag||w(this,t)}).on(\"mouseleave\",function(t){t.parent.inBrushDrag||m()}).call(i.behavior.drag().on(\"dragstart\",function(t){!function(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.unitToPaddedPx.invert(r),o=e.brush,s=b(e,r),l=s.interval,c=o.svgBrush;if(c.wasDragged=!1,c.grabbingBar=\"ns\"===s.region,c.grabbingBar){var u=l.map(e.unitToPaddedPx);c.grabPoint=r-u[0]-n.verticalPadding,c.barLength=u[1]-u[0]}c.clickableOrdinalRange=s.clickableOrdinalRange,c.stayingIntervals=e.multiselect&&o.filterSpecified?o.filter.getConsolidated():[],l&&(c.stayingIntervals=c.stayingIntervals.filter(function(t){return t[0]!==l[0]&&t[1]!==l[1]})),c.startExtent=s.region?l[\"s\"===s.region?1:0]:a,e.parent.inBrushDrag=!0,c.brushStartCallback()}(this,t)}).on(\"drag\",function(t){_(this,t)}).on(\"dragend\",function(t){!function(t,e){var r=e.brush,n=r.filter,a=r.svgBrush;a._dragging||(w(t,e),_(t,e),e.brush.svgBrush.wasDragged=!1),a._dragging=!1,i.event.sourceEvent.stopPropagation();var o=a.grabbingBar;if(a.grabbingBar=!1,a.grabLocation=void 0,e.parent.inBrushDrag=!1,m(),!a.wasDragged)return a.wasDragged=void 0,a.clickableOrdinalRange?r.filterSpecified&&e.multiselect?a.extent.push(a.clickableOrdinalRange):(a.extent=[a.clickableOrdinalRange],r.filterSpecified=!0):o?(a.extent=a.stayingIntervals,0===a.extent.length&&A(r)):A(r),a.brushCallback(e),x(t.parentNode),void a.brushEndCallback(r.filterSpecified?n.getConsolidated():[]);var s=function(){n.set(n.getConsolidated())};if(e.ordinal){var l=e.unitTickvals;l[l.length-1]<l[0]&&l.reverse(),a.newExtent=[f(0,l,a.newExtent[0],a.stayingIntervals),f(1,l,a.newExtent[1],a.stayingIntervals)];var c=a.newExtent[1]>a.newExtent[0];a.extent=a.stayingIntervals.concat(c?[a.newExtent]:[]),a.extent.length||A(r),a.brushCallback(e),c?x(t.parentNode,s):(s(),x(t.parentNode))}else s();a.brushEndCallback(r.filterSpecified?n.getConsolidated():[])}(this,t)}))}function T(t,e){return t[0]-e[0]}function A(t){t.filterSpecified=!1,t.svgBrush.extent=[[-1/0,1/0]]}function M(t){for(var e,r=t.slice(),n=[],i=r.shift();i;){for(e=i.slice();(i=r.shift())&&i[0]<=e[1];)e[1]=Math.max(e[1],i[1]);n.push(e)}return n}e.exports={makeBrush:function(t,e,r,n,i,a){var o,l=function(){var t,e,r=[];return{set:function(n){1===(r=n.map(function(t){return t.slice().sort(s)}).sort(T)).length&&r[0][0]===-1/0&&r[0][1]===1/0&&(r=[[0,-1]]),t=M(r),e=r.reduce(function(t,e){return[Math.min(t[0],e[0]),Math.max(t[1],e[1])]},[1/0,-1/0])},get:function(){return r.slice()},getConsolidated:function(){return t},getBounds:function(){return e}}}();return l.set(r),{filter:l,filterSpecified:e,svgBrush:{extent:[],brushStartCallback:n,brushCallback:(o=i,function(t){var e=t.brush,r=function(t){return t.svgBrush.extent.map(function(t){return t.slice()})}(e).slice();e.filter.set(r),o()}),brushEndCallback:a}}},ensureAxisBrush:function(t){var e=t.selectAll(\".\"+n.cn.axisBrush).data(o,a);e.enter().append(\"g\").classed(n.cn.axisBrush,!0),function(t){var e=t.selectAll(\".background\").data(o);e.enter().append(\"rect\").classed(\"background\",!0).call(p).call(d).style(\"pointer-events\",\"auto\").attr(\"transform\",\"translate(0 \"+n.verticalPadding+\")\"),e.call(k).attr(\"height\",function(t){return t.height-n.verticalPadding});var r=t.selectAll(\".highlight-shadow\").data(o);r.enter().append(\"line\").classed(\"highlight-shadow\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width+n.bar.strokeWidth).attr(\"stroke\",n.bar.strokeColor).attr(\"opacity\",n.bar.strokeOpacity).attr(\"stroke-linecap\",\"butt\"),r.attr(\"y1\",function(t){return t.height}).call(y);var i=t.selectAll(\".highlight\").data(o);i.enter().append(\"line\").classed(\"highlight\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width-n.bar.strokeWidth).attr(\"stroke\",n.bar.fillColor).attr(\"opacity\",n.bar.fillOpacity).attr(\"stroke-linecap\",\"butt\"),i.attr(\"y1\",function(t){return t.height}).call(y)}(e)},cleanRanges:function(t,e){if(Array.isArray(t[0])?(t=t.map(function(t){return t.sort(s)}),t=e.multiselect?M(t.sort(T)):[t[0]]):t=[t.sort(s)],e.tickvals){var r=e.tickvals.slice().sort(s);if(!(t=t.map(function(t){var e=[f(0,r,t[0],[]),f(1,r,t[1],[])];if(e[1]>e[0])return e}).filter(function(t){return t})).length)return}return t.length>1?t:t[0]}}},{\"../../lib\":719,\"../../lib/gup\":717,\"./constants\":1078,d3:163}],1076:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../constants/xmlns_namespaces\");r.name=\"parcoords\",r.plot=function(t){var e=i(t.calcdata,\"parcoords\")[0];e.length&&a(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcoords\"),a=e._has&&e._has(\"parcoords\");i&&!a&&(n._paperdiv.selectAll(\".parcoords\").remove(),n._glimages.selectAll(\"*\").remove())},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter(function(t,e){return e===r.size()-1}).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each(function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})}),window.setTimeout(function(){n.selectAll(\"#filterBarPattern\").attr(\"id\",\"filterBarPattern\")},60)}},{\"../../constants/xmlns_namespaces\":696,\"../../plots/get_data\":802,\"./plot\":1085,d3:163}],1077:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale\"),a=t(\"../../lib/gup\").wrap;e.exports=function(t,e){var r,o;return i.hasColorscale(e,\"line\")&&n(e.line.color)?(r=e.line.color,o=i.extractOpts(e.line).colorscale,i.calc(t,e,{vals:r,containerStr:\"line\",cLetter:\"c\"})):(r=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=.5;return e}(e._length),o=[[0,e.line.color],[1,e.line.color]]),a({lineColor:r,cscale:o})}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gup\":717}],1078:[function(t,e,r){\"use strict\";e.exports={maxDimensionCount:60,overdrag:45,verticalPadding:2,tickDistance:50,canvasPixelRatio:1,blockLineCount:5e3,layers:[\"contextLineLayer\",\"focusLineLayer\",\"pickLineLayer\"],axisTitleOffset:28,axisExtentOffset:10,deselectedLineColor:\"#777\",bar:{width:4,captureWidth:10,fillColor:\"magenta\",fillOpacity:1,snapDuration:150,snapRatio:.25,snapClose:.01,strokeColor:\"white\",strokeOpacity:1,strokeWidth:1,handleHeight:8,handleOpacity:1,handleOverlap:0},cn:{axisExtentText:\"axis-extent-text\",parcoordsLineLayers:\"parcoords-line-layers\",parcoordsLineLayer:\"parcoords-lines\",parcoords:\"parcoords\",parcoordsControlView:\"parcoords-control-view\",yAxis:\"y-axis\",axisOverlays:\"axis-overlays\",axis:\"axis\",axisHeading:\"axis-heading\",axisTitle:\"axis-title\",axisExtent:\"axis-extent\",axisExtentTop:\"axis-extent-top\",axisExtentTopText:\"axis-extent-top-text\",axisExtentBottom:\"axis-extent-bottom\",axisExtentBottomText:\"axis-extent-bottom-text\",axisBrush:\"axis-brush\"},id:{filterBarPattern:\"filter-bar-pattern\"}}},{}],1079:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"../../plots/cartesian/axes\"),c=t(\"./attributes\"),u=t(\"./axisbrush\"),h=t(\"./constants\").maxDimensionCount,f=t(\"./merge_length\");function p(t,e,r,i){function a(r,i){return n.coerce(t,e,c.dimensions,r,i)}var o=a(\"values\"),s=a(\"visible\");if(o&&o.length||(s=e.visible=!1),s){a(\"label\"),a(\"tickvals\"),a(\"ticktext\"),a(\"tickformat\");var h=a(\"range\");e._ax={_id:\"y\",type:\"linear\",showexponent:\"all\",exponentformat:\"B\",range:h},l.setConvert(e._ax,i.layout),a(\"multiselect\");var f=a(\"constraintrange\");f&&(e.constraintrange=u.cleanRanges(f,e))}}e.exports=function(t,e,r,l){function u(r,i){return n.coerce(t,e,c,r,i)}var d=t.dimensions;Array.isArray(d)&&d.length>h&&(n.log(\"parcoords traces support up to \"+h+\" dimensions at the moment\"),d.splice(h));var g=s(t,e,{name:\"dimensions\",layout:l,handleItemDefaults:p}),v=function(t,e,r,o,s){var l=s(\"line.color\",r);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,l,u);o(e,l,u),Array.isArray(g)&&g.length||(e.visible=!1),f(e,g,\"values\",v);var m={family:l.font.family,size:Math.round(l.font.size/1.2),color:l.font.color};n.coerceFont(u,\"labelfont\",m),n.coerceFont(u,\"tickfont\",m),n.coerceFont(u,\"rangefont\",m),u(\"labelangle\"),u(\"labelside\")}},{\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"../../plots/domain\":792,\"./attributes\":1074,\"./axisbrush\":1075,\"./constants\":1078,\"./merge_length\":1083}],1080:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isTypedArray;r.convertTypedArray=function(t){return n(t)?Array.prototype.slice.call(t):t},r.isOrdinal=function(t){return!!t.tickvals},r.isVisible=function(t){return t.visible||!(\"visible\"in t)}},{\"../../lib\":719}],1081:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcoords\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"noOpacity\",\"noHover\"],meta:{}}},{\"./attributes\":1074,\"./base_plot\":1076,\"./calc\":1077,\"./defaults\":1079,\"./plot\":1085}],1082:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nattribute vec4 p01_04, p05_08, p09_12, p13_16,\\n               p17_20, p21_24, p25_28, p29_32,\\n               p33_36, p37_40, p41_44, p45_48,\\n               p49_52, p53_56, p57_60, colors;\\n\\nuniform mat4 dim0A, dim1A, dim0B, dim1B, dim0C, dim1C, dim0D, dim1D,\\n             loA, hiA, loB, hiB, loC, hiC, loD, hiD;\\n\\nuniform vec2 resolution, viewBoxPos, viewBoxSize;\\nuniform sampler2D mask, palette;\\nuniform float maskHeight;\\nuniform float drwLayer; // 0: context, 1: focus, 2: pick\\nuniform vec4 contextColor;\\n\\nbool isPick    = (drwLayer > 1.5);\\nbool isContext = (drwLayer < 0.5);\\n\\nconst vec4 ZEROS = vec4(0.0, 0.0, 0.0, 0.0);\\nconst vec4 UNITS = vec4(1.0, 1.0, 1.0, 1.0);\\n\\nfloat val(mat4 p, mat4 v) {\\n    return dot(matrixCompMult(p, v) * UNITS, UNITS);\\n}\\n\\nfloat axisY(float ratio, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float y1 = val(A, dim0A) + val(B, dim0B) + val(C, dim0C) + val(D, dim0D);\\n    float y2 = val(A, dim1A) + val(B, dim1B) + val(C, dim1C) + val(D, dim1D);\\n    return y1 * (1.0 - ratio) + y2 * ratio;\\n}\\n\\nint iMod(int a, int b) {\\n    return a - b * (a / b);\\n}\\n\\nbool fOutside(float p, float lo, float hi) {\\n    return (lo < hi) && (lo > p || p > hi);\\n}\\n\\nbool vOutside(vec4 p, vec4 lo, vec4 hi) {\\n    return (\\n        fOutside(p[0], lo[0], hi[0]) ||\\n        fOutside(p[1], lo[1], hi[1]) ||\\n        fOutside(p[2], lo[2], hi[2]) ||\\n        fOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool mOutside(mat4 p, mat4 lo, mat4 hi) {\\n    return (\\n        vOutside(p[0], lo[0], hi[0]) ||\\n        vOutside(p[1], lo[1], hi[1]) ||\\n        vOutside(p[2], lo[2], hi[2]) ||\\n        vOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool outsideBoundingBox(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    return mOutside(A, loA, hiA) ||\\n           mOutside(B, loB, hiB) ||\\n           mOutside(C, loC, hiC) ||\\n           mOutside(D, loD, hiD);\\n}\\n\\nbool outsideRasterMask(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    mat4 pnts[4];\\n    pnts[0] = A;\\n    pnts[1] = B;\\n    pnts[2] = C;\\n    pnts[3] = D;\\n\\n    for(int i = 0; i < 4; ++i) {\\n        for(int j = 0; j < 4; ++j) {\\n            for(int k = 0; k < 4; ++k) {\\n                if(0 == iMod(\\n                    int(255.0 * texture2D(mask,\\n                        vec2(\\n                            (float(i * 2 + j / 2) + 0.5) / 8.0,\\n                            (pnts[i][j][k] * (maskHeight - 1.0) + 1.0) / maskHeight\\n                        ))[3]\\n                    ) / int(pow(2.0, float(iMod(j * 4 + k, 8)))),\\n                    2\\n                )) return true;\\n            }\\n        }\\n    }\\n    return false;\\n}\\n\\nvec4 position(bool isContext, float v, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float x = 0.5 * sign(v) + 0.5;\\n    float y = axisY(x, A, B, C, D);\\n    float z = 1.0 - abs(v);\\n\\n    z += isContext ? 0.0 : 2.0 * float(\\n        outsideBoundingBox(A, B, C, D) ||\\n        outsideRasterMask(A, B, C, D)\\n    );\\n\\n    return vec4(\\n        2.0 * (vec2(x, y) * viewBoxSize + viewBoxPos) / resolution - 1.0,\\n        z,\\n        1.0\\n    );\\n}\\n\\nvoid main() {\\n    mat4 A = mat4(p01_04, p05_08, p09_12, p13_16);\\n    mat4 B = mat4(p17_20, p21_24, p25_28, p29_32);\\n    mat4 C = mat4(p33_36, p37_40, p41_44, p45_48);\\n    mat4 D = mat4(p49_52, p53_56, p57_60, ZEROS);\\n\\n    float v = colors[3];\\n\\n    gl_Position = position(isContext, v, A, B, C, D);\\n\\n    fragColor =\\n        isContext ? vec4(contextColor) :\\n        isPick ? vec4(colors.rgb, 1.0) : texture2D(palette, vec2(abs(v), 0.5));\\n}\\n\"]),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n    gl_FragColor = fragColor;\\n}\\n\"]),o=t(\"./constants\").maxDimensionCount,s=t(\"../../lib\"),l=1e-6,c=2048,u=new Uint8Array(4),h=new Uint8Array(4),f={shape:[256,1],format:\"rgba\",type:\"uint8\",mag:\"nearest\",min:\"nearest\"};function p(t,e,r,n,i){var a=t._gl;a.enable(a.SCISSOR_TEST),a.scissor(e,r,n,i),t.clear({color:[0,0,0,0],depth:1})}function d(t,e,r,n,i,a){var o=a.key;r.drawCompleted||(!function(t){t.read({x:0,y:0,width:1,height:1,data:u})}(t),r.drawCompleted=!0),function s(l){var c=Math.min(n,i-l*n);0===l&&(window.cancelAnimationFrame(r.currentRafs[o]),delete r.currentRafs[o],p(t,a.scissorX,a.scissorY,a.scissorWidth,a.viewBoxSize[1])),r.clearOnly||(a.count=2*c,a.offset=2*l*n,e(a),l*n+c<i&&(r.currentRafs[o]=window.requestAnimationFrame(function(){s(l+1)})),r.drawCompleted=!1)}(0)}function g(t,e){return(t>>>8*e)%256/255}function v(t,e,r){for(var n=new Array(8*e),i=0,a=0;a<e;a++)for(var o=0;o<2;o++)for(var s=0;s<4;s++){var l=4*t+s,c=r[64*a+l];63===l&&0===o&&(c*=-1),n[i++]=c}return n}function m(t){var e=\"0\"+t;return e.substr(e.length-2)}function y(t){return t<o?\"p\"+m(t+1)+\"_\"+m(t+4):\"colors\"}function x(t,e,r,n,i,a,o,l,c,u,h,f,p){for(var d=[[],[]],g=0;g<64;g++)d[0][g]=g===i?1:0,d[1][g]=g===a?1:0;var v=t.lines.canvasOverdrag,m=t.domain,y=t.canvasWidth,x=t.canvasHeight,b=t.deselectedLines.color;return s.extendFlat({key:h,resolution:[y,x],viewBoxPos:[o+v,l],viewBoxSize:[c,u],i0:i,i1:a,dim0A:d[0].slice(0,16),dim0B:d[0].slice(16,32),dim0C:d[0].slice(32,48),dim0D:d[0].slice(48,64),dim1A:d[1].slice(0,16),dim1B:d[1].slice(16,32),dim1C:d[1].slice(32,48),dim1D:d[1].slice(48,64),drwLayer:f,contextColor:[b[0]/255,b[1]/255,b[2]/255,b[3]<1?b[3]:Math.max(1/255,Math.pow(1/t.lines.color.length,1/3))],scissorX:(n===e?0:o+v)+(t.pad.l-v)+t.layoutWidth*m.x[0],scissorWidth:(n===r?y-o+v:c+.5)+(n===e?o+v:0),scissorY:l+t.pad.b+t.layoutHeight*m.y[0],scissorHeight:u,viewportX:t.pad.l-v+t.layoutWidth*m.x[0],viewportY:t.pad.b+t.layoutHeight*m.y[0],viewportWidth:y,viewportHeight:x},p)}function b(t){var e=c-1,r=Math.max(0,Math.floor(t[0]*e),0),n=Math.min(e,Math.ceil(t[1]*e),e);return[Math.min(r,n),Math.max(r,n)]}e.exports=function(t,e){var r,n,u,m,_,w=e.context,k=e.pick,T=e.regl,A={currentRafs:{},drawCompleted:!0,clearOnly:!1},M=function(t){for(var e={},r=0;r<=o;r+=4)e[y(r)]=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)});return e}(T),S=T.texture(f),E=[];L(e);var C=T({profile:!1,blend:{enable:w,func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:1,dstAlpha:1},equation:{rgb:\"add\",alpha:\"add\"},color:[0,0,0,0]},depth:{enable:!w,mask:!0,func:\"less\",range:[0,1]},cull:{enable:!0,face:\"back\"},scissor:{enable:!0,box:{x:T.prop(\"scissorX\"),y:T.prop(\"scissorY\"),width:T.prop(\"scissorWidth\"),height:T.prop(\"scissorHeight\")}},viewport:{x:T.prop(\"viewportX\"),y:T.prop(\"viewportY\"),width:T.prop(\"viewportWidth\"),height:T.prop(\"viewportHeight\")},dither:!1,vert:i,frag:a,primitive:\"lines\",lineWidth:1,attributes:M,uniforms:{resolution:T.prop(\"resolution\"),viewBoxPos:T.prop(\"viewBoxPos\"),viewBoxSize:T.prop(\"viewBoxSize\"),dim0A:T.prop(\"dim0A\"),dim1A:T.prop(\"dim1A\"),dim0B:T.prop(\"dim0B\"),dim1B:T.prop(\"dim1B\"),dim0C:T.prop(\"dim0C\"),dim1C:T.prop(\"dim1C\"),dim0D:T.prop(\"dim0D\"),dim1D:T.prop(\"dim1D\"),loA:T.prop(\"loA\"),hiA:T.prop(\"hiA\"),loB:T.prop(\"loB\"),hiB:T.prop(\"hiB\"),loC:T.prop(\"loC\"),hiC:T.prop(\"hiC\"),loD:T.prop(\"loD\"),hiD:T.prop(\"hiD\"),palette:S,contextColor:T.prop(\"contextColor\"),mask:T.prop(\"maskTexture\"),drwLayer:T.prop(\"drwLayer\"),maskHeight:T.prop(\"maskHeight\")},offset:T.prop(\"offset\"),count:T.prop(\"count\")});function L(t){r=t.model,n=t.viewModel,u=n.dimensions.slice(),m=u[0]?u[0].values.length:0;var e=r.lines,i=k?e.color.map(function(t,r){return r/e.color.length}):e.color,a=function(t,e,r){for(var n,i=new Array(t*(o+4)),a=0,s=0;s<t;s++){for(var c=0;c<o;c++)i[a++]=c<e.length?e[c].paddedUnitValues[s]:.5;i[a++]=g(s,2),i[a++]=g(s,1),i[a++]=g(s,0),i[a++]=(n=r[s],Math.max(l,Math.min(1-l,n)))}return i}(m,u,i);!function(t,e,r){for(var n=0;n<=o;n+=4)t[y(n)](v(n/4,e,r))}(M,m,a),w||k||(S=T.texture(s.extendFlat({data:function(t,e){for(var r=new Array(256),n=0;n<256;n++)r[n]=t(n/255).concat(e);return r}(r.unitToColor,255)},f)))}return{render:function(t,e,n){var i,a,o,s=t.length,l=1/0,h=-1/0;for(i=0;i<s;i++)t[i].dim0.canvasX<l&&(l=t[i].dim0.canvasX,a=i),t[i].dim1.canvasX>h&&(h=t[i].dim1.canvasX,o=i);0===s&&p(T,0,0,r.canvasWidth,r.canvasHeight);var f=function(t){var e,r,n,i=[[],[]];for(n=0;n<64;n++){var a=!t&&n<u.length?u[n].brush.filter.getBounds():[-1/0,1/0];i[0][n]=a[0],i[1][n]=a[1]}var o=8*c,s=new Array(o);for(e=0;e<o;e++)s[e]=255;if(!t)for(e=0;e<u.length;e++){var l=e%8,h=(e-l)/8,f=Math.pow(2,l),p=u[e].brush.filter.get();if(!(p.length<2)){var d=b(p[0])[1];for(r=1;r<p.length;r++){var g=b(p[r]);for(n=d+1;n<g[0];n++)s[8*n+h]&=~f;d=Math.max(d,g[1])}}}var v={shape:[8,c],format:\"alpha\",type:\"uint8\",mag:\"nearest\",min:\"nearest\",data:s};return _?_(v):_=T.texture(v),{maskTexture:_,maskHeight:c,loA:i[0].slice(0,16),loB:i[0].slice(16,32),loC:i[0].slice(32,48),loD:i[0].slice(48,64),hiA:i[1].slice(0,16),hiB:i[1].slice(16,32),hiC:i[1].slice(32,48),hiD:i[1].slice(48,64)}}(w);for(i=0;i<s;i++){var g=t[i],v=g.dim0.crossfilterDimensionIndex,y=g.dim1.crossfilterDimensionIndex,M=g.canvasX,S=g.canvasY,L=M+g.panelSizeX;if(e||!E[v]||E[v][0]!==M||E[v][1]!==L){E[v]=[M,L];var P=x(r,a,o,i,v,y,M,S,g.panelSizeX,g.panelSizeY,g.dim0.crossfilterDimensionIndex,w?0:k?2:1,f);A.clearOnly=n;var O=e?r.lines.blockLineCount:m;d(T,C,A,O,m,P)}}},readPixel:function(t,e){return T.read({x:t,y:e,width:1,height:1,data:h}),h},readPixels:function(t,e,r,n){var i=new Uint8Array(4*r*n);return T.read({x:t,y:e,width:r,height:n,data:i}),i},destroy:function(){for(var e in t.style[\"pointer-events\"]=\"none\",S.destroy(),_&&_.destroy(),M)M[e].destroy()},update:L}}},{\"../../lib\":719,\"./constants\":1078,glslify:409}],1083:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a;for(n||(n=1/0),i=0;i<e.length;i++)(a=e[i]).visible&&(n=Math.min(n,a[r].length));for(n===1/0&&(n=0),t._length=n,i=0;i<e.length;i++)(a=e[i]).visible&&(a._length=n);return n}},{}],1084:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"color-rgba\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../components/drawing\"),c=t(\"../../components/colorscale\"),u=t(\"../../lib/gup\"),h=u.keyFun,f=u.repeat,p=u.unwrap,d=t(\"./helpers\"),g=t(\"./constants\"),v=t(\"./axisbrush\"),m=t(\"./lines\");function y(t,e,r){return o.aggNums(t,null,e,r)}function x(t,e){return _(y(Math.min,t,e),y(Math.max,t,e))}function b(t){var e=t.range;return e?_(e[0],e[1]):x(t.values,t._length)}function _(t,e){return!isNaN(t)&&isFinite(t)||(t=0),!isNaN(e)&&isFinite(e)||(e=0),t===e&&(0===t?(t-=1,e+=1):(t*=.9,e*=1.1)),[t,e]}function w(t){return t.dimensions.some(function(t){return t.brush.filterSpecified})}function k(t,e,r){var a=p(e),s=a.trace,l=d.convertTypedArray(a.lineColor),u=s.line,h={color:i(g.deselectedLineColor)},f=c.extractOpts(u),v=f.reversescale?c.flipScale(a.cscale):a.cscale,m=s.domain,y=s.dimensions,x=t.width,_=s.labelangle,w=s.labelside,k=s.labelfont,T=s.tickfont,A=s.rangefont,M=o.extendDeepNoArrays({},u,{color:l.map(n.scale.linear().domain(b({values:l,range:[f.min,f.max],_length:s._length}))),blockLineCount:g.blockLineCount,canvasOverdrag:g.overdrag*g.canvasPixelRatio}),S=Math.floor(x*(m.x[1]-m.x[0])),E=Math.floor(t.height*(m.y[1]-m.y[0])),C=t.margin||{l:80,r:80,t:100,b:80},L=S,P=E;return{key:r,colCount:y.filter(d.isVisible).length,dimensions:y,tickDistance:g.tickDistance,unitToColor:function(t){var e=t.map(function(t){return t[0]}),r=t.map(function(t){var e=i(t[1]);return n.rgb(\"rgb(\"+e[0]+\",\"+e[1]+\",\"+e[2]+\")\")}),a=\"rgb\".split(\"\").map(function(t){return n.scale.linear().clamp(!0).domain(e).range(r.map((i=t,function(t){return t[i]})));var i});return function(t){return a.map(function(e){return e(t)})}}(v),lines:M,deselectedLines:h,labelAngle:_,labelSide:w,labelFont:k,tickFont:T,rangeFont:A,layoutWidth:x,layoutHeight:t.height,domain:m,translateX:m.x[0]*x,translateY:t.height-m.y[1]*t.height,pad:C,canvasWidth:L*g.canvasPixelRatio+2*M.canvasOverdrag,canvasHeight:P*g.canvasPixelRatio,width:L,height:P,canvasPixelRatio:g.canvasPixelRatio}}function T(t,e,r){var i=r.width,a=r.height,s=r.dimensions,l=r.canvasPixelRatio,c=function(t){return i*t/Math.max(1,r.colCount-1)},u=g.verticalPadding/a,h=function(t,e){return n.scale.linear().range([e,t-e])}(a,g.verticalPadding),f={key:r.key,xScale:c,model:r,inBrushDrag:!1},p={};return f.dimensions=s.filter(d.isVisible).map(function(i,s){var m=function(t,e){return n.scale.linear().domain(b(t)).range([e,1-e])}(i,u),y=p[i.label];p[i.label]=(y||0)+1;var x=i.label+(y?\"__\"+y:\"\"),_=i.constraintrange,k=_&&_.length;k&&!Array.isArray(_[0])&&(_=[_]);var T=k?_.map(function(t){return t.map(m)}):[[-1/0,1/0]],A=i.values;A.length>i._length&&(A=A.slice(0,i._length));var M,S=i.tickvals;function E(t,e){return{val:t,text:M[e]}}function C(t,e){return t.val-e.val}if(Array.isArray(S)&&S.length){M=i.ticktext,Array.isArray(M)&&M.length?M.length>S.length?M=M.slice(0,S.length):S.length>M.length&&(S=S.slice(0,M.length)):M=S.map(n.format(i.tickformat));for(var L=1;L<S.length;L++)if(S[L]<S[L-1]){for(var P=S.map(E).sort(C),O=0;O<S.length;O++)S[O]=P[O].val,M[O]=P[O].text;break}}else S=void 0;return A=d.convertTypedArray(A),A=d.convertTypedArray(A),{key:x,label:i.label,tickFormat:i.tickformat,tickvals:S,ticktext:M,ordinal:d.isOrdinal(i),multiselect:i.multiselect,xIndex:s,crossfilterDimensionIndex:s,visibleIndex:i._index,height:a,values:A,paddedUnitValues:A.map(m),unitTickvals:S&&S.map(m),xScale:c,x:c(s),canvasX:c(s)*l,unitToPaddedPx:h,domainScale:function(t,e,r,i,a){var o,s,l=b(r);return i?n.scale.ordinal().domain(i.map((o=n.format(r.tickformat),s=a,s?function(t,e){var r=s[e];return null==r?o(t):r}:o))).range(i.map(function(r){var n=(r-l[0])/(l[1]-l[0]);return t-e+n*(2*e-t)})):n.scale.linear().domain(l).range([t-e,e])}(a,g.verticalPadding,i,S,M),ordinalScale:function(t){if(t.tickvals){var e=b(t);return n.scale.ordinal().domain(t.tickvals).range(t.tickvals.map(function(t){return(t-e[0])/(e[1]-e[0])}))}}(i),parent:f,model:r,brush:v.makeBrush(t,k,T,function(){t.linePickActive(!1)},function(){var e=f;e.focusLayer&&e.focusLayer.render(e.panels,!0);var r=w(e);!t.contextShown()&&r?(e.contextLayer&&e.contextLayer.render(e.panels,!0),t.contextShown(!0)):t.contextShown()&&!r&&(e.contextLayer&&e.contextLayer.render(e.panels,!0,!0),t.contextShown(!1))},function(r){if(f.focusLayer.render(f.panels,!0),f.pickLayer&&f.pickLayer.render(f.panels,!0),t.linePickActive(!0),e&&e.filterChanged){var n=m.invert,a=r.map(function(t){return t.map(n).sort(o.sorterAsc)}).sort(function(t,e){return t[0]-e[0]});e.filterChanged(f.key,i._index,a)}})}}),f}function A(t){t.classed(g.cn.axisExtentText,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"default\").style(\"user-select\",\"none\")}function M(t,e){var r=\"top\"===e?1:-1,n=t*Math.PI/180;return{dir:r,dx:Math.sin(n),dy:Math.cos(n),degrees:t}}function S(t,e){for(var r=e.panels||(e.panels=[]),n=t.data(),i=0;i<n.length-1;i++){var a=r[i]||(r[i]={}),o=n[i],s=n[i+1];a.dim0=o,a.dim1=s,a.canvasX=o.canvasX,a.panelSizeX=s.canvasX-o.canvasX,a.panelSizeY=e.model.canvasHeight,a.y=0,a.canvasY=0}}function E(t,e){return a.tickText(t._ax,e,!1).text}function C(t,e){if(t.ordinal)return\"\";var r=t.domainScale.domain(),n=r[e?r.length-1:0];return E(t.model.dimensions[t.visibleIndex],n)}e.exports=function(t,e,r,i){var c=t._fullLayout,u=c._toppaper,y=c._glcontainer;!function(t){for(var e=0;e<t.length;e++)for(var r=0;r<t[e].length;r++)for(var n=t[e][r].trace,i=n.dimensions,o=0;o<i.length;o++){var s=i[o].values,l=i[o]._ax;l&&(l.range?l.range=_(l.range[0],l.range[1]):l.range=x(s,n._length),l.dtick||(l.dtick=.01*(Math.abs(l.range[1]-l.range[0])||1)),l.tickformat=i[o].tickformat,a.calcTicks(l),l.cleanRange())}}(e);var b,L,P=(b=!0,L=!1,{linePickActive:function(t){return arguments.length?b=!!t:b},contextShown:function(t){return arguments.length?L=!!t:L}}),O=e.filter(function(t){return p(t).trace.visible}).map(k.bind(0,r)).map(T.bind(0,P,i));y.each(function(t,e){return o.extendFlat(t,O[e])});var z=y.selectAll(\".gl-canvas\").each(function(t){t.viewModel=O[0],t.model=t.viewModel?t.viewModel.model:null}),I=null;z.filter(function(t){return t.pick}).style(\"pointer-events\",\"auto\").on(\"mousemove\",function(t){if(P.linePickActive()&&t.lineLayer&&i&&i.hover){var e=n.event,r=this.width,a=this.height,o=n.mouse(this),s=o[0],l=o[1];if(s<0||l<0||s>=r||l>=a)return;var c=t.lineLayer.readPixel(s,a-1-l),u=0!==c[3],h=u?c[2]+256*(c[1]+256*c[0]):null,f={x:s,y:l,clientX:e.clientX,clientY:e.clientY,dataIndex:t.model.key,curveNumber:h};h!==I&&(u?i.hover(f):i.unhover&&i.unhover(f),I=h)}}),z.style(\"opacity\",function(t){return t.pick?0:1}),u.style(\"background\",\"rgba(255, 255, 255, 0)\");var D=u.selectAll(\".\"+g.cn.parcoords).data(O,h);D.exit().remove(),D.enter().append(\"g\").classed(g.cn.parcoords,!0).style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"none\"),D.attr(\"transform\",function(t){return\"translate(\"+t.model.translateX+\",\"+t.model.translateY+\")\"});var R=D.selectAll(\".\"+g.cn.parcoordsControlView).data(f,h);R.enter().append(\"g\").classed(g.cn.parcoordsControlView,!0),R.attr(\"transform\",function(t){return\"translate(\"+t.model.pad.l+\",\"+t.model.pad.t+\")\"});var F=R.selectAll(\".\"+g.cn.yAxis).data(function(t){return t.dimensions},h);F.enter().append(\"g\").classed(g.cn.yAxis,!0),R.each(function(t){S(F,t)}),z.each(function(t){if(t.viewModel){!t.lineLayer||i?t.lineLayer=m(this,t):t.lineLayer.update(t),(t.key||0===t.key)&&(t.viewModel[t.key]=t.lineLayer);var e=!t.context||i;t.lineLayer.render(t.viewModel.panels,e)}}),F.attr(\"transform\",function(t){return\"translate(\"+t.xScale(t.xIndex)+\", 0)\"}),F.call(n.behavior.drag().origin(function(t){return t}).on(\"drag\",function(t){var e=t.parent;P.linePickActive(!1),t.x=Math.max(-g.overdrag,Math.min(t.model.width+g.overdrag,n.event.x)),t.canvasX=t.x*t.model.canvasPixelRatio,F.sort(function(t,e){return t.x-e.x}).each(function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e.xIndex),e.canvasX=e.x*e.model.canvasPixelRatio}),S(F,e),F.filter(function(e){return 0!==Math.abs(t.xIndex-e.xIndex)}).attr(\"transform\",function(t){return\"translate(\"+t.xScale(t.xIndex)+\", 0)\"}),n.select(this).attr(\"transform\",\"translate(\"+t.x+\", 0)\"),F.each(function(r,n,i){i===t.parent.key&&(e.dimensions[n]=r)}),e.contextLayer&&e.contextLayer.render(e.panels,!1,!w(e)),e.focusLayer.render&&e.focusLayer.render(e.panels)}).on(\"dragend\",function(t){var e=t.parent;t.x=t.xScale(t.xIndex),t.canvasX=t.x*t.model.canvasPixelRatio,S(F,e),n.select(this).attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),e.contextLayer&&e.contextLayer.render(e.panels,!1,!w(e)),e.focusLayer&&e.focusLayer.render(e.panels),e.pickLayer&&e.pickLayer.render(e.panels,!0),P.linePickActive(!0),i&&i.axesMoved&&i.axesMoved(e.key,e.dimensions.map(function(t){return t.crossfilterDimensionIndex}))})),F.exit().remove();var B=F.selectAll(\".\"+g.cn.axisOverlays).data(f,h);B.enter().append(\"g\").classed(g.cn.axisOverlays,!0),B.selectAll(\".\"+g.cn.axis).remove();var N=B.selectAll(\".\"+g.cn.axis).data(f,h);N.enter().append(\"g\").classed(g.cn.axis,!0),N.each(function(t){var e=t.model.height/t.model.tickDistance,r=t.domainScale,i=r.domain();n.select(this).call(n.svg.axis().orient(\"left\").tickSize(4).outerTickSize(2).ticks(e,t.tickFormat).tickValues(t.ordinal?i:null).tickFormat(function(e){return d.isOrdinal(t)?e:E(t.model.dimensions[t.visibleIndex],e)}).scale(r)),l.font(N.selectAll(\"text\"),t.model.tickFont)}),N.selectAll(\".domain, .tick>line\").attr(\"fill\",\"none\").attr(\"stroke\",\"black\").attr(\"stroke-opacity\",.25).attr(\"stroke-width\",\"1px\"),N.selectAll(\"text\").style(\"text-shadow\",\"1px 1px 1px #fff, -1px -1px 1px #fff, 1px -1px 1px #fff, -1px 1px 1px #fff\").style(\"cursor\",\"default\").style(\"user-select\",\"none\");var j=B.selectAll(\".\"+g.cn.axisHeading).data(f,h);j.enter().append(\"g\").classed(g.cn.axisHeading,!0);var U=j.selectAll(\".\"+g.cn.axisTitle).data(f,h);U.enter().append(\"text\").classed(g.cn.axisTitle,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"ew-resize\").style(\"user-select\",\"none\").style(\"pointer-events\",\"auto\"),U.text(function(t){return t.label}).each(function(e){var r=n.select(this);l.font(r,e.model.labelFont),s.convertToTspans(r,t)}).attr(\"transform\",function(t){var e=M(t.model.labelAngle,t.model.labelSide),r=g.axisTitleOffset;return(e.dir>0?\"\":\"translate(0,\"+(2*r+t.model.height)+\")\")+\"rotate(\"+e.degrees+\")translate(\"+-r*e.dx+\",\"+-r*e.dy+\")\"}).attr(\"text-anchor\",function(t){var e=M(t.model.labelAngle,t.model.labelSide);return 2*Math.abs(e.dx)>Math.abs(e.dy)?e.dir*e.dx<0?\"start\":\"end\":\"middle\"});var V=B.selectAll(\".\"+g.cn.axisExtent).data(f,h);V.enter().append(\"g\").classed(g.cn.axisExtent,!0);var q=V.selectAll(\".\"+g.cn.axisExtentTop).data(f,h);q.enter().append(\"g\").classed(g.cn.axisExtentTop,!0),q.attr(\"transform\",\"translate(0,\"+-g.axisExtentOffset+\")\");var H=q.selectAll(\".\"+g.cn.axisExtentTopText).data(f,h);H.enter().append(\"text\").classed(g.cn.axisExtentTopText,!0).call(A),H.text(function(t){return C(t,!0)}).each(function(t){l.font(n.select(this),t.model.rangeFont)});var G=V.selectAll(\".\"+g.cn.axisExtentBottom).data(f,h);G.enter().append(\"g\").classed(g.cn.axisExtentBottom,!0),G.attr(\"transform\",function(t){return\"translate(0,\"+(t.model.height+g.axisExtentOffset)+\")\"});var Y=G.selectAll(\".\"+g.cn.axisExtentBottomText).data(f,h);Y.enter().append(\"text\").classed(g.cn.axisExtentBottomText,!0).attr(\"dy\",\"0.75em\").call(A),Y.text(function(t){return C(t,!1)}).each(function(t){l.font(n.select(this),t.model.rangeFont)}),v.ensureAxisBrush(B)}},{\"../../components/colorscale\":605,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/gup\":717,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"./axisbrush\":1075,\"./constants\":1078,\"./helpers\":1080,\"./lines\":1082,\"color-rgba\":122,d3:163}],1085:[function(t,e,r){\"use strict\";var n=t(\"./parcoords\"),i=t(\"../../lib/prepare_regl\"),a=t(\"./helpers\").isVisible;function o(t,e,r){var n=e.indexOf(r),i=t.indexOf(n);return-1===i&&(i+=e.length),i}e.exports=function(t,e){var r=t._fullLayout;if(i(t)){var s={},l={},c={},u={},h=r._size;e.forEach(function(e,r){var n=e[0].trace;c[r]=n.index;var i=u[r]=n._fullInput.index;s[r]=t.data[i].dimensions,l[r]=t.data[i].dimensions.slice()});n(t,e,{width:h.w,height:h.h,margin:{t:h.t,r:h.r,b:h.b,l:h.l}},{filterChanged:function(e,n,i){var a=l[e][n],o=i.map(function(t){return t.slice()}),s=\"dimensions[\"+n+\"].constraintrange\",h=r._tracePreGUI[t._fullData[c[e]]._fullInput.uid];if(void 0===h[s]){var f=a.constraintrange;h[s]=f||null}var p=t._fullData[c[e]].dimensions[n];o.length?(1===o.length&&(o=o[0]),a.constraintrange=o,p.constraintrange=o.slice(),o=[o]):(delete a.constraintrange,delete p.constraintrange,o=null);var d={};d[s]=o,t.emit(\"plotly_restyle\",[d,[u[e]]])},hover:function(e){t.emit(\"plotly_hover\",e)},unhover:function(e){t.emit(\"plotly_unhover\",e)},axesMoved:function(e,r){var n=function(t,e){return function(r,n){return o(t,e,r)-o(t,e,n)}}(r,l[e].filter(a));s[e].sort(n),l[e].filter(function(t){return!a(t)}).sort(function(t){return l[e].indexOf(t)}).forEach(function(t){s[e].splice(s[e].indexOf(t),1),s[e].splice(l[e].indexOf(t),0,t)}),t.emit(\"plotly_restyle\",[{dimensions:[s[e]]},[u[e]]])}})}}},{\"../../lib/prepare_regl\":732,\"./helpers\":1080,\"./parcoords\":1084}],1086:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../plots/domain\").attributes,a=t(\"../../plots/font_attributes\"),o=t(\"../../components/color/attributes\"),s=t(\"../../components/fx/hovertemplate_attributes\"),l=t(\"../../lib/extend\").extendFlat,c=a({editType:\"plot\",arrayOk:!0,colorEditType:\"plot\"});e.exports={labels:{valType:\"data_array\",editType:\"calc\"},label0:{valType:\"number\",dflt:0,editType:\"calc\"},dlabel:{valType:\"number\",dflt:1,editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},marker:{colors:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:o.defaultLine,arrayOk:!0,editType:\"style\"},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0,editType:\"style\"},editType:\"calc\"},editType:\"calc\"},text:{valType:\"data_array\",editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"value\",\"percent\"],extras:[\"none\"],editType:\"calc\"},hoverinfo:l({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:s({},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"auto\",arrayOk:!0,editType:\"plot\"},textfont:l({},c,{}),insidetextfont:l({},c,{}),outsidetextfont:l({},c,{}),title:{text:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:l({},c,{}),position:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"plot\"},editType:\"plot\"},domain:i({name:\"pie\",trace:!0,editType:\"calc\"}),hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},sort:{valType:\"boolean\",dflt:!0,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"number\",min:-360,max:360,dflt:0,editType:\"calc\"},pull:{valType:\"number\",min:0,max:1,dflt:0,arrayOk:!0,editType:\"calc\"},_deprecated:{title:{valType:\"string\",dflt:\"\",editType:\"calc\"},titlefont:l({},c,{}),titleposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"calc\"}}}},{\"../../components/color/attributes\":592,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1087:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData;r.name=\"pie\",r.plot=function(t){var e=n.getModule(\"pie\"),r=i(t.calcdata,e)[0];e.plot(t,r)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"pie\"),a=e._has&&e._has(\"pie\");i&&!a&&n._pielayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],1088:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"tinycolor2\"),o=t(\"../../components/color\"),s=t(\"./helpers\"),l=t(\"../../lib\").isValidTextValue,c={};function u(t){return function(e,r){return!!e&&(!!(e=a(e)).isValid()&&(e=o.addOpacity(e,e.getAlpha()),t[r]||(t[r]=e),e))}}function h(t,e){var r,n=JSON.stringify(t),i=e[n];if(!i){for(i=t.slice(),r=0;r<t.length;r++)i.push(a(t[r]).lighten(20).toHexString());for(r=0;r<t.length;r++)i.push(a(t[r]).darken(20).toHexString());e[n]=i}return i}e.exports={calc:function(t,e){var r,a,o=[],c=t._fullLayout,h=c.hiddenlabels||[],f=e.labels,p=e.marker.colors||[],d=e.values,g=i(d)&&d.length;if(e.dlabel)for(f=new Array(d.length),r=0;r<d.length;r++)f[r]=String(e.label0+r*e.dlabel);var v={},m=u(c[\"_\"+e.type+\"colormap\"]),y=(g?d:f).length,x=0,b=!1;for(r=0;r<y;r++){var _,w,k;if(g){if(_=d[r],!n(_))continue;if((_=+_)<0)continue}else _=1;void 0!==(w=f[r])&&\"\"!==w||(w=r);var T=v[w=String(w)];void 0===T?(v[w]=o.length,(k=-1!==h.indexOf(w))||(x+=_),o.push({v:_,label:w,color:m(p[r],w),i:r,pts:[r],hidden:k})):(b=!0,(a=o[T]).v+=_,a.pts.push(r),a.hidden||(x+=_),!1===a.color&&p[r]&&(a.color=m(p[r],w)))}(\"funnelarea\"===e.type?b:e.sort)&&o.sort(function(t,e){return e.v-t.v}),o[0]&&(o[0].vTotal=x);var A=e.textinfo;if(A&&\"none\"!==A){var M,S=A.split(\"+\"),E=function(t){return-1!==S.indexOf(t)},C=E(\"label\"),L=E(\"text\"),P=E(\"value\"),O=E(\"percent\"),z=c.separators;for(r=0;r<o.length;r++){if(a=o[r],M=C?[a.label]:[],L){var I=s.getFirstFilled(e.text,a.pts);l(I)&&M.push(I)}P&&M.push(s.formatPieValue(a.v,z)),O&&M.push(s.formatPiePercent(a.v/x,z)),a.text=M.join(\"<br>\")}}return o},crossTraceCalc:function(t,e){var r=(e||{}).type;r||(r=\"pie\");var n=t._fullLayout,i=t.calcdata,a=n[r+\"colorway\"],o=n[\"_\"+r+\"colormap\"];n[\"extend\"+r+\"colors\"]&&(a=h(a,c));for(var s=0,l=0;l<i.length;l++){var u=i[l];if(u[0].trace.type===r)for(var f=0;f<u.length;f++){var p=u[f];!1===p.color&&(o[p.label]?p.color=o[p.label]:(o[p.label]=p.color=a[s%a.length],s++))}}},makePullColorFn:u,generateExtendedColors:h}},{\"../../components/color\":593,\"../../lib\":719,\"./helpers\":1091,\"fast-isnumeric\":225,tinycolor2:537}],1089:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}var c,u=l(\"values\"),h=n.isArrayOrTypedArray(u),f=l(\"labels\");if(Array.isArray(f)?(c=f.length,h&&(c=Math.min(c,u.length))):h&&(c=u.length,l(\"label0\"),l(\"dlabel\")),c){e._length=c,l(\"marker.line.width\")&&l(\"marker.line.color\"),l(\"marker.colors\"),l(\"scalegroup\");var p=l(\"text\"),d=l(\"textinfo\",Array.isArray(p)?\"text+percent\":\"percent\");if(l(\"hovertext\"),l(\"hovertemplate\"),d&&\"none\"!==d){var g=l(\"textposition\");o(t,e,s,l,g,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}a(e,s,l);var v=l(\"hole\");if(l(\"title.text\")){var m=l(\"title.position\",v?\"middle center\":\"top center\");v||\"middle center\"!==m||(e.title.position=\"top center\"),n.coerceFont(l,\"title.font\",s.font)}l(\"sort\"),l(\"direction\"),l(\"rotation\"),l(\"pull\")}else e.visible=!1}},{\"../../lib\":719,\"../../plots/domain\":792,\"../bar/defaults\":861,\"./attributes\":1086}],1090:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/helpers\").appendArrayMultiPointValues;e.exports=function(t,e){var r={curveNumber:e.index,pointNumbers:t.pts,data:e._input,fullData:e,label:t.label,color:t.color,value:t.v,percent:t.percent,text:t.text,v:t.v};return 1===t.pts.length&&(r.pointNumber=r.i=t.pts[0]),n(r,e,t.pts),\"funnelarea\"===e.type&&(delete r.v,delete r.i),r}},{\"../../components/fx/helpers\":628}],1091:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");r.formatPiePercent=function(t,e){var r=(100*t).toPrecision(3);return-1!==r.lastIndexOf(\".\")&&(r=r.replace(/[.]?0+$/,\"\")),n.numSeparate(r,e)+\"%\"},r.formatPieValue=function(t,e){var r=t.toPrecision(10);return-1!==r.lastIndexOf(\".\")&&(r=r.replace(/[.]?0+$/,\"\")),n.numSeparate(r,e)},r.getFirstFilled=function(t,e){if(Array.isArray(t))for(var r=0;r<e.length;r++){var n=t[e[r]];if(n||0===n)return n}},r.castOption=function(t,e){return Array.isArray(t)?r.getFirstFilled(t,e):t||void 0}},{\"../../lib\":719}],1092:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),layoutAttributes:t(\"./layout_attributes\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\"),styleOne:t(\"./style_one\"),moduleType:\"trace\",name:\"pie\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"pie\",\"showLegend\"],meta:{}}},{\"./attributes\":1086,\"./base_plot\":1087,\"./calc\":1088,\"./defaults\":1089,\"./layout_attributes\":1093,\"./layout_defaults\":1094,\"./plot\":1095,\"./style\":1096,\"./style_one\":1097}],1093:[function(t,e,r){\"use strict\";e.exports={hiddenlabels:{valType:\"data_array\",editType:\"calc\"},piecolorway:{valType:\"colorlist\",editType:\"calc\"},extendpiecolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1094:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"piecolorway\",e.colorway),r(\"extendpiecolors\")}},{\"../../lib\":719,\"./layout_attributes\":1093}],1095:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/fx\"),a=t(\"../../components/color\"),o=t(\"../../components/drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"./helpers\"),u=t(\"./event_data\");function h(t,e,r){var a=r[0],o=a.trace,l=a.cx,h=a.cy;\"_hasHoverLabel\"in o||(o._hasHoverLabel=!1),\"_hasHoverEvent\"in o||(o._hasHoverEvent=!1),t.on(\"mouseover\",function(t){var r=e._fullLayout,f=e._fullData[o.index];if(!e._dragging&&!1!==r.hovermode){var p=f.hoverinfo;if(Array.isArray(p)&&(p=i.castHoverinfo({hoverinfo:[c.castOption(p,t.pts)],_module:o._module},r,0)),\"all\"===p&&(p=\"label+text+value+percent+name\"),f.hovertemplate||\"none\"!==p&&\"skip\"!==p&&p){var d=t.rInscribed||0,g=l+t.pxmid[0]*(1-d),v=h+t.pxmid[1]*(1-d),m=r.separators,y=[];if(p&&-1!==p.indexOf(\"label\")&&y.push(t.label),t.text=c.castOption(f.hovertext||f.text,t.pts),p&&-1!==p.indexOf(\"text\")){var x=t.text;s.isValidTextValue(x)&&y.push(x)}t.value=t.v,t.valueLabel=c.formatPieValue(t.v,m),p&&-1!==p.indexOf(\"value\")&&y.push(t.valueLabel),t.percent=t.v/a.vTotal,t.percentLabel=c.formatPiePercent(t.percent,m),p&&-1!==p.indexOf(\"percent\")&&y.push(t.percentLabel);var b=f.hoverlabel,_=b.font;i.loneHover({trace:o,x0:g-d*a.r,x1:g+d*a.r,y:v,text:y.join(\"<br>\"),name:f.hovertemplate||-1!==p.indexOf(\"name\")?f.name:void 0,idealAlign:t.pxmid[0]<0?\"left\":\"right\",color:c.castOption(b.bgcolor,t.pts)||t.color,borderColor:c.castOption(b.bordercolor,t.pts),fontFamily:c.castOption(_.family,t.pts),fontSize:c.castOption(_.size,t.pts),fontColor:c.castOption(_.color,t.pts),nameLength:c.castOption(b.namelength,t.pts),textAlign:c.castOption(b.align,t.pts),hovertemplate:c.castOption(f.hovertemplate,t.pts),hovertemplateLabels:t,eventData:[u(t,f)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e}),o._hasHoverLabel=!0}o._hasHoverEvent=!0,e.emit(\"plotly_hover\",{points:[u(t,f)],event:n.event})}}),t.on(\"mouseout\",function(t){var r=e._fullLayout,a=e._fullData[o.index],s=n.select(this).datum();o._hasHoverEvent&&(t.originalEvent=n.event,e.emit(\"plotly_unhover\",{points:[u(s,a)],event:n.event}),o._hasHoverEvent=!1),o._hasHoverLabel&&(i.loneUnhover(r._hoverlayer.node()),o._hasHoverLabel=!1)}),t.on(\"click\",function(t){var r=e._fullLayout,a=e._fullData[o.index];e._dragging||!1===r.hovermode||(e._hoverdata=[u(t,a)],i.click(e,n.event))})}function f(t,e,r){var n=c.castOption(t.insidetextfont.color,e.pts);!n&&t._input.textfont&&(n=c.castOption(t._input.textfont.color,e.pts));var i=c.castOption(t.insidetextfont.family,e.pts)||c.castOption(t.textfont.family,e.pts)||r.family,o=c.castOption(t.insidetextfont.size,e.pts)||c.castOption(t.textfont.size,e.pts)||r.size;return{color:n||a.contrast(e.color),family:i,size:o}}function p(t,e){for(var r,n,i=0;i<t.length;i++)if((n=(r=t[i][0]).trace).title.text){var a=n.title.text;n._meta&&(a=s.templateString(a,n._meta));var c=o.tester.append(\"text\").attr(\"data-notex\",1).text(a).call(o.font,n.title.font).call(l.convertToTspans,e),u=o.bBox(c.node(),!0);r.titleBox={width:u.width,height:u.height},c.remove()}}function d(t,e,r){var n=Math.sqrt(t.width*t.width+t.height*t.height),i=t.width/t.height,a=e.halfangle,o=e.ring,s=e.rInscribed,l=r.r||e.rpx1,c={scale:s*l*2/n,rCenter:1-s,rotate:0};if(c.scale>=1)return c;var u=i+1/(2*Math.tan(a)),h=l*Math.min(1/(Math.sqrt(u*u+.5)+u),o/(Math.sqrt(i*i+o/2)+i)),f={scale:2*h/t.height,rCenter:Math.cos(h/l)-h*i/l,rotate:(180/Math.PI*e.midangle+720)%180-90},p=1/i,d=p+1/(2*Math.tan(a)),g=l*Math.min(1/(Math.sqrt(d*d+.5)+d),o/(Math.sqrt(p*p+o/2)+p)),v={scale:2*g/t.width,rCenter:Math.cos(g/l)-g/i/l,rotate:(180/Math.PI*e.midangle+810)%180-90},m=v.scale>f.scale?v:f;return c.scale<1&&m.scale>c.scale?m:c}function g(t,e){return t.v!==e.vTotal||e.trace.hole?Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2):1}function v(t,e){var r=e.pxmid[0],n=e.pxmid[1],i=t.width/2,a=t.height/2;return r<0&&(i*=-1),n<0&&(a*=-1),{scale:1,rCenter:1,rotate:0,x:i+Math.abs(a)*(i>0?1:-1)/2,y:a/(1+r*r/(n*n)),outside:!0}}function m(t,e){var r,n,i,a=t.trace,o={x:t.cx,y:t.cy},s={tx:0,ty:0};s.ty+=a.title.font.size,i=x(a),-1!==a.title.position.indexOf(\"top\")?(o.y-=(1+i)*t.r,s.ty-=t.titleBox.height):-1!==a.title.position.indexOf(\"bottom\")&&(o.y+=(1+i)*t.r);var l,c,u=(l=t.r,c=t.trace.aspectratio,l/(void 0===c?1:c)),h=e.w*(a.domain.x[1]-a.domain.x[0])/2;return-1!==a.title.position.indexOf(\"left\")?(h+=u,o.x-=(1+i)*u,s.tx+=t.titleBox.width/2):-1!==a.title.position.indexOf(\"center\")?h*=2:-1!==a.title.position.indexOf(\"right\")&&(h+=u,o.x+=(1+i)*u,s.tx-=t.titleBox.width/2),r=h/t.titleBox.width,n=y(t,e)/t.titleBox.height,{x:o.x,y:o.y,scale:Math.min(r,n),tx:s.tx,ty:s.ty}}function y(t,e){var r=t.trace,n=e.h*(r.domain.y[1]-r.domain.y[0]);return Math.min(t.titleBox.height,n/2)}function x(t){var e,r=t.pull;if(!r)return 0;if(Array.isArray(r))for(r=0,e=0;e<t.pull.length;e++)t.pull[e]>r&&(r=t.pull[e]);return r}function b(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n][0],a=i.trace,o=a.domain,s=e.w*(o.x[1]-o.x[0]),l=e.h*(o.y[1]-o.y[0]);a.title.text&&\"middle center\"!==a.title.position&&(l-=y(i,e));var c=s/2,u=l/2;\"funnelarea\"!==a.type||a.scalegroup||(u/=a.aspectratio),i.r=Math.min(c,u)/(1+x(a)),i.cx=e.l+e.w*(a.domain.x[1]+a.domain.x[0])/2,i.cy=e.t+e.h*(1-a.domain.y[0])-l/2,a.title.text&&-1!==a.title.position.indexOf(\"bottom\")&&(i.cy-=y(i,e)),a.scalegroup&&-1===r.indexOf(a.scalegroup)&&r.push(a.scalegroup)}!function(t,e){for(var r,n,i,a=0;a<e.length;a++){var o=1/0,s=e[a];for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var l;if(\"pie\"===i.type)l=r.r*r.r;else if(\"funnelarea\"===i.type){var c,u;i.aspectratio>1?(c=r.r,u=c/i.aspectratio):(u=r.r,c=u*i.aspectratio),c*=(1+i.baseratio)/2,l=c*u}o=Math.min(o,l/r.vTotal)}for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var h=o*r.vTotal;\"funnelarea\"===i.type&&(h/=(1+i.baseratio)/2,h/=i.aspectratio),r.r=Math.sqrt(h)}}}(t,r)}e.exports={plot:function(t,e){var r=t._fullLayout;p(e,t),b(e,r._size);var i=s.makeTraceGroups(r._pielayer,e,\"trace\").each(function(e){var i=n.select(this),u=e[0],p=u.trace;!function(t){var e,r,n,i=t[0],a=i.trace,o=a.rotation*Math.PI/180,s=2*Math.PI/i.vTotal,l=\"px0\",c=\"px1\";if(\"counterclockwise\"===a.direction){for(e=0;e<t.length&&t[e].hidden;e++);if(e===t.length)return;o+=s*t[e].v,s*=-1,l=\"px1\",c=\"px0\"}function u(t){return[i.r*Math.sin(t),-i.r*Math.cos(t)]}for(n=u(o),e=0;e<t.length;e++)(r=t[e]).hidden||(r[l]=n,o+=s*r.v/2,r.pxmid=u(o),r.midangle=o,o+=s*r.v/2,n=u(o),r[c]=n,r.largeArc=r.v>i.vTotal/2?1:0,r.halfangle=Math.PI*Math.min(r.v/i.vTotal,.5),r.ring=1-a.hole,r.rInscribed=g(r,i))}(e),i.attr(\"stroke-linejoin\",\"round\"),i.each(function(){var i=n.select(this).selectAll(\"g.slice\").data(e);i.enter().append(\"g\").classed(\"slice\",!0),i.exit().remove();var g=[[[],[]],[[],[]]],y=!1;i.each(function(r){if(r.hidden)n.select(this).selectAll(\"path,g\").remove();else{r.pointNumber=r.i,r.curveNumber=p.index,g[r.pxmid[1]<0?0:1][r.pxmid[0]<0?0:1].push(r);var i=u.cx,a=u.cy,m=n.select(this),x=m.selectAll(\"path.surface\").data([r]);if(x.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),m.call(h,t,e),p.pull){var b=+c.castOption(p.pull,r.pts)||0;b>0&&(i+=b*r.pxmid[0],a+=b*r.pxmid[1])}r.cxFinal=i,r.cyFinal=a;var _=p.hole;if(r.v===u.vTotal){var w=\"M\"+(i+r.px0[0])+\",\"+(a+r.px0[1])+S(r.px0,r.pxmid,!0,1)+S(r.pxmid,r.px0,!0,1)+\"Z\";_?x.attr(\"d\",\"M\"+(i+_*r.px0[0])+\",\"+(a+_*r.px0[1])+S(r.px0,r.pxmid,!1,_)+S(r.pxmid,r.px0,!1,_)+\"Z\"+w):x.attr(\"d\",w)}else{var k=S(r.px0,r.px1,!0,1);if(_){var T=1-_;x.attr(\"d\",\"M\"+(i+_*r.px1[0])+\",\"+(a+_*r.px1[1])+S(r.px1,r.px0,!1,_)+\"l\"+T*r.px0[0]+\",\"+T*r.px0[1]+k+\"Z\")}else x.attr(\"d\",\"M\"+i+\",\"+a+\"l\"+r.px0[0]+\",\"+r.px0[1]+k+\"Z\")}var A=c.castOption(p.textposition,r.pts),M=m.selectAll(\"g.slicetext\").data(r.text&&\"none\"!==A?[0]:[]);M.enter().append(\"g\").classed(\"slicetext\",!0),M.exit().remove(),M.each(function(){var e=s.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)});e.text(r.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(o.font,\"outside\"===A?function(t,e,r){var n=c.castOption(t.outsidetextfont.color,e.pts)||c.castOption(t.textfont.color,e.pts)||r.color,i=c.castOption(t.outsidetextfont.family,e.pts)||c.castOption(t.textfont.family,e.pts)||r.family,a=c.castOption(t.outsidetextfont.size,e.pts)||c.castOption(t.textfont.size,e.pts)||r.size;return{color:n,family:i,size:a}}(p,r,t._fullLayout.font):f(p,r,t._fullLayout.font)).call(l.convertToTspans,t);var h,g=o.bBox(e.node());\"outside\"===A?h=v(g,r):(h=d(g,r,u),\"auto\"===A&&h.scale<1&&(e.call(o.font,p.outsidetextfont),p.outsidetextfont.family===p.insidetextfont.family&&p.outsidetextfont.size===p.insidetextfont.size||(g=o.bBox(e.node())),h=v(g,r)));var m=i+r.pxmid[0]*h.rCenter+(h.x||0),x=a+r.pxmid[1]*h.rCenter+(h.y||0);h.outside&&(r.yLabelMin=x-g.height/2,r.yLabelMid=x,r.yLabelMax=x+g.height/2,r.labelExtraX=0,r.labelExtraY=0,y=!0),e.attr(\"transform\",\"translate(\"+m+\",\"+x+\")\"+(h.scale<1?\"scale(\"+h.scale+\")\":\"\")+(h.rotate?\"rotate(\"+h.rotate+\")\":\"\")+\"translate(\"+-(g.left+g.right)/2+\",\"+-(g.top+g.bottom)/2+\")\")})}function S(t,e,n,i){var a=i*(e[0]-t[0]),o=i*(e[1]-t[1]);return\"a\"+i*u.r+\",\"+i*u.r+\" 0 \"+r.largeArc+(n?\" 1 \":\" 0 \")+a+\",\"+o}});var x=n.select(this).selectAll(\"g.titletext\").data(p.title.text?[0]:[]);x.enter().append(\"g\").classed(\"titletext\",!0),x.exit().remove(),x.each(function(){var e,i=s.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),a=p.title.text;p._meta&&(a=s.templateString(a,p._meta)),i.text(a).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(o.font,p.title.font).call(l.convertToTspans,t),e=\"middle center\"===p.title.position?function(t){var e=Math.sqrt(t.titleBox.width*t.titleBox.width+t.titleBox.height*t.titleBox.height);return{x:t.cx,y:t.cy,scale:t.trace.hole*t.r*2/e,tx:0,ty:-t.titleBox.height/2+t.trace.title.font.size}}(u):m(u,r._size),i.attr(\"transform\",\"translate(\"+e.x+\",\"+e.y+\")\"+(e.scale<1?\"scale(\"+e.scale+\")\":\"\")+\"translate(\"+e.tx+\",\"+e.ty+\")\")}),y&&function(t,e){var r,n,i,a,o,s,l,u,h,f,p,d,g;function v(t,e){return t.pxmid[1]-e.pxmid[1]}function m(t,e){return e.pxmid[1]-t.pxmid[1]}function y(t,r){r||(r={});var i,u,h,p,d,g,v=r.labelExtraY+(n?r.yLabelMax:r.yLabelMin),m=n?t.yLabelMin:t.yLabelMax,y=n?t.yLabelMax:t.yLabelMin,x=t.cyFinal+o(t.px0[1],t.px1[1]),b=v-m;if(b*l>0&&(t.labelExtraY=b),Array.isArray(e.pull))for(u=0;u<f.length;u++)(h=f[u])===t||(c.castOption(e.pull,t.pts)||0)>=(c.castOption(e.pull,h.pts)||0)||((t.pxmid[1]-h.pxmid[1])*l>0?(p=h.cyFinal+o(h.px0[1],h.px1[1]),(b=p-m-t.labelExtraY)*l>0&&(t.labelExtraY+=b)):(y+t.labelExtraY-x)*l>0&&(i=3*s*Math.abs(u-f.indexOf(t)),d=h.cxFinal+a(h.px0[0],h.px1[0]),(g=d+i-(t.cxFinal+t.pxmid[0])-t.labelExtraX)*s>0&&(t.labelExtraX+=g)))}for(n=0;n<2;n++)for(i=n?v:m,o=n?Math.max:Math.min,l=n?1:-1,r=0;r<2;r++){for(a=r?Math.max:Math.min,s=r?1:-1,(u=t[n][r]).sort(i),h=t[1-n][r],f=h.concat(u),d=[],p=0;p<u.length;p++)void 0!==u[p].yLabelMid&&d.push(u[p]);for(g=!1,p=0;n&&p<h.length;p++)if(void 0!==h[p].yLabelMid){g=h[p];break}for(p=0;p<d.length;p++){var x=p&&d[p-1];g&&!p&&(x=g),y(d[p],x)}}}(g,p),function(t,e){t.each(function(t){var r=n.select(this);if(t.labelExtraX||t.labelExtraY){var i=r.select(\"g.slicetext text\");i.attr(\"transform\",\"translate(\"+t.labelExtraX+\",\"+t.labelExtraY+\")\"+i.attr(\"transform\"));var o=t.cxFinal+t.pxmid[0],l=t.cyFinal+t.pxmid[1],c=\"M\"+o+\",\"+l,u=(t.yLabelMax-t.yLabelMin)*(t.pxmid[0]<0?-1:1)/4;if(t.labelExtraX){var h=t.labelExtraX*t.pxmid[1]/t.pxmid[0],f=t.yLabelMid+t.labelExtraY-(t.cyFinal+t.pxmid[1]);Math.abs(h)>Math.abs(f)?c+=\"l\"+f*t.pxmid[0]/t.pxmid[1]+\",\"+f+\"H\"+(o+t.labelExtraX+u):c+=\"l\"+t.labelExtraX+\",\"+h+\"v\"+(f-h)+\"h\"+u}else c+=\"V\"+(t.yLabelMid+t.labelExtraY)+\"h\"+u;s.ensureSingle(r,\"path\",\"textline\").call(a.stroke,e.outsidetextfont.color).attr({\"stroke-width\":Math.min(2,e.outsidetextfont.size/8),d:c,fill:\"none\"})}else r.select(\"path.textline\").remove()})}(i,p)})});setTimeout(function(){i.selectAll(\"tspan\").each(function(){var t=n.select(this);t.attr(\"dy\")&&t.attr(\"dy\",t.attr(\"dy\"))})},0)},transformInsideText:d,determineInsideTextFont:f,positionTitleOutside:m,prerenderTitles:p,layoutAreas:b,attachFxHandlers:h}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"./event_data\":1090,\"./helpers\":1091,d3:163}],1096:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./style_one\");e.exports=function(t){t._fullLayout._pielayer.selectAll(\".trace\").each(function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each(function(t){n.select(this).call(i,t,e)})})}},{\"./style_one\":1097,d3:163}],1097:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./helpers\").castOption;e.exports=function(t,e,r){var a=r.marker.line,o=i(a.color,e.pts)||n.defaultLine,s=i(a.width,e.pts)||0;t.style(\"stroke-width\",s).call(n.fill,e.color).call(n.stroke,o)}},{\"../../components/color\":593,\"./helpers\":1091}],1098:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\");e.exports={x:n.x,y:n.y,xy:{valType:\"data_array\",editType:\"calc\"},indices:{valType:\"data_array\",editType:\"calc\"},xbounds:{valType:\"data_array\",editType:\"calc\"},ybounds:{valType:\"data_array\",editType:\"calc\"},text:n.text,marker:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,arrayOk:!1,editType:\"calc\"},blend:{valType:\"boolean\",dflt:null,editType:\"calc\"},sizemin:{valType:\"number\",min:.1,max:2,dflt:.5,editType:\"calc\"},sizemax:{valType:\"number\",min:.1,dflt:20,editType:\"calc\"},border:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},arearatio:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},transforms:void 0}},{\"../scatter/attributes\":1112}],1099:[function(t,e,r){\"use strict\";var n=t(\"gl-pointcloud2d\"),i=t(\"../../lib/str2rgbarray\"),a=t(\"../../plots/cartesian/autorange\").findExtremes,o=t(\"../scatter/get_trace_color\");function s(t,e){this.scene=t,this.uid=e,this.type=\"pointcloud\",this.pickXData=[],this.pickYData=[],this.xData=[],this.yData=[],this.textLabels=[],this.color=\"rgb(0, 0, 0)\",this.name=\"\",this.hoverinfo=\"all\",this.idToIndex=new Int32Array(0),this.bounds=[0,0,0,0],this.pointcloudOptions={positions:new Float32Array(0),idToIndex:this.idToIndex,sizemin:.5,sizemax:12,color:[0,0,0,1],areaRatio:1,borderColor:[0,0,0,1]},this.pointcloud=n(t.glplot,this.pointcloudOptions),this.pointcloud._trace=this}var l=s.prototype;l.handlePick=function(t){var e=this.idToIndex[t.pointId];return{trace:this,dataCoord:t.dataCoord,traceCoord:this.pickXYData?[this.pickXYData[2*e],this.pickXYData[2*e+1]]:[this.pickXData[e],this.pickYData[e]],textLabel:Array.isArray(this.textLabels)?this.textLabels[e]:this.textLabels,color:this.color,name:this.name,pointIndex:e,hoverinfo:this.hoverinfo}},l.update=function(t){this.index=t.index,this.textLabels=t.text,this.name=t.name,this.hoverinfo=t.hoverinfo,this.bounds=[1/0,1/0,-1/0,-1/0],this.updateFast(t),this.color=o(t,{})},l.updateFast=function(t){var e,r,n,o,s,l,c=this.xData=this.pickXData=t.x,u=this.yData=this.pickYData=t.y,h=this.pickXYData=t.xy,f=t.xbounds&&t.ybounds,p=t.indices,d=this.bounds;if(h){if(n=h,e=h.length>>>1,f)d[0]=t.xbounds[0],d[2]=t.xbounds[1],d[1]=t.ybounds[0],d[3]=t.ybounds[1];else for(l=0;l<e;l++)o=n[2*l],s=n[2*l+1],o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);if(p)r=p;else for(r=new Int32Array(e),l=0;l<e;l++)r[l]=l}else for(e=c.length,n=new Float32Array(2*e),r=new Int32Array(e),l=0;l<e;l++)o=c[l],s=u[l],r[l]=l,n[2*l]=o,n[2*l+1]=s,o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);this.idToIndex=r,this.pointcloudOptions.idToIndex=r,this.pointcloudOptions.positions=n;var g=i(t.marker.color),v=i(t.marker.border.color),m=t.opacity*t.marker.opacity;g[3]*=m,this.pointcloudOptions.color=g;var y=t.marker.blend;if(null===y){y=c.length<100||u.length<100}this.pointcloudOptions.blend=y,v[3]*=m,this.pointcloudOptions.borderColor=v;var x=t.marker.sizemin,b=Math.max(t.marker.sizemax,t.marker.sizemin);this.pointcloudOptions.sizeMin=x,this.pointcloudOptions.sizeMax=b,this.pointcloudOptions.areaRatio=t.marker.border.arearatio,this.pointcloud.update(this.pointcloudOptions);var _=this.scene.xaxis,w=this.scene.yaxis,k=b/2||.5;t._extremes[_._id]=a(_,[d[0],d[2]],{ppad:k}),t._extremes[w._id]=a(w,[d[1],d[3]],{ppad:k})},l.dispose=function(){this.pointcloud.dispose()},e.exports=function(t,e){var r=new s(t,e.uid);return r.update(e),r}},{\"../../lib/str2rgbarray\":742,\"../../plots/cartesian/autorange\":766,\"../scatter/get_trace_color\":1121,\"gl-pointcloud2d\":292}],1100:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\");e.exports=function(t,e,r){function a(r,a){return n.coerce(t,e,i,r,a)}a(\"x\"),a(\"y\"),a(\"xbounds\"),a(\"ybounds\"),t.xy&&t.xy instanceof Float32Array&&(e.xy=t.xy),t.indices&&t.indices instanceof Int32Array&&(e.indices=t.indices),a(\"text\"),a(\"marker.color\",r),a(\"marker.opacity\"),a(\"marker.blend\"),a(\"marker.sizemin\"),a(\"marker.sizemax\"),a(\"marker.border.color\",r),a(\"marker.border.arearatio\"),e._length=null}},{\"../../lib\":719,\"./attributes\":1098}],1101:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../scatter3d/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"pointcloud\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"showLegend\"],meta:{}}},{\"../../plots/gl2d\":805,\"../scatter3d/calc\":1139,\"./attributes\":1098,\"./convert\":1099,\"./defaults\":1100}],1102:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../components/fx/attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../../components/fx/hovertemplate_attributes\"),c=t(\"../../components/colorscale/attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,h=t(\"../../lib/extend\").extendFlat,f=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=f({hoverinfo:h({},i.hoverinfo,{flags:[],arrayOk:!1}),hoverlabel:o.hoverlabel,domain:s({name:\"sankey\",trace:!0}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\"},valueformat:{valType:\"string\",dflt:\".3s\"},valuesuffix:{valType:\"string\",dflt:\"\"},arrangement:{valType:\"enumerated\",values:[\"snap\",\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"snap\"},textfont:n({}),node:{label:{valType:\"data_array\",dflt:[]},groups:{valType:\"info_array\",impliedEdits:{x:[],y:[]},dimensions:2,freeLength:!0,dflt:[],items:{valType:\"number\",editType:\"calc\"}},x:{valType:\"data_array\",dflt:[]},y:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:.5,arrayOk:!0}},pad:{valType:\"number\",arrayOk:!1,min:0,dflt:20},thickness:{valType:\"number\",arrayOk:!1,min:1,dflt:20},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]})},link:{label:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0}},source:{valType:\"data_array\",dflt:[]},target:{valType:\"data_array\",dflt:[]},value:{valType:\"data_array\",dflt:[]},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]}),colorscales:u(\"concentrationscales\",{editType:\"calc\",label:{valType:\"string\",editType:\"calc\",dflt:\"\"},cmax:{valType:\"number\",editType:\"calc\",dflt:1},cmin:{valType:\"number\",editType:\"calc\",dflt:0},colorscale:h(c().colorscale,{dflt:[[0,\"white\"],[1,\"black\"]]})})}},\"calc\",\"nested\")).transforms=void 0},{\"../../components/color/attributes\":592,\"../../components/colorscale/attributes\":600,\"../../components/fx/attributes\":623,\"../../components/fx/hovertemplate_attributes\":631,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1103:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../components/fx/layout_attributes\"),s=t(\"../../lib/setcursor\"),l=t(\"../../components/dragelement\"),c=t(\"../../plots/cartesian/select\").prepSelect,u=t(\"../../lib\"),h=t(\"../../registry\");function f(t,e){var r=t._fullData[e],n=t._fullLayout,i=n.dragmode,a=\"pan\"===n.dragmode?\"move\":\"crosshair\",o=r._bgRect;if(\"pan\"!==i&&\"zoom\"!==i){s(o,a);var f={_id:\"x\",c2p:u.identity,_offset:r._sankey.translateX,_length:r._sankey.width},p={_id:\"y\",c2p:u.identity,_offset:r._sankey.translateY,_length:r._sankey.height},d={gd:t,element:o.node(),plotinfo:{id:e,xaxis:f,yaxis:p,fillRangeItems:u.noop},subplot:e,xaxes:[f],yaxes:[p],doneFnCompleted:function(r){var n,i=t._fullData[e],a=i.node.groups.slice(),o=[];function s(t){for(var e=i._sankey.graph.nodes,r=0;r<e.length;r++)if(e[r].pointNumber===t)return e[r]}for(var l=0;l<r.length;l++){var c=s(r[l].pointNumber);if(c)if(c.group){for(var u=0;u<c.childrenNodes.length;u++)o.push(c.childrenNodes[u].pointNumber);a[c.pointNumber-i.node._count]=!1}else o.push(c.pointNumber)}n=a.filter(Boolean).concat([o]),h.call(\"_guiRestyle\",t,{\"node.groups\":[n]},e)},prepFn:function(t,e,r){c(t,e,r,d,i)}};l.init(d)}}r.name=\"sankey\",r.baseLayoutAttrOverrides=n({hoverlabel:o.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){var e=i(t.calcdata,\"sankey\")[0];a(t,e),r.updateFx(t)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"sankey\"),a=e._has&&e._has(\"sankey\");i&&!a&&(n._paperdiv.selectAll(\".sankey\").remove(),n._paperdiv.selectAll(\".bgsankey\").remove())},r.updateFx=function(t){for(var e=0;e<t._fullData.length;e++)f(t,e)}},{\"../../components/dragelement\":611,\"../../components/fx/layout_attributes\":633,\"../../lib\":719,\"../../lib/setcursor\":739,\"../../plot_api/edit_types\":750,\"../../plots/cartesian/select\":784,\"../../plots/get_data\":802,\"../../registry\":847,\"./plot\":1108}],1104:[function(t,e,r){\"use strict\";var n=t(\"strongly-connected-components\"),i=t(\"../../lib\"),a=t(\"../../lib/gup\").wrap,o=i.isArrayOrTypedArray,s=i.isIndex,l=t(\"../../components/colorscale\");function c(t){var e,r=t.node,a=t.link,c=[],u=o(a.color),h={},f={},p=a.colorscales.length;for(e=0;e<p;e++){var d=a.colorscales[e],g=l.extractScale(d,{cLetter:\"c\"}),v=l.makeColorScaleFunc(g);f[d.label]=v}var m=0;for(e=0;e<a.value.length;e++)a.source[e]>m&&(m=a.source[e]),a.target[e]>m&&(m=a.target[e]);var y,x=m+1;t.node._count=x;var b=t.node.groups,_={};for(e=0;e<b.length;e++){var w=b[e];for(y=0;y<w.length;y++){var k=w[y],T=x+e;_.hasOwnProperty(k)?i.warn(\"Node \"+k+\" is already part of a group.\"):_[k]=T}}var A={source:[],target:[]};for(e=0;e<a.value.length;e++){var M=a.value[e],S=a.source[e],E=a.target[e];if(M>0&&s(S,x)&&s(E,x)&&(!_.hasOwnProperty(S)||!_.hasOwnProperty(E)||_[S]!==_[E])){_.hasOwnProperty(E)&&(E=_[E]),_.hasOwnProperty(S)&&(S=_[S]),E=+E,h[S=+S]=h[E]=!0;var C=\"\";a.label&&a.label[e]&&(C=a.label[e]);var L=null;C&&f.hasOwnProperty(C)&&(L=f[C]),c.push({pointNumber:e,label:C,color:u?a.color[e]:a.color,concentrationscale:L,source:S,target:E,value:+M}),A.source.push(S),A.target.push(E)}}var P=x+b.length,O=o(r.color),z=[];for(e=0;e<P;e++)if(h[e]){var I=r.label[e];z.push({group:e>x-1,childrenNodes:[],pointNumber:e,label:I,color:O?r.color[e]:r.color})}var D=!1;return function(t,e,r){for(var a=i.init2dArray(t,0),o=0;o<Math.min(e.length,r.length);o++)if(i.isIndex(e[o],t)&&i.isIndex(r[o],t)){if(e[o]===r[o])return!0;a[e[o]].push(r[o])}return n(a).components.some(function(t){return t.length>1})}(P,A.source,A.target)&&(D=!0),{circular:D,links:c,nodes:z,groups:b,groupLookup:_}}e.exports=function(t,e){var r=c(e);return a({circular:r.circular,_nodes:r.nodes,_links:r.links,_groups:r.groups,_groupLookup:r.groupLookup})}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gup\":717,\"strongly-connected-components\":530}],1105:[function(t,e,r){\"use strict\";e.exports={nodeTextOffsetHorizontal:4,nodeTextOffsetVertical:3,nodePadAcross:10,sankeyIterations:50,forceIterations:5,forceTicksPerFrame:10,duration:500,ease:\"linear\",cn:{sankey:\"sankey\",sankeyLinks:\"sankey-links\",sankeyLink:\"sankey-link\",sankeyNodeSet:\"sankey-node-set\",sankeyNode:\"sankey-node\",nodeRect:\"node-rect\",nodeCapture:\"node-capture\",nodeCentered:\"node-entered\",nodeLabelGuide:\"node-label-guide\",nodeLabel:\"node-label\",nodeLabelTextPath:\"node-label-text-path\"}}},{}],1106:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../components/color\"),o=t(\"tinycolor2\"),s=t(\"../../plots/domain\").defaults,l=t(\"../../components/fx/hoverlabel_defaults\"),c=t(\"../../plot_api/plot_template\"),u=t(\"../../plots/array_container_defaults\");function h(t,e){function r(r,a){return n.coerce(t,e,i.link.colorscales,r,a)}r(\"label\"),r(\"cmin\"),r(\"cmax\"),r(\"colorscale\")}e.exports=function(t,e,r,f){function p(r,a){return n.coerce(t,e,i,r,a)}var d=n.extendDeep(f.hoverlabel,t.hoverlabel),g=t.node,v=c.newContainer(e,\"node\");function m(t,e){return n.coerce(g,v,i.node,t,e)}m(\"label\"),m(\"groups\"),m(\"x\"),m(\"y\"),m(\"pad\"),m(\"thickness\"),m(\"line.color\"),m(\"line.width\"),m(\"hoverinfo\",t.hoverinfo),l(g,v,m,d),m(\"hovertemplate\");var y=f.colorway;m(\"color\",v.label.map(function(t,e){return a.addOpacity(function(t){return y[t%y.length]}(e),.8)}));var x=t.link||{},b=c.newContainer(e,\"link\");function _(t,e){return n.coerce(x,b,i.link,t,e)}_(\"label\"),_(\"source\"),_(\"target\"),_(\"value\"),_(\"line.color\"),_(\"line.width\"),_(\"hoverinfo\",t.hoverinfo),l(x,b,_,d),_(\"hovertemplate\");var w,k=o(f.paper_bgcolor).getLuminance()<.333?\"rgba(255, 255, 255, 0.6)\":\"rgba(0, 0, 0, 0.2)\";_(\"color\",n.repeat(k,b.value.length)),u(x,b,{name:\"colorscales\",handleItemDefaults:h}),s(e,f,p),p(\"orientation\"),p(\"valueformat\"),p(\"valuesuffix\"),v.x.length&&v.y.length&&(w=\"freeform\"),p(\"arrangement\",w),n.coerceFont(p,\"textfont\",n.extendFlat({},f.font)),e._length=null}},{\"../../components/color\":593,\"../../components/fx/hoverlabel_defaults\":630,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/array_container_defaults\":763,\"../../plots/domain\":792,\"./attributes\":1102,tinycolor2:537}],1107:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"sankey\",basePlotModule:t(\"./base_plot\"),selectPoints:t(\"./select.js\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1102,\"./base_plot\":1103,\"./calc\":1104,\"./defaults\":1106,\"./plot\":1108,\"./select.js\":1110}],1108:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./render\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\"),l=t(\"./constants\").cn,c=s._;function u(t){return\"\"!==t}function h(t,e){return t.filter(function(t){return t.key===e.traceId})}function f(t,e){n.select(t).select(\"path\").style(\"fill-opacity\",e),n.select(t).select(\"rect\").style(\"fill-opacity\",e)}function p(t){n.select(t).select(\"text.name\").style(\"fill\",\"black\")}function d(t){return function(e){return-1!==t.node.sourceLinks.indexOf(e.link)||-1!==t.node.targetLinks.indexOf(e.link)}}function g(t){return function(e){return-1!==e.node.sourceLinks.indexOf(t.link)||-1!==e.node.targetLinks.indexOf(t.link)}}function v(t,e,r){e&&r&&h(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(y.bind(0,e,r,!1))}function m(t,e,r){e&&r&&h(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(x.bind(0,e,r,!1))}function y(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",function(t){if(!t.link.concentrationscale)return.4}),i&&h(e,t).selectAll(\".\"+l.sankeyLink).filter(function(t){return t.link.label===i}).style(\"fill-opacity\",function(t){if(!t.link.concentrationscale)return.4}),r&&h(e,t).selectAll(\".\"+l.sankeyNode).filter(g(t)).call(v)}function x(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),i&&h(e,t).selectAll(\".\"+l.sankeyLink).filter(function(t){return t.link.label===i}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),r&&h(e,t).selectAll(l.sankeyNode).filter(g(t)).call(m)}function b(t,e){var r=t.hoverlabel||{},n=s.nestedProperty(r,e).get();return!Array.isArray(n)&&n}e.exports=function(t,e){for(var r=t._fullLayout,s=r._paper,h=r._size,d=0;d<t._fullData.length;d++)if(t._fullData[d].type===l.sankey&&!t._fullData[d]._viewInitial){var g=t._fullData[d].node;t._fullData[d]._viewInitial={node:{groups:g.groups.slice(),x:g.x.slice(),y:g.y.slice()}}}var _=c(t,\"source:\")+\" \",w=c(t,\"target:\")+\" \",k=c(t,\"concentration:\")+\" \",T=c(t,\"incoming flow count:\")+\" \",A=c(t,\"outgoing flow count:\")+\" \";i(t,s,e,{width:h.w,height:h.h,margin:{t:h.t,r:h.r,b:h.b,l:h.l}},{linkEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(y.bind(0,r,i,!0)),\"skip\"!==r.link.trace.link.hoverinfo&&(r.link.fullData=r.link.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.link]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var s=i.link.trace.link;if(\"none\"!==s.hoverinfo&&\"skip\"!==s.hoverinfo){for(var l=[],c=0,h=0;h<i.flow.links.length;h++){var d=i.flow.links[h];if(\"closest\"!==t._fullLayout.hovermode||i.link.pointNumber===d.pointNumber){i.link.pointNumber===d.pointNumber&&(c=h),d.fullData=d.trace,s=i.link.trace.link;var g=m(d),v={valueLabel:n.format(i.valueFormat)(d.value)+i.valueSuffix};l.push({x:g[0],y:g[1],name:v.valueLabel,text:[d.label||\"\",_+d.source.label,w+d.target.label,d.concentrationscale?k+n.format(\"%0.2f\")(d.flow.labelConcentration):\"\"].filter(u).join(\"<br>\"),color:b(s,\"bgcolor\")||o.addOpacity(d.color,1),borderColor:b(s,\"bordercolor\"),fontFamily:b(s,\"font.family\"),fontSize:b(s,\"font.size\"),fontColor:b(s,\"font.color\"),nameLength:b(s,\"namelength\"),textAlign:b(s,\"align\"),idealAlign:n.event.x<g[0]?\"right\":\"left\",hovertemplate:s.hovertemplate,hovertemplateLabels:v,eventData:[d]})}}a.loneHover(l,{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t,anchorIndex:c}).each(function(){i.link.concentrationscale||f(this,.65),p(this)})}}function m(t){var e,r;return t.circular?(e=(t.circularPathData.leftInnerExtent+t.circularPathData.rightInnerExtent)/2+i.parent.translateX,r=t.circularPathData.verticalFullExtent+i.parent.translateY):(e=(t.source.x1+t.target.x0)/2+i.parent.translateX,r=(t.y0+t.y1)/2+i.parent.translateY),[e,r]}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(x.bind(0,i,o,!0)),\"skip\"!==i.link.trace.link.hoverinfo&&(i.link.fullData=i.link.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.link]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r){var i=r.link;i.originalEvent=n.event,t._hoverdata=[i],a.click(t,{target:!0})}},nodeEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(v,r,i),\"skip\"!==r.node.trace.node.hoverinfo&&(r.node.fullData=r.node.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.node]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var o=i.node.trace.node;if(\"none\"!==o.hoverinfo&&\"skip\"!==o.hoverinfo){var s=n.select(e).select(\".\"+l.nodeRect),c=t._fullLayout._paperdiv.node().getBoundingClientRect(),h=s.node().getBoundingClientRect(),d=h.left-2-c.left,g=h.right+2-c.left,v=h.top+h.height/4-c.top,m={valueLabel:n.format(i.valueFormat)(i.node.value)+i.valueSuffix};i.node.fullData=i.node.trace;var y=a.loneHover({x0:d,x1:g,y:v,name:n.format(i.valueFormat)(i.node.value)+i.valueSuffix,text:[i.node.label,T+i.node.targetLinks.length,A+i.node.sourceLinks.length].filter(u).join(\"<br>\"),color:b(o,\"bgcolor\")||i.tinyColorHue,borderColor:b(o,\"bordercolor\"),fontFamily:b(o,\"font.family\"),fontSize:b(o,\"font.size\"),fontColor:b(o,\"font.color\"),nameLength:b(o,\"namelength\"),textAlign:b(o,\"align\"),idealAlign:\"left\",hovertemplate:o.hovertemplate,hovertemplateLabels:m,eventData:[i.node]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t});f(y,.85),p(y)}}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(m,i,o),\"skip\"!==i.node.trace.node.hoverinfo&&(i.node.fullData=i.node.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.node]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r,i){var o=r.node;o.originalEvent=n.event,t._hoverdata=[o],n.select(e).call(m,r,i),a.click(t,{target:!0})}}})}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"./constants\":1105,\"./render\":1109,d3:163}],1109:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"tinycolor2\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"@plotly/d3-sankey\"),c=t(\"@plotly/d3-sankey-circular\"),u=t(\"d3-force\"),h=t(\"../../lib\"),f=t(\"../../lib/gup\"),p=f.keyFun,d=f.repeat,g=f.unwrap,v=t(\"d3-interpolate\").interpolateNumber,m=t(\"../../registry\");function y(){var t=.5;return function(e){if(e.link.circular)return r=e.link,n=r.width/2,i=r.circularPathData,\"top\"===r.circularLinkType?\"M \"+i.targetX+\" \"+(i.targetY+n)+\" L\"+i.rightInnerExtent+\" \"+(i.targetY+n)+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightSmallArcRadius+n)+\" 0 0 1 \"+(i.rightFullExtent-n)+\" \"+(i.targetY-i.rightSmallArcRadius)+\"L\"+(i.rightFullExtent-n)+\" \"+i.verticalRightInnerExtent+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightLargeArcRadius+n)+\" 0 0 1 \"+i.rightInnerExtent+\" \"+(i.verticalFullExtent-n)+\"L\"+i.leftInnerExtent+\" \"+(i.verticalFullExtent-n)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftLargeArcRadius+n)+\" 0 0 1 \"+(i.leftFullExtent+n)+\" \"+i.verticalLeftInnerExtent+\"L\"+(i.leftFullExtent+n)+\" \"+(i.sourceY-i.leftSmallArcRadius)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftSmallArcRadius+n)+\" 0 0 1 \"+i.leftInnerExtent+\" \"+(i.sourceY+n)+\"L\"+i.sourceX+\" \"+(i.sourceY+n)+\"L\"+i.sourceX+\" \"+(i.sourceY-n)+\"L\"+i.leftInnerExtent+\" \"+(i.sourceY-n)+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftSmallArcRadius-n)+\" 0 0 0 \"+(i.leftFullExtent-n)+\" \"+(i.sourceY-i.leftSmallArcRadius)+\"L\"+(i.leftFullExtent-n)+\" \"+i.verticalLeftInnerExtent+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftLargeArcRadius-n)+\" 0 0 0 \"+i.leftInnerExtent+\" \"+(i.verticalFullExtent+n)+\"L\"+i.rightInnerExtent+\" \"+(i.verticalFullExtent+n)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightLargeArcRadius-n)+\" 0 0 0 \"+(i.rightFullExtent+n)+\" \"+i.verticalRightInnerExtent+\"L\"+(i.rightFullExtent+n)+\" \"+(i.targetY-i.rightSmallArcRadius)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightSmallArcRadius-n)+\" 0 0 0 \"+i.rightInnerExtent+\" \"+(i.targetY-n)+\"L\"+i.targetX+\" \"+(i.targetY-n)+\"Z\":\"M \"+i.targetX+\" \"+(i.targetY-n)+\" L\"+i.rightInnerExtent+\" \"+(i.targetY-n)+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightSmallArcRadius+n)+\" 0 0 0 \"+(i.rightFullExtent-n)+\" \"+(i.targetY+i.rightSmallArcRadius)+\"L\"+(i.rightFullExtent-n)+\" \"+i.verticalRightInnerExtent+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightLargeArcRadius+n)+\" 0 0 0 \"+i.rightInnerExtent+\" \"+(i.verticalFullExtent+n)+\"L\"+i.leftInnerExtent+\" \"+(i.verticalFullExtent+n)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftLargeArcRadius+n)+\" 0 0 0 \"+(i.leftFullExtent+n)+\" \"+i.verticalLeftInnerExtent+\"L\"+(i.leftFullExtent+n)+\" \"+(i.sourceY+i.leftSmallArcRadius)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftSmallArcRadius+n)+\" 0 0 0 \"+i.leftInnerExtent+\" \"+(i.sourceY-n)+\"L\"+i.sourceX+\" \"+(i.sourceY-n)+\"L\"+i.sourceX+\" \"+(i.sourceY+n)+\"L\"+i.leftInnerExtent+\" \"+(i.sourceY+n)+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftSmallArcRadius-n)+\" 0 0 1 \"+(i.leftFullExtent-n)+\" \"+(i.sourceY+i.leftSmallArcRadius)+\"L\"+(i.leftFullExtent-n)+\" \"+i.verticalLeftInnerExtent+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftLargeArcRadius-n)+\" 0 0 1 \"+i.leftInnerExtent+\" \"+(i.verticalFullExtent-n)+\"L\"+i.rightInnerExtent+\" \"+(i.verticalFullExtent-n)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightLargeArcRadius-n)+\" 0 0 1 \"+(i.rightFullExtent+n)+\" \"+i.verticalRightInnerExtent+\"L\"+(i.rightFullExtent+n)+\" \"+(i.targetY+i.rightSmallArcRadius)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightSmallArcRadius-n)+\" 0 0 1 \"+i.rightInnerExtent+\" \"+(i.targetY+n)+\"L\"+i.targetX+\" \"+(i.targetY+n)+\"Z\";var r,n,i,a=e.link.source.x1,o=e.link.target.x0,s=v(a,o),l=s(t),c=s(1-t),u=e.link.y0-e.link.width/2,h=e.link.y0+e.link.width/2,f=e.link.y1-e.link.width/2,p=e.link.y1+e.link.width/2;return\"M\"+a+\",\"+u+\"C\"+l+\",\"+u+\" \"+c+\",\"+f+\" \"+o+\",\"+f+\"L\"+o+\",\"+p+\"C\"+c+\",\"+p+\" \"+l+\",\"+h+\" \"+a+\",\"+h+\"Z\"}}function x(t){t.attr(\"transform\",function(t){return\"translate(\"+t.node.x0.toFixed(3)+\", \"+t.node.y0.toFixed(3)+\")\"})}function b(t){t.call(x)}function _(t,e){t.call(b),e.attr(\"d\",y())}function w(t){t.attr(\"width\",function(t){return t.node.x1-t.node.x0}).attr(\"height\",function(t){return t.visibleHeight})}function k(t){return t.link.width>1||t.linkLineWidth>0}function T(t){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"+(t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\")}function A(t){return\"translate(\"+(t.horizontal?0:t.labelY)+\" \"+(t.horizontal?t.labelY:0)+\")\"}function M(t){return i.svg.line()([[t.horizontal?t.left?-t.sizeAcross:t.visibleWidth+n.nodeTextOffsetHorizontal:n.nodeTextOffsetHorizontal,0],[t.horizontal?t.left?-n.nodeTextOffsetHorizontal:t.sizeAcross:t.visibleHeight-n.nodeTextOffsetHorizontal,0]])}function S(t){return t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\"}function E(t){return t.horizontal?\"scale(1 1)\":\"scale(-1 1)\"}function C(t){return t.darkBackground&&!t.horizontal?\"rgb(255,255,255)\":\"rgb(0,0,0)\"}function L(t){return t.horizontal&&t.left?\"100%\":\"0%\"}function P(t,e,r){t.on(\".basic\",null).on(\"mouseover.basic\",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.hover(this,t,e),t.interactionState.hovered=[this,t])}).on(\"mousemove.basic\",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.follow(this,t),t.interactionState.hovered=[this,t])}).on(\"mouseout.basic\",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.unhover(this,t,e),t.interactionState.hovered=!1)}).on(\"click.basic\",function(t){t.interactionState.hovered&&(r.unhover(this,t,e),t.interactionState.hovered=!1),t.interactionState.dragInProgress||t.partOfGroup||r.select(this,t,e)})}function O(t,e,r,a){var o=i.behavior.drag().origin(function(t){return{x:t.node.x0+t.visibleWidth/2,y:t.node.y0+t.visibleHeight/2}}).on(\"dragstart\",function(i){if(\"fixed\"!==i.arrangement&&(h.ensureSingle(a._fullLayout._infolayer,\"g\",\"dragcover\",function(t){a._fullLayout._dragCover=t}),h.raiseToTop(this),i.interactionState.dragInProgress=i.node,I(i.node),i.interactionState.hovered&&(r.nodeEvents.unhover.apply(0,i.interactionState.hovered),i.interactionState.hovered=!1),\"snap\"===i.arrangement)){var o=i.traceId+\"|\"+i.key;i.forceLayouts[o]?i.forceLayouts[o].alpha(1):function(t,e,r,i){!function(t){for(var e=0;e<t.length;e++)t[e].y=(t[e].y0+t[e].y1)/2,t[e].x=(t[e].x0+t[e].x1)/2}(r.graph.nodes);var a=r.graph.nodes.filter(function(t){return t.originalX===r.node.originalX}).filter(function(t){return!t.partOfGroup});r.forceLayouts[e]=u.forceSimulation(a).alphaDecay(0).force(\"collide\",u.forceCollide().radius(function(t){return t.dy/2+r.nodePad/2}).strength(1).iterations(n.forceIterations)).force(\"constrain\",function(t,e,r,i){return function(){for(var t=0,a=0;a<r.length;a++){var o=r[a];o===i.interactionState.dragInProgress?(o.x=o.lastDraggedX,o.y=o.lastDraggedY):(o.vx=(o.originalX-o.x)/n.forceTicksPerFrame,o.y=Math.min(i.size-o.dy/2,Math.max(o.dy/2,o.y))),t=Math.max(t,Math.abs(o.vx),Math.abs(o.vy))}!i.interactionState.dragInProgress&&t<.1&&i.forceLayouts[e].alpha()>0&&i.forceLayouts[e].alpha(0)}}(0,e,a,r)).stop()}(0,o,i),function(t,e,r,i,a){window.requestAnimationFrame(function o(){var s;for(s=0;s<n.forceTicksPerFrame;s++)r.forceLayouts[i].tick();var l=r.graph.nodes;if(function(t){for(var e=0;e<t.length;e++)t[e].y0=t[e].y-t[e].dy/2,t[e].y1=t[e].y0+t[e].dy,t[e].x0=t[e].x-t[e].dx/2,t[e].x1=t[e].x0+t[e].dx}(l),r.sankey.update(r.graph),_(t.filter(D(r)),e),r.forceLayouts[i].alpha()>0)window.requestAnimationFrame(o);else{var c=r.node.originalX;r.node.x0=c-r.visibleWidth/2,r.node.x1=c+r.visibleWidth/2,z(r,a)}})}(t,e,i,o,a)}}).on(\"drag\",function(r){if(\"fixed\"!==r.arrangement){var n=i.event.x,a=i.event.y;\"snap\"===r.arrangement?(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2,r.node.y0=a-r.visibleHeight/2,r.node.y1=a+r.visibleHeight/2):(\"freeform\"===r.arrangement&&(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2),a=Math.max(0,Math.min(r.size-r.visibleHeight/2,a)),r.node.y0=a-r.visibleHeight/2,r.node.y1=a+r.visibleHeight/2),I(r.node),\"snap\"!==r.arrangement&&(r.sankey.update(r.graph),_(t.filter(D(r)),e))}}).on(\"dragend\",function(t){if(\"fixed\"!==t.arrangement){t.interactionState.dragInProgress=!1;for(var e=0;e<t.node.childrenNodes.length;e++)t.node.childrenNodes[e].x=t.node.x,t.node.childrenNodes[e].y=t.node.y;\"snap\"!==t.arrangement&&z(t,a)}});t.on(\".drag\",null).call(o)}function z(t,e){for(var r=[],n=[],i=0;i<t.graph.nodes.length;i++){var a=(t.graph.nodes[i].x0+t.graph.nodes[i].x1)/2,o=(t.graph.nodes[i].y0+t.graph.nodes[i].y1)/2;r.push(a/t.figure.width),n.push(o/t.figure.height)}m.call(\"_guiRestyle\",e,{\"node.x\":[r],\"node.y\":[n]},t.trace.index).then(function(){e._fullLayout._dragCover&&e._fullLayout._dragCover.remove()})}function I(t){t.lastDraggedX=t.x0+t.dx/2,t.lastDraggedY=t.y0+t.dy/2}function D(t){return function(e){return e.node.originalX===t.node.originalX}}e.exports=function(t,e,r,u,f){var v=!1;h.ensureSingle(t._fullLayout._infolayer,\"g\",\"first-render\",function(){v=!0});var m=t._fullLayout._dragCover,b=r.filter(function(t){return g(t).trace.visible}).map(function(t,e,r){var i,o=g(e),s=o.trace,u=s.domain,f=\"h\"===s.orientation,p=s.node.pad,d=s.node.thickness,v=t.width*(u.x[1]-u.x[0]),m=t.height*(u.y[1]-u.y[0]),y=o._nodes,x=o._links,b=o.circular;(i=b?c.sankeyCircular().circularLinkGap(0):l.sankey()).iterations(n.sankeyIterations).size(f?[v,m]:[m,v]).nodeWidth(d).nodePadding(p).nodeId(function(t){return t.pointNumber}).nodes(y).links(x);var _,w,k,T=i();for(var A in i.nodePadding()<p&&h.warn(\"node.pad was reduced to \",i.nodePadding(),\" to fit within the figure.\"),o._groupLookup){var M,S=parseInt(o._groupLookup[A]);for(_=0;_<T.nodes.length;_++)if(T.nodes[_].pointNumber===S){M=T.nodes[_];break}if(M){var E={pointNumber:parseInt(A),x0:M.x0,x1:M.x1,y0:M.y0,y1:M.y1,partOfGroup:!0,sourceLinks:[],targetLinks:[]};T.nodes.unshift(E),M.childrenNodes.unshift(E)}}if(function(){for(_=0;_<T.nodes.length;_++){var t,e,r=T.nodes[_],n={};for(w=0;w<r.targetLinks.length;w++)t=(e=r.targetLinks[w]).source.pointNumber+\":\"+e.target.pointNumber,n.hasOwnProperty(t)||(n[t]=[]),n[t].push(e);var i=Object.keys(n);for(w=0;w<i.length;w++){var o=n[t=i[w]],s=0,l={};for(k=0;k<o.length;k++)l[(e=o[k]).label]||(l[e.label]=0),l[e.label]+=e.value,s+=e.value;for(k=0;k<o.length;k++)(e=o[k]).flow={value:s,labelConcentration:l[e.label]/s,concentration:e.value/s,links:o},e.concentrationscale&&(e.color=a(e.concentrationscale(e.flow.labelConcentration)))}var c=0;for(w=0;w<r.sourceLinks.length;w++)c+=r.sourceLinks[w].value;for(w=0;w<r.sourceLinks.length;w++)(e=r.sourceLinks[w]).concentrationOut=e.value/c;var u=0;for(w=0;w<r.targetLinks.length;w++)u+=r.targetLinks[w].value;for(w=0;w<r.targetLinks.length;w++)(e=r.targetLinks[w]).concenrationIn=e.value/u}}(),s.node.x.length&&s.node.y.length){for(_=0;_<Math.min(s.node.x.length,s.node.y.length,T.nodes.length);_++)if(s.node.x[_]&&s.node.y[_]){var C=[s.node.x[_]*v,s.node.y[_]*m];T.nodes[_].x0=C[0]-d/2,T.nodes[_].x1=C[0]+d/2;var L=T.nodes[_].y1-T.nodes[_].y0;T.nodes[_].y0=C[1]-L/2,T.nodes[_].y1=C[1]+L/2}\"snap\"===s.arrangement&&function(t){t.forEach(function(t){var e,r,n,i=0,a=t.length;for(t.sort(function(t,e){return t.y0-e.y0}),n=0;n<a;++n)(e=t[n]).y0>=i||(r=i-e.y0)>1e-6&&(e.y0+=r,e.y1+=r),i=e.y1+p})}(function(t){var e,r,n=t.map(function(t,e){return{x0:t.x0,index:e}}).sort(function(t,e){return t.x0-e.x0}),i=[],a=-1,o=-1/0;for(_=0;_<n.length;_++){var s=t[n[_].index];s.x0>o+d&&(a+=1,e=s.x0),o=s.x0,i[a]||(i[a]=[]),i[a].push(s),r=e-s.x0,s.x0+=r,s.x1+=r}return i}(y=T.nodes)),i.update(T)}return{circular:b,key:r,trace:s,guid:h.randstr(),horizontal:f,width:v,height:m,nodePad:s.node.pad,nodeLineColor:s.node.line.color,nodeLineWidth:s.node.line.width,linkLineColor:s.link.line.color,linkLineWidth:s.link.line.width,valueFormat:s.valueformat,valueSuffix:s.valuesuffix,textFont:s.textfont,translateX:u.x[0]*t.width+t.margin.l,translateY:t.height-u.y[1]*t.height+t.margin.t,dragParallel:f?m:v,dragPerpendicular:f?v:m,arrangement:s.arrangement,sankey:i,graph:T,forceLayouts:{},interactionState:{dragInProgress:!1,hovered:!1}}}.bind(null,u)),_=e.selectAll(\".\"+n.cn.sankey).data(b,p);_.exit().remove(),_.enter().append(\"g\").classed(n.cn.sankey,!0).style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"shape-rendering\",\"geometricPrecision\").style(\"pointer-events\",\"auto\").attr(\"transform\",T),_.each(function(e,r){t._fullData[r]._sankey=e;var n=\"bgsankey-\"+e.trace.uid+\"-\"+r;h.ensureSingle(t._fullLayout._draggers,\"rect\",n),t._fullData[r]._bgRect=i.select(\".\"+n),t._fullData[r]._bgRect.style(\"pointer-events\",\"all\").attr(\"width\",e.width).attr(\"height\",e.height).attr(\"x\",e.translateX).attr(\"y\",e.translateY).classed(\"bgsankey\",!0).style({fill:\"transparent\",\"stroke-width\":0})}),_.transition().ease(n.ease).duration(n.duration).attr(\"transform\",T);var z=_.selectAll(\".\"+n.cn.sankeyLinks).data(d,p);z.enter().append(\"g\").classed(n.cn.sankeyLinks,!0).style(\"fill\",\"none\");var I=z.selectAll(\".\"+n.cn.sankeyLink).data(function(t){return t.graph.links.filter(function(t){return t.value}).map(function(t,e,r){var n=a(e.color),i=e.source.label+\"|\"+e.target.label+\"__\"+r;return e.trace=t.trace,e.curveNumber=t.trace.index,{circular:t.circular,key:i,traceId:t.key,pointNumber:e.pointNumber,link:e,tinyColorHue:o.tinyRGB(n),tinyColorAlpha:n.getAlpha(),linkPath:y,linkLineColor:t.linkLineColor,linkLineWidth:t.linkLineWidth,valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,parent:t,interactionState:t.interactionState,flow:e.flow}}.bind(null,t))},p);I.enter().append(\"path\").classed(n.cn.sankeyLink,!0).call(P,_,f.linkEvents),I.style(\"stroke\",function(t){return k(t)?o.tinyRGB(a(t.linkLineColor)):t.tinyColorHue}).style(\"stroke-opacity\",function(t){return k(t)?o.opacity(t.linkLineColor):t.tinyColorAlpha}).style(\"fill\",function(t){return t.tinyColorHue}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}).style(\"stroke-width\",function(t){return k(t)?t.linkLineWidth:1}).attr(\"d\",y()),I.style(\"opacity\",function(){return t._context.staticPlot||v||m?1:0}).transition().ease(n.ease).duration(n.duration).style(\"opacity\",1),I.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var D=_.selectAll(\".\"+n.cn.sankeyNodeSet).data(d,p);D.enter().append(\"g\").classed(n.cn.sankeyNodeSet,!0),D.style(\"cursor\",function(t){switch(t.arrangement){case\"fixed\":return\"default\";case\"perpendicular\":return\"ns-resize\";default:return\"move\"}});var R=D.selectAll(\".\"+n.cn.sankeyNode).data(function(t){var e=t.graph.nodes;return function(t){var e,r=[];for(e=0;e<t.length;e++)t[e].originalX=(t[e].x0+t[e].x1)/2,t[e].originalY=(t[e].y0+t[e].y1)/2,-1===r.indexOf(t[e].originalX)&&r.push(t[e].originalX);for(r.sort(function(t,e){return t-e}),e=0;e<t.length;e++)t[e].originalLayerIndex=r.indexOf(t[e].originalX),t[e].originalLayer=t[e].originalLayerIndex/(r.length-1)}(e),e.map(function(t,e){var r=a(e.color),i=n.nodePadAcross,s=t.nodePad/2;e.dx=e.x1-e.x0,e.dy=e.y1-e.y0;var l=e.dx,c=Math.max(.5,e.dy),u=\"node_\"+e.pointNumber;return e.group&&(u=h.randstr()),e.trace=t.trace,e.curveNumber=t.trace.index,{index:e.pointNumber,key:u,partOfGroup:e.partOfGroup||!1,group:e.group,traceId:t.key,trace:t.trace,node:e,nodePad:t.nodePad,nodeLineColor:t.nodeLineColor,nodeLineWidth:t.nodeLineWidth,textFont:t.textFont,size:t.horizontal?t.height:t.width,visibleWidth:Math.ceil(l),visibleHeight:c,zoneX:-i,zoneY:-s,zoneWidth:l+2*i,zoneHeight:c+2*s,labelY:t.horizontal?e.dy/2+1:e.dx/2+1,left:1===e.originalLayer,sizeAcross:t.width,forceLayouts:t.forceLayouts,horizontal:t.horizontal,darkBackground:r.getBrightness()<=128,tinyColorHue:o.tinyRGB(r),tinyColorAlpha:r.getAlpha(),valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,graph:t.graph,arrangement:t.arrangement,uniqueNodeLabelPathId:[t.guid,t.key,u].join(\"_\"),interactionState:t.interactionState,figure:t}}.bind(null,t))},p);R.enter().append(\"g\").classed(n.cn.sankeyNode,!0).call(x).style(\"opacity\",function(e){return!t._context.staticPlot&&!v||e.partOfGroup?0:1}),R.call(P,_,f.nodeEvents).call(O,I,f,t),R.transition().ease(n.ease).duration(n.duration).call(x).style(\"opacity\",function(t){return t.partOfGroup?0:1}),R.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var F=R.selectAll(\".\"+n.cn.nodeRect).data(d);F.enter().append(\"rect\").classed(n.cn.nodeRect,!0).call(w),F.style(\"stroke-width\",function(t){return t.nodeLineWidth}).style(\"stroke\",function(t){return o.tinyRGB(a(t.nodeLineColor))}).style(\"stroke-opacity\",function(t){return o.opacity(t.nodeLineColor)}).style(\"fill\",function(t){return t.tinyColorHue}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),F.transition().ease(n.ease).duration(n.duration).call(w);var B=R.selectAll(\".\"+n.cn.nodeCapture).data(d);B.enter().append(\"rect\").classed(n.cn.nodeCapture,!0).style(\"fill-opacity\",0),B.attr(\"x\",function(t){return t.zoneX}).attr(\"y\",function(t){return t.zoneY}).attr(\"width\",function(t){return t.zoneWidth}).attr(\"height\",function(t){return t.zoneHeight});var N=R.selectAll(\".\"+n.cn.nodeCentered).data(d);N.enter().append(\"g\").classed(n.cn.nodeCentered,!0).attr(\"transform\",A),N.transition().ease(n.ease).duration(n.duration).attr(\"transform\",A);var j=N.selectAll(\".\"+n.cn.nodeLabelGuide).data(d);j.enter().append(\"path\").classed(n.cn.nodeLabelGuide,!0).attr(\"id\",function(t){return t.uniqueNodeLabelPathId}).attr(\"d\",M).attr(\"transform\",S),j.transition().ease(n.ease).duration(n.duration).attr(\"d\",M).attr(\"transform\",S);var U=N.selectAll(\".\"+n.cn.nodeLabel).data(d);U.enter().append(\"text\").classed(n.cn.nodeLabel,!0).attr(\"transform\",E).style(\"user-select\",\"none\").style(\"cursor\",\"default\").style(\"fill\",\"black\"),U.style(\"text-shadow\",function(t){return t.horizontal?\"-1px 1px 1px #fff, 1px 1px 1px #fff, 1px -1px 1px #fff, -1px -1px 1px #fff\":\"none\"}).each(function(t){s.font(U,t.textFont)}),U.transition().ease(n.ease).duration(n.duration).attr(\"transform\",E);var V=U.selectAll(\".\"+n.cn.nodeLabelTextPath).data(d);V.enter().append(\"textPath\").classed(n.cn.nodeLabelTextPath,!0).attr(\"alignment-baseline\",\"middle\").attr(\"xlink:href\",function(t){return\"#\"+t.uniqueNodeLabelPathId}).attr(\"startOffset\",L).style(\"fill\",C),V.text(function(t){return t.horizontal||t.node.dy>5?t.node.label:\"\"}).attr(\"text-anchor\",function(t){return t.horizontal&&t.left?\"end\":\"start\"}),V.transition().ease(n.ease).duration(n.duration).attr(\"startOffset\",L).style(\"fill\",C)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/gup\":717,\"../../registry\":847,\"./constants\":1105,\"@plotly/d3-sankey\":54,\"@plotly/d3-sankey-circular\":53,d3:163,\"d3-force\":156,\"d3-interpolate\":158,tinycolor2:537}],1110:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=[],n=t.cd[0].trace,i=n._sankey.graph.nodes,a=0;a<i.length;a++){var o=i[a];if(!o.partOfGroup){var s=[(o.x0+o.x1)/2,(o.y0+o.y1)/2];\"v\"===n.orientation&&s.reverse(),e&&e.contains(s,!1,a,t)&&r.push({pointNumber:o.pointNumber})}}return r}},{}],1111:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\"),n.mergeArray(e.customdata,t,\"data\"),n.mergeArray(e.textposition,t,\"tp\"),e.textfont&&(n.mergeArrayCastPositive(e.textfont.size,t,\"ts\"),n.mergeArray(e.textfont.color,t,\"tc\"),n.mergeArray(e.textfont.family,t,\"tf\"));var i=e.marker;if(i){n.mergeArrayCastPositive(i.size,t,\"ms\"),n.mergeArrayCastPositive(i.opacity,t,\"mo\"),n.mergeArray(i.symbol,t,\"mx\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;i.line&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"));var o=i.gradient;o&&\"none\"!==o.type&&(n.mergeArray(o.type,t,\"mgt\"),n.mergeArray(o.color,t,\"mgc\"))}}},{\"../../lib\":719}],1112:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../components/drawing/attributes\").dash,s=t(\"../../components/drawing\"),l=t(\"./constants\"),c=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},x0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dx:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},y0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dy:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},stackgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc\"},groupnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},stackgaps:{valType:\"enumerated\",values:[\"infer zero\",\"interpolate\"],dflt:\"infer zero\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"],editType:\"calc\"},hoveron:{valType:\"flaglist\",flags:[\"points\",\"fills\"],editType:\"style\"},hovertemplate:n({},{keys:l.eventDataKeys}),line:{color:{valType:\"color\",editType:\"style\",anim:!0},width:{valType:\"number\",min:0,dflt:2,editType:\"style\",anim:!0},shape:{valType:\"enumerated\",values:[\"linear\",\"spline\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},smoothing:{valType:\"number\",min:0,max:1.3,dflt:1,editType:\"plot\"},dash:c({},o,{editType:\"style\"}),simplify:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cliponaxis:{valType:\"boolean\",dflt:!0,editType:\"plot\"},fill:{valType:\"enumerated\",values:[\"none\",\"tozeroy\",\"tozerox\",\"tonexty\",\"tonextx\",\"toself\",\"tonext\"],editType:\"calc\"},fillcolor:{valType:\"color\",editType:\"style\",anim:!0},marker:c({symbol:{valType:\"enumerated\",values:s.symbolList,dflt:\"circle\",arrayOk:!0,editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,arrayOk:!0,editType:\"style\",anim:!0},size:{valType:\"number\",min:0,dflt:6,arrayOk:!0,editType:\"calc\",anim:!0},maxdisplayed:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},sizeref:{valType:\"number\",dflt:1,editType:\"calc\"},sizemin:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"diameter\",\"area\"],dflt:\"diameter\",editType:\"calc\"},line:c({width:{valType:\"number\",min:0,arrayOk:!0,editType:\"style\",anim:!0},editType:\"calc\"},i(\"marker.line\",{anim:!0})),gradient:{type:{valType:\"enumerated\",values:[\"radial\",\"horizontal\",\"vertical\",\"none\"],arrayOk:!0,dflt:\"none\",editType:\"calc\"},color:{valType:\"color\",arrayOk:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},i(\"marker\",{anim:!0})),selected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},unselected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\"],dflt:\"middle center\",arrayOk:!0,editType:\"calc\"},textfont:a({editType:\"calc\",colorEditType:\"style\",arrayOk:!0}),r:{valType:\"data_array\",editType:\"calc\"},t:{valType:\"data_array\",editType:\"calc\"}}},{\"../../components/colorscale/attributes\":600,\"../../components/drawing\":614,\"../../components/drawing/attributes\":613,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"./constants\":1116}],1113:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/numerical\").BADNUM,s=t(\"./subtypes\"),l=t(\"./colorscale_calc\"),c=t(\"./arrays_to_calcdata\"),u=t(\"./calc_selection\");function h(t,e,r,n,i,o,l){var c=e._length,u=t._fullLayout,h=r._id,f=n._id,p=u._firstScatter[d(e)]===e.uid,v=(g(e,u,r,n)||{}).orientation,m=e.fill;r._minDtick=0,n._minDtick=0;var y={padded:!0},x={padded:!0};l&&(y.ppad=x.ppad=l);var b=c<2||i[0]!==i[c-1]||o[0]!==o[c-1];b&&(\"tozerox\"===m||\"tonextx\"===m&&(p||\"h\"===v))?y.tozero=!0:(e.error_y||{}).visible||\"tonexty\"!==m&&\"tozeroy\"!==m&&(s.hasMarkers(e)||s.hasText(e))||(y.padded=!1,y.ppad=0),b&&(\"tozeroy\"===m||\"tonexty\"===m&&(p||\"v\"===v))?x.tozero=!0:\"tonextx\"!==m&&\"tozerox\"!==m||(x.padded=!1),h&&(e._extremes[h]=a.findExtremes(r,i,y)),f&&(e._extremes[f]=a.findExtremes(n,o,x))}function f(t,e){if(s.hasMarkers(t)){var r,n=t.marker,o=1.6*(t.marker.sizeref||1);if(r=\"area\"===t.marker.sizemode?function(t){return Math.max(Math.sqrt((t||0)/o),3)}:function(t){return Math.max((t||0)/o,3)},i.isArrayOrTypedArray(n.size)){var l={type:\"linear\"};a.setConvert(l);for(var c=l.makeCalcdata(t.marker,\"size\"),u=new Array(e),h=0;h<e;h++)u[h]=r(c[h]);return u}return r(n.size)}}function p(t,e){var r=d(e),n=t._firstScatter;n[r]||(n[r]=e.uid)}function d(t){var e=t.stackgroup;return t.xaxis+t.yaxis+t.type+(e?\"-\"+e:\"\")}function g(t,e,r,n){var i=t.stackgroup;if(i){var a=e._scatterStackOpts[r._id+n._id][i],o=\"v\"===a.orientation?n:r;return\"linear\"===o.type||\"log\"===o.type?a:void 0}}e.exports={calc:function(t,e){var r,s,d,v,m,y,x=t._fullLayout,b=a.getFromId(t,e.xaxis||\"x\"),_=a.getFromId(t,e.yaxis||\"y\"),w=b.makeCalcdata(e,\"x\"),k=_.makeCalcdata(e,\"y\"),T=e._length,A=new Array(T),M=e.ids,S=g(e,x,b,_),E=!1;p(x,e);var C,L=\"x\",P=\"y\";for(S?(i.pushUnique(S.traceIndices,e._expandedIndex),(r=\"v\"===S.orientation)?(P=\"s\",C=\"x\"):(L=\"s\",C=\"y\"),m=\"interpolate\"===S.stackgaps):h(t,e,b,_,w,k,f(e,T)),s=0;s<T;s++){var O=A[s]={},z=n(w[s]),I=n(k[s]);z&&I?(O[L]=w[s],O[P]=k[s]):S&&(r?z:I)?(O[C]=r?w[s]:k[s],O.gap=!0,m?(O.s=o,E=!0):O.s=0):O[L]=O[P]=o,M&&(O.id=String(M[s]))}if(c(A,e),l(t,e),u(A,e),S){for(s=0;s<A.length;)A[s][C]===o?A.splice(s,1):s++;if(i.sort(A,function(t,e){return t[C]-e[C]||t.i-e.i}),E){for(s=0;s<A.length-1&&A[s].gap;)s++;for((y=A[s].s)||(y=A[s].s=0),d=0;d<s;d++)A[d].s=y;for(v=A.length-1;v>s&&A[v].gap;)v--;for(y=A[v].s,d=A.length-1;d>v;d--)A[d].s=y;for(;s<v;)if(A[++s].gap){for(d=s+1;A[d].gap;)d++;for(var D=A[s-1][C],R=A[s-1].s,F=(A[d].s-R)/(A[d][C]-D);s<d;)A[s].s=R+(A[s][C]-D)*F,s++}}}return A},calcMarkerSize:f,calcAxisExpansion:h,setFirstScatter:p,getStackOpts:g}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./arrays_to_calcdata\":1111,\"./calc_selection\":1114,\"./colorscale_calc\":1115,\"./subtypes\":1135,\"fast-isnumeric\":225}],1114:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){n.isArrayOrTypedArray(e.selectedpoints)&&n.tagSelected(t,e)}},{\"../../lib\":719}],1115:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"./subtypes\");e.exports=function(t,e){a.hasLines(e)&&n(e,\"line\")&&i(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),a.hasMarkers(e)&&(n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}))}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"./subtypes\":1135}],1116:[function(t,e,r){\"use strict\";e.exports={PTS_LINESONLY:20,minTolerance:.2,toleranceGrowth:10,maxScreensAway:20,eventDataKeys:[]}},{}],1117:[function(t,e,r){\"use strict\";var n=t(\"./calc\");function i(t,e,r,n,i,a,o){i[n]=!0;var s={i:null,gap:!0,s:0};if(s[o]=r,t.splice(e,0,s),e&&r===t[e-1][o]){var l=t[e-1];s.s=l.s,s.i=l.i,s.gap=l.gap}else a&&(s.s=function(t,e,r,n){var i=t[e-1],a=t[e+1];return a?i?i.s+(a.s-i.s)*(r-i[n])/(a[n]-i[n]):a.s:i.s}(t,e,r,o));e||(t[0].t=t[1].t,t[0].trace=t[1].trace,delete t[1].t,delete t[1].trace)}e.exports=function(t,e){var r=e.xaxis,a=e.yaxis,o=r._id+a._id,s=t._fullLayout._scatterStackOpts[o];if(s){var l,c,u,h,f,p,d,g,v,m,y,x,b,_,w,k=t.calcdata;for(var T in s){var A=(m=s[T]).traceIndices;if(A.length){for(y=\"interpolate\"===m.stackgaps,x=m.groupnorm,\"v\"===m.orientation?(b=\"x\",_=\"y\"):(b=\"y\",_=\"x\"),w=new Array(A.length),l=0;l<w.length;l++)w[l]=!1;p=k[A[0]];var M=new Array(p.length);for(l=0;l<p.length;l++)M[l]=p[l][b];for(l=1;l<A.length;l++){for(f=k[A[l]],c=u=0;c<f.length;c++){for(d=f[c][b];d>M[u]&&u<M.length;u++)i(f,c,M[u],l,w,y,b),c++;if(d!==M[u]){for(h=0;h<l;h++)i(k[A[h]],u,d,h,w,y,b);M.splice(u,0,d)}u++}for(;u<M.length;u++)i(f,c,M[u],l,w,y,b),c++}var S=M.length;for(c=0;c<p.length;c++){for(g=p[c][_]=p[c].s,l=1;l<A.length;l++)(f=k[A[l]])[0].trace._rawLength=f[0].trace._length,f[0].trace._length=S,g+=f[c].s,f[c][_]=g;if(x)for(v=(\"fraction\"===x?g:g/100)||1,l=0;l<A.length;l++){var E=k[A[l]][c];E[_]/=v,E.sNorm=E.s/v}}for(l=0;l<A.length;l++){var C=(f=k[A[l]])[0].trace,L=n.calcMarkerSize(C,C._rawLength),P=Array.isArray(L);if(L&&w[l]||P){var O=L;for(L=new Array(S),c=0;c<S;c++)L[c]=f[c].gap?0:P?O[f[c].i]:O}var z=new Array(S),I=new Array(S);for(c=0;c<S;c++)z[c]=f[c].x,I[c]=f[c].y;n.calcAxisExpansion(t,C,r,a,z,I,L),f[0].t.orientation=m.orientation}}}}}},{\"./calc\":1113}],1118:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0;e<t.length;e++){var r=t[e];if(\"scatter\"===r.type){var n=r.fill;if(\"none\"!==n&&\"toself\"!==n&&(r.opacity=void 0,\"tonexty\"===n||\"tonextx\"===n))for(var i=e-1;i>=0;i--){var a=t[i];if(\"scatter\"===a.type&&a.xaxis===r.xaxis&&a.yaxis===r.yaxis){a.opacity=void 0;break}}}}}},{}],1119:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"./constants\"),s=t(\"./subtypes\"),l=t(\"./xy_defaults\"),c=t(\"./stack_defaults\"),u=t(\"./marker_defaults\"),h=t(\"./line_defaults\"),f=t(\"./line_shape_defaults\"),p=t(\"./text_defaults\"),d=t(\"./fillcolor_defaults\");e.exports=function(t,e,r,g){function v(r,i){return n.coerce(t,e,a,r,i)}var m=l(t,e,g,v);if(m||(e.visible=!1),e.visible){var y=c(t,e,g,v),x=!y&&m<o.PTS_LINESONLY?\"lines+markers\":\"lines\";v(\"text\"),v(\"hovertext\"),v(\"mode\",x),s.hasLines(e)&&(h(t,e,r,g,v),f(t,e,v),v(\"connectgaps\"),v(\"line.simplify\")),s.hasMarkers(e)&&u(t,e,r,g,v,{gradient:!0}),s.hasText(e)&&p(t,e,g,v);var b=[];(s.hasMarkers(e)||s.hasText(e))&&(v(\"cliponaxis\"),v(\"marker.maxdisplayed\"),b.push(\"points\")),v(\"fill\",y?y.fillDflt:\"none\"),\"none\"!==e.fill&&(d(t,e,r,v),s.hasLines(e)||f(t,e,v));var _=(e.line||{}).color,w=(e.marker||{}).color;\"tonext\"!==e.fill&&\"toself\"!==e.fill||b.push(\"fills\"),v(\"hoveron\",b.join(\"+\")||\"points\"),\"fills\"!==e.hoveron&&v(\"hovertemplate\");var k=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");k(t,e,_||w||r,{axis:\"y\"}),k(t,e,_||w||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,v)}}},{\"../../lib\":719,\"../../registry\":847,\"./attributes\":1112,\"./constants\":1116,\"./fillcolor_defaults\":1120,\"./line_defaults\":1124,\"./line_shape_defaults\":1126,\"./marker_defaults\":1130,\"./stack_defaults\":1133,\"./subtypes\":1135,\"./text_defaults\":1136,\"./xy_defaults\":1137}],1120:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a){var o=!1;if(e.marker){var s=e.marker.color,l=(e.marker.line||{}).color;s&&!i(s)?o=s:l&&!i(l)&&(o=l)}a(\"fillcolor\",n.addOpacity((e.line||{}).color||o||r,.5))}},{\"../../components/color\":593,\"../../lib\":719}],1121:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./subtypes\");e.exports=function(t,e){var r,a;if(\"lines\"===t.mode)return(r=t.line.color)&&n.opacity(r)?r:t.fillcolor;if(\"none\"===t.mode)return t.fill?t.fillcolor:\"\";var o=e.mcc||(t.marker||{}).color,s=e.mlcc||((t.marker||{}).line||{}).color;return(a=o&&n.opacity(o)?o:s&&n.opacity(s)&&(e.mlw||((t.marker||{}).line||{}).width)?s:\"\")?n.opacity(a)<.3?n.addOpacity(a,.3):a:(r=(t.line||{}).color)&&n.opacity(r)&&i.hasLines(t)&&t.line.width?r:t.fillcolor}},{\"../../components/color\":593,\"./subtypes\":1135}],1122:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/fx\"),a=t(\"../../registry\"),o=t(\"./get_trace_color\"),s=t(\"../../components/color\"),l=n.fillText;e.exports=function(t,e,r,c){var u=t.cd,h=u[0].trace,f=t.xa,p=t.ya,d=f.c2p(e),g=p.c2p(r),v=[d,g],m=h.hoveron||\"\",y=-1!==h.mode.indexOf(\"markers\")?3:.5;if(-1!==m.indexOf(\"points\")){var x=function(t){var e=Math.max(y,t.mrc||0),r=f.c2p(t.x)-d,n=p.c2p(t.y)-g;return Math.max(Math.sqrt(r*r+n*n)-e,1-y/e)},b=i.getDistanceFunction(c,function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(f.c2p(t.x)-d);return n<e?r*n/e:n-e+r},function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(p.c2p(t.y)-g);return n<e?r*n/e:n-e+r},x);if(i.getClosest(u,b,t),!1!==t.index){var _=u[t.index],w=f.c2p(_.x,!0),k=p.c2p(_.y,!0),T=_.mrc||1;t.index=_.i;var A=u[0].t.orientation,M=A&&(_.sNorm||_.s),S=\"h\"===A?M:_.x,E=\"v\"===A?M:_.y;return n.extendFlat(t,{color:o(h,_),x0:w-T,x1:w+T,xLabelVal:S,y0:k-T,y1:k+T,yLabelVal:E,spikeDistance:x(_),hovertemplate:h.hovertemplate}),l(_,h,t),a.getComponentMethod(\"errorbars\",\"hoverInfo\")(_,h,t),[t]}}if(-1!==m.indexOf(\"fills\")&&h._polygons){var C,L,P,O,z,I,D,R,F,B=h._polygons,N=[],j=!1,U=1/0,V=-1/0,q=1/0,H=-1/0;for(C=0;C<B.length;C++)(P=B[C]).contains(v)&&(j=!j,N.push(P),q=Math.min(q,P.ymin),H=Math.max(H,P.ymax));if(j){var G=((q=Math.max(q,0))+(H=Math.min(H,p._length)))/2;for(C=0;C<N.length;C++)for(O=N[C].pts,L=1;L<O.length;L++)(R=O[L-1][1])>G!=(F=O[L][1])>=G&&(I=O[L-1][0],D=O[L][0],F-R&&(z=I+(D-I)*(G-R)/(F-R),U=Math.min(U,z),V=Math.max(V,z)));U=Math.max(U,0),V=Math.min(V,f._length);var Y=s.defaultLine;return s.opacity(h.fillcolor)?Y=h.fillcolor:s.opacity((h.line||{}).color)&&(Y=h.line.color),n.extendFlat(t,{distance:t.maxHoverDistance,x0:U,x1:V,y0:G,y1:G,color:Y,hovertemplate:!1}),delete t.index,h.text&&!Array.isArray(h.text)?t.text=String(h.text):t.text=h.name,[t]}}}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"../../registry\":847,\"./get_trace_color\":1121}],1123:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports={hasLines:n.hasLines,hasMarkers:n.hasMarkers,hasText:n.hasText,isBubble:n.isBubble,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./cross_trace_calc\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\"),colorbar:t(\"./marker_colorbar\"),style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"./select\"),animatable:!0,moduleType:\"trace\",name:\"scatter\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"./arrays_to_calcdata\":1111,\"./attributes\":1112,\"./calc\":1113,\"./cross_trace_calc\":1117,\"./cross_trace_defaults\":1118,\"./defaults\":1119,\"./hover\":1122,\"./marker_colorbar\":1129,\"./plot\":1131,\"./select\":1132,\"./style\":1134,\"./subtypes\":1135}],1124:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s,l){var c=(t.marker||{}).color;(s(\"line.color\",r),i(t,\"line\"))?a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}):s(\"line.color\",!n(c)&&c||r);s(\"line.width\"),(l||{}).noDash||s(\"line.dash\")}},{\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"../../lib\":719}],1125:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.BADNUM,a=n.LOG_CLIP,o=a+.5,s=a-.5,l=t(\"../../lib\"),c=l.segmentsIntersect,u=l.constrain,h=t(\"./constants\");e.exports=function(t,e){var r,n,a,f,p,d,g,v,m,y,x,b,_,w,k,T,A,M,S=e.xaxis,E=e.yaxis,C=\"log\"===S.type,L=\"log\"===E.type,P=S._length,O=E._length,z=e.connectGaps,I=e.baseTolerance,D=e.shape,R=\"linear\"===D,F=e.fill&&\"none\"!==e.fill,B=[],N=h.minTolerance,j=t.length,U=new Array(j),V=0;function q(e){var r=t[e];if(!r)return!1;var n=S.c2p(r.x),a=E.c2p(r.y);if(n===i){if(C&&(n=S.c2p(r.x,!0)),n===i)return!1;L&&a===i&&(n*=Math.abs(S._m*O*(S._m>0?o:s)/(E._m*P*(E._m>0?o:s)))),n*=1e3}if(a===i){if(L&&(a=E.c2p(r.y,!0)),a===i)return!1;a*=1e3}return[n,a]}function H(t,e,r,n){var i=r-t,a=n-e,o=.5-t,s=.5-e,l=i*i+a*a,c=i*o+a*s;if(c>0&&c<l){var u=o*a-s*i;if(u*u<l)return!0}}function G(t,e){var r=t[0]/P,n=t[1]/O,i=Math.max(0,-r,r-1,-n,n-1);return i&&void 0!==A&&H(r,n,A,M)&&(i=0),i&&e&&H(r,n,e[0]/P,e[1]/O)&&(i=0),(1+h.toleranceGrowth*i)*I}function Y(t,e){var r=t[0]-e[0],n=t[1]-e[1];return Math.sqrt(r*r+n*n)}var W,X,Z,J,K,$,Q,tt=h.maxScreensAway,et=-P*tt,rt=P*(1+tt),nt=-O*tt,it=O*(1+tt),at=[[et,nt,rt,nt],[rt,nt,rt,it],[rt,it,et,it],[et,it,et,nt]];function ot(t){if(t[0]<et||t[0]>rt||t[1]<nt||t[1]>it)return[u(t[0],et,rt),u(t[1],nt,it)]}function st(t,e){return t[0]===e[0]&&(t[0]===et||t[0]===rt)||(t[1]===e[1]&&(t[1]===nt||t[1]===it)||void 0)}function lt(t,e,r){return function(n,i){var a=ot(n),o=ot(i),s=[];if(a&&o&&st(a,o))return s;a&&s.push(a),o&&s.push(o);var c=2*l.constrain((n[t]+i[t])/2,e,r)-((a||n)[t]+(o||i)[t]);c&&((a&&o?c>0==a[t]>o[t]?a:o:a||o)[t]+=c);return s}}function ct(t){var e=t[0],r=t[1],n=e===U[V-1][0],i=r===U[V-1][1];if(!n||!i)if(V>1){var a=e===U[V-2][0],o=r===U[V-2][1];n&&(e===et||e===rt)&&a?o?V--:U[V-1]=t:i&&(r===nt||r===it)&&o?a?V--:U[V-1]=t:U[V++]=t}else U[V++]=t}function ut(t){U[V-1][0]!==t[0]&&U[V-1][1]!==t[1]&&ct([Z,J]),ct(t),K=null,Z=J=0}function ht(t){if(A=t[0]/P,M=t[1]/O,W=t[0]<et?et:t[0]>rt?rt:0,X=t[1]<nt?nt:t[1]>it?it:0,W||X){if(V)if(K){var e=Q(K,t);e.length>1&&(ut(e[0]),U[V++]=e[1])}else $=Q(U[V-1],t)[0],U[V++]=$;else U[V++]=[W||t[0],X||t[1]];var r=U[V-1];W&&X&&(r[0]!==W||r[1]!==X)?(K&&(Z!==W&&J!==X?ct(Z&&J?(n=K,a=(i=t)[0]-n[0],o=(i[1]-n[1])/a,(n[1]*i[0]-i[1]*n[0])/a>0?[o>0?et:rt,it]:[o>0?rt:et,nt]):[Z||W,J||X]):Z&&J&&ct([Z,J])),ct([W,X])):Z-W&&J-X&&ct([W||Z,X||J]),K=t,Z=W,J=X}else K&&ut(Q(K,t)[0]),U[V++]=t;var n,i,a,o}for(\"linear\"===D||\"spline\"===D?Q=function(t,e){for(var r=[],n=0,i=0;i<4;i++){var a=at[i],o=c(t[0],t[1],e[0],e[1],a[0],a[1],a[2],a[3]);o&&(!n||Math.abs(o.x-r[0][0])>1||Math.abs(o.y-r[0][1])>1)&&(o=[o.x,o.y],n&&Y(o,t)<Y(r[0],t)?r.unshift(o):r.push(o),n++)}return r}:\"hv\"===D||\"vh\"===D?Q=function(t,e){var r=[],n=ot(t),i=ot(e);return n&&i&&st(n,i)?r:(n&&r.push(n),i&&r.push(i),r)}:\"hvh\"===D?Q=lt(0,et,rt):\"vhv\"===D&&(Q=lt(1,nt,it)),r=0;r<j;r++)if(n=q(r)){for(V=0,K=null,ht(n),r++;r<j;r++){if(!(f=q(r))){if(z)continue;break}if(R&&e.simplify){var ft=q(r+1);if(y=Y(f,n),F&&(0===V||V===j-1)||!(y<G(f,ft)*N)){for(v=[(f[0]-n[0])/y,(f[1]-n[1])/y],p=n,x=y,b=w=k=0,g=!1,a=f,r++;r<t.length;r++){if(d=ft,ft=q(r+1),!d){if(z)continue;break}if(T=(m=[d[0]-n[0],d[1]-n[1]])[0]*v[1]-m[1]*v[0],w=Math.min(w,T),(k=Math.max(k,T))-w>G(d,ft))break;a=d,(_=m[0]*v[0]+m[1]*v[1])>x?(x=_,f=d,g=!1):_<b&&(b=_,p=d,g=!0)}if(g?(ht(f),a!==p&&ht(p)):(p!==n&&ht(p),a!==f&&ht(f)),ht(a),r>=t.length||!d)break;ht(d),n=d}}else ht(f)}K&&ct([Z||K[0],J||K[1]]),B.push(U.slice(0,V))}return B}},{\"../../constants/numerical\":695,\"../../lib\":719,\"./constants\":1116}],1126:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){\"spline\"===r(\"line.shape\")&&r(\"line.smoothing\")}},{}],1127:[function(t,e,r){\"use strict\";var n={tonextx:1,tonexty:1,tonext:1};e.exports=function(t,e,r){var i,a,o,s,l,c={},u=!1,h=-1,f=0,p=-1;for(a=0;a<r.length;a++)(o=(i=r[a][0].trace).stackgroup||\"\")?o in c?l=c[o]:(l=c[o]=f,f++):i.fill in n&&p>=0?l=p:(l=p=f,f++),l<h&&(u=!0),i._groupIndex=h=l;var d=r.slice();u&&d.sort(function(t,e){var r=t[0].trace,n=e[0].trace;return r._groupIndex-n._groupIndex||r.index-n.index});var g={};for(a=0;a<d.length;a++)o=(i=d[a][0].trace).stackgroup||\"\",!0===i.visible?(i._nexttrace=null,i.fill in n&&(s=g[o],i._prevtrace=s||null,s&&(s._nexttrace=i)),i._ownfill=i.fill&&(\"tozero\"===i.fill.substr(0,6)||\"toself\"===i.fill||\"to\"===i.fill.substr(0,2)&&!i._prevtrace),g[o]=i):i._prevtrace=i._nexttrace=i._ownfill=null;return d}},{}],1128:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t){var e=t.marker,r=e.sizeref||1,i=e.sizemin||0,a=\"area\"===e.sizemode?function(t){return Math.sqrt(t/r)}:function(t){return t/r};return function(t){var e=a(t/2);return n(e)&&e>0?Math.max(e,i):0}}},{\"fast-isnumeric\":225}],1129:[function(t,e,r){\"use strict\";e.exports={container:\"marker\",min:\"cmin\",max:\"cmax\"}},{}],1130:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"./subtypes\");e.exports=function(t,e,r,s,l,c){var u=o.isBubble(t),h=(t.line||{}).color;(c=c||{},h&&(r=h),l(\"marker.symbol\"),l(\"marker.opacity\",u?.7:1),l(\"marker.size\"),l(\"marker.color\",r),i(t,\"marker\")&&a(t,e,s,l,{prefix:\"marker.\",cLetter:\"c\"}),c.noSelect||(l(\"selected.marker.color\"),l(\"unselected.marker.color\"),l(\"selected.marker.size\"),l(\"unselected.marker.size\")),c.noLine||(l(\"marker.line.color\",h&&!Array.isArray(h)&&e.marker.color!==h?h:u?n.background:n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,l,{prefix:\"marker.line.\",cLetter:\"c\"}),l(\"marker.line.width\",u?1:0)),u&&(l(\"marker.sizeref\"),l(\"marker.sizemin\"),l(\"marker.sizemode\")),c.gradient)&&(\"none\"!==l(\"marker.gradient.type\")&&l(\"marker.gradient.color\"))}},{\"../../components/color\":593,\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"./subtypes\":1135}],1131:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=a.ensureSingle,s=a.identity,l=t(\"../../components/drawing\"),c=t(\"./subtypes\"),u=t(\"./line_points\"),h=t(\"./link_traces\"),f=t(\"../../lib/polygon\").tester;function p(t,e,r,h,p,d,g){var v;!function(t,e,r,i,o){var s=r.xaxis,l=r.yaxis,u=n.extent(a.simpleMap(s.range,s.r2c)),h=n.extent(a.simpleMap(l.range,l.r2c)),f=i[0].trace;if(!c.hasMarkers(f))return;var p=f.marker.maxdisplayed;if(0===p)return;var d=i.filter(function(t){return t.x>=u[0]&&t.x<=u[1]&&t.y>=h[0]&&t.y<=h[1]}),g=Math.ceil(d.length/p),v=0;o.forEach(function(t,r){var n=t[0].trace;c.hasMarkers(n)&&n.marker.maxdisplayed>0&&r<e&&v++});var m=Math.round(v*g/3+Math.floor(v/3)*g/7.1);i.forEach(function(t){delete t.vis}),d.forEach(function(t,e){0===Math.round((e+m)%g)&&(t.vis=!0)})}(0,e,r,h,p);var m=!!g&&g.duration>0;function y(t){return m?t.transition():t}var x=r.xaxis,b=r.yaxis,_=h[0].trace,w=_.line,k=n.select(d),T=o(k,\"g\",\"errorbars\"),A=o(k,\"g\",\"lines\"),M=o(k,\"g\",\"points\"),S=o(k,\"g\",\"text\");if(i.getComponentMethod(\"errorbars\",\"plot\")(t,T,r,g),!0===_.visible){var E,C;y(k).style(\"opacity\",_.opacity);var L=_.fill.charAt(_.fill.length-1);\"x\"!==L&&\"y\"!==L&&(L=\"\"),h[0][r.isRangePlot?\"nodeRangePlot3\":\"node3\"]=k;var P,O,z=\"\",I=[],D=_._prevtrace;D&&(z=D._prevRevpath||\"\",C=D._nextFill,I=D._polygons);var R,F,B,N,j,U,V,q=\"\",H=\"\",G=[],Y=a.noop;if(E=_._ownFill,c.hasLines(_)||\"none\"!==_.fill){for(C&&C.datum(h),-1!==[\"hv\",\"vh\",\"hvh\",\"vhv\"].indexOf(w.shape)?(R=l.steps(w.shape),F=l.steps(w.shape.split(\"\").reverse().join(\"\"))):R=F=\"spline\"===w.shape?function(t){var e=t[t.length-1];return t.length>1&&t[0][0]===e[0]&&t[0][1]===e[1]?l.smoothclosed(t.slice(1),w.smoothing):l.smoothopen(t,w.smoothing)}:function(t){return\"M\"+t.join(\"L\")},B=function(t){return F(t.reverse())},G=u(h,{xaxis:x,yaxis:b,connectGaps:_.connectgaps,baseTolerance:Math.max(w.width||1,3)/4,shape:w.shape,simplify:w.simplify,fill:_.fill}),V=_._polygons=new Array(G.length),v=0;v<G.length;v++)_._polygons[v]=f(G[v]);G.length&&(N=G[0][0],U=(j=G[G.length-1])[j.length-1]),Y=function(t){return function(e){if(P=R(e),O=B(e),q?L?(q+=\"L\"+P.substr(1),H=O+\"L\"+H.substr(1)):(q+=\"Z\"+P,H=O+\"Z\"+H):(q=P,H=O),c.hasLines(_)&&e.length>1){var r=n.select(this);if(r.datum(h),t)y(r.style(\"opacity\",0).attr(\"d\",P).call(l.lineGroupStyle)).style(\"opacity\",1);else{var i=y(r);i.attr(\"d\",P),l.singleLineStyle(h,i)}}}}}var W=A.selectAll(\".js-line\").data(G);y(W.exit()).style(\"opacity\",0).remove(),W.each(Y(!1)),W.enter().append(\"path\").classed(\"js-line\",!0).style(\"vector-effect\",\"non-scaling-stroke\").call(l.lineGroupStyle).each(Y(!0)),l.setClipUrl(W,r.layerClipId,t),G.length?(E?(E.datum(h),N&&U&&(L?(\"y\"===L?N[1]=U[1]=b.c2p(0,!0):\"x\"===L&&(N[0]=U[0]=x.c2p(0,!0)),y(E).attr(\"d\",\"M\"+U+\"L\"+N+\"L\"+q.substr(1)).call(l.singleFillStyle)):y(E).attr(\"d\",q+\"Z\").call(l.singleFillStyle))):C&&(\"tonext\"===_.fill.substr(0,6)&&q&&z?(\"tonext\"===_.fill?y(C).attr(\"d\",q+\"Z\"+z+\"Z\").call(l.singleFillStyle):y(C).attr(\"d\",q+\"L\"+z.substr(1)+\"Z\").call(l.singleFillStyle),_._polygons=_._polygons.concat(I)):(Z(C),_._polygons=null)),_._prevRevpath=H,_._prevPolygons=V):(E?Z(E):C&&Z(C),_._polygons=_._prevRevpath=_._prevPolygons=null),M.datum(h),S.datum(h),function(e,i,a){var o,u=a[0].trace,h=c.hasMarkers(u),f=c.hasText(u),p=tt(u),d=et,g=et;if(h||f){var v=s,_=u.stackgroup,w=_&&\"infer zero\"===t._fullLayout._scatterStackOpts[x._id+b._id][_].stackgaps;u.marker.maxdisplayed||u._needsCull?v=w?K:J:_&&!w&&(v=$),h&&(d=v),f&&(g=v)}var k,T=(o=e.selectAll(\"path.point\").data(d,p)).enter().append(\"path\").classed(\"point\",!0);m&&T.call(l.pointStyle,u,t).call(l.translatePoints,x,b).style(\"opacity\",0).transition().style(\"opacity\",1),o.order(),h&&(k=l.makePointStyleFns(u)),o.each(function(e){var i=n.select(this),a=y(i);l.translatePoint(e,a,x,b)?(l.singlePointStyle(e,a,u,k,t),r.layerClipId&&l.hideOutsideRangePoint(e,a,x,b,u.xcalendar,u.ycalendar),u.customdata&&i.classed(\"plotly-customdata\",null!==e.data&&void 0!==e.data)):a.remove()}),m?o.exit().transition().style(\"opacity\",0).remove():o.exit().remove(),(o=i.selectAll(\"g\").data(g,p)).enter().append(\"g\").classed(\"textpoint\",!0).append(\"text\"),o.order(),o.each(function(t){var e=n.select(this),i=y(e.select(\"text\"));l.translatePoint(t,i,x,b)?r.layerClipId&&l.hideOutsideRangePoint(t,e,x,b,u.xcalendar,u.ycalendar):e.remove()}),o.selectAll(\"text\").call(l.textPointStyle,u,t).each(function(t){var e=x.c2p(t.x),r=b.c2p(t.y);n.select(this).selectAll(\"tspan.line\").each(function(){y(n.select(this)).attr({x:e,y:r})})}),o.exit().remove()}(M,S,h);var X=!1===_.cliponaxis?null:r.layerClipId;l.setClipUrl(M,X,t),l.setClipUrl(S,X,t)}function Z(t){y(t).attr(\"d\",\"M0,0Z\")}function J(t){return t.filter(function(t){return!t.gap&&t.vis})}function K(t){return t.filter(function(t){return t.vis})}function $(t){return t.filter(function(t){return!t.gap})}function Q(t){return t.id}function tt(t){if(t.ids)return Q}function et(){return!1}}e.exports=function(t,e,r,i,a,c){var u,f,d=!a,g=!!a&&a.duration>0,v=h(t,e,r);((u=i.selectAll(\"g.trace\").data(v,function(t){return t[0].trace.uid})).enter().append(\"g\").attr(\"class\",function(t){return\"trace scatter trace\"+t[0].trace.uid}).style(\"stroke-miterlimit\",2),u.order(),function(t,e,r){e.each(function(e){var i=o(n.select(this),\"g\",\"fills\");l.setClipUrl(i,r.layerClipId,t);var a=e[0].trace,c=[];a._ownfill&&c.push(\"_ownFill\"),a._nexttrace&&c.push(\"_nextFill\");var u=i.selectAll(\"g\").data(c,s);u.enter().append(\"g\"),u.exit().each(function(t){a[t]=null}).remove(),u.order().each(function(t){a[t]=o(n.select(this),\"path\",\"js-fill\")})})}(t,u,e),g)?(c&&(f=c()),n.transition().duration(a.duration).ease(a.easing).each(\"end\",function(){f&&f()}).each(\"interrupt\",function(){f&&f()}).each(function(){i.selectAll(\"g.trace\").each(function(r,n){p(t,n,e,r,v,this,a)})})):u.each(function(r,n){p(t,n,e,r,v,this,a)});d&&u.exit().remove(),i.selectAll(\"path:not([d])\").remove()}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/polygon\":731,\"../../registry\":847,\"./line_points\":1125,\"./link_traces\":1127,\"./subtypes\":1135,d3:163}],1132:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports=function(t,e){var r,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[],h=s[0].trace;if(!n.hasMarkers(h)&&!n.hasText(h))return[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)i=s[r],a=l.c2p(i.x),o=c.c2p(i.y),null!==i.i&&e.contains([a,o],!1,r,t)?(u.push({pointNumber:i.i,x:l.c2d(i.x),y:c.c2d(i.y)}),i.selected=1):i.selected=0;return u}},{\"./subtypes\":1135}],1133:[function(t,e,r){\"use strict\";var n=[\"orientation\",\"groupnorm\",\"stackgaps\"];e.exports=function(t,e,r,i){var a=r._scatterStackOpts,o=i(\"stackgroup\");if(o){var s=e.xaxis+e.yaxis,l=a[s];l||(l=a[s]={});var c=l[o],u=!1;c?c.traces.push(e):(c=l[o]={traceIndices:[],traces:[e]},u=!0);for(var h={orientation:e.x&&!e.y?\"h\":\"v\"},f=0;f<n.length;f++){var p=n[f],d=p+\"Found\";if(!c[d]){var g=void 0!==t[p],v=\"orientation\"===p;if((g||u)&&(c[p]=i(p,h[p]),v&&(c.fillDflt=\"h\"===c[p]?\"tonextx\":\"tonexty\"),g&&(c[d]=!0,!u&&(delete c.traces[0][p],v))))for(var m=0;m<c.traces.length-1;m++){var y=c.traces[m];y._input.fill!==y.fill&&(y.fill=c.fillDflt)}}}return c}}},{}],1134:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../registry\");function o(t,e,r){i.pointStyle(t.selectAll(\"path.point\"),e,r)}function s(t,e,r){i.textPointStyle(t.selectAll(\"text\"),e,r)}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.trace.scatter\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.selectAll(\"g.points\").each(function(e){o(n.select(this),e.trace||e[0].trace,t)}),e.selectAll(\"g.text\").each(function(e){s(n.select(this),e.trace||e[0].trace,t)}),e.selectAll(\"g.trace path.js-line\").call(i.lineGroupStyle),e.selectAll(\"g.trace path.js-fill\").call(i.fillGroupStyle),a.getComponentMethod(\"errorbars\",\"style\")(e)},stylePoints:o,styleText:s,styleOnSelect:function(t,e,r){var n=e[0].trace;n.selectedpoints?(i.selectedPointStyle(r.selectAll(\"path.point\"),n),i.selectedTextStyle(r.selectAll(\"text\"),n)):(o(r,n,t),s(r,n,t))}}},{\"../../components/drawing\":614,\"../../registry\":847,d3:163}],1135:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports={hasLines:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"lines\")},hasMarkers:function(t){return t.visible&&(t.mode&&-1!==t.mode.indexOf(\"markers\")||\"splom\"===t.type)},hasText:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"text\")},isBubble:function(t){return n.isPlainObject(t.marker)&&n.isArrayOrTypedArray(t.marker.size)}}},{\"../../lib\":719}],1136:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i,a){a=a||{},i(\"textposition\"),n.coerceFont(i,\"textfont\",r.font),a.noSelect||(i(\"selected.textfont.color\"),i(\"unselected.textfont.color\"))}},{\"../../lib\":719}],1137:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");e.exports=function(t,e,r,a){var o,s=a(\"x\"),l=a(\"y\");if(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],r),s){var c=n.minRowLength(s);l?o=Math.min(c,n.minRowLength(l)):(o=c,a(\"y0\"),a(\"dy\"))}else{if(!l)return 0;o=n.minRowLength(l),a(\"x0\"),a(\"dx\")}return e._length=o,o}},{\"../../lib\":719,\"../../registry\":847}],1138:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../constants/gl3d_dashes\"),l=t(\"../../constants/gl3d_markers\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../plot_api/edit_types\").overrideAll,h=n.line,f=n.marker,p=f.line,d=c({width:h.width,dash:{valType:\"enumerated\",values:Object.keys(s),dflt:\"solid\"}},i(\"line\"));var g=e.exports=u({x:n.x,y:n.y,z:{valType:\"data_array\"},text:c({},n.text,{}),hovertext:c({},n.hovertext,{}),hovertemplate:a(),mode:c({},n.mode,{dflt:\"lines+markers\"}),surfaceaxis:{valType:\"enumerated\",values:[-1,0,1,2],dflt:-1},surfacecolor:{valType:\"color\"},projection:{x:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},y:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},z:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}}},connectgaps:n.connectgaps,line:d,marker:c({symbol:{valType:\"enumerated\",values:Object.keys(l),dflt:\"circle\",arrayOk:!0},size:c({},f.size,{dflt:8}),sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode,opacity:c({},f.opacity,{arrayOk:!1}),colorbar:f.colorbar,line:c({width:c({},p.width,{arrayOk:!1})},i(\"marker.line\"))},i(\"marker\")),textposition:c({},n.textposition,{dflt:\"top center\"}),textfont:{color:n.textfont.color,size:n.textfont.size,family:c({},n.textfont.family,{arrayOk:!1})},hoverinfo:c({},o.hoverinfo)},\"calc\",\"nested\");g.x.editType=g.y.editType=g.z.editType=\"calc+clearAxisTypes\"},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../constants/gl3d_dashes\":692,\"../../constants/gl3d_markers\":693,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1139:[function(t,e,r){\"use strict\";var n=t(\"../scatter/arrays_to_calcdata\"),i=t(\"../scatter/colorscale_calc\");e.exports=function(t,e){var r=[{x:!1,y:!1,trace:e,t:{}}];return n(r,e),i(t,e),r}},{\"../scatter/arrays_to_calcdata\":1111,\"../scatter/colorscale_calc\":1115}],1140:[function(t,e,r){\"use strict\";var n=t(\"../../registry\");function i(t,e,r,i){if(!e||!e.visible)return null;for(var a=n.getComponentMethod(\"errorbars\",\"makeComputeError\")(e),o=new Array(t.length),s=0;s<t.length;s++){var l=a(+t[s],s);if(\"log\"===i.type){var c=i.c2l(t[s]),u=t[s]-l[0],h=t[s]+l[1];if(o[s]=[(i.c2l(u,!0)-c)*r,(i.c2l(h,!0)-c)*r],u>0){var f=i.c2l(u);i._lowerLogErrorBound||(i._lowerLogErrorBound=f),i._lowerErrorBound=Math.min(i._lowerLogErrorBound,f)}}else o[s]=[-l[0]*r,l[1]*r]}return o}e.exports=function(t,e,r){var n=[i(t.x,t.error_x,e[0],r.xaxis),i(t.y,t.error_y,e[1],r.yaxis),i(t.z,t.error_z,e[2],r.zaxis)],a=function(t){for(var e=0;e<t.length;e++)if(t[e])return t[e].length;return 0}(n);if(0===a)return null;for(var o=new Array(a),s=0;s<a;s++){for(var l=[[0,0,0],[0,0,0]],c=0;c<3;c++)if(n[c])for(var u=0;u<2;u++)l[u][c]=n[c][s][u];o[s]=l}return o}},{\"../../registry\":847}],1141:[function(t,e,r){\"use strict\";var n=t(\"gl-line3d\"),i=t(\"gl-scatter3d\"),a=t(\"gl-error3d\"),o=t(\"gl-mesh3d\"),s=t(\"delaunay-triangulate\"),l=t(\"../../lib\"),c=t(\"../../lib/str2rgbarray\"),u=t(\"../../lib/gl_format_color\").formatColor,h=t(\"../scatter/make_bubble_size_func\"),f=t(\"../../constants/gl3d_dashes\"),p=t(\"../../constants/gl3d_markers\"),d=t(\"./calc_errors\");function g(t,e){this.scene=t,this.uid=e,this.linePlot=null,this.scatterPlot=null,this.errorBars=null,this.textMarkers=null,this.delaunayMesh=null,this.color=null,this.mode=\"\",this.dataPoints=[],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.textLabels=null,this.data=null}var v=g.prototype;function m(t){return null==t?0:t.indexOf(\"left\")>-1?-1:t.indexOf(\"right\")>-1?1:0}function y(t){return null==t?0:t.indexOf(\"top\")>-1?-1:t.indexOf(\"bottom\")>-1?1:0}function x(t,e){return e(4*t)}function b(t){return p[t]}function _(t,e,r,n,i){var a=null;if(l.isArrayOrTypedArray(t)){a=[];for(var o=0;o<e;o++)void 0===t[o]?a[o]=n:a[o]=r(t[o],i)}else a=r(t,l.identity);return a}function w(t,e){var r,n,i,a,o,s,f=[],p=t.fullSceneLayout,g=t.dataScale,v=p.xaxis,w=p.yaxis,k=p.zaxis,T=e.marker,A=e.line,M=e.x||[],S=e.y||[],E=e.z||[],C=M.length,L=e.xcalendar,P=e.ycalendar,O=e.zcalendar;for(o=0;o<C;o++)r=v.d2l(M[o],0,L)*g[0],n=w.d2l(S[o],0,P)*g[1],i=k.d2l(E[o],0,O)*g[2],f[o]=[r,n,i];if(Array.isArray(e.text))s=e.text;else if(void 0!==e.text)for(s=new Array(C),o=0;o<C;o++)s[o]=e.text;if(a={position:f,mode:e.mode,text:s},\"line\"in e&&(a.lineColor=u(A,1,C),a.lineWidth=A.width,a.lineDashes=A.dash),\"marker\"in e){var z=h(e);a.scatterColor=u(T,1,C),a.scatterSize=_(T.size,C,x,20,z),a.scatterMarker=_(T.symbol,C,b,\"\\u25cf\"),a.scatterLineWidth=T.line.width,a.scatterLineColor=u(T.line,1,C),a.scatterAngle=0}\"textposition\"in e&&(a.textOffset=function(t){var e=[0,0];if(Array.isArray(t))for(var r=0;r<t.length;r++)e[r]=[0,0],t[r]&&(e[r][0]=m(t[r]),e[r][1]=y(t[r]));else e[0]=m(t),e[1]=y(t);return e}(e.textposition),a.textColor=u(e.textfont,1,C),a.textSize=_(e.textfont.size,C,l.identity,12),a.textFont=e.textfont.family,a.textAngle=0);var I=[\"x\",\"y\",\"z\"];for(a.project=[!1,!1,!1],a.projectScale=[1,1,1],a.projectOpacity=[1,1,1],o=0;o<3;++o){var D=e.projection[I[o]];(a.project[o]=D.show)&&(a.projectOpacity[o]=D.opacity,a.projectScale[o]=D.scale)}a.errorBounds=d(e,g,p);var R=function(t){for(var e=[0,0,0],r=[[0,0,0],[0,0,0],[0,0,0]],n=[1,1,1],i=0;i<3;i++){var a=t[i];a&&!1!==a.copy_zstyle&&!1!==t[2].visible&&(a=t[2]),a&&a.visible&&(e[i]=a.width/2,r[i]=c(a.color),n[i]=a.thickness)}return{capSize:e,color:r,lineWidth:n}}([e.error_x,e.error_y,e.error_z]);return a.errorColor=R.color,a.errorLineWidth=R.lineWidth,a.errorCapSize=R.capSize,a.delaunayAxis=e.surfaceaxis,a.delaunayColor=c(e.surfacecolor),a}function k(t){if(Array.isArray(t)){var e=t[0];return Array.isArray(e)&&(t=e),\"rgb(\"+t.slice(0,3).map(function(t){return Math.round(255*t)})+\")\"}return null}v.handlePick=function(t){if(t.object&&(t.object===this.linePlot||t.object===this.delaunayMesh||t.object===this.textMarkers||t.object===this.scatterPlot)){var e=t.index=t.data.index;return t.object.highlight&&t.object.highlight(null),this.scatterPlot&&(t.object=this.scatterPlot,this.scatterPlot.highlight(t.data)),t.textLabel=\"\",this.textLabels&&(Array.isArray(this.textLabels)?(this.textLabels[e]||0===this.textLabels[e])&&(t.textLabel=this.textLabels[e]):t.textLabel=this.textLabels),t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]],!0}},v.update=function(t){var e,r,l,c,u=this.scene.glplot.gl,h=f.solid;this.data=t;var p=w(this.scene,t);\"mode\"in p&&(this.mode=p.mode),\"lineDashes\"in p&&p.lineDashes in f&&(h=f[p.lineDashes]),this.color=k(p.scatterColor)||k(p.lineColor),this.dataPoints=p.position,e={gl:this.scene.glplot.gl,position:p.position,color:p.lineColor,lineWidth:p.lineWidth||1,dashes:h[0],dashScale:h[1],opacity:t.opacity,connectGaps:t.connectgaps},-1!==this.mode.indexOf(\"lines\")?this.linePlot?this.linePlot.update(e):(this.linePlot=n(e),this.linePlot._trace=this,this.scene.glplot.add(this.linePlot)):this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose(),this.linePlot=null);var d=t.opacity;if(t.marker&&t.marker.opacity&&(d*=t.marker.opacity),r={gl:this.scene.glplot.gl,position:p.position,color:p.scatterColor,size:p.scatterSize,glyph:p.scatterMarker,opacity:d,orthographic:!0,lineWidth:p.scatterLineWidth,lineColor:p.scatterLineColor,project:p.project,projectScale:p.projectScale,projectOpacity:p.projectOpacity},-1!==this.mode.indexOf(\"markers\")?this.scatterPlot?this.scatterPlot.update(r):(this.scatterPlot=i(r),this.scatterPlot._trace=this,this.scatterPlot.highlightScale=1,this.scene.glplot.add(this.scatterPlot)):this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose(),this.scatterPlot=null),c={gl:this.scene.glplot.gl,position:p.position,glyph:p.text,color:p.textColor,size:p.textSize,angle:p.textAngle,alignment:p.textOffset,font:p.textFont,orthographic:!0,lineWidth:0,project:!1,opacity:t.opacity},this.textLabels=t.hovertext||t.text,-1!==this.mode.indexOf(\"text\")?this.textMarkers?this.textMarkers.update(c):(this.textMarkers=i(c),this.textMarkers._trace=this,this.textMarkers.highlightScale=1,this.scene.glplot.add(this.textMarkers)):this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose(),this.textMarkers=null),l={gl:this.scene.glplot.gl,position:p.position,color:p.errorColor,error:p.errorBounds,lineWidth:p.errorLineWidth,capSize:p.errorCapSize,opacity:t.opacity},this.errorBars?p.errorBounds?this.errorBars.update(l):(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose(),this.errorBars=null):p.errorBounds&&(this.errorBars=a(l),this.errorBars._trace=this,this.scene.glplot.add(this.errorBars)),p.delaunayAxis>=0){var g=function(t,e,r){var n,i=(r+1)%3,a=(r+2)%3,o=[],l=[];for(n=0;n<t.length;++n){var c=t[n];!isNaN(c[i])&&isFinite(c[i])&&!isNaN(c[a])&&isFinite(c[a])&&(o.push([c[i],c[a]]),l.push(n))}var u=s(o);for(n=0;n<u.length;++n)for(var h=u[n],f=0;f<h.length;++f)h[f]=l[h[f]];return{positions:t,cells:u,meshColor:e}}(p.position,p.delaunayColor,p.delaunayAxis);g.opacity=t.opacity,this.delaunayMesh?this.delaunayMesh.update(g):(g.gl=u,this.delaunayMesh=o(g),this.delaunayMesh._trace=this,this.scene.glplot.add(this.delaunayMesh))}else this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose(),this.delaunayMesh=null)},v.dispose=function(){this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose()),this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose()),this.errorBars&&(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose()),this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose()),this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose())},e.exports=function(t,e){var r=new g(t,e.uid);return r.update(e),r}},{\"../../constants/gl3d_dashes\":692,\"../../constants/gl3d_markers\":693,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../scatter/make_bubble_size_func\":1128,\"./calc_errors\":1140,\"delaunay-triangulate\":165,\"gl-error3d\":247,\"gl-line3d\":255,\"gl-mesh3d\":280,\"gl-scatter3d\":297}],1142:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,n){return i.coerce(t,e,c,r,n)}if(function(t,e,r,i){var a=0,o=r(\"x\"),s=r(\"y\"),l=r(\"z\");n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],i),o&&s&&l&&(a=Math.min(o.length,s.length,l.length),e._length=e._xlength=e._ylength=e._zlength=a);return a}(t,e,h,u)){h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),a.hasLines(e)&&(h(\"connectgaps\"),s(t,e,r,u,h)),a.hasMarkers(e)&&o(t,e,r,u,h,{noSelect:!0}),a.hasText(e)&&l(t,e,u,h,{noSelect:!0});var f=(e.line||{}).color,p=(e.marker||{}).color;h(\"surfaceaxis\")>=0&&h(\"surfacecolor\",f||p);for(var d=[\"x\",\"y\",\"z\"],g=0;g<3;++g){var v=\"projection.\"+d[g];h(v+\".show\")&&(h(v+\".opacity\"),h(v+\".scale\"))}var m=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");m(t,e,f||p||r,{axis:\"z\"}),m(t,e,f||p||r,{axis:\"y\",inherit:\"z\"}),m(t,e,f||p||r,{axis:\"x\",inherit:\"z\"})}else e.visible=!1}},{\"../../lib\":719,\"../../registry\":847,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1138}],1143:[function(t,e,r){\"use strict\";e.exports={plot:t(\"./convert\"),attributes:t(\"./attributes\"),markerSymbols:t(\"../../constants/gl3d_markers\"),supplyDefaults:t(\"./defaults\"),colorbar:[{container:\"marker\",min:\"cmin\",max:\"cmax\"},{container:\"line\",min:\"cmin\",max:\"cmax\"}],calc:t(\"./calc\"),moduleType:\"trace\",name:\"scatter3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"symbols\",\"showLegend\"],meta:{}}},{\"../../constants/gl3d_markers\":693,\"../../plots/gl3d\":807,\"./attributes\":1138,\"./calc\":1139,\"./convert\":1141,\"./defaults\":1142}],1144:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=n.marker,c=n.line,u=l.line;e.exports={carpet:{valType:\"string\",editType:\"calc\"},a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},mode:s({},n.mode,{dflt:\"markers\"}),text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),line:{color:c.color,width:c.width,dash:c.dash,shape:s({},c.shape,{values:[\"linear\",\"spline\"]}),smoothing:c.smoothing,editType:\"calc\"},connectgaps:n.connectgaps,fill:s({},n.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:n.fillcolor,marker:s({symbol:l.symbol,opacity:l.opacity,maxdisplayed:l.maxdisplayed,size:l.size,sizeref:l.sizeref,sizemin:l.sizemin,sizemode:l.sizemode,line:s({width:u.width,editType:\"calc\"},o(\"marker.line\")),gradient:l.gradient,editType:\"calc\"},o(\"marker\")),textfont:n.textfont,textposition:n.textposition,selected:n.selected,unselected:n.unselected,hoverinfo:s({},i.hoverinfo,{flags:[\"a\",\"b\",\"text\",\"name\"]}),hoveron:n.hoveron,hovertemplate:a()}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1145:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=t(\"../carpet/lookup_carpetid\");e.exports=function(t,e){var r=e._carpetTrace=l(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){var c;e.xaxis=r.xaxis,e.yaxis=r.yaxis;var u,h,f=e._length,p=new Array(f),d=!1;for(c=0;c<f;c++)if(u=e.a[c],h=e.b[c],n(u)&&n(h)){var g=r.ab2xy(+u,+h,!0),v=r.isVisible(+u,+h);v||(d=!0),p[c]={x:g[0],y:g[1],a:u,b:h,vis:v}}else p[c]={x:!1,y:!1};return e._needsCull=d,p[0].carpet=r,p[0].trace=e,s(e,f),i(t,e),a(p,e),o(p,e),p}}},{\"../carpet/lookup_carpetid\":915,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc\":1113,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1146:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}p(\"carpet\"),e.xaxis=\"x\",e.yaxis=\"y\";var d=p(\"a\"),g=p(\"b\"),v=Math.min(d.length,g.length);if(v){e._length=v,p(\"text\"),p(\"hovertext\"),p(\"mode\",v<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,f,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,f,p,{gradient:!0}),a.hasText(e)&&c(t,e,f,p);var m=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"marker.maxdisplayed\"),m.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||m.push(\"fills\"),\"fills\"!==p(\"hoveron\",m.join(\"+\")||\"points\")&&p(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/line_shape_defaults\":1126,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1144}],1147:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=n[i];return t.a=a.a,t.b=a.b,t.y=a.y,t}},{}],1148:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../lib\").fillText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,h=c-u;return s.x0=Math.max(Math.min(s.x0,h),u),s.x1=Math.max(Math.min(s.x1,h),u),o}var f=s.cd[s.index];s.a=f.a,s.b=f.b,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.trace,d=p._carpet,g=d.ab2ij([f.a,f.b]),v=Math.floor(g[0]),m=g[0]-v,y=Math.floor(g[1]),x=g[1]-y,b=d.evalxy([],v,y,m,x);s.yLabel=b[1].toFixed(3),delete s.text;var _=[];if(!p.hovertemplate){var w=(f.hi||p.hoverinfo).split(\"+\");-1!==w.indexOf(\"all\")&&(w=[\"a\",\"b\",\"text\"]),-1!==w.indexOf(\"a\")&&k(d.aaxis,f.a),-1!==w.indexOf(\"b\")&&k(d.baxis,f.b),_.push(\"y: \"+s.yLabel),-1!==w.indexOf(\"text\")&&i(f,p,_),s.extraText=_.join(\"<br>\")}return o}function k(t,e){var r;r=t.labelprefix&&t.labelprefix.length>0?t.labelprefix.replace(/ = $/,\"\"):t._hovertitle,_.push(r+\": \"+e.toFixed(3)+t.labelsuffix)}}},{\"../../lib\":719,\"../scatter/hover\":1122}],1149:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scattercarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"svg\",\"carpet\",\"symbols\",\"showLegend\",\"carpetDependent\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../scatter/marker_colorbar\":1129,\"../scatter/select\":1132,\"../scatter/style\":1134,\"./attributes\":1144,\"./calc\":1145,\"./defaults\":1146,\"./event_data\":1147,\"./hover\":1148,\"./plot\":1150}],1150:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../components/drawing\");e.exports=function(t,e,r,o){var s,l,c,u=r[0][0].carpet,h={xaxis:i.getFromId(t,u.xaxis||\"x\"),yaxis:i.getFromId(t,u.yaxis||\"y\"),plot:e.plot};for(n(t,h,r,o),s=0;s<r.length;s++)l=r[s][0].trace,c=o.selectAll(\"g.trace\"+l.uid+\" .js-line\"),a.setClipUrl(c,r[s][0].carpet._clipPathId,t)}},{\"../../components/drawing\":614,\"../../plots/cartesian/axes\":767,\"../scatter/plot\":1131}],1151:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/drawing/attributes\").dash,l=t(\"../../lib/extend\").extendFlat,c=t(\"../../plot_api/edit_types\").overrideAll,u=i.marker,h=i.line,f=u.line;e.exports=c({lon:{valType:\"data_array\"},lat:{valType:\"data_array\"},locations:{valType:\"data_array\"},locationmode:{valType:\"enumerated\",values:[\"ISO-3\",\"USA-states\",\"country names\"],dflt:\"ISO-3\"},mode:l({},i.mode,{dflt:\"markers\"}),text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),textfont:i.textfont,textposition:i.textposition,line:{color:h.color,width:h.width,dash:s},connectgaps:i.connectgaps,marker:l({symbol:u.symbol,opacity:u.opacity,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,colorbar:u.colorbar,line:l({width:f.width},o(\"marker.line\")),gradient:u.gradient},o(\"marker\")),fill:{valType:\"enumerated\",values:[\"none\",\"toself\"],dflt:\"none\"},fillcolor:i.fillcolor,selected:i.selected,unselected:i.unselected,hoverinfo:l({},a.hoverinfo,{flags:[\"lon\",\"lat\",\"location\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":600,\"../../components/drawing/attributes\":613,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1152:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../scatter/colorscale_calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\"),l=t(\"../../lib\")._;e.exports=function(t,e){for(var r=Array.isArray(e.locations),c=r?e.locations.length:e._length,u=new Array(c),h=0;h<c;h++){var f=u[h]={};if(r){var p=e.locations[h];f.loc=\"string\"==typeof p?p:null}else{var d=e.lon[h],g=e.lat[h];n(d)&&n(g)?f.lonlat=[+d,+g]:f.lonlat=[i,i]}}return o(u,e),a(t,e),s(u,e),c&&(u[0].t={labels:{lat:l(t,\"lat:\")+\" \",lon:l(t,\"lon:\")+\" \"}}),u}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1153:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,i){return n.coerce(t,e,c,r,i)}!function(t,e,r){var n,i,a=0,o=r(\"locations\");if(o)return r(\"locationmode\"),a=o.length;return n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length),e._length=a,a}(0,e,h)?e.visible=!1:(h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),i.hasLines(e)&&(o(t,e,r,u,h),h(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,u,h,{gradient:!0}),i.hasText(e)&&s(t,e,u,h),h(\"fill\"),\"none\"!==e.fill&&l(t,e,r,h),n.coerceSelectionMarkerOpacity(e,h))}},{\"../../lib\":719,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1151}],1154:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.location=e.loc?e.loc:null,t}},{}],1155:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../scatter/get_trace_color\"),s=t(\"../../lib\").fillText,l=t(\"./attributes\");e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,h=t.xa,f=t.ya,p=t.subplot,d=p.projection.isLonLatOverEdges,g=p.project;if(n.getClosest(c,function(t){var n=t.lonlat;if(n[0]===a)return 1/0;if(d(n))return 1/0;var i=g(n),o=g([e,r]),s=Math.abs(i[0]-o[0]),l=Math.abs(i[1]-o[1]),c=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(s*s+l*l)-c,1-3/c)},t),!1!==t.index){var v=c[t.index],m=v.lonlat,y=[h.c2p(m),f.c2p(m)],x=v.mrc||1;t.x0=y[0]-x,t.x1=y[0]+x,t.y0=y[1]-x,t.y1=y[1]+x,t.loc=v.loc,t.lon=m[0],t.lat=m[1];var b=p.mockAxis;return t.lonLabel=i.tickText(b,b.c2l(t.lon),\"hover\").text,t.latLabel=i.tickText(b,b.c2l(t.lat),\"hover\").text,t.color=o(u,v),t.extraText=function(t,e,r,n){if(t.hovertemplate)return;var i=e.hi||t.hoverinfo,a=\"all\"===i?l.hoverinfo.flags:i.split(\"+\"),o=-1!==a.indexOf(\"location\")&&Array.isArray(t.locations),c=-1!==a.indexOf(\"lon\"),u=-1!==a.indexOf(\"lat\"),h=-1!==a.indexOf(\"text\"),f=[];function p(t){return t+\"\\xb0\"}o?f.push(e.loc):c&&u?f.push(\"(\"+p(r.lonLabel)+\", \"+p(r.latLabel)+\")\"):c?f.push(n.lon+p(r.lonLabel)):u&&f.push(n.lat+p(r.latLabel));h&&s(e,t,f);return f.join(\"<br>\")}(u,v,t,c[0].t.labels),t.hovertemplate=u.hovertemplate,[t]}}},{\"../../components/fx\":632,\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scatter/get_trace_color\":1121,\"./attributes\":1151}],1156:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"scattergeo\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/geo\":797,\"../scatter/marker_colorbar\":1129,\"../scatter/style\":1134,\"./attributes\":1151,\"./calc\":1152,\"./defaults\":1153,\"./event_data\":1154,\"./hover\":1155,\"./plot\":1157,\"./select\":1158,\"./style\":1159}],1157:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../lib/topojson_utils\").getTopojsonFeatures,s=t(\"../../lib/geo_location_utils\").locationToFeature,l=t(\"../../lib/geojson_utils\"),c=t(\"../scatter/subtypes\"),u=t(\"./style\");function h(t,e){var r=t[0].trace;if(Array.isArray(r.locations))for(var n=o(r,e),i=r.locationmode,l=0;l<t.length;l++){var c=t[l],u=s(i,c.loc,n);c.lonlat=u?u.properties.ct:[a,a]}}e.exports=function(t,e,r){for(var o=0;o<r.length;o++)h(r[o],e.topojson);function s(t,e){t.lonlat[0]===a&&n.select(e).remove()}var f=e.layers.frontplot.select(\".scatterlayer\"),p=i.makeTraceGroups(f,r,\"trace scattergeo\");p.selectAll(\"*\").remove(),p.each(function(e){var r=n.select(this),a=e[0].trace;if(c.hasLines(a)||\"none\"!==a.fill){var o=l.calcTraceToLineCoords(e),h=\"none\"!==a.fill?l.makePolygon(o):l.makeLine(o);r.selectAll(\"path.js-line\").data([{geojson:h,trace:a}]).enter().append(\"path\").classed(\"js-line\",!0).style(\"stroke-miterlimit\",2)}c.hasMarkers(a)&&r.selectAll(\"path.point\").data(i.identity).enter().append(\"path\").classed(\"point\",!0).each(function(t){s(t,this)}),c.hasText(a)&&r.selectAll(\"g\").data(i.identity).enter().append(\"g\").append(\"text\").each(function(t){s(t,this)}),u(t,e)})}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/geo_location_utils\":713,\"../../lib/geojson_utils\":714,\"../../lib/topojson_utils\":746,\"../scatter/subtypes\":1135,\"./style\":1159,d3:163}],1158:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,a,o,s,l,c=t.cd,u=t.xaxis,h=t.yaxis,f=[],p=c[0].trace;if(!n.hasMarkers(p)&&!n.hasText(p))return[];if(!1===e)for(l=0;l<c.length;l++)c[l].selected=0;else for(l=0;l<c.length;l++)(a=(r=c[l]).lonlat)[0]!==i&&(o=u.c2p(a),s=h.c2p(a),e.contains([o,s],null,l,t)?(f.push({pointNumber:l,lon:a[0],lat:a[1]}),r.selected=1):r.selected=0);return f}},{\"../../constants/numerical\":695,\"../scatter/subtypes\":1135}],1159:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../scatter/style\"),s=o.stylePoints,l=o.styleText;e.exports=function(t,e){e&&function(t,e){var r=e[0].trace,o=e[0].node3;o.style(\"opacity\",e[0].trace.opacity),s(o,r,t),l(o,r,t),o.selectAll(\"path.js-line\").style(\"fill\",\"none\").each(function(t){var e=n.select(this),r=t.trace,o=r.line||{};e.call(a.stroke,o.color).call(i.dashLine,o.dash||\"\",o.width||0),\"none\"!==r.fill&&e.call(a.fill,r.fillcolor)})}(t,e)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../scatter/style\":1134,d3:163}],1160:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=t(\"./constants\").DASHES,c=i.line,u=i.marker,h=u.line,f=e.exports=s({x:i.x,x0:i.x0,dx:i.dx,y:i.y,y0:i.y0,dy:i.dy,text:i.text,hovertext:i.hovertext,textposition:i.textposition,textfont:i.textfont,mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"]},line:{color:c.color,width:c.width,shape:{valType:\"enumerated\",values:[\"linear\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},dash:{valType:\"enumerated\",values:Object.keys(l),dflt:\"solid\"}},marker:o({},a(\"marker\"),{symbol:u.symbol,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:o({},a(\"marker.line\"),{width:h.width})}),connectgaps:i.connectgaps,fill:o({},i.fill,{dflt:\"none\"}),fillcolor:i.fillcolor,selected:{marker:i.selected.marker,textfont:i.selected.textfont},unselected:{marker:i.unselected.marker,textfont:i.unselected.textfont},opacity:n.opacity},\"calc\",\"nested\");f.x.editType=f.y.editType=f.x0.editType=f.y0.editType=\"calc+clearAxisTypes\",f.hovertemplate=i.hovertemplate},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../scatter/attributes\":1112,\"./constants\":1162}],1161:[function(t,e,r){\"use strict\";var n=t(\"point-cluster\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../plots/cartesian/autorange\").findExtremes,s=t(\"../scatter/calc\"),l=s.calcMarkerSize,c=s.calcAxisExpansion,u=s.setFirstScatter,h=t(\"../scatter/colorscale_calc\"),f=t(\"./convert\"),p=t(\"./scene_update\"),d=t(\"../../constants/numerical\").BADNUM,g=t(\"./constants\").TOO_MANY_POINTS;function v(t,e,r){var n=t._extremes[e._id],i=o(e,r._bnds,{padded:!0});n.min=n.min.concat(i.min),n.max=n.max.concat(i.max)}e.exports=function(t,e){var r,o,s,m=t._fullLayout,y=a.getFromId(t,e.xaxis),x=a.getFromId(t,e.yaxis),b=m._plots[e.xaxis+e.yaxis],_=e._length,w=_>=g,k=2*_,T={},A=y.makeCalcdata(e,\"x\"),M=x.makeCalcdata(e,\"y\"),S=new Array(k);for(r=0;r<_;r++)o=A[r],s=M[r],S[2*r]=o===d?NaN:o,S[2*r+1]=s===d?NaN:s;if(\"log\"===y.type)for(r=0;r<k;r+=2)S[r]=y.c2l(S[r]);if(\"log\"===x.type)for(r=1;r<k;r+=2)S[r]=x.c2l(S[r]);if(w&&\"log\"!==y.type&&\"log\"!==x.type)T.tree=n(S);else{var E=T.ids=new Array(_);for(r=0;r<_;r++)E[r]=r}h(t,e);var C,L=function(t,e,r,n,a,o){var s=f.style(t,r);s.marker&&(s.marker.positions=n);s.line&&n.length>1&&i.extendFlat(s.line,f.linePositions(t,r,n));if(s.errorX||s.errorY){var l=f.errorBarPositions(t,r,n,a,o);s.errorX&&i.extendFlat(s.errorX,l.x),s.errorY&&i.extendFlat(s.errorY,l.y)}s.text&&(i.extendFlat(s.text,{positions:n},f.textPosition(t,r,s.text,s.marker)),i.extendFlat(s.textSel,{positions:n},f.textPosition(t,r,s.text,s.markerSel)),i.extendFlat(s.textUnsel,{positions:n},f.textPosition(t,r,s.text,s.markerUnsel)));return s}(t,0,e,S,A,M),P=p(t,b);return u(m,e),w?L.marker&&(C=2*(L.marker.sizeAvg||Math.max(L.marker.size,3))):C=l(e,_),c(t,e,y,x,A,M,C),L.errorX&&v(e,y,L.errorX),L.errorY&&v(e,x,L.errorY),L.fill&&!P.fill2d&&(P.fill2d=!0),L.marker&&!P.scatter2d&&(P.scatter2d=!0),L.line&&!P.line2d&&(P.line2d=!0),!L.errorX&&!L.errorY||P.error2d||(P.error2d=!0),L.text&&!P.glText&&(P.glText=!0),L.marker&&(L.marker.snap=T.tree||g),P.lineOptions.push(L.line),P.errorXOptions.push(L.errorX),P.errorYOptions.push(L.errorY),P.fillOptions.push(L.fill),P.markerOptions.push(L.marker),P.markerSelectedOptions.push(L.markerSel),P.markerUnselectedOptions.push(L.markerUnsel),P.textOptions.push(L.text),P.textSelectedOptions.push(L.textSel),P.textUnselectedOptions.push(L.textUnsel),P.selectBatch.push([]),P.unselectBatch.push([]),T._scene=P,T.index=P.count,T.x=A,T.y=M,T.positions=S,P.count++,[{x:!1,y:!1,t:T,trace:e}]}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/autorange\":766,\"../../plots/cartesian/axis_ids\":770,\"../scatter/calc\":1113,\"../scatter/colorscale_calc\":1115,\"./constants\":1162,\"./convert\":1163,\"./scene_update\":1169,\"point-cluster\":469}],1162:[function(t,e,r){\"use strict\";e.exports={TOO_MANY_POINTS:1e5,SYMBOL_SDF_SIZE:200,SYMBOL_SIZE:20,SYMBOL_STROKE:1,DOT_RE:/-dot/,OPEN_RE:/-open/,DASHES:{solid:[1],dot:[1,1],dash:[4,1],longdash:[8,1],dashdot:[4,1,1,1],longdashdot:[8,1,1,1]}}},{}],1163:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"svg-path-sdf\"),a=t(\"color-normalize\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../components/drawing\"),c=t(\"../../plots/cartesian/axis_ids\"),u=t(\"../../lib/gl_format_color\").formatColor,h=t(\"../scatter/subtypes\"),f=t(\"../scatter/make_bubble_size_func\"),p=t(\"./constants\"),d=t(\"../../constants/interactions\").DESELECTDIM,g={start:1,left:1,end:-1,right:-1,middle:0,center:0,bottom:1,top:-1};function v(t){var e,r=t._length,i=t.textfont,a=t.textposition,o=Array.isArray(a)?a:[a],s=i.color,l=i.size,c=i.family,u={};for(u.text=t.text,u.opacity=t.opacity,u.font={},u.align=[],u.baseline=[],e=0;e<o.length;e++){var h=o[e].split(/\\s+/);switch(h[1]){case\"left\":u.align.push(\"right\");break;case\"right\":u.align.push(\"left\");break;default:u.align.push(h[1])}switch(h[0]){case\"top\":u.baseline.push(\"bottom\");break;case\"bottom\":u.baseline.push(\"top\");break;default:u.baseline.push(h[0])}}if(Array.isArray(s))for(u.color=new Array(r),e=0;e<r;e++)u.color[e]=s[e];else u.color=s;if(Array.isArray(l)||Array.isArray(c))for(u.font=new Array(r),e=0;e<r;e++){var f=u.font[e]={};f.size=Array.isArray(l)?n(l[e])?l[e]:0:l,f.family=Array.isArray(c)?c[e]:c}else u.font={size:l,family:c};return u}function m(t){var e,r,n=t._length,i=t.marker,o={},l=Array.isArray(i.symbol),c=s.isArrayOrTypedArray(i.color),h=s.isArrayOrTypedArray(i.line.color),d=s.isArrayOrTypedArray(i.opacity),g=s.isArrayOrTypedArray(i.size),v=s.isArrayOrTypedArray(i.line.width);if(l||(r=p.OPEN_RE.test(i.symbol)),l||c||h||d){o.colors=new Array(n),o.borderColors=new Array(n);var m=u(i,i.opacity,n),y=u(i.line,i.opacity,n);if(!Array.isArray(y[0])){var x=y;for(y=Array(n),e=0;e<n;e++)y[e]=x}if(!Array.isArray(m[0])){var b=m;for(m=Array(n),e=0;e<n;e++)m[e]=b}for(o.colors=m,o.borderColors=y,e=0;e<n;e++){if(l){var _=i.symbol[e];r=p.OPEN_RE.test(_)}r&&(y[e]=m[e].slice(),m[e]=m[e].slice(),m[e][3]=0)}o.opacity=t.opacity}else r?(o.color=a(i.color,\"uint8\"),o.color[3]=0,o.borderColor=a(i.color,\"uint8\")):(o.color=a(i.color,\"uint8\"),o.borderColor=a(i.line.color,\"uint8\")),o.opacity=t.opacity*i.opacity;if(l)for(o.markers=new Array(n),e=0;e<n;e++)o.markers[e]=M(i.symbol[e]);else o.marker=M(i.symbol);var w,k=f(t);if(g||v){var T,A=o.sizes=new Array(n),S=o.borderSizes=new Array(n),E=0;if(g){for(e=0;e<n;e++)A[e]=k(i.size[e]),E+=A[e];T=E/n}else for(w=k(i.size),e=0;e<n;e++)A[e]=w;if(v)for(e=0;e<n;e++)S[e]=i.line.width[e]/2;else for(w=i.line.width/2,e=0;e<n;e++)S[e]=w;o.sizeAvg=T}else o.size=k(i&&i.size||10),o.borderSizes=k(i.line.width);return o}function y(t,e){var r=t.marker,n={};return e?(e.marker&&e.marker.symbol?n=m(s.extendFlat({},r,e.marker)):e.marker&&(e.marker.size&&(n.size=e.marker.size/2),e.marker.color&&(n.colors=e.marker.color),void 0!==e.marker.opacity&&(n.opacity=e.marker.opacity)),n):n}function x(t,e){var r={};if(!e)return r;if(e.textfont){var n={opacity:1,text:t.text,textposition:t.textposition,textfont:s.extendFlat({},t.textfont)};e.textfont&&s.extendFlat(n.textfont,e.textfont),r=v(n)}return r}function b(t,e){var r={capSize:2*e.width,lineWidth:e.thickness,color:e.color};return e.copy_ystyle&&(r=t.error_y),r}var _=p.SYMBOL_SDF_SIZE,w=p.SYMBOL_SIZE,k=p.SYMBOL_STROKE,T={},A=l.symbolFuncs[0](.05*w);function M(t){if(\"circle\"===t)return null;var e,r,n=l.symbolNumber(t),a=l.symbolFuncs[n%100],o=!!l.symbolNoDot[n%100],s=!!l.symbolNoFill[n%100],c=p.DOT_RE.test(t);return T[t]?T[t]:(e=c&&!o?a(1.1*w)+A:a(w),r=i(e,{w:_,h:_,viewBox:[-w,-w,w,w],stroke:s?k:-k}),T[t]=r,r||null)}e.exports={style:function(t,e){var r,n={marker:void 0,markerSel:void 0,markerUnsel:void 0,line:void 0,fill:void 0,errorX:void 0,errorY:void 0,text:void 0,textSel:void 0,textUnsel:void 0};if(!0!==e.visible)return n;if(h.hasText(e)&&(n.text=v(e),n.textSel=x(e,e.selected),n.textUnsel=x(e,e.unselected)),h.hasMarkers(e)&&(n.marker=m(e),n.markerSel=y(e,e.selected),n.markerUnsel=y(e,e.unselected),!e.unselected&&Array.isArray(e.marker.opacity))){var i=e.marker.opacity;for(n.markerUnsel.opacity=new Array(i.length),r=0;r<i.length;r++)n.markerUnsel.opacity[r]=d*i[r]}if(h.hasLines(e)){n.line={overlay:!0,thickness:e.line.width,color:e.line.color,opacity:e.opacity};var a=(p.DASHES[e.line.dash]||[1]).slice();for(r=0;r<a.length;++r)a[r]*=e.line.width;n.line.dashes=a}return e.error_x&&e.error_x.visible&&(n.errorX=b(e,e.error_x)),e.error_y&&e.error_y.visible&&(n.errorY=b(e,e.error_y)),e.fill&&\"none\"!==e.fill&&(n.fill={closed:!0,fill:e.fillcolor,thickness:0}),n},markerStyle:m,markerSelection:y,linePositions:function(t,e,r){var n,i,a=r.length,o=a/2;if(h.hasLines(e)&&o)if(\"hv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i+2],r[2*i+1]));n.push(r[a-2],r[a-1])}else if(\"hvh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var s=(r[2*i]+r[2*i+2])/2;n.push(r[2*i],r[2*i+1],s,r[2*i+1],s,r[2*i+3])}n.push(r[a-2],r[a-1])}else if(\"vhv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var l=(r[2*i+1]+r[2*i+3])/2;n.push(r[2*i],r[2*i+1],r[2*i],l,r[2*i+2],l)}n.push(r[a-2],r[a-1])}else if(\"vh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+3]));n.push(r[a-2],r[a-1])}else n=r;var c=!1;for(i=0;i<n.length;i++)if(isNaN(n[i])){c=!0;break}var u=c||n.length>p.TOO_MANY_POINTS?\"rect\":h.hasMarkers(e)?\"rect\":\"round\";if(c&&e.connectgaps){var f=n[0],d=n[1];for(i=0;i<n.length;i+=2)isNaN(n[i])||isNaN(n[i+1])?(n[i]=f,n[i+1]=d):(f=n[i],d=n[i+1])}return{join:u,positions:n}},errorBarPositions:function(t,e,r,i,a){var s=o.getComponentMethod(\"errorbars\",\"makeComputeError\"),l=c.getFromId(t,e.xaxis),u=c.getFromId(t,e.yaxis),h=r.length/2,f={};function p(t,i){var a=i._id.charAt(0),o=e[\"error_\"+a];if(o&&o.visible&&(\"linear\"===i.type||\"log\"===i.type)){for(var l=s(o),c={x:0,y:1}[a],u={x:[0,1,2,3],y:[2,3,0,1]}[a],p=new Float64Array(4*h),d=1/0,g=-1/0,v=0,m=0;v<h;v++,m+=4){var y=t[v];if(n(y)){var x=r[2*v+c],b=l(y,v),_=b[0],w=b[1];if(n(_)&&n(w)){var k=y-_,T=y+w;p[m+u[0]]=x-i.c2l(k),p[m+u[1]]=i.c2l(T)-x,p[m+u[2]]=0,p[m+u[3]]=0,d=Math.min(d,y-_),g=Math.max(g,y+w)}}}f[a]={positions:r,errors:p,_bnds:[d,g]}}}return p(i,l),p(a,u),f},textPosition:function(t,e,r,n){var i,a=e._length,o={};if(h.hasMarkers(e)){var s=r.font,l=r.align,c=r.baseline;for(o.offset=new Array(a),i=0;i<a;i++){var u=n.sizes?n.sizes[i]:n.size,f=Array.isArray(s)?s[i].size:s.size,p=Array.isArray(l)?l.length>1?l[i]:l[0]:l,d=Array.isArray(c)?c.length>1?c[i]:c[0]:c,v=g[p],m=g[d],y=u?u/.8+1:0,x=-m*y-.5*m;o.offset[i]=[v*y/f,x/f]}}return o}}},{\"../../components/drawing\":614,\"../../constants/interactions\":694,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../scatter/make_bubble_size_func\":1128,\"../scatter/subtypes\":1135,\"./constants\":1162,\"color-normalize\":120,\"fast-isnumeric\":225,\"svg-path-sdf\":535}],1164:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"../scatter/constants\"),s=t(\"../scatter/subtypes\"),l=t(\"../scatter/xy_defaults\"),c=t(\"../scatter/marker_defaults\"),u=t(\"../scatter/line_defaults\"),h=t(\"../scatter/fillcolor_defaults\"),f=t(\"../scatter/text_defaults\");e.exports=function(t,e,r,p){function d(r,i){return n.coerce(t,e,a,r,i)}var g=!!t.marker&&/-open/.test(t.marker.symbol),v=s.isBubble(t),m=l(t,e,p,d);if(m){var y=m<o.PTS_LINESONLY?\"lines+markers\":\"lines\";d(\"text\"),d(\"hovertext\"),d(\"hovertemplate\"),d(\"mode\",y),s.hasLines(e)&&(d(\"connectgaps\"),u(t,e,r,p,d),d(\"line.shape\")),s.hasMarkers(e)&&(c(t,e,r,p,d),d(\"marker.line.width\",g||v?1:0)),s.hasText(e)&&f(t,e,p,d);var x=(e.line||{}).color,b=(e.marker||{}).color;d(\"fill\"),\"none\"!==e.fill&&h(t,e,r,d);var _=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");_(t,e,x||b||r,{axis:\"y\"}),_(t,e,x||b||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}},{\"../../lib\":719,\"../../registry\":847,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"../scatter/xy_defaults\":1137,\"./attributes\":1160}],1165:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../constants/interactions\").DESELECTDIM;e.exports={styleTextSelection:function(t){var e,r,o=t[0],s=o.trace,l=o.t,c=l._scene,u=l.index,h=c.selectBatch[u],f=c.unselectBatch[u],p=c.textOptions[u],d=c.textSelectedOptions[u]||{},g=c.textUnselectedOptions[u]||{},v=n.extendFlat({},p);if(h.length||f.length){var m=d.color,y=g.color,x=p.color,b=Array.isArray(x);for(v.color=new Array(s._length),e=0;e<h.length;e++)r=h[e],v.color[r]=m||(b?x[r]:x);for(e=0;e<f.length;e++){r=f[e];var _=b?x[r]:x;v.color[r]=y||(m?_:i.addOpacity(_,a))}}c.glText[u].update(v)}}},{\"../../components/color\":593,\"../../constants/interactions\":694,\"../../lib\":719}],1166:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\");function o(t,e,r,o){var s=t.xa,l=t.ya,c=t.distance,u=t.dxy,h=t.index,f={pointNumber:h,x:e[h],y:r[h]};f.tx=Array.isArray(o.text)?o.text[h]:o.text,f.htx=Array.isArray(o.hovertext)?o.hovertext[h]:o.hovertext,f.data=Array.isArray(o.customdata)?o.customdata[h]:o.customdata,f.tp=Array.isArray(o.textposition)?o.textposition[h]:o.textposition;var p=o.textfont;p&&(f.ts=Array.isArray(p.size)?p.size[h]:p.size,f.tc=Array.isArray(p.color)?p.color[h]:p.color,f.tf=Array.isArray(p.family)?p.family[h]:p.family);var d=o.marker;d&&(f.ms=i.isArrayOrTypedArray(d.size)?d.size[h]:d.size,f.mo=i.isArrayOrTypedArray(d.opacity)?d.opacity[h]:d.opacity,f.mx=Array.isArray(d.symbol)?d.symbol[h]:d.symbol,f.mc=i.isArrayOrTypedArray(d.color)?d.color[h]:d.color);var g=d&&d.line;g&&(f.mlc=Array.isArray(g.color)?g.color[h]:g.color,f.mlw=i.isArrayOrTypedArray(g.width)?g.width[h]:g.width);var v=d&&d.gradient;v&&\"none\"!==v.type&&(f.mgt=Array.isArray(v.type)?v.type[h]:v.type,f.mgc=Array.isArray(v.color)?v.color[h]:v.color);var m=s.c2p(f.x,!0),y=l.c2p(f.y,!0),x=f.mrc||1,b=o.hoverlabel;b&&(f.hbg=Array.isArray(b.bgcolor)?b.bgcolor[h]:b.bgcolor,f.hbc=Array.isArray(b.bordercolor)?b.bordercolor[h]:b.bordercolor,f.hts=Array.isArray(b.font.size)?b.font.size[h]:b.font.size,f.htc=Array.isArray(b.font.color)?b.font.color[h]:b.font.color,f.htf=Array.isArray(b.font.family)?b.font.family[h]:b.font.family,f.hnl=Array.isArray(b.namelength)?b.namelength[h]:b.namelength);var _=o.hoverinfo;_&&(f.hi=Array.isArray(_)?_[h]:_);var w=o.hovertemplate;w&&(f.ht=Array.isArray(w)?w[h]:w);var k={};return k[t.index]=f,i.extendFlat(t,{color:a(o,f),x0:m-x,x1:m+x,xLabelVal:f.x,y0:y-x,y1:y+x,yLabelVal:f.y,cd:k,distance:c,spikeDistance:u,hovertemplate:f.ht}),f.htx?t.text=f.htx:f.tx?t.text=f.tx:o.text&&(t.text=o.text),i.fillText(f,o,t),n.getComponentMethod(\"errorbars\",\"hoverInfo\")(f,o,t),t}e.exports={hoverPoints:function(t,e,r,n){var i,a,s,l,c,u,h,f,p,d=t.cd,g=d[0].t,v=d[0].trace,m=t.xa,y=t.ya,x=g.x,b=g.y,_=m.c2p(e),w=y.c2p(r),k=t.distance;if(g.tree){var T=m.p2c(_-k),A=m.p2c(_+k),M=y.p2c(w-k),S=y.p2c(w+k);i=\"x\"===n?g.tree.range(Math.min(T,A),Math.min(y._rl[0],y._rl[1]),Math.max(T,A),Math.max(y._rl[0],y._rl[1])):g.tree.range(Math.min(T,A),Math.min(M,S),Math.max(T,A),Math.max(M,S))}else{if(!g.ids)return[t];i=g.ids}var E=k;if(\"x\"===n)for(c=0;c<i.length;c++)s=x[i[c]],(u=Math.abs(m.c2p(s)-_))<E&&(E=u,h=y.c2p(b[i[c]])-w,p=Math.sqrt(u*u+h*h),a=i[c]);else for(c=i.length-1;c>-1;c--)s=x[i[c]],l=b[i[c]],u=m.c2p(s)-_,h=y.c2p(l)-w,(f=Math.sqrt(u*u+h*h))<E&&(E=p=f,a=i[c]);return t.index=a,t.distance=E,t.dxy=p,void 0===a?[t]:(o(t,x,b,v),[t])},calcHover:o}},{\"../../lib\":719,\"../../registry\":847,\"../scatter/get_trace_color\":1121}],1167:[function(t,e,r){\"use strict\";var n=t(\"./hover\");e.exports={moduleType:\"trace\",name:\"scattergl\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../scatter/cross_trace_defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:n.hoverPoints,selectPoints:t(\"./select\"),meta:{}}},{\"../../plots/cartesian\":778,\"../scatter/cross_trace_defaults\":1118,\"../scatter/marker_colorbar\":1129,\"./attributes\":1160,\"./calc\":1161,\"./defaults\":1164,\"./hover\":1166,\"./plot\":1168,\"./select\":1170}],1168:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"regl-line2d\"),a=t(\"regl-error2d\"),o=t(\"gl-text\"),s=t(\"../../lib\"),l=t(\"../../lib/prepare_regl\"),c=t(\"../scatter/subtypes\"),u=t(\"../scatter/link_traces\"),h=t(\"./edit_style\").styleTextSelection;e.exports=function(t,e,r){if(r.length){var f,p,d=t._fullLayout,g=e._scene,v=e.xaxis,m=e.yaxis;if(g)if(l(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])){var y=g.count,x=d._glcanvas.data()[0].regl;if(u(t,e,r),g.dirty){if(!0===g.error2d&&(g.error2d=a(x)),!0===g.line2d&&(g.line2d=i(x)),!0===g.scatter2d&&(g.scatter2d=n(x)),!0===g.fill2d&&(g.fill2d=i(x)),!0===g.glText)for(g.glText=new Array(y),f=0;f<y;f++)g.glText[f]=new o(x);if(g.glText){if(y>g.glText.length){var b=y-g.glText.length;for(f=0;f<b;f++)g.glText.push(new o(x))}else if(y<g.glText.length){var _=g.glText.length-y;g.glText.splice(y,_).forEach(function(t){t.destroy()})}for(f=0;f<y;f++)g.glText[f].update(g.textOptions[f])}if(g.line2d&&(g.line2d.update(g.lineOptions),g.lineOptions=g.lineOptions.map(function(t){if(t&&t.positions){for(var e=t.positions,r=0;r<e.length&&(isNaN(e[r])||isNaN(e[r+1]));)r+=2;for(var n=e.length-2;n>r&&(isNaN(e[n])||isNaN(e[n+1]));)n-=2;t.positions=e.slice(r,n+2)}return t}),g.line2d.update(g.lineOptions)),g.error2d){var w=(g.errorXOptions||[]).concat(g.errorYOptions||[]);g.error2d.update(w)}g.scatter2d&&g.scatter2d.update(g.markerOptions),g.fillOrder=s.repeat(null,y),g.fill2d&&(g.fillOptions=g.fillOptions.map(function(t,e){var n=r[e];if(t&&n&&n[0]&&n[0].trace){var i,a,o=n[0],s=o.trace,l=o.t,c=g.lineOptions[e],u=[];s._ownfill&&u.push(e),s._nexttrace&&u.push(e+1),u.length&&(g.fillOrder[e]=u);var h,f,p=[],d=c&&c.positions||l.positions;if(\"tozeroy\"===s.fill){for(h=0;h<d.length&&isNaN(d[h+1]);)h+=2;for(f=d.length-2;f>h&&isNaN(d[f+1]);)f-=2;0!==d[h+1]&&(p=[d[h],0]),p=p.concat(d.slice(h,f+2)),0!==d[f+1]&&(p=p.concat([d[f],0]))}else if(\"tozerox\"===s.fill){for(h=0;h<d.length&&isNaN(d[h]);)h+=2;for(f=d.length-2;f>h&&isNaN(d[f]);)f-=2;0!==d[h]&&(p=[0,d[h+1]]),p=p.concat(d.slice(h,f+2)),0!==d[f]&&(p=p.concat([0,d[f+1]]))}else if(\"toself\"===s.fill||\"tonext\"===s.fill){for(p=[],i=0,a=0;a<d.length;a+=2)(isNaN(d[a])||isNaN(d[a+1]))&&((p=p.concat(d.slice(i,a))).push(d[i],d[i+1]),i=a+2);p=p.concat(d.slice(i)),i&&p.push(d[i],d[i+1])}else{var v=s._nexttrace;if(v){var m=g.lineOptions[e+1];if(m){var y=m.positions;if(\"tonexty\"===s.fill){for(p=d.slice(),e=Math.floor(y.length/2);e--;){var x=y[2*e],b=y[2*e+1];isNaN(x)||isNaN(b)||p.push(x,b)}t.fill=v.fillcolor}}}}if(s._prevtrace&&\"tonext\"===s._prevtrace.fill){var _=g.lineOptions[e-1].positions,w=p.length/2,k=[i=w];for(a=0;a<_.length;a+=2)(isNaN(_[a])||isNaN(_[a+1]))&&(k.push(a/2+w+1),i=a+2);p=p.concat(_),t.hole=k}return t.fillmode=s.fill,t.opacity=s.opacity,t.positions=p,t}}),g.fill2d.update(g.fillOptions))}var k=d.dragmode,T=\"lasso\"===k||\"select\"===k,A=d.clickmode.indexOf(\"select\")>-1;for(f=0;f<y;f++){var M=r[f][0],S=M.trace,E=M.t,C=E.index,L=S._length,P=E.x,O=E.y;if(S.selectedpoints||T||A){if(T||(T=!0),S.selectedpoints){var z=g.selectBatch[C]=s.selIndices2selPoints(S),I={};for(p=0;p<z.length;p++)I[z[p]]=1;var D=[];for(p=0;p<L;p++)I[p]||D.push(p);g.unselectBatch[C]=D}var R=E.xpx=new Array(L),F=E.ypx=new Array(L);for(p=0;p<L;p++)R[p]=v.c2p(P[p]),F[p]=m.c2p(O[p])}else E.xpx=E.ypx=null}if(T){if(g.select2d||(g.select2d=n(d._glcanvas.data()[1].regl)),g.scatter2d){var B=new Array(y);for(f=0;f<y;f++)B[f]=g.selectBatch[f].length||g.unselectBatch[f].length?g.markerUnselectedOptions[f]:{};g.scatter2d.update(B)}g.select2d&&(g.select2d.update(g.markerOptions),g.select2d.update(g.markerSelectedOptions)),g.glText&&r.forEach(function(t){var e=((t||[])[0]||{}).trace||{};c.hasText(e)&&h(t)})}else g.scatter2d&&g.scatter2d.update(g.markerOptions);var N={viewport:function(t,e,r){var n=t._size,i=t.width,a=t.height;return[n.l+e.domain[0]*n.w,n.b+r.domain[0]*n.h,i-n.r-(1-e.domain[1])*n.w,a-n.t-(1-r.domain[1])*n.h]}(d,v,m),range:[(v._rl||v.range)[0],(m._rl||m.range)[0],(v._rl||v.range)[1],(m._rl||m.range)[1]]},j=s.repeat(N,g.count);g.fill2d&&g.fill2d.update(j),g.line2d&&g.line2d.update(j),g.error2d&&g.error2d.update(j.concat(j)),g.scatter2d&&g.scatter2d.update(j),g.select2d&&g.select2d.update(j),g.glText&&g.glText.forEach(function(t){t.update(N)})}else g.init()}}},{\"../../lib\":719,\"../../lib/prepare_regl\":732,\"../scatter/link_traces\":1127,\"../scatter/subtypes\":1135,\"./edit_style\":1165,\"gl-text\":317,\"regl-error2d\":490,\"regl-line2d\":491,\"regl-scatter2d\":497}],1169:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=e._scene,i={count:0,dirty:!0,lineOptions:[],fillOptions:[],markerOptions:[],markerSelectedOptions:[],markerUnselectedOptions:[],errorXOptions:[],errorYOptions:[],textOptions:[],textSelectedOptions:[],textUnselectedOptions:[],selectBatch:[],unselectBatch:[]},a={fill2d:!1,scatter2d:!1,error2d:!1,line2d:!1,glText:!1,select2d:!1};return e._scene||((r=e._scene={}).init=function(){n.extendFlat(r,a,i)},r.init(),r.update=function(t){var e=n.repeat(t,r.count);if(r.fill2d&&r.fill2d.update(e),r.scatter2d&&r.scatter2d.update(e),r.line2d&&r.line2d.update(e),r.error2d&&r.error2d.update(e.concat(e)),r.select2d&&r.select2d.update(e),r.glText)for(var i=0;i<r.count;i++)r.glText[i].update(t)},r.draw=function(){for(var t=r.count,e=r.fill2d,i=r.error2d,a=r.line2d,o=r.scatter2d,s=r.glText,l=r.select2d,c=r.selectBatch,u=r.unselectBatch,h=0;h<t;h++){if(e&&r.fillOrder[h]&&e.draw(r.fillOrder[h]),a&&r.lineOptions[h]&&a.draw(h),i&&(r.errorXOptions[h]&&i.draw(h),r.errorYOptions[h]&&i.draw(h+t)),o&&r.markerOptions[h])if(u[h].length){var f=n.repeat([],r.count);f[h]=u[h],o.draw(f)}else c[h].length||o.draw(h);s[h]&&r.textOptions[h]&&s[h].render()}l&&l.draw(c),r.dirty=!1},r.destroy=function(){r.fill2d&&r.fill2d.destroy&&r.fill2d.destroy(),r.scatter2d&&r.scatter2d.destroy&&r.scatter2d.destroy(),r.error2d&&r.error2d.destroy&&r.error2d.destroy(),r.line2d&&r.line2d.destroy&&r.line2d.destroy(),r.select2d&&r.select2d.destroy&&r.select2d.destroy(),r.glText&&r.glText.forEach(function(t){t.destroy&&t.destroy()}),r.lineOptions=null,r.fillOptions=null,r.markerOptions=null,r.markerSelectedOptions=null,r.markerUnselectedOptions=null,r.errorXOptions=null,r.errorYOptions=null,r.textOptions=null,r.textSelectedOptions=null,r.textUnselectedOptions=null,r.selectBatch=null,r.unselectBatch=null,e._scene=null}),r.dirty||n.extendFlat(r,i),r}},{\"../../lib\":719}],1170:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"./edit_style\").styleTextSelection;e.exports=function(t,e){var r=t.cd,a=[],o=r[0].trace,s=r[0].t,l=o._length,c=s.x,u=s.y,h=s._scene,f=s.index;if(!h)return a;var p=n.hasText(o),d=n.hasMarkers(o),g=!d&&!p;if(!0!==o.visible||g)return a;var v=[],m=[];if(!1!==e&&!e.degenerate)for(var y=0;y<l;y++)e.contains([s.xpx[y],s.ypx[y]],!1,y,t)?(v.push(y),a.push({pointNumber:y,x:c[y],y:u[y]})):m.push(y);if(d){var x=h.scatter2d;if(v.length||m.length){if(!h.selectBatch[f].length&&!h.unselectBatch[f].length){var b=new Array(h.count);b[f]=h.markerUnselectedOptions[f],x.update.apply(x,b)}}else{var _=new Array(h.count);_[f]=h.markerOptions[f],x.update.apply(x,_)}}return h.selectBatch[f]=v,h.unselectBatch[f]=m,p&&i(r),a}},{\"../scatter/subtypes\":1135,\"./edit_style\":1165}],1171:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scattergeo/attributes\"),a=t(\"../scatter/attributes\"),o=t(\"../../plots/mapbox/layout_attributes\"),s=t(\"../../plots/attributes\"),l=t(\"../../components/colorscale/attributes\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../plot_api/edit_types\").overrideAll,h=i.line,f=i.marker;e.exports=u({lon:i.lon,lat:i.lat,mode:c({},a.mode,{dflt:\"markers\"}),text:c({},a.text,{}),hovertext:c({},a.hovertext,{}),line:{color:h.color,width:h.width},connectgaps:a.connectgaps,marker:c({symbol:{valType:\"string\",dflt:\"circle\",arrayOk:!0},opacity:f.opacity,size:f.size,sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode},l(\"marker\")),fill:i.fill,fillcolor:a.fillcolor,textfont:o.layers.symbol.textfont,textposition:o.layers.symbol.textposition,below:{valType:\"string\"},selected:{marker:a.selected.marker},unselected:{marker:a.unselected.marker},hoverinfo:c({},s.hoverinfo,{flags:[\"lon\",\"lat\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../../plots/mapbox/layout_attributes\":824,\"../scatter/attributes\":1112,\"../scattergeo/attributes\":1151}],1172:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../lib/geojson_utils\"),s=t(\"../../components/colorscale\"),l=t(\"../../components/drawing\"),c=t(\"../scatter/make_bubble_size_func\"),u=t(\"../scatter/subtypes\"),h=t(\"../../plots/mapbox/convert_text_opts\");function f(){return{geojson:o.makeBlank(),layout:{visibility:\"none\"},paint:{}}}function p(t){return i.isArrayOrTypedArray(t)?function(t){return t}:t?function(){return t}:d}function d(){return\"\"}function g(t){return t[0]===a}e.exports=function(t){var e,r=t[0].trace,a=!0===r.visible&&0!==r._length,v=\"none\"!==r.fill,m=u.hasLines(r),y=u.hasMarkers(r),x=u.hasText(r),b=y&&\"circle\"===r.marker.symbol,_=y&&\"circle\"!==r.marker.symbol,w=f(),k=f(),T=f(),A=f(),M={fill:w,line:k,circle:T,symbol:A};if(!a)return M;if((v||m)&&(e=o.calcTraceToLineCoords(t)),v&&(w.geojson=o.makePolygon(e),w.layout.visibility=\"visible\",i.extendFlat(w.paint,{\"fill-color\":r.fillcolor})),m&&(k.geojson=o.makeLine(e),k.layout.visibility=\"visible\",i.extendFlat(k.paint,{\"line-width\":r.line.width,\"line-color\":r.line.color,\"line-opacity\":r.opacity})),b){var S=function(t){var e,r,a,o,u=t[0].trace,h=u.marker,f=u.selectedpoints,p=i.isArrayOrTypedArray(h.color),d=i.isArrayOrTypedArray(h.size),v=i.isArrayOrTypedArray(h.opacity);function m(t){return u.opacity*t}p&&(r=s.hasColorscale(u,\"marker\")?s.makeColorScaleFuncFromTrace(h):i.identity);d&&(a=c(u));v&&(o=function(t){var e=n(t)?+i.constrain(t,0,1):0;return m(e)});var y,x=[];for(e=0;e<t.length;e++){var b=t[e],_=b.lonlat;if(!g(_)){var w={};r&&(w.mcc=b.mcc=r(b.mc)),a&&(w.mrc=b.mrc=a(b.ms)),o&&(w.mo=o(b.mo)),f&&(w.selected=b.selected||0),x.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:_},properties:w})}}if(f)for(y=l.makeSelectedPointStyleFns(u),e=0;e<x.length;e++){var k=x[e].properties;y.selectedOpacityFn&&(k.mo=m(y.selectedOpacityFn(k))),y.selectedColorFn&&(k.mcc=y.selectedColorFn(k)),y.selectedSizeFn&&(k.mrc=y.selectedSizeFn(k))}return{geojson:{type:\"FeatureCollection\",features:x},mcc:p||y&&y.selectedColorFn?{type:\"identity\",property:\"mcc\"}:h.color,mrc:d||y&&y.selectedSizeFn?{type:\"identity\",property:\"mrc\"}:(T=h.size,T/2),mo:v||y&&y.selectedOpacityFn?{type:\"identity\",property:\"mo\"}:m(h.opacity)};var T}(t);T.geojson=S.geojson,T.layout.visibility=\"visible\",i.extendFlat(T.paint,{\"circle-color\":S.mcc,\"circle-radius\":S.mrc,\"circle-opacity\":S.mo})}if((_||x)&&(A.geojson=function(t){for(var e=t[0].trace,r=(e.marker||{}).symbol,n=e.text,i=\"circle\"!==r?p(r):d,a=u.hasText(e)?p(n):d,o=[],s=0;s<t.length;s++){var l=t[s];g(l.lonlat)||o.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:l.lonlat},properties:{symbol:i(l.mx),text:a(l.tx)}})}return{type:\"FeatureCollection\",features:o}}(t),i.extendFlat(A.layout,{visibility:\"visible\",\"icon-image\":\"{symbol}-15\",\"text-field\":\"{text}\"}),_&&(i.extendFlat(A.layout,{\"icon-size\":r.marker.size/10}),i.extendFlat(A.paint,{\"icon-opacity\":r.opacity*r.marker.opacity,\"icon-color\":r.marker.color})),x)){var E=(r.marker||{}).size,C=h(r.textposition,E);i.extendFlat(A.layout,{\"text-size\":r.textfont.size,\"text-anchor\":C.anchor,\"text-offset\":C.offset}),i.extendFlat(A.paint,{\"text-color\":r.textfont.color,\"text-opacity\":r.opacity})}return M}},{\"../../components/colorscale\":605,\"../../components/drawing\":614,\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/geojson_utils\":714,\"../../plots/mapbox/convert_text_opts\":821,\"../scatter/make_bubble_size_func\":1128,\"../scatter/subtypes\":1135,\"fast-isnumeric\":225}],1173:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,i){return n.coerce(t,e,c,r,i)}if(function(t,e,r){var n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length);return e._length=a,a}(0,e,h)){if(h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),h(\"below\"),i.hasLines(e)&&(o(t,e,r,u,h,{noDash:!0}),h(\"connectgaps\")),i.hasMarkers(e)){a(t,e,r,u,h,{noLine:!0});var f=e.marker;\"circle\"!==f.symbol&&(n.isArrayOrTypedArray(f.size)&&(f.size=f.size[0]),n.isArrayOrTypedArray(f.color)&&(f.color=f.color[0]))}i.hasText(e)&&s(t,e,u,h,{noSelect:!0}),h(\"fill\"),\"none\"!==e.fill&&l(t,e,r,h),n.coerceSelectionMarkerOpacity(e,h)}else e.visible=!1}},{\"../../lib\":719,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1171}],1174:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t}},{}],1175:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\"),o=i.fillText,s=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,h=t.ya,f=t.subplot,p=360*(e>=0?Math.floor((e+180)/360):Math.ceil((e-180)/360)),d=e-p;if(n.getClosest(l,function(t){var e=t.lonlat;if(e[0]===s)return 1/0;var n=i.modHalf(e[0],360),a=e[1],o=f.project([n,a]),l=o.x-u.c2p([d,a]),c=o.y-h.c2p([n,r]),p=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(l*l+c*c)-p,1-3/p)},t),!1!==t.index){var g=l[t.index],v=g.lonlat,m=[i.modHalf(v[0],360)+p,v[1]],y=u.c2p(m),x=h.c2p(m),b=g.mrc||1;return t.x0=y-b,t.x1=y+b,t.y0=x-b,t.y1=x+b,t.color=a(c,g),t.extraText=function(t,e,r){if(t.hovertemplate)return;var n=(e.hi||t.hoverinfo).split(\"+\"),i=-1!==n.indexOf(\"all\"),a=-1!==n.indexOf(\"lon\"),s=-1!==n.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}i||a&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):a?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(i||-1!==n.indexOf(\"text\"))&&o(e,t,c);return c.join(\"<br>\")}(c,g,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},{\"../../components/fx\":632,\"../../constants/numerical\":695,\"../../lib\":719,\"../scatter/get_trace_color\":1121}],1176:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"../scattergeo/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.update(e)},moduleType:\"trace\",name:\"scattermapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"symbols\",\"showLegend\",\"scatterlike\"],meta:{}}},{\"../../plots/mapbox\":822,\"../scatter/marker_colorbar\":1129,\"../scattergeo/calc\":1152,\"./attributes\":1171,\"./defaults\":1173,\"./event_data\":1174,\"./hover\":1175,\"./plot\":1177,\"./select\":1178}],1177:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix,a=[\"fill\",\"line\",\"circle\",\"symbol\"];function o(t,e){this.subplot=t,this.uid=e,this.sourceIds={fill:\"source-\"+e+\"-fill\",line:\"source-\"+e+\"-line\",circle:\"source-\"+e+\"-circle\",symbol:\"source-\"+e+\"-symbol\"},this.layerIds={fill:i+e+\"-fill\",line:i+e+\"-line\",circle:i+e+\"-circle\",symbol:i+e+\"-symbol\"},this.below=null}var s=o.prototype;s.addSource=function(t,e){this.subplot.map.addSource(this.sourceIds[t],{type:\"geojson\",data:e.geojson})},s.setSourceData=function(t,e){this.subplot.map.getSource(this.sourceIds[t]).setData(e.geojson)},s.addLayer=function(t,e,r){this.subplot.addLayer({type:t,id:this.layerIds[t],source:this.sourceIds[t],layout:e.layout,paint:e.paint},r)},s.update=function(t){var e,r,i,o=this.subplot,s=o.map,l=n(t),c=o.belowLookup[\"trace-\"+this.uid];if(c!==this.below){for(e=a.length-1;e>=0;e--)r=a[e],s.removeLayer(this.layerIds[r]);for(e=0;e<a.length;e++)i=l[r=a[e]],this.addLayer(r,i,c);this.below=c}for(e=0;e<a.length;e++)i=l[r=a[e]],o.setOptions(this.layerIds[r],\"setLayoutProperty\",i.layout),\"visible\"===i.layout.visibility&&(this.setSourceData(r,i),o.setOptions(this.layerIds[r],\"setPaintProperty\",i.paint));t[0].trace._glTrace=this},s.dispose=function(){for(var t=this.subplot.map,e=a.length-1;e>=0;e--){var r=a[e];t.removeLayer(this.layerIds[r]),t.removeSource(this.sourceIds[r])}},e.exports=function(t,e){for(var r=e[0].trace,i=new o(t,r.uid),s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid],c=0;c<a.length;c++){var u=a[c],h=s[u];i.addSource(u,h),i.addLayer(u,h,l)}return e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":820,\"./convert\":1172}],1178:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,o=t.cd,s=t.xaxis,l=t.yaxis,c=[],u=o[0].trace;if(!i.hasMarkers(u))return[];if(!1===e)for(r=0;r<o.length;r++)o[r].selected=0;else for(r=0;r<o.length;r++){var h=o[r],f=h.lonlat;if(f[0]!==a){var p=[n.modHalf(f[0],360),f[1]],d=[s.c2p(p),l.c2p(p)];e.contains(d,null,r,t)?(c.push({pointNumber:r,lon:f[0],lat:f[1]}),h.selected=1):h.selected=0}}return c}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../scatter/subtypes\":1135}],1179:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../scatter/attributes\"),o=t(\"../../plots/attributes\"),s=a.line;e.exports={mode:a.mode,r:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},theta:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},r0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dr:{valType:\"number\",dflt:1,editType:\"calc\"},theta0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dtheta:{valType:\"number\",editType:\"calc\"},thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\",\"gradians\"],dflt:\"degrees\",editType:\"calc+clearAxisTypes\"},text:a.text,hovertext:a.hovertext,line:{color:s.color,width:s.width,dash:s.dash,shape:i({},s.shape,{values:[\"linear\",\"spline\"]}),smoothing:s.smoothing,editType:\"calc\"},connectgaps:a.connectgaps,marker:a.marker,cliponaxis:i({},a.cliponaxis,{dflt:!1}),textposition:a.textposition,textfont:a.textfont,fill:i({},a.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:a.fillcolor,hoverinfo:i({},o.hoverinfo,{flags:[\"r\",\"theta\",\"text\",\"name\"]}),hoveron:a.hoveron,hovertemplate:n(),selected:a.selected,unselected:a.unselected}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1180:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../plots/cartesian/axes\"),o=t(\"../scatter/colorscale_calc\"),s=t(\"../scatter/arrays_to_calcdata\"),l=t(\"../scatter/calc_selection\"),c=t(\"../scatter/calc\").calcMarkerSize;e.exports=function(t,e){for(var r=t._fullLayout,u=e.subplot,h=r[u].radialaxis,f=r[u].angularaxis,p=h.makeCalcdata(e,\"r\"),d=f.makeCalcdata(e,\"theta\"),g=e._length,v=new Array(g),m=0;m<g;m++){var y=p[m],x=d[m],b=v[m]={};n(y)&&n(x)?(b.r=y,b.theta=x):b.r=i}var _=c(e,g);return e._extremes.x=a.findExtremes(h,p,{ppad:_}),o(t,e),s(v,e),l(v,e),v}},{\"../../constants/numerical\":695,\"../../plots/cartesian/axes\":767,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc\":1113,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1181:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/line_shape_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,h=t(\"./attributes\");function f(t,e,r,n){var i,a=n(\"r\"),o=n(\"theta\");if(a)o?i=Math.min(a.length,o.length):(i=a.length,n(\"theta0\"),n(\"dtheta\"));else{if(!o)return 0;i=e.theta.length,n(\"r0\"),n(\"dr\")}return e._length=i,i}e.exports={handleRThetaDefaults:f,supplyDefaults:function(t,e,r,p){function d(r,i){return n.coerce(t,e,h,r,i)}var g=f(0,e,0,d);if(g){d(\"thetaunit\"),d(\"mode\",g<u?\"lines+markers\":\"lines\"),d(\"text\"),d(\"hovertext\"),\"fills\"!==e.hoveron&&d(\"hovertemplate\"),i.hasLines(e)&&(o(t,e,r,p,d),s(t,e,d),d(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,p,d,{gradient:!0}),i.hasText(e)&&l(t,e,p,d);var v=[];(i.hasMarkers(e)||i.hasText(e))&&(d(\"cliponaxis\"),d(\"marker.maxdisplayed\"),v.push(\"points\")),d(\"fill\"),\"none\"!==e.fill&&(c(t,e,r,d),i.hasLines(e)||s(t,e,d)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||v.push(\"fills\"),d(\"hoveron\",v.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/line_shape_defaults\":1126,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1179}],1182:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\");function o(t,e,r,n){var o=r.radialAxis,s=r.angularAxis;o._hovertitle=\"r\",s._hovertitle=\"\\u03b8\";var l=o.c2l(t.r);n.rLabel=i.tickText(o,l,\"hover\").text;var c=\"degrees\"===s.thetaunit?a.rad2deg(t.theta):t.theta;n.thetaLabel=i.tickText(s,c,\"hover\").text;var u=t.hi||e.hoverinfo,h=[];function f(t,e){h.push(t._hovertitle+\": \"+e)}if(!e.hovertemplate){var p=u.split(\"+\");-1!==p.indexOf(\"all\")&&(p=[\"r\",\"theta\",\"text\"]),-1!==p.indexOf(\"r\")&&f(o,n.rLabel),-1!==p.indexOf(\"theta\")&&f(s,n.thetaLabel),-1!==p.indexOf(\"text\")&&n.text&&(h.push(n.text),delete n.text),n.extraText=h.join(\"<br>\")}}e.exports={hoverPoints:function(t,e,r,i){var a=n(t,e,r,i);if(a&&!1!==a[0].index){var s=a[0];if(void 0===s.index)return a;var l=t.subplot,c=s.cd[s.index],u=s.trace;if(l.isPtInside(c))return s.xLabelVal=void 0,s.yLabelVal=void 0,o(c,u,l,s),s.hovertemplate=u.hovertemplate,a}},makeHoverPointText:o}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scatter/hover\":1122}],1183:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scatter/select\"),meta:{}}},{\"../../plots/polar\":831,\"../scatter/marker_colorbar\":1129,\"../scatter/select\":1132,\"../scatter/style\":1134,\"./attributes\":1179,\"./calc\":1180,\"./defaults\":1181,\"./hover\":1182,\"./plot\":1184}],1184:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){for(var a=e.layers.frontplot.select(\"g.scatterlayer\"),o={xaxis:e.xaxis,yaxis:e.yaxis,plot:e.framework,layerClipId:e._hasClipOnAxisFalse?e.clipIds.forTraces:null},s=e.radialAxis,l=e.angularAxis,c=0;c<r.length;c++)for(var u=r[c],h=0;h<u.length;h++){var f=u[h],p=f.r;if(p===i)f.x=f.y=i;else{var d=s.c2g(p),g=l.c2g(f.theta);f.x=d*Math.cos(g),f.y=d*Math.sin(g)}}n(t,o,r,a)}},{\"../../constants/numerical\":695,\"../scatter/plot\":1131}],1185:[function(t,e,r){\"use strict\";var n=t(\"../scatterpolar/attributes\"),i=t(\"../scattergl/attributes\");e.exports={mode:n.mode,r:n.r,theta:n.theta,r0:n.r0,dr:n.dr,theta0:n.theta0,dtheta:n.dtheta,thetaunit:n.thetaunit,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,line:i.line,connectgaps:i.connectgaps,marker:i.marker,fill:i.fill,fillcolor:i.fillcolor,textposition:i.textposition,textfont:i.textfont,hoverinfo:n.hoverinfo,selected:n.selected,unselected:n.unselected}},{\"../scattergl/attributes\":1160,\"../scatterpolar/attributes\":1179}],1186:[function(t,e,r){\"use strict\";var n=t(\"../scatter/colorscale_calc\"),i=t(\"../scatter/calc\").calcMarkerSize,a=t(\"../scattergl/convert\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r=t._fullLayout,l=e.subplot,c=r[l].radialaxis,u=r[l].angularaxis,h=c.makeCalcdata(e,\"r\"),f=u.makeCalcdata(e,\"theta\"),p=e._length,d={};p<h.length&&(h=h.slice(0,p)),p<f.length&&(f=f.slice(0,p)),d.r=h,d.theta=f,n(t,e);var g,v=d.opts=a.style(t,e);return p<s?g=i(e,p):v.marker&&(g=2*(v.marker.sizeAvg||Math.max(v.marker.size,3))),e._extremes.x=o.findExtremes(c,h,{ppad:g}),[{x:!1,y:!1,t:d,trace:e}]}},{\"../../plots/cartesian/axes\":767,\"../scatter/calc\":1113,\"../scatter/colorscale_calc\":1115,\"../scattergl/constants\":1162,\"../scattergl/convert\":1163}],1187:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatterpolar/defaults\").handleRThetaDefaults,o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}var d=a(t,e,f,p);d?(p(\"thetaunit\"),p(\"mode\",d<u?\"lines+markers\":\"lines\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),i.hasLines(e)&&(s(t,e,r,f,p),p(\"connectgaps\")),i.hasMarkers(e)&&o(t,e,r,f,p),i.hasText(e)&&l(t,e,f,p),p(\"fill\"),\"none\"!==e.fill&&c(t,e,r,p),n.coerceSelectionMarkerOpacity(e,p)):e.visible=!1}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"../scatterpolar/defaults\":1181,\"./attributes\":1185}],1188:[function(t,e,r){\"use strict\";var n=t(\"../scattergl/hover\"),i=t(\"../scatterpolar/hover\").makeHoverPointText;e.exports={hoverPoints:function(t,e,r,a){var o=t.cd[0].t,s=o.r,l=o.theta,c=n.hoverPoints(t,e,r,a);if(c&&!1!==c[0].index){var u=c[0];if(void 0===u.index)return c;var h=t.subplot,f=u.cd[u.index],p=u.trace;if(f.r=s[u.index],f.theta=l[u.index],h.isPtInside(f))return u.xLabelVal=void 0,u.yLabelVal=void 0,i(f,p,h,u),c}}}},{\"../scattergl/hover\":1166,\"../scatterpolar/hover\":1182}],1189:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolargl\",basePlotModule:t(\"../../plots/polar\"),categories:[\"gl\",\"regl\",\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scattergl/select\"),meta:{}}},{\"../../plots/polar\":831,\"../scatter/marker_colorbar\":1129,\"../scattergl/select\":1170,\"./attributes\":1185,\"./calc\":1186,\"./defaults\":1187,\"./hover\":1188,\"./plot\":1190}],1190:[function(t,e,r){\"use strict\";var n=t(\"point-cluster\"),i=t(\"fast-isnumeric\"),a=t(\"../scattergl/plot\"),o=t(\"../scattergl/scene_update\"),s=t(\"../scattergl/convert\"),l=t(\"../../lib\"),c=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e,r){if(r.length){var u=e.radialAxis,h=e.angularAxis,f=o(t,e);return r.forEach(function(r){if(r&&r[0]&&r[0].trace){var a,o=r[0],p=o.trace,d=o.t,g=p._length,v=d.r,m=d.theta,y=d.opts,x=v.slice(),b=m.slice();for(a=0;a<v.length;a++)e.isPtInside({r:v[a],theta:m[a]})||(x[a]=NaN,b[a]=NaN);var _=new Array(2*g),w=Array(g),k=Array(g);for(a=0;a<g;a++){var T,A,M=x[a];if(i(M)){var S=u.c2g(M),E=h.c2g(b[a],p.thetaunit);T=S*Math.cos(E),A=S*Math.sin(E)}else T=A=NaN;w[a]=_[2*a]=T,k[a]=_[2*a+1]=A}d.tree=n(_),y.marker&&g>=c&&(y.marker.cluster=d.tree),y.marker&&(y.markerSel.positions=y.markerUnsel.positions=y.marker.positions=_),y.line&&_.length>1&&l.extendFlat(y.line,s.linePositions(t,p,_)),y.text&&(l.extendFlat(y.text,{positions:_},s.textPosition(t,p,y.text,y.marker)),l.extendFlat(y.textSel,{positions:_},s.textPosition(t,p,y.text,y.markerSel)),l.extendFlat(y.textUnsel,{positions:_},s.textPosition(t,p,y.text,y.markerUnsel))),y.fill&&!f.fill2d&&(f.fill2d=!0),y.marker&&!f.scatter2d&&(f.scatter2d=!0),y.line&&!f.line2d&&(f.line2d=!0),y.text&&!f.glText&&(f.glText=!0),f.lineOptions.push(y.line),f.fillOptions.push(y.fill),f.markerOptions.push(y.marker),f.markerSelectedOptions.push(y.markerSel),f.markerUnselectedOptions.push(y.markerUnsel),f.textOptions.push(y.text),f.textSelectedOptions.push(y.textSel),f.textUnselectedOptions.push(y.textUnsel),f.selectBatch.push([]),f.unselectBatch.push([]),d.x=w,d.y=k,d.rawx=w,d.rawy=k,d.r=v,d.theta=m,d.positions=_,d._scene=f,d.index=f.count,f.count++}}),a(t,e,r)}}},{\"../../lib\":719,\"../scattergl/constants\":1162,\"../scattergl/convert\":1163,\"../scattergl/plot\":1168,\"../scattergl/scene_update\":1169,\"fast-isnumeric\":225,\"point-cluster\":469}],1191:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/drawing/attributes\").dash,l=t(\"../../lib/extend\").extendFlat,c=i.marker,u=i.line,h=c.line;e.exports={a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},c:{valType:\"data_array\",editType:\"calc\"},sum:{valType:\"number\",dflt:0,min:0,editType:\"calc\"},mode:l({},i.mode,{dflt:\"markers\"}),text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),line:{color:u.color,width:u.width,dash:s,shape:l({},u.shape,{values:[\"linear\",\"spline\"]}),smoothing:u.smoothing,editType:\"calc\"},connectgaps:i.connectgaps,cliponaxis:i.cliponaxis,fill:l({},i.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:i.fillcolor,marker:l({symbol:c.symbol,opacity:c.opacity,maxdisplayed:c.maxdisplayed,size:c.size,sizeref:c.sizeref,sizemin:c.sizemin,sizemode:c.sizemode,line:l({width:h.width,editType:\"calc\"},o(\"marker.line\")),gradient:c.gradient,editType:\"calc\"},o(\"marker\")),textfont:i.textfont,textposition:i.textposition,selected:i.selected,unselected:i.unselected,hoverinfo:l({},a.hoverinfo,{flags:[\"a\",\"b\",\"c\",\"text\",\"name\"]}),hoveron:i.hoveron,hovertemplate:n()}},{\"../../components/colorscale/attributes\":600,\"../../components/drawing/attributes\":613,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1192:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=[\"a\",\"b\",\"c\"],c={a:[\"b\",\"c\"],b:[\"a\",\"c\"],c:[\"a\",\"b\"]};e.exports=function(t,e){var r,u,h,f,p,d,g=t._fullLayout[e.subplot].sum,v=e.sum||g,m={a:e.a,b:e.b,c:e.c};for(r=0;r<l.length;r++)if(!m[h=l[r]]){for(p=m[c[h][0]],d=m[c[h][1]],f=new Array(p.length),u=0;u<p.length;u++)f[u]=v-p[u]-d[u];m[h]=f}var y,x,b,_,w,k,T=e._length,A=new Array(T);for(r=0;r<T;r++)y=m.a[r],x=m.b[r],b=m.c[r],n(y)&&n(x)&&n(b)?(1!==(_=g/((y=+y)+(x=+x)+(b=+b)))&&(y*=_,x*=_,b*=_),k=y,w=b-x,A[r]={x:w,y:k,a:y,b:x,c:b}):A[r]={x:!1,y:!1};return s(e,T),i(t,e),a(A,e),o(A,e),A}},{\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc\":1113,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1193:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}var d,g=p(\"a\"),v=p(\"b\"),m=p(\"c\");if(g?(d=g.length,v?(d=Math.min(d,v.length),m&&(d=Math.min(d,m.length))):d=m?Math.min(d,m.length):0):v&&m&&(d=Math.min(v.length,m.length)),d){e._length=d,p(\"sum\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),p(\"mode\",d<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,f,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,f,p,{gradient:!0}),a.hasText(e)&&c(t,e,f,p);var y=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"cliponaxis\"),p(\"marker.maxdisplayed\"),y.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||y.push(\"fills\"),p(\"hoveron\",y.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/line_shape_defaults\":1126,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1191}],1194:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),n[i]){var a=n[i];t.a=a.a,t.b=a.b,t.c=a.c}else t.a=e.a,t.b=e.b,t.c=e.c;return t}},{}],1195:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,h=c-u;return s.x0=Math.max(Math.min(s.x0,h),u),s.x1=Math.max(Math.min(s.x1,h),u),o}var f=s.cd[s.index];s.a=f.a,s.b=f.b,s.c=f.c,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.subplot;s.aLabel=i.tickText(p.aaxis,f.a,\"hover\").text,s.bLabel=i.tickText(p.baxis,f.b,\"hover\").text,s.cLabel=i.tickText(p.caxis,f.c,\"hover\").text;var d=s.trace,g=f.hi||d.hoverinfo,v=[];if(!d.hovertemplate){var m=g.split(\"+\");-1!==m.indexOf(\"all\")&&(m=[\"a\",\"b\",\"c\"]),-1!==m.indexOf(\"a\")&&y(p.aaxis,s.aLabel),-1!==m.indexOf(\"b\")&&y(p.baxis,s.bLabel),-1!==m.indexOf(\"c\")&&y(p.caxis,s.cLabel)}return s.extraText=v.join(\"<br>\"),s.hovertemplate=d.hovertemplate,o}function y(t,e){v.push(t._hovertitle+\": \"+e)}}},{\"../../plots/cartesian/axes\":767,\"../scatter/hover\":1122}],1196:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scatterternary\",basePlotModule:t(\"../../plots/ternary\"),categories:[\"ternary\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/ternary\":843,\"../scatter/marker_colorbar\":1129,\"../scatter/select\":1132,\"../scatter/style\":1134,\"./attributes\":1191,\"./calc\":1192,\"./defaults\":1193,\"./event_data\":1194,\"./hover\":1195,\"./plot\":1197}],1197:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\");e.exports=function(t,e,r){var i=e.plotContainer;i.select(\".scatterlayer\").selectAll(\"*\").remove();var a={xaxis:e.xaxis,yaxis:e.yaxis,plot:i,layerClipId:e._hasClipOnAxisFalse?e.clipIdRelative:null},o=e.layers.frontplot.select(\"g.scatterlayer\");n(t,a,r,o)}},{\"../scatter/plot\":1131}],1198:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../scattergl/attributes\"),s=t(\"../../plots/cartesian/constants\").idRegex,l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"../../lib/extend\").extendFlat,u=n.marker,h=u.line,f=c(i(\"marker.line\",{editTypeOverride:\"calc\"}),{width:c({},h.width,{editType:\"calc\"}),editType:\"calc\"}),p=c(i(\"marker\"),{symbol:u.symbol,size:c({},u.size,{editType:\"markerSize\"}),sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:f,editType:\"calc\"});function d(t){return{valType:\"info_array\",freeLength:!0,editType:\"calc\",items:{valType:\"subplotid\",regex:s[t],editType:\"plot\"}}}p.color.editType=p.cmin.editType=p.cmax.editType=\"style\",e.exports={dimensions:l(\"dimension\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},label:{valType:\"string\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},axis:{type:{valType:\"enumerated\",values:[\"linear\",\"log\",\"date\",\"category\"],editType:\"calc+clearAxisTypes\"},matches:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc+clearAxisTypes\"},editType:\"calc+clearAxisTypes\"}),text:c({},o.text,{}),hovertext:c({},o.hovertext,{}),hovertemplate:a(),marker:p,xaxes:d(\"x\"),yaxes:d(\"y\"),diagonal:{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},showupperhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},showlowerhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},selected:{marker:o.selected.marker,editType:\"calc\"},unselected:{marker:o.unselected.marker,editType:\"calc\"},opacity:o.opacity}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773,\"../scatter/attributes\":1112,\"../scattergl/attributes\":1160}],1199:[function(t,e,r){\"use strict\";var n=t(\"regl-line2d\"),i=t(\"../../registry\"),a=t(\"../../lib/prepare_regl\"),o=t(\"../../plots/get_data\").getModuleCalcData,s=t(\"../../plots/cartesian\"),l=t(\"../../plots/cartesian/axis_ids\").getFromId,c=t(\"../../plots/cartesian/axes\").shouldShowZeroLine,u=\"splom\";function h(t,e,r){for(var n=r.matrixOptions.data.length,i=e._visibleDims,a=r.viewOpts.ranges=new Array(n),o=0;o<i.length;o++){var s=i[o],c=a[o]=new Array(4),u=l(t,e._diag[s][0]);u&&(c[0]=u.r2l(u.range[0]),c[2]=u.r2l(u.range[1]));var h=l(t,e._diag[s][1]);h&&(c[1]=h.r2l(h.range[0]),c[3]=h.r2l(h.range[1]))}r.selectBatch.length||r.unselectBatch.length?r.matrix.update({ranges:a},{ranges:a}):r.matrix.update({ranges:a})}function f(t){var e=t._fullLayout,r=e._glcanvas.data()[0].regl,i=e._splomGrid;i||(i=e._splomGrid=n(r)),i.update(function(t){var e,r=t._fullLayout,n=r._size,i=[0,0,r.width,r.height],a={};function o(t,e,r,n,o,s){var l=e[t+\"color\"],c=e[t+\"width\"],u=String(l+c);u in a?a[u].data.push(NaN,NaN,r,n,o,s):a[u]={data:[r,n,o,s],join:\"rect\",thickness:c,color:l,viewport:i,range:i,overlay:!1}}for(e in r._splomSubplots){var s,l,u=r._plots[e],h=u.xaxis,f=u.yaxis,p=h._vals,d=f._vals,g=n.b+f.domain[0]*n.h,v=-f._m,m=-v*f.r2l(f.range[0],f.calendar);if(h.showgrid)for(e=0;e<p.length;e++)s=h._offset+h.l2p(p[e].x),o(\"grid\",h,s,g,s,g+f._length);if(f.showgrid)for(e=0;e<d.length;e++)l=g+m+v*d[e].x,o(\"grid\",f,h._offset,l,h._offset+h._length,l);c(t,h,f)&&(s=h._offset+h.l2p(0),o(\"zeroline\",h,s,g,s,g+f._length)),c(t,f,h)&&(l=g+m+0,o(\"zeroline\",f,h._offset,l,h._offset+h._length,l))}var y=[];for(e in a)y.push(a[e]);return y}(t))}e.exports={name:u,attr:s.attr,attrRegex:s.attrRegex,layoutAttributes:s.layoutAttributes,supplyLayoutDefaults:s.supplyLayoutDefaults,drawFramework:s.drawFramework,plot:function(t){var e=t._fullLayout,r=i.getModule(u),n=o(t.calcdata,r)[0];a(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])&&(e._hasOnlyLargeSploms&&f(t),r.plot(t,{},n))},drag:function(t){var e=t.calcdata,r=t._fullLayout;r._hasOnlyLargeSploms&&f(t);for(var n=0;n<e.length;n++){var i=e[n][0].trace,a=r._splomScenes[i.uid];\"splom\"===i.type&&a&&a.matrix&&h(t,i,a)}},updateGrid:f,clean:function(t,e,r,n){var i,a={};if(n._splomScenes){for(i=0;i<t.length;i++){var o=t[i];\"splom\"===o.type&&(a[o.uid]=1)}for(i=0;i<r.length;i++){var l=r[i];if(!a[l.uid]){var c=n._splomScenes[l.uid];c&&c.destroy&&c.destroy(),n._splomScenes[l.uid]=null,delete n._splomScenes[l.uid]}}}0===Object.keys(n._splomScenes||{}).length&&delete n._splomScenes,n._splomGrid&&!e._hasOnlyLargeSploms&&n._hasOnlyLargeSploms&&(n._splomGrid.destroy(),n._splomGrid=null,delete n._splomGrid),s.clean(t,e,r,n)},updateFx:s.updateFx,toSVG:s.toSVG}},{\"../../lib/prepare_regl\":732,\"../../plots/cartesian\":778,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_ids\":770,\"../../plots/get_data\":802,\"../../registry\":847,\"regl-line2d\":491}],1200:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../scatter/calc\").calcMarkerSize,o=t(\"../scatter/calc\").calcAxisExpansion,s=t(\"../scatter/colorscale_calc\"),l=t(\"../scattergl/convert\").markerSelection,c=t(\"../scattergl/convert\").markerStyle,u=t(\"./scene_update\"),h=t(\"../../constants/numerical\").BADNUM,f=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r,p,d,g,v,m,y=e.dimensions,x=e._length,b={},_=b.cdata=[],w=b.data=[],k=e._visibleDims=[];function T(t,r){for(var i=t.makeCalcdata({v:r.values,vcalendar:e.calendar},\"v\"),a=0;a<i.length;a++)i[a]=i[a]===h?NaN:i[a];_.push(i),w.push(\"log\"===t.type?n.simpleMap(i,t.c2l):i)}for(r=0;r<y.length;r++)if((d=y[r]).visible){if(g=i.getFromId(t,e._diag[r][0]),v=i.getFromId(t,e._diag[r][1]),g&&v&&g.type!==v.type){n.log(\"Skipping splom dimension \"+r+\" with conflicting axis types\");continue}g?(T(g,d),v&&\"category\"===v.type&&(v._categories=g._categories.slice())):T(v,d),k.push(r)}for(s(t,e),n.extendFlat(b,c(e)),m=_.length*x>f?2*(b.sizeAvg||Math.max(b.size,3)):a(e,x),p=0;p<k.length;p++)d=y[r=k[p]],g=i.getFromId(t,e._diag[r][0])||{},v=i.getFromId(t,e._diag[r][1])||{},o(t,e,g,v,_[p],_[p],m);var A=u(t,e);return A.matrix||(A.matrix=!0),A.matrixOptions=b,A.selectedOptions=l(e,e.selected),A.unselectedOptions=l(e,e.unselected),[{x:!1,y:!1,t:{},trace:e}]}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../scatter/calc\":1113,\"../scatter/colorscale_calc\":1115,\"../scattergl/constants\":1162,\"../scattergl/convert\":1163,\"./scene_update\":1207}],1201:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"../scatter/subtypes\"),s=t(\"../scatter/marker_defaults\"),l=t(\"../parcoords/merge_length\"),c=/-open/;function u(t,e){function r(r,i){return n.coerce(t,e,a.dimensions,r,i)}r(\"label\");var i=r(\"values\");i&&i.length?r(\"visible\"):e.visible=!1,r(\"axis.type\"),r(\"axis.matches\")}e.exports=function(t,e,r,h){function f(r,i){return n.coerce(t,e,a,r,i)}var p=i(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=f(\"diagonal.visible\"),g=f(\"showupperhalf\"),v=f(\"showlowerhalf\");if(l(e,p,\"values\")&&(d||g||v)){f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),s(t,e,r,h,f);var m=c.test(e.marker.symbol),y=o.isBubble(e);f(\"marker.line.width\",m||y?1:0),function(t,e,r,n){var i,a,o=e.dimensions,s=o.length,l=e.showupperhalf,c=e.showlowerhalf,u=e.diagonal.visible,h=new Array(s),f=new Array(s);for(i=0;i<s;i++){var p=i?i+1:\"\";h[i]=\"x\"+p,f[i]=\"y\"+p}var d=n(\"xaxes\",h),g=n(\"yaxes\",f),v=e._diag=new Array(s);e._xaxes={},e._yaxes={};var m=[],y=[];function x(t,n,i,a){if(t){var o=t.charAt(0),s=r._splomAxes[o];if(e[\"_\"+o+\"axes\"][t]=1,a.push(t),!(t in s)){var l=s[t]={};i&&(l.label=i.label||\"\",i.visible&&i.axis&&(i.axis.type&&(l.type=i.axis.type),i.axis.matches&&(l.matches=n)))}}}var b=!u&&!c,_=!u&&!l;for(e._axesDim={},i=0;i<s;i++){var w=o[i],k=0===i,T=i===s-1,A=k&&b||T&&_?void 0:d[i],M=k&&_||T&&b?void 0:g[i];x(A,M,w,m),x(M,A,w,y),v[i]=[A,M],e._axesDim[A]=i,e._axesDim[M]=i}for(i=0;i<m.length;i++)for(a=0;a<y.length;a++){var S=m[i]+y[a];i>a&&l?r._splomSubplots[S]=1:i<a&&c?r._splomSubplots[S]=1:i!==a||!u&&c&&l||(r._splomSubplots[S]=1)}(!c||!u&&l&&c)&&(r._splomGridDflt.xside=\"bottom\",r._splomGridDflt.yside=\"left\")}(0,e,h,f),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../parcoords/merge_length\":1083,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"./attributes\":1198}],1202:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scattergl/convert\").markerStyle;e.exports=function(t,e){var r=e.trace,o=t._fullLayout._splomScenes[r.uid];if(o){i(t,r),n.extendFlat(o.matrixOptions,a(r));var s=n.extendFlat({},o.matrixOptions,o.viewOpts);o.matrix.update(s,null)}}},{\"../../lib\":719,\"../scatter/colorscale_calc\":1115,\"../scattergl/convert\":1163}],1203:[function(t,e,r){\"use strict\";r.getDimIndex=function(t,e){for(var r=e._id,n={x:0,y:1}[r.charAt(0)],i=t._visibleDims,a=0;a<i.length;a++){var o=i[a];if(t._diag[o][n]===r)return a}return!1}},{}],1204:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i=t(\"../scattergl/hover\").calcHover;e.exports={hoverPoints:function(t,e,r){var a=t.cd[0].trace,o=t.scene.matrixOptions.cdata,s=t.xa,l=t.ya,c=s.c2p(e),u=l.c2p(r),h=t.distance,f=n.getDimIndex(a,s),p=n.getDimIndex(a,l);if(!1===f||!1===p)return[t];for(var d,g,v=o[f],m=o[p],y=h,x=0;x<v.length;x++){var b=v[x],_=m[x],w=s.c2p(b)-c,k=l.c2p(_)-u,T=Math.sqrt(w*w+k*k);T<y&&(y=g=T,d=x)}return t.index=d,t.distance=y,t.dxy=g,void 0===d?[t]:(i(t,v,m,a),[t])}}},{\"../scattergl/hover\":1166,\"./helpers\":1203}],1205:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../components/grid\");e.exports={moduleType:\"trace\",name:\"splom\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\"),editStyle:t(\"./edit_style\"),meta:{}},n.register(i)},{\"../../components/grid\":636,\"../../registry\":847,\"../scatter/marker_colorbar\":1129,\"./attributes\":1198,\"./base_plot\":1199,\"./calc\":1200,\"./defaults\":1201,\"./edit_style\":1202,\"./hover\":1204,\"./plot\":1206,\"./select\":1208}],1206:[function(t,e,r){\"use strict\";var n=t(\"regl-splom\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\");function o(t,e){var r,o,s,l,c,u=t._fullLayout,h=u._size,f=e.trace,p=e.t,d=u._splomScenes[f.uid],g=d.matrixOptions,v=g.cdata,m=u._glcanvas.data()[0].regl,y=u.dragmode;if(0!==v.length){g.lower=f.showupperhalf,g.upper=f.showlowerhalf,g.diagonal=f.diagonal.visible;var x=f._visibleDims,b=v.length,_=d.viewOpts={};for(_.ranges=new Array(b),_.domains=new Array(b),c=0;c<x.length;c++){s=x[c];var w=_.ranges[c]=new Array(4),k=_.domains[c]=new Array(4);(r=a.getFromId(t,f._diag[s][0]))&&(w[0]=r._rl[0],w[2]=r._rl[1],k[0]=r.domain[0],k[2]=r.domain[1]),(o=a.getFromId(t,f._diag[s][1]))&&(w[1]=o._rl[0],w[3]=o._rl[1],k[1]=o.domain[0],k[3]=o.domain[1])}_.viewport=[h.l,h.b,h.w+h.l,h.h+h.b],!0===d.matrix&&(d.matrix=n(m));var T=u.clickmode.indexOf(\"select\")>-1,A=!0;if(\"lasso\"===y||\"select\"===y||!!f.selectedpoints||T){var M=f._length;if(f.selectedpoints){d.selectBatch=f.selectedpoints;var S=f.selectedpoints,E={};for(s=0;s<S.length;s++)E[S[s]]=!0;var C=[];for(s=0;s<M;s++)E[s]||C.push(s);d.unselectBatch=C}var L=p.xpx=new Array(b),P=p.ypx=new Array(b);for(c=0;c<x.length;c++){if(s=x[c],r=a.getFromId(t,f._diag[s][0]))for(L[c]=new Array(M),l=0;l<M;l++)L[c][l]=r.c2p(v[c][l]);if(o=a.getFromId(t,f._diag[s][1]))for(P[c]=new Array(M),l=0;l<M;l++)P[c][l]=o.c2p(v[c][l])}if(d.selectBatch.length||d.unselectBatch.length){var O=i.extendFlat({},g,d.unselectedOptions,_),z=i.extendFlat({},g,d.selectedOptions,_);d.matrix.update(O,z),A=!1}}else p.xpx=p.ypx=null;if(A){var I=i.extendFlat({},g,_);d.matrix.update(I,null)}}}e.exports=function(t,e,r){if(r.length)for(var n=0;n<r.length;n++)o(t,r[n][0])}},{\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"regl-splom\":501}],1207:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t._fullLayout,i=e.uid,a=r._splomScenes;a||(a=r._splomScenes={});var o={dirty:!0},s=a[e.uid];return s||((s=a[i]=n.extendFlat({},o,{matrix:!1,selectBatch:[],unselectBatch:[]})).draw=function(){s.matrix&&s.matrix.draw&&(s.selectBatch.length||s.unselectBatch.length?s.matrix.draw(s.unselectBatch,s.selectBatch):s.matrix.draw()),s.dirty=!1},s.destroy=function(){s.matrix&&s.matrix.destroy&&s.matrix.destroy(),s.matrixOptions=null,s.selectBatch=null,s.unselectBatch=null,s=null}),s.dirty||n.extendFlat(s,o),s}},{\"../../lib\":719}],1208:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"./helpers\");e.exports=function(t,e){var r=t.cd,o=r[0].trace,s=r[0].t,l=t.scene,c=l.matrixOptions.cdata,u=t.xaxis,h=t.yaxis,f=[];if(!l)return f;var p=!i.hasMarkers(o)&&!i.hasText(o);if(!0!==o.visible||p)return f;var d=a.getDimIndex(o,u),g=a.getDimIndex(o,h);if(!1===d||!1===g)return f;var v=s.xpx[d],m=s.ypx[g],y=c[d],x=c[g],b=[],_=[];if(!1!==e&&!e.degenerate)for(var w=0;w<y.length;w++)e.contains([v[w],m[w]],null,w,t)?(b.push(w),f.push({pointNumber:w,x:y[w],y:x[w]})):_.push(w);var k=l.matrixOptions;return b.length||_.length?l.selectBatch.length||l.unselectBatch.length||l.matrix.update(l.unselectedOptions,n.extendFlat({},k,l.selectedOptions,l.viewOpts)):l.matrix.update(k,null),l.selectBatch=b,l.unselectBatch=_,f}},{\"../../lib\":719,\"../scatter/subtypes\":1135,\"./helpers\":1203}],1209:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},starts:{x:{valType:\"data_array\",editType:\"calc\"},y:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},maxdisplayed:{valType:\"integer\",min:0,dflt:1e3,editType:\"calc\"},sizeref:{valType:\"number\",editType:\"calc\",min:0,dflt:1},text:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:i({editType:\"calc\"},{keys:[\"tubex\",\"tubey\",\"tubez\",\"tubeu\",\"tubev\",\"tubew\",\"norm\",\"divergence\"]})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach(function(t){l[t]=a[t]}),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"divergence\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../mesh3d/attributes\":1053}],1210:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){var r,i,a,o,s=e.u,l=e.v,c=e.w,u=e.x,h=e.y,f=e.z,p=Math.min(u.length,h.length,f.length,s.length,l.length,c.length),d=0;e.starts&&(i=e.starts.x||[],a=e.starts.y||[],o=e.starts.z||[],d=Math.min(i.length,a.length,o.length));var g=0,v=1/0;for(r=0;r<p;r++){var m=s[r],y=l[r],x=c[r],b=Math.sqrt(m*m+y*y+x*x);g=Math.max(g,b),v=Math.min(v,b)}n(t,e,{vals:[v,g],containerStr:\"\",cLetter:\"c\"});var _=-1/0,w=1/0,k=-1/0,T=1/0,A=-1/0,M=1/0;for(r=0;r<p;r++){var S=u[r];_=Math.max(_,S),w=Math.min(w,S);var E=h[r];k=Math.max(k,E),T=Math.min(T,E);var C=f[r];A=Math.max(A,C),M=Math.min(M,C)}for(r=0;r<d;r++){var L=i[r];_=Math.max(_,L),w=Math.min(w,L);var P=a[r];k=Math.max(k,P),T=Math.min(T,P);var O=o[r];A=Math.max(A,O),M=Math.min(M,O)}e._len=p,e._slen=d,e._normMax=g,e._xbnds=[w,_],e._ybnds=[T,k],e._zbnds=[M,A]}},{\"../../components/colorscale/calc\":601}],1211:[function(t,e,r){\"use strict\";var n=t(\"gl-streamtube3d\"),i=n.createTubeMesh,a=t(\"../../lib\"),o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\"),c={xaxis:0,yaxis:1,zaxis:2};function u(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var h=u.prototype;function f(t){return a.distinctVals(t).vals}function p(t){var e=t.length;return e>2?t.slice(1,e-1):2===e?[(t[0]+t[1])/2]:t}function d(t){var e=t.length;return 1===e?[.5,.5]:[t[1]-t[0],t[e-1]-t[e-2]]}function g(t,e){var r=t.fullSceneLayout,i=t.dataScale,u=e._len,h={};function g(t,e){var n=r[e],o=i[c[e]];return a.simpleMap(t,function(t){return n.d2l(t)*o})}h.vectors=l(g(e.u,\"xaxis\"),g(e.v,\"yaxis\"),g(e.w,\"zaxis\"),u);var v=f(e.x.slice(0,u)),m=f(e.y.slice(0,u)),y=f(e.z.slice(0,u));if(v.length*m.length*y.length>u)return{positions:[],cells:[]};var x=g(v,\"xaxis\"),b=g(m,\"yaxis\"),_=g(y,\"zaxis\");if(h.meshgrid=[x,b,_],e.starts){var w=e._slen;h.startingPositions=l(g(e.starts.x.slice(0,w),\"xaxis\"),g(e.starts.y.slice(0,w),\"yaxis\"),g(e.starts.z.slice(0,w),\"zaxis\"))}else{for(var k=b[0],T=p(x),A=p(_),M=new Array(T.length*A.length),S=0,E=0;E<T.length;E++)for(var C=0;C<A.length;C++)M[S++]=[T[E],k,A[C]];h.startingPositions=M}h.colormap=o(e),h.tubeSize=e.sizeref,h.maxLength=e.maxdisplayed;var L=g(e._xbnds,\"xaxis\"),P=g(e._ybnds,\"yaxis\"),O=g(e._zbnds,\"zaxis\"),z=d(x),I=d(b),D=d(_),R=[[L[0]-z[0],P[0]-I[0],O[0]-D[0]],[L[1]+z[1],P[1]+I[1],O[1]+D[1]]],F=n(h,R),B=s(e);F.vertexIntensityBounds=[B.min/e._normMax,B.max/e._normMax];var N=e.lightposition;return F.lightPosition=[N.x,N.y,N.z],F.ambient=e.lighting.ambient,F.diffuse=e.lighting.diffuse,F.specular=e.lighting.specular,F.roughness=e.lighting.roughness,F.fresnel=e.lighting.fresnel,F.opacity=e.opacity,e._pad=F.tubeScale*e.sizeref*2,F}h.handlePick=function(t){var e=this.scene.fullSceneLayout,r=this.scene.dataScale;function n(t,n){var i=e[n],a=r[c[n]];return i.l2c(t)/a}if(t.object===this.mesh){var i=t.data.position,a=t.data.velocity;return t.traceCoordinate=[n(i[0],\"xaxis\"),n(i[1],\"yaxis\"),n(i[2],\"zaxis\"),n(a[0],\"xaxis\"),n(a[1],\"yaxis\"),n(a[2],\"zaxis\"),t.data.intensity*this.data._normMax,t.data.divergence],t.textLabel=this.data.hovertext||this.data.text,!0}},h.update=function(t){this.data=t;var e=g(this.scene,t);this.mesh.update(e)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=g(t,e),a=i(r,n),o=new u(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../plots/gl3d/zip3\":818,\"gl-streamtube3d\":313}],1212:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),h=s(\"x\"),f=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length&&p&&p.length?(s(\"starts.x\"),s(\"starts.y\"),s(\"starts.z\"),s(\"maxdisplayed\"),s(\"sizeref\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":1209}],1213:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"streamtube\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),eventData:function(t,e){return t.tubex=t.x,t.tubey=t.y,t.tubez=t.z,t.tubeu=e.traceCoordinate[3],t.tubev=e.traceCoordinate[4],t.tubew=e.traceCoordinate[5],t.norm=e.traceCoordinate[6],t.divergence=e.traceCoordinate[7],delete t.x,delete t.y,delete t.z,t},meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1209,\"./calc\":1210,\"./convert\":1211,\"./defaults\":1212}],1214:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../plots/domain\").attributes,o=t(\"../pie/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports={labels:{valType:\"data_array\",editType:\"calc\"},parents:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},branchvalues:{valType:\"enumerated\",values:[\"remainder\",\"total\"],dflt:\"remainder\",editType:\"calc\"},level:{valType:\"any\",editType:\"plot\",anim:!0},maxdepth:{valType:\"integer\",editType:\"plot\",dflt:-1},marker:{colors:{valType:\"data_array\",editType:\"calc\"},line:{color:s({},o.marker.line.color,{dflt:null}),width:s({},o.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},leaf:{opacity:{valType:\"number\",editType:\"style\",min:0,max:1,dflt:.7},editType:\"plot\"},text:o.text,textinfo:s({},o.textinfo,{editType:\"plot\",flags:[\"label\",\"text\",\"value\"]}),textfont:o.textfont,hovertext:o.hovertext,hoverinfo:s({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"name\"]}),hovertemplate:i(),insidetextfont:o.insidetextfont,outsidetextfont:o.outsidetextfont,domain:a({name:\"sunburst\",trace:!0,editType:\"calc\"})}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../pie/attributes\":1086}],1215:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=r.name=\"sunburst\";r.plot=function(t,e,r,o){var s=n.getModule(a),l=i(t.calcdata,s)[0];s.plot(t,l,r,o)},r.clean=function(t,e,r,n){var i=n._has&&n._has(a),o=e._has&&e._has(a);i&&!o&&n._sunburstlayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],1216:[function(t,e,r){\"use strict\";var n=t(\"d3-hierarchy\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../pie/calc\").makePullColorFn,s=t(\"../pie/calc\").generateExtendedColors,l=a.isArrayOrTypedArray,c={};r.calc=function(t,e){var r,s,c,u,h,f,p=t._fullLayout,d=e.ids,g=l(d),v=e.labels,m=e.parents,y=e.values,x=l(y),b=[],_={},w={},k=function(t){return t||\"number\"==typeof t},T=function(t){return!x||i(y[t])&&y[t]>=0};g?(r=Math.min(d.length,m.length),s=function(t){return k(d[t])&&T(t)},c=function(t){return String(d[t])}):(r=Math.min(v.length,m.length),s=function(t){return k(v[t])&&T(t)},c=function(t){return String(v[t])}),x&&(r=Math.min(r,y.length));for(var A=0;A<r;A++)if(s(A)){var M=c(A),S=k(m[A])?String(m[A]):\"\",E={i:A,id:M,pid:S,label:k(v[A])?String(v[A]):\"\"};x&&(E.v=+y[A]),b.push(E),h=M,_[u=S]?_[u].push(h):_[u]=[h],w[h]=1}if(_[\"\"]){if(_[\"\"].length>1){for(var C=a.randstr(),L=0;L<b.length;L++)\"\"===b[L].pid&&(b[L].pid=C);b.unshift({hasMultipleRoots:!0,id:C,pid:\"\"})}}else{var P,O=[];for(P in _)w[P]||O.push(P);if(1!==O.length)return a.warn(\"Multiple implied roots, cannot build sunburst hierarchy.\");P=O[0],b.unshift({id:P,pid:\"\",label:P})}try{f=n.stratify().id(function(t){return t.id}).parentId(function(t){return t.pid})(b)}catch(t){return a.warn(\"Failed to build sunburst hierarchy. Error: \"+t.message)}var z=n.hierarchy(f),I=!1;if(x)switch(e.branchvalues){case\"remainder\":z.sum(function(t){return t.data.v});break;case\"total\":z.each(function(t){var e=t.data.data.v;if(t.children&&e<t.children.reduce(function(t,e){return t+e.data.data.v},0))return I=!0,a.warn([\"Total value for node\",t.data.data.id,\"is smaller than the sum of its children.\"].join(\" \"));t.value=e})}else z.count();if(!I){z.sort(function(t,e){return e.value-t.value});var D=e.marker.colors||[],R=o(p._sunburstcolormap);return z.each(function(t){var e=t.data.data,r=e.id;e.color=R(D[e.i],r)}),b[0].hierarchy=z,b}},r.crossTraceCalc=function(t){var e=t._fullLayout,r=t.calcdata,n=e.sunburstcolorway,i=e._sunburstcolormap;e.extendsunburstcolors&&(n=s(n,c));var a=0;function o(t){var e=t.data.data,r=e.id;!1===e.color&&(i[r]?e.color=i[r]:t.parent?t.parent.parent?e.color=t.parent.data.data.color:(i[r]=e.color=n[a%n.length],a++):e.color=\"rgba(0,0,0,0)\")}for(var l=0;l<r.length;l++){var u=r[l][0];\"sunburst\"===u.trace.type&&u.hierarchy&&u.hierarchy.each(o)}}},{\"../../lib\":719,\"../pie/calc\":1088,\"d3-hierarchy\":157,\"fast-isnumeric\":225}],1217:[function(t,e,r){\"use strict\";e.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:\"linear\"}},{}],1218:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}var c=l(\"labels\"),u=l(\"parents\");if(c&&c.length&&u&&u.length){var h=l(\"values\");h&&h.length&&l(\"branchvalues\"),l(\"level\"),l(\"maxdepth\"),l(\"marker.line.width\")&&l(\"marker.line.color\",s.paper_bgcolor),l(\"marker.colors\"),l(\"leaf.opacity\");var f=l(\"text\");l(\"textinfo\",Array.isArray(f)?\"text+label\":\"label\"),l(\"hovertext\"),l(\"hovertemplate\");o(t,e,s,l,\"auto\",{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),a(e,s,l),e._length=null}else e.visible=!1}},{\"../../lib\":719,\"../../plots/domain\":792,\"../bar/defaults\":861,\"./attributes\":1214}],1219:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"sunburst\",basePlotModule:t(\"./base_plot\"),categories:[],animatable:!0,attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\").style,meta:{}}},{\"./attributes\":1214,\"./base_plot\":1215,\"./calc\":1216,\"./defaults\":1218,\"./layout_attributes\":1220,\"./layout_defaults\":1221,\"./plot\":1222,\"./style\":1223}],1220:[function(t,e,r){\"use strict\";e.exports={sunburstcolorway:{valType:\"colorlist\",editType:\"calc\"},extendsunburstcolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1221:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"sunburstcolorway\",e.colorway),r(\"extendsunburstcolors\")}},{\"../../lib\":719,\"./layout_attributes\":1220}],1222:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"d3-hierarchy\"),a=t(\"../../registry\"),o=t(\"../../components/fx\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../lib\"),u=t(\"../../lib/events\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"../../lib/setcursor\"),p=t(\"../../components/fx/helpers\").appendArrayPointValue,d=t(\"../pie/plot\").transformInsideText,g=t(\"../pie/helpers\").formatPieValue,v=t(\"./style\").styleOne,m=t(\"./constants\");function y(t,e,r,a){var o=t._fullLayout,u=a&&a.duration>0,f=n.select(r).selectAll(\"g.slice\"),p=e[0],m=p.trace,y=x(p.hierarchy,m.level),w=m.maxdepth>=0?m.maxdepth:1/0,M=o._size,S=m.domain,E=M.w*(S.x[1]-S.x[0]),C=M.h*(S.y[1]-S.y[0]),L=.5*Math.min(E,C),P=p.cx=M.l+M.w*(S.x[1]+S.x[0])/2,O=p.cy=M.t+M.h*(1-S.y[0])-C/2;if(!y)return f.remove();var z=null,I={};u&&f.each(function(t){I[k(t)]={rpx0:t.rpx0,rpx1:t.rpx1,x0:t.x0,x1:t.x1,transform:t.transform},!z&&_(t)&&(z=t)});var D=function(t){return i.partition().size([2*Math.PI,t.height+1])(t)}(y).descendants(),R=y.height+1,F=0,B=w;p.hasMultipleRoots&&b(y)&&(D=D.slice(1),R-=1,F=1,B+=1),D=D.filter(function(t){return t.y1<=B});var N=Math.min(R,w),j=function(t){return(t-F)/N*L},U=function(t,e){return[t*Math.cos(e),-t*Math.sin(e)]},V=function(t){return c.pathAnnulus(t.rpx0,t.rpx1,t.x0,t.x1,P,O)},q=function(t){return P+t.pxmid[0]*t.transform.rCenter+(t.transform.x||0)},H=function(t){return O+t.pxmid[1]*t.transform.rCenter+(t.transform.y||0)};(f=f.data(D,function(t){return k(t)})).enter().append(\"g\").classed(\"slice\",!0),u?f.exit().transition().each(function(){var t=n.select(this);t.select(\"path.surface\").transition().attrTween(\"d\",function(t){var e=function(t){var e,r=k(t),i=I[r],a=I[k(y)];if(a){var o=t.x1>a.x1?2*Math.PI:0;e=t.rpx1<a.rpx1?{rpx0:0,rpx1:0}:{x0:o,x1:o}}else{var s,l=k(t.parent);f.each(function(t){if(k(t)===l)return s=t});var c,u=s.children;u.forEach(function(t,e){if(k(t)===r)return c=e});var h=u.length,p=n.interpolate(s.x0,s.x1);e={rpx0:L,rpx1:L,x0:p(c/h),x1:p((c+1)/h)}}return n.interpolate(i,e)}(t);return function(t){return V(e(t))}}),t.select(\"g.slicetext\").attr(\"opacity\",0)}).remove():f.exit().remove(),f.order();var G=null;if(u&&z){var Y=k(z);f.each(function(t){null===G&&k(t)===Y&&(G=t.x1)})}var W=f;function X(t){var e=t.parent,r=I[k(e)],i={};if(r){var a=e.children,o=a.indexOf(t),s=a.length,l=n.interpolate(r.x0,r.x1);i.x0=l(o/s),i.x1=l(o/s)}else i.x0=i.x1=0;return i}u&&(W=W.transition().each(\"end\",function(){T(n.select(this),t,{isTransitioning:!1})})),W.each(function(r){var i=n.select(this),a=c.ensureSingle(i,\"path\",\"surface\",function(t){t.style(\"pointer-events\",\"all\")});r.rpx0=j(r.y0),r.rpx1=j(r.y1),r.xmid=(r.x0+r.x1)/2,r.pxmid=U(r.rpx1,r.xmid),r.midangle=-(r.xmid-Math.PI/2),r.halfangle=.5*Math.min(c.angleDelta(r.x0,r.x1)||Math.PI,Math.PI),r.ring=1-r.rpx0/r.rpx1,r.rInscribed=function(t){return 0===t.rpx0&&c.isFullCircle([t.x0,t.x1])?1:Math.max(0,Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2))}(r),u?a.transition().attrTween(\"d\",function(t){var e=function(t){var e,r=I[k(t)],i={x0:t.x0,x1:t.x1,rpx0:t.rpx0,rpx1:t.rpx1};if(r)e=r;else if(z)if(t.parent)if(G){var a=t.x1>G?2*Math.PI:0;e={x0:a,x1:a}}else e={rpx0:L,rpx1:L},c.extendFlat(e,X(t));else e={rpx0:0,rpx1:0};else e={x0:0,x1:0};return n.interpolate(e,i)}(t);return function(t){return V(e(t))}}):a.attr(\"d\",V),i.call(A,t,e).call(T,t,{isTransitioning:t._transitioning}),a.call(v,r,m);var f=c.ensureSingle(i,\"g\",\"slicetext\"),y=c.ensureSingle(f,\"text\",\"\",function(t){t.attr(\"data-notex\",1)});y.text(function(t,e,r){var n=e.textinfo;if(!n||\"none\"===n)return\"\";var i=t.data.data,a=r.separators,o=n.split(\"+\"),s=function(t){return-1!==o.indexOf(t)},l=[];s(\"label\")&&i.label&&l.push(i.label);i.hasOwnProperty(\"v\")&&s(\"value\")&&l.push(g(i.v,a));if(s(\"text\")){var u=c.castOption(e,i.i,\"text\");c.isValidTextValue(u)&&l.push(u)}return l.join(\"<br>\")}(r,m,o)).classed(\"slicetext\",!0).attr(\"text-anchor\",\"middle\").call(l.font,b(r)?function(t,e,r){var n=e.data.data.i,i=c.castOption(t,n,\"outsidetextfont.color\")||c.castOption(t,n,\"textfont.color\")||r.color,a=c.castOption(t,n,\"outsidetextfont.family\")||c.castOption(t,n,\"textfont.family\")||r.family,o=c.castOption(t,n,\"outsidetextfont.size\")||c.castOption(t,n,\"textfont.size\")||r.size;return{color:i,family:a,size:o}}(m,r,o.font):function(t,e,r){var n=e.data.data,i=n.i,a=c.castOption(t,i,\"insidetextfont.color\");!a&&t._input.textfont&&(a=c.castOption(t._input,i,\"textfont.color\"));var o=c.castOption(t,i,\"insidetextfont.family\")||c.castOption(t,i,\"textfont.family\")||r.family,l=c.castOption(t,i,\"insidetextfont.size\")||c.castOption(t,i,\"textfont.size\")||r.size;return{color:a||s.contrast(n.color),family:o,size:l}}(m,r,o.font)).call(h.convertToTspans,t);var x=l.bBox(y.node());r.transform=d(x,r,p),r.translateX=q(r),r.translateY=H(r);var _=function(t,e){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"+(t.transform.scale<1?\"scale(\"+t.transform.scale+\")\":\"\")+(t.transform.rotate?\"rotate(\"+t.transform.rotate+\")\":\"\")+\"translate(\"+-(e.left+e.right)/2+\",\"+-(e.top+e.bottom)/2+\")\"};u?y.transition().attrTween(\"transform\",function(t){var e=function(t){var e,r=I[k(t)],i=t.transform;if(r)e=r;else if(e={rpx1:t.rpx1,transform:{scale:0,rotate:i.rotate,rCenter:i.rCenter,x:i.x,y:i.y}},z)if(t.parent)if(G){var a=t.x1>G?2*Math.PI:0;e.x0=e.x1=a}else c.extendFlat(e,X(t));else e.x0=e.x1=0;else e.x0=e.x1=0;var o=n.interpolate(e.rpx1,t.rpx1),s=n.interpolate(e.x0,t.x0),l=n.interpolate(e.x1,t.x1),u=n.interpolate(e.transform.scale,i.scale),h=n.interpolate(e.transform.rotate,i.rotate),f=0===i.rCenter?3:0===e.transform.rCenter?1/3:1,p=n.interpolate(e.transform.rCenter,i.rCenter);return function(t){var e=o(t),r=s(t),n=l(t),a=function(t){return p(Math.pow(t,f))}(t),c={pxmid:U(e,(r+n)/2),transform:{rCenter:a,x:i.x,y:i.y}},d={rpx1:o(t),translateX:q(c),translateY:H(c),transform:{scale:u(t),rotate:h(t),rCenter:a}};return d}}(t);return function(t){return _(e(t),x)}}):y.attr(\"transform\",_(r,x))})}function x(t,e){var r;return e&&t.eachAfter(function(t){if(k(t)===e)return r=t.copy()}),r||t}function b(t){return\"\"===t.data.data.pid}function _(t){return!t.parent}function w(t){return!t.children}function k(t){return t.data.data.id}function T(t,e,r){var n=t.datum(),i=(r||{}).isTransitioning;f(t,i||w(n)||b(n)?null:\"pointer\")}function A(t,e,r){var i=r[0],s=i.trace;\"_hasHoverLabel\"in s||(s._hasHoverLabel=!1),\"_hasHoverEvent\"in s||(s._hasHoverEvent=!1),t.on(\"mouseover\",function(t){var r=e._fullLayout;if(!e._dragging&&!1!==r.hovermode){var a=e._fullData[s.index],l=t.data.data,u=l.i,h=function(t){return c.castOption(a,u,t)},f=h(\"hovertemplate\"),p=o.castHoverinfo(a,r,u),d=r.separators;if(f||p&&\"none\"!==p&&\"skip\"!==p){var v=t.rInscribed,m=i.cx+t.pxmid[0]*(1-v),y=i.cy+t.pxmid[1]*(1-v),x={},b=[],_=[],w=function(t){return-1!==b.indexOf(t)};if(p&&(b=\"all\"===p?a._module.attributes.hoverinfo.flags:p.split(\"+\")),x.label=l.label,w(\"label\")&&x.label&&_.push(x.label),l.hasOwnProperty(\"v\")&&(x.value=l.v,x.valueLabel=g(x.value,d),w(\"value\")&&_.push(x.valueLabel)),x.text=h(\"hovertext\")||h(\"text\"),w(\"text\")){var k=x.text;c.isValidTextValue(k)&&_.push(k)}o.loneHover({trace:a,x0:m-v*t.rpx1,x1:m+v*t.rpx1,y:y,idealAlign:t.pxmid[0]<0?\"left\":\"right\",text:_.join(\"<br>\"),name:f||w(\"name\")?a.name:void 0,color:h(\"hoverlabel.bgcolor\")||l.color,borderColor:h(\"hoverlabel.bordercolor\"),fontFamily:h(\"hoverlabel.font.family\"),fontSize:h(\"hoverlabel.font.size\"),fontColor:h(\"hoverlabel.font.color\"),nameLength:h(\"hoverlabel.namelength\"),textAlign:h(\"hoverlabel.align\"),hovertemplate:f,hovertemplateLabels:x,eventData:[M(t,a)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e}),s._hasHoverLabel=!0}s._hasHoverEvent=!0,e.emit(\"plotly_hover\",{points:[M(t,a)],event:n.event})}}),t.on(\"mouseout\",function(t){var r=e._fullLayout,i=e._fullData[s.index],a=n.select(this).datum();s._hasHoverEvent&&(t.originalEvent=n.event,e.emit(\"plotly_unhover\",{points:[M(a,i)],event:n.event}),s._hasHoverEvent=!1),s._hasHoverLabel&&(o.loneUnhover(r._hoverlayer.node()),s._hasHoverLabel=!1)}),t.on(\"click\",function(t){var r=e._fullLayout,l=e._fullData[s.index];if(!1===u.triggerHandler(e,\"plotly_sunburstclick\",{points:[M(t,l)],event:n.event})||w(t)||b(t))r.hovermode&&(e._hoverdata=[M(t,l)],o.click(e,n.event));else if(!e._dragging&&!e._transitioning){a.call(\"_storeDirectGUIEdit\",l,r._tracePreGUI[l.uid],{level:l.level});var c=i.hierarchy,h=k(t),f=_(t)?function(t,e){var r;return t.eachAfter(function(t){for(var n=t.children||[],i=0;i<n.length;i++)if(k(n[i])===e)return r=t.copy()}),r||t}(c,h):x(c,h),p={data:[{level:k(f)}],traces:[s.index]},d={frame:{redraw:!1,duration:m.CLICK_TRANSITION_TIME},transition:{duration:m.CLICK_TRANSITION_TIME,easing:m.CLICK_TRANSITION_EASING},mode:\"immediate\",fromcurrent:!0};o.loneUnhover(r._hoverlayer.node()),a.call(\"animate\",e,p,d)}})}function M(t,e){var r=t.data.data,n={curveNumber:e.index,pointNumber:r.i,data:e._input,fullData:e};return p(n,e,r.i),n}e.exports=function(t,e,r,i){var a,o,s=t._fullLayout._sunburstlayer,l=!r,c=r&&r.duration>0;((a=s.selectAll(\"g.trace.sunburst\").data(e,function(t){return t[0].trace.uid})).enter().append(\"g\").classed(\"trace\",!0).classed(\"sunburst\",!0).attr(\"stroke-linejoin\",\"round\"),a.order(),c)?(i&&(o=i()),n.transition().duration(r.duration).ease(r.easing).each(\"end\",function(){o&&o()}).each(\"interrupt\",function(){o&&o()}).each(function(){s.selectAll(\"g.trace\").each(function(e){y(t,e,this,r)})})):a.each(function(e){y(t,e,this,r)});l&&a.exit().remove()}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../components/fx/helpers\":628,\"../../lib\":719,\"../../lib/events\":709,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../registry\":847,\"../pie/helpers\":1091,\"../pie/plot\":1095,\"./constants\":1217,\"./style\":1223,d3:163,\"d3-hierarchy\":157}],1223:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../lib\");function o(t,e,r){var n=e.data.data,o=!e.children,s=n.i,l=a.castOption(r,s,\"marker.line.color\")||i.defaultLine,c=a.castOption(r,s,\"marker.line.width\")||0;t.style(\"stroke-width\",c).call(i.fill,n.color).call(i.stroke,l).style(\"opacity\",o?r.leaf.opacity:null)}e.exports={style:function(t){t._fullLayout._sunburstlayer.selectAll(\".trace\").each(function(t){var e=n.select(this),r=t[0].trace;e.style(\"opacity\",r.opacity),e.selectAll(\"path.surface\").each(function(t){n.select(this).call(o,t,r)})})},styleOne:o}},{\"../../components/color\":593,\"../../lib\":719,d3:163}],1224:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;function c(t){return{show:{valType:\"boolean\",dflt:!1},start:{valType:\"number\",dflt:null,editType:\"plot\"},end:{valType:\"number\",dflt:null,editType:\"plot\"},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\"},project:{x:{valType:\"boolean\",dflt:!1},y:{valType:\"boolean\",dflt:!1},z:{valType:\"boolean\",dflt:!1}},color:{valType:\"color\",dflt:n.defaultLine},usecolormap:{valType:\"boolean\",dflt:!1},width:{valType:\"number\",min:1,max:16,dflt:2},highlight:{valType:\"boolean\",dflt:!0},highlightcolor:{valType:\"color\",dflt:n.defaultLine},highlightwidth:{valType:\"number\",min:1,max:16,dflt:2}}}var u=e.exports=l(s({z:{valType:\"data_array\"},x:{valType:\"data_array\"},y:{valType:\"data_array\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:a(),connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},surfacecolor:{valType:\"data_array\"}},i(\"\",{colorAttr:\"z or surfacecolor\",showScaleDflt:!0,autoColorDflt:!1,editTypeOverride:\"calc\"}),{contours:{x:c(),y:c(),z:c()},hidesurface:{valType:\"boolean\",dflt:!1},lightposition:{x:{valType:\"number\",min:-1e5,max:1e5,dflt:10},y:{valType:\"number\",min:-1e5,max:1e5,dflt:1e4},z:{valType:\"number\",min:-1e5,max:1e5,dflt:0}},lighting:{ambient:{valType:\"number\",min:0,max:1,dflt:.8},diffuse:{valType:\"number\",min:0,max:1,dflt:.8},specular:{valType:\"number\",min:0,max:2,dflt:.05},roughness:{valType:\"number\",min:0,max:1,dflt:.5},fresnel:{valType:\"number\",min:0,max:5,dflt:.2}},opacity:{valType:\"number\",min:0,max:1,dflt:1},_deprecated:{zauto:s({},i.zauto,{}),zmin:s({},i.zmin,{}),zmax:s({},i.zmax,{})},hoverinfo:s({},o.hoverinfo)}),\"calc\",\"nested\");u.x.editType=u.y.editType=u.z.editType=\"calc+clearAxisTypes\",u.transforms=void 0},{\"../../components/color\":593,\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764}],1225:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.surfacecolor?n(t,e,{vals:e.surfacecolor,containerStr:\"\",cLetter:\"c\"}):n(t,e,{vals:e.z,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],1226:[function(t,e,r){\"use strict\";var n=t(\"gl-surface3d\"),i=t(\"ndarray\"),a=t(\"ndarray-homography\"),o=t(\"ndarray-fill\"),s=t(\"../../lib\").isArrayOrTypedArray,l=t(\"../../lib/gl_format_color\").parseColorScale,c=t(\"../../lib/str2rgbarray\"),u=t(\"../../components/colorscale\").extractOpts,h=t(\"../heatmap/interp2d\"),f=t(\"../heatmap/find_empties\");function p(t,e,r){this.scene=t,this.uid=r,this.surface=e,this.data=null,this.showContour=[!1,!1,!1],this.contourStart=[null,null,null],this.contourEnd=[null,null,null],this.contourSize=[0,0,0],this.minValues=[1/0,1/0,1/0],this.maxValues=[-1/0,-1/0,-1/0],this.dataScaleX=1,this.dataScaleY=1,this.refineData=!0,this.objectOffset=[0,0,0]}var d=p.prototype;d.getXat=function(t,e,r,n){var i=s(this.data.x)?s(this.data.x[0])?this.data.x[e][t]:this.data.x[t]:t;return void 0===r?i:n.d2l(i,0,r)},d.getYat=function(t,e,r,n){var i=s(this.data.y)?s(this.data.y[0])?this.data.y[e][t]:this.data.y[e]:e;return void 0===r?i:n.d2l(i,0,r)},d.getZat=function(t,e,r,n){var i=this.data.z[e][t];return null===i&&this.data.connectgaps&&this.data._interpolatedZ&&(i=this.data._interpolatedZ[e][t]),void 0===r?i:n.d2l(i,0,r)},d.handlePick=function(t){if(t.object===this.surface){var e=(t.data.index[0]-1)/this.dataScaleX-1,r=(t.data.index[1]-1)/this.dataScaleY-1,n=Math.max(Math.min(Math.round(e),this.data.z[0].length-1),0),i=Math.max(Math.min(Math.round(r),this.data._ylength-1),0);t.index=[n,i],t.traceCoordinate=[this.getXat(n,i),this.getYat(n,i),this.getZat(n,i)],t.dataCoordinate=[this.getXat(n,i,this.data.xcalendar,this.scene.fullSceneLayout.xaxis),this.getYat(n,i,this.data.ycalendar,this.scene.fullSceneLayout.yaxis),this.getZat(n,i,this.data.zcalendar,this.scene.fullSceneLayout.zaxis)];for(var a=0;a<3;a++){var o=t.dataCoordinate[a];null!=o&&(t.dataCoordinate[a]*=this.scene.dataScale[a])}var s=this.data.hovertext||this.data.text;return Array.isArray(s)&&s[i]&&void 0!==s[i][n]?t.textLabel=s[i][n]:t.textLabel=s||\"\",t.data.dataCoordinate=t.dataCoordinate.slice(),this.surface.highlight(t.data),this.scene.glplot.spikes.position=t.dataCoordinate,!0}};var g=[2,3,5,7,11,13,17,19,23,29,31,37,41,43,47,53,59,61,67,71,73,79,83,89,97,101,103,107,109,113,127,131,137,139,149,151,157,163,167,173,179,181,191,193,197,199,211,223,227,229,233,239,241,251,257,263,269,271,277,281,283,293,307,311,313,317,331,337,347,349,353,359,367,373,379,383,389,397,401,409,419,421,431,433,439,443,449,457,461,463,467,479,487,491,499,503,509,521,523,541,547,557,563,569,571,577,587,593,599,601,607,613,617,619,631,641,643,647,653,659,661,673,677,683,691,701,709,719,727,733,739,743,751,757,761,769,773,787,797,809,811,821,823,827,829,839,853,857,859,863,877,881,883,887,907,911,919,929,937,941,947,953,967,971,977,983,991,997,1009,1013,1019,1021,1031,1033,1039,1049,1051,1061,1063,1069,1087,1091,1093,1097,1103,1109,1117,1123,1129,1151,1153,1163,1171,1181,1187,1193,1201,1213,1217,1223,1229,1231,1237,1249,1259,1277,1279,1283,1289,1291,1297,1301,1303,1307,1319,1321,1327,1361,1367,1373,1381,1399,1409,1423,1427,1429,1433,1439,1447,1451,1453,1459,1471,1481,1483,1487,1489,1493,1499,1511,1523,1531,1543,1549,1553,1559,1567,1571,1579,1583,1597,1601,1607,1609,1613,1619,1621,1627,1637,1657,1663,1667,1669,1693,1697,1699,1709,1721,1723,1733,1741,1747,1753,1759,1777,1783,1787,1789,1801,1811,1823,1831,1847,1861,1867,1871,1873,1877,1879,1889,1901,1907,1913,1931,1933,1949,1951,1973,1979,1987,1993,1997,1999,2003,2011,2017,2027,2029,2039,2053,2063,2069,2081,2083,2087,2089,2099,2111,2113,2129,2131,2137,2141,2143,2153,2161,2179,2203,2207,2213,2221,2237,2239,2243,2251,2267,2269,2273,2281,2287,2293,2297,2309,2311,2333,2339,2341,2347,2351,2357,2371,2377,2381,2383,2389,2393,2399,2411,2417,2423,2437,2441,2447,2459,2467,2473,2477,2503,2521,2531,2539,2543,2549,2551,2557,2579,2591,2593,2609,2617,2621,2633,2647,2657,2659,2663,2671,2677,2683,2687,2689,2693,2699,2707,2711,2713,2719,2729,2731,2741,2749,2753,2767,2777,2789,2791,2797,2801,2803,2819,2833,2837,2843,2851,2857,2861,2879,2887,2897,2903,2909,2917,2927,2939,2953,2957,2963,2969,2971,2999];function v(t,e){if(t<e)return 0;for(var r=0;0===Math.floor(t%e);)t/=e,r++;return r}function m(t){for(var e=[],r=0;r<g.length;r++){var n=g[r];e.push(v(t,n))}return e}function y(t){for(var e=m(t),r=t,n=0;n<g.length;n++)if(e[n]>0){r=g[n];break}return r}function x(t,e){if(!(t<1||e<1)){for(var r=m(t),n=m(e),i=1,a=0;a<g.length;a++)i*=Math.pow(g[a],Math.max(r[a],n[a]));return i}}d.calcXnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getXat(e-1,0),i=this.getXat(e,0);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r},d.calcYnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getYat(0,e-1),i=this.getYat(0,e);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r};var b=[1,2,4,6,12,24,36,48,60,120,180,240,360,720,840,1260],_=b[9],w=b[13];function k(t,e){for(var r=!1,n=0;n<t.length;n++)if(e===t[n]){r=!0;break}!1===r&&t.push(e)}d.estimateScale=function(t,e){for(var r=1+function(t){if(0!==t.length){for(var e=1,r=0;r<t.length;r++)e=x(e,t[r]);return e}}(0===e?this.calcXnums(t):this.calcYnums(t));r<_;)r*=2;for(;r>w;)r--,r/=y(r),++r<_&&(r=w);var n=Math.round(r/t);return n>1?n:1},d.refineCoords=function(t){for(var e=this.dataScaleX,r=this.dataScaleY,n=t[0].shape[0],o=t[0].shape[1],s=0|Math.floor(t[0].shape[0]*e+1),l=0|Math.floor(t[0].shape[1]*r+1),c=1+n+1,u=1+o+1,h=i(new Float32Array(c*u),[c,u]),f=0;f<t.length;++f){this.surface.padField(h,t[f]);var p=i(new Float32Array(s*l),[s,l]);a(p,h,[e,0,0,0,r,0,0,0,1]),t[f]=p}},d.setContourLevels=function(){var t,e,r,n=[[],[],[]],i=[!1,!1,!1],a=!1;for(t=0;t<3;++t)if(this.showContour[t]&&(a=!0,this.contourSize[t]>0&&null!==this.contourStart[t]&&null!==this.contourEnd[t]&&this.contourEnd[t]>this.contourStart[t]))for(i[t]=!0,e=this.contourStart[t];e<this.contourEnd[t];e+=this.contourSize[t])r=e*this.scene.dataScale[t],k(n[t],r);if(a){var o=[[],[],[]];for(t=0;t<3;++t)this.showContour[t]&&(o[t]=i[t]?n[t]:this.scene.contourLevels[t]);this.surface.update({levels:o})}},d.update=function(t){var e,r,n,a,s=this.scene,p=s.fullSceneLayout,d=this.surface,g=t.opacity,v=l(t,g),m=s.dataScale,y=t.z[0].length,x=t._ylength,b=s.contourLevels;this.data=t;var _=[];for(e=0;e<3;e++)for(_[e]=[],r=0;r<y;r++)_[e][r]=[];for(r=0;r<y;r++)for(n=0;n<x;n++)_[0][r][n]=this.getXat(r,n,t.xcalendar,p.xaxis),_[1][r][n]=this.getYat(r,n,t.ycalendar,p.yaxis),_[2][r][n]=this.getZat(r,n,t.zcalendar,p.zaxis);if(t.connectgaps)for(t._emptypoints=f(_[2]),h(_[2],t._emptypoints),t._interpolatedZ=[],r=0;r<y;r++)for(t._interpolatedZ[r]=[],n=0;n<x;n++)t._interpolatedZ[r][n]=_[2][r][n];for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null==(a=_[e][r][n])?_[e][r][n]=NaN:a=_[e][r][n]*=m[e];for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null!=(a=_[e][r][n])&&(this.minValues[e]>a&&(this.minValues[e]=a),this.maxValues[e]<a&&(this.maxValues[e]=a));for(e=0;e<3;e++)this.objectOffset[e]=.5*(this.minValues[e]+this.maxValues[e]);for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null!=(a=_[e][r][n])&&(_[e][r][n]-=this.objectOffset[e]);var k=[i(new Float32Array(y*x),[y,x]),i(new Float32Array(y*x),[y,x]),i(new Float32Array(y*x),[y,x])];o(k[0],function(t,e){return _[0][t][e]}),o(k[1],function(t,e){return _[1][t][e]}),o(k[2],function(t,e){return _[2][t][e]}),_=[];var T={colormap:v,levels:[[],[],[]],showContour:[!0,!0,!0],showSurface:!t.hidesurface,contourProject:[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],contourWidth:[1,1,1],contourColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],contourTint:[1,1,1],dynamicColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],dynamicWidth:[1,1,1],dynamicTint:[1,1,1],opacity:t.opacity},A=u(t);if(T.intensityBounds=[A.min,A.max],t.surfacecolor){var M=i(new Float32Array(y*x),[y,x]);o(M,function(e,r){return t.surfacecolor[r][e]}),k.push(M)}else T.intensityBounds[0]*=m[2],T.intensityBounds[1]*=m[2];(w<k[0].shape[0]||w<k[0].shape[1])&&(this.refineData=!1),!0===this.refineData&&(this.dataScaleX=this.estimateScale(k[0].shape[0],0),this.dataScaleY=this.estimateScale(k[0].shape[1],1),1===this.dataScaleX&&1===this.dataScaleY||this.refineCoords(k)),t.surfacecolor&&(T.intensity=k.pop());var S=[!0,!0,!0],E=[\"x\",\"y\",\"z\"];for(e=0;e<3;++e){var C=t.contours[E[e]];S[e]=C.highlight,T.showContour[e]=C.show||C.highlight,T.showContour[e]&&(T.contourProject[e]=[C.project.x,C.project.y,C.project.z],C.show?(this.showContour[e]=!0,T.levels[e]=b[e],d.highlightColor[e]=T.contourColor[e]=c(C.color),C.usecolormap?d.highlightTint[e]=T.contourTint[e]=0:d.highlightTint[e]=T.contourTint[e]=1,T.contourWidth[e]=C.width,this.contourStart[e]=C.start,this.contourEnd[e]=C.end,this.contourSize[e]=C.size):(this.showContour[e]=!1,this.contourStart[e]=null,this.contourEnd[e]=null,this.contourSize[e]=0),C.highlight&&(T.dynamicColor[e]=c(C.highlightcolor),T.dynamicWidth[e]=C.highlightwidth))}(function(t){var e=t[0].rgb,r=t[t.length-1].rgb;return e[0]===r[0]&&e[1]===r[1]&&e[2]===r[2]&&e[3]===r[3]})(v)&&(T.vertexColor=!0),T.objectOffset=this.objectOffset,T.coords=k,d.update(T),d.visible=t.visible,d.enableDynamic=S,d.enableHighlight=S,d.snapToData=!0,\"lighting\"in t&&(d.ambientLight=t.lighting.ambient,d.diffuseLight=t.lighting.diffuse,d.specularLight=t.lighting.specular,d.roughness=t.lighting.roughness,d.fresnel=t.lighting.fresnel),\"lightposition\"in t&&(d.lightPosition=[t.lightposition.x,t.lightposition.y,t.lightposition.z]),g&&g<1&&(d.supportsTransparency=!0)},d.dispose=function(){this.scene.glplot.remove(this.surface),this.surface.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new p(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../heatmap/find_empties\":1007,\"../heatmap/interp2d\":1010,\"gl-surface3d\":316,ndarray:450,\"ndarray-fill\":440,\"ndarray-homography\":442}],1227:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");function s(t,e,r){e in t&&!(r in t)&&(t[r]=t[e])}e.exports=function(t,e,r,l){var c,u;function h(r,n){return i.coerce(t,e,o,r,n)}var f=h(\"x\"),p=h(\"y\"),d=h(\"z\");if(!d||!d.length||f&&f.length<1||p&&p.length<1)e.visible=!1;else{e._xlength=Array.isArray(f)&&i.isArrayOrTypedArray(f[0])?d.length:d[0].length,e._ylength=d.length,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],l),h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"hidesurface\",\"connectgaps\",\"opacity\"].forEach(function(t){h(t)});var g=h(\"surfacecolor\"),v=[\"x\",\"y\",\"z\"];for(c=0;c<3;++c){var m=\"contours.\"+v[c],y=h(m+\".show\"),x=h(m+\".highlight\");if(y||x)for(u=0;u<3;++u)h(m+\".project.\"+v[u]);y&&(h(m+\".color\"),h(m+\".width\"),h(m+\".usecolormap\")),x&&(h(m+\".highlightcolor\"),h(m+\".highlightwidth\")),h(m+\".start\"),h(m+\".end\"),h(m+\".size\")}g||(s(t,\"zmin\",\"cmin\"),s(t,\"zmax\",\"cmax\"),s(t,\"zauto\",\"cauto\")),a(t,e,l,h,{prefix:\"\",cLetter:\"c\"}),e._length=null}}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../../registry\":847,\"./attributes\":1224}],1228:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"surface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"2dMap\",\"noOpacity\"],meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1224,\"./calc\":1225,\"./convert\":1226,\"./defaults\":1227}],1229:[function(t,e,r){\"use strict\";var n=t(\"../../components/annotations/attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../plots/domain\").attributes;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=a({domain:s({name:\"table\",trace:!0}),columnwidth:{valType:\"number\",arrayOk:!0,dflt:null},columnorder:{valType:\"data_array\"},header:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:28},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))},cells:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:20},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))}},\"calc\",\"from-root\")).transforms=void 0},{\"../../components/annotations/attributes\":576,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1230:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"table\",r.plot=function(t){var e=n(t.calcdata,\"table\")[0];e.length&&i(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"table\"),a=e._has&&e._has(\"table\");i&&!a&&n._paperdiv.selectAll(\".table\").remove()}},{\"../../plots/get_data\":802,\"./plot\":1237}],1231:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap;e.exports=function(){return n({})}},{\"../../lib/gup\":717}],1232:[function(t,e,r){\"use strict\";e.exports={cellPad:8,columnExtentOffset:10,columnTitleOffset:28,emptyHeaderHeight:16,latexCheck:/^\\$.*\\$$/,goldenRatio:1.618,lineBreaker:\"<br>\",maxDimensionCount:60,overdrag:45,releaseTransitionDuration:120,releaseTransitionEase:\"cubic-out\",scrollbarCaptureWidth:18,scrollbarHideDelay:1e3,scrollbarHideDuration:1e3,scrollbarOffset:5,scrollbarWidth:8,transitionDuration:100,transitionEase:\"cubic-out\",uplift:5,wrapSpacer:\" \",wrapSplitCharacter:\" \",cn:{table:\"table\",tableControlView:\"table-control-view\",scrollBackground:\"scroll-background\",yColumn:\"y-column\",columnBlock:\"column-block\",scrollAreaClip:\"scroll-area-clip\",scrollAreaClipRect:\"scroll-area-clip-rect\",columnBoundary:\"column-boundary\",columnBoundaryClippath:\"column-boundary-clippath\",columnBoundaryRect:\"column-boundary-rect\",columnCells:\"column-cells\",columnCell:\"column-cell\",cellRect:\"cell-rect\",cellText:\"cell-text\",cellTextHolder:\"cell-text-holder\",scrollbarKit:\"scrollbar-kit\",scrollbar:\"scrollbar\",scrollbarSlider:\"scrollbar-slider\",scrollbarGlyph:\"scrollbar-glyph\",scrollbarCaptureZone:\"scrollbar-capture-zone\"}}},{}],1233:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"fast-isnumeric\");function o(t){if(Array.isArray(t)){for(var e=0,r=0;r<t.length;r++)e=Math.max(e,o(t[r]));return e}return t}function s(t,e){return t+e}function l(t){var e,r=t.slice(),n=1/0,i=0;for(e=0;e<r.length;e++)Array.isArray(r[e])||(r[e]=[r[e]]),n=Math.min(n,r[e].length),i=Math.max(i,r[e].length);if(n!==i)for(e=0;e<r.length;e++){var a=i-r[e].length;a&&(r[e]=r[e].concat(c(a)))}return r}function c(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=\"\";return e}function u(t){return t.calcdata.columns.reduce(function(e,r){return r.xIndex<t.xIndex?e+r.columnWidth:e},0)}function h(t,e){return Object.keys(t).map(function(r){return i({},t[r],{auxiliaryBlocks:e})})}function f(t,e){for(var r,n={},i=0,a=0,o={firstRowIndex:null,lastRowIndex:null,rows:[]},s=0,l=0,c=0;c<t.length;c++)r=t[c],o.rows.push({rowIndex:c,rowHeight:r}),((a+=r)>=e||c===t.length-1)&&(n[i]=o,o.key=l++,o.firstRowIndex=s,o.lastRowIndex=c,o={firstRowIndex:null,lastRowIndex:null,rows:[]},i+=a,s=c+1,a=0);return n}e.exports=function(t,e){var r=l(e.cells.values),p=function(t){return t.slice(e.header.values.length,t.length)},d=l(e.header.values);d.length&&!d[0].length&&(d[0]=[\"\"],d=l(d));var g=d.concat(p(r).map(function(){return c((d[0]||[\"\"]).length)})),v=e.domain,m=Math.floor(t._fullLayout._size.w*(v.x[1]-v.x[0])),y=Math.floor(t._fullLayout._size.h*(v.y[1]-v.y[0])),x=e.header.values.length?g[0].map(function(){return e.header.height}):[n.emptyHeaderHeight],b=r.length?r[0].map(function(){return e.cells.height}):[],_=x.reduce(s,0),w=f(b,y-_+n.uplift),k=h(f(x,_),[]),T=h(w,k),A={},M=e._fullInput.columnorder.concat(p(r.map(function(t,e){return e}))),S=g.map(function(t,r){var n=Array.isArray(e.columnwidth)?e.columnwidth[Math.min(r,e.columnwidth.length-1)]:e.columnwidth;return a(n)?Number(n):1}),E=S.reduce(s,0);S=S.map(function(t){return t/E*m});var C=Math.max(o(e.header.line.width),o(e.cells.line.width)),L={key:e.uid+t._context.staticPlot,translateX:v.x[0]*t._fullLayout._size.w,translateY:t._fullLayout._size.h*(1-v.y[1]),size:t._fullLayout._size,width:m,maxLineWidth:C,height:y,columnOrder:M,groupHeight:y,rowBlocks:T,headerRowBlocks:k,scrollY:0,cells:i({},e.cells,{values:r}),headerCells:i({},e.header,{values:g}),gdColumns:g.map(function(t){return t[0]}),gdColumnsOriginalOrder:g.map(function(t){return t[0]}),prevPages:[0,0],scrollbarState:{scrollbarScrollInProgress:!1},columns:g.map(function(t,e){var r=A[t];return A[t]=(r||0)+1,{key:t+\"__\"+A[t],label:t,specIndex:e,xIndex:M[e],xScale:u,x:void 0,calcdata:void 0,columnWidth:S[e]}})};return L.columns.forEach(function(t){t.calcdata=L,t.x=u(t)}),L}},{\"../../lib/extend\":710,\"./constants\":1232,\"fast-isnumeric\":225}],1234:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat;r.splitToPanels=function(t){var e=[0,0],r=n({},t,{key:\"header\",type:\"header\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!0,values:t.calcdata.headerCells.values[t.specIndex],rowBlocks:t.calcdata.headerRowBlocks,calcdata:n({},t.calcdata,{cells:t.calcdata.headerCells})});return[n({},t,{key:\"cells1\",type:\"cells\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),n({},t,{key:\"cells2\",type:\"cells\",page:1,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),r]},r.splitToCells=function(t){var e=function(t){var e=t.rowBlocks[t.page],r=e?e.rows[0].rowIndex:0,n=e?r+e.rows.length:0;return[r,n]}(t);return(t.values||[]).slice(e[0],e[1]).map(function(r,n){return{keyWithinBlock:n+(\"string\"==typeof r&&r.match(/[<$&> ]/)?\"_keybuster_\"+Math.random():\"\"),key:e[0]+n,column:t,calcdata:t.calcdata,page:t.page,rowBlocks:t.rowBlocks,value:r}})}},{\"../../lib/extend\":710}],1235:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults;e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}a(e,o,s),s(\"columnwidth\"),s(\"header.values\"),s(\"header.format\"),s(\"header.align\"),s(\"header.prefix\"),s(\"header.suffix\"),s(\"header.height\"),s(\"header.line.width\"),s(\"header.line.color\"),s(\"header.fill.color\"),n.coerceFont(s,\"header.font\",n.extendFlat({},o.font)),function(t,e){for(var r=t.columnorder||[],n=t.header.values.length,i=r.slice(0,n),a=i.slice().sort(function(t,e){return t-e}),o=i.map(function(t){return a.indexOf(t)}),s=o.length;s<n;s++)o.push(s);e(\"columnorder\",o)}(e,s),s(\"cells.values\"),s(\"cells.format\"),s(\"cells.align\"),s(\"cells.prefix\"),s(\"cells.suffix\"),s(\"cells.height\"),s(\"cells.line.width\"),s(\"cells.line.color\"),s(\"cells.fill.color\"),n.coerceFont(s,\"cells.font\",n.extendFlat({},o.font)),e._length=null}},{\"../../lib\":719,\"../../plots/domain\":792,\"./attributes\":1229}],1236:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"table\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1229,\"./base_plot\":1230,\"./calc\":1231,\"./defaults\":1235,\"./plot\":1237}],1237:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\"),o=t(\"../../components/drawing\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../lib\").raiseToTop,c=t(\"../../lib\").cancelTransition,u=t(\"./data_preparation_helper\"),h=t(\"./data_split_helpers\"),f=t(\"../../components/color\");function p(t){return Math.ceil(t.calcdata.maxLineWidth/2)}function d(t,e){return\"clip\"+t._fullLayout._uid+\"_scrollAreaBottomClip_\"+e.key}function g(t,e){return\"clip\"+t._fullLayout._uid+\"_columnBoundaryClippath_\"+e.calcdata.key+\"_\"+e.specIndex}function v(t){return[].concat.apply([],t.map(function(t){return t})).map(function(t){return t.__data__})}function m(t,e,r){var o=t.selectAll(\".\"+n.cn.scrollbarKit).data(a.repeat,a.keyFun);o.enter().append(\"g\").classed(n.cn.scrollbarKit,!0).style(\"shape-rendering\",\"geometricPrecision\"),o.each(function(t){var e=t.scrollbarState;e.totalHeight=function(t){var e=t.rowBlocks;return z(e,e.length-1)+(e.length?I(e[e.length-1],1/0):1)}(t),e.scrollableAreaHeight=t.groupHeight-A(t),e.currentlyVisibleHeight=Math.min(e.totalHeight,e.scrollableAreaHeight),e.ratio=e.currentlyVisibleHeight/e.totalHeight,e.barLength=Math.max(e.ratio*e.currentlyVisibleHeight,n.goldenRatio*n.scrollbarWidth),e.barWiggleRoom=e.currentlyVisibleHeight-e.barLength,e.wiggleRoom=Math.max(0,e.totalHeight-e.scrollableAreaHeight),e.topY=0===e.barWiggleRoom?0:t.scrollY/e.wiggleRoom*e.barWiggleRoom,e.bottomY=e.topY+e.barLength,e.dragMultiplier=e.wiggleRoom/e.barWiggleRoom}).attr(\"transform\",function(t){return\"translate(\"+(t.width+n.scrollbarWidth/2+n.scrollbarOffset)+\" \"+A(t)+\")\"});var s=o.selectAll(\".\"+n.cn.scrollbar).data(a.repeat,a.keyFun);s.enter().append(\"g\").classed(n.cn.scrollbar,!0);var l=s.selectAll(\".\"+n.cn.scrollbarSlider).data(a.repeat,a.keyFun);l.enter().append(\"g\").classed(n.cn.scrollbarSlider,!0),l.attr(\"transform\",function(t){return\"translate(0 \"+(t.scrollbarState.topY||0)+\")\"});var c=l.selectAll(\".\"+n.cn.scrollbarGlyph).data(a.repeat,a.keyFun);c.enter().append(\"line\").classed(n.cn.scrollbarGlyph,!0).attr(\"stroke\",\"black\").attr(\"stroke-width\",n.scrollbarWidth).attr(\"stroke-linecap\",\"round\").attr(\"y1\",n.scrollbarWidth/2),c.attr(\"y2\",function(t){return t.scrollbarState.barLength-n.scrollbarWidth/2}).attr(\"stroke-opacity\",function(t){return t.columnDragInProgress||!t.scrollbarState.barWiggleRoom||r?0:.4}),c.transition().delay(0).duration(0),c.transition().delay(n.scrollbarHideDelay).duration(n.scrollbarHideDuration).attr(\"stroke-opacity\",0);var u=s.selectAll(\".\"+n.cn.scrollbarCaptureZone).data(a.repeat,a.keyFun);u.enter().append(\"line\").classed(n.cn.scrollbarCaptureZone,!0).attr(\"stroke\",\"white\").attr(\"stroke-opacity\",.01).attr(\"stroke-width\",n.scrollbarCaptureWidth).attr(\"stroke-linecap\",\"butt\").attr(\"y1\",0).on(\"mousedown\",function(r){var n=i.event.y,a=this.getBoundingClientRect(),o=r.scrollbarState,s=n-a.top,l=i.scale.linear().domain([0,o.scrollableAreaHeight]).range([0,o.totalHeight]).clamp(!0);o.topY<=s&&s<=o.bottomY||S(e,t,null,l(s-o.barLength/2))(r)}).call(i.behavior.drag().origin(function(t){return i.event.stopPropagation(),t.scrollbarState.scrollbarScrollInProgress=!0,t}).on(\"drag\",S(e,t)).on(\"dragend\",function(){})),u.attr(\"y2\",function(t){return t.scrollbarState.scrollableAreaHeight}),e._context.staticPlot&&(c.remove(),u.remove())}function y(t,e,r,s){var l=function(t){var e=t.selectAll(\".\"+n.cn.columnCell).data(h.splitToCells,function(t){return t.keyWithinBlock});return e.enter().append(\"g\").classed(n.cn.columnCell,!0),e.exit().remove(),e}(function(t){var e=t.selectAll(\".\"+n.cn.columnCells).data(a.repeat,a.keyFun);return e.enter().append(\"g\").classed(n.cn.columnCells,!0),e.exit().remove(),e}(r));!function(t){t.each(function(t,e){var r=t.calcdata.cells.font,n=t.column.specIndex,i={size:_(r.size,n,e),color:_(r.color,n,e),family:_(r.family,n,e)};t.rowNumber=t.key,t.align=_(t.calcdata.cells.align,n,e),t.cellBorderWidth=_(t.calcdata.cells.line.width,n,e),t.font=i})}(l),function(t){t.attr(\"width\",function(t){return t.column.columnWidth}).attr(\"stroke-width\",function(t){return t.cellBorderWidth}).each(function(t){var e=i.select(this);f.stroke(e,_(t.calcdata.cells.line.color,t.column.specIndex,t.rowNumber)),f.fill(e,_(t.calcdata.cells.fill.color,t.column.specIndex,t.rowNumber))})}(function(t){var e=t.selectAll(\".\"+n.cn.cellRect).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"rect\").classed(n.cn.cellRect,!0),e}(l));var c=function(t){var e=t.selectAll(\".\"+n.cn.cellText).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"text\").classed(n.cn.cellText,!0).style(\"cursor\",function(){return\"auto\"}).on(\"mousedown\",function(){i.event.stopPropagation()}),e}(function(t){var e=t.selectAll(\".\"+n.cn.cellTextHolder).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"g\").classed(n.cn.cellTextHolder,!0).style(\"shape-rendering\",\"geometricPrecision\"),e}(l));!function(t){t.each(function(t){o.font(i.select(this),t.font)})}(c),x(c,e,s,t),O(l)}function x(t,e,r,a){t.text(function(t){var e=t.column.specIndex,r=t.rowNumber,a=t.value,o=\"string\"==typeof a,s=o&&a.match(/<br>/i),l=!o||s;t.mayHaveMarkup=o&&a.match(/[<&>]/);var c,u=\"string\"==typeof(c=a)&&c.match(n.latexCheck);t.latex=u;var h,f,p=u?\"\":_(t.calcdata.cells.prefix,e,r)||\"\",d=u?\"\":_(t.calcdata.cells.suffix,e,r)||\"\",g=u?null:_(t.calcdata.cells.format,e,r)||null,v=p+(g?i.format(g)(t.value):t.value)+d;if(t.wrappingNeeded=!t.wrapped&&!l&&!u&&(h=b(v)),t.cellHeightMayIncrease=s||u||t.mayHaveMarkup||(void 0===h?b(v):h),t.needsConvertToTspans=t.mayHaveMarkup||t.wrappingNeeded||t.latex,t.wrappingNeeded){var m=(\" \"===n.wrapSplitCharacter?v.replace(/<a href=/gi,\"<a_href=\"):v).split(n.wrapSplitCharacter),y=\" \"===n.wrapSplitCharacter?m.map(function(t){return t.replace(/<a_href=/gi,\"<a href=\")}):m;t.fragments=y.map(function(t){return{text:t,width:null}}),t.fragments.push({fragment:n.wrapSpacer,width:null}),f=y.join(n.lineBreaker)+n.lineBreaker+n.wrapSpacer}else delete t.fragments,f=v;return f}).attr(\"dy\",function(t){return t.needsConvertToTspans?0:\"0.75em\"}).each(function(t){var o=i.select(this),l=t.wrappingNeeded?C:L;t.needsConvertToTspans?s.convertToTspans(o,a,l(r,this,e,a,t)):i.select(this.parentNode).attr(\"transform\",function(t){return\"translate(\"+P(t)+\" \"+n.cellPad+\")\"}).attr(\"text-anchor\",function(t){return{left:\"start\",center:\"middle\",right:\"end\"}[t.align]})})}function b(t){return-1!==t.indexOf(n.wrapSplitCharacter)}function _(t,e,r){if(Array.isArray(t)){var n=t[Math.min(e,t.length-1)];return Array.isArray(n)?n[Math.min(r,n.length-1)]:n}return t}function w(t,e,r){t.transition().ease(n.releaseTransitionEase).duration(n.releaseTransitionDuration).attr(\"transform\",\"translate(\"+e.x+\" \"+r+\")\")}function k(t){return\"cells\"===t.type}function T(t){return\"header\"===t.type}function A(t){return(t.rowBlocks.length?t.rowBlocks[0].auxiliaryBlocks:[]).reduce(function(t,e){return t+I(e,1/0)},0)}function M(t,e,r){var n=v(e)[0];if(void 0!==n){var i=n.rowBlocks,a=n.calcdata,o=z(i,i.length),s=n.calcdata.groupHeight-A(n),l=a.scrollY=Math.max(0,Math.min(o-s,a.scrollY)),c=function(t,e,r){for(var n=[],i=0,a=0;a<t.length;a++){for(var o=t[a],s=o.rows,l=0,c=0;c<s.length;c++)l+=s[c].rowHeight;o.allRowsHeight=l,e<i+l&&e+r>i&&n.push(a),i+=l}return n}(i,l,s);1===c.length&&(c[0]===i.length-1?c.unshift(c[0]-1):c.push(c[0]+1)),c[0]%2&&c.reverse(),e.each(function(t,e){t.page=c[e],t.scrollY=l}),e.attr(\"transform\",function(t){return\"translate(0 \"+(z(t.rowBlocks,t.page)-t.scrollY)+\")\"}),t&&(E(t,r,e,c,n.prevPages,n,0),E(t,r,e,c,n.prevPages,n,1),m(r,t))}}function S(t,e,r,a){return function(o){var s=o.calcdata?o.calcdata:o,l=e.filter(function(t){return s.key===t.key}),c=r||s.scrollbarState.dragMultiplier,u=s.scrollY;s.scrollY=void 0===a?s.scrollY+c*i.event.dy:a;var h=l.selectAll(\".\"+n.cn.yColumn).selectAll(\".\"+n.cn.columnBlock).filter(k);return M(t,h,l),s.scrollY===u}}function E(t,e,r,n,i,a,o){n[o]!==i[o]&&(clearTimeout(a.currentRepaint[o]),a.currentRepaint[o]=setTimeout(function(){var a=r.filter(function(t,e){return e===o&&n[e]!==i[e]});y(t,e,a,r),i[o]=n[o]}))}function C(t,e,r,a){return function(){var o=i.select(e.parentNode);o.each(function(t){var e=t.fragments;o.selectAll(\"tspan.line\").each(function(t,r){e[r].width=this.getComputedTextLength()});var r,i,a=e[e.length-1].width,s=e.slice(0,-1),l=[],c=0,u=t.column.columnWidth-2*n.cellPad;for(t.value=\"\";s.length;)c+(i=(r=s.shift()).width+a)>u&&(t.value+=l.join(n.wrapSpacer)+n.lineBreaker,l=[],c=0),l.push(r.text),c+=i;c&&(t.value+=l.join(n.wrapSpacer)),t.wrapped=!0}),o.selectAll(\"tspan.line\").remove(),x(o.select(\".\"+n.cn.cellText),r,t,a),i.select(e.parentNode.parentNode).call(O)}}function L(t,e,r,a,o){return function(){if(!o.settledY){var s=i.select(e.parentNode),l=R(o),c=o.key-l.firstRowIndex,u=l.rows[c].rowHeight,h=o.cellHeightMayIncrease?e.parentNode.getBoundingClientRect().height+2*n.cellPad:u,f=Math.max(h,u);f-l.rows[c].rowHeight&&(l.rows[c].rowHeight=f,t.selectAll(\".\"+n.cn.columnCell).call(O),M(null,t.filter(k),0),m(r,a,!0)),s.attr(\"transform\",function(){var t=this.parentNode.getBoundingClientRect(),e=i.select(this.parentNode).select(\".\"+n.cn.cellRect).node().getBoundingClientRect(),r=this.transform.baseVal.consolidate(),a=e.top-t.top+(r?r.matrix.f:n.cellPad);return\"translate(\"+P(o,i.select(this.parentNode).select(\".\"+n.cn.cellTextHolder).node().getBoundingClientRect().width)+\" \"+a+\")\"}),o.settledY=!0}}}function P(t,e){switch(t.align){case\"left\":return n.cellPad;case\"right\":return t.column.columnWidth-(e||0)-n.cellPad;case\"center\":return(t.column.columnWidth-(e||0))/2;default:return n.cellPad}}function O(t){t.attr(\"transform\",function(t){var e=t.rowBlocks[0].auxiliaryBlocks.reduce(function(t,e){return t+I(e,1/0)},0);return\"translate(0 \"+(I(R(t),t.key)+e)+\")\"}).selectAll(\".\"+n.cn.cellRect).attr(\"height\",function(t){return(e=R(t),r=t.key,e.rows[r-e.firstRowIndex]).rowHeight;var e,r})}function z(t,e){for(var r=0,n=e-1;n>=0;n--)r+=D(t[n]);return r}function I(t,e){for(var r=0,n=0;n<t.rows.length&&t.rows[n].rowIndex<e;n++)r+=t.rows[n].rowHeight;return r}function D(t){var e=t.allRowsHeight;if(void 0!==e)return e;for(var r=0,n=0;n<t.rows.length;n++)r+=t.rows[n].rowHeight;return t.allRowsHeight=r,r}function R(t){return t.rowBlocks[t.page]}e.exports=function(t,e){var r=!t._context.staticPlot,s=t._fullLayout._paper.selectAll(\".\"+n.cn.table).data(e.map(function(e){var r=a.unwrap(e).trace;return u(t,r)}),a.keyFun);s.exit().remove(),s.enter().append(\"g\").classed(n.cn.table,!0).attr(\"overflow\",\"visible\").style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"overflow\",\"visible\").style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"all\"),s.attr(\"width\",function(t){return t.width+t.size.l+t.size.r}).attr(\"height\",function(t){return t.height+t.size.t+t.size.b}).attr(\"transform\",function(t){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"});var f=s.selectAll(\".\"+n.cn.tableControlView).data(a.repeat,a.keyFun),x=f.enter().append(\"g\").classed(n.cn.tableControlView,!0).style(\"box-sizing\",\"content-box\");r&&x.on(\"mousemove\",function(e){f.filter(function(t){return e===t}).call(m,t)}).on(\"mousewheel\",function(e){if(!e.scrollbarState.wheeling){e.scrollbarState.wheeling=!0;var r=e.scrollY+i.event.deltaY;S(t,f,null,r)(e)||(i.event.stopPropagation(),i.event.preventDefault()),e.scrollbarState.wheeling=!1}}).call(m,t,!0),f.attr(\"transform\",function(t){return\"translate(\"+t.size.l+\" \"+t.size.t+\")\"});var b=f.selectAll(\".\"+n.cn.scrollBackground).data(a.repeat,a.keyFun);b.enter().append(\"rect\").classed(n.cn.scrollBackground,!0).attr(\"fill\",\"none\"),b.attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}),f.each(function(e){o.setClipUrl(i.select(this),d(t,e),t)});var _=f.selectAll(\".\"+n.cn.yColumn).data(function(t){return t.columns},a.keyFun);_.enter().append(\"g\").classed(n.cn.yColumn,!0),_.exit().remove(),_.attr(\"transform\",function(t){return\"translate(\"+t.x+\" 0)\"}),r&&_.call(i.behavior.drag().origin(function(e){return w(i.select(this),e,-n.uplift),l(this),e.calcdata.columnDragInProgress=!0,m(f.filter(function(t){return e.calcdata.key===t.key}),t),e}).on(\"drag\",function(t){var e=i.select(this),r=function(e){return(t===e?i.event.x:e.x)+e.columnWidth/2};t.x=Math.max(-n.overdrag,Math.min(t.calcdata.width+n.overdrag-t.columnWidth,i.event.x)),v(_).filter(function(e){return e.calcdata.key===t.calcdata.key}).sort(function(t,e){return r(t)-r(e)}).forEach(function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e)}),_.filter(function(e){return t!==e}).transition().ease(n.transitionEase).duration(n.transitionDuration).attr(\"transform\",function(t){return\"translate(\"+t.x+\" 0)\"}),e.call(c).attr(\"transform\",\"translate(\"+t.x+\" -\"+n.uplift+\" )\")}).on(\"dragend\",function(e){var r=i.select(this),n=e.calcdata;e.x=e.xScale(e),e.calcdata.columnDragInProgress=!1,w(r,e,0),function(t,e,r){var n=e.gdColumnsOriginalOrder;e.gdColumns.sort(function(t,e){return r[n.indexOf(t)]-r[n.indexOf(e)]}),e.columnorder=r,t.emit(\"plotly_restyle\")}(t,n,n.columns.map(function(t){return t.xIndex}))})),_.each(function(e){o.setClipUrl(i.select(this),g(t,e),t)});var A=_.selectAll(\".\"+n.cn.columnBlock).data(h.splitToPanels,a.keyFun);A.enter().append(\"g\").classed(n.cn.columnBlock,!0).attr(\"id\",function(t){return t.key}),A.style(\"cursor\",function(t){return t.dragHandle?\"ew-resize\":t.calcdata.scrollbarState.barWiggleRoom?\"ns-resize\":\"default\"});var E=A.filter(T),C=A.filter(k);r&&C.call(i.behavior.drag().origin(function(t){return i.event.stopPropagation(),t}).on(\"drag\",S(t,f,-1)).on(\"dragend\",function(){})),y(t,f,E,A),y(t,f,C,A);var L=f.selectAll(\".\"+n.cn.scrollAreaClip).data(a.repeat,a.keyFun);L.enter().append(\"clipPath\").classed(n.cn.scrollAreaClip,!0).attr(\"id\",function(e){return d(t,e)});var P=L.selectAll(\".\"+n.cn.scrollAreaClipRect).data(a.repeat,a.keyFun);P.enter().append(\"rect\").classed(n.cn.scrollAreaClipRect,!0).attr(\"x\",-n.overdrag).attr(\"y\",-n.uplift).attr(\"fill\",\"none\"),P.attr(\"width\",function(t){return t.width+2*n.overdrag}).attr(\"height\",function(t){return t.height+n.uplift}),_.selectAll(\".\"+n.cn.columnBoundary).data(a.repeat,a.keyFun).enter().append(\"g\").classed(n.cn.columnBoundary,!0);var O=_.selectAll(\".\"+n.cn.columnBoundaryClippath).data(a.repeat,a.keyFun);O.enter().append(\"clipPath\").classed(n.cn.columnBoundaryClippath,!0),O.attr(\"id\",function(e){return g(t,e)});var z=O.selectAll(\".\"+n.cn.columnBoundaryRect).data(a.repeat,a.keyFun);z.enter().append(\"rect\").classed(n.cn.columnBoundaryRect,!0).attr(\"fill\",\"none\"),z.attr(\"width\",function(t){return t.columnWidth+2*p(t)}).attr(\"height\",function(t){return t.calcdata.height+2*p(t)+n.uplift}).attr(\"x\",function(t){return-p(t)}).attr(\"y\",function(t){return-p(t)}),M(null,C,f)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/gup\":717,\"../../lib/svg_text_utils\":743,\"./constants\":1232,\"./data_preparation_helper\":1233,\"./data_split_helpers\":1234,d3:163}],1238:[function(t,e,r){\"use strict\";var n=t(\"../box/attributes\"),i=t(\"../../lib/extend\").extendFlat;e.exports={y:n.y,x:n.x,x0:n.x0,y0:n.y0,name:i({},n.name,{}),orientation:i({},n.orientation,{}),bandwidth:{valType:\"number\",min:0,editType:\"calc\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},scalemode:{valType:\"enumerated\",values:[\"width\",\"count\"],dflt:\"width\",editType:\"calc\"},spanmode:{valType:\"enumerated\",values:[\"soft\",\"hard\",\"manual\"],dflt:\"soft\",editType:\"calc\"},span:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}],editType:\"calc\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,points:i({},n.boxpoints,{}),jitter:i({},n.jitter,{}),pointpos:i({},n.pointpos,{}),width:i({},n.width,{}),marker:n.marker,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,box:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},width:{valType:\"number\",min:0,max:1,dflt:.25,editType:\"plot\"},fillcolor:{valType:\"color\",editType:\"style\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},editType:\"plot\"},meanline:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"plot\"},side:{valType:\"enumerated\",values:[\"both\",\"positive\",\"negative\"],dflt:\"both\",editType:\"calc\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,hoveron:{valType:\"flaglist\",flags:[\"violins\",\"points\",\"kde\"],dflt:\"violins+points+kde\",extras:[\"all\"],editType:\"style\"}}},{\"../../lib/extend\":710,\"../box/attributes\":880}],1239:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/calc\"),o=t(\"./helpers\"),s=t(\"../../constants/numerical\").BADNUM;function l(t,e,r){var i=e.max-e.min;if(!i)return t.bandwidth?t.bandwidth:0;if(t.bandwidth)return Math.max(t.bandwidth,i/1e4);var a=r.length,o=n.stdev(r,a-1,e.mean);return Math.max(function(t,e,r){return 1.059*Math.min(e,r/1.349)*Math.pow(t,-.2)}(a,o,e.q3-e.q1),i/100)}function c(t,e,r,n){var a,o=t.spanmode,l=t.span||[],c=[e.min,e.max],u=[e.min-2*n,e.max+2*n];function h(n){var i=l[n],a=\"multicategory\"===r.type?r.r2c(i):r.d2c(i,0,t[e.valLetter+\"calendar\"]);return a===s?u[n]:a}var f={type:\"linear\",range:a=\"soft\"===o?u:\"hard\"===o?c:[h(0),h(1)]};return i.setConvert(f),f.cleanRange(),a}e.exports=function(t,e){var r=a(t,e);if(r[0].t.empty)return r;for(var s=t._fullLayout,u=i.getFromId(t,e[\"h\"===e.orientation?\"xaxis\":\"yaxis\"]),h=1/0,f=-1/0,p=0,d=0,g=0;g<r.length;g++){var v=r[g],m=v.pts.map(o.extractVal),y=v.bandwidth=l(e,v,m),x=v.span=c(e,v,u,y);if(v.min===v.max&&0===y)x=v.span=[v.min,v.max],v.density=[{v:1,t:x[0]}],v.bandwidth=y,p=Math.max(p,1);else{var b=x[1]-x[0],_=Math.ceil(b/(y/3)),w=b/_;if(!isFinite(w)||!isFinite(_))return n.error(\"Something went wrong with computing the violin span\"),r[0].t.empty=!0,r;var k=o.makeKDE(v,e,m);v.density=new Array(_);for(var T=0,A=x[0];A<x[1]+w/2;T++,A+=w){var M=k(A);v.density[T]={v:M,t:A},p=Math.max(p,M)}}d=Math.max(d,m.length),h=Math.min(h,x[0]),f=Math.max(f,x[1])}var S=i.findExtremes(u,[h,f],{padded:!0});if(e._extremes[u._id]=S,e.width)r[0].t.maxKDE=p;else{var E=s._violinScaleGroupStats,C=e.scalegroup,L=E[C];L?(L.maxKDE=Math.max(L.maxKDE,p),L.maxCount=Math.max(L.maxCount,d)):E[C]={maxKDE:p,maxCount:d}}return r[0].t.labels.kde=n._(t,\"kde:\"),r}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../box/calc\":881,\"./helpers\":1242}],1240:[function(t,e,r){\"use strict\";var n=t(\"../box/cross_trace_calc\").setPositionOffset,i=[\"v\",\"h\"];e.exports=function(t,e){for(var r=t.calcdata,a=e.xaxis,o=e.yaxis,s=0;s<i.length;s++){for(var l=i[s],c=\"h\"===l?o:a,u=[],h=0;h<r.length;h++){var f=r[h],p=f[0].t,d=f[0].trace;!0!==d.visible||\"violin\"!==d.type||p.empty||d.orientation!==l||d.xaxis!==a._id||d.yaxis!==o._id||u.push(h)}n(\"violin\",t,u,c)}}},{\"../box/cross_trace_calc\":882}],1241:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../box/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}function c(r,i){return n.coerce2(t,e,o,r,i)}if(a.handleSampleDefaults(t,e,l,s),!1!==e.visible){l(\"bandwidth\"),l(\"side\"),l(\"width\")||(l(\"scalegroup\",e.name),l(\"scalemode\"));var u,h=l(\"span\");Array.isArray(h)&&(u=\"manual\"),l(\"spanmode\",u);var f=l(\"line.color\",(t.marker||{}).color||r),p=l(\"line.width\"),d=l(\"fillcolor\",i.addOpacity(e.line.color,.5));a.handlePointsDefaults(t,e,l,{prefix:\"\"});var g=c(\"box.width\"),v=c(\"box.fillcolor\",d),m=c(\"box.line.color\",f),y=c(\"box.line.width\",p);l(\"box.visible\",Boolean(g||v||m||y))||(e.box={visible:!1});var x=c(\"meanline.color\",f),b=c(\"meanline.width\",p);l(\"meanline.visible\",Boolean(x||b))||(e.meanline={visible:!1})}}},{\"../../components/color\":593,\"../../lib\":719,\"../box/defaults\":883,\"./attributes\":1238}],1242:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=function(t){return 1/Math.sqrt(2*Math.PI)*Math.exp(-.5*t*t)};r.makeKDE=function(t,e,r){var n=r.length,a=i,o=t.bandwidth,s=1/(n*o);return function(t){for(var e=0,i=0;i<n;i++)e+=a((t-r[i])/o);return s*e}},r.getPositionOnKdePath=function(t,e,r){var i,a;\"h\"===e.orientation?(i=\"y\",a=\"x\"):(i=\"x\",a=\"y\");var o=n.findPointOnPath(t.path,r,a,{pathLength:t.pathLength}),s=t.posCenterPx,l=o[i];return[l,\"both\"===e.side?2*s-l:s]},r.getKdeValue=function(t,e,n){var i=t.pts.map(r.extractVal);return r.makeKDE(t,e,i)(n)/t.posDensityScale},r.extractVal=function(t){return t.v}},{\"../../lib\":719}],1243:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/hover\"),o=t(\"./helpers\");e.exports=function(t,e,r,s,l){var c,u,h=t.cd,f=h[0].trace,p=f.hoveron,d=-1!==p.indexOf(\"violins\"),g=-1!==p.indexOf(\"kde\"),v=[];if(d||g){var m=a.hoverOnBoxes(t,e,r,s);if(g&&m.length>0){var y,x,b,_,w,k=t.xa,T=t.ya;\"h\"===f.orientation?(w=e,y=\"y\",b=T,x=\"x\",_=k):(w=r,y=\"x\",b=k,x=\"y\",_=T);var A=h[t.index];if(w>=A.span[0]&&w<=A.span[1]){var M=n.extendFlat({},t),S=_.c2p(w,!0),E=o.getKdeValue(A,f,w),C=o.getPositionOnKdePath(A,f,S),L=b._offset,P=b._length;M[y+\"0\"]=C[0],M[y+\"1\"]=C[1],M[x+\"0\"]=M[x+\"1\"]=S,M[x+\"Label\"]=x+\": \"+i.hoverLabelText(_,w)+\", \"+h[0].t.labels.kde+\" \"+E.toFixed(3),M.spikeDistance=m[0].spikeDistance;var O=y+\"Spike\";M[O]=m[0][O],m[0].spikeDistance=void 0,m[0][O]=void 0,M.hovertemplate=!1,v.push(M),(u={stroke:t.color})[y+\"1\"]=n.constrain(L+C[0],L,L+P),u[y+\"2\"]=n.constrain(L+C[1],L,L+P),u[x+\"1\"]=u[x+\"2\"]=_._offset+S}}d&&(v=v.concat(m))}-1!==p.indexOf(\"points\")&&(c=a.hoverOnPoints(t,e,r));var z=l.selectAll(\".violinline-\"+f.uid).data(u?[0]:[]);return z.enter().append(\"line\").classed(\"violinline-\"+f.uid,!0).attr(\"stroke-width\",1.5),z.exit().remove(),z.attr(u),\"closest\"===s?c?[c]:v:c?(v.push(c),v):v}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../box/hover\":885,\"./helpers\":1242}],1244:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../box/defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../box/select\"),moduleType:\"trace\",name:\"violin\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"violinLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../box/defaults\":883,\"../box/select\":890,\"../scatter/style\":1134,\"./attributes\":1238,\"./calc\":1239,\"./cross_trace_calc\":1240,\"./defaults\":1241,\"./hover\":1243,\"./layout_attributes\":1245,\"./layout_defaults\":1246,\"./plot\":1247,\"./style\":1248}],1245:[function(t,e,r){\"use strict\";var n=t(\"../box/layout_attributes\"),i=t(\"../../lib\").extendFlat;e.exports={violinmode:i({},n.boxmode,{}),violingap:i({},n.boxgap,{}),violingroupgap:i({},n.boxgroupgap,{})}},{\"../../lib\":719,\"../box/layout_attributes\":887}],1246:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"../box/layout_defaults\");e.exports=function(t,e,r){a._supply(t,e,r,function(r,a){return n.coerce(t,e,i,r,a)},\"violin\")}},{\"../../lib\":719,\"../box/layout_defaults\":888,\"./layout_attributes\":1245}],1247:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../box/plot\"),s=t(\"../scatter/line_points\"),l=t(\"./helpers\");e.exports=function(t,e,r,c){var u=t._fullLayout,h=e.xaxis,f=e.yaxis;function p(t){var e=s(t,{xaxis:h,yaxis:f,connectGaps:!0,baseTolerance:.75,shape:\"spline\",simplify:!0});return a.smoothopen(e[0],1)}i.makeTraceGroups(c,r,\"trace violins\").each(function(t){var r=n.select(this),a=t[0],s=a.t,c=a.trace;if(!0!==c.visible||s.empty)r.remove();else{var d=s.bPos,g=s.bdPos,v=e[s.valLetter+\"axis\"],m=e[s.posLetter+\"axis\"],y=\"both\"===c.side,x=y||\"positive\"===c.side,b=y||\"negative\"===c.side,_=r.selectAll(\"path.violin\").data(i.identity);_.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"violin\"),_.exit().remove(),_.each(function(t){var e,r,i,a,o,l,h,f,_=n.select(this),w=t.density,k=w.length,T=t.pos+d,A=m.c2p(T);if(c.width)e=s.maxKDE/g;else{var M=u._violinScaleGroupStats[c.scalegroup];e=\"count\"===c.scalemode?M.maxKDE/g*(M.maxCount/t.pts.length):M.maxKDE/g}if(x){for(h=new Array(k),o=0;o<k;o++)(f=h[o]={})[s.posLetter]=T+w[o].v/e,f[s.valLetter]=w[o].t;r=p(h)}if(b){for(h=new Array(k),l=0,o=k-1;l<k;l++,o--)(f=h[l]={})[s.posLetter]=T-w[o].v/e,f[s.valLetter]=w[o].t;i=p(h)}if(y)a=r+\"L\"+i.substr(1)+\"Z\";else{var S=[A,v.c2p(w[0].t)],E=[A,v.c2p(w[k-1].t)];\"h\"===c.orientation&&(S.reverse(),E.reverse()),a=x?\"M\"+S+\"L\"+r.substr(1)+\"L\"+E:\"M\"+E+\"L\"+i.substr(1)+\"L\"+S}_.attr(\"d\",a),t.posCenterPx=A,t.posDensityScale=e*g,t.path=_.node(),t.pathLength=t.path.getTotalLength()/(y?2:1)});var w,k,T,A=c.box,M=A.width,S=(A.line||{}).width;y?(w=g*M,k=0):x?(w=[0,g*M/2],k=-S):(w=[g*M/2,0],k=S),o.plotBoxAndWhiskers(r,{pos:m,val:v},c,{bPos:d,bdPos:w,bPosPxOffset:k}),o.plotBoxMean(r,{pos:m,val:v},c,{bPos:d,bdPos:w,bPosPxOffset:k}),!c.box.visible&&c.meanline.visible&&(T=i.identity);var E=r.selectAll(\"path.meanline\").data(T||[]);E.enter().append(\"path\").attr(\"class\",\"meanline\").style(\"fill\",\"none\").style(\"vector-effect\",\"non-scaling-stroke\"),E.exit().remove(),E.each(function(t){var e=v.c2p(t.mean,!0),r=l.getPositionOnKdePath(t,c,e);n.select(this).attr(\"d\",\"h\"===c.orientation?\"M\"+e+\",\"+r[0]+\"V\"+r[1]:\"M\"+r[0]+\",\"+e+\"H\"+r[1])}),o.plotPoints(r,{x:h,y:f},c,s)}})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../box/plot\":889,\"../scatter/line_points\":1125,\"./helpers\":1242,d3:163}],1248:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../scatter/style\").stylePoints;e.exports=function(t){var e=n.select(t).selectAll(\"g.trace.violins\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.each(function(e){var r=e[0].trace,o=n.select(this),s=r.box||{},l=s.line||{},c=r.meanline||{},u=c.width;o.selectAll(\"path.violin\").style(\"stroke-width\",r.line.width+\"px\").call(i.stroke,r.line.color).call(i.fill,r.fillcolor),o.selectAll(\"path.box\").style(\"stroke-width\",l.width+\"px\").call(i.stroke,l.color).call(i.fill,s.fillcolor);var h={\"stroke-width\":u+\"px\",\"stroke-dasharray\":2*u+\"px,\"+u+\"px\"};o.selectAll(\"path.mean\").style(h).call(i.stroke,c.color),o.selectAll(\"path.meanline\").style(h).call(i.stroke,c.color),a(o,r,t)})}},{\"../../components/color\":593,\"../scatter/style\":1134,d3:163}],1249:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../isosurface/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=e.exports=s(o({x:i.x,y:i.y,z:i.z,value:i.value,isomin:i.isomin,isomax:i.isomax,surface:i.surface,spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:1}},slices:i.slices,caps:i.caps,text:i.text,hovertext:i.hovertext,hovertemplate:i.hovertemplate},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{colorbar:i.colorbar,opacity:i.opacity,opacityscale:{valType:\"any\",editType:\"calc\"},lightposition:i.lightposition,lighting:i.lighting,flatshading:i.flatshading,contour:i.contour,hoverinfo:o({},a.hoverinfo)}),\"calc\",\"nested\");l.x.editType=l.y.editType=l.z.editType=l.value.editType=\"calc+clearAxisTypes\",l.transforms=void 0},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../isosurface/attributes\":1048}],1250:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib/gl_format_color\").parseColorScale,a=t(\"../../lib/str2rgbarray\"),o=t(\"../../components/colorscale\").extractOpts,s=t(\"../../plots/gl3d/zip3\"),l=t(\"../isosurface/convert\").findNearestOnAxis,c=t(\"../isosurface/convert\").generateIsoMeshes;function u(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var h=u.prototype;h.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._x[e],n=this.data._y[e],i=this.data._z[e],a=this.data._Ys.length,o=this.data._Zs.length,s=l(r,this.data._Xs).id,c=l(n,this.data._Ys).id,u=l(i,this.data._Zs).id,h=t.index=u+o*c+o*a*s;t.traceCoordinate=[this.data._x[h],this.data._y[h],this.data._z[h],this.data.value[h]];var f=this.data.hovertext||this.data.text;return Array.isArray(f)&&void 0!==f[h]?t.textLabel=f[h]:f&&(t.textLabel=f),!0}},h.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map(function(e){return t.d2l(e,0,n)*r})}this.data=c(t);var l={positions:s(n(r.xaxis,t._x,e.dataScale[0],t.xcalendar),n(r.yaxis,t._y,e.dataScale[1],t.ycalendar),n(r.zaxis,t._z,e.dataScale[2],t.zcalendar)),cells:s(t._i,t._j,t._k),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,opacityscale:t.opacityscale,contourEnable:t.contour.show,contourColor:a(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},u=o(t);l.vertexIntensity=t._intensity,l.vertexIntensityBounds=[u.min,u.max],l.colormap=i(t),this.mesh.update(l)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new u(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":605,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../../plots/gl3d/zip3\":818,\"../isosurface/convert\":1050,\"gl-mesh3d\":280}],1251:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../isosurface/defaults\").supplyIsoDefaults;e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}a(t,e,r,o,s);var l=s(\"opacityscale\");\"max\"===l?e.opacityscale=[[0,.1],[1,1]]:\"min\"===l?e.opacityscale=[[0,1],[1,.1]]:\"extremes\"===l?e.opacityscale=function(t,e){for(var r=[],n=0;n<32;n++){var i=n/31,a=e+(1-e)*(1-Math.pow(Math.sin(t*i*Math.PI),2));r.push([i,Math.max(1,Math.min(0,a))])}return r}(1,.1):function(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var n=t[r];if(2!==n.length||+n[0]<e)return!1;e=+n[0]}return!0}(l)||(e.opacityscale=void 0)}},{\"../../lib\":719,\"../isosurface/defaults\":1051,\"./attributes\":1249}],1252:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../isosurface/calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"volume\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],meta:{}}},{\"../../plots/gl3d\":807,\"../isosurface/calc\":1049,\"./attributes\":1249,\"./convert\":1250,\"./defaults\":1251}],1253:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"./constants\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../components/color\");function u(t){return{marker:{color:l({},n.marker.color,{arrayOk:!1,editType:\"style\"}),line:{color:l({},n.marker.line.color,{arrayOk:!1,editType:\"style\"}),width:l({},n.marker.line.width,{arrayOk:!1,editType:\"style\"}),editType:\"style\"},editType:\"style\"},editType:\"style\"}}e.exports={measure:{valType:\"data_array\",dflt:[],editType:\"calc\"},base:{valType:\"number\",dflt:null,arrayOk:!1,editType:\"calc\"},x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,hovertext:n.hovertext,hovertemplate:o({},{keys:s.eventDataKeys}),hoverinfo:l({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"initial\",\"delta\",\"final\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"initial\",\"delta\",\"final\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},text:n.text,textposition:n.textposition,insidetextanchor:n.insidetextanchor,textangle:n.textangle,textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:n.orientation,offset:n.offset,width:n.width,increasing:u(),decreasing:u(),totals:u(),connector:{line:{color:l({},i.color,{dflt:c.defaultLine}),width:l({},i.width,{editType:\"plot\"}),dash:i.dash,editType:\"plot\"},mode:{valType:\"enumerated\",values:[\"spanning\",\"between\"],dflt:\"between\",editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":593,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../bar/attributes\":857,\"../scatter/attributes\":1112,\"./constants\":1255}],1254:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\").mergeArray,a=t(\"../scatter/calc_selection\"),o=t(\"../../constants/numerical\").BADNUM;function s(t){return\"a\"===t||\"absolute\"===t}function l(t){return\"t\"===t||\"total\"===t}e.exports=function(t,e){var r,c,u=n.getFromId(t,e.xaxis||\"x\"),h=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=u.makeCalcdata(e,\"x\"),c=h.makeCalcdata(e,\"y\")):(r=h.makeCalcdata(e,\"y\"),c=u.makeCalcdata(e,\"x\"));for(var f,p=Math.min(c.length,r.length),d=new Array(p),g=0,v=!1,m=0;m<p;m++){var y=r[m]||0,x=!1;(r[m]!==o||l(e.measure[m])||s(e.measure[m]))&&m+1<p&&(r[m+1]!==o||l(e.measure[m+1])||s(e.measure[m+1]))&&(x=!0);var b=d[m]={i:m,p:c[m],s:y,rawS:y,cNext:x};s(e.measure[m])?(g=b.s,b.isSum=!0,b.dir=\"totals\",b.s=g):l(e.measure[m])?(b.isSum=!0,b.dir=\"totals\",b.s=g):(b.isSum=!1,b.dir=b.rawS<0?\"decreasing\":\"increasing\",f=b.s,b.s=g+f,g+=f),\"totals\"===b.dir&&(v=!0),e.ids&&(b.id=String(e.ids[m])),b.v=(e.base||0)+g}return d.length&&(d[0].hasTotals=v),i(e.text,d,\"tx\"),i(e.hovertext,d,\"htx\"),a(d,e),d}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scatter/calc_selection\":1114}],1255:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"initial\",\"delta\",\"final\"]}},{}],1256:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],h=[],f=[];for(i=0;i<o.length;i++){var p=o[i];!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"waterfall\"===p.type&&(r=s[i],\"h\"===p.orientation?f.push(r):h.push(r),u.push(r))}var d={mode:a.waterfallmode,norm:a.waterfallnorm,gap:a.waterfallgap,groupgap:a.waterfallgroupgap};for(n(t,l,c,h,d),n(t,c,l,f,d),i=0;i<u.length;i++){r=u[i];for(var g=0;g<r.length;g++){var v=r[g];!1===v.isSum&&(v.s0+=0===g?0:r[g-1].s),g+1<r.length&&(r[g].nextP0=r[g+1].p0,r[g].nextS0=r[g+1].s0)}}}},{\"../bar/cross_trace_calc\":860}],1257:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"./attributes\"),l=t(\"../../components/color\"),c=t(\"../../constants/delta.js\"),u=c.INCREASING.COLOR,h=c.DECREASING.COLOR,f=\"#4499FF\";function p(t,e,r){t(e+\".marker.color\",r),t(e+\".marker.line.color\",l.defaultLine),t(e+\".marker.line.width\")}e.exports={supplyDefaults:function(t,e,r,i){function l(r,i){return n.coerce(t,e,s,r,i)}if(o(t,e,i,l)){l(\"measure\"),l(\"orientation\",e.x&&!e.y?\"h\":\"v\"),l(\"base\"),l(\"offset\"),l(\"width\"),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\");var c=l(\"textposition\");a(t,e,i,l,c,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"!==e.textposition&&l(\"textinfo\"),p(l,\"increasing\",u),p(l,\"decreasing\",h),p(l,\"totals\",f),l(\"connector.visible\")&&(l(\"connector.mode\"),l(\"connector.line.width\")&&(l(\"connector.line.color\"),l(\"connector.line.dash\")))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,s,t)}if(\"group\"===e.waterfallmode)for(var l=0;l<t.length;l++)r=(a=t[l])._input,i(r,a,e,o)}}},{\"../../components/color\":593,\"../../constants/delta.js\":689,\"../../lib\":719,\"../bar/defaults\":861,\"../scatter/xy_defaults\":1137,\"./attributes\":1253}],1258:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"initial\"in e&&(t.initial=e.initial),\"delta\"in e&&(t.delta=e.delta),\"final\"in e&&(t.final=e.final),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],1259:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\").hoverLabelText,i=t(\"../../components/color\").opacity,a=t(\"../bar/hover\").hoverOnBars,o=t(\"../../constants/delta.js\"),s=o.INCREASING.SYMBOL,l=o.DECREASING.SYMBOL;e.exports=function(t,e,r,o){var c=a(t,e,r,o);if(c){var u=c.cd,h=u[0].trace,f=\"h\"===h.orientation,p=f?t.xa:t.ya,d=u[c.index],g=d.isSum?d.b+d.s:d.rawS;if(!d.isSum){c.initial=d.b+d.s-g,c.delta=g,c.final=c.initial+c.delta;var v=w(Math.abs(c.delta));c.deltaLabel=g<0?\"(\"+v+\")\":v,c.finalLabel=w(c.final),c.initialLabel=w(c.initial)}var m=d.hi||h.hoverinfo,y=[];if(m&&\"none\"!==m&&\"skip\"!==m){var x=\"all\"===m,b=m.split(\"+\"),_=function(t){return x||-1!==b.indexOf(t)};d.isSum||(!_(\"final\")||_(f?\"x\":\"y\")||y.push(c.finalLabel),_(\"delta\")&&(g<0?y.push(c.deltaLabel+\" \"+l):y.push(c.deltaLabel+\" \"+s)),_(\"initial\")&&y.push(\"Initial: \"+c.initialLabel))}return y.length&&(c.extraText=y.join(\"<br>\")),c.color=function(t,e){var r=t[e.dir].marker,n=r.color,a=r.line.color,o=r.line.width;if(i(n))return n;if(i(a)&&o)return a}(h,d),[c]}function w(t){return n(p,t)}}},{\"../../components/color\":593,\"../../constants/delta.js\":689,\"../../plots/cartesian/axes\":767,\"../bar/hover\":863}],1260:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"waterfall\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../bar/select\":868,\"./attributes\":1253,\"./calc\":1254,\"./cross_trace_calc\":1256,\"./defaults\":1257,\"./event_data\":1258,\"./hover\":1259,\"./layout_attributes\":1261,\"./layout_defaults\":1262,\"./plot\":1263,\"./style\":1264}],1261:[function(t,e,r){\"use strict\";e.exports={waterfallmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"group\",editType:\"calc\"},waterfallgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},waterfallgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],1262:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"waterfall\"===l.type){a=!0;break}}a&&(o(\"waterfallmode\"),o(\"waterfallgap\",.2),o(\"waterfallgroupgap\"))}},{\"../../lib\":719,\"./layout_attributes\":1261}],1263:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../bar/plot\").plot;e.exports=function(t,e,r,s){var l=t._fullLayout;o(t,e,r,s,{mode:l.waterfallmode,norm:l.waterfallmode,gap:l.waterfallgap,groupgap:l.waterfallgroupgap}),function(t,e,r,o){var s=e.xaxis,l=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each(function(r){var o=n.select(this),c=r[0].trace,u=i.ensureSingle(o,\"g\",\"lines\");if(c.connector&&c.connector.visible){var h=\"h\"===c.orientation,f=c.connector.mode,p=u.selectAll(\"g.line\").data(i.identity);p.enter().append(\"g\").classed(\"line\",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var c=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),n?[i,a]:[a,i]}(r,s,l,h),u=c[0],p=c[1],g=\"\";\"spanning\"===f&&!r.isSum&&o>0&&(g+=h?\"M\"+u[0]+\",\"+p[1]+\"V\"+p[0]:\"M\"+u[1]+\",\"+p[0]+\"H\"+u[0]),\"between\"!==f&&(r.isSum||o<d-1)&&(g+=h?\"M\"+u[1]+\",\"+p[0]+\"V\"+p[1]:\"M\"+u[0]+\",\"+p[1]+\"H\"+u[1]),void 0!==u[2]&&void 0!==p[2]&&(g+=h?\"M\"+u[1]+\",\"+p[1]+\"V\"+p[2]:\"M\"+u[1]+\",\"+p[1]+\"H\"+u[2]),\"\"===g&&(g=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}})}else u.remove()})}(t,e,r,s)}},{\"../../components/drawing\":614,\"../../lib\":719,\"../bar/plot\":867,d3:163}],1264:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\").styleTextPoints;e.exports={style:function(t,e,r){var l=r||n.select(t).selectAll(\"g.waterfalllayer\").selectAll(\"g.trace\");l.style(\"opacity\",function(t){return t[0].trace.opacity}),l.each(function(e){var r=n.select(this),l=e[0].trace;r.selectAll(\".point > path\").each(function(t){if(!t.isBlank){var e=l[t.dir].marker;n.select(this).call(a.fill,e.color).call(a.stroke,e.line.color).call(i.dashLine,e.line.dash,e.line.width).style(\"opacity\",l.selectedpoints&&!t.selected?o:1)}}),s(r,l,t),r.selectAll(\".lines\").each(function(){var t=l.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)})})}}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../constants/interactions\":694,\"../bar/style\":870,d3:163}],1265:[function(t,e,r){\"use strict\";var n=t(\"../plots/cartesian/axes\"),i=t(\"../lib\"),a=t(\"../plot_api/plot_schema\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/numerical\").BADNUM;r.moduleType=\"transform\",r.name=\"aggregate\";var l=r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},aggregations:{_isLinkedToArray:\"aggregation\",target:{valType:\"string\",editType:\"calc\"},func:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"median\",\"mode\",\"rms\",\"stddev\",\"min\",\"max\",\"first\",\"last\",\"change\",\"range\"],dflt:\"first\",editType:\"calc\"},funcmode:{valType:\"enumerated\",values:[\"sample\",\"population\"],dflt:\"sample\",editType:\"calc\"},enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},c=l.aggregations;function u(t,e,r,a){if(a.enabled){for(var o=a.target,l=i.nestedProperty(e,o),c=l.get(),u=function(t,e){var r=t.func,n=e.d2c,i=e.c2d;switch(r){case\"count\":return h;case\"first\":return f;case\"last\":return p;case\"sum\":return function(t,e){for(var r=0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r+=o)}return i(r)};case\"avg\":return function(t,e){for(var r=0,a=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l,a++)}return a?i(r/a):s};case\"min\":return function(t,e){for(var r=1/0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r=Math.min(r,o))}return r===1/0?s:i(r)};case\"max\":return function(t,e){for(var r=-1/0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r=Math.max(r,o))}return r===-1/0?s:i(r)};case\"range\":return function(t,e){for(var r=1/0,a=-1/0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r=Math.min(r,l),a=Math.max(a,l))}return a===-1/0||r===1/0?s:i(a-r)};case\"change\":return function(t,e){var r=n(t[e[0]]),a=n(t[e[e.length-1]]);return r===s||a===s?s:i(a-r)};case\"median\":return function(t,e){for(var r=[],a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&r.push(o)}if(!r.length)return s;r.sort();var l=(r.length-1)/2;return i((r[Math.floor(l)]+r[Math.ceil(l)])/2)};case\"mode\":return function(t,e){for(var r={},a=0,o=s,l=0;l<e.length;l++){var c=n(t[e[l]]);if(c!==s){var u=r[c]=(r[c]||0)+1;u>a&&(a=u,o=c)}}return a?i(o):s};case\"rms\":return function(t,e){for(var r=0,a=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l*l,a++)}return a?i(Math.sqrt(r/a)):s};case\"stddev\":return function(e,r){var i,a=0,o=0,l=1,c=s;for(i=0;i<r.length&&c===s;i++)c=n(e[r[i]]);if(c===s)return s;for(;i<r.length;i++){var u=n(e[r[i]]);if(u!==s){var h=u-c;a+=h,o+=h*h,l++}}var f=\"sample\"===t.funcmode?l-1:l;return f?Math.sqrt((o-a*a/l)/f):0}}}(a,n.getDataConversions(t,e,o,c)),d=new Array(r.length),g=0;g<r.length;g++)d[g]=u(c,r[g]);l.set(d),\"count\"===a.func&&i.pushUnique(e._arrayAttrs,o)}}function h(t,e){return e.length}function f(t,e){return t[e[0]]}function p(t,e){return t[e[e.length-1]]}r.supplyDefaults=function(t,e){var r,n={};function o(e,r){return i.coerce(t,n,l,e,r)}if(!o(\"enabled\"))return n;var s=a.findArrayAttributes(e),u={};for(r=0;r<s.length;r++)u[s[r]]=1;var h=o(\"groups\");if(!Array.isArray(h)){if(!u[h])return n.enabled=!1,n;u[h]=0}var f,p=t.aggregations||[],d=n.aggregations=new Array(p.length);function g(t,e){return i.coerce(p[r],f,c,t,e)}for(r=0;r<p.length;r++){f={_index:r};var v=g(\"target\"),m=g(\"func\");g(\"enabled\")&&v&&(u[v]||\"count\"===m&&void 0===u[v])?(\"stddev\"===m&&g(\"funcmode\"),u[v]=0,d[r]=f):d[r]={enabled:!1,_index:r}}for(r=0;r<s.length;r++)u[s[r]]&&d.push({target:s[r],func:c.func.dflt,enabled:!0,_index:-1});return n},r.calcTransform=function(t,e,r){if(r.enabled){var n=r.groups,a=i.getTargetArray(e,{target:n});if(a){var s,l,c,h,f={},p={},d=[],g=o(e.transforms,r),v=a.length;for(e._length&&(v=Math.min(v,e._length)),s=0;s<v;s++)void 0===(c=f[l=a[s]])?(f[l]=d.length,h=[s],d.push(h),p[f[l]]=g(s)):(d[c].push(s),p[f[l]]=(p[f[l]]||[]).concat(g(s)));r._indexToPoints=p;var m=r.aggregations;for(s=0;s<m.length;s++)u(t,e,d,m[s]);\"string\"==typeof n&&u(t,e,d,{target:n,func:\"first\",enabled:!0}),e._length=d.length}}}},{\"../constants/numerical\":695,\"../lib\":719,\"../plot_api/plot_schema\":756,\"../plots/cartesian/axes\":767,\"./helpers\":1268}],1266:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../registry\"),a=t(\"../plots/cartesian/axes\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/filter_ops\"),l=s.COMPARISON_OPS,c=s.INTERVAL_OPS,u=s.SET_OPS;r.moduleType=\"transform\",r.name=\"filter\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},operation:{valType:\"enumerated\",values:[].concat(l).concat(c).concat(u),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},preservegaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function a(i,a){return n.coerce(t,e,r.attributes,i,a)}if(a(\"enabled\")){var o=a(\"target\");if(n.isArrayOrTypedArray(o)&&0===o.length)return e.enabled=!1,e;a(\"preservegaps\"),a(\"operation\"),a(\"value\");var s=i.getComponentMethod(\"calendars\",\"handleDefaults\");s(t,e,\"valuecalendar\",null),s(t,e,\"targetcalendar\",null)}return e},r.calcTransform=function(t,e,r){if(r.enabled){var i=n.getTargetArray(e,r);if(i){var s=r.target,h=i.length;e._length&&(h=Math.min(h,e._length));var f=r.targetcalendar,p=e._arrayAttrs,d=r.preservegaps;if(\"string\"==typeof s){var g=n.nestedProperty(e,s+\"calendar\").get();g&&(f=g)}var v,m,y=function(t,e,r){var n=t.operation,i=t.value,a=Array.isArray(i);function o(t){return-1!==t.indexOf(n)}var s,h=function(r){return e(r,0,t.valuecalendar)},f=function(t){return e(t,0,r)};o(l)?s=h(a?i[0]:i):o(c)?s=a?[h(i[0]),h(i[1])]:[h(i),h(i)]:o(u)&&(s=a?i.map(h):[h(i)]);switch(n){case\"=\":return function(t){return f(t)===s};case\"!=\":return function(t){return f(t)!==s};case\"<\":return function(t){return f(t)<s};case\"<=\":return function(t){return f(t)<=s};case\">\":return function(t){return f(t)>s};case\">=\":return function(t){return f(t)>=s};case\"[]\":return function(t){var e=f(t);return e>=s[0]&&e<=s[1]};case\"()\":return function(t){var e=f(t);return e>s[0]&&e<s[1]};case\"[)\":return function(t){var e=f(t);return e>=s[0]&&e<s[1]};case\"(]\":return function(t){var e=f(t);return e>s[0]&&e<=s[1]};case\"][\":return function(t){var e=f(t);return e<=s[0]||e>=s[1]};case\")(\":return function(t){var e=f(t);return e<s[0]||e>s[1]};case\"](\":return function(t){var e=f(t);return e<=s[0]||e>s[1]};case\")[\":return function(t){var e=f(t);return e<s[0]||e>=s[1]};case\"{}\":return function(t){return-1!==s.indexOf(f(t))};case\"}{\":return function(t){return-1===s.indexOf(f(t))}}}(r,a.getDataToCoordFunc(t,e,s,i),f),x={},b={},_=0;d?(v=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set(new Array(h))},m=function(t,e){var r=x[t.astr][e];t.get()[e]=r}):(v=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set([])},m=function(t,e){var r=x[t.astr][e];t.get().push(r)}),T(v);for(var w=o(e.transforms,r),k=0;k<h;k++){y(i[k])?(T(m,k),b[_++]=w(k)):d&&_++}r._indexToPoints=b,e._length=_}}function T(t,r){for(var i=0;i<p.length;i++){t(n.nestedProperty(e,p[i]),r)}}}},{\"../constants/filter_ops\":691,\"../lib\":719,\"../plots/cartesian/axes\":767,\"../registry\":847,\"./helpers\":1268}],1267:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_schema\"),a=t(\"../plots/plots\"),o=t(\"./helpers\").pointsAccessorFunction;function s(t,e){var r,s,l,c,u,h,f,p,d,g,v=e.transform,m=e.transformIndex,y=t.transforms[m].groups,x=o(t.transforms,v);if(!Array.isArray(y)||0===y.length)return[t];var b=n.filterUnique(y),_=new Array(b.length),w=y.length,k=i.findArrayAttributes(t),T=v.styles||[],A={};for(r=0;r<T.length;r++)A[T[r].target]=T[r].value;v.styles&&(g=n.keyedContainer(v,\"styles\",\"target\",\"value.name\"));var M={},S={};for(r=0;r<b.length;r++){M[h=b[r]]=r,S[h]=0,(f=_[r]=n.extendDeepNoArrays({},t))._group=h,f.transforms[m]._indexToPoints={};var E=null;for(g&&(E=g.get(h)),f.name=E||\"\"===E?E:n.templateString(v.nameformat,{trace:t.name,group:h}),p=f.transforms,f.transforms=[],s=0;s<p.length;s++)f.transforms[s]=n.extendDeepNoArrays({},p[s]);for(s=0;s<k.length;s++)n.nestedProperty(f,k[s]).set([])}for(l=0;l<k.length;l++){for(c=k[l],s=0,d=[];s<b.length;s++)d[s]=n.nestedProperty(_[s],c).get();for(u=n.nestedProperty(t,c).get(),s=0;s<w;s++)d[M[y[s]]].push(u[s])}for(s=0;s<w;s++){(f=_[M[y[s]]]).transforms[m]._indexToPoints[S[y[s]]]=x(s),S[y[s]]++}for(r=0;r<b.length;r++)h=b[r],f=_[r],a.clearExpandedTraceDefaultColors(f),f=n.extendDeepNoArrays(f,A[h]||{});return _}r.moduleType=\"transform\",r.name=\"groupby\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"data_array\",dflt:[],editType:\"calc\"},nameformat:{valType:\"string\",editType:\"calc\"},styles:{_isLinkedToArray:\"style\",target:{valType:\"string\",editType:\"calc\"},value:{valType:\"any\",dflt:{},editType:\"calc\",_compareAsJSON:!0},editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t,e,i){var a,o={};function s(e,i){return n.coerce(t,o,r.attributes,e,i)}if(!s(\"enabled\"))return o;s(\"groups\"),s(\"nameformat\",i._dataLength>1?\"%{group} (%{trace})\":\"%{group}\");var l=t.styles,c=o.styles=[];if(l)for(a=0;a<l.length;a++){var u=c[a]={};n.coerce(l[a],c[a],r.attributes.styles,\"target\");var h=n.coerce(l[a],c[a],r.attributes.styles,\"value\");n.isPlainObject(h)?u.value=n.extendDeep({},h):h&&delete u.value}return o},r.transform=function(t,e){var r,n,i,a=[];for(n=0;n<t.length;n++)for(r=s(t[n],e),i=0;i<r.length;i++)a.push(r[i]);return a}},{\"../lib\":719,\"../plot_api/plot_schema\":756,\"../plots/plots\":828,\"./helpers\":1268}],1268:[function(t,e,r){\"use strict\";r.pointsAccessorFunction=function(t,e){for(var r,n,i=0;i<t.length&&(r=t[i])!==e;i++)r._indexToPoints&&!1!==r.enabled&&(n=r._indexToPoints);return n?function(t){return n[t]}:function(t){return[t]}}},{}],1269:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/cartesian/axes\"),a=t(\"./helpers\").pointsAccessorFunction;r.moduleType=\"transform\",r.name=\"sort\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},order:{valType:\"enumerated\",values:[\"ascending\",\"descending\"],dflt:\"ascending\",editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function i(i,a){return n.coerce(t,e,r.attributes,i,a)}return i(\"enabled\")&&(i(\"target\"),i(\"order\")),e},r.calcTransform=function(t,e,r){if(r.enabled){var o=n.getTargetArray(e,r);if(o){var s=r.target,l=o.length;e._length&&(l=Math.min(l,e._length));var c,u,h=e._arrayAttrs,f=function(t,e,r,n){var i,a=new Array(n),o=new Array(n);for(i=0;i<n;i++)a[i]={v:e[i],i:i};for(a.sort(function(t,e){switch(t.order){case\"ascending\":return function(t,r){return e(t.v)-e(r.v)};case\"descending\":return function(t,r){return e(r.v)-e(t.v)}}}(t,r)),i=0;i<n;i++)o[i]=a[i].i;return o}(r,o,i.getDataToCoordFunc(t,e,s,o),l),p=a(e.transforms,r),d={};for(c=0;c<h.length;c++){var g=n.nestedProperty(e,h[c]),v=g.get(),m=new Array(l);for(u=0;u<l;u++)m[u]=v[f[u]];g.set(m)}for(u=0;u<l;u++)d[u]=p(f[u]);r._indexToPoints=d,e._length=l}}}},{\"../lib\":719,\"../plots/cartesian/axes\":767,\"./helpers\":1268}]},{},[25])(25)});</script>    \n",
       "            <div id=\"3fc6dc7d-1f00-42e5-a80a-3a400d233f6f\" class=\"plotly-graph-div\" style=\"height:500px; width:500px;\"></div>\n",
       "            <script type=\"text/javascript\">\n",
       "                \n",
       "                    window.PLOTLYENV=window.PLOTLYENV || {};\n",
       "                    \n",
       "                if (document.getElementById(\"3fc6dc7d-1f00-42e5-a80a-3a400d233f6f\")) {\n",
       "                    Plotly.newPlot(\n",
       "                        '3fc6dc7d-1f00-42e5-a80a-3a400d233f6f',\n",
       "                        [{\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"A = 2\", \"showscale\": false, \"type\": \"surface\", \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.2, 0.282842712474619, 0.3464101615137755, 0.4, 0.447213595499958, 0.48989794855663565, 0.5291502622129182, 0.565685424949238, 0.6, 0.6324555320336759, 0.66332495807108, 0.692820323027551, 0.7211102550927979, 0.7483314773547883, 0.7745966692414833, 0.8, 0.8246211251235321, 0.848528137423857, 0.8717797887081349, 0.894427190999916, 0.9165151389911681, 0.938083151964686, 0.959166304662544, 0.9797958971132713, 1.0, 1.019803902718557, 1.0392304845413265, 1.0583005244258363, 1.077032961426901, 1.0954451150103321, 1.1135528725660044, 1.131370849898476, 1.148912529307606, 1.1661903789690602, 1.1832159566199232, 1.2, 1.216552506059644, 1.2328828005937953, 1.2489995996796799, 1.2649110640673518, 1.2806248474865698, 1.2961481396815722, 1.3114877048604001, 1.32664991614216, 1.3416407864998738, 1.3564659966250536, 1.3711309200802089, 1.385640646055102, 1.4000000000000001, 1.4142135623730951, 1.4282856857085702, 1.4422205101855958, 1.4560219778561039, 1.469693845669907, 1.4832396974191326, 1.4966629547095767, 1.50996688705415, 1.5231546211727818, 1.5362291495737217, 1.5491933384829666, 1.5620499351813308, 1.574801574802362, 1.5874507866387544, 1.6, 1.6124515496597098, 1.624807680927192, 1.6370705543744901, 1.6492422502470643, 1.661324772583615, 1.6733200530681511, 1.6852299546352718, 1.697056274847714, 1.7088007490635062, 1.7204650534085253, 1.7320508075688774, 1.7435595774162698, 1.7549928774784245, 1.7663521732655696, 1.7776388834631178, 1.788854381999832, 1.8, 1.8110770276274835, 1.8220867158288598, 1.8330302779823362, 1.8439088914585775, 1.854723699099141, 1.8654758106177631, 1.876166303929372, 1.8867962264113207, 1.8973665961010275, 1.9078784028338913, 1.918332609325088, 1.9287301521985911, 1.9390719429665317, 1.9493588689617927, 1.9595917942265426, 1.9697715603592212, 1.9798989873223332, 1.9899748742132402, 2.0, 2.0099751242241783], [0.0, 0.282842712474619, 0.39999999999999997, 0.48989794855663565, 0.565685424949238, 0.6324555320336759, 0.6928203230275509, 0.7483314773547882, 0.7999999999999999, 0.848528137423857, 0.8944271909999159, 0.938083151964686, 0.9797958971132713, 1.019803902718557, 1.058300524425836, 1.0954451150103321, 1.131370849898476, 1.16619037896906, 1.2, 1.2328828005937953, 1.2649110640673518, 1.2961481396815722, 1.3266499161421599, 1.3564659966250536, 1.3856406460551018, 1.4142135623730951, 1.4422205101855958, 1.469693845669907, 1.4966629547095764, 1.5231546211727818, 1.5491933384829666, 1.5748015748023623, 1.5999999999999999, 1.624807680927192, 1.6492422502470643, 1.6733200530681511, 1.697056274847714, 1.7204650534085253, 1.7435595774162695, 1.7663521732655694, 1.7888543819998317, 1.8110770276274835, 1.8330302779823362, 1.8547236990991405, 1.876166303929372, 1.8973665961010273, 1.9183326093250879, 1.9390719429665315, 1.9595917942265426, 1.979898987322333, 2.0, 2.0199009876724157, 2.039607805437114, 2.0591260281974004, 2.078460969082653, 2.0976176963403033, 2.116601048851672, 2.1354156504062622, 2.1540659228538015, 2.172556098240043, 2.1908902300206643, 2.209072203437452, 2.2271057451320084, 2.244994432064365, 2.262741699796952, 2.2803508501982757, 2.2978250586152114, 2.315167380558045, 2.33238075793812, 2.349468024894146, 2.3664319132398464, 2.3832750575625967, 2.4, 2.4166091947189146, 2.4331050121192876, 2.449489742783178, 2.4657656011875906, 2.4819347291981715, 2.4979991993593593, 2.513961017995307, 2.5298221281347035, 2.545584412271571, 2.5612496949731396, 2.576819745345025, 2.5922962793631443, 2.6076809620810595, 2.6229754097208002, 2.6381811916545836, 2.6532998322843198, 2.6683328128252666, 2.6832815729997477, 2.698147512646408, 2.7129319932501073, 2.727636339397171, 2.7422618401604177, 2.756809750418044, 2.7712812921102037, 2.785677655436824, 2.8, 2.814249455894058, 2.8284271247461903, 2.8425340807103794], [0.0, 0.3464101615137755, 0.48989794855663565, 0.6000000000000002, 0.692820323027551, 0.7745966692414835, 0.8485281374238571, 0.9165151389911681, 0.9797958971132713, 1.0392304845413265, 1.0954451150103324, 1.148912529307606, 1.2000000000000004, 1.2489995996796799, 1.2961481396815722, 1.3416407864998738, 1.385640646055102, 1.4282856857085702, 1.4696938456699071, 1.5099668870541503, 1.549193338482967, 1.5874507866387546, 1.6248076809271923, 1.6613247725836153, 1.6970562748477143, 1.7320508075688776, 1.7663521732655698, 1.8000000000000003, 1.8330302779823362, 1.8654758106177634, 1.8973665961010278, 1.9287301521985913, 1.9595917942265426, 1.9899748742132404, 2.019900987672416, 2.04939015319192, 2.078460969082653, 2.107130750570548, 2.1354156504062627, 2.163330765278394, 2.1908902300206647, 2.2181073012818837, 2.2449944320643653, 2.2715633383201097, 2.297825058615212, 2.32379000772445, 2.3494680248941466, 2.374868417407584, 2.400000000000001, 2.4248711305964283, 2.4494897427831783, 2.473863375370597, 2.4979991993593598, 2.521904042583699, 2.5455844122715714, 2.5690465157330262, 2.5922962793631443, 2.6153393661244047, 2.6381811916545845, 2.6608269391300143, 2.6832815729997477, 2.705549851693737, 2.727636339397171, 2.7495454169735045, 2.771281292110204, 2.7928480087537886, 2.8142494558940583, 2.8354893757515653, 2.8565713714171403, 2.8774989139876324, 2.8982753492378883, 2.918903903865285, 2.9393876913398143, 2.9597297173897488, 2.979932885150268, 3.0000000000000004, 3.0199337741083006, 3.039736830714133, 3.0594117081556718, 3.078960863668131, 3.098386676965934, 3.1176914536239795, 3.136877428271625, 3.1559467676119004, 3.174901573277509, 3.193743884534263, 3.2124756808418025, 3.231098884280703, 3.2496153618543846, 3.2680269276736387, 3.286335345030997, 3.3045423283716615, 3.3226495451672307, 3.340658617698014, 3.3585711247493335, 3.3763886032268267, 3.3941125496954285, 3.411744421846397, 3.4292856398964497, 3.4467375879228177, 3.4641016151377553, 3.481379037105843], [0.0, 0.4, 0.565685424949238, 0.692820323027551, 0.8, 0.894427190999916, 0.9797958971132713, 1.0583005244258363, 1.131370849898476, 1.2, 1.2649110640673518, 1.32664991614216, 1.385640646055102, 1.4422205101855958, 1.4966629547095767, 1.5491933384829666, 1.6, 1.6492422502470643, 1.697056274847714, 1.7435595774162698, 1.788854381999832, 1.8330302779823362, 1.876166303929372, 1.918332609325088, 1.9595917942265426, 2.0, 2.039607805437114, 2.078460969082653, 2.1166010488516727, 2.154065922853802, 2.1908902300206643, 2.227105745132009, 2.262741699796952, 2.297825058615212, 2.3323807579381204, 2.3664319132398464, 2.4, 2.433105012119288, 2.4657656011875906, 2.4979991993593598, 2.5298221281347035, 2.5612496949731396, 2.5922962793631443, 2.6229754097208002, 2.65329983228432, 2.6832815729997477, 2.7129319932501073, 2.7422618401604177, 2.771281292110204, 2.8000000000000003, 2.8284271247461903, 2.8565713714171403, 2.8844410203711917, 2.9120439557122078, 2.939387691339814, 2.9664793948382653, 2.9933259094191533, 3.0199337741083, 3.0463092423455636, 3.0724582991474434, 3.098386676965933, 3.1240998703626617, 3.149603149604724, 3.1749015732775088, 3.2, 3.2249030993194197, 3.249615361854384, 3.2741411087489802, 3.2984845004941286, 3.32264954516723, 3.3466401061363023, 3.3704599092705436, 3.394112549695428, 3.4176014981270124, 3.4409301068170506, 3.464101615137755, 3.4871191548325395, 3.509985754956849, 3.532704346531139, 3.5552777669262356, 3.577708763999664, 3.6, 3.622154055254967, 3.6441734316577197, 3.6660605559646724, 3.687817782917155, 3.709447398198282, 3.7309516212355263, 3.752332607858744, 3.7735924528226414, 3.794733192202055, 3.8157568056677826, 3.836665218650176, 3.8574603043971822, 3.8781438859330635, 3.8987177379235853, 3.9191835884530852, 3.9395431207184424, 3.9597979746446663, 3.9799497484264803, 4.0, 4.019950248448357], [0.0, 0.447213595499958, 0.6324555320336759, 0.7745966692414835, 0.894427190999916, 1.0000000000000002, 1.0954451150103324, 1.1832159566199234, 1.2649110640673518, 1.3416407864998738, 1.4142135623730951, 1.4832396974191329, 1.549193338482967, 1.61245154965971, 1.6733200530681511, 1.7320508075688772, 1.788854381999832, 1.8439088914585775, 1.8973665961010278, 1.9493588689617931, 2.0000000000000004, 2.04939015319192, 2.0976176963403033, 2.144761058952722, 2.1908902300206647, 2.23606797749979, 2.280350850198276, 2.3237900077244507, 2.366431913239847, 2.4083189157584592, 2.4494897427831783, 2.489979919597747, 2.5298221281347035, 2.5690465157330262, 2.60768096208106, 2.6457513110645907, 2.6832815729997477, 2.720294101747089, 2.7568097504180447, 2.7928480087537886, 2.8284271247461903, 2.863564212655271, 2.8982753492378883, 2.932575659723036, 2.9664793948382657, 3.0, 3.0331501776206204, 3.0659419433511785, 3.098386676965934, 3.130495168499706, 3.1622776601683795, 3.193743884534263, 3.22490309931942, 3.255764119219942, 3.286335345030997, 3.3166247903554003, 3.3466401061363023, 3.3763886032268267, 3.405877273185281, 3.4351128074635335, 3.4641016151377544, 3.492849839314596, 3.521363372331802, 3.5496478698597698, 3.577708763999664, 3.605551275463989, 3.6331804249169903, 3.6606010435446255, 3.687817782917155, 3.7148351242013424, 3.7416573867739418, 3.768288736283355, 3.7947331922020555, 3.82099463490856, 3.847076812334269, 3.872983346207417, 3.8987177379235862, 3.924283374069717, 3.9496835316263006, 3.9749213828703587, 4.000000000000001, 4.024922359499622, 4.049691346263318, 4.0743097574926725, 4.09878030638384, 4.123105625617661, 4.147288270665545, 4.171330722922843, 4.1952353926806065, 4.219004621945797, 4.242640687119286, 4.266145801540309, 4.289522117905444, 4.312771730569565, 4.335896677735761, 4.358898943540674, 4.3817804600413295, 4.404543109109049, 4.427188724235731, 4.449719092257398, 4.47213595499958, 4.494441010848847], [0.0, 0.48989794855663565, 0.6928203230275509, 0.8485281374238571, 0.9797958971132713, 1.0954451150103324, 1.2000000000000002, 1.2961481396815722, 1.3856406460551018, 1.469693845669907, 1.5491933384829668, 1.6248076809271923, 1.6970562748477143, 1.7663521732655696, 1.833030277982336, 1.8973665961010275, 1.9595917942265426, 2.0199009876724157, 2.078460969082653, 2.1354156504062627, 2.1908902300206647, 2.244994432064365, 2.297825058615212, 2.349468024894146, 2.4000000000000004, 2.4494897427831783, 2.4979991993593598, 2.5455844122715714, 2.5922962793631443, 2.638181191654584, 2.6832815729997477, 2.727636339397171, 2.7712812921102037, 2.8142494558940583, 2.8565713714171403, 2.898275349237888, 2.939387691339814, 2.979932885150268, 3.0199337741083, 3.0594117081556713, 3.0983866769659336, 3.136877428271625, 3.174901573277509, 3.212475680841802, 3.2496153618543846, 3.2863353450309964, 3.32264954516723, 3.358571124749333, 3.3941125496954285, 3.4292856398964493, 3.464101615137755, 3.498571136907181, 3.532704346531139, 3.5665109000254023, 3.6, 3.6331804249169903, 3.666060555964672, 3.698648401781386, 3.7309516212355263, 3.7629775444453557, 3.794733192202055, 3.8262252939417984, 3.857460304397182, 3.8884444190447165, 3.9191835884530852, 3.9496835316262997, 3.97994974842648, 4.009987531152684, 4.039801975344831, 4.069397989875161, 4.09878030638384, 4.127953488110059, 4.156921938165306, 4.18568990729127, 4.214261501141095, 4.242640687119286, 4.270831300812525, 4.298837052040936, 4.3266615305567875, 4.354308211415448, 4.3817804600413295, 4.409081537009721, 4.436214602563767, 4.463182720884279, 4.48998886412873, 4.5166359162544865, 4.543126676640219, 4.5694638635183455, 4.595650117230424, 4.621688003316537, 4.6475800154489, 4.673328578219169, 4.698936049788292, 4.724404724407087, 4.749736834815168, 4.774934554525329, 4.800000000000001, 4.824935232725928, 4.849742261192857, 4.874423042781577, 4.898979485566357, 4.9234134500364695], [0.0, 0.5291502622129182, 0.7483314773547882, 0.9165151389911681, 1.0583005244258363, 1.1832159566199234, 1.2961481396815722, 1.4000000000000001, 1.4966629547095764, 1.5874507866387544, 1.6733200530681511, 1.7549928774784245, 1.8330302779823362, 1.9078784028338915, 1.9798989873223332, 2.0493901531919194, 2.1166010488516727, 2.181742422927143, 2.244994432064365, 2.3065125189341593, 2.366431913239847, 2.4248711305964283, 2.4819347291981715, 2.5377155080899043, 2.5922962793631443, 2.6457513110645907, 2.6981475126464085, 2.749545416973504, 2.8000000000000003, 2.8495613697550017, 2.8982753492378874, 2.946183972531247, 2.993325909419153, 3.039736830714133, 3.0854497241083028, 3.1304951684997055, 3.1749015732775088, 3.2186953878862163, 3.2619012860600183, 3.3045423283716615, 3.3466401061363023, 3.3882148692194836, 3.4292856398964497, 3.4698703145794942, 3.509985754956849, 3.5496478698597693, 3.5888716889852725, 3.627671429443411, 3.6660605559646724, 3.704051835490427, 3.7416573867739418, 3.7788887255382373, 3.815756805667783, 3.852272056851645, 3.8884444190447165, 3.924283374069717, 3.9597979746446663, 3.994996871087636, 4.029888335921977, 4.064480286580315, 4.098780306383839, 4.132795663954365, 4.166533331199932, 4.2, 4.233202097703345, 4.266145801540308, 4.298837052040936, 4.331281565541543, 4.363484845854286, 4.3954521951671826, 4.427188724235731, 4.458699361921591, 4.48998886412873, 4.521061822182926, 4.551922670696417, 4.58257569495584, 4.613025037868319, 4.64327470649756, 4.67332857821917, 4.703190406521939, 4.732863826479694, 4.762352359916263, 4.791659420284376, 4.82078831727758, 4.849742261192857, 4.878524367060187, 4.907137658554119, 4.935585071701227, 4.963869458396343, 4.991993589739474, 5.019960159204453, 5.047771785649585, 5.075431016179809, 5.10294032886923, 5.130302135352265, 5.15751878329105, 5.184592558726289, 5.2115256883181535, 5.238320341483518, 5.264978632435274, 5.291502622129181, 5.317894320123333], [0.0, 0.565685424949238, 0.7999999999999999, 0.9797958971132713, 1.131370849898476, 1.2649110640673518, 1.3856406460551018, 1.4966629547095764, 1.5999999999999999, 1.697056274847714, 1.7888543819998317, 1.876166303929372, 1.9595917942265426, 2.039607805437114, 2.116601048851672, 2.1908902300206643, 2.262741699796952, 2.33238075793812, 2.4, 2.4657656011875906, 2.5298221281347035, 2.5922962793631443, 2.6532998322843198, 2.7129319932501073, 2.7712812921102037, 2.8284271247461903, 2.8844410203711917, 2.939387691339814, 2.993325909419153, 3.0463092423455636, 3.098386676965933, 3.1496031496047245, 3.1999999999999997, 3.249615361854384, 3.2984845004941286, 3.3466401061363023, 3.394112549695428, 3.4409301068170506, 3.487119154832539, 3.5327043465311387, 3.5777087639996634, 3.622154055254967, 3.6660605559646724, 3.709447398198281, 3.752332607858744, 3.7947331922020546, 3.8366652186501757, 3.878143885933063, 3.9191835884530852, 3.959797974644666, 4.0, 4.039801975344831, 4.079215610874228, 4.118252056394801, 4.156921938165306, 4.1952353926806065, 4.233202097703344, 4.2708313008125245, 4.308131845707603, 4.345112196480086, 4.381780460041329, 4.418144406874904, 4.454211490264017, 4.48998886412873, 4.525483399593904, 4.560701700396551, 4.595650117230423, 4.63033476111609, 4.66476151587624, 4.698936049788292, 4.732863826479693, 4.766550115125193, 4.8, 4.833218389437829, 4.866210024238575, 4.898979485566356, 4.931531202375181, 4.963869458396343, 4.995998398718719, 5.027922035990614, 5.059644256269407, 5.091168824543142, 5.122499389946279, 5.15363949069005, 5.184592558726289, 5.215361924162119, 5.2459508194416005, 5.276362383309167, 5.3065996645686395, 5.336665625650533, 5.366563145999495, 5.396295025292816, 5.4258639865002145, 5.455272678794342, 5.4845236803208355, 5.513619500836088, 5.542562584220407, 5.571355310873648, 5.6, 5.628498911788116, 5.656854249492381, 5.685068161420759], [0.0, 0.6, 0.848528137423857, 1.0392304845413265, 1.2, 1.3416407864998738, 1.469693845669907, 1.5874507866387544, 1.697056274847714, 1.7999999999999998, 1.8973665961010275, 1.98997487421324, 2.078460969082653, 2.1633307652783937, 2.244994432064365, 2.3237900077244498, 2.4, 2.473863375370596, 2.545584412271571, 2.615339366124404, 2.6832815729997477, 2.749545416973504, 2.814249455894058, 2.877498913987632, 2.939387691339814, 3.0, 3.059411708155671, 3.117691453623979, 3.1749015732775088, 3.2310988842807027, 3.2863353450309964, 3.340658617698013, 3.394112549695428, 3.4467375879228173, 3.4985711369071804, 3.5496478698597693, 3.5999999999999996, 3.6496575181789317, 3.698648401781386, 3.746998799039039, 3.794733192202055, 3.8418745424597094, 3.8884444190447165, 3.9344631145812, 3.97994974842648, 4.024922359499621, 4.069397989875161, 4.113392760240626, 4.156921938165306, 4.2, 4.242640687119285, 4.28485705712571, 4.3266615305567875, 4.368065933568311, 4.409081537009721, 4.449719092257398, 4.48998886412873, 4.52990066116245, 4.569463863518345, 4.608687448721165, 4.6475800154488995, 4.686149805543993, 4.724404724407086, 4.762352359916263, 4.8, 4.8373546489791295, 4.874423042781576, 4.91121166312347, 4.947726750741192, 4.983974317750845, 5.019960159204453, 5.0556898639058145, 5.091168824543142, 5.126402247190518, 5.161395160225576, 5.196152422706632, 5.230678732248808, 5.264978632435273, 5.299056519796709, 5.332916650389353, 5.366563145999495, 5.4, 5.43323108288245, 5.466260147486579, 5.499090833947008, 5.531726674375732, 5.5641710972974225, 5.596427431853289, 5.628498911788116, 5.660388679233962, 5.692099788303082, 5.7236352085016735, 5.754997827975264, 5.786190456595773, 5.817215828899595, 5.848076606885377, 5.878775382679628, 5.909314681077663, 5.939696961966999, 5.96992462263972, 6.0, 6.029925372672535], [0.0, 0.6324555320336759, 0.8944271909999159, 1.0954451150103324, 1.2649110640673518, 1.4142135623730951, 1.5491933384829668, 1.6733200530681511, 1.7888543819998317, 1.8973665961010275, 2.0, 2.0976176963403033, 2.1908902300206647, 2.280350850198276, 2.3664319132398464, 2.449489742783178, 2.5298221281347035, 2.6076809620810595, 2.6832815729997477, 2.7568097504180447, 2.8284271247461903, 2.898275349237888, 2.9664793948382653, 3.0331501776206204, 3.0983866769659336, 3.1622776601683795, 3.22490309931942, 3.286335345030997, 3.3466401061363023, 3.4058772731852804, 3.4641016151377544, 3.521363372331802, 3.5777087639996634, 3.6331804249169903, 3.687817782917155, 3.7416573867739413, 3.794733192202055, 3.847076812334269, 3.898717737923586, 3.9496835316263, 4.0, 4.049691346263318, 4.09878030638384, 4.147288270665544, 4.1952353926806065, 4.242640687119285, 4.2895221179054435, 4.33589667773576, 4.3817804600413295, 4.427188724235731, 4.47213595499958, 4.5166359162544865, 4.560701700396552, 4.604345773288536, 4.6475800154489, 4.69041575982343, 4.732863826479693, 4.774934554525329, 4.8166378315169185, 4.857983120596447, 4.898979485566356, 4.9396356140913875, 4.979959839195493, 5.019960159204453, 5.059644256269407, 5.0990195135927845, 5.138093031466052, 5.176871642217914, 5.215361924162119, 5.253570214625479, 5.291502622129181, 5.329165037789691, 5.366563145999495, 5.403702434442518, 5.440588203494177, 5.477225575051661, 5.513619500836089, 5.549774770204643, 5.585696017507577, 5.621387729022079, 5.656854249492381, 5.692099788303083, 5.727128425310542, 5.761944116355173, 5.796550698475776, 5.830951894845301, 5.865151319446072, 5.8991524815010505, 5.932958789676531, 5.966573556070519, 6.0, 6.0332412515993425, 6.066300355241241, 6.099180272790763, 6.131883886702357, 6.164414002968976, 6.196773353931867, 6.228964600958975, 6.260990336999411, 6.29285308902091, 6.324555320336759, 6.356099432828282], [0.0, 0.66332495807108, 0.938083151964686, 1.148912529307606, 1.32664991614216, 1.4832396974191329, 1.6248076809271923, 1.7549928774784245, 1.876166303929372, 1.98997487421324, 2.0976176963403033, 2.2, 2.297825058615212, 2.3916521486202797, 2.4819347291981715, 2.569046515733026, 2.65329983228432, 2.734958866235469, 2.814249455894058, 2.8913664589601926, 2.9664793948382657, 3.039736830714133, 3.1112698372208096, 3.1811947441173736, 3.2496153618543846, 3.3166247903554003, 3.382306905057553, 3.4467375879228177, 3.509985754956849, 3.5721142198983507, 3.63318042491699, 3.693237062523878, 3.752332607858744, 3.8105117766515306, 3.8678159211627436, 3.924283374069717, 3.97994974842648, 4.034848200366404, 4.0890096600521755, 4.1424630354415966, 4.1952353926806065, 4.247352116319061, 4.298837052040936, 4.349712634186309, 4.4, 4.449719092257398, 4.498888751680798, 4.54752680036083, 4.595650117230424, 4.64327470649756, 4.69041575982343, 4.737087712930806, 4.7833042972405595, 4.829078587059855, 4.874423042781577, 4.919349550499538, 4.963869458396343, 5.007993610219566, 5.051732376126036, 5.095095681142799, 5.138093031466052, 5.180733538795447, 5.223025942880239, 5.264978632435274, 5.30659966456864, 5.347896782848375, 5.388877434122993, 5.429548784199292, 5.469917732470938, 5.509990925582365, 5.549774770204644, 5.589275444992849, 5.628498911788116, 5.667450926121902, 5.706137047074843, 5.7445626465380295, 5.782732917920385, 5.8206528843421, 5.858327406350725, 5.895761189193471, 5.9329587896765315, 5.969924622639721, 6.006662967072484, 6.043177971895251, 6.079473661428266, 6.115553940568263, 6.15142259969188, 6.187083319303208, 6.222539674441619, 6.2577951388648065, 6.29285308902091, 6.327716807822551, 6.362389488234747, 6.3968742366877915, 6.431174076325411, 6.465291950097845, 6.499230723708769, 6.532993188424431, 6.566582063752802, 6.600000000000001, 6.6332495807108005, 6.666333324999584], [0.0, 0.692820323027551, 0.9797958971132713, 1.2000000000000004, 1.385640646055102, 1.549193338482967, 1.6970562748477143, 1.8330302779823362, 1.9595917942265426, 2.078460969082653, 2.1908902300206647, 2.297825058615212, 2.400000000000001, 2.4979991993593598, 2.5922962793631443, 2.6832815729997477, 2.771281292110204, 2.8565713714171403, 2.9393876913398143, 3.0199337741083006, 3.098386676965934, 3.174901573277509, 3.2496153618543846, 3.3226495451672307, 3.3941125496954285, 3.4641016151377553, 3.5327043465311396, 3.6000000000000005, 3.6660605559646724, 3.7309516212355267, 3.7947331922020555, 3.8574603043971827, 3.9191835884530852, 3.9799497484264807, 4.039801975344832, 4.09878030638384, 4.156921938165306, 4.214261501141096, 4.270831300812525, 4.326661530556788, 4.3817804600413295, 4.436214602563767, 4.489988864128731, 4.543126676640219, 4.595650117230424, 4.6475800154489, 4.698936049788293, 4.749736834815168, 4.800000000000002, 4.849742261192857, 4.898979485566357, 4.947726750741194, 4.9959983987187195, 5.043808085167398, 5.091168824543143, 5.1380930314660525, 5.184592558726289, 5.230678732248809, 5.276362383309169, 5.321653878260029, 5.366563145999495, 5.411099703387474, 5.455272678794342, 5.499090833947009, 5.542562584220408, 5.585696017507577, 5.628498911788117, 5.670978751503131, 5.713142742834281, 5.754997827975265, 5.796550698475777, 5.83780780773057, 5.8787753826796285, 5.9194594347794975, 5.959865770300536, 6.000000000000001, 6.039867548216601, 6.079473661428266, 6.1188234163113435, 6.157921727336262, 6.196773353931868, 6.235382907247959, 6.27375485654325, 6.311893535223801, 6.349803146555018, 6.387487769068526, 6.424951361683605, 6.462197768561406, 6.499230723708769, 6.536053855347277, 6.572670690061994, 6.609084656743323, 6.645299090334461, 6.681317235396028, 6.717142249498667, 6.752777206453653, 6.788225099390857, 6.823488843692794, 6.8585712797928995, 6.893475175845635, 6.9282032302755105, 6.962758074211686], [0.0, 0.7211102550927979, 1.019803902718557, 1.2489995996796799, 1.4422205101855958, 1.61245154965971, 1.7663521732655696, 1.9078784028338915, 2.039607805437114, 2.1633307652783937, 2.280350850198276, 2.3916521486202797, 2.4979991993593598, 2.6000000000000005, 2.6981475126464085, 2.792848008753788, 2.8844410203711917, 2.973213749463701, 3.0594117081556713, 3.1432467291003428, 3.22490309931942, 3.3045423283716615, 3.3823069050575527, 3.458323293158117, 3.532704346531139, 3.6055512754639896, 3.6769552621700474, 3.7469987990390394, 3.815756805667783, 3.88329756778952, 3.9496835316262997, 4.014971979976947, 4.079215610874228, 4.1424630354415966, 4.204759208325728, 4.266145801540309, 4.3266615305567875, 4.386342439892262, 4.445222154178574, 4.503332099679081, 4.560701700396552, 4.617358552246079, 4.67332857821917, 4.728636167014756, 4.7833042972405595, 4.8373546489791295, 4.890807704254994, 4.94368283772331, 4.9959983987187195, 5.047771785649585, 5.099019513592785, 5.149757275833494, 5.200000000000001, 5.249761899362676, 5.299056519796709, 5.347896782848376, 5.396295025292817, 5.44426303552648, 5.491812087098393, 5.5389529696504916, 5.585696017507576, 5.63205113613149, 5.678027826631356, 5.723635208501674, 5.768882040742383, 5.813776741499453, 5.858327406350725, 5.902541825349482, 5.946427498927402, 5.989991652748776, 6.033241251599343, 6.076183012385325, 6.118823416311343, 6.161168720299745, 6.203224967708329, 6.244997998398398, 6.2864934582006855, 6.327716807822551, 6.3686733312362644, 6.409368143584826, 6.44980619863884, 6.489992295835181, 6.529931086925804, 6.569627082262737, 6.609084656743323, 6.648308055437865, 6.687301398920196, 6.726068688320096, 6.764613810115105, 6.802940540677979, 6.841052550594828, 6.878953408767936, 6.916646586316234, 6.954135460285485, 6.9914233171794145, 7.0285133563222315, 7.065408693062278, 7.102112361825883, 7.138627319029899, 7.17495644586084, 7.211102550927979, 7.247068372797377], [0.0, 0.7483314773547883, 1.058300524425836, 1.2961481396815722, 1.4966629547095767, 1.6733200530681511, 1.833030277982336, 1.9798989873223332, 2.116601048851672, 2.244994432064365, 2.3664319132398464, 2.4819347291981715, 2.5922962793631443, 2.6981475126464085, 2.8, 2.8982753492378874, 2.9933259094191533, 3.0854497241083023, 3.1749015732775088, 3.2619012860600183, 3.3466401061363023, 3.4292856398964493, 3.509985754956849, 3.5888716889852725, 3.666060555964672, 3.7416573867739413, 3.8157568056677826, 3.8884444190447165, 3.9597979746446663, 4.029888335921977, 4.098780306383839, 4.166533331199932, 4.233202097703344, 4.298837052040936, 4.363484845854286, 4.427188724235731, 4.48998886412873, 4.551922670696417, 4.613025037868319, 4.673328578219169, 4.732863826479693, 4.791659420284376, 4.849742261192857, 4.907137658554118, 4.963869458396343, 5.0199601592044525, 5.075431016179809, 5.130302135352264, 5.184592558726289, 5.238320341483518, 5.291502622129181, 5.344155686354956, 5.396295025292817, 5.447935388750495, 5.499090833947008, 5.549774770204643, 5.6, 5.649778756730214, 5.6991227395100035, 5.748043145279965, 5.796550698475775, 5.844655678480983, 5.892367945062493, 5.939696961966999, 5.986651818838307, 6.033241251599342, 6.079473661428265, 6.125357132445422, 6.170899448216605, 6.216108107168021, 6.260990336999411, 6.305553108173778, 6.3498031465550175, 6.393746945258312, 6.437390775772432, 6.48074069840786, 6.523802572120037, 6.566582063752802, 6.609084656743323, 6.6513156593263565, 6.6932802122726045, 6.734983296193095, 6.776429738438967, 6.817624219623724, 6.858571279792899, 6.899275324264136, 6.939740629158989, 6.979971346646059, 7.019971509913698, 7.059745037889116, 7.099295739719539, 7.138627319029899, 7.177743377970545, 7.216647421067487, 7.255342858886822, 7.293833011524187, 7.332121111929344, 7.370210309075312, 7.408103670980854, 7.445804187594514, 7.483314773547883, 7.520638270785267], [0.0, 0.7745966692414833, 1.0954451150103321, 1.3416407864998738, 1.5491933384829666, 1.7320508075688772, 1.8973665961010275, 2.0493901531919194, 2.1908902300206643, 2.3237900077244498, 2.449489742783178, 2.569046515733026, 2.6832815729997477, 2.792848008753788, 2.8982753492378874, 2.9999999999999996, 3.098386676965933, 3.1937438845342623, 3.2863353450309964, 3.3763886032268267, 3.4641016151377544, 3.5496478698597693, 3.63318042491699, 3.714835124201342, 3.794733192202055, 3.8729833462074166, 3.9496835316262997, 4.024922359499621, 4.098780306383839, 4.171330722922842, 4.242640687119285, 4.3127717305695645, 4.381780460041329, 4.449719092257398, 4.516635916254486, 4.58257569495584, 4.6475800154488995, 4.711687595755898, 4.774934554525329, 4.8373546489791295, 4.898979485566356, 4.959838707054898, 5.019960159204453, 5.079370039680117, 5.138093031466052, 5.196152422706631, 5.253570214625478, 5.310367218940701, 5.366563145999495, 5.422176684690383, 5.477225575051661, 5.531726674375732, 5.585696017507576, 5.639148871948674, 5.692099788303082, 5.744562646538029, 5.796550698475775, 5.848076606885378, 5.8991524815010505, 5.949789912257406, 5.999999999999999, 6.049793384901669, 6.099180272790762, 6.148170459575758, 6.196773353931866, 6.244997998398397, 6.292853089020909, 6.340346993658943, 6.387487769068525, 6.434283176858164, 6.48074069840786, 6.526867548832287, 6.572670690061993, 6.618156843109718, 6.663332499583071, 6.7082039324993685, 6.752777206453653, 6.797058187186571, 6.841052550594828, 6.884765791223402, 6.928203230275509, 6.97137002317335, 7.014271166700073, 7.056911505750939, 7.099295739719539, 7.1414284285428495, 7.183313998427188, 7.224956747275377, 7.26636084983398, 7.307530362578043, 7.348469228349534, 7.389181280764466, 7.429670248402684, 7.469939758793239, 7.5099933422074345, 7.549834435270749, 7.58946638440411, 7.628892449104261, 7.668115805072325, 7.707139547199078, 7.745966692414833, 7.784600182411426], [0.0, 0.8, 1.131370849898476, 1.385640646055102, 1.6, 1.788854381999832, 1.9595917942265426, 2.1166010488516727, 2.262741699796952, 2.4, 2.5298221281347035, 2.65329983228432, 2.771281292110204, 2.8844410203711917, 2.9933259094191533, 3.098386676965933, 3.2, 3.2984845004941286, 3.394112549695428, 3.4871191548325395, 3.577708763999664, 3.6660605559646724, 3.752332607858744, 3.836665218650176, 3.9191835884530852, 4.0, 4.079215610874228, 4.156921938165306, 4.233202097703345, 4.308131845707604, 4.381780460041329, 4.454211490264018, 4.525483399593904, 4.595650117230424, 4.664761515876241, 4.732863826479693, 4.8, 4.866210024238576, 4.931531202375181, 4.9959983987187195, 5.059644256269407, 5.122499389946279, 5.184592558726289, 5.2459508194416005, 5.30659966456864, 5.366563145999495, 5.4258639865002145, 5.4845236803208355, 5.542562584220408, 5.6000000000000005, 5.656854249492381, 5.713142742834281, 5.768882040742383, 5.8240879114244155, 5.878775382679628, 5.932958789676531, 5.986651818838307, 6.0398675482166, 6.092618484691127, 6.144916598294887, 6.196773353931866, 6.248199740725323, 6.299206299209448, 6.3498031465550175, 6.4, 6.449806198638839, 6.499230723708768, 6.5482822174979605, 6.596969000988257, 6.64529909033446, 6.6932802122726045, 6.740919818541087, 6.788225099390856, 6.835202996254025, 6.881860213634101, 6.92820323027551, 6.974238309665079, 7.019971509913698, 7.065408693062278, 7.110555533852471, 7.155417527999328, 7.2, 7.244308110509934, 7.288346863315439, 7.332121111929345, 7.37563556583431, 7.418894796396564, 7.4619032424710525, 7.504665215717488, 7.547184905645283, 7.58946638440411, 7.631513611335565, 7.673330437300352, 7.7149206087943645, 7.756287771866127, 7.797435475847171, 7.8383671769061705, 7.879086241436885, 7.919595949289333, 7.959899496852961, 8.0, 8.039900496896713], [0.0, 0.8246211251235321, 1.16619037896906, 1.4282856857085702, 1.6492422502470643, 1.8439088914585775, 2.0199009876724157, 2.181742422927143, 2.33238075793812, 2.473863375370596, 2.6076809620810595, 2.734958866235469, 2.8565713714171403, 2.973213749463701, 3.0854497241083023, 3.1937438845342623, 3.2984845004941286, 3.4, 3.4985711369071804, 3.594440151122286, 3.687817782917155, 3.778888725538237, 3.867815921162743, 3.954743986657038, 4.039801975344831, 4.123105625617661, 4.204759208325728, 4.28485705712571, 4.363484845854286, 4.440720662234904, 4.516635916254486, 4.591296113299599, 4.66476151587624, 4.737087712930805, 4.8083261120685235, 4.878524367060187, 4.947726750741192, 5.015974481593781, 5.083306010855534, 5.149757275833494, 5.215361924162119, 5.280151512977635, 5.344155686354956, 5.407402333838309, 5.469917732470938, 5.531726674375732, 5.592852581643825, 5.653317610041028, 5.713142742834281, 5.772347875864725, 5.830951894845301, 5.888972745734184, 5.946427498927402, 6.003332407921454, 6.059702963017247, 6.115553940568263, 6.170899448216605, 6.2257529665093525, 6.280127387243033, 6.334035048845246, 6.387487769068525, 6.440496875241847, 6.49307323229917, 6.545227268781429, 6.596969000988257, 6.648308055437864, 6.699253689777691, 6.749814812274482, 6.8, 6.849817515817484, 6.899275324264137, 6.948381106416083, 6.997142273814361, 7.045565981523414, 7.093659140387279, 7.14142842854285, 7.188880302244572, 7.236021006050217, 7.282856582413251, 7.329392880723478, 7.37563556583431, 7.42159012611179, 7.467261881037788, 7.512655988397179, 7.557777451076474, 7.602631123499285, 7.647221717722065, 7.691553809211764, 7.735631842325486, 7.779460135510689, 7.8230428862431785, 7.866384175718855, 7.909487973314076, 7.952358140828418, 7.994998436522675, 8.037412518964047, 8.079603950689663, 8.121576201698781, 8.16333265278342, 8.204876598706406, 8.246211251235321, 8.287339742040265], [0.0, 0.848528137423857, 1.2, 1.4696938456699071, 1.697056274847714, 1.8973665961010278, 2.078460969082653, 2.244994432064365, 2.4, 2.545584412271571, 2.6832815729997477, 2.814249455894058, 2.9393876913398143, 3.0594117081556713, 3.1749015732775088, 3.2863353450309964, 3.394112549695428, 3.4985711369071804, 3.6, 3.6986484017813863, 3.7947331922020555, 3.8884444190447165, 3.97994974842648, 4.069397989875161, 4.156921938165306, 4.242640687119286, 4.3266615305567875, 4.409081537009721, 4.48998886412873, 4.5694638635183455, 4.6475800154489, 4.724404724407087, 4.8, 4.874423042781577, 4.947726750741193, 5.019960159204453, 5.091168824543142, 5.1613951602255765, 5.230678732248808, 5.299056519796709, 5.366563145999495, 5.43323108288245, 5.499090833947008, 5.564171097297422, 5.628498911788116, 5.692099788303082, 5.754997827975264, 5.817215828899595, 5.8787753826796285, 5.939696961966999, 6.0, 6.059702963017248, 6.118823416311343, 6.177378084592201, 6.235382907247959, 6.29285308902091, 6.3498031465550175, 6.406246951218787, 6.462197768561405, 6.517668294720129, 6.572670690061993, 6.627216610312357, 6.681317235396026, 6.734983296193095, 6.788225099390856, 6.841052550594828, 6.8934751758456345, 6.945502141674135, 6.997142273814361, 7.048404074682439, 7.0992957397195395, 7.149825172687791, 7.2, 7.249827584156743, 7.299315036357863, 7.3484692283495345, 7.397296803562773, 7.445804187594514, 7.493997598078079, 7.541883053985921, 7.589466384404111, 7.636753236814713, 7.68374908491942, 7.730459236035075, 7.776888838089433, 7.823042886243179, 7.868926229162401, 7.914543574963752, 7.95989949685296, 8.0049984384758, 8.049844718999243, 8.094442537939225, 8.138795979750322, 8.182909018191515, 8.226785520481254, 8.270429251254132, 8.313843876330612, 8.357032966310472, 8.4, 8.442748367682174, 8.485281374238571, 8.527602242131138], [0.0, 0.8717797887081349, 1.2328828005937953, 1.5099668870541503, 1.7435595774162698, 1.9493588689617931, 2.1354156504062627, 2.3065125189341593, 2.4657656011875906, 2.615339366124404, 2.7568097504180447, 2.8913664589601926, 3.0199337741083006, 3.1432467291003428, 3.2619012860600183, 3.3763886032268267, 3.4871191548325395, 3.594440151122286, 3.6986484017813863, 3.8000000000000007, 3.8987177379235862, 3.9949968710876362, 4.0890096600521755, 4.180908992073375, 4.270831300812525, 4.358898943540674, 4.445222154178575, 4.529900661162451, 4.613025037868319, 4.694677837722201, 4.774934554525329, 4.8538644398046396, 4.931531202375181, 5.007993610219566, 5.083306010855535, 5.157518783291051, 5.230678732248808, 5.302829433425142, 5.374011537017762, 5.444263035526481, 5.513619500836089, 5.582114294781146, 5.649778756730215, 5.716642371182581, 5.782732917920385, 5.848076606885378, 5.912698199637794, 5.976621118993575, 6.039867548216601, 6.102458520956944, 6.164414002968978, 6.225752966509353, 6.2864934582006855, 6.3466526610489735, 6.406246951218788, 6.465291950097846, 6.523802572120037, 6.581793068761734, 6.639277069079134, 6.696267617113283, 6.752777206453653, 6.808817812219681, 6.864400920692206, 6.919537556802479, 6.974238309665079, 7.0285133563222315, 7.08237248385031, 7.13582510996451, 7.188880302244572, 7.2415467960926705, 7.293833011524189, 7.345747068882784, 7.397296803562773, 7.448489779814429, 7.49933330370107, 7.549834435270751, 7.600000000000001, 7.649836599562112, 7.6993506219680645, 7.748548251124208, 7.7974354758471724, 7.8460180983732135, 7.894301742396222, 7.942291860665913, 7.9899937421752725, 8.037412518964048, 8.084553172563096, 8.13142054010245, 8.178019320104351, 8.224354077980836, 8.270429251254134, 8.316249154516717, 8.36181798414675, 8.407139822793482, 8.452218643646177, 8.497058314499201, 8.54166260162505, 8.586035173466273, 8.630179604156568, 8.674099376880578, 8.717797887081348, 8.761278445523805], [0.0, 0.894427190999916, 1.2649110640673518, 1.549193338482967, 1.788854381999832, 2.0000000000000004, 2.1908902300206647, 2.366431913239847, 2.5298221281347035, 2.6832815729997477, 2.8284271247461903, 2.9664793948382657, 3.098386676965934, 3.22490309931942, 3.3466401061363023, 3.4641016151377544, 3.577708763999664, 3.687817782917155, 3.7947331922020555, 3.8987177379235862, 4.000000000000001, 4.09878030638384, 4.1952353926806065, 4.289522117905444, 4.3817804600413295, 4.47213595499958, 4.560701700396552, 4.647580015448901, 4.732863826479694, 4.8166378315169185, 4.898979485566357, 4.979959839195494, 5.059644256269407, 5.1380930314660525, 5.21536192416212, 5.291502622129181, 5.366563145999495, 5.440588203494178, 5.513619500836089, 5.585696017507577, 5.656854249492381, 5.727128425310542, 5.796550698475777, 5.865151319446072, 5.9329587896765315, 6.0, 6.066300355241241, 6.131883886702357, 6.196773353931868, 6.260990336999412, 6.324555320336759, 6.387487769068526, 6.44980619863884, 6.511528238439884, 6.572670690061994, 6.6332495807108005, 6.6932802122726045, 6.752777206453653, 6.811754546370562, 6.870225614927067, 6.928203230275509, 6.985699678629192, 7.042726744663604, 7.0992957397195395, 7.155417527999328, 7.211102550927978, 7.266360849833981, 7.321202087089251, 7.37563556583431, 7.429670248402685, 7.4833147735478835, 7.53657747256671, 7.589466384404111, 7.64198926981712, 7.694153624668538, 7.745966692414834, 7.7974354758471724, 7.848566748139434, 7.899367063252601, 7.949842765740717, 8.000000000000002, 8.049844718999244, 8.099382692526635, 8.148619514985345, 8.19756061276768, 8.246211251235321, 8.29457654133109, 8.342661445845685, 8.390470785361213, 8.438009243891594, 8.485281374238571, 8.532291603080617, 8.579044235810889, 8.62554346113913, 8.671793355471522, 8.717797887081348, 8.763560920082659, 8.809086218218098, 8.854377448471462, 8.899438184514796, 8.94427190999916, 8.988882021697695], [0.0, 0.9165151389911681, 1.2961481396815722, 1.5874507866387546, 1.8330302779823362, 2.04939015319192, 2.244994432064365, 2.4248711305964283, 2.5922962793631443, 2.749545416973504, 2.898275349237888, 3.039736830714133, 3.174901573277509, 3.3045423283716615, 3.4292856398964493, 3.5496478698597693, 3.6660605559646724, 3.778888725538237, 3.8884444190447165, 3.9949968710876362, 4.09878030638384, 4.2, 4.298837052040936, 4.3954521951671826, 4.48998886412873, 4.582575694955841, 4.67332857821917, 4.762352359916264, 4.849742261192857, 4.935585071701227, 5.019960159204453, 5.10294032886923, 5.184592558726289, 5.264978632435274, 5.344155686354956, 5.422176684690384, 5.499090833947008, 5.574943945906542, 5.649778756730214, 5.723635208501674, 5.796550698475776, 5.868560300448484, 5.939696961967, 6.009991680526688, 6.079473661428266, 6.148170459575759, 6.216108107168022, 6.2833112289620034, 6.349803146555018, 6.4156059729381765, 6.480740698407861, 6.54522726878143, 6.609084656743323, 6.672330927044912, 6.7349832961930955, 6.797058187186572, 6.858571279792899, 6.919537556802478, 6.97997134664606, 7.0398863627192165, 7.099295739719539, 7.158212067269313, 7.216647421067486, 7.274613391789285, 7.332121111929345, 7.389181280764467, 7.445804187594514, 7.501999733404421, 7.557777451076474, 7.6131465242697125, 7.668115805072326, 7.72269383052313, 7.776888838089433, 7.830708780180758, 7.884161337770809, 7.937253933193772, 7.9899937421752725, 8.04238770515324, 8.094442537939226, 8.14616474176652, 8.19756061276768, 8.248636250920512, 8.299397568498573, 8.349850298059241, 8.4, 8.449852069711044, 8.499411744350311, 8.548684109265006, 8.597674104081872, 8.646386528486914, 8.694826047713663, 8.742997197757758, 8.790904390334365, 8.838551917593742, 8.885943956609225, 8.933084573650918, 8.97997772825746, 9.026627277117408, 9.073036977771006, 9.119210492142399, 9.165151389911681, 9.210863151735564], [0.0, 0.938083151964686, 1.3266499161421599, 1.6248076809271923, 1.876166303929372, 2.0976176963403033, 2.297825058615212, 2.4819347291981715, 2.6532998322843198, 2.814249455894058, 2.9664793948382653, 3.1112698372208096, 3.2496153618543846, 3.3823069050575527, 3.509985754956849, 3.63318042491699, 3.752332607858744, 3.867815921162743, 3.97994974842648, 4.0890096600521755, 4.1952353926806065, 4.298837052040936, 4.4, 4.498888751680798, 4.595650117230424, 4.69041575982343, 4.7833042972405595, 4.874423042781577, 4.963869458396343, 5.0517323761260355, 5.138093031466052, 5.223025942880239, 5.3065996645686395, 5.388877434122993, 5.469917732470938, 5.549774770204643, 5.628498911788116, 5.706137047074843, 5.782732917920384, 5.858327406350725, 5.932958789676531, 6.006662967072483, 6.079473661428266, 6.151422599691879, 6.222539674441619, 6.292853089020909, 6.362389488234747, 6.431174076325411, 6.499230723708769, 6.566582063752802, 6.6332495807108005, 6.6992536897776915, 6.764613810115105, 6.82934843158555, 6.8934751758456345, 6.957010852370435, 7.019971509913698, 7.0823724838503095, 7.144228439796701, 7.205553413860728, 7.26636084983398, 7.326663633605681, 7.386474125047755, 7.445804187594514, 7.504665215717488, 7.5630681604756145, 7.62102355330306, 7.678541528180987, 7.735631842325486, 7.792303895511263, 7.848566748139434, 7.904429138147802, 7.95989949685296, 8.014985963805552, 8.069696400732806, 8.12403840463596, 8.178019320104351, 8.231646250902672, 8.284926070883193, 8.337865434270332, 8.390470785361213, 8.442748367682174, 8.494704232638123, 8.546344247688598, 8.597674104081872, 8.648699324175862, 8.699425268372618, 8.749857141690944, 8.8, 8.849858755935035, 8.899438184514796, 8.948742928478838, 8.997777503361595, 9.046546302318914, 9.09505360072166, 9.143303560529969, 9.191300234460847, 9.23904756996088, 9.28654941299512, 9.333809511662428, 9.38083151964686, 9.427618999514142], [0.0, 0.959166304662544, 1.3564659966250536, 1.6613247725836153, 1.918332609325088, 2.144761058952722, 2.349468024894146, 2.5377155080899043, 2.7129319932501073, 2.877498913987632, 3.0331501776206204, 3.1811947441173736, 3.3226495451672307, 3.458323293158117, 3.5888716889852725, 3.714835124201342, 3.836665218650176, 3.954743986657038, 4.069397989875161, 4.180908992073375, 4.289522117905444, 4.3954521951671826, 4.498888751680798, 4.6000000000000005, 4.698936049788292, 4.79583152331272, 4.8908077042549944, 4.983974317750846, 5.075431016179809, 5.165268628057984, 5.253570214625479, 5.340411969127476, 5.4258639865002145, 5.509990925582366, 5.592852581643825, 5.674504383644443, 5.754997827975264, 5.83438085832593, 5.912698199637794, 5.989991652748776, 6.066300355241241, 6.1416610131136355, 6.216108107168022, 6.289674077406555, 6.362389488234747, 6.434283176858165, 6.505382386916238, 6.575712889109439, 6.645299090334461, 6.714164132637808, 6.782329983125269, 6.8498175158174845, 6.916646586316234, 6.982836100038438, 7.0484040746824395, 7.113367697511497, 7.177743377970545, 7.24154679609267, 7.3047929470998705, 7.367496182557545, 7.429670248402684, 7.491328320131218, 7.552483035399683, 7.6131465242697125, 7.673330437300352, 7.733045971672482, 7.792303895511263, 7.851114570556209, 7.909487973314076, 7.967433714816837, 8.024961059095553, 8.082078940470701, 8.138795979750322, 8.195120499419152, 8.251060537894508, 8.306623862918075, 8.36181798414675, 8.416650165000327, 8.47112743381895, 8.525256594378847, 8.579044235810889, 8.632496741962896, 8.685620300243388, 8.738420909981391, 8.790904390334365, 8.843076387773658, 8.894942383174834, 8.946507698538017, 8.997777503361595, 9.048756820690896, 9.099450532861862, 9.1498633869583, 9.200000000000001, 9.249864863877743, 9.299462350050137, 9.348796714016196, 9.397872099576585, 9.446692542895637, 9.495261976375376, 9.54358423235212, 9.59166304662544, 9.639502061828715], [0.0, 0.9797958971132713, 1.3856406460551018, 1.6970562748477143, 1.9595917942265426, 2.1908902300206647, 2.4000000000000004, 2.5922962793631443, 2.7712812921102037, 2.939387691339814, 3.0983866769659336, 3.2496153618543846, 3.3941125496954285, 3.532704346531139, 3.666060555964672, 3.794733192202055, 3.9191835884530852, 4.039801975344831, 4.156921938165306, 4.270831300812525, 4.3817804600413295, 4.48998886412873, 4.595650117230424, 4.698936049788292, 4.800000000000001, 4.898979485566357, 4.9959983987187195, 5.091168824543143, 5.184592558726289, 5.276362383309168, 5.366563145999495, 5.455272678794342, 5.542562584220407, 5.628498911788117, 5.713142742834281, 5.796550698475776, 5.878775382679628, 5.959865770300536, 6.0398675482166, 6.118823416311343, 6.196773353931867, 6.27375485654325, 6.349803146555018, 6.424951361683604, 6.499230723708769, 6.572670690061993, 6.64529909033446, 6.717142249498666, 6.788225099390857, 6.858571279792899, 6.92820323027551, 6.997142273814362, 7.065408693062278, 7.1330218000508046, 7.2, 7.266360849833981, 7.332121111929344, 7.397296803562772, 7.4619032424710525, 7.525955088890711, 7.58946638440411, 7.652450587883597, 7.714920608794364, 7.776888838089433, 7.8383671769061705, 7.899367063252599, 7.95989949685296, 8.019975062305368, 8.079603950689663, 8.138795979750322, 8.19756061276768, 8.255906976220118, 8.313843876330612, 8.37137981458254, 8.42852300228219, 8.485281374238571, 8.54166260162505, 8.597674104081872, 8.653323061113575, 8.708616422830897, 8.763560920082659, 8.818163074019441, 8.872429205127535, 8.926365441768558, 8.97997772825746, 9.033271832508973, 9.086253353280439, 9.138927727036691, 9.191300234460847, 9.243376006633074, 9.2951600308978, 9.346657156438338, 9.397872099576585, 9.448809448814174, 9.499473669630335, 9.549869109050658, 9.600000000000001, 9.649870465451857, 9.699484522385713, 9.748846085563153, 9.797958971132713, 9.846826900072939], [0.0, 1.0, 1.4142135623730951, 1.7320508075688776, 2.0, 2.23606797749979, 2.4494897427831783, 2.6457513110645907, 2.8284271247461903, 3.0, 3.1622776601683795, 3.3166247903554003, 3.4641016151377553, 3.6055512754639896, 3.7416573867739413, 3.8729833462074166, 4.0, 4.123105625617661, 4.242640687119286, 4.358898943540674, 4.47213595499958, 4.582575694955841, 4.69041575982343, 4.79583152331272, 4.898979485566357, 5.000000000000001, 5.099019513592785, 5.196152422706633, 5.291502622129181, 5.385164807134505, 5.477225575051661, 5.567764362830022, 5.656854249492381, 5.7445626465380295, 5.830951894845301, 5.916079783099616, 6.0, 6.08276253029822, 6.164414002968977, 6.244997998398399, 6.324555320336759, 6.403124237432849, 6.480740698407861, 6.557438524302, 6.6332495807108005, 6.7082039324993685, 6.782329983125269, 6.855654600401045, 6.9282032302755105, 7.0, 7.071067811865476, 7.141428428542851, 7.211102550927979, 7.28010988928052, 7.348469228349535, 7.416198487095664, 7.483314773547883, 7.54983443527075, 7.6157731058639095, 7.681145747868608, 7.745966692414833, 7.810249675906655, 7.874007874011811, 7.937253933193772, 8.0, 8.06225774829855, 8.12403840463596, 8.18535277187245, 8.246211251235321, 8.306623862918075, 8.366600265340756, 8.426149773176359, 8.485281374238571, 8.544003745317532, 8.602325267042627, 8.660254037844387, 8.717797887081348, 8.774964387392123, 8.831760866327848, 8.88819441731559, 8.94427190999916, 9.000000000000002, 9.055385138137417, 9.1104335791443, 9.165151389911681, 9.219544457292889, 9.273618495495704, 9.327379053088816, 9.38083151964686, 9.433981132056603, 9.486832980505138, 9.539392014169458, 9.59166304662544, 9.643650760992957, 9.695359714832659, 9.746794344808963, 9.797958971132713, 9.848857801796106, 9.899494936611665, 9.949874371066201, 10.000000000000002, 10.049875621120892], [0.0, 1.019803902718557, 1.4422205101855958, 1.7663521732655698, 2.039607805437114, 2.280350850198276, 2.4979991993593598, 2.6981475126464085, 2.8844410203711917, 3.059411708155671, 3.22490309931942, 3.382306905057553, 3.5327043465311396, 3.6769552621700474, 3.8157568056677826, 3.9496835316262997, 4.079215610874228, 4.204759208325728, 4.3266615305567875, 4.445222154178575, 4.560701700396552, 4.67332857821917, 4.7833042972405595, 4.8908077042549944, 4.9959983987187195, 5.099019513592785, 5.200000000000001, 5.299056519796709, 5.396295025292817, 5.491812087098393, 5.585696017507576, 5.678027826631356, 5.768882040742383, 5.858327406350725, 5.946427498927402, 6.0332412515993425, 6.118823416311342, 6.20322496770833, 6.2864934582006855, 6.3686733312362644, 6.44980619863884, 6.529931086925804, 6.609084656743324, 6.687301398920195, 6.764613810115106, 6.841052550594828, 6.916646586316234, 6.9914233171794145, 7.065408693062279, 7.138627319029899, 7.211102550927979, 7.282856582413251, 7.353910524340095, 7.424284477308236, 7.493997598078079, 7.563068160475615, 7.631513611335565, 7.699350621968064, 7.766595135579041, 7.833262411026456, 7.899367063252599, 7.964923100695951, 8.029943959953892, 8.094442537939226, 8.158431221748456, 8.221921916437786, 8.284926070883191, 8.347454701883683, 8.409518416651457, 8.47112743381895, 8.532291603080617, 8.593020423576334, 8.653323061113575, 8.713208364316786, 8.772684879784524, 8.831760866327848, 8.89044430835715, 8.948742928478838, 9.006664199358164, 9.064215354899728, 9.121403400793104, 9.178235124467014, 9.234717104492159, 9.290855719469548, 9.34665715643834, 9.402127418834528, 9.457272334029513, 9.512097560475294, 9.566608594481119, 9.620810776644555, 9.67470929795826, 9.728309205612248, 9.781615408509989, 9.834632682515398, 9.887365675446622, 9.939818911831342, 9.991996797437439, 10.043903623591778, 10.09554357129917, 10.146920715172659, 10.19803902718557, 10.248902380255167], [0.0, 1.0392304845413265, 1.469693845669907, 1.8000000000000003, 2.078460969082653, 2.3237900077244507, 2.5455844122715714, 2.749545416973504, 2.939387691339814, 3.117691453623979, 3.286335345030997, 3.4467375879228177, 3.6000000000000005, 3.7469987990390394, 3.8884444190447165, 4.024922359499621, 4.156921938165306, 4.28485705712571, 4.409081537009721, 4.529900661162451, 4.647580015448901, 4.762352359916264, 4.874423042781577, 4.983974317750846, 5.091168824543143, 5.196152422706633, 5.299056519796709, 5.4, 5.499090833947008, 5.596427431853289, 5.692099788303083, 5.786190456595773, 5.878775382679628, 5.969924622639721, 6.059702963017247, 6.148170459575759, 6.235382907247958, 6.321392251711644, 6.406246951218788, 6.489992295835182, 6.572670690061994, 6.654321903845651, 6.7349832961930955, 6.814690014960328, 6.893475175845635, 6.971370023173351, 7.0484040746824395, 7.124605252222751, 7.200000000000001, 7.274613391789285, 7.348469228349535, 7.4215901261117905, 7.493997598078079, 7.565712127751096, 7.636753236814714, 7.707139547199078, 7.776888838089433, 7.846018098373213, 7.914543574963752, 7.982480817390043, 8.049844718999243, 8.11664955508121, 8.182909018191513, 8.248636250920512, 8.313843876330612, 8.378544026261364, 8.442748367682174, 8.506468127254696, 8.56971411425142, 8.632496741962896, 8.694826047713665, 8.756711711595855, 8.818163074019441, 8.879189152169246, 8.939798655450804, 9.0, 9.059801322324901, 9.119210492142399, 9.178235124467015, 9.236882591004392, 9.295160030897803, 9.353074360871938, 9.410632284814875, 9.4678403028357, 9.524704719832528, 9.581231653602789, 9.637427042525408, 9.693296652842108, 9.748846085563153, 9.804080783020915, 9.85900603509299, 9.913626985114984, 9.967948635501692, 10.021975853094041, 10.075713374248, 10.12916580968048, 10.182337649086286, 10.23523326553919, 10.287856919689348, 10.340212763768452, 10.392304845413266, 10.444137111317527], [0.0, 1.0583005244258363, 1.4966629547095764, 1.8330302779823362, 2.1166010488516727, 2.366431913239847, 2.5922962793631443, 2.8000000000000003, 2.993325909419153, 3.1749015732775088, 3.3466401061363023, 3.509985754956849, 3.6660605559646724, 3.815756805667783, 3.9597979746446663, 4.098780306383839, 4.233202097703345, 4.363484845854286, 4.48998886412873, 4.613025037868319, 4.732863826479694, 4.849742261192857, 4.963869458396343, 5.075431016179809, 5.184592558726289, 5.291502622129181, 5.396295025292817, 5.499090833947008, 5.6000000000000005, 5.6991227395100035, 5.796550698475775, 5.892367945062494, 5.986651818838306, 6.079473661428266, 6.1708994482166055, 6.260990336999411, 6.3498031465550175, 6.437390775772433, 6.523802572120037, 6.609084656743323, 6.6932802122726045, 6.776429738438967, 6.8585712797928995, 6.9397406291589885, 7.019971509913698, 7.099295739719539, 7.177743377970545, 7.255342858886822, 7.332121111929345, 7.408103670980854, 7.4833147735478835, 7.557777451076475, 7.631513611335566, 7.70454411370329, 7.776888838089433, 7.848566748139434, 7.919595949289333, 7.989993742175272, 8.059776671843954, 8.12896057316063, 8.197560612767678, 8.26559132790873, 8.333066662399863, 8.4, 8.46640419540669, 8.532291603080616, 8.597674104081872, 8.662563131083086, 8.726969691708572, 8.790904390334365, 8.854377448471462, 8.917398723843181, 8.97997772825746, 9.042123644365851, 9.103845341392834, 9.16515138991168, 9.226050075736637, 9.28654941299512, 9.34665715643834, 9.406380813043878, 9.465727652959387, 9.524704719832526, 9.583318840568753, 9.64157663455516, 9.699484522385713, 9.757048734120374, 9.814275317108239, 9.871170143402454, 9.927738916792686, 9.983987179478948, 10.039920318408907, 10.09554357129917, 10.150862032359617, 10.20588065773846, 10.26060427070453, 10.3150375665821, 10.369185117452577, 10.423051376636307, 10.476640682967036, 10.529957264870548, 10.583005244258363, 10.635788640246666], [0.0, 1.077032961426901, 1.5231546211727818, 1.8654758106177634, 2.154065922853802, 2.4083189157584592, 2.638181191654584, 2.8495613697550017, 3.0463092423455636, 3.2310988842807027, 3.4058772731852804, 3.5721142198983507, 3.7309516212355267, 3.88329756778952, 4.029888335921977, 4.171330722922842, 4.308131845707604, 4.440720662234904, 4.5694638635183455, 4.694677837722201, 4.8166378315169185, 4.935585071701227, 5.0517323761260355, 5.165268628057984, 5.276362383309168, 5.385164807134505, 5.491812087098393, 5.596427431853289, 5.6991227395100035, 5.800000000000001, 5.8991524815010505, 5.99666574022598, 6.092618484691127, 6.187083319303209, 6.280127387243033, 6.371812928829597, 6.462197768561405, 6.551335741663681, 6.639277069079133, 6.726068688320096, 6.811754546370561, 6.896375859826668, 6.97997134664606, 7.06257743320383, 7.144228439796701, 7.224956747275377, 7.3047929470998705, 7.383765976789894, 7.461903242471053, 7.539230729988306, 7.6157731058639095, 7.691553809211766, 7.76659513557904, 7.840918313565065, 7.914543574963752, 7.987490219086344, 8.059776671843954, 8.131420540102448, 8.202438661763953, 8.272847151978574, 8.342661445845684, 8.411896337925237, 8.480566018845677, 8.548684109265006, 8.616263691415208, 8.683317338436964, 8.749857141690944, 8.815894736213677, 8.881441324469808, 8.946507698538017, 9.01110426085505, 9.075241043630742, 9.138927727036691, 9.202173656261873, 9.264987857520376, 9.327379053088816, 9.389355675444403, 9.450925880568528, 9.512097560475294, 9.572878355019457, 9.633275663033837, 9.693296652842108, 9.752948272189288, 9.812237257628864, 9.871170143402454, 9.92975326984513, 9.987992791347018, 10.045894683899489, 10.103464752252071, 10.160708636704431, 10.21763181955584, 10.274239631233058, 10.330537256115967, 10.386529738079028, 10.442221985765292, 10.497618777608567, 10.552724766618336, 10.607544484940897, 10.662082348209472, 10.716342659695053, 10.77032961426901, 10.824047302187848], [0.0, 1.0954451150103321, 1.5491933384829666, 1.8973665961010278, 2.1908902300206643, 2.4494897427831783, 2.6832815729997477, 2.8982753492378874, 3.098386676965933, 3.2863353450309964, 3.4641016151377544, 3.63318042491699, 3.7947331922020555, 3.9496835316262997, 4.098780306383839, 4.242640687119285, 4.381780460041329, 4.516635916254486, 4.6475800154489, 4.774934554525329, 4.898979485566357, 5.019960159204453, 5.138093031466052, 5.253570214625479, 5.366563145999495, 5.477225575051661, 5.585696017507576, 5.692099788303083, 5.796550698475775, 5.8991524815010505, 5.999999999999999, 6.099180272790762, 6.196773353931866, 6.29285308902091, 6.387487769068525, 6.4807406984078595, 6.572670690061993, 6.663332499583072, 6.752777206453652, 6.841052550594828, 6.928203230275509, 7.014271166700073, 7.0992957397195395, 7.183313998427187, 7.26636084983398, 7.348469228349534, 7.429670248402684, 7.5099933422074345, 7.589466384404111, 7.6681158050723255, 7.745966692414834, 7.8230428862431785, 7.899367063252599, 7.974960814950755, 8.049844718999243, 8.12403840463596, 8.197560612767678, 8.270429251254132, 8.342661445845684, 8.41427358718505, 8.48528137423857, 8.555699854482974, 8.625543461139129, 8.694826047713663, 8.763560920082657, 8.831760866327846, 8.899438184514795, 8.966604708583956, 9.033271832508971, 9.09945053286186, 9.16515138991168, 9.23038460737146, 9.2951600308978, 9.359487165438072, 9.423375191511797, 9.486832980505138, 9.549869109050658, 9.612491872558332, 9.67470929795826, 9.736529155710468, 9.797958971132713, 9.85900603509299, 9.919677414109795, 9.979979959899719, 10.039920318408907, 10.099504938362077, 10.158740079360236, 10.21763181955584, 10.276186062932103, 10.33440854621105, 10.392304845413264, 10.449880382090505, 10.507140429250958, 10.564090116995406, 10.620734437881403, 10.67707825203131, 10.73312629199899, 10.788883167408942, 10.844353369380766, 10.89954127475097, 10.954451150103322, 11.009087155618309], [0.0, 1.1135528725660044, 1.5748015748023623, 1.9287301521985913, 2.227105745132009, 2.489979919597747, 2.727636339397171, 2.946183972531247, 3.1496031496047245, 3.340658617698013, 3.521363372331802, 3.693237062523878, 3.8574603043971827, 4.014971979976947, 4.166533331199932, 4.3127717305695645, 4.454211490264018, 4.591296113299599, 4.724404724407087, 4.8538644398046396, 4.979959839195494, 5.10294032886923, 5.223025942880239, 5.340411969127476, 5.455272678794342, 5.567764362830022, 5.678027826631356, 5.786190456595773, 5.892367945062494, 5.99666574022598, 6.099180272790762, 6.2, 6.299206299209449, 6.396874236687791, 6.493073232299171, 6.587867636800241, 6.681317235396026, 6.77347768875044, 6.864400920692206, 6.954135460285484, 7.042726744663604, 7.130217387990355, 7.216647421067487, 7.302054505411473, 7.386474125047756, 7.469939758793239, 7.552483035399683, 7.634133873596926, 7.714920608794365, 7.794870107962031, 7.874007874011811, 7.9523581408284185, 8.029943959953894, 8.106787279804498, 8.182909018191515, 8.258329128825032, 8.333066662399863, 8.40713982279348, 8.480566018845677, 8.553361912137238, 8.625543461139129, 8.69712596206356, 8.76812408671319, 8.838551917593742, 8.908422980528035, 8.977750274985375, 9.046546302318912, 9.114823092084674, 9.182592226599198, 9.249864863877743, 9.316651759081694, 9.38296328459192, 9.448809448814174, 9.514199913813037, 9.579144011862438, 9.643650760992955, 9.707728879609279, 9.771386800244887, 9.834632682515398, 9.897474425326898, 9.959919678390987, 10.02197585309404, 10.083650132764426, 10.144949482377918, 10.20588065773846, 10.26645021416848, 10.32666451474047, 10.386529738079028, 10.446051885760477, 10.505236789335116, 10.564090116995406, 10.6226173799116, 10.680823938254951, 10.73871500692704, 10.796295661012625, 10.853570840972107, 10.910545357588685, 10.967223896684157, 11.023611023616535, 11.079711187571634, 11.135528725660045, 11.191067866830226], [0.0, 1.131370849898476, 1.5999999999999999, 1.9595917942265426, 2.262741699796952, 2.5298221281347035, 2.7712812921102037, 2.993325909419153, 3.1999999999999997, 3.394112549695428, 3.5777087639996634, 3.752332607858744, 3.9191835884530852, 4.079215610874228, 4.233202097703344, 4.381780460041329, 4.525483399593904, 4.66476151587624, 4.8, 4.931531202375181, 5.059644256269407, 5.184592558726289, 5.3065996645686395, 5.4258639865002145, 5.542562584220407, 5.656854249492381, 5.768882040742383, 5.878775382679628, 5.986651818838306, 6.092618484691127, 6.196773353931866, 6.299206299209449, 6.3999999999999995, 6.499230723708768, 6.596969000988257, 6.6932802122726045, 6.788225099390856, 6.881860213634101, 6.974238309665078, 7.0654086930622775, 7.155417527999327, 7.244308110509934, 7.332121111929345, 7.418894796396562, 7.504665215717488, 7.589466384404109, 7.6733304373003515, 7.756287771866126, 7.8383671769061705, 7.919595949289332, 8.0, 8.079603950689663, 8.158431221748456, 8.236504112789602, 8.313843876330612, 8.390470785361213, 8.466404195406689, 8.541662601625049, 8.616263691415206, 8.690224392960172, 8.763560920082657, 8.836288813749809, 8.908422980528034, 8.97997772825746, 9.050966799187808, 9.121403400793103, 9.191300234460845, 9.26066952223218, 9.32952303175248, 9.397872099576585, 9.465727652959385, 9.533100230250387, 9.6, 9.666436778875658, 9.73242004847715, 9.797958971132712, 9.863062404750362, 9.927738916792686, 9.991996797437437, 10.055844071981229, 10.119288512538814, 10.182337649086284, 10.244998779892558, 10.3072789813801, 10.369185117452577, 10.430723848324238, 10.491901638883201, 10.552724766618335, 10.613199329137279, 10.673331251301066, 10.73312629199899, 10.792590050585632, 10.851727973000429, 10.910545357588685, 10.969047360641671, 11.027239001672177, 11.085125168440815, 11.142710621747296, 11.2, 11.256997823576231, 11.313708498984761, 11.370136322841518], [0.0, 1.148912529307606, 1.624807680927192, 1.9899748742132404, 2.297825058615212, 2.5690465157330262, 2.8142494558940583, 3.039736830714133, 3.249615361854384, 3.4467375879228173, 3.6331804249169903, 3.8105117766515306, 3.9799497484264807, 4.1424630354415966, 4.298837052040936, 4.449719092257398, 4.595650117230424, 4.737087712930805, 4.874423042781577, 5.007993610219566, 5.1380930314660525, 5.264978632435274, 5.388877434122993, 5.509990925582366, 5.628498911788117, 5.7445626465380295, 5.858327406350725, 5.969924622639721, 6.079473661428266, 6.187083319303209, 6.29285308902091, 6.396874236687791, 6.499230723708768, 6.600000000000001, 6.6992536897776915, 6.797058187186572, 6.8934751758456345, 6.98856208386246, 7.08237248385031, 7.17495644586084, 7.266360849833981, 7.35662966309981, 7.445804187594515, 7.533923280734945, 7.621023553303061, 7.707139547199078, 7.792303895511264, 7.8765474670060875, 7.9598994968529615, 8.04238770515324, 8.12403840463596, 8.204876598706408, 8.284926070883193, 8.364209466530596, 8.442748367682174, 8.520563361656318, 8.597674104081872, 8.674099376880577, 8.749857141690944, 8.824964589164084, 8.899438184514796, 8.973293709669823, 9.046546302318914, 9.119210492142399, 9.191300234460847, 9.262828941527529, 9.333809511662428, 9.404254356406998, 9.47417542586161, 9.54358423235212, 9.612491872558333, 9.680909048224759, 9.748846085563153, 9.816312953446422, 9.88331928048467, 9.949874371066201, 10.015987220439133, 10.081666528902849, 10.14692071517266, 10.211757928975796, 10.276186062932105, 10.340212763768452, 10.403845442911964, 10.46709128650362, 10.529957264870548, 10.59245014149229, 10.654576481493764, 10.716342659695052, 10.777754868245985, 10.838819123871383, 10.899541274750971, 10.959927007056207, 11.019981851164731, 11.079711187571634, 11.139120252515458, 11.198214143335536, 11.256997823576233, 11.315476127852511, 11.373653766490346, 11.431535329954592, 11.489125293076059, 11.54642801908885], [0.0, 1.1661903789690602, 1.6492422502470643, 2.019900987672416, 2.3323807579381204, 2.60768096208106, 2.8565713714171403, 3.0854497241083028, 3.2984845004941286, 3.4985711369071804, 3.687817782917155, 3.8678159211627436, 4.039801975344832, 4.204759208325728, 4.363484845854286, 4.516635916254486, 4.664761515876241, 4.8083261120685235, 4.947726750741193, 5.083306010855535, 5.21536192416212, 5.344155686354956, 5.469917732470938, 5.592852581643825, 5.713142742834281, 5.830951894845301, 5.946427498927402, 6.059702963017247, 6.1708994482166055, 6.280127387243033, 6.387487769068525, 6.493073232299171, 6.596969000988257, 6.6992536897776915, 6.800000000000001, 6.899275324264136, 6.997142273814361, 7.09365914038728, 7.188880302244572, 7.282856582413251, 7.37563556583431, 7.467261881037788, 7.557777451076475, 7.647221717722064, 7.735631842325487, 7.823042886243178, 7.909487973314076, 7.994998436522674, 8.079603950689664, 8.16333265278342, 8.246211251235321, 8.328265125462806, 8.409518416651457, 8.48999411071645, 8.56971411425142, 8.648699324175862, 8.726969691708572, 8.804544281222055, 8.881441324469808, 8.957678270623477, 9.033271832508971, 9.108238029388561, 9.182592226599196, 9.256349172324908, 9.329523031752482, 9.402127418834526, 9.47417542586161, 9.54567965102538, 9.616652224137047, 9.687104830649869, 9.757048734120374, 9.826494797230598, 9.895453501482386, 9.96393496566492, 10.031948963187562, 10.099504938362077, 10.16661202171107, 10.233279044372825, 10.299514551666988, 10.365326815879952, 10.43072384832424, 10.495713410721542, 10.56030302595527, 10.62449998823474, 10.688311372709911, 10.75174404457249, 10.81480466767662, 10.877499712709719, 10.939835464941876, 11.001818031580052, 11.063453348751466, 11.124747188138704, 11.18570516328765, 11.24633273560764, 11.306635220082057, 11.366617790706258, 11.426285485668561, 11.485643212288984, 11.54469575172945, 11.60344776348823, 11.661903789690601, 11.72006825918689], [0.0, 1.1832159566199232, 1.6733200530681511, 2.04939015319192, 2.3664319132398464, 2.6457513110645907, 2.898275349237888, 3.1304951684997055, 3.3466401061363023, 3.5496478698597693, 3.7416573867739413, 3.924283374069717, 4.09878030638384, 4.266145801540309, 4.427188724235731, 4.58257569495584, 4.732863826479693, 4.878524367060187, 5.019960159204453, 5.157518783291051, 5.291502622129181, 5.422176684690384, 5.549774770204643, 5.674504383644443, 5.796550698475776, 5.916079783099616, 6.0332412515993425, 6.148170459575759, 6.260990336999411, 6.371812928829597, 6.4807406984078595, 6.587867636800241, 6.6932802122726045, 6.797058187186572, 6.899275324264136, 7.0, 7.099295739719539, 7.197221686178633, 7.293833011524188, 7.389181280764467, 7.483314773547883, 7.576278769950325, 7.668115805072326, 7.758865896508328, 7.848566748139434, 7.937253933193771, 8.024961059095553, 8.1117199162693, 8.19756061276768, 8.282511696339462, 8.366600265340756, 8.449852069711044, 8.532291603080617, 8.613942186943213, 8.694826047713663, 8.774964387392123, 8.854377448471462, 8.933084573650918, 9.01110426085505, 9.08845421400141, 9.16515138991168, 9.241212041718336, 9.316651759081692, 9.391485505499118, 9.465727652959385, 9.539392014169456, 9.612491872558332, 9.6850400102426, 9.757048734120374, 9.828529900244492, 9.899494936611665, 9.969954864491614, 10.039920318408907, 10.10940156488009, 10.178408519999577, 10.246950765959598, 10.315037566582102, 10.382677881933928, 10.449880382090507, 10.516653460107925, 10.583005244258363, 10.648943609579309, 10.7144761887831, 10.779610382569492, 10.844353369380768, 10.908712114635716, 10.972693379476162, 11.036303729057115, 11.099549540409287, 11.16243700990066, 11.224972160321824, 11.287160847617969, 11.349008767288886, 11.41052146047673, 11.47170431975999, 11.532562594670795, 11.593101396951552, 11.653325705565774, 11.713240371477058, 11.772850122209151, 11.832159566199232, 11.8911731969558], [0.0, 1.2, 1.697056274847714, 2.078460969082653, 2.4, 2.6832815729997477, 2.939387691339814, 3.1749015732775088, 3.394112549695428, 3.5999999999999996, 3.794733192202055, 3.97994974842648, 4.156921938165306, 4.3266615305567875, 4.48998886412873, 4.6475800154488995, 4.8, 4.947726750741192, 5.091168824543142, 5.230678732248808, 5.366563145999495, 5.499090833947008, 5.628498911788116, 5.754997827975264, 5.878775382679628, 6.0, 6.118823416311342, 6.235382907247958, 6.3498031465550175, 6.462197768561405, 6.572670690061993, 6.681317235396026, 6.788225099390856, 6.8934751758456345, 6.997142273814361, 7.099295739719539, 7.199999999999999, 7.299315036357863, 7.397296803562772, 7.493997598078078, 7.58946638440411, 7.683749084919419, 7.776888838089433, 7.8689262291624, 7.95989949685296, 8.049844718999243, 8.138795979750322, 8.226785520481252, 8.313843876330612, 8.4, 8.48528137423857, 8.56971411425142, 8.653323061113575, 8.736131867136622, 8.818163074019441, 8.899438184514796, 8.97997772825746, 9.0598013223249, 9.13892772703669, 9.21737489744233, 9.295160030897799, 9.372299611087985, 9.448809448814172, 9.524704719832526, 9.6, 9.674709297958259, 9.748846085563152, 9.82242332624694, 9.895453501482384, 9.96794863550169, 10.039920318408907, 10.111379727811629, 10.182337649086284, 10.252804494381037, 10.322790320451151, 10.392304845413264, 10.461357464497617, 10.529957264870546, 10.598113039593418, 10.665833300778706, 10.73312629199899, 10.8, 10.8664621657649, 10.932520294973157, 10.998181667894016, 11.063453348751464, 11.128342194594845, 11.192854863706579, 11.256997823576231, 11.320777358467923, 11.384199576606164, 11.447270417003347, 11.509995655950528, 11.572380913191546, 11.63443165779919, 11.696153213770755, 11.757550765359255, 11.818629362155326, 11.879393923933998, 11.93984924527944, 12.0, 12.05985074534507], [0.0, 1.216552506059644, 1.7204650534085253, 2.107130750570548, 2.433105012119288, 2.720294101747089, 2.979932885150268, 3.2186953878862163, 3.4409301068170506, 3.6496575181789317, 3.847076812334269, 4.034848200366404, 4.214261501141096, 4.386342439892262, 4.551922670696417, 4.711687595755898, 4.866210024238576, 5.015974481593781, 5.1613951602255765, 5.302829433425142, 5.440588203494178, 5.574943945906542, 5.706137047074843, 5.83438085832593, 5.959865770300536, 6.08276253029822, 6.20322496770833, 6.321392251711644, 6.437390775772433, 6.551335741663681, 6.663332499583072, 6.77347768875044, 6.881860213634101, 6.98856208386246, 7.09365914038728, 7.197221686178633, 7.299315036357863, 7.4, 7.4993333037010705, 7.597367965289033, 7.694153624668538, 7.78973683766018, 7.88416133777081, 7.977468270071652, 8.069696400732807, 8.160882305241266, 8.251060537894508, 8.340263784797218, 8.428523002282192, 8.515867542417508, 8.602325267042628, 8.68792265158939, 8.772684879784524, 8.856635930193812, 8.939798655450804, 9.02219485491197, 9.103845341392834, 9.184770002564028, 9.264987857520376, 9.344517108978932, 9.423375191511797, 9.501578816175762, 9.579144011862438, 9.65608616365865, 9.732420048477152, 9.808159868191382, 9.88331928048467, 9.957911427603682, 10.031948963187562, 10.105444077327824, 10.178408519999579, 10.250853622991599, 10.322790320451153, 10.394229168149026, 10.465180361560904, 10.53565375285274, 10.605658866850284, 10.675204916066015, 10.744300814850636, 10.812955192730618, 10.881176406988356, 10.948972554536796, 11.016351483136331, 11.083320801997928, 11.149887891813083, 11.216059914247962, 11.281843820936365, 11.347246362003428, 11.412274094149685, 11.476933388322859, 11.541230437002808, 11.605171261123207, 11.66876171665186, 11.732007500849972, 11.794914158229385, 11.85748708622531, 11.919731540601072, 11.98165264060013, 12.043255373859678, 12.10454460109921, 12.16552506059644, 12.226201372462342], [0.0, 1.2328828005937953, 1.7435595774162695, 2.1354156504062627, 2.4657656011875906, 2.7568097504180447, 3.0199337741083, 3.2619012860600183, 3.487119154832539, 3.698648401781386, 3.898717737923586, 4.0890096600521755, 4.270831300812525, 4.445222154178574, 4.613025037868319, 4.774934554525329, 4.931531202375181, 5.083306010855534, 5.230678732248808, 5.374011537017762, 5.513619500836089, 5.649778756730214, 5.782732917920384, 5.912698199637794, 6.0398675482166, 6.164414002968977, 6.2864934582006855, 6.406246951218788, 6.523802572120037, 6.639277069079133, 6.752777206453652, 6.864400920692206, 6.974238309665078, 7.08237248385031, 7.188880302244572, 7.293833011524188, 7.397296803562772, 7.4993333037010705, 7.6000000000000005, 7.6993506219680645, 7.797435475847172, 7.894301742396221, 7.9899937421752725, 8.084553172563094, 8.178019320104351, 8.270429251254132, 8.36181798414675, 8.452218643646177, 8.54166260162505, 8.630179604156568, 8.717797887081348, 8.804544281222057, 8.890444308357148, 8.975522268926753, 9.059801322324901, 9.143303560529969, 9.226050075736637, 9.308061022576076, 9.389355675444403, 9.469952481401371, 9.549869109050658, 9.629122493768579, 9.707728879609277, 9.785703858180055, 9.863062404750362, 9.939818911831342, 10.015987220439133, 10.091580649234292, 10.166612021711067, 10.241093691593687, 10.315037566582102, 10.388455130576443, 10.461357464497617, 10.533755265810955, 10.605658866850282, 10.677078252031311, 10.748023074035524, 10.818502669038818, 10.888526071052961, 10.95810202544218, 11.027239001672179, 11.095945205344158, 11.164228589562292, 11.232096865679178, 11.299557513460428, 11.36661779070626, 11.433284742365162, 11.499565209172042, 11.565465835840769, 11.63099307883897, 11.696153213770756, 11.760952342391326, 11.825396399275588, 11.889491158161482, 11.95324223798715, 12.016655108639842, 12.0797350964332, 12.142487389328434, 12.204917041913886, 12.267028980156525, 12.328828005937954, 12.390318801386833], [0.0, 1.2489995996796799, 1.7663521732655694, 2.163330765278394, 2.4979991993593598, 2.7928480087537886, 3.0594117081556713, 3.3045423283716615, 3.5327043465311387, 3.746998799039039, 3.9496835316263, 4.1424630354415966, 4.326661530556788, 4.503332099679081, 4.673328578219169, 4.8373546489791295, 4.9959983987187195, 5.149757275833494, 5.299056519796709, 5.444263035526481, 5.585696017507577, 5.723635208501674, 5.858327406350725, 5.989991652748776, 6.118823416311343, 6.244997998398399, 6.3686733312362644, 6.489992295835182, 6.609084656743323, 6.726068688320096, 6.841052550594828, 6.954135460285484, 7.0654086930622775, 7.17495644586084, 7.282856582413251, 7.389181280764467, 7.493997598078078, 7.597367965289033, 7.6993506219680645, 7.800000000000002, 7.8993670632526, 7.997499609252883, 8.094442537939226, 8.190238091777308, 8.284926070883193, 8.378544026261364, 8.47112743381895, 8.562709851443058, 8.653323061113577, 8.742997197757758, 8.831760866327848, 8.919641248391105, 9.006664199358163, 9.092854337335446, 9.178235124467014, 9.26282894152753, 9.346657156438338, 9.429740187301027, 9.512097560475294, 9.593747964169166, 9.674709297958259, 9.75499871860576, 9.834632682515398, 9.913626985114984, 9.991996797437439, 10.069756700139283, 10.146920715172659, 10.223502335305646, 10.299514551666988, 10.374969879474351, 10.449880382090507, 10.524257693538296, 10.598113039593418, 10.671457257563281, 10.744300814850634, 10.816653826391969, 10.888526071052961, 10.959927007056207, 11.030865786510144, 11.101351269102336, 11.171392035015154, 11.240996397117119, 11.310172412478956, 11.37892789325954, 11.447270417003349, 11.515207336387826, 11.582745788456208, 11.649892703368561, 11.71665481270145, 11.783038657324349, 11.8490505948789, 11.914696806885186, 11.979983305497552, 12.04491593993084, 12.109500402576485, 12.17374223482656, 12.237646832622685, 12.301219451745427, 12.364465212858986, 12.427389106324789, 12.489995996796798, 12.552290627610565], [0.0, 1.2649110640673518, 1.7888543819998317, 2.1908902300206647, 2.5298221281347035, 2.8284271247461903, 3.0983866769659336, 3.3466401061363023, 3.5777087639996634, 3.794733192202055, 4.0, 4.1952353926806065, 4.3817804600413295, 4.560701700396552, 4.732863826479693, 4.898979485566356, 5.059644256269407, 5.215361924162119, 5.366563145999495, 5.513619500836089, 5.656854249492381, 5.796550698475776, 5.932958789676531, 6.066300355241241, 6.196773353931867, 6.324555320336759, 6.44980619863884, 6.572670690061994, 6.6932802122726045, 6.811754546370561, 6.928203230275509, 7.042726744663604, 7.155417527999327, 7.266360849833981, 7.37563556583431, 7.483314773547883, 7.58946638440411, 7.694153624668538, 7.797435475847172, 7.8993670632526, 8.0, 8.099382692526635, 8.19756061276768, 8.294576541331088, 8.390470785361213, 8.48528137423857, 8.579044235810887, 8.67179335547152, 8.763560920082659, 8.854377448471462, 8.94427190999916, 9.033271832508973, 9.121403400793104, 9.208691546577072, 9.2951600308978, 9.38083151964686, 9.465727652959385, 9.549869109050658, 9.633275663033837, 9.715966241192895, 9.797958971132712, 9.879271228182775, 9.959919678390985, 10.039920318408907, 10.119288512538814, 10.198039027185569, 10.276186062932103, 10.353743284435827, 10.430723848324238, 10.507140429250958, 10.583005244258363, 10.658330075579382, 10.73312629199899, 10.807404868885037, 10.881176406988354, 10.954451150103322, 11.027239001672179, 11.099549540409287, 11.171392035015154, 11.242775458044157, 11.313708498984761, 11.384199576606166, 11.454256850621084, 11.523888232710346, 11.593101396951552, 11.661903789690601, 11.730302638892145, 11.798304963002101, 11.865917579353061, 11.933147112141038, 12.0, 12.066482503198685, 12.132600710482482, 12.198360545581526, 12.263767773404714, 12.328828005937952, 12.393546707863734, 12.45792920191795, 12.521980673998822, 12.58570617804182, 12.649110640673518, 12.712198865656564], [0.0, 1.2806248474865698, 1.8110770276274835, 2.2181073012818837, 2.5612496949731396, 2.863564212655271, 3.136877428271625, 3.3882148692194836, 3.622154055254967, 3.8418745424597094, 4.049691346263318, 4.247352116319061, 4.436214602563767, 4.617358552246079, 4.791659420284376, 4.959838707054898, 5.122499389946279, 5.280151512977635, 5.43323108288245, 5.582114294781146, 5.727128425310542, 5.868560300448484, 6.006662967072483, 6.1416610131136355, 6.27375485654325, 6.403124237432849, 6.529931086925804, 6.654321903845651, 6.776429738438967, 6.896375859826668, 7.014271166700073, 7.130217387990355, 7.244308110509934, 7.35662966309981, 7.467261881037788, 7.576278769950325, 7.683749084919419, 7.78973683766018, 7.894301742396221, 7.997499609252883, 8.099382692526635, 8.200000000000001, 8.299397568498573, 8.397618710086807, 8.494704232638123, 8.590692637965812, 8.685620300243386, 8.779521627059188, 8.872429205127535, 8.964373932405989, 9.055385138137417, 9.145490692138942, 9.234717104492159, 9.323089616645333, 9.410632284814874, 9.497368056467014, 9.583318840568753, 9.668505572217457, 9.752948272189288, 9.836666101886351, 9.919677414109795, 10.001999800039991, 10.083650132764426, 10.16464460765845, 10.244998779892558, 10.324727599312245, 10.403845442911964, 10.482366145102928, 10.56030302595527, 10.637668917577761, 10.7144761887831, 10.79073676817297, 10.8664621657649, 10.941663493271944, 11.01635148313633, 11.090536506409418, 11.164228589562292, 11.23743743030412, 11.310172412478956, 11.382442620105758, 11.454256850621084, 11.52562362737913, 11.596551211459381, 11.667047612828192, 11.737120600896969, 11.806777714516354, 11.87602627144282, 11.944873377311291, 12.013325934144966, 12.081390648431166, 12.149074038789953, 12.216382443260363, 12.283322026227271, 12.349898785010348, 12.416118556135007, 12.48198702130394, 12.5475097130865, 12.61269202034205, 12.677539193392384, 12.742056348957183, 12.806248474865699, 12.870120434556938], [0.0, 1.2961481396815722, 1.8330302779823362, 2.2449944320643653, 2.5922962793631443, 2.8982753492378883, 3.174901573277509, 3.4292856398964497, 3.6660605559646724, 3.8884444190447165, 4.09878030638384, 4.298837052040936, 4.489988864128731, 4.67332857821917, 4.849742261192857, 5.019960159204453, 5.184592558726289, 5.344155686354956, 5.499090833947008, 5.649778756730215, 5.796550698475777, 5.939696961967, 6.079473661428266, 6.216108107168022, 6.349803146555018, 6.480740698407861, 6.609084656743324, 6.7349832961930955, 6.8585712797928995, 6.97997134664606, 7.0992957397195395, 7.216647421067487, 7.332121111929345, 7.445804187594515, 7.557777451076475, 7.668115805072326, 7.776888838089433, 7.88416133777081, 7.9899937421752725, 8.094442537939226, 8.19756061276768, 8.299397568498573, 8.400000000000002, 8.499411744350311, 8.597674104081872, 8.694826047713663, 8.790904390334365, 8.885943956609225, 8.979977728257461, 9.073036977771006, 9.165151389911681, 9.25634917232491, 9.34665715643834, 9.436100889668362, 9.524704719832528, 9.612491872558333, 9.699484522385713, 9.785703858180055, 9.871170143402454, 9.955902771722915, 10.039920318408907, 10.123240587875012, 10.20588065773846, 10.287856919689348, 10.369185117452577, 10.449880382090505, 10.529957264870548, 10.609429767899876, 10.688311372709911, 10.766615066955818, 10.84435336938077, 10.92153835318084, 10.998181667894016, 11.074294559925702, 11.149887891813083, 11.224972160321824, 11.29955751346043, 11.373653766490346, 11.44727041700335, 11.520416659131737, 11.593101396951553, 11.66533325713415, 11.73712060089697, 11.80847153530041, 11.879393923934, 11.949895397031726, 12.019983361053377, 12.089665007765932, 12.158947322856532, 12.227837094106219, 12.296340919151518, 12.364465212858986, 12.432216214336044, 12.499599993599798, 12.566622457924009, 12.633289357883006, 12.699606293110037, 12.76557871778636, 12.831211945876353, 12.89651115612281, 12.961481396815723, 13.026127590347027], [0.0, 1.3114877048604001, 1.8547236990991405, 2.2715633383201097, 2.6229754097208002, 2.932575659723036, 3.212475680841802, 3.4698703145794942, 3.709447398198281, 3.9344631145812, 4.147288270665544, 4.349712634186309, 4.543126676640219, 4.728636167014756, 4.907137658554118, 5.079370039680117, 5.2459508194416005, 5.407402333838309, 5.564171097297422, 5.716642371182581, 5.865151319446072, 6.009991680526688, 6.151422599691879, 6.289674077406555, 6.424951361683604, 6.557438524302, 6.687301398920195, 6.814690014960328, 6.9397406291589885, 7.06257743320383, 7.183313998427187, 7.302054505411473, 7.418894796396562, 7.533923280734945, 7.647221717722064, 7.758865896508328, 7.8689262291624, 7.977468270071652, 8.084553172563094, 8.190238091777308, 8.294576541331088, 8.397618710086807, 8.499411744350311, 8.599999999999998, 8.699425268372618, 8.797726979169106, 8.894942383174834, 8.991106717195608, 9.086253353280439, 9.1804139340228, 9.273618495495704, 9.365895579174477, 9.457272334029511, 9.547774609824009, 9.637427042525406, 9.726253132630262, 9.814275317108237, 9.90151503558925, 9.987992791347018, 10.07372820757042, 10.158740079360234, 10.243046421841502, 10.326664514740468, 10.409610943738484, 10.491901638883201, 10.57355191030904, 10.654576481493761, 10.734989520255713, 10.814804667676619, 10.894035065117057, 10.972693379476162, 11.050791826833043, 11.128342194594843, 11.20535586226515, 11.281843820936361, 11.357816691600547, 11.433284742365162, 11.508257904652641, 11.582745788456208, 11.656757696718243, 11.730302638892145, 11.8033893437436, 11.876026271442818, 11.948221624995076, 12.019983361053376, 12.091319200153471, 12.162236636408617, 12.232742946698421, 12.302845199383759, 12.372550262577233, 12.44186481199663, 12.51079533842673, 12.57934815481311, 12.647529403009901, 12.715345060201866, 12.782800945019833, 12.849902723367208, 12.916655913974019, 12.983065893693984, 13.049137902558927, 13.114877048604, 13.180288312476325], [0.0, 1.32664991614216, 1.876166303929372, 2.297825058615212, 2.65329983228432, 2.9664793948382657, 3.2496153618543846, 3.509985754956849, 3.752332607858744, 3.97994974842648, 4.1952353926806065, 4.4, 4.595650117230424, 4.7833042972405595, 4.963869458396343, 5.138093031466052, 5.30659966456864, 5.469917732470938, 5.628498911788116, 5.782732917920385, 5.9329587896765315, 6.079473661428266, 6.222539674441619, 6.362389488234747, 6.499230723708769, 6.6332495807108005, 6.764613810115106, 6.893475175845635, 7.019971509913698, 7.144228439796701, 7.26636084983398, 7.386474125047756, 7.504665215717488, 7.621023553303061, 7.735631842325487, 7.848566748139434, 7.95989949685296, 8.069696400732807, 8.178019320104351, 8.284926070883193, 8.390470785361213, 8.494704232638123, 8.597674104081872, 8.699425268372618, 8.8, 8.899438184514796, 8.997777503361595, 9.09505360072166, 9.191300234460847, 9.28654941299512, 9.38083151964686, 9.474175425861612, 9.566608594481119, 9.65815717411971, 9.748846085563153, 9.838699100999076, 9.927738916792686, 10.015987220439133, 10.103464752252073, 10.190191362285598, 10.276186062932103, 10.361467077590895, 10.446051885760477, 10.529957264870548, 10.61319932913728, 10.69579356569675, 10.777754868245985, 10.859097568398584, 10.939835464941876, 11.01998185116473, 11.099549540409289, 11.178550889985697, 11.256997823576231, 11.334901852243805, 11.412274094149685, 11.489125293076059, 11.56546583584077, 11.6413057686842, 11.71665481270145, 11.791522378386942, 11.865917579353063, 11.939849245279442, 12.013325934144968, 12.086355943790503, 12.158947322856532, 12.231107881136525, 12.30284519938376, 12.374166638606416, 12.445079348883239, 12.515590277729613, 12.58570617804182, 12.655433615645101, 12.724778976469494, 12.793748473375583, 12.862348152650823, 12.93058390019569, 12.998461447417538, 13.065986376848862, 13.133164127505603, 13.200000000000003, 13.266499161421601, 13.332666649999169], [0.0, 1.3416407864998738, 1.8973665961010273, 2.32379000772445, 2.6832815729997477, 3.0, 3.2863353450309964, 3.5496478698597693, 3.7947331922020546, 4.024922359499621, 4.242640687119285, 4.449719092257398, 4.6475800154489, 4.8373546489791295, 5.0199601592044525, 5.196152422706631, 5.366563145999495, 5.531726674375732, 5.692099788303082, 5.848076606885378, 6.0, 6.148170459575759, 6.292853089020909, 6.434283176858165, 6.572670690061993, 6.7082039324993685, 6.841052550594828, 6.971370023173351, 7.099295739719539, 7.224956747275377, 7.348469228349534, 7.469939758793239, 7.589466384404109, 7.707139547199078, 7.823042886243178, 7.937253933193771, 8.049844718999243, 8.160882305241266, 8.270429251254132, 8.378544026261364, 8.48528137423857, 8.590692637965812, 8.694826047713663, 8.797726979169106, 8.899438184514796, 8.999999999999998, 9.09945053286186, 9.197825830053535, 9.2951600308978, 9.391485505499116, 9.486832980505138, 9.581231653602787, 9.674709297958259, 9.767292357659825, 9.859006035092989, 9.9498743710662, 10.039920318408905, 10.129165809680478, 10.21763181955584, 10.3053384223906, 10.392304845413262, 10.478549517943787, 10.564090116995404, 10.648943609579309, 10.73312629199899, 10.816653826391967, 10.89954127475097, 10.981803130633875, 11.063453348751464, 11.144505372604025, 11.224972160321824, 11.304866208850061, 11.384199576606164, 11.462983904725679, 11.541230437002806, 11.61895003862225, 11.696153213770756, 11.77285012220915, 11.8490505948789, 11.924764148611073, 12.0, 12.074767078498864, 12.149074038789953, 12.222929272478016, 12.296340919151518, 12.36931687685298, 12.441864811996632, 12.513992168768526, 12.585706178041818, 12.65701386583739, 12.727922061357855, 12.798437404620923, 12.86856635371633, 12.938315191708694, 13.007690033207279, 13.07669683062202, 13.145341380123986, 13.213629327327144, 13.281566172707192, 13.349157276772193, 13.416407864998737, 13.48332303254654], [0.0, 1.3564659966250536, 1.9183326093250879, 2.3494680248941466, 2.7129319932501073, 3.0331501776206204, 3.32264954516723, 3.5888716889852725, 3.8366652186501757, 4.069397989875161, 4.2895221179054435, 4.498888751680798, 4.698936049788293, 4.890807704254994, 5.075431016179809, 5.253570214625478, 5.4258639865002145, 5.592852581643825, 5.754997827975264, 5.912698199637794, 6.066300355241241, 6.216108107168022, 6.362389488234747, 6.505382386916238, 6.64529909033446, 6.782329983125269, 6.916646586316234, 7.0484040746824395, 7.177743377970545, 7.3047929470998705, 7.429670248402684, 7.552483035399683, 7.6733304373003515, 7.792303895511264, 7.909487973314076, 8.024961059095553, 8.138795979750322, 8.251060537894508, 8.36181798414675, 8.47112743381895, 8.579044235810887, 8.685620300243386, 8.790904390334365, 8.894942383174834, 8.997777503361595, 9.09945053286186, 9.200000000000001, 9.299462350050137, 9.397872099576587, 9.495261976375376, 9.59166304662544, 9.687104830649869, 9.781615408509987, 9.875221516502808, 9.96794863550169, 10.059821071967434, 10.150862032359617, 10.241093691593687, 10.330537256115967, 10.419213022104884, 10.507140429250956, 10.594338110519223, 10.680823938254951, 10.766615066955817, 10.851727973000429, 10.936178491593852, 11.01998185116473, 11.103152705425607, 11.18570516328765, 11.26765281680262, 11.349008767288886, 11.42978564978364, 11.509995655950528, 11.589650555560336, 11.668761716651858, 11.747340124470732, 11.825396399275588, 11.90294081309321, 11.979983305497552, 12.05653349848123, 12.132600710482482, 12.208193969625484, 12.283322026227271, 12.357993364620325, 12.432216214336044, 12.505998560690786, 12.579348154813111, 12.652272523147769, 12.724778976469494, 12.796874618437112, 12.86856635371633, 12.93986089569745, 13.010764773832475, 13.081284340614268, 13.15142577821888, 13.221195104830727, 13.29059818066892, 13.35964071373179, 13.428328265275615, 13.496666255042392, 13.564659966250538, 13.63231455036158], [0.0, 1.3711309200802089, 1.9390719429665315, 2.374868417407584, 2.7422618401604177, 3.0659419433511785, 3.358571124749333, 3.627671429443411, 3.878143885933063, 4.113392760240626, 4.33589667773576, 4.54752680036083, 4.749736834815168, 4.94368283772331, 5.130302135352264, 5.310367218940701, 5.4845236803208355, 5.653317610041028, 5.817215828899595, 5.976621118993575, 6.131883886702357, 6.2833112289620034, 6.431174076325411, 6.575712889109439, 6.717142249498666, 6.855654600401045, 6.9914233171794145, 7.124605252222751, 7.255342858886822, 7.383765976789894, 7.5099933422074345, 7.634133873596926, 7.756287771866126, 7.8765474670060875, 7.994998436522674, 8.1117199162693, 8.226785520481252, 8.340263784797218, 8.452218643646177, 8.562709851443058, 8.67179335547152, 8.779521627059188, 8.885943956609225, 8.991106717195608, 9.09505360072166, 9.197825830053535, 9.299462350050137, 9.4, 9.499473669630335, 9.597916440561463, 9.695359714832659, 9.79183333191492, 9.88736567544662, 9.981983770774226, 10.075713374248, 10.16857905510893, 10.260604270704528, 10.351811435686027, 10.442221985765292, 10.531856436545269, 10.620734437881403, 10.708874824182043, 10.796295661012623, 10.883014288330234, 10.969047360641671, 11.054410884348382, 11.139120252515456, 11.22319027727856, 11.306635220082056, 11.38946881992308, 11.47170431975999, 11.553354491228944, 11.63443165779919, 11.714947716485977, 11.794914158229384, 11.874342087037917, 11.95324223798715, 12.031624994156028, 12.109500402576485, 12.1868781892657, 12.263767773404714, 12.34017828072188, 12.416118556135006, 12.491597175701752, 12.566622457924007, 12.641202474448386, 12.715345060201868, 12.789057822998535, 12.862348152650823, 12.935223229616101, 13.007690033207279, 13.079755349393963, 13.151425778218877, 13.222707740852478, 13.293607486307094, 13.36413109783049, 13.434284498997332, 13.504073459515837, 13.573503600765722, 13.642580401082489, 13.71130920080209, 13.779695207079149], [0.0, 1.385640646055102, 1.9595917942265426, 2.400000000000001, 2.771281292110204, 3.098386676965934, 3.3941125496954285, 3.6660605559646724, 3.9191835884530852, 4.156921938165306, 4.3817804600413295, 4.595650117230424, 4.800000000000002, 4.9959983987187195, 5.184592558726289, 5.366563145999495, 5.542562584220408, 5.713142742834281, 5.8787753826796285, 6.039867548216601, 6.196773353931868, 6.349803146555018, 6.499230723708769, 6.645299090334461, 6.788225099390857, 6.9282032302755105, 7.065408693062279, 7.200000000000001, 7.332121111929345, 7.461903242471053, 7.589466384404111, 7.714920608794365, 7.8383671769061705, 7.9598994968529615, 8.079603950689664, 8.19756061276768, 8.313843876330612, 8.428523002282192, 8.54166260162505, 8.653323061113577, 8.763560920082659, 8.872429205127535, 8.979977728257461, 9.086253353280439, 9.191300234460847, 9.2951600308978, 9.397872099576587, 9.499473669630335, 9.600000000000003, 9.699484522385713, 9.797958971132713, 9.895453501482388, 9.991996797437439, 10.087616170334796, 10.182337649086286, 10.276186062932105, 10.369185117452577, 10.461357464497619, 10.552724766618338, 10.643307756520057, 10.73312629199899, 10.822199406774947, 10.910545357588685, 10.998181667894018, 11.085125168440817, 11.171392035015154, 11.256997823576233, 11.341957503006261, 11.426285485668561, 11.50999565595053, 11.593101396951553, 11.67561561546114, 11.757550765359257, 11.838918869558995, 11.919731540601072, 12.000000000000002, 12.079735096433202, 12.158947322856532, 12.237646832622687, 12.315843454672525, 12.393546707863736, 12.470765814495918, 12.5475097130865, 12.623787070447602, 12.699606293110037, 12.774975538137053, 12.84990272336721, 12.924395537122813, 12.998461447417538, 13.072107710694555, 13.145341380123988, 13.218169313486646, 13.290598180668923, 13.362634470792056, 13.434284498997334, 13.505554412907307, 13.576450198781714, 13.646977687385588, 13.717142559585799, 13.78695035169127, 13.856406460551021, 13.925516148423371], [0.0, 1.4000000000000001, 1.979898987322333, 2.4248711305964283, 2.8000000000000003, 3.130495168499706, 3.4292856398964493, 3.704051835490427, 3.959797974644666, 4.2, 4.427188724235731, 4.64327470649756, 4.849742261192857, 5.047771785649585, 5.238320341483518, 5.422176684690383, 5.6000000000000005, 5.772347875864725, 5.939696961966999, 6.102458520956944, 6.260990336999412, 6.4156059729381765, 6.566582063752802, 6.714164132637808, 6.858571279792899, 7.0, 7.138627319029899, 7.274613391789285, 7.408103670980854, 7.539230729988306, 7.6681158050723255, 7.794870107962031, 7.919595949289332, 8.04238770515324, 8.16333265278342, 8.282511696339462, 8.4, 8.515867542417508, 8.630179604156568, 8.742997197757758, 8.854377448471462, 8.964373932405989, 9.073036977771006, 9.1804139340228, 9.28654941299512, 9.391485505499116, 9.495261976375376, 9.597916440561463, 9.699484522385713, 9.8, 9.899494936611665, 9.997999799959992, 10.09554357129917, 10.192153844992726, 10.287856919689348, 10.382677881933928, 10.476640682967036, 10.569768209379049, 10.662082348209472, 10.75360404701605, 10.844353369380766, 10.934349546269315, 11.023611023616535, 11.11215550647128, 11.200000000000001, 11.287160847617969, 11.373653766490344, 11.45949388062143, 11.54469575172945, 11.629273408085306, 11.713240371477058, 11.796609682446903, 11.879393923933998, 11.961605243444543, 12.043255373859678, 12.12435565298214, 12.204917041913887, 12.284950142348972, 12.364465212858986, 12.443472184241825, 12.521980673998824, 12.600000000000001, 12.677539193392384, 12.754607010802019, 12.831211945876353, 12.907362240210043, 12.983065893693986, 13.058330674324342, 13.133164127505603, 13.207573584879245, 13.281566172707194, 13.35514881983724, 13.428328265275615, 13.501111065390138, 13.573503600765722, 13.645512082732548, 13.717142559585797, 13.788400922514548, 13.85929291125633, 13.92982411949268, 14.0, 14.069825869569248], [0.0, 1.4142135623730951, 2.0, 2.4494897427831783, 2.8284271247461903, 3.1622776601683795, 3.464101615137755, 3.7416573867739418, 4.0, 4.242640687119285, 4.47213595499958, 4.69041575982343, 4.898979485566357, 5.099019513592785, 5.291502622129181, 5.477225575051661, 5.656854249492381, 5.830951894845301, 6.0, 6.164414002968978, 6.324555320336759, 6.480740698407861, 6.6332495807108005, 6.782329983125269, 6.92820323027551, 7.071067811865476, 7.211102550927979, 7.348469228349535, 7.4833147735478835, 7.6157731058639095, 7.745966692414834, 7.874007874011811, 8.0, 8.12403840463596, 8.246211251235321, 8.366600265340756, 8.48528137423857, 8.602325267042628, 8.717797887081348, 8.831760866327848, 8.94427190999916, 9.055385138137417, 9.165151389911681, 9.273618495495704, 9.38083151964686, 9.486832980505138, 9.59166304662544, 9.695359714832659, 9.797958971132713, 9.899494936611665, 10.000000000000002, 10.09950493836208, 10.19803902718557, 10.295630140987003, 10.392304845413264, 10.488088481701517, 10.583005244258363, 10.677078252031311, 10.77032961426901, 10.862780491200215, 10.954451150103322, 11.045361017187261, 11.135528725660043, 11.224972160321824, 11.313708498984761, 11.40175425099138, 11.489125293076057, 11.575836902790225, 11.661903789690601, 11.747340124470732, 11.832159566199234, 11.916375287812986, 12.0, 12.083045973594572, 12.165525060596439, 12.247448713915892, 12.328828005937956, 12.409673645990857, 12.489995996796798, 12.569805089976535, 12.649110640673518, 12.727922061357857, 12.806248474865699, 12.884098726725126, 12.961481396815723, 13.038404810405298, 13.114877048604002, 13.19090595827292, 13.266499161421601, 13.341664064126334, 13.416407864998739, 13.490737563232042, 13.564659966250538, 13.638181696985857, 13.71130920080209, 13.784048752090222, 13.85640646055102, 13.928388277184121, 14.0, 14.07124727947029, 14.142135623730953, 14.212670403551897], [0.0, 1.4282856857085702, 2.0199009876724157, 2.473863375370597, 2.8565713714171403, 3.193743884534263, 3.498571136907181, 3.7788887255382373, 4.039801975344831, 4.28485705712571, 4.5166359162544865, 4.737087712930806, 4.947726750741194, 5.149757275833494, 5.344155686354956, 5.531726674375732, 5.713142742834281, 5.888972745734184, 6.059702963017248, 6.225752966509353, 6.387487769068526, 6.54522726878143, 6.6992536897776915, 6.8498175158174845, 6.997142273814362, 7.141428428542851, 7.282856582413251, 7.4215901261117905, 7.557777451076475, 7.691553809211766, 7.8230428862431785, 7.9523581408284185, 8.079603950689663, 8.204876598706408, 8.328265125462806, 8.449852069711044, 8.56971411425142, 8.68792265158939, 8.804544281222057, 8.919641248391105, 9.033271832508973, 9.145490692138942, 9.25634917232491, 9.365895579174477, 9.474175425861612, 9.581231653602787, 9.687104830649869, 9.79183333191492, 9.895453501482388, 9.997999799959992, 10.09950493836208, 10.200000000000003, 10.299514551666988, 10.398076745244769, 10.495713410721542, 10.59245014149229, 10.688311372709911, 10.783320453366859, 10.87749971270972, 10.970870521521983, 11.063453348751464, 11.155267813907473, 11.24633273560764, 11.336666176614711, 11.426285485668561, 11.515207336387826, 11.60344776348823, 11.691022196540388, 11.777945491468367, 11.864231959971114, 11.949895397031726, 12.034949106664309, 12.119405926034496, 12.203278248077442, 12.286578042726136, 12.369316876852983, 12.451505933018707, 12.533156027114641, 12.614277624977186, 12.694880858046682, 12.774975538137053, 12.854571171377131, 12.933676971379796, 13.012301871690498, 13.09045453756286, 13.168143377105219, 13.24537655183876, 13.322161986704712, 13.398507379555383, 13.47442021016118, 13.54990774876346, 13.62497706420088, 13.699635031634969, 13.773888339898798, 13.847743498491011, 13.921206844235885, 13.994284547628723, 14.066982618884552, 14.13930691370691, 14.211263138792416, 14.282856857085703, 14.354093492798494], [0.0, 1.4422205101855958, 2.039607805437114, 2.4979991993593598, 2.8844410203711917, 3.22490309931942, 3.532704346531139, 3.815756805667783, 4.079215610874228, 4.3266615305567875, 4.560701700396552, 4.7833042972405595, 4.9959983987187195, 5.200000000000001, 5.396295025292817, 5.585696017507576, 5.768882040742383, 5.946427498927402, 6.118823416311343, 6.2864934582006855, 6.44980619863884, 6.609084656743323, 6.764613810115105, 6.916646586316234, 7.065408693062278, 7.211102550927979, 7.353910524340095, 7.493997598078079, 7.631513611335566, 7.76659513557904, 7.899367063252599, 8.029943959953894, 8.158431221748456, 8.284926070883193, 8.409518416651457, 8.532291603080617, 8.653323061113575, 8.772684879784524, 8.890444308357148, 9.006664199358163, 9.121403400793104, 9.234717104492159, 9.34665715643834, 9.457272334029511, 9.566608594481119, 9.674709297958259, 9.781615408509987, 9.88736567544662, 9.991996797437439, 10.09554357129917, 10.19803902718557, 10.299514551666988, 10.400000000000002, 10.499523798725352, 10.598113039593418, 10.695793565696752, 10.792590050585634, 10.88852607105296, 10.983624174196786, 11.077905939300983, 11.171392035015153, 11.26410227226298, 11.356055653262713, 11.447270417003349, 11.537764081484767, 11.627553482998906, 11.71665481270145, 11.805083650698965, 11.892854997854805, 11.979983305497552, 12.066482503198687, 12.15236602477065, 12.237646832622685, 12.32233744059949, 12.406449935416658, 12.489995996796797, 12.572986916401371, 12.655433615645101, 12.737346662472529, 12.818736287169653, 12.89961239727768, 12.979984591670362, 13.059862173851608, 13.139254164525473, 13.218169313486646, 13.29661611087573, 13.374602797840392, 13.452137376640191, 13.52922762023021, 13.605881081355959, 13.682105101189656, 13.757906817535872, 13.833293172632468, 13.90827092057097, 13.982846634358829, 14.057026712644463, 14.130817386124557, 14.204224723651766, 14.277254638059798, 14.34991289172168, 14.422205101855958, 14.494136745594753], [0.0, 1.4560219778561039, 2.0591260281974004, 2.521904042583699, 2.9120439557122078, 3.255764119219942, 3.5665109000254023, 3.852272056851645, 4.118252056394801, 4.368065933568311, 4.604345773288536, 4.829078587059855, 5.043808085167398, 5.249761899362676, 5.447935388750495, 5.639148871948674, 5.8240879114244155, 6.003332407921454, 6.177378084592201, 6.3466526610489735, 6.511528238439884, 6.672330927044912, 6.82934843158555, 6.982836100038438, 7.1330218000508046, 7.28010988928052, 7.424284477308236, 7.565712127751096, 7.70454411370329, 7.840918313565065, 7.974960814950755, 8.106787279804498, 8.236504112789602, 8.364209466530596, 8.48999411071645, 8.613942186943213, 8.736131867136622, 8.856635930193812, 8.975522268926753, 9.092854337335446, 9.208691546577072, 9.323089616645333, 9.436100889668362, 9.547774609824009, 9.65815717411971, 9.767292357659825, 9.875221516502808, 9.981983770774226, 10.087616170334796, 10.192153844992726, 10.295630140987003, 10.398076745244769, 10.499523798725352, 10.600000000000001, 10.699532700076206, 10.798147989354472, 10.89587077750099, 10.992724866929038, 11.088733020503291, 11.183917024012652, 11.278297743897348, 11.3718951806636, 11.464728518373212, 11.556816170554935, 11.648175822848831, 11.738824472663351, 11.828778466096997, 11.918053532351665, 12.006664815842909, 12.094626906192685, 12.18195386627285, 12.268659258452002, 12.354756169184402, 12.440257232067191, 12.525174649480942, 12.609520212918493, 12.693305322097947, 12.776541002947551, 12.85923792454281, 12.941406415069425, 13.023056476879768, 13.104197800704934, 13.18483977907961, 13.264991519032344, 13.344661854089823, 13.42385935563987, 13.502592343694602, 13.58086889709197, 13.6586968631711, 13.736083866954221, 13.813037319865607, 13.889564428015735, 13.965672200076876, 14.041367454774484, 14.116656828017039, 14.191546779685433, 14.266043600101609, 14.340153416194685, 14.413882197381803, 14.487235761179566, 14.56021977856104, 14.63283977907228], [0.0, 1.469693845669907, 2.078460969082653, 2.5455844122715714, 2.939387691339814, 3.286335345030997, 3.6, 3.8884444190447165, 4.156921938165306, 4.409081537009721, 4.6475800154489, 4.874423042781577, 5.091168824543143, 5.299056519796709, 5.499090833947008, 5.692099788303082, 5.878775382679628, 6.059702963017247, 6.235382907247959, 6.406246951218788, 6.572670690061994, 6.7349832961930955, 6.8934751758456345, 7.0484040746824395, 7.2, 7.348469228349535, 7.493997598078079, 7.636753236814714, 7.776888838089433, 7.914543574963752, 8.049844718999243, 8.182909018191515, 8.313843876330612, 8.442748367682174, 8.56971411425142, 8.694826047713663, 8.818163074019441, 8.939798655450804, 9.059801322324901, 9.178235124467014, 9.2951600308978, 9.410632284814874, 9.524704719832528, 9.637427042525406, 9.748846085563153, 9.859006035092989, 9.96794863550169, 10.075713374248, 10.182337649086286, 10.287856919689348, 10.392304845413264, 10.495713410721542, 10.598113039593418, 10.699532700076206, 10.8, 10.899541274750971, 10.998181667894016, 11.095945205344158, 11.192854863706579, 11.288932633336067, 11.384199576606164, 11.478675881825394, 11.572380913191546, 11.665333257134149, 11.757550765359255, 11.849050594878898, 11.93984924527944, 12.029962593458054, 12.119405926034494, 12.208193969625484, 12.296340919151518, 12.383860464330176, 12.470765814495918, 12.55706972187381, 12.642784503423286, 12.727922061357855, 12.812493902437575, 12.896511156122807, 12.979984591670364, 13.062924634246345, 13.145341380123988, 13.227244611029162, 13.308643807691302, 13.389548162652838, 13.469966592386191, 13.54990774876346, 13.629380029920657, 13.708391590555037, 13.786950351691269, 13.865064009949611, 13.942740046346701, 14.019985734657508, 14.096808149364879, 14.173214173221261, 14.249210504445502, 14.324803663575986, 14.4, 14.474805698177784, 14.54922678357857, 14.623269128344731, 14.69693845669907, 14.770240350109408], [0.0, 1.4832396974191326, 2.0976176963403033, 2.5690465157330262, 2.9664793948382653, 3.3166247903554003, 3.6331804249169903, 3.924283374069717, 4.1952353926806065, 4.449719092257398, 4.69041575982343, 4.919349550499538, 5.1380930314660525, 5.347896782848376, 5.549774770204643, 5.744562646538029, 5.932958789676531, 6.115553940568263, 6.29285308902091, 6.465291950097846, 6.6332495807108005, 6.797058187186572, 6.957010852370435, 7.113367697511497, 7.266360849833981, 7.416198487095664, 7.563068160475615, 7.707139547199078, 7.848566748139434, 7.987490219086344, 8.12403840463596, 8.258329128825032, 8.390470785361213, 8.520563361656318, 8.648699324175862, 8.774964387392123, 8.899438184514796, 9.02219485491197, 9.143303560529969, 9.26282894152753, 9.38083151964686, 9.497368056467014, 9.612491872558333, 9.726253132630262, 9.838699100999076, 9.9498743710662, 10.059821071967434, 10.16857905510893, 10.276186062932105, 10.382677881933928, 10.488088481701517, 10.59245014149229, 10.695793565696752, 10.798147989354472, 10.899541274750971, 11.0, 11.099549540409287, 11.198214143335536, 11.296016997154352, 11.392980294900891, 11.489125293076057, 11.584472366059664, 11.679041056525145, 11.772850122209151, 11.865917579353061, 11.958260743101398, 12.049896265113654, 12.14084016862095, 12.231107881136525, 12.320714265009153, 12.409673645990857, 12.497999839974396, 12.58570617804182, 12.672805529952711, 12.759310326189265, 12.84523257866513, 12.930583900195693, 13.015375522819156, 13.099618315050254, 13.183322798141598, 13.266499161421601, 13.349157276772194, 13.431306712304654, 13.512956745287095, 13.594116374373144, 13.674794331177344, 13.75499909123952, 13.83473888441701, 13.91402170474087, 13.992855319769443, 14.071247279470288, 14.149204924659195, 14.226735395022994, 14.30384563675098, 14.380542409798041, 14.456832294800959, 14.532721699667961, 14.60821686586012, 14.683323874382122, 14.758048651498614, 14.832396974191328, 14.906374475371269], [0.0, 1.4966629547095767, 2.116601048851672, 2.5922962793631443, 2.9933259094191533, 3.3466401061363023, 3.666060555964672, 3.9597979746446663, 4.233202097703344, 4.48998886412873, 4.732863826479693, 4.963869458396343, 5.184592558726289, 5.396295025292817, 5.6, 5.796550698475775, 5.986651818838307, 6.170899448216605, 6.3498031465550175, 6.523802572120037, 6.6932802122726045, 6.858571279792899, 7.019971509913698, 7.177743377970545, 7.332121111929344, 7.483314773547883, 7.631513611335565, 7.776888838089433, 7.919595949289333, 8.059776671843954, 8.197560612767678, 8.333066662399863, 8.466404195406689, 8.597674104081872, 8.726969691708572, 8.854377448471462, 8.97997772825746, 9.103845341392834, 9.226050075736637, 9.346657156438338, 9.465727652959385, 9.583318840568753, 9.699484522385713, 9.814275317108237, 9.927738916792686, 10.039920318408905, 10.150862032359617, 10.260604270704528, 10.369185117452577, 10.476640682967036, 10.583005244258363, 10.688311372709911, 10.792590050585634, 10.89587077750099, 10.998181667894016, 11.099549540409287, 11.2, 11.299557513460428, 11.398245479020007, 11.49608629055993, 11.59310139695155, 11.689311356961966, 11.784735890124987, 11.879393923933998, 11.973303637676613, 12.066482503198683, 12.15894732285653, 12.250714264890844, 12.34179889643321, 12.432216214336043, 12.521980673998822, 12.611106216347556, 12.699606293110035, 12.787493890516624, 12.874781551544864, 12.96148139681572, 13.047605144240073, 13.133164127505603, 13.218169313486646, 13.302631318652713, 13.386560424545209, 13.46996659238619, 13.552859476877934, 13.635248439247448, 13.717142559585797, 13.798550648528272, 13.879481258317979, 13.959942693292119, 14.039943019827396, 14.119490075778232, 14.198591479439077, 14.277254638059798, 14.35548675594109, 14.433294842134973, 14.510685717773644, 14.587666023048374, 14.664242223858688, 14.740420618150624, 14.816207341961707, 14.891608375189028, 14.966629547095765, 15.041276541570534], [0.0, 1.50996688705415, 2.1354156504062622, 2.6153393661244047, 3.0199337741083, 3.3763886032268267, 3.698648401781386, 3.994996871087636, 4.2708313008125245, 4.52990066116245, 4.774934554525329, 5.007993610219566, 5.230678732248809, 5.44426303552648, 5.649778756730214, 5.848076606885378, 6.0398675482166, 6.2257529665093525, 6.406246951218787, 6.581793068761734, 6.752777206453653, 6.919537556802478, 7.0823724838503095, 7.24154679609267, 7.397296803562772, 7.54983443527075, 7.699350621968064, 7.846018098373213, 7.989993742175272, 8.131420540102448, 8.270429251254132, 8.40713982279348, 8.541662601625049, 8.674099376880577, 8.804544281222055, 8.933084573650918, 9.0598013223249, 9.184770002564028, 9.308061022576076, 9.429740187301027, 9.549869109050658, 9.668505572217457, 9.785703858180055, 9.90151503558925, 10.015987220439133, 10.129165809680478, 10.241093691593687, 10.351811435686027, 10.461357464497619, 10.569768209379049, 10.677078252031311, 10.783320453366859, 10.88852607105296, 10.992724866929038, 11.095945205344158, 11.198214143335536, 11.299557513460428, 11.4, 11.499565209172042, 11.598275733918381, 11.696153213770756, 11.793218390244455, 11.889491158161478, 11.984990613262907, 12.0797350964332, 12.17374223482656, 12.267028980156523, 12.3596116443843, 12.451505933018705, 12.542726976220123, 12.633289357883006, 12.723207142855138, 12.812493902437573, 12.90116273829611, 12.989226304903614, 13.076696830622021, 13.163586137523469, 13.24990566004151, 13.335666462535723, 13.420879255846094, 13.505554412907307, 13.58970198348735, 13.67333170810977, 13.756453031214114, 13.839075113604956, 13.921206844235885, 14.002856851371437, 14.084033513166604, 14.164744967700619, 14.244999122499095, 14.324803663575986, 14.404166064024672, 14.48309359218534, 14.561593319413918, 14.63967212747608, 14.717336715588184, 14.794593607125543, 14.871449156017043, 14.947909552843836, 15.023980830658699, 15.0996688705415, 15.174979406905305], [0.0, 1.5231546211727818, 2.1540659228538015, 2.6381811916545845, 3.0463092423455636, 3.405877273185281, 3.7309516212355263, 4.029888335921977, 4.308131845707603, 4.569463863518345, 4.8166378315169185, 5.051732376126036, 5.276362383309169, 5.491812087098393, 5.6991227395100035, 5.8991524815010505, 6.092618484691127, 6.280127387243033, 6.462197768561405, 6.639277069079134, 6.811754546370562, 6.97997134664606, 7.144228439796701, 7.3047929470998705, 7.4619032424710525, 7.6157731058639095, 7.766595135579041, 7.914543574963752, 8.059776671843954, 8.202438661763953, 8.342661445845684, 8.480566018845677, 8.616263691415206, 8.749857141690944, 8.881441324469808, 9.01110426085505, 9.13892772703669, 9.264987857520376, 9.389355675444403, 9.512097560475294, 9.633275663033837, 9.752948272189288, 9.871170143402454, 9.987992791347018, 10.103464752252073, 10.21763181955584, 10.330537256115967, 10.442221985765292, 10.552724766618338, 10.662082348209472, 10.77032961426901, 10.87749971270972, 10.983624174196786, 11.088733020503291, 11.192854863706579, 11.296016997154352, 11.398245479020007, 11.499565209172042, 11.600000000000001, 11.699572641767732, 11.798304963002101, 11.896217886370442, 11.99333148045196, 12.089665007765932, 12.185236969382254, 12.280065146407, 12.374166638606416, 12.46755790040696, 12.560254774486067, 12.65227252314777, 12.743625857659195, 12.834328965707558, 12.92439553712281, 13.013838787997953, 13.10267148332736, 13.19090595827292, 13.278554138158269, 13.365627557282899, 13.452137376640191, 13.53809440061636, 13.623509092741124, 13.708391590555037, 13.792751719653337, 13.876599006961325, 13.95994269329212, 14.042791745233568, 14.125154866407662, 14.207040508142434, 14.288456879593403, 14.369411957348847, 14.449913494550756, 14.529969029560938, 14.609585894199741, 14.688771221582833, 14.767531953579788, 14.845874847916507, 14.923806484942105, 15.001333274079343, 15.078461459976612, 15.15519712837811, 15.231546211727819, 15.307514494521966], [0.0, 1.5362291495737217, 2.172556098240043, 2.6608269391300143, 3.0724582991474434, 3.4351128074635335, 3.7629775444453557, 4.064480286580315, 4.345112196480086, 4.608687448721165, 4.857983120596447, 5.095095681142799, 5.321653878260029, 5.5389529696504916, 5.748043145279965, 5.949789912257406, 6.144916598294887, 6.334035048845246, 6.517668294720129, 6.696267617113283, 6.870225614927067, 7.0398863627192165, 7.205553413860728, 7.367496182557545, 7.525955088890711, 7.681145747868608, 7.833262411026456, 7.982480817390043, 8.12896057316063, 8.272847151978574, 8.41427358718505, 8.553361912137238, 8.690224392960172, 8.824964589164084, 8.957678270623477, 9.08845421400141, 9.21737489744233, 9.344517108978932, 9.469952481401371, 9.593747964169166, 9.715966241192895, 9.836666101886351, 9.955902771722915, 10.07372820757042, 10.190191362285598, 10.3053384223906, 10.419213022104884, 10.531856436545269, 10.643307756520057, 10.75360404701605, 10.862780491200215, 10.970870521521983, 11.077905939300983, 11.183917024012652, 11.288932633336067, 11.392980294900891, 11.49608629055993, 11.598275733918381, 11.699572641767732, 11.799999999999999, 11.899579824514811, 11.998333217576514, 12.09628042002995, 12.193440859740944, 12.289833196589774, 12.385475364312827, 12.480384609458154, 12.574577527694519, 12.668070097690492, 12.760877712759417, 12.853015210447703, 12.944496900227524, 13.035336589440258, 13.125547607623842, 13.215142829345432, 13.30413469565007, 13.392535234226566, 13.480356078383092, 13.567608484917304, 13.654303350958628, 13.740451229854134, 13.826062346163495, 13.911146609823362, 13.995713629536722, 14.079772725438433, 14.163332941084171, 14.246403054806501, 14.328991590478376, 14.411106827721456, 14.492756811593852, 14.573949361789342, 14.654692081377895, 14.73499236511509, 14.814857407346182, 14.894294209528695, 14.973309587395832, 15.051910177781423, 15.130102445125743, 15.207892687680301, 15.285287043428397, 15.362291495737216, 15.438911878756224], [0.0, 1.5491933384829666, 2.1908902300206643, 2.6832815729997477, 3.098386676965933, 3.4641016151377544, 3.794733192202055, 4.098780306383839, 4.381780460041329, 4.6475800154488995, 4.898979485566356, 5.138093031466052, 5.366563145999495, 5.585696017507576, 5.796550698475775, 5.999999999999999, 6.196773353931866, 6.387487769068525, 6.572670690061993, 6.752777206453653, 6.928203230275509, 7.099295739719539, 7.26636084983398, 7.429670248402684, 7.58946638440411, 7.745966692414833, 7.899367063252599, 8.049844718999243, 8.197560612767678, 8.342661445845684, 8.48528137423857, 8.625543461139129, 8.763560920082657, 8.899438184514796, 9.033271832508971, 9.16515138991168, 9.295160030897799, 9.423375191511797, 9.549869109050658, 9.674709297958259, 9.797958971132712, 9.919677414109795, 10.039920318408907, 10.158740079360234, 10.276186062932103, 10.392304845413262, 10.507140429250956, 10.620734437881403, 10.73312629199899, 10.844353369380766, 10.954451150103322, 11.063453348751464, 11.171392035015153, 11.278297743897348, 11.384199576606164, 11.489125293076057, 11.59310139695155, 11.696153213770756, 11.798304963002101, 11.899579824514811, 11.999999999999998, 12.099586769803338, 12.198360545581524, 12.296340919151517, 12.393546707863733, 12.489995996796795, 12.585706178041818, 12.680693987317886, 12.77497553813705, 12.868566353716329, 12.96148139681572, 13.053735097664575, 13.145341380123986, 13.236313686219436, 13.326664999166143, 13.416407864998737, 13.505554412907307, 13.594116374373142, 13.682105101189656, 13.769531582446804, 13.856406460551018, 13.9427400463467, 14.028542333400146, 14.113823011501879, 14.198591479439077, 14.282856857085699, 14.366627996854376, 14.449913494550755, 14.53272169966796, 14.615060725156086, 14.696938456699067, 14.778362561528931, 14.859340496805368, 14.939879517586478, 15.019986684414869, 15.099668870541498, 15.17893276880822, 15.257784898208522, 15.33623161014465, 15.414279094398156, 15.491933384829666, 15.569200364822851], [0.0, 1.5620499351813308, 2.209072203437452, 2.705549851693737, 3.1240998703626617, 3.492849839314596, 3.8262252939417984, 4.132795663954365, 4.418144406874904, 4.686149805543993, 4.9396356140913875, 5.180733538795447, 5.411099703387474, 5.63205113613149, 5.844655678480983, 6.049793384901669, 6.248199740725323, 6.440496875241847, 6.627216610312357, 6.808817812219681, 6.985699678629192, 7.158212067269313, 7.326663633605681, 7.491328320131218, 7.652450587883597, 7.810249675906655, 7.964923100695951, 8.11664955508121, 8.26559132790873, 8.411896337925237, 8.555699854482974, 8.69712596206356, 8.836288813749809, 8.973293709669823, 9.108238029388561, 9.241212041718336, 9.372299611087985, 9.501578816175762, 9.629122493768579, 9.75499871860576, 9.879271228182775, 10.001999800039991, 10.123240587875012, 10.243046421841502, 10.361467077590895, 10.478549517943787, 10.594338110519223, 10.708874824182043, 10.822199406774947, 10.934349546269315, 11.045361017187261, 11.155267813907473, 11.26410227226298, 11.3718951806636, 11.478675881825394, 11.584472366059664, 11.689311356961966, 11.793218390244455, 11.896217886370442, 11.998333217576514, 12.099586769803338, 12.2, 12.299593489217438, 12.398386991863095, 12.496399481450647, 12.59364919314493, 12.690153663372245, 12.785929766739686, 12.880993750483695, 12.975361266646875, 13.069047402163633, 13.162066707018317, 13.254433220624714, 13.346160496562298, 13.43726162579266, 13.527749258468683, 13.617635624439362, 13.706932552544352, 13.79565148878443, 13.883803513446884, 13.971399357258385, 14.058449416631978, 14.14496376806954, 14.230952181776171, 14.316424134538625, 14.401388821915754, 14.485855169785456, 14.569831845289087, 14.653327267211361, 14.736349615830916, 14.818906842274163, 14.901006677402705, 14.982656640262435, 15.063864046120438, 15.144636014114042, 15.224979474534603, 15.304901175767194, 15.384407690905752, 15.463505424062165, 15.542200616386344, 15.62049935181331, 15.698407562552326], [0.0, 1.574801574802362, 2.2271057451320084, 2.727636339397171, 3.149603149604724, 3.521363372331802, 3.857460304397182, 4.166533331199932, 4.454211490264017, 4.724404724407086, 4.979959839195493, 5.223025942880239, 5.455272678794342, 5.678027826631356, 5.892367945062493, 6.099180272790762, 6.299206299209448, 6.49307323229917, 6.681317235396026, 6.864400920692206, 7.042726744663604, 7.216647421067486, 7.386474125047755, 7.552483035399683, 7.714920608794364, 7.874007874011811, 8.029943959953892, 8.182909018191513, 8.333066662399863, 8.480566018845677, 8.625543461139129, 8.76812408671319, 8.908422980528034, 9.046546302318914, 9.182592226599196, 9.316651759081692, 9.448809448814172, 9.579144011862438, 9.707728879609277, 9.834632682515398, 9.959919678390985, 10.083650132764426, 10.20588065773846, 10.326664514740468, 10.446051885760477, 10.564090116995404, 10.680823938254951, 10.796295661012623, 10.910545357588685, 11.023611023616535, 11.135528725660043, 11.24633273560764, 11.356055653262713, 11.464728518373212, 11.572380913191546, 11.679041056525145, 11.784735890124987, 11.889491158161478, 11.99333148045196, 12.09628042002995, 12.198360545581524, 12.299593489217438, 12.399999999999999, 12.499599993599794, 12.598412598418896, 12.696456198483101, 12.79374847337558, 12.890306435457614, 12.98614646459834, 13.081284340614266, 13.175735273600482, 13.269513932318695, 13.362634470792052, 13.455110553243328, 13.546955377500877, 13.638181696985855, 13.728801841384412, 13.81882773609976, 13.908270920570969, 13.997142565538153, 14.085453489327207, 14.17321417322126, 14.26043477598071, 14.347125147568763, 14.433294842134972, 14.51895313030523, 14.604109010822947, 14.688771221582831, 14.77294825009551, 14.85664834341851, 14.939879517586478, 15.022649566571138, 15.104966070799366, 15.186836405255704, 15.268267747193851, 15.349267083479912, 15.429841217588727, 15.509996776273038, 15.58974021592406, 15.669077828640715, 15.748015748023622, 15.826559954709047], [0.0, 1.5874507866387544, 2.244994432064365, 2.7495454169735045, 3.1749015732775088, 3.5496478698597698, 3.8884444190447165, 4.2, 4.48998886412873, 4.762352359916263, 5.019960159204453, 5.264978632435274, 5.499090833947009, 5.723635208501674, 5.939696961966999, 6.148170459575758, 6.3498031465550175, 6.545227268781429, 6.734983296193095, 6.919537556802479, 7.0992957397195395, 7.274613391789285, 7.445804187594514, 7.6131465242697125, 7.776888838089433, 7.937253933193772, 8.094442537939226, 8.248636250920512, 8.4, 8.548684109265006, 8.694826047713663, 8.838551917593742, 8.97997772825746, 9.119210492142399, 9.256349172324908, 9.391485505499118, 9.524704719832526, 9.65608616365865, 9.785703858180055, 9.913626985114984, 10.039920318408907, 10.16464460765845, 10.287856919689348, 10.409610943738484, 10.529957264870548, 10.648943609579309, 10.766615066955817, 10.883014288330234, 10.998181667894018, 11.11215550647128, 11.224972160321824, 11.336666176614711, 11.447270417003349, 11.556816170554935, 11.665333257134149, 11.772850122209151, 11.879393923933998, 11.984990613262907, 12.089665007765932, 12.193440859740944, 12.296340919151517, 12.398386991863095, 12.499599993599794, 12.6, 12.699606293110035, 12.798437404620925, 12.896511156122806, 12.99384469662463, 13.090454537562858, 13.186356585501548, 13.281566172707194, 13.376098085764772, 13.46996659238619, 13.563185466548779, 13.65576801208925, 13.74772708486752, 13.839075113604958, 13.92982411949268, 14.019985734657508, 14.109571219565817, 14.198591479439079, 14.28705707974879, 14.37497826085313, 14.46236495183274, 14.54922678357857, 14.635573101180562, 14.721412975662357, 14.80675521510368, 14.891608375189028, 14.975980769218422, 15.05988047761336, 15.143315356948756, 15.226293048539425, 15.30882098660769, 15.390906406056793, 15.472556349873152, 15.553777676178866, 15.634577064954462, 15.714961024450554, 15.794935897305821, 15.874507866387544, 15.95368296037], [0.0, 1.6, 2.262741699796952, 2.771281292110204, 3.2, 3.577708763999664, 3.9191835884530852, 4.233202097703345, 4.525483399593904, 4.8, 5.059644256269407, 5.30659966456864, 5.542562584220408, 5.768882040742383, 5.986651818838307, 6.196773353931866, 6.4, 6.596969000988257, 6.788225099390856, 6.974238309665079, 7.155417527999328, 7.332121111929345, 7.504665215717488, 7.673330437300352, 7.8383671769061705, 8.0, 8.158431221748456, 8.313843876330612, 8.46640419540669, 8.616263691415208, 8.763560920082657, 8.908422980528035, 9.050966799187808, 9.191300234460847, 9.329523031752482, 9.465727652959385, 9.6, 9.732420048477152, 9.863062404750362, 9.991996797437439, 10.119288512538814, 10.244998779892558, 10.369185117452577, 10.491901638883201, 10.61319932913728, 10.73312629199899, 10.851727973000429, 10.969047360641671, 11.085125168440817, 11.200000000000001, 11.313708498984761, 11.426285485668561, 11.537764081484767, 11.648175822848831, 11.757550765359255, 11.865917579353061, 11.973303637676613, 12.0797350964332, 12.185236969382254, 12.289833196589774, 12.393546707863733, 12.496399481450647, 12.598412598418896, 12.699606293110035, 12.8, 12.899612397277679, 12.998461447417537, 13.096564434995921, 13.193938001976514, 13.29059818066892, 13.386560424545209, 13.481839637082174, 13.576450198781712, 13.67040599250805, 13.763720427268202, 13.85640646055102, 13.948476619330158, 14.039943019827396, 14.130817386124557, 14.221111067704943, 14.310835055998655, 14.4, 14.488616221019868, 14.576693726630879, 14.66424222385869, 14.75127113166862, 14.837789592793127, 14.923806484942105, 15.009330431434975, 15.094369811290566, 15.17893276880822, 15.26302722267113, 15.346660874600705, 15.429841217588729, 15.512575543732254, 15.594870951694341, 15.676734353812341, 15.75817248287377, 15.839191898578665, 15.919798993705921, 16.0, 16.079800993793427], [0.0, 1.6124515496597098, 2.2803508501982757, 2.7928480087537886, 3.2249030993194197, 3.605551275463989, 3.9496835316262997, 4.266145801540308, 4.560701700396551, 4.8373546489791295, 5.0990195135927845, 5.347896782848375, 5.585696017507577, 5.813776741499453, 6.033241251599342, 6.244997998398397, 6.449806198638839, 6.648308055437864, 6.841052550594828, 7.0285133563222315, 7.211102550927978, 7.389181280764467, 7.5630681604756145, 7.733045971672482, 7.899367063252599, 8.06225774829855, 8.221921916437786, 8.378544026261364, 8.532291603080616, 8.683317338436964, 8.831760866327846, 8.977750274985375, 9.121403400793103, 9.262828941527529, 9.402127418834526, 9.539392014169456, 9.674709297958259, 9.808159868191382, 9.939818911831342, 10.069756700139283, 10.198039027185569, 10.324727599312245, 10.449880382090505, 10.57355191030904, 10.69579356569675, 10.816653826391967, 10.936178491593852, 11.054410884348382, 11.171392035015154, 11.287160847617969, 11.40175425099138, 11.515207336387826, 11.627553482998906, 11.738824472663351, 11.849050594878898, 11.958260743101398, 12.066482503198683, 12.17374223482656, 12.280065146407, 12.385475364312827, 12.489995996796795, 12.59364919314493, 12.696456198483101, 12.798437404620925, 12.899612397277679, 12.999999999999998, 13.09961831505025, 13.198484761517133, 13.296616110875728, 13.394028520202575, 13.490737563232042, 13.586758259423032, 13.682105101189656, 13.776792079435618, 13.87083270751976, 13.96424004376894, 14.057026712644463, 14.149204924659195, 14.24078649513432, 14.331782861877304, 14.422205101855956, 14.512063946937388, 14.601369798755185, 14.690132742763081, 14.778362561528933, 14.866068747318506, 14.953260514014994, 15.039946808416577, 15.126136320951229, 15.211837495845133, 15.297058540778353, 15.381807436059, 15.466091943344964, 15.549919613940132, 15.633297796690243, 15.716233645501708, 15.798734126505199, 15.880806024884254, 15.96245595138793, 16.043690348545127, 16.1245154965971, 16.20493751916372], [0.0, 1.624807680927192, 2.2978250586152114, 2.8142494558940583, 3.249615361854384, 3.6331804249169903, 3.97994974842648, 4.298837052040936, 4.595650117230423, 4.874423042781576, 5.138093031466052, 5.388877434122993, 5.628498911788117, 5.858327406350725, 6.079473661428265, 6.292853089020909, 6.499230723708768, 6.699253689777691, 6.8934751758456345, 7.08237248385031, 7.266360849833981, 7.445804187594514, 7.62102355330306, 7.792303895511263, 7.95989949685296, 8.12403840463596, 8.284926070883191, 8.442748367682174, 8.597674104081872, 8.749857141690944, 8.899438184514795, 9.046546302318912, 9.191300234460845, 9.333809511662428, 9.47417542586161, 9.612491872558332, 9.748846085563152, 9.88331928048467, 10.015987220439133, 10.146920715172659, 10.276186062932103, 10.403845442911964, 10.529957264870548, 10.654576481493761, 10.777754868245985, 10.89954127475097, 11.01998185116473, 11.139120252515456, 11.256997823576233, 11.373653766490344, 11.489125293076057, 11.60344776348823, 11.71665481270145, 11.828778466096997, 11.93984924527944, 12.049896265113654, 12.15894732285653, 12.267028980156523, 12.374166638606416, 12.480384609458154, 12.585706178041818, 12.690153663372245, 12.79374847337558, 12.896511156122806, 12.998461447417537, 13.09961831505025, 13.2, 13.299624054837038, 13.398507379555381, 13.496666255042392, 13.594116374373144, 13.690872872099865, 13.786950351691269, 13.882362911262621, 13.977124167724918, 14.071247279470288, 14.16474496770062, 14.257629536497292, 14.34991289172168, 14.441606558828557, 14.532721699667961, 14.62326912834473, 14.713259326199617, 14.802702455970666, 14.891608375189028, 14.979986648859205, 15.06784656146989, 15.155197128378108, 15.24204710660612, 15.328405005087776, 15.414279094398154, 15.49967741599805, 15.584607791022526, 15.669077828640715, 15.753094934012175, 15.836666315863322, 15.91979899370592, 16.002499804718013, 16.08477541030648, 16.166632302368978, 16.24807680927192, 16.32911510156016], [0.0, 1.6370705543744901, 2.315167380558045, 2.8354893757515653, 3.2741411087489802, 3.6606010435446255, 4.009987531152684, 4.331281565541543, 4.63033476111609, 4.91121166312347, 5.176871642217914, 5.429548784199292, 5.670978751503131, 5.902541825349482, 6.125357132445422, 6.340346993658943, 6.5482822174979605, 6.749814812274482, 6.945502141674135, 7.13582510996451, 7.321202087089251, 7.501999733404421, 7.678541528180987, 7.851114570556209, 8.019975062305368, 8.18535277187245, 8.347454701883683, 8.506468127254696, 8.662563131083086, 8.815894736213677, 8.966604708583956, 9.114823092084674, 9.26066952223218, 9.404254356406998, 9.54567965102538, 9.6850400102426, 9.82242332624694, 9.957911427603682, 10.091580649234292, 10.223502335305646, 10.353743284435827, 10.482366145102928, 10.609429767899876, 10.734989520255713, 10.859097568398584, 10.981803130633875, 11.103152705425607, 11.22319027727856, 11.341957503006261, 11.45949388062143, 11.575836902790225, 11.691022196540388, 11.805083650698965, 11.918053532351665, 12.029962593458054, 12.14084016862095, 12.250714264890844, 12.3596116443843, 12.46755790040696, 12.574577527694519, 12.680693987317886, 12.785929766739686, 12.890306435457614, 12.99384469662463, 13.096564434995921, 13.198484761517133, 13.299624054837038, 13.4, 13.499629624548964, 13.59852933224766, 13.696714934611146, 13.794201680416304, 13.89100428334827, 13.98713694792469, 14.082613393827154, 14.177446878757825, 14.27165021992902, 14.365235814284429, 14.458215657542256, 14.550601362143079, 14.642404174178502, 14.73363498937041, 14.824304368165139, 14.914422550001726, 15.003999466808843, 15.093044755780724, 15.181567771478676, 15.269577597301112, 15.357083056361974, 15.444092721814382, 15.53061492665374, 15.616657773031974, 15.702229141112419, 15.78733669749271, 15.871987903221198, 15.956190021430553, 16.039950124610737, 16.12327510154187, 16.206171663906314, 16.288646352597873, 16.3707055437449, 16.45235545446305], [0.0, 1.6492422502470643, 2.33238075793812, 2.8565713714171403, 3.2984845004941286, 3.687817782917155, 4.039801975344831, 4.363484845854286, 4.66476151587624, 4.947726750741192, 5.215361924162119, 5.469917732470938, 5.713142742834281, 5.946427498927402, 6.170899448216605, 6.387487769068525, 6.596969000988257, 6.8, 6.997142273814361, 7.188880302244572, 7.37563556583431, 7.557777451076474, 7.735631842325486, 7.909487973314076, 8.079603950689663, 8.246211251235321, 8.409518416651457, 8.56971411425142, 8.726969691708572, 8.881441324469808, 9.033271832508971, 9.182592226599198, 9.32952303175248, 9.47417542586161, 9.616652224137047, 9.757048734120374, 9.895453501482384, 10.031948963187562, 10.166612021711067, 10.299514551666988, 10.430723848324238, 10.56030302595527, 10.688311372709911, 10.814804667676619, 10.939835464941876, 11.063453348751464, 11.18570516328765, 11.306635220082056, 11.426285485668561, 11.54469575172945, 11.661903789690601, 11.777945491468367, 11.892854997854805, 12.006664815842909, 12.119405926034494, 12.231107881136525, 12.34179889643321, 12.451505933018705, 12.560254774486067, 12.668070097690492, 12.77497553813705, 12.880993750483695, 12.98614646459834, 13.090454537562858, 13.193938001976514, 13.296616110875728, 13.398507379555381, 13.499629624548964, 13.6, 13.699635031634967, 13.798550648528273, 13.896762212832167, 13.994284547628721, 14.091131963046829, 14.187318280774559, 14.2828568570857, 14.377760604489144, 14.472042012100435, 14.565713164826501, 14.658785761446955, 14.75127113166862, 14.84318025222358, 14.934523762075576, 15.025311976794358, 15.115554902152947, 15.20526224699857, 15.29444343544413, 15.383107618423528, 15.471263684650973, 15.558920271021378, 15.646085772486357, 15.73276835143771, 15.818975946628152, 15.904716281656835, 15.98999687304535, 16.074825037928093, 16.159207901379325, 16.243152403397563, 16.32666530556684, 16.40975319741281, 16.492422502470642, 16.57467948408053], [0.0, 1.661324772583615, 2.349468024894146, 2.8774989139876324, 3.32264954516723, 3.7148351242013424, 4.069397989875161, 4.3954521951671826, 4.698936049788292, 4.983974317750845, 5.253570214625479, 5.509990925582365, 5.754997827975265, 5.989991652748776, 6.216108107168021, 6.434283176858164, 6.64529909033446, 6.849817515817484, 7.048404074682439, 7.2415467960926705, 7.429670248402685, 7.6131465242697125, 7.792303895511263, 7.967433714816837, 8.138795979750322, 8.306623862918075, 8.47112743381895, 8.632496741962896, 8.790904390334365, 8.946507698538017, 9.09945053286186, 9.249864863877743, 9.397872099576585, 9.54358423235212, 9.687104830649869, 9.828529900244492, 9.96794863550169, 10.105444077327824, 10.241093691593687, 10.374969879474351, 10.507140429250958, 10.637668917577761, 10.766615066955818, 10.894035065117057, 11.01998185116473, 11.144505372604025, 11.26765281680262, 11.38946881992308, 11.50999565595053, 11.629273408085306, 11.747340124470732, 11.864231959971114, 11.979983305497552, 12.094626906192685, 12.208193969625484, 12.320714265009153, 12.432216214336043, 12.542726976220123, 12.65227252314777, 12.760877712759417, 12.868566353716329, 12.975361266646875, 13.081284340614266, 13.186356585501548, 13.29059818066892, 13.394028520202575, 13.496666255042392, 13.59852933224766, 13.699635031634967, 13.8, 13.899640283115245, 13.998571355677694, 14.096808149364877, 14.194365079143202, 14.291256067959877, 14.38749456993816, 14.483093592185341, 14.578065715313539, 14.672423112764983, 14.766177569025778, 14.85934049680537, 14.951922953252536, 15.043935655273193, 15.135388994010032, 15.226293048539425, 15.316657598836635, 15.406492138056606, 15.49580588417395, 15.584607791022526, 15.672906558772052, 15.760710643876436, 15.848028268526026, 15.934867429633673, 16.02123590738243, 16.10714127336071, 16.192590898309017, 16.277591959500644, 16.36215144777728, 16.446276174259022, 16.529972776747094, 16.61324772583615, 16.69610733075228], [0.0, 1.6733200530681511, 2.3664319132398464, 2.8982753492378883, 3.3466401061363023, 3.7416573867739418, 4.09878030638384, 4.427188724235731, 4.732863826479693, 5.019960159204453, 5.291502622129181, 5.549774770204644, 5.796550698475777, 6.033241251599343, 6.260990336999411, 6.48074069840786, 6.6932802122726045, 6.899275324264137, 7.0992957397195395, 7.293833011524189, 7.4833147735478835, 7.668115805072326, 7.848566748139434, 8.024961059095553, 8.19756061276768, 8.366600265340756, 8.532291603080617, 8.694826047713665, 8.854377448471462, 9.01110426085505, 9.16515138991168, 9.316651759081694, 9.465727652959385, 9.612491872558333, 9.757048734120374, 9.899494936611665, 10.039920318408907, 10.178408519999579, 10.315037566582102, 10.449880382090507, 10.583005244258363, 10.7144761887831, 10.84435336938077, 10.972693379476162, 11.099549540409289, 11.224972160321824, 11.349008767288886, 11.47170431975999, 11.593101396951553, 11.713240371477058, 11.832159566199234, 11.949895397031726, 12.066482503198687, 12.18195386627285, 12.296340919151518, 12.409673645990857, 12.521980673998822, 12.633289357883006, 12.743625857659195, 12.853015210447703, 12.96148139681572, 13.069047402163633, 13.175735273600482, 13.281566172707194, 13.386560424545209, 13.490737563232042, 13.594116374373144, 13.696714934611146, 13.798550648528273, 13.899640283115245, 14.000000000000002, 14.099645385611653, 14.198591479439079, 14.296852800529214, 14.394443372357266, 14.49137674618944, 14.587666023048378, 14.683323874382124, 14.778362561528935, 14.872793954062567, 14.966629547095767, 15.059880477613362, 15.15255753990065, 15.244671200127604, 15.336231610144653, 15.427248620541514, 15.51773179301666, 15.607690412101338, 15.697133496278868, 15.786069808536892, 15.874507866387544, 15.962455951387932, 16.049922118191105, 16.13691420315545, 16.2234398325386, 16.30950643030009, 16.39512122553536, 16.480291259562133, 16.565023392678924, 16.64932431061393, 16.73320053068151, 16.816658407662327], [0.0, 1.6852299546352718, 2.3832750575625967, 2.918903903865285, 3.3704599092705436, 3.768288736283355, 4.127953488110059, 4.458699361921591, 4.766550115125193, 5.0556898639058145, 5.329165037789691, 5.589275444992849, 5.83780780773057, 6.076183012385325, 6.305553108173778, 6.526867548832287, 6.740919818541087, 6.948381106416083, 7.149825172687791, 7.345747068882784, 7.53657747256671, 7.72269383052313, 7.904429138147802, 8.082078940470701, 8.255906976220118, 8.426149773176359, 8.593020423576334, 8.756711711595855, 8.917398723843181, 9.075241043630742, 9.23038460737146, 9.38296328459192, 9.533100230250387, 9.680909048224759, 9.826494797230598, 9.969954864491614, 10.111379727811629, 10.250853622991599, 10.388455130576443, 10.524257693538296, 10.658330075579382, 10.79073676817297, 10.92153835318084, 11.050791826833043, 11.178550889985697, 11.304866208850061, 11.42978564978364, 11.553354491228944, 11.67561561546114, 11.796609682446903, 11.916375287812986, 12.034949106664309, 12.15236602477065, 12.268659258452002, 12.383860464330176, 12.497999839974396, 12.611106216347556, 12.723207142855138, 12.834328965707558, 12.944496900227524, 13.053735097664575, 13.162066707018317, 13.269513932318695, 13.376098085764772, 13.481839637082174, 13.586758259423032, 13.690872872099865, 13.794201680416304, 13.896762212832167, 13.998571355677694, 14.099645385611653, 14.2, 14.299650345375582, 14.398611044125055, 14.496896219536097, 14.594519519326424, 14.691494137765568, 14.787832836490951, 14.883547964111248, 14.978651474682225, 15.07315494513342, 15.167069591717446, 15.260406285548234, 15.353175567289002, 15.44538766104626, 15.537052487521564, 15.628179676469042, 15.718778578502848, 15.808858276295604, 15.898427595205758, 15.987495113369073, 16.076069171286868, 16.164157880941403, 16.251769134466564, 16.33891061240008, 16.425589791541732, 16.511813952440235, 16.597590186530095, 16.682925402938178, 16.767826334978544, 16.852299546352718, 16.936351437071682], [0.0, 1.697056274847714, 2.4, 2.9393876913398143, 3.394112549695428, 3.7947331922020555, 4.156921938165306, 4.48998886412873, 4.8, 5.091168824543142, 5.366563145999495, 5.628498911788116, 5.8787753826796285, 6.118823416311343, 6.3498031465550175, 6.572670690061993, 6.788225099390856, 6.997142273814361, 7.2, 7.397296803562773, 7.589466384404111, 7.776888838089433, 7.95989949685296, 8.138795979750322, 8.313843876330612, 8.485281374238571, 8.653323061113575, 8.818163074019441, 8.97997772825746, 9.138927727036691, 9.2951600308978, 9.448809448814174, 9.6, 9.748846085563153, 9.895453501482386, 10.039920318408907, 10.182337649086284, 10.322790320451153, 10.461357464497617, 10.598113039593418, 10.73312629199899, 10.8664621657649, 10.998181667894016, 11.128342194594843, 11.256997823576231, 11.384199576606164, 11.509995655950528, 11.63443165779919, 11.757550765359257, 11.879393923933998, 12.0, 12.119405926034496, 12.237646832622685, 12.354756169184402, 12.470765814495918, 12.58570617804182, 12.699606293110035, 12.812493902437573, 12.92439553712281, 13.035336589440258, 13.145341380123986, 13.254433220624714, 13.362634470792052, 13.46996659238619, 13.576450198781712, 13.682105101189656, 13.786950351691269, 13.89100428334827, 13.994284547628721, 14.096808149364877, 14.198591479439079, 14.299650345375582, 14.4, 14.499655168313486, 14.598630072715727, 14.696938456699069, 14.794593607125545, 14.891608375189028, 14.987995196156158, 15.083766107971842, 15.178932768808222, 15.273506473629427, 15.36749816983884, 15.46091847207015, 15.553777676178866, 15.646085772486359, 15.737852458324802, 15.829087149927505, 15.91979899370592, 16.0099968769516, 16.099689437998485, 16.18888507587845, 16.277591959500644, 16.36581803638303, 16.453571040962508, 16.540858502508264, 16.627687752661224, 16.714065932620944, 16.8, 16.88549673536435, 16.970562748477143, 17.055204484262276], [0.0, 1.7088007490635062, 2.4166091947189146, 2.9597297173897488, 3.4176014981270124, 3.82099463490856, 4.18568990729127, 4.521061822182926, 4.833218389437829, 5.126402247190518, 5.403702434442518, 5.667450926121902, 5.9194594347794975, 6.161168720299745, 6.393746945258312, 6.618156843109718, 6.835202996254025, 7.045565981523414, 7.249827584156743, 7.448489779814429, 7.64198926981712, 7.830708780180758, 8.014985963805552, 8.195120499419152, 8.37137981458254, 8.544003745317532, 8.713208364316786, 8.879189152169246, 9.042123644365851, 9.202173656261873, 9.359487165438072, 9.514199913813037, 9.666436778875658, 9.816312953446422, 9.96393496566492, 10.10940156488009, 10.252804494381037, 10.394229168149026, 10.533755265810955, 10.671457257563281, 10.807404868885037, 10.941663493271944, 11.074294559925702, 11.20535586226515, 11.334901852243805, 11.462983904725679, 11.589650555560336, 11.714947716485977, 11.838918869558995, 11.961605243444543, 12.083045973594572, 12.203278248077442, 12.32233744059949, 12.440257232067191, 12.55706972187381, 12.672805529952711, 12.787493890516624, 12.90116273829611, 13.013838787997953, 13.125547607623842, 13.236313686219436, 13.346160496562298, 13.455110553243328, 13.563185466548779, 13.67040599250805, 13.776792079435618, 13.882362911262621, 13.98713694792469, 14.091131963046829, 14.194365079143202, 14.296852800529214, 14.398611044125055, 14.499655168313486, 14.6, 14.699659860010366, 14.798648586948742, 14.896979559628859, 14.994665718181249, 15.091719583930788, 15.188153278130953, 15.28397853963424, 15.379206741571556, 15.473848907107762, 15.567915724335098, 15.661417560361516, 15.754364474646383, 15.846766231632245, 15.938632312717425, 16.029971927611104, 16.12079402510931, 16.211107303327555, 16.300920219423197, 16.390240998838305, 16.479077644091614, 16.56743794314619, 16.655329477377503, 16.74275962916508, 16.829735589129143, 16.9162643630324, 17.002352778365704, 17.088007490635064, 17.17323498936645], [0.0, 1.7204650534085253, 2.4331050121192876, 2.979932885150268, 3.4409301068170506, 3.847076812334269, 4.214261501141095, 4.551922670696417, 4.866210024238575, 5.161395160225576, 5.440588203494177, 5.706137047074843, 5.959865770300536, 6.203224967708329, 6.437390775772432, 6.663332499583071, 6.881860213634101, 7.093659140387279, 7.299315036357863, 7.49933330370107, 7.694153624668538, 7.884161337770809, 8.069696400732806, 8.251060537894508, 8.42852300228219, 8.602325267042627, 8.772684879784524, 8.939798655450804, 9.103845341392834, 9.264987857520376, 9.423375191511797, 9.579144011862438, 9.73242004847715, 9.88331928048467, 10.031948963187562, 10.178408519999577, 10.322790320451151, 10.465180361560904, 10.605658866850282, 10.744300814850634, 10.881176406988354, 11.01635148313633, 11.149887891813083, 11.281843820936361, 11.412274094149685, 11.541230437002806, 11.668761716651858, 11.794914158229384, 11.919731540601072, 12.043255373859678, 12.165525060596439, 12.286578042726136, 12.406449935416658, 12.525174649480942, 12.642784503423286, 12.759310326189265, 12.874781551544864, 12.989226304903614, 13.10267148332736, 13.215142829345432, 13.326664999166143, 13.43726162579266, 13.546955377500877, 13.65576801208925, 13.763720427268202, 13.87083270751976, 13.977124167724918, 14.082613393827154, 14.187318280774559, 14.291256067959877, 14.394443372357266, 14.496896219536097, 14.598630072715727, 14.699659860010366, 14.799999999999999, 14.89966442575134, 14.99866660740214, 15.097019573412496, 15.194735930578064, 15.291827882892221, 15.388307249337076, 15.484185480676729, 15.579473675320358, 15.674182594317317, 15.768322675541619, 15.861904047118681, 15.954936540143304, 16.047429700734007, 16.13939280146561, 16.230834852218784, 16.321764610482532, 16.412190591142913, 16.502121075789017, 16.59156412156491, 16.680527569594435, 16.769019053003664, 16.85704600456438, 16.94461566398011, 17.031735084835013, 17.118411141224527, 17.204650534085253, 17.29045979724079], [0.0, 1.7320508075688774, 2.449489742783178, 3.0000000000000004, 3.464101615137755, 3.872983346207417, 4.242640687119286, 4.58257569495584, 4.898979485566356, 5.196152422706632, 5.477225575051661, 5.7445626465380295, 6.000000000000001, 6.244997998398398, 6.48074069840786, 6.7082039324993685, 6.92820323027551, 7.14142842854285, 7.3484692283495345, 7.549834435270751, 7.745966692414834, 7.937253933193772, 8.12403840463596, 8.306623862918075, 8.485281374238571, 8.660254037844387, 8.831760866327848, 9.0, 9.16515138991168, 9.327379053088816, 9.486832980505138, 9.643650760992955, 9.797958971132712, 9.949874371066201, 10.099504938362077, 10.246950765959598, 10.392304845413264, 10.53565375285274, 10.677078252031311, 10.816653826391969, 10.954451150103322, 11.090536506409418, 11.224972160321824, 11.357816691600547, 11.489125293076059, 11.61895003862225, 11.747340124470732, 11.874342087037917, 12.000000000000002, 12.12435565298214, 12.247448713915892, 12.369316876852983, 12.489995996796797, 12.609520212918493, 12.727922061357855, 12.84523257866513, 12.96148139681572, 13.076696830622021, 13.19090595827292, 13.30413469565007, 13.416407864998737, 13.527749258468683, 13.638181696985855, 13.74772708486752, 13.85640646055102, 13.96424004376894, 14.071247279470288, 14.177446878757825, 14.2828568570857, 14.38749456993816, 14.49137674618944, 14.594519519326424, 14.696938456699069, 14.798648586948742, 14.89966442575134, 15.0, 15.099668870541501, 15.198684153570664, 15.297058540778357, 15.394804318340654, 15.491933384829668, 15.588457268119896, 15.684387141358124, 15.7797338380595, 15.874507866387544, 15.968719422671313, 16.06237840420901, 16.155494421403514, 16.24807680927192, 16.34013463836819, 16.431676725154983, 16.522711641858308, 16.61324772583615, 16.703293088490067, 16.792855623746668, 16.88194301613413, 16.970562748477143, 17.058722109231983, 17.146428199482248, 17.233687939614086, 17.320508075688775, 17.406895185529212], [0.0, 1.7435595774162698, 2.4657656011875906, 3.0199337741083006, 3.4871191548325395, 3.8987177379235862, 4.270831300812525, 4.613025037868319, 4.931531202375181, 5.230678732248808, 5.513619500836089, 5.782732917920385, 6.039867548216601, 6.2864934582006855, 6.523802572120037, 6.752777206453653, 6.974238309665079, 7.188880302244572, 7.397296803562773, 7.600000000000001, 7.7974354758471724, 7.9899937421752725, 8.178019320104351, 8.36181798414675, 8.54166260162505, 8.717797887081348, 8.89044430835715, 9.059801322324901, 9.226050075736637, 9.389355675444403, 9.549869109050658, 9.707728879609279, 9.863062404750362, 10.015987220439133, 10.16661202171107, 10.315037566582102, 10.461357464497617, 10.605658866850284, 10.748023074035524, 10.888526071052961, 11.027239001672179, 11.164228589562292, 11.29955751346043, 11.433284742365162, 11.56546583584077, 11.696153213770756, 11.825396399275588, 11.95324223798715, 12.079735096433202, 12.204917041913887, 12.328828005937956, 12.451505933018707, 12.572986916401371, 12.693305322097947, 12.812493902437575, 12.930583900195693, 13.047605144240073, 13.163586137523469, 13.278554138158269, 13.392535234226566, 13.505554412907307, 13.617635624439362, 13.728801841384412, 13.839075113604958, 13.948476619330158, 14.057026712644463, 14.16474496770062, 14.27165021992902, 14.377760604489144, 14.483093592185341, 14.587666023048378, 14.691494137765568, 14.794593607125545, 14.896979559628859, 14.99866660740214, 15.099668870541501, 15.200000000000003, 15.299673199124223, 15.398701243936129, 15.497096502248416, 15.594870951694345, 15.692036196746427, 15.788603484792445, 15.884583721331826, 15.979987484350545, 16.074825037928097, 16.169106345126192, 16.2628410802049, 16.356038640208702, 16.448708155961672, 16.540858502508268, 16.632498309033434, 16.7236359682935, 16.814279645586964, 16.904437287292353, 16.994116628998402, 17.0833252032501, 17.172070346932546, 17.260359208313137, 17.348198753761157, 17.435595774162696, 17.52255689104761], [0.0, 1.7549928774784245, 2.4819347291981715, 3.039736830714133, 3.509985754956849, 3.924283374069717, 4.298837052040936, 4.64327470649756, 4.963869458396343, 5.264978632435273, 5.549774770204643, 5.8206528843421, 6.079473661428266, 6.327716807822551, 6.566582063752802, 6.797058187186571, 7.019971509913698, 7.236021006050217, 7.445804187594514, 7.649836599562112, 7.848566748139434, 8.04238770515324, 8.231646250902672, 8.416650165000327, 8.597674104081872, 8.774964387392123, 8.948742928478838, 9.119210492142399, 9.28654941299512, 9.450925880568528, 9.612491872558332, 9.771386800244887, 9.927738916792686, 10.081666528902849, 10.233279044372825, 10.382677881933928, 10.529957264870546, 10.675204916066015, 10.818502669038818, 10.959927007056207, 11.099549540409287, 11.23743743030412, 11.373653766490346, 11.508257904652641, 11.6413057686842, 11.77285012220915, 11.90294081309321, 12.031624994156028, 12.158947322856532, 12.284950142348972, 12.409673645990857, 12.533156027114641, 12.655433615645101, 12.776541002947551, 12.896511156122807, 13.015375522819156, 13.133164127505603, 13.24990566004151, 13.365627557282899, 13.480356078383092, 13.594116374373142, 13.706932552544352, 13.81882773609976, 13.92982411949268, 14.039943019827396, 14.149204924659195, 14.257629536497292, 14.365235814284429, 14.472042012100435, 14.578065715313539, 14.683323874382124, 14.787832836490951, 14.891608375189028, 14.994665718181249, 15.097019573412496, 15.198684153570664, 15.299673199124223, 15.4, 15.499677415998052, 15.598717896032355, 15.697133496278868, 15.794935897305821, 15.892136420255147, 15.988746042138514, 16.08477541030648, 16.180234856144704, 16.275134408047144, 16.369483803712324, 16.463292501805345, 16.556569693025182, 16.64932431061393, 16.741565040341957, 16.833300330000654, 16.924538398432023, 17.015287244122565, 17.10555465338672, 17.195348208163743, 17.28467529344998, 17.3735431043872, 17.4619586530263, 17.549928774784245, 17.63746013461122], [0.0, 1.7663521732655696, 2.4979991993593593, 3.0594117081556718, 3.532704346531139, 3.9496835316263006, 4.3266615305567875, 4.67332857821917, 4.995998398718719, 5.299056519796709, 5.585696017507577, 5.858327406350725, 6.1188234163113435, 6.3686733312362644, 6.609084656743323, 6.841052550594828, 7.065408693062278, 7.282856582413251, 7.493997598078079, 7.6993506219680645, 7.899367063252601, 8.094442537939226, 8.284926070883193, 8.47112743381895, 8.653323061113575, 8.831760866327848, 9.006664199358164, 9.178235124467015, 9.34665715643834, 9.512097560475294, 9.67470929795826, 9.834632682515398, 9.991996797437437, 10.14692071517266, 10.299514551666988, 10.449880382090507, 10.598113039593418, 10.744300814850636, 10.888526071052961, 11.030865786510144, 11.171392035015154, 11.310172412478956, 11.44727041700335, 11.582745788456208, 11.71665481270145, 11.8490505948789, 11.979983305497552, 12.109500402576485, 12.237646832622687, 12.364465212858986, 12.489995996796798, 12.614277624977186, 12.737346662472529, 12.85923792454281, 12.979984591670364, 13.099618315050254, 13.218169313486646, 13.335666462535723, 13.452137376640191, 13.567608484917304, 13.682105101189656, 13.79565148878443, 13.908270920570969, 14.019985734657508, 14.130817386124557, 14.24078649513432, 14.34991289172168, 14.458215657542256, 14.565713164826501, 14.672423112764983, 14.778362561528935, 14.883547964111248, 14.987995196156158, 15.091719583930788, 15.194735930578064, 15.297058540778357, 15.398701243936129, 15.499677415998052, 15.600000000000003, 15.699681525432293, 15.798734126505202, 15.897169559390127, 15.994999218505768, 16.092234151913154, 16.188885075878453, 16.284962388657828, 16.38047618355462, 16.47543626129518, 16.569852141766386, 16.66373307515456, 16.757088052522732, 16.849925815860438, 16.9422548676379, 17.034083479894072, 17.12541970288612, 17.216271373325874, 17.30664612222715, 17.39655138238611, 17.485994395515515, 17.574982219052174, 17.663521732655695, 17.751619644415552], [0.0, 1.7776388834631178, 2.513961017995307, 3.078960863668131, 3.5552777669262356, 3.9749213828703587, 4.354308211415448, 4.703190406521939, 5.027922035990614, 5.332916650389353, 5.621387729022079, 5.895761189193471, 6.157921727336262, 6.409368143584826, 6.6513156593263565, 6.884765791223402, 7.110555533852471, 7.329392880723478, 7.541883053985921, 7.748548251124208, 7.949842765740717, 8.14616474176652, 8.337865434270332, 8.525256594378847, 8.708616422830897, 8.88819441731559, 9.064215354899728, 9.236882591004392, 9.406380813043878, 9.572878355019457, 9.736529155710468, 9.897474425326898, 10.055844071981229, 10.211757928975796, 10.365326815879952, 10.516653460107925, 10.665833300778706, 10.812955192730618, 10.95810202544218, 11.101351269102336, 11.242775458044157, 11.382442620105758, 11.520416659131737, 11.656757696718243, 11.791522378386942, 11.924764148611073, 12.05653349848123, 12.1868781892657, 12.315843454672525, 12.443472184241825, 12.569805089976535, 12.694880858046682, 12.818736287169653, 12.941406415069425, 13.062924634246345, 13.183322798141598, 13.302631318652713, 13.420879255846094, 13.53809440061636, 13.654303350958628, 13.769531582446804, 13.883803513446884, 13.997142565538153, 14.109571219565817, 14.221111067704943, 14.331782861877304, 14.441606558828557, 14.550601362143079, 14.658785761446955, 14.766177569025778, 14.872793954062567, 14.978651474682225, 15.083766107971842, 15.188153278130953, 15.291827882892221, 15.394804318340654, 15.497096502248416, 15.598717896032355, 15.699681525432293, 15.8, 15.899685531481435, 15.998749951168062, 16.09720472628711, 16.195060975494968, 16.29232948353304, 16.389020715100706, 16.485144827995903, 16.580711685570076, 16.675730868540665, 16.770211686201222, 16.864163187066236, 16.957594168985175, 17.050513188757694, 17.142928571279764, 17.23484841824842, 17.326280616450838, 17.417232845661793, 17.507712586171845, 17.59772712596715, 17.687283567580412, 17.77638883463118, 17.86504967807255], [0.0, 1.788854381999832, 2.5298221281347035, 3.098386676965934, 3.577708763999664, 4.000000000000001, 4.3817804600413295, 4.732863826479694, 5.059644256269407, 5.366563145999495, 5.656854249492381, 5.9329587896765315, 6.196773353931868, 6.44980619863884, 6.6932802122726045, 6.928203230275509, 7.155417527999328, 7.37563556583431, 7.589466384404111, 7.7974354758471724, 8.000000000000002, 8.19756061276768, 8.390470785361213, 8.579044235810889, 8.763560920082659, 8.94427190999916, 9.121403400793104, 9.295160030897803, 9.465727652959387, 9.633275663033837, 9.797958971132713, 9.959919678390987, 10.119288512538814, 10.276186062932105, 10.43072384832424, 10.583005244258363, 10.73312629199899, 10.881176406988356, 11.027239001672179, 11.171392035015154, 11.313708498984761, 11.454256850621084, 11.593101396951553, 11.730302638892145, 11.865917579353063, 12.0, 12.132600710482482, 12.263767773404714, 12.393546707863736, 12.521980673998824, 12.649110640673518, 12.774975538137053, 12.89961239727768, 13.023056476879768, 13.145341380123988, 13.266499161421601, 13.386560424545209, 13.505554412907307, 13.623509092741124, 13.740451229854134, 13.856406460551018, 13.971399357258385, 14.085453489327207, 14.198591479439079, 14.310835055998655, 14.422205101855956, 14.532721699667961, 14.642404174178502, 14.75127113166862, 14.85934049680537, 14.966629547095767, 15.07315494513342, 15.178932768808222, 15.28397853963424, 15.388307249337076, 15.491933384829668, 15.594870951694345, 15.697133496278868, 15.798734126505202, 15.899685531481435, 16.000000000000004, 16.09968943799849, 16.19876538505327, 16.29723902997069, 16.39512122553536, 16.492422502470642, 16.58915308266218, 16.68532289169137, 16.780941570722426, 16.87601848778319, 16.970562748477143, 17.064583206161235, 17.158088471621777, 17.25108692227826, 17.343586710943043, 17.435595774162696, 17.527121840165318, 17.618172436436197, 17.708754896942924, 17.798876369029593, 17.88854381999832, 17.97776404339539], [0.0, 1.8, 2.545584412271571, 3.1176914536239795, 3.6, 4.024922359499622, 4.409081537009721, 4.762352359916263, 5.091168824543142, 5.4, 5.692099788303083, 5.969924622639721, 6.235382907247959, 6.489992295835181, 6.734983296193095, 6.97137002317335, 7.2, 7.42159012611179, 7.636753236814713, 7.8460180983732135, 8.049844718999244, 8.248636250920512, 8.442748367682174, 8.632496741962896, 8.818163074019441, 9.000000000000002, 9.178235124467014, 9.353074360871938, 9.524704719832526, 9.693296652842108, 9.85900603509299, 10.02197585309404, 10.182337649086284, 10.340212763768452, 10.495713410721542, 10.648943609579309, 10.8, 10.948972554536796, 11.095945205344158, 11.240996397117119, 11.384199576606166, 11.52562362737913, 11.66533325713415, 11.8033893437436, 11.939849245279442, 12.074767078498864, 12.208193969625484, 12.34017828072188, 12.470765814495918, 12.600000000000001, 12.727922061357857, 12.854571171377131, 12.979984591670362, 13.104197800704934, 13.227244611029162, 13.349157276772194, 13.46996659238619, 13.58970198348735, 13.708391590555037, 13.826062346163495, 13.9427400463467, 14.058449416631978, 14.17321417322126, 14.28705707974879, 14.4, 14.512063946937388, 14.62326912834473, 14.73363498937041, 14.84318025222358, 14.951922953252536, 15.059880477613362, 15.167069591717446, 15.273506473629427, 15.379206741571556, 15.484185480676729, 15.588457268119896, 15.692036196746427, 15.794935897305821, 15.897169559390127, 15.998749951168062, 16.09968943799849, 16.200000000000003, 16.29969324864735, 16.39878044245974, 16.497272501841024, 16.5951800231272, 16.69251329189227, 16.789282295559868, 16.88549673536435, 16.981166037701886, 17.07629936490925, 17.17090562550502, 17.264993483925792, 17.35857136978732, 17.451647486698786, 17.544229820656135, 17.636326148038883, 17.72794404323299, 17.819090885900998, 17.90977386791916, 18.000000000000004, 18.089776118017607], [0.0, 1.8110770276274835, 2.5612496949731396, 3.136877428271625, 3.622154055254967, 4.049691346263318, 4.436214602563767, 4.791659420284376, 5.122499389946279, 5.43323108288245, 5.727128425310542, 6.006662967072484, 6.27375485654325, 6.529931086925804, 6.776429738438967, 7.014271166700073, 7.244308110509934, 7.467261881037788, 7.68374908491942, 7.894301742396222, 8.099382692526635, 8.299397568498573, 8.494704232638123, 8.685620300243388, 8.872429205127535, 9.055385138137417, 9.234717104492159, 9.410632284814875, 9.583318840568753, 9.752948272189288, 9.919677414109795, 10.083650132764426, 10.244998779892558, 10.403845442911964, 10.56030302595527, 10.7144761887831, 10.8664621657649, 11.016351483136331, 11.164228589562292, 11.310172412478956, 11.454256850621084, 11.596551211459381, 11.73712060089697, 11.876026271442818, 12.013325934144968, 12.149074038789953, 12.283322026227271, 12.416118556135006, 12.5475097130865, 12.677539193392384, 12.806248474865699, 12.933676971379796, 13.059862173851608, 13.18483977907961, 13.308643807691302, 13.431306712304654, 13.552859476877934, 13.67333170810977, 13.792751719653337, 13.911146609823362, 14.028542333400146, 14.14496376806954, 14.26043477598071, 14.37497826085313, 14.488616221019868, 14.601369798755185, 14.713259326199617, 14.824304368165139, 14.934523762075576, 15.043935655273193, 15.15255753990065, 15.260406285548234, 15.36749816983884, 15.473848907107762, 15.579473675320358, 15.684387141358124, 15.788603484792445, 15.892136420255147, 15.994999218505768, 16.09720472628711, 16.19876538505327, 16.29969324864735, 16.400000000000002, 16.49969696691427, 16.598795136997147, 16.697305171793445, 16.795237420173617, 16.892601931022945, 16.989408465276245, 17.085666507338836, 17.181385275931625, 17.276573734395374, 17.371240600486775, 17.465394355696642, 17.55904325411838, 17.652195330892983, 17.74485841025507, 17.837040113202644, 17.928747864811978, 18.019988901217452, 18.110770276274835, 18.201098867925534], [0.0, 1.8220867158288598, 2.576819745345025, 3.1559467676119004, 3.6441734316577197, 4.0743097574926725, 4.463182720884279, 4.82078831727758, 5.15363949069005, 5.466260147486579, 5.761944116355173, 6.043177971895251, 6.311893535223801, 6.569627082262737, 6.817624219623724, 7.056911505750939, 7.288346863315439, 7.512655988397179, 7.730459236035075, 7.942291860665913, 8.148619514985345, 8.349850298059241, 8.546344247688598, 8.738420909981391, 8.926365441768558, 9.1104335791443, 9.290855719469548, 9.4678403028357, 9.64157663455516, 9.812237257628864, 9.979979959899719, 10.144949482377918, 10.3072789813801, 10.46709128650362, 10.62449998823474, 10.779610382569492, 10.932520294973157, 11.083320801997928, 11.232096865679178, 11.37892789325954, 11.523888232710346, 11.667047612828192, 11.80847153530041, 11.948221624995076, 12.086355943790503, 12.222929272478016, 12.357993364620325, 12.491597175701752, 12.623787070447602, 12.754607010802019, 12.884098726725126, 13.012301871690498, 13.139254164525473, 13.264991519032344, 13.389548162652838, 13.512956745287095, 13.635248439247448, 13.756453031214114, 13.876599006961325, 13.995713629536722, 14.113823011501879, 14.230952181776171, 14.347125147568763, 14.46236495183274, 14.576693726630879, 14.690132742763081, 14.802702455970666, 14.914422550001726, 15.025311976794358, 15.135388994010032, 15.244671200127604, 15.353175567289002, 15.46091847207015, 15.567915724335098, 15.674182594317317, 15.7797338380595, 15.884583721331826, 15.988746042138514, 16.092234151913154, 16.195060975494968, 16.29723902997069, 16.39878044245974, 16.49969696691427, 16.599999999999998, 16.699700596118483, 16.798809481626964, 16.89733706830754, 16.9952934661335, 17.092688495377196, 17.189531698100446, 17.28583234906552, 17.381599466102077, 17.476841819962782, 17.57156794369814, 17.66578614157887, 17.759504497592268, 17.852730883537117, 17.94547296674011, 18.037738217415175, 18.129533915685755, 18.2208671582886, 18.311744864976685], [0.0, 1.8330302779823362, 2.5922962793631443, 3.174901573277509, 3.6660605559646724, 4.09878030638384, 4.48998886412873, 4.849742261192857, 5.184592558726289, 5.499090833947008, 5.796550698475776, 6.079473661428266, 6.349803146555018, 6.609084656743323, 6.858571279792899, 7.099295739719539, 7.332121111929345, 7.557777451076474, 7.776888838089433, 7.9899937421752725, 8.19756061276768, 8.4, 8.597674104081872, 8.790904390334365, 8.97997772825746, 9.165151389911681, 9.34665715643834, 9.524704719832528, 9.699484522385713, 9.871170143402454, 10.039920318408907, 10.20588065773846, 10.369185117452577, 10.529957264870548, 10.688311372709911, 10.844353369380768, 10.998181667894016, 11.149887891813083, 11.299557513460428, 11.447270417003349, 11.593101396951552, 11.737120600896969, 11.879393923934, 12.019983361053376, 12.158947322856532, 12.296340919151518, 12.432216214336044, 12.566622457924007, 12.699606293110037, 12.831211945876353, 12.961481396815723, 13.09045453756286, 13.218169313486646, 13.344661854089823, 13.469966592386191, 13.594116374373144, 13.717142559585797, 13.839075113604956, 13.95994269329212, 14.079772725438433, 14.198591479439077, 14.316424134538625, 14.433294842134972, 14.54922678357857, 14.66424222385869, 14.778362561528933, 14.891608375189028, 15.003999466808843, 15.115554902152947, 15.226293048539425, 15.336231610144653, 15.44538766104626, 15.553777676178866, 15.661417560361516, 15.768322675541619, 15.874507866387544, 15.979987484350545, 16.08477541030648, 16.188885075878453, 16.29232948353304, 16.39512122553536, 16.497272501841024, 16.598795136997147, 16.699700596118483, 16.8, 16.899704139422088, 16.998823488700623, 17.09736821853001, 17.195348208163743, 17.29277305697383, 17.389652095427326, 17.485994395515515, 17.58180878066873, 17.677103835187484, 17.77188791321845, 17.866169147301836, 17.95995545651492, 18.053254554234815, 18.14607395554201, 18.238420984284797, 18.330302779823363, 18.42172630347113], [0.0, 1.8439088914585775, 2.6076809620810595, 3.193743884534263, 3.687817782917155, 4.123105625617661, 4.5166359162544865, 4.878524367060187, 5.215361924162119, 5.531726674375732, 5.830951894845301, 6.115553940568263, 6.387487769068526, 6.648308055437865, 6.899275324264136, 7.1414284285428495, 7.37563556583431, 7.602631123499285, 7.823042886243179, 8.037412518964048, 8.246211251235321, 8.449852069711044, 8.648699324175862, 8.843076387773658, 9.033271832508973, 9.219544457292889, 9.402127418834528, 9.581231653602789, 9.757048734120374, 9.92975326984513, 10.099504938362077, 10.26645021416848, 10.430723848324238, 10.59245014149229, 10.75174404457249, 10.908712114635716, 11.063453348751464, 11.216059914247962, 11.36661779070626, 11.515207336387826, 11.661903789690601, 11.806777714516354, 11.949895397031726, 12.091319200153471, 12.231107881136525, 12.36931687685298, 12.505998560690786, 12.641202474448386, 12.774975538137053, 12.907362240210043, 13.038404810405298, 13.168143377105219, 13.29661611087573, 13.42385935563987, 13.54990774876346, 13.674794331177344, 13.798550648528272, 13.921206844235885, 14.042791745233568, 14.163332941084171, 14.282856857085699, 14.401388821915754, 14.51895313030523, 14.635573101180562, 14.75127113166862, 14.866068747318506, 14.979986648859205, 15.093044755780724, 15.20526224699857, 15.316657598836635, 15.427248620541514, 15.537052487521564, 15.646085772486359, 15.754364474646383, 15.861904047118681, 15.968719422671313, 16.074825037928097, 16.180234856144704, 16.284962388657828, 16.389020715100706, 16.492422502470642, 16.5951800231272, 16.697305171793445, 16.798809481626964, 16.899704139422088, 17.0, 17.099707599839245, 17.198837169994956, 17.297398648351724, 17.395401691251628, 17.492855684535904, 17.58976975403601, 17.686152775547317, 17.782013384316187, 17.877359984069237, 17.97220075561143, 18.066543665017946, 18.160396471443022, 18.253766734567417, 18.34666182170479, 18.439088914585778, 18.531055015837605], [0.0, 1.854723699099141, 2.6229754097208002, 3.2124756808418025, 3.709447398198282, 4.147288270665545, 4.543126676640219, 4.907137658554119, 5.2459508194416005, 5.5641710972974225, 5.865151319446072, 6.15142259969188, 6.424951361683605, 6.687301398920196, 6.939740629158989, 7.183313998427188, 7.418894796396564, 7.647221717722065, 7.868926229162401, 8.084553172563096, 8.29457654133109, 8.499411744350311, 8.699425268372618, 8.894942383174834, 9.086253353280439, 9.273618495495704, 9.457272334029513, 9.637427042525408, 9.814275317108239, 9.987992791347018, 10.158740079360236, 10.32666451474047, 10.491901638883201, 10.654576481493764, 10.81480466767662, 10.972693379476162, 11.128342194594845, 11.281843820936365, 11.433284742365162, 11.582745788456208, 11.730302638892145, 11.87602627144282, 12.019983361053377, 12.162236636408617, 12.30284519938376, 12.441864811996632, 12.579348154813111, 12.715345060201868, 12.84990272336721, 12.983065893693986, 13.114877048604002, 13.24537655183876, 13.374602797840392, 13.502592343694602, 13.629380029920657, 13.75499909123952, 13.879481258317979, 14.002856851371437, 14.125154866407662, 14.246403054806501, 14.366627996854376, 14.485855169785456, 14.604109010822947, 14.721412975662357, 14.837789592793127, 14.953260514014994, 15.06784656146989, 15.181567771478676, 15.29444343544413, 15.406492138056606, 15.51773179301666, 15.628179676469042, 15.737852458324802, 15.846766231632245, 15.954936540143304, 16.06237840420901, 16.169106345126192, 16.275134408047144, 16.38047618355462, 16.485144827995903, 16.58915308266218, 16.69251329189227, 16.795237420173617, 16.89733706830754, 16.998823488700623, 17.099707599839245, 17.200000000000003, 17.29971098024473, 17.398850536745236, 17.497428382479523, 17.59545395833822, 17.69293644367718, 17.78988476634967, 17.886307612249098, 17.98221343439122, 18.077610461562667, 18.172506706560878, 18.266909974048705, 18.360827868045604, 18.45426779907564, 18.547236990991408, 18.639742487491613], [0.0, 1.8654758106177631, 2.6381811916545836, 3.231098884280703, 3.7309516212355263, 4.171330722922843, 4.5694638635183455, 4.935585071701227, 5.276362383309167, 5.596427431853289, 5.8991524815010505, 6.187083319303208, 6.462197768561406, 6.726068688320096, 6.979971346646059, 7.224956747275377, 7.4619032424710525, 7.691553809211764, 7.914543574963752, 8.13142054010245, 8.342661445845685, 8.548684109265006, 8.749857141690944, 8.946507698538017, 9.138927727036691, 9.327379053088816, 9.512097560475294, 9.693296652842108, 9.871170143402454, 10.045894683899489, 10.21763181955584, 10.386529738079028, 10.552724766618335, 10.716342659695052, 10.877499712709719, 11.036303729057115, 11.192854863706579, 11.347246362003428, 11.499565209172042, 11.649892703368561, 11.798304963002101, 11.944873377311291, 12.089665007765932, 12.232742946698421, 12.374166638606416, 12.513992168768526, 12.652272523147769, 12.789057822998535, 12.924395537122813, 13.058330674324342, 13.19090595827292, 13.322161986704712, 13.452137376640191, 13.58086889709197, 13.708391590555037, 13.83473888441701, 13.959942693292119, 14.084033513166604, 14.207040508142434, 14.328991590478376, 14.449913494550755, 14.569831845289087, 14.688771221582831, 14.80675521510368, 14.923806484942105, 15.039946808416577, 15.155197128378108, 15.269577597301112, 15.383107618423528, 15.49580588417395, 15.607690412101338, 15.718778578502848, 15.829087149927505, 15.938632312717425, 16.047429700734007, 16.155494421403514, 16.2628410802049, 16.369483803712324, 16.47543626129518, 16.580711685570076, 16.68532289169137, 16.789282295559868, 16.892601931022945, 16.9952934661335, 17.09736821853001, 17.198837169994956, 17.29971098024473, 17.400000000000002, 17.499714283381888, 17.598863599675976, 17.69745744450315, 17.795505050433384, 17.893015397076034, 17.989997220677942, 18.086459023258257, 18.182409081307128, 18.277855454073382, 18.37280599146467, 18.467268341582088, 18.561249957909627, 18.65475810617763, 18.74779987091819], [0.0, 1.876166303929372, 2.6532998322843198, 3.2496153618543846, 3.752332607858744, 4.1952353926806065, 4.595650117230424, 4.963869458396343, 5.3065996645686395, 5.628498911788116, 5.932958789676531, 6.222539674441619, 6.499230723708769, 6.764613810115105, 7.019971509913698, 7.26636084983398, 7.504665215717488, 7.735631842325486, 7.95989949685296, 8.178019320104351, 8.390470785361213, 8.597674104081872, 8.8, 8.997777503361595, 9.191300234460847, 9.38083151964686, 9.566608594481119, 9.748846085563153, 9.927738916792686, 10.103464752252071, 10.276186062932103, 10.446051885760477, 10.613199329137279, 10.777754868245985, 10.939835464941876, 11.099549540409287, 11.256997823576231, 11.412274094149685, 11.565465835840769, 11.71665481270145, 11.865917579353061, 12.013325934144966, 12.158947322856532, 12.302845199383759, 12.445079348883239, 12.585706178041818, 12.724778976469494, 12.862348152650823, 12.998461447417538, 13.133164127505603, 13.266499161421601, 13.398507379555383, 13.52922762023021, 13.6586968631711, 13.786950351691269, 13.91402170474087, 14.039943019827396, 14.164744967700619, 14.288456879593403, 14.411106827721456, 14.53272169966796, 14.653327267211361, 14.77294825009551, 14.891608375189028, 15.009330431434975, 15.126136320951229, 15.24204710660612, 15.357083056361974, 15.471263684650973, 15.584607791022526, 15.697133496278868, 15.808858276295604, 15.91979899370592, 16.029971927611104, 16.13939280146561, 16.24807680927192, 16.356038640208702, 16.463292501805345, 16.569852141766386, 16.675730868540665, 16.780941570722426, 16.88549673536435, 16.989408465276245, 17.092688495377196, 17.195348208163743, 17.297398648351724, 17.398850536745236, 17.499714283381888, 17.6, 17.69971751187007, 17.798876369029593, 17.897485856957676, 17.99555500672319, 18.093092604637828, 18.19010720144332, 18.286607121059937, 18.382600468921694, 18.47809513992176, 18.57309882599024, 18.667619023324857, 18.76166303929372, 18.855237999028283], [0.0, 1.8867962264113207, 2.6683328128252666, 3.2680269276736387, 3.7735924528226414, 4.219004621945797, 4.621688003316537, 4.991993589739474, 5.336665625650533, 5.660388679233962, 5.966573556070519, 6.2577951388648065, 6.536053855347277, 6.802940540677979, 7.059745037889116, 7.307530362578043, 7.547184905645283, 7.779460135510689, 8.0049984384758, 8.224354077980836, 8.438009243891594, 8.646386528486914, 8.849858755935035, 9.048756820690896, 9.243376006633074, 9.433981132056603, 9.620810776644555, 9.804080783020915, 9.983987179478948, 10.160708636704431, 10.33440854621105, 10.505236789335116, 10.673331251301066, 10.838819123871383, 11.001818031580052, 11.16243700990066, 11.320777358467923, 11.476933388322859, 11.63099307883897, 11.783038657324349, 11.933147112141038, 12.081390648431166, 12.227837094106219, 12.372550262577233, 12.515590277729613, 12.65701386583739, 12.796874618437112, 12.935223229616101, 13.072107710694555, 13.207573584879245, 13.341664064126334, 13.47442021016118, 13.605881081355959, 13.736083866954221, 13.865064009949611, 13.992855319769443, 14.119490075778232, 14.244999122499095, 14.369411957348847, 14.492756811593852, 14.615060725156086, 14.736349615830916, 14.85664834341851, 14.975980769218422, 15.094369811290566, 15.211837495845133, 15.328405005087776, 15.444092721814382, 15.558920271021378, 15.672906558772052, 15.786069808536892, 15.898427595205758, 16.0099968769516, 16.12079402510931, 16.230834852218784, 16.34013463836819, 16.448708155961672, 16.556569693025182, 16.66373307515456, 16.770211686201222, 16.87601848778319, 16.981166037701886, 17.085666507338836, 17.189531698100446, 17.29277305697383, 17.395401691251628, 17.497428382479523, 17.598863599675976, 17.69971751187007, 17.799999999999997, 17.899720668211557, 17.99888885459322, 18.09751364138179, 18.19560386467017, 18.2931681236466, 18.390214789392754, 18.48675201326615, 18.582787734890587, 18.678329689776866, 18.77338541659442, 18.867962264113206, 18.962067397834026], [0.0, 1.8973665961010275, 2.6832815729997477, 3.286335345030997, 3.794733192202055, 4.242640687119286, 4.6475800154489, 5.019960159204453, 5.366563145999495, 5.692099788303082, 6.0, 6.29285308902091, 6.572670690061994, 6.841052550594828, 7.099295739719539, 7.348469228349534, 7.58946638440411, 7.8230428862431785, 8.049844718999243, 8.270429251254134, 8.485281374238571, 8.694826047713663, 8.899438184514796, 9.099450532861862, 9.2951600308978, 9.486832980505138, 9.67470929795826, 9.85900603509299, 10.039920318408907, 10.21763181955584, 10.392304845413264, 10.564090116995406, 10.73312629199899, 10.899541274750971, 11.063453348751466, 11.224972160321824, 11.384199576606164, 11.541230437002808, 11.696153213770756, 11.8490505948789, 12.0, 12.149074038789953, 12.296340919151518, 12.44186481199663, 12.58570617804182, 12.727922061357855, 12.86856635371633, 13.007690033207279, 13.145341380123988, 13.281566172707194, 13.416407864998739, 13.54990774876346, 13.682105101189656, 13.813037319865607, 13.942740046346701, 14.071247279470288, 14.198591479439077, 14.324803663575986, 14.449913494550756, 14.573949361789342, 14.696938456699067, 14.818906842274163, 14.939879517586478, 15.05988047761336, 15.17893276880822, 15.297058540778353, 15.414279094398154, 15.53061492665374, 15.646085772486357, 15.760710643876436, 15.874507866387544, 15.987495113369073, 16.099689437998485, 16.211107303327555, 16.321764610482532, 16.431676725154983, 16.540858502508268, 16.64932431061393, 16.757088052522732, 16.864163187066236, 16.970562748477143, 17.07629936490925, 17.181385275931625, 17.28583234906552, 17.389652095427326, 17.492855684535904, 17.59545395833822, 17.69745744450315, 17.798876369029593, 17.899720668211557, 18.0, 18.099723754798028, 18.198901065723724, 18.29754081837229, 18.39565166010707, 18.49324200890693, 18.5903200617956, 18.686893802876927, 18.78297101099823, 18.87855926706273, 18.973665961010276, 19.068298298484848], [0.0, 1.9078784028338913, 2.698147512646408, 3.3045423283716615, 3.8157568056677826, 4.266145801540309, 4.673328578219169, 5.047771785649585, 5.396295025292816, 5.7236352085016735, 6.0332412515993425, 6.327716807822551, 6.609084656743323, 6.878953408767936, 7.138627319029899, 7.389181280764466, 7.631513611335565, 7.866384175718855, 8.094442537939225, 8.316249154516717, 8.532291603080617, 8.742997197757758, 8.948742928478838, 9.1498633869583, 9.346657156438338, 9.539392014169458, 9.728309205612248, 9.913626985114984, 10.09554357129917, 10.274239631233058, 10.449880382090505, 10.6226173799116, 10.792590050585632, 10.959927007056207, 11.124747188138704, 11.287160847617969, 11.447270417003347, 11.605171261123207, 11.760952342391326, 11.914696806885186, 12.066482503198685, 12.216382443260363, 12.364465212858986, 12.51079533842673, 12.655433615645101, 12.798437404620923, 12.93986089569745, 13.079755349393963, 13.218169313486646, 13.35514881983724, 13.490737563232042, 13.62497706420088, 13.757906817535872, 13.889564428015735, 14.019985734657508, 14.149204924659195, 14.277254638059798, 14.404166064024672, 14.529969029560938, 14.654692081377895, 14.778362561528931, 14.901006677402705, 15.022649566571138, 15.143315356948756, 15.26302722267113, 15.381807436059, 15.49967741599805, 15.616657773031974, 15.73276835143771, 15.848028268526026, 15.962455951387932, 16.076069171286868, 16.18888507587845, 16.300920219423197, 16.412190591142913, 16.522711641858308, 16.632498309033434, 16.741565040341957, 16.849925815860438, 16.957594168985175, 17.064583206161235, 17.17090562550502, 17.276573734395374, 17.381599466102077, 17.485994395515515, 17.58976975403601, 17.69293644367718, 17.795505050433384, 17.897485856957676, 17.99888885459322, 18.099723754798028, 18.2, 18.2997267739166, 18.398913011371082, 18.497567407634985, 18.59569842732453, 18.693314312876677, 18.790423092628863, 18.887032588524857, 18.983150423467652, 19.078784028338916, 19.173940648703386], [0.0, 1.918332609325088, 2.7129319932501073, 3.3226495451672307, 3.836665218650176, 4.289522117905444, 4.698936049788292, 5.075431016179809, 5.4258639865002145, 5.754997827975264, 6.066300355241241, 6.362389488234747, 6.645299090334461, 6.916646586316234, 7.177743377970545, 7.429670248402684, 7.673330437300352, 7.909487973314076, 8.138795979750322, 8.36181798414675, 8.579044235810889, 8.790904390334365, 8.997777503361595, 9.200000000000001, 9.397872099576585, 9.59166304662544, 9.781615408509989, 9.967948635501692, 10.150862032359617, 10.330537256115967, 10.507140429250958, 10.680823938254951, 10.851727973000429, 11.019981851164731, 11.18570516328765, 11.349008767288886, 11.509995655950528, 11.66876171665186, 11.825396399275588, 11.979983305497552, 12.132600710482482, 12.283322026227271, 12.432216214336044, 12.57934815481311, 12.724778976469494, 12.86856635371633, 13.010764773832475, 13.151425778218877, 13.290598180668923, 13.428328265275615, 13.564659966250538, 13.699635031634969, 13.833293172632468, 13.965672200076876, 14.096808149364879, 14.226735395022994, 14.35548675594109, 14.48309359218534, 14.609585894199741, 14.73499236511509, 14.859340496805368, 14.982656640262435, 15.104966070799366, 15.226293048539425, 15.346660874600705, 15.466091943344964, 15.584607791022526, 15.702229141112419, 15.818975946628152, 15.934867429633673, 16.049922118191105, 16.164157880941403, 16.277591959500644, 16.390240998838305, 16.502121075789017, 16.61324772583615, 16.7236359682935, 16.833300330000654, 16.9422548676379, 17.050513188757694, 17.158088471621777, 17.264993483925792, 17.371240600486775, 17.476841819962782, 17.58180878066873, 17.686152775547317, 17.78988476634967, 17.893015397076034, 17.99555500672319, 18.09751364138179, 18.198901065723724, 18.2997267739166, 18.400000000000002, 18.499729727755486, 18.598924700100273, 18.69759342803239, 18.79574419915317, 18.893385085791273, 18.990523952750753, 19.08716846470424, 19.18332609325088, 19.27900412365743], [0.0, 1.9287301521985911, 2.727636339397171, 3.340658617698014, 3.8574603043971822, 4.312771730569565, 4.724404724407087, 5.10294032886923, 5.455272678794342, 5.786190456595773, 6.099180272790763, 6.3968742366877915, 6.681317235396028, 6.954135460285485, 7.216647421067487, 7.469939758793239, 7.7149206087943645, 7.952358140828418, 8.182909018191515, 8.407139822793482, 8.62554346113913, 8.838551917593742, 9.046546302318914, 9.249864863877743, 9.448809448814174, 9.643650760992957, 9.834632682515398, 10.021975853094041, 10.20588065773846, 10.386529738079028, 10.564090116995406, 10.73871500692704, 10.910545357588685, 11.079711187571634, 11.24633273560764, 11.41052146047673, 11.572380913191546, 11.732007500849972, 11.889491158161482, 12.04491593993084, 12.198360545581526, 12.349898785010348, 12.499599993599798, 12.647529403009901, 12.793748473375583, 12.938315191708694, 13.081284340614268, 13.222707740852478, 13.362634470792056, 13.501111065390138, 13.638181696985857, 13.773888339898798, 13.90827092057097, 14.041367454774484, 14.173214173221261, 14.30384563675098, 14.433294842134973, 14.561593319413918, 14.688771221582833, 14.814857407346182, 14.939879517586478, 15.063864046120438, 15.186836405255704, 15.30882098660769, 15.429841217588729, 15.549919613940132, 15.669077828640715, 15.78733669749271, 15.904716281656835, 16.02123590738243, 16.13691420315545, 16.251769134466564, 16.36581803638303, 16.479077644091614, 16.59156412156491, 16.703293088490067, 16.814279645586964, 16.924538398432023, 17.034083479894072, 17.142928571279764, 17.25108692227826, 17.35857136978732, 17.465394355696642, 17.57156794369814, 17.677103835187484, 17.782013384316187, 17.886307612249098, 17.989997220677942, 18.093092604637828, 18.19560386467017, 18.29754081837229, 18.398913011371082, 18.499729727755486, 18.6, 18.699732618409282, 18.79893614011176, 18.897618897628348, 18.995789007040486, 19.0934543757802, 19.190622710063373, 19.287301521985913, 19.38349813630141], [0.0, 1.9390719429665317, 2.7422618401604177, 3.3585711247493335, 3.8781438859330635, 4.335896677735761, 4.749736834815168, 5.130302135352265, 5.4845236803208355, 5.817215828899595, 6.131883886702357, 6.431174076325411, 6.717142249498667, 6.9914233171794145, 7.255342858886822, 7.5099933422074345, 7.756287771866127, 7.994998436522675, 8.226785520481254, 8.452218643646177, 8.671793355471522, 8.885943956609225, 9.09505360072166, 9.299462350050137, 9.499473669630335, 9.695359714832659, 9.887365675446622, 10.075713374248, 10.26060427070453, 10.442221985765292, 10.620734437881403, 10.796295661012625, 10.969047360641671, 11.139120252515458, 11.306635220082057, 11.47170431975999, 11.63443165779919, 11.794914158229385, 11.95324223798715, 12.109500402576485, 12.263767773404714, 12.416118556135007, 12.566622457924009, 12.715345060201866, 12.862348152650823, 13.007690033207279, 13.15142577821888, 13.293607486307094, 13.434284498997334, 13.573503600765722, 13.71130920080209, 13.847743498491011, 13.982846634358829, 14.116656828017039, 14.249210504445502, 14.380542409798041, 14.510685717773644, 14.63967212747608, 14.767531953579788, 14.894294209528695, 15.019986684414869, 15.144636014114042, 15.268267747193851, 15.390906406056793, 15.512575543732254, 15.633297796690243, 15.753094934012175, 15.871987903221198, 15.98999687304535, 16.10714127336071, 16.2234398325386, 16.33891061240008, 16.453571040962508, 16.56743794314619, 16.680527569594435, 16.792855623746668, 16.904437287292353, 17.015287244122565, 17.12541970288612, 17.23484841824842, 17.343586710943043, 17.451647486698786, 17.55904325411838, 17.66578614157887, 17.77188791321845, 17.877359984069237, 17.98221343439122, 18.086459023258257, 18.19010720144332, 18.2931681236466, 18.39565166010707, 18.497567407634985, 18.598924700100273, 18.699732618409282, 18.8, 18.89973544788392, 18.99894733926067, 19.097643833729858, 19.195832881122925, 19.293522228976236, 19.390719429665317, 19.48743184721887], [0.0, 1.9493588689617927, 2.756809750418044, 3.3763886032268267, 3.8987177379235853, 4.358898943540674, 4.774934554525329, 5.15751878329105, 5.513619500836088, 5.848076606885377, 6.164414002968976, 6.465291950097845, 6.752777206453653, 7.0285133563222315, 7.293833011524187, 7.549834435270749, 7.797435475847171, 8.037412518964047, 8.270429251254132, 8.497058314499201, 8.717797887081348, 8.933084573650918, 9.143303560529969, 9.348796714016196, 9.549869109050658, 9.746794344808963, 9.939818911831342, 10.12916580968048, 10.3150375665821, 10.497618777608567, 10.67707825203131, 10.853570840972107, 11.027239001672177, 11.198214143335536, 11.366617790706258, 11.532562594670795, 11.696153213770755, 11.85748708622531, 12.016655108639842, 12.17374223482656, 12.328828005937952, 12.48198702130394, 12.633289357883006, 12.782800945019833, 12.93058390019569, 13.07669683062202, 13.221195104830727, 13.36413109783049, 13.505554412907307, 13.645512082732548, 13.784048752090222, 13.921206844235885, 14.057026712644463, 14.191546779685433, 14.324803663575986, 14.456832294800959, 14.587666023048374, 14.717336715588184, 14.845874847916507, 14.973309587395832, 15.099668870541498, 15.224979474534603, 15.349267083479912, 15.472556349873152, 15.594870951694341, 15.716233645501708, 15.836666315863322, 15.956190021430553, 16.074825037928093, 16.192590898309017, 16.30950643030009, 16.425589791541732, 16.540858502508264, 16.655329477377503, 16.769019053003664, 16.88194301613413, 16.994116628998402, 17.10555465338672, 17.216271373325874, 17.326280616450838, 17.435595774162696, 17.544229820656135, 17.652195330892983, 17.759504497592268, 17.866169147301836, 17.97220075561143, 18.077610461562667, 18.182409081307128, 18.286607121059937, 18.390214789392754, 18.49324200890693, 18.59569842732453, 18.69759342803239, 18.79893614011176, 18.89973544788392, 18.999999999999996, 19.099738218101315, 19.198958305074783, 19.297668252926307, 19.395875850293535, 19.493588689617926, 19.590814173994914], [0.0, 1.9595917942265426, 2.7712812921102037, 3.3941125496954285, 3.9191835884530852, 4.3817804600413295, 4.800000000000001, 5.184592558726289, 5.542562584220407, 5.878775382679628, 6.196773353931867, 6.499230723708769, 6.788225099390857, 7.065408693062278, 7.332121111929344, 7.58946638440411, 7.8383671769061705, 8.079603950689663, 8.313843876330612, 8.54166260162505, 8.763560920082659, 8.97997772825746, 9.191300234460847, 9.397872099576585, 9.600000000000001, 9.797958971132713, 9.991996797437439, 10.182337649086286, 10.369185117452577, 10.552724766618336, 10.73312629199899, 10.910545357588685, 11.085125168440815, 11.256997823576233, 11.426285485668561, 11.593101396951552, 11.757550765359255, 11.919731540601072, 12.0797350964332, 12.237646832622685, 12.393546707863734, 12.5475097130865, 12.699606293110037, 12.849902723367208, 12.998461447417538, 13.145341380123986, 13.29059818066892, 13.434284498997332, 13.576450198781714, 13.717142559585797, 13.85640646055102, 13.994284547628723, 14.130817386124557, 14.266043600101609, 14.4, 14.532721699667961, 14.664242223858688, 14.794593607125543, 14.923806484942105, 15.051910177781423, 15.17893276880822, 15.304901175767194, 15.429841217588727, 15.553777676178866, 15.676734353812341, 15.798734126505199, 15.91979899370592, 16.039950124610737, 16.159207901379325, 16.277591959500644, 16.39512122553536, 16.511813952440235, 16.627687752661224, 16.74275962916508, 16.85704600456438, 16.970562748477143, 17.0833252032501, 17.195348208163743, 17.30664612222715, 17.417232845661793, 17.527121840165318, 17.636326148038883, 17.74485841025507, 17.852730883537117, 17.95995545651492, 18.066543665017946, 18.172506706560878, 18.277855454073382, 18.382600468921694, 18.48675201326615, 18.5903200617956, 18.693314312876677, 18.79574419915317, 18.897618897628348, 18.99894733926067, 19.099738218101315, 19.200000000000003, 19.299740930903713, 19.398969044771427, 19.497692171126307, 19.595917942265427, 19.693653800145878], [0.0, 1.9697715603592212, 2.785677655436824, 3.411744421846397, 3.9395431207184424, 4.404543109109049, 4.824935232725928, 5.2115256883181535, 5.571355310873648, 5.909314681077663, 6.228964600958975, 6.532993188424431, 6.823488843692794, 7.102112361825883, 7.370210309075312, 7.628892449104261, 7.879086241436885, 8.121576201698781, 8.357032966310472, 8.586035173466273, 8.809086218218098, 9.026627277117408, 9.23904756996088, 9.446692542895637, 9.649870465451857, 9.848857801796106, 10.043903623591778, 10.23523326553919, 10.423051376636307, 10.607544484940897, 10.788883167408942, 10.967223896684157, 11.142710621747296, 11.315476127852511, 11.485643212288984, 11.653325705565774, 11.818629362155326, 11.98165264060013, 12.142487389328434, 12.301219451745427, 12.45792920191795, 12.61269202034205, 12.76557871778636, 12.916655913974019, 13.065986376848862, 13.213629327327144, 13.35964071373179, 13.504073459515837, 13.646977687385588, 13.788400922514548, 13.928388277184121, 14.066982618884552, 14.204224723651766, 14.340153416194685, 14.474805698177784, 14.60821686586012, 14.740420618150624, 14.871449156017043, 15.001333274079343, 15.130102445125743, 15.257784898208522, 15.384407690905752, 15.509996776273038, 15.634577064954462, 15.75817248287377, 15.880806024884254, 16.002499804718013, 16.12327510154187, 16.243152403397563, 16.36215144777728, 16.480291259562133, 16.597590186530095, 16.714065932620944, 16.829735589129143, 16.94461566398011, 17.058722109231983, 17.172070346932546, 17.28467529344998, 17.39655138238611, 17.507712586171845, 17.618172436436197, 17.72794404323299, 17.837040113202644, 17.94547296674011, 18.053254554234815, 18.160396471443022, 18.266909974048705, 18.37280599146467, 18.47809513992176, 18.582787734890587, 18.686893802876927, 18.790423092628863, 18.893385085791273, 18.995789007040486, 19.097643833729858, 19.198958305074783, 19.299740930903713, 19.400000000000006, 19.49974358805777, 19.598979565273293, 19.69771560359221, 19.795959183631396], [0.0, 1.9798989873223332, 2.8, 3.4292856398964497, 3.9597979746446663, 4.427188724235731, 4.849742261192857, 5.238320341483518, 5.6, 5.939696961966999, 6.260990336999411, 6.566582063752802, 6.8585712797928995, 7.138627319029899, 7.408103670980854, 7.668115805072325, 7.919595949289333, 8.16333265278342, 8.4, 8.630179604156568, 8.854377448471462, 9.073036977771006, 9.28654941299512, 9.495261976375376, 9.699484522385713, 9.899494936611665, 10.09554357129917, 10.287856919689348, 10.476640682967036, 10.662082348209472, 10.844353369380766, 11.023611023616535, 11.2, 11.373653766490346, 11.54469575172945, 11.713240371477058, 11.879393923933998, 12.043255373859678, 12.204917041913886, 12.364465212858986, 12.521980673998822, 12.677539193392384, 12.831211945876353, 12.983065893693984, 13.133164127505603, 13.281566172707192, 13.428328265275615, 13.573503600765722, 13.717142559585799, 13.85929291125633, 14.0, 14.13930691370691, 14.277254638059798, 14.413882197381803, 14.54922678357857, 14.683323874382122, 14.816207341961707, 14.947909552843836, 15.078461459976612, 15.207892687680301, 15.33623161014465, 15.463505424062165, 15.58974021592406, 15.714961024450554, 15.839191898578665, 15.96245595138793, 16.08477541030648, 16.206171663906314, 16.32666530556684, 16.446276174259022, 16.565023392678924, 16.682925402938178, 16.8, 16.9162643630324, 17.031735084835013, 17.146428199482248, 17.260359208313137, 17.3735431043872, 17.485994395515515, 17.59772712596715, 17.708754896942924, 17.819090885900998, 17.928747864811978, 18.037738217415175, 18.14607395554201, 18.253766734567417, 18.360827868045604, 18.467268341582088, 18.57309882599024, 18.678329689776866, 18.78297101099823, 18.887032588524857, 18.990523952750753, 19.0934543757802, 19.195832881122925, 19.297668252926307, 19.398969044771427, 19.49974358805777, 19.6, 19.699746191258406, 19.79898987322333, 19.897738564972656], [0.0, 1.9899748742132402, 2.814249455894058, 3.4467375879228177, 3.9799497484264803, 4.449719092257398, 4.874423042781577, 5.264978632435274, 5.628498911788116, 5.96992462263972, 6.29285308902091, 6.600000000000001, 6.893475175845635, 7.17495644586084, 7.445804187594514, 7.707139547199078, 7.959899496852961, 8.204876598706406, 8.442748367682174, 8.674099376880578, 8.899438184514796, 9.119210492142399, 9.333809511662428, 9.54358423235212, 9.748846085563153, 9.949874371066201, 10.146920715172659, 10.340212763768452, 10.529957264870548, 10.716342659695053, 10.89954127475097, 11.079711187571634, 11.256997823576231, 11.431535329954592, 11.60344776348823, 11.772850122209151, 11.93984924527944, 12.10454460109921, 12.267028980156525, 12.427389106324789, 12.58570617804182, 12.742056348957183, 12.89651115612281, 13.049137902558927, 13.200000000000003, 13.349157276772193, 13.496666255042392, 13.642580401082489, 13.78695035169127, 13.92982411949268, 14.07124727947029, 14.211263138792416, 14.34991289172168, 14.487235761179566, 14.623269128344731, 14.758048651498614, 14.891608375189028, 15.023980830658699, 15.15519712837811, 15.285287043428397, 15.414279094398156, 15.542200616386344, 15.669077828640715, 15.794935897305821, 15.919798993705921, 16.043690348545127, 16.166632302368978, 16.288646352597873, 16.40975319741281, 16.529972776747094, 16.64932431061393, 16.767826334978544, 16.88549673536435, 17.002352778365704, 17.118411141224527, 17.233687939614086, 17.348198753761157, 17.4619586530263, 17.574982219052174, 17.687283567580412, 17.798876369029593, 17.90977386791916, 18.019988901217452, 18.129533915685755, 18.238420984284797, 18.34666182170479, 18.45426779907564, 18.561249957909627, 18.667619023324857, 18.77338541659442, 18.87855926706273, 18.983150423467652, 19.08716846470424, 19.190622710063373, 19.293522228976236, 19.395875850293535, 19.497692171126307, 19.598979565273293, 19.699746191258406, 19.800000000000004, 19.899748742132402, 19.998999974998753], [0.0, 2.0, 2.8284271247461903, 3.4641016151377553, 4.0, 4.47213595499958, 4.898979485566357, 5.291502622129181, 5.656854249492381, 6.0, 6.324555320336759, 6.6332495807108005, 6.9282032302755105, 7.211102550927979, 7.483314773547883, 7.745966692414833, 8.0, 8.246211251235321, 8.485281374238571, 8.717797887081348, 8.94427190999916, 9.165151389911681, 9.38083151964686, 9.59166304662544, 9.797958971132713, 10.000000000000002, 10.19803902718557, 10.392304845413266, 10.583005244258363, 10.77032961426901, 10.954451150103322, 11.135528725660045, 11.313708498984761, 11.489125293076059, 11.661903789690601, 11.832159566199232, 12.0, 12.16552506059644, 12.328828005937954, 12.489995996796798, 12.649110640673518, 12.806248474865699, 12.961481396815723, 13.114877048604, 13.266499161421601, 13.416407864998737, 13.564659966250538, 13.71130920080209, 13.856406460551021, 14.0, 14.142135623730953, 14.282856857085703, 14.422205101855958, 14.56021977856104, 14.69693845669907, 14.832396974191328, 14.966629547095765, 15.0996688705415, 15.231546211727819, 15.362291495737216, 15.491933384829666, 15.62049935181331, 15.748015748023622, 15.874507866387544, 16.0, 16.1245154965971, 16.24807680927192, 16.3707055437449, 16.492422502470642, 16.61324772583615, 16.73320053068151, 16.852299546352718, 16.970562748477143, 17.088007490635064, 17.204650534085253, 17.320508075688775, 17.435595774162696, 17.549928774784245, 17.663521732655695, 17.77638883463118, 17.88854381999832, 18.000000000000004, 18.110770276274835, 18.2208671582886, 18.330302779823363, 18.439088914585778, 18.547236990991408, 18.65475810617763, 18.76166303929372, 18.867962264113206, 18.973665961010276, 19.078784028338916, 19.18332609325088, 19.287301521985913, 19.390719429665317, 19.493588689617926, 19.595917942265427, 19.69771560359221, 19.79898987322333, 19.899748742132402, 20.000000000000004, 20.099751242241783], [0.0, 2.0099751242241783, 2.8425340807103794, 3.481379037105843, 4.019950248448357, 4.494441010848847, 4.9234134500364695, 5.317894320123333, 5.685068161420759, 6.029925372672535, 6.356099432828282, 6.666333324999584, 6.962758074211686, 7.247068372797377, 7.520638270785267, 7.784600182411426, 8.039900496896713, 8.287339742040265, 8.527602242131138, 8.761278445523805, 8.988882021697695, 9.210863151735564, 9.427618999514142, 9.639502061828715, 9.846826900072939, 10.049875621120892, 10.248902380255167, 10.444137111317527, 10.635788640246666, 10.824047302187848, 11.009087155618309, 11.191067866830226, 11.370136322841518, 11.54642801908885, 11.72006825918689, 11.8911731969558, 12.05985074534507, 12.226201372462342, 12.390318801386833, 12.552290627610565, 12.712198865656564, 12.870120434556938, 13.026127590347027, 13.180288312476325, 13.332666649999169, 13.48332303254654, 13.63231455036158, 13.779695207079149, 13.925516148423371, 14.069825869569248, 14.212670403551897, 14.354093492798494, 14.494136745594753, 14.63283977907228, 14.770240350109408, 14.906374475371269, 15.041276541570534, 15.174979406905305, 15.307514494521966, 15.438911878756224, 15.569200364822851, 15.698407562552326, 15.826559954709047, 15.95368296037, 16.079800993793427, 16.20493751916372, 16.32911510156016, 16.45235545446305, 16.57467948408053, 16.69610733075228, 16.816658407662327, 16.936351437071682, 17.055204484262276, 17.17323498936645, 17.29045979724079, 17.406895185529212, 17.52255689104761, 17.63746013461122, 17.751619644415552, 17.86504967807255, 17.97776404339539, 18.089776118017607, 18.201098867925534, 18.311744864976685, 18.42172630347113, 18.531055015837605, 18.639742487491613, 18.74779987091819, 18.855237999028283, 18.962067397834026, 19.068298298484848, 19.173940648703386, 19.27900412365743, 19.38349813630141, 19.48743184721887, 19.590814173994914, 19.693653800145878, 19.795959183631396, 19.897738564972656, 19.998999974998753, 20.099751242241783, 20.200000000000003]]}, {\"colorscale\": [[0.0, \"#440154\"], [0.1111111111111111, \"#482878\"], [0.2222222222222222, \"#3e4989\"], [0.3333333333333333, \"#31688e\"], [0.4444444444444444, \"#26828e\"], [0.5555555555555556, \"#1f9e89\"], [0.6666666666666666, \"#35b779\"], [0.7777777777777778, \"#6ece58\"], [0.8888888888888888, \"#b5de2b\"], [1.0, \"#fde725\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"A = 1\", \"showscale\": false, \"type\": \"surface\", \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.1, 0.1414213562373095, 0.17320508075688776, 0.2, 0.223606797749979, 0.24494897427831783, 0.2645751311064591, 0.282842712474619, 0.3, 0.31622776601683794, 0.33166247903554, 0.3464101615137755, 0.36055512754639896, 0.37416573867739417, 0.38729833462074165, 0.4, 0.41231056256176607, 0.4242640687119285, 0.43588989435406744, 0.447213595499958, 0.45825756949558405, 0.469041575982343, 0.479583152331272, 0.48989794855663565, 0.5, 0.5099019513592785, 0.5196152422706632, 0.5291502622129182, 0.5385164807134505, 0.5477225575051661, 0.5567764362830022, 0.565685424949238, 0.574456264653803, 0.5830951894845301, 0.5916079783099616, 0.6, 0.608276253029822, 0.6164414002968976, 0.6244997998398399, 0.6324555320336759, 0.6403124237432849, 0.6480740698407861, 0.6557438524302001, 0.66332495807108, 0.6708203932499369, 0.6782329983125268, 0.6855654600401044, 0.692820323027551, 0.7000000000000001, 0.7071067811865476, 0.7141428428542851, 0.7211102550927979, 0.7280109889280519, 0.7348469228349535, 0.7416198487095663, 0.7483314773547883, 0.754983443527075, 0.7615773105863909, 0.7681145747868608, 0.7745966692414833, 0.7810249675906654, 0.787400787401181, 0.7937253933193772, 0.8, 0.8062257748298549, 0.812403840463596, 0.8185352771872451, 0.8246211251235321, 0.8306623862918076, 0.8366600265340756, 0.8426149773176359, 0.848528137423857, 0.8544003745317531, 0.8602325267042626, 0.8660254037844387, 0.8717797887081349, 0.8774964387392122, 0.8831760866327848, 0.8888194417315589, 0.894427190999916, 0.9, 0.9055385138137417, 0.9110433579144299, 0.9165151389911681, 0.9219544457292888, 0.9273618495495705, 0.9327379053088816, 0.938083151964686, 0.9433981132056604, 0.9486832980505138, 0.9539392014169457, 0.959166304662544, 0.9643650760992956, 0.9695359714832659, 0.9746794344808963, 0.9797958971132713, 0.9848857801796106, 0.9899494936611666, 0.9949874371066201, 1.0, 1.0049875621120892], [0.0, 0.1414213562373095, 0.19999999999999998, 0.24494897427831783, 0.282842712474619, 0.31622776601683794, 0.34641016151377546, 0.3741657386773941, 0.39999999999999997, 0.4242640687119285, 0.4472135954999579, 0.469041575982343, 0.48989794855663565, 0.5099019513592785, 0.529150262212918, 0.5477225575051661, 0.565685424949238, 0.58309518948453, 0.6, 0.6164414002968976, 0.6324555320336759, 0.6480740698407861, 0.6633249580710799, 0.6782329983125268, 0.6928203230275509, 0.7071067811865476, 0.7211102550927979, 0.7348469228349535, 0.7483314773547882, 0.7615773105863909, 0.7745966692414833, 0.7874007874011811, 0.7999999999999999, 0.812403840463596, 0.8246211251235321, 0.8366600265340756, 0.848528137423857, 0.8602325267042626, 0.8717797887081348, 0.8831760866327847, 0.8944271909999159, 0.9055385138137417, 0.9165151389911681, 0.9273618495495702, 0.938083151964686, 0.9486832980505137, 0.9591663046625439, 0.9695359714832658, 0.9797958971132713, 0.9899494936611665, 1.0, 1.0099504938362078, 1.019803902718557, 1.0295630140987002, 1.0392304845413265, 1.0488088481701516, 1.058300524425836, 1.0677078252031311, 1.0770329614269007, 1.0862780491200215, 1.0954451150103321, 1.104536101718726, 1.1135528725660042, 1.1224972160321824, 1.131370849898476, 1.1401754250991378, 1.1489125293076057, 1.1575836902790224, 1.16619037896906, 1.174734012447073, 1.1832159566199232, 1.1916375287812984, 1.2, 1.2083045973594573, 1.2165525060596438, 1.224744871391589, 1.2328828005937953, 1.2409673645990857, 1.2489995996796797, 1.2569805089976536, 1.2649110640673518, 1.2727922061357855, 1.2806248474865698, 1.2884098726725124, 1.2961481396815722, 1.3038404810405297, 1.3114877048604001, 1.3190905958272918, 1.3266499161421599, 1.3341664064126333, 1.3416407864998738, 1.349073756323204, 1.3564659966250536, 1.3638181696985856, 1.3711309200802089, 1.378404875209022, 1.3856406460551018, 1.392838827718412, 1.4, 1.407124727947029, 1.4142135623730951, 1.4212670403551897], [0.0, 0.17320508075688776, 0.24494897427831783, 0.3000000000000001, 0.3464101615137755, 0.38729833462074176, 0.42426406871192857, 0.45825756949558405, 0.48989794855663565, 0.5196152422706632, 0.5477225575051662, 0.574456264653803, 0.6000000000000002, 0.6244997998398399, 0.6480740698407861, 0.6708203932499369, 0.692820323027551, 0.7141428428542851, 0.7348469228349536, 0.7549834435270751, 0.7745966692414835, 0.7937253933193773, 0.8124038404635961, 0.8306623862918077, 0.8485281374238571, 0.8660254037844388, 0.8831760866327849, 0.9000000000000001, 0.9165151389911681, 0.9327379053088817, 0.9486832980505139, 0.9643650760992957, 0.9797958971132713, 0.9949874371066202, 1.009950493836208, 1.02469507659596, 1.0392304845413265, 1.053565375285274, 1.0677078252031313, 1.081665382639197, 1.0954451150103324, 1.1090536506409419, 1.1224972160321827, 1.1357816691600549, 1.148912529307606, 1.161895003862225, 1.1747340124470733, 1.187434208703792, 1.2000000000000004, 1.2124355652982142, 1.2247448713915892, 1.2369316876852985, 1.2489995996796799, 1.2609520212918495, 1.2727922061357857, 1.2845232578665131, 1.2961481396815722, 1.3076696830622023, 1.3190905958272923, 1.3304134695650072, 1.3416407864998738, 1.3527749258468684, 1.3638181696985856, 1.3747727084867523, 1.385640646055102, 1.3964240043768943, 1.4071247279470291, 1.4177446878757827, 1.4282856857085702, 1.4387494569938162, 1.4491376746189442, 1.4594519519326425, 1.4696938456699071, 1.4798648586948744, 1.489966442575134, 1.5000000000000002, 1.5099668870541503, 1.5198684153570665, 1.5297058540778359, 1.5394804318340656, 1.549193338482967, 1.5588457268119897, 1.5684387141358125, 1.5779733838059502, 1.5874507866387546, 1.5968719422671316, 1.6062378404209012, 1.6155494421403516, 1.6248076809271923, 1.6340134638368193, 1.6431676725154984, 1.6522711641858308, 1.6613247725836153, 1.670329308849007, 1.6792855623746668, 1.6881943016134133, 1.6970562748477143, 1.7058722109231985, 1.7146428199482249, 1.7233687939614089, 1.7320508075688776, 1.7406895185529214], [0.0, 0.2, 0.282842712474619, 0.3464101615137755, 0.4, 0.447213595499958, 0.48989794855663565, 0.5291502622129182, 0.565685424949238, 0.6, 0.6324555320336759, 0.66332495807108, 0.692820323027551, 0.7211102550927979, 0.7483314773547883, 0.7745966692414833, 0.8, 0.8246211251235321, 0.848528137423857, 0.8717797887081349, 0.894427190999916, 0.9165151389911681, 0.938083151964686, 0.959166304662544, 0.9797958971132713, 1.0, 1.019803902718557, 1.0392304845413265, 1.0583005244258363, 1.077032961426901, 1.0954451150103321, 1.1135528725660044, 1.131370849898476, 1.148912529307606, 1.1661903789690602, 1.1832159566199232, 1.2, 1.216552506059644, 1.2328828005937953, 1.2489995996796799, 1.2649110640673518, 1.2806248474865698, 1.2961481396815722, 1.3114877048604001, 1.32664991614216, 1.3416407864998738, 1.3564659966250536, 1.3711309200802089, 1.385640646055102, 1.4000000000000001, 1.4142135623730951, 1.4282856857085702, 1.4422205101855958, 1.4560219778561039, 1.469693845669907, 1.4832396974191326, 1.4966629547095767, 1.50996688705415, 1.5231546211727818, 1.5362291495737217, 1.5491933384829666, 1.5620499351813308, 1.574801574802362, 1.5874507866387544, 1.6, 1.6124515496597098, 1.624807680927192, 1.6370705543744901, 1.6492422502470643, 1.661324772583615, 1.6733200530681511, 1.6852299546352718, 1.697056274847714, 1.7088007490635062, 1.7204650534085253, 1.7320508075688774, 1.7435595774162698, 1.7549928774784245, 1.7663521732655696, 1.7776388834631178, 1.788854381999832, 1.8, 1.8110770276274835, 1.8220867158288598, 1.8330302779823362, 1.8439088914585775, 1.854723699099141, 1.8654758106177631, 1.876166303929372, 1.8867962264113207, 1.8973665961010275, 1.9078784028338913, 1.918332609325088, 1.9287301521985911, 1.9390719429665317, 1.9493588689617927, 1.9595917942265426, 1.9697715603592212, 1.9798989873223332, 1.9899748742132402, 2.0, 2.0099751242241783], [0.0, 0.223606797749979, 0.31622776601683794, 0.38729833462074176, 0.447213595499958, 0.5000000000000001, 0.5477225575051662, 0.5916079783099617, 0.6324555320336759, 0.6708203932499369, 0.7071067811865476, 0.7416198487095664, 0.7745966692414835, 0.806225774829855, 0.8366600265340756, 0.8660254037844386, 0.894427190999916, 0.9219544457292888, 0.9486832980505139, 0.9746794344808966, 1.0000000000000002, 1.02469507659596, 1.0488088481701516, 1.072380529476361, 1.0954451150103324, 1.118033988749895, 1.140175425099138, 1.1618950038622253, 1.1832159566199234, 1.2041594578792296, 1.2247448713915892, 1.2449899597988734, 1.2649110640673518, 1.2845232578665131, 1.30384048104053, 1.3228756555322954, 1.3416407864998738, 1.3601470508735445, 1.3784048752090223, 1.3964240043768943, 1.4142135623730951, 1.4317821063276355, 1.4491376746189442, 1.466287829861518, 1.4832396974191329, 1.5, 1.5165750888103102, 1.5329709716755893, 1.549193338482967, 1.565247584249853, 1.5811388300841898, 1.5968719422671316, 1.61245154965971, 1.627882059609971, 1.6431676725154984, 1.6583123951777001, 1.6733200530681511, 1.6881943016134133, 1.7029386365926404, 1.7175564037317668, 1.7320508075688772, 1.746424919657298, 1.760681686165901, 1.7748239349298849, 1.788854381999832, 1.8027756377319946, 1.8165902124584952, 1.8303005217723127, 1.8439088914585775, 1.8574175621006712, 1.8708286933869709, 1.8841443681416774, 1.8973665961010278, 1.91049731745428, 1.9235384061671346, 1.9364916731037085, 1.9493588689617931, 1.9621416870348585, 1.9748417658131503, 1.9874606914351793, 2.0000000000000004, 2.012461179749811, 2.024845673131659, 2.0371548787463363, 2.04939015319192, 2.0615528128088303, 2.0736441353327724, 2.0856653614614213, 2.0976176963403033, 2.1095023109728985, 2.121320343559643, 2.1330729007701543, 2.144761058952722, 2.1563858652847827, 2.1679483388678804, 2.179449471770337, 2.1908902300206647, 2.2022715545545246, 2.2135943621178655, 2.224859546128699, 2.23606797749979, 2.2472205054244236], [0.0, 0.24494897427831783, 0.34641016151377546, 0.42426406871192857, 0.48989794855663565, 0.5477225575051662, 0.6000000000000001, 0.6480740698407861, 0.6928203230275509, 0.7348469228349535, 0.7745966692414834, 0.8124038404635961, 0.8485281374238571, 0.8831760866327848, 0.916515138991168, 0.9486832980505138, 0.9797958971132713, 1.0099504938362078, 1.0392304845413265, 1.0677078252031313, 1.0954451150103324, 1.1224972160321824, 1.148912529307606, 1.174734012447073, 1.2000000000000002, 1.2247448713915892, 1.2489995996796799, 1.2727922061357857, 1.2961481396815722, 1.319090595827292, 1.3416407864998738, 1.3638181696985856, 1.3856406460551018, 1.4071247279470291, 1.4282856857085702, 1.449137674618944, 1.469693845669907, 1.489966442575134, 1.50996688705415, 1.5297058540778357, 1.5491933384829668, 1.5684387141358125, 1.5874507866387546, 1.606237840420901, 1.6248076809271923, 1.6431676725154982, 1.661324772583615, 1.6792855623746665, 1.6970562748477143, 1.7146428199482247, 1.7320508075688774, 1.7492855684535904, 1.7663521732655696, 1.7832554500127011, 1.8, 1.8165902124584952, 1.833030277982336, 1.849324200890693, 1.8654758106177631, 1.8814887722226779, 1.8973665961010275, 1.9131126469708992, 1.928730152198591, 1.9442222095223582, 1.9595917942265426, 1.9748417658131499, 1.98997487421324, 2.004993765576342, 2.0199009876724157, 2.0346989949375804, 2.04939015319192, 2.0639767440550294, 2.078460969082653, 2.092844953645635, 2.1071307505705477, 2.121320343559643, 2.1354156504062627, 2.149418526020468, 2.1633307652783937, 2.177154105707724, 2.1908902300206647, 2.2045407685048604, 2.2181073012818837, 2.2315913604421396, 2.244994432064365, 2.2583179581272432, 2.2715633383201097, 2.2847319317591728, 2.297825058615212, 2.3108440016582685, 2.32379000772445, 2.3366642891095846, 2.349468024894146, 2.3622023622035435, 2.374868417407584, 2.3874672772626644, 2.4000000000000004, 2.412467616362964, 2.4248711305964283, 2.4372115213907883, 2.4494897427831783, 2.4617067250182347], [0.0, 0.2645751311064591, 0.3741657386773941, 0.45825756949558405, 0.5291502622129182, 0.5916079783099617, 0.6480740698407861, 0.7000000000000001, 0.7483314773547882, 0.7937253933193772, 0.8366600265340756, 0.8774964387392122, 0.9165151389911681, 0.9539392014169458, 0.9899494936611666, 1.0246950765959597, 1.0583005244258363, 1.0908712114635715, 1.1224972160321824, 1.1532562594670797, 1.1832159566199234, 1.2124355652982142, 1.2409673645990857, 1.2688577540449522, 1.2961481396815722, 1.3228756555322954, 1.3490737563232043, 1.374772708486752, 1.4000000000000001, 1.4247806848775009, 1.4491376746189437, 1.4730919862656235, 1.4966629547095764, 1.5198684153570665, 1.5427248620541514, 1.5652475842498528, 1.5874507866387544, 1.6093476939431082, 1.6309506430300091, 1.6522711641858308, 1.6733200530681511, 1.6941074346097418, 1.7146428199482249, 1.7349351572897471, 1.7549928774784245, 1.7748239349298847, 1.7944358444926363, 1.8138357147217055, 1.8330302779823362, 1.8520259177452134, 1.8708286933869709, 1.8894443627691186, 1.9078784028338915, 1.9261360284258224, 1.9442222095223582, 1.9621416870348585, 1.9798989873223332, 1.997498435543818, 2.0149441679609885, 2.0322401432901573, 2.0493901531919194, 2.0663978319771825, 2.083266665599966, 2.1, 2.1166010488516727, 2.133072900770154, 2.149418526020468, 2.1656407827707715, 2.181742422927143, 2.1977260975835913, 2.2135943621178655, 2.2293496809607953, 2.244994432064365, 2.260530911091463, 2.2759613353482084, 2.29128784747792, 2.3065125189341593, 2.32163735324878, 2.336664289109585, 2.3515952032609695, 2.366431913239847, 2.3811761799581315, 2.395829710142188, 2.41039415863879, 2.4248711305964283, 2.4392621835300936, 2.4535688292770597, 2.4677925358506134, 2.4819347291981715, 2.495996794869737, 2.5099800796022267, 2.5238858928247927, 2.5377155080899043, 2.551470164434615, 2.5651510676761324, 2.578759391645525, 2.5922962793631443, 2.6057628441590768, 2.619160170741759, 2.632489316217637, 2.6457513110645907, 2.6589471600616665], [0.0, 0.282842712474619, 0.39999999999999997, 0.48989794855663565, 0.565685424949238, 0.6324555320336759, 0.6928203230275509, 0.7483314773547882, 0.7999999999999999, 0.848528137423857, 0.8944271909999159, 0.938083151964686, 0.9797958971132713, 1.019803902718557, 1.058300524425836, 1.0954451150103321, 1.131370849898476, 1.16619037896906, 1.2, 1.2328828005937953, 1.2649110640673518, 1.2961481396815722, 1.3266499161421599, 1.3564659966250536, 1.3856406460551018, 1.4142135623730951, 1.4422205101855958, 1.469693845669907, 1.4966629547095764, 1.5231546211727818, 1.5491933384829666, 1.5748015748023623, 1.5999999999999999, 1.624807680927192, 1.6492422502470643, 1.6733200530681511, 1.697056274847714, 1.7204650534085253, 1.7435595774162695, 1.7663521732655694, 1.7888543819998317, 1.8110770276274835, 1.8330302779823362, 1.8547236990991405, 1.876166303929372, 1.8973665961010273, 1.9183326093250879, 1.9390719429665315, 1.9595917942265426, 1.979898987322333, 2.0, 2.0199009876724157, 2.039607805437114, 2.0591260281974004, 2.078460969082653, 2.0976176963403033, 2.116601048851672, 2.1354156504062622, 2.1540659228538015, 2.172556098240043, 2.1908902300206643, 2.209072203437452, 2.2271057451320084, 2.244994432064365, 2.262741699796952, 2.2803508501982757, 2.2978250586152114, 2.315167380558045, 2.33238075793812, 2.349468024894146, 2.3664319132398464, 2.3832750575625967, 2.4, 2.4166091947189146, 2.4331050121192876, 2.449489742783178, 2.4657656011875906, 2.4819347291981715, 2.4979991993593593, 2.513961017995307, 2.5298221281347035, 2.545584412271571, 2.5612496949731396, 2.576819745345025, 2.5922962793631443, 2.6076809620810595, 2.6229754097208002, 2.6381811916545836, 2.6532998322843198, 2.6683328128252666, 2.6832815729997477, 2.698147512646408, 2.7129319932501073, 2.727636339397171, 2.7422618401604177, 2.756809750418044, 2.7712812921102037, 2.785677655436824, 2.8, 2.814249455894058, 2.8284271247461903, 2.8425340807103794], [0.0, 0.3, 0.4242640687119285, 0.5196152422706632, 0.6, 0.6708203932499369, 0.7348469228349535, 0.7937253933193772, 0.848528137423857, 0.8999999999999999, 0.9486832980505138, 0.99498743710662, 1.0392304845413265, 1.0816653826391969, 1.1224972160321824, 1.1618950038622249, 1.2, 1.236931687685298, 1.2727922061357855, 1.307669683062202, 1.3416407864998738, 1.374772708486752, 1.407124727947029, 1.438749456993816, 1.469693845669907, 1.5, 1.5297058540778354, 1.5588457268119895, 1.5874507866387544, 1.6155494421403513, 1.6431676725154982, 1.6703293088490065, 1.697056274847714, 1.7233687939614086, 1.7492855684535902, 1.7748239349298847, 1.7999999999999998, 1.8248287590894658, 1.849324200890693, 1.8734993995195195, 1.8973665961010275, 1.9209372712298547, 1.9442222095223582, 1.9672315572906, 1.98997487421324, 2.0124611797498106, 2.0346989949375804, 2.056696380120313, 2.078460969082653, 2.1, 2.1213203435596424, 2.142428528562855, 2.1633307652783937, 2.1840329667841556, 2.2045407685048604, 2.224859546128699, 2.244994432064365, 2.264950330581225, 2.2847319317591723, 2.3043437243605824, 2.3237900077244498, 2.3430749027719964, 2.362202362203543, 2.3811761799581315, 2.4, 2.4186773244895647, 2.437211521390788, 2.455605831561735, 2.473863375370596, 2.4919871588754225, 2.5099800796022267, 2.5278449319529073, 2.545584412271571, 2.563201123595259, 2.580697580112788, 2.598076211353316, 2.615339366124404, 2.6324893162176366, 2.6495282598983545, 2.6664583251946765, 2.6832815729997477, 2.7, 2.716615541441225, 2.7331300737432893, 2.749545416973504, 2.765863337187866, 2.7820855486487113, 2.7982137159266447, 2.814249455894058, 2.830194339616981, 2.846049894151541, 2.8618176042508368, 2.877498913987632, 2.8930952282978866, 2.9086079144497976, 2.9240383034426887, 2.939387691339814, 2.9546573405388314, 2.9698484809834995, 2.98496231131986, 3.0, 3.0149626863362675], [0.0, 0.31622776601683794, 0.4472135954999579, 0.5477225575051662, 0.6324555320336759, 0.7071067811865476, 0.7745966692414834, 0.8366600265340756, 0.8944271909999159, 0.9486832980505138, 1.0, 1.0488088481701516, 1.0954451150103324, 1.140175425099138, 1.1832159566199232, 1.224744871391589, 1.2649110640673518, 1.3038404810405297, 1.3416407864998738, 1.3784048752090223, 1.4142135623730951, 1.449137674618944, 1.4832396974191326, 1.5165750888103102, 1.5491933384829668, 1.5811388300841898, 1.61245154965971, 1.6431676725154984, 1.6733200530681511, 1.7029386365926402, 1.7320508075688772, 1.760681686165901, 1.7888543819998317, 1.8165902124584952, 1.8439088914585775, 1.8708286933869707, 1.8973665961010275, 1.9235384061671346, 1.949358868961793, 1.97484176581315, 2.0, 2.024845673131659, 2.04939015319192, 2.073644135332772, 2.0976176963403033, 2.1213203435596424, 2.1447610589527217, 2.16794833886788, 2.1908902300206647, 2.2135943621178655, 2.23606797749979, 2.2583179581272432, 2.280350850198276, 2.302172886644268, 2.32379000772445, 2.345207879911715, 2.3664319132398464, 2.3874672772626644, 2.4083189157584592, 2.4289915602982237, 2.449489742783178, 2.4698178070456938, 2.4899799195977463, 2.5099800796022267, 2.5298221281347035, 2.5495097567963922, 2.569046515733026, 2.588435821108957, 2.6076809620810595, 2.6267851073127395, 2.6457513110645907, 2.6645825188948455, 2.6832815729997477, 2.701851217221259, 2.7202941017470885, 2.7386127875258306, 2.7568097504180447, 2.7748873851023217, 2.7928480087537886, 2.8106938645110393, 2.8284271247461903, 2.8460498941515415, 2.863564212655271, 2.8809720581775866, 2.898275349237888, 2.9154759474226504, 2.932575659723036, 2.9495762407505253, 2.9664793948382653, 2.9832867780352594, 3.0, 3.0166206257996713, 3.0331501776206204, 3.0495901363953815, 3.0659419433511785, 3.082207001484488, 3.0983866769659336, 3.1144823004794877, 3.1304951684997055, 3.146426544510455, 3.1622776601683795, 3.178049716414141], [0.0, 0.33166247903554, 0.469041575982343, 0.574456264653803, 0.66332495807108, 0.7416198487095664, 0.8124038404635961, 0.8774964387392122, 0.938083151964686, 0.99498743710662, 1.0488088481701516, 1.1, 1.148912529307606, 1.1958260743101399, 1.2409673645990857, 1.284523257866513, 1.32664991614216, 1.3674794331177345, 1.407124727947029, 1.4456832294800963, 1.4832396974191329, 1.5198684153570665, 1.5556349186104048, 1.5905973720586868, 1.6248076809271923, 1.6583123951777001, 1.6911534525287766, 1.7233687939614089, 1.7549928774784245, 1.7860571099491753, 1.816590212458495, 1.846618531261939, 1.876166303929372, 1.9052558883257653, 1.9339079605813718, 1.9621416870348585, 1.98997487421324, 2.017424100183202, 2.0445048300260877, 2.0712315177207983, 2.0976176963403033, 2.1236760581595306, 2.149418526020468, 2.1748563170931545, 2.2, 2.224859546128699, 2.249444375840399, 2.273763400180415, 2.297825058615212, 2.32163735324878, 2.345207879911715, 2.368543856465403, 2.3916521486202797, 2.4145392935299275, 2.4372115213907883, 2.459674775249769, 2.4819347291981715, 2.503996805109783, 2.525866188063018, 2.5475478405713994, 2.569046515733026, 2.5903667693977237, 2.6115129714401193, 2.632489316217637, 2.65329983228432, 2.6739483914241875, 2.6944387170614963, 2.714774392099646, 2.734958866235469, 2.7549954627911823, 2.774887385102322, 2.7946377224964243, 2.814249455894058, 2.833725463060951, 2.8530685235374214, 2.8722813232690148, 2.8913664589601926, 2.91032644217105, 2.9291637031753623, 2.9478805945967355, 2.9664793948382657, 2.9849623113198605, 3.003331483536242, 3.0215889859476257, 3.039736830714133, 3.0577769702841313, 3.07571129984594, 3.093541659651604, 3.1112698372208096, 3.1288975694324033, 3.146426544510455, 3.1638584039112754, 3.1811947441173736, 3.1984371183438958, 3.2155870381627056, 3.2326459750489227, 3.2496153618543846, 3.2664965942122155, 3.283291031876401, 3.3000000000000007, 3.3166247903554003, 3.333166662499792], [0.0, 0.3464101615137755, 0.48989794855663565, 0.6000000000000002, 0.692820323027551, 0.7745966692414835, 0.8485281374238571, 0.9165151389911681, 0.9797958971132713, 1.0392304845413265, 1.0954451150103324, 1.148912529307606, 1.2000000000000004, 1.2489995996796799, 1.2961481396815722, 1.3416407864998738, 1.385640646055102, 1.4282856857085702, 1.4696938456699071, 1.5099668870541503, 1.549193338482967, 1.5874507866387546, 1.6248076809271923, 1.6613247725836153, 1.6970562748477143, 1.7320508075688776, 1.7663521732655698, 1.8000000000000003, 1.8330302779823362, 1.8654758106177634, 1.8973665961010278, 1.9287301521985913, 1.9595917942265426, 1.9899748742132404, 2.019900987672416, 2.04939015319192, 2.078460969082653, 2.107130750570548, 2.1354156504062627, 2.163330765278394, 2.1908902300206647, 2.2181073012818837, 2.2449944320643653, 2.2715633383201097, 2.297825058615212, 2.32379000772445, 2.3494680248941466, 2.374868417407584, 2.400000000000001, 2.4248711305964283, 2.4494897427831783, 2.473863375370597, 2.4979991993593598, 2.521904042583699, 2.5455844122715714, 2.5690465157330262, 2.5922962793631443, 2.6153393661244047, 2.6381811916545845, 2.6608269391300143, 2.6832815729997477, 2.705549851693737, 2.727636339397171, 2.7495454169735045, 2.771281292110204, 2.7928480087537886, 2.8142494558940583, 2.8354893757515653, 2.8565713714171403, 2.8774989139876324, 2.8982753492378883, 2.918903903865285, 2.9393876913398143, 2.9597297173897488, 2.979932885150268, 3.0000000000000004, 3.0199337741083006, 3.039736830714133, 3.0594117081556718, 3.078960863668131, 3.098386676965934, 3.1176914536239795, 3.136877428271625, 3.1559467676119004, 3.174901573277509, 3.193743884534263, 3.2124756808418025, 3.231098884280703, 3.2496153618543846, 3.2680269276736387, 3.286335345030997, 3.3045423283716615, 3.3226495451672307, 3.340658617698014, 3.3585711247493335, 3.3763886032268267, 3.3941125496954285, 3.411744421846397, 3.4292856398964497, 3.4467375879228177, 3.4641016151377553, 3.481379037105843], [0.0, 0.36055512754639896, 0.5099019513592785, 0.6244997998398399, 0.7211102550927979, 0.806225774829855, 0.8831760866327848, 0.9539392014169458, 1.019803902718557, 1.0816653826391969, 1.140175425099138, 1.1958260743101399, 1.2489995996796799, 1.3000000000000003, 1.3490737563232043, 1.396424004376894, 1.4422205101855958, 1.4866068747318506, 1.5297058540778357, 1.5716233645501714, 1.61245154965971, 1.6522711641858308, 1.6911534525287764, 1.7291616465790585, 1.7663521732655696, 1.8027756377319948, 1.8384776310850237, 1.8734993995195197, 1.9078784028338915, 1.94164878389476, 1.9748417658131499, 2.0074859899884734, 2.039607805437114, 2.0712315177207983, 2.102379604162864, 2.1330729007701543, 2.1633307652783937, 2.193171219946131, 2.222611077089287, 2.2516660498395407, 2.280350850198276, 2.3086792761230397, 2.336664289109585, 2.364318083507378, 2.3916521486202797, 2.4186773244895647, 2.445403852127497, 2.471841418861655, 2.4979991993593598, 2.5238858928247927, 2.5495097567963927, 2.574878637916747, 2.6000000000000005, 2.624880949681338, 2.6495282598983545, 2.673948391424188, 2.6981475126464085, 2.72213151776324, 2.7459060435491964, 2.7694764848252458, 2.792848008753788, 2.816025568065745, 2.839013913315678, 2.861817604250837, 2.8844410203711917, 2.9068883707497264, 2.9291637031753623, 2.951270912674741, 2.973213749463701, 2.994995826374388, 3.0166206257996717, 3.0380915061926625, 3.0594117081556713, 3.0805843601498726, 3.1016124838541645, 3.122498999199199, 3.1432467291003428, 3.1638584039112754, 3.1843366656181322, 3.204684071792413, 3.22490309931942, 3.2449961479175906, 3.264965543462902, 3.2848135411313684, 3.3045423283716615, 3.3241540277189325, 3.343650699460098, 3.363034344160048, 3.3823069050575527, 3.4014702703389896, 3.420526275297414, 3.439476704383968, 3.458323293158117, 3.4770677301427426, 3.4957116585897072, 3.5142566781611158, 3.532704346531139, 3.5510561809129415, 3.5693136595149495, 3.58747822293042, 3.6055512754639896, 3.6235341863986883], [0.0, 0.37416573867739417, 0.529150262212918, 0.6480740698407861, 0.7483314773547883, 0.8366600265340756, 0.916515138991168, 0.9899494936611666, 1.058300524425836, 1.1224972160321824, 1.1832159566199232, 1.2409673645990857, 1.2961481396815722, 1.3490737563232043, 1.4, 1.4491376746189437, 1.4966629547095767, 1.5427248620541512, 1.5874507866387544, 1.6309506430300091, 1.6733200530681511, 1.7146428199482247, 1.7549928774784245, 1.7944358444926363, 1.833030277982336, 1.8708286933869707, 1.9078784028338913, 1.9442222095223582, 1.9798989873223332, 2.0149441679609885, 2.0493901531919194, 2.083266665599966, 2.116601048851672, 2.149418526020468, 2.181742422927143, 2.2135943621178655, 2.244994432064365, 2.2759613353482084, 2.3065125189341593, 2.3366642891095846, 2.3664319132398464, 2.395829710142188, 2.4248711305964283, 2.453568829277059, 2.4819347291981715, 2.5099800796022262, 2.5377155080899043, 2.565151067676132, 2.5922962793631443, 2.619160170741759, 2.6457513110645907, 2.672077843177478, 2.6981475126464085, 2.7239676943752476, 2.749545416973504, 2.7748873851023217, 2.8, 2.824889378365107, 2.8495613697550017, 2.8740215726399825, 2.8982753492378874, 2.9223278392404914, 2.9461839725312466, 2.9698484809834995, 2.9933259094191533, 3.016620625799671, 3.0397368307141326, 3.062678566222711, 3.0854497241083023, 3.1080540535840107, 3.1304951684997055, 3.152776554086889, 3.1749015732775088, 3.196873472629156, 3.218695387886216, 3.24037034920393, 3.2619012860600183, 3.283291031876401, 3.3045423283716615, 3.3256578296631782, 3.3466401061363023, 3.3674916480965473, 3.3882148692194836, 3.408812109811862, 3.4292856398964493, 3.449637662132068, 3.4698703145794947, 3.4899856733230297, 3.509985754956849, 3.529872518944558, 3.5496478698597693, 3.5693136595149495, 3.5888716889852725, 3.6083237105337433, 3.627671429443411, 3.6469165057620936, 3.666060555964672, 3.685105154537656, 3.704051835490427, 3.722902093797257, 3.7416573867739413, 3.7603191353926335], [0.0, 0.38729833462074165, 0.5477225575051661, 0.6708203932499369, 0.7745966692414833, 0.8660254037844386, 0.9486832980505138, 1.0246950765959597, 1.0954451150103321, 1.1618950038622249, 1.224744871391589, 1.284523257866513, 1.3416407864998738, 1.396424004376894, 1.4491376746189437, 1.4999999999999998, 1.5491933384829666, 1.5968719422671311, 1.6431676725154982, 1.6881943016134133, 1.7320508075688772, 1.7748239349298847, 1.816590212458495, 1.857417562100671, 1.8973665961010275, 1.9364916731037083, 1.9748417658131499, 2.0124611797498106, 2.0493901531919194, 2.085665361461421, 2.1213203435596424, 2.1563858652847823, 2.1908902300206643, 2.224859546128699, 2.258317958127243, 2.29128784747792, 2.3237900077244498, 2.355843797877949, 2.3874672772626644, 2.4186773244895647, 2.449489742783178, 2.479919353527449, 2.5099800796022267, 2.5396850198400585, 2.569046515733026, 2.5980762113533156, 2.626785107312739, 2.6551836094703507, 2.6832815729997477, 2.7110883423451915, 2.7386127875258306, 2.765863337187866, 2.792848008753788, 2.819574435974337, 2.846049894151541, 2.8722813232690143, 2.8982753492378874, 2.924038303442689, 2.9495762407505253, 2.974894956128703, 2.9999999999999996, 3.0248966924508345, 3.049590136395381, 3.074085229787879, 3.098386676965933, 3.1224989991991987, 3.1464265445104544, 3.1701734968294715, 3.1937438845342623, 3.217141588429082, 3.24037034920393, 3.2634337744161437, 3.2863353450309964, 3.309078421554859, 3.3316662497915357, 3.3541019662496843, 3.3763886032268267, 3.3985290935932855, 3.420526275297414, 3.442382895611701, 3.4641016151377544, 3.485685011586675, 3.5071355833500366, 3.5284557528754696, 3.5496478698597693, 3.5707142142714248, 3.591656999213594, 3.6124783736376886, 3.63318042491699, 3.6537651812890215, 3.674234614174767, 3.694590640382233, 3.714835124201342, 3.7349698793966195, 3.7549966711037173, 3.7749172176353745, 3.794733192202055, 3.8144462245521304, 3.8340579025361623, 3.853569773599539, 3.8729833462074166, 3.892300091205713], [0.0, 0.4, 0.565685424949238, 0.692820323027551, 0.8, 0.894427190999916, 0.9797958971132713, 1.0583005244258363, 1.131370849898476, 1.2, 1.2649110640673518, 1.32664991614216, 1.385640646055102, 1.4422205101855958, 1.4966629547095767, 1.5491933384829666, 1.6, 1.6492422502470643, 1.697056274847714, 1.7435595774162698, 1.788854381999832, 1.8330302779823362, 1.876166303929372, 1.918332609325088, 1.9595917942265426, 2.0, 2.039607805437114, 2.078460969082653, 2.1166010488516727, 2.154065922853802, 2.1908902300206643, 2.227105745132009, 2.262741699796952, 2.297825058615212, 2.3323807579381204, 2.3664319132398464, 2.4, 2.433105012119288, 2.4657656011875906, 2.4979991993593598, 2.5298221281347035, 2.5612496949731396, 2.5922962793631443, 2.6229754097208002, 2.65329983228432, 2.6832815729997477, 2.7129319932501073, 2.7422618401604177, 2.771281292110204, 2.8000000000000003, 2.8284271247461903, 2.8565713714171403, 2.8844410203711917, 2.9120439557122078, 2.939387691339814, 2.9664793948382653, 2.9933259094191533, 3.0199337741083, 3.0463092423455636, 3.0724582991474434, 3.098386676965933, 3.1240998703626617, 3.149603149604724, 3.1749015732775088, 3.2, 3.2249030993194197, 3.249615361854384, 3.2741411087489802, 3.2984845004941286, 3.32264954516723, 3.3466401061363023, 3.3704599092705436, 3.394112549695428, 3.4176014981270124, 3.4409301068170506, 3.464101615137755, 3.4871191548325395, 3.509985754956849, 3.532704346531139, 3.5552777669262356, 3.577708763999664, 3.6, 3.622154055254967, 3.6441734316577197, 3.6660605559646724, 3.687817782917155, 3.709447398198282, 3.7309516212355263, 3.752332607858744, 3.7735924528226414, 3.794733192202055, 3.8157568056677826, 3.836665218650176, 3.8574603043971822, 3.8781438859330635, 3.8987177379235853, 3.9191835884530852, 3.9395431207184424, 3.9597979746446663, 3.9799497484264803, 4.0, 4.019950248448357], [0.0, 0.41231056256176607, 0.58309518948453, 0.7141428428542851, 0.8246211251235321, 0.9219544457292888, 1.0099504938362078, 1.0908712114635715, 1.16619037896906, 1.236931687685298, 1.3038404810405297, 1.3674794331177345, 1.4282856857085702, 1.4866068747318506, 1.5427248620541512, 1.5968719422671311, 1.6492422502470643, 1.7, 1.7492855684535902, 1.797220075561143, 1.8439088914585775, 1.8894443627691184, 1.9339079605813716, 1.977371993328519, 2.0199009876724157, 2.0615528128088303, 2.102379604162864, 2.142428528562855, 2.181742422927143, 2.220360331117452, 2.258317958127243, 2.2956480566497994, 2.33238075793812, 2.3685438564654024, 2.4041630560342617, 2.4392621835300936, 2.473863375370596, 2.5079872407968904, 2.541653005427767, 2.574878637916747, 2.6076809620810595, 2.6400757564888173, 2.672077843177478, 2.7037011669191546, 2.734958866235469, 2.765863337187866, 2.7964262908219126, 2.826658805020514, 2.8565713714171403, 2.8861739379323623, 2.9154759474226504, 2.944486372867092, 2.973213749463701, 3.001666203960727, 3.0298514815086235, 3.0577769702841313, 3.0854497241083023, 3.1128764832546763, 3.1400636936215167, 3.167017524422623, 3.1937438845342623, 3.2202484376209237, 3.246536616149585, 3.2726136343907144, 3.2984845004941286, 3.324154027718932, 3.3496268448888453, 3.374907406137241, 3.4, 3.424908757908742, 3.4496376621320683, 3.4741905532080417, 3.4985711369071804, 3.522782990761707, 3.5468295701936396, 3.570714214271425, 3.594440151122286, 3.6180105030251086, 3.6414282912066254, 3.664696440361739, 3.687817782917155, 3.710795063055895, 3.733630940518894, 3.7563279941985894, 3.778888725538237, 3.8013155617496426, 3.8236108588610325, 3.845776904605882, 3.867815921162743, 3.8897300677553446, 3.9115214431215892, 3.9331920878594273, 3.954743986657038, 3.976179070414209, 3.9974992182613374, 4.018706259482023, 4.039801975344831, 4.060788100849391, 4.08166632639171, 4.102438299353203, 4.123105625617661, 4.1436698710201325], [0.0, 0.4242640687119285, 0.6, 0.7348469228349536, 0.848528137423857, 0.9486832980505139, 1.0392304845413265, 1.1224972160321824, 1.2, 1.2727922061357855, 1.3416407864998738, 1.407124727947029, 1.4696938456699071, 1.5297058540778357, 1.5874507866387544, 1.6431676725154982, 1.697056274847714, 1.7492855684535902, 1.8, 1.8493242008906932, 1.8973665961010278, 1.9442222095223582, 1.98997487421324, 2.0346989949375804, 2.078460969082653, 2.121320343559643, 2.1633307652783937, 2.2045407685048604, 2.244994432064365, 2.2847319317591728, 2.32379000772445, 2.3622023622035435, 2.4, 2.4372115213907883, 2.4738633753705965, 2.5099800796022267, 2.545584412271571, 2.5806975801127883, 2.615339366124404, 2.6495282598983545, 2.6832815729997477, 2.716615541441225, 2.749545416973504, 2.782085548648711, 2.814249455894058, 2.846049894151541, 2.877498913987632, 2.9086079144497976, 2.9393876913398143, 2.9698484809834995, 3.0, 3.029851481508624, 3.0594117081556713, 3.0886890422961004, 3.1176914536239795, 3.146426544510455, 3.1749015732775088, 3.2031234756093934, 3.2310988842807027, 3.2588341473600644, 3.2863353450309964, 3.3136083051561784, 3.340658617698013, 3.3674916480965473, 3.394112549695428, 3.420526275297414, 3.4467375879228173, 3.4727510708370675, 3.4985711369071804, 3.5242020373412193, 3.5496478698597698, 3.5749125863438955, 3.6, 3.6249137920783716, 3.6496575181789317, 3.6742346141747673, 3.6986484017813863, 3.722902093797257, 3.7469987990390394, 3.7709415269929605, 3.7947331922020555, 3.8183766184073566, 3.84187454245971, 3.8652296180175374, 3.8884444190447165, 3.9115214431215897, 3.9344631145812006, 3.957271787481876, 3.97994974842648, 4.0024992192379, 4.024922359499621, 4.047221268969612, 4.069397989875161, 4.091454509095757, 4.113392760240627, 4.135214625627066, 4.156921938165306, 4.178516483155236, 4.2, 4.221374183841087, 4.242640687119286, 4.263801121065569], [0.0, 0.43588989435406744, 0.6164414002968976, 0.7549834435270751, 0.8717797887081349, 0.9746794344808966, 1.0677078252031313, 1.1532562594670797, 1.2328828005937953, 1.307669683062202, 1.3784048752090223, 1.4456832294800963, 1.5099668870541503, 1.5716233645501714, 1.6309506430300091, 1.6881943016134133, 1.7435595774162698, 1.797220075561143, 1.8493242008906932, 1.9000000000000004, 1.9493588689617931, 1.9974984355438181, 2.0445048300260877, 2.0904544960366875, 2.1354156504062627, 2.179449471770337, 2.2226110770892875, 2.2649503305812253, 2.3065125189341593, 2.3473389188611007, 2.3874672772626644, 2.4269322199023198, 2.4657656011875906, 2.503996805109783, 2.5416530054277673, 2.5787593916455256, 2.615339366124404, 2.651414716712571, 2.687005768508881, 2.7221315177632404, 2.7568097504180447, 2.791057147390573, 2.8248893783651075, 2.8583211855912904, 2.8913664589601926, 2.924038303442689, 2.956349099818897, 2.9883105594967874, 3.0199337741083006, 3.051229260478472, 3.082207001484489, 3.1128764832546767, 3.1432467291003428, 3.1733263305244868, 3.203123475609394, 3.232645975048923, 3.2619012860600183, 3.290896534380867, 3.319638534539567, 3.3481338085566414, 3.3763886032268267, 3.4044089061098406, 3.432200460346103, 3.4597687784012394, 3.4871191548325395, 3.5142566781611158, 3.541186241925155, 3.567912554982255, 3.594440151122286, 3.6207733980463352, 3.6469165057620945, 3.672873534441392, 3.6986484017813863, 3.7242448899072147, 3.749666651850535, 3.7749172176353754, 3.8000000000000007, 3.824918299781056, 3.8496753109840323, 3.874274125562104, 3.8987177379235862, 3.9230090491866068, 3.947150871198111, 3.9711459303329564, 3.9949968710876362, 4.018706259482024, 4.042276586281548, 4.065710270051225, 4.0890096600521755, 4.112177038990418, 4.135214625627067, 4.158124577258358, 4.180908992073375, 4.203569911396741, 4.226109321823088, 4.2485291572496005, 4.270831300812525, 4.293017586733137, 4.315089802078284, 4.337049688440289, 4.358898943540674, 4.380639222761903], [0.0, 0.447213595499958, 0.6324555320336759, 0.7745966692414835, 0.894427190999916, 1.0000000000000002, 1.0954451150103324, 1.1832159566199234, 1.2649110640673518, 1.3416407864998738, 1.4142135623730951, 1.4832396974191329, 1.549193338482967, 1.61245154965971, 1.6733200530681511, 1.7320508075688772, 1.788854381999832, 1.8439088914585775, 1.8973665961010278, 1.9493588689617931, 2.0000000000000004, 2.04939015319192, 2.0976176963403033, 2.144761058952722, 2.1908902300206647, 2.23606797749979, 2.280350850198276, 2.3237900077244507, 2.366431913239847, 2.4083189157584592, 2.4494897427831783, 2.489979919597747, 2.5298221281347035, 2.5690465157330262, 2.60768096208106, 2.6457513110645907, 2.6832815729997477, 2.720294101747089, 2.7568097504180447, 2.7928480087537886, 2.8284271247461903, 2.863564212655271, 2.8982753492378883, 2.932575659723036, 2.9664793948382657, 3.0, 3.0331501776206204, 3.0659419433511785, 3.098386676965934, 3.130495168499706, 3.1622776601683795, 3.193743884534263, 3.22490309931942, 3.255764119219942, 3.286335345030997, 3.3166247903554003, 3.3466401061363023, 3.3763886032268267, 3.405877273185281, 3.4351128074635335, 3.4641016151377544, 3.492849839314596, 3.521363372331802, 3.5496478698597698, 3.577708763999664, 3.605551275463989, 3.6331804249169903, 3.6606010435446255, 3.687817782917155, 3.7148351242013424, 3.7416573867739418, 3.768288736283355, 3.7947331922020555, 3.82099463490856, 3.847076812334269, 3.872983346207417, 3.8987177379235862, 3.924283374069717, 3.9496835316263006, 3.9749213828703587, 4.000000000000001, 4.024922359499622, 4.049691346263318, 4.0743097574926725, 4.09878030638384, 4.123105625617661, 4.147288270665545, 4.171330722922843, 4.1952353926806065, 4.219004621945797, 4.242640687119286, 4.266145801540309, 4.289522117905444, 4.312771730569565, 4.335896677735761, 4.358898943540674, 4.3817804600413295, 4.404543109109049, 4.427188724235731, 4.449719092257398, 4.47213595499958, 4.494441010848847], [0.0, 0.45825756949558405, 0.6480740698407861, 0.7937253933193773, 0.9165151389911681, 1.02469507659596, 1.1224972160321824, 1.2124355652982142, 1.2961481396815722, 1.374772708486752, 1.449137674618944, 1.5198684153570665, 1.5874507866387546, 1.6522711641858308, 1.7146428199482247, 1.7748239349298847, 1.8330302779823362, 1.8894443627691184, 1.9442222095223582, 1.9974984355438181, 2.04939015319192, 2.1, 2.149418526020468, 2.1977260975835913, 2.244994432064365, 2.2912878474779204, 2.336664289109585, 2.381176179958132, 2.4248711305964283, 2.4677925358506134, 2.5099800796022267, 2.551470164434615, 2.5922962793631443, 2.632489316217637, 2.672077843177478, 2.711088342345192, 2.749545416973504, 2.787471972953271, 2.824889378365107, 2.861817604250837, 2.898275349237888, 2.934280150224242, 2.9698484809835, 3.004995840263344, 3.039736830714133, 3.0740852297878796, 3.108054053584011, 3.1416556144810017, 3.174901573277509, 3.2078029864690882, 3.2403703492039306, 3.272613634390715, 3.3045423283716615, 3.336165463522456, 3.3674916480965478, 3.398529093593286, 3.4292856398964493, 3.459768778401239, 3.48998567332303, 3.5199431813596083, 3.5496478698597693, 3.5791060336346563, 3.608323710533743, 3.6373066958946425, 3.6660605559646724, 3.6945906403822333, 3.722902093797257, 3.7509998667022106, 3.778888725538237, 3.8065732621348563, 3.834057902536163, 3.861346915261565, 3.8884444190447165, 3.915354390090379, 3.9420806688854046, 3.968626966596886, 3.9949968710876362, 4.02119385257662, 4.047221268969613, 4.07308237088326, 4.09878030638384, 4.124318125460256, 4.149698784249287, 4.174925149029621, 4.2, 4.224926034855522, 4.249705872175156, 4.274342054632503, 4.298837052040936, 4.323193264243457, 4.347413023856832, 4.371498598878879, 4.3954521951671826, 4.419275958796871, 4.442971978304612, 4.466542286825459, 4.48998886412873, 4.513313638558704, 4.536518488885503, 4.559605246071199, 4.582575694955841, 4.605431575867782], [0.0, 0.469041575982343, 0.6633249580710799, 0.8124038404635961, 0.938083151964686, 1.0488088481701516, 1.148912529307606, 1.2409673645990857, 1.3266499161421599, 1.407124727947029, 1.4832396974191326, 1.5556349186104048, 1.6248076809271923, 1.6911534525287764, 1.7549928774784245, 1.816590212458495, 1.876166303929372, 1.9339079605813716, 1.98997487421324, 2.0445048300260877, 2.0976176963403033, 2.149418526020468, 2.2, 2.249444375840399, 2.297825058615212, 2.345207879911715, 2.3916521486202797, 2.4372115213907883, 2.4819347291981715, 2.5258661880630178, 2.569046515733026, 2.6115129714401193, 2.6532998322843198, 2.6944387170614963, 2.734958866235469, 2.7748873851023217, 2.814249455894058, 2.8530685235374214, 2.891366458960192, 2.9291637031753623, 2.9664793948382653, 3.0033314835362415, 3.039736830714133, 3.0757112998459397, 3.1112698372208096, 3.1464265445104544, 3.1811947441173736, 3.2155870381627056, 3.2496153618543846, 3.283291031876401, 3.3166247903554003, 3.3496268448888458, 3.3823069050575527, 3.414674215792775, 3.4467375879228173, 3.4785054261852175, 3.509985754956849, 3.5411862419251547, 3.5721142198983507, 3.602776706930364, 3.63318042491699, 3.6633318168028404, 3.6932370625238775, 3.722902093797257, 3.752332607858744, 3.7815340802378072, 3.81051177665153, 3.8392707640904935, 3.867815921162743, 3.8961519477556315, 3.924283374069717, 3.952214569073901, 3.97994974842648, 4.007492981902776, 4.034848200366403, 4.06201920231798, 4.0890096600521755, 4.115823125451336, 4.1424630354415966, 4.168932717135166, 4.1952353926806065, 4.221374183841087, 4.247352116319061, 4.273172123844299, 4.298837052040936, 4.324349662087931, 4.349712634186309, 4.374928570845472, 4.4, 4.424929377967517, 4.449719092257398, 4.474371464239419, 4.498888751680798, 4.523273151159457, 4.54752680036083, 4.571651780264984, 4.595650117230424, 4.61952378498044, 4.64327470649756, 4.666904755831214, 4.69041575982343, 4.713809499757071], [0.0, 0.479583152331272, 0.6782329983125268, 0.8306623862918077, 0.959166304662544, 1.072380529476361, 1.174734012447073, 1.2688577540449522, 1.3564659966250536, 1.438749456993816, 1.5165750888103102, 1.5905973720586868, 1.6613247725836153, 1.7291616465790585, 1.7944358444926363, 1.857417562100671, 1.918332609325088, 1.977371993328519, 2.0346989949375804, 2.0904544960366875, 2.144761058952722, 2.1977260975835913, 2.249444375840399, 2.3000000000000003, 2.349468024894146, 2.39791576165636, 2.4454038521274972, 2.491987158875423, 2.5377155080899043, 2.582634314028992, 2.6267851073127395, 2.670205984563738, 2.7129319932501073, 2.754995462791183, 2.7964262908219126, 2.8372521918222215, 2.877498913987632, 2.917190429162965, 2.956349099818897, 2.994995826374388, 3.0331501776206204, 3.0708305065568178, 3.108054053584011, 3.1448370387032774, 3.1811947441173736, 3.2171415884290826, 3.252691193458119, 3.2878564445547194, 3.3226495451672307, 3.357082066318904, 3.3911649915626345, 3.4249087579087423, 3.458323293158117, 3.491418050019219, 3.5242020373412197, 3.5566838487557484, 3.5888716889852725, 3.620773398046335, 3.6523964735499352, 3.6837480912787726, 3.714835124201342, 3.745664160065609, 3.7762415176998414, 3.8065732621348563, 3.836665218650176, 3.866522985836241, 3.8961519477556315, 3.9255572852781047, 3.954743986657038, 3.9837168574084183, 4.012480529547776, 4.041039470235351, 4.069397989875161, 4.097560249709576, 4.125530268947254, 4.153311931459037, 4.180908992073375, 4.2083250825001635, 4.235563716909475, 4.262628297189424, 4.289522117905444, 4.316248370981448, 4.342810150121694, 4.369210454990696, 4.3954521951671826, 4.421538193886829, 4.447471191587417, 4.473253849269009, 4.498888751680798, 4.524378410345448, 4.549725266430931, 4.57493169347915, 4.6000000000000005, 4.624932431938872, 4.649731175025068, 4.674398357008098, 4.698936049788292, 4.723346271447818, 4.747630988187688, 4.77179211617606, 4.79583152331272, 4.819751030914357], [0.0, 0.48989794855663565, 0.6928203230275509, 0.8485281374238571, 0.9797958971132713, 1.0954451150103324, 1.2000000000000002, 1.2961481396815722, 1.3856406460551018, 1.469693845669907, 1.5491933384829668, 1.6248076809271923, 1.6970562748477143, 1.7663521732655696, 1.833030277982336, 1.8973665961010275, 1.9595917942265426, 2.0199009876724157, 2.078460969082653, 2.1354156504062627, 2.1908902300206647, 2.244994432064365, 2.297825058615212, 2.349468024894146, 2.4000000000000004, 2.4494897427831783, 2.4979991993593598, 2.5455844122715714, 2.5922962793631443, 2.638181191654584, 2.6832815729997477, 2.727636339397171, 2.7712812921102037, 2.8142494558940583, 2.8565713714171403, 2.898275349237888, 2.939387691339814, 2.979932885150268, 3.0199337741083, 3.0594117081556713, 3.0983866769659336, 3.136877428271625, 3.174901573277509, 3.212475680841802, 3.2496153618543846, 3.2863353450309964, 3.32264954516723, 3.358571124749333, 3.3941125496954285, 3.4292856398964493, 3.464101615137755, 3.498571136907181, 3.532704346531139, 3.5665109000254023, 3.6, 3.6331804249169903, 3.666060555964672, 3.698648401781386, 3.7309516212355263, 3.7629775444453557, 3.794733192202055, 3.8262252939417984, 3.857460304397182, 3.8884444190447165, 3.9191835884530852, 3.9496835316262997, 3.97994974842648, 4.009987531152684, 4.039801975344831, 4.069397989875161, 4.09878030638384, 4.127953488110059, 4.156921938165306, 4.18568990729127, 4.214261501141095, 4.242640687119286, 4.270831300812525, 4.298837052040936, 4.3266615305567875, 4.354308211415448, 4.3817804600413295, 4.409081537009721, 4.436214602563767, 4.463182720884279, 4.48998886412873, 4.5166359162544865, 4.543126676640219, 4.5694638635183455, 4.595650117230424, 4.621688003316537, 4.6475800154489, 4.673328578219169, 4.698936049788292, 4.724404724407087, 4.749736834815168, 4.774934554525329, 4.800000000000001, 4.824935232725928, 4.849742261192857, 4.874423042781577, 4.898979485566357, 4.9234134500364695], [0.0, 0.5, 0.7071067811865476, 0.8660254037844388, 1.0, 1.118033988749895, 1.2247448713915892, 1.3228756555322954, 1.4142135623730951, 1.5, 1.5811388300841898, 1.6583123951777001, 1.7320508075688776, 1.8027756377319948, 1.8708286933869707, 1.9364916731037083, 2.0, 2.0615528128088303, 2.121320343559643, 2.179449471770337, 2.23606797749979, 2.2912878474779204, 2.345207879911715, 2.39791576165636, 2.4494897427831783, 2.5000000000000004, 2.5495097567963927, 2.5980762113533165, 2.6457513110645907, 2.6925824035672523, 2.7386127875258306, 2.783882181415011, 2.8284271247461903, 2.8722813232690148, 2.9154759474226504, 2.958039891549808, 3.0, 3.04138126514911, 3.0822070014844885, 3.1224989991991996, 3.1622776601683795, 3.2015621187164247, 3.2403703492039306, 3.278719262151, 3.3166247903554003, 3.3541019662496843, 3.3911649915626345, 3.4278273002005224, 3.4641016151377553, 3.5, 3.535533905932738, 3.5707142142714257, 3.6055512754639896, 3.64005494464026, 3.6742346141747677, 3.708099243547832, 3.7416573867739413, 3.774917217635375, 3.8078865529319548, 3.840572873934304, 3.8729833462074166, 3.9051248379533274, 3.9370039370059056, 3.968626966596886, 4.0, 4.031128874149275, 4.06201920231798, 4.092676385936225, 4.123105625617661, 4.153311931459037, 4.183300132670378, 4.2130748865881795, 4.242640687119286, 4.272001872658766, 4.301162633521313, 4.330127018922194, 4.358898943540674, 4.387482193696061, 4.415880433163924, 4.444097208657795, 4.47213595499958, 4.500000000000001, 4.527692569068709, 4.55521678957215, 4.582575694955841, 4.609772228646444, 4.636809247747852, 4.663689526544408, 4.69041575982343, 4.716990566028302, 4.743416490252569, 4.769696007084729, 4.79583152331272, 4.821825380496478, 4.847679857416329, 4.873397172404482, 4.898979485566357, 4.924428900898053, 4.949747468305833, 4.974937185533101, 5.000000000000001, 5.024937810560446], [0.0, 0.5099019513592785, 0.7211102550927979, 0.8831760866327849, 1.019803902718557, 1.140175425099138, 1.2489995996796799, 1.3490737563232043, 1.4422205101855958, 1.5297058540778354, 1.61245154965971, 1.6911534525287766, 1.7663521732655698, 1.8384776310850237, 1.9078784028338913, 1.9748417658131499, 2.039607805437114, 2.102379604162864, 2.1633307652783937, 2.2226110770892875, 2.280350850198276, 2.336664289109585, 2.3916521486202797, 2.4454038521274972, 2.4979991993593598, 2.5495097567963927, 2.6000000000000005, 2.6495282598983545, 2.6981475126464085, 2.7459060435491964, 2.792848008753788, 2.839013913315678, 2.8844410203711917, 2.9291637031753623, 2.973213749463701, 3.0166206257996713, 3.059411708155671, 3.101612483854165, 3.1432467291003428, 3.1843366656181322, 3.22490309931942, 3.264965543462902, 3.304542328371662, 3.3436506994600976, 3.382306905057553, 3.420526275297414, 3.458323293158117, 3.4957116585897072, 3.5327043465311396, 3.5693136595149495, 3.6055512754639896, 3.6414282912066254, 3.6769552621700474, 3.712142238654118, 3.7469987990390394, 3.7815340802378077, 3.8157568056677826, 3.849675310984032, 3.8832975677895205, 3.916631205513228, 3.9496835316262997, 3.9824615503479754, 4.014971979976946, 4.047221268969613, 4.079215610874228, 4.110960958218893, 4.142463035441596, 4.173727350941841, 4.204759208325728, 4.235563716909475, 4.266145801540309, 4.296510211788167, 4.3266615305567875, 4.356604182158393, 4.386342439892262, 4.415880433163924, 4.445222154178575, 4.474371464239419, 4.503332099679082, 4.532107677449864, 4.560701700396552, 4.589117562233507, 4.617358552246079, 4.645427859734774, 4.67332857821917, 4.701063709417264, 4.7286361670147565, 4.756048780237647, 4.7833042972405595, 4.810405388322278, 4.83735464897913, 4.864154602806124, 4.8908077042549944, 4.917316341257699, 4.943682837723311, 4.969909455915671, 4.9959983987187195, 5.021951811795889, 5.047771785649585, 5.073460357586329, 5.099019513592785, 5.1244511901275835], [0.0, 0.5196152422706632, 0.7348469228349535, 0.9000000000000001, 1.0392304845413265, 1.1618950038622253, 1.2727922061357857, 1.374772708486752, 1.469693845669907, 1.5588457268119895, 1.6431676725154984, 1.7233687939614089, 1.8000000000000003, 1.8734993995195197, 1.9442222095223582, 2.0124611797498106, 2.078460969082653, 2.142428528562855, 2.2045407685048604, 2.2649503305812253, 2.3237900077244507, 2.381176179958132, 2.4372115213907883, 2.491987158875423, 2.5455844122715714, 2.5980762113533165, 2.6495282598983545, 2.7, 2.749545416973504, 2.7982137159266447, 2.8460498941515415, 2.8930952282978866, 2.939387691339814, 2.9849623113198605, 3.0298514815086235, 3.0740852297878796, 3.117691453623979, 3.160696125855822, 3.203123475609394, 3.244996147917591, 3.286335345030997, 3.3271609519228256, 3.3674916480965478, 3.407345007480164, 3.4467375879228177, 3.4856850115866753, 3.5242020373412197, 3.5623026261113755, 3.6000000000000005, 3.6373066958946425, 3.6742346141747677, 3.7107950630558952, 3.7469987990390394, 3.782856063875548, 3.818376618407357, 3.853569773599539, 3.8884444190447165, 3.9230090491866063, 3.957271787481876, 3.9912404086950213, 4.024922359499621, 4.058324777540605, 4.091454509095756, 4.124318125460256, 4.156921938165306, 4.189272013130682, 4.221374183841087, 4.253234063627348, 4.28485705712571, 4.316248370981448, 4.3474130238568325, 4.378355855797928, 4.409081537009721, 4.439594576084623, 4.469899327725402, 4.5, 4.529900661162451, 4.559605246071199, 4.589117562233508, 4.618441295502196, 4.647580015448901, 4.676537180435969, 4.705316142407438, 4.73392015141785, 4.762352359916264, 4.790615826801394, 4.818713521262704, 4.846648326421054, 4.874423042781577, 4.902040391510457, 4.929503017546495, 4.956813492557492, 4.983974317750846, 5.0109879265470205, 5.037856687124, 5.06458290484024, 5.091168824543143, 5.117616632769595, 5.143928459844674, 5.170106381884226, 5.196152422706633, 5.222068555658764], [0.0, 0.5291502622129182, 0.7483314773547882, 0.9165151389911681, 1.0583005244258363, 1.1832159566199234, 1.2961481396815722, 1.4000000000000001, 1.4966629547095764, 1.5874507866387544, 1.6733200530681511, 1.7549928774784245, 1.8330302779823362, 1.9078784028338915, 1.9798989873223332, 2.0493901531919194, 2.1166010488516727, 2.181742422927143, 2.244994432064365, 2.3065125189341593, 2.366431913239847, 2.4248711305964283, 2.4819347291981715, 2.5377155080899043, 2.5922962793631443, 2.6457513110645907, 2.6981475126464085, 2.749545416973504, 2.8000000000000003, 2.8495613697550017, 2.8982753492378874, 2.946183972531247, 2.993325909419153, 3.039736830714133, 3.0854497241083028, 3.1304951684997055, 3.1749015732775088, 3.2186953878862163, 3.2619012860600183, 3.3045423283716615, 3.3466401061363023, 3.3882148692194836, 3.4292856398964497, 3.4698703145794942, 3.509985754956849, 3.5496478698597693, 3.5888716889852725, 3.627671429443411, 3.6660605559646724, 3.704051835490427, 3.7416573867739418, 3.7788887255382373, 3.815756805667783, 3.852272056851645, 3.8884444190447165, 3.924283374069717, 3.9597979746446663, 3.994996871087636, 4.029888335921977, 4.064480286580315, 4.098780306383839, 4.132795663954365, 4.166533331199932, 4.2, 4.233202097703345, 4.266145801540308, 4.298837052040936, 4.331281565541543, 4.363484845854286, 4.3954521951671826, 4.427188724235731, 4.458699361921591, 4.48998886412873, 4.521061822182926, 4.551922670696417, 4.58257569495584, 4.613025037868319, 4.64327470649756, 4.67332857821917, 4.703190406521939, 4.732863826479694, 4.762352359916263, 4.791659420284376, 4.82078831727758, 4.849742261192857, 4.878524367060187, 4.907137658554119, 4.935585071701227, 4.963869458396343, 4.991993589739474, 5.019960159204453, 5.047771785649585, 5.075431016179809, 5.10294032886923, 5.130302135352265, 5.15751878329105, 5.184592558726289, 5.2115256883181535, 5.238320341483518, 5.264978632435274, 5.291502622129181, 5.317894320123333], [0.0, 0.5385164807134505, 0.7615773105863909, 0.9327379053088817, 1.077032961426901, 1.2041594578792296, 1.319090595827292, 1.4247806848775009, 1.5231546211727818, 1.6155494421403513, 1.7029386365926402, 1.7860571099491753, 1.8654758106177634, 1.94164878389476, 2.0149441679609885, 2.085665361461421, 2.154065922853802, 2.220360331117452, 2.2847319317591728, 2.3473389188611007, 2.4083189157584592, 2.4677925358506134, 2.5258661880630178, 2.582634314028992, 2.638181191654584, 2.6925824035672523, 2.7459060435491964, 2.7982137159266447, 2.8495613697550017, 2.9000000000000004, 2.9495762407505253, 2.99833287011299, 3.0463092423455636, 3.0935416596516045, 3.1400636936215167, 3.1859064644147983, 3.2310988842807027, 3.2756678708318403, 3.3196385345395667, 3.363034344160048, 3.4058772731852804, 3.448187929913334, 3.48998567332303, 3.531288716601915, 3.5721142198983507, 3.6124783736376886, 3.6523964735499352, 3.691882988394947, 3.7309516212355267, 3.769615364994153, 3.8078865529319548, 3.845776904605883, 3.88329756778952, 3.9204591567825324, 3.957271787481876, 3.993745109543172, 4.029888335921977, 4.065710270051224, 4.101219330881976, 4.136423575989287, 4.171330722922842, 4.205948168962618, 4.240283009422838, 4.274342054632503, 4.308131845707604, 4.341658669218482, 4.374928570845472, 4.407947368106838, 4.440720662234904, 4.473253849269009, 4.505552130427525, 4.537620521815371, 4.5694638635183455, 4.601086828130937, 4.632493928760188, 4.663689526544408, 4.694677837722201, 4.725462940284264, 4.756048780237647, 4.786439177509728, 4.8166378315169185, 4.846648326421054, 4.876474136094644, 4.906118628814432, 4.935585071701227, 4.964876634922565, 4.993996395673509, 5.022947341949744, 5.0517323761260355, 5.0803543183522155, 5.10881590977792, 5.137119815616529, 5.165268628057984, 5.193264869039514, 5.221110992882646, 5.2488093888042835, 5.276362383309168, 5.3037722424704485, 5.331041174104736, 5.358171329847527, 5.385164807134505, 5.412023651093924], [0.0, 0.5477225575051661, 0.7745966692414833, 0.9486832980505139, 1.0954451150103321, 1.2247448713915892, 1.3416407864998738, 1.4491376746189437, 1.5491933384829666, 1.6431676725154982, 1.7320508075688772, 1.816590212458495, 1.8973665961010278, 1.9748417658131499, 2.0493901531919194, 2.1213203435596424, 2.1908902300206643, 2.258317958127243, 2.32379000772445, 2.3874672772626644, 2.4494897427831783, 2.5099800796022267, 2.569046515733026, 2.6267851073127395, 2.6832815729997477, 2.7386127875258306, 2.792848008753788, 2.8460498941515415, 2.8982753492378874, 2.9495762407505253, 2.9999999999999996, 3.049590136395381, 3.098386676965933, 3.146426544510455, 3.1937438845342623, 3.2403703492039297, 3.2863353450309964, 3.331666249791536, 3.376388603226826, 3.420526275297414, 3.4641016151377544, 3.5071355833500366, 3.5496478698597698, 3.5916569992135936, 3.63318042491699, 3.674234614174767, 3.714835124201342, 3.7549966711037173, 3.7947331922020555, 3.8340579025361627, 3.872983346207417, 3.9115214431215892, 3.9496835316262997, 3.9874804074753776, 4.024922359499621, 4.06201920231798, 4.098780306383839, 4.135214625627066, 4.171330722922842, 4.207136793592525, 4.242640687119285, 4.277849927241487, 4.3127717305695645, 4.347413023856832, 4.381780460041329, 4.415880433163923, 4.449719092257397, 4.483302354291978, 4.516635916254486, 4.54972526643093, 4.58257569495584, 4.61519230368573, 4.6475800154489, 4.679743582719036, 4.711687595755898, 4.743416490252569, 4.774934554525329, 4.806245936279166, 4.83735464897913, 4.868264577855234, 4.898979485566357, 4.929503017546495, 4.959838707054898, 4.9899899799498595, 5.019960159204453, 5.049752469181039, 5.079370039680118, 5.10881590977792, 5.138093031466052, 5.167204273105525, 5.196152422706632, 5.224940191045253, 5.253570214625479, 5.282045058497703, 5.310367218940701, 5.338539126015655, 5.366563145999495, 5.394441583704471, 5.422176684690383, 5.449770637375485, 5.477225575051661, 5.504543577809154], [0.0, 0.5567764362830022, 0.7874007874011811, 0.9643650760992957, 1.1135528725660044, 1.2449899597988734, 1.3638181696985856, 1.4730919862656235, 1.5748015748023623, 1.6703293088490065, 1.760681686165901, 1.846618531261939, 1.9287301521985913, 2.0074859899884734, 2.083266665599966, 2.1563858652847823, 2.227105745132009, 2.2956480566497994, 2.3622023622035435, 2.4269322199023198, 2.489979919597747, 2.551470164434615, 2.6115129714401193, 2.670205984563738, 2.727636339397171, 2.783882181415011, 2.839013913315678, 2.8930952282978866, 2.946183972531247, 2.99833287011299, 3.049590136395381, 3.1, 3.1496031496047245, 3.1984371183438953, 3.2465366161495854, 3.2939338184001206, 3.340658617698013, 3.38673884437522, 3.432200460346103, 3.477067730142742, 3.521363372331802, 3.5651086939951777, 3.6083237105337433, 3.6510272527057364, 3.693237062523878, 3.7349698793966195, 3.7762415176998414, 3.817066936798463, 3.8574603043971827, 3.8974350539810154, 3.9370039370059056, 3.9761790704142093, 4.014971979976947, 4.053393639902249, 4.091454509095757, 4.129164564412516, 4.166533331199932, 4.20356991139674, 4.240283009422838, 4.276680956068619, 4.3127717305695645, 4.34856298103178, 4.384062043356595, 4.419275958796871, 4.454211490264018, 4.488875137492688, 4.523273151159456, 4.557411546042337, 4.591296113299599, 4.624932431938872, 4.658325879540847, 4.69148164229596, 4.724404724407087, 4.757099956906519, 4.789572005931219, 4.8218253804964775, 4.8538644398046396, 4.8856934001224435, 4.917316341257699, 4.948737212663449, 4.979959839195494, 5.01098792654702, 5.041825066382213, 5.072474741188959, 5.10294032886923, 5.13322510708424, 5.163332257370235, 5.193264869039514, 5.223025942880239, 5.252618394667558, 5.282045058497703, 5.3113086899558, 5.340411969127476, 5.36935750346352, 5.398147830506312, 5.426785420486054, 5.455272678794342, 5.483611948342078, 5.511805511808268, 5.539855593785817, 5.567764362830022, 5.595533933415113], [0.0, 0.565685424949238, 0.7999999999999999, 0.9797958971132713, 1.131370849898476, 1.2649110640673518, 1.3856406460551018, 1.4966629547095764, 1.5999999999999999, 1.697056274847714, 1.7888543819998317, 1.876166303929372, 1.9595917942265426, 2.039607805437114, 2.116601048851672, 2.1908902300206643, 2.262741699796952, 2.33238075793812, 2.4, 2.4657656011875906, 2.5298221281347035, 2.5922962793631443, 2.6532998322843198, 2.7129319932501073, 2.7712812921102037, 2.8284271247461903, 2.8844410203711917, 2.939387691339814, 2.993325909419153, 3.0463092423455636, 3.098386676965933, 3.1496031496047245, 3.1999999999999997, 3.249615361854384, 3.2984845004941286, 3.3466401061363023, 3.394112549695428, 3.4409301068170506, 3.487119154832539, 3.5327043465311387, 3.5777087639996634, 3.622154055254967, 3.6660605559646724, 3.709447398198281, 3.752332607858744, 3.7947331922020546, 3.8366652186501757, 3.878143885933063, 3.9191835884530852, 3.959797974644666, 4.0, 4.039801975344831, 4.079215610874228, 4.118252056394801, 4.156921938165306, 4.1952353926806065, 4.233202097703344, 4.2708313008125245, 4.308131845707603, 4.345112196480086, 4.381780460041329, 4.418144406874904, 4.454211490264017, 4.48998886412873, 4.525483399593904, 4.560701700396551, 4.595650117230423, 4.63033476111609, 4.66476151587624, 4.698936049788292, 4.732863826479693, 4.766550115125193, 4.8, 4.833218389437829, 4.866210024238575, 4.898979485566356, 4.931531202375181, 4.963869458396343, 4.995998398718719, 5.027922035990614, 5.059644256269407, 5.091168824543142, 5.122499389946279, 5.15363949069005, 5.184592558726289, 5.215361924162119, 5.2459508194416005, 5.276362383309167, 5.3065996645686395, 5.336665625650533, 5.366563145999495, 5.396295025292816, 5.4258639865002145, 5.455272678794342, 5.4845236803208355, 5.513619500836088, 5.542562584220407, 5.571355310873648, 5.6, 5.628498911788116, 5.656854249492381, 5.685068161420759], [0.0, 0.574456264653803, 0.812403840463596, 0.9949874371066202, 1.148912529307606, 1.2845232578665131, 1.4071247279470291, 1.5198684153570665, 1.624807680927192, 1.7233687939614086, 1.8165902124584952, 1.9052558883257653, 1.9899748742132404, 2.0712315177207983, 2.149418526020468, 2.224859546128699, 2.297825058615212, 2.3685438564654024, 2.4372115213907883, 2.503996805109783, 2.5690465157330262, 2.632489316217637, 2.6944387170614963, 2.754995462791183, 2.8142494558940583, 2.8722813232690148, 2.9291637031753623, 2.9849623113198605, 3.039736830714133, 3.0935416596516045, 3.146426544510455, 3.1984371183438953, 3.249615361854384, 3.3000000000000007, 3.3496268448888458, 3.398529093593286, 3.4467375879228173, 3.49428104193123, 3.541186241925155, 3.58747822293042, 3.6331804249169903, 3.678314831549905, 3.7229020937972575, 3.7669616403674726, 3.8105117766515306, 3.853569773599539, 3.896151947755632, 3.9382737335030438, 3.9799497484264807, 4.02119385257662, 4.06201920231798, 4.102438299353204, 4.1424630354415966, 4.182104733265298, 4.221374183841087, 4.260281680828159, 4.298837052040936, 4.337049688440288, 4.374928570845472, 4.412482294582042, 4.449719092257398, 4.486646854834912, 4.523273151159457, 4.559605246071199, 4.595650117230424, 4.631414470763764, 4.666904755831214, 4.702127178203499, 4.737087712930805, 4.77179211617606, 4.806245936279167, 4.8404545241123795, 4.874423042781577, 4.908156476723211, 4.941659640242335, 4.974937185533101, 5.007993610219566, 5.040833264451424, 5.07346035758633, 5.105878964487898, 5.1380930314660525, 5.170106381884226, 5.201922721455982, 5.23354564325181, 5.264978632435274, 5.296225070746145, 5.327288240746882, 5.358171329847526, 5.388877434122993, 5.419409561935692, 5.449770637375486, 5.479963503528103, 5.509990925582366, 5.539855593785817, 5.569560126257729, 5.599107071667768, 5.628498911788117, 5.657738063926256, 5.686826883245173, 5.715767664977296, 5.7445626465380295, 5.773214009544425], [0.0, 0.5830951894845301, 0.8246211251235321, 1.009950493836208, 1.1661903789690602, 1.30384048104053, 1.4282856857085702, 1.5427248620541514, 1.6492422502470643, 1.7492855684535902, 1.8439088914585775, 1.9339079605813718, 2.019900987672416, 2.102379604162864, 2.181742422927143, 2.258317958127243, 2.3323807579381204, 2.4041630560342617, 2.4738633753705965, 2.5416530054277673, 2.60768096208106, 2.672077843177478, 2.734958866235469, 2.7964262908219126, 2.8565713714171403, 2.9154759474226504, 2.973213749463701, 3.0298514815086235, 3.0854497241083028, 3.1400636936215167, 3.1937438845342623, 3.2465366161495854, 3.2984845004941286, 3.3496268448888458, 3.4000000000000004, 3.449637662132068, 3.4985711369071804, 3.54682957019364, 3.594440151122286, 3.6414282912066254, 3.687817782917155, 3.733630940518894, 3.7788887255382373, 3.823610858861032, 3.8678159211627436, 3.911521443121589, 3.954743986657038, 3.997499218261337, 4.039801975344832, 4.08166632639171, 4.123105625617661, 4.164132562731403, 4.204759208325728, 4.244997055358225, 4.28485705712571, 4.324349662087931, 4.363484845854286, 4.402272140611028, 4.440720662234904, 4.4788391353117385, 4.516635916254486, 4.5541190146942805, 4.591296113299598, 4.628174586162454, 4.664761515876241, 4.701063709417263, 4.737087712930805, 4.77283982551269, 4.8083261120685235, 4.843552415324934, 4.878524367060187, 4.913247398615299, 4.947726750741193, 4.98196748283246, 5.015974481593781, 5.049752469181039, 5.083306010855535, 5.1166395221864125, 5.149757275833494, 5.182663407939976, 5.21536192416212, 5.247856705360771, 5.280151512977635, 5.31224999411737, 5.344155686354956, 5.375872022286245, 5.40740233383831, 5.4387498563548595, 5.469917732470938, 5.500909015790026, 5.531726674375733, 5.562373594069352, 5.592852581643825, 5.62316636780382, 5.653317610041029, 5.683308895353129, 5.713142742834281, 5.742821606144492, 5.772347875864725, 5.801723881744115, 5.830951894845301, 5.860034129593445], [0.0, 0.5916079783099616, 0.8366600265340756, 1.02469507659596, 1.1832159566199232, 1.3228756555322954, 1.449137674618944, 1.5652475842498528, 1.6733200530681511, 1.7748239349298847, 1.8708286933869707, 1.9621416870348585, 2.04939015319192, 2.1330729007701543, 2.2135943621178655, 2.29128784747792, 2.3664319132398464, 2.4392621835300936, 2.5099800796022267, 2.5787593916455256, 2.6457513110645907, 2.711088342345192, 2.7748873851023217, 2.8372521918222215, 2.898275349237888, 2.958039891549808, 3.0166206257996713, 3.0740852297878796, 3.1304951684997055, 3.1859064644147983, 3.2403703492039297, 3.2939338184001206, 3.3466401061363023, 3.398529093593286, 3.449637662132068, 3.5, 3.5496478698597693, 3.5986108430893164, 3.646916505762094, 3.6945906403822333, 3.7416573867739413, 3.7881393849751626, 3.834057902536163, 3.879432948254164, 3.924283374069717, 3.9686269665968856, 4.012480529547776, 4.05585995813465, 4.09878030638384, 4.141255848169731, 4.183300132670378, 4.224926034855522, 4.266145801540309, 4.306971093471606, 4.347413023856832, 4.387482193696061, 4.427188724235731, 4.466542286825459, 4.505552130427525, 4.544227107000705, 4.58257569495584, 4.620606020859168, 4.658325879540846, 4.695742752749559, 4.732863826479693, 4.769696007084728, 4.806245936279166, 4.8425200051213, 4.878524367060187, 4.914264950122246, 4.949747468305833, 4.984977432245807, 5.019960159204453, 5.054700782440045, 5.089204259999788, 5.123475382979799, 5.157518783291051, 5.191338940966964, 5.2249401910452535, 5.2583267300539625, 5.291502622129181, 5.324471804789654, 5.35723809439155, 5.389805191284746, 5.422176684690384, 5.454356057317858, 5.486346689738081, 5.518151864528558, 5.549774770204643, 5.58121850495033, 5.612486080160912, 5.643580423808984, 5.674504383644443, 5.705260730238365, 5.735852159879995, 5.766281297335397, 5.796550698475776, 5.826662852782887, 5.856620185738529, 5.886425061104576, 5.916079783099616, 5.9455865984779], [0.0, 0.6, 0.848528137423857, 1.0392304845413265, 1.2, 1.3416407864998738, 1.469693845669907, 1.5874507866387544, 1.697056274847714, 1.7999999999999998, 1.8973665961010275, 1.98997487421324, 2.078460969082653, 2.1633307652783937, 2.244994432064365, 2.3237900077244498, 2.4, 2.473863375370596, 2.545584412271571, 2.615339366124404, 2.6832815729997477, 2.749545416973504, 2.814249455894058, 2.877498913987632, 2.939387691339814, 3.0, 3.059411708155671, 3.117691453623979, 3.1749015732775088, 3.2310988842807027, 3.2863353450309964, 3.340658617698013, 3.394112549695428, 3.4467375879228173, 3.4985711369071804, 3.5496478698597693, 3.5999999999999996, 3.6496575181789317, 3.698648401781386, 3.746998799039039, 3.794733192202055, 3.8418745424597094, 3.8884444190447165, 3.9344631145812, 3.97994974842648, 4.024922359499621, 4.069397989875161, 4.113392760240626, 4.156921938165306, 4.2, 4.242640687119285, 4.28485705712571, 4.3266615305567875, 4.368065933568311, 4.409081537009721, 4.449719092257398, 4.48998886412873, 4.52990066116245, 4.569463863518345, 4.608687448721165, 4.6475800154488995, 4.686149805543993, 4.724404724407086, 4.762352359916263, 4.8, 4.8373546489791295, 4.874423042781576, 4.91121166312347, 4.947726750741192, 4.983974317750845, 5.019960159204453, 5.0556898639058145, 5.091168824543142, 5.126402247190518, 5.161395160225576, 5.196152422706632, 5.230678732248808, 5.264978632435273, 5.299056519796709, 5.332916650389353, 5.366563145999495, 5.4, 5.43323108288245, 5.466260147486579, 5.499090833947008, 5.531726674375732, 5.5641710972974225, 5.596427431853289, 5.628498911788116, 5.660388679233962, 5.692099788303082, 5.7236352085016735, 5.754997827975264, 5.786190456595773, 5.817215828899595, 5.848076606885377, 5.878775382679628, 5.909314681077663, 5.939696961966999, 5.96992462263972, 6.0, 6.029925372672535], [0.0, 0.608276253029822, 0.8602325267042626, 1.053565375285274, 1.216552506059644, 1.3601470508735445, 1.489966442575134, 1.6093476939431082, 1.7204650534085253, 1.8248287590894658, 1.9235384061671346, 2.017424100183202, 2.107130750570548, 2.193171219946131, 2.2759613353482084, 2.355843797877949, 2.433105012119288, 2.5079872407968904, 2.5806975801127883, 2.651414716712571, 2.720294101747089, 2.787471972953271, 2.8530685235374214, 2.917190429162965, 2.979932885150268, 3.04138126514911, 3.101612483854165, 3.160696125855822, 3.2186953878862163, 3.2756678708318403, 3.331666249791536, 3.38673884437522, 3.4409301068170506, 3.49428104193123, 3.54682957019364, 3.5986108430893164, 3.6496575181789317, 3.7, 3.7496666518505353, 3.7986839826445165, 3.847076812334269, 3.89486841883009, 3.942080668885405, 3.988734135035826, 4.034848200366404, 4.080441152620633, 4.125530268947254, 4.170131892398609, 4.214261501141096, 4.257933771208754, 4.301162633521314, 4.343961325794695, 4.386342439892262, 4.428317965096906, 4.469899327725402, 4.511097427455985, 4.551922670696417, 4.592385001282014, 4.632493928760188, 4.672258554489466, 4.711687595755898, 4.750789408087881, 4.789572005931219, 4.828043081829325, 4.866210024238576, 4.904079934095691, 4.941659640242335, 4.978955713801841, 5.015974481593781, 5.052722038663912, 5.089204259999789, 5.1254268114957995, 5.1613951602255765, 5.197114584074513, 5.232590180780452, 5.26782687642637, 5.302829433425142, 5.3376024580330075, 5.372150407425318, 5.406477596365309, 5.440588203494178, 5.474486277268398, 5.508175741568166, 5.541660400998964, 5.574943945906542, 5.608029957123981, 5.640921910468182, 5.673623181001714, 5.706137047074843, 5.7384666941614295, 5.770615218501404, 5.8025856305616035, 5.83438085832593, 5.866003750424986, 5.897457079114693, 5.928743543112655, 5.959865770300536, 5.990826320300065, 6.021627686929839, 6.052272300549605, 6.08276253029822, 6.113100686231171], [0.0, 0.6164414002968976, 0.8717797887081348, 1.0677078252031313, 1.2328828005937953, 1.3784048752090223, 1.50996688705415, 1.6309506430300091, 1.7435595774162695, 1.849324200890693, 1.949358868961793, 2.0445048300260877, 2.1354156504062627, 2.222611077089287, 2.3065125189341593, 2.3874672772626644, 2.4657656011875906, 2.541653005427767, 2.615339366124404, 2.687005768508881, 2.7568097504180447, 2.824889378365107, 2.891366458960192, 2.956349099818897, 3.0199337741083, 3.0822070014844885, 3.1432467291003428, 3.203123475609394, 3.2619012860600183, 3.3196385345395667, 3.376388603226826, 3.432200460346103, 3.487119154832539, 3.541186241925155, 3.594440151122286, 3.646916505762094, 3.698648401781386, 3.7496666518505353, 3.8000000000000003, 3.8496753109840323, 3.898717737923586, 3.9471508711981107, 3.9949968710876362, 4.042276586281547, 4.0890096600521755, 4.135214625627066, 4.180908992073375, 4.226109321823088, 4.270831300812525, 4.315089802078284, 4.358898943540674, 4.402272140611029, 4.445222154178574, 4.487761134463376, 4.529900661162451, 4.571651780264984, 4.613025037868319, 4.654030511288038, 4.694677837722201, 4.734976240700686, 4.774934554525329, 4.814561246884289, 4.853864439804639, 4.892851929090027, 4.931531202375181, 4.969909455915671, 5.007993610219566, 5.045790324617146, 5.083306010855534, 5.120546845796843, 5.157518783291051, 5.194227565288221, 5.230678732248808, 5.266877632905477, 5.302829433425141, 5.338539126015656, 5.374011537017762, 5.409251334519409, 5.444263035526481, 5.47905101272109, 5.513619500836089, 5.547972602672079, 5.582114294781146, 5.616048432839589, 5.649778756730214, 5.68330889535313, 5.716642371182581, 5.749782604586021, 5.782732917920384, 5.815496539419485, 5.848076606885378, 5.880476171195663, 5.912698199637794, 5.944745579080741, 5.976621118993575, 6.008327554319921, 6.0398675482166, 6.071243694664217, 6.102458520956943, 6.133514490078262, 6.164414002968977, 6.1951594006934165], [0.0, 0.6244997998398399, 0.8831760866327847, 1.081665382639197, 1.2489995996796799, 1.3964240043768943, 1.5297058540778357, 1.6522711641858308, 1.7663521732655694, 1.8734993995195195, 1.97484176581315, 2.0712315177207983, 2.163330765278394, 2.2516660498395407, 2.3366642891095846, 2.4186773244895647, 2.4979991993593598, 2.574878637916747, 2.6495282598983545, 2.7221315177632404, 2.7928480087537886, 2.861817604250837, 2.9291637031753623, 2.994995826374388, 3.0594117081556713, 3.1224989991991996, 3.1843366656181322, 3.244996147917591, 3.3045423283716615, 3.363034344160048, 3.420526275297414, 3.477067730142742, 3.5327043465311387, 3.58747822293042, 3.6414282912066254, 3.6945906403822333, 3.746998799039039, 3.7986839826445165, 3.8496753109840323, 3.900000000000001, 3.9496835316263, 3.9987498046264416, 4.047221268969613, 4.095119045888654, 4.1424630354415966, 4.189272013130682, 4.235563716909475, 4.281354925721529, 4.326661530556788, 4.371498598878879, 4.415880433163924, 4.459820624195553, 4.503332099679081, 4.546427168667723, 4.589117562233507, 4.631414470763765, 4.673328578219169, 4.7148700936505135, 4.756048780237647, 4.796873982084583, 4.8373546489791295, 4.87749935930288, 4.917316341257699, 4.956813492557492, 4.9959983987187195, 5.034878350069642, 5.073460357586329, 5.111751167652823, 5.149757275833494, 5.187484939737176, 5.2249401910452535, 5.262128846769148, 5.299056519796709, 5.335728628781641, 5.372150407425317, 5.408326913195984, 5.444263035526481, 5.479963503528103, 5.515432893255072, 5.550675634551168, 5.585696017507577, 5.620498198558559, 5.655086206239478, 5.68946394662977, 5.723635208501674, 5.757603668193913, 5.791372894228104, 5.8249463516842805, 5.858327406350725, 5.8915193286621745, 5.92452529743945, 5.957348403442593, 5.989991652748776, 6.02245796996542, 6.054750201288242, 6.08687111741328, 6.118823416311343, 6.150609725872713, 6.182232606429493, 6.213694553162394, 6.244997998398399, 6.276145313805283], [0.0, 0.6324555320336759, 0.8944271909999159, 1.0954451150103324, 1.2649110640673518, 1.4142135623730951, 1.5491933384829668, 1.6733200530681511, 1.7888543819998317, 1.8973665961010275, 2.0, 2.0976176963403033, 2.1908902300206647, 2.280350850198276, 2.3664319132398464, 2.449489742783178, 2.5298221281347035, 2.6076809620810595, 2.6832815729997477, 2.7568097504180447, 2.8284271247461903, 2.898275349237888, 2.9664793948382653, 3.0331501776206204, 3.0983866769659336, 3.1622776601683795, 3.22490309931942, 3.286335345030997, 3.3466401061363023, 3.4058772731852804, 3.4641016151377544, 3.521363372331802, 3.5777087639996634, 3.6331804249169903, 3.687817782917155, 3.7416573867739413, 3.794733192202055, 3.847076812334269, 3.898717737923586, 3.9496835316263, 4.0, 4.049691346263318, 4.09878030638384, 4.147288270665544, 4.1952353926806065, 4.242640687119285, 4.2895221179054435, 4.33589667773576, 4.3817804600413295, 4.427188724235731, 4.47213595499958, 4.5166359162544865, 4.560701700396552, 4.604345773288536, 4.6475800154489, 4.69041575982343, 4.732863826479693, 4.774934554525329, 4.8166378315169185, 4.857983120596447, 4.898979485566356, 4.9396356140913875, 4.979959839195493, 5.019960159204453, 5.059644256269407, 5.0990195135927845, 5.138093031466052, 5.176871642217914, 5.215361924162119, 5.253570214625479, 5.291502622129181, 5.329165037789691, 5.366563145999495, 5.403702434442518, 5.440588203494177, 5.477225575051661, 5.513619500836089, 5.549774770204643, 5.585696017507577, 5.621387729022079, 5.656854249492381, 5.692099788303083, 5.727128425310542, 5.761944116355173, 5.796550698475776, 5.830951894845301, 5.865151319446072, 5.8991524815010505, 5.932958789676531, 5.966573556070519, 6.0, 6.0332412515993425, 6.066300355241241, 6.099180272790763, 6.131883886702357, 6.164414002968976, 6.196773353931867, 6.228964600958975, 6.260990336999411, 6.29285308902091, 6.324555320336759, 6.356099432828282], [0.0, 0.6403124237432849, 0.9055385138137417, 1.1090536506409419, 1.2806248474865698, 1.4317821063276355, 1.5684387141358125, 1.6941074346097418, 1.8110770276274835, 1.9209372712298547, 2.024845673131659, 2.1236760581595306, 2.2181073012818837, 2.3086792761230397, 2.395829710142188, 2.479919353527449, 2.5612496949731396, 2.6400757564888173, 2.716615541441225, 2.791057147390573, 2.863564212655271, 2.934280150224242, 3.0033314835362415, 3.0708305065568178, 3.136877428271625, 3.2015621187164247, 3.264965543462902, 3.3271609519228256, 3.3882148692194836, 3.448187929913334, 3.5071355833500366, 3.5651086939951777, 3.622154055254967, 3.678314831549905, 3.733630940518894, 3.7881393849751626, 3.8418745424597094, 3.89486841883009, 3.9471508711981107, 3.9987498046264416, 4.049691346263318, 4.1000000000000005, 4.149698784249287, 4.198809355043403, 4.247352116319061, 4.295346318982906, 4.342810150121693, 4.389760813529594, 4.436214602563767, 4.4821869662029945, 4.527692569068709, 4.572745346069471, 4.617358552246079, 4.661544808322667, 4.705316142407437, 4.748684028233507, 4.791659420284376, 4.8342527861087286, 4.876474136094644, 4.9183330509431755, 4.959838707054898, 5.000999900019996, 5.041825066382213, 5.082322303829225, 5.122499389946279, 5.162363799656123, 5.201922721455982, 5.241183072551464, 5.280151512977635, 5.3188344587888805, 5.35723809439155, 5.395368384086485, 5.43323108288245, 5.470831746635972, 5.508175741568165, 5.545268253204709, 5.582114294781146, 5.61871871515206, 5.655086206239478, 5.691221310052879, 5.727128425310542, 5.762811813689565, 5.798275605729691, 5.833523806414096, 5.868560300448484, 5.903388857258177, 5.93801313572141, 5.9724366886556455, 6.006662967072483, 6.040695324215583, 6.074537019394977, 6.1081912216301815, 6.1416610131136355, 6.174949392505174, 6.208059278067504, 6.24099351065197, 6.27375485654325, 6.306346010171025, 6.338769596696192, 6.3710281744785915, 6.403124237432849, 6.435060217278469], [0.0, 0.6480740698407861, 0.9165151389911681, 1.1224972160321827, 1.2961481396815722, 1.4491376746189442, 1.5874507866387546, 1.7146428199482249, 1.8330302779823362, 1.9442222095223582, 2.04939015319192, 2.149418526020468, 2.2449944320643653, 2.336664289109585, 2.4248711305964283, 2.5099800796022267, 2.5922962793631443, 2.672077843177478, 2.749545416973504, 2.8248893783651075, 2.8982753492378883, 2.9698484809835, 3.039736830714133, 3.108054053584011, 3.174901573277509, 3.2403703492039306, 3.304542328371662, 3.3674916480965478, 3.4292856398964497, 3.48998567332303, 3.5496478698597698, 3.6083237105337433, 3.6660605559646724, 3.7229020937972575, 3.7788887255382373, 3.834057902536163, 3.8884444190447165, 3.942080668885405, 3.9949968710876362, 4.047221268969613, 4.09878030638384, 4.149698784249287, 4.200000000000001, 4.249705872175156, 4.298837052040936, 4.347413023856832, 4.3954521951671826, 4.442971978304612, 4.489988864128731, 4.536518488885503, 4.582575694955841, 4.628174586162455, 4.67332857821917, 4.718050444834181, 4.762352359916264, 4.806245936279167, 4.849742261192857, 4.892851929090027, 4.935585071701227, 4.9779513858614575, 5.019960159204453, 5.061620293937506, 5.10294032886923, 5.143928459844674, 5.184592558726289, 5.224940191045253, 5.264978632435274, 5.304714883949938, 5.344155686354956, 5.383307533477909, 5.422176684690385, 5.46076917659042, 5.499090833947008, 5.537147279962851, 5.574943945906542, 5.612486080160912, 5.649778756730215, 5.686826883245173, 5.723635208501675, 5.760208329565868, 5.796550698475777, 5.832666628567075, 5.868560300448485, 5.904235767650205, 5.939696961967, 5.974947698515863, 6.009991680526689, 6.044832503882966, 6.079473661428266, 6.113918547053109, 6.148170459575759, 6.182232606429493, 6.216108107168022, 6.249799996799899, 6.283311228962004, 6.316644678941503, 6.349803146555018, 6.38278935889318, 6.4156059729381765, 6.448255578061405, 6.480740698407861, 6.5130637951735135], [0.0, 0.6557438524302001, 0.9273618495495702, 1.1357816691600549, 1.3114877048604001, 1.466287829861518, 1.606237840420901, 1.7349351572897471, 1.8547236990991405, 1.9672315572906, 2.073644135332772, 2.1748563170931545, 2.2715633383201097, 2.364318083507378, 2.453568829277059, 2.5396850198400585, 2.6229754097208002, 2.7037011669191546, 2.782085548648711, 2.8583211855912904, 2.932575659723036, 3.004995840263344, 3.0757112998459397, 3.1448370387032774, 3.212475680841802, 3.278719262151, 3.3436506994600976, 3.407345007480164, 3.4698703145794942, 3.531288716601915, 3.5916569992135936, 3.6510272527057364, 3.709447398198281, 3.7669616403674726, 3.823610858861032, 3.879432948254164, 3.9344631145812, 3.988734135035826, 4.042276586281547, 4.095119045888654, 4.147288270665544, 4.198809355043403, 4.249705872175156, 4.299999999999999, 4.349712634186309, 4.398863489584553, 4.447471191587417, 4.495553358597804, 4.543126676640219, 4.5902069670114, 4.636809247747852, 4.682947789587239, 4.728636167014756, 4.773887304912004, 4.818713521262703, 4.863126566315131, 4.907137658554118, 4.950757517794625, 4.993996395673509, 5.03686410378521, 5.079370039680117, 5.121523210920751, 5.163332257370234, 5.204805471869242, 5.2459508194416005, 5.28677595515452, 5.3272882407468805, 5.367494760127856, 5.407402333838309, 5.447017532558529, 5.486346689738081, 5.525395913416522, 5.564171097297422, 5.602677931132575, 5.6409219104681805, 5.678908345800274, 5.716642371182581, 5.754128952326321, 5.791372894228104, 5.8283788483591215, 5.865151319446072, 5.9016946718718, 5.938013135721409, 5.974110812497538, 6.009991680526688, 6.0456596000767355, 6.081118318204308, 6.1163714733492105, 6.151422599691879, 6.186275131288617, 6.220932405998315, 6.255397669213365, 6.289674077406555, 6.323764701504951, 6.357672530100933, 6.3914004725099165, 6.424951361683604, 6.458327956987009, 6.491532946846992, 6.524568951279464, 6.557438524302, 6.590144156238162], [0.0, 0.66332495807108, 0.938083151964686, 1.148912529307606, 1.32664991614216, 1.4832396974191329, 1.6248076809271923, 1.7549928774784245, 1.876166303929372, 1.98997487421324, 2.0976176963403033, 2.2, 2.297825058615212, 2.3916521486202797, 2.4819347291981715, 2.569046515733026, 2.65329983228432, 2.734958866235469, 2.814249455894058, 2.8913664589601926, 2.9664793948382657, 3.039736830714133, 3.1112698372208096, 3.1811947441173736, 3.2496153618543846, 3.3166247903554003, 3.382306905057553, 3.4467375879228177, 3.509985754956849, 3.5721142198983507, 3.63318042491699, 3.693237062523878, 3.752332607858744, 3.8105117766515306, 3.8678159211627436, 3.924283374069717, 3.97994974842648, 4.034848200366404, 4.0890096600521755, 4.1424630354415966, 4.1952353926806065, 4.247352116319061, 4.298837052040936, 4.349712634186309, 4.4, 4.449719092257398, 4.498888751680798, 4.54752680036083, 4.595650117230424, 4.64327470649756, 4.69041575982343, 4.737087712930806, 4.7833042972405595, 4.829078587059855, 4.874423042781577, 4.919349550499538, 4.963869458396343, 5.007993610219566, 5.051732376126036, 5.095095681142799, 5.138093031466052, 5.180733538795447, 5.223025942880239, 5.264978632435274, 5.30659966456864, 5.347896782848375, 5.388877434122993, 5.429548784199292, 5.469917732470938, 5.509990925582365, 5.549774770204644, 5.589275444992849, 5.628498911788116, 5.667450926121902, 5.706137047074843, 5.7445626465380295, 5.782732917920385, 5.8206528843421, 5.858327406350725, 5.895761189193471, 5.9329587896765315, 5.969924622639721, 6.006662967072484, 6.043177971895251, 6.079473661428266, 6.115553940568263, 6.15142259969188, 6.187083319303208, 6.222539674441619, 6.2577951388648065, 6.29285308902091, 6.327716807822551, 6.362389488234747, 6.3968742366877915, 6.431174076325411, 6.465291950097845, 6.499230723708769, 6.532993188424431, 6.566582063752802, 6.600000000000001, 6.6332495807108005, 6.666333324999584], [0.0, 0.6708203932499369, 0.9486832980505137, 1.161895003862225, 1.3416407864998738, 1.5, 1.6431676725154982, 1.7748239349298847, 1.8973665961010273, 2.0124611797498106, 2.1213203435596424, 2.224859546128699, 2.32379000772445, 2.4186773244895647, 2.5099800796022262, 2.5980762113533156, 2.6832815729997477, 2.765863337187866, 2.846049894151541, 2.924038303442689, 3.0, 3.0740852297878796, 3.1464265445104544, 3.2171415884290826, 3.2863353450309964, 3.3541019662496843, 3.420526275297414, 3.4856850115866753, 3.5496478698597693, 3.6124783736376886, 3.674234614174767, 3.7349698793966195, 3.7947331922020546, 3.853569773599539, 3.911521443121589, 3.9686269665968856, 4.024922359499621, 4.080441152620633, 4.135214625627066, 4.189272013130682, 4.242640687119285, 4.295346318982906, 4.347413023856832, 4.398863489584553, 4.449719092257398, 4.499999999999999, 4.54972526643093, 4.598912915026768, 4.6475800154489, 4.695742752749558, 4.743416490252569, 4.790615826801393, 4.8373546489791295, 4.883646178829912, 4.9295030175464944, 4.9749371855331, 5.0199601592044525, 5.064582904840239, 5.10881590977792, 5.1526692111953, 5.196152422706631, 5.239274758971893, 5.282045058497702, 5.324471804789654, 5.366563145999495, 5.4083269131959835, 5.449770637375485, 5.490901565316937, 5.531726674375732, 5.572252686302012, 5.612486080160912, 5.652433104425031, 5.692099788303082, 5.731491952362839, 5.770615218501403, 5.809475019311125, 5.848076606885378, 5.886425061104575, 5.92452529743945, 5.962382074305537, 6.0, 6.037383539249432, 6.074537019394977, 6.111464636239008, 6.148170459575759, 6.18465843842649, 6.220932405998316, 6.256996084384263, 6.292853089020909, 6.328506932918695, 6.363961030678928, 6.399218702310462, 6.434283176858165, 6.469157595854347, 6.5038450166036395, 6.53834841531101, 6.572670690061993, 6.606814663663572, 6.640783086353596, 6.674578638386096, 6.7082039324993685, 6.74166151627327], [0.0, 0.6782329983125268, 0.9591663046625439, 1.1747340124470733, 1.3564659966250536, 1.5165750888103102, 1.661324772583615, 1.7944358444926363, 1.9183326093250879, 2.0346989949375804, 2.1447610589527217, 2.249444375840399, 2.3494680248941466, 2.445403852127497, 2.5377155080899043, 2.626785107312739, 2.7129319932501073, 2.7964262908219126, 2.877498913987632, 2.956349099818897, 3.0331501776206204, 3.108054053584011, 3.1811947441173736, 3.252691193458119, 3.32264954516723, 3.3911649915626345, 3.458323293158117, 3.5242020373412197, 3.5888716889852725, 3.6523964735499352, 3.714835124201342, 3.7762415176998414, 3.8366652186501757, 3.896151947755632, 3.954743986657038, 4.012480529547776, 4.069397989875161, 4.125530268947254, 4.180908992073375, 4.235563716909475, 4.2895221179054435, 4.342810150121693, 4.3954521951671826, 4.447471191587417, 4.498888751680798, 4.54972526643093, 4.6000000000000005, 4.649731175025068, 4.698936049788293, 4.747630988187688, 4.79583152331272, 4.843552415324934, 4.890807704254994, 4.937610758251404, 4.983974317750845, 5.029910535983717, 5.075431016179809, 5.120546845796843, 5.165268628057984, 5.209606511052442, 5.253570214625478, 5.297169055259611, 5.340411969127476, 5.383307533477908, 5.4258639865002145, 5.468089245796926, 5.509990925582365, 5.551576352712804, 5.592852581643825, 5.63382640840131, 5.674504383644443, 5.71489282489182, 5.754997827975264, 5.794825277780168, 5.834380858325929, 5.873670062235366, 5.912698199637794, 5.951470406546605, 5.989991652748776, 6.028266749240615, 6.066300355241241, 6.104096984812742, 6.1416610131136355, 6.178996682310163, 6.216108107168022, 6.252999280345393, 6.289674077406556, 6.326136261573884, 6.362389488234747, 6.398437309218556, 6.434283176858165, 6.469930447848725, 6.505382386916238, 6.540642170307134, 6.57571288910944, 6.6105975524153635, 6.64529909033446, 6.679820356865895, 6.714164132637808, 6.748333127521196, 6.782329983125269, 6.81615727518079], [0.0, 0.6855654600401044, 0.9695359714832658, 1.187434208703792, 1.3711309200802089, 1.5329709716755893, 1.6792855623746665, 1.8138357147217055, 1.9390719429665315, 2.056696380120313, 2.16794833886788, 2.273763400180415, 2.374868417407584, 2.471841418861655, 2.565151067676132, 2.6551836094703507, 2.7422618401604177, 2.826658805020514, 2.9086079144497976, 2.9883105594967874, 3.0659419433511785, 3.1416556144810017, 3.2155870381627056, 3.2878564445547194, 3.358571124749333, 3.4278273002005224, 3.4957116585897072, 3.5623026261113755, 3.627671429443411, 3.691882988394947, 3.7549966711037173, 3.817066936798463, 3.878143885933063, 3.9382737335030438, 3.997499218261337, 4.05585995813465, 4.113392760240626, 4.170131892398609, 4.226109321823088, 4.281354925721529, 4.33589667773576, 4.389760813529594, 4.442971978304612, 4.495553358597804, 4.54752680036083, 4.598912915026768, 4.649731175025068, 4.7, 4.749736834815168, 4.798958220280731, 4.847679857416329, 4.89591666595746, 4.94368283772331, 4.990991885387113, 5.037856687124, 5.084289527554465, 5.130302135352264, 5.175905717843014, 5.221110992882646, 5.265928218272634, 5.310367218940701, 5.354437412091022, 5.3981478305063115, 5.441507144165117, 5.4845236803208355, 5.527205442174191, 5.569560126257728, 5.61159513863928, 5.653317610041028, 5.69473440996154, 5.735852159879995, 5.776677245614472, 5.817215828899595, 5.857473858242988, 5.897457079114692, 5.937171043518958, 5.976621118993575, 6.015812497078014, 6.054750201288242, 6.09343909463285, 6.131883886702357, 6.17008914036094, 6.208059278067503, 6.245798587850876, 6.2833112289620034, 6.320601237224193, 6.357672530100934, 6.394528911499267, 6.431174076325411, 6.4676116148080505, 6.5038450166036395, 6.539877674696982, 6.575712889109439, 6.611353870426239, 6.646803743153547, 6.682065548915245, 6.717142249498666, 6.7520367297579185, 6.786751800382861, 6.821290200541244, 6.855654600401045, 6.889847603539574], [0.0, 0.692820323027551, 0.9797958971132713, 1.2000000000000004, 1.385640646055102, 1.549193338482967, 1.6970562748477143, 1.8330302779823362, 1.9595917942265426, 2.078460969082653, 2.1908902300206647, 2.297825058615212, 2.400000000000001, 2.4979991993593598, 2.5922962793631443, 2.6832815729997477, 2.771281292110204, 2.8565713714171403, 2.9393876913398143, 3.0199337741083006, 3.098386676965934, 3.174901573277509, 3.2496153618543846, 3.3226495451672307, 3.3941125496954285, 3.4641016151377553, 3.5327043465311396, 3.6000000000000005, 3.6660605559646724, 3.7309516212355267, 3.7947331922020555, 3.8574603043971827, 3.9191835884530852, 3.9799497484264807, 4.039801975344832, 4.09878030638384, 4.156921938165306, 4.214261501141096, 4.270831300812525, 4.326661530556788, 4.3817804600413295, 4.436214602563767, 4.489988864128731, 4.543126676640219, 4.595650117230424, 4.6475800154489, 4.698936049788293, 4.749736834815168, 4.800000000000002, 4.849742261192857, 4.898979485566357, 4.947726750741194, 4.9959983987187195, 5.043808085167398, 5.091168824543143, 5.1380930314660525, 5.184592558726289, 5.230678732248809, 5.276362383309169, 5.321653878260029, 5.366563145999495, 5.411099703387474, 5.455272678794342, 5.499090833947009, 5.542562584220408, 5.585696017507577, 5.628498911788117, 5.670978751503131, 5.713142742834281, 5.754997827975265, 5.796550698475777, 5.83780780773057, 5.8787753826796285, 5.9194594347794975, 5.959865770300536, 6.000000000000001, 6.039867548216601, 6.079473661428266, 6.1188234163113435, 6.157921727336262, 6.196773353931868, 6.235382907247959, 6.27375485654325, 6.311893535223801, 6.349803146555018, 6.387487769068526, 6.424951361683605, 6.462197768561406, 6.499230723708769, 6.536053855347277, 6.572670690061994, 6.609084656743323, 6.645299090334461, 6.681317235396028, 6.717142249498667, 6.752777206453653, 6.788225099390857, 6.823488843692794, 6.8585712797928995, 6.893475175845635, 6.9282032302755105, 6.962758074211686], [0.0, 0.7000000000000001, 0.9899494936611665, 1.2124355652982142, 1.4000000000000001, 1.565247584249853, 1.7146428199482247, 1.8520259177452134, 1.979898987322333, 2.1, 2.2135943621178655, 2.32163735324878, 2.4248711305964283, 2.5238858928247927, 2.619160170741759, 2.7110883423451915, 2.8000000000000003, 2.8861739379323623, 2.9698484809834995, 3.051229260478472, 3.130495168499706, 3.2078029864690882, 3.283291031876401, 3.357082066318904, 3.4292856398964493, 3.5, 3.5693136595149495, 3.6373066958946425, 3.704051835490427, 3.769615364994153, 3.8340579025361627, 3.8974350539810154, 3.959797974644666, 4.02119385257662, 4.08166632639171, 4.141255848169731, 4.2, 4.257933771208754, 4.315089802078284, 4.371498598878879, 4.427188724235731, 4.4821869662029945, 4.536518488885503, 4.5902069670114, 4.64327470649756, 4.695742752749558, 4.747630988187688, 4.798958220280731, 4.849742261192857, 4.9, 4.949747468305833, 4.998999899979996, 5.047771785649585, 5.096076922496363, 5.143928459844674, 5.191338940966964, 5.238320341483518, 5.2848841046895245, 5.331041174104736, 5.376802023508025, 5.422176684690383, 5.467174773134658, 5.511805511808268, 5.55607775323564, 5.6000000000000005, 5.643580423808984, 5.686826883245172, 5.729746940310715, 5.772347875864725, 5.814636704042653, 5.856620185738529, 5.898304841223451, 5.939696961966999, 5.980802621722272, 6.021627686929839, 6.06217782649107, 6.102458520956944, 6.142475071174486, 6.182232606429493, 6.221736092120913, 6.260990336999412, 6.300000000000001, 6.338769596696192, 6.377303505401009, 6.4156059729381765, 6.4536811201050215, 6.491532946846993, 6.529165337162171, 6.566582063752802, 6.603786792439623, 6.640783086353597, 6.67757440991862, 6.714164132637808, 6.750555532695069, 6.786751800382861, 6.822756041366274, 6.858571279792899, 6.894200461257274, 6.929646455628165, 6.96491205974634, 7.0, 7.034912934784624], [0.0, 0.7071067811865476, 1.0, 1.2247448713915892, 1.4142135623730951, 1.5811388300841898, 1.7320508075688774, 1.8708286933869709, 2.0, 2.1213203435596424, 2.23606797749979, 2.345207879911715, 2.4494897427831783, 2.5495097567963927, 2.6457513110645907, 2.7386127875258306, 2.8284271247461903, 2.9154759474226504, 3.0, 3.082207001484489, 3.1622776601683795, 3.2403703492039306, 3.3166247903554003, 3.3911649915626345, 3.464101615137755, 3.535533905932738, 3.6055512754639896, 3.6742346141747677, 3.7416573867739418, 3.8078865529319548, 3.872983346207417, 3.9370039370059056, 4.0, 4.06201920231798, 4.123105625617661, 4.183300132670378, 4.242640687119285, 4.301162633521314, 4.358898943540674, 4.415880433163924, 4.47213595499958, 4.527692569068709, 4.582575694955841, 4.636809247747852, 4.69041575982343, 4.743416490252569, 4.79583152331272, 4.847679857416329, 4.898979485566357, 4.949747468305833, 5.000000000000001, 5.04975246918104, 5.099019513592785, 5.147815070493501, 5.196152422706632, 5.244044240850759, 5.291502622129181, 5.338539126015656, 5.385164807134505, 5.431390245600108, 5.477225575051661, 5.522680508593631, 5.5677643628300215, 5.612486080160912, 5.656854249492381, 5.70087712549569, 5.744562646538029, 5.787918451395113, 5.830951894845301, 5.873670062235366, 5.916079783099617, 5.958187643906493, 6.0, 6.041522986797286, 6.082762530298219, 6.123724356957946, 6.164414002968978, 6.2048368229954285, 6.244997998398399, 6.284902544988268, 6.324555320336759, 6.3639610306789285, 6.403124237432849, 6.442049363362563, 6.480740698407861, 6.519202405202649, 6.557438524302001, 6.59545297913646, 6.6332495807108005, 6.670832032063167, 6.708203932499369, 6.745368781616021, 6.782329983125269, 6.8190908484929285, 6.855654600401045, 6.892024376045111, 6.92820323027551, 6.9641941385920605, 7.0, 7.035623639735145, 7.071067811865476, 7.1063352017759485], [0.0, 0.7141428428542851, 1.0099504938362078, 1.2369316876852985, 1.4282856857085702, 1.5968719422671316, 1.7492855684535904, 1.8894443627691186, 2.0199009876724157, 2.142428528562855, 2.2583179581272432, 2.368543856465403, 2.473863375370597, 2.574878637916747, 2.672077843177478, 2.765863337187866, 2.8565713714171403, 2.944486372867092, 3.029851481508624, 3.1128764832546767, 3.193743884534263, 3.272613634390715, 3.3496268448888458, 3.4249087579087423, 3.498571136907181, 3.5707142142714257, 3.6414282912066254, 3.7107950630558952, 3.7788887255382373, 3.845776904605883, 3.9115214431215892, 3.9761790704142093, 4.039801975344831, 4.102438299353204, 4.164132562731403, 4.224926034855522, 4.28485705712571, 4.343961325794695, 4.402272140611029, 4.459820624195553, 4.5166359162544865, 4.572745346069471, 4.628174586162455, 4.682947789587239, 4.737087712930806, 4.790615826801393, 4.843552415324934, 4.89591666595746, 4.947726750741194, 4.998999899979996, 5.04975246918104, 5.100000000000001, 5.149757275833494, 5.199038372622384, 5.247856705360771, 5.296225070746145, 5.344155686354956, 5.391660226683429, 5.43874985635486, 5.485435260760991, 5.531726674375732, 5.577633906953737, 5.62316636780382, 5.668333088307356, 5.713142742834281, 5.757603668193913, 5.801723881744115, 5.845511098270194, 5.888972745734184, 5.932115979985557, 5.974947698515863, 6.017474553332154, 6.059702963017248, 6.101639124038721, 6.143289021363068, 6.184658438426491, 6.225752966509353, 6.266578013557321, 6.307138812488593, 6.347440429023341, 6.387487769068526, 6.427285585688566, 6.466838485689898, 6.506150935845249, 6.54522726878143, 6.584071688552609, 6.62268827591938, 6.661080993352356, 6.6992536897776915, 6.73721010508059, 6.77495387438173, 6.81248853210044, 6.8498175158174845, 6.886944169949399, 6.923871749245506, 6.960603422117942, 6.997142273814362, 7.033491309442276, 7.069653456853455, 7.105631569396208, 7.141428428542851, 7.177046746399247], [0.0, 0.7211102550927979, 1.019803902718557, 1.2489995996796799, 1.4422205101855958, 1.61245154965971, 1.7663521732655696, 1.9078784028338915, 2.039607805437114, 2.1633307652783937, 2.280350850198276, 2.3916521486202797, 2.4979991993593598, 2.6000000000000005, 2.6981475126464085, 2.792848008753788, 2.8844410203711917, 2.973213749463701, 3.0594117081556713, 3.1432467291003428, 3.22490309931942, 3.3045423283716615, 3.3823069050575527, 3.458323293158117, 3.532704346531139, 3.6055512754639896, 3.6769552621700474, 3.7469987990390394, 3.815756805667783, 3.88329756778952, 3.9496835316262997, 4.014971979976947, 4.079215610874228, 4.1424630354415966, 4.204759208325728, 4.266145801540309, 4.3266615305567875, 4.386342439892262, 4.445222154178574, 4.503332099679081, 4.560701700396552, 4.617358552246079, 4.67332857821917, 4.728636167014756, 4.7833042972405595, 4.8373546489791295, 4.890807704254994, 4.94368283772331, 4.9959983987187195, 5.047771785649585, 5.099019513592785, 5.149757275833494, 5.200000000000001, 5.249761899362676, 5.299056519796709, 5.347896782848376, 5.396295025292817, 5.44426303552648, 5.491812087098393, 5.5389529696504916, 5.585696017507576, 5.63205113613149, 5.678027826631356, 5.723635208501674, 5.768882040742383, 5.813776741499453, 5.858327406350725, 5.902541825349482, 5.946427498927402, 5.989991652748776, 6.033241251599343, 6.076183012385325, 6.118823416311343, 6.161168720299745, 6.203224967708329, 6.244997998398398, 6.2864934582006855, 6.327716807822551, 6.3686733312362644, 6.409368143584826, 6.44980619863884, 6.489992295835181, 6.529931086925804, 6.569627082262737, 6.609084656743323, 6.648308055437865, 6.687301398920196, 6.726068688320096, 6.764613810115105, 6.802940540677979, 6.841052550594828, 6.878953408767936, 6.916646586316234, 6.954135460285485, 6.9914233171794145, 7.0285133563222315, 7.065408693062278, 7.102112361825883, 7.138627319029899, 7.17495644586084, 7.211102550927979, 7.247068372797377], [0.0, 0.7280109889280519, 1.0295630140987002, 1.2609520212918495, 1.4560219778561039, 1.627882059609971, 1.7832554500127011, 1.9261360284258224, 2.0591260281974004, 2.1840329667841556, 2.302172886644268, 2.4145392935299275, 2.521904042583699, 2.624880949681338, 2.7239676943752476, 2.819574435974337, 2.9120439557122078, 3.001666203960727, 3.0886890422961004, 3.1733263305244868, 3.255764119219942, 3.336165463522456, 3.414674215792775, 3.491418050019219, 3.5665109000254023, 3.64005494464026, 3.712142238654118, 3.782856063875548, 3.852272056851645, 3.9204591567825324, 3.9874804074753776, 4.053393639902249, 4.118252056394801, 4.182104733265298, 4.244997055358225, 4.306971093471606, 4.368065933568311, 4.428317965096906, 4.487761134463376, 4.546427168667723, 4.604345773288536, 4.661544808322667, 4.718050444834181, 4.773887304912004, 4.829078587059855, 4.883646178829912, 4.937610758251404, 4.990991885387113, 5.043808085167398, 5.096076922496363, 5.147815070493501, 5.199038372622384, 5.249761899362676, 5.300000000000001, 5.349766350038103, 5.399073994677236, 5.447935388750495, 5.496362433464519, 5.5443665102516455, 5.591958512006326, 5.639148871948674, 5.6859475903318, 5.732364259186606, 5.7784080852774675, 5.8240879114244155, 5.869412236331676, 5.914389233048499, 5.959026766175833, 6.003332407921454, 6.047313453096343, 6.090976933136425, 6.134329629226001, 6.177378084592201, 6.220128616033596, 6.262587324740471, 6.304760106459247, 6.3466526610489735, 6.388270501473776, 6.429618962271405, 6.470703207534712, 6.511528238439884, 6.552098900352467, 6.592419889539805, 6.632495759516172, 6.672330927044912, 6.711929677819935, 6.751296171847301, 6.790434448545985, 6.82934843158555, 6.868041933477111, 6.906518659932804, 6.944782214007867, 6.982836100038438, 7.020683727387242, 7.058328414008519, 7.095773389842717, 7.1330218000508046, 7.170076708097342, 7.206941098690901, 7.243617880589783, 7.28010988928052, 7.31641988953614], [0.0, 0.7348469228349535, 1.0392304845413265, 1.2727922061357857, 1.469693845669907, 1.6431676725154984, 1.8, 1.9442222095223582, 2.078460969082653, 2.2045407685048604, 2.32379000772445, 2.4372115213907883, 2.5455844122715714, 2.6495282598983545, 2.749545416973504, 2.846049894151541, 2.939387691339814, 3.0298514815086235, 3.1176914536239795, 3.203123475609394, 3.286335345030997, 3.3674916480965478, 3.4467375879228173, 3.5242020373412197, 3.6, 3.6742346141747677, 3.7469987990390394, 3.818376618407357, 3.8884444190447165, 3.957271787481876, 4.024922359499621, 4.091454509095757, 4.156921938165306, 4.221374183841087, 4.28485705712571, 4.347413023856832, 4.409081537009721, 4.469899327725402, 4.529900661162451, 4.589117562233507, 4.6475800154489, 4.705316142407437, 4.762352359916264, 4.818713521262703, 4.874423042781577, 4.9295030175464944, 4.983974317750845, 5.037856687124, 5.091168824543143, 5.143928459844674, 5.196152422706632, 5.247856705360771, 5.299056519796709, 5.349766350038103, 5.4, 5.449770637375486, 5.499090833947008, 5.547972602672079, 5.596427431853289, 5.644466316668034, 5.692099788303082, 5.739337940912697, 5.786190456595773, 5.8326666285670745, 5.878775382679628, 5.924525297439449, 5.96992462263972, 6.014981296729027, 6.059702963017247, 6.104096984812742, 6.148170459575759, 6.191930232165088, 6.235382907247959, 6.278534860936905, 6.321392251711643, 6.363961030678928, 6.406246951218788, 6.448255578061404, 6.489992295835182, 6.5314623171231725, 6.572670690061994, 6.613622305514581, 6.654321903845651, 6.694774081326419, 6.7349832961930955, 6.77495387438173, 6.814690014960329, 6.854195795277518, 6.8934751758456345, 6.932532004974806, 6.971370023173351, 7.009992867328754, 7.0484040746824395, 7.0866070866106305, 7.124605252222751, 7.162401831787993, 7.2, 7.237402849088892, 7.274613391789285, 7.3116345641723655, 7.348469228349535, 7.385120175054704], [0.0, 0.7416198487095663, 1.0488088481701516, 1.2845232578665131, 1.4832396974191326, 1.6583123951777001, 1.8165902124584952, 1.9621416870348585, 2.0976176963403033, 2.224859546128699, 2.345207879911715, 2.459674775249769, 2.5690465157330262, 2.673948391424188, 2.7748873851023217, 2.8722813232690143, 2.9664793948382653, 3.0577769702841313, 3.146426544510455, 3.232645975048923, 3.3166247903554003, 3.398529093593286, 3.4785054261852175, 3.5566838487557484, 3.6331804249169903, 3.708099243547832, 3.7815340802378077, 3.853569773599539, 3.924283374069717, 3.993745109543172, 4.06201920231798, 4.129164564412516, 4.1952353926806065, 4.260281680828159, 4.324349662087931, 4.387482193696061, 4.449719092257398, 4.511097427455985, 4.571651780264984, 4.631414470763765, 4.69041575982343, 4.748684028233507, 4.806245936279167, 4.863126566315131, 4.919349550499538, 4.9749371855331, 5.029910535983717, 5.084289527554465, 5.1380930314660525, 5.191338940966964, 5.244044240850759, 5.296225070746145, 5.347896782848376, 5.399073994677236, 5.449770637375486, 5.5, 5.549774770204643, 5.599107071667768, 5.648008498577176, 5.6964901474504455, 5.744562646538029, 5.792236183029832, 5.839520528262573, 5.886425061104576, 5.932958789676531, 5.979130371550699, 6.024948132556827, 6.070420084310475, 6.115553940568263, 6.1603571325045765, 6.2048368229954285, 6.248999919987198, 6.29285308902091, 6.336402764976356, 6.3796551630946325, 6.422616289332565, 6.465291950097846, 6.507687761409578, 6.549809157525127, 6.591661399070799, 6.6332495807108005, 6.674578638386097, 6.715653356152327, 6.756478372643548, 6.797058187186572, 6.837397165588672, 6.87749954561976, 6.917369442208505, 6.957010852370435, 6.996427659884722, 7.035623639735144, 7.074602462329597, 7.113367697511497, 7.15192281837549, 7.1902712048990205, 7.2284161474004796, 7.266360849833981, 7.30410843293006, 7.341661937191061, 7.379024325749307, 7.416198487095664, 7.4531872376856345], [0.0, 0.7483314773547883, 1.058300524425836, 1.2961481396815722, 1.4966629547095767, 1.6733200530681511, 1.833030277982336, 1.9798989873223332, 2.116601048851672, 2.244994432064365, 2.3664319132398464, 2.4819347291981715, 2.5922962793631443, 2.6981475126464085, 2.8, 2.8982753492378874, 2.9933259094191533, 3.0854497241083023, 3.1749015732775088, 3.2619012860600183, 3.3466401061363023, 3.4292856398964493, 3.509985754956849, 3.5888716889852725, 3.666060555964672, 3.7416573867739413, 3.8157568056677826, 3.8884444190447165, 3.9597979746446663, 4.029888335921977, 4.098780306383839, 4.166533331199932, 4.233202097703344, 4.298837052040936, 4.363484845854286, 4.427188724235731, 4.48998886412873, 4.551922670696417, 4.613025037868319, 4.673328578219169, 4.732863826479693, 4.791659420284376, 4.849742261192857, 4.907137658554118, 4.963869458396343, 5.0199601592044525, 5.075431016179809, 5.130302135352264, 5.184592558726289, 5.238320341483518, 5.291502622129181, 5.344155686354956, 5.396295025292817, 5.447935388750495, 5.499090833947008, 5.549774770204643, 5.6, 5.649778756730214, 5.6991227395100035, 5.748043145279965, 5.796550698475775, 5.844655678480983, 5.892367945062493, 5.939696961966999, 5.986651818838307, 6.033241251599342, 6.079473661428265, 6.125357132445422, 6.170899448216605, 6.216108107168021, 6.260990336999411, 6.305553108173778, 6.3498031465550175, 6.393746945258312, 6.437390775772432, 6.48074069840786, 6.523802572120037, 6.566582063752802, 6.609084656743323, 6.6513156593263565, 6.6932802122726045, 6.734983296193095, 6.776429738438967, 6.817624219623724, 6.858571279792899, 6.899275324264136, 6.939740629158989, 6.979971346646059, 7.019971509913698, 7.059745037889116, 7.099295739719539, 7.138627319029899, 7.177743377970545, 7.216647421067487, 7.255342858886822, 7.293833011524187, 7.332121111929344, 7.370210309075312, 7.408103670980854, 7.445804187594514, 7.483314773547883, 7.520638270785267], [0.0, 0.754983443527075, 1.0677078252031311, 1.3076696830622023, 1.50996688705415, 1.6881943016134133, 1.849324200890693, 1.997498435543818, 2.1354156504062622, 2.264950330581225, 2.3874672772626644, 2.503996805109783, 2.6153393661244047, 2.72213151776324, 2.824889378365107, 2.924038303442689, 3.0199337741083, 3.1128764832546763, 3.2031234756093934, 3.290896534380867, 3.3763886032268267, 3.459768778401239, 3.5411862419251547, 3.620773398046335, 3.698648401781386, 3.774917217635375, 3.849675310984032, 3.9230090491866063, 3.994996871087636, 4.065710270051224, 4.135214625627066, 4.20356991139674, 4.2708313008125245, 4.337049688440288, 4.402272140611028, 4.466542286825459, 4.52990066116245, 4.592385001282014, 4.654030511288038, 4.7148700936505135, 4.774934554525329, 4.8342527861087286, 4.892851929090027, 4.950757517794625, 5.007993610219566, 5.064582904840239, 5.120546845796843, 5.175905717843014, 5.230678732248809, 5.2848841046895245, 5.338539126015656, 5.391660226683429, 5.44426303552648, 5.496362433464519, 5.547972602672079, 5.599107071667768, 5.649778756730214, 5.7, 5.749782604586021, 5.799137866959191, 5.848076606885378, 5.8966091951222275, 5.944745579080739, 5.9924953066314535, 6.0398675482166, 6.08687111741328, 6.133514490078261, 6.17980582219215, 6.2257529665093525, 6.271363488110062, 6.316644678941503, 6.361603571427569, 6.406246951218787, 6.450581369148055, 6.494613152451807, 6.5383484153110105, 6.581793068761734, 6.624952830020755, 6.667833231267862, 6.710439627923047, 6.752777206453653, 6.794850991743675, 6.836665854054885, 6.878226515607057, 6.919537556802478, 6.960603422117942, 7.001428425685718, 7.042016756583302, 7.0823724838503095, 7.122499561249548, 7.162401831787993, 7.202083032012336, 7.24154679609267, 7.280796659706959, 7.31983606373804, 7.358668357794092, 7.397296803562772, 7.4357245780085215, 7.473954776421918, 7.5119904153293495, 7.54983443527075, 7.587489703452652], [0.0, 0.7615773105863909, 1.0770329614269007, 1.3190905958272923, 1.5231546211727818, 1.7029386365926404, 1.8654758106177631, 2.0149441679609885, 2.1540659228538015, 2.2847319317591723, 2.4083189157584592, 2.525866188063018, 2.6381811916545845, 2.7459060435491964, 2.8495613697550017, 2.9495762407505253, 3.0463092423455636, 3.1400636936215167, 3.2310988842807027, 3.319638534539567, 3.405877273185281, 3.48998567332303, 3.5721142198983507, 3.6523964735499352, 3.7309516212355263, 3.8078865529319548, 3.8832975677895205, 3.957271787481876, 4.029888335921977, 4.101219330881976, 4.171330722922842, 4.240283009422838, 4.308131845707603, 4.374928570845472, 4.440720662234904, 4.505552130427525, 4.569463863518345, 4.632493928760188, 4.694677837722201, 4.756048780237647, 4.8166378315169185, 4.876474136094644, 4.935585071701227, 4.993996395673509, 5.051732376126036, 5.10881590977792, 5.165268628057984, 5.221110992882646, 5.276362383309169, 5.331041174104736, 5.385164807134505, 5.43874985635486, 5.491812087098393, 5.5443665102516455, 5.596427431853289, 5.648008498577176, 5.6991227395100035, 5.749782604586021, 5.800000000000001, 5.849786320883866, 5.8991524815010505, 5.948108943185221, 5.99666574022598, 6.044832503882966, 6.092618484691127, 6.1400325732035, 6.187083319303208, 6.23377895020348, 6.280127387243033, 6.326136261573885, 6.3718129288295975, 6.417164482853779, 6.462197768561405, 6.5069193939989765, 6.55133574166368, 6.59545297913646, 6.639277069079134, 6.682813778641449, 6.726068688320096, 6.76904720030818, 6.811754546370562, 6.854195795277518, 6.8963758598266685, 6.938299503480662, 6.97997134664606, 7.021395872616784, 7.062577433203831, 7.103520254071217, 7.144228439796701, 7.184705978674423, 7.224956747275378, 7.264984514780469, 7.3047929470998705, 7.3443856107914165, 7.383765976789894, 7.4229374239582535, 7.4619032424710525, 7.5006666370396715, 7.539230729988306, 7.577598564189055, 7.6157731058639095, 7.653757247260983], [0.0, 0.7681145747868608, 1.0862780491200215, 1.3304134695650072, 1.5362291495737217, 1.7175564037317668, 1.8814887722226779, 2.0322401432901573, 2.172556098240043, 2.3043437243605824, 2.4289915602982237, 2.5475478405713994, 2.6608269391300143, 2.7694764848252458, 2.8740215726399825, 2.974894956128703, 3.0724582991474434, 3.167017524422623, 3.2588341473600644, 3.3481338085566414, 3.4351128074635335, 3.5199431813596083, 3.602776706930364, 3.6837480912787726, 3.7629775444453557, 3.840572873934304, 3.916631205513228, 3.9912404086950213, 4.064480286580315, 4.136423575989287, 4.207136793592525, 4.276680956068619, 4.345112196480086, 4.412482294582042, 4.4788391353117385, 4.544227107000705, 4.608687448721165, 4.672258554489466, 4.734976240700686, 4.796873982084583, 4.857983120596447, 4.9183330509431755, 4.9779513858614575, 5.03686410378521, 5.095095681142799, 5.1526692111953, 5.209606511052442, 5.265928218272634, 5.321653878260029, 5.376802023508025, 5.431390245600108, 5.485435260760991, 5.5389529696504916, 5.591958512006326, 5.644466316668034, 5.6964901474504455, 5.748043145279965, 5.799137866959191, 5.849786320883866, 5.8999999999999995, 5.949789912257406, 5.999166608788257, 6.048140210014975, 6.096720429870472, 6.144916598294887, 6.192737682156413, 6.240192304729077, 6.287288763847259, 6.334035048845246, 6.380438856379708, 6.4265076052238514, 6.472248450113762, 6.517668294720129, 6.562773803811921, 6.607571414672716, 6.652067347825035, 6.696267617113283, 6.740178039191546, 6.783804242458652, 6.827151675479314, 6.870225614927067, 6.913031173081747, 6.955573304911681, 6.997856814768361, 7.0398863627192165, 7.0816664705420855, 7.123201527403251, 7.164495795239188, 7.205553413860728, 7.246378405796926, 7.286974680894671, 7.327346040688948, 7.367496182557545, 7.407428703673091, 7.447147104764348, 7.486654793697916, 7.525955088890711, 7.565051222562872, 7.603946343840151, 7.642643521714199, 7.681145747868608, 7.719455939378112], [0.0, 0.7745966692414833, 1.0954451150103321, 1.3416407864998738, 1.5491933384829666, 1.7320508075688772, 1.8973665961010275, 2.0493901531919194, 2.1908902300206643, 2.3237900077244498, 2.449489742783178, 2.569046515733026, 2.6832815729997477, 2.792848008753788, 2.8982753492378874, 2.9999999999999996, 3.098386676965933, 3.1937438845342623, 3.2863353450309964, 3.3763886032268267, 3.4641016151377544, 3.5496478698597693, 3.63318042491699, 3.714835124201342, 3.794733192202055, 3.8729833462074166, 3.9496835316262997, 4.024922359499621, 4.098780306383839, 4.171330722922842, 4.242640687119285, 4.3127717305695645, 4.381780460041329, 4.449719092257398, 4.516635916254486, 4.58257569495584, 4.6475800154488995, 4.711687595755898, 4.774934554525329, 4.8373546489791295, 4.898979485566356, 4.959838707054898, 5.019960159204453, 5.079370039680117, 5.138093031466052, 5.196152422706631, 5.253570214625478, 5.310367218940701, 5.366563145999495, 5.422176684690383, 5.477225575051661, 5.531726674375732, 5.585696017507576, 5.639148871948674, 5.692099788303082, 5.744562646538029, 5.796550698475775, 5.848076606885378, 5.8991524815010505, 5.949789912257406, 5.999999999999999, 6.049793384901669, 6.099180272790762, 6.148170459575758, 6.196773353931866, 6.244997998398397, 6.292853089020909, 6.340346993658943, 6.387487769068525, 6.434283176858164, 6.48074069840786, 6.526867548832287, 6.572670690061993, 6.618156843109718, 6.663332499583071, 6.7082039324993685, 6.752777206453653, 6.797058187186571, 6.841052550594828, 6.884765791223402, 6.928203230275509, 6.97137002317335, 7.014271166700073, 7.056911505750939, 7.099295739719539, 7.1414284285428495, 7.183313998427188, 7.224956747275377, 7.26636084983398, 7.307530362578043, 7.348469228349534, 7.389181280764466, 7.429670248402684, 7.469939758793239, 7.5099933422074345, 7.549834435270749, 7.58946638440411, 7.628892449104261, 7.668115805072325, 7.707139547199078, 7.745966692414833, 7.784600182411426], [0.0, 0.7810249675906654, 1.104536101718726, 1.3527749258468684, 1.5620499351813308, 1.746424919657298, 1.9131126469708992, 2.0663978319771825, 2.209072203437452, 2.3430749027719964, 2.4698178070456938, 2.5903667693977237, 2.705549851693737, 2.816025568065745, 2.9223278392404914, 3.0248966924508345, 3.1240998703626617, 3.2202484376209237, 3.3136083051561784, 3.4044089061098406, 3.492849839314596, 3.5791060336346563, 3.6633318168028404, 3.745664160065609, 3.8262252939417984, 3.9051248379533274, 3.9824615503479754, 4.058324777540605, 4.132795663954365, 4.205948168962618, 4.277849927241487, 4.34856298103178, 4.418144406874904, 4.486646854834912, 4.5541190146942805, 4.620606020859168, 4.686149805543993, 4.750789408087881, 4.814561246884289, 4.87749935930288, 4.9396356140913875, 5.000999900019996, 5.061620293937506, 5.121523210920751, 5.180733538795447, 5.239274758971893, 5.297169055259611, 5.354437412091022, 5.411099703387474, 5.467174773134658, 5.522680508593631, 5.577633906953737, 5.63205113613149, 5.6859475903318, 5.739337940912697, 5.792236183029832, 5.844655678480983, 5.8966091951222275, 5.948108943185221, 5.999166608788257, 6.049793384901669, 6.1, 6.149796744608719, 6.199193495931548, 6.248199740725323, 6.296824596572465, 6.345076831686122, 6.392964883369843, 6.440496875241847, 6.487680633323437, 6.534523701081817, 6.5810333535091585, 6.627216610312357, 6.673080248281149, 6.71863081289633, 6.7638746292343415, 6.808817812219681, 6.853466276272176, 6.897825744392215, 6.941901756723442, 6.985699678629192, 7.029224708315989, 7.07248188403477, 7.115476090888086, 7.158212067269313, 7.200694410957877, 7.242927584892728, 7.284915922644544, 7.326663633605681, 7.368174807915458, 7.409453421137082, 7.450503338701353, 7.491328320131218, 7.531932023060219, 7.572318007057021, 7.6124897372673015, 7.652450587883597, 7.692203845452876, 7.731752712031082, 7.771100308193172, 7.810249675906655, 7.849203781276163], [0.0, 0.787400787401181, 1.1135528725660042, 1.3638181696985856, 1.574801574802362, 1.760681686165901, 1.928730152198591, 2.083266665599966, 2.2271057451320084, 2.362202362203543, 2.4899799195977463, 2.6115129714401193, 2.727636339397171, 2.839013913315678, 2.9461839725312466, 3.049590136395381, 3.149603149604724, 3.246536616149585, 3.340658617698013, 3.432200460346103, 3.521363372331802, 3.608323710533743, 3.6932370625238775, 3.7762415176998414, 3.857460304397182, 3.9370039370059056, 4.014971979976946, 4.091454509095756, 4.166533331199932, 4.240283009422838, 4.3127717305695645, 4.384062043356595, 4.454211490264017, 4.523273151159457, 4.591296113299598, 4.658325879540846, 4.724404724407086, 4.789572005931219, 4.853864439804639, 4.917316341257699, 4.979959839195493, 5.041825066382213, 5.10294032886923, 5.163332257370234, 5.223025942880239, 5.282045058497702, 5.340411969127476, 5.3981478305063115, 5.455272678794342, 5.511805511808268, 5.5677643628300215, 5.62316636780382, 5.678027826631356, 5.732364259186606, 5.786190456595773, 5.839520528262573, 5.892367945062493, 5.944745579080739, 5.99666574022598, 6.048140210014975, 6.099180272790762, 6.149796744608719, 6.199999999999999, 6.249799996799897, 6.299206299209448, 6.348228099241551, 6.39687423668779, 6.445153217728807, 6.49307323229917, 6.540642170307133, 6.587867636800241, 6.6347569661593475, 6.681317235396026, 6.727555276621664, 6.773477688750439, 6.819090848492928, 6.864400920692206, 6.90941386804988, 6.954135460285484, 6.998571282769077, 7.042726744663604, 7.08660708661063, 7.130217387990355, 7.173562573784381, 7.216647421067486, 7.259476565152615, 7.302054505411474, 7.344385610791416, 7.386474125047755, 7.428324171709255, 7.469939758793239, 7.511324783285569, 7.552483035399683, 7.593418202627852, 7.634133873596926, 7.674633541739956, 7.714920608794364, 7.754998388136519, 7.79487010796203, 7.834538914320357, 7.874007874011811, 7.913279977354524], [0.0, 0.7937253933193772, 1.1224972160321824, 1.3747727084867523, 1.5874507866387544, 1.7748239349298849, 1.9442222095223582, 2.1, 2.244994432064365, 2.3811761799581315, 2.5099800796022267, 2.632489316217637, 2.7495454169735045, 2.861817604250837, 2.9698484809834995, 3.074085229787879, 3.1749015732775088, 3.2726136343907144, 3.3674916480965473, 3.4597687784012394, 3.5496478698597698, 3.6373066958946425, 3.722902093797257, 3.8065732621348563, 3.8884444190447165, 3.968626966596886, 4.047221268969613, 4.124318125460256, 4.2, 4.274342054632503, 4.347413023856832, 4.419275958796871, 4.48998886412873, 4.559605246071199, 4.628174586162454, 4.695742752749559, 4.762352359916263, 4.828043081829325, 4.892851929090027, 4.956813492557492, 5.019960159204453, 5.082322303829225, 5.143928459844674, 5.204805471869242, 5.264978632435274, 5.324471804789654, 5.383307533477908, 5.441507144165117, 5.499090833947009, 5.55607775323564, 5.612486080160912, 5.668333088307356, 5.723635208501674, 5.7784080852774675, 5.8326666285670745, 5.886425061104576, 5.939696961966999, 5.9924953066314535, 6.044832503882966, 6.096720429870472, 6.148170459575758, 6.199193495931548, 6.249799996799897, 6.3, 6.3498031465550175, 6.3992187023104625, 6.448255578061403, 6.496922348312315, 6.545227268781429, 6.593178292750774, 6.640783086353597, 6.688049042882386, 6.734983296193095, 6.7815927332743895, 6.827884006044625, 6.87386354243376, 6.919537556802479, 6.96491205974634, 7.009992867328754, 7.0547856097829085, 7.0992957397195395, 7.143528539874395, 7.187489130426565, 7.23118247591637, 7.274613391789285, 7.317786550590281, 7.3607064878311785, 7.40337760755184, 7.445804187594514, 7.487990384609211, 7.52994023880668, 7.571657678474378, 7.6131465242697125, 7.654410493303845, 7.695453203028396, 7.736278174936576, 7.776888838089433, 7.817288532477231, 7.857480512225277, 7.897467948652911, 7.937253933193772, 7.976841480185], [0.0, 0.8, 1.131370849898476, 1.385640646055102, 1.6, 1.788854381999832, 1.9595917942265426, 2.1166010488516727, 2.262741699796952, 2.4, 2.5298221281347035, 2.65329983228432, 2.771281292110204, 2.8844410203711917, 2.9933259094191533, 3.098386676965933, 3.2, 3.2984845004941286, 3.394112549695428, 3.4871191548325395, 3.577708763999664, 3.6660605559646724, 3.752332607858744, 3.836665218650176, 3.9191835884530852, 4.0, 4.079215610874228, 4.156921938165306, 4.233202097703345, 4.308131845707604, 4.381780460041329, 4.454211490264018, 4.525483399593904, 4.595650117230424, 4.664761515876241, 4.732863826479693, 4.8, 4.866210024238576, 4.931531202375181, 4.9959983987187195, 5.059644256269407, 5.122499389946279, 5.184592558726289, 5.2459508194416005, 5.30659966456864, 5.366563145999495, 5.4258639865002145, 5.4845236803208355, 5.542562584220408, 5.6000000000000005, 5.656854249492381, 5.713142742834281, 5.768882040742383, 5.8240879114244155, 5.878775382679628, 5.932958789676531, 5.986651818838307, 6.0398675482166, 6.092618484691127, 6.144916598294887, 6.196773353931866, 6.248199740725323, 6.299206299209448, 6.3498031465550175, 6.4, 6.449806198638839, 6.499230723708768, 6.5482822174979605, 6.596969000988257, 6.64529909033446, 6.6932802122726045, 6.740919818541087, 6.788225099390856, 6.835202996254025, 6.881860213634101, 6.92820323027551, 6.974238309665079, 7.019971509913698, 7.065408693062278, 7.110555533852471, 7.155417527999328, 7.2, 7.244308110509934, 7.288346863315439, 7.332121111929345, 7.37563556583431, 7.418894796396564, 7.4619032424710525, 7.504665215717488, 7.547184905645283, 7.58946638440411, 7.631513611335565, 7.673330437300352, 7.7149206087943645, 7.756287771866127, 7.797435475847171, 7.8383671769061705, 7.879086241436885, 7.919595949289333, 7.959899496852961, 8.0, 8.039900496896713], [0.0, 0.8062257748298549, 1.1401754250991378, 1.3964240043768943, 1.6124515496597098, 1.8027756377319946, 1.9748417658131499, 2.133072900770154, 2.2803508501982757, 2.4186773244895647, 2.5495097567963922, 2.6739483914241875, 2.7928480087537886, 2.9068883707497264, 3.016620625799671, 3.1224989991991987, 3.2249030993194197, 3.324154027718932, 3.420526275297414, 3.5142566781611158, 3.605551275463989, 3.6945906403822333, 3.7815340802378072, 3.866522985836241, 3.9496835316262997, 4.031128874149275, 4.110960958218893, 4.189272013130682, 4.266145801540308, 4.341658669218482, 4.415880433163923, 4.488875137492688, 4.560701700396551, 4.631414470763764, 4.701063709417263, 4.769696007084728, 4.8373546489791295, 4.904079934095691, 4.969909455915671, 5.034878350069642, 5.0990195135927845, 5.162363799656123, 5.224940191045253, 5.28677595515452, 5.347896782848375, 5.4083269131959835, 5.468089245796926, 5.527205442174191, 5.585696017507577, 5.643580423808984, 5.70087712549569, 5.757603668193913, 5.813776741499453, 5.869412236331676, 5.924525297439449, 5.979130371550699, 6.033241251599342, 6.08687111741328, 6.1400325732035, 6.192737682156413, 6.244997998398397, 6.296824596572465, 6.348228099241551, 6.3992187023104625, 6.449806198638839, 6.499999999999999, 6.549809157525125, 6.599242380758566, 6.648308055437864, 6.697014260101287, 6.745368781616021, 6.793379129711516, 6.841052550594828, 6.888396039717809, 6.93541635375988, 6.98212002188447, 7.0285133563222315, 7.074602462329597, 7.12039324756716, 7.165891430938652, 7.211102550927978, 7.256031973468694, 7.300684899377592, 7.345066371381541, 7.389181280764467, 7.433034373659253, 7.476630257007497, 7.519973404208288, 7.5630681604756145, 7.6059187479225665, 7.648529270389177, 7.6909037180295, 7.733045971672482, 7.774959806970066, 7.816648898345122, 7.858116822750854, 7.899367063252599, 7.940403012442127, 7.981227975693965, 8.021845174272563, 8.06225774829855, 8.10246875958186], [0.0, 0.812403840463596, 1.1489125293076057, 1.4071247279470291, 1.624807680927192, 1.8165902124584952, 1.98997487421324, 2.149418526020468, 2.2978250586152114, 2.437211521390788, 2.569046515733026, 2.6944387170614963, 2.8142494558940583, 2.9291637031753623, 3.0397368307141326, 3.1464265445104544, 3.249615361854384, 3.3496268448888453, 3.4467375879228173, 3.541186241925155, 3.6331804249169903, 3.722902093797257, 3.81051177665153, 3.8961519477556315, 3.97994974842648, 4.06201920231798, 4.142463035441596, 4.221374183841087, 4.298837052040936, 4.374928570845472, 4.449719092257397, 4.523273151159456, 4.595650117230423, 4.666904755831214, 4.737087712930805, 4.806245936279166, 4.874423042781576, 4.941659640242335, 5.007993610219566, 5.073460357586329, 5.138093031466052, 5.201922721455982, 5.264978632435274, 5.3272882407468805, 5.388877434122993, 5.449770637375485, 5.509990925582365, 5.569560126257728, 5.628498911788117, 5.686826883245172, 5.744562646538029, 5.801723881744115, 5.858327406350725, 5.914389233048499, 5.96992462263972, 6.024948132556827, 6.079473661428265, 6.133514490078261, 6.187083319303208, 6.240192304729077, 6.292853089020909, 6.345076831686122, 6.39687423668779, 6.448255578061403, 6.499230723708768, 6.549809157525125, 6.6, 6.649812027418519, 6.699253689777691, 6.748333127521196, 6.797058187186572, 6.8454364360499325, 6.8934751758456345, 6.941181455631311, 6.988562083862459, 7.035623639735144, 7.08237248385031, 7.128814768248646, 7.17495644586084, 7.2208032794142785, 7.266360849833981, 7.311634564172365, 7.356629663099809, 7.401351227985333, 7.445804187594514, 7.489993324429602, 7.533923280734945, 7.577598564189054, 7.62102355330306, 7.664202502543888, 7.707139547199077, 7.749838707999025, 7.792303895511263, 7.834538914320357, 7.8765474670060875, 7.918333157931661, 7.95989949685296, 8.001249902359007, 8.04238770515324, 8.083316151184489, 8.12403840463596, 8.16455755078008], [0.0, 0.8185352771872451, 1.1575836902790224, 1.4177446878757827, 1.6370705543744901, 1.8303005217723127, 2.004993765576342, 2.1656407827707715, 2.315167380558045, 2.455605831561735, 2.588435821108957, 2.714774392099646, 2.8354893757515653, 2.951270912674741, 3.062678566222711, 3.1701734968294715, 3.2741411087489802, 3.374907406137241, 3.4727510708370675, 3.567912554982255, 3.6606010435446255, 3.7509998667022106, 3.8392707640904935, 3.9255572852781047, 4.009987531152684, 4.092676385936225, 4.173727350941841, 4.253234063627348, 4.331281565541543, 4.407947368106838, 4.483302354291978, 4.557411546042337, 4.63033476111609, 4.702127178203499, 4.77283982551269, 4.8425200051213, 4.91121166312347, 4.978955713801841, 5.045790324617146, 5.111751167652823, 5.176871642217914, 5.241183072551464, 5.304714883949938, 5.367494760127856, 5.429548784199292, 5.490901565316937, 5.551576352712804, 5.61159513863928, 5.670978751503131, 5.729746940310715, 5.787918451395113, 5.845511098270194, 5.902541825349482, 5.959026766175833, 6.014981296729027, 6.070420084310475, 6.125357132445422, 6.17980582219215, 6.23377895020348, 6.287288763847259, 6.340346993658943, 6.392964883369843, 6.445153217728807, 6.496922348312315, 6.5482822174979605, 6.599242380758566, 6.649812027418519, 6.7, 6.749814812274482, 6.79926466612383, 6.848357467305573, 6.897100840208152, 6.945502141674135, 6.993568473962345, 7.041306696913577, 7.088723439378913, 7.13582510996451, 7.182617907142214, 7.229107828771128, 7.275300681071539, 7.321202087089251, 7.366817494685205, 7.4121521840825695, 7.457211275000863, 7.501999733404421, 7.546522377890362, 7.590783885739338, 7.634788798650556, 7.678541528180987, 7.722046360907191, 7.76530746332687, 7.808328886515987, 7.851114570556209, 7.893668348746355, 7.935993951610599, 7.978095010715276, 8.019975062305368, 8.061637550770936, 8.103085831953157, 8.144323176298936, 8.18535277187245, 8.226177727231525], [0.0, 0.8246211251235321, 1.16619037896906, 1.4282856857085702, 1.6492422502470643, 1.8439088914585775, 2.0199009876724157, 2.181742422927143, 2.33238075793812, 2.473863375370596, 2.6076809620810595, 2.734958866235469, 2.8565713714171403, 2.973213749463701, 3.0854497241083023, 3.1937438845342623, 3.2984845004941286, 3.4, 3.4985711369071804, 3.594440151122286, 3.687817782917155, 3.778888725538237, 3.867815921162743, 3.954743986657038, 4.039801975344831, 4.123105625617661, 4.204759208325728, 4.28485705712571, 4.363484845854286, 4.440720662234904, 4.516635916254486, 4.591296113299599, 4.66476151587624, 4.737087712930805, 4.8083261120685235, 4.878524367060187, 4.947726750741192, 5.015974481593781, 5.083306010855534, 5.149757275833494, 5.215361924162119, 5.280151512977635, 5.344155686354956, 5.407402333838309, 5.469917732470938, 5.531726674375732, 5.592852581643825, 5.653317610041028, 5.713142742834281, 5.772347875864725, 5.830951894845301, 5.888972745734184, 5.946427498927402, 6.003332407921454, 6.059702963017247, 6.115553940568263, 6.170899448216605, 6.2257529665093525, 6.280127387243033, 6.334035048845246, 6.387487769068525, 6.440496875241847, 6.49307323229917, 6.545227268781429, 6.596969000988257, 6.648308055437864, 6.699253689777691, 6.749814812274482, 6.8, 6.849817515817484, 6.899275324264137, 6.948381106416083, 6.997142273814361, 7.045565981523414, 7.093659140387279, 7.14142842854285, 7.188880302244572, 7.236021006050217, 7.282856582413251, 7.329392880723478, 7.37563556583431, 7.42159012611179, 7.467261881037788, 7.512655988397179, 7.557777451076474, 7.602631123499285, 7.647221717722065, 7.691553809211764, 7.735631842325486, 7.779460135510689, 7.8230428862431785, 7.866384175718855, 7.909487973314076, 7.952358140828418, 7.994998436522675, 8.037412518964047, 8.079603950689663, 8.121576201698781, 8.16333265278342, 8.204876598706406, 8.246211251235321, 8.287339742040265], [0.0, 0.8306623862918076, 1.174734012447073, 1.4387494569938162, 1.661324772583615, 1.8574175621006712, 2.0346989949375804, 2.1977260975835913, 2.349468024894146, 2.4919871588754225, 2.6267851073127395, 2.7549954627911823, 2.8774989139876324, 2.994995826374388, 3.1080540535840107, 3.217141588429082, 3.32264954516723, 3.424908757908742, 3.5242020373412193, 3.6207733980463352, 3.7148351242013424, 3.8065732621348563, 3.8961519477556315, 3.9837168574084183, 4.069397989875161, 4.153311931459037, 4.235563716909475, 4.316248370981448, 4.3954521951671826, 4.473253849269009, 4.54972526643093, 4.624932431938872, 4.698936049788292, 4.77179211617606, 4.843552415324934, 4.914264950122246, 4.983974317750845, 5.052722038663912, 5.120546845796843, 5.187484939737176, 5.253570214625479, 5.3188344587888805, 5.383307533477909, 5.447017532558529, 5.509990925582365, 5.572252686302012, 5.63382640840131, 5.69473440996154, 5.754997827975265, 5.814636704042653, 5.873670062235366, 5.932115979985557, 5.989991652748776, 6.047313453096343, 6.104096984812742, 6.1603571325045765, 6.216108107168021, 6.271363488110062, 6.326136261573885, 6.380438856379708, 6.434283176858164, 6.487680633323437, 6.540642170307133, 6.593178292750774, 6.64529909033446, 6.697014260101287, 6.748333127521196, 6.79926466612383, 6.849817515817484, 6.9, 6.949820141557622, 6.999285677838847, 7.048404074682439, 7.097182539571601, 7.145628033979938, 7.19374728496908, 7.2415467960926705, 7.289032857656769, 7.336211556382492, 7.383088784512889, 7.429670248402685, 7.475961476626268, 7.521967827636597, 7.567694497005016, 7.6131465242697125, 7.658328799418317, 7.703246069028303, 7.747902942086975, 7.792303895511263, 7.836453279386026, 7.880355321938218, 7.924014134263013, 7.967433714816837, 8.010617953691215, 8.053570636680355, 8.096295449154509, 8.138795979750322, 8.18107572388864, 8.223138087129511, 8.264986388373547, 8.306623862918075, 8.34805366537614], [0.0, 0.8366600265340756, 1.1832159566199232, 1.4491376746189442, 1.6733200530681511, 1.8708286933869709, 2.04939015319192, 2.2135943621178655, 2.3664319132398464, 2.5099800796022267, 2.6457513110645907, 2.774887385102322, 2.8982753492378883, 3.0166206257996717, 3.1304951684997055, 3.24037034920393, 3.3466401061363023, 3.4496376621320683, 3.5496478698597698, 3.6469165057620945, 3.7416573867739418, 3.834057902536163, 3.924283374069717, 4.012480529547776, 4.09878030638384, 4.183300132670378, 4.266145801540309, 4.3474130238568325, 4.427188724235731, 4.505552130427525, 4.58257569495584, 4.658325879540847, 4.732863826479693, 4.806245936279167, 4.878524367060187, 4.949747468305833, 5.019960159204453, 5.089204259999789, 5.157518783291051, 5.2249401910452535, 5.291502622129181, 5.35723809439155, 5.422176684690385, 5.486346689738081, 5.549774770204644, 5.612486080160912, 5.674504383644443, 5.735852159879995, 5.796550698475777, 5.856620185738529, 5.916079783099617, 5.974947698515863, 6.033241251599343, 6.090976933136425, 6.148170459575759, 6.2048368229954285, 6.260990336999411, 6.316644678941503, 6.3718129288295975, 6.4265076052238514, 6.48074069840786, 6.534523701081817, 6.587867636800241, 6.640783086353597, 6.6932802122726045, 6.745368781616021, 6.797058187186572, 6.848357467305573, 6.899275324264137, 6.949820141557622, 7.000000000000001, 7.049822692805827, 7.0992957397195395, 7.148426400264607, 7.197221686178633, 7.24568837309472, 7.293833011524189, 7.341661937191062, 7.3891812807644675, 7.436396977031284, 7.4833147735478835, 7.529940238806681, 7.576278769950325, 7.622335600063802, 7.668115805072326, 7.713624310270757, 7.75886589650833, 7.803845206050669, 7.848566748139434, 7.893034904268446, 7.937253933193772, 7.981227975693966, 8.024961059095553, 8.068457101577724, 8.1117199162693, 8.154753215150045, 8.19756061276768, 8.240145629781066, 8.282511696339462, 8.324662155306966, 8.366600265340756, 8.408329203831164], [0.0, 0.8426149773176359, 1.1916375287812984, 1.4594519519326425, 1.6852299546352718, 1.8841443681416774, 2.0639767440550294, 2.2293496809607953, 2.3832750575625967, 2.5278449319529073, 2.6645825188948455, 2.7946377224964243, 2.918903903865285, 3.0380915061926625, 3.152776554086889, 3.2634337744161437, 3.3704599092705436, 3.4741905532080417, 3.5749125863438955, 3.672873534441392, 3.768288736283355, 3.861346915261565, 3.952214569073901, 4.041039470235351, 4.127953488110059, 4.2130748865881795, 4.296510211788167, 4.378355855797928, 4.458699361921591, 4.537620521815371, 4.61519230368573, 4.69148164229596, 4.766550115125193, 4.8404545241123795, 4.913247398615299, 4.984977432245807, 5.0556898639058145, 5.1254268114957995, 5.194227565288221, 5.262128846769148, 5.329165037789691, 5.395368384086485, 5.46076917659042, 5.525395913416522, 5.589275444992849, 5.652433104425031, 5.71489282489182, 5.776677245614472, 5.83780780773057, 5.898304841223451, 5.958187643906493, 6.017474553332154, 6.076183012385325, 6.134329629226001, 6.191930232165088, 6.248999919987198, 6.305553108173778, 6.361603571427569, 6.417164482853779, 6.472248450113762, 6.526867548832287, 6.5810333535091585, 6.6347569661593475, 6.688049042882386, 6.740919818541087, 6.793379129711516, 6.8454364360499325, 6.897100840208152, 6.948381106416083, 6.999285677838847, 7.049822692805827, 7.1, 7.149825172687791, 7.199305522062527, 7.248448109768049, 7.297259759663212, 7.345747068882784, 7.3939164182454755, 7.441773982055624, 7.489325737341113, 7.53657747256671, 7.583534795858723, 7.630203142774117, 7.676587783644501, 7.72269383052313, 7.768526243760782, 7.814089838234521, 7.859389289251424, 7.904429138147802, 7.949213797602879, 7.993747556684537, 8.038034585643434, 8.082078940470701, 8.125884567233282, 8.16945530620004, 8.212794895770866, 8.255906976220118, 8.298795093265047, 8.341462701469089, 8.383913167489272, 8.426149773176359, 8.468175718535841], [0.0, 0.848528137423857, 1.2, 1.4696938456699071, 1.697056274847714, 1.8973665961010278, 2.078460969082653, 2.244994432064365, 2.4, 2.545584412271571, 2.6832815729997477, 2.814249455894058, 2.9393876913398143, 3.0594117081556713, 3.1749015732775088, 3.2863353450309964, 3.394112549695428, 3.4985711369071804, 3.6, 3.6986484017813863, 3.7947331922020555, 3.8884444190447165, 3.97994974842648, 4.069397989875161, 4.156921938165306, 4.242640687119286, 4.3266615305567875, 4.409081537009721, 4.48998886412873, 4.5694638635183455, 4.6475800154489, 4.724404724407087, 4.8, 4.874423042781577, 4.947726750741193, 5.019960159204453, 5.091168824543142, 5.1613951602255765, 5.230678732248808, 5.299056519796709, 5.366563145999495, 5.43323108288245, 5.499090833947008, 5.564171097297422, 5.628498911788116, 5.692099788303082, 5.754997827975264, 5.817215828899595, 5.8787753826796285, 5.939696961966999, 6.0, 6.059702963017248, 6.118823416311343, 6.177378084592201, 6.235382907247959, 6.29285308902091, 6.3498031465550175, 6.406246951218787, 6.462197768561405, 6.517668294720129, 6.572670690061993, 6.627216610312357, 6.681317235396026, 6.734983296193095, 6.788225099390856, 6.841052550594828, 6.8934751758456345, 6.945502141674135, 6.997142273814361, 7.048404074682439, 7.0992957397195395, 7.149825172687791, 7.2, 7.249827584156743, 7.299315036357863, 7.3484692283495345, 7.397296803562773, 7.445804187594514, 7.493997598078079, 7.541883053985921, 7.589466384404111, 7.636753236814713, 7.68374908491942, 7.730459236035075, 7.776888838089433, 7.823042886243179, 7.868926229162401, 7.914543574963752, 7.95989949685296, 8.0049984384758, 8.049844718999243, 8.094442537939225, 8.138795979750322, 8.182909018191515, 8.226785520481254, 8.270429251254132, 8.313843876330612, 8.357032966310472, 8.4, 8.442748367682174, 8.485281374238571, 8.527602242131138], [0.0, 0.8544003745317531, 1.2083045973594573, 1.4798648586948744, 1.7088007490635062, 1.91049731745428, 2.092844953645635, 2.260530911091463, 2.4166091947189146, 2.563201123595259, 2.701851217221259, 2.833725463060951, 2.9597297173897488, 3.0805843601498726, 3.196873472629156, 3.309078421554859, 3.4176014981270124, 3.522782990761707, 3.6249137920783716, 3.7242448899072147, 3.82099463490856, 3.915354390090379, 4.007492981902776, 4.097560249709576, 4.18568990729127, 4.272001872658766, 4.356604182158393, 4.439594576084623, 4.521061822182926, 4.601086828130937, 4.679743582719036, 4.757099956906519, 4.833218389437829, 4.908156476723211, 4.98196748283246, 5.054700782440045, 5.126402247190518, 5.197114584074513, 5.266877632905477, 5.335728628781641, 5.403702434442518, 5.470831746635972, 5.537147279962851, 5.602677931132575, 5.667450926121902, 5.731491952362839, 5.794825277780168, 5.857473858242988, 5.9194594347794975, 5.980802621722272, 6.041522986797286, 6.101639124038721, 6.161168720299745, 6.220128616033596, 6.278534860936905, 6.336402764976356, 6.393746945258312, 6.450581369148055, 6.5069193939989765, 6.562773803811921, 6.618156843109718, 6.673080248281149, 6.727555276621664, 6.7815927332743895, 6.835202996254025, 6.888396039717809, 6.941181455631311, 6.993568473962345, 7.045565981523414, 7.097182539571601, 7.148426400264607, 7.199305522062527, 7.249827584156743, 7.3, 7.349829930005183, 7.399324293474371, 7.448489779814429, 7.4973328590906245, 7.545859791965394, 7.594076639065476, 7.64198926981712, 7.689603370785778, 7.736924453553881, 7.783957862167549, 7.830708780180758, 7.877182237323192, 7.923383115816122, 7.969316156358713, 8.014985963805552, 8.060397012554654, 8.105553651663778, 8.150460109711599, 8.195120499419152, 8.239538822045807, 8.283718971573094, 8.327664738688751, 8.37137981458254, 8.414867794564572, 8.4581321815162, 8.501176389182852, 8.544003745317532, 8.586617494683225], [0.0, 0.8602325267042626, 1.2165525060596438, 1.489966442575134, 1.7204650534085253, 1.9235384061671346, 2.1071307505705477, 2.2759613353482084, 2.4331050121192876, 2.580697580112788, 2.7202941017470885, 2.8530685235374214, 2.979932885150268, 3.1016124838541645, 3.218695387886216, 3.3316662497915357, 3.4409301068170506, 3.5468295701936396, 3.6496575181789317, 3.749666651850535, 3.847076812334269, 3.9420806688854046, 4.034848200366403, 4.125530268947254, 4.214261501141095, 4.301162633521313, 4.386342439892262, 4.469899327725402, 4.551922670696417, 4.632493928760188, 4.711687595755898, 4.789572005931219, 4.866210024238575, 4.941659640242335, 5.015974481593781, 5.089204259999788, 5.161395160225576, 5.232590180780452, 5.302829433425141, 5.372150407425317, 5.440588203494177, 5.508175741568165, 5.574943945906542, 5.6409219104681805, 5.706137047074843, 5.770615218501403, 5.834380858325929, 5.897457079114692, 5.959865770300536, 6.021627686929839, 6.082762530298219, 6.143289021363068, 6.203224967708329, 6.262587324740471, 6.321392251711643, 6.3796551630946325, 6.437390775772432, 6.494613152451807, 6.55133574166368, 6.607571414672716, 6.663332499583071, 6.71863081289633, 6.773477688750439, 6.827884006044625, 6.881860213634101, 6.93541635375988, 6.988562083862459, 7.041306696913577, 7.093659140387279, 7.145628033979938, 7.197221686178633, 7.248448109768049, 7.299315036357863, 7.349829930005183, 7.3999999999999995, 7.44983221287567, 7.49933330370107, 7.548509786706248, 7.597367965289032, 7.645913941446111, 7.694153624668538, 7.742092740338364, 7.789736837660179, 7.837091297158659, 7.884161337770809, 7.930952023559341, 7.977468270071652, 8.023714850367003, 8.069696400732806, 8.115417426109392, 8.160882305241266, 8.206095295571457, 8.251060537894508, 8.295782060782456, 8.340263784797218, 8.384509526501832, 8.42852300228219, 8.472307831990054, 8.515867542417507, 8.559205570612264, 8.602325267042627, 8.645229898620395], [0.0, 0.8660254037844387, 1.224744871391589, 1.5000000000000002, 1.7320508075688774, 1.9364916731037085, 2.121320343559643, 2.29128784747792, 2.449489742783178, 2.598076211353316, 2.7386127875258306, 2.8722813232690148, 3.0000000000000004, 3.122498999199199, 3.24037034920393, 3.3541019662496843, 3.464101615137755, 3.570714214271425, 3.6742346141747673, 3.7749172176353754, 3.872983346207417, 3.968626966596886, 4.06201920231798, 4.153311931459037, 4.242640687119286, 4.330127018922194, 4.415880433163924, 4.5, 4.58257569495584, 4.663689526544408, 4.743416490252569, 4.8218253804964775, 4.898979485566356, 4.974937185533101, 5.049752469181039, 5.123475382979799, 5.196152422706632, 5.26782687642637, 5.338539126015656, 5.408326913195984, 5.477225575051661, 5.545268253204709, 5.612486080160912, 5.678908345800274, 5.7445626465380295, 5.809475019311125, 5.873670062235366, 5.937171043518958, 6.000000000000001, 6.06217782649107, 6.123724356957946, 6.184658438426491, 6.244997998398398, 6.304760106459247, 6.363961030678928, 6.422616289332565, 6.48074069840786, 6.5383484153110105, 6.59545297913646, 6.652067347825035, 6.7082039324993685, 6.7638746292343415, 6.819090848492928, 6.87386354243376, 6.92820323027551, 6.98212002188447, 7.035623639735144, 7.088723439378913, 7.14142842854285, 7.19374728496908, 7.24568837309472, 7.297259759663212, 7.3484692283495345, 7.399324293474371, 7.44983221287567, 7.5, 7.549834435270751, 7.599342076785332, 7.6485292703891785, 7.697402159170327, 7.745966692414834, 7.794228634059948, 7.842193570679062, 7.88986691902975, 7.937253933193772, 7.984359711335657, 8.031189202104505, 8.077747210701757, 8.12403840463596, 8.170067319184096, 8.215838362577491, 8.261355820929154, 8.306623862918075, 8.351646544245034, 8.396427811873334, 8.440971508067065, 8.485281374238571, 8.529361054615991, 8.573214099741124, 8.616843969807043, 8.660254037844387, 8.703447592764606], [0.0, 0.8717797887081349, 1.2328828005937953, 1.5099668870541503, 1.7435595774162698, 1.9493588689617931, 2.1354156504062627, 2.3065125189341593, 2.4657656011875906, 2.615339366124404, 2.7568097504180447, 2.8913664589601926, 3.0199337741083006, 3.1432467291003428, 3.2619012860600183, 3.3763886032268267, 3.4871191548325395, 3.594440151122286, 3.6986484017813863, 3.8000000000000007, 3.8987177379235862, 3.9949968710876362, 4.0890096600521755, 4.180908992073375, 4.270831300812525, 4.358898943540674, 4.445222154178575, 4.529900661162451, 4.613025037868319, 4.694677837722201, 4.774934554525329, 4.8538644398046396, 4.931531202375181, 5.007993610219566, 5.083306010855535, 5.157518783291051, 5.230678732248808, 5.302829433425142, 5.374011537017762, 5.444263035526481, 5.513619500836089, 5.582114294781146, 5.649778756730215, 5.716642371182581, 5.782732917920385, 5.848076606885378, 5.912698199637794, 5.976621118993575, 6.039867548216601, 6.102458520956944, 6.164414002968978, 6.225752966509353, 6.2864934582006855, 6.3466526610489735, 6.406246951218788, 6.465291950097846, 6.523802572120037, 6.581793068761734, 6.639277069079134, 6.696267617113283, 6.752777206453653, 6.808817812219681, 6.864400920692206, 6.919537556802479, 6.974238309665079, 7.0285133563222315, 7.08237248385031, 7.13582510996451, 7.188880302244572, 7.2415467960926705, 7.293833011524189, 7.345747068882784, 7.397296803562773, 7.448489779814429, 7.49933330370107, 7.549834435270751, 7.600000000000001, 7.649836599562112, 7.6993506219680645, 7.748548251124208, 7.7974354758471724, 7.8460180983732135, 7.894301742396222, 7.942291860665913, 7.9899937421752725, 8.037412518964048, 8.084553172563096, 8.13142054010245, 8.178019320104351, 8.224354077980836, 8.270429251254134, 8.316249154516717, 8.36181798414675, 8.407139822793482, 8.452218643646177, 8.497058314499201, 8.54166260162505, 8.586035173466273, 8.630179604156568, 8.674099376880578, 8.717797887081348, 8.761278445523805], [0.0, 0.8774964387392122, 1.2409673645990857, 1.5198684153570665, 1.7549928774784245, 1.9621416870348585, 2.149418526020468, 2.32163735324878, 2.4819347291981715, 2.6324893162176366, 2.7748873851023217, 2.91032644217105, 3.039736830714133, 3.1638584039112754, 3.283291031876401, 3.3985290935932855, 3.509985754956849, 3.6180105030251086, 3.722902093797257, 3.824918299781056, 3.924283374069717, 4.02119385257662, 4.115823125451336, 4.2083250825001635, 4.298837052040936, 4.387482193696061, 4.474371464239419, 4.559605246071199, 4.64327470649756, 4.725462940284264, 4.806245936279166, 4.8856934001224435, 4.963869458396343, 5.040833264451424, 5.1166395221864125, 5.191338940966964, 5.264978632435273, 5.3376024580330075, 5.409251334519409, 5.479963503528103, 5.549774770204643, 5.61871871515206, 5.686826883245173, 5.754128952326321, 5.8206528843421, 5.886425061104575, 5.951470406546605, 6.015812497078014, 6.079473661428266, 6.142475071174486, 6.2048368229954285, 6.266578013557321, 6.327716807822551, 6.388270501473776, 6.448255578061404, 6.507687761409578, 6.566582063752802, 6.624952830020755, 6.682813778641449, 6.740178039191546, 6.797058187186571, 6.853466276272176, 6.90941386804988, 6.96491205974634, 7.019971509913698, 7.074602462329597, 7.128814768248646, 7.182617907142214, 7.236021006050217, 7.289032857656769, 7.341661937191062, 7.3939164182454755, 7.445804187594514, 7.4973328590906245, 7.548509786706248, 7.599342076785332, 7.649836599562112, 7.7, 7.749838707999026, 7.799358948016177, 7.848566748139434, 7.897467948652911, 7.9460682101275735, 7.994373021069257, 8.04238770515324, 8.090117428072352, 8.137567204023572, 8.184741901856162, 8.231646250902672, 8.278284846512591, 8.324662155306966, 8.370782520170978, 8.416650165000327, 8.462269199216012, 8.507643622061282, 8.55277732669336, 8.597674104081872, 8.64233764672499, 8.6867715521936, 8.73097932651315, 8.774964387392123, 8.81873006730561], [0.0, 0.8831760866327848, 1.2489995996796797, 1.5297058540778359, 1.7663521732655696, 1.9748417658131503, 2.1633307652783937, 2.336664289109585, 2.4979991993593593, 2.6495282598983545, 2.7928480087537886, 2.9291637031753623, 3.0594117081556718, 3.1843366656181322, 3.3045423283716615, 3.420526275297414, 3.532704346531139, 3.6414282912066254, 3.7469987990390394, 3.8496753109840323, 3.9496835316263006, 4.047221268969613, 4.1424630354415966, 4.235563716909475, 4.3266615305567875, 4.415880433163924, 4.503332099679082, 4.589117562233508, 4.67332857821917, 4.756048780237647, 4.83735464897913, 4.917316341257699, 4.995998398718719, 5.07346035758633, 5.149757275833494, 5.2249401910452535, 5.299056519796709, 5.372150407425318, 5.444263035526481, 5.515432893255072, 5.585696017507577, 5.655086206239478, 5.723635208501675, 5.791372894228104, 5.858327406350725, 5.92452529743945, 5.989991652748776, 6.054750201288242, 6.1188234163113435, 6.182232606429493, 6.244997998398399, 6.307138812488593, 6.3686733312362644, 6.429618962271405, 6.489992295835182, 6.549809157525127, 6.609084656743323, 6.667833231267862, 6.726068688320096, 6.783804242458652, 6.841052550594828, 6.897825744392215, 6.954135460285484, 7.009992867328754, 7.065408693062278, 7.12039324756716, 7.17495644586084, 7.229107828771128, 7.282856582413251, 7.336211556382492, 7.3891812807644675, 7.441773982055624, 7.493997598078079, 7.545859791965394, 7.597367965289032, 7.6485292703891785, 7.6993506219680645, 7.749838707999026, 7.800000000000002, 7.849840762716147, 7.899367063252601, 7.9485847796950635, 7.997499609252884, 8.046117075956577, 8.094442537939226, 8.142481194328914, 8.19023809177731, 8.23771813064759, 8.284926070883193, 8.33186653757728, 8.378544026261366, 8.424962907930219, 8.47112743381895, 8.517041739947036, 8.56270985144306, 8.608135686662937, 8.653323061113575, 8.698275691193055, 8.742997197757758, 8.787491109526087, 8.831760866327848, 8.875809822207776], [0.0, 0.8888194417315589, 1.2569805089976536, 1.5394804318340656, 1.7776388834631178, 1.9874606914351793, 2.177154105707724, 2.3515952032609695, 2.513961017995307, 2.6664583251946765, 2.8106938645110393, 2.9478805945967355, 3.078960863668131, 3.204684071792413, 3.3256578296631782, 3.442382895611701, 3.5552777669262356, 3.664696440361739, 3.7709415269929605, 3.874274125562104, 3.9749213828703587, 4.07308237088326, 4.168932717135166, 4.262628297189424, 4.354308211415448, 4.444097208657795, 4.532107677449864, 4.618441295502196, 4.703190406521939, 4.786439177509728, 4.868264577855234, 4.948737212663449, 5.027922035990614, 5.105878964487898, 5.182663407939976, 5.2583267300539625, 5.332916650389353, 5.406477596365309, 5.47905101272109, 5.550675634551168, 5.621387729022079, 5.691221310052879, 5.760208329565868, 5.8283788483591215, 5.895761189193471, 5.962382074305537, 6.028266749240615, 6.09343909463285, 6.157921727336262, 6.221736092120913, 6.284902544988268, 6.347440429023341, 6.409368143584826, 6.470703207534712, 6.5314623171231725, 6.591661399070799, 6.6513156593263565, 6.710439627923047, 6.76904720030818, 6.827151675479314, 6.884765791223402, 6.941901756723442, 6.998571282769077, 7.0547856097829085, 7.110555533852471, 7.165891430938652, 7.2208032794142785, 7.275300681071539, 7.329392880723478, 7.383088784512889, 7.436396977031284, 7.489325737341113, 7.541883053985921, 7.594076639065476, 7.645913941446111, 7.697402159170327, 7.748548251124208, 7.799358948016177, 7.849840762716147, 7.9, 7.949842765740717, 7.999374975584031, 8.048602363143555, 8.097530487747484, 8.14616474176652, 8.194510357550353, 8.242572413997951, 8.290355842785038, 8.337865434270332, 8.385105843100611, 8.432081593533118, 8.478797084492587, 8.525256594378847, 8.571464285639882, 8.61742420912421, 8.663140308225419, 8.708616422830897, 8.753856293085923, 8.798863562983575, 8.843641783790206, 8.88819441731559, 8.932524839036274], [0.0, 0.894427190999916, 1.2649110640673518, 1.549193338482967, 1.788854381999832, 2.0000000000000004, 2.1908902300206647, 2.366431913239847, 2.5298221281347035, 2.6832815729997477, 2.8284271247461903, 2.9664793948382657, 3.098386676965934, 3.22490309931942, 3.3466401061363023, 3.4641016151377544, 3.577708763999664, 3.687817782917155, 3.7947331922020555, 3.8987177379235862, 4.000000000000001, 4.09878030638384, 4.1952353926806065, 4.289522117905444, 4.3817804600413295, 4.47213595499958, 4.560701700396552, 4.647580015448901, 4.732863826479694, 4.8166378315169185, 4.898979485566357, 4.979959839195494, 5.059644256269407, 5.1380930314660525, 5.21536192416212, 5.291502622129181, 5.366563145999495, 5.440588203494178, 5.513619500836089, 5.585696017507577, 5.656854249492381, 5.727128425310542, 5.796550698475777, 5.865151319446072, 5.9329587896765315, 6.0, 6.066300355241241, 6.131883886702357, 6.196773353931868, 6.260990336999412, 6.324555320336759, 6.387487769068526, 6.44980619863884, 6.511528238439884, 6.572670690061994, 6.6332495807108005, 6.6932802122726045, 6.752777206453653, 6.811754546370562, 6.870225614927067, 6.928203230275509, 6.985699678629192, 7.042726744663604, 7.0992957397195395, 7.155417527999328, 7.211102550927978, 7.266360849833981, 7.321202087089251, 7.37563556583431, 7.429670248402685, 7.4833147735478835, 7.53657747256671, 7.589466384404111, 7.64198926981712, 7.694153624668538, 7.745966692414834, 7.7974354758471724, 7.848566748139434, 7.899367063252601, 7.949842765740717, 8.000000000000002, 8.049844718999244, 8.099382692526635, 8.148619514985345, 8.19756061276768, 8.246211251235321, 8.29457654133109, 8.342661445845685, 8.390470785361213, 8.438009243891594, 8.485281374238571, 8.532291603080617, 8.579044235810889, 8.62554346113913, 8.671793355471522, 8.717797887081348, 8.763560920082659, 8.809086218218098, 8.854377448471462, 8.899438184514796, 8.94427190999916, 8.988882021697695], [0.0, 0.9, 1.2727922061357855, 1.5588457268119897, 1.8, 2.012461179749811, 2.2045407685048604, 2.3811761799581315, 2.545584412271571, 2.7, 2.8460498941515415, 2.9849623113198605, 3.1176914536239795, 3.2449961479175906, 3.3674916480965473, 3.485685011586675, 3.6, 3.710795063055895, 3.8183766184073566, 3.9230090491866068, 4.024922359499622, 4.124318125460256, 4.221374183841087, 4.316248370981448, 4.409081537009721, 4.500000000000001, 4.589117562233507, 4.676537180435969, 4.762352359916263, 4.846648326421054, 4.929503017546495, 5.01098792654702, 5.091168824543142, 5.170106381884226, 5.247856705360771, 5.324471804789654, 5.4, 5.474486277268398, 5.547972602672079, 5.620498198558559, 5.692099788303083, 5.762811813689565, 5.832666628567075, 5.9016946718718, 5.969924622639721, 6.037383539249432, 6.104096984812742, 6.17008914036094, 6.235382907247959, 6.300000000000001, 6.3639610306789285, 6.427285585688566, 6.489992295835181, 6.552098900352467, 6.613622305514581, 6.674578638386097, 6.734983296193095, 6.794850991743675, 6.854195795277518, 6.913031173081747, 6.97137002317335, 7.029224708315989, 7.08660708661063, 7.143528539874395, 7.2, 7.256031973468694, 7.311634564172365, 7.366817494685205, 7.42159012611179, 7.475961476626268, 7.529940238806681, 7.583534795858723, 7.636753236814713, 7.689603370785778, 7.742092740338364, 7.794228634059948, 7.8460180983732135, 7.897467948652911, 7.9485847796950635, 7.999374975584031, 8.049844718999244, 8.100000000000001, 8.149846624323676, 8.19939022122987, 8.248636250920512, 8.2975900115636, 8.346256645946134, 8.394641147779934, 8.442748367682174, 8.490583018850943, 8.538149682454625, 8.58545281275251, 8.632496741962896, 8.67928568489366, 8.725823743349393, 8.772114910328067, 8.818163074019441, 8.863972021616496, 8.909545442950499, 8.95488693395958, 9.000000000000002, 9.044888059008803], [0.0, 0.9055385138137417, 1.2806248474865698, 1.5684387141358125, 1.8110770276274835, 2.024845673131659, 2.2181073012818837, 2.395829710142188, 2.5612496949731396, 2.716615541441225, 2.863564212655271, 3.003331483536242, 3.136877428271625, 3.264965543462902, 3.3882148692194836, 3.5071355833500366, 3.622154055254967, 3.733630940518894, 3.84187454245971, 3.947150871198111, 4.049691346263318, 4.149698784249287, 4.247352116319061, 4.342810150121694, 4.436214602563767, 4.527692569068709, 4.617358552246079, 4.705316142407438, 4.791659420284376, 4.876474136094644, 4.959838707054898, 5.041825066382213, 5.122499389946279, 5.201922721455982, 5.280151512977635, 5.35723809439155, 5.43323108288245, 5.508175741568166, 5.582114294781146, 5.655086206239478, 5.727128425310542, 5.798275605729691, 5.868560300448485, 5.938013135721409, 6.006662967072484, 6.074537019394977, 6.1416610131136355, 6.208059278067503, 6.27375485654325, 6.338769596696192, 6.403124237432849, 6.466838485689898, 6.529931086925804, 6.592419889539805, 6.654321903845651, 6.715653356152327, 6.776429738438967, 6.836665854054885, 6.8963758598266685, 6.955573304911681, 7.014271166700073, 7.07248188403477, 7.130217387990355, 7.187489130426565, 7.244308110509934, 7.300684899377592, 7.356629663099809, 7.4121521840825695, 7.467261881037788, 7.521967827636597, 7.576278769950325, 7.630203142774117, 7.68374908491942, 7.736924453553881, 7.789736837660179, 7.842193570679062, 7.894301742396222, 7.9460682101275735, 7.997499609252884, 8.048602363143555, 8.099382692526635, 8.149846624323676, 8.200000000000001, 8.249848483457136, 8.299397568498573, 8.348652585896723, 8.397618710086808, 8.446300965511472, 8.494704232638123, 8.542833253669418, 8.590692637965812, 8.638286867197687, 8.685620300243388, 8.732697177848321, 8.77952162705919, 8.826097665446492, 8.872429205127535, 8.918520056601322, 8.964373932405989, 9.009994450608726, 9.055385138137417, 9.100549433962767], [0.0, 0.9110433579144299, 1.2884098726725124, 1.5779733838059502, 1.8220867158288598, 2.0371548787463363, 2.2315913604421396, 2.41039415863879, 2.576819745345025, 2.7331300737432893, 2.8809720581775866, 3.0215889859476257, 3.1559467676119004, 3.2848135411313684, 3.408812109811862, 3.5284557528754696, 3.6441734316577197, 3.7563279941985894, 3.8652296180175374, 3.9711459303329564, 4.0743097574926725, 4.174925149029621, 4.273172123844299, 4.369210454990696, 4.463182720884279, 4.55521678957215, 4.645427859734774, 4.73392015141785, 4.82078831727758, 4.906118628814432, 4.9899899799498595, 5.072474741188959, 5.15363949069005, 5.23354564325181, 5.31224999411737, 5.389805191284746, 5.466260147486579, 5.541660400998964, 5.616048432839589, 5.68946394662977, 5.761944116355173, 5.833523806414096, 5.904235767650205, 5.974110812497538, 6.043177971895251, 6.111464636239008, 6.178996682310163, 6.245798587850876, 6.311893535223801, 6.377303505401009, 6.442049363362563, 6.506150935845249, 6.569627082262737, 6.632495759516172, 6.694774081326419, 6.756478372643548, 6.817624219623724, 6.878226515607057, 6.938299503480662, 6.997856814768361, 7.056911505750939, 7.115476090888086, 7.173562573784381, 7.23118247591637, 7.288346863315439, 7.345066371381541, 7.401351227985333, 7.457211275000863, 7.512655988397179, 7.567694497005016, 7.622335600063802, 7.676587783644501, 7.730459236035075, 7.783957862167549, 7.837091297158659, 7.88986691902975, 7.942291860665913, 7.994373021069257, 8.046117075956577, 8.097530487747484, 8.148619514985345, 8.19939022122987, 8.249848483457136, 8.299999999999999, 8.349850298059241, 8.399404740813482, 8.44866853415377, 8.49764673306675, 8.546344247688598, 8.594765849050223, 8.64291617453276, 8.690799733051039, 8.738420909981391, 8.78578397184907, 8.832893070789435, 8.879752248796134, 8.926365441768558, 8.972736483370054, 9.018869108707587, 9.064766957842878, 9.1104335791443, 9.155872432488342], [0.0, 0.9165151389911681, 1.2961481396815722, 1.5874507866387546, 1.8330302779823362, 2.04939015319192, 2.244994432064365, 2.4248711305964283, 2.5922962793631443, 2.749545416973504, 2.898275349237888, 3.039736830714133, 3.174901573277509, 3.3045423283716615, 3.4292856398964493, 3.5496478698597693, 3.6660605559646724, 3.778888725538237, 3.8884444190447165, 3.9949968710876362, 4.09878030638384, 4.2, 4.298837052040936, 4.3954521951671826, 4.48998886412873, 4.582575694955841, 4.67332857821917, 4.762352359916264, 4.849742261192857, 4.935585071701227, 5.019960159204453, 5.10294032886923, 5.184592558726289, 5.264978632435274, 5.344155686354956, 5.422176684690384, 5.499090833947008, 5.574943945906542, 5.649778756730214, 5.723635208501674, 5.796550698475776, 5.868560300448484, 5.939696961967, 6.009991680526688, 6.079473661428266, 6.148170459575759, 6.216108107168022, 6.2833112289620034, 6.349803146555018, 6.4156059729381765, 6.480740698407861, 6.54522726878143, 6.609084656743323, 6.672330927044912, 6.7349832961930955, 6.797058187186572, 6.858571279792899, 6.919537556802478, 6.97997134664606, 7.0398863627192165, 7.099295739719539, 7.158212067269313, 7.216647421067486, 7.274613391789285, 7.332121111929345, 7.389181280764467, 7.445804187594514, 7.501999733404421, 7.557777451076474, 7.6131465242697125, 7.668115805072326, 7.72269383052313, 7.776888838089433, 7.830708780180758, 7.884161337770809, 7.937253933193772, 7.9899937421752725, 8.04238770515324, 8.094442537939226, 8.14616474176652, 8.19756061276768, 8.248636250920512, 8.299397568498573, 8.349850298059241, 8.4, 8.449852069711044, 8.499411744350311, 8.548684109265006, 8.597674104081872, 8.646386528486914, 8.694826047713663, 8.742997197757758, 8.790904390334365, 8.838551917593742, 8.885943956609225, 8.933084573650918, 8.97997772825746, 9.026627277117408, 9.073036977771006, 9.119210492142399, 9.165151389911681, 9.210863151735564], [0.0, 0.9219544457292888, 1.3038404810405297, 1.5968719422671316, 1.8439088914585775, 2.0615528128088303, 2.2583179581272432, 2.4392621835300936, 2.6076809620810595, 2.765863337187866, 2.9154759474226504, 3.0577769702841313, 3.193743884534263, 3.3241540277189325, 3.449637662132068, 3.5707142142714248, 3.687817782917155, 3.8013155617496426, 3.9115214431215897, 4.018706259482024, 4.123105625617661, 4.224926034855522, 4.324349662087931, 4.421538193886829, 4.5166359162544865, 4.609772228646444, 4.701063709417264, 4.790615826801394, 4.878524367060187, 4.964876634922565, 5.049752469181039, 5.13322510708424, 5.215361924162119, 5.296225070746145, 5.375872022286245, 5.454356057317858, 5.531726674375732, 5.608029957123981, 5.68330889535313, 5.757603668193913, 5.830951894845301, 5.903388857258177, 5.974947698515863, 6.0456596000767355, 6.115553940568263, 6.18465843842649, 6.252999280345393, 6.320601237224193, 6.387487769068526, 6.4536811201050215, 6.519202405202649, 6.584071688552609, 6.648308055437865, 6.711929677819935, 6.77495387438173, 6.837397165588672, 6.899275324264136, 6.960603422117942, 7.021395872616784, 7.0816664705420855, 7.1414284285428495, 7.200694410957877, 7.259476565152615, 7.317786550590281, 7.37563556583431, 7.433034373659253, 7.489993324429602, 7.546522377890362, 7.602631123499285, 7.658328799418317, 7.713624310270757, 7.768526243760782, 7.823042886243179, 7.877182237323192, 7.930952023559341, 7.984359711335657, 8.037412518964048, 8.090117428072352, 8.142481194328914, 8.194510357550353, 8.246211251235321, 8.2975900115636, 8.348652585896723, 8.399404740813482, 8.449852069711044, 8.5, 8.549853799919623, 8.599418584997478, 8.648699324175862, 8.697700845625814, 8.746427842267952, 8.794884877018005, 8.843076387773658, 8.891006692158093, 8.938679992034618, 8.986100377805714, 9.033271832508973, 9.080198235721511, 9.126883367283709, 9.173330910852394, 9.219544457292889, 9.265527507918803], [0.0, 0.9273618495495705, 1.3114877048604001, 1.6062378404209012, 1.854723699099141, 2.0736441353327724, 2.2715633383201097, 2.4535688292770597, 2.6229754097208002, 2.7820855486487113, 2.932575659723036, 3.07571129984594, 3.2124756808418025, 3.343650699460098, 3.4698703145794947, 3.591656999213594, 3.709447398198282, 3.8236108588610325, 3.9344631145812006, 4.042276586281548, 4.147288270665545, 4.249705872175156, 4.349712634186309, 4.447471191587417, 4.543126676640219, 4.636809247747852, 4.7286361670147565, 4.818713521262704, 4.907137658554119, 4.993996395673509, 5.079370039680118, 5.163332257370235, 5.2459508194416005, 5.327288240746882, 5.40740233383831, 5.486346689738081, 5.5641710972974225, 5.640921910468182, 5.716642371182581, 5.791372894228104, 5.865151319446072, 5.93801313572141, 6.009991680526689, 6.081118318204308, 6.15142259969188, 6.220932405998316, 6.289674077406556, 6.357672530100934, 6.424951361683605, 6.491532946846993, 6.557438524302001, 6.62268827591938, 6.687301398920196, 6.751296171847301, 6.814690014960329, 6.87749954561976, 6.939740629158989, 7.001428425685718, 7.062577433203831, 7.123201527403251, 7.183313998427188, 7.242927584892728, 7.302054505411474, 7.3607064878311785, 7.418894796396564, 7.476630257007497, 7.533923280734945, 7.590783885739338, 7.647221717722065, 7.703246069028303, 7.75886589650833, 7.814089838234521, 7.868926229162401, 7.923383115816122, 7.977468270071652, 8.031189202104505, 8.084553172563096, 8.137567204023572, 8.19023809177731, 8.242572413997951, 8.29457654133109, 8.346256645946134, 8.397618710086808, 8.44866853415377, 8.499411744350311, 8.549853799919623, 8.600000000000001, 8.649855490122365, 8.699425268372618, 8.748714191239761, 8.79772697916911, 8.84646822183859, 8.894942383174834, 8.943153806124549, 8.99110671719561, 9.038805230781334, 9.086253353280439, 9.133454987024352, 9.180413934022802, 9.22713389953782, 9.273618495495704, 9.319871243745807], [0.0, 0.9327379053088816, 1.3190905958272918, 1.6155494421403516, 1.8654758106177631, 2.0856653614614213, 2.2847319317591728, 2.4677925358506134, 2.6381811916545836, 2.7982137159266447, 2.9495762407505253, 3.093541659651604, 3.231098884280703, 3.363034344160048, 3.4899856733230297, 3.6124783736376886, 3.7309516212355263, 3.845776904605882, 3.957271787481876, 4.065710270051225, 4.171330722922843, 4.274342054632503, 4.374928570845472, 4.473253849269009, 4.5694638635183455, 4.663689526544408, 4.756048780237647, 4.846648326421054, 4.935585071701227, 5.022947341949744, 5.10881590977792, 5.193264869039514, 5.276362383309167, 5.358171329847526, 5.4387498563548595, 5.518151864528558, 5.596427431853289, 5.673623181001714, 5.749782604586021, 5.8249463516842805, 5.8991524815010505, 5.9724366886556455, 6.044832503882966, 6.1163714733492105, 6.187083319303208, 6.256996084384263, 6.326136261573884, 6.394528911499267, 6.462197768561406, 6.529165337162171, 6.59545297913646, 6.661080993352356, 6.726068688320096, 6.790434448545985, 6.854195795277518, 6.917369442208505, 6.979971346646059, 7.042016756583302, 7.103520254071217, 7.164495795239188, 7.224956747275377, 7.284915922644544, 7.344385610791416, 7.40337760755184, 7.4619032424710525, 7.519973404208288, 7.577598564189054, 7.634788798650556, 7.691553809211764, 7.747902942086975, 7.803845206050669, 7.859389289251424, 7.914543574963752, 7.969316156358713, 8.023714850367003, 8.077747210701757, 8.13142054010245, 8.184741901856162, 8.23771813064759, 8.290355842785038, 8.342661445845685, 8.394641147779934, 8.446300965511472, 8.49764673306675, 8.548684109265006, 8.599418584997478, 8.649855490122365, 8.700000000000001, 8.749857141690944, 8.799431799837988, 8.848728722251575, 8.897752525216692, 8.946507698538017, 8.994998610338971, 9.043229511629129, 9.091204540653564, 9.138927727036691, 9.186402995732335, 9.233634170791044, 9.280624978954814, 9.327379053088816, 9.373899935459095], [0.0, 0.938083151964686, 1.3266499161421599, 1.6248076809271923, 1.876166303929372, 2.0976176963403033, 2.297825058615212, 2.4819347291981715, 2.6532998322843198, 2.814249455894058, 2.9664793948382653, 3.1112698372208096, 3.2496153618543846, 3.3823069050575527, 3.509985754956849, 3.63318042491699, 3.752332607858744, 3.867815921162743, 3.97994974842648, 4.0890096600521755, 4.1952353926806065, 4.298837052040936, 4.4, 4.498888751680798, 4.595650117230424, 4.69041575982343, 4.7833042972405595, 4.874423042781577, 4.963869458396343, 5.0517323761260355, 5.138093031466052, 5.223025942880239, 5.3065996645686395, 5.388877434122993, 5.469917732470938, 5.549774770204643, 5.628498911788116, 5.706137047074843, 5.782732917920384, 5.858327406350725, 5.932958789676531, 6.006662967072483, 6.079473661428266, 6.151422599691879, 6.222539674441619, 6.292853089020909, 6.362389488234747, 6.431174076325411, 6.499230723708769, 6.566582063752802, 6.6332495807108005, 6.6992536897776915, 6.764613810115105, 6.82934843158555, 6.8934751758456345, 6.957010852370435, 7.019971509913698, 7.0823724838503095, 7.144228439796701, 7.205553413860728, 7.26636084983398, 7.326663633605681, 7.386474125047755, 7.445804187594514, 7.504665215717488, 7.5630681604756145, 7.62102355330306, 7.678541528180987, 7.735631842325486, 7.792303895511263, 7.848566748139434, 7.904429138147802, 7.95989949685296, 8.014985963805552, 8.069696400732806, 8.12403840463596, 8.178019320104351, 8.231646250902672, 8.284926070883193, 8.337865434270332, 8.390470785361213, 8.442748367682174, 8.494704232638123, 8.546344247688598, 8.597674104081872, 8.648699324175862, 8.699425268372618, 8.749857141690944, 8.8, 8.849858755935035, 8.899438184514796, 8.948742928478838, 8.997777503361595, 9.046546302318914, 9.09505360072166, 9.143303560529969, 9.191300234460847, 9.23904756996088, 9.28654941299512, 9.333809511662428, 9.38083151964686, 9.427618999514142], [0.0, 0.9433981132056604, 1.3341664064126333, 1.6340134638368193, 1.8867962264113207, 2.1095023109728985, 2.3108440016582685, 2.495996794869737, 2.6683328128252666, 2.830194339616981, 2.9832867780352594, 3.1288975694324033, 3.2680269276736387, 3.4014702703389896, 3.529872518944558, 3.6537651812890215, 3.7735924528226414, 3.8897300677553446, 4.0024992192379, 4.112177038990418, 4.219004621945797, 4.323193264243457, 4.424929377967517, 4.524378410345448, 4.621688003316537, 4.716990566028302, 4.810405388322278, 4.902040391510457, 4.991993589739474, 5.0803543183522155, 5.167204273105525, 5.252618394667558, 5.336665625650533, 5.419409561935692, 5.500909015790026, 5.58121850495033, 5.660388679233962, 5.7384666941614295, 5.815496539419485, 5.8915193286621745, 5.966573556070519, 6.040695324215583, 6.113918547053109, 6.186275131288617, 6.2577951388648065, 6.328506932918695, 6.398437309218556, 6.4676116148080505, 6.536053855347277, 6.603786792439623, 6.670832032063167, 6.73721010508059, 6.802940540677979, 6.868041933477111, 6.932532004974806, 6.996427659884722, 7.059745037889116, 7.122499561249548, 7.184705978674423, 7.246378405796926, 7.307530362578043, 7.368174807915458, 7.428324171709255, 7.487990384609211, 7.547184905645283, 7.6059187479225665, 7.664202502543888, 7.722046360907191, 7.779460135510689, 7.836453279386026, 7.893034904268446, 7.949213797602879, 8.0049984384758, 8.060397012554654, 8.115417426109392, 8.170067319184096, 8.224354077980836, 8.278284846512591, 8.33186653757728, 8.385105843100611, 8.438009243891594, 8.490583018850943, 8.542833253669418, 8.594765849050223, 8.646386528486914, 8.697700845625814, 8.748714191239761, 8.799431799837988, 8.849858755935035, 8.899999999999999, 8.949860334105779, 8.99944442729661, 9.048756820690896, 9.097801932335084, 9.1465840618233, 9.195107394696377, 9.243376006633074, 9.291393867445294, 9.339164844888433, 9.38669270829721, 9.433981132056603, 9.481033698917013], [0.0, 0.9486832980505138, 1.3416407864998738, 1.6431676725154984, 1.8973665961010275, 2.121320343559643, 2.32379000772445, 2.5099800796022267, 2.6832815729997477, 2.846049894151541, 3.0, 3.146426544510455, 3.286335345030997, 3.420526275297414, 3.5496478698597693, 3.674234614174767, 3.794733192202055, 3.9115214431215892, 4.024922359499621, 4.135214625627067, 4.242640687119286, 4.347413023856832, 4.449719092257398, 4.549725266430931, 4.6475800154489, 4.743416490252569, 4.83735464897913, 4.929503017546495, 5.019960159204453, 5.10881590977792, 5.196152422706632, 5.282045058497703, 5.366563145999495, 5.449770637375486, 5.531726674375733, 5.612486080160912, 5.692099788303082, 5.770615218501404, 5.848076606885378, 5.92452529743945, 6.0, 6.074537019394977, 6.148170459575759, 6.220932405998315, 6.29285308902091, 6.363961030678928, 6.434283176858165, 6.5038450166036395, 6.572670690061994, 6.640783086353597, 6.708203932499369, 6.77495387438173, 6.841052550594828, 6.906518659932804, 6.971370023173351, 7.035623639735144, 7.099295739719539, 7.162401831787993, 7.224956747275378, 7.286974680894671, 7.348469228349534, 7.409453421137082, 7.469939758793239, 7.52994023880668, 7.58946638440411, 7.648529270389177, 7.707139547199077, 7.76530746332687, 7.8230428862431785, 7.880355321938218, 7.937253933193772, 7.993747556684537, 8.049844718999243, 8.105553651663778, 8.160882305241266, 8.215838362577491, 8.270429251254134, 8.324662155306966, 8.378544026261366, 8.432081593533118, 8.485281374238571, 8.538149682454625, 8.590692637965812, 8.64291617453276, 8.694826047713663, 8.746427842267952, 8.79772697916911, 8.848728722251575, 8.899438184514796, 8.949860334105779, 9.0, 9.049861877399014, 9.099450532861862, 9.148770409186145, 9.197825830053535, 9.246621004453464, 9.2951600308978, 9.343446901438464, 9.391485505499116, 9.439279633531365, 9.486832980505138, 9.534149149242424], [0.0, 0.9539392014169457, 1.349073756323204, 1.6522711641858308, 1.9078784028338913, 2.1330729007701543, 2.3366642891095846, 2.5238858928247927, 2.698147512646408, 2.8618176042508368, 3.0166206257996713, 3.1638584039112754, 3.3045423283716615, 3.439476704383968, 3.5693136595149495, 3.694590640382233, 3.8157568056677826, 3.9331920878594273, 4.047221268969612, 4.158124577258358, 4.266145801540309, 4.371498598878879, 4.474371464239419, 4.57493169347915, 4.673328578219169, 4.769696007084729, 4.864154602806124, 4.956813492557492, 5.047771785649585, 5.137119815616529, 5.224940191045253, 5.3113086899558, 5.396295025292816, 5.479963503528103, 5.562373594069352, 5.643580423808984, 5.7236352085016735, 5.8025856305616035, 5.880476171195663, 5.957348403442593, 6.0332412515993425, 6.1081912216301815, 6.182232606429493, 6.255397669213365, 6.327716807822551, 6.399218702310462, 6.469930447848725, 6.539877674696982, 6.609084656743323, 6.67757440991862, 6.745368781616021, 6.81248853210044, 6.878953408767936, 6.944782214007867, 7.009992867328754, 7.074602462329597, 7.138627319029899, 7.202083032012336, 7.264984514780469, 7.327346040688948, 7.389181280764466, 7.450503338701353, 7.511324783285569, 7.571657678474378, 7.631513611335565, 7.6909037180295, 7.749838707999025, 7.808328886515987, 7.866384175718855, 7.924014134263013, 7.981227975693966, 8.038034585643434, 8.094442537939225, 8.150460109711599, 8.206095295571457, 8.261355820929154, 8.316249154516717, 8.370782520170978, 8.424962907930219, 8.478797084492587, 8.532291603080617, 8.58545281275251, 8.638286867197687, 8.690799733051039, 8.742997197757758, 8.794884877018005, 8.84646822183859, 8.897752525216692, 8.948742928478838, 8.99944442729661, 9.049861877399014, 9.1, 9.1498633869583, 9.199456505685541, 9.248783703817493, 9.297849213662264, 9.346657156438338, 9.395211546314432, 9.443516294262428, 9.491575211733826, 9.539392014169458, 9.586970324351693], [0.0, 0.959166304662544, 1.3564659966250536, 1.6613247725836153, 1.918332609325088, 2.144761058952722, 2.349468024894146, 2.5377155080899043, 2.7129319932501073, 2.877498913987632, 3.0331501776206204, 3.1811947441173736, 3.3226495451672307, 3.458323293158117, 3.5888716889852725, 3.714835124201342, 3.836665218650176, 3.954743986657038, 4.069397989875161, 4.180908992073375, 4.289522117905444, 4.3954521951671826, 4.498888751680798, 4.6000000000000005, 4.698936049788292, 4.79583152331272, 4.8908077042549944, 4.983974317750846, 5.075431016179809, 5.165268628057984, 5.253570214625479, 5.340411969127476, 5.4258639865002145, 5.509990925582366, 5.592852581643825, 5.674504383644443, 5.754997827975264, 5.83438085832593, 5.912698199637794, 5.989991652748776, 6.066300355241241, 6.1416610131136355, 6.216108107168022, 6.289674077406555, 6.362389488234747, 6.434283176858165, 6.505382386916238, 6.575712889109439, 6.645299090334461, 6.714164132637808, 6.782329983125269, 6.8498175158174845, 6.916646586316234, 6.982836100038438, 7.0484040746824395, 7.113367697511497, 7.177743377970545, 7.24154679609267, 7.3047929470998705, 7.367496182557545, 7.429670248402684, 7.491328320131218, 7.552483035399683, 7.6131465242697125, 7.673330437300352, 7.733045971672482, 7.792303895511263, 7.851114570556209, 7.909487973314076, 7.967433714816837, 8.024961059095553, 8.082078940470701, 8.138795979750322, 8.195120499419152, 8.251060537894508, 8.306623862918075, 8.36181798414675, 8.416650165000327, 8.47112743381895, 8.525256594378847, 8.579044235810889, 8.632496741962896, 8.685620300243388, 8.738420909981391, 8.790904390334365, 8.843076387773658, 8.894942383174834, 8.946507698538017, 8.997777503361595, 9.048756820690896, 9.099450532861862, 9.1498633869583, 9.200000000000001, 9.249864863877743, 9.299462350050137, 9.348796714016196, 9.397872099576585, 9.446692542895637, 9.495261976375376, 9.54358423235212, 9.59166304662544, 9.639502061828715], [0.0, 0.9643650760992956, 1.3638181696985856, 1.670329308849007, 1.9287301521985911, 2.1563858652847827, 2.3622023622035435, 2.551470164434615, 2.727636339397171, 2.8930952282978866, 3.0495901363953815, 3.1984371183438958, 3.340658617698014, 3.4770677301427426, 3.6083237105337433, 3.7349698793966195, 3.8574603043971822, 3.976179070414209, 4.091454509095757, 4.203569911396741, 4.312771730569565, 4.419275958796871, 4.523273151159457, 4.624932431938872, 4.724404724407087, 4.821825380496478, 4.917316341257699, 5.0109879265470205, 5.10294032886923, 5.193264869039514, 5.282045058497703, 5.36935750346352, 5.455272678794342, 5.539855593785817, 5.62316636780382, 5.705260730238365, 5.786190456595773, 5.866003750424986, 5.944745579080741, 6.02245796996542, 6.099180272790763, 6.174949392505174, 6.249799996799899, 6.323764701504951, 6.3968742366877915, 6.469157595854347, 6.540642170307134, 6.611353870426239, 6.681317235396028, 6.750555532695069, 6.8190908484929285, 6.886944169949399, 6.954135460285485, 7.020683727387242, 7.0866070866106305, 7.15192281837549, 7.216647421067487, 7.280796659706959, 7.3443856107914165, 7.407428703673091, 7.469939758793239, 7.531932023060219, 7.593418202627852, 7.654410493303845, 7.7149206087943645, 7.774959806970066, 7.834538914320357, 7.893668348746355, 7.952358140828418, 8.010617953691215, 8.068457101577724, 8.125884567233282, 8.182909018191515, 8.239538822045807, 8.295782060782456, 8.351646544245034, 8.407139822793482, 8.462269199216012, 8.517041739947036, 8.571464285639882, 8.62554346113913, 8.67928568489366, 8.732697177848321, 8.78578397184907, 8.838551917593742, 8.891006692158093, 8.943153806124549, 8.994998610338971, 9.046546302318914, 9.097801932335084, 9.148770409186145, 9.199456505685541, 9.249864863877743, 9.3, 9.349866309204641, 9.39946807005588, 9.448809448814174, 9.497894503520243, 9.5467271878901, 9.595311355031686, 9.643650760992957, 9.691749068150704], [0.0, 0.9695359714832659, 1.3711309200802089, 1.6792855623746668, 1.9390719429665317, 2.1679483388678804, 2.374868417407584, 2.5651510676761324, 2.7422618401604177, 2.9086079144497976, 3.0659419433511785, 3.2155870381627056, 3.3585711247493335, 3.4957116585897072, 3.627671429443411, 3.7549966711037173, 3.8781438859330635, 3.9974992182613374, 4.113392760240627, 4.226109321823088, 4.335896677735761, 4.442971978304612, 4.54752680036083, 4.649731175025068, 4.749736834815168, 4.847679857416329, 4.943682837723311, 5.037856687124, 5.130302135352265, 5.221110992882646, 5.310367218940701, 5.398147830506312, 5.4845236803208355, 5.569560126257729, 5.653317610041029, 5.735852159879995, 5.817215828899595, 5.897457079114693, 5.976621118993575, 6.054750201288242, 6.131883886702357, 6.208059278067504, 6.283311228962004, 6.357672530100933, 6.431174076325411, 6.5038450166036395, 6.57571288910944, 6.646803743153547, 6.717142249498667, 6.786751800382861, 6.855654600401045, 6.923871749245506, 6.9914233171794145, 7.058328414008519, 7.124605252222751, 7.1902712048990205, 7.255342858886822, 7.31983606373804, 7.383765976789894, 7.447147104764348, 7.5099933422074345, 7.572318007057021, 7.634133873596926, 7.695453203028396, 7.756287771866127, 7.816648898345122, 7.8765474670060875, 7.935993951610599, 7.994998436522675, 8.053570636680355, 8.1117199162693, 8.16945530620004, 8.226785520481254, 8.283718971573094, 8.340263784797218, 8.396427811873334, 8.452218643646177, 8.507643622061282, 8.56270985144306, 8.61742420912421, 8.671793355471522, 8.725823743349393, 8.77952162705919, 8.832893070789435, 8.885943956609225, 8.938679992034618, 8.99110671719561, 9.043229511629129, 9.09505360072166, 9.1465840618233, 9.197825830053535, 9.248783703817493, 9.299462350050137, 9.349866309204641, 9.4, 9.44986772394196, 9.499473669630335, 9.548821916864929, 9.597916440561463, 9.646761114488118, 9.695359714832659, 9.743715923609434], [0.0, 0.9746794344808963, 1.378404875209022, 1.6881943016134133, 1.9493588689617927, 2.179449471770337, 2.3874672772626644, 2.578759391645525, 2.756809750418044, 2.9240383034426887, 3.082207001484488, 3.2326459750489227, 3.3763886032268267, 3.5142566781611158, 3.6469165057620936, 3.7749172176353745, 3.8987177379235853, 4.018706259482023, 4.135214625627066, 4.2485291572496005, 4.358898943540674, 4.466542286825459, 4.571651780264984, 4.674398357008098, 4.774934554525329, 4.873397172404482, 4.969909455915671, 5.06458290484024, 5.15751878329105, 5.2488093888042835, 5.338539126015655, 5.426785420486054, 5.513619500836088, 5.599107071667768, 5.683308895353129, 5.766281297335397, 5.848076606885377, 5.928743543112655, 6.008327554319921, 6.08687111741328, 6.164414002968976, 6.24099351065197, 6.316644678941503, 6.3914004725099165, 6.465291950097845, 6.53834841531101, 6.6105975524153635, 6.682065548915245, 6.752777206453653, 6.822756041366274, 6.892024376045111, 6.960603422117942, 7.0285133563222315, 7.095773389842717, 7.162401831787993, 7.2284161474004796, 7.293833011524187, 7.358668357794092, 7.4229374239582535, 7.486654793697916, 7.549834435270749, 7.6124897372673015, 7.674633541739956, 7.736278174936576, 7.797435475847171, 7.858116822750854, 7.918333157931661, 7.978095010715276, 8.037412518964047, 8.096295449154509, 8.154753215150045, 8.212794895770866, 8.270429251254132, 8.327664738688751, 8.384509526501832, 8.440971508067065, 8.497058314499201, 8.55277732669336, 8.608135686662937, 8.663140308225419, 8.717797887081348, 8.772114910328067, 8.826097665446492, 8.879752248796134, 8.933084573650918, 8.986100377805714, 9.038805230781334, 9.091204540653564, 9.143303560529969, 9.195107394696377, 9.246621004453464, 9.297849213662264, 9.348796714016196, 9.39946807005588, 9.44986772394196, 9.499999999999998, 9.549869109050658, 9.599479152537391, 9.648834126463154, 9.697937925146768, 9.746794344808963, 9.795407086997457], [0.0, 0.9797958971132713, 1.3856406460551018, 1.6970562748477143, 1.9595917942265426, 2.1908902300206647, 2.4000000000000004, 2.5922962793631443, 2.7712812921102037, 2.939387691339814, 3.0983866769659336, 3.2496153618543846, 3.3941125496954285, 3.532704346531139, 3.666060555964672, 3.794733192202055, 3.9191835884530852, 4.039801975344831, 4.156921938165306, 4.270831300812525, 4.3817804600413295, 4.48998886412873, 4.595650117230424, 4.698936049788292, 4.800000000000001, 4.898979485566357, 4.9959983987187195, 5.091168824543143, 5.184592558726289, 5.276362383309168, 5.366563145999495, 5.455272678794342, 5.542562584220407, 5.628498911788117, 5.713142742834281, 5.796550698475776, 5.878775382679628, 5.959865770300536, 6.0398675482166, 6.118823416311343, 6.196773353931867, 6.27375485654325, 6.349803146555018, 6.424951361683604, 6.499230723708769, 6.572670690061993, 6.64529909033446, 6.717142249498666, 6.788225099390857, 6.858571279792899, 6.92820323027551, 6.997142273814362, 7.065408693062278, 7.1330218000508046, 7.2, 7.266360849833981, 7.332121111929344, 7.397296803562772, 7.4619032424710525, 7.525955088890711, 7.58946638440411, 7.652450587883597, 7.714920608794364, 7.776888838089433, 7.8383671769061705, 7.899367063252599, 7.95989949685296, 8.019975062305368, 8.079603950689663, 8.138795979750322, 8.19756061276768, 8.255906976220118, 8.313843876330612, 8.37137981458254, 8.42852300228219, 8.485281374238571, 8.54166260162505, 8.597674104081872, 8.653323061113575, 8.708616422830897, 8.763560920082659, 8.818163074019441, 8.872429205127535, 8.926365441768558, 8.97997772825746, 9.033271832508973, 9.086253353280439, 9.138927727036691, 9.191300234460847, 9.243376006633074, 9.2951600308978, 9.346657156438338, 9.397872099576585, 9.448809448814174, 9.499473669630335, 9.549869109050658, 9.600000000000001, 9.649870465451857, 9.699484522385713, 9.748846085563153, 9.797958971132713, 9.846826900072939], [0.0, 0.9848857801796106, 1.392838827718412, 1.7058722109231985, 1.9697715603592212, 2.2022715545545246, 2.412467616362964, 2.6057628441590768, 2.785677655436824, 2.9546573405388314, 3.1144823004794877, 3.2664965942122155, 3.411744421846397, 3.5510561809129415, 3.685105154537656, 3.8144462245521304, 3.9395431207184424, 4.060788100849391, 4.178516483155236, 4.293017586733137, 4.404543109109049, 4.513313638558704, 4.61952378498044, 4.723346271447818, 4.824935232725928, 4.924428900898053, 5.021951811795889, 5.117616632769595, 5.2115256883181535, 5.3037722424704485, 5.394441583704471, 5.483611948342078, 5.571355310873648, 5.657738063926256, 5.742821606144492, 5.826662852782887, 5.909314681077663, 5.990826320300065, 6.071243694664217, 6.150609725872713, 6.228964600958975, 6.306346010171025, 6.38278935889318, 6.458327956987009, 6.532993188424431, 6.606814663663572, 6.679820356865895, 6.7520367297579185, 6.823488843692794, 6.894200461257274, 6.9641941385920605, 7.033491309442276, 7.102112361825883, 7.170076708097342, 7.237402849088892, 7.30410843293006, 7.370210309075312, 7.4357245780085215, 7.5006666370396715, 7.565051222562872, 7.628892449104261, 7.692203845452876, 7.754998388136519, 7.817288532477231, 7.879086241436885, 7.940403012442127, 8.001249902359007, 8.061637550770936, 8.121576201698781, 8.18107572388864, 8.240145629781066, 8.298795093265047, 8.357032966310472, 8.414867794564572, 8.472307831990054, 8.529361054615991, 8.586035173466273, 8.64233764672499, 8.698275691193055, 8.753856293085923, 8.809086218218098, 8.863972021616496, 8.918520056601322, 8.972736483370054, 9.026627277117408, 9.080198235721511, 9.133454987024352, 9.186402995732335, 9.23904756996088, 9.291393867445294, 9.343446901438464, 9.395211546314432, 9.446692542895637, 9.497894503520243, 9.548821916864929, 9.599479152537391, 9.649870465451857, 9.700000000000003, 9.749871794028884, 9.799489782636646, 9.848857801796106, 9.897979591815698], [0.0, 0.9899494936611666, 1.4, 1.7146428199482249, 1.9798989873223332, 2.2135943621178655, 2.4248711305964283, 2.619160170741759, 2.8, 2.9698484809834995, 3.1304951684997055, 3.283291031876401, 3.4292856398964497, 3.5693136595149495, 3.704051835490427, 3.8340579025361623, 3.9597979746446663, 4.08166632639171, 4.2, 4.315089802078284, 4.427188724235731, 4.536518488885503, 4.64327470649756, 4.747630988187688, 4.849742261192857, 4.949747468305833, 5.047771785649585, 5.143928459844674, 5.238320341483518, 5.331041174104736, 5.422176684690383, 5.511805511808268, 5.6, 5.686826883245173, 5.772347875864725, 5.856620185738529, 5.939696961966999, 6.021627686929839, 6.102458520956943, 6.182232606429493, 6.260990336999411, 6.338769596696192, 6.4156059729381765, 6.491532946846992, 6.566582063752802, 6.640783086353596, 6.714164132637808, 6.786751800382861, 6.8585712797928995, 6.929646455628165, 7.0, 7.069653456853455, 7.138627319029899, 7.206941098690901, 7.274613391789285, 7.341661937191061, 7.408103670980854, 7.473954776421918, 7.539230729988306, 7.603946343840151, 7.668115805072325, 7.731752712031082, 7.79487010796203, 7.857480512225277, 7.919595949289333, 7.981227975693965, 8.04238770515324, 8.103085831953157, 8.16333265278342, 8.223138087129511, 8.282511696339462, 8.341462701469089, 8.4, 8.4581321815162, 8.515867542417507, 8.573214099741124, 8.630179604156568, 8.6867715521936, 8.742997197757758, 8.798863562983575, 8.854377448471462, 8.909545442950499, 8.964373932405989, 9.018869108707587, 9.073036977771006, 9.126883367283709, 9.180413934022802, 9.233634170791044, 9.28654941299512, 9.339164844888433, 9.391485505499116, 9.443516294262428, 9.495261976375376, 9.5467271878901, 9.597916440561463, 9.648834126463154, 9.699484522385713, 9.749871794028884, 9.8, 9.849873095629203, 9.899494936611665, 9.948869282486328], [0.0, 0.9949874371066201, 1.407124727947029, 1.7233687939614089, 1.9899748742132402, 2.224859546128699, 2.4372115213907883, 2.632489316217637, 2.814249455894058, 2.98496231131986, 3.146426544510455, 3.3000000000000007, 3.4467375879228177, 3.58747822293042, 3.722902093797257, 3.853569773599539, 3.9799497484264803, 4.102438299353203, 4.221374183841087, 4.337049688440289, 4.449719092257398, 4.559605246071199, 4.666904755831214, 4.77179211617606, 4.874423042781577, 4.974937185533101, 5.073460357586329, 5.170106381884226, 5.264978632435274, 5.358171329847527, 5.449770637375485, 5.539855593785817, 5.628498911788116, 5.715767664977296, 5.801723881744115, 5.886425061104576, 5.96992462263972, 6.052272300549605, 6.133514490078262, 6.213694553162394, 6.29285308902091, 6.3710281744785915, 6.448255578061405, 6.524568951279464, 6.600000000000001, 6.674578638386096, 6.748333127521196, 6.821290200541244, 6.893475175845635, 6.96491205974634, 7.035623639735145, 7.105631569396208, 7.17495644586084, 7.243617880589783, 7.3116345641723655, 7.379024325749307, 7.445804187594514, 7.5119904153293495, 7.577598564189055, 7.642643521714199, 7.707139547199078, 7.771100308193172, 7.834538914320357, 7.897467948652911, 7.959899496852961, 8.021845174272563, 8.083316151184489, 8.144323176298936, 8.204876598706406, 8.264986388373547, 8.324662155306966, 8.383913167489272, 8.442748367682174, 8.501176389182852, 8.559205570612264, 8.616843969807043, 8.674099376880578, 8.73097932651315, 8.787491109526087, 8.843641783790206, 8.899438184514796, 8.95488693395958, 9.009994450608726, 9.064766957842878, 9.119210492142399, 9.173330910852394, 9.22713389953782, 9.280624978954814, 9.333809511662428, 9.38669270829721, 9.439279633531365, 9.491575211733826, 9.54358423235212, 9.595311355031686, 9.646761114488118, 9.697937925146768, 9.748846085563153, 9.799489782636646, 9.849873095629203, 9.900000000000002, 9.949874371066201, 9.999499987499377], [0.0, 1.0, 1.4142135623730951, 1.7320508075688776, 2.0, 2.23606797749979, 2.4494897427831783, 2.6457513110645907, 2.8284271247461903, 3.0, 3.1622776601683795, 3.3166247903554003, 3.4641016151377553, 3.6055512754639896, 3.7416573867739413, 3.8729833462074166, 4.0, 4.123105625617661, 4.242640687119286, 4.358898943540674, 4.47213595499958, 4.582575694955841, 4.69041575982343, 4.79583152331272, 4.898979485566357, 5.000000000000001, 5.099019513592785, 5.196152422706633, 5.291502622129181, 5.385164807134505, 5.477225575051661, 5.567764362830022, 5.656854249492381, 5.7445626465380295, 5.830951894845301, 5.916079783099616, 6.0, 6.08276253029822, 6.164414002968977, 6.244997998398399, 6.324555320336759, 6.403124237432849, 6.480740698407861, 6.557438524302, 6.6332495807108005, 6.7082039324993685, 6.782329983125269, 6.855654600401045, 6.9282032302755105, 7.0, 7.071067811865476, 7.141428428542851, 7.211102550927979, 7.28010988928052, 7.348469228349535, 7.416198487095664, 7.483314773547883, 7.54983443527075, 7.6157731058639095, 7.681145747868608, 7.745966692414833, 7.810249675906655, 7.874007874011811, 7.937253933193772, 8.0, 8.06225774829855, 8.12403840463596, 8.18535277187245, 8.246211251235321, 8.306623862918075, 8.366600265340756, 8.426149773176359, 8.485281374238571, 8.544003745317532, 8.602325267042627, 8.660254037844387, 8.717797887081348, 8.774964387392123, 8.831760866327848, 8.88819441731559, 8.94427190999916, 9.000000000000002, 9.055385138137417, 9.1104335791443, 9.165151389911681, 9.219544457292889, 9.273618495495704, 9.327379053088816, 9.38083151964686, 9.433981132056603, 9.486832980505138, 9.539392014169458, 9.59166304662544, 9.643650760992957, 9.695359714832659, 9.746794344808963, 9.797958971132713, 9.848857801796106, 9.899494936611665, 9.949874371066201, 10.000000000000002, 10.049875621120892], [0.0, 1.0049875621120892, 1.4212670403551897, 1.7406895185529214, 2.0099751242241783, 2.2472205054244236, 2.4617067250182347, 2.6589471600616665, 2.8425340807103794, 3.0149626863362675, 3.178049716414141, 3.333166662499792, 3.481379037105843, 3.6235341863986883, 3.7603191353926335, 3.892300091205713, 4.019950248448357, 4.1436698710201325, 4.263801121065569, 4.380639222761903, 4.494441010848847, 4.605431575867782, 4.713809499757071, 4.819751030914357, 4.9234134500364695, 5.024937810560446, 5.1244511901275835, 5.222068555658764, 5.317894320123333, 5.412023651093924, 5.504543577809154, 5.595533933415113, 5.685068161420759, 5.773214009544425, 5.860034129593445, 5.9455865984779, 6.029925372672535, 6.113100686231171, 6.1951594006934165, 6.276145313805283, 6.356099432828282, 6.435060217278469, 6.5130637951735135, 6.590144156238162, 6.666333324999584, 6.74166151627327, 6.81615727518079, 6.889847603539574, 6.962758074211686, 7.034912934784624, 7.1063352017759485, 7.177046746399247, 7.247068372797377, 7.31641988953614, 7.385120175054704, 7.4531872376856345, 7.520638270785267, 7.587489703452652, 7.653757247260983, 7.719455939378112, 7.784600182411426, 7.849203781276163, 7.913279977354524, 7.976841480185, 8.039900496896713, 8.10246875958186, 8.16455755078008, 8.226177727231525, 8.287339742040265, 8.34805366537614, 8.408329203831164, 8.468175718535841, 8.527602242131138, 8.586617494683225, 8.645229898620395, 8.703447592764606, 8.761278445523805, 8.81873006730561, 8.875809822207776, 8.932524839036274, 8.988882021697695, 9.044888059008803, 9.100549433962767, 9.155872432488342, 9.210863151735564, 9.265527507918803, 9.319871243745807, 9.373899935459095, 9.427618999514142, 9.481033698917013, 9.534149149242424, 9.586970324351693, 9.639502061828715, 9.691749068150704, 9.743715923609434, 9.795407086997457, 9.846826900072939, 9.897979591815698, 9.948869282486328, 9.999499987499377, 10.049875621120892, 10.100000000000001]]}],\n",
       "                        {\"autosize\": false, \"height\": 500, \"margin\": {\"b\": 65, \"l\": 65, \"r\": 50, \"t\": 90}, \"scene\": {\"xaxis\": {\"title\": {\"text\": \"K\"}}, \"yaxis\": {\"title\": {\"text\": \"L\"}}, \"zaxis\": {\"title\": {\"text\": \"Y\"}}}, \"template\": {\"data\": {\"bar\": [{\"error_x\": {\"color\": \"#2a3f5f\"}, \"error_y\": {\"color\": \"#2a3f5f\"}, \"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"bar\"}], \"barpolar\": [{\"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"barpolar\"}], \"carpet\": [{\"aaxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"baxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"type\": \"carpet\"}], \"choropleth\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"choropleth\"}], \"contour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"contour\"}], \"contourcarpet\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"contourcarpet\"}], \"heatmap\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmap\"}], \"heatmapgl\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmapgl\"}], \"histogram\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"histogram\"}], \"histogram2d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2d\"}], \"histogram2dcontour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2dcontour\"}], \"mesh3d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"mesh3d\"}], \"parcoords\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"parcoords\"}], \"scatter\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter\"}], \"scatter3d\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter3d\"}], \"scattercarpet\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattercarpet\"}], \"scattergeo\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergeo\"}], \"scattergl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergl\"}], \"scattermapbox\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattermapbox\"}], \"scatterpolar\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolar\"}], \"scatterpolargl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolargl\"}], \"scatterternary\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterternary\"}], \"surface\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"surface\"}], \"table\": [{\"cells\": {\"fill\": {\"color\": \"#EBF0F8\"}, \"line\": {\"color\": \"white\"}}, \"header\": {\"fill\": {\"color\": \"#C8D4E3\"}, \"line\": {\"color\": \"white\"}}, \"type\": \"table\"}]}, \"layout\": {\"annotationdefaults\": {\"arrowcolor\": \"#2a3f5f\", \"arrowhead\": 0, \"arrowwidth\": 1}, \"colorscale\": {\"diverging\": [[0, \"#8e0152\"], [0.1, \"#c51b7d\"], [0.2, \"#de77ae\"], [0.3, \"#f1b6da\"], [0.4, \"#fde0ef\"], [0.5, \"#f7f7f7\"], [0.6, \"#e6f5d0\"], [0.7, \"#b8e186\"], [0.8, \"#7fbc41\"], [0.9, \"#4d9221\"], [1, \"#276419\"]], \"sequential\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"sequentialminus\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]]}, \"colorway\": [\"#636efa\", \"#EF553B\", \"#00cc96\", \"#ab63fa\", \"#FFA15A\", \"#19d3f3\", \"#FF6692\", \"#B6E880\", \"#FF97FF\", \"#FECB52\"], \"font\": {\"color\": \"#2a3f5f\"}, \"geo\": {\"bgcolor\": \"white\", \"lakecolor\": \"white\", \"landcolor\": \"#E5ECF6\", \"showlakes\": true, \"showland\": true, \"subunitcolor\": \"white\"}, \"hoverlabel\": {\"align\": \"left\"}, \"hovermode\": \"closest\", \"mapbox\": {\"style\": \"light\"}, \"paper_bgcolor\": \"white\", \"plot_bgcolor\": \"#E5ECF6\", \"polar\": {\"angularaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"radialaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"scene\": {\"xaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"yaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"zaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}}, \"shapedefaults\": {\"line\": {\"color\": \"#2a3f5f\"}}, \"ternary\": {\"aaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"baxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"caxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"title\": {\"x\": 0.05}, \"xaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}, \"yaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}}}, \"title\": {\"text\": \"Cobb-Douglas Production Function\"}, \"width\": 500},\n",
       "                        {\"responsive\": true}\n",
       "                    )\n",
       "                };\n",
       "                \n",
       "            </script>\n",
       "        </div>\n",
       "</body>\n",
       "</html>"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "change_A(2, filename=\"fig1.html\")\n",
    "display(HTML(\"fig1.html\"))"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Supply or total factor productivity shocks could cause $A$ to change. These occur if there is a change in total output for a given level of capital and labor. Examples of these include financial crises, technology shocks, natural environment/distasters and energy prices."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 15,
   "metadata": {
    "tags": [
     "remove_input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<html>\n",
       "<head><meta charset=\"utf-8\" /></head>\n",
       "<body>\n",
       "    <div>\n",
       "            <script src=\"https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.5/MathJax.js?config=TeX-AMS-MML_SVG\"></script><script type=\"text/javascript\">if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}</script>\n",
       "                <script type=\"text/javascript\">window.PlotlyConfig = {MathJaxConfig: 'local'};</script>\n",
       "        <script type=\"text/javascript\">/**\n",
       "* plotly.js v1.49.1\n",
       "* Copyright 2012-2019, Plotly, Inc.\n",
       "* All rights reserved.\n",
       "* Licensed under the MIT license\n",
       "*/\n",
       "!function(t){if(\"object\"==typeof exports&&\"undefined\"!=typeof module)module.exports=t();else if(\"function\"==typeof define&&define.amd)define([],t);else{(\"undefined\"!=typeof window?window:\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:this).Plotly=t()}}(function(){return function(){return function t(e,r,n){function i(o,s){if(!r[o]){if(!e[o]){var l=\"function\"==typeof require&&require;if(!s&&l)return l(o,!0);if(a)return a(o,!0);var c=new Error(\"Cannot find module '\"+o+\"'\");throw c.code=\"MODULE_NOT_FOUND\",c}var u=r[o]={exports:{}};e[o][0].call(u.exports,function(t){return i(e[o][1][t]||t)},u,u.exports,t,e,r,n)}return r[o].exports}for(var a=\"function\"==typeof require&&require,o=0;o<n.length;o++)i(n[o]);return i}}()({1:[function(t,e,r){\"use strict\";var n=t(\"../src/lib\"),i={\"X,X div\":\"direction:ltr;font-family:'Open Sans', verdana, arial, sans-serif;margin:0;padding:0;\",\"X input,X button\":\"font-family:'Open Sans', verdana, arial, sans-serif;\",\"X input:focus,X button:focus\":\"outline:none;\",\"X a\":\"text-decoration:none;\",\"X a:hover\":\"text-decoration:none;\",\"X .crisp\":\"shape-rendering:crispEdges;\",\"X .user-select-none\":\"-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;\",\"X svg\":\"overflow:hidden;\",\"X svg a\":\"fill:#447adb;\",\"X svg a:hover\":\"fill:#3c6dc5;\",\"X .main-svg\":\"position:absolute;top:0;left:0;pointer-events:none;\",\"X .main-svg .draglayer\":\"pointer-events:all;\",\"X .cursor-default\":\"cursor:default;\",\"X .cursor-pointer\":\"cursor:pointer;\",\"X .cursor-crosshair\":\"cursor:crosshair;\",\"X .cursor-move\":\"cursor:move;\",\"X .cursor-col-resize\":\"cursor:col-resize;\",\"X .cursor-row-resize\":\"cursor:row-resize;\",\"X .cursor-ns-resize\":\"cursor:ns-resize;\",\"X .cursor-ew-resize\":\"cursor:ew-resize;\",\"X .cursor-sw-resize\":\"cursor:sw-resize;\",\"X .cursor-s-resize\":\"cursor:s-resize;\",\"X .cursor-se-resize\":\"cursor:se-resize;\",\"X .cursor-w-resize\":\"cursor:w-resize;\",\"X .cursor-e-resize\":\"cursor:e-resize;\",\"X .cursor-nw-resize\":\"cursor:nw-resize;\",\"X .cursor-n-resize\":\"cursor:n-resize;\",\"X .cursor-ne-resize\":\"cursor:ne-resize;\",\"X .cursor-grab\":\"cursor:-webkit-grab;cursor:grab;\",\"X .modebar\":\"position:absolute;top:2px;right:2px;\",\"X .ease-bg\":\"-webkit-transition:background-color 0.3s ease 0s;-moz-transition:background-color 0.3s ease 0s;-ms-transition:background-color 0.3s ease 0s;-o-transition:background-color 0.3s ease 0s;transition:background-color 0.3s ease 0s;\",\"X .modebar--hover>:not(.watermark)\":\"opacity:0;-webkit-transition:opacity 0.3s ease 0s;-moz-transition:opacity 0.3s ease 0s;-ms-transition:opacity 0.3s ease 0s;-o-transition:opacity 0.3s ease 0s;transition:opacity 0.3s ease 0s;\",\"X:hover .modebar--hover .modebar-group\":\"opacity:1;\",\"X .modebar-group\":\"float:left;display:inline-block;box-sizing:border-box;padding-left:8px;position:relative;vertical-align:middle;white-space:nowrap;\",\"X .modebar-btn\":\"position:relative;font-size:16px;padding:3px 4px;height:22px;cursor:pointer;line-height:normal;box-sizing:border-box;\",\"X .modebar-btn svg\":\"position:relative;top:2px;\",\"X .modebar.vertical\":\"display:flex;flex-direction:column;flex-wrap:wrap;align-content:flex-end;max-height:100%;\",\"X .modebar.vertical svg\":\"top:-1px;\",\"X .modebar.vertical .modebar-group\":\"display:block;float:none;padding-left:0px;padding-bottom:8px;\",\"X .modebar.vertical .modebar-group .modebar-btn\":\"display:block;text-align:center;\",\"X [data-title]:before,X [data-title]:after\":\"position:absolute;-webkit-transform:translate3d(0, 0, 0);-moz-transform:translate3d(0, 0, 0);-ms-transform:translate3d(0, 0, 0);-o-transform:translate3d(0, 0, 0);transform:translate3d(0, 0, 0);display:none;opacity:0;z-index:1001;pointer-events:none;top:110%;right:50%;\",\"X [data-title]:hover:before,X [data-title]:hover:after\":\"display:block;opacity:1;\",\"X [data-title]:before\":\"content:'';position:absolute;background:transparent;border:6px solid transparent;z-index:1002;margin-top:-12px;border-bottom-color:#69738a;margin-right:-6px;\",\"X [data-title]:after\":\"content:attr(data-title);background:#69738a;color:white;padding:8px 10px;font-size:12px;line-height:12px;white-space:nowrap;margin-right:-18px;border-radius:2px;\",\"X .vertical [data-title]:before,X .vertical [data-title]:after\":\"top:0%;right:200%;\",\"X .vertical [data-title]:before\":\"border:6px solid transparent;border-left-color:#69738a;margin-top:8px;margin-right:-30px;\",\"X .select-outline\":\"fill:none;stroke-width:1;shape-rendering:crispEdges;\",\"X .select-outline-1\":\"stroke:white;\",\"X .select-outline-2\":\"stroke:black;stroke-dasharray:2px 2px;\",Y:\"font-family:'Open Sans';position:fixed;top:50px;right:20px;z-index:10000;font-size:10pt;max-width:180px;\",\"Y p\":\"margin:0;\",\"Y .notifier-note\":\"min-width:180px;max-width:250px;border:1px solid #fff;z-index:3000;margin:0;background-color:#8c97af;background-color:rgba(140,151,175,0.9);color:#fff;padding:10px;overflow-wrap:break-word;word-wrap:break-word;-ms-hyphens:auto;-webkit-hyphens:auto;hyphens:auto;\",\"Y .notifier-close\":\"color:#fff;opacity:0.8;float:right;padding:0 5px;background:none;border:none;font-size:20px;font-weight:bold;line-height:20px;\",\"Y .notifier-close:hover\":\"color:#444;text-decoration:none;cursor:pointer;\"};for(var a in i){var o=a.replace(/^,/,\" ,\").replace(/X/g,\".js-plotly-plot .plotly\").replace(/Y/g,\".plotly-notifier\");n.addStyleRule(o,i[a])}},{\"../src/lib\":719}],2:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/aggregate\")},{\"../src/transforms/aggregate\":1265}],3:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/bar\")},{\"../src/traces/bar\":864}],4:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/barpolar\")},{\"../src/traces/barpolar\":876}],5:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/box\")},{\"../src/traces/box\":886}],6:[function(t,e,r){\"use strict\";e.exports=t(\"../src/components/calendars\")},{\"../src/components/calendars\":591}],7:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/candlestick\")},{\"../src/traces/candlestick\":895}],8:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/carpet\")},{\"../src/traces/carpet\":914}],9:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choropleth\")},{\"../src/traces/choropleth\":928}],10:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choroplethmapbox\")},{\"../src/traces/choroplethmapbox\":935}],11:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/cone\")},{\"../src/traces/cone\":941}],12:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contour\")},{\"../src/traces/contour\":956}],13:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contourcarpet\")},{\"../src/traces/contourcarpet\":967}],14:[function(t,e,r){\"use strict\";e.exports=t(\"../src/core\")},{\"../src/core\":697}],15:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/densitymapbox\")},{\"../src/traces/densitymapbox\":977}],16:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/filter\")},{\"../src/transforms/filter\":1266}],17:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnel\")},{\"../src/traces/funnel\":987}],18:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnelarea\")},{\"../src/traces/funnelarea\":996}],19:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/groupby\")},{\"../src/transforms/groupby\":1267}],20:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmap\")},{\"../src/traces/heatmap\":1009}],21:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmapgl\")},{\"../src/traces/heatmapgl\":1018}],22:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram\")},{\"../src/traces/histogram\":1030}],23:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2d\")},{\"../src/traces/histogram2d\":1036}],24:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2dcontour\")},{\"../src/traces/histogram2dcontour\":1040}],25:[function(t,e,r){\"use strict\";var n=t(\"./core\");n.register([t(\"./bar\"),t(\"./box\"),t(\"./heatmap\"),t(\"./histogram\"),t(\"./histogram2d\"),t(\"./histogram2dcontour\"),t(\"./contour\"),t(\"./scatterternary\"),t(\"./violin\"),t(\"./funnel\"),t(\"./waterfall\"),t(\"./pie\"),t(\"./sunburst\"),t(\"./funnelarea\"),t(\"./scatter3d\"),t(\"./surface\"),t(\"./isosurface\"),t(\"./volume\"),t(\"./mesh3d\"),t(\"./cone\"),t(\"./streamtube\"),t(\"./scattergeo\"),t(\"./choropleth\"),t(\"./scattergl\"),t(\"./splom\"),t(\"./pointcloud\"),t(\"./heatmapgl\"),t(\"./parcoords\"),t(\"./parcats\"),t(\"./scattermapbox\"),t(\"./choroplethmapbox\"),t(\"./densitymapbox\"),t(\"./sankey\"),t(\"./indicator\"),t(\"./table\"),t(\"./carpet\"),t(\"./scattercarpet\"),t(\"./contourcarpet\"),t(\"./ohlc\"),t(\"./candlestick\"),t(\"./scatterpolar\"),t(\"./scatterpolargl\"),t(\"./barpolar\")]),n.register([t(\"./aggregate\"),t(\"./filter\"),t(\"./groupby\"),t(\"./sort\")]),n.register([t(\"./calendars\")]),e.exports=n},{\"./aggregate\":2,\"./bar\":3,\"./barpolar\":4,\"./box\":5,\"./calendars\":6,\"./candlestick\":7,\"./carpet\":8,\"./choropleth\":9,\"./choroplethmapbox\":10,\"./cone\":11,\"./contour\":12,\"./contourcarpet\":13,\"./core\":14,\"./densitymapbox\":15,\"./filter\":16,\"./funnel\":17,\"./funnelarea\":18,\"./groupby\":19,\"./heatmap\":20,\"./heatmapgl\":21,\"./histogram\":22,\"./histogram2d\":23,\"./histogram2dcontour\":24,\"./indicator\":26,\"./isosurface\":27,\"./mesh3d\":28,\"./ohlc\":29,\"./parcats\":30,\"./parcoords\":31,\"./pie\":32,\"./pointcloud\":33,\"./sankey\":34,\"./scatter3d\":35,\"./scattercarpet\":36,\"./scattergeo\":37,\"./scattergl\":38,\"./scattermapbox\":39,\"./scatterpolar\":40,\"./scatterpolargl\":41,\"./scatterternary\":42,\"./sort\":43,\"./splom\":44,\"./streamtube\":45,\"./sunburst\":46,\"./surface\":47,\"./table\":48,\"./violin\":49,\"./volume\":50,\"./waterfall\":51}],26:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/indicator\")},{\"../src/traces/indicator\":1046}],27:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/isosurface\")},{\"../src/traces/isosurface\":1052}],28:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/mesh3d\")},{\"../src/traces/mesh3d\":1057}],29:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/ohlc\")},{\"../src/traces/ohlc\":1062}],30:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcats\")},{\"../src/traces/parcats\":1071}],31:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcoords\")},{\"../src/traces/parcoords\":1081}],32:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pie\")},{\"../src/traces/pie\":1092}],33:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pointcloud\")},{\"../src/traces/pointcloud\":1101}],34:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sankey\")},{\"../src/traces/sankey\":1107}],35:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatter3d\")},{\"../src/traces/scatter3d\":1143}],36:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattercarpet\")},{\"../src/traces/scattercarpet\":1149}],37:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergeo\")},{\"../src/traces/scattergeo\":1156}],38:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergl\")},{\"../src/traces/scattergl\":1167}],39:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattermapbox\")},{\"../src/traces/scattermapbox\":1176}],40:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolar\")},{\"../src/traces/scatterpolar\":1183}],41:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolargl\")},{\"../src/traces/scatterpolargl\":1189}],42:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterternary\")},{\"../src/traces/scatterternary\":1196}],43:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/sort\")},{\"../src/transforms/sort\":1269}],44:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/splom\")},{\"../src/traces/splom\":1205}],45:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/streamtube\")},{\"../src/traces/streamtube\":1213}],46:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sunburst\")},{\"../src/traces/sunburst\":1219}],47:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/surface\")},{\"../src/traces/surface\":1228}],48:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/table\")},{\"../src/traces/table\":1236}],49:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/violin\")},{\"../src/traces/violin\":1244}],50:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/volume\")},{\"../src/traces/volume\":1252}],51:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/waterfall\")},{\"../src/traces/waterfall\":1260}],52:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).eye||[0,0,1],r=t.center||[0,0,0],s=t.up||[0,1,0],l=t.distanceLimits||[0,1/0],c=t.mode||\"turntable\",u=n(),h=i(),f=a();return u.setDistanceLimits(l[0],l[1]),u.lookAt(0,e,r,s),h.setDistanceLimits(l[0],l[1]),h.lookAt(0,e,r,s),f.setDistanceLimits(l[0],l[1]),f.lookAt(0,e,r,s),new o({turntable:u,orbit:h,matrix:f},c)};var n=t(\"turntable-camera-controller\"),i=t(\"orbit-camera-controller\"),a=t(\"matrix-camera-controller\");function o(t,e){this._controllerNames=Object.keys(t),this._controllerList=this._controllerNames.map(function(e){return t[e]}),this._mode=e,this._active=t[e],this._active||(this._mode=\"turntable\",this._active=t.turntable),this.modes=this._controllerNames,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}var s=o.prototype;[[\"flush\",1],[\"idle\",1],[\"lookAt\",4],[\"rotate\",4],[\"pan\",4],[\"translate\",4],[\"setMatrix\",2],[\"setDistanceLimits\",2],[\"setDistance\",2]].forEach(function(t){for(var e=t[0],r=[],n=0;n<t[1];++n)r.push(\"a\"+n);var i=\"var cc=this._controllerList;for(var i=0;i<cc.length;++i){cc[i].\"+t[0]+\"(\"+r.join()+\")}\";s[e]=Function.apply(null,r.concat(i))}),s.recalcMatrix=function(t){this._active.recalcMatrix(t)},s.getDistance=function(t){return this._active.getDistance(t)},s.getDistanceLimits=function(t){return this._active.getDistanceLimits(t)},s.lastT=function(){return this._active.lastT()},s.setMode=function(t){if(t!==this._mode){var e=this._controllerNames.indexOf(t);if(!(e<0)){var r=this._active,n=this._controllerList[e],i=Math.max(r.lastT(),n.lastT());r.recalcMatrix(i),n.setMatrix(i,r.computedMatrix),this._active=n,this._mode=t,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}}},s.getMode=function(){return this._mode}},{\"matrix-camera-controller\":433,\"orbit-camera-controller\":456,\"turntable-camera-controller\":542}],53:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n,i){\"use strict\";function a(t){return t.target.depth}function o(t,e){return t.sourceLinks.length?t.depth:e-1}function s(t){return function(){return t}}i=i&&i.hasOwnProperty(\"default\")?i.default:i;var l=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&\"function\"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?\"symbol\":typeof t};function c(t,e){return h(t.source,e.source)||t.index-e.index}function u(t,e){return h(t.target,e.target)||t.index-e.index}function h(t,e){return t.partOfCycle===e.partOfCycle?t.y0-e.y0:\"top\"===t.circularLinkType||\"bottom\"===e.circularLinkType?-1:1}function f(t){return t.value}function p(t){return(t.y0+t.y1)/2}function d(t){return p(t.source)}function g(t){return p(t.target)}function v(t){return t.index}function m(t){return t.nodes}function y(t){return t.links}function x(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function b(t,e){return e(t)}var _=25,w=10,k=.3;function T(t,e){var r=0,n=0;t.links.forEach(function(i){i.circular&&(i.source.circularLinkType||i.target.circularLinkType?i.circularLinkType=i.source.circularLinkType?i.source.circularLinkType:i.target.circularLinkType:i.circularLinkType=r<n?\"top\":\"bottom\",\"top\"==i.circularLinkType?r+=1:n+=1,t.nodes.forEach(function(t){b(t,e)!=b(i.source,e)&&b(t,e)!=b(i.target,e)||(t.circularLinkType=i.circularLinkType)}))}),t.links.forEach(function(t){t.circular&&(t.source.circularLinkType==t.target.circularLinkType&&(t.circularLinkType=t.source.circularLinkType),Y(t,e)&&(t.circularLinkType=t.source.circularLinkType))})}function A(t){var e=Math.abs(t.y1-t.y0),r=Math.abs(t.target.x0-t.source.x1);return Math.atan(r/e)}function M(t,e){var r=0;t.sourceLinks.forEach(function(t){r=t.circular&&!Y(t,e)?r+1:r});var n=0;return t.targetLinks.forEach(function(t){n=t.circular&&!Y(t,e)?n+1:n}),r+n}function S(t){var e=t.source.sourceLinks,r=0;e.forEach(function(t){r=t.circular?r+1:r});var n=t.target.targetLinks,i=0;return n.forEach(function(t){i=t.circular?i+1:i}),!(r>1||i>1)}function E(t,e,r){return t.sort(L),t.forEach(function(n,i){var a,o,s=0;if(Y(n,r)&&S(n))n.circularPathData.verticalBuffer=s+n.width/2;else{for(var l=0;l<i;l++)if(a=t[i],o=t[l],!(a.source.column<o.target.column||a.target.column>o.source.column)){var c=t[l].circularPathData.verticalBuffer+t[l].width/2+e;s=c>s?c:s}n.circularPathData.verticalBuffer=s+n.width/2}}),t}function C(t,r,i,a){var o=e.min(t.links,function(t){return t.source.y0});t.links.forEach(function(t){t.circular&&(t.circularPathData={})}),E(t.links.filter(function(t){return\"top\"==t.circularLinkType}),r,a),E(t.links.filter(function(t){return\"bottom\"==t.circularLinkType}),r,a),t.links.forEach(function(e){if(e.circular){if(e.circularPathData.arcRadius=e.width+w,e.circularPathData.leftNodeBuffer=5,e.circularPathData.rightNodeBuffer=5,e.circularPathData.sourceWidth=e.source.x1-e.source.x0,e.circularPathData.sourceX=e.source.x0+e.circularPathData.sourceWidth,e.circularPathData.targetX=e.target.x0,e.circularPathData.sourceY=e.y0,e.circularPathData.targetY=e.y1,Y(e,a)&&S(e))e.circularPathData.leftSmallArcRadius=w+e.width/2,e.circularPathData.leftLargeArcRadius=w+e.width/2,e.circularPathData.rightSmallArcRadius=w+e.width/2,e.circularPathData.rightLargeArcRadius=w+e.width/2,\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=e.source.y1+_+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=e.source.y0-_-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius);else{var s=e.source.column,l=e.circularLinkType,c=t.links.filter(function(t){return t.source.column==s&&t.circularLinkType==l});\"bottom\"==e.circularLinkType?c.sort(O):c.sort(P);var u=0;c.forEach(function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.leftSmallArcRadius=w+e.width/2+u,e.circularPathData.leftLargeArcRadius=w+e.width/2+n*r+u),u+=t.width}),s=e.target.column,c=t.links.filter(function(t){return t.target.column==s&&t.circularLinkType==l}),\"bottom\"==e.circularLinkType?c.sort(I):c.sort(z),u=0,c.forEach(function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.rightSmallArcRadius=w+e.width/2+u,e.circularPathData.rightLargeArcRadius=w+e.width/2+n*r+u),u+=t.width}),\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=Math.max(i,e.source.y1,e.target.y1)+_+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=o-_-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius)}e.circularPathData.leftInnerExtent=e.circularPathData.sourceX+e.circularPathData.leftNodeBuffer,e.circularPathData.rightInnerExtent=e.circularPathData.targetX-e.circularPathData.rightNodeBuffer,e.circularPathData.leftFullExtent=e.circularPathData.sourceX+e.circularPathData.leftLargeArcRadius+e.circularPathData.leftNodeBuffer,e.circularPathData.rightFullExtent=e.circularPathData.targetX-e.circularPathData.rightLargeArcRadius-e.circularPathData.rightNodeBuffer}if(e.circular)e.path=function(t){var e=\"\";e=\"top\"==t.circularLinkType?\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 0 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY-t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 0 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 0 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY-t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 0 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY:\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 1 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY+t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 1 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 1 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY+t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 1 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY;return e}(e);else{var h=n.linkHorizontal().source(function(t){return[t.source.x0+(t.source.x1-t.source.x0),t.y0]}).target(function(t){return[t.target.x0,t.y1]});e.path=h(e)}})}function L(t,e){return D(t)==D(e)?\"bottom\"==t.circularLinkType?O(t,e):P(t,e):D(e)-D(t)}function P(t,e){return t.y0-e.y0}function O(t,e){return e.y0-t.y0}function z(t,e){return t.y1-e.y1}function I(t,e){return e.y1-t.y1}function D(t){return t.target.column-t.source.column}function R(t){return t.target.x0-t.source.x1}function F(t,e){var r=A(t),n=R(e)/Math.tan(r);return\"up\"==G(t)?t.y1+n:t.y1-n}function B(t,e){var r=A(t),n=R(e)/Math.tan(r);return\"up\"==G(t)?t.y1-n:t.y1+n}function N(t,e,r,n){t.links.forEach(function(i){if(!i.circular&&i.target.column-i.source.column>1){var a=i.source.column+1,o=i.target.column-1,s=1,l=o-a+1;for(s=1;a<=o;a++,s++)t.nodes.forEach(function(o){if(o.column==a){var c,u=s/(l+1),h=Math.pow(1-u,3),f=3*u*Math.pow(1-u,2),p=3*Math.pow(u,2)*(1-u),d=Math.pow(u,3),g=h*i.y0+f*i.y0+p*i.y1+d*i.y1,v=g-i.width/2,m=g+i.width/2;v>o.y0&&v<o.y1?(c=o.y1-v+10,c=\"bottom\"==o.circularLinkType?c:-c,o=U(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&j(o,t)&&U(t,c,e,r)})):m>o.y0&&m<o.y1?(c=m-o.y0+10,o=U(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&U(t,c,e,r)})):v<o.y0&&m>o.y1&&(c=m-o.y0+10,o=U(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&U(t,c,e,r)}))}})}})}function j(t,e){return t.y0>e.y0&&t.y0<e.y1||(t.y1>e.y0&&t.y1<e.y1||t.y0<e.y0&&t.y1>e.y1)}function U(t,e,r,n){return t.y0+e>=r&&t.y1+e<=n&&(t.y0=t.y0+e,t.y1=t.y1+e,t.targetLinks.forEach(function(t){t.y1=t.y1+e}),t.sourceLinks.forEach(function(t){t.y0=t.y0+e})),t}function V(t,e,r,n){t.nodes.forEach(function(i){n&&i.y+(i.y1-i.y0)>e&&(i.y=i.y-(i.y+(i.y1-i.y0)-e));var a=t.links.filter(function(t){return b(t.source,r)==b(i,r)}),o=a.length;o>1&&a.sort(function(t,e){if(!t.circular&&!e.circular){if(t.target.column==e.target.column)return t.y1-e.y1;if(!H(t,e))return t.y1-e.y1;if(t.target.column>e.target.column){var r=B(e,t);return t.y1-r}if(e.target.column>t.target.column)return B(t,e)-e.y1}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.target.column===e.target.column?t.target.y1-e.target.y1:e.target.column-t.target.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.target.column===e.target.column?e.target.y1-t.target.y1:t.target.column-e.target.column:\"top\"==t.circularLinkType?-1:1:void 0});var s=i.y0;a.forEach(function(t){t.y0=s+t.width/2,s+=t.width}),a.forEach(function(t,e){if(\"bottom\"==t.circularLinkType){for(var r=e+1,n=0;r<o;r++)n+=a[r].width;t.y0=i.y1-n-t.width/2}})})}function q(t,e,r){t.nodes.forEach(function(e){var n=t.links.filter(function(t){return b(t.target,r)==b(e,r)}),i=n.length;i>1&&n.sort(function(t,e){if(!t.circular&&!e.circular){if(t.source.column==e.source.column)return t.y0-e.y0;if(!H(t,e))return t.y0-e.y0;if(e.source.column<t.source.column){var r=F(e,t);return t.y0-r}if(t.source.column<e.source.column)return F(t,e)-e.y0}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:t.source.column-e.source.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:e.source.column-t.source.column:\"top\"==t.circularLinkType?-1:1:void 0});var a=e.y0;n.forEach(function(t){t.y1=a+t.width/2,a+=t.width}),n.forEach(function(t,r){if(\"bottom\"==t.circularLinkType){for(var a=r+1,o=0;a<i;a++)o+=n[a].width;t.y1=e.y1-o-t.width/2}})})}function H(t,e){return G(t)==G(e)}function G(t){return t.y0-t.y1>0?\"up\":\"down\"}function Y(t,e){return b(t.source,e)==b(t.target,e)}t.sankeyCircular=function(){var t,n,a=0,b=0,A=1,S=1,E=24,L=v,P=o,O=m,z=y,I=32,D=2,R=null;function F(){var o={nodes:O.apply(null,arguments),links:z.apply(null,arguments)};!function(t){t.nodes.forEach(function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]});var e=r.map(t.nodes,L);t.links.forEach(function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!==(\"undefined\"==typeof n?\"undefined\":l(n))&&(n=t.source=x(e,n)),\"object\"!==(\"undefined\"==typeof i?\"undefined\":l(i))&&(i=t.target=x(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)})}(o),function(t,e,r){var n=0;if(null===r){for(var a=[],o=0;o<t.links.length;o++){var s=t.links[o],l=s.source.index,c=s.target.index;a[l]||(a[l]=[]),a[c]||(a[c]=[]),-1===a[l].indexOf(c)&&a[l].push(c)}var u=i(a);u.sort(function(t,e){return t.length-e.length});var h={};for(o=0;o<u.length;o++){var f=u[o],p=f.slice(-2);h[p[0]]||(h[p[0]]={}),h[p[0]][p[1]]=!0}t.links.forEach(function(t){var e=t.target.index,r=t.source.index;e===r||h[r]&&h[r][e]?(t.circular=!0,t.circularLinkID=n,n+=1):t.circular=!1})}else t.links.forEach(function(t){t.source[r]<t.target[r]?t.circular=!1:(t.circular=!0,t.circularLinkID=n,n+=1)})}(o,0,R),function(t){t.nodes.forEach(function(t){t.partOfCycle=!1,t.value=Math.max(e.sum(t.sourceLinks,f),e.sum(t.targetLinks,f)),t.sourceLinks.forEach(function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)}),t.targetLinks.forEach(function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)})})}(o),function(t){var e,r,n;for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach(function(t){t.depth=n,t.sourceLinks.forEach(function(t){r.indexOf(t.target)<0&&!t.circular&&r.push(t.target)})});for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach(function(t){t.height=n,t.targetLinks.forEach(function(t){r.indexOf(t.source)<0&&!t.circular&&r.push(t.source)})});t.nodes.forEach(function(t){t.column=Math.floor(P.call(null,t,n))})}(o),T(o,L),function(i,o,s){var l=r.nest().key(function(t){return t.column}).sortKeys(e.ascending).entries(i.nodes).map(function(t){return t.values});(function(r){if(n){var o=1/0;l.forEach(function(t){var e=S*n/(t.length+1);o=e<o?e:o}),t=o}var s=e.min(l,function(r){return(S-b-(r.length-1)*t)/e.sum(r,f)});s*=k,i.links.forEach(function(t){t.width=t.value*s});var c=function(t){var r=0,n=0,i=0,a=0,o=e.max(t.nodes,function(t){return t.column});return t.links.forEach(function(t){t.circular&&(\"top\"==t.circularLinkType?r+=t.width:n+=t.width,0==t.target.column&&(a+=t.width),t.source.column==o&&(i+=t.width))}),{top:r=r>0?r+_+w:r,bottom:n=n>0?n+_+w:n,left:a=a>0?a+_+w:a,right:i=i>0?i+_+w:i}}(i),u=function(t,r){var n=e.max(t.nodes,function(t){return t.column}),i=A-a,o=S-b,s=i+r.right+r.left,l=o+r.top+r.bottom,c=i/s,u=o/l;return a=a*c+r.left,A=0==r.right?A:A*c,b=b*u+r.top,S*=u,t.nodes.forEach(function(t){t.x0=a+t.column*((A-a-E)/n),t.x1=t.x0+E}),u}(i,c);s*=u,i.links.forEach(function(t){t.width=t.value*s}),l.forEach(function(t){var e=t.length;t.forEach(function(t,n){t.depth==l.length-1&&1==e?(t.y0=S/2-t.value*s,t.y1=t.y0+t.value*s):0==t.depth&&1==e?(t.y0=S/2-t.value*s,t.y1=t.y0+t.value*s):t.partOfCycle?0==M(t,r)?(t.y0=S/2+n,t.y1=t.y0+t.value*s):\"top\"==t.circularLinkType?(t.y0=b+n,t.y1=t.y0+t.value*s):(t.y0=S-t.value*s-n,t.y1=t.y0+t.value*s):0==c.top||0==c.bottom?(t.y0=(S-b)/e*n,t.y1=t.y0+t.value*s):(t.y0=(S-b)/2-e/2+n,t.y1=t.y0+t.value*s)})})})(s),m();for(var c=1,u=o;u>0;--u)v(c*=.99,s),m();function v(t,r){var n=l.length;l.forEach(function(i){var a=i.length,o=i[0].depth;i.forEach(function(i){var s;if(i.sourceLinks.length||i.targetLinks.length)if(i.partOfCycle&&M(i,r)>0);else if(0==o&&1==a)s=i.y1-i.y0,i.y0=S/2-s/2,i.y1=S/2+s/2;else if(o==n-1&&1==a)s=i.y1-i.y0,i.y0=S/2-s/2,i.y1=S/2+s/2;else{var l=e.mean(i.sourceLinks,g),c=e.mean(i.targetLinks,d),u=((l&&c?(l+c)/2:l||c)-p(i))*t;i.y0+=u,i.y1+=u}})})}function m(){l.forEach(function(e){var r,n,i,a=b,o=e.length;for(e.sort(h),i=0;i<o;++i)r=e[i],(n=a-r.y0)>0&&(r.y0+=n,r.y1+=n),a=r.y1+t;if((n=a-t-S)>0)for(a=r.y0-=n,r.y1-=n,i=o-2;i>=0;--i)r=e[i],(n=r.y1+t-a)>0&&(r.y0-=n,r.y1-=n),a=r.y0})}}(o,I,L),B(o);for(var s=0;s<4;s++)V(o,S,L),q(o,0,L),N(o,b,S,L),V(o,S,L),q(o,0,L);return function(t,r,n){var i=t.nodes,a=t.links,o=!1,s=!1;if(a.forEach(function(t){\"top\"==t.circularLinkType?o=!0:\"bottom\"==t.circularLinkType&&(s=!0)}),0==o||0==s){var l=e.min(i,function(t){return t.y0}),c=e.max(i,function(t){return t.y1}),u=c-l,h=n-r,f=h/u;i.forEach(function(t){var e=(t.y1-t.y0)*f;t.y0=(t.y0-l)*f,t.y1=t.y0+e}),a.forEach(function(t){t.y0=(t.y0-l)*f,t.y1=(t.y1-l)*f,t.width=t.width*f})}}(o,b,S),C(o,D,S,L),o}function B(t){t.nodes.forEach(function(t){t.sourceLinks.sort(u),t.targetLinks.sort(c)}),t.nodes.forEach(function(t){var e=t.y0,r=e,n=t.y1,i=n;t.sourceLinks.forEach(function(t){t.circular?(t.y0=n-t.width/2,n-=t.width):(t.y0=e+t.width/2,e+=t.width)}),t.targetLinks.forEach(function(t){t.circular?(t.y1=i-t.width/2,i-=t.width):(t.y1=r+t.width/2,r+=t.width)})})}return F.nodeId=function(t){return arguments.length?(L=\"function\"==typeof t?t:s(t),F):L},F.nodeAlign=function(t){return arguments.length?(P=\"function\"==typeof t?t:s(t),F):P},F.nodeWidth=function(t){return arguments.length?(E=+t,F):E},F.nodePadding=function(e){return arguments.length?(t=+e,F):t},F.nodes=function(t){return arguments.length?(O=\"function\"==typeof t?t:s(t),F):O},F.links=function(t){return arguments.length?(z=\"function\"==typeof t?t:s(t),F):z},F.size=function(t){return arguments.length?(a=b=0,A=+t[0],S=+t[1],F):[A-a,S-b]},F.extent=function(t){return arguments.length?(a=+t[0][0],A=+t[1][0],b=+t[0][1],S=+t[1][1],F):[[a,b],[A,S]]},F.iterations=function(t){return arguments.length?(I=+t,F):I},F.circularLinkGap=function(t){return arguments.length?(D=+t,F):D},F.nodePaddingRatio=function(t){return arguments.length?(n=+t,F):n},F.sortNodes=function(t){return arguments.length?(R=t,F):R},F.update=function(t){return T(t,L),B(t),t.links.forEach(function(t){t.circular&&(t.circularLinkType=t.y0+t.y1<S?\"top\":\"bottom\",t.source.circularLinkType=t.circularLinkType,t.target.circularLinkType=t.circularLinkType)}),V(t,S,L,!1),q(t,0,L),C(t,D,S,L),t},F},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,a)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=o,Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\"),t(\"elementary-circuits-directed-graph\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,null)},{\"d3-array\":152,\"d3-collection\":153,\"d3-shape\":161,\"elementary-circuits-directed-graph\":172}],54:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n){\"use strict\";function i(t){return t.target.depth}function a(t,e){return t.sourceLinks.length?t.depth:e-1}function o(t){return function(){return t}}function s(t,e){return c(t.source,e.source)||t.index-e.index}function l(t,e){return c(t.target,e.target)||t.index-e.index}function c(t,e){return t.y0-e.y0}function u(t){return t.value}function h(t){return(t.y0+t.y1)/2}function f(t){return h(t.source)*t.value}function p(t){return h(t.target)*t.value}function d(t){return t.index}function g(t){return t.nodes}function v(t){return t.links}function m(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function y(t){return[t.source.x1,t.y0]}function x(t){return[t.target.x0,t.y1]}t.sankey=function(){var t=0,n=0,i=1,y=1,x=24,b=8,_=d,w=a,k=g,T=v,A=32,M=2/3;function S(){var a={nodes:k.apply(null,arguments),links:T.apply(null,arguments)};return function(t){t.nodes.forEach(function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]});var e=r.map(t.nodes,_);t.links.forEach(function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!=typeof n&&(n=t.source=m(e,n)),\"object\"!=typeof i&&(i=t.target=m(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)})}(a),function(t){t.nodes.forEach(function(t){t.value=Math.max(e.sum(t.sourceLinks,u),e.sum(t.targetLinks,u))})}(a),function(e){var r,n,a;for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach(function(t){t.depth=a,t.sourceLinks.forEach(function(t){n.indexOf(t.target)<0&&n.push(t.target)})});for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach(function(t){t.height=a,t.targetLinks.forEach(function(t){n.indexOf(t.source)<0&&n.push(t.source)})});var o=(i-t-x)/(a-1);e.nodes.forEach(function(e){e.x1=(e.x0=t+Math.max(0,Math.min(a-1,Math.floor(w.call(null,e,a))))*o)+x})}(a),function(t){var i=r.nest().key(function(t){return t.x0}).sortKeys(e.ascending).entries(t.nodes).map(function(t){return t.values});(function(){var r=e.max(i,function(t){return t.length}),a=M*(y-n)/(r-1);b>a&&(b=a);var o=e.min(i,function(t){return(y-n-(t.length-1)*b)/e.sum(t,u)});i.forEach(function(t){t.forEach(function(t,e){t.y1=(t.y0=e)+t.value*o})}),t.links.forEach(function(t){t.width=t.value*o})})(),d();for(var a=1,o=A;o>0;--o)l(a*=.99),d(),s(a),d();function s(t){i.forEach(function(r){r.forEach(function(r){if(r.targetLinks.length){var n=(e.sum(r.targetLinks,f)/e.sum(r.targetLinks,u)-h(r))*t;r.y0+=n,r.y1+=n}})})}function l(t){i.slice().reverse().forEach(function(r){r.forEach(function(r){if(r.sourceLinks.length){var n=(e.sum(r.sourceLinks,p)/e.sum(r.sourceLinks,u)-h(r))*t;r.y0+=n,r.y1+=n}})})}function d(){i.forEach(function(t){var e,r,i,a=n,o=t.length;for(t.sort(c),i=0;i<o;++i)e=t[i],(r=a-e.y0)>0&&(e.y0+=r,e.y1+=r),a=e.y1+b;if((r=a-b-y)>0)for(a=e.y0-=r,e.y1-=r,i=o-2;i>=0;--i)e=t[i],(r=e.y1+b-a)>0&&(e.y0-=r,e.y1-=r),a=e.y0})}}(a),E(a),a}function E(t){t.nodes.forEach(function(t){t.sourceLinks.sort(l),t.targetLinks.sort(s)}),t.nodes.forEach(function(t){var e=t.y0,r=e;t.sourceLinks.forEach(function(t){t.y0=e+t.width/2,e+=t.width}),t.targetLinks.forEach(function(t){t.y1=r+t.width/2,r+=t.width})})}return S.update=function(t){return E(t),t},S.nodeId=function(t){return arguments.length?(_=\"function\"==typeof t?t:o(t),S):_},S.nodeAlign=function(t){return arguments.length?(w=\"function\"==typeof t?t:o(t),S):w},S.nodeWidth=function(t){return arguments.length?(x=+t,S):x},S.nodePadding=function(t){return arguments.length?(b=+t,S):b},S.nodes=function(t){return arguments.length?(k=\"function\"==typeof t?t:o(t),S):k},S.links=function(t){return arguments.length?(T=\"function\"==typeof t?t:o(t),S):T},S.size=function(e){return arguments.length?(t=n=0,i=+e[0],y=+e[1],S):[i-t,y-n]},S.extent=function(e){return arguments.length?(t=+e[0][0],i=+e[1][0],n=+e[0][1],y=+e[1][1],S):[[t,n],[i,y]]},S.iterations=function(t){return arguments.length?(A=+t,S):A},S},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,i)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=a,t.sankeyLinkHorizontal=function(){return n.linkHorizontal().source(y).target(x)},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3)},{\"d3-array\":152,\"d3-collection\":153,\"d3-shape\":161}],55:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\"),i=6378137;function a(t){var e=0;if(t&&t.length>0){e+=Math.abs(o(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(o(t[r]))}return e}function o(t){var e,r,n,a,o,l,c=0,u=t.length;if(u>2){for(l=0;l<u;l++)l===u-2?(n=u-2,a=u-1,o=0):l===u-1?(n=u-1,a=0,o=1):(n=l,a=l+1,o=l+2),e=t[n],r=t[a],c+=(s(t[o][0])-s(e[0]))*Math.sin(s(r[1]));c=c*i*i/2}return c}function s(t){return t*Math.PI/180}r.default=function(t){return n.geomReduce(t,function(t,e){return t+function(t){var e,r=0;switch(t.type){case\"Polygon\":return a(t.coordinates);case\"MultiPolygon\":for(e=0;e<t.coordinates.length;e++)r+=a(t.coordinates[e]);return r;case\"Point\":case\"MultiPoint\":case\"LineString\":case\"MultiLineString\":return 0}return 0}(e)},0)}},{\"@turf/meta\":58}],56:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\"),i=t(\"@turf/helpers\");r.default=function(t,e){void 0===e&&(e={});var r=0,a=0,o=0;return n.coordEach(t,function(t){r+=t[0],a+=t[1],o++}),i.point([r/o,a/o],e.properties)}},{\"@turf/helpers\":57,\"@turf/meta\":58}],57:[function(t,e,r){\"use strict\";function n(t,e,r){void 0===r&&(r={});var n={type:\"Feature\"};return(0===r.id||r.id)&&(n.id=r.id),r.bbox&&(n.bbox=r.bbox),n.properties=e||{},n.geometry=t,n}function i(t,e,r){return void 0===r&&(r={}),n({type:\"Point\",coordinates:t},e,r)}function a(t,e,r){void 0===r&&(r={});for(var i=0,a=t;i<a.length;i++){var o=a[i];if(o.length<4)throw new Error(\"Each LinearRing of a Polygon must have 4 or more Positions.\");for(var s=0;s<o[o.length-1].length;s++)if(o[o.length-1][s]!==o[0][s])throw new Error(\"First and last Position are not equivalent.\")}return n({type:\"Polygon\",coordinates:t},e,r)}function o(t,e,r){if(void 0===r&&(r={}),t.length<2)throw new Error(\"coordinates must be an array of two or more positions\");return n({type:\"LineString\",coordinates:t},e,r)}function s(t,e){void 0===e&&(e={});var r={type:\"FeatureCollection\"};return e.id&&(r.id=e.id),e.bbox&&(r.bbox=e.bbox),r.features=t,r}function l(t,e,r){return void 0===r&&(r={}),n({type:\"MultiLineString\",coordinates:t},e,r)}function c(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPoint\",coordinates:t},e,r)}function u(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPolygon\",coordinates:t},e,r)}function h(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t*n}function f(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t/n}function p(t){return 180*(t%(2*Math.PI))/Math.PI}function d(t){return!isNaN(t)&&null!==t&&!Array.isArray(t)&&!/^\\s*$/.test(t)}Object.defineProperty(r,\"__esModule\",{value:!0}),r.earthRadius=6371008.8,r.factors={centimeters:100*r.earthRadius,centimetres:100*r.earthRadius,degrees:r.earthRadius/111325,feet:3.28084*r.earthRadius,inches:39.37*r.earthRadius,kilometers:r.earthRadius/1e3,kilometres:r.earthRadius/1e3,meters:r.earthRadius,metres:r.earthRadius,miles:r.earthRadius/1609.344,millimeters:1e3*r.earthRadius,millimetres:1e3*r.earthRadius,nauticalmiles:r.earthRadius/1852,radians:1,yards:r.earthRadius/1.0936},r.unitsFactors={centimeters:100,centimetres:100,degrees:1/111325,feet:3.28084,inches:39.37,kilometers:.001,kilometres:.001,meters:1,metres:1,miles:1/1609.344,millimeters:1e3,millimetres:1e3,nauticalmiles:1/1852,radians:1/r.earthRadius,yards:1/1.0936},r.areaFactors={acres:247105e-9,centimeters:1e4,centimetres:1e4,feet:10.763910417,inches:1550.003100006,kilometers:1e-6,kilometres:1e-6,meters:1,metres:1,miles:3.86e-7,millimeters:1e6,millimetres:1e6,yards:1.195990046},r.feature=n,r.geometry=function(t,e,r){switch(void 0===r&&(r={}),t){case\"Point\":return i(e).geometry;case\"LineString\":return o(e).geometry;case\"Polygon\":return a(e).geometry;case\"MultiPoint\":return c(e).geometry;case\"MultiLineString\":return l(e).geometry;case\"MultiPolygon\":return u(e).geometry;default:throw new Error(t+\" is invalid\")}},r.point=i,r.points=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return i(t,e)}),r)},r.polygon=a,r.polygons=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return a(t,e)}),r)},r.lineString=o,r.lineStrings=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return o(t,e)}),r)},r.featureCollection=s,r.multiLineString=l,r.multiPoint=c,r.multiPolygon=u,r.geometryCollection=function(t,e,r){return void 0===r&&(r={}),n({type:\"GeometryCollection\",geometries:t},e,r)},r.round=function(t,e){if(void 0===e&&(e=0),e&&!(e>=0))throw new Error(\"precision must be a positive number\");var r=Math.pow(10,e||0);return Math.round(t*r)/r},r.radiansToLength=h,r.lengthToRadians=f,r.lengthToDegrees=function(t,e){return p(f(t,e))},r.bearingToAzimuth=function(t){var e=t%360;return e<0&&(e+=360),e},r.radiansToDegrees=p,r.degreesToRadians=function(t){return t%360*Math.PI/180},r.convertLength=function(t,e,r){if(void 0===e&&(e=\"kilometers\"),void 0===r&&(r=\"kilometers\"),!(t>=0))throw new Error(\"length must be a positive number\");return h(f(t,e),r)},r.convertArea=function(t,e,n){if(void 0===e&&(e=\"meters\"),void 0===n&&(n=\"kilometers\"),!(t>=0))throw new Error(\"area must be a positive number\");var i=r.areaFactors[e];if(!i)throw new Error(\"invalid original units\");var a=r.areaFactors[n];if(!a)throw new Error(\"invalid final units\");return t/i*a},r.isNumber=d,r.isObject=function(t){return!!t&&t.constructor===Object},r.validateBBox=function(t){if(!t)throw new Error(\"bbox is required\");if(!Array.isArray(t))throw new Error(\"bbox must be an Array\");if(4!==t.length&&6!==t.length)throw new Error(\"bbox must be an Array of 4 or 6 numbers\");t.forEach(function(t){if(!d(t))throw new Error(\"bbox must only contain numbers\")})},r.validateId=function(t){if(!t)throw new Error(\"id is required\");if(-1===[\"string\",\"number\"].indexOf(typeof t))throw new Error(\"id must be a number or a string\")},r.radians2degrees=function(){throw new Error(\"method has been renamed to `radiansToDegrees`\")},r.degrees2radians=function(){throw new Error(\"method has been renamed to `degreesToRadians`\")},r.distanceToDegrees=function(){throw new Error(\"method has been renamed to `lengthToDegrees`\")},r.distanceToRadians=function(){throw new Error(\"method has been renamed to `lengthToRadians`\")},r.radiansToDistance=function(){throw new Error(\"method has been renamed to `radiansToLength`\")},r.bearingToAngle=function(){throw new Error(\"method has been renamed to `bearingToAzimuth`\")},r.convertDistance=function(){throw new Error(\"method has been renamed to `convertLength`\")}},{}],58:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/helpers\");function i(t,e,r){if(null!==t)for(var n,a,o,s,l,c,u,h,f=0,p=0,d=t.type,g=\"FeatureCollection\"===d,v=\"Feature\"===d,m=g?t.features.length:1,y=0;y<m;y++){l=(h=!!(u=g?t.features[y].geometry:v?t.geometry:t)&&\"GeometryCollection\"===u.type)?u.geometries.length:1;for(var x=0;x<l;x++){var b=0,_=0;if(null!==(s=h?u.geometries[x]:u)){c=s.coordinates;var w=s.type;switch(f=!r||\"Polygon\"!==w&&\"MultiPolygon\"!==w?0:1,w){case null:break;case\"Point\":if(!1===e(c,p,y,b,_))return!1;p++,b++;break;case\"LineString\":case\"MultiPoint\":for(n=0;n<c.length;n++){if(!1===e(c[n],p,y,b,_))return!1;p++,\"MultiPoint\"===w&&b++}\"LineString\"===w&&b++;break;case\"Polygon\":case\"MultiLineString\":for(n=0;n<c.length;n++){for(a=0;a<c[n].length-f;a++){if(!1===e(c[n][a],p,y,b,_))return!1;p++}\"MultiLineString\"===w&&b++,\"Polygon\"===w&&_++}\"Polygon\"===w&&b++;break;case\"MultiPolygon\":for(n=0;n<c.length;n++){for(_=0,a=0;a<c[n].length;a++){for(o=0;o<c[n][a].length-f;o++){if(!1===e(c[n][a][o],p,y,b,_))return!1;p++}_++}b++}break;case\"GeometryCollection\":for(n=0;n<s.geometries.length;n++)if(!1===i(s.geometries[n],e,r))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}}}}}function a(t,e){var r;switch(t.type){case\"FeatureCollection\":for(r=0;r<t.features.length&&!1!==e(t.features[r].properties,r);r++);break;case\"Feature\":e(t.properties,0)}}function o(t,e){if(\"Feature\"===t.type)e(t,0);else if(\"FeatureCollection\"===t.type)for(var r=0;r<t.features.length&&!1!==e(t.features[r],r);r++);}function s(t,e){var r,n,i,a,o,s,l,c,u,h,f=0,p=\"FeatureCollection\"===t.type,d=\"Feature\"===t.type,g=p?t.features.length:1;for(r=0;r<g;r++){for(s=p?t.features[r].geometry:d?t.geometry:t,c=p?t.features[r].properties:d?t.properties:{},u=p?t.features[r].bbox:d?t.bbox:void 0,h=p?t.features[r].id:d?t.id:void 0,o=(l=!!s&&\"GeometryCollection\"===s.type)?s.geometries.length:1,i=0;i<o;i++)if(null!==(a=l?s.geometries[i]:s))switch(a.type){case\"Point\":case\"LineString\":case\"MultiPoint\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":if(!1===e(a,f,c,u,h))return!1;break;case\"GeometryCollection\":for(n=0;n<a.geometries.length;n++)if(!1===e(a.geometries[n],f,c,u,h))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}else if(!1===e(null,f,c,u,h))return!1;f++}}function l(t,e){s(t,function(t,r,i,a,o){var s,l=null===t?null:t.type;switch(l){case null:case\"Point\":case\"LineString\":case\"Polygon\":return!1!==e(n.feature(t,i,{bbox:a,id:o}),r,0)&&void 0}switch(l){case\"MultiPoint\":s=\"Point\";break;case\"MultiLineString\":s=\"LineString\";break;case\"MultiPolygon\":s=\"Polygon\"}for(var c=0;c<t.coordinates.length;c++){var u={type:s,coordinates:t.coordinates[c]};if(!1===e(n.feature(u,i),r,c))return!1}})}function c(t,e){l(t,function(t,r,a){var o=0;if(t.geometry){var s=t.geometry.type;if(\"Point\"!==s&&\"MultiPoint\"!==s){var l,c=0,u=0,h=0;return!1!==i(t,function(i,s,f,p,d){if(void 0===l||r>c||p>u||d>h)return l=i,c=r,u=p,h=d,void(o=0);var g=n.lineString([l,i],t.properties);if(!1===e(g,r,a,d,o))return!1;o++,l=i})&&void 0}}})}function u(t,e){if(!t)throw new Error(\"geojson is required\");l(t,function(t,r,i){if(null!==t.geometry){var a=t.geometry.type,o=t.geometry.coordinates;switch(a){case\"LineString\":if(!1===e(t,r,i,0,0))return!1;break;case\"Polygon\":for(var s=0;s<o.length;s++)if(!1===e(n.lineString(o[s],t.properties),r,i,s))return!1}}})}r.coordEach=i,r.coordReduce=function(t,e,r,n){var a=r;return i(t,function(t,n,i,o,s){a=0===n&&void 0===r?t:e(a,t,n,i,o,s)},n),a},r.propEach=a,r.propReduce=function(t,e,r){var n=r;return a(t,function(t,i){n=0===i&&void 0===r?t:e(n,t,i)}),n},r.featureEach=o,r.featureReduce=function(t,e,r){var n=r;return o(t,function(t,i){n=0===i&&void 0===r?t:e(n,t,i)}),n},r.coordAll=function(t){var e=[];return i(t,function(t){e.push(t)}),e},r.geomEach=s,r.geomReduce=function(t,e,r){var n=r;return s(t,function(t,i,a,o,s){n=0===i&&void 0===r?t:e(n,t,i,a,o,s)}),n},r.flattenEach=l,r.flattenReduce=function(t,e,r){var n=r;return l(t,function(t,i,a){n=0===i&&0===a&&void 0===r?t:e(n,t,i,a)}),n},r.segmentEach=c,r.segmentReduce=function(t,e,r){var n=r,i=!1;return c(t,function(t,a,o,s,l){n=!1===i&&void 0===r?t:e(n,t,a,o,s,l),i=!0}),n},r.lineEach=u,r.lineReduce=function(t,e,r){var n=r;return u(t,function(t,i,a,o){n=0===i&&void 0===r?t:e(n,t,i,a,o)}),n},r.findSegment=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.segmentIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":case\"MultiPoint\":return null;case\"LineString\":return s<0&&(s=c.length+s-1),n.lineString([c[s],c[s+1]],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s-1),n.lineString([c[o][s],c[o][s+1]],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s-1),n.lineString([c[a][s],c[a][s+1]],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s-1),n.lineString([c[a][o][s],c[a][o][s+1]],l,e)}throw new Error(\"geojson is invalid\")},r.findPoint=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.coordIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":return n.point(c,l,e);case\"MultiPoint\":return a<0&&(a=c.length+a),n.point(c[a],l,e);case\"LineString\":return s<0&&(s=c.length+s),n.point(c[s],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s),n.point(c[o][s],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s),n.point(c[a][s],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s),n.point(c[a][o][s],l,e)}throw new Error(\"geojson is invalid\")}},{\"@turf/helpers\":57}],59:[function(t,e,r){\"use strict\";var n=\"undefined\"==typeof WeakMap?t(\"weak-map\"):WeakMap,i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=new n;e.exports=function(t){var e=o.get(t),r=e&&(e._triangleBuffer.handle||e._triangleBuffer.buffer);if(!r||!t.isBuffer(r)){var n=i(t,new Float32Array([-1,-1,-1,4,4,-1]));(e=a(t,[{buffer:n,type:t.FLOAT,size:2}]))._triangleBuffer=n,o.set(t,e)}e.bind(),t.drawArrays(t.TRIANGLES,0,3),e.unbind()}},{\"gl-buffer\":241,\"gl-vao\":327,\"weak-map\":552}],60:[function(t,e,r){e.exports=function(t){var e=0,r=0,n=0,i=0;return t.map(function(t){var a=(t=t.slice())[0],o=a.toUpperCase();if(a!=o)switch(t[0]=o,a){case\"a\":t[6]+=n,t[7]+=i;break;case\"v\":t[1]+=i;break;case\"h\":t[1]+=n;break;default:for(var s=1;s<t.length;)t[s++]+=n,t[s++]+=i}switch(o){case\"Z\":n=e,i=r;break;case\"H\":n=t[1];break;case\"V\":i=t[1];break;case\"M\":n=e=t[1],i=r=t[2];break;default:n=t[t.length-2],i=t[t.length-1]}return t})}},{}],61:[function(t,e,r){var n=t(\"pad-left\");e.exports=function(t,e,r){e=\"number\"==typeof e?e:1,r=r||\": \";var i=t.split(/\\r?\\n/),a=String(i.length+e-1).length;return i.map(function(t,i){var o=i+e,s=String(o).length,l=n(o,a-s);return l+r+t}).join(\"\\n\")}},{\"pad-left\":457}],62:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[0];for(var r=t[0].length,n=[t[0]],a=[0],o=1;o<e;++o)if(n.push(t[o]),i(n,r)){if(a.push(o),a.length===r+1)return a}else n.pop();return a};var n=t(\"robust-orientation\");function i(t,e){for(var r=new Array(e+1),i=0;i<t.length;++i)r[i]=t[i];for(i=0;i<=t.length;++i){for(var a=t.length;a<=e;++a){for(var o=new Array(e),s=0;s<e;++s)o[s]=Math.pow(a+1-i,s);r[a]=o}if(n.apply(void 0,r))return!0}return!1}},{\"robust-orientation\":510}],63:[function(t,e,r){\"use strict\";e.exports=function(t,e){return n(e).filter(function(r){for(var n=new Array(r.length),a=0;a<r.length;++a)n[a]=e[r[a]];return i(n)*t<1})};var n=t(\"delaunay-triangulate\"),i=t(\"circumradius\")},{circumradius:114,\"delaunay-triangulate\":165}],64:[function(t,e,r){e.exports=function(t,e){return i(n(t,e))};var n=t(\"alpha-complex\"),i=t(\"simplicial-complex-boundary\")},{\"alpha-complex\":63,\"simplicial-complex-boundary\":517}],65:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(!t||null==t.length)throw Error(\"Argument should be an array\");e=null==e?1:Math.floor(e);for(var r=Array(2*e),n=0;n<e;n++){for(var i=-1/0,a=1/0,o=n,s=t.length;o<s;o+=e)t[o]>i&&(i=t[o]),t[o]<a&&(a=t[o]);r[n]=a,r[e+n]=i}return r}},{}],66:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\");e.exports=function(t,e,r){if(!t||null==t.length)throw Error(\"Argument should be an array\");null==e&&(e=1);null==r&&(r=n(t,e));for(var i=0;i<e;i++){var a=r[e+i],o=r[i],s=i,l=t.length;if(a===1/0&&o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:t[s]===o?0:.5;else if(a===1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:0;else if(o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===o?0:1;else{var c=a-o;for(s=i;s<l;s+=e)t[s]=0===c?.5:(t[s]-o)/c}}return t}},{\"array-bounds\":65}],67:[function(t,e,r){e.exports=function(t,e){var r=\"number\"==typeof t,n=\"number\"==typeof e;r&&!n?(e=t,t=0):r||n||(t=0,e=0);var i=(e|=0)-(t|=0);if(i<0)throw new Error(\"array length must be positive\");for(var a=new Array(i),o=0,s=t;o<i;o++,s++)a[o]=s;return a}},{}],68:[function(t,e,r){(function(r){\"use strict\";var n=t(\"object-assign\");function i(t,e){if(t===e)return 0;for(var r=t.length,n=e.length,i=0,a=Math.min(r,n);i<a;++i)if(t[i]!==e[i]){r=t[i],n=e[i];break}return r<n?-1:n<r?1:0}function a(t){return r.Buffer&&\"function\"==typeof r.Buffer.isBuffer?r.Buffer.isBuffer(t):!(null==t||!t._isBuffer)}var o=t(\"util/\"),s=Object.prototype.hasOwnProperty,l=Array.prototype.slice,c=\"foo\"===function(){}.name;function u(t){return Object.prototype.toString.call(t)}function h(t){return!a(t)&&(\"function\"==typeof r.ArrayBuffer&&(\"function\"==typeof ArrayBuffer.isView?ArrayBuffer.isView(t):!!t&&(t instanceof DataView||!!(t.buffer&&t.buffer instanceof ArrayBuffer))))}var f=e.exports=y,p=/\\s*function\\s+([^\\(\\s]*)\\s*/;function d(t){if(o.isFunction(t)){if(c)return t.name;var e=t.toString().match(p);return e&&e[1]}}function g(t,e){return\"string\"==typeof t?t.length<e?t:t.slice(0,e):t}function v(t){if(c||!o.isFunction(t))return o.inspect(t);var e=d(t);return\"[Function\"+(e?\": \"+e:\"\")+\"]\"}function m(t,e,r,n,i){throw new f.AssertionError({message:r,actual:t,expected:e,operator:n,stackStartFunction:i})}function y(t,e){t||m(t,!0,e,\"==\",f.ok)}function x(t,e,r,n){if(t===e)return!0;if(a(t)&&a(e))return 0===i(t,e);if(o.isDate(t)&&o.isDate(e))return t.getTime()===e.getTime();if(o.isRegExp(t)&&o.isRegExp(e))return t.source===e.source&&t.global===e.global&&t.multiline===e.multiline&&t.lastIndex===e.lastIndex&&t.ignoreCase===e.ignoreCase;if(null!==t&&\"object\"==typeof t||null!==e&&\"object\"==typeof e){if(h(t)&&h(e)&&u(t)===u(e)&&!(t instanceof Float32Array||t instanceof Float64Array))return 0===i(new Uint8Array(t.buffer),new Uint8Array(e.buffer));if(a(t)!==a(e))return!1;var s=(n=n||{actual:[],expected:[]}).actual.indexOf(t);return-1!==s&&s===n.expected.indexOf(e)||(n.actual.push(t),n.expected.push(e),function(t,e,r,n){if(null==t||null==e)return!1;if(o.isPrimitive(t)||o.isPrimitive(e))return t===e;if(r&&Object.getPrototypeOf(t)!==Object.getPrototypeOf(e))return!1;var i=b(t),a=b(e);if(i&&!a||!i&&a)return!1;if(i)return t=l.call(t),e=l.call(e),x(t,e,r);var s,c,u=k(t),h=k(e);if(u.length!==h.length)return!1;for(u.sort(),h.sort(),c=u.length-1;c>=0;c--)if(u[c]!==h[c])return!1;for(c=u.length-1;c>=0;c--)if(s=u[c],!x(t[s],e[s],r,n))return!1;return!0}(t,e,r,n))}return r?t===e:t==e}function b(t){return\"[object Arguments]\"==Object.prototype.toString.call(t)}function _(t,e){if(!t||!e)return!1;if(\"[object RegExp]\"==Object.prototype.toString.call(e))return e.test(t);try{if(t instanceof e)return!0}catch(t){}return!Error.isPrototypeOf(e)&&!0===e.call({},t)}function w(t,e,r,n){var i;if(\"function\"!=typeof e)throw new TypeError('\"block\" argument must be a function');\"string\"==typeof r&&(n=r,r=null),i=function(t){var e;try{t()}catch(t){e=t}return e}(e),n=(r&&r.name?\" (\"+r.name+\").\":\".\")+(n?\" \"+n:\".\"),t&&!i&&m(i,r,\"Missing expected exception\"+n);var a=\"string\"==typeof n,s=!t&&i&&!r;if((!t&&o.isError(i)&&a&&_(i,r)||s)&&m(i,r,\"Got unwanted exception\"+n),t&&i&&r&&!_(i,r)||!t&&i)throw i}f.AssertionError=function(t){var e;this.name=\"AssertionError\",this.actual=t.actual,this.expected=t.expected,this.operator=t.operator,t.message?(this.message=t.message,this.generatedMessage=!1):(this.message=g(v((e=this).actual),128)+\" \"+e.operator+\" \"+g(v(e.expected),128),this.generatedMessage=!0);var r=t.stackStartFunction||m;if(Error.captureStackTrace)Error.captureStackTrace(this,r);else{var n=new Error;if(n.stack){var i=n.stack,a=d(r),o=i.indexOf(\"\\n\"+a);if(o>=0){var s=i.indexOf(\"\\n\",o+1);i=i.substring(s+1)}this.stack=i}}},o.inherits(f.AssertionError,Error),f.fail=m,f.ok=y,f.equal=function(t,e,r){t!=e&&m(t,e,r,\"==\",f.equal)},f.notEqual=function(t,e,r){t==e&&m(t,e,r,\"!=\",f.notEqual)},f.deepEqual=function(t,e,r){x(t,e,!1)||m(t,e,r,\"deepEqual\",f.deepEqual)},f.deepStrictEqual=function(t,e,r){x(t,e,!0)||m(t,e,r,\"deepStrictEqual\",f.deepStrictEqual)},f.notDeepEqual=function(t,e,r){x(t,e,!1)&&m(t,e,r,\"notDeepEqual\",f.notDeepEqual)},f.notDeepStrictEqual=function t(e,r,n){x(e,r,!0)&&m(e,r,n,\"notDeepStrictEqual\",t)},f.strictEqual=function(t,e,r){t!==e&&m(t,e,r,\"===\",f.strictEqual)},f.notStrictEqual=function(t,e,r){t===e&&m(t,e,r,\"!==\",f.notStrictEqual)},f.throws=function(t,e,r){w(!0,t,e,r)},f.doesNotThrow=function(t,e,r){w(!1,t,e,r)},f.ifError=function(t){if(t)throw t},f.strict=n(function t(e,r){e||m(e,!0,r,\"==\",t)},f,{equal:f.strictEqual,deepEqual:f.deepStrictEqual,notEqual:f.notStrictEqual,notDeepEqual:f.notDeepStrictEqual}),f.strict.strict=f.strict;var k=Object.keys||function(t){var e=[];for(var r in t)s.call(t,r)&&e.push(r);return e}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"object-assign\":454,\"util/\":71}],69:[function(t,e,r){\"function\"==typeof Object.create?e.exports=function(t,e){t.super_=e,t.prototype=Object.create(e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}})}:e.exports=function(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}},{}],70:[function(t,e,r){e.exports=function(t){return t&&\"object\"==typeof t&&\"function\"==typeof t.copy&&\"function\"==typeof t.fill&&\"function\"==typeof t.readUInt8}},{}],71:[function(t,e,r){(function(e,n){var i=/%[sdj%]/g;r.format=function(t){if(!m(t)){for(var e=[],r=0;r<arguments.length;r++)e.push(s(arguments[r]));return e.join(\" \")}r=1;for(var n=arguments,a=n.length,o=String(t).replace(i,function(t){if(\"%%\"===t)return\"%\";if(r>=a)return t;switch(t){case\"%s\":return String(n[r++]);case\"%d\":return Number(n[r++]);case\"%j\":try{return JSON.stringify(n[r++])}catch(t){return\"[Circular]\"}default:return t}}),l=n[r];r<a;l=n[++r])g(l)||!b(l)?o+=\" \"+l:o+=\" \"+s(l);return o},r.deprecate=function(t,i){if(y(n.process))return function(){return r.deprecate(t,i).apply(this,arguments)};if(!0===e.noDeprecation)return t;var a=!1;return function(){if(!a){if(e.throwDeprecation)throw new Error(i);e.traceDeprecation?console.trace(i):console.error(i),a=!0}return t.apply(this,arguments)}};var a,o={};function s(t,e){var n={seen:[],stylize:c};return arguments.length>=3&&(n.depth=arguments[2]),arguments.length>=4&&(n.colors=arguments[3]),d(e)?n.showHidden=e:e&&r._extend(n,e),y(n.showHidden)&&(n.showHidden=!1),y(n.depth)&&(n.depth=2),y(n.colors)&&(n.colors=!1),y(n.customInspect)&&(n.customInspect=!0),n.colors&&(n.stylize=l),u(n,t,n.depth)}function l(t,e){var r=s.styles[e];return r?\"\\x1b[\"+s.colors[r][0]+\"m\"+t+\"\\x1b[\"+s.colors[r][1]+\"m\":t}function c(t,e){return t}function u(t,e,n){if(t.customInspect&&e&&k(e.inspect)&&e.inspect!==r.inspect&&(!e.constructor||e.constructor.prototype!==e)){var i=e.inspect(n,t);return m(i)||(i=u(t,i,n)),i}var a=function(t,e){if(y(e))return t.stylize(\"undefined\",\"undefined\");if(m(e)){var r=\"'\"+JSON.stringify(e).replace(/^\"|\"$/g,\"\").replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"')+\"'\";return t.stylize(r,\"string\")}if(v(e))return t.stylize(\"\"+e,\"number\");if(d(e))return t.stylize(\"\"+e,\"boolean\");if(g(e))return t.stylize(\"null\",\"null\")}(t,e);if(a)return a;var o=Object.keys(e),s=function(t){var e={};return t.forEach(function(t,r){e[t]=!0}),e}(o);if(t.showHidden&&(o=Object.getOwnPropertyNames(e)),w(e)&&(o.indexOf(\"message\")>=0||o.indexOf(\"description\")>=0))return h(e);if(0===o.length){if(k(e)){var l=e.name?\": \"+e.name:\"\";return t.stylize(\"[Function\"+l+\"]\",\"special\")}if(x(e))return t.stylize(RegExp.prototype.toString.call(e),\"regexp\");if(_(e))return t.stylize(Date.prototype.toString.call(e),\"date\");if(w(e))return h(e)}var c,b=\"\",T=!1,A=[\"{\",\"}\"];(p(e)&&(T=!0,A=[\"[\",\"]\"]),k(e))&&(b=\" [Function\"+(e.name?\": \"+e.name:\"\")+\"]\");return x(e)&&(b=\" \"+RegExp.prototype.toString.call(e)),_(e)&&(b=\" \"+Date.prototype.toUTCString.call(e)),w(e)&&(b=\" \"+h(e)),0!==o.length||T&&0!=e.length?n<0?x(e)?t.stylize(RegExp.prototype.toString.call(e),\"regexp\"):t.stylize(\"[Object]\",\"special\"):(t.seen.push(e),c=T?function(t,e,r,n,i){for(var a=[],o=0,s=e.length;o<s;++o)S(e,String(o))?a.push(f(t,e,r,n,String(o),!0)):a.push(\"\");return i.forEach(function(i){i.match(/^\\d+$/)||a.push(f(t,e,r,n,i,!0))}),a}(t,e,n,s,o):o.map(function(r){return f(t,e,n,s,r,T)}),t.seen.pop(),function(t,e,r){if(t.reduce(function(t,e){return 0,e.indexOf(\"\\n\")>=0&&0,t+e.replace(/\\u001b\\[\\d\\d?m/g,\"\").length+1},0)>60)return r[0]+(\"\"===e?\"\":e+\"\\n \")+\" \"+t.join(\",\\n  \")+\" \"+r[1];return r[0]+e+\" \"+t.join(\", \")+\" \"+r[1]}(c,b,A)):A[0]+b+A[1]}function h(t){return\"[\"+Error.prototype.toString.call(t)+\"]\"}function f(t,e,r,n,i,a){var o,s,l;if((l=Object.getOwnPropertyDescriptor(e,i)||{value:e[i]}).get?s=l.set?t.stylize(\"[Getter/Setter]\",\"special\"):t.stylize(\"[Getter]\",\"special\"):l.set&&(s=t.stylize(\"[Setter]\",\"special\")),S(n,i)||(o=\"[\"+i+\"]\"),s||(t.seen.indexOf(l.value)<0?(s=g(r)?u(t,l.value,null):u(t,l.value,r-1)).indexOf(\"\\n\")>-1&&(s=a?s.split(\"\\n\").map(function(t){return\"  \"+t}).join(\"\\n\").substr(2):\"\\n\"+s.split(\"\\n\").map(function(t){return\"   \"+t}).join(\"\\n\")):s=t.stylize(\"[Circular]\",\"special\")),y(o)){if(a&&i.match(/^\\d+$/))return s;(o=JSON.stringify(\"\"+i)).match(/^\"([a-zA-Z_][a-zA-Z_0-9]*)\"$/)?(o=o.substr(1,o.length-2),o=t.stylize(o,\"name\")):(o=o.replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"').replace(/(^\"|\"$)/g,\"'\"),o=t.stylize(o,\"string\"))}return o+\": \"+s}function p(t){return Array.isArray(t)}function d(t){return\"boolean\"==typeof t}function g(t){return null===t}function v(t){return\"number\"==typeof t}function m(t){return\"string\"==typeof t}function y(t){return void 0===t}function x(t){return b(t)&&\"[object RegExp]\"===T(t)}function b(t){return\"object\"==typeof t&&null!==t}function _(t){return b(t)&&\"[object Date]\"===T(t)}function w(t){return b(t)&&(\"[object Error]\"===T(t)||t instanceof Error)}function k(t){return\"function\"==typeof t}function T(t){return Object.prototype.toString.call(t)}function A(t){return t<10?\"0\"+t.toString(10):t.toString(10)}r.debuglog=function(t){if(y(a)&&(a=e.env.NODE_DEBUG||\"\"),t=t.toUpperCase(),!o[t])if(new RegExp(\"\\\\b\"+t+\"\\\\b\",\"i\").test(a)){var n=e.pid;o[t]=function(){var e=r.format.apply(r,arguments);console.error(\"%s %d: %s\",t,n,e)}}else o[t]=function(){};return o[t]},r.inspect=s,s.colors={bold:[1,22],italic:[3,23],underline:[4,24],inverse:[7,27],white:[37,39],grey:[90,39],black:[30,39],blue:[34,39],cyan:[36,39],green:[32,39],magenta:[35,39],red:[31,39],yellow:[33,39]},s.styles={special:\"cyan\",number:\"yellow\",boolean:\"yellow\",undefined:\"grey\",null:\"bold\",string:\"green\",date:\"magenta\",regexp:\"red\"},r.isArray=p,r.isBoolean=d,r.isNull=g,r.isNullOrUndefined=function(t){return null==t},r.isNumber=v,r.isString=m,r.isSymbol=function(t){return\"symbol\"==typeof t},r.isUndefined=y,r.isRegExp=x,r.isObject=b,r.isDate=_,r.isError=w,r.isFunction=k,r.isPrimitive=function(t){return null===t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||\"symbol\"==typeof t||\"undefined\"==typeof t},r.isBuffer=t(\"./support/isBuffer\");var M=[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"];function S(t,e){return Object.prototype.hasOwnProperty.call(t,e)}r.log=function(){var t,e;console.log(\"%s - %s\",(t=new Date,e=[A(t.getHours()),A(t.getMinutes()),A(t.getSeconds())].join(\":\"),[t.getDate(),M[t.getMonth()],e].join(\" \")),r.format.apply(r,arguments))},r.inherits=t(\"inherits\"),r._extend=function(t,e){if(!e||!b(e))return t;for(var r=Object.keys(e),n=r.length;n--;)t[r[n]]=e[r[n]];return t}}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./support/isBuffer\":70,_process:482,inherits:69}],72:[function(t,e,r){e.exports=function(t){return atob(t)}},{}],73:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=e.length,a=new Array(r+1),o=0;o<r;++o){for(var s=new Array(r+1),l=0;l<=r;++l)s[l]=t[l][o];a[o]=s}a[r]=new Array(r+1);for(var o=0;o<=r;++o)a[r][o]=1;for(var c=new Array(r+1),o=0;o<r;++o)c[o]=e[o];c[r]=1;var u=n(a,c),h=i(u[r+1]);0===h&&(h=1);for(var f=new Array(r+1),o=0;o<=r;++o)f[o]=i(u[o])/h;return f};var n=t(\"robust-linear-solve\");function i(t){for(var e=0,r=0;r<t.length;++r)e+=t[r];return e}},{\"robust-linear-solve\":509}],74:[function(t,e,r){\"use strict\";r.byteLength=function(t){var e=c(t),r=e[0],n=e[1];return 3*(r+n)/4-n},r.toByteArray=function(t){for(var e,r=c(t),n=r[0],o=r[1],s=new a(function(t,e,r){return 3*(e+r)/4-r}(0,n,o)),l=0,u=o>0?n-4:n,h=0;h<u;h+=4)e=i[t.charCodeAt(h)]<<18|i[t.charCodeAt(h+1)]<<12|i[t.charCodeAt(h+2)]<<6|i[t.charCodeAt(h+3)],s[l++]=e>>16&255,s[l++]=e>>8&255,s[l++]=255&e;2===o&&(e=i[t.charCodeAt(h)]<<2|i[t.charCodeAt(h+1)]>>4,s[l++]=255&e);1===o&&(e=i[t.charCodeAt(h)]<<10|i[t.charCodeAt(h+1)]<<4|i[t.charCodeAt(h+2)]>>2,s[l++]=e>>8&255,s[l++]=255&e);return s},r.fromByteArray=function(t){for(var e,r=t.length,i=r%3,a=[],o=0,s=r-i;o<s;o+=16383)a.push(u(t,o,o+16383>s?s:o+16383));1===i?(e=t[r-1],a.push(n[e>>2]+n[e<<4&63]+\"==\")):2===i&&(e=(t[r-2]<<8)+t[r-1],a.push(n[e>>10]+n[e>>4&63]+n[e<<2&63]+\"=\"));return a.join(\"\")};for(var n=[],i=[],a=\"undefined\"!=typeof Uint8Array?Uint8Array:Array,o=\"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/\",s=0,l=o.length;s<l;++s)n[s]=o[s],i[o.charCodeAt(s)]=s;function c(t){var e=t.length;if(e%4>0)throw new Error(\"Invalid string. Length must be a multiple of 4\");var r=t.indexOf(\"=\");return-1===r&&(r=e),[r,r===e?0:4-r%4]}function u(t,e,r){for(var i,a,o=[],s=e;s<r;s+=3)i=(t[s]<<16&16711680)+(t[s+1]<<8&65280)+(255&t[s+2]),o.push(n[(a=i)>>18&63]+n[a>>12&63]+n[a>>6&63]+n[63&a]);return o.join(\"\")}i[\"-\".charCodeAt(0)]=62,i[\"_\".charCodeAt(0)]=63},{}],75:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).add(e[0].mul(t[1])),t[1].mul(e[1]))}},{\"./lib/rationalize\":85}],76:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t[0].mul(e[1]).cmp(e[0].mul(t[1]))}},{}],77:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]),t[1].mul(e[0]))}},{\"./lib/rationalize\":85}],78:[function(t,e,r){\"use strict\";var n=t(\"./is-rat\"),i=t(\"./lib/is-bn\"),a=t(\"./lib/num-to-bn\"),o=t(\"./lib/str-to-bn\"),s=t(\"./lib/rationalize\"),l=t(\"./div\");e.exports=function t(e,r){if(n(e))return r?l(e,t(r)):[e[0].clone(),e[1].clone()];var c=0;var u,h;if(i(e))u=e.clone();else if(\"string\"==typeof e)u=o(e);else{if(0===e)return[a(0),a(1)];if(e===Math.floor(e))u=a(e);else{for(;e!==Math.floor(e);)e*=Math.pow(2,256),c-=256;u=a(e)}}if(n(r))u.mul(r[1]),h=r[0].clone();else if(i(r))h=r.clone();else if(\"string\"==typeof r)h=o(r);else if(r)if(r===Math.floor(r))h=a(r);else{for(;r!==Math.floor(r);)r*=Math.pow(2,256),c+=256;h=a(r)}else h=a(1);c>0?u=u.ushln(c):c<0&&(h=h.ushln(-c));return s(u,h)}},{\"./div\":77,\"./is-rat\":79,\"./lib/is-bn\":83,\"./lib/num-to-bn\":84,\"./lib/rationalize\":85,\"./lib/str-to-bn\":86}],79:[function(t,e,r){\"use strict\";var n=t(\"./lib/is-bn\");e.exports=function(t){return Array.isArray(t)&&2===t.length&&n(t[0])&&n(t[1])}},{\"./lib/is-bn\":83}],80:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return t.cmp(new n(0))}},{\"bn.js\":94}],81:[function(t,e,r){\"use strict\";var n=t(\"./bn-sign\");e.exports=function(t){var e=t.length,r=t.words,i=0;if(1===e)i=r[0];else if(2===e)i=r[0]+67108864*r[1];else for(var a=0;a<e;a++){var o=r[a];i+=o*Math.pow(67108864,a)}return n(t)*i}},{\"./bn-sign\":80}],82:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=t(\"bit-twiddle\").countTrailingZeros;e.exports=function(t){var e=i(n.lo(t));if(e<32)return e;var r=i(n.hi(t));if(r>20)return 52;return r+32}},{\"bit-twiddle\":92,\"double-bits\":167}],83:[function(t,e,r){\"use strict\";t(\"bn.js\");e.exports=function(t){return t&&\"object\"==typeof t&&Boolean(t.words)}},{\"bn.js\":94}],84:[function(t,e,r){\"use strict\";var n=t(\"bn.js\"),i=t(\"double-bits\");e.exports=function(t){var e=i.exponent(t);return e<52?new n(t):new n(t*Math.pow(2,52-e)).ushln(e-52)}},{\"bn.js\":94,\"double-bits\":167}],85:[function(t,e,r){\"use strict\";var n=t(\"./num-to-bn\"),i=t(\"./bn-sign\");e.exports=function(t,e){var r=i(t),a=i(e);if(0===r)return[n(0),n(1)];if(0===a)return[n(0),n(0)];a<0&&(t=t.neg(),e=e.neg());var o=t.gcd(e);if(o.cmpn(1))return[t.div(o),e.div(o)];return[t,e]}},{\"./bn-sign\":80,\"./num-to-bn\":84}],86:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return new n(t)}},{\"bn.js\":94}],87:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[0]),t[1].mul(e[1]))}},{\"./lib/rationalize\":85}],88:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-sign\");e.exports=function(t){return n(t[0])*n(t[1])}},{\"./lib/bn-sign\":80}],89:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).sub(t[1].mul(e[0])),t[1].mul(e[1]))}},{\"./lib/rationalize\":85}],90:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-to-num\"),i=t(\"./lib/ctz\");e.exports=function(t){var e=t[0],r=t[1];if(0===e.cmpn(0))return 0;var a=e.abs().divmod(r.abs()),o=a.div,s=n(o),l=a.mod,c=e.negative!==r.negative?-1:1;if(0===l.cmpn(0))return c*s;if(s){var u=i(s)+4,h=n(l.ushln(u).divRound(r));return c*(s+h*Math.pow(2,-u))}var f=r.bitLength()-l.bitLength()+53,h=n(l.ushln(f).divRound(r));return f<1023?c*h*Math.pow(2,-f):(h*=Math.pow(2,-1023),c*h*Math.pow(2,1023-f))}},{\"./lib/bn-to-num\":81,\"./lib/ctz\":82}],91:[function(t,e,r){\"use strict\";function n(t,e,r,n,i,a){var o=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",a?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a\",i?\".get(m)\":\"[m]\"];return a?e.indexOf(\"c\")<0?o.push(\";if(x===y){return m}else if(x<=y){\"):o.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):o.push(\";if(\",e,\"){i=m;\"),r?o.push(\"l=m+1}else{h=m-1}\"):o.push(\"h=m-1}else{l=m+1}\"),o.push(\"}\"),a?o.push(\"return -1};\"):o.push(\"return i};\"),o.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],!1,i),n(\"B\",\"x\"+t+\"y\",e,[\"y\"],!0,i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!1,i),n(\"Q\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!0,i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(a.shape){if(typeof(c)==='function'){return Q(a,(l===undefined)?0:l|0,(h===undefined)?a.shape[0]-1:h|0,y,c)}else{return B(a,(c===undefined)?0:c|0,(l===undefined)?a.shape[0]-1:l|0,y)}}else{if(typeof(c)==='function'){return P(a,(l===undefined)?0:l|0,(h===undefined)?a.length-1:h|0,y,c)}else{return A(a,(c===undefined)?0:c|0,(l===undefined)?a.length-1:l|0,y)}}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],92:[function(t,e,r){\"use strict\";function n(t){var e=32;return(t&=-t)&&e--,65535&t&&(e-=16),16711935&t&&(e-=8),252645135&t&&(e-=4),858993459&t&&(e-=2),1431655765&t&&(e-=1),e}r.INT_BITS=32,r.INT_MAX=2147483647,r.INT_MIN=-1<<31,r.sign=function(t){return(t>0)-(t<0)},r.abs=function(t){var e=t>>31;return(t^e)-e},r.min=function(t,e){return e^(t^e)&-(t<e)},r.max=function(t,e){return t^(t^e)&-(t<e)},r.isPow2=function(t){return!(t&t-1||!t)},r.log2=function(t){var e,r;return e=(t>65535)<<4,e|=r=((t>>>=e)>255)<<3,e|=r=((t>>>=r)>15)<<2,(e|=r=((t>>>=r)>3)<<1)|(t>>>=r)>>1},r.log10=function(t){return t>=1e9?9:t>=1e8?8:t>=1e7?7:t>=1e6?6:t>=1e5?5:t>=1e4?4:t>=1e3?3:t>=100?2:t>=10?1:0},r.popCount=function(t){return 16843009*((t=(858993459&(t-=t>>>1&1431655765))+(t>>>2&858993459))+(t>>>4)&252645135)>>>24},r.countTrailingZeros=n,r.nextPow2=function(t){return t+=0===t,--t,t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)+1},r.prevPow2=function(t){return t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)-(t>>>1)},r.parity=function(t){return t^=t>>>16,t^=t>>>8,t^=t>>>4,27030>>>(t&=15)&1};var i=new Array(256);!function(t){for(var e=0;e<256;++e){var r=e,n=e,i=7;for(r>>>=1;r;r>>>=1)n<<=1,n|=1&r,--i;t[e]=n<<i&255}}(i),r.reverse=function(t){return i[255&t]<<24|i[t>>>8&255]<<16|i[t>>>16&255]<<8|i[t>>>24&255]},r.interleave2=function(t,e){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t&=65535)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e&=65535)|e<<8))|e<<4))|e<<2))|e<<1))<<1},r.deinterleave2=function(t,e){return(t=65535&((t=16711935&((t=252645135&((t=858993459&((t=t>>>e&1431655765)|t>>>1))|t>>>2))|t>>>4))|t>>>16))<<16>>16},r.interleave3=function(t,e,r){return t=1227133513&((t=3272356035&((t=251719695&((t=4278190335&((t&=1023)|t<<16))|t<<8))|t<<4))|t<<2),(t|=(e=1227133513&((e=3272356035&((e=251719695&((e=4278190335&((e&=1023)|e<<16))|e<<8))|e<<4))|e<<2))<<1)|(r=1227133513&((r=3272356035&((r=251719695&((r=4278190335&((r&=1023)|r<<16))|r<<8))|r<<4))|r<<2))<<2},r.deinterleave3=function(t,e){return(t=1023&((t=4278190335&((t=251719695&((t=3272356035&((t=t>>>e&1227133513)|t>>>2))|t>>>4))|t>>>8))|t>>>16))<<22>>22},r.nextCombination=function(t){var e=t|t-1;return e+1|(~e&-~e)-1>>>n(t)+1}},{}],93:[function(t,e,r){\"use strict\";var n=t(\"clamp\");e.exports=function(t,e){e||(e={});var r,o,s,l,c,u,h,f,p,d,g,v=null==e.cutoff?.25:e.cutoff,m=null==e.radius?8:e.radius,y=e.channel||0;if(ArrayBuffer.isView(t)||Array.isArray(t)){if(!e.width||!e.height)throw Error(\"For raw data width and height should be provided by options\");r=e.width,o=e.height,l=t,u=e.stride?e.stride:Math.floor(t.length/r/o)}else window.HTMLCanvasElement&&t instanceof window.HTMLCanvasElement?(h=(f=t).getContext(\"2d\"),r=f.width,o=f.height,p=h.getImageData(0,0,r,o),l=p.data,u=4):window.CanvasRenderingContext2D&&t instanceof window.CanvasRenderingContext2D?(f=t.canvas,h=t,r=f.width,o=f.height,p=h.getImageData(0,0,r,o),l=p.data,u=4):window.ImageData&&t instanceof window.ImageData&&(p=t,r=t.width,o=t.height,l=p.data,u=4);if(s=Math.max(r,o),window.Uint8ClampedArray&&l instanceof window.Uint8ClampedArray||window.Uint8Array&&l instanceof window.Uint8Array)for(c=l,l=Array(r*o),d=0,g=c.length;d<g;d++)l[d]=c[d*u+y]/255;else if(1!==u)throw Error(\"Raw data can have only 1 value per pixel\");var x=Array(r*o),b=Array(r*o),_=Array(s),w=Array(s),k=Array(s+1),T=Array(s);for(d=0,g=r*o;d<g;d++){var A=l[d];x[d]=1===A?0:0===A?i:Math.pow(Math.max(0,.5-A),2),b[d]=1===A?i:0===A?0:Math.pow(Math.max(0,A-.5),2)}a(x,r,o,_,w,T,k),a(b,r,o,_,w,T,k);var M=window.Float32Array?new Float32Array(r*o):new Array(r*o);for(d=0,g=r*o;d<g;d++)M[d]=n(1-((x[d]-b[d])/m+v),0,1);return M};var i=1e20;function a(t,e,r,n,i,a,s){for(var l=0;l<e;l++){for(var c=0;c<r;c++)n[c]=t[c*e+l];for(o(n,i,a,s,r),c=0;c<r;c++)t[c*e+l]=i[c]}for(c=0;c<r;c++){for(l=0;l<e;l++)n[l]=t[c*e+l];for(o(n,i,a,s,e),l=0;l<e;l++)t[c*e+l]=Math.sqrt(i[l])}}function o(t,e,r,n,a){r[0]=0,n[0]=-i,n[1]=+i;for(var o=1,s=0;o<a;o++){for(var l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);l<=n[s];)s--,l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);r[++s]=o,n[s]=l,n[s+1]=+i}for(o=0,s=0;o<a;o++){for(;n[s+1]<o;)s++;e[o]=(o-r[s])*(o-r[s])+t[r[s]]}}},{clamp:115}],94:[function(t,e,r){!function(e,r){\"use strict\";function n(t,e){if(!t)throw new Error(e||\"Assertion failed\")}function i(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}function a(t,e,r){if(a.isBN(t))return t;this.negative=0,this.words=null,this.length=0,this.red=null,null!==t&&(\"le\"!==e&&\"be\"!==e||(r=e,e=10),this._init(t||0,e||10,r||\"be\"))}var o;\"object\"==typeof e?e.exports=a:r.BN=a,a.BN=a,a.wordSize=26;try{o=t(\"buffer\").Buffer}catch(t){}function s(t,e,r){for(var n=0,i=Math.min(t.length,r),a=e;a<i;a++){var o=t.charCodeAt(a)-48;n<<=4,n|=o>=49&&o<=54?o-49+10:o>=17&&o<=22?o-17+10:15&o}return n}function l(t,e,r,n){for(var i=0,a=Math.min(t.length,r),o=e;o<a;o++){var s=t.charCodeAt(o)-48;i*=n,i+=s>=49?s-49+10:s>=17?s-17+10:s}return i}a.isBN=function(t){return t instanceof a||null!==t&&\"object\"==typeof t&&t.constructor.wordSize===a.wordSize&&Array.isArray(t.words)},a.max=function(t,e){return t.cmp(e)>0?t:e},a.min=function(t,e){return t.cmp(e)<0?t:e},a.prototype._init=function(t,e,r){if(\"number\"==typeof t)return this._initNumber(t,e,r);if(\"object\"==typeof t)return this._initArray(t,e,r);\"hex\"===e&&(e=16),n(e===(0|e)&&e>=2&&e<=36);var i=0;\"-\"===(t=t.toString().replace(/\\s+/g,\"\"))[0]&&i++,16===e?this._parseHex(t,i):this._parseBase(t,e,i),\"-\"===t[0]&&(this.negative=1),this.strip(),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initNumber=function(t,e,r){t<0&&(this.negative=1,t=-t),t<67108864?(this.words=[67108863&t],this.length=1):t<4503599627370496?(this.words=[67108863&t,t/67108864&67108863],this.length=2):(n(t<9007199254740992),this.words=[67108863&t,t/67108864&67108863,1],this.length=3),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initArray=function(t,e,r){if(n(\"number\"==typeof t.length),t.length<=0)return this.words=[0],this.length=1,this;this.length=Math.ceil(t.length/3),this.words=new Array(this.length);for(var i=0;i<this.length;i++)this.words[i]=0;var a,o,s=0;if(\"be\"===r)for(i=t.length-1,a=0;i>=0;i-=3)o=t[i]|t[i-1]<<8|t[i-2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);else if(\"le\"===r)for(i=0,a=0;i<t.length;i+=3)o=t[i]|t[i+1]<<8|t[i+2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);return this.strip()},a.prototype._parseHex=function(t,e){this.length=Math.ceil((t.length-e)/6),this.words=new Array(this.length);for(var r=0;r<this.length;r++)this.words[r]=0;var n,i,a=0;for(r=t.length-6,n=0;r>=e;r-=6)i=s(t,r,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303,(a+=24)>=26&&(a-=26,n++);r+6!==e&&(i=s(t,e,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303),this.strip()},a.prototype._parseBase=function(t,e,r){this.words=[0],this.length=1;for(var n=0,i=1;i<=67108863;i*=e)n++;n--,i=i/e|0;for(var a=t.length-r,o=a%n,s=Math.min(a,a-o)+r,c=0,u=r;u<s;u+=n)c=l(t,u,u+n,e),this.imuln(i),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c);if(0!==o){var h=1;for(c=l(t,u,t.length,e),u=0;u<o;u++)h*=e;this.imuln(h),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c)}},a.prototype.copy=function(t){t.words=new Array(this.length);for(var e=0;e<this.length;e++)t.words[e]=this.words[e];t.length=this.length,t.negative=this.negative,t.red=this.red},a.prototype.clone=function(){var t=new a(null);return this.copy(t),t},a.prototype._expand=function(t){for(;this.length<t;)this.words[this.length++]=0;return this},a.prototype.strip=function(){for(;this.length>1&&0===this.words[this.length-1];)this.length--;return this._normSign()},a.prototype._normSign=function(){return 1===this.length&&0===this.words[0]&&(this.negative=0),this},a.prototype.inspect=function(){return(this.red?\"<BN-R: \":\"<BN: \")+this.toString(16)+\">\"};var c=[\"\",\"0\",\"00\",\"000\",\"0000\",\"00000\",\"000000\",\"0000000\",\"00000000\",\"000000000\",\"0000000000\",\"00000000000\",\"000000000000\",\"0000000000000\",\"00000000000000\",\"000000000000000\",\"0000000000000000\",\"00000000000000000\",\"000000000000000000\",\"0000000000000000000\",\"00000000000000000000\",\"000000000000000000000\",\"0000000000000000000000\",\"00000000000000000000000\",\"000000000000000000000000\",\"0000000000000000000000000\"],u=[0,0,25,16,12,11,10,9,8,8,7,7,7,7,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5],h=[0,0,33554432,43046721,16777216,48828125,60466176,40353607,16777216,43046721,1e7,19487171,35831808,62748517,7529536,11390625,16777216,24137569,34012224,47045881,64e6,4084101,5153632,6436343,7962624,9765625,11881376,14348907,17210368,20511149,243e5,28629151,33554432,39135393,45435424,52521875,60466176];function f(t,e,r){r.negative=e.negative^t.negative;var n=t.length+e.length|0;r.length=n,n=n-1|0;var i=0|t.words[0],a=0|e.words[0],o=i*a,s=67108863&o,l=o/67108864|0;r.words[0]=s;for(var c=1;c<n;c++){for(var u=l>>>26,h=67108863&l,f=Math.min(c,e.length-1),p=Math.max(0,c-t.length+1);p<=f;p++){var d=c-p|0;u+=(o=(i=0|t.words[d])*(a=0|e.words[p])+h)/67108864|0,h=67108863&o}r.words[c]=0|h,l=0|u}return 0!==l?r.words[c]=0|l:r.length--,r.strip()}a.prototype.toString=function(t,e){var r;if(e=0|e||1,16===(t=t||10)||\"hex\"===t){r=\"\";for(var i=0,a=0,o=0;o<this.length;o++){var s=this.words[o],l=(16777215&(s<<i|a)).toString(16);r=0!==(a=s>>>24-i&16777215)||o!==this.length-1?c[6-l.length]+l+r:l+r,(i+=2)>=26&&(i-=26,o--)}for(0!==a&&(r=a.toString(16)+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}if(t===(0|t)&&t>=2&&t<=36){var f=u[t],p=h[t];r=\"\";var d=this.clone();for(d.negative=0;!d.isZero();){var g=d.modn(p).toString(t);r=(d=d.idivn(p)).isZero()?g+r:c[f-g.length]+g+r}for(this.isZero()&&(r=\"0\"+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}n(!1,\"Base should be between 2 and 36\")},a.prototype.toNumber=function(){var t=this.words[0];return 2===this.length?t+=67108864*this.words[1]:3===this.length&&1===this.words[2]?t+=4503599627370496+67108864*this.words[1]:this.length>2&&n(!1,\"Number can only safely store up to 53 bits\"),0!==this.negative?-t:t},a.prototype.toJSON=function(){return this.toString(16)},a.prototype.toBuffer=function(t,e){return n(\"undefined\"!=typeof o),this.toArrayLike(o,t,e)},a.prototype.toArray=function(t,e){return this.toArrayLike(Array,t,e)},a.prototype.toArrayLike=function(t,e,r){var i=this.byteLength(),a=r||Math.max(1,i);n(i<=a,\"byte array longer than desired length\"),n(a>0,\"Requested array length <= 0\"),this.strip();var o,s,l=\"le\"===e,c=new t(a),u=this.clone();if(l){for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[s]=o;for(;s<a;s++)c[s]=0}else{for(s=0;s<a-i;s++)c[s]=0;for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[a-s-1]=o}return c},Math.clz32?a.prototype._countBits=function(t){return 32-Math.clz32(t)}:a.prototype._countBits=function(t){var e=t,r=0;return e>=4096&&(r+=13,e>>>=13),e>=64&&(r+=7,e>>>=7),e>=8&&(r+=4,e>>>=4),e>=2&&(r+=2,e>>>=2),r+e},a.prototype._zeroBits=function(t){if(0===t)return 26;var e=t,r=0;return 0==(8191&e)&&(r+=13,e>>>=13),0==(127&e)&&(r+=7,e>>>=7),0==(15&e)&&(r+=4,e>>>=4),0==(3&e)&&(r+=2,e>>>=2),0==(1&e)&&r++,r},a.prototype.bitLength=function(){var t=this.words[this.length-1],e=this._countBits(t);return 26*(this.length-1)+e},a.prototype.zeroBits=function(){if(this.isZero())return 0;for(var t=0,e=0;e<this.length;e++){var r=this._zeroBits(this.words[e]);if(t+=r,26!==r)break}return t},a.prototype.byteLength=function(){return Math.ceil(this.bitLength()/8)},a.prototype.toTwos=function(t){return 0!==this.negative?this.abs().inotn(t).iaddn(1):this.clone()},a.prototype.fromTwos=function(t){return this.testn(t-1)?this.notn(t).iaddn(1).ineg():this.clone()},a.prototype.isNeg=function(){return 0!==this.negative},a.prototype.neg=function(){return this.clone().ineg()},a.prototype.ineg=function(){return this.isZero()||(this.negative^=1),this},a.prototype.iuor=function(t){for(;this.length<t.length;)this.words[this.length++]=0;for(var e=0;e<t.length;e++)this.words[e]=this.words[e]|t.words[e];return this.strip()},a.prototype.ior=function(t){return n(0==(this.negative|t.negative)),this.iuor(t)},a.prototype.or=function(t){return this.length>t.length?this.clone().ior(t):t.clone().ior(this)},a.prototype.uor=function(t){return this.length>t.length?this.clone().iuor(t):t.clone().iuor(this)},a.prototype.iuand=function(t){var e;e=this.length>t.length?t:this;for(var r=0;r<e.length;r++)this.words[r]=this.words[r]&t.words[r];return this.length=e.length,this.strip()},a.prototype.iand=function(t){return n(0==(this.negative|t.negative)),this.iuand(t)},a.prototype.and=function(t){return this.length>t.length?this.clone().iand(t):t.clone().iand(this)},a.prototype.uand=function(t){return this.length>t.length?this.clone().iuand(t):t.clone().iuand(this)},a.prototype.iuxor=function(t){var e,r;this.length>t.length?(e=this,r=t):(e=t,r=this);for(var n=0;n<r.length;n++)this.words[n]=e.words[n]^r.words[n];if(this!==e)for(;n<e.length;n++)this.words[n]=e.words[n];return this.length=e.length,this.strip()},a.prototype.ixor=function(t){return n(0==(this.negative|t.negative)),this.iuxor(t)},a.prototype.xor=function(t){return this.length>t.length?this.clone().ixor(t):t.clone().ixor(this)},a.prototype.uxor=function(t){return this.length>t.length?this.clone().iuxor(t):t.clone().iuxor(this)},a.prototype.inotn=function(t){n(\"number\"==typeof t&&t>=0);var e=0|Math.ceil(t/26),r=t%26;this._expand(e),r>0&&e--;for(var i=0;i<e;i++)this.words[i]=67108863&~this.words[i];return r>0&&(this.words[i]=~this.words[i]&67108863>>26-r),this.strip()},a.prototype.notn=function(t){return this.clone().inotn(t)},a.prototype.setn=function(t,e){n(\"number\"==typeof t&&t>=0);var r=t/26|0,i=t%26;return this._expand(r+1),this.words[r]=e?this.words[r]|1<<i:this.words[r]&~(1<<i),this.strip()},a.prototype.iadd=function(t){var e,r,n;if(0!==this.negative&&0===t.negative)return this.negative=0,e=this.isub(t),this.negative^=1,this._normSign();if(0===this.negative&&0!==t.negative)return t.negative=0,e=this.isub(t),t.negative=1,e._normSign();this.length>t.length?(r=this,n=t):(r=t,n=this);for(var i=0,a=0;a<n.length;a++)e=(0|r.words[a])+(0|n.words[a])+i,this.words[a]=67108863&e,i=e>>>26;for(;0!==i&&a<r.length;a++)e=(0|r.words[a])+i,this.words[a]=67108863&e,i=e>>>26;if(this.length=r.length,0!==i)this.words[this.length]=i,this.length++;else if(r!==this)for(;a<r.length;a++)this.words[a]=r.words[a];return this},a.prototype.add=function(t){var e;return 0!==t.negative&&0===this.negative?(t.negative=0,e=this.sub(t),t.negative^=1,e):0===t.negative&&0!==this.negative?(this.negative=0,e=t.sub(this),this.negative=1,e):this.length>t.length?this.clone().iadd(t):t.clone().iadd(this)},a.prototype.isub=function(t){if(0!==t.negative){t.negative=0;var e=this.iadd(t);return t.negative=1,e._normSign()}if(0!==this.negative)return this.negative=0,this.iadd(t),this.negative=1,this._normSign();var r,n,i=this.cmp(t);if(0===i)return this.negative=0,this.length=1,this.words[0]=0,this;i>0?(r=this,n=t):(r=t,n=this);for(var a=0,o=0;o<n.length;o++)a=(e=(0|r.words[o])-(0|n.words[o])+a)>>26,this.words[o]=67108863&e;for(;0!==a&&o<r.length;o++)a=(e=(0|r.words[o])+a)>>26,this.words[o]=67108863&e;if(0===a&&o<r.length&&r!==this)for(;o<r.length;o++)this.words[o]=r.words[o];return this.length=Math.max(this.length,o),r!==this&&(this.negative=1),this.strip()},a.prototype.sub=function(t){return this.clone().isub(t)};var p=function(t,e,r){var n,i,a,o=t.words,s=e.words,l=r.words,c=0,u=0|o[0],h=8191&u,f=u>>>13,p=0|o[1],d=8191&p,g=p>>>13,v=0|o[2],m=8191&v,y=v>>>13,x=0|o[3],b=8191&x,_=x>>>13,w=0|o[4],k=8191&w,T=w>>>13,A=0|o[5],M=8191&A,S=A>>>13,E=0|o[6],C=8191&E,L=E>>>13,P=0|o[7],O=8191&P,z=P>>>13,I=0|o[8],D=8191&I,R=I>>>13,F=0|o[9],B=8191&F,N=F>>>13,j=0|s[0],U=8191&j,V=j>>>13,q=0|s[1],H=8191&q,G=q>>>13,Y=0|s[2],W=8191&Y,X=Y>>>13,Z=0|s[3],J=8191&Z,K=Z>>>13,$=0|s[4],Q=8191&$,tt=$>>>13,et=0|s[5],rt=8191&et,nt=et>>>13,it=0|s[6],at=8191&it,ot=it>>>13,st=0|s[7],lt=8191&st,ct=st>>>13,ut=0|s[8],ht=8191&ut,ft=ut>>>13,pt=0|s[9],dt=8191&pt,gt=pt>>>13;r.negative=t.negative^e.negative,r.length=19;var vt=(c+(n=Math.imul(h,U))|0)+((8191&(i=(i=Math.imul(h,V))+Math.imul(f,U)|0))<<13)|0;c=((a=Math.imul(f,V))+(i>>>13)|0)+(vt>>>26)|0,vt&=67108863,n=Math.imul(d,U),i=(i=Math.imul(d,V))+Math.imul(g,U)|0,a=Math.imul(g,V);var mt=(c+(n=n+Math.imul(h,H)|0)|0)+((8191&(i=(i=i+Math.imul(h,G)|0)+Math.imul(f,H)|0))<<13)|0;c=((a=a+Math.imul(f,G)|0)+(i>>>13)|0)+(mt>>>26)|0,mt&=67108863,n=Math.imul(m,U),i=(i=Math.imul(m,V))+Math.imul(y,U)|0,a=Math.imul(y,V),n=n+Math.imul(d,H)|0,i=(i=i+Math.imul(d,G)|0)+Math.imul(g,H)|0,a=a+Math.imul(g,G)|0;var yt=(c+(n=n+Math.imul(h,W)|0)|0)+((8191&(i=(i=i+Math.imul(h,X)|0)+Math.imul(f,W)|0))<<13)|0;c=((a=a+Math.imul(f,X)|0)+(i>>>13)|0)+(yt>>>26)|0,yt&=67108863,n=Math.imul(b,U),i=(i=Math.imul(b,V))+Math.imul(_,U)|0,a=Math.imul(_,V),n=n+Math.imul(m,H)|0,i=(i=i+Math.imul(m,G)|0)+Math.imul(y,H)|0,a=a+Math.imul(y,G)|0,n=n+Math.imul(d,W)|0,i=(i=i+Math.imul(d,X)|0)+Math.imul(g,W)|0,a=a+Math.imul(g,X)|0;var xt=(c+(n=n+Math.imul(h,J)|0)|0)+((8191&(i=(i=i+Math.imul(h,K)|0)+Math.imul(f,J)|0))<<13)|0;c=((a=a+Math.imul(f,K)|0)+(i>>>13)|0)+(xt>>>26)|0,xt&=67108863,n=Math.imul(k,U),i=(i=Math.imul(k,V))+Math.imul(T,U)|0,a=Math.imul(T,V),n=n+Math.imul(b,H)|0,i=(i=i+Math.imul(b,G)|0)+Math.imul(_,H)|0,a=a+Math.imul(_,G)|0,n=n+Math.imul(m,W)|0,i=(i=i+Math.imul(m,X)|0)+Math.imul(y,W)|0,a=a+Math.imul(y,X)|0,n=n+Math.imul(d,J)|0,i=(i=i+Math.imul(d,K)|0)+Math.imul(g,J)|0,a=a+Math.imul(g,K)|0;var bt=(c+(n=n+Math.imul(h,Q)|0)|0)+((8191&(i=(i=i+Math.imul(h,tt)|0)+Math.imul(f,Q)|0))<<13)|0;c=((a=a+Math.imul(f,tt)|0)+(i>>>13)|0)+(bt>>>26)|0,bt&=67108863,n=Math.imul(M,U),i=(i=Math.imul(M,V))+Math.imul(S,U)|0,a=Math.imul(S,V),n=n+Math.imul(k,H)|0,i=(i=i+Math.imul(k,G)|0)+Math.imul(T,H)|0,a=a+Math.imul(T,G)|0,n=n+Math.imul(b,W)|0,i=(i=i+Math.imul(b,X)|0)+Math.imul(_,W)|0,a=a+Math.imul(_,X)|0,n=n+Math.imul(m,J)|0,i=(i=i+Math.imul(m,K)|0)+Math.imul(y,J)|0,a=a+Math.imul(y,K)|0,n=n+Math.imul(d,Q)|0,i=(i=i+Math.imul(d,tt)|0)+Math.imul(g,Q)|0,a=a+Math.imul(g,tt)|0;var _t=(c+(n=n+Math.imul(h,rt)|0)|0)+((8191&(i=(i=i+Math.imul(h,nt)|0)+Math.imul(f,rt)|0))<<13)|0;c=((a=a+Math.imul(f,nt)|0)+(i>>>13)|0)+(_t>>>26)|0,_t&=67108863,n=Math.imul(C,U),i=(i=Math.imul(C,V))+Math.imul(L,U)|0,a=Math.imul(L,V),n=n+Math.imul(M,H)|0,i=(i=i+Math.imul(M,G)|0)+Math.imul(S,H)|0,a=a+Math.imul(S,G)|0,n=n+Math.imul(k,W)|0,i=(i=i+Math.imul(k,X)|0)+Math.imul(T,W)|0,a=a+Math.imul(T,X)|0,n=n+Math.imul(b,J)|0,i=(i=i+Math.imul(b,K)|0)+Math.imul(_,J)|0,a=a+Math.imul(_,K)|0,n=n+Math.imul(m,Q)|0,i=(i=i+Math.imul(m,tt)|0)+Math.imul(y,Q)|0,a=a+Math.imul(y,tt)|0,n=n+Math.imul(d,rt)|0,i=(i=i+Math.imul(d,nt)|0)+Math.imul(g,rt)|0,a=a+Math.imul(g,nt)|0;var wt=(c+(n=n+Math.imul(h,at)|0)|0)+((8191&(i=(i=i+Math.imul(h,ot)|0)+Math.imul(f,at)|0))<<13)|0;c=((a=a+Math.imul(f,ot)|0)+(i>>>13)|0)+(wt>>>26)|0,wt&=67108863,n=Math.imul(O,U),i=(i=Math.imul(O,V))+Math.imul(z,U)|0,a=Math.imul(z,V),n=n+Math.imul(C,H)|0,i=(i=i+Math.imul(C,G)|0)+Math.imul(L,H)|0,a=a+Math.imul(L,G)|0,n=n+Math.imul(M,W)|0,i=(i=i+Math.imul(M,X)|0)+Math.imul(S,W)|0,a=a+Math.imul(S,X)|0,n=n+Math.imul(k,J)|0,i=(i=i+Math.imul(k,K)|0)+Math.imul(T,J)|0,a=a+Math.imul(T,K)|0,n=n+Math.imul(b,Q)|0,i=(i=i+Math.imul(b,tt)|0)+Math.imul(_,Q)|0,a=a+Math.imul(_,tt)|0,n=n+Math.imul(m,rt)|0,i=(i=i+Math.imul(m,nt)|0)+Math.imul(y,rt)|0,a=a+Math.imul(y,nt)|0,n=n+Math.imul(d,at)|0,i=(i=i+Math.imul(d,ot)|0)+Math.imul(g,at)|0,a=a+Math.imul(g,ot)|0;var kt=(c+(n=n+Math.imul(h,lt)|0)|0)+((8191&(i=(i=i+Math.imul(h,ct)|0)+Math.imul(f,lt)|0))<<13)|0;c=((a=a+Math.imul(f,ct)|0)+(i>>>13)|0)+(kt>>>26)|0,kt&=67108863,n=Math.imul(D,U),i=(i=Math.imul(D,V))+Math.imul(R,U)|0,a=Math.imul(R,V),n=n+Math.imul(O,H)|0,i=(i=i+Math.imul(O,G)|0)+Math.imul(z,H)|0,a=a+Math.imul(z,G)|0,n=n+Math.imul(C,W)|0,i=(i=i+Math.imul(C,X)|0)+Math.imul(L,W)|0,a=a+Math.imul(L,X)|0,n=n+Math.imul(M,J)|0,i=(i=i+Math.imul(M,K)|0)+Math.imul(S,J)|0,a=a+Math.imul(S,K)|0,n=n+Math.imul(k,Q)|0,i=(i=i+Math.imul(k,tt)|0)+Math.imul(T,Q)|0,a=a+Math.imul(T,tt)|0,n=n+Math.imul(b,rt)|0,i=(i=i+Math.imul(b,nt)|0)+Math.imul(_,rt)|0,a=a+Math.imul(_,nt)|0,n=n+Math.imul(m,at)|0,i=(i=i+Math.imul(m,ot)|0)+Math.imul(y,at)|0,a=a+Math.imul(y,ot)|0,n=n+Math.imul(d,lt)|0,i=(i=i+Math.imul(d,ct)|0)+Math.imul(g,lt)|0,a=a+Math.imul(g,ct)|0;var Tt=(c+(n=n+Math.imul(h,ht)|0)|0)+((8191&(i=(i=i+Math.imul(h,ft)|0)+Math.imul(f,ht)|0))<<13)|0;c=((a=a+Math.imul(f,ft)|0)+(i>>>13)|0)+(Tt>>>26)|0,Tt&=67108863,n=Math.imul(B,U),i=(i=Math.imul(B,V))+Math.imul(N,U)|0,a=Math.imul(N,V),n=n+Math.imul(D,H)|0,i=(i=i+Math.imul(D,G)|0)+Math.imul(R,H)|0,a=a+Math.imul(R,G)|0,n=n+Math.imul(O,W)|0,i=(i=i+Math.imul(O,X)|0)+Math.imul(z,W)|0,a=a+Math.imul(z,X)|0,n=n+Math.imul(C,J)|0,i=(i=i+Math.imul(C,K)|0)+Math.imul(L,J)|0,a=a+Math.imul(L,K)|0,n=n+Math.imul(M,Q)|0,i=(i=i+Math.imul(M,tt)|0)+Math.imul(S,Q)|0,a=a+Math.imul(S,tt)|0,n=n+Math.imul(k,rt)|0,i=(i=i+Math.imul(k,nt)|0)+Math.imul(T,rt)|0,a=a+Math.imul(T,nt)|0,n=n+Math.imul(b,at)|0,i=(i=i+Math.imul(b,ot)|0)+Math.imul(_,at)|0,a=a+Math.imul(_,ot)|0,n=n+Math.imul(m,lt)|0,i=(i=i+Math.imul(m,ct)|0)+Math.imul(y,lt)|0,a=a+Math.imul(y,ct)|0,n=n+Math.imul(d,ht)|0,i=(i=i+Math.imul(d,ft)|0)+Math.imul(g,ht)|0,a=a+Math.imul(g,ft)|0;var At=(c+(n=n+Math.imul(h,dt)|0)|0)+((8191&(i=(i=i+Math.imul(h,gt)|0)+Math.imul(f,dt)|0))<<13)|0;c=((a=a+Math.imul(f,gt)|0)+(i>>>13)|0)+(At>>>26)|0,At&=67108863,n=Math.imul(B,H),i=(i=Math.imul(B,G))+Math.imul(N,H)|0,a=Math.imul(N,G),n=n+Math.imul(D,W)|0,i=(i=i+Math.imul(D,X)|0)+Math.imul(R,W)|0,a=a+Math.imul(R,X)|0,n=n+Math.imul(O,J)|0,i=(i=i+Math.imul(O,K)|0)+Math.imul(z,J)|0,a=a+Math.imul(z,K)|0,n=n+Math.imul(C,Q)|0,i=(i=i+Math.imul(C,tt)|0)+Math.imul(L,Q)|0,a=a+Math.imul(L,tt)|0,n=n+Math.imul(M,rt)|0,i=(i=i+Math.imul(M,nt)|0)+Math.imul(S,rt)|0,a=a+Math.imul(S,nt)|0,n=n+Math.imul(k,at)|0,i=(i=i+Math.imul(k,ot)|0)+Math.imul(T,at)|0,a=a+Math.imul(T,ot)|0,n=n+Math.imul(b,lt)|0,i=(i=i+Math.imul(b,ct)|0)+Math.imul(_,lt)|0,a=a+Math.imul(_,ct)|0,n=n+Math.imul(m,ht)|0,i=(i=i+Math.imul(m,ft)|0)+Math.imul(y,ht)|0,a=a+Math.imul(y,ft)|0;var Mt=(c+(n=n+Math.imul(d,dt)|0)|0)+((8191&(i=(i=i+Math.imul(d,gt)|0)+Math.imul(g,dt)|0))<<13)|0;c=((a=a+Math.imul(g,gt)|0)+(i>>>13)|0)+(Mt>>>26)|0,Mt&=67108863,n=Math.imul(B,W),i=(i=Math.imul(B,X))+Math.imul(N,W)|0,a=Math.imul(N,X),n=n+Math.imul(D,J)|0,i=(i=i+Math.imul(D,K)|0)+Math.imul(R,J)|0,a=a+Math.imul(R,K)|0,n=n+Math.imul(O,Q)|0,i=(i=i+Math.imul(O,tt)|0)+Math.imul(z,Q)|0,a=a+Math.imul(z,tt)|0,n=n+Math.imul(C,rt)|0,i=(i=i+Math.imul(C,nt)|0)+Math.imul(L,rt)|0,a=a+Math.imul(L,nt)|0,n=n+Math.imul(M,at)|0,i=(i=i+Math.imul(M,ot)|0)+Math.imul(S,at)|0,a=a+Math.imul(S,ot)|0,n=n+Math.imul(k,lt)|0,i=(i=i+Math.imul(k,ct)|0)+Math.imul(T,lt)|0,a=a+Math.imul(T,ct)|0,n=n+Math.imul(b,ht)|0,i=(i=i+Math.imul(b,ft)|0)+Math.imul(_,ht)|0,a=a+Math.imul(_,ft)|0;var St=(c+(n=n+Math.imul(m,dt)|0)|0)+((8191&(i=(i=i+Math.imul(m,gt)|0)+Math.imul(y,dt)|0))<<13)|0;c=((a=a+Math.imul(y,gt)|0)+(i>>>13)|0)+(St>>>26)|0,St&=67108863,n=Math.imul(B,J),i=(i=Math.imul(B,K))+Math.imul(N,J)|0,a=Math.imul(N,K),n=n+Math.imul(D,Q)|0,i=(i=i+Math.imul(D,tt)|0)+Math.imul(R,Q)|0,a=a+Math.imul(R,tt)|0,n=n+Math.imul(O,rt)|0,i=(i=i+Math.imul(O,nt)|0)+Math.imul(z,rt)|0,a=a+Math.imul(z,nt)|0,n=n+Math.imul(C,at)|0,i=(i=i+Math.imul(C,ot)|0)+Math.imul(L,at)|0,a=a+Math.imul(L,ot)|0,n=n+Math.imul(M,lt)|0,i=(i=i+Math.imul(M,ct)|0)+Math.imul(S,lt)|0,a=a+Math.imul(S,ct)|0,n=n+Math.imul(k,ht)|0,i=(i=i+Math.imul(k,ft)|0)+Math.imul(T,ht)|0,a=a+Math.imul(T,ft)|0;var Et=(c+(n=n+Math.imul(b,dt)|0)|0)+((8191&(i=(i=i+Math.imul(b,gt)|0)+Math.imul(_,dt)|0))<<13)|0;c=((a=a+Math.imul(_,gt)|0)+(i>>>13)|0)+(Et>>>26)|0,Et&=67108863,n=Math.imul(B,Q),i=(i=Math.imul(B,tt))+Math.imul(N,Q)|0,a=Math.imul(N,tt),n=n+Math.imul(D,rt)|0,i=(i=i+Math.imul(D,nt)|0)+Math.imul(R,rt)|0,a=a+Math.imul(R,nt)|0,n=n+Math.imul(O,at)|0,i=(i=i+Math.imul(O,ot)|0)+Math.imul(z,at)|0,a=a+Math.imul(z,ot)|0,n=n+Math.imul(C,lt)|0,i=(i=i+Math.imul(C,ct)|0)+Math.imul(L,lt)|0,a=a+Math.imul(L,ct)|0,n=n+Math.imul(M,ht)|0,i=(i=i+Math.imul(M,ft)|0)+Math.imul(S,ht)|0,a=a+Math.imul(S,ft)|0;var Ct=(c+(n=n+Math.imul(k,dt)|0)|0)+((8191&(i=(i=i+Math.imul(k,gt)|0)+Math.imul(T,dt)|0))<<13)|0;c=((a=a+Math.imul(T,gt)|0)+(i>>>13)|0)+(Ct>>>26)|0,Ct&=67108863,n=Math.imul(B,rt),i=(i=Math.imul(B,nt))+Math.imul(N,rt)|0,a=Math.imul(N,nt),n=n+Math.imul(D,at)|0,i=(i=i+Math.imul(D,ot)|0)+Math.imul(R,at)|0,a=a+Math.imul(R,ot)|0,n=n+Math.imul(O,lt)|0,i=(i=i+Math.imul(O,ct)|0)+Math.imul(z,lt)|0,a=a+Math.imul(z,ct)|0,n=n+Math.imul(C,ht)|0,i=(i=i+Math.imul(C,ft)|0)+Math.imul(L,ht)|0,a=a+Math.imul(L,ft)|0;var Lt=(c+(n=n+Math.imul(M,dt)|0)|0)+((8191&(i=(i=i+Math.imul(M,gt)|0)+Math.imul(S,dt)|0))<<13)|0;c=((a=a+Math.imul(S,gt)|0)+(i>>>13)|0)+(Lt>>>26)|0,Lt&=67108863,n=Math.imul(B,at),i=(i=Math.imul(B,ot))+Math.imul(N,at)|0,a=Math.imul(N,ot),n=n+Math.imul(D,lt)|0,i=(i=i+Math.imul(D,ct)|0)+Math.imul(R,lt)|0,a=a+Math.imul(R,ct)|0,n=n+Math.imul(O,ht)|0,i=(i=i+Math.imul(O,ft)|0)+Math.imul(z,ht)|0,a=a+Math.imul(z,ft)|0;var Pt=(c+(n=n+Math.imul(C,dt)|0)|0)+((8191&(i=(i=i+Math.imul(C,gt)|0)+Math.imul(L,dt)|0))<<13)|0;c=((a=a+Math.imul(L,gt)|0)+(i>>>13)|0)+(Pt>>>26)|0,Pt&=67108863,n=Math.imul(B,lt),i=(i=Math.imul(B,ct))+Math.imul(N,lt)|0,a=Math.imul(N,ct),n=n+Math.imul(D,ht)|0,i=(i=i+Math.imul(D,ft)|0)+Math.imul(R,ht)|0,a=a+Math.imul(R,ft)|0;var Ot=(c+(n=n+Math.imul(O,dt)|0)|0)+((8191&(i=(i=i+Math.imul(O,gt)|0)+Math.imul(z,dt)|0))<<13)|0;c=((a=a+Math.imul(z,gt)|0)+(i>>>13)|0)+(Ot>>>26)|0,Ot&=67108863,n=Math.imul(B,ht),i=(i=Math.imul(B,ft))+Math.imul(N,ht)|0,a=Math.imul(N,ft);var zt=(c+(n=n+Math.imul(D,dt)|0)|0)+((8191&(i=(i=i+Math.imul(D,gt)|0)+Math.imul(R,dt)|0))<<13)|0;c=((a=a+Math.imul(R,gt)|0)+(i>>>13)|0)+(zt>>>26)|0,zt&=67108863;var It=(c+(n=Math.imul(B,dt))|0)+((8191&(i=(i=Math.imul(B,gt))+Math.imul(N,dt)|0))<<13)|0;return c=((a=Math.imul(N,gt))+(i>>>13)|0)+(It>>>26)|0,It&=67108863,l[0]=vt,l[1]=mt,l[2]=yt,l[3]=xt,l[4]=bt,l[5]=_t,l[6]=wt,l[7]=kt,l[8]=Tt,l[9]=At,l[10]=Mt,l[11]=St,l[12]=Et,l[13]=Ct,l[14]=Lt,l[15]=Pt,l[16]=Ot,l[17]=zt,l[18]=It,0!==c&&(l[19]=c,r.length++),r};function d(t,e,r){return(new g).mulp(t,e,r)}function g(t,e){this.x=t,this.y=e}Math.imul||(p=f),a.prototype.mulTo=function(t,e){var r=this.length+t.length;return 10===this.length&&10===t.length?p(this,t,e):r<63?f(this,t,e):r<1024?function(t,e,r){r.negative=e.negative^t.negative,r.length=t.length+e.length;for(var n=0,i=0,a=0;a<r.length-1;a++){var o=i;i=0;for(var s=67108863&n,l=Math.min(a,e.length-1),c=Math.max(0,a-t.length+1);c<=l;c++){var u=a-c,h=(0|t.words[u])*(0|e.words[c]),f=67108863&h;s=67108863&(f=f+s|0),i+=(o=(o=o+(h/67108864|0)|0)+(f>>>26)|0)>>>26,o&=67108863}r.words[a]=s,n=o,o=i}return 0!==n?r.words[a]=n:r.length--,r.strip()}(this,t,e):d(this,t,e)},g.prototype.makeRBT=function(t){for(var e=new Array(t),r=a.prototype._countBits(t)-1,n=0;n<t;n++)e[n]=this.revBin(n,r,t);return e},g.prototype.revBin=function(t,e,r){if(0===t||t===r-1)return t;for(var n=0,i=0;i<e;i++)n|=(1&t)<<e-i-1,t>>=1;return n},g.prototype.permute=function(t,e,r,n,i,a){for(var o=0;o<a;o++)n[o]=e[t[o]],i[o]=r[t[o]]},g.prototype.transform=function(t,e,r,n,i,a){this.permute(a,t,e,r,n,i);for(var o=1;o<i;o<<=1)for(var s=o<<1,l=Math.cos(2*Math.PI/s),c=Math.sin(2*Math.PI/s),u=0;u<i;u+=s)for(var h=l,f=c,p=0;p<o;p++){var d=r[u+p],g=n[u+p],v=r[u+p+o],m=n[u+p+o],y=h*v-f*m;m=h*m+f*v,v=y,r[u+p]=d+v,n[u+p]=g+m,r[u+p+o]=d-v,n[u+p+o]=g-m,p!==s&&(y=l*h-c*f,f=l*f+c*h,h=y)}},g.prototype.guessLen13b=function(t,e){var r=1|Math.max(e,t),n=1&r,i=0;for(r=r/2|0;r;r>>>=1)i++;return 1<<i+1+n},g.prototype.conjugate=function(t,e,r){if(!(r<=1))for(var n=0;n<r/2;n++){var i=t[n];t[n]=t[r-n-1],t[r-n-1]=i,i=e[n],e[n]=-e[r-n-1],e[r-n-1]=-i}},g.prototype.normalize13b=function(t,e){for(var r=0,n=0;n<e/2;n++){var i=8192*Math.round(t[2*n+1]/e)+Math.round(t[2*n]/e)+r;t[n]=67108863&i,r=i<67108864?0:i/67108864|0}return t},g.prototype.convert13b=function(t,e,r,i){for(var a=0,o=0;o<e;o++)a+=0|t[o],r[2*o]=8191&a,a>>>=13,r[2*o+1]=8191&a,a>>>=13;for(o=2*e;o<i;++o)r[o]=0;n(0===a),n(0==(-8192&a))},g.prototype.stub=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=0;return e},g.prototype.mulp=function(t,e,r){var n=2*this.guessLen13b(t.length,e.length),i=this.makeRBT(n),a=this.stub(n),o=new Array(n),s=new Array(n),l=new Array(n),c=new Array(n),u=new Array(n),h=new Array(n),f=r.words;f.length=n,this.convert13b(t.words,t.length,o,n),this.convert13b(e.words,e.length,c,n),this.transform(o,a,s,l,n,i),this.transform(c,a,u,h,n,i);for(var p=0;p<n;p++){var d=s[p]*u[p]-l[p]*h[p];l[p]=s[p]*h[p]+l[p]*u[p],s[p]=d}return this.conjugate(s,l,n),this.transform(s,l,f,a,n,i),this.conjugate(f,a,n),this.normalize13b(f,n),r.negative=t.negative^e.negative,r.length=t.length+e.length,r.strip()},a.prototype.mul=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),this.mulTo(t,e)},a.prototype.mulf=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),d(this,t,e)},a.prototype.imul=function(t){return this.clone().mulTo(t,this)},a.prototype.imuln=function(t){n(\"number\"==typeof t),n(t<67108864);for(var e=0,r=0;r<this.length;r++){var i=(0|this.words[r])*t,a=(67108863&i)+(67108863&e);e>>=26,e+=i/67108864|0,e+=a>>>26,this.words[r]=67108863&a}return 0!==e&&(this.words[r]=e,this.length++),this},a.prototype.muln=function(t){return this.clone().imuln(t)},a.prototype.sqr=function(){return this.mul(this)},a.prototype.isqr=function(){return this.imul(this.clone())},a.prototype.pow=function(t){var e=function(t){for(var e=new Array(t.bitLength()),r=0;r<e.length;r++){var n=r/26|0,i=r%26;e[r]=(t.words[n]&1<<i)>>>i}return e}(t);if(0===e.length)return new a(1);for(var r=this,n=0;n<e.length&&0===e[n];n++,r=r.sqr());if(++n<e.length)for(var i=r.sqr();n<e.length;n++,i=i.sqr())0!==e[n]&&(r=r.mul(i));return r},a.prototype.iushln=function(t){n(\"number\"==typeof t&&t>=0);var e,r=t%26,i=(t-r)/26,a=67108863>>>26-r<<26-r;if(0!==r){var o=0;for(e=0;e<this.length;e++){var s=this.words[e]&a,l=(0|this.words[e])-s<<r;this.words[e]=l|o,o=s>>>26-r}o&&(this.words[e]=o,this.length++)}if(0!==i){for(e=this.length-1;e>=0;e--)this.words[e+i]=this.words[e];for(e=0;e<i;e++)this.words[e]=0;this.length+=i}return this.strip()},a.prototype.ishln=function(t){return n(0===this.negative),this.iushln(t)},a.prototype.iushrn=function(t,e,r){var i;n(\"number\"==typeof t&&t>=0),i=e?(e-e%26)/26:0;var a=t%26,o=Math.min((t-a)/26,this.length),s=67108863^67108863>>>a<<a,l=r;if(i-=o,i=Math.max(0,i),l){for(var c=0;c<o;c++)l.words[c]=this.words[c];l.length=o}if(0===o);else if(this.length>o)for(this.length-=o,c=0;c<this.length;c++)this.words[c]=this.words[c+o];else this.words[0]=0,this.length=1;var u=0;for(c=this.length-1;c>=0&&(0!==u||c>=i);c--){var h=0|this.words[c];this.words[c]=u<<26-a|h>>>a,u=h&s}return l&&0!==u&&(l.words[l.length++]=u),0===this.length&&(this.words[0]=0,this.length=1),this.strip()},a.prototype.ishrn=function(t,e,r){return n(0===this.negative),this.iushrn(t,e,r)},a.prototype.shln=function(t){return this.clone().ishln(t)},a.prototype.ushln=function(t){return this.clone().iushln(t)},a.prototype.shrn=function(t){return this.clone().ishrn(t)},a.prototype.ushrn=function(t){return this.clone().iushrn(t)},a.prototype.testn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26,i=1<<e;return!(this.length<=r)&&!!(this.words[r]&i)},a.prototype.imaskn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26;if(n(0===this.negative,\"imaskn works only with positive numbers\"),this.length<=r)return this;if(0!==e&&r++,this.length=Math.min(r,this.length),0!==e){var i=67108863^67108863>>>e<<e;this.words[this.length-1]&=i}return this.strip()},a.prototype.maskn=function(t){return this.clone().imaskn(t)},a.prototype.iaddn=function(t){return n(\"number\"==typeof t),n(t<67108864),t<0?this.isubn(-t):0!==this.negative?1===this.length&&(0|this.words[0])<t?(this.words[0]=t-(0|this.words[0]),this.negative=0,this):(this.negative=0,this.isubn(t),this.negative=1,this):this._iaddn(t)},a.prototype._iaddn=function(t){this.words[0]+=t;for(var e=0;e<this.length&&this.words[e]>=67108864;e++)this.words[e]-=67108864,e===this.length-1?this.words[e+1]=1:this.words[e+1]++;return this.length=Math.max(this.length,e+1),this},a.prototype.isubn=function(t){if(n(\"number\"==typeof t),n(t<67108864),t<0)return this.iaddn(-t);if(0!==this.negative)return this.negative=0,this.iaddn(t),this.negative=1,this;if(this.words[0]-=t,1===this.length&&this.words[0]<0)this.words[0]=-this.words[0],this.negative=1;else for(var e=0;e<this.length&&this.words[e]<0;e++)this.words[e]+=67108864,this.words[e+1]-=1;return this.strip()},a.prototype.addn=function(t){return this.clone().iaddn(t)},a.prototype.subn=function(t){return this.clone().isubn(t)},a.prototype.iabs=function(){return this.negative=0,this},a.prototype.abs=function(){return this.clone().iabs()},a.prototype._ishlnsubmul=function(t,e,r){var i,a,o=t.length+r;this._expand(o);var s=0;for(i=0;i<t.length;i++){a=(0|this.words[i+r])+s;var l=(0|t.words[i])*e;s=((a-=67108863&l)>>26)-(l/67108864|0),this.words[i+r]=67108863&a}for(;i<this.length-r;i++)s=(a=(0|this.words[i+r])+s)>>26,this.words[i+r]=67108863&a;if(0===s)return this.strip();for(n(-1===s),s=0,i=0;i<this.length;i++)s=(a=-(0|this.words[i])+s)>>26,this.words[i]=67108863&a;return this.negative=1,this.strip()},a.prototype._wordDiv=function(t,e){var r=(this.length,t.length),n=this.clone(),i=t,o=0|i.words[i.length-1];0!==(r=26-this._countBits(o))&&(i=i.ushln(r),n.iushln(r),o=0|i.words[i.length-1]);var s,l=n.length-i.length;if(\"mod\"!==e){(s=new a(null)).length=l+1,s.words=new Array(s.length);for(var c=0;c<s.length;c++)s.words[c]=0}var u=n.clone()._ishlnsubmul(i,1,l);0===u.negative&&(n=u,s&&(s.words[l]=1));for(var h=l-1;h>=0;h--){var f=67108864*(0|n.words[i.length+h])+(0|n.words[i.length+h-1]);for(f=Math.min(f/o|0,67108863),n._ishlnsubmul(i,f,h);0!==n.negative;)f--,n.negative=0,n._ishlnsubmul(i,1,h),n.isZero()||(n.negative^=1);s&&(s.words[h]=f)}return s&&s.strip(),n.strip(),\"div\"!==e&&0!==r&&n.iushrn(r),{div:s||null,mod:n}},a.prototype.divmod=function(t,e,r){return n(!t.isZero()),this.isZero()?{div:new a(0),mod:new a(0)}:0!==this.negative&&0===t.negative?(s=this.neg().divmod(t,e),\"mod\"!==e&&(i=s.div.neg()),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.iadd(t)),{div:i,mod:o}):0===this.negative&&0!==t.negative?(s=this.divmod(t.neg(),e),\"mod\"!==e&&(i=s.div.neg()),{div:i,mod:s.mod}):0!=(this.negative&t.negative)?(s=this.neg().divmod(t.neg(),e),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.isub(t)),{div:s.div,mod:o}):t.length>this.length||this.cmp(t)<0?{div:new a(0),mod:this}:1===t.length?\"div\"===e?{div:this.divn(t.words[0]),mod:null}:\"mod\"===e?{div:null,mod:new a(this.modn(t.words[0]))}:{div:this.divn(t.words[0]),mod:new a(this.modn(t.words[0]))}:this._wordDiv(t,e);var i,o,s},a.prototype.div=function(t){return this.divmod(t,\"div\",!1).div},a.prototype.mod=function(t){return this.divmod(t,\"mod\",!1).mod},a.prototype.umod=function(t){return this.divmod(t,\"mod\",!0).mod},a.prototype.divRound=function(t){var e=this.divmod(t);if(e.mod.isZero())return e.div;var r=0!==e.div.negative?e.mod.isub(t):e.mod,n=t.ushrn(1),i=t.andln(1),a=r.cmp(n);return a<0||1===i&&0===a?e.div:0!==e.div.negative?e.div.isubn(1):e.div.iaddn(1)},a.prototype.modn=function(t){n(t<=67108863);for(var e=(1<<26)%t,r=0,i=this.length-1;i>=0;i--)r=(e*r+(0|this.words[i]))%t;return r},a.prototype.idivn=function(t){n(t<=67108863);for(var e=0,r=this.length-1;r>=0;r--){var i=(0|this.words[r])+67108864*e;this.words[r]=i/t|0,e=i%t}return this.strip()},a.prototype.divn=function(t){return this.clone().idivn(t)},a.prototype.egcd=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i=new a(1),o=new a(0),s=new a(0),l=new a(1),c=0;e.isEven()&&r.isEven();)e.iushrn(1),r.iushrn(1),++c;for(var u=r.clone(),h=e.clone();!e.isZero();){for(var f=0,p=1;0==(e.words[0]&p)&&f<26;++f,p<<=1);if(f>0)for(e.iushrn(f);f-- >0;)(i.isOdd()||o.isOdd())&&(i.iadd(u),o.isub(h)),i.iushrn(1),o.iushrn(1);for(var d=0,g=1;0==(r.words[0]&g)&&d<26;++d,g<<=1);if(d>0)for(r.iushrn(d);d-- >0;)(s.isOdd()||l.isOdd())&&(s.iadd(u),l.isub(h)),s.iushrn(1),l.iushrn(1);e.cmp(r)>=0?(e.isub(r),i.isub(s),o.isub(l)):(r.isub(e),s.isub(i),l.isub(o))}return{a:s,b:l,gcd:r.iushln(c)}},a.prototype._invmp=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i,o=new a(1),s=new a(0),l=r.clone();e.cmpn(1)>0&&r.cmpn(1)>0;){for(var c=0,u=1;0==(e.words[0]&u)&&c<26;++c,u<<=1);if(c>0)for(e.iushrn(c);c-- >0;)o.isOdd()&&o.iadd(l),o.iushrn(1);for(var h=0,f=1;0==(r.words[0]&f)&&h<26;++h,f<<=1);if(h>0)for(r.iushrn(h);h-- >0;)s.isOdd()&&s.iadd(l),s.iushrn(1);e.cmp(r)>=0?(e.isub(r),o.isub(s)):(r.isub(e),s.isub(o))}return(i=0===e.cmpn(1)?o:s).cmpn(0)<0&&i.iadd(t),i},a.prototype.gcd=function(t){if(this.isZero())return t.abs();if(t.isZero())return this.abs();var e=this.clone(),r=t.clone();e.negative=0,r.negative=0;for(var n=0;e.isEven()&&r.isEven();n++)e.iushrn(1),r.iushrn(1);for(;;){for(;e.isEven();)e.iushrn(1);for(;r.isEven();)r.iushrn(1);var i=e.cmp(r);if(i<0){var a=e;e=r,r=a}else if(0===i||0===r.cmpn(1))break;e.isub(r)}return r.iushln(n)},a.prototype.invm=function(t){return this.egcd(t).a.umod(t)},a.prototype.isEven=function(){return 0==(1&this.words[0])},a.prototype.isOdd=function(){return 1==(1&this.words[0])},a.prototype.andln=function(t){return this.words[0]&t},a.prototype.bincn=function(t){n(\"number\"==typeof t);var e=t%26,r=(t-e)/26,i=1<<e;if(this.length<=r)return this._expand(r+1),this.words[r]|=i,this;for(var a=i,o=r;0!==a&&o<this.length;o++){var s=0|this.words[o];a=(s+=a)>>>26,s&=67108863,this.words[o]=s}return 0!==a&&(this.words[o]=a,this.length++),this},a.prototype.isZero=function(){return 1===this.length&&0===this.words[0]},a.prototype.cmpn=function(t){var e,r=t<0;if(0!==this.negative&&!r)return-1;if(0===this.negative&&r)return 1;if(this.strip(),this.length>1)e=1;else{r&&(t=-t),n(t<=67108863,\"Number is too big\");var i=0|this.words[0];e=i===t?0:i<t?-1:1}return 0!==this.negative?0|-e:e},a.prototype.cmp=function(t){if(0!==this.negative&&0===t.negative)return-1;if(0===this.negative&&0!==t.negative)return 1;var e=this.ucmp(t);return 0!==this.negative?0|-e:e},a.prototype.ucmp=function(t){if(this.length>t.length)return 1;if(this.length<t.length)return-1;for(var e=0,r=this.length-1;r>=0;r--){var n=0|this.words[r],i=0|t.words[r];if(n!==i){n<i?e=-1:n>i&&(e=1);break}}return e},a.prototype.gtn=function(t){return 1===this.cmpn(t)},a.prototype.gt=function(t){return 1===this.cmp(t)},a.prototype.gten=function(t){return this.cmpn(t)>=0},a.prototype.gte=function(t){return this.cmp(t)>=0},a.prototype.ltn=function(t){return-1===this.cmpn(t)},a.prototype.lt=function(t){return-1===this.cmp(t)},a.prototype.lten=function(t){return this.cmpn(t)<=0},a.prototype.lte=function(t){return this.cmp(t)<=0},a.prototype.eqn=function(t){return 0===this.cmpn(t)},a.prototype.eq=function(t){return 0===this.cmp(t)},a.red=function(t){return new w(t)},a.prototype.toRed=function(t){return n(!this.red,\"Already a number in reduction context\"),n(0===this.negative,\"red works only with positives\"),t.convertTo(this)._forceRed(t)},a.prototype.fromRed=function(){return n(this.red,\"fromRed works only with numbers in reduction context\"),this.red.convertFrom(this)},a.prototype._forceRed=function(t){return this.red=t,this},a.prototype.forceRed=function(t){return n(!this.red,\"Already a number in reduction context\"),this._forceRed(t)},a.prototype.redAdd=function(t){return n(this.red,\"redAdd works only with red numbers\"),this.red.add(this,t)},a.prototype.redIAdd=function(t){return n(this.red,\"redIAdd works only with red numbers\"),this.red.iadd(this,t)},a.prototype.redSub=function(t){return n(this.red,\"redSub works only with red numbers\"),this.red.sub(this,t)},a.prototype.redISub=function(t){return n(this.red,\"redISub works only with red numbers\"),this.red.isub(this,t)},a.prototype.redShl=function(t){return n(this.red,\"redShl works only with red numbers\"),this.red.shl(this,t)},a.prototype.redMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.mul(this,t)},a.prototype.redIMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.imul(this,t)},a.prototype.redSqr=function(){return n(this.red,\"redSqr works only with red numbers\"),this.red._verify1(this),this.red.sqr(this)},a.prototype.redISqr=function(){return n(this.red,\"redISqr works only with red numbers\"),this.red._verify1(this),this.red.isqr(this)},a.prototype.redSqrt=function(){return n(this.red,\"redSqrt works only with red numbers\"),this.red._verify1(this),this.red.sqrt(this)},a.prototype.redInvm=function(){return n(this.red,\"redInvm works only with red numbers\"),this.red._verify1(this),this.red.invm(this)},a.prototype.redNeg=function(){return n(this.red,\"redNeg works only with red numbers\"),this.red._verify1(this),this.red.neg(this)},a.prototype.redPow=function(t){return n(this.red&&!t.red,\"redPow(normalNum)\"),this.red._verify1(this),this.red.pow(this,t)};var v={k256:null,p224:null,p192:null,p25519:null};function m(t,e){this.name=t,this.p=new a(e,16),this.n=this.p.bitLength(),this.k=new a(1).iushln(this.n).isub(this.p),this.tmp=this._tmp()}function y(){m.call(this,\"k256\",\"ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffe fffffc2f\")}function x(){m.call(this,\"p224\",\"ffffffff ffffffff ffffffff ffffffff 00000000 00000000 00000001\")}function b(){m.call(this,\"p192\",\"ffffffff ffffffff ffffffff fffffffe ffffffff ffffffff\")}function _(){m.call(this,\"25519\",\"7fffffffffffffff ffffffffffffffff ffffffffffffffff ffffffffffffffed\")}function w(t){if(\"string\"==typeof t){var e=a._prime(t);this.m=e.p,this.prime=e}else n(t.gtn(1),\"modulus must be greater than 1\"),this.m=t,this.prime=null}function k(t){w.call(this,t),this.shift=this.m.bitLength(),this.shift%26!=0&&(this.shift+=26-this.shift%26),this.r=new a(1).iushln(this.shift),this.r2=this.imod(this.r.sqr()),this.rinv=this.r._invmp(this.m),this.minv=this.rinv.mul(this.r).isubn(1).div(this.m),this.minv=this.minv.umod(this.r),this.minv=this.r.sub(this.minv)}m.prototype._tmp=function(){var t=new a(null);return t.words=new Array(Math.ceil(this.n/13)),t},m.prototype.ireduce=function(t){var e,r=t;do{this.split(r,this.tmp),e=(r=(r=this.imulK(r)).iadd(this.tmp)).bitLength()}while(e>this.n);var n=e<this.n?-1:r.ucmp(this.p);return 0===n?(r.words[0]=0,r.length=1):n>0?r.isub(this.p):r.strip(),r},m.prototype.split=function(t,e){t.iushrn(this.n,0,e)},m.prototype.imulK=function(t){return t.imul(this.k)},i(y,m),y.prototype.split=function(t,e){for(var r=Math.min(t.length,9),n=0;n<r;n++)e.words[n]=t.words[n];if(e.length=r,t.length<=9)return t.words[0]=0,void(t.length=1);var i=t.words[9];for(e.words[e.length++]=4194303&i,n=10;n<t.length;n++){var a=0|t.words[n];t.words[n-10]=(4194303&a)<<4|i>>>22,i=a}i>>>=22,t.words[n-10]=i,0===i&&t.length>10?t.length-=10:t.length-=9},y.prototype.imulK=function(t){t.words[t.length]=0,t.words[t.length+1]=0,t.length+=2;for(var e=0,r=0;r<t.length;r++){var n=0|t.words[r];e+=977*n,t.words[r]=67108863&e,e=64*n+(e/67108864|0)}return 0===t.words[t.length-1]&&(t.length--,0===t.words[t.length-1]&&t.length--),t},i(x,m),i(b,m),i(_,m),_.prototype.imulK=function(t){for(var e=0,r=0;r<t.length;r++){var n=19*(0|t.words[r])+e,i=67108863&n;n>>>=26,t.words[r]=i,e=n}return 0!==e&&(t.words[t.length++]=e),t},a._prime=function(t){if(v[t])return v[t];var e;if(\"k256\"===t)e=new y;else if(\"p224\"===t)e=new x;else if(\"p192\"===t)e=new b;else{if(\"p25519\"!==t)throw new Error(\"Unknown prime \"+t);e=new _}return v[t]=e,e},w.prototype._verify1=function(t){n(0===t.negative,\"red works only with positives\"),n(t.red,\"red works only with red numbers\")},w.prototype._verify2=function(t,e){n(0==(t.negative|e.negative),\"red works only with positives\"),n(t.red&&t.red===e.red,\"red works only with red numbers\")},w.prototype.imod=function(t){return this.prime?this.prime.ireduce(t)._forceRed(this):t.umod(this.m)._forceRed(this)},w.prototype.neg=function(t){return t.isZero()?t.clone():this.m.sub(t)._forceRed(this)},w.prototype.add=function(t,e){this._verify2(t,e);var r=t.add(e);return r.cmp(this.m)>=0&&r.isub(this.m),r._forceRed(this)},w.prototype.iadd=function(t,e){this._verify2(t,e);var r=t.iadd(e);return r.cmp(this.m)>=0&&r.isub(this.m),r},w.prototype.sub=function(t,e){this._verify2(t,e);var r=t.sub(e);return r.cmpn(0)<0&&r.iadd(this.m),r._forceRed(this)},w.prototype.isub=function(t,e){this._verify2(t,e);var r=t.isub(e);return r.cmpn(0)<0&&r.iadd(this.m),r},w.prototype.shl=function(t,e){return this._verify1(t),this.imod(t.ushln(e))},w.prototype.imul=function(t,e){return this._verify2(t,e),this.imod(t.imul(e))},w.prototype.mul=function(t,e){return this._verify2(t,e),this.imod(t.mul(e))},w.prototype.isqr=function(t){return this.imul(t,t.clone())},w.prototype.sqr=function(t){return this.mul(t,t)},w.prototype.sqrt=function(t){if(t.isZero())return t.clone();var e=this.m.andln(3);if(n(e%2==1),3===e){var r=this.m.add(new a(1)).iushrn(2);return this.pow(t,r)}for(var i=this.m.subn(1),o=0;!i.isZero()&&0===i.andln(1);)o++,i.iushrn(1);n(!i.isZero());var s=new a(1).toRed(this),l=s.redNeg(),c=this.m.subn(1).iushrn(1),u=this.m.bitLength();for(u=new a(2*u*u).toRed(this);0!==this.pow(u,c).cmp(l);)u.redIAdd(l);for(var h=this.pow(u,i),f=this.pow(t,i.addn(1).iushrn(1)),p=this.pow(t,i),d=o;0!==p.cmp(s);){for(var g=p,v=0;0!==g.cmp(s);v++)g=g.redSqr();n(v<d);var m=this.pow(h,new a(1).iushln(d-v-1));f=f.redMul(m),h=m.redSqr(),p=p.redMul(h),d=v}return f},w.prototype.invm=function(t){var e=t._invmp(this.m);return 0!==e.negative?(e.negative=0,this.imod(e).redNeg()):this.imod(e)},w.prototype.pow=function(t,e){if(e.isZero())return new a(1).toRed(this);if(0===e.cmpn(1))return t.clone();var r=new Array(16);r[0]=new a(1).toRed(this),r[1]=t;for(var n=2;n<r.length;n++)r[n]=this.mul(r[n-1],t);var i=r[0],o=0,s=0,l=e.bitLength()%26;for(0===l&&(l=26),n=e.length-1;n>=0;n--){for(var c=e.words[n],u=l-1;u>=0;u--){var h=c>>u&1;i!==r[0]&&(i=this.sqr(i)),0!==h||0!==o?(o<<=1,o|=h,(4===++s||0===n&&0===u)&&(i=this.mul(i,r[o]),s=0,o=0)):s=0}l=26}return i},w.prototype.convertTo=function(t){var e=t.umod(this.m);return e===t?e.clone():e},w.prototype.convertFrom=function(t){var e=t.clone();return e.red=null,e},a.mont=function(t){return new k(t)},i(k,w),k.prototype.convertTo=function(t){return this.imod(t.ushln(this.shift))},k.prototype.convertFrom=function(t){var e=this.imod(t.mul(this.rinv));return e.red=null,e},k.prototype.imul=function(t,e){if(t.isZero()||e.isZero())return t.words[0]=0,t.length=1,t;var r=t.imul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),a=i;return i.cmp(this.m)>=0?a=i.isub(this.m):i.cmpn(0)<0&&(a=i.iadd(this.m)),a._forceRed(this)},k.prototype.mul=function(t,e){if(t.isZero()||e.isZero())return new a(0)._forceRed(this);var r=t.mul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),o=i;return i.cmp(this.m)>=0?o=i.isub(this.m):i.cmpn(0)<0&&(o=i.iadd(this.m)),o._forceRed(this)},k.prototype.invm=function(t){return this.imod(t._invmp(this.m).mul(this.r2))._forceRed(this)}}(\"undefined\"==typeof e||e,this)},{buffer:103}],95:[function(t,e,r){\"use strict\";e.exports=function(t){var e,r,n,i=t.length,a=0;for(e=0;e<i;++e)a+=t[e].length;var o=new Array(a),s=0;for(e=0;e<i;++e){var l=t[e],c=l.length;for(r=0;r<c;++r){var u=o[s++]=new Array(c-1),h=0;for(n=0;n<c;++n)n!==r&&(u[h++]=l[n]);if(1&r){var f=u[1];u[1]=u[0],u[0]=f}}}return o}},{}],96:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 1:return n=[],c(i=t,i,u,!0),n;case 2:return\"function\"==typeof e?c(t,t,e,!0):function(t,e){return n=[],c(t,e,u,!1),n}(t,e);case 3:return c(t,e,r,!1);default:throw new Error(\"box-intersect: Invalid arguments\")}var i};var n,i=t(\"typedarray-pool\"),a=t(\"./lib/sweep\"),o=t(\"./lib/intersect\");function s(t,e){for(var r=0;r<t;++r)if(!(e[r]<=e[r+t]))return!0;return!1}function l(t,e,r,n){for(var i=0,a=0,o=0,l=t.length;o<l;++o){var c=t[o];if(!s(e,c)){for(var u=0;u<2*e;++u)r[i++]=c[u];n[a++]=o}}return a}function c(t,e,r,n){var s=t.length,c=e.length;if(!(s<=0||c<=0)){var u=t[0].length>>>1;if(!(u<=0)){var h,f=i.mallocDouble(2*u*s),p=i.mallocInt32(s);if((s=l(t,u,f,p))>0){if(1===u&&n)a.init(s),h=a.sweepComplete(u,r,0,s,f,p,0,s,f,p);else{var d=i.mallocDouble(2*u*c),g=i.mallocInt32(c);(c=l(e,u,d,g))>0&&(a.init(s+c),h=1===u?a.sweepBipartite(u,r,0,s,f,p,0,c,d,g):o(u,r,n,s,f,p,c,d,g),i.free(d),i.free(g))}i.free(f),i.free(p)}return h}}}function u(t,e){n.push([t,e])}},{\"./lib/intersect\":98,\"./lib/sweep\":102,\"typedarray-pool\":545}],97:[function(t,e,r){\"use strict\";var n=\"d\",i=\"ax\",a=\"vv\",o=\"fp\",s=\"es\",l=\"rs\",c=\"re\",u=\"rb\",h=\"ri\",f=\"rp\",p=\"bs\",d=\"be\",g=\"bb\",v=\"bi\",m=\"bp\",y=\"rv\",x=\"Q\",b=[n,i,a,l,c,u,h,p,d,g,v];function _(t){var e=\"bruteForce\"+(t?\"Full\":\"Partial\"),r=[],_=b.slice();t||_.splice(3,0,o);var w=[\"function \"+e+\"(\"+_.join()+\"){\"];function k(e,o){var _=function(t,e,r){var o=\"bruteForce\"+(t?\"Red\":\"Blue\")+(e?\"Flip\":\"\")+(r?\"Full\":\"\"),_=[\"function \",o,\"(\",b.join(),\"){\",\"var \",s,\"=2*\",n,\";\"],w=\"for(var i=\"+l+\",\"+f+\"=\"+s+\"*\"+l+\";i<\"+c+\";++i,\"+f+\"+=\"+s+\"){var x0=\"+u+\"[\"+i+\"+\"+f+\"],x1=\"+u+\"[\"+i+\"+\"+f+\"+\"+n+\"],xi=\"+h+\"[i];\",k=\"for(var j=\"+p+\",\"+m+\"=\"+s+\"*\"+p+\";j<\"+d+\";++j,\"+m+\"+=\"+s+\"){var y0=\"+g+\"[\"+i+\"+\"+m+\"],\"+(r?\"y1=\"+g+\"[\"+i+\"+\"+m+\"+\"+n+\"],\":\"\")+\"yi=\"+v+\"[j];\";return t?_.push(w,x,\":\",k):_.push(k,x,\":\",w),r?_.push(\"if(y1<x0||x1<y0)continue;\"):e?_.push(\"if(y0<=x0||x1<y0)continue;\"):_.push(\"if(y0<x0||x1<y0)continue;\"),_.push(\"for(var k=\"+i+\"+1;k<\"+n+\";++k){var r0=\"+u+\"[k+\"+f+\"],r1=\"+u+\"[k+\"+n+\"+\"+f+\"],b0=\"+g+\"[k+\"+m+\"],b1=\"+g+\"[k+\"+n+\"+\"+m+\"];if(r1<b0||b1<r0)continue \"+x+\";}var \"+y+\"=\"+a+\"(\"),e?_.push(\"yi,xi\"):_.push(\"xi,yi\"),_.push(\");if(\"+y+\"!==void 0)return \"+y+\";}}}\"),{name:o,code:_.join(\"\")}}(e,o,t);r.push(_.code),w.push(\"return \"+_.name+\"(\"+b.join()+\");\")}w.push(\"if(\"+c+\"-\"+l+\">\"+d+\"-\"+p+\"){\"),t?(k(!0,!1),w.push(\"}else{\"),k(!1,!1)):(w.push(\"if(\"+o+\"){\"),k(!0,!0),w.push(\"}else{\"),k(!0,!1),w.push(\"}}else{if(\"+o+\"){\"),k(!1,!0),w.push(\"}else{\"),k(!1,!1),w.push(\"}\")),w.push(\"}}return \"+e);var T=r.join(\"\")+w.join(\"\");return new Function(T)()}r.partial=_(!1),r.full=_(!0)},{}],98:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,u,S,E,C,L){!function(t,e){var r=8*i.log2(e+1)*(t+1)|0,a=i.nextPow2(b*r);w.length<a&&(n.free(w),w=n.mallocInt32(a));var o=i.nextPow2(_*r);k<o&&(n.free(k),k=n.mallocDouble(o))}(t,a+E);var P,O=0,z=2*t;T(O++,0,0,a,0,E,r?16:0,-1/0,1/0),r||T(O++,0,0,E,0,a,1,-1/0,1/0);for(;O>0;){var I=(O-=1)*b,D=w[I],R=w[I+1],F=w[I+2],B=w[I+3],N=w[I+4],j=w[I+5],U=O*_,V=k[U],q=k[U+1],H=1&j,G=!!(16&j),Y=u,W=S,X=C,Z=L;if(H&&(Y=C,W=L,X=u,Z=S),!(2&j&&(F=v(t,D,R,F,Y,W,q),R>=F)||4&j&&(R=m(t,D,R,F,Y,W,V))>=F)){var J=F-R,K=N-B;if(G){if(t*J*(J+K)<p){if(void 0!==(P=l.scanComplete(t,D,e,R,F,Y,W,B,N,X,Z)))return P;continue}}else{if(t*Math.min(J,K)<h){if(void 0!==(P=o(t,D,e,H,R,F,Y,W,B,N,X,Z)))return P;continue}if(t*J*K<f){if(void 0!==(P=l.scanBipartite(t,D,e,H,R,F,Y,W,B,N,X,Z)))return P;continue}}var $=d(t,D,R,F,Y,W,V,q);if(R<$)if(t*($-R)<h){if(void 0!==(P=s(t,D+1,e,R,$,Y,W,B,N,X,Z)))return P}else if(D===t-2){if(void 0!==(P=H?l.sweepBipartite(t,e,B,N,X,Z,R,$,Y,W):l.sweepBipartite(t,e,R,$,Y,W,B,N,X,Z)))return P}else T(O++,D+1,R,$,B,N,H,-1/0,1/0),T(O++,D+1,B,N,R,$,1^H,-1/0,1/0);if($<F){var Q=c(t,D,B,N,X,Z),tt=X[z*Q+D],et=g(t,D,Q,N,X,Z,tt);if(et<N&&T(O++,D,$,F,et,N,(4|H)+(G?16:0),tt,q),B<Q&&T(O++,D,$,F,B,Q,(2|H)+(G?16:0),V,tt),Q+1===et){if(void 0!==(P=G?M(t,D,e,$,F,Y,W,Q,X,Z[Q]):A(t,D,e,H,$,F,Y,W,Q,X,Z[Q])))return P}else if(Q<et){var rt;if(G){if(rt=y(t,D,$,F,Y,W,tt),$<rt){var nt=g(t,D,$,rt,Y,W,tt);if(D===t-2){if($<nt&&void 0!==(P=l.sweepComplete(t,e,$,nt,Y,W,Q,et,X,Z)))return P;if(nt<rt&&void 0!==(P=l.sweepBipartite(t,e,nt,rt,Y,W,Q,et,X,Z)))return P}else $<nt&&T(O++,D+1,$,nt,Q,et,16,-1/0,1/0),nt<rt&&(T(O++,D+1,nt,rt,Q,et,0,-1/0,1/0),T(O++,D+1,Q,et,nt,rt,1,-1/0,1/0))}}else rt=H?x(t,D,$,F,Y,W,tt):y(t,D,$,F,Y,W,tt),$<rt&&(D===t-2?P=H?l.sweepBipartite(t,e,Q,et,X,Z,$,rt,Y,W):l.sweepBipartite(t,e,$,rt,Y,W,Q,et,X,Z):(T(O++,D+1,$,rt,Q,et,H,-1/0,1/0),T(O++,D+1,Q,et,$,rt,1^H,-1/0,1/0)))}}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./brute\"),o=a.partial,s=a.full,l=t(\"./sweep\"),c=t(\"./median\"),u=t(\"./partition\"),h=128,f=1<<22,p=1<<22,d=u(\"!(lo>=p0)&&!(p1>=hi)\",[\"p0\",\"p1\"]),g=u(\"lo===p0\",[\"p0\"]),v=u(\"lo<p0\",[\"p0\"]),m=u(\"hi<=p0\",[\"p0\"]),y=u(\"lo<=p0&&p0<=hi\",[\"p0\"]),x=u(\"lo<p0&&p0<=hi\",[\"p0\"]),b=6,_=2,w=n.mallocInt32(1024),k=n.mallocDouble(1024);function T(t,e,r,n,i,a,o,s,l){var c=b*t;w[c]=e,w[c+1]=r,w[c+2]=n,w[c+3]=i,w[c+4]=a,w[c+5]=o;var u=_*t;k[u]=s,k[u+1]=l}function A(t,e,r,n,i,a,o,s,l,c,u){var h=2*t,f=l*h,p=c[f+e];t:for(var d=i,g=i*h;d<a;++d,g+=h){var v=o[g+e],m=o[g+e+t];if(!(p<v||m<p)&&(!n||p!==v)){for(var y,x=s[d],b=e+1;b<t;++b){v=o[g+b],m=o[g+b+t];var _=c[f+b],w=c[f+b+t];if(m<_||w<v)continue t}if(void 0!==(y=n?r(u,x):r(x,u)))return y}}}function M(t,e,r,n,i,a,o,s,l,c){var u=2*t,h=s*u,f=l[h+e];t:for(var p=n,d=n*u;p<i;++p,d+=u){var g=o[p];if(g!==c){var v=a[d+e],m=a[d+e+t];if(!(f<v||m<f)){for(var y=e+1;y<t;++y){v=a[d+y],m=a[d+y+t];var x=l[h+y],b=l[h+y+t];if(m<x||b<v)continue t}var _=r(g,c);if(void 0!==_)return _}}}}},{\"./brute\":97,\"./median\":99,\"./partition\":100,\"./sweep\":102,\"bit-twiddle\":92,\"typedarray-pool\":545}],99:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,o,s,l){if(o<=r+1)return r;var c=r,u=o,h=o+r>>>1,f=2*t,p=h,d=s[f*h+e];for(;c<u;){if(u-c<i){a(t,e,c,u,s,l),d=s[f*h+e];break}var g=u-c,v=Math.random()*g+c|0,m=s[f*v+e],y=Math.random()*g+c|0,x=s[f*y+e],b=Math.random()*g+c|0,_=s[f*b+e];m<=x?_>=x?(p=y,d=x):m>=_?(p=v,d=m):(p=b,d=_):x>=_?(p=y,d=x):_>=m?(p=v,d=m):(p=b,d=_);for(var w=f*(u-1),k=f*p,T=0;T<f;++T,++w,++k){var A=s[w];s[w]=s[k],s[k]=A}var M=l[u-1];l[u-1]=l[p],l[p]=M,p=n(t,e,c,u-1,s,l,d);for(var w=f*(u-1),k=f*p,T=0;T<f;++T,++w,++k){var A=s[w];s[w]=s[k],s[k]=A}var M=l[u-1];if(l[u-1]=l[p],l[p]=M,h<p){for(u=p-1;c<u&&s[f*(u-1)+e]===d;)u-=1;u+=1}else{if(!(p<h))break;for(c=p+1;c<u&&s[f*c+e]===d;)c+=1}}return n(t,e,r,h,s,l,s[f*h+e])};var n=t(\"./partition\")(\"lo<p0\",[\"p0\"]),i=8;function a(t,e,r,n,i,a){for(var o=2*t,s=o*(r+1)+e,l=r+1;l<n;++l,s+=o)for(var c=i[s],u=l,h=o*(l-1);u>r&&i[h+e]>c;--u,h-=o){for(var f=h,p=h+o,d=0;d<o;++d,++f,++p){var g=i[f];i[f]=i[p],i[p]=g}var v=a[u];a[u]=a[u-1],a[u-1]=v}}},{\"./partition\":100}],100:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=\"abcdef\".split(\"\").concat(e),i=[];t.indexOf(\"lo\")>=0&&i.push(\"lo=e[k+n]\");t.indexOf(\"hi\")>=0&&i.push(\"hi=e[k+o]\");return r.push(n.replace(\"_\",i.join()).replace(\"$\",t)),Function.apply(void 0,r)};var n=\"for(var j=2*a,k=j*c,l=k,m=c,n=b,o=a+b,p=c;d>p;++p,k+=j){var _;if($)if(m===p)m+=1,l+=j;else{for(var s=0;j>s;++s){var t=e[k+s];e[k+s]=e[l],e[l++]=t}var u=f[p];f[p]=f[m],f[m++]=u}}return m\"},{}],101:[function(t,e,r){\"use strict\";e.exports=function(t,e){e<=4*n?i(0,e-1,t):function t(e,r,h){var f=(r-e+1)/6|0,p=e+f,d=r-f,g=e+r>>1,v=g-f,m=g+f,y=p,x=v,b=g,_=m,w=d,k=e+1,T=r-1,A=0;c(y,x,h)&&(A=y,y=x,x=A);c(_,w,h)&&(A=_,_=w,w=A);c(y,b,h)&&(A=y,y=b,b=A);c(x,b,h)&&(A=x,x=b,b=A);c(y,_,h)&&(A=y,y=_,_=A);c(b,_,h)&&(A=b,b=_,_=A);c(x,w,h)&&(A=x,x=w,w=A);c(x,b,h)&&(A=x,x=b,b=A);c(_,w,h)&&(A=_,_=w,w=A);var M=h[2*x];var S=h[2*x+1];var E=h[2*_];var C=h[2*_+1];var L=2*y;var P=2*b;var O=2*w;var z=2*p;var I=2*g;var D=2*d;for(var R=0;R<2;++R){var F=h[L+R],B=h[P+R],N=h[O+R];h[z+R]=F,h[I+R]=B,h[D+R]=N}o(v,e,h);o(m,r,h);for(var j=k;j<=T;++j)if(u(j,M,S,h))j!==k&&a(j,k,h),++k;else if(!u(j,E,C,h))for(;;){if(u(T,E,C,h)){u(T,M,S,h)?(s(j,k,T,h),++k,--T):(a(j,T,h),--T);break}if(--T<j)break}l(e,k-1,M,S,h);l(r,T+1,E,C,h);k-2-e<=n?i(e,k-2,h):t(e,k-2,h);r-(T+2)<=n?i(T+2,r,h):t(T+2,r,h);T-k<=n?i(k,T,h):t(k,T,h)}(0,e-1,t)};var n=32;function i(t,e,r){for(var n=2*(t+1),i=t+1;i<=e;++i){for(var a=r[n++],o=r[n++],s=i,l=n-2;s-- >t;){var c=r[l-2],u=r[l-1];if(c<a)break;if(c===a&&u<o)break;r[l]=c,r[l+1]=u,l-=2}r[l]=a,r[l+1]=o}}function a(t,e,r){e*=2;var n=r[t*=2],i=r[t+1];r[t]=r[e],r[t+1]=r[e+1],r[e]=n,r[e+1]=i}function o(t,e,r){e*=2,r[t*=2]=r[e],r[t+1]=r[e+1]}function s(t,e,r,n){e*=2,r*=2;var i=n[t*=2],a=n[t+1];n[t]=n[e],n[t+1]=n[e+1],n[e]=n[r],n[e+1]=n[r+1],n[r]=i,n[r+1]=a}function l(t,e,r,n,i){e*=2,i[t*=2]=i[e],i[e]=r,i[t+1]=i[e+1],i[e+1]=n}function c(t,e,r){e*=2;var n=r[t*=2],i=r[e];return!(n<i)&&(n!==i||r[t+1]>r[e+1])}function u(t,e,r,n){var i=n[t*=2];return i<e||i===e&&n[t+1]<r}},{}],102:[function(t,e,r){\"use strict\";e.exports={init:function(t){var e=i.nextPow2(t);s.length<e&&(n.free(s),s=n.mallocInt32(e));l.length<e&&(n.free(l),l=n.mallocInt32(e));c.length<e&&(n.free(c),c=n.mallocInt32(e));u.length<e&&(n.free(u),u=n.mallocInt32(e));h.length<e&&(n.free(h),h=n.mallocInt32(e));f.length<e&&(n.free(f),f=n.mallocInt32(e));var r=8*e;p.length<r&&(n.free(p),p=n.mallocDouble(r))},sweepBipartite:function(t,e,r,n,i,h,f,v,m,y){for(var x=0,b=2*t,_=t-1,w=b-1,k=r;k<n;++k){var T=h[k],A=b*k;p[x++]=i[A+_],p[x++]=-(T+1),p[x++]=i[A+w],p[x++]=T}for(var k=f;k<v;++k){var T=y[k]+o,M=b*k;p[x++]=m[M+_],p[x++]=-T,p[x++]=m[M+w],p[x++]=T}var S=x>>>1;a(p,S);for(var E=0,C=0,k=0;k<S;++k){var L=0|p[2*k+1];if(L>=o)d(c,u,C--,L=L-o|0);else if(L>=0)d(s,l,E--,L);else if(L<=-o){L=-L-o|0;for(var P=0;P<E;++P){var O=e(s[P],L);if(void 0!==O)return O}g(c,u,C++,L)}else{L=-L-1|0;for(var P=0;P<C;++P){var O=e(L,c[P]);if(void 0!==O)return O}g(s,l,E++,L)}}},sweepComplete:function(t,e,r,n,i,o,v,m,y,x){for(var b=0,_=2*t,w=t-1,k=_-1,T=r;T<n;++T){var A=o[T]+1<<1,M=_*T;p[b++]=i[M+w],p[b++]=-A,p[b++]=i[M+k],p[b++]=A}for(var T=v;T<m;++T){var A=x[T]+1<<1,S=_*T;p[b++]=y[S+w],p[b++]=1|-A,p[b++]=y[S+k],p[b++]=1|A}var E=b>>>1;a(p,E);for(var C=0,L=0,P=0,T=0;T<E;++T){var O=0|p[2*T+1],z=1&O;if(T<E-1&&O>>1==p[2*T+3]>>1&&(z=2,T+=1),O<0){for(var I=-(O>>1)-1,D=0;D<P;++D){var R=e(h[D],I);if(void 0!==R)return R}if(0!==z)for(var D=0;D<C;++D){var R=e(s[D],I);if(void 0!==R)return R}if(1!==z)for(var D=0;D<L;++D){var R=e(c[D],I);if(void 0!==R)return R}0===z?g(s,l,C++,I):1===z?g(c,u,L++,I):2===z&&g(h,f,P++,I)}else{var I=(O>>1)-1;0===z?d(s,l,C--,I):1===z?d(c,u,L--,I):2===z&&d(h,f,P--,I)}}},scanBipartite:function(t,e,r,n,i,c,u,h,f,v,m,y){var x=0,b=2*t,_=e,w=e+t,k=1,T=1;n?T=o:k=o;for(var A=i;A<c;++A){var M=A+k,S=b*A;p[x++]=u[S+_],p[x++]=-M,p[x++]=u[S+w],p[x++]=M}for(var A=f;A<v;++A){var M=A+T,E=b*A;p[x++]=m[E+_],p[x++]=-M}var C=x>>>1;a(p,C);for(var L=0,A=0;A<C;++A){var P=0|p[2*A+1];if(P<0){var M=-P,O=!1;if(M>=o?(O=!n,M-=o):(O=!!n,M-=1),O)g(s,l,L++,M);else{var z=y[M],I=b*M,D=m[I+e+1],R=m[I+e+1+t];t:for(var F=0;F<L;++F){var B=s[F],N=b*B;if(!(R<u[N+e+1]||u[N+e+1+t]<D)){for(var j=e+2;j<t;++j)if(m[I+j+t]<u[N+j]||u[N+j+t]<m[I+j])continue t;var U,V=h[B];if(void 0!==(U=n?r(z,V):r(V,z)))return U}}}}else d(s,l,L--,P-k)}},scanComplete:function(t,e,r,n,i,l,c,u,h,f,d){for(var g=0,v=2*t,m=e,y=e+t,x=n;x<i;++x){var b=x+o,_=v*x;p[g++]=l[_+m],p[g++]=-b,p[g++]=l[_+y],p[g++]=b}for(var x=u;x<h;++x){var b=x+1,w=v*x;p[g++]=f[w+m],p[g++]=-b}var k=g>>>1;a(p,k);for(var T=0,x=0;x<k;++x){var A=0|p[2*x+1];if(A<0){var b=-A;if(b>=o)s[T++]=b-o;else{var M=d[b-=1],S=v*b,E=f[S+e+1],C=f[S+e+1+t];t:for(var L=0;L<T;++L){var P=s[L],O=c[P];if(O===M)break;var z=v*P;if(!(C<l[z+e+1]||l[z+e+1+t]<E)){for(var I=e+2;I<t;++I)if(f[S+I+t]<l[z+I]||l[z+I+t]<f[S+I])continue t;var D=r(O,M);if(void 0!==D)return D}}}}else{for(var b=A-o,L=T-1;L>=0;--L)if(s[L]===b){for(var I=L+1;I<T;++I)s[I-1]=s[I];break}--T}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./sort\"),o=1<<28,s=n.mallocInt32(1024),l=n.mallocInt32(1024),c=n.mallocInt32(1024),u=n.mallocInt32(1024),h=n.mallocInt32(1024),f=n.mallocInt32(1024),p=n.mallocDouble(8192);function d(t,e,r,n){var i=e[n],a=t[r-1];t[i]=a,e[a]=i}function g(t,e,r,n){t[r]=n,e[n]=r}},{\"./sort\":101,\"bit-twiddle\":92,\"typedarray-pool\":545}],103:[function(t,e,r){},{}],104:[function(t,e,r){var n=Object.create||function(t){var e=function(){};return e.prototype=t,new e},i=Object.keys||function(t){var e=[];for(var r in t)Object.prototype.hasOwnProperty.call(t,r)&&e.push(r);return r},a=Function.prototype.bind||function(t){var e=this;return function(){return e.apply(t,arguments)}};function o(){this._events&&Object.prototype.hasOwnProperty.call(this,\"_events\")||(this._events=n(null),this._eventsCount=0),this._maxListeners=this._maxListeners||void 0}e.exports=o,o.EventEmitter=o,o.prototype._events=void 0,o.prototype._maxListeners=void 0;var s,l=10;try{var c={};Object.defineProperty&&Object.defineProperty(c,\"x\",{value:0}),s=0===c.x}catch(t){s=!1}function u(t){return void 0===t._maxListeners?o.defaultMaxListeners:t._maxListeners}function h(t,e,r,i){var a,o,s;if(\"function\"!=typeof r)throw new TypeError('\"listener\" argument must be a function');if((o=t._events)?(o.newListener&&(t.emit(\"newListener\",e,r.listener?r.listener:r),o=t._events),s=o[e]):(o=t._events=n(null),t._eventsCount=0),s){if(\"function\"==typeof s?s=o[e]=i?[r,s]:[s,r]:i?s.unshift(r):s.push(r),!s.warned&&(a=u(t))&&a>0&&s.length>a){s.warned=!0;var l=new Error(\"Possible EventEmitter memory leak detected. \"+s.length+' \"'+String(e)+'\" listeners added. Use emitter.setMaxListeners() to increase limit.');l.name=\"MaxListenersExceededWarning\",l.emitter=t,l.type=e,l.count=s.length,\"object\"==typeof console&&console.warn&&console.warn(\"%s: %s\",l.name,l.message)}}else s=o[e]=r,++t._eventsCount;return t}function f(){if(!this.fired)switch(this.target.removeListener(this.type,this.wrapFn),this.fired=!0,arguments.length){case 0:return this.listener.call(this.target);case 1:return this.listener.call(this.target,arguments[0]);case 2:return this.listener.call(this.target,arguments[0],arguments[1]);case 3:return this.listener.call(this.target,arguments[0],arguments[1],arguments[2]);default:for(var t=new Array(arguments.length),e=0;e<t.length;++e)t[e]=arguments[e];this.listener.apply(this.target,t)}}function p(t,e,r){var n={fired:!1,wrapFn:void 0,target:t,type:e,listener:r},i=a.call(f,n);return i.listener=r,n.wrapFn=i,i}function d(t,e,r){var n=t._events;if(!n)return[];var i=n[e];return i?\"function\"==typeof i?r?[i.listener||i]:[i]:r?function(t){for(var e=new Array(t.length),r=0;r<e.length;++r)e[r]=t[r].listener||t[r];return e}(i):v(i,i.length):[]}function g(t){var e=this._events;if(e){var r=e[t];if(\"function\"==typeof r)return 1;if(r)return r.length}return 0}function v(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t[n];return r}s?Object.defineProperty(o,\"defaultMaxListeners\",{enumerable:!0,get:function(){return l},set:function(t){if(\"number\"!=typeof t||t<0||t!=t)throw new TypeError('\"defaultMaxListeners\" must be a positive number');l=t}}):o.defaultMaxListeners=l,o.prototype.setMaxListeners=function(t){if(\"number\"!=typeof t||t<0||isNaN(t))throw new TypeError('\"n\" argument must be a positive number');return this._maxListeners=t,this},o.prototype.getMaxListeners=function(){return u(this)},o.prototype.emit=function(t){var e,r,n,i,a,o,s=\"error\"===t;if(o=this._events)s=s&&null==o.error;else if(!s)return!1;if(s){if(arguments.length>1&&(e=arguments[1]),e instanceof Error)throw e;var l=new Error('Unhandled \"error\" event. ('+e+\")\");throw l.context=e,l}if(!(r=o[t]))return!1;var c=\"function\"==typeof r;switch(n=arguments.length){case 1:!function(t,e,r){if(e)t.call(r);else for(var n=t.length,i=v(t,n),a=0;a<n;++a)i[a].call(r)}(r,c,this);break;case 2:!function(t,e,r,n){if(e)t.call(r,n);else for(var i=t.length,a=v(t,i),o=0;o<i;++o)a[o].call(r,n)}(r,c,this,arguments[1]);break;case 3:!function(t,e,r,n,i){if(e)t.call(r,n,i);else for(var a=t.length,o=v(t,a),s=0;s<a;++s)o[s].call(r,n,i)}(r,c,this,arguments[1],arguments[2]);break;case 4:!function(t,e,r,n,i,a){if(e)t.call(r,n,i,a);else for(var o=t.length,s=v(t,o),l=0;l<o;++l)s[l].call(r,n,i,a)}(r,c,this,arguments[1],arguments[2],arguments[3]);break;default:for(i=new Array(n-1),a=1;a<n;a++)i[a-1]=arguments[a];!function(t,e,r,n){if(e)t.apply(r,n);else for(var i=t.length,a=v(t,i),o=0;o<i;++o)a[o].apply(r,n)}(r,c,this,i)}return!0},o.prototype.addListener=function(t,e){return h(this,t,e,!1)},o.prototype.on=o.prototype.addListener,o.prototype.prependListener=function(t,e){return h(this,t,e,!0)},o.prototype.once=function(t,e){if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');return this.on(t,p(this,t,e)),this},o.prototype.prependOnceListener=function(t,e){if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');return this.prependListener(t,p(this,t,e)),this},o.prototype.removeListener=function(t,e){var r,i,a,o,s;if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');if(!(i=this._events))return this;if(!(r=i[t]))return this;if(r===e||r.listener===e)0==--this._eventsCount?this._events=n(null):(delete i[t],i.removeListener&&this.emit(\"removeListener\",t,r.listener||e));else if(\"function\"!=typeof r){for(a=-1,o=r.length-1;o>=0;o--)if(r[o]===e||r[o].listener===e){s=r[o].listener,a=o;break}if(a<0)return this;0===a?r.shift():function(t,e){for(var r=e,n=r+1,i=t.length;n<i;r+=1,n+=1)t[r]=t[n];t.pop()}(r,a),1===r.length&&(i[t]=r[0]),i.removeListener&&this.emit(\"removeListener\",t,s||e)}return this},o.prototype.removeAllListeners=function(t){var e,r,a;if(!(r=this._events))return this;if(!r.removeListener)return 0===arguments.length?(this._events=n(null),this._eventsCount=0):r[t]&&(0==--this._eventsCount?this._events=n(null):delete r[t]),this;if(0===arguments.length){var o,s=i(r);for(a=0;a<s.length;++a)\"removeListener\"!==(o=s[a])&&this.removeAllListeners(o);return this.removeAllListeners(\"removeListener\"),this._events=n(null),this._eventsCount=0,this}if(\"function\"==typeof(e=r[t]))this.removeListener(t,e);else if(e)for(a=e.length-1;a>=0;a--)this.removeListener(t,e[a]);return this},o.prototype.listeners=function(t){return d(this,t,!0)},o.prototype.rawListeners=function(t){return d(this,t,!1)},o.listenerCount=function(t,e){return\"function\"==typeof t.listenerCount?t.listenerCount(e):g.call(t,e)},o.prototype.listenerCount=g,o.prototype.eventNames=function(){return this._eventsCount>0?Reflect.ownKeys(this._events):[]}},{}],105:[function(t,e,r){(function(e){\"use strict\";var n=t(\"base64-js\"),i=t(\"ieee754\");r.Buffer=e,r.SlowBuffer=function(t){+t!=t&&(t=0);return e.alloc(+t)},r.INSPECT_MAX_BYTES=50;var a=2147483647;function o(t){if(t>a)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"');var r=new Uint8Array(t);return r.__proto__=e.prototype,r}function e(t,e,r){if(\"number\"==typeof t){if(\"string\"==typeof e)throw new TypeError('The \"string\" argument must be of type string. Received type number');return c(t)}return s(t,e,r)}function s(t,r,n){if(\"string\"==typeof t)return function(t,r){\"string\"==typeof r&&\"\"!==r||(r=\"utf8\");if(!e.isEncoding(r))throw new TypeError(\"Unknown encoding: \"+r);var n=0|f(t,r),i=o(n),a=i.write(t,r);a!==n&&(i=i.slice(0,a));return i}(t,r);if(ArrayBuffer.isView(t))return u(t);if(null==t)throw TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t);if(N(t,ArrayBuffer)||t&&N(t.buffer,ArrayBuffer))return function(t,r,n){if(r<0||t.byteLength<r)throw new RangeError('\"offset\" is outside of buffer bounds');if(t.byteLength<r+(n||0))throw new RangeError('\"length\" is outside of buffer bounds');var i;i=void 0===r&&void 0===n?new Uint8Array(t):void 0===n?new Uint8Array(t,r):new Uint8Array(t,r,n);return i.__proto__=e.prototype,i}(t,r,n);if(\"number\"==typeof t)throw new TypeError('The \"value\" argument must not be of type number. Received type number');var i=t.valueOf&&t.valueOf();if(null!=i&&i!==t)return e.from(i,r,n);var a=function(t){if(e.isBuffer(t)){var r=0|h(t.length),n=o(r);return 0===n.length?n:(t.copy(n,0,0,r),n)}if(void 0!==t.length)return\"number\"!=typeof t.length||j(t.length)?o(0):u(t);if(\"Buffer\"===t.type&&Array.isArray(t.data))return u(t.data)}(t);if(a)return a;if(\"undefined\"!=typeof Symbol&&null!=Symbol.toPrimitive&&\"function\"==typeof t[Symbol.toPrimitive])return e.from(t[Symbol.toPrimitive](\"string\"),r,n);throw new TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t)}function l(t){if(\"number\"!=typeof t)throw new TypeError('\"size\" argument must be of type number');if(t<0)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"')}function c(t){return l(t),o(t<0?0:0|h(t))}function u(t){for(var e=t.length<0?0:0|h(t.length),r=o(e),n=0;n<e;n+=1)r[n]=255&t[n];return r}function h(t){if(t>=a)throw new RangeError(\"Attempt to allocate Buffer larger than maximum size: 0x\"+a.toString(16)+\" bytes\");return 0|t}function f(t,r){if(e.isBuffer(t))return t.length;if(ArrayBuffer.isView(t)||N(t,ArrayBuffer))return t.byteLength;if(\"string\"!=typeof t)throw new TypeError('The \"string\" argument must be one of type string, Buffer, or ArrayBuffer. Received type '+typeof t);var n=t.length,i=arguments.length>2&&!0===arguments[2];if(!i&&0===n)return 0;for(var a=!1;;)switch(r){case\"ascii\":case\"latin1\":case\"binary\":return n;case\"utf8\":case\"utf-8\":return R(t).length;case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return 2*n;case\"hex\":return n>>>1;case\"base64\":return F(t).length;default:if(a)return i?-1:R(t).length;r=(\"\"+r).toLowerCase(),a=!0}}function p(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function d(t,r,n,i,a){if(0===t.length)return-1;if(\"string\"==typeof n?(i=n,n=0):n>2147483647?n=2147483647:n<-2147483648&&(n=-2147483648),j(n=+n)&&(n=a?0:t.length-1),n<0&&(n=t.length+n),n>=t.length){if(a)return-1;n=t.length-1}else if(n<0){if(!a)return-1;n=0}if(\"string\"==typeof r&&(r=e.from(r,i)),e.isBuffer(r))return 0===r.length?-1:g(t,r,n,i,a);if(\"number\"==typeof r)return r&=255,\"function\"==typeof Uint8Array.prototype.indexOf?a?Uint8Array.prototype.indexOf.call(t,r,n):Uint8Array.prototype.lastIndexOf.call(t,r,n):g(t,[r],n,i,a);throw new TypeError(\"val must be string, number or Buffer\")}function g(t,e,r,n,i){var a,o=1,s=t.length,l=e.length;if(void 0!==n&&(\"ucs2\"===(n=String(n).toLowerCase())||\"ucs-2\"===n||\"utf16le\"===n||\"utf-16le\"===n)){if(t.length<2||e.length<2)return-1;o=2,s/=2,l/=2,r/=2}function c(t,e){return 1===o?t[e]:t.readUInt16BE(e*o)}if(i){var u=-1;for(a=r;a<s;a++)if(c(t,a)===c(e,-1===u?0:a-u)){if(-1===u&&(u=a),a-u+1===l)return u*o}else-1!==u&&(a-=a-u),u=-1}else for(r+l>s&&(r=s-l),a=r;a>=0;a--){for(var h=!0,f=0;f<l;f++)if(c(t,a+f)!==c(e,f)){h=!1;break}if(h)return a}return-1}function v(t,e,r,n){r=Number(r)||0;var i=t.length-r;n?(n=Number(n))>i&&(n=i):n=i;var a=e.length;n>a/2&&(n=a/2);for(var o=0;o<n;++o){var s=parseInt(e.substr(2*o,2),16);if(j(s))return o;t[r+o]=s}return o}function m(t,e,r,n){return B(R(e,t.length-r),t,r,n)}function y(t,e,r,n){return B(function(t){for(var e=[],r=0;r<t.length;++r)e.push(255&t.charCodeAt(r));return e}(e),t,r,n)}function x(t,e,r,n){return y(t,e,r,n)}function b(t,e,r,n){return B(F(e),t,r,n)}function _(t,e,r,n){return B(function(t,e){for(var r,n,i,a=[],o=0;o<t.length&&!((e-=2)<0);++o)r=t.charCodeAt(o),n=r>>8,i=r%256,a.push(i),a.push(n);return a}(e,t.length-r),t,r,n)}function w(t,e,r){return 0===e&&r===t.length?n.fromByteArray(t):n.fromByteArray(t.slice(e,r))}function k(t,e,r){r=Math.min(t.length,r);for(var n=[],i=e;i<r;){var a,o,s,l,c=t[i],u=null,h=c>239?4:c>223?3:c>191?2:1;if(i+h<=r)switch(h){case 1:c<128&&(u=c);break;case 2:128==(192&(a=t[i+1]))&&(l=(31&c)<<6|63&a)>127&&(u=l);break;case 3:a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&(l=(15&c)<<12|(63&a)<<6|63&o)>2047&&(l<55296||l>57343)&&(u=l);break;case 4:a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&(l=(15&c)<<18|(63&a)<<12|(63&o)<<6|63&s)>65535&&l<1114112&&(u=l)}null===u?(u=65533,h=1):u>65535&&(u-=65536,n.push(u>>>10&1023|55296),u=56320|1023&u),n.push(u),i+=h}return function(t){var e=t.length;if(e<=T)return String.fromCharCode.apply(String,t);var r=\"\",n=0;for(;n<e;)r+=String.fromCharCode.apply(String,t.slice(n,n+=T));return r}(n)}r.kMaxLength=a,e.TYPED_ARRAY_SUPPORT=function(){try{var t=new Uint8Array(1);return t.__proto__={__proto__:Uint8Array.prototype,foo:function(){return 42}},42===t.foo()}catch(t){return!1}}(),e.TYPED_ARRAY_SUPPORT||\"undefined\"==typeof console||\"function\"!=typeof console.error||console.error(\"This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support.\"),Object.defineProperty(e.prototype,\"parent\",{enumerable:!0,get:function(){if(e.isBuffer(this))return this.buffer}}),Object.defineProperty(e.prototype,\"offset\",{enumerable:!0,get:function(){if(e.isBuffer(this))return this.byteOffset}}),\"undefined\"!=typeof Symbol&&null!=Symbol.species&&e[Symbol.species]===e&&Object.defineProperty(e,Symbol.species,{value:null,configurable:!0,enumerable:!1,writable:!1}),e.poolSize=8192,e.from=function(t,e,r){return s(t,e,r)},e.prototype.__proto__=Uint8Array.prototype,e.__proto__=Uint8Array,e.alloc=function(t,e,r){return function(t,e,r){return l(t),t<=0?o(t):void 0!==e?\"string\"==typeof r?o(t).fill(e,r):o(t).fill(e):o(t)}(t,e,r)},e.allocUnsafe=function(t){return c(t)},e.allocUnsafeSlow=function(t){return c(t)},e.isBuffer=function(t){return null!=t&&!0===t._isBuffer&&t!==e.prototype},e.compare=function(t,r){if(N(t,Uint8Array)&&(t=e.from(t,t.offset,t.byteLength)),N(r,Uint8Array)&&(r=e.from(r,r.offset,r.byteLength)),!e.isBuffer(t)||!e.isBuffer(r))throw new TypeError('The \"buf1\", \"buf2\" arguments must be one of type Buffer or Uint8Array');if(t===r)return 0;for(var n=t.length,i=r.length,a=0,o=Math.min(n,i);a<o;++a)if(t[a]!==r[a]){n=t[a],i=r[a];break}return n<i?-1:i<n?1:0},e.isEncoding=function(t){switch(String(t).toLowerCase()){case\"hex\":case\"utf8\":case\"utf-8\":case\"ascii\":case\"latin1\":case\"binary\":case\"base64\":case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return!0;default:return!1}},e.concat=function(t,r){if(!Array.isArray(t))throw new TypeError('\"list\" argument must be an Array of Buffers');if(0===t.length)return e.alloc(0);var n;if(void 0===r)for(r=0,n=0;n<t.length;++n)r+=t[n].length;var i=e.allocUnsafe(r),a=0;for(n=0;n<t.length;++n){var o=t[n];if(N(o,Uint8Array)&&(o=e.from(o)),!e.isBuffer(o))throw new TypeError('\"list\" argument must be an Array of Buffers');o.copy(i,a),a+=o.length}return i},e.byteLength=f,e.prototype._isBuffer=!0,e.prototype.swap16=function(){var t=this.length;if(t%2!=0)throw new RangeError(\"Buffer size must be a multiple of 16-bits\");for(var e=0;e<t;e+=2)p(this,e,e+1);return this},e.prototype.swap32=function(){var t=this.length;if(t%4!=0)throw new RangeError(\"Buffer size must be a multiple of 32-bits\");for(var e=0;e<t;e+=4)p(this,e,e+3),p(this,e+1,e+2);return this},e.prototype.swap64=function(){var t=this.length;if(t%8!=0)throw new RangeError(\"Buffer size must be a multiple of 64-bits\");for(var e=0;e<t;e+=8)p(this,e,e+7),p(this,e+1,e+6),p(this,e+2,e+5),p(this,e+3,e+4);return this},e.prototype.toString=function(){var t=this.length;return 0===t?\"\":0===arguments.length?k(this,0,t):function(t,e,r){var n=!1;if((void 0===e||e<0)&&(e=0),e>this.length)return\"\";if((void 0===r||r>this.length)&&(r=this.length),r<=0)return\"\";if((r>>>=0)<=(e>>>=0))return\"\";for(t||(t=\"utf8\");;)switch(t){case\"hex\":return S(this,e,r);case\"utf8\":case\"utf-8\":return k(this,e,r);case\"ascii\":return A(this,e,r);case\"latin1\":case\"binary\":return M(this,e,r);case\"base64\":return w(this,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return E(this,e,r);default:if(n)throw new TypeError(\"Unknown encoding: \"+t);t=(t+\"\").toLowerCase(),n=!0}}.apply(this,arguments)},e.prototype.toLocaleString=e.prototype.toString,e.prototype.equals=function(t){if(!e.isBuffer(t))throw new TypeError(\"Argument must be a Buffer\");return this===t||0===e.compare(this,t)},e.prototype.inspect=function(){var t=\"\",e=r.INSPECT_MAX_BYTES;return t=this.toString(\"hex\",0,e).replace(/(.{2})/g,\"$1 \").trim(),this.length>e&&(t+=\" ... \"),\"<Buffer \"+t+\">\"},e.prototype.compare=function(t,r,n,i,a){if(N(t,Uint8Array)&&(t=e.from(t,t.offset,t.byteLength)),!e.isBuffer(t))throw new TypeError('The \"target\" argument must be one of type Buffer or Uint8Array. Received type '+typeof t);if(void 0===r&&(r=0),void 0===n&&(n=t?t.length:0),void 0===i&&(i=0),void 0===a&&(a=this.length),r<0||n>t.length||i<0||a>this.length)throw new RangeError(\"out of range index\");if(i>=a&&r>=n)return 0;if(i>=a)return-1;if(r>=n)return 1;if(this===t)return 0;for(var o=(a>>>=0)-(i>>>=0),s=(n>>>=0)-(r>>>=0),l=Math.min(o,s),c=this.slice(i,a),u=t.slice(r,n),h=0;h<l;++h)if(c[h]!==u[h]){o=c[h],s=u[h];break}return o<s?-1:s<o?1:0},e.prototype.includes=function(t,e,r){return-1!==this.indexOf(t,e,r)},e.prototype.indexOf=function(t,e,r){return d(this,t,e,r,!0)},e.prototype.lastIndexOf=function(t,e,r){return d(this,t,e,r,!1)},e.prototype.write=function(t,e,r,n){if(void 0===e)n=\"utf8\",r=this.length,e=0;else if(void 0===r&&\"string\"==typeof e)n=e,r=this.length,e=0;else{if(!isFinite(e))throw new Error(\"Buffer.write(string, encoding, offset[, length]) is no longer supported\");e>>>=0,isFinite(r)?(r>>>=0,void 0===n&&(n=\"utf8\")):(n=r,r=void 0)}var i=this.length-e;if((void 0===r||r>i)&&(r=i),t.length>0&&(r<0||e<0)||e>this.length)throw new RangeError(\"Attempt to write outside buffer bounds\");n||(n=\"utf8\");for(var a=!1;;)switch(n){case\"hex\":return v(this,t,e,r);case\"utf8\":case\"utf-8\":return m(this,t,e,r);case\"ascii\":return y(this,t,e,r);case\"latin1\":case\"binary\":return x(this,t,e,r);case\"base64\":return b(this,t,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return _(this,t,e,r);default:if(a)throw new TypeError(\"Unknown encoding: \"+n);n=(\"\"+n).toLowerCase(),a=!0}},e.prototype.toJSON=function(){return{type:\"Buffer\",data:Array.prototype.slice.call(this._arr||this,0)}};var T=4096;function A(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(127&t[i]);return n}function M(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(t[i]);return n}function S(t,e,r){var n=t.length;(!e||e<0)&&(e=0),(!r||r<0||r>n)&&(r=n);for(var i=\"\",a=e;a<r;++a)i+=D(t[a]);return i}function E(t,e,r){for(var n=t.slice(e,r),i=\"\",a=0;a<n.length;a+=2)i+=String.fromCharCode(n[a]+256*n[a+1]);return i}function C(t,e,r){if(t%1!=0||t<0)throw new RangeError(\"offset is not uint\");if(t+e>r)throw new RangeError(\"Trying to access beyond buffer length\")}function L(t,r,n,i,a,o){if(!e.isBuffer(t))throw new TypeError('\"buffer\" argument must be a Buffer instance');if(r>a||r<o)throw new RangeError('\"value\" argument is out of bounds');if(n+i>t.length)throw new RangeError(\"Index out of range\")}function P(t,e,r,n,i,a){if(r+n>t.length)throw new RangeError(\"Index out of range\");if(r<0)throw new RangeError(\"Index out of range\")}function O(t,e,r,n,a){return e=+e,r>>>=0,a||P(t,0,r,4),i.write(t,e,r,n,23,4),r+4}function z(t,e,r,n,a){return e=+e,r>>>=0,a||P(t,0,r,8),i.write(t,e,r,n,52,8),r+8}e.prototype.slice=function(t,r){var n=this.length;(t=~~t)<0?(t+=n)<0&&(t=0):t>n&&(t=n),(r=void 0===r?n:~~r)<0?(r+=n)<0&&(r=0):r>n&&(r=n),r<t&&(r=t);var i=this.subarray(t,r);return i.__proto__=e.prototype,i},e.prototype.readUIntLE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n},e.prototype.readUIntBE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t+--e],i=1;e>0&&(i*=256);)n+=this[t+--e]*i;return n},e.prototype.readUInt8=function(t,e){return t>>>=0,e||C(t,1,this.length),this[t]},e.prototype.readUInt16LE=function(t,e){return t>>>=0,e||C(t,2,this.length),this[t]|this[t+1]<<8},e.prototype.readUInt16BE=function(t,e){return t>>>=0,e||C(t,2,this.length),this[t]<<8|this[t+1]},e.prototype.readUInt32LE=function(t,e){return t>>>=0,e||C(t,4,this.length),(this[t]|this[t+1]<<8|this[t+2]<<16)+16777216*this[t+3]},e.prototype.readUInt32BE=function(t,e){return t>>>=0,e||C(t,4,this.length),16777216*this[t]+(this[t+1]<<16|this[t+2]<<8|this[t+3])},e.prototype.readIntLE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n>=(i*=128)&&(n-=Math.pow(2,8*e)),n},e.prototype.readIntBE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=e,i=1,a=this[t+--n];n>0&&(i*=256);)a+=this[t+--n]*i;return a>=(i*=128)&&(a-=Math.pow(2,8*e)),a},e.prototype.readInt8=function(t,e){return t>>>=0,e||C(t,1,this.length),128&this[t]?-1*(255-this[t]+1):this[t]},e.prototype.readInt16LE=function(t,e){t>>>=0,e||C(t,2,this.length);var r=this[t]|this[t+1]<<8;return 32768&r?4294901760|r:r},e.prototype.readInt16BE=function(t,e){t>>>=0,e||C(t,2,this.length);var r=this[t+1]|this[t]<<8;return 32768&r?4294901760|r:r},e.prototype.readInt32LE=function(t,e){return t>>>=0,e||C(t,4,this.length),this[t]|this[t+1]<<8|this[t+2]<<16|this[t+3]<<24},e.prototype.readInt32BE=function(t,e){return t>>>=0,e||C(t,4,this.length),this[t]<<24|this[t+1]<<16|this[t+2]<<8|this[t+3]},e.prototype.readFloatLE=function(t,e){return t>>>=0,e||C(t,4,this.length),i.read(this,t,!0,23,4)},e.prototype.readFloatBE=function(t,e){return t>>>=0,e||C(t,4,this.length),i.read(this,t,!1,23,4)},e.prototype.readDoubleLE=function(t,e){return t>>>=0,e||C(t,8,this.length),i.read(this,t,!0,52,8)},e.prototype.readDoubleBE=function(t,e){return t>>>=0,e||C(t,8,this.length),i.read(this,t,!1,52,8)},e.prototype.writeUIntLE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||L(this,t,e,r,Math.pow(2,8*r)-1,0);var i=1,a=0;for(this[e]=255&t;++a<r&&(i*=256);)this[e+a]=t/i&255;return e+r},e.prototype.writeUIntBE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||L(this,t,e,r,Math.pow(2,8*r)-1,0);var i=r-1,a=1;for(this[e+i]=255&t;--i>=0&&(a*=256);)this[e+i]=t/a&255;return e+r},e.prototype.writeUInt8=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,1,255,0),this[e]=255&t,e+1},e.prototype.writeUInt16LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,65535,0),this[e]=255&t,this[e+1]=t>>>8,e+2},e.prototype.writeUInt16BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,65535,0),this[e]=t>>>8,this[e+1]=255&t,e+2},e.prototype.writeUInt32LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,4294967295,0),this[e+3]=t>>>24,this[e+2]=t>>>16,this[e+1]=t>>>8,this[e]=255&t,e+4},e.prototype.writeUInt32BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,4294967295,0),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},e.prototype.writeIntLE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);L(this,t,e,r,i-1,-i)}var a=0,o=1,s=0;for(this[e]=255&t;++a<r&&(o*=256);)t<0&&0===s&&0!==this[e+a-1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},e.prototype.writeIntBE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);L(this,t,e,r,i-1,-i)}var a=r-1,o=1,s=0;for(this[e+a]=255&t;--a>=0&&(o*=256);)t<0&&0===s&&0!==this[e+a+1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},e.prototype.writeInt8=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,1,127,-128),t<0&&(t=255+t+1),this[e]=255&t,e+1},e.prototype.writeInt16LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,32767,-32768),this[e]=255&t,this[e+1]=t>>>8,e+2},e.prototype.writeInt16BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,32767,-32768),this[e]=t>>>8,this[e+1]=255&t,e+2},e.prototype.writeInt32LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,2147483647,-2147483648),this[e]=255&t,this[e+1]=t>>>8,this[e+2]=t>>>16,this[e+3]=t>>>24,e+4},e.prototype.writeInt32BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,2147483647,-2147483648),t<0&&(t=4294967295+t+1),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},e.prototype.writeFloatLE=function(t,e,r){return O(this,t,e,!0,r)},e.prototype.writeFloatBE=function(t,e,r){return O(this,t,e,!1,r)},e.prototype.writeDoubleLE=function(t,e,r){return z(this,t,e,!0,r)},e.prototype.writeDoubleBE=function(t,e,r){return z(this,t,e,!1,r)},e.prototype.copy=function(t,r,n,i){if(!e.isBuffer(t))throw new TypeError(\"argument should be a Buffer\");if(n||(n=0),i||0===i||(i=this.length),r>=t.length&&(r=t.length),r||(r=0),i>0&&i<n&&(i=n),i===n)return 0;if(0===t.length||0===this.length)return 0;if(r<0)throw new RangeError(\"targetStart out of bounds\");if(n<0||n>=this.length)throw new RangeError(\"Index out of range\");if(i<0)throw new RangeError(\"sourceEnd out of bounds\");i>this.length&&(i=this.length),t.length-r<i-n&&(i=t.length-r+n);var a=i-n;if(this===t&&\"function\"==typeof Uint8Array.prototype.copyWithin)this.copyWithin(r,n,i);else if(this===t&&n<r&&r<i)for(var o=a-1;o>=0;--o)t[o+r]=this[o+n];else Uint8Array.prototype.set.call(t,this.subarray(n,i),r);return a},e.prototype.fill=function(t,r,n,i){if(\"string\"==typeof t){if(\"string\"==typeof r?(i=r,r=0,n=this.length):\"string\"==typeof n&&(i=n,n=this.length),void 0!==i&&\"string\"!=typeof i)throw new TypeError(\"encoding must be a string\");if(\"string\"==typeof i&&!e.isEncoding(i))throw new TypeError(\"Unknown encoding: \"+i);if(1===t.length){var a=t.charCodeAt(0);(\"utf8\"===i&&a<128||\"latin1\"===i)&&(t=a)}}else\"number\"==typeof t&&(t&=255);if(r<0||this.length<r||this.length<n)throw new RangeError(\"Out of range index\");if(n<=r)return this;var o;if(r>>>=0,n=void 0===n?this.length:n>>>0,t||(t=0),\"number\"==typeof t)for(o=r;o<n;++o)this[o]=t;else{var s=e.isBuffer(t)?t:e.from(t,i),l=s.length;if(0===l)throw new TypeError('The value \"'+t+'\" is invalid for argument \"value\"');for(o=0;o<n-r;++o)this[o+r]=s[o%l]}return this};var I=/[^+\\/0-9A-Za-z-_]/g;function D(t){return t<16?\"0\"+t.toString(16):t.toString(16)}function R(t,e){var r;e=e||1/0;for(var n=t.length,i=null,a=[],o=0;o<n;++o){if((r=t.charCodeAt(o))>55295&&r<57344){if(!i){if(r>56319){(e-=3)>-1&&a.push(239,191,189);continue}if(o+1===n){(e-=3)>-1&&a.push(239,191,189);continue}i=r;continue}if(r<56320){(e-=3)>-1&&a.push(239,191,189),i=r;continue}r=65536+(i-55296<<10|r-56320)}else i&&(e-=3)>-1&&a.push(239,191,189);if(i=null,r<128){if((e-=1)<0)break;a.push(r)}else if(r<2048){if((e-=2)<0)break;a.push(r>>6|192,63&r|128)}else if(r<65536){if((e-=3)<0)break;a.push(r>>12|224,r>>6&63|128,63&r|128)}else{if(!(r<1114112))throw new Error(\"Invalid code point\");if((e-=4)<0)break;a.push(r>>18|240,r>>12&63|128,r>>6&63|128,63&r|128)}}return a}function F(t){return n.toByteArray(function(t){if((t=(t=t.split(\"=\")[0]).trim().replace(I,\"\")).length<2)return\"\";for(;t.length%4!=0;)t+=\"=\";return t}(t))}function B(t,e,r,n){for(var i=0;i<n&&!(i+r>=e.length||i>=t.length);++i)e[i+r]=t[i];return i}function N(t,e){return t instanceof e||null!=t&&null!=t.constructor&&null!=t.constructor.name&&t.constructor.name===e.name}function j(t){return t!=t}}).call(this,t(\"buffer\").Buffer)},{\"base64-js\":74,buffer:105,ieee754:412}],106:[function(t,e,r){\"use strict\";var n=t(\"./lib/monotone\"),i=t(\"./lib/triangulation\"),a=t(\"./lib/delaunay\"),o=t(\"./lib/filter\");function s(t){return[Math.min(t[0],t[1]),Math.max(t[0],t[1])]}function l(t,e){return t[0]-e[0]||t[1]-e[1]}function c(t,e,r){return e in t?t[e]:r}e.exports=function(t,e,r){Array.isArray(e)?(r=r||{},e=e||[]):(r=e||{},e=[]);var u=!!c(r,\"delaunay\",!0),h=!!c(r,\"interior\",!0),f=!!c(r,\"exterior\",!0),p=!!c(r,\"infinity\",!1);if(!h&&!f||0===t.length)return[];var d=n(t,e);if(u||h!==f||p){for(var g=i(t.length,function(t){return t.map(s).sort(l)}(e)),v=0;v<d.length;++v){var m=d[v];g.addTriangle(m[0],m[1],m[2])}return u&&a(t,g),f?h?p?o(g,0,p):g.cells():o(g,1,p):o(g,-1)}return d}},{\"./lib/delaunay\":107,\"./lib/filter\":108,\"./lib/monotone\":109,\"./lib/triangulation\":110}],107:[function(t,e,r){\"use strict\";var n=t(\"robust-in-sphere\")[4];t(\"binary-search-bounds\");function i(t,e,r,i,a,o){var s=e.opposite(i,a);if(!(s<0)){if(a<i){var l=i;i=a,a=l,l=o,o=s,s=l}e.isConstraint(i,a)||n(t[i],t[a],t[o],t[s])<0&&r.push(i,a)}}e.exports=function(t,e){for(var r=[],a=t.length,o=e.stars,s=0;s<a;++s)for(var l=o[s],c=1;c<l.length;c+=2){var u=l[c];if(!(u<s)&&!e.isConstraint(s,u)){for(var h=l[c-1],f=-1,p=1;p<l.length;p+=2)if(l[p-1]===u){f=l[p];break}f<0||n(t[s],t[u],t[h],t[f])<0&&r.push(s,u)}}for(;r.length>0;){for(var u=r.pop(),s=r.pop(),h=-1,f=-1,l=o[s],d=1;d<l.length;d+=2){var g=l[d-1],v=l[d];g===u?f=v:v===u&&(h=g)}h<0||f<0||(n(t[s],t[u],t[h],t[f])>=0||(e.flip(s,u),i(t,e,r,h,s,f),i(t,e,r,s,f,h),i(t,e,r,f,u,h),i(t,e,r,u,h,f)))}}},{\"binary-search-bounds\":111,\"robust-in-sphere\":508}],108:[function(t,e,r){\"use strict\";var n,i=t(\"binary-search-bounds\");function a(t,e,r,n,i,a,o){this.cells=t,this.neighbor=e,this.flags=n,this.constraint=r,this.active=i,this.next=a,this.boundary=o}function o(t,e){return t[0]-e[0]||t[1]-e[1]||t[2]-e[2]}e.exports=function(t,e,r){var n=function(t,e){for(var r=t.cells(),n=r.length,i=0;i<n;++i){var s=r[i],l=s[0],c=s[1],u=s[2];c<u?c<l&&(s[0]=c,s[1]=u,s[2]=l):u<l&&(s[0]=u,s[1]=l,s[2]=c)}r.sort(o);for(var h=new Array(n),i=0;i<h.length;++i)h[i]=0;var f=[],p=[],d=new Array(3*n),g=new Array(3*n),v=null;e&&(v=[]);for(var m=new a(r,d,g,h,f,p,v),i=0;i<n;++i)for(var s=r[i],y=0;y<3;++y){var l=s[y],c=s[(y+1)%3],x=d[3*i+y]=m.locate(c,l,t.opposite(c,l)),b=g[3*i+y]=t.isConstraint(l,c);x<0&&(b?p.push(i):(f.push(i),h[i]=1),e&&v.push([c,l,-1]))}return m}(t,r);if(0===e)return r?n.cells.concat(n.boundary):n.cells;var i=1,s=n.active,l=n.next,c=n.flags,u=n.cells,h=n.constraint,f=n.neighbor;for(;s.length>0||l.length>0;){for(;s.length>0;){var p=s.pop();if(c[p]!==-i){c[p]=i;u[p];for(var d=0;d<3;++d){var g=f[3*p+d];g>=0&&0===c[g]&&(h[3*p+d]?l.push(g):(s.push(g),c[g]=i))}}}var v=l;l=s,s=v,l.length=0,i=-i}var m=function(t,e,r){for(var n=0,i=0;i<t.length;++i)e[i]===r&&(t[n++]=t[i]);return t.length=n,t}(u,c,e);if(r)return m.concat(n.boundary);return m},a.prototype.locate=(n=[0,0,0],function(t,e,r){var a=t,s=e,l=r;return e<r?e<t&&(a=e,s=r,l=t):r<t&&(a=r,s=t,l=e),a<0?-1:(n[0]=a,n[1]=s,n[2]=l,i.eq(this.cells,n,o))})},{\"binary-search-bounds\":111}],109:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"robust-orientation\")[3],a=0,o=1,s=2;function l(t,e,r,n,i){this.a=t,this.b=e,this.idx=r,this.lowerIds=n,this.upperIds=i}function c(t,e,r,n){this.a=t,this.b=e,this.type=r,this.idx=n}function u(t,e){var r=t.a[0]-e.a[0]||t.a[1]-e.a[1]||t.type-e.type;return r||(t.type!==a&&(r=i(t.a,t.b,e.b))?r:t.idx-e.idx)}function h(t,e){return i(t.a,t.b,e)}function f(t,e,r,a,o){for(var s=n.lt(e,a,h),l=n.gt(e,a,h),c=s;c<l;++c){for(var u=e[c],f=u.lowerIds,p=f.length;p>1&&i(r[f[p-2]],r[f[p-1]],a)>0;)t.push([f[p-1],f[p-2],o]),p-=1;f.length=p,f.push(o);var d=u.upperIds;for(p=d.length;p>1&&i(r[d[p-2]],r[d[p-1]],a)<0;)t.push([d[p-2],d[p-1],o]),p-=1;d.length=p,d.push(o)}}function p(t,e){var r;return(r=t.a[0]<e.a[0]?i(t.a,t.b,e.a):i(e.b,e.a,t.a))?r:(r=e.b[0]<t.b[0]?i(t.a,t.b,e.b):i(e.b,e.a,t.b))||t.idx-e.idx}function d(t,e,r){var i=n.le(t,r,p),a=t[i],o=a.upperIds,s=o[o.length-1];a.upperIds=[s],t.splice(i+1,0,new l(r.a,r.b,r.idx,[s],o))}function g(t,e,r){var i=r.a;r.a=r.b,r.b=i;var a=n.eq(t,r,p),o=t[a];t[a-1].upperIds=o.upperIds,t.splice(a,1)}e.exports=function(t,e){for(var r=t.length,n=e.length,i=[],h=0;h<r;++h)i.push(new c(t[h],null,a,h));for(var h=0;h<n;++h){var p=e[h],v=t[p[0]],m=t[p[1]];v[0]<m[0]?i.push(new c(v,m,s,h),new c(m,v,o,h)):v[0]>m[0]&&i.push(new c(m,v,s,h),new c(v,m,o,h))}i.sort(u);for(var y=i[0].a[0]-(1+Math.abs(i[0].a[0]))*Math.pow(2,-52),x=[new l([y,1],[y,0],-1,[],[],[],[])],b=[],h=0,_=i.length;h<_;++h){var w=i[h],k=w.type;k===a?f(b,x,t,w.a,w.idx):k===s?d(x,t,w):g(x,t,w)}return b}},{\"binary-search-bounds\":111,\"robust-orientation\":510}],110:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\");function i(t,e){this.stars=t,this.edges=e}e.exports=function(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=[];return new i(r,e)};var a=i.prototype;function o(t,e,r){for(var n=1,i=t.length;n<i;n+=2)if(t[n-1]===e&&t[n]===r)return t[n-1]=t[i-2],t[n]=t[i-1],void(t.length=i-2)}a.isConstraint=function(){var t=[0,0];function e(t,e){return t[0]-e[0]||t[1]-e[1]}return function(r,i){return t[0]=Math.min(r,i),t[1]=Math.max(r,i),n.eq(this.edges,t,e)>=0}}(),a.removeTriangle=function(t,e,r){var n=this.stars;o(n[t],e,r),o(n[e],r,t),o(n[r],t,e)},a.addTriangle=function(t,e,r){var n=this.stars;n[t].push(e,r),n[e].push(r,t),n[r].push(t,e)},a.opposite=function(t,e){for(var r=this.stars[e],n=1,i=r.length;n<i;n+=2)if(r[n]===t)return r[n-1];return-1},a.flip=function(t,e){var r=this.opposite(t,e),n=this.opposite(e,t);this.removeTriangle(t,e,r),this.removeTriangle(e,t,n),this.addTriangle(t,n,r),this.addTriangle(e,r,n)},a.edges=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2)e.push([i[a],i[a+1]]);return e},a.cells=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2){var s=i[a],l=i[a+1];r<Math.min(s,l)&&e.push([r,s,l])}return e}},{\"binary-search-bounds\":111}],111:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",i?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a[m]\"];return i?e.indexOf(\"c\")<0?a.push(\";if(x===y){return m}else if(x<=y){\"):a.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):a.push(\";if(\",e,\"){i=m;\"),r?a.push(\"l=m+1}else{h=m-1}\"):a.push(\"h=m-1}else{l=m+1}\"),a.push(\"}\"),i?a.push(\"return -1};\"):a.push(\"return i};\"),a.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(typeof(c)==='function'){return P(a,(l===void 0)?0:l|0,(h===void 0)?a.length-1:h|0,y,c)}else{return A(a,(c===void 0)?0:c|0,(l===void 0)?a.length-1:l|0,y)}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],112:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1,r=1;r<t.length;++r)for(var n=0;n<r;++n)if(t[r]<t[n])e=-e;else if(t[n]===t[r])return 0;return e}},{}],113:[function(t,e,r){\"use strict\";var n=t(\"dup\"),i=t(\"robust-linear-solve\");function a(t,e){for(var r=0,n=t.length,i=0;i<n;++i)r+=t[i]*e[i];return r}function o(t){var e=t.length;if(0===e)return[];t[0].length;var r=n([t.length+1,t.length+1],1),o=n([t.length+1],1);r[e][e]=0;for(var s=0;s<e;++s){for(var l=0;l<=s;++l)r[l][s]=r[s][l]=2*a(t[s],t[l]);o[s]=a(t[s],t[s])}var c=i(r,o),u=0,h=c[e+1];for(s=0;s<h.length;++s)u+=h[s];var f=new Array(e);for(s=0;s<e;++s){h=c[s];var p=0;for(l=0;l<h.length;++l)p+=h[l];f[s]=p/u}return f}function s(t){if(0===t.length)return[];for(var e=t[0].length,r=n([e]),i=o(t),a=0;a<t.length;++a)for(var s=0;s<e;++s)r[s]+=t[a][s]*i[a];return r}s.barycenetric=o,e.exports=s},{dup:170,\"robust-linear-solve\":509}],114:[function(t,e,r){e.exports=function(t){for(var e=n(t),r=0,i=0;i<t.length;++i)for(var a=t[i],o=0;o<e.length;++o)r+=Math.pow(a[o]-e[o],2);return Math.sqrt(r/t.length)};var n=t(\"circumcenter\")},{circumcenter:113}],115:[function(t,e,r){e.exports=function(t,e,r){return e<r?t<e?e:t>r?r:t:t<r?r:t>e?e:t}},{}],116:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n;if(r){n=e;for(var i=new Array(e.length),a=0;a<e.length;++a){var o=e[a];i[a]=[o[0],o[1],r[a]]}e=i}var s=function(t,e,r){var n=d(t,[],p(t));return m(e,n,r),!!n}(t,e,!!r);for(;y(t,e,!!r);)s=!0;if(r&&s){n.length=0,r.length=0;for(var a=0;a<e.length;++a){var o=e[a];n.push([o[0],o[1]]),r.push(o[2])}}return s};var n=t(\"union-find\"),i=t(\"box-intersect\"),a=t(\"robust-segment-intersect\"),o=t(\"big-rat\"),s=t(\"big-rat/cmp\"),l=t(\"big-rat/to-float\"),c=t(\"rat-vec\"),u=t(\"nextafter\"),h=t(\"./lib/rat-seg-intersect\");function f(t){var e=l(t);return[u(e,-1/0),u(e,1/0)]}function p(t){for(var e=new Array(t.length),r=0;r<t.length;++r){var n=t[r];e[r]=[u(n[0],-1/0),u(n[1],-1/0),u(n[0],1/0),u(n[1],1/0)]}return e}function d(t,e,r){for(var a=e.length,o=new n(a),s=[],l=0;l<e.length;++l){var c=e[l],h=f(c[0]),p=f(c[1]);s.push([u(h[0],-1/0),u(p[0],-1/0),u(h[1],1/0),u(p[1],1/0)])}i(s,function(t,e){o.link(t,e)});var d=!0,g=new Array(a);for(l=0;l<a;++l){(m=o.find(l))!==l&&(d=!1,t[m]=[Math.min(t[l][0],t[m][0]),Math.min(t[l][1],t[m][1])])}if(d)return null;var v=0;for(l=0;l<a;++l){var m;(m=o.find(l))===l?(g[l]=v,t[v++]=t[l]):g[l]=-1}t.length=v;for(l=0;l<a;++l)g[l]<0&&(g[l]=g[o.find(l)]);return g}function g(t,e){return t[0]-e[0]||t[1]-e[1]}function v(t,e){var r=t[0]-e[0]||t[1]-e[1];return r||(t[2]<e[2]?-1:t[2]>e[2]?1:0)}function m(t,e,r){if(0!==t.length){if(e)for(var n=0;n<t.length;++n){var i=e[(o=t[n])[0]],a=e[o[1]];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}else for(n=0;n<t.length;++n){var o;i=(o=t[n])[0],a=o[1];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}r?t.sort(v):t.sort(g);var s=1;for(n=1;n<t.length;++n){var l=t[n-1],c=t[n];(c[0]!==l[0]||c[1]!==l[1]||r&&c[2]!==l[2])&&(t[s++]=c)}t.length=s}}function y(t,e,r){var n=function(t,e){for(var r=new Array(e.length),n=0;n<e.length;++n){var i=e[n],a=t[i[0]],o=t[i[1]];r[n]=[u(Math.min(a[0],o[0]),-1/0),u(Math.min(a[1],o[1]),-1/0),u(Math.max(a[0],o[0]),1/0),u(Math.max(a[1],o[1]),1/0)]}return r}(t,e),f=function(t,e,r){var n=[];return i(r,function(r,i){var o=e[r],s=e[i];if(o[0]!==s[0]&&o[0]!==s[1]&&o[1]!==s[0]&&o[1]!==s[1]){var l=t[o[0]],c=t[o[1]],u=t[s[0]],h=t[s[1]];a(l,c,u,h)&&n.push([r,i])}}),n}(t,e,n),g=p(t),v=function(t,e,r,n){var o=[];return i(r,n,function(r,n){var i=e[r];if(i[0]!==n&&i[1]!==n){var s=t[n],l=t[i[0]],c=t[i[1]];a(l,c,s,s)&&o.push([r,n])}}),o}(t,e,n,g),y=d(t,function(t,e,r,n,i){var a,u,f=t.map(function(t){return[o(t[0]),o(t[1])]});for(a=0;a<r.length;++a){var p=r[a];u=p[0];var d=p[1],g=e[u],v=e[d],m=h(c(t[g[0]]),c(t[g[1]]),c(t[v[0]]),c(t[v[1]]));if(m){var y=t.length;t.push([l(m[0]),l(m[1])]),f.push(m),n.push([u,y],[d,y])}}for(n.sort(function(t,e){if(t[0]!==e[0])return t[0]-e[0];var r=f[t[1]],n=f[e[1]];return s(r[0],n[0])||s(r[1],n[1])}),a=n.length-1;a>=0;--a){var x=e[u=(S=n[a])[0]],b=x[0],_=x[1],w=t[b],k=t[_];if((w[0]-k[0]||w[1]-k[1])<0){var T=b;b=_,_=T}x[0]=b;var A,M=x[1]=S[1];for(i&&(A=x[2]);a>0&&n[a-1][0]===u;){var S,E=(S=n[--a])[1];i?e.push([M,E,A]):e.push([M,E]),M=E}i?e.push([M,_,A]):e.push([M,_])}return f}(t,e,f,v,r));return m(e,y,r),!!y||(f.length>0||v.length>0)}},{\"./lib/rat-seg-intersect\":117,\"big-rat\":78,\"big-rat/cmp\":76,\"big-rat/to-float\":90,\"box-intersect\":96,nextafter:451,\"rat-vec\":486,\"robust-segment-intersect\":513,\"union-find\":546}],117:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var a=s(e,t),h=s(n,r),f=u(a,h);if(0===o(f))return null;var p=s(t,r),d=u(h,p),g=i(d,f),v=c(a,g);return l(t,v)};var n=t(\"big-rat/mul\"),i=t(\"big-rat/div\"),a=t(\"big-rat/sub\"),o=t(\"big-rat/sign\"),s=t(\"rat-vec/sub\"),l=t(\"rat-vec/add\"),c=t(\"rat-vec/muls\");function u(t,e){return a(n(t[0],e[1]),n(t[1],e[0]))}},{\"big-rat/div\":77,\"big-rat/mul\":87,\"big-rat/sign\":88,\"big-rat/sub\":89,\"rat-vec/add\":485,\"rat-vec/muls\":487,\"rat-vec/sub\":488}],118:[function(t,e,r){\"use strict\";var n=t(\"clamp\");function i(t,e){null==e&&(e=!0);var r=t[0],i=t[1],a=t[2],o=t[3];return null==o&&(o=e?1:255),e&&(r*=255,i*=255,a*=255,o*=255),16777216*(r=255&n(r,0,255))+((i=255&n(i,0,255))<<16)+((a=255&n(a,0,255))<<8)+(o=255&n(o,0,255))}e.exports=i,e.exports.to=i,e.exports.from=function(t,e){var r=(t=+t)>>>24,n=(16711680&t)>>>16,i=(65280&t)>>>8,a=255&t;return!1===e?[r,n,i,a]:[r/255,n/255,i/255,a/255]}},{clamp:115}],119:[function(t,e,r){\"use strict\";e.exports={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]}},{}],120:[function(t,e,r){\"use strict\";var n=t(\"color-rgba\"),i=t(\"clamp\"),a=t(\"dtype\");e.exports=function(t,e){\"float\"!==e&&e||(e=\"array\"),\"uint\"===e&&(e=\"uint8\"),\"uint_clamped\"===e&&(e=\"uint8_clamped\");var r=new(a(e))(4),o=\"uint8\"!==e&&\"uint8_clamped\"!==e;return t.length&&\"string\"!=typeof t||((t=n(t))[0]/=255,t[1]/=255,t[2]/=255),function(t){return t instanceof Uint8Array||t instanceof Uint8ClampedArray||!!(Array.isArray(t)&&(t[0]>1||0===t[0])&&(t[1]>1||0===t[1])&&(t[2]>1||0===t[2])&&(!t[3]||t[3]>1))}(t)?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:255,o&&(r[0]/=255,r[1]/=255,r[2]/=255,r[3]/=255),r):(o?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:1):(r[0]=i(Math.floor(255*t[0]),0,255),r[1]=i(Math.floor(255*t[1]),0,255),r[2]=i(Math.floor(255*t[2]),0,255),r[3]=null==t[3]?255:i(Math.floor(255*t[3]),0,255)),r)}},{clamp:115,\"color-rgba\":122,dtype:169}],121:[function(t,e,r){(function(r){\"use strict\";var n=t(\"color-name\"),i=t(\"is-plain-obj\"),a=t(\"defined\");e.exports=function(t){var e,s,l=[],c=1;if(\"string\"==typeof t)if(n[t])l=n[t].slice(),s=\"rgb\";else if(\"transparent\"===t)c=0,s=\"rgb\",l=[0,0,0];else if(/^#[A-Fa-f0-9]+$/.test(t)){var u=t.slice(1),h=u.length,f=h<=4;c=1,f?(l=[parseInt(u[0]+u[0],16),parseInt(u[1]+u[1],16),parseInt(u[2]+u[2],16)],4===h&&(c=parseInt(u[3]+u[3],16)/255)):(l=[parseInt(u[0]+u[1],16),parseInt(u[2]+u[3],16),parseInt(u[4]+u[5],16)],8===h&&(c=parseInt(u[6]+u[7],16)/255)),l[0]||(l[0]=0),l[1]||(l[1]=0),l[2]||(l[2]=0),s=\"rgb\"}else if(e=/^((?:rgb|hs[lvb]|hwb|cmyk?|xy[zy]|gray|lab|lchu?v?|[ly]uv|lms)a?)\\s*\\(([^\\)]*)\\)/.exec(t)){var p=e[1],d=\"rgb\"===p,u=p.replace(/a$/,\"\");s=u;var h=\"cmyk\"===u?4:\"gray\"===u?1:3;l=e[2].trim().split(/\\s*,\\s*/).map(function(t,e){if(/%$/.test(t))return e===h?parseFloat(t)/100:\"rgb\"===u?255*parseFloat(t)/100:parseFloat(t);if(\"h\"===u[e]){if(/deg$/.test(t))return parseFloat(t);if(void 0!==o[t])return o[t]}return parseFloat(t)}),p===u&&l.push(1),c=d?1:void 0===l[h]?1:l[h],l=l.slice(0,h)}else t.length>10&&/[0-9](?:\\s|\\/)/.test(t)&&(l=t.match(/([0-9]+)/g).map(function(t){return parseFloat(t)}),s=t.match(/([a-z])/gi).join(\"\").toLowerCase());else if(isNaN(t))if(i(t)){var g=a(t.r,t.red,t.R,null);null!==g?(s=\"rgb\",l=[g,a(t.g,t.green,t.G),a(t.b,t.blue,t.B)]):(s=\"hsl\",l=[a(t.h,t.hue,t.H),a(t.s,t.saturation,t.S),a(t.l,t.lightness,t.L,t.b,t.brightness)]),c=a(t.a,t.alpha,t.opacity,1),null!=t.opacity&&(c/=100)}else(Array.isArray(t)||r.ArrayBuffer&&ArrayBuffer.isView&&ArrayBuffer.isView(t))&&(l=[t[0],t[1],t[2]],s=\"rgb\",c=4===t.length?t[3]:1);else s=\"rgb\",l=[t>>>16,(65280&t)>>>8,255&t];return{space:s,values:l,alpha:c}};var o={red:0,orange:60,yellow:120,green:180,blue:240,purple:300}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"color-name\":119,defined:164,\"is-plain-obj\":422}],122:[function(t,e,r){\"use strict\";var n=t(\"color-parse\"),i=t(\"color-space/hsl\"),a=t(\"clamp\");e.exports=function(t){var e,r=n(t);return r.space?((e=Array(3))[0]=a(r.values[0],0,255),e[1]=a(r.values[1],0,255),e[2]=a(r.values[2],0,255),\"h\"===r.space[0]&&(e=i.rgb(e)),e.push(a(r.alpha,0,1)),e):[]}},{clamp:115,\"color-parse\":121,\"color-space/hsl\":123}],123:[function(t,e,r){\"use strict\";var n=t(\"./rgb\");e.exports={name:\"hsl\",min:[0,0,0],max:[360,100,100],channel:[\"hue\",\"saturation\",\"lightness\"],alias:[\"HSL\"],rgb:function(t){var e,r,n,i,a,o=t[0]/360,s=t[1]/100,l=t[2]/100;if(0===s)return[a=255*l,a,a];e=2*l-(r=l<.5?l*(1+s):l+s-l*s),i=[0,0,0];for(var c=0;c<3;c++)(n=o+1/3*-(c-1))<0?n++:n>1&&n--,a=6*n<1?e+6*(r-e)*n:2*n<1?r:3*n<2?e+(r-e)*(2/3-n)*6:e,i[c]=255*a;return i}},n.hsl=function(t){var e,r,n=t[0]/255,i=t[1]/255,a=t[2]/255,o=Math.min(n,i,a),s=Math.max(n,i,a),l=s-o;return s===o?e=0:n===s?e=(i-a)/l:i===s?e=2+(a-n)/l:a===s&&(e=4+(n-i)/l),(e=Math.min(60*e,360))<0&&(e+=360),r=(o+s)/2,[e,100*(s===o?0:r<=.5?l/(s+o):l/(2-s-o)),100*r]}},{\"./rgb\":124}],124:[function(t,e,r){\"use strict\";e.exports={name:\"rgb\",min:[0,0,0],max:[255,255,255],channel:[\"red\",\"green\",\"blue\"],alias:[\"RGB\"]}},{}],125:[function(t,e,r){e.exports={jet:[{index:0,rgb:[0,0,131]},{index:.125,rgb:[0,60,170]},{index:.375,rgb:[5,255,255]},{index:.625,rgb:[255,255,0]},{index:.875,rgb:[250,0,0]},{index:1,rgb:[128,0,0]}],hsv:[{index:0,rgb:[255,0,0]},{index:.169,rgb:[253,255,2]},{index:.173,rgb:[247,255,2]},{index:.337,rgb:[0,252,4]},{index:.341,rgb:[0,252,10]},{index:.506,rgb:[1,249,255]},{index:.671,rgb:[2,0,253]},{index:.675,rgb:[8,0,253]},{index:.839,rgb:[255,0,251]},{index:.843,rgb:[255,0,245]},{index:1,rgb:[255,0,6]}],hot:[{index:0,rgb:[0,0,0]},{index:.3,rgb:[230,0,0]},{index:.6,rgb:[255,210,0]},{index:1,rgb:[255,255,255]}],cool:[{index:0,rgb:[0,255,255]},{index:1,rgb:[255,0,255]}],spring:[{index:0,rgb:[255,0,255]},{index:1,rgb:[255,255,0]}],summer:[{index:0,rgb:[0,128,102]},{index:1,rgb:[255,255,102]}],autumn:[{index:0,rgb:[255,0,0]},{index:1,rgb:[255,255,0]}],winter:[{index:0,rgb:[0,0,255]},{index:1,rgb:[0,255,128]}],bone:[{index:0,rgb:[0,0,0]},{index:.376,rgb:[84,84,116]},{index:.753,rgb:[169,200,200]},{index:1,rgb:[255,255,255]}],copper:[{index:0,rgb:[0,0,0]},{index:.804,rgb:[255,160,102]},{index:1,rgb:[255,199,127]}],greys:[{index:0,rgb:[0,0,0]},{index:1,rgb:[255,255,255]}],yignbu:[{index:0,rgb:[8,29,88]},{index:.125,rgb:[37,52,148]},{index:.25,rgb:[34,94,168]},{index:.375,rgb:[29,145,192]},{index:.5,rgb:[65,182,196]},{index:.625,rgb:[127,205,187]},{index:.75,rgb:[199,233,180]},{index:.875,rgb:[237,248,217]},{index:1,rgb:[255,255,217]}],greens:[{index:0,rgb:[0,68,27]},{index:.125,rgb:[0,109,44]},{index:.25,rgb:[35,139,69]},{index:.375,rgb:[65,171,93]},{index:.5,rgb:[116,196,118]},{index:.625,rgb:[161,217,155]},{index:.75,rgb:[199,233,192]},{index:.875,rgb:[229,245,224]},{index:1,rgb:[247,252,245]}],yiorrd:[{index:0,rgb:[128,0,38]},{index:.125,rgb:[189,0,38]},{index:.25,rgb:[227,26,28]},{index:.375,rgb:[252,78,42]},{index:.5,rgb:[253,141,60]},{index:.625,rgb:[254,178,76]},{index:.75,rgb:[254,217,118]},{index:.875,rgb:[255,237,160]},{index:1,rgb:[255,255,204]}],bluered:[{index:0,rgb:[0,0,255]},{index:1,rgb:[255,0,0]}],rdbu:[{index:0,rgb:[5,10,172]},{index:.35,rgb:[106,137,247]},{index:.5,rgb:[190,190,190]},{index:.6,rgb:[220,170,132]},{index:.7,rgb:[230,145,90]},{index:1,rgb:[178,10,28]}],picnic:[{index:0,rgb:[0,0,255]},{index:.1,rgb:[51,153,255]},{index:.2,rgb:[102,204,255]},{index:.3,rgb:[153,204,255]},{index:.4,rgb:[204,204,255]},{index:.5,rgb:[255,255,255]},{index:.6,rgb:[255,204,255]},{index:.7,rgb:[255,153,255]},{index:.8,rgb:[255,102,204]},{index:.9,rgb:[255,102,102]},{index:1,rgb:[255,0,0]}],rainbow:[{index:0,rgb:[150,0,90]},{index:.125,rgb:[0,0,200]},{index:.25,rgb:[0,25,255]},{index:.375,rgb:[0,152,255]},{index:.5,rgb:[44,255,150]},{index:.625,rgb:[151,255,0]},{index:.75,rgb:[255,234,0]},{index:.875,rgb:[255,111,0]},{index:1,rgb:[255,0,0]}],portland:[{index:0,rgb:[12,51,131]},{index:.25,rgb:[10,136,186]},{index:.5,rgb:[242,211,56]},{index:.75,rgb:[242,143,56]},{index:1,rgb:[217,30,30]}],blackbody:[{index:0,rgb:[0,0,0]},{index:.2,rgb:[230,0,0]},{index:.4,rgb:[230,210,0]},{index:.7,rgb:[255,255,255]},{index:1,rgb:[160,200,255]}],earth:[{index:0,rgb:[0,0,130]},{index:.1,rgb:[0,180,180]},{index:.2,rgb:[40,210,40]},{index:.4,rgb:[230,230,50]},{index:.6,rgb:[120,70,20]},{index:1,rgb:[255,255,255]}],electric:[{index:0,rgb:[0,0,0]},{index:.15,rgb:[30,0,100]},{index:.4,rgb:[120,0,100]},{index:.6,rgb:[160,90,0]},{index:.8,rgb:[230,200,0]},{index:1,rgb:[255,250,220]}],alpha:[{index:0,rgb:[255,255,255,0]},{index:1,rgb:[255,255,255,1]}],viridis:[{index:0,rgb:[68,1,84]},{index:.13,rgb:[71,44,122]},{index:.25,rgb:[59,81,139]},{index:.38,rgb:[44,113,142]},{index:.5,rgb:[33,144,141]},{index:.63,rgb:[39,173,129]},{index:.75,rgb:[92,200,99]},{index:.88,rgb:[170,220,50]},{index:1,rgb:[253,231,37]}],inferno:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[31,12,72]},{index:.25,rgb:[85,15,109]},{index:.38,rgb:[136,34,106]},{index:.5,rgb:[186,54,85]},{index:.63,rgb:[227,89,51]},{index:.75,rgb:[249,140,10]},{index:.88,rgb:[249,201,50]},{index:1,rgb:[252,255,164]}],magma:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[28,16,68]},{index:.25,rgb:[79,18,123]},{index:.38,rgb:[129,37,129]},{index:.5,rgb:[181,54,122]},{index:.63,rgb:[229,80,100]},{index:.75,rgb:[251,135,97]},{index:.88,rgb:[254,194,135]},{index:1,rgb:[252,253,191]}],plasma:[{index:0,rgb:[13,8,135]},{index:.13,rgb:[75,3,161]},{index:.25,rgb:[125,3,168]},{index:.38,rgb:[168,34,150]},{index:.5,rgb:[203,70,121]},{index:.63,rgb:[229,107,93]},{index:.75,rgb:[248,148,65]},{index:.88,rgb:[253,195,40]},{index:1,rgb:[240,249,33]}],warm:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[172,0,187]},{index:.25,rgb:[219,0,170]},{index:.38,rgb:[255,0,130]},{index:.5,rgb:[255,63,74]},{index:.63,rgb:[255,123,0]},{index:.75,rgb:[234,176,0]},{index:.88,rgb:[190,228,0]},{index:1,rgb:[147,255,0]}],cool:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[116,0,218]},{index:.25,rgb:[98,74,237]},{index:.38,rgb:[68,146,231]},{index:.5,rgb:[0,204,197]},{index:.63,rgb:[0,247,146]},{index:.75,rgb:[0,255,88]},{index:.88,rgb:[40,255,8]},{index:1,rgb:[147,255,0]}],\"rainbow-soft\":[{index:0,rgb:[125,0,179]},{index:.1,rgb:[199,0,180]},{index:.2,rgb:[255,0,121]},{index:.3,rgb:[255,108,0]},{index:.4,rgb:[222,194,0]},{index:.5,rgb:[150,255,0]},{index:.6,rgb:[0,255,55]},{index:.7,rgb:[0,246,150]},{index:.8,rgb:[50,167,222]},{index:.9,rgb:[103,51,235]},{index:1,rgb:[124,0,186]}],bathymetry:[{index:0,rgb:[40,26,44]},{index:.13,rgb:[59,49,90]},{index:.25,rgb:[64,76,139]},{index:.38,rgb:[63,110,151]},{index:.5,rgb:[72,142,158]},{index:.63,rgb:[85,174,163]},{index:.75,rgb:[120,206,163]},{index:.88,rgb:[187,230,172]},{index:1,rgb:[253,254,204]}],cdom:[{index:0,rgb:[47,15,62]},{index:.13,rgb:[87,23,86]},{index:.25,rgb:[130,28,99]},{index:.38,rgb:[171,41,96]},{index:.5,rgb:[206,67,86]},{index:.63,rgb:[230,106,84]},{index:.75,rgb:[242,149,103]},{index:.88,rgb:[249,193,135]},{index:1,rgb:[254,237,176]}],chlorophyll:[{index:0,rgb:[18,36,20]},{index:.13,rgb:[25,63,41]},{index:.25,rgb:[24,91,59]},{index:.38,rgb:[13,119,72]},{index:.5,rgb:[18,148,80]},{index:.63,rgb:[80,173,89]},{index:.75,rgb:[132,196,122]},{index:.88,rgb:[175,221,162]},{index:1,rgb:[215,249,208]}],density:[{index:0,rgb:[54,14,36]},{index:.13,rgb:[89,23,80]},{index:.25,rgb:[110,45,132]},{index:.38,rgb:[120,77,178]},{index:.5,rgb:[120,113,213]},{index:.63,rgb:[115,151,228]},{index:.75,rgb:[134,185,227]},{index:.88,rgb:[177,214,227]},{index:1,rgb:[230,241,241]}],\"freesurface-blue\":[{index:0,rgb:[30,4,110]},{index:.13,rgb:[47,14,176]},{index:.25,rgb:[41,45,236]},{index:.38,rgb:[25,99,212]},{index:.5,rgb:[68,131,200]},{index:.63,rgb:[114,156,197]},{index:.75,rgb:[157,181,203]},{index:.88,rgb:[200,208,216]},{index:1,rgb:[241,237,236]}],\"freesurface-red\":[{index:0,rgb:[60,9,18]},{index:.13,rgb:[100,17,27]},{index:.25,rgb:[142,20,29]},{index:.38,rgb:[177,43,27]},{index:.5,rgb:[192,87,63]},{index:.63,rgb:[205,125,105]},{index:.75,rgb:[216,162,148]},{index:.88,rgb:[227,199,193]},{index:1,rgb:[241,237,236]}],oxygen:[{index:0,rgb:[64,5,5]},{index:.13,rgb:[106,6,15]},{index:.25,rgb:[144,26,7]},{index:.38,rgb:[168,64,3]},{index:.5,rgb:[188,100,4]},{index:.63,rgb:[206,136,11]},{index:.75,rgb:[220,174,25]},{index:.88,rgb:[231,215,44]},{index:1,rgb:[248,254,105]}],par:[{index:0,rgb:[51,20,24]},{index:.13,rgb:[90,32,35]},{index:.25,rgb:[129,44,34]},{index:.38,rgb:[159,68,25]},{index:.5,rgb:[182,99,19]},{index:.63,rgb:[199,134,22]},{index:.75,rgb:[212,171,35]},{index:.88,rgb:[221,210,54]},{index:1,rgb:[225,253,75]}],phase:[{index:0,rgb:[145,105,18]},{index:.13,rgb:[184,71,38]},{index:.25,rgb:[186,58,115]},{index:.38,rgb:[160,71,185]},{index:.5,rgb:[110,97,218]},{index:.63,rgb:[50,123,164]},{index:.75,rgb:[31,131,110]},{index:.88,rgb:[77,129,34]},{index:1,rgb:[145,105,18]}],salinity:[{index:0,rgb:[42,24,108]},{index:.13,rgb:[33,50,162]},{index:.25,rgb:[15,90,145]},{index:.38,rgb:[40,118,137]},{index:.5,rgb:[59,146,135]},{index:.63,rgb:[79,175,126]},{index:.75,rgb:[120,203,104]},{index:.88,rgb:[193,221,100]},{index:1,rgb:[253,239,154]}],temperature:[{index:0,rgb:[4,35,51]},{index:.13,rgb:[23,51,122]},{index:.25,rgb:[85,59,157]},{index:.38,rgb:[129,79,143]},{index:.5,rgb:[175,95,130]},{index:.63,rgb:[222,112,101]},{index:.75,rgb:[249,146,66]},{index:.88,rgb:[249,196,65]},{index:1,rgb:[232,250,91]}],turbidity:[{index:0,rgb:[34,31,27]},{index:.13,rgb:[65,50,41]},{index:.25,rgb:[98,69,52]},{index:.38,rgb:[131,89,57]},{index:.5,rgb:[161,112,59]},{index:.63,rgb:[185,140,66]},{index:.75,rgb:[202,174,88]},{index:.88,rgb:[216,209,126]},{index:1,rgb:[233,246,171]}],\"velocity-blue\":[{index:0,rgb:[17,32,64]},{index:.13,rgb:[35,52,116]},{index:.25,rgb:[29,81,156]},{index:.38,rgb:[31,113,162]},{index:.5,rgb:[50,144,169]},{index:.63,rgb:[87,173,176]},{index:.75,rgb:[149,196,189]},{index:.88,rgb:[203,221,211]},{index:1,rgb:[254,251,230]}],\"velocity-green\":[{index:0,rgb:[23,35,19]},{index:.13,rgb:[24,64,38]},{index:.25,rgb:[11,95,45]},{index:.38,rgb:[39,123,35]},{index:.5,rgb:[95,146,12]},{index:.63,rgb:[152,165,18]},{index:.75,rgb:[201,186,69]},{index:.88,rgb:[233,216,137]},{index:1,rgb:[255,253,205]}],cubehelix:[{index:0,rgb:[0,0,0]},{index:.07,rgb:[22,5,59]},{index:.13,rgb:[60,4,105]},{index:.2,rgb:[109,1,135]},{index:.27,rgb:[161,0,147]},{index:.33,rgb:[210,2,142]},{index:.4,rgb:[251,11,123]},{index:.47,rgb:[255,29,97]},{index:.53,rgb:[255,54,69]},{index:.6,rgb:[255,85,46]},{index:.67,rgb:[255,120,34]},{index:.73,rgb:[255,157,37]},{index:.8,rgb:[241,191,57]},{index:.87,rgb:[224,220,93]},{index:.93,rgb:[218,241,142]},{index:1,rgb:[227,253,198]}]}},{}],126:[function(t,e,r){\"use strict\";var n=t(\"./colorScale\"),i=t(\"lerp\");function a(t){return[t[0]/255,t[1]/255,t[2]/255,t[3]]}function o(t){for(var e,r=\"#\",n=0;n<3;++n)r+=(\"00\"+(e=(e=t[n]).toString(16))).substr(e.length);return r}function s(t){return\"rgba(\"+t.join(\",\")+\")\"}e.exports=function(t){var e,r,l,c,u,h,f,p,d,g;t||(t={});p=(t.nshades||72)-1,f=t.format||\"hex\",(h=t.colormap)||(h=\"jet\");if(\"string\"==typeof h){if(h=h.toLowerCase(),!n[h])throw Error(h+\" not a supported colorscale\");u=n[h]}else{if(!Array.isArray(h))throw Error(\"unsupported colormap option\",h);u=h.slice()}if(u.length>p+1)throw new Error(h+\" map requires nshades to be at least size \"+u.length);d=Array.isArray(t.alpha)?2!==t.alpha.length?[1,1]:t.alpha.slice():\"number\"==typeof t.alpha?[t.alpha,t.alpha]:[1,1];e=u.map(function(t){return Math.round(t.index*p)}),d[0]=Math.min(Math.max(d[0],0),1),d[1]=Math.min(Math.max(d[1],0),1);var v=u.map(function(t,e){var r=u[e].index,n=u[e].rgb.slice();return 4===n.length&&n[3]>=0&&n[3]<=1?n:(n[3]=d[0]+(d[1]-d[0])*r,n)}),m=[];for(g=0;g<e.length-1;++g){c=e[g+1]-e[g],r=v[g],l=v[g+1];for(var y=0;y<c;y++){var x=y/c;m.push([Math.round(i(r[0],l[0],x)),Math.round(i(r[1],l[1],x)),Math.round(i(r[2],l[2],x)),i(r[3],l[3],x)])}}m.push(u[u.length-1].rgb.concat(d[1])),\"hex\"===f?m=m.map(o):\"rgbaString\"===f?m=m.map(s):\"float\"===f&&(m=m.map(a));return m}},{\"./colorScale\":125,lerp:425}],127:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a){var o=n(e,r,a);if(0===o){var s=i(n(t,e,r)),c=i(n(t,e,a));if(s===c){if(0===s){var u=l(t,e,r),h=l(t,e,a);return u===h?0:u?1:-1}return 0}return 0===c?s>0?-1:l(t,e,a)?-1:1:0===s?c>0?1:l(t,e,r)?1:-1:i(c-s)}var f=n(t,e,r);if(f>0)return o>0&&n(t,e,a)>0?1:-1;if(f<0)return o>0||n(t,e,a)>0?1:-1;var p=n(t,e,a);return p>0?1:l(t,e,r)?1:-1};var n=t(\"robust-orientation\"),i=t(\"signum\"),a=t(\"two-sum\"),o=t(\"robust-product\"),s=t(\"robust-sum\");function l(t,e,r){var n=a(t[0],-e[0]),i=a(t[1],-e[1]),l=a(r[0],-e[0]),c=a(r[1],-e[1]),u=s(o(n,l),o(i,c));return u[u.length-1]>=0}},{\"robust-orientation\":510,\"robust-product\":511,\"robust-sum\":515,signum:516,\"two-sum\":544}],128:[function(t,e,r){e.exports=function(t,e){var r=t.length,a=t.length-e.length;if(a)return a;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return t[0]+t[1]-e[0]-e[1]||n(t[0],t[1])-n(e[0],e[1]);case 3:var o=t[0]+t[1],s=e[0]+e[1];if(a=o+t[2]-(s+e[2]))return a;var l=n(t[0],t[1]),c=n(e[0],e[1]);return n(l,t[2])-n(c,e[2])||n(l+t[2],o)-n(c+e[2],s);case 4:var u=t[0],h=t[1],f=t[2],p=t[3],d=e[0],g=e[1],v=e[2],m=e[3];return u+h+f+p-(d+g+v+m)||n(u,h,f,p)-n(d,g,v,m,d)||n(u+h,u+f,u+p,h+f,h+p,f+p)-n(d+g,d+v,d+m,g+v,g+m,v+m)||n(u+h+f,u+h+p,u+f+p,h+f+p)-n(d+g+v,d+g+m,d+v+m,g+v+m);default:for(var y=t.slice().sort(i),x=e.slice().sort(i),b=0;b<r;++b)if(a=y[b]-x[b])return a;return 0}};var n=Math.min;function i(t,e){return t-e}},{}],129:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"cell-orientation\");e.exports=function(t,e){return n(t,e)||i(t)-i(e)}},{\"cell-orientation\":112,\"compare-cell\":128}],130:[function(t,e,r){\"use strict\";var n=t(\"./lib/ch1d\"),i=t(\"./lib/ch2d\"),a=t(\"./lib/chnd\");e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[[0]];var r=t[0].length;if(0===r)return[];if(1===r)return n(t);if(2===r)return i(t);return a(t,r)}},{\"./lib/ch1d\":131,\"./lib/ch2d\":132,\"./lib/chnd\":133}],131:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0,r=0,n=1;n<t.length;++n)t[n][0]<t[e][0]&&(e=n),t[n][0]>t[r][0]&&(r=n);return e<r?[[e],[r]]:e>r?[[r],[e]]:[[e]]}},{}],132:[function(t,e,r){\"use strict\";e.exports=function(t){var e=n(t),r=e.length;if(r<=2)return[];for(var i=new Array(r),a=e[r-1],o=0;o<r;++o){var s=e[o];i[o]=[a,s],a=s}return i};var n=t(\"monotone-convex-hull-2d\")},{\"monotone-convex-hull-2d\":434}],133:[function(t,e,r){\"use strict\";e.exports=function(t,e){try{return n(t,!0)}catch(s){var r=i(t);if(r.length<=e)return[];var a=function(t,e){for(var r=t.length,n=new Array(r),i=0;i<e.length;++i)n[i]=t[e[i]];for(var a=e.length,i=0;i<r;++i)e.indexOf(i)<0&&(n[a++]=t[i]);return n}(t,r),o=n(a,!0);return function(t,e){for(var r=t.length,n=e.length,i=0;i<r;++i)for(var a=t[i],o=0;o<a.length;++o){var s=a[o];if(s<n)a[o]=e[s];else{s-=n;for(var l=0;l<n;++l)s>=e[l]&&(s+=1);a[o]=s}}return t}(o,r)}};var n=t(\"incremental-convex-hull\"),i=t(\"affine-hull\")},{\"affine-hull\":62,\"incremental-convex-hull\":413}],134:[function(t,e,r){e.exports={AFG:\"afghan\",ALA:\"\\\\b\\\\wland\",ALB:\"albania\",DZA:\"algeria\",ASM:\"^(?=.*americ).*samoa\",AND:\"andorra\",AGO:\"angola\",AIA:\"anguill?a\",ATA:\"antarctica\",ATG:\"antigua\",ARG:\"argentin\",ARM:\"armenia\",ABW:\"^(?!.*bonaire).*\\\\baruba\",AUS:\"australia\",AUT:\"^(?!.*hungary).*austria|\\\\baustri.*\\\\bemp\",AZE:\"azerbaijan\",BHS:\"bahamas\",BHR:\"bahrain\",BGD:\"bangladesh|^(?=.*east).*paki?stan\",BRB:\"barbados\",BLR:\"belarus|byelo\",BEL:\"^(?!.*luxem).*belgium\",BLZ:\"belize|^(?=.*british).*honduras\",BEN:\"benin|dahome\",BMU:\"bermuda\",BTN:\"bhutan\",BOL:\"bolivia\",BES:\"^(?=.*bonaire).*eustatius|^(?=.*carib).*netherlands|\\\\bbes.?islands\",BIH:\"herzegovina|bosnia\",BWA:\"botswana|bechuana\",BVT:\"bouvet\",BRA:\"brazil\",IOT:\"british.?indian.?ocean\",BRN:\"brunei\",BGR:\"bulgaria\",BFA:\"burkina|\\\\bfaso|upper.?volta\",BDI:\"burundi\",CPV:\"verde\",KHM:\"cambodia|kampuchea|khmer\",CMR:\"cameroon\",CAN:\"canada\",CYM:\"cayman\",CAF:\"\\\\bcentral.african.republic\",TCD:\"\\\\bchad\",CHL:\"\\\\bchile\",CHN:\"^(?!.*\\\\bmac)(?!.*\\\\bhong)(?!.*\\\\btai)(?!.*\\\\brep).*china|^(?=.*peo)(?=.*rep).*china\",CXR:\"christmas\",CCK:\"\\\\bcocos|keeling\",COL:\"colombia\",COM:\"comoro\",COG:\"^(?!.*\\\\bdem)(?!.*\\\\bd[\\\\.]?r)(?!.*kinshasa)(?!.*zaire)(?!.*belg)(?!.*l.opoldville)(?!.*free).*\\\\bcongo\",COK:\"\\\\bcook\",CRI:\"costa.?rica\",CIV:\"ivoire|ivory\",HRV:\"croatia\",CUB:\"\\\\bcuba\",CUW:\"^(?!.*bonaire).*\\\\bcura(c|\\xe7)ao\",CYP:\"cyprus\",CSK:\"czechoslovakia\",CZE:\"^(?=.*rep).*czech|czechia|bohemia\",COD:\"\\\\bdem.*congo|congo.*\\\\bdem|congo.*\\\\bd[\\\\.]?r|\\\\bd[\\\\.]?r.*congo|belgian.?congo|congo.?free.?state|kinshasa|zaire|l.opoldville|drc|droc|rdc\",DNK:\"denmark\",DJI:\"djibouti\",DMA:\"dominica(?!n)\",DOM:\"dominican.rep\",ECU:\"ecuador\",EGY:\"egypt\",SLV:\"el.?salvador\",GNQ:\"guine.*eq|eq.*guine|^(?=.*span).*guinea\",ERI:\"eritrea\",EST:\"estonia\",ETH:\"ethiopia|abyssinia\",FLK:\"falkland|malvinas\",FRO:\"faroe|faeroe\",FJI:\"fiji\",FIN:\"finland\",FRA:\"^(?!.*\\\\bdep)(?!.*martinique).*france|french.?republic|\\\\bgaul\",GUF:\"^(?=.*french).*guiana\",PYF:\"french.?polynesia|tahiti\",ATF:\"french.?southern\",GAB:\"gabon\",GMB:\"gambia\",GEO:\"^(?!.*south).*georgia\",DDR:\"german.?democratic.?republic|democratic.?republic.*germany|east.germany\",DEU:\"^(?!.*east).*germany|^(?=.*\\\\bfed.*\\\\brep).*german\",GHA:\"ghana|gold.?coast\",GIB:\"gibraltar\",GRC:\"greece|hellenic|hellas\",GRL:\"greenland\",GRD:\"grenada\",GLP:\"guadeloupe\",GUM:\"\\\\bguam\",GTM:\"guatemala\",GGY:\"guernsey\",GIN:\"^(?!.*eq)(?!.*span)(?!.*bissau)(?!.*portu)(?!.*new).*guinea\",GNB:\"bissau|^(?=.*portu).*guinea\",GUY:\"guyana|british.?guiana\",HTI:\"haiti\",HMD:\"heard.*mcdonald\",VAT:\"holy.?see|vatican|papal.?st\",HND:\"^(?!.*brit).*honduras\",HKG:\"hong.?kong\",HUN:\"^(?!.*austr).*hungary\",ISL:\"iceland\",IND:\"india(?!.*ocea)\",IDN:\"indonesia\",IRN:\"\\\\biran|persia\",IRQ:\"\\\\biraq|mesopotamia\",IRL:\"(^ireland)|(^republic.*ireland)\",IMN:\"^(?=.*isle).*\\\\bman\",ISR:\"israel\",ITA:\"italy\",JAM:\"jamaica\",JPN:\"japan\",JEY:\"jersey\",JOR:\"jordan\",KAZ:\"kazak\",KEN:\"kenya|british.?east.?africa|east.?africa.?prot\",KIR:\"kiribati\",PRK:\"^(?=.*democrat|people|north|d.*p.*.r).*\\\\bkorea|dprk|korea.*(d.*p.*r)\",KWT:\"kuwait\",KGZ:\"kyrgyz|kirghiz\",LAO:\"\\\\blaos?\\\\b\",LVA:\"latvia\",LBN:\"lebanon\",LSO:\"lesotho|basuto\",LBR:\"liberia\",LBY:\"libya\",LIE:\"liechtenstein\",LTU:\"lithuania\",LUX:\"^(?!.*belg).*luxem\",MAC:\"maca(o|u)\",MDG:\"madagascar|malagasy\",MWI:\"malawi|nyasa\",MYS:\"malaysia\",MDV:\"maldive\",MLI:\"\\\\bmali\\\\b\",MLT:\"\\\\bmalta\",MHL:\"marshall\",MTQ:\"martinique\",MRT:\"mauritania\",MUS:\"mauritius\",MYT:\"\\\\bmayotte\",MEX:\"\\\\bmexic\",FSM:\"fed.*micronesia|micronesia.*fed\",MCO:\"monaco\",MNG:\"mongolia\",MNE:\"^(?!.*serbia).*montenegro\",MSR:\"montserrat\",MAR:\"morocco|\\\\bmaroc\",MOZ:\"mozambique\",MMR:\"myanmar|burma\",NAM:\"namibia\",NRU:\"nauru\",NPL:\"nepal\",NLD:\"^(?!.*\\\\bant)(?!.*\\\\bcarib).*netherlands\",ANT:\"^(?=.*\\\\bant).*(nether|dutch)\",NCL:\"new.?caledonia\",NZL:\"new.?zealand\",NIC:\"nicaragua\",NER:\"\\\\bniger(?!ia)\",NGA:\"nigeria\",NIU:\"niue\",NFK:\"norfolk\",MNP:\"mariana\",NOR:\"norway\",OMN:\"\\\\boman|trucial\",PAK:\"^(?!.*east).*paki?stan\",PLW:\"palau\",PSE:\"palestin|\\\\bgaza|west.?bank\",PAN:\"panama\",PNG:\"papua|new.?guinea\",PRY:\"paraguay\",PER:\"peru\",PHL:\"philippines\",PCN:\"pitcairn\",POL:\"poland\",PRT:\"portugal\",PRI:\"puerto.?rico\",QAT:\"qatar\",KOR:\"^(?!.*d.*p.*r)(?!.*democrat)(?!.*people)(?!.*north).*\\\\bkorea(?!.*d.*p.*r)\",MDA:\"moldov|b(a|e)ssarabia\",REU:\"r(e|\\xe9)union\",ROU:\"r(o|u|ou)mania\",RUS:\"\\\\brussia|soviet.?union|u\\\\.?s\\\\.?s\\\\.?r|socialist.?republics\",RWA:\"rwanda\",BLM:\"barth(e|\\xe9)lemy\",SHN:\"helena\",KNA:\"kitts|\\\\bnevis\",LCA:\"\\\\blucia\",MAF:\"^(?=.*collectivity).*martin|^(?=.*france).*martin(?!ique)|^(?=.*french).*martin(?!ique)\",SPM:\"miquelon\",VCT:\"vincent\",WSM:\"^(?!.*amer).*samoa\",SMR:\"san.?marino\",STP:\"\\\\bs(a|\\xe3)o.?tom(e|\\xe9)\",SAU:\"\\\\bsa\\\\w*.?arabia\",SEN:\"senegal\",SRB:\"^(?!.*monte).*serbia\",SYC:\"seychell\",SLE:\"sierra\",SGP:\"singapore\",SXM:\"^(?!.*martin)(?!.*saba).*maarten\",SVK:\"^(?!.*cze).*slovak\",SVN:\"slovenia\",SLB:\"solomon\",SOM:\"somali\",ZAF:\"south.africa|s\\\\\\\\..?africa\",SGS:\"south.?georgia|sandwich\",SSD:\"\\\\bs\\\\w*.?sudan\",ESP:\"spain\",LKA:\"sri.?lanka|ceylon\",SDN:\"^(?!.*\\\\bs(?!u)).*sudan\",SUR:\"surinam|dutch.?guiana\",SJM:\"svalbard\",SWZ:\"swaziland\",SWE:\"sweden\",CHE:\"switz|swiss\",SYR:\"syria\",TWN:\"taiwan|taipei|formosa|^(?!.*peo)(?=.*rep).*china\",TJK:\"tajik\",THA:\"thailand|\\\\bsiam\",MKD:\"macedonia|fyrom\",TLS:\"^(?=.*leste).*timor|^(?=.*east).*timor\",TGO:\"togo\",TKL:\"tokelau\",TON:\"tonga\",TTO:\"trinidad|tobago\",TUN:\"tunisia\",TUR:\"turkey\",TKM:\"turkmen\",TCA:\"turks\",TUV:\"tuvalu\",UGA:\"uganda\",UKR:\"ukrain\",ARE:\"emirates|^u\\\\.?a\\\\.?e\\\\.?$|united.?arab.?em\",GBR:\"united.?kingdom|britain|^u\\\\.?k\\\\.?$\",TZA:\"tanzania\",USA:\"united.?states\\\\b(?!.*islands)|\\\\bu\\\\.?s\\\\.?a\\\\.?\\\\b|^\\\\s*u\\\\.?s\\\\.?\\\\b(?!.*islands)\",UMI:\"minor.?outlying.?is\",URY:\"uruguay\",UZB:\"uzbek\",VUT:\"vanuatu|new.?hebrides\",VEN:\"venezuela\",VNM:\"^(?!.*republic).*viet.?nam|^(?=.*socialist).*viet.?nam\",VGB:\"^(?=.*\\\\bu\\\\.?\\\\s?k).*virgin|^(?=.*brit).*virgin|^(?=.*kingdom).*virgin\",VIR:\"^(?=.*\\\\bu\\\\.?\\\\s?s).*virgin|^(?=.*states).*virgin\",WLF:\"futuna|wallis\",ESH:\"western.sahara\",YEM:\"^(?!.*arab)(?!.*north)(?!.*sana)(?!.*peo)(?!.*dem)(?!.*south)(?!.*aden)(?!.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YMD:\"^(?=.*peo).*yemen|^(?!.*rep)(?=.*dem).*yemen|^(?=.*south).*yemen|^(?=.*aden).*yemen|^(?=.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YUG:\"yugoslavia\",ZMB:\"zambia|northern.?rhodesia\",EAZ:\"zanzibar\",ZWE:\"zimbabwe|^(?!.*northern).*rhodesia\"}},{}],135:[function(t,e,r){e.exports=[\"xx-small\",\"x-small\",\"small\",\"medium\",\"large\",\"x-large\",\"xx-large\",\"larger\",\"smaller\"]},{}],136:[function(t,e,r){e.exports=[\"normal\",\"condensed\",\"semi-condensed\",\"extra-condensed\",\"ultra-condensed\",\"expanded\",\"semi-expanded\",\"extra-expanded\",\"ultra-expanded\"]},{}],137:[function(t,e,r){e.exports=[\"normal\",\"italic\",\"oblique\"]},{}],138:[function(t,e,r){e.exports=[\"normal\",\"bold\",\"bolder\",\"lighter\",\"100\",\"200\",\"300\",\"400\",\"500\",\"600\",\"700\",\"800\",\"900\"]},{}],139:[function(t,e,r){\"use strict\";e.exports={parse:t(\"./parse\"),stringify:t(\"./stringify\")}},{\"./parse\":141,\"./stringify\":142}],140:[function(t,e,r){\"use strict\";var n=t(\"css-font-size-keywords\");e.exports={isSize:function(t){return/^[\\d\\.]/.test(t)||-1!==t.indexOf(\"/\")||-1!==n.indexOf(t)}}},{\"css-font-size-keywords\":135}],141:[function(t,e,r){\"use strict\";var n=t(\"unquote\"),i=t(\"css-global-keywords\"),a=t(\"css-system-font-keywords\"),o=t(\"css-font-weight-keywords\"),s=t(\"css-font-style-keywords\"),l=t(\"css-font-stretch-keywords\"),c=t(\"string-split-by\"),u=t(\"./lib/util\").isSize;e.exports=f;var h=f.cache={};function f(t){if(\"string\"!=typeof t)throw new Error(\"Font argument must be a string.\");if(h[t])return h[t];if(\"\"===t)throw new Error(\"Cannot parse an empty string.\");if(-1!==a.indexOf(t))return h[t]={system:t};for(var e,r={style:\"normal\",variant:\"normal\",weight:\"normal\",stretch:\"normal\",lineHeight:\"normal\",size:\"1rem\",family:[\"serif\"]},f=c(t,/\\s+/);e=f.shift();){if(-1!==i.indexOf(e))return[\"style\",\"variant\",\"weight\",\"stretch\"].forEach(function(t){r[t]=e}),h[t]=r;if(-1===s.indexOf(e))if(\"normal\"!==e&&\"small-caps\"!==e)if(-1===l.indexOf(e)){if(-1===o.indexOf(e)){if(u(e)){var d=c(e,\"/\");if(r.size=d[0],null!=d[1]?r.lineHeight=p(d[1]):\"/\"===f[0]&&(f.shift(),r.lineHeight=p(f.shift())),!f.length)throw new Error(\"Missing required font-family.\");return r.family=c(f.join(\" \"),/\\s*,\\s*/).map(n),h[t]=r}throw new Error(\"Unknown or unsupported font token: \"+e)}r.weight=e}else r.stretch=e;else r.variant=e;else r.style=e}throw new Error(\"Missing required font-size.\")}function p(t){var e=parseFloat(t);return e.toString()===t?e:t}},{\"./lib/util\":140,\"css-font-stretch-keywords\":136,\"css-font-style-keywords\":137,\"css-font-weight-keywords\":138,\"css-global-keywords\":143,\"css-system-font-keywords\":144,\"string-split-by\":529,unquote:548}],142:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\"),i=t(\"./lib/util\").isSize,a=g(t(\"css-global-keywords\")),o=g(t(\"css-system-font-keywords\")),s=g(t(\"css-font-weight-keywords\")),l=g(t(\"css-font-style-keywords\")),c=g(t(\"css-font-stretch-keywords\")),u={normal:1,\"small-caps\":1},h={serif:1,\"sans-serif\":1,monospace:1,cursive:1,fantasy:1,\"system-ui\":1},f=\"1rem\",p=\"serif\";function d(t,e){if(t&&!e[t]&&!a[t])throw Error(\"Unknown keyword `\"+t+\"`\");return t}function g(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=1;return e}e.exports=function(t){if((t=n(t,{style:\"style fontstyle fontStyle font-style slope distinction\",variant:\"variant font-variant fontVariant fontvariant var capitalization\",weight:\"weight w font-weight fontWeight fontweight\",stretch:\"stretch font-stretch fontStretch fontstretch width\",size:\"size s font-size fontSize fontsize height em emSize\",lineHeight:\"lh line-height lineHeight lineheight leading\",family:\"font family fontFamily font-family fontfamily type typeface face\",system:\"system reserved default global\"})).system)return t.system&&d(t.system,o),t.system;if(d(t.style,l),d(t.variant,u),d(t.weight,s),d(t.stretch,c),null==t.size&&(t.size=f),\"number\"==typeof t.size&&(t.size+=\"px\"),!i)throw Error(\"Bad size value `\"+t.size+\"`\");t.family||(t.family=p),Array.isArray(t.family)&&(t.family.length||(t.family=[p]),t.family=t.family.map(function(t){return h[t]?t:'\"'+t+'\"'}).join(\", \"));var e=[];return e.push(t.style),t.variant!==t.style&&e.push(t.variant),t.weight!==t.variant&&t.weight!==t.style&&e.push(t.weight),t.stretch!==t.weight&&t.stretch!==t.variant&&t.stretch!==t.style&&e.push(t.stretch),e.push(t.size+(null==t.lineHeight||\"normal\"===t.lineHeight||t.lineHeight+\"\"==\"1\"?\"\":\"/\"+t.lineHeight)),e.push(t.family),e.filter(Boolean).join(\" \")}},{\"./lib/util\":140,\"css-font-stretch-keywords\":136,\"css-font-style-keywords\":137,\"css-font-weight-keywords\":138,\"css-global-keywords\":143,\"css-system-font-keywords\":144,\"pick-by-alias\":465}],143:[function(t,e,r){e.exports=[\"inherit\",\"initial\",\"unset\"]},{}],144:[function(t,e,r){e.exports=[\"caption\",\"icon\",\"menu\",\"message-box\",\"small-caption\",\"status-bar\"]},{}],145:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i-1,s=i*i,l=o*o,c=(1+2*i)*l,u=i*l,h=s*(3-2*i),f=s*o;if(t.length){a||(a=new Array(t.length));for(var p=t.length-1;p>=0;--p)a[p]=c*t[p]+u*e[p]+h*r[p]+f*n[p];return a}return c*t+u*e+h*r+f*n},e.exports.derivative=function(t,e,r,n,i,a){var o=6*i*i-6*i,s=3*i*i-4*i+1,l=-6*i*i+6*i,c=3*i*i-2*i;if(t.length){a||(a=new Array(t.length));for(var u=t.length-1;u>=0;--u)a[u]=o*t[u]+s*e[u]+l*r[u]+c*n[u];return a}return o*t+s*e+l*r[u]+c*n}},{}],146:[function(t,e,r){\"use strict\";var n=t(\"./lib/thunk.js\");function i(){this.argTypes=[],this.shimArgs=[],this.arrayArgs=[],this.arrayBlockIndices=[],this.scalarArgs=[],this.offsetArgs=[],this.offsetArgIndex=[],this.indexArgs=[],this.shapeArgs=[],this.funcName=\"\",this.pre=null,this.body=null,this.post=null,this.debug=!1}e.exports=function(t){var e=new i;e.pre=t.pre,e.body=t.body,e.post=t.post;var r=t.args.slice(0);e.argTypes=r;for(var a=0;a<r.length;++a){var o=r[a];if(\"array\"===o||\"object\"==typeof o&&o.blockIndices){if(e.argTypes[a]=\"array\",e.arrayArgs.push(a),e.arrayBlockIndices.push(o.blockIndices?o.blockIndices:0),e.shimArgs.push(\"array\"+a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array args\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array args\")}else if(\"scalar\"===o)e.scalarArgs.push(a),e.shimArgs.push(\"scalar\"+a);else if(\"index\"===o){if(e.indexArgs.push(a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array index\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array index\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array index\")}else if(\"shape\"===o){if(e.shapeArgs.push(a),a<e.pre.args.length&&e.pre.args[a].lvalue)throw new Error(\"cwise: pre() block may not write to array shape\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array shape\");if(a<e.post.args.length&&e.post.args[a].lvalue)throw new Error(\"cwise: post() block may not write to array shape\")}else{if(\"object\"!=typeof o||!o.offset)throw new Error(\"cwise: Unknown argument type \"+r[a]);e.argTypes[a]=\"offset\",e.offsetArgs.push({array:o.array,offset:o.offset}),e.offsetArgIndex.push(a)}}if(e.arrayArgs.length<=0)throw new Error(\"cwise: No array arguments specified\");if(e.pre.args.length>r.length)throw new Error(\"cwise: Too many arguments in pre() block\");if(e.body.args.length>r.length)throw new Error(\"cwise: Too many arguments in body() block\");if(e.post.args.length>r.length)throw new Error(\"cwise: Too many arguments in post() block\");return e.debug=!!t.printCode||!!t.debug,e.funcName=t.funcName||\"cwise\",e.blockSize=t.blockSize||64,n(e)}},{\"./lib/thunk.js\":148}],147:[function(t,e,r){\"use strict\";var n=t(\"uniq\");function i(t,e,r){var n,i,a=t.length,o=e.arrayArgs.length,s=e.indexArgs.length>0,l=[],c=[],u=0,h=0;for(n=0;n<a;++n)c.push([\"i\",n,\"=0\"].join(\"\"));for(i=0;i<o;++i)for(n=0;n<a;++n)h=u,u=t[n],0===n?c.push([\"d\",i,\"s\",n,\"=t\",i,\"p\",u].join(\"\")):c.push([\"d\",i,\"s\",n,\"=(t\",i,\"p\",u,\"-s\",h,\"*t\",i,\"p\",h,\")\"].join(\"\"));for(c.length>0&&l.push(\"var \"+c.join(\",\")),n=a-1;n>=0;--n)u=t[n],l.push([\"for(i\",n,\"=0;i\",n,\"<s\",u,\";++i\",n,\"){\"].join(\"\"));for(l.push(r),n=0;n<a;++n){for(h=u,u=t[n],i=0;i<o;++i)l.push([\"p\",i,\"+=d\",i,\"s\",n].join(\"\"));s&&(n>0&&l.push([\"index[\",h,\"]-=s\",h].join(\"\")),l.push([\"++index[\",u,\"]\"].join(\"\"))),l.push(\"}\")}return l.join(\"\\n\")}function a(t,e,r){for(var n=t.body,i=[],a=[],o=0;o<t.args.length;++o){var s=t.args[o];if(!(s.count<=0)){var l=new RegExp(s.name,\"g\"),c=\"\",u=e.arrayArgs.indexOf(o);switch(e.argTypes[o]){case\"offset\":var h=e.offsetArgIndex.indexOf(o);u=e.offsetArgs[h].array,c=\"+q\"+h;case\"array\":c=\"p\"+u+c;var f=\"l\"+o,p=\"a\"+u;if(0===e.arrayBlockIndices[u])1===s.count?\"generic\"===r[u]?s.lvalue?(i.push([\"var \",f,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,f),a.push([p,\".set(\",c,\",\",f,\")\"].join(\"\"))):n=n.replace(l,[p,\".get(\",c,\")\"].join(\"\")):n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\")):\"generic\"===r[u]?(i.push([\"var \",f,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,f),s.lvalue&&a.push([p,\".set(\",c,\",\",f,\")\"].join(\"\"))):(i.push([\"var \",f,\"=\",p,\"[\",c,\"]\"].join(\"\")),n=n.replace(l,f),s.lvalue&&a.push([p,\"[\",c,\"]=\",f].join(\"\")));else{for(var d=[s.name],g=[c],v=0;v<Math.abs(e.arrayBlockIndices[u]);v++)d.push(\"\\\\s*\\\\[([^\\\\]]+)\\\\]\"),g.push(\"$\"+(v+1)+\"*t\"+u+\"b\"+v);if(l=new RegExp(d.join(\"\"),\"g\"),c=g.join(\"+\"),\"generic\"===r[u])throw new Error(\"cwise: Generic arrays not supported in combination with blocks!\");n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\"))}break;case\"scalar\":n=n.replace(l,\"Y\"+e.scalarArgs.indexOf(o));break;case\"index\":n=n.replace(l,\"index\");break;case\"shape\":n=n.replace(l,\"shape\")}}}return[i.join(\"\\n\"),n,a.join(\"\\n\")].join(\"\\n\").trim()}e.exports=function(t,e){for(var r=e[1].length-Math.abs(t.arrayBlockIndices[0])|0,o=new Array(t.arrayArgs.length),s=new Array(t.arrayArgs.length),l=0;l<t.arrayArgs.length;++l)s[l]=e[2*l],o[l]=e[2*l+1];var c=[],u=[],h=[],f=[],p=[];for(l=0;l<t.arrayArgs.length;++l){t.arrayBlockIndices[l]<0?(h.push(0),f.push(r),c.push(r),u.push(r+t.arrayBlockIndices[l])):(h.push(t.arrayBlockIndices[l]),f.push(t.arrayBlockIndices[l]+r),c.push(0),u.push(t.arrayBlockIndices[l]));for(var d=[],g=0;g<o[l].length;g++)h[l]<=o[l][g]&&o[l][g]<f[l]&&d.push(o[l][g]-h[l]);p.push(d)}var v=[\"SS\"],m=[\"'use strict'\"],y=[];for(g=0;g<r;++g)y.push([\"s\",g,\"=SS[\",g,\"]\"].join(\"\"));for(l=0;l<t.arrayArgs.length;++l){for(v.push(\"a\"+l),v.push(\"t\"+l),v.push(\"p\"+l),g=0;g<r;++g)y.push([\"t\",l,\"p\",g,\"=t\",l,\"[\",h[l]+g,\"]\"].join(\"\"));for(g=0;g<Math.abs(t.arrayBlockIndices[l]);++g)y.push([\"t\",l,\"b\",g,\"=t\",l,\"[\",c[l]+g,\"]\"].join(\"\"))}for(l=0;l<t.scalarArgs.length;++l)v.push(\"Y\"+l);if(t.shapeArgs.length>0&&y.push(\"shape=SS.slice(0)\"),t.indexArgs.length>0){var x=new Array(r);for(l=0;l<r;++l)x[l]=\"0\";y.push([\"index=[\",x.join(\",\"),\"]\"].join(\"\"))}for(l=0;l<t.offsetArgs.length;++l){var b=t.offsetArgs[l],_=[];for(g=0;g<b.offset.length;++g)0!==b.offset[g]&&(1===b.offset[g]?_.push([\"t\",b.array,\"p\",g].join(\"\")):_.push([b.offset[g],\"*t\",b.array,\"p\",g].join(\"\")));0===_.length?y.push(\"q\"+l+\"=0\"):y.push([\"q\",l,\"=\",_.join(\"+\")].join(\"\"))}var w=n([].concat(t.pre.thisVars).concat(t.body.thisVars).concat(t.post.thisVars));for((y=y.concat(w)).length>0&&m.push(\"var \"+y.join(\",\")),l=0;l<t.arrayArgs.length;++l)m.push(\"p\"+l+\"|=0\");t.pre.body.length>3&&m.push(a(t.pre,t,s));var k=a(t.body,t,s),T=function(t){for(var e=0,r=t[0].length;e<r;){for(var n=1;n<t.length;++n)if(t[n][e]!==t[0][e])return e;++e}return e}(p);T<r?m.push(function(t,e,r,n){for(var a=e.length,o=r.arrayArgs.length,s=r.blockSize,l=r.indexArgs.length>0,c=[],u=0;u<o;++u)c.push([\"var offset\",u,\"=p\",u].join(\"\"));for(u=t;u<a;++u)c.push([\"for(var j\"+u+\"=SS[\",e[u],\"]|0;j\",u,\">0;){\"].join(\"\")),c.push([\"if(j\",u,\"<\",s,\"){\"].join(\"\")),c.push([\"s\",e[u],\"=j\",u].join(\"\")),c.push([\"j\",u,\"=0\"].join(\"\")),c.push([\"}else{s\",e[u],\"=\",s].join(\"\")),c.push([\"j\",u,\"-=\",s,\"}\"].join(\"\")),l&&c.push([\"index[\",e[u],\"]=j\",u].join(\"\"));for(u=0;u<o;++u){for(var h=[\"offset\"+u],f=t;f<a;++f)h.push([\"j\",f,\"*t\",u,\"p\",e[f]].join(\"\"));c.push([\"p\",u,\"=(\",h.join(\"+\"),\")\"].join(\"\"))}for(c.push(i(e,r,n)),u=t;u<a;++u)c.push(\"}\");return c.join(\"\\n\")}(T,p[0],t,k)):m.push(i(p[0],t,k)),t.post.body.length>3&&m.push(a(t.post,t,s)),t.debug&&console.log(\"-----Generated cwise routine for \",e,\":\\n\"+m.join(\"\\n\")+\"\\n----------\");var A=[t.funcName||\"unnamed\",\"_cwise_loop_\",o[0].join(\"s\"),\"m\",T,function(t){for(var e=new Array(t.length),r=!0,n=0;n<t.length;++n){var i=t[n],a=i.match(/\\d+/);a=a?a[0]:\"\",0===i.charAt(0)?e[n]=\"u\"+i.charAt(1)+a:e[n]=i.charAt(0)+a,n>0&&(r=r&&e[n]===e[n-1])}return r?e[0]:e.join(\"\")}(s)].join(\"\");return new Function([\"function \",A,\"(\",v.join(\",\"),\"){\",m.join(\"\\n\"),\"} return \",A].join(\"\"))()}},{uniq:547}],148:[function(t,e,r){\"use strict\";var n=t(\"./compile.js\");e.exports=function(t){var e=[\"'use strict'\",\"var CACHED={}\"],r=[],i=t.funcName+\"_cwise_thunk\";e.push([\"return function \",i,\"(\",t.shimArgs.join(\",\"),\"){\"].join(\"\"));for(var a=[],o=[],s=[[\"array\",t.arrayArgs[0],\".shape.slice(\",Math.max(0,t.arrayBlockIndices[0]),t.arrayBlockIndices[0]<0?\",\"+t.arrayBlockIndices[0]+\")\":\")\"].join(\"\")],l=[],c=[],u=0;u<t.arrayArgs.length;++u){var h=t.arrayArgs[u];r.push([\"t\",h,\"=array\",h,\".dtype,\",\"r\",h,\"=array\",h,\".order\"].join(\"\")),a.push(\"t\"+h),a.push(\"r\"+h),o.push(\"t\"+h),o.push(\"r\"+h+\".join()\"),s.push(\"array\"+h+\".data\"),s.push(\"array\"+h+\".stride\"),s.push(\"array\"+h+\".offset|0\"),u>0&&(l.push(\"array\"+t.arrayArgs[0]+\".shape.length===array\"+h+\".shape.length+\"+(Math.abs(t.arrayBlockIndices[0])-Math.abs(t.arrayBlockIndices[u]))),c.push(\"array\"+t.arrayArgs[0]+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[0])+\"]===array\"+h+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[u])+\"]\"))}for(t.arrayArgs.length>1&&(e.push(\"if (!(\"+l.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same dimensionality!')\"),e.push(\"for(var shapeIndex=array\"+t.arrayArgs[0]+\".shape.length-\"+Math.abs(t.arrayBlockIndices[0])+\"; shapeIndex--\\x3e0;) {\"),e.push(\"if (!(\"+c.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same shape!')\"),e.push(\"}\")),u=0;u<t.scalarArgs.length;++u)s.push(\"scalar\"+t.scalarArgs[u]);return r.push([\"type=[\",o.join(\",\"),\"].join()\"].join(\"\")),r.push(\"proc=CACHED[type]\"),e.push(\"var \"+r.join(\",\")),e.push([\"if(!proc){\",\"CACHED[type]=proc=compile([\",a.join(\",\"),\"])}\",\"return proc(\",s.join(\",\"),\")}\"].join(\"\")),t.debug&&console.log(\"-----Generated thunk:\\n\"+e.join(\"\\n\")+\"\\n----------\"),new Function(\"compile\",e.join(\"\\n\"))(n.bind(void 0,t))}},{\"./compile.js\":147}],149:[function(t,e,r){e.exports=t(\"cwise-compiler\")},{\"cwise-compiler\":146}],150:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/copy\"),a=t(\"es5-ext/object/normalize-options\"),o=t(\"es5-ext/object/valid-callable\"),s=t(\"es5-ext/object/map\"),l=t(\"es5-ext/object/valid-callable\"),c=t(\"es5-ext/object/valid-value\"),u=Function.prototype.bind,h=Object.defineProperty,f=Object.prototype.hasOwnProperty;n=function(t,e,r){var n,a=c(e)&&l(e.value);return delete(n=i(e)).writable,delete n.value,n.get=function(){return!r.overwriteDefinition&&f.call(this,t)?a:(e.value=u.call(a,r.resolveContext?r.resolveContext(this):this),h(this,t,e),this[t])},n},e.exports=function(t){var e=a(arguments[1]);return null!=e.resolveContext&&o(e.resolveContext),s(t,function(t,r){return n(r,t,e)})}},{\"es5-ext/object/copy\":189,\"es5-ext/object/map\":198,\"es5-ext/object/normalize-options\":199,\"es5-ext/object/valid-callable\":203,\"es5-ext/object/valid-value\":205}],151:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/object/assign\"),i=t(\"es5-ext/object/normalize-options\"),a=t(\"es5-ext/object/is-callable\"),o=t(\"es5-ext/string/#/contains\");(e.exports=function(t,e){var r,a,s,l,c;return arguments.length<2||\"string\"!=typeof t?(l=e,e=t,t=null):l=arguments[2],null==t?(r=s=!0,a=!1):(r=o.call(t,\"c\"),a=o.call(t,\"e\"),s=o.call(t,\"w\")),c={value:e,configurable:r,enumerable:a,writable:s},l?n(i(l),c):c}).gs=function(t,e,r){var s,l,c,u;return\"string\"!=typeof t?(c=r,r=e,e=t,t=null):c=arguments[3],null==e?e=void 0:a(e)?null==r?r=void 0:a(r)||(c=r,r=void 0):(c=e,e=r=void 0),null==t?(s=!0,l=!1):(s=o.call(t,\"c\"),l=o.call(t,\"e\")),u={get:e,set:r,configurable:s,enumerable:l},c?n(i(c),u):u}},{\"es5-ext/object/assign\":186,\"es5-ext/object/is-callable\":192,\"es5-ext/object/normalize-options\":199,\"es5-ext/string/#/contains\":206}],152:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function r(t){var r;return 1===t.length&&(r=t,t=function(t,n){return e(r(t),n)}),{left:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}var n=r(e),i=n.right,a=n.left;function o(t,e){return[t,e]}function s(t){return null===t?NaN:+t}function l(t,e){var r,n,i=t.length,a=0,o=-1,l=0,c=0;if(null==e)for(;++o<i;)isNaN(r=s(t[o]))||(c+=(n=r-l)*(r-(l+=n/++a)));else for(;++o<i;)isNaN(r=s(e(t[o],o,t)))||(c+=(n=r-l)*(r-(l+=n/++a)));if(a>1)return c/(a-1)}function c(t,e){var r=l(t,e);return r?Math.sqrt(r):r}function u(t,e){var r,n,i,a=t.length,o=-1;if(null==e){for(;++o<a;)if(null!=(r=t[o])&&r>=r)for(n=i=r;++o<a;)null!=(r=t[o])&&(n>r&&(n=r),i<r&&(i=r))}else for(;++o<a;)if(null!=(r=e(t[o],o,t))&&r>=r)for(n=i=r;++o<a;)null!=(r=e(t[o],o,t))&&(n>r&&(n=r),i<r&&(i=r));return[n,i]}var h=Array.prototype,f=h.slice,p=h.map;function d(t){return function(){return t}}function g(t){return t}function v(t,e,r){t=+t,e=+e,r=(i=arguments.length)<2?(e=t,t=0,1):i<3?1:+r;for(var n=-1,i=0|Math.max(0,Math.ceil((e-t)/r)),a=new Array(i);++n<i;)a[n]=t+n*r;return a}var m=Math.sqrt(50),y=Math.sqrt(10),x=Math.sqrt(2);function b(t,e,r){var n=(e-t)/Math.max(0,r),i=Math.floor(Math.log(n)/Math.LN10),a=n/Math.pow(10,i);return i>=0?(a>=m?10:a>=y?5:a>=x?2:1)*Math.pow(10,i):-Math.pow(10,-i)/(a>=m?10:a>=y?5:a>=x?2:1)}function _(t,e,r){var n=Math.abs(e-t)/Math.max(0,r),i=Math.pow(10,Math.floor(Math.log(n)/Math.LN10)),a=n/i;return a>=m?i*=10:a>=y?i*=5:a>=x&&(i*=2),e<t?-i:i}function w(t){return Math.ceil(Math.log(t.length)/Math.LN2)+1}function k(t,e,r){if(null==r&&(r=s),n=t.length){if((e=+e)<=0||n<2)return+r(t[0],0,t);if(e>=1)return+r(t[n-1],n-1,t);var n,i=(n-1)*e,a=Math.floor(i),o=+r(t[a],a,t);return o+(+r(t[a+1],a+1,t)-o)*(i-a)}}function T(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&n>r&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&n>r&&(n=r);return n}function A(t){if(!(i=t.length))return[];for(var e=-1,r=T(t,M),n=new Array(r);++e<r;)for(var i,a=-1,o=n[e]=new Array(i);++a<i;)o[a]=t[a][e];return n}function M(t){return t.length}t.bisect=i,t.bisectRight=i,t.bisectLeft=a,t.ascending=e,t.bisector=r,t.cross=function(t,e,r){var n,i,a,s,l=t.length,c=e.length,u=new Array(l*c);for(null==r&&(r=o),n=a=0;n<l;++n)for(s=t[n],i=0;i<c;++i,++a)u[a]=r(s,e[i]);return u},t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.deviation=c,t.extent=u,t.histogram=function(){var t=g,e=u,r=w;function n(n){var a,o,s=n.length,l=new Array(s);for(a=0;a<s;++a)l[a]=t(n[a],a,n);var c=e(l),u=c[0],h=c[1],f=r(l,u,h);Array.isArray(f)||(f=_(u,h,f),f=v(Math.ceil(u/f)*f,h,f));for(var p=f.length;f[0]<=u;)f.shift(),--p;for(;f[p-1]>h;)f.pop(),--p;var d,g=new Array(p+1);for(a=0;a<=p;++a)(d=g[a]=[]).x0=a>0?f[a-1]:u,d.x1=a<p?f[a]:h;for(a=0;a<s;++a)u<=(o=l[a])&&o<=h&&g[i(f,o,0,p)].push(n[a]);return g}return n.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:d(e),n):t},n.domain=function(t){return arguments.length?(e=\"function\"==typeof t?t:d([t[0],t[1]]),n):e},n.thresholds=function(t){return arguments.length?(r=\"function\"==typeof t?t:Array.isArray(t)?d(f.call(t)):d(t),n):r},n},t.thresholdFreedmanDiaconis=function(t,r,n){return t=p.call(t,s).sort(e),Math.ceil((n-r)/(2*(k(t,.75)-k(t,.25))*Math.pow(t.length,-1/3)))},t.thresholdScott=function(t,e,r){return Math.ceil((r-e)/(3.5*c(t)*Math.pow(t.length,-1/3)))},t.thresholdSturges=w,t.max=function(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&r>n&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&r>n&&(n=r);return n},t.mean=function(t,e){var r,n=t.length,i=n,a=-1,o=0;if(null==e)for(;++a<n;)isNaN(r=s(t[a]))?--i:o+=r;else for(;++a<n;)isNaN(r=s(e(t[a],a,t)))?--i:o+=r;if(i)return o/i},t.median=function(t,r){var n,i=t.length,a=-1,o=[];if(null==r)for(;++a<i;)isNaN(n=s(t[a]))||o.push(n);else for(;++a<i;)isNaN(n=s(r(t[a],a,t)))||o.push(n);return k(o.sort(e),.5)},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r},t.min=T,t.pairs=function(t,e){null==e&&(e=o);for(var r=0,n=t.length-1,i=t[0],a=new Array(n<0?0:n);r<n;)a[r]=e(i,i=t[++r]);return a},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.quantile=k,t.range=v,t.scan=function(t,r){if(n=t.length){var n,i,a=0,o=0,s=t[o];for(null==r&&(r=e);++a<n;)(r(i=t[a],s)<0||0!==r(s,s))&&(s=i,o=a);return 0===r(s,s)?o:void 0}},t.shuffle=function(t,e,r){for(var n,i,a=(null==r?t.length:r)-(e=null==e?0:+e);a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.sum=function(t,e){var r,n=t.length,i=-1,a=0;if(null==e)for(;++i<n;)(r=+t[i])&&(a+=r);else for(;++i<n;)(r=+e(t[i],i,t))&&(a+=r);return a},t.ticks=function(t,e,r){var n,i,a,o,s=-1;if(r=+r,(t=+t)==(e=+e)&&r>0)return[t];if((n=e<t)&&(i=t,t=e,e=i),0===(o=b(t,e,r))||!isFinite(o))return[];if(o>0)for(t=Math.ceil(t/o),e=Math.floor(e/o),a=new Array(i=Math.ceil(e-t+1));++s<i;)a[s]=(t+s)*o;else for(t=Math.floor(t*o),e=Math.ceil(e*o),a=new Array(i=Math.ceil(t-e+1));++s<i;)a[s]=(t-s)/o;return n&&a.reverse(),a},t.tickIncrement=b,t.tickStep=_,t.transpose=A,t.variance=l,t.zip=function(){return A(arguments)},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],153:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(){}function r(t,r){var n=new e;if(t instanceof e)t.each(function(t,e){n.set(e,t)});else if(Array.isArray(t)){var i,a=-1,o=t.length;if(null==r)for(;++a<o;)n.set(a,t[a]);else for(;++a<o;)n.set(r(i=t[a],a,t),i)}else if(t)for(var s in t)n.set(s,t[s]);return n}e.prototype=r.prototype={constructor:e,has:function(t){return\"$\"+t in this},get:function(t){return this[\"$\"+t]},set:function(t,e){return this[\"$\"+t]=e,this},remove:function(t){var e=\"$\"+t;return e in this&&delete this[e]},clear:function(){for(var t in this)\"$\"===t[0]&&delete this[t]},keys:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(e.slice(1));return t},values:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(this[e]);return t},entries:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push({key:e.slice(1),value:this[e]});return t},size:function(){var t=0;for(var e in this)\"$\"===e[0]&&++t;return t},empty:function(){for(var t in this)if(\"$\"===t[0])return!1;return!0},each:function(t){for(var e in this)\"$\"===e[0]&&t(this[e],e.slice(1),this)}};function n(){return{}}function i(t,e,r){t[e]=r}function a(){return r()}function o(t,e,r){t.set(e,r)}function s(){}var l=r.prototype;function c(t,e){var r=new s;if(t instanceof s)t.each(function(t){r.add(t)});else if(t){var n=-1,i=t.length;if(null==e)for(;++n<i;)r.add(t[n]);else for(;++n<i;)r.add(e(t[n],n,t))}return r}s.prototype=c.prototype={constructor:s,has:l.has,add:function(t){return this[\"$\"+(t+=\"\")]=t,this},remove:l.remove,clear:l.clear,values:l.keys,size:l.size,empty:l.empty,each:l.each};t.nest=function(){var t,e,s,l=[],c=[];function u(n,i,a,o){if(i>=l.length)return null!=t&&n.sort(t),null!=e?e(n):n;for(var s,c,h,f=-1,p=n.length,d=l[i++],g=r(),v=a();++f<p;)(h=g.get(s=d(c=n[f])+\"\"))?h.push(c):g.set(s,[c]);return g.each(function(t,e){o(v,e,u(t,i,a,o))}),v}return s={object:function(t){return u(t,0,n,i)},map:function(t){return u(t,0,a,o)},entries:function(t){return function t(r,n){if(++n>l.length)return r;var i,a=c[n-1];return null!=e&&n>=l.length?i=r.entries():(i=[],r.each(function(e,r){i.push({key:r,values:t(e,n)})})),null!=a?i.sort(function(t,e){return a(t.key,e.key)}):i}(u(t,0,a,o),0)},key:function(t){return l.push(t),s},sortKeys:function(t){return c[l.length-1]=t,s},sortValues:function(e){return t=e,s},rollup:function(t){return e=t,s}}},t.set=c,t.map=r,t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],154:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e,r){t.prototype=e.prototype=r,r.constructor=t}function r(t,e){var r=Object.create(t.prototype);for(var n in e)r[n]=e[n];return r}function n(){}var i=\"\\\\s*([+-]?\\\\d+)\\\\s*\",a=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)\\\\s*\",o=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)%\\\\s*\",s=/^#([0-9a-f]{3})$/,l=/^#([0-9a-f]{6})$/,c=new RegExp(\"^rgb\\\\(\"+[i,i,i]+\"\\\\)$\"),u=new RegExp(\"^rgb\\\\(\"+[o,o,o]+\"\\\\)$\"),h=new RegExp(\"^rgba\\\\(\"+[i,i,i,a]+\"\\\\)$\"),f=new RegExp(\"^rgba\\\\(\"+[o,o,o,a]+\"\\\\)$\"),p=new RegExp(\"^hsl\\\\(\"+[a,o,o]+\"\\\\)$\"),d=new RegExp(\"^hsla\\\\(\"+[a,o,o,a]+\"\\\\)$\"),g={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};function v(t){var e;return t=(t+\"\").trim().toLowerCase(),(e=s.exec(t))?new _((e=parseInt(e[1],16))>>8&15|e>>4&240,e>>4&15|240&e,(15&e)<<4|15&e,1):(e=l.exec(t))?m(parseInt(e[1],16)):(e=c.exec(t))?new _(e[1],e[2],e[3],1):(e=u.exec(t))?new _(255*e[1]/100,255*e[2]/100,255*e[3]/100,1):(e=h.exec(t))?y(e[1],e[2],e[3],e[4]):(e=f.exec(t))?y(255*e[1]/100,255*e[2]/100,255*e[3]/100,e[4]):(e=p.exec(t))?k(e[1],e[2]/100,e[3]/100,1):(e=d.exec(t))?k(e[1],e[2]/100,e[3]/100,e[4]):g.hasOwnProperty(t)?m(g[t]):\"transparent\"===t?new _(NaN,NaN,NaN,0):null}function m(t){return new _(t>>16&255,t>>8&255,255&t,1)}function y(t,e,r,n){return n<=0&&(t=e=r=NaN),new _(t,e,r,n)}function x(t){return t instanceof n||(t=v(t)),t?new _((t=t.rgb()).r,t.g,t.b,t.opacity):new _}function b(t,e,r,n){return 1===arguments.length?x(t):new _(t,e,r,null==n?1:n)}function _(t,e,r,n){this.r=+t,this.g=+e,this.b=+r,this.opacity=+n}function w(t){return((t=Math.max(0,Math.min(255,Math.round(t)||0)))<16?\"0\":\"\")+t.toString(16)}function k(t,e,r,n){return n<=0?t=e=r=NaN:r<=0||r>=1?t=e=NaN:e<=0&&(t=NaN),new A(t,e,r,n)}function T(t,e,r,i){return 1===arguments.length?function(t){if(t instanceof A)return new A(t.h,t.s,t.l,t.opacity);if(t instanceof n||(t=v(t)),!t)return new A;if(t instanceof A)return t;var e=(t=t.rgb()).r/255,r=t.g/255,i=t.b/255,a=Math.min(e,r,i),o=Math.max(e,r,i),s=NaN,l=o-a,c=(o+a)/2;return l?(s=e===o?(r-i)/l+6*(r<i):r===o?(i-e)/l+2:(e-r)/l+4,l/=c<.5?o+a:2-o-a,s*=60):l=c>0&&c<1?0:s,new A(s,l,c,t.opacity)}(t):new A(t,e,r,null==i?1:i)}function A(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}function M(t,e,r){return 255*(t<60?e+(r-e)*t/60:t<180?r:t<240?e+(r-e)*(240-t)/60:e)}e(n,v,{displayable:function(){return this.rgb().displayable()},hex:function(){return this.rgb().hex()},toString:function(){return this.rgb()+\"\"}}),e(_,b,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new _(this.r*t,this.g*t,this.b*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new _(this.r*t,this.g*t,this.b*t,this.opacity)},rgb:function(){return this},displayable:function(){return 0<=this.r&&this.r<=255&&0<=this.g&&this.g<=255&&0<=this.b&&this.b<=255&&0<=this.opacity&&this.opacity<=1},hex:function(){return\"#\"+w(this.r)+w(this.g)+w(this.b)},toString:function(){var t=this.opacity;return(1===(t=isNaN(t)?1:Math.max(0,Math.min(1,t)))?\"rgb(\":\"rgba(\")+Math.max(0,Math.min(255,Math.round(this.r)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.g)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.b)||0))+(1===t?\")\":\", \"+t+\")\")}})),e(A,T,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new A(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new A(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=this.h%360+360*(this.h<0),e=isNaN(t)||isNaN(this.s)?0:this.s,r=this.l,n=r+(r<.5?r:1-r)*e,i=2*r-n;return new _(M(t>=240?t-240:t+120,i,n),M(t,i,n),M(t<120?t+240:t-120,i,n),this.opacity)},displayable:function(){return(0<=this.s&&this.s<=1||isNaN(this.s))&&0<=this.l&&this.l<=1&&0<=this.opacity&&this.opacity<=1}}));var S=Math.PI/180,E=180/Math.PI,C=.96422,L=1,P=.82521,O=4/29,z=6/29,I=3*z*z,D=z*z*z;function R(t){if(t instanceof B)return new B(t.l,t.a,t.b,t.opacity);if(t instanceof G){if(isNaN(t.h))return new B(t.l,0,0,t.opacity);var e=t.h*S;return new B(t.l,Math.cos(e)*t.c,Math.sin(e)*t.c,t.opacity)}t instanceof _||(t=x(t));var r,n,i=V(t.r),a=V(t.g),o=V(t.b),s=N((.2225045*i+.7168786*a+.0606169*o)/L);return i===a&&a===o?r=n=s:(r=N((.4360747*i+.3850649*a+.1430804*o)/C),n=N((.0139322*i+.0971045*a+.7141733*o)/P)),new B(116*s-16,500*(r-s),200*(s-n),t.opacity)}function F(t,e,r,n){return 1===arguments.length?R(t):new B(t,e,r,null==n?1:n)}function B(t,e,r,n){this.l=+t,this.a=+e,this.b=+r,this.opacity=+n}function N(t){return t>D?Math.pow(t,1/3):t/I+O}function j(t){return t>z?t*t*t:I*(t-O)}function U(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function V(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function q(t){if(t instanceof G)return new G(t.h,t.c,t.l,t.opacity);if(t instanceof B||(t=R(t)),0===t.a&&0===t.b)return new G(NaN,0,t.l,t.opacity);var e=Math.atan2(t.b,t.a)*E;return new G(e<0?e+360:e,Math.sqrt(t.a*t.a+t.b*t.b),t.l,t.opacity)}function H(t,e,r,n){return 1===arguments.length?q(t):new G(t,e,r,null==n?1:n)}function G(t,e,r,n){this.h=+t,this.c=+e,this.l=+r,this.opacity=+n}e(B,F,r(n,{brighter:function(t){return new B(this.l+18*(null==t?1:t),this.a,this.b,this.opacity)},darker:function(t){return new B(this.l-18*(null==t?1:t),this.a,this.b,this.opacity)},rgb:function(){var t=(this.l+16)/116,e=isNaN(this.a)?t:t+this.a/500,r=isNaN(this.b)?t:t-this.b/200;return new _(U(3.1338561*(e=C*j(e))-1.6168667*(t=L*j(t))-.4906146*(r=P*j(r))),U(-.9787684*e+1.9161415*t+.033454*r),U(.0719453*e-.2289914*t+1.4052427*r),this.opacity)}})),e(G,H,r(n,{brighter:function(t){return new G(this.h,this.c,this.l+18*(null==t?1:t),this.opacity)},darker:function(t){return new G(this.h,this.c,this.l-18*(null==t?1:t),this.opacity)},rgb:function(){return R(this).rgb()}}));var Y=-.14861,W=1.78277,X=-.29227,Z=-.90649,J=1.97294,K=J*Z,$=J*W,Q=W*X-Z*Y;function tt(t,e,r,n){return 1===arguments.length?function(t){if(t instanceof et)return new et(t.h,t.s,t.l,t.opacity);t instanceof _||(t=x(t));var e=t.r/255,r=t.g/255,n=t.b/255,i=(Q*n+K*e-$*r)/(Q+K-$),a=n-i,o=(J*(r-i)-X*a)/Z,s=Math.sqrt(o*o+a*a)/(J*i*(1-i)),l=s?Math.atan2(o,a)*E-120:NaN;return new et(l<0?l+360:l,s,i,t.opacity)}(t):new et(t,e,r,null==n?1:n)}function et(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}e(et,tt,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new et(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new et(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=isNaN(this.h)?0:(this.h+120)*S,e=+this.l,r=isNaN(this.s)?0:this.s*e*(1-e),n=Math.cos(t),i=Math.sin(t);return new _(255*(e+r*(Y*n+W*i)),255*(e+r*(X*n+Z*i)),255*(e+r*(J*n)),this.opacity)}})),t.color=v,t.rgb=b,t.hsl=T,t.lab=F,t.hcl=H,t.lch=function(t,e,r,n){return 1===arguments.length?q(t):new G(r,e,t,null==n?1:n)},t.gray=function(t,e){return new B(t,0,0,null==e?1:e)},t.cubehelix=tt,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],155:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e={value:function(){}};function r(){for(var t,e=0,r=arguments.length,i={};e<r;++e){if(!(t=arguments[e]+\"\")||t in i)throw new Error(\"illegal type: \"+t);i[t]=[]}return new n(i)}function n(t){this._=t}function i(t,e){for(var r,n=0,i=t.length;n<i;++n)if((r=t[n]).name===e)return r.value}function a(t,r,n){for(var i=0,a=t.length;i<a;++i)if(t[i].name===r){t[i]=e,t=t.slice(0,i).concat(t.slice(i+1));break}return null!=n&&t.push({name:r,value:n}),t}n.prototype=r.prototype={constructor:n,on:function(t,e){var r,n,o=this._,s=(n=o,(t+\"\").trim().split(/^|\\s+/).map(function(t){var e=\"\",r=t.indexOf(\".\");if(r>=0&&(e=t.slice(r+1),t=t.slice(0,r)),t&&!n.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);return{type:t,name:e}})),l=-1,c=s.length;if(!(arguments.length<2)){if(null!=e&&\"function\"!=typeof e)throw new Error(\"invalid callback: \"+e);for(;++l<c;)if(r=(t=s[l]).type)o[r]=a(o[r],t.name,e);else if(null==e)for(r in o)o[r]=a(o[r],t.name,null);return this}for(;++l<c;)if((r=(t=s[l]).type)&&(r=i(o[r],t.name)))return r},copy:function(){var t={},e=this._;for(var r in e)t[r]=e[r].slice();return new n(t)},call:function(t,e){if((r=arguments.length-2)>0)for(var r,n,i=new Array(r),a=0;a<r;++a)i[a]=arguments[a+2];if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(a=0,r=(n=this._[t]).length;a<r;++a)n[a].value.apply(e,i)},apply:function(t,e,r){if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(var n=this._[t],i=0,a=n.length;i<a;++i)n[i].value.apply(e,r)}},t.dispatch=r,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],156:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n,i){\"use strict\";var a=function(t){return function(){return t}},o=function(){return 1e-6*(Math.random()-.5)};function s(t){return t.x+t.vx}function l(t){return t.y+t.vy}function c(t){return t.index}function u(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function h(t){return t.x}function f(t){return t.y}var p=10,d=Math.PI*(3-Math.sqrt(5));t.forceCenter=function(t,e){var r;function n(){var n,i,a=r.length,o=0,s=0;for(n=0;n<a;++n)o+=(i=r[n]).x,s+=i.y;for(o=o/a-t,s=s/a-e,n=0;n<a;++n)(i=r[n]).x-=o,i.y-=s}return null==t&&(t=0),null==e&&(e=0),n.initialize=function(t){r=t},n.x=function(e){return arguments.length?(t=+e,n):t},n.y=function(t){return arguments.length?(e=+t,n):e},n},t.forceCollide=function(t){var r,n,i=1,c=1;function u(){for(var t,a,u,f,p,d,g,v=r.length,m=0;m<c;++m)for(a=e.quadtree(r,s,l).visitAfter(h),t=0;t<v;++t)u=r[t],d=n[u.index],g=d*d,f=u.x+u.vx,p=u.y+u.vy,a.visit(y);function y(t,e,r,n,a){var s=t.data,l=t.r,c=d+l;if(!s)return e>f+c||n<f-c||r>p+c||a<p-c;if(s.index>u.index){var h=f-s.x-s.vx,v=p-s.y-s.vy,m=h*h+v*v;m<c*c&&(0===h&&(m+=(h=o())*h),0===v&&(m+=(v=o())*v),m=(c-(m=Math.sqrt(m)))/m*i,u.vx+=(h*=m)*(c=(l*=l)/(g+l)),u.vy+=(v*=m)*c,s.vx-=h*(c=1-c),s.vy-=v*c)}}}function h(t){if(t.data)return t.r=n[t.data.index];for(var e=t.r=0;e<4;++e)t[e]&&t[e].r>t.r&&(t.r=t[e].r)}function f(){if(r){var e,i,a=r.length;for(n=new Array(a),e=0;e<a;++e)i=r[e],n[i.index]=+t(i,e,r)}}return\"function\"!=typeof t&&(t=a(null==t?1:+t)),u.initialize=function(t){r=t,f()},u.iterations=function(t){return arguments.length?(c=+t,u):c},u.strength=function(t){return arguments.length?(i=+t,u):i},u.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),f(),u):t},u},t.forceLink=function(t){var e,n,i,s,l,h=c,f=function(t){return 1/Math.min(s[t.source.index],s[t.target.index])},p=a(30),d=1;function g(r){for(var i=0,a=t.length;i<d;++i)for(var s,c,u,h,f,p,g,v=0;v<a;++v)c=(s=t[v]).source,h=(u=s.target).x+u.vx-c.x-c.vx||o(),f=u.y+u.vy-c.y-c.vy||o(),h*=p=((p=Math.sqrt(h*h+f*f))-n[v])/p*r*e[v],f*=p,u.vx-=h*(g=l[v]),u.vy-=f*g,c.vx+=h*(g=1-g),c.vy+=f*g}function v(){if(i){var a,o,c=i.length,f=t.length,p=r.map(i,h);for(a=0,s=new Array(c);a<f;++a)(o=t[a]).index=a,\"object\"!=typeof o.source&&(o.source=u(p,o.source)),\"object\"!=typeof o.target&&(o.target=u(p,o.target)),s[o.source.index]=(s[o.source.index]||0)+1,s[o.target.index]=(s[o.target.index]||0)+1;for(a=0,l=new Array(f);a<f;++a)o=t[a],l[a]=s[o.source.index]/(s[o.source.index]+s[o.target.index]);e=new Array(f),m(),n=new Array(f),y()}}function m(){if(i)for(var r=0,n=t.length;r<n;++r)e[r]=+f(t[r],r,t)}function y(){if(i)for(var e=0,r=t.length;e<r;++e)n[e]=+p(t[e],e,t)}return null==t&&(t=[]),g.initialize=function(t){i=t,v()},g.links=function(e){return arguments.length?(t=e,v(),g):t},g.id=function(t){return arguments.length?(h=t,g):h},g.iterations=function(t){return arguments.length?(d=+t,g):d},g.strength=function(t){return arguments.length?(f=\"function\"==typeof t?t:a(+t),m(),g):f},g.distance=function(t){return arguments.length?(p=\"function\"==typeof t?t:a(+t),y(),g):p},g},t.forceManyBody=function(){var t,r,n,i,s=a(-30),l=1,c=1/0,u=.81;function p(i){var a,o=t.length,s=e.quadtree(t,h,f).visitAfter(g);for(n=i,a=0;a<o;++a)r=t[a],s.visit(v)}function d(){if(t){var e,r,n=t.length;for(i=new Array(n),e=0;e<n;++e)r=t[e],i[r.index]=+s(r,e,t)}}function g(t){var e,r,n,a,o,s=0,l=0;if(t.length){for(n=a=o=0;o<4;++o)(e=t[o])&&(r=Math.abs(e.value))&&(s+=e.value,l+=r,n+=r*e.x,a+=r*e.y);t.x=n/l,t.y=a/l}else{(e=t).x=e.data.x,e.y=e.data.y;do{s+=i[e.data.index]}while(e=e.next)}t.value=s}function v(t,e,a,s){if(!t.value)return!0;var h=t.x-r.x,f=t.y-r.y,p=s-e,d=h*h+f*f;if(p*p/u<d)return d<c&&(0===h&&(d+=(h=o())*h),0===f&&(d+=(f=o())*f),d<l&&(d=Math.sqrt(l*d)),r.vx+=h*t.value*n/d,r.vy+=f*t.value*n/d),!0;if(!(t.length||d>=c)){(t.data!==r||t.next)&&(0===h&&(d+=(h=o())*h),0===f&&(d+=(f=o())*f),d<l&&(d=Math.sqrt(l*d)));do{t.data!==r&&(p=i[t.data.index]*n/d,r.vx+=h*p,r.vy+=f*p)}while(t=t.next)}}return p.initialize=function(e){t=e,d()},p.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),d(),p):s},p.distanceMin=function(t){return arguments.length?(l=t*t,p):Math.sqrt(l)},p.distanceMax=function(t){return arguments.length?(c=t*t,p):Math.sqrt(c)},p.theta=function(t){return arguments.length?(u=t*t,p):Math.sqrt(u)},p},t.forceRadial=function(t,e,r){var n,i,o,s=a(.1);function l(t){for(var a=0,s=n.length;a<s;++a){var l=n[a],c=l.x-e||1e-6,u=l.y-r||1e-6,h=Math.sqrt(c*c+u*u),f=(o[a]-h)*i[a]*t/h;l.vx+=c*f,l.vy+=u*f}}function c(){if(n){var e,r=n.length;for(i=new Array(r),o=new Array(r),e=0;e<r;++e)o[e]=+t(n[e],e,n),i[e]=isNaN(o[e])?0:+s(n[e],e,n)}}return\"function\"!=typeof t&&(t=a(+t)),null==e&&(e=0),null==r&&(r=0),l.initialize=function(t){n=t,c()},l.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),c(),l):s},l.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),c(),l):t},l.x=function(t){return arguments.length?(e=+t,l):e},l.y=function(t){return arguments.length?(r=+t,l):r},l},t.forceSimulation=function(t){var e,a=1,o=.001,s=1-Math.pow(o,1/300),l=0,c=.6,u=r.map(),h=i.timer(g),f=n.dispatch(\"tick\",\"end\");function g(){v(),f.call(\"tick\",e),a<o&&(h.stop(),f.call(\"end\",e))}function v(){var e,r,n=t.length;for(a+=(l-a)*s,u.each(function(t){t(a)}),e=0;e<n;++e)null==(r=t[e]).fx?r.x+=r.vx*=c:(r.x=r.fx,r.vx=0),null==r.fy?r.y+=r.vy*=c:(r.y=r.fy,r.vy=0)}function m(){for(var e,r=0,n=t.length;r<n;++r){if((e=t[r]).index=r,isNaN(e.x)||isNaN(e.y)){var i=p*Math.sqrt(r),a=r*d;e.x=i*Math.cos(a),e.y=i*Math.sin(a)}(isNaN(e.vx)||isNaN(e.vy))&&(e.vx=e.vy=0)}}function y(e){return e.initialize&&e.initialize(t),e}return null==t&&(t=[]),m(),e={tick:v,restart:function(){return h.restart(g),e},stop:function(){return h.stop(),e},nodes:function(r){return arguments.length?(t=r,m(),u.each(y),e):t},alpha:function(t){return arguments.length?(a=+t,e):a},alphaMin:function(t){return arguments.length?(o=+t,e):o},alphaDecay:function(t){return arguments.length?(s=+t,e):+s},alphaTarget:function(t){return arguments.length?(l=+t,e):l},velocityDecay:function(t){return arguments.length?(c=1-t,e):1-c},force:function(t,r){return arguments.length>1?(null==r?u.remove(t):u.set(t,y(r)),e):u.get(t)},find:function(e,r,n){var i,a,o,s,l,c=0,u=t.length;for(null==n?n=1/0:n*=n,c=0;c<u;++c)(o=(i=e-(s=t[c]).x)*i+(a=r-s.y)*a)<n&&(l=s,n=o);return l},on:function(t,r){return arguments.length>1?(f.on(t,r),e):f.on(t)}}},t.forceX=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vx+=(n[a]-i.x)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},t.forceY=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vy+=(n[a]-i.y)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.y=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-quadtree\"),t(\"d3-collection\"),t(\"d3-dispatch\"),t(\"d3-timer\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,n.d3)},{\"d3-collection\":153,\"d3-dispatch\":155,\"d3-quadtree\":160,\"d3-timer\":162}],157:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e){return t.parent===e.parent?1:2}function r(t,e){return t+e.x}function n(t,e){return Math.max(t,e.y)}function i(t){var e=0,r=t.children,n=r&&r.length;if(n)for(;--n>=0;)e+=r[n].value;else e=1;t.value=e}function a(t,e){var r,n,i,a,s,u=new c(t),h=+t.value&&(u.value=t.value),f=[u];for(null==e&&(e=o);r=f.pop();)if(h&&(r.value=+r.data.value),(i=e(r.data))&&(s=i.length))for(r.children=new Array(s),a=s-1;a>=0;--a)f.push(n=r.children[a]=new c(i[a])),n.parent=r,n.depth=r.depth+1;return u.eachBefore(l)}function o(t){return t.children}function s(t){t.data=t.data.data}function l(t){var e=0;do{t.height=e}while((t=t.parent)&&t.height<++e)}function c(t){this.data=t,this.depth=this.height=0,this.parent=null}c.prototype=a.prototype={constructor:c,count:function(){return this.eachAfter(i)},each:function(t){var e,r,n,i,a=this,o=[a];do{for(e=o.reverse(),o=[];a=e.pop();)if(t(a),r=a.children)for(n=0,i=r.length;n<i;++n)o.push(r[n])}while(o.length);return this},eachAfter:function(t){for(var e,r,n,i=this,a=[i],o=[];i=a.pop();)if(o.push(i),e=i.children)for(r=0,n=e.length;r<n;++r)a.push(e[r]);for(;i=o.pop();)t(i);return this},eachBefore:function(t){for(var e,r,n=this,i=[n];n=i.pop();)if(t(n),e=n.children)for(r=e.length-1;r>=0;--r)i.push(e[r]);return this},sum:function(t){return this.eachAfter(function(e){for(var r=+t(e.data)||0,n=e.children,i=n&&n.length;--i>=0;)r+=n[i].value;e.value=r})},sort:function(t){return this.eachBefore(function(e){e.children&&e.children.sort(t)})},path:function(t){for(var e=this,r=function(t,e){if(t===e)return t;var r=t.ancestors(),n=e.ancestors(),i=null;for(t=r.pop(),e=n.pop();t===e;)i=t,t=r.pop(),e=n.pop();return i}(e,t),n=[e];e!==r;)e=e.parent,n.push(e);for(var i=n.length;t!==r;)n.splice(i,0,t),t=t.parent;return n},ancestors:function(){for(var t=this,e=[t];t=t.parent;)e.push(t);return e},descendants:function(){var t=[];return this.each(function(e){t.push(e)}),t},leaves:function(){var t=[];return this.eachBefore(function(e){e.children||t.push(e)}),t},links:function(){var t=this,e=[];return t.each(function(r){r!==t&&e.push({source:r.parent,target:r})}),e},copy:function(){return a(this).eachBefore(s)}};var u=Array.prototype.slice;function h(t){for(var e,r,n=0,i=(t=function(t){for(var e,r,n=t.length;n;)r=Math.random()*n--|0,e=t[n],t[n]=t[r],t[r]=e;return t}(u.call(t))).length,a=[];n<i;)e=t[n],r&&d(r,e)?++n:(r=v(a=f(a,e)),n=0);return r}function f(t,e){var r,n;if(g(e,t))return[e];for(r=0;r<t.length;++r)if(p(e,t[r])&&g(m(t[r],e),t))return[t[r],e];for(r=0;r<t.length-1;++r)for(n=r+1;n<t.length;++n)if(p(m(t[r],t[n]),e)&&p(m(t[r],e),t[n])&&p(m(t[n],e),t[r])&&g(y(t[r],t[n],e),t))return[t[r],t[n],e];throw new Error}function p(t,e){var r=t.r-e.r,n=e.x-t.x,i=e.y-t.y;return r<0||r*r<n*n+i*i}function d(t,e){var r=t.r-e.r+1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function g(t,e){for(var r=0;r<e.length;++r)if(!d(t,e[r]))return!1;return!0}function v(t){switch(t.length){case 1:return{x:(e=t[0]).x,y:e.y,r:e.r};case 2:return m(t[0],t[1]);case 3:return y(t[0],t[1],t[2])}var e}function m(t,e){var r=t.x,n=t.y,i=t.r,a=e.x,o=e.y,s=e.r,l=a-r,c=o-n,u=s-i,h=Math.sqrt(l*l+c*c);return{x:(r+a+l/h*u)/2,y:(n+o+c/h*u)/2,r:(h+i+s)/2}}function y(t,e,r){var n=t.x,i=t.y,a=t.r,o=e.x,s=e.y,l=e.r,c=r.x,u=r.y,h=r.r,f=n-o,p=n-c,d=i-s,g=i-u,v=l-a,m=h-a,y=n*n+i*i-a*a,x=y-o*o-s*s+l*l,b=y-c*c-u*u+h*h,_=p*d-f*g,w=(d*b-g*x)/(2*_)-n,k=(g*v-d*m)/_,T=(p*x-f*b)/(2*_)-i,A=(f*m-p*v)/_,M=k*k+A*A-1,S=2*(a+w*k+T*A),E=w*w+T*T-a*a,C=-(M?(S+Math.sqrt(S*S-4*M*E))/(2*M):E/S);return{x:n+w+k*C,y:i+T+A*C,r:C}}function x(t,e,r){var n,i,a,o,s=t.x-e.x,l=t.y-e.y,c=s*s+l*l;c?(i=e.r+r.r,i*=i,o=t.r+r.r,i>(o*=o)?(n=(c+o-i)/(2*c),a=Math.sqrt(Math.max(0,o/c-n*n)),r.x=t.x-n*s-a*l,r.y=t.y-n*l+a*s):(n=(c+i-o)/(2*c),a=Math.sqrt(Math.max(0,i/c-n*n)),r.x=e.x+n*s-a*l,r.y=e.y+n*l+a*s)):(r.x=e.x+r.r,r.y=e.y)}function b(t,e){var r=t.r+e.r-1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function _(t){var e=t._,r=t.next._,n=e.r+r.r,i=(e.x*r.r+r.x*e.r)/n,a=(e.y*r.r+r.y*e.r)/n;return i*i+a*a}function w(t){this._=t,this.next=null,this.previous=null}function k(t){if(!(i=t.length))return 0;var e,r,n,i,a,o,s,l,c,u,f;if((e=t[0]).x=0,e.y=0,!(i>1))return e.r;if(r=t[1],e.x=-r.r,r.x=e.r,r.y=0,!(i>2))return e.r+r.r;x(r,e,n=t[2]),e=new w(e),r=new w(r),n=new w(n),e.next=n.previous=r,r.next=e.previous=n,n.next=r.previous=e;t:for(s=3;s<i;++s){x(e._,r._,n=t[s]),n=new w(n),l=r.next,c=e.previous,u=r._.r,f=e._.r;do{if(u<=f){if(b(l._,n._)){r=l,e.next=r,r.previous=e,--s;continue t}u+=l._.r,l=l.next}else{if(b(c._,n._)){(e=c).next=r,r.previous=e,--s;continue t}f+=c._.r,c=c.previous}}while(l!==c.next);for(n.previous=e,n.next=r,e.next=r.previous=r=n,a=_(e);(n=n.next)!==r;)(o=_(n))<a&&(e=n,a=o);r=e.next}for(e=[r._],n=r;(n=n.next)!==r;)e.push(n._);for(n=h(e),s=0;s<i;++s)(e=t[s]).x-=n.x,e.y-=n.y;return n.r}function T(t){if(\"function\"!=typeof t)throw new Error;return t}function A(){return 0}function M(t){return function(){return t}}function S(t){return Math.sqrt(t.value)}function E(t){return function(e){e.children||(e.r=Math.max(0,+t(e)||0))}}function C(t,e){return function(r){if(n=r.children){var n,i,a,o=n.length,s=t(r)*e||0;if(s)for(i=0;i<o;++i)n[i].r+=s;if(a=k(n),s)for(i=0;i<o;++i)n[i].r-=s;r.r=a+s}}}function L(t){return function(e){var r=e.parent;e.r*=t,r&&(e.x=r.x+t*e.x,e.y=r.y+t*e.y)}}function P(t){t.x0=Math.round(t.x0),t.y0=Math.round(t.y0),t.x1=Math.round(t.x1),t.y1=Math.round(t.y1)}function O(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(n-e)/t.value;++s<l;)(a=o[s]).y0=r,a.y1=i,a.x0=e,a.x1=e+=a.value*c}var z=\"$\",I={depth:-1},D={};function R(t){return t.id}function F(t){return t.parentId}function B(t,e){return t.parent===e.parent?1:2}function N(t){var e=t.children;return e?e[0]:t.t}function j(t){var e=t.children;return e?e[e.length-1]:t.t}function U(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function V(t,e,r){return t.a.parent===e.parent?t.a:r}function q(t,e){this._=t,this.parent=null,this.children=null,this.A=null,this.a=this,this.z=0,this.m=0,this.c=0,this.s=0,this.t=null,this.i=e}function H(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(i-r)/t.value;++s<l;)(a=o[s]).x0=e,a.x1=n,a.y0=r,a.y1=r+=a.value*c}q.prototype=Object.create(c.prototype);var G=(1+Math.sqrt(5))/2;function Y(t,e,r,n,i,a){for(var o,s,l,c,u,h,f,p,d,g,v,m=[],y=e.children,x=0,b=0,_=y.length,w=e.value;x<_;){l=i-r,c=a-n;do{u=y[b++].value}while(!u&&b<_);for(h=f=u,v=u*u*(g=Math.max(c/l,l/c)/(w*t)),d=Math.max(f/v,v/h);b<_;++b){if(u+=s=y[b].value,s<h&&(h=s),s>f&&(f=s),v=u*u*g,(p=Math.max(f/v,v/h))>d){u-=s;break}d=p}m.push(o={value:u,dice:l<c,children:y.slice(x,b)}),o.dice?O(o,r,n,i,w?n+=c*u/w:a):H(o,r,n,w?r+=l*u/w:i,a),w-=u,x=b}return m}var W=function t(e){function r(t,r,n,i,a){Y(e,t,r,n,i,a)}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);var X=function t(e){function r(t,r,n,i,a){if((o=t._squarify)&&o.ratio===e)for(var o,s,l,c,u,h=-1,f=o.length,p=t.value;++h<f;){for(l=(s=o[h]).children,c=s.value=0,u=l.length;c<u;++c)s.value+=l[c].value;s.dice?O(s,r,n,i,n+=(a-n)*s.value/p):H(s,r,n,r+=(i-r)*s.value/p,a),p-=s.value}else t._squarify=o=Y(e,t,r,n,i,a),o.ratio=e}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);t.cluster=function(){var t=e,i=1,a=1,o=!1;function s(e){var s,l=0;e.eachAfter(function(e){var i=e.children;i?(e.x=function(t){return t.reduce(r,0)/t.length}(i),e.y=function(t){return 1+t.reduce(n,0)}(i)):(e.x=s?l+=t(e,s):0,e.y=0,s=e)});var c=function(t){for(var e;e=t.children;)t=e[0];return t}(e),u=function(t){for(var e;e=t.children;)t=e[e.length-1];return t}(e),h=c.x-t(c,u)/2,f=u.x+t(u,c)/2;return e.eachAfter(o?function(t){t.x=(t.x-e.x)*i,t.y=(e.y-t.y)*a}:function(t){t.x=(t.x-h)/(f-h)*i,t.y=(1-(e.y?t.y/e.y:1))*a})}return s.separation=function(e){return arguments.length?(t=e,s):t},s.size=function(t){return arguments.length?(o=!1,i=+t[0],a=+t[1],s):o?null:[i,a]},s.nodeSize=function(t){return arguments.length?(o=!0,i=+t[0],a=+t[1],s):o?[i,a]:null},s},t.hierarchy=a,t.pack=function(){var t=null,e=1,r=1,n=A;function i(i){return i.x=e/2,i.y=r/2,t?i.eachBefore(E(t)).eachAfter(C(n,.5)).eachBefore(L(1)):i.eachBefore(E(S)).eachAfter(C(A,1)).eachAfter(C(n,i.r/Math.min(e,r))).eachBefore(L(Math.min(e,r)/(2*i.r))),i}return i.radius=function(e){return arguments.length?(t=null==(r=e)?null:T(r),i):t;var r},i.size=function(t){return arguments.length?(e=+t[0],r=+t[1],i):[e,r]},i.padding=function(t){return arguments.length?(n=\"function\"==typeof t?t:M(+t),i):n},i},t.packSiblings=function(t){return k(t),t},t.packEnclose=h,t.partition=function(){var t=1,e=1,r=0,n=!1;function i(i){var a=i.height+1;return i.x0=i.y0=r,i.x1=t,i.y1=e/a,i.eachBefore(function(t,e){return function(n){n.children&&O(n,n.x0,t*(n.depth+1)/e,n.x1,t*(n.depth+2)/e);var i=n.x0,a=n.y0,o=n.x1-r,s=n.y1-r;o<i&&(i=o=(i+o)/2),s<a&&(a=s=(a+s)/2),n.x0=i,n.y0=a,n.x1=o,n.y1=s}}(e,a)),n&&i.eachBefore(P),i}return i.round=function(t){return arguments.length?(n=!!t,i):n},i.size=function(r){return arguments.length?(t=+r[0],e=+r[1],i):[t,e]},i.padding=function(t){return arguments.length?(r=+t,i):r},i},t.stratify=function(){var t=R,e=F;function r(r){var n,i,a,o,s,u,h,f=r.length,p=new Array(f),d={};for(i=0;i<f;++i)n=r[i],s=p[i]=new c(n),null!=(u=t(n,i,r))&&(u+=\"\")&&(d[h=z+(s.id=u)]=h in d?D:s);for(i=0;i<f;++i)if(s=p[i],null!=(u=e(r[i],i,r))&&(u+=\"\")){if(!(o=d[z+u]))throw new Error(\"missing: \"+u);if(o===D)throw new Error(\"ambiguous: \"+u);o.children?o.children.push(s):o.children=[s],s.parent=o}else{if(a)throw new Error(\"multiple roots\");a=s}if(!a)throw new Error(\"no root\");if(a.parent=I,a.eachBefore(function(t){t.depth=t.parent.depth+1,--f}).eachBefore(l),a.parent=null,f>0)throw new Error(\"cycle\");return a}return r.id=function(e){return arguments.length?(t=T(e),r):t},r.parentId=function(t){return arguments.length?(e=T(t),r):e},r},t.tree=function(){var t=B,e=1,r=1,n=null;function i(i){var l=function(t){for(var e,r,n,i,a,o=new q(t,0),s=[o];e=s.pop();)if(n=e._.children)for(e.children=new Array(a=n.length),i=a-1;i>=0;--i)s.push(r=e.children[i]=new q(n[i],i)),r.parent=e;return(o.parent=new q(null,0)).children=[o],o}(i);if(l.eachAfter(a),l.parent.m=-l.z,l.eachBefore(o),n)i.eachBefore(s);else{var c=i,u=i,h=i;i.eachBefore(function(t){t.x<c.x&&(c=t),t.x>u.x&&(u=t),t.depth>h.depth&&(h=t)});var f=c===u?1:t(c,u)/2,p=f-c.x,d=e/(u.x+f+p),g=r/(h.depth||1);i.eachBefore(function(t){t.x=(t.x+p)*d,t.y=t.depth*g})}return i}function a(e){var r=e.children,n=e.parent.children,i=e.i?n[e.i-1]:null;if(r){!function(t){for(var e,r=0,n=0,i=t.children,a=i.length;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(e);var a=(r[0].z+r[r.length-1].z)/2;i?(e.z=i.z+t(e._,i._),e.m=e.z-a):e.z=a}else i&&(e.z=i.z+t(e._,i._));e.parent.A=function(e,r,n){if(r){for(var i,a=e,o=e,s=r,l=a.parent.children[0],c=a.m,u=o.m,h=s.m,f=l.m;s=j(s),a=N(a),s&&a;)l=N(l),(o=j(o)).a=e,(i=s.z+h-a.z-c+t(s._,a._))>0&&(U(V(s,e,n),e,i),c+=i,u+=i),h+=s.m,c+=a.m,f+=l.m,u+=o.m;s&&!j(o)&&(o.t=s,o.m+=h-u),a&&!N(l)&&(l.t=a,l.m+=c-f,n=e)}return n}(e,i,e.parent.A||n[0])}function o(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function s(t){t.x*=e,t.y=t.depth*r}return i.separation=function(e){return arguments.length?(t=e,i):t},i.size=function(t){return arguments.length?(n=!1,e=+t[0],r=+t[1],i):n?null:[e,r]},i.nodeSize=function(t){return arguments.length?(n=!0,e=+t[0],r=+t[1],i):n?[e,r]:null},i},t.treemap=function(){var t=W,e=!1,r=1,n=1,i=[0],a=A,o=A,s=A,l=A,c=A;function u(t){return t.x0=t.y0=0,t.x1=r,t.y1=n,t.eachBefore(h),i=[0],e&&t.eachBefore(P),t}function h(e){var r=i[e.depth],n=e.x0+r,u=e.y0+r,h=e.x1-r,f=e.y1-r;h<n&&(n=h=(n+h)/2),f<u&&(u=f=(u+f)/2),e.x0=n,e.y0=u,e.x1=h,e.y1=f,e.children&&(r=i[e.depth+1]=a(e)/2,n+=c(e)-r,u+=o(e)-r,(h-=s(e)-r)<n&&(n=h=(n+h)/2),(f-=l(e)-r)<u&&(u=f=(u+f)/2),t(e,n,u,h,f))}return u.round=function(t){return arguments.length?(e=!!t,u):e},u.size=function(t){return arguments.length?(r=+t[0],n=+t[1],u):[r,n]},u.tile=function(e){return arguments.length?(t=T(e),u):t},u.padding=function(t){return arguments.length?u.paddingInner(t).paddingOuter(t):u.paddingInner()},u.paddingInner=function(t){return arguments.length?(a=\"function\"==typeof t?t:M(+t),u):a},u.paddingOuter=function(t){return arguments.length?u.paddingTop(t).paddingRight(t).paddingBottom(t).paddingLeft(t):u.paddingTop()},u.paddingTop=function(t){return arguments.length?(o=\"function\"==typeof t?t:M(+t),u):o},u.paddingRight=function(t){return arguments.length?(s=\"function\"==typeof t?t:M(+t),u):s},u.paddingBottom=function(t){return arguments.length?(l=\"function\"==typeof t?t:M(+t),u):l},u.paddingLeft=function(t){return arguments.length?(c=\"function\"==typeof t?t:M(+t),u):c},u},t.treemapBinary=function(t,e,r,n,i){var a,o,s=t.children,l=s.length,c=new Array(l+1);for(c[0]=o=a=0;a<l;++a)c[a+1]=o+=s[a].value;!function t(e,r,n,i,a,o,l){if(e>=r-1){var u=s[e];return u.x0=i,u.y0=a,u.x1=o,void(u.y1=l)}for(var h=c[e],f=n/2+h,p=e+1,d=r-1;p<d;){var g=p+d>>>1;c[g]<f?p=g+1:d=g}f-c[p-1]<c[p]-f&&e+1<p&&--p;var v=c[p]-h,m=n-v;if(o-i>l-a){var y=(i*m+o*v)/n;t(e,p,v,i,a,y,l),t(p,r,m,y,a,o,l)}else{var x=(a*m+l*v)/n;t(e,p,v,i,a,o,x),t(p,r,m,i,x,o,l)}}(0,l,t.value,e,r,n,i)},t.treemapDice=O,t.treemapSlice=H,t.treemapSliceDice=function(t,e,r,n,i){(1&t.depth?H:O)(t,e,r,n,i)},t.treemapSquarify=W,t.treemapResquarify=X,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],158:[function(t,e,r){var n,i;n=this,i=function(t,e){\"use strict\";function r(t,e,r,n,i){var a=t*t,o=a*t;return((1-3*t+3*a-o)*e+(4-6*a+3*o)*r+(1+3*t+3*a-3*o)*n+o*i)/6}function n(t){var e=t.length-1;return function(n){var i=n<=0?n=0:n>=1?(n=1,e-1):Math.floor(n*e),a=t[i],o=t[i+1],s=i>0?t[i-1]:2*a-o,l=i<e-1?t[i+2]:2*o-a;return r((n-i/e)*e,s,a,o,l)}}function i(t){var e=t.length;return function(n){var i=Math.floor(((n%=1)<0?++n:n)*e),a=t[(i+e-1)%e],o=t[i%e],s=t[(i+1)%e],l=t[(i+2)%e];return r((n-i/e)*e,a,o,s,l)}}function a(t){return function(){return t}}function o(t,e){return function(r){return t+r*e}}function s(t,e){var r=e-t;return r?o(t,r>180||r<-180?r-360*Math.round(r/360):r):a(isNaN(t)?e:t)}function l(t){return 1==(t=+t)?c:function(e,r){return r-e?function(t,e,r){return t=Math.pow(t,r),e=Math.pow(e,r)-t,r=1/r,function(n){return Math.pow(t+n*e,r)}}(e,r,t):a(isNaN(e)?r:e)}}function c(t,e){var r=e-t;return r?o(t,r):a(isNaN(t)?e:t)}var u=function t(r){var n=l(r);function i(t,r){var i=n((t=e.rgb(t)).r,(r=e.rgb(r)).r),a=n(t.g,r.g),o=n(t.b,r.b),s=c(t.opacity,r.opacity);return function(e){return t.r=i(e),t.g=a(e),t.b=o(e),t.opacity=s(e),t+\"\"}}return i.gamma=t,i}(1);function h(t){return function(r){var n,i,a=r.length,o=new Array(a),s=new Array(a),l=new Array(a);for(n=0;n<a;++n)i=e.rgb(r[n]),o[n]=i.r||0,s[n]=i.g||0,l[n]=i.b||0;return o=t(o),s=t(s),l=t(l),i.opacity=1,function(t){return i.r=o(t),i.g=s(t),i.b=l(t),i+\"\"}}}var f=h(n),p=h(i);function d(t,e){var r,n=e?e.length:0,i=t?Math.min(n,t.length):0,a=new Array(i),o=new Array(n);for(r=0;r<i;++r)a[r]=_(t[r],e[r]);for(;r<n;++r)o[r]=e[r];return function(t){for(r=0;r<i;++r)o[r]=a[r](t);return o}}function g(t,e){var r=new Date;return e-=t=+t,function(n){return r.setTime(t+e*n),r}}function v(t,e){return e-=t=+t,function(r){return t+e*r}}function m(t,e){var r,n={},i={};for(r in null!==t&&\"object\"==typeof t||(t={}),null!==e&&\"object\"==typeof e||(e={}),e)r in t?n[r]=_(t[r],e[r]):i[r]=e[r];return function(t){for(r in n)i[r]=n[r](t);return i}}var y=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,x=new RegExp(y.source,\"g\");function b(t,e){var r,n,i,a=y.lastIndex=x.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=y.exec(t))&&(n=x.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:v(r,n)})),a=x.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?function(t){return function(e){return t(e)+\"\"}}(l[0].x):function(t){return function(){return t}}(e):(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}function _(t,r){var n,i=typeof r;return null==r||\"boolean\"===i?a(r):(\"number\"===i?v:\"string\"===i?(n=e.color(r))?(r=n,u):b:r instanceof e.color?u:r instanceof Date?g:Array.isArray(r)?d:\"function\"!=typeof r.valueOf&&\"function\"!=typeof r.toString||isNaN(r)?m:v)(t,r)}var w,k,T,A,M=180/Math.PI,S={translateX:0,translateY:0,rotate:0,skewX:0,scaleX:1,scaleY:1};function E(t,e,r,n,i,a){var o,s,l;return(o=Math.sqrt(t*t+e*e))&&(t/=o,e/=o),(l=t*r+e*n)&&(r-=t*l,n-=e*l),(s=Math.sqrt(r*r+n*n))&&(r/=s,n/=s,l/=s),t*n<e*r&&(t=-t,e=-e,l=-l,o=-o),{translateX:i,translateY:a,rotate:Math.atan2(e,t)*M,skewX:Math.atan(l)*M,scaleX:o,scaleY:s}}function C(t,e,r,n){function i(t){return t.length?t.pop()+\" \":\"\"}return function(a,o){var s=[],l=[];return a=t(a),o=t(o),function(t,n,i,a,o,s){if(t!==i||n!==a){var l=o.push(\"translate(\",null,e,null,r);s.push({i:l-4,x:v(t,i)},{i:l-2,x:v(n,a)})}else(i||a)&&o.push(\"translate(\"+i+e+a+r)}(a.translateX,a.translateY,o.translateX,o.translateY,s,l),function(t,e,r,a){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),a.push({i:r.push(i(r)+\"rotate(\",null,n)-2,x:v(t,e)})):e&&r.push(i(r)+\"rotate(\"+e+n)}(a.rotate,o.rotate,s,l),function(t,e,r,a){t!==e?a.push({i:r.push(i(r)+\"skewX(\",null,n)-2,x:v(t,e)}):e&&r.push(i(r)+\"skewX(\"+e+n)}(a.skewX,o.skewX,s,l),function(t,e,r,n,a,o){if(t!==r||e!==n){var s=a.push(i(a)+\"scale(\",null,\",\",null,\")\");o.push({i:s-4,x:v(t,r)},{i:s-2,x:v(e,n)})}else 1===r&&1===n||a.push(i(a)+\"scale(\"+r+\",\"+n+\")\")}(a.scaleX,a.scaleY,o.scaleX,o.scaleY,s,l),a=o=null,function(t){for(var e,r=-1,n=l.length;++r<n;)s[(e=l[r]).i]=e.x(t);return s.join(\"\")}}}var L=C(function(t){return\"none\"===t?S:(w||(w=document.createElement(\"DIV\"),k=document.documentElement,T=document.defaultView),w.style.transform=t,t=T.getComputedStyle(k.appendChild(w),null).getPropertyValue(\"transform\"),k.removeChild(w),E(+(t=t.slice(7,-1).split(\",\"))[0],+t[1],+t[2],+t[3],+t[4],+t[5]))},\"px, \",\"px)\",\"deg)\"),P=C(function(t){return null==t?S:(A||(A=document.createElementNS(\"http://www.w3.org/2000/svg\",\"g\")),A.setAttribute(\"transform\",t),(t=A.transform.baseVal.consolidate())?E((t=t.matrix).a,t.b,t.c,t.d,t.e,t.f):S)},\", \",\")\",\")\"),O=Math.SQRT2,z=2,I=4,D=1e-12;function R(t){return((t=Math.exp(t))+1/t)/2}function F(t){return function(r,n){var i=t((r=e.hsl(r)).h,(n=e.hsl(n)).h),a=c(r.s,n.s),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.s=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var B=F(s),N=F(c);function j(t){return function(r,n){var i=t((r=e.hcl(r)).h,(n=e.hcl(n)).h),a=c(r.c,n.c),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.c=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var U=j(s),V=j(c);function q(t){return function r(n){function i(r,i){var a=t((r=e.cubehelix(r)).h,(i=e.cubehelix(i)).h),o=c(r.s,i.s),s=c(r.l,i.l),l=c(r.opacity,i.opacity);return function(t){return r.h=a(t),r.s=o(t),r.l=s(Math.pow(t,n)),r.opacity=l(t),r+\"\"}}return n=+n,i.gamma=r,i}(1)}var H=q(s),G=q(c);t.interpolate=_,t.interpolateArray=d,t.interpolateBasis=n,t.interpolateBasisClosed=i,t.interpolateDate=g,t.interpolateDiscrete=function(t){var e=t.length;return function(r){return t[Math.max(0,Math.min(e-1,Math.floor(r*e)))]}},t.interpolateHue=function(t,e){var r=s(+t,+e);return function(t){var e=r(t);return e-360*Math.floor(e/360)}},t.interpolateNumber=v,t.interpolateObject=m,t.interpolateRound=function(t,e){return e-=t=+t,function(r){return Math.round(t+e*r)}},t.interpolateString=b,t.interpolateTransformCss=L,t.interpolateTransformSvg=P,t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,h=l-a,f=u*u+h*h;if(f<D)n=Math.log(c/o)/O,r=function(t){return[i+t*u,a+t*h,o*Math.exp(O*t*n)]};else{var p=Math.sqrt(f),d=(c*c-o*o+I*f)/(2*o*z*p),g=(c*c-o*o-I*f)/(2*c*z*p),v=Math.log(Math.sqrt(d*d+1)-d),m=Math.log(Math.sqrt(g*g+1)-g);n=(m-v)/O,r=function(t){var e,r=t*n,s=R(v),l=o/(z*p)*(s*(e=O*r+v,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(v));return[i+l*u,a+l*h,o*s/R(O*r+v)]}}return r.duration=1e3*n,r},t.interpolateRgb=u,t.interpolateRgbBasis=f,t.interpolateRgbBasisClosed=p,t.interpolateHsl=B,t.interpolateHslLong=N,t.interpolateLab=function(t,r){var n=c((t=e.lab(t)).l,(r=e.lab(r)).l),i=c(t.a,r.a),a=c(t.b,r.b),o=c(t.opacity,r.opacity);return function(e){return t.l=n(e),t.a=i(e),t.b=a(e),t.opacity=o(e),t+\"\"}},t.interpolateHcl=U,t.interpolateHclLong=V,t.interpolateCubehelix=H,t.interpolateCubehelixLong=G,t.piecewise=function(t,e){for(var r=0,n=e.length-1,i=e[0],a=new Array(n<0?0:n);r<n;)a[r]=t(i,i=e[++r]);return function(t){var e=Math.max(0,Math.min(n-1,Math.floor(t*=n)));return a[e](t-e)}},t.quantize=function(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t(n/(e-1));return r},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-color\")):i(n.d3=n.d3||{},n.d3)},{\"d3-color\":154}],159:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e=Math.PI,r=2*e,n=r-1e-6;function i(){this._x0=this._y0=this._x1=this._y1=null,this._=\"\"}function a(){return new i}i.prototype=a.prototype={constructor:i,moveTo:function(t,e){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)},closePath:function(){null!==this._x1&&(this._x1=this._x0,this._y1=this._y0,this._+=\"Z\")},lineTo:function(t,e){this._+=\"L\"+(this._x1=+t)+\",\"+(this._y1=+e)},quadraticCurveTo:function(t,e,r,n){this._+=\"Q\"+ +t+\",\"+ +e+\",\"+(this._x1=+r)+\",\"+(this._y1=+n)},bezierCurveTo:function(t,e,r,n,i,a){this._+=\"C\"+ +t+\",\"+ +e+\",\"+ +r+\",\"+ +n+\",\"+(this._x1=+i)+\",\"+(this._y1=+a)},arcTo:function(t,r,n,i,a){t=+t,r=+r,n=+n,i=+i,a=+a;var o=this._x1,s=this._y1,l=n-t,c=i-r,u=o-t,h=s-r,f=u*u+h*h;if(a<0)throw new Error(\"negative radius: \"+a);if(null===this._x1)this._+=\"M\"+(this._x1=t)+\",\"+(this._y1=r);else if(f>1e-6)if(Math.abs(h*l-c*u)>1e-6&&a){var p=n-o,d=i-s,g=l*l+c*c,v=p*p+d*d,m=Math.sqrt(g),y=Math.sqrt(f),x=a*Math.tan((e-Math.acos((g+f-v)/(2*m*y)))/2),b=x/y,_=x/m;Math.abs(b-1)>1e-6&&(this._+=\"L\"+(t+b*u)+\",\"+(r+b*h)),this._+=\"A\"+a+\",\"+a+\",0,0,\"+ +(h*p>u*d)+\",\"+(this._x1=t+_*l)+\",\"+(this._y1=r+_*c)}else this._+=\"L\"+(this._x1=t)+\",\"+(this._y1=r);else;},arc:function(t,i,a,o,s,l){t=+t,i=+i;var c=(a=+a)*Math.cos(o),u=a*Math.sin(o),h=t+c,f=i+u,p=1^l,d=l?o-s:s-o;if(a<0)throw new Error(\"negative radius: \"+a);null===this._x1?this._+=\"M\"+h+\",\"+f:(Math.abs(this._x1-h)>1e-6||Math.abs(this._y1-f)>1e-6)&&(this._+=\"L\"+h+\",\"+f),a&&(d<0&&(d=d%r+r),d>n?this._+=\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(t-c)+\",\"+(i-u)+\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(this._x1=h)+\",\"+(this._y1=f):d>1e-6&&(this._+=\"A\"+a+\",\"+a+\",0,\"+ +(d>=e)+\",\"+p+\",\"+(this._x1=t+a*Math.cos(s))+\",\"+(this._y1=i+a*Math.sin(s))))},rect:function(t,e,r,n){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)+\"h\"+ +r+\"v\"+ +n+\"h\"+-r+\"Z\"},toString:function(){return this._}},t.path=a,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],160:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e,r,n){if(isNaN(e)||isNaN(r))return t;var i,a,o,s,l,c,u,h,f,p=t._root,d={data:n},g=t._x0,v=t._y0,m=t._x1,y=t._y1;if(!p)return t._root=d,t;for(;p.length;)if((c=e>=(a=(g+m)/2))?g=a:m=a,(u=r>=(o=(v+y)/2))?v=o:y=o,i=p,!(p=p[h=u<<1|c]))return i[h]=d,t;if(s=+t._x.call(null,p.data),l=+t._y.call(null,p.data),e===s&&r===l)return d.next=p,i?i[h]=d:t._root=d,t;do{i=i?i[h]=new Array(4):t._root=new Array(4),(c=e>=(a=(g+m)/2))?g=a:m=a,(u=r>=(o=(v+y)/2))?v=o:y=o}while((h=u<<1|c)==(f=(l>=o)<<1|s>=a));return i[f]=p,i[h]=d,t}var r=function(t,e,r,n,i){this.node=t,this.x0=e,this.y0=r,this.x1=n,this.y1=i};function n(t){return t[0]}function i(t){return t[1]}function a(t,e,r){var a=new o(null==e?n:e,null==r?i:r,NaN,NaN,NaN,NaN);return null==t?a:a.addAll(t)}function o(t,e,r,n,i,a){this._x=t,this._y=e,this._x0=r,this._y0=n,this._x1=i,this._y1=a,this._root=void 0}function s(t){for(var e={data:t.data},r=e;t=t.next;)r=r.next={data:t.data};return e}var l=a.prototype=o.prototype;l.copy=function(){var t,e,r=new o(this._x,this._y,this._x0,this._y0,this._x1,this._y1),n=this._root;if(!n)return r;if(!n.length)return r._root=s(n),r;for(t=[{source:n,target:r._root=new Array(4)}];n=t.pop();)for(var i=0;i<4;++i)(e=n.source[i])&&(e.length?t.push({source:e,target:n.target[i]=new Array(4)}):n.target[i]=s(e));return r},l.add=function(t){var r=+this._x.call(null,t),n=+this._y.call(null,t);return e(this.cover(r,n),r,n,t)},l.addAll=function(t){var r,n,i,a,o=t.length,s=new Array(o),l=new Array(o),c=1/0,u=1/0,h=-1/0,f=-1/0;for(n=0;n<o;++n)isNaN(i=+this._x.call(null,r=t[n]))||isNaN(a=+this._y.call(null,r))||(s[n]=i,l[n]=a,i<c&&(c=i),i>h&&(h=i),a<u&&(u=a),a>f&&(f=a));for(h<c&&(c=this._x0,h=this._x1),f<u&&(u=this._y0,f=this._y1),this.cover(c,u).cover(h,f),n=0;n<o;++n)e(this,s[n],l[n],t[n]);return this},l.cover=function(t,e){if(isNaN(t=+t)||isNaN(e=+e))return this;var r=this._x0,n=this._y0,i=this._x1,a=this._y1;if(isNaN(r))i=(r=Math.floor(t))+1,a=(n=Math.floor(e))+1;else{if(!(r>t||t>i||n>e||e>a))return this;var o,s,l=i-r,c=this._root;switch(s=(e<(n+a)/2)<<1|t<(r+i)/2){case 0:do{(o=new Array(4))[s]=c,c=o}while(a=n+(l*=2),t>(i=r+l)||e>a);break;case 1:do{(o=new Array(4))[s]=c,c=o}while(a=n+(l*=2),(r=i-l)>t||e>a);break;case 2:do{(o=new Array(4))[s]=c,c=o}while(n=a-(l*=2),t>(i=r+l)||n>e);break;case 3:do{(o=new Array(4))[s]=c,c=o}while(n=a-(l*=2),(r=i-l)>t||n>e)}this._root&&this._root.length&&(this._root=c)}return this._x0=r,this._y0=n,this._x1=i,this._y1=a,this},l.data=function(){var t=[];return this.visit(function(e){if(!e.length)do{t.push(e.data)}while(e=e.next)}),t},l.extent=function(t){return arguments.length?this.cover(+t[0][0],+t[0][1]).cover(+t[1][0],+t[1][1]):isNaN(this._x0)?void 0:[[this._x0,this._y0],[this._x1,this._y1]]},l.find=function(t,e,n){var i,a,o,s,l,c,u,h=this._x0,f=this._y0,p=this._x1,d=this._y1,g=[],v=this._root;for(v&&g.push(new r(v,h,f,p,d)),null==n?n=1/0:(h=t-n,f=e-n,p=t+n,d=e+n,n*=n);c=g.pop();)if(!(!(v=c.node)||(a=c.x0)>p||(o=c.y0)>d||(s=c.x1)<h||(l=c.y1)<f))if(v.length){var m=(a+s)/2,y=(o+l)/2;g.push(new r(v[3],m,y,s,l),new r(v[2],a,y,m,l),new r(v[1],m,o,s,y),new r(v[0],a,o,m,y)),(u=(e>=y)<<1|t>=m)&&(c=g[g.length-1],g[g.length-1]=g[g.length-1-u],g[g.length-1-u]=c)}else{var x=t-+this._x.call(null,v.data),b=e-+this._y.call(null,v.data),_=x*x+b*b;if(_<n){var w=Math.sqrt(n=_);h=t-w,f=e-w,p=t+w,d=e+w,i=v.data}}return i},l.remove=function(t){if(isNaN(a=+this._x.call(null,t))||isNaN(o=+this._y.call(null,t)))return this;var e,r,n,i,a,o,s,l,c,u,h,f,p=this._root,d=this._x0,g=this._y0,v=this._x1,m=this._y1;if(!p)return this;if(p.length)for(;;){if((c=a>=(s=(d+v)/2))?d=s:v=s,(u=o>=(l=(g+m)/2))?g=l:m=l,e=p,!(p=p[h=u<<1|c]))return this;if(!p.length)break;(e[h+1&3]||e[h+2&3]||e[h+3&3])&&(r=e,f=h)}for(;p.data!==t;)if(n=p,!(p=p.next))return this;return(i=p.next)&&delete p.next,n?(i?n.next=i:delete n.next,this):e?(i?e[h]=i:delete e[h],(p=e[0]||e[1]||e[2]||e[3])&&p===(e[3]||e[2]||e[1]||e[0])&&!p.length&&(r?r[f]=p:this._root=p),this):(this._root=i,this)},l.removeAll=function(t){for(var e=0,r=t.length;e<r;++e)this.remove(t[e]);return this},l.root=function(){return this._root},l.size=function(){var t=0;return this.visit(function(e){if(!e.length)do{++t}while(e=e.next)}),t},l.visit=function(t){var e,n,i,a,o,s,l=[],c=this._root;for(c&&l.push(new r(c,this._x0,this._y0,this._x1,this._y1));e=l.pop();)if(!t(c=e.node,i=e.x0,a=e.y0,o=e.x1,s=e.y1)&&c.length){var u=(i+o)/2,h=(a+s)/2;(n=c[3])&&l.push(new r(n,u,h,o,s)),(n=c[2])&&l.push(new r(n,i,h,u,s)),(n=c[1])&&l.push(new r(n,u,a,o,h)),(n=c[0])&&l.push(new r(n,i,a,u,h))}return this},l.visitAfter=function(t){var e,n=[],i=[];for(this._root&&n.push(new r(this._root,this._x0,this._y0,this._x1,this._y1));e=n.pop();){var a=e.node;if(a.length){var o,s=e.x0,l=e.y0,c=e.x1,u=e.y1,h=(s+c)/2,f=(l+u)/2;(o=a[0])&&n.push(new r(o,s,l,h,f)),(o=a[1])&&n.push(new r(o,h,l,c,f)),(o=a[2])&&n.push(new r(o,s,f,h,u)),(o=a[3])&&n.push(new r(o,h,f,c,u))}i.push(e)}for(;e=i.pop();)t(e.node,e.x0,e.y0,e.x1,e.y1);return this},l.x=function(t){return arguments.length?(this._x=t,this):this._x},l.y=function(t){return arguments.length?(this._y=t,this):this._y},t.quadtree=a,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],161:[function(t,e,r){var n,i;n=this,i=function(t,e){\"use strict\";function r(t){return function(){return t}}var n=Math.abs,i=Math.atan2,a=Math.cos,o=Math.max,s=Math.min,l=Math.sin,c=Math.sqrt,u=1e-12,h=Math.PI,f=h/2,p=2*h;function d(t){return t>=1?f:t<=-1?-f:Math.asin(t)}function g(t){return t.innerRadius}function v(t){return t.outerRadius}function m(t){return t.startAngle}function y(t){return t.endAngle}function x(t){return t&&t.padAngle}function b(t,e,r,n,i,a,s){var l=t-r,u=e-n,h=(s?a:-a)/c(l*l+u*u),f=h*u,p=-h*l,d=t+f,g=e+p,v=r+f,m=n+p,y=(d+v)/2,x=(g+m)/2,b=v-d,_=m-g,w=b*b+_*_,k=i-a,T=d*m-v*g,A=(_<0?-1:1)*c(o(0,k*k*w-T*T)),M=(T*_-b*A)/w,S=(-T*b-_*A)/w,E=(T*_+b*A)/w,C=(-T*b+_*A)/w,L=M-y,P=S-x,O=E-y,z=C-x;return L*L+P*P>O*O+z*z&&(M=E,S=C),{cx:M,cy:S,x01:-f,y01:-p,x11:M*(i/k-1),y11:S*(i/k-1)}}function _(t){this._context=t}function w(t){return new _(t)}function k(t){return t[0]}function T(t){return t[1]}function A(){var t=k,n=T,i=r(!0),a=null,o=w,s=null;function l(r){var l,c,u,h=r.length,f=!1;for(null==a&&(s=o(u=e.path())),l=0;l<=h;++l)!(l<h&&i(c=r[l],l,r))===f&&((f=!f)?s.lineStart():s.lineEnd()),f&&s.point(+t(c,l,r),+n(c,l,r));if(u)return s=null,u+\"\"||null}return l.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),l):t},l.y=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),l):n},l.defined=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(!!t),l):i},l.curve=function(t){return arguments.length?(o=t,null!=a&&(s=o(a)),l):o},l.context=function(t){return arguments.length?(null==t?a=s=null:s=o(a=t),l):a},l}function M(){var t=k,n=null,i=r(0),a=T,o=r(!0),s=null,l=w,c=null;function u(r){var u,h,f,p,d,g=r.length,v=!1,m=new Array(g),y=new Array(g);for(null==s&&(c=l(d=e.path())),u=0;u<=g;++u){if(!(u<g&&o(p=r[u],u,r))===v)if(v=!v)h=u,c.areaStart(),c.lineStart();else{for(c.lineEnd(),c.lineStart(),f=u-1;f>=h;--f)c.point(m[f],y[f]);c.lineEnd(),c.areaEnd()}v&&(m[u]=+t(p,u,r),y[u]=+i(p,u,r),c.point(n?+n(p,u,r):m[u],a?+a(p,u,r):y[u]))}if(d)return c=null,d+\"\"||null}function h(){return A().defined(o).curve(l).context(s)}return u.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),n=null,u):t},u.x0=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),u):t},u.x1=function(t){return arguments.length?(n=null==t?null:\"function\"==typeof t?t:r(+t),u):n},u.y=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a=null,u):i},u.y0=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),u):i},u.y1=function(t){return arguments.length?(a=null==t?null:\"function\"==typeof t?t:r(+t),u):a},u.lineX0=u.lineY0=function(){return h().x(t).y(i)},u.lineY1=function(){return h().x(t).y(a)},u.lineX1=function(){return h().x(n).y(i)},u.defined=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(!!t),u):o},u.curve=function(t){return arguments.length?(l=t,null!=s&&(c=l(s)),u):l},u.context=function(t){return arguments.length?(null==t?s=c=null:c=l(s=t),u):s},u}function S(t,e){return e<t?-1:e>t?1:e>=t?0:NaN}function E(t){return t}_.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._point=0},lineEnd:function(){(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:this._context.lineTo(t,e)}}};var C=P(w);function L(t){this._curve=t}function P(t){function e(e){return new L(t(e))}return e._curve=t,e}function O(t){var e=t.curve;return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function z(){return O(A().curve(C))}function I(){var t=M().curve(C),e=t.curve,r=t.lineX0,n=t.lineX1,i=t.lineY0,a=t.lineY1;return t.angle=t.x,delete t.x,t.startAngle=t.x0,delete t.x0,t.endAngle=t.x1,delete t.x1,t.radius=t.y,delete t.y,t.innerRadius=t.y0,delete t.y0,t.outerRadius=t.y1,delete t.y1,t.lineStartAngle=function(){return O(r())},delete t.lineX0,t.lineEndAngle=function(){return O(n())},delete t.lineX1,t.lineInnerRadius=function(){return O(i())},delete t.lineY0,t.lineOuterRadius=function(){return O(a())},delete t.lineY1,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function D(t,e){return[(e=+e)*Math.cos(t-=Math.PI/2),e*Math.sin(t)]}L.prototype={areaStart:function(){this._curve.areaStart()},areaEnd:function(){this._curve.areaEnd()},lineStart:function(){this._curve.lineStart()},lineEnd:function(){this._curve.lineEnd()},point:function(t,e){this._curve.point(e*Math.sin(t),e*-Math.cos(t))}};var R=Array.prototype.slice;function F(t){return t.source}function B(t){return t.target}function N(t){var n=F,i=B,a=k,o=T,s=null;function l(){var r,l=R.call(arguments),c=n.apply(this,l),u=i.apply(this,l);if(s||(s=r=e.path()),t(s,+a.apply(this,(l[0]=c,l)),+o.apply(this,l),+a.apply(this,(l[0]=u,l)),+o.apply(this,l)),r)return s=null,r+\"\"||null}return l.source=function(t){return arguments.length?(n=t,l):n},l.target=function(t){return arguments.length?(i=t,l):i},l.x=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),l):a},l.y=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),l):o},l.context=function(t){return arguments.length?(s=null==t?null:t,l):s},l}function j(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e=(e+n)/2,r,e,i,n,i)}function U(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e,r=(r+i)/2,n,r,n,i)}function V(t,e,r,n,i){var a=D(e,r),o=D(e,r=(r+i)/2),s=D(n,r),l=D(n,i);t.moveTo(a[0],a[1]),t.bezierCurveTo(o[0],o[1],s[0],s[1],l[0],l[1])}var q={draw:function(t,e){var r=Math.sqrt(e/h);t.moveTo(r,0),t.arc(0,0,r,0,p)}},H={draw:function(t,e){var r=Math.sqrt(e/5)/2;t.moveTo(-3*r,-r),t.lineTo(-r,-r),t.lineTo(-r,-3*r),t.lineTo(r,-3*r),t.lineTo(r,-r),t.lineTo(3*r,-r),t.lineTo(3*r,r),t.lineTo(r,r),t.lineTo(r,3*r),t.lineTo(-r,3*r),t.lineTo(-r,r),t.lineTo(-3*r,r),t.closePath()}},G=Math.sqrt(1/3),Y=2*G,W={draw:function(t,e){var r=Math.sqrt(e/Y),n=r*G;t.moveTo(0,-r),t.lineTo(n,0),t.lineTo(0,r),t.lineTo(-n,0),t.closePath()}},X=Math.sin(h/10)/Math.sin(7*h/10),Z=Math.sin(p/10)*X,J=-Math.cos(p/10)*X,K={draw:function(t,e){var r=Math.sqrt(.8908130915292852*e),n=Z*r,i=J*r;t.moveTo(0,-r),t.lineTo(n,i);for(var a=1;a<5;++a){var o=p*a/5,s=Math.cos(o),l=Math.sin(o);t.lineTo(l*r,-s*r),t.lineTo(s*n-l*i,l*n+s*i)}t.closePath()}},$={draw:function(t,e){var r=Math.sqrt(e),n=-r/2;t.rect(n,n,r,r)}},Q=Math.sqrt(3),tt={draw:function(t,e){var r=-Math.sqrt(e/(3*Q));t.moveTo(0,2*r),t.lineTo(-Q*r,-r),t.lineTo(Q*r,-r),t.closePath()}},et=-.5,rt=Math.sqrt(3)/2,nt=1/Math.sqrt(12),it=3*(nt/2+1),at={draw:function(t,e){var r=Math.sqrt(e/it),n=r/2,i=r*nt,a=n,o=r*nt+r,s=-a,l=o;t.moveTo(n,i),t.lineTo(a,o),t.lineTo(s,l),t.lineTo(et*n-rt*i,rt*n+et*i),t.lineTo(et*a-rt*o,rt*a+et*o),t.lineTo(et*s-rt*l,rt*s+et*l),t.lineTo(et*n+rt*i,et*i-rt*n),t.lineTo(et*a+rt*o,et*o-rt*a),t.lineTo(et*s+rt*l,et*l-rt*s),t.closePath()}},ot=[q,H,W,$,K,tt,at];function st(){}function lt(t,e,r){t._context.bezierCurveTo((2*t._x0+t._x1)/3,(2*t._y0+t._y1)/3,(t._x0+2*t._x1)/3,(t._y0+2*t._y1)/3,(t._x0+4*t._x1+e)/6,(t._y0+4*t._y1+r)/6)}function ct(t){this._context=t}function ut(t){this._context=t}function ht(t){this._context=t}function ft(t,e){this._basis=new ct(t),this._beta=e}ct.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){switch(this._point){case 3:lt(this,this._x1,this._y1);case 2:this._context.lineTo(this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,this._context.lineTo((5*this._x0+this._x1)/6,(5*this._y0+this._y1)/6);default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ut.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._y0=this._y1=this._y2=this._y3=this._y4=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x2,this._y2),this._context.closePath();break;case 2:this._context.moveTo((this._x2+2*this._x3)/3,(this._y2+2*this._y3)/3),this._context.lineTo((this._x3+2*this._x2)/3,(this._y3+2*this._y2)/3),this._context.closePath();break;case 3:this.point(this._x2,this._y2),this.point(this._x3,this._y3),this.point(this._x4,this._y4)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x2=t,this._y2=e;break;case 1:this._point=2,this._x3=t,this._y3=e;break;case 2:this._point=3,this._x4=t,this._y4=e,this._context.moveTo((this._x0+4*this._x1+t)/6,(this._y0+4*this._y1+e)/6);break;default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ht.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3;var r=(this._x0+4*this._x1+t)/6,n=(this._y0+4*this._y1+e)/6;this._line?this._context.lineTo(r,n):this._context.moveTo(r,n);break;case 3:this._point=4;default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ft.prototype={lineStart:function(){this._x=[],this._y=[],this._basis.lineStart()},lineEnd:function(){var t=this._x,e=this._y,r=t.length-1;if(r>0)for(var n,i=t[0],a=e[0],o=t[r]-i,s=e[r]-a,l=-1;++l<=r;)n=l/r,this._basis.point(this._beta*t[l]+(1-this._beta)*(i+n*o),this._beta*e[l]+(1-this._beta)*(a+n*s));this._x=this._y=null,this._basis.lineEnd()},point:function(t,e){this._x.push(+t),this._y.push(+e)}};var pt=function t(e){function r(t){return 1===e?new ct(t):new ft(t,e)}return r.beta=function(e){return t(+e)},r}(.85);function dt(t,e,r){t._context.bezierCurveTo(t._x1+t._k*(t._x2-t._x0),t._y1+t._k*(t._y2-t._y0),t._x2+t._k*(t._x1-e),t._y2+t._k*(t._y1-r),t._x2,t._y2)}function gt(t,e){this._context=t,this._k=(1-e)/6}gt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:dt(this,this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2,this._x1=t,this._y1=e;break;case 2:this._point=3;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var vt=function t(e){function r(t){return new gt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function mt(t,e){this._context=t,this._k=(1-e)/6}mt.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var yt=function t(e){function r(t){return new mt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function xt(t,e){this._context=t,this._k=(1-e)/6}xt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var bt=function t(e){function r(t){return new xt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function _t(t,e,r){var n=t._x1,i=t._y1,a=t._x2,o=t._y2;if(t._l01_a>u){var s=2*t._l01_2a+3*t._l01_a*t._l12_a+t._l12_2a,l=3*t._l01_a*(t._l01_a+t._l12_a);n=(n*s-t._x0*t._l12_2a+t._x2*t._l01_2a)/l,i=(i*s-t._y0*t._l12_2a+t._y2*t._l01_2a)/l}if(t._l23_a>u){var c=2*t._l23_2a+3*t._l23_a*t._l12_a+t._l12_2a,h=3*t._l23_a*(t._l23_a+t._l12_a);a=(a*c+t._x1*t._l23_2a-e*t._l12_2a)/h,o=(o*c+t._y1*t._l23_2a-r*t._l12_2a)/h}t._context.bezierCurveTo(n,i,a,o,t._x2,t._y2)}function wt(t,e){this._context=t,this._alpha=e}wt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:this.point(this._x2,this._y2)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var kt=function t(e){function r(t){return e?new wt(t,e):new gt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Tt(t,e){this._context=t,this._alpha=e}Tt.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var At=function t(e){function r(t){return e?new Tt(t,e):new mt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Mt(t,e){this._context=t,this._alpha=e}Mt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var St=function t(e){function r(t){return e?new Mt(t,e):new xt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Et(t){this._context=t}function Ct(t){return t<0?-1:1}function Lt(t,e,r){var n=t._x1-t._x0,i=e-t._x1,a=(t._y1-t._y0)/(n||i<0&&-0),o=(r-t._y1)/(i||n<0&&-0),s=(a*i+o*n)/(n+i);return(Ct(a)+Ct(o))*Math.min(Math.abs(a),Math.abs(o),.5*Math.abs(s))||0}function Pt(t,e){var r=t._x1-t._x0;return r?(3*(t._y1-t._y0)/r-e)/2:e}function Ot(t,e,r){var n=t._x0,i=t._y0,a=t._x1,o=t._y1,s=(a-n)/3;t._context.bezierCurveTo(n+s,i+s*e,a-s,o-s*r,a,o)}function zt(t){this._context=t}function It(t){this._context=new Dt(t)}function Dt(t){this._context=t}function Rt(t){this._context=t}function Ft(t){var e,r,n=t.length-1,i=new Array(n),a=new Array(n),o=new Array(n);for(i[0]=0,a[0]=2,o[0]=t[0]+2*t[1],e=1;e<n-1;++e)i[e]=1,a[e]=4,o[e]=4*t[e]+2*t[e+1];for(i[n-1]=2,a[n-1]=7,o[n-1]=8*t[n-1]+t[n],e=1;e<n;++e)r=i[e]/a[e-1],a[e]-=r,o[e]-=r*o[e-1];for(i[n-1]=o[n-1]/a[n-1],e=n-2;e>=0;--e)i[e]=(o[e]-i[e+1])/a[e];for(a[n-1]=(t[n]+i[n-1])/2,e=0;e<n-1;++e)a[e]=2*t[e+1]-i[e+1];return[i,a]}function Bt(t,e){this._context=t,this._t=e}function Nt(t,e){if((i=t.length)>1)for(var r,n,i,a=1,o=t[e[0]],s=o.length;a<i;++a)for(n=o,o=t[e[a]],r=0;r<s;++r)o[r][1]+=o[r][0]=isNaN(n[r][1])?n[r][0]:n[r][1]}function jt(t){for(var e=t.length,r=new Array(e);--e>=0;)r[e]=e;return r}function Ut(t,e){return t[e]}function Vt(t){var e=t.map(qt);return jt(t).sort(function(t,r){return e[t]-e[r]})}function qt(t){for(var e,r=-1,n=0,i=t.length,a=-1/0;++r<i;)(e=+t[r][1])>a&&(a=e,n=r);return n}function Ht(t){var e=t.map(Gt);return jt(t).sort(function(t,r){return e[t]-e[r]})}function Gt(t){for(var e,r=0,n=-1,i=t.length;++n<i;)(e=+t[n][1])&&(r+=e);return r}Et.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._point=0},lineEnd:function(){this._point&&this._context.closePath()},point:function(t,e){t=+t,e=+e,this._point?this._context.lineTo(t,e):(this._point=1,this._context.moveTo(t,e))}},zt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=this._t0=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x1,this._y1);break;case 3:Ot(this,this._t0,Pt(this,this._t0))}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){var r=NaN;if(e=+e,(t=+t)!==this._x1||e!==this._y1){switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,Ot(this,Pt(this,r=Lt(this,t,e)),r);break;default:Ot(this,this._t0,r=Lt(this,t,e))}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e,this._t0=r}}},(It.prototype=Object.create(zt.prototype)).point=function(t,e){zt.prototype.point.call(this,e,t)},Dt.prototype={moveTo:function(t,e){this._context.moveTo(e,t)},closePath:function(){this._context.closePath()},lineTo:function(t,e){this._context.lineTo(e,t)},bezierCurveTo:function(t,e,r,n,i,a){this._context.bezierCurveTo(e,t,n,r,a,i)}},Rt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=[],this._y=[]},lineEnd:function(){var t=this._x,e=this._y,r=t.length;if(r)if(this._line?this._context.lineTo(t[0],e[0]):this._context.moveTo(t[0],e[0]),2===r)this._context.lineTo(t[1],e[1]);else for(var n=Ft(t),i=Ft(e),a=0,o=1;o<r;++a,++o)this._context.bezierCurveTo(n[0][a],i[0][a],n[1][a],i[1][a],t[o],e[o]);(this._line||0!==this._line&&1===r)&&this._context.closePath(),this._line=1-this._line,this._x=this._y=null},point:function(t,e){this._x.push(+t),this._y.push(+e)}},Bt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=this._y=NaN,this._point=0},lineEnd:function(){0<this._t&&this._t<1&&2===this._point&&this._context.lineTo(this._x,this._y),(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line>=0&&(this._t=1-this._t,this._line=1-this._line)},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:if(this._t<=0)this._context.lineTo(this._x,e),this._context.lineTo(t,e);else{var r=this._x*(1-this._t)+t*this._t;this._context.lineTo(r,this._y),this._context.lineTo(r,e)}}this._x=t,this._y=e}},t.arc=function(){var t=g,o=v,_=r(0),w=null,k=m,T=y,A=x,M=null;function S(){var r,g,v,m=+t.apply(this,arguments),y=+o.apply(this,arguments),x=k.apply(this,arguments)-f,S=T.apply(this,arguments)-f,E=n(S-x),C=S>x;if(M||(M=r=e.path()),y<m&&(g=y,y=m,m=g),y>u)if(E>p-u)M.moveTo(y*a(x),y*l(x)),M.arc(0,0,y,x,S,!C),m>u&&(M.moveTo(m*a(S),m*l(S)),M.arc(0,0,m,S,x,C));else{var L,P,O=x,z=S,I=x,D=S,R=E,F=E,B=A.apply(this,arguments)/2,N=B>u&&(w?+w.apply(this,arguments):c(m*m+y*y)),j=s(n(y-m)/2,+_.apply(this,arguments)),U=j,V=j;if(N>u){var q=d(N/m*l(B)),H=d(N/y*l(B));(R-=2*q)>u?(I+=q*=C?1:-1,D-=q):(R=0,I=D=(x+S)/2),(F-=2*H)>u?(O+=H*=C?1:-1,z-=H):(F=0,O=z=(x+S)/2)}var G=y*a(O),Y=y*l(O),W=m*a(D),X=m*l(D);if(j>u){var Z,J=y*a(z),K=y*l(z),$=m*a(I),Q=m*l(I);if(E<h&&(Z=function(t,e,r,n,i,a,o,s){var l=r-t,c=n-e,h=o-i,f=s-a,p=f*l-h*c;if(!(p*p<u))return[t+(p=(h*(e-a)-f*(t-i))/p)*l,e+p*c]}(G,Y,$,Q,J,K,W,X))){var tt=G-Z[0],et=Y-Z[1],rt=J-Z[0],nt=K-Z[1],it=1/l(((v=(tt*rt+et*nt)/(c(tt*tt+et*et)*c(rt*rt+nt*nt)))>1?0:v<-1?h:Math.acos(v))/2),at=c(Z[0]*Z[0]+Z[1]*Z[1]);U=s(j,(m-at)/(it-1)),V=s(j,(y-at)/(it+1))}}F>u?V>u?(L=b($,Q,G,Y,y,V,C),P=b(J,K,W,X,y,V,C),M.moveTo(L.cx+L.x01,L.cy+L.y01),V<j?M.arc(L.cx,L.cy,V,i(L.y01,L.x01),i(P.y01,P.x01),!C):(M.arc(L.cx,L.cy,V,i(L.y01,L.x01),i(L.y11,L.x11),!C),M.arc(0,0,y,i(L.cy+L.y11,L.cx+L.x11),i(P.cy+P.y11,P.cx+P.x11),!C),M.arc(P.cx,P.cy,V,i(P.y11,P.x11),i(P.y01,P.x01),!C))):(M.moveTo(G,Y),M.arc(0,0,y,O,z,!C)):M.moveTo(G,Y),m>u&&R>u?U>u?(L=b(W,X,J,K,m,-U,C),P=b(G,Y,$,Q,m,-U,C),M.lineTo(L.cx+L.x01,L.cy+L.y01),U<j?M.arc(L.cx,L.cy,U,i(L.y01,L.x01),i(P.y01,P.x01),!C):(M.arc(L.cx,L.cy,U,i(L.y01,L.x01),i(L.y11,L.x11),!C),M.arc(0,0,m,i(L.cy+L.y11,L.cx+L.x11),i(P.cy+P.y11,P.cx+P.x11),C),M.arc(P.cx,P.cy,U,i(P.y11,P.x11),i(P.y01,P.x01),!C))):M.arc(0,0,m,D,I,C):M.lineTo(W,X)}else M.moveTo(0,0);if(M.closePath(),r)return M=null,r+\"\"||null}return S.centroid=function(){var e=(+t.apply(this,arguments)+ +o.apply(this,arguments))/2,r=(+k.apply(this,arguments)+ +T.apply(this,arguments))/2-h/2;return[a(r)*e,l(r)*e]},S.innerRadius=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),S):t},S.outerRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),S):o},S.cornerRadius=function(t){return arguments.length?(_=\"function\"==typeof t?t:r(+t),S):_},S.padRadius=function(t){return arguments.length?(w=null==t?null:\"function\"==typeof t?t:r(+t),S):w},S.startAngle=function(t){return arguments.length?(k=\"function\"==typeof t?t:r(+t),S):k},S.endAngle=function(t){return arguments.length?(T=\"function\"==typeof t?t:r(+t),S):T},S.padAngle=function(t){return arguments.length?(A=\"function\"==typeof t?t:r(+t),S):A},S.context=function(t){return arguments.length?(M=null==t?null:t,S):M},S},t.area=M,t.line=A,t.pie=function(){var t=E,e=S,n=null,i=r(0),a=r(p),o=r(0);function s(r){var s,l,c,u,h,f=r.length,d=0,g=new Array(f),v=new Array(f),m=+i.apply(this,arguments),y=Math.min(p,Math.max(-p,a.apply(this,arguments)-m)),x=Math.min(Math.abs(y)/f,o.apply(this,arguments)),b=x*(y<0?-1:1);for(s=0;s<f;++s)(h=v[g[s]=s]=+t(r[s],s,r))>0&&(d+=h);for(null!=e?g.sort(function(t,r){return e(v[t],v[r])}):null!=n&&g.sort(function(t,e){return n(r[t],r[e])}),s=0,c=d?(y-f*b)/d:0;s<f;++s,m=u)l=g[s],u=m+((h=v[l])>0?h*c:0)+b,v[l]={data:r[l],index:s,value:h,startAngle:m,endAngle:u,padAngle:x};return v}return s.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),s):t},s.sortValues=function(t){return arguments.length?(e=t,n=null,s):e},s.sort=function(t){return arguments.length?(n=t,e=null,s):n},s.startAngle=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),s):i},s.endAngle=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),s):a},s.padAngle=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),s):o},s},t.areaRadial=I,t.radialArea=I,t.lineRadial=z,t.radialLine=z,t.pointRadial=D,t.linkHorizontal=function(){return N(j)},t.linkVertical=function(){return N(U)},t.linkRadial=function(){var t=N(V);return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t},t.symbol=function(){var t=r(q),n=r(64),i=null;function a(){var r;if(i||(i=r=e.path()),t.apply(this,arguments).draw(i,+n.apply(this,arguments)),r)return i=null,r+\"\"||null}return a.type=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(e),a):t},a.size=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),a):n},a.context=function(t){return arguments.length?(i=null==t?null:t,a):i},a},t.symbols=ot,t.symbolCircle=q,t.symbolCross=H,t.symbolDiamond=W,t.symbolSquare=$,t.symbolStar=K,t.symbolTriangle=tt,t.symbolWye=at,t.curveBasisClosed=function(t){return new ut(t)},t.curveBasisOpen=function(t){return new ht(t)},t.curveBasis=function(t){return new ct(t)},t.curveBundle=pt,t.curveCardinalClosed=yt,t.curveCardinalOpen=bt,t.curveCardinal=vt,t.curveCatmullRomClosed=At,t.curveCatmullRomOpen=St,t.curveCatmullRom=kt,t.curveLinearClosed=function(t){return new Et(t)},t.curveLinear=w,t.curveMonotoneX=function(t){return new zt(t)},t.curveMonotoneY=function(t){return new It(t)},t.curveNatural=function(t){return new Rt(t)},t.curveStep=function(t){return new Bt(t,.5)},t.curveStepAfter=function(t){return new Bt(t,1)},t.curveStepBefore=function(t){return new Bt(t,0)},t.stack=function(){var t=r([]),e=jt,n=Nt,i=Ut;function a(r){var a,o,s=t.apply(this,arguments),l=r.length,c=s.length,u=new Array(c);for(a=0;a<c;++a){for(var h,f=s[a],p=u[a]=new Array(l),d=0;d<l;++d)p[d]=h=[0,+i(r[d],f,d,r)],h.data=r[d];p.key=f}for(a=0,o=e(u);a<c;++a)u[o[a]].index=a;return n(u,o),u}return a.keys=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(R.call(e)),a):t},a.value=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a):i},a.order=function(t){return arguments.length?(e=null==t?jt:\"function\"==typeof t?t:r(R.call(t)),a):e},a.offset=function(t){return arguments.length?(n=null==t?Nt:t,a):n},a},t.stackOffsetExpand=function(t,e){if((n=t.length)>0){for(var r,n,i,a=0,o=t[0].length;a<o;++a){for(i=r=0;r<n;++r)i+=t[r][a][1]||0;if(i)for(r=0;r<n;++r)t[r][a][1]/=i}Nt(t,e)}},t.stackOffsetDiverging=function(t,e){if((s=t.length)>1)for(var r,n,i,a,o,s,l=0,c=t[e[0]].length;l<c;++l)for(a=o=0,r=0;r<s;++r)(i=(n=t[e[r]][l])[1]-n[0])>=0?(n[0]=a,n[1]=a+=i):i<0?(n[1]=o,n[0]=o+=i):n[0]=a},t.stackOffsetNone=Nt,t.stackOffsetSilhouette=function(t,e){if((r=t.length)>0){for(var r,n=0,i=t[e[0]],a=i.length;n<a;++n){for(var o=0,s=0;o<r;++o)s+=t[o][n][1]||0;i[n][1]+=i[n][0]=-s/2}Nt(t,e)}},t.stackOffsetWiggle=function(t,e){if((i=t.length)>0&&(n=(r=t[e[0]]).length)>0){for(var r,n,i,a=0,o=1;o<n;++o){for(var s=0,l=0,c=0;s<i;++s){for(var u=t[e[s]],h=u[o][1]||0,f=(h-(u[o-1][1]||0))/2,p=0;p<s;++p){var d=t[e[p]];f+=(d[o][1]||0)-(d[o-1][1]||0)}l+=h,c+=f*h}r[o-1][1]+=r[o-1][0]=a,l&&(a-=c/l)}r[o-1][1]+=r[o-1][0]=a,Nt(t,e)}},t.stackOrderAppearance=Vt,t.stackOrderAscending=Ht,t.stackOrderDescending=function(t){return Ht(t).reverse()},t.stackOrderInsideOut=function(t){var e,r,n=t.length,i=t.map(Gt),a=Vt(t),o=0,s=0,l=[],c=[];for(e=0;e<n;++e)r=a[e],o<s?(o+=i[r],l.push(r)):(s+=i[r],c.push(r));return c.reverse().concat(l)},t.stackOrderNone=jt,t.stackOrderReverse=function(t){return jt(t).reverse()},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-path\")):i(n.d3=n.d3||{},n.d3)},{\"d3-path\":159}],162:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e,r,n=0,i=0,a=0,o=1e3,s=0,l=0,c=0,u=\"object\"==typeof performance&&performance.now?performance:Date,h=\"object\"==typeof window&&window.requestAnimationFrame?window.requestAnimationFrame.bind(window):function(t){setTimeout(t,17)};function f(){return l||(h(p),l=u.now()+c)}function p(){l=0}function d(){this._call=this._time=this._next=null}function g(t,e,r){var n=new d;return n.restart(t,e,r),n}function v(){f(),++n;for(var t,r=e;r;)(t=l-r._time)>=0&&r._call.call(null,t),r=r._next;--n}function m(){l=(s=u.now())+c,n=i=0;try{v()}finally{n=0,function(){var t,n,i=e,a=1/0;for(;i;)i._call?(a>i._time&&(a=i._time),t=i,i=i._next):(n=i._next,i._next=null,i=t?t._next=n:e=n);r=t,x(a)}(),l=0}}function y(){var t=u.now(),e=t-s;e>o&&(c-=e,s=t)}function x(t){n||(i&&(i=clearTimeout(i)),t-l>24?(t<1/0&&(i=setTimeout(m,t-u.now()-c)),a&&(a=clearInterval(a))):(a||(s=u.now(),a=setInterval(y,o)),n=1,h(m)))}d.prototype=g.prototype={constructor:d,restart:function(t,n,i){if(\"function\"!=typeof t)throw new TypeError(\"callback is not a function\");i=(null==i?f():+i)+(null==n?0:+n),this._next||r===this||(r?r._next=this:e=this,r=this),this._call=t,this._time=i,x()},stop:function(){this._call&&(this._call=null,this._time=1/0,x())}};t.now=f,t.timer=g,t.timerFlush=v,t.timeout=function(t,e,r){var n=new d;return e=null==e?0:+e,n.restart(function(r){n.stop(),t(r+e)},e,r),n},t.interval=function(t,e,r){var n=new d,i=e;return null==e?(n.restart(t,e,r),n):(e=+e,r=null==r?f():+r,n.restart(function a(o){o+=i,n.restart(a,i+=e,r),t(o)},e,r),n)},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],163:[function(t,e,r){!function(){var t={version:\"3.5.17\"},r=[].slice,n=function(t){return r.call(t)},i=this.document;function a(t){return t&&(t.ownerDocument||t.document||t).documentElement}function o(t){return t&&(t.ownerDocument&&t.ownerDocument.defaultView||t.document&&t||t.defaultView)}if(i)try{n(i.documentElement.childNodes)[0].nodeType}catch(t){n=function(t){for(var e=t.length,r=new Array(e);e--;)r[e]=t[e];return r}}if(Date.now||(Date.now=function(){return+new Date}),i)try{i.createElement(\"DIV\").style.setProperty(\"opacity\",0,\"\")}catch(t){var s=this.Element.prototype,l=s.setAttribute,c=s.setAttributeNS,u=this.CSSStyleDeclaration.prototype,h=u.setProperty;s.setAttribute=function(t,e){l.call(this,t,e+\"\")},s.setAttributeNS=function(t,e,r){c.call(this,t,e,r+\"\")},u.setProperty=function(t,e,r){h.call(this,t,e+\"\",r)}}function f(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function p(t){return null===t?NaN:+t}function d(t){return!isNaN(t)}function g(t){return{left:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}t.ascending=f,t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.min=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&r>n&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&r>n&&(r=n)}return r},t.max=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&n>r&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&n>r&&(r=n)}return r},t.extent=function(t,e){var r,n,i,a=-1,o=t.length;if(1===arguments.length){for(;++a<o;)if(null!=(n=t[a])&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=t[a])&&(r>n&&(r=n),i<n&&(i=n))}else{for(;++a<o;)if(null!=(n=e.call(t,t[a],a))&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=e.call(t,t[a],a))&&(r>n&&(r=n),i<n&&(i=n))}return[r,i]},t.sum=function(t,e){var r,n=0,i=t.length,a=-1;if(1===arguments.length)for(;++a<i;)d(r=+t[a])&&(n+=r);else for(;++a<i;)d(r=+e.call(t,t[a],a))&&(n+=r);return n},t.mean=function(t,e){var r,n=0,i=t.length,a=-1,o=i;if(1===arguments.length)for(;++a<i;)d(r=p(t[a]))?n+=r:--o;else for(;++a<i;)d(r=p(e.call(t,t[a],a)))?n+=r:--o;if(o)return n/o},t.quantile=function(t,e){var r=(t.length-1)*e+1,n=Math.floor(r),i=+t[n-1],a=r-n;return a?i+a*(t[n]-i):i},t.median=function(e,r){var n,i=[],a=e.length,o=-1;if(1===arguments.length)for(;++o<a;)d(n=p(e[o]))&&i.push(n);else for(;++o<a;)d(n=p(r.call(e,e[o],o)))&&i.push(n);if(i.length)return t.quantile(i.sort(f),.5)},t.variance=function(t,e){var r,n,i=t.length,a=0,o=0,s=-1,l=0;if(1===arguments.length)for(;++s<i;)d(r=p(t[s]))&&(o+=(n=r-a)*(r-(a+=n/++l)));else for(;++s<i;)d(r=p(e.call(t,t[s],s)))&&(o+=(n=r-a)*(r-(a+=n/++l)));if(l>1)return o/(l-1)},t.deviation=function(){var e=t.variance.apply(this,arguments);return e?Math.sqrt(e):e};var v=g(f);function m(t){return t.length}t.bisectLeft=v.left,t.bisect=t.bisectRight=v.right,t.bisector=function(t){return g(1===t.length?function(e,r){return f(t(e),r)}:t)},t.shuffle=function(t,e,r){(a=arguments.length)<3&&(r=t.length,a<2&&(e=0));for(var n,i,a=r-e;a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.pairs=function(t){for(var e=0,r=t.length-1,n=t[0],i=new Array(r<0?0:r);e<r;)i[e]=[n,n=t[++e]];return i},t.transpose=function(e){if(!(a=e.length))return[];for(var r=-1,n=t.min(e,m),i=new Array(n);++r<n;)for(var a,o=-1,s=i[r]=new Array(a);++o<a;)s[o]=e[o][r];return i},t.zip=function(){return t.transpose(arguments)},t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r};var y=Math.abs;function x(t,e){for(var r in e)Object.defineProperty(t.prototype,r,{value:e[r],enumerable:!1})}function b(){this._=Object.create(null)}t.range=function(t,e,r){if(arguments.length<3&&(r=1,arguments.length<2&&(e=t,t=0)),(e-t)/r==1/0)throw new Error(\"infinite range\");var n,i=[],a=function(t){var e=1;for(;t*e%1;)e*=10;return e}(y(r)),o=-1;if(t*=a,e*=a,(r*=a)<0)for(;(n=t+r*++o)>e;)i.push(n/a);else for(;(n=t+r*++o)<e;)i.push(n/a);return i},t.map=function(t,e){var r=new b;if(t instanceof b)t.forEach(function(t,e){r.set(t,e)});else if(Array.isArray(t)){var n,i=-1,a=t.length;if(1===arguments.length)for(;++i<a;)r.set(i,t[i]);else for(;++i<a;)r.set(e.call(t,n=t[i],i),n)}else for(var o in t)r.set(o,t[o]);return r};var _=\"__proto__\",w=\"\\0\";function k(t){return(t+=\"\")===_||t[0]===w?w+t:t}function T(t){return(t+=\"\")[0]===w?t.slice(1):t}function A(t){return k(t)in this._}function M(t){return(t=k(t))in this._&&delete this._[t]}function S(){var t=[];for(var e in this._)t.push(T(e));return t}function E(){var t=0;for(var e in this._)++t;return t}function C(){for(var t in this._)return!1;return!0}function L(){this._=Object.create(null)}function P(t){return t}function O(t,e,r){return function(){var n=r.apply(e,arguments);return n===e?t:n}}function z(t,e){if(e in t)return e;e=e.charAt(0).toUpperCase()+e.slice(1);for(var r=0,n=I.length;r<n;++r){var i=I[r]+e;if(i in t)return i}}x(b,{has:A,get:function(t){return this._[k(t)]},set:function(t,e){return this._[k(t)]=e},remove:M,keys:S,values:function(){var t=[];for(var e in this._)t.push(this._[e]);return t},entries:function(){var t=[];for(var e in this._)t.push({key:T(e),value:this._[e]});return t},size:E,empty:C,forEach:function(t){for(var e in this._)t.call(this,T(e),this._[e])}}),t.nest=function(){var e,r,n={},i=[],a=[];function o(t,a,s){if(s>=i.length)return r?r.call(n,a):e?a.sort(e):a;for(var l,c,u,h,f=-1,p=a.length,d=i[s++],g=new b;++f<p;)(h=g.get(l=d(c=a[f])))?h.push(c):g.set(l,[c]);return t?(c=t(),u=function(e,r){c.set(e,o(t,r,s))}):(c={},u=function(e,r){c[e]=o(t,r,s)}),g.forEach(u),c}return n.map=function(t,e){return o(e,t,0)},n.entries=function(e){return function t(e,r){if(r>=i.length)return e;var n=[],o=a[r++];return e.forEach(function(e,i){n.push({key:e,values:t(i,r)})}),o?n.sort(function(t,e){return o(t.key,e.key)}):n}(o(t.map,e,0),0)},n.key=function(t){return i.push(t),n},n.sortKeys=function(t){return a[i.length-1]=t,n},n.sortValues=function(t){return e=t,n},n.rollup=function(t){return r=t,n},n},t.set=function(t){var e=new L;if(t)for(var r=0,n=t.length;r<n;++r)e.add(t[r]);return e},x(L,{has:A,add:function(t){return this._[k(t+=\"\")]=!0,t},remove:M,values:S,size:E,empty:C,forEach:function(t){for(var e in this._)t.call(this,T(e))}}),t.behavior={},t.rebind=function(t,e){for(var r,n=1,i=arguments.length;++n<i;)t[r=arguments[n]]=O(t,e,e[r]);return t};var I=[\"webkit\",\"ms\",\"moz\",\"Moz\",\"o\",\"O\"];function D(){}function R(){}function F(t){var e=[],r=new b;function n(){for(var r,n=e,i=-1,a=n.length;++i<a;)(r=n[i].on)&&r.apply(this,arguments);return t}return n.on=function(n,i){var a,o=r.get(n);return arguments.length<2?o&&o.on:(o&&(o.on=null,e=e.slice(0,a=e.indexOf(o)).concat(e.slice(a+1)),r.remove(n)),i&&e.push(r.set(n,{on:i})),t)},n}function B(){t.event.preventDefault()}function N(){for(var e,r=t.event;e=r.sourceEvent;)r=e;return r}function j(e){for(var r=new R,n=0,i=arguments.length;++n<i;)r[arguments[n]]=F(r);return r.of=function(n,i){return function(a){try{var o=a.sourceEvent=t.event;a.target=e,t.event=a,r[a.type].apply(n,i)}finally{t.event=o}}},r}t.dispatch=function(){for(var t=new R,e=-1,r=arguments.length;++e<r;)t[arguments[e]]=F(t);return t},R.prototype.on=function(t,e){var r=t.indexOf(\".\"),n=\"\";if(r>=0&&(n=t.slice(r+1),t=t.slice(0,r)),t)return arguments.length<2?this[t].on(n):this[t].on(n,e);if(2===arguments.length){if(null==e)for(t in this)this.hasOwnProperty(t)&&this[t].on(n,null);return this}},t.event=null,t.requote=function(t){return t.replace(U,\"\\\\$&\")};var U=/[\\\\\\^\\$\\*\\+\\?\\|\\[\\]\\(\\)\\.\\{\\}]/g,V={}.__proto__?function(t,e){t.__proto__=e}:function(t,e){for(var r in e)t[r]=e[r]};function q(t){return V(t,W),t}var H=function(t,e){return e.querySelector(t)},G=function(t,e){return e.querySelectorAll(t)},Y=function(t,e){var r=t.matches||t[z(t,\"matchesSelector\")];return(Y=function(t,e){return r.call(t,e)})(t,e)};\"function\"==typeof Sizzle&&(H=function(t,e){return Sizzle(t,e)[0]||null},G=Sizzle,Y=Sizzle.matchesSelector),t.selection=function(){return t.select(i.documentElement)};var W=t.selection.prototype=[];function X(t){return\"function\"==typeof t?t:function(){return H(t,this)}}function Z(t){return\"function\"==typeof t?t:function(){return G(t,this)}}W.select=function(t){var e,r,n,i,a=[];t=X(t);for(var o=-1,s=this.length;++o<s;){a.push(e=[]),e.parentNode=(n=this[o]).parentNode;for(var l=-1,c=n.length;++l<c;)(i=n[l])?(e.push(r=t.call(i,i.__data__,l,o)),r&&\"__data__\"in i&&(r.__data__=i.__data__)):e.push(null)}return q(a)},W.selectAll=function(t){var e,r,i=[];t=Z(t);for(var a=-1,o=this.length;++a<o;)for(var s=this[a],l=-1,c=s.length;++l<c;)(r=s[l])&&(i.push(e=n(t.call(r,r.__data__,l,a))),e.parentNode=r);return q(i)};var J=\"http://www.w3.org/1999/xhtml\",K={svg:\"http://www.w3.org/2000/svg\",xhtml:J,xlink:\"http://www.w3.org/1999/xlink\",xml:\"http://www.w3.org/XML/1998/namespace\",xmlns:\"http://www.w3.org/2000/xmlns/\"};function $(e,r){return e=t.ns.qualify(e),null==r?e.local?function(){this.removeAttributeNS(e.space,e.local)}:function(){this.removeAttribute(e)}:\"function\"==typeof r?e.local?function(){var t=r.apply(this,arguments);null==t?this.removeAttributeNS(e.space,e.local):this.setAttributeNS(e.space,e.local,t)}:function(){var t=r.apply(this,arguments);null==t?this.removeAttribute(e):this.setAttribute(e,t)}:e.local?function(){this.setAttributeNS(e.space,e.local,r)}:function(){this.setAttribute(e,r)}}function Q(t){return t.trim().replace(/\\s+/g,\" \")}function tt(e){return new RegExp(\"(?:^|\\\\s+)\"+t.requote(e)+\"(?:\\\\s+|$)\",\"g\")}function et(t){return(t+\"\").trim().split(/^|\\s+/)}function rt(t,e){var r=(t=et(t).map(nt)).length;return\"function\"==typeof e?function(){for(var n=-1,i=e.apply(this,arguments);++n<r;)t[n](this,i)}:function(){for(var n=-1;++n<r;)t[n](this,e)}}function nt(t){var e=tt(t);return function(r,n){if(i=r.classList)return n?i.add(t):i.remove(t);var i=r.getAttribute(\"class\")||\"\";n?(e.lastIndex=0,e.test(i)||r.setAttribute(\"class\",Q(i+\" \"+t))):r.setAttribute(\"class\",Q(i.replace(e,\" \")))}}function it(t,e,r){return null==e?function(){this.style.removeProperty(t)}:\"function\"==typeof e?function(){var n=e.apply(this,arguments);null==n?this.style.removeProperty(t):this.style.setProperty(t,n,r)}:function(){this.style.setProperty(t,e,r)}}function at(t,e){return null==e?function(){delete this[t]}:\"function\"==typeof e?function(){var r=e.apply(this,arguments);null==r?delete this[t]:this[t]=r}:function(){this[t]=e}}function ot(e){return\"function\"==typeof e?e:(e=t.ns.qualify(e)).local?function(){return this.ownerDocument.createElementNS(e.space,e.local)}:function(){var t=this.ownerDocument,r=this.namespaceURI;return r===J&&t.documentElement.namespaceURI===J?t.createElement(e):t.createElementNS(r,e)}}function st(){var t=this.parentNode;t&&t.removeChild(this)}function lt(t){return{__data__:t}}function ct(t){return function(){return Y(this,t)}}function ut(t,e){for(var r=0,n=t.length;r<n;r++)for(var i,a=t[r],o=0,s=a.length;o<s;o++)(i=a[o])&&e(i,o,r);return t}function ht(t){return V(t,ft),t}t.ns={prefix:K,qualify:function(t){var e=t.indexOf(\":\"),r=t;return e>=0&&\"xmlns\"!==(r=t.slice(0,e))&&(t=t.slice(e+1)),K.hasOwnProperty(r)?{space:K[r],local:t}:t}},W.attr=function(e,r){if(arguments.length<2){if(\"string\"==typeof e){var n=this.node();return(e=t.ns.qualify(e)).local?n.getAttributeNS(e.space,e.local):n.getAttribute(e)}for(r in e)this.each($(r,e[r]));return this}return this.each($(e,r))},W.classed=function(t,e){if(arguments.length<2){if(\"string\"==typeof t){var r=this.node(),n=(t=et(t)).length,i=-1;if(e=r.classList){for(;++i<n;)if(!e.contains(t[i]))return!1}else for(e=r.getAttribute(\"class\");++i<n;)if(!tt(t[i]).test(e))return!1;return!0}for(e in t)this.each(rt(e,t[e]));return this}return this.each(rt(t,e))},W.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.each(it(r,t[r],e));return this}if(n<2){var i=this.node();return o(i).getComputedStyle(i,null).getPropertyValue(t)}r=\"\"}return this.each(it(t,e,r))},W.property=function(t,e){if(arguments.length<2){if(\"string\"==typeof t)return this.node()[t];for(e in t)this.each(at(e,t[e]));return this}return this.each(at(t,e))},W.text=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.textContent=null==e?\"\":e}:null==t?function(){this.textContent=\"\"}:function(){this.textContent=t}):this.node().textContent},W.html=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.innerHTML=null==e?\"\":e}:null==t?function(){this.innerHTML=\"\"}:function(){this.innerHTML=t}):this.node().innerHTML},W.append=function(t){return t=ot(t),this.select(function(){return this.appendChild(t.apply(this,arguments))})},W.insert=function(t,e){return t=ot(t),e=X(e),this.select(function(){return this.insertBefore(t.apply(this,arguments),e.apply(this,arguments)||null)})},W.remove=function(){return this.each(st)},W.data=function(t,e){var r,n,i=-1,a=this.length;if(!arguments.length){for(t=new Array(a=(r=this[0]).length);++i<a;)(n=r[i])&&(t[i]=n.__data__);return t}function o(t,r){var n,i,a,o=t.length,u=r.length,h=Math.min(o,u),f=new Array(u),p=new Array(u),d=new Array(o);if(e){var g,v=new b,m=new Array(o);for(n=-1;++n<o;)(i=t[n])&&(v.has(g=e.call(i,i.__data__,n))?d[n]=i:v.set(g,i),m[n]=g);for(n=-1;++n<u;)(i=v.get(g=e.call(r,a=r[n],n)))?!0!==i&&(f[n]=i,i.__data__=a):p[n]=lt(a),v.set(g,!0);for(n=-1;++n<o;)n in m&&!0!==v.get(m[n])&&(d[n]=t[n])}else{for(n=-1;++n<h;)i=t[n],a=r[n],i?(i.__data__=a,f[n]=i):p[n]=lt(a);for(;n<u;++n)p[n]=lt(r[n]);for(;n<o;++n)d[n]=t[n]}p.update=f,p.parentNode=f.parentNode=d.parentNode=t.parentNode,s.push(p),l.push(f),c.push(d)}var s=ht([]),l=q([]),c=q([]);if(\"function\"==typeof t)for(;++i<a;)o(r=this[i],t.call(r,r.parentNode.__data__,i));else for(;++i<a;)o(r=this[i],t);return l.enter=function(){return s},l.exit=function(){return c},l},W.datum=function(t){return arguments.length?this.property(\"__data__\",t):this.property(\"__data__\")},W.filter=function(t){var e,r,n,i=[];\"function\"!=typeof t&&(t=ct(t));for(var a=0,o=this.length;a<o;a++){i.push(e=[]),e.parentNode=(r=this[a]).parentNode;for(var s=0,l=r.length;s<l;s++)(n=r[s])&&t.call(n,n.__data__,s,a)&&e.push(n)}return q(i)},W.order=function(){for(var t=-1,e=this.length;++t<e;)for(var r,n=this[t],i=n.length-1,a=n[i];--i>=0;)(r=n[i])&&(a&&a!==r.nextSibling&&a.parentNode.insertBefore(r,a),a=r);return this},W.sort=function(t){t=function(t){arguments.length||(t=f);return function(e,r){return e&&r?t(e.__data__,r.__data__):!e-!r}}.apply(this,arguments);for(var e=-1,r=this.length;++e<r;)this[e].sort(t);return this.order()},W.each=function(t){return ut(this,function(e,r,n){t.call(e,e.__data__,r,n)})},W.call=function(t){var e=n(arguments);return t.apply(e[0]=this,e),this},W.empty=function(){return!this.node()},W.node=function(){for(var t=0,e=this.length;t<e;t++)for(var r=this[t],n=0,i=r.length;n<i;n++){var a=r[n];if(a)return a}return null},W.size=function(){var t=0;return ut(this,function(){++t}),t};var ft=[];function pt(e,r,i){var a=\"__on\"+e,o=e.indexOf(\".\"),s=gt;o>0&&(e=e.slice(0,o));var l=dt.get(e);function c(){var t=this[a];t&&(this.removeEventListener(e,t,t.$),delete this[a])}return l&&(e=l,s=vt),o?r?function(){var t=s(r,n(arguments));c.call(this),this.addEventListener(e,this[a]=t,t.$=i),t._=r}:c:r?D:function(){var r,n=new RegExp(\"^__on([^.]+)\"+t.requote(e)+\"$\");for(var i in this)if(r=i.match(n)){var a=this[i];this.removeEventListener(r[1],a,a.$),delete this[i]}}}t.selection.enter=ht,t.selection.enter.prototype=ft,ft.append=W.append,ft.empty=W.empty,ft.node=W.node,ft.call=W.call,ft.size=W.size,ft.select=function(t){for(var e,r,n,i,a,o=[],s=-1,l=this.length;++s<l;){n=(i=this[s]).update,o.push(e=[]),e.parentNode=i.parentNode;for(var c=-1,u=i.length;++c<u;)(a=i[c])?(e.push(n[c]=r=t.call(i.parentNode,a.__data__,c,s)),r.__data__=a.__data__):e.push(null)}return q(o)},ft.insert=function(t,e){var r,n,i;return arguments.length<2&&(r=this,e=function(t,e,a){var o,s=r[a].update,l=s.length;for(a!=i&&(i=a,n=0),e>=n&&(n=e+1);!(o=s[n])&&++n<l;);return o}),W.insert.call(this,t,e)},t.select=function(t){var e;return\"string\"==typeof t?(e=[H(t,i)]).parentNode=i.documentElement:(e=[t]).parentNode=a(t),q([e])},t.selectAll=function(t){var e;return\"string\"==typeof t?(e=n(G(t,i))).parentNode=i.documentElement:(e=n(t)).parentNode=null,q([e])},W.on=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=!1),t)this.each(pt(r,t[r],e));return this}if(n<2)return(n=this.node()[\"__on\"+t])&&n._;r=!1}return this.each(pt(t,e,r))};var dt=t.map({mouseenter:\"mouseover\",mouseleave:\"mouseout\"});function gt(e,r){return function(n){var i=t.event;t.event=n,r[0]=this.__data__;try{e.apply(this,r)}finally{t.event=i}}}function vt(t,e){var r=gt(t,e);return function(t){var e=t.relatedTarget;e&&(e===this||8&e.compareDocumentPosition(this))||r.call(this,t)}}i&&dt.forEach(function(t){\"on\"+t in i&&dt.remove(t)});var mt,yt=0;function xt(e){var r=\".dragsuppress-\"+ ++yt,n=\"click\"+r,i=t.select(o(e)).on(\"touchmove\"+r,B).on(\"dragstart\"+r,B).on(\"selectstart\"+r,B);if(null==mt&&(mt=!(\"onselectstart\"in e)&&z(e.style,\"userSelect\")),mt){var s=a(e).style,l=s[mt];s[mt]=\"none\"}return function(t){if(i.on(r,null),mt&&(s[mt]=l),t){var e=function(){i.on(n,null)};i.on(n,function(){B(),e()},!0),setTimeout(e,0)}}}t.mouse=function(t){return _t(t,N())};var bt=this.navigator&&/WebKit/.test(this.navigator.userAgent)?-1:0;function _t(e,r){r.changedTouches&&(r=r.changedTouches[0]);var n=e.ownerSVGElement||e;if(n.createSVGPoint){var i=n.createSVGPoint();if(bt<0){var a=o(e);if(a.scrollX||a.scrollY){var s=(n=t.select(\"body\").append(\"svg\").style({position:\"absolute\",top:0,left:0,margin:0,padding:0,border:\"none\"},\"important\"))[0][0].getScreenCTM();bt=!(s.f||s.e),n.remove()}}return bt?(i.x=r.pageX,i.y=r.pageY):(i.x=r.clientX,i.y=r.clientY),[(i=i.matrixTransform(e.getScreenCTM().inverse())).x,i.y]}var l=e.getBoundingClientRect();return[r.clientX-l.left-e.clientLeft,r.clientY-l.top-e.clientTop]}function wt(){return t.event.changedTouches[0].identifier}t.touch=function(t,e,r){if(arguments.length<3&&(r=e,e=N().changedTouches),e)for(var n,i=0,a=e.length;i<a;++i)if((n=e[i]).identifier===r)return _t(t,n)},t.behavior.drag=function(){var e=j(a,\"drag\",\"dragstart\",\"dragend\"),r=null,n=s(D,t.mouse,o,\"mousemove\",\"mouseup\"),i=s(wt,t.touch,P,\"touchmove\",\"touchend\");function a(){this.on(\"mousedown.drag\",n).on(\"touchstart.drag\",i)}function s(n,i,a,o,s){return function(){var l,c=t.event.target.correspondingElement||t.event.target,u=this.parentNode,h=e.of(this,arguments),f=0,p=n(),d=\".drag\"+(null==p?\"\":\"-\"+p),g=t.select(a(c)).on(o+d,function(){var t,e,r=i(u,p);if(!r)return;t=r[0]-m[0],e=r[1]-m[1],f|=t|e,m=r,h({type:\"drag\",x:r[0]+l[0],y:r[1]+l[1],dx:t,dy:e})}).on(s+d,function(){if(!i(u,p))return;g.on(o+d,null).on(s+d,null),v(f),h({type:\"dragend\"})}),v=xt(c),m=i(u,p);l=r?[(l=r.apply(this,arguments)).x-m[0],l.y-m[1]]:[0,0],h({type:\"dragstart\"})}}return a.origin=function(t){return arguments.length?(r=t,a):r},t.rebind(a,e,\"on\")},t.touches=function(t,e){return arguments.length<2&&(e=N().touches),e?n(e).map(function(e){var r=_t(t,e);return r.identifier=e.identifier,r}):[]};var kt=1e-6,Tt=kt*kt,At=Math.PI,Mt=2*At,St=Mt-kt,Et=At/2,Ct=At/180,Lt=180/At;function Pt(t){return t>0?1:t<0?-1:0}function Ot(t,e,r){return(e[0]-t[0])*(r[1]-t[1])-(e[1]-t[1])*(r[0]-t[0])}function zt(t){return t>1?0:t<-1?At:Math.acos(t)}function It(t){return t>1?Et:t<-1?-Et:Math.asin(t)}function Dt(t){return((t=Math.exp(t))+1/t)/2}function Rt(t){return(t=Math.sin(t/2))*t}var Ft=Math.SQRT2;t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,h=l-a,f=u*u+h*h;if(f<Tt)n=Math.log(c/o)/Ft,r=function(t){return[i+t*u,a+t*h,o*Math.exp(Ft*t*n)]};else{var p=Math.sqrt(f),d=(c*c-o*o+4*f)/(2*o*2*p),g=(c*c-o*o-4*f)/(2*c*2*p),v=Math.log(Math.sqrt(d*d+1)-d),m=Math.log(Math.sqrt(g*g+1)-g);n=(m-v)/Ft,r=function(t){var e,r=t*n,s=Dt(v),l=o/(2*p)*(s*(e=Ft*r+v,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(v));return[i+l*u,a+l*h,o*s/Dt(Ft*r+v)]}}return r.duration=1e3*n,r},t.behavior.zoom=function(){var e,r,n,a,s,l,c,u,h,f={x:0,y:0,k:1},p=[960,500],d=jt,g=250,v=0,m=\"mousedown.zoom\",y=\"mousemove.zoom\",x=\"mouseup.zoom\",b=\"touchstart.zoom\",_=j(w,\"zoomstart\",\"zoom\",\"zoomend\");function w(t){t.on(m,P).on(Nt+\".zoom\",z).on(\"dblclick.zoom\",I).on(b,O)}function k(t){return[(t[0]-f.x)/f.k,(t[1]-f.y)/f.k]}function T(t){f.k=Math.max(d[0],Math.min(d[1],t))}function A(t,e){e=function(t){return[t[0]*f.k+f.x,t[1]*f.k+f.y]}(e),f.x+=t[0]-e[0],f.y+=t[1]-e[1]}function M(e,n,i,a){e.__chart__={x:f.x,y:f.y,k:f.k},T(Math.pow(2,a)),A(r=n,i),e=t.select(e),g>0&&(e=e.transition().duration(g)),e.call(w.event)}function S(){c&&c.domain(l.range().map(function(t){return(t-f.x)/f.k}).map(l.invert)),h&&h.domain(u.range().map(function(t){return(t-f.y)/f.k}).map(u.invert))}function E(t){v++||t({type:\"zoomstart\"})}function C(t){S(),t({type:\"zoom\",scale:f.k,translate:[f.x,f.y]})}function L(t){--v||(t({type:\"zoomend\"}),r=null)}function P(){var e=this,r=_.of(e,arguments),n=0,i=t.select(o(e)).on(y,function(){n=1,A(t.mouse(e),a),C(r)}).on(x,function(){i.on(y,null).on(x,null),s(n),L(r)}),a=k(t.mouse(e)),s=xt(e);hs.call(e),E(r)}function O(){var e,r=this,n=_.of(r,arguments),i={},a=0,o=\".zoom-\"+t.event.changedTouches[0].identifier,l=\"touchmove\"+o,c=\"touchend\"+o,u=[],h=t.select(r),p=xt(r);function d(){var n=t.touches(r);return e=f.k,n.forEach(function(t){t.identifier in i&&(i[t.identifier]=k(t))}),n}function g(){var e=t.event.target;t.select(e).on(l,v).on(c,y),u.push(e);for(var n=t.event.changedTouches,o=0,h=n.length;o<h;++o)i[n[o].identifier]=null;var p=d(),g=Date.now();if(1===p.length){if(g-s<500){var m=p[0];M(r,m,i[m.identifier],Math.floor(Math.log(f.k)/Math.LN2)+1),B()}s=g}else if(p.length>1){m=p[0];var x=p[1],b=m[0]-x[0],_=m[1]-x[1];a=b*b+_*_}}function v(){var o,l,c,u,h=t.touches(r);hs.call(r);for(var f=0,p=h.length;f<p;++f,u=null)if(c=h[f],u=i[c.identifier]){if(l)break;o=c,l=u}if(u){var d=(d=c[0]-o[0])*d+(d=c[1]-o[1])*d,g=a&&Math.sqrt(d/a);o=[(o[0]+c[0])/2,(o[1]+c[1])/2],l=[(l[0]+u[0])/2,(l[1]+u[1])/2],T(g*e)}s=null,A(o,l),C(n)}function y(){if(t.event.touches.length){for(var e=t.event.changedTouches,r=0,a=e.length;r<a;++r)delete i[e[r].identifier];for(var s in i)return void d()}t.selectAll(u).on(o,null),h.on(m,P).on(b,O),p(),L(n)}g(),E(n),h.on(m,null).on(b,g)}function z(){var i=_.of(this,arguments);a?clearTimeout(a):(hs.call(this),e=k(r=n||t.mouse(this)),E(i)),a=setTimeout(function(){a=null,L(i)},50),B(),T(Math.pow(2,.002*Bt())*f.k),A(r,e),C(i)}function I(){var e=t.mouse(this),r=Math.log(f.k)/Math.LN2;M(this,e,k(e),t.event.shiftKey?Math.ceil(r)-1:Math.floor(r)+1)}return Nt||(Nt=\"onwheel\"in i?(Bt=function(){return-t.event.deltaY*(t.event.deltaMode?120:1)},\"wheel\"):\"onmousewheel\"in i?(Bt=function(){return t.event.wheelDelta},\"mousewheel\"):(Bt=function(){return-t.event.detail},\"MozMousePixelScroll\")),w.event=function(e){e.each(function(){var e=_.of(this,arguments),n=f;ds?t.select(this).transition().each(\"start.zoom\",function(){f=this.__chart__||{x:0,y:0,k:1},E(e)}).tween(\"zoom:zoom\",function(){var i=p[0],a=p[1],o=r?r[0]:i/2,s=r?r[1]:a/2,l=t.interpolateZoom([(o-f.x)/f.k,(s-f.y)/f.k,i/f.k],[(o-n.x)/n.k,(s-n.y)/n.k,i/n.k]);return function(t){var r=l(t),n=i/r[2];this.__chart__=f={x:o-r[0]*n,y:s-r[1]*n,k:n},C(e)}}).each(\"interrupt.zoom\",function(){L(e)}).each(\"end.zoom\",function(){L(e)}):(this.__chart__=f,E(e),C(e),L(e))})},w.translate=function(t){return arguments.length?(f={x:+t[0],y:+t[1],k:f.k},S(),w):[f.x,f.y]},w.scale=function(t){return arguments.length?(f={x:f.x,y:f.y,k:null},T(+t),S(),w):f.k},w.scaleExtent=function(t){return arguments.length?(d=null==t?jt:[+t[0],+t[1]],w):d},w.center=function(t){return arguments.length?(n=t&&[+t[0],+t[1]],w):n},w.size=function(t){return arguments.length?(p=t&&[+t[0],+t[1]],w):p},w.duration=function(t){return arguments.length?(g=+t,w):g},w.x=function(t){return arguments.length?(c=t,l=t.copy(),f={x:0,y:0,k:1},w):c},w.y=function(t){return arguments.length?(h=t,u=t.copy(),f={x:0,y:0,k:1},w):h},t.rebind(w,_,\"on\")};var Bt,Nt,jt=[0,1/0];function Ut(){}function Vt(t,e,r){return this instanceof Vt?(this.h=+t,this.s=+e,void(this.l=+r)):arguments.length<2?t instanceof Vt?new Vt(t.h,t.s,t.l):ue(\"\"+t,he,Vt):new Vt(t,e,r)}t.color=Ut,Ut.prototype.toString=function(){return this.rgb()+\"\"},t.hsl=Vt;var qt=Vt.prototype=new Ut;function Ht(t,e,r){var n,i;function a(t){return Math.round(255*function(t){return t>360?t-=360:t<0&&(t+=360),t<60?n+(i-n)*t/60:t<180?i:t<240?n+(i-n)*(240-t)/60:n}(t))}return t=isNaN(t)?0:(t%=360)<0?t+360:t,e=isNaN(e)?0:e<0?0:e>1?1:e,n=2*(r=r<0?0:r>1?1:r)-(i=r<=.5?r*(1+e):r+e-r*e),new ae(a(t+120),a(t),a(t-120))}function Gt(e,r,n){return this instanceof Gt?(this.h=+e,this.c=+r,void(this.l=+n)):arguments.length<2?e instanceof Gt?new Gt(e.h,e.c,e.l):ee(e instanceof Xt?e.l:(e=fe((e=t.rgb(e)).r,e.g,e.b)).l,e.a,e.b):new Gt(e,r,n)}qt.brighter=function(t){return t=Math.pow(.7,arguments.length?t:1),new Vt(this.h,this.s,this.l/t)},qt.darker=function(t){return t=Math.pow(.7,arguments.length?t:1),new Vt(this.h,this.s,t*this.l)},qt.rgb=function(){return Ht(this.h,this.s,this.l)},t.hcl=Gt;var Yt=Gt.prototype=new Ut;function Wt(t,e,r){return isNaN(t)&&(t=0),isNaN(e)&&(e=0),new Xt(r,Math.cos(t*=Ct)*e,Math.sin(t)*e)}function Xt(t,e,r){return this instanceof Xt?(this.l=+t,this.a=+e,void(this.b=+r)):arguments.length<2?t instanceof Xt?new Xt(t.l,t.a,t.b):t instanceof Gt?Wt(t.h,t.c,t.l):fe((t=ae(t)).r,t.g,t.b):new Xt(t,e,r)}Yt.brighter=function(t){return new Gt(this.h,this.c,Math.min(100,this.l+Zt*(arguments.length?t:1)))},Yt.darker=function(t){return new Gt(this.h,this.c,Math.max(0,this.l-Zt*(arguments.length?t:1)))},Yt.rgb=function(){return Wt(this.h,this.c,this.l).rgb()},t.lab=Xt;var Zt=18,Jt=.95047,Kt=1,$t=1.08883,Qt=Xt.prototype=new Ut;function te(t,e,r){var n=(t+16)/116,i=n+e/500,a=n-r/200;return new ae(ie(3.2404542*(i=re(i)*Jt)-1.5371385*(n=re(n)*Kt)-.4985314*(a=re(a)*$t)),ie(-.969266*i+1.8760108*n+.041556*a),ie(.0556434*i-.2040259*n+1.0572252*a))}function ee(t,e,r){return t>0?new Gt(Math.atan2(r,e)*Lt,Math.sqrt(e*e+r*r),t):new Gt(NaN,NaN,t)}function re(t){return t>.206893034?t*t*t:(t-4/29)/7.787037}function ne(t){return t>.008856?Math.pow(t,1/3):7.787037*t+4/29}function ie(t){return Math.round(255*(t<=.00304?12.92*t:1.055*Math.pow(t,1/2.4)-.055))}function ae(t,e,r){return this instanceof ae?(this.r=~~t,this.g=~~e,void(this.b=~~r)):arguments.length<2?t instanceof ae?new ae(t.r,t.g,t.b):ue(\"\"+t,ae,Ht):new ae(t,e,r)}function oe(t){return new ae(t>>16,t>>8&255,255&t)}function se(t){return oe(t)+\"\"}Qt.brighter=function(t){return new Xt(Math.min(100,this.l+Zt*(arguments.length?t:1)),this.a,this.b)},Qt.darker=function(t){return new Xt(Math.max(0,this.l-Zt*(arguments.length?t:1)),this.a,this.b)},Qt.rgb=function(){return te(this.l,this.a,this.b)},t.rgb=ae;var le=ae.prototype=new Ut;function ce(t){return t<16?\"0\"+Math.max(0,t).toString(16):Math.min(255,t).toString(16)}function ue(t,e,r){var n,i,a,o=0,s=0,l=0;if(n=/([a-z]+)\\((.*)\\)/.exec(t=t.toLowerCase()))switch(i=n[2].split(\",\"),n[1]){case\"hsl\":return r(parseFloat(i[0]),parseFloat(i[1])/100,parseFloat(i[2])/100);case\"rgb\":return e(de(i[0]),de(i[1]),de(i[2]))}return(a=ge.get(t))?e(a.r,a.g,a.b):(null==t||\"#\"!==t.charAt(0)||isNaN(a=parseInt(t.slice(1),16))||(4===t.length?(o=(3840&a)>>4,o|=o>>4,s=240&a,s|=s>>4,l=15&a,l|=l<<4):7===t.length&&(o=(16711680&a)>>16,s=(65280&a)>>8,l=255&a)),e(o,s,l))}function he(t,e,r){var n,i,a=Math.min(t/=255,e/=255,r/=255),o=Math.max(t,e,r),s=o-a,l=(o+a)/2;return s?(i=l<.5?s/(o+a):s/(2-o-a),n=t==o?(e-r)/s+(e<r?6:0):e==o?(r-t)/s+2:(t-e)/s+4,n*=60):(n=NaN,i=l>0&&l<1?0:n),new Vt(n,i,l)}function fe(t,e,r){var n=ne((.4124564*(t=pe(t))+.3575761*(e=pe(e))+.1804375*(r=pe(r)))/Jt),i=ne((.2126729*t+.7151522*e+.072175*r)/Kt);return Xt(116*i-16,500*(n-i),200*(i-ne((.0193339*t+.119192*e+.9503041*r)/$t)))}function pe(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function de(t){var e=parseFloat(t);return\"%\"===t.charAt(t.length-1)?Math.round(2.55*e):e}le.brighter=function(t){t=Math.pow(.7,arguments.length?t:1);var e=this.r,r=this.g,n=this.b,i=30;return e||r||n?(e&&e<i&&(e=i),r&&r<i&&(r=i),n&&n<i&&(n=i),new ae(Math.min(255,e/t),Math.min(255,r/t),Math.min(255,n/t))):new ae(i,i,i)},le.darker=function(t){return new ae((t=Math.pow(.7,arguments.length?t:1))*this.r,t*this.g,t*this.b)},le.hsl=function(){return he(this.r,this.g,this.b)},le.toString=function(){return\"#\"+ce(this.r)+ce(this.g)+ce(this.b)};var ge=t.map({aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074});function ve(t){return\"function\"==typeof t?t:function(){return t}}function me(t){return function(e,r,n){return 2===arguments.length&&\"function\"==typeof r&&(n=r,r=null),ye(e,r,t,n)}}function ye(e,r,i,a){var o={},s=t.dispatch(\"beforesend\",\"progress\",\"load\",\"error\"),l={},c=new XMLHttpRequest,u=null;function h(){var t,e=c.status;if(!e&&function(t){var e=t.responseType;return e&&\"text\"!==e?t.response:t.responseText}(c)||e>=200&&e<300||304===e){try{t=i.call(o,c)}catch(t){return void s.error.call(o,t)}s.load.call(o,t)}else s.error.call(o,c)}return!this.XDomainRequest||\"withCredentials\"in c||!/^(http(s)?:)?\\/\\//.test(e)||(c=new XDomainRequest),\"onload\"in c?c.onload=c.onerror=h:c.onreadystatechange=function(){c.readyState>3&&h()},c.onprogress=function(e){var r=t.event;t.event=e;try{s.progress.call(o,c)}finally{t.event=r}},o.header=function(t,e){return t=(t+\"\").toLowerCase(),arguments.length<2?l[t]:(null==e?delete l[t]:l[t]=e+\"\",o)},o.mimeType=function(t){return arguments.length?(r=null==t?null:t+\"\",o):r},o.responseType=function(t){return arguments.length?(u=t,o):u},o.response=function(t){return i=t,o},[\"get\",\"post\"].forEach(function(t){o[t]=function(){return o.send.apply(o,[t].concat(n(arguments)))}}),o.send=function(t,n,i){if(2===arguments.length&&\"function\"==typeof n&&(i=n,n=null),c.open(t,e,!0),null==r||\"accept\"in l||(l.accept=r+\",*/*\"),c.setRequestHeader)for(var a in l)c.setRequestHeader(a,l[a]);return null!=r&&c.overrideMimeType&&c.overrideMimeType(r),null!=u&&(c.responseType=u),null!=i&&o.on(\"error\",i).on(\"load\",function(t){i(null,t)}),s.beforesend.call(o,c),c.send(null==n?null:n),o},o.abort=function(){return c.abort(),o},t.rebind(o,s,\"on\"),null==a?o:o.get(function(t){return 1===t.length?function(e,r){t(null==e?r:null)}:t}(a))}ge.forEach(function(t,e){ge.set(t,oe(e))}),t.functor=ve,t.xhr=me(P),t.dsv=function(t,e){var r=new RegExp('[\"'+t+\"\\n]\"),n=t.charCodeAt(0);function i(t,r,n){arguments.length<3&&(n=r,r=null);var i=ye(t,e,null==r?a:o(r),n);return i.row=function(t){return arguments.length?i.response(null==(r=t)?a:o(t)):r},i}function a(t){return i.parse(t.responseText)}function o(t){return function(e){return i.parse(e.responseText,t)}}function s(e){return e.map(l).join(t)}function l(t){return r.test(t)?'\"'+t.replace(/\\\"/g,'\"\"')+'\"':t}return i.parse=function(t,e){var r;return i.parseRows(t,function(t,n){if(r)return r(t,n-1);var i=new Function(\"d\",\"return {\"+t.map(function(t,e){return JSON.stringify(t)+\": d[\"+e+\"]\"}).join(\",\")+\"}\");r=e?function(t,r){return e(i(t),r)}:i})},i.parseRows=function(t,e){var r,i,a={},o={},s=[],l=t.length,c=0,u=0;function h(){if(c>=l)return o;if(i)return i=!1,a;var e=c;if(34===t.charCodeAt(e)){for(var r=e;r++<l;)if(34===t.charCodeAt(r)){if(34!==t.charCodeAt(r+1))break;++r}return c=r+2,13===(s=t.charCodeAt(r+1))?(i=!0,10===t.charCodeAt(r+2)&&++c):10===s&&(i=!0),t.slice(e+1,r).replace(/\"\"/g,'\"')}for(;c<l;){var s,u=1;if(10===(s=t.charCodeAt(c++)))i=!0;else if(13===s)i=!0,10===t.charCodeAt(c)&&(++c,++u);else if(s!==n)continue;return t.slice(e,c-u)}return t.slice(e)}for(;(r=h())!==o;){for(var f=[];r!==a&&r!==o;)f.push(r),r=h();e&&null==(f=e(f,u++))||s.push(f)}return s},i.format=function(e){if(Array.isArray(e[0]))return i.formatRows(e);var r=new L,n=[];return e.forEach(function(t){for(var e in t)r.has(e)||n.push(r.add(e))}),[n.map(l).join(t)].concat(e.map(function(e){return n.map(function(t){return l(e[t])}).join(t)})).join(\"\\n\")},i.formatRows=function(t){return t.map(s).join(\"\\n\")},i},t.csv=t.dsv(\",\",\"text/csv\"),t.tsv=t.dsv(\"\\t\",\"text/tab-separated-values\");var xe,be,_e,we,ke=this[z(this,\"requestAnimationFrame\")]||function(t){setTimeout(t,17)};function Te(t,e,r){var n=arguments.length;n<2&&(e=0),n<3&&(r=Date.now());var i={c:t,t:r+e,n:null};return be?be.n=i:xe=i,be=i,_e||(we=clearTimeout(we),_e=1,ke(Ae)),i}function Ae(){var t=Me(),e=Se()-t;e>24?(isFinite(e)&&(clearTimeout(we),we=setTimeout(Ae,e)),_e=0):(_e=1,ke(Ae))}function Me(){for(var t=Date.now(),e=xe;e;)t>=e.t&&e.c(t-e.t)&&(e.c=null),e=e.n;return t}function Se(){for(var t,e=xe,r=1/0;e;)e.c?(e.t<r&&(r=e.t),e=(t=e).n):e=t?t.n=e.n:xe=e.n;return be=t,r}function Ee(t,e){return e-(t?Math.ceil(Math.log(t)/Math.LN10):1)}t.timer=function(){Te.apply(this,arguments)},t.timer.flush=function(){Me(),Se()},t.round=function(t,e){return e?Math.round(t*(e=Math.pow(10,e)))/e:Math.round(t)};var Ce=[\"y\",\"z\",\"a\",\"f\",\"p\",\"n\",\"\\xb5\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\",\"P\",\"E\",\"Z\",\"Y\"].map(function(t,e){var r=Math.pow(10,3*y(8-e));return{scale:e>8?function(t){return t/r}:function(t){return t*r},symbol:t}});t.formatPrefix=function(e,r){var n=0;return(e=+e)&&(e<0&&(e*=-1),r&&(e=t.round(e,Ee(e,r))),n=1+Math.floor(1e-12+Math.log(e)/Math.LN10),n=Math.max(-24,Math.min(24,3*Math.floor((n-1)/3)))),Ce[8+n/3]};var Le=/(?:([^{])?([<>=^]))?([+\\- ])?([$#])?(0)?(\\d+)?(,)?(\\.-?\\d+)?([a-z%])?/i,Pe=t.map({b:function(t){return t.toString(2)},c:function(t){return String.fromCharCode(t)},o:function(t){return t.toString(8)},x:function(t){return t.toString(16)},X:function(t){return t.toString(16).toUpperCase()},g:function(t,e){return t.toPrecision(e)},e:function(t,e){return t.toExponential(e)},f:function(t,e){return t.toFixed(e)},r:function(e,r){return(e=t.round(e,Ee(e,r))).toFixed(Math.max(0,Math.min(20,Ee(e*(1+1e-15),r))))}});function Oe(t){return t+\"\"}var ze=t.time={},Ie=Date;function De(){this._=new Date(arguments.length>1?Date.UTC.apply(this,arguments):arguments[0])}De.prototype={getDate:function(){return this._.getUTCDate()},getDay:function(){return this._.getUTCDay()},getFullYear:function(){return this._.getUTCFullYear()},getHours:function(){return this._.getUTCHours()},getMilliseconds:function(){return this._.getUTCMilliseconds()},getMinutes:function(){return this._.getUTCMinutes()},getMonth:function(){return this._.getUTCMonth()},getSeconds:function(){return this._.getUTCSeconds()},getTime:function(){return this._.getTime()},getTimezoneOffset:function(){return 0},valueOf:function(){return this._.valueOf()},setDate:function(){Re.setUTCDate.apply(this._,arguments)},setDay:function(){Re.setUTCDay.apply(this._,arguments)},setFullYear:function(){Re.setUTCFullYear.apply(this._,arguments)},setHours:function(){Re.setUTCHours.apply(this._,arguments)},setMilliseconds:function(){Re.setUTCMilliseconds.apply(this._,arguments)},setMinutes:function(){Re.setUTCMinutes.apply(this._,arguments)},setMonth:function(){Re.setUTCMonth.apply(this._,arguments)},setSeconds:function(){Re.setUTCSeconds.apply(this._,arguments)},setTime:function(){Re.setTime.apply(this._,arguments)}};var Re=Date.prototype;function Fe(t,e,r){function n(e){var r=t(e),n=a(r,1);return e-r<n-e?r:n}function i(r){return e(r=t(new Ie(r-1)),1),r}function a(t,r){return e(t=new Ie(+t),r),t}function o(t,n,a){var o=i(t),s=[];if(a>1)for(;o<n;)r(o)%a||s.push(new Date(+o)),e(o,1);else for(;o<n;)s.push(new Date(+o)),e(o,1);return s}t.floor=t,t.round=n,t.ceil=i,t.offset=a,t.range=o;var s=t.utc=Be(t);return s.floor=s,s.round=Be(n),s.ceil=Be(i),s.offset=Be(a),s.range=function(t,e,r){try{Ie=De;var n=new De;return n._=t,o(n,e,r)}finally{Ie=Date}},t}function Be(t){return function(e,r){try{Ie=De;var n=new De;return n._=e,t(n,r)._}finally{Ie=Date}}}ze.year=Fe(function(t){return(t=ze.day(t)).setMonth(0,1),t},function(t,e){t.setFullYear(t.getFullYear()+e)},function(t){return t.getFullYear()}),ze.years=ze.year.range,ze.years.utc=ze.year.utc.range,ze.day=Fe(function(t){var e=new Ie(2e3,0);return e.setFullYear(t.getFullYear(),t.getMonth(),t.getDate()),e},function(t,e){t.setDate(t.getDate()+e)},function(t){return t.getDate()-1}),ze.days=ze.day.range,ze.days.utc=ze.day.utc.range,ze.dayOfYear=function(t){var e=ze.year(t);return Math.floor((t-e-6e4*(t.getTimezoneOffset()-e.getTimezoneOffset()))/864e5)},[\"sunday\",\"monday\",\"tuesday\",\"wednesday\",\"thursday\",\"friday\",\"saturday\"].forEach(function(t,e){e=7-e;var r=ze[t]=Fe(function(t){return(t=ze.day(t)).setDate(t.getDate()-(t.getDay()+e)%7),t},function(t,e){t.setDate(t.getDate()+7*Math.floor(e))},function(t){var r=ze.year(t).getDay();return Math.floor((ze.dayOfYear(t)+(r+e)%7)/7)-(r!==e)});ze[t+\"s\"]=r.range,ze[t+\"s\"].utc=r.utc.range,ze[t+\"OfYear\"]=function(t){var r=ze.year(t).getDay();return Math.floor((ze.dayOfYear(t)+(r+e)%7)/7)}}),ze.week=ze.sunday,ze.weeks=ze.sunday.range,ze.weeks.utc=ze.sunday.utc.range,ze.weekOfYear=ze.sundayOfYear;var Ne={\"-\":\"\",_:\" \",0:\"0\"},je=/^\\s*\\d+/,Ue=/^%/;function Ve(t,e,r){var n=t<0?\"-\":\"\",i=(n?-t:t)+\"\",a=i.length;return n+(a<r?new Array(r-a+1).join(e)+i:i)}function qe(e){return new RegExp(\"^(?:\"+e.map(t.requote).join(\"|\")+\")\",\"i\")}function He(t){for(var e=new b,r=-1,n=t.length;++r<n;)e.set(t[r].toLowerCase(),r);return e}function Ge(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+1));return n?(t.w=+n[0],r+n[0].length):-1}function Ye(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.U=+n[0],r+n[0].length):-1}function We(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.W=+n[0],r+n[0].length):-1}function Xe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+4));return n?(t.y=+n[0],r+n[0].length):-1}function Ze(t,e,r){je.lastIndex=0;var n,i=je.exec(e.slice(r,r+2));return i?(t.y=(n=+i[0])+(n>68?1900:2e3),r+i[0].length):-1}function Je(t,e,r){return/^[+-]\\d{4}$/.test(e=e.slice(r,r+5))?(t.Z=-e,r+5):-1}function Ke(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.m=n[0]-1,r+n[0].length):-1}function $e(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.d=+n[0],r+n[0].length):-1}function Qe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.j=+n[0],r+n[0].length):-1}function tr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.H=+n[0],r+n[0].length):-1}function er(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.M=+n[0],r+n[0].length):-1}function rr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.S=+n[0],r+n[0].length):-1}function nr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.L=+n[0],r+n[0].length):-1}function ir(t){var e=t.getTimezoneOffset(),r=e>0?\"-\":\"+\",n=y(e)/60|0,i=y(e)%60;return r+Ve(n,\"0\",2)+Ve(i,\"0\",2)}function ar(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r,r+1));return n?r+n[0].length:-1}function or(t){for(var e=t.length,r=-1;++r<e;)t[r][0]=this(t[r][0]);return function(e){for(var r=0,n=t[r];!n[1](e);)n=t[++r];return n[0](e)}}t.locale=function(e){return{numberFormat:function(e){var r=e.decimal,n=e.thousands,i=e.grouping,a=e.currency,o=i&&n?function(t,e){for(var r=t.length,a=[],o=0,s=i[0],l=0;r>0&&s>0&&(l+s+1>e&&(s=Math.max(1,e-l)),a.push(t.substring(r-=s,r+s)),!((l+=s+1)>e));)s=i[o=(o+1)%i.length];return a.reverse().join(n)}:P;return function(e){var n=Le.exec(e),i=n[1]||\" \",s=n[2]||\">\",l=n[3]||\"-\",c=n[4]||\"\",u=n[5],h=+n[6],f=n[7],p=n[8],d=n[9],g=1,v=\"\",m=\"\",y=!1,x=!0;switch(p&&(p=+p.substring(1)),(u||\"0\"===i&&\"=\"===s)&&(u=i=\"0\",s=\"=\"),d){case\"n\":f=!0,d=\"g\";break;case\"%\":g=100,m=\"%\",d=\"f\";break;case\"p\":g=100,m=\"%\",d=\"r\";break;case\"b\":case\"o\":case\"x\":case\"X\":\"#\"===c&&(v=\"0\"+d.toLowerCase());case\"c\":x=!1;case\"d\":y=!0,p=0;break;case\"s\":g=-1,d=\"r\"}\"$\"===c&&(v=a[0],m=a[1]),\"r\"!=d||p||(d=\"g\"),null!=p&&(\"g\"==d?p=Math.max(1,Math.min(21,p)):\"e\"!=d&&\"f\"!=d||(p=Math.max(0,Math.min(20,p)))),d=Pe.get(d)||Oe;var b=u&&f;return function(e){var n=m;if(y&&e%1)return\"\";var a=e<0||0===e&&1/e<0?(e=-e,\"-\"):\"-\"===l?\"\":l;if(g<0){var c=t.formatPrefix(e,p);e=c.scale(e),n=c.symbol+m}else e*=g;var _,w,k=(e=d(e,p)).lastIndexOf(\".\");if(k<0){var T=x?e.lastIndexOf(\"e\"):-1;T<0?(_=e,w=\"\"):(_=e.substring(0,T),w=e.substring(T))}else _=e.substring(0,k),w=r+e.substring(k+1);!u&&f&&(_=o(_,1/0));var A=v.length+_.length+w.length+(b?0:a.length),M=A<h?new Array(A=h-A+1).join(i):\"\";return b&&(_=o(M+_,M.length?h-w.length:1/0)),a+=v,e=_+w,(\"<\"===s?a+e+M:\">\"===s?M+a+e:\"^\"===s?M.substring(0,A>>=1)+a+e+M.substring(A):a+(b?e:M+e))+n}}}(e),timeFormat:function(e){var r=e.dateTime,n=e.date,i=e.time,a=e.periods,o=e.days,s=e.shortDays,l=e.months,c=e.shortMonths;function u(t){var e=t.length;function r(r){for(var n,i,a,o=[],s=-1,l=0;++s<e;)37===t.charCodeAt(s)&&(o.push(t.slice(l,s)),null!=(i=Ne[n=t.charAt(++s)])&&(n=t.charAt(++s)),(a=_[n])&&(n=a(r,null==i?\"e\"===n?\" \":\"0\":i)),o.push(n),l=s+1);return o.push(t.slice(l,s)),o.join(\"\")}return r.parse=function(e){var r={y:1900,m:0,d:1,H:0,M:0,S:0,L:0,Z:null};if(h(r,t,e,0)!=e.length)return null;\"p\"in r&&(r.H=r.H%12+12*r.p);var n=null!=r.Z&&Ie!==De,i=new(n?De:Ie);return\"j\"in r?i.setFullYear(r.y,0,r.j):\"W\"in r||\"U\"in r?(\"w\"in r||(r.w=\"W\"in r?1:0),i.setFullYear(r.y,0,1),i.setFullYear(r.y,0,\"W\"in r?(r.w+6)%7+7*r.W-(i.getDay()+5)%7:r.w+7*r.U-(i.getDay()+6)%7)):i.setFullYear(r.y,r.m,r.d),i.setHours(r.H+(r.Z/100|0),r.M+r.Z%100,r.S,r.L),n?i._:i},r.toString=function(){return t},r}function h(t,e,r,n){for(var i,a,o,s=0,l=e.length,c=r.length;s<l;){if(n>=c)return-1;if(37===(i=e.charCodeAt(s++))){if(o=e.charAt(s++),!(a=w[o in Ne?e.charAt(s++):o])||(n=a(t,r,n))<0)return-1}else if(i!=r.charCodeAt(n++))return-1}return n}u.utc=function(t){var e=u(t);function r(t){try{var r=new(Ie=De);return r._=t,e(r)}finally{Ie=Date}}return r.parse=function(t){try{Ie=De;var r=e.parse(t);return r&&r._}finally{Ie=Date}},r.toString=e.toString,r},u.multi=u.utc.multi=or;var f=t.map(),p=qe(o),d=He(o),g=qe(s),v=He(s),m=qe(l),y=He(l),x=qe(c),b=He(c);a.forEach(function(t,e){f.set(t.toLowerCase(),e)});var _={a:function(t){return s[t.getDay()]},A:function(t){return o[t.getDay()]},b:function(t){return c[t.getMonth()]},B:function(t){return l[t.getMonth()]},c:u(r),d:function(t,e){return Ve(t.getDate(),e,2)},e:function(t,e){return Ve(t.getDate(),e,2)},H:function(t,e){return Ve(t.getHours(),e,2)},I:function(t,e){return Ve(t.getHours()%12||12,e,2)},j:function(t,e){return Ve(1+ze.dayOfYear(t),e,3)},L:function(t,e){return Ve(t.getMilliseconds(),e,3)},m:function(t,e){return Ve(t.getMonth()+1,e,2)},M:function(t,e){return Ve(t.getMinutes(),e,2)},p:function(t){return a[+(t.getHours()>=12)]},S:function(t,e){return Ve(t.getSeconds(),e,2)},U:function(t,e){return Ve(ze.sundayOfYear(t),e,2)},w:function(t){return t.getDay()},W:function(t,e){return Ve(ze.mondayOfYear(t),e,2)},x:u(n),X:u(i),y:function(t,e){return Ve(t.getFullYear()%100,e,2)},Y:function(t,e){return Ve(t.getFullYear()%1e4,e,4)},Z:ir,\"%\":function(){return\"%\"}},w={a:function(t,e,r){g.lastIndex=0;var n=g.exec(e.slice(r));return n?(t.w=v.get(n[0].toLowerCase()),r+n[0].length):-1},A:function(t,e,r){p.lastIndex=0;var n=p.exec(e.slice(r));return n?(t.w=d.get(n[0].toLowerCase()),r+n[0].length):-1},b:function(t,e,r){x.lastIndex=0;var n=x.exec(e.slice(r));return n?(t.m=b.get(n[0].toLowerCase()),r+n[0].length):-1},B:function(t,e,r){m.lastIndex=0;var n=m.exec(e.slice(r));return n?(t.m=y.get(n[0].toLowerCase()),r+n[0].length):-1},c:function(t,e,r){return h(t,_.c.toString(),e,r)},d:$e,e:$e,H:tr,I:tr,j:Qe,L:nr,m:Ke,M:er,p:function(t,e,r){var n=f.get(e.slice(r,r+=2).toLowerCase());return null==n?-1:(t.p=n,r)},S:rr,U:Ye,w:Ge,W:We,x:function(t,e,r){return h(t,_.x.toString(),e,r)},X:function(t,e,r){return h(t,_.X.toString(),e,r)},y:Ze,Y:Xe,Z:Je,\"%\":ar};return u}(e)}};var sr=t.locale({decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],dateTime:\"%a %b %e %X %Y\",date:\"%m/%d/%Y\",time:\"%H:%M:%S\",periods:[\"AM\",\"PM\"],days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"]});function lr(){}t.format=sr.numberFormat,t.geo={},lr.prototype={s:0,t:0,add:function(t){ur(t,this.t,cr),ur(cr.s,this.s,this),this.s?this.t+=cr.t:this.s=cr.t},reset:function(){this.s=this.t=0},valueOf:function(){return this.s}};var cr=new lr;function ur(t,e,r){var n=r.s=t+e,i=n-t,a=n-i;r.t=t-a+(e-i)}function hr(t,e){t&&pr.hasOwnProperty(t.type)&&pr[t.type](t,e)}t.geo.stream=function(t,e){t&&fr.hasOwnProperty(t.type)?fr[t.type](t,e):hr(t,e)};var fr={Feature:function(t,e){hr(t.geometry,e)},FeatureCollection:function(t,e){for(var r=t.features,n=-1,i=r.length;++n<i;)hr(r[n].geometry,e)}},pr={Sphere:function(t,e){e.sphere()},Point:function(t,e){t=t.coordinates,e.point(t[0],t[1],t[2])},MultiPoint:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)t=r[n],e.point(t[0],t[1],t[2])},LineString:function(t,e){dr(t.coordinates,e,0)},MultiLineString:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)dr(r[n],e,0)},Polygon:function(t,e){gr(t.coordinates,e)},MultiPolygon:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)gr(r[n],e)},GeometryCollection:function(t,e){for(var r=t.geometries,n=-1,i=r.length;++n<i;)hr(r[n],e)}};function dr(t,e,r){var n,i=-1,a=t.length-r;for(e.lineStart();++i<a;)n=t[i],e.point(n[0],n[1],n[2]);e.lineEnd()}function gr(t,e){var r=-1,n=t.length;for(e.polygonStart();++r<n;)dr(t[r],e,1);e.polygonEnd()}t.geo.area=function(e){return vr=0,t.geo.stream(e,Cr),vr};var vr,mr,yr,xr,br,_r,wr,kr,Tr,Ar,Mr,Sr,Er=new lr,Cr={sphere:function(){vr+=4*At},point:D,lineStart:D,lineEnd:D,polygonStart:function(){Er.reset(),Cr.lineStart=Lr},polygonEnd:function(){var t=2*Er;vr+=t<0?4*At+t:t,Cr.lineStart=Cr.lineEnd=Cr.point=D}};function Lr(){var t,e,r,n,i;function a(t,e){e=e*Ct/2+At/4;var a=(t*=Ct)-r,o=a>=0?1:-1,s=o*a,l=Math.cos(e),c=Math.sin(e),u=i*c,h=n*l+u*Math.cos(s),f=u*o*Math.sin(s);Er.add(Math.atan2(f,h)),r=t,n=l,i=c}Cr.point=function(o,s){Cr.point=a,r=(t=o)*Ct,n=Math.cos(s=(e=s)*Ct/2+At/4),i=Math.sin(s)},Cr.lineEnd=function(){a(t,e)}}function Pr(t){var e=t[0],r=t[1],n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}function Or(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}function zr(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}function Ir(t,e){t[0]+=e[0],t[1]+=e[1],t[2]+=e[2]}function Dr(t,e){return[t[0]*e,t[1]*e,t[2]*e]}function Rr(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]+t[2]*t[2]);t[0]/=e,t[1]/=e,t[2]/=e}function Fr(t){return[Math.atan2(t[1],t[0]),It(t[2])]}function Br(t,e){return y(t[0]-e[0])<kt&&y(t[1]-e[1])<kt}t.geo.bounds=function(){var e,r,n,i,a,o,s,l,c,u,h,f={point:p,lineStart:g,lineEnd:v,polygonStart:function(){f.point=m,f.lineStart=x,f.lineEnd=b,c=0,Cr.polygonStart()},polygonEnd:function(){Cr.polygonEnd(),f.point=p,f.lineStart=g,f.lineEnd=v,Er<0?(e=-(n=180),r=-(i=90)):c>kt?i=90:c<-kt&&(r=-90),h[0]=e,h[1]=n}};function p(t,a){u.push(h=[e=t,n=t]),a<r&&(r=a),a>i&&(i=a)}function d(t,o){var s=Pr([t*Ct,o*Ct]);if(l){var c=zr(l,s),u=zr([c[1],-c[0],0],c);Rr(u),u=Fr(u);var h=t-a,f=h>0?1:-1,d=u[0]*Lt*f,g=y(h)>180;if(g^(f*a<d&&d<f*t))(v=u[1]*Lt)>i&&(i=v);else if(g^(f*a<(d=(d+360)%360-180)&&d<f*t)){var v;(v=-u[1]*Lt)<r&&(r=v)}else o<r&&(r=o),o>i&&(i=o);g?t<a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t):n>=e?(t<e&&(e=t),t>n&&(n=t)):t>a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t)}else p(t,o);l=s,a=t}function g(){f.point=d}function v(){h[0]=e,h[1]=n,f.point=p,l=null}function m(t,e){if(l){var r=t-a;c+=y(r)>180?r+(r>0?360:-360):r}else o=t,s=e;Cr.point(t,e),d(t,e)}function x(){Cr.lineStart()}function b(){m(o,s),Cr.lineEnd(),y(c)>kt&&(e=-(n=180)),h[0]=e,h[1]=n,l=null}function _(t,e){return(e-=t)<0?e+360:e}function w(t,e){return t[0]-e[0]}function k(t,e){return e[0]<=e[1]?e[0]<=t&&t<=e[1]:t<e[0]||e[1]<t}return function(a){if(i=n=-(e=r=1/0),u=[],t.geo.stream(a,f),c=u.length){u.sort(w);for(var o=1,s=[g=u[0]];o<c;++o)k((p=u[o])[0],g)||k(p[1],g)?(_(g[0],p[1])>_(g[0],g[1])&&(g[1]=p[1]),_(p[0],g[1])>_(g[0],g[1])&&(g[0]=p[0])):s.push(g=p);for(var l,c,p,d=-1/0,g=(o=0,s[c=s.length-1]);o<=c;g=p,++o)p=s[o],(l=_(g[1],p[0]))>d&&(d=l,e=p[0],n=g[1])}return u=h=null,e===1/0||r===1/0?[[NaN,NaN],[NaN,NaN]]:[[e,r],[n,i]]}}(),t.geo.centroid=function(e){mr=yr=xr=br=_r=wr=kr=Tr=Ar=Mr=Sr=0,t.geo.stream(e,Nr);var r=Ar,n=Mr,i=Sr,a=r*r+n*n+i*i;return a<Tt&&(r=wr,n=kr,i=Tr,yr<kt&&(r=xr,n=br,i=_r),(a=r*r+n*n+i*i)<Tt)?[NaN,NaN]:[Math.atan2(n,r)*Lt,It(i/Math.sqrt(a))*Lt]};var Nr={sphere:D,point:jr,lineStart:Vr,lineEnd:qr,polygonStart:function(){Nr.lineStart=Hr},polygonEnd:function(){Nr.lineStart=Vr}};function jr(t,e){t*=Ct;var r=Math.cos(e*=Ct);Ur(r*Math.cos(t),r*Math.sin(t),Math.sin(e))}function Ur(t,e,r){xr+=(t-xr)/++mr,br+=(e-br)/mr,_r+=(r-_r)/mr}function Vr(){var t,e,r;function n(n,i){n*=Ct;var a=Math.cos(i*=Ct),o=a*Math.cos(n),s=a*Math.sin(n),l=Math.sin(i),c=Math.atan2(Math.sqrt((c=e*l-r*s)*c+(c=r*o-t*l)*c+(c=t*s-e*o)*c),t*o+e*s+r*l);yr+=c,wr+=c*(t+(t=o)),kr+=c*(e+(e=s)),Tr+=c*(r+(r=l)),Ur(t,e,r)}Nr.point=function(i,a){i*=Ct;var o=Math.cos(a*=Ct);t=o*Math.cos(i),e=o*Math.sin(i),r=Math.sin(a),Nr.point=n,Ur(t,e,r)}}function qr(){Nr.point=jr}function Hr(){var t,e,r,n,i;function a(t,e){t*=Ct;var a=Math.cos(e*=Ct),o=a*Math.cos(t),s=a*Math.sin(t),l=Math.sin(e),c=n*l-i*s,u=i*o-r*l,h=r*s-n*o,f=Math.sqrt(c*c+u*u+h*h),p=r*o+n*s+i*l,d=f&&-zt(p)/f,g=Math.atan2(f,p);Ar+=d*c,Mr+=d*u,Sr+=d*h,yr+=g,wr+=g*(r+(r=o)),kr+=g*(n+(n=s)),Tr+=g*(i+(i=l)),Ur(r,n,i)}Nr.point=function(o,s){t=o,e=s,Nr.point=a,o*=Ct;var l=Math.cos(s*=Ct);r=l*Math.cos(o),n=l*Math.sin(o),i=Math.sin(s),Ur(r,n,i)},Nr.lineEnd=function(){a(t,e),Nr.lineEnd=qr,Nr.point=jr}}function Gr(t,e){function r(r,n){return r=t(r,n),e(r[0],r[1])}return t.invert&&e.invert&&(r.invert=function(r,n){return(r=e.invert(r,n))&&t.invert(r[0],r[1])}),r}function Yr(){return!0}function Wr(t,e,r,n,i){var a=[],o=[];if(t.forEach(function(t){if(!((e=t.length-1)<=0)){var e,r=t[0],n=t[e];if(Br(r,n)){i.lineStart();for(var s=0;s<e;++s)i.point((r=t[s])[0],r[1]);i.lineEnd()}else{var l=new Zr(r,t,null,!0),c=new Zr(r,null,l,!1);l.o=c,a.push(l),o.push(c),l=new Zr(n,t,null,!1),c=new Zr(n,null,l,!0),l.o=c,a.push(l),o.push(c)}}}),o.sort(e),Xr(a),Xr(o),a.length){for(var s=0,l=r,c=o.length;s<c;++s)o[s].e=l=!l;for(var u,h,f=a[0];;){for(var p=f,d=!0;p.v;)if((p=p.n)===f)return;u=p.z,i.lineStart();do{if(p.v=p.o.v=!0,p.e){if(d)for(s=0,c=u.length;s<c;++s)i.point((h=u[s])[0],h[1]);else n(p.x,p.n.x,1,i);p=p.n}else{if(d)for(s=(u=p.p.z).length-1;s>=0;--s)i.point((h=u[s])[0],h[1]);else n(p.x,p.p.x,-1,i);p=p.p}u=(p=p.o).z,d=!d}while(!p.v);i.lineEnd()}}}function Xr(t){if(e=t.length){for(var e,r,n=0,i=t[0];++n<e;)i.n=r=t[n],r.p=i,i=r;i.n=r=t[0],r.p=i}}function Zr(t,e,r,n){this.x=t,this.z=e,this.o=r,this.e=n,this.v=!1,this.n=this.p=null}function Jr(e,r,n,i){return function(a,o){var s,l=r(o),c=a.invert(i[0],i[1]),u={point:h,lineStart:p,lineEnd:d,polygonStart:function(){u.point=b,u.lineStart=_,u.lineEnd=w,s=[],g=[]},polygonEnd:function(){u.point=h,u.lineStart=p,u.lineEnd=d,s=t.merge(s);var e=function(t,e){var r=t[0],n=t[1],i=[Math.sin(r),-Math.cos(r),0],a=0,o=0;Er.reset();for(var s=0,l=e.length;s<l;++s){var c=e[s],u=c.length;if(u)for(var h=c[0],f=h[0],p=h[1]/2+At/4,d=Math.sin(p),g=Math.cos(p),v=1;;){v===u&&(v=0);var m=(t=c[v])[0],y=t[1]/2+At/4,x=Math.sin(y),b=Math.cos(y),_=m-f,w=_>=0?1:-1,k=w*_,T=k>At,A=d*x;if(Er.add(Math.atan2(A*w*Math.sin(k),g*b+A*Math.cos(k))),a+=T?_+w*Mt:_,T^f>=r^m>=r){var M=zr(Pr(h),Pr(t));Rr(M);var S=zr(i,M);Rr(S);var E=(T^_>=0?-1:1)*It(S[2]);(n>E||n===E&&(M[0]||M[1]))&&(o+=T^_>=0?1:-1)}if(!v++)break;f=m,d=x,g=b,h=t}}return(a<-kt||a<kt&&Er<-kt)^1&o}(c,g);s.length?(x||(o.polygonStart(),x=!0),Wr(s,Qr,e,n,o)):e&&(x||(o.polygonStart(),x=!0),o.lineStart(),n(null,null,1,o),o.lineEnd()),x&&(o.polygonEnd(),x=!1),s=g=null},sphere:function(){o.polygonStart(),o.lineStart(),n(null,null,1,o),o.lineEnd(),o.polygonEnd()}};function h(t,r){var n=a(t,r);e(t=n[0],r=n[1])&&o.point(t,r)}function f(t,e){var r=a(t,e);l.point(r[0],r[1])}function p(){u.point=f,l.lineStart()}function d(){u.point=h,l.lineEnd()}var g,v,m=$r(),y=r(m),x=!1;function b(t,e){v.push([t,e]);var r=a(t,e);y.point(r[0],r[1])}function _(){y.lineStart(),v=[]}function w(){b(v[0][0],v[0][1]),y.lineEnd();var t,e=y.clean(),r=m.buffer(),n=r.length;if(v.pop(),g.push(v),v=null,n)if(1&e){var i,a=-1;if((n=(t=r[0]).length-1)>0){for(x||(o.polygonStart(),x=!0),o.lineStart();++a<n;)o.point((i=t[a])[0],i[1]);o.lineEnd()}}else n>1&&2&e&&r.push(r.pop().concat(r.shift())),s.push(r.filter(Kr))}return u}}function Kr(t){return t.length>1}function $r(){var t,e=[];return{lineStart:function(){e.push(t=[])},point:function(e,r){t.push([e,r])},lineEnd:D,buffer:function(){var r=e;return e=[],t=null,r},rejoin:function(){e.length>1&&e.push(e.pop().concat(e.shift()))}}}function Qr(t,e){return((t=t.x)[0]<0?t[1]-Et-kt:Et-t[1])-((e=e.x)[0]<0?e[1]-Et-kt:Et-e[1])}var tn=Jr(Yr,function(t){var e,r=NaN,n=NaN,i=NaN;return{lineStart:function(){t.lineStart(),e=1},point:function(a,o){var s=a>0?At:-At,l=y(a-r);y(l-At)<kt?(t.point(r,n=(n+o)/2>0?Et:-Et),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),t.point(a,n),e=0):i!==s&&l>=At&&(y(r-i)<kt&&(r-=i*kt),y(a-s)<kt&&(a-=s*kt),n=function(t,e,r,n){var i,a,o=Math.sin(t-r);return y(o)>kt?Math.atan((Math.sin(e)*(a=Math.cos(n))*Math.sin(r)-Math.sin(n)*(i=Math.cos(e))*Math.sin(t))/(i*a*o)):(e+n)/2}(r,n,a,o),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),e=0),t.point(r=a,n=o),i=s},lineEnd:function(){t.lineEnd(),r=n=NaN},clean:function(){return 2-e}}},function(t,e,r,n){var i;if(null==t)i=r*Et,n.point(-At,i),n.point(0,i),n.point(At,i),n.point(At,0),n.point(At,-i),n.point(0,-i),n.point(-At,-i),n.point(-At,0),n.point(-At,i);else if(y(t[0]-e[0])>kt){var a=t[0]<e[0]?At:-At;i=r*a/2,n.point(-a,i),n.point(0,i),n.point(a,i)}else n.point(e[0],e[1])},[-At,-At/2]);function en(t,e,r,n){return function(i){var a,o=i.a,s=i.b,l=o.x,c=o.y,u=0,h=1,f=s.x-l,p=s.y-c;if(a=t-l,f||!(a>0)){if(a/=f,f<0){if(a<u)return;a<h&&(h=a)}else if(f>0){if(a>h)return;a>u&&(u=a)}if(a=r-l,f||!(a<0)){if(a/=f,f<0){if(a>h)return;a>u&&(u=a)}else if(f>0){if(a<u)return;a<h&&(h=a)}if(a=e-c,p||!(a>0)){if(a/=p,p<0){if(a<u)return;a<h&&(h=a)}else if(p>0){if(a>h)return;a>u&&(u=a)}if(a=n-c,p||!(a<0)){if(a/=p,p<0){if(a>h)return;a>u&&(u=a)}else if(p>0){if(a<u)return;a<h&&(h=a)}return u>0&&(i.a={x:l+u*f,y:c+u*p}),h<1&&(i.b={x:l+h*f,y:c+h*p}),i}}}}}}var rn=1e9;function nn(e,r,n,i){return function(l){var c,u,h,f,p,d,g,v,m,y,x,b=l,_=$r(),w=en(e,r,n,i),k={point:M,lineStart:function(){k.point=S,u&&u.push(h=[]);y=!0,m=!1,g=v=NaN},lineEnd:function(){c&&(S(f,p),d&&m&&_.rejoin(),c.push(_.buffer()));k.point=M,m&&l.lineEnd()},polygonStart:function(){l=_,c=[],u=[],x=!0},polygonEnd:function(){l=b,c=t.merge(c);var r=function(t){for(var e=0,r=u.length,n=t[1],i=0;i<r;++i)for(var a,o=1,s=u[i],l=s.length,c=s[0];o<l;++o)a=s[o],c[1]<=n?a[1]>n&&Ot(c,a,t)>0&&++e:a[1]<=n&&Ot(c,a,t)<0&&--e,c=a;return 0!==e}([e,i]),n=x&&r,a=c.length;(n||a)&&(l.polygonStart(),n&&(l.lineStart(),T(null,null,1,l),l.lineEnd()),a&&Wr(c,o,r,T,l),l.polygonEnd()),c=u=h=null}};function T(t,o,l,c){var u=0,h=0;if(null==t||(u=a(t,l))!==(h=a(o,l))||s(t,o)<0^l>0)do{c.point(0===u||3===u?e:n,u>1?i:r)}while((u=(u+l+4)%4)!==h);else c.point(o[0],o[1])}function A(t,a){return e<=t&&t<=n&&r<=a&&a<=i}function M(t,e){A(t,e)&&l.point(t,e)}function S(t,e){var r=A(t=Math.max(-rn,Math.min(rn,t)),e=Math.max(-rn,Math.min(rn,e)));if(u&&h.push([t,e]),y)f=t,p=e,d=r,y=!1,r&&(l.lineStart(),l.point(t,e));else if(r&&m)l.point(t,e);else{var n={a:{x:g,y:v},b:{x:t,y:e}};w(n)?(m||(l.lineStart(),l.point(n.a.x,n.a.y)),l.point(n.b.x,n.b.y),r||l.lineEnd(),x=!1):r&&(l.lineStart(),l.point(t,e),x=!1)}g=t,v=e,m=r}return k};function a(t,i){return y(t[0]-e)<kt?i>0?0:3:y(t[0]-n)<kt?i>0?2:1:y(t[1]-r)<kt?i>0?1:0:i>0?3:2}function o(t,e){return s(t.x,e.x)}function s(t,e){var r=a(t,1),n=a(e,1);return r!==n?r-n:0===r?e[1]-t[1]:1===r?t[0]-e[0]:2===r?t[1]-e[1]:e[0]-t[0]}}function an(t){var e=0,r=At/3,n=Cn(t),i=n(e,r);return i.parallels=function(t){return arguments.length?n(e=t[0]*At/180,r=t[1]*At/180):[e/At*180,r/At*180]},i}function on(t,e){var r=Math.sin(t),n=(r+Math.sin(e))/2,i=1+r*(2*n-r),a=Math.sqrt(i)/n;function o(t,e){var r=Math.sqrt(i-2*n*Math.sin(e))/n;return[r*Math.sin(t*=n),a-r*Math.cos(t)]}return o.invert=function(t,e){var r=a-e;return[Math.atan2(t,r)/n,It((i-(t*t+r*r)*n*n)/(2*n))]},o}t.geo.clipExtent=function(){var t,e,r,n,i,a,o={stream:function(t){return i&&(i.valid=!1),(i=a(t)).valid=!0,i},extent:function(s){return arguments.length?(a=nn(t=+s[0][0],e=+s[0][1],r=+s[1][0],n=+s[1][1]),i&&(i.valid=!1,i=null),o):[[t,e],[r,n]]}};return o.extent([[0,0],[960,500]])},(t.geo.conicEqualArea=function(){return an(on)}).raw=on,t.geo.albers=function(){return t.geo.conicEqualArea().rotate([96,0]).center([-.6,38.7]).parallels([29.5,45.5]).scale(1070)},t.geo.albersUsa=function(){var e,r,n,i,a=t.geo.albers(),o=t.geo.conicEqualArea().rotate([154,0]).center([-2,58.5]).parallels([55,65]),s=t.geo.conicEqualArea().rotate([157,0]).center([-3,19.9]).parallels([8,18]),l={point:function(t,r){e=[t,r]}};function c(t){var a=t[0],o=t[1];return e=null,r(a,o),e||(n(a,o),e)||i(a,o),e}return c.invert=function(t){var e=a.scale(),r=a.translate(),n=(t[0]-r[0])/e,i=(t[1]-r[1])/e;return(i>=.12&&i<.234&&n>=-.425&&n<-.214?o:i>=.166&&i<.234&&n>=-.214&&n<-.115?s:a).invert(t)},c.stream=function(t){var e=a.stream(t),r=o.stream(t),n=s.stream(t);return{point:function(t,i){e.point(t,i),r.point(t,i),n.point(t,i)},sphere:function(){e.sphere(),r.sphere(),n.sphere()},lineStart:function(){e.lineStart(),r.lineStart(),n.lineStart()},lineEnd:function(){e.lineEnd(),r.lineEnd(),n.lineEnd()},polygonStart:function(){e.polygonStart(),r.polygonStart(),n.polygonStart()},polygonEnd:function(){e.polygonEnd(),r.polygonEnd(),n.polygonEnd()}}},c.precision=function(t){return arguments.length?(a.precision(t),o.precision(t),s.precision(t),c):a.precision()},c.scale=function(t){return arguments.length?(a.scale(t),o.scale(.35*t),s.scale(t),c.translate(a.translate())):a.scale()},c.translate=function(t){if(!arguments.length)return a.translate();var e=a.scale(),u=+t[0],h=+t[1];return r=a.translate(t).clipExtent([[u-.455*e,h-.238*e],[u+.455*e,h+.238*e]]).stream(l).point,n=o.translate([u-.307*e,h+.201*e]).clipExtent([[u-.425*e+kt,h+.12*e+kt],[u-.214*e-kt,h+.234*e-kt]]).stream(l).point,i=s.translate([u-.205*e,h+.212*e]).clipExtent([[u-.214*e+kt,h+.166*e+kt],[u-.115*e-kt,h+.234*e-kt]]).stream(l).point,c},c.scale(1070)};var sn,ln,cn,un,hn,fn,pn={point:D,lineStart:D,lineEnd:D,polygonStart:function(){ln=0,pn.lineStart=dn},polygonEnd:function(){pn.lineStart=pn.lineEnd=pn.point=D,sn+=y(ln/2)}};function dn(){var t,e,r,n;function i(t,e){ln+=n*t-r*e,r=t,n=e}pn.point=function(a,o){pn.point=i,t=r=a,e=n=o},pn.lineEnd=function(){i(t,e)}}var gn={point:function(t,e){t<cn&&(cn=t);t>hn&&(hn=t);e<un&&(un=e);e>fn&&(fn=e)},lineStart:D,lineEnd:D,polygonStart:D,polygonEnd:D};function vn(){var t=mn(4.5),e=[],r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(e){return t=mn(e),r},result:function(){if(e.length){var t=e.join(\"\");return e=[],t}}};function n(r,n){e.push(\"M\",r,\",\",n,t)}function i(t,n){e.push(\"M\",t,\",\",n),r.point=a}function a(t,r){e.push(\"L\",t,\",\",r)}function o(){r.point=n}function s(){e.push(\"Z\")}return r}function mn(t){return\"m0,\"+t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+-2*t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+2*t+\"z\"}var yn,xn={point:bn,lineStart:_n,lineEnd:wn,polygonStart:function(){xn.lineStart=kn},polygonEnd:function(){xn.point=bn,xn.lineStart=_n,xn.lineEnd=wn}};function bn(t,e){xr+=t,br+=e,++_r}function _n(){var t,e;function r(r,n){var i=r-t,a=n-e,o=Math.sqrt(i*i+a*a);wr+=o*(t+r)/2,kr+=o*(e+n)/2,Tr+=o,bn(t=r,e=n)}xn.point=function(n,i){xn.point=r,bn(t=n,e=i)}}function wn(){xn.point=bn}function kn(){var t,e,r,n;function i(t,e){var i=t-r,a=e-n,o=Math.sqrt(i*i+a*a);wr+=o*(r+t)/2,kr+=o*(n+e)/2,Tr+=o,Ar+=(o=n*t-r*e)*(r+t),Mr+=o*(n+e),Sr+=3*o,bn(r=t,n=e)}xn.point=function(a,o){xn.point=i,bn(t=r=a,e=n=o)},xn.lineEnd=function(){i(t,e)}}function Tn(t){var e=4.5,r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(t){return e=t,r},result:D};function n(r,n){t.moveTo(r+e,n),t.arc(r,n,e,0,Mt)}function i(e,n){t.moveTo(e,n),r.point=a}function a(e,r){t.lineTo(e,r)}function o(){r.point=n}function s(){t.closePath()}return r}function An(t){var e=.5,r=Math.cos(30*Ct),n=16;function i(e){return(n?function(e){var r,i,o,s,l,c,u,h,f,p,d,g,v={point:m,lineStart:y,lineEnd:b,polygonStart:function(){e.polygonStart(),v.lineStart=_},polygonEnd:function(){e.polygonEnd(),v.lineStart=y}};function m(r,n){r=t(r,n),e.point(r[0],r[1])}function y(){h=NaN,v.point=x,e.lineStart()}function x(r,i){var o=Pr([r,i]),s=t(r,i);a(h,f,u,p,d,g,h=s[0],f=s[1],u=r,p=o[0],d=o[1],g=o[2],n,e),e.point(h,f)}function b(){v.point=m,e.lineEnd()}function _(){y(),v.point=w,v.lineEnd=k}function w(t,e){x(r=t,e),i=h,o=f,s=p,l=d,c=g,v.point=x}function k(){a(h,f,u,p,d,g,i,o,r,s,l,c,n,e),v.lineEnd=b,b()}return v}:function(e){return Sn(e,function(r,n){r=t(r,n),e.point(r[0],r[1])})})(e)}function a(n,i,o,s,l,c,u,h,f,p,d,g,v,m){var x=u-n,b=h-i,_=x*x+b*b;if(_>4*e&&v--){var w=s+p,k=l+d,T=c+g,A=Math.sqrt(w*w+k*k+T*T),M=Math.asin(T/=A),S=y(y(T)-1)<kt||y(o-f)<kt?(o+f)/2:Math.atan2(k,w),E=t(S,M),C=E[0],L=E[1],P=C-n,O=L-i,z=b*P-x*O;(z*z/_>e||y((x*P+b*O)/_-.5)>.3||s*p+l*d+c*g<r)&&(a(n,i,o,s,l,c,C,L,S,w/=A,k/=A,T,v,m),m.point(C,L),a(C,L,S,w,k,T,u,h,f,p,d,g,v,m))}}return i.precision=function(t){return arguments.length?(n=(e=t*t)>0&&16,i):Math.sqrt(e)},i}function Mn(t){this.stream=t}function Sn(t,e){return{point:e,sphere:function(){t.sphere()},lineStart:function(){t.lineStart()},lineEnd:function(){t.lineEnd()},polygonStart:function(){t.polygonStart()},polygonEnd:function(){t.polygonEnd()}}}function En(t){return Cn(function(){return t})()}function Cn(e){var r,n,i,a,o,s,l=An(function(t,e){return[(t=r(t,e))[0]*c+a,o-t[1]*c]}),c=150,u=480,h=250,f=0,p=0,d=0,g=0,v=0,m=tn,x=P,b=null,_=null;function w(t){return[(t=i(t[0]*Ct,t[1]*Ct))[0]*c+a,o-t[1]*c]}function k(t){return(t=i.invert((t[0]-a)/c,(o-t[1])/c))&&[t[0]*Lt,t[1]*Lt]}function T(){i=Gr(n=zn(d,g,v),r);var t=r(f,p);return a=u-t[0]*c,o=h+t[1]*c,A()}function A(){return s&&(s.valid=!1,s=null),w}return w.stream=function(t){return s&&(s.valid=!1),(s=Ln(m(n,l(x(t))))).valid=!0,s},w.clipAngle=function(t){return arguments.length?(m=null==t?(b=t,tn):function(t){var e=Math.cos(t),r=e>0,n=y(e)>kt;return Jr(i,function(t){var e,s,l,c,u;return{lineStart:function(){c=l=!1,u=1},point:function(h,f){var p,d=[h,f],g=i(h,f),v=r?g?0:o(h,f):g?o(h+(h<0?At:-At),f):0;if(!e&&(c=l=g)&&t.lineStart(),g!==l&&(p=a(e,d),(Br(e,p)||Br(d,p))&&(d[0]+=kt,d[1]+=kt,g=i(d[0],d[1]))),g!==l)u=0,g?(t.lineStart(),p=a(d,e),t.point(p[0],p[1])):(p=a(e,d),t.point(p[0],p[1]),t.lineEnd()),e=p;else if(n&&e&&r^g){var m;v&s||!(m=a(d,e,!0))||(u=0,r?(t.lineStart(),t.point(m[0][0],m[0][1]),t.point(m[1][0],m[1][1]),t.lineEnd()):(t.point(m[1][0],m[1][1]),t.lineEnd(),t.lineStart(),t.point(m[0][0],m[0][1])))}!g||e&&Br(e,d)||t.point(d[0],d[1]),e=d,l=g,s=v},lineEnd:function(){l&&t.lineEnd(),e=null},clean:function(){return u|(c&&l)<<1}}},Fn(t,6*Ct),r?[0,-t]:[-At,t-At]);function i(t,r){return Math.cos(t)*Math.cos(r)>e}function a(t,r,n){var i=[1,0,0],a=zr(Pr(t),Pr(r)),o=Or(a,a),s=a[0],l=o-s*s;if(!l)return!n&&t;var c=e*o/l,u=-e*s/l,h=zr(i,a),f=Dr(i,c);Ir(f,Dr(a,u));var p=h,d=Or(f,p),g=Or(p,p),v=d*d-g*(Or(f,f)-1);if(!(v<0)){var m=Math.sqrt(v),x=Dr(p,(-d-m)/g);if(Ir(x,f),x=Fr(x),!n)return x;var b,_=t[0],w=r[0],k=t[1],T=r[1];w<_&&(b=_,_=w,w=b);var A=w-_,M=y(A-At)<kt;if(!M&&T<k&&(b=k,k=T,T=b),M||A<kt?M?k+T>0^x[1]<(y(x[0]-_)<kt?k:T):k<=x[1]&&x[1]<=T:A>At^(_<=x[0]&&x[0]<=w)){var S=Dr(p,(-d+m)/g);return Ir(S,f),[x,Fr(S)]}}}function o(e,n){var i=r?t:At-t,a=0;return e<-i?a|=1:e>i&&(a|=2),n<-i?a|=4:n>i&&(a|=8),a}}((b=+t)*Ct),A()):b},w.clipExtent=function(t){return arguments.length?(_=t,x=t?nn(t[0][0],t[0][1],t[1][0],t[1][1]):P,A()):_},w.scale=function(t){return arguments.length?(c=+t,T()):c},w.translate=function(t){return arguments.length?(u=+t[0],h=+t[1],T()):[u,h]},w.center=function(t){return arguments.length?(f=t[0]%360*Ct,p=t[1]%360*Ct,T()):[f*Lt,p*Lt]},w.rotate=function(t){return arguments.length?(d=t[0]%360*Ct,g=t[1]%360*Ct,v=t.length>2?t[2]%360*Ct:0,T()):[d*Lt,g*Lt,v*Lt]},t.rebind(w,l,\"precision\"),function(){return r=e.apply(this,arguments),w.invert=r.invert&&k,T()}}function Ln(t){return Sn(t,function(e,r){t.point(e*Ct,r*Ct)})}function Pn(t,e){return[t,e]}function On(t,e){return[t>At?t-Mt:t<-At?t+Mt:t,e]}function zn(t,e,r){return t?e||r?Gr(Dn(t),Rn(e,r)):Dn(t):e||r?Rn(e,r):On}function In(t){return function(e,r){return[(e+=t)>At?e-Mt:e<-At?e+Mt:e,r]}}function Dn(t){var e=In(t);return e.invert=In(-t),e}function Rn(t,e){var r=Math.cos(t),n=Math.sin(t),i=Math.cos(e),a=Math.sin(e);function o(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*r+s*n;return[Math.atan2(l*i-u*a,s*r-c*n),It(u*i+l*a)]}return o.invert=function(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*i-l*a;return[Math.atan2(l*i+c*a,s*r+u*n),It(u*r-s*n)]},o}function Fn(t,e){var r=Math.cos(t),n=Math.sin(t);return function(i,a,o,s){var l=o*e;null!=i?(i=Bn(r,i),a=Bn(r,a),(o>0?i<a:i>a)&&(i+=o*Mt)):(i=t+o*Mt,a=t-.5*l);for(var c,u=i;o>0?u>a:u<a;u-=l)s.point((c=Fr([r,-n*Math.cos(u),-n*Math.sin(u)]))[0],c[1])}}function Bn(t,e){var r=Pr(e);r[0]-=t,Rr(r);var n=zt(-r[1]);return((-r[2]<0?-n:n)+2*Math.PI-kt)%(2*Math.PI)}function Nn(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map(function(e){return[t,e]})}}function jn(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map(function(e){return[e,t]})}}function Un(t){return t.source}function Vn(t){return t.target}t.geo.path=function(){var e,r,n,i,a,o=4.5;function s(e){return e&&(\"function\"==typeof o&&i.pointRadius(+o.apply(this,arguments)),a&&a.valid||(a=n(i)),t.geo.stream(e,a)),i.result()}function l(){return a=null,s}return s.area=function(e){return sn=0,t.geo.stream(e,n(pn)),sn},s.centroid=function(e){return xr=br=_r=wr=kr=Tr=Ar=Mr=Sr=0,t.geo.stream(e,n(xn)),Sr?[Ar/Sr,Mr/Sr]:Tr?[wr/Tr,kr/Tr]:_r?[xr/_r,br/_r]:[NaN,NaN]},s.bounds=function(e){return hn=fn=-(cn=un=1/0),t.geo.stream(e,n(gn)),[[cn,un],[hn,fn]]},s.projection=function(t){return arguments.length?(n=(e=t)?t.stream||(r=t,i=An(function(t,e){return r([t*Lt,e*Lt])}),function(t){return Ln(i(t))}):P,l()):e;var r,i},s.context=function(t){return arguments.length?(i=null==(r=t)?new vn:new Tn(t),\"function\"!=typeof o&&i.pointRadius(o),l()):r},s.pointRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:(i.pointRadius(+t),+t),s):o},s.projection(t.geo.albersUsa()).context(null)},t.geo.transform=function(t){return{stream:function(e){var r=new Mn(e);for(var n in t)r[n]=t[n];return r}}},Mn.prototype={point:function(t,e){this.stream.point(t,e)},sphere:function(){this.stream.sphere()},lineStart:function(){this.stream.lineStart()},lineEnd:function(){this.stream.lineEnd()},polygonStart:function(){this.stream.polygonStart()},polygonEnd:function(){this.stream.polygonEnd()}},t.geo.projection=En,t.geo.projectionMutator=Cn,(t.geo.equirectangular=function(){return En(Pn)}).raw=Pn.invert=Pn,t.geo.rotation=function(t){function e(e){return(e=t(e[0]*Ct,e[1]*Ct))[0]*=Lt,e[1]*=Lt,e}return t=zn(t[0]%360*Ct,t[1]*Ct,t.length>2?t[2]*Ct:0),e.invert=function(e){return(e=t.invert(e[0]*Ct,e[1]*Ct))[0]*=Lt,e[1]*=Lt,e},e},On.invert=Pn,t.geo.circle=function(){var t,e,r=[0,0],n=6;function i(){var t=\"function\"==typeof r?r.apply(this,arguments):r,n=zn(-t[0]*Ct,-t[1]*Ct,0).invert,i=[];return e(null,null,1,{point:function(t,e){i.push(t=n(t,e)),t[0]*=Lt,t[1]*=Lt}}),{type:\"Polygon\",coordinates:[i]}}return i.origin=function(t){return arguments.length?(r=t,i):r},i.angle=function(r){return arguments.length?(e=Fn((t=+r)*Ct,n*Ct),i):t},i.precision=function(r){return arguments.length?(e=Fn(t*Ct,(n=+r)*Ct),i):n},i.angle(90)},t.geo.distance=function(t,e){var r,n=(e[0]-t[0])*Ct,i=t[1]*Ct,a=e[1]*Ct,o=Math.sin(n),s=Math.cos(n),l=Math.sin(i),c=Math.cos(i),u=Math.sin(a),h=Math.cos(a);return Math.atan2(Math.sqrt((r=h*o)*r+(r=c*u-l*h*s)*r),l*u+c*h*s)},t.geo.graticule=function(){var e,r,n,i,a,o,s,l,c,u,h,f,p=10,d=p,g=90,v=360,m=2.5;function x(){return{type:\"MultiLineString\",coordinates:b()}}function b(){return t.range(Math.ceil(i/g)*g,n,g).map(h).concat(t.range(Math.ceil(l/v)*v,s,v).map(f)).concat(t.range(Math.ceil(r/p)*p,e,p).filter(function(t){return y(t%g)>kt}).map(c)).concat(t.range(Math.ceil(o/d)*d,a,d).filter(function(t){return y(t%v)>kt}).map(u))}return x.lines=function(){return b().map(function(t){return{type:\"LineString\",coordinates:t}})},x.outline=function(){return{type:\"Polygon\",coordinates:[h(i).concat(f(s).slice(1),h(n).reverse().slice(1),f(l).reverse().slice(1))]}},x.extent=function(t){return arguments.length?x.majorExtent(t).minorExtent(t):x.minorExtent()},x.majorExtent=function(t){return arguments.length?(i=+t[0][0],n=+t[1][0],l=+t[0][1],s=+t[1][1],i>n&&(t=i,i=n,n=t),l>s&&(t=l,l=s,s=t),x.precision(m)):[[i,l],[n,s]]},x.minorExtent=function(t){return arguments.length?(r=+t[0][0],e=+t[1][0],o=+t[0][1],a=+t[1][1],r>e&&(t=r,r=e,e=t),o>a&&(t=o,o=a,a=t),x.precision(m)):[[r,o],[e,a]]},x.step=function(t){return arguments.length?x.majorStep(t).minorStep(t):x.minorStep()},x.majorStep=function(t){return arguments.length?(g=+t[0],v=+t[1],x):[g,v]},x.minorStep=function(t){return arguments.length?(p=+t[0],d=+t[1],x):[p,d]},x.precision=function(t){return arguments.length?(m=+t,c=Nn(o,a,90),u=jn(r,e,m),h=Nn(l,s,90),f=jn(i,n,m),x):m},x.majorExtent([[-180,-90+kt],[180,90-kt]]).minorExtent([[-180,-80-kt],[180,80+kt]])},t.geo.greatArc=function(){var e,r,n=Un,i=Vn;function a(){return{type:\"LineString\",coordinates:[e||n.apply(this,arguments),r||i.apply(this,arguments)]}}return a.distance=function(){return t.geo.distance(e||n.apply(this,arguments),r||i.apply(this,arguments))},a.source=function(t){return arguments.length?(n=t,e=\"function\"==typeof t?null:t,a):n},a.target=function(t){return arguments.length?(i=t,r=\"function\"==typeof t?null:t,a):i},a.precision=function(){return arguments.length?a:0},a},t.geo.interpolate=function(t,e){return r=t[0]*Ct,n=t[1]*Ct,i=e[0]*Ct,a=e[1]*Ct,o=Math.cos(n),s=Math.sin(n),l=Math.cos(a),c=Math.sin(a),u=o*Math.cos(r),h=o*Math.sin(r),f=l*Math.cos(i),p=l*Math.sin(i),d=2*Math.asin(Math.sqrt(Rt(a-n)+o*l*Rt(i-r))),g=1/Math.sin(d),(v=d?function(t){var e=Math.sin(t*=d)*g,r=Math.sin(d-t)*g,n=r*u+e*f,i=r*h+e*p,a=r*s+e*c;return[Math.atan2(i,n)*Lt,Math.atan2(a,Math.sqrt(n*n+i*i))*Lt]}:function(){return[r*Lt,n*Lt]}).distance=d,v;var r,n,i,a,o,s,l,c,u,h,f,p,d,g,v},t.geo.length=function(e){return yn=0,t.geo.stream(e,qn),yn};var qn={sphere:D,point:D,lineStart:function(){var t,e,r;function n(n,i){var a=Math.sin(i*=Ct),o=Math.cos(i),s=y((n*=Ct)-t),l=Math.cos(s);yn+=Math.atan2(Math.sqrt((s=o*Math.sin(s))*s+(s=r*a-e*o*l)*s),e*a+r*o*l),t=n,e=a,r=o}qn.point=function(i,a){t=i*Ct,e=Math.sin(a*=Ct),r=Math.cos(a),qn.point=n},qn.lineEnd=function(){qn.point=qn.lineEnd=D}},lineEnd:D,polygonStart:D,polygonEnd:D};function Hn(t,e){function r(e,r){var n=Math.cos(e),i=Math.cos(r),a=t(n*i);return[a*i*Math.sin(e),a*Math.sin(r)]}return r.invert=function(t,r){var n=Math.sqrt(t*t+r*r),i=e(n),a=Math.sin(i),o=Math.cos(i);return[Math.atan2(t*a,n*o),Math.asin(n&&r*a/n)]},r}var Gn=Hn(function(t){return Math.sqrt(2/(1+t))},function(t){return 2*Math.asin(t/2)});(t.geo.azimuthalEqualArea=function(){return En(Gn)}).raw=Gn;var Yn=Hn(function(t){var e=Math.acos(t);return e&&e/Math.sin(e)},P);function Wn(t,e){var r=Math.cos(t),n=function(t){return Math.tan(At/4+t/2)},i=t===e?Math.sin(t):Math.log(r/Math.cos(e))/Math.log(n(e)/n(t)),a=r*Math.pow(n(t),i)/i;if(!i)return Jn;function o(t,e){a>0?e<-Et+kt&&(e=-Et+kt):e>Et-kt&&(e=Et-kt);var r=a/Math.pow(n(e),i);return[r*Math.sin(i*t),a-r*Math.cos(i*t)]}return o.invert=function(t,e){var r=a-e,n=Pt(i)*Math.sqrt(t*t+r*r);return[Math.atan2(t,r)/i,2*Math.atan(Math.pow(a/n,1/i))-Et]},o}function Xn(t,e){var r=Math.cos(t),n=t===e?Math.sin(t):(r-Math.cos(e))/(e-t),i=r/n+t;if(y(n)<kt)return Pn;function a(t,e){var r=i-e;return[r*Math.sin(n*t),i-r*Math.cos(n*t)]}return a.invert=function(t,e){var r=i-e;return[Math.atan2(t,r)/n,i-Pt(n)*Math.sqrt(t*t+r*r)]},a}(t.geo.azimuthalEquidistant=function(){return En(Yn)}).raw=Yn,(t.geo.conicConformal=function(){return an(Wn)}).raw=Wn,(t.geo.conicEquidistant=function(){return an(Xn)}).raw=Xn;var Zn=Hn(function(t){return 1/t},Math.atan);function Jn(t,e){return[t,Math.log(Math.tan(At/4+e/2))]}function Kn(t){var e,r=En(t),n=r.scale,i=r.translate,a=r.clipExtent;return r.scale=function(){var t=n.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.translate=function(){var t=i.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.clipExtent=function(t){var o=a.apply(r,arguments);if(o===r){if(e=null==t){var s=At*n(),l=i();a([[l[0]-s,l[1]-s],[l[0]+s,l[1]+s]])}}else e&&(o=null);return o},r.clipExtent(null)}(t.geo.gnomonic=function(){return En(Zn)}).raw=Zn,Jn.invert=function(t,e){return[t,2*Math.atan(Math.exp(e))-Et]},(t.geo.mercator=function(){return Kn(Jn)}).raw=Jn;var $n=Hn(function(){return 1},Math.asin);(t.geo.orthographic=function(){return En($n)}).raw=$n;var Qn=Hn(function(t){return 1/(1+t)},function(t){return 2*Math.atan(t)});function ti(t,e){return[Math.log(Math.tan(At/4+e/2)),-t]}function ei(t){return t[0]}function ri(t){return t[1]}function ni(t){for(var e=t.length,r=[0,1],n=2,i=2;i<e;i++){for(;n>1&&Ot(t[r[n-2]],t[r[n-1]],t[i])<=0;)--n;r[n++]=i}return r.slice(0,n)}function ii(t,e){return t[0]-e[0]||t[1]-e[1]}(t.geo.stereographic=function(){return En(Qn)}).raw=Qn,ti.invert=function(t,e){return[-e,2*Math.atan(Math.exp(t))-Et]},(t.geo.transverseMercator=function(){var t=Kn(ti),e=t.center,r=t.rotate;return t.center=function(t){return t?e([-t[1],t[0]]):[(t=e())[1],-t[0]]},t.rotate=function(t){return t?r([t[0],t[1],t.length>2?t[2]+90:90]):[(t=r())[0],t[1],t[2]-90]},r([0,0,90])}).raw=ti,t.geom={},t.geom.hull=function(t){var e=ei,r=ri;if(arguments.length)return n(t);function n(t){if(t.length<3)return[];var n,i=ve(e),a=ve(r),o=t.length,s=[],l=[];for(n=0;n<o;n++)s.push([+i.call(this,t[n],n),+a.call(this,t[n],n),n]);for(s.sort(ii),n=0;n<o;n++)l.push([s[n][0],-s[n][1]]);var c=ni(s),u=ni(l),h=u[0]===c[0],f=u[u.length-1]===c[c.length-1],p=[];for(n=c.length-1;n>=0;--n)p.push(t[s[c[n]][2]]);for(n=+h;n<u.length-f;++n)p.push(t[s[u[n]][2]]);return p}return n.x=function(t){return arguments.length?(e=t,n):e},n.y=function(t){return arguments.length?(r=t,n):r},n},t.geom.polygon=function(t){return V(t,ai),t};var ai=t.geom.polygon.prototype=[];function oi(t,e,r){return(r[0]-e[0])*(t[1]-e[1])<(r[1]-e[1])*(t[0]-e[0])}function si(t,e,r,n){var i=t[0],a=r[0],o=e[0]-i,s=n[0]-a,l=t[1],c=r[1],u=e[1]-l,h=n[1]-c,f=(s*(l-c)-h*(i-a))/(h*o-s*u);return[i+f*o,l+f*u]}function li(t){var e=t[0],r=t[t.length-1];return!(e[0]-r[0]||e[1]-r[1])}ai.area=function(){for(var t,e=-1,r=this.length,n=this[r-1],i=0;++e<r;)t=n,n=this[e],i+=t[1]*n[0]-t[0]*n[1];return.5*i},ai.centroid=function(t){var e,r,n=-1,i=this.length,a=0,o=0,s=this[i-1];for(arguments.length||(t=-1/(6*this.area()));++n<i;)e=s,s=this[n],r=e[0]*s[1]-s[0]*e[1],a+=(e[0]+s[0])*r,o+=(e[1]+s[1])*r;return[a*t,o*t]},ai.clip=function(t){for(var e,r,n,i,a,o,s=li(t),l=-1,c=this.length-li(this),u=this[c-1];++l<c;){for(e=t.slice(),t.length=0,i=this[l],a=e[(n=e.length-s)-1],r=-1;++r<n;)oi(o=e[r],u,i)?(oi(a,u,i)||t.push(si(a,o,u,i)),t.push(o)):oi(a,u,i)&&t.push(si(a,o,u,i)),a=o;s&&t.push(t[0]),u=i}return t};var ci,ui,hi,fi,pi,di=[],gi=[];function vi(){Ii(this),this.edge=this.site=this.circle=null}function mi(t){var e=di.pop()||new vi;return e.site=t,e}function yi(t){Si(t),hi.remove(t),di.push(t),Ii(t)}function xi(t){var e=t.circle,r=e.x,n=e.cy,i={x:r,y:n},a=t.P,o=t.N,s=[t];yi(t);for(var l=a;l.circle&&y(r-l.circle.x)<kt&&y(n-l.circle.cy)<kt;)a=l.P,s.unshift(l),yi(l),l=a;s.unshift(l),Si(l);for(var c=o;c.circle&&y(r-c.circle.x)<kt&&y(n-c.circle.cy)<kt;)o=c.N,s.push(c),yi(c),c=o;s.push(c),Si(c);var u,h=s.length;for(u=1;u<h;++u)c=s[u],l=s[u-1],Pi(c.edge,l.site,c.site,i);l=s[0],(c=s[h-1]).edge=Li(l.site,c.site,null,i),Mi(l),Mi(c)}function bi(t){for(var e,r,n,i,a=t.x,o=t.y,s=hi._;s;)if((n=_i(s,o)-a)>kt)s=s.L;else{if(!((i=a-wi(s,o))>kt)){n>-kt?(e=s.P,r=s):i>-kt?(e=s,r=s.N):e=r=s;break}if(!s.R){e=s;break}s=s.R}var l=mi(t);if(hi.insert(e,l),e||r){if(e===r)return Si(e),r=mi(e.site),hi.insert(l,r),l.edge=r.edge=Li(e.site,l.site),Mi(e),void Mi(r);if(r){Si(e),Si(r);var c=e.site,u=c.x,h=c.y,f=t.x-u,p=t.y-h,d=r.site,g=d.x-u,v=d.y-h,m=2*(f*v-p*g),y=f*f+p*p,x=g*g+v*v,b={x:(v*y-p*x)/m+u,y:(f*x-g*y)/m+h};Pi(r.edge,c,d,b),l.edge=Li(c,t,null,b),r.edge=Li(t,d,null,b),Mi(e),Mi(r)}else l.edge=Li(e.site,l.site)}}function _i(t,e){var r=t.site,n=r.x,i=r.y,a=i-e;if(!a)return n;var o=t.P;if(!o)return-1/0;var s=(r=o.site).x,l=r.y,c=l-e;if(!c)return s;var u=s-n,h=1/a-1/c,f=u/c;return h?(-f+Math.sqrt(f*f-2*h*(u*u/(-2*c)-l+c/2+i-a/2)))/h+n:(n+s)/2}function wi(t,e){var r=t.N;if(r)return _i(r,e);var n=t.site;return n.y===e?n.x:1/0}function ki(t){this.site=t,this.edges=[]}function Ti(t,e){return e.angle-t.angle}function Ai(){Ii(this),this.x=this.y=this.arc=this.site=this.cy=null}function Mi(t){var e=t.P,r=t.N;if(e&&r){var n=e.site,i=t.site,a=r.site;if(n!==a){var o=i.x,s=i.y,l=n.x-o,c=n.y-s,u=a.x-o,h=2*(l*(v=a.y-s)-c*u);if(!(h>=-Tt)){var f=l*l+c*c,p=u*u+v*v,d=(v*f-c*p)/h,g=(l*p-u*f)/h,v=g+s,m=gi.pop()||new Ai;m.arc=t,m.site=i,m.x=d+o,m.y=v+Math.sqrt(d*d+g*g),m.cy=v,t.circle=m;for(var y=null,x=pi._;x;)if(m.y<x.y||m.y===x.y&&m.x<=x.x){if(!x.L){y=x.P;break}x=x.L}else{if(!x.R){y=x;break}x=x.R}pi.insert(y,m),y||(fi=m)}}}}function Si(t){var e=t.circle;e&&(e.P||(fi=e.N),pi.remove(e),gi.push(e),Ii(e),t.circle=null)}function Ei(t,e){var r=t.b;if(r)return!0;var n,i,a=t.a,o=e[0][0],s=e[1][0],l=e[0][1],c=e[1][1],u=t.l,h=t.r,f=u.x,p=u.y,d=h.x,g=h.y,v=(f+d)/2,m=(p+g)/2;if(g===p){if(v<o||v>=s)return;if(f>d){if(a){if(a.y>=c)return}else a={x:v,y:l};r={x:v,y:c}}else{if(a){if(a.y<l)return}else a={x:v,y:c};r={x:v,y:l}}}else if(i=m-(n=(f-d)/(g-p))*v,n<-1||n>1)if(f>d){if(a){if(a.y>=c)return}else a={x:(l-i)/n,y:l};r={x:(c-i)/n,y:c}}else{if(a){if(a.y<l)return}else a={x:(c-i)/n,y:c};r={x:(l-i)/n,y:l}}else if(p<g){if(a){if(a.x>=s)return}else a={x:o,y:n*o+i};r={x:s,y:n*s+i}}else{if(a){if(a.x<o)return}else a={x:s,y:n*s+i};r={x:o,y:n*o+i}}return t.a=a,t.b=r,!0}function Ci(t,e){this.l=t,this.r=e,this.a=this.b=null}function Li(t,e,r,n){var i=new Ci(t,e);return ci.push(i),r&&Pi(i,t,e,r),n&&Pi(i,e,t,n),ui[t.i].edges.push(new Oi(i,t,e)),ui[e.i].edges.push(new Oi(i,e,t)),i}function Pi(t,e,r,n){t.a||t.b?t.l===r?t.b=n:t.a=n:(t.a=n,t.l=e,t.r=r)}function Oi(t,e,r){var n=t.a,i=t.b;this.edge=t,this.site=e,this.angle=r?Math.atan2(r.y-e.y,r.x-e.x):t.l===e?Math.atan2(i.x-n.x,n.y-i.y):Math.atan2(n.x-i.x,i.y-n.y)}function zi(){this._=null}function Ii(t){t.U=t.C=t.L=t.R=t.P=t.N=null}function Di(t,e){var r=e,n=e.R,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.R=n.L,r.R&&(r.R.U=r),n.L=r}function Ri(t,e){var r=e,n=e.L,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.L=n.R,r.L&&(r.L.U=r),n.R=r}function Fi(t){for(;t.L;)t=t.L;return t}function Bi(t,e){var r,n,i,a=t.sort(Ni).pop();for(ci=[],ui=new Array(t.length),hi=new zi,pi=new zi;;)if(i=fi,a&&(!i||a.y<i.y||a.y===i.y&&a.x<i.x))a.x===r&&a.y===n||(ui[a.i]=new ki(a),bi(a),r=a.x,n=a.y),a=t.pop();else{if(!i)break;xi(i.arc)}e&&(function(t){for(var e,r=ci,n=en(t[0][0],t[0][1],t[1][0],t[1][1]),i=r.length;i--;)(!Ei(e=r[i],t)||!n(e)||y(e.a.x-e.b.x)<kt&&y(e.a.y-e.b.y)<kt)&&(e.a=e.b=null,r.splice(i,1))}(e),function(t){for(var e,r,n,i,a,o,s,l,c,u,h=t[0][0],f=t[1][0],p=t[0][1],d=t[1][1],g=ui,v=g.length;v--;)if((a=g[v])&&a.prepare())for(l=(s=a.edges).length,o=0;o<l;)n=(u=s[o].end()).x,i=u.y,e=(c=s[++o%l].start()).x,r=c.y,(y(n-e)>kt||y(i-r)>kt)&&(s.splice(o,0,new Oi((m=a.site,x=u,b=y(n-h)<kt&&d-i>kt?{x:h,y:y(e-h)<kt?r:d}:y(i-d)<kt&&f-n>kt?{x:y(r-d)<kt?e:f,y:d}:y(n-f)<kt&&i-p>kt?{x:f,y:y(e-f)<kt?r:p}:y(i-p)<kt&&n-h>kt?{x:y(r-p)<kt?e:h,y:p}:null,_=void 0,_=new Ci(m,null),_.a=x,_.b=b,ci.push(_),_),a.site,null)),++l);var m,x,b,_}(e));var o={cells:ui,edges:ci};return hi=pi=ci=ui=null,o}function Ni(t,e){return e.y-t.y||e.x-t.x}ki.prototype.prepare=function(){for(var t,e=this.edges,r=e.length;r--;)(t=e[r].edge).b&&t.a||e.splice(r,1);return e.sort(Ti),e.length},Oi.prototype={start:function(){return this.edge.l===this.site?this.edge.a:this.edge.b},end:function(){return this.edge.l===this.site?this.edge.b:this.edge.a}},zi.prototype={insert:function(t,e){var r,n,i;if(t){if(e.P=t,e.N=t.N,t.N&&(t.N.P=e),t.N=e,t.R){for(t=t.R;t.L;)t=t.L;t.L=e}else t.R=e;r=t}else this._?(t=Fi(this._),e.P=null,e.N=t,t.P=t.L=e,r=t):(e.P=e.N=null,this._=e,r=null);for(e.L=e.R=null,e.U=r,e.C=!0,t=e;r&&r.C;)r===(n=r.U).L?(i=n.R)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.R&&(Di(this,r),r=(t=r).U),r.C=!1,n.C=!0,Ri(this,n)):(i=n.L)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.L&&(Ri(this,r),r=(t=r).U),r.C=!1,n.C=!0,Di(this,n)),r=t.U;this._.C=!1},remove:function(t){t.N&&(t.N.P=t.P),t.P&&(t.P.N=t.N),t.N=t.P=null;var e,r,n,i=t.U,a=t.L,o=t.R;if(r=a?o?Fi(o):a:o,i?i.L===t?i.L=r:i.R=r:this._=r,a&&o?(n=r.C,r.C=t.C,r.L=a,a.U=r,r!==o?(i=r.U,r.U=t.U,t=r.R,i.L=t,r.R=o,o.U=r):(r.U=i,i=r,t=r.R)):(n=t.C,t=r),t&&(t.U=i),!n)if(t&&t.C)t.C=!1;else{do{if(t===this._)break;if(t===i.L){if((e=i.R).C&&(e.C=!1,i.C=!0,Di(this,i),e=i.R),e.L&&e.L.C||e.R&&e.R.C){e.R&&e.R.C||(e.L.C=!1,e.C=!0,Ri(this,e),e=i.R),e.C=i.C,i.C=e.R.C=!1,Di(this,i),t=this._;break}}else if((e=i.L).C&&(e.C=!1,i.C=!0,Ri(this,i),e=i.L),e.L&&e.L.C||e.R&&e.R.C){e.L&&e.L.C||(e.R.C=!1,e.C=!0,Di(this,e),e=i.L),e.C=i.C,i.C=e.L.C=!1,Ri(this,i),t=this._;break}e.C=!0,t=i,i=i.U}while(!t.C);t&&(t.C=!1)}}},t.geom.voronoi=function(t){var e=ei,r=ri,n=e,i=r,a=ji;if(t)return o(t);function o(t){var e=new Array(t.length),r=a[0][0],n=a[0][1],i=a[1][0],o=a[1][1];return Bi(s(t),a).cells.forEach(function(a,s){var l=a.edges,c=a.site;(e[s]=l.length?l.map(function(t){var e=t.start();return[e.x,e.y]}):c.x>=r&&c.x<=i&&c.y>=n&&c.y<=o?[[r,o],[i,o],[i,n],[r,n]]:[]).point=t[s]}),e}function s(t){return t.map(function(t,e){return{x:Math.round(n(t,e)/kt)*kt,y:Math.round(i(t,e)/kt)*kt,i:e}})}return o.links=function(t){return Bi(s(t)).edges.filter(function(t){return t.l&&t.r}).map(function(e){return{source:t[e.l.i],target:t[e.r.i]}})},o.triangles=function(t){var e=[];return Bi(s(t)).cells.forEach(function(r,n){for(var i,a,o,s,l=r.site,c=r.edges.sort(Ti),u=-1,h=c.length,f=c[h-1].edge,p=f.l===l?f.r:f.l;++u<h;)f,i=p,p=(f=c[u].edge).l===l?f.r:f.l,n<i.i&&n<p.i&&(o=i,s=p,((a=l).x-s.x)*(o.y-a.y)-(a.x-o.x)*(s.y-a.y)<0)&&e.push([t[n],t[i.i],t[p.i]])}),e},o.x=function(t){return arguments.length?(n=ve(e=t),o):e},o.y=function(t){return arguments.length?(i=ve(r=t),o):r},o.clipExtent=function(t){return arguments.length?(a=null==t?ji:t,o):a===ji?null:a},o.size=function(t){return arguments.length?o.clipExtent(t&&[[0,0],t]):a===ji?null:a&&a[1]},o};var ji=[[-1e6,-1e6],[1e6,1e6]];function Ui(t){return t.x}function Vi(t){return t.y}function qi(e,r){e=t.rgb(e),r=t.rgb(r);var n=e.r,i=e.g,a=e.b,o=r.r-n,s=r.g-i,l=r.b-a;return function(t){return\"#\"+ce(Math.round(n+o*t))+ce(Math.round(i+s*t))+ce(Math.round(a+l*t))}}function Hi(t,e){var r,n={},i={};for(r in t)r in e?n[r]=Zi(t[r],e[r]):i[r]=t[r];for(r in e)r in t||(i[r]=e[r]);return function(t){for(r in n)i[r]=n[r](t);return i}}function Gi(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function Yi(t,e){var r,n,i,a=Wi.lastIndex=Xi.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=Wi.exec(t))&&(n=Xi.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:Gi(r,n)})),a=Xi.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?(e=l[0].x,function(t){return e(t)+\"\"}):function(){return e}:(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}t.geom.delaunay=function(e){return t.geom.voronoi().triangles(e)},t.geom.quadtree=function(t,e,r,n,i){var a,o=ei,s=ri;if(a=arguments.length)return o=Ui,s=Vi,3===a&&(i=r,n=e,r=e=0),l(t);function l(t){var l,c,u,h,f,p,d,g,v,m=ve(o),x=ve(s);if(null!=e)p=e,d=r,g=n,v=i;else if(g=v=-(p=d=1/0),c=[],u=[],f=t.length,a)for(h=0;h<f;++h)(l=t[h]).x<p&&(p=l.x),l.y<d&&(d=l.y),l.x>g&&(g=l.x),l.y>v&&(v=l.y),c.push(l.x),u.push(l.y);else for(h=0;h<f;++h){var b=+m(l=t[h],h),_=+x(l,h);b<p&&(p=b),_<d&&(d=_),b>g&&(g=b),_>v&&(v=_),c.push(b),u.push(_)}var w=g-p,k=v-d;function T(t,e,r,n,i,a,o,s){if(!isNaN(r)&&!isNaN(n))if(t.leaf){var l=t.x,c=t.y;if(null!=l)if(y(l-r)+y(c-n)<.01)A(t,e,r,n,i,a,o,s);else{var u=t.point;t.x=t.y=t.point=null,A(t,u,l,c,i,a,o,s),A(t,e,r,n,i,a,o,s)}else t.x=r,t.y=n,t.point=e}else A(t,e,r,n,i,a,o,s)}function A(t,e,r,n,i,a,o,s){var l=.5*(i+o),c=.5*(a+s),u=r>=l,h=n>=c,f=h<<1|u;t.leaf=!1,u?i=l:o=l,h?a=c:s=c,T(t=t.nodes[f]||(t.nodes[f]={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){T(M,t,+m(t,++h),+x(t,h),p,d,g,v)}}),e,r,n,i,a,o,s)}w>k?v=d+w:g=p+k;var M={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){T(M,t,+m(t,++h),+x(t,h),p,d,g,v)}};if(M.visit=function(t){!function t(e,r,n,i,a,o){if(!e(r,n,i,a,o)){var s=.5*(n+a),l=.5*(i+o),c=r.nodes;c[0]&&t(e,c[0],n,i,s,l),c[1]&&t(e,c[1],s,i,a,l),c[2]&&t(e,c[2],n,l,s,o),c[3]&&t(e,c[3],s,l,a,o)}}(t,M,p,d,g,v)},M.find=function(t){return function(t,e,r,n,i,a,o){var s,l=1/0;return function t(c,u,h,f,p){if(!(u>a||h>o||f<n||p<i)){if(d=c.point){var d,g=e-c.x,v=r-c.y,m=g*g+v*v;if(m<l){var y=Math.sqrt(l=m);n=e-y,i=r-y,a=e+y,o=r+y,s=d}}for(var x=c.nodes,b=.5*(u+f),_=.5*(h+p),w=(r>=_)<<1|e>=b,k=w+4;w<k;++w)if(c=x[3&w])switch(3&w){case 0:t(c,u,h,b,_);break;case 1:t(c,b,h,f,_);break;case 2:t(c,u,_,b,p);break;case 3:t(c,b,_,f,p)}}}(t,n,i,a,o),s}(M,t[0],t[1],p,d,g,v)},h=-1,null==e){for(;++h<f;)T(M,t[h],c[h],u[h],p,d,g,v);--h}else t.forEach(M.add);return c=u=t=l=null,M}return l.x=function(t){return arguments.length?(o=t,l):o},l.y=function(t){return arguments.length?(s=t,l):s},l.extent=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=+t[0][0],r=+t[0][1],n=+t[1][0],i=+t[1][1]),l):null==e?null:[[e,r],[n,i]]},l.size=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=r=0,n=+t[0],i=+t[1]),l):null==e?null:[n-e,i-r]},l},t.interpolateRgb=qi,t.interpolateObject=Hi,t.interpolateNumber=Gi,t.interpolateString=Yi;var Wi=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,Xi=new RegExp(Wi.source,\"g\");function Zi(e,r){for(var n,i=t.interpolators.length;--i>=0&&!(n=t.interpolators[i](e,r)););return n}function Ji(t,e){var r,n=[],i=[],a=t.length,o=e.length,s=Math.min(t.length,e.length);for(r=0;r<s;++r)n.push(Zi(t[r],e[r]));for(;r<a;++r)i[r]=t[r];for(;r<o;++r)i[r]=e[r];return function(t){for(r=0;r<s;++r)i[r]=n[r](t);return i}}t.interpolate=Zi,t.interpolators=[function(t,e){var r=typeof e;return(\"string\"===r?ge.has(e.toLowerCase())||/^(#|rgb\\(|hsl\\()/i.test(e)?qi:Yi:e instanceof Ut?qi:Array.isArray(e)?Ji:\"object\"===r&&isNaN(e)?Hi:Gi)(t,e)}],t.interpolateArray=Ji;var Ki=function(){return P},$i=t.map({linear:Ki,poly:function(t){return function(e){return Math.pow(e,t)}},quad:function(){return ra},cubic:function(){return na},sin:function(){return aa},exp:function(){return oa},circle:function(){return sa},elastic:function(t,e){var r;arguments.length<2&&(e=.45);arguments.length?r=e/Mt*Math.asin(1/t):(t=1,r=e/4);return function(n){return 1+t*Math.pow(2,-10*n)*Math.sin((n-r)*Mt/e)}},back:function(t){t||(t=1.70158);return function(e){return e*e*((t+1)*e-t)}},bounce:function(){return la}}),Qi=t.map({in:P,out:ta,\"in-out\":ea,\"out-in\":function(t){return ea(ta(t))}});function ta(t){return function(e){return 1-t(1-e)}}function ea(t){return function(e){return.5*(e<.5?t(2*e):2-t(2-2*e))}}function ra(t){return t*t}function na(t){return t*t*t}function ia(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}function aa(t){return 1-Math.cos(t*Et)}function oa(t){return Math.pow(2,10*(t-1))}function sa(t){return 1-Math.sqrt(1-t*t)}function la(t){return t<1/2.75?7.5625*t*t:t<2/2.75?7.5625*(t-=1.5/2.75)*t+.75:t<2.5/2.75?7.5625*(t-=2.25/2.75)*t+.9375:7.5625*(t-=2.625/2.75)*t+.984375}function ca(t,e){return e-=t,function(r){return Math.round(t+e*r)}}function ua(t){var e,r,n,i=[t.a,t.b],a=[t.c,t.d],o=fa(i),s=ha(i,a),l=fa(((e=a)[0]+=(n=-s)*(r=i)[0],e[1]+=n*r[1],e))||0;i[0]*a[1]<a[0]*i[1]&&(i[0]*=-1,i[1]*=-1,o*=-1,s*=-1),this.rotate=(o?Math.atan2(i[1],i[0]):Math.atan2(-a[0],a[1]))*Lt,this.translate=[t.e,t.f],this.scale=[o,l],this.skew=l?Math.atan2(s,l)*Lt:0}function ha(t,e){return t[0]*e[0]+t[1]*e[1]}function fa(t){var e=Math.sqrt(ha(t,t));return e&&(t[0]/=e,t[1]/=e),e}t.ease=function(t){var e,n=t.indexOf(\"-\"),i=n>=0?t.slice(0,n):t,a=n>=0?t.slice(n+1):\"in\";return i=$i.get(i)||Ki,a=Qi.get(a)||P,e=a(i.apply(null,r.call(arguments,1))),function(t){return t<=0?0:t>=1?1:e(t)}},t.interpolateHcl=function(e,r){e=t.hcl(e),r=t.hcl(r);var n=e.h,i=e.c,a=e.l,o=r.h-n,s=r.c-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.c:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Wt(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateHsl=function(e,r){e=t.hsl(e),r=t.hsl(r);var n=e.h,i=e.s,a=e.l,o=r.h-n,s=r.s-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.s:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Ht(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateLab=function(e,r){e=t.lab(e),r=t.lab(r);var n=e.l,i=e.a,a=e.b,o=r.l-n,s=r.a-i,l=r.b-a;return function(t){return te(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateRound=ca,t.transform=function(e){var r=i.createElementNS(t.ns.prefix.svg,\"g\");return(t.transform=function(t){if(null!=t){r.setAttribute(\"transform\",t);var e=r.transform.baseVal.consolidate()}return new ua(e?e.matrix:pa)})(e)},ua.prototype.toString=function(){return\"translate(\"+this.translate+\")rotate(\"+this.rotate+\")skewX(\"+this.skew+\")scale(\"+this.scale+\")\"};var pa={a:1,b:0,c:0,d:1,e:0,f:0};function da(t){return t.length?t.pop()+\",\":\"\"}function ga(e,r){var n=[],i=[];return e=t.transform(e),r=t.transform(r),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(\"translate(\",null,\",\",null,\")\");n.push({i:i-4,x:Gi(t[0],e[0])},{i:i-2,x:Gi(t[1],e[1])})}else(e[0]||e[1])&&r.push(\"translate(\"+e+\")\")}(e.translate,r.translate,n,i),function(t,e,r,n){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),n.push({i:r.push(da(r)+\"rotate(\",null,\")\")-2,x:Gi(t,e)})):e&&r.push(da(r)+\"rotate(\"+e+\")\")}(e.rotate,r.rotate,n,i),function(t,e,r,n){t!==e?n.push({i:r.push(da(r)+\"skewX(\",null,\")\")-2,x:Gi(t,e)}):e&&r.push(da(r)+\"skewX(\"+e+\")\")}(e.skew,r.skew,n,i),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(da(r)+\"scale(\",null,\",\",null,\")\");n.push({i:i-4,x:Gi(t[0],e[0])},{i:i-2,x:Gi(t[1],e[1])})}else 1===e[0]&&1===e[1]||r.push(da(r)+\"scale(\"+e+\")\")}(e.scale,r.scale,n,i),e=r=null,function(t){for(var e,r=-1,a=i.length;++r<a;)n[(e=i[r]).i]=e.x(t);return n.join(\"\")}}function va(t,e){return e=(e-=t=+t)||1/e,function(r){return(r-t)/e}}function ma(t,e){return e=(e-=t=+t)||1/e,function(r){return Math.max(0,Math.min(1,(r-t)/e))}}function ya(t){for(var e=t.source,r=t.target,n=function(t,e){if(t===e)return t;var r=xa(t),n=xa(e),i=r.pop(),a=n.pop(),o=null;for(;i===a;)o=i,i=r.pop(),a=n.pop();return o}(e,r),i=[e];e!==n;)e=e.parent,i.push(e);for(var a=i.length;r!==n;)i.splice(a,0,r),r=r.parent;return i}function xa(t){for(var e=[],r=t.parent;null!=r;)e.push(t),t=r,r=r.parent;return e.push(t),e}function ba(t){t.fixed|=2}function _a(t){t.fixed&=-7}function wa(t){t.fixed|=4,t.px=t.x,t.py=t.y}function ka(t){t.fixed&=-5}t.interpolateTransform=ga,t.layout={},t.layout.bundle=function(){return function(t){for(var e=[],r=-1,n=t.length;++r<n;)e.push(ya(t[r]));return e}},t.layout.chord=function(){var e,r,n,i,a,o,s,l={},c=0;function u(){var l,u,f,p,d,g={},v=[],m=t.range(i),y=[];for(e=[],r=[],l=0,p=-1;++p<i;){for(u=0,d=-1;++d<i;)u+=n[p][d];v.push(u),y.push(t.range(i)),l+=u}for(a&&m.sort(function(t,e){return a(v[t],v[e])}),o&&y.forEach(function(t,e){t.sort(function(t,r){return o(n[e][t],n[e][r])})}),l=(Mt-c*i)/l,u=0,p=-1;++p<i;){for(f=u,d=-1;++d<i;){var x=m[p],b=y[x][d],_=n[x][b],w=u,k=u+=_*l;g[x+\"-\"+b]={index:x,subindex:b,startAngle:w,endAngle:k,value:_}}r[x]={index:x,startAngle:f,endAngle:u,value:v[x]},u+=c}for(p=-1;++p<i;)for(d=p-1;++d<i;){var T=g[p+\"-\"+d],A=g[d+\"-\"+p];(T.value||A.value)&&e.push(T.value<A.value?{source:A,target:T}:{source:T,target:A})}s&&h()}function h(){e.sort(function(t,e){return s((t.source.value+t.target.value)/2,(e.source.value+e.target.value)/2)})}return l.matrix=function(t){return arguments.length?(i=(n=t)&&n.length,e=r=null,l):n},l.padding=function(t){return arguments.length?(c=t,e=r=null,l):c},l.sortGroups=function(t){return arguments.length?(a=t,e=r=null,l):a},l.sortSubgroups=function(t){return arguments.length?(o=t,e=null,l):o},l.sortChords=function(t){return arguments.length?(s=t,e&&h(),l):s},l.chords=function(){return e||u(),e},l.groups=function(){return r||u(),r},l},t.layout.force=function(){var e,r,n,i,a,o,s={},l=t.dispatch(\"start\",\"tick\",\"end\"),c=[1,1],u=.9,h=Ta,f=Aa,p=-30,d=Ma,g=.1,v=.64,m=[],y=[];function x(t){return function(e,r,n,i){if(e.point!==t){var a=e.cx-t.x,o=e.cy-t.y,s=i-r,l=a*a+o*o;if(s*s/v<l){if(l<d){var c=e.charge/l;t.px-=a*c,t.py-=o*c}return!0}if(e.point&&l&&l<d){c=e.pointCharge/l;t.px-=a*c,t.py-=o*c}}return!e.charge}}function b(e){e.px=t.event.x,e.py=t.event.y,s.resume()}return s.tick=function(){if((n*=.99)<.005)return e=null,l.end({type:\"end\",alpha:n=0}),!0;var r,s,h,f,d,v,b,_,w,k=m.length,T=y.length;for(s=0;s<T;++s)f=(h=y[s]).source,(v=(_=(d=h.target).x-f.x)*_+(w=d.y-f.y)*w)&&(_*=v=n*a[s]*((v=Math.sqrt(v))-i[s])/v,w*=v,d.x-=_*(b=f.weight+d.weight?f.weight/(f.weight+d.weight):.5),d.y-=w*b,f.x+=_*(b=1-b),f.y+=w*b);if((b=n*g)&&(_=c[0]/2,w=c[1]/2,s=-1,b))for(;++s<k;)(h=m[s]).x+=(_-h.x)*b,h.y+=(w-h.y)*b;if(p)for(!function t(e,r,n){var i=0,a=0;e.charge=0;if(!e.leaf)for(var o,s=e.nodes,l=s.length,c=-1;++c<l;)null!=(o=s[c])&&(t(o,r,n),e.charge+=o.charge,i+=o.charge*o.cx,a+=o.charge*o.cy);if(e.point){e.leaf||(e.point.x+=Math.random()-.5,e.point.y+=Math.random()-.5);var u=r*n[e.point.index];e.charge+=e.pointCharge=u,i+=u*e.point.x,a+=u*e.point.y}e.cx=i/e.charge;e.cy=a/e.charge}(r=t.geom.quadtree(m),n,o),s=-1;++s<k;)(h=m[s]).fixed||r.visit(x(h));for(s=-1;++s<k;)(h=m[s]).fixed?(h.x=h.px,h.y=h.py):(h.x-=(h.px-(h.px=h.x))*u,h.y-=(h.py-(h.py=h.y))*u);l.tick({type:\"tick\",alpha:n})},s.nodes=function(t){return arguments.length?(m=t,s):m},s.links=function(t){return arguments.length?(y=t,s):y},s.size=function(t){return arguments.length?(c=t,s):c},s.linkDistance=function(t){return arguments.length?(h=\"function\"==typeof t?t:+t,s):h},s.distance=s.linkDistance,s.linkStrength=function(t){return arguments.length?(f=\"function\"==typeof t?t:+t,s):f},s.friction=function(t){return arguments.length?(u=+t,s):u},s.charge=function(t){return arguments.length?(p=\"function\"==typeof t?t:+t,s):p},s.chargeDistance=function(t){return arguments.length?(d=t*t,s):Math.sqrt(d)},s.gravity=function(t){return arguments.length?(g=+t,s):g},s.theta=function(t){return arguments.length?(v=t*t,s):Math.sqrt(v)},s.alpha=function(t){return arguments.length?(t=+t,n?t>0?n=t:(e.c=null,e.t=NaN,e=null,l.end({type:\"end\",alpha:n=0})):t>0&&(l.start({type:\"start\",alpha:n=t}),e=Te(s.tick)),s):n},s.start=function(){var t,e,r,n=m.length,l=y.length,u=c[0],d=c[1];for(t=0;t<n;++t)(r=m[t]).index=t,r.weight=0;for(t=0;t<l;++t)\"number\"==typeof(r=y[t]).source&&(r.source=m[r.source]),\"number\"==typeof r.target&&(r.target=m[r.target]),++r.source.weight,++r.target.weight;for(t=0;t<n;++t)r=m[t],isNaN(r.x)&&(r.x=g(\"x\",u)),isNaN(r.y)&&(r.y=g(\"y\",d)),isNaN(r.px)&&(r.px=r.x),isNaN(r.py)&&(r.py=r.y);if(i=[],\"function\"==typeof h)for(t=0;t<l;++t)i[t]=+h.call(this,y[t],t);else for(t=0;t<l;++t)i[t]=h;if(a=[],\"function\"==typeof f)for(t=0;t<l;++t)a[t]=+f.call(this,y[t],t);else for(t=0;t<l;++t)a[t]=f;if(o=[],\"function\"==typeof p)for(t=0;t<n;++t)o[t]=+p.call(this,m[t],t);else for(t=0;t<n;++t)o[t]=p;function g(r,i){if(!e){for(e=new Array(n),c=0;c<n;++c)e[c]=[];for(c=0;c<l;++c){var a=y[c];e[a.source.index].push(a.target),e[a.target.index].push(a.source)}}for(var o,s=e[t],c=-1,u=s.length;++c<u;)if(!isNaN(o=s[c][r]))return o;return Math.random()*i}return s.resume()},s.resume=function(){return s.alpha(.1)},s.stop=function(){return s.alpha(0)},s.drag=function(){if(r||(r=t.behavior.drag().origin(P).on(\"dragstart.force\",ba).on(\"drag.force\",b).on(\"dragend.force\",_a)),!arguments.length)return r;this.on(\"mouseover.force\",wa).on(\"mouseout.force\",ka).call(r)},t.rebind(s,l,\"on\")};var Ta=20,Aa=1,Ma=1/0;function Sa(e,r){return t.rebind(e,r,\"sort\",\"children\",\"value\"),e.nodes=e,e.links=za,e}function Ea(t,e){for(var r=[t];null!=(t=r.pop());)if(e(t),(i=t.children)&&(n=i.length))for(var n,i;--n>=0;)r.push(i[n])}function Ca(t,e){for(var r=[t],n=[];null!=(t=r.pop());)if(n.push(t),(a=t.children)&&(i=a.length))for(var i,a,o=-1;++o<i;)r.push(a[o]);for(;null!=(t=n.pop());)e(t)}function La(t){return t.children}function Pa(t){return t.value}function Oa(t,e){return e.value-t.value}function za(e){return t.merge(e.map(function(t){return(t.children||[]).map(function(e){return{source:t,target:e}})}))}t.layout.hierarchy=function(){var t=Oa,e=La,r=Pa;function n(i){var a,o=[i],s=[];for(i.depth=0;null!=(a=o.pop());)if(s.push(a),(c=e.call(n,a,a.depth))&&(l=c.length)){for(var l,c,u;--l>=0;)o.push(u=c[l]),u.parent=a,u.depth=a.depth+1;r&&(a.value=0),a.children=c}else r&&(a.value=+r.call(n,a,a.depth)||0),delete a.children;return Ca(i,function(e){var n,i;t&&(n=e.children)&&n.sort(t),r&&(i=e.parent)&&(i.value+=e.value)}),s}return n.sort=function(e){return arguments.length?(t=e,n):t},n.children=function(t){return arguments.length?(e=t,n):e},n.value=function(t){return arguments.length?(r=t,n):r},n.revalue=function(t){return r&&(Ea(t,function(t){t.children&&(t.value=0)}),Ca(t,function(t){var e;t.children||(t.value=+r.call(n,t,t.depth)||0),(e=t.parent)&&(e.value+=t.value)})),t},n},t.layout.partition=function(){var e=t.layout.hierarchy(),r=[1,1];function n(t,n){var i=e.call(this,t,n);return function t(e,r,n,i){var a=e.children;if(e.x=r,e.y=e.depth*i,e.dx=n,e.dy=i,a&&(o=a.length)){var o,s,l,c=-1;for(n=e.value?n/e.value:0;++c<o;)t(s=a[c],r,l=s.value*n,i),r+=l}}(i[0],0,r[0],r[1]/function t(e){var r=e.children,n=0;if(r&&(i=r.length))for(var i,a=-1;++a<i;)n=Math.max(n,t(r[a]));return 1+n}(i[0])),i}return n.size=function(t){return arguments.length?(r=t,n):r},Sa(n,e)},t.layout.pie=function(){var e=Number,r=Ia,n=0,i=Mt,a=0;function o(s){var l,c=s.length,u=s.map(function(t,r){return+e.call(o,t,r)}),h=+(\"function\"==typeof n?n.apply(this,arguments):n),f=(\"function\"==typeof i?i.apply(this,arguments):i)-h,p=Math.min(Math.abs(f)/c,+(\"function\"==typeof a?a.apply(this,arguments):a)),d=p*(f<0?-1:1),g=t.sum(u),v=g?(f-c*d)/g:0,m=t.range(c),y=[];return null!=r&&m.sort(r===Ia?function(t,e){return u[e]-u[t]}:function(t,e){return r(s[t],s[e])}),m.forEach(function(t){y[t]={data:s[t],value:l=u[t],startAngle:h,endAngle:h+=l*v+d,padAngle:p}}),y}return o.value=function(t){return arguments.length?(e=t,o):e},o.sort=function(t){return arguments.length?(r=t,o):r},o.startAngle=function(t){return arguments.length?(n=t,o):n},o.endAngle=function(t){return arguments.length?(i=t,o):i},o.padAngle=function(t){return arguments.length?(a=t,o):a},o};var Ia={};function Da(t){return t.x}function Ra(t){return t.y}function Fa(t,e,r){t.y0=e,t.y=r}t.layout.stack=function(){var e=P,r=ja,n=Ua,i=Fa,a=Da,o=Ra;function s(l,c){if(!(p=l.length))return l;var u=l.map(function(t,r){return e.call(s,t,r)}),h=u.map(function(t){return t.map(function(t,e){return[a.call(s,t,e),o.call(s,t,e)]})}),f=r.call(s,h,c);u=t.permute(u,f),h=t.permute(h,f);var p,d,g,v,m=n.call(s,h,c),y=u[0].length;for(g=0;g<y;++g)for(i.call(s,u[0][g],v=m[g],h[0][g][1]),d=1;d<p;++d)i.call(s,u[d][g],v+=h[d-1][g][1],h[d][g][1]);return l}return s.values=function(t){return arguments.length?(e=t,s):e},s.order=function(t){return arguments.length?(r=\"function\"==typeof t?t:Ba.get(t)||ja,s):r},s.offset=function(t){return arguments.length?(n=\"function\"==typeof t?t:Na.get(t)||Ua,s):n},s.x=function(t){return arguments.length?(a=t,s):a},s.y=function(t){return arguments.length?(o=t,s):o},s.out=function(t){return arguments.length?(i=t,s):i},s};var Ba=t.map({\"inside-out\":function(e){var r,n,i=e.length,a=e.map(Va),o=e.map(qa),s=t.range(i).sort(function(t,e){return a[t]-a[e]}),l=0,c=0,u=[],h=[];for(r=0;r<i;++r)n=s[r],l<c?(l+=o[n],u.push(n)):(c+=o[n],h.push(n));return h.reverse().concat(u)},reverse:function(e){return t.range(e.length).reverse()},default:ja}),Na=t.map({silhouette:function(t){var e,r,n,i=t.length,a=t[0].length,o=[],s=0,l=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];n>s&&(s=n),o.push(n)}for(r=0;r<a;++r)l[r]=(s-o[r])/2;return l},wiggle:function(t){var e,r,n,i,a,o,s,l,c,u=t.length,h=t[0],f=h.length,p=[];for(p[0]=l=c=0,r=1;r<f;++r){for(e=0,i=0;e<u;++e)i+=t[e][r][1];for(e=0,a=0,s=h[r][0]-h[r-1][0];e<u;++e){for(n=0,o=(t[e][r][1]-t[e][r-1][1])/(2*s);n<e;++n)o+=(t[n][r][1]-t[n][r-1][1])/s;a+=o*t[e][r][1]}p[r]=l-=i?a/i*s:0,l<c&&(c=l)}for(r=0;r<f;++r)p[r]-=c;return p},expand:function(t){var e,r,n,i=t.length,a=t[0].length,o=1/i,s=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];if(n)for(e=0;e<i;e++)t[e][r][1]/=n;else for(e=0;e<i;e++)t[e][r][1]=o}for(r=0;r<a;++r)s[r]=0;return s},zero:Ua});function ja(e){return t.range(e.length)}function Ua(t){for(var e=-1,r=t[0].length,n=[];++e<r;)n[e]=0;return n}function Va(t){for(var e,r=1,n=0,i=t[0][1],a=t.length;r<a;++r)(e=t[r][1])>i&&(n=r,i=e);return n}function qa(t){return t.reduce(Ha,0)}function Ha(t,e){return t+e[1]}function Ga(t,e){return Ya(t,Math.ceil(Math.log(e.length)/Math.LN2+1))}function Ya(t,e){for(var r=-1,n=+t[0],i=(t[1]-n)/e,a=[];++r<=e;)a[r]=i*r+n;return a}function Wa(e){return[t.min(e),t.max(e)]}function Xa(t,e){return t.value-e.value}function Za(t,e){var r=t._pack_next;t._pack_next=e,e._pack_prev=t,e._pack_next=r,r._pack_prev=e}function Ja(t,e){t._pack_next=e,e._pack_prev=t}function Ka(t,e){var r=e.x-t.x,n=e.y-t.y,i=t.r+e.r;return.999*i*i>r*r+n*n}function $a(t){if((e=t.children)&&(l=e.length)){var e,r,n,i,a,o,s,l,c=1/0,u=-1/0,h=1/0,f=-1/0;if(e.forEach(Qa),(r=e[0]).x=-r.r,r.y=0,x(r),l>1&&((n=e[1]).x=n.r,n.y=0,x(n),l>2))for(eo(r,n,i=e[2]),x(i),Za(r,i),r._pack_prev=i,Za(i,n),n=r._pack_next,a=3;a<l;a++){eo(r,n,i=e[a]);var p=0,d=1,g=1;for(o=n._pack_next;o!==n;o=o._pack_next,d++)if(Ka(o,i)){p=1;break}if(1==p)for(s=r._pack_prev;s!==o._pack_prev&&!Ka(s,i);s=s._pack_prev,g++);p?(d<g||d==g&&n.r<r.r?Ja(r,n=o):Ja(r=s,n),a--):(Za(r,i),n=i,x(i))}var v=(c+u)/2,m=(h+f)/2,y=0;for(a=0;a<l;a++)(i=e[a]).x-=v,i.y-=m,y=Math.max(y,i.r+Math.sqrt(i.x*i.x+i.y*i.y));t.r=y,e.forEach(to)}function x(t){c=Math.min(t.x-t.r,c),u=Math.max(t.x+t.r,u),h=Math.min(t.y-t.r,h),f=Math.max(t.y+t.r,f)}}function Qa(t){t._pack_next=t._pack_prev=t}function to(t){delete t._pack_next,delete t._pack_prev}function eo(t,e,r){var n=t.r+r.r,i=e.x-t.x,a=e.y-t.y;if(n&&(i||a)){var o=e.r+r.r,s=i*i+a*a,l=.5+((n*=n)-(o*=o))/(2*s),c=Math.sqrt(Math.max(0,2*o*(n+s)-(n-=s)*n-o*o))/(2*s);r.x=t.x+l*i+c*a,r.y=t.y+l*a-c*i}else r.x=t.x+n,r.y=t.y}function ro(t,e){return t.parent==e.parent?1:2}function no(t){var e=t.children;return e.length?e[0]:t.t}function io(t){var e,r=t.children;return(e=r.length)?r[e-1]:t.t}function ao(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function oo(t,e,r){return t.a.parent===e.parent?t.a:r}function so(t){return{x:t.x,y:t.y,dx:t.dx,dy:t.dy}}function lo(t,e){var r=t.x+e[3],n=t.y+e[0],i=t.dx-e[1]-e[3],a=t.dy-e[0]-e[2];return i<0&&(r+=i/2,i=0),a<0&&(n+=a/2,a=0),{x:r,y:n,dx:i,dy:a}}function co(t){var e=t[0],r=t[t.length-1];return e<r?[e,r]:[r,e]}function uo(t){return t.rangeExtent?t.rangeExtent():co(t.range())}function ho(t,e,r,n){var i=r(t[0],t[1]),a=n(e[0],e[1]);return function(t){return a(i(t))}}function fo(t,e){var r,n=0,i=t.length-1,a=t[n],o=t[i];return o<a&&(r=n,n=i,i=r,r=a,a=o,o=r),t[n]=e.floor(a),t[i]=e.ceil(o),t}function po(t){return t?{floor:function(e){return Math.floor(e/t)*t},ceil:function(e){return Math.ceil(e/t)*t}}:go}t.layout.histogram=function(){var e=!0,r=Number,n=Wa,i=Ga;function a(a,o){for(var s,l,c=[],u=a.map(r,this),h=n.call(this,u,o),f=i.call(this,h,u,o),p=(o=-1,u.length),d=f.length-1,g=e?1:1/p;++o<d;)(s=c[o]=[]).dx=f[o+1]-(s.x=f[o]),s.y=0;if(d>0)for(o=-1;++o<p;)(l=u[o])>=h[0]&&l<=h[1]&&((s=c[t.bisect(f,l,1,d)-1]).y+=g,s.push(a[o]));return c}return a.value=function(t){return arguments.length?(r=t,a):r},a.range=function(t){return arguments.length?(n=ve(t),a):n},a.bins=function(t){return arguments.length?(i=\"number\"==typeof t?function(e){return Ya(e,t)}:ve(t),a):i},a.frequency=function(t){return arguments.length?(e=!!t,a):e},a},t.layout.pack=function(){var e,r=t.layout.hierarchy().sort(Xa),n=0,i=[1,1];function a(t,a){var o=r.call(this,t,a),s=o[0],l=i[0],c=i[1],u=null==e?Math.sqrt:\"function\"==typeof e?e:function(){return e};if(s.x=s.y=0,Ca(s,function(t){t.r=+u(t.value)}),Ca(s,$a),n){var h=n*(e?1:Math.max(2*s.r/l,2*s.r/c))/2;Ca(s,function(t){t.r+=h}),Ca(s,$a),Ca(s,function(t){t.r-=h})}return function t(e,r,n,i){var a=e.children;e.x=r+=i*e.x;e.y=n+=i*e.y;e.r*=i;if(a)for(var o=-1,s=a.length;++o<s;)t(a[o],r,n,i)}(s,l/2,c/2,e?1:1/Math.max(2*s.r/l,2*s.r/c)),o}return a.size=function(t){return arguments.length?(i=t,a):i},a.radius=function(t){return arguments.length?(e=null==t||\"function\"==typeof t?t:+t,a):e},a.padding=function(t){return arguments.length?(n=+t,a):n},Sa(a,r)},t.layout.tree=function(){var e=t.layout.hierarchy().sort(null).value(null),r=ro,n=[1,1],i=null;function a(t,a){var c=e.call(this,t,a),u=c[0],h=function(t){var e,r={A:null,children:[t]},n=[r];for(;null!=(e=n.pop());)for(var i,a=e.children,o=0,s=a.length;o<s;++o)n.push((a[o]=i={_:a[o],parent:e,children:(i=a[o].children)&&i.slice()||[],A:null,a:null,z:0,m:0,c:0,s:0,t:null,i:o}).a=i);return r.children[0]}(u);if(Ca(h,o),h.parent.m=-h.z,Ea(h,s),i)Ea(u,l);else{var f=u,p=u,d=u;Ea(u,function(t){t.x<f.x&&(f=t),t.x>p.x&&(p=t),t.depth>d.depth&&(d=t)});var g=r(f,p)/2-f.x,v=n[0]/(p.x+r(p,f)/2+g),m=n[1]/(d.depth||1);Ea(u,function(t){t.x=(t.x+g)*v,t.y=t.depth*m})}return c}function o(t){var e=t.children,n=t.parent.children,i=t.i?n[t.i-1]:null;if(e.length){!function(t){var e,r=0,n=0,i=t.children,a=i.length;for(;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(t);var a=(e[0].z+e[e.length-1].z)/2;i?(t.z=i.z+r(t._,i._),t.m=t.z-a):t.z=a}else i&&(t.z=i.z+r(t._,i._));t.parent.A=function(t,e,n){if(e){for(var i,a=t,o=t,s=e,l=a.parent.children[0],c=a.m,u=o.m,h=s.m,f=l.m;s=io(s),a=no(a),s&&a;)l=no(l),(o=io(o)).a=t,(i=s.z+h-a.z-c+r(s._,a._))>0&&(ao(oo(s,t,n),t,i),c+=i,u+=i),h+=s.m,c+=a.m,f+=l.m,u+=o.m;s&&!io(o)&&(o.t=s,o.m+=h-u),a&&!no(l)&&(l.t=a,l.m+=c-f,n=t)}return n}(t,i,t.parent.A||n[0])}function s(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function l(t){t.x*=n[0],t.y=t.depth*n[1]}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t)?l:null,a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null==(n=t)?null:l,a):i?n:null},Sa(a,e)},t.layout.cluster=function(){var e=t.layout.hierarchy().sort(null).value(null),r=ro,n=[1,1],i=!1;function a(a,o){var s,l=e.call(this,a,o),c=l[0],u=0;Ca(c,function(e){var n=e.children;n&&n.length?(e.x=function(t){return t.reduce(function(t,e){return t+e.x},0)/t.length}(n),e.y=function(e){return 1+t.max(e,function(t){return t.y})}(n)):(e.x=s?u+=r(e,s):0,e.y=0,s=e)});var h=function t(e){var r=e.children;return r&&r.length?t(r[0]):e}(c),f=function t(e){var r,n=e.children;return n&&(r=n.length)?t(n[r-1]):e}(c),p=h.x-r(h,f)/2,d=f.x+r(f,h)/2;return Ca(c,i?function(t){t.x=(t.x-c.x)*n[0],t.y=(c.y-t.y)*n[1]}:function(t){t.x=(t.x-p)/(d-p)*n[0],t.y=(1-(c.y?t.y/c.y:1))*n[1]}),l}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t),a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null!=(n=t),a):i?n:null},Sa(a,e)},t.layout.treemap=function(){var e,r=t.layout.hierarchy(),n=Math.round,i=[1,1],a=null,o=so,s=!1,l=\"squarify\",c=.5*(1+Math.sqrt(5));function u(t,e){for(var r,n,i=-1,a=t.length;++i<a;)n=(r=t[i]).value*(e<0?0:e),r.area=isNaN(n)||n<=0?0:n}function h(t){var e=t.children;if(e&&e.length){var r,n,i,a=o(t),s=[],c=e.slice(),f=1/0,g=\"slice\"===l?a.dx:\"dice\"===l?a.dy:\"slice-dice\"===l?1&t.depth?a.dy:a.dx:Math.min(a.dx,a.dy);for(u(c,a.dx*a.dy/t.value),s.area=0;(i=c.length)>0;)s.push(r=c[i-1]),s.area+=r.area,\"squarify\"!==l||(n=p(s,g))<=f?(c.pop(),f=n):(s.area-=s.pop().area,d(s,g,a,!1),g=Math.min(a.dx,a.dy),s.length=s.area=0,f=1/0);s.length&&(d(s,g,a,!0),s.length=s.area=0),e.forEach(h)}}function f(t){var e=t.children;if(e&&e.length){var r,n=o(t),i=e.slice(),a=[];for(u(i,n.dx*n.dy/t.value),a.area=0;r=i.pop();)a.push(r),a.area+=r.area,null!=r.z&&(d(a,r.z?n.dx:n.dy,n,!i.length),a.length=a.area=0);e.forEach(f)}}function p(t,e){for(var r,n=t.area,i=0,a=1/0,o=-1,s=t.length;++o<s;)(r=t[o].area)&&(r<a&&(a=r),r>i&&(i=r));return e*=e,(n*=n)?Math.max(e*i*c/n,n/(e*a*c)):1/0}function d(t,e,r,i){var a,o=-1,s=t.length,l=r.x,c=r.y,u=e?n(t.area/e):0;if(e==r.dx){for((i||u>r.dy)&&(u=r.dy);++o<s;)(a=t[o]).x=l,a.y=c,a.dy=u,l+=a.dx=Math.min(r.x+r.dx-l,u?n(a.area/u):0);a.z=!0,a.dx+=r.x+r.dx-l,r.y+=u,r.dy-=u}else{for((i||u>r.dx)&&(u=r.dx);++o<s;)(a=t[o]).x=l,a.y=c,a.dx=u,c+=a.dy=Math.min(r.y+r.dy-c,u?n(a.area/u):0);a.z=!1,a.dy+=r.y+r.dy-c,r.x+=u,r.dx-=u}}function g(t){var n=e||r(t),a=n[0];return a.x=a.y=0,a.value?(a.dx=i[0],a.dy=i[1]):a.dx=a.dy=0,e&&r.revalue(a),u([a],a.dx*a.dy/a.value),(e?f:h)(a),s&&(e=n),n}return g.size=function(t){return arguments.length?(i=t,g):i},g.padding=function(t){if(!arguments.length)return a;function e(e){return lo(e,t)}var r;return o=null==(a=t)?so:\"function\"==(r=typeof t)?function(e){var r=t.call(g,e,e.depth);return null==r?so(e):lo(e,\"number\"==typeof r?[r,r,r,r]:r)}:\"number\"===r?(t=[t,t,t,t],e):e,g},g.round=function(t){return arguments.length?(n=t?Math.round:Number,g):n!=Number},g.sticky=function(t){return arguments.length?(s=t,e=null,g):s},g.ratio=function(t){return arguments.length?(c=t,g):c},g.mode=function(t){return arguments.length?(l=t+\"\",g):l},Sa(g,r)},t.random={normal:function(t,e){var r=arguments.length;return r<2&&(e=1),r<1&&(t=0),function(){var r,n,i;do{i=(r=2*Math.random()-1)*r+(n=2*Math.random()-1)*n}while(!i||i>1);return t+e*r*Math.sqrt(-2*Math.log(i)/i)}},logNormal:function(){var e=t.random.normal.apply(t,arguments);return function(){return Math.exp(e())}},bates:function(e){var r=t.random.irwinHall(e);return function(){return r()/e}},irwinHall:function(t){return function(){for(var e=0,r=0;r<t;r++)e+=Math.random();return e}}},t.scale={};var go={floor:P,ceil:P};function vo(e,r,n,i){var a=[],o=[],s=0,l=Math.min(e.length,r.length)-1;for(e[l]<e[0]&&(e=e.slice().reverse(),r=r.slice().reverse());++s<=l;)a.push(n(e[s-1],e[s])),o.push(i(r[s-1],r[s]));return function(r){var n=t.bisect(e,r,1,l)-1;return o[n](a[n](r))}}function mo(e,r){return t.rebind(e,r,\"range\",\"rangeRound\",\"interpolate\",\"clamp\")}function yo(t,e){return fo(t,po(xo(t,e)[2])),fo(t,po(xo(t,e)[2])),t}function xo(t,e){null==e&&(e=10);var r=co(t),n=r[1]-r[0],i=Math.pow(10,Math.floor(Math.log(n/e)/Math.LN10)),a=e/n*i;return a<=.15?i*=10:a<=.35?i*=5:a<=.75&&(i*=2),r[0]=Math.ceil(r[0]/i)*i,r[1]=Math.floor(r[1]/i)*i+.5*i,r[2]=i,r}function bo(e,r){return t.range.apply(t,xo(e,r))}function _o(e,r,n){var i=xo(e,r);if(n){var a=Le.exec(n);if(a.shift(),\"s\"===a[8]){var o=t.formatPrefix(Math.max(y(i[0]),y(i[1])));return a[7]||(a[7]=\".\"+ko(o.scale(i[2]))),a[8]=\"f\",n=t.format(a.join(\"\")),function(t){return n(o.scale(t))+o.symbol}}a[7]||(a[7]=\".\"+function(t,e){var r=ko(e[2]);return t in wo?Math.abs(r-ko(Math.max(y(e[0]),y(e[1]))))+ +(\"e\"!==t):r-2*(\"%\"===t)}(a[8],i)),n=a.join(\"\")}else n=\",.\"+ko(i[2])+\"f\";return t.format(n)}t.scale.linear=function(){return function t(e,r,n,i){var a,o;function s(){var t=Math.min(e.length,r.length)>2?vo:ho,s=i?ma:va;return a=t(e,r,s,n),o=t(r,e,s,Zi),l}function l(t){return a(t)}l.invert=function(t){return o(t)};l.domain=function(t){return arguments.length?(e=t.map(Number),s()):e};l.range=function(t){return arguments.length?(r=t,s()):r};l.rangeRound=function(t){return l.range(t).interpolate(ca)};l.clamp=function(t){return arguments.length?(i=t,s()):i};l.interpolate=function(t){return arguments.length?(n=t,s()):n};l.ticks=function(t){return bo(e,t)};l.tickFormat=function(t,r){return _o(e,t,r)};l.nice=function(t){return yo(e,t),s()};l.copy=function(){return t(e,r,n,i)};return s()}([0,1],[0,1],Zi,!1)};var wo={s:1,g:1,p:1,r:1,e:1};function ko(t){return-Math.floor(Math.log(t)/Math.LN10+.01)}t.scale.log=function(){return function e(r,n,i,a){function o(t){return(i?Math.log(t<0?0:t):-Math.log(t>0?0:-t))/Math.log(n)}function s(t){return i?Math.pow(n,t):-Math.pow(n,-t)}function l(t){return r(o(t))}l.invert=function(t){return s(r.invert(t))};l.domain=function(t){return arguments.length?(i=t[0]>=0,r.domain((a=t.map(Number)).map(o)),l):a};l.base=function(t){return arguments.length?(n=+t,r.domain(a.map(o)),l):n};l.nice=function(){var t=fo(a.map(o),i?Math:Ao);return r.domain(t),a=t.map(s),l};l.ticks=function(){var t=co(a),e=[],r=t[0],l=t[1],c=Math.floor(o(r)),u=Math.ceil(o(l)),h=n%1?2:n;if(isFinite(u-c)){if(i){for(;c<u;c++)for(var f=1;f<h;f++)e.push(s(c)*f);e.push(s(c))}else for(e.push(s(c));c++<u;)for(var f=h-1;f>0;f--)e.push(s(c)*f);for(c=0;e[c]<r;c++);for(u=e.length;e[u-1]>l;u--);e=e.slice(c,u)}return e};l.tickFormat=function(e,r){if(!arguments.length)return To;arguments.length<2?r=To:\"function\"!=typeof r&&(r=t.format(r));var i=Math.max(1,n*e/l.ticks().length);return function(t){var e=t/s(Math.round(o(t)));return e*n<n-.5&&(e*=n),e<=i?r(t):\"\"}};l.copy=function(){return e(r.copy(),n,i,a)};return mo(l,r)}(t.scale.linear().domain([0,1]),10,!0,[1,10])};var To=t.format(\".0e\"),Ao={floor:function(t){return-Math.ceil(-t)},ceil:function(t){return-Math.floor(-t)}};function Mo(t){return function(e){return e<0?-Math.pow(-e,t):Math.pow(e,t)}}t.scale.pow=function(){return function t(e,r,n){var i=Mo(r),a=Mo(1/r);function o(t){return e(i(t))}o.invert=function(t){return a(e.invert(t))};o.domain=function(t){return arguments.length?(e.domain((n=t.map(Number)).map(i)),o):n};o.ticks=function(t){return bo(n,t)};o.tickFormat=function(t,e){return _o(n,t,e)};o.nice=function(t){return o.domain(yo(n,t))};o.exponent=function(t){return arguments.length?(i=Mo(r=t),a=Mo(1/r),e.domain(n.map(i)),o):r};o.copy=function(){return t(e.copy(),r,n)};return mo(o,e)}(t.scale.linear(),1,[0,1])},t.scale.sqrt=function(){return t.scale.pow().exponent(.5)},t.scale.ordinal=function(){return function e(r,n){var i,a,o;function s(t){return a[((i.get(t)||(\"range\"===n.t?i.set(t,r.push(t)):NaN))-1)%a.length]}function l(e,n){return t.range(r.length).map(function(t){return e+n*t})}s.domain=function(t){if(!arguments.length)return r;r=[],i=new b;for(var e,a=-1,o=t.length;++a<o;)i.has(e=t[a])||i.set(e,r.push(e));return s[n.t].apply(s,n.a)};s.range=function(t){return arguments.length?(a=t,o=0,n={t:\"range\",a:arguments},s):a};s.rangePoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=(i+c)/2,0):(c-i)/(r.length-1+e);return a=l(i+u*e/2,u),o=0,n={t:\"rangePoints\",a:arguments},s};s.rangeRoundPoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=c=Math.round((i+c)/2),0):(c-i)/(r.length-1+e)|0;return a=l(i+Math.round(u*e/2+(c-i-(r.length-1+e)*u)/2),u),o=0,n={t:\"rangeRoundPoints\",a:arguments},s};s.rangeBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],h=t[1-c],f=(h-u)/(r.length-e+2*i);return a=l(u+f*i,f),c&&a.reverse(),o=f*(1-e),n={t:\"rangeBands\",a:arguments},s};s.rangeRoundBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],h=t[1-c],f=Math.floor((h-u)/(r.length-e+2*i));return a=l(u+Math.round((h-u-(r.length-e)*f)/2),f),c&&a.reverse(),o=Math.round(f*(1-e)),n={t:\"rangeRoundBands\",a:arguments},s};s.rangeBand=function(){return o};s.rangeExtent=function(){return co(n.a[0])};s.copy=function(){return e(r,n)};return s.domain(r)}([],{t:\"range\",a:[[]]})},t.scale.category10=function(){return t.scale.ordinal().range(So)},t.scale.category20=function(){return t.scale.ordinal().range(Eo)},t.scale.category20b=function(){return t.scale.ordinal().range(Co)},t.scale.category20c=function(){return t.scale.ordinal().range(Lo)};var So=[2062260,16744206,2924588,14034728,9725885,9197131,14907330,8355711,12369186,1556175].map(se),Eo=[2062260,11454440,16744206,16759672,2924588,10018698,14034728,16750742,9725885,12955861,9197131,12885140,14907330,16234194,8355711,13092807,12369186,14408589,1556175,10410725].map(se),Co=[3750777,5395619,7040719,10264286,6519097,9216594,11915115,13556636,9202993,12426809,15186514,15190932,8666169,11356490,14049643,15177372,8077683,10834324,13528509,14589654].map(se),Lo=[3244733,7057110,10406625,13032431,15095053,16616764,16625259,16634018,3253076,7652470,10607003,13101504,7695281,10394312,12369372,14342891,6513507,9868950,12434877,14277081].map(se);function Po(){return 0}t.scale.quantile=function(){return function e(r,n){var i;function a(){var e=0,a=n.length;for(i=[];++e<a;)i[e-1]=t.quantile(r,e/a);return o}function o(e){if(!isNaN(e=+e))return n[t.bisect(i,e)]}o.domain=function(t){return arguments.length?(r=t.map(p).filter(d).sort(f),a()):r};o.range=function(t){return arguments.length?(n=t,a()):n};o.quantiles=function(){return i};o.invertExtent=function(t){return(t=n.indexOf(t))<0?[NaN,NaN]:[t>0?i[t-1]:r[0],t<i.length?i[t]:r[r.length-1]]};o.copy=function(){return e(r,n)};return a()}([],[])},t.scale.quantize=function(){return function t(e,r,n){var i,a;function o(t){return n[Math.max(0,Math.min(a,Math.floor(i*(t-e))))]}function s(){return i=n.length/(r-e),a=n.length-1,o}o.domain=function(t){return arguments.length?(e=+t[0],r=+t[t.length-1],s()):[e,r]};o.range=function(t){return arguments.length?(n=t,s()):n};o.invertExtent=function(t){return[t=(t=n.indexOf(t))<0?NaN:t/i+e,t+1/i]};o.copy=function(){return t(e,r,n)};return s()}(0,1,[0,1])},t.scale.threshold=function(){return function e(r,n){function i(e){if(e<=e)return n[t.bisect(r,e)]}i.domain=function(t){return arguments.length?(r=t,i):r};i.range=function(t){return arguments.length?(n=t,i):n};i.invertExtent=function(t){return t=n.indexOf(t),[r[t-1],r[t]]};i.copy=function(){return e(r,n)};return i}([.5],[0,1])},t.scale.identity=function(){return function t(e){function r(t){return+t}r.invert=r;r.domain=r.range=function(t){return arguments.length?(e=t.map(r),r):e};r.ticks=function(t){return bo(e,t)};r.tickFormat=function(t,r){return _o(e,t,r)};r.copy=function(){return t(e)};return r}([0,1])},t.svg={},t.svg.arc=function(){var t=zo,e=Io,r=Po,n=Oo,i=Do,a=Ro,o=Fo;function s(){var s=Math.max(0,+t.apply(this,arguments)),c=Math.max(0,+e.apply(this,arguments)),u=i.apply(this,arguments)-Et,h=a.apply(this,arguments)-Et,f=Math.abs(h-u),p=u>h?0:1;if(c<s&&(d=c,c=s,s=d),f>=St)return l(c,p)+(s?l(s,1-p):\"\")+\"Z\";var d,g,v,m,y,x,b,_,w,k,T,A,M=0,S=0,E=[];if((m=(+o.apply(this,arguments)||0)/2)&&(v=n===Oo?Math.sqrt(s*s+c*c):+n.apply(this,arguments),p||(S*=-1),c&&(S=It(v/c*Math.sin(m))),s&&(M=It(v/s*Math.sin(m)))),c){y=c*Math.cos(u+S),x=c*Math.sin(u+S),b=c*Math.cos(h-S),_=c*Math.sin(h-S);var C=Math.abs(h-u-2*S)<=At?0:1;if(S&&Bo(y,x,b,_)===p^C){var L=(u+h)/2;y=c*Math.cos(L),x=c*Math.sin(L),b=_=null}}else y=x=0;if(s){w=s*Math.cos(h-M),k=s*Math.sin(h-M),T=s*Math.cos(u+M),A=s*Math.sin(u+M);var P=Math.abs(u-h+2*M)<=At?0:1;if(M&&Bo(w,k,T,A)===1-p^P){var O=(u+h)/2;w=s*Math.cos(O),k=s*Math.sin(O),T=A=null}}else w=k=0;if(f>kt&&(d=Math.min(Math.abs(c-s)/2,+r.apply(this,arguments)))>.001){g=s<c^p?0:1;var z=d,I=d;if(f<At){var D=null==T?[w,k]:null==b?[y,x]:si([y,x],[T,A],[b,_],[w,k]),R=y-D[0],F=x-D[1],B=b-D[0],N=_-D[1],j=1/Math.sin(Math.acos((R*B+F*N)/(Math.sqrt(R*R+F*F)*Math.sqrt(B*B+N*N)))/2),U=Math.sqrt(D[0]*D[0]+D[1]*D[1]);I=Math.min(d,(s-U)/(j-1)),z=Math.min(d,(c-U)/(j+1))}if(null!=b){var V=No(null==T?[w,k]:[T,A],[y,x],c,z,p),q=No([b,_],[w,k],c,z,p);d===z?E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 0,\",g,\" \",V[1],\"A\",c,\",\",c,\" 0 \",1-p^Bo(V[1][0],V[1][1],q[1][0],q[1][1]),\",\",p,\" \",q[1],\"A\",z,\",\",z,\" 0 0,\",g,\" \",q[0]):E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 1,\",g,\" \",q[0])}else E.push(\"M\",y,\",\",x);if(null!=T){var H=No([y,x],[T,A],s,-I,p),G=No([w,k],null==b?[y,x]:[b,_],s,-I,p);d===I?E.push(\"L\",G[0],\"A\",I,\",\",I,\" 0 0,\",g,\" \",G[1],\"A\",s,\",\",s,\" 0 \",p^Bo(G[1][0],G[1][1],H[1][0],H[1][1]),\",\",1-p,\" \",H[1],\"A\",I,\",\",I,\" 0 0,\",g,\" \",H[0]):E.push(\"L\",G[0],\"A\",I,\",\",I,\" 0 0,\",g,\" \",H[0])}else E.push(\"L\",w,\",\",k)}else E.push(\"M\",y,\",\",x),null!=b&&E.push(\"A\",c,\",\",c,\" 0 \",C,\",\",p,\" \",b,\",\",_),E.push(\"L\",w,\",\",k),null!=T&&E.push(\"A\",s,\",\",s,\" 0 \",P,\",\",1-p,\" \",T,\",\",A);return E.push(\"Z\"),E.join(\"\")}function l(t,e){return\"M0,\"+t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+-t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+t}return s.innerRadius=function(e){return arguments.length?(t=ve(e),s):t},s.outerRadius=function(t){return arguments.length?(e=ve(t),s):e},s.cornerRadius=function(t){return arguments.length?(r=ve(t),s):r},s.padRadius=function(t){return arguments.length?(n=t==Oo?Oo:ve(t),s):n},s.startAngle=function(t){return arguments.length?(i=ve(t),s):i},s.endAngle=function(t){return arguments.length?(a=ve(t),s):a},s.padAngle=function(t){return arguments.length?(o=ve(t),s):o},s.centroid=function(){var r=(+t.apply(this,arguments)+ +e.apply(this,arguments))/2,n=(+i.apply(this,arguments)+ +a.apply(this,arguments))/2-Et;return[Math.cos(n)*r,Math.sin(n)*r]},s};var Oo=\"auto\";function zo(t){return t.innerRadius}function Io(t){return t.outerRadius}function Do(t){return t.startAngle}function Ro(t){return t.endAngle}function Fo(t){return t&&t.padAngle}function Bo(t,e,r,n){return(t-r)*e-(e-n)*t>0?0:1}function No(t,e,r,n,i){var a=t[0]-e[0],o=t[1]-e[1],s=(i?n:-n)/Math.sqrt(a*a+o*o),l=s*o,c=-s*a,u=t[0]+l,h=t[1]+c,f=e[0]+l,p=e[1]+c,d=(u+f)/2,g=(h+p)/2,v=f-u,m=p-h,y=v*v+m*m,x=r-n,b=u*p-f*h,_=(m<0?-1:1)*Math.sqrt(Math.max(0,x*x*y-b*b)),w=(b*m-v*_)/y,k=(-b*v-m*_)/y,T=(b*m+v*_)/y,A=(-b*v+m*_)/y,M=w-d,S=k-g,E=T-d,C=A-g;return M*M+S*S>E*E+C*C&&(w=T,k=A),[[w-l,k-c],[w*r/x,k*r/x]]}function jo(t){var e=ei,r=ri,n=Yr,i=Vo,a=i.key,o=.7;function s(a){var s,l=[],c=[],u=-1,h=a.length,f=ve(e),p=ve(r);function d(){l.push(\"M\",i(t(c),o))}for(;++u<h;)n.call(this,s=a[u],u)?c.push([+f.call(this,s,u),+p.call(this,s,u)]):c.length&&(d(),c=[]);return c.length&&d(),l.length?l.join(\"\"):null}return s.x=function(t){return arguments.length?(e=t,s):e},s.y=function(t){return arguments.length?(r=t,s):r},s.defined=function(t){return arguments.length?(n=t,s):n},s.interpolate=function(t){return arguments.length?(a=\"function\"==typeof t?i=t:(i=Uo.get(t)||Vo).key,s):a},s.tension=function(t){return arguments.length?(o=t,s):o},s}t.svg.line=function(){return jo(P)};var Uo=t.map({linear:Vo,\"linear-closed\":qo,step:function(t){var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];for(;++e<r;)i.push(\"H\",(n[0]+(n=t[e])[0])/2,\"V\",n[1]);r>1&&i.push(\"H\",n[0]);return i.join(\"\")},\"step-before\":Ho,\"step-after\":Go,basis:Xo,\"basis-open\":function(t){if(t.length<4)return Vo(t);var e,r=[],n=-1,i=t.length,a=[0],o=[0];for(;++n<3;)e=t[n],a.push(e[0]),o.push(e[1]);r.push(Zo($o,a)+\",\"+Zo($o,o)),--n;for(;++n<i;)e=t[n],a.shift(),a.push(e[0]),o.shift(),o.push(e[1]),Qo(r,a,o);return r.join(\"\")},\"basis-closed\":function(t){var e,r,n=-1,i=t.length,a=i+4,o=[],s=[];for(;++n<4;)r=t[n%i],o.push(r[0]),s.push(r[1]);e=[Zo($o,o),\",\",Zo($o,s)],--n;for(;++n<a;)r=t[n%i],o.shift(),o.push(r[0]),s.shift(),s.push(r[1]),Qo(e,o,s);return e.join(\"\")},bundle:function(t,e){var r=t.length-1;if(r)for(var n,i,a=t[0][0],o=t[0][1],s=t[r][0]-a,l=t[r][1]-o,c=-1;++c<=r;)n=t[c],i=c/r,n[0]=e*n[0]+(1-e)*(a+i*s),n[1]=e*n[1]+(1-e)*(o+i*l);return Xo(t)},cardinal:function(t,e){return t.length<3?Vo(t):t[0]+Yo(t,Wo(t,e))},\"cardinal-open\":function(t,e){return t.length<4?Vo(t):t[1]+Yo(t.slice(1,-1),Wo(t,e))},\"cardinal-closed\":function(t,e){return t.length<3?qo(t):t[0]+Yo((t.push(t[0]),t),Wo([t[t.length-2]].concat(t,[t[1]]),e))},monotone:function(t){return t.length<3?Vo(t):t[0]+Yo(t,function(t){var e,r,n,i,a=[],o=function(t){var e=0,r=t.length-1,n=[],i=t[0],a=t[1],o=n[0]=ts(i,a);for(;++e<r;)n[e]=(o+(o=ts(i=a,a=t[e+1])))/2;return n[e]=o,n}(t),s=-1,l=t.length-1;for(;++s<l;)e=ts(t[s],t[s+1]),y(e)<kt?o[s]=o[s+1]=0:(r=o[s]/e,n=o[s+1]/e,(i=r*r+n*n)>9&&(i=3*e/Math.sqrt(i),o[s]=i*r,o[s+1]=i*n));s=-1;for(;++s<=l;)i=(t[Math.min(l,s+1)][0]-t[Math.max(0,s-1)][0])/(6*(1+o[s]*o[s])),a.push([i||0,o[s]*i||0]);return a}(t))}});function Vo(t){return t.length>1?t.join(\"L\"):t+\"Z\"}function qo(t){return t.join(\"L\")+\"Z\"}function Ho(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"V\",(n=t[e])[1],\"H\",n[0]);return i.join(\"\")}function Go(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"H\",(n=t[e])[0],\"V\",n[1]);return i.join(\"\")}function Yo(t,e){if(e.length<1||t.length!=e.length&&t.length!=e.length+2)return Vo(t);var r=t.length!=e.length,n=\"\",i=t[0],a=t[1],o=e[0],s=o,l=1;if(r&&(n+=\"Q\"+(a[0]-2*o[0]/3)+\",\"+(a[1]-2*o[1]/3)+\",\"+a[0]+\",\"+a[1],i=t[1],l=2),e.length>1){s=e[1],a=t[l],l++,n+=\"C\"+(i[0]+o[0])+\",\"+(i[1]+o[1])+\",\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1];for(var c=2;c<e.length;c++,l++)a=t[l],s=e[c],n+=\"S\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1]}if(r){var u=t[l];n+=\"Q\"+(a[0]+2*s[0]/3)+\",\"+(a[1]+2*s[1]/3)+\",\"+u[0]+\",\"+u[1]}return n}function Wo(t,e){for(var r,n=[],i=(1-e)/2,a=t[0],o=t[1],s=1,l=t.length;++s<l;)r=a,a=o,o=t[s],n.push([i*(o[0]-r[0]),i*(o[1]-r[1])]);return n}function Xo(t){if(t.length<3)return Vo(t);var e=1,r=t.length,n=t[0],i=n[0],a=n[1],o=[i,i,i,(n=t[1])[0]],s=[a,a,a,n[1]],l=[i,\",\",a,\"L\",Zo($o,o),\",\",Zo($o,s)];for(t.push(t[r-1]);++e<=r;)n=t[e],o.shift(),o.push(n[0]),s.shift(),s.push(n[1]),Qo(l,o,s);return t.pop(),l.push(\"L\",n),l.join(\"\")}function Zo(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}Uo.forEach(function(t,e){e.key=t,e.closed=/-closed$/.test(t)});var Jo=[0,2/3,1/3,0],Ko=[0,1/3,2/3,0],$o=[0,1/6,2/3,1/6];function Qo(t,e,r){t.push(\"C\",Zo(Jo,e),\",\",Zo(Jo,r),\",\",Zo(Ko,e),\",\",Zo(Ko,r),\",\",Zo($o,e),\",\",Zo($o,r))}function ts(t,e){return(e[1]-t[1])/(e[0]-t[0])}function es(t){for(var e,r,n,i=-1,a=t.length;++i<a;)r=(e=t[i])[0],n=e[1]-Et,e[0]=r*Math.cos(n),e[1]=r*Math.sin(n);return t}function rs(t){var e=ei,r=ei,n=0,i=ri,a=Yr,o=Vo,s=o.key,l=o,c=\"L\",u=.7;function h(s){var h,f,p,d=[],g=[],v=[],m=-1,y=s.length,x=ve(e),b=ve(n),_=e===r?function(){return f}:ve(r),w=n===i?function(){return p}:ve(i);function k(){d.push(\"M\",o(t(v),u),c,l(t(g.reverse()),u),\"Z\")}for(;++m<y;)a.call(this,h=s[m],m)?(g.push([f=+x.call(this,h,m),p=+b.call(this,h,m)]),v.push([+_.call(this,h,m),+w.call(this,h,m)])):g.length&&(k(),g=[],v=[]);return g.length&&k(),d.length?d.join(\"\"):null}return h.x=function(t){return arguments.length?(e=r=t,h):r},h.x0=function(t){return arguments.length?(e=t,h):e},h.x1=function(t){return arguments.length?(r=t,h):r},h.y=function(t){return arguments.length?(n=i=t,h):i},h.y0=function(t){return arguments.length?(n=t,h):n},h.y1=function(t){return arguments.length?(i=t,h):i},h.defined=function(t){return arguments.length?(a=t,h):a},h.interpolate=function(t){return arguments.length?(s=\"function\"==typeof t?o=t:(o=Uo.get(t)||Vo).key,l=o.reverse||o,c=o.closed?\"M\":\"L\",h):s},h.tension=function(t){return arguments.length?(u=t,h):u},h}function ns(t){return t.radius}function is(t){return[t.x,t.y]}function as(){return 64}function os(){return\"circle\"}function ss(t){var e=Math.sqrt(t/At);return\"M0,\"+e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+-e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+e+\"Z\"}t.svg.line.radial=function(){var t=jo(es);return t.radius=t.x,delete t.x,t.angle=t.y,delete t.y,t},Ho.reverse=Go,Go.reverse=Ho,t.svg.area=function(){return rs(P)},t.svg.area.radial=function(){var t=rs(es);return t.radius=t.x,delete t.x,t.innerRadius=t.x0,delete t.x0,t.outerRadius=t.x1,delete t.x1,t.angle=t.y,delete t.y,t.startAngle=t.y0,delete t.y0,t.endAngle=t.y1,delete t.y1,t},t.svg.chord=function(){var t=Un,e=Vn,r=ns,n=Do,i=Ro;function a(r,n){var i,a,c=o(this,t,r,n),u=o(this,e,r,n);return\"M\"+c.p0+s(c.r,c.p1,c.a1-c.a0)+(a=u,(i=c).a0==a.a0&&i.a1==a.a1?l(c.r,c.p1,c.r,c.p0):l(c.r,c.p1,u.r,u.p0)+s(u.r,u.p1,u.a1-u.a0)+l(u.r,u.p1,c.r,c.p0))+\"Z\"}function o(t,e,a,o){var s=e.call(t,a,o),l=r.call(t,s,o),c=n.call(t,s,o)-Et,u=i.call(t,s,o)-Et;return{r:l,a0:c,a1:u,p0:[l*Math.cos(c),l*Math.sin(c)],p1:[l*Math.cos(u),l*Math.sin(u)]}}function s(t,e,r){return\"A\"+t+\",\"+t+\" 0 \"+ +(r>At)+\",1 \"+e}function l(t,e,r,n){return\"Q 0,0 \"+n}return a.radius=function(t){return arguments.length?(r=ve(t),a):r},a.source=function(e){return arguments.length?(t=ve(e),a):t},a.target=function(t){return arguments.length?(e=ve(t),a):e},a.startAngle=function(t){return arguments.length?(n=ve(t),a):n},a.endAngle=function(t){return arguments.length?(i=ve(t),a):i},a},t.svg.diagonal=function(){var t=Un,e=Vn,r=is;function n(n,i){var a=t.call(this,n,i),o=e.call(this,n,i),s=(a.y+o.y)/2,l=[a,{x:a.x,y:s},{x:o.x,y:s},o];return\"M\"+(l=l.map(r))[0]+\"C\"+l[1]+\" \"+l[2]+\" \"+l[3]}return n.source=function(e){return arguments.length?(t=ve(e),n):t},n.target=function(t){return arguments.length?(e=ve(t),n):e},n.projection=function(t){return arguments.length?(r=t,n):r},n},t.svg.diagonal.radial=function(){var e=t.svg.diagonal(),r=is,n=e.projection;return e.projection=function(t){return arguments.length?n(function(t){return function(){var e=t.apply(this,arguments),r=e[0],n=e[1]-Et;return[r*Math.cos(n),r*Math.sin(n)]}}(r=t)):r},e},t.svg.symbol=function(){var t=os,e=as;function r(r,n){return(ls.get(t.call(this,r,n))||ss)(e.call(this,r,n))}return r.type=function(e){return arguments.length?(t=ve(e),r):t},r.size=function(t){return arguments.length?(e=ve(t),r):e},r};var ls=t.map({circle:ss,cross:function(t){var e=Math.sqrt(t/5)/2;return\"M\"+-3*e+\",\"+-e+\"H\"+-e+\"V\"+-3*e+\"H\"+e+\"V\"+-e+\"H\"+3*e+\"V\"+e+\"H\"+e+\"V\"+3*e+\"H\"+-e+\"V\"+e+\"H\"+-3*e+\"Z\"},diamond:function(t){var e=Math.sqrt(t/(2*us)),r=e*us;return\"M0,\"+-e+\"L\"+r+\",0 0,\"+e+\" \"+-r+\",0Z\"},square:function(t){var e=Math.sqrt(t)/2;return\"M\"+-e+\",\"+-e+\"L\"+e+\",\"+-e+\" \"+e+\",\"+e+\" \"+-e+\",\"+e+\"Z\"},\"triangle-down\":function(t){var e=Math.sqrt(t/cs),r=e*cs/2;return\"M0,\"+r+\"L\"+e+\",\"+-r+\" \"+-e+\",\"+-r+\"Z\"},\"triangle-up\":function(t){var e=Math.sqrt(t/cs),r=e*cs/2;return\"M0,\"+-r+\"L\"+e+\",\"+r+\" \"+-e+\",\"+r+\"Z\"}});t.svg.symbolTypes=ls.keys();var cs=Math.sqrt(3),us=Math.tan(30*Ct);W.transition=function(t){for(var e,r,n=ds||++ms,i=bs(t),a=[],o=gs||{time:Date.now(),ease:ia,delay:0,duration:250},s=-1,l=this.length;++s<l;){a.push(e=[]);for(var c=this[s],u=-1,h=c.length;++u<h;)(r=c[u])&&_s(r,u,i,n,o),e.push(r)}return ps(a,i,n)},W.interrupt=function(t){return this.each(null==t?hs:fs(bs(t)))};var hs=fs(bs());function fs(t){return function(){var e,r,n;(e=this[t])&&(n=e[r=e.active])&&(n.timer.c=null,n.timer.t=NaN,--e.count?delete e[r]:delete this[t],e.active+=.5,n.event&&n.event.interrupt.call(this,this.__data__,n.index))}}function ps(t,e,r){return V(t,vs),t.namespace=e,t.id=r,t}var ds,gs,vs=[],ms=0;function ys(t,e,r,n){var i=t.id,a=t.namespace;return ut(t,\"function\"==typeof r?function(t,o,s){t[a][i].tween.set(e,n(r.call(t,t.__data__,o,s)))}:(r=n(r),function(t){t[a][i].tween.set(e,r)}))}function xs(t){return null==t&&(t=\"\"),function(){this.textContent=t}}function bs(t){return null==t?\"__transition__\":\"__transition_\"+t+\"__\"}function _s(t,e,r,n,i){var a,o,s,l,c,u=t[r]||(t[r]={active:0,count:0}),h=u[n];function f(r){var i=u.active,f=u[i];for(var d in f&&(f.timer.c=null,f.timer.t=NaN,--u.count,delete u[i],f.event&&f.event.interrupt.call(t,t.__data__,f.index)),u)if(+d<n){var g=u[d];g.timer.c=null,g.timer.t=NaN,--u.count,delete u[d]}o.c=p,Te(function(){return o.c&&p(r||1)&&(o.c=null,o.t=NaN),1},0,a),u.active=n,h.event&&h.event.start.call(t,t.__data__,e),c=[],h.tween.forEach(function(r,n){(n=n.call(t,t.__data__,e))&&c.push(n)}),l=h.ease,s=h.duration}function p(i){for(var a=i/s,o=l(a),f=c.length;f>0;)c[--f].call(t,o);if(a>=1)return h.event&&h.event.end.call(t,t.__data__,e),--u.count?delete u[n]:delete t[r],1}h||(a=i.time,o=Te(function(t){var e=h.delay;if(o.t=e+a,e<=t)return f(t-e);o.c=f},0,a),h=u[n]={tween:new b,time:a,timer:o,delay:i.delay,duration:i.duration,ease:i.ease,index:e},i=null,++u.count)}vs.call=W.call,vs.empty=W.empty,vs.node=W.node,vs.size=W.size,t.transition=function(e,r){return e&&e.transition?ds?e.transition(r):e:t.selection().transition(e)},t.transition.prototype=vs,vs.select=function(t){var e,r,n,i=this.id,a=this.namespace,o=[];t=X(t);for(var s=-1,l=this.length;++s<l;){o.push(e=[]);for(var c=this[s],u=-1,h=c.length;++u<h;)(n=c[u])&&(r=t.call(n,n.__data__,u,s))?(\"__data__\"in n&&(r.__data__=n.__data__),_s(r,u,a,i,n[a][i]),e.push(r)):e.push(null)}return ps(o,a,i)},vs.selectAll=function(t){var e,r,n,i,a,o=this.id,s=this.namespace,l=[];t=Z(t);for(var c=-1,u=this.length;++c<u;)for(var h=this[c],f=-1,p=h.length;++f<p;)if(n=h[f]){a=n[s][o],r=t.call(n,n.__data__,f,c),l.push(e=[]);for(var d=-1,g=r.length;++d<g;)(i=r[d])&&_s(i,d,s,o,a),e.push(i)}return ps(l,s,o)},vs.filter=function(t){var e,r,n=[];\"function\"!=typeof t&&(t=ct(t));for(var i=0,a=this.length;i<a;i++){n.push(e=[]);for(var o,s=0,l=(o=this[i]).length;s<l;s++)(r=o[s])&&t.call(r,r.__data__,s,i)&&e.push(r)}return ps(n,this.namespace,this.id)},vs.tween=function(t,e){var r=this.id,n=this.namespace;return arguments.length<2?this.node()[n][r].tween.get(t):ut(this,null==e?function(e){e[n][r].tween.remove(t)}:function(i){i[n][r].tween.set(t,e)})},vs.attr=function(e,r){if(arguments.length<2){for(r in e)this.attr(r,e[r]);return this}var n=\"transform\"==e?ga:Zi,i=t.ns.qualify(e);function a(){this.removeAttribute(i)}function o(){this.removeAttributeNS(i.space,i.local)}return ys(this,\"attr.\"+e,r,i.local?function(t){return null==t?o:(t+=\"\",function(){var e,r=this.getAttributeNS(i.space,i.local);return r!==t&&(e=n(r,t),function(t){this.setAttributeNS(i.space,i.local,e(t))})})}:function(t){return null==t?a:(t+=\"\",function(){var e,r=this.getAttribute(i);return r!==t&&(e=n(r,t),function(t){this.setAttribute(i,e(t))})})})},vs.attrTween=function(e,r){var n=t.ns.qualify(e);return this.tween(\"attr.\"+e,n.local?function(t,e){var i=r.call(this,t,e,this.getAttributeNS(n.space,n.local));return i&&function(t){this.setAttributeNS(n.space,n.local,i(t))}}:function(t,e){var i=r.call(this,t,e,this.getAttribute(n));return i&&function(t){this.setAttribute(n,i(t))}})},vs.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.style(r,t[r],e);return this}r=\"\"}function i(){this.style.removeProperty(t)}return ys(this,\"style.\"+t,e,function(e){return null==e?i:(e+=\"\",function(){var n,i=o(this).getComputedStyle(this,null).getPropertyValue(t);return i!==e&&(n=Zi(i,e),function(e){this.style.setProperty(t,n(e),r)})})})},vs.styleTween=function(t,e,r){return arguments.length<3&&(r=\"\"),this.tween(\"style.\"+t,function(n,i){var a=e.call(this,n,i,o(this).getComputedStyle(this,null).getPropertyValue(t));return a&&function(e){this.style.setProperty(t,a(e),r)}})},vs.text=function(t){return ys(this,\"text\",t,xs)},vs.remove=function(){var t=this.namespace;return this.each(\"end.transition\",function(){var e;this[t].count<2&&(e=this.parentNode)&&e.removeChild(this)})},vs.ease=function(e){var r=this.id,n=this.namespace;return arguments.length<1?this.node()[n][r].ease:(\"function\"!=typeof e&&(e=t.ease.apply(t,arguments)),ut(this,function(t){t[n][r].ease=e}))},vs.delay=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].delay:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].delay=+t.call(n,n.__data__,i,a)}:(t=+t,function(n){n[r][e].delay=t}))},vs.duration=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].duration:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].duration=Math.max(1,t.call(n,n.__data__,i,a))}:(t=Math.max(1,t),function(n){n[r][e].duration=t}))},vs.each=function(e,r){var n=this.id,i=this.namespace;if(arguments.length<2){var a=gs,o=ds;try{ds=n,ut(this,function(t,r,a){gs=t[i][n],e.call(t,t.__data__,r,a)})}finally{gs=a,ds=o}}else ut(this,function(a){var o=a[i][n];(o.event||(o.event=t.dispatch(\"start\",\"end\",\"interrupt\"))).on(e,r)});return this},vs.transition=function(){for(var t,e,r,n=this.id,i=++ms,a=this.namespace,o=[],s=0,l=this.length;s<l;s++){o.push(t=[]);for(var c,u=0,h=(c=this[s]).length;u<h;u++)(e=c[u])&&_s(e,u,a,i,{time:(r=e[a][n]).time,ease:r.ease,delay:r.delay+r.duration,duration:r.duration}),t.push(e)}return ps(o,a,i)},t.svg.axis=function(){var e,r=t.scale.linear(),i=ws,a=6,o=6,s=3,l=[10],c=null;function u(n){n.each(function(){var n,u=t.select(this),h=this.__chart__||r,f=this.__chart__=r.copy(),p=null==c?f.ticks?f.ticks.apply(f,l):f.domain():c,d=null==e?f.tickFormat?f.tickFormat.apply(f,l):P:e,g=u.selectAll(\".tick\").data(p,f),v=g.enter().insert(\"g\",\".domain\").attr(\"class\",\"tick\").style(\"opacity\",kt),m=t.transition(g.exit()).style(\"opacity\",kt).remove(),y=t.transition(g.order()).style(\"opacity\",1),x=Math.max(a,0)+s,b=uo(f),_=u.selectAll(\".domain\").data([0]),w=(_.enter().append(\"path\").attr(\"class\",\"domain\"),t.transition(_));v.append(\"line\"),v.append(\"text\");var k,T,A,M,S=v.select(\"line\"),E=y.select(\"line\"),C=g.select(\"text\").text(d),L=v.select(\"text\"),O=y.select(\"text\"),z=\"top\"===i||\"left\"===i?-1:1;if(\"bottom\"===i||\"top\"===i?(n=Ts,k=\"x\",A=\"y\",T=\"x2\",M=\"y2\",C.attr(\"dy\",z<0?\"0em\":\".71em\").style(\"text-anchor\",\"middle\"),w.attr(\"d\",\"M\"+b[0]+\",\"+z*o+\"V0H\"+b[1]+\"V\"+z*o)):(n=As,k=\"y\",A=\"x\",T=\"y2\",M=\"x2\",C.attr(\"dy\",\".32em\").style(\"text-anchor\",z<0?\"end\":\"start\"),w.attr(\"d\",\"M\"+z*o+\",\"+b[0]+\"H0V\"+b[1]+\"H\"+z*o)),S.attr(M,z*a),L.attr(A,z*x),E.attr(T,0).attr(M,z*a),O.attr(k,0).attr(A,z*x),f.rangeBand){var I=f,D=I.rangeBand()/2;h=f=function(t){return I(t)+D}}else h.rangeBand?h=f:m.call(n,f,h);v.call(n,h,f),y.call(n,f,f)})}return u.scale=function(t){return arguments.length?(r=t,u):r},u.orient=function(t){return arguments.length?(i=t in ks?t+\"\":ws,u):i},u.ticks=function(){return arguments.length?(l=n(arguments),u):l},u.tickValues=function(t){return arguments.length?(c=t,u):c},u.tickFormat=function(t){return arguments.length?(e=t,u):e},u.tickSize=function(t){var e=arguments.length;return e?(a=+t,o=+arguments[e-1],u):a},u.innerTickSize=function(t){return arguments.length?(a=+t,u):a},u.outerTickSize=function(t){return arguments.length?(o=+t,u):o},u.tickPadding=function(t){return arguments.length?(s=+t,u):s},u.tickSubdivide=function(){return arguments.length&&u},u};var ws=\"bottom\",ks={top:1,right:1,bottom:1,left:1};function Ts(t,e,r){t.attr(\"transform\",function(t){var n=e(t);return\"translate(\"+(isFinite(n)?n:r(t))+\",0)\"})}function As(t,e,r){t.attr(\"transform\",function(t){var n=e(t);return\"translate(0,\"+(isFinite(n)?n:r(t))+\")\"})}t.svg.brush=function(){var e,r,n=j(f,\"brushstart\",\"brush\",\"brushend\"),i=null,a=null,s=[0,0],l=[0,0],c=!0,u=!0,h=Ss[0];function f(e){e.each(function(){var e=t.select(this).style(\"pointer-events\",\"all\").style(\"-webkit-tap-highlight-color\",\"rgba(0,0,0,0)\").on(\"mousedown.brush\",v).on(\"touchstart.brush\",v),r=e.selectAll(\".background\").data([0]);r.enter().append(\"rect\").attr(\"class\",\"background\").style(\"visibility\",\"hidden\").style(\"cursor\",\"crosshair\"),e.selectAll(\".extent\").data([0]).enter().append(\"rect\").attr(\"class\",\"extent\").style(\"cursor\",\"move\");var n=e.selectAll(\".resize\").data(h,P);n.exit().remove(),n.enter().append(\"g\").attr(\"class\",function(t){return\"resize \"+t}).style(\"cursor\",function(t){return Ms[t]}).append(\"rect\").attr(\"x\",function(t){return/[ew]$/.test(t)?-3:null}).attr(\"y\",function(t){return/^[ns]/.test(t)?-3:null}).attr(\"width\",6).attr(\"height\",6).style(\"visibility\",\"hidden\"),n.style(\"display\",f.empty()?\"none\":null);var o,s=t.transition(e),l=t.transition(r);i&&(o=uo(i),l.attr(\"x\",o[0]).attr(\"width\",o[1]-o[0]),d(s)),a&&(o=uo(a),l.attr(\"y\",o[0]).attr(\"height\",o[1]-o[0]),g(s)),p(s)})}function p(t){t.selectAll(\".resize\").attr(\"transform\",function(t){return\"translate(\"+s[+/e$/.test(t)]+\",\"+l[+/^s/.test(t)]+\")\"})}function d(t){t.select(\".extent\").attr(\"x\",s[0]),t.selectAll(\".extent,.n>rect,.s>rect\").attr(\"width\",s[1]-s[0])}function g(t){t.select(\".extent\").attr(\"y\",l[0]),t.selectAll(\".extent,.e>rect,.w>rect\").attr(\"height\",l[1]-l[0])}function v(){var h,v,m=this,y=t.select(t.event.target),x=n.of(m,arguments),b=t.select(m),_=y.datum(),w=!/^(n|s)$/.test(_)&&i,k=!/^(e|w)$/.test(_)&&a,T=y.classed(\"extent\"),A=xt(m),M=t.mouse(m),S=t.select(o(m)).on(\"keydown.brush\",function(){32==t.event.keyCode&&(T||(h=null,M[0]-=s[1],M[1]-=l[1],T=2),B())}).on(\"keyup.brush\",function(){32==t.event.keyCode&&2==T&&(M[0]+=s[1],M[1]+=l[1],T=0,B())});if(t.event.changedTouches?S.on(\"touchmove.brush\",L).on(\"touchend.brush\",O):S.on(\"mousemove.brush\",L).on(\"mouseup.brush\",O),b.interrupt().selectAll(\"*\").interrupt(),T)M[0]=s[0]-M[0],M[1]=l[0]-M[1];else if(_){var E=+/w$/.test(_),C=+/^n/.test(_);v=[s[1-E]-M[0],l[1-C]-M[1]],M[0]=s[E],M[1]=l[C]}else t.event.altKey&&(h=M.slice());function L(){var e=t.mouse(m),r=!1;v&&(e[0]+=v[0],e[1]+=v[1]),T||(t.event.altKey?(h||(h=[(s[0]+s[1])/2,(l[0]+l[1])/2]),M[0]=s[+(e[0]<h[0])],M[1]=l[+(e[1]<h[1])]):h=null),w&&P(e,i,0)&&(d(b),r=!0),k&&P(e,a,1)&&(g(b),r=!0),r&&(p(b),x({type:\"brush\",mode:T?\"move\":\"resize\"}))}function P(t,n,i){var a,o,f=uo(n),p=f[0],d=f[1],g=M[i],v=i?l:s,m=v[1]-v[0];if(T&&(p-=g,d-=m+g),a=(i?u:c)?Math.max(p,Math.min(d,t[i])):t[i],T?o=(a+=g)+m:(h&&(g=Math.max(p,Math.min(d,2*h[i]-a))),g<a?(o=a,a=g):o=g),v[0]!=a||v[1]!=o)return i?r=null:e=null,v[0]=a,v[1]=o,!0}function O(){L(),b.style(\"pointer-events\",\"all\").selectAll(\".resize\").style(\"display\",f.empty()?\"none\":null),t.select(\"body\").style(\"cursor\",null),S.on(\"mousemove.brush\",null).on(\"mouseup.brush\",null).on(\"touchmove.brush\",null).on(\"touchend.brush\",null).on(\"keydown.brush\",null).on(\"keyup.brush\",null),A(),x({type:\"brushend\"})}b.style(\"pointer-events\",\"none\").selectAll(\".resize\").style(\"display\",null),t.select(\"body\").style(\"cursor\",y.style(\"cursor\")),x({type:\"brushstart\"}),L()}return f.event=function(i){i.each(function(){var i=n.of(this,arguments),a={x:s,y:l,i:e,j:r},o=this.__chart__||a;this.__chart__=a,ds?t.select(this).transition().each(\"start.brush\",function(){e=o.i,r=o.j,s=o.x,l=o.y,i({type:\"brushstart\"})}).tween(\"brush:brush\",function(){var t=Ji(s,a.x),n=Ji(l,a.y);return e=r=null,function(e){s=a.x=t(e),l=a.y=n(e),i({type:\"brush\",mode:\"resize\"})}}).each(\"end.brush\",function(){e=a.i,r=a.j,i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"})}):(i({type:\"brushstart\"}),i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"}))})},f.x=function(t){return arguments.length?(h=Ss[!(i=t)<<1|!a],f):i},f.y=function(t){return arguments.length?(h=Ss[!i<<1|!(a=t)],f):a},f.clamp=function(t){return arguments.length?(i&&a?(c=!!t[0],u=!!t[1]):i?c=!!t:a&&(u=!!t),f):i&&a?[c,u]:i?c:a?u:null},f.extent=function(t){var n,o,c,u,h;return arguments.length?(i&&(n=t[0],o=t[1],a&&(n=n[0],o=o[0]),e=[n,o],i.invert&&(n=i(n),o=i(o)),o<n&&(h=n,n=o,o=h),n==s[0]&&o==s[1]||(s=[n,o])),a&&(c=t[0],u=t[1],i&&(c=c[1],u=u[1]),r=[c,u],a.invert&&(c=a(c),u=a(u)),u<c&&(h=c,c=u,u=h),c==l[0]&&u==l[1]||(l=[c,u])),f):(i&&(e?(n=e[0],o=e[1]):(n=s[0],o=s[1],i.invert&&(n=i.invert(n),o=i.invert(o)),o<n&&(h=n,n=o,o=h))),a&&(r?(c=r[0],u=r[1]):(c=l[0],u=l[1],a.invert&&(c=a.invert(c),u=a.invert(u)),u<c&&(h=c,c=u,u=h))),i&&a?[[n,c],[o,u]]:i?[n,o]:a&&[c,u])},f.clear=function(){return f.empty()||(s=[0,0],l=[0,0],e=r=null),f},f.empty=function(){return!!i&&s[0]==s[1]||!!a&&l[0]==l[1]},t.rebind(f,n,\"on\")};var Ms={n:\"ns-resize\",e:\"ew-resize\",s:\"ns-resize\",w:\"ew-resize\",nw:\"nwse-resize\",ne:\"nesw-resize\",se:\"nwse-resize\",sw:\"nesw-resize\"},Ss=[[\"n\",\"e\",\"s\",\"w\",\"nw\",\"ne\",\"se\",\"sw\"],[\"e\",\"w\"],[\"n\",\"s\"],[]],Es=ze.format=sr.timeFormat,Cs=Es.utc,Ls=Cs(\"%Y-%m-%dT%H:%M:%S.%LZ\");function Ps(t){return t.toISOString()}function Os(e,r,n){function i(t){return e(t)}function a(e,n){var i=(e[1]-e[0])/n,a=t.bisect(Is,i);return a==Is.length?[r.year,xo(e.map(function(t){return t/31536e6}),n)[2]]:a?r[i/Is[a-1]<Is[a]/i?a-1:a]:[Fs,xo(e,n)[2]]}return i.invert=function(t){return zs(e.invert(t))},i.domain=function(t){return arguments.length?(e.domain(t),i):e.domain().map(zs)},i.nice=function(t,e){var r=i.domain(),n=co(r),o=null==t?a(n,10):\"number\"==typeof t&&a(n,t);function s(r){return!isNaN(r)&&!t.range(r,zs(+r+1),e).length}return o&&(t=o[0],e=o[1]),i.domain(fo(r,e>1?{floor:function(e){for(;s(e=t.floor(e));)e=zs(e-1);return e},ceil:function(e){for(;s(e=t.ceil(e));)e=zs(+e+1);return e}}:t))},i.ticks=function(t,e){var r=co(i.domain()),n=null==t?a(r,10):\"number\"==typeof t?a(r,t):!t.range&&[{range:t},e];return n&&(t=n[0],e=n[1]),t.range(r[0],zs(+r[1]+1),e<1?1:e)},i.tickFormat=function(){return n},i.copy=function(){return Os(e.copy(),r,n)},mo(i,e)}function zs(t){return new Date(t)}Es.iso=Date.prototype.toISOString&&+new Date(\"2000-01-01T00:00:00.000Z\")?Ps:Ls,Ps.parse=function(t){var e=new Date(t);return isNaN(e)?null:e},Ps.toString=Ls.toString,ze.second=Fe(function(t){return new Ie(1e3*Math.floor(t/1e3))},function(t,e){t.setTime(t.getTime()+1e3*Math.floor(e))},function(t){return t.getSeconds()}),ze.seconds=ze.second.range,ze.seconds.utc=ze.second.utc.range,ze.minute=Fe(function(t){return new Ie(6e4*Math.floor(t/6e4))},function(t,e){t.setTime(t.getTime()+6e4*Math.floor(e))},function(t){return t.getMinutes()}),ze.minutes=ze.minute.range,ze.minutes.utc=ze.minute.utc.range,ze.hour=Fe(function(t){var e=t.getTimezoneOffset()/60;return new Ie(36e5*(Math.floor(t/36e5-e)+e))},function(t,e){t.setTime(t.getTime()+36e5*Math.floor(e))},function(t){return t.getHours()}),ze.hours=ze.hour.range,ze.hours.utc=ze.hour.utc.range,ze.month=Fe(function(t){return(t=ze.day(t)).setDate(1),t},function(t,e){t.setMonth(t.getMonth()+e)},function(t){return t.getMonth()}),ze.months=ze.month.range,ze.months.utc=ze.month.utc.range;var Is=[1e3,5e3,15e3,3e4,6e4,3e5,9e5,18e5,36e5,108e5,216e5,432e5,864e5,1728e5,6048e5,2592e6,7776e6,31536e6],Ds=[[ze.second,1],[ze.second,5],[ze.second,15],[ze.second,30],[ze.minute,1],[ze.minute,5],[ze.minute,15],[ze.minute,30],[ze.hour,1],[ze.hour,3],[ze.hour,6],[ze.hour,12],[ze.day,1],[ze.day,2],[ze.week,1],[ze.month,1],[ze.month,3],[ze.year,1]],Rs=Es.multi([[\".%L\",function(t){return t.getMilliseconds()}],[\":%S\",function(t){return t.getSeconds()}],[\"%I:%M\",function(t){return t.getMinutes()}],[\"%I %p\",function(t){return t.getHours()}],[\"%a %d\",function(t){return t.getDay()&&1!=t.getDate()}],[\"%b %d\",function(t){return 1!=t.getDate()}],[\"%B\",function(t){return t.getMonth()}],[\"%Y\",Yr]]),Fs={range:function(e,r,n){return t.range(Math.ceil(e/n)*n,+r,n).map(zs)},floor:P,ceil:P};Ds.year=ze.year,ze.scale=function(){return Os(t.scale.linear(),Ds,Rs)};var Bs=Ds.map(function(t){return[t[0].utc,t[1]]}),Ns=Cs.multi([[\".%L\",function(t){return t.getUTCMilliseconds()}],[\":%S\",function(t){return t.getUTCSeconds()}],[\"%I:%M\",function(t){return t.getUTCMinutes()}],[\"%I %p\",function(t){return t.getUTCHours()}],[\"%a %d\",function(t){return t.getUTCDay()&&1!=t.getUTCDate()}],[\"%b %d\",function(t){return 1!=t.getUTCDate()}],[\"%B\",function(t){return t.getUTCMonth()}],[\"%Y\",Yr]]);function js(t){return JSON.parse(t.responseText)}function Us(t){var e=i.createRange();return e.selectNode(i.body),e.createContextualFragment(t.responseText)}Bs.year=ze.year.utc,ze.scale.utc=function(){return Os(t.scale.linear(),Bs,Ns)},t.text=me(function(t){return t.responseText}),t.json=function(t,e){return ye(t,\"application/json\",js,e)},t.html=function(t,e){return ye(t,\"text/html\",Us,e)},t.xml=me(function(t){return t.responseXML}),\"object\"==typeof e&&e.exports?e.exports=t:this.d3=t}()},{}],164:[function(t,e,r){e.exports=function(){for(var t=0;t<arguments.length;t++)if(void 0!==arguments[t])return arguments[t]}},{}],165:[function(t,e,r){\"use strict\";var n=t(\"incremental-convex-hull\"),i=t(\"uniq\");function a(t,e){this.point=t,this.index=e}function o(t,e){for(var r=t.point,n=e.point,i=r.length,a=0;a<i;++a){var o=n[a]-r[a];if(o)return o}return 0}e.exports=function(t,e){var r=t.length;if(0===r)return[];var s=t[0].length;if(s<1)return[];if(1===s)return function(t,e,r){if(1===t)return r?[[-1,0]]:[];var n=e.map(function(t,e){return[t[0],e]});n.sort(function(t,e){return t[0]-e[0]});for(var i=new Array(t-1),a=1;a<t;++a){var o=n[a-1],s=n[a];i[a-1]=[o[1],s[1]]}r&&i.push([-1,i[0][1]],[i[t-1][1],-1]);return i}(r,t,e);for(var l=new Array(r),c=1,u=0;u<r;++u){for(var h=t[u],f=new Array(s+1),p=0,d=0;d<s;++d){var g=h[d];f[d]=g,p+=g*g}f[s]=p,l[u]=new a(f,u),c=Math.max(p,c)}i(l,o),r=l.length;for(var v=new Array(r+s+1),m=new Array(r+s+1),y=(s+1)*(s+1)*c,x=new Array(s+1),u=0;u<=s;++u)x[u]=0;x[s]=y,v[0]=x.slice(),m[0]=-1;for(var u=0;u<=s;++u){var f=x.slice();f[u]=1,v[u+1]=f,m[u+1]=-1}for(var u=0;u<r;++u){var b=l[u];v[u+s+1]=b.point,m[u+s+1]=b.index}var _=n(v,!1);_=e?_.filter(function(t){for(var e=0,r=0;r<=s;++r){var n=m[t[r]];if(n<0&&++e>=2)return!1;t[r]=n}return!0}):_.filter(function(t){for(var e=0;e<=s;++e){var r=m[t[e]];if(r<0)return!1;t[e]=r}return!0});if(1&s)for(var u=0;u<_.length;++u){var b=_[u],f=b[0];b[0]=b[1],b[1]=f}return _}},{\"incremental-convex-hull\":413,uniq:547}],166:[function(t,e,r){\"use strict\";e.exports=a;var n=(a.canvas=document.createElement(\"canvas\")).getContext(\"2d\"),i=o([32,126]);function a(t,e){Array.isArray(t)&&(t=t.join(\", \"));var r,a={},s=16,l=.05;e&&(2===e.length&&\"number\"==typeof e[0]?r=o(e):Array.isArray(e)?r=e:(e.o?r=o(e.o):e.pairs&&(r=e.pairs),e.fontSize&&(s=e.fontSize),null!=e.threshold&&(l=e.threshold))),r||(r=i),n.font=s+\"px \"+t;for(var c=0;c<r.length;c++){var u=r[c],h=n.measureText(u[0]).width+n.measureText(u[1]).width,f=n.measureText(u).width;if(Math.abs(h-f)>s*l){var p=(f-h)/s;a[u]=1e3*p}}return a}function o(t){for(var e=[],r=t[0];r<=t[1];r++)for(var n=String.fromCharCode(r),i=t[0];i<t[1];i++){var a=n+String.fromCharCode(i);e.push(a)}return e}a.createPairs=o,a.ascii=i},{}],167:[function(t,e,r){(function(t){var r=!1;if(\"undefined\"!=typeof Float64Array){var n=new Float64Array(1),i=new Uint32Array(n.buffer);if(n[0]=1,r=!0,1072693248===i[1]){e.exports=function(t){return n[0]=t,[i[0],i[1]]},e.exports.pack=function(t,e){return i[0]=t,i[1]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[0]},e.exports.hi=function(t){return n[0]=t,i[1]}}else if(1072693248===i[0]){e.exports=function(t){return n[0]=t,[i[1],i[0]]},e.exports.pack=function(t,e){return i[1]=t,i[0]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[1]},e.exports.hi=function(t){return n[0]=t,i[0]}}else r=!1}if(!r){var a=new t(8);e.exports=function(t){return a.writeDoubleLE(t,0,!0),[a.readUInt32LE(0,!0),a.readUInt32LE(4,!0)]},e.exports.pack=function(t,e){return a.writeUInt32LE(t,0,!0),a.writeUInt32LE(e,4,!0),a.readDoubleLE(0,!0)},e.exports.lo=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(0,!0)},e.exports.hi=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(4,!0)}}e.exports.sign=function(t){return e.exports.hi(t)>>>31},e.exports.exponent=function(t){return(e.exports.hi(t)<<1>>>21)-1023},e.exports.fraction=function(t){var r=e.exports.lo(t),n=e.exports.hi(t),i=1048575&n;return 2146435072&n&&(i+=1<<20),[r,i]},e.exports.denormalized=function(t){return!(2146435072&e.exports.hi(t))}}).call(this,t(\"buffer\").Buffer)},{buffer:105}],168:[function(t,e,r){var n=t(\"abs-svg-path\"),i=t(\"normalize-svg-path\"),a={M:\"moveTo\",C:\"bezierCurveTo\"};e.exports=function(t,e){t.beginPath(),i(n(e)).forEach(function(e){var r=e[0],n=e.slice(1);t[a[r]].apply(t,n)}),t.closePath()}},{\"abs-svg-path\":60,\"normalize-svg-path\":452}],169:[function(t,e,r){e.exports=function(t){switch(t){case\"int8\":return Int8Array;case\"int16\":return Int16Array;case\"int32\":return Int32Array;case\"uint8\":return Uint8Array;case\"uint16\":return Uint16Array;case\"uint32\":return Uint32Array;case\"float32\":return Float32Array;case\"float64\":return Float64Array;case\"array\":return Array;case\"uint8_clamped\":return Uint8ClampedArray}}},{}],170:[function(t,e,r){\"use strict\";e.exports=function(t,e){switch(\"undefined\"==typeof e&&(e=0),typeof t){case\"number\":if(t>0)return function(t,e){var r,n;for(r=new Array(t),n=0;n<t;++n)r[n]=e;return r}(0|t,e);break;case\"object\":if(\"number\"==typeof t.length)return function t(e,r,n){var i=0|e[n];if(i<=0)return[];var a,o=new Array(i);if(n===e.length-1)for(a=0;a<i;++a)o[a]=r;else for(a=0;a<i;++a)o[a]=t(e,r,n+1);return o}(t,e,0)}return[]}},{}],171:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(\"number\"!=typeof e){e=0;for(var i=0;i<r;++i){var a=t[i];e=Math.max(e,a[0],a[1])}e=1+(0|e)}e|=0;for(var o=new Array(e),i=0;i<e;++i)o[i]=[];for(var i=0;i<r;++i){var a=t[i];o[a[0]].push(a[1]),o[a[1]].push(a[0])}for(var s=0;s<e;++s)n(o[s],function(t,e){return t-e});return o};var n=t(\"uniq\")},{uniq:547}],172:[function(t,e,r){var n=t(\"strongly-connected-components\");e.exports=function(t){var e,r=[],i=[],a=[],o={},s=[];function l(t){var r,n,u=!1;for(i.push(t),a[t]=!0,r=0;r<s[t].length;r++)(n=s[t][r])===e?(c(e,i),u=!0):a[n]||(u=l(n));if(u)!function t(e){a[e]=!1,o.hasOwnProperty(e)&&Object.keys(o[e]).forEach(function(r){delete o[e][r],a[r]&&t(r)})}(t);else for(r=0;r<s[t].length;r++){n=s[t][r];var h=o[n];h||(h={},o[n]=h),h[n]=!0}return i.pop(),u}function c(t,e){var n=[].concat(e).concat(t);r.push(n)}function u(e){!function(e){for(var r=0;r<t.length;r++)r<e&&(t[r]=[]),t[r]=t[r].filter(function(t){return t>=e})}(e);for(var r,i=n(t).components.filter(function(t){return t.length>1}),a=1/0,o=0;o<i.length;o++)for(var s=0;s<i[o].length;s++)i[o][s]<a&&(a=i[o][s],r=o);var l=i[r];return!!l&&{leastVertex:a,adjList:t.map(function(t,e){return-1===l.indexOf(e)?[]:t.filter(function(t){return-1!==l.indexOf(t)})})}}e=0;for(var h=t.length;e<h;){var f=u(e);if(e=f.leastVertex,s=f.adjList){for(var p=0;p<s.length;p++)for(var d=0;d<s[p].length;d++){var g=s[p][d];a[+g]=!1,o[g]={}}l(e),e+=1}else e=h}return r}},{\"strongly-connected-components\":530}],173:[function(t,e,r){\"use strict\";var n=t(\"../../object/valid-value\");e.exports=function(){return n(this).length=0,this}},{\"../../object/valid-value\":205}],174:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Array.from:t(\"./shim\")},{\"./is-implemented\":175,\"./shim\":176}],175:[function(t,e,r){\"use strict\";e.exports=function(){var t,e,r=Array.from;return\"function\"==typeof r&&(e=r(t=[\"raz\",\"dwa\"]),Boolean(e&&e!==t&&\"dwa\"===e[1]))}},{}],176:[function(t,e,r){\"use strict\";var n=t(\"es6-symbol\").iterator,i=t(\"../../function/is-arguments\"),a=t(\"../../function/is-function\"),o=t(\"../../number/to-pos-integer\"),s=t(\"../../object/valid-callable\"),l=t(\"../../object/valid-value\"),c=t(\"../../object/is-value\"),u=t(\"../../string/is-string\"),h=Array.isArray,f=Function.prototype.call,p={configurable:!0,enumerable:!0,writable:!0,value:null},d=Object.defineProperty;e.exports=function(t){var e,r,g,v,m,y,x,b,_,w,k=arguments[1],T=arguments[2];if(t=Object(l(t)),c(k)&&s(k),this&&this!==Array&&a(this))e=this;else{if(!k){if(i(t))return 1!==(m=t.length)?Array.apply(null,t):((v=new Array(1))[0]=t[0],v);if(h(t)){for(v=new Array(m=t.length),r=0;r<m;++r)v[r]=t[r];return v}}v=[]}if(!h(t))if(void 0!==(_=t[n])){for(x=s(_).call(t),e&&(v=new e),b=x.next(),r=0;!b.done;)w=k?f.call(k,T,b.value,r):b.value,e?(p.value=w,d(v,r,p)):v[r]=w,b=x.next(),++r;m=r}else if(u(t)){for(m=t.length,e&&(v=new e),r=0,g=0;r<m;++r)w=t[r],r+1<m&&(y=w.charCodeAt(0))>=55296&&y<=56319&&(w+=t[++r]),w=k?f.call(k,T,w,g):w,e?(p.value=w,d(v,g,p)):v[g]=w,++g;m=g}if(void 0===m)for(m=o(t.length),e&&(v=new e(m)),r=0;r<m;++r)w=k?f.call(k,T,t[r],r):t[r],e?(p.value=w,d(v,r,p)):v[r]=w;return e&&(p.value=null,v.length=m),v}},{\"../../function/is-arguments\":177,\"../../function/is-function\":178,\"../../number/to-pos-integer\":184,\"../../object/is-value\":194,\"../../object/valid-callable\":203,\"../../object/valid-value\":205,\"../../string/is-string\":209,\"es6-symbol\":219}],177:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(function(){return arguments}());e.exports=function(t){return n.call(t)===i}},{}],178:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(t(\"./noop\"));e.exports=function(t){return\"function\"==typeof t&&n.call(t)===i}},{\"./noop\":179}],179:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],180:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Math.sign:t(\"./shim\")},{\"./is-implemented\":181,\"./shim\":182}],181:[function(t,e,r){\"use strict\";e.exports=function(){var t=Math.sign;return\"function\"==typeof t&&(1===t(10)&&-1===t(-20))}},{}],182:[function(t,e,r){\"use strict\";e.exports=function(t){return t=Number(t),isNaN(t)||0===t?t:t>0?1:-1}},{}],183:[function(t,e,r){\"use strict\";var n=t(\"../math/sign\"),i=Math.abs,a=Math.floor;e.exports=function(t){return isNaN(t)?0:0!==(t=Number(t))&&isFinite(t)?n(t)*a(i(t)):t}},{\"../math/sign\":180}],184:[function(t,e,r){\"use strict\";var n=t(\"./to-integer\"),i=Math.max;e.exports=function(t){return i(0,n(t))}},{\"./to-integer\":183}],185:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./valid-value\"),a=Function.prototype.bind,o=Function.prototype.call,s=Object.keys,l=Object.prototype.propertyIsEnumerable;e.exports=function(t,e){return function(r,c){var u,h=arguments[2],f=arguments[3];return r=Object(i(r)),n(c),u=s(r),f&&u.sort(\"function\"==typeof f?a.call(f,r):void 0),\"function\"!=typeof t&&(t=u[t]),o.call(t,u,function(t,n){return l.call(r,t)?o.call(c,h,r[t],t,r,n):e})}}},{\"./valid-callable\":203,\"./valid-value\":205}],186:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.assign:t(\"./shim\")},{\"./is-implemented\":187,\"./shim\":188}],187:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=Object.assign;return\"function\"==typeof e&&(e(t={foo:\"raz\"},{bar:\"dwa\"},{trzy:\"trzy\"}),t.foo+t.bar+t.trzy===\"razdwatrzy\")}},{}],188:[function(t,e,r){\"use strict\";var n=t(\"../keys\"),i=t(\"../valid-value\"),a=Math.max;e.exports=function(t,e){var r,o,s,l=a(arguments.length,2);for(t=Object(i(t)),s=function(n){try{t[n]=e[n]}catch(t){r||(r=t)}},o=1;o<l;++o)e=arguments[o],n(e).forEach(s);if(void 0!==r)throw r;return t}},{\"../keys\":195,\"../valid-value\":205}],189:[function(t,e,r){\"use strict\";var n=t(\"../array/from\"),i=t(\"./assign\"),a=t(\"./valid-value\");e.exports=function(t){var e=Object(a(t)),r=arguments[1],o=Object(arguments[2]);if(e!==t&&!r)return e;var s={};return r?n(r,function(e){(o.ensure||e in t)&&(s[e]=t[e])}):i(s,t),s}},{\"../array/from\":174,\"./assign\":186,\"./valid-value\":205}],190:[function(t,e,r){\"use strict\";var n,i,a,o,s=Object.create;t(\"./set-prototype-of/is-implemented\")()||(n=t(\"./set-prototype-of/shim\")),e.exports=n?1!==n.level?s:(i={},a={},o={configurable:!1,enumerable:!1,writable:!0,value:void 0},Object.getOwnPropertyNames(Object.prototype).forEach(function(t){a[t]=\"__proto__\"!==t?o:{configurable:!0,enumerable:!1,writable:!0,value:void 0}}),Object.defineProperties(i,a),Object.defineProperty(n,\"nullPolyfill\",{configurable:!1,enumerable:!1,writable:!1,value:i}),function(t,e){return s(null===t?i:t,e)}):s},{\"./set-prototype-of/is-implemented\":201,\"./set-prototype-of/shim\":202}],191:[function(t,e,r){\"use strict\";e.exports=t(\"./_iterate\")(\"forEach\")},{\"./_iterate\":185}],192:[function(t,e,r){\"use strict\";e.exports=function(t){return\"function\"==typeof t}},{}],193:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i={function:!0,object:!0};e.exports=function(t){return n(t)&&i[typeof t]||!1}},{\"./is-value\":194}],194:[function(t,e,r){\"use strict\";var n=t(\"../function/noop\")();e.exports=function(t){return t!==n&&null!==t}},{\"../function/noop\":179}],195:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.keys:t(\"./shim\")},{\"./is-implemented\":196,\"./shim\":197}],196:[function(t,e,r){\"use strict\";e.exports=function(){try{return Object.keys(\"primitive\"),!0}catch(t){return!1}}},{}],197:[function(t,e,r){\"use strict\";var n=t(\"../is-value\"),i=Object.keys;e.exports=function(t){return i(n(t)?Object(t):t)}},{\"../is-value\":194}],198:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./for-each\"),a=Function.prototype.call;e.exports=function(t,e){var r={},o=arguments[2];return n(e),i(t,function(t,n,i,s){r[n]=a.call(e,o,t,n,i,s)}),r}},{\"./for-each\":191,\"./valid-callable\":203}],199:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i=Array.prototype.forEach,a=Object.create;e.exports=function(t){var e=a(null);return i.call(arguments,function(t){n(t)&&function(t,e){var r;for(r in t)e[r]=t[r]}(Object(t),e)}),e}},{\"./is-value\":194}],200:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.setPrototypeOf:t(\"./shim\")},{\"./is-implemented\":201,\"./shim\":202}],201:[function(t,e,r){\"use strict\";var n=Object.create,i=Object.getPrototypeOf,a={};e.exports=function(){var t=Object.setPrototypeOf,e=arguments[0]||n;return\"function\"==typeof t&&i(t(e(null),a))===a}},{}],202:[function(t,e,r){\"use strict\";var n,i,a,o,s=t(\"../is-object\"),l=t(\"../valid-value\"),c=Object.prototype.isPrototypeOf,u=Object.defineProperty,h={configurable:!0,enumerable:!1,writable:!0,value:void 0};n=function(t,e){if(l(t),null===e||s(e))return t;throw new TypeError(\"Prototype must be null or an object\")},e.exports=(i=function(){var t,e=Object.create(null),r={},n=Object.getOwnPropertyDescriptor(Object.prototype,\"__proto__\");if(n){try{(t=n.set).call(e,r)}catch(t){}if(Object.getPrototypeOf(e)===r)return{set:t,level:2}}return e.__proto__=r,Object.getPrototypeOf(e)===r?{level:2}:((e={}).__proto__=r,Object.getPrototypeOf(e)===r&&{level:1})}())?(2===i.level?i.set?(o=i.set,a=function(t,e){return o.call(n(t,e),e),t}):a=function(t,e){return n(t,e).__proto__=e,t}:a=function t(e,r){var i;return n(e,r),(i=c.call(t.nullPolyfill,e))&&delete t.nullPolyfill.__proto__,null===r&&(r=t.nullPolyfill),e.__proto__=r,i&&u(t.nullPolyfill,\"__proto__\",h),e},Object.defineProperty(a,\"level\",{configurable:!1,enumerable:!1,writable:!1,value:i.level})):null,t(\"../create\")},{\"../create\":190,\"../is-object\":193,\"../valid-value\":205}],203:[function(t,e,r){\"use strict\";e.exports=function(t){if(\"function\"!=typeof t)throw new TypeError(t+\" is not a function\");return t}},{}],204:[function(t,e,r){\"use strict\";var n=t(\"./is-object\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not an Object\");return t}},{\"./is-object\":193}],205:[function(t,e,r){\"use strict\";var n=t(\"./is-value\");e.exports=function(t){if(!n(t))throw new TypeError(\"Cannot use null or undefined\");return t}},{\"./is-value\":194}],206:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?String.prototype.contains:t(\"./shim\")},{\"./is-implemented\":207,\"./shim\":208}],207:[function(t,e,r){\"use strict\";var n=\"razdwatrzy\";e.exports=function(){return\"function\"==typeof n.contains&&(!0===n.contains(\"dwa\")&&!1===n.contains(\"foo\"))}},{}],208:[function(t,e,r){\"use strict\";var n=String.prototype.indexOf;e.exports=function(t){return n.call(this,t,arguments[1])>-1}},{}],209:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(\"\");e.exports=function(t){return\"string\"==typeof t||t&&\"object\"==typeof t&&(t instanceof String||n.call(t)===i)||!1}},{}],210:[function(t,e,r){\"use strict\";var n=Object.create(null),i=Math.random;e.exports=function(){var t;do{t=i().toString(36).slice(2)}while(n[t]);return t}},{}],211:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"es5-ext/string/#/contains\"),o=t(\"d\"),s=t(\"es6-symbol\"),l=t(\"./\"),c=Object.defineProperty;n=e.exports=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");l.call(this,t),e=e?a.call(e,\"key+value\")?\"key+value\":a.call(e,\"key\")?\"key\":\"value\":\"value\",c(this,\"__kind__\",o(\"\",e))},i&&i(n,l),delete n.prototype.constructor,n.prototype=Object.create(l.prototype,{_resolve:o(function(t){return\"value\"===this.__kind__?this.__list__[t]:\"key+value\"===this.__kind__?[t,this.__list__[t]]:t})}),c(n.prototype,s.toStringTag,o(\"c\",\"Array Iterator\"))},{\"./\":214,d:151,\"es5-ext/object/set-prototype-of\":200,\"es5-ext/string/#/contains\":206,\"es6-symbol\":219}],212:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/valid-callable\"),a=t(\"es5-ext/string/is-string\"),o=t(\"./get\"),s=Array.isArray,l=Function.prototype.call,c=Array.prototype.some;e.exports=function(t,e){var r,u,h,f,p,d,g,v,m=arguments[2];if(s(t)||n(t)?r=\"array\":a(t)?r=\"string\":t=o(t),i(e),h=function(){f=!0},\"array\"!==r)if(\"string\"!==r)for(u=t.next();!u.done;){if(l.call(e,m,u.value,h),f)return;u=t.next()}else for(d=t.length,p=0;p<d&&(g=t[p],p+1<d&&(v=g.charCodeAt(0))>=55296&&v<=56319&&(g+=t[++p]),l.call(e,m,g,h),!f);++p);else c.call(t,function(t){return l.call(e,m,t,h),f})}},{\"./get\":213,\"es5-ext/function/is-arguments\":177,\"es5-ext/object/valid-callable\":203,\"es5-ext/string/is-string\":209}],213:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/string/is-string\"),a=t(\"./array\"),o=t(\"./string\"),s=t(\"./valid-iterable\"),l=t(\"es6-symbol\").iterator;e.exports=function(t){return\"function\"==typeof s(t)[l]?t[l]():n(t)?new a(t):i(t)?new o(t):new a(t)}},{\"./array\":211,\"./string\":216,\"./valid-iterable\":217,\"es5-ext/function/is-arguments\":177,\"es5-ext/string/is-string\":209,\"es6-symbol\":219}],214:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/array/#/clear\"),a=t(\"es5-ext/object/assign\"),o=t(\"es5-ext/object/valid-callable\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"d\"),c=t(\"d/auto-bind\"),u=t(\"es6-symbol\"),h=Object.defineProperty,f=Object.defineProperties;e.exports=n=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");f(this,{__list__:l(\"w\",s(t)),__context__:l(\"w\",e),__nextIndex__:l(\"w\",0)}),e&&(o(e.on),e.on(\"_add\",this._onAdd),e.on(\"_delete\",this._onDelete),e.on(\"_clear\",this._onClear))},delete n.prototype.constructor,f(n.prototype,a({_next:l(function(){var t;if(this.__list__)return this.__redo__&&void 0!==(t=this.__redo__.shift())?t:this.__nextIndex__<this.__list__.length?this.__nextIndex__++:void this._unBind()}),next:l(function(){return this._createResult(this._next())}),_createResult:l(function(t){return void 0===t?{done:!0,value:void 0}:{done:!1,value:this._resolve(t)}}),_resolve:l(function(t){return this.__list__[t]}),_unBind:l(function(){this.__list__=null,delete this.__redo__,this.__context__&&(this.__context__.off(\"_add\",this._onAdd),this.__context__.off(\"_delete\",this._onDelete),this.__context__.off(\"_clear\",this._onClear),this.__context__=null)}),toString:l(function(){return\"[object \"+(this[u.toStringTag]||\"Object\")+\"]\"})},c({_onAdd:l(function(t){t>=this.__nextIndex__||(++this.__nextIndex__,this.__redo__?(this.__redo__.forEach(function(e,r){e>=t&&(this.__redo__[r]=++e)},this),this.__redo__.push(t)):h(this,\"__redo__\",l(\"c\",[t])))}),_onDelete:l(function(t){var e;t>=this.__nextIndex__||(--this.__nextIndex__,this.__redo__&&(-1!==(e=this.__redo__.indexOf(t))&&this.__redo__.splice(e,1),this.__redo__.forEach(function(e,r){e>t&&(this.__redo__[r]=--e)},this)))}),_onClear:l(function(){this.__redo__&&i.call(this.__redo__),this.__nextIndex__=0})}))),h(n.prototype,u.iterator,l(function(){return this}))},{d:151,\"d/auto-bind\":150,\"es5-ext/array/#/clear\":173,\"es5-ext/object/assign\":186,\"es5-ext/object/valid-callable\":203,\"es5-ext/object/valid-value\":205,\"es6-symbol\":219}],215:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/string/is-string\"),o=t(\"es6-symbol\").iterator,s=Array.isArray;e.exports=function(t){return!!i(t)&&(!!s(t)||(!!a(t)||(!!n(t)||\"function\"==typeof t[o])))}},{\"es5-ext/function/is-arguments\":177,\"es5-ext/object/is-value\":194,\"es5-ext/string/is-string\":209,\"es6-symbol\":219}],216:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"d\"),o=t(\"es6-symbol\"),s=t(\"./\"),l=Object.defineProperty;n=e.exports=function(t){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");t=String(t),s.call(this,t),l(this,\"__length__\",a(\"\",t.length))},i&&i(n,s),delete n.prototype.constructor,n.prototype=Object.create(s.prototype,{_next:a(function(){if(this.__list__)return this.__nextIndex__<this.__length__?this.__nextIndex__++:void this._unBind()}),_resolve:a(function(t){var e,r=this.__list__[t];return this.__nextIndex__===this.__length__?r:(e=r.charCodeAt(0))>=55296&&e<=56319?r+this.__list__[this.__nextIndex__++]:r})}),l(n.prototype,o.toStringTag,a(\"c\",\"String Iterator\"))},{\"./\":214,d:151,\"es5-ext/object/set-prototype-of\":200,\"es6-symbol\":219}],217:[function(t,e,r){\"use strict\";var n=t(\"./is-iterable\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not iterable\");return t}},{\"./is-iterable\":215}],218:[function(t,e,r){(function(n,i){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():t.ES6Promise=n()}(this,function(){\"use strict\";function e(t){return\"function\"==typeof t}var r=Array.isArray?Array.isArray:function(t){return\"[object Array]\"===Object.prototype.toString.call(t)},a=0,o=void 0,s=void 0,l=function(t,e){g[a]=t,g[a+1]=e,2===(a+=2)&&(s?s(v):_())};var c=\"undefined\"!=typeof window?window:void 0,u=c||{},h=u.MutationObserver||u.WebKitMutationObserver,f=\"undefined\"==typeof self&&\"undefined\"!=typeof n&&\"[object process]\"==={}.toString.call(n),p=\"undefined\"!=typeof Uint8ClampedArray&&\"undefined\"!=typeof importScripts&&\"undefined\"!=typeof MessageChannel;function d(){var t=setTimeout;return function(){return t(v,1)}}var g=new Array(1e3);function v(){for(var t=0;t<a;t+=2){(0,g[t])(g[t+1]),g[t]=void 0,g[t+1]=void 0}a=0}var m,y,x,b,_=void 0;function w(t,e){var r=arguments,n=this,i=new this.constructor(A);void 0===i[T]&&V(i);var a,o=n._state;return o?(a=r[o-1],l(function(){return j(o,i,a,n._result)})):R(n,i,t,e),i}function k(t){if(t&&\"object\"==typeof t&&t.constructor===this)return t;var e=new this(A);return O(e,t),e}f?_=function(){return n.nextTick(v)}:h?(y=0,x=new h(v),b=document.createTextNode(\"\"),x.observe(b,{characterData:!0}),_=function(){b.data=y=++y%2}):p?((m=new MessageChannel).port1.onmessage=v,_=function(){return m.port2.postMessage(0)}):_=void 0===c&&\"function\"==typeof t?function(){try{var e=t(\"vertx\");return o=e.runOnLoop||e.runOnContext,function(){o(v)}}catch(t){return d()}}():d();var T=Math.random().toString(36).substring(16);function A(){}var M=void 0,S=1,E=2,C=new B;function L(t){try{return t.then}catch(t){return C.error=t,C}}function P(t,r,n){r.constructor===t.constructor&&n===w&&r.constructor.resolve===k?function(t,e){e._state===S?I(t,e._result):e._state===E?D(t,e._result):R(e,void 0,function(e){return O(t,e)},function(e){return D(t,e)})}(t,r):n===C?D(t,C.error):void 0===n?I(t,r):e(n)?function(t,e,r){l(function(t){var n=!1,i=function(t,e,r,n){try{t.call(e,r,n)}catch(t){return t}}(r,e,function(r){n||(n=!0,e!==r?O(t,r):I(t,r))},function(e){n||(n=!0,D(t,e))},t._label);!n&&i&&(n=!0,D(t,i))},t)}(t,r,n):I(t,r)}function O(t,e){var r;t===e?D(t,new TypeError(\"You cannot resolve a promise with itself\")):\"function\"==typeof(r=e)||\"object\"==typeof r&&null!==r?P(t,e,L(e)):I(t,e)}function z(t){t._onerror&&t._onerror(t._result),F(t)}function I(t,e){t._state===M&&(t._result=e,t._state=S,0!==t._subscribers.length&&l(F,t))}function D(t,e){t._state===M&&(t._state=E,t._result=e,l(z,t))}function R(t,e,r,n){var i=t._subscribers,a=i.length;t._onerror=null,i[a]=e,i[a+S]=r,i[a+E]=n,0===a&&t._state&&l(F,t)}function F(t){var e=t._subscribers,r=t._state;if(0!==e.length){for(var n=void 0,i=void 0,a=t._result,o=0;o<e.length;o+=3)n=e[o],i=e[o+r],n?j(r,n,i,a):i(a);t._subscribers.length=0}}function B(){this.error=null}var N=new B;function j(t,r,n,i){var a=e(n),o=void 0,s=void 0,l=void 0,c=void 0;if(a){if((o=function(t,e){try{return t(e)}catch(t){return N.error=t,N}}(n,i))===N?(c=!0,s=o.error,o=null):l=!0,r===o)return void D(r,new TypeError(\"A promises callback cannot return that same promise.\"))}else o=i,l=!0;r._state!==M||(a&&l?O(r,o):c?D(r,s):t===S?I(r,o):t===E&&D(r,o))}var U=0;function V(t){t[T]=U++,t._state=void 0,t._result=void 0,t._subscribers=[]}function q(t,e){this._instanceConstructor=t,this.promise=new t(A),this.promise[T]||V(this.promise),r(e)?(this._input=e,this.length=e.length,this._remaining=e.length,this._result=new Array(this.length),0===this.length?I(this.promise,this._result):(this.length=this.length||0,this._enumerate(),0===this._remaining&&I(this.promise,this._result))):D(this.promise,new Error(\"Array Methods must be provided an Array\"))}function H(t){this[T]=U++,this._result=this._state=void 0,this._subscribers=[],A!==t&&(\"function\"!=typeof t&&function(){throw new TypeError(\"You must pass a resolver function as the first argument to the promise constructor\")}(),this instanceof H?function(t,e){try{e(function(e){O(t,e)},function(e){D(t,e)})}catch(e){D(t,e)}}(this,t):function(){throw new TypeError(\"Failed to construct 'Promise': Please use the 'new' operator, this object constructor cannot be called as a function.\")}())}function G(){var t=void 0;if(\"undefined\"!=typeof i)t=i;else if(\"undefined\"!=typeof self)t=self;else try{t=Function(\"return this\")()}catch(t){throw new Error(\"polyfill failed because global object is unavailable in this environment\")}var e=t.Promise;if(e){var r=null;try{r=Object.prototype.toString.call(e.resolve())}catch(t){}if(\"[object Promise]\"===r&&!e.cast)return}t.Promise=H}return q.prototype._enumerate=function(){for(var t=this.length,e=this._input,r=0;this._state===M&&r<t;r++)this._eachEntry(e[r],r)},q.prototype._eachEntry=function(t,e){var r=this._instanceConstructor,n=r.resolve;if(n===k){var i=L(t);if(i===w&&t._state!==M)this._settledAt(t._state,e,t._result);else if(\"function\"!=typeof i)this._remaining--,this._result[e]=t;else if(r===H){var a=new r(A);P(a,t,i),this._willSettleAt(a,e)}else this._willSettleAt(new r(function(e){return e(t)}),e)}else this._willSettleAt(n(t),e)},q.prototype._settledAt=function(t,e,r){var n=this.promise;n._state===M&&(this._remaining--,t===E?D(n,r):this._result[e]=r),0===this._remaining&&I(n,this._result)},q.prototype._willSettleAt=function(t,e){var r=this;R(t,void 0,function(t){return r._settledAt(S,e,t)},function(t){return r._settledAt(E,e,t)})},H.all=function(t){return new q(this,t).promise},H.race=function(t){var e=this;return r(t)?new e(function(r,n){for(var i=t.length,a=0;a<i;a++)e.resolve(t[a]).then(r,n)}):new e(function(t,e){return e(new TypeError(\"You must pass an array to race.\"))})},H.resolve=k,H.reject=function(t){var e=new this(A);return D(e,t),e},H._setScheduler=function(t){s=t},H._setAsap=function(t){l=t},H._asap=l,H.prototype={constructor:H,then:w,catch:function(t){return this.then(null,t)}},G(),H.polyfill=G,H.Promise=H,H})}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{_process:482}],219:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Symbol:t(\"./polyfill\")},{\"./is-implemented\":220,\"./polyfill\":222}],220:[function(t,e,r){\"use strict\";var n={object:!0,symbol:!0};e.exports=function(){var t;if(\"function\"!=typeof Symbol)return!1;t=Symbol(\"test symbol\");try{String(t)}catch(t){return!1}return!!n[typeof Symbol.iterator]&&(!!n[typeof Symbol.toPrimitive]&&!!n[typeof Symbol.toStringTag])}},{}],221:[function(t,e,r){\"use strict\";e.exports=function(t){return!!t&&(\"symbol\"==typeof t||!!t.constructor&&(\"Symbol\"===t.constructor.name&&\"Symbol\"===t[t.constructor.toStringTag]))}},{}],222:[function(t,e,r){\"use strict\";var n,i,a,o,s=t(\"d\"),l=t(\"./validate-symbol\"),c=Object.create,u=Object.defineProperties,h=Object.defineProperty,f=Object.prototype,p=c(null);if(\"function\"==typeof Symbol){n=Symbol;try{String(n()),o=!0}catch(t){}}var d,g=(d=c(null),function(t){for(var e,r,n=0;d[t+(n||\"\")];)++n;return d[t+=n||\"\"]=!0,h(f,e=\"@@\"+t,s.gs(null,function(t){r||(r=!0,h(this,e,s(t)),r=!1)})),e});a=function(t){if(this instanceof a)throw new TypeError(\"Symbol is not a constructor\");return i(t)},e.exports=i=function t(e){var r;if(this instanceof t)throw new TypeError(\"Symbol is not a constructor\");return o?n(e):(r=c(a.prototype),e=void 0===e?\"\":String(e),u(r,{__description__:s(\"\",e),__name__:s(\"\",g(e))}))},u(i,{for:s(function(t){return p[t]?p[t]:p[t]=i(String(t))}),keyFor:s(function(t){var e;for(e in l(t),p)if(p[e]===t)return e}),hasInstance:s(\"\",n&&n.hasInstance||i(\"hasInstance\")),isConcatSpreadable:s(\"\",n&&n.isConcatSpreadable||i(\"isConcatSpreadable\")),iterator:s(\"\",n&&n.iterator||i(\"iterator\")),match:s(\"\",n&&n.match||i(\"match\")),replace:s(\"\",n&&n.replace||i(\"replace\")),search:s(\"\",n&&n.search||i(\"search\")),species:s(\"\",n&&n.species||i(\"species\")),split:s(\"\",n&&n.split||i(\"split\")),toPrimitive:s(\"\",n&&n.toPrimitive||i(\"toPrimitive\")),toStringTag:s(\"\",n&&n.toStringTag||i(\"toStringTag\")),unscopables:s(\"\",n&&n.unscopables||i(\"unscopables\"))}),u(a.prototype,{constructor:s(i),toString:s(\"\",function(){return this.__name__})}),u(i.prototype,{toString:s(function(){return\"Symbol (\"+l(this).__description__+\")\"}),valueOf:s(function(){return l(this)})}),h(i.prototype,i.toPrimitive,s(\"\",function(){var t=l(this);return\"symbol\"==typeof t?t:t.toString()})),h(i.prototype,i.toStringTag,s(\"c\",\"Symbol\")),h(a.prototype,i.toStringTag,s(\"c\",i.prototype[i.toStringTag])),h(a.prototype,i.toPrimitive,s(\"c\",i.prototype[i.toPrimitive]))},{\"./validate-symbol\":223,d:151}],223:[function(t,e,r){\"use strict\";var n=t(\"./is-symbol\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not a symbol\");return t}},{\"./is-symbol\":221}],224:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=e||0,i=r||1;return[[t[12]+t[0],t[13]+t[1],t[14]+t[2],t[15]+t[3]],[t[12]-t[0],t[13]-t[1],t[14]-t[2],t[15]-t[3]],[t[12]+t[4],t[13]+t[5],t[14]+t[6],t[15]+t[7]],[t[12]-t[4],t[13]-t[5],t[14]-t[6],t[15]-t[7]],[n*t[12]+t[8],n*t[13]+t[9],n*t[14]+t[10],n*t[15]+t[11]],[i*t[12]-t[8],i*t[13]-t[9],i*t[14]-t[10],i*t[15]-t[11]]]}},{}],225:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\");e.exports=function(t){var e=typeof t;if(\"string\"===e){var r=t;if(0===(t=+t)&&n(r))return!1}else if(\"number\"!==e)return!1;return t-t<1}},{\"is-string-blank\":423}],226:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 0:return new o([0],[0],0);case 1:if(\"number\"==typeof t){var n=l(t);return new o(n,n,0)}return new o(t,l(t.length),0);case 2:if(\"number\"==typeof e){var n=l(t.length);return new o(t,n,+e)}r=0;case 3:if(t.length!==e.length)throw new Error(\"state and velocity lengths must match\");return new o(t,e,r)}};var n=t(\"cubic-hermite\"),i=t(\"binary-search-bounds\");function a(t,e,r){return Math.min(e,Math.max(t,r))}function o(t,e,r){this.dimension=t.length,this.bounds=[new Array(this.dimension),new Array(this.dimension)];for(var n=0;n<this.dimension;++n)this.bounds[0][n]=-1/0,this.bounds[1][n]=1/0;this._state=t.slice().reverse(),this._velocity=e.slice().reverse(),this._time=[r],this._scratch=[t.slice(),t.slice(),t.slice(),t.slice(),t.slice()]}var s=o.prototype;function l(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=0;return e}s.flush=function(t){var e=i.gt(this._time,t)-1;e<=0||(this._time.splice(0,e),this._state.splice(0,e*this.dimension),this._velocity.splice(0,e*this.dimension))},s.curve=function(t){var e=this._time,r=e.length,o=i.le(e,t),s=this._scratch[0],l=this._state,c=this._velocity,u=this.dimension,h=this.bounds;if(o<0)for(var f=u-1,p=0;p<u;++p,--f)s[p]=l[f];else if(o>=r-1){f=l.length-1;var d=t-e[r-1];for(p=0;p<u;++p,--f)s[p]=l[f]+d*c[f]}else{f=u*(o+1)-1;var g=e[o],v=e[o+1]-g||1,m=this._scratch[1],y=this._scratch[2],x=this._scratch[3],b=this._scratch[4],_=!0;for(p=0;p<u;++p,--f)m[p]=l[f],x[p]=c[f]*v,y[p]=l[f+u],b[p]=c[f+u]*v,_=_&&m[p]===y[p]&&x[p]===b[p]&&0===x[p];if(_)for(p=0;p<u;++p)s[p]=m[p];else n(m,x,y,b,(t-g)/v,s)}var w=h[0],k=h[1];for(p=0;p<u;++p)s[p]=a(w[p],k[p],s[p]);return s},s.dcurve=function(t){var e=this._time,r=e.length,a=i.le(e,t),o=this._scratch[0],s=this._state,l=this._velocity,c=this.dimension;if(a>=r-1)for(var u=s.length-1,h=(e[r-1],0);h<c;++h,--u)o[h]=l[u];else{u=c*(a+1)-1;var f=e[a],p=e[a+1]-f||1,d=this._scratch[1],g=this._scratch[2],v=this._scratch[3],m=this._scratch[4],y=!0;for(h=0;h<c;++h,--u)d[h]=s[u],v[h]=l[u]*p,g[h]=s[u+c],m[h]=l[u+c]*p,y=y&&d[h]===g[h]&&v[h]===m[h]&&0===v[h];if(y)for(h=0;h<c;++h)o[h]=0;else{n.derivative(d,v,g,m,(t-f)/p,o);for(h=0;h<c;++h)o[h]/=p}}return o},s.lastT=function(){var t=this._time;return t[t.length-1]},s.stable=function(){for(var t=this._velocity,e=t.length,r=this.dimension-1;r>=0;--r)if(t[--e])return!1;return!0},s.jump=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1];this._time.push(e,t);for(var u=0;u<2;++u)for(var h=0;h<r;++h)n.push(n[o++]),i.push(0);this._time.push(t);for(h=r;h>0;--h)n.push(a(l[h-1],c[h-1],arguments[h])),i.push(0)}},s.push=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=t-e,l=this.bounds,c=l[0],u=l[1],h=s>1e-6?1/s:0;this._time.push(t);for(var f=r;f>0;--f){var p=a(c[f-1],u[f-1],arguments[f]);n.push(p),i.push((p-n[o++])*h)}}},s.set=function(t){var e=this.dimension;if(!(t<this.lastT()||arguments.length!==e+1)){var r=this._state,n=this._velocity,i=this.bounds,o=i[0],s=i[1];this._time.push(t);for(var l=e;l>0;--l)r.push(a(o[l-1],s[l-1],arguments[l])),n.push(0)}},s.move=function(t){var e=this.lastT(),r=this.dimension;if(!(t<=e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1],u=t-e,h=u>1e-6?1/u:0;this._time.push(t);for(var f=r;f>0;--f){var p=arguments[f];n.push(a(l[f-1],c[f-1],n[o++]+p)),i.push(p*h)}}},s.idle=function(t){var e=this.lastT();if(!(t<e)){var r=this.dimension,n=this._state,i=this._velocity,o=n.length-r,s=this.bounds,l=s[0],c=s[1],u=t-e;this._time.push(t);for(var h=r-1;h>=0;--h)n.push(a(l[h],c[h],n[o]+u*i[o])),i.push(0),o+=1}}},{\"binary-search-bounds\":91,\"cubic-hermite\":145}],227:[function(t,e,r){var n=t(\"dtype\");e.exports=function(t,e,r){if(!t)throw new TypeError(\"must specify data as first parameter\");if(r=0|+(r||0),Array.isArray(t)&&t[0]&&\"number\"==typeof t[0][0]){var i,a,o,s,l=t[0].length,c=t.length*l;e&&\"string\"!=typeof e||(e=new(n(e||\"float32\"))(c+r));var u=e.length-r;if(c!==u)throw new Error(\"source length \"+c+\" (\"+l+\"x\"+t.length+\") does not match destination length \"+u);for(i=0,o=r;i<t.length;i++)for(a=0;a<l;a++)e[o++]=null===t[i][a]?NaN:t[i][a]}else if(e&&\"string\"!=typeof e)e.set(t,r);else{var h=n(e||\"float32\");if(Array.isArray(t)||\"array\"===e)for(e=new h(t.length+r),i=0,o=r,s=e.length;o<s;o++,i++)e[o]=null===t[i]?NaN:t[i];else 0===r?e=new h(t):(e=new h(t.length+r)).set(t,r)}return e}},{dtype:169}],228:[function(t,e,r){\"use strict\";var n=t(\"css-font/stringify\"),i=[32,126];e.exports=function(t){var e=(t=t||{}).shape?t.shape:t.canvas?[t.canvas.width,t.canvas.height]:[512,512],r=t.canvas||document.createElement(\"canvas\"),a=t.font,o=\"number\"==typeof t.step?[t.step,t.step]:t.step||[32,32],s=t.chars||i;a&&\"string\"!=typeof a&&(a=n(a));if(Array.isArray(s)){if(2===s.length&&\"number\"==typeof s[0]&&\"number\"==typeof s[1]){for(var l=[],c=s[0],u=0;c<=s[1];c++)l[u++]=String.fromCharCode(c);s=l}}else s=String(s).split(\"\");e=e.slice(),r.width=e[0],r.height=e[1];var h=r.getContext(\"2d\");h.fillStyle=\"#000\",h.fillRect(0,0,r.width,r.height),h.font=a,h.textAlign=\"center\",h.textBaseline=\"middle\",h.fillStyle=\"#fff\";for(var f=o[0]/2,p=o[1]/2,c=0;c<s.length;c++)h.fillText(s[c],f,p),(f+=o[0])>e[0]-o[0]/2&&(f=o[0]/2,p+=o[1]);return r}},{\"css-font/stringify\":142}],229:[function(t,e,r){\"use strict\";function n(t,e){e||(e={}),(\"string\"==typeof t||Array.isArray(t))&&(e.family=t);var r=Array.isArray(e.family)?e.family.join(\", \"):e.family;if(!r)throw Error(\"`family` must be defined\");var s=e.size||e.fontSize||e.em||48,l=e.weight||e.fontWeight||\"\",c=(t=[e.style||e.fontStyle||\"\",l,s].join(\" \")+\"px \"+r,e.origin||\"top\");if(n.cache[r]&&s<=n.cache[r].em)return i(n.cache[r],c);var u=e.canvas||n.canvas,h=u.getContext(\"2d\"),f={upper:void 0!==e.upper?e.upper:\"H\",lower:void 0!==e.lower?e.lower:\"x\",descent:void 0!==e.descent?e.descent:\"p\",ascent:void 0!==e.ascent?e.ascent:\"h\",tittle:void 0!==e.tittle?e.tittle:\"i\",overshoot:void 0!==e.overshoot?e.overshoot:\"O\"},p=Math.ceil(1.5*s);u.height=p,u.width=.5*p,h.font=t;var d={top:0};h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillStyle=\"black\",h.fillText(\"H\",0,0);var g=a(h.getImageData(0,0,p,p));h.clearRect(0,0,p,p),h.textBaseline=\"bottom\",h.fillText(\"H\",0,p);var v=a(h.getImageData(0,0,p,p));d.lineHeight=d.bottom=p-v+g,h.clearRect(0,0,p,p),h.textBaseline=\"alphabetic\",h.fillText(\"H\",0,p);var m=p-a(h.getImageData(0,0,p,p))-1+g;d.baseline=d.alphabetic=m,h.clearRect(0,0,p,p),h.textBaseline=\"middle\",h.fillText(\"H\",0,.5*p);var y=a(h.getImageData(0,0,p,p));d.median=d.middle=p-y-1+g-.5*p,h.clearRect(0,0,p,p),h.textBaseline=\"hanging\",h.fillText(\"H\",0,.5*p);var x=a(h.getImageData(0,0,p,p));d.hanging=p-x-1+g-.5*p,h.clearRect(0,0,p,p),h.textBaseline=\"ideographic\",h.fillText(\"H\",0,p);var b=a(h.getImageData(0,0,p,p));if(d.ideographic=p-b-1+g,f.upper&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.upper,0,0),d.upper=a(h.getImageData(0,0,p,p)),d.capHeight=d.baseline-d.upper),f.lower&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.lower,0,0),d.lower=a(h.getImageData(0,0,p,p)),d.xHeight=d.baseline-d.lower),f.tittle&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.tittle,0,0),d.tittle=a(h.getImageData(0,0,p,p))),f.ascent&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.ascent,0,0),d.ascent=a(h.getImageData(0,0,p,p))),f.descent&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.descent,0,0),d.descent=o(h.getImageData(0,0,p,p))),f.overshoot){h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.overshoot,0,0);var _=o(h.getImageData(0,0,p,p));d.overshoot=_-m}for(var w in d)d[w]/=s;return d.em=s,n.cache[r]=d,i(d,c)}function i(t,e){var r={};for(var n in\"string\"==typeof e&&(e=t[e]),t)\"em\"!==n&&(r[n]=t[n]-e);return r}function a(t){for(var e=t.height,r=t.data,n=3;n<r.length;n+=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}function o(t){for(var e=t.height,r=t.data,n=r.length-1;n>0;n-=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}e.exports=n,n.canvas=document.createElement(\"canvas\"),n.cache={}},{}],230:[function(t,e,r){\"use strict\";e.exports=function(t){return new c(t||d,null)};var n=0,i=1;function a(t,e,r,n,i,a){this._color=t,this.key=e,this.value=r,this.left=n,this.right=i,this._count=a}function o(t){return new a(t._color,t.key,t.value,t.left,t.right,t._count)}function s(t,e){return new a(t,e.key,e.value,e.left,e.right,e._count)}function l(t){t._count=1+(t.left?t.left._count:0)+(t.right?t.right._count:0)}function c(t,e){this._compare=t,this.root=e}var u=c.prototype;function h(t,e){this.tree=t,this._stack=e}Object.defineProperty(u,\"keys\",{get:function(){var t=[];return this.forEach(function(e,r){t.push(e)}),t}}),Object.defineProperty(u,\"values\",{get:function(){var t=[];return this.forEach(function(e,r){t.push(r)}),t}}),Object.defineProperty(u,\"length\",{get:function(){return this.root?this.root._count:0}}),u.insert=function(t,e){for(var r=this._compare,o=this.root,u=[],h=[];o;){var f=r(t,o.key);u.push(o),h.push(f),o=f<=0?o.left:o.right}u.push(new a(n,t,e,null,null,1));for(var p=u.length-2;p>=0;--p){o=u[p];h[p]<=0?u[p]=new a(o._color,o.key,o.value,u[p+1],o.right,o._count+1):u[p]=new a(o._color,o.key,o.value,o.left,u[p+1],o._count+1)}for(p=u.length-1;p>1;--p){var d=u[p-1];o=u[p];if(d._color===i||o._color===i)break;var g=u[p-2];if(g.left===d)if(d.left===o){if(!(v=g.right)||v._color!==n){if(g._color=n,g.left=d.right,d._color=i,d.right=g,u[p-2]=d,u[p-1]=o,l(g),l(d),p>=3)(m=u[p-3]).left===g?m.left=d:m.right=d;break}d._color=i,g.right=s(i,v),g._color=n,p-=1}else{if(!(v=g.right)||v._color!==n){if(d.right=o.left,g._color=n,g.left=o.right,o._color=i,o.left=d,o.right=g,u[p-2]=o,u[p-1]=d,l(g),l(d),l(o),p>=3)(m=u[p-3]).left===g?m.left=o:m.right=o;break}d._color=i,g.right=s(i,v),g._color=n,p-=1}else if(d.right===o){if(!(v=g.left)||v._color!==n){if(g._color=n,g.right=d.left,d._color=i,d.left=g,u[p-2]=d,u[p-1]=o,l(g),l(d),p>=3)(m=u[p-3]).right===g?m.right=d:m.left=d;break}d._color=i,g.left=s(i,v),g._color=n,p-=1}else{var v;if(!(v=g.left)||v._color!==n){var m;if(d.left=o.right,g._color=n,g.right=o.left,o._color=i,o.right=d,o.left=g,u[p-2]=o,u[p-1]=d,l(g),l(d),l(o),p>=3)(m=u[p-3]).right===g?m.right=o:m.left=o;break}d._color=i,g.left=s(i,v),g._color=n,p-=1}}return u[0]._color=i,new c(r,u[0])},u.forEach=function(t,e,r){if(this.root)switch(arguments.length){case 1:return function t(e,r){var n;if(r.left&&(n=t(e,r.left)))return n;return(n=e(r.key,r.value))||(r.right?t(e,r.right):void 0)}(t,this.root);case 2:return function t(e,r,n,i){if(r(e,i.key)<=0){var a;if(i.left&&(a=t(e,r,n,i.left)))return a;if(a=n(i.key,i.value))return a}if(i.right)return t(e,r,n,i.right)}(e,this._compare,t,this.root);case 3:if(this._compare(e,r)>=0)return;return function t(e,r,n,i,a){var o,s=n(e,a.key),l=n(r,a.key);if(s<=0){if(a.left&&(o=t(e,r,n,i,a.left)))return o;if(l>0&&(o=i(a.key,a.value)))return o}if(l>0&&a.right)return t(e,r,n,i,a.right)}(e,r,this._compare,t,this.root)}},Object.defineProperty(u,\"begin\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.left;return new h(this,t)}}),Object.defineProperty(u,\"end\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.right;return new h(this,t)}}),u.at=function(t){if(t<0)return new h(this,[]);for(var e=this.root,r=[];;){if(r.push(e),e.left){if(t<e.left._count){e=e.left;continue}t-=e.left._count}if(!t)return new h(this,r);if(t-=1,!e.right)break;if(t>=e.right._count)break;e=e.right}return new h(this,[])},u.ge=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<=0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},u.gt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},u.lt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},u.le=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>=0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},u.find=function(t){for(var e=this._compare,r=this.root,n=[];r;){var i=e(t,r.key);if(n.push(r),0===i)return new h(this,n);r=i<=0?r.left:r.right}return new h(this,[])},u.remove=function(t){var e=this.find(t);return e?e.remove():this},u.get=function(t){for(var e=this._compare,r=this.root;r;){var n=e(t,r.key);if(0===n)return r.value;r=n<=0?r.left:r.right}};var f=h.prototype;function p(t,e){t.key=e.key,t.value=e.value,t.left=e.left,t.right=e.right,t._color=e._color,t._count=e._count}function d(t,e){return t<e?-1:t>e?1:0}Object.defineProperty(f,\"valid\",{get:function(){return this._stack.length>0}}),Object.defineProperty(f,\"node\",{get:function(){return this._stack.length>0?this._stack[this._stack.length-1]:null},enumerable:!0}),f.clone=function(){return new h(this.tree,this._stack.slice())},f.remove=function(){var t=this._stack;if(0===t.length)return this.tree;var e=new Array(t.length),r=t[t.length-1];e[e.length-1]=new a(r._color,r.key,r.value,r.left,r.right,r._count);for(var u=t.length-2;u>=0;--u){(r=t[u]).left===t[u+1]?e[u]=new a(r._color,r.key,r.value,e[u+1],r.right,r._count):e[u]=new a(r._color,r.key,r.value,r.left,e[u+1],r._count)}if((r=e[e.length-1]).left&&r.right){var h=e.length;for(r=r.left;r.right;)e.push(r),r=r.right;var f=e[h-1];e.push(new a(r._color,f.key,f.value,r.left,r.right,r._count)),e[h-1].key=r.key,e[h-1].value=r.value;for(u=e.length-2;u>=h;--u)r=e[u],e[u]=new a(r._color,r.key,r.value,r.left,e[u+1],r._count);e[h-1].left=e[h]}if((r=e[e.length-1])._color===n){var d=e[e.length-2];d.left===r?d.left=null:d.right===r&&(d.right=null),e.pop();for(u=0;u<e.length;++u)e[u]._count--;return new c(this.tree._compare,e[0])}if(r.left||r.right){r.left?p(r,r.left):r.right&&p(r,r.right),r._color=i;for(u=0;u<e.length-1;++u)e[u]._count--;return new c(this.tree._compare,e[0])}if(1===e.length)return new c(this.tree._compare,null);for(u=0;u<e.length;++u)e[u]._count--;var g=e[e.length-2];return function(t){for(var e,r,a,c,u=t.length-1;u>=0;--u){if(e=t[u],0===u)return void(e._color=i);if((r=t[u-1]).left===e){if((a=r.right).right&&a.right._color===n)return c=(a=r.right=o(a)).right=o(a.right),r.right=a.left,a.left=r,a.right=c,a._color=r._color,e._color=i,r._color=i,c._color=i,l(r),l(a),u>1&&((h=t[u-2]).left===r?h.left=a:h.right=a),void(t[u-1]=a);if(a.left&&a.left._color===n)return c=(a=r.right=o(a)).left=o(a.left),r.right=c.left,a.left=c.right,c.left=r,c.right=a,c._color=r._color,r._color=i,a._color=i,e._color=i,l(r),l(a),l(c),u>1&&((h=t[u-2]).left===r?h.left=c:h.right=c),void(t[u-1]=c);if(a._color===i){if(r._color===n)return r._color=i,void(r.right=s(n,a));r.right=s(n,a);continue}a=o(a),r.right=a.left,a.left=r,a._color=r._color,r._color=n,l(r),l(a),u>1&&((h=t[u-2]).left===r?h.left=a:h.right=a),t[u-1]=a,t[u]=r,u+1<t.length?t[u+1]=e:t.push(e),u+=2}else{if((a=r.left).left&&a.left._color===n)return c=(a=r.left=o(a)).left=o(a.left),r.left=a.right,a.right=r,a.left=c,a._color=r._color,e._color=i,r._color=i,c._color=i,l(r),l(a),u>1&&((h=t[u-2]).right===r?h.right=a:h.left=a),void(t[u-1]=a);if(a.right&&a.right._color===n)return c=(a=r.left=o(a)).right=o(a.right),r.left=c.right,a.right=c.left,c.right=r,c.left=a,c._color=r._color,r._color=i,a._color=i,e._color=i,l(r),l(a),l(c),u>1&&((h=t[u-2]).right===r?h.right=c:h.left=c),void(t[u-1]=c);if(a._color===i){if(r._color===n)return r._color=i,void(r.left=s(n,a));r.left=s(n,a);continue}var h;a=o(a),r.left=a.right,a.right=r,a._color=r._color,r._color=n,l(r),l(a),u>1&&((h=t[u-2]).right===r?h.right=a:h.left=a),t[u-1]=a,t[u]=r,u+1<t.length?t[u+1]=e:t.push(e),u+=2}}}(e),g.left===r?g.left=null:g.right=null,new c(this.tree._compare,e[0])},Object.defineProperty(f,\"key\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].key},enumerable:!0}),Object.defineProperty(f,\"value\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].value},enumerable:!0}),Object.defineProperty(f,\"index\",{get:function(){var t=0,e=this._stack;if(0===e.length){var r=this.tree.root;return r?r._count:0}e[e.length-1].left&&(t=e[e.length-1].left._count);for(var n=e.length-2;n>=0;--n)e[n+1]===e[n].right&&(++t,e[n].left&&(t+=e[n].left._count));return t},enumerable:!0}),f.next=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.right)for(e=e.right;e;)t.push(e),e=e.left;else for(t.pop();t.length>0&&t[t.length-1].right===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(f,\"hasNext\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].right)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].left===t[e])return!0;return!1}}),f.update=function(t){var e=this._stack;if(0===e.length)throw new Error(\"Can't update empty node!\");var r=new Array(e.length),n=e[e.length-1];r[r.length-1]=new a(n._color,n.key,t,n.left,n.right,n._count);for(var i=e.length-2;i>=0;--i)(n=e[i]).left===e[i+1]?r[i]=new a(n._color,n.key,n.value,r[i+1],n.right,n._count):r[i]=new a(n._color,n.key,n.value,n.left,r[i+1],n._count);return new c(this.tree._compare,r[0])},f.prev=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.left)for(e=e.left;e;)t.push(e),e=e.right;else for(t.pop();t.length>0&&t[t.length-1].left===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(f,\"hasPrev\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].left)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].right===t[e])return!0;return!1}})},{}],231:[function(t,e,r){var n=[.9999999999998099,676.5203681218851,-1259.1392167224028,771.3234287776531,-176.6150291621406,12.507343278686905,-.13857109526572012,9984369578019572e-21,1.5056327351493116e-7],i=607/128,a=[.9999999999999971,57.15623566586292,-59.59796035547549,14.136097974741746,-.4919138160976202,3399464998481189e-20,4652362892704858e-20,-9837447530487956e-20,.0001580887032249125,-.00021026444172410488,.00021743961811521265,-.0001643181065367639,8441822398385275e-20,-26190838401581408e-21,36899182659531625e-22];function o(t){if(t<0)return Number(\"0/0\");for(var e=a[0],r=a.length-1;r>0;--r)e+=a[r]/(t+r);var n=t+i+.5;return.5*Math.log(2*Math.PI)+(t+.5)*Math.log(n)-n+Math.log(e)-Math.log(t)}e.exports=function t(e){if(e<.5)return Math.PI/(Math.sin(Math.PI*e)*t(1-e));if(e>100)return Math.exp(o(e));e-=1;for(var r=n[0],i=1;i<9;i++)r+=n[i]/(e+i);var a=e+7+.5;return Math.sqrt(2*Math.PI)*Math.pow(a,e+.5)*Math.exp(-a)*r},e.exports.log=o},{}],232:[function(t,e,r){e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"must specify type string\");if(e=e||{},\"undefined\"==typeof document&&!e.canvas)return null;var r=e.canvas||document.createElement(\"canvas\");\"number\"==typeof e.width&&(r.width=e.width);\"number\"==typeof e.height&&(r.height=e.height);var n,i=e;try{var a=[t];0===t.indexOf(\"webgl\")&&a.push(\"experimental-\"+t);for(var o=0;o<a.length;o++)if(n=r.getContext(a[o],i))return n}catch(t){n=null}return n||null}},{}],233:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=new u(t);return r.update(e),r};var n=t(\"./lib/text.js\"),i=t(\"./lib/lines.js\"),a=t(\"./lib/background.js\"),o=t(\"./lib/cube.js\"),s=t(\"./lib/ticks.js\"),l=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]);function c(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function u(t){this.gl=t,this.pixelRatio=1,this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.autoTicks=!0,this.tickSpacing=[1,1,1],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickAlign=[\"auto\",\"auto\",\"auto\"],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[10,10,10],this.lastCubeProps={cubeEdges:[0,0,0],axis:[0,0,0]},this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=\"sans-serif\",this.labelSize=[20,20,20],this.labelAngle=[0,0,0],this.labelAlign=[\"auto\",\"auto\",\"auto\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[10,10,10],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[0,0,0],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!1,!1,!1],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._firstInit=!0,this._text=null,this._lines=null,this._background=a(t)}var h=u.prototype;function f(){this.primalOffset=[0,0,0],this.primalMinor=[0,0,0],this.mirrorOffset=[0,0,0],this.mirrorMinor=[0,0,0]}h.update=function(t){function e(e,r,n){if(n in t){var i,a=t[n],o=this[n];(e?Array.isArray(a)&&Array.isArray(a[0]):Array.isArray(a))?this[n]=i=[r(a[0]),r(a[1]),r(a[2])]:this[n]=i=[r(a),r(a),r(a)];for(var s=0;s<3;++s)if(i[s]!==o[s])return!0}return!1}t=t||{};var r,a=e.bind(this,!1,Number),o=e.bind(this,!1,Boolean),l=e.bind(this,!1,String),c=e.bind(this,!0,function(t){if(Array.isArray(t)){if(3===t.length)return[+t[0],+t[1],+t[2],1];if(4===t.length)return[+t[0],+t[1],+t[2],+t[3]]}return[0,0,0,1]}),u=!1,h=!1;if(\"bounds\"in t)for(var f=t.bounds,p=0;p<2;++p)for(var d=0;d<3;++d)f[p][d]!==this.bounds[p][d]&&(h=!0),this.bounds[p][d]=f[p][d];if(\"ticks\"in t){r=t.ticks,u=!0,this.autoTicks=!1;for(p=0;p<3;++p)this.tickSpacing[p]=0}else a(\"tickSpacing\")&&(this.autoTicks=!0,h=!0);if(this._firstInit&&(\"ticks\"in t||\"tickSpacing\"in t||(this.autoTicks=!0),h=!0,u=!0,this._firstInit=!1),h&&this.autoTicks&&(r=s.create(this.bounds,this.tickSpacing),u=!0),u){for(p=0;p<3;++p)r[p].sort(function(t,e){return t.x-e.x});s.equal(r,this.ticks)?u=!1:this.ticks=r}o(\"tickEnable\"),l(\"tickFont\")&&(u=!0),a(\"tickSize\"),a(\"tickAngle\"),a(\"tickPad\"),c(\"tickColor\");var g=l(\"labels\");l(\"labelFont\")&&(g=!0),o(\"labelEnable\"),a(\"labelSize\"),a(\"labelPad\"),c(\"labelColor\"),o(\"lineEnable\"),o(\"lineMirror\"),a(\"lineWidth\"),c(\"lineColor\"),o(\"lineTickEnable\"),o(\"lineTickMirror\"),a(\"lineTickLength\"),a(\"lineTickWidth\"),c(\"lineTickColor\"),o(\"gridEnable\"),a(\"gridWidth\"),c(\"gridColor\"),o(\"zeroEnable\"),c(\"zeroLineColor\"),a(\"zeroLineWidth\"),o(\"backgroundEnable\"),c(\"backgroundColor\"),this._text?this._text&&(g||u)&&this._text.update(this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont):this._text=n(this.gl,this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont),this._lines&&u&&(this._lines.dispose(),this._lines=null),this._lines||(this._lines=i(this.gl,this.bounds,this.ticks))};var p=[new f,new f,new f];function d(t,e,r,n,i){for(var a=t.primalOffset,o=t.primalMinor,s=t.mirrorOffset,l=t.mirrorMinor,c=n[e],u=0;u<3;++u)if(e!==u){var h=a,f=s,p=o,d=l;c&1<<u&&(h=s,f=a,p=l,d=o),h[u]=r[0][u],f[u]=r[1][u],i[u]>0?(p[u]=-1,d[u]=0):(p[u]=0,d[u]=1)}}var g=[0,0,0],v={model:l,view:l,projection:l,_ortho:!1};h.isOpaque=function(){return!0},h.isTransparent=function(){return!1},h.drawTransparent=function(t){};var m=[0,0,0],y=[0,0,0],x=[0,0,0];h.draw=function(t){t=t||v;for(var e=this.gl,r=t.model||l,n=t.view||l,i=t.projection||l,a=this.bounds,s=t._ortho||!1,u=o(r,n,i,a,s),h=u.cubeEdges,f=u.axis,b=n[12],_=n[13],w=n[14],k=n[15],T=(s?2:1)*this.pixelRatio*(i[3]*b+i[7]*_+i[11]*w+i[15]*k)/e.drawingBufferHeight,A=0;A<3;++A)this.lastCubeProps.cubeEdges[A]=h[A],this.lastCubeProps.axis[A]=f[A];var M=p;for(A=0;A<3;++A)d(p[A],A,this.bounds,h,f);e=this.gl;var S,E=g;for(A=0;A<3;++A)this.backgroundEnable[A]?E[A]=f[A]:E[A]=0;this._background.draw(r,n,i,a,E,this.backgroundColor),this._lines.bind(r,n,i,this);for(A=0;A<3;++A){var C=[0,0,0];f[A]>0?C[A]=a[1][A]:C[A]=a[0][A];for(var L=0;L<2;++L){var P=(A+1+L)%3,O=(A+1+(1^L))%3;this.gridEnable[P]&&this._lines.drawGrid(P,O,this.bounds,C,this.gridColor[P],this.gridWidth[P]*this.pixelRatio)}for(L=0;L<2;++L){P=(A+1+L)%3,O=(A+1+(1^L))%3;this.zeroEnable[O]&&Math.min(a[0][O],a[1][O])<=0&&Math.max(a[0][O],a[1][O])>=0&&this._lines.drawZero(P,O,this.bounds,C,this.zeroLineColor[O],this.zeroLineWidth[O]*this.pixelRatio)}}for(A=0;A<3;++A){this.lineEnable[A]&&this._lines.drawAxisLine(A,this.bounds,M[A].primalOffset,this.lineColor[A],this.lineWidth[A]*this.pixelRatio),this.lineMirror[A]&&this._lines.drawAxisLine(A,this.bounds,M[A].mirrorOffset,this.lineColor[A],this.lineWidth[A]*this.pixelRatio);var z=c(m,M[A].primalMinor),I=c(y,M[A].mirrorMinor),D=this.lineTickLength;for(L=0;L<3;++L){var R=T/r[5*L];z[L]*=D[L]*R,I[L]*=D[L]*R}this.lineTickEnable[A]&&this._lines.drawAxisTicks(A,M[A].primalOffset,z,this.lineTickColor[A],this.lineTickWidth[A]*this.pixelRatio),this.lineTickMirror[A]&&this._lines.drawAxisTicks(A,M[A].mirrorOffset,I,this.lineTickColor[A],this.lineTickWidth[A]*this.pixelRatio)}this._lines.unbind(),this._text.bind(r,n,i,this.pixelRatio);var F,B;function N(t){(B=[0,0,0])[t]=1}function j(t,e,r){var n=(t+1)%3,i=(t+2)%3,a=e[n],o=e[i],s=r[n],l=r[i];a>0&&l>0?N(n):a>0&&l<0?N(n):a<0&&l>0?N(n):a<0&&l<0?N(n):o>0&&s>0?N(i):o>0&&s<0?N(i):o<0&&s>0?N(i):o<0&&s<0&&N(i)}for(A=0;A<3;++A){var U=M[A].primalMinor,V=M[A].mirrorMinor,q=c(x,M[A].primalOffset);for(L=0;L<3;++L)this.lineTickEnable[A]&&(q[L]+=T*U[L]*Math.max(this.lineTickLength[L],0)/r[5*L]);var H=[0,0,0];if(H[A]=1,this.tickEnable[A]){-3600===this.tickAngle[A]?(this.tickAngle[A]=0,this.tickAlign[A]=\"auto\"):this.tickAlign[A]=-1,F=1,\"auto\"===(S=[this.tickAlign[A],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]),B=[0,0,0],j(A,U,V);for(L=0;L<3;++L)q[L]+=T*U[L]*this.tickPad[L]/r[5*L];this._text.drawTicks(A,this.tickSize[A],this.tickAngle[A],q,this.tickColor[A],H,B,S)}if(this.labelEnable[A]){F=0,B=[0,0,0],this.labels[A].length>4&&(N(A),F=1),\"auto\"===(S=[this.labelAlign[A],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]);for(L=0;L<3;++L)q[L]+=T*U[L]*this.labelPad[L]/r[5*L];q[A]+=.5*(a[0][A]+a[1][A]),this._text.drawLabel(A,this.labelSize[A],this.labelAngle[A],q,this.labelColor[A],[0,0,0],B,S)}}this._text.unbind()},h.dispose=function(){this._text.dispose(),this._lines.dispose(),this._background.dispose(),this._lines=null,this._text=null,this._background=null,this.gl=null}},{\"./lib/background.js\":234,\"./lib/cube.js\":235,\"./lib/lines.js\":236,\"./lib/text.js\":238,\"./lib/ticks.js\":239}],234:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=[],r=[],s=0,l=0;l<3;++l)for(var c=(l+1)%3,u=(l+2)%3,h=[0,0,0],f=[0,0,0],p=-1;p<=1;p+=2){r.push(s,s+2,s+1,s+1,s+2,s+3),h[l]=p,f[l]=p;for(var d=-1;d<=1;d+=2){h[c]=d;for(var g=-1;g<=1;g+=2)h[u]=g,e.push(h[0],h[1],h[2],f[0],f[1],f[2]),s+=1}var v=c;c=u,u=v}var m=n(t,new Float32Array(e)),y=n(t,new Uint16Array(r),t.ELEMENT_ARRAY_BUFFER),x=i(t,[{buffer:m,type:t.FLOAT,size:3,offset:0,stride:24},{buffer:m,type:t.FLOAT,size:3,offset:12,stride:24}],y),b=a(t);return b.attributes.position.location=0,b.attributes.normal.location=1,new o(t,m,x,b)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").bg;function o(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n}var s=o.prototype;s.draw=function(t,e,r,n,i,a){for(var o=!1,s=0;s<3;++s)o=o||i[s];if(o){var l=this.gl;l.enable(l.POLYGON_OFFSET_FILL),l.polygonOffset(1,2),this.shader.bind(),this.shader.uniforms={model:t,view:e,projection:r,bounds:n,enable:i,colors:a},this.vao.bind(),this.vao.draw(this.gl.TRIANGLES,36),this.vao.unbind(),l.disable(l.POLYGON_OFFSET_FILL)}},s.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders\":237,\"gl-buffer\":241,\"gl-vao\":327}],235:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,p){i(s,e,t),i(s,r,s);for(var y=0,x=0;x<2;++x){u[2]=a[x][2];for(var b=0;b<2;++b){u[1]=a[b][1];for(var _=0;_<2;++_)u[0]=a[_][0],f(l[y],u,s),y+=1}}for(var w=-1,x=0;x<8;++x){for(var k=l[x][3],T=0;T<3;++T)c[x][T]=l[x][T]/k;p&&(c[x][2]*=-1),k<0&&(w<0?w=x:c[x][2]<c[w][2]&&(w=x))}if(w<0){w=0;for(var A=0;A<3;++A){for(var M=(A+2)%3,S=(A+1)%3,E=-1,C=-1,L=0;L<2;++L){var P=L<<A,O=P+(L<<M)+(1-L<<S),z=P+(1-L<<M)+(L<<S);o(c[P],c[O],c[z],h)<0||(L?E=1:C=1)}if(E<0||C<0)C>E&&(w|=1<<A);else{for(var L=0;L<2;++L){var P=L<<A,O=P+(L<<M)+(1-L<<S),z=P+(1-L<<M)+(L<<S),I=d([l[P],l[O],l[z],l[P+(1<<M)+(1<<S)]]);L?E=I:C=I}C>E&&(w|=1<<A)}}}for(var D=7^w,R=-1,x=0;x<8;++x)x!==w&&x!==D&&(R<0?R=x:c[R][1]>c[x][1]&&(R=x));for(var F=-1,x=0;x<3;++x){var B=R^1<<x;if(B!==w&&B!==D){F<0&&(F=B);var S=c[B];S[0]<c[F][0]&&(F=B)}}for(var N=-1,x=0;x<3;++x){var B=R^1<<x;if(B!==w&&B!==D&&B!==F){N<0&&(N=B);var S=c[B];S[0]>c[N][0]&&(N=B)}}var j=g;j[0]=j[1]=j[2]=0,j[n.log2(F^R)]=R&F,j[n.log2(R^N)]=R&N;var U=7^N;U===w||U===D?(U=7^F,j[n.log2(N^U)]=U&N):j[n.log2(F^U)]=U&F;for(var V=v,q=w,A=0;A<3;++A)V[A]=q&1<<A?-1:1;return m};var n=t(\"bit-twiddle\"),i=t(\"gl-mat4/multiply\"),a=t(\"split-polygon\"),o=t(\"robust-orientation\"),s=new Array(16),l=new Array(8),c=new Array(8),u=new Array(3),h=[0,0,0];function f(t,e,r){for(var n=0;n<4;++n){t[n]=r[12+n];for(var i=0;i<3;++i)t[n]+=e[i]*r[4*i+n]}}!function(){for(var t=0;t<8;++t)l[t]=[1,1,1,1],c[t]=[1,1,1]}();var p=[[0,0,1,0,0],[0,0,-1,1,0],[0,-1,0,1,0],[0,1,0,1,0],[-1,0,0,1,0],[1,0,0,1,0]];function d(t){for(var e=0;e<p.length;++e)if((t=a.positive(t,p[e])).length<3)return 0;var r=t[0],n=r[0]/r[3],i=r[1]/r[3],o=0;for(e=1;e+1<t.length;++e){var s=t[e],l=t[e+1],c=s[0]/s[3]-n,u=s[1]/s[3]-i,h=l[0]/l[3]-n,f=l[1]/l[3]-i;o+=Math.abs(c*f-u*h)}return o}var g=[1,1,1],v=[0,0,0],m={cubeEdges:g,axis:v}},{\"bit-twiddle\":92,\"gl-mat4/multiply\":267,\"robust-orientation\":510,\"split-polygon\":527}],236:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var o=[],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[0,0,0];o.push(0,0,1,0,1,1,0,0,-1,0,0,-1,0,1,1,0,1,-1);for(var h=0;h<3;++h){for(var f=o.length/3|0,d=0;d<r[h].length;++d){var g=+r[h][d].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var v=o.length/3|0;s[h]=f,l[h]=v-f;for(var f=o.length/3|0,m=0;m<r[h].length;++m){var g=+r[h][m].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var v=o.length/3|0;c[h]=f,u[h]=v-f}var y=n(t,new Float32Array(o)),x=i(t,[{buffer:y,type:t.FLOAT,size:3,stride:0,offset:0}]),b=a(t);return b.attributes.position.location=0,new p(t,y,x,b,l,s,u,c)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").line,o=[0,0,0],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[1,1];function h(t){return t[0]=t[1]=t[2]=0,t}function f(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function p(t,e,r,n,i,a,o,s){this.gl=t,this.vertBuffer=e,this.vao=r,this.shader=n,this.tickCount=i,this.tickOffset=a,this.gridCount=o,this.gridOffset=s}var d=p.prototype;d.bind=function(t,e,r){this.shader.bind(),this.shader.uniforms.model=t,this.shader.uniforms.view=e,this.shader.uniforms.projection=r,u[0]=this.gl.drawingBufferWidth,u[1]=this.gl.drawingBufferHeight,this.shader.uniforms.screenShape=u,this.vao.bind()},d.unbind=function(){this.vao.unbind()},d.drawAxisLine=function(t,e,r,n,i){var a=h(s);this.shader.uniforms.majorAxis=s,a[t]=e[1][t]-e[0][t],this.shader.uniforms.minorAxis=a;var o,u=f(c,r);u[t]+=e[0][t],this.shader.uniforms.offset=u,this.shader.uniforms.lineWidth=i,this.shader.uniforms.color=n,(o=h(l))[(t+2)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6),(o=h(l))[(t+1)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6)},d.drawAxisTicks=function(t,e,r,n,i){if(this.tickCount[t]){var a=h(o);a[t]=1,this.shader.uniforms.majorAxis=a,this.shader.uniforms.offset=e,this.shader.uniforms.minorAxis=r,this.shader.uniforms.color=n,this.shader.uniforms.lineWidth=i;var s=h(l);s[t]=1,this.shader.uniforms.screenAxis=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t])}},d.drawGrid=function(t,e,r,n,i,a){if(this.gridCount[t]){var u=h(s);u[e]=r[1][e]-r[0][e],this.shader.uniforms.minorAxis=u;var p=f(c,n);p[e]+=r[0][e],this.shader.uniforms.offset=p;var d=h(o);d[t]=1,this.shader.uniforms.majorAxis=d;var g=h(l);g[t]=1,this.shader.uniforms.screenAxis=g,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,this.gridCount[t],this.gridOffset[t])}},d.drawZero=function(t,e,r,n,i,a){var o=h(s);this.shader.uniforms.majorAxis=o,o[t]=r[1][t]-r[0][t],this.shader.uniforms.minorAxis=o;var u=f(c,n);u[t]+=r[0][t],this.shader.uniforms.offset=u;var p=h(l);p[e]=1,this.shader.uniforms.screenAxis=p,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,6)},d.dispose=function(){this.vao.dispose(),this.vertBuffer.dispose(),this.shader.dispose()}},{\"./shaders\":237,\"gl-buffer\":241,\"gl-vao\":327}],237:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, majorAxis, minorAxis, screenAxis;\\nuniform float lineWidth;\\nuniform vec2 screenShape;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nvoid main() {\\n  vec3 major = position.x * majorAxis;\\n  vec3 minor = position.y * minorAxis;\\n\\n  vec3 vPosition = major + minor + offset;\\n  vec3 pPosition = project(vPosition);\\n  vec3 offset = project(vPosition + screenAxis * position.z);\\n\\n  vec2 screen = normalize((offset - pPosition).xy * screenShape) / screenShape;\\n\\n  gl_Position = vec4(pPosition + vec3(0.5 * screen * lineWidth, 0), 1.0);\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.line=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"}])};var s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, axis, alignDir, alignOpt;\\nuniform float scale, angle, pixelScale;\\nuniform vec2 resolution;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nfloat computeViewAngle(vec3 a, vec3 b) {\\n  vec3 A = project(a);\\n  vec3 B = project(b);\\n\\n  return atan(\\n    (B.y - A.y) * resolution.y,\\n    (B.x - A.x) * resolution.x\\n  );\\n}\\n\\nconst float PI = 3.141592;\\nconst float TWO_PI = 2.0 * PI;\\nconst float HALF_PI = 0.5 * PI;\\nconst float ONE_AND_HALF_PI = 1.5 * PI;\\n\\nint option = int(floor(alignOpt.x + 0.001));\\nfloat hv_ratio =       alignOpt.y;\\nbool enableAlign =    (alignOpt.z != 0.0);\\n\\nfloat mod_angle(float a) {\\n  return mod(a, PI);\\n}\\n\\nfloat positive_angle(float a) {\\n  return mod_angle((a < 0.0) ?\\n    a + TWO_PI :\\n    a\\n  );\\n}\\n\\nfloat look_upwards(float a) {\\n  float b = positive_angle(a);\\n  return ((b > HALF_PI) && (b <= ONE_AND_HALF_PI)) ?\\n    b - PI :\\n    b;\\n}\\n\\nfloat look_horizontal_or_vertical(float a, float ratio) {\\n  // ratio controls the ratio between being horizontal to (vertical + horizontal)\\n  // if ratio is set to 0.5 then it is 50%, 50%.\\n  // when using a higher ratio e.g. 0.75 the result would\\n  // likely be more horizontal than vertical.\\n\\n  float b = positive_angle(a);\\n\\n  return\\n    (b < (      ratio) * HALF_PI) ? 0.0 :\\n    (b < (2.0 - ratio) * HALF_PI) ? -HALF_PI :\\n    (b < (2.0 + ratio) * HALF_PI) ? 0.0 :\\n    (b < (4.0 - ratio) * HALF_PI) ? HALF_PI :\\n                                    0.0;\\n}\\n\\nfloat roundTo(float a, float b) {\\n  return float(b * floor((a + 0.5 * b) / b));\\n}\\n\\nfloat look_round_n_directions(float a, int n) {\\n  float b = positive_angle(a);\\n  float div = TWO_PI / float(n);\\n  float c = roundTo(b, div);\\n  return look_upwards(c);\\n}\\n\\nfloat applyAlignOption(float rawAngle, float delta) {\\n  return\\n    (option >  2) ? look_round_n_directions(rawAngle + delta, option) :       // option 3-n: round to n directions\\n    (option == 2) ? look_horizontal_or_vertical(rawAngle + delta, hv_ratio) : // horizontal or vertical\\n    (option == 1) ? rawAngle + delta :       // use free angle, and flip to align with one direction of the axis\\n    (option == 0) ? look_upwards(rawAngle) : // use free angle, and stay upwards\\n    (option ==-1) ? 0.0 :                    // useful for backward compatibility, all texts remains horizontal\\n                    rawAngle;                // otherwise return back raw input angle\\n}\\n\\nbool isAxisTitle = (axis.x == 0.0) &&\\n                   (axis.y == 0.0) &&\\n                   (axis.z == 0.0);\\n\\nvoid main() {\\n  //Compute world offset\\n  float axisDistance = position.z;\\n  vec3 dataPosition = axisDistance * axis + offset;\\n\\n  float beta = angle; // i.e. user defined attributes for each tick\\n\\n  float axisAngle;\\n  float clipAngle;\\n  float flip;\\n\\n  if (enableAlign) {\\n    axisAngle = (isAxisTitle) ? HALF_PI :\\n                      computeViewAngle(dataPosition, dataPosition + axis);\\n    clipAngle = computeViewAngle(dataPosition, dataPosition + alignDir);\\n\\n    axisAngle += (sin(axisAngle) < 0.0) ? PI : 0.0;\\n    clipAngle += (sin(clipAngle) < 0.0) ? PI : 0.0;\\n\\n    flip = (dot(vec2(cos(axisAngle), sin(axisAngle)),\\n                vec2(sin(clipAngle),-cos(clipAngle))) > 0.0) ? 1.0 : 0.0;\\n\\n    beta += applyAlignOption(clipAngle, flip * PI);\\n  }\\n\\n  //Compute plane offset\\n  vec2 planeCoord = position.xy * pixelScale;\\n\\n  mat2 planeXform = scale * mat2(\\n     cos(beta), sin(beta),\\n    -sin(beta), cos(beta)\\n  );\\n\\n  vec2 viewOffset = 2.0 * planeXform * planeCoord / resolution;\\n\\n  //Compute clip position\\n  vec3 clipPosition = project(dataPosition);\\n\\n  //Apply text offset in clip coordinates\\n  clipPosition += vec3(viewOffset, 0.0);\\n\\n  //Done\\n  gl_Position = vec4(clipPosition, 1.0);\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.text=function(t){return i(t,s,l,null,[{name:\"position\",type:\"vec3\"}])};var c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec3 normal;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 enable;\\nuniform vec3 bounds[2];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n\\n  vec3 signAxis = sign(bounds[1] - bounds[0]);\\n\\n  vec3 realNormal = signAxis * normal;\\n\\n  if(dot(realNormal, enable) > 0.0) {\\n    vec3 minRange = min(bounds[0], bounds[1]);\\n    vec3 maxRange = max(bounds[0], bounds[1]);\\n    vec3 nPosition = mix(minRange, maxRange, 0.5 * (position + 1.0));\\n    gl_Position = projection * view * model * vec4(nPosition, 1.0);\\n  } else {\\n    gl_Position = vec4(0,0,0,0);\\n  }\\n\\n  colorChannel = abs(realNormal);\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 colors[3];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n  gl_FragColor = colorChannel.x * colors[0] +\\n                 colorChannel.y * colors[1] +\\n                 colorChannel.z * colors[2];\\n}\"]);r.bg=function(t){return i(t,c,u,null,[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}])}},{\"gl-shader\":301,glslify:409}],238:[function(t,e,r){(function(r){\"use strict\";e.exports=function(t,e,r,a,s,l){var u=n(t),h=i(t,[{buffer:u,size:3}]),f=o(t);f.attributes.position.location=0;var p=new c(t,f,u,h);return p.update(e,r,a,s,l),p};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"vectorize-text\"),o=t(\"./shaders\").text,s=window||r.global||{},l=s.__TEXT_CACHE||{};s.__TEXT_CACHE={};function c(t,e,r,n){this.gl=t,this.shader=e,this.buffer=r,this.vao=n,this.tickOffset=this.tickCount=this.labelOffset=this.labelCount=null}var u=c.prototype,h=[0,0];u.bind=function(t,e,r,n){this.vao.bind(),this.shader.bind();var i=this.shader.uniforms;i.model=t,i.view=e,i.projection=r,i.pixelScale=n,h[0]=this.gl.drawingBufferWidth,h[1]=this.gl.drawingBufferHeight,this.shader.uniforms.resolution=h},u.unbind=function(){this.vao.unbind()},u.update=function(t,e,r,n,i){var o=[];function s(t,e,r,n,i,s){var c=l[r];c||(c=l[r]={});var u=c[e];u||(u=c[e]=function(t,e){try{return a(t,e)}catch(e){return console.warn('error vectorizing text:\"'+t+'\" error:',e),{cells:[],positions:[]}}}(e,{triangles:!0,font:r,textAlign:\"center\",textBaseline:\"middle\",lineSpacing:i,styletags:s}));for(var h=(n||12)/12,f=u.positions,p=u.cells,d=0,g=p.length;d<g;++d)for(var v=p[d],m=2;m>=0;--m){var y=f[v[m]];o.push(h*y[0],-h*y[1],t)}}for(var c=[0,0,0],u=[0,0,0],h=[0,0,0],f=[0,0,0],p={breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},d=0;d<3;++d){h[d]=o.length/3|0,s(.5*(t[0][d]+t[1][d]),e[d],r[d],12,1.25,p),f[d]=(o.length/3|0)-h[d],c[d]=o.length/3|0;for(var g=0;g<n[d].length;++g)n[d][g].text&&s(n[d][g].x,n[d][g].text,n[d][g].font||i,n[d][g].fontSize||12,1.25,p);u[d]=(o.length/3|0)-c[d]}this.buffer.update(o),this.tickOffset=c,this.tickCount=u,this.labelOffset=h,this.labelCount=f},u.drawTicks=function(t,e,r,n,i,a,o,s){this.tickCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t]))},u.drawLabel=function(t,e,r,n,i,a,o,s){this.labelCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.labelCount[t],this.labelOffset[t]))},u.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()}}).call(this,t(\"_process\"))},{\"./shaders\":237,_process:482,\"gl-buffer\":241,\"gl-vao\":327,\"vectorize-text\":550}],239:[function(t,e,r){\"use strict\";function n(t,e){var r=t+\"\",n=r.indexOf(\".\"),i=0;n>=0&&(i=r.length-n-1);var a=Math.pow(10,i),o=Math.round(t*e*a),s=o+\"\";if(s.indexOf(\"e\")>=0)return s;var l=o/a,c=o%a;o<0?(l=0|-Math.ceil(l),c=0|-c):(l=0|Math.floor(l),c|=0);var u=\"\"+l;if(o<0&&(u=\"-\"+u),i){for(var h=\"\"+c;h.length<i;)h=\"0\"+h;return u+\".\"+h}return u}r.create=function(t,e){for(var r=[],i=0;i<3;++i){for(var a=[],o=(t[0][i],t[1][i],0);o*e[i]<=t[1][i];++o)a.push({x:o*e[i],text:n(e[i],o)});for(var o=-1;o*e[i]>=t[0][i];--o)a.push({x:o*e[i],text:n(e[i],o)});r.push(a)}return r},r.equal=function(t,e){for(var r=0;r<3;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;++n){var i=t[r][n],a=e[r][n];if(i.x!==a.x||i.text!==a.text||i.font!==a.font||i.fontColor!==a.fontColor||i.fontSize!==a.fontSize||i.dx!==a.dx||i.dy!==a.dy)return!1}}return!0}},{}],240:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,l,h){var f=e.model||c,p=e.view||c,m=e.projection||c,y=e._ortho||!1,x=t.bounds,b=(h=h||a(f,p,m,x,y)).axis;o(u,p,f),o(u,m,u);for(var _=g,w=0;w<3;++w)_[w].lo=1/0,_[w].hi=-1/0,_[w].pixelsPerDataUnit=1/0;var k=n(s(u,u));s(u,u);for(var T=0;T<3;++T){var A=(T+1)%3,M=(T+2)%3,S=v;t:for(var w=0;w<2;++w){var E=[];if(b[T]<0!=!!w){S[T]=x[w][T];for(var C=0;C<2;++C){S[A]=x[C^w][A];for(var L=0;L<2;++L)S[M]=x[L^C^w][M],E.push(S.slice())}for(var P=y?5:4,C=P;C===P;++C){if(0===E.length)continue t;E=i.positive(E,k[C])}for(var C=0;C<E.length;++C)for(var M=E[C],O=d(v,u,M,r,l),L=0;L<3;++L)_[L].lo=Math.min(_[L].lo,M[L]),_[L].hi=Math.max(_[L].hi,M[L]),L!==T&&(_[L].pixelsPerDataUnit=Math.min(_[L].pixelsPerDataUnit,Math.abs(O[L])))}}}return _};var n=t(\"extract-frustum-planes\"),i=t(\"split-polygon\"),a=t(\"./lib/cube.js\"),o=t(\"gl-mat4/multiply\"),s=t(\"gl-mat4/transpose\"),l=t(\"gl-vec4/transformMat4\"),c=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]),u=new Float32Array(16);function h(t,e,r){this.lo=t,this.hi=e,this.pixelsPerDataUnit=r}var f=[0,0,0,1],p=[0,0,0,1];function d(t,e,r,n,i){for(var a=0;a<3;++a){for(var o=f,s=p,c=0;c<3;++c)s[c]=o[c]=r[c];s[3]=o[3]=1,s[a]+=1,l(s,s,e),s[3]<0&&(t[a]=1/0),o[a]-=1,l(o,o,e),o[3]<0&&(t[a]=1/0);var u=(o[0]/o[3]-s[0]/s[3])*n,h=(o[1]/o[3]-s[1]/s[3])*i;t[a]=.25*Math.sqrt(u*u+h*h)}return t}var g=[new h(1/0,-1/0,1/0),new h(1/0,-1/0,1/0),new h(1/0,-1/0,1/0)],v=[0,0,0]},{\"./lib/cube.js\":235,\"extract-frustum-planes\":224,\"gl-mat4/multiply\":267,\"gl-mat4/transpose\":276,\"gl-vec4/transformMat4\":398,\"split-polygon\":527}],241:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"ndarray-ops\"),a=t(\"ndarray\"),o=[\"uint8\",\"uint8_clamped\",\"uint16\",\"uint32\",\"int8\",\"int16\",\"int32\",\"float32\"];function s(t,e,r,n,i){this.gl=t,this.type=e,this.handle=r,this.length=n,this.usage=i}var l=s.prototype;function c(t,e,r,n,i,a){var o=i.length*i.BYTES_PER_ELEMENT;if(a<0)return t.bufferData(e,i,n),o;if(o+a>r)throw new Error(\"gl-buffer: If resizing buffer, must not specify offset\");return t.bufferSubData(e,a,i),r}function u(t,e){for(var r=n.malloc(t.length,e),i=t.length,a=0;a<i;++a)r[a]=t[a];return r}l.bind=function(){this.gl.bindBuffer(this.type,this.handle)},l.unbind=function(){this.gl.bindBuffer(this.type,null)},l.dispose=function(){this.gl.deleteBuffer(this.handle)},l.update=function(t,e){if(\"number\"!=typeof e&&(e=-1),this.bind(),\"object\"==typeof t&&\"undefined\"!=typeof t.shape){var r=t.dtype;if(o.indexOf(r)<0&&(r=\"float32\"),this.type===this.gl.ELEMENT_ARRAY_BUFFER)r=gl.getExtension(\"OES_element_index_uint\")&&\"uint16\"!==r?\"uint32\":\"uint16\";if(r===t.dtype&&function(t,e){for(var r=1,n=e.length-1;n>=0;--n){if(e[n]!==r)return!1;r*=t[n]}return!0}(t.shape,t.stride))0===t.offset&&t.data.length===t.shape[0]?this.length=c(this.gl,this.type,this.length,this.usage,t.data,e):this.length=c(this.gl,this.type,this.length,this.usage,t.data.subarray(t.offset,t.shape[0]),e);else{var s=n.malloc(t.size,r),l=a(s,t.shape);i.assign(l,t),this.length=c(this.gl,this.type,this.length,this.usage,e<0?s:s.subarray(0,t.size),e),n.free(s)}}else if(Array.isArray(t)){var h;h=this.type===this.gl.ELEMENT_ARRAY_BUFFER?u(t,\"uint16\"):u(t,\"float32\"),this.length=c(this.gl,this.type,this.length,this.usage,e<0?h:h.subarray(0,t.length),e),n.free(h)}else if(\"object\"==typeof t&&\"number\"==typeof t.length)this.length=c(this.gl,this.type,this.length,this.usage,t,e);else{if(\"number\"!=typeof t&&void 0!==t)throw new Error(\"gl-buffer: Invalid data type\");if(e>=0)throw new Error(\"gl-buffer: Cannot specify offset when resizing buffer\");(t|=0)<=0&&(t=1),this.gl.bufferData(this.type,0|t,this.usage),this.length=t}},e.exports=function(t,e,r,n){if(r=r||t.ARRAY_BUFFER,n=n||t.DYNAMIC_DRAW,r!==t.ARRAY_BUFFER&&r!==t.ELEMENT_ARRAY_BUFFER)throw new Error(\"gl-buffer: Invalid type for webgl buffer, must be either gl.ARRAY_BUFFER or gl.ELEMENT_ARRAY_BUFFER\");if(n!==t.DYNAMIC_DRAW&&n!==t.STATIC_DRAW&&n!==t.STREAM_DRAW)throw new Error(\"gl-buffer: Invalid usage for buffer, must be either gl.DYNAMIC_DRAW, gl.STATIC_DRAW or gl.STREAM_DRAW\");var i=t.createBuffer(),a=new s(t,r,i,0,n);return a.update(e),a}},{ndarray:450,\"ndarray-ops\":444,\"typedarray-pool\":545}],242:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\"),i=function(t,e){for(var r=0;r<t.length;r++)if(t[r]>=e)return r-1;return r},a=n.create(),o=n.create(),s=function(t,e,r){return t<e?e:t>r?r:t},l=function(t,e,r,l){var c=t[0],u=t[1],h=t[2],f=r[0].length,p=r[1].length,d=r[2].length,g=i(r[0],c),v=i(r[1],u),m=i(r[2],h),y=g+1,x=v+1,b=m+1;if(l&&(g=s(g,0,f-1),y=s(y,0,f-1),v=s(v,0,p-1),x=s(x,0,p-1),m=s(m,0,d-1),b=s(b,0,d-1)),g<0||v<0||m<0||y>=f||x>=p||b>=d)return n.create();var _=(c-r[0][g])/(r[0][y]-r[0][g]),w=(u-r[1][v])/(r[1][x]-r[1][v]),k=(h-r[2][m])/(r[2][b]-r[2][m]);(_<0||_>1||isNaN(_))&&(_=0),(w<0||w>1||isNaN(w))&&(w=0),(k<0||k>1||isNaN(k))&&(k=0);var T=m*f*p,A=b*f*p,M=v*f,S=x*f,E=g,C=y,L=e[M+T+E],P=e[M+T+C],O=e[S+T+E],z=e[S+T+C],I=e[M+A+E],D=e[M+A+C],R=e[S+A+E],F=e[S+A+C],B=n.create();return n.lerp(B,L,P,_),n.lerp(a,O,z,_),n.lerp(B,B,a,w),n.lerp(a,I,D,_),n.lerp(o,R,F,_),n.lerp(a,a,o,w),n.lerp(B,B,a,k),B};e.exports=function(t,e){var r;r=t.positions?t.positions:function(t){for(var e=t[0],r=t[1],n=t[2],i=[],a=0;a<n.length;a++)for(var o=0;o<r.length;o++)for(var s=0;s<e.length;s++)i.push([n[a],r[o],e[s]]);return i}(t.meshgrid);var i=t.meshgrid,a=t.vectors,o={positions:[],vertexIntensity:[],vertexIntensityBounds:t.vertexIntensityBounds,vertexNormals:[],vectors:[],cells:[],coneOffset:t.coneOffset,colormap:t.colormap};if(0===t.positions.length)return e&&(e[0]=[0,0,0],e[1]=[0,0,0]),o;for(var s=0,c=1/0,u=-1/0,h=1/0,f=-1/0,p=1/0,d=-1/0,g=null,v=null,m=[],y=1/0,x=0;x<r.length;x++){var b,_=r[x];c=Math.min(_[0],c),u=Math.max(_[0],u),h=Math.min(_[1],h),f=Math.max(_[1],f),p=Math.min(_[2],p),d=Math.max(_[2],d),b=i?l(_,a,i,!0):a[x],n.length(b)>s&&(s=n.length(b)),x&&(y=Math.min(y,2*n.distance(g,_)/(n.length(v)+n.length(b)))),g=_,v=b,m.push(b)}var w=[c,h,p],k=[u,f,d];e&&(e[0]=w,e[1]=k),0===s&&(s=1);var T=1/s;isFinite(y)&&!isNaN(y)||(y=1),o.vectorScale=y;var A=function(t,e,r){var i=n.create();return void 0!==t&&n.set(i,t,e,r),i}(0,1,0),M=t.coneSize||.5;t.absoluteConeSize&&(M=t.absoluteConeSize*T),o.coneScale=M;x=0;for(var S=0;x<r.length;x++)for(var E=(_=r[x])[0],C=_[1],L=_[2],P=m[x],O=n.length(P)*T,z=0;z<8;z++){o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vertexIntensity.push(O,O,O),o.vertexIntensity.push(O,O,O),o.vertexNormals.push(A,A,A),o.vertexNormals.push(A,A,A);var I=o.positions.length;o.cells.push([I-6,I-5,I-4],[I-3,I-2,I-1])}return o},e.exports.createConeMesh=t(\"./lib/conemesh\")},{\"./lib/conemesh\":243,\"gl-vec3\":346}],243:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./shaders\"),g=d.meshShader,v=d.pickShader,m=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function y(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,y,x,b,_,w,k,T){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=i,this.triangleVectors=a,this.triangleColors=s,this.triangleNormals=c,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=u,this.triangleCount=0,this.lineWidth=1,this.edgePositions=h,this.edgeColors=p,this.edgeUVs=d,this.edgeIds=f,this.edgeVAO=g,this.edgeCount=0,this.pointPositions=v,this.pointColors=x,this.pointUVs=b,this.pointSizes=_,this.pointIds=y,this.pointVAO=w,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=k,this.contourVAO=T,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.coneScale=2,this.vectorScale=1,this.coneOffset=.25,this._model=m,this._view=m,this._projection=m,this._resolution=[1,1]}var x=y.prototype;function b(t){var e=n(t,v.vertex,v.fragment,null,v.attributes);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.vector.location=5,e}x.isOpaque=function(){return this.opacity>=1},x.isTransparent=function(){return this.opacity<1},x.pickSlots=1,x.setPickBase=function(t){this.pickId=t},x.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=i[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},x.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),void 0!==t.vectorScale&&(this.vectorScale=t.vectorScale),void 0!==t.coneScale&&(this.coneScale=t.coneScale),void 0!==t.coneOffset&&(this.coneOffset=t.coneOffset),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=h({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return u(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,i=t.vectors;if(n&&r&&i){var a=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[],w=[],k=[];this.cells=r,this.positions=n;var T=t.vertexNormals,A=t.cellNormals,M=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,S=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!A&&(A=s.faceNormals(r,n,S)),A||T||(T=s.vertexNormals(r,n,M));var E=t.vertexColors,C=t.cellColors,L=t.meshColor||[1,1,1,1],P=t.vertexUVs,O=t.vertexIntensity,z=t.cellUVs,I=t.cellIntensity,D=1/0,R=-1/0;if(!P&&!z)if(O)if(t.vertexIntensityBounds)D=+t.vertexIntensityBounds[0],R=+t.vertexIntensityBounds[1];else for(var F=0;F<O.length;++F){var B=O[F];D=Math.min(D,B),R=Math.max(R,B)}else if(I)for(F=0;F<I.length;++F){B=I[F];D=Math.min(D,B),R=Math.max(R,B)}else for(F=0;F<n.length;++F){B=n[F][2];D=Math.min(D,B),R=Math.max(R,B)}this.intensity=O||(I?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,I):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var N=t.pointSizes,j=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(F=0;F<n.length;++F)for(var U=n[F],V=0;V<3;++V)!isNaN(U[V])&&isFinite(U[V])&&(this.bounds[0][V]=Math.min(this.bounds[0][V],U[V]),this.bounds[1][V]=Math.max(this.bounds[1][V],U[V]));var q=0,H=0,G=0;t:for(F=0;F<r.length;++F){var Y=r[F];switch(Y.length){case 1:for(U=n[X=Y[0]],V=0;V<3;++V)if(isNaN(U[V])||!isFinite(U[V]))continue t;x.push(U[0],U[1],U[2],U[3]),3===(Z=E?E[X]:C?C[F]:L).length?b.push(Z[0],Z[1],Z[2],1):b.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],_.push(J[0],J[1]),N?w.push(N[X]):w.push(j),k.push(F),G+=1;break;case 2:for(V=0;V<2;++V){U=n[X=Y[V]];for(var W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t}for(V=0;V<2;++V){U=n[X=Y[V]];g.push(U[0],U[1],U[2]),3===(Z=E?E[X]:C?C[F]:L).length?v.push(Z[0],Z[1],Z[2],1):v.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],m.push(J[0],J[1]),y.push(F)}H+=1;break;case 3:for(V=0;V<3;++V)for(U=n[X=Y[V]],W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t;for(V=0;V<3;++V){var X;U=n[X=Y[2-V]];a.push(U[0],U[1],U[2],U[3]);var Z,J,K,$=i[X];l.push($[0],$[1],$[2]),3===(Z=E?E[X]:C?C[F]:L).length?c.push(Z[0],Z[1],Z[2],1):c.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],p.push(J[0],J[1]),K=T?T[X]:A[F],f.push(K[0],K[1],K[2]),d.push(F)}q+=1}}this.pointCount=G,this.edgeCount=H,this.triangleCount=q,this.pointPositions.update(x),this.pointColors.update(b),this.pointUVs.update(_),this.pointSizes.update(w),this.pointIds.update(new Uint32Array(k)),this.edgePositions.update(g),this.edgeColors.update(v),this.edgeUVs.update(m),this.edgeIds.update(new Uint32Array(y)),this.trianglePositions.update(a),this.triangleVectors.update(l),this.triangleColors.update(c),this.triangleUVs.update(p),this.triangleNormals.update(f),this.triangleIds.update(new Uint32Array(d))}},x.drawTransparent=x.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:m.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var f=u[12+o],p=0;p<3;++p)f+=u[4*p+o]*this.lightPosition[p];s.lightPosition[o]=f/h}if(this.triangleCount>0){var d=this.triShader;d.bind(),d.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},x.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:i,clipBounds:a,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind())},x.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3);return{index:Math.floor(r[1]/48),position:n,dataCoordinate:n}},x.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose()},e.exports=function(t,e){1===arguments.length&&(t=(e=t).gl);var r=e.triShader||function(t){var e=n(t,g.vertex,g.fragment,null,g.attributes);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.vector.location=5,e}(t),s=b(t),l=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));l.generateMipmap(),l.minFilter=t.LINEAR_MIPMAP_LINEAR,l.magFilter=t.LINEAR;var c=i(t),h=i(t),f=i(t),p=i(t),d=i(t),v=i(t),m=a(t,[{buffer:c,type:t.FLOAT,size:4},{buffer:v,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:f,type:t.FLOAT,size:4},{buffer:p,type:t.FLOAT,size:2},{buffer:d,type:t.FLOAT,size:3},{buffer:h,type:t.FLOAT,size:3}]),x=i(t),_=i(t),w=i(t),k=i(t),T=a(t,[{buffer:x,type:t.FLOAT,size:3},{buffer:k,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:_,type:t.FLOAT,size:4},{buffer:w,type:t.FLOAT,size:2}]),A=i(t),M=i(t),S=i(t),E=i(t),C=i(t),L=a(t,[{buffer:A,type:t.FLOAT,size:3},{buffer:C,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:M,type:t.FLOAT,size:4},{buffer:S,type:t.FLOAT,size:2},{buffer:E,type:t.FLOAT,size:1}]),P=i(t),O=new y(t,l,r,s,c,h,v,f,p,d,m,x,k,_,w,T,A,C,M,S,E,L,P,a(t,[{buffer:P,type:t.FLOAT,size:3}]));return O.update(e),O}},{\"./shaders\":244,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-shader\":301,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,normals:453,\"simplicial-complex-contour\":518,\"typedarray-pool\":545}],244:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\nuniform float vectorScale;\\nuniform float coneScale;\\n\\nuniform float coneOffset;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * conePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal,0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(conePosition, 1.0);\\n  vec4 t_position  = view * conePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = conePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular\\n            , opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nuniform float vectorScale;\\nuniform float coneScale;\\nuniform float coneOffset;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n  gl_Position = projection * view * conePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec3\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec3\"}]}},{glslify:409}],245:[function(t,e,r){e.exports={0:\"NONE\",1:\"ONE\",2:\"LINE_LOOP\",3:\"LINE_STRIP\",4:\"TRIANGLES\",5:\"TRIANGLE_STRIP\",6:\"TRIANGLE_FAN\",256:\"DEPTH_BUFFER_BIT\",512:\"NEVER\",513:\"LESS\",514:\"EQUAL\",515:\"LEQUAL\",516:\"GREATER\",517:\"NOTEQUAL\",518:\"GEQUAL\",519:\"ALWAYS\",768:\"SRC_COLOR\",769:\"ONE_MINUS_SRC_COLOR\",770:\"SRC_ALPHA\",771:\"ONE_MINUS_SRC_ALPHA\",772:\"DST_ALPHA\",773:\"ONE_MINUS_DST_ALPHA\",774:\"DST_COLOR\",775:\"ONE_MINUS_DST_COLOR\",776:\"SRC_ALPHA_SATURATE\",1024:\"STENCIL_BUFFER_BIT\",1028:\"FRONT\",1029:\"BACK\",1032:\"FRONT_AND_BACK\",1280:\"INVALID_ENUM\",1281:\"INVALID_VALUE\",1282:\"INVALID_OPERATION\",1285:\"OUT_OF_MEMORY\",1286:\"INVALID_FRAMEBUFFER_OPERATION\",2304:\"CW\",2305:\"CCW\",2849:\"LINE_WIDTH\",2884:\"CULL_FACE\",2885:\"CULL_FACE_MODE\",2886:\"FRONT_FACE\",2928:\"DEPTH_RANGE\",2929:\"DEPTH_TEST\",2930:\"DEPTH_WRITEMASK\",2931:\"DEPTH_CLEAR_VALUE\",2932:\"DEPTH_FUNC\",2960:\"STENCIL_TEST\",2961:\"STENCIL_CLEAR_VALUE\",2962:\"STENCIL_FUNC\",2963:\"STENCIL_VALUE_MASK\",2964:\"STENCIL_FAIL\",2965:\"STENCIL_PASS_DEPTH_FAIL\",2966:\"STENCIL_PASS_DEPTH_PASS\",2967:\"STENCIL_REF\",2968:\"STENCIL_WRITEMASK\",2978:\"VIEWPORT\",3024:\"DITHER\",3042:\"BLEND\",3088:\"SCISSOR_BOX\",3089:\"SCISSOR_TEST\",3106:\"COLOR_CLEAR_VALUE\",3107:\"COLOR_WRITEMASK\",3317:\"UNPACK_ALIGNMENT\",3333:\"PACK_ALIGNMENT\",3379:\"MAX_TEXTURE_SIZE\",3386:\"MAX_VIEWPORT_DIMS\",3408:\"SUBPIXEL_BITS\",3410:\"RED_BITS\",3411:\"GREEN_BITS\",3412:\"BLUE_BITS\",3413:\"ALPHA_BITS\",3414:\"DEPTH_BITS\",3415:\"STENCIL_BITS\",3553:\"TEXTURE_2D\",4352:\"DONT_CARE\",4353:\"FASTEST\",4354:\"NICEST\",5120:\"BYTE\",5121:\"UNSIGNED_BYTE\",5122:\"SHORT\",5123:\"UNSIGNED_SHORT\",5124:\"INT\",5125:\"UNSIGNED_INT\",5126:\"FLOAT\",5386:\"INVERT\",5890:\"TEXTURE\",6401:\"STENCIL_INDEX\",6402:\"DEPTH_COMPONENT\",6406:\"ALPHA\",6407:\"RGB\",6408:\"RGBA\",6409:\"LUMINANCE\",6410:\"LUMINANCE_ALPHA\",7680:\"KEEP\",7681:\"REPLACE\",7682:\"INCR\",7683:\"DECR\",7936:\"VENDOR\",7937:\"RENDERER\",7938:\"VERSION\",9728:\"NEAREST\",9729:\"LINEAR\",9984:\"NEAREST_MIPMAP_NEAREST\",9985:\"LINEAR_MIPMAP_NEAREST\",9986:\"NEAREST_MIPMAP_LINEAR\",9987:\"LINEAR_MIPMAP_LINEAR\",10240:\"TEXTURE_MAG_FILTER\",10241:\"TEXTURE_MIN_FILTER\",10242:\"TEXTURE_WRAP_S\",10243:\"TEXTURE_WRAP_T\",10497:\"REPEAT\",10752:\"POLYGON_OFFSET_UNITS\",16384:\"COLOR_BUFFER_BIT\",32769:\"CONSTANT_COLOR\",32770:\"ONE_MINUS_CONSTANT_COLOR\",32771:\"CONSTANT_ALPHA\",32772:\"ONE_MINUS_CONSTANT_ALPHA\",32773:\"BLEND_COLOR\",32774:\"FUNC_ADD\",32777:\"BLEND_EQUATION_RGB\",32778:\"FUNC_SUBTRACT\",32779:\"FUNC_REVERSE_SUBTRACT\",32819:\"UNSIGNED_SHORT_4_4_4_4\",32820:\"UNSIGNED_SHORT_5_5_5_1\",32823:\"POLYGON_OFFSET_FILL\",32824:\"POLYGON_OFFSET_FACTOR\",32854:\"RGBA4\",32855:\"RGB5_A1\",32873:\"TEXTURE_BINDING_2D\",32926:\"SAMPLE_ALPHA_TO_COVERAGE\",32928:\"SAMPLE_COVERAGE\",32936:\"SAMPLE_BUFFERS\",32937:\"SAMPLES\",32938:\"SAMPLE_COVERAGE_VALUE\",32939:\"SAMPLE_COVERAGE_INVERT\",32968:\"BLEND_DST_RGB\",32969:\"BLEND_SRC_RGB\",32970:\"BLEND_DST_ALPHA\",32971:\"BLEND_SRC_ALPHA\",33071:\"CLAMP_TO_EDGE\",33170:\"GENERATE_MIPMAP_HINT\",33189:\"DEPTH_COMPONENT16\",33306:\"DEPTH_STENCIL_ATTACHMENT\",33635:\"UNSIGNED_SHORT_5_6_5\",33648:\"MIRRORED_REPEAT\",33901:\"ALIASED_POINT_SIZE_RANGE\",33902:\"ALIASED_LINE_WIDTH_RANGE\",33984:\"TEXTURE0\",33985:\"TEXTURE1\",33986:\"TEXTURE2\",33987:\"TEXTURE3\",33988:\"TEXTURE4\",33989:\"TEXTURE5\",33990:\"TEXTURE6\",33991:\"TEXTURE7\",33992:\"TEXTURE8\",33993:\"TEXTURE9\",33994:\"TEXTURE10\",33995:\"TEXTURE11\",33996:\"TEXTURE12\",33997:\"TEXTURE13\",33998:\"TEXTURE14\",33999:\"TEXTURE15\",34000:\"TEXTURE16\",34001:\"TEXTURE17\",34002:\"TEXTURE18\",34003:\"TEXTURE19\",34004:\"TEXTURE20\",34005:\"TEXTURE21\",34006:\"TEXTURE22\",34007:\"TEXTURE23\",34008:\"TEXTURE24\",34009:\"TEXTURE25\",34010:\"TEXTURE26\",34011:\"TEXTURE27\",34012:\"TEXTURE28\",34013:\"TEXTURE29\",34014:\"TEXTURE30\",34015:\"TEXTURE31\",34016:\"ACTIVE_TEXTURE\",34024:\"MAX_RENDERBUFFER_SIZE\",34041:\"DEPTH_STENCIL\",34055:\"INCR_WRAP\",34056:\"DECR_WRAP\",34067:\"TEXTURE_CUBE_MAP\",34068:\"TEXTURE_BINDING_CUBE_MAP\",34069:\"TEXTURE_CUBE_MAP_POSITIVE_X\",34070:\"TEXTURE_CUBE_MAP_NEGATIVE_X\",34071:\"TEXTURE_CUBE_MAP_POSITIVE_Y\",34072:\"TEXTURE_CUBE_MAP_NEGATIVE_Y\",34073:\"TEXTURE_CUBE_MAP_POSITIVE_Z\",34074:\"TEXTURE_CUBE_MAP_NEGATIVE_Z\",34076:\"MAX_CUBE_MAP_TEXTURE_SIZE\",34338:\"VERTEX_ATTRIB_ARRAY_ENABLED\",34339:\"VERTEX_ATTRIB_ARRAY_SIZE\",34340:\"VERTEX_ATTRIB_ARRAY_STRIDE\",34341:\"VERTEX_ATTRIB_ARRAY_TYPE\",34342:\"CURRENT_VERTEX_ATTRIB\",34373:\"VERTEX_ATTRIB_ARRAY_POINTER\",34466:\"NUM_COMPRESSED_TEXTURE_FORMATS\",34467:\"COMPRESSED_TEXTURE_FORMATS\",34660:\"BUFFER_SIZE\",34661:\"BUFFER_USAGE\",34816:\"STENCIL_BACK_FUNC\",34817:\"STENCIL_BACK_FAIL\",34818:\"STENCIL_BACK_PASS_DEPTH_FAIL\",34819:\"STENCIL_BACK_PASS_DEPTH_PASS\",34877:\"BLEND_EQUATION_ALPHA\",34921:\"MAX_VERTEX_ATTRIBS\",34922:\"VERTEX_ATTRIB_ARRAY_NORMALIZED\",34930:\"MAX_TEXTURE_IMAGE_UNITS\",34962:\"ARRAY_BUFFER\",34963:\"ELEMENT_ARRAY_BUFFER\",34964:\"ARRAY_BUFFER_BINDING\",34965:\"ELEMENT_ARRAY_BUFFER_BINDING\",34975:\"VERTEX_ATTRIB_ARRAY_BUFFER_BINDING\",35040:\"STREAM_DRAW\",35044:\"STATIC_DRAW\",35048:\"DYNAMIC_DRAW\",35632:\"FRAGMENT_SHADER\",35633:\"VERTEX_SHADER\",35660:\"MAX_VERTEX_TEXTURE_IMAGE_UNITS\",35661:\"MAX_COMBINED_TEXTURE_IMAGE_UNITS\",35663:\"SHADER_TYPE\",35664:\"FLOAT_VEC2\",35665:\"FLOAT_VEC3\",35666:\"FLOAT_VEC4\",35667:\"INT_VEC2\",35668:\"INT_VEC3\",35669:\"INT_VEC4\",35670:\"BOOL\",35671:\"BOOL_VEC2\",35672:\"BOOL_VEC3\",35673:\"BOOL_VEC4\",35674:\"FLOAT_MAT2\",35675:\"FLOAT_MAT3\",35676:\"FLOAT_MAT4\",35678:\"SAMPLER_2D\",35680:\"SAMPLER_CUBE\",35712:\"DELETE_STATUS\",35713:\"COMPILE_STATUS\",35714:\"LINK_STATUS\",35715:\"VALIDATE_STATUS\",35716:\"INFO_LOG_LENGTH\",35717:\"ATTACHED_SHADERS\",35718:\"ACTIVE_UNIFORMS\",35719:\"ACTIVE_UNIFORM_MAX_LENGTH\",35720:\"SHADER_SOURCE_LENGTH\",35721:\"ACTIVE_ATTRIBUTES\",35722:\"ACTIVE_ATTRIBUTE_MAX_LENGTH\",35724:\"SHADING_LANGUAGE_VERSION\",35725:\"CURRENT_PROGRAM\",36003:\"STENCIL_BACK_REF\",36004:\"STENCIL_BACK_VALUE_MASK\",36005:\"STENCIL_BACK_WRITEMASK\",36006:\"FRAMEBUFFER_BINDING\",36007:\"RENDERBUFFER_BINDING\",36048:\"FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE\",36049:\"FRAMEBUFFER_ATTACHMENT_OBJECT_NAME\",36050:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL\",36051:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE\",36053:\"FRAMEBUFFER_COMPLETE\",36054:\"FRAMEBUFFER_INCOMPLETE_ATTACHMENT\",36055:\"FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT\",36057:\"FRAMEBUFFER_INCOMPLETE_DIMENSIONS\",36061:\"FRAMEBUFFER_UNSUPPORTED\",36064:\"COLOR_ATTACHMENT0\",36096:\"DEPTH_ATTACHMENT\",36128:\"STENCIL_ATTACHMENT\",36160:\"FRAMEBUFFER\",36161:\"RENDERBUFFER\",36162:\"RENDERBUFFER_WIDTH\",36163:\"RENDERBUFFER_HEIGHT\",36164:\"RENDERBUFFER_INTERNAL_FORMAT\",36168:\"STENCIL_INDEX8\",36176:\"RENDERBUFFER_RED_SIZE\",36177:\"RENDERBUFFER_GREEN_SIZE\",36178:\"RENDERBUFFER_BLUE_SIZE\",36179:\"RENDERBUFFER_ALPHA_SIZE\",36180:\"RENDERBUFFER_DEPTH_SIZE\",36181:\"RENDERBUFFER_STENCIL_SIZE\",36194:\"RGB565\",36336:\"LOW_FLOAT\",36337:\"MEDIUM_FLOAT\",36338:\"HIGH_FLOAT\",36339:\"LOW_INT\",36340:\"MEDIUM_INT\",36341:\"HIGH_INT\",36346:\"SHADER_COMPILER\",36347:\"MAX_VERTEX_UNIFORM_VECTORS\",36348:\"MAX_VARYING_VECTORS\",36349:\"MAX_FRAGMENT_UNIFORM_VECTORS\",37440:\"UNPACK_FLIP_Y_WEBGL\",37441:\"UNPACK_PREMULTIPLY_ALPHA_WEBGL\",37442:\"CONTEXT_LOST_WEBGL\",37443:\"UNPACK_COLORSPACE_CONVERSION_WEBGL\",37444:\"BROWSER_DEFAULT_WEBGL\"}},{}],246:[function(t,e,r){var n=t(\"./1.0/numbers\");e.exports=function(t){return n[t]}},{\"./1.0/numbers\":245}],247:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),o=i(e,[{buffer:r,type:e.FLOAT,size:3,offset:0,stride:40},{buffer:r,type:e.FLOAT,size:4,offset:12,stride:40},{buffer:r,type:e.FLOAT,size:3,offset:28,stride:40}]),l=a(e);l.attributes.position.location=0,l.attributes.color.location=1,l.attributes.offset.location=2;var c=new s(e,r,o,l);return c.update(t),c};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\"),o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.shader=n,this.buffer=e,this.vao=r,this.pixelRatio=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lineWidth=[1,1,1],this.capSize=[10,10,10],this.lineCount=[0,0,0],this.lineOffset=[0,0,0],this.opacity=1,this.hasAlpha=!1}var l=s.prototype;function c(t,e){for(var r=0;r<3;++r)t[0][r]=Math.min(t[0][r],e[r]),t[1][r]=Math.max(t[1][r],e[r])}l.isOpaque=function(){return!this.hasAlpha},l.isTransparent=function(){return this.hasAlpha},l.drawTransparent=l.draw=function(t){var e=this.gl,r=this.shader.uniforms;this.shader.bind();var n=r.view=t.view||o,i=r.projection=t.projection||o;r.model=t.model||o,r.clipBounds=this.clipBounds,r.opacity=this.opacity;var a=n[12],s=n[13],l=n[14],c=n[15],u=(t._ortho||!1?2:1)*this.pixelRatio*(i[3]*a+i[7]*s+i[11]*l+i[15]*c)/e.drawingBufferHeight;this.vao.bind();for(var h=0;h<3;++h)e.lineWidth(this.lineWidth[h]*this.pixelRatio),r.capSize=this.capSize[h]*u,this.lineCount[h]&&e.drawArrays(e.LINES,this.lineOffset[h],this.lineCount[h]);this.vao.unbind()};var u=function(){for(var t=new Array(3),e=0;e<3;++e){for(var r=[],n=1;n<=2;++n)for(var i=-1;i<=1;i+=2){var a=[0,0,0];a[(n+e)%3]=i,r.push(a)}t[e]=r}return t}();function h(t,e,r,n){for(var i=u[n],a=0;a<i.length;++a){var o=i[a];t.push(e[0],e[1],e[2],r[0],r[1],r[2],r[3],o[0],o[1],o[2])}return i.length}l.update=function(t){\"lineWidth\"in(t=t||{})&&(this.lineWidth=t.lineWidth,Array.isArray(this.lineWidth)||(this.lineWidth=[this.lineWidth,this.lineWidth,this.lineWidth])),\"capSize\"in t&&(this.capSize=t.capSize,Array.isArray(this.capSize)||(this.capSize=[this.capSize,this.capSize,this.capSize])),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var e=t.color||[[0,0,0],[0,0,0],[0,0,0]],r=t.position,n=t.error;if(Array.isArray(e[0])||(e=[e,e,e]),r&&n){var i=[],a=r.length,o=0;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.lineCount=[0,0,0];for(var s=0;s<3;++s){this.lineOffset[s]=o;t:for(var l=0;l<a;++l){for(var u=r[l],f=0;f<3;++f)if(isNaN(u[f])||!isFinite(u[f]))continue t;var p=n[l],d=e[s];if(Array.isArray(d[0])&&(d=e[l]),3===d.length?d=[d[0],d[1],d[2],1]:4===d.length&&(d=[d[0],d[1],d[2],d[3]],!this.hasAlpha&&d[3]<1&&(this.hasAlpha=!0)),!isNaN(p[0][s])&&!isNaN(p[1][s])){var g;if(p[0][s]<0)(g=u.slice())[s]+=p[0][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+h(i,g,d,s);if(p[1][s]>0)(g=u.slice())[s]+=p[1][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+h(i,g,d,s)}}this.lineCount[s]=o-this.lineOffset[s]}this.buffer.update(i)}},l.dispose=function(){this.shader.dispose(),this.buffer.dispose(),this.vao.dispose()}},{\"./shaders/index\":248,\"gl-buffer\":241,\"gl-vao\":327}],248:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, offset;\\nattribute vec4 color;\\nuniform mat4 model, view, projection;\\nuniform float capSize;\\nvarying vec4 fragColor;\\nvarying vec3 fragPosition;\\n\\nvoid main() {\\n  vec4 worldPosition  = model * vec4(position, 1.0);\\n  worldPosition       = (worldPosition / worldPosition.w) + vec4(capSize * offset, 0.0);\\n  gl_Position         = projection * view * worldPosition;\\n  fragColor           = color;\\n  fragPosition        = position;\\n}\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float opacity;\\nvarying vec3 fragPosition;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], fragPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  gl_FragColor = opacity * fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"offset\",type:\"vec3\"}])}},{\"gl-shader\":301,glslify:409}],249:[function(t,e,r){\"use strict\";var n=t(\"gl-texture2d\");e.exports=function(t,e,r,n){i||(i=t.FRAMEBUFFER_UNSUPPORTED,a=t.FRAMEBUFFER_INCOMPLETE_ATTACHMENT,o=t.FRAMEBUFFER_INCOMPLETE_DIMENSIONS,s=t.FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT);var c=t.getExtension(\"WEBGL_draw_buffers\");!l&&c&&function(t,e){var r=t.getParameter(e.MAX_COLOR_ATTACHMENTS_WEBGL);l=new Array(r+1);for(var n=0;n<=r;++n){for(var i=new Array(r),a=0;a<n;++a)i[a]=t.COLOR_ATTACHMENT0+a;for(var a=n;a<r;++a)i[a]=t.NONE;l[n]=i}}(t,c);Array.isArray(e)&&(n=r,r=0|e[1],e=0|e[0]);if(\"number\"!=typeof e)throw new Error(\"gl-fbo: Missing shape parameter\");var u=t.getParameter(t.MAX_RENDERBUFFER_SIZE);if(e<0||e>u||r<0||r>u)throw new Error(\"gl-fbo: Parameters are too large for FBO\");var h=1;if(\"color\"in(n=n||{})){if((h=Math.max(0|n.color,0))<0)throw new Error(\"gl-fbo: Must specify a nonnegative number of colors\");if(h>1){if(!c)throw new Error(\"gl-fbo: Multiple draw buffer extension not supported\");if(h>t.getParameter(c.MAX_COLOR_ATTACHMENTS_WEBGL))throw new Error(\"gl-fbo: Context does not support \"+h+\" draw buffers\")}}var f=t.UNSIGNED_BYTE,p=t.getExtension(\"OES_texture_float\");if(n.float&&h>0){if(!p)throw new Error(\"gl-fbo: Context does not support floating point textures\");f=t.FLOAT}else n.preferFloat&&h>0&&p&&(f=t.FLOAT);var g=!0;\"depth\"in n&&(g=!!n.depth);var v=!1;\"stencil\"in n&&(v=!!n.stencil);return new d(t,e,r,f,h,g,v,c)};var i,a,o,s,l=null;function c(t){return[t.getParameter(t.FRAMEBUFFER_BINDING),t.getParameter(t.RENDERBUFFER_BINDING),t.getParameter(t.TEXTURE_BINDING_2D)]}function u(t,e){t.bindFramebuffer(t.FRAMEBUFFER,e[0]),t.bindRenderbuffer(t.RENDERBUFFER,e[1]),t.bindTexture(t.TEXTURE_2D,e[2])}function h(t){switch(t){case i:throw new Error(\"gl-fbo: Framebuffer unsupported\");case a:throw new Error(\"gl-fbo: Framebuffer incomplete attachment\");case o:throw new Error(\"gl-fbo: Framebuffer incomplete dimensions\");case s:throw new Error(\"gl-fbo: Framebuffer incomplete missing attachment\");default:throw new Error(\"gl-fbo: Framebuffer failed for unspecified reason\")}}function f(t,e,r,i,a,o){if(!i)return null;var s=n(t,e,r,a,i);return s.magFilter=t.NEAREST,s.minFilter=t.NEAREST,s.mipSamples=1,s.bind(),t.framebufferTexture2D(t.FRAMEBUFFER,o,t.TEXTURE_2D,s.handle,0),s}function p(t,e,r,n,i){var a=t.createRenderbuffer();return t.bindRenderbuffer(t.RENDERBUFFER,a),t.renderbufferStorage(t.RENDERBUFFER,n,e,r),t.framebufferRenderbuffer(t.FRAMEBUFFER,i,t.RENDERBUFFER,a),a}function d(t,e,r,n,i,a,o,s){this.gl=t,this._shape=[0|e,0|r],this._destroyed=!1,this._ext=s,this.color=new Array(i);for(var d=0;d<i;++d)this.color[d]=null;this._color_rb=null,this.depth=null,this._depth_rb=null,this._colorType=n,this._useDepth=a,this._useStencil=o;var g=this,v=[0|e,0|r];Object.defineProperties(v,{0:{get:function(){return g._shape[0]},set:function(t){return g.width=t}},1:{get:function(){return g._shape[1]},set:function(t){return g.height=t}}}),this._shapeVector=v,function(t){var e=c(t.gl),r=t.gl,n=t.handle=r.createFramebuffer(),i=t._shape[0],a=t._shape[1],o=t.color.length,s=t._ext,d=t._useStencil,g=t._useDepth,v=t._colorType;r.bindFramebuffer(r.FRAMEBUFFER,n);for(var m=0;m<o;++m)t.color[m]=f(r,i,a,v,r.RGBA,r.COLOR_ATTACHMENT0+m);0===o?(t._color_rb=p(r,i,a,r.RGBA4,r.COLOR_ATTACHMENT0),s&&s.drawBuffersWEBGL(l[0])):o>1&&s.drawBuffersWEBGL(l[o]);var y=r.getExtension(\"WEBGL_depth_texture\");y?d?t.depth=f(r,i,a,y.UNSIGNED_INT_24_8_WEBGL,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g&&(t.depth=f(r,i,a,r.UNSIGNED_SHORT,r.DEPTH_COMPONENT,r.DEPTH_ATTACHMENT)):g&&d?t._depth_rb=p(r,i,a,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g?t._depth_rb=p(r,i,a,r.DEPTH_COMPONENT16,r.DEPTH_ATTACHMENT):d&&(t._depth_rb=p(r,i,a,r.STENCIL_INDEX,r.STENCIL_ATTACHMENT));var x=r.checkFramebufferStatus(r.FRAMEBUFFER);if(x!==r.FRAMEBUFFER_COMPLETE){for(t._destroyed=!0,r.bindFramebuffer(r.FRAMEBUFFER,null),r.deleteFramebuffer(t.handle),t.handle=null,t.depth&&(t.depth.dispose(),t.depth=null),t._depth_rb&&(r.deleteRenderbuffer(t._depth_rb),t._depth_rb=null),m=0;m<t.color.length;++m)t.color[m].dispose(),t.color[m]=null;t._color_rb&&(r.deleteRenderbuffer(t._color_rb),t._color_rb=null),u(r,e),h(x)}u(r,e)}(this)}var g=d.prototype;function v(t,e,r){if(t._destroyed)throw new Error(\"gl-fbo: Can't resize destroyed FBO\");if(t._shape[0]!==e||t._shape[1]!==r){var n=t.gl,i=n.getParameter(n.MAX_RENDERBUFFER_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-fbo: Can't resize FBO, invalid dimensions\");t._shape[0]=e,t._shape[1]=r;for(var a=c(n),o=0;o<t.color.length;++o)t.color[o].shape=t._shape;t._color_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._color_rb),n.renderbufferStorage(n.RENDERBUFFER,n.RGBA4,t._shape[0],t._shape[1])),t.depth&&(t.depth.shape=t._shape),t._depth_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._depth_rb),t._useDepth&&t._useStencil?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_STENCIL,t._shape[0],t._shape[1]):t._useDepth?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_COMPONENT16,t._shape[0],t._shape[1]):t._useStencil&&n.renderbufferStorage(n.RENDERBUFFER,n.STENCIL_INDEX,t._shape[0],t._shape[1])),n.bindFramebuffer(n.FRAMEBUFFER,t.handle);var s=n.checkFramebufferStatus(n.FRAMEBUFFER);s!==n.FRAMEBUFFER_COMPLETE&&(t.dispose(),u(n,a),h(s)),u(n,a)}}Object.defineProperties(g,{shape:{get:function(){return this._destroyed?[0,0]:this._shapeVector},set:function(t){if(Array.isArray(t)||(t=[0|t,0|t]),2!==t.length)throw new Error(\"gl-fbo: Shape vector must be length 2\");var e=0|t[0],r=0|t[1];return v(this,e,r),[e,r]},enumerable:!1},width:{get:function(){return this._destroyed?0:this._shape[0]},set:function(t){return v(this,t|=0,this._shape[1]),t},enumerable:!1},height:{get:function(){return this._destroyed?0:this._shape[1]},set:function(t){return t|=0,v(this,this._shape[0],t),t},enumerable:!1}}),g.bind=function(){if(!this._destroyed){var t=this.gl;t.bindFramebuffer(t.FRAMEBUFFER,this.handle),t.viewport(0,0,this._shape[0],this._shape[1])}},g.dispose=function(){if(!this._destroyed){this._destroyed=!0;var t=this.gl;t.deleteFramebuffer(this.handle),this.handle=null,this.depth&&(this.depth.dispose(),this.depth=null),this._depth_rb&&(t.deleteRenderbuffer(this._depth_rb),this._depth_rb=null);for(var e=0;e<this.color.length;++e)this.color[e].dispose(),this.color[e]=null;this._color_rb&&(t.deleteRenderbuffer(this._color_rb),this._color_rb=null)}}},{\"gl-texture2d\":322}],250:[function(t,e,r){var n=t(\"sprintf-js\").sprintf,i=t(\"gl-constants/lookup\"),a=t(\"glsl-shader-name\"),o=t(\"add-line-numbers\");e.exports=function(t,e,r){\"use strict\";var s=a(e)||\"of unknown name (see npm glsl-shader-name)\",l=\"unknown type\";void 0!==r&&(l=r===i.FRAGMENT_SHADER?\"fragment\":\"vertex\");for(var c=n(\"Error compiling %s shader %s:\\n\",l,s),u=n(\"%s%s\",c,t),h=t.split(\"\\n\"),f={},p=0;p<h.length;p++){var d=h[p];if(\"\"!==d&&\"\\0\"!==d){var g=parseInt(d.split(\":\")[2]);if(isNaN(g))throw new Error(n(\"Could not parse error: %s\",d));f[g]=d}}for(var v=o(e).split(\"\\n\"),p=0;p<v.length;p++)if(f[p+3]||f[p+2]||f[p+1]){var m=v[p];if(c+=m+\"\\n\",f[p+1]){var y=f[p+1];y=y.substr(y.split(\":\",3).join(\":\").length+1).trim(),c+=n(\"^^^ %s\\n\\n\",y)}}return{long:c.trim(),short:u.trim()}}},{\"add-line-numbers\":61,\"gl-constants/lookup\":246,\"glsl-shader-name\":401,\"sprintf-js\":528}],251:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.gl,n=o(r,l.vertex,l.fragment),i=o(r,l.pickVertex,l.pickFragment),a=s(r),u=s(r),h=s(r),f=s(r),p=new c(t,n,i,a,u,h,f);return p.update(e),t.addObject(p),p};var n=t(\"binary-search-bounds\"),i=t(\"iota-array\"),a=t(\"typedarray-pool\"),o=t(\"gl-shader\"),s=t(\"gl-buffer\"),l=t(\"./lib/shaders\");function c(t,e,r,n,i,a,o){this.plot=t,this.shader=e,this.pickShader=r,this.positionBuffer=n,this.weightBuffer=i,this.colorBuffer=a,this.idBuffer=o,this.xData=[],this.yData=[],this.shape=[0,0],this.bounds=[1/0,1/0,-1/0,-1/0],this.pickOffset=0}var u,h=c.prototype,f=[0,0,1,0,0,1,1,0,1,1,0,1];h.draw=(u=[1,0,0,0,1,0,0,0,1],function(){var t=this.plot,e=this.shader,r=this.bounds,n=this.numVertices;if(!(n<=0)){var i=t.gl,a=t.dataBox,o=r[2]-r[0],s=r[3]-r[1],l=a[2]-a[0],c=a[3]-a[1];u[0]=2*o/l,u[4]=2*s/c,u[6]=2*(r[0]-a[0])/l-1,u[7]=2*(r[1]-a[1])/c-1,e.bind();var h=e.uniforms;h.viewTransform=u,h.shape=this.shape;var f=e.attributes;this.positionBuffer.bind(),f.position.pointer(),this.weightBuffer.bind(),f.weight.pointer(i.UNSIGNED_BYTE,!1),this.colorBuffer.bind(),f.color.pointer(i.UNSIGNED_BYTE,!0),i.drawArrays(i.TRIANGLES,0,n)}}),h.drawPick=function(){var t=[1,0,0,0,1,0,0,0,1],e=[0,0,0,0];return function(r){var n=this.plot,i=this.pickShader,a=this.bounds,o=this.numVertices;if(!(o<=0)){var s=n.gl,l=n.dataBox,c=a[2]-a[0],u=a[3]-a[1],h=l[2]-l[0],f=l[3]-l[1];t[0]=2*c/h,t[4]=2*u/f,t[6]=2*(a[0]-l[0])/h-1,t[7]=2*(a[1]-l[1])/f-1;for(var p=0;p<4;++p)e[p]=r>>8*p&255;this.pickOffset=r,i.bind();var d=i.uniforms;d.viewTransform=t,d.pickOffset=e,d.shape=this.shape;var g=i.attributes;return this.positionBuffer.bind(),g.position.pointer(),this.weightBuffer.bind(),g.weight.pointer(s.UNSIGNED_BYTE,!1),this.idBuffer.bind(),g.pickId.pointer(s.UNSIGNED_BYTE,!1),s.drawArrays(s.TRIANGLES,0,o),r+this.shape[0]*this.shape[1]}}}(),h.pick=function(t,e,r){var n=this.pickOffset,i=this.shape[0]*this.shape[1];if(r<n||r>=n+i)return null;var a=r-n,o=this.xData,s=this.yData;return{object:this,pointId:a,dataCoord:[o[a%this.shape[0]],s[a/this.shape[0]|0]]}},h.update=function(t){var e=(t=t||{}).shape||[0,0],r=t.x||i(e[0]),o=t.y||i(e[1]),s=t.z||new Float32Array(e[0]*e[1]);this.xData=r,this.yData=o;var l=t.colorLevels||[0],c=t.colorValues||[0,0,0,1],u=l.length,h=this.bounds,p=h[0]=r[0],d=h[1]=o[0],g=1/((h[2]=r[r.length-1])-p),v=1/((h[3]=o[o.length-1])-d),m=e[0],y=e[1];this.shape=[m,y];var x=(m-1)*(y-1)*(f.length>>>1);this.numVertices=x;for(var b=a.mallocUint8(4*x),_=a.mallocFloat32(2*x),w=a.mallocUint8(2*x),k=a.mallocUint32(x),T=0,A=0;A<y-1;++A)for(var M=v*(o[A]-d),S=v*(o[A+1]-d),E=0;E<m-1;++E)for(var C=g*(r[E]-p),L=g*(r[E+1]-p),P=0;P<f.length;P+=2){var O,z,I,D,R=f[P],F=f[P+1],B=s[(A+F)*m+(E+R)],N=n.le(l,B);if(N<0)O=c[0],z=c[1],I=c[2],D=c[3];else if(N===u-1)O=c[4*u-4],z=c[4*u-3],I=c[4*u-2],D=c[4*u-1];else{var j=(B-l[N])/(l[N+1]-l[N]),U=1-j,V=4*N,q=4*(N+1);O=U*c[V]+j*c[q],z=U*c[V+1]+j*c[q+1],I=U*c[V+2]+j*c[q+2],D=U*c[V+3]+j*c[q+3]}b[4*T]=255*O,b[4*T+1]=255*z,b[4*T+2]=255*I,b[4*T+3]=255*D,_[2*T]=.5*C+.5*L,_[2*T+1]=.5*M+.5*S,w[2*T]=R,w[2*T+1]=F,k[T]=A*m+E,T+=1}this.positionBuffer.update(_),this.weightBuffer.update(w),this.colorBuffer.update(b),this.idBuffer.update(k),a.free(_),a.free(b),a.free(w),a.free(k)},h.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.positionBuffer.dispose(),this.weightBuffer.dispose(),this.colorBuffer.dispose(),this.idBuffer.dispose(),this.plot.removeObject(this)}},{\"./lib/shaders\":252,\"binary-search-bounds\":253,\"gl-buffer\":241,\"gl-shader\":301,\"iota-array\":416,\"typedarray-pool\":545}],252:[function(t,e,r){\"use strict\";var n=t(\"glslify\");e.exports={fragment:n([\"precision lowp float;\\n#define GLSLIFY 1\\nvarying vec4 fragColor;\\nvoid main() {\\n  gl_FragColor = vec4(fragColor.rgb * fragColor.a, fragColor.a);\\n}\\n\"]),vertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 color;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  fragColor = color;\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"]),pickFragment:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nuniform vec2 shape;\\nuniform vec4 pickOffset;\\n\\nvoid main() {\\n  vec2 d = step(.5, vWeight);\\n  vec4 id = fragId + pickOffset;\\n  id.x += d.x + d.y*shape.x;\\n\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  gl_FragColor = id/255.;\\n}\\n\"]),pickVertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nvoid main() {\\n  vWeight = weight;\\n\\n  fragId = pickId;\\n\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"])}},{glslify:409}],253:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],254:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, nextPosition;\\nattribute float arcLength, lineWidth;\\nattribute vec4 color;\\n\\nuniform vec2 screenShape;\\nuniform float pixelRatio;\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 fragColor;\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  vec4 startPoint = project(position);\\n  vec4 endPoint   = project(nextPosition);\\n\\n  vec2 A = startPoint.xy / startPoint.w;\\n  vec2 B =   endPoint.xy /   endPoint.w;\\n\\n  float clipAngle = atan(\\n    (B.y - A.y) * screenShape.y,\\n    (B.x - A.x) * screenShape.x\\n  );\\n\\n  vec2 offset = 0.5 * pixelRatio * lineWidth * vec2(\\n    sin(clipAngle),\\n    -cos(clipAngle)\\n  ) / screenShape;\\n\\n  gl_Position = vec4(startPoint.xy + startPoint.w * offset, startPoint.zw);\\n\\n  worldPosition = position;\\n  pixelArcLength = arcLength;\\n  fragColor = color;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3      clipBounds[2];\\nuniform sampler2D dashTexture;\\nuniform float     dashScale;\\nuniform float     opacity;\\n\\nvarying vec3    worldPosition;\\nvarying float   pixelArcLength;\\nvarying vec4    fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], worldPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  float dashWeight = texture2D(dashTexture, vec2(dashScale * pixelArcLength, 0)).r;\\n  if(dashWeight < 0.5) {\\n    discard;\\n  }\\n  gl_FragColor = fragColor * opacity;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\n#define FLOAT_MAX  1.70141184e38\\n#define FLOAT_MIN  1.17549435e-38\\n\\nlowp vec4 encode_float_1540259130(highp float v) {\\n  highp float av = abs(v);\\n\\n  //Handle special cases\\n  if(av < FLOAT_MIN) {\\n    return vec4(0.0, 0.0, 0.0, 0.0);\\n  } else if(v > FLOAT_MAX) {\\n    return vec4(127.0, 128.0, 0.0, 0.0) / 255.0;\\n  } else if(v < -FLOAT_MAX) {\\n    return vec4(255.0, 128.0, 0.0, 0.0) / 255.0;\\n  }\\n\\n  highp vec4 c = vec4(0,0,0,0);\\n\\n  //Compute exponent and mantissa\\n  highp float e = floor(log2(av));\\n  highp float m = av * pow(2.0, -e) - 1.0;\\n  \\n  //Unpack mantissa\\n  c[1] = floor(128.0 * m);\\n  m -= c[1] / 128.0;\\n  c[2] = floor(32768.0 * m);\\n  m -= c[2] / 32768.0;\\n  c[3] = floor(8388608.0 * m);\\n  \\n  //Unpack exponent\\n  highp float ebias = e + 127.0;\\n  c[0] = floor(ebias / 2.0);\\n  ebias -= c[0] * 2.0;\\n  c[1] += floor(ebias) * 128.0; \\n\\n  //Unpack sign bit\\n  c[0] += 128.0 * step(0.0, -v);\\n\\n  //Scale back to range\\n  return c / 255.0;\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform float pickId;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], worldPosition)) discard;\\n\\n  gl_FragColor = vec4(pickId/255.0, encode_float_1540259130(pixelArcLength).xyz);\\n}\"]),l=[{name:\"position\",type:\"vec3\"},{name:\"nextPosition\",type:\"vec3\"},{name:\"arcLength\",type:\"float\"},{name:\"lineWidth\",type:\"float\"},{name:\"color\",type:\"vec4\"}];r.createShader=function(t){return i(t,a,o,null,l)},r.createPickShader=function(t){return i(t,a,s,null,l)}},{\"gl-shader\":301,glslify:409}],255:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl||t.scene&&t.scene.gl,r=u(e);r.attributes.position.location=0,r.attributes.nextPosition.location=1,r.attributes.arcLength.location=2,r.attributes.lineWidth.location=3,r.attributes.color.location=4;var o=h(e);o.attributes.position.location=0,o.attributes.nextPosition.location=1,o.attributes.arcLength.location=2,o.attributes.lineWidth.location=3,o.attributes.color.location=4;for(var s=n(e),c=i(e,[{buffer:s,size:3,offset:0,stride:48},{buffer:s,size:3,offset:12,stride:48},{buffer:s,size:1,offset:24,stride:48},{buffer:s,size:1,offset:28,stride:48},{buffer:s,size:4,offset:32,stride:48}]),f=l(new Array(1024),[256,1,4]),p=0;p<1024;++p)f.data[p]=255;var d=a(e,f);d.wrap=e.REPEAT;var g=new v(e,r,o,s,c,d);return g.update(t),g};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"gl-texture2d\"),o=t(\"glsl-read-float\"),s=t(\"binary-search-bounds\"),l=t(\"ndarray\"),c=t(\"./lib/shaders\"),u=c.createShader,h=c.createPickShader,f=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function p(t,e){for(var r=0,n=0;n<3;++n){var i=t[n]-e[n];r+=i*i}return Math.sqrt(r)}function d(t){for(var e=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],r=0;r<3;++r)e[0][r]=Math.max(t[0][r],e[0][r]),e[1][r]=Math.min(t[1][r],e[1][r]);return e}function g(t,e,r,n){this.arcLength=t,this.position=e,this.index=r,this.dataCoordinate=n}function v(t,e,r,n,i,a){this.gl=t,this.shader=e,this.pickShader=r,this.buffer=n,this.vao=i,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.points=[],this.arcLength=[],this.vertexCount=0,this.bounds=[[0,0,0],[0,0,0]],this.pickId=0,this.lineWidth=1,this.texture=a,this.dashScale=1,this.opacity=1,this.hasAlpha=!1,this.dirty=!0,this.pixelRatio=1}var m=v.prototype;m.isTransparent=function(){return this.hasAlpha},m.isOpaque=function(){return!this.hasAlpha},m.pickSlots=1,m.setPickBase=function(t){this.pickId=t},m.drawTransparent=m.draw=function(t){if(this.vertexCount){var e=this.gl,r=this.shader,n=this.vao;r.bind(),r.uniforms={model:t.model||f,view:t.view||f,projection:t.projection||f,clipBounds:d(this.clipBounds),dashTexture:this.texture.bind(),dashScale:this.dashScale/this.arcLength[this.arcLength.length-1],opacity:this.opacity,screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},m.drawPick=function(t){if(this.vertexCount){var e=this.gl,r=this.pickShader,n=this.vao;r.bind(),r.uniforms={model:t.model||f,view:t.view||f,projection:t.projection||f,pickId:this.pickId,clipBounds:d(this.clipBounds),screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},m.update=function(t){var e,r;this.dirty=!0;var n=!!t.connectGaps;\"dashScale\"in t&&(this.dashScale=t.dashScale),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var i=[],a=[],o=[],c=0,u=0,h=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],f=t.position||t.positions;if(f){var d=t.color||t.colors||[0,0,0,1],g=t.lineWidth||1,v=!1;t:for(e=1;e<f.length;++e){var m,y,x,b=f[e-1],_=f[e];for(a.push(c),o.push(b.slice()),r=0;r<3;++r){if(isNaN(b[r])||isNaN(_[r])||!isFinite(b[r])||!isFinite(_[r])){if(!n&&i.length>0){for(var w=0;w<24;++w)i.push(i[i.length-12]);u+=2,v=!0}continue t}h[0][r]=Math.min(h[0][r],b[r],_[r]),h[1][r]=Math.max(h[1][r],b[r],_[r])}Array.isArray(d[0])?(m=d.length>e-1?d[e-1]:d.length>0?d[d.length-1]:[0,0,0,1],y=d.length>e?d[e]:d.length>0?d[d.length-1]:[0,0,0,1]):m=y=d,3===m.length&&(m=[m[0],m[1],m[2],1]),3===y.length&&(y=[y[0],y[1],y[2],1]),!this.hasAlpha&&m[3]<1&&(this.hasAlpha=!0),x=Array.isArray(g)?g.length>e-1?g[e-1]:g.length>0?g[g.length-1]:[0,0,0,1]:g;var k=c;if(c+=p(b,_),v){for(r=0;r<2;++r)i.push(b[0],b[1],b[2],_[0],_[1],_[2],k,x,m[0],m[1],m[2],m[3]);u+=2,v=!1}i.push(b[0],b[1],b[2],_[0],_[1],_[2],k,x,m[0],m[1],m[2],m[3],b[0],b[1],b[2],_[0],_[1],_[2],k,-x,m[0],m[1],m[2],m[3],_[0],_[1],_[2],b[0],b[1],b[2],c,-x,y[0],y[1],y[2],y[3],_[0],_[1],_[2],b[0],b[1],b[2],c,x,y[0],y[1],y[2],y[3]),u+=4}}if(this.buffer.update(i),a.push(c),o.push(f[f.length-1].slice()),this.bounds=h,this.vertexCount=u,this.points=o,this.arcLength=a,\"dashes\"in t){var T=t.dashes.slice();for(T.unshift(0),e=1;e<T.length;++e)T[e]=T[e-1]+T[e];var A=l(new Array(1024),[256,1,4]);for(e=0;e<256;++e){for(r=0;r<4;++r)A.set(e,0,r,0);1&s.le(T,T[T.length-1]*e/255)?A.set(e,0,0,0):A.set(e,0,0,255)}this.texture.setPixels(A)}},m.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()},m.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=o(t.value[0],t.value[1],t.value[2],0),r=s.le(this.arcLength,e);if(r<0)return null;if(r===this.arcLength.length-1)return new g(this.arcLength[this.arcLength.length-1],this.points[this.points.length-1].slice(),r);for(var n=this.points[r],i=this.points[Math.min(r+1,this.points.length-1)],a=(e-this.arcLength[r])/(this.arcLength[r+1]-this.arcLength[r]),l=1-a,c=[0,0,0],u=0;u<3;++u)c[u]=l*n[u]+a*i[u];var h=Math.min(a<.5?r:r+1,this.points.length-1);return new g(e,c,h,this.points[h])}},{\"./lib/shaders\":254,\"binary-search-bounds\":256,\"gl-buffer\":241,\"gl-texture2d\":322,\"gl-vao\":327,\"glsl-read-float\":400,ndarray:450}],256:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],257:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r*a-i*n;return o?(o=1/o,t[0]=a*o,t[1]=-n*o,t[2]=-i*o,t[3]=r*o,t):null}},{}],258:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=u*o-s*c,f=-u*a+s*l,p=c*a-o*l,d=r*h+n*f+i*p;return d?(d=1/d,t[0]=h*d,t[1]=(-u*n+i*c)*d,t[2]=(s*n-i*o)*d,t[3]=f*d,t[4]=(u*r-i*l)*d,t[5]=(-s*r+i*a)*d,t[6]=p*d,t[7]=(-c*r+n*l)*d,t[8]=(o*r-n*a)*d,t):null}},{}],259:[function(t,e,r){e.exports=function(t){var e=new Float32Array(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e}},{}],260:[function(t,e,r){e.exports=function(){var t=new Float32Array(16);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],261:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3],a=t[4],o=t[5],s=t[6],l=t[7],c=t[8],u=t[9],h=t[10],f=t[11],p=t[12],d=t[13],g=t[14],v=t[15];return(e*o-r*a)*(h*v-f*g)-(e*s-n*a)*(u*v-f*d)+(e*l-i*a)*(u*g-h*d)+(r*s-n*o)*(c*v-f*p)-(r*l-i*o)*(c*g-h*p)+(n*l-i*s)*(c*d-u*p)}},{}],262:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r+r,s=n+n,l=i+i,c=r*o,u=n*o,h=n*s,f=i*o,p=i*s,d=i*l,g=a*o,v=a*s,m=a*l;return t[0]=1-h-d,t[1]=u+m,t[2]=f-v,t[3]=0,t[4]=u-m,t[5]=1-c-d,t[6]=p+g,t[7]=0,t[8]=f+v,t[9]=p-g,t[10]=1-c-h,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],263:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=n+n,l=i+i,c=a+a,u=n*s,h=n*l,f=n*c,p=i*l,d=i*c,g=a*c,v=o*s,m=o*l,y=o*c;return t[0]=1-(p+g),t[1]=h+y,t[2]=f-m,t[3]=0,t[4]=h-y,t[5]=1-(u+g),t[6]=d+v,t[7]=0,t[8]=f+m,t[9]=d-v,t[10]=1-(u+p),t[11]=0,t[12]=r[0],t[13]=r[1],t[14]=r[2],t[15]=1,t}},{}],264:[function(t,e,r){e.exports=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],265:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],g=e[13],v=e[14],m=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,k=i*c-a*l,T=u*g-h*d,A=u*v-f*d,M=u*m-p*d,S=h*v-f*g,E=h*m-p*g,C=f*m-p*v,L=y*C-x*E+b*S+_*M-w*A+k*T;if(!L)return null;return L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(i*E-n*C-a*S)*L,t[2]=(g*k-v*w+m*_)*L,t[3]=(f*w-h*k-p*_)*L,t[4]=(l*M-o*C-c*A)*L,t[5]=(r*C-i*M+a*A)*L,t[6]=(v*b-d*k-m*x)*L,t[7]=(u*k-f*b+p*x)*L,t[8]=(o*E-s*M+c*T)*L,t[9]=(n*M-r*E-a*T)*L,t[10]=(d*w-g*b+m*y)*L,t[11]=(h*b-u*w-p*y)*L,t[12]=(s*A-o*S-l*T)*L,t[13]=(r*S-n*A+i*T)*L,t[14]=(g*x-d*_-v*y)*L,t[15]=(u*_-h*x+f*y)*L,t}},{}],266:[function(t,e,r){var n=t(\"./identity\");e.exports=function(t,e,r,i){var a,o,s,l,c,u,h,f,p,d,g=e[0],v=e[1],m=e[2],y=i[0],x=i[1],b=i[2],_=r[0],w=r[1],k=r[2];if(Math.abs(g-_)<1e-6&&Math.abs(v-w)<1e-6&&Math.abs(m-k)<1e-6)return n(t);h=g-_,f=v-w,p=m-k,d=1/Math.sqrt(h*h+f*f+p*p),a=x*(p*=d)-b*(f*=d),o=b*(h*=d)-y*p,s=y*f-x*h,(d=Math.sqrt(a*a+o*o+s*s))?(a*=d=1/d,o*=d,s*=d):(a=0,o=0,s=0);l=f*s-p*o,c=p*a-h*s,u=h*o-f*a,(d=Math.sqrt(l*l+c*c+u*u))?(l*=d=1/d,c*=d,u*=d):(l=0,c=0,u=0);return t[0]=a,t[1]=l,t[2]=h,t[3]=0,t[4]=o,t[5]=c,t[6]=f,t[7]=0,t[8]=s,t[9]=u,t[10]=p,t[11]=0,t[12]=-(a*g+o*v+s*m),t[13]=-(l*g+c*v+u*m),t[14]=-(h*g+f*v+p*m),t[15]=1,t}},{\"./identity\":264}],267:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],g=e[12],v=e[13],m=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*h+w*g,t[1]=x*i+b*l+_*f+w*v,t[2]=x*a+b*c+_*p+w*m,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*h+w*g,t[5]=x*i+b*l+_*f+w*v,t[6]=x*a+b*c+_*p+w*m,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*h+w*g,t[9]=x*i+b*l+_*f+w*v,t[10]=x*a+b*c+_*p+w*m,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*h+w*g,t[13]=x*i+b*l+_*f+w*v,t[14]=x*a+b*c+_*p+w*m,t[15]=x*o+b*u+_*d+w*y,t}},{}],268:[function(t,e,r){e.exports=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t}},{}],269:[function(t,e,r){e.exports=function(t,e,r,n,i){var a=1/Math.tan(e/2),o=1/(n-i);return t[0]=a/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=a,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=(i+n)*o,t[11]=-1,t[12]=0,t[13]=0,t[14]=2*i*n*o,t[15]=0,t}},{}],270:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_,w,k,T,A,M,S,E=n[0],C=n[1],L=n[2],P=Math.sqrt(E*E+C*C+L*L);if(Math.abs(P)<1e-6)return null;E*=P=1/P,C*=P,L*=P,i=Math.sin(r),a=Math.cos(r),o=1-a,s=e[0],l=e[1],c=e[2],u=e[3],h=e[4],f=e[5],p=e[6],d=e[7],g=e[8],v=e[9],m=e[10],y=e[11],x=E*E*o+a,b=C*E*o+L*i,_=L*E*o-C*i,w=E*C*o-L*i,k=C*C*o+a,T=L*C*o+E*i,A=E*L*o+C*i,M=C*L*o-E*i,S=L*L*o+a,t[0]=s*x+h*b+g*_,t[1]=l*x+f*b+v*_,t[2]=c*x+p*b+m*_,t[3]=u*x+d*b+y*_,t[4]=s*w+h*k+g*T,t[5]=l*w+f*k+v*T,t[6]=c*w+p*k+m*T,t[7]=u*w+d*k+y*T,t[8]=s*A+h*M+g*S,t[9]=l*A+f*M+v*S,t[10]=c*A+p*M+m*S,t[11]=u*A+d*M+y*S,e!==t&&(t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t}},{}],271:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+h*n,t[7]=l*i+f*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=h*i-s*n,t[11]=f*i-l*n,t}},{}],272:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[8],u=e[9],h=e[10],f=e[11];e!==t&&(t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i-c*n,t[1]=o*i-u*n,t[2]=s*i-h*n,t[3]=l*i-f*n,t[8]=a*n+c*i,t[9]=o*n+u*i,t[10]=s*n+h*i,t[11]=l*n+f*i,t}},{}],273:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+h*n,t[3]=l*i+f*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=h*i-s*n,t[7]=f*i-l*n,t}},{}],274:[function(t,e,r){e.exports=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},{}],275:[function(t,e,r){e.exports=function(t,e,r){var n,i,a,o,s,l,c,u,h,f,p,d,g=r[0],v=r[1],m=r[2];e===t?(t[12]=e[0]*g+e[4]*v+e[8]*m+e[12],t[13]=e[1]*g+e[5]*v+e[9]*m+e[13],t[14]=e[2]*g+e[6]*v+e[10]*m+e[14],t[15]=e[3]*g+e[7]*v+e[11]*m+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*g+s*v+h*m+e[12],t[13]=i*g+l*v+f*m+e[13],t[14]=a*g+c*v+p*m+e[14],t[15]=o*g+u*v+d*m+e[15]);return t}},{}],276:[function(t,e,r){e.exports=function(t,e){if(t===e){var r=e[1],n=e[2],i=e[3],a=e[6],o=e[7],s=e[11];t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=r,t[6]=e[9],t[7]=e[13],t[8]=n,t[9]=a,t[11]=e[14],t[12]=i,t[13]=o,t[14]=s}else t[0]=e[0],t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=e[1],t[5]=e[5],t[6]=e[9],t[7]=e[13],t[8]=e[2],t[9]=e[6],t[10]=e[10],t[11]=e[14],t[12]=e[3],t[13]=e[7],t[14]=e[11],t[15]=e[15];return t}},{}],277:[function(t,e,r){\"use strict\";e.exports=function(t,e){switch(e.length){case 0:break;case 1:t[0]=1/e[0];break;case 4:n(t,e);break;case 9:i(t,e);break;case 16:a(t,e);break;default:throw new Error(\"currently supports matrices up to 4x4\")}return t};var n=t(\"gl-mat2/invert\"),i=t(\"gl-mat3/invert\"),a=t(\"gl-mat4/invert\")},{\"gl-mat2/invert\":257,\"gl-mat3/invert\":258,\"gl-mat4/invert\":265}],278:[function(t,e,r){\"use strict\";var n=t(\"barycentric\"),i=t(\"polytope-closest-point/lib/closest_point_2d.js\");function a(t,e){for(var r=[0,0,0,0],n=0;n<4;++n)for(var i=0;i<4;++i)r[i]+=t[4*n+i]*e[n];return r}function o(t,e,r,n,i){for(var o=a(n,a(r,a(e,[t[0],t[1],t[2],1]))),s=0;s<3;++s)o[s]/=o[3];return[.5*i[0]*(1+o[0]),.5*i[1]*(1-o[1])]}e.exports=function(t,e,r,a,s,l){if(1===t.length)return[0,t[0].slice()];for(var c=new Array(t.length),u=0;u<t.length;++u)c[u]=o(t[u],r,a,s,l);for(var h=0,f=1/0,u=0;u<c.length;++u){for(var p=0,d=0;d<2;++d)p+=Math.pow(c[u][d]-e[d],2);p<f&&(f=p,h=u)}for(var g=function(t,e){if(2===t.length){for(var r=0,a=0,o=0;o<2;++o)r+=Math.pow(e[o]-t[0][o],2),a+=Math.pow(e[o]-t[1][o],2);return r=Math.sqrt(r),a=Math.sqrt(a),r+a<1e-6?[1,0]:[a/(r+a),r/(a+r)]}if(3===t.length){var s=[0,0];return i(t[0],t[1],t[2],e,s),n(t,s)}return[]}(c,e),v=0,u=0;u<3;++u){if(g[u]<-.001||g[u]>1.0001)return null;v+=g[u]}if(Math.abs(v-1)>.001)return null;return[h,function(t,e){for(var r=[0,0,0],n=0;n<t.length;++n)for(var i=t[n],a=e[n],o=0;o<3;++o)r[o]+=a*i[o];return r}(t,g),g]}},{barycentric:73,\"polytope-closest-point/lib/closest_point_2d.js\":481}],279:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, normal;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  gl_Position      = project(position);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * vec4(position , 1.0);\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal  = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  f_color          = color;\\n  f_data           = position;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\n//#pragma glslify: beckmann = require(glsl-specular-beckmann) // used in gl-surface3d\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (f_color.a == 0.0 ||\\n    outOfRange(clipBounds[0], clipBounds[1], f_data)\\n  ) discard;\\n\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  //float specular = max(0.0, beckmann(L, V, N, roughness)); // used in gl-surface3d\\n\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = vec4(f_color.rgb, 1.0) * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * f_color.a;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_color = color;\\n  f_data  = position;\\n  f_uv    = uv;\\n}\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_data)) discard;\\n\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\nattribute float pointSize;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0 ,0.0 ,0.0);\\n  } else {\\n    gl_Position = projection * view * model * vec4(position, 1.0);\\n  }\\n  gl_PointSize = pointSize;\\n  f_color = color;\\n  f_uv = uv;\\n}\"]),c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  vec2 pointR = gl_PointCoord.xy - vec2(0.5, 0.5);\\n  if(dot(pointR, pointR) > 0.25) {\\n    discard;\\n  }\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_id        = id;\\n  f_position  = position;\\n}\"]),h=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]),f=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3  position;\\nattribute float pointSize;\\nattribute vec4  id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0, 0.0, 0.0);\\n  } else {\\n    gl_Position  = projection * view * model * vec4(position, 1.0);\\n    gl_PointSize = pointSize;\\n  }\\n  f_id         = id;\\n  f_position   = position;\\n}\"]),p=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n}\"]),d=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec3 contourColor;\\n\\nvoid main() {\\n  gl_FragColor = vec4(contourColor, 1.0);\\n}\\n\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.wireShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.pointShader={vertex:l,fragment:c,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"pointSize\",type:\"float\"}]},r.pickShader={vertex:u,fragment:h,attributes:[{name:\"position\",type:\"vec3\"},{name:\"id\",type:\"vec4\"}]},r.pointPickShader={vertex:f,fragment:h,attributes:[{name:\"position\",type:\"vec3\"},{name:\"pointSize\",type:\"float\"},{name:\"id\",type:\"vec4\"}]},r.contourShader={vertex:p,fragment:d,attributes:[{name:\"position\",type:\"vec3\"}]}},{glslify:409}],280:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./lib/shaders\"),g=t(\"./lib/closest-point\"),v=d.meshShader,m=d.wireShader,y=d.pointShader,x=d.pickShader,b=d.pointPickShader,_=d.contourShader,w=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function k(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_,k,T,A,M,S){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.lineShader=n,this.pointShader=i,this.pickShader=a,this.pointPickShader=o,this.contourShader=s,this.trianglePositions=l,this.triangleColors=u,this.triangleNormals=f,this.triangleUVs=h,this.triangleIds=c,this.triangleVAO=p,this.triangleCount=0,this.lineWidth=1,this.edgePositions=d,this.edgeColors=v,this.edgeUVs=m,this.edgeIds=g,this.edgeVAO=y,this.edgeCount=0,this.pointPositions=x,this.pointColors=_,this.pointUVs=k,this.pointSizes=T,this.pointIds=b,this.pointVAO=A,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=M,this.contourVAO=S,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.hasAlpha=!1,this.opacityscale=!1,this._model=w,this._view=w,this._projection=w,this._resolution=[1,1]}var T=k.prototype;function A(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}function M(t){var e=n(t,y.vertex,y.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.pointSize.location=4,e}function S(t){var e=n(t,x.vertex,x.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e}function E(t){var e=n(t,b.vertex,b.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.pointSize.location=4,e}function C(t){var e=n(t,_.vertex,_.fragment);return e.attributes.position.location=0,e}T.isOpaque=function(){return!this.hasAlpha},T.isTransparent=function(){return this.hasAlpha},T.pickSlots=1,T.setPickBase=function(t){this.pickId=t},T.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=i[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},T.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=t.opacity,this.opacity<1&&(this.hasAlpha=!0)),\"opacityscale\"in t&&(this.opacityscale=t.opacityscale,this.hasAlpha=!0),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t,e){for(var r=h({colormap:t,nshades:256,format:\"rgba\"}),n=new Uint8Array(1024),i=0;i<256;++i){for(var a=r[i],o=0;o<3;++o)n[4*i+o]=a[o];n[4*i+3]=e?255*A(i/255,e):255*a[3]}return u(n,[256,256,4],[4,0,1])}(t.colormap,this.opacityscale)),this.texture.generateMipmap());var r=t.cells,n=t.positions;if(n&&r){var i=[],a=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[];this.cells=r,this.positions=n;var w=t.vertexNormals,k=t.cellNormals,T=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,M=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!k&&(k=s.faceNormals(r,n,M)),k||w||(w=s.vertexNormals(r,n,T));var S=t.vertexColors,E=t.cellColors,C=t.meshColor||[1,1,1,1],L=t.vertexUVs,P=t.vertexIntensity,O=t.cellUVs,z=t.cellIntensity,I=1/0,D=-1/0;if(!L&&!O)if(P)if(t.vertexIntensityBounds)I=+t.vertexIntensityBounds[0],D=+t.vertexIntensityBounds[1];else for(var R=0;R<P.length;++R){var F=P[R];I=Math.min(I,F),D=Math.max(D,F)}else if(z)for(R=0;R<z.length;++R){F=z[R];I=Math.min(I,F),D=Math.max(D,F)}else for(R=0;R<n.length;++R){F=n[R][2];I=Math.min(I,F),D=Math.max(D,F)}this.intensity=P||(z?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,z):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var B=t.pointSizes,N=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(R=0;R<n.length;++R)for(var j=n[R],U=0;U<3;++U)!isNaN(j[U])&&isFinite(j[U])&&(this.bounds[0][U]=Math.min(this.bounds[0][U],j[U]),this.bounds[1][U]=Math.max(this.bounds[1][U],j[U]));var V=0,q=0,H=0;t:for(R=0;R<r.length;++R){var G=r[R];switch(G.length){case 1:for(j=n[W=G[0]],U=0;U<3;++U)if(isNaN(j[U])||!isFinite(j[U]))continue t;m.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?y.push(X[0],X[1],X[2],this.opacity):(y.push(X[0],X[1],X[2],X[3]*this.opacity),!this.hasAlpha&&X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],x.push(Z[0],Z[1]),B?b.push(B[W]):b.push(N),_.push(R),H+=1;break;case 2:for(U=0;U<2;++U){j=n[W=G[U]];for(var Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t}for(U=0;U<2;++U){j=n[W=G[U]];p.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?d.push(X[0],X[1],X[2],this.opacity):(d.push(X[0],X[1],X[2],X[3]*this.opacity),!this.hasAlpha&&X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],g.push(Z[0],Z[1]),v.push(R)}q+=1;break;case 3:for(U=0;U<3;++U)for(j=n[W=G[U]],Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t;for(U=0;U<3;++U){var W,X,Z,J;j=n[W=G[2-U]];i.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?a.push(X[0],X[1],X[2],this.opacity):(a.push(X[0],X[1],X[2],X[3]*this.opacity),!this.hasAlpha&&X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],c.push(Z[0],Z[1]),J=w?w[W]:k[R],l.push(J[0],J[1],J[2]),f.push(R)}V+=1}}this.pointCount=H,this.edgeCount=q,this.triangleCount=V,this.pointPositions.update(m),this.pointColors.update(y),this.pointUVs.update(x),this.pointSizes.update(b),this.pointIds.update(new Uint32Array(_)),this.edgePositions.update(p),this.edgeColors.update(d),this.edgeUVs.update(g),this.edgeIds.update(new Uint32Array(v)),this.trianglePositions.update(i),this.triangleColors.update(a),this.triangleUVs.update(c),this.triangleNormals.update(l),this.triangleIds.update(new Uint32Array(f))}},T.drawTransparent=T.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:w.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h,f=u[15];for(o=0;o<3;++o)f+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];s.lightPosition[o]=p/f}this.triangleCount>0&&((h=this.triShader).bind(),h.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind());this.edgeCount>0&&this.lineWidth>0&&((h=this.lineShader).bind(),h.uniforms=s,this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind());this.pointCount>0&&((h=this.pointShader).bind(),h.uniforms=s,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind());this.contourEnable&&this.contourCount>0&&this.contourLineWidth>0&&((h=this.contourShader).bind(),h.uniforms=s,this.contourVAO.bind(),e.drawArrays(e.LINES,0,this.contourCount),this.contourVAO.unbind())},T.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s,l={model:r,view:n,projection:i,clipBounds:a,pickId:this.pickId/255};((s=this.pickShader).bind(),s.uniforms=l,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind()),this.pointCount>0)&&((s=this.pointPickShader).bind(),s.uniforms=l,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind())},T.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;for(var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions,i=new Array(r.length),a=0;a<r.length;++a)i[a]=n[r[a]];var o=g(i,[t.coord[0],this._resolution[1]-t.coord[1]],this._model,this._view,this._projection,this._resolution);if(!o)return null;var s=o[2],l=0;for(a=0;a<r.length;++a)l+=s[a]*this.intensity[r[a]];return{position:o[1],index:r[o[0]],cell:r,cellId:e,intensity:l,dataCoordinate:this.positions[r[o[0]]]}},T.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.lineShader.dispose(),this.pointShader.dispose(),this.pickShader.dispose(),this.pointPickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose(),this.contourShader.dispose()},e.exports=function(t,e){if(1===arguments.length&&(t=(e=t).gl),!(t.getExtension(\"OES_standard_derivatives\")||t.getExtension(\"MOZ_OES_standard_derivatives\")||t.getExtension(\"WEBKIT_OES_standard_derivatives\")))throw new Error(\"derivatives not supported\");var r=function(t){var e=n(t,v.vertex,v.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.normal.location=4,e}(t),s=function(t){var e=n(t,m.vertex,m.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e}(t),l=M(t),c=S(t),h=E(t),f=C(t),p=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));p.generateMipmap(),p.minFilter=t.LINEAR_MIPMAP_LINEAR,p.magFilter=t.LINEAR;var d=i(t),g=i(t),y=i(t),x=i(t),b=i(t),_=a(t,[{buffer:d,type:t.FLOAT,size:3},{buffer:b,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:g,type:t.FLOAT,size:4},{buffer:y,type:t.FLOAT,size:2},{buffer:x,type:t.FLOAT,size:3}]),w=i(t),T=i(t),A=i(t),L=i(t),P=a(t,[{buffer:w,type:t.FLOAT,size:3},{buffer:L,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:T,type:t.FLOAT,size:4},{buffer:A,type:t.FLOAT,size:2}]),O=i(t),z=i(t),I=i(t),D=i(t),R=i(t),F=a(t,[{buffer:O,type:t.FLOAT,size:3},{buffer:R,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:z,type:t.FLOAT,size:4},{buffer:I,type:t.FLOAT,size:2},{buffer:D,type:t.FLOAT,size:1}]),B=i(t),N=new k(t,p,r,s,l,c,h,f,d,b,g,y,x,_,w,L,T,A,P,O,R,z,I,D,F,B,a(t,[{buffer:B,type:t.FLOAT,size:3}]));return N.update(e),N}},{\"./lib/closest-point\":278,\"./lib/shaders\":279,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-shader\":301,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,normals:453,\"simplicial-complex-contour\":518,\"typedarray-pool\":545}],281:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[0,0,0,1,1,0,1,1]),s=i(e,a.boxVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawBox=(s=[0,0],l=[0,0],function(t,e,r,n,i){var a=this.plot,o=this.shader,c=a.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,o.uniforms.lo=s,o.uniforms.hi=l,o.uniforms.color=i,c.drawArrays(c.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":284,\"gl-buffer\":241,\"gl-shader\":301}],282:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,o.gridVert,o.gridFrag),l=i(e,o.tickVert,o.gridFrag);return new s(t,r,a,l)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"binary-search-bounds\"),o=t(\"./shaders\");function s(t,e,r,n){this.plot=t,this.vbo=e,this.shader=r,this.tickShader=n,this.ticks=[[],[]]}function l(t,e){return t-e}var c,u,h,f,p,d=s.prototype;d.draw=(c=[0,0],u=[0,0],h=[0,0],function(){for(var t=this.plot,e=this.vbo,r=this.shader,n=this.ticks,i=t.gl,a=t._tickBounds,o=t.dataBox,s=t.viewBox,l=t.gridLineWidth,f=t.gridLineColor,p=t.gridLineEnable,d=t.pixelRatio,g=0;g<2;++g){var v=a[g],m=a[g+2]-v,y=.5*(o[g+2]+o[g]),x=o[g+2]-o[g];u[g]=2*m/x,c[g]=2*(v-y)/x}r.bind(),e.bind(),r.attributes.dataCoord.pointer(),r.uniforms.dataShift=c,r.uniforms.dataScale=u;var b=0;for(g=0;g<2;++g){h[0]=h[1]=0,h[g]=1,r.uniforms.dataAxis=h,r.uniforms.lineWidth=l[g]/(s[g+2]-s[g])*d,r.uniforms.color=f[g];var _=6*n[g].length;p[g]&&_&&i.drawArrays(i.TRIANGLES,b,_),b+=_}}),d.drawTickMarks=function(){var t=[0,0],e=[0,0],r=[1,0],n=[0,1],i=[0,0],o=[0,0];return function(){for(var s=this.plot,c=this.vbo,u=this.tickShader,h=this.ticks,f=s.gl,p=s._tickBounds,d=s.dataBox,g=s.viewBox,v=s.pixelRatio,m=s.screenBox,y=m[2]-m[0],x=m[3]-m[1],b=g[2]-g[0],_=g[3]-g[1],w=0;w<2;++w){var k=p[w],T=p[w+2]-k,A=.5*(d[w+2]+d[w]),M=d[w+2]-d[w];e[w]=2*T/M,t[w]=2*(k-A)/M}e[0]*=b/y,t[0]*=b/y,e[1]*=_/x,t[1]*=_/x,u.bind(),c.bind(),u.attributes.dataCoord.pointer();var S=u.uniforms;S.dataShift=t,S.dataScale=e;var E=s.tickMarkLength,C=s.tickMarkWidth,L=s.tickMarkColor,P=6*h[0].length,O=Math.min(a.ge(h[0],(d[0]-p[0])/(p[2]-p[0]),l),h[0].length),z=Math.min(a.gt(h[0],(d[2]-p[0])/(p[2]-p[0]),l),h[0].length),I=0+6*O,D=6*Math.max(0,z-O),R=Math.min(a.ge(h[1],(d[1]-p[1])/(p[3]-p[1]),l),h[1].length),F=Math.min(a.gt(h[1],(d[3]-p[1])/(p[3]-p[1]),l),h[1].length),B=P+6*R,N=6*Math.max(0,F-R);i[0]=2*(g[0]-E[1])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=E[1]*v/y,o[1]=C[1]*v/x,N&&(S.color=L[1],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,f.drawArrays(f.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[1]-E[0])/x-1,o[0]=C[0]*v/y,o[1]=E[0]*v/x,D&&(S.color=L[0],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,f.drawArrays(f.TRIANGLES,I,D)),i[0]=2*(g[2]+E[3])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=E[3]*v/y,o[1]=C[3]*v/x,N&&(S.color=L[3],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,f.drawArrays(f.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[3]+E[2])/x-1,o[0]=C[2]*v/y,o[1]=E[2]*v/x,D&&(S.color=L[2],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,f.drawArrays(f.TRIANGLES,I,D))}}(),d.update=(f=[1,1,-1,-1,1,-1],p=[1,-1,1,1,-1,-1],function(t){for(var e=t.ticks,r=t.bounds,n=new Float32Array(18*(e[0].length+e[1].length)),i=(this.plot.zeroLineEnable,0),a=[[],[]],o=0;o<2;++o)for(var s=a[o],l=e[o],c=r[o],u=r[o+2],h=0;h<l.length;++h){var d=(l[h].x-c)/(u-c);s.push(d);for(var g=0;g<6;++g)n[i++]=d,n[i++]=f[g],n[i++]=p[g]}this.ticks=a,this.vbo.update(n)}),d.dispose=function(){this.vbo.dispose(),this.shader.dispose(),this.tickShader.dispose()}},{\"./shaders\":284,\"binary-search-bounds\":286,\"gl-buffer\":241,\"gl-shader\":301}],283:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[-1,-1,-1,1,1,-1,1,1]),s=i(e,a.lineVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawLine=(s=[0,0],l=[0,0],function(t,e,r,n,i,a){var o=this.plot,c=this.shader,u=o.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,c.uniforms.start=s,c.uniforms.end=l,c.uniforms.width=i*o.pixelRatio,c.uniforms.color=a,u.drawArrays(u.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":284,\"gl-buffer\":241,\"gl-shader\":301}],284:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision lowp float;\\n#define GLSLIFY 1\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = vec4(color.xyz * color.w, color.w);\\n}\\n\"]);e.exports={lineVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 start, end;\\nuniform float width;\\n\\nvec2 perp(vec2 v) {\\n  return vec2(v.y, -v.x);\\n}\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  vec2 delta = normalize(perp(start - end));\\n  vec2 offset = mix(start, end, 0.5 * (coord.y+1.0));\\n  gl_Position = vec4(screen(offset + 0.5 * width * delta * coord.x), 0, 1);\\n}\\n\"]),lineFrag:i,textVert:n([\"#define GLSLIFY 1\\nattribute vec3 textCoordinate;\\n\\nuniform vec2 dataScale, dataShift, dataAxis, screenOffset, textScale;\\nuniform float angle;\\n\\nvoid main() {\\n  float dataOffset  = textCoordinate.z;\\n  vec2 glyphOffset  = textCoordinate.xy;\\n  mat2 glyphMatrix = mat2(cos(angle), sin(angle), -sin(angle), cos(angle));\\n  vec2 screenCoordinate = dataAxis * (dataScale * dataOffset + dataShift) +\\n    glyphMatrix * glyphOffset * textScale + screenOffset;\\n  gl_Position = vec4(screenCoordinate, 0, 1);\\n}\\n\"]),textFrag:i,gridVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale;\\nuniform float lineWidth;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  pos += 10.0 * dataCoord.y * vec2(dataAxis.y, -dataAxis.x) + dataCoord.z * lineWidth;\\n  gl_Position = vec4(pos, 0, 1);\\n}\\n\"]),gridFrag:i,boxVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 lo, hi;\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  gl_Position = vec4(screen(mix(lo, hi, coord)), 0, 1);\\n}\\n\"]),tickVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale, screenOffset, tickScale;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  gl_Position = vec4(pos + tickScale*dataCoord.yz + screenOffset, 0, 1);\\n}\\n\"])}},{glslify:409}],285:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,s.textVert,s.textFrag);return new l(t,r,a)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"text-cache\"),o=t(\"binary-search-bounds\"),s=t(\"./shaders\");function l(t,e,r){this.plot=t,this.vbo=e,this.shader=r,this.tickOffset=[[],[]],this.tickX=[[],[]],this.labelOffset=[0,0],this.labelCount=[0,0]}var c,u,h,f,p,d,g=l.prototype;g.drawTicks=(c=[0,0],u=[0,0],h=[0,0],function(t){var e=this.plot,r=this.shader,n=this.tickX[t],i=this.tickOffset[t],a=e.gl,s=e.viewBox,l=e.dataBox,f=e.screenBox,p=e.pixelRatio,d=e.tickEnable,g=e.tickPad,v=e.tickColor,m=e.tickAngle,y=e.labelEnable,x=e.labelPad,b=e.labelColor,_=e.labelAngle,w=this.labelOffset[t],k=this.labelCount[t],T=o.lt(n,l[t]),A=o.le(n,l[t+2]);c[0]=c[1]=0,c[t]=1,u[t]=(s[2+t]+s[t])/(f[2+t]-f[t])-1;var M=2/f[2+(1^t)]-f[1^t];u[1^t]=M*s[1^t]-1,d[t]&&(u[1^t]-=M*p*g[t],T<A&&i[A]>i[T]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=v[t],r.uniforms.angle=m[t],a.drawArrays(a.TRIANGLES,i[T],i[A]-i[T]))),y[t]&&k&&(u[1^t]-=M*p*x[t],r.uniforms.dataAxis=h,r.uniforms.screenOffset=u,r.uniforms.color=b[t],r.uniforms.angle=_[t],a.drawArrays(a.TRIANGLES,w,k)),u[1^t]=M*s[2+(1^t)]-1,d[t+2]&&(u[1^t]+=M*p*g[t+2],T<A&&i[A]>i[T]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=v[t+2],r.uniforms.angle=m[t+2],a.drawArrays(a.TRIANGLES,i[T],i[A]-i[T]))),y[t+2]&&k&&(u[1^t]+=M*p*x[t+2],r.uniforms.dataAxis=h,r.uniforms.screenOffset=u,r.uniforms.color=b[t+2],r.uniforms.angle=_[t+2],a.drawArrays(a.TRIANGLES,w,k))}),g.drawTitle=function(){var t=[0,0],e=[0,0];return function(){var r=this.plot,n=this.shader,i=r.gl,a=r.screenBox,o=r.titleCenter,s=r.titleAngle,l=r.titleColor,c=r.pixelRatio;if(this.titleCount){for(var u=0;u<2;++u)e[u]=2*(o[u]*c-a[u])/(a[2+u]-a[u])-1;n.bind(),n.uniforms.dataAxis=t,n.uniforms.screenOffset=e,n.uniforms.angle=s,n.uniforms.color=l,i.drawArrays(i.TRIANGLES,this.titleOffset,this.titleCount)}}}(),g.bind=(f=[0,0],p=[0,0],d=[0,0],function(){var t=this.plot,e=this.shader,r=t._tickBounds,n=t.dataBox,i=t.screenBox,a=t.viewBox;e.bind();for(var o=0;o<2;++o){var s=r[o],l=r[o+2]-s,c=.5*(n[o+2]+n[o]),u=n[o+2]-n[o],h=a[o],g=a[o+2]-h,v=i[o],m=i[o+2]-v;p[o]=2*l/u*g/m,f[o]=2*(s-c)/u*g/m}d[1]=2*t.pixelRatio/(i[3]-i[1]),d[0]=d[1]*(i[3]-i[1])/(i[2]-i[0]),e.uniforms.dataScale=p,e.uniforms.dataShift=f,e.uniforms.textScale=d,this.vbo.bind(),e.attributes.textCoordinate.pointer()}),g.update=function(t){var e,r,n,i,o,s=[],l=t.ticks,c=t.bounds;for(o=0;o<2;++o){var u=[Math.floor(s.length/3)],h=[-1/0],f=l[o];for(e=0;e<f.length;++e){var p=f[e],d=p.x,g=p.text,v=p.font||\"sans-serif\";i=p.fontSize||12;for(var m=1/(c[o+2]-c[o]),y=c[o],x=g.split(\"\\n\"),b=0;b<x.length;b++)for(n=a(v,x[b]).data,r=0;r<n.length;r+=2)s.push(n[r]*i,-n[r+1]*i-b*i*1.2,(d-y)*m);u.push(Math.floor(s.length/3)),h.push(d)}this.tickOffset[o]=u,this.tickX[o]=h}for(o=0;o<2;++o){for(this.labelOffset[o]=Math.floor(s.length/3),n=a(t.labelFont[o],t.labels[o],{textAlign:\"center\"}).data,i=t.labelSize[o],e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.labelCount[o]=Math.floor(s.length/3)-this.labelOffset[o]}for(this.titleOffset=Math.floor(s.length/3),n=a(t.titleFont,t.title).data,i=t.titleSize,e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.titleCount=Math.floor(s.length/3)-this.titleOffset,this.vbo.update(s)},g.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":284,\"binary-search-bounds\":286,\"gl-buffer\":241,\"gl-shader\":301,\"text-cache\":536}],286:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],287:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[e.drawingBufferWidth,e.drawingBufferHeight]),c=new l(e,r);return c.grid=i(c),c.text=a(c),c.line=o(c),c.box=s(c),c.update(t),c};var n=t(\"gl-select-static\"),i=t(\"./lib/grid\"),a=t(\"./lib/text\"),o=t(\"./lib/line\"),s=t(\"./lib/box\");function l(t,e){this.gl=t,this.pickBuffer=e,this.screenBox=[0,0,t.drawingBufferWidth,t.drawingBufferHeight],this.viewBox=[0,0,0,0],this.dataBox=[-10,-10,10,10],this.gridLineEnable=[!0,!0],this.gridLineWidth=[1,1],this.gridLineColor=[[0,0,0,1],[0,0,0,1]],this.pixelRatio=1,this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickEnable=[!0,!0,!0,!0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[15,15,15,15],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelEnable=[!0,!0,!0,!0],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.titleCenter=[0,0],this.titleEnable=!0,this.titleAngle=0,this.titleColor=[0,0,0,1],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[4,4],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderLineEnable=[!0,!0,!0,!0],this.borderLineWidth=[2,2,2,2],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.grid=null,this.text=null,this.line=null,this.box=null,this.objects=[],this.overlays=[],this._tickBounds=[1/0,1/0,-1/0,-1/0],this.static=!1,this.dirty=!1,this.pickDirty=!1,this.pickDelay=120,this.pickRadius=10,this._pickTimeout=null,this._drawPick=this.drawPick.bind(this),this._depthCounter=0}var c=l.prototype;function u(t){for(var e=t.slice(),r=0;r<e.length;++r)e[r]=e[r].slice();return e}function h(t,e){return t.x-e.x}c.setDirty=function(){this.dirty=this.pickDirty=!0},c.setOverlayDirty=function(){this.dirty=!0},c.nextDepthValue=function(){return this._depthCounter++/65536},c.draw=function(){var t=this.gl,e=this.screenBox,r=this.viewBox,n=this.dataBox,i=this.pixelRatio,a=this.grid,o=this.line,s=this.text,l=this.objects;if(this._depthCounter=0,this.pickDirty&&(this._pickTimeout&&clearTimeout(this._pickTimeout),this.pickDirty=!1,this._pickTimeout=setTimeout(this._drawPick,this.pickDelay)),this.dirty){if(this.dirty=!1,t.bindFramebuffer(t.FRAMEBUFFER,null),t.enable(t.SCISSOR_TEST),t.disable(t.DEPTH_TEST),t.depthFunc(t.LESS),t.depthMask(!1),t.enable(t.BLEND),t.blendEquation(t.FUNC_ADD,t.FUNC_ADD),t.blendFunc(t.ONE,t.ONE_MINUS_SRC_ALPHA),this.borderColor){t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]);var c=this.borderColor;t.clearColor(c[0]*c[3],c[1]*c[3],c[2]*c[3],c[3]),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT)}t.scissor(r[0],r[1],r[2]-r[0],r[3]-r[1]),t.viewport(r[0],r[1],r[2]-r[0],r[3]-r[1]);var u=this.backgroundColor;t.clearColor(u[0]*u[3],u[1]*u[3],u[2]*u[3],u[3]),t.clear(t.COLOR_BUFFER_BIT),a.draw();var h=this.zeroLineEnable,f=this.zeroLineColor,p=this.zeroLineWidth;if(h[0]||h[1]){o.bind();for(var d=0;d<2;++d)if(h[d]&&n[d]<=0&&n[d+2]>=0){var g=e[d]-n[d]*(e[d+2]-e[d])/(n[d+2]-n[d]);0===d?o.drawLine(g,e[1],g,e[3],p[d],f[d]):o.drawLine(e[0],g,e[2],g,p[d],f[d])}}for(d=0;d<l.length;++d)l[d].draw();t.viewport(e[0],e[1],e[2]-e[0],e[3]-e[1]),t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]),this.grid.drawTickMarks(),o.bind();var v=this.borderLineEnable,m=this.borderLineWidth,y=this.borderLineColor;for(v[1]&&o.drawLine(r[0],r[1]-.5*m[1]*i,r[0],r[3]+.5*m[3]*i,m[1],y[1]),v[0]&&o.drawLine(r[0]-.5*m[0]*i,r[1],r[2]+.5*m[2]*i,r[1],m[0],y[0]),v[3]&&o.drawLine(r[2],r[1]-.5*m[1]*i,r[2],r[3]+.5*m[3]*i,m[3],y[3]),v[2]&&o.drawLine(r[0]-.5*m[0]*i,r[3],r[2]+.5*m[2]*i,r[3],m[2],y[2]),s.bind(),d=0;d<2;++d)s.drawTicks(d);this.titleEnable&&s.drawTitle();var x=this.overlays;for(d=0;d<x.length;++d)x[d].draw();t.disable(t.SCISSOR_TEST),t.disable(t.BLEND),t.depthMask(!0)}},c.drawPick=function(){if(!this.static){var t=this.pickBuffer;this.gl;this._pickTimeout=null,t.begin();for(var e=1,r=this.objects,n=0;n<r.length;++n)e=r[n].drawPick(e);t.end()}},c.pick=function(t,e){if(!this.static){var r=this.pixelRatio,n=this.pickPixelRatio,i=this.viewBox,a=0|Math.round((t-i[0]/r)*n),o=0|Math.round((e-i[1]/r)*n),s=this.pickBuffer.query(a,o,this.pickRadius);if(!s)return null;for(var l=s.id+(s.value[0]<<8)+(s.value[1]<<16)+(s.value[2]<<24),c=this.objects,u=0;u<c.length;++u){var h=c[u].pick(a,o,l);if(h)return h}return null}},c.setScreenBox=function(t){var e=this.screenBox,r=this.pixelRatio;e[0]=0|Math.round(t[0]*r),e[1]=0|Math.round(t[1]*r),e[2]=0|Math.round(t[2]*r),e[3]=0|Math.round(t[3]*r),this.setDirty()},c.setDataBox=function(t){var e=this.dataBox;(e[0]!==t[0]||e[1]!==t[1]||e[2]!==t[2]||e[3]!==t[3])&&(e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],this.setDirty())},c.setViewBox=function(t){var e=this.pixelRatio,r=this.viewBox;r[0]=0|Math.round(t[0]*e),r[1]=0|Math.round(t[1]*e),r[2]=0|Math.round(t[2]*e),r[3]=0|Math.round(t[3]*e);var n=this.pickPixelRatio;this.pickBuffer.shape=[0|Math.round((t[2]-t[0])*n),0|Math.round((t[3]-t[1])*n)],this.setDirty()},c.update=function(t){t=t||{};var e=this.gl;this.pixelRatio=t.pixelRatio||1;var r=this.pixelRatio;this.pickPixelRatio=Math.max(r,1),this.setScreenBox(t.screenBox||[0,0,e.drawingBufferWidth/r,e.drawingBufferHeight/r]);this.screenBox;this.setViewBox(t.viewBox||[.125*(this.screenBox[2]-this.screenBox[0])/r,.125*(this.screenBox[3]-this.screenBox[1])/r,.875*(this.screenBox[2]-this.screenBox[0])/r,.875*(this.screenBox[3]-this.screenBox[1])/r]);var n=this.viewBox,i=(n[2]-n[0])/(n[3]-n[1]);this.setDataBox(t.dataBox||[-10,-10/i,10,10/i]),this.borderColor=!1!==t.borderColor&&(t.borderColor||[0,0,0,0]).slice(),this.backgroundColor=(t.backgroundColor||[0,0,0,0]).slice(),this.gridLineEnable=(t.gridLineEnable||[!0,!0]).slice(),this.gridLineWidth=(t.gridLineWidth||[1,1]).slice(),this.gridLineColor=u(t.gridLineColor||[[.5,.5,.5,1],[.5,.5,.5,1]]),this.zeroLineEnable=(t.zeroLineEnable||[!0,!0]).slice(),this.zeroLineWidth=(t.zeroLineWidth||[4,4]).slice(),this.zeroLineColor=u(t.zeroLineColor||[[0,0,0,1],[0,0,0,1]]),this.tickMarkLength=(t.tickMarkLength||[0,0,0,0]).slice(),this.tickMarkWidth=(t.tickMarkWidth||[0,0,0,0]).slice(),this.tickMarkColor=u(t.tickMarkColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.titleCenter=(t.titleCenter||[.5*(n[0]+n[2])/r,(n[3]+120)/r]).slice(),this.titleEnable=!(\"titleEnable\"in t&&!t.titleEnable),this.titleAngle=t.titleAngle||0,this.titleColor=(t.titleColor||[0,0,0,1]).slice(),this.labelPad=(t.labelPad||[15,15,15,15]).slice(),this.labelAngle=(t.labelAngle||[0,Math.PI/2,0,3*Math.PI/2]).slice(),this.labelEnable=(t.labelEnable||[!0,!0,!0,!0]).slice(),this.labelColor=u(t.labelColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.tickPad=(t.tickPad||[15,15,15,15]).slice(),this.tickAngle=(t.tickAngle||[0,0,0,0]).slice(),this.tickEnable=(t.tickEnable||[!0,!0,!0,!0]).slice(),this.tickColor=u(t.tickColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.borderLineEnable=(t.borderLineEnable||[!0,!0,!0,!0]).slice(),this.borderLineWidth=(t.borderLineWidth||[2,2,2,2]).slice(),this.borderLineColor=u(t.borderLineColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]);var a=t.ticks||[[],[]],o=this._tickBounds;o[0]=o[1]=1/0,o[2]=o[3]=-1/0;for(var s=0;s<2;++s){var l=a[s].slice(0);0!==l.length&&(l.sort(h),o[s]=Math.min(o[s],l[0].x),o[s+2]=Math.max(o[s+2],l[l.length-1].x))}this.grid.update({bounds:o,ticks:a}),this.text.update({bounds:o,ticks:a,labels:t.labels||[\"x\",\"y\"],labelSize:t.labelSize||[12,12],labelFont:t.labelFont||[\"sans-serif\",\"sans-serif\"],title:t.title||\"\",titleSize:t.titleSize||18,titleFont:t.titleFont||\"sans-serif\"}),this.static=!!t.static,this.setDirty()},c.dispose=function(){this.box.dispose(),this.grid.dispose(),this.text.dispose(),this.line.dispose();for(var t=this.objects.length-1;t>=0;--t)this.objects[t].dispose();this.objects.length=0;for(t=this.overlays.length-1;t>=0;--t)this.overlays[t].dispose();this.overlays.length=0,this.gl=null},c.addObject=function(t){this.objects.indexOf(t)<0&&(this.objects.push(t),this.setDirty())},c.removeObject=function(t){for(var e=this.objects,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setDirty();break}},c.addOverlay=function(t){this.overlays.indexOf(t)<0&&(this.overlays.push(t),this.setOverlayDirty())},c.removeOverlay=function(t){for(var e=this.overlays,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setOverlayDirty();break}}},{\"./lib/box\":281,\"./lib/grid\":282,\"./lib/line\":283,\"./lib/text\":285,\"gl-select-static\":300}],288:[function(t,e,r){\"use strict\";e.exports=function(t,e){t=t||document.body,e=e||{};var r=[.01,1/0];\"distanceLimits\"in e&&(r[0]=e.distanceLimits[0],r[1]=e.distanceLimits[1]);\"zoomMin\"in e&&(r[0]=e.zoomMin);\"zoomMax\"in e&&(r[1]=e.zoomMax);var c=i({center:e.center||[0,0,0],up:e.up||[0,1,0],eye:e.eye||[0,0,10],mode:e.mode||\"orbit\",distanceLimits:r}),u=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],h=0,f=t.clientWidth,p=t.clientHeight,d={keyBindingMode:\"rotate\",enableWheel:!0,view:c,element:t,delay:e.delay||16,rotateSpeed:e.rotateSpeed||1,zoomSpeed:e.zoomSpeed||1,translateSpeed:e.translateSpeed||1,flipX:!!e.flipX,flipY:!!e.flipY,modes:c.modes,_ortho:e._ortho||e.projection&&\"orthographic\"===e.projection.type||!1,tick:function(){var e=n(),r=this.delay,i=e-2*r;c.idle(e-r),c.recalcMatrix(i),c.flush(e-(100+2*r));for(var a=!0,o=c.computedMatrix,s=0;s<16;++s)a=a&&u[s]===o[s],u[s]=o[s];var l=t.clientWidth===f&&t.clientHeight===p;return f=t.clientWidth,p=t.clientHeight,a?!l:(h=Math.exp(c.computedRadius[0]),!0)},lookAt:function(t,e,r){c.lookAt(c.lastT(),t,e,r)},rotate:function(t,e,r){c.rotate(c.lastT(),t,e,r)},pan:function(t,e,r){c.pan(c.lastT(),t,e,r)},translate:function(t,e,r){c.translate(c.lastT(),t,e,r)}};return Object.defineProperties(d,{matrix:{get:function(){return c.computedMatrix},set:function(t){return c.setMatrix(c.lastT(),t),c.computedMatrix},enumerable:!0},mode:{get:function(){return c.getMode()},set:function(t){var e=c.computedUp.slice(),r=c.computedEye.slice(),i=c.computedCenter.slice();if(c.setMode(t),\"turntable\"===t){var a=n();c._active.lookAt(a,r,i,e),c._active.lookAt(a+500,r,i,[0,0,1]),c._active.flush(a)}return c.getMode()},enumerable:!0},center:{get:function(){return c.computedCenter},set:function(t){return c.lookAt(c.lastT(),null,t),c.computedCenter},enumerable:!0},eye:{get:function(){return c.computedEye},set:function(t){return c.lookAt(c.lastT(),t),c.computedEye},enumerable:!0},up:{get:function(){return c.computedUp},set:function(t){return c.lookAt(c.lastT(),null,null,t),c.computedUp},enumerable:!0},distance:{get:function(){return h},set:function(t){return c.setDistance(c.lastT(),t),t},enumerable:!0},distanceLimits:{get:function(){return c.getDistanceLimits(r)},set:function(t){return c.setDistanceLimits(t),t},enumerable:!0}}),t.addEventListener(\"contextmenu\",function(t){return t.preventDefault(),!1}),d._lastX=-1,d._lastY=-1,d._lastMods={shift:!1,control:!1,alt:!1,meta:!1},d.enableMouseListeners=function(){function e(e,r,i,a){var o=d.keyBindingMode;if(!1!==o){var s=\"rotate\"===o,l=\"pan\"===o,u=\"zoom\"===o,f=!!a.control,p=!!a.alt,g=!!a.shift,v=!!(1&e),m=!!(2&e),y=!!(4&e),x=1/t.clientHeight,b=x*(r-d._lastX),_=x*(i-d._lastY),w=d.flipX?1:-1,k=d.flipY?1:-1,T=Math.PI*d.rotateSpeed,A=n();if(-1!==d._lastX&&-1!==d._lastY&&((s&&v&&!f&&!p&&!g||v&&!f&&!p&&g)&&c.rotate(A,w*T*b,-k*T*_,0),(l&&v&&!f&&!p&&!g||m||v&&f&&!p&&!g)&&c.pan(A,-d.translateSpeed*b*h,d.translateSpeed*_*h,0),u&&v&&!f&&!p&&!g||y||v&&!f&&p&&!g)){var M=-d.zoomSpeed*_/window.innerHeight*(A-c.lastT())*100;c.pan(A,0,0,h*(Math.exp(M)-1))}return d._lastX=r,d._lastY=i,d._lastMods=a,!0}}d.mouseListener=a(t,e),t.addEventListener(\"touchstart\",function(r){var n=s(r.changedTouches[0],t);e(0,n[0],n[1],d._lastMods),e(1,n[0],n[1],d._lastMods),r.preventDefault()},!!l&&{passive:!1}),t.addEventListener(\"touchmove\",function(r){var n=s(r.changedTouches[0],t);e(1,n[0],n[1],d._lastMods),r.preventDefault()},!!l&&{passive:!1}),t.addEventListener(\"touchend\",function(t){e(0,d._lastX,d._lastY,d._lastMods),t.preventDefault()},!!l&&{passive:!1}),d.wheelListener=o(t,function(t,e){if(!1!==d.keyBindingMode&&d.enableWheel){var r=d.flipX?1:-1,i=d.flipY?1:-1,a=n();if(Math.abs(t)>Math.abs(e))c.rotate(a,0,0,-t*r*Math.PI*d.rotateSpeed/window.innerWidth);else if(!d._ortho){var o=-d.zoomSpeed*i*e/window.innerHeight*(a-c.lastT())/20;c.pan(a,0,0,h*(Math.exp(o)-1))}}},!0)},d.enableMouseListeners(),d};var n=t(\"right-now\"),i=t(\"3d-view\"),a=t(\"mouse-change\"),o=t(\"mouse-wheel\"),s=t(\"mouse-event-offset\"),l=t(\"has-passive-events\")},{\"3d-view\":52,\"has-passive-events\":411,\"mouse-change\":435,\"mouse-event-offset\":436,\"mouse-wheel\":438,\"right-now\":504}],289:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\nattribute vec2 position;\\nvarying vec2 uv;\\nvoid main() {\\n  uv = position;\\n  gl_Position = vec4(position, 0, 1);\\n}\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D accumBuffer;\\nvarying vec2 uv;\\n\\nvoid main() {\\n  vec4 accum = texture2D(accumBuffer, 0.5 * (uv + 1.0));\\n  gl_FragColor = min(vec4(1,1,1,1), accum);\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec2\"}])}},{\"gl-shader\":301,glslify:409}],290:[function(t,e,r){\"use strict\";var n=t(\"./camera.js\"),i=t(\"gl-axes3d\"),a=t(\"gl-axes3d/properties\"),o=t(\"gl-spikes3d\"),s=t(\"gl-select-static\"),l=t(\"gl-fbo\"),c=t(\"a-big-triangle\"),u=t(\"mouse-change\"),h=t(\"mouse-wheel\"),f=t(\"gl-mat4/perspective\"),p=t(\"gl-mat4/ortho\"),d=t(\"./lib/shader\"),g=t(\"is-mobile\")({tablet:!0});function v(){this.mouse=[-1,-1],this.screen=null,this.distance=1/0,this.index=null,this.dataCoordinate=null,this.dataPosition=null,this.object=null,this.data=null}function m(t){var e=Math.round(Math.log(Math.abs(t))/Math.log(10));if(e<0){var r=Math.round(Math.pow(10,-e));return Math.ceil(t*r)/r}if(e>0){r=Math.round(Math.pow(10,e));return Math.ceil(t/r)*r}return Math.ceil(t)}function y(t){return\"boolean\"!=typeof t||t}e.exports={createScene:function(t){(t=t||{}).camera=t.camera||{};var e=t.canvas;if(!e)if(e=document.createElement(\"canvas\"),t.container){var r=t.container;r.appendChild(e)}else document.body.appendChild(e);var x=t.gl;x||(x=function(t,e){var r=null;try{(r=t.getContext(\"webgl\",e))||(r=t.getContext(\"experimental-webgl\",e))}catch(t){return null}return r}(e,t.glOptions||{premultipliedAlpha:!0,antialias:!0,preserveDrawingBuffer:g}));if(!x)throw new Error(\"webgl not supported\");var b=t.bounds||[[-10,-10,-10],[10,10,10]],_=new v,w=l(x,[x.drawingBufferWidth,x.drawingBufferHeight],{preferFloat:!g}),k=d(x),T=t.cameraObject&&!0===t.cameraObject._ortho||t.camera.projection&&\"orthographic\"===t.camera.projection.type||!1,A={eye:t.camera.eye||[2,0,0],center:t.camera.center||[0,0,0],up:t.camera.up||[0,1,0],zoomMin:t.camera.zoomMax||.1,zoomMax:t.camera.zoomMin||100,mode:t.camera.mode||\"turntable\",_ortho:T},M=t.axes||{},S=i(x,M);S.enable=!M.disable;var E=t.spikes||{},C=o(x,E),L=[],P=[],O=[],z=[],I=!0,D=!0,R=new Array(16),F=new Array(16),B={view:null,projection:R,model:F,_ortho:!1},D=!0,N=[x.drawingBufferWidth,x.drawingBufferHeight],j=t.cameraObject||n(e,A),U={gl:x,contextLost:!1,pixelRatio:t.pixelRatio||1,canvas:e,selection:_,camera:j,axes:S,axesPixels:null,spikes:C,bounds:b,objects:L,shape:N,aspect:t.aspectRatio||[1,1,1],pickRadius:t.pickRadius||10,zNear:t.zNear||.01,zFar:t.zFar||1e3,fovy:t.fovy||Math.PI/4,clearColor:t.clearColor||[0,0,0,0],autoResize:y(t.autoResize),autoBounds:y(t.autoBounds),autoScale:!!t.autoScale,autoCenter:y(t.autoCenter),clipToBounds:y(t.clipToBounds),snapToData:!!t.snapToData,onselect:t.onselect||null,onrender:t.onrender||null,onclick:t.onclick||null,cameraParams:B,oncontextloss:null,mouseListener:null,_stopped:!1},V=[x.drawingBufferWidth/U.pixelRatio|0,x.drawingBufferHeight/U.pixelRatio|0];function q(){if(!U._stopped&&U.autoResize){var t=e.parentNode,r=1,n=1;t&&t!==document.body?(r=t.clientWidth,n=t.clientHeight):(r=window.innerWidth,n=window.innerHeight);var i=0|Math.ceil(r*U.pixelRatio),a=0|Math.ceil(n*U.pixelRatio);if(i!==e.width||a!==e.height){e.width=i,e.height=a;var o=e.style;o.position=o.position||\"absolute\",o.left=\"0px\",o.top=\"0px\",o.width=r+\"px\",o.height=n+\"px\",I=!0}}}U.autoResize&&q();function H(){for(var t=L.length,e=z.length,r=0;r<e;++r)O[r]=0;t:for(var r=0;r<t;++r){var n=L[r],i=n.pickSlots;if(i){for(var a=0;a<e;++a)if(O[a]+i<255){P[r]=a,n.setPickBase(O[a]+1),O[a]+=i;continue t}var o=s(x,N);P[r]=e,z.push(o),O.push(i),n.setPickBase(1),e+=1}else P[r]=-1}for(;e>0&&0===O[e-1];)O.pop(),z.pop().dispose()}function G(){if(U.contextLost)return!0;x.isContextLost()&&(U.contextLost=!0,U.mouseListener.enabled=!1,U.selection.object=null,U.oncontextloss&&U.oncontextloss())}window.addEventListener(\"resize\",q),U.update=function(t){U._stopped||(t=t||{},I=!0,D=!0)},U.add=function(t){U._stopped||(t.axes=S,L.push(t),P.push(-1),I=!0,D=!0,H())},U.remove=function(t){if(!U._stopped){var e=L.indexOf(t);e<0||(L.splice(e,1),P.pop(),I=!0,D=!0,H())}},U.dispose=function(){if(!U._stopped&&(U._stopped=!0,window.removeEventListener(\"resize\",q),e.removeEventListener(\"webglcontextlost\",G),U.mouseListener.enabled=!1,!U.contextLost)){S.dispose(),C.dispose();for(var t=0;t<L.length;++t)L[t].dispose();w.dispose();for(var t=0;t<z.length;++t)z[t].dispose();k.dispose(),x=null,S=null,C=null,L=[]}},U.wheelListener=h(e,function(t,e){if(!1!==j.keyBindingMode&&j.enableWheel&&j._ortho){var r=t>e?1.1:1/1.1;U.aspect[0]*=r,U.aspect[1]*=r,U.aspect[2]*=r,U.redraw()}},!0),U._mouseRotating=!1,U._prevButtons=0,U.enableMouseListeners=function(){U.mouseListener=u(e,function(t,e,r){if(!U._stopped){var n=z.length,i=L.length,a=_.object;_.distance=1/0,_.mouse[0]=e,_.mouse[1]=r,_.object=null,_.screen=null,_.dataCoordinate=_.dataPosition=null;var o=!1;if(t&&U._prevButtons)U._mouseRotating=!0;else{U._mouseRotating&&(D=!0),U._mouseRotating=!1;for(var s=0;s<n;++s){var l=z[s].query(e,V[1]-r-1,U.pickRadius);if(l){if(l.distance>_.distance)continue;for(var c=0;c<i;++c){var u=L[c];if(P[c]===s){var h=u.pick(l);h&&(_.buttons=t,_.screen=l.coord,_.distance=l.distance,_.object=u,_.index=h.distance,_.dataPosition=h.position,_.dataCoordinate=h.dataCoordinate,_.data=h,o=!0)}}}}}a&&a!==_.object&&(a.highlight&&a.highlight(null),I=!0),_.object&&(_.object.highlight&&_.object.highlight(_.data),I=!0),(o=o||_.object!==a)&&U.onselect&&U.onselect(_),1&t&&!(1&U._prevButtons)&&U.onclick&&U.onclick(_),U._prevButtons=t}})},e.addEventListener(\"webglcontextlost\",G);var Y=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],W=[Y[0].slice(),Y[1].slice()];function X(){if(!G()){q();var t=U.camera.tick();B.view=U.camera.matrix,I=I||t,D=D||t,S.pixelRatio=U.pixelRatio,C.pixelRatio=U.pixelRatio;var e=L.length,r=Y[0],n=Y[1];r[0]=r[1]=r[2]=1/0,n[0]=n[1]=n[2]=-1/0;for(var i=0;i<e;++i){var o=L[i];o.pixelRatio=U.pixelRatio,o.axes=U.axes,I=I||!!o.dirty,D=D||!!o.dirty;var s=o.bounds;if(s)for(var l=s[0],u=s[1],h=0;h<3;++h)r[h]=Math.min(r[h],l[h]),n[h]=Math.max(n[h],u[h])}var d=U.bounds;if(U.autoBounds)for(var h=0;h<3;++h){if(n[h]<r[h])r[h]=-1,n[h]=1;else{r[h]===n[h]&&(r[h]-=1,n[h]+=1);var g=.05*(n[h]-r[h]);r[h]=r[h]-g,n[h]=n[h]+g}d[0][h]=r[h],d[1][h]=n[h]}for(var v=!1,h=0;h<3;++h)v=v||W[0][h]!==d[0][h]||W[1][h]!==d[1][h],W[0][h]=d[0][h],W[1][h]=d[1][h];if(D=D||v,I=I||v){if(v){for(var y=[0,0,0],i=0;i<3;++i)y[i]=m((d[1][i]-d[0][i])/10);S.autoTicks?S.update({bounds:d,tickSpacing:y}):S.update({bounds:d})}var b=x.drawingBufferWidth,A=x.drawingBufferHeight;N[0]=b,N[1]=A,V[0]=0|Math.max(b/U.pixelRatio,1),V[1]=0|Math.max(A/U.pixelRatio,1),T?(p(R,-b/A,b/A,-1,1,U.zNear,U.zFar),B._ortho=!0):(f(R,U.fovy,b/A,U.zNear,U.zFar),B._ortho=!1);for(var i=0;i<16;++i)F[i]=0;F[15]=1;for(var M=0,i=0;i<3;++i)M=Math.max(M,d[1][i]-d[0][i]);for(var i=0;i<3;++i)U.autoScale?F[5*i]=U.aspect[i]/(d[1][i]-d[0][i]):F[5*i]=1/M,U.autoCenter&&(F[12+i]=.5*-F[5*i]*(d[0][i]+d[1][i]));for(var i=0;i<e;++i){var o=L[i];o.axesBounds=d,U.clipToBounds&&(o.clipBounds=d)}_.object&&(U.snapToData?C.position=_.dataCoordinate:C.position=_.dataPosition,C.bounds=d),D&&(D=!1,function(){if(G())return;x.colorMask(!0,!0,!0,!0),x.depthMask(!0),x.disable(x.BLEND),x.enable(x.DEPTH_TEST);for(var t=L.length,e=z.length,r=0;r<e;++r){var n=z[r];n.shape=V,n.begin();for(var i=0;i<t;++i)if(P[i]===r){var a=L[i];a.drawPick&&(a.pixelRatio=1,a.drawPick(B))}n.end()}}()),U.axesPixels=a(U.axes,B,b,A),U.onrender&&U.onrender(),x.bindFramebuffer(x.FRAMEBUFFER,null),x.viewport(0,0,b,A);var E=U.clearColor;x.clearColor(E[0],E[1],E[2],E[3]),x.clear(x.COLOR_BUFFER_BIT|x.DEPTH_BUFFER_BIT),x.depthMask(!0),x.colorMask(!0,!0,!0,!0),x.enable(x.DEPTH_TEST),x.depthFunc(x.LEQUAL),x.disable(x.BLEND),x.disable(x.CULL_FACE);var O=!1;S.enable&&(O=O||S.isTransparent(),S.draw(B)),C.axes=S,_.object&&C.draw(B),x.disable(x.CULL_FACE);for(var i=0;i<e;++i){var o=L[i];o.axes=S,o.pixelRatio=U.pixelRatio,o.isOpaque&&o.isOpaque()&&o.draw(B),o.isTransparent&&o.isTransparent()&&(O=!0)}if(O){w.shape=N,w.bind(),x.clear(x.DEPTH_BUFFER_BIT),x.colorMask(!1,!1,!1,!1),x.depthMask(!0),x.depthFunc(x.LESS),S.enable&&S.isTransparent()&&S.drawTransparent(B);for(var i=0;i<e;++i){var o=L[i];o.isOpaque&&o.isOpaque()&&o.draw(B)}x.enable(x.BLEND),x.blendEquation(x.FUNC_ADD),x.blendFunc(x.ONE,x.ONE_MINUS_SRC_ALPHA),x.colorMask(!0,!0,!0,!0),x.depthMask(!1),x.clearColor(0,0,0,0),x.clear(x.COLOR_BUFFER_BIT),S.isTransparent()&&S.drawTransparent(B);for(var i=0;i<e;++i){var o=L[i];o.isTransparent&&o.isTransparent()&&o.drawTransparent(B)}x.bindFramebuffer(x.FRAMEBUFFER,null),x.blendFunc(x.ONE,x.ONE_MINUS_SRC_ALPHA),x.disable(x.DEPTH_TEST),k.bind(),w.color[0].bind(0),k.uniforms.accumBuffer=0,c(x),x.disable(x.BLEND)}I=!1;for(var i=0;i<e;++i)L[i].dirty=!1}}}return U.enableMouseListeners(),function t(){U._stopped||U.contextLost||(X(),requestAnimationFrame(t))}(),U.redraw=function(){U._stopped||(I=!0,X())},U},createCamera:n}},{\"./camera.js\":288,\"./lib/shader\":289,\"a-big-triangle\":59,\"gl-axes3d\":233,\"gl-axes3d/properties\":240,\"gl-fbo\":249,\"gl-mat4/ortho\":268,\"gl-mat4/perspective\":269,\"gl-select-static\":300,\"gl-spikes3d\":310,\"is-mobile\":420,\"mouse-change\":435,\"mouse-wheel\":438}],291:[function(t,e,r){var n=t(\"glslify\");r.pointVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform float pointCloud;\\n\\nhighp float rand(vec2 co) {\\n  highp float a = 12.9898;\\n  highp float b = 78.233;\\n  highp float c = 43758.5453;\\n  highp float d = dot(co.xy, vec2(a, b));\\n  highp float e = mod(d, 3.14);\\n  return fract(sin(e) * c);\\n}\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n    // if we don't jitter the point size a bit, overall point cloud\\n    // saturation 'jumps' on zooming, which is disturbing and confusing\\n  gl_PointSize = pointSize * ((19.5 + rand(position)) / 20.0);\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    // get the same square surface as circle would be\\n    gl_PointSize *= 0.886;\\n  }\\n}\"]),r.pointFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color, borderColor;\\nuniform float centerFraction;\\nuniform float pointCloud;\\n\\nvoid main() {\\n  float radius;\\n  vec4 baseColor;\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    if(centerFraction == 1.0) {\\n      gl_FragColor = color;\\n    } else {\\n      gl_FragColor = mix(borderColor, color, centerFraction);\\n    }\\n  } else {\\n    radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n    if(radius > 1.0) {\\n      discard;\\n    }\\n    baseColor = mix(borderColor, color, step(radius, centerFraction));\\n    gl_FragColor = vec4(baseColor.rgb * baseColor.a, baseColor.a);\\n  }\\n}\\n\"]),r.pickVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform vec4 pickOffset;\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n  gl_PointSize = pointSize;\\n\\n  vec4 id = pickId + pickOffset;\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  fragId = id;\\n}\\n\"]),r.pickFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  float radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n  if(radius > 1.0) {\\n    discard;\\n  }\\n  gl_FragColor = fragId / 255.0;\\n}\\n\"])},{glslify:409}],292:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"typedarray-pool\"),o=t(\"./lib/shader\");function s(t,e,r,n,i){this.plot=t,this.offsetBuffer=e,this.pickBuffer=r,this.shader=n,this.pickShader=i,this.sizeMin=.5,this.sizeMinCap=2,this.sizeMax=20,this.areaRatio=1,this.pointCount=0,this.color=[1,0,0,1],this.borderColor=[0,0,0,1],this.blend=!1,this.pickOffset=0,this.points=null}e.exports=function(t,e){var r=t.gl,a=i(r),l=i(r),c=n(r,o.pointVertex,o.pointFragment),u=n(r,o.pickVertex,o.pickFragment),h=new s(t,a,l,c,u);return h.update(e),t.addObject(h),h};var l,c,u=s.prototype;u.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.offsetBuffer.dispose(),this.pickBuffer.dispose(),this.plot.removeObject(this)},u.update=function(t){var e;function r(e,r){return e in t?t[e]:r}t=t||{},this.sizeMin=r(\"sizeMin\",.5),this.sizeMax=r(\"sizeMax\",20),this.color=r(\"color\",[1,0,0,1]).slice(),this.areaRatio=r(\"areaRatio\",1),this.borderColor=r(\"borderColor\",[0,0,0,1]).slice(),this.blend=r(\"blend\",!1);var n=t.positions.length>>>1,i=t.positions instanceof Float32Array,o=t.idToIndex instanceof Int32Array&&t.idToIndex.length>=n,s=t.positions,l=i?s:a.mallocFloat32(s.length),c=o?t.idToIndex:a.mallocInt32(n);if(i||l.set(s),!o)for(l.set(s),e=0;e<n;e++)c[e]=e;this.points=s,this.offsetBuffer.update(l),this.pickBuffer.update(c),i||a.free(l),o||a.free(c),this.pointCount=n,this.pickOffset=0},u.unifiedDraw=(l=[1,0,0,0,1,0,0,0,1],c=[0,0,0,0],function(t){var e=void 0!==t,r=e?this.pickShader:this.shader,n=this.plot.gl,i=this.plot.dataBox;if(0===this.pointCount)return t;var a=i[2]-i[0],o=i[3]-i[1],s=function(t,e){var r,n=0,i=t.length>>>1;for(r=0;r<i;r++){var a=t[2*r],o=t[2*r+1];a>=e[0]&&a<=e[2]&&o>=e[1]&&o<=e[3]&&n++}return n}(this.points,i),u=this.plot.pickPixelRatio*Math.max(Math.min(this.sizeMinCap,this.sizeMin),Math.min(this.sizeMax,this.sizeMax/Math.pow(s,.33333)));l[0]=2/a,l[4]=2/o,l[6]=-2*i[0]/a-1,l[7]=-2*i[1]/o-1,this.offsetBuffer.bind(),r.bind(),r.attributes.position.pointer(),r.uniforms.matrix=l,r.uniforms.color=this.color,r.uniforms.borderColor=this.borderColor,r.uniforms.pointCloud=u<5,r.uniforms.pointSize=u,r.uniforms.centerFraction=Math.min(1,Math.max(0,Math.sqrt(1-this.areaRatio))),e&&(c[0]=255&t,c[1]=t>>8&255,c[2]=t>>16&255,c[3]=t>>24&255,this.pickBuffer.bind(),r.attributes.pickId.pointer(n.UNSIGNED_BYTE),r.uniforms.pickOffset=c,this.pickOffset=t);var h=n.getParameter(n.BLEND),f=n.getParameter(n.DITHER);return h&&!this.blend&&n.disable(n.BLEND),f&&n.disable(n.DITHER),n.drawArrays(n.POINTS,0,this.pointCount),h&&!this.blend&&n.enable(n.BLEND),f&&n.enable(n.DITHER),t+this.pointCount}),u.draw=u.unifiedDraw,u.drawPick=u.unifiedDraw,u.pick=function(t,e,r){var n=this.pickOffset,i=this.pointCount;if(r<n||r>=n+i)return null;var a=r-n,o=this.points;return{object:this,pointId:a,dataCoord:[o[2*a],o[2*a+1]]}}},{\"./lib/shader\":291,\"gl-buffer\":241,\"gl-shader\":301,\"typedarray-pool\":545}],293:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c=e[0],u=e[1],h=e[2],f=e[3],p=r[0],d=r[1],g=r[2],v=r[3];(a=c*p+u*d+h*g+f*v)<0&&(a=-a,p=-p,d=-d,g=-g,v=-v);1-a>1e-6?(i=Math.acos(a),o=Math.sin(i),s=Math.sin((1-n)*i)/o,l=Math.sin(n*i)/o):(s=1-n,l=n);return t[0]=s*c+l*p,t[1]=s*u+l*d,t[2]=s*h+l*g,t[3]=s*f+l*v,t}},{}],294:[function(t,e,r){\"use strict\";e.exports=function(t){return t||0===t?t.toString():\"\"}},{}],295:[function(t,e,r){\"use strict\";var n=t(\"vectorize-text\");e.exports=function(t,e,r){var a=i[e];a||(a=i[e]={});if(t in a)return a[t];var o={textAlign:\"center\",textBaseline:\"middle\",lineHeight:1,font:e,lineSpacing:1.25,styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},triangles:!0},s=n(t,o);o.triangles=!1;var l,c,u=n(t,o);if(r&&1!==r){for(l=0;l<s.positions.length;++l)for(c=0;c<s.positions[l].length;++c)s.positions[l][c]/=r;for(l=0;l<u.positions.length;++l)for(c=0;c<u.positions[l].length;++c)u.positions[l][c]/=r}var h=[[1/0,1/0],[-1/0,-1/0]],f=u.positions.length;for(l=0;l<f;++l){var p=u.positions[l];for(c=0;c<2;++c)h[0][c]=Math.min(h[0][c],p[c]),h[1][c]=Math.max(h[1][c],p[c])}return a[t]=[s,u,h]};var i={}},{\"vectorize-text\":550}],296:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform vec4 highlightId;\\nuniform float highlightScale;\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = 1.0;\\n    if(distance(highlightId, id) < 0.0001) {\\n      scale = highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1);\\n    vec4 viewPosition = view * worldPosition;\\n    viewPosition = viewPosition / viewPosition.w;\\n    vec4 clipPosition = projection * (viewPosition + scale * vec4(glyph.x, -glyph.y, 0, 0));\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float highlightScale, pixelRatio;\\nuniform vec4 highlightId;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = pixelRatio;\\n    if(distance(highlightId.bgr, id.bgr) < 0.001) {\\n      scale *= highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1.0);\\n    vec4 viewPosition = view * worldPosition;\\n    vec4 clipPosition = projection * viewPosition;\\n    clipPosition /= clipPosition.w;\\n\\n    gl_Position = clipPosition + vec4(screenSize * scale * vec2(glyph.x, -glyph.y), 0.0, 0.0);\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform float highlightScale;\\nuniform vec4 highlightId;\\nuniform vec3 axes[2];\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float scale, pixelRatio;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float lscale = pixelRatio * scale;\\n    if(distance(highlightId, id) < 0.0001) {\\n      lscale *= highlightScale;\\n    }\\n\\n    vec4 clipCenter   = projection * view * model * vec4(position, 1);\\n    vec3 dataPosition = position + 0.5*lscale*(axes[0] * glyph.x + axes[1] * glyph.y) * clipCenter.w * screenSize.y;\\n    vec4 clipPosition = projection * view * model * vec4(dataPosition, 1);\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = dataPosition;\\n  }\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float opacity;\\n\\nvarying vec4 interpColor;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (\\n    outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate) ||\\n    interpColor.a * opacity == 0.\\n  ) discard;\\n  gl_FragColor = interpColor * opacity;\\n}\\n\"]),c=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float pickGroup;\\n\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate)) discard;\\n\\n  gl_FragColor = vec4(pickGroup, pickId.bgr);\\n}\"]),u=[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"glyph\",type:\"vec2\"},{name:\"id\",type:\"vec4\"}],h={vertex:a,fragment:l,attributes:u},f={vertex:o,fragment:l,attributes:u},p={vertex:s,fragment:l,attributes:u},d={vertex:a,fragment:c,attributes:u},g={vertex:o,fragment:c,attributes:u},v={vertex:s,fragment:c,attributes:u};function m(t,e){var r=n(t,e),i=r.attributes;return i.position.location=0,i.color.location=1,i.glyph.location=2,i.id.location=3,r}r.createPerspective=function(t){return m(t,h)},r.createOrtho=function(t){return m(t,f)},r.createProject=function(t){return m(t,p)},r.createPickPerspective=function(t){return m(t,d)},r.createPickOrtho=function(t){return m(t,g)},r.createPickProject=function(t){return m(t,v)}},{\"gl-shader\":301,glslify:409}],297:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"typedarray-pool\"),s=t(\"gl-mat4/multiply\"),l=t(\"./lib/shaders\"),c=t(\"./lib/glyphs\"),u=t(\"./lib/get-simple-string\"),h=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function f(t,e){var r=t[0],n=t[1],i=t[2],a=t[3];return t[0]=e[0]*r+e[4]*n+e[8]*i+e[12]*a,t[1]=e[1]*r+e[5]*n+e[9]*i+e[13]*a,t[2]=e[2]*r+e[6]*n+e[10]*i+e[14]*a,t[3]=e[3]*r+e[7]*n+e[11]*i+e[15]*a,t}function p(t,e,r,n){return f(n,n),f(n,n),f(n,n)}function d(t,e){this.index=t,this.dataCoordinate=this.position=e}function g(t){return!0===t?1:t>1?1:t}function v(t,e,r,n,i,a,o,s,l,c,u,h){this.gl=t,this.pixelRatio=1,this.shader=e,this.orthoShader=r,this.projectShader=n,this.pointBuffer=i,this.colorBuffer=a,this.glyphBuffer=o,this.idBuffer=s,this.vao=l,this.vertexCount=0,this.lineVertexCount=0,this.opacity=1,this.hasAlpha=!1,this.lineWidth=0,this.projectScale=[2/3,2/3,2/3],this.projectOpacity=[1,1,1],this.projectHasAlpha=!1,this.pickId=0,this.pickPerspectiveShader=c,this.pickOrthoShader=u,this.pickProjectShader=h,this.points=[],this._selectResult=new d(0,[0,0,0]),this.useOrtho=!0,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.axesProject=[!0,!0,!0],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.highlightId=[1,1,1,1],this.highlightScale=2,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.dirty=!0}e.exports=function(t){var e=t.gl,r=l.createPerspective(e),n=l.createOrtho(e),o=l.createProject(e),s=l.createPickPerspective(e),c=l.createPickOrtho(e),u=l.createPickProject(e),h=i(e),f=i(e),p=i(e),d=i(e),g=a(e,[{buffer:h,size:3,type:e.FLOAT},{buffer:f,size:4,type:e.FLOAT},{buffer:p,size:2,type:e.FLOAT},{buffer:d,size:4,type:e.UNSIGNED_BYTE,normalized:!0}]),m=new v(e,r,n,o,h,f,p,d,g,s,c,u);return m.update(t),m};var m=v.prototype;m.pickSlots=1,m.setPickBase=function(t){this.pickId=t},m.isTransparent=function(){if(this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&this.projectHasAlpha)return!0;return!1},m.isOpaque=function(){if(!this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&!this.projectHasAlpha)return!0;return!1};var y=[0,0],x=[0,0,0],b=[0,0,0],_=[0,0,0,1],w=[0,0,0,1],k=h.slice(),T=[0,0,0],A=[[0,0,0],[0,0,0]];function M(t){return t[0]=t[1]=t[2]=0,t}function S(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=1,t}function E(t,e,r,n){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[r]=n,t}function C(t,e,r,n){var i,a=e.axesProject,o=e.gl,l=t.uniforms,c=r.model||h,u=r.view||h,f=r.projection||h,d=e.axesBounds,g=function(t){for(var e=A,r=0;r<2;++r)for(var n=0;n<3;++n)e[r][n]=Math.max(Math.min(t[r][n],1e8),-1e8);return e}(e.clipBounds);i=e.axes&&e.axes.lastCubeProps?e.axes.lastCubeProps.axis:[1,1,1],y[0]=2/o.drawingBufferWidth,y[1]=2/o.drawingBufferHeight,t.bind(),l.view=u,l.projection=f,l.screenSize=y,l.highlightId=e.highlightId,l.highlightScale=e.highlightScale,l.clipBounds=g,l.pickGroup=e.pickId/255,l.pixelRatio=n;for(var v=0;v<3;++v)if(a[v]){l.scale=e.projectScale[v],l.opacity=e.projectOpacity[v];for(var m=k,C=0;C<16;++C)m[C]=0;for(C=0;C<4;++C)m[5*C]=1;m[5*v]=0,i[v]<0?m[12+v]=d[0][v]:m[12+v]=d[1][v],s(m,c,m),l.model=m;var L=(v+1)%3,P=(v+2)%3,O=M(x),z=M(b);O[L]=1,z[P]=1;var I=p(0,0,0,S(_,O)),D=p(0,0,0,S(w,z));if(Math.abs(I[1])>Math.abs(D[1])){var R=I;I=D,D=R,R=O,O=z,z=R;var F=L;L=P,P=F}I[0]<0&&(O[L]=-1),D[1]>0&&(z[P]=-1);var B=0,N=0;for(C=0;C<4;++C)B+=Math.pow(c[4*L+C],2),N+=Math.pow(c[4*P+C],2);O[L]/=Math.sqrt(B),z[P]/=Math.sqrt(N),l.axes[0]=O,l.axes[1]=z,l.fragClipBounds[0]=E(T,g[0],v,-1e8),l.fragClipBounds[1]=E(T,g[1],v,1e8),e.vao.bind(),e.vao.draw(o.TRIANGLES,e.vertexCount),e.lineWidth>0&&(o.lineWidth(e.lineWidth*n),e.vao.draw(o.LINES,e.lineVertexCount,e.vertexCount)),e.vao.unbind()}}var L=[[-1e8,-1e8,-1e8],[1e8,1e8,1e8]];function P(t,e,r,n,i,a,o){var s=r.gl;if((a===r.projectHasAlpha||o)&&C(e,r,n,i),a===r.hasAlpha||o){t.bind();var l=t.uniforms;l.model=n.model||h,l.view=n.view||h,l.projection=n.projection||h,y[0]=2/s.drawingBufferWidth,y[1]=2/s.drawingBufferHeight,l.screenSize=y,l.highlightId=r.highlightId,l.highlightScale=r.highlightScale,l.fragClipBounds=L,l.clipBounds=r.axes.bounds,l.opacity=r.opacity,l.pickGroup=r.pickId/255,l.pixelRatio=i,r.vao.bind(),r.vao.draw(s.TRIANGLES,r.vertexCount),r.lineWidth>0&&(s.lineWidth(r.lineWidth*i),r.vao.draw(s.LINES,r.lineVertexCount,r.vertexCount)),r.vao.unbind()}}function O(t,e,r,i){var a;a=Array.isArray(t)?e<t.length?t[e]:void 0:t,a=u(a);var o=!0;n(a)&&(a=\"\\u25bc\",o=!1);var s=c(a,r,i);return{mesh:s[0],lines:s[1],bounds:s[2],visible:o}}m.draw=function(t){P(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!1,!1)},m.drawTransparent=function(t){P(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!0,!1)},m.drawPick=function(t){P(this.useOrtho?this.pickOrthoShader:this.pickPerspectiveShader,this.pickProjectShader,this,t,1,!0,!0)},m.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[2]+(t.value[1]<<8)+(t.value[0]<<16);if(e>=this.pointCount||e<0)return null;var r=this.points[e],n=this._selectResult;n.index=e;for(var i=0;i<3;++i)n.position[i]=n.dataCoordinate[i]=r[i];return n},m.highlight=function(t){if(t){var e=t.index,r=255&e,n=e>>8&255,i=e>>16&255;this.highlightId=[r/255,n/255,i/255,0]}else this.highlightId=[1,1,1,1]},m.update=function(t){if(\"perspective\"in(t=t||{})&&(this.useOrtho=!t.perspective),\"orthographic\"in t&&(this.useOrtho=!!t.orthographic),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"project\"in t)if(Array.isArray(t.project))this.axesProject=t.project;else{var e=!!t.project;this.axesProject=[e,e,e]}if(\"projectScale\"in t)if(Array.isArray(t.projectScale))this.projectScale=t.projectScale.slice();else{var r=+t.projectScale;this.projectScale=[r,r,r]}if(this.projectHasAlpha=!1,\"projectOpacity\"in t){if(Array.isArray(t.projectOpacity))this.projectOpacity=t.projectOpacity.slice();else{r=+t.projectOpacity;this.projectOpacity=[r,r,r]}for(var n=0;n<3;++n)this.projectOpacity[n]=g(this.projectOpacity[n]),this.projectOpacity[n]<1&&(this.projectHasAlpha=!0)}this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=g(t.opacity),this.opacity<1&&(this.hasAlpha=!0)),this.dirty=!0;var i,a,s=t.position,l=t.font||\"normal\",c=t.alignment||[0,0];if(2===c.length)i=c[0],a=c[1];else{i=[],a=[];for(n=0;n<c.length;++n)i[n]=c[n][0],a[n]=c[n][1]}var u=[1/0,1/0,1/0],h=[-1/0,-1/0,-1/0],f=t.glyph,p=t.color,d=t.size,v=t.angle,m=t.lineColor,y=-1,x=0,b=0,_=0;if(s.length){_=s.length;t:for(n=0;n<_;++n){for(var w=s[n],k=0;k<3;++k)if(isNaN(w[k])||!isFinite(w[k]))continue t;var T=(N=O(f,n,l,this.pixelRatio)).mesh,A=N.lines,M=N.bounds;x+=3*T.cells.length,b+=2*A.edges.length}}var S=x+b,E=o.mallocFloat(3*S),C=o.mallocFloat(4*S),L=o.mallocFloat(2*S),P=o.mallocUint32(S);if(S>0){var z=0,I=x,D=[0,0,0,1],R=[0,0,0,1],F=Array.isArray(p)&&Array.isArray(p[0]),B=Array.isArray(m)&&Array.isArray(m[0]);t:for(n=0;n<_;++n){y+=1;for(w=s[n],k=0;k<3;++k){if(isNaN(w[k])||!isFinite(w[k]))continue t;h[k]=Math.max(h[k],w[k]),u[k]=Math.min(u[k],w[k])}T=(N=O(f,n,l,this.pixelRatio)).mesh,A=N.lines,M=N.bounds;var N,j=N.visible;if(j)if(Array.isArray(p)){if(3===(U=F?n<p.length?p[n]:[0,0,0,0]:p).length){for(k=0;k<3;++k)D[k]=U[k];D[3]=1}else if(4===U.length){for(k=0;k<4;++k)D[k]=U[k];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else D[0]=D[1]=D[2]=0,D[3]=1;else D=[1,1,1,0];if(j)if(Array.isArray(m)){var U;if(3===(U=B?n<m.length?m[n]:[0,0,0,0]:m).length){for(k=0;k<3;++k)R[k]=U[k];R[k]=1}else if(4===U.length){for(k=0;k<4;++k)R[k]=U[k];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else R[0]=R[1]=R[2]=0,R[3]=1;else R=[1,1,1,0];var V=.5;j?Array.isArray(d)?V=n<d.length?+d[n]:12:d?V=+d:this.useOrtho&&(V=12):V=0;var q=0;Array.isArray(v)?q=n<v.length?+v[n]:0:v&&(q=+v);var H=Math.cos(q),G=Math.sin(q);for(w=s[n],k=0;k<3;++k)h[k]=Math.max(h[k],w[k]),u[k]=Math.min(u[k],w[k]);var Y=i,W=a;Y=0;Array.isArray(i)?Y=n<i.length?i[n]:0:i&&(Y=i);W=0;Array.isArray(a)?W=n<a.length?a[n]:0:a&&(W=a);var X=[Y*=Y>0?1-M[0][0]:Y<0?1+M[1][0]:1,W*=W>0?1-M[0][1]:W<0?1+M[1][1]:1],Z=T.cells||[],J=T.positions||[];for(k=0;k<Z.length;++k)for(var K=Z[k],$=0;$<3;++$){for(var Q=0;Q<3;++Q)E[3*z+Q]=w[Q];for(Q=0;Q<4;++Q)C[4*z+Q]=D[Q];P[z]=y;var tt=J[K[$]];L[2*z]=V*(H*tt[0]-G*tt[1]+X[0]),L[2*z+1]=V*(G*tt[0]+H*tt[1]+X[1]),z+=1}for(Z=A.edges,J=A.positions,k=0;k<Z.length;++k)for(K=Z[k],$=0;$<2;++$){for(Q=0;Q<3;++Q)E[3*I+Q]=w[Q];for(Q=0;Q<4;++Q)C[4*I+Q]=R[Q];P[I]=y;tt=J[K[$]];L[2*I]=V*(H*tt[0]-G*tt[1]+X[0]),L[2*I+1]=V*(G*tt[0]+H*tt[1]+X[1]),I+=1}}}this.bounds=[u,h],this.points=s,this.pointCount=s.length,this.vertexCount=x,this.lineVertexCount=b,this.pointBuffer.update(E),this.colorBuffer.update(C),this.glyphBuffer.update(L),this.idBuffer.update(P),o.free(E),o.free(C),o.free(L),o.free(P)},m.dispose=function(){this.shader.dispose(),this.orthoShader.dispose(),this.pickPerspectiveShader.dispose(),this.pickOrthoShader.dispose(),this.vao.dispose(),this.pointBuffer.dispose(),this.colorBuffer.dispose(),this.glyphBuffer.dispose(),this.idBuffer.dispose()}},{\"./lib/get-simple-string\":294,\"./lib/glyphs\":295,\"./lib/shaders\":296,\"gl-buffer\":241,\"gl-mat4/multiply\":267,\"gl-vao\":327,\"is-string-blank\":423,\"typedarray-pool\":545}],298:[function(t,e,r){\"use strict\";var n=t(\"glslify\");r.boxVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 vertex;\\n\\nuniform vec2 cornerA, cornerB;\\n\\nvoid main() {\\n  gl_Position = vec4(mix(cornerA, cornerB, vertex), 0, 1);\\n}\\n\"]),r.boxFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\n\\nvoid main() {\\n  gl_FragColor = color;\\n}\\n\"])},{glslify:409}],299:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"./lib/shaders\");function o(t,e,r){this.plot=t,this.boxBuffer=e,this.boxShader=r,this.enabled=!0,this.selectBox=[1/0,1/0,-1/0,-1/0],this.borderColor=[0,0,0,1],this.innerFill=!1,this.innerColor=[0,0,0,.25],this.outerFill=!0,this.outerColor=[0,0,0,.5],this.borderWidth=10}e.exports=function(t,e){var r=t.gl,s=i(r,[0,0,0,1,1,0,1,1]),l=n(r,a.boxVertex,a.boxFragment),c=new o(t,s,l);return c.update(e),t.addOverlay(c),c};var s=o.prototype;s.draw=function(){if(this.enabled){var t=this.plot,e=this.selectBox,r=this.borderWidth,n=(this.innerFill,this.innerColor),i=(this.outerFill,this.outerColor),a=this.borderColor,o=t.box,s=t.screenBox,l=t.dataBox,c=t.viewBox,u=t.pixelRatio,h=(e[0]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],f=(e[1]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1],p=(e[2]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],d=(e[3]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1];if(h=Math.max(h,c[0]),f=Math.max(f,c[1]),p=Math.min(p,c[2]),d=Math.min(d,c[3]),!(p<h||d<f)){o.bind();var g=s[2]-s[0],v=s[3]-s[1];if(this.outerFill&&(o.drawBox(0,0,g,f,i),o.drawBox(0,f,h,d,i),o.drawBox(0,d,g,v,i),o.drawBox(p,f,g,d,i)),this.innerFill&&o.drawBox(h,f,p,d,n),r>0){var m=r*u;o.drawBox(h-m,f-m,p+m,f+m,a),o.drawBox(h-m,d-m,p+m,d+m,a),o.drawBox(h-m,f-m,h+m,d+m,a),o.drawBox(p-m,f-m,p+m,d+m,a)}}}},s.update=function(t){t=t||{},this.innerFill=!!t.innerFill,this.outerFill=!!t.outerFill,this.innerColor=(t.innerColor||[0,0,0,.5]).slice(),this.outerColor=(t.outerColor||[0,0,0,.5]).slice(),this.borderColor=(t.borderColor||[0,0,0,1]).slice(),this.borderWidth=t.borderWidth||0,this.selectBox=(t.selectBox||this.selectBox).slice()},s.dispose=function(){this.boxBuffer.dispose(),this.boxShader.dispose(),this.plot.removeOverlay(this)}},{\"./lib/shaders\":298,\"gl-buffer\":241,\"gl-shader\":301}],300:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=n(t,e),a=i.mallocUint8(e[0]*e[1]*4);return new c(t,r,a)};var n=t(\"gl-fbo\"),i=t(\"typedarray-pool\"),a=t(\"ndarray\"),o=t(\"bit-twiddle\").nextPow2,s=t(\"cwise/lib/wrapper\")({args:[\"array\",{offset:[0,0,1],array:0},{offset:[0,0,2],array:0},{offset:[0,0,3],array:0},\"scalar\",\"scalar\",\"index\"],pre:{body:\"{this_closestD2=1e8,this_closestX=-1,this_closestY=-1}\",args:[],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[]},body:{body:\"{if(_inline_16_arg0_<255||_inline_16_arg1_<255||_inline_16_arg2_<255||_inline_16_arg3_<255){var _inline_16_l=_inline_16_arg4_-_inline_16_arg6_[0],_inline_16_a=_inline_16_arg5_-_inline_16_arg6_[1],_inline_16_f=_inline_16_l*_inline_16_l+_inline_16_a*_inline_16_a;_inline_16_f<this_closestD2&&(this_closestD2=_inline_16_f,this_closestX=_inline_16_arg6_[0],this_closestY=_inline_16_arg6_[1])}}\",args:[{name:\"_inline_16_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg4_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg5_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg6_\",lvalue:!1,rvalue:!0,count:4}],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[\"_inline_16_a\",\"_inline_16_f\",\"_inline_16_l\"]},post:{body:\"{return[this_closestX,this_closestY,this_closestD2]}\",args:[],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[]},debug:!1,funcName:\"cwise\",blockSize:64});function l(t,e,r,n,i){this.coord=[t,e],this.id=r,this.value=n,this.distance=i}function c(t,e,r){this.gl=t,this.fbo=e,this.buffer=r,this._readTimeout=null;var n=this;this._readCallback=function(){n.gl&&(e.bind(),t.readPixels(0,0,e.shape[0],e.shape[1],t.RGBA,t.UNSIGNED_BYTE,n.buffer),n._readTimeout=null)}}var u=c.prototype;Object.defineProperty(u,\"shape\",{get:function(){return this.gl?this.fbo.shape.slice():[0,0]},set:function(t){if(this.gl){this.fbo.shape=t;var e=this.fbo.shape[0],r=this.fbo.shape[1];if(r*e*4>this.buffer.length){i.free(this.buffer);for(var n=this.buffer=i.mallocUint8(o(r*e*4)),a=0;a<r*e*4;++a)n[a]=255}return t}}}),u.begin=function(){var t=this.gl;this.shape;t&&(this.fbo.bind(),t.clearColor(1,1,1,1),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT))},u.end=function(){var t=this.gl;t&&(t.bindFramebuffer(t.FRAMEBUFFER,null),this._readTimeout||clearTimeout(this._readTimeout),this._readTimeout=setTimeout(this._readCallback,1))},u.query=function(t,e,r){if(!this.gl)return null;var n=this.fbo.shape.slice();t|=0,e|=0,\"number\"!=typeof r&&(r=1);var i=0|Math.min(Math.max(t-r,0),n[0]),o=0|Math.min(Math.max(t+r,0),n[0]),c=0|Math.min(Math.max(e-r,0),n[1]),u=0|Math.min(Math.max(e+r,0),n[1]);if(o<=i||u<=c)return null;var h=[o-i,u-c],f=a(this.buffer,[h[0],h[1],4],[4,4*n[0],1],4*(i+n[0]*c)),p=s(f.hi(h[0],h[1],1),r,r),d=p[0],g=p[1];return d<0||Math.pow(this.radius,2)<p[2]?null:new l(d+i|0,g+c|0,f.get(d,g,0),[f.get(d,g,1),f.get(d,g,2),f.get(d,g,3)],Math.sqrt(p[2]))},u.dispose=function(){this.gl&&(this.fbo.dispose(),i.free(this.buffer),this.gl=null,this._readTimeout&&clearTimeout(this._readTimeout))}},{\"bit-twiddle\":92,\"cwise/lib/wrapper\":149,\"gl-fbo\":249,ndarray:450,\"typedarray-pool\":545}],301:[function(t,e,r){\"use strict\";var n=t(\"./lib/create-uniforms\"),i=t(\"./lib/create-attributes\"),a=t(\"./lib/reflect\"),o=t(\"./lib/shader-cache\"),s=t(\"./lib/runtime-reflect\"),l=t(\"./lib/GLError\");function c(t){this.gl=t,this.gl.lastAttribCount=0,this._vref=this._fref=this._relink=this.vertShader=this.fragShader=this.program=this.attributes=this.uniforms=this.types=null}var u=c.prototype;function h(t,e){return t.name<e.name?-1:1}u.bind=function(){var t;this.program||this._relink();var e=this.gl.getProgramParameter(this.program,this.gl.ACTIVE_ATTRIBUTES),r=this.gl.lastAttribCount;if(e>r)for(t=r;t<e;t++)this.gl.enableVertexAttribArray(t);else if(r>e)for(t=e;t<r;t++)this.gl.disableVertexAttribArray(t);this.gl.lastAttribCount=e,this.gl.useProgram(this.program)},u.dispose=function(){for(var t=this.gl.lastAttribCount,e=0;e<t;e++)this.gl.disableVertexAttribArray(e);this.gl.lastAttribCount=0,this._fref&&this._fref.dispose(),this._vref&&this._vref.dispose(),this.attributes=this.types=this.vertShader=this.fragShader=this.program=this._relink=this._fref=this._vref=null},u.update=function(t,e,r,c){if(!e||1===arguments.length){var u=t;t=u.vertex,e=u.fragment,r=u.uniforms,c=u.attributes}var f=this,p=f.gl,d=f._vref;f._vref=o.shader(p,p.VERTEX_SHADER,t),d&&d.dispose(),f.vertShader=f._vref.shader;var g=this._fref;if(f._fref=o.shader(p,p.FRAGMENT_SHADER,e),g&&g.dispose(),f.fragShader=f._fref.shader,!r||!c){var v=p.createProgram();if(p.attachShader(v,f.fragShader),p.attachShader(v,f.vertShader),p.linkProgram(v),!p.getProgramParameter(v,p.LINK_STATUS)){var m=p.getProgramInfoLog(v);throw new l(m,\"Error linking program:\"+m)}r=r||s.uniforms(p,v),c=c||s.attributes(p,v),p.deleteProgram(v)}(c=c.slice()).sort(h);var y,x=[],b=[],_=[];for(y=0;y<c.length;++y){var w=c[y];if(w.type.indexOf(\"mat\")>=0){for(var k=0|w.type.charAt(w.type.length-1),T=new Array(k),A=0;A<k;++A)T[A]=_.length,b.push(w.name+\"[\"+A+\"]\"),\"number\"==typeof w.location?_.push(w.location+A):Array.isArray(w.location)&&w.location.length===k&&\"number\"==typeof w.location[A]?_.push(0|w.location[A]):_.push(-1);x.push({name:w.name,type:w.type,locations:T})}else x.push({name:w.name,type:w.type,locations:[_.length]}),b.push(w.name),\"number\"==typeof w.location?_.push(0|w.location):_.push(-1)}var M=0;for(y=0;y<_.length;++y)if(_[y]<0){for(;_.indexOf(M)>=0;)M+=1;_[y]=M}var S=new Array(r.length);function E(){f.program=o.program(p,f._vref,f._fref,b,_);for(var t=0;t<r.length;++t)S[t]=p.getUniformLocation(f.program,r[t].name)}E(),f._relink=E,f.types={uniforms:a(r),attributes:a(c)},f.attributes=i(p,f,x,_),Object.defineProperty(f,\"uniforms\",n(p,f,r,S))},e.exports=function(t,e,r,n,i){var a=new c(t);return a.update(e,r,n,i),a}},{\"./lib/GLError\":302,\"./lib/create-attributes\":303,\"./lib/create-uniforms\":304,\"./lib/reflect\":305,\"./lib/runtime-reflect\":306,\"./lib/shader-cache\":307}],302:[function(t,e,r){function n(t,e,r){this.shortMessage=e||\"\",this.longMessage=r||\"\",this.rawError=t||\"\",this.message=\"gl-shader: \"+(e||t||\"\")+(r?\"\\n\"+r:\"\"),this.stack=(new Error).stack}n.prototype=new Error,n.prototype.name=\"GLError\",n.prototype.constructor=n,e.exports=n},{}],303:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){for(var a={},l=0,c=r.length;l<c;++l){var u=r[l],h=u.name,f=u.type,p=u.locations;switch(f){case\"bool\":case\"int\":case\"float\":o(t,e,p[0],i,1,a,h);break;default:if(f.indexOf(\"vec\")>=0){var d=f.charCodeAt(f.length-1)-48;if(d<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+h+\": \"+f);o(t,e,p[0],i,d,a,h)}else{if(!(f.indexOf(\"mat\")>=0))throw new n(\"\",\"Unknown data type for attribute \"+h+\": \"+f);var d=f.charCodeAt(f.length-1)-48;if(d<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+h+\": \"+f);s(t,e,p,i,d,a,h)}}}return a};var n=t(\"./GLError\");function i(t,e,r,n,i,a){this._gl=t,this._wrapper=e,this._index=r,this._locations=n,this._dimension=i,this._constFunc=a}var a=i.prototype;function o(t,e,r,n,a,o,s){for(var l=[\"gl\",\"v\"],c=[],u=0;u<a;++u)l.push(\"x\"+u),c.push(\"x\"+u);l.push(\"if(x0.length===void 0){return gl.vertexAttrib\"+a+\"f(v,\"+c.join()+\")}else{return gl.vertexAttrib\"+a+\"fv(v,x0)}\");var h=Function.apply(null,l),f=new i(t,e,r,n,a,h);Object.defineProperty(o,s,{set:function(e){return t.disableVertexAttribArray(n[r]),h(t,n[r],e),e},get:function(){return f},enumerable:!0})}function s(t,e,r,n,i,a,s){for(var l=new Array(i),c=new Array(i),u=0;u<i;++u)o(t,e,r[u],n,i,l,u),c[u]=l[u];Object.defineProperty(l,\"location\",{set:function(t){if(Array.isArray(t))for(var e=0;e<i;++e)c[e].location=t[e];else for(e=0;e<i;++e)c[e].location=t+e;return t},get:function(){for(var t=new Array(i),e=0;e<i;++e)t[e]=n[r[e]];return t},enumerable:!0}),l.pointer=function(e,a,o,s){e=e||t.FLOAT,a=!!a,o=o||i*i,s=s||0;for(var l=0;l<i;++l){var c=n[r[l]];t.vertexAttribPointer(c,i,e,a,o,s+l*i),t.enableVertexAttribArray(c)}};var h=new Array(i),f=t[\"vertexAttrib\"+i+\"fv\"];Object.defineProperty(a,s,{set:function(e){for(var a=0;a<i;++a){var o=n[r[a]];if(t.disableVertexAttribArray(o),Array.isArray(e[0]))f.call(t,o,e[a]);else{for(var s=0;s<i;++s)h[s]=e[i*a+s];f.call(t,o,h)}}return e},get:function(){return l},enumerable:!0})}a.pointer=function(t,e,r,n){var i=this._gl,a=this._locations[this._index];i.vertexAttribPointer(a,this._dimension,t||i.FLOAT,!!e,r||0,n||0),i.enableVertexAttribArray(a)},a.set=function(t,e,r,n){return this._constFunc(this._locations[this._index],t,e,r,n)},Object.defineProperty(a,\"location\",{get:function(){return this._locations[this._index]},set:function(t){return t!==this._locations[this._index]&&(this._locations[this._index]=0|t,this._wrapper.program=null),0|t}})},{\"./GLError\":302}],304:[function(t,e,r){\"use strict\";var n=t(\"./reflect\"),i=t(\"./GLError\");function a(t){return new Function(\"y\",\"return function(){return y}\")(t)}function o(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}e.exports=function(t,e,r,s){function l(t,e,r){switch(r){case\"bool\":case\"int\":case\"sampler2D\":case\"samplerCube\":return\"gl.uniform1i(locations[\"+e+\"],obj\"+t+\")\";case\"float\":return\"gl.uniform1f(locations[\"+e+\"],obj\"+t+\")\";default:var n=r.indexOf(\"vec\");if(!(0<=n&&n<=1&&r.length===4+n)){if(0===r.indexOf(\"mat\")&&4===r.length){var a=r.charCodeAt(r.length-1)-48;if(a<2||a>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+r);return\"gl.uniformMatrix\"+a+\"fv(locations[\"+e+\"],false,obj\"+t+\")\"}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+r)}var a=r.charCodeAt(r.length-1)-48;if(a<2||a>4)throw new i(\"\",\"Invalid data type\");switch(r.charAt(0)){case\"b\":case\"i\":return\"gl.uniform\"+a+\"iv(locations[\"+e+\"],obj\"+t+\")\";case\"v\":return\"gl.uniform\"+a+\"fv(locations[\"+e+\"],obj\"+t+\")\";default:throw new i(\"\",\"Unrecognized data type for vector \"+name+\": \"+r)}}}function c(e){for(var n=[\"return function updateProperty(obj){\"],i=function t(e,r){if(\"object\"!=typeof r)return[[e,r]];var n=[];for(var i in r){var a=r[i],o=e;parseInt(i)+\"\"===i?o+=\"[\"+i+\"]\":o+=\".\"+i,\"object\"==typeof a?n.push.apply(n,t(o,a)):n.push([o,a])}return n}(\"\",e),a=0;a<i.length;++a){var o=i[a],c=o[0],u=o[1];s[u]&&n.push(l(c,u,r[u].type))}n.push(\"return obj}\");var h=new Function(\"gl\",\"locations\",n.join(\"\\n\"));return h(t,s)}function u(n,l,u){if(\"object\"==typeof u){var f=h(u);Object.defineProperty(n,l,{get:a(f),set:c(u),enumerable:!0,configurable:!1})}else s[u]?Object.defineProperty(n,l,{get:(p=u,new Function(\"gl\",\"wrapper\",\"locations\",\"return function(){return gl.getUniform(wrapper.program,locations[\"+p+\"])}\")(t,e,s)),set:c(u),enumerable:!0,configurable:!1}):n[l]=function(t){switch(t){case\"bool\":return!1;case\"int\":case\"sampler2D\":case\"samplerCube\":case\"float\":return 0;default:var e=t.indexOf(\"vec\");if(0<=e&&e<=1&&t.length===4+e){var r=t.charCodeAt(t.length-1)-48;if(r<2||r>4)throw new i(\"\",\"Invalid data type\");return\"b\"===t.charAt(0)?o(r,!1):o(r,0)}if(0===t.indexOf(\"mat\")&&4===t.length){var r=t.charCodeAt(t.length-1)-48;if(r<2||r>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+t);return o(r*r,0)}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+t)}}(r[u].type);var p}function h(t){var e;if(Array.isArray(t)){e=new Array(t.length);for(var r=0;r<t.length;++r)u(e,r,t[r])}else for(var n in e={},t)u(e,n,t[n]);return e}var f=n(r,!0);return{get:a(h(f)),set:c(f),enumerable:!0,configurable:!0}}},{\"./GLError\":302,\"./reflect\":305}],305:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r={},n=0;n<t.length;++n)for(var i=t[n].name,a=i.split(\".\"),o=r,s=0;s<a.length;++s){var l=a[s].split(\"[\");if(l.length>1){l[0]in o||(o[l[0]]=[]),o=o[l[0]];for(var c=1;c<l.length;++c){var u=parseInt(l[c]);c<l.length-1||s<a.length-1?(u in o||(c<l.length-1?o[u]=[]:o[u]={}),o=o[u]):o[u]=e?n:t[n].type}}else s<a.length-1?(l[0]in o||(o[l[0]]={}),o=o[l[0]]):o[l[0]]=e?n:t[n].type}return r}},{}],306:[function(t,e,r){\"use strict\";r.uniforms=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_UNIFORMS),n=[],i=0;i<r;++i){var o=t.getActiveUniform(e,i);if(o){var s=a(t,o.type);if(o.size>1)for(var l=0;l<o.size;++l)n.push({name:o.name.replace(\"[0]\",\"[\"+l+\"]\"),type:s});else n.push({name:o.name,type:s})}}return n},r.attributes=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_ATTRIBUTES),n=[],i=0;i<r;++i){var o=t.getActiveAttrib(e,i);o&&n.push({name:o.name,type:a(t,o.type)})}return n};var n={FLOAT:\"float\",FLOAT_VEC2:\"vec2\",FLOAT_VEC3:\"vec3\",FLOAT_VEC4:\"vec4\",INT:\"int\",INT_VEC2:\"ivec2\",INT_VEC3:\"ivec3\",INT_VEC4:\"ivec4\",BOOL:\"bool\",BOOL_VEC2:\"bvec2\",BOOL_VEC3:\"bvec3\",BOOL_VEC4:\"bvec4\",FLOAT_MAT2:\"mat2\",FLOAT_MAT3:\"mat3\",FLOAT_MAT4:\"mat4\",SAMPLER_2D:\"sampler2D\",SAMPLER_CUBE:\"samplerCube\"},i=null;function a(t,e){if(!i){var r=Object.keys(n);i={};for(var a=0;a<r.length;++a){var o=r[a];i[t[o]]=n[o]}}return i[e]}},{}],307:[function(t,e,r){\"use strict\";r.shader=function(t,e,r){return u(t).getShaderReference(e,r)},r.program=function(t,e,r,n,i){return u(t).getProgram(e,r,n,i)};var n=t(\"./GLError\"),i=t(\"gl-format-compiler-error\"),a=new(\"undefined\"==typeof WeakMap?t(\"weakmap-shim\"):WeakMap),o=0;function s(t,e,r,n,i,a,o){this.id=t,this.src=e,this.type=r,this.shader=n,this.count=a,this.programs=[],this.cache=o}function l(t){this.gl=t,this.shaders=[{},{}],this.programs={}}s.prototype.dispose=function(){if(0==--this.count){for(var t=this.cache,e=t.gl,r=this.programs,n=0,i=r.length;n<i;++n){var a=t.programs[r[n]];a&&(delete t.programs[n],e.deleteProgram(a))}e.deleteShader(this.shader),delete t.shaders[this.type===e.FRAGMENT_SHADER|0][this.src]}};var c=l.prototype;function u(t){var e=a.get(t);return e||(e=new l(t),a.set(t,e)),e}c.getShaderReference=function(t,e){var r=this.gl,a=this.shaders[t===r.FRAGMENT_SHADER|0],l=a[e];if(l&&r.isShader(l.shader))l.count+=1;else{var c=function(t,e,r){var a=t.createShader(e);if(t.shaderSource(a,r),t.compileShader(a),!t.getShaderParameter(a,t.COMPILE_STATUS)){var o=t.getShaderInfoLog(a);try{var s=i(o,r,e)}catch(t){throw console.warn(\"Failed to format compiler error: \"+t),new n(o,\"Error compiling shader:\\n\"+o)}throw new n(o,s.short,s.long)}return a}(r,t,e);l=a[e]=new s(o++,e,t,c,[],1,this)}return l},c.getProgram=function(t,e,r,i){var a=[t.id,e.id,r.join(\":\"),i.join(\":\")].join(\"@\"),o=this.programs[a];return o&&this.gl.isProgram(o)||(this.programs[a]=o=function(t,e,r,i,a){var o=t.createProgram();t.attachShader(o,e),t.attachShader(o,r);for(var s=0;s<i.length;++s)t.bindAttribLocation(o,a[s],i[s]);if(t.linkProgram(o),!t.getProgramParameter(o,t.LINK_STATUS)){var l=t.getProgramInfoLog(o);throw new n(l,\"Error linking program: \"+l)}return o}(this.gl,t.shader,e.shader,r,i),t.programs.push(a),e.programs.push(a)),o}},{\"./GLError\":302,\"gl-format-compiler-error\":250,\"weakmap-shim\":555}],308:[function(t,e,r){\"use strict\";function n(t){this.plot=t,this.enable=[!0,!0,!1,!1],this.width=[1,1,1,1],this.color=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.center=[1/0,1/0]}e.exports=function(t,e){var r=new n(t);return r.update(e),t.addOverlay(r),r};var i=n.prototype;i.update=function(t){t=t||{},this.enable=(t.enable||[!0,!0,!1,!1]).slice(),this.width=(t.width||[1,1,1,1]).slice(),this.color=(t.color||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]).map(function(t){return t.slice()}),this.center=(t.center||[1/0,1/0]).slice(),this.plot.setOverlayDirty()},i.draw=function(){var t=this.enable,e=this.width,r=this.color,n=this.center,i=this.plot,a=i.line,o=i.dataBox,s=i.viewBox;if(a.bind(),o[0]<=n[0]&&n[0]<=o[2]&&o[1]<=n[1]&&n[1]<=o[3]){var l=s[0]+(n[0]-o[0])/(o[2]-o[0])*(s[2]-s[0]),c=s[1]+(n[1]-o[1])/(o[3]-o[1])*(s[3]-s[1]);t[0]&&a.drawLine(l,c,s[0],c,e[0],r[0]),t[1]&&a.drawLine(l,c,l,s[1],e[1],r[1]),t[2]&&a.drawLine(l,c,s[2],c,e[2],r[2]),t[3]&&a.drawLine(l,c,l,s[3],e[3],r[3])}},i.dispose=function(){this.plot.removeOverlay(this)}},{}],309:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, color;\\nattribute float weight;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 coordinates[3];\\nuniform vec4 colors[3];\\nuniform vec2 screenShape;\\nuniform float lineWidth;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vertexPosition = mix(coordinates[0],\\n    mix(coordinates[2], coordinates[1], 0.5 * (position + 1.0)), abs(position));\\n\\n  vec4 clipPos = projection * view * model * vec4(vertexPosition, 1.0);\\n  vec2 clipOffset = (projection * view * model * vec4(color, 0.0)).xy;\\n  vec2 delta = weight * clipOffset * screenShape;\\n  vec2 lineOffset = normalize(vec2(delta.y, -delta.x)) / screenShape;\\n\\n  gl_Position   = vec4(clipPos.xy + clipPos.w * 0.5 * lineWidth * lineOffset, clipPos.z, clipPos.w);\\n  fragColor     = color.x * colors[0] + color.y * colors[1] + color.z * colors[2];\\n}\\n\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  gl_FragColor = fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec3\"},{name:\"weight\",type:\"float\"}])}},{\"gl-shader\":301,glslify:409}],310:[function(t,e,r){\"use strict\";var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\");e.exports=function(t,e){var r=[];function o(t,e,n,i,a,o){var s=[t,e,n,0,0,0,1];s[i+3]=1,s[i]=a,r.push.apply(r,s),s[6]=-1,r.push.apply(r,s),s[i]=o,r.push.apply(r,s),r.push.apply(r,s),s[6]=1,r.push.apply(r,s),s[i]=a,r.push.apply(r,s)}o(0,0,0,0,0,1),o(0,0,0,1,0,1),o(0,0,0,2,0,1),o(1,0,0,1,-1,1),o(1,0,0,2,-1,1),o(0,1,0,0,-1,1),o(0,1,0,2,-1,1),o(0,0,1,0,-1,1),o(0,0,1,1,-1,1);var l=n(t,r),c=i(t,[{type:t.FLOAT,buffer:l,size:3,offset:0,stride:28},{type:t.FLOAT,buffer:l,size:3,offset:12,stride:28},{type:t.FLOAT,buffer:l,size:1,offset:24,stride:28}]),u=a(t);u.attributes.position.location=0,u.attributes.color.location=1,u.attributes.weight.location=2;var h=new s(t,l,c,u);return h.update(e),h};var o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n,this.pixelRatio=1,this.bounds=[[-1e3,-1e3,-1e3],[1e3,1e3,1e3]],this.position=[0,0,0],this.lineWidth=[2,2,2],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.enabled=[!0,!0,!0],this.drawSides=[!0,!0,!0],this.axes=null}var l=s.prototype,c=[0,0,0],u=[0,0,0],h=[0,0];l.isTransparent=function(){return!1},l.drawTransparent=function(t){},l.draw=function(t){var e=this.gl,r=this.vao,n=this.shader;r.bind(),n.bind();var i,a=t.model||o,s=t.view||o,l=t.projection||o;this.axes&&(i=this.axes.lastCubeProps.axis);for(var f=c,p=u,d=0;d<3;++d)i&&i[d]<0?(f[d]=this.bounds[0][d],p[d]=this.bounds[1][d]):(f[d]=this.bounds[1][d],p[d]=this.bounds[0][d]);h[0]=e.drawingBufferWidth,h[1]=e.drawingBufferHeight,n.uniforms.model=a,n.uniforms.view=s,n.uniforms.projection=l,n.uniforms.coordinates=[this.position,f,p],n.uniforms.colors=this.colors,n.uniforms.screenShape=h;for(d=0;d<3;++d)n.uniforms.lineWidth=this.lineWidth[d]*this.pixelRatio,this.enabled[d]&&(r.draw(e.TRIANGLES,6,6*d),this.drawSides[d]&&r.draw(e.TRIANGLES,12,18+12*d));r.unbind()},l.update=function(t){t&&(\"bounds\"in t&&(this.bounds=t.bounds),\"position\"in t&&(this.position=t.position),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"colors\"in t&&(this.colors=t.colors),\"enabled\"in t&&(this.enabled=t.enabled),\"drawSides\"in t&&(this.drawSides=t.drawSides))},l.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders/index\":309,\"gl-buffer\":241,\"gl-vao\":327}],311:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\nuniform float vectorScale;\\nuniform float tubeScale;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * tubePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal,0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(tubePosition, 1.0);\\n  vec4 t_position  = view * tubePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = tubePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular\\n            , opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform float tubeScale;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  gl_Position = projection * view * tubePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec4\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec4\"}]}},{glslify:409}],312:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./shaders\"),g=d.meshShader,v=d.pickShader,m=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function y(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,y,x,b,_,w,k,T){this.gl=t,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=i,this.triangleVectors=a,this.triangleColors=s,this.triangleNormals=c,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=u,this.triangleCount=0,this.lineWidth=1,this.edgePositions=h,this.edgeColors=p,this.edgeUVs=d,this.edgeIds=f,this.edgeVAO=g,this.edgeCount=0,this.pointPositions=v,this.pointColors=x,this.pointUVs=b,this.pointSizes=_,this.pointIds=y,this.pointVAO=w,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=k,this.contourVAO=T,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!1,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.tubeScale=1,this._model=m,this._view=m,this._projection=m,this._resolution=[1,1],this.pixelRatio=1}var x=y.prototype;function b(t){var e=n(t,v.vertex,v.fragment,null,v.attributes);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.vector.location=5,e}x.isOpaque=function(){return this.opacity>=1},x.isTransparent=function(){return this.opacity<1},x.pickSlots=1,x.setPickBase=function(t){this.pickId=t},x.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=i[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},x.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=h({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return u(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,i=t.vectors;if(n&&r&&i){void 0!==t.tubeScale&&(this.tubeScale=t.tubeScale);var a=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[],w=[],k=[];this.cells=r,this.positions=n,this.vectors=i;var T=t.vertexNormals,A=t.cellNormals,M=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,S=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!A&&(A=s.faceNormals(r,n,S)),A||T||(T=s.vertexNormals(r,n,M));var E=t.vertexColors,C=t.cellColors,L=t.meshColor||[1,1,1,1],P=t.vertexUVs,O=t.vertexIntensity,z=t.cellUVs,I=t.cellIntensity,D=1/0,R=-1/0;if(!P&&!z)if(O)if(t.vertexIntensityBounds)D=+t.vertexIntensityBounds[0],R=+t.vertexIntensityBounds[1];else for(var F=0;F<O.length;++F){var B=O[F];D=Math.min(D,B),R=Math.max(R,B)}else if(I)for(F=0;F<I.length;++F){B=I[F];D=Math.min(D,B),R=Math.max(R,B)}else for(F=0;F<n.length;++F){B=n[F][2];D=Math.min(D,B),R=Math.max(R,B)}this.intensity=O||(I?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,I):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var N=t.pointSizes,j=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(F=0;F<n.length;++F)for(var U=n[F],V=0;V<3;++V)!isNaN(U[V])&&isFinite(U[V])&&(this.bounds[0][V]=Math.min(this.bounds[0][V],U[V]),this.bounds[1][V]=Math.max(this.bounds[1][V],U[V]));var q=0,H=0,G=0;t:for(F=0;F<r.length;++F){var Y=r[F];switch(Y.length){case 1:for(U=n[X=Y[0]],V=0;V<3;++V)if(isNaN(U[V])||!isFinite(U[V]))continue t;x.push(U[0],U[1],U[2],U[3]),3===(Z=E?E[X]:C?C[F]:L).length?b.push(Z[0],Z[1],Z[2],1):b.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],_.push(J[0],J[1]),N?w.push(N[X]):w.push(j),k.push(F),G+=1;break;case 2:for(V=0;V<2;++V){U=n[X=Y[V]];for(var W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t}for(V=0;V<2;++V){U=n[X=Y[V]];g.push(U[0],U[1],U[2]),3===(Z=E?E[X]:C?C[F]:L).length?v.push(Z[0],Z[1],Z[2],1):v.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],m.push(J[0],J[1]),y.push(F)}H+=1;break;case 3:for(V=0;V<3;++V)for(U=n[X=Y[V]],W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t;for(V=0;V<3;++V){var X;U=n[X=Y[2-V]];a.push(U[0],U[1],U[2],U[3]);var Z,J,K,$=i[X];l.push($[0],$[1],$[2],$[3]),3===(Z=E?E[X]:C?C[F]:L).length?c.push(Z[0],Z[1],Z[2],1):c.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],p.push(J[0],J[1]),K=T?T[X]:A[F],f.push(K[0],K[1],K[2]),d.push(F)}q+=1}}this.pointCount=G,this.edgeCount=H,this.triangleCount=q,this.pointPositions.update(x),this.pointColors.update(b),this.pointUVs.update(_),this.pointSizes.update(w),this.pointIds.update(new Uint32Array(k)),this.edgePositions.update(g),this.edgeColors.update(v),this.edgeUVs.update(m),this.edgeIds.update(new Uint32Array(y)),this.trianglePositions.update(a),this.triangleVectors.update(l),this.triangleColors.update(c),this.triangleUVs.update(p),this.triangleNormals.update(f),this.triangleIds.update(new Uint32Array(d))}},x.drawTransparent=x.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:m.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,tubeScale:this.tubeScale,contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var f=u[12+o],p=0;p<3;++p)f+=u[4*p+o]*this.lightPosition[p];s.lightPosition[o]=f/h}if(this.triangleCount>0){var d=this.triShader;d.bind(),d.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},x.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:i,clipBounds:a,tubeScale:this.tubeScale,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind())},x.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3);return{index:e,position:n,intensity:this.intensity[r[1]],velocity:this.vectors[r[1]].slice(0,3),divergence:this.vectors[r[1]][3],dataCoordinate:n}},x.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose()},e.exports=function(t,e){1===arguments.length&&(t=(e=t).gl);var r=e.triShader||function(t){var e=n(t,g.vertex,g.fragment,null,g.attributes);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.vector.location=5,e}(t),s=b(t),l=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));l.generateMipmap(),l.minFilter=t.LINEAR_MIPMAP_LINEAR,l.magFilter=t.LINEAR;var c=i(t),h=i(t),f=i(t),p=i(t),d=i(t),v=i(t),m=a(t,[{buffer:c,type:t.FLOAT,size:4},{buffer:v,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:f,type:t.FLOAT,size:4},{buffer:p,type:t.FLOAT,size:2},{buffer:d,type:t.FLOAT,size:3},{buffer:h,type:t.FLOAT,size:4}]),x=i(t),_=i(t),w=i(t),k=i(t),T=a(t,[{buffer:x,type:t.FLOAT,size:3},{buffer:k,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:_,type:t.FLOAT,size:4},{buffer:w,type:t.FLOAT,size:2}]),A=i(t),M=i(t),S=i(t),E=i(t),C=i(t),L=a(t,[{buffer:A,type:t.FLOAT,size:3},{buffer:C,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:M,type:t.FLOAT,size:4},{buffer:S,type:t.FLOAT,size:2},{buffer:E,type:t.FLOAT,size:1}]),P=i(t),O=new y(t,l,r,s,c,h,v,f,p,d,m,x,k,_,w,T,A,C,M,S,E,L,P,a(t,[{buffer:P,type:t.FLOAT,size:3}]));return O.update(e),O}},{\"./shaders\":311,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-shader\":301,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,normals:453,\"simplicial-complex-contour\":518,\"typedarray-pool\":545}],313:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\"),i=t(\"gl-vec4\"),a=function(t,e,r,a){for(var o=0,s=0;s<t.length;s++)for(var l=t[s].velocities,c=0;c<l.length;c++){var u=n.length(l[c]);u>o&&(o=u)}var h=t.map(function(t){return function(t,e,r,a){var o,s,l,c=t.points,u=t.velocities,h=t.divergences;n.set(n.create(),0,1,0),n.create(),n.create();n.create();for(var f=[],p=[],d=[],g=[],v=[],m=[],y=0,x=0,b=i.create(),_=i.create(),w=0;w<c.length;w++){o=c[w],s=u[w],l=h[w],0===e&&(l=.05*r),x=n.length(s)/a,b=i.create(),n.copy(b,s),b[3]=l;for(var k=0;k<8;k++)v[k]=[o[0],o[1],o[2],k];if(g.length>0)for(k=0;k<8;k++){var T=(k+1)%8;f.push(g[k],v[k],v[T],v[T],g[T],g[k]),d.push(_,b,b,b,_,_),m.push(y,x,x,x,y,y),p.push([f.length-6,f.length-5,f.length-4],[f.length-3,f.length-2,f.length-1])}var A=g;g=v,v=A,A=_,_=b,b=A,A=y,y=x,x=A}return{positions:f,cells:p,vectors:d,vertexIntensity:m}}(t,r,a,o)}),f=[],p=[],d=[],g=[];for(s=0;s<h.length;s++){var v=h[s],m=f.length;f=f.concat(v.positions),d=d.concat(v.vectors),g=g.concat(v.vertexIntensity);for(c=0;c<v.cells.length;c++){var y=v.cells[c],x=[];p.push(x);for(var b=0;b<y.length;b++)x.push(y[b]+m)}}return{positions:f,cells:p,vectors:d,vertexIntensity:g,colormap:e}},o=function(t,e){var r=n.create(),i=1e-4;n.add(r,t,[i,0,0]);var a=this.getVelocity(r);n.subtract(a,a,e),n.scale(a,a,1e4),n.add(r,t,[0,i,0]);var o=this.getVelocity(r);n.subtract(o,o,e),n.scale(o,o,1e4),n.add(r,t,[0,0,i]);var s=this.getVelocity(r);return n.subtract(s,s,e),n.scale(s,s,1e4),n.add(r,a,o),n.add(r,r,s),r},s=function(t){return f(t,this.vectors,this.meshgrid,this.clampBorders)},l=function(t,e){for(var r=0;r<t.length;r++){var n=t[r];if(n===e)return r;if(n>e)return r-1}return r},c=n.create(),u=n.create(),h=function(t,e,r){return t<e?e:t>r?r:t},f=function(t,e,r,i){var a=t[0],o=t[1],s=t[2],f=r[0].length,p=r[1].length,d=r[2].length,g=l(r[0],a),v=l(r[1],o),m=l(r[2],s),y=g+1,x=v+1,b=m+1;if(r[0][g]===a&&(y=g),r[1][v]===o&&(x=v),r[2][m]===s&&(b=m),i&&(g=h(g,0,f-1),y=h(y,0,f-1),v=h(v,0,p-1),x=h(x,0,p-1),m=h(m,0,d-1),b=h(b,0,d-1)),g<0||v<0||m<0||y>=f||x>=p||b>=d)return n.create();var _=(a-r[0][g])/(r[0][y]-r[0][g]),w=(o-r[1][v])/(r[1][x]-r[1][v]),k=(s-r[2][m])/(r[2][b]-r[2][m]);(_<0||_>1||isNaN(_))&&(_=0),(w<0||w>1||isNaN(w))&&(w=0),(k<0||k>1||isNaN(k))&&(k=0);var T=m*f*p,A=b*f*p,M=v*f,S=x*f,E=g,C=y,L=e[M+T+E],P=e[M+T+C],O=e[S+T+E],z=e[S+T+C],I=e[M+A+E],D=e[M+A+C],R=e[S+A+E],F=e[S+A+C],B=n.create();return n.lerp(B,L,P,_),n.lerp(c,O,z,_),n.lerp(B,B,c,w),n.lerp(c,I,D,_),n.lerp(u,R,F,_),n.lerp(c,c,u,w),n.lerp(B,B,c,k),B},p=function(t){var e=1/0;t.sort(function(t,e){return t-e});for(var r=1;r<t.length;r++){var n=Math.abs(t[r]-t[r-1]);n<e&&(e=n)}return e};e.exports=function(t,e){var r=t.startingPositions,i=t.maxLength||1e3,l=t.tubeSize||1,c=t.absoluteTubeSize;t.getDivergence||(t.getDivergence=o),t.getVelocity||(t.getVelocity=s),void 0===t.clampBorders&&(t.clampBorders=!0);var u=[],h=e[0][0],f=e[0][1],d=e[0][2],g=e[1][0],v=e[1][1],m=e[1][2],y=function(t,e){var r=e[0],n=e[1],i=e[2];return r>=h&&r<=g&&n>=f&&n<=v&&i>=d&&i<=m},x=10*n.distance(e[0],e[1])/i,b=x*x,_=1,w=0;n.create();r.length>=2&&(_=function(t){for(var e=[],r=[],n=[],i={},a={},o={},s=0;s<t.length;s++){var l=t[s],c=l[0],u=l[1],h=l[2];i[c]||(e.push(c),i[c]=!0),a[u]||(r.push(u),a[u]=!0),o[h]||(n.push(h),o[h]=!0)}var f=p(e),d=p(r),g=p(n),v=Math.min(f,d,g);return isFinite(v)?v:1}(r));for(var k=0;k<r.length;k++){var T=n.create();n.copy(T,r[k]);var A=[T],M=[],S=t.getVelocity(T),E=T;M.push(S);var C=[],L=t.getDivergence(T,S);(I=n.length(L))>w&&!isNaN(I)&&isFinite(I)&&(w=I),C.push(I),u.push({points:A,velocities:M,divergences:C});for(var P=0;P<100*i&&A.length<i&&y(0,T);){P++;var O=n.clone(S),z=n.squaredLength(O);if(0===z)break;if(z>b&&n.scale(O,O,x/Math.sqrt(z)),n.add(O,O,T),S=t.getVelocity(O),n.squaredDistance(E,O)-b>-1e-4*b){A.push(O),E=O,M.push(S);L=t.getDivergence(O,S);(I=n.length(L))>w&&!isNaN(I)&&isFinite(I)&&(w=I),C.push(I)}T=O}}for(k=0;k<C.length;k++){var I=C[k];!isNaN(I)&&isFinite(I)||(C[k]=w)}var D=a(u,t.colormap,w,_);return c?D.tubeScale=c:(0===w&&(w=1),D.tubeScale=.5*l*_/w),D},e.exports.createTubeMesh=t(\"./lib/tubemesh\")},{\"./lib/tubemesh\":312,\"gl-vec3\":346,\"gl-vec4\":382}],314:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute vec3 f;\\nattribute vec3 normal;\\n\\nuniform vec3 objectOffset;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 lightPosition, eyePosition;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 localCoordinate = vec3(uv.zw, f.x);\\n  worldCoordinate = objectOffset + localCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n  vec4 clipPosition = projection * view * worldPosition;\\n  gl_Position = clipPosition;\\n  kill = f.y;\\n  value = f.z;\\n  planeCoordinate = uv.xy;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * worldPosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  lightDirection = lightPosition - cameraCoordinate.xyz;\\n  eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  surfaceNormal  = normalize((vec4(normal,0) * inverseModel).xyz);\\n}\\n\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat beckmannSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness) {\\n  return beckmannDistribution(dot(surfaceNormal, normalize(lightDirection + viewDirection)), roughness);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 lowerBound, upperBound;\\nuniform float contourTint;\\nuniform vec4 contourColor;\\nuniform sampler2D colormap;\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform float vertexColor;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec3 N = normalize(surfaceNormal);\\n  vec3 V = normalize(eyeDirection);\\n  vec3 L = normalize(lightDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = max(beckmannSpecular(L, V, N, roughness), 0.);\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  //decide how to interpolate color \\u2014 in vertex or in fragment\\n  vec4 surfaceColor =\\n    step(vertexColor, .5) * texture2D(colormap, vec2(value, value)) +\\n    step(.5, vertexColor) * vColor;\\n\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = mix(litColor, contourColor, contourTint) * opacity;\\n}\\n\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute float f;\\n\\nuniform vec3 objectOffset;\\nuniform mat3 permutation;\\nuniform mat4 model, view, projection;\\nuniform float height, zOffset;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 dataCoordinate = permutation * vec3(uv.xy, height);\\n  worldCoordinate = objectOffset + dataCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n\\n  vec4 clipPosition = projection * view * worldPosition;\\n  clipPosition.z += zOffset;\\n\\n  gl_Position = clipPosition;\\n  value = f + objectOffset.z;\\n  kill = -1.0;\\n  planeCoordinate = uv.zw;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Don't do lighting for contours\\n  surfaceNormal   = vec3(1,0,0);\\n  eyeDirection    = vec3(0,1,0);\\n  lightDirection  = vec3(0,0,1);\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec2 shape;\\nuniform vec3 clipBounds[2];\\nuniform float pickId;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 surfaceNormal;\\n\\nvec2 splitFloat(float v) {\\n  float vh = 255.0 * v;\\n  float upper = floor(vh);\\n  float lower = fract(vh);\\n  return vec2(upper / 255.0, floor(lower * 16.0) / 16.0);\\n}\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec2 ux = splitFloat(planeCoordinate.x / shape.x);\\n  vec2 uy = splitFloat(planeCoordinate.y / shape.y);\\n  gl_FragColor = vec4(pickId, ux.x, uy.x, ux.y + (uy.y/16.0));\\n}\\n\"]);r.createShader=function(t){var e=n(t,a,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createPickShader=function(t){var e=n(t,a,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createContourShader=function(t){var e=n(t,s,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e},r.createPickContourShader=function(t){var e=n(t,s,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e}},{\"gl-shader\":301,glslify:409}],315:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],316:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=y(e),n=b(e),s=x(e),l=_(e),c=i(e),u=a(e,[{buffer:c,size:4,stride:w,offset:0},{buffer:c,size:3,stride:w,offset:16},{buffer:c,size:3,stride:w,offset:28}]),h=i(e),f=a(e,[{buffer:h,size:4,stride:20,offset:0},{buffer:h,size:1,stride:20,offset:16}]),p=i(e),d=a(e,[{buffer:p,size:2,type:e.FLOAT}]),g=o(e,1,S,e.RGBA,e.UNSIGNED_BYTE);g.minFilter=e.LINEAR,g.magFilter=e.LINEAR;var v=new E(e,[0,0],[[0,0,0],[0,0,0]],r,n,c,u,g,s,l,h,f,p,d,[0,0,0]),m={levels:[[],[],[]]};for(var k in t)m[k]=t[k];return m.colormap=m.colormap||\"jet\",v.update(m),v};var n=t(\"bit-twiddle\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"typedarray-pool\"),l=t(\"colormap\"),c=t(\"ndarray-ops\"),u=t(\"ndarray-pack\"),h=t(\"ndarray\"),f=t(\"surface-nets\"),p=t(\"gl-mat4/multiply\"),d=t(\"gl-mat4/invert\"),g=t(\"binary-search-bounds\"),v=t(\"ndarray-gradient\"),m=t(\"./lib/shaders\"),y=m.createShader,x=m.createContourShader,b=m.createPickShader,_=m.createPickContourShader,w=40,k=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1],T=[[0,0],[0,1],[1,0],[1,1],[1,0],[0,1]],A=[[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0]];function M(t,e,r,n,i){this.position=t,this.index=e,this.uv=r,this.level=n,this.dataCoordinate=i}!function(){for(var t=0;t<3;++t){var e=A[t],r=(t+2)%3;e[(t+1)%3+0]=1,e[r+3]=1,e[t+6]=1}}();var S=256;function E(t,e,r,n,i,a,o,l,c,u,f,p,d,g,v){this.gl=t,this.shape=e,this.bounds=r,this.objectOffset=v,this.intensityBounds=[],this._shader=n,this._pickShader=i,this._coordinateBuffer=a,this._vao=o,this._colorMap=l,this._contourShader=c,this._contourPickShader=u,this._contourBuffer=f,this._contourVAO=p,this._contourOffsets=[[],[],[]],this._contourCounts=[[],[],[]],this._vertexCount=0,this._pickResult=new M([0,0,0],[0,0],[0,0],[0,0,0],[0,0,0]),this._dynamicBuffer=d,this._dynamicVAO=g,this._dynamicOffsets=[0,0,0],this._dynamicCounts=[0,0,0],this.contourWidth=[1,1,1],this.contourLevels=[[1],[1],[1]],this.contourTint=[0,0,0],this.contourColor=[[.5,.5,.5,1],[.5,.5,.5,1],[.5,.5,.5,1]],this.showContour=!0,this.showSurface=!0,this.enableHighlight=[!0,!0,!0],this.highlightColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.highlightTint=[1,1,1],this.highlightLevel=[-1,-1,-1],this.enableDynamic=[!0,!0,!0],this.dynamicLevel=[NaN,NaN,NaN],this.dynamicColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.dynamicTint=[1,1,1],this.dynamicWidth=[1,1,1],this.axesBounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.surfaceProject=[!1,!1,!1],this.contourProject=[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],this.colorBounds=[!1,!1],this._field=[h(s.mallocFloat(1024),[0,0]),h(s.mallocFloat(1024),[0,0]),h(s.mallocFloat(1024),[0,0])],this.pickId=1,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.snapToData=!1,this.pixelRatio=1,this.opacity=1,this.lightPosition=[10,1e4,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.vertexColor=0,this.dirty=!0}var C=E.prototype;C.isTransparent=function(){return this.opacity<1},C.isOpaque=function(){if(this.opacity>=1)return!0;for(var t=0;t<3;++t)if(this._contourCounts[t].length>0||this._dynamicCounts[t]>0)return!0;return!1},C.pickSlots=1,C.setPickBase=function(t){this.pickId=t};var L=[0,0,0],P={showSurface:!1,showContour:!1,projections:[k.slice(),k.slice(),k.slice()],clipBounds:[[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]]]};function O(t,e){var r,n,i,a=e.axes&&e.axes.lastCubeProps.axis||L,o=e.showSurface,s=e.showContour;for(r=0;r<3;++r)for(o=o||e.surfaceProject[r],n=0;n<3;++n)s=s||e.contourProject[r][n];for(r=0;r<3;++r){var l=P.projections[r];for(n=0;n<16;++n)l[n]=0;for(n=0;n<4;++n)l[5*n]=1;l[5*r]=0,l[12+r]=e.axesBounds[+(a[r]>0)][r],p(l,t.model,l);var c=P.clipBounds[r];for(i=0;i<2;++i)for(n=0;n<3;++n)c[i][n]=t.clipBounds[i][n];c[0][r]=-1e8,c[1][r]=1e8}return P.showSurface=o,P.showContour=s,P}var z={model:k,view:k,projection:k,inverseModel:k.slice(),lowerBound:[0,0,0],upperBound:[0,0,0],colorMap:0,clipBounds:[[0,0,0],[0,0,0]],height:0,contourTint:0,contourColor:[0,0,0,1],permutation:[1,0,0,0,1,0,0,0,1],zOffset:-1e-4,objectOffset:[0,0,0],kambient:1,kdiffuse:1,kspecular:1,lightPosition:[1e3,1e3,1e3],eyePosition:[0,0,0],roughness:1,fresnel:1,opacity:1,vertexColor:0},I=k.slice(),D=[1,0,0,0,1,0,0,0,1];function R(t,e){t=t||{};var r=this.gl;r.disable(r.CULL_FACE),this._colorMap.bind(0);var n=z;n.model=t.model||k,n.view=t.view||k,n.projection=t.projection||k,n.lowerBound=[this.bounds[0][0],this.bounds[0][1],this.colorBounds[0]||this.bounds[0][2]],n.upperBound=[this.bounds[1][0],this.bounds[1][1],this.colorBounds[1]||this.bounds[1][2]],n.objectOffset=this.objectOffset,n.contourColor=this.contourColor[0],n.inverseModel=d(n.inverseModel,n.model);for(var i=0;i<2;++i)for(var a=n.clipBounds[i],o=0;o<3;++o)a[o]=Math.min(Math.max(this.clipBounds[i][o],-1e8),1e8);n.kambient=this.ambientLight,n.kdiffuse=this.diffuseLight,n.kspecular=this.specularLight,n.roughness=this.roughness,n.fresnel=this.fresnel,n.opacity=this.opacity,n.height=0,n.permutation=D,n.vertexColor=this.vertexColor;var s=I;for(p(s,n.view,n.model),p(s,n.projection,s),d(s,s),i=0;i<3;++i)n.eyePosition[i]=s[12+i]/s[15];var l=s[15];for(i=0;i<3;++i)l+=this.lightPosition[i]*s[4*i+3];for(i=0;i<3;++i){var c=s[12+i];for(o=0;o<3;++o)c+=s[4*o+i]*this.lightPosition[o];n.lightPosition[i]=c/l}var u=O(n,this);if(u.showSurface&&e===this.opacity<1){for(this._shader.bind(),this._shader.uniforms=n,this._vao.bind(),this.showSurface&&this._vertexCount&&this._vao.draw(r.TRIANGLES,this._vertexCount),i=0;i<3;++i)this.surfaceProject[i]&&this.vertexCount&&(this._shader.uniforms.model=u.projections[i],this._shader.uniforms.clipBounds=u.clipBounds[i],this._vao.draw(r.TRIANGLES,this._vertexCount));this._vao.unbind()}if(u.showContour&&!e){var h=this._contourShader;n.kambient=1,n.kdiffuse=0,n.kspecular=0,n.opacity=1,h.bind(),h.uniforms=n;var f=this._contourVAO;for(f.bind(),i=0;i<3;++i)for(h.uniforms.permutation=A[i],r.lineWidth(this.contourWidth[i]*this.pixelRatio),o=0;o<this.contourLevels[i].length;++o)o===this.highlightLevel[i]?(h.uniforms.contourColor=this.highlightColor[i],h.uniforms.contourTint=this.highlightTint[i]):0!==o&&o-1!==this.highlightLevel[i]||(h.uniforms.contourColor=this.contourColor[i],h.uniforms.contourTint=this.contourTint[i]),this._contourCounts[i][o]&&(h.uniforms.height=this.contourLevels[i][o],f.draw(r.LINES,this._contourCounts[i][o],this._contourOffsets[i][o]));for(i=0;i<3;++i)for(h.uniforms.model=u.projections[i],h.uniforms.clipBounds=u.clipBounds[i],o=0;o<3;++o)if(this.contourProject[i][o]){h.uniforms.permutation=A[o],r.lineWidth(this.contourWidth[o]*this.pixelRatio);for(var g=0;g<this.contourLevels[o].length;++g)g===this.highlightLevel[o]?(h.uniforms.contourColor=this.highlightColor[o],h.uniforms.contourTint=this.highlightTint[o]):0!==g&&g-1!==this.highlightLevel[o]||(h.uniforms.contourColor=this.contourColor[o],h.uniforms.contourTint=this.contourTint[o]),this._contourCounts[o][g]&&(h.uniforms.height=this.contourLevels[o][g],f.draw(r.LINES,this._contourCounts[o][g],this._contourOffsets[o][g]))}for(f.unbind(),(f=this._dynamicVAO).bind(),i=0;i<3;++i)if(0!==this._dynamicCounts[i])for(h.uniforms.model=n.model,h.uniforms.clipBounds=n.clipBounds,h.uniforms.permutation=A[i],r.lineWidth(this.dynamicWidth[i]*this.pixelRatio),h.uniforms.contourColor=this.dynamicColor[i],h.uniforms.contourTint=this.dynamicTint[i],h.uniforms.height=this.dynamicLevel[i],f.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]),o=0;o<3;++o)this.contourProject[o][i]&&(h.uniforms.model=u.projections[o],h.uniforms.clipBounds=u.clipBounds[o],f.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]));f.unbind()}}C.draw=function(t){return R.call(this,t,!1)},C.drawTransparent=function(t){return R.call(this,t,!0)};var F={model:k,view:k,projection:k,inverseModel:k,clipBounds:[[0,0,0],[0,0,0]],height:0,shape:[0,0],pickId:0,lowerBound:[0,0,0],upperBound:[0,0,0],zOffset:0,objectOffset:[0,0,0],permutation:[1,0,0,0,1,0,0,0,1],lightPosition:[0,0,0],eyePosition:[0,0,0]};function B(t,e){return Array.isArray(t)?[e(t[0]),e(t[1]),e(t[2])]:[e(t),e(t),e(t)]}function N(t){return Array.isArray(t)?3===t.length?[t[0],t[1],t[2],1]:[t[0],t[1],t[2],t[3]]:[0,0,0,1]}function j(t){if(Array.isArray(t)){if(Array.isArray(t))return[N(t[0]),N(t[1]),N(t[2])];var e=N(t);return[e.slice(),e.slice(),e.slice()]}}C.drawPick=function(t){t=t||{};var e=this.gl;e.disable(e.CULL_FACE);var r=F;r.model=t.model||k,r.view=t.view||k,r.projection=t.projection||k,r.shape=this._field[2].shape,r.pickId=this.pickId/255,r.lowerBound=this.bounds[0],r.upperBound=this.bounds[1],r.objectOffset=this.objectOffset,r.permutation=D;for(var n=0;n<2;++n)for(var i=r.clipBounds[n],a=0;a<3;++a)i[a]=Math.min(Math.max(this.clipBounds[n][a],-1e8),1e8);var o=O(r,this);if(o.showSurface){for(this._pickShader.bind(),this._pickShader.uniforms=r,this._vao.bind(),this._vao.draw(e.TRIANGLES,this._vertexCount),n=0;n<3;++n)this.surfaceProject[n]&&(this._pickShader.uniforms.model=o.projections[n],this._pickShader.uniforms.clipBounds=o.clipBounds[n],this._vao.draw(e.TRIANGLES,this._vertexCount));this._vao.unbind()}if(o.showContour){var s=this._contourPickShader;s.bind(),s.uniforms=r;var l=this._contourVAO;for(l.bind(),a=0;a<3;++a)for(e.lineWidth(this.contourWidth[a]*this.pixelRatio),s.uniforms.permutation=A[a],n=0;n<this.contourLevels[a].length;++n)this._contourCounts[a][n]&&(s.uniforms.height=this.contourLevels[a][n],l.draw(e.LINES,this._contourCounts[a][n],this._contourOffsets[a][n]));for(n=0;n<3;++n)for(s.uniforms.model=o.projections[n],s.uniforms.clipBounds=o.clipBounds[n],a=0;a<3;++a)if(this.contourProject[n][a]){s.uniforms.permutation=A[a],e.lineWidth(this.contourWidth[a]*this.pixelRatio);for(var c=0;c<this.contourLevels[a].length;++c)this._contourCounts[a][c]&&(s.uniforms.height=this.contourLevels[a][c],l.draw(e.LINES,this._contourCounts[a][c],this._contourOffsets[a][c]))}l.unbind()}},C.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=this._field[2].shape,r=this._pickResult,n=e[0]*(t.value[0]+(t.value[2]>>4)/16)/255,i=Math.floor(n),a=n-i,o=e[1]*(t.value[1]+(15&t.value[2])/16)/255,s=Math.floor(o),l=o-s;i+=1,s+=1;var c=r.position;c[0]=c[1]=c[2]=0;for(var u=0;u<2;++u)for(var h=u?a:1-a,f=0;f<2;++f)for(var p=i+u,d=s+f,v=h*(f?l:1-l),m=0;m<3;++m)c[m]+=this._field[m].get(p,d)*v;for(var y=this._pickResult.level,x=0;x<3;++x)if(y[x]=g.le(this.contourLevels[x],c[x]),y[x]<0)this.contourLevels[x].length>0&&(y[x]=0);else if(y[x]<this.contourLevels[x].length-1){var b=this.contourLevels[x][y[x]],_=this.contourLevels[x][y[x]+1];Math.abs(b-c[x])>Math.abs(_-c[x])&&(y[x]+=1)}for(r.index[0]=a<.5?i:i+1,r.index[1]=l<.5?s:s+1,r.uv[0]=n/e[0],r.uv[1]=o/e[1],m=0;m<3;++m)r.dataCoordinate[m]=this._field[m].get(r.index[0],r.index[1]);return r},C.padField=function(t,e){var r=e.shape.slice(),n=t.shape.slice();c.assign(t.lo(1,1).hi(r[0],r[1]),e),c.assign(t.lo(1).hi(r[0],1),e.hi(r[0],1)),c.assign(t.lo(1,n[1]-1).hi(r[0],1),e.lo(0,r[1]-1).hi(r[0],1)),c.assign(t.lo(0,1).hi(1,r[1]),e.hi(1)),c.assign(t.lo(n[0]-1,1).hi(1,r[1]),e.lo(r[0]-1)),t.set(0,0,e.get(0,0)),t.set(0,n[1]-1,e.get(0,r[1]-1)),t.set(n[0]-1,0,e.get(r[0]-1,0)),t.set(n[0]-1,n[1]-1,e.get(r[0]-1,r[1]-1))},C.update=function(t){t=t||{},this.objectOffset=t.objectOffset||this.objectOffset,this.dirty=!0,\"contourWidth\"in t&&(this.contourWidth=B(t.contourWidth,Number)),\"showContour\"in t&&(this.showContour=B(t.showContour,Boolean)),\"showSurface\"in t&&(this.showSurface=!!t.showSurface),\"contourTint\"in t&&(this.contourTint=B(t.contourTint,Boolean)),\"contourColor\"in t&&(this.contourColor=j(t.contourColor)),\"contourProject\"in t&&(this.contourProject=B(t.contourProject,function(t){return B(t,Boolean)})),\"surfaceProject\"in t&&(this.surfaceProject=t.surfaceProject),\"dynamicColor\"in t&&(this.dynamicColor=j(t.dynamicColor)),\"dynamicTint\"in t&&(this.dynamicTint=B(t.dynamicTint,Number)),\"dynamicWidth\"in t&&(this.dynamicWidth=B(t.dynamicWidth,Number)),\"opacity\"in t&&(this.opacity=t.opacity),\"colorBounds\"in t&&(this.colorBounds=t.colorBounds),\"vertexColor\"in t&&(this.vertexColor=t.vertexColor?1:0);var e=t.field||t.coords&&t.coords[2]||null,r=!1;if(e||(e=this._field[2].shape[0]||this._field[2].shape[2]?this._field[2].lo(1,1).hi(this._field[2].shape[0]-2,this._field[2].shape[1]-2):this._field[2].hi(0,0)),\"field\"in t||\"coords\"in t){var i=(e.shape[0]+2)*(e.shape[1]+2);i>this._field[2].data.length&&(s.freeFloat(this._field[2].data),this._field[2].data=s.mallocFloat(n.nextPow2(i))),this._field[2]=h(this._field[2].data,[e.shape[0]+2,e.shape[1]+2]),this.padField(this._field[2],e),this.shape=e.shape.slice();for(var a=this.shape,o=0;o<2;++o)this._field[2].size>this._field[o].data.length&&(s.freeFloat(this._field[o].data),this._field[o].data=s.mallocFloat(this._field[2].size)),this._field[o]=h(this._field[o].data,[a[0]+2,a[1]+2]);if(t.coords){var p=t.coords;if(!Array.isArray(p)||3!==p.length)throw new Error(\"gl-surface: invalid coordinates for x/y\");for(o=0;o<2;++o){var d=p[o];for(b=0;b<2;++b)if(d.shape[b]!==a[b])throw new Error(\"gl-surface: coords have incorrect shape\");this.padField(this._field[o],d)}}else if(t.ticks){var g=t.ticks;if(!Array.isArray(g)||2!==g.length)throw new Error(\"gl-surface: invalid ticks\");for(o=0;o<2;++o){var m=g[o];if((Array.isArray(m)||m.length)&&(m=h(m)),m.shape[0]!==a[o])throw new Error(\"gl-surface: invalid tick length\");var y=h(m.data,a);y.stride[o]=m.stride[0],y.stride[1^o]=0,this.padField(this._field[o],y)}}else{for(o=0;o<2;++o){var x=[0,0];x[o]=1,this._field[o]=h(this._field[o].data,[a[0]+2,a[1]+2],x,0)}this._field[0].set(0,0,0);for(var b=0;b<a[0];++b)this._field[0].set(b+1,0,b);for(this._field[0].set(a[0]+1,0,a[0]-1),this._field[1].set(0,0,0),b=0;b<a[1];++b)this._field[1].set(0,b+1,b);this._field[1].set(0,a[1]+1,a[1]-1)}var _=this._field,w=h(s.mallocFloat(3*_[2].size*2),[3,a[0]+2,a[1]+2,2]);for(o=0;o<3;++o)v(w.pick(o),_[o],\"mirror\");var k=h(s.mallocFloat(3*_[2].size),[a[0]+2,a[1]+2,3]);for(o=0;o<a[0]+2;++o)for(b=0;b<a[1]+2;++b){var A=w.get(0,o,b,0),M=w.get(0,o,b,1),E=w.get(1,o,b,0),C=w.get(1,o,b,1),L=w.get(2,o,b,0),P=w.get(2,o,b,1),O=E*P-C*L,z=L*M-P*A,I=A*C-M*E,D=Math.sqrt(O*O+z*z+I*I);D<1e-8?(D=Math.max(Math.abs(O),Math.abs(z),Math.abs(I)))<1e-8?(I=1,z=O=0,D=1):D=1/D:D=1/Math.sqrt(D),k.set(o,b,0,O*D),k.set(o,b,1,z*D),k.set(o,b,2,I*D)}s.free(w.data);var R=[1/0,1/0,1/0],F=[-1/0,-1/0,-1/0],N=1/0,U=-1/0,V=(a[0]-1)*(a[1]-1)*6,q=s.mallocFloat(n.nextPow2(10*V)),H=0,G=0;for(o=0;o<a[0]-1;++o)t:for(b=0;b<a[1]-1;++b){for(var Y=0;Y<2;++Y)for(var W=0;W<2;++W)for(var X=0;X<3;++X){var Z=this._field[X].get(1+o+Y,1+b+W);if(isNaN(Z)||!isFinite(Z))continue t}for(X=0;X<6;++X){var J=o+T[X][0],K=b+T[X][1],$=this._field[0].get(J+1,K+1),Q=this._field[1].get(J+1,K+1);Z=this._field[2].get(J+1,K+1),O=k.get(J+1,K+1,0),z=k.get(J+1,K+1,1),I=k.get(J+1,K+1,2),t.intensity&&(tt=t.intensity.get(J,K));var tt=t.intensity?t.intensity.get(J,K):Z+this.objectOffset[2];q[H++]=J,q[H++]=K,q[H++]=$,q[H++]=Q,q[H++]=Z,q[H++]=0,q[H++]=tt,q[H++]=O,q[H++]=z,q[H++]=I,R[0]=Math.min(R[0],$+this.objectOffset[0]),R[1]=Math.min(R[1],Q+this.objectOffset[1]),R[2]=Math.min(R[2],Z+this.objectOffset[2]),N=Math.min(N,tt),F[0]=Math.max(F[0],$+this.objectOffset[0]),F[1]=Math.max(F[1],Q+this.objectOffset[1]),F[2]=Math.max(F[2],Z+this.objectOffset[2]),U=Math.max(U,tt),G+=1}}for(t.intensityBounds&&(N=+t.intensityBounds[0],U=+t.intensityBounds[1]),o=6;o<H;o+=10)q[o]=(q[o]-N)/(U-N);this._vertexCount=G,this._coordinateBuffer.update(q.subarray(0,H)),s.freeFloat(q),s.free(k.data),this.bounds=[R,F],this.intensity=t.intensity||this._field[2],this.intensityBounds[0]===N&&this.intensityBounds[1]===U||(r=!0),this.intensityBounds=[N,U]}if(\"levels\"in t){var et=t.levels;for(et=Array.isArray(et[0])?et.slice():[[],[],et],o=0;o<3;++o)et[o]=et[o].slice(),et[o].sort(function(t,e){return t-e});for(o=0;o<3;++o)for(b=0;b<et[o].length;++b)et[o][b]-=this.objectOffset[o];t:for(o=0;o<3;++o){if(et[o].length!==this.contourLevels[o].length){r=!0;break}for(b=0;b<et[o].length;++b)if(et[o][b]!==this.contourLevels[o][b]){r=!0;break t}}this.contourLevels=et}if(r){_=this._field,a=this.shape;for(var rt=[],nt=0;nt<3;++nt){var it=this.contourLevels[nt],at=[],ot=[],st=[0,0,0];for(o=0;o<it.length;++o){var lt=f(this._field[nt],it[o]);at.push(rt.length/5|0),G=0;t:for(b=0;b<lt.cells.length;++b){var ct=lt.cells[b];for(X=0;X<2;++X){var ut=lt.positions[ct[X]],ht=ut[0],ft=0|Math.floor(ht),pt=ht-ft,dt=ut[1],gt=0|Math.floor(dt),vt=dt-gt,mt=!1;e:for(var yt=0;yt<3;++yt){st[yt]=0;var xt=(nt+yt+1)%3;for(Y=0;Y<2;++Y){var bt=Y?pt:1-pt;for(J=0|Math.min(Math.max(ft+Y,0),a[0]),W=0;W<2;++W){var _t=W?vt:1-vt;if(K=0|Math.min(Math.max(gt+W,0),a[1]),Z=yt<2?this._field[xt].get(J,K):(this.intensity.get(J,K)-this.intensityBounds[0])/(this.intensityBounds[1]-this.intensityBounds[0]),!isFinite(Z)||isNaN(Z)){mt=!0;break e}var wt=bt*_t;st[yt]+=wt*Z}}}if(mt){if(X>0){for(var kt=0;kt<5;++kt)rt.pop();G-=1}continue t}rt.push(st[0],st[1],ut[0],ut[1],st[2]),G+=1}}ot.push(G)}this._contourOffsets[nt]=at,this._contourCounts[nt]=ot}var Tt=s.mallocFloat(rt.length);for(o=0;o<rt.length;++o)Tt[o]=rt[o];this._contourBuffer.update(Tt),s.freeFloat(Tt)}t.colormap&&this._colorMap.setPixels(function(t){var e=u([l({colormap:t,nshades:S,format:\"rgba\"}).map(function(t){return[t[0],t[1],t[2],255*t[3]]})]);return c.divseq(e,255),e}(t.colormap))},C.dispose=function(){this._shader.dispose(),this._vao.dispose(),this._coordinateBuffer.dispose(),this._colorMap.dispose(),this._contourBuffer.dispose(),this._contourVAO.dispose(),this._contourShader.dispose(),this._contourPickShader.dispose(),this._dynamicBuffer.dispose(),this._dynamicVAO.dispose();for(var t=0;t<3;++t)s.freeFloat(this._field[t].data)},C.highlight=function(t){var e,r;if(!t)return this._dynamicCounts=[0,0,0],this.dyanamicLevel=[NaN,NaN,NaN],void(this.highlightLevel=[-1,-1,-1]);for(e=0;e<3;++e)this.enableHighlight[e]?this.highlightLevel[e]=t.level[e]:this.highlightLevel[e]=-1;for(r=this.snapToData?t.dataCoordinate:t.position,e=0;e<3;++e)r[e]-=this.objectOffset[e];if(this.enableDynamic[0]&&r[0]!==this.dynamicLevel[0]||this.enableDynamic[1]&&r[1]!==this.dynamicLevel[1]||this.enableDynamic[2]&&r[2]!==this.dynamicLevel[2]){for(var n=0,i=this.shape,a=s.mallocFloat(12*i[0]*i[1]),o=0;o<3;++o)if(this.enableDynamic[o]){this.dynamicLevel[o]=r[o];var l=(o+1)%3,c=(o+2)%3,u=this._field[o],h=this._field[l],p=this._field[c],d=f(u,r[o]),g=d.cells,v=d.positions;for(this._dynamicOffsets[o]=n,e=0;e<g.length;++e)for(var m=g[e],y=0;y<2;++y){var x=v[m[y]],b=+x[0],_=0|b,w=0|Math.min(_+1,i[0]),k=b-_,T=1-k,A=+x[1],M=0|A,S=0|Math.min(M+1,i[1]),E=A-M,C=1-E,L=T*C,P=T*E,O=k*C,z=k*E,I=L*h.get(_,M)+P*h.get(_,S)+O*h.get(w,M)+z*h.get(w,S),D=L*p.get(_,M)+P*p.get(_,S)+O*p.get(w,M)+z*p.get(w,S);if(isNaN(I)||isNaN(D)){y&&(n-=1);break}a[2*n+0]=I,a[2*n+1]=D,n+=1}this._dynamicCounts[o]=n-this._dynamicOffsets[o]}else this.dynamicLevel[o]=NaN,this._dynamicCounts[o]=0;this._dynamicBuffer.update(a.subarray(0,2*n)),s.freeFloat(a)}}},{\"./lib/shaders\":314,\"binary-search-bounds\":315,\"bit-twiddle\":92,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,\"ndarray-gradient\":441,\"ndarray-ops\":444,\"ndarray-pack\":445,\"surface-nets\":531,\"typedarray-pool\":545}],317:[function(t,e,r){\"use strict\";var n=t(\"css-font\"),i=t(\"pick-by-alias\"),a=t(\"regl\"),o=t(\"gl-util/context\"),s=t(\"es6-weak-map\"),l=t(\"color-normalize\"),c=t(\"font-atlas\"),u=t(\"typedarray-pool\"),h=t(\"parse-rect\"),f=t(\"is-plain-obj\"),p=t(\"parse-unit\"),d=t(\"to-px\"),g=t(\"detect-kerning\"),v=t(\"object-assign\"),m=t(\"font-measure\"),y=t(\"flatten-vertex-data\"),x=t(\"bit-twiddle\").nextPow2,b=new s,_=!1;if(document.body){var w=document.body.appendChild(document.createElement(\"div\"));w.style.font=\"italic small-caps bold condensed 16px/2 cursive\",getComputedStyle(w).fontStretch&&(_=!0),document.body.removeChild(w)}var k=function(t){!function(t){return\"function\"==typeof t&&t._gl&&t.prop&&t.texture&&t.buffer}(t)?this.gl=o(t):(t={regl:t},this.gl=t.regl._gl),this.shader=b.get(this.gl),this.shader?this.regl=this.shader.regl:this.regl=t.regl||a({gl:this.gl}),this.charBuffer=this.regl.buffer({type:\"uint8\",usage:\"stream\"}),this.sizeBuffer=this.regl.buffer({type:\"float\",usage:\"stream\"}),this.shader||(this.shader=this.createShader(),b.set(this.gl,this.shader)),this.batch=[],this.fontSize=[],this.font=[],this.fontAtlas=[],this.draw=this.shader.draw.bind(this),this.render=function(){this.regl._refresh(),this.draw(this.batch)},this.canvas=this.gl.canvas,this.update(f(t)?t:{})};k.prototype.createShader=function(){var t=this.regl,e=t({blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},stencil:{enable:!1},depth:{enable:!1},count:t.prop(\"count\"),offset:t.prop(\"offset\"),attributes:{charOffset:{offset:4,stride:8,buffer:t.this(\"sizeBuffer\")},width:{offset:0,stride:8,buffer:t.this(\"sizeBuffer\")},char:t.this(\"charBuffer\"),position:t.this(\"position\")},uniforms:{atlasSize:function(t,e){return[e.atlas.width,e.atlas.height]},atlasDim:function(t,e){return[e.atlas.cols,e.atlas.rows]},atlas:function(t,e){return e.atlas.texture},charStep:function(t,e){return e.atlas.step},em:function(t,e){return e.atlas.em},color:t.prop(\"color\"),opacity:t.prop(\"opacity\"),viewport:t.this(\"viewportArray\"),scale:t.this(\"scale\"),align:t.prop(\"align\"),baseline:t.prop(\"baseline\"),translate:t.this(\"translate\"),positionOffset:t.prop(\"positionOffset\")},primitive:\"points\",viewport:t.this(\"viewport\"),vert:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tattribute float width, charOffset, char;\\n\\t\\t\\tattribute vec2 position;\\n\\t\\t\\tuniform float fontSize, charStep, em, align, baseline;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tuniform vec4 color;\\n\\t\\t\\tuniform vec2 atlasSize, atlasDim, scale, translate, positionOffset;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\t\"+(k.normalViewport?\"\":\"vec2 positionOffset = vec2(positionOffset.x,- positionOffset.y);\")+\"\\n\\n\\t\\t\\t\\tvec2 offset = floor(em * (vec2(align + charOffset, baseline)\\n\\t\\t\\t\\t\\t+ positionOffset))\\n\\t\\t\\t\\t\\t/ (viewport.zw * scale.xy);\\n\\n\\t\\t\\t\\tvec2 position = (position + translate) * scale;\\n\\t\\t\\t\\tposition += offset * scale;\\n\\n\\t\\t\\t\\t\"+(k.normalViewport?\"position.y = 1. - position.y;\":\"\")+\"\\n\\n\\t\\t\\t\\tcharCoord = position * viewport.zw + viewport.xy;\\n\\n\\t\\t\\t\\tgl_Position = vec4(position * 2. - 1., 0, 1);\\n\\n\\t\\t\\t\\tgl_PointSize = charStep;\\n\\n\\t\\t\\t\\tcharId.x = mod(char, atlasDim.x);\\n\\t\\t\\t\\tcharId.y = floor(char / atlasDim.x);\\n\\n\\t\\t\\t\\tcharWidth = width * em;\\n\\n\\t\\t\\t\\tfontColor = color / 255.;\\n\\t\\t\\t}\",frag:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tuniform sampler2D atlas;\\n\\t\\t\\tuniform float fontSize, charStep, opacity;\\n\\t\\t\\tuniform vec2 atlasSize;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\n\\t\\t\\tfloat lightness(vec4 color) {\\n\\t\\t\\t\\treturn color.r * 0.299 + color.g * 0.587 + color.b * 0.114;\\n\\t\\t\\t}\\n\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\tvec2 uv = gl_FragCoord.xy - charCoord + charStep * .5;\\n\\t\\t\\t\\tfloat halfCharStep = floor(charStep * .5 + .5);\\n\\n\\t\\t\\t\\t// invert y and shift by 1px (FF expecially needs that)\\n\\t\\t\\t\\tuv.y = charStep - uv.y;\\n\\n\\t\\t\\t\\t// ignore points outside of character bounding box\\n\\t\\t\\t\\tfloat halfCharWidth = ceil(charWidth * .5);\\n\\t\\t\\t\\tif (floor(uv.x) > halfCharStep + halfCharWidth ||\\n\\t\\t\\t\\t\\tfloor(uv.x) < halfCharStep - halfCharWidth) return;\\n\\n\\t\\t\\t\\tuv += charId * charStep;\\n\\t\\t\\t\\tuv = uv / atlasSize;\\n\\n\\t\\t\\t\\tvec4 color = fontColor;\\n\\t\\t\\t\\tvec4 mask = texture2D(atlas, uv);\\n\\n\\t\\t\\t\\tfloat maskY = lightness(mask);\\n\\t\\t\\t\\t// float colorY = lightness(color);\\n\\t\\t\\t\\tcolor.a *= maskY;\\n\\t\\t\\t\\tcolor.a *= opacity;\\n\\n\\t\\t\\t\\t// color.a += .1;\\n\\n\\t\\t\\t\\t// antialiasing, see yiq color space y-channel formula\\n\\t\\t\\t\\t// color.rgb += (1. - color.rgb) * (1. - mask.rgb);\\n\\n\\t\\t\\t\\tgl_FragColor = color;\\n\\t\\t\\t}\"});return{regl:t,draw:e,atlas:{}}},k.prototype.update=function(t){var e=this;if(\"string\"==typeof t)t={text:t};else if(!t)return;null!=(t=i(t,{position:\"position positions coord coords coordinates\",font:\"font fontFace fontface typeface cssFont css-font family fontFamily\",fontSize:\"fontSize fontsize size font-size\",text:\"text texts chars characters value values symbols\",align:\"align alignment textAlign textbaseline\",baseline:\"baseline textBaseline textbaseline\",direction:\"dir direction textDirection\",color:\"color colour fill fill-color fillColor textColor textcolor\",kerning:\"kerning kern\",range:\"range dataBox\",viewport:\"vp viewport viewBox viewbox viewPort\",opacity:\"opacity alpha transparency visible visibility opaque\",offset:\"offset positionOffset padding shift indent indentation\"},!0)).opacity&&(Array.isArray(t.opacity)?this.opacity=t.opacity.map(function(t){return parseFloat(t)}):this.opacity=parseFloat(t.opacity)),null!=t.viewport&&(this.viewport=h(t.viewport),k.normalViewport&&(this.viewport.y=this.canvas.height-this.viewport.y-this.viewport.height),this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null==this.viewport&&(this.viewport={x:0,y:0,width:this.gl.drawingBufferWidth,height:this.gl.drawingBufferHeight},this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null!=t.kerning&&(this.kerning=t.kerning),null!=t.offset&&(\"number\"==typeof t.offset&&(t.offset=[t.offset,0]),this.positionOffset=y(t.offset)),t.direction&&(this.direction=t.direction),t.range&&(this.range=t.range,this.scale=[1/(t.range[2]-t.range[0]),1/(t.range[3]-t.range[1])],this.translate=[-t.range[0],-t.range[1]]),t.scale&&(this.scale=t.scale),t.translate&&(this.translate=t.translate),this.scale||(this.scale=[1/this.viewport.width,1/this.viewport.height]),this.translate||(this.translate=[0,0]),this.font.length||t.font||(t.font=k.baseFontSize+\"px sans-serif\");var r,a=!1,o=!1;if(t.font&&(Array.isArray(t.font)?t.font:[t.font]).forEach(function(t,r){if(\"string\"==typeof t)try{t=n.parse(t)}catch(e){t=n.parse(k.baseFontSize+\"px \"+t)}else t=n.parse(n.stringify(t));var i=n.stringify({size:k.baseFontSize,family:t.family,stretch:_?t.stretch:void 0,variant:t.variant,weight:t.weight,style:t.style}),s=p(t.size),l=Math.round(s[0]*d(s[1]));if(l!==e.fontSize[r]&&(o=!0,e.fontSize[r]=l),!(e.font[r]&&i==e.font[r].baseString||(a=!0,e.font[r]=k.fonts[i],e.font[r]))){var c=t.family.join(\", \"),u=[t.style];t.style!=t.variant&&u.push(t.variant),t.variant!=t.weight&&u.push(t.weight),_&&t.weight!=t.stretch&&u.push(t.stretch),e.font[r]={baseString:i,family:c,weight:t.weight,stretch:t.stretch,style:t.style,variant:t.variant,width:{},kerning:{},metrics:m(c,{origin:\"top\",fontSize:k.baseFontSize,fontStyle:u.join(\" \")})},k.fonts[i]=e.font[r]}}),(a||o)&&this.font.forEach(function(r,i){var a=n.stringify({size:e.fontSize[i],family:r.family,stretch:_?r.stretch:void 0,variant:r.variant,weight:r.weight,style:r.style});if(e.fontAtlas[i]=e.shader.atlas[a],!e.fontAtlas[i]){var o=r.metrics;e.shader.atlas[a]=e.fontAtlas[i]={fontString:a,step:2*Math.ceil(e.fontSize[i]*o.bottom*.5),em:e.fontSize[i],cols:0,rows:0,height:0,width:0,chars:[],ids:{},texture:e.regl.texture()}}null==t.text&&(t.text=e.text)}),\"string\"==typeof t.text&&t.position&&t.position.length>2){for(var s=Array(.5*t.position.length),f=0;f<s.length;f++)s[f]=t.text;t.text=s}if(null!=t.text||a){if(this.textOffsets=[0],Array.isArray(t.text)){this.count=t.text[0].length,this.counts=[this.count];for(var b=1;b<t.text.length;b++)this.textOffsets[b]=this.textOffsets[b-1]+t.text[b-1].length,this.count+=t.text[b].length,this.counts.push(t.text[b].length);this.text=t.text.join(\"\")}else this.text=t.text,this.count=this.text.length,this.counts=[this.count];r=[],this.font.forEach(function(t,n){k.atlasContext.font=t.baseString;for(var i=e.fontAtlas[n],a=0;a<e.text.length;a++){var o=e.text.charAt(a);if(null==i.ids[o]&&(i.ids[o]=i.chars.length,i.chars.push(o),r.push(o)),null==t.width[o]&&(t.width[o]=k.atlasContext.measureText(o).width/k.baseFontSize,e.kerning)){var s=[];for(var l in t.width)s.push(l+o,o+l);v(t.kerning,g(t.family,{pairs:s}))}}})}if(t.position)if(t.position.length>2){for(var w=!t.position[0].length,T=u.mallocFloat(2*this.count),A=0,M=0;A<this.counts.length;A++){var S=this.counts[A];if(w)for(var E=0;E<S;E++)T[M++]=t.position[2*A],T[M++]=t.position[2*A+1];else for(var C=0;C<S;C++)T[M++]=t.position[A][0],T[M++]=t.position[A][1]}this.position.call?this.position({type:\"float\",data:T}):this.position=this.regl.buffer({type:\"float\",data:T}),u.freeFloat(T)}else this.position.destroy&&this.position.destroy(),this.position={constant:t.position};if(t.text||a){var L=u.mallocUint8(this.count),P=u.mallocFloat(2*this.count);this.textWidth=[];for(var O=0,z=0;O<this.counts.length;O++){for(var I=this.counts[O],D=this.font[O]||this.font[0],R=this.fontAtlas[O]||this.fontAtlas[0],F=0;F<I;F++){var B=this.text.charAt(z),N=this.text.charAt(z-1);if(L[z]=R.ids[B],P[2*z]=D.width[B],F){var j=P[2*z-2],U=P[2*z],V=P[2*z-1]+.5*j+.5*U;if(this.kerning){var q=D.kerning[N+B];q&&(V+=.001*q)}P[2*z+1]=V}else P[2*z+1]=.5*P[2*z];z++}this.textWidth.push(P.length?.5*P[2*z-2]+P[2*z-1]:0)}t.align||(t.align=this.align),this.charBuffer({data:L,type:\"uint8\",usage:\"stream\"}),this.sizeBuffer({data:P,type:\"float\",usage:\"stream\"}),u.freeUint8(L),u.freeFloat(P),r.length&&this.font.forEach(function(t,r){var n=e.fontAtlas[r],i=n.step,a=Math.floor(k.maxAtlasSize/i),o=Math.min(a,n.chars.length),s=Math.ceil(n.chars.length/o),l=x(o*i),u=x(s*i);n.width=l,n.height=u,n.rows=s,n.cols=o,n.em&&n.texture({data:c({canvas:k.atlasCanvas,font:n.fontString,chars:n.chars,shape:[l,u],step:[i,i]})})})}if(t.align&&(this.align=t.align,this.alignOffset=this.textWidth.map(function(t,r){var n=Array.isArray(e.align)?e.align.length>1?e.align[r]:e.align[0]:e.align;if(\"number\"==typeof n)return n;switch(n){case\"right\":case\"end\":return-t;case\"center\":case\"centre\":case\"middle\":return.5*-t}return 0})),null==this.baseline&&null==t.baseline&&(t.baseline=0),null!=t.baseline&&(this.baseline=t.baseline,Array.isArray(this.baseline)||(this.baseline=[this.baseline]),this.baselineOffset=this.baseline.map(function(t,r){var n=(e.font[r]||e.font[0]).metrics,i=0;return i+=.5*n.bottom,i+=\"number\"==typeof t?t-n.baseline:-n[t],k.normalViewport||(i*=-1),i})),null!=t.color)if(t.color||(t.color=\"transparent\"),\"string\"!=typeof t.color&&isNaN(t.color)){var H;if(\"number\"==typeof t.color[0]&&t.color.length>this.counts.length){var G=t.color.length;H=u.mallocUint8(G);for(var Y=(t.color.subarray||t.color.slice).bind(t.color),W=0;W<G;W+=4)H.set(l(Y(W,W+4),\"uint8\"),W)}else{var X=t.color.length;H=u.mallocUint8(4*X);for(var Z=0;Z<X;Z++)H.set(l(t.color[Z]||0,\"uint8\"),4*Z)}this.color=H}else this.color=l(t.color,\"uint8\");if(t.position||t.text||t.color||t.baseline||t.align||t.font||t.offset||t.opacity)if(this.color.length>4||this.baselineOffset.length>1||this.align&&this.align.length>1||this.fontAtlas.length>1||this.positionOffset.length>2){var J=Math.max(.5*this.position.length||0,.25*this.color.length||0,this.baselineOffset.length||0,this.alignOffset.length||0,this.font.length||0,this.opacity.length||0,.5*this.positionOffset.length||0);this.batch=Array(J);for(var K=0;K<this.batch.length;K++)this.batch[K]={count:this.counts.length>1?this.counts[K]:this.counts[0],offset:this.textOffsets.length>1?this.textOffsets[K]:this.textOffsets[0],color:this.color?this.color.length<=4?this.color:this.color.subarray(4*K,4*K+4):[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[K]:this.opacity,baseline:null!=this.baselineOffset[K]?this.baselineOffset[K]:this.baselineOffset[0],align:this.align?null!=this.alignOffset[K]?this.alignOffset[K]:this.alignOffset[0]:0,atlas:this.fontAtlas[K]||this.fontAtlas[0],positionOffset:this.positionOffset.length>2?this.positionOffset.subarray(2*K,2*K+2):this.positionOffset}}else this.count?this.batch=[{count:this.count,offset:0,color:this.color||[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[0]:this.opacity,baseline:this.baselineOffset[0],align:this.alignOffset?this.alignOffset[0]:0,atlas:this.fontAtlas[0],positionOffset:this.positionOffset}]:this.batch=[]},k.prototype.destroy=function(){},k.prototype.kerning=!0,k.prototype.position={constant:new Float32Array(2)},k.prototype.translate=null,k.prototype.scale=null,k.prototype.font=null,k.prototype.text=\"\",k.prototype.positionOffset=[0,0],k.prototype.opacity=1,k.prototype.color=new Uint8Array([0,0,0,255]),k.prototype.alignOffset=[0,0],k.normalViewport=!1,k.maxAtlasSize=1024,k.atlasCanvas=document.createElement(\"canvas\"),k.atlasContext=k.atlasCanvas.getContext(\"2d\",{alpha:!1}),k.baseFontSize=64,k.fonts={},e.exports=k},{\"bit-twiddle\":92,\"color-normalize\":120,\"css-font\":139,\"detect-kerning\":166,\"es6-weak-map\":318,\"flatten-vertex-data\":227,\"font-atlas\":228,\"font-measure\":229,\"gl-util/context\":323,\"is-plain-obj\":422,\"object-assign\":454,\"parse-rect\":459,\"parse-unit\":461,\"pick-by-alias\":465,regl:502,\"to-px\":539,\"typedarray-pool\":545}],318:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?WeakMap:t(\"./polyfill\")},{\"./is-implemented\":319,\"./polyfill\":321}],319:[function(t,e,r){\"use strict\";e.exports=function(){var t,e;if(\"function\"!=typeof WeakMap)return!1;try{t=new WeakMap([[e={},\"one\"],[{},\"two\"],[{},\"three\"]])}catch(t){return!1}return\"[object WeakMap]\"===String(t)&&(\"function\"==typeof t.set&&(t.set({},1)===t&&(\"function\"==typeof t.delete&&(\"function\"==typeof t.has&&\"one\"===t.get(e)))))}},{}],320:[function(t,e,r){\"use strict\";e.exports=\"function\"==typeof WeakMap&&\"[object WeakMap]\"===Object.prototype.toString.call(new WeakMap)},{}],321:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/object/set-prototype-of\"),o=t(\"es5-ext/object/valid-object\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"es5-ext/string/random-uniq\"),c=t(\"d\"),u=t(\"es6-iterator/get\"),h=t(\"es6-iterator/for-of\"),f=t(\"es6-symbol\").toStringTag,p=t(\"./is-native-implemented\"),d=Array.isArray,g=Object.defineProperty,v=Object.prototype.hasOwnProperty,m=Object.getPrototypeOf;e.exports=n=function(){var t,e=arguments[0];if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");return t=p&&a&&WeakMap!==n?a(new WeakMap,m(this)):this,i(e)&&(d(e)||(e=u(e))),g(t,\"__weakMapData__\",c(\"c\",\"$weakMap$\"+l())),e?(h(e,function(e){s(e),t.set(e[0],e[1])}),t):t},p&&(a&&a(n,WeakMap),n.prototype=Object.create(WeakMap.prototype,{constructor:c(n)})),Object.defineProperties(n.prototype,{delete:c(function(t){return!!v.call(o(t),this.__weakMapData__)&&(delete t[this.__weakMapData__],!0)}),get:c(function(t){if(v.call(o(t),this.__weakMapData__))return t[this.__weakMapData__]}),has:c(function(t){return v.call(o(t),this.__weakMapData__)}),set:c(function(t,e){return g(o(t),this.__weakMapData__,c(\"c\",e)),this}),toString:c(function(){return\"[object WeakMap]\"})}),g(n.prototype,f,c(\"c\",\"WeakMap\"))},{\"./is-native-implemented\":320,d:151,\"es5-ext/object/is-value\":194,\"es5-ext/object/set-prototype-of\":200,\"es5-ext/object/valid-object\":204,\"es5-ext/object/valid-value\":205,\"es5-ext/string/random-uniq\":210,\"es6-iterator/for-of\":212,\"es6-iterator/get\":213,\"es6-symbol\":219}],322:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"ndarray-ops\"),a=t(\"typedarray-pool\");e.exports=function(t){if(arguments.length<=1)throw new Error(\"gl-texture2d: Missing arguments for texture2d constructor\");o||function(t){o=[t.LINEAR,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_NEAREST],s=[t.NEAREST,t.LINEAR,t.NEAREST_MIPMAP_NEAREST,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_LINEAR],l=[t.REPEAT,t.CLAMP_TO_EDGE,t.MIRRORED_REPEAT]}(t);if(\"number\"==typeof arguments[1])return v(t,arguments[1],arguments[2],arguments[3]||t.RGBA,arguments[4]||t.UNSIGNED_BYTE);if(Array.isArray(arguments[1]))return v(t,0|arguments[1][0],0|arguments[1][1],arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(\"object\"==typeof arguments[1]){var e=arguments[1],r=c(e)?e:e.raw;if(r)return function(t,e,r,n,i,a){var o=g(t);return t.texImage2D(t.TEXTURE_2D,0,i,i,a,e),new f(t,o,r,n,i,a)}(t,r,0|e.width,0|e.height,arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(e.shape&&e.data&&e.stride)return function(t,e){var r=e.dtype,o=e.shape.slice(),s=t.getParameter(t.MAX_TEXTURE_SIZE);if(o[0]<0||o[0]>s||o[1]<0||o[1]>s)throw new Error(\"gl-texture2d: Invalid texture size\");var l=d(o,e.stride.slice()),c=0;\"float32\"===r?c=t.FLOAT:\"float64\"===r?(c=t.FLOAT,l=!1,r=\"float32\"):\"uint8\"===r?c=t.UNSIGNED_BYTE:(c=t.UNSIGNED_BYTE,l=!1,r=\"uint8\");var h,p,v=0;if(2===o.length)v=t.LUMINANCE,o=[o[0],o[1],1],e=n(e.data,o,[e.stride[0],e.stride[1],1],e.offset);else{if(3!==o.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===o[2])v=t.ALPHA;else if(2===o[2])v=t.LUMINANCE_ALPHA;else if(3===o[2])v=t.RGB;else{if(4!==o[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");v=t.RGBA}}c!==t.FLOAT||t.getExtension(\"OES_texture_float\")||(c=t.UNSIGNED_BYTE,l=!1);var m=e.size;if(l)h=0===e.offset&&e.data.length===m?e.data:e.data.subarray(e.offset,e.offset+m);else{var y=[o[2],o[2]*o[0],1];p=a.malloc(m,r);var x=n(p,o,y,0);\"float32\"!==r&&\"float64\"!==r||c!==t.UNSIGNED_BYTE?i.assign(x,e):u(x,e),h=p.subarray(0,m)}var b=g(t);t.texImage2D(t.TEXTURE_2D,0,v,o[0],o[1],0,v,c,h),l||a.free(p);return new f(t,b,o[0],o[1],v,c)}(t,e)}throw new Error(\"gl-texture2d: Invalid arguments for texture2d constructor\")};var o=null,s=null,l=null;function c(t){return\"undefined\"!=typeof HTMLCanvasElement&&t instanceof HTMLCanvasElement||\"undefined\"!=typeof HTMLImageElement&&t instanceof HTMLImageElement||\"undefined\"!=typeof HTMLVideoElement&&t instanceof HTMLVideoElement||\"undefined\"!=typeof ImageData&&t instanceof ImageData}var u=function(t,e){i.muls(t,e,255)};function h(t,e,r){var n=t.gl,i=n.getParameter(n.MAX_TEXTURE_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-texture2d: Invalid texture size\");return t._shape=[e,r],t.bind(),n.texImage2D(n.TEXTURE_2D,0,t.format,e,r,0,t.format,t.type,null),t._mipLevels=[0],t}function f(t,e,r,n,i,a){this.gl=t,this.handle=e,this.format=i,this.type=a,this._shape=[r,n],this._mipLevels=[0],this._magFilter=t.NEAREST,this._minFilter=t.NEAREST,this._wrapS=t.CLAMP_TO_EDGE,this._wrapT=t.CLAMP_TO_EDGE,this._anisoSamples=1;var o=this,s=[this._wrapS,this._wrapT];Object.defineProperties(s,[{get:function(){return o._wrapS},set:function(t){return o.wrapS=t}},{get:function(){return o._wrapT},set:function(t){return o.wrapT=t}}]),this._wrapVector=s;var l=[this._shape[0],this._shape[1]];Object.defineProperties(l,[{get:function(){return o._shape[0]},set:function(t){return o.width=t}},{get:function(){return o._shape[1]},set:function(t){return o.height=t}}]),this._shapeVector=l}var p=f.prototype;function d(t,e){return 3===t.length?1===e[2]&&e[1]===t[0]*t[2]&&e[0]===t[2]:1===e[0]&&e[1]===t[0]}function g(t){var e=t.createTexture();return t.bindTexture(t.TEXTURE_2D,e),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MIN_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MAG_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_S,t.CLAMP_TO_EDGE),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_T,t.CLAMP_TO_EDGE),e}function v(t,e,r,n,i){var a=t.getParameter(t.MAX_TEXTURE_SIZE);if(e<0||e>a||r<0||r>a)throw new Error(\"gl-texture2d: Invalid texture shape\");if(i===t.FLOAT&&!t.getExtension(\"OES_texture_float\"))throw new Error(\"gl-texture2d: Floating point textures not supported on this platform\");var o=g(t);return t.texImage2D(t.TEXTURE_2D,0,n,e,r,0,n,i,null),new f(t,o,e,r,n,i)}Object.defineProperties(p,{minFilter:{get:function(){return this._minFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,t),this._minFilter=t}},magFilter:{get:function(){return this._magFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,t),this._magFilter=t}},mipSamples:{get:function(){return this._anisoSamples},set:function(t){var e=this._anisoSamples;if(this._anisoSamples=0|Math.max(t,1),e!==this._anisoSamples){var r=this.gl.getExtension(\"EXT_texture_filter_anisotropic\");r&&this.gl.texParameterf(this.gl.TEXTURE_2D,r.TEXTURE_MAX_ANISOTROPY_EXT,this._anisoSamples)}return this._anisoSamples}},wrapS:{get:function(){return this._wrapS},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_S,t),this._wrapS=t}},wrapT:{get:function(){return this._wrapT},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_T,t),this._wrapT=t}},wrap:{get:function(){return this._wrapVector},set:function(t){if(Array.isArray(t)||(t=[t,t]),2!==t.length)throw new Error(\"gl-texture2d: Must specify wrap mode for rows and columns\");for(var e=0;e<2;++e)if(l.indexOf(t[e])<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);this._wrapS=t[0],this._wrapT=t[1];var r=this.gl;return this.bind(),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_S,this._wrapS),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_T,this._wrapT),t}},shape:{get:function(){return this._shapeVector},set:function(t){if(Array.isArray(t)){if(2!==t.length)throw new Error(\"gl-texture2d: Invalid texture shape\")}else t=[0|t,0|t];return h(this,0|t[0],0|t[1]),[0|t[0],0|t[1]]}},width:{get:function(){return this._shape[0]},set:function(t){return h(this,t|=0,this._shape[1]),t}},height:{get:function(){return this._shape[1]},set:function(t){return t|=0,h(this,this._shape[0],t),t}}}),p.bind=function(t){var e=this.gl;return void 0!==t&&e.activeTexture(e.TEXTURE0+(0|t)),e.bindTexture(e.TEXTURE_2D,this.handle),void 0!==t?0|t:e.getParameter(e.ACTIVE_TEXTURE)-e.TEXTURE0},p.dispose=function(){this.gl.deleteTexture(this.handle)},p.generateMipmap=function(){this.bind(),this.gl.generateMipmap(this.gl.TEXTURE_2D);for(var t=Math.min(this._shape[0],this._shape[1]),e=0;t>0;++e,t>>>=1)this._mipLevels.indexOf(e)<0&&this._mipLevels.push(e)},p.setPixels=function(t,e,r,o){var s=this.gl;this.bind(),Array.isArray(e)?(o=r,r=0|e[1],e=0|e[0]):(e=e||0,r=r||0),o=o||0;var l=c(t)?t:t.raw;if(l){this._mipLevels.indexOf(o)<0?(s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,this.type,l),this._mipLevels.push(o)):s.texSubImage2D(s.TEXTURE_2D,o,e,r,this.format,this.type,l)}else{if(!(t.shape&&t.stride&&t.data))throw new Error(\"gl-texture2d: Unsupported data type\");if(t.shape.length<2||e+t.shape[1]>this._shape[1]>>>o||r+t.shape[0]>this._shape[0]>>>o||e<0||r<0)throw new Error(\"gl-texture2d: Texture dimensions are out of bounds\");!function(t,e,r,o,s,l,c,h){var f=h.dtype,p=h.shape.slice();if(p.length<2||p.length>3)throw new Error(\"gl-texture2d: Invalid ndarray, must be 2d or 3d\");var g=0,v=0,m=d(p,h.stride.slice());\"float32\"===f?g=t.FLOAT:\"float64\"===f?(g=t.FLOAT,m=!1,f=\"float32\"):\"uint8\"===f?g=t.UNSIGNED_BYTE:(g=t.UNSIGNED_BYTE,m=!1,f=\"uint8\");if(2===p.length)v=t.LUMINANCE,p=[p[0],p[1],1],h=n(h.data,p,[h.stride[0],h.stride[1],1],h.offset);else{if(3!==p.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===p[2])v=t.ALPHA;else if(2===p[2])v=t.LUMINANCE_ALPHA;else if(3===p[2])v=t.RGB;else{if(4!==p[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");v=t.RGBA}p[2]}v!==t.LUMINANCE&&v!==t.ALPHA||s!==t.LUMINANCE&&s!==t.ALPHA||(v=s);if(v!==s)throw new Error(\"gl-texture2d: Incompatible texture format for setPixels\");var y=h.size,x=c.indexOf(o)<0;x&&c.push(o);if(g===l&&m)0===h.offset&&h.data.length===y?x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,h.data):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,h.data):x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,h.data.subarray(h.offset,h.offset+y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,h.data.subarray(h.offset,h.offset+y));else{var b;b=l===t.FLOAT?a.mallocFloat32(y):a.mallocUint8(y);var _=n(b,p,[p[2],p[2]*p[0],1]);g===t.FLOAT&&l===t.UNSIGNED_BYTE?u(_,h):i.assign(_,h),x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,b.subarray(0,y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,b.subarray(0,y)),l===t.FLOAT?a.freeFloat32(b):a.freeUint8(b)}}(s,e,r,o,this.format,this.type,this._mipLevels,t)}}},{ndarray:450,\"ndarray-ops\":444,\"typedarray-pool\":545}],323:[function(t,e,r){(function(r){\"use strict\";var n=t(\"pick-by-alias\");function i(t){if(t.container)if(t.container==document.body)document.body.style.width||(t.canvas.width=t.width||t.pixelRatio*r.innerWidth),document.body.style.height||(t.canvas.height=t.height||t.pixelRatio*r.innerHeight);else{var e=t.container.getBoundingClientRect();t.canvas.width=t.width||e.right-e.left,t.canvas.height=t.height||e.bottom-e.top}}function a(t){return\"function\"==typeof t.getContext&&\"width\"in t&&\"height\"in t}function o(){var t=document.createElement(\"canvas\");return t.style.position=\"absolute\",t.style.top=0,t.style.left=0,t}e.exports=function(t){var e;if(t?\"string\"==typeof t&&(t={container:t}):t={},a(t)?t={container:t}:t=\"string\"==typeof(e=t).nodeName&&\"function\"==typeof e.appendChild&&\"function\"==typeof e.getBoundingClientRect?{container:t}:function(t){return\"function\"==typeof t.drawArrays||\"function\"==typeof t.drawElements}(t)?{gl:t}:n(t,{container:\"container target element el canvas holder parent parentNode wrapper use ref root node\",gl:\"gl context webgl glContext\",attrs:\"attributes attrs contextAttributes\",pixelRatio:\"pixelRatio pxRatio px ratio pxratio pixelratio\",width:\"w width\",height:\"h height\"},!0),t.pixelRatio||(t.pixelRatio=r.pixelRatio||1),t.gl)return t.gl;if(t.canvas&&(t.container=t.canvas.parentNode),t.container){if(\"string\"==typeof t.container){var s=document.querySelector(t.container);if(!s)throw Error(\"Element \"+t.container+\" is not found\");t.container=s}a(t.container)?(t.canvas=t.container,t.container=t.canvas.parentNode):t.canvas||(t.canvas=o(),t.container.appendChild(t.canvas),i(t))}else if(!t.canvas){if(\"undefined\"==typeof document)throw Error(\"Not DOM environment. Use headless-gl.\");t.container=document.body||document.documentElement,t.canvas=o(),t.container.appendChild(t.canvas),i(t)}if(!t.gl)try{t.gl=t.canvas.getContext(\"webgl\",t.attrs)}catch(e){try{t.gl=t.canvas.getContext(\"experimental-webgl\",t.attrs)}catch(e){t.gl=t.canvas.getContext(\"webgl-experimental\",t.attrs)}}return t.gl}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"pick-by-alias\":465}],324:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){e?e.bind():t.bindBuffer(t.ELEMENT_ARRAY_BUFFER,null);var n=0|t.getParameter(t.MAX_VERTEX_ATTRIBS);if(r){if(r.length>n)throw new Error(\"gl-vao: Too many vertex attributes\");for(var i=0;i<r.length;++i){var a=r[i];if(a.buffer){var o=a.buffer,s=a.size||4,l=a.type||t.FLOAT,c=!!a.normalized,u=a.stride||0,h=a.offset||0;o.bind(),t.enableVertexAttribArray(i),t.vertexAttribPointer(i,s,l,c,u,h)}else{if(\"number\"==typeof a)t.vertexAttrib1f(i,a);else if(1===a.length)t.vertexAttrib1f(i,a[0]);else if(2===a.length)t.vertexAttrib2f(i,a[0],a[1]);else if(3===a.length)t.vertexAttrib3f(i,a[0],a[1],a[2]);else{if(4!==a.length)throw new Error(\"gl-vao: Invalid vertex attribute\");t.vertexAttrib4f(i,a[0],a[1],a[2],a[3])}t.disableVertexAttribArray(i)}}for(;i<n;++i)t.disableVertexAttribArray(i)}else for(t.bindBuffer(t.ARRAY_BUFFER,null),i=0;i<n;++i)t.disableVertexAttribArray(i)}},{}],325:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t){this.gl=t,this._elements=null,this._attributes=null,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(){n(this.gl,this._elements,this._attributes)},i.prototype.update=function(t,e,r){this._elements=e,this._attributes=t,this._elementsType=r||this.gl.UNSIGNED_SHORT},i.prototype.dispose=function(){},i.prototype.unbind=function(){},i.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._elements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t){return new i(t)}},{\"./do-bind.js\":324}],326:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t,e,r,n,i,a){this.location=t,this.dimension=e,this.a=r,this.b=n,this.c=i,this.d=a}function a(t,e,r){this.gl=t,this._ext=e,this.handle=r,this._attribs=[],this._useElements=!1,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(t){switch(this.dimension){case 1:t.vertexAttrib1f(this.location,this.a);break;case 2:t.vertexAttrib2f(this.location,this.a,this.b);break;case 3:t.vertexAttrib3f(this.location,this.a,this.b,this.c);break;case 4:t.vertexAttrib4f(this.location,this.a,this.b,this.c,this.d)}},a.prototype.bind=function(){this._ext.bindVertexArrayOES(this.handle);for(var t=0;t<this._attribs.length;++t)this._attribs[t].bind(this.gl)},a.prototype.unbind=function(){this._ext.bindVertexArrayOES(null)},a.prototype.dispose=function(){this._ext.deleteVertexArrayOES(this.handle)},a.prototype.update=function(t,e,r){if(this.bind(),n(this.gl,e,t),this.unbind(),this._attribs.length=0,t)for(var a=0;a<t.length;++a){var o=t[a];\"number\"==typeof o?this._attribs.push(new i(a,1,o)):Array.isArray(o)&&this._attribs.push(new i(a,o.length,o[0],o[1],o[2],o[3]))}this._useElements=!!e,this._elementsType=r||this.gl.UNSIGNED_SHORT},a.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._useElements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t,e){return new a(t,e,e.createVertexArrayOES())}},{\"./do-bind.js\":324}],327:[function(t,e,r){\"use strict\";var n=t(\"./lib/vao-native.js\"),i=t(\"./lib/vao-emulated.js\");function a(t){this.bindVertexArrayOES=t.bindVertexArray.bind(t),this.createVertexArrayOES=t.createVertexArray.bind(t),this.deleteVertexArrayOES=t.deleteVertexArray.bind(t)}e.exports=function(t,e,r,o){var s,l=t.createVertexArray?new a(t):t.getExtension(\"OES_vertex_array_object\");return(s=l?n(t,l):i(t)).update(e,r,o),s}},{\"./lib/vao-emulated.js\":325,\"./lib/vao-native.js\":326}],328:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t}},{}],329:[function(t,e,r){e.exports=function(t,e){var r=n(t[0],t[1],t[2]),o=n(e[0],e[1],e[2]);i(r,r),i(o,o);var s=a(r,o);return s>1?0:Math.acos(s)};var n=t(\"./fromValues\"),i=t(\"./normalize\"),a=t(\"./dot\")},{\"./dot\":339,\"./fromValues\":345,\"./normalize\":356}],330:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.ceil(e[0]),t[1]=Math.ceil(e[1]),t[2]=Math.ceil(e[2]),t}},{}],331:[function(t,e,r){e.exports=function(t){var e=new Float32Array(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e}},{}],332:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}},{}],333:[function(t,e,r){e.exports=function(){var t=new Float32Array(3);return t[0]=0,t[1]=0,t[2]=0,t}},{}],334:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2];return t[0]=i*l-a*s,t[1]=a*o-n*l,t[2]=n*s-i*o,t}},{}],335:[function(t,e,r){e.exports=t(\"./distance\")},{\"./distance\":336}],336:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return Math.sqrt(r*r+n*n+i*i)}},{}],337:[function(t,e,r){e.exports=t(\"./divide\")},{\"./divide\":338}],338:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t}},{}],339:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}},{}],340:[function(t,e,r){e.exports=1e-6},{}],341:[function(t,e,r){e.exports=function(t,e){var r=t[0],i=t[1],a=t[2],o=e[0],s=e[1],l=e[2];return Math.abs(r-o)<=n*Math.max(1,Math.abs(r),Math.abs(o))&&Math.abs(i-s)<=n*Math.max(1,Math.abs(i),Math.abs(s))&&Math.abs(a-l)<=n*Math.max(1,Math.abs(a),Math.abs(l))};var n=t(\"./epsilon\")},{\"./epsilon\":340}],342:[function(t,e,r){e.exports=function(t,e){return t[0]===e[0]&&t[1]===e[1]&&t[2]===e[2]}},{}],343:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.floor(e[0]),t[1]=Math.floor(e[1]),t[2]=Math.floor(e[2]),t}},{}],344:[function(t,e,r){e.exports=function(t,e,r,i,a,o){var s,l;e||(e=3);r||(r=0);l=i?Math.min(i*e+r,t.length):t.length;for(s=r;s<l;s+=e)n[0]=t[s],n[1]=t[s+1],n[2]=t[s+2],a(n,n,o),t[s]=n[0],t[s+1]=n[1],t[s+2]=n[2];return t};var n=t(\"./create\")()},{\"./create\":333}],345:[function(t,e,r){e.exports=function(t,e,r){var n=new Float32Array(3);return n[0]=t,n[1]=e,n[2]=r,n}},{}],346:[function(t,e,r){e.exports={EPSILON:t(\"./epsilon\"),create:t(\"./create\"),clone:t(\"./clone\"),angle:t(\"./angle\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),equals:t(\"./equals\"),exactEquals:t(\"./exactEquals\"),add:t(\"./add\"),subtract:t(\"./subtract\"),sub:t(\"./sub\"),multiply:t(\"./multiply\"),mul:t(\"./mul\"),divide:t(\"./divide\"),div:t(\"./div\"),min:t(\"./min\"),max:t(\"./max\"),floor:t(\"./floor\"),ceil:t(\"./ceil\"),round:t(\"./round\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),dist:t(\"./dist\"),squaredDistance:t(\"./squaredDistance\"),sqrDist:t(\"./sqrDist\"),length:t(\"./length\"),len:t(\"./len\"),squaredLength:t(\"./squaredLength\"),sqrLen:t(\"./sqrLen\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),cross:t(\"./cross\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformMat3:t(\"./transformMat3\"),transformQuat:t(\"./transformQuat\"),rotateX:t(\"./rotateX\"),rotateY:t(\"./rotateY\"),rotateZ:t(\"./rotateZ\"),forEach:t(\"./forEach\")}},{\"./add\":328,\"./angle\":329,\"./ceil\":330,\"./clone\":331,\"./copy\":332,\"./create\":333,\"./cross\":334,\"./dist\":335,\"./distance\":336,\"./div\":337,\"./divide\":338,\"./dot\":339,\"./epsilon\":340,\"./equals\":341,\"./exactEquals\":342,\"./floor\":343,\"./forEach\":344,\"./fromValues\":345,\"./inverse\":347,\"./len\":348,\"./length\":349,\"./lerp\":350,\"./max\":351,\"./min\":352,\"./mul\":353,\"./multiply\":354,\"./negate\":355,\"./normalize\":356,\"./random\":357,\"./rotateX\":358,\"./rotateY\":359,\"./rotateZ\":360,\"./round\":361,\"./scale\":362,\"./scaleAndAdd\":363,\"./set\":364,\"./sqrDist\":365,\"./sqrLen\":366,\"./squaredDistance\":367,\"./squaredLength\":368,\"./sub\":369,\"./subtract\":370,\"./transformMat3\":371,\"./transformMat4\":372,\"./transformQuat\":373}],347:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t}},{}],348:[function(t,e,r){e.exports=t(\"./length\")},{\"./length\":349}],349:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return Math.sqrt(e*e+r*r+n*n)}},{}],350:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t}},{}],351:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t}},{}],352:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t}},{}],353:[function(t,e,r){e.exports=t(\"./multiply\")},{\"./multiply\":354}],354:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t}},{}],355:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t}},{}],356:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=r*r+n*n+i*i;a>0&&(a=1/Math.sqrt(a),t[0]=e[0]*a,t[1]=e[1]*a,t[2]=e[2]*a);return t}},{}],357:[function(t,e,r){e.exports=function(t,e){e=e||1;var r=2*Math.random()*Math.PI,n=2*Math.random()-1,i=Math.sqrt(1-n*n)*e;return t[0]=Math.cos(r)*i,t[1]=Math.sin(r)*i,t[2]=n*e,t}},{}],358:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[1],a=r[2],o=e[1]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=e[0],t[1]=i+o*c-s*l,t[2]=a+o*l+s*c,t}},{}],359:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[2],o=e[0]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+s*l+o*c,t[1]=e[1],t[2]=a+s*c-o*l,t}},{}],360:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[1],o=e[0]-i,s=e[1]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+o*c-s*l,t[1]=a+o*l+s*c,t[2]=e[2],t}},{}],361:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.round(e[0]),t[1]=Math.round(e[1]),t[2]=Math.round(e[2]),t}},{}],362:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t}},{}],363:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t}},{}],364:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e,t[1]=r,t[2]=n,t}},{}],365:[function(t,e,r){e.exports=t(\"./squaredDistance\")},{\"./squaredDistance\":367}],366:[function(t,e,r){e.exports=t(\"./squaredLength\")},{\"./squaredLength\":368}],367:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return r*r+n*n+i*i}},{}],368:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return e*e+r*r+n*n}},{}],369:[function(t,e,r){e.exports=t(\"./subtract\")},{\"./subtract\":370}],370:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t}},{}],371:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t}},{}],372:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[3]*n+r[7]*i+r[11]*a+r[15];return o=o||1,t[0]=(r[0]*n+r[4]*i+r[8]*a+r[12])/o,t[1]=(r[1]*n+r[5]*i+r[9]*a+r[13])/o,t[2]=(r[2]*n+r[6]*i+r[10]*a+r[14])/o,t}},{}],373:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,h=c*i+l*n-o*a,f=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+h*-l-f*-s,t[1]=h*c+p*-s+f*-o-u*-l,t[2]=f*c+p*-l+u*-s-h*-o,t}},{}],374:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t[3]=e[3]+r[3],t}},{}],375:[function(t,e,r){e.exports=function(t){var e=new Float32Array(4);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e}},{}],376:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t}},{}],377:[function(t,e,r){e.exports=function(){var t=new Float32Array(4);return t[0]=0,t[1]=0,t[2]=0,t[3]=0,t}},{}],378:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return Math.sqrt(r*r+n*n+i*i+a*a)}},{}],379:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t[3]=e[3]/r[3],t}},{}],380:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}},{}],381:[function(t,e,r){e.exports=function(t,e,r,n){var i=new Float32Array(4);return i[0]=t,i[1]=e,i[2]=r,i[3]=n,i}},{}],382:[function(t,e,r){e.exports={create:t(\"./create\"),clone:t(\"./clone\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),add:t(\"./add\"),subtract:t(\"./subtract\"),multiply:t(\"./multiply\"),divide:t(\"./divide\"),min:t(\"./min\"),max:t(\"./max\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),squaredDistance:t(\"./squaredDistance\"),length:t(\"./length\"),squaredLength:t(\"./squaredLength\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformQuat:t(\"./transformQuat\")}},{\"./add\":374,\"./clone\":375,\"./copy\":376,\"./create\":377,\"./distance\":378,\"./divide\":379,\"./dot\":380,\"./fromValues\":381,\"./inverse\":383,\"./length\":384,\"./lerp\":385,\"./max\":386,\"./min\":387,\"./multiply\":388,\"./negate\":389,\"./normalize\":390,\"./random\":391,\"./scale\":392,\"./scaleAndAdd\":393,\"./set\":394,\"./squaredDistance\":395,\"./squaredLength\":396,\"./subtract\":397,\"./transformMat4\":398,\"./transformQuat\":399}],383:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t[3]=1/e[3],t}},{}],384:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return Math.sqrt(e*e+r*r+n*n+i*i)}},{}],385:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2],s=e[3];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t[3]=s+n*(r[3]-s),t}},{}],386:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t[3]=Math.max(e[3],r[3]),t}},{}],387:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t[3]=Math.min(e[3],r[3]),t}},{}],388:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t[3]=e[3]*r[3],t}},{}],389:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t[3]=-e[3],t}},{}],390:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r*r+n*n+i*i+a*a;o>0&&(o=1/Math.sqrt(o),t[0]=r*o,t[1]=n*o,t[2]=i*o,t[3]=a*o);return t}},{}],391:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"./scale\");e.exports=function(t,e){return e=e||1,t[0]=Math.random(),t[1]=Math.random(),t[2]=Math.random(),t[3]=Math.random(),n(t,t),i(t,t,e),t}},{\"./normalize\":390,\"./scale\":392}],392:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t}},{}],393:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t[3]=e[3]+r[3]*n,t}},{}],394:[function(t,e,r){e.exports=function(t,e,r,n,i){return t[0]=e,t[1]=r,t[2]=n,t[3]=i,t}},{}],395:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return r*r+n*n+i*i+a*a}},{}],396:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return e*e+r*r+n*n+i*i}},{}],397:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t[3]=e[3]-r[3],t}},{}],398:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}},{}],399:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,h=c*i+l*n-o*a,f=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+h*-l-f*-s,t[1]=h*c+p*-s+f*-o-u*-l,t[2]=f*c+p*-l+u*-s-h*-o,t[3]=e[3],t}},{}],400:[function(t,e,r){e.exports=function(t,e,r,a){return n[0]=a,n[1]=r,n[2]=e,n[3]=t,i[0]};var n=new Uint8Array(4),i=new Float32Array(n.buffer)},{}],401:[function(t,e,r){var n=t(\"glsl-tokenizer\"),i=t(\"atob-lite\");e.exports=function(t){for(var e=Array.isArray(t)?t:n(t),r=0;r<e.length;r++){var a=e[r];if(\"preprocessor\"===a.type){var o=a.data.match(/\\#define\\s+SHADER_NAME(_B64)?\\s+(.+)$/);if(o&&o[2]){var s=o[1],l=o[2];return(s?i(l):l).trim()}}}}},{\"atob-lite\":72,\"glsl-tokenizer\":408}],402:[function(t,e,r){e.exports=function(t){var e,r,k,T=0,A=0,M=l,S=[],E=[],C=1,L=0,P=0,O=!1,z=!1,I=\"\",D=a,R=n;\"300 es\"===(t=t||{}).version&&(D=s,R=o);return function(t){return E=[],null!==t?function(t){var r;T=0,k=(I+=t).length;for(;e=I[T],T<k;){switch(r=T,M){case u:T=U();break;case h:case f:T=j();break;case p:T=V();break;case d:T=G();break;case _:T=H();break;case g:T=Y();break;case c:T=W();break;case x:T=N();break;case l:T=B()}if(r!==T)switch(I[r]){case\"\\n\":L=0,++C;break;default:++L}}return A+=T,I=I.slice(T),E}(t.replace?t.replace(/\\r\\n/g,\"\\n\"):t):function(t){S.length&&F(S.join(\"\"));return M=b,F(\"(eof)\"),E}()};function F(t){t.length&&E.push({type:w[M],data:t,position:P,line:C,column:L})}function B(){return S=S.length?[]:S,\"/\"===r&&\"*\"===e?(P=A+T-1,M=u,r=e,T+1):\"/\"===r&&\"/\"===e?(P=A+T-1,M=h,r=e,T+1):\"#\"===e?(M=f,P=A+T,T):/\\s/.test(e)?(M=x,P=A+T,T):(O=/\\d/.test(e),z=/[^\\w_]/.test(e),P=A+T,M=O?d:z?p:c,T)}function N(){return/[^\\s]/g.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function j(){return\"\\r\"!==e&&\"\\n\"!==e||\"\\\\\"===r?(S.push(e),r=e,T+1):(F(S.join(\"\")),M=l,T)}function U(){return\"/\"===e&&\"*\"===r?(S.push(e),F(S.join(\"\")),M=l,T+1):(S.push(e),r=e,T+1)}function V(){if(\".\"===r&&/\\d/.test(e))return M=g,T;if(\"/\"===r&&\"*\"===e)return M=u,T;if(\"/\"===r&&\"/\"===e)return M=h,T;if(\".\"===e&&S.length){for(;q(S););return M=g,T}if(\";\"===e||\")\"===e||\"(\"===e){if(S.length)for(;q(S););return F(e),M=l,T+1}var t=2===S.length&&\"=\"!==e;if(/[\\w_\\d\\s]/.test(e)||t){for(;q(S););return M=l,T}return S.push(e),r=e,T+1}function q(t){for(var e,r,n=0;;){if(e=i.indexOf(t.slice(0,t.length+n).join(\"\")),r=i[e],-1===e){if(n--+t.length>0)continue;r=t.slice(0,1).join(\"\")}return F(r),P+=r.length,(S=S.slice(r.length)).length}}function H(){return/[^a-fA-F0-9]/.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function G(){return\".\"===e?(S.push(e),M=g,r=e,T+1):/[eE]/.test(e)?(S.push(e),M=g,r=e,T+1):\"x\"===e&&1===S.length&&\"0\"===S[0]?(M=_,S.push(e),r=e,T+1):/[^\\d]/.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function Y(){return\"f\"===e&&(S.push(e),r=e,T+=1),/[eE]/.test(e)?(S.push(e),r=e,T+1):\"-\"===e&&/[eE]/.test(r)?(S.push(e),r=e,T+1):/[^\\d]/.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function W(){if(/[^\\d\\w_]/.test(e)){var t=S.join(\"\");return M=R.indexOf(t)>-1?y:D.indexOf(t)>-1?m:v,F(S.join(\"\")),M=l,T}return S.push(e),r=e,T+1}};var n=t(\"./lib/literals\"),i=t(\"./lib/operators\"),a=t(\"./lib/builtins\"),o=t(\"./lib/literals-300es\"),s=t(\"./lib/builtins-300es\"),l=999,c=9999,u=0,h=1,f=2,p=3,d=4,g=5,v=6,m=7,y=8,x=9,b=10,_=11,w=[\"block-comment\",\"line-comment\",\"preprocessor\",\"operator\",\"integer\",\"float\",\"ident\",\"builtin\",\"keyword\",\"whitespace\",\"eof\",\"integer\"]},{\"./lib/builtins\":404,\"./lib/builtins-300es\":403,\"./lib/literals\":406,\"./lib/literals-300es\":405,\"./lib/operators\":407}],403:[function(t,e,r){var n=t(\"./builtins\");n=n.slice().filter(function(t){return!/^(gl\\_|texture)/.test(t)}),e.exports=n.concat([\"gl_VertexID\",\"gl_InstanceID\",\"gl_Position\",\"gl_PointSize\",\"gl_FragCoord\",\"gl_FrontFacing\",\"gl_FragDepth\",\"gl_PointCoord\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexUniformVectors\",\"gl_MaxVertexOutputVectors\",\"gl_MaxFragmentInputVectors\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxTextureImageUnits\",\"gl_MaxFragmentUniformVectors\",\"gl_MaxDrawBuffers\",\"gl_MinProgramTexelOffset\",\"gl_MaxProgramTexelOffset\",\"gl_DepthRangeParameters\",\"gl_DepthRange\",\"trunc\",\"round\",\"roundEven\",\"isnan\",\"isinf\",\"floatBitsToInt\",\"floatBitsToUint\",\"intBitsToFloat\",\"uintBitsToFloat\",\"packSnorm2x16\",\"unpackSnorm2x16\",\"packUnorm2x16\",\"unpackUnorm2x16\",\"packHalf2x16\",\"unpackHalf2x16\",\"outerProduct\",\"transpose\",\"determinant\",\"inverse\",\"texture\",\"textureSize\",\"textureProj\",\"textureLod\",\"textureOffset\",\"texelFetch\",\"texelFetchOffset\",\"textureProjOffset\",\"textureLodOffset\",\"textureProjLod\",\"textureProjLodOffset\",\"textureGrad\",\"textureGradOffset\",\"textureProjGrad\",\"textureProjGradOffset\"])},{\"./builtins\":404}],404:[function(t,e,r){e.exports=[\"abs\",\"acos\",\"all\",\"any\",\"asin\",\"atan\",\"ceil\",\"clamp\",\"cos\",\"cross\",\"dFdx\",\"dFdy\",\"degrees\",\"distance\",\"dot\",\"equal\",\"exp\",\"exp2\",\"faceforward\",\"floor\",\"fract\",\"gl_BackColor\",\"gl_BackLightModelProduct\",\"gl_BackLightProduct\",\"gl_BackMaterial\",\"gl_BackSecondaryColor\",\"gl_ClipPlane\",\"gl_ClipVertex\",\"gl_Color\",\"gl_DepthRange\",\"gl_DepthRangeParameters\",\"gl_EyePlaneQ\",\"gl_EyePlaneR\",\"gl_EyePlaneS\",\"gl_EyePlaneT\",\"gl_Fog\",\"gl_FogCoord\",\"gl_FogFragCoord\",\"gl_FogParameters\",\"gl_FragColor\",\"gl_FragCoord\",\"gl_FragData\",\"gl_FragDepth\",\"gl_FragDepthEXT\",\"gl_FrontColor\",\"gl_FrontFacing\",\"gl_FrontLightModelProduct\",\"gl_FrontLightProduct\",\"gl_FrontMaterial\",\"gl_FrontSecondaryColor\",\"gl_LightModel\",\"gl_LightModelParameters\",\"gl_LightModelProducts\",\"gl_LightProducts\",\"gl_LightSource\",\"gl_LightSourceParameters\",\"gl_MaterialParameters\",\"gl_MaxClipPlanes\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxDrawBuffers\",\"gl_MaxFragmentUniformComponents\",\"gl_MaxLights\",\"gl_MaxTextureCoords\",\"gl_MaxTextureImageUnits\",\"gl_MaxTextureUnits\",\"gl_MaxVaryingFloats\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxVertexUniformComponents\",\"gl_ModelViewMatrix\",\"gl_ModelViewMatrixInverse\",\"gl_ModelViewMatrixInverseTranspose\",\"gl_ModelViewMatrixTranspose\",\"gl_ModelViewProjectionMatrix\",\"gl_ModelViewProjectionMatrixInverse\",\"gl_ModelViewProjectionMatrixInverseTranspose\",\"gl_ModelViewProjectionMatrixTranspose\",\"gl_MultiTexCoord0\",\"gl_MultiTexCoord1\",\"gl_MultiTexCoord2\",\"gl_MultiTexCoord3\",\"gl_MultiTexCoord4\",\"gl_MultiTexCoord5\",\"gl_MultiTexCoord6\",\"gl_MultiTexCoord7\",\"gl_Normal\",\"gl_NormalMatrix\",\"gl_NormalScale\",\"gl_ObjectPlaneQ\",\"gl_ObjectPlaneR\",\"gl_ObjectPlaneS\",\"gl_ObjectPlaneT\",\"gl_Point\",\"gl_PointCoord\",\"gl_PointParameters\",\"gl_PointSize\",\"gl_Position\",\"gl_ProjectionMatrix\",\"gl_ProjectionMatrixInverse\",\"gl_ProjectionMatrixInverseTranspose\",\"gl_ProjectionMatrixTranspose\",\"gl_SecondaryColor\",\"gl_TexCoord\",\"gl_TextureEnvColor\",\"gl_TextureMatrix\",\"gl_TextureMatrixInverse\",\"gl_TextureMatrixInverseTranspose\",\"gl_TextureMatrixTranspose\",\"gl_Vertex\",\"greaterThan\",\"greaterThanEqual\",\"inversesqrt\",\"length\",\"lessThan\",\"lessThanEqual\",\"log\",\"log2\",\"matrixCompMult\",\"max\",\"min\",\"mix\",\"mod\",\"normalize\",\"not\",\"notEqual\",\"pow\",\"radians\",\"reflect\",\"refract\",\"sign\",\"sin\",\"smoothstep\",\"sqrt\",\"step\",\"tan\",\"texture2D\",\"texture2DLod\",\"texture2DProj\",\"texture2DProjLod\",\"textureCube\",\"textureCubeLod\",\"texture2DLodEXT\",\"texture2DProjLodEXT\",\"textureCubeLodEXT\",\"texture2DGradEXT\",\"texture2DProjGradEXT\",\"textureCubeGradEXT\"]},{}],405:[function(t,e,r){var n=t(\"./literals\");e.exports=n.slice().concat([\"layout\",\"centroid\",\"smooth\",\"case\",\"mat2x2\",\"mat2x3\",\"mat2x4\",\"mat3x2\",\"mat3x3\",\"mat3x4\",\"mat4x2\",\"mat4x3\",\"mat4x4\",\"uint\",\"uvec2\",\"uvec3\",\"uvec4\",\"samplerCubeShadow\",\"sampler2DArray\",\"sampler2DArrayShadow\",\"isampler2D\",\"isampler3D\",\"isamplerCube\",\"isampler2DArray\",\"usampler2D\",\"usampler3D\",\"usamplerCube\",\"usampler2DArray\",\"coherent\",\"restrict\",\"readonly\",\"writeonly\",\"resource\",\"atomic_uint\",\"noperspective\",\"patch\",\"sample\",\"subroutine\",\"common\",\"partition\",\"active\",\"filter\",\"image1D\",\"image2D\",\"image3D\",\"imageCube\",\"iimage1D\",\"iimage2D\",\"iimage3D\",\"iimageCube\",\"uimage1D\",\"uimage2D\",\"uimage3D\",\"uimageCube\",\"image1DArray\",\"image2DArray\",\"iimage1DArray\",\"iimage2DArray\",\"uimage1DArray\",\"uimage2DArray\",\"image1DShadow\",\"image2DShadow\",\"image1DArrayShadow\",\"image2DArrayShadow\",\"imageBuffer\",\"iimageBuffer\",\"uimageBuffer\",\"sampler1DArray\",\"sampler1DArrayShadow\",\"isampler1D\",\"isampler1DArray\",\"usampler1D\",\"usampler1DArray\",\"isampler2DRect\",\"usampler2DRect\",\"samplerBuffer\",\"isamplerBuffer\",\"usamplerBuffer\",\"sampler2DMS\",\"isampler2DMS\",\"usampler2DMS\",\"sampler2DMSArray\",\"isampler2DMSArray\",\"usampler2DMSArray\"])},{\"./literals\":406}],406:[function(t,e,r){e.exports=[\"precision\",\"highp\",\"mediump\",\"lowp\",\"attribute\",\"const\",\"uniform\",\"varying\",\"break\",\"continue\",\"do\",\"for\",\"while\",\"if\",\"else\",\"in\",\"out\",\"inout\",\"float\",\"int\",\"void\",\"bool\",\"true\",\"false\",\"discard\",\"return\",\"mat2\",\"mat3\",\"mat4\",\"vec2\",\"vec3\",\"vec4\",\"ivec2\",\"ivec3\",\"ivec4\",\"bvec2\",\"bvec3\",\"bvec4\",\"sampler1D\",\"sampler2D\",\"sampler3D\",\"samplerCube\",\"sampler1DShadow\",\"sampler2DShadow\",\"struct\",\"asm\",\"class\",\"union\",\"enum\",\"typedef\",\"template\",\"this\",\"packed\",\"goto\",\"switch\",\"default\",\"inline\",\"noinline\",\"volatile\",\"public\",\"static\",\"extern\",\"external\",\"interface\",\"long\",\"short\",\"double\",\"half\",\"fixed\",\"unsigned\",\"input\",\"output\",\"hvec2\",\"hvec3\",\"hvec4\",\"dvec2\",\"dvec3\",\"dvec4\",\"fvec2\",\"fvec3\",\"fvec4\",\"sampler2DRect\",\"sampler3DRect\",\"sampler2DRectShadow\",\"sizeof\",\"cast\",\"namespace\",\"using\"]},{}],407:[function(t,e,r){e.exports=[\"<<=\",\">>=\",\"++\",\"--\",\"<<\",\">>\",\"<=\",\">=\",\"==\",\"!=\",\"&&\",\"||\",\"+=\",\"-=\",\"*=\",\"/=\",\"%=\",\"&=\",\"^^\",\"^=\",\"|=\",\"(\",\")\",\"[\",\"]\",\".\",\"!\",\"~\",\"*\",\"/\",\"%\",\"+\",\"-\",\"<\",\">\",\"&\",\"^\",\"|\",\"?\",\":\",\"=\",\",\",\";\",\"{\",\"}\"]},{}],408:[function(t,e,r){var n=t(\"./index\");e.exports=function(t,e){var r=n(e),i=[];return i=(i=i.concat(r(t))).concat(r(null))}},{\"./index\":402}],409:[function(t,e,r){e.exports=function(t){\"string\"==typeof t&&(t=[t]);for(var e=[].slice.call(arguments,1),r=[],n=0;n<t.length-1;n++)r.push(t[n],e[n]||\"\");return r.push(t[n]),r.join(\"\")}},{}],410:[function(t,e,r){(function(r){\"use strict\";var n,i=t(\"is-browser\");n=\"function\"==typeof r.matchMedia?!r.matchMedia(\"(hover: none)\").matches:i,e.exports=n}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"is-browser\":417}],411:[function(t,e,r){\"use strict\";var n=t(\"is-browser\");e.exports=n&&function(){var t=!1;try{var e=Object.defineProperty({},\"passive\",{get:function(){t=!0}});window.addEventListener(\"test\",null,e),window.removeEventListener(\"test\",null,e)}catch(e){t=!1}return t}()},{\"is-browser\":417}],412:[function(t,e,r){r.read=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?i-1:0,f=r?-1:1,p=t[e+h];for(h+=f,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+h],h+=f,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},r.write=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,h=u>>1,f=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,i),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g}},{}],413:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(0===r)throw new Error(\"Must have at least d+1 points\");var i=t[0].length;if(r<=i)throw new Error(\"Must input at least d+1 points\");var o=t.slice(0,i+1),s=n.apply(void 0,o);if(0===s)throw new Error(\"Input not in general position\");for(var l=new Array(i+1),u=0;u<=i;++u)l[u]=u;s<0&&(l[0]=1,l[1]=0);for(var h=new a(l,new Array(i+1),!1),f=h.adjacent,p=new Array(i+2),u=0;u<=i;++u){for(var d=l.slice(),g=0;g<=i;++g)g===u&&(d[g]=-1);var v=d[0];d[0]=d[1],d[1]=v;var m=new a(d,new Array(i+1),!0);f[u]=m,p[u]=m}p[i+1]=h;for(var u=0;u<=i;++u)for(var d=f[u].vertices,y=f[u].adjacent,g=0;g<=i;++g){var x=d[g];if(x<0)y[g]=h;else for(var b=0;b<=i;++b)f[b].vertices.indexOf(x)<0&&(y[g]=f[b])}for(var _=new c(i,o,p),w=!!e,u=i+1;u<r;++u)_.insert(t[u],w);return _.boundary()};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\").compareCells;function a(t,e,r){this.vertices=t,this.adjacent=e,this.boundary=r,this.lastVisited=-1}function o(t,e,r){this.vertices=t,this.cell=e,this.index=r}function s(t,e){return i(t.vertices,e.vertices)}a.prototype.flip=function(){var t=this.vertices[0];this.vertices[0]=this.vertices[1],this.vertices[1]=t;var e=this.adjacent[0];this.adjacent[0]=this.adjacent[1],this.adjacent[1]=e};var l=[];function c(t,e,r){this.dimension=t,this.vertices=e,this.simplices=r,this.interior=r.filter(function(t){return!t.boundary}),this.tuple=new Array(t+1);for(var i=0;i<=t;++i)this.tuple[i]=this.vertices[i];var a=l[t];a||(a=l[t]=function(t){for(var e=[\"function orient(){var tuple=this.tuple;return test(\"],r=0;r<=t;++r)r>0&&e.push(\",\"),e.push(\"tuple[\",r,\"]\");e.push(\")}return orient\");var i=new Function(\"test\",e.join(\"\")),a=n[t+1];return a||(a=n),i(a)}(t)),this.orient=a}var u=c.prototype;u.handleBoundaryDegeneracy=function(t,e){var r=this.dimension,n=this.vertices.length-1,i=this.tuple,a=this.vertices,o=[t];for(t.lastVisited=-n;o.length>0;){(t=o.pop()).vertices;for(var s=t.adjacent,l=0;l<=r;++l){var c=s[l];if(c.boundary&&!(c.lastVisited<=-n)){for(var u=c.vertices,h=0;h<=r;++h){var f=u[h];i[h]=f<0?e:a[f]}var p=this.orient();if(p>0)return c;c.lastVisited=-n,0===p&&o.push(c)}}}return null},u.walk=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,a=this.tuple,o=e?this.interior.length*Math.random()|0:this.interior.length-1,s=this.interior[o];t:for(;!s.boundary;){for(var l=s.vertices,c=s.adjacent,u=0;u<=n;++u)a[u]=i[l[u]];s.lastVisited=r;for(u=0;u<=n;++u){var h=c[u];if(!(h.lastVisited>=r)){var f=a[u];a[u]=t;var p=this.orient();if(a[u]=f,p<0){s=h;continue t}h.boundary?h.lastVisited=-r:h.lastVisited=r}}return}return s},u.addPeaks=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,l=this.tuple,c=this.interior,u=this.simplices,h=[e];e.lastVisited=r,e.vertices[e.vertices.indexOf(-1)]=r,e.boundary=!1,c.push(e);for(var f=[];h.length>0;){var p=(e=h.pop()).vertices,d=e.adjacent,g=p.indexOf(r);if(!(g<0))for(var v=0;v<=n;++v)if(v!==g){var m=d[v];if(m.boundary&&!(m.lastVisited>=r)){var y=m.vertices;if(m.lastVisited!==-r){for(var x=0,b=0;b<=n;++b)y[b]<0?(x=b,l[b]=t):l[b]=i[y[b]];if(this.orient()>0){y[x]=r,m.boundary=!1,c.push(m),h.push(m),m.lastVisited=r;continue}m.lastVisited=-r}var _=m.adjacent,w=p.slice(),k=d.slice(),T=new a(w,k,!0);u.push(T);var A=_.indexOf(e);if(!(A<0)){_[A]=T,k[g]=m,w[v]=-1,k[v]=e,d[v]=T,T.flip();for(b=0;b<=n;++b){var M=w[b];if(!(M<0||M===r)){for(var S=new Array(n-1),E=0,C=0;C<=n;++C){var L=w[C];L<0||C===b||(S[E++]=L)}f.push(new o(S,T,b))}}}}}}f.sort(s);for(v=0;v+1<f.length;v+=2){var P=f[v],O=f[v+1],z=P.index,I=O.index;z<0||I<0||(P.cell.adjacent[P.index]=O.cell,O.cell.adjacent[O.index]=P.cell)}},u.insert=function(t,e){var r=this.vertices;r.push(t);var n=this.walk(t,e);if(n){for(var i=this.dimension,a=this.tuple,o=0;o<=i;++o){var s=n.vertices[o];a[o]=s<0?t:r[s]}var l=this.orient(a);l<0||(0!==l||(n=this.handleBoundaryDegeneracy(n,t)))&&this.addPeaks(t,n)}},u.boundary=function(){for(var t=this.dimension,e=[],r=this.simplices,n=r.length,i=0;i<n;++i){var a=r[i];if(a.boundary){for(var o=new Array(t),s=a.vertices,l=0,c=0,u=0;u<=t;++u)s[u]>=0?o[l++]=s[u]:c=1&u;if(c===(1&t)){var h=o[0];o[0]=o[1],o[1]=h}e.push(o)}}return e}},{\"robust-orientation\":510,\"simplicial-complex\":520}],414:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=0,a=1;function o(t,e,r,n,i){this.mid=t,this.left=e,this.right=r,this.leftPoints=n,this.rightPoints=i,this.count=(e?e.count:0)+(r?r.count:0)+n.length}e.exports=function(t){if(!t||0===t.length)return new x(null);return new x(y(t))};var s=o.prototype;function l(t,e){t.mid=e.mid,t.left=e.left,t.right=e.right,t.leftPoints=e.leftPoints,t.rightPoints=e.rightPoints,t.count=e.count}function c(t,e){var r=y(e);t.mid=r.mid,t.left=r.left,t.right=r.right,t.leftPoints=r.leftPoints,t.rightPoints=r.rightPoints,t.count=r.count}function u(t,e){var r=t.intervals([]);r.push(e),c(t,r)}function h(t,e){var r=t.intervals([]),n=r.indexOf(e);return n<0?i:(r.splice(n,1),c(t,r),a)}function f(t,e,r){for(var n=0;n<t.length&&t[n][0]<=e;++n){var i=r(t[n]);if(i)return i}}function p(t,e,r){for(var n=t.length-1;n>=0&&t[n][1]>=e;--n){var i=r(t[n]);if(i)return i}}function d(t,e){for(var r=0;r<t.length;++r){var n=e(t[r]);if(n)return n}}function g(t,e){return t-e}function v(t,e){var r=t[0]-e[0];return r||t[1]-e[1]}function m(t,e){var r=t[1]-e[1];return r||t[0]-e[0]}function y(t){if(0===t.length)return null;for(var e=[],r=0;r<t.length;++r)e.push(t[r][0],t[r][1]);e.sort(g);var n=e[e.length>>1],i=[],a=[],s=[];for(r=0;r<t.length;++r){var l=t[r];l[1]<n?i.push(l):n<l[0]?a.push(l):s.push(l)}var c=s,u=s.slice();return c.sort(v),u.sort(m),new o(n,y(i),y(a),c,u)}function x(t){this.root=t}s.intervals=function(t){return t.push.apply(t,this.leftPoints),this.left&&this.left.intervals(t),this.right&&this.right.intervals(t),t},s.insert=function(t){var e=this.count-this.leftPoints.length;if(this.count+=1,t[1]<this.mid)this.left?4*(this.left.count+1)>3*(e+1)?u(this,t):this.left.insert(t):this.left=y([t]);else if(t[0]>this.mid)this.right?4*(this.right.count+1)>3*(e+1)?u(this,t):this.right.insert(t):this.right=y([t]);else{var r=n.ge(this.leftPoints,t,v),i=n.ge(this.rightPoints,t,m);this.leftPoints.splice(r,0,t),this.rightPoints.splice(i,0,t)}},s.remove=function(t){var e=this.count-this.leftPoints;if(t[1]<this.mid)return this.left?4*(this.right?this.right.count:0)>3*(e-1)?h(this,t):2===(c=this.left.remove(t))?(this.left=null,this.count-=1,a):(c===a&&(this.count-=1),c):i;if(t[0]>this.mid)return this.right?4*(this.left?this.left.count:0)>3*(e-1)?h(this,t):2===(c=this.right.remove(t))?(this.right=null,this.count-=1,a):(c===a&&(this.count-=1),c):i;if(1===this.count)return this.leftPoints[0]===t?2:i;if(1===this.leftPoints.length&&this.leftPoints[0]===t){if(this.left&&this.right){for(var r=this,o=this.left;o.right;)r=o,o=o.right;if(r===this)o.right=this.right;else{var s=this.left,c=this.right;r.count-=o.count,r.right=o.left,o.left=s,o.right=c}l(this,o),this.count=(this.left?this.left.count:0)+(this.right?this.right.count:0)+this.leftPoints.length}else this.left?l(this,this.left):l(this,this.right);return a}for(s=n.ge(this.leftPoints,t,v);s<this.leftPoints.length&&this.leftPoints[s][0]===t[0];++s)if(this.leftPoints[s]===t){this.count-=1,this.leftPoints.splice(s,1);for(c=n.ge(this.rightPoints,t,m);c<this.rightPoints.length&&this.rightPoints[c][1]===t[1];++c)if(this.rightPoints[c]===t)return this.rightPoints.splice(c,1),a}return i},s.queryPoint=function(t,e){if(t<this.mid){if(this.left)if(r=this.left.queryPoint(t,e))return r;return f(this.leftPoints,t,e)}if(t>this.mid){var r;if(this.right)if(r=this.right.queryPoint(t,e))return r;return p(this.rightPoints,t,e)}return d(this.leftPoints,e)},s.queryInterval=function(t,e,r){var n;if(t<this.mid&&this.left&&(n=this.left.queryInterval(t,e,r)))return n;if(e>this.mid&&this.right&&(n=this.right.queryInterval(t,e,r)))return n;return e<this.mid?f(this.leftPoints,e,r):t>this.mid?p(this.rightPoints,t,r):d(this.leftPoints,r)};var b=x.prototype;b.insert=function(t){this.root?this.root.insert(t):this.root=new o(t[0],null,null,[t],[t])},b.remove=function(t){if(this.root){var e=this.root.remove(t);return 2===e&&(this.root=null),e!==i}return!1},b.queryPoint=function(t,e){if(this.root)return this.root.queryPoint(t,e)},b.queryInterval=function(t,e,r){if(t<=e&&this.root)return this.root.queryInterval(t,e,r)},Object.defineProperty(b,\"count\",{get:function(){return this.root?this.root.count:0}}),Object.defineProperty(b,\"intervals\",{get:function(){return this.root?this.root.intervals([]):[]}})},{\"binary-search-bounds\":91}],415:[function(t,e,r){\"use strict\";e.exports=function(t,e){e=e||new Array(t.length);for(var r=0;r<t.length;++r)e[t[r]]=r;return e}},{}],416:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=r;return e}},{}],417:[function(t,e,r){e.exports=!0},{}],418:[function(t,e,r){function n(t){return!!t.constructor&&\"function\"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}e.exports=function(t){return null!=t&&(n(t)||function(t){return\"function\"==typeof t.readFloatLE&&\"function\"==typeof t.slice&&n(t.slice(0,0))}(t)||!!t._isBuffer)}},{}],419:[function(t,e,r){\"use strict\";e.exports=\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion))},{}],420:[function(t,e,r){\"use strict\";e.exports=a,e.exports.isMobile=a;var n=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i,i=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino|android|ipad|playbook|silk/i;function a(t){t||(t={});var e=t.ua;return e||\"undefined\"==typeof navigator||(e=navigator.userAgent),e&&e.headers&&\"string\"==typeof e.headers[\"user-agent\"]&&(e=e.headers[\"user-agent\"]),\"string\"==typeof e&&(t.tablet?i.test(e):n.test(e))}},{}],421:[function(t,e,r){\"use strict\";e.exports=function(t){var e=typeof t;return null!==t&&(\"object\"===e||\"function\"===e)}},{}],422:[function(t,e,r){\"use strict\";var n=Object.prototype.toString;e.exports=function(t){var e;return\"[object Object]\"===n.call(t)&&(null===(e=Object.getPrototypeOf(t))||e===Object.getPrototypeOf({}))}},{}],423:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=t.length,n=0;n<r;n++)if(((e=t.charCodeAt(n))<9||e>13)&&32!==e&&133!==e&&160!==e&&5760!==e&&6158!==e&&(e<8192||e>8205)&&8232!==e&&8233!==e&&8239!==e&&8287!==e&&8288!==e&&12288!==e&&65279!==e)return!1;return!0}},{}],424:[function(t,e,r){\"use strict\";e.exports=function(t){return\"string\"==typeof t&&(t=t.trim(),!!(/^[mzlhvcsqta]\\s*[-+.0-9][^mlhvzcsqta]+/i.test(t)&&/[\\dz]$/i.test(t)&&t.length>4))}},{}],425:[function(t,e,r){e.exports=function(t,e,r){return t*(1-r)+e*r}},{}],426:[function(t,e,r){var n,i;n=this,i=function(){\"use strict\";var t,e,r;function n(n,i){if(t)if(e){var a=\"var sharedChunk = {}; (\"+t+\")(sharedChunk); (\"+e+\")(sharedChunk);\",o={};t(o),(r=i(o)).workerUrl=window.URL.createObjectURL(new Blob([a],{type:\"text/javascript\"}))}else e=i;else t=i}return n(0,function(t){function e(t,e){return t(e={exports:{}},e.exports),e.exports}var r=n;function n(t,e,r,n){this.cx=3*t,this.bx=3*(r-t)-this.cx,this.ax=1-this.cx-this.bx,this.cy=3*e,this.by=3*(n-e)-this.cy,this.ay=1-this.cy-this.by,this.p1x=t,this.p1y=n,this.p2x=r,this.p2y=n}n.prototype.sampleCurveX=function(t){return((this.ax*t+this.bx)*t+this.cx)*t},n.prototype.sampleCurveY=function(t){return((this.ay*t+this.by)*t+this.cy)*t},n.prototype.sampleCurveDerivativeX=function(t){return(3*this.ax*t+2*this.bx)*t+this.cx},n.prototype.solveCurveX=function(t,e){var r,n,i,a,o;for(void 0===e&&(e=1e-6),i=t,o=0;o<8;o++){if(a=this.sampleCurveX(i)-t,Math.abs(a)<e)return i;var s=this.sampleCurveDerivativeX(i);if(Math.abs(s)<1e-6)break;i-=a/s}if((i=t)<(r=0))return r;if(i>(n=1))return n;for(;r<n;){if(a=this.sampleCurveX(i),Math.abs(a-t)<e)return i;t>a?r=i:n=i,i=.5*(n-r)+r}return i},n.prototype.solve=function(t,e){return this.sampleCurveY(this.solveCurveX(t,e))};var i=a;function a(t,e){this.x=t,this.y=e}function o(t,e){if(Array.isArray(t)){if(!Array.isArray(e)||t.length!==e.length)return!1;for(var r=0;r<t.length;r++)if(!o(t[r],e[r]))return!1;return!0}if(\"object\"==typeof t&&null!==t&&null!==e){if(\"object\"!=typeof e)return!1;if(Object.keys(t).length!==Object.keys(e).length)return!1;for(var n in t)if(!o(t[n],e[n]))return!1;return!0}return t===e}function s(t,e,n,i){var a=new r(t,e,n,i);return function(t){return a.solve(t)}}a.prototype={clone:function(){return new a(this.x,this.y)},add:function(t){return this.clone()._add(t)},sub:function(t){return this.clone()._sub(t)},multByPoint:function(t){return this.clone()._multByPoint(t)},divByPoint:function(t){return this.clone()._divByPoint(t)},mult:function(t){return this.clone()._mult(t)},div:function(t){return this.clone()._div(t)},rotate:function(t){return this.clone()._rotate(t)},rotateAround:function(t,e){return this.clone()._rotateAround(t,e)},matMult:function(t){return this.clone()._matMult(t)},unit:function(){return this.clone()._unit()},perp:function(){return this.clone()._perp()},round:function(){return this.clone()._round()},mag:function(){return Math.sqrt(this.x*this.x+this.y*this.y)},equals:function(t){return this.x===t.x&&this.y===t.y},dist:function(t){return Math.sqrt(this.distSqr(t))},distSqr:function(t){var e=t.x-this.x,r=t.y-this.y;return e*e+r*r},angle:function(){return Math.atan2(this.y,this.x)},angleTo:function(t){return Math.atan2(this.y-t.y,this.x-t.x)},angleWith:function(t){return this.angleWithSep(t.x,t.y)},angleWithSep:function(t,e){return Math.atan2(this.x*e-this.y*t,this.x*t+this.y*e)},_matMult:function(t){var e=t[0]*this.x+t[1]*this.y,r=t[2]*this.x+t[3]*this.y;return this.x=e,this.y=r,this},_add:function(t){return this.x+=t.x,this.y+=t.y,this},_sub:function(t){return this.x-=t.x,this.y-=t.y,this},_mult:function(t){return this.x*=t,this.y*=t,this},_div:function(t){return this.x/=t,this.y/=t,this},_multByPoint:function(t){return this.x*=t.x,this.y*=t.y,this},_divByPoint:function(t){return this.x/=t.x,this.y/=t.y,this},_unit:function(){return this._div(this.mag()),this},_perp:function(){var t=this.y;return this.y=this.x,this.x=-t,this},_rotate:function(t){var e=Math.cos(t),r=Math.sin(t),n=e*this.x-r*this.y,i=r*this.x+e*this.y;return this.x=n,this.y=i,this},_rotateAround:function(t,e){var r=Math.cos(t),n=Math.sin(t),i=e.x+r*(this.x-e.x)-n*(this.y-e.y),a=e.y+n*(this.x-e.x)+r*(this.y-e.y);return this.x=i,this.y=a,this},_round:function(){return this.x=Math.round(this.x),this.y=Math.round(this.y),this}},a.convert=function(t){return t instanceof a?t:Array.isArray(t)?new a(t[0],t[1]):t};var l=s(.25,.1,.25,1);function c(t,e,r){return Math.min(r,Math.max(e,t))}function u(t,e,r){var n=r-e,i=((t-e)%n+n)%n+e;return i===e?r:i}function h(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}var f=1;function p(){return f++}function d(){return function t(e){return e?(e^16*Math.random()>>e/4).toString(16):([1e7]+-[1e3]+-4e3+-8e3+-1e11).replace(/[018]/g,t)}()}function g(t){return!!t&&/^[0-9a-f]{8}-[0-9a-f]{4}-[4][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$/i.test(t)}function v(t,e){t.forEach(function(t){e[t]&&(e[t]=e[t].bind(e))})}function m(t,e){return-1!==t.indexOf(e,t.length-e.length)}function y(t,e,r){var n={};for(var i in t)n[i]=e.call(r||this,t[i],i,t);return n}function x(t,e,r){var n={};for(var i in t)e.call(r||this,t[i],i,t)&&(n[i]=t[i]);return n}function b(t){return Array.isArray(t)?t.map(b):\"object\"==typeof t&&t?y(t,b):t}var _={};function w(t){_[t]||(\"undefined\"!=typeof console&&console.warn(t),_[t]=!0)}function k(t,e,r){return(r.y-t.y)*(e.x-t.x)>(e.y-t.y)*(r.x-t.x)}function T(t){for(var e=0,r=0,n=t.length,i=n-1,a=void 0,o=void 0;r<n;i=r++)a=t[r],e+=((o=t[i]).x-a.x)*(a.y+o.y);return e}function A(t){var e={};if(t.replace(/(?:^|(?:\\s*\\,\\s*))([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)(?:\\=(?:([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)|(?:\\\"((?:[^\"\\\\]|\\\\.)*)\\\")))?/g,function(t,r,n,i){var a=n||i;return e[r]=!a||a.toLowerCase(),\"\"}),e[\"max-age\"]){var r=parseInt(e[\"max-age\"],10);isNaN(r)?delete e[\"max-age\"]:e[\"max-age\"]=r}return e}function M(t){try{var e=self[t];return e.setItem(\"_mapbox_test_\",1),e.removeItem(\"_mapbox_test_\"),!0}catch(t){return!1}}var S,E,C,L=self.performance&&self.performance.now?self.performance.now.bind(self.performance):Date.now.bind(Date),P=self.requestAnimationFrame||self.mozRequestAnimationFrame||self.webkitRequestAnimationFrame||self.msRequestAnimationFrame,O=self.cancelAnimationFrame||self.mozCancelAnimationFrame||self.webkitCancelAnimationFrame||self.msCancelAnimationFrame,z={now:L,frame:function(t){var e=P(t);return{cancel:function(){return O(e)}}},getImageData:function(t){var e=self.document.createElement(\"canvas\"),r=e.getContext(\"2d\");if(!r)throw new Error(\"failed to create canvas 2d context\");return e.width=t.width,e.height=t.height,r.drawImage(t,0,0,t.width,t.height),r.getImageData(0,0,t.width,t.height)},resolveURL:function(t){return S||(S=self.document.createElement(\"a\")),S.href=t,S.href},hardwareConcurrency:self.navigator.hardwareConcurrency||4,get devicePixelRatio(){return self.devicePixelRatio}},I={API_URL:\"https://api.mapbox.com\",get EVENTS_URL(){return this.API_URL?0===this.API_URL.indexOf(\"https://api.mapbox.cn\")?\"https://events.mapbox.cn/events/v2\":0===this.API_URL.indexOf(\"https://api.mapbox.com\")?\"https://events.mapbox.com/events/v2\":null:null},FEEDBACK_URL:\"https://apps.mapbox.com/feedback\",REQUIRE_ACCESS_TOKEN:!0,ACCESS_TOKEN:null,MAX_PARALLEL_IMAGE_REQUESTS:16},D={supported:!1,testSupport:function(t){!R&&C&&(F?B(t):E=t)}},R=!1,F=!1;function B(t){var e=t.createTexture();t.bindTexture(t.TEXTURE_2D,e);try{if(t.texImage2D(t.TEXTURE_2D,0,t.RGBA,t.RGBA,t.UNSIGNED_BYTE,C),t.isContextLost())return;D.supported=!0}catch(t){}t.deleteTexture(e),R=!0}self.document&&((C=self.document.createElement(\"img\")).onload=function(){E&&B(E),E=null,F=!0},C.onerror=function(){R=!0,E=null},C.src=\"data:image/webp;base64,UklGRh4AAABXRUJQVlA4TBEAAAAvAQAAAAfQ//73v/+BiOh/AAA=\");var N=\"01\",j=function(t){this._transformRequestFn=t,this._createSkuToken()};j.prototype._createSkuToken=function(){var t=function(){for(var t=\"\",e=0;e<10;e++)t+=\"0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ\"[Math.floor(62*Math.random())];return{token:[\"1\",N,t].join(\"\"),tokenExpiresAt:Date.now()+432e5}}();this._skuToken=t.token,this._skuTokenExpiresAt=t.tokenExpiresAt},j.prototype._isSkuTokenExpired=function(){return Date.now()>this._skuTokenExpiresAt},j.prototype.transformRequest=function(t,e){return this._transformRequestFn&&this._transformRequestFn(t,e)||{url:t}},j.prototype.normalizeStyleURL=function(t,e){return Y(t,e)},j.prototype.normalizeGlyphsURL=function(t,e){return W(t,e)},j.prototype.normalizeSourceURL=function(t,e){return X(t,e)},j.prototype.normalizeSpriteURL=function(t,e,r,n){return Z(t,e,r,n)},j.prototype.normalizeTileURL=function(t,e,r){return this._isSkuTokenExpired()&&this._createSkuToken(),K(t,e,r,this._skuToken)},j.prototype.canonicalizeTileURL=function(t){return Q(t)},j.prototype.canonicalizeTileset=function(t,e){return tt(t,e)};var U=\"See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\";function V(t,e){var r=rt(I.API_URL);if(t.protocol=r.protocol,t.authority=r.authority,\"/\"!==r.path&&(t.path=\"\"+r.path+t.path),!I.REQUIRE_ACCESS_TOKEN)return nt(t);if(!(e=e||I.ACCESS_TOKEN))throw new Error(\"An API access token is required to use Mapbox GL. \"+U);if(\"s\"===e[0])throw new Error(\"Use a public access token (pk.*) with Mapbox GL, not a secret access token (sk.*). \"+U);return t.params.push(\"access_token=\"+e),nt(t)}function q(t){return 0===t.indexOf(\"mapbox:\")}var H=/^((https?:)?\\/\\/)?([^\\/]+\\.)?mapbox\\.c(n|om)(\\/|\\?|$)/i;function G(t){return H.test(t)}var Y=function(t,e){if(!q(t))return t;var r=rt(t);return r.path=\"/styles/v1\"+r.path,V(r,e)},W=function(t,e){if(!q(t))return t;var r=rt(t);return r.path=\"/fonts/v1\"+r.path,V(r,e)},X=function(t,e){if(!q(t))return t;var r=rt(t);return r.path=\"/v4/\"+r.authority+\".json\",r.params.push(\"secure\"),V(r,e)},Z=function(t,e,r,n){var i=rt(t);return q(t)?(i.path=\"/styles/v1\"+i.path+\"/sprite\"+e+r,V(i,n)):(i.path+=\"\"+e+r,nt(i))},J=/(\\.(png|jpg)\\d*)(?=$)/,K=function(t,e,r,n){if(!e||!q(e))return t;var i=rt(t),a=z.devicePixelRatio>=2||512===r?\"@2x\":\"\",o=D.supported?\".webp\":\"$1\";return i.path=i.path.replace(J,\"\"+a+o),i.path=\"/v4\"+i.path,I.REQUIRE_ACCESS_TOKEN&&I.ACCESS_TOKEN&&n&&i.params.push(\"sku=\"+n),V(i)},$=/\\.[\\w]+$/,Q=function(t){var e=rt(t);if(!e.path.match(/(^\\/v4\\/)/)||!e.path.match($))return t;var r=\"mapbox://tiles/\";r+=e.path.replace(\"/v4/\",\"\");var n=e.params.filter(function(t){return!t.match(/^access_token=/)});return n.length&&(r+=\"?\"+n.join(\"&\")),r},tt=function(t,e){if(!q(e))return t.tiles||[];for(var r=[],n=0,i=t.tiles;n<i.length;n+=1){var a=i[n],o=Q(a);r.push(o)}return r},et=/^(\\w+):\\/\\/([^\\/?]*)(\\/[^?]+)?\\??(.+)?/;function rt(t){var e=t.match(et);if(!e)throw new Error(\"Unable to parse URL object\");return{protocol:e[1],authority:e[2],path:e[3]||\"/\",params:e[4]?e[4].split(\"&\"):[]}}function nt(t){var e=t.params.length?\"?\"+t.params.join(\"&\"):\"\";return t.protocol+\"://\"+t.authority+t.path+e}function it(t){if(!t)return null;var e,r=t.split(\".\");if(!r||3!==r.length)return null;try{return JSON.parse((e=r[1],decodeURIComponent(self.atob(e).split(\"\").map(function(t){return\"%\"+(\"00\"+t.charCodeAt(0).toString(16)).slice(-2)}).join(\"\"))))}catch(t){return null}}var at=function(t){this.type=t,this.anonId=null,this.eventData={},this.queue=[],this.pendingRequest=null};at.prototype.getStorageKey=function(t){var e,r=it(I.ACCESS_TOKEN),n=\"\";return r&&r.u?(e=r.u,n=self.btoa(encodeURIComponent(e).replace(/%([0-9A-F]{2})/g,function(t,e){return String.fromCharCode(Number(\"0x\"+e))}))):n=I.ACCESS_TOKEN||\"\",t?\"mapbox.eventData.\"+t+\":\"+n:\"mapbox.eventData:\"+n},at.prototype.fetchEventData=function(){var t=M(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{var n=self.localStorage.getItem(e);n&&(this.eventData=JSON.parse(n));var i=self.localStorage.getItem(r);i&&(this.anonId=i)}catch(t){w(\"Unable to read from LocalStorage\")}},at.prototype.saveEventData=function(){var t=M(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{self.localStorage.setItem(r,this.anonId),Object.keys(this.eventData).length>=1&&self.localStorage.setItem(e,JSON.stringify(this.eventData))}catch(t){w(\"Unable to write to LocalStorage\")}},at.prototype.processRequests=function(){},at.prototype.postEvent=function(t,e,r){var n=this;if(I.EVENTS_URL){var i=rt(I.EVENTS_URL);i.params.push(\"access_token=\"+(I.ACCESS_TOKEN||\"\"));var a={event:this.type,created:new Date(t).toISOString(),sdkIdentifier:\"mapbox-gl-js\",sdkVersion:\"1.1.1\",skuId:N,userId:this.anonId},o=e?h(a,e):a,s={url:nt(i),headers:{\"Content-Type\":\"text/plain\"},body:JSON.stringify([o])};this.pendingRequest=St(s,function(t){n.pendingRequest=null,r(t),n.saveEventData(),n.processRequests()})}},at.prototype.queueRequest=function(t){this.queue.push(t),this.processRequests()};var ot,st=function(t){function e(){t.call(this,\"map.load\"),this.success={},this.skuToken=\"\"}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.postMapLoadEvent=function(t,e,r){this.skuToken=r,I.EVENTS_URL&&I.ACCESS_TOKEN&&Array.isArray(t)&&t.some(function(t){return q(t)||G(t)})&&this.queueRequest({id:e,timestamp:Date.now()})},e.prototype.processRequests=function(){var t=this;if(!this.pendingRequest&&0!==this.queue.length){var e=this.queue.shift(),r=e.id,n=e.timestamp;r&&this.success[r]||(this.anonId||this.fetchEventData(),g(this.anonId)||(this.anonId=d()),this.postEvent(n,{skuToken:this.skuToken},function(e){e||r&&(t.success[r]=!0)}))}},e}(at),lt=new(function(t){function e(){t.call(this,\"appUserTurnstile\")}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.postTurnstileEvent=function(t){I.EVENTS_URL&&I.ACCESS_TOKEN&&Array.isArray(t)&&t.some(function(t){return q(t)||G(t)})&&this.queueRequest(Date.now())},e.prototype.processRequests=function(){var t=this;if(!this.pendingRequest&&0!==this.queue.length){this.anonId&&this.eventData.lastSuccess&&this.eventData.tokenU||this.fetchEventData();var e=it(I.ACCESS_TOKEN),r=e?e.u:I.ACCESS_TOKEN,n=r!==this.eventData.tokenU;g(this.anonId)||(this.anonId=d(),n=!0);var i=this.queue.shift();if(this.eventData.lastSuccess){var a=new Date(this.eventData.lastSuccess),o=new Date(i),s=(i-this.eventData.lastSuccess)/864e5;n=n||s>=1||s<-1||a.getDate()!==o.getDate()}else n=!0;if(!n)return this.processRequests();this.postEvent(i,{\"enabled.telemetry\":!1},function(e){e||(t.eventData.lastSuccess=i,t.eventData.tokenU=r)})}},e}(at)),ct=lt.postTurnstileEvent.bind(lt),ut=new st,ht=ut.postMapLoadEvent.bind(ut),ft=\"mapbox-tiles\",pt=500,dt=50,gt=42e4;function vt(t){var e=t.indexOf(\"?\");return e<0?t:t.slice(0,e)}var mt=1/0,yt={Unknown:\"Unknown\",Style:\"Style\",Source:\"Source\",Tile:\"Tile\",Glyphs:\"Glyphs\",SpriteImage:\"SpriteImage\",SpriteJSON:\"SpriteJSON\",Image:\"Image\"};\"function\"==typeof Object.freeze&&Object.freeze(yt);var xt=function(t){function e(e,r,n){401===r&&G(n)&&(e+=\": you may have provided an invalid Mapbox access token. See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\"),t.call(this,e),this.status=r,this.url=n,this.name=this.constructor.name,this.message=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.toString=function(){return this.name+\": \"+this.message+\" (\"+this.status+\"): \"+this.url},e}(Error);function bt(){return\"undefined\"!=typeof WorkerGlobalScope&&\"undefined\"!=typeof self&&self instanceof WorkerGlobalScope}var _t=bt()?function(){return self.worker&&self.worker.referrer}:function(){var t=self.location.origin;if(t&&\"null\"!==t&&\"file://\"!==t)return t+self.location.pathname};function wt(t,e){var r,n=new self.AbortController,i=new self.Request(t.url,{method:t.method||\"GET\",body:t.body,credentials:t.credentials,headers:t.headers,referrer:_t(),signal:n.signal}),a=!1,o=!1,s=(r=i.url).indexOf(\"sku=\")>0&&G(r);\"json\"===t.type&&i.headers.set(\"Accept\",\"application/json\");var l=function(r,n,a){if(!o){if(r&&\"SecurityError\"!==r.message&&w(r),n&&a)return c(n);var l=Date.now();self.fetch(i).then(function(r){if(r.ok){var n=s?r.clone():null;return c(r,n,l)}return e(new xt(r.statusText,r.status,t.url))}).catch(function(t){20!==t.code&&e(new Error(t.message))})}},c=function(r,n,s){(\"arrayBuffer\"===t.type?r.arrayBuffer():\"json\"===t.type?r.json():r.text()).then(function(t){o||(n&&s&&function(t,e,r){if(self.caches){var n={status:e.status,statusText:e.statusText,headers:new self.Headers};e.headers.forEach(function(t,e){return n.headers.set(e,t)});var i=A(e.headers.get(\"Cache-Control\")||\"\");i[\"no-store\"]||(i[\"max-age\"]&&n.headers.set(\"Expires\",new Date(r+1e3*i[\"max-age\"]).toUTCString()),new Date(n.headers.get(\"Expires\")).getTime()-r<gt||function(t,e){if(void 0===ot)try{new Response(new ReadableStream),ot=!0}catch(t){ot=!1}ot?e(t.body):t.blob().then(e)}(e,function(e){var r=new self.Response(e,n);self.caches.open(ft).then(function(e){return e.put(vt(t.url),r)})}))}}(i,n,s),a=!0,e(null,t,r.headers.get(\"Cache-Control\"),r.headers.get(\"Expires\")))}).catch(function(t){return e(new Error(t.message))})};return s?function(t,e){if(!self.caches)return e(null);var r=vt(t.url);self.caches.open(ft).catch(e).then(function(t){t.match(r).catch(e).then(function(n){var i=function(t){if(!t)return!1;var e=new Date(t.headers.get(\"Expires\")),r=A(t.headers.get(\"Cache-Control\")||\"\");return e>Date.now()&&!r[\"no-cache\"]}(n);t.delete(r),i&&t.put(r,n.clone()),e(null,n,i)})})}(i,l):l(null,null),{cancel:function(){o=!0,a||n.abort()}}}var kt,Tt,At=function(t,e){if(!/^file:/.test(t.url)){if(self.fetch&&self.Request&&self.AbortController&&self.Request.prototype.hasOwnProperty(\"signal\"))return wt(t,e);if(bt()&&self.worker&&self.worker.actor)return self.worker.actor.send(\"getResource\",t,e)}return function(t,e){var r=new self.XMLHttpRequest;for(var n in r.open(t.method||\"GET\",t.url,!0),\"arrayBuffer\"===t.type&&(r.responseType=\"arraybuffer\"),t.headers)r.setRequestHeader(n,t.headers[n]);return\"json\"===t.type&&r.setRequestHeader(\"Accept\",\"application/json\"),r.withCredentials=\"include\"===t.credentials,r.onerror=function(){e(new Error(r.statusText))},r.onload=function(){if((r.status>=200&&r.status<300||0===r.status)&&null!==r.response){var n=r.response;if(\"json\"===t.type)try{n=JSON.parse(r.response)}catch(t){return e(t)}e(null,n,r.getResponseHeader(\"Cache-Control\"),r.getResponseHeader(\"Expires\"))}else e(new xt(r.statusText,r.status,t.url))},r.send(t.body),{cancel:function(){return r.abort()}}}(t,e)},Mt=function(t,e){return At(h(t,{type:\"arrayBuffer\"}),e)},St=function(t,e){return At(h(t,{method:\"POST\"}),e)};kt=[],Tt=0;var Et=function(t,e){if(Tt>=I.MAX_PARALLEL_IMAGE_REQUESTS){var r={requestParameters:t,callback:e,cancelled:!1,cancel:function(){this.cancelled=!0}};return kt.push(r),r}Tt++;var n=!1,i=function(){if(!n)for(n=!0,Tt--;kt.length&&Tt<I.MAX_PARALLEL_IMAGE_REQUESTS;){var t=kt.shift(),e=t.requestParameters,r=t.callback;t.cancelled||(t.cancel=Et(e,r).cancel)}},a=Mt(t,function(t,r,n,a){if(i(),t)e(t);else if(r){var o=new self.Image,s=self.URL||self.webkitURL;o.onload=function(){e(null,o),s.revokeObjectURL(o.src)},o.onerror=function(){return e(new Error(\"Could not load image. Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.\"))};var l=new self.Blob([new Uint8Array(r)],{type:\"image/png\"});o.cacheControl=n,o.expires=a,o.src=r.byteLength?s.createObjectURL(l):\"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAC0lEQVQYV2NgAAIAAAUAAarVyFEAAAAASUVORK5CYII=\"}});return{cancel:function(){a.cancel(),i()}}};function Ct(t,e,r){r[t]&&-1!==r[t].indexOf(e)||(r[t]=r[t]||[],r[t].push(e))}function Lt(t,e,r){if(r&&r[t]){var n=r[t].indexOf(e);-1!==n&&r[t].splice(n,1)}}var Pt=function(t,e){void 0===e&&(e={}),h(this,e),this.type=t},Ot=function(t){function e(e,r){void 0===r&&(r={}),t.call(this,\"error\",h({error:e},r))}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Pt),zt=function(){};zt.prototype.on=function(t,e){return this._listeners=this._listeners||{},Ct(t,e,this._listeners),this},zt.prototype.off=function(t,e){return Lt(t,e,this._listeners),Lt(t,e,this._oneTimeListeners),this},zt.prototype.once=function(t,e){return this._oneTimeListeners=this._oneTimeListeners||{},Ct(t,e,this._oneTimeListeners),this},zt.prototype.fire=function(t,e){\"string\"==typeof t&&(t=new Pt(t,e||{}));var r=t.type;if(this.listens(r)){t.target=this;for(var n=0,i=this._listeners&&this._listeners[r]?this._listeners[r].slice():[];n<i.length;n+=1)i[n].call(this,t);for(var a=0,o=this._oneTimeListeners&&this._oneTimeListeners[r]?this._oneTimeListeners[r].slice():[];a<o.length;a+=1){var s=o[a];Lt(r,s,this._oneTimeListeners),s.call(this,t)}var l=this._eventedParent;l&&(h(t,\"function\"==typeof this._eventedParentData?this._eventedParentData():this._eventedParentData),l.fire(t))}else t instanceof Ot&&console.error(t.error);return this},zt.prototype.listens=function(t){return this._listeners&&this._listeners[t]&&this._listeners[t].length>0||this._oneTimeListeners&&this._oneTimeListeners[t]&&this._oneTimeListeners[t].length>0||this._eventedParent&&this._eventedParent.listens(t)},zt.prototype.setEventedParent=function(t,e){return this._eventedParent=t,this._eventedParentData=e,this};var It={$version:8,$root:{version:{required:!0,type:\"enum\",values:[8]},name:{type:\"string\"},metadata:{type:\"*\"},center:{type:\"array\",value:\"number\"},zoom:{type:\"number\"},bearing:{type:\"number\",default:0,period:360,units:\"degrees\"},pitch:{type:\"number\",default:0,units:\"degrees\"},light:{type:\"light\"},sources:{required:!0,type:\"sources\"},sprite:{type:\"string\"},glyphs:{type:\"string\"},transition:{type:\"transition\"},layers:{required:!0,type:\"array\",value:\"layer\"}},sources:{\"*\":{type:\"source\"}},source:[\"source_vector\",\"source_raster\",\"source_raster_dem\",\"source_geojson\",\"source_video\",\"source_image\"],source_vector:{type:{required:!0,type:\"enum\",values:{vector:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},attribution:{type:\"string\"},\"*\":{type:\"*\"}},source_raster:{type:{required:!0,type:\"enum\",values:{raster:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},attribution:{type:\"string\"},\"*\":{type:\"*\"}},source_raster_dem:{type:{required:!0,type:\"enum\",values:{\"raster-dem\":{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},attribution:{type:\"string\"},encoding:{type:\"enum\",values:{terrarium:{},mapbox:{}},default:\"mapbox\"},\"*\":{type:\"*\"}},source_geojson:{type:{required:!0,type:\"enum\",values:{geojson:{}}},data:{type:\"*\"},maxzoom:{type:\"number\",default:18},attribution:{type:\"string\"},buffer:{type:\"number\",default:128,maximum:512,minimum:0},tolerance:{type:\"number\",default:.375},cluster:{type:\"boolean\",default:!1},clusterRadius:{type:\"number\",default:50,minimum:0},clusterMaxZoom:{type:\"number\"},clusterProperties:{type:\"*\"},lineMetrics:{type:\"boolean\",default:!1},generateId:{type:\"boolean\",default:!1}},source_video:{type:{required:!0,type:\"enum\",values:{video:{}}},urls:{required:!0,type:\"array\",value:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},source_image:{type:{required:!0,type:\"enum\",values:{image:{}}},url:{required:!0,type:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},layer:{id:{type:\"string\",required:!0},type:{type:\"enum\",values:{fill:{},line:{},symbol:{},circle:{},heatmap:{},\"fill-extrusion\":{},raster:{},hillshade:{},background:{}},required:!0},metadata:{type:\"*\"},source:{type:\"string\"},\"source-layer\":{type:\"string\"},minzoom:{type:\"number\",minimum:0,maximum:24},maxzoom:{type:\"number\",minimum:0,maximum:24},filter:{type:\"filter\"},layout:{type:\"layout\"},paint:{type:\"paint\"}},layout:[\"layout_fill\",\"layout_line\",\"layout_circle\",\"layout_heatmap\",\"layout_fill-extrusion\",\"layout_symbol\",\"layout_raster\",\"layout_hillshade\",\"layout_background\"],layout_background:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_fill:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_circle:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_heatmap:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},\"layout_fill-extrusion\":{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_line:{\"line-cap\":{type:\"enum\",values:{butt:{},round:{},square:{}},default:\"butt\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-join\":{type:\"enum\",values:{bevel:{},round:{},miter:{}},default:\"miter\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"line-miter-limit\":{type:\"number\",default:2,requires:[{\"line-join\":\"miter\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-round-limit\":{type:\"number\",default:1.05,requires:[{\"line-join\":\"round\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_symbol:{\"symbol-placement\":{type:\"enum\",values:{point:{},line:{},\"line-center\":{}},default:\"point\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-spacing\":{type:\"number\",default:250,minimum:1,units:\"pixels\",requires:[{\"symbol-placement\":\"line\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-avoid-edges\":{type:\"boolean\",default:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"symbol-z-order\":{type:\"enum\",values:{auto:{},\"viewport-y\":{},source:{}},default:\"auto\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-optional\":{type:\"boolean\",default:!1,requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-size\":{type:\"number\",default:1,minimum:0,units:\"factor of the original icon size\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-text-fit\":{type:\"enum\",values:{none:{},width:{},height:{},both:{}},default:\"none\",requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-text-fit-padding\":{type:\"array\",value:\"number\",length:4,default:[0,0,0,0],units:\"pixels\",requires:[\"icon-image\",\"text-field\",{\"icon-text-fit\":[\"both\",\"width\",\"height\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-image\":{type:\"string\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-keep-upright\":{type:\"boolean\",default:!1,requires:[\"icon-image\",{\"icon-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-offset\":{type:\"array\",value:\"number\",length:2,default:[0,0],requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-anchor\":{type:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-field\":{type:\"formatted\",default:\"\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-font\":{type:\"array\",value:\"string\",default:[\"Open Sans Regular\",\"Arial Unicode MS Regular\"],requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-size\":{type:\"number\",default:16,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-width\":{type:\"number\",default:10,minimum:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-line-height\":{type:\"number\",default:1.2,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-letter-spacing\":{type:\"number\",default:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-justify\":{type:\"enum\",values:{auto:{},left:{},center:{},right:{}},default:\"center\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-radial-offset\":{type:\"number\",units:\"ems\",default:0,requires:[{\"!\":\"text-offset\"}],\"property-type\":\"data-driven\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]}},\"text-variable-anchor\":{type:\"array\",value:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},requires:[{\"!\":\"text-anchor\"},{\"!\":\"text-offset\"},{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-anchor\":{type:\"enum\",requires:[\"text-field\"],values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-angle\":{type:\"number\",default:45,units:\"degrees\",requires:[\"text-field\",{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-keep-upright\":{type:\"boolean\",default:!0,requires:[\"text-field\",{\"text-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-transform\":{type:\"enum\",values:{none:{},uppercase:{},lowercase:{}},default:\"none\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-offset\":{type:\"array\",value:\"number\",units:\"ems\",length:2,default:[0,0],requires:[\"text-field\",{\"!\":\"text-radial-offset\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-optional\":{type:\"boolean\",default:!1,requires:[\"text-field\",\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_raster:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_hillshade:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},filter:{type:\"array\",value:\"*\"},filter_operator:{type:\"enum\",values:{\"==\":{},\"!=\":{},\">\":{},\">=\":{},\"<\":{},\"<=\":{},in:{},\"!in\":{},all:{},any:{},none:{},has:{},\"!has\":{}}},geometry_type:{type:\"enum\",values:{Point:{},LineString:{},Polygon:{}}},function:{expression:{type:\"expression\"},stops:{type:\"array\",value:\"function_stop\"},base:{type:\"number\",default:1,minimum:0},property:{type:\"string\",default:\"$zoom\"},type:{type:\"enum\",values:{identity:{},exponential:{},interval:{},categorical:{}},default:\"exponential\"},colorSpace:{type:\"enum\",values:{rgb:{},lab:{},hcl:{}},default:\"rgb\"},default:{type:\"*\",required:!1}},function_stop:{type:\"array\",minimum:0,maximum:22,value:[\"number\",\"color\"],length:2},expression:{type:\"array\",value:\"*\",minimum:1},expression_name:{type:\"enum\",values:{let:{group:\"Variable binding\"},var:{group:\"Variable binding\"},literal:{group:\"Types\"},array:{group:\"Types\"},at:{group:\"Lookup\"},case:{group:\"Decision\"},match:{group:\"Decision\"},coalesce:{group:\"Decision\"},step:{group:\"Ramps, scales, curves\"},interpolate:{group:\"Ramps, scales, curves\"},\"interpolate-hcl\":{group:\"Ramps, scales, curves\"},\"interpolate-lab\":{group:\"Ramps, scales, curves\"},ln2:{group:\"Math\"},pi:{group:\"Math\"},e:{group:\"Math\"},typeof:{group:\"Types\"},string:{group:\"Types\"},number:{group:\"Types\"},boolean:{group:\"Types\"},object:{group:\"Types\"},collator:{group:\"Types\"},format:{group:\"Types\"},\"number-format\":{group:\"Types\"},\"to-string\":{group:\"Types\"},\"to-number\":{group:\"Types\"},\"to-boolean\":{group:\"Types\"},\"to-rgba\":{group:\"Color\"},\"to-color\":{group:\"Types\"},rgb:{group:\"Color\"},rgba:{group:\"Color\"},get:{group:\"Lookup\"},has:{group:\"Lookup\"},length:{group:\"Lookup\"},properties:{group:\"Feature data\"},\"feature-state\":{group:\"Feature data\"},\"geometry-type\":{group:\"Feature data\"},id:{group:\"Feature data\"},zoom:{group:\"Zoom\"},\"heatmap-density\":{group:\"Heatmap\"},\"line-progress\":{group:\"Feature data\"},accumulated:{group:\"Feature data\"},\"+\":{group:\"Math\"},\"*\":{group:\"Math\"},\"-\":{group:\"Math\"},\"/\":{group:\"Math\"},\"%\":{group:\"Math\"},\"^\":{group:\"Math\"},sqrt:{group:\"Math\"},log10:{group:\"Math\"},ln:{group:\"Math\"},log2:{group:\"Math\"},sin:{group:\"Math\"},cos:{group:\"Math\"},tan:{group:\"Math\"},asin:{group:\"Math\"},acos:{group:\"Math\"},atan:{group:\"Math\"},min:{group:\"Math\"},max:{group:\"Math\"},round:{group:\"Math\"},abs:{group:\"Math\"},ceil:{group:\"Math\"},floor:{group:\"Math\"},\"==\":{group:\"Decision\"},\"!=\":{group:\"Decision\"},\">\":{group:\"Decision\"},\"<\":{group:\"Decision\"},\">=\":{group:\"Decision\"},\"<=\":{group:\"Decision\"},all:{group:\"Decision\"},any:{group:\"Decision\"},\"!\":{group:\"Decision\"},\"is-supported-script\":{group:\"String\"},upcase:{group:\"String\"},downcase:{group:\"String\"},concat:{group:\"String\"},\"resolved-locale\":{group:\"String\"}}},light:{anchor:{type:\"enum\",default:\"viewport\",values:{map:{},viewport:{}},\"property-type\":\"data-constant\",transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]}},position:{type:\"array\",default:[1.15,210,30],length:3,value:\"number\",\"property-type\":\"data-constant\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]}},color:{type:\"color\",\"property-type\":\"data-constant\",default:\"#ffffff\",expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0},intensity:{type:\"number\",\"property-type\":\"data-constant\",default:.5,minimum:0,maximum:1,expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0}},paint:[\"paint_fill\",\"paint_line\",\"paint_circle\",\"paint_heatmap\",\"paint_fill-extrusion\",\"paint_symbol\",\"paint_raster\",\"paint_hillshade\",\"paint_background\"],paint_fill:{\"fill-antialias\":{type:\"boolean\",default:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-outline-color\":{type:\"color\",transition:!0,requires:[{\"!\":\"fill-pattern\"},{\"fill-antialias\":!0}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"}},\"paint_fill-extrusion\":{\"fill-extrusion-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-extrusion-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-extrusion-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"fill-extrusion-height\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-base\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,requires:[\"fill-extrusion-height\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-vertical-gradient\":{type:\"boolean\",default:!0,transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_line:{\"line-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"line-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-width\":{type:\"number\",default:1,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-gap-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-offset\":{type:\"number\",default:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-dasharray\":{type:\"array\",value:\"number\",minimum:0,transition:!0,units:\"line widths\",requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"line-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"line-gradient\":{type:\"color\",transition:!1,requires:[{\"!\":\"line-dasharray\"},{\"!\":\"line-pattern\"},{source:\"geojson\",has:{lineMetrics:!0}}],expression:{interpolated:!0,parameters:[\"line-progress\"]},\"property-type\":\"color-ramp\"}},paint_circle:{\"circle-radius\":{type:\"number\",default:5,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-blur\":{type:\"number\",default:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"circle-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-scale\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-stroke-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"}},paint_heatmap:{\"heatmap-radius\":{type:\"number\",default:30,minimum:1,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-weight\":{type:\"number\",default:1,minimum:0,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-intensity\":{type:\"number\",default:1,minimum:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"heatmap-color\":{type:\"color\",default:[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,\"rgba(0, 0, 255, 0)\",.1,\"royalblue\",.3,\"cyan\",.5,\"lime\",.7,\"yellow\",1,\"red\"],transition:!1,expression:{interpolated:!0,parameters:[\"heatmap-density\"]},\"property-type\":\"color-ramp\"},\"heatmap-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_symbol:{\"icon-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"icon-image\",\"icon-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"text-field\",\"text-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_raster:{\"raster-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-hue-rotate\":{type:\"number\",default:0,period:360,transition:!0,units:\"degrees\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-min\":{type:\"number\",default:0,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-max\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-saturation\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-contrast\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-resampling\":{type:\"enum\",values:{linear:{},nearest:{}},default:\"linear\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-fade-duration\":{type:\"number\",default:300,minimum:0,transition:!1,units:\"milliseconds\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_hillshade:{\"hillshade-illumination-direction\":{type:\"number\",default:335,minimum:0,maximum:359,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-illumination-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-exaggeration\":{type:\"number\",default:.5,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-shadow-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-highlight-color\":{type:\"color\",default:\"#FFFFFF\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-accent-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_background:{\"background-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"background-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"background-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"background-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},transition:{duration:{type:\"number\",default:300,minimum:0,units:\"milliseconds\"},delay:{type:\"number\",default:0,minimum:0,units:\"milliseconds\"}},\"property-type\":{\"data-driven\":{type:\"property-type\"},\"cross-faded\":{type:\"property-type\"},\"cross-faded-data-driven\":{type:\"property-type\"},\"color-ramp\":{type:\"property-type\"},\"data-constant\":{type:\"property-type\"},constant:{type:\"property-type\"}}},Dt=function(t,e,r,n){this.message=(t?t+\": \":\"\")+r,n&&(this.identifier=n),null!=e&&e.__line__&&(this.line=e.__line__)};function Rt(t){var e=t.key,r=t.value;return r?[new Dt(e,r,\"constants have been deprecated as of v8\")]:[]}function Ft(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}function Bt(t){return t instanceof Number||t instanceof String||t instanceof Boolean}function Nt(t){return Bt(t)?t.valueOf():t}function jt(t){if(Array.isArray(t))return t.map(jt);if(t instanceof Object&&!Bt(t)){var e={};for(var r in t)e[r]=jt(t[r]);return e}return Nt(t)}var Ut=function(t){function e(e,r){t.call(this,r),this.message=r,this.key=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Error),Vt=function(t,e){void 0===e&&(e=[]),this.parent=t,this.bindings={};for(var r=0,n=e;r<n.length;r+=1){var i=n[r],a=i[0],o=i[1];this.bindings[a]=o}};Vt.prototype.concat=function(t){return new Vt(this,t)},Vt.prototype.get=function(t){if(this.bindings[t])return this.bindings[t];if(this.parent)return this.parent.get(t);throw new Error(t+\" not found in scope.\")},Vt.prototype.has=function(t){return!!this.bindings[t]||!!this.parent&&this.parent.has(t)};var qt={kind:\"null\"},Ht={kind:\"number\"},Gt={kind:\"string\"},Yt={kind:\"boolean\"},Wt={kind:\"color\"},Xt={kind:\"object\"},Zt={kind:\"value\"},Jt={kind:\"collator\"},Kt={kind:\"formatted\"};function $t(t,e){return{kind:\"array\",itemType:t,N:e}}function Qt(t){if(\"array\"===t.kind){var e=Qt(t.itemType);return\"number\"==typeof t.N?\"array<\"+e+\", \"+t.N+\">\":\"value\"===t.itemType.kind?\"array\":\"array<\"+e+\">\"}return t.kind}var te=[qt,Ht,Gt,Yt,Wt,Kt,Xt,$t(Zt)];function ee(t,e){if(\"error\"===e.kind)return null;if(\"array\"===t.kind){if(\"array\"===e.kind&&(0===e.N&&\"value\"===e.itemType.kind||!ee(t.itemType,e.itemType))&&(\"number\"!=typeof t.N||t.N===e.N))return null}else{if(t.kind===e.kind)return null;if(\"value\"===t.kind)for(var r=0,n=te;r<n.length;r+=1)if(!ee(n[r],e))return null}return\"Expected \"+Qt(t)+\" but found \"+Qt(e)+\" instead.\"}var re=e(function(t,e){var r={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],rebeccapurple:[102,51,153,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function n(t){return(t=Math.round(t))<0?0:t>255?255:t}function i(t){return t<0?0:t>1?1:t}function a(t){return\"%\"===t[t.length-1]?n(parseFloat(t)/100*255):n(parseInt(t))}function o(t){return\"%\"===t[t.length-1]?i(parseFloat(t)/100):i(parseFloat(t))}function s(t,e,r){return r<0?r+=1:r>1&&(r-=1),6*r<1?t+(e-t)*r*6:2*r<1?e:3*r<2?t+(e-t)*(2/3-r)*6:t}try{e.parseCSSColor=function(t){var e,i=t.replace(/ /g,\"\").toLowerCase();if(i in r)return r[i].slice();if(\"#\"===i[0])return 4===i.length?(e=parseInt(i.substr(1),16))>=0&&e<=4095?[(3840&e)>>4|(3840&e)>>8,240&e|(240&e)>>4,15&e|(15&e)<<4,1]:null:7===i.length&&(e=parseInt(i.substr(1),16))>=0&&e<=16777215?[(16711680&e)>>16,(65280&e)>>8,255&e,1]:null;var l=i.indexOf(\"(\"),c=i.indexOf(\")\");if(-1!==l&&c+1===i.length){var u=i.substr(0,l),h=i.substr(l+1,c-(l+1)).split(\",\"),f=1;switch(u){case\"rgba\":if(4!==h.length)return null;f=o(h.pop());case\"rgb\":return 3!==h.length?null:[a(h[0]),a(h[1]),a(h[2]),f];case\"hsla\":if(4!==h.length)return null;f=o(h.pop());case\"hsl\":if(3!==h.length)return null;var p=(parseFloat(h[0])%360+360)%360/360,d=o(h[1]),g=o(h[2]),v=g<=.5?g*(d+1):g+d-g*d,m=2*g-v;return[n(255*s(m,v,p+1/3)),n(255*s(m,v,p)),n(255*s(m,v,p-1/3)),f];default:return null}}return null}}catch(t){}}).parseCSSColor,ne=function(t,e,r,n){void 0===n&&(n=1),this.r=t,this.g=e,this.b=r,this.a=n};ne.parse=function(t){if(t){if(t instanceof ne)return t;if(\"string\"==typeof t){var e=re(t);if(e)return new ne(e[0]/255*e[3],e[1]/255*e[3],e[2]/255*e[3],e[3])}}},ne.prototype.toString=function(){var t=this.toArray(),e=t[0],r=t[1],n=t[2],i=t[3];return\"rgba(\"+Math.round(e)+\",\"+Math.round(r)+\",\"+Math.round(n)+\",\"+i+\")\"},ne.prototype.toArray=function(){var t=this.r,e=this.g,r=this.b,n=this.a;return 0===n?[0,0,0,0]:[255*t/n,255*e/n,255*r/n,n]},ne.black=new ne(0,0,0,1),ne.white=new ne(1,1,1,1),ne.transparent=new ne(0,0,0,0),ne.red=new ne(1,0,0,1);var ie=function(t,e,r){this.sensitivity=t?e?\"variant\":\"case\":e?\"accent\":\"base\",this.locale=r,this.collator=new Intl.Collator(this.locale?this.locale:[],{sensitivity:this.sensitivity,usage:\"search\"})};ie.prototype.compare=function(t,e){return this.collator.compare(t,e)},ie.prototype.resolvedLocale=function(){return new Intl.Collator(this.locale?this.locale:[]).resolvedOptions().locale};var ae=function(t,e,r){this.text=t,this.scale=e,this.fontStack=r},oe=function(t){this.sections=t};function se(t,e,r,n){return\"number\"==typeof t&&t>=0&&t<=255&&\"number\"==typeof e&&e>=0&&e<=255&&\"number\"==typeof r&&r>=0&&r<=255?void 0===n||\"number\"==typeof n&&n>=0&&n<=1?null:\"Invalid rgba value [\"+[t,e,r,n].join(\", \")+\"]: 'a' must be between 0 and 1.\":\"Invalid rgba value [\"+(\"number\"==typeof n?[t,e,r,n]:[t,e,r]).join(\", \")+\"]: 'r', 'g', and 'b' must be between 0 and 255.\"}function le(t){if(null===t)return qt;if(\"string\"==typeof t)return Gt;if(\"boolean\"==typeof t)return Yt;if(\"number\"==typeof t)return Ht;if(t instanceof ne)return Wt;if(t instanceof ie)return Jt;if(t instanceof oe)return Kt;if(Array.isArray(t)){for(var e,r=t.length,n=0,i=t;n<i.length;n+=1){var a=le(i[n]);if(e){if(e===a)continue;e=Zt;break}e=a}return $t(e||Zt,r)}return Xt}function ce(t){var e=typeof t;return null===t?\"\":\"string\"===e||\"number\"===e||\"boolean\"===e?String(t):t instanceof ne||t instanceof oe?t.toString():JSON.stringify(t)}oe.fromString=function(t){return new oe([new ae(t,null,null)])},oe.prototype.toString=function(){return this.sections.map(function(t){return t.text}).join(\"\")},oe.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.text);var i={};n.fontStack&&(i[\"text-font\"]=[\"literal\",n.fontStack.split(\",\")]),n.scale&&(i[\"font-scale\"]=n.scale),t.push(i)}return t};var ue=function(t,e){this.type=t,this.value=e};ue.parse=function(t,e){if(2!==t.length)return e.error(\"'literal' expression requires exactly one argument, but found \"+(t.length-1)+\" instead.\");if(!function t(e){if(null===e)return!0;if(\"string\"==typeof e)return!0;if(\"boolean\"==typeof e)return!0;if(\"number\"==typeof e)return!0;if(e instanceof ne)return!0;if(e instanceof ie)return!0;if(e instanceof oe)return!0;if(Array.isArray(e)){for(var r=0,n=e;r<n.length;r+=1)if(!t(n[r]))return!1;return!0}if(\"object\"==typeof e){for(var i in e)if(!t(e[i]))return!1;return!0}return!1}(t[1]))return e.error(\"invalid value\");var r=t[1],n=le(r),i=e.expectedType;return\"array\"!==n.kind||0!==n.N||!i||\"array\"!==i.kind||\"number\"==typeof i.N&&0!==i.N||(n=i),new ue(n,r)},ue.prototype.evaluate=function(){return this.value},ue.prototype.eachChild=function(){},ue.prototype.possibleOutputs=function(){return[this.value]},ue.prototype.serialize=function(){return\"array\"===this.type.kind||\"object\"===this.type.kind?[\"literal\",this.value]:this.value instanceof ne?[\"rgba\"].concat(this.value.toArray()):this.value instanceof oe?this.value.serialize():this.value};var he=function(t){this.name=\"ExpressionEvaluationError\",this.message=t};he.prototype.toJSON=function(){return this.message};var fe={string:Gt,number:Ht,boolean:Yt,object:Xt},pe=function(t,e){this.type=t,this.args=e};pe.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r,n=1,i=t[0];if(\"array\"===i){var a,o;if(t.length>2){var s=t[1];if(\"string\"!=typeof s||!(s in fe)||\"object\"===s)return e.error('The item type argument of \"array\" must be one of string, number, boolean',1);a=fe[s],n++}else a=Zt;if(t.length>3){if(null!==t[2]&&(\"number\"!=typeof t[2]||t[2]<0||t[2]!==Math.floor(t[2])))return e.error('The length argument to \"array\" must be a positive integer literal',2);o=t[2],n++}r=$t(a,o)}else r=fe[i];for(var l=[];n<t.length;n++){var c=e.parse(t[n],n,Zt);if(!c)return null;l.push(c)}return new pe(r,l)},pe.prototype.evaluate=function(t){for(var e=0;e<this.args.length;e++){var r=this.args[e].evaluate(t);if(!ee(this.type,le(r)))return r;if(e===this.args.length-1)throw new he(\"Expected value to be of type \"+Qt(this.type)+\", but found \"+Qt(le(r))+\" instead.\")}return null},pe.prototype.eachChild=function(t){this.args.forEach(t)},pe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},pe.prototype.serialize=function(){var t=this.type,e=[t.kind];if(\"array\"===t.kind){var r=t.itemType;if(\"string\"===r.kind||\"number\"===r.kind||\"boolean\"===r.kind){e.push(r.kind);var n=t.N;(\"number\"==typeof n||this.args.length>1)&&e.push(n)}}return e.concat(this.args.map(function(t){return t.serialize()}))};var de=function(t){this.type=Kt,this.sections=t};de.parse=function(t,e){if(t.length<3)return e.error(\"Expected at least two arguments.\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");for(var r=[],n=1;n<t.length-1;n+=2){var i=e.parse(t[n],1,Zt);if(!i)return null;var a=i.type.kind;if(\"string\"!==a&&\"value\"!==a&&\"null\"!==a)return e.error(\"Formatted text type must be 'string', 'value', or 'null'.\");var o=t[n+1];if(\"object\"!=typeof o||Array.isArray(o))return e.error(\"Format options argument must be an object.\");var s=null;if(o[\"font-scale\"]&&!(s=e.parse(o[\"font-scale\"],1,Ht)))return null;var l=null;if(o[\"text-font\"]&&!(l=e.parse(o[\"text-font\"],1,$t(Gt))))return null;r.push({text:i,scale:s,font:l})}return new de(r)},de.prototype.evaluate=function(t){return new oe(this.sections.map(function(e){return new ae(ce(e.text.evaluate(t)),e.scale?e.scale.evaluate(t):null,e.font?e.font.evaluate(t).join(\",\"):null)}))},de.prototype.eachChild=function(t){for(var e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t(n.text),n.scale&&t(n.scale),n.font&&t(n.font)}},de.prototype.possibleOutputs=function(){return[void 0]},de.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.text.serialize());var i={};n.scale&&(i[\"font-scale\"]=n.scale.serialize()),n.font&&(i[\"text-font\"]=n.font.serialize()),t.push(i)}return t};var ge={\"to-boolean\":Yt,\"to-color\":Wt,\"to-number\":Ht,\"to-string\":Gt},ve=function(t,e){this.type=t,this.args=e};ve.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r=t[0];if((\"to-boolean\"===r||\"to-string\"===r)&&2!==t.length)return e.error(\"Expected one argument.\");for(var n=ge[r],i=[],a=1;a<t.length;a++){var o=e.parse(t[a],a,Zt);if(!o)return null;i.push(o)}return new ve(n,i)},ve.prototype.evaluate=function(t){if(\"boolean\"===this.type.kind)return Boolean(this.args[0].evaluate(t));if(\"color\"===this.type.kind){for(var e,r,n=0,i=this.args;n<i.length;n+=1){if(r=null,(e=i[n].evaluate(t))instanceof ne)return e;if(\"string\"==typeof e){var a=t.parseColor(e);if(a)return a}else if(Array.isArray(e)&&!(r=e.length<3||e.length>4?\"Invalid rbga value \"+JSON.stringify(e)+\": expected an array containing either three or four numeric values.\":se(e[0],e[1],e[2],e[3])))return new ne(e[0]/255,e[1]/255,e[2]/255,e[3])}throw new he(r||\"Could not parse color from value '\"+(\"string\"==typeof e?e:String(JSON.stringify(e)))+\"'\")}if(\"number\"===this.type.kind){for(var o=null,s=0,l=this.args;s<l.length;s+=1){if(null===(o=l[s].evaluate(t)))return 0;var c=Number(o);if(!isNaN(c))return c}throw new he(\"Could not convert \"+JSON.stringify(o)+\" to number.\")}return\"formatted\"===this.type.kind?oe.fromString(ce(this.args[0].evaluate(t))):ce(this.args[0].evaluate(t))},ve.prototype.eachChild=function(t){this.args.forEach(t)},ve.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},ve.prototype.serialize=function(){if(\"formatted\"===this.type.kind)return new de([{text:this.args[0],scale:null,font:null}]).serialize();var t=[\"to-\"+this.type.kind];return this.eachChild(function(e){t.push(e.serialize())}),t};var me=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],ye=function(){this.globals=null,this.feature=null,this.featureState=null,this._parseColorCache={}};ye.prototype.id=function(){return this.feature&&\"id\"in this.feature?this.feature.id:null},ye.prototype.geometryType=function(){return this.feature?\"number\"==typeof this.feature.type?me[this.feature.type]:this.feature.type:null},ye.prototype.properties=function(){return this.feature&&this.feature.properties||{}},ye.prototype.parseColor=function(t){var e=this._parseColorCache[t];return e||(e=this._parseColorCache[t]=ne.parse(t)),e};var xe=function(t,e,r,n){this.name=t,this.type=e,this._evaluate=r,this.args=n};xe.prototype.evaluate=function(t){return this._evaluate(t,this.args)},xe.prototype.eachChild=function(t){this.args.forEach(t)},xe.prototype.possibleOutputs=function(){return[void 0]},xe.prototype.serialize=function(){return[this.name].concat(this.args.map(function(t){return t.serialize()}))},xe.parse=function(t,e){var r,n=t[0],i=xe.definitions[n];if(!i)return e.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0);for(var a=Array.isArray(i)?i[0]:i.type,o=Array.isArray(i)?[[i[1],i[2]]]:i.overloads,s=o.filter(function(e){var r=e[0];return!Array.isArray(r)||r.length===t.length-1}),l=null,c=0,u=s;c<u.length;c+=1){var h=u[c],f=h[0],p=h[1];l=new Ae(e.registry,e.path,null,e.scope);for(var d=[],g=!1,v=1;v<t.length;v++){var m=t[v],y=Array.isArray(f)?f[v-1]:f.type,x=l.parse(m,1+d.length,y);if(!x){g=!0;break}d.push(x)}if(!g)if(Array.isArray(f)&&f.length!==d.length)l.error(\"Expected \"+f.length+\" arguments, but found \"+d.length+\" instead.\");else{for(var b=0;b<d.length;b++){var _=Array.isArray(f)?f[b]:f.type,w=d[b];l.concat(b+1).checkSubtype(_,w.type)}if(0===l.errors.length)return new xe(n,a,p,d)}}if(1===s.length)(r=e.errors).push.apply(r,l.errors);else{for(var k=(s.length?s:o).map(function(t){var e;return e=t[0],Array.isArray(e)?\"(\"+e.map(Qt).join(\", \")+\")\":\"(\"+Qt(e.type)+\"...)\"}).join(\" | \"),T=[],A=1;A<t.length;A++){var M=e.parse(t[A],1+T.length);if(!M)return null;T.push(Qt(M.type))}e.error(\"Expected arguments of type \"+k+\", but found (\"+T.join(\", \")+\") instead.\")}return null},xe.register=function(t,e){for(var r in xe.definitions=e,e)t[r]=xe};var be=function(t,e,r){this.type=Jt,this.locale=r,this.caseSensitive=t,this.diacriticSensitive=e};function _e(t){if(t instanceof xe){if(\"get\"===t.name&&1===t.args.length)return!1;if(\"feature-state\"===t.name)return!1;if(\"has\"===t.name&&1===t.args.length)return!1;if(\"properties\"===t.name||\"geometry-type\"===t.name||\"id\"===t.name)return!1;if(/^filter-/.test(t.name))return!1}var e=!0;return t.eachChild(function(t){e&&!_e(t)&&(e=!1)}),e}function we(t){if(t instanceof xe&&\"feature-state\"===t.name)return!1;var e=!0;return t.eachChild(function(t){e&&!we(t)&&(e=!1)}),e}function ke(t,e){if(t instanceof xe&&e.indexOf(t.name)>=0)return!1;var r=!0;return t.eachChild(function(t){r&&!ke(t,e)&&(r=!1)}),r}be.parse=function(t,e){if(2!==t.length)return e.error(\"Expected one argument.\");var r=t[1];if(\"object\"!=typeof r||Array.isArray(r))return e.error(\"Collator options argument must be an object.\");var n=e.parse(void 0!==r[\"case-sensitive\"]&&r[\"case-sensitive\"],1,Yt);if(!n)return null;var i=e.parse(void 0!==r[\"diacritic-sensitive\"]&&r[\"diacritic-sensitive\"],1,Yt);if(!i)return null;var a=null;return r.locale&&!(a=e.parse(r.locale,1,Gt))?null:new be(n,i,a)},be.prototype.evaluate=function(t){return new ie(this.caseSensitive.evaluate(t),this.diacriticSensitive.evaluate(t),this.locale?this.locale.evaluate(t):null)},be.prototype.eachChild=function(t){t(this.caseSensitive),t(this.diacriticSensitive),this.locale&&t(this.locale)},be.prototype.possibleOutputs=function(){return[void 0]},be.prototype.serialize=function(){var t={};return t[\"case-sensitive\"]=this.caseSensitive.serialize(),t[\"diacritic-sensitive\"]=this.diacriticSensitive.serialize(),this.locale&&(t.locale=this.locale.serialize()),[\"collator\",t]};var Te=function(t,e){this.type=e.type,this.name=t,this.boundExpression=e};Te.parse=function(t,e){if(2!==t.length||\"string\"!=typeof t[1])return e.error(\"'var' expression requires exactly one string literal argument.\");var r=t[1];return e.scope.has(r)?new Te(r,e.scope.get(r)):e.error('Unknown variable \"'+r+'\". Make sure \"'+r+'\" has been bound in an enclosing \"let\" expression before using it.',1)},Te.prototype.evaluate=function(t){return this.boundExpression.evaluate(t)},Te.prototype.eachChild=function(){},Te.prototype.possibleOutputs=function(){return[void 0]},Te.prototype.serialize=function(){return[\"var\",this.name]};var Ae=function(t,e,r,n,i){void 0===e&&(e=[]),void 0===n&&(n=new Vt),void 0===i&&(i=[]),this.registry=t,this.path=e,this.key=e.map(function(t){return\"[\"+t+\"]\"}).join(\"\"),this.scope=n,this.errors=i,this.expectedType=r};function Me(t,e){for(var r,n,i=t.length-1,a=0,o=i,s=0;a<=o;)if(r=t[s=Math.floor((a+o)/2)],n=t[s+1],r<=e){if(s===i||e<n)return s;a=s+1}else{if(!(r>e))throw new he(\"Input is not a number.\");o=s-1}return 0}Ae.prototype.parse=function(t,e,r,n,i){return void 0===i&&(i={}),e?this.concat(e,r,n)._parse(t,i):this._parse(t,i)},Ae.prototype._parse=function(t,e){function r(t,e,r){return\"assert\"===r?new pe(e,[t]):\"coerce\"===r?new ve(e,[t]):t}if(null!==t&&\"string\"!=typeof t&&\"boolean\"!=typeof t&&\"number\"!=typeof t||(t=[\"literal\",t]),Array.isArray(t)){if(0===t.length)return this.error('Expected an array with at least one element. If you wanted a literal array, use [\"literal\", []].');var n=t[0];if(\"string\"!=typeof n)return this.error(\"Expression name must be a string, but found \"+typeof n+' instead. If you wanted a literal array, use [\"literal\", [...]].',0),null;var i=this.registry[n];if(i){var a=i.parse(t,this);if(!a)return null;if(this.expectedType){var o=this.expectedType,s=a.type;if(\"string\"!==o.kind&&\"number\"!==o.kind&&\"boolean\"!==o.kind&&\"object\"!==o.kind&&\"array\"!==o.kind||\"value\"!==s.kind)if(\"color\"!==o.kind&&\"formatted\"!==o.kind||\"value\"!==s.kind&&\"string\"!==s.kind){if(this.checkSubtype(o,s))return null}else a=r(a,o,e.typeAnnotation||\"coerce\");else a=r(a,o,e.typeAnnotation||\"assert\")}if(!(a instanceof ue)&&function t(e){if(e instanceof Te)return t(e.boundExpression);if(e instanceof xe&&\"error\"===e.name)return!1;if(e instanceof be)return!1;var r=e instanceof ve||e instanceof pe,n=!0;return e.eachChild(function(e){n=r?n&&t(e):n&&e instanceof ue}),!!n&&(_e(e)&&ke(e,[\"zoom\",\"heatmap-density\",\"line-progress\",\"accumulated\",\"is-supported-script\"]))}(a)){var l=new ye;try{a=new ue(a.type,a.evaluate(l))}catch(t){return this.error(t.message),null}}return a}return this.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0)}return void 0===t?this.error(\"'undefined' value invalid. Use null instead.\"):\"object\"==typeof t?this.error('Bare objects invalid. Use [\"literal\", {...}] instead.'):this.error(\"Expected an array, but found \"+typeof t+\" instead.\")},Ae.prototype.concat=function(t,e,r){var n=\"number\"==typeof t?this.path.concat(t):this.path,i=r?this.scope.concat(r):this.scope;return new Ae(this.registry,n,e||null,i,this.errors)},Ae.prototype.error=function(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];var n=\"\"+this.key+e.map(function(t){return\"[\"+t+\"]\"}).join(\"\");this.errors.push(new Ut(n,t))},Ae.prototype.checkSubtype=function(t,e){var r=ee(t,e);return r&&this.error(r),r};var Se=function(t,e,r){this.type=t,this.input=e,this.labels=[],this.outputs=[];for(var n=0,i=r;n<i.length;n+=1){var a=i[n],o=a[0],s=a[1];this.labels.push(o),this.outputs.push(s)}};function Ee(t,e,r){return t*(1-r)+e*r}Se.parse=function(t,e){if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");var r=e.parse(t[1],1,Ht);if(!r)return null;var n=[],i=null;e.expectedType&&\"value\"!==e.expectedType.kind&&(i=e.expectedType);for(var a=1;a<t.length;a+=2){var o=1===a?-1/0:t[a],s=t[a+1],l=a,c=a+1;if(\"number\"!=typeof o)return e.error('Input/output pairs for \"step\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',l);if(n.length&&n[n.length-1][0]>=o)return e.error('Input/output pairs for \"step\" expressions must be arranged with input values in strictly ascending order.',l);var u=e.parse(s,c,i);if(!u)return null;i=i||u.type,n.push([o,u])}return new Se(i,r,n)},Se.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;return n>=e[i-1]?r[i-1].evaluate(t):r[Me(e,n)].evaluate(t)},Se.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},Se.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()}))},Se.prototype.serialize=function(){for(var t=[\"step\",this.input.serialize()],e=0;e<this.labels.length;e++)e>0&&t.push(this.labels[e]),t.push(this.outputs[e].serialize());return t};var Ce=Object.freeze({number:Ee,color:function(t,e,r){return new ne(Ee(t.r,e.r,r),Ee(t.g,e.g,r),Ee(t.b,e.b,r),Ee(t.a,e.a,r))},array:function(t,e,r){return t.map(function(t,n){return Ee(t,e[n],r)})}}),Le=.95047,Pe=1,Oe=1.08883,ze=4/29,Ie=6/29,De=3*Ie*Ie,Re=Ie*Ie*Ie,Fe=Math.PI/180,Be=180/Math.PI;function Ne(t){return t>Re?Math.pow(t,1/3):t/De+ze}function je(t){return t>Ie?t*t*t:De*(t-ze)}function Ue(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function Ve(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function qe(t){var e=Ve(t.r),r=Ve(t.g),n=Ve(t.b),i=Ne((.4124564*e+.3575761*r+.1804375*n)/Le),a=Ne((.2126729*e+.7151522*r+.072175*n)/Pe);return{l:116*a-16,a:500*(i-a),b:200*(a-Ne((.0193339*e+.119192*r+.9503041*n)/Oe)),alpha:t.a}}function He(t){var e=(t.l+16)/116,r=isNaN(t.a)?e:e+t.a/500,n=isNaN(t.b)?e:e-t.b/200;return e=Pe*je(e),r=Le*je(r),n=Oe*je(n),new ne(Ue(3.2404542*r-1.5371385*e-.4985314*n),Ue(-.969266*r+1.8760108*e+.041556*n),Ue(.0556434*r-.2040259*e+1.0572252*n),t.alpha)}var Ge={forward:qe,reverse:He,interpolate:function(t,e,r){return{l:Ee(t.l,e.l,r),a:Ee(t.a,e.a,r),b:Ee(t.b,e.b,r),alpha:Ee(t.alpha,e.alpha,r)}}},Ye={forward:function(t){var e=qe(t),r=e.l,n=e.a,i=e.b,a=Math.atan2(i,n)*Be;return{h:a<0?a+360:a,c:Math.sqrt(n*n+i*i),l:r,alpha:t.a}},reverse:function(t){var e=t.h*Fe,r=t.c;return He({l:t.l,a:Math.cos(e)*r,b:Math.sin(e)*r,alpha:t.alpha})},interpolate:function(t,e,r){return{h:function(t,e,r){var n=e-t;return t+r*(n>180||n<-180?n-360*Math.round(n/360):n)}(t.h,e.h,r),c:Ee(t.c,e.c,r),l:Ee(t.l,e.l,r),alpha:Ee(t.alpha,e.alpha,r)}}},We=Object.freeze({lab:Ge,hcl:Ye}),Xe=function(t,e,r,n,i){this.type=t,this.operator=e,this.interpolation=r,this.input=n,this.labels=[],this.outputs=[];for(var a=0,o=i;a<o.length;a+=1){var s=o[a],l=s[0],c=s[1];this.labels.push(l),this.outputs.push(c)}};function Ze(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}Xe.interpolationFactor=function(t,e,n,i){var a=0;if(\"exponential\"===t.name)a=Ze(e,t.base,n,i);else if(\"linear\"===t.name)a=Ze(e,1,n,i);else if(\"cubic-bezier\"===t.name){var o=t.controlPoints;a=new r(o[0],o[1],o[2],o[3]).solve(Ze(e,1,n,i))}return a},Xe.parse=function(t,e){var r=t[0],n=t[1],i=t[2],a=t.slice(3);if(!Array.isArray(n)||0===n.length)return e.error(\"Expected an interpolation type expression.\",1);if(\"linear\"===n[0])n={name:\"linear\"};else if(\"exponential\"===n[0]){var o=n[1];if(\"number\"!=typeof o)return e.error(\"Exponential interpolation requires a numeric base.\",1,1);n={name:\"exponential\",base:o}}else{if(\"cubic-bezier\"!==n[0])return e.error(\"Unknown interpolation type \"+String(n[0]),1,0);var s=n.slice(1);if(4!==s.length||s.some(function(t){return\"number\"!=typeof t||t<0||t>1}))return e.error(\"Cubic bezier interpolation requires four numeric arguments with values between 0 and 1.\",1);n={name:\"cubic-bezier\",controlPoints:s}}if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");if(!(i=e.parse(i,2,Ht)))return null;var l=[],c=null;\"interpolate-hcl\"===r||\"interpolate-lab\"===r?c=Wt:e.expectedType&&\"value\"!==e.expectedType.kind&&(c=e.expectedType);for(var u=0;u<a.length;u+=2){var h=a[u],f=a[u+1],p=u+3,d=u+4;if(\"number\"!=typeof h)return e.error('Input/output pairs for \"interpolate\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',p);if(l.length&&l[l.length-1][0]>=h)return e.error('Input/output pairs for \"interpolate\" expressions must be arranged with input values in strictly ascending order.',p);var g=e.parse(f,d,c);if(!g)return null;c=c||g.type,l.push([h,g])}return\"number\"===c.kind||\"color\"===c.kind||\"array\"===c.kind&&\"number\"===c.itemType.kind&&\"number\"==typeof c.N?new Xe(c,r,n,i,l):e.error(\"Type \"+Qt(c)+\" is not interpolatable.\")},Xe.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;if(n>=e[i-1])return r[i-1].evaluate(t);var a=Me(e,n),o=e[a],s=e[a+1],l=Xe.interpolationFactor(this.interpolation,n,o,s),c=r[a].evaluate(t),u=r[a+1].evaluate(t);return\"interpolate\"===this.operator?Ce[this.type.kind.toLowerCase()](c,u,l):\"interpolate-hcl\"===this.operator?Ye.reverse(Ye.interpolate(Ye.forward(c),Ye.forward(u),l)):Ge.reverse(Ge.interpolate(Ge.forward(c),Ge.forward(u),l))},Xe.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},Xe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()}))},Xe.prototype.serialize=function(){var t;t=\"linear\"===this.interpolation.name?[\"linear\"]:\"exponential\"===this.interpolation.name?1===this.interpolation.base?[\"linear\"]:[\"exponential\",this.interpolation.base]:[\"cubic-bezier\"].concat(this.interpolation.controlPoints);for(var e=[this.operator,t,this.input.serialize()],r=0;r<this.labels.length;r++)e.push(this.labels[r],this.outputs[r].serialize());return e};var Je=function(t,e){this.type=t,this.args=e};Je.parse=function(t,e){if(t.length<2)return e.error(\"Expectected at least one argument.\");var r=null,n=e.expectedType;n&&\"value\"!==n.kind&&(r=n);for(var i=[],a=0,o=t.slice(1);a<o.length;a+=1){var s=o[a],l=e.parse(s,1+i.length,r,void 0,{typeAnnotation:\"omit\"});if(!l)return null;r=r||l.type,i.push(l)}var c=n&&i.some(function(t){return ee(n,t.type)});return new Je(c?Zt:r,i)},Je.prototype.evaluate=function(t){for(var e=null,r=0,n=this.args;r<n.length&&null===(e=n[r].evaluate(t));r+=1);return e},Je.prototype.eachChild=function(t){this.args.forEach(t)},Je.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},Je.prototype.serialize=function(){var t=[\"coalesce\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var Ke=function(t,e){this.type=e.type,this.bindings=[].concat(t),this.result=e};Ke.prototype.evaluate=function(t){return this.result.evaluate(t)},Ke.prototype.eachChild=function(t){for(var e=0,r=this.bindings;e<r.length;e+=1)t(r[e][1]);t(this.result)},Ke.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found \"+(t.length-1)+\" instead.\");for(var r=[],n=1;n<t.length-1;n+=2){var i=t[n];if(\"string\"!=typeof i)return e.error(\"Expected string, but found \"+typeof i+\" instead.\",n);if(/[^a-zA-Z0-9_]/.test(i))return e.error(\"Variable names must contain only alphanumeric characters or '_'.\",n);var a=e.parse(t[n+1],n+1);if(!a)return null;r.push([i,a])}var o=e.parse(t[t.length-1],t.length-1,e.expectedType,r);return o?new Ke(r,o):null},Ke.prototype.possibleOutputs=function(){return this.result.possibleOutputs()},Ke.prototype.serialize=function(){for(var t=[\"let\"],e=0,r=this.bindings;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];t.push(i,a.serialize())}return t.push(this.result.serialize()),t};var $e=function(t,e,r){this.type=t,this.index=e,this.input=r};$e.parse=function(t,e){if(3!==t.length)return e.error(\"Expected 2 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,Ht),n=e.parse(t[2],2,$t(e.expectedType||Zt));if(!r||!n)return null;var i=n.type;return new $e(i.itemType,r,n)},$e.prototype.evaluate=function(t){var e=this.index.evaluate(t),r=this.input.evaluate(t);if(e<0)throw new he(\"Array index out of bounds: \"+e+\" < 0.\");if(e>=r.length)throw new he(\"Array index out of bounds: \"+e+\" > \"+(r.length-1)+\".\");if(e!==Math.floor(e))throw new he(\"Array index must be an integer, but found \"+e+\" instead.\");return r[e]},$e.prototype.eachChild=function(t){t(this.index),t(this.input)},$e.prototype.possibleOutputs=function(){return[void 0]},$e.prototype.serialize=function(){return[\"at\",this.index.serialize(),this.input.serialize()]};var Qe=function(t,e,r,n,i,a){this.inputType=t,this.type=e,this.input=r,this.cases=n,this.outputs=i,this.otherwise=a};Qe.parse=function(t,e){if(t.length<5)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=1)return e.error(\"Expected an even number of arguments.\");var r,n;e.expectedType&&\"value\"!==e.expectedType.kind&&(n=e.expectedType);for(var i={},a=[],o=2;o<t.length-1;o+=2){var s=t[o],l=t[o+1];Array.isArray(s)||(s=[s]);var c=e.concat(o);if(0===s.length)return c.error(\"Expected at least one branch label.\");for(var u=0,h=s;u<h.length;u+=1){var f=h[u];if(\"number\"!=typeof f&&\"string\"!=typeof f)return c.error(\"Branch labels must be numbers or strings.\");if(\"number\"==typeof f&&Math.abs(f)>Number.MAX_SAFE_INTEGER)return c.error(\"Branch labels must be integers no larger than \"+Number.MAX_SAFE_INTEGER+\".\");if(\"number\"==typeof f&&Math.floor(f)!==f)return c.error(\"Numeric branch labels must be integer values.\");if(r){if(c.checkSubtype(r,le(f)))return null}else r=le(f);if(void 0!==i[String(f)])return c.error(\"Branch labels must be unique.\");i[String(f)]=a.length}var p=e.parse(l,o,n);if(!p)return null;n=n||p.type,a.push(p)}var d=e.parse(t[1],1,Zt);if(!d)return null;var g=e.parse(t[t.length-1],t.length-1,n);return g?\"value\"!==d.type.kind&&e.concat(1).checkSubtype(r,d.type)?null:new Qe(r,n,d,i,a,g):null},Qe.prototype.evaluate=function(t){var e=this.input.evaluate(t);return(le(e)===this.inputType&&this.outputs[this.cases[e]]||this.otherwise).evaluate(t)},Qe.prototype.eachChild=function(t){t(this.input),this.outputs.forEach(t),t(this.otherwise)},Qe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()})).concat(this.otherwise.possibleOutputs())},Qe.prototype.serialize=function(){for(var t=this,e=[\"match\",this.input.serialize()],r=[],n={},i=0,a=Object.keys(this.cases).sort();i<a.length;i+=1){var o=a[i];void 0===(h=n[this.cases[o]])?(n[this.cases[o]]=r.length,r.push([this.cases[o],[o]])):r[h][1].push(o)}for(var s=function(e){return\"number\"===t.inputType.kind?Number(e):e},l=0,c=r;l<c.length;l+=1){var u=c[l],h=u[0],f=u[1];1===f.length?e.push(s(f[0])):e.push(f.map(s)),e.push(this.outputs[outputIndex$1].serialize())}return e.push(this.otherwise.serialize()),e};var tr=function(t,e,r){this.type=t,this.branches=e,this.otherwise=r};function er(t,e){return\"==\"===t||\"!=\"===t?\"boolean\"===e.kind||\"string\"===e.kind||\"number\"===e.kind||\"null\"===e.kind||\"value\"===e.kind:\"string\"===e.kind||\"number\"===e.kind||\"value\"===e.kind}function rr(t,e,r,n){return 0===n.compare(e,r)}function nr(t,e,r){var n=\"==\"!==t&&\"!=\"!==t;return function(){function i(t,e,r){this.type=Yt,this.lhs=t,this.rhs=e,this.collator=r,this.hasUntypedArgument=\"value\"===t.type.kind||\"value\"===e.type.kind}return i.parse=function(t,e){if(3!==t.length&&4!==t.length)return e.error(\"Expected two or three arguments.\");var r=t[0],a=e.parse(t[1],1,Zt);if(!a)return null;if(!er(r,a.type))return e.concat(1).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Qt(a.type)+\"'.\");var o=e.parse(t[2],2,Zt);if(!o)return null;if(!er(r,o.type))return e.concat(2).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Qt(o.type)+\"'.\");if(a.type.kind!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot compare types '\"+Qt(a.type)+\"' and '\"+Qt(o.type)+\"'.\");n&&(\"value\"===a.type.kind&&\"value\"!==o.type.kind?a=new pe(o.type,[a]):\"value\"!==a.type.kind&&\"value\"===o.type.kind&&(o=new pe(a.type,[o])));var s=null;if(4===t.length){if(\"string\"!==a.type.kind&&\"string\"!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot use collator to compare non-string types.\");if(!(s=e.parse(t[3],3,Jt)))return null}return new i(a,o,s)},i.prototype.evaluate=function(i){var a=this.lhs.evaluate(i),o=this.rhs.evaluate(i);if(n&&this.hasUntypedArgument){var s=le(a),l=le(o);if(s.kind!==l.kind||\"string\"!==s.kind&&\"number\"!==s.kind)throw new he('Expected arguments for \"'+t+'\" to be (string, string) or (number, number), but found ('+s.kind+\", \"+l.kind+\") instead.\")}if(this.collator&&!n&&this.hasUntypedArgument){var c=le(a),u=le(o);if(\"string\"!==c.kind||\"string\"!==u.kind)return e(i,a,o)}return this.collator?r(i,a,o,this.collator.evaluate(i)):e(i,a,o)},i.prototype.eachChild=function(t){t(this.lhs),t(this.rhs),this.collator&&t(this.collator)},i.prototype.possibleOutputs=function(){return[!0,!1]},i.prototype.serialize=function(){var e=[t];return this.eachChild(function(t){e.push(t.serialize())}),e},i}()}tr.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=0)return e.error(\"Expected an odd number of arguments.\");var r;e.expectedType&&\"value\"!==e.expectedType.kind&&(r=e.expectedType);for(var n=[],i=1;i<t.length-1;i+=2){var a=e.parse(t[i],i,Yt);if(!a)return null;var o=e.parse(t[i+1],i+1,r);if(!o)return null;n.push([a,o]),r=r||o.type}var s=e.parse(t[t.length-1],t.length-1,r);return s?new tr(r,n,s):null},tr.prototype.evaluate=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];if(i.evaluate(t))return a.evaluate(t)}return this.otherwise.evaluate(t)},tr.prototype.eachChild=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];t(i),t(a)}t(this.otherwise)},tr.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.branches.map(function(t){return t[0],t[1].possibleOutputs()})).concat(this.otherwise.possibleOutputs())},tr.prototype.serialize=function(){var t=[\"case\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var ir=nr(\"==\",function(t,e,r){return e===r},rr),ar=nr(\"!=\",function(t,e,r){return e!==r},function(t,e,r,n){return!rr(0,e,r,n)}),or=nr(\"<\",function(t,e,r){return e<r},function(t,e,r,n){return n.compare(e,r)<0}),sr=nr(\">\",function(t,e,r){return e>r},function(t,e,r,n){return n.compare(e,r)>0}),lr=nr(\"<=\",function(t,e,r){return e<=r},function(t,e,r,n){return n.compare(e,r)<=0}),cr=nr(\">=\",function(t,e,r){return e>=r},function(t,e,r,n){return n.compare(e,r)>=0}),ur=function(t,e,r,n,i){this.type=Gt,this.number=t,this.locale=e,this.currency=r,this.minFractionDigits=n,this.maxFractionDigits=i};ur.parse=function(t,e){if(3!==t.length)return e.error(\"Expected two arguments.\");var r=e.parse(t[1],1,Ht);if(!r)return null;var n=t[2];if(\"object\"!=typeof n||Array.isArray(n))return e.error(\"NumberFormat options argument must be an object.\");var i=null;if(n.locale&&!(i=e.parse(n.locale,1,Gt)))return null;var a=null;if(n.currency&&!(a=e.parse(n.currency,1,Gt)))return null;var o=null;if(n[\"min-fraction-digits\"]&&!(o=e.parse(n[\"min-fraction-digits\"],1,Ht)))return null;var s=null;return n[\"max-fraction-digits\"]&&!(s=e.parse(n[\"max-fraction-digits\"],1,Ht))?null:new ur(r,i,a,o,s)},ur.prototype.evaluate=function(t){return new Intl.NumberFormat(this.locale?this.locale.evaluate(t):[],{style:this.currency?\"currency\":\"decimal\",currency:this.currency?this.currency.evaluate(t):void 0,minimumFractionDigits:this.minFractionDigits?this.minFractionDigits.evaluate(t):void 0,maximumFractionDigits:this.maxFractionDigits?this.maxFractionDigits.evaluate(t):void 0}).format(this.number.evaluate(t))},ur.prototype.eachChild=function(t){t(this.number),this.locale&&t(this.locale),this.currency&&t(this.currency),this.minFractionDigits&&t(this.minFractionDigits),this.maxFractionDigits&&t(this.maxFractionDigits)},ur.prototype.possibleOutputs=function(){return[void 0]},ur.prototype.serialize=function(){var t={};return this.locale&&(t.locale=this.locale.serialize()),this.currency&&(t.currency=this.currency.serialize()),this.minFractionDigits&&(t[\"min-fraction-digits\"]=this.minFractionDigits.serialize()),this.maxFractionDigits&&(t[\"max-fraction-digits\"]=this.maxFractionDigits.serialize()),[\"number-format\",this.number.serialize(),t]};var hr=function(t){this.type=Ht,this.input=t};hr.parse=function(t,e){if(2!==t.length)return e.error(\"Expected 1 argument, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1);return r?\"array\"!==r.type.kind&&\"string\"!==r.type.kind&&\"value\"!==r.type.kind?e.error(\"Expected argument of type string or array, but found \"+Qt(r.type)+\" instead.\"):new hr(r):null},hr.prototype.evaluate=function(t){var e=this.input.evaluate(t);if(\"string\"==typeof e)return e.length;if(Array.isArray(e))return e.length;throw new he(\"Expected value to be of type string or array, but found \"+Qt(le(e))+\" instead.\")},hr.prototype.eachChild=function(t){t(this.input)},hr.prototype.possibleOutputs=function(){return[void 0]},hr.prototype.serialize=function(){var t=[\"length\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var fr={\"==\":ir,\"!=\":ar,\">\":sr,\"<\":or,\">=\":cr,\"<=\":lr,array:pe,at:$e,boolean:pe,case:tr,coalesce:Je,collator:be,format:de,interpolate:Xe,\"interpolate-hcl\":Xe,\"interpolate-lab\":Xe,length:hr,let:Ke,literal:ue,match:Qe,number:pe,\"number-format\":ur,object:pe,step:Se,string:pe,\"to-boolean\":ve,\"to-color\":ve,\"to-number\":ve,\"to-string\":ve,var:Te};function pr(t,e){var r=e[0],n=e[1],i=e[2],a=e[3];r=r.evaluate(t),n=n.evaluate(t),i=i.evaluate(t);var o=a?a.evaluate(t):1,s=se(r,n,i,o);if(s)throw new he(s);return new ne(r/255*o,n/255*o,i/255*o,o)}function dr(t,e){return t in e}function gr(t,e){var r=e[t];return void 0===r?null:r}function vr(t){return{type:t}}function mr(t){return{result:\"success\",value:t}}function yr(t){return{result:\"error\",value:t}}function xr(t){return\"data-driven\"===t[\"property-type\"]||\"cross-faded-data-driven\"===t[\"property-type\"]}function br(t){return!!t.expression&&t.expression.parameters.indexOf(\"zoom\")>-1}function _r(t){return!!t.expression&&t.expression.interpolated}function wr(t){return t instanceof Number?\"number\":t instanceof String?\"string\":t instanceof Boolean?\"boolean\":Array.isArray(t)?\"array\":null===t?\"null\":typeof t}function kr(t){return\"object\"==typeof t&&null!==t&&!Array.isArray(t)}function Tr(t){return t}function Ar(t,e,r){return void 0!==t?t:void 0!==e?e:void 0!==r?r:void 0}function Mr(t,e,r,n,i){return Ar(typeof r===i?n[r]:void 0,t.default,e.default)}function Sr(t,e,r){if(\"number\"!==wr(r))return Ar(t.default,e.default);var n=t.stops.length;if(1===n)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[n-1][0])return t.stops[n-1][1];var i=Me(t.stops.map(function(t){return t[0]}),r);return t.stops[i][1]}function Er(t,e,r){var n=void 0!==t.base?t.base:1;if(\"number\"!==wr(r))return Ar(t.default,e.default);var i=t.stops.length;if(1===i)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[i-1][0])return t.stops[i-1][1];var a=Me(t.stops.map(function(t){return t[0]}),r),o=function(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}(r,n,t.stops[a][0],t.stops[a+1][0]),s=t.stops[a][1],l=t.stops[a+1][1],c=Ce[e.type]||Tr;if(t.colorSpace&&\"rgb\"!==t.colorSpace){var u=We[t.colorSpace];c=function(t,e){return u.reverse(u.interpolate(u.forward(t),u.forward(e),o))}}return\"function\"==typeof s.evaluate?{evaluate:function(){for(var t=[],e=arguments.length;e--;)t[e]=arguments[e];var r=s.evaluate.apply(void 0,t),n=l.evaluate.apply(void 0,t);if(void 0!==r&&void 0!==n)return c(r,n,o)}}:c(s,l,o)}function Cr(t,e,r){return\"color\"===e.type?r=ne.parse(r):\"formatted\"===e.type?r=oe.fromString(r.toString()):wr(r)===e.type||\"enum\"===e.type&&e.values[r]||(r=void 0),Ar(r,t.default,e.default)}xe.register(fr,{error:[{kind:\"error\"},[Gt],function(t,e){var r=e[0];throw new he(r.evaluate(t))}],typeof:[Gt,[Zt],function(t,e){return Qt(le(e[0].evaluate(t)))}],\"to-rgba\":[$t(Ht,4),[Wt],function(t,e){return e[0].evaluate(t).toArray()}],rgb:[Wt,[Ht,Ht,Ht],pr],rgba:[Wt,[Ht,Ht,Ht,Ht],pr],has:{type:Yt,overloads:[[[Gt],function(t,e){return dr(e[0].evaluate(t),t.properties())}],[[Gt,Xt],function(t,e){var r=e[0],n=e[1];return dr(r.evaluate(t),n.evaluate(t))}]]},get:{type:Zt,overloads:[[[Gt],function(t,e){return gr(e[0].evaluate(t),t.properties())}],[[Gt,Xt],function(t,e){var r=e[0],n=e[1];return gr(r.evaluate(t),n.evaluate(t))}]]},\"feature-state\":[Zt,[Gt],function(t,e){return gr(e[0].evaluate(t),t.featureState||{})}],properties:[Xt,[],function(t){return t.properties()}],\"geometry-type\":[Gt,[],function(t){return t.geometryType()}],id:[Zt,[],function(t){return t.id()}],zoom:[Ht,[],function(t){return t.globals.zoom}],\"heatmap-density\":[Ht,[],function(t){return t.globals.heatmapDensity||0}],\"line-progress\":[Ht,[],function(t){return t.globals.lineProgress||0}],accumulated:[Zt,[],function(t){return void 0===t.globals.accumulated?null:t.globals.accumulated}],\"+\":[Ht,vr(Ht),function(t,e){for(var r=0,n=0,i=e;n<i.length;n+=1)r+=i[n].evaluate(t);return r}],\"*\":[Ht,vr(Ht),function(t,e){for(var r=1,n=0,i=e;n<i.length;n+=1)r*=i[n].evaluate(t);return r}],\"-\":{type:Ht,overloads:[[[Ht,Ht],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)-n.evaluate(t)}],[[Ht],function(t,e){return-e[0].evaluate(t)}]]},\"/\":[Ht,[Ht,Ht],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)/n.evaluate(t)}],\"%\":[Ht,[Ht,Ht],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)%n.evaluate(t)}],ln2:[Ht,[],function(){return Math.LN2}],pi:[Ht,[],function(){return Math.PI}],e:[Ht,[],function(){return Math.E}],\"^\":[Ht,[Ht,Ht],function(t,e){var r=e[0],n=e[1];return Math.pow(r.evaluate(t),n.evaluate(t))}],sqrt:[Ht,[Ht],function(t,e){var r=e[0];return Math.sqrt(r.evaluate(t))}],log10:[Ht,[Ht],function(t,e){var r=e[0];return Math.log(r.evaluate(t))/Math.LN10}],ln:[Ht,[Ht],function(t,e){var r=e[0];return Math.log(r.evaluate(t))}],log2:[Ht,[Ht],function(t,e){var r=e[0];return Math.log(r.evaluate(t))/Math.LN2}],sin:[Ht,[Ht],function(t,e){var r=e[0];return Math.sin(r.evaluate(t))}],cos:[Ht,[Ht],function(t,e){var r=e[0];return Math.cos(r.evaluate(t))}],tan:[Ht,[Ht],function(t,e){var r=e[0];return Math.tan(r.evaluate(t))}],asin:[Ht,[Ht],function(t,e){var r=e[0];return Math.asin(r.evaluate(t))}],acos:[Ht,[Ht],function(t,e){var r=e[0];return Math.acos(r.evaluate(t))}],atan:[Ht,[Ht],function(t,e){var r=e[0];return Math.atan(r.evaluate(t))}],min:[Ht,vr(Ht),function(t,e){return Math.min.apply(Math,e.map(function(e){return e.evaluate(t)}))}],max:[Ht,vr(Ht),function(t,e){return Math.max.apply(Math,e.map(function(e){return e.evaluate(t)}))}],abs:[Ht,[Ht],function(t,e){var r=e[0];return Math.abs(r.evaluate(t))}],round:[Ht,[Ht],function(t,e){var r=e[0].evaluate(t);return r<0?-Math.round(-r):Math.round(r)}],floor:[Ht,[Ht],function(t,e){var r=e[0];return Math.floor(r.evaluate(t))}],ceil:[Ht,[Ht],function(t,e){var r=e[0];return Math.ceil(r.evaluate(t))}],\"filter-==\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1];return t.properties()[r.value]===n.value}],\"filter-id-==\":[Yt,[Zt],function(t,e){var r=e[0];return t.id()===r.value}],\"filter-type-==\":[Yt,[Gt],function(t,e){var r=e[0];return t.geometryType()===r.value}],\"filter-<\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<a}],\"filter-id-<\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<i}],\"filter->\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>a}],\"filter-id->\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>i}],\"filter-<=\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<=a}],\"filter-id-<=\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<=i}],\"filter->=\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>=a}],\"filter-id->=\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>=i}],\"filter-has\":[Yt,[Zt],function(t,e){return e[0].value in t.properties()}],\"filter-has-id\":[Yt,[],function(t){return null!==t.id()}],\"filter-type-in\":[Yt,[$t(Gt)],function(t,e){return e[0].value.indexOf(t.geometryType())>=0}],\"filter-id-in\":[Yt,[$t(Zt)],function(t,e){return e[0].value.indexOf(t.id())>=0}],\"filter-in-small\":[Yt,[Gt,$t(Zt)],function(t,e){var r=e[0];return e[1].value.indexOf(t.properties()[r.value])>=0}],\"filter-in-large\":[Yt,[Gt,$t(Zt)],function(t,e){var r=e[0],n=e[1];return function(t,e,r,n){for(;r<=n;){var i=r+n>>1;if(e[i]===t)return!0;e[i]>t?n=i-1:r=i+1}return!1}(t.properties()[r.value],n.value,0,n.value.length-1)}],all:{type:Yt,overloads:[[[Yt,Yt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)&&n.evaluate(t)}],[vr(Yt),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(!n[r].evaluate(t))return!1;return!0}]]},any:{type:Yt,overloads:[[[Yt,Yt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)||n.evaluate(t)}],[vr(Yt),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(n[r].evaluate(t))return!0;return!1}]]},\"!\":[Yt,[Yt],function(t,e){return!e[0].evaluate(t)}],\"is-supported-script\":[Yt,[Gt],function(t,e){var r=e[0],n=t.globals&&t.globals.isSupportedScript;return!n||n(r.evaluate(t))}],upcase:[Gt,[Gt],function(t,e){return e[0].evaluate(t).toUpperCase()}],downcase:[Gt,[Gt],function(t,e){return e[0].evaluate(t).toLowerCase()}],concat:[Gt,vr(Zt),function(t,e){return e.map(function(e){return ce(e.evaluate(t))}).join(\"\")}],\"resolved-locale\":[Gt,[Jt],function(t,e){return e[0].evaluate(t).resolvedLocale()}]});var Lr=function(t,e){var r;this.expression=t,this._warningHistory={},this._evaluator=new ye,this._defaultValue=e?\"color\"===(r=e).type&&kr(r.default)?new ne(0,0,0,0):\"color\"===r.type?ne.parse(r.default)||null:void 0===r.default?null:r.default:null,this._enumValues=e&&\"enum\"===e.type?e.values:null};function Pr(t){return Array.isArray(t)&&t.length>0&&\"string\"==typeof t[0]&&t[0]in fr}function Or(t,e){var r=new Ae(fr,[],e?function(t){var e={color:Wt,string:Gt,number:Ht,enum:Gt,boolean:Yt,formatted:Kt};return\"array\"===t.type?$t(e[t.value]||Zt,t.length):e[t.type]}(e):void 0),n=r.parse(t,void 0,void 0,void 0,e&&\"string\"===e.type?{typeAnnotation:\"coerce\"}:void 0);return n?mr(new Lr(n,e)):yr(r.errors)}Lr.prototype.evaluateWithoutErrorHandling=function(t,e,r){return this._evaluator.globals=t,this._evaluator.feature=e,this._evaluator.featureState=r,this.expression.evaluate(this._evaluator)},Lr.prototype.evaluate=function(t,e,r){this._evaluator.globals=t,this._evaluator.feature=e||null,this._evaluator.featureState=r||null;try{var n=this.expression.evaluate(this._evaluator);if(null==n)return this._defaultValue;if(this._enumValues&&!(n in this._enumValues))throw new he(\"Expected value to be one of \"+Object.keys(this._enumValues).map(function(t){return JSON.stringify(t)}).join(\", \")+\", but found \"+JSON.stringify(n)+\" instead.\");return n}catch(t){return this._warningHistory[t.message]||(this._warningHistory[t.message]=!0,\"undefined\"!=typeof console&&console.warn(t.message)),this._defaultValue}};var zr=function(t,e){this.kind=t,this._styleExpression=e,this.isStateDependent=\"constant\"!==t&&!we(e.expression)};zr.prototype.evaluateWithoutErrorHandling=function(t,e,r){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r)},zr.prototype.evaluate=function(t,e,r){return this._styleExpression.evaluate(t,e,r)};var Ir=function(t,e,r){this.kind=t,this.zoomStops=r.labels,this._styleExpression=e,this.isStateDependent=\"camera\"!==t&&!we(e.expression),r instanceof Xe&&(this.interpolationType=r.interpolation)};function Dr(t,e){if(\"error\"===(t=Or(t,e)).result)return t;var r=t.value.expression,n=_e(r);if(!n&&!xr(e))return yr([new Ut(\"\",\"data expressions not supported\")]);var i=ke(r,[\"zoom\"]);if(!i&&!br(e))return yr([new Ut(\"\",\"zoom expressions not supported\")]);var a=function t(e){var r=null;if(e instanceof Ke)r=t(e.result);else if(e instanceof Je)for(var n=0,i=e.args;n<i.length;n+=1){var a=i[n];if(r=t(a))break}else(e instanceof Se||e instanceof Xe)&&e.input instanceof xe&&\"zoom\"===e.input.name&&(r=e);return r instanceof Ut?r:(e.eachChild(function(e){var n=t(e);n instanceof Ut?r=n:!r&&n?r=new Ut(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.'):r&&n&&r!==n&&(r=new Ut(\"\",'Only one zoom-based \"step\" or \"interpolate\" subexpression may be used in an expression.'))}),r)}(r);return a||i?a instanceof Ut?yr([a]):a instanceof Xe&&!_r(e)?yr([new Ut(\"\",'\"interpolate\" expressions cannot be used with this property')]):mr(a?new Ir(n?\"camera\":\"composite\",t.value,a):new zr(n?\"constant\":\"source\",t.value)):yr([new Ut(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.')])}Ir.prototype.evaluateWithoutErrorHandling=function(t,e,r){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r)},Ir.prototype.evaluate=function(t,e,r){return this._styleExpression.evaluate(t,e,r)},Ir.prototype.interpolationFactor=function(t,e,r){return this.interpolationType?Xe.interpolationFactor(this.interpolationType,t,e,r):0};var Rr=function(t,e){this._parameters=t,this._specification=e,Ft(this,function t(e,r){var n,i,a,o=\"color\"===r.type,s=e.stops&&\"object\"==typeof e.stops[0][0],l=s||void 0!==e.property,c=s||!l,u=e.type||(_r(r)?\"exponential\":\"interval\");if(o&&((e=Ft({},e)).stops&&(e.stops=e.stops.map(function(t){return[t[0],ne.parse(t[1])]})),e.default?e.default=ne.parse(e.default):e.default=ne.parse(r.default)),e.colorSpace&&\"rgb\"!==e.colorSpace&&!We[e.colorSpace])throw new Error(\"Unknown color space: \"+e.colorSpace);if(\"exponential\"===u)n=Er;else if(\"interval\"===u)n=Sr;else if(\"categorical\"===u){n=Mr,i=Object.create(null);for(var h=0,f=e.stops;h<f.length;h+=1){var p=f[h];i[p[0]]=p[1]}a=typeof e.stops[0][0]}else{if(\"identity\"!==u)throw new Error('Unknown function type \"'+u+'\"');n=Cr}if(s){for(var d={},g=[],v=0;v<e.stops.length;v++){var m=e.stops[v],y=m[0].zoom;void 0===d[y]&&(d[y]={zoom:y,type:e.type,property:e.property,default:e.default,stops:[]},g.push(y)),d[y].stops.push([m[0].value,m[1]])}for(var x=[],b=0,_=g;b<_.length;b+=1){var w=_[b];x.push([d[w].zoom,t(d[w],r)])}var k={name:\"linear\"};return{kind:\"composite\",interpolationType:k,interpolationFactor:Xe.interpolationFactor.bind(void 0,k),zoomStops:x.map(function(t){return t[0]}),evaluate:function(t,n){var i=t.zoom;return Er({stops:x,base:e.base},r,i).evaluate(i,n)}}}if(c){var T=\"exponential\"===u?{name:\"exponential\",base:void 0!==e.base?e.base:1}:null;return{kind:\"camera\",interpolationType:T,interpolationFactor:Xe.interpolationFactor.bind(void 0,T),zoomStops:e.stops.map(function(t){return t[0]}),evaluate:function(t){var o=t.zoom;return n(e,r,o,i,a)}}}return{kind:\"source\",evaluate:function(t,o){var s=o&&o.properties?o.properties[e.property]:void 0;return void 0===s?Ar(e.default,r.default):n(e,r,s,i,a)}}}(this._parameters,this._specification))};function Fr(t){var e=t.key,r=t.value,n=t.valueSpec||{},i=t.objectElementValidators||{},a=t.style,o=t.styleSpec,s=[],l=wr(r);if(\"object\"!==l)return[new Dt(e,r,\"object expected, \"+l+\" found\")];for(var c in r){var u=c.split(\".\")[0],h=n[u]||n[\"*\"],f=void 0;if(i[u])f=i[u];else if(n[u])f=ln;else if(i[\"*\"])f=i[\"*\"];else{if(!n[\"*\"]){s.push(new Dt(e,r[c],'unknown property \"'+c+'\"'));continue}f=ln}s=s.concat(f({key:(e?e+\".\":e)+c,value:r[c],valueSpec:h,style:a,styleSpec:o,object:r,objectKey:c},r))}for(var p in n)i[p]||n[p].required&&void 0===n[p].default&&void 0===r[p]&&s.push(new Dt(e,r,'missing required property \"'+p+'\"'));return s}function Br(t){var e=t.value,r=t.valueSpec,n=t.style,i=t.styleSpec,a=t.key,o=t.arrayElementValidator||ln;if(\"array\"!==wr(e))return[new Dt(a,e,\"array expected, \"+wr(e)+\" found\")];if(r.length&&e.length!==r.length)return[new Dt(a,e,\"array length \"+r.length+\" expected, length \"+e.length+\" found\")];if(r[\"min-length\"]&&e.length<r[\"min-length\"])return[new Dt(a,e,\"array length at least \"+r[\"min-length\"]+\" expected, length \"+e.length+\" found\")];var s={type:r.value,values:r.values};i.$version<7&&(s.function=r.function),\"object\"===wr(r.value)&&(s=r.value);for(var l=[],c=0;c<e.length;c++)l=l.concat(o({array:e,arrayIndex:c,value:e[c],valueSpec:s,style:n,styleSpec:i,key:a+\"[\"+c+\"]\"}));return l}function Nr(t){var e=t.key,r=t.value,n=t.valueSpec,i=wr(r);return\"number\"!==i?[new Dt(e,r,\"number expected, \"+i+\" found\")]:\"minimum\"in n&&r<n.minimum?[new Dt(e,r,r+\" is less than the minimum value \"+n.minimum)]:\"maximum\"in n&&r>n.maximum?[new Dt(e,r,r+\" is greater than the maximum value \"+n.maximum)]:[]}function jr(t){var e,r,n,i=t.valueSpec,a=Nt(t.value.type),o={},s=\"categorical\"!==a&&void 0===t.value.property,l=!s,c=\"array\"===wr(t.value.stops)&&\"array\"===wr(t.value.stops[0])&&\"object\"===wr(t.value.stops[0][0]),u=Fr({key:t.key,value:t.value,valueSpec:t.styleSpec.function,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{stops:function(t){if(\"identity\"===a)return[new Dt(t.key,t.value,'identity function may not have a \"stops\" property')];var e=[],r=t.value;return e=e.concat(Br({key:t.key,value:r,valueSpec:t.valueSpec,style:t.style,styleSpec:t.styleSpec,arrayElementValidator:h})),\"array\"===wr(r)&&0===r.length&&e.push(new Dt(t.key,r,\"array must have at least one stop\")),e},default:function(t){return ln({key:t.key,value:t.value,valueSpec:i,style:t.style,styleSpec:t.styleSpec})}}});return\"identity\"===a&&s&&u.push(new Dt(t.key,t.value,'missing required property \"property\"')),\"identity\"===a||t.value.stops||u.push(new Dt(t.key,t.value,'missing required property \"stops\"')),\"exponential\"===a&&t.valueSpec.expression&&!_r(t.valueSpec)&&u.push(new Dt(t.key,t.value,\"exponential functions not supported\")),t.styleSpec.$version>=8&&(l&&!xr(t.valueSpec)?u.push(new Dt(t.key,t.value,\"property functions not supported\")):s&&!br(t.valueSpec)&&u.push(new Dt(t.key,t.value,\"zoom functions not supported\"))),\"categorical\"!==a&&!c||void 0!==t.value.property||u.push(new Dt(t.key,t.value,'\"property\" property is required')),u;function h(t){var e=[],a=t.value,s=t.key;if(\"array\"!==wr(a))return[new Dt(s,a,\"array expected, \"+wr(a)+\" found\")];if(2!==a.length)return[new Dt(s,a,\"array length 2 expected, length \"+a.length+\" found\")];if(c){if(\"object\"!==wr(a[0]))return[new Dt(s,a,\"object expected, \"+wr(a[0])+\" found\")];if(void 0===a[0].zoom)return[new Dt(s,a,\"object stop key must have zoom\")];if(void 0===a[0].value)return[new Dt(s,a,\"object stop key must have value\")];if(n&&n>Nt(a[0].zoom))return[new Dt(s,a[0].zoom,\"stop zoom values must appear in ascending order\")];Nt(a[0].zoom)!==n&&(n=Nt(a[0].zoom),r=void 0,o={}),e=e.concat(Fr({key:s+\"[0]\",value:a[0],valueSpec:{zoom:{}},style:t.style,styleSpec:t.styleSpec,objectElementValidators:{zoom:Nr,value:f}}))}else e=e.concat(f({key:s+\"[0]\",value:a[0],valueSpec:{},style:t.style,styleSpec:t.styleSpec},a));return Pr(jt(a[1]))?e.concat([new Dt(s+\"[1]\",a[1],\"expressions are not allowed in function stops.\")]):e.concat(ln({key:s+\"[1]\",value:a[1],valueSpec:i,style:t.style,styleSpec:t.styleSpec}))}function f(t,n){var s=wr(t.value),l=Nt(t.value),c=null!==t.value?t.value:n;if(e){if(s!==e)return[new Dt(t.key,c,s+\" stop domain type must match previous stop domain type \"+e)]}else e=s;if(\"number\"!==s&&\"string\"!==s&&\"boolean\"!==s)return[new Dt(t.key,c,\"stop domain value must be a number, string, or boolean\")];if(\"number\"!==s&&\"categorical\"!==a){var u=\"number expected, \"+s+\" found\";return xr(i)&&void 0===a&&(u+='\\nIf you intended to use a categorical function, specify `\"type\": \"categorical\"`.'),[new Dt(t.key,c,u)]}return\"categorical\"!==a||\"number\"!==s||isFinite(l)&&Math.floor(l)===l?\"categorical\"!==a&&\"number\"===s&&void 0!==r&&l<r?[new Dt(t.key,c,\"stop domain values must appear in ascending order\")]:(r=l,\"categorical\"===a&&l in o?[new Dt(t.key,c,\"stop domain values must be unique\")]:(o[l]=!0,[])):[new Dt(t.key,c,\"integer expected, found \"+l)]}}function Ur(t){var e=(\"property\"===t.expressionContext?Dr:Or)(jt(t.value),t.valueSpec);if(\"error\"===e.result)return e.value.map(function(e){return new Dt(\"\"+t.key+e.key,t.value,e.message)});var r=e.value.expression||e.value._styleExpression.expression;if(\"property\"===t.expressionContext&&\"text-font\"===t.propertyKey&&-1!==r.possibleOutputs().indexOf(void 0))return[new Dt(t.key,t.value,'Invalid data expression for \"'+t.propertyKey+'\". Output values must be contained as literals within the expression.')];if(\"property\"===t.expressionContext&&\"layout\"===t.propertyType&&!we(r))return[new Dt(t.key,t.value,'\"feature-state\" data expressions are not supported with layout properties.')];if(\"filter\"===t.expressionContext&&!we(r))return[new Dt(t.key,t.value,'\"feature-state\" data expressions are not supported with filters.')];if(t.expressionContext&&0===t.expressionContext.indexOf(\"cluster\")){if(!ke(r,[\"zoom\",\"feature-state\"]))return[new Dt(t.key,t.value,'\"zoom\" and \"feature-state\" expressions are not supported with cluster properties.')];if(\"cluster-initial\"===t.expressionContext&&!_e(r))return[new Dt(t.key,t.value,\"Feature data expressions are not supported with initial expression part of cluster properties.\")]}return[]}function Vr(t){var e=t.key,r=t.value,n=t.valueSpec,i=[];return Array.isArray(n.values)?-1===n.values.indexOf(Nt(r))&&i.push(new Dt(e,r,\"expected one of [\"+n.values.join(\", \")+\"], \"+JSON.stringify(r)+\" found\")):-1===Object.keys(n.values).indexOf(Nt(r))&&i.push(new Dt(e,r,\"expected one of [\"+Object.keys(n.values).join(\", \")+\"], \"+JSON.stringify(r)+\" found\")),i}function qr(t){if(!0===t||!1===t)return!0;if(!Array.isArray(t)||0===t.length)return!1;switch(t[0]){case\"has\":return t.length>=2&&\"$id\"!==t[1]&&\"$type\"!==t[1];case\"in\":case\"!in\":case\"!has\":case\"none\":return!1;case\"==\":case\"!=\":case\">\":case\">=\":case\"<\":case\"<=\":return 3!==t.length||Array.isArray(t[1])||Array.isArray(t[2]);case\"any\":case\"all\":for(var e=0,r=t.slice(1);e<r.length;e+=1){var n=r[e];if(!qr(n)&&\"boolean\"!=typeof n)return!1}return!0;default:return!0}}Rr.deserialize=function(t){return new Rr(t._parameters,t._specification)},Rr.serialize=function(t){return{_parameters:t._parameters,_specification:t._specification}};var Hr={type:\"boolean\",default:!1,transition:!1,\"property-type\":\"data-driven\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]}};function Gr(t){if(null==t)return function(){return!0};qr(t)||(t=Wr(t));var e=Or(t,Hr);if(\"error\"===e.result)throw new Error(e.value.map(function(t){return t.key+\": \"+t.message}).join(\", \"));return function(t,r){return e.value.evaluate(t,r)}}function Yr(t,e){return t<e?-1:t>e?1:0}function Wr(t){if(!t)return!0;var e,r=t[0];return t.length<=1?\"any\"!==r:\"==\"===r?Xr(t[1],t[2],\"==\"):\"!=\"===r?Kr(Xr(t[1],t[2],\"==\")):\"<\"===r||\">\"===r||\"<=\"===r||\">=\"===r?Xr(t[1],t[2],r):\"any\"===r?(e=t.slice(1),[\"any\"].concat(e.map(Wr))):\"all\"===r?[\"all\"].concat(t.slice(1).map(Wr)):\"none\"===r?[\"all\"].concat(t.slice(1).map(Wr).map(Kr)):\"in\"===r?Zr(t[1],t.slice(2)):\"!in\"===r?Kr(Zr(t[1],t.slice(2))):\"has\"===r?Jr(t[1]):\"!has\"!==r||Kr(Jr(t[1]))}function Xr(t,e,r){switch(t){case\"$type\":return[\"filter-type-\"+r,e];case\"$id\":return[\"filter-id-\"+r,e];default:return[\"filter-\"+r,t,e]}}function Zr(t,e){if(0===e.length)return!1;switch(t){case\"$type\":return[\"filter-type-in\",[\"literal\",e]];case\"$id\":return[\"filter-id-in\",[\"literal\",e]];default:return e.length>200&&!e.some(function(t){return typeof t!=typeof e[0]})?[\"filter-in-large\",t,[\"literal\",e.sort(Yr)]]:[\"filter-in-small\",t,[\"literal\",e]]}}function Jr(t){switch(t){case\"$type\":return!0;case\"$id\":return[\"filter-has-id\"];default:return[\"filter-has\",t]}}function Kr(t){return[\"!\",t]}function $r(t){return qr(jt(t.value))?Ur(Ft({},t,{expressionContext:\"filter\",valueSpec:{value:\"boolean\"}})):function t(e){var r=e.value,n=e.key;if(\"array\"!==wr(r))return[new Dt(n,r,\"array expected, \"+wr(r)+\" found\")];var i,a=e.styleSpec,o=[];if(r.length<1)return[new Dt(n,r,\"filter array must have at least 1 element\")];switch(o=o.concat(Vr({key:n+\"[0]\",value:r[0],valueSpec:a.filter_operator,style:e.style,styleSpec:e.styleSpec})),Nt(r[0])){case\"<\":case\"<=\":case\">\":case\">=\":r.length>=2&&\"$type\"===Nt(r[1])&&o.push(new Dt(n,r,'\"$type\" cannot be use with operator \"'+r[0]+'\"'));case\"==\":case\"!=\":3!==r.length&&o.push(new Dt(n,r,'filter array for operator \"'+r[0]+'\" must have 3 elements'));case\"in\":case\"!in\":r.length>=2&&\"string\"!==(i=wr(r[1]))&&o.push(new Dt(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"));for(var s=2;s<r.length;s++)i=wr(r[s]),\"$type\"===Nt(r[1])?o=o.concat(Vr({key:n+\"[\"+s+\"]\",value:r[s],valueSpec:a.geometry_type,style:e.style,styleSpec:e.styleSpec})):\"string\"!==i&&\"number\"!==i&&\"boolean\"!==i&&o.push(new Dt(n+\"[\"+s+\"]\",r[s],\"string, number, or boolean expected, \"+i+\" found\"));break;case\"any\":case\"all\":case\"none\":for(var l=1;l<r.length;l++)o=o.concat(t({key:n+\"[\"+l+\"]\",value:r[l],style:e.style,styleSpec:e.styleSpec}));break;case\"has\":case\"!has\":i=wr(r[1]),2!==r.length?o.push(new Dt(n,r,'filter array for \"'+r[0]+'\" operator must have 2 elements')):\"string\"!==i&&o.push(new Dt(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"))}return o}(t)}function Qr(t,e){var r=t.key,n=t.style,i=t.styleSpec,a=t.value,o=t.objectKey,s=i[e+\"_\"+t.layerType];if(!s)return[];var l=o.match(/^(.*)-transition$/);if(\"paint\"===e&&l&&s[l[1]]&&s[l[1]].transition)return ln({key:r,value:a,valueSpec:i.transition,style:n,styleSpec:i});var c,u=t.valueSpec||s[o];if(!u)return[new Dt(r,a,'unknown property \"'+o+'\"')];if(\"string\"===wr(a)&&xr(u)&&!u.tokens&&(c=/^{([^}]+)}$/.exec(a)))return[new Dt(r,a,'\"'+o+'\" does not support interpolation syntax\\nUse an identity property function instead: `{ \"type\": \"identity\", \"property\": '+JSON.stringify(c[1])+\" }`.\")];var h=[];return\"symbol\"===t.layerType&&(\"text-field\"===o&&n&&!n.glyphs&&h.push(new Dt(r,a,'use of \"text-field\" requires a style \"glyphs\" property')),\"text-font\"===o&&kr(jt(a))&&\"identity\"===Nt(a.type)&&h.push(new Dt(r,a,'\"text-font\" does not support identity functions'))),h.concat(ln({key:t.key,value:a,valueSpec:u,style:n,styleSpec:i,expressionContext:\"property\",propertyType:e,propertyKey:o}))}function tn(t){return Qr(t,\"paint\")}function en(t){return Qr(t,\"layout\")}function rn(t){var e=[],r=t.value,n=t.key,i=t.style,a=t.styleSpec;r.type||r.ref||e.push(new Dt(n,r,'either \"type\" or \"ref\" is required'));var o,s=Nt(r.type),l=Nt(r.ref);if(r.id)for(var c=Nt(r.id),u=0;u<t.arrayIndex;u++){var h=i.layers[u];Nt(h.id)===c&&e.push(new Dt(n,r.id,'duplicate layer id \"'+r.id+'\", previously used at line '+h.id.__line__))}if(\"ref\"in r)[\"type\",\"source\",\"source-layer\",\"filter\",\"layout\"].forEach(function(t){t in r&&e.push(new Dt(n,r[t],'\"'+t+'\" is prohibited for ref layers'))}),i.layers.forEach(function(t){Nt(t.id)===l&&(o=t)}),o?o.ref?e.push(new Dt(n,r.ref,\"ref cannot reference another ref layer\")):s=Nt(o.type):e.push(new Dt(n,r.ref,'ref layer \"'+l+'\" not found'));else if(\"background\"!==s)if(r.source){var f=i.sources&&i.sources[r.source],p=f&&Nt(f.type);f?\"vector\"===p&&\"raster\"===s?e.push(new Dt(n,r.source,'layer \"'+r.id+'\" requires a raster source')):\"raster\"===p&&\"raster\"!==s?e.push(new Dt(n,r.source,'layer \"'+r.id+'\" requires a vector source')):\"vector\"!==p||r[\"source-layer\"]?\"raster-dem\"===p&&\"hillshade\"!==s?e.push(new Dt(n,r.source,\"raster-dem source can only be used with layer type 'hillshade'.\")):\"line\"!==s||!r.paint||!r.paint[\"line-gradient\"]||\"geojson\"===p&&f.lineMetrics||e.push(new Dt(n,r,'layer \"'+r.id+'\" specifies a line-gradient, which requires a GeoJSON source with `lineMetrics` enabled.')):e.push(new Dt(n,r,'layer \"'+r.id+'\" must specify a \"source-layer\"')):e.push(new Dt(n,r.source,'source \"'+r.source+'\" not found'))}else e.push(new Dt(n,r,'missing required property \"source\"'));return e=e.concat(Fr({key:n,value:r,valueSpec:a.layer,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(){return[]},type:function(){return ln({key:n+\".type\",value:r.type,valueSpec:a.layer.type,style:t.style,styleSpec:t.styleSpec,object:r,objectKey:\"type\"})},filter:$r,layout:function(t){return Fr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return en(Ft({layerType:s},t))}}})},paint:function(t){return Fr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return tn(Ft({layerType:s},t))}}})}}}))}function nn(t){var e=t.value,r=t.key,n=t.styleSpec,i=t.style;if(!e.type)return[new Dt(r,e,'\"type\" is required')];var a,o=Nt(e.type);switch(o){case\"vector\":case\"raster\":case\"raster-dem\":if(a=Fr({key:r,value:e,valueSpec:n[\"source_\"+o.replace(\"-\",\"_\")],style:t.style,styleSpec:n}),\"url\"in e)for(var s in e)[\"type\",\"url\",\"tileSize\"].indexOf(s)<0&&a.push(new Dt(r+\".\"+s,e[s],'a source with a \"url\" property may not include a \"'+s+'\" property'));return a;case\"geojson\":if(a=Fr({key:r,value:e,valueSpec:n.source_geojson,style:i,styleSpec:n}),e.cluster)for(var l in e.clusterProperties){var c=e.clusterProperties[l],u=c[0],h=c[1],f=\"string\"==typeof u?[u,[\"accumulated\"],[\"get\",l]]:u;a.push.apply(a,Ur({key:r+\".\"+l+\".map\",value:h,expressionContext:\"cluster-map\"})),a.push.apply(a,Ur({key:r+\".\"+l+\".reduce\",value:f,expressionContext:\"cluster-reduce\"}))}return a;case\"video\":return Fr({key:r,value:e,valueSpec:n.source_video,style:i,styleSpec:n});case\"image\":return Fr({key:r,value:e,valueSpec:n.source_image,style:i,styleSpec:n});case\"canvas\":return[new Dt(r,null,\"Please use runtime APIs to add canvas sources, rather than including them in stylesheets.\",\"source.canvas\")];default:return Vr({key:r+\".type\",value:e.type,valueSpec:{values:[\"vector\",\"raster\",\"raster-dem\",\"geojson\",\"video\",\"image\"]},style:i,styleSpec:n})}}function an(t){var e=t.value,r=t.styleSpec,n=r.light,i=t.style,a=[],o=wr(e);if(void 0===e)return a;if(\"object\"!==o)return a.concat([new Dt(\"light\",e,\"object expected, \"+o+\" found\")]);for(var s in e){var l=s.match(/^(.*)-transition$/);a=l&&n[l[1]]&&n[l[1]].transition?a.concat(ln({key:s,value:e[s],valueSpec:r.transition,style:i,styleSpec:r})):n[s]?a.concat(ln({key:s,value:e[s],valueSpec:n[s],style:i,styleSpec:r})):a.concat([new Dt(s,e[s],'unknown property \"'+s+'\"')])}return a}function on(t){var e=t.value,r=t.key,n=wr(e);return\"string\"!==n?[new Dt(r,e,\"string expected, \"+n+\" found\")]:[]}var sn={\"*\":function(){return[]},array:Br,boolean:function(t){var e=t.value,r=t.key,n=wr(e);return\"boolean\"!==n?[new Dt(r,e,\"boolean expected, \"+n+\" found\")]:[]},number:Nr,color:function(t){var e=t.key,r=t.value,n=wr(r);return\"string\"!==n?[new Dt(e,r,\"color expected, \"+n+\" found\")]:null===re(r)?[new Dt(e,r,'color expected, \"'+r+'\" found')]:[]},constants:Rt,enum:Vr,filter:$r,function:jr,layer:rn,object:Fr,source:nn,light:an,string:on,formatted:function(t){return 0===on(t).length?[]:Ur(t)}};function ln(t){var e=t.value,r=t.valueSpec,n=t.styleSpec;return r.expression&&kr(Nt(e))?jr(t):r.expression&&Pr(jt(e))?Ur(t):r.type&&sn[r.type]?sn[r.type](t):Fr(Ft({},t,{valueSpec:r.type?n[r.type]:r}))}function cn(t){var e=t.value,r=t.key,n=on(t);return n.length?n:(-1===e.indexOf(\"{fontstack}\")&&n.push(new Dt(r,e,'\"glyphs\" url must include a \"{fontstack}\" token')),-1===e.indexOf(\"{range}\")&&n.push(new Dt(r,e,'\"glyphs\" url must include a \"{range}\" token')),n)}function un(t,e){e=e||It;var r=[];return r=r.concat(ln({key:\"\",value:t,valueSpec:e.$root,styleSpec:e,style:t,objectElementValidators:{glyphs:cn,\"*\":function(){return[]}}})),t.constants&&(r=r.concat(Rt({key:\"constants\",value:t.constants,style:t,styleSpec:e}))),hn(r)}function hn(t){return[].concat(t).sort(function(t,e){return t.line-e.line})}function fn(t){return function(){for(var e=[],r=arguments.length;r--;)e[r]=arguments[r];return hn(t.apply(this,e))}}un.source=fn(nn),un.light=fn(an),un.layer=fn(rn),un.filter=fn($r),un.paintProperty=fn(tn),un.layoutProperty=fn(en);var pn=un,dn=pn.light,gn=pn.paintProperty,vn=pn.layoutProperty;function mn(t,e){var r=!1;if(e&&e.length)for(var n=0,i=e;n<i.length;n+=1){var a=i[n];t.fire(new Ot(new Error(a.message))),r=!0}return r}var yn=bn,xn=3;function bn(t,e,r){var n=this.cells=[];if(t instanceof ArrayBuffer){this.arrayBuffer=t;var i=new Int32Array(this.arrayBuffer);t=i[0],e=i[1],r=i[2],this.d=e+2*r;for(var a=0;a<this.d*this.d;a++){var o=i[xn+a],s=i[xn+a+1];n.push(o===s?null:i.subarray(o,s))}var l=i[xn+n.length],c=i[xn+n.length+1];this.keys=i.subarray(l,c),this.bboxes=i.subarray(c),this.insert=this._insertReadonly}else{this.d=e+2*r;for(var u=0;u<this.d*this.d;u++)n.push([]);this.keys=[],this.bboxes=[]}this.n=e,this.extent=t,this.padding=r,this.scale=e/t,this.uid=0;var h=r/e*t;this.min=-h,this.max=t+h}bn.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertCell,this.uid++),this.keys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},bn.prototype._insertReadonly=function(){throw\"Cannot insert into a GridIndex created from an ArrayBuffer.\"},bn.prototype._insertCell=function(t,e,r,n,i,a){this.cells[i].push(a)},bn.prototype.query=function(t,e,r,n,i){var a=this.min,o=this.max;if(t<=a&&e<=a&&o<=r&&o<=n&&!i)return Array.prototype.slice.call(this.keys);var s=[];return this._forEachCell(t,e,r,n,this._queryCell,s,{},i),s},bn.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=this.cells[i];if(null!==l)for(var c=this.keys,u=this.bboxes,h=0;h<l.length;h++){var f=l[h];if(void 0===o[f]){var p=4*f;(s?s(u[p+0],u[p+1],u[p+2],u[p+3]):t<=u[p+2]&&e<=u[p+3]&&r>=u[p+0]&&n>=u[p+1])?(o[f]=!0,a.push(c[f])):o[f]=!1}}},bn.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToCellCoord(t),c=this._convertToCellCoord(e),u=this._convertToCellCoord(r),h=this._convertToCellCoord(n),f=l;f<=u;f++)for(var p=c;p<=h;p++){var d=this.d*p+f;if((!s||s(this._convertFromCellCoord(f),this._convertFromCellCoord(p),this._convertFromCellCoord(f+1),this._convertFromCellCoord(p+1)))&&i.call(this,t,e,r,n,d,a,o,s))return}},bn.prototype._convertFromCellCoord=function(t){return(t-this.padding)/this.scale},bn.prototype._convertToCellCoord=function(t){return Math.max(0,Math.min(this.d-1,Math.floor(t*this.scale)+this.padding))},bn.prototype.toArrayBuffer=function(){if(this.arrayBuffer)return this.arrayBuffer;for(var t=this.cells,e=xn+this.cells.length+1+1,r=0,n=0;n<this.cells.length;n++)r+=this.cells[n].length;var i=new Int32Array(e+r+this.keys.length+this.bboxes.length);i[0]=this.extent,i[1]=this.n,i[2]=this.padding;for(var a=e,o=0;o<t.length;o++){var s=t[o];i[xn+o]=a,i.set(s,a),a+=s.length}return i[xn+t.length]=a,i.set(this.keys,a),a+=this.keys.length,i[xn+t.length+1]=a,i.set(this.bboxes,a),a+=this.bboxes.length,i.buffer};var _n=self.ImageData,wn={};function kn(t,e,r){void 0===r&&(r={}),Object.defineProperty(e,\"_classRegistryKey\",{value:t,writeable:!1}),wn[t]={klass:e,omit:r.omit||[],shallow:r.shallow||[]}}for(var Tn in kn(\"Object\",Object),yn.serialize=function(t,e){var r=t.toArrayBuffer();return e&&e.push(r),{buffer:r}},yn.deserialize=function(t){return new yn(t.buffer)},kn(\"Grid\",yn),kn(\"Color\",ne),kn(\"Error\",Error),kn(\"StylePropertyFunction\",Rr),kn(\"StyleExpression\",Lr,{omit:[\"_evaluator\"]}),kn(\"ZoomDependentExpression\",Ir),kn(\"ZoomConstantExpression\",zr),kn(\"CompoundExpression\",xe,{omit:[\"_evaluate\"]}),fr)fr[Tn]._classRegistryKey||kn(\"Expression_\"+Tn,fr[Tn]);function An(t,e){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp)return t;if(t instanceof ArrayBuffer)return e&&e.push(t),t;if(ArrayBuffer.isView(t)){var r=t;return e&&e.push(r.buffer),r}if(t instanceof _n)return e&&e.push(t.data.buffer),t;if(Array.isArray(t)){for(var n=[],i=0,a=t;i<a.length;i+=1){var o=a[i];n.push(An(o,e))}return n}if(\"object\"==typeof t){var s=t.constructor,l=s._classRegistryKey;if(!l)throw new Error(\"can't serialize object of unregistered class\");var c=s.serialize?s.serialize(t,e):{};if(!s.serialize){for(var u in t)if(t.hasOwnProperty(u)&&!(wn[l].omit.indexOf(u)>=0)){var h=t[u];c[u]=wn[l].shallow.indexOf(u)>=0?h:An(h,e)}t instanceof Error&&(c.message=t.message)}if(c.$name)throw new Error(\"$name property is reserved for worker serialization logic.\");return\"Object\"!==l&&(c.$name=l),c}throw new Error(\"can't serialize object of type \"+typeof t)}function Mn(t){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp||t instanceof ArrayBuffer||ArrayBuffer.isView(t)||t instanceof _n)return t;if(Array.isArray(t))return t.map(Mn);if(\"object\"==typeof t){var e=t.$name||\"Object\",r=wn[e].klass;if(!r)throw new Error(\"can't deserialize unregistered class \"+e);if(r.deserialize)return r.deserialize(t);for(var n=Object.create(r.prototype),i=0,a=Object.keys(t);i<a.length;i+=1){var o=a[i];if(\"$name\"!==o){var s=t[o];n[o]=wn[e].shallow.indexOf(o)>=0?s:Mn(s)}}return n}throw new Error(\"can't deserialize object of type \"+typeof t)}var Sn=function(){this.first=!0};Sn.prototype.update=function(t,e){var r=Math.floor(t);return this.first?(this.first=!1,this.lastIntegerZoom=r,this.lastIntegerZoomTime=0,this.lastZoom=t,this.lastFloorZoom=r,!0):(this.lastFloorZoom>r?(this.lastIntegerZoom=r+1,this.lastIntegerZoomTime=e):this.lastFloorZoom<r&&(this.lastIntegerZoom=r,this.lastIntegerZoomTime=e),t!==this.lastZoom&&(this.lastZoom=t,this.lastFloorZoom=r,!0))};var En={\"Latin-1 Supplement\":function(t){return t>=128&&t<=255},Arabic:function(t){return t>=1536&&t<=1791},\"Arabic Supplement\":function(t){return t>=1872&&t<=1919},\"Arabic Extended-A\":function(t){return t>=2208&&t<=2303},\"Hangul Jamo\":function(t){return t>=4352&&t<=4607},\"Unified Canadian Aboriginal Syllabics\":function(t){return t>=5120&&t<=5759},Khmer:function(t){return t>=6016&&t<=6143},\"Unified Canadian Aboriginal Syllabics Extended\":function(t){return t>=6320&&t<=6399},\"General Punctuation\":function(t){return t>=8192&&t<=8303},\"Letterlike Symbols\":function(t){return t>=8448&&t<=8527},\"Number Forms\":function(t){return t>=8528&&t<=8591},\"Miscellaneous Technical\":function(t){return t>=8960&&t<=9215},\"Control Pictures\":function(t){return t>=9216&&t<=9279},\"Optical Character Recognition\":function(t){return t>=9280&&t<=9311},\"Enclosed Alphanumerics\":function(t){return t>=9312&&t<=9471},\"Geometric Shapes\":function(t){return t>=9632&&t<=9727},\"Miscellaneous Symbols\":function(t){return t>=9728&&t<=9983},\"Miscellaneous Symbols and Arrows\":function(t){return t>=11008&&t<=11263},\"CJK Radicals Supplement\":function(t){return t>=11904&&t<=12031},\"Kangxi Radicals\":function(t){return t>=12032&&t<=12255},\"Ideographic Description Characters\":function(t){return t>=12272&&t<=12287},\"CJK Symbols and Punctuation\":function(t){return t>=12288&&t<=12351},Hiragana:function(t){return t>=12352&&t<=12447},Katakana:function(t){return t>=12448&&t<=12543},Bopomofo:function(t){return t>=12544&&t<=12591},\"Hangul Compatibility Jamo\":function(t){return t>=12592&&t<=12687},Kanbun:function(t){return t>=12688&&t<=12703},\"Bopomofo Extended\":function(t){return t>=12704&&t<=12735},\"CJK Strokes\":function(t){return t>=12736&&t<=12783},\"Katakana Phonetic Extensions\":function(t){return t>=12784&&t<=12799},\"Enclosed CJK Letters and Months\":function(t){return t>=12800&&t<=13055},\"CJK Compatibility\":function(t){return t>=13056&&t<=13311},\"CJK Unified Ideographs Extension A\":function(t){return t>=13312&&t<=19903},\"Yijing Hexagram Symbols\":function(t){return t>=19904&&t<=19967},\"CJK Unified Ideographs\":function(t){return t>=19968&&t<=40959},\"Yi Syllables\":function(t){return t>=40960&&t<=42127},\"Yi Radicals\":function(t){return t>=42128&&t<=42191},\"Hangul Jamo Extended-A\":function(t){return t>=43360&&t<=43391},\"Hangul Syllables\":function(t){return t>=44032&&t<=55215},\"Hangul Jamo Extended-B\":function(t){return t>=55216&&t<=55295},\"Private Use Area\":function(t){return t>=57344&&t<=63743},\"CJK Compatibility Ideographs\":function(t){return t>=63744&&t<=64255},\"Arabic Presentation Forms-A\":function(t){return t>=64336&&t<=65023},\"Vertical Forms\":function(t){return t>=65040&&t<=65055},\"CJK Compatibility Forms\":function(t){return t>=65072&&t<=65103},\"Small Form Variants\":function(t){return t>=65104&&t<=65135},\"Arabic Presentation Forms-B\":function(t){return t>=65136&&t<=65279},\"Halfwidth and Fullwidth Forms\":function(t){return t>=65280&&t<=65519}};function Cn(t){for(var e=0,r=t;e<r.length;e+=1)if(On(r[e].charCodeAt(0)))return!0;return!1}function Ln(t){for(var e=0,r=t;e<r.length;e+=1)if(!Pn(r[e].charCodeAt(0)))return!1;return!0}function Pn(t){return!(En.Arabic(t)||En[\"Arabic Supplement\"](t)||En[\"Arabic Extended-A\"](t)||En[\"Arabic Presentation Forms-A\"](t)||En[\"Arabic Presentation Forms-B\"](t))}function On(t){return!!(746===t||747===t||!(t<4352)&&(En[\"Bopomofo Extended\"](t)||En.Bopomofo(t)||En[\"CJK Compatibility Forms\"](t)&&!(t>=65097&&t<=65103)||En[\"CJK Compatibility Ideographs\"](t)||En[\"CJK Compatibility\"](t)||En[\"CJK Radicals Supplement\"](t)||En[\"CJK Strokes\"](t)||!(!En[\"CJK Symbols and Punctuation\"](t)||t>=12296&&t<=12305||t>=12308&&t<=12319||12336===t)||En[\"CJK Unified Ideographs Extension A\"](t)||En[\"CJK Unified Ideographs\"](t)||En[\"Enclosed CJK Letters and Months\"](t)||En[\"Hangul Compatibility Jamo\"](t)||En[\"Hangul Jamo Extended-A\"](t)||En[\"Hangul Jamo Extended-B\"](t)||En[\"Hangul Jamo\"](t)||En[\"Hangul Syllables\"](t)||En.Hiragana(t)||En[\"Ideographic Description Characters\"](t)||En.Kanbun(t)||En[\"Kangxi Radicals\"](t)||En[\"Katakana Phonetic Extensions\"](t)||En.Katakana(t)&&12540!==t||!(!En[\"Halfwidth and Fullwidth Forms\"](t)||65288===t||65289===t||65293===t||t>=65306&&t<=65310||65339===t||65341===t||65343===t||t>=65371&&t<=65503||65507===t||t>=65512&&t<=65519)||!(!En[\"Small Form Variants\"](t)||t>=65112&&t<=65118||t>=65123&&t<=65126)||En[\"Unified Canadian Aboriginal Syllabics\"](t)||En[\"Unified Canadian Aboriginal Syllabics Extended\"](t)||En[\"Vertical Forms\"](t)||En[\"Yijing Hexagram Symbols\"](t)||En[\"Yi Syllables\"](t)||En[\"Yi Radicals\"](t)))}function zn(t){return!(On(t)||function(t){return!!(En[\"Latin-1 Supplement\"](t)&&(167===t||169===t||174===t||177===t||188===t||189===t||190===t||215===t||247===t)||En[\"General Punctuation\"](t)&&(8214===t||8224===t||8225===t||8240===t||8241===t||8251===t||8252===t||8258===t||8263===t||8264===t||8265===t||8273===t)||En[\"Letterlike Symbols\"](t)||En[\"Number Forms\"](t)||En[\"Miscellaneous Technical\"](t)&&(t>=8960&&t<=8967||t>=8972&&t<=8991||t>=8996&&t<=9e3||9003===t||t>=9085&&t<=9114||t>=9150&&t<=9165||9167===t||t>=9169&&t<=9179||t>=9186&&t<=9215)||En[\"Control Pictures\"](t)&&9251!==t||En[\"Optical Character Recognition\"](t)||En[\"Enclosed Alphanumerics\"](t)||En[\"Geometric Shapes\"](t)||En[\"Miscellaneous Symbols\"](t)&&!(t>=9754&&t<=9759)||En[\"Miscellaneous Symbols and Arrows\"](t)&&(t>=11026&&t<=11055||t>=11088&&t<=11097||t>=11192&&t<=11243)||En[\"CJK Symbols and Punctuation\"](t)||En.Katakana(t)||En[\"Private Use Area\"](t)||En[\"CJK Compatibility Forms\"](t)||En[\"Small Form Variants\"](t)||En[\"Halfwidth and Fullwidth Forms\"](t)||8734===t||8756===t||8757===t||t>=9984&&t<=10087||t>=10102&&t<=10131||65532===t||65533===t)}(t))}function In(t,e){return!(!e&&(t>=1424&&t<=2303||En[\"Arabic Presentation Forms-A\"](t)||En[\"Arabic Presentation Forms-B\"](t))||t>=2304&&t<=3583||t>=3840&&t<=4255||En.Khmer(t))}var Dn,Rn=!1,Fn=null,Bn=!1,Nn=new zt,jn={applyArabicShaping:null,processBidirectionalText:null,processStyledBidirectionalText:null,isLoaded:function(){return Bn||null!=jn.applyArabicShaping}},Un=function(t,e){this.zoom=t,e?(this.now=e.now,this.fadeDuration=e.fadeDuration,this.zoomHistory=e.zoomHistory,this.transition=e.transition):(this.now=0,this.fadeDuration=0,this.zoomHistory=new Sn,this.transition={})};Un.prototype.isSupportedScript=function(t){return function(t,e){for(var r=0,n=t;r<n.length;r+=1)if(!In(n[r].charCodeAt(0),e))return!1;return!0}(t,jn.isLoaded())},Un.prototype.crossFadingFactor=function(){return 0===this.fadeDuration?1:Math.min((this.now-this.zoomHistory.lastIntegerZoomTime)/this.fadeDuration,1)},Un.prototype.getCrossfadeParameters=function(){var t=this.zoom,e=t-Math.floor(t),r=this.crossFadingFactor();return t>this.zoomHistory.lastIntegerZoom?{fromScale:2,toScale:1,t:e+(1-e)*r}:{fromScale:.5,toScale:1,t:1-(1-r)*e}};var Vn=function(t,e){this.property=t,this.value=e,this.expression=function(t,e){if(kr(t))return new Rr(t,e);if(Pr(t)){var r=Dr(t,e);if(\"error\"===r.result)throw new Error(r.value.map(function(t){return t.key+\": \"+t.message}).join(\", \"));return r.value}var n=t;return\"string\"==typeof t&&\"color\"===e.type&&(n=ne.parse(t)),{kind:\"constant\",evaluate:function(){return n}}}(void 0===e?t.specification.default:e,t.specification)};Vn.prototype.isDataDriven=function(){return\"source\"===this.expression.kind||\"composite\"===this.expression.kind},Vn.prototype.possiblyEvaluate=function(t){return this.property.possiblyEvaluate(this,t)};var qn=function(t){this.property=t,this.value=new Vn(t,void 0)};qn.prototype.transitioned=function(t,e){return new Gn(this.property,this.value,e,h({},t.transition,this.transition),t.now)},qn.prototype.untransitioned=function(){return new Gn(this.property,this.value,null,{},0)};var Hn=function(t){this._properties=t,this._values=Object.create(t.defaultTransitionablePropertyValues)};Hn.prototype.getValue=function(t){return b(this._values[t].value.value)},Hn.prototype.setValue=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new qn(this._values[t].property)),this._values[t].value=new Vn(this._values[t].property,null===e?void 0:b(e))},Hn.prototype.getTransition=function(t){return b(this._values[t].transition)},Hn.prototype.setTransition=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new qn(this._values[t].property)),this._values[t].transition=b(e)||void 0},Hn.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i);var a=this.getTransition(n);void 0!==a&&(t[n+\"-transition\"]=a)}return t},Hn.prototype.transitioned=function(t,e){for(var r=new Yn(this._properties),n=0,i=Object.keys(this._values);n<i.length;n+=1){var a=i[n];r._values[a]=this._values[a].transitioned(t,e._values[a])}return r},Hn.prototype.untransitioned=function(){for(var t=new Yn(this._properties),e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e];t._values[n]=this._values[n].untransitioned()}return t};var Gn=function(t,e,r,n,i){this.property=t,this.value=e,this.begin=i+n.delay||0,this.end=this.begin+n.duration||0,t.specification.transition&&(n.delay||n.duration)&&(this.prior=r)};Gn.prototype.possiblyEvaluate=function(t){var e=t.now||0,r=this.value.possiblyEvaluate(t),n=this.prior;if(n){if(e>this.end)return this.prior=null,r;if(this.value.isDataDriven())return this.prior=null,r;if(e<this.begin)return n.possiblyEvaluate(t);var i=(e-this.begin)/(this.end-this.begin);return this.property.interpolate(n.possiblyEvaluate(t),r,function(t){if(i<=0)return 0;if(i>=1)return 1;var e=i*i,r=e*i;return 4*(i<.5?r:3*(i-e)+r-.75)}())}return r};var Yn=function(t){this._properties=t,this._values=Object.create(t.defaultTransitioningPropertyValues)};Yn.prototype.possiblyEvaluate=function(t){for(var e=new Zn(this._properties),r=0,n=Object.keys(this._values);r<n.length;r+=1){var i=n[r];e._values[i]=this._values[i].possiblyEvaluate(t)}return e},Yn.prototype.hasTransition=function(){for(var t=0,e=Object.keys(this._values);t<e.length;t+=1){var r=e[t];if(this._values[r].prior)return!0}return!1};var Wn=function(t){this._properties=t,this._values=Object.create(t.defaultPropertyValues)};Wn.prototype.getValue=function(t){return b(this._values[t].value)},Wn.prototype.setValue=function(t,e){this._values[t]=new Vn(this._values[t].property,null===e?void 0:b(e))},Wn.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i)}return t},Wn.prototype.possiblyEvaluate=function(t){for(var e=new Zn(this._properties),r=0,n=Object.keys(this._values);r<n.length;r+=1){var i=n[r];e._values[i]=this._values[i].possiblyEvaluate(t)}return e};var Xn=function(t,e,r){this.property=t,this.value=e,this.parameters=r};Xn.prototype.isConstant=function(){return\"constant\"===this.value.kind},Xn.prototype.constantOr=function(t){return\"constant\"===this.value.kind?this.value.value:t},Xn.prototype.evaluate=function(t,e){return this.property.evaluate(this.value,this.parameters,t,e)};var Zn=function(t){this._properties=t,this._values=Object.create(t.defaultPossiblyEvaluatedValues)};Zn.prototype.get=function(t){return this._values[t]};var Jn=function(t){this.specification=t};Jn.prototype.possiblyEvaluate=function(t,e){return t.expression.evaluate(e)},Jn.prototype.interpolate=function(t,e,r){var n=Ce[this.specification.type];return n?n(t,e,r):t};var Kn=function(t){this.specification=t};Kn.prototype.possiblyEvaluate=function(t,e){return\"constant\"===t.expression.kind||\"camera\"===t.expression.kind?new Xn(this,{kind:\"constant\",value:t.expression.evaluate(e)},e):new Xn(this,t.expression,e)},Kn.prototype.interpolate=function(t,e,r){if(\"constant\"!==t.value.kind||\"constant\"!==e.value.kind)return t;if(void 0===t.value.value||void 0===e.value.value)return new Xn(this,{kind:\"constant\",value:void 0},t.parameters);var n=Ce[this.specification.type];return n?new Xn(this,{kind:\"constant\",value:n(t.value.value,e.value.value,r)},t.parameters):t},Kn.prototype.evaluate=function(t,e,r,n){return\"constant\"===t.kind?t.value:t.evaluate(e,r,n)};var $n=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(t,e){if(void 0===t.value)return new Xn(this,{kind:\"constant\",value:void 0},e);if(\"constant\"===t.expression.kind){var r=t.expression.evaluate(e),n=this._calculate(r,r,r,e);return new Xn(this,{kind:\"constant\",value:n},e)}if(\"camera\"===t.expression.kind){var i=this._calculate(t.expression.evaluate({zoom:e.zoom-1}),t.expression.evaluate({zoom:e.zoom}),t.expression.evaluate({zoom:e.zoom+1}),e);return new Xn(this,{kind:\"constant\",value:i},e)}return new Xn(this,t.expression,e)},e.prototype.evaluate=function(t,e,r,n){if(\"source\"===t.kind){var i=t.evaluate(e,r,n);return this._calculate(i,i,i,e)}return\"composite\"===t.kind?this._calculate(t.evaluate({zoom:Math.floor(e.zoom)-1},r,n),t.evaluate({zoom:Math.floor(e.zoom)},r,n),t.evaluate({zoom:Math.floor(e.zoom)+1},r,n),e):t.value},e.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},e.prototype.interpolate=function(t){return t},e}(Kn),Qn=function(t){this.specification=t};Qn.prototype.possiblyEvaluate=function(t,e){if(void 0!==t.value){if(\"constant\"===t.expression.kind){var r=t.expression.evaluate(e);return this._calculate(r,r,r,e)}return this._calculate(t.expression.evaluate(new Un(Math.floor(e.zoom-1),e)),t.expression.evaluate(new Un(Math.floor(e.zoom),e)),t.expression.evaluate(new Un(Math.floor(e.zoom+1),e)),e)}},Qn.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},Qn.prototype.interpolate=function(t){return t};var ti=function(t){this.specification=t};ti.prototype.possiblyEvaluate=function(t,e){return!!t.expression.evaluate(e)},ti.prototype.interpolate=function(){return!1};var ei=function(t){for(var e in this.properties=t,this.defaultPropertyValues={},this.defaultTransitionablePropertyValues={},this.defaultTransitioningPropertyValues={},this.defaultPossiblyEvaluatedValues={},t){var r=t[e],n=this.defaultPropertyValues[e]=new Vn(r,void 0),i=this.defaultTransitionablePropertyValues[e]=new qn(r);this.defaultTransitioningPropertyValues[e]=i.untransitioned(),this.defaultPossiblyEvaluatedValues[e]=n.possiblyEvaluate({})}};kn(\"DataDrivenProperty\",Kn),kn(\"DataConstantProperty\",Jn),kn(\"CrossFadedDataDrivenProperty\",$n),kn(\"CrossFadedProperty\",Qn),kn(\"ColorRampProperty\",ti);var ri=function(t){function e(e,r){if(t.call(this),this.id=e.id,this.type=e.type,this._featureFilter=function(){return!0},\"custom\"!==e.type&&(e=e,this.metadata=e.metadata,this.minzoom=e.minzoom,this.maxzoom=e.maxzoom,\"background\"!==e.type&&(this.source=e.source,this.sourceLayer=e[\"source-layer\"],this.filter=e.filter),r.layout&&(this._unevaluatedLayout=new Wn(r.layout)),r.paint)){for(var n in this._transitionablePaint=new Hn(r.paint),e.paint)this.setPaintProperty(n,e.paint[n],{validate:!1});for(var i in e.layout)this.setLayoutProperty(i,e.layout[i],{validate:!1});this._transitioningPaint=this._transitionablePaint.untransitioned()}}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getCrossfadeParameters=function(){return this._crossfadeParameters},e.prototype.getLayoutProperty=function(t){return\"visibility\"===t?this.visibility:this._unevaluatedLayout.getValue(t)},e.prototype.setLayoutProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e){var n=\"layers.\"+this.id+\".layout.\"+t;if(this._validate(vn,n,t,e,r))return}\"visibility\"!==t?this._unevaluatedLayout.setValue(t,e):this.visibility=e},e.prototype.getPaintProperty=function(t){return m(t,\"-transition\")?this._transitionablePaint.getTransition(t.slice(0,-\"-transition\".length)):this._transitionablePaint.getValue(t)},e.prototype.setPaintProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e){var n=\"layers.\"+this.id+\".paint.\"+t;if(this._validate(gn,n,t,e,r))return!1}if(m(t,\"-transition\"))return this._transitionablePaint.setTransition(t.slice(0,-\"-transition\".length),e||void 0),!1;var i=this._transitionablePaint._values[t],a=\"cross-faded-data-driven\"===i.property.specification[\"property-type\"],o=i.value.isDataDriven();return this._transitionablePaint.setValue(t,e),this._handleSpecialPaintPropertyUpdate(t),this._transitionablePaint._values[t].value.isDataDriven()||o||a},e.prototype._handleSpecialPaintPropertyUpdate=function(t){},e.prototype.isHidden=function(t){return!!(this.minzoom&&t<this.minzoom)||!!(this.maxzoom&&t>=this.maxzoom)||\"none\"===this.visibility},e.prototype.updateTransitions=function(t){this._transitioningPaint=this._transitionablePaint.transitioned(t,this._transitioningPaint)},e.prototype.hasTransition=function(){return this._transitioningPaint.hasTransition()},e.prototype.recalculate=function(t){t.getCrossfadeParameters&&(this._crossfadeParameters=t.getCrossfadeParameters()),this._unevaluatedLayout&&(this.layout=this._unevaluatedLayout.possiblyEvaluate(t)),this.paint=this._transitioningPaint.possiblyEvaluate(t)},e.prototype.serialize=function(){var t={id:this.id,type:this.type,source:this.source,\"source-layer\":this.sourceLayer,metadata:this.metadata,minzoom:this.minzoom,maxzoom:this.maxzoom,filter:this.filter,layout:this._unevaluatedLayout&&this._unevaluatedLayout.serialize(),paint:this._transitionablePaint&&this._transitionablePaint.serialize()};return this.visibility&&(t.layout=t.layout||{},t.layout.visibility=this.visibility),x(t,function(t,e){return!(void 0===t||\"layout\"===e&&!Object.keys(t).length||\"paint\"===e&&!Object.keys(t).length)})},e.prototype._validate=function(t,e,r,n,i){return void 0===i&&(i={}),(!i||!1!==i.validate)&&mn(this,t.call(pn,{key:e,layerType:this.type,objectKey:r,value:n,styleSpec:It,style:{glyphs:!0,sprite:!0}}))},e.prototype.is3D=function(){return!1},e.prototype.isTileClipped=function(){return!1},e.prototype.hasOffscreenPass=function(){return!1},e.prototype.resize=function(){},e.prototype.isStateDependent=function(){for(var t in this.paint._values){var e=this.paint.get(t);if(e instanceof Xn&&xr(e.property.specification)&&(\"source\"===e.value.kind||\"composite\"===e.value.kind)&&e.value.isStateDependent)return!0}return!1},e}(zt),ni={Int8:Int8Array,Uint8:Uint8Array,Int16:Int16Array,Uint16:Uint16Array,Int32:Int32Array,Uint32:Uint32Array,Float32:Float32Array},ii=function(t,e){this._structArray=t,this._pos1=e*this.size,this._pos2=this._pos1/2,this._pos4=this._pos1/4,this._pos8=this._pos1/8},ai=function(){this.isTransferred=!1,this.capacity=-1,this.resize(0)};function oi(t,e){void 0===e&&(e=1);var r=0,n=0;return{members:t.map(function(t){var i,a=(i=t.type,ni[i].BYTES_PER_ELEMENT),o=r=si(r,Math.max(e,a)),s=t.components||1;return n=Math.max(n,a),r+=a*s,{name:t.name,type:t.type,components:s,offset:o}}),size:si(r,Math.max(n,e)),alignment:e}}function si(t,e){return Math.ceil(t/e)*e}ai.serialize=function(t,e){return t._trim(),e&&(t.isTransferred=!0,e.push(t.arrayBuffer)),{length:t.length,arrayBuffer:t.arrayBuffer}},ai.deserialize=function(t){var e=Object.create(this.prototype);return e.arrayBuffer=t.arrayBuffer,e.length=t.length,e.capacity=t.arrayBuffer.byteLength/e.bytesPerElement,e._refreshViews(),e},ai.prototype._trim=function(){this.length!==this.capacity&&(this.capacity=this.length,this.arrayBuffer=this.arrayBuffer.slice(0,this.length*this.bytesPerElement),this._refreshViews())},ai.prototype.clear=function(){this.length=0},ai.prototype.resize=function(t){this.reserve(t),this.length=t},ai.prototype.reserve=function(t){if(t>this.capacity){this.capacity=Math.max(t,Math.floor(5*this.capacity),128),this.arrayBuffer=new ArrayBuffer(this.capacity*this.bytesPerElement);var e=this.uint8;this._refreshViews(),e&&this.uint8.set(e)}},ai.prototype._refreshViews=function(){throw new Error(\"_refreshViews() must be implemented by each concrete StructArray layout\")};var li=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.int16[n+0]=e,this.int16[n+1]=r,t},e}(ai);li.prototype.bytesPerElement=4,kn(\"StructArrayLayout2i4\",li);var ci=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.int16[a+0]=e,this.int16[a+1]=r,this.int16[a+2]=n,this.int16[a+3]=i,t},e}(ai);ci.prototype.bytesPerElement=8,kn(\"StructArrayLayout4i8\",ci);var ui=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(ai);ui.prototype.bytesPerElement=12,kn(\"StructArrayLayout2i4i12\",ui);var hi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=4*t,l=8*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.uint8[l+4]=n,this.uint8[l+5]=i,this.uint8[l+6]=a,this.uint8[l+7]=o,t},e}(ai);hi.prototype.bytesPerElement=8,kn(\"StructArrayLayout2i4ub8\",hi);var fi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s){var l=this.length;return this.resize(l+1),this.emplace(l,t,e,r,n,i,a,o,s)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l){var c=8*t;return this.uint16[c+0]=e,this.uint16[c+1]=r,this.uint16[c+2]=n,this.uint16[c+3]=i,this.uint16[c+4]=a,this.uint16[c+5]=o,this.uint16[c+6]=s,this.uint16[c+7]=l,t},e}(ai);fi.prototype.bytesPerElement=16,kn(\"StructArrayLayout8ui16\",fi);var pi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s){var l=this.length;return this.resize(l+1),this.emplace(l,t,e,r,n,i,a,o,s)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l){var c=8*t;return this.int16[c+0]=e,this.int16[c+1]=r,this.int16[c+2]=n,this.int16[c+3]=i,this.uint16[c+4]=a,this.uint16[c+5]=o,this.uint16[c+6]=s,this.uint16[c+7]=l,t},e}(ai);pi.prototype.bytesPerElement=16,kn(\"StructArrayLayout4i4ui16\",pi);var di=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.float32[i+0]=e,this.float32[i+1]=r,this.float32[i+2]=n,t},e}(ai);di.prototype.bytesPerElement=12,kn(\"StructArrayLayout3f12\",di);var gi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.uint32[r+0]=e,t},e}(ai);gi.prototype.bytesPerElement=4,kn(\"StructArrayLayout1ul4\",gi);var vi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u){var h=this.length;return this.resize(h+1),this.emplace(h,t,e,r,n,i,a,o,s,l,c,u)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h){var f=12*t,p=6*t;return this.int16[f+0]=e,this.int16[f+1]=r,this.int16[f+2]=n,this.int16[f+3]=i,this.int16[f+4]=a,this.int16[f+5]=o,this.uint32[p+3]=s,this.uint16[f+8]=l,this.uint16[f+9]=c,this.int16[f+10]=u,this.int16[f+11]=h,t},e}(ai);vi.prototype.bytesPerElement=24,kn(\"StructArrayLayout6i1ul2ui2i24\",vi);var mi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(ai);mi.prototype.bytesPerElement=12,kn(\"StructArrayLayout2i2i2i12\",mi);var yi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=12*t,o=3*t;return this.uint8[a+0]=e,this.uint8[a+1]=r,this.float32[o+1]=n,this.float32[o+2]=i,t},e}(ai);yi.prototype.bytesPerElement=12,kn(\"StructArrayLayout2ub2f12\",yi);var xi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d){var g=this.length;return this.resize(g+1),this.emplace(g,t,e,r,n,i,a,o,s,l,c,u,h,f,p,d)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g){var v=22*t,m=11*t,y=44*t;return this.int16[v+0]=e,this.int16[v+1]=r,this.uint16[v+2]=n,this.uint16[v+3]=i,this.uint32[m+2]=a,this.uint32[m+3]=o,this.uint32[m+4]=s,this.uint16[v+10]=l,this.uint16[v+11]=c,this.uint16[v+12]=u,this.float32[m+7]=h,this.float32[m+8]=f,this.uint8[y+36]=p,this.uint8[y+37]=d,this.uint32[m+10]=g,t},e}(ai);xi.prototype.bytesPerElement=44,kn(\"StructArrayLayout2i2ui3ul3ui2f2ub1ul44\",xi);var bi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m){var y=this.length;return this.resize(y+1),this.emplace(y,t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m,y){var x=22*t,b=11*t;return this.int16[x+0]=e,this.int16[x+1]=r,this.int16[x+2]=n,this.int16[x+3]=i,this.int16[x+4]=a,this.int16[x+5]=o,this.uint16[x+6]=s,this.uint16[x+7]=l,this.uint16[x+8]=c,this.uint16[x+9]=u,this.uint16[x+10]=h,this.uint16[x+11]=f,this.uint16[x+12]=p,this.uint16[x+13]=d,this.uint16[x+14]=g,this.uint32[b+8]=v,this.float32[b+9]=m,this.float32[b+10]=y,t},e}(ai);bi.prototype.bytesPerElement=44,kn(\"StructArrayLayout6i9ui1ul2f44\",bi);var _i=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.float32[r+0]=e,t},e}(ai);_i.prototype.bytesPerElement=4,kn(\"StructArrayLayout1f4\",_i);var wi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.int16[i+0]=e,this.int16[i+1]=r,this.int16[i+2]=n,t},e}(ai);wi.prototype.bytesPerElement=6,kn(\"StructArrayLayout3i6\",wi);var ki=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=2*t,a=4*t;return this.uint32[i+0]=e,this.uint16[a+2]=r,this.uint16[a+3]=n,t},e}(ai);ki.prototype.bytesPerElement=8,kn(\"StructArrayLayout1ul2ui8\",ki);var Ti=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.uint16[i+0]=e,this.uint16[i+1]=r,this.uint16[i+2]=n,t},e}(ai);Ti.prototype.bytesPerElement=6,kn(\"StructArrayLayout3ui6\",Ti);var Ai=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.uint16[n+0]=e,this.uint16[n+1]=r,t},e}(ai);Ai.prototype.bytesPerElement=4,kn(\"StructArrayLayout2ui4\",Ai);var Mi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.uint16[r+0]=e,t},e}(ai);Mi.prototype.bytesPerElement=2,kn(\"StructArrayLayout1ui2\",Mi);var Si=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.float32[n+0]=e,this.float32[n+1]=r,t},e}(ai);Si.prototype.bytesPerElement=8,kn(\"StructArrayLayout2f8\",Si);var Ei=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.float32[a+0]=e,this.float32[a+1]=r,this.float32[a+2]=n,this.float32[a+3]=i,t},e}(ai);Ei.prototype.bytesPerElement=16,kn(\"StructArrayLayout4f16\",Ei);var Ci=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorPointX:{configurable:!0},anchorPointY:{configurable:!0},x1:{configurable:!0},y1:{configurable:!0},x2:{configurable:!0},y2:{configurable:!0},featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0},radius:{configurable:!0},signedDistanceFromAnchor:{configurable:!0},anchorPoint:{configurable:!0}};return r.anchorPointX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorPointX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorPointY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorPointY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.x1.get=function(){return this._structArray.int16[this._pos2+2]},r.x1.set=function(t){this._structArray.int16[this._pos2+2]=t},r.y1.get=function(){return this._structArray.int16[this._pos2+3]},r.y1.set=function(t){this._structArray.int16[this._pos2+3]=t},r.x2.get=function(){return this._structArray.int16[this._pos2+4]},r.x2.set=function(t){this._structArray.int16[this._pos2+4]=t},r.y2.get=function(){return this._structArray.int16[this._pos2+5]},r.y2.set=function(t){this._structArray.int16[this._pos2+5]=t},r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.featureIndex.set=function(t){this._structArray.uint32[this._pos4+3]=t},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.sourceLayerIndex.set=function(t){this._structArray.uint16[this._pos2+8]=t},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.bucketIndex.set=function(t){this._structArray.uint16[this._pos2+9]=t},r.radius.get=function(){return this._structArray.int16[this._pos2+10]},r.radius.set=function(t){this._structArray.int16[this._pos2+10]=t},r.signedDistanceFromAnchor.get=function(){return this._structArray.int16[this._pos2+11]},r.signedDistanceFromAnchor.set=function(t){this._structArray.int16[this._pos2+11]=t},r.anchorPoint.get=function(){return new i(this.anchorPointX,this.anchorPointY)},Object.defineProperties(e.prototype,r),e}(ii);Ci.prototype.size=24;var Li=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Ci(this,t)},e}(vi);kn(\"CollisionBoxArray\",Li);var Pi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},glyphStartIndex:{configurable:!0},numGlyphs:{configurable:!0},vertexStartIndex:{configurable:!0},lineStartIndex:{configurable:!0},lineLength:{configurable:!0},segment:{configurable:!0},lowerSize:{configurable:!0},upperSize:{configurable:!0},lineOffsetX:{configurable:!0},lineOffsetY:{configurable:!0},writingMode:{configurable:!0},hidden:{configurable:!0},crossTileID:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.glyphStartIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.glyphStartIndex.set=function(t){this._structArray.uint16[this._pos2+2]=t},r.numGlyphs.get=function(){return this._structArray.uint16[this._pos2+3]},r.numGlyphs.set=function(t){this._structArray.uint16[this._pos2+3]=t},r.vertexStartIndex.get=function(){return this._structArray.uint32[this._pos4+2]},r.vertexStartIndex.set=function(t){this._structArray.uint32[this._pos4+2]=t},r.lineStartIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.lineStartIndex.set=function(t){this._structArray.uint32[this._pos4+3]=t},r.lineLength.get=function(){return this._structArray.uint32[this._pos4+4]},r.lineLength.set=function(t){this._structArray.uint32[this._pos4+4]=t},r.segment.get=function(){return this._structArray.uint16[this._pos2+10]},r.segment.set=function(t){this._structArray.uint16[this._pos2+10]=t},r.lowerSize.get=function(){return this._structArray.uint16[this._pos2+11]},r.lowerSize.set=function(t){this._structArray.uint16[this._pos2+11]=t},r.upperSize.get=function(){return this._structArray.uint16[this._pos2+12]},r.upperSize.set=function(t){this._structArray.uint16[this._pos2+12]=t},r.lineOffsetX.get=function(){return this._structArray.float32[this._pos4+7]},r.lineOffsetX.set=function(t){this._structArray.float32[this._pos4+7]=t},r.lineOffsetY.get=function(){return this._structArray.float32[this._pos4+8]},r.lineOffsetY.set=function(t){this._structArray.float32[this._pos4+8]=t},r.writingMode.get=function(){return this._structArray.uint8[this._pos1+36]},r.writingMode.set=function(t){this._structArray.uint8[this._pos1+36]=t},r.hidden.get=function(){return this._structArray.uint8[this._pos1+37]},r.hidden.set=function(t){this._structArray.uint8[this._pos1+37]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+10]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+10]=t},Object.defineProperties(e.prototype,r),e}(ii);Pi.prototype.size=44;var Oi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Pi(this,t)},e}(xi);kn(\"PlacedSymbolArray\",Oi);var zi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},rightJustifiedTextSymbolIndex:{configurable:!0},centerJustifiedTextSymbolIndex:{configurable:!0},leftJustifiedTextSymbolIndex:{configurable:!0},verticalPlacedTextSymbolIndex:{configurable:!0},key:{configurable:!0},textBoxStartIndex:{configurable:!0},textBoxEndIndex:{configurable:!0},iconBoxStartIndex:{configurable:!0},iconBoxEndIndex:{configurable:!0},featureIndex:{configurable:!0},numHorizontalGlyphVertices:{configurable:!0},numVerticalGlyphVertices:{configurable:!0},numIconVertices:{configurable:!0},crossTileID:{configurable:!0},textBoxScale:{configurable:!0},radialTextOffset:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.rightJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+2]},r.rightJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+2]=t},r.centerJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+3]},r.centerJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+3]=t},r.leftJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+4]},r.leftJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+4]=t},r.verticalPlacedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+5]},r.verticalPlacedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+5]=t},r.key.get=function(){return this._structArray.uint16[this._pos2+6]},r.key.set=function(t){this._structArray.uint16[this._pos2+6]=t},r.textBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+7]},r.textBoxStartIndex.set=function(t){this._structArray.uint16[this._pos2+7]=t},r.textBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.textBoxEndIndex.set=function(t){this._structArray.uint16[this._pos2+8]=t},r.iconBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.iconBoxStartIndex.set=function(t){this._structArray.uint16[this._pos2+9]=t},r.iconBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+10]},r.iconBoxEndIndex.set=function(t){this._structArray.uint16[this._pos2+10]=t},r.featureIndex.get=function(){return this._structArray.uint16[this._pos2+11]},r.featureIndex.set=function(t){this._structArray.uint16[this._pos2+11]=t},r.numHorizontalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+12]},r.numHorizontalGlyphVertices.set=function(t){this._structArray.uint16[this._pos2+12]=t},r.numVerticalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+13]},r.numVerticalGlyphVertices.set=function(t){this._structArray.uint16[this._pos2+13]=t},r.numIconVertices.get=function(){return this._structArray.uint16[this._pos2+14]},r.numIconVertices.set=function(t){this._structArray.uint16[this._pos2+14]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+8]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+8]=t},r.textBoxScale.get=function(){return this._structArray.float32[this._pos4+9]},r.textBoxScale.set=function(t){this._structArray.float32[this._pos4+9]=t},r.radialTextOffset.get=function(){return this._structArray.float32[this._pos4+10]},r.radialTextOffset.set=function(t){this._structArray.float32[this._pos4+10]=t},Object.defineProperties(e.prototype,r),e}(ii);zi.prototype.size=44;var Ii=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new zi(this,t)},e}(bi);kn(\"SymbolInstanceArray\",Ii);var Di=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={offsetX:{configurable:!0}};return r.offsetX.get=function(){return this._structArray.float32[this._pos4+0]},r.offsetX.set=function(t){this._structArray.float32[this._pos4+0]=t},Object.defineProperties(e.prototype,r),e}(ii);Di.prototype.size=4;var Ri=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getoffsetX=function(t){return this.float32[1*t+0]},e.prototype.get=function(t){return new Di(this,t)},e}(_i);kn(\"GlyphOffsetArray\",Ri);var Fi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={x:{configurable:!0},y:{configurable:!0},tileUnitDistanceFromAnchor:{configurable:!0}};return r.x.get=function(){return this._structArray.int16[this._pos2+0]},r.x.set=function(t){this._structArray.int16[this._pos2+0]=t},r.y.get=function(){return this._structArray.int16[this._pos2+1]},r.y.set=function(t){this._structArray.int16[this._pos2+1]=t},r.tileUnitDistanceFromAnchor.get=function(){return this._structArray.int16[this._pos2+2]},r.tileUnitDistanceFromAnchor.set=function(t){this._structArray.int16[this._pos2+2]=t},Object.defineProperties(e.prototype,r),e}(ii);Fi.prototype.size=6;var Bi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getx=function(t){return this.int16[3*t+0]},e.prototype.gety=function(t){return this.int16[3*t+1]},e.prototype.gettileUnitDistanceFromAnchor=function(t){return this.int16[3*t+2]},e.prototype.get=function(t){return new Fi(this,t)},e}(wi);kn(\"SymbolLineVertexArray\",Bi);var Ni=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0}};return r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+0]},r.featureIndex.set=function(t){this._structArray.uint32[this._pos4+0]=t},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.sourceLayerIndex.set=function(t){this._structArray.uint16[this._pos2+2]=t},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+3]},r.bucketIndex.set=function(t){this._structArray.uint16[this._pos2+3]=t},Object.defineProperties(e.prototype,r),e}(ii);Ni.prototype.size=8;var ji=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Ni(this,t)},e}(ki);kn(\"FeatureIndexArray\",ji);var Ui=oi([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,Vi=function(t){void 0===t&&(t=[]),this.segments=t};function qi(t,e){return 256*(t=c(Math.floor(t),0,255))+c(Math.floor(e),0,255)}Vi.prototype.prepareSegment=function(t,e,r,n){var i=this.segments[this.segments.length-1];return t>Vi.MAX_VERTEX_ARRAY_LENGTH&&w(\"Max vertices per segment is \"+Vi.MAX_VERTEX_ARRAY_LENGTH+\": bucket requested \"+t),(!i||i.vertexLength+t>Vi.MAX_VERTEX_ARRAY_LENGTH||i.sortKey!==n)&&(i={vertexOffset:e.length,primitiveOffset:r.length,vertexLength:0,primitiveLength:0},void 0!==n&&(i.sortKey=n),this.segments.push(i)),i},Vi.prototype.get=function(){return this.segments},Vi.prototype.destroy=function(){for(var t=0,e=this.segments;t<e.length;t+=1){var r=e[t];for(var n in r.vaos)r.vaos[n].destroy()}},Vi.simpleSegment=function(t,e,r,n){return new Vi([{vertexOffset:t,primitiveOffset:e,vertexLength:r,primitiveLength:n,vaos:{},sortKey:0}])},Vi.MAX_VERTEX_ARRAY_LENGTH=Math.pow(2,16)-1,kn(\"SegmentVector\",Vi);var Hi=function(){this.ids=[],this.positions=[],this.indexed=!1};function Gi(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}Hi.prototype.add=function(t,e,r,n){this.ids.push(t),this.positions.push(e,r,n)},Hi.prototype.getPositions=function(t){for(var e=0,r=this.ids.length-1;e<r;){var n=e+r>>1;this.ids[n]>=t?r=n:e=n+1}for(var i=[];this.ids[e]===t;){var a=this.positions[3*e],o=this.positions[3*e+1],s=this.positions[3*e+2];i.push({index:a,start:o,end:s}),e++}return i},Hi.serialize=function(t,e){var r=new Float64Array(t.ids),n=new Uint32Array(t.positions);return function t(e,r,n,i){if(!(n>=i)){for(var a=e[n+i>>1],o=n-1,s=i+1;;){do{o++}while(e[o]<a);do{s--}while(e[s]>a);if(o>=s)break;Gi(e,o,s),Gi(r,3*o,3*s),Gi(r,3*o+1,3*s+1),Gi(r,3*o+2,3*s+2)}t(e,r,n,s),t(e,r,s+1,i)}}(r,n,0,r.length-1),e.push(r.buffer,n.buffer),{ids:r,positions:n}},Hi.deserialize=function(t){var e=new Hi;return e.ids=t.ids,e.positions=t.positions,e.indexed=!0,e},kn(\"FeaturePositionMap\",Hi);var Yi=function(t,e){this.gl=t.gl,this.location=e},Wi=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1i(this.location,t))},e}(Yi),Xi=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1f(this.location,t))},e}(Yi),Zi=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]||(this.current=t,this.gl.uniform2f(this.location,t[0],t[1]))},e}(Yi),Ji=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]||(this.current=t,this.gl.uniform3f(this.location,t[0],t[1],t[2]))},e}(Yi),Ki=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]&&t[3]===this.current[3]||(this.current=t,this.gl.uniform4f(this.location,t[0],t[1],t[2],t[3]))},e}(Yi),$i=function(t){function e(e,r){t.call(this,e,r),this.current=ne.transparent}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t.r===this.current.r&&t.g===this.current.g&&t.b===this.current.b&&t.a===this.current.a||(this.current=t,this.gl.uniform4f(this.location,t.r,t.g,t.b,t.a))},e}(Yi),Qi=new Float32Array(16),ta=function(t){function e(e,r){t.call(this,e,r),this.current=Qi}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(t[12]!==this.current[12]||t[0]!==this.current[0])return this.current=t,void this.gl.uniformMatrix4fv(this.location,!1,t);for(var e=1;e<16;e++)if(t[e]!==this.current[e]){this.current=t,this.gl.uniformMatrix4fv(this.location,!1,t);break}},e}(Yi);function ea(t){return[qi(255*t.r,255*t.g),qi(255*t.b,255*t.a)]}var ra=function(t,e,r){this.value=t,this.names=e,this.uniformNames=this.names.map(function(t){return\"u_\"+t}),this.type=r,this.maxValue=-1/0};ra.prototype.defines=function(){return this.names.map(function(t){return\"#define HAS_UNIFORM_u_\"+t})},ra.prototype.setConstantPatternPositions=function(){},ra.prototype.populatePaintArray=function(){},ra.prototype.updatePaintArray=function(){},ra.prototype.upload=function(){},ra.prototype.destroy=function(){},ra.prototype.setUniforms=function(t,e,r,n){e.set(n.constantOr(this.value))},ra.prototype.getBinding=function(t,e){return\"color\"===this.type?new $i(t,e):new Xi(t,e)},ra.serialize=function(t){var e=t.value,r=t.names,n=t.type;return{value:An(e),names:r,type:n}},ra.deserialize=function(t){var e=t.value,r=t.names,n=t.type;return new ra(Mn(e),r,n)};var na=function(t,e,r){this.value=t,this.names=e,this.uniformNames=this.names.map(function(t){return\"u_\"+t}),this.type=r,this.maxValue=-1/0,this.patternPositions={patternTo:null,patternFrom:null}};na.prototype.defines=function(){return this.names.map(function(t){return\"#define HAS_UNIFORM_u_\"+t})},na.prototype.populatePaintArray=function(){},na.prototype.updatePaintArray=function(){},na.prototype.upload=function(){},na.prototype.destroy=function(){},na.prototype.setConstantPatternPositions=function(t,e){this.patternPositions.patternTo=t.tlbr,this.patternPositions.patternFrom=e.tlbr},na.prototype.setUniforms=function(t,e,r,n,i){var a=this.patternPositions;\"u_pattern_to\"===i&&a.patternTo&&e.set(a.patternTo),\"u_pattern_from\"===i&&a.patternFrom&&e.set(a.patternFrom)},na.prototype.getBinding=function(t,e){return new Ki(t,e)};var ia=function(t,e,r,n){this.expression=t,this.names=e,this.type=r,this.uniformNames=this.names.map(function(t){return\"a_\"+t}),this.maxValue=-1/0,this.paintVertexAttributes=e.map(function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?2:1,offset:0}}),this.paintVertexArray=new n};ia.prototype.defines=function(){return[]},ia.prototype.setConstantPatternPositions=function(){},ia.prototype.populatePaintArray=function(t,e){var r=this.paintVertexArray,n=r.length;r.reserve(t);var i=this.expression.evaluate(new Un(0),e,{});if(\"color\"===this.type)for(var a=ea(i),o=n;o<t;o++)r.emplaceBack(a[0],a[1]);else{for(var s=n;s<t;s++)r.emplaceBack(i);this.maxValue=Math.max(this.maxValue,i)}},ia.prototype.updatePaintArray=function(t,e,r,n){var i=this.paintVertexArray,a=this.expression.evaluate({zoom:0},r,n);if(\"color\"===this.type)for(var o=ea(a),s=t;s<e;s++)i.emplace(s,o[0],o[1]);else{for(var l=t;l<e;l++)i.emplace(l,a);this.maxValue=Math.max(this.maxValue,a)}},ia.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},ia.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},ia.prototype.setUniforms=function(t,e){e.set(0)},ia.prototype.getBinding=function(t,e){return new Xi(t,e)};var aa=function(t,e,r,n,i,a){this.expression=t,this.names=e,this.uniformNames=this.names.map(function(t){return\"u_\"+t+\"_t\"}),this.type=r,this.useIntegerZoom=n,this.zoom=i,this.maxValue=-1/0;var o=a;this.paintVertexAttributes=e.map(function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?4:2,offset:0}}),this.paintVertexArray=new o};aa.prototype.defines=function(){return[]},aa.prototype.setConstantPatternPositions=function(){},aa.prototype.populatePaintArray=function(t,e){var r=this.paintVertexArray,n=r.length;r.reserve(t);var i=this.expression.evaluate(new Un(this.zoom),e,{}),a=this.expression.evaluate(new Un(this.zoom+1),e,{});if(\"color\"===this.type)for(var o=ea(i),s=ea(a),l=n;l<t;l++)r.emplaceBack(o[0],o[1],s[0],s[1]);else{for(var c=n;c<t;c++)r.emplaceBack(i,a);this.maxValue=Math.max(this.maxValue,i,a)}},aa.prototype.updatePaintArray=function(t,e,r,n){var i=this.paintVertexArray,a=this.expression.evaluate({zoom:this.zoom},r,n),o=this.expression.evaluate({zoom:this.zoom+1},r,n);if(\"color\"===this.type)for(var s=ea(a),l=ea(o),c=t;c<e;c++)i.emplace(c,s[0],s[1],l[0],l[1]);else{for(var u=t;u<e;u++)i.emplace(u,a,o);this.maxValue=Math.max(this.maxValue,a,o)}},aa.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},aa.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},aa.prototype.interpolationFactor=function(t){return this.useIntegerZoom?this.expression.interpolationFactor(Math.floor(t),this.zoom,this.zoom+1):this.expression.interpolationFactor(t,this.zoom,this.zoom+1)},aa.prototype.setUniforms=function(t,e,r){e.set(this.interpolationFactor(r.zoom))},aa.prototype.getBinding=function(t,e){return new Xi(t,e)};var oa=function(t,e,r,n,i,a,o){this.expression=t,this.names=e,this.type=r,this.uniformNames=this.names.map(function(t){return\"u_\"+t+\"_t\"}),this.useIntegerZoom=n,this.zoom=i,this.maxValue=-1/0,this.layerId=o,this.paintVertexAttributes=e.map(function(t){return{name:\"a_\"+t,type:\"Uint16\",components:4,offset:0}}),this.zoomInPaintVertexArray=new a,this.zoomOutPaintVertexArray=new a};oa.prototype.defines=function(){return[]},oa.prototype.setConstantPatternPositions=function(){},oa.prototype.populatePaintArray=function(t,e,r){var n=this.zoomInPaintVertexArray,i=this.zoomOutPaintVertexArray,a=this.layerId,o=n.length;if(n.reserve(t),i.reserve(t),r&&e.patterns&&e.patterns[a]){var s=e.patterns[a],l=s.min,c=s.mid,u=s.max,h=r[l],f=r[c],p=r[u];if(!h||!f||!p)return;for(var d=o;d<t;d++)n.emplaceBack(f.tl[0],f.tl[1],f.br[0],f.br[1],h.tl[0],h.tl[1],h.br[0],h.br[1]),i.emplaceBack(f.tl[0],f.tl[1],f.br[0],f.br[1],p.tl[0],p.tl[1],p.br[0],p.br[1])}},oa.prototype.updatePaintArray=function(t,e,r,n,i){var a=this.zoomInPaintVertexArray,o=this.zoomOutPaintVertexArray,s=this.layerId;if(i&&r.patterns&&r.patterns[s]){var l=r.patterns[s],c=l.min,u=l.mid,h=l.max,f=i[c],p=i[u],d=i[h];if(!f||!p||!d)return;for(var g=t;g<e;g++)a.emplace(g,p.tl[0],p.tl[1],p.br[0],p.br[1],f.tl[0],f.tl[1],f.br[0],f.br[1]),o.emplace(g,p.tl[0],p.tl[1],p.br[0],p.br[1],d.tl[0],d.tl[1],d.br[0],d.br[1])}},oa.prototype.upload=function(t){this.zoomInPaintVertexArray&&this.zoomInPaintVertexArray.arrayBuffer&&this.zoomOutPaintVertexArray&&this.zoomOutPaintVertexArray.arrayBuffer&&(this.zoomInPaintVertexBuffer=t.createVertexBuffer(this.zoomInPaintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent),this.zoomOutPaintVertexBuffer=t.createVertexBuffer(this.zoomOutPaintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},oa.prototype.destroy=function(){this.zoomOutPaintVertexBuffer&&this.zoomOutPaintVertexBuffer.destroy(),this.zoomInPaintVertexBuffer&&this.zoomInPaintVertexBuffer.destroy()},oa.prototype.setUniforms=function(t,e){e.set(0)},oa.prototype.getBinding=function(t,e){return new Xi(t,e)};var sa=function(){this.binders={},this.cacheKey=\"\",this._buffers=[],this._featureMap=new Hi,this._bufferOffset=0};sa.createDynamic=function(t,e,r){var n=new sa,i=[];for(var a in t.paint._values)if(r(a)){var o=t.paint.get(a);if(o instanceof Xn&&xr(o.property.specification)){var s=ca(a,t.type),l=o.property.specification.type,c=o.property.useIntegerZoom;if(\"cross-faded\"===o.property.specification[\"property-type\"]||\"cross-faded-data-driven\"===o.property.specification[\"property-type\"])if(\"constant\"===o.value.kind)n.binders[a]=new na(o.value.value,s,l),i.push(\"/u_\"+a);else{var u=ua(a,l,\"source\");n.binders[a]=new oa(o.value,s,l,c,e,u,t.id),i.push(\"/a_\"+a)}else if(\"constant\"===o.value.kind)n.binders[a]=new ra(o.value.value,s,l),i.push(\"/u_\"+a);else if(\"source\"===o.value.kind){var h=ua(a,l,\"source\");n.binders[a]=new ia(o.value,s,l,h),i.push(\"/a_\"+a)}else{var f=ua(a,l,\"composite\");n.binders[a]=new aa(o.value,s,l,c,e,f),i.push(\"/z_\"+a)}}}return n.cacheKey=i.sort().join(\"\"),n},sa.prototype.populatePaintArrays=function(t,e,r,n){for(var i in this.binders)this.binders[i].populatePaintArray(t,e,n);void 0!==e.id&&this._featureMap.add(+e.id,r,this._bufferOffset,t),this._bufferOffset=t},sa.prototype.setConstantPatternPositions=function(t,e){for(var r in this.binders)this.binders[r].setConstantPatternPositions(t,e)},sa.prototype.updatePaintArrays=function(t,e,r,n){var i=!1;for(var a in t)for(var o=0,s=this._featureMap.getPositions(+a);o<s.length;o+=1){var l=s[o],c=e.feature(l.index);for(var u in this.binders){var h=this.binders[u];if(!(h instanceof ra||h instanceof na)&&!0===h.expression.isStateDependent){var f=r.paint.get(u);h.expression=f.value,h.updatePaintArray(l.start,l.end,c,t[a],n),i=!0}}}return i},sa.prototype.defines=function(){var t=[];for(var e in this.binders)t.push.apply(t,this.binders[e].defines());return t},sa.prototype.getPaintVertexBuffers=function(){return this._buffers},sa.prototype.getUniforms=function(t,e){var r=[];for(var n in this.binders)for(var i=this.binders[n],a=0,o=i.uniformNames;a<o.length;a+=1){var s=o[a];if(e[s]){var l=i.getBinding(t,e[s]);r.push({name:s,property:n,binding:l})}}return r},sa.prototype.setUniforms=function(t,e,r,n){for(var i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.name,l=o.property,c=o.binding;this.binders[l].setUniforms(t,c,n,r.get(l),s)}},sa.prototype.updatePatternPaintBuffers=function(t){var e=[];for(var r in this.binders){var n=this.binders[r];if(n instanceof oa){var i=2===t.fromScale?n.zoomInPaintVertexBuffer:n.zoomOutPaintVertexBuffer;i&&e.push(i)}else(n instanceof ia||n instanceof aa)&&n.paintVertexBuffer&&e.push(n.paintVertexBuffer)}this._buffers=e},sa.prototype.upload=function(t){for(var e in this.binders)this.binders[e].upload(t);var r=[];for(var n in this.binders){var i=this.binders[n];(i instanceof ia||i instanceof aa)&&i.paintVertexBuffer&&r.push(i.paintVertexBuffer)}this._buffers=r},sa.prototype.destroy=function(){for(var t in this.binders)this.binders[t].destroy()};var la=function(t,e,r,n){void 0===n&&(n=function(){return!0}),this.programConfigurations={};for(var i=0,a=e;i<a.length;i+=1){var o=a[i];this.programConfigurations[o.id]=sa.createDynamic(o,r,n),this.programConfigurations[o.id].layoutAttributes=t}this.needsUpload=!1};function ca(t,e){return{\"text-opacity\":[\"opacity\"],\"icon-opacity\":[\"opacity\"],\"text-color\":[\"fill_color\"],\"icon-color\":[\"fill_color\"],\"text-halo-color\":[\"halo_color\"],\"icon-halo-color\":[\"halo_color\"],\"text-halo-blur\":[\"halo_blur\"],\"icon-halo-blur\":[\"halo_blur\"],\"text-halo-width\":[\"halo_width\"],\"icon-halo-width\":[\"halo_width\"],\"line-gap-width\":[\"gapwidth\"],\"line-pattern\":[\"pattern_to\",\"pattern_from\"],\"fill-pattern\":[\"pattern_to\",\"pattern_from\"],\"fill-extrusion-pattern\":[\"pattern_to\",\"pattern_from\"]}[t]||[t.replace(e+\"-\",\"\").replace(/-/g,\"_\")]}function ua(t,e,r){var n={color:{source:Si,composite:Ei},number:{source:_i,composite:Si}},i=function(t){return{\"line-pattern\":{source:fi,composite:fi},\"fill-pattern\":{source:fi,composite:fi},\"fill-extrusion-pattern\":{source:fi,composite:fi}}[t]}(t);return i&&i[r]||n[e][r]}la.prototype.populatePaintArrays=function(t,e,r,n){for(var i in this.programConfigurations)this.programConfigurations[i].populatePaintArrays(t,e,r,n);this.needsUpload=!0},la.prototype.updatePaintArrays=function(t,e,r,n){for(var i=0,a=r;i<a.length;i+=1){var o=a[i];this.needsUpload=this.programConfigurations[o.id].updatePaintArrays(t,e,o,n)||this.needsUpload}},la.prototype.get=function(t){return this.programConfigurations[t]},la.prototype.upload=function(t){if(this.needsUpload){for(var e in this.programConfigurations)this.programConfigurations[e].upload(t);this.needsUpload=!1}},la.prototype.destroy=function(){for(var t in this.programConfigurations)this.programConfigurations[t].destroy()},kn(\"ConstantBinder\",ra),kn(\"CrossFadedConstantBinder\",na),kn(\"SourceExpressionBinder\",ia),kn(\"CrossFadedCompositeBinder\",oa),kn(\"CompositeExpressionBinder\",aa),kn(\"ProgramConfiguration\",sa,{omit:[\"_buffers\"]}),kn(\"ProgramConfigurationSet\",la);var ha=8192,fa=(16,{min:-1*Math.pow(2,15),max:Math.pow(2,15)-1});function pa(t){for(var e=ha/t.extent,r=t.loadGeometry(),n=0;n<r.length;n++)for(var i=r[n],a=0;a<i.length;a++){var o=i[a];o.x=Math.round(o.x*e),o.y=Math.round(o.y*e),(o.x<fa.min||o.x>fa.max||o.y<fa.min||o.y>fa.max)&&w(\"Geometry exceeds allowed extent, reduce your vector tile buffer size\")}return r}function da(t,e,r,n,i){t.emplaceBack(2*e+(n+1)/2,2*r+(i+1)/2)}var ga=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new li,this.indexArray=new Ti,this.segments=new Vi,this.programConfigurations=new la(Ui,t.layers,t.zoom),this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function va(t,e){for(var r=0;r<t.length;r++)if(Aa(e,t[r]))return!0;for(var n=0;n<e.length;n++)if(Aa(t,e[n]))return!0;return!!ba(t,e)}function ma(t,e,r){return!!Aa(t,e)||!!wa(e,t,r)}function ya(t,e){if(1===t.length)return Ta(e,t[0]);for(var r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++)if(Aa(t,n[i]))return!0;for(var a=0;a<t.length;a++)if(Ta(e,t[a]))return!0;for(var o=0;o<e.length;o++)if(ba(t,e[o]))return!0;return!1}function xa(t,e,r){if(t.length>1){if(ba(t,e))return!0;for(var n=0;n<e.length;n++)if(wa(e[n],t,r))return!0}for(var i=0;i<t.length;i++)if(wa(t[i],e,r))return!0;return!1}function ba(t,e){if(0===t.length||0===e.length)return!1;for(var r=0;r<t.length-1;r++)for(var n=t[r],i=t[r+1],a=0;a<e.length-1;a++)if(_a(n,i,e[a],e[a+1]))return!0;return!1}function _a(t,e,r,n){return k(t,r,n)!==k(e,r,n)&&k(t,e,r)!==k(t,e,n)}function wa(t,e,r){var n=r*r;if(1===e.length)return t.distSqr(e[0])<n;for(var i=1;i<e.length;i++)if(ka(t,e[i-1],e[i])<n)return!0;return!1}function ka(t,e,r){var n=e.distSqr(r);if(0===n)return t.distSqr(e);var i=((t.x-e.x)*(r.x-e.x)+(t.y-e.y)*(r.y-e.y))/n;return i<0?t.distSqr(e):i>1?t.distSqr(r):t.distSqr(r.sub(e)._mult(i)._add(e))}function Ta(t,e){for(var r,n,i,a=!1,o=0;o<t.length;o++)for(var s=0,l=(r=t[o]).length-1;s<r.length;l=s++)n=r[s],i=r[l],n.y>e.y!=i.y>e.y&&e.x<(i.x-n.x)*(e.y-n.y)/(i.y-n.y)+n.x&&(a=!a);return a}function Aa(t,e){for(var r=!1,n=0,i=t.length-1;n<t.length;i=n++){var a=t[n],o=t[i];a.y>e.y!=o.y>e.y&&e.x<(o.x-a.x)*(e.y-a.y)/(o.y-a.y)+a.x&&(r=!r)}return r}function Ma(t,e,r){var n=r[0],i=r[2];if(t.x<n.x&&e.x<n.x||t.x>i.x&&e.x>i.x||t.y<n.y&&e.y<n.y||t.y>i.y&&e.y>i.y)return!1;var a=k(t,e,r[0]);return a!==k(t,e,r[1])||a!==k(t,e,r[2])||a!==k(t,e,r[3])}function Sa(t,e,r){var n=e.paint.get(t).value;return\"constant\"===n.kind?n.value:r.programConfigurations.get(e.id).binders[t].maxValue}function Ea(t){return Math.sqrt(t[0]*t[0]+t[1]*t[1])}function Ca(t,e,r,n,a){if(!e[0]&&!e[1])return t;var o=i.convert(e)._mult(a);\"viewport\"===r&&o._rotate(-n);for(var s=[],l=0;l<t.length;l++){var c=t[l];s.push(c.sub(o))}return s}ga.prototype.populate=function(t,e){for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a);this.addFeature(a,l,o),e.featureIndex.insert(a,l,o,s,this.index)}}},ga.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},ga.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},ga.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},ga.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ui),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},ga.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},ga.prototype.addFeature=function(t,e,r){for(var n=0,i=e;n<i.length;n+=1)for(var a=0,o=i[n];a<o.length;a+=1){var s=o[a],l=s.x,c=s.y;if(!(l<0||l>=ha||c<0||c>=ha)){var u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),h=u.vertexLength;da(this.layoutVertexArray,l,c,-1,-1),da(this.layoutVertexArray,l,c,1,-1),da(this.layoutVertexArray,l,c,1,1),da(this.layoutVertexArray,l,c,-1,1),this.indexArray.emplaceBack(h,h+1,h+2),this.indexArray.emplaceBack(h,h+3,h+2),u.vertexLength+=4,u.primitiveLength+=2}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,{})},kn(\"CircleBucket\",ga,{omit:[\"layers\"]});var La={paint:new ei({\"circle-radius\":new Kn(It.paint_circle[\"circle-radius\"]),\"circle-color\":new Kn(It.paint_circle[\"circle-color\"]),\"circle-blur\":new Kn(It.paint_circle[\"circle-blur\"]),\"circle-opacity\":new Kn(It.paint_circle[\"circle-opacity\"]),\"circle-translate\":new Jn(It.paint_circle[\"circle-translate\"]),\"circle-translate-anchor\":new Jn(It.paint_circle[\"circle-translate-anchor\"]),\"circle-pitch-scale\":new Jn(It.paint_circle[\"circle-pitch-scale\"]),\"circle-pitch-alignment\":new Jn(It.paint_circle[\"circle-pitch-alignment\"]),\"circle-stroke-width\":new Kn(It.paint_circle[\"circle-stroke-width\"]),\"circle-stroke-color\":new Kn(It.paint_circle[\"circle-stroke-color\"]),\"circle-stroke-opacity\":new Kn(It.paint_circle[\"circle-stroke-opacity\"])})},Pa=\"undefined\"!=typeof Float32Array?Float32Array:Array;function Oa(){var t=new Pa(9);return Pa!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[5]=0,t[6]=0,t[7]=0),t[0]=1,t[4]=1,t[8]=1,t}function za(){var t=new Pa(3);return Pa!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0),t}function Ia(t,e,r){var n=new Pa(3);return n[0]=t,n[1]=e,n[2]=r,n}Math.PI;function Da(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}function Ra(){var t=new Pa(4);return Pa!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0),t[3]=1,t}za(),function(){var t;t=new Pa(4),Pa!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0,t[3]=0)}();za(),Ia(1,0,0),Ia(0,1,0),Ra(),Ra(),Oa(),function(){var t;t=new Pa(2),Pa!=Float32Array&&(t[0]=0,t[1]=0)}();var Fa=function(t){function e(e){t.call(this,e,La)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new ga(t)},e.prototype.queryRadius=function(t){var e=t;return Sa(\"circle-radius\",this,e)+Sa(\"circle-stroke-width\",this,e)+Ea(this.paint.get(\"circle-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o,s){for(var l=Ca(t,this.paint.get(\"circle-translate\"),this.paint.get(\"circle-translate-anchor\"),a.angle,o),c=this.paint.get(\"circle-radius\").evaluate(e,r)+this.paint.get(\"circle-stroke-width\").evaluate(e,r),u=\"map\"===this.paint.get(\"circle-pitch-alignment\"),h=u?l:function(t,e){return l.map(function(t){return Ba(t,e)})}(0,s),f=u?c*o:c,p=0,d=n;p<d.length;p+=1)for(var g=0,v=d[p];g<v.length;g+=1){var m=v[g],y=u?m:Ba(m,s),x=f,b=Da([],[m.x,m.y,0,1],s);if(\"viewport\"===this.paint.get(\"circle-pitch-scale\")&&\"map\"===this.paint.get(\"circle-pitch-alignment\")?x*=b[3]/a.cameraToCenterDistance:\"map\"===this.paint.get(\"circle-pitch-scale\")&&\"viewport\"===this.paint.get(\"circle-pitch-alignment\")&&(x*=a.cameraToCenterDistance/b[3]),ma(h,y,x))return!0}return!1},e}(ri);function Ba(t,e){var r=Da([],[t.x,t.y,0,1],e);return new i(r[0]/r[3],r[1]/r[3])}var Na=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ga);function ja(t,e,r,n){var i=e.width,a=e.height;if(n){if(n instanceof Uint8ClampedArray)n=new Uint8Array(n.buffer);else if(n.length!==i*a*r)throw new RangeError(\"mismatched image size\")}else n=new Uint8Array(i*a*r);return t.width=i,t.height=a,t.data=n,t}function Ua(t,e,r){var n=e.width,i=e.height;if(n!==t.width||i!==t.height){var a=ja({},{width:n,height:i},r);Va(t,a,{x:0,y:0},{x:0,y:0},{width:Math.min(t.width,n),height:Math.min(t.height,i)},r),t.width=n,t.height=i,t.data=a.data}}function Va(t,e,r,n,i,a){if(0===i.width||0===i.height)return e;if(i.width>t.width||i.height>t.height||r.x>t.width-i.width||r.y>t.height-i.height)throw new RangeError(\"out of range source coordinates for image copy\");if(i.width>e.width||i.height>e.height||n.x>e.width-i.width||n.y>e.height-i.height)throw new RangeError(\"out of range destination coordinates for image copy\");for(var o=t.data,s=e.data,l=0;l<i.height;l++)for(var c=((r.y+l)*t.width+r.x)*a,u=((n.y+l)*e.width+n.x)*a,h=0;h<i.width*a;h++)s[u+h]=o[c+h];return e}kn(\"HeatmapBucket\",Na,{omit:[\"layers\"]});var qa=function(t,e){ja(this,t,1,e)};qa.prototype.resize=function(t){Ua(this,t,1)},qa.prototype.clone=function(){return new qa({width:this.width,height:this.height},new Uint8Array(this.data))},qa.copy=function(t,e,r,n,i){Va(t,e,r,n,i,1)};var Ha=function(t,e){ja(this,t,4,e)};Ha.prototype.resize=function(t){Ua(this,t,4)},Ha.prototype.replace=function(t,e){e?this.data.set(t):t instanceof Uint8ClampedArray?this.data=new Uint8Array(t.buffer):this.data=t},Ha.prototype.clone=function(){return new Ha({width:this.width,height:this.height},new Uint8Array(this.data))},Ha.copy=function(t,e,r,n,i){Va(t,e,r,n,i,4)},kn(\"AlphaImage\",qa),kn(\"RGBAImage\",Ha);var Ga={paint:new ei({\"heatmap-radius\":new Kn(It.paint_heatmap[\"heatmap-radius\"]),\"heatmap-weight\":new Kn(It.paint_heatmap[\"heatmap-weight\"]),\"heatmap-intensity\":new Jn(It.paint_heatmap[\"heatmap-intensity\"]),\"heatmap-color\":new ti(It.paint_heatmap[\"heatmap-color\"]),\"heatmap-opacity\":new Jn(It.paint_heatmap[\"heatmap-opacity\"])})};function Ya(t,e){for(var r=new Uint8Array(1024),n={},i=0,a=0;i<256;i++,a+=4){n[e]=i/255;var o=t.evaluate(n);r[a+0]=Math.floor(255*o.r/o.a),r[a+1]=Math.floor(255*o.g/o.a),r[a+2]=Math.floor(255*o.b/o.a),r[a+3]=Math.floor(255*o.a)}return new Ha({width:256,height:1},r)}var Wa=function(t){function e(e){t.call(this,e,Ga),this._updateColorRamp()}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new Na(t)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"heatmap-color\"===t&&this._updateColorRamp()},e.prototype._updateColorRamp=function(){var t=this._transitionablePaint._values[\"heatmap-color\"].value.expression;this.colorRamp=Ya(t,\"heatmapDensity\"),this.colorRampTexture=null},e.prototype.resize=function(){this.heatmapFbo&&(this.heatmapFbo.destroy(),this.heatmapFbo=null)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"heatmap-opacity\")&&\"none\"!==this.visibility},e}(ri),Xa={paint:new ei({\"hillshade-illumination-direction\":new Jn(It.paint_hillshade[\"hillshade-illumination-direction\"]),\"hillshade-illumination-anchor\":new Jn(It.paint_hillshade[\"hillshade-illumination-anchor\"]),\"hillshade-exaggeration\":new Jn(It.paint_hillshade[\"hillshade-exaggeration\"]),\"hillshade-shadow-color\":new Jn(It.paint_hillshade[\"hillshade-shadow-color\"]),\"hillshade-highlight-color\":new Jn(It.paint_hillshade[\"hillshade-highlight-color\"]),\"hillshade-accent-color\":new Jn(It.paint_hillshade[\"hillshade-accent-color\"])})},Za=function(t){function e(e){t.call(this,e,Xa)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"hillshade-exaggeration\")&&\"none\"!==this.visibility},e}(ri),Ja=oi([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,Ka=Qa,$a=Qa;function Qa(t,e,r){r=r||2;var n,i,a,o,s,l,c,u=e&&e.length,h=u?e[0]*r:t.length,f=to(t,0,h,r,!0),p=[];if(!f||f.next===f.prev)return p;if(u&&(f=function(t,e,r,n){var i,a,o,s=[];for(i=0,a=e.length;i<a;i++)(o=to(t,e[i]*n,i<a-1?e[i+1]*n:t.length,n,!1))===o.next&&(o.steiner=!0),s.push(uo(o));for(s.sort(so),i=0;i<s.length;i++)lo(s[i],r),r=eo(r,r.next);return r}(t,e,f,r)),t.length>80*r){n=a=t[0],i=o=t[1];for(var d=r;d<h;d+=r)(s=t[d])<n&&(n=s),(l=t[d+1])<i&&(i=l),s>a&&(a=s),l>o&&(o=l);c=0!==(c=Math.max(a-n,o-i))?1/c:0}return ro(f,p,r,n,i,c),p}function to(t,e,r,n,i){var a,o;if(i===wo(t,e,r,n)>0)for(a=e;a<r;a+=n)o=xo(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=xo(a,t[a],t[a+1],o);return o&&go(o,o.next)&&(bo(o),o=o.next),o}function eo(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!go(n,n.next)&&0!==po(n.prev,n,n.next))n=n.next;else{if(bo(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function ro(t,e,r,n,i,a,o){if(t){!o&&a&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=co(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,a);for(var s,l,c=t;t.prev!==t.next;)if(s=t.prev,l=t.next,a?io(t,n,i,a):no(t))e.push(s.i/r),e.push(t.i/r),e.push(l.i/r),bo(t),t=l.next,c=l.next;else if((t=l)===c){o?1===o?ro(t=ao(t,e,r),e,r,n,i,a,2):2===o&&oo(t,e,r,n,i,a):ro(eo(t),e,r,n,i,a,1);break}}}function no(t){var e=t.prev,r=t,n=t.next;if(po(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(ho(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&po(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function io(t,e,r,n){var i=t.prev,a=t,o=t.next;if(po(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,h=co(s,l,e,r,n),f=co(c,u,e,r,n),p=t.prevZ,d=t.nextZ;p&&p.z>=h&&d&&d.z<=f;){if(p!==t.prev&&p!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&po(p.prev,p,p.next)>=0)return!1;if(p=p.prevZ,d!==t.prev&&d!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&po(d.prev,d,d.next)>=0)return!1;d=d.nextZ}for(;p&&p.z>=h;){if(p!==t.prev&&p!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&po(p.prev,p,p.next)>=0)return!1;p=p.prevZ}for(;d&&d.z<=f;){if(d!==t.prev&&d!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&po(d.prev,d,d.next)>=0)return!1;d=d.nextZ}return!0}function ao(t,e,r){var n=t;do{var i=n.prev,a=n.next.next;!go(i,a)&&vo(i,n,n.next,a)&&mo(i,a)&&mo(a,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(a.i/r),bo(n),bo(n.next),n=t=a),n=n.next}while(n!==t);return n}function oo(t,e,r,n,i,a){var o=t;do{for(var s=o.next.next;s!==o.prev;){if(o.i!==s.i&&fo(o,s)){var l=yo(o,s);return o=eo(o,o.next),l=eo(l,l.next),ro(o,e,r,n,i,a),void ro(l,e,r,n,i,a)}s=s.next}o=o.next}while(o!==t)}function so(t,e){return t.x-e.x}function lo(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r.prev;var l,c=r,u=r.x,h=r.y,f=1/0;for(n=r.next;n!==c;)i>=n.x&&n.x>=u&&i!==n.x&&ho(a<h?i:o,a,u,h,a<h?o:i,a,n.x,n.y)&&((l=Math.abs(a-n.y)/(i-n.x))<f||l===f&&n.x>r.x)&&mo(n,t)&&(r=n,f=l),n=n.next;return r}(t,e)){var r=yo(e,t);eo(r,r.next)}}function co(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function uo(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function ho(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function fo(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&vo(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&mo(t,e)&&mo(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)}function po(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function go(t,e){return t.x===e.x&&t.y===e.y}function vo(t,e,r,n){return!!(go(t,e)&&go(r,n)||go(t,n)&&go(r,e))||po(t,e,r)>0!=po(t,e,n)>0&&po(r,n,t)>0!=po(r,n,e)>0}function mo(t,e){return po(t.prev,t,t.next)<0?po(t,e,t.next)>=0&&po(t,t.prev,e)>=0:po(t,e,t.prev)<0||po(t,t.next,e)<0}function yo(t,e){var r=new _o(t.i,t.x,t.y),n=new _o(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function xo(t,e,r,n){var i=new _o(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function bo(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function _o(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function wo(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}function ko(t,e,r,n,i){!function t(e,r,n,i,a){for(;i>n;){if(i-n>600){var o=i-n+1,s=r-n+1,l=Math.log(o),c=.5*Math.exp(2*l/3),u=.5*Math.sqrt(l*c*(o-c)/o)*(s-o/2<0?-1:1);t(e,r,Math.max(n,Math.floor(r-s*c/o+u)),Math.min(i,Math.floor(r+(o-s)*c/o+u)),a)}var h=e[r],f=n,p=i;for(To(e,n,r),a(e[i],h)>0&&To(e,n,i);f<p;){for(To(e,f,p),f++,p--;a(e[f],h)<0;)f++;for(;a(e[p],h)>0;)p--}0===a(e[n],h)?To(e,n,p):To(e,++p,i),p<=r&&(n=p+1),r<=p&&(i=p-1)}}(t,e,r||0,n||t.length-1,i||Ao)}function To(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function Ao(t,e){return t<e?-1:t>e?1:0}function Mo(t,e){var r=t.length;if(r<=1)return[t];for(var n,i,a=[],o=0;o<r;o++){var s=T(t[o]);0!==s&&(t[o].area=Math.abs(s),void 0===i&&(i=s<0),i===s<0?(n&&a.push(n),n=[t[o]]):n.push(t[o]))}if(n&&a.push(n),e>1)for(var l=0;l<a.length;l++)a[l].length<=e||(ko(a[l],e,1,a[l].length-1,So),a[l]=a[l].slice(0,e));return a}function So(t,e){return e.area-t.area}function Eo(t,e,r){for(var n=r.patternDependencies,i=!1,a=0,o=e;a<o.length;a+=1){var s=o[a].paint.get(t+\"-pattern\");s.isConstant()||(i=!0);var l=s.constantOr(null);l&&(i=!0,n[l.to]=!0,n[l.from]=!0)}return i}function Co(t,e,r,n,i){for(var a=i.patternDependencies,o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.paint.get(t+\"-pattern\").value;if(\"constant\"!==c.kind){var u=c.evaluate({zoom:n-1},r,{}),h=c.evaluate({zoom:n},r,{}),f=c.evaluate({zoom:n+1},r,{});a[u]=!0,a[h]=!0,a[f]=!0,r.patterns[l.id]={min:u,mid:h,max:f}}}return r}Qa.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(wo(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(wo(t,c,u,r))}var h=0;for(s=0;s<n.length;s+=3){var f=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;h+=Math.abs((t[f]-t[d])*(t[p+1]-t[f+1])-(t[f]-t[p])*(t[d+1]-t[f+1]))}return 0===o&&0===h?0:Math.abs((h-o)/o)},Qa.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r},Ka.default=$a;var Lo=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new li,this.indexArray=new Ti,this.indexArray2=new Ai,this.programConfigurations=new la(Ja,t.layers,t.zoom),this.segments=new Vi,this.segments2=new Vi,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};Lo.prototype.populate=function(t,e){this.features=[],this.hasPattern=Eo(\"fill\",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a),c={sourceLayerIndex:s,index:o,geometry:l,properties:a.properties,type:a.type,patterns:{}};void 0!==a.id&&(c.id=a.id),this.hasPattern?this.features.push(Co(\"fill\",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(a,l,o,s,this.index)}}},Lo.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Lo.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var i=n[r],a=i.geometry;this.addFeature(i,a,i.index,e)}},Lo.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Lo.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Lo.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ja),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.indexBuffer2=t.createIndexBuffer(this.indexArray2)),this.programConfigurations.upload(t),this.uploaded=!0},Lo.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.indexBuffer2.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.segments2.destroy())},Lo.prototype.addFeature=function(t,e,r,n){for(var i=0,a=Mo(e,500);i<a.length;i+=1){for(var o=a[i],s=0,l=0,c=o;l<c.length;l+=1)s+=c[l].length;for(var u=this.segments.prepareSegment(s,this.layoutVertexArray,this.indexArray),h=u.vertexLength,f=[],p=[],d=0,g=o;d<g.length;d+=1){var v=g[d];if(0!==v.length){v!==o[0]&&p.push(f.length/2);var m=this.segments2.prepareSegment(v.length,this.layoutVertexArray,this.indexArray2),y=m.vertexLength;this.layoutVertexArray.emplaceBack(v[0].x,v[0].y),this.indexArray2.emplaceBack(y+v.length-1,y),f.push(v[0].x),f.push(v[0].y);for(var x=1;x<v.length;x++)this.layoutVertexArray.emplaceBack(v[x].x,v[x].y),this.indexArray2.emplaceBack(y+x-1,y+x),f.push(v[x].x),f.push(v[x].y);m.vertexLength+=v.length,m.primitiveLength+=v.length}}for(var b=Ka(f,p),_=0;_<b.length;_+=3)this.indexArray.emplaceBack(h+b[_],h+b[_+1],h+b[_+2]);u.vertexLength+=s,u.primitiveLength+=b.length/3}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,n)},kn(\"FillBucket\",Lo,{omit:[\"layers\",\"features\"]});var Po={paint:new ei({\"fill-antialias\":new Jn(It.paint_fill[\"fill-antialias\"]),\"fill-opacity\":new Kn(It.paint_fill[\"fill-opacity\"]),\"fill-color\":new Kn(It.paint_fill[\"fill-color\"]),\"fill-outline-color\":new Kn(It.paint_fill[\"fill-outline-color\"]),\"fill-translate\":new Jn(It.paint_fill[\"fill-translate\"]),\"fill-translate-anchor\":new Jn(It.paint_fill[\"fill-translate-anchor\"]),\"fill-pattern\":new $n(It.paint_fill[\"fill-pattern\"])})},Oo=function(t){function e(e){t.call(this,e,Po)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e);var r=this.paint._values[\"fill-outline-color\"];\"constant\"===r.value.kind&&void 0===r.value.value&&(this.paint._values[\"fill-outline-color\"]=this.paint._values[\"fill-color\"])},e.prototype.createBucket=function(t){return new Lo(t)},e.prototype.queryRadius=function(){return Ea(this.paint.get(\"fill-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o){return ya(Ca(t,this.paint.get(\"fill-translate\"),this.paint.get(\"fill-translate-anchor\"),a.angle,o),n)},e.prototype.isTileClipped=function(){return!0},e}(ri),zo=oi([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_normal_ed\",components:4,type:\"Int16\"}],4).members,Io=Do;function Do(t,e,r,n,i){this.properties={},this.extent=r,this.type=0,this._pbf=t,this._geometry=-1,this._keys=n,this._values=i,t.readFields(Ro,this,e)}function Ro(t,e,r){1==t?e.id=r.readVarint():2==t?function(t,e){for(var r=t.readVarint()+t.pos;t.pos<r;){var n=e._keys[t.readVarint()],i=e._values[t.readVarint()];e.properties[n]=i}}(r,e):3==t?e.type=r.readVarint():4==t&&(e._geometry=r.pos)}function Fo(t){for(var e,r,n=0,i=0,a=t.length,o=a-1;i<a;o=i++)e=t[i],n+=((r=t[o]).x-e.x)*(e.y+r.y);return n}Do.types=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],Do.prototype.loadGeometry=function(){var t=this._pbf;t.pos=this._geometry;for(var e,r=t.readVarint()+t.pos,n=1,a=0,o=0,s=0,l=[];t.pos<r;){if(a<=0){var c=t.readVarint();n=7&c,a=c>>3}if(a--,1===n||2===n)o+=t.readSVarint(),s+=t.readSVarint(),1===n&&(e&&l.push(e),e=[]),e.push(new i(o,s));else{if(7!==n)throw new Error(\"unknown command \"+n);e&&e.push(e[0].clone())}}return e&&l.push(e),l},Do.prototype.bbox=function(){var t=this._pbf;t.pos=this._geometry;for(var e=t.readVarint()+t.pos,r=1,n=0,i=0,a=0,o=1/0,s=-1/0,l=1/0,c=-1/0;t.pos<e;){if(n<=0){var u=t.readVarint();r=7&u,n=u>>3}if(n--,1===r||2===r)(i+=t.readSVarint())<o&&(o=i),i>s&&(s=i),(a+=t.readSVarint())<l&&(l=a),a>c&&(c=a);else if(7!==r)throw new Error(\"unknown command \"+r)}return[o,l,s,c]},Do.prototype.toGeoJSON=function(t,e,r){var n,i,a=this.extent*Math.pow(2,r),o=this.extent*t,s=this.extent*e,l=this.loadGeometry(),c=Do.types[this.type];function u(t){for(var e=0;e<t.length;e++){var r=t[e],n=180-360*(r.y+s)/a;t[e]=[360*(r.x+o)/a-180,360/Math.PI*Math.atan(Math.exp(n*Math.PI/180))-90]}}switch(this.type){case 1:var h=[];for(n=0;n<l.length;n++)h[n]=l[n][0];u(l=h);break;case 2:for(n=0;n<l.length;n++)u(l[n]);break;case 3:for(l=function(t){var e=t.length;if(e<=1)return[t];for(var r,n,i=[],a=0;a<e;a++){var o=Fo(t[a]);0!==o&&(void 0===n&&(n=o<0),n===o<0?(r&&i.push(r),r=[t[a]]):r.push(t[a]))}return r&&i.push(r),i}(l),n=0;n<l.length;n++)for(i=0;i<l[n].length;i++)u(l[n][i])}1===l.length?l=l[0]:c=\"Multi\"+c;var f={type:\"Feature\",geometry:{type:c,coordinates:l},properties:this.properties};return\"id\"in this&&(f.id=this.id),f};var Bo=No;function No(t,e){this.version=1,this.name=null,this.extent=4096,this.length=0,this._pbf=t,this._keys=[],this._values=[],this._features=[],t.readFields(jo,this,e),this.length=this._features.length}function jo(t,e,r){15===t?e.version=r.readVarint():1===t?e.name=r.readString():5===t?e.extent=r.readVarint():2===t?e._features.push(r.pos):3===t?e._keys.push(r.readString()):4===t&&e._values.push(function(t){for(var e=null,r=t.readVarint()+t.pos;t.pos<r;){var n=t.readVarint()>>3;e=1===n?t.readString():2===n?t.readFloat():3===n?t.readDouble():4===n?t.readVarint64():5===n?t.readVarint():6===n?t.readSVarint():7===n?t.readBoolean():null}return e}(r))}function Uo(t,e,r){if(3===t){var n=new Bo(r,r.readVarint()+r.pos);n.length&&(e[n.name]=n)}}No.prototype.feature=function(t){if(t<0||t>=this._features.length)throw new Error(\"feature index out of bounds\");this._pbf.pos=this._features[t];var e=this._pbf.readVarint()+this._pbf.pos;return new Io(this._pbf,e,this.extent,this._keys,this._values)};var Vo={VectorTile:function(t,e){this.layers=t.readFields(Uo,{},e)},VectorTileFeature:Io,VectorTileLayer:Bo},qo=Vo.VectorTileFeature.types,Ho=Math.pow(2,13);function Go(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,2*Math.floor(n*Ho)+o,i*Ho*2,a*Ho*2,Math.round(s))}var Yo=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new ui,this.indexArray=new Ti,this.programConfigurations=new la(zo,t.layers,t.zoom),this.segments=new Vi,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function Wo(t,e){return t.x===e.x&&(t.x<0||t.x>ha)||t.y===e.y&&(t.y<0||t.y>ha)}function Xo(t){return t.every(function(t){return t.x<0})||t.every(function(t){return t.x>ha})||t.every(function(t){return t.y<0})||t.every(function(t){return t.y>ha})}Yo.prototype.populate=function(t,e){this.features=[],this.hasPattern=Eo(\"fill-extrusion\",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a),c={sourceLayerIndex:s,index:o,geometry:l,properties:a.properties,type:a.type,patterns:{}};void 0!==a.id&&(c.id=a.id),this.hasPattern?this.features.push(Co(\"fill-extrusion\",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(a,l,o,s,this.index,!0)}}},Yo.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var i=n[r],a=i.geometry;this.addFeature(i,a,i.index,e)}},Yo.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Yo.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Yo.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Yo.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,zo),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Yo.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Yo.prototype.addFeature=function(t,e,r,n){for(var i=0,a=Mo(e,500);i<a.length;i+=1){for(var o=a[i],s=0,l=0,c=o;l<c.length;l+=1)s+=c[l].length;for(var u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),h=0,f=o;h<f.length;h+=1){var p=f[h];if(0!==p.length&&!Xo(p))for(var d=0,g=0;g<p.length;g++){var v=p[g];if(g>=1){var m=p[g-1];if(!Wo(v,m)){u.vertexLength+4>Vi.MAX_VERTEX_ARRAY_LENGTH&&(u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray));var y=v.sub(m)._perp()._unit(),x=m.dist(v);d+x>32768&&(d=0),Go(this.layoutVertexArray,v.x,v.y,y.x,y.y,0,0,d),Go(this.layoutVertexArray,v.x,v.y,y.x,y.y,0,1,d),d+=x,Go(this.layoutVertexArray,m.x,m.y,y.x,y.y,0,0,d),Go(this.layoutVertexArray,m.x,m.y,y.x,y.y,0,1,d);var b=u.vertexLength;this.indexArray.emplaceBack(b,b+2,b+1),this.indexArray.emplaceBack(b+1,b+2,b+3),u.vertexLength+=4,u.primitiveLength+=2}}}}if(u.vertexLength+s>Vi.MAX_VERTEX_ARRAY_LENGTH&&(u=this.segments.prepareSegment(s,this.layoutVertexArray,this.indexArray)),\"Polygon\"===qo[t.type]){for(var _=[],w=[],k=u.vertexLength,T=0,A=o;T<A.length;T+=1){var M=A[T];if(0!==M.length){M!==o[0]&&w.push(_.length/2);for(var S=0;S<M.length;S++){var E=M[S];Go(this.layoutVertexArray,E.x,E.y,0,0,1,1,0),_.push(E.x),_.push(E.y)}}}for(var C=Ka(_,w),L=0;L<C.length;L+=3)this.indexArray.emplaceBack(k+C[L],k+C[L+2],k+C[L+1]);u.primitiveLength+=C.length/3,u.vertexLength+=s}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,n)},kn(\"FillExtrusionBucket\",Yo,{omit:[\"layers\",\"features\"]});var Zo={paint:new ei({\"fill-extrusion-opacity\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-opacity\"]),\"fill-extrusion-color\":new Kn(It[\"paint_fill-extrusion\"][\"fill-extrusion-color\"]),\"fill-extrusion-translate\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-translate\"]),\"fill-extrusion-translate-anchor\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-translate-anchor\"]),\"fill-extrusion-pattern\":new $n(It[\"paint_fill-extrusion\"][\"fill-extrusion-pattern\"]),\"fill-extrusion-height\":new Kn(It[\"paint_fill-extrusion\"][\"fill-extrusion-height\"]),\"fill-extrusion-base\":new Kn(It[\"paint_fill-extrusion\"][\"fill-extrusion-base\"]),\"fill-extrusion-vertical-gradient\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-vertical-gradient\"])})},Jo=function(t){function e(e){t.call(this,e,Zo)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new Yo(t)},e.prototype.queryRadius=function(){return Ea(this.paint.get(\"fill-extrusion-translate\"))},e.prototype.is3D=function(){return!0},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s,l){var c=Ca(t,this.paint.get(\"fill-extrusion-translate\"),this.paint.get(\"fill-extrusion-translate-anchor\"),o.angle,s),u=this.paint.get(\"fill-extrusion-height\").evaluate(e,r),h=this.paint.get(\"fill-extrusion-base\").evaluate(e,r),f=function(t,e,r,n){for(var a=[],o=0,s=t;o<s.length;o+=1){var l=s[o],c=[l.x,l.y,0,1];Da(c,c,e),a.push(new i(c[0]/c[3],c[1]/c[3]))}return a}(c,l),p=function(t,e,r,n){for(var a=[],o=[],s=n[8]*e,l=n[9]*e,c=n[10]*e,u=n[11]*e,h=n[8]*r,f=n[9]*r,p=n[10]*r,d=n[11]*r,g=0,v=t;g<v.length;g+=1){for(var m=[],y=[],x=0,b=v[g];x<b.length;x+=1){var _=b[x],w=_.x,k=_.y,T=n[0]*w+n[4]*k+n[12],A=n[1]*w+n[5]*k+n[13],M=n[2]*w+n[6]*k+n[14],S=n[3]*w+n[7]*k+n[15],E=M+c,C=S+u,L=T+h,P=A+f,O=M+p,z=S+d,I=new i((T+s)/C,(A+l)/C);I.z=E/C,m.push(I);var D=new i(L/z,P/z);D.z=O/z,y.push(D)}a.push(m),o.push(y)}return[a,o]}(n,h,u,l);return function(t,e,r){var n=1/0;ya(r,e)&&(n=$o(r,e[0]));for(var i=0;i<e.length;i++)for(var a=e[i],o=t[i],s=0;s<a.length-1;s++){var l=a[s],c=a[s+1],u=o[s],h=[l,c,o[s+1],u,l];va(r,h)&&(n=Math.min(n,$o(r,h)))}return n!==1/0&&n}(p[0],p[1],f)},e}(ri);function Ko(t,e){return t.x*e.x+t.y*e.y}function $o(t,e){if(1===t.length){var r=e[0],n=e[1],i=e[3],a=t[0],o=n.sub(r),s=i.sub(r),l=a.sub(r),c=Ko(o,o),u=Ko(o,s),h=Ko(s,s),f=Ko(l,o),p=Ko(l,s),d=c*h-u*u,g=(h*f-u*p)/d,v=(c*p-u*f)/d,m=1-g-v;return r.z*m+n.z*g+i.z*v}for(var y=1/0,x=0,b=e;x<b.length;x+=1){var _=b[x];y=Math.min(y,_.z)}return y}var Qo=oi([{name:\"a_pos_normal\",components:2,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint8\"}],4).members,ts=Vo.VectorTileFeature.types,es=63,rs=Math.cos(Math.PI/180*37.5),ns=.5,is=Math.pow(2,14)/ns;function as(t,e,r,n,i,a,o){t.emplaceBack((e.x<<1)+(n?1:0),(e.y<<1)+(i?1:0),Math.round(es*r.x)+128,Math.round(es*r.y)+128,1+(0===a?0:a<0?-1:1)|(o*ns&63)<<2,o*ns>>6)}var os=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.features=[],this.hasPattern=!1,this.layoutVertexArray=new hi,this.indexArray=new Ti,this.programConfigurations=new la(Qo,t.layers,t.zoom),this.segments=new Vi,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function ss(t,e){return(t/e.tileTotal*(e.end-e.start)+e.start)*(is-1)}os.prototype.populate=function(t,e){this.features=[],this.hasPattern=Eo(\"line\",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a),c={sourceLayerIndex:s,index:o,geometry:l,properties:a.properties,type:a.type,patterns:{}};void 0!==a.id&&(c.id=a.id),this.hasPattern?this.features.push(Co(\"line\",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(a,l,o,s,this.index)}}},os.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},os.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var i=n[r],a=i.geometry;this.addFeature(i,a,i.index,e)}},os.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},os.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},os.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Qo),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},os.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},os.prototype.addFeature=function(t,e,r,n){for(var i=this.layers[0].layout,a=i.get(\"line-join\").evaluate(t,{}),o=i.get(\"line-cap\"),s=i.get(\"line-miter-limit\"),l=i.get(\"line-round-limit\"),c=0,u=e;c<u.length;c+=1){var h=u[c];this.addLine(h,t,a,o,s,l,r,n)}},os.prototype.addLine=function(t,e,r,n,i,a,o,s){var l=null;e.properties&&e.properties.hasOwnProperty(\"mapbox_clip_start\")&&e.properties.hasOwnProperty(\"mapbox_clip_end\")&&(l={start:e.properties.mapbox_clip_start,end:e.properties.mapbox_clip_end,tileTotal:void 0});for(var c=\"Polygon\"===ts[e.type],u=t.length;u>=2&&t[u-1].equals(t[u-2]);)u--;for(var h=0;h<u-1&&t[h].equals(t[h+1]);)h++;if(!(u<(c?3:2))){l&&(l.tileTotal=function(t,e,r){for(var n,i,a=0,o=h;o<r-1;o++)n=t[o],i=t[o+1],a+=n.dist(i);return a}(t,0,u)),\"bevel\"===r&&(i=1.05);var f=ha/(512*this.overscaling)*15,p=t[h],d=this.segments.prepareSegment(10*u,this.layoutVertexArray,this.indexArray);this.distance=0;var g,v,m,y=n,x=c?\"butt\":n,b=!0,_=void 0,w=void 0,k=void 0,T=void 0;this.e1=this.e2=this.e3=-1,c&&(g=t[u-2],T=p.sub(g)._unit()._perp());for(var A=h;A<u;A++)if(!(w=c&&A===u-1?t[h+1]:t[A+1])||!t[A].equals(w)){T&&(k=T),g&&(_=g),g=t[A],T=w?w.sub(g)._unit()._perp():k;var M=(k=k||T).add(T);0===M.x&&0===M.y||M._unit();var S=M.x*T.x+M.y*T.y,E=0!==S?1/S:1/0,C=S<rs&&_&&w;if(C&&A>h){var L=g.dist(_);if(L>2*f){var P=g.sub(g.sub(_)._mult(f/L)._round());this.distance+=P.dist(_),this.addCurrentVertex(P,this.distance,k.mult(1),0,0,!1,d,l),_=P}}var O=_&&w,z=O?r:w?y:x;if(O&&\"round\"===z&&(E<a?z=\"miter\":E<=2&&(z=\"fakeround\")),\"miter\"===z&&E>i&&(z=\"bevel\"),\"bevel\"===z&&(E>2&&(z=\"flipbevel\"),E<i&&(z=\"miter\")),_&&(this.distance+=g.dist(_)),\"miter\"===z)M._mult(E),this.addCurrentVertex(g,this.distance,M,0,0,!1,d,l);else if(\"flipbevel\"===z){if(E>100)M=T.clone().mult(-1);else{var I=k.x*T.y-k.y*T.x>0?-1:1,D=E*k.add(T).mag()/k.sub(T).mag();M._perp()._mult(D*I)}this.addCurrentVertex(g,this.distance,M,0,0,!1,d,l),this.addCurrentVertex(g,this.distance,M.mult(-1),0,0,!1,d,l)}else if(\"bevel\"===z||\"fakeround\"===z){var R=k.x*T.y-k.y*T.x>0,F=-Math.sqrt(E*E-1);if(R?(m=0,v=F):(v=0,m=F),b||this.addCurrentVertex(g,this.distance,k,v,m,!1,d,l),\"fakeround\"===z){for(var B=Math.floor(8*(.5-(S-.5))),N=void 0,j=0;j<B;j++)N=T.mult((j+1)/(B+1))._add(k)._unit(),this.addPieSliceVertex(g,this.distance,N,R,d,l);this.addPieSliceVertex(g,this.distance,M,R,d,l);for(var U=B-1;U>=0;U--)N=k.mult((U+1)/(B+1))._add(T)._unit(),this.addPieSliceVertex(g,this.distance,N,R,d,l)}w&&this.addCurrentVertex(g,this.distance,T,-v,-m,!1,d,l)}else\"butt\"===z?(b||this.addCurrentVertex(g,this.distance,k,0,0,!1,d,l),w&&this.addCurrentVertex(g,this.distance,T,0,0,!1,d,l)):\"square\"===z?(b||(this.addCurrentVertex(g,this.distance,k,1,1,!1,d,l),this.e1=this.e2=-1),w&&this.addCurrentVertex(g,this.distance,T,-1,-1,!1,d,l)):\"round\"===z&&(b||(this.addCurrentVertex(g,this.distance,k,0,0,!1,d,l),this.addCurrentVertex(g,this.distance,k,1,1,!0,d,l),this.e1=this.e2=-1),w&&(this.addCurrentVertex(g,this.distance,T,-1,-1,!0,d,l),this.addCurrentVertex(g,this.distance,T,0,0,!1,d,l)));if(C&&A<u-1){var V=g.dist(w);if(V>2*f){var q=g.add(w.sub(g)._mult(f/V)._round());this.distance+=q.dist(g),this.addCurrentVertex(q,this.distance,T.mult(1),0,0,!1,d,l),g=q}}b=!1}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,e,o,s)}},os.prototype.addCurrentVertex=function(t,e,r,n,i,a,o,s){var l,c=this.layoutVertexArray,u=this.indexArray;s&&(e=ss(e,s)),l=r.clone(),n&&l._sub(r.perp()._mult(n)),as(c,t,l,a,!1,n,e),this.e3=o.vertexLength++,this.e1>=0&&this.e2>=0&&(u.emplaceBack(this.e1,this.e2,this.e3),o.primitiveLength++),this.e1=this.e2,this.e2=this.e3,l=r.mult(-1),i&&l._sub(r.perp()._mult(i)),as(c,t,l,a,!0,-i,e),this.e3=o.vertexLength++,this.e1>=0&&this.e2>=0&&(u.emplaceBack(this.e1,this.e2,this.e3),o.primitiveLength++),this.e1=this.e2,this.e2=this.e3,e>is/2&&!s&&(this.distance=0,this.addCurrentVertex(t,this.distance,r,n,i,a,o))},os.prototype.addPieSliceVertex=function(t,e,r,n,i,a){r=r.mult(n?-1:1);var o=this.layoutVertexArray,s=this.indexArray;a&&(e=ss(e,a)),as(o,t,r,!1,n,0,e),this.e3=i.vertexLength++,this.e1>=0&&this.e2>=0&&(s.emplaceBack(this.e1,this.e2,this.e3),i.primitiveLength++),n?this.e2=this.e3:this.e1=this.e3},kn(\"LineBucket\",os,{omit:[\"layers\",\"features\"]});var ls=new ei({\"line-cap\":new Jn(It.layout_line[\"line-cap\"]),\"line-join\":new Kn(It.layout_line[\"line-join\"]),\"line-miter-limit\":new Jn(It.layout_line[\"line-miter-limit\"]),\"line-round-limit\":new Jn(It.layout_line[\"line-round-limit\"])}),cs={paint:new ei({\"line-opacity\":new Kn(It.paint_line[\"line-opacity\"]),\"line-color\":new Kn(It.paint_line[\"line-color\"]),\"line-translate\":new Jn(It.paint_line[\"line-translate\"]),\"line-translate-anchor\":new Jn(It.paint_line[\"line-translate-anchor\"]),\"line-width\":new Kn(It.paint_line[\"line-width\"]),\"line-gap-width\":new Kn(It.paint_line[\"line-gap-width\"]),\"line-offset\":new Kn(It.paint_line[\"line-offset\"]),\"line-blur\":new Kn(It.paint_line[\"line-blur\"]),\"line-dasharray\":new Qn(It.paint_line[\"line-dasharray\"]),\"line-pattern\":new $n(It.paint_line[\"line-pattern\"]),\"line-gradient\":new ti(It.paint_line[\"line-gradient\"])}),layout:ls},us=new(function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(e,r){return r=new Un(Math.floor(r.zoom),{now:r.now,fadeDuration:r.fadeDuration,zoomHistory:r.zoomHistory,transition:r.transition}),t.prototype.possiblyEvaluate.call(this,e,r)},e.prototype.evaluate=function(e,r,n,i){return r=h({},r,{zoom:Math.floor(r.zoom)}),t.prototype.evaluate.call(this,e,r,n,i)},e}(Kn))(cs.paint.properties[\"line-width\"].specification);us.useIntegerZoom=!0;var hs=function(t){function e(e){t.call(this,e,cs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"line-gradient\"===t&&this._updateGradient()},e.prototype._updateGradient=function(){var t=this._transitionablePaint._values[\"line-gradient\"].value.expression;this.gradient=Ya(t,\"lineProgress\"),this.gradientTexture=null},e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e),this.paint._values[\"line-floorwidth\"]=us.possiblyEvaluate(this._transitioningPaint._values[\"line-width\"].value,e)},e.prototype.createBucket=function(t){return new os(t)},e.prototype.queryRadius=function(t){var e=t,r=fs(Sa(\"line-width\",this,e),Sa(\"line-gap-width\",this,e)),n=Sa(\"line-offset\",this,e);return r/2+Math.abs(n)+Ea(this.paint.get(\"line-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s){var l=Ca(t,this.paint.get(\"line-translate\"),this.paint.get(\"line-translate-anchor\"),o.angle,s),c=s/2*fs(this.paint.get(\"line-width\").evaluate(e,r),this.paint.get(\"line-gap-width\").evaluate(e,r)),u=this.paint.get(\"line-offset\").evaluate(e,r);return u&&(n=function(t,e){for(var r=[],n=new i(0,0),a=0;a<t.length;a++){for(var o=t[a],s=[],l=0;l<o.length;l++){var c=o[l-1],u=o[l],h=o[l+1],f=0===l?n:u.sub(c)._unit()._perp(),p=l===o.length-1?n:h.sub(u)._unit()._perp(),d=f._add(p)._unit(),g=d.x*p.x+d.y*p.y;d._mult(1/g),s.push(d._mult(e)._add(u))}r.push(s)}return r}(n,u*s)),function(t,e,r){for(var n=0;n<e.length;n++){var i=e[n];if(t.length>=3)for(var a=0;a<i.length;a++)if(Aa(t,i[a]))return!0;if(xa(t,i,r))return!0}return!1}(l,n,c)},e.prototype.isTileClipped=function(){return!0},e}(ri);function fs(t,e){return e>0?e+2*t:t}var ps=oi([{name:\"a_pos_offset\",components:4,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint16\"}]),ds=oi([{name:\"a_projected_pos\",components:3,type:\"Float32\"}],4),gs=(oi([{name:\"a_fade_opacity\",components:1,type:\"Uint32\"}],4),oi([{name:\"a_placed\",components:2,type:\"Uint8\"},{name:\"a_shift\",components:2,type:\"Float32\"}])),vs=(oi([{type:\"Int16\",name:\"anchorPointX\"},{type:\"Int16\",name:\"anchorPointY\"},{type:\"Int16\",name:\"x1\"},{type:\"Int16\",name:\"y1\"},{type:\"Int16\",name:\"x2\"},{type:\"Int16\",name:\"y2\"},{type:\"Uint32\",name:\"featureIndex\"},{type:\"Uint16\",name:\"sourceLayerIndex\"},{type:\"Uint16\",name:\"bucketIndex\"},{type:\"Int16\",name:\"radius\"},{type:\"Int16\",name:\"signedDistanceFromAnchor\"}]),oi([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4)),ms=oi([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4);function ys(t,e,r){return t.sections.forEach(function(t){t.text=function(t,e,r){var n=e.layout.get(\"text-transform\").evaluate(r,{});return\"uppercase\"===n?t=t.toLocaleUpperCase():\"lowercase\"===n&&(t=t.toLocaleLowerCase()),jn.applyArabicShaping&&(t=jn.applyArabicShaping(t)),t}(t.text,e,r)}),t}oi([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Uint16\",name:\"glyphStartIndex\"},{type:\"Uint16\",name:\"numGlyphs\"},{type:\"Uint32\",name:\"vertexStartIndex\"},{type:\"Uint32\",name:\"lineStartIndex\"},{type:\"Uint32\",name:\"lineLength\"},{type:\"Uint16\",name:\"segment\"},{type:\"Uint16\",name:\"lowerSize\"},{type:\"Uint16\",name:\"upperSize\"},{type:\"Float32\",name:\"lineOffsetX\"},{type:\"Float32\",name:\"lineOffsetY\"},{type:\"Uint8\",name:\"writingMode\"},{type:\"Uint8\",name:\"hidden\"},{type:\"Uint32\",name:\"crossTileID\"}]),oi([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Int16\",name:\"rightJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"centerJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"leftJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"verticalPlacedTextSymbolIndex\"},{type:\"Uint16\",name:\"key\"},{type:\"Uint16\",name:\"textBoxStartIndex\"},{type:\"Uint16\",name:\"textBoxEndIndex\"},{type:\"Uint16\",name:\"iconBoxStartIndex\"},{type:\"Uint16\",name:\"iconBoxEndIndex\"},{type:\"Uint16\",name:\"featureIndex\"},{type:\"Uint16\",name:\"numHorizontalGlyphVertices\"},{type:\"Uint16\",name:\"numVerticalGlyphVertices\"},{type:\"Uint16\",name:\"numIconVertices\"},{type:\"Uint32\",name:\"crossTileID\"},{type:\"Float32\",name:\"textBoxScale\"},{type:\"Float32\",name:\"radialTextOffset\"}]),oi([{type:\"Float32\",name:\"offsetX\"}]),oi([{type:\"Int16\",name:\"x\"},{type:\"Int16\",name:\"y\"},{type:\"Int16\",name:\"tileUnitDistanceFromAnchor\"}]);var xs={\"!\":\"\\ufe15\",\"#\":\"\\uff03\",$:\"\\uff04\",\"%\":\"\\uff05\",\"&\":\"\\uff06\",\"(\":\"\\ufe35\",\")\":\"\\ufe36\",\"*\":\"\\uff0a\",\"+\":\"\\uff0b\",\",\":\"\\ufe10\",\"-\":\"\\ufe32\",\".\":\"\\u30fb\",\"/\":\"\\uff0f\",\":\":\"\\ufe13\",\";\":\"\\ufe14\",\"<\":\"\\ufe3f\",\"=\":\"\\uff1d\",\">\":\"\\ufe40\",\"?\":\"\\ufe16\",\"@\":\"\\uff20\",\"[\":\"\\ufe47\",\"\\\\\":\"\\uff3c\",\"]\":\"\\ufe48\",\"^\":\"\\uff3e\",_:\"\\ufe33\",\"`\":\"\\uff40\",\"{\":\"\\ufe37\",\"|\":\"\\u2015\",\"}\":\"\\ufe38\",\"~\":\"\\uff5e\",\"\\xa2\":\"\\uffe0\",\"\\xa3\":\"\\uffe1\",\"\\xa5\":\"\\uffe5\",\"\\xa6\":\"\\uffe4\",\"\\xac\":\"\\uffe2\",\"\\xaf\":\"\\uffe3\",\"\\u2013\":\"\\ufe32\",\"\\u2014\":\"\\ufe31\",\"\\u2018\":\"\\ufe43\",\"\\u2019\":\"\\ufe44\",\"\\u201c\":\"\\ufe41\",\"\\u201d\":\"\\ufe42\",\"\\u2026\":\"\\ufe19\",\"\\u2027\":\"\\u30fb\",\"\\u20a9\":\"\\uffe6\",\"\\u3001\":\"\\ufe11\",\"\\u3002\":\"\\ufe12\",\"\\u3008\":\"\\ufe3f\",\"\\u3009\":\"\\ufe40\",\"\\u300a\":\"\\ufe3d\",\"\\u300b\":\"\\ufe3e\",\"\\u300c\":\"\\ufe41\",\"\\u300d\":\"\\ufe42\",\"\\u300e\":\"\\ufe43\",\"\\u300f\":\"\\ufe44\",\"\\u3010\":\"\\ufe3b\",\"\\u3011\":\"\\ufe3c\",\"\\u3014\":\"\\ufe39\",\"\\u3015\":\"\\ufe3a\",\"\\u3016\":\"\\ufe17\",\"\\u3017\":\"\\ufe18\",\"\\uff01\":\"\\ufe15\",\"\\uff08\":\"\\ufe35\",\"\\uff09\":\"\\ufe36\",\"\\uff0c\":\"\\ufe10\",\"\\uff0d\":\"\\ufe32\",\"\\uff0e\":\"\\u30fb\",\"\\uff1a\":\"\\ufe13\",\"\\uff1b\":\"\\ufe14\",\"\\uff1c\":\"\\ufe3f\",\"\\uff1e\":\"\\ufe40\",\"\\uff1f\":\"\\ufe16\",\"\\uff3b\":\"\\ufe47\",\"\\uff3d\":\"\\ufe48\",\"\\uff3f\":\"\\ufe33\",\"\\uff5b\":\"\\ufe37\",\"\\uff5c\":\"\\u2015\",\"\\uff5d\":\"\\ufe38\",\"\\uff5f\":\"\\ufe35\",\"\\uff60\":\"\\ufe36\",\"\\uff61\":\"\\ufe12\",\"\\uff62\":\"\\ufe41\",\"\\uff63\":\"\\ufe42\"},bs=function(t){function e(e,r,n,i){t.call(this,e,r),this.angle=n,void 0!==i&&(this.segment=i)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.clone=function(){return new e(this.x,this.y,this.angle,this.segment)},e}(i);kn(\"Anchor\",bs);var _s=256;function ws(t,e){var r=e.expression;if(\"constant\"===r.kind)return{kind:\"constant\",layoutSize:r.evaluate(new Un(t+1))};if(\"source\"===r.kind)return{kind:\"source\"};for(var n=r.zoomStops,i=r.interpolationType,a=0;a<n.length&&n[a]<=t;)a++;for(var o=a=Math.max(0,a-1);o<n.length&&n[o]<t+1;)o++;o=Math.min(n.length-1,o);var s=n[a],l=n[o];return\"composite\"===r.kind?{kind:\"composite\",minZoom:s,maxZoom:l,interpolationType:i}:{kind:\"camera\",minZoom:s,maxZoom:l,minSize:r.evaluate(new Un(s)),maxSize:r.evaluate(new Un(l)),interpolationType:i}}function ks(t,e,r){var n=e.uSize,i=e.uSizeT,a=r.lowerSize,o=r.upperSize;return\"source\"===t.kind?a/_s:\"composite\"===t.kind?Ee(a/_s,o/_s,i):n}function Ts(t,e){var r=0,n=0;if(\"constant\"===t.kind)n=t.layoutSize;else if(\"source\"!==t.kind){var i=t.interpolationType,a=t.minZoom,o=t.maxZoom,s=i?c(Xe.interpolationFactor(i,e,a,o),0,1):0;\"camera\"===t.kind?n=Ee(t.minSize,t.maxSize,s):r=s}return{uSizeT:r,uSize:n}}var As=Object.freeze({getSizeData:ws,evaluateSizeForFeature:ks,evaluateSizeForZoom:Ts,SIZE_PACK_FACTOR:_s}),Ms=Vo.VectorTileFeature.types,Ss=[{name:\"a_fade_opacity\",components:1,type:\"Uint8\",offset:0}];function Es(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,Math.round(32*n),Math.round(32*i),a,o,s?s[0]:0,s?s[1]:0)}function Cs(t,e,r){t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r)}var Ls=function(t){this.layoutVertexArray=new pi,this.indexArray=new Ti,this.programConfigurations=t,this.segments=new Vi,this.dynamicLayoutVertexArray=new di,this.opacityVertexArray=new gi,this.placedSymbolArray=new Oi};Ls.prototype.upload=function(t,e,r,n){r&&(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,ps.members),this.indexBuffer=t.createIndexBuffer(this.indexArray,e),this.dynamicLayoutVertexBuffer=t.createVertexBuffer(this.dynamicLayoutVertexArray,ds.members,!0),this.opacityVertexBuffer=t.createVertexBuffer(this.opacityVertexArray,Ss,!0),this.opacityVertexBuffer.itemSize=1),(r||n)&&this.programConfigurations.upload(t)},Ls.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.dynamicLayoutVertexBuffer.destroy(),this.opacityVertexBuffer.destroy())},kn(\"SymbolBuffers\",Ls);var Ps=function(t,e,r){this.layoutVertexArray=new t,this.layoutAttributes=e,this.indexArray=new r,this.segments=new Vi,this.collisionVertexArray=new yi};Ps.prototype.upload=function(t){this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,this.layoutAttributes),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.collisionVertexBuffer=t.createVertexBuffer(this.collisionVertexArray,gs.members,!0)},Ps.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.segments.destroy(),this.collisionVertexBuffer.destroy())},kn(\"CollisionBuffers\",Ps);var Os=function(t){this.collisionBoxArray=t.collisionBoxArray,this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.pixelRatio=t.pixelRatio,this.sourceLayerIndex=t.sourceLayerIndex,this.hasPattern=!1;var e=this.layers[0]._unevaluatedLayout._values;this.textSizeData=ws(this.zoom,e[\"text-size\"]),this.iconSizeData=ws(this.zoom,e[\"icon-size\"]);var r=this.layers[0].layout,n=r.get(\"symbol-sort-key\"),i=r.get(\"symbol-z-order\");this.sortFeaturesByKey=\"viewport-y\"!==i&&void 0!==n.constantOr(1);var a=\"viewport-y\"===i||\"auto\"===i&&!this.sortFeaturesByKey;this.sortFeaturesByY=a&&(r.get(\"text-allow-overlap\")||r.get(\"icon-allow-overlap\")||r.get(\"text-ignore-placement\")||r.get(\"icon-ignore-placement\")),this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id}),this.sourceID=t.sourceID};Os.prototype.createArrays=function(){this.text=new Ls(new la(ps.members,this.layers,this.zoom,function(t){return/^text/.test(t)})),this.icon=new Ls(new la(ps.members,this.layers,this.zoom,function(t){return/^icon/.test(t)})),this.collisionBox=new Ps(mi,vs.members,Ai),this.collisionCircle=new Ps(mi,ms.members,Ti),this.glyphOffsetArray=new Ri,this.lineVertexArray=new Bi,this.symbolInstances=new Ii},Os.prototype.calculateGlyphDependencies=function(t,e,r,n){for(var i=0;i<t.length;i++)if(e[t.charCodeAt(i)]=!0,r&&n){var a=xs[t.charAt(i)];a&&(e[a.charCodeAt(0)]=!0)}},Os.prototype.populate=function(t,e){var r=this.layers[0],n=r.layout,i=n.get(\"text-font\"),a=n.get(\"text-field\"),o=n.get(\"icon-image\"),s=(\"constant\"!==a.value.kind||a.value.value.toString().length>0)&&(\"constant\"!==i.value.kind||i.value.value.length>0),l=\"constant\"!==o.value.kind||o.value.value&&o.value.value.length>0,c=n.get(\"symbol-sort-key\");if(this.features=[],s||l){for(var u=e.iconDependencies,h=e.glyphDependencies,f=new Un(this.zoom),p=0,d=t;p<d.length;p+=1){var g=d[p],v=g.feature,m=g.index,y=g.sourceLayerIndex;if(r._featureFilter(f,v)){var x=void 0;if(s){var b=r.getValueAndResolveTokens(\"text-field\",v);x=ys(b instanceof oe?b:oe.fromString(b),r,v)}var _=void 0;if(l&&(_=r.getValueAndResolveTokens(\"icon-image\",v)),x||_){var w=this.sortFeaturesByKey?c.evaluate(v,{}):void 0,k={text:x,icon:_,index:m,sourceLayerIndex:y,geometry:pa(v),properties:v.properties,type:Ms[v.type],sortKey:w};if(void 0!==v.id&&(k.id=v.id),this.features.push(k),_&&(u[_]=!0),x)for(var T=i.evaluate(v,{}).join(\",\"),A=\"map\"===n.get(\"text-rotation-alignment\")&&\"point\"!==n.get(\"symbol-placement\"),M=0,S=x.sections;M<S.length;M+=1){var E=S[M],C=Cn(x.toString()),L=E.fontStack||T,P=h[L]=h[L]||{};this.calculateGlyphDependencies(E.text,P,A,C)}}}}\"line\"===n.get(\"symbol-placement\")&&(this.features=function(t){var e={},r={},n=[],i=0;function a(e){n.push(t[e]),i++}function o(t,e,i){var a=r[t];return delete r[t],r[e]=a,n[a].geometry[0].pop(),n[a].geometry[0]=n[a].geometry[0].concat(i[0]),a}function s(t,r,i){var a=e[r];return delete e[r],e[t]=a,n[a].geometry[0].shift(),n[a].geometry[0]=i[0].concat(n[a].geometry[0]),a}function l(t,e,r){var n=r?e[0][e[0].length-1]:e[0][0];return t+\":\"+n.x+\":\"+n.y}for(var c=0;c<t.length;c++){var u=t[c],h=u.geometry,f=u.text?u.text.toString():null;if(f){var p=l(f,h),d=l(f,h,!0);if(p in r&&d in e&&r[p]!==e[d]){var g=s(p,d,h),v=o(p,d,n[g].geometry);delete e[p],delete r[d],r[l(f,n[v].geometry,!0)]=v,n[g].geometry=null}else p in r?o(p,d,h):d in e?s(p,d,h):(a(c),e[p]=i-1,r[d]=i-1)}else a(c)}return n.filter(function(t){return t.geometry})}(this.features)),this.sortFeaturesByKey&&this.features.sort(function(t,e){return t.sortKey-e.sortKey})}},Os.prototype.update=function(t,e,r){this.stateDependentLayers.length&&(this.text.programConfigurations.updatePaintArrays(t,e,this.layers,r),this.icon.programConfigurations.updatePaintArrays(t,e,this.layers,r))},Os.prototype.isEmpty=function(){return 0===this.symbolInstances.length},Os.prototype.uploadPending=function(){return!this.uploaded||this.text.programConfigurations.needsUpload||this.icon.programConfigurations.needsUpload},Os.prototype.upload=function(t){this.uploaded||(this.collisionBox.upload(t),this.collisionCircle.upload(t)),this.text.upload(t,this.sortFeaturesByY,!this.uploaded,this.text.programConfigurations.needsUpload),this.icon.upload(t,this.sortFeaturesByY,!this.uploaded,this.icon.programConfigurations.needsUpload),this.uploaded=!0},Os.prototype.destroy=function(){this.text.destroy(),this.icon.destroy(),this.collisionBox.destroy(),this.collisionCircle.destroy()},Os.prototype.addToLineVertexArray=function(t,e){var r=this.lineVertexArray.length;if(void 0!==t.segment){for(var n=t.dist(e[t.segment+1]),i=t.dist(e[t.segment]),a={},o=t.segment+1;o<e.length;o++)a[o]={x:e[o].x,y:e[o].y,tileUnitDistanceFromAnchor:n},o<e.length-1&&(n+=e[o+1].dist(e[o]));for(var s=t.segment||0;s>=0;s--)a[s]={x:e[s].x,y:e[s].y,tileUnitDistanceFromAnchor:i},s>0&&(i+=e[s-1].dist(e[s]));for(var l=0;l<e.length;l++){var c=a[l];this.lineVertexArray.emplaceBack(c.x,c.y,c.tileUnitDistanceFromAnchor)}}return{lineStartIndex:r,lineLength:this.lineVertexArray.length-r}},Os.prototype.addSymbols=function(t,e,r,n,i,a,o,s,l,c){for(var u=t.indexArray,h=t.layoutVertexArray,f=t.dynamicLayoutVertexArray,p=t.segments.prepareSegment(4*e.length,t.layoutVertexArray,t.indexArray,a.sortKey),d=this.glyphOffsetArray.length,g=p.vertexLength,v=0,m=e;v<m.length;v+=1){var y=m[v],x=y.tl,b=y.tr,_=y.bl,w=y.br,k=y.tex,T=p.vertexLength,A=y.glyphOffset[1];Es(h,s.x,s.y,x.x,A+x.y,k.x,k.y,r),Es(h,s.x,s.y,b.x,A+b.y,k.x+k.w,k.y,r),Es(h,s.x,s.y,_.x,A+_.y,k.x,k.y+k.h,r),Es(h,s.x,s.y,w.x,A+w.y,k.x+k.w,k.y+k.h,r),Cs(f,s,0),u.emplaceBack(T,T+1,T+2),u.emplaceBack(T+1,T+2,T+3),p.vertexLength+=4,p.primitiveLength+=2,this.glyphOffsetArray.emplaceBack(y.glyphOffset[0])}t.placedSymbolArray.emplaceBack(s.x,s.y,d,this.glyphOffsetArray.length-d,g,l,c,s.segment,r?r[0]:0,r?r[1]:0,n[0],n[1],o,!1,0),t.programConfigurations.populatePaintArrays(t.layoutVertexArray.length,a,a.index,{})},Os.prototype._addCollisionDebugVertex=function(t,e,r,n,i,a){return e.emplaceBack(0,0),t.emplaceBack(r.x,r.y,n,i,Math.round(a.x),Math.round(a.y))},Os.prototype.addCollisionDebugVertices=function(t,e,r,n,a,o,s,l){var c=a.segments.prepareSegment(4,a.layoutVertexArray,a.indexArray),u=c.vertexLength,h=a.layoutVertexArray,f=a.collisionVertexArray,p=s.anchorX,d=s.anchorY;if(this._addCollisionDebugVertex(h,f,o,p,d,new i(t,e)),this._addCollisionDebugVertex(h,f,o,p,d,new i(r,e)),this._addCollisionDebugVertex(h,f,o,p,d,new i(r,n)),this._addCollisionDebugVertex(h,f,o,p,d,new i(t,n)),c.vertexLength+=4,l){var g=a.indexArray;g.emplaceBack(u,u+1,u+2),g.emplaceBack(u,u+2,u+3),c.primitiveLength+=2}else{var v=a.indexArray;v.emplaceBack(u,u+1),v.emplaceBack(u+1,u+2),v.emplaceBack(u+2,u+3),v.emplaceBack(u+3,u),c.primitiveLength+=4}},Os.prototype.addDebugCollisionBoxes=function(t,e,r){for(var n=t;n<e;n++){var i=this.collisionBoxArray.get(n),a=i.x1,o=i.y1,s=i.x2,l=i.y2,c=i.radius>0;this.addCollisionDebugVertices(a,o,s,l,c?this.collisionCircle:this.collisionBox,i.anchorPoint,r,c)}},Os.prototype.generateCollisionDebugBuffers=function(){for(var t=0;t<this.symbolInstances.length;t++){var e=this.symbolInstances.get(t);this.addDebugCollisionBoxes(e.textBoxStartIndex,e.textBoxEndIndex,e),this.addDebugCollisionBoxes(e.iconBoxStartIndex,e.iconBoxEndIndex,e)}},Os.prototype._deserializeCollisionBoxesForSymbol=function(t,e,r,n,i){for(var a={},o=e;o<r;o++){var s=t.get(o);if(0===s.radius){a.textBox={x1:s.x1,y1:s.y1,x2:s.x2,y2:s.y2,anchorPointX:s.anchorPointX,anchorPointY:s.anchorPointY},a.textFeatureIndex=s.featureIndex;break}a.textCircles||(a.textCircles=[],a.textFeatureIndex=s.featureIndex),a.textCircles.push(s.anchorPointX,s.anchorPointY,s.radius,s.signedDistanceFromAnchor,1)}for(var l=n;l<i;l++){var c=t.get(l);if(0===c.radius){a.iconBox={x1:c.x1,y1:c.y1,x2:c.x2,y2:c.y2,anchorPointX:c.anchorPointX,anchorPointY:c.anchorPointY},a.iconFeatureIndex=c.featureIndex;break}}return a},Os.prototype.deserializeCollisionBoxes=function(t){this.collisionArrays=[];for(var e=0;e<this.symbolInstances.length;e++){var r=this.symbolInstances.get(e);this.collisionArrays.push(this._deserializeCollisionBoxesForSymbol(t,r.textBoxStartIndex,r.textBoxEndIndex,r.iconBoxStartIndex,r.iconBoxEndIndex))}},Os.prototype.hasTextData=function(){return this.text.segments.get().length>0},Os.prototype.hasIconData=function(){return this.icon.segments.get().length>0},Os.prototype.hasCollisionBoxData=function(){return this.collisionBox.segments.get().length>0},Os.prototype.hasCollisionCircleData=function(){return this.collisionCircle.segments.get().length>0},Os.prototype.addIndicesForPlacedTextSymbol=function(t){for(var e=this.text.placedSymbolArray.get(t),r=e.vertexStartIndex+4*e.numGlyphs,n=e.vertexStartIndex;n<r;n+=4)this.text.indexArray.emplaceBack(n,n+1,n+2),this.text.indexArray.emplaceBack(n+1,n+2,n+3)},Os.prototype.getSortedSymbolIndexes=function(t){if(this.sortedAngle===t&&void 0!==this.symbolInstanceIndexes)return this.symbolInstanceIndexes;for(var e=Math.sin(t),r=Math.cos(t),n=[],i=[],a=[],o=0;o<this.symbolInstances.length;++o){a.push(o);var s=this.symbolInstances.get(o);n.push(0|Math.round(e*s.anchorX+r*s.anchorY)),i.push(s.featureIndex)}return a.sort(function(t,e){return n[t]-n[e]||i[e]-i[t]}),a},Os.prototype.sortFeatures=function(t){var e=this;if(this.sortFeaturesByY&&this.sortedAngle!==t&&!(this.text.segments.get().length>1||this.icon.segments.get().length>1)){this.symbolInstanceIndexes=this.getSortedSymbolIndexes(t),this.sortedAngle=t,this.text.indexArray.clear(),this.icon.indexArray.clear(),this.featureSortOrder=[];for(var r=0,n=this.symbolInstanceIndexes;r<n.length;r+=1){var i=n[r],a=this.symbolInstances.get(i);this.featureSortOrder.push(a.featureIndex),[a.rightJustifiedTextSymbolIndex,a.centerJustifiedTextSymbolIndex,a.leftJustifiedTextSymbolIndex].forEach(function(t,r,n){t>=0&&n.indexOf(t)===r&&e.addIndicesForPlacedTextSymbol(t)}),a.verticalPlacedTextSymbolIndex>=0&&this.addIndicesForPlacedTextSymbol(a.verticalPlacedTextSymbolIndex);var o=this.icon.placedSymbolArray.get(i);if(o.numGlyphs){var s=o.vertexStartIndex;this.icon.indexArray.emplaceBack(s,s+1,s+2),this.icon.indexArray.emplaceBack(s+1,s+2,s+3)}}this.text.indexBuffer&&this.text.indexBuffer.updateData(this.text.indexArray),this.icon.indexBuffer&&this.icon.indexBuffer.updateData(this.icon.indexArray)}},kn(\"SymbolBucket\",Os,{omit:[\"layers\",\"collisionBoxArray\",\"features\",\"compareText\"]}),Os.MAX_GLYPHS=65535,Os.addDynamicAttributes=Cs;var zs=new ei({\"symbol-placement\":new Jn(It.layout_symbol[\"symbol-placement\"]),\"symbol-spacing\":new Jn(It.layout_symbol[\"symbol-spacing\"]),\"symbol-avoid-edges\":new Jn(It.layout_symbol[\"symbol-avoid-edges\"]),\"symbol-sort-key\":new Kn(It.layout_symbol[\"symbol-sort-key\"]),\"symbol-z-order\":new Jn(It.layout_symbol[\"symbol-z-order\"]),\"icon-allow-overlap\":new Jn(It.layout_symbol[\"icon-allow-overlap\"]),\"icon-ignore-placement\":new Jn(It.layout_symbol[\"icon-ignore-placement\"]),\"icon-optional\":new Jn(It.layout_symbol[\"icon-optional\"]),\"icon-rotation-alignment\":new Jn(It.layout_symbol[\"icon-rotation-alignment\"]),\"icon-size\":new Kn(It.layout_symbol[\"icon-size\"]),\"icon-text-fit\":new Jn(It.layout_symbol[\"icon-text-fit\"]),\"icon-text-fit-padding\":new Jn(It.layout_symbol[\"icon-text-fit-padding\"]),\"icon-image\":new Kn(It.layout_symbol[\"icon-image\"]),\"icon-rotate\":new Kn(It.layout_symbol[\"icon-rotate\"]),\"icon-padding\":new Jn(It.layout_symbol[\"icon-padding\"]),\"icon-keep-upright\":new Jn(It.layout_symbol[\"icon-keep-upright\"]),\"icon-offset\":new Kn(It.layout_symbol[\"icon-offset\"]),\"icon-anchor\":new Kn(It.layout_symbol[\"icon-anchor\"]),\"icon-pitch-alignment\":new Jn(It.layout_symbol[\"icon-pitch-alignment\"]),\"text-pitch-alignment\":new Jn(It.layout_symbol[\"text-pitch-alignment\"]),\"text-rotation-alignment\":new Jn(It.layout_symbol[\"text-rotation-alignment\"]),\"text-field\":new Kn(It.layout_symbol[\"text-field\"]),\"text-font\":new Kn(It.layout_symbol[\"text-font\"]),\"text-size\":new Kn(It.layout_symbol[\"text-size\"]),\"text-max-width\":new Kn(It.layout_symbol[\"text-max-width\"]),\"text-line-height\":new Jn(It.layout_symbol[\"text-line-height\"]),\"text-letter-spacing\":new Kn(It.layout_symbol[\"text-letter-spacing\"]),\"text-justify\":new Kn(It.layout_symbol[\"text-justify\"]),\"text-radial-offset\":new Kn(It.layout_symbol[\"text-radial-offset\"]),\"text-variable-anchor\":new Jn(It.layout_symbol[\"text-variable-anchor\"]),\"text-anchor\":new Kn(It.layout_symbol[\"text-anchor\"]),\"text-max-angle\":new Jn(It.layout_symbol[\"text-max-angle\"]),\"text-rotate\":new Kn(It.layout_symbol[\"text-rotate\"]),\"text-padding\":new Jn(It.layout_symbol[\"text-padding\"]),\"text-keep-upright\":new Jn(It.layout_symbol[\"text-keep-upright\"]),\"text-transform\":new Kn(It.layout_symbol[\"text-transform\"]),\"text-offset\":new Kn(It.layout_symbol[\"text-offset\"]),\"text-allow-overlap\":new Jn(It.layout_symbol[\"text-allow-overlap\"]),\"text-ignore-placement\":new Jn(It.layout_symbol[\"text-ignore-placement\"]),\"text-optional\":new Jn(It.layout_symbol[\"text-optional\"])}),Is={paint:new ei({\"icon-opacity\":new Kn(It.paint_symbol[\"icon-opacity\"]),\"icon-color\":new Kn(It.paint_symbol[\"icon-color\"]),\"icon-halo-color\":new Kn(It.paint_symbol[\"icon-halo-color\"]),\"icon-halo-width\":new Kn(It.paint_symbol[\"icon-halo-width\"]),\"icon-halo-blur\":new Kn(It.paint_symbol[\"icon-halo-blur\"]),\"icon-translate\":new Jn(It.paint_symbol[\"icon-translate\"]),\"icon-translate-anchor\":new Jn(It.paint_symbol[\"icon-translate-anchor\"]),\"text-opacity\":new Kn(It.paint_symbol[\"text-opacity\"]),\"text-color\":new Kn(It.paint_symbol[\"text-color\"]),\"text-halo-color\":new Kn(It.paint_symbol[\"text-halo-color\"]),\"text-halo-width\":new Kn(It.paint_symbol[\"text-halo-width\"]),\"text-halo-blur\":new Kn(It.paint_symbol[\"text-halo-blur\"]),\"text-translate\":new Jn(It.paint_symbol[\"text-translate\"]),\"text-translate-anchor\":new Jn(It.paint_symbol[\"text-translate-anchor\"])}),layout:zs},Ds=function(t){function e(e){t.call(this,e,Is)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e),\"auto\"===this.layout.get(\"icon-rotation-alignment\")&&(\"point\"!==this.layout.get(\"symbol-placement\")?this.layout._values[\"icon-rotation-alignment\"]=\"map\":this.layout._values[\"icon-rotation-alignment\"]=\"viewport\"),\"auto\"===this.layout.get(\"text-rotation-alignment\")&&(\"point\"!==this.layout.get(\"symbol-placement\")?this.layout._values[\"text-rotation-alignment\"]=\"map\":this.layout._values[\"text-rotation-alignment\"]=\"viewport\"),\"auto\"===this.layout.get(\"text-pitch-alignment\")&&(this.layout._values[\"text-pitch-alignment\"]=this.layout.get(\"text-rotation-alignment\")),\"auto\"===this.layout.get(\"icon-pitch-alignment\")&&(this.layout._values[\"icon-pitch-alignment\"]=this.layout.get(\"icon-rotation-alignment\"))},e.prototype.getValueAndResolveTokens=function(t,e){var r,n=this.layout.get(t).evaluate(e,{}),i=this._unevaluatedLayout._values[t];return i.isDataDriven()||Pr(i.value)?n:(r=e.properties,n.replace(/{([^{}]+)}/g,function(t,e){return e in r?String(r[e]):\"\"}))},e.prototype.createBucket=function(t){return new Os(t)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e}(ri),Rs={paint:new ei({\"background-color\":new Jn(It.paint_background[\"background-color\"]),\"background-pattern\":new Qn(It.paint_background[\"background-pattern\"]),\"background-opacity\":new Jn(It.paint_background[\"background-opacity\"])})},Fs=function(t){function e(e){t.call(this,e,Rs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ri),Bs={paint:new ei({\"raster-opacity\":new Jn(It.paint_raster[\"raster-opacity\"]),\"raster-hue-rotate\":new Jn(It.paint_raster[\"raster-hue-rotate\"]),\"raster-brightness-min\":new Jn(It.paint_raster[\"raster-brightness-min\"]),\"raster-brightness-max\":new Jn(It.paint_raster[\"raster-brightness-max\"]),\"raster-saturation\":new Jn(It.paint_raster[\"raster-saturation\"]),\"raster-contrast\":new Jn(It.paint_raster[\"raster-contrast\"]),\"raster-resampling\":new Jn(It.paint_raster[\"raster-resampling\"]),\"raster-fade-duration\":new Jn(It.paint_raster[\"raster-fade-duration\"])})},Ns=function(t){function e(e){t.call(this,e,Bs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ri),js=function(t){function e(e){t.call(this,e,{}),this.implementation=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.is3D=function(){return\"3d\"===this.implementation.renderingMode},e.prototype.hasOffscreenPass=function(){return void 0!==this.implementation.prerender},e.prototype.recalculate=function(){},e.prototype.updateTransitions=function(){},e.prototype.hasTransition=function(){},e.prototype.serialize=function(){},e.prototype.onAdd=function(t){this.implementation.onAdd&&this.implementation.onAdd(t,t.painter.context.gl)},e.prototype.onRemove=function(t){this.implementation.onRemove&&this.implementation.onRemove(t,t.painter.context.gl)},e}(ri),Us={circle:Fa,heatmap:Wa,hillshade:Za,fill:Oo,\"fill-extrusion\":Jo,line:hs,symbol:Ds,background:Fs,raster:Ns};function Vs(t){for(var e=0,r=0,n=0,i=t;n<i.length;n+=1){var a=i[n];e+=a.w*a.h,r=Math.max(r,a.w)}t.sort(function(t,e){return e.h-t.h});for(var o=[{x:0,y:0,w:Math.max(Math.ceil(Math.sqrt(e/.95)),r),h:1/0}],s=0,l=0,c=0,u=t;c<u.length;c+=1)for(var h=u[c],f=o.length-1;f>=0;f--){var p=o[f];if(!(h.w>p.w||h.h>p.h)){if(h.x=p.x,h.y=p.y,l=Math.max(l,h.y+h.h),s=Math.max(s,h.x+h.w),h.w===p.w&&h.h===p.h){var d=o.pop();f<o.length&&(o[f]=d)}else h.h===p.h?(p.x+=h.w,p.w-=h.w):h.w===p.w?(p.y+=h.h,p.h-=h.h):(o.push({x:p.x+h.w,y:p.y,w:p.w-h.w,h:h.h}),p.y+=h.h,p.h-=h.h);break}}return{w:s,h:l,fill:e/(s*l)||0}}var qs=function(t,e){var r=e.pixelRatio,n=e.version;this.paddedRect=t,this.pixelRatio=r,this.version=n},Hs={tl:{configurable:!0},br:{configurable:!0},tlbr:{configurable:!0},displaySize:{configurable:!0}};Hs.tl.get=function(){return[this.paddedRect.x+1,this.paddedRect.y+1]},Hs.br.get=function(){return[this.paddedRect.x+this.paddedRect.w-1,this.paddedRect.y+this.paddedRect.h-1]},Hs.tlbr.get=function(){return this.tl.concat(this.br)},Hs.displaySize.get=function(){return[(this.paddedRect.w-2)/this.pixelRatio,(this.paddedRect.h-2)/this.pixelRatio]},Object.defineProperties(qs.prototype,Hs);var Gs=function(t,e){var r={},n={};this.haveRenderCallbacks=[];var i=[];this.addImages(t,r,i),this.addImages(e,n,i);var a=Vs(i),o=a.w,s=a.h,l=new Ha({width:o||1,height:s||1});for(var c in t){var u=t[c],h=r[c].paddedRect;Ha.copy(u.data,l,{x:0,y:0},{x:h.x+1,y:h.y+1},u.data)}for(var f in e){var p=e[f],d=n[f].paddedRect,g=d.x+1,v=d.y+1,m=p.data.width,y=p.data.height;Ha.copy(p.data,l,{x:0,y:0},{x:g,y:v},p.data),Ha.copy(p.data,l,{x:0,y:y-1},{x:g,y:v-1},{width:m,height:1}),Ha.copy(p.data,l,{x:0,y:0},{x:g,y:v+y},{width:m,height:1}),Ha.copy(p.data,l,{x:m-1,y:0},{x:g-1,y:v},{width:1,height:y}),Ha.copy(p.data,l,{x:0,y:0},{x:g+m,y:v},{width:1,height:y})}this.image=l,this.iconPositions=r,this.patternPositions=n};Gs.prototype.addImages=function(t,e,r){for(var n in t){var i=t[n],a={x:0,y:0,w:i.data.width+2,h:i.data.height+2};r.push(a),e[n]=new qs(a,i),i.hasRenderCallback&&this.haveRenderCallbacks.push(n)}},Gs.prototype.patchUpdatedImages=function(t,e){for(var r in t.dispatchRenderCallbacks(this.haveRenderCallbacks),t.updatedImages)this.patchUpdatedImage(this.iconPositions[r],t.getImage(r),e),this.patchUpdatedImage(this.patternPositions[r],t.getImage(r),e)},Gs.prototype.patchUpdatedImage=function(t,e,r){if(t&&e&&t.version!==e.version){t.version=e.version;var n=t.tl,i=n[0],a=n[1];r.update(e.data,void 0,{x:i,y:a})}},kn(\"ImagePosition\",qs),kn(\"ImageAtlas\",Gs);var Ys=self.HTMLImageElement,Ws=self.HTMLCanvasElement,Xs=self.HTMLVideoElement,Zs=self.ImageData,Js=function(t,e,r,n){this.context=t,this.format=r,this.texture=t.gl.createTexture(),this.update(e,n)};Js.prototype.update=function(t,e,r){var n=t.width,i=t.height,a=!(this.size&&this.size[0]===n&&this.size[1]===i||r),o=this.context,s=o.gl;if(this.useMipmap=Boolean(e&&e.useMipmap),s.bindTexture(s.TEXTURE_2D,this.texture),o.pixelStoreUnpackFlipY.set(!1),o.pixelStoreUnpack.set(1),o.pixelStoreUnpackPremultiplyAlpha.set(this.format===s.RGBA&&(!e||!1!==e.premultiply)),a)this.size=[n,i],t instanceof Ys||t instanceof Ws||t instanceof Xs||t instanceof Zs?s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,s.UNSIGNED_BYTE,t):s.texImage2D(s.TEXTURE_2D,0,this.format,n,i,0,this.format,s.UNSIGNED_BYTE,t.data);else{var l=r||{x:0,y:0},c=l.x,u=l.y;t instanceof Ys||t instanceof Ws||t instanceof Xs||t instanceof Zs?s.texSubImage2D(s.TEXTURE_2D,0,c,u,s.RGBA,s.UNSIGNED_BYTE,t):s.texSubImage2D(s.TEXTURE_2D,0,c,u,n,i,s.RGBA,s.UNSIGNED_BYTE,t.data)}this.useMipmap&&this.isSizePowerOfTwo()&&s.generateMipmap(s.TEXTURE_2D)},Js.prototype.bind=function(t,e,r){var n=this.context.gl;n.bindTexture(n.TEXTURE_2D,this.texture),r!==n.LINEAR_MIPMAP_NEAREST||this.isSizePowerOfTwo()||(r=n.LINEAR),t!==this.filter&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,t),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,r||t),this.filter=t),e!==this.wrap&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,e),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,e),this.wrap=e)},Js.prototype.isSizePowerOfTwo=function(){return this.size[0]===this.size[1]&&Math.log(this.size[0])/Math.LN2%1==0},Js.prototype.destroy=function(){this.context.gl.deleteTexture(this.texture),this.texture=null};var Ks=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?i-1:0,f=r?-1:1,p=t[e+h];for(h+=f,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+h],h+=f,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},$s=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,h=u>>1,f=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,i),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g},Qs=tl;function tl(t){this.buf=ArrayBuffer.isView&&ArrayBuffer.isView(t)?t:new Uint8Array(t||0),this.pos=0,this.type=0,this.length=this.buf.length}function el(t){return t.type===tl.Bytes?t.readVarint()+t.pos:t.pos+1}function rl(t,e,r){return r?4294967296*e+(t>>>0):4294967296*(e>>>0)+(t>>>0)}function nl(t,e,r){var n=e<=16383?1:e<=2097151?2:e<=268435455?3:Math.floor(Math.log(e)/(7*Math.LN2));r.realloc(n);for(var i=r.pos-1;i>=t;i--)r.buf[i+n]=r.buf[i]}function il(t,e){for(var r=0;r<t.length;r++)e.writeVarint(t[r])}function al(t,e){for(var r=0;r<t.length;r++)e.writeSVarint(t[r])}function ol(t,e){for(var r=0;r<t.length;r++)e.writeFloat(t[r])}function sl(t,e){for(var r=0;r<t.length;r++)e.writeDouble(t[r])}function ll(t,e){for(var r=0;r<t.length;r++)e.writeBoolean(t[r])}function cl(t,e){for(var r=0;r<t.length;r++)e.writeFixed32(t[r])}function ul(t,e){for(var r=0;r<t.length;r++)e.writeSFixed32(t[r])}function hl(t,e){for(var r=0;r<t.length;r++)e.writeFixed64(t[r])}function fl(t,e){for(var r=0;r<t.length;r++)e.writeSFixed64(t[r])}function pl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+16777216*t[e+3]}function dl(t,e,r){t[r]=e,t[r+1]=e>>>8,t[r+2]=e>>>16,t[r+3]=e>>>24}function gl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+(t[e+3]<<24)}tl.Varint=0,tl.Fixed64=1,tl.Bytes=2,tl.Fixed32=5,tl.prototype={destroy:function(){this.buf=null},readFields:function(t,e,r){for(r=r||this.length;this.pos<r;){var n=this.readVarint(),i=n>>3,a=this.pos;this.type=7&n,t(i,e,this),this.pos===a&&this.skip(n)}return e},readMessage:function(t,e){return this.readFields(t,e,this.readVarint()+this.pos)},readFixed32:function(){var t=pl(this.buf,this.pos);return this.pos+=4,t},readSFixed32:function(){var t=gl(this.buf,this.pos);return this.pos+=4,t},readFixed64:function(){var t=pl(this.buf,this.pos)+4294967296*pl(this.buf,this.pos+4);return this.pos+=8,t},readSFixed64:function(){var t=pl(this.buf,this.pos)+4294967296*gl(this.buf,this.pos+4);return this.pos+=8,t},readFloat:function(){var t=Ks(this.buf,this.pos,!0,23,4);return this.pos+=4,t},readDouble:function(){var t=Ks(this.buf,this.pos,!0,52,8);return this.pos+=8,t},readVarint:function(t){var e,r,n=this.buf;return e=127&(r=n[this.pos++]),r<128?e:(e|=(127&(r=n[this.pos++]))<<7,r<128?e:(e|=(127&(r=n[this.pos++]))<<14,r<128?e:(e|=(127&(r=n[this.pos++]))<<21,r<128?e:function(t,e,r){var n,i,a=r.buf;if(n=(112&(i=a[r.pos++]))>>4,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<3,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<10,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<17,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<24,i<128)return rl(t,n,e);if(n|=(1&(i=a[r.pos++]))<<31,i<128)return rl(t,n,e);throw new Error(\"Expected varint not more than 10 bytes\")}(e|=(15&(r=n[this.pos]))<<28,t,this))))},readVarint64:function(){return this.readVarint(!0)},readSVarint:function(){var t=this.readVarint();return t%2==1?(t+1)/-2:t/2},readBoolean:function(){return Boolean(this.readVarint())},readString:function(){var t=this.readVarint()+this.pos,e=function(t,e,r){for(var n=\"\",i=e;i<r;){var a,o,s,l=t[i],c=null,u=l>239?4:l>223?3:l>191?2:1;if(i+u>r)break;1===u?l<128&&(c=l):2===u?128==(192&(a=t[i+1]))&&(c=(31&l)<<6|63&a)<=127&&(c=null):3===u?(a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&((c=(15&l)<<12|(63&a)<<6|63&o)<=2047||c>=55296&&c<=57343)&&(c=null)):4===u&&(a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&((c=(15&l)<<18|(63&a)<<12|(63&o)<<6|63&s)<=65535||c>=1114112)&&(c=null)),null===c?(c=65533,u=1):c>65535&&(c-=65536,n+=String.fromCharCode(c>>>10&1023|55296),c=56320|1023&c),n+=String.fromCharCode(c),i+=u}return n}(this.buf,this.pos,t);return this.pos=t,e},readBytes:function(){var t=this.readVarint()+this.pos,e=this.buf.subarray(this.pos,t);return this.pos=t,e},readPackedVarint:function(t,e){if(this.type!==tl.Bytes)return t.push(this.readVarint(e));var r=el(this);for(t=t||[];this.pos<r;)t.push(this.readVarint(e));return t},readPackedSVarint:function(t){if(this.type!==tl.Bytes)return t.push(this.readSVarint());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSVarint());return t},readPackedBoolean:function(t){if(this.type!==tl.Bytes)return t.push(this.readBoolean());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readBoolean());return t},readPackedFloat:function(t){if(this.type!==tl.Bytes)return t.push(this.readFloat());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFloat());return t},readPackedDouble:function(t){if(this.type!==tl.Bytes)return t.push(this.readDouble());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readDouble());return t},readPackedFixed32:function(t){if(this.type!==tl.Bytes)return t.push(this.readFixed32());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFixed32());return t},readPackedSFixed32:function(t){if(this.type!==tl.Bytes)return t.push(this.readSFixed32());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed32());return t},readPackedFixed64:function(t){if(this.type!==tl.Bytes)return t.push(this.readFixed64());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFixed64());return t},readPackedSFixed64:function(t){if(this.type!==tl.Bytes)return t.push(this.readSFixed64());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed64());return t},skip:function(t){var e=7&t;if(e===tl.Varint)for(;this.buf[this.pos++]>127;);else if(e===tl.Bytes)this.pos=this.readVarint()+this.pos;else if(e===tl.Fixed32)this.pos+=4;else{if(e!==tl.Fixed64)throw new Error(\"Unimplemented type: \"+e);this.pos+=8}},writeTag:function(t,e){this.writeVarint(t<<3|e)},realloc:function(t){for(var e=this.length||16;e<this.pos+t;)e*=2;if(e!==this.length){var r=new Uint8Array(e);r.set(this.buf),this.buf=r,this.length=e}},finish:function(){return this.length=this.pos,this.pos=0,this.buf.subarray(0,this.length)},writeFixed32:function(t){this.realloc(4),dl(this.buf,t,this.pos),this.pos+=4},writeSFixed32:function(t){this.realloc(4),dl(this.buf,t,this.pos),this.pos+=4},writeFixed64:function(t){this.realloc(8),dl(this.buf,-1&t,this.pos),dl(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeSFixed64:function(t){this.realloc(8),dl(this.buf,-1&t,this.pos),dl(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeVarint:function(t){(t=+t||0)>268435455||t<0?function(t,e){var r,n;if(t>=0?(r=t%4294967296|0,n=t/4294967296|0):(n=~(-t/4294967296),4294967295^(r=~(-t%4294967296))?r=r+1|0:(r=0,n=n+1|0)),t>=0x10000000000000000||t<-0x10000000000000000)throw new Error(\"Given varint doesn't fit into 10 bytes\");e.realloc(10),function(t,e,r){r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos]=127&t}(r,0,e),function(t,e){var r=(7&t)<<4;e.buf[e.pos++]|=r|((t>>>=3)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t)))))}(n,e)}(t,this):(this.realloc(4),this.buf[this.pos++]=127&t|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=t>>>7&127))))},writeSVarint:function(t){this.writeVarint(t<0?2*-t-1:2*t)},writeBoolean:function(t){this.writeVarint(Boolean(t))},writeString:function(t){t=String(t),this.realloc(4*t.length),this.pos++;var e=this.pos;this.pos=function(t,e,r){for(var n,i,a=0;a<e.length;a++){if((n=e.charCodeAt(a))>55295&&n<57344){if(!i){n>56319||a+1===e.length?(t[r++]=239,t[r++]=191,t[r++]=189):i=n;continue}if(n<56320){t[r++]=239,t[r++]=191,t[r++]=189,i=n;continue}n=i-55296<<10|n-56320|65536,i=null}else i&&(t[r++]=239,t[r++]=191,t[r++]=189,i=null);n<128?t[r++]=n:(n<2048?t[r++]=n>>6|192:(n<65536?t[r++]=n>>12|224:(t[r++]=n>>18|240,t[r++]=n>>12&63|128),t[r++]=n>>6&63|128),t[r++]=63&n|128)}return r}(this.buf,t,this.pos);var r=this.pos-e;r>=128&&nl(e,r,this),this.pos=e-1,this.writeVarint(r),this.pos+=r},writeFloat:function(t){this.realloc(4),$s(this.buf,t,this.pos,!0,23,4),this.pos+=4},writeDouble:function(t){this.realloc(8),$s(this.buf,t,this.pos,!0,52,8),this.pos+=8},writeBytes:function(t){var e=t.length;this.writeVarint(e),this.realloc(e);for(var r=0;r<e;r++)this.buf[this.pos++]=t[r]},writeRawMessage:function(t,e){this.pos++;var r=this.pos;t(e,this);var n=this.pos-r;n>=128&&nl(r,n,this),this.pos=r-1,this.writeVarint(n),this.pos+=n},writeMessage:function(t,e,r){this.writeTag(t,tl.Bytes),this.writeRawMessage(e,r)},writePackedVarint:function(t,e){e.length&&this.writeMessage(t,il,e)},writePackedSVarint:function(t,e){e.length&&this.writeMessage(t,al,e)},writePackedBoolean:function(t,e){e.length&&this.writeMessage(t,ll,e)},writePackedFloat:function(t,e){e.length&&this.writeMessage(t,ol,e)},writePackedDouble:function(t,e){e.length&&this.writeMessage(t,sl,e)},writePackedFixed32:function(t,e){e.length&&this.writeMessage(t,cl,e)},writePackedSFixed32:function(t,e){e.length&&this.writeMessage(t,ul,e)},writePackedFixed64:function(t,e){e.length&&this.writeMessage(t,hl,e)},writePackedSFixed64:function(t,e){e.length&&this.writeMessage(t,fl,e)},writeBytesField:function(t,e){this.writeTag(t,tl.Bytes),this.writeBytes(e)},writeFixed32Field:function(t,e){this.writeTag(t,tl.Fixed32),this.writeFixed32(e)},writeSFixed32Field:function(t,e){this.writeTag(t,tl.Fixed32),this.writeSFixed32(e)},writeFixed64Field:function(t,e){this.writeTag(t,tl.Fixed64),this.writeFixed64(e)},writeSFixed64Field:function(t,e){this.writeTag(t,tl.Fixed64),this.writeSFixed64(e)},writeVarintField:function(t,e){this.writeTag(t,tl.Varint),this.writeVarint(e)},writeSVarintField:function(t,e){this.writeTag(t,tl.Varint),this.writeSVarint(e)},writeStringField:function(t,e){this.writeTag(t,tl.Bytes),this.writeString(e)},writeFloatField:function(t,e){this.writeTag(t,tl.Fixed32),this.writeFloat(e)},writeDoubleField:function(t,e){this.writeTag(t,tl.Fixed64),this.writeDouble(e)},writeBooleanField:function(t,e){this.writeVarintField(t,Boolean(e))}};var vl=3;function ml(t,e,r){1===t&&r.readMessage(yl,e)}function yl(t,e,r){if(3===t){var n=r.readMessage(xl,{}),i=n.id,a=n.bitmap,o=n.width,s=n.height,l=n.left,c=n.top,u=n.advance;e.push({id:i,bitmap:new qa({width:o+2*vl,height:s+2*vl},a),metrics:{width:o,height:s,left:l,top:c,advance:u}})}}function xl(t,e,r){1===t?e.id=r.readVarint():2===t?e.bitmap=r.readBytes():3===t?e.width=r.readVarint():4===t?e.height=r.readVarint():5===t?e.left=r.readSVarint():6===t?e.top=r.readSVarint():7===t&&(e.advance=r.readVarint())}var bl=vl,_l=function(t,e,r){this.target=t,this.parent=e,this.mapId=r,this.callbacks={},this.callbackID=0,v([\"receive\"],this),this.target.addEventListener(\"message\",this.receive,!1)};function wl(t,e,r){var n=2*Math.PI*6378137/256/Math.pow(2,r);return[t*n-2*Math.PI*6378137/2,e*n-2*Math.PI*6378137/2]}_l.prototype.send=function(t,e,r,n){var i=this,a=r?this.mapId+\":\"+this.callbackID++:null;r&&(this.callbacks[a]=r);var o=[];if(this.target.postMessage({targetMapId:n,sourceMapId:this.mapId,type:t,id:String(a),data:An(e,o)},o),r)return{cancel:function(){i.callbacks[a]=null,i.target.postMessage({targetMapId:n,sourceMapId:i.mapId,type:\"<cancel>\",id:String(a)})}}},_l.prototype.receive=function(t){var e,r=this,n=t.data,i=n.id;if(!n.targetMapId||this.mapId===n.targetMapId){var a=function(t,e){delete r.callbacks[i];var n=[];r.target.postMessage({sourceMapId:r.mapId,type:\"<response>\",id:String(i),error:t?An(t):null,data:An(e,n)},n)};if(\"<response>\"===n.type||\"<cancel>\"===n.type)e=this.callbacks[n.id],delete this.callbacks[n.id],e&&n.error?e(Mn(n.error)):e&&e(null,Mn(n.data));else if(void 0!==n.id&&this.parent[n.type]){this.callbacks[n.id]=null;var o=this.parent[n.type](n.sourceMapId,Mn(n.data),a);o&&null===this.callbacks[n.id]&&(this.callbacks[n.id]=o.cancel)}else if(void 0!==n.id&&this.parent.getWorkerSource){var s=n.type.split(\".\"),l=Mn(n.data);this.parent.getWorkerSource(n.sourceMapId,s[0],l.source)[s[1]](l,a)}else this.parent[n.type](Mn(n.data))}},_l.prototype.remove=function(){this.target.removeEventListener(\"message\",this.receive,!1)};var kl=function(t,e){t&&(e?this.setSouthWest(t).setNorthEast(e):4===t.length?this.setSouthWest([t[0],t[1]]).setNorthEast([t[2],t[3]]):this.setSouthWest(t[0]).setNorthEast(t[1]))};kl.prototype.setNorthEast=function(t){return this._ne=t instanceof Tl?new Tl(t.lng,t.lat):Tl.convert(t),this},kl.prototype.setSouthWest=function(t){return this._sw=t instanceof Tl?new Tl(t.lng,t.lat):Tl.convert(t),this},kl.prototype.extend=function(t){var e,r,n=this._sw,i=this._ne;if(t instanceof Tl)e=t,r=t;else{if(!(t instanceof kl))return Array.isArray(t)?t.every(Array.isArray)?this.extend(kl.convert(t)):this.extend(Tl.convert(t)):this;if(e=t._sw,r=t._ne,!e||!r)return this}return n||i?(n.lng=Math.min(e.lng,n.lng),n.lat=Math.min(e.lat,n.lat),i.lng=Math.max(r.lng,i.lng),i.lat=Math.max(r.lat,i.lat)):(this._sw=new Tl(e.lng,e.lat),this._ne=new Tl(r.lng,r.lat)),this},kl.prototype.getCenter=function(){return new Tl((this._sw.lng+this._ne.lng)/2,(this._sw.lat+this._ne.lat)/2)},kl.prototype.getSouthWest=function(){return this._sw},kl.prototype.getNorthEast=function(){return this._ne},kl.prototype.getNorthWest=function(){return new Tl(this.getWest(),this.getNorth())},kl.prototype.getSouthEast=function(){return new Tl(this.getEast(),this.getSouth())},kl.prototype.getWest=function(){return this._sw.lng},kl.prototype.getSouth=function(){return this._sw.lat},kl.prototype.getEast=function(){return this._ne.lng},kl.prototype.getNorth=function(){return this._ne.lat},kl.prototype.toArray=function(){return[this._sw.toArray(),this._ne.toArray()]},kl.prototype.toString=function(){return\"LngLatBounds(\"+this._sw.toString()+\", \"+this._ne.toString()+\")\"},kl.prototype.isEmpty=function(){return!(this._sw&&this._ne)},kl.convert=function(t){return!t||t instanceof kl?t:new kl(t)};var Tl=function(t,e){if(isNaN(t)||isNaN(e))throw new Error(\"Invalid LngLat object: (\"+t+\", \"+e+\")\");if(this.lng=+t,this.lat=+e,this.lat>90||this.lat<-90)throw new Error(\"Invalid LngLat latitude value: must be between -90 and 90\")};function Al(t){return 2*Math.PI*6378137*Math.cos(t*Math.PI/180)}function Ml(t){return(180+t)/360}function Sl(t){return(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+t*Math.PI/360)))/360}function El(t,e){return t/Al(e)}function Cl(t){var e=180-360*t;return 360/Math.PI*Math.atan(Math.exp(e*Math.PI/180))-90}Tl.prototype.wrap=function(){return new Tl(u(this.lng,-180,180),this.lat)},Tl.prototype.toArray=function(){return[this.lng,this.lat]},Tl.prototype.toString=function(){return\"LngLat(\"+this.lng+\", \"+this.lat+\")\"},Tl.prototype.toBounds=function(t){void 0===t&&(t=0);var e=360*t/40075017,r=e/Math.cos(Math.PI/180*this.lat);return new kl(new Tl(this.lng-r,this.lat-e),new Tl(this.lng+r,this.lat+e))},Tl.convert=function(t){if(t instanceof Tl)return t;if(Array.isArray(t)&&(2===t.length||3===t.length))return new Tl(Number(t[0]),Number(t[1]));if(!Array.isArray(t)&&\"object\"==typeof t&&null!==t)return new Tl(Number(\"lng\"in t?t.lng:t.lon),Number(t.lat));throw new Error(\"`LngLatLike` argument must be specified as a LngLat instance, an object {lng: <lng>, lat: <lat>}, an object {lon: <lng>, lat: <lat>}, or an array of [<lng>, <lat>]\")};var Ll=function(t,e,r){void 0===r&&(r=0),this.x=+t,this.y=+e,this.z=+r};Ll.fromLngLat=function(t,e){void 0===e&&(e=0);var r=Tl.convert(t);return new Ll(Ml(r.lng),Sl(r.lat),El(e,r.lat))},Ll.prototype.toLngLat=function(){return new Tl(360*this.x-180,Cl(this.y))},Ll.prototype.toAltitude=function(){return this.z*Al(Cl(this.y))};var Pl=function(t,e,r){this.z=t,this.x=e,this.y=r,this.key=Il(0,t,e,r)};Pl.prototype.equals=function(t){return this.z===t.z&&this.x===t.x&&this.y===t.y},Pl.prototype.url=function(t,e){var r,n,i,a,o,s=(r=this.x,n=this.y,i=this.z,a=wl(256*r,256*(n=Math.pow(2,i)-n-1),i),o=wl(256*(r+1),256*(n+1),i),a[0]+\",\"+a[1]+\",\"+o[0]+\",\"+o[1]),l=function(t,e,r){for(var n,i=\"\",a=t;a>0;a--)i+=(e&(n=1<<a-1)?1:0)+(r&n?2:0);return i}(this.z,this.x,this.y);return t[(this.x+this.y)%t.length].replace(\"{prefix}\",(this.x%16).toString(16)+(this.y%16).toString(16)).replace(\"{z}\",String(this.z)).replace(\"{x}\",String(this.x)).replace(\"{y}\",String(\"tms\"===e?Math.pow(2,this.z)-this.y-1:this.y)).replace(\"{quadkey}\",l).replace(\"{bbox-epsg-3857}\",s)},Pl.prototype.getTilePoint=function(t){var e=Math.pow(2,this.z);return new i((t.x*e-this.x)*ha,(t.y*e-this.y)*ha)};var Ol=function(t,e){this.wrap=t,this.canonical=e,this.key=Il(t,e.z,e.x,e.y)},zl=function(t,e,r,n,i){this.overscaledZ=t,this.wrap=e,this.canonical=new Pl(r,+n,+i),this.key=Il(e,t,n,i)};function Il(t,e,r,n){(t*=2)<0&&(t=-1*t-1);var i=1<<e;return 32*(i*i*t+i*n+r)+e}zl.prototype.equals=function(t){return this.overscaledZ===t.overscaledZ&&this.wrap===t.wrap&&this.canonical.equals(t.canonical)},zl.prototype.scaledTo=function(t){var e=this.canonical.z-t;return t>this.canonical.z?new zl(t,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y):new zl(t,this.wrap,t,this.canonical.x>>e,this.canonical.y>>e)},zl.prototype.isChildOf=function(t){if(t.wrap!==this.wrap)return!1;var e=this.canonical.z-t.canonical.z;return 0===t.overscaledZ||t.overscaledZ<this.overscaledZ&&t.canonical.x===this.canonical.x>>e&&t.canonical.y===this.canonical.y>>e},zl.prototype.children=function(t){if(this.overscaledZ>=t)return[new zl(this.overscaledZ+1,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y)];var e=this.canonical.z+1,r=2*this.canonical.x,n=2*this.canonical.y;return[new zl(e,this.wrap,e,r,n),new zl(e,this.wrap,e,r+1,n),new zl(e,this.wrap,e,r,n+1),new zl(e,this.wrap,e,r+1,n+1)]},zl.prototype.isLessThan=function(t){return this.wrap<t.wrap||!(this.wrap>t.wrap)&&(this.overscaledZ<t.overscaledZ||!(this.overscaledZ>t.overscaledZ)&&(this.canonical.x<t.canonical.x||!(this.canonical.x>t.canonical.x)&&this.canonical.y<t.canonical.y))},zl.prototype.wrapped=function(){return new zl(this.overscaledZ,0,this.canonical.z,this.canonical.x,this.canonical.y)},zl.prototype.unwrapTo=function(t){return new zl(this.overscaledZ,t,this.canonical.z,this.canonical.x,this.canonical.y)},zl.prototype.overscaleFactor=function(){return Math.pow(2,this.overscaledZ-this.canonical.z)},zl.prototype.toUnwrapped=function(){return new Ol(this.wrap,this.canonical)},zl.prototype.toString=function(){return this.overscaledZ+\"/\"+this.canonical.x+\"/\"+this.canonical.y},zl.prototype.getTilePoint=function(t){return this.canonical.getTilePoint(new Ll(t.x-this.wrap,t.y))},kn(\"CanonicalTileID\",Pl),kn(\"OverscaledTileID\",zl,{omit:[\"posMatrix\"]});var Dl=function(t,e,r){if(this.uid=t,e.height!==e.width)throw new RangeError(\"DEM tiles must be square\");if(r&&\"mapbox\"!==r&&\"terrarium\"!==r)return w('\"'+r+'\" is not a valid encoding type. Valid types include \"mapbox\" and \"terrarium\".');var n=this.dim=e.height;this.stride=this.dim+2,this.data=new Int32Array(this.stride*this.stride);for(var i=e.data,a=\"terrarium\"===r?this._unpackTerrarium:this._unpackMapbox,o=0;o<n;o++)for(var s=0;s<n;s++){var l=4*(o*n+s);this.set(s,o,a(i[l],i[l+1],i[l+2]))}for(var c=0;c<n;c++)this.set(-1,c,this.get(0,c)),this.set(n,c,this.get(n-1,c)),this.set(c,-1,this.get(c,0)),this.set(c,n,this.get(c,n-1));this.set(-1,-1,this.get(0,0)),this.set(n,-1,this.get(n-1,0)),this.set(-1,n,this.get(0,n-1)),this.set(n,n,this.get(n-1,n-1))};Dl.prototype.set=function(t,e,r){this.data[this._idx(t,e)]=r+65536},Dl.prototype.get=function(t,e){return this.data[this._idx(t,e)]-65536},Dl.prototype._idx=function(t,e){if(t<-1||t>=this.dim+1||e<-1||e>=this.dim+1)throw new RangeError(\"out of range source coordinates for DEM data\");return(e+1)*this.stride+(t+1)},Dl.prototype._unpackMapbox=function(t,e,r){return(256*t*256+256*e+r)/10-1e4},Dl.prototype._unpackTerrarium=function(t,e,r){return 256*t+e+r/256-32768},Dl.prototype.getPixels=function(){return new Ha({width:this.stride,height:this.stride},new Uint8Array(this.data.buffer))},Dl.prototype.backfillBorder=function(t,e,r){if(this.dim!==t.dim)throw new Error(\"dem dimension mismatch\");var n=e*this.dim,i=e*this.dim+this.dim,a=r*this.dim,o=r*this.dim+this.dim;switch(e){case-1:n=i-1;break;case 1:i=n+1}switch(r){case-1:a=o-1;break;case 1:o=a+1}for(var s=-e*this.dim,l=-r*this.dim,c=a;c<o;c++)for(var u=n;u<i;u++)this.set(u,c,t.get(u+s,c+l))},kn(\"DEMData\",Dl);var Rl=oi([{name:\"a_pos\",type:\"Int16\",components:2},{name:\"a_texture_pos\",type:\"Int16\",components:2}]),Fl=function(t){this._stringToNumber={},this._numberToString=[];for(var e=0;e<t.length;e++){var r=t[e];this._stringToNumber[r]=e,this._numberToString[e]=r}};Fl.prototype.encode=function(t){return this._stringToNumber[t]},Fl.prototype.decode=function(t){return this._numberToString[t]};var Bl=function(t,e,r,n){this.type=\"Feature\",this._vectorTileFeature=t,t._z=e,t._x=r,t._y=n,this.properties=t.properties,null!=t.id&&(this.id=t.id)},Nl={geometry:{configurable:!0}};Nl.geometry.get=function(){return void 0===this._geometry&&(this._geometry=this._vectorTileFeature.toGeoJSON(this._vectorTileFeature._x,this._vectorTileFeature._y,this._vectorTileFeature._z).geometry),this._geometry},Nl.geometry.set=function(t){this._geometry=t},Bl.prototype.toJSON=function(){var t={geometry:this.geometry};for(var e in this)\"_geometry\"!==e&&\"_vectorTileFeature\"!==e&&(t[e]=this[e]);return t},Object.defineProperties(Bl.prototype,Nl);var jl=function(){this.state={},this.stateChanges={},this.deletedStates={}};jl.prototype.updateState=function(t,e,r){var n=String(e);if(this.stateChanges[t]=this.stateChanges[t]||{},this.stateChanges[t][n]=this.stateChanges[t][n]||{},h(this.stateChanges[t][n],r),null===this.deletedStates[t])for(var i in this.deletedStates[t]={},this.state[t])i!==n&&(this.deletedStates[t][i]=null);else if(this.deletedStates[t]&&null===this.deletedStates[t][n])for(var a in this.deletedStates[t][n]={},this.state[t][n])r[a]||(this.deletedStates[t][n][a]=null);else for(var o in r)this.deletedStates[t]&&this.deletedStates[t][n]&&null===this.deletedStates[t][n][o]&&delete this.deletedStates[t][n][o]},jl.prototype.removeFeatureState=function(t,e,r){if(null!==this.deletedStates[t]){var n=String(e);if(this.deletedStates[t]=this.deletedStates[t]||{},r&&void 0!==e&&e>=0)null!==this.deletedStates[t][n]&&(this.deletedStates[t][n]=this.deletedStates[t][n]||{},this.deletedStates[t][n][r]=null);else if(void 0!==e&&e>=0)if(this.stateChanges[t]&&this.stateChanges[t][n])for(r in this.deletedStates[t][n]={},this.stateChanges[t][n])this.deletedStates[t][n][r]=null;else this.deletedStates[t][n]=null;else this.deletedStates[t]=null}},jl.prototype.getState=function(t,e){var r=String(e),n=this.state[t]||{},i=this.stateChanges[t]||{},a=h({},n[r],i[r]);if(null===this.deletedStates[t])return{};if(this.deletedStates[t]){var o=this.deletedStates[t][e];if(null===o)return{};for(var s in o)delete a[s]}return a},jl.prototype.initializeTileState=function(t,e){t.setFeatureState(this.state,e)},jl.prototype.coalesceChanges=function(t,e){var r={};for(var n in this.stateChanges){this.state[n]=this.state[n]||{};var i={};for(var a in this.stateChanges[n])this.state[n][a]||(this.state[n][a]={}),h(this.state[n][a],this.stateChanges[n][a]),i[a]=this.state[n][a];r[n]=i}for(var o in this.deletedStates){this.state[o]=this.state[o]||{};var s={};if(null===this.deletedStates[o])for(var l in this.state[o])s[l]={},this.state[o][l]={};else for(var c in this.deletedStates[o]){if(null===this.deletedStates[o][c])this.state[o][c]={};else for(var u=0,f=Object.keys(this.deletedStates[o][c]);u<f.length;u+=1){var p=f[u];delete this.state[o][c][p]}s[c]=this.state[o][c]}r[o]=r[o]||{},h(r[o],s)}if(this.stateChanges={},this.deletedStates={},0!==Object.keys(r).length)for(var d in t)t[d].setFeatureState(r,e)};var Ul=function(t,e,r){this.tileID=t,this.x=t.canonical.x,this.y=t.canonical.y,this.z=t.canonical.z,this.grid=e||new yn(ha,16,0),this.grid3D=new yn(ha,16,0),this.featureIndexArray=r||new ji};function Vl(t){for(var e=1/0,r=1/0,n=-1/0,i=-1/0,a=0,o=t;a<o.length;a+=1){var s=o[a];e=Math.min(e,s.x),r=Math.min(r,s.y),n=Math.max(n,s.x),i=Math.max(i,s.y)}return{minX:e,minY:r,maxX:n,maxY:i}}function ql(t,e){return e-t}Ul.prototype.insert=function(t,e,r,n,i,a){var o=this.featureIndexArray.length;this.featureIndexArray.emplaceBack(r,n,i);for(var s=a?this.grid3D:this.grid,l=0;l<e.length;l++){for(var c=e[l],u=[1/0,1/0,-1/0,-1/0],h=0;h<c.length;h++){var f=c[h];u[0]=Math.min(u[0],f.x),u[1]=Math.min(u[1],f.y),u[2]=Math.max(u[2],f.x),u[3]=Math.max(u[3],f.y)}u[0]<ha&&u[1]<ha&&u[2]>=0&&u[3]>=0&&s.insert(o,u[0],u[1],u[2],u[3])}},Ul.prototype.loadVTLayers=function(){return this.vtLayers||(this.vtLayers=new Vo.VectorTile(new Qs(this.rawTileData)).layers,this.sourceLayerCoder=new Fl(this.vtLayers?Object.keys(this.vtLayers).sort():[\"_geojsonTileLayer\"])),this.vtLayers},Ul.prototype.query=function(t,e,r){var n=this;this.loadVTLayers();for(var a=t.params||{},o=ha/t.tileSize/t.scale,s=Gr(a.filter),l=t.queryGeometry,c=t.queryPadding*o,u=Vl(l),h=this.grid.query(u.minX-c,u.minY-c,u.maxX+c,u.maxY+c),f=Vl(t.cameraQueryGeometry),p=0,d=this.grid3D.query(f.minX-c,f.minY-c,f.maxX+c,f.maxY+c,function(e,r,n,a){return function(t,e,r,n,a){for(var o=0,s=t;o<s.length;o+=1){var l=s[o];if(e<=l.x&&r<=l.y&&n>=l.x&&a>=l.y)return!0}var c=[new i(e,r),new i(e,a),new i(n,a),new i(n,r)];if(t.length>2)for(var u=0,h=c;u<h.length;u+=1)if(Aa(t,h[u]))return!0;for(var f=0;f<t.length-1;f++)if(Ma(t[f],t[f+1],c))return!0;return!1}(t.cameraQueryGeometry,e-c,r-c,n+c,a+c)});p<d.length;p+=1){var g=d[p];h.push(g)}h.sort(ql);for(var v,m={},y=function(i){var c=h[i];if(c!==v){v=c;var u=n.featureIndexArray.get(c),f=null;n.loadMatchingFeature(m,u.bucketIndex,u.sourceLayerIndex,u.featureIndex,s,a.layers,e,function(e,i){f||(f=pa(e));var a={};return e.id&&(a=r.getState(i.sourceLayer||\"_geojsonTileLayer\",e.id)),i.queryIntersectsFeature(l,e,a,f,n.z,t.transform,o,t.pixelPosMatrix)})}},x=0;x<h.length;x++)y(x);return m},Ul.prototype.loadMatchingFeature=function(t,e,r,n,i,a,o,s){var l=this.bucketLayerIDs[e];if(!a||function(t,e){for(var r=0;r<t.length;r++)if(e.indexOf(t[r])>=0)return!0;return!1}(a,l)){var c=this.sourceLayerCoder.decode(r),u=this.vtLayers[c].feature(n);if(i(new Un(this.tileID.overscaledZ),u))for(var h=0;h<l.length;h++){var f=l[h];if(!(a&&a.indexOf(f)<0)){var p=o[f];if(p){var d=!s||s(u,p);if(d){var g=new Bl(u,this.z,this.x,this.y);g.layer=p.serialize();var v=t[f];void 0===v&&(v=t[f]=[]),v.push({featureIndex:n,feature:g,intersectionZ:d})}}}}}},Ul.prototype.lookupSymbolFeatures=function(t,e,r,n,i,a){var o={};this.loadVTLayers();for(var s=Gr(n),l=0,c=t;l<c.length;l+=1){var u=c[l];this.loadMatchingFeature(o,e,r,u,s,i,a)}return o},Ul.prototype.hasLayer=function(t){for(var e=0,r=this.bucketLayerIDs;e<r.length;e+=1)for(var n=0,i=r[e];n<i.length;n+=1)if(t===i[n])return!0;return!1},kn(\"FeatureIndex\",Ul,{omit:[\"rawTileData\",\"sourceLayerCoder\"]});var Hl=function(t,e){this.tileID=t,this.uid=p(),this.uses=0,this.tileSize=e,this.buckets={},this.expirationTime=null,this.queryPadding=0,this.hasSymbolBuckets=!1,this.expiredRequestCount=0,this.state=\"loading\"};Hl.prototype.registerFadeDuration=function(t){var e=t+this.timeAdded;e<z.now()||this.fadeEndTime&&e<this.fadeEndTime||(this.fadeEndTime=e)},Hl.prototype.wasRequested=function(){return\"errored\"===this.state||\"loaded\"===this.state||\"reloading\"===this.state},Hl.prototype.loadVectorData=function(t,e,r){if(this.hasData()&&this.unloadVectorData(),this.state=\"loaded\",t){for(var n in t.featureIndex&&(this.latestFeatureIndex=t.featureIndex,t.rawTileData?(this.latestRawTileData=t.rawTileData,this.latestFeatureIndex.rawTileData=t.rawTileData):this.latestRawTileData&&(this.latestFeatureIndex.rawTileData=this.latestRawTileData)),this.collisionBoxArray=t.collisionBoxArray,this.buckets=function(t,e){var r={};if(!e)return r;for(var n=function(){var t=a[i],n=t.layerIds.map(function(t){return e.getLayer(t)}).filter(Boolean);if(0!==n.length){t.layers=n,t.stateDependentLayerIds&&(t.stateDependentLayers=t.stateDependentLayerIds.map(function(t){return n.filter(function(e){return e.id===t})[0]}));for(var o=0,s=n;o<s.length;o+=1){var l=s[o];r[l.id]=t}}},i=0,a=t;i<a.length;i+=1)n();return r}(t.buckets,e.style),this.hasSymbolBuckets=!1,this.buckets){var i=this.buckets[n];if(i instanceof Os){if(this.hasSymbolBuckets=!0,!r)break;i.justReloaded=!0}}for(var a in this.queryPadding=0,this.buckets){var o=this.buckets[a];this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(a).queryRadius(o))}t.imageAtlas&&(this.imageAtlas=t.imageAtlas),t.glyphAtlasImage&&(this.glyphAtlasImage=t.glyphAtlasImage)}else this.collisionBoxArray=new Li},Hl.prototype.unloadVectorData=function(){for(var t in this.buckets)this.buckets[t].destroy();this.buckets={},this.imageAtlasTexture&&this.imageAtlasTexture.destroy(),this.imageAtlas&&(this.imageAtlas=null),this.glyphAtlasTexture&&this.glyphAtlasTexture.destroy(),this.latestFeatureIndex=null,this.state=\"unloaded\"},Hl.prototype.unloadDEMData=function(){this.dem=null,this.neighboringTiles=null,this.state=\"unloaded\"},Hl.prototype.getBucket=function(t){return this.buckets[t.id]},Hl.prototype.upload=function(t){for(var e in this.buckets){var r=this.buckets[e];r.uploadPending()&&r.upload(t)}var n=t.gl;this.imageAtlas&&!this.imageAtlas.uploaded&&(this.imageAtlasTexture=new Js(t,this.imageAtlas.image,n.RGBA),this.imageAtlas.uploaded=!0),this.glyphAtlasImage&&(this.glyphAtlasTexture=new Js(t,this.glyphAtlasImage,n.ALPHA),this.glyphAtlasImage=null)},Hl.prototype.prepare=function(t){this.imageAtlas&&this.imageAtlas.patchUpdatedImages(t,this.imageAtlasTexture)},Hl.prototype.queryRenderedFeatures=function(t,e,r,n,i,a,o,s,l){return this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData?this.latestFeatureIndex.query({queryGeometry:r,cameraQueryGeometry:n,scale:i,tileSize:this.tileSize,pixelPosMatrix:l,transform:o,params:a,queryPadding:this.queryPadding*s},t,e):{}},Hl.prototype.querySourceFeatures=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData){var r=this.latestFeatureIndex.loadVTLayers(),n=e?e.sourceLayer:\"\",i=r._geojsonTileLayer||r[n];if(i)for(var a=Gr(e&&e.filter),o=this.tileID.canonical,s=o.z,l=o.x,c=o.y,u={z:s,x:l,y:c},h=0;h<i.length;h++){var f=i.feature(h);if(a(new Un(this.tileID.overscaledZ),f)){var p=new Bl(f,s,l,c);p.tile=u,t.push(p)}}}},Hl.prototype.clearMask=function(){this.segments&&(this.segments.destroy(),delete this.segments),this.maskedBoundsBuffer&&(this.maskedBoundsBuffer.destroy(),delete this.maskedBoundsBuffer),this.maskedIndexBuffer&&(this.maskedIndexBuffer.destroy(),delete this.maskedIndexBuffer)},Hl.prototype.setMask=function(t,e){if(!o(this.mask,t)&&(this.mask=t,this.clearMask(),!o(t,{0:!0}))){var r=new ci,n=new Ti;this.segments=new Vi,this.segments.prepareSegment(0,r,n);for(var a=Object.keys(t),s=0;s<a.length;s++){var l=t[+a[s]],c=ha>>l.z,u=new i(l.x*c,l.y*c),h=new i(u.x+c,u.y+c),f=this.segments.prepareSegment(4,r,n);r.emplaceBack(u.x,u.y,u.x,u.y),r.emplaceBack(h.x,u.y,h.x,u.y),r.emplaceBack(u.x,h.y,u.x,h.y),r.emplaceBack(h.x,h.y,h.x,h.y);var p=f.vertexLength;n.emplaceBack(p,p+1,p+2),n.emplaceBack(p+1,p+2,p+3),f.vertexLength+=4,f.primitiveLength+=2}this.maskedBoundsBuffer=e.createVertexBuffer(r,Rl.members),this.maskedIndexBuffer=e.createIndexBuffer(n)}},Hl.prototype.hasData=function(){return\"loaded\"===this.state||\"reloading\"===this.state||\"expired\"===this.state},Hl.prototype.patternsLoaded=function(){return this.imageAtlas&&!!Object.keys(this.imageAtlas.patternPositions).length},Hl.prototype.setExpiryData=function(t){var e=this.expirationTime;if(t.cacheControl){var r=A(t.cacheControl);r[\"max-age\"]&&(this.expirationTime=Date.now()+1e3*r[\"max-age\"])}else t.expires&&(this.expirationTime=new Date(t.expires).getTime());if(this.expirationTime){var n=Date.now(),i=!1;if(this.expirationTime>n)i=!1;else if(e)if(this.expirationTime<e)i=!0;else{var a=this.expirationTime-e;a?this.expirationTime=n+Math.max(a,3e4):i=!0}else i=!0;i?(this.expiredRequestCount++,this.state=\"expired\"):this.expiredRequestCount=0}},Hl.prototype.getExpiryTimeout=function(){if(this.expirationTime)return this.expiredRequestCount?1e3*(1<<Math.min(this.expiredRequestCount-1,31)):Math.min(this.expirationTime-(new Date).getTime(),Math.pow(2,31)-1)},Hl.prototype.setFeatureState=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData&&0!==Object.keys(t).length){var r=this.latestFeatureIndex.loadVTLayers();for(var n in this.buckets){var i=this.buckets[n],a=i.layers[0].sourceLayer||\"_geojsonTileLayer\",o=r[a],s=t[a];o&&s&&0!==Object.keys(s).length&&(i.update(s,o,this.imageAtlas&&this.imageAtlas.patternPositions||{}),e&&e.style&&(this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(n).queryRadius(i))))}}},Hl.prototype.holdingForFade=function(){return void 0!==this.symbolFadeHoldUntil},Hl.prototype.symbolFadeFinished=function(){return!this.symbolFadeHoldUntil||this.symbolFadeHoldUntil<z.now()},Hl.prototype.clearFadeHold=function(){this.symbolFadeHoldUntil=void 0},Hl.prototype.setHoldDuration=function(t){this.symbolFadeHoldUntil=z.now()+t};var Gl=24,Yl={horizontal:1,vertical:2,horizontalOnly:3},Wl=function(){this.text=\"\",this.sectionIndex=[],this.sections=[]};function Xl(t,e,r,n,i,a,o,s,l,c){var u,h=Wl.fromFeature(t,r);c===Yl.vertical&&h.verticalizePunctuation();var f=jn.processBidirectionalText,p=jn.processStyledBidirectionalText;if(f&&1===h.sections.length){u=[];for(var d=0,g=f(h.toString(),tc(h,s,n,e));d<g.length;d+=1){var v=g[d],m=new Wl;m.text=v,m.sections=h.sections;for(var y=0;y<v.length;y++)m.sectionIndex.push(0);u.push(m)}}else if(p){u=[];for(var x=0,b=p(h.text,h.sectionIndex,tc(h,s,n,e));x<b.length;x+=1){var _=b[x],w=new Wl;w.text=_[0],w.sectionIndex=_[1],w.sections=h.sections,u.push(w)}}else u=function(t,e){for(var r=[],n=t.text,i=0,a=0,o=e;a<o.length;a+=1){var s=o[a];r.push(t.substring(i,s)),i=s}return i<n.length&&r.push(t.substring(i,n.length)),r}(h,tc(h,s,n,e));var k=[],T={positionedGlyphs:k,text:h.toString(),top:l[1],bottom:l[1],left:l[0],right:l[0],writingMode:c,lineCount:u.length};return function(t,e,r,n,i,a,o,s){for(var l=0,c=-17,u=0,h=t.positionedGlyphs,f=\"right\"===a?1:\"left\"===a?0:.5,p=0,d=r;p<d.length;p+=1){var g=d[p];g.trim();var v=g.getMaxScale();if(g.length()){for(var m=h.length,y=0;y<g.length();y++){var x=g.getSection(y),b=g.getCharCode(y),_=24*(v-x.scale),w=e[x.fontStack],k=w&&w[b];k&&(On(b)&&o!==Yl.horizontal?(h.push({glyph:b,x:l,y:_,vertical:!0,scale:x.scale,fontStack:x.fontStack}),l+=Gl*x.scale+s):(h.push({glyph:b,x:l,y:c+_,vertical:!1,scale:x.scale,fontStack:x.fontStack}),l+=k.metrics.advance*x.scale+s))}if(h.length!==m){var T=l-s;u=Math.max(T,u),rc(h,e,m,h.length-1,f)}l=0,c+=n*v}else c+=n}var A=ec(i),M=A.horizontalAlign,S=A.verticalAlign;!function(t,e,r,n,i,a,o){for(var s=(e-r)*i,l=(-n*o+.5)*a,c=0;c<t.length;c++)t[c].x+=s,t[c].y+=l}(h,f,M,S,u,n,r.length);var E=c- -17;t.top+=-S*E,t.bottom=t.top+E,t.left+=-M*u,t.right=t.left+u}(T,e,u,i,a,o,c,s),!!k.length&&T}Wl.fromFeature=function(t,e){for(var r=new Wl,n=0;n<t.sections.length;n++){var i=t.sections[n];r.sections.push({scale:i.scale||1,fontStack:i.fontStack||e}),r.text+=i.text;for(var a=0;a<i.text.length;a++)r.sectionIndex.push(n)}return r},Wl.prototype.length=function(){return this.text.length},Wl.prototype.getSection=function(t){return this.sections[this.sectionIndex[t]]},Wl.prototype.getCharCode=function(t){return this.text.charCodeAt(t)},Wl.prototype.verticalizePunctuation=function(){this.text=function(t){for(var e=\"\",r=0;r<t.length;r++){var n=t.charCodeAt(r+1)||null,i=t.charCodeAt(r-1)||null;n&&zn(n)&&!xs[t[r+1]]||i&&zn(i)&&!xs[t[r-1]]||!xs[t[r]]?e+=t[r]:e+=xs[t[r]]}return e}(this.text)},Wl.prototype.trim=function(){for(var t=0,e=0;e<this.text.length&&Zl[this.text.charCodeAt(e)];e++)t++;for(var r=this.text.length,n=this.text.length-1;n>=0&&n>=t&&Zl[this.text.charCodeAt(n)];n--)r--;this.text=this.text.substring(t,r),this.sectionIndex=this.sectionIndex.slice(t,r)},Wl.prototype.substring=function(t,e){var r=new Wl;return r.text=this.text.substring(t,e),r.sectionIndex=this.sectionIndex.slice(t,e),r.sections=this.sections,r},Wl.prototype.toString=function(){return this.text},Wl.prototype.getMaxScale=function(){var t=this;return this.sectionIndex.reduce(function(e,r){return Math.max(e,t.sections[r].scale)},0)};var Zl={9:!0,10:!0,11:!0,12:!0,13:!0,32:!0},Jl={};function Kl(t,e,r,n){var i=Math.pow(t-e,2);return n?t<e?i/2:2*i:i+Math.abs(r)*r}function $l(t,e,r){var n=0;return 10===t&&(n-=1e4),r&&(n+=150),40!==t&&65288!==t||(n+=50),41!==e&&65289!==e||(n+=50),n}function Ql(t,e,r,n,i,a){for(var o=null,s=Kl(e,r,i,a),l=0,c=n;l<c.length;l+=1){var u=c[l],h=Kl(e-u.x,r,i,a)+u.badness;h<=s&&(o=u,s=h)}return{index:t,x:e,priorBreak:o,badness:s}}function tc(t,e,r,n){if(!r)return[];if(!t)return[];for(var i,a=[],o=function(t,e,r,n){for(var i=0,a=0;a<t.length();a++){var o=t.getSection(a),s=n[o.fontStack],l=s&&s[t.getCharCode(a)];l&&(i+=l.metrics.advance*o.scale+e)}return i/Math.max(1,Math.ceil(i/r))}(t,e,r,n),s=t.text.indexOf(\"\\u200b\")>=0,l=0,c=0;c<t.length();c++){var u=t.getSection(c),h=t.getCharCode(c),f=n[u.fontStack],p=f&&f[h];if(p&&!Zl[h]&&(l+=p.metrics.advance*u.scale+e),c<t.length()-1){var d=!((i=h)<11904||!(En[\"Bopomofo Extended\"](i)||En.Bopomofo(i)||En[\"CJK Compatibility Forms\"](i)||En[\"CJK Compatibility Ideographs\"](i)||En[\"CJK Compatibility\"](i)||En[\"CJK Radicals Supplement\"](i)||En[\"CJK Strokes\"](i)||En[\"CJK Symbols and Punctuation\"](i)||En[\"CJK Unified Ideographs Extension A\"](i)||En[\"CJK Unified Ideographs\"](i)||En[\"Enclosed CJK Letters and Months\"](i)||En[\"Halfwidth and Fullwidth Forms\"](i)||En.Hiragana(i)||En[\"Ideographic Description Characters\"](i)||En[\"Kangxi Radicals\"](i)||En[\"Katakana Phonetic Extensions\"](i)||En.Katakana(i)||En[\"Vertical Forms\"](i)||En[\"Yi Radicals\"](i)||En[\"Yi Syllables\"](i)));(Jl[h]||d)&&a.push(Ql(c+1,l,o,a,$l(h,t.getCharCode(c+1),d&&s),!1))}}return function t(e){return e?t(e.priorBreak).concat(e.index):[]}(Ql(t.length(),l,o,a,0,!0))}function ec(t){var e=.5,r=.5;switch(t){case\"right\":case\"top-right\":case\"bottom-right\":e=1;break;case\"left\":case\"top-left\":case\"bottom-left\":e=0}switch(t){case\"bottom\":case\"bottom-right\":case\"bottom-left\":r=1;break;case\"top\":case\"top-right\":case\"top-left\":r=0}return{horizontalAlign:e,verticalAlign:r}}function rc(t,e,r,n,i){if(i){var a=t[n],o=e[a.fontStack],s=o&&o[a.glyph];if(s)for(var l=s.metrics.advance*a.scale,c=(t[n].x+l)*i,u=r;u<=n;u++)t[u].x-=c}}function nc(t,e,r){var n=ec(r),i=n.horizontalAlign,a=n.verticalAlign,o=e[0],s=e[1],l=o-t.displaySize[0]*i,c=l+t.displaySize[0],u=s-t.displaySize[1]*a;return{image:t,top:u,bottom:u+t.displaySize[1],left:l,right:c}}function ic(t,e,r,n,i){if(void 0===e.segment)return!0;for(var a=e,o=e.segment+1,s=0;s>-r/2;){if(--o<0)return!1;s-=t[o].dist(a),a=t[o]}s+=t[o].dist(t[o+1]),o++;for(var l=[],c=0;s<r/2;){var u=t[o-1],h=t[o],f=t[o+1];if(!f)return!1;var p=u.angleTo(h)-h.angleTo(f);for(p=Math.abs((p+3*Math.PI)%(2*Math.PI)-Math.PI),l.push({distance:s,angleDelta:p}),c+=p;s-l[0].distance>n;)c-=l.shift().angleDelta;if(c>i)return!1;o++,s+=h.dist(f)}return!0}function ac(t){for(var e=0,r=0;r<t.length-1;r++)e+=t[r].dist(t[r+1]);return e}function oc(t,e,r){return t?.6*e*r:0}function sc(t,e){return Math.max(t?t.right-t.left:0,e?e.right-e.left:0)}function lc(t,e,r,n,i,a){for(var o=oc(r,i,a),s=sc(r,n)*a,l=0,c=ac(t)/2,u=0;u<t.length-1;u++){var h=t[u],f=t[u+1],p=h.dist(f);if(l+p>c){var d=(c-l)/p,g=Ee(h.x,f.x,d),v=Ee(h.y,f.y,d),m=new bs(g,v,f.angleTo(h),u);return m._round(),!o||ic(t,m,s,o,e)?m:void 0}l+=p}}function cc(t,e,r,n,i,a,o,s,l){var c=oc(n,a,o),u=sc(n,i),h=u*o,f=0===t[0].x||t[0].x===l||0===t[0].y||t[0].y===l;return e-h<e/4&&(e=h+e/4),function t(e,r,n,i,a,o,s,l,c){for(var u=o/2,h=ac(e),f=0,p=r-n,d=[],g=0;g<e.length-1;g++){for(var v=e[g],m=e[g+1],y=v.dist(m),x=m.angleTo(v);p+n<f+y;){var b=((p+=n)-f)/y,_=Ee(v.x,m.x,b),w=Ee(v.y,m.y,b);if(_>=0&&_<c&&w>=0&&w<c&&p-u>=0&&p+u<=h){var k=new bs(_,w,x,g);k._round(),i&&!ic(e,k,o,i,a)||d.push(k)}}f+=y}return l||d.length||s||(d=t(e,f/2,n,i,a,o,s,!0,c)),d}(t,f?e/2*s%e:(u/2+2*a)*o*s%e,e,c,r,h,f,!1,l)}Jl[10]=!0,Jl[32]=!0,Jl[38]=!0,Jl[40]=!0,Jl[41]=!0,Jl[43]=!0,Jl[45]=!0,Jl[47]=!0,Jl[173]=!0,Jl[183]=!0,Jl[8203]=!0,Jl[8208]=!0,Jl[8211]=!0,Jl[8231]=!0;var uc=function(t,e,r,n,a,o,s,l,c,u,h,f){var p=s.top*l-c,d=s.bottom*l+c,g=s.left*l-c,v=s.right*l+c;if(this.boxStartIndex=t.length,u){var m=d-p,y=v-g;m>0&&(m=Math.max(10*l,m),this._addLineCollisionCircles(t,e,r,r.segment,y,m,n,a,o,h))}else{if(f){var x=new i(g,p),b=new i(v,p),_=new i(g,d),w=new i(v,d),k=f*Math.PI/180;x._rotate(k),b._rotate(k),_._rotate(k),w._rotate(k),g=Math.min(x.x,b.x,_.x,w.x),v=Math.max(x.x,b.x,_.x,w.x),p=Math.min(x.y,b.y,_.y,w.y),d=Math.max(x.y,b.y,_.y,w.y)}t.emplaceBack(r.x,r.y,g,p,v,d,n,a,o,0,0)}this.boxEndIndex=t.length};uc.prototype._addLineCollisionCircles=function(t,e,r,n,i,a,o,s,l,c){var u=a/2,h=Math.floor(i/u)||1,f=1+.4*Math.log(c)/Math.LN2,p=Math.floor(h*f/2),d=-a/2,g=r,v=n+1,m=d,y=-i/2,x=y-i/4;do{if(--v<0){if(m>y)return;v=0;break}m-=e[v].dist(g),g=e[v]}while(m>x);for(var b=e[v].dist(e[v+1]),_=-p;_<h+p;_++){var w=_*u,k=y+w;if(w<0&&(k+=w),w>i&&(k+=w-i),!(k<m)){for(;m+b<k;){if(m+=b,++v+1>=e.length)return;b=e[v].dist(e[v+1])}var T=k-m,A=e[v],M=e[v+1].sub(A)._unit()._mult(T)._add(A)._round(),S=Math.abs(k-d)<u?0:.8*(k-d);t.emplaceBack(M.x,M.y,-a/2,-a/2,a/2,a/2,o,s,l,a/2,S)}}};var hc=function(t,e){if(void 0===t&&(t=[]),void 0===e&&(e=fc),this.data=t,this.length=this.data.length,this.compare=e,this.length>0)for(var r=(this.length>>1)-1;r>=0;r--)this._down(r)};function fc(t,e){return t<e?-1:t>e?1:0}function pc(t,e,r){void 0===e&&(e=1),void 0===r&&(r=!1);for(var n=1/0,a=1/0,o=-1/0,s=-1/0,l=t[0],c=0;c<l.length;c++){var u=l[c];(!c||u.x<n)&&(n=u.x),(!c||u.y<a)&&(a=u.y),(!c||u.x>o)&&(o=u.x),(!c||u.y>s)&&(s=u.y)}var h=o-n,f=s-a,p=Math.min(h,f),d=p/2,g=new hc([],dc);if(0===p)return new i(n,a);for(var v=n;v<o;v+=p)for(var m=a;m<s;m+=p)g.push(new gc(v+d,m+d,d,t));for(var y=function(t){for(var e=0,r=0,n=0,i=t[0],a=0,o=i.length,s=o-1;a<o;s=a++){var l=i[a],c=i[s],u=l.x*c.y-c.x*l.y;r+=(l.x+c.x)*u,n+=(l.y+c.y)*u,e+=3*u}return new gc(r/e,n/e,0,t)}(t),x=g.length;g.length;){var b=g.pop();(b.d>y.d||!y.d)&&(y=b,r&&console.log(\"found best %d after %d probes\",Math.round(1e4*b.d)/1e4,x)),b.max-y.d<=e||(d=b.h/2,g.push(new gc(b.p.x-d,b.p.y-d,d,t)),g.push(new gc(b.p.x+d,b.p.y-d,d,t)),g.push(new gc(b.p.x-d,b.p.y+d,d,t)),g.push(new gc(b.p.x+d,b.p.y+d,d,t)),x+=4)}return r&&(console.log(\"num probes: \"+x),console.log(\"best distance: \"+y.d)),y.p}function dc(t,e){return e.max-t.max}function gc(t,e,r,n){this.p=new i(t,e),this.h=r,this.d=function(t,e){for(var r=!1,n=1/0,i=0;i<e.length;i++)for(var a=e[i],o=0,s=a.length,l=s-1;o<s;l=o++){var c=a[o],u=a[l];c.y>t.y!=u.y>t.y&&t.x<(u.x-c.x)*(t.y-c.y)/(u.y-c.y)+c.x&&(r=!r),n=Math.min(n,ka(t,c,u))}return(r?1:-1)*Math.sqrt(n)}(this.p,n),this.max=this.d+this.h*Math.SQRT2}hc.prototype.push=function(t){this.data.push(t),this.length++,this._up(this.length-1)},hc.prototype.pop=function(){if(0!==this.length){var t=this.data[0];return this.length--,this.length>0&&(this.data[0]=this.data[this.length],this._down(0)),this.data.pop(),t}},hc.prototype.peek=function(){return this.data[0]},hc.prototype._up=function(t){for(var e=this.data,r=this.compare,n=e[t];t>0;){var i=t-1>>1,a=e[i];if(r(n,a)>=0)break;e[t]=a,t=i}e[t]=n},hc.prototype._down=function(t){for(var e=this.data,r=this.compare,n=this.length>>1,i=e[t];t<n;){var a=1+(t<<1),o=e[a],s=a+1;if(s<this.length&&r(e[s],o)<0&&(a=s,o=e[s]),r(o,i)>=0)break;e[t]=o,t=a}e[t]=i};var vc=e(function(t){t.exports=function(t,e){var r,n,i,a,o,s,l,c;for(r=3&t.length,n=t.length-r,i=e,o=3432918353,s=461845907,c=0;c<n;)l=255&t.charCodeAt(c)|(255&t.charCodeAt(++c))<<8|(255&t.charCodeAt(++c))<<16|(255&t.charCodeAt(++c))<<24,++c,i=27492+(65535&(a=5*(65535&(i=(i^=l=(65535&(l=(l=(65535&l)*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295)<<13|i>>>19))+((5*(i>>>16)&65535)<<16)&4294967295))+((58964+(a>>>16)&65535)<<16);switch(l=0,r){case 3:l^=(255&t.charCodeAt(c+2))<<16;case 2:l^=(255&t.charCodeAt(c+1))<<8;case 1:i^=l=(65535&(l=(l=(65535&(l^=255&t.charCodeAt(c)))*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295}return i^=t.length,i=2246822507*(65535&(i^=i>>>16))+((2246822507*(i>>>16)&65535)<<16)&4294967295,i=3266489909*(65535&(i^=i>>>13))+((3266489909*(i>>>16)&65535)<<16)&4294967295,(i^=i>>>16)>>>0}}),mc=e(function(t){t.exports=function(t,e){for(var r,n=t.length,i=e^n,a=0;n>=4;)r=1540483477*(65535&(r=255&t.charCodeAt(a)|(255&t.charCodeAt(++a))<<8|(255&t.charCodeAt(++a))<<16|(255&t.charCodeAt(++a))<<24))+((1540483477*(r>>>16)&65535)<<16),i=1540483477*(65535&i)+((1540483477*(i>>>16)&65535)<<16)^(r=1540483477*(65535&(r^=r>>>24))+((1540483477*(r>>>16)&65535)<<16)),n-=4,++a;switch(n){case 3:i^=(255&t.charCodeAt(a+2))<<16;case 2:i^=(255&t.charCodeAt(a+1))<<8;case 1:i=1540483477*(65535&(i^=255&t.charCodeAt(a)))+((1540483477*(i>>>16)&65535)<<16)}return i=1540483477*(65535&(i^=i>>>13))+((1540483477*(i>>>16)&65535)<<16),(i^=i>>>15)>>>0}}),yc=vc,xc=vc,bc=mc;yc.murmur3=xc,yc.murmur2=bc;var _c=7;function wc(t,e){var r=0,n=0,i=e/Math.sqrt(2);switch(t){case\"top-right\":case\"top-left\":n=i-_c;break;case\"bottom-right\":case\"bottom-left\":n=-i+_c;break;case\"bottom\":n=-e+_c;break;case\"top\":n=e-_c}switch(t){case\"top-right\":case\"bottom-right\":r=-i;break;case\"top-left\":case\"bottom-left\":r=i;break;case\"left\":r=e;break;case\"right\":r=-e}return[r,n]}function kc(t){switch(t){case\"right\":case\"top-right\":case\"bottom-right\":return\"right\";case\"left\":case\"top-left\":case\"bottom-left\":return\"left\"}return\"center\"}function Tc(t,e,r,n,a,o,s){var l=o.layoutTextSize.evaluate(e,{}),c=o.layoutIconSize.evaluate(e,{}),u=o.textMaxSize.evaluate(e,{});void 0===u&&(u=l);var h=t.layers[0].layout,f=h.get(\"icon-offset\").evaluate(e,{}),p=Sc(r.horizontal),d=l/24,g=t.tilePixelRatio*d,v=t.tilePixelRatio*u/24,m=t.tilePixelRatio*c,y=t.tilePixelRatio*h.get(\"symbol-spacing\"),x=h.get(\"text-padding\")*t.tilePixelRatio,b=h.get(\"icon-padding\")*t.tilePixelRatio,_=h.get(\"text-max-angle\")/180*Math.PI,k=\"map\"===h.get(\"text-rotation-alignment\")&&\"point\"!==h.get(\"symbol-placement\"),T=\"map\"===h.get(\"icon-rotation-alignment\")&&\"point\"!==h.get(\"symbol-placement\"),A=h.get(\"symbol-placement\"),M=y/2,S=function(l,c){c.x<0||c.x>=ha||c.y<0||c.y>=ha||function(t,e,r,n,a,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_){var k,T,A=t.addToLineVertexArray(e,r),M=0,S=0,E=0,C={},L=yc(\"\"),P=(o.layout.get(\"text-radial-offset\").evaluate(x,{})||0)*Gl;for(var O in n.horizontal){var z=n.horizontal[O];if(!k){L=yc(z.text);var I=o.layout.get(\"text-rotate\").evaluate(x,{});k=new uc(s,r,e,l,c,u,z,h,f,p,t.overscaling,I)}var D=1===z.lineCount;if(S+=Mc(t,e,z,o,p,x,d,A,n.vertical?Yl.horizontal:Yl.horizontalOnly,D?Object.keys(n.horizontal):[O],C,b,_),D)break}n.vertical&&(E+=Mc(t,e,n.vertical,o,p,x,d,A,Yl.vertical,[\"vertical\"],C,b,_));var R=k?k.boxStartIndex:t.collisionBoxArray.length,F=k?k.boxEndIndex:t.collisionBoxArray.length;if(a){var B=function(t,e,r,n,a,o){var s,l,c,u,h=e.image,f=r.layout,p=e.top-1/h.pixelRatio,d=e.left-1/h.pixelRatio,g=e.bottom+1/h.pixelRatio,v=e.right+1/h.pixelRatio;if(\"none\"!==f.get(\"icon-text-fit\")&&a){var m=v-d,y=g-p,x=f.get(\"text-size\").evaluate(o,{})/24,b=a.left*x,_=a.right*x,w=a.top*x,k=_-b,T=a.bottom*x-w,A=f.get(\"icon-text-fit-padding\")[0],M=f.get(\"icon-text-fit-padding\")[1],S=f.get(\"icon-text-fit-padding\")[2],E=f.get(\"icon-text-fit-padding\")[3],C=\"width\"===f.get(\"icon-text-fit\")?.5*(T-y):0,L=\"height\"===f.get(\"icon-text-fit\")?.5*(k-m):0,P=\"width\"===f.get(\"icon-text-fit\")||\"both\"===f.get(\"icon-text-fit\")?k:m,O=\"height\"===f.get(\"icon-text-fit\")||\"both\"===f.get(\"icon-text-fit\")?T:y;s=new i(b+L-E,w+C-A),l=new i(b+L+M+P,w+C-A),c=new i(b+L+M+P,w+C+S+O),u=new i(b+L-E,w+C+S+O)}else s=new i(d,p),l=new i(v,p),c=new i(v,g),u=new i(d,g);var z=r.layout.get(\"icon-rotate\").evaluate(o,{})*Math.PI/180;if(z){var I=Math.sin(z),D=Math.cos(z),R=[D,-I,I,D];s._matMult(R),l._matMult(R),u._matMult(R),c._matMult(R)}return[{tl:s,tr:l,bl:u,br:c,tex:h.paddedRect,writingMode:void 0,glyphOffset:[0,0]}]}(0,a,o,0,Sc(n.horizontal),x),N=o.layout.get(\"icon-rotate\").evaluate(x,{});T=new uc(s,r,e,l,c,u,a,g,v,!1,t.overscaling,N),M=4*B.length;var j=t.iconSizeData,U=null;\"source\"===j.kind?(U=[_s*o.layout.get(\"icon-size\").evaluate(x,{})])[0]>Ac&&w(t.layerIds[0]+': Value for \"icon-size\" is >= 256. Reduce your \"icon-size\".'):\"composite\"===j.kind&&((U=[_s*_.compositeIconSizes[0].evaluate(x,{}),_s*_.compositeIconSizes[1].evaluate(x,{})])[0]>Ac||U[1]>Ac)&&w(t.layerIds[0]+': Value for \"icon-size\" is >= 256. Reduce your \"icon-size\".'),t.addSymbols(t.icon,B,U,y,m,x,!1,e,A.lineStartIndex,A.lineLength)}var V=T?T.boxStartIndex:t.collisionBoxArray.length,q=T?T.boxEndIndex:t.collisionBoxArray.length;t.glyphOffsetArray.length>=Os.MAX_GLYPHS&&w(\"Too many glyphs being rendered in a tile. See https://github.com/mapbox/mapbox-gl-js/issues/2907\"),t.symbolInstances.emplaceBack(e.x,e.y,C.right>=0?C.right:-1,C.center>=0?C.center:-1,C.left>=0?C.left:-1,C.vertical||-1,L,R,F,V,q,l,S,E,M,0,h,P)}(t,c,l,r,n,t.layers[0],t.collisionBoxArray,e.index,e.sourceLayerIndex,t.index,g,x,k,s,m,b,T,f,e,a,o)};if(\"line\"===A)for(var E=0,C=function(t,e,r,n,a){for(var o=[],s=0;s<t.length;s++)for(var l=t[s],c=void 0,u=0;u<l.length-1;u++){var h=l[u],f=l[u+1];h.x<0&&f.x<0||(h.x<0?h=new i(0,h.y+(f.y-h.y)*((0-h.x)/(f.x-h.x)))._round():f.x<0&&(f=new i(0,h.y+(f.y-h.y)*((0-h.x)/(f.x-h.x)))._round()),h.y<0&&f.y<0||(h.y<0?h=new i(h.x+(f.x-h.x)*((0-h.y)/(f.y-h.y)),0)._round():f.y<0&&(f=new i(h.x+(f.x-h.x)*((0-h.y)/(f.y-h.y)),0)._round()),h.x>=n&&f.x>=n||(h.x>=n?h=new i(n,h.y+(f.y-h.y)*((n-h.x)/(f.x-h.x)))._round():f.x>=n&&(f=new i(n,h.y+(f.y-h.y)*((n-h.x)/(f.x-h.x)))._round()),h.y>=a&&f.y>=a||(h.y>=a?h=new i(h.x+(f.x-h.x)*((a-h.y)/(f.y-h.y)),a)._round():f.y>=a&&(f=new i(h.x+(f.x-h.x)*((a-h.y)/(f.y-h.y)),a)._round()),c&&h.equals(c[c.length-1])||(c=[h],o.push(c)),c.push(f)))))}return o}(e.geometry,0,0,ha,ha);E<C.length;E+=1)for(var L=C[E],P=0,O=cc(L,y,_,r.vertical||p,n,24,v,t.overscaling,ha);P<O.length;P+=1){var z=O[P];p&&Ec(t,p.text,M,z)||S(L,z)}else if(\"line-center\"===A)for(var I=0,D=e.geometry;I<D.length;I+=1){var R=D[I];if(R.length>1){var F=lc(R,_,r.vertical||p,n,24,v);F&&S(R,F)}}else if(\"Polygon\"===e.type)for(var B=0,N=Mo(e.geometry,0);B<N.length;B+=1){var j=N[B],U=pc(j,16);S(j[0],new bs(U.x,U.y,0))}else if(\"LineString\"===e.type)for(var V=0,q=e.geometry;V<q.length;V+=1){var H=q[V];S(H,new bs(H[0].x,H[0].y,0))}else if(\"Point\"===e.type)for(var G=0,Y=e.geometry;G<Y.length;G+=1)for(var W=0,X=Y[G];W<X.length;W+=1){var Z=X[W];S([Z],new bs(Z.x,Z.y,0))}}var Ac=65535;function Mc(t,e,r,n,a,o,s,l,c,u,h,f,p){var d=function(t,e,r,n,a,o,s){for(var l=n.layout.get(\"text-rotate\").evaluate(o,{})*Math.PI/180,c=e.positionedGlyphs,u=[],h=0;h<c.length;h++){var f=c[h],p=s[f.fontStack],d=p&&p[f.glyph];if(d){var g=d.rect;if(g){var v=bl+1,m=d.metrics.advance*f.scale/2,y=a?[f.x+m,f.y]:[0,0],x=a?[0,0]:[f.x+m+r[0],f.y+r[1]],b=(d.metrics.left-v)*f.scale-m+x[0],_=(-d.metrics.top-v)*f.scale+x[1],w=b+g.w*f.scale,k=_+g.h*f.scale,T=new i(b,_),A=new i(w,_),M=new i(b,k),S=new i(w,k);if(a&&f.vertical){var E=new i(-m,m),C=-Math.PI/2,L=new i(5,0);T._rotateAround(C,E)._add(L),A._rotateAround(C,E)._add(L),M._rotateAround(C,E)._add(L),S._rotateAround(C,E)._add(L)}if(l){var P=Math.sin(l),O=Math.cos(l),z=[O,-P,P,O];T._matMult(z),A._matMult(z),M._matMult(z),S._matMult(z)}u.push({tl:T,tr:A,bl:M,br:S,tex:g,writingMode:e.writingMode,glyphOffset:y})}}}return u}(0,r,s,n,a,o,f),g=t.textSizeData,v=null;\"source\"===g.kind?(v=[_s*n.layout.get(\"text-size\").evaluate(o,{})])[0]>Ac&&w(t.layerIds[0]+': Value for \"text-size\" is >= 256. Reduce your \"text-size\".'):\"composite\"===g.kind&&((v=[_s*p.compositeTextSizes[0].evaluate(o,{}),_s*p.compositeTextSizes[1].evaluate(o,{})])[0]>Ac||v[1]>Ac)&&w(t.layerIds[0]+': Value for \"text-size\" is >= 256. Reduce your \"text-size\".'),t.addSymbols(t.text,d,v,s,a,o,c,e,l.lineStartIndex,l.lineLength);for(var m=0,y=u;m<y.length;m+=1)h[y[m]]=t.text.placedSymbolArray.length-1;return 4*d.length}function Sc(t){for(var e in t)return t[e];return null}function Ec(t,e,r,n){var i=t.compareText;if(e in i){for(var a=i[e],o=a.length-1;o>=0;o--)if(n.dist(a[o])<r)return!0}else i[e]=[];return i[e].push(n),!1}t.Actor=_l,t.AlphaImage=qa,t.CanonicalTileID=Pl,t.CollisionBoxArray=Li,t.Color=ne,t.DEMData=Dl,t.DataConstantProperty=Jn,t.DictionaryCoder=Fl,t.EXTENT=ha,t.ErrorEvent=Ot,t.EvaluationParameters=Un,t.Event=Pt,t.Evented=zt,t.FeatureIndex=Ul,t.FillBucket=Lo,t.FillExtrusionBucket=Yo,t.ImageAtlas=Gs,t.ImagePosition=qs,t.LineBucket=os,t.LngLat=Tl,t.LngLatBounds=kl,t.MercatorCoordinate=Ll,t.ONE_EM=Gl,t.OverscaledTileID=zl,t.Point=i,t.Point$1=i,t.ProgramConfiguration=sa,t.Properties=ei,t.Protobuf=Qs,t.RGBAImage=Ha,t.RequestManager=j,t.ResourceType=yt,t.SegmentVector=Vi,t.SourceFeatureState=jl,t.StructArrayLayout1ui2=Mi,t.StructArrayLayout2i4=li,t.StructArrayLayout2ui4=Ai,t.StructArrayLayout3ui6=Ti,t.StructArrayLayout4i8=ci,t.SymbolBucket=Os,t.Texture=Js,t.Tile=Hl,t.Transitionable=Hn,t.Uniform1f=Xi,t.Uniform1i=Wi,t.Uniform2f=Zi,t.Uniform3f=Ji,t.Uniform4f=Ki,t.UniformColor=$i,t.UniformMatrix4f=ta,t.UnwrappedTileID=Ol,t.ValidationError=Dt,t.WritingMode=Yl,t.ZoomHistory=Sn,t.addDynamicAttributes=Cs,t.asyncAll=function(t,e,r){if(!t.length)return r(null,[]);var n=t.length,i=new Array(t.length),a=null;t.forEach(function(t,o){e(t,function(t,e){t&&(a=t),i[o]=e,0==--n&&r(a,i)})})},t.bezier=s,t.bindAll=v,t.browser=z,t.cacheEntryPossiblyAdded=function(t){++mt>dt&&(t.send(\"enforceCacheSizeLimit\",pt),mt=0)},t.clamp=c,t.clearTileCache=function(t){var e=self.caches.delete(ft);t&&e.catch(t).then(function(){return t()})},t.clone=function(t){var e=new Pa(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e},t.clone$1=b,t.config=I,t.create=function(){var t=new Pa(16);return Pa!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=0,t[12]=0,t[13]=0,t[14]=0),t[0]=1,t[5]=1,t[10]=1,t[15]=1,t},t.create$1=Oa,t.create$2=function(){var t=new Pa(4);return Pa!=Float32Array&&(t[1]=0,t[2]=0),t[0]=1,t[3]=1,t},t.createCommonjsModule=e,t.createExpression=Or,t.createLayout=oi,t.createStyleLayer=function(t){return\"custom\"===t.type?new js(t):new Us[t.type](t)},t.deepEqual=o,t.ease=l,t.emitValidationErrors=mn,t.endsWith=m,t.enforceCacheSizeLimit=function(t){self.caches&&self.caches.open(ft).then(function(e){e.keys().then(function(r){for(var n=0;n<r.length-t;n++)e.delete(r[n])})})},t.evaluateRadialOffset=wc,t.evaluateSizeForFeature=ks,t.evaluateSizeForZoom=Ts,t.evented=Nn,t.extend=h,t.featureFilter=Gr,t.filterObject=x,t.fromRotation=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=r,t[2]=0,t[3]=-r,t[4]=n,t[5]=0,t[6]=0,t[7]=0,t[8]=1,t},t.getAnchorAlignment=ec,t.getAnchorJustification=kc,t.getArrayBuffer=Mt,t.getImage=Et,t.getJSON=function(t,e){return At(h(t,{type:\"json\"}),e)},t.getReferrer=_t,t.getVideo=function(t,e){var r,n,i=self.document.createElement(\"video\");i.muted=!0,i.onloadstart=function(){e(null,i)};for(var a=0;a<t.length;a++){var o=self.document.createElement(\"source\");r=t[a],n=void 0,(n=self.document.createElement(\"a\")).href=r,(n.protocol!==self.document.location.protocol||n.host!==self.document.location.host)&&(i.crossOrigin=\"Anonymous\"),o.src=t[a],i.appendChild(o)}return{cancel:function(){}}},t.identity=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t},t.invert=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],g=e[13],v=e[14],m=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,k=i*c-a*l,T=u*g-h*d,A=u*v-f*d,M=u*m-p*d,S=h*v-f*g,E=h*m-p*g,C=f*m-p*v,L=y*C-x*E+b*S+_*M-w*A+k*T;return L?(L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(i*E-n*C-a*S)*L,t[2]=(g*k-v*w+m*_)*L,t[3]=(f*w-h*k-p*_)*L,t[4]=(l*M-o*C-c*A)*L,t[5]=(r*C-i*M+a*A)*L,t[6]=(v*b-d*k-m*x)*L,t[7]=(u*k-f*b+p*x)*L,t[8]=(o*E-s*M+c*T)*L,t[9]=(n*M-r*E-a*T)*L,t[10]=(d*w-g*b+m*y)*L,t[11]=(h*b-u*w-p*y)*L,t[12]=(s*A-o*S-l*T)*L,t[13]=(r*S-n*A+i*T)*L,t[14]=(g*x-d*_-v*y)*L,t[15]=(u*_-h*x+f*y)*L,t):null},t.isChar=En,t.isMapboxURL=q,t.keysDifference=function(t,e){var r=[];for(var n in t)n in e||r.push(n);return r},t.makeRequest=At,t.mapObject=y,t.mercatorXfromLng=Ml,t.mercatorYfromLat=Sl,t.mercatorZfromAltitude=El,t.multiply=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],g=e[12],v=e[13],m=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*h+w*g,t[1]=x*i+b*l+_*f+w*v,t[2]=x*a+b*c+_*p+w*m,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*h+w*g,t[5]=x*i+b*l+_*f+w*v,t[6]=x*a+b*c+_*p+w*m,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*h+w*g,t[9]=x*i+b*l+_*f+w*v,t[10]=x*a+b*c+_*p+w*m,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*h+w*g,t[13]=x*i+b*l+_*f+w*v,t[14]=x*a+b*c+_*p+w*m,t[15]=x*o+b*u+_*d+w*y,t},t.mvt=Vo,t.number=Ee,t.ortho=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t},t.parseGlyphPBF=function(t){return new Qs(t).readFields(ml,[])},t.pbf=Qs,t.performSymbolLayout=function(t,e,r,n,i,a){t.createArrays();var o=512*t.overscaling;t.tilePixelRatio=ha/o,t.compareText={},t.iconsNeedLinear=!1;var s=t.layers[0].layout,l=t.layers[0]._unevaluatedLayout._values,c={};if(\"composite\"===t.textSizeData.kind){var u=t.textSizeData,h=u.minZoom,f=u.maxZoom;c.compositeTextSizes=[l[\"text-size\"].possiblyEvaluate(new Un(h)),l[\"text-size\"].possiblyEvaluate(new Un(f))]}if(\"composite\"===t.iconSizeData.kind){var p=t.iconSizeData,d=p.minZoom,g=p.maxZoom;c.compositeIconSizes=[l[\"icon-size\"].possiblyEvaluate(new Un(d)),l[\"icon-size\"].possiblyEvaluate(new Un(g))]}c.layoutTextSize=l[\"text-size\"].possiblyEvaluate(new Un(t.zoom+1)),c.layoutIconSize=l[\"icon-size\"].possiblyEvaluate(new Un(t.zoom+1)),c.textMaxSize=l[\"text-size\"].possiblyEvaluate(new Un(18));for(var v=s.get(\"text-line-height\")*Gl,m=\"map\"===s.get(\"text-rotation-alignment\")&&\"point\"!==s.get(\"symbol-placement\"),y=s.get(\"text-keep-upright\"),x=0,b=t.features;x<b.length;x+=1){var _=b[x],k=s.get(\"text-font\").evaluate(_,{}).join(\",\"),T=r,A={horizontal:{},vertical:void 0},M=_.text,S=[0,0];if(M){var E=M.toString(),C=s.get(\"text-letter-spacing\").evaluate(_,{})*Gl,L=Ln(E)?C:0,P=s.get(\"text-anchor\").evaluate(_,{}),O=s.get(\"text-variable-anchor\"),z=s.get(\"text-radial-offset\").evaluate(_,{});O||(S=z?wc(P,z*Gl):s.get(\"text-offset\").evaluate(_,{}).map(function(t){return t*Gl}));var I=m?\"center\":s.get(\"text-justify\").evaluate(_,{}),D=\"point\"===s.get(\"symbol-placement\")?s.get(\"text-max-width\").evaluate(_,{})*Gl:0;if(!m&&O)for(var R=\"auto\"===I?O.map(function(t){return kc(t)}):[I],F=!1,B=0;B<R.length;B++){var N=R[B];if(!A.horizontal[N])if(F)A.horizontal[N]=A.horizontal[0];else{var j=Xl(M,e,k,D,v,\"center\",N,L,S,Yl.horizontal);j&&(A.horizontal[N]=j,F=1===j.lineCount)}}else{\"auto\"===I&&(I=kc(P));var U=Xl(M,e,k,D,v,P,I,L,S,Yl.horizontal);U&&(A.horizontal[I]=U),Cn(E)&&m&&y&&(A.vertical=Xl(M,e,k,D,v,P,I,L,S,Yl.vertical))}}var V=void 0;if(_.icon){var q=n[_.icon];q&&(V=nc(i[_.icon],s.get(\"icon-offset\").evaluate(_,{}),s.get(\"icon-anchor\").evaluate(_,{})),void 0===t.sdfIcons?t.sdfIcons=q.sdf:t.sdfIcons!==q.sdf&&w(\"Style sheet warning: Cannot mix SDF and non-SDF icons in one buffer\"),q.pixelRatio!==t.pixelRatio?t.iconsNeedLinear=!0:0!==s.get(\"icon-rotate\").constantOr(1)&&(t.iconsNeedLinear=!0))}(Object.keys(A.horizontal).length||V)&&Tc(t,_,A,V,T,c,S)}a&&t.generateCollisionDebugBuffers()},t.perspective=function(t,e,r,n,i){var a,o=1/Math.tan(e/2);return t[0]=o/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=o,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=-1,t[12]=0,t[13]=0,t[15]=0,null!=i&&i!==1/0?(a=1/(n-i),t[10]=(i+n)*a,t[14]=2*i*n*a):(t[10]=-1,t[14]=-2*n),t},t.pick=function(t,e){for(var r={},n=0;n<e.length;n++){var i=e[n];i in t&&(r[i]=t[i])}return r},t.plugin=jn,t.polygonIntersectsPolygon=va,t.postMapLoadEvent=ht,t.postTurnstileEvent=ct,t.potpack=Vs,t.rasterBoundsAttributes=Rl,t.refProperties=[\"type\",\"source\",\"source-layer\",\"minzoom\",\"maxzoom\",\"filter\",\"layout\"],t.register=kn,t.registerForPluginAvailability=function(t){return Fn?t({pluginURL:Fn,completionCallback:Dn}):Nn.once(\"pluginAvailable\",t),t},t.rotate=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=Math.sin(r),l=Math.cos(r);return t[0]=n*l+a*s,t[1]=i*l+o*s,t[2]=n*-s+a*l,t[3]=i*-s+o*l,t},t.rotateX=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];return e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+h*n,t[7]=l*i+f*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=h*i-s*n,t[11]=f*i-l*n,t},t.rotateZ=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];return e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+h*n,t[3]=l*i+f*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=h*i-s*n,t[7]=f*i-l*n,t},t.scale=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t},t.setCacheLimits=function(t,e){pt=t,dt=e},t.setRTLTextPlugin=function(t,e){if(Rn)throw new Error(\"setRTLTextPlugin cannot be called multiple times.\");Rn=!0,Fn=z.resolveURL(t),Dn=function(t){t?(Rn=!1,Fn=null,e&&e(t)):Bn=!0},Nn.fire(new Pt(\"pluginAvailable\",{pluginURL:Fn,completionCallback:Dn}))},t.sphericalToCartesian=function(t){var e=t[0],r=t[1],n=t[2];return r+=90,r*=Math.PI/180,n*=Math.PI/180,{x:e*Math.cos(r)*Math.sin(n),y:e*Math.sin(r)*Math.sin(n),z:e*Math.cos(n)}},t.styleSpec=It,t.symbolSize=As,t.transformMat3=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t},t.transformMat4=Da,t.translate=function(t,e,r){var n,i,a,o,s,l,c,u,h,f,p,d,g=r[0],v=r[1],m=r[2];return e===t?(t[12]=e[0]*g+e[4]*v+e[8]*m+e[12],t[13]=e[1]*g+e[5]*v+e[9]*m+e[13],t[14]=e[2]*g+e[6]*v+e[10]*m+e[14],t[15]=e[3]*g+e[7]*v+e[11]*m+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*g+s*v+h*m+e[12],t[13]=i*g+l*v+f*m+e[13],t[14]=a*g+c*v+p*m+e[14],t[15]=o*g+u*v+d*m+e[15]),t},t.uniqueId=p,t.validateCustomStyleLayer=function(t){var e=[],r=t.id;return void 0===r&&e.push({message:\"layers.\"+r+': missing required property \"id\"'}),void 0===t.render&&e.push({message:\"layers.\"+r+': missing required method \"render\"'}),t.renderingMode&&\"2d\"!==t.renderingMode&&\"3d\"!==t.renderingMode&&e.push({message:\"layers.\"+r+': property \"renderingMode\" must be either \"2d\" or \"3d\"'}),e},t.validateLight=dn,t.validateStyle=pn,t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.vectorTile=Vo,t.version=\"1.1.1\",t.warnOnce=w,t.webpSupported=D,t.window=self,t.wrap=u}),n(0,function(t){function e(t){var r=typeof t;if(\"number\"===r||\"boolean\"===r||\"string\"===r||null==t)return JSON.stringify(t);if(Array.isArray(t)){for(var n=\"[\",i=0,a=t;i<a.length;i+=1)n+=e(a[i])+\",\";return n+\"]\"}for(var o=Object.keys(t).sort(),s=\"{\",l=0;l<o.length;l++)s+=JSON.stringify(o[l])+\":\"+e(t[o[l]])+\",\";return s+\"}\"}function r(r){for(var n=\"\",i=0,a=t.refProperties;i<a.length;i+=1)n+=\"/\"+e(r[a[i]]);return n}var n=function(t){this.keyCache={},t&&this.replace(t)};n.prototype.replace=function(t){this._layerConfigs={},this._layers={},this.update(t,[])},n.prototype.update=function(e,n){for(var i=this,a=0,o=e;a<o.length;a+=1){var s=o[a];this._layerConfigs[s.id]=s;var l=this._layers[s.id]=t.createStyleLayer(s);l._featureFilter=t.featureFilter(l.filter),this.keyCache[s.id]&&delete this.keyCache[s.id]}for(var c=0,u=n;c<u.length;c+=1){var h=u[c];delete this.keyCache[h],delete this._layerConfigs[h],delete this._layers[h]}this.familiesBySource={};for(var f=0,p=function(t,e){for(var n={},i=0;i<t.length;i++){var a=e&&e[t[i].id]||r(t[i]);e&&(e[t[i].id]=a);var o=n[a];o||(o=n[a]=[]),o.push(t[i])}var s=[];for(var l in n)s.push(n[l]);return s}(t.values(this._layerConfigs),this.keyCache);f<p.length;f+=1){var d=p[f].map(function(t){return i._layers[t.id]}),g=d[0];if(\"none\"!==g.visibility){var v=g.source||\"\",m=this.familiesBySource[v];m||(m=this.familiesBySource[v]={});var y=g.sourceLayer||\"_geojsonTileLayer\",x=m[y];x||(x=m[y]=[]),x.push(d)}}};var i=function(e){var r={},n=[];for(var i in e){var a=e[i],o=r[i]={};for(var s in a){var l=a[+s];if(l&&0!==l.bitmap.width&&0!==l.bitmap.height){var c={x:0,y:0,w:l.bitmap.width+2,h:l.bitmap.height+2};n.push(c),o[s]={rect:c,metrics:l.metrics}}}}var u=t.potpack(n),h=u.w,f=u.h,p=new t.AlphaImage({width:h||1,height:f||1});for(var d in e){var g=e[d];for(var v in g){var m=g[+v];if(m&&0!==m.bitmap.width&&0!==m.bitmap.height){var y=r[d][v].rect;t.AlphaImage.copy(m.bitmap,p,{x:0,y:0},{x:y.x+1,y:y.y+1},m.bitmap)}}}this.image=p,this.positions=r};t.register(\"GlyphAtlas\",i);var a=function(e){this.tileID=new t.OverscaledTileID(e.tileID.overscaledZ,e.tileID.wrap,e.tileID.canonical.z,e.tileID.canonical.x,e.tileID.canonical.y),this.uid=e.uid,this.zoom=e.zoom,this.pixelRatio=e.pixelRatio,this.tileSize=e.tileSize,this.source=e.source,this.overscaling=this.tileID.overscaleFactor(),this.showCollisionBoxes=e.showCollisionBoxes,this.collectResourceTiming=!!e.collectResourceTiming,this.returnDependencies=!!e.returnDependencies};function o(e,r){for(var n=new t.EvaluationParameters(r),i=0,a=e;i<a.length;i+=1)a[i].recalculate(n)}a.prototype.parse=function(e,r,n,a){var s=this;this.status=\"parsing\",this.data=e,this.collisionBoxArray=new t.CollisionBoxArray;var l=new t.DictionaryCoder(Object.keys(e.layers).sort()),c=new t.FeatureIndex(this.tileID);c.bucketLayerIDs=[];var u,h,f,p,d={},g={featureIndex:c,iconDependencies:{},patternDependencies:{},glyphDependencies:{}},v=r.familiesBySource[this.source];for(var m in v){var y=e.layers[m];if(y){1===y.version&&t.warnOnce('Vector tile source \"'+this.source+'\" layer \"'+m+'\" does not use vector tile spec v2 and therefore may have some rendering errors.');for(var x=l.encode(m),b=[],_=0;_<y.length;_++){var w=y.feature(_);b.push({feature:w,index:_,sourceLayerIndex:x})}for(var k=0,T=v[m];k<T.length;k+=1){var A=T[k],M=A[0];M.minzoom&&this.zoom<Math.floor(M.minzoom)||M.maxzoom&&this.zoom>=M.maxzoom||\"none\"!==M.visibility&&(o(A,this.zoom),(d[M.id]=M.createBucket({index:c.bucketLayerIDs.length,layers:A,zoom:this.zoom,pixelRatio:this.pixelRatio,overscaling:this.overscaling,collisionBoxArray:this.collisionBoxArray,sourceLayerIndex:x,sourceID:this.source})).populate(b,g),c.bucketLayerIDs.push(A.map(function(t){return t.id})))}}}var S=t.mapObject(g.glyphDependencies,function(t){return Object.keys(t).map(Number)});Object.keys(S).length?n.send(\"getGlyphs\",{uid:this.uid,stacks:S},function(t,e){u||(u=t,h=e,L.call(s))}):h={};var E=Object.keys(g.iconDependencies);E.length?n.send(\"getImages\",{icons:E},function(t,e){u||(u=t,f=e,L.call(s))}):f={};var C=Object.keys(g.patternDependencies);function L(){if(u)return a(u);if(h&&f&&p){var e=new i(h),r=new t.ImageAtlas(f,p);for(var n in d){var s=d[n];s instanceof t.SymbolBucket?(o(s.layers,this.zoom),t.performSymbolLayout(s,h,e.positions,f,r.iconPositions,this.showCollisionBoxes)):s.hasPattern&&(s instanceof t.LineBucket||s instanceof t.FillBucket||s instanceof t.FillExtrusionBucket)&&(o(s.layers,this.zoom),s.addFeatures(g,r.patternPositions))}this.status=\"done\",a(null,{buckets:t.values(d).filter(function(t){return!t.isEmpty()}),featureIndex:c,collisionBoxArray:this.collisionBoxArray,glyphAtlasImage:e.image,imageAtlas:r,glyphMap:this.returnDependencies?h:null,iconMap:this.returnDependencies?f:null,glyphPositions:this.returnDependencies?e.positions:null})}}C.length?n.send(\"getImages\",{icons:C},function(t,e){u||(u=t,p=e,L.call(s))}):p={},L.call(this)};var s=\"undefined\"!=typeof performance,l={getEntriesByName:function(t){return!!(s&&performance&&performance.getEntriesByName)&&performance.getEntriesByName(t)},mark:function(t){return!!(s&&performance&&performance.mark)&&performance.mark(t)},measure:function(t,e,r){return!!(s&&performance&&performance.measure)&&performance.measure(t,e,r)},clearMarks:function(t){return!!(s&&performance&&performance.clearMarks)&&performance.clearMarks(t)},clearMeasures:function(t){return!!(s&&performance&&performance.clearMeasures)&&performance.clearMeasures(t)}},c=function(t){this._marks={start:[t.url,\"start\"].join(\"#\"),end:[t.url,\"end\"].join(\"#\"),measure:t.url.toString()},l.mark(this._marks.start)};function u(e,r){var n=t.getArrayBuffer(e.request,function(e,n,i,a){e?r(e):n&&r(null,{vectorTile:new t.vectorTile.VectorTile(new t.pbf(n)),rawData:n,cacheControl:i,expires:a})});return function(){n.cancel(),r()}}c.prototype.finish=function(){l.mark(this._marks.end);var t=l.getEntriesByName(this._marks.measure);return 0===t.length&&(l.measure(this._marks.measure,this._marks.start,this._marks.end),t=l.getEntriesByName(this._marks.measure),l.clearMarks(this._marks.start),l.clearMarks(this._marks.end),l.clearMeasures(this._marks.measure)),t},l.Performance=c;var h=function(t,e,r){this.actor=t,this.layerIndex=e,this.loadVectorData=r||u,this.loading={},this.loaded={}};h.prototype.loadTile=function(e,r){var n=this,i=e.uid;this.loading||(this.loading={});var o=!!(e&&e.request&&e.request.collectResourceTiming)&&new l.Performance(e.request),s=this.loading[i]=new a(e);s.abort=this.loadVectorData(e,function(e,a){if(delete n.loading[i],e||!a)return s.status=\"done\",n.loaded[i]=s,r(e);var l=a.rawData,c={};a.expires&&(c.expires=a.expires),a.cacheControl&&(c.cacheControl=a.cacheControl);var u={};if(o){var h=o.finish();h&&(u.resourceTiming=JSON.parse(JSON.stringify(h)))}s.vectorTile=a.vectorTile,s.parse(a.vectorTile,n.layerIndex,n.actor,function(e,n){if(e||!n)return r(e);r(null,t.extend({rawTileData:l.slice(0)},n,c,u))}),n.loaded=n.loaded||{},n.loaded[i]=s})},h.prototype.reloadTile=function(t,e){var r=this.loaded,n=t.uid,i=this;if(r&&r[n]){var a=r[n];a.showCollisionBoxes=t.showCollisionBoxes;var o=function(t,r){var n=a.reloadCallback;n&&(delete a.reloadCallback,a.parse(a.vectorTile,i.layerIndex,i.actor,n)),e(t,r)};\"parsing\"===a.status?a.reloadCallback=o:\"done\"===a.status&&(a.vectorTile?a.parse(a.vectorTile,this.layerIndex,this.actor,o):o())}},h.prototype.abortTile=function(t,e){var r=this.loading,n=t.uid;r&&r[n]&&r[n].abort&&(r[n].abort(),delete r[n]),e()},h.prototype.removeTile=function(t,e){var r=this.loaded,n=t.uid;r&&r[n]&&delete r[n],e()};var f=function(){this.loaded={}};f.prototype.loadTile=function(e,r){var n=e.uid,i=e.encoding,a=e.rawImageData,o=new t.DEMData(n,a,i);this.loaded=this.loaded||{},this.loaded[n]=o,r(null,o)},f.prototype.removeTile=function(t){var e=this.loaded,r=t.uid;e&&e[r]&&delete e[r]};var p={RADIUS:6378137,FLATTENING:1/298.257223563,POLAR_RADIUS:6356752.3142};function d(t){var e=0;if(t&&t.length>0){e+=Math.abs(g(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(g(t[r]))}return e}function g(t){var e,r,n,i,a,o,s=0,l=t.length;if(l>2){for(o=0;o<l;o++)o===l-2?(n=l-2,i=l-1,a=0):o===l-1?(n=l-1,i=0,a=1):(n=o,i=o+1,a=o+2),e=t[n],r=t[i],s+=(v(t[a][0])-v(e[0]))*Math.sin(v(r[1]));s=s*p.RADIUS*p.RADIUS/2}return s}function v(t){return t*Math.PI/180}var m={geometry:function t(e){var r,n=0;switch(e.type){case\"Polygon\":return d(e.coordinates);case\"MultiPolygon\":for(r=0;r<e.coordinates.length;r++)n+=d(e.coordinates[r]);return n;case\"Point\":case\"MultiPoint\":case\"LineString\":case\"MultiLineString\":return 0;case\"GeometryCollection\":for(r=0;r<e.geometries.length;r++)n+=t(e.geometries[r]);return n}},ring:g};function y(t,e){return function(r){return t(r,e)}}function x(t,e){e=!!e,t[0]=b(t[0],e);for(var r=1;r<t.length;r++)t[r]=b(t[r],!e);return t}function b(t,e){return function(t){return m.ring(t)>=0}(t)===e?t:t.reverse()}var _=t.vectorTile.VectorTileFeature.prototype.toGeoJSON,w=function(e){this._feature=e,this.extent=t.EXTENT,this.type=e.type,this.properties=e.tags,\"id\"in e&&!isNaN(e.id)&&(this.id=parseInt(e.id,10))};w.prototype.loadGeometry=function(){if(1===this._feature.type){for(var e=[],r=0,n=this._feature.geometry;r<n.length;r+=1){var i=n[r];e.push([new t.Point$1(i[0],i[1])])}return e}for(var a=[],o=0,s=this._feature.geometry;o<s.length;o+=1){for(var l=[],c=0,u=s[o];c<u.length;c+=1){var h=u[c];l.push(new t.Point$1(h[0],h[1]))}a.push(l)}return a},w.prototype.toGeoJSON=function(t,e,r){return _.call(this,t,e,r)};var k=function(e){this.layers={_geojsonTileLayer:this},this.name=\"_geojsonTileLayer\",this.extent=t.EXTENT,this.length=e.length,this._features=e};k.prototype.feature=function(t){return new w(this._features[t])};var T=t.vectorTile.VectorTileFeature,A=M;function M(t,e){this.options=e||{},this.features=t,this.length=t.length}function S(t,e){this.id=\"number\"==typeof t.id?t.id:void 0,this.type=t.type,this.rawGeometry=1===t.type?[t.geometry]:t.geometry,this.properties=t.tags,this.extent=e||4096}M.prototype.feature=function(t){return new S(this.features[t],this.options.extent)},S.prototype.loadGeometry=function(){var e=this.rawGeometry;this.geometry=[];for(var r=0;r<e.length;r++){for(var n=e[r],i=[],a=0;a<n.length;a++)i.push(new t.Point$1(n[a][0],n[a][1]));this.geometry.push(i)}return this.geometry},S.prototype.bbox=function(){this.geometry||this.loadGeometry();for(var t=this.geometry,e=1/0,r=-1/0,n=1/0,i=-1/0,a=0;a<t.length;a++)for(var o=t[a],s=0;s<o.length;s++){var l=o[s];e=Math.min(e,l.x),r=Math.max(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.y)}return[e,n,r,i]},S.prototype.toGeoJSON=T.prototype.toGeoJSON;var E=P,C=P,L=A;function P(e){var r=new t.pbf;return function(t,e){for(var r in t.layers)e.writeMessage(3,O,t.layers[r])}(e,r),r.finish()}function O(t,e){var r;e.writeVarintField(15,t.version||1),e.writeStringField(1,t.name||\"\"),e.writeVarintField(5,t.extent||4096);var n={keys:[],values:[],keycache:{},valuecache:{}};for(r=0;r<t.length;r++)n.feature=t.feature(r),e.writeMessage(2,z,n);var i=n.keys;for(r=0;r<i.length;r++)e.writeStringField(3,i[r]);var a=n.values;for(r=0;r<a.length;r++)e.writeMessage(4,B,a[r])}function z(t,e){var r=t.feature;void 0!==r.id&&e.writeVarintField(1,r.id),e.writeMessage(2,I,t),e.writeVarintField(3,r.type),e.writeMessage(4,F,r)}function I(t,e){var r=t.feature,n=t.keys,i=t.values,a=t.keycache,o=t.valuecache;for(var s in r.properties){var l=a[s];void 0===l&&(n.push(s),l=n.length-1,a[s]=l),e.writeVarint(l);var c=r.properties[s],u=typeof c;\"string\"!==u&&\"boolean\"!==u&&\"number\"!==u&&(c=JSON.stringify(c));var h=u+\":\"+c,f=o[h];void 0===f&&(i.push(c),f=i.length-1,o[h]=f),e.writeVarint(f)}}function D(t,e){return(e<<3)+(7&t)}function R(t){return t<<1^t>>31}function F(t,e){for(var r=t.loadGeometry(),n=t.type,i=0,a=0,o=r.length,s=0;s<o;s++){var l=r[s],c=1;1===n&&(c=l.length),e.writeVarint(D(1,c));for(var u=3===n?l.length-1:l.length,h=0;h<u;h++){1===h&&1!==n&&e.writeVarint(D(2,u-1));var f=l[h].x-i,p=l[h].y-a;e.writeVarint(R(f)),e.writeVarint(R(p)),i+=f,a+=p}3===n&&e.writeVarint(D(7,1))}}function B(t,e){var r=typeof t;\"string\"===r?e.writeStringField(1,t):\"boolean\"===r?e.writeBooleanField(7,t):\"number\"===r&&(t%1!=0?e.writeDoubleField(3,t):t<0?e.writeSVarintField(6,t):e.writeVarintField(5,t))}function N(t,e,r,n){j(t,r,n),j(e,2*r,2*n),j(e,2*r+1,2*n+1)}function j(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function U(t,e,r,n){var i=t-r,a=e-n;return i*i+a*a}E.fromVectorTileJs=C,E.fromGeojsonVt=function(t,e){e=e||{};var r={};for(var n in t)r[n]=new A(t[n].features,e),r[n].name=n,r[n].version=e.version,r[n].extent=e.extent;return P({layers:r})},E.GeoJSONWrapper=L;var V=function(t){return t[0]},q=function(t){return t[1]},H=function(t,e,r,n,i){void 0===e&&(e=V),void 0===r&&(r=q),void 0===n&&(n=64),void 0===i&&(i=Float64Array),this.nodeSize=n,this.points=t;for(var a=t.length<65536?Uint16Array:Uint32Array,o=this.ids=new a(t.length),s=this.coords=new i(2*t.length),l=0;l<t.length;l++)o[l]=l,s[2*l]=e(t[l]),s[2*l+1]=r(t[l]);!function t(e,r,n,i,a,o){if(!(a-i<=n)){var s=i+a>>1;!function t(e,r,n,i,a,o){for(;a>i;){if(a-i>600){var s=a-i+1,l=n-i+1,c=Math.log(s),u=.5*Math.exp(2*c/3),h=.5*Math.sqrt(c*u*(s-u)/s)*(l-s/2<0?-1:1);t(e,r,n,Math.max(i,Math.floor(n-l*u/s+h)),Math.min(a,Math.floor(n+(s-l)*u/s+h)),o)}var f=r[2*n+o],p=i,d=a;for(N(e,r,i,n),r[2*a+o]>f&&N(e,r,i,a);p<d;){for(N(e,r,p,d),p++,d--;r[2*p+o]<f;)p++;for(;r[2*d+o]>f;)d--}r[2*i+o]===f?N(e,r,i,d):N(e,r,++d,a),d<=n&&(i=d+1),n<=d&&(a=d-1)}}(e,r,s,i,a,o%2),t(e,r,n,i,s-1,o+1),t(e,r,n,s+1,a,o+1)}}(o,s,n,0,o.length-1,0)};H.prototype.range=function(t,e,r,n){return function(t,e,r,n,i,a,o){for(var s,l,c=[0,t.length-1,0],u=[];c.length;){var h=c.pop(),f=c.pop(),p=c.pop();if(f-p<=o)for(var d=p;d<=f;d++)s=e[2*d],l=e[2*d+1],s>=r&&s<=i&&l>=n&&l<=a&&u.push(t[d]);else{var g=Math.floor((p+f)/2);s=e[2*g],l=e[2*g+1],s>=r&&s<=i&&l>=n&&l<=a&&u.push(t[g]);var v=(h+1)%2;(0===h?r<=s:n<=l)&&(c.push(p),c.push(g-1),c.push(v)),(0===h?i>=s:a>=l)&&(c.push(g+1),c.push(f),c.push(v))}}return u}(this.ids,this.coords,t,e,r,n,this.nodeSize)},H.prototype.within=function(t,e,r){return function(t,e,r,n,i,a){for(var o=[0,t.length-1,0],s=[],l=i*i;o.length;){var c=o.pop(),u=o.pop(),h=o.pop();if(u-h<=a)for(var f=h;f<=u;f++)U(e[2*f],e[2*f+1],r,n)<=l&&s.push(t[f]);else{var p=Math.floor((h+u)/2),d=e[2*p],g=e[2*p+1];U(d,g,r,n)<=l&&s.push(t[p]);var v=(c+1)%2;(0===c?r-i<=d:n-i<=g)&&(o.push(h),o.push(p-1),o.push(v)),(0===c?r+i>=d:n+i>=g)&&(o.push(p+1),o.push(u),o.push(v))}}return s}(this.ids,this.coords,t,e,r,this.nodeSize)};var G={minZoom:0,maxZoom:16,radius:40,extent:512,nodeSize:64,log:!1,reduce:null,map:function(t){return t}},Y=function(t){this.options=Q(Object.create(G),t),this.trees=new Array(this.options.maxZoom+1)};function W(t,e,r,n,i){return{x:t,y:e,zoom:1/0,id:r,parentId:-1,numPoints:n,properties:i}}function X(t,e){var r=t.geometry.coordinates,n=r[0],i=r[1];return{x:K(n),y:$(i),zoom:1/0,index:e,parentId:-1}}function Z(t){return{type:\"Feature\",id:t.id,properties:J(t),geometry:{type:\"Point\",coordinates:[(n=t.x,360*(n-.5)),(e=t.y,r=(180-360*e)*Math.PI/180,360*Math.atan(Math.exp(r))/Math.PI-90)]}};var e,r,n}function J(t){var e=t.numPoints,r=e>=1e4?Math.round(e/1e3)+\"k\":e>=1e3?Math.round(e/100)/10+\"k\":e;return Q(Q({},t.properties),{cluster:!0,cluster_id:t.id,point_count:e,point_count_abbreviated:r})}function K(t){return t/360+.5}function $(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function Q(t,e){for(var r in e)t[r]=e[r];return t}function tt(t){return t.x}function et(t){return t.y}function rt(t,e,r,n,i,a){var o=i-r,s=a-n;if(0!==o||0!==s){var l=((t-r)*o+(e-n)*s)/(o*o+s*s);l>1?(r=i,n=a):l>0&&(r+=o*l,n+=s*l)}return(o=t-r)*o+(s=e-n)*s}function nt(t,e,r,n){var i={id:void 0===t?null:t,type:e,geometry:r,tags:n,minX:1/0,minY:1/0,maxX:-1/0,maxY:-1/0};return function(t){var e=t.geometry,r=t.type;if(\"Point\"===r||\"MultiPoint\"===r||\"LineString\"===r)it(t,e);else if(\"Polygon\"===r||\"MultiLineString\"===r)for(var n=0;n<e.length;n++)it(t,e[n]);else if(\"MultiPolygon\"===r)for(n=0;n<e.length;n++)for(var i=0;i<e[n].length;i++)it(t,e[n][i])}(i),i}function it(t,e){for(var r=0;r<e.length;r+=3)t.minX=Math.min(t.minX,e[r]),t.minY=Math.min(t.minY,e[r+1]),t.maxX=Math.max(t.maxX,e[r]),t.maxY=Math.max(t.maxY,e[r+1])}function at(t,e,r,n){if(e.geometry){var i=e.geometry.coordinates,a=e.geometry.type,o=Math.pow(r.tolerance/((1<<r.maxZoom)*r.extent),2),s=[],l=e.id;if(r.promoteId?l=e.properties[r.promoteId]:r.generateId&&(l=n||0),\"Point\"===a)ot(i,s);else if(\"MultiPoint\"===a)for(var c=0;c<i.length;c++)ot(i[c],s);else if(\"LineString\"===a)st(i,s,o,!1);else if(\"MultiLineString\"===a){if(r.lineMetrics){for(c=0;c<i.length;c++)s=[],st(i[c],s,o,!1),t.push(nt(l,\"LineString\",s,e.properties));return}lt(i,s,o,!1)}else if(\"Polygon\"===a)lt(i,s,o,!0);else{if(\"MultiPolygon\"!==a){if(\"GeometryCollection\"===a){for(c=0;c<e.geometry.geometries.length;c++)at(t,{id:l,geometry:e.geometry.geometries[c],properties:e.properties},r,n);return}throw new Error(\"Input data is not a valid GeoJSON object.\")}for(c=0;c<i.length;c++){var u=[];lt(i[c],u,o,!0),s.push(u)}}t.push(nt(l,a,s,e.properties))}}function ot(t,e){e.push(ct(t[0])),e.push(ut(t[1])),e.push(0)}function st(t,e,r,n){for(var i,a,o=0,s=0;s<t.length;s++){var l=ct(t[s][0]),c=ut(t[s][1]);e.push(l),e.push(c),e.push(0),s>0&&(o+=n?(i*c-l*a)/2:Math.sqrt(Math.pow(l-i,2)+Math.pow(c-a,2))),i=l,a=c}var u=e.length-3;e[2]=1,function t(e,r,n,i){for(var a,o=i,s=n-r>>1,l=n-r,c=e[r],u=e[r+1],h=e[n],f=e[n+1],p=r+3;p<n;p+=3){var d=rt(e[p],e[p+1],c,u,h,f);if(d>o)a=p,o=d;else if(d===o){var g=Math.abs(p-s);g<l&&(a=p,l=g)}}o>i&&(a-r>3&&t(e,r,a,i),e[a+2]=o,n-a>3&&t(e,a,n,i))}(e,0,u,r),e[u+2]=1,e.size=Math.abs(o),e.start=0,e.end=e.size}function lt(t,e,r,n){for(var i=0;i<t.length;i++){var a=[];st(t[i],a,r,n),e.push(a)}}function ct(t){return t/360+.5}function ut(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function ht(t,e,r,n,i,a,o,s){if(n/=e,a>=(r/=e)&&o<n)return t;if(o<r||a>=n)return null;for(var l=[],c=0;c<t.length;c++){var u=t[c],h=u.geometry,f=u.type,p=0===i?u.minX:u.minY,d=0===i?u.maxX:u.maxY;if(p>=r&&d<n)l.push(u);else if(!(d<r||p>=n)){var g=[];if(\"Point\"===f||\"MultiPoint\"===f)ft(h,g,r,n,i);else if(\"LineString\"===f)pt(h,g,r,n,i,!1,s.lineMetrics);else if(\"MultiLineString\"===f)gt(h,g,r,n,i,!1);else if(\"Polygon\"===f)gt(h,g,r,n,i,!0);else if(\"MultiPolygon\"===f)for(var v=0;v<h.length;v++){var m=[];gt(h[v],m,r,n,i,!0),m.length&&g.push(m)}if(g.length){if(s.lineMetrics&&\"LineString\"===f){for(v=0;v<g.length;v++)l.push(nt(u.id,f,g[v],u.tags));continue}\"LineString\"!==f&&\"MultiLineString\"!==f||(1===g.length?(f=\"LineString\",g=g[0]):f=\"MultiLineString\"),\"Point\"!==f&&\"MultiPoint\"!==f||(f=3===g.length?\"Point\":\"MultiPoint\"),l.push(nt(u.id,f,g,u.tags))}}}return l.length?l:null}function ft(t,e,r,n,i){for(var a=0;a<t.length;a+=3){var o=t[a+i];o>=r&&o<=n&&(e.push(t[a]),e.push(t[a+1]),e.push(t[a+2]))}}function pt(t,e,r,n,i,a,o){for(var s,l,c=dt(t),u=0===i?mt:yt,h=t.start,f=0;f<t.length-3;f+=3){var p=t[f],d=t[f+1],g=t[f+2],v=t[f+3],m=t[f+4],y=0===i?p:d,x=0===i?v:m,b=!1;o&&(s=Math.sqrt(Math.pow(p-v,2)+Math.pow(d-m,2))),y<r?x>r&&(l=u(c,p,d,v,m,r),o&&(c.start=h+s*l)):y>n?x<n&&(l=u(c,p,d,v,m,n),o&&(c.start=h+s*l)):vt(c,p,d,g),x<r&&y>=r&&(l=u(c,p,d,v,m,r),b=!0),x>n&&y<=n&&(l=u(c,p,d,v,m,n),b=!0),!a&&b&&(o&&(c.end=h+s*l),e.push(c),c=dt(t)),o&&(h+=s)}var _=t.length-3;p=t[_],d=t[_+1],g=t[_+2],(y=0===i?p:d)>=r&&y<=n&&vt(c,p,d,g),_=c.length-3,a&&_>=3&&(c[_]!==c[0]||c[_+1]!==c[1])&&vt(c,c[0],c[1],c[2]),c.length&&e.push(c)}function dt(t){var e=[];return e.size=t.size,e.start=t.start,e.end=t.end,e}function gt(t,e,r,n,i,a){for(var o=0;o<t.length;o++)pt(t[o],e,r,n,i,a,!1)}function vt(t,e,r,n){t.push(e),t.push(r),t.push(n)}function mt(t,e,r,n,i,a){var o=(a-e)/(n-e);return t.push(a),t.push(r+(i-r)*o),t.push(1),o}function yt(t,e,r,n,i,a){var o=(a-r)/(i-r);return t.push(e+(n-e)*o),t.push(a),t.push(1),o}function xt(t,e){for(var r=[],n=0;n<t.length;n++){var i,a=t[n],o=a.type;if(\"Point\"===o||\"MultiPoint\"===o||\"LineString\"===o)i=bt(a.geometry,e);else if(\"MultiLineString\"===o||\"Polygon\"===o){i=[];for(var s=0;s<a.geometry.length;s++)i.push(bt(a.geometry[s],e))}else if(\"MultiPolygon\"===o)for(i=[],s=0;s<a.geometry.length;s++){for(var l=[],c=0;c<a.geometry[s].length;c++)l.push(bt(a.geometry[s][c],e));i.push(l)}r.push(nt(a.id,o,i,a.tags))}return r}function bt(t,e){var r=[];r.size=t.size,void 0!==t.start&&(r.start=t.start,r.end=t.end);for(var n=0;n<t.length;n+=3)r.push(t[n]+e,t[n+1],t[n+2]);return r}function _t(t,e){if(t.transformed)return t;var r,n,i,a=1<<t.z,o=t.x,s=t.y;for(r=0;r<t.features.length;r++){var l=t.features[r],c=l.geometry,u=l.type;if(l.geometry=[],1===u)for(n=0;n<c.length;n+=2)l.geometry.push(wt(c[n],c[n+1],e,a,o,s));else for(n=0;n<c.length;n++){var h=[];for(i=0;i<c[n].length;i+=2)h.push(wt(c[n][i],c[n][i+1],e,a,o,s));l.geometry.push(h)}}return t.transformed=!0,t}function wt(t,e,r,n,i,a){return[Math.round(r*(t*n-i)),Math.round(r*(e*n-a))]}function kt(t,e,r,n,i){for(var a=e===i.maxZoom?0:i.tolerance/((1<<e)*i.extent),o={features:[],numPoints:0,numSimplified:0,numFeatures:0,source:null,x:r,y:n,z:e,transformed:!1,minX:2,minY:1,maxX:-1,maxY:0},s=0;s<t.length;s++){o.numFeatures++,Tt(o,t[s],a,i);var l=t[s].minX,c=t[s].minY,u=t[s].maxX,h=t[s].maxY;l<o.minX&&(o.minX=l),c<o.minY&&(o.minY=c),u>o.maxX&&(o.maxX=u),h>o.maxY&&(o.maxY=h)}return o}function Tt(t,e,r,n){var i=e.geometry,a=e.type,o=[];if(\"Point\"===a||\"MultiPoint\"===a)for(var s=0;s<i.length;s+=3)o.push(i[s]),o.push(i[s+1]),t.numPoints++,t.numSimplified++;else if(\"LineString\"===a)At(o,i,t,r,!1,!1);else if(\"MultiLineString\"===a||\"Polygon\"===a)for(s=0;s<i.length;s++)At(o,i[s],t,r,\"Polygon\"===a,0===s);else if(\"MultiPolygon\"===a)for(var l=0;l<i.length;l++){var c=i[l];for(s=0;s<c.length;s++)At(o,c[s],t,r,!0,0===s)}if(o.length){var u=e.tags||null;if(\"LineString\"===a&&n.lineMetrics){for(var h in u={},e.tags)u[h]=e.tags[h];u.mapbox_clip_start=i.start/i.size,u.mapbox_clip_end=i.end/i.size}var f={geometry:o,type:\"Polygon\"===a||\"MultiPolygon\"===a?3:\"LineString\"===a||\"MultiLineString\"===a?2:1,tags:u};null!==e.id&&(f.id=e.id),t.features.push(f)}}function At(t,e,r,n,i,a){var o=n*n;if(n>0&&e.size<(i?o:n))r.numPoints+=e.length/3;else{for(var s=[],l=0;l<e.length;l+=3)(0===n||e[l+2]>o)&&(r.numSimplified++,s.push(e[l]),s.push(e[l+1])),r.numPoints++;i&&function(t,e){for(var r=0,n=0,i=t.length,a=i-2;n<i;a=n,n+=2)r+=(t[n]-t[a])*(t[n+1]+t[a+1]);if(r>0===e)for(n=0,i=t.length;n<i/2;n+=2){var o=t[n],s=t[n+1];t[n]=t[i-2-n],t[n+1]=t[i-1-n],t[i-2-n]=o,t[i-1-n]=s}}(s,a),t.push(s)}}function Mt(t,e){var r=(e=this.options=function(t,e){for(var r in e)t[r]=e[r];return t}(Object.create(this.options),e)).debug;if(r&&console.time(\"preprocess data\"),e.maxZoom<0||e.maxZoom>24)throw new Error(\"maxZoom should be in the 0-24 range\");if(e.promoteId&&e.generateId)throw new Error(\"promoteId and generateId cannot be used together.\");var n=function(t,e){var r=[];if(\"FeatureCollection\"===t.type)for(var n=0;n<t.features.length;n++)at(r,t.features[n],e,n);else\"Feature\"===t.type?at(r,t,e):at(r,{geometry:t},e);return r}(t,e);this.tiles={},this.tileCoords=[],r&&(console.timeEnd(\"preprocess data\"),console.log(\"index: maxZoom: %d, maxPoints: %d\",e.indexMaxZoom,e.indexMaxPoints),console.time(\"generate tiles\"),this.stats={},this.total=0),(n=function(t,e){var r=e.buffer/e.extent,n=t,i=ht(t,1,-1-r,r,0,-1,2,e),a=ht(t,1,1-r,2+r,0,-1,2,e);return(i||a)&&(n=ht(t,1,-r,1+r,0,-1,2,e)||[],i&&(n=xt(i,1).concat(n)),a&&(n=n.concat(xt(a,-1)))),n}(n,e)).length&&this.splitTile(n,0,0,0),r&&(n.length&&console.log(\"features: %d, points: %d\",this.tiles[0].numFeatures,this.tiles[0].numPoints),console.timeEnd(\"generate tiles\"),console.log(\"tiles generated:\",this.total,JSON.stringify(this.stats)))}function St(t,e,r){return 32*((1<<t)*r+e)+t}function Et(t,e){var r=t.tileID.canonical;if(!this._geoJSONIndex)return e(null,null);var n=this._geoJSONIndex.getTile(r.z,r.x,r.y);if(!n)return e(null,null);var i=new k(n.features),a=E(i);0===a.byteOffset&&a.byteLength===a.buffer.byteLength||(a=new Uint8Array(a)),e(null,{vectorTile:i,rawData:a.buffer})}Y.prototype.load=function(t){var e=this.options,r=e.log,n=e.minZoom,i=e.maxZoom,a=e.nodeSize;r&&console.time(\"total time\");var o=\"prepare \"+t.length+\" points\";r&&console.time(o),this.points=t;for(var s=[],l=0;l<t.length;l++)t[l].geometry&&s.push(X(t[l],l));this.trees[i+1]=new H(s,tt,et,a,Float32Array),r&&console.timeEnd(o);for(var c=i;c>=n;c--){var u=+Date.now();s=this._cluster(s,c),this.trees[c]=new H(s,tt,et,a,Float32Array),r&&console.log(\"z%d: %d clusters in %dms\",c,s.length,+Date.now()-u)}return r&&console.timeEnd(\"total time\"),this},Y.prototype.getClusters=function(t,e){var r=((t[0]+180)%360+360)%360-180,n=Math.max(-90,Math.min(90,t[1])),i=180===t[2]?180:((t[2]+180)%360+360)%360-180,a=Math.max(-90,Math.min(90,t[3]));if(t[2]-t[0]>=360)r=-180,i=180;else if(r>i){var o=this.getClusters([r,n,180,a],e),s=this.getClusters([-180,n,i,a],e);return o.concat(s)}for(var l=this.trees[this._limitZoom(e)],c=[],u=0,h=l.range(K(r),$(a),K(i),$(n));u<h.length;u+=1){var f=h[u],p=l.points[f];c.push(p.numPoints?Z(p):this.points[p.index])}return c},Y.prototype.getChildren=function(t){var e=t>>5,r=t%32,n=\"No cluster with the specified id.\",i=this.trees[r];if(!i)throw new Error(n);var a=i.points[e];if(!a)throw new Error(n);for(var o=this.options.radius/(this.options.extent*Math.pow(2,r-1)),s=[],l=0,c=i.within(a.x,a.y,o);l<c.length;l+=1){var u=c[l],h=i.points[u];h.parentId===t&&s.push(h.numPoints?Z(h):this.points[h.index])}if(0===s.length)throw new Error(n);return s},Y.prototype.getLeaves=function(t,e,r){e=e||10,r=r||0;var n=[];return this._appendLeaves(n,t,e,r,0),n},Y.prototype.getTile=function(t,e,r){var n=this.trees[this._limitZoom(t)],i=Math.pow(2,t),a=this.options,o=a.extent,s=a.radius/o,l=(r-s)/i,c=(r+1+s)/i,u={features:[]};return this._addTileFeatures(n.range((e-s)/i,l,(e+1+s)/i,c),n.points,e,r,i,u),0===e&&this._addTileFeatures(n.range(1-s/i,l,1,c),n.points,i,r,i,u),e===i-1&&this._addTileFeatures(n.range(0,l,s/i,c),n.points,-1,r,i,u),u.features.length?u:null},Y.prototype.getClusterExpansionZoom=function(t){for(var e=t%32-1;e<=this.options.maxZoom;){var r=this.getChildren(t);if(e++,1!==r.length)break;t=r[0].properties.cluster_id}return e},Y.prototype._appendLeaves=function(t,e,r,n,i){for(var a=0,o=this.getChildren(e);a<o.length;a+=1){var s=o[a],l=s.properties;if(l&&l.cluster?i+l.point_count<=n?i+=l.point_count:i=this._appendLeaves(t,l.cluster_id,r,n,i):i<n?i++:t.push(s),t.length===r)break}return i},Y.prototype._addTileFeatures=function(t,e,r,n,i,a){for(var o=0,s=t;o<s.length;o+=1){var l=e[s[o]],c={type:1,geometry:[[Math.round(this.options.extent*(l.x*i-r)),Math.round(this.options.extent*(l.y*i-n))]],tags:l.numPoints?J(l):this.points[l.index].properties},u=l.numPoints?l.id:this.points[l.index].id;void 0!==u&&(c.id=u),a.features.push(c)}},Y.prototype._limitZoom=function(t){return Math.max(this.options.minZoom,Math.min(t,this.options.maxZoom+1))},Y.prototype._cluster=function(t,e){for(var r=[],n=this.options,i=n.radius,a=n.extent,o=n.reduce,s=i/(a*Math.pow(2,e)),l=0;l<t.length;l++){var c=t[l];if(!(c.zoom<=e)){c.zoom=e;for(var u=this.trees[e+1],h=u.within(c.x,c.y,s),f=c.numPoints||1,p=c.x*f,d=c.y*f,g=o?this._map(c,!0):null,v=(l<<5)+(e+1),m=0,y=h;m<y.length;m+=1){var x=y[m],b=u.points[x];if(!(b.zoom<=e)){b.zoom=e;var _=b.numPoints||1;p+=b.x*_,d+=b.y*_,f+=_,b.parentId=v,o&&o(g,this._map(b))}}1===f?r.push(c):(c.parentId=v,r.push(W(p/f,d/f,v,f,g)))}}return r},Y.prototype._map=function(t,e){if(t.numPoints)return e?Q({},t.properties):t.properties;var r=this.points[t.index].properties,n=this.options.map(r);return e&&n===r?Q({},n):n},Mt.prototype.options={maxZoom:14,indexMaxZoom:5,indexMaxPoints:1e5,tolerance:3,extent:4096,buffer:64,lineMetrics:!1,promoteId:null,generateId:!1,debug:0},Mt.prototype.splitTile=function(t,e,r,n,i,a,o){for(var s=[t,e,r,n],l=this.options,c=l.debug;s.length;){n=s.pop(),r=s.pop(),e=s.pop(),t=s.pop();var u=1<<e,h=St(e,r,n),f=this.tiles[h];if(!f&&(c>1&&console.time(\"creation\"),f=this.tiles[h]=kt(t,e,r,n,l),this.tileCoords.push({z:e,x:r,y:n}),c)){c>1&&(console.log(\"tile z%d-%d-%d (features: %d, points: %d, simplified: %d)\",e,r,n,f.numFeatures,f.numPoints,f.numSimplified),console.timeEnd(\"creation\"));var p=\"z\"+e;this.stats[p]=(this.stats[p]||0)+1,this.total++}if(f.source=t,i){if(e===l.maxZoom||e===i)continue;var d=1<<i-e;if(r!==Math.floor(a/d)||n!==Math.floor(o/d))continue}else if(e===l.indexMaxZoom||f.numPoints<=l.indexMaxPoints)continue;if(f.source=null,0!==t.length){c>1&&console.time(\"clipping\");var g,v,m,y,x,b,_=.5*l.buffer/l.extent,w=.5-_,k=.5+_,T=1+_;g=v=m=y=null,x=ht(t,u,r-_,r+k,0,f.minX,f.maxX,l),b=ht(t,u,r+w,r+T,0,f.minX,f.maxX,l),t=null,x&&(g=ht(x,u,n-_,n+k,1,f.minY,f.maxY,l),v=ht(x,u,n+w,n+T,1,f.minY,f.maxY,l),x=null),b&&(m=ht(b,u,n-_,n+k,1,f.minY,f.maxY,l),y=ht(b,u,n+w,n+T,1,f.minY,f.maxY,l),b=null),c>1&&console.timeEnd(\"clipping\"),s.push(g||[],e+1,2*r,2*n),s.push(v||[],e+1,2*r,2*n+1),s.push(m||[],e+1,2*r+1,2*n),s.push(y||[],e+1,2*r+1,2*n+1)}}},Mt.prototype.getTile=function(t,e,r){var n=this.options,i=n.extent,a=n.debug;if(t<0||t>24)return null;var o=1<<t,s=St(t,e=(e%o+o)%o,r);if(this.tiles[s])return _t(this.tiles[s],i);a>1&&console.log(\"drilling down to z%d-%d-%d\",t,e,r);for(var l,c=t,u=e,h=r;!l&&c>0;)c--,u=Math.floor(u/2),h=Math.floor(h/2),l=this.tiles[St(c,u,h)];return l&&l.source?(a>1&&console.log(\"found parent tile z%d-%d-%d\",c,u,h),a>1&&console.time(\"drilling down\"),this.splitTile(l.source,c,u,h,t,e,r),a>1&&console.timeEnd(\"drilling down\"),this.tiles[s]?_t(this.tiles[s],i):null):null};var Ct=function(e){function r(t,r,n){e.call(this,t,r,Et),n&&(this.loadGeoJSON=n)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadData=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),this._pendingCallback=e,this._pendingLoadDataParams=t,this._state&&\"Idle\"!==this._state?this._state=\"NeedsLoadData\":(this._state=\"Coalescing\",this._loadData())},r.prototype._loadData=function(){var e=this;if(this._pendingCallback&&this._pendingLoadDataParams){var r=this._pendingCallback,n=this._pendingLoadDataParams;delete this._pendingCallback,delete this._pendingLoadDataParams;var i=!!(n&&n.request&&n.request.collectResourceTiming)&&new l.Performance(n.request);this.loadGeoJSON(n,function(a,o){if(a||!o)return r(a);if(\"object\"!=typeof o)return r(new Error(\"Input data given to '\"+n.source+\"' is not a valid GeoJSON object.\"));!function t(e,r){switch(e&&e.type||null){case\"FeatureCollection\":return e.features=e.features.map(y(t,r)),e;case\"GeometryCollection\":return e.geometries=e.geometries.map(y(t,r)),e;case\"Feature\":return e.geometry=t(e.geometry,r),e;case\"Polygon\":case\"MultiPolygon\":return function(t,e){return\"Polygon\"===t.type?t.coordinates=x(t.coordinates,e):\"MultiPolygon\"===t.type&&(t.coordinates=t.coordinates.map(y(x,e))),t}(e,r);default:return e}}(o,!0);try{e._geoJSONIndex=n.cluster?new Y(function(e){var r=e.superclusterOptions,n=e.clusterProperties;if(!n||!r)return r;for(var i={},a={},o={accumulated:null,zoom:0},s={properties:null},l=Object.keys(n),c=0,u=l;c<u.length;c+=1){var h=u[c],f=n[h],p=f[0],d=f[1],g=t.createExpression(d),v=t.createExpression(\"string\"==typeof p?[p,[\"accumulated\"],[\"get\",h]]:p);i[h]=g.value,a[h]=v.value}return r.map=function(t){s.properties=t;for(var e={},r=0,n=l;r<n.length;r+=1){var a=n[r];e[a]=i[a].evaluate(o,s)}return e},r.reduce=function(t,e){s.properties=e;for(var r=0,n=l;r<n.length;r+=1){var i=n[r];o.accumulated=t[i],t[i]=a[i].evaluate(o,s)}},r}(n)).load(o.features):new Mt(o,n.geojsonVtOptions)}catch(a){return r(a)}e.loaded={};var s={};if(i){var l=i.finish();l&&(s.resourceTiming={},s.resourceTiming[n.source]=JSON.parse(JSON.stringify(l)))}r(null,s)})}},r.prototype.coalesce=function(){\"Coalescing\"===this._state?this._state=\"Idle\":\"NeedsLoadData\"===this._state&&(this._state=\"Coalescing\",this._loadData())},r.prototype.reloadTile=function(t,r){var n=this.loaded,i=t.uid;return n&&n[i]?e.prototype.reloadTile.call(this,t,r):this.loadTile(t,r)},r.prototype.loadGeoJSON=function(e,r){if(e.request)t.getJSON(e.request,r);else{if(\"string\"!=typeof e.data)return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"));try{return r(null,JSON.parse(e.data))}catch(t){return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"))}}},r.prototype.removeSource=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),e()},r.prototype.getClusterExpansionZoom=function(t,e){e(null,this._geoJSONIndex.getClusterExpansionZoom(t.clusterId))},r.prototype.getClusterChildren=function(t,e){e(null,this._geoJSONIndex.getChildren(t.clusterId))},r.prototype.getClusterLeaves=function(t,e){e(null,this._geoJSONIndex.getLeaves(t.clusterId,t.limit,t.offset))},r}(h),Lt=function(e){var r=this;this.self=e,this.actor=new t.Actor(e,this),this.layerIndexes={},this.workerSourceTypes={vector:h,geojson:Ct},this.workerSources={},this.demWorkerSources={},this.self.registerWorkerSource=function(t,e){if(r.workerSourceTypes[t])throw new Error('Worker source with name \"'+t+'\" already registered.');r.workerSourceTypes[t]=e},this.self.registerRTLTextPlugin=function(e){if(t.plugin.isLoaded())throw new Error(\"RTL text plugin already registered.\");t.plugin.applyArabicShaping=e.applyArabicShaping,t.plugin.processBidirectionalText=e.processBidirectionalText,t.plugin.processStyledBidirectionalText=e.processStyledBidirectionalText}};return Lt.prototype.setReferrer=function(t,e){this.referrer=e},Lt.prototype.setLayers=function(t,e,r){this.getLayerIndex(t).replace(e),r()},Lt.prototype.updateLayers=function(t,e,r){this.getLayerIndex(t).update(e.layers,e.removedIds),r()},Lt.prototype.loadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).loadTile(e,r)},Lt.prototype.loadDEMTile=function(t,e,r){this.getDEMWorkerSource(t,e.source).loadTile(e,r)},Lt.prototype.reloadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).reloadTile(e,r)},Lt.prototype.abortTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).abortTile(e,r)},Lt.prototype.removeTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).removeTile(e,r)},Lt.prototype.removeDEMTile=function(t,e){this.getDEMWorkerSource(t,e.source).removeTile(e)},Lt.prototype.removeSource=function(t,e,r){if(this.workerSources[t]&&this.workerSources[t][e.type]&&this.workerSources[t][e.type][e.source]){var n=this.workerSources[t][e.type][e.source];delete this.workerSources[t][e.type][e.source],void 0!==n.removeSource?n.removeSource(e,r):r()}},Lt.prototype.loadWorkerSource=function(t,e,r){try{this.self.importScripts(e.url),r()}catch(t){r(t.toString())}},Lt.prototype.loadRTLTextPlugin=function(e,r,n){try{t.plugin.isLoaded()||(this.self.importScripts(r),n(t.plugin.isLoaded()?null:new Error(\"RTL Text Plugin failed to import scripts from \"+r)))}catch(t){n(t.toString())}},Lt.prototype.getLayerIndex=function(t){var e=this.layerIndexes[t];return e||(e=this.layerIndexes[t]=new n),e},Lt.prototype.getWorkerSource=function(t,e,r){var n=this;if(this.workerSources[t]||(this.workerSources[t]={}),this.workerSources[t][e]||(this.workerSources[t][e]={}),!this.workerSources[t][e][r]){var i={send:function(e,r,i){n.actor.send(e,r,i,t)}};this.workerSources[t][e][r]=new this.workerSourceTypes[e](i,this.getLayerIndex(t))}return this.workerSources[t][e][r]},Lt.prototype.getDEMWorkerSource=function(t,e){return this.demWorkerSources[t]||(this.demWorkerSources[t]={}),this.demWorkerSources[t][e]||(this.demWorkerSources[t][e]=new f),this.demWorkerSources[t][e]},Lt.prototype.enforceCacheSizeLimit=function(e,r){t.enforceCacheSizeLimit(r)},\"undefined\"!=typeof WorkerGlobalScope&&void 0!==t.window&&t.window instanceof WorkerGlobalScope&&(t.window.worker=new Lt(t.window)),Lt}),n(0,function(t){var e=t.createCommonjsModule(function(t){function e(t){return!!(\"undefined\"!=typeof window&&\"undefined\"!=typeof document&&Array.prototype&&Array.prototype.every&&Array.prototype.filter&&Array.prototype.forEach&&Array.prototype.indexOf&&Array.prototype.lastIndexOf&&Array.prototype.map&&Array.prototype.some&&Array.prototype.reduce&&Array.prototype.reduceRight&&Array.isArray&&Function.prototype&&Function.prototype.bind&&Object.keys&&Object.create&&Object.getPrototypeOf&&Object.getOwnPropertyNames&&Object.isSealed&&Object.isFrozen&&Object.isExtensible&&Object.getOwnPropertyDescriptor&&Object.defineProperty&&Object.defineProperties&&Object.seal&&Object.freeze&&Object.preventExtensions&&\"JSON\"in window&&\"parse\"in JSON&&\"stringify\"in JSON&&function(){if(!(\"Worker\"in window&&\"Blob\"in window&&\"URL\"in window))return!1;var t,e,r=new Blob([\"\"],{type:\"text/javascript\"}),n=URL.createObjectURL(r);try{e=new Worker(n),t=!0}catch(e){t=!1}return e&&e.terminate(),URL.revokeObjectURL(n),t}()&&\"Uint8ClampedArray\"in window&&ArrayBuffer.isView&&function(t){return void 0===r[t]&&(r[t]=function(t){var r=document.createElement(\"canvas\"),n=Object.create(e.webGLContextAttributes);return n.failIfMajorPerformanceCaveat=t,r.probablySupportsContext?r.probablySupportsContext(\"webgl\",n)||r.probablySupportsContext(\"experimental-webgl\",n):r.supportsContext?r.supportsContext(\"webgl\",n)||r.supportsContext(\"experimental-webgl\",n):r.getContext(\"webgl\",n)||r.getContext(\"experimental-webgl\",n)}(t)),r[t]}(t&&t.failIfMajorPerformanceCaveat))}t.exports?t.exports=e:window&&(window.mapboxgl=window.mapboxgl||{},window.mapboxgl.supported=e);var r={};e.webGLContextAttributes={antialias:!1,alpha:!0,stencil:!0,depth:!0}}),r={create:function(e,r,n){var i=t.window.document.createElement(e);return void 0!==r&&(i.className=r),n&&n.appendChild(i),i},createNS:function(e,r){return t.window.document.createElementNS(e,r)}},n=t.window.document.documentElement.style;function i(t){if(!n)return t[0];for(var e=0;e<t.length;e++)if(t[e]in n)return t[e];return t[0]}var a,o=i([\"userSelect\",\"MozUserSelect\",\"WebkitUserSelect\",\"msUserSelect\"]);r.disableDrag=function(){n&&o&&(a=n[o],n[o]=\"none\")},r.enableDrag=function(){n&&o&&(n[o]=a)};var s=i([\"transform\",\"WebkitTransform\"]);r.setTransform=function(t,e){t.style[s]=e};var l=!1;try{var c=Object.defineProperty({},\"passive\",{get:function(){l=!0}});t.window.addEventListener(\"test\",c,c),t.window.removeEventListener(\"test\",c,c)}catch(t){l=!1}r.addEventListener=function(t,e,r,n){void 0===n&&(n={}),\"passive\"in n&&l?t.addEventListener(e,r,n):t.addEventListener(e,r,n.capture)},r.removeEventListener=function(t,e,r,n){void 0===n&&(n={}),\"passive\"in n&&l?t.removeEventListener(e,r,n):t.removeEventListener(e,r,n.capture)};var u=function(e){e.preventDefault(),e.stopPropagation(),t.window.removeEventListener(\"click\",u,!0)};function h(t){var e=t.userImage;return!!(e&&e.render&&e.render())&&(t.data.replace(new Uint8Array(e.data.buffer)),!0)}r.suppressClick=function(){t.window.addEventListener(\"click\",u,!0),t.window.setTimeout(function(){t.window.removeEventListener(\"click\",u,!0)},0)},r.mousePos=function(e,r){var n=e.getBoundingClientRect(),i=t.window.TouchEvent&&r instanceof t.window.TouchEvent?r.touches[0]:r;return new t.Point(i.clientX-n.left-e.clientLeft,i.clientY-n.top-e.clientTop)},r.touchPos=function(e,r){for(var n=e.getBoundingClientRect(),i=[],a=\"touchend\"===r.type?r.changedTouches:r.touches,o=0;o<a.length;o++)i.push(new t.Point(a[o].clientX-n.left-e.clientLeft,a[o].clientY-n.top-e.clientTop));return i},r.mouseButton=function(e){return void 0!==t.window.InstallTrigger&&2===e.button&&e.ctrlKey&&t.window.navigator.platform.toUpperCase().indexOf(\"MAC\")>=0?0:e.button},r.remove=function(t){t.parentNode&&t.parentNode.removeChild(t)};var f=function(e){function r(){e.call(this),this.images={},this.updatedImages={},this.callbackDispatchedThisFrame={},this.loaded=!1,this.requestors=[],this.patterns={},this.atlasImage=new t.RGBAImage({width:1,height:1}),this.dirty=!0}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.isLoaded=function(){return this.loaded},r.prototype.setLoaded=function(t){if(this.loaded!==t&&(this.loaded=t,t)){for(var e=0,r=this.requestors;e<r.length;e+=1){var n=r[e],i=n.ids,a=n.callback;this._notify(i,a)}this.requestors=[]}},r.prototype.getImage=function(t){return this.images[t]},r.prototype.addImage=function(t,e){this.images[t]=e},r.prototype.updateImage=function(t,e){var r=this.images[t];e.version=r.version+1,this.images[t]=e,this.updatedImages[t]=!0},r.prototype.removeImage=function(t){var e=this.images[t];delete this.images[t],delete this.patterns[t],e.userImage&&e.userImage.onRemove&&e.userImage.onRemove()},r.prototype.listImages=function(){return Object.keys(this.images)},r.prototype.getImages=function(t,e){var r=!0;if(!this.isLoaded())for(var n=0,i=t;n<i.length;n+=1){var a=i[n];this.images[a]||(r=!1)}this.isLoaded()||r?this._notify(t,e):this.requestors.push({ids:t,callback:e})},r.prototype._notify=function(e,r){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i];this.images[o]||this.fire(new t.Event(\"styleimagemissing\",{id:o}));var s=this.images[o];s?n[o]={data:s.data.clone(),pixelRatio:s.pixelRatio,sdf:s.sdf,version:s.version,hasRenderCallback:Boolean(s.userImage&&s.userImage.render)}:t.warnOnce('Image \"'+o+'\" could not be loaded. Please make sure you have added the image with map.addImage() or a \"sprite\" property in your style. You can provide missing images by listening for the \"styleimagemissing\" map event.')}r(null,n)},r.prototype.getPixelSize=function(){var t=this.atlasImage;return{width:t.width,height:t.height}},r.prototype.getPattern=function(e){var r=this.patterns[e],n=this.getImage(e);if(!n)return null;if(r&&r.position.version===n.version)return r.position;if(r)r.position.version=n.version;else{var i={w:n.data.width+2,h:n.data.height+2,x:0,y:0},a=new t.ImagePosition(i,n);this.patterns[e]={bin:i,position:a}}return this._updatePatternAtlas(),this.patterns[e].position},r.prototype.bind=function(e){var r=e.gl;this.atlasTexture?this.dirty&&(this.atlasTexture.update(this.atlasImage),this.dirty=!1):this.atlasTexture=new t.Texture(e,this.atlasImage,r.RGBA),this.atlasTexture.bind(r.LINEAR,r.CLAMP_TO_EDGE)},r.prototype._updatePatternAtlas=function(){var e=[];for(var r in this.patterns)e.push(this.patterns[r].bin);var n=t.potpack(e),i=n.w,a=n.h,o=this.atlasImage;for(var s in o.resize({width:i||1,height:a||1}),this.patterns){var l=this.patterns[s].bin,c=l.x+1,u=l.y+1,h=this.images[s].data,f=h.width,p=h.height;t.RGBAImage.copy(h,o,{x:0,y:0},{x:c,y:u},{width:f,height:p}),t.RGBAImage.copy(h,o,{x:0,y:p-1},{x:c,y:u-1},{width:f,height:1}),t.RGBAImage.copy(h,o,{x:0,y:0},{x:c,y:u+p},{width:f,height:1}),t.RGBAImage.copy(h,o,{x:f-1,y:0},{x:c-1,y:u},{width:1,height:p}),t.RGBAImage.copy(h,o,{x:0,y:0},{x:c+f,y:u},{width:1,height:p})}this.dirty=!0},r.prototype.beginFrame=function(){this.callbackDispatchedThisFrame={}},r.prototype.dispatchRenderCallbacks=function(t){for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!this.callbackDispatchedThisFrame[n]){this.callbackDispatchedThisFrame[n]=!0;var i=this.images[n];h(i)&&this.updateImage(n,i)}}},r}(t.Evented),p=g,d=1e20;function g(t,e,r,n,i,a){this.fontSize=t||24,this.buffer=void 0===e?3:e,this.cutoff=n||.25,this.fontFamily=i||\"sans-serif\",this.fontWeight=a||\"normal\",this.radius=r||8;var o=this.size=this.fontSize+2*this.buffer;this.canvas=document.createElement(\"canvas\"),this.canvas.width=this.canvas.height=o,this.ctx=this.canvas.getContext(\"2d\"),this.ctx.font=this.fontWeight+\" \"+this.fontSize+\"px \"+this.fontFamily,this.ctx.textBaseline=\"middle\",this.ctx.fillStyle=\"black\",this.gridOuter=new Float64Array(o*o),this.gridInner=new Float64Array(o*o),this.f=new Float64Array(o),this.d=new Float64Array(o),this.z=new Float64Array(o+1),this.v=new Int16Array(o),this.middle=Math.round(o/2*(navigator.userAgent.indexOf(\"Gecko/\")>=0?1.2:1))}function v(t,e,r,n,i,a,o){for(var s=0;s<e;s++){for(var l=0;l<r;l++)n[l]=t[l*e+s];for(m(n,i,a,o,r),l=0;l<r;l++)t[l*e+s]=i[l]}for(l=0;l<r;l++){for(s=0;s<e;s++)n[s]=t[l*e+s];for(m(n,i,a,o,e),s=0;s<e;s++)t[l*e+s]=Math.sqrt(i[s])}}function m(t,e,r,n,i){r[0]=0,n[0]=-d,n[1]=+d;for(var a=1,o=0;a<i;a++){for(var s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);s<=n[o];)o--,s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);r[++o]=a,n[o]=s,n[o+1]=+d}for(a=0,o=0;a<i;a++){for(;n[o+1]<a;)o++;e[a]=(a-r[o])*(a-r[o])+t[r[o]]}}g.prototype.draw=function(t){this.ctx.clearRect(0,0,this.size,this.size),this.ctx.fillText(t,this.buffer,this.middle);for(var e=this.ctx.getImageData(0,0,this.size,this.size),r=new Uint8ClampedArray(this.size*this.size),n=0;n<this.size*this.size;n++){var i=e.data[4*n+3]/255;this.gridOuter[n]=1===i?0:0===i?d:Math.pow(Math.max(0,.5-i),2),this.gridInner[n]=1===i?d:0===i?0:Math.pow(Math.max(0,i-.5),2)}for(v(this.gridOuter,this.size,this.size,this.f,this.d,this.v,this.z),v(this.gridInner,this.size,this.size,this.f,this.d,this.v,this.z),n=0;n<this.size*this.size;n++){var a=this.gridOuter[n]-this.gridInner[n];r[n]=Math.max(0,Math.min(255,Math.round(255-255*(a/this.radius+this.cutoff))))}return r};var y=function(t,e){this.requestManager=t,this.localIdeographFontFamily=e,this.entries={}};y.prototype.setURL=function(t){this.url=t},y.prototype.getGlyphs=function(e,r){var n=this,i=[];for(var a in e)for(var o=0,s=e[a];o<s.length;o+=1){var l=s[o];i.push({stack:a,id:l})}t.asyncAll(i,function(t,e){var r=t.stack,i=t.id,a=n.entries[r];a||(a=n.entries[r]={glyphs:{},requests:{}});var o=a.glyphs[i];if(void 0===o)if(o=n._tinySDF(a,r,i))e(null,{stack:r,id:i,glyph:o});else{var s=Math.floor(i/256);if(256*s>65535)e(new Error(\"glyphs > 65535 not supported\"));else{var l=a.requests[s];l||(l=a.requests[s]=[],y.loadGlyphRange(r,s,n.url,n.requestManager,function(t,e){if(e)for(var r in e)a.glyphs[+r]=e[+r];for(var n=0,i=l;n<i.length;n+=1)(0,i[n])(t,e);delete a.requests[s]})),l.push(function(t,n){t?e(t):n&&e(null,{stack:r,id:i,glyph:n[i]||null})})}}else e(null,{stack:r,id:i,glyph:o})},function(t,e){if(t)r(t);else if(e){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.stack,l=o.id,c=o.glyph;(n[s]||(n[s]={}))[l]=c&&{id:c.id,bitmap:c.bitmap.clone(),metrics:c.metrics}}r(null,n)}})},y.prototype._tinySDF=function(e,r,n){var i=this.localIdeographFontFamily;if(i&&(t.isChar[\"CJK Unified Ideographs\"](n)||t.isChar[\"Hangul Syllables\"](n)||t.isChar.Hiragana(n)||t.isChar.Katakana(n))){var a=e.tinySDF;if(!a){var o=\"400\";/bold/i.test(r)?o=\"900\":/medium/i.test(r)?o=\"500\":/light/i.test(r)&&(o=\"200\"),a=e.tinySDF=new y.TinySDF(24,3,8,.25,i,o)}return{id:n,bitmap:new t.AlphaImage({width:30,height:30},a.draw(String.fromCharCode(n))),metrics:{width:24,height:24,left:0,top:-8,advance:24}}}},y.loadGlyphRange=function(e,r,n,i,a){var o=256*r,s=o+255,l=i.transformRequest(i.normalizeGlyphsURL(n).replace(\"{fontstack}\",e).replace(\"{range}\",o+\"-\"+s),t.ResourceType.Glyphs);t.getArrayBuffer(l,function(e,r){if(e)a(e);else if(r){for(var n={},i=0,o=t.parseGlyphPBF(r);i<o.length;i+=1){var s=o[i];n[s.id]=s}a(null,n)}})},y.TinySDF=p;var x=function(){this.specification=t.styleSpec.light.position};x.prototype.possiblyEvaluate=function(e,r){return t.sphericalToCartesian(e.expression.evaluate(r))},x.prototype.interpolate=function(e,r,n){return{x:t.number(e.x,r.x,n),y:t.number(e.y,r.y,n),z:t.number(e.z,r.z,n)}};var b=new t.Properties({anchor:new t.DataConstantProperty(t.styleSpec.light.anchor),position:new x,color:new t.DataConstantProperty(t.styleSpec.light.color),intensity:new t.DataConstantProperty(t.styleSpec.light.intensity)}),_=function(e){function r(r){e.call(this),this._transitionable=new t.Transitionable(b),this.setLight(r),this._transitioning=this._transitionable.untransitioned()}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getLight=function(){return this._transitionable.serialize()},r.prototype.setLight=function(e,r){if(void 0===r&&(r={}),!this._validate(t.validateLight,e,r))for(var n in e){var i=e[n];t.endsWith(n,\"-transition\")?this._transitionable.setTransition(n.slice(0,-\"-transition\".length),i):this._transitionable.setValue(n,i)}},r.prototype.updateTransitions=function(t){this._transitioning=this._transitionable.transitioned(t,this._transitioning)},r.prototype.hasTransition=function(){return this._transitioning.hasTransition()},r.prototype.recalculate=function(t){this.properties=this._transitioning.possiblyEvaluate(t)},r.prototype._validate=function(e,r,n){return(!n||!1!==n.validate)&&t.emitValidationErrors(this,e.call(t.validateStyle,t.extend({value:r,style:{glyphs:!0,sprite:!0},styleSpec:t.styleSpec})))},r}(t.Evented),w=function(t,e){this.width=t,this.height=e,this.nextRow=0,this.bytes=4,this.data=new Uint8Array(this.width*this.height*this.bytes),this.positions={}};w.prototype.getDash=function(t,e){var r=t.join(\",\")+String(e);return this.positions[r]||(this.positions[r]=this.addDash(t,e)),this.positions[r]},w.prototype.addDash=function(e,r){var n=r?7:0,i=2*n+1;if(this.nextRow+i>this.height)return t.warnOnce(\"LineAtlas out of space\"),null;for(var a=0,o=0;o<e.length;o++)a+=e[o];for(var s=this.width/a,l=s/2,c=e.length%2==1,u=-n;u<=n;u++)for(var h=this.nextRow+n+u,f=this.width*h,p=c?-e[e.length-1]:0,d=e[0],g=1,v=0;v<this.width;v++){for(;d<v/s;)p=d,d+=e[g],c&&g===e.length-1&&(d+=e[0]),g++;var m=Math.abs(v-p*s),y=Math.abs(v-d*s),x=Math.min(m,y),b=g%2==1,_=void 0;if(r){var w=n?u/n*(l+1):0;if(b){var k=l-Math.abs(w);_=Math.sqrt(x*x+k*k)}else _=l-Math.sqrt(x*x+w*w)}else _=(b?1:-1)*x;this.data[3+4*(f+v)]=Math.max(0,Math.min(255,_+128))}var T={y:(this.nextRow+n+.5)/this.height,height:2*n/this.height,width:a};return this.nextRow+=i,this.dirty=!0,T},w.prototype.bind=function(t){var e=t.gl;this.texture?(e.bindTexture(e.TEXTURE_2D,this.texture),this.dirty&&(this.dirty=!1,e.texSubImage2D(e.TEXTURE_2D,0,0,0,this.width,this.height,e.RGBA,e.UNSIGNED_BYTE,this.data))):(this.texture=e.createTexture(),e.bindTexture(e.TEXTURE_2D,this.texture),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_S,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_T,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,e.LINEAR),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,e.LINEAR),e.texImage2D(e.TEXTURE_2D,0,e.RGBA,this.width,this.height,0,e.RGBA,e.UNSIGNED_BYTE,this.data))};var k=function e(r,n){this.workerPool=r,this.actors=[],this.currentActor=0,this.id=t.uniqueId();for(var i=this.workerPool.acquire(this.id),a=0;a<i.length;a++){var o=i[a],s=new e.Actor(o,n,this.id);s.name=\"Worker \"+a,this.actors.push(s)}};function T(e,r,n){var i=function(i,a){if(i)return n(i);if(a){var o=t.pick(a,[\"tiles\",\"minzoom\",\"maxzoom\",\"attribution\",\"mapbox_logo\",\"bounds\"]);a.vector_layers&&(o.vectorLayers=a.vector_layers,o.vectorLayerIds=o.vectorLayers.map(function(t){return t.id})),e.url&&(o.tiles=r.canonicalizeTileset(o,e.url)),n(null,o)}};return e.url?t.getJSON(r.transformRequest(r.normalizeSourceURL(e.url),t.ResourceType.Source),i):t.browser.frame(function(){return i(null,e)})}k.prototype.broadcast=function(e,r,n){n=n||function(){},t.asyncAll(this.actors,function(t,n){t.send(e,r,n)},n)},k.prototype.send=function(t,e,r,n){return(\"number\"!=typeof n||isNaN(n))&&(n=this.currentActor=(this.currentActor+1)%this.actors.length),this.actors[n].send(t,e,r),n},k.prototype.remove=function(){this.actors.forEach(function(t){t.remove()}),this.actors=[],this.workerPool.release(this.id)},k.Actor=t.Actor;var A=function(e,r,n){this.bounds=t.LngLatBounds.convert(this.validateBounds(e)),this.minzoom=r||0,this.maxzoom=n||24};A.prototype.validateBounds=function(t){return Array.isArray(t)&&4===t.length?[Math.max(-180,t[0]),Math.max(-90,t[1]),Math.min(180,t[2]),Math.min(90,t[3])]:[-180,-90,180,90]},A.prototype.contains=function(e){var r=Math.pow(2,e.z),n=Math.floor(t.mercatorXfromLng(this.bounds.getWest())*r),i=Math.floor(t.mercatorYfromLat(this.bounds.getNorth())*r),a=Math.ceil(t.mercatorXfromLng(this.bounds.getEast())*r),o=Math.ceil(t.mercatorYfromLat(this.bounds.getSouth())*r);return e.x>=n&&e.x<a&&e.y>=i&&e.y<o};var M=function(e){function r(r,n,i,a){if(e.call(this),this.id=r,this.dispatcher=i,this.type=\"vector\",this.minzoom=0,this.maxzoom=22,this.scheme=\"xyz\",this.tileSize=512,this.reparseOverscaled=!0,this.isTileClipped=!0,t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"])),this._options=t.extend({type:\"vector\"},n),this._collectResourceTiming=n.collectResourceTiming,512!==this.tileSize)throw new Error(\"vector tile sources must have a tileSize of 512\");this.setEventedParent(a)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=T(this._options,this.map._requestManager,function(r,n){e._tileJSONRequest=null,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))})},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,null),i={request:this.map._requestManager.transformRequest(n,t.ResourceType.Tile),uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,tileSize:this.tileSize*e.tileID.overscaleFactor(),type:this.type,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes};function a(n,i){return e.aborted?r(null):n&&404!==n.status?r(n):(i&&i.resourceTiming&&(e.resourceTiming=i.resourceTiming),this.map._refreshExpiredTiles&&i&&e.setExpiryData(i),e.loadVectorData(i,this.map.painter),t.cacheEntryPossiblyAdded(this.dispatcher),r(null),void(e.reloadCallback&&(this.loadTile(e,e.reloadCallback),e.reloadCallback=null)))}i.request.collectResourceTiming=this._collectResourceTiming,void 0===e.workerID||\"expired\"===e.state?e.workerID=this.dispatcher.send(\"loadTile\",i,a.bind(this)):\"loading\"===e.state?e.reloadCallback=r:this.dispatcher.send(\"reloadTile\",i,a.bind(this),e.workerID)},r.prototype.abortTile=function(t){this.dispatcher.send(\"abortTile\",{uid:t.uid,type:this.type,source:this.id},void 0,t.workerID)},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.dispatcher.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},void 0,t.workerID)},r.prototype.hasTransition=function(){return!1},r}(t.Evented),S=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.dispatcher=i,this.setEventedParent(a),this.type=\"raster\",this.minzoom=0,this.maxzoom=22,this.roundZoom=!0,this.scheme=\"xyz\",this.tileSize=512,this._loaded=!1,this._options=t.extend({},n),t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"]))}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=T(this._options,this.map._requestManager,function(r,n){e._tileJSONRequest=null,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))})},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.loadTile=function(e,r){var n=this,i=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(i,t.ResourceType.Tile),function(i,a){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(i)e.state=\"errored\",r(i);else if(a){n.map._refreshExpiredTiles&&e.setExpiryData(a),delete a.cacheControl,delete a.expires;var o=n.map.painter.context,s=o.gl;e.texture=n.map.painter.getTileTexture(a.width),e.texture?e.texture.update(a,{useMipmap:!0}):(e.texture=new t.Texture(o,a,s.RGBA,{useMipmap:!0}),e.texture.bind(s.LINEAR,s.CLAMP_TO_EDGE,s.LINEAR_MIPMAP_NEAREST),o.extTextureFilterAnisotropic&&s.texParameterf(s.TEXTURE_2D,o.extTextureFilterAnisotropic.TEXTURE_MAX_ANISOTROPY_EXT,o.extTextureFilterAnisotropicMax)),e.state=\"loaded\",t.cacheEntryPossiblyAdded(n.dispatcher),r(null)}})},r.prototype.abortTile=function(t,e){t.request&&(t.request.cancel(),delete t.request),e()},r.prototype.unloadTile=function(t,e){t.texture&&this.map.painter.saveTileTexture(t.texture),e()},r.prototype.hasTransition=function(){return!1},r}(t.Evented),E=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),this.type=\"raster-dem\",this.maxzoom=22,this._options=t.extend({},n),this.encoding=n.encoding||\"mapbox\"}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.serialize=function(){return{type:\"raster-dem\",url:this.url,tileSize:this.tileSize,tiles:this.tiles,bounds:this.bounds,encoding:this.encoding}},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(n,t.ResourceType.Tile),function(n,i){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(n)e.state=\"errored\",r(n);else if(i){this.map._refreshExpiredTiles&&e.setExpiryData(i),delete i.cacheControl,delete i.expires;var a=t.browser.getImageData(i),o={uid:e.uid,coord:e.tileID,source:this.id,rawImageData:a,encoding:this.encoding};e.workerID&&\"expired\"!==e.state||(e.workerID=this.dispatcher.send(\"loadDEMTile\",o,function(t,n){t&&(e.state=\"errored\",r(t)),n&&(e.dem=n,e.needsHillshadePrepare=!0,e.state=\"loaded\",r(null))}.bind(this)))}}.bind(this)),e.neighboringTiles=this._getNeighboringTiles(e.tileID)},r.prototype._getNeighboringTiles=function(e){var r=e.canonical,n=Math.pow(2,r.z),i=(r.x-1+n)%n,a=0===r.x?e.wrap-1:e.wrap,o=(r.x+1+n)%n,s=r.x+1===n?e.wrap+1:e.wrap,l={};return l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y).key]={backfilled:!1},r.y>0&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y-1).key]={backfilled:!1}),r.y+1<n&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y+1).key]={backfilled:!1}),l},r.prototype.unloadTile=function(t){t.demTexture&&this.map.painter.saveTileTexture(t.demTexture),t.fbo&&(t.fbo.destroy(),delete t.fbo),t.dem&&delete t.dem,delete t.neighboringTiles,t.state=\"unloaded\",this.dispatcher.send(\"removeDEMTile\",{uid:t.uid,source:this.id},void 0,t.workerID)},r}(S),C=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.type=\"geojson\",this.minzoom=0,this.maxzoom=18,this.tileSize=512,this.isTileClipped=!0,this.reparseOverscaled=!0,this._removed=!1,this.dispatcher=i,this.setEventedParent(a),this._data=n.data,this._options=t.extend({},n),this._collectResourceTiming=n.collectResourceTiming,this._resourceTiming=[],void 0!==n.maxzoom&&(this.maxzoom=n.maxzoom),n.type&&(this.type=n.type),n.attribution&&(this.attribution=n.attribution);var o=t.EXTENT/this.tileSize;this.workerOptions=t.extend({source:this.id,cluster:n.cluster||!1,geojsonVtOptions:{buffer:(void 0!==n.buffer?n.buffer:128)*o,tolerance:(void 0!==n.tolerance?n.tolerance:.375)*o,extent:t.EXTENT,maxZoom:this.maxzoom,lineMetrics:n.lineMetrics||!1,generateId:n.generateId||!1},superclusterOptions:{maxZoom:void 0!==n.clusterMaxZoom?Math.min(n.clusterMaxZoom,this.maxzoom-1):this.maxzoom-1,extent:t.EXTENT,radius:(n.clusterRadius||50)*o,log:!1},clusterProperties:n.clusterProperties},n.workerOptions)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData(function(r){if(r)e.fire(new t.ErrorEvent(r));else{var n={dataType:\"source\",sourceDataType:\"metadata\"};e._collectResourceTiming&&e._resourceTiming&&e._resourceTiming.length>0&&(n.resourceTiming=e._resourceTiming,e._resourceTiming=[]),e.fire(new t.Event(\"data\",n))}})},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setData=function(e){var r=this;return this._data=e,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData(function(e){if(e)r.fire(new t.ErrorEvent(e));else{var n={dataType:\"source\",sourceDataType:\"content\"};r._collectResourceTiming&&r._resourceTiming&&r._resourceTiming.length>0&&(n.resourceTiming=r._resourceTiming,r._resourceTiming=[]),r.fire(new t.Event(\"data\",n))}}),this},r.prototype.getClusterExpansionZoom=function(t,e){return this.dispatcher.send(\"geojson.getClusterExpansionZoom\",{clusterId:t,source:this.id},e,this.workerID),this},r.prototype.getClusterChildren=function(t,e){return this.dispatcher.send(\"geojson.getClusterChildren\",{clusterId:t,source:this.id},e,this.workerID),this},r.prototype.getClusterLeaves=function(t,e,r,n){return this.dispatcher.send(\"geojson.getClusterLeaves\",{source:this.id,clusterId:t,limit:e,offset:r},n,this.workerID),this},r.prototype._updateWorkerData=function(e){var r=this,n=t.extend({},this.workerOptions),i=this._data;\"string\"==typeof i?(n.request=this.map._requestManager.transformRequest(t.browser.resolveURL(i),t.ResourceType.Source),n.request.collectResourceTiming=this._collectResourceTiming):n.data=JSON.stringify(i),this.workerID=this.dispatcher.send(this.type+\".loadData\",n,function(t,i){r._removed||i&&i.abandoned||(r._loaded=!0,i&&i.resourceTiming&&i.resourceTiming[r.id]&&(r._resourceTiming=i.resourceTiming[r.id].slice(0)),r.dispatcher.send(r.type+\".coalesce\",{source:n.source},null,r.workerID),e(t))},this.workerID)},r.prototype.loadTile=function(e,r){var n=this,i=void 0===e.workerID?\"loadTile\":\"reloadTile\",a={type:this.type,uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,maxZoom:this.maxzoom,tileSize:this.tileSize,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes};e.workerID=this.dispatcher.send(i,a,function(t,a){return e.unloadVectorData(),e.aborted?r(null):t?r(t):(e.loadVectorData(a,n.map.painter,\"reloadTile\"===i),r(null))},this.workerID)},r.prototype.abortTile=function(t){t.aborted=!0},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.dispatcher.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},null,t.workerID)},r.prototype.onRemove=function(){this._removed=!0,this.dispatcher.send(\"removeSource\",{type:this.type,source:this.id},null,this.workerID)},r.prototype.serialize=function(){return t.extend({},this._options,{type:this.type,data:this._data})},r.prototype.hasTransition=function(){return!1},r}(t.Evented),L=function(e){function r(t,r,n,i){e.call(this),this.id=t,this.dispatcher=n,this.coordinates=r.coordinates,this.type=\"image\",this.minzoom=0,this.maxzoom=22,this.tileSize=512,this.tiles={},this.setEventedParent(i),this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(e,r){var n=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this.url=this.options.url,t.getImage(this.map._requestManager.transformRequest(this.url,t.ResourceType.Image),function(i,a){i?n.fire(new t.ErrorEvent(i)):a&&(n.image=a,e&&(n.coordinates=e),r&&r(),n._finishLoading())})},r.prototype.updateImage=function(t){var e=this;return this.image&&t.url?(this.options.url=t.url,this.load(t.coordinates,function(){e.texture=null}),this):this},r.prototype._finishLoading=function(){this.map&&(this.setCoordinates(this.coordinates),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setCoordinates=function(e){var r=this;this.coordinates=e;var n=e.map(t.MercatorCoordinate.fromLngLat);this.tileID=function(e){for(var r=1/0,n=1/0,i=-1/0,a=-1/0,o=0,s=e;o<s.length;o+=1){var l=s[o];r=Math.min(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.x),a=Math.max(a,l.y)}var c=i-r,u=a-n,h=Math.max(c,u),f=Math.max(0,Math.floor(-Math.log(h)/Math.LN2)),p=Math.pow(2,f);return new t.CanonicalTileID(f,Math.floor((r+i)/2*p),Math.floor((n+a)/2*p))}(n),this.minzoom=this.maxzoom=this.tileID.z;var i=n.map(function(t){return r.tileID.getTilePoint(t)._round()});return this._boundsArray=new t.StructArrayLayout4i8,this._boundsArray.emplaceBack(i[0].x,i[0].y,0,0),this._boundsArray.emplaceBack(i[1].x,i[1].y,t.EXTENT,0),this._boundsArray.emplaceBack(i[3].x,i[3].y,0,t.EXTENT),this._boundsArray.emplaceBack(i[2].x,i[2].y,t.EXTENT,t.EXTENT),this.boundsBuffer&&(this.boundsBuffer.destroy(),delete this.boundsBuffer),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})),this},r.prototype.prepare=function(){if(0!==Object.keys(this.tiles).length&&this.image){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture||(this.texture=new t.Texture(e,this.image,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.loadTile=function(t,e){this.tileID&&this.tileID.equals(t.tileID.canonical)?(this.tiles[String(t.tileID.wrap)]=t,t.buckets={},e(null)):(t.state=\"errored\",e(null))},r.prototype.serialize=function(){return{type:\"image\",url:this.options.url,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return!1},r}(t.Evented),P=function(e){function r(t,r,n,i){e.call(this,t,r,n,i),this.roundZoom=!0,this.type=\"video\",this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this,r=this.options;this.urls=[];for(var n=0,i=r.urls;n<i.length;n+=1){var a=i[n];this.urls.push(this.map._requestManager.transformRequest(a,t.ResourceType.Source).url)}t.getVideo(this.urls,function(r,n){r?e.fire(new t.ErrorEvent(r)):n&&(e.video=n,e.video.loop=!0,e.video.addEventListener(\"playing\",function(){e.map.triggerRepaint()}),e.map&&e.video.play(),e._finishLoading())})},r.prototype.getVideo=function(){return this.video},r.prototype.onAdd=function(t){this.map||(this.map=t,this.load(),this.video&&(this.video.play(),this.setCoordinates(this.coordinates)))},r.prototype.prepare=function(){if(!(0===Object.keys(this.tiles).length||this.video.readyState<2)){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?this.video.paused||(this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE),r.texSubImage2D(r.TEXTURE_2D,0,0,0,r.RGBA,r.UNSIGNED_BYTE,this.video)):(this.texture=new t.Texture(e,this.video,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"video\",urls:this.urls,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this.video&&!this.video.paused},r}(L),O=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),n.coordinates?Array.isArray(n.coordinates)&&4===n.coordinates.length&&!n.coordinates.some(function(t){return!Array.isArray(t)||2!==t.length||t.some(function(t){return\"number\"!=typeof t})})||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"coordinates\" property must be an array of 4 longitude/latitude array pairs'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"coordinates\"'))),n.animate&&\"boolean\"!=typeof n.animate&&this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'optional \"animate\" property must be a boolean value'))),n.canvas?\"string\"==typeof n.canvas||n.canvas instanceof t.window.HTMLCanvasElement||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"canvas\" must be either a string representing the ID of the canvas element from which to read, or an HTMLCanvasElement instance'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"canvas\"'))),this.options=n,this.animate=void 0===n.animate||n.animate}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){this.canvas||(this.canvas=this.options.canvas instanceof t.window.HTMLCanvasElement?this.options.canvas:t.window.document.getElementById(this.options.canvas)),this.width=this.canvas.width,this.height=this.canvas.height,this._hasInvalidDimensions()?this.fire(new t.ErrorEvent(new Error(\"Canvas dimensions cannot be less than or equal to zero.\"))):(this.play=function(){this._playing=!0,this.map.triggerRepaint()},this.pause=function(){this._playing&&(this.prepare(),this._playing=!1)},this._finishLoading())},r.prototype.getCanvas=function(){return this.canvas},r.prototype.onAdd=function(t){this.map=t,this.load(),this.canvas&&this.animate&&this.play()},r.prototype.onRemove=function(){this.pause()},r.prototype.prepare=function(){var e=!1;if(this.canvas.width!==this.width&&(this.width=this.canvas.width,e=!0),this.canvas.height!==this.height&&(this.height=this.canvas.height,e=!0),!this._hasInvalidDimensions()&&0!==Object.keys(this.tiles).length){var r=this.map.painter.context,n=r.gl;for(var i in this.boundsBuffer||(this.boundsBuffer=r.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?(e||this._playing)&&this.texture.update(this.canvas,{premultiply:!0}):this.texture=new t.Texture(r,this.canvas,n.RGBA,{premultiply:!0}),this.tiles){var a=this.tiles[i];\"loaded\"!==a.state&&(a.state=\"loaded\",a.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"canvas\",coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this._playing},r.prototype._hasInvalidDimensions=function(){for(var t=0,e=[this.canvas.width,this.canvas.height];t<e.length;t+=1){var r=e[t];if(isNaN(r)||r<=0)return!0}return!1},r}(L),z={vector:M,raster:S,\"raster-dem\":E,geojson:C,video:P,image:L,canvas:O},I=function(e,r,n,i){var a=new z[r.type](e,r,n,i);if(a.id!==e)throw new Error(\"Expected Source id to be \"+e+\" instead of \"+a.id);return t.bindAll([\"load\",\"abort\",\"unload\",\"serialize\",\"prepare\"],a),a};function D(e,r){var n=t.identity([]);return t.translate(n,n,[1,1,0]),t.scale(n,n,[.5*e.width,.5*e.height,1]),t.multiply(n,n,e.calculatePosMatrix(r.toUnwrapped()))}function R(t,e,r,n,i){var a=function(t,e,r){if(t)for(var n=0,i=t;n<i.length;n+=1){var a=e[i[n]];if(a&&a.source===r&&\"fill-extrusion\"===a.type)return!0}else for(var o in e){var s=e[o];if(s.source===r&&\"fill-extrusion\"===s.type)return!0}return!1}(n&&n.layers,e,t.id),o=i.maxPitchScaleFactor(),s=t.tilesIn(r,o,a);s.sort(F);for(var l=[],c=0,u=s;c<u.length;c+=1){var h=u[c];l.push({wrappedTileID:h.tileID.wrapped().key,queryResults:h.tile.queryRenderedFeatures(e,t._state,h.queryGeometry,h.cameraQueryGeometry,h.scale,n,i,o,D(t.transform,h.tileID))})}var f=function(t){for(var e={},r={},n=0,i=t;n<i.length;n+=1){var a=i[n],o=a.queryResults,s=a.wrappedTileID,l=r[s]=r[s]||{};for(var c in o)for(var u=o[c],h=l[c]=l[c]||{},f=e[c]=e[c]||[],p=0,d=u;p<d.length;p+=1){var g=d[p];h[g.featureIndex]||(h[g.featureIndex]=!0,f.push(g))}}return e}(l);for(var p in f)f[p].forEach(function(e){var r=e.feature,n=t.getFeatureState(r.layer[\"source-layer\"],r.id);r.source=r.layer.source,r.layer[\"source-layer\"]&&(r.sourceLayer=r.layer[\"source-layer\"]),r.state=n});return f}function F(t,e){var r=t.tileID,n=e.tileID;return r.overscaledZ-n.overscaledZ||r.canonical.y-n.canonical.y||r.wrap-n.wrap||r.canonical.x-n.canonical.x}var B=function(t,e){this.max=t,this.onRemove=e,this.reset()};B.prototype.reset=function(){for(var t in this.data)for(var e=0,r=this.data[t];e<r.length;e+=1){var n=r[e];n.timeout&&clearTimeout(n.timeout),this.onRemove(n.value)}return this.data={},this.order=[],this},B.prototype.add=function(t,e,r){var n=this,i=t.wrapped().key;void 0===this.data[i]&&(this.data[i]=[]);var a={value:e,timeout:void 0};if(void 0!==r&&(a.timeout=setTimeout(function(){n.remove(t,a)},r)),this.data[i].push(a),this.order.push(i),this.order.length>this.max){var o=this._getAndRemoveByKey(this.order[0]);o&&this.onRemove(o)}return this},B.prototype.has=function(t){return t.wrapped().key in this.data},B.prototype.getAndRemove=function(t){return this.has(t)?this._getAndRemoveByKey(t.wrapped().key):null},B.prototype._getAndRemoveByKey=function(t){var e=this.data[t].shift();return e.timeout&&clearTimeout(e.timeout),0===this.data[t].length&&delete this.data[t],this.order.splice(this.order.indexOf(t),1),e.value},B.prototype.get=function(t){return this.has(t)?this.data[t.wrapped().key][0].value:null},B.prototype.remove=function(t,e){if(!this.has(t))return this;var r=t.wrapped().key,n=void 0===e?0:this.data[r].indexOf(e),i=this.data[r][n];return this.data[r].splice(n,1),i.timeout&&clearTimeout(i.timeout),0===this.data[r].length&&delete this.data[r],this.onRemove(i.value),this.order.splice(this.order.indexOf(r),1),this},B.prototype.setMaxSize=function(t){for(this.max=t;this.order.length>this.max;){var e=this._getAndRemoveByKey(this.order[0]);e&&this.onRemove(e)}return this};var N=function(t,e,r){this.context=t;var n=t.gl;this.buffer=n.createBuffer(),this.dynamicDraw=Boolean(r),this.context.unbindVAO(),t.bindElementBuffer.set(this.buffer),n.bufferData(n.ELEMENT_ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?n.DYNAMIC_DRAW:n.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};N.prototype.bind=function(){this.context.bindElementBuffer.set(this.buffer)},N.prototype.updateData=function(t){var e=this.context.gl;this.context.unbindVAO(),this.bind(),e.bufferSubData(e.ELEMENT_ARRAY_BUFFER,0,t.arrayBuffer)},N.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var j={Int8:\"BYTE\",Uint8:\"UNSIGNED_BYTE\",Int16:\"SHORT\",Uint16:\"UNSIGNED_SHORT\",Int32:\"INT\",Uint32:\"UNSIGNED_INT\",Float32:\"FLOAT\"},U=function(t,e,r,n){this.length=e.length,this.attributes=r,this.itemSize=e.bytesPerElement,this.dynamicDraw=n,this.context=t;var i=t.gl;this.buffer=i.createBuffer(),t.bindVertexBuffer.set(this.buffer),i.bufferData(i.ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?i.DYNAMIC_DRAW:i.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};U.prototype.bind=function(){this.context.bindVertexBuffer.set(this.buffer)},U.prototype.updateData=function(t){var e=this.context.gl;this.bind(),e.bufferSubData(e.ARRAY_BUFFER,0,t.arrayBuffer)},U.prototype.enableAttributes=function(t,e){for(var r=0;r<this.attributes.length;r++){var n=this.attributes[r],i=e.attributes[n.name];void 0!==i&&t.enableVertexAttribArray(i)}},U.prototype.setVertexAttribPointers=function(t,e,r){for(var n=0;n<this.attributes.length;n++){var i=this.attributes[n],a=e.attributes[i.name];void 0!==a&&t.vertexAttribPointer(a,i.components,t[j[i.type]],!1,this.itemSize,i.offset+this.itemSize*(r||0))}},U.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var V=function(t){this.gl=t.gl,this.default=this.getDefault(),this.current=this.default,this.dirty=!1};V.prototype.get=function(){return this.current},V.prototype.set=function(t){},V.prototype.getDefault=function(){return this.default},V.prototype.setDefault=function(){this.set(this.default)};var q=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.clearColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(V),H=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 1},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearDepth(t),this.current=t,this.dirty=!1)},e}(V),G=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearStencil(t),this.current=t,this.dirty=!1)},e}(V),Y=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return[!0,!0,!0,!0]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.colorMask(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(V),W=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthMask(t),this.current=t,this.dirty=!1)},e}(V),X=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 255},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.stencilMask(t),this.current=t,this.dirty=!1)},e}(V),Z=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return{func:this.gl.ALWAYS,ref:0,mask:255}},e.prototype.set=function(t){var e=this.current;(t.func!==e.func||t.ref!==e.ref||t.mask!==e.mask||this.dirty)&&(this.gl.stencilFunc(t.func,t.ref,t.mask),this.current=t,this.dirty=!1)},e}(V),J=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.KEEP,t.KEEP,t.KEEP]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||this.dirty)&&(this.gl.stencilOp(t[0],t[1],t[2]),this.current=t,this.dirty=!1)},e}(V),K=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.STENCIL_TEST):e.disable(e.STENCIL_TEST),this.current=t,this.dirty=!1}},e}(V),$=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return[0,1]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.depthRange(t[0],t[1]),this.current=t,this.dirty=!1)},e}(V),Q=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.DEPTH_TEST):e.disable(e.DEPTH_TEST),this.current=t,this.dirty=!1}},e}(V),tt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.LESS},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthFunc(t),this.current=t,this.dirty=!1)},e}(V),et=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.BLEND):e.disable(e.BLEND),this.current=t,this.dirty=!1}},e}(V),rt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.ONE,t.ZERO]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.blendFunc(t[0],t[1]),this.current=t,this.dirty=!1)},e}(V),nt=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.blendColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(V),it=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.FUNC_ADD},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.blendEquation(t),this.current=t,this.dirty=!1)},e}(V),at=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.CULL_FACE):e.disable(e.CULL_FACE),this.current=t,this.dirty=!1}},e}(V),ot=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.BACK},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.cullFace(t),this.current=t,this.dirty=!1)},e}(V),st=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.CCW},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.frontFace(t),this.current=t,this.dirty=!1)},e}(V),lt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.useProgram(t),this.current=t,this.dirty=!1)},e}(V),ct=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.TEXTURE0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.activeTexture(t),this.current=t,this.dirty=!1)},e}(V),ut=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[0,0,t.drawingBufferWidth,t.drawingBufferHeight]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.viewport(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(V),ht=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindFramebuffer(e.FRAMEBUFFER,t),this.current=t,this.dirty=!1}},e}(V),ft=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindRenderbuffer(e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(V),pt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindTexture(e.TEXTURE_2D,t),this.current=t,this.dirty=!1}},e}(V),dt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindBuffer(e.ARRAY_BUFFER,t),this.current=t,this.dirty=!1}},e}(V),gt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){var e=this.gl;e.bindBuffer(e.ELEMENT_ARRAY_BUFFER,t),this.current=t,this.dirty=!1},e}(V),vt=function(t){function e(e){t.call(this,e),this.vao=e.extVertexArrayObject}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){this.vao&&(t!==this.current||this.dirty)&&(this.vao.bindVertexArrayOES(t),this.current=t,this.dirty=!1)},e}(V),mt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 4},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_ALIGNMENT,t),this.current=t,this.dirty=!1}},e}(V),yt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_PREMULTIPLY_ALPHA_WEBGL,t),this.current=t,this.dirty=!1}},e}(V),xt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_FLIP_Y_WEBGL,t),this.current=t,this.dirty=!1}},e}(V),bt=function(t){function e(e,r){t.call(this,e),this.context=e,this.parent=r}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e}(V),_t=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.setDirty=function(){this.dirty=!0},e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferTexture2D(e.FRAMEBUFFER,e.COLOR_ATTACHMENT0,e.TEXTURE_2D,t,0),this.current=t,this.dirty=!1}},e}(bt),wt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferRenderbuffer(e.FRAMEBUFFER,e.DEPTH_ATTACHMENT,e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(bt),kt=function(t,e,r){this.context=t,this.width=e,this.height=r;var n=t.gl,i=this.framebuffer=n.createFramebuffer();this.colorAttachment=new _t(t,i),this.depthAttachment=new wt(t,i)};kt.prototype.destroy=function(){var t=this.context.gl,e=this.colorAttachment.get();e&&t.deleteTexture(e);var r=this.depthAttachment.get();r&&t.deleteRenderbuffer(r),t.deleteFramebuffer(this.framebuffer)};var Tt=function(t,e,r){this.func=t,this.mask=e,this.range=r};Tt.ReadOnly=!1,Tt.ReadWrite=!0,Tt.disabled=new Tt(519,Tt.ReadOnly,[0,1]);var At=function(t,e,r,n,i,a){this.test=t,this.ref=e,this.mask=r,this.fail=n,this.depthFail=i,this.pass=a};At.disabled=new At({func:519,mask:0},0,0,7680,7680,7680);var Mt=function(t,e,r){this.blendFunction=t,this.blendColor=e,this.mask=r};Mt.disabled=new Mt(Mt.Replace=[1,0],t.Color.transparent,[!1,!1,!1,!1]),Mt.unblended=new Mt(Mt.Replace,t.Color.transparent,[!0,!0,!0,!0]),Mt.alphaBlended=new Mt([1,771],t.Color.transparent,[!0,!0,!0,!0]);var St=function(t,e,r){this.enable=t,this.mode=e,this.frontFace=r};St.disabled=new St(!1,1029,2305),St.backCCW=new St(!0,1029,2305);var Et=function(t){this.gl=t,this.extVertexArrayObject=this.gl.getExtension(\"OES_vertex_array_object\"),this.clearColor=new q(this),this.clearDepth=new H(this),this.clearStencil=new G(this),this.colorMask=new Y(this),this.depthMask=new W(this),this.stencilMask=new X(this),this.stencilFunc=new Z(this),this.stencilOp=new J(this),this.stencilTest=new K(this),this.depthRange=new $(this),this.depthTest=new Q(this),this.depthFunc=new tt(this),this.blend=new et(this),this.blendFunc=new rt(this),this.blendColor=new nt(this),this.blendEquation=new it(this),this.cullFace=new at(this),this.cullFaceSide=new ot(this),this.frontFace=new st(this),this.program=new lt(this),this.activeTexture=new ct(this),this.viewport=new ut(this),this.bindFramebuffer=new ht(this),this.bindRenderbuffer=new ft(this),this.bindTexture=new pt(this),this.bindVertexBuffer=new dt(this),this.bindElementBuffer=new gt(this),this.bindVertexArrayOES=this.extVertexArrayObject&&new vt(this),this.pixelStoreUnpack=new mt(this),this.pixelStoreUnpackPremultiplyAlpha=new yt(this),this.pixelStoreUnpackFlipY=new xt(this),this.extTextureFilterAnisotropic=t.getExtension(\"EXT_texture_filter_anisotropic\")||t.getExtension(\"MOZ_EXT_texture_filter_anisotropic\")||t.getExtension(\"WEBKIT_EXT_texture_filter_anisotropic\"),this.extTextureFilterAnisotropic&&(this.extTextureFilterAnisotropicMax=t.getParameter(this.extTextureFilterAnisotropic.MAX_TEXTURE_MAX_ANISOTROPY_EXT)),this.extTextureHalfFloat=t.getExtension(\"OES_texture_half_float\"),this.extTextureHalfFloat&&t.getExtension(\"OES_texture_half_float_linear\")};Et.prototype.setDefault=function(){this.unbindVAO(),this.clearColor.setDefault(),this.clearDepth.setDefault(),this.clearStencil.setDefault(),this.colorMask.setDefault(),this.depthMask.setDefault(),this.stencilMask.setDefault(),this.stencilFunc.setDefault(),this.stencilOp.setDefault(),this.stencilTest.setDefault(),this.depthRange.setDefault(),this.depthTest.setDefault(),this.depthFunc.setDefault(),this.blend.setDefault(),this.blendFunc.setDefault(),this.blendColor.setDefault(),this.blendEquation.setDefault(),this.cullFace.setDefault(),this.cullFaceSide.setDefault(),this.frontFace.setDefault(),this.program.setDefault(),this.activeTexture.setDefault(),this.bindFramebuffer.setDefault(),this.pixelStoreUnpack.setDefault(),this.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.pixelStoreUnpackFlipY.setDefault()},Et.prototype.setDirty=function(){this.clearColor.dirty=!0,this.clearDepth.dirty=!0,this.clearStencil.dirty=!0,this.colorMask.dirty=!0,this.depthMask.dirty=!0,this.stencilMask.dirty=!0,this.stencilFunc.dirty=!0,this.stencilOp.dirty=!0,this.stencilTest.dirty=!0,this.depthRange.dirty=!0,this.depthTest.dirty=!0,this.depthFunc.dirty=!0,this.blend.dirty=!0,this.blendFunc.dirty=!0,this.blendColor.dirty=!0,this.blendEquation.dirty=!0,this.cullFace.dirty=!0,this.cullFaceSide.dirty=!0,this.frontFace.dirty=!0,this.program.dirty=!0,this.activeTexture.dirty=!0,this.viewport.dirty=!0,this.bindFramebuffer.dirty=!0,this.bindRenderbuffer.dirty=!0,this.bindTexture.dirty=!0,this.bindVertexBuffer.dirty=!0,this.bindElementBuffer.dirty=!0,this.extVertexArrayObject&&(this.bindVertexArrayOES.dirty=!0),this.pixelStoreUnpack.dirty=!0,this.pixelStoreUnpackPremultiplyAlpha.dirty=!0,this.pixelStoreUnpackFlipY.dirty=!0},Et.prototype.createIndexBuffer=function(t,e){return new N(this,t,e)},Et.prototype.createVertexBuffer=function(t,e,r){return new U(this,t,e,r)},Et.prototype.createRenderbuffer=function(t,e,r){var n=this.gl,i=n.createRenderbuffer();return this.bindRenderbuffer.set(i),n.renderbufferStorage(n.RENDERBUFFER,t,e,r),this.bindRenderbuffer.set(null),i},Et.prototype.createFramebuffer=function(t,e){return new kt(this,t,e)},Et.prototype.clear=function(t){var e=t.color,r=t.depth,n=this.gl,i=0;e&&(i|=n.COLOR_BUFFER_BIT,this.clearColor.set(e),this.colorMask.set([!0,!0,!0,!0])),void 0!==r&&(i|=n.DEPTH_BUFFER_BIT,this.depthRange.set([0,1]),this.clearDepth.set(r),this.depthMask.set(!0)),n.clear(i)},Et.prototype.setCullFace=function(t){!1===t.enable?this.cullFace.set(!1):(this.cullFace.set(!0),this.cullFaceSide.set(t.mode),this.frontFace.set(t.frontFace))},Et.prototype.setDepthMode=function(t){t.func!==this.gl.ALWAYS||t.mask?(this.depthTest.set(!0),this.depthFunc.set(t.func),this.depthMask.set(t.mask),this.depthRange.set(t.range)):this.depthTest.set(!1)},Et.prototype.setStencilMode=function(t){t.test.func!==this.gl.ALWAYS||t.mask?(this.stencilTest.set(!0),this.stencilMask.set(t.mask),this.stencilOp.set([t.fail,t.depthFail,t.pass]),this.stencilFunc.set({func:t.test.func,ref:t.ref,mask:t.test.mask})):this.stencilTest.set(!1)},Et.prototype.setColorMode=function(e){t.deepEqual(e.blendFunction,Mt.Replace)?this.blend.set(!1):(this.blend.set(!0),this.blendFunc.set(e.blendFunction),this.blendColor.set(e.blendColor)),this.colorMask.set(e.mask)},Et.prototype.unbindVAO=function(){this.extVertexArrayObject&&this.bindVertexArrayOES.set(null)};var Ct=function(e){function r(r,n,i){var a=this;e.call(this),this.id=r,this.dispatcher=i,this.on(\"data\",function(t){\"source\"===t.dataType&&\"metadata\"===t.sourceDataType&&(a._sourceLoaded=!0),a._sourceLoaded&&!a._paused&&\"source\"===t.dataType&&\"content\"===t.sourceDataType&&(a.reload(),a.transform&&a.update(a.transform))}),this.on(\"error\",function(){a._sourceErrored=!0}),this._source=I(r,n,i,this),this._tiles={},this._cache=new B(0,this._unloadTile.bind(this)),this._timers={},this._cacheTimers={},this._maxTileCacheSize=null,this._coveredTiles={},this._state=new t.SourceFeatureState}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.onAdd=function(t){this.map=t,this._maxTileCacheSize=t?t._maxTileCacheSize:null,this._source&&this._source.onAdd&&this._source.onAdd(t)},r.prototype.onRemove=function(t){this._source&&this._source.onRemove&&this._source.onRemove(t)},r.prototype.loaded=function(){if(this._sourceErrored)return!0;if(!this._sourceLoaded)return!1;for(var t in this._tiles){var e=this._tiles[t];if(\"loaded\"!==e.state&&\"errored\"!==e.state)return!1}return!0},r.prototype.getSource=function(){return this._source},r.prototype.pause=function(){this._paused=!0},r.prototype.resume=function(){if(this._paused){var t=this._shouldReloadOnResume;this._paused=!1,this._shouldReloadOnResume=!1,t&&this.reload(),this.transform&&this.update(this.transform)}},r.prototype._loadTile=function(t,e){return this._source.loadTile(t,e)},r.prototype._unloadTile=function(t){if(this._source.unloadTile)return this._source.unloadTile(t,function(){})},r.prototype._abortTile=function(t){if(this._source.abortTile)return this._source.abortTile(t,function(){})},r.prototype.serialize=function(){return this._source.serialize()},r.prototype.prepare=function(t){for(var e in this._source.prepare&&this._source.prepare(),this._state.coalesceChanges(this._tiles,this.map?this.map.painter:null),this._tiles){var r=this._tiles[e];r.upload(t),r.prepare(this.map.style.imageManager)}},r.prototype.getIds=function(){return Object.keys(this._tiles).map(Number).sort(Lt)},r.prototype.getRenderableIds=function(e){var r=this,n=[];for(var i in this._tiles)this._isIdRenderable(+i,e)&&n.push(+i);return e?n.sort(function(e,n){var i=r._tiles[e].tileID,a=r._tiles[n].tileID,o=new t.Point(i.canonical.x,i.canonical.y)._rotate(r.transform.angle),s=new t.Point(a.canonical.x,a.canonical.y)._rotate(r.transform.angle);return i.overscaledZ-a.overscaledZ||s.y-o.y||s.x-o.x}):n.sort(Lt)},r.prototype.hasRenderableParent=function(t){var e=this.findLoadedParent(t,0);return!!e&&this._isIdRenderable(e.tileID.key)},r.prototype._isIdRenderable=function(t,e){return this._tiles[t]&&this._tiles[t].hasData()&&!this._coveredTiles[t]&&(e||!this._tiles[t].holdingForFade())},r.prototype.reload=function(){if(this._paused)this._shouldReloadOnResume=!0;else for(var t in this._cache.reset(),this._tiles)\"errored\"!==this._tiles[t].state&&this._reloadTile(t,\"reloading\")},r.prototype._reloadTile=function(t,e){var r=this._tiles[t];r&&(\"loading\"!==r.state&&(r.state=e),this._loadTile(r,this._tileLoaded.bind(this,r,t,e)))},r.prototype._tileLoaded=function(e,r,n,i){if(i)return e.state=\"errored\",void(404!==i.status?this._source.fire(new t.ErrorEvent(i,{tile:e})):this.update(this.transform));e.timeAdded=t.browser.now(),\"expired\"===n&&(e.refreshedUponExpiration=!0),this._setTileReloadTimer(r,e),\"raster-dem\"===this.getSource().type&&e.dem&&this._backfillDEM(e),this._state.initializeTileState(e,this.map?this.map.painter:null),this._source.fire(new t.Event(\"data\",{dataType:\"source\",tile:e,coord:e.tileID}))},r.prototype._backfillDEM=function(t){for(var e=this.getRenderableIds(),r=0;r<e.length;r++){var n=e[r];if(t.neighboringTiles&&t.neighboringTiles[n]){var i=this.getTileByID(n);a(t,i),a(i,t)}}function a(t,e){t.needsHillshadePrepare=!0;var r=e.tileID.canonical.x-t.tileID.canonical.x,n=e.tileID.canonical.y-t.tileID.canonical.y,i=Math.pow(2,t.tileID.canonical.z),a=e.tileID.key;0===r&&0===n||Math.abs(n)>1||(Math.abs(r)>1&&(1===Math.abs(r+i)?r+=i:1===Math.abs(r-i)&&(r-=i)),e.dem&&t.dem&&(t.dem.backfillBorder(e.dem,r,n),t.neighboringTiles&&t.neighboringTiles[a]&&(t.neighboringTiles[a].backfilled=!0)))}},r.prototype.getTile=function(t){return this.getTileByID(t.key)},r.prototype.getTileByID=function(t){return this._tiles[t]},r.prototype.getZoom=function(t){return t.zoom+t.scaleZoom(t.tileSize/this._source.tileSize)},r.prototype._retainLoadedChildren=function(t,e,r,n){for(var i in this._tiles){var a=this._tiles[i];if(!(n[i]||!a.hasData()||a.tileID.overscaledZ<=e||a.tileID.overscaledZ>r)){for(var o=a.tileID;a&&a.tileID.overscaledZ>e+1;){var s=a.tileID.scaledTo(a.tileID.overscaledZ-1);(a=this._tiles[s.key])&&a.hasData()&&(o=s)}for(var l=o;l.overscaledZ>e;)if(t[(l=l.scaledTo(l.overscaledZ-1)).key]){n[o.key]=o;break}}}},r.prototype.findLoadedParent=function(t,e){for(var r=t.overscaledZ-1;r>=e;r--){var n=t.scaledTo(r);if(!n)return;var i=String(n.key),a=this._tiles[i];if(a&&a.hasData())return a;if(this._cache.has(n))return this._cache.get(n)}},r.prototype.updateCacheSize=function(t){var e=(Math.ceil(t.width/this._source.tileSize)+1)*(Math.ceil(t.height/this._source.tileSize)+1),r=Math.floor(5*e),n=\"number\"==typeof this._maxTileCacheSize?Math.min(this._maxTileCacheSize,r):r;this._cache.setMaxSize(n)},r.prototype.handleWrapJump=function(t){var e=(t-(void 0===this._prevLng?t:this._prevLng))/360,r=Math.round(e);if(this._prevLng=t,r){var n={};for(var i in this._tiles){var a=this._tiles[i];a.tileID=a.tileID.unwrapTo(a.tileID.wrap+r),n[a.tileID.key]=a}for(var o in this._tiles=n,this._timers)clearTimeout(this._timers[o]),delete this._timers[o];for(var s in this._tiles){var l=this._tiles[s];this._setTileReloadTimer(s,l)}}},r.prototype.update=function(e){var n=this;if(this.transform=e,this._sourceLoaded&&!this._paused){var i;this.updateCacheSize(e),this.handleWrapJump(this.transform.center.lng),this._coveredTiles={},this.used?this._source.tileID?i=e.getVisibleUnwrappedCoordinates(this._source.tileID).map(function(e){return new t.OverscaledTileID(e.canonical.z,e.wrap,e.canonical.z,e.canonical.x,e.canonical.y)}):(i=e.coveringTiles({tileSize:this._source.tileSize,minzoom:this._source.minzoom,maxzoom:this._source.maxzoom,roundZoom:this._source.roundZoom,reparseOverscaled:this._source.reparseOverscaled}),this._source.hasTile&&(i=i.filter(function(t){return n._source.hasTile(t)}))):i=[];var a=(this._source.roundZoom?Math.round:Math.floor)(this.getZoom(e)),o=Math.max(a-r.maxOverzooming,this._source.minzoom),s=Math.max(a+r.maxUnderzooming,this._source.minzoom),l=this._updateRetainedTiles(i,a);if(Pt(this._source.type)){for(var c={},u={},h=0,f=Object.keys(l);h<f.length;h+=1){var p=f[h],d=l[p],g=this._tiles[p];if(g&&!(g.fadeEndTime&&g.fadeEndTime<=t.browser.now())){var v=this.findLoadedParent(d,o);v&&(this._addTile(v.tileID),c[v.tileID.key]=v.tileID),u[p]=d}}for(var m in this._retainLoadedChildren(u,a,s,l),c)l[m]||(this._coveredTiles[m]=!0,l[m]=c[m])}for(var y in l)this._tiles[y].clearFadeHold();for(var x=0,b=t.keysDifference(this._tiles,l);x<b.length;x+=1){var _=b[x],w=this._tiles[_];w.hasSymbolBuckets&&!w.holdingForFade()?w.setHoldDuration(this.map._fadeDuration):w.hasSymbolBuckets&&!w.symbolFadeFinished()||this._removeTile(_)}}},r.prototype.releaseSymbolFadeTiles=function(){for(var t in this._tiles)this._tiles[t].holdingForFade()&&this._removeTile(t)},r.prototype._updateRetainedTiles=function(t,e){for(var n={},i={},a=Math.max(e-r.maxOverzooming,this._source.minzoom),o=Math.max(e+r.maxUnderzooming,this._source.minzoom),s={},l=0,c=t;l<c.length;l+=1){var u=c[l],h=this._addTile(u);n[u.key]=u,h.hasData()||e<this._source.maxzoom&&(s[u.key]=u)}this._retainLoadedChildren(s,e,o,n);for(var f=0,p=t;f<p.length;f+=1){var d=p[f],g=this._tiles[d.key];if(!g.hasData()){if(e+1>this._source.maxzoom){var v=d.children(this._source.maxzoom)[0],m=this.getTile(v);if(m&&m.hasData()){n[v.key]=v;continue}}else{var y=d.children(this._source.maxzoom);if(n[y[0].key]&&n[y[1].key]&&n[y[2].key]&&n[y[3].key])continue}for(var x=g.wasRequested(),b=d.overscaledZ-1;b>=a;--b){var _=d.scaledTo(b);if(i[_.key])break;if(i[_.key]=!0,!(g=this.getTile(_))&&x&&(g=this._addTile(_)),g&&(n[_.key]=_,x=g.wasRequested(),g.hasData()))break}}}return n},r.prototype._addTile=function(e){var r=this._tiles[e.key];if(r)return r;(r=this._cache.getAndRemove(e))&&(this._setTileReloadTimer(e.key,r),r.tileID=e,this._state.initializeTileState(r,this.map?this.map.painter:null),this._cacheTimers[e.key]&&(clearTimeout(this._cacheTimers[e.key]),delete this._cacheTimers[e.key],this._setTileReloadTimer(e.key,r)));var n=Boolean(r);return n||(r=new t.Tile(e,this._source.tileSize*e.overscaleFactor()),this._loadTile(r,this._tileLoaded.bind(this,r,e.key,r.state))),r?(r.uses++,this._tiles[e.key]=r,n||this._source.fire(new t.Event(\"dataloading\",{tile:r,coord:r.tileID,dataType:\"source\"})),r):null},r.prototype._setTileReloadTimer=function(t,e){var r=this;t in this._timers&&(clearTimeout(this._timers[t]),delete this._timers[t]);var n=e.getExpiryTimeout();n&&(this._timers[t]=setTimeout(function(){r._reloadTile(t,\"expired\"),delete r._timers[t]},n))},r.prototype._removeTile=function(t){var e=this._tiles[t];e&&(e.uses--,delete this._tiles[t],this._timers[t]&&(clearTimeout(this._timers[t]),delete this._timers[t]),e.uses>0||(e.hasData()?this._cache.add(e.tileID,e,e.getExpiryTimeout()):(e.aborted=!0,this._abortTile(e),this._unloadTile(e))))},r.prototype.clearTiles=function(){for(var t in this._shouldReloadOnResume=!1,this._paused=!1,this._tiles)this._removeTile(t);this._cache.reset()},r.prototype.tilesIn=function(e,r,n){var i=this,a=[],o=this.transform;if(!o)return a;for(var s=n?o.getCameraQueryGeometry(e):e,l=e.map(function(t){return o.pointCoordinate(t)}),c=s.map(function(t){return o.pointCoordinate(t)}),u=this.getIds(),h=1/0,f=1/0,p=-1/0,d=-1/0,g=0,v=c;g<v.length;g+=1){var m=v[g];h=Math.min(h,m.x),f=Math.min(f,m.y),p=Math.max(p,m.x),d=Math.max(d,m.y)}for(var y=function(e){var n=i._tiles[u[e]];if(!n.holdingForFade()){var s=n.tileID,g=Math.pow(2,o.zoom-n.tileID.overscaledZ),v=r*n.queryPadding*t.EXTENT/n.tileSize/g,m=[s.getTilePoint(new t.MercatorCoordinate(h,f)),s.getTilePoint(new t.MercatorCoordinate(p,d))];if(m[0].x-v<t.EXTENT&&m[0].y-v<t.EXTENT&&m[1].x+v>=0&&m[1].y+v>=0){var y=l.map(function(t){return s.getTilePoint(t)}),x=c.map(function(t){return s.getTilePoint(t)});a.push({tile:n,tileID:s,queryGeometry:y,cameraQueryGeometry:x,scale:g})}}},x=0;x<u.length;x++)y(x);return a},r.prototype.getVisibleCoordinates=function(t){for(var e=this,r=this.getRenderableIds(t).map(function(t){return e._tiles[t].tileID}),n=0,i=r;n<i.length;n+=1){var a=i[n];a.posMatrix=this.transform.calculatePosMatrix(a.toUnwrapped())}return r},r.prototype.hasTransition=function(){if(this._source.hasTransition())return!0;if(Pt(this._source.type))for(var e in this._tiles){var r=this._tiles[e];if(void 0!==r.fadeEndTime&&r.fadeEndTime>=t.browser.now())return!0}return!1},r.prototype.setFeatureState=function(t,e,r){t=t||\"_geojsonTileLayer\",this._state.updateState(t,e,r)},r.prototype.removeFeatureState=function(t,e,r){t=t||\"_geojsonTileLayer\",this._state.removeFeatureState(t,e,r)},r.prototype.getFeatureState=function(t,e){return t=t||\"_geojsonTileLayer\",this._state.getState(t,e)},r}(t.Evented);function Lt(t,e){return t%32-e%32||e-t}function Pt(t){return\"raster\"===t||\"image\"===t||\"video\"===t}function Ot(){return new t.window.Worker(Jn.workerUrl)}Ct.maxOverzooming=10,Ct.maxUnderzooming=3;var zt=function(){this.active={}};zt.prototype.acquire=function(t){if(!this.workers)for(this.workers=[];this.workers.length<zt.workerCount;)this.workers.push(new Ot);return this.active[t]=!0,this.workers.slice()},zt.prototype.release=function(t){delete this.active[t],0===Object.keys(this.active).length&&(this.workers.forEach(function(t){t.terminate()}),this.workers=null)};var It,Dt=Math.floor(t.browser.hardwareConcurrency/2);function Rt(e,r){var n={};for(var i in e)\"ref\"!==i&&(n[i]=e[i]);return t.refProperties.forEach(function(t){t in r&&(n[t]=r[t])}),n}function Ft(t){t=t.slice();for(var e=Object.create(null),r=0;r<t.length;r++)e[t[r].id]=t[r];for(var n=0;n<t.length;n++)\"ref\"in t[n]&&(t[n]=Rt(t[n],e[t[n].ref]));return t}zt.workerCount=Math.max(Math.min(Dt,6),1);var Bt={setStyle:\"setStyle\",addLayer:\"addLayer\",removeLayer:\"removeLayer\",setPaintProperty:\"setPaintProperty\",setLayoutProperty:\"setLayoutProperty\",setFilter:\"setFilter\",addSource:\"addSource\",removeSource:\"removeSource\",setGeoJSONSourceData:\"setGeoJSONSourceData\",setLayerZoomRange:\"setLayerZoomRange\",setLayerProperty:\"setLayerProperty\",setCenter:\"setCenter\",setZoom:\"setZoom\",setBearing:\"setBearing\",setPitch:\"setPitch\",setSprite:\"setSprite\",setGlyphs:\"setGlyphs\",setTransition:\"setTransition\",setLight:\"setLight\"};function Nt(t,e,r){r.push({command:Bt.addSource,args:[t,e[t]]})}function jt(t,e,r){e.push({command:Bt.removeSource,args:[t]}),r[t]=!0}function Ut(t,e,r,n){jt(t,r,n),Nt(t,e,r)}function Vt(e,r,n){var i;for(i in e[n])if(e[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;for(i in r[n])if(r[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;return!0}function qt(e,r,n,i,a,o){var s;for(s in r=r||{},e=e||{})e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}));for(s in r)r.hasOwnProperty(s)&&!e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}))}function Ht(t){return t.id}function Gt(t,e){return t[e.id]=e,t}var Yt=function(t,e,r){var n=this.boxCells=[],i=this.circleCells=[];this.xCellCount=Math.ceil(t/r),this.yCellCount=Math.ceil(e/r);for(var a=0;a<this.xCellCount*this.yCellCount;a++)n.push([]),i.push([]);this.circleKeys=[],this.boxKeys=[],this.bboxes=[],this.circles=[],this.width=t,this.height=e,this.xScale=this.xCellCount/t,this.yScale=this.yCellCount/e,this.boxUid=0,this.circleUid=0};function Wt(e,r,n,i,a){var o=t.create();return r?(t.scale(o,o,[1/a,1/a,1]),n||t.rotateZ(o,o,i.angle)):t.multiply(o,i.labelPlaneMatrix,e),o}function Xt(e,r,n,i,a){if(r){var o=t.clone(e);return t.scale(o,o,[a,a,1]),n||t.rotateZ(o,o,-i.angle),o}return i.glCoordMatrix}function Zt(e,r){var n=[e.x,e.y,0,1];ae(n,n,r);var i=n[3];return{point:new t.Point(n[0]/i,n[1]/i),signedDistanceFromCamera:i}}function Jt(t,e){var r=t[0]/t[3],n=t[1]/t[3];return r>=-e[0]&&r<=e[0]&&n>=-e[1]&&n<=e[1]}function Kt(e,r,n,i,a,o,s,l){var c=i?e.textSizeData:e.iconSizeData,u=t.evaluateSizeForZoom(c,n.transform.zoom),h=[256/n.width*2+1,256/n.height*2+1],f=i?e.text.dynamicLayoutVertexArray:e.icon.dynamicLayoutVertexArray;f.clear();for(var p=e.lineVertexArray,d=i?e.text.placedSymbolArray:e.icon.placedSymbolArray,g=n.transform.width/n.transform.height,v=!1,m=0;m<d.length;m++){var y=d.get(m);if(y.hidden||y.writingMode===t.WritingMode.vertical&&!v)ie(y.numGlyphs,f);else{v=!1;var x=[y.anchorX,y.anchorY,0,1];if(t.transformMat4(x,x,r),Jt(x,h)){var b=.5+x[3]/n.transform.cameraToCenterDistance*.5,_=t.evaluateSizeForFeature(c,u,y),w=s?_*b:_/b,k=new t.Point(y.anchorX,y.anchorY),T=Zt(k,a).point,A={},M=te(y,w,!1,l,r,a,o,e.glyphOffsetArray,p,f,T,k,A,g);v=M.useVertical,(M.notEnoughRoom||v||M.needsFlipping&&te(y,w,!0,l,r,a,o,e.glyphOffsetArray,p,f,T,k,A,g).notEnoughRoom)&&ie(y.numGlyphs,f)}else ie(y.numGlyphs,f)}}i?e.text.dynamicLayoutVertexBuffer.updateData(f):e.icon.dynamicLayoutVertexBuffer.updateData(f)}function $t(t,e,r,n,i,a,o,s,l,c,u,h){var f=s.glyphStartIndex+s.numGlyphs,p=s.lineStartIndex,d=s.lineStartIndex+s.lineLength,g=e.getoffsetX(s.glyphStartIndex),v=e.getoffsetX(f-1),m=re(t*g,r,n,i,a,o,s.segment,p,d,l,c,u,h);if(!m)return null;var y=re(t*v,r,n,i,a,o,s.segment,p,d,l,c,u,h);return y?{first:m,last:y}:null}function Qt(e,r,n,i){return e===t.WritingMode.horizontal&&Math.abs(n.y-r.y)>Math.abs(n.x-r.x)*i?{useVertical:!0}:(e===t.WritingMode.vertical?r.y<n.y:r.x>n.x)?{needsFlipping:!0}:null}function te(e,r,n,i,a,o,s,l,c,u,h,f,p,d){var g,v=r/24,m=e.lineOffsetX*v,y=e.lineOffsetY*v;if(e.numGlyphs>1){var x=e.glyphStartIndex+e.numGlyphs,b=e.lineStartIndex,_=e.lineStartIndex+e.lineLength,w=$t(v,l,m,y,n,h,f,e,c,o,p,!1);if(!w)return{notEnoughRoom:!0};var k=Zt(w.first.point,s).point,T=Zt(w.last.point,s).point;if(i&&!n){var A=Qt(e.writingMode,k,T,d);if(A)return A}g=[w.first];for(var M=e.glyphStartIndex+1;M<x-1;M++)g.push(re(v*l.getoffsetX(M),m,y,n,h,f,e.segment,b,_,c,o,p,!1));g.push(w.last)}else{if(i&&!n){var S=Zt(f,a).point,E=e.lineStartIndex+e.segment+1,C=new t.Point(c.getx(E),c.gety(E)),L=Zt(C,a),P=L.signedDistanceFromCamera>0?L.point:ee(f,C,S,1,a),O=Qt(e.writingMode,S,P,d);if(O)return O}var z=re(v*l.getoffsetX(e.glyphStartIndex),m,y,n,h,f,e.segment,e.lineStartIndex,e.lineStartIndex+e.lineLength,c,o,p,!1);if(!z)return{notEnoughRoom:!0};g=[z]}for(var I=0,D=g;I<D.length;I+=1){var R=D[I];t.addDynamicAttributes(u,R.point,R.angle)}return{}}function ee(t,e,r,n,i){var a=Zt(t.add(t.sub(e)._unit()),i).point,o=r.sub(a);return r.add(o._mult(n/o.mag()))}function re(e,r,n,i,a,o,s,l,c,u,h,f,p){var d=i?e-r:e+r,g=d>0?1:-1,v=0;i&&(g*=-1,v=Math.PI),g<0&&(v+=Math.PI);for(var m=g>0?l+s:l+s+1,y=m,x=a,b=a,_=0,w=0,k=Math.abs(d);_+w<=k;){if((m+=g)<l||m>=c)return null;if(b=x,void 0===(x=f[m])){var T=new t.Point(u.getx(m),u.gety(m)),A=Zt(T,h);if(A.signedDistanceFromCamera>0)x=f[m]=A.point;else{var M=m-g;x=ee(0===_?o:new t.Point(u.getx(M),u.gety(M)),T,b,k-_+1,h)}}_+=w,w=b.dist(x)}var S=(k-_)/w,E=x.sub(b),C=E.mult(S)._add(b);return C._add(E._unit()._perp()._mult(n*g)),{point:C,angle:v+Math.atan2(x.y-b.y,x.x-b.x),tileDistance:p?{prevTileDistance:m-g===y?0:u.gettileUnitDistanceFromAnchor(m-g),lastSegmentViewportDistance:k-_}:null}}Yt.prototype.keysLength=function(){return this.boxKeys.length+this.circleKeys.length},Yt.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertBoxCell,this.boxUid++),this.boxKeys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},Yt.prototype.insertCircle=function(t,e,r,n){this._forEachCell(e-n,r-n,e+n,r+n,this._insertCircleCell,this.circleUid++),this.circleKeys.push(t),this.circles.push(e),this.circles.push(r),this.circles.push(n)},Yt.prototype._insertBoxCell=function(t,e,r,n,i,a){this.boxCells[i].push(a)},Yt.prototype._insertCircleCell=function(t,e,r,n,i,a){this.circleCells[i].push(a)},Yt.prototype._query=function(t,e,r,n,i,a){if(r<0||t>this.width||n<0||e>this.height)return!i&&[];var o=[];if(t<=0&&e<=0&&this.width<=r&&this.height<=n){if(i)return!0;for(var s=0;s<this.boxKeys.length;s++)o.push({key:this.boxKeys[s],x1:this.bboxes[4*s],y1:this.bboxes[4*s+1],x2:this.bboxes[4*s+2],y2:this.bboxes[4*s+3]});for(var l=0;l<this.circleKeys.length;l++){var c=this.circles[3*l],u=this.circles[3*l+1],h=this.circles[3*l+2];o.push({key:this.circleKeys[l],x1:c-h,y1:u-h,x2:c+h,y2:u+h})}return a?o.filter(a):o}var f={hitTest:i,seenUids:{box:{},circle:{}}};return this._forEachCell(t,e,r,n,this._queryCell,o,f,a),i?o.length>0:o},Yt.prototype._queryCircle=function(t,e,r,n,i){var a=t-r,o=t+r,s=e-r,l=e+r;if(o<0||a>this.width||l<0||s>this.height)return!n&&[];var c=[],u={hitTest:n,circle:{x:t,y:e,radius:r},seenUids:{box:{},circle:{}}};return this._forEachCell(a,s,o,l,this._queryCellCircle,c,u,i),n?c.length>0:c},Yt.prototype.query=function(t,e,r,n,i){return this._query(t,e,r,n,!1,i)},Yt.prototype.hitTest=function(t,e,r,n,i){return this._query(t,e,r,n,!0,i)},Yt.prototype.hitTestCircle=function(t,e,r,n){return this._queryCircle(t,e,r,!0,n)},Yt.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=o.seenUids,c=this.boxCells[i];if(null!==c)for(var u=this.bboxes,h=0,f=c;h<f.length;h+=1){var p=f[h];if(!l.box[p]){l.box[p]=!0;var d=4*p;if(t<=u[d+2]&&e<=u[d+3]&&r>=u[d+0]&&n>=u[d+1]&&(!s||s(this.boxKeys[p]))){if(o.hitTest)return a.push(!0),!0;a.push({key:this.boxKeys[p],x1:u[d],y1:u[d+1],x2:u[d+2],y2:u[d+3]})}}}var g=this.circleCells[i];if(null!==g)for(var v=this.circles,m=0,y=g;m<y.length;m+=1){var x=y[m];if(!l.circle[x]){l.circle[x]=!0;var b=3*x;if(this._circleAndRectCollide(v[b],v[b+1],v[b+2],t,e,r,n)&&(!s||s(this.circleKeys[x]))){if(o.hitTest)return a.push(!0),!0;var _=v[b],w=v[b+1],k=v[b+2];a.push({key:this.circleKeys[x],x1:_-k,y1:w-k,x2:_+k,y2:w+k})}}}},Yt.prototype._queryCellCircle=function(t,e,r,n,i,a,o,s){var l=o.circle,c=o.seenUids,u=this.boxCells[i];if(null!==u)for(var h=this.bboxes,f=0,p=u;f<p.length;f+=1){var d=p[f];if(!c.box[d]){c.box[d]=!0;var g=4*d;if(this._circleAndRectCollide(l.x,l.y,l.radius,h[g+0],h[g+1],h[g+2],h[g+3])&&(!s||s(this.boxKeys[d])))return a.push(!0),!0}}var v=this.circleCells[i];if(null!==v)for(var m=this.circles,y=0,x=v;y<x.length;y+=1){var b=x[y];if(!c.circle[b]){c.circle[b]=!0;var _=3*b;if(this._circlesCollide(m[_],m[_+1],m[_+2],l.x,l.y,l.radius)&&(!s||s(this.circleKeys[b])))return a.push(!0),!0}}},Yt.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToXCellCoord(t),c=this._convertToYCellCoord(e),u=this._convertToXCellCoord(r),h=this._convertToYCellCoord(n),f=l;f<=u;f++)for(var p=c;p<=h;p++){var d=this.xCellCount*p+f;if(i.call(this,t,e,r,n,d,a,o,s))return}},Yt.prototype._convertToXCellCoord=function(t){return Math.max(0,Math.min(this.xCellCount-1,Math.floor(t*this.xScale)))},Yt.prototype._convertToYCellCoord=function(t){return Math.max(0,Math.min(this.yCellCount-1,Math.floor(t*this.yScale)))},Yt.prototype._circlesCollide=function(t,e,r,n,i,a){var o=n-t,s=i-e,l=r+a;return l*l>o*o+s*s},Yt.prototype._circleAndRectCollide=function(t,e,r,n,i,a,o){var s=(a-n)/2,l=Math.abs(t-(n+s));if(l>s+r)return!1;var c=(o-i)/2,u=Math.abs(e-(i+c));if(u>c+r)return!1;if(l<=s||u<=c)return!0;var h=l-s,f=u-c;return h*h+f*f<=r*r};var ne=new Float32Array([-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0]);function ie(t,e){for(var r=0;r<t;r++){var n=e.length;e.resize(n+4),e.float32.set(ne,3*n)}}function ae(t,e,r){var n=e[0],i=e[1];return t[0]=r[0]*n+r[4]*i+r[12],t[1]=r[1]*n+r[5]*i+r[13],t[3]=r[3]*n+r[7]*i+r[15],t}var oe=function(t,e,r){void 0===e&&(e=new Yt(t.width+200,t.height+200,25)),void 0===r&&(r=new Yt(t.width+200,t.height+200,25)),this.transform=t,this.grid=e,this.ignoredGrid=r,this.pitchfactor=Math.cos(t._pitch)*t.cameraToCenterDistance,this.screenRightBoundary=t.width+100,this.screenBottomBoundary=t.height+100,this.gridRightBoundary=t.width+200,this.gridBottomBoundary=t.height+200};function se(t,e,r){t[e+4]=r?1:0}function le(e,r,n){return r*(t.EXTENT/(e.tileSize*Math.pow(2,n-e.tileID.overscaledZ)))}oe.prototype.placeCollisionBox=function(t,e,r,n,i){var a=this.projectAndGetPerspectiveRatio(n,t.anchorPointX,t.anchorPointY),o=r*a.perspectiveRatio,s=t.x1*o+a.point.x,l=t.y1*o+a.point.y,c=t.x2*o+a.point.x,u=t.y2*o+a.point.y;return!this.isInsideGrid(s,l,c,u)||!e&&this.grid.hitTest(s,l,c,u,i)?{box:[],offscreen:!1}:{box:[s,l,c,u],offscreen:this.isOffscreen(s,l,c,u)}},oe.prototype.approximateTileDistance=function(t,e,r,n,i){var a=i?1:n/this.pitchfactor,o=t.lastSegmentViewportDistance*r;return t.prevTileDistance+o+(a-1)*o*Math.abs(Math.sin(e))},oe.prototype.placeCollisionCircles=function(e,r,n,i,a,o,s,l,c,u,h,f,p){var d=[],g=this.projectAnchor(c,a.anchorX,a.anchorY),v=l/24,m=a.lineOffsetX*l,y=a.lineOffsetY*l,x=new t.Point(a.anchorX,a.anchorY),b=$t(v,s,m,y,!1,Zt(x,u).point,x,a,o,u,{},!0),_=!1,w=!1,k=!0,T=g.perspectiveRatio*i,A=1/(i*n),M=0,S=0;b&&(M=this.approximateTileDistance(b.first.tileDistance,b.first.angle,A,g.cameraDistance,f),S=this.approximateTileDistance(b.last.tileDistance,b.last.angle,A,g.cameraDistance,f));for(var E=0;E<e.length;E+=5){var C=e[E],L=e[E+1],P=e[E+2],O=e[E+3];if(!b||O<-M||O>S)se(e,E,!1);else{var z=this.projectPoint(c,C,L),I=P*T;if(d.length>0){var D=z.x-d[d.length-4],R=z.y-d[d.length-3];if(I*I*2>D*D+R*R&&E+8<e.length){var F=e[E+8];if(F>-M&&F<S){se(e,E,!1);continue}}}var B=E/5;d.push(z.x,z.y,I,B),se(e,E,!0);var N=z.x-I,j=z.y-I,U=z.x+I,V=z.y+I;if(k=k&&this.isOffscreen(N,j,U,V),w=w||this.isInsideGrid(N,j,U,V),!r&&this.grid.hitTestCircle(z.x,z.y,I,p)){if(!h)return{circles:[],offscreen:!1};_=!0}}}return{circles:_||!w?[]:d,offscreen:k}},oe.prototype.queryRenderedSymbols=function(e){if(0===e.length||0===this.grid.keysLength()&&0===this.ignoredGrid.keysLength())return{};for(var r=[],n=1/0,i=1/0,a=-1/0,o=-1/0,s=0,l=e;s<l.length;s+=1){var c=l[s],u=new t.Point(c.x+100,c.y+100);n=Math.min(n,u.x),i=Math.min(i,u.y),a=Math.max(a,u.x),o=Math.max(o,u.y),r.push(u)}for(var h={},f={},p=0,d=this.grid.query(n,i,a,o).concat(this.ignoredGrid.query(n,i,a,o));p<d.length;p+=1){var g=d[p],v=g.key;if(void 0===h[v.bucketInstanceId]&&(h[v.bucketInstanceId]={}),!h[v.bucketInstanceId][v.featureIndex]){var m=[new t.Point(g.x1,g.y1),new t.Point(g.x2,g.y1),new t.Point(g.x2,g.y2),new t.Point(g.x1,g.y2)];t.polygonIntersectsPolygon(r,m)&&(h[v.bucketInstanceId][v.featureIndex]=!0,void 0===f[v.bucketInstanceId]&&(f[v.bucketInstanceId]=[]),f[v.bucketInstanceId].push(v.featureIndex))}}return f},oe.prototype.insertCollisionBox=function(t,e,r,n,i){var a={bucketInstanceId:r,featureIndex:n,collisionGroupID:i};(e?this.ignoredGrid:this.grid).insert(a,t[0],t[1],t[2],t[3])},oe.prototype.insertCollisionCircles=function(t,e,r,n,i){for(var a=e?this.ignoredGrid:this.grid,o={bucketInstanceId:r,featureIndex:n,collisionGroupID:i},s=0;s<t.length;s+=4)a.insertCircle(o,t[s],t[s+1],t[s+2])},oe.prototype.projectAnchor=function(t,e,r){var n=[e,r,0,1];return ae(n,n,t),{perspectiveRatio:.5+this.transform.cameraToCenterDistance/n[3]*.5,cameraDistance:n[3]}},oe.prototype.projectPoint=function(e,r,n){var i=[r,n,0,1];return ae(i,i,e),new t.Point((i[0]/i[3]+1)/2*this.transform.width+100,(-i[1]/i[3]+1)/2*this.transform.height+100)},oe.prototype.projectAndGetPerspectiveRatio=function(e,r,n){var i=[r,n,0,1];return ae(i,i,e),{point:new t.Point((i[0]/i[3]+1)/2*this.transform.width+100,(-i[1]/i[3]+1)/2*this.transform.height+100),perspectiveRatio:.5+this.transform.cameraToCenterDistance/i[3]*.5}},oe.prototype.isOffscreen=function(t,e,r,n){return r<100||t>=this.screenRightBoundary||n<100||e>this.screenBottomBoundary},oe.prototype.isInsideGrid=function(t,e,r,n){return r>=0&&t<this.gridRightBoundary&&n>=0&&e<this.gridBottomBoundary};var ce=function(t,e,r,n){this.opacity=t?Math.max(0,Math.min(1,t.opacity+(t.placed?e:-e))):n&&r?1:0,this.placed=r};ce.prototype.isHidden=function(){return 0===this.opacity&&!this.placed};var ue=function(t,e,r,n,i){this.text=new ce(t?t.text:null,e,r,i),this.icon=new ce(t?t.icon:null,e,n,i)};ue.prototype.isHidden=function(){return this.text.isHidden()&&this.icon.isHidden()};var he=function(t,e,r){this.text=t,this.icon=e,this.skipFade=r},fe=function(t,e,r,n,i){this.bucketInstanceId=t,this.featureIndex=e,this.sourceLayerIndex=r,this.bucketIndex=n,this.tileID=i},pe=function(t){this.crossSourceCollisions=t,this.maxGroupID=0,this.collisionGroups={}};function de(e,r,n,i,a){var o=t.getAnchorAlignment(e),s=-(o.horizontalAlign-.5)*r,l=-(o.verticalAlign-.5)*n,c=t.evaluateRadialOffset(e,i);return new t.Point(s+c[0]*a,l+c[1]*a)}pe.prototype.get=function(t){if(this.crossSourceCollisions)return{ID:0,predicate:null};if(!this.collisionGroups[t]){var e=++this.maxGroupID;this.collisionGroups[t]={ID:e,predicate:function(t){return t.collisionGroupID===e}}}return this.collisionGroups[t]};var ge=function(t,e,r,n){this.transform=t.clone(),this.collisionIndex=new oe(this.transform),this.placements={},this.opacities={},this.variableOffsets={},this.stale=!1,this.commitTime=0,this.fadeDuration=e,this.retainedQueryData={},this.collisionGroups=new pe(r),this.prevPlacement=n,n&&(n.prevPlacement=void 0)};function ve(t,e,r,n,i){t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0)}ge.prototype.placeLayerTile=function(e,r,n,i){var a=r.getBucket(e),o=r.latestFeatureIndex;if(a&&o&&e.id===a.layerIds[0]){var s=r.collisionBoxArray,l=a.layers[0].layout,c=Math.pow(2,this.transform.zoom-r.tileID.overscaledZ),u=r.tileSize/t.EXTENT,h=this.transform.calculatePosMatrix(r.tileID.toUnwrapped()),f=Wt(h,\"map\"===l.get(\"text-pitch-alignment\"),\"map\"===l.get(\"text-rotation-alignment\"),this.transform,le(r,1,this.transform.zoom)),p=Wt(h,\"map\"===l.get(\"icon-pitch-alignment\"),\"map\"===l.get(\"icon-rotation-alignment\"),this.transform,le(r,1,this.transform.zoom));this.retainedQueryData[a.bucketInstanceId]=new fe(a.bucketInstanceId,o,a.sourceLayerIndex,a.index,r.tileID),this.placeLayerBucket(a,h,f,p,c,u,n,r.holdingForFade(),i,s)}},ge.prototype.attemptAnchorPlacement=function(e,r,n,i,a,o,s,l,c,u,h,f,p,d){var g,v=de(e,n,i,a,o),m=this.collisionIndex.placeCollisionBox(function(e,r,n,i,a,o){var s=e.x1,l=e.x2,c=e.y1,u=e.y2,h=e.anchorPointX,f=e.anchorPointY,p=new t.Point(r,n);return i&&p._rotate(a?o:-o),{x1:s+p.x,y1:c+p.y,x2:l+p.x,y2:u+p.y,anchorPointX:h,anchorPointY:f}}(r,v.x,v.y,s,l,this.transform.angle),f,c,u,h.predicate);if(m.box.length>0)return this.prevPlacement&&this.prevPlacement.variableOffsets[p.crossTileID]&&this.prevPlacement.placements[p.crossTileID]&&this.prevPlacement.placements[p.crossTileID].text&&(g=this.prevPlacement.variableOffsets[p.crossTileID].anchor),this.variableOffsets[p.crossTileID]={radialOffset:a,width:n,height:i,anchor:e,textBoxScale:o,prevAnchor:g},this.markUsedJustification(d,e,p),m},ge.prototype.placeLayerBucket=function(e,r,n,i,a,o,s,l,c,u){var h=this,f=e.layers[0].layout,p=t.evaluateSizeForZoom(e.textSizeData,this.transform.zoom),d=f.get(\"text-optional\"),g=f.get(\"icon-optional\"),v=f.get(\"text-allow-overlap\"),m=f.get(\"icon-allow-overlap\"),y=v&&(m||!e.hasIconData()||g),x=m&&(v||!e.hasTextData()||d),b=this.collisionGroups.get(e.sourceID),_=\"map\"===f.get(\"text-rotation-alignment\"),w=\"map\"===f.get(\"text-pitch-alignment\"),k=\"viewport-y\"===f.get(\"symbol-z-order\");!e.collisionArrays&&u&&e.deserializeCollisionBoxes(u);var T=function(i,u){if(!c[i.crossTileID])if(l)h.placements[i.crossTileID]=new he(!1,!1,!1);else{var m=!1,k=!1,T=!0,A=null,M=null,S=null,E=0,C=0;u.textFeatureIndex&&(E=u.textFeatureIndex);var L=u.textBox;if(L)if(f.get(\"text-variable-anchor\")){var P=L.x2-L.x1,O=L.y2-L.y1,z=i.textBoxScale,I=f.get(\"text-variable-anchor\");if(h.prevPlacement&&h.prevPlacement.variableOffsets[i.crossTileID]){var D=h.prevPlacement.variableOffsets[i.crossTileID];I[0]!==D.anchor&&(I=I.filter(function(t){return t!==D.anchor})).unshift(D.anchor)}for(var R=0,F=I;R<F.length;R+=1){var B=F[R];if(A=h.attemptAnchorPlacement(B,L,P,O,i.radialTextOffset,z,_,w,o,r,b,v,i,e)){m=!0;break}}if(!h.variableOffsets[i.crossTileID]&&h.prevPlacement){var N=h.prevPlacement.variableOffsets[i.crossTileID];N&&(h.variableOffsets[i.crossTileID]=N,h.markUsedJustification(e,N.anchor,i))}}else m=(A=h.collisionIndex.placeCollisionBox(L,f.get(\"text-allow-overlap\"),o,r,b.predicate)).box.length>0;T=A&&A.offscreen;var j=u.textCircles;if(j){var U=e.text.placedSymbolArray.get(i.centerJustifiedTextSymbolIndex),V=t.evaluateSizeForFeature(e.textSizeData,p,U);M=h.collisionIndex.placeCollisionCircles(j,f.get(\"text-allow-overlap\"),a,o,U,e.lineVertexArray,e.glyphOffsetArray,V,r,n,s,w,b.predicate),m=f.get(\"text-allow-overlap\")||M.circles.length>0,T=T&&M.offscreen}u.iconFeatureIndex&&(C=u.iconFeatureIndex),u.iconBox&&(k=(S=h.collisionIndex.placeCollisionBox(u.iconBox,f.get(\"icon-allow-overlap\"),o,r,b.predicate)).box.length>0,T=T&&S.offscreen);var q=d||0===i.numHorizontalGlyphVertices&&0===i.numVerticalGlyphVertices,H=g||0===i.numIconVertices;q||H?H?q||(k=k&&m):m=k&&m:k=m=k&&m,m&&A&&h.collisionIndex.insertCollisionBox(A.box,f.get(\"text-ignore-placement\"),e.bucketInstanceId,E,b.ID),k&&S&&h.collisionIndex.insertCollisionBox(S.box,f.get(\"icon-ignore-placement\"),e.bucketInstanceId,C,b.ID),m&&M&&h.collisionIndex.insertCollisionCircles(M.circles,f.get(\"text-ignore-placement\"),e.bucketInstanceId,E,b.ID),h.placements[i.crossTileID]=new he(m||y,k||x,T||e.justReloaded),c[i.crossTileID]=!0}};if(k)for(var A=e.getSortedSymbolIndexes(this.transform.angle),M=A.length-1;M>=0;--M){var S=A[M];T(e.symbolInstances.get(S),e.collisionArrays[S])}else for(var E=0;E<e.symbolInstances.length;++E)T(e.symbolInstances.get(E),e.collisionArrays[E]);e.justReloaded=!1},ge.prototype.markUsedJustification=function(e,r,n){var i={left:n.leftJustifiedTextSymbolIndex,center:n.centerJustifiedTextSymbolIndex,right:n.rightJustifiedTextSymbolIndex},a=i[t.getAnchorJustification(r)];for(var o in i){var s=i[o];s>=0&&(e.text.placedSymbolArray.get(s).crossTileID=a>=0&&s!==a?0:n.crossTileID)}},ge.prototype.commit=function(t){this.commitTime=t;var e=this.prevPlacement,r=!1,n=e&&0!==this.fadeDuration?(this.commitTime-e.commitTime)/this.fadeDuration:1,i=e?e.opacities:{},a=e?e.variableOffsets:{};for(var o in this.placements){var s=this.placements[o],l=i[o];l?(this.opacities[o]=new ue(l,n,s.text,s.icon),r=r||s.text!==l.text.placed||s.icon!==l.icon.placed):(this.opacities[o]=new ue(null,n,s.text,s.icon,s.skipFade),r=r||s.text||s.icon)}for(var c in i){var u=i[c];if(!this.opacities[c]){var h=new ue(u,n,!1,!1);h.isHidden()||(this.opacities[c]=h,r=r||u.text.placed||u.icon.placed)}}for(var f in a)this.variableOffsets[f]||!this.opacities[f]||this.opacities[f].isHidden()||(this.variableOffsets[f]=a[f]);r?this.lastPlacementChangeTime=t:\"number\"!=typeof this.lastPlacementChangeTime&&(this.lastPlacementChangeTime=e?e.lastPlacementChangeTime:t)},ge.prototype.updateLayerOpacities=function(t,e){for(var r={},n=0,i=e;n<i.length;n+=1){var a=i[n],o=a.getBucket(t);o&&a.latestFeatureIndex&&t.id===o.layerIds[0]&&this.updateBucketOpacities(o,r,a.collisionBoxArray)}},ge.prototype.updateBucketOpacities=function(e,r,n){e.hasTextData()&&e.text.opacityVertexArray.clear(),e.hasIconData()&&e.icon.opacityVertexArray.clear(),e.hasCollisionBoxData()&&e.collisionBox.collisionVertexArray.clear(),e.hasCollisionCircleData()&&e.collisionCircle.collisionVertexArray.clear();var i=e.layers[0].layout,a=new ue(null,0,!1,!1,!0),o=i.get(\"text-allow-overlap\"),s=i.get(\"icon-allow-overlap\"),l=i.get(\"text-variable-anchor\"),c=\"map\"===i.get(\"text-rotation-alignment\"),u=\"map\"===i.get(\"text-pitch-alignment\"),h=new ue(null,0,o&&(s||!e.hasIconData()||i.get(\"icon-optional\")),s&&(o||!e.hasTextData()||i.get(\"text-optional\")),!0);!e.collisionArrays&&n&&(e.hasCollisionBoxData()||e.hasCollisionCircleData())&&e.deserializeCollisionBoxes(n);for(var f=0;f<e.symbolInstances.length;f++){var p=e.symbolInstances.get(f),d=p.numHorizontalGlyphVertices,g=p.numVerticalGlyphVertices,v=p.crossTileID,m=r[v],y=this.opacities[v];m?y=a:y||(y=h,this.opacities[v]=y),r[v]=!0;var x=d>0||g>0,b=p.numIconVertices>0;if(x){for(var _=Te(y.text),w=(d+g)/4,k=0;k<w;k++)e.text.opacityVertexArray.emplaceBack(_);var T=y.text.isHidden()?1:0;[p.rightJustifiedTextSymbolIndex,p.centerJustifiedTextSymbolIndex,p.leftJustifiedTextSymbolIndex,p.verticalPlacedTextSymbolIndex].forEach(function(t){t>=0&&(e.text.placedSymbolArray.get(t).hidden=T)});var A=this.variableOffsets[p.crossTileID];A&&this.markUsedJustification(e,A.anchor,p)}if(b){for(var M=Te(y.icon),S=0;S<p.numIconVertices/4;S++)e.icon.opacityVertexArray.emplaceBack(M);e.icon.placedSymbolArray.get(f).hidden=y.icon.isHidden()}if(e.hasCollisionBoxData()||e.hasCollisionCircleData()){var E=e.collisionArrays[f];if(E){if(E.textBox){var C=new t.Point(0,0),L=!0;if(l){var P=this.variableOffsets[v];P?(C=de(P.anchor,P.width,P.height,P.radialOffset,P.textBoxScale),c&&C._rotate(u?this.transform.angle:-this.transform.angle)):L=!1}ve(e.collisionBox.collisionVertexArray,y.text.placed,!L,C.x,C.y)}E.iconBox&&ve(e.collisionBox.collisionVertexArray,y.icon.placed,!1);var O=E.textCircles;if(O&&e.hasCollisionCircleData())for(var z=0;z<O.length;z+=5){var I=m||0===O[z+4];ve(e.collisionCircle.collisionVertexArray,y.text.placed,I)}}}}e.sortFeatures(this.transform.angle),this.retainedQueryData[e.bucketInstanceId]&&(this.retainedQueryData[e.bucketInstanceId].featureSortOrder=e.featureSortOrder),e.hasTextData()&&e.text.opacityVertexBuffer&&e.text.opacityVertexBuffer.updateData(e.text.opacityVertexArray),e.hasIconData()&&e.icon.opacityVertexBuffer&&e.icon.opacityVertexBuffer.updateData(e.icon.opacityVertexArray),e.hasCollisionBoxData()&&e.collisionBox.collisionVertexBuffer&&e.collisionBox.collisionVertexBuffer.updateData(e.collisionBox.collisionVertexArray),e.hasCollisionCircleData()&&e.collisionCircle.collisionVertexBuffer&&e.collisionCircle.collisionVertexBuffer.updateData(e.collisionCircle.collisionVertexArray)},ge.prototype.symbolFadeChange=function(t){return 0===this.fadeDuration?1:(t-this.commitTime)/this.fadeDuration},ge.prototype.hasTransitions=function(t){return this.stale||t-this.lastPlacementChangeTime<this.fadeDuration},ge.prototype.stillRecent=function(t){return this.commitTime+this.fadeDuration>t},ge.prototype.setStale=function(){this.stale=!0};var me=Math.pow(2,25),ye=Math.pow(2,24),xe=Math.pow(2,17),be=Math.pow(2,16),_e=Math.pow(2,9),we=Math.pow(2,8),ke=Math.pow(2,1);function Te(t){if(0===t.opacity&&!t.placed)return 0;if(1===t.opacity&&t.placed)return 4294967295;var e=t.placed?1:0,r=Math.floor(127*t.opacity);return r*me+e*ye+r*xe+e*be+r*_e+e*we+r*ke+e}var Ae=function(){this._currentTileIndex=0,this._seenCrossTileIDs={}};Ae.prototype.continuePlacement=function(t,e,r,n,i){for(;this._currentTileIndex<t.length;){var a=t[this._currentTileIndex];if(e.placeLayerTile(n,a,r,this._seenCrossTileIDs),this._currentTileIndex++,i())return!0}};var Me=function(t,e,r,n,i,a,o){this.placement=new ge(t,i,a,o),this._currentPlacementIndex=e.length-1,this._forceFullPlacement=r,this._showCollisionBoxes=n,this._done=!1};Me.prototype.isDone=function(){return this._done},Me.prototype.continuePlacement=function(e,r,n){for(var i=this,a=t.browser.now(),o=function(){var e=t.browser.now()-a;return!i._forceFullPlacement&&e>2};this._currentPlacementIndex>=0;){var s=r[e[this._currentPlacementIndex]],l=this.placement.collisionIndex.transform.zoom;if(\"symbol\"===s.type&&(!s.minzoom||s.minzoom<=l)&&(!s.maxzoom||s.maxzoom>l)){if(this._inProgressLayer||(this._inProgressLayer=new Ae),this._inProgressLayer.continuePlacement(n[s.source],this.placement,this._showCollisionBoxes,s,o))return;delete this._inProgressLayer}this._currentPlacementIndex--}this._done=!0},Me.prototype.commit=function(t){return this.placement.commit(t),this.placement};var Se=512/t.EXTENT/2,Ee=function(t,e,r){this.tileID=t,this.indexedSymbolInstances={},this.bucketInstanceId=r;for(var n=0;n<e.length;n++){var i=e.get(n),a=i.key;this.indexedSymbolInstances[a]||(this.indexedSymbolInstances[a]=[]),this.indexedSymbolInstances[a].push({crossTileID:i.crossTileID,coord:this.getScaledCoordinates(i,t)})}};Ee.prototype.getScaledCoordinates=function(e,r){var n=r.canonical.z-this.tileID.canonical.z,i=Se/Math.pow(2,n);return{x:Math.floor((r.canonical.x*t.EXTENT+e.anchorX)*i),y:Math.floor((r.canonical.y*t.EXTENT+e.anchorY)*i)}},Ee.prototype.findMatches=function(t,e,r){for(var n=this.tileID.canonical.z<e.canonical.z?1:Math.pow(2,this.tileID.canonical.z-e.canonical.z),i=0;i<t.length;i++){var a=t.get(i);if(!a.crossTileID){var o=this.indexedSymbolInstances[a.key];if(o)for(var s=this.getScaledCoordinates(a,e),l=0,c=o;l<c.length;l+=1){var u=c[l];if(Math.abs(u.coord.x-s.x)<=n&&Math.abs(u.coord.y-s.y)<=n&&!r[u.crossTileID]){r[u.crossTileID]=!0,a.crossTileID=u.crossTileID;break}}}}};var Ce=function(){this.maxCrossTileID=0};Ce.prototype.generate=function(){return++this.maxCrossTileID};var Le=function(){this.indexes={},this.usedCrossTileIDs={},this.lng=0};Le.prototype.handleWrapJump=function(t){var e=Math.round((t-this.lng)/360);if(0!==e)for(var r in this.indexes){var n=this.indexes[r],i={};for(var a in n){var o=n[a];o.tileID=o.tileID.unwrapTo(o.tileID.wrap+e),i[o.tileID.key]=o}this.indexes[r]=i}this.lng=t},Le.prototype.addBucket=function(t,e,r){if(this.indexes[t.overscaledZ]&&this.indexes[t.overscaledZ][t.key]){if(this.indexes[t.overscaledZ][t.key].bucketInstanceId===e.bucketInstanceId)return!1;this.removeBucketCrossTileIDs(t.overscaledZ,this.indexes[t.overscaledZ][t.key])}for(var n=0;n<e.symbolInstances.length;n++)e.symbolInstances.get(n).crossTileID=0;this.usedCrossTileIDs[t.overscaledZ]||(this.usedCrossTileIDs[t.overscaledZ]={});var i=this.usedCrossTileIDs[t.overscaledZ];for(var a in this.indexes){var o=this.indexes[a];if(Number(a)>t.overscaledZ)for(var s in o){var l=o[s];l.tileID.isChildOf(t)&&l.findMatches(e.symbolInstances,t,i)}else{var c=o[t.scaledTo(Number(a)).key];c&&c.findMatches(e.symbolInstances,t,i)}}for(var u=0;u<e.symbolInstances.length;u++){var h=e.symbolInstances.get(u);h.crossTileID||(h.crossTileID=r.generate(),i[h.crossTileID]=!0)}return void 0===this.indexes[t.overscaledZ]&&(this.indexes[t.overscaledZ]={}),this.indexes[t.overscaledZ][t.key]=new Ee(t,e.symbolInstances,e.bucketInstanceId),!0},Le.prototype.removeBucketCrossTileIDs=function(t,e){for(var r in e.indexedSymbolInstances)for(var n=0,i=e.indexedSymbolInstances[r];n<i.length;n+=1){var a=i[n];delete this.usedCrossTileIDs[t][a.crossTileID]}},Le.prototype.removeStaleBuckets=function(t){var e=!1;for(var r in this.indexes){var n=this.indexes[r];for(var i in n)t[n[i].bucketInstanceId]||(this.removeBucketCrossTileIDs(r,n[i]),delete n[i],e=!0)}return e};var Pe=function(){this.layerIndexes={},this.crossTileIDs=new Ce,this.maxBucketInstanceId=0,this.bucketsInCurrentPlacement={}};Pe.prototype.addLayer=function(t,e,r){var n=this.layerIndexes[t.id];void 0===n&&(n=this.layerIndexes[t.id]=new Le);var i=!1,a={};n.handleWrapJump(r);for(var o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.getBucket(t);c&&t.id===c.layerIds[0]&&(c.bucketInstanceId||(c.bucketInstanceId=++this.maxBucketInstanceId),n.addBucket(l.tileID,c,this.crossTileIDs)&&(i=!0),a[c.bucketInstanceId]=!0)}return n.removeStaleBuckets(a)&&(i=!0),i},Pe.prototype.pruneUnusedLayers=function(t){var e={};for(var r in t.forEach(function(t){e[t]=!0}),this.layerIndexes)e[r]||delete this.layerIndexes[r]};var Oe=function(e,r){return t.emitValidationErrors(e,r&&r.filter(function(t){return\"source.canvas\"!==t.identifier}))},ze=t.pick(Bt,[\"addLayer\",\"removeLayer\",\"setPaintProperty\",\"setLayoutProperty\",\"setFilter\",\"addSource\",\"removeSource\",\"setLayerZoomRange\",\"setLight\",\"setTransition\",\"setGeoJSONSourceData\"]),Ie=t.pick(Bt,[\"setCenter\",\"setZoom\",\"setBearing\",\"setPitch\"]),De=function(e){function r(n,i){var a=this;void 0===i&&(i={}),e.call(this),this.map=n,this.dispatcher=new k((It||(It=new zt),It),this),this.imageManager=new f,this.imageManager.setEventedParent(this),this.glyphManager=new y(n._requestManager,i.localIdeographFontFamily),this.lineAtlas=new w(256,512),this.crossTileSymbolIndex=new Pe,this._layers={},this._order=[],this.sourceCaches={},this.zoomHistory=new t.ZoomHistory,this._loaded=!1,this._resetUpdates(),this.dispatcher.broadcast(\"setReferrer\",t.getReferrer());var o=this;this._rtlTextPluginCallback=r.registerForPluginAvailability(function(t){for(var e in o.dispatcher.broadcast(\"loadRTLTextPlugin\",t.pluginURL,t.completionCallback),o.sourceCaches)o.sourceCaches[e].reload()}),this.on(\"data\",function(t){if(\"source\"===t.dataType&&\"metadata\"===t.sourceDataType){var e=a.sourceCaches[t.sourceId];if(e){var r=e.getSource();if(r&&r.vectorLayerIds)for(var n in a._layers){var i=a._layers[n];i.source===r.id&&a._validateLayer(i)}}}})}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadURL=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"}));var i=\"boolean\"==typeof r.validate?r.validate:!t.isMapboxURL(e);e=this.map._requestManager.normalizeStyleURL(e,r.accessToken);var a=this.map._requestManager.transformRequest(e,t.ResourceType.Style);this._request=t.getJSON(a,function(e,r){n._request=null,e?n.fire(new t.ErrorEvent(e)):r&&n._load(r,i)})},r.prototype.loadJSON=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"})),this._request=t.browser.frame(function(){n._request=null,n._load(e,!1!==r.validate)})},r.prototype._load=function(e,r){var n=this;if(!r||!Oe(this,t.validateStyle(e))){for(var i in this._loaded=!0,this.stylesheet=e,e.sources)this.addSource(i,e.sources[i],{validate:!1});e.sprite?this._spriteRequest=function(e,r,n){var i,a,o,s=t.browser.devicePixelRatio>1?\"@2x\":\"\",l=t.getJSON(r.transformRequest(r.normalizeSpriteURL(e,s,\".json\"),t.ResourceType.SpriteJSON),function(t,e){l=null,o||(o=t,i=e,u())}),c=t.getImage(r.transformRequest(r.normalizeSpriteURL(e,s,\".png\"),t.ResourceType.SpriteImage),function(t,e){c=null,o||(o=t,a=e,u())});function u(){if(o)n(o);else if(i&&a){var e=t.browser.getImageData(a),r={};for(var s in i){var l=i[s],c=l.width,u=l.height,h=l.x,f=l.y,p=l.sdf,d=l.pixelRatio,g=new t.RGBAImage({width:c,height:u});t.RGBAImage.copy(e,g,{x:h,y:f},{x:0,y:0},{width:c,height:u}),r[s]={data:g,pixelRatio:d,sdf:p}}n(null,r)}}return{cancel:function(){l&&(l.cancel(),l=null),c&&(c.cancel(),c=null)}}}(e.sprite,this.map._requestManager,function(e,r){if(n._spriteRequest=null,e)n.fire(new t.ErrorEvent(e));else if(r)for(var i in r)n.imageManager.addImage(i,r[i]);n.imageManager.setLoaded(!0),n.fire(new t.Event(\"data\",{dataType:\"style\"}))}):this.imageManager.setLoaded(!0),this.glyphManager.setURL(e.glyphs);var a=Ft(this.stylesheet.layers);this._order=a.map(function(t){return t.id}),this._layers={};for(var o=0,s=a;o<s.length;o+=1){var l=s[o];(l=t.createStyleLayer(l)).setEventedParent(this,{layer:{id:l.id}}),this._layers[l.id]=l}this.dispatcher.broadcast(\"setLayers\",this._serializeLayers(this._order)),this.light=new _(this.stylesheet.light),this.fire(new t.Event(\"data\",{dataType:\"style\"})),this.fire(new t.Event(\"style.load\"))}},r.prototype._validateLayer=function(e){var r=this.sourceCaches[e.source];if(r){var n=e.sourceLayer;if(n){var i=r.getSource();(\"geojson\"===i.type||i.vectorLayerIds&&-1===i.vectorLayerIds.indexOf(n))&&this.fire(new t.ErrorEvent(new Error('Source layer \"'+n+'\" does not exist on source \"'+i.id+'\" as specified by style layer \"'+e.id+'\"')))}}},r.prototype.loaded=function(){if(!this._loaded)return!1;if(Object.keys(this._updatedSources).length)return!1;for(var t in this.sourceCaches)if(!this.sourceCaches[t].loaded())return!1;return!!this.imageManager.isLoaded()},r.prototype._serializeLayers=function(t){for(var e=[],r=0,n=t;r<n.length;r+=1){var i=n[r],a=this._layers[i];\"custom\"!==a.type&&e.push(a.serialize())}return e},r.prototype.hasTransitions=function(){if(this.light&&this.light.hasTransition())return!0;for(var t in this.sourceCaches)if(this.sourceCaches[t].hasTransition())return!0;for(var e in this._layers)if(this._layers[e].hasTransition())return!0;return!1},r.prototype._checkLoaded=function(){if(!this._loaded)throw new Error(\"Style is not done loading\")},r.prototype.update=function(e){if(this._loaded){var r=this._changed;if(this._changed){var n=Object.keys(this._updatedLayers),i=Object.keys(this._removedLayers);for(var a in(n.length||i.length)&&this._updateWorkerLayers(n,i),this._updatedSources){var o=this._updatedSources[a];\"reload\"===o?this._reloadSource(a):\"clear\"===o&&this._clearSource(a)}for(var s in this._updatedPaintProps)this._layers[s].updateTransitions(e);this.light.updateTransitions(e),this._resetUpdates()}for(var l in this.sourceCaches)this.sourceCaches[l].used=!1;for(var c=0,u=this._order;c<u.length;c+=1){var h=u[c],f=this._layers[h];f.recalculate(e),!f.isHidden(e.zoom)&&f.source&&(this.sourceCaches[f.source].used=!0)}this.light.recalculate(e),this.z=e.zoom,r&&this.fire(new t.Event(\"data\",{dataType:\"style\"}))}},r.prototype._updateWorkerLayers=function(t,e){this.dispatcher.broadcast(\"updateLayers\",{layers:this._serializeLayers(t),removedIds:e})},r.prototype._resetUpdates=function(){this._changed=!1,this._updatedLayers={},this._removedLayers={},this._updatedSources={},this._updatedPaintProps={}},r.prototype.setState=function(e){var r=this;if(this._checkLoaded(),Oe(this,t.validateStyle(e)))return!1;(e=t.clone$1(e)).layers=Ft(e.layers);var n=function(e,r){if(!e)return[{command:Bt.setStyle,args:[r]}];var n=[];try{if(!t.deepEqual(e.version,r.version))return[{command:Bt.setStyle,args:[r]}];t.deepEqual(e.center,r.center)||n.push({command:Bt.setCenter,args:[r.center]}),t.deepEqual(e.zoom,r.zoom)||n.push({command:Bt.setZoom,args:[r.zoom]}),t.deepEqual(e.bearing,r.bearing)||n.push({command:Bt.setBearing,args:[r.bearing]}),t.deepEqual(e.pitch,r.pitch)||n.push({command:Bt.setPitch,args:[r.pitch]}),t.deepEqual(e.sprite,r.sprite)||n.push({command:Bt.setSprite,args:[r.sprite]}),t.deepEqual(e.glyphs,r.glyphs)||n.push({command:Bt.setGlyphs,args:[r.glyphs]}),t.deepEqual(e.transition,r.transition)||n.push({command:Bt.setTransition,args:[r.transition]}),t.deepEqual(e.light,r.light)||n.push({command:Bt.setLight,args:[r.light]});var i={},a=[];!function(e,r,n,i){var a;for(a in r=r||{},e=e||{})e.hasOwnProperty(a)&&(r.hasOwnProperty(a)||jt(a,n,i));for(a in r)r.hasOwnProperty(a)&&(e.hasOwnProperty(a)?t.deepEqual(e[a],r[a])||(\"geojson\"===e[a].type&&\"geojson\"===r[a].type&&Vt(e,r,a)?n.push({command:Bt.setGeoJSONSourceData,args:[a,r[a].data]}):Ut(a,r,n,i)):Nt(a,r,n))}(e.sources,r.sources,a,i);var o=[];e.layers&&e.layers.forEach(function(t){i[t.source]?n.push({command:Bt.removeLayer,args:[t.id]}):o.push(t)}),n=n.concat(a),function(e,r,n){r=r||[];var i,a,o,s,l,c,u,h=(e=e||[]).map(Ht),f=r.map(Ht),p=e.reduce(Gt,{}),d=r.reduce(Gt,{}),g=h.slice(),v=Object.create(null);for(i=0,a=0;i<h.length;i++)o=h[i],d.hasOwnProperty(o)?a++:(n.push({command:Bt.removeLayer,args:[o]}),g.splice(g.indexOf(o,a),1));for(i=0,a=0;i<f.length;i++)o=f[f.length-1-i],g[g.length-1-i]!==o&&(p.hasOwnProperty(o)?(n.push({command:Bt.removeLayer,args:[o]}),g.splice(g.lastIndexOf(o,g.length-a),1)):a++,c=g[g.length-i],n.push({command:Bt.addLayer,args:[d[o],c]}),g.splice(g.length-i,0,o),v[o]=!0);for(i=0;i<f.length;i++)if(s=p[o=f[i]],l=d[o],!v[o]&&!t.deepEqual(s,l))if(t.deepEqual(s.source,l.source)&&t.deepEqual(s[\"source-layer\"],l[\"source-layer\"])&&t.deepEqual(s.type,l.type)){for(u in qt(s.layout,l.layout,n,o,null,Bt.setLayoutProperty),qt(s.paint,l.paint,n,o,null,Bt.setPaintProperty),t.deepEqual(s.filter,l.filter)||n.push({command:Bt.setFilter,args:[o,l.filter]}),t.deepEqual(s.minzoom,l.minzoom)&&t.deepEqual(s.maxzoom,l.maxzoom)||n.push({command:Bt.setLayerZoomRange,args:[o,l.minzoom,l.maxzoom]}),s)s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?qt(s[u],l[u],n,o,u.slice(6),Bt.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Bt.setLayerProperty,args:[o,u,l[u]]}));for(u in l)l.hasOwnProperty(u)&&!s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?qt(s[u],l[u],n,o,u.slice(6),Bt.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Bt.setLayerProperty,args:[o,u,l[u]]}))}else n.push({command:Bt.removeLayer,args:[o]}),c=g[g.lastIndexOf(o)+1],n.push({command:Bt.addLayer,args:[l,c]})}(o,r.layers,n)}catch(t){console.warn(\"Unable to compute style diff:\",t),n=[{command:Bt.setStyle,args:[r]}]}return n}(this.serialize(),e).filter(function(t){return!(t.command in Ie)});if(0===n.length)return!1;var i=n.filter(function(t){return!(t.command in ze)});if(i.length>0)throw new Error(\"Unimplemented: \"+i.map(function(t){return t.command}).join(\", \")+\".\");return n.forEach(function(t){\"setTransition\"!==t.command&&r[t.command].apply(r,t.args)}),this.stylesheet=e,!0},r.prototype.addImage=function(e,r){if(this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"An image with this name already exists.\")));this.imageManager.addImage(e,r),this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.updateImage=function(t,e){this.imageManager.updateImage(t,e)},r.prototype.getImage=function(t){return this.imageManager.getImage(t)},r.prototype.removeImage=function(e){if(!this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"No image with this name exists.\")));this.imageManager.removeImage(e),this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.listImages=function(){return this._checkLoaded(),this.imageManager.listImages()},r.prototype.addSource=function(e,r,n){var i=this;if(void 0===n&&(n={}),this._checkLoaded(),void 0!==this.sourceCaches[e])throw new Error(\"There is already a source with this ID\");if(!r.type)throw new Error(\"The type property must be defined, but the only the following properties were given: \"+Object.keys(r).join(\", \")+\".\");if(!([\"vector\",\"raster\",\"geojson\",\"video\",\"image\"].indexOf(r.type)>=0&&this._validate(t.validateStyle.source,\"sources.\"+e,r,null,n))){this.map&&this.map._collectResourceTiming&&(r.collectResourceTiming=!0);var a=this.sourceCaches[e]=new Ct(e,r,this.dispatcher);a.style=this,a.setEventedParent(this,function(){return{isSourceLoaded:i.loaded(),source:a.serialize(),sourceId:e}}),a.onAdd(this.map),this._changed=!0}},r.prototype.removeSource=function(e){if(this._checkLoaded(),void 0===this.sourceCaches[e])throw new Error(\"There is no source with this ID\");for(var r in this._layers)if(this._layers[r].source===e)return this.fire(new t.ErrorEvent(new Error('Source \"'+e+'\" cannot be removed while layer \"'+r+'\" is using it.')));var n=this.sourceCaches[e];delete this.sourceCaches[e],delete this._updatedSources[e],n.fire(new t.Event(\"data\",{sourceDataType:\"metadata\",dataType:\"source\",sourceId:e})),n.setEventedParent(null),n.clearTiles(),n.onRemove&&n.onRemove(this.map),this._changed=!0},r.prototype.setGeoJSONSourceData=function(t,e){this._checkLoaded(),this.sourceCaches[t].getSource().setData(e),this._changed=!0},r.prototype.getSource=function(t){return this.sourceCaches[t]&&this.sourceCaches[t].getSource()},r.prototype.addLayer=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=e.id;if(this.getLayer(i))this.fire(new t.ErrorEvent(new Error('Layer with id \"'+i+'\" already exists on this map')));else{var a;if(\"custom\"===e.type){if(Oe(this,t.validateCustomStyleLayer(e)))return;a=t.createStyleLayer(e)}else{if(\"object\"==typeof e.source&&(this.addSource(i,e.source),e=t.clone$1(e),e=t.extend(e,{source:i})),this._validate(t.validateStyle.layer,\"layers.\"+i,e,{arrayIndex:-1},n))return;a=t.createStyleLayer(e),this._validateLayer(a),a.setEventedParent(this,{layer:{id:i}})}var o=r?this._order.indexOf(r):this._order.length;if(r&&-1===o)this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.')));else{if(this._order.splice(o,0,i),this._layerOrderChanged=!0,this._layers[i]=a,this._removedLayers[i]&&a.source&&\"custom\"!==a.type){var s=this._removedLayers[i];delete this._removedLayers[i],s.type!==a.type?this._updatedSources[a.source]=\"clear\":(this._updatedSources[a.source]=\"reload\",this.sourceCaches[a.source].pause())}this._updateLayer(a),a.onAdd&&a.onAdd(this.map)}}},r.prototype.moveLayer=function(e,r){if(this._checkLoaded(),this._changed=!0,this._layers[e]){if(e!==r){var n=this._order.indexOf(e);this._order.splice(n,1);var i=r?this._order.indexOf(r):this._order.length;r&&-1===i?this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.'))):(this._order.splice(i,0,e),this._layerOrderChanged=!0)}}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be moved.\")))},r.prototype.removeLayer=function(e){this._checkLoaded();var r=this._layers[e];if(r){r.setEventedParent(null);var n=this._order.indexOf(e);this._order.splice(n,1),this._layerOrderChanged=!0,this._changed=!0,this._removedLayers[e]=r,delete this._layers[e],delete this._updatedLayers[e],delete this._updatedPaintProps[e],r.onRemove&&r.onRemove(this.map)}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be removed.\")))},r.prototype.getLayer=function(t){return this._layers[t]},r.prototype.setLayerZoomRange=function(e,r,n){this._checkLoaded();var i=this.getLayer(e);i?i.minzoom===r&&i.maxzoom===n||(null!=r&&(i.minzoom=r),null!=n&&(i.maxzoom=n),this._updateLayer(i)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot have zoom extent.\")))},r.prototype.setFilter=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=this.getLayer(e);if(i){if(!t.deepEqual(i.filter,r))return null==r?(i.filter=void 0,void this._updateLayer(i)):void(this._validate(t.validateStyle.filter,\"layers.\"+i.id+\".filter\",r,null,n)||(i.filter=t.clone$1(r),this._updateLayer(i)))}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be filtered.\")))},r.prototype.getFilter=function(e){return t.clone$1(this.getLayer(e).filter)},r.prototype.setLayoutProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getLayoutProperty(r),n)||(a.setLayoutProperty(r,n,i),this._updateLayer(a)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getLayoutProperty=function(e,r){var n=this.getLayer(e);if(n)return n.getLayoutProperty(r);this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style.\")))},r.prototype.setPaintProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getPaintProperty(r),n)||(a.setPaintProperty(r,n,i)&&this._updateLayer(a),this._changed=!0,this._updatedPaintProps[e]=!0):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getPaintProperty=function(t,e){return this.getLayer(t).getPaintProperty(e)},r.prototype.setFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=e.sourceLayer,a=this.sourceCaches[n],o=parseInt(e.id,10);if(void 0!==a){var s=a.getSource().type;\"geojson\"===s&&i?this.fire(new t.ErrorEvent(new Error(\"GeoJSON sources cannot have a sourceLayer parameter.\"))):\"vector\"!==s||i?isNaN(o)||o<0?this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided and non-negative.\"))):a.setFeatureState(i,o,r):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.removeFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=this.sourceCaches[n];if(void 0!==i){var a=i.getSource().type,o=\"vector\"===a?e.sourceLayer:void 0,s=parseInt(e.id,10);\"vector\"!==a||o?void 0!==e.id&&isNaN(s)||s<0?this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be non-negative.\"))):r&&\"string\"!=typeof e.id&&\"number\"!=typeof e.id?this.fire(new t.ErrorEvent(new Error(\"A feature id is requred to remove its specific state property.\"))):i.removeFeatureState(o,s,r):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.getFeatureState=function(e){this._checkLoaded();var r=e.source,n=e.sourceLayer,i=this.sourceCaches[r],a=parseInt(e.id,10);if(void 0!==i)if(\"vector\"!==i.getSource().type||n){if(!(isNaN(a)||a<0))return i.getFeatureState(n,a);this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided and non-negative.\")))}else this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")));else this.fire(new t.ErrorEvent(new Error(\"The source '\"+r+\"' does not exist in the map's style.\")))},r.prototype.getTransition=function(){return t.extend({duration:300,delay:0},this.stylesheet&&this.stylesheet.transition)},r.prototype.serialize=function(){return t.filterObject({version:this.stylesheet.version,name:this.stylesheet.name,metadata:this.stylesheet.metadata,light:this.stylesheet.light,center:this.stylesheet.center,zoom:this.stylesheet.zoom,bearing:this.stylesheet.bearing,pitch:this.stylesheet.pitch,sprite:this.stylesheet.sprite,glyphs:this.stylesheet.glyphs,transition:this.stylesheet.transition,sources:t.mapObject(this.sourceCaches,function(t){return t.serialize()}),layers:this._serializeLayers(this._order)},function(t){return void 0!==t})},r.prototype._updateLayer=function(t){this._updatedLayers[t.id]=!0,t.source&&!this._updatedSources[t.source]&&(this._updatedSources[t.source]=\"reload\",this.sourceCaches[t.source].pause()),this._changed=!0},r.prototype._flattenAndSortRenderedFeatures=function(t){for(var e=this,r=function(t){return\"fill-extrusion\"===e._layers[t].type},n={},i=[],a=this._order.length-1;a>=0;a--){var o=this._order[a];if(r(o)){n[o]=a;for(var s=0,l=t;s<l.length;s+=1){var c=l[s][o];if(c)for(var u=0,h=c;u<h.length;u+=1){var f=h[u];i.push(f)}}}}i.sort(function(t,e){return e.intersectionZ-t.intersectionZ});for(var p=[],d=this._order.length-1;d>=0;d--){var g=this._order[d];if(r(g))for(var v=i.length-1;v>=0;v--){var m=i[v].feature;if(n[m.layer.id]<d)break;p.push(m),i.pop()}else for(var y=0,x=t;y<x.length;y+=1){var b=x[y][g];if(b)for(var _=0,w=b;_<w.length;_+=1){var k=w[_];p.push(k.feature)}}}return p},r.prototype.queryRenderedFeatures=function(e,r,n){r&&r.filter&&this._validate(t.validateStyle.filter,\"queryRenderedFeatures.filter\",r.filter,null,r);var i={};if(r&&r.layers){if(!Array.isArray(r.layers))return this.fire(new t.ErrorEvent(new Error(\"parameters.layers must be an Array.\"))),[];for(var a=0,o=r.layers;a<o.length;a+=1){var s=o[a],l=this._layers[s];if(!l)return this.fire(new t.ErrorEvent(new Error(\"The layer '\"+s+\"' does not exist in the map's style and cannot be queried for features.\"))),[];i[l.source]=!0}}var c=[];for(var u in this.sourceCaches)r.layers&&!i[u]||c.push(R(this.sourceCaches[u],this._layers,e,r,n));return this.placement&&c.push(function(t,e,r,n,i,a){for(var o={},s=i.queryRenderedSymbols(r),l=[],c=0,u=Object.keys(s).map(Number);c<u.length;c+=1){var h=u[c];l.push(a[h])}l.sort(F);for(var f=function(){var e=d[p],r=e.featureIndex.lookupSymbolFeatures(s[e.bucketInstanceId],e.bucketIndex,e.sourceLayerIndex,n.filter,n.layers,t);for(var i in r){var a=o[i]=o[i]||[],l=r[i];l.sort(function(t,r){var n=e.featureSortOrder;if(n){var i=n.indexOf(t.featureIndex);return n.indexOf(r.featureIndex)-i}return r.featureIndex-t.featureIndex});for(var c=0,u=l;c<u.length;c+=1){var h=u[c];a.push(h)}}},p=0,d=l;p<d.length;p+=1)f();var g=function(r){o[r].forEach(function(n){var i=n.feature,a=t[r],o=e[a.source].getFeatureState(i.layer[\"source-layer\"],i.id);i.source=i.layer.source,i.layer[\"source-layer\"]&&(i.sourceLayer=i.layer[\"source-layer\"]),i.state=o})};for(var v in o)g(v);return o}(this._layers,this.sourceCaches,e,r,this.placement.collisionIndex,this.placement.retainedQueryData)),this._flattenAndSortRenderedFeatures(c)},r.prototype.querySourceFeatures=function(e,r){r&&r.filter&&this._validate(t.validateStyle.filter,\"querySourceFeatures.filter\",r.filter,null,r);var n=this.sourceCaches[e];return n?function(t,e){for(var r=t.getRenderableIds().map(function(e){return t.getTileByID(e)}),n=[],i={},a=0;a<r.length;a++){var o=r[a],s=o.tileID.canonical.key;i[s]||(i[s]=!0,o.querySourceFeatures(n,e))}return n}(n,r):[]},r.prototype.addSourceType=function(t,e,n){return r.getSourceType(t)?n(new Error('A source type called \"'+t+'\" already exists.')):(r.setSourceType(t,e),e.workerSourceURL?void this.dispatcher.broadcast(\"loadWorkerSource\",{name:t,url:e.workerSourceURL},n):n(null,null))},r.prototype.getLight=function(){return this.light.getLight()},r.prototype.setLight=function(e,r){void 0===r&&(r={}),this._checkLoaded();var n=this.light.getLight(),i=!1;for(var a in e)if(!t.deepEqual(e[a],n[a])){i=!0;break}if(i){var o={now:t.browser.now(),transition:t.extend({duration:300,delay:0},this.stylesheet.transition)};this.light.setLight(e,r),this.light.updateTransitions(o)}},r.prototype._validate=function(e,r,n,i,a){return void 0===a&&(a={}),(!a||!1!==a.validate)&&Oe(this,e.call(t.validateStyle,t.extend({key:r,style:this.serialize(),value:n,styleSpec:t.styleSpec},i)))},r.prototype._remove=function(){for(var e in this._request&&(this._request.cancel(),this._request=null),this._spriteRequest&&(this._spriteRequest.cancel(),this._spriteRequest=null),t.evented.off(\"pluginAvailable\",this._rtlTextPluginCallback),this.sourceCaches)this.sourceCaches[e].clearTiles();this.dispatcher.remove()},r.prototype._clearSource=function(t){this.sourceCaches[t].clearTiles()},r.prototype._reloadSource=function(t){this.sourceCaches[t].resume(),this.sourceCaches[t].reload()},r.prototype._updateSources=function(t){for(var e in this.sourceCaches)this.sourceCaches[e].update(t)},r.prototype._generateCollisionBoxes=function(){for(var t in this.sourceCaches)this._reloadSource(t)},r.prototype._updatePlacement=function(e,r,n,i){for(var a=!1,o=!1,s={},l=0,c=this._order;l<c.length;l+=1){var u=c[l],h=this._layers[u];if(\"symbol\"===h.type){if(!s[h.source]){var f=this.sourceCaches[h.source];s[h.source]=f.getRenderableIds(!0).map(function(t){return f.getTileByID(t)}).sort(function(t,e){return e.tileID.overscaledZ-t.tileID.overscaledZ||(t.tileID.isLessThan(e.tileID)?-1:1)})}var p=this.crossTileSymbolIndex.addLayer(h,s[h.source],e.center.lng);a=a||p}}this.crossTileSymbolIndex.pruneUnusedLayers(this._order);var d=this._layerOrderChanged||0===n;if((d||!this.pauseablePlacement||this.pauseablePlacement.isDone()&&!this.placement.stillRecent(t.browser.now()))&&(this.pauseablePlacement=new Me(e,this._order,d,r,n,i,this.placement),this._layerOrderChanged=!1),this.pauseablePlacement.isDone()?this.placement.setStale():(this.pauseablePlacement.continuePlacement(this._order,this._layers,s),this.pauseablePlacement.isDone()&&(this.placement=this.pauseablePlacement.commit(t.browser.now()),o=!0),a&&this.pauseablePlacement.placement.setStale()),o||a)for(var g=0,v=this._order;g<v.length;g+=1){var m=v[g],y=this._layers[m];\"symbol\"===y.type&&this.placement.updateLayerOpacities(y,s[y.source])}return!this.pauseablePlacement.isDone()||this.placement.hasTransitions(t.browser.now())},r.prototype._releaseSymbolFadeTiles=function(){for(var t in this.sourceCaches)this.sourceCaches[t].releaseSymbolFadeTiles()},r.prototype.getImages=function(t,e,r){this.imageManager.getImages(e.icons,r)},r.prototype.getGlyphs=function(t,e,r){this.glyphManager.getGlyphs(e.stacks,r)},r.prototype.getResource=function(e,r,n){return t.makeRequest(r,n)},r}(t.Evented);De.getSourceType=function(t){return z[t]},De.setSourceType=function(t,e){z[t]=e},De.registerForPluginAvailability=t.registerForPluginAvailability;var Re=t.createLayout([{name:\"a_pos\",type:\"Int16\",components:2}]),Fe=lr(\"#ifdef GL_ES\\nprecision mediump float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\",\"#ifdef GL_ES\\nprecision highp float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\\nvec2 unpack_float(const float packedValue) {int packedIntValue=int(packedValue);int v0=packedIntValue/256;return vec2(v0,packedIntValue-v0*256);}vec2 unpack_opacity(const float packedOpacity) {int intOpacity=int(packedOpacity)/2;return vec2(float(intOpacity)/127.0,mod(packedOpacity,2.0));}vec4 decode_color(const vec2 encodedColor) {return vec4(unpack_float(encodedColor[0])/255.0,unpack_float(encodedColor[1])/255.0\\n);}float unpack_mix_vec2(const vec2 packedValue,const float t) {return mix(packedValue[0],packedValue[1],t);}vec4 unpack_mix_color(const vec4 packedColors,const float t) {vec4 minColor=decode_color(vec2(packedColors[0],packedColors[1]));vec4 maxColor=decode_color(vec2(packedColors[2],packedColors[3]));return mix(minColor,maxColor,t);}vec2 get_pattern_pos(const vec2 pixel_coord_upper,const vec2 pixel_coord_lower,const vec2 pattern_size,const float tile_units_to_pixels,const vec2 pos) {vec2 offset=mod(mod(mod(pixel_coord_upper,pattern_size)*256.0,pattern_size)*256.0+pixel_coord_lower,pattern_size);return (tile_units_to_pixels*pos+offset)/pattern_size;}\"),Be=lr(\"uniform vec4 u_color;uniform float u_opacity;void main() {gl_FragColor=u_color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),Ne=lr(\"uniform vec2 u_pattern_tl_a;uniform vec2 u_pattern_br_a;uniform vec2 u_pattern_tl_b;uniform vec2 u_pattern_br_b;uniform vec2 u_texsize;uniform float u_mix;uniform float u_opacity;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(u_pattern_tl_a/u_texsize,u_pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(u_pattern_tl_b/u_texsize,u_pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_mix)*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pattern_size_a;uniform vec2 u_pattern_size_b;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_scale_a;uniform float u_scale_b;uniform float u_tile_units_to_pixels;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_a*u_pattern_size_a,u_tile_units_to_pixels,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_b*u_pattern_size_b,u_tile_units_to_pixels,a_pos);}\"),je=lr(\"varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=v_data.xy;float extrude_length=length(extrude);lowp float antialiasblur=v_data.z;float antialiased_blur=-max(blur,antialiasblur);float opacity_t=smoothstep(0.0,antialiased_blur,extrude_length-1.0);float color_t=stroke_width < 0.01 ? 0.0 : smoothstep(antialiased_blur,0.0,extrude_length-radius/(radius+stroke_width));gl_FragColor=opacity_t*mix(color*opacity,stroke_color*stroke_opacity,color_t);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform bool u_scale_with_map;uniform bool u_pitch_with_map;uniform vec2 u_extrude_scale;uniform lowp float u_device_pixel_ratio;uniform highp float u_camera_to_center_distance;attribute vec2 a_pos;varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main(void) {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=vec2(mod(a_pos,2.0)*2.0-1.0);vec2 circle_center=floor(a_pos*0.5);if (u_pitch_with_map) {vec2 corner_position=circle_center;if (u_scale_with_map) {corner_position+=extrude*(radius+stroke_width)*u_extrude_scale;} else {vec4 projected_center=u_matrix*vec4(circle_center,0,1);corner_position+=extrude*(radius+stroke_width)*u_extrude_scale*(projected_center.w/u_camera_to_center_distance);}gl_Position=u_matrix*vec4(corner_position,0,1);} else {gl_Position=u_matrix*vec4(circle_center,0,1);if (u_scale_with_map) {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*u_camera_to_center_distance;} else {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*gl_Position.w;}}lowp float antialiasblur=1.0/u_device_pixel_ratio/(radius+stroke_width);v_data=vec3(extrude.x,extrude.y,antialiasblur);}\"),Ue=lr(\"void main() {gl_FragColor=vec4(1.0);}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),Ve=lr(\"uniform highp float u_intensity;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main() {\\n#pragma mapbox: initialize highp float weight\\nfloat d=-0.5*3.0*3.0*dot(v_extrude,v_extrude);float val=weight*u_intensity*GAUSS_COEF*exp(d);gl_FragColor=vec4(val,1.0,1.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform float u_extrude_scale;uniform float u_opacity;uniform float u_intensity;attribute vec2 a_pos;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#pragma mapbox: define mediump float radius\\nconst highp float ZERO=1.0/255.0/16.0;\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main(void) {\\n#pragma mapbox: initialize highp float weight\\n#pragma mapbox: initialize mediump float radius\\nvec2 unscaled_extrude=vec2(mod(a_pos,2.0)*2.0-1.0);float S=sqrt(-2.0*log(ZERO/weight/u_intensity/GAUSS_COEF))/3.0;v_extrude=S*unscaled_extrude;vec2 extrude=v_extrude*radius*u_extrude_scale;vec4 pos=vec4(floor(a_pos*0.5)+extrude,0,1);gl_Position=u_matrix*pos;}\"),qe=lr(\"uniform sampler2D u_image;uniform sampler2D u_color_ramp;uniform float u_opacity;varying vec2 v_pos;void main() {float t=texture2D(u_image,v_pos).r;vec4 color=texture2D(u_color_ramp,vec2(t,0.5));gl_FragColor=color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(0.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;attribute vec2 a_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos*u_world,0,1);v_pos.x=a_pos.x;v_pos.y=1.0-a_pos.y;}\"),He=lr(\"varying float v_placed;varying float v_notUsed;void main() {float alpha=0.5;gl_FragColor=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {gl_FragColor=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {gl_FragColor*=.1;}}\",\"attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;attribute vec2 a_shift;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);gl_Position.xy+=(a_extrude+a_shift)*u_extrude_scale*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;}\"),Ge=lr(\"uniform float u_overscale_factor;varying float v_placed;varying float v_notUsed;varying float v_radius;varying vec2 v_extrude;varying vec2 v_extrude_scale;void main() {float alpha=0.5;vec4 color=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {color=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {color*=.2;}float extrude_scale_length=length(v_extrude_scale);float extrude_length=length(v_extrude)*extrude_scale_length;float stroke_width=15.0*extrude_scale_length/u_overscale_factor;float radius=v_radius*extrude_scale_length;float distance_to_edge=abs(extrude_length-radius);float opacity_t=smoothstep(-stroke_width,0.0,-distance_to_edge);gl_FragColor=opacity_t*color;}\",\"attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;varying float v_radius;varying vec2 v_extrude;varying vec2 v_extrude_scale;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);highp float padding_factor=1.2;gl_Position.xy+=a_extrude*u_extrude_scale*padding_factor*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;v_radius=abs(a_extrude.y);v_extrude=a_extrude*padding_factor;v_extrude_scale=u_extrude_scale*u_camera_to_center_distance*collision_perspective_ratio;}\"),Ye=lr(\"uniform highp vec4 u_color;void main() {gl_FragColor=u_color;}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),We=lr(\"#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_FragColor=color*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);}\"),Xe=lr(\"varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=outline_color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;uniform vec2 u_world;varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),Ze=lr(\"uniform vec2 u_texsize;uniform sampler2D u_image;uniform float u_fade;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);float dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=mix(color1,color2,u_fade)*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec4 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;gl_Position=u_matrix*vec4(a_pos,0,1);vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,a_pos);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),Je=lr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_fade)*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec4 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileZoomRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileZoomRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileZoomRatio,a_pos);}\"),Ke=lr(\"varying vec4 v_color;void main() {gl_FragColor=v_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;uniform float u_vertical_gradient;uniform lowp float u_opacity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec4 v_color;\\n#pragma mapbox: define highp float base\\n#pragma mapbox: define highp float height\\n#pragma mapbox: define highp vec4 color\\nvoid main() {\\n#pragma mapbox: initialize highp float base\\n#pragma mapbox: initialize highp float height\\n#pragma mapbox: initialize highp vec4 color\\nvec3 normal=a_normal_ed.xyz;base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);gl_Position=u_matrix*vec4(a_pos,t > 0.0 ? height : base,1);float colorvalue=color.r*0.2126+color.g*0.7152+color.b*0.0722;v_color=vec4(0.0,0.0,0.0,1.0);vec4 ambientlight=vec4(0.03,0.03,0.03,1.0);color+=ambientlight;float directional=clamp(dot(normal/16384.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((1.0-colorvalue+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_color.r+=clamp(color.r*directional*u_lightcolor.r,mix(0.0,0.3,1.0-u_lightcolor.r),1.0);v_color.g+=clamp(color.g*directional*u_lightcolor.g,mix(0.0,0.3,1.0-u_lightcolor.g),1.0);v_color.b+=clamp(color.b*directional*u_lightcolor.b,mix(0.0,0.3,1.0-u_lightcolor.b),1.0);v_color*=u_opacity;}\"),$e=lr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);vec4 mixedColor=mix(color1,color2,u_fade);gl_FragColor=mixedColor*v_lighting;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_height_factor;uniform vec4 u_scale;uniform float u_vertical_gradient;uniform lowp float u_opacity;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec3 normal=a_normal_ed.xyz;float edgedistance=a_normal_ed.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);float z=t > 0.0 ? height : base;gl_Position=u_matrix*vec4(a_pos,z,1);vec2 pos=normal.x==1.0 && normal.y==0.0 && normal.z==16384.0\\n? a_pos\\n: vec2(edgedistance,z*u_height_factor);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,pos);v_lighting=vec4(0.0,0.0,0.0,1.0);float directional=clamp(dot(normal/16383.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((0.5+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_lighting.rgb+=clamp(directional*u_lightcolor,mix(vec3(0.0),vec3(0.3),1.0-u_lightcolor),vec3(1.0));v_lighting*=u_opacity;}\"),Qe=lr(\"#ifdef GL_ES\\nprecision highp float;\\n#endif\\nuniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_dimension;uniform float u_zoom;uniform float u_maxzoom;float getElevation(vec2 coord,float bias) {vec4 data=texture2D(u_image,coord)*255.0;return (data.r+data.g*256.0+data.b*256.0*256.0)/4.0;}void main() {vec2 epsilon=1.0/u_dimension;float a=getElevation(v_pos+vec2(-epsilon.x,-epsilon.y),0.0);float b=getElevation(v_pos+vec2(0,-epsilon.y),0.0);float c=getElevation(v_pos+vec2(epsilon.x,-epsilon.y),0.0);float d=getElevation(v_pos+vec2(-epsilon.x,0),0.0);float e=getElevation(v_pos,0.0);float f=getElevation(v_pos+vec2(epsilon.x,0),0.0);float g=getElevation(v_pos+vec2(-epsilon.x,epsilon.y),0.0);float h=getElevation(v_pos+vec2(0,epsilon.y),0.0);float i=getElevation(v_pos+vec2(epsilon.x,epsilon.y),0.0);float exaggeration=u_zoom < 2.0 ? 0.4 : u_zoom < 4.5 ? 0.35 : 0.3;vec2 deriv=vec2((c+f+f+i)-(a+d+d+g),(g+h+h+i)-(a+b+b+c))/ pow(2.0,(u_zoom-u_maxzoom)*exaggeration+19.2562-u_zoom);gl_FragColor=clamp(vec4(deriv.x/2.0+0.5,deriv.y/2.0+0.5,1.0,1.0),0.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_dimension;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);highp vec2 epsilon=1.0/u_dimension;float scale=(u_dimension.x-2.0)/u_dimension.x;v_pos=(a_texture_pos/8192.0)*scale+epsilon;}\"),tr=lr(\"uniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_latrange;uniform vec2 u_light;uniform vec4 u_shadow;uniform vec4 u_highlight;uniform vec4 u_accent;\\n#define PI 3.141592653589793\\nvoid main() {vec4 pixel=texture2D(u_image,v_pos);vec2 deriv=((pixel.rg*2.0)-1.0);float scaleFactor=cos(radians((u_latrange[0]-u_latrange[1])*(1.0-v_pos.y)+u_latrange[1]));float slope=atan(1.25*length(deriv)/scaleFactor);float aspect=deriv.x !=0.0 ? atan(deriv.y,-deriv.x) : PI/2.0*(deriv.y > 0.0 ? 1.0 :-1.0);float intensity=u_light.x;float azimuth=u_light.y+PI;float base=1.875-intensity*1.75;float maxValue=0.5*PI;float scaledSlope=intensity !=0.5 ? ((pow(base,slope)-1.0)/(pow(base,maxValue)-1.0))*maxValue : slope;float accent=cos(scaledSlope);vec4 accent_color=(1.0-accent)*u_accent*clamp(intensity*2.0,0.0,1.0);float shade=abs(mod((aspect+azimuth)/PI+0.5,2.0)-1.0);vec4 shade_color=mix(u_shadow,u_highlight,shade)*sin(scaledSlope)*clamp(intensity*2.0,0.0,1.0);gl_FragColor=accent_color*(1.0-shade_color.a)+shade_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos=a_texture_pos/8192.0;}\"),er=lr(\"uniform lowp float u_device_pixel_ratio;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform vec2 u_units_to_pixels;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_linesofar;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),rr=lr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);vec4 color=texture2D(u_image,vec2(v_lineprogress,0.5));gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define MAX_LINE_DISTANCE 32767.0\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_lineprogress=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0/MAX_LINE_DISTANCE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),nr=lr(\"uniform lowp float u_device_pixel_ratio;uniform vec2 u_texsize;uniform float u_fade;uniform mediump vec4 u_scale;uniform sampler2D u_image;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileZoomRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);vec2 pattern_size_a=vec2(display_size_a.x*fromScale/tileZoomRatio,display_size_a.y);vec2 pattern_size_b=vec2(display_size_b.x*toScale/tileZoomRatio,display_size_b.y);float dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float x_a=mod(v_linesofar/pattern_size_a.x,1.0);float x_b=mod(v_linesofar/pattern_size_b.x,1.0);float y_a=0.5+(v_normal.y*clamp(v_width2.s,0.0,(pattern_size_a.y+2.0)/2.0)/pattern_size_a.y);float y_b=0.5+(v_normal.y*clamp(v_width2.s,0.0,(pattern_size_b.y+2.0)/2.0)/pattern_size_b.y);vec2 pos_a=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,vec2(x_a,y_a));vec2 pos_b=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,vec2(x_b,y_b));vec4 color=mix(texture2D(u_image,pos_a),texture2D(u_image,pos_b),u_fade);gl_FragColor=color*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform vec2 u_units_to_pixels;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_linesofar=a_linesofar;v_width2=vec2(outset,inset);}\"),ir=lr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;uniform float u_sdfgamma;uniform float u_mix;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float sdfdist_a=texture2D(u_image,v_tex_a).a;float sdfdist_b=texture2D(u_image,v_tex_b).a;float sdfdist=mix(sdfdist_a,sdfdist_b,u_mix);alpha*=smoothstep(0.5-u_sdfgamma/floorwidth,0.5+u_sdfgamma/floorwidth,sdfdist);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_patternscale_a;uniform float u_tex_y_a;uniform vec2 u_patternscale_b;uniform float u_tex_y_b;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_tex_a=vec2(a_linesofar*u_patternscale_a.x/floorwidth,normal.y*u_patternscale_a.y+u_tex_y_a);v_tex_b=vec2(a_linesofar*u_patternscale_b.x/floorwidth,normal.y*u_patternscale_b.y+u_tex_y_b);v_width2=vec2(outset,inset);}\"),ar=lr(\"uniform float u_fade_t;uniform float u_opacity;uniform sampler2D u_image0;uniform sampler2D u_image1;varying vec2 v_pos0;varying vec2 v_pos1;uniform float u_brightness_low;uniform float u_brightness_high;uniform float u_saturation_factor;uniform float u_contrast_factor;uniform vec3 u_spin_weights;void main() {vec4 color0=texture2D(u_image0,v_pos0);vec4 color1=texture2D(u_image1,v_pos1);if (color0.a > 0.0) {color0.rgb=color0.rgb/color0.a;}if (color1.a > 0.0) {color1.rgb=color1.rgb/color1.a;}vec4 color=mix(color0,color1,u_fade_t);color.a*=u_opacity;vec3 rgb=color.rgb;rgb=vec3(dot(rgb,u_spin_weights.xyz),dot(rgb,u_spin_weights.zxy),dot(rgb,u_spin_weights.yzx));float average=(color.r+color.g+color.b)/3.0;rgb+=(average-rgb)*u_saturation_factor;rgb=(rgb-0.5)*u_contrast_factor+0.5;vec3 u_high_vec=vec3(u_brightness_low,u_brightness_low,u_brightness_low);vec3 u_low_vec=vec3(u_brightness_high,u_brightness_high,u_brightness_high);gl_FragColor=vec4(mix(u_high_vec,u_low_vec,rgb)*color.a,color.a);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_tl_parent;uniform float u_scale_parent;uniform float u_buffer_scale;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos0;varying vec2 v_pos1;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos0=(((a_texture_pos/8192.0)-0.5)/u_buffer_scale )+0.5;v_pos1=(v_pos0*u_scale_parent)+u_tl_parent;}\"),or=lr(\"uniform sampler2D u_texture;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nlowp float alpha=opacity*v_fade_opacity;gl_FragColor=texture2D(u_texture,v_tex)*alpha;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform highp float u_camera_to_center_distance;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform float u_fade_change;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform vec2 u_texsize;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size[0],a_size[1],u_size_t)/256.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size[0]/256.0;} else if (!u_is_size_zoom_constant && u_is_size_feature_constant) {size=u_size;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);v_tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;v_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));}\"),sr=lr(\"#define SDF_PX 8.0\\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;uniform bool u_is_text;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nfloat EDGE_GAMMA=0.105/u_device_pixel_ratio;vec2 tex=v_data0.xy;float gamma_scale=v_data1.x;float size=v_data1.y;float fade_opacity=v_data1[2];float fontScale=u_is_text ? size/24.0 : size;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size[0],a_size[1],u_size_t)/256.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size[0]/256.0;} else if (!u_is_size_zoom_constant && u_is_size_feature_constant) {size=u_size;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);float gamma_scale=gl_Position.w;vec2 tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));v_data0=vec2(tex.x,tex.y);v_data1=vec3(gamma_scale,size,interpolated_fade_opacity);}\");function lr(t,e){var r=/#pragma mapbox: ([\\w]+) ([\\w]+) ([\\w]+) ([\\w]+)/g,n={};return{fragmentSource:t=t.replace(r,function(t,e,r,i,a){return n[a]=!0,\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"\\n#ifdef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"}),vertexSource:e=e.replace(r,function(t,e,r,i,a){var o=\"float\"===i?\"vec2\":\"vec4\",s=a.match(/color/)?\"color\":o;return n[a]?\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"})}}var cr=Object.freeze({prelude:Fe,background:Be,backgroundPattern:Ne,circle:je,clippingMask:Ue,heatmap:Ve,heatmapTexture:qe,collisionBox:He,collisionCircle:Ge,debug:Ye,fill:We,fillOutline:Xe,fillOutlinePattern:Ze,fillPattern:Je,fillExtrusion:Ke,fillExtrusionPattern:$e,hillshadePrepare:Qe,hillshade:tr,line:er,lineGradient:rr,linePattern:nr,lineSDF:ir,raster:ar,symbolIcon:or,symbolSDF:sr}),ur=function(){this.boundProgram=null,this.boundLayoutVertexBuffer=null,this.boundPaintVertexBuffers=[],this.boundIndexBuffer=null,this.boundVertexOffset=null,this.boundDynamicVertexBuffer=null,this.vao=null};ur.prototype.bind=function(t,e,r,n,i,a,o,s){this.context=t;for(var l=this.boundPaintVertexBuffers.length!==n.length,c=0;!l&&c<n.length;c++)this.boundPaintVertexBuffers[c]!==n[c]&&(l=!0);var u=!this.vao||this.boundProgram!==e||this.boundLayoutVertexBuffer!==r||l||this.boundIndexBuffer!==i||this.boundVertexOffset!==a||this.boundDynamicVertexBuffer!==o||this.boundDynamicVertexBuffer2!==s;!t.extVertexArrayObject||u?this.freshBind(e,r,n,i,a,o,s):(t.bindVertexArrayOES.set(this.vao),o&&o.bind(),i&&i.dynamicDraw&&i.bind(),s&&s.bind())},ur.prototype.freshBind=function(t,e,r,n,i,a,o){var s,l=t.numAttributes,c=this.context,u=c.gl;if(c.extVertexArrayObject)this.vao&&this.destroy(),this.vao=c.extVertexArrayObject.createVertexArrayOES(),c.bindVertexArrayOES.set(this.vao),s=0,this.boundProgram=t,this.boundLayoutVertexBuffer=e,this.boundPaintVertexBuffers=r,this.boundIndexBuffer=n,this.boundVertexOffset=i,this.boundDynamicVertexBuffer=a,this.boundDynamicVertexBuffer2=o;else{s=c.currentNumAttributes||0;for(var h=l;h<s;h++)u.disableVertexAttribArray(h)}e.enableAttributes(u,t);for(var f=0,p=r;f<p.length;f+=1)p[f].enableAttributes(u,t);a&&a.enableAttributes(u,t),o&&o.enableAttributes(u,t),e.bind(),e.setVertexAttribPointers(u,t,i);for(var d=0,g=r;d<g.length;d+=1){var v=g[d];v.bind(),v.setVertexAttribPointers(u,t,i)}a&&(a.bind(),a.setVertexAttribPointers(u,t,i)),n&&n.bind(),o&&(o.bind(),o.setVertexAttribPointers(u,t,i)),c.currentNumAttributes=l},ur.prototype.destroy=function(){this.vao&&(this.context.extVertexArrayObject.deleteVertexArrayOES(this.vao),this.vao=null)};var hr=function(t,e,r,n,i){var a=t.gl;this.program=a.createProgram();var o=r.defines();i&&o.push(\"#define OVERDRAW_INSPECTOR;\");var s=o.concat(Fe.fragmentSource,e.fragmentSource).join(\"\\n\"),l=o.concat(Fe.vertexSource,e.vertexSource).join(\"\\n\"),c=a.createShader(a.FRAGMENT_SHADER);a.shaderSource(c,s),a.compileShader(c),a.attachShader(this.program,c);var u=a.createShader(a.VERTEX_SHADER);a.shaderSource(u,l),a.compileShader(u),a.attachShader(this.program,u);for(var h=r.layoutAttributes||[],f=0;f<h.length;f++)a.bindAttribLocation(this.program,f,h[f].name);a.linkProgram(this.program),this.numAttributes=a.getProgramParameter(this.program,a.ACTIVE_ATTRIBUTES),this.attributes={};for(var p={},d=0;d<this.numAttributes;d++){var g=a.getActiveAttrib(this.program,d);g&&(this.attributes[g.name]=a.getAttribLocation(this.program,g.name))}for(var v=a.getProgramParameter(this.program,a.ACTIVE_UNIFORMS),m=0;m<v;m++){var y=a.getActiveUniform(this.program,m);y&&(p[y.name]=a.getUniformLocation(this.program,y.name))}this.fixedUniforms=n(t,p),this.binderUniforms=r.getUniforms(t,p)};function fr(e,r,n){var i=1/le(n,1,r.transform.tileZoom),a=Math.pow(2,n.tileID.overscaledZ),o=n.tileSize*Math.pow(2,r.transform.tileZoom)/a,s=o*(n.tileID.canonical.x+n.tileID.wrap*a),l=o*n.tileID.canonical.y;return{u_image:0,u_texsize:n.imageAtlasTexture.size,u_scale:[t.browser.devicePixelRatio,i,e.fromScale,e.toScale],u_fade:e.t,u_pixel_coord_upper:[s>>16,l>>16],u_pixel_coord_lower:[65535&s,65535&l]}}hr.prototype.draw=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g){var v,m=t.gl;for(var y in t.program.set(this.program),t.setDepthMode(r),t.setStencilMode(n),t.setColorMode(i),t.setCullFace(a),this.fixedUniforms)this.fixedUniforms[y].set(o[y]);p&&p.setUniforms(t,this.binderUniforms,h,{zoom:f});for(var x=(v={},v[m.LINES]=2,v[m.TRIANGLES]=3,v[m.LINE_STRIP]=1,v)[e],b=0,_=u.get();b<_.length;b+=1){var w=_[b],k=w.vaos||(w.vaos={});(k[s]||(k[s]=new ur)).bind(t,this,l,p?p.getPaintVertexBuffers():[],c,w.vertexOffset,d,g),m.drawElements(e,w.primitiveLength*x,m.UNSIGNED_SHORT,w.primitiveOffset*x*2)}};var pr=function(e,r,n,i){var a=r.style.light,o=a.properties.get(\"position\"),s=[o.x,o.y,o.z],l=t.create$1();\"viewport\"===a.properties.get(\"anchor\")&&t.fromRotation(l,-r.transform.angle),t.transformMat3(s,s,l);var c=a.properties.get(\"color\");return{u_matrix:e,u_lightpos:s,u_lightintensity:a.properties.get(\"intensity\"),u_lightcolor:[c.r,c.g,c.b],u_vertical_gradient:+n,u_opacity:i}},dr=function(e,r,n,i,a,o,s){return t.extend(pr(e,r,n,i),fr(o,r,s),{u_height_factor:-Math.pow(2,a.overscaledZ)/s.tileSize/8})},gr=function(t){return{u_matrix:t}},vr=function(e,r,n,i){return t.extend(gr(e),fr(n,r,i))},mr=function(t,e){return{u_matrix:t,u_world:e}},yr=function(e,r,n,i,a){return t.extend(vr(e,r,n,i),{u_world:a})},xr=function(e,r,n,i){var a,o,s=e.transform;if(\"map\"===i.paint.get(\"circle-pitch-alignment\")){var l=le(n,1,s.zoom);a=!0,o=[l,l]}else a=!1,o=s.pixelsToGLUnits;return{u_camera_to_center_distance:s.cameraToCenterDistance,u_scale_with_map:+(\"map\"===i.paint.get(\"circle-pitch-scale\")),u_matrix:e.translatePosMatrix(r.posMatrix,n,i.paint.get(\"circle-translate\"),i.paint.get(\"circle-translate-anchor\")),u_pitch_with_map:+a,u_device_pixel_ratio:t.browser.devicePixelRatio,u_extrude_scale:o}},br=function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pixels_to_tile_units:new t.Uniform1f(e,r.u_pixels_to_tile_units),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_overscale_factor:new t.Uniform1f(e,r.u_overscale_factor)}},_r=function(t,e,r){var n=le(r,1,e.zoom),i=Math.pow(2,e.zoom-r.tileID.overscaledZ),a=r.tileID.overscaleFactor();return{u_matrix:t,u_camera_to_center_distance:e.cameraToCenterDistance,u_pixels_to_tile_units:n,u_extrude_scale:[e.pixelsToGLUnits[0]/(n*i),e.pixelsToGLUnits[1]/(n*i)],u_overscale_factor:a}},wr=function(t,e){return{u_matrix:t,u_color:e}},kr=function(t){return{u_matrix:t}},Tr=function(t,e,r,n){return{u_matrix:t,u_extrude_scale:le(e,1,r),u_intensity:n}},Ar=function(t,e,r){var n=r.paint.get(\"hillshade-shadow-color\"),i=r.paint.get(\"hillshade-highlight-color\"),a=r.paint.get(\"hillshade-accent-color\"),o=r.paint.get(\"hillshade-illumination-direction\")*(Math.PI/180);\"viewport\"===r.paint.get(\"hillshade-illumination-anchor\")&&(o-=t.transform.angle);var s=!t.options.moving;return{u_matrix:t.transform.calculatePosMatrix(e.tileID.toUnwrapped(),s),u_image:0,u_latrange:Sr(t,e.tileID),u_light:[r.paint.get(\"hillshade-exaggeration\"),o],u_shadow:n,u_highlight:i,u_accent:a}},Mr=function(e,r){var n=e.dem.stride,i=t.create();return t.ortho(i,0,t.EXTENT,-t.EXTENT,0,0,1),t.translate(i,i,[0,-t.EXTENT,0]),{u_matrix:i,u_image:1,u_dimension:[n,n],u_zoom:e.tileID.overscaledZ,u_maxzoom:r}};function Sr(e,r){var n=Math.pow(2,r.canonical.z),i=r.canonical.y;return[new t.MercatorCoordinate(0,i/n).toLngLat().lat,new t.MercatorCoordinate(0,(i+1)/n).toLngLat().lat]}var Er=function(e,r,n){var i=e.transform;return{u_matrix:zr(e,r,n),u_ratio:1/le(r,1,i.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_units_to_pixels:[1/i.pixelsToGLUnits[0],1/i.pixelsToGLUnits[1]]}},Cr=function(e,r,n){return t.extend(Er(e,r,n),{u_image:0})},Lr=function(e,r,n,i){var a=e.transform,o=Or(r,a);return{u_matrix:zr(e,r,n),u_texsize:r.imageAtlasTexture.size,u_ratio:1/le(r,1,a.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_image:0,u_scale:[t.browser.devicePixelRatio,o,i.fromScale,i.toScale],u_fade:i.t,u_units_to_pixels:[1/a.pixelsToGLUnits[0],1/a.pixelsToGLUnits[1]]}},Pr=function(e,r,n,i,a){var o=e.transform,s=e.lineAtlas,l=Or(r,o),c=\"round\"===n.layout.get(\"line-cap\"),u=s.getDash(i.from,c),h=s.getDash(i.to,c),f=u.width*a.fromScale,p=h.width*a.toScale;return t.extend(Er(e,r,n),{u_patternscale_a:[l/f,-u.height/2],u_patternscale_b:[l/p,-h.height/2],u_sdfgamma:s.width/(256*Math.min(f,p)*t.browser.devicePixelRatio)/2,u_image:0,u_tex_y_a:u.y,u_tex_y_b:h.y,u_mix:a.t})};function Or(t,e){return 1/le(t,1,e.tileZoom)}function zr(t,e,r){return t.translatePosMatrix(e.tileID.posMatrix,e,r.paint.get(\"line-translate\"),r.paint.get(\"line-translate-anchor\"))}var Ir=function(t,e,r,n,i){return{u_matrix:t,u_tl_parent:e,u_scale_parent:r,u_buffer_scale:1,u_fade_t:n.mix,u_opacity:n.opacity*i.paint.get(\"raster-opacity\"),u_image0:0,u_image1:1,u_brightness_low:i.paint.get(\"raster-brightness-min\"),u_brightness_high:i.paint.get(\"raster-brightness-max\"),u_saturation_factor:(o=i.paint.get(\"raster-saturation\"),o>0?1-1/(1.001-o):-o),u_contrast_factor:(a=i.paint.get(\"raster-contrast\"),a>0?1/(1-a):1+a),u_spin_weights:function(t){t*=Math.PI/180;var e=Math.sin(t),r=Math.cos(t);return[(2*r+1)/3,(-Math.sqrt(3)*e-r+1)/3,(Math.sqrt(3)*e-r+1)/3]}(i.paint.get(\"raster-hue-rotate\"))};var a,o};var Dr=function(t,e,r,n,i,a,o,s,l,c){var u=i.transform;return{u_is_size_zoom_constant:+(\"constant\"===t||\"source\"===t),u_is_size_feature_constant:+(\"constant\"===t||\"camera\"===t),u_size_t:e?e.uSizeT:0,u_size:e?e.uSize:0,u_camera_to_center_distance:u.cameraToCenterDistance,u_pitch:u.pitch/360*2*Math.PI,u_rotate_symbol:+r,u_aspect_ratio:u.width/u.height,u_fade_change:i.options.fadeDuration?i.symbolFadeChange:1,u_matrix:a,u_label_plane_matrix:o,u_coord_matrix:s,u_is_text:+l,u_pitch_with_map:+n,u_texsize:c,u_texture:0}},Rr=function(e,r,n,i,a,o,s,l,c,u,h){var f=a.transform;return t.extend(Dr(e,r,n,i,a,o,s,l,c,u),{u_gamma_scale:i?Math.cos(f._pitch)*f.cameraToCenterDistance:1,u_device_pixel_ratio:t.browser.devicePixelRatio,u_is_halo:+h})},Fr=function(t,e,r){return{u_matrix:t,u_opacity:e,u_color:r}},Br=function(e,r,n,i,a,o){return t.extend(function(t,e,r,n){var i=r.imageManager.getPattern(t.from),a=r.imageManager.getPattern(t.to),o=r.imageManager.getPixelSize(),s=o.width,l=o.height,c=Math.pow(2,n.tileID.overscaledZ),u=n.tileSize*Math.pow(2,r.transform.tileZoom)/c,h=u*(n.tileID.canonical.x+n.tileID.wrap*c),f=u*n.tileID.canonical.y;return{u_image:0,u_pattern_tl_a:i.tl,u_pattern_br_a:i.br,u_pattern_tl_b:a.tl,u_pattern_br_b:a.br,u_texsize:[s,l],u_mix:e.t,u_pattern_size_a:i.displaySize,u_pattern_size_b:a.displaySize,u_scale_a:e.fromScale,u_scale_b:e.toScale,u_tile_units_to_pixels:1/le(n,1,r.transform.tileZoom),u_pixel_coord_upper:[h>>16,f>>16],u_pixel_coord_lower:[65535&h,65535&f]}}(i,o,n,a),{u_matrix:e,u_opacity:r})},Nr={fillExtrusion:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fillExtrusionPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_height_factor:new t.Uniform1f(e,r.u_height_factor),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fill:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},fillPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},fillOutline:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world)}},fillOutlinePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},circle:function(e,r){return{u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_scale_with_map:new t.Uniform1i(e,r.u_scale_with_map),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},collisionBox:br,collisionCircle:br,debug:function(e,r){return{u_color:new t.UniformColor(e,r.u_color),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},clippingMask:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmap:function(e,r){return{u_extrude_scale:new t.Uniform1f(e,r.u_extrude_scale),u_intensity:new t.Uniform1f(e,r.u_intensity),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmapTexture:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_color_ramp:new t.Uniform1i(e,r.u_color_ramp),u_opacity:new t.Uniform1f(e,r.u_opacity)}},hillshade:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_latrange:new t.Uniform2f(e,r.u_latrange),u_light:new t.Uniform2f(e,r.u_light),u_shadow:new t.UniformColor(e,r.u_shadow),u_highlight:new t.UniformColor(e,r.u_highlight),u_accent:new t.UniformColor(e,r.u_accent)}},hillshadePrepare:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_dimension:new t.Uniform2f(e,r.u_dimension),u_zoom:new t.Uniform1f(e,r.u_zoom),u_maxzoom:new t.Uniform1f(e,r.u_maxzoom)}},line:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels)}},lineGradient:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_image:new t.Uniform1i(e,r.u_image)}},linePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_texsize:new t.Uniform2f(e,r.u_texsize),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_image:new t.Uniform1i(e,r.u_image),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},lineSDF:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_patternscale_a:new t.Uniform2f(e,r.u_patternscale_a),u_patternscale_b:new t.Uniform2f(e,r.u_patternscale_b),u_sdfgamma:new t.Uniform1f(e,r.u_sdfgamma),u_image:new t.Uniform1i(e,r.u_image),u_tex_y_a:new t.Uniform1f(e,r.u_tex_y_a),u_tex_y_b:new t.Uniform1f(e,r.u_tex_y_b),u_mix:new t.Uniform1f(e,r.u_mix)}},raster:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_tl_parent:new t.Uniform2f(e,r.u_tl_parent),u_scale_parent:new t.Uniform1f(e,r.u_scale_parent),u_buffer_scale:new t.Uniform1f(e,r.u_buffer_scale),u_fade_t:new t.Uniform1f(e,r.u_fade_t),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image0:new t.Uniform1i(e,r.u_image0),u_image1:new t.Uniform1i(e,r.u_image1),u_brightness_low:new t.Uniform1f(e,r.u_brightness_low),u_brightness_high:new t.Uniform1f(e,r.u_brightness_high),u_saturation_factor:new t.Uniform1f(e,r.u_saturation_factor),u_contrast_factor:new t.Uniform1f(e,r.u_contrast_factor),u_spin_weights:new t.Uniform3f(e,r.u_spin_weights)}},symbolIcon:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1f(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture)}},symbolSDF:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1f(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture),u_gamma_scale:new t.Uniform1f(e,r.u_gamma_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_is_halo:new t.Uniform1f(e,r.u_is_halo)}},background:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_color:new t.UniformColor(e,r.u_color)}},backgroundPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image:new t.Uniform1i(e,r.u_image),u_pattern_tl_a:new t.Uniform2f(e,r.u_pattern_tl_a),u_pattern_br_a:new t.Uniform2f(e,r.u_pattern_br_a),u_pattern_tl_b:new t.Uniform2f(e,r.u_pattern_tl_b),u_pattern_br_b:new t.Uniform2f(e,r.u_pattern_br_b),u_texsize:new t.Uniform2f(e,r.u_texsize),u_mix:new t.Uniform1f(e,r.u_mix),u_pattern_size_a:new t.Uniform2f(e,r.u_pattern_size_a),u_pattern_size_b:new t.Uniform2f(e,r.u_pattern_size_b),u_scale_a:new t.Uniform1f(e,r.u_scale_a),u_scale_b:new t.Uniform1f(e,r.u_scale_b),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_tile_units_to_pixels:new t.Uniform1f(e,r.u_tile_units_to_pixels)}}};function jr(e,r){for(var n=e.sort(function(t,e){return t.tileID.isLessThan(e.tileID)?-1:e.tileID.isLessThan(t.tileID)?1:0}),i=0;i<n.length;i++){var a={},o=n[i],s=n.slice(i+1);Ur(o.tileID.wrapped(),o.tileID,s,new t.OverscaledTileID(0,o.tileID.wrap+1,0,0,0),a),o.setMask(a,r)}}function Ur(e,r,n,i,a){for(var o=0;o<n.length;o++){var s=n[o];if(i.isLessThan(s.tileID))break;if(r.key===s.tileID.key)return;if(s.tileID.isChildOf(r)){for(var l=r.children(1/0),c=0;c<l.length;c++)Ur(e,l[c],n.slice(o),i,a);return}}var u=r.overscaledZ-e.overscaledZ,h=new t.CanonicalTileID(u,r.canonical.x-(e.canonical.x<<u),r.canonical.y-(e.canonical.y<<u));a[h.key]=a[h.key]||h}function Vr(t,e,r,n,i){for(var a=t.context,o=a.gl,s=i?t.useProgram(\"collisionCircle\"):t.useProgram(\"collisionBox\"),l=0;l<n.length;l++){var c=n[l],u=e.getTile(c),h=u.getBucket(r);if(h){var f=i?h.collisionCircle:h.collisionBox;f&&s.draw(a,i?o.TRIANGLES:o.LINES,Tt.disabled,At.disabled,t.colorModeForRenderPass(),St.disabled,_r(c.posMatrix,t.transform,u),r.id,f.layoutVertexBuffer,f.indexBuffer,f.segments,null,t.transform.zoom,null,null,f.collisionVertexBuffer)}}}var qr=t.identity(new Float32Array(16));function Hr(e,r,n,i,a,o){var s=t.getAnchorAlignment(e),l=-(s.horizontalAlign-.5)*r,c=-(s.verticalAlign-.5)*n,u=t.evaluateRadialOffset(e,i);return new t.Point((l/a+u[0])*o,(c/a+u[1])*o)}function Gr(e,r,n,i,a,o,s,l,c,u){var h=e.text.placedSymbolArray,f=e.text.dynamicLayoutVertexArray;f.clear();for(var p=0;p<h.length;p++){var d=h.get(p),g=!d.hidden&&d.crossTileID?i[d.crossTileID]:null;if(g){var v=new t.Point(d.anchorX,d.anchorY),m=Zt(v,n?l:s),y=.5+o.cameraToCenterDistance/m.signedDistanceFromCamera*.5,x=a.evaluateSizeForFeature(e.textSizeData,u,d)*y/t.ONE_EM;n&&(x*=e.tilePixelRatio/c);for(var b=g.width,_=g.height,w=g.radialOffset,k=g.textBoxScale,T=Hr(g.anchor,b,_,w,k,x),A=n?Zt(v.add(T),s).point:m.point.add(r?T.rotate(-o.angle):T),M=0;M<d.numGlyphs;M++)t.addDynamicAttributes(f,A,0)}else ie(d.numGlyphs,f)}e.text.dynamicLayoutVertexBuffer.updateData(f)}function Yr(e,r,n,i,a,o,s,l,c,u,h,f,p){for(var d,g,v=e.context,m=v.gl,y=e.transform,x=\"map\"===l,b=\"map\"===c,_=x&&\"point\"!==n.layout.get(\"symbol-placement\"),w=x&&!b&&!_,k=void 0!==n.layout.get(\"symbol-sort-key\").constantOr(1),T=e.depthModeForSublayer(0,Tt.ReadOnly),A=n.layout.get(\"text-variable-anchor\"),M=[],S=0,E=i;S<E.length;S+=1){var C=E[S],L=r.getTile(C),P=L.getBucket(n);if(P){var O=a?P.text:P.icon;if(O&&O.segments.get().length){var z=O.programConfigurations.get(n.id),I=a||P.sdfIcons,D=a?P.textSizeData:P.iconSizeData;d||(d=e.useProgram(I?\"symbolSDF\":\"symbolIcon\",z),g=t.evaluateSizeForZoom(D,y.zoom)),v.activeTexture.set(m.TEXTURE0);var R=void 0,F=void 0,B=void 0;if(a)F=L.glyphAtlasTexture,B=m.LINEAR,R=L.glyphAtlasTexture.size;else{var N=1!==n.layout.get(\"icon-size\").constantOr(0)||P.iconsNeedLinear,j=b||0!==y.pitch;F=L.imageAtlasTexture,B=I||e.options.rotating||e.options.zooming||N||j?m.LINEAR:m.NEAREST,R=L.imageAtlasTexture.size}var U=le(L,1,e.transform.zoom),V=Wt(C.posMatrix,b,x,e.transform,U),q=Xt(C.posMatrix,b,x,e.transform,U);if(_)Kt(P,C.posMatrix,e,a,V,q,b,u);else if(a&&g&&A){var H=Math.pow(2,y.zoom-L.tileID.overscaledZ);Gr(P,x,b,p,t.symbolSize,y,V,C.posMatrix,H,g)}var G=e.translatePosMatrix(C.posMatrix,L,o,s),Y=_||a&&A?qr:V,W=e.translatePosMatrix(q,L,o,s,!0),X=I&&0!==n.paint.get(a?\"text-halo-width\":\"icon-halo-width\").constantOr(1),Z={program:d,buffers:O,uniformValues:I?Rr(D.kind,g,w,b,e,G,Y,W,a,R,!0):Dr(D.kind,g,w,b,e,G,Y,W,a,R),atlasTexture:F,atlasInterpolation:B,isSDF:I,hasHalo:X};if(k)for(var J=0,K=O.segments.get();J<K.length;J+=1){var $=K[J];M.push({segments:new t.SegmentVector([$]),sortKey:$.sortKey,state:Z})}else M.push({segments:O.segments,sortKey:0,state:Z})}}}k&&M.sort(function(t,e){return t.sortKey-e.sortKey});for(var Q=0,tt=M;Q<tt.length;Q+=1){var et=tt[Q],rt=et.state;if(rt.atlasTexture.bind(rt.atlasInterpolation,m.CLAMP_TO_EDGE),rt.isSDF){var nt=rt.uniformValues;rt.hasHalo&&(nt.u_is_halo=1,Wr(rt.buffers,et.segments,n,e,rt.program,T,h,f,nt)),nt.u_is_halo=0}Wr(rt.buffers,et.segments,n,e,rt.program,T,h,f,rt.uniformValues)}}function Wr(t,e,r,n,i,a,o,s,l){var c=n.context,u=c.gl;i.draw(c,u.TRIANGLES,a,o,s,St.disabled,l,r.id,t.layoutVertexBuffer,t.indexBuffer,e,r.paint,n.transform.zoom,t.programConfigurations.get(r.id),t.dynamicLayoutVertexBuffer,t.opacityVertexBuffer)}function Xr(t,e,r,n,i,a,o){var s,l,c,u,h,f=t.context.gl,p=r.paint.get(\"fill-pattern\"),d=p&&p.constantOr(1),g=r.getCrossfadeParameters();o?(l=d&&!r.getPaintProperty(\"fill-outline-color\")?\"fillOutlinePattern\":\"fillOutline\",s=f.LINES):(l=d?\"fillPattern\":\"fill\",s=f.TRIANGLES);for(var v=0,m=n;v<m.length;v+=1){var y=m[v],x=e.getTile(y);if(!d||x.patternsLoaded()){var b=x.getBucket(r);if(b){var _=b.programConfigurations.get(r.id),w=t.useProgram(l,_);d&&(t.context.activeTexture.set(f.TEXTURE0),x.imageAtlasTexture.bind(f.LINEAR,f.CLAMP_TO_EDGE),_.updatePatternPaintBuffers(g));var k=p.constantOr(null);if(k&&x.imageAtlas){var T=x.imageAtlas.patternPositions[k.to],A=x.imageAtlas.patternPositions[k.from];T&&A&&_.setConstantPatternPositions(T,A)}var M=t.translatePosMatrix(y.posMatrix,x,r.paint.get(\"fill-translate\"),r.paint.get(\"fill-translate-anchor\"));if(o){u=b.indexBuffer2,h=b.segments2;var S=[f.drawingBufferWidth,f.drawingBufferHeight];c=\"fillOutlinePattern\"===l&&d?yr(M,t,g,x,S):mr(M,S)}else u=b.indexBuffer,h=b.segments,c=d?vr(M,t,g,x):gr(M);w.draw(t.context,s,i,t.stencilModeForClipping(y),a,St.disabled,c,r.id,b.layoutVertexBuffer,u,h,r.paint,t.transform.zoom,_)}}}}function Zr(t,e,r,n,i,a,o){for(var s=t.context,l=s.gl,c=r.paint.get(\"fill-extrusion-pattern\"),u=c.constantOr(1),h=r.getCrossfadeParameters(),f=r.paint.get(\"fill-extrusion-opacity\"),p=0,d=n;p<d.length;p+=1){var g=d[p],v=e.getTile(g),m=v.getBucket(r);if(m){var y=m.programConfigurations.get(r.id),x=t.useProgram(u?\"fillExtrusionPattern\":\"fillExtrusion\",y);u&&(t.context.activeTexture.set(l.TEXTURE0),v.imageAtlasTexture.bind(l.LINEAR,l.CLAMP_TO_EDGE),y.updatePatternPaintBuffers(h));var b=c.constantOr(null);if(b&&v.imageAtlas){var _=v.imageAtlas.patternPositions[b.to],w=v.imageAtlas.patternPositions[b.from];_&&w&&y.setConstantPatternPositions(_,w)}var k=t.translatePosMatrix(g.posMatrix,v,r.paint.get(\"fill-extrusion-translate\"),r.paint.get(\"fill-extrusion-translate-anchor\")),T=r.paint.get(\"fill-extrusion-vertical-gradient\"),A=u?dr(k,t,T,f,g,h,v):pr(k,t,T,f);x.draw(s,s.gl.TRIANGLES,i,a,o,St.backCCW,A,r.id,m.layoutVertexBuffer,m.indexBuffer,m.segments,r.paint,t.transform.zoom,y)}}}function Jr(t,e,r,n,i,a){var o=t.context,s=o.gl,l=e.fbo;if(l){var c=t.useProgram(\"hillshade\");o.activeTexture.set(s.TEXTURE0),s.bindTexture(s.TEXTURE_2D,l.colorAttachment.get());var u=Ar(t,e,r);e.maskedBoundsBuffer&&e.maskedIndexBuffer&&e.segments?c.draw(o,s.TRIANGLES,n,i,a,St.disabled,u,r.id,e.maskedBoundsBuffer,e.maskedIndexBuffer,e.segments):c.draw(o,s.TRIANGLES,n,i,a,St.disabled,u,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}}function Kr(e,r,n,i,a,o,s){var l=e.context,c=l.gl;if(r.dem&&r.dem.data){var u=r.dem.dim,h=r.dem.stride,f=r.dem.getPixels();if(l.activeTexture.set(c.TEXTURE1),l.pixelStoreUnpackPremultiplyAlpha.set(!1),r.demTexture=r.demTexture||e.getTileTexture(h),r.demTexture){var p=r.demTexture;p.update(f,{premultiply:!1}),p.bind(c.NEAREST,c.CLAMP_TO_EDGE)}else r.demTexture=new t.Texture(l,f,c.RGBA,{premultiply:!1}),r.demTexture.bind(c.NEAREST,c.CLAMP_TO_EDGE);l.activeTexture.set(c.TEXTURE0);var d=r.fbo;if(!d){var g=new t.Texture(l,{width:u,height:u,data:null},c.RGBA);g.bind(c.LINEAR,c.CLAMP_TO_EDGE),(d=r.fbo=l.createFramebuffer(u,u)).colorAttachment.set(g.texture)}l.bindFramebuffer.set(d.framebuffer),l.viewport.set([0,0,u,u]),e.useProgram(\"hillshadePrepare\").draw(l,c.TRIANGLES,a,o,s,St.disabled,Mr(r,i),n.id,e.rasterBoundsBuffer,e.quadTriangleIndexBuffer,e.rasterBoundsSegments),r.needsHillshadePrepare=!1}}function $r(e,r,n,i,a){var o=i.paint.get(\"raster-fade-duration\");if(o>0){var s=t.browser.now(),l=(s-e.timeAdded)/o,c=r?(s-r.timeAdded)/o:-1,u=n.getSource(),h=a.coveringZoomLevel({tileSize:u.tileSize,roundZoom:u.roundZoom}),f=!r||Math.abs(r.tileID.overscaledZ-h)>Math.abs(e.tileID.overscaledZ-h),p=f&&e.refreshedUponExpiration?1:t.clamp(f?l:1-c,0,1);return e.refreshedUponExpiration&&l>=1&&(e.refreshedUponExpiration=!1),r?{opacity:1,mix:1-p}:{opacity:p,mix:0}}return{opacity:1,mix:0}}function Qr(e,r,n){var i=e.context,a=i.gl,o=n.posMatrix,s=e.useProgram(\"debug\"),l=Tt.disabled,c=At.disabled,u=e.colorModeForRenderPass(),h=\"$debug\";s.draw(i,a.LINE_STRIP,l,c,u,St.disabled,wr(o,t.Color.red),h,e.debugBuffer,e.tileBorderIndexBuffer,e.debugSegments);for(var f=r.getTileByID(n.key).latestRawTileData,p=f&&f.byteLength||0,d=Math.floor(p/1024),g=function(t,e,r,n){n=n||1;var i,a,o,s,l,c,u,h,f=[];for(i=0,a=t.length;i<a;i++)if(l=tn[t[i]]){for(h=null,o=0,s=l[1].length;o<s;o+=2)-1===l[1][o]&&-1===l[1][o+1]?h=null:(c=e+l[1][o]*n,u=200-l[1][o+1]*n,h&&f.push(h.x,h.y,c,u),h={x:c,y:u});e+=l[0]*n}return f}(n.toString()+\" \"+d+\"kb\",50,0,5),v=new t.StructArrayLayout2i4,m=new t.StructArrayLayout2ui4,y=0;y<g.length;y+=2)v.emplaceBack(g[y],g[y+1]),m.emplaceBack(y,y+1);for(var x=i.createVertexBuffer(v,Re.members),b=i.createIndexBuffer(m),_=t.SegmentVector.simpleSegment(0,0,v.length/2,v.length/2),w=r.getTile(n).tileSize,k=t.EXTENT/(Math.pow(2,e.transform.zoom-n.overscaledZ)*w),T=[[-1,-1],[-1,1],[1,-1],[1,1]],A=0;A<T.length;A++){var M=T[A];s.draw(i,a.LINES,l,c,u,St.disabled,wr(t.translate([],o,[k*M[0],k*M[1],0]),t.Color.white),h,x,b,_)}s.draw(i,a.LINES,l,c,u,St.disabled,wr(o,t.Color.black),h,x,b,_)}var tn={\" \":[16,[]],\"!\":[10,[5,21,5,7,-1,-1,5,2,4,1,5,0,6,1,5,2]],'\"':[16,[4,21,4,14,-1,-1,12,21,12,14]],\"#\":[21,[11,25,4,-7,-1,-1,17,25,10,-7,-1,-1,4,12,18,12,-1,-1,3,6,17,6]],$:[20,[8,25,8,-4,-1,-1,12,25,12,-4,-1,-1,17,18,15,20,12,21,8,21,5,20,3,18,3,16,4,14,5,13,7,12,13,10,15,9,16,8,17,6,17,3,15,1,12,0,8,0,5,1,3,3]],\"%\":[24,[21,21,3,0,-1,-1,8,21,10,19,10,17,9,15,7,14,5,14,3,16,3,18,4,20,6,21,8,21,10,20,13,19,16,19,19,20,21,21,-1,-1,17,7,15,6,14,4,14,2,16,0,18,0,20,1,21,3,21,5,19,7,17,7]],\"&\":[26,[23,12,23,13,22,14,21,14,20,13,19,11,17,6,15,3,13,1,11,0,7,0,5,1,4,2,3,4,3,6,4,8,5,9,12,13,13,14,14,16,14,18,13,20,11,21,9,20,8,18,8,16,9,13,11,10,16,3,18,1,20,0,22,0,23,1,23,2]],\"'\":[10,[5,19,4,20,5,21,6,20,6,18,5,16,4,15]],\"(\":[14,[11,25,9,23,7,20,5,16,4,11,4,7,5,2,7,-2,9,-5,11,-7]],\")\":[14,[3,25,5,23,7,20,9,16,10,11,10,7,9,2,7,-2,5,-5,3,-7]],\"*\":[16,[8,21,8,9,-1,-1,3,18,13,12,-1,-1,13,18,3,12]],\"+\":[26,[13,18,13,0,-1,-1,4,9,22,9]],\",\":[10,[6,1,5,0,4,1,5,2,6,1,6,-1,5,-3,4,-4]],\"-\":[26,[4,9,22,9]],\".\":[10,[5,2,4,1,5,0,6,1,5,2]],\"/\":[22,[20,25,2,-7]],0:[20,[9,21,6,20,4,17,3,12,3,9,4,4,6,1,9,0,11,0,14,1,16,4,17,9,17,12,16,17,14,20,11,21,9,21]],1:[20,[6,17,8,18,11,21,11,0]],2:[20,[4,16,4,17,5,19,6,20,8,21,12,21,14,20,15,19,16,17,16,15,15,13,13,10,3,0,17,0]],3:[20,[5,21,16,21,10,13,13,13,15,12,16,11,17,8,17,6,16,3,14,1,11,0,8,0,5,1,4,2,3,4]],4:[20,[13,21,3,7,18,7,-1,-1,13,21,13,0]],5:[20,[15,21,5,21,4,12,5,13,8,14,11,14,14,13,16,11,17,8,17,6,16,3,14,1,11,0,8,0,5,1,4,2,3,4]],6:[20,[16,18,15,20,12,21,10,21,7,20,5,17,4,12,4,7,5,3,7,1,10,0,11,0,14,1,16,3,17,6,17,7,16,10,14,12,11,13,10,13,7,12,5,10,4,7]],7:[20,[17,21,7,0,-1,-1,3,21,17,21]],8:[20,[8,21,5,20,4,18,4,16,5,14,7,13,11,12,14,11,16,9,17,7,17,4,16,2,15,1,12,0,8,0,5,1,4,2,3,4,3,7,4,9,6,11,9,12,13,13,15,14,16,16,16,18,15,20,12,21,8,21]],9:[20,[16,14,15,11,13,9,10,8,9,8,6,9,4,11,3,14,3,15,4,18,6,20,9,21,10,21,13,20,15,18,16,14,16,9,15,4,13,1,10,0,8,0,5,1,4,3]],\":\":[10,[5,14,4,13,5,12,6,13,5,14,-1,-1,5,2,4,1,5,0,6,1,5,2]],\";\":[10,[5,14,4,13,5,12,6,13,5,14,-1,-1,6,1,5,0,4,1,5,2,6,1,6,-1,5,-3,4,-4]],\"<\":[24,[20,18,4,9,20,0]],\"=\":[26,[4,12,22,12,-1,-1,4,6,22,6]],\">\":[24,[4,18,20,9,4,0]],\"?\":[18,[3,16,3,17,4,19,5,20,7,21,11,21,13,20,14,19,15,17,15,15,14,13,13,12,9,10,9,7,-1,-1,9,2,8,1,9,0,10,1,9,2]],\"@\":[27,[18,13,17,15,15,16,12,16,10,15,9,14,8,11,8,8,9,6,11,5,14,5,16,6,17,8,-1,-1,12,16,10,14,9,11,9,8,10,6,11,5,-1,-1,18,16,17,8,17,6,19,5,21,5,23,7,24,10,24,12,23,15,22,17,20,19,18,20,15,21,12,21,9,20,7,19,5,17,4,15,3,12,3,9,4,6,5,4,7,2,9,1,12,0,15,0,18,1,20,2,21,3,-1,-1,19,16,18,8,18,6,19,5]],A:[18,[9,21,1,0,-1,-1,9,21,17,0,-1,-1,4,7,14,7]],B:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,15,17,13,16,12,13,11,-1,-1,4,11,13,11,16,10,17,9,18,7,18,4,17,2,16,1,13,0,4,0]],C:[21,[18,16,17,18,15,20,13,21,9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5]],D:[21,[4,21,4,0,-1,-1,4,21,11,21,14,20,16,18,17,16,18,13,18,8,17,5,16,3,14,1,11,0,4,0]],E:[19,[4,21,4,0,-1,-1,4,21,17,21,-1,-1,4,11,12,11,-1,-1,4,0,17,0]],F:[18,[4,21,4,0,-1,-1,4,21,17,21,-1,-1,4,11,12,11]],G:[21,[18,16,17,18,15,20,13,21,9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,18,8,-1,-1,13,8,18,8]],H:[22,[4,21,4,0,-1,-1,18,21,18,0,-1,-1,4,11,18,11]],I:[8,[4,21,4,0]],J:[16,[12,21,12,5,11,2,10,1,8,0,6,0,4,1,3,2,2,5,2,7]],K:[21,[4,21,4,0,-1,-1,18,21,4,7,-1,-1,9,12,18,0]],L:[17,[4,21,4,0,-1,-1,4,0,16,0]],M:[24,[4,21,4,0,-1,-1,4,21,12,0,-1,-1,20,21,12,0,-1,-1,20,21,20,0]],N:[22,[4,21,4,0,-1,-1,4,21,18,0,-1,-1,18,21,18,0]],O:[22,[9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,19,8,19,13,18,16,17,18,15,20,13,21,9,21]],P:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,14,17,12,16,11,13,10,4,10]],Q:[22,[9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,19,8,19,13,18,16,17,18,15,20,13,21,9,21,-1,-1,12,4,18,-2]],R:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,15,17,13,16,12,13,11,4,11,-1,-1,11,11,18,0]],S:[20,[17,18,15,20,12,21,8,21,5,20,3,18,3,16,4,14,5,13,7,12,13,10,15,9,16,8,17,6,17,3,15,1,12,0,8,0,5,1,3,3]],T:[16,[8,21,8,0,-1,-1,1,21,15,21]],U:[22,[4,21,4,6,5,3,7,1,10,0,12,0,15,1,17,3,18,6,18,21]],V:[18,[1,21,9,0,-1,-1,17,21,9,0]],W:[24,[2,21,7,0,-1,-1,12,21,7,0,-1,-1,12,21,17,0,-1,-1,22,21,17,0]],X:[20,[3,21,17,0,-1,-1,17,21,3,0]],Y:[18,[1,21,9,11,9,0,-1,-1,17,21,9,11]],Z:[20,[17,21,3,0,-1,-1,3,21,17,21,-1,-1,3,0,17,0]],\"[\":[14,[4,25,4,-7,-1,-1,5,25,5,-7,-1,-1,4,25,11,25,-1,-1,4,-7,11,-7]],\"\\\\\":[14,[0,21,14,-3]],\"]\":[14,[9,25,9,-7,-1,-1,10,25,10,-7,-1,-1,3,25,10,25,-1,-1,3,-7,10,-7]],\"^\":[16,[6,15,8,18,10,15,-1,-1,3,12,8,17,13,12,-1,-1,8,17,8,0]],_:[16,[0,-2,16,-2]],\"`\":[10,[6,21,5,20,4,18,4,16,5,15,6,16,5,17]],a:[19,[15,14,15,0,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],b:[19,[4,21,4,0,-1,-1,4,11,6,13,8,14,11,14,13,13,15,11,16,8,16,6,15,3,13,1,11,0,8,0,6,1,4,3]],c:[18,[15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],d:[19,[15,21,15,0,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],e:[18,[3,8,15,8,15,10,14,12,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],f:[12,[10,21,8,21,6,20,5,17,5,0,-1,-1,2,14,9,14]],g:[19,[15,14,15,-2,14,-5,13,-6,11,-7,8,-7,6,-6,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],h:[19,[4,21,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0]],i:[8,[3,21,4,20,5,21,4,22,3,21,-1,-1,4,14,4,0]],j:[10,[5,21,6,20,7,21,6,22,5,21,-1,-1,6,14,6,-3,5,-6,3,-7,1,-7]],k:[17,[4,21,4,0,-1,-1,14,14,4,4,-1,-1,8,8,15,0]],l:[8,[4,21,4,0]],m:[30,[4,14,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0,-1,-1,15,10,18,13,20,14,23,14,25,13,26,10,26,0]],n:[19,[4,14,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0]],o:[19,[8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3,16,6,16,8,15,11,13,13,11,14,8,14]],p:[19,[4,14,4,-7,-1,-1,4,11,6,13,8,14,11,14,13,13,15,11,16,8,16,6,15,3,13,1,11,0,8,0,6,1,4,3]],q:[19,[15,14,15,-7,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],r:[13,[4,14,4,0,-1,-1,4,8,5,11,7,13,9,14,12,14]],s:[17,[14,11,13,13,10,14,7,14,4,13,3,11,4,9,6,8,11,7,13,6,14,4,14,3,13,1,10,0,7,0,4,1,3,3]],t:[12,[5,21,5,4,6,1,8,0,10,0,-1,-1,2,14,9,14]],u:[19,[4,14,4,4,5,1,7,0,10,0,12,1,15,4,-1,-1,15,14,15,0]],v:[16,[2,14,8,0,-1,-1,14,14,8,0]],w:[22,[3,14,7,0,-1,-1,11,14,7,0,-1,-1,11,14,15,0,-1,-1,19,14,15,0]],x:[17,[3,14,14,0,-1,-1,14,14,3,0]],y:[16,[2,14,8,0,-1,-1,14,14,8,0,6,-4,4,-6,2,-7,1,-7]],z:[17,[14,14,3,0,-1,-1,3,14,14,14,-1,-1,3,0,14,0]],\"{\":[14,[9,25,7,24,6,23,5,21,5,19,6,17,7,16,8,14,8,12,6,10,-1,-1,7,24,6,22,6,20,7,18,8,17,9,15,9,13,8,11,4,9,8,7,9,5,9,3,8,1,7,0,6,-2,6,-4,7,-6,-1,-1,6,8,8,6,8,4,7,2,6,1,5,-1,5,-3,6,-5,7,-6,9,-7]],\"|\":[8,[4,25,4,-7]],\"}\":[14,[5,25,7,24,8,23,9,21,9,19,8,17,7,16,6,14,6,12,8,10,-1,-1,7,24,8,22,8,20,7,18,6,17,5,15,5,13,6,11,10,9,6,7,5,5,5,3,6,1,7,0,8,-2,8,-4,7,-6,-1,-1,8,8,6,6,6,4,7,2,8,1,9,-1,9,-3,8,-5,7,-6,5,-7]],\"~\":[24,[3,6,3,8,4,11,6,12,8,12,10,11,14,8,16,7,18,7,20,8,21,10,-1,-1,3,8,4,10,6,11,8,11,10,10,14,7,16,6,18,6,20,7,21,10,21,12]]},en={symbol:function(t,e,r,n,i){if(\"translucent\"===t.renderPass){var a=At.disabled,o=t.colorModeForRenderPass();0!==r.paint.get(\"icon-opacity\").constantOr(1)&&Yr(t,e,r,n,!1,r.paint.get(\"icon-translate\"),r.paint.get(\"icon-translate-anchor\"),r.layout.get(\"icon-rotation-alignment\"),r.layout.get(\"icon-pitch-alignment\"),r.layout.get(\"icon-keep-upright\"),a,o,i),0!==r.paint.get(\"text-opacity\").constantOr(1)&&Yr(t,e,r,n,!0,r.paint.get(\"text-translate\"),r.paint.get(\"text-translate-anchor\"),r.layout.get(\"text-rotation-alignment\"),r.layout.get(\"text-pitch-alignment\"),r.layout.get(\"text-keep-upright\"),a,o,i),e.map.showCollisionBoxes&&function(t,e,r,n){Vr(t,e,r,n,!1),Vr(t,e,r,n,!0)}(t,e,r,n)}},circle:function(t,e,r,n){if(\"translucent\"===t.renderPass){var i=r.paint.get(\"circle-opacity\"),a=r.paint.get(\"circle-stroke-width\"),o=r.paint.get(\"circle-stroke-opacity\");if(0!==i.constantOr(1)||0!==a.constantOr(1)&&0!==o.constantOr(1))for(var s=t.context,l=s.gl,c=t.depthModeForSublayer(0,Tt.ReadOnly),u=At.disabled,h=t.colorModeForRenderPass(),f=0;f<n.length;f++){var p=n[f],d=e.getTile(p),g=d.getBucket(r);if(g){var v=g.programConfigurations.get(r.id);t.useProgram(\"circle\",v).draw(s,l.TRIANGLES,c,u,h,St.disabled,xr(t,p,d,r),r.id,g.layoutVertexBuffer,g.indexBuffer,g.segments,r.paint,t.transform.zoom,v)}}}},heatmap:function(e,r,n,i){if(0!==n.paint.get(\"heatmap-opacity\"))if(\"offscreen\"===e.renderPass){var a=e.context,o=a.gl,s=e.depthModeForSublayer(0,Tt.ReadOnly),l=At.disabled,c=new Mt([o.ONE,o.ONE],t.Color.transparent,[!0,!0,!0,!0]);!function(t,e,r){var n=t.gl;t.activeTexture.set(n.TEXTURE1),t.viewport.set([0,0,e.width/4,e.height/4]);var i=r.heatmapFbo;if(i)n.bindTexture(n.TEXTURE_2D,i.colorAttachment.get()),t.bindFramebuffer.set(i.framebuffer);else{var a=n.createTexture();n.bindTexture(n.TEXTURE_2D,a),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,n.LINEAR),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,n.LINEAR),i=r.heatmapFbo=t.createFramebuffer(e.width/4,e.height/4),function t(e,r,n,i){var a=e.gl;a.texImage2D(a.TEXTURE_2D,0,a.RGBA,r.width/4,r.height/4,0,a.RGBA,e.extTextureHalfFloat?e.extTextureHalfFloat.HALF_FLOAT_OES:a.UNSIGNED_BYTE,null),i.colorAttachment.set(n),e.extTextureHalfFloat&&a.checkFramebufferStatus(a.FRAMEBUFFER)!==a.FRAMEBUFFER_COMPLETE&&(e.extTextureHalfFloat=null,i.colorAttachment.setDirty(),t(e,r,n,i))}(t,e,a,i)}}(a,e,n),a.clear({color:t.Color.transparent});for(var u=0;u<i.length;u++){var h=i[u];if(!r.hasRenderableParent(h)){var f=r.getTile(h),p=f.getBucket(n);if(p){var d=p.programConfigurations.get(n.id),g=e.useProgram(\"heatmap\",d),v=e.transform.zoom;g.draw(a,o.TRIANGLES,s,l,c,St.disabled,Tr(h.posMatrix,f,v,n.paint.get(\"heatmap-intensity\")),n.id,p.layoutVertexBuffer,p.indexBuffer,p.segments,n.paint,e.transform.zoom,d)}}}a.viewport.set([0,0,e.width,e.height])}else\"translucent\"===e.renderPass&&(e.context.setColorMode(e.colorModeForRenderPass()),function(e,r){var n=e.context,i=n.gl,a=r.heatmapFbo;if(a){n.activeTexture.set(i.TEXTURE0),i.bindTexture(i.TEXTURE_2D,a.colorAttachment.get()),n.activeTexture.set(i.TEXTURE1);var o=r.colorRampTexture;o||(o=r.colorRampTexture=new t.Texture(n,r.colorRamp,i.RGBA)),o.bind(i.LINEAR,i.CLAMP_TO_EDGE),e.useProgram(\"heatmapTexture\").draw(n,i.TRIANGLES,Tt.disabled,At.disabled,e.colorModeForRenderPass(),St.disabled,function(e,r,n,i){var a=t.create();t.ortho(a,0,e.width,e.height,0,0,1);var o=e.context.gl;return{u_matrix:a,u_world:[o.drawingBufferWidth,o.drawingBufferHeight],u_image:n,u_color_ramp:i,u_opacity:r.paint.get(\"heatmap-opacity\")}}(e,r,0,1),r.id,e.viewportBuffer,e.quadTriangleIndexBuffer,e.viewportSegments,r.paint,e.transform.zoom)}}(e,n))},line:function(e,r,n,i){if(\"translucent\"===e.renderPass){var a=n.paint.get(\"line-opacity\"),o=n.paint.get(\"line-width\");if(0!==a.constantOr(1)&&0!==o.constantOr(1)){var s=e.depthModeForSublayer(0,Tt.ReadOnly),l=e.colorModeForRenderPass(),c=n.paint.get(\"line-dasharray\"),u=n.paint.get(\"line-pattern\"),h=u.constantOr(1),f=n.paint.get(\"line-gradient\"),p=n.getCrossfadeParameters(),d=c?\"lineSDF\":h?\"linePattern\":f?\"lineGradient\":\"line\",g=e.context,v=g.gl,m=!0;if(f){g.activeTexture.set(v.TEXTURE0);var y=n.gradientTexture;if(!n.gradient)return;y||(y=n.gradientTexture=new t.Texture(g,n.gradient,v.RGBA)),y.bind(v.LINEAR,v.CLAMP_TO_EDGE)}for(var x=0,b=i;x<b.length;x+=1){var _=b[x],w=r.getTile(_);if(!h||w.patternsLoaded()){var k=w.getBucket(n);if(k){var T=k.programConfigurations.get(n.id),A=e.context.program.get(),M=e.useProgram(d,T),S=m||M.program!==A,E=u.constantOr(null);if(E&&w.imageAtlas){var C=w.imageAtlas.patternPositions[E.to],L=w.imageAtlas.patternPositions[E.from];C&&L&&T.setConstantPatternPositions(C,L)}var P=c?Pr(e,w,n,c,p):h?Lr(e,w,n,p):f?Cr(e,w,n):Er(e,w,n);c&&(S||e.lineAtlas.dirty)?(g.activeTexture.set(v.TEXTURE0),e.lineAtlas.bind(g)):h&&(g.activeTexture.set(v.TEXTURE0),w.imageAtlasTexture.bind(v.LINEAR,v.CLAMP_TO_EDGE),T.updatePatternPaintBuffers(p)),M.draw(g,v.TRIANGLES,s,e.stencilModeForClipping(_),l,St.disabled,P,n.id,k.layoutVertexBuffer,k.indexBuffer,k.segments,n.paint,e.transform.zoom,T),m=!1}}}}}},fill:function(e,r,n,i){var a=n.paint.get(\"fill-color\"),o=n.paint.get(\"fill-opacity\");if(0!==o.constantOr(1)){var s=e.colorModeForRenderPass(),l=n.paint.get(\"fill-pattern\"),c=e.opaquePassEnabledForLayer()&&!l.constantOr(1)&&1===a.constantOr(t.Color.transparent).a&&1===o.constantOr(0)?\"opaque\":\"translucent\";if(e.renderPass===c){var u=e.depthModeForSublayer(1,\"opaque\"===e.renderPass?Tt.ReadWrite:Tt.ReadOnly);Xr(e,r,n,i,u,s,!1)}if(\"translucent\"===e.renderPass&&n.paint.get(\"fill-antialias\")){var h=e.depthModeForSublayer(n.getPaintProperty(\"fill-outline-color\")?2:0,Tt.ReadOnly);Xr(e,r,n,i,h,s,!0)}}},\"fill-extrusion\":function(t,e,r,n){var i=r.paint.get(\"fill-extrusion-opacity\");if(0!==i&&\"translucent\"===t.renderPass){var a=new Tt(t.context.gl.LEQUAL,Tt.ReadWrite,t.depthRangeFor3D);if(1!==i||r.paint.get(\"fill-extrusion-pattern\").constantOr(1))Zr(t,e,r,n,a,At.disabled,Mt.disabled),Zr(t,e,r,n,a,t.stencilModeFor3D(),t.colorModeForRenderPass());else{var o=t.colorModeForRenderPass();Zr(t,e,r,n,a,At.disabled,o)}}},hillshade:function(t,e,r,n){if(\"offscreen\"===t.renderPass||\"translucent\"===t.renderPass){for(var i=t.context,a=e.getSource().maxzoom,o=t.depthModeForSublayer(0,Tt.ReadOnly),s=At.disabled,l=t.colorModeForRenderPass(),c=0,u=n;c<u.length;c+=1){var h=u[c],f=e.getTile(h);f.needsHillshadePrepare&&\"offscreen\"===t.renderPass?Kr(t,f,r,a,o,s,l):\"translucent\"===t.renderPass&&Jr(t,f,r,o,s,l)}i.viewport.set([0,0,t.width,t.height])}},raster:function(t,e,r,n){if(\"translucent\"===t.renderPass&&0!==r.paint.get(\"raster-opacity\"))for(var i=t.context,a=i.gl,o=e.getSource(),s=t.useProgram(\"raster\"),l=At.disabled,c=t.colorModeForRenderPass(),u=n.length&&n[0].overscaledZ,h=!t.options.moving,f=0,p=n;f<p.length;f+=1){var d=p[f],g=t.depthModeForSublayer(d.overscaledZ-u,1===r.paint.get(\"raster-opacity\")?Tt.ReadWrite:Tt.ReadOnly,a.LESS),v=e.getTile(d),m=t.transform.calculatePosMatrix(d.toUnwrapped(),h);v.registerFadeDuration(r.paint.get(\"raster-fade-duration\"));var y=e.findLoadedParent(d,0),x=$r(v,y,e,r,t.transform),b=void 0,_=void 0,w=\"nearest\"===r.paint.get(\"raster-resampling\")?a.NEAREST:a.LINEAR;i.activeTexture.set(a.TEXTURE0),v.texture.bind(w,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),i.activeTexture.set(a.TEXTURE1),y?(y.texture.bind(w,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),b=Math.pow(2,y.tileID.overscaledZ-v.tileID.overscaledZ),_=[v.tileID.canonical.x*b%1,v.tileID.canonical.y*b%1]):v.texture.bind(w,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST);var k=Ir(m,_||[0,0],b||1,x,r);o instanceof L?s.draw(i,a.TRIANGLES,g,l,c,St.disabled,k,r.id,o.boundsBuffer,t.quadTriangleIndexBuffer,o.boundsSegments):v.maskedBoundsBuffer&&v.maskedIndexBuffer&&v.segments?s.draw(i,a.TRIANGLES,g,l,c,St.disabled,k,r.id,v.maskedBoundsBuffer,v.maskedIndexBuffer,v.segments,r.paint,t.transform.zoom):s.draw(i,a.TRIANGLES,g,l,c,St.disabled,k,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}},background:function(t,e,r){var n=r.paint.get(\"background-color\"),i=r.paint.get(\"background-opacity\");if(0!==i){var a=t.context,o=a.gl,s=t.transform,l=s.tileSize,c=r.paint.get(\"background-pattern\");if(!t.isPatternMissing(c)){var u=c||1!==n.a||1!==i?\"translucent\":\"opaque\";if(t.renderPass===u){var h=At.disabled,f=t.depthModeForSublayer(0,\"opaque\"===u?Tt.ReadWrite:Tt.ReadOnly),p=t.colorModeForRenderPass(),d=t.useProgram(c?\"backgroundPattern\":\"background\"),g=s.coveringTiles({tileSize:l});c&&(a.activeTexture.set(o.TEXTURE0),t.imageManager.bind(t.context));for(var v=r.getCrossfadeParameters(),m=0,y=g;m<y.length;m+=1){var x=y[m],b=t.transform.calculatePosMatrix(x.toUnwrapped()),_=c?Br(b,i,t,c,{tileID:x,tileSize:l},v):Fr(b,i,n);d.draw(a,o.TRIANGLES,f,h,p,St.disabled,_,r.id,t.tileExtentBuffer,t.quadTriangleIndexBuffer,t.tileExtentSegments)}}}}},debug:function(t,e,r){for(var n=0;n<r.length;n++)Qr(t,e,r[n])},custom:function(t,e,r){var n=t.context,i=r.implementation;if(\"offscreen\"===t.renderPass){var a=i.prerender;a&&(t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),a.call(i,n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState())}else if(\"translucent\"===t.renderPass){t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),n.setStencilMode(At.disabled);var o=\"3d\"===i.renderingMode?new Tt(t.context.gl.LEQUAL,Tt.ReadWrite,t.depthRangeFor3D):t.depthModeForSublayer(0,Tt.ReadOnly);n.setDepthMode(o),i.render(n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState(),n.bindFramebuffer.set(null)}}},rn=function(e,r){this.context=new Et(e),this.transform=r,this._tileTextures={},this.setup(),this.numSublayers=Ct.maxUnderzooming+Ct.maxOverzooming+1,this.depthEpsilon=1/Math.pow(2,16),this.depthRboNeedsClear=!0,this.emptyProgramConfiguration=new t.ProgramConfiguration,this.crossTileSymbolIndex=new Pe};function nn(t,e){if(t.y>e.y){var r=t;t=e,e=r}return{x0:t.x,y0:t.y,x1:e.x,y1:e.y,dx:e.x-t.x,dy:e.y-t.y}}function an(t,e,r,n,i){var a=Math.max(r,Math.floor(e.y0)),o=Math.min(n,Math.ceil(e.y1));if(t.x0===e.x0&&t.y0===e.y0?t.x0+e.dy/t.dy*t.dx<e.x1:t.x1-e.dy/t.dy*t.dx<e.x0){var s=t;t=e,e=s}for(var l=t.dx/t.dy,c=e.dx/e.dy,u=t.dx>0,h=e.dx<0,f=a;f<o;f++){var p=l*Math.max(0,Math.min(t.dy,f+u-t.y0))+t.x0,d=c*Math.max(0,Math.min(e.dy,f+h-e.y0))+e.x0;i(Math.floor(d),Math.ceil(p),f)}}function on(t,e,r,n,i,a){var o,s=nn(t,e),l=nn(e,r),c=nn(r,t);s.dy>l.dy&&(o=s,s=l,l=o),s.dy>c.dy&&(o=s,s=c,c=o),l.dy>c.dy&&(o=l,l=c,c=o),s.dy&&an(c,s,n,i,a),l.dy&&an(c,l,n,i,a)}rn.prototype.resize=function(e,r){var n=this.context.gl;if(this.width=e*t.browser.devicePixelRatio,this.height=r*t.browser.devicePixelRatio,this.context.viewport.set([0,0,this.width,this.height]),this.style)for(var i=0,a=this.style._order;i<a.length;i+=1){var o=a[i];this.style._layers[o].resize()}this.depthRbo&&(n.deleteRenderbuffer(this.depthRbo),this.depthRbo=null)},rn.prototype.setup=function(){var e=this.context,r=new t.StructArrayLayout2i4;r.emplaceBack(0,0),r.emplaceBack(t.EXTENT,0),r.emplaceBack(0,t.EXTENT),r.emplaceBack(t.EXTENT,t.EXTENT),this.tileExtentBuffer=e.createVertexBuffer(r,Re.members),this.tileExtentSegments=t.SegmentVector.simpleSegment(0,0,4,2);var n=new t.StructArrayLayout2i4;n.emplaceBack(0,0),n.emplaceBack(t.EXTENT,0),n.emplaceBack(0,t.EXTENT),n.emplaceBack(t.EXTENT,t.EXTENT),this.debugBuffer=e.createVertexBuffer(n,Re.members),this.debugSegments=t.SegmentVector.simpleSegment(0,0,4,5);var i=new t.StructArrayLayout4i8;i.emplaceBack(0,0,0,0),i.emplaceBack(t.EXTENT,0,t.EXTENT,0),i.emplaceBack(0,t.EXTENT,0,t.EXTENT),i.emplaceBack(t.EXTENT,t.EXTENT,t.EXTENT,t.EXTENT),this.rasterBoundsBuffer=e.createVertexBuffer(i,t.rasterBoundsAttributes.members),this.rasterBoundsSegments=t.SegmentVector.simpleSegment(0,0,4,2);var a=new t.StructArrayLayout2i4;a.emplaceBack(0,0),a.emplaceBack(1,0),a.emplaceBack(0,1),a.emplaceBack(1,1),this.viewportBuffer=e.createVertexBuffer(a,Re.members),this.viewportSegments=t.SegmentVector.simpleSegment(0,0,4,2);var o=new t.StructArrayLayout1ui2;o.emplaceBack(0),o.emplaceBack(1),o.emplaceBack(3),o.emplaceBack(2),o.emplaceBack(0),this.tileBorderIndexBuffer=e.createIndexBuffer(o);var s=new t.StructArrayLayout3ui6;s.emplaceBack(0,1,2),s.emplaceBack(2,1,3),this.quadTriangleIndexBuffer=e.createIndexBuffer(s);var l=this.context.gl;this.stencilClearMode=new At({func:l.ALWAYS,mask:0},0,255,l.ZERO,l.ZERO,l.ZERO)},rn.prototype.clearStencil=function(){var e=this.context,r=e.gl;this.nextStencilID=1,this.currentStencilSource=void 0;var n=t.create();t.ortho(n,0,this.width,this.height,0,0,1),t.scale(n,n,[r.drawingBufferWidth,r.drawingBufferHeight,0]),this.useProgram(\"clippingMask\").draw(e,r.TRIANGLES,Tt.disabled,this.stencilClearMode,Mt.disabled,St.disabled,kr(n),\"$clipping\",this.viewportBuffer,this.quadTriangleIndexBuffer,this.viewportSegments)},rn.prototype._renderTileClippingMasks=function(t,e){if(this.currentStencilSource!==t.source&&t.isTileClipped()&&e&&e.length){this.currentStencilSource=t.source;var r=this.context,n=r.gl;this.nextStencilID+e.length>256&&this.clearStencil(),r.setColorMode(Mt.disabled),r.setDepthMode(Tt.disabled);var i=this.useProgram(\"clippingMask\");this._tileClippingMaskIDs={};for(var a=0,o=e;a<o.length;a+=1){var s=o[a],l=this._tileClippingMaskIDs[s.key]=this.nextStencilID++;i.draw(r,n.TRIANGLES,Tt.disabled,new At({func:n.ALWAYS,mask:0},l,255,n.KEEP,n.KEEP,n.REPLACE),Mt.disabled,St.disabled,kr(s.posMatrix),\"$clipping\",this.tileExtentBuffer,this.quadTriangleIndexBuffer,this.tileExtentSegments)}}},rn.prototype.stencilModeFor3D=function(){this.nextStencilID+1>256&&this.clearStencil();var t=this.nextStencilID++,e=this.context.gl;return new At({func:e.NOTEQUAL,mask:255},t,255,e.KEEP,e.KEEP,e.REPLACE)},rn.prototype.stencilModeForClipping=function(t){var e=this.context.gl;return new At({func:e.EQUAL,mask:255},this._tileClippingMaskIDs[t.key],0,e.KEEP,e.KEEP,e.REPLACE)},rn.prototype.colorModeForRenderPass=function(){var e=this.context.gl;return this._showOverdrawInspector?new Mt([e.CONSTANT_COLOR,e.ONE],new t.Color(1/8,1/8,1/8,0),[!0,!0,!0,!0]):\"opaque\"===this.renderPass?Mt.unblended:Mt.alphaBlended},rn.prototype.depthModeForSublayer=function(t,e,r){if(!this.opaquePassEnabledForLayer())return Tt.disabled;var n=1-((1+this.currentLayer)*this.numSublayers+t)*this.depthEpsilon;return new Tt(r||this.context.gl.LEQUAL,e,[n,n])},rn.prototype.opaquePassEnabledForLayer=function(){return this.currentLayer<this.opaquePassCutoff},rn.prototype.render=function(e,r){this.style=e,this.options=r,this.lineAtlas=e.lineAtlas,this.imageManager=e.imageManager,this.glyphManager=e.glyphManager,this.symbolFadeChange=e.placement.symbolFadeChange(t.browser.now()),this.imageManager.beginFrame();var n=this.style._order,i=this.style.sourceCaches;for(var a in i){var o=i[a];o.used&&o.prepare(this.context)}var s={},l={},c={};for(var u in i){var h=i[u];s[u]=h.getVisibleCoordinates(),l[u]=s[u].slice().reverse(),c[u]=h.getVisibleCoordinates(!0).reverse()}for(var f in i){var p=i[f],d=p.getSource();if(\"raster\"===d.type||\"raster-dem\"===d.type){for(var g=[],v=0,m=s[f];v<m.length;v+=1){var y=m[v];g.push(p.getTile(y))}jr(g,this.context)}}this.opaquePassCutoff=1/0;for(var x=0;x<n.length;x++){var b=n[x];if(this.style._layers[b].is3D()){this.opaquePassCutoff=x;break}}this.renderPass=\"offscreen\",this.depthRboNeedsClear=!0;for(var _=0,w=n;_<w.length;_+=1){var k=w[_],T=this.style._layers[k];if(T.hasOffscreenPass()&&!T.isHidden(this.transform.zoom)){var A=l[T.source];(\"custom\"===T.type||A.length)&&this.renderLayer(this,i[T.source],T,A)}}for(this.context.bindFramebuffer.set(null),this.context.clear({color:r.showOverdrawInspector?t.Color.black:t.Color.transparent,depth:1}),this.clearStencil(),this._showOverdrawInspector=r.showOverdrawInspector,this.depthRangeFor3D=[0,1-(e._order.length+2)*this.numSublayers*this.depthEpsilon],this.renderPass=\"opaque\",this.currentLayer=n.length-1;this.currentLayer>=0;this.currentLayer--){var M=this.style._layers[n[this.currentLayer]],S=i[M.source],E=s[M.source];this._renderTileClippingMasks(M,E),this.renderLayer(this,S,M,E)}for(this.renderPass=\"translucent\",this.currentLayer=0;this.currentLayer<n.length;this.currentLayer++){var C=this.style._layers[n[this.currentLayer]],L=i[C.source],P=(\"symbol\"===C.type?c:l)[C.source];this._renderTileClippingMasks(C,s[C.source]),this.renderLayer(this,L,C,P)}if(this.options.showTileBoundaries)for(var O in i){en.debug(this,i[O],s[O]);break}this.context.setDefault()},rn.prototype.setupOffscreenDepthRenderbuffer=function(){var t=this.context;this.depthRbo||(this.depthRbo=t.createRenderbuffer(t.gl.DEPTH_COMPONENT16,this.width,this.height))},rn.prototype.renderLayer=function(t,e,r,n){r.isHidden(this.transform.zoom)||(\"background\"===r.type||\"custom\"===r.type||n.length)&&(this.id=r.id,en[r.type](t,e,r,n,this.style.placement.variableOffsets))},rn.prototype.translatePosMatrix=function(e,r,n,i,a){if(!n[0]&&!n[1])return e;var o=a?\"map\"===i?this.transform.angle:0:\"viewport\"===i?-this.transform.angle:0;if(o){var s=Math.sin(o),l=Math.cos(o);n=[n[0]*l-n[1]*s,n[0]*s+n[1]*l]}var c=[a?n[0]:le(r,n[0],this.transform.zoom),a?n[1]:le(r,n[1],this.transform.zoom),0],u=new Float32Array(16);return t.translate(u,e,c),u},rn.prototype.saveTileTexture=function(t){var e=this._tileTextures[t.size[0]];e?e.push(t):this._tileTextures[t.size[0]]=[t]},rn.prototype.getTileTexture=function(t){var e=this._tileTextures[t];return e&&e.length>0?e.pop():null},rn.prototype.isPatternMissing=function(t){if(!t)return!1;var e=this.imageManager.getPattern(t.from),r=this.imageManager.getPattern(t.to);return!e||!r},rn.prototype.useProgram=function(t,e){void 0===e&&(e=this.emptyProgramConfiguration),this.cache=this.cache||{};var r=\"\"+t+(e.cacheKey||\"\")+(this._showOverdrawInspector?\"/overdraw\":\"\");return this.cache[r]||(this.cache[r]=new hr(this.context,cr[t],e,Nr[t],this._showOverdrawInspector)),this.cache[r]},rn.prototype.setCustomLayerDefaults=function(){this.context.unbindVAO(),this.context.cullFace.setDefault(),this.context.activeTexture.setDefault(),this.context.pixelStoreUnpack.setDefault(),this.context.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.context.pixelStoreUnpackFlipY.setDefault()},rn.prototype.setBaseState=function(){var t=this.context.gl;this.context.cullFace.set(!1),this.context.viewport.set([0,0,this.width,this.height]),this.context.blendEquation.set(t.FUNC_ADD)};var sn=function(e,r,n){this.tileSize=512,this.maxValidLatitude=85.051129,this._renderWorldCopies=void 0===n||n,this._minZoom=e||0,this._maxZoom=r||22,this.setMaxBounds(),this.width=0,this.height=0,this._center=new t.LngLat(0,0),this.zoom=0,this.angle=0,this._fov=.6435011087932844,this._pitch=0,this._unmodified=!0,this._posMatrixCache={},this._alignedPosMatrixCache={}},ln={minZoom:{configurable:!0},maxZoom:{configurable:!0},renderWorldCopies:{configurable:!0},worldSize:{configurable:!0},centerPoint:{configurable:!0},size:{configurable:!0},bearing:{configurable:!0},pitch:{configurable:!0},fov:{configurable:!0},zoom:{configurable:!0},center:{configurable:!0},unmodified:{configurable:!0},point:{configurable:!0}};sn.prototype.clone=function(){var t=new sn(this._minZoom,this._maxZoom,this._renderWorldCopies);return t.tileSize=this.tileSize,t.latRange=this.latRange,t.width=this.width,t.height=this.height,t._center=this._center,t.zoom=this.zoom,t.angle=this.angle,t._fov=this._fov,t._pitch=this._pitch,t._unmodified=this._unmodified,t._calcMatrices(),t},ln.minZoom.get=function(){return this._minZoom},ln.minZoom.set=function(t){this._minZoom!==t&&(this._minZoom=t,this.zoom=Math.max(this.zoom,t))},ln.maxZoom.get=function(){return this._maxZoom},ln.maxZoom.set=function(t){this._maxZoom!==t&&(this._maxZoom=t,this.zoom=Math.min(this.zoom,t))},ln.renderWorldCopies.get=function(){return this._renderWorldCopies},ln.renderWorldCopies.set=function(t){void 0===t?t=!0:null===t&&(t=!1),this._renderWorldCopies=t},ln.worldSize.get=function(){return this.tileSize*this.scale},ln.centerPoint.get=function(){return this.size._div(2)},ln.size.get=function(){return new t.Point(this.width,this.height)},ln.bearing.get=function(){return-this.angle/Math.PI*180},ln.bearing.set=function(e){var r=-t.wrap(e,-180,180)*Math.PI/180;this.angle!==r&&(this._unmodified=!1,this.angle=r,this._calcMatrices(),this.rotationMatrix=t.create$2(),t.rotate(this.rotationMatrix,this.rotationMatrix,this.angle))},ln.pitch.get=function(){return this._pitch/Math.PI*180},ln.pitch.set=function(e){var r=t.clamp(e,0,60)/180*Math.PI;this._pitch!==r&&(this._unmodified=!1,this._pitch=r,this._calcMatrices())},ln.fov.get=function(){return this._fov/Math.PI*180},ln.fov.set=function(t){t=Math.max(.01,Math.min(60,t)),this._fov!==t&&(this._unmodified=!1,this._fov=t/180*Math.PI,this._calcMatrices())},ln.zoom.get=function(){return this._zoom},ln.zoom.set=function(t){var e=Math.min(Math.max(t,this.minZoom),this.maxZoom);this._zoom!==e&&(this._unmodified=!1,this._zoom=e,this.scale=this.zoomScale(e),this.tileZoom=Math.floor(e),this.zoomFraction=e-this.tileZoom,this._constrain(),this._calcMatrices())},ln.center.get=function(){return this._center},ln.center.set=function(t){t.lat===this._center.lat&&t.lng===this._center.lng||(this._unmodified=!1,this._center=t,this._constrain(),this._calcMatrices())},sn.prototype.coveringZoomLevel=function(t){return(t.roundZoom?Math.round:Math.floor)(this.zoom+this.scaleZoom(this.tileSize/t.tileSize))},sn.prototype.getVisibleUnwrappedCoordinates=function(e){var r=[new t.UnwrappedTileID(0,e)];if(this._renderWorldCopies)for(var n=this.pointCoordinate(new t.Point(0,0)),i=this.pointCoordinate(new t.Point(this.width,0)),a=this.pointCoordinate(new t.Point(this.width,this.height)),o=this.pointCoordinate(new t.Point(0,this.height)),s=Math.floor(Math.min(n.x,i.x,a.x,o.x)),l=Math.floor(Math.max(n.x,i.x,a.x,o.x)),c=s-1;c<=l+1;c++)0!==c&&r.push(new t.UnwrappedTileID(c,e));return r},sn.prototype.coveringTiles=function(e){var r=this.coveringZoomLevel(e),n=r;if(void 0!==e.minzoom&&r<e.minzoom)return[];void 0!==e.maxzoom&&r>e.maxzoom&&(r=e.maxzoom);var i=t.MercatorCoordinate.fromLngLat(this.center),a=Math.pow(2,r),o=new t.Point(a*i.x-.5,a*i.y-.5);return function(e,r,n,i){void 0===i&&(i=!0);var a=1<<e,o={};function s(r,s,l){var c,u,h,f;if(l>=0&&l<=a)for(c=r;c<s;c++)u=Math.floor(c/a),h=(c%a+a)%a,0!==u&&!0!==i||(f=new t.OverscaledTileID(n,u,e,h,l),o[f.key]=f)}var l=r.map(function(e){return new t.Point(e.x,e.y)._mult(a)});return on(l[0],l[1],l[2],0,a,s),on(l[2],l[3],l[0],0,a,s),Object.keys(o).map(function(t){return o[t]})}(r,[this.pointCoordinate(new t.Point(0,0)),this.pointCoordinate(new t.Point(this.width,0)),this.pointCoordinate(new t.Point(this.width,this.height)),this.pointCoordinate(new t.Point(0,this.height))],e.reparseOverscaled?n:r,this._renderWorldCopies).sort(function(t,e){return o.dist(t.canonical)-o.dist(e.canonical)})},sn.prototype.resize=function(t,e){this.width=t,this.height=e,this.pixelsToGLUnits=[2/t,-2/e],this._constrain(),this._calcMatrices()},ln.unmodified.get=function(){return this._unmodified},sn.prototype.zoomScale=function(t){return Math.pow(2,t)},sn.prototype.scaleZoom=function(t){return Math.log(t)/Math.LN2},sn.prototype.project=function(e){var r=t.clamp(e.lat,-this.maxValidLatitude,this.maxValidLatitude);return new t.Point(t.mercatorXfromLng(e.lng)*this.worldSize,t.mercatorYfromLat(r)*this.worldSize)},sn.prototype.unproject=function(e){return new t.MercatorCoordinate(e.x/this.worldSize,e.y/this.worldSize).toLngLat()},ln.point.get=function(){return this.project(this.center)},sn.prototype.setLocationAtPoint=function(e,r){var n=this.pointCoordinate(r),i=this.pointCoordinate(this.centerPoint),a=this.locationCoordinate(e),o=new t.MercatorCoordinate(a.x-(n.x-i.x),a.y-(n.y-i.y));this.center=this.coordinateLocation(o),this._renderWorldCopies&&(this.center=this.center.wrap())},sn.prototype.locationPoint=function(t){return this.coordinatePoint(this.locationCoordinate(t))},sn.prototype.pointLocation=function(t){return this.coordinateLocation(this.pointCoordinate(t))},sn.prototype.locationCoordinate=function(e){return t.MercatorCoordinate.fromLngLat(e)},sn.prototype.coordinateLocation=function(t){return t.toLngLat()},sn.prototype.pointCoordinate=function(e){var r=[e.x,e.y,0,1],n=[e.x,e.y,1,1];t.transformMat4(r,r,this.pixelMatrixInverse),t.transformMat4(n,n,this.pixelMatrixInverse);var i=r[3],a=n[3],o=r[0]/i,s=n[0]/a,l=r[1]/i,c=n[1]/a,u=r[2]/i,h=n[2]/a,f=u===h?0:(0-u)/(h-u);return new t.MercatorCoordinate(t.number(o,s,f)/this.worldSize,t.number(l,c,f)/this.worldSize)},sn.prototype.coordinatePoint=function(e){var r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix),new t.Point(r[0]/r[3],r[1]/r[3])},sn.prototype.getBounds=function(){return(new t.LngLatBounds).extend(this.pointLocation(new t.Point(0,0))).extend(this.pointLocation(new t.Point(this.width,0))).extend(this.pointLocation(new t.Point(this.width,this.height))).extend(this.pointLocation(new t.Point(0,this.height)))},sn.prototype.getMaxBounds=function(){return this.latRange&&2===this.latRange.length&&this.lngRange&&2===this.lngRange.length?new t.LngLatBounds([this.lngRange[0],this.latRange[0]],[this.lngRange[1],this.latRange[1]]):null},sn.prototype.setMaxBounds=function(t){t?(this.lngRange=[t.getWest(),t.getEast()],this.latRange=[t.getSouth(),t.getNorth()],this._constrain()):(this.lngRange=null,this.latRange=[-this.maxValidLatitude,this.maxValidLatitude])},sn.prototype.calculatePosMatrix=function(e,r){void 0===r&&(r=!1);var n=e.key,i=r?this._alignedPosMatrixCache:this._posMatrixCache;if(i[n])return i[n];var a=e.canonical,o=this.worldSize/this.zoomScale(a.z),s=a.x+Math.pow(2,a.z)*e.wrap,l=t.identity(new Float64Array(16));return t.translate(l,l,[s*o,a.y*o,0]),t.scale(l,l,[o/t.EXTENT,o/t.EXTENT,1]),t.multiply(l,r?this.alignedProjMatrix:this.projMatrix,l),i[n]=new Float32Array(l),i[n]},sn.prototype.customLayerMatrix=function(){return this.mercatorMatrix.slice()},sn.prototype._constrain=function(){if(this.center&&this.width&&this.height&&!this._constraining){this._constraining=!0;var e,r,n,i,a=-90,o=90,s=-180,l=180,c=this.size,u=this._unmodified;if(this.latRange){var h=this.latRange;a=t.mercatorYfromLat(h[1])*this.worldSize,e=(o=t.mercatorYfromLat(h[0])*this.worldSize)-a<c.y?c.y/(o-a):0}if(this.lngRange){var f=this.lngRange;s=t.mercatorXfromLng(f[0])*this.worldSize,r=(l=t.mercatorXfromLng(f[1])*this.worldSize)-s<c.x?c.x/(l-s):0}var p=this.point,d=Math.max(r||0,e||0);if(d)return this.center=this.unproject(new t.Point(r?(l+s)/2:p.x,e?(o+a)/2:p.y)),this.zoom+=this.scaleZoom(d),this._unmodified=u,void(this._constraining=!1);if(this.latRange){var g=p.y,v=c.y/2;g-v<a&&(i=a+v),g+v>o&&(i=o-v)}if(this.lngRange){var m=p.x,y=c.x/2;m-y<s&&(n=s+y),m+y>l&&(n=l-y)}void 0===n&&void 0===i||(this.center=this.unproject(new t.Point(void 0!==n?n:p.x,void 0!==i?i:p.y))),this._unmodified=u,this._constraining=!1}},sn.prototype._calcMatrices=function(){if(this.height){this.cameraToCenterDistance=.5/Math.tan(this._fov/2)*this.height;var e=this._fov/2,r=Math.PI/2+this._pitch,n=Math.sin(e)*this.cameraToCenterDistance/Math.sin(Math.PI-r-e),i=this.point,a=i.x,o=i.y,s=1.01*(Math.cos(Math.PI/2-this._pitch)*n+this.cameraToCenterDistance),l=new Float64Array(16);t.perspective(l,this._fov,this.width/this.height,1,s),t.scale(l,l,[1,-1,1]),t.translate(l,l,[0,0,-this.cameraToCenterDistance]),t.rotateX(l,l,this._pitch),t.rotateZ(l,l,this.angle),t.translate(l,l,[-a,-o,0]),this.mercatorMatrix=t.scale([],l,[this.worldSize,this.worldSize,this.worldSize]),t.scale(l,l,[1,1,t.mercatorZfromAltitude(1,this.center.lat)*this.worldSize,1]),this.projMatrix=l;var c=this.width%2/2,u=this.height%2/2,h=Math.cos(this.angle),f=Math.sin(this.angle),p=a-Math.round(a)+h*c+f*u,d=o-Math.round(o)+h*u+f*c,g=new Float64Array(l);if(t.translate(g,g,[p>.5?p-1:p,d>.5?d-1:d,0]),this.alignedProjMatrix=g,l=t.create(),t.scale(l,l,[this.width/2,-this.height/2,1]),t.translate(l,l,[1,-1,0]),this.labelPlaneMatrix=l,l=t.create(),t.scale(l,l,[1,-1,1]),t.translate(l,l,[-1,-1,0]),t.scale(l,l,[2/this.width,2/this.height,1]),this.glCoordMatrix=l,this.pixelMatrix=t.multiply(new Float64Array(16),this.labelPlaneMatrix,this.projMatrix),!(l=t.invert(new Float64Array(16),this.pixelMatrix)))throw new Error(\"failed to invert matrix\");this.pixelMatrixInverse=l,this._posMatrixCache={},this._alignedPosMatrixCache={}}},sn.prototype.maxPitchScaleFactor=function(){if(!this.pixelMatrixInverse)return 1;var e=this.pointCoordinate(new t.Point(0,0)),r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix)[3]/this.cameraToCenterDistance},sn.prototype.getCameraPoint=function(){var e=this._pitch,r=Math.tan(e)*(this.cameraToCenterDistance||1);return this.centerPoint.add(new t.Point(0,r))},sn.prototype.getCameraQueryGeometry=function(e){var r=this.getCameraPoint();if(1===e.length)return[e[0],r];for(var n=r.x,i=r.y,a=r.x,o=r.y,s=0,l=e;s<l.length;s+=1){var c=l[s];n=Math.min(n,c.x),i=Math.min(i,c.y),a=Math.max(a,c.x),o=Math.max(o,c.y)}return[new t.Point(n,i),new t.Point(a,i),new t.Point(a,o),new t.Point(n,o),new t.Point(n,i)]},Object.defineProperties(sn.prototype,ln);var cn=function(){var e,r,n,i;t.bindAll([\"_onHashChange\",\"_updateHash\"],this),this._updateHash=(e=this._updateHashUnthrottled.bind(this),300,r=!1,n=null,i=function(){n=null,r&&(e(),n=setTimeout(i,300),r=!1)},function(){return r=!0,n||i(),n})};cn.prototype.addTo=function(e){return this._map=e,t.window.addEventListener(\"hashchange\",this._onHashChange,!1),this._map.on(\"moveend\",this._updateHash),this},cn.prototype.remove=function(){return t.window.removeEventListener(\"hashchange\",this._onHashChange,!1),this._map.off(\"moveend\",this._updateHash),clearTimeout(this._updateHash()),delete this._map,this},cn.prototype.getHashString=function(t){var e=this._map.getCenter(),r=Math.round(100*this._map.getZoom())/100,n=Math.ceil((r*Math.LN2+Math.log(512/360/.5))/Math.LN10),i=Math.pow(10,n),a=Math.round(e.lng*i)/i,o=Math.round(e.lat*i)/i,s=this._map.getBearing(),l=this._map.getPitch(),c=\"\";return c+=t?\"#/\"+a+\"/\"+o+\"/\"+r:\"#\"+r+\"/\"+o+\"/\"+a,(s||l)&&(c+=\"/\"+Math.round(10*s)/10),l&&(c+=\"/\"+Math.round(l)),c},cn.prototype._onHashChange=function(){var e=t.window.location.hash.replace(\"#\",\"\").split(\"/\");return e.length>=3&&(this._map.jumpTo({center:[+e[2],+e[1]],zoom:+e[0],bearing:+(e[3]||0),pitch:+(e[4]||0)}),!0)},cn.prototype._updateHashUnthrottled=function(){var e=this.getHashString();try{t.window.history.replaceState(t.window.history.state,\"\",e)}catch(t){}};var un=function(e){function n(n,i,a,o){void 0===o&&(o={});var s=r.mousePos(i.getCanvasContainer(),a),l=i.unproject(s);e.call(this,n,t.extend({point:s,lngLat:l,originalEvent:a},o)),this._defaultPrevented=!1,this.target=i}e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),hn=function(e){function n(n,i,a){var o=r.touchPos(i.getCanvasContainer(),a),s=o.map(function(t){return i.unproject(t)}),l=o.reduce(function(t,e,r,n){return t.add(e.div(n.length))},new t.Point(0,0)),c=i.unproject(l);e.call(this,n,{points:o,point:l,lngLats:s,lngLat:c,originalEvent:a}),this._defaultPrevented=!1}e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),fn=function(t){function e(e,r,n){t.call(this,e,{originalEvent:n}),this._defaultPrevented=!1}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={defaultPrevented:{configurable:!0}};return e.prototype.preventDefault=function(){this._defaultPrevented=!0},r.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(e.prototype,r),e}(t.Event),pn=function(e){this._map=e,this._el=e.getCanvasContainer(),this._delta=0,this._defaultZoomRate=.01,this._wheelZoomRate=1/450,t.bindAll([\"_onWheel\",\"_onTimeout\",\"_onScrollFrame\",\"_onScrollFinished\"],this)};pn.prototype.setZoomRate=function(t){this._defaultZoomRate=t},pn.prototype.setWheelZoomRate=function(t){this._wheelZoomRate=t},pn.prototype.isEnabled=function(){return!!this._enabled},pn.prototype.isActive=function(){return!!this._active},pn.prototype.isZooming=function(){return!!this._zooming},pn.prototype.enable=function(t){this.isEnabled()||(this._enabled=!0,this._aroundCenter=t&&\"center\"===t.around)},pn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},pn.prototype.onWheel=function(e){if(this.isEnabled()){var r=e.deltaMode===t.window.WheelEvent.DOM_DELTA_LINE?40*e.deltaY:e.deltaY,n=t.browser.now(),i=n-(this._lastWheelEventTime||0);this._lastWheelEventTime=n,0!==r&&r%4.000244140625==0?this._type=\"wheel\":0!==r&&Math.abs(r)<4?this._type=\"trackpad\":i>400?(this._type=null,this._lastValue=r,this._timeout=setTimeout(this._onTimeout,40,e)):this._type||(this._type=Math.abs(i*r)<200?\"trackpad\":\"wheel\",this._timeout&&(clearTimeout(this._timeout),this._timeout=null,r+=this._lastValue)),e.shiftKey&&r&&(r/=4),this._type&&(this._lastWheelEvent=e,this._delta-=r,this.isActive()||this._start(e)),e.preventDefault()}},pn.prototype._onTimeout=function(t){this._type=\"wheel\",this._delta-=this._lastValue,this.isActive()||this._start(t)},pn.prototype._start=function(e){if(this._delta){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),this._active=!0,this.isZooming()||(this._zooming=!0,this._map.fire(new t.Event(\"movestart\",{originalEvent:e})),this._map.fire(new t.Event(\"zoomstart\",{originalEvent:e}))),this._finishTimeout&&clearTimeout(this._finishTimeout);var n=r.mousePos(this._el,e);this._around=t.LngLat.convert(this._aroundCenter?this._map.getCenter():this._map.unproject(n)),this._aroundPoint=this._map.transform.locationPoint(this._around),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onScrollFrame))}},pn.prototype._onScrollFrame=function(){var e=this;if(this._frameId=null,this.isActive()){var r=this._map.transform;if(0!==this._delta){var n=\"wheel\"===this._type&&Math.abs(this._delta)>4.000244140625?this._wheelZoomRate:this._defaultZoomRate,i=2/(1+Math.exp(-Math.abs(this._delta*n)));this._delta<0&&0!==i&&(i=1/i);var a=\"number\"==typeof this._targetZoom?r.zoomScale(this._targetZoom):r.scale;this._targetZoom=Math.min(r.maxZoom,Math.max(r.minZoom,r.scaleZoom(a*i))),\"wheel\"===this._type&&(this._startZoom=r.zoom,this._easing=this._smoothOutEasing(200)),this._delta=0}var o=\"number\"==typeof this._targetZoom?this._targetZoom:r.zoom,s=this._startZoom,l=this._easing,c=!1;if(\"wheel\"===this._type&&s&&l){var u=Math.min((t.browser.now()-this._lastWheelEventTime)/200,1),h=l(u);r.zoom=t.number(s,o,h),u<1?this._frameId||(this._frameId=this._map._requestRenderFrame(this._onScrollFrame)):c=!0}else r.zoom=o,c=!0;r.setLocationAtPoint(this._around,this._aroundPoint),this._map.fire(new t.Event(\"move\",{originalEvent:this._lastWheelEvent})),this._map.fire(new t.Event(\"zoom\",{originalEvent:this._lastWheelEvent})),c&&(this._active=!1,this._finishTimeout=setTimeout(function(){e._zooming=!1,e._map.fire(new t.Event(\"zoomend\",{originalEvent:e._lastWheelEvent})),e._map.fire(new t.Event(\"moveend\",{originalEvent:e._lastWheelEvent})),delete e._targetZoom},200))}},pn.prototype._smoothOutEasing=function(e){var r=t.ease;if(this._prevEase){var n=this._prevEase,i=(t.browser.now()-n.start)/n.duration,a=n.easing(i+.01)-n.easing(i),o=.27/Math.sqrt(a*a+1e-4)*.01,s=Math.sqrt(.0729-o*o);r=t.bezier(o,s,.25,1)}return this._prevEase={start:t.browser.now(),duration:e,easing:r},r};var dn=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._container=e.getContainer(),this._clickTolerance=r.clickTolerance||1,t.bindAll([\"_onMouseMove\",\"_onMouseUp\",\"_onKeyDown\"],this)};dn.prototype.isEnabled=function(){return!!this._enabled},dn.prototype.isActive=function(){return!!this._active},dn.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},dn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},dn.prototype.onMouseDown=function(e){this.isEnabled()&&e.shiftKey&&0===e.button&&(t.window.document.addEventListener(\"mousemove\",this._onMouseMove,!1),t.window.document.addEventListener(\"keydown\",this._onKeyDown,!1),t.window.document.addEventListener(\"mouseup\",this._onMouseUp,!1),r.disableDrag(),this._startPos=this._lastPos=r.mousePos(this._el,e),this._active=!0)},dn.prototype._onMouseMove=function(t){var e=r.mousePos(this._el,t);if(!(this._lastPos.equals(e)||!this._box&&e.dist(this._startPos)<this._clickTolerance)){var n=this._startPos;this._lastPos=e,this._box||(this._box=r.create(\"div\",\"mapboxgl-boxzoom\",this._container),this._container.classList.add(\"mapboxgl-crosshair\"),this._fireEvent(\"boxzoomstart\",t));var i=Math.min(n.x,e.x),a=Math.max(n.x,e.x),o=Math.min(n.y,e.y),s=Math.max(n.y,e.y);r.setTransform(this._box,\"translate(\"+i+\"px,\"+o+\"px)\"),this._box.style.width=a-i+\"px\",this._box.style.height=s-o+\"px\"}},dn.prototype._onMouseUp=function(e){if(0===e.button){var n=this._startPos,i=r.mousePos(this._el,e);this._finish(),r.suppressClick(),n.x===i.x&&n.y===i.y?this._fireEvent(\"boxzoomcancel\",e):this._map.fitScreenCoordinates(n,i,this._map.getBearing(),{linear:!0}).fire(new t.Event(\"boxzoomend\",{originalEvent:e}))}},dn.prototype._onKeyDown=function(t){27===t.keyCode&&(this._finish(),this._fireEvent(\"boxzoomcancel\",t))},dn.prototype._finish=function(){this._active=!1,t.window.document.removeEventListener(\"mousemove\",this._onMouseMove,!1),t.window.document.removeEventListener(\"keydown\",this._onKeyDown,!1),t.window.document.removeEventListener(\"mouseup\",this._onMouseUp,!1),this._container.classList.remove(\"mapboxgl-crosshair\"),this._box&&(r.remove(this._box),this._box=null),r.enableDrag(),delete this._startPos,delete this._lastPos},dn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,{originalEvent:r}))};var gn=t.bezier(0,0,.25,1),vn=function(e,r){this._map=e,this._el=r.element||e.getCanvasContainer(),this._state=\"disabled\",this._button=r.button||\"right\",this._bearingSnap=r.bearingSnap||0,this._pitchWithRotate=!1!==r.pitchWithRotate,t.bindAll([\"onMouseDown\",\"_onMouseMove\",\"_onMouseUp\",\"_onBlur\",\"_onDragFrame\"],this)};vn.prototype.isEnabled=function(){return\"disabled\"!==this._state},vn.prototype.isActive=function(){return\"active\"===this._state},vn.prototype.enable=function(){this.isEnabled()||(this._state=\"enabled\")},vn.prototype.disable=function(){if(this.isEnabled())switch(this._state){case\"active\":this._state=\"disabled\",this._unbind(),this._deactivate(),this._fireEvent(\"rotateend\"),this._pitchWithRotate&&this._fireEvent(\"pitchend\"),this._fireEvent(\"moveend\");break;case\"pending\":this._state=\"disabled\",this._unbind();break;default:this._state=\"disabled\"}},vn.prototype.onMouseDown=function(e){if(\"enabled\"===this._state){if(\"right\"===this._button){if(this._eventButton=r.mouseButton(e),this._eventButton!==(e.ctrlKey?0:2))return}else{if(e.ctrlKey||0!==r.mouseButton(e))return;this._eventButton=0}r.disableDrag(),t.window.document.addEventListener(\"mousemove\",this._onMouseMove,{capture:!0}),t.window.document.addEventListener(\"mouseup\",this._onMouseUp),t.window.addEventListener(\"blur\",this._onBlur),this._state=\"pending\",this._inertia=[[t.browser.now(),this._map.getBearing()]],this._startPos=this._lastPos=r.mousePos(this._el,e),this._center=this._map.transform.centerPoint,e.preventDefault()}},vn.prototype._onMouseMove=function(t){var e=r.mousePos(this._el,t);this._lastPos.equals(e)||(this._lastMoveEvent=t,this._lastPos=e,\"pending\"===this._state&&(this._state=\"active\",this._fireEvent(\"rotatestart\",t),this._fireEvent(\"movestart\",t),this._pitchWithRotate&&this._fireEvent(\"pitchstart\",t)),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onDragFrame)))},vn.prototype._onDragFrame=function(){this._frameId=null;var e=this._lastMoveEvent;if(e){var r=this._map.transform,n=this._startPos,i=this._lastPos,a=.8*(n.x-i.x),o=-.5*(n.y-i.y),s=r.bearing-a,l=r.pitch-o,c=this._inertia,u=c[c.length-1];this._drainInertiaBuffer(),c.push([t.browser.now(),this._map._normalizeBearing(s,u[1])]),r.bearing=s,this._pitchWithRotate&&(this._fireEvent(\"pitch\",e),r.pitch=l),this._fireEvent(\"rotate\",e),this._fireEvent(\"move\",e),delete this._lastMoveEvent,this._startPos=this._lastPos}},vn.prototype._onMouseUp=function(t){if(r.mouseButton(t)===this._eventButton)switch(this._state){case\"active\":this._state=\"enabled\",r.suppressClick(),this._unbind(),this._deactivate(),this._inertialRotate(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},vn.prototype._onBlur=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._fireEvent(\"rotateend\",t),this._pitchWithRotate&&this._fireEvent(\"pitchend\",t),this._fireEvent(\"moveend\",t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},vn.prototype._unbind=function(){t.window.document.removeEventListener(\"mousemove\",this._onMouseMove,{capture:!0}),t.window.document.removeEventListener(\"mouseup\",this._onMouseUp),t.window.removeEventListener(\"blur\",this._onBlur),r.enableDrag()},vn.prototype._deactivate=function(){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._lastMoveEvent,delete this._startPos,delete this._lastPos},vn.prototype._inertialRotate=function(t){var e=this;this._fireEvent(\"rotateend\",t),this._drainInertiaBuffer();var r=this._map,n=r.getBearing(),i=this._inertia,a=function(){Math.abs(n)<e._bearingSnap?r.resetNorth({noMoveStart:!0},{originalEvent:t}):e._fireEvent(\"moveend\",t),e._pitchWithRotate&&e._fireEvent(\"pitchend\",t)};if(i.length<2)a();else{var o=i[0],s=i[i.length-1],l=i[i.length-2],c=r._normalizeBearing(n,l[1]),u=s[1]-o[1],h=u<0?-1:1,f=(s[0]-o[0])/1e3;if(0!==u&&0!==f){var p=Math.abs(u*(.25/f));p>180&&(p=180);var d=p/180;c+=h*p*(d/2),Math.abs(r._normalizeBearing(c,0))<this._bearingSnap&&(c=r._normalizeBearing(0,c)),r.rotateTo(c,{duration:1e3*d,easing:gn,noMoveStart:!0},{originalEvent:t})}else a()}},vn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},vn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>0&&r-e[0][0]>160;)e.shift()};var mn=t.bezier(0,0,.3,1),yn=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._state=\"disabled\",this._clickTolerance=r.clickTolerance||1,t.bindAll([\"_onMove\",\"_onMouseUp\",\"_onTouchEnd\",\"_onBlur\",\"_onDragFrame\"],this)};yn.prototype.isEnabled=function(){return\"disabled\"!==this._state},yn.prototype.isActive=function(){return\"active\"===this._state},yn.prototype.enable=function(){this.isEnabled()||(this._el.classList.add(\"mapboxgl-touch-drag-pan\"),this._state=\"enabled\")},yn.prototype.disable=function(){if(this.isEnabled())switch(this._el.classList.remove(\"mapboxgl-touch-drag-pan\"),this._state){case\"active\":this._state=\"disabled\",this._unbind(),this._deactivate(),this._fireEvent(\"dragend\"),this._fireEvent(\"moveend\");break;case\"pending\":this._state=\"disabled\",this._unbind();break;default:this._state=\"disabled\"}},yn.prototype.onMouseDown=function(e){\"enabled\"===this._state&&(e.ctrlKey||0!==r.mouseButton(e)||(r.addEventListener(t.window.document,\"mousemove\",this._onMove,{capture:!0}),r.addEventListener(t.window.document,\"mouseup\",this._onMouseUp),this._start(e)))},yn.prototype.onTouchStart=function(e){\"enabled\"===this._state&&(e.touches.length>1||(r.addEventListener(t.window.document,\"touchmove\",this._onMove,{capture:!0,passive:!1}),r.addEventListener(t.window.document,\"touchend\",this._onTouchEnd),this._start(e)))},yn.prototype._start=function(e){t.window.addEventListener(\"blur\",this._onBlur),this._state=\"pending\",this._startPos=this._mouseDownPos=this._lastPos=r.mousePos(this._el,e),this._inertia=[[t.browser.now(),this._startPos]]},yn.prototype._onMove=function(e){e.preventDefault();var n=r.mousePos(this._el,e);this._lastPos.equals(n)||\"pending\"===this._state&&n.dist(this._mouseDownPos)<this._clickTolerance||(this._lastMoveEvent=e,this._lastPos=n,this._drainInertiaBuffer(),this._inertia.push([t.browser.now(),this._lastPos]),\"pending\"===this._state&&(this._state=\"active\",this._fireEvent(\"dragstart\",e),this._fireEvent(\"movestart\",e)),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onDragFrame)))},yn.prototype._onDragFrame=function(){this._frameId=null;var t=this._lastMoveEvent;if(t){var e=this._map.transform;e.setLocationAtPoint(e.pointLocation(this._startPos),this._lastPos),this._fireEvent(\"drag\",t),this._fireEvent(\"move\",t),this._startPos=this._lastPos,delete this._lastMoveEvent}},yn.prototype._onMouseUp=function(t){if(0===r.mouseButton(t))switch(this._state){case\"active\":this._state=\"enabled\",r.suppressClick(),this._unbind(),this._deactivate(),this._inertialPan(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},yn.prototype._onTouchEnd=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._inertialPan(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},yn.prototype._onBlur=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._fireEvent(\"dragend\",t),this._fireEvent(\"moveend\",t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},yn.prototype._unbind=function(){r.removeEventListener(t.window.document,\"touchmove\",this._onMove,{capture:!0,passive:!1}),r.removeEventListener(t.window.document,\"touchend\",this._onTouchEnd),r.removeEventListener(t.window.document,\"mousemove\",this._onMove,{capture:!0}),r.removeEventListener(t.window.document,\"mouseup\",this._onMouseUp),r.removeEventListener(t.window,\"blur\",this._onBlur)},yn.prototype._deactivate=function(){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._lastMoveEvent,delete this._startPos,delete this._mouseDownPos,delete this._lastPos},yn.prototype._inertialPan=function(t){this._fireEvent(\"dragend\",t),this._drainInertiaBuffer();var e=this._inertia;if(e.length<2)this._fireEvent(\"moveend\",t);else{var r=e[e.length-1],n=e[0],i=r[1].sub(n[1]),a=(r[0]-n[0])/1e3;if(0===a||r[1].equals(n[1]))this._fireEvent(\"moveend\",t);else{var o=i.mult(.3/a),s=o.mag();s>1400&&(s=1400,o._unit()._mult(s));var l=s/750,c=o.mult(-l/2);this._map.panBy(c,{duration:1e3*l,easing:mn,noMoveStart:!0},{originalEvent:t})}}},yn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},yn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>0&&r-e[0][0]>160;)e.shift()};var xn=function(e){this._map=e,this._el=e.getCanvasContainer(),t.bindAll([\"_onKeyDown\"],this)};function bn(t){return t*(2-t)}xn.prototype.isEnabled=function(){return!!this._enabled},xn.prototype.enable=function(){this.isEnabled()||(this._el.addEventListener(\"keydown\",this._onKeyDown,!1),this._enabled=!0)},xn.prototype.disable=function(){this.isEnabled()&&(this._el.removeEventListener(\"keydown\",this._onKeyDown),this._enabled=!1)},xn.prototype._onKeyDown=function(t){if(!(t.altKey||t.ctrlKey||t.metaKey)){var e=0,r=0,n=0,i=0,a=0;switch(t.keyCode){case 61:case 107:case 171:case 187:e=1;break;case 189:case 109:case 173:e=-1;break;case 37:t.shiftKey?r=-1:(t.preventDefault(),i=-1);break;case 39:t.shiftKey?r=1:(t.preventDefault(),i=1);break;case 38:t.shiftKey?n=1:(t.preventDefault(),a=-1);break;case 40:t.shiftKey?n=-1:(a=1,t.preventDefault());break;default:return}var o=this._map,s=o.getZoom(),l={duration:300,delayEndEvents:500,easing:bn,zoom:e?Math.round(s)+e*(t.shiftKey?2:1):s,bearing:o.getBearing()+15*r,pitch:o.getPitch()+10*n,offset:[100*-i,100*-a],center:o.getCenter()};o.easeTo(l,{originalEvent:t})}};var _n=function(e){this._map=e,t.bindAll([\"_onDblClick\",\"_onZoomEnd\"],this)};_n.prototype.isEnabled=function(){return!!this._enabled},_n.prototype.isActive=function(){return!!this._active},_n.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},_n.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},_n.prototype.onTouchStart=function(t){var e=this;if(this.isEnabled()&&!(t.points.length>1))if(this._tapped){var r=t.points[0],n=this._tappedPoint;if(n&&n.dist(r)<=30){t.originalEvent.preventDefault();var i=function(){e._tapped&&e._zoom(t),e._map.off(\"touchcancel\",a),e._resetTapped()},a=function(){e._map.off(\"touchend\",i),e._resetTapped()};this._map.once(\"touchend\",i),this._map.once(\"touchcancel\",a)}else this._resetTapped()}else this._tappedPoint=t.points[0],this._tapped=setTimeout(function(){e._tapped=null,e._tappedPoint=null},300)},_n.prototype._resetTapped=function(){clearTimeout(this._tapped),this._tapped=null,this._tappedPoint=null},_n.prototype.onDblClick=function(t){this.isEnabled()&&(t.originalEvent.preventDefault(),this._zoom(t))},_n.prototype._zoom=function(t){this._active=!0,this._map.on(\"zoomend\",this._onZoomEnd),this._map.zoomTo(this._map.getZoom()+(t.originalEvent.shiftKey?-1:1),{around:t.lngLat},t)},_n.prototype._onZoomEnd=function(){this._active=!1,this._map.off(\"zoomend\",this._onZoomEnd)};var wn=t.bezier(0,0,.15,1),kn=function(e){this._map=e,this._el=e.getCanvasContainer(),t.bindAll([\"_onMove\",\"_onEnd\",\"_onTouchFrame\"],this)};kn.prototype.isEnabled=function(){return!!this._enabled},kn.prototype.enable=function(t){this.isEnabled()||(this._el.classList.add(\"mapboxgl-touch-zoom-rotate\"),this._enabled=!0,this._aroundCenter=!!t&&\"center\"===t.around)},kn.prototype.disable=function(){this.isEnabled()&&(this._el.classList.remove(\"mapboxgl-touch-zoom-rotate\"),this._enabled=!1)},kn.prototype.disableRotation=function(){this._rotationDisabled=!0},kn.prototype.enableRotation=function(){this._rotationDisabled=!1},kn.prototype.onStart=function(e){if(this.isEnabled()&&2===e.touches.length){var n=r.mousePos(this._el,e.touches[0]),i=r.mousePos(this._el,e.touches[1]),a=n.add(i).div(2);this._startVec=n.sub(i),this._startAround=this._map.transform.pointLocation(a),this._gestureIntent=void 0,this._inertia=[],r.addEventListener(t.window.document,\"touchmove\",this._onMove,{passive:!1}),r.addEventListener(t.window.document,\"touchend\",this._onEnd)}},kn.prototype._getTouchEventData=function(t){var e=r.mousePos(this._el,t.touches[0]),n=r.mousePos(this._el,t.touches[1]),i=e.sub(n);return{vec:i,center:e.add(n).div(2),scale:i.mag()/this._startVec.mag(),bearing:this._rotationDisabled?0:180*i.angleWith(this._startVec)/Math.PI}},kn.prototype._onMove=function(e){if(2===e.touches.length){var r=this._getTouchEventData(e),n=r.vec,i=r.scale,a=r.bearing;if(!this._gestureIntent){var o=this._rotationDisabled&&1!==i||Math.abs(1-i)>.15;Math.abs(a)>10?this._gestureIntent=\"rotate\":o&&(this._gestureIntent=\"zoom\"),this._gestureIntent&&(this._map.fire(new t.Event(this._gestureIntent+\"start\",{originalEvent:e})),this._map.fire(new t.Event(\"movestart\",{originalEvent:e})),this._startVec=n)}this._lastTouchEvent=e,this._frameId||(this._frameId=this._map._requestRenderFrame(this._onTouchFrame)),e.preventDefault()}},kn.prototype._onTouchFrame=function(){this._frameId=null;var e=this._gestureIntent;if(e){var r=this._map.transform;this._startScale||(this._startScale=r.scale,this._startBearing=r.bearing);var n=this._getTouchEventData(this._lastTouchEvent),i=n.center,a=n.bearing,o=n.scale,s=r.pointLocation(i),l=r.locationPoint(s);\"rotate\"===e&&(r.bearing=this._startBearing+a),r.zoom=r.scaleZoom(this._startScale*o),r.setLocationAtPoint(this._startAround,l),this._map.fire(new t.Event(e,{originalEvent:this._lastTouchEvent})),this._map.fire(new t.Event(\"move\",{originalEvent:this._lastTouchEvent})),this._drainInertiaBuffer(),this._inertia.push([t.browser.now(),o,i])}},kn.prototype._onEnd=function(e){r.removeEventListener(t.window.document,\"touchmove\",this._onMove,{passive:!1}),r.removeEventListener(t.window.document,\"touchend\",this._onEnd);var n=this._gestureIntent,i=this._startScale;if(this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._gestureIntent,delete this._startScale,delete this._startBearing,delete this._lastTouchEvent,n){this._map.fire(new t.Event(n+\"end\",{originalEvent:e})),this._drainInertiaBuffer();var a=this._inertia,o=this._map;if(a.length<2)o.snapToNorth({},{originalEvent:e});else{var s=a[a.length-1],l=a[0],c=o.transform.scaleZoom(i*s[1]),u=o.transform.scaleZoom(i*l[1]),h=c-u,f=(s[0]-l[0])/1e3,p=s[2];if(0!==f&&c!==u){var d=.15*h/f;Math.abs(d)>2.5&&(d=d>0?2.5:-2.5);var g=1e3*Math.abs(d/(12*.15)),v=c+d*g/2e3;v<0&&(v=0),o.easeTo({zoom:v,duration:g,easing:wn,around:this._aroundCenter?o.getCenter():o.unproject(p),noMoveStart:!0},{originalEvent:e})}else o.snapToNorth({},{originalEvent:e})}}},kn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>2&&r-e[0][0]>160;)e.shift()};var Tn={scrollZoom:pn,boxZoom:dn,dragRotate:vn,dragPan:yn,keyboard:xn,doubleClickZoom:_n,touchZoomRotate:kn},An=function(e){function r(r,n){e.call(this),this._moving=!1,this._zooming=!1,this.transform=r,this._bearingSnap=n.bearingSnap,t.bindAll([\"_renderFrameCallback\"],this)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getCenter=function(){return new t.LngLat(this.transform.center.lng,this.transform.center.lat)},r.prototype.setCenter=function(t,e){return this.jumpTo({center:t},e)},r.prototype.panBy=function(e,r,n){return e=t.Point.convert(e).mult(-1),this.panTo(this.transform.center,t.extend({offset:e},r),n)},r.prototype.panTo=function(e,r,n){return this.easeTo(t.extend({center:e},r),n)},r.prototype.getZoom=function(){return this.transform.zoom},r.prototype.setZoom=function(t,e){return this.jumpTo({zoom:t},e),this},r.prototype.zoomTo=function(e,r,n){return this.easeTo(t.extend({zoom:e},r),n)},r.prototype.zoomIn=function(t,e){return this.zoomTo(this.getZoom()+1,t,e),this},r.prototype.zoomOut=function(t,e){return this.zoomTo(this.getZoom()-1,t,e),this},r.prototype.getBearing=function(){return this.transform.bearing},r.prototype.setBearing=function(t,e){return this.jumpTo({bearing:t},e),this},r.prototype.rotateTo=function(e,r,n){return this.easeTo(t.extend({bearing:e},r),n)},r.prototype.resetNorth=function(e,r){return this.rotateTo(0,t.extend({duration:1e3},e),r),this},r.prototype.snapToNorth=function(t,e){return Math.abs(this.getBearing())<this._bearingSnap?this.resetNorth(t,e):this},r.prototype.getPitch=function(){return this.transform.pitch},r.prototype.setPitch=function(t,e){return this.jumpTo({pitch:t},e),this},r.prototype.cameraForBounds=function(e,r){return e=t.LngLatBounds.convert(e),this._cameraForBoxAndBearing(e.getNorthWest(),e.getSouthEast(),0,r)},r.prototype._cameraForBoxAndBearing=function(e,r,n,i){if(\"number\"==typeof(i=t.extend({padding:{top:0,bottom:0,right:0,left:0},offset:[0,0],maxZoom:this.transform.maxZoom},i)).padding){var a=i.padding;i.padding={top:a,bottom:a,right:a,left:a}}if(t.deepEqual(Object.keys(i.padding).sort(function(t,e){return t<e?-1:t>e?1:0}),[\"bottom\",\"left\",\"right\",\"top\"])){var o=this.transform,s=o.project(t.LngLat.convert(e)),l=o.project(t.LngLat.convert(r)),c=s.rotate(-n*Math.PI/180),u=l.rotate(-n*Math.PI/180),h=new t.Point(Math.max(c.x,u.x),Math.max(c.y,u.y)),f=new t.Point(Math.min(c.x,u.x),Math.min(c.y,u.y)),p=h.sub(f),d=(o.width-i.padding.left-i.padding.right)/p.x,g=(o.height-i.padding.top-i.padding.bottom)/p.y;if(!(g<0||d<0)){var v=Math.min(o.scaleZoom(o.scale*Math.min(d,g)),i.maxZoom),m=t.Point.convert(i.offset),y=(i.padding.left-i.padding.right)/2,x=(i.padding.top-i.padding.bottom)/2,b=new t.Point(m.x+y,m.y+x).mult(o.scale/o.zoomScale(v));return{center:o.unproject(s.add(l).div(2).sub(b)),zoom:v,bearing:n}}t.warnOnce(\"Map cannot fit within canvas with the given bounds, padding, and/or offset.\")}else t.warnOnce(\"options.padding must be a positive number, or an Object with keys 'bottom', 'left', 'right', 'top'\")},r.prototype.fitBounds=function(t,e,r){return this._fitInternal(this.cameraForBounds(t,e),e,r)},r.prototype.fitScreenCoordinates=function(e,r,n,i,a){return this._fitInternal(this._cameraForBoxAndBearing(this.transform.pointLocation(t.Point.convert(e)),this.transform.pointLocation(t.Point.convert(r)),n,i),i,a)},r.prototype._fitInternal=function(e,r,n){return e?(r=t.extend(e,r)).linear?this.easeTo(r,n):this.flyTo(r,n):this},r.prototype.jumpTo=function(e,r){this.stop();var n=this.transform,i=!1,a=!1,o=!1;return\"zoom\"in e&&n.zoom!==+e.zoom&&(i=!0,n.zoom=+e.zoom),void 0!==e.center&&(n.center=t.LngLat.convert(e.center)),\"bearing\"in e&&n.bearing!==+e.bearing&&(a=!0,n.bearing=+e.bearing),\"pitch\"in e&&n.pitch!==+e.pitch&&(o=!0,n.pitch=+e.pitch),this.fire(new t.Event(\"movestart\",r)).fire(new t.Event(\"move\",r)),i&&this.fire(new t.Event(\"zoomstart\",r)).fire(new t.Event(\"zoom\",r)).fire(new t.Event(\"zoomend\",r)),a&&this.fire(new t.Event(\"rotatestart\",r)).fire(new t.Event(\"rotate\",r)).fire(new t.Event(\"rotateend\",r)),o&&this.fire(new t.Event(\"pitchstart\",r)).fire(new t.Event(\"pitch\",r)).fire(new t.Event(\"pitchend\",r)),this.fire(new t.Event(\"moveend\",r))},r.prototype.easeTo=function(e,r){var n=this;this.stop(),!1===(e=t.extend({offset:[0,0],duration:500,easing:t.ease},e)).animate&&(e.duration=0);var i=this.transform,a=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=\"zoom\"in e?+e.zoom:a,c=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,u=\"pitch\"in e?+e.pitch:s,h=i.centerPoint.add(t.Point.convert(e.offset)),f=i.pointLocation(h),p=t.LngLat.convert(e.center||f);this._normalizeCenter(p);var d,g,v=i.project(f),m=i.project(p).sub(v),y=i.zoomScale(l-a);return e.around&&(d=t.LngLat.convert(e.around),g=i.locationPoint(d)),this._zooming=l!==a,this._rotating=o!==c,this._pitching=u!==s,this._prepareEase(r,e.noMoveStart),clearTimeout(this._easeEndTimeoutID),this._ease(function(e){if(n._zooming&&(i.zoom=t.number(a,l,e)),n._rotating&&(i.bearing=t.number(o,c,e)),n._pitching&&(i.pitch=t.number(s,u,e)),d)i.setLocationAtPoint(d,g);else{var f=i.zoomScale(i.zoom-a),p=l>a?Math.min(2,y):Math.max(.5,y),x=Math.pow(p,1-e),b=i.unproject(v.add(m.mult(e*x)).mult(f));i.setLocationAtPoint(i.renderWorldCopies?b.wrap():b,h)}n._fireMoveEvents(r)},function(){e.delayEndEvents?n._easeEndTimeoutID=setTimeout(function(){return n._afterEase(r)},e.delayEndEvents):n._afterEase(r)},e),this},r.prototype._prepareEase=function(e,r){this._moving=!0,r||this.fire(new t.Event(\"movestart\",e)),this._zooming&&this.fire(new t.Event(\"zoomstart\",e)),this._rotating&&this.fire(new t.Event(\"rotatestart\",e)),this._pitching&&this.fire(new t.Event(\"pitchstart\",e))},r.prototype._fireMoveEvents=function(e){this.fire(new t.Event(\"move\",e)),this._zooming&&this.fire(new t.Event(\"zoom\",e)),this._rotating&&this.fire(new t.Event(\"rotate\",e)),this._pitching&&this.fire(new t.Event(\"pitch\",e))},r.prototype._afterEase=function(e){var r=this._zooming,n=this._rotating,i=this._pitching;this._moving=!1,this._zooming=!1,this._rotating=!1,this._pitching=!1,r&&this.fire(new t.Event(\"zoomend\",e)),n&&this.fire(new t.Event(\"rotateend\",e)),i&&this.fire(new t.Event(\"pitchend\",e)),this.fire(new t.Event(\"moveend\",e))},r.prototype.flyTo=function(e,r){var n=this;this.stop(),e=t.extend({offset:[0,0],speed:1.2,curve:1.42,easing:t.ease},e);var i=this.transform,a=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=\"zoom\"in e?t.clamp(+e.zoom,i.minZoom,i.maxZoom):a,c=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,u=\"pitch\"in e?+e.pitch:s,h=i.zoomScale(l-a),f=i.centerPoint.add(t.Point.convert(e.offset)),p=i.pointLocation(f),d=t.LngLat.convert(e.center||p);this._normalizeCenter(d);var g=i.project(p),v=i.project(d).sub(g),m=e.curve,y=Math.max(i.width,i.height),x=y/h,b=v.mag();if(\"minZoom\"in e){var _=t.clamp(Math.min(e.minZoom,a,l),i.minZoom,i.maxZoom),w=y/i.zoomScale(_-a);m=Math.sqrt(w/b*2)}var k=m*m;function T(t){var e=(x*x-y*y+(t?-1:1)*k*k*b*b)/(2*(t?x:y)*k*b);return Math.log(Math.sqrt(e*e+1)-e)}function A(t){return(Math.exp(t)-Math.exp(-t))/2}function M(t){return(Math.exp(t)+Math.exp(-t))/2}var S=T(0),E=function(t){return M(S)/M(S+m*t)},C=function(t){return y*((M(S)*(A(e=S+m*t)/M(e))-A(S))/k)/b;var e},L=(T(1)-S)/m;if(Math.abs(b)<1e-6||!isFinite(L)){if(Math.abs(y-x)<1e-6)return this.easeTo(e,r);var P=x<y?-1:1;L=Math.abs(Math.log(x/y))/m,C=function(){return 0},E=function(t){return Math.exp(P*m*t)}}if(\"duration\"in e)e.duration=+e.duration;else{var O=\"screenSpeed\"in e?+e.screenSpeed/m:+e.speed;e.duration=1e3*L/O}return e.maxDuration&&e.duration>e.maxDuration&&(e.duration=0),this._zooming=!0,this._rotating=o!==c,this._pitching=u!==s,this._prepareEase(r,!1),this._ease(function(e){var h=e*L,p=1/E(h);i.zoom=1===e?l:a+i.scaleZoom(p),n._rotating&&(i.bearing=t.number(o,c,e)),n._pitching&&(i.pitch=t.number(s,u,e));var m=1===e?d:i.unproject(g.add(v.mult(C(h))).mult(p));i.setLocationAtPoint(i.renderWorldCopies?m.wrap():m,f),n._fireMoveEvents(r)},function(){return n._afterEase(r)},e),this},r.prototype.isEasing=function(){return!!this._easeFrameId},r.prototype.stop=function(){if(this._easeFrameId&&(this._cancelRenderFrame(this._easeFrameId),delete this._easeFrameId,delete this._onEaseFrame),this._onEaseEnd){var t=this._onEaseEnd;delete this._onEaseEnd,t.call(this)}return this},r.prototype._ease=function(e,r,n){!1===n.animate||0===n.duration?(e(1),r()):(this._easeStart=t.browser.now(),this._easeOptions=n,this._onEaseFrame=e,this._onEaseEnd=r,this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback))},r.prototype._renderFrameCallback=function(){var e=Math.min((t.browser.now()-this._easeStart)/this._easeOptions.duration,1);this._onEaseFrame(this._easeOptions.easing(e)),e<1?this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback):this.stop()},r.prototype._normalizeBearing=function(e,r){e=t.wrap(e,-180,180);var n=Math.abs(e-r);return Math.abs(e-360-r)<n&&(e-=360),Math.abs(e+360-r)<n&&(e+=360),e},r.prototype._normalizeCenter=function(t){var e=this.transform;if(e.renderWorldCopies&&!e.lngRange){var r=t.lng-e.center.lng;t.lng+=r>180?-360:r<-180?360:0}},r}(t.Evented),Mn=function(e){void 0===e&&(e={}),this.options=e,t.bindAll([\"_updateEditLink\",\"_updateData\",\"_updateCompact\"],this)};Mn.prototype.getDefaultPosition=function(){return\"bottom-right\"},Mn.prototype.onAdd=function(t){var e=this.options&&this.options.compact;return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-attrib\"),this._innerContainer=r.create(\"div\",\"mapboxgl-ctrl-attrib-inner\",this._container),e&&this._container.classList.add(\"mapboxgl-compact\"),this._updateAttributions(),this._updateEditLink(),this._map.on(\"styledata\",this._updateData),this._map.on(\"sourcedata\",this._updateData),this._map.on(\"moveend\",this._updateEditLink),void 0===e&&(this._map.on(\"resize\",this._updateCompact),this._updateCompact()),this._container},Mn.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"styledata\",this._updateData),this._map.off(\"sourcedata\",this._updateData),this._map.off(\"moveend\",this._updateEditLink),this._map.off(\"resize\",this._updateCompact),this._map=void 0},Mn.prototype._updateEditLink=function(){var e=this._editLink;e||(e=this._editLink=this._container.querySelector(\".mapbox-improve-map\"));var r=[{key:\"owner\",value:this.styleOwner},{key:\"id\",value:this.styleId},{key:\"access_token\",value:t.config.ACCESS_TOKEN}];if(e){var n=r.reduce(function(t,e,n){return e.value&&(t+=e.key+\"=\"+e.value+(n<r.length-1?\"&\":\"\")),t},\"?\");e.href=t.config.FEEDBACK_URL+\"/\"+n+(this._map._hash?this._map._hash.getHashString(!0):\"\"),e.rel=\"noopener nofollow\"}},Mn.prototype._updateData=function(t){!t||\"metadata\"!==t.sourceDataType&&\"style\"!==t.dataType||(this._updateAttributions(),this._updateEditLink())},Mn.prototype._updateAttributions=function(){if(this._map.style){var t=[];if(this.options.customAttribution&&(Array.isArray(this.options.customAttribution)?t=t.concat(this.options.customAttribution.map(function(t){return\"string\"!=typeof t?\"\":t})):\"string\"==typeof this.options.customAttribution&&t.push(this.options.customAttribution)),this._map.style.stylesheet){var e=this._map.style.stylesheet;this.styleOwner=e.owner,this.styleId=e.id}var r=this._map.style.sourceCaches;for(var n in r){var i=r[n];if(i.used){var a=i.getSource();a.attribution&&t.indexOf(a.attribution)<0&&t.push(a.attribution)}}t.sort(function(t,e){return t.length-e.length});var o=(t=t.filter(function(e,r){for(var n=r+1;n<t.length;n++)if(t[n].indexOf(e)>=0)return!1;return!0})).join(\" | \");o!==this._attribHTML&&(this._attribHTML=o,t.length?(this._innerContainer.innerHTML=o,this._container.classList.remove(\"mapboxgl-attrib-empty\")):this._container.classList.add(\"mapboxgl-attrib-empty\"),this._editLink=null)}},Mn.prototype._updateCompact=function(){this._map.getCanvasContainer().offsetWidth<=640?this._container.classList.add(\"mapboxgl-compact\"):this._container.classList.remove(\"mapboxgl-compact\")};var Sn=function(){t.bindAll([\"_updateLogo\"],this),t.bindAll([\"_updateCompact\"],this)};Sn.prototype.onAdd=function(t){this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl\");var e=r.create(\"a\",\"mapboxgl-ctrl-logo\");return e.target=\"_blank\",e.rel=\"noopener nofollow\",e.href=\"https://www.mapbox.com/\",e.setAttribute(\"aria-label\",\"Mapbox logo\"),e.setAttribute(\"rel\",\"noopener nofollow\"),this._container.appendChild(e),this._container.style.display=\"none\",this._map.on(\"sourcedata\",this._updateLogo),this._updateLogo(),this._map.on(\"resize\",this._updateCompact),this._updateCompact(),this._container},Sn.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"sourcedata\",this._updateLogo),this._map.off(\"resize\",this._updateCompact)},Sn.prototype.getDefaultPosition=function(){return\"bottom-left\"},Sn.prototype._updateLogo=function(t){t&&\"metadata\"!==t.sourceDataType||(this._container.style.display=this._logoRequired()?\"block\":\"none\")},Sn.prototype._logoRequired=function(){if(this._map.style){var t=this._map.style.sourceCaches;for(var e in t)if(t[e].getSource().mapbox_logo)return!0;return!1}},Sn.prototype._updateCompact=function(){var t=this._container.children;if(t.length){var e=t[0];this._map.getCanvasContainer().offsetWidth<250?e.classList.add(\"mapboxgl-compact\"):e.classList.remove(\"mapboxgl-compact\")}};var En=function(){this._queue=[],this._id=0,this._cleared=!1,this._currentlyRunning=!1};En.prototype.add=function(t){var e=++this._id;return this._queue.push({callback:t,id:e,cancelled:!1}),e},En.prototype.remove=function(t){for(var e=this._currentlyRunning,r=0,n=e?this._queue.concat(e):this._queue;r<n.length;r+=1){var i=n[r];if(i.id===t)return void(i.cancelled=!0)}},En.prototype.run=function(){var t=this._currentlyRunning=this._queue;this._queue=[];for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!n.cancelled&&(n.callback(),this._cleared))break}this._cleared=!1,this._currentlyRunning=!1},En.prototype.clear=function(){this._currentlyRunning&&(this._cleared=!0),this._queue=[]};var Cn=t.window.HTMLImageElement,Ln=t.window.HTMLElement,Pn={center:[0,0],zoom:0,bearing:0,pitch:0,minZoom:0,maxZoom:22,interactive:!0,scrollZoom:!0,boxZoom:!0,dragRotate:!0,dragPan:!0,keyboard:!0,doubleClickZoom:!0,touchZoomRotate:!0,bearingSnap:7,clickTolerance:3,hash:!1,attributionControl:!0,failIfMajorPerformanceCaveat:!1,preserveDrawingBuffer:!1,trackResize:!0,renderWorldCopies:!0,refreshExpiredTiles:!0,maxTileCacheSize:null,localIdeographFontFamily:\"sans-serif\",transformRequest:null,fadeDuration:300,crossSourceCollisions:!0},On=function(n){function i(e){var i=this;if(null!=(e=t.extend({},Pn,e)).minZoom&&null!=e.maxZoom&&e.minZoom>e.maxZoom)throw new Error(\"maxZoom must be greater than minZoom\");var a=new sn(e.minZoom,e.maxZoom,e.renderWorldCopies);if(n.call(this,a,e),this._interactive=e.interactive,this._maxTileCacheSize=e.maxTileCacheSize,this._failIfMajorPerformanceCaveat=e.failIfMajorPerformanceCaveat,this._preserveDrawingBuffer=e.preserveDrawingBuffer,this._antialias=e.antialias,this._trackResize=e.trackResize,this._bearingSnap=e.bearingSnap,this._refreshExpiredTiles=e.refreshExpiredTiles,this._fadeDuration=e.fadeDuration,this._crossSourceCollisions=e.crossSourceCollisions,this._crossFadingFactor=1,this._collectResourceTiming=e.collectResourceTiming,this._renderTaskQueue=new En,this._controls=[],this._mapId=t.uniqueId(),this._requestManager=new t.RequestManager(e.transformRequest),\"string\"==typeof e.container){if(this._container=t.window.document.getElementById(e.container),!this._container)throw new Error(\"Container '\"+e.container+\"' not found.\")}else{if(!(e.container instanceof Ln))throw new Error(\"Invalid type: 'container' must be a String or HTMLElement.\");this._container=e.container}if(e.maxBounds&&this.setMaxBounds(e.maxBounds),t.bindAll([\"_onWindowOnline\",\"_onWindowResize\",\"_contextLost\",\"_contextRestored\"],this),this._setupContainer(),this._setupPainter(),void 0===this.painter)throw new Error(\"Failed to initialize WebGL.\");this.on(\"move\",function(){return i._update(!1)}),this.on(\"moveend\",function(){return i._update(!1)}),this.on(\"zoom\",function(){return i._update(!0)}),void 0!==t.window&&(t.window.addEventListener(\"online\",this._onWindowOnline,!1),t.window.addEventListener(\"resize\",this._onWindowResize,!1)),function(t,e){var n=t.getCanvasContainer(),i=null,a=!1,o=null;for(var s in Tn)t[s]=new Tn[s](t,e),e.interactive&&e[s]&&t[s].enable(e[s]);r.addEventListener(n,\"mouseout\",function(e){t.fire(new un(\"mouseout\",t,e))}),r.addEventListener(n,\"mousedown\",function(i){a=!0,o=r.mousePos(n,i);var s=new un(\"mousedown\",t,i);t.fire(s),s.defaultPrevented||(e.interactive&&!t.doubleClickZoom.isActive()&&t.stop(),t.boxZoom.onMouseDown(i),t.boxZoom.isActive()||t.dragPan.isActive()||t.dragRotate.onMouseDown(i),t.boxZoom.isActive()||t.dragRotate.isActive()||t.dragPan.onMouseDown(i))}),r.addEventListener(n,\"mouseup\",function(e){var r=t.dragRotate.isActive();i&&!r&&t.fire(new un(\"contextmenu\",t,i)),i=null,a=!1,t.fire(new un(\"mouseup\",t,e))}),r.addEventListener(n,\"mousemove\",function(e){if(!t.dragPan.isActive()&&!t.dragRotate.isActive()){for(var r=e.target;r&&r!==n;)r=r.parentNode;r===n&&t.fire(new un(\"mousemove\",t,e))}}),r.addEventListener(n,\"mouseover\",function(e){for(var r=e.target;r&&r!==n;)r=r.parentNode;r===n&&t.fire(new un(\"mouseover\",t,e))}),r.addEventListener(n,\"touchstart\",function(r){var n=new hn(\"touchstart\",t,r);t.fire(n),n.defaultPrevented||(e.interactive&&t.stop(),t.boxZoom.isActive()||t.dragRotate.isActive()||t.dragPan.onTouchStart(r),t.touchZoomRotate.onStart(r),t.doubleClickZoom.onTouchStart(n))},{passive:!1}),r.addEventListener(n,\"touchmove\",function(e){t.fire(new hn(\"touchmove\",t,e))},{passive:!1}),r.addEventListener(n,\"touchend\",function(e){t.fire(new hn(\"touchend\",t,e))}),r.addEventListener(n,\"touchcancel\",function(e){t.fire(new hn(\"touchcancel\",t,e))}),r.addEventListener(n,\"click\",function(i){var a=r.mousePos(n,i);(a.equals(o)||a.dist(o)<e.clickTolerance)&&t.fire(new un(\"click\",t,i))}),r.addEventListener(n,\"dblclick\",function(e){var r=new un(\"dblclick\",t,e);t.fire(r),r.defaultPrevented||t.doubleClickZoom.onDblClick(r)}),r.addEventListener(n,\"contextmenu\",function(e){var r=t.dragRotate.isActive();a||r?a&&(i=e):t.fire(new un(\"contextmenu\",t,e)),(t.dragRotate.isEnabled()||t.listens(\"contextmenu\"))&&e.preventDefault()}),r.addEventListener(n,\"wheel\",function(r){e.interactive&&t.stop();var n=new fn(\"wheel\",t,r);t.fire(n),n.defaultPrevented||t.scrollZoom.onWheel(r)},{passive:!1})}(this,e),this._hash=e.hash&&(new cn).addTo(this),this._hash&&this._hash._onHashChange()||(this.jumpTo({center:e.center,zoom:e.zoom,bearing:e.bearing,pitch:e.pitch}),e.bounds&&(this.resize(),this.fitBounds(e.bounds,t.extend({},e.fitBoundsOptions,{duration:0})))),this.resize(),this._localIdeographFontFamily=e.localIdeographFontFamily,e.style&&this.setStyle(e.style,{localIdeographFontFamily:e.localIdeographFontFamily}),e.attributionControl&&this.addControl(new Mn({customAttribution:e.customAttribution})),this.addControl(new Sn,e.logoPosition),this.on(\"style.load\",function(){i.transform.unmodified&&i.jumpTo(i.style.stylesheet)}),this.on(\"data\",function(e){i._update(\"style\"===e.dataType),i.fire(new t.Event(e.dataType+\"data\",e))}),this.on(\"dataloading\",function(e){i.fire(new t.Event(e.dataType+\"dataloading\",e))})}n&&(i.__proto__=n),i.prototype=Object.create(n&&n.prototype),i.prototype.constructor=i;var a={showTileBoundaries:{configurable:!0},showCollisionBoxes:{configurable:!0},showOverdrawInspector:{configurable:!0},repaint:{configurable:!0},vertices:{configurable:!0}};return i.prototype._getMapId=function(){return this._mapId},i.prototype.addControl=function(e,r){if(void 0===r&&e.getDefaultPosition&&(r=e.getDefaultPosition()),void 0===r&&(r=\"top-right\"),!e||!e.onAdd)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.addControl(). Argument must be a control with onAdd and onRemove methods.\")));var n=e.onAdd(this);this._controls.push(e);var i=this._controlPositions[r];return-1!==r.indexOf(\"bottom\")?i.insertBefore(n,i.firstChild):i.appendChild(n),this},i.prototype.removeControl=function(e){if(!e||!e.onRemove)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.removeControl(). Argument must be a control with onAdd and onRemove methods.\")));var r=this._controls.indexOf(e);return r>-1&&this._controls.splice(r,1),e.onRemove(this),this},i.prototype.resize=function(e){var r=this._containerDimensions(),n=r[0],i=r[1];return this._resizeCanvas(n,i),this.transform.resize(n,i),this.painter.resize(n,i),this.fire(new t.Event(\"movestart\",e)).fire(new t.Event(\"move\",e)).fire(new t.Event(\"resize\",e)).fire(new t.Event(\"moveend\",e)),this},i.prototype.getBounds=function(){return this.transform.getBounds()},i.prototype.getMaxBounds=function(){return this.transform.getMaxBounds()},i.prototype.setMaxBounds=function(e){return this.transform.setMaxBounds(t.LngLatBounds.convert(e)),this._update()},i.prototype.setMinZoom=function(t){if((t=null==t?0:t)>=0&&t<=this.transform.maxZoom)return this.transform.minZoom=t,this._update(),this.getZoom()<t&&this.setZoom(t),this;throw new Error(\"minZoom must be between 0 and the current maxZoom, inclusive\")},i.prototype.getMinZoom=function(){return this.transform.minZoom},i.prototype.setMaxZoom=function(t){if((t=null==t?22:t)>=this.transform.minZoom)return this.transform.maxZoom=t,this._update(),this.getZoom()>t&&this.setZoom(t),this;throw new Error(\"maxZoom must be greater than the current minZoom\")},i.prototype.getRenderWorldCopies=function(){return this.transform.renderWorldCopies},i.prototype.setRenderWorldCopies=function(t){return this.transform.renderWorldCopies=t,this._update()},i.prototype.getMaxZoom=function(){return this.transform.maxZoom},i.prototype.project=function(e){return this.transform.locationPoint(t.LngLat.convert(e))},i.prototype.unproject=function(e){return this.transform.pointLocation(t.Point.convert(e))},i.prototype.isMoving=function(){return this._moving||this.dragPan.isActive()||this.dragRotate.isActive()||this.scrollZoom.isActive()},i.prototype.isZooming=function(){return this._zooming||this.scrollZoom.isZooming()},i.prototype.isRotating=function(){return this._rotating||this.dragRotate.isActive()},i.prototype.on=function(t,e,r){var i=this;if(void 0===r)return n.prototype.on.call(this,t,e);var a=function(){var n;if(\"mouseenter\"===t||\"mouseover\"===t){var a=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){var o=i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[];o.length?a||(a=!0,r.call(i,new un(t,i,n.originalEvent,{features:o}))):a=!1},mouseout:function(){a=!1}}}}if(\"mouseleave\"===t||\"mouseout\"===t){var o=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){(i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[]).length?o=!0:o&&(o=!1,r.call(i,new un(t,i,n.originalEvent)))},mouseout:function(e){o&&(o=!1,r.call(i,new un(t,i,e.originalEvent)))}}}}return{layer:e,listener:r,delegates:(n={},n[t]=function(t){var n=i.getLayer(e)?i.queryRenderedFeatures(t.point,{layers:[e]}):[];n.length&&(t.features=n,r.call(i,t),delete t.features)},n)}}();for(var o in this._delegatedListeners=this._delegatedListeners||{},this._delegatedListeners[t]=this._delegatedListeners[t]||[],this._delegatedListeners[t].push(a),a.delegates)this.on(o,a.delegates[o]);return this},i.prototype.off=function(t,e,r){if(void 0===r)return n.prototype.off.call(this,t,e);if(this._delegatedListeners&&this._delegatedListeners[t])for(var i=this._delegatedListeners[t],a=0;a<i.length;a++){var o=i[a];if(o.layer===e&&o.listener===r){for(var s in o.delegates)this.off(s,o.delegates[s]);return i.splice(a,1),this}}return this},i.prototype.queryRenderedFeatures=function(e,r){if(!this.style)return[];var n;if(void 0!==r||void 0===e||e instanceof t.Point||Array.isArray(e)||(r=e,e=void 0),r=r||{},(e=e||[[0,0],[this.transform.width,this.transform.height]])instanceof t.Point||\"number\"==typeof e[0])n=[t.Point.convert(e)];else{var i=t.Point.convert(e[0]),a=t.Point.convert(e[1]);n=[i,new t.Point(a.x,i.y),a,new t.Point(i.x,a.y),i]}return this.style.queryRenderedFeatures(n,r,this.transform)},i.prototype.querySourceFeatures=function(t,e){return this.style.querySourceFeatures(t,e)},i.prototype.setStyle=function(e,r){return!1!==(r=t.extend({},{localIdeographFontFamily:Pn.localIdeographFontFamily},r)).diff&&r.localIdeographFontFamily===this._localIdeographFontFamily&&this.style&&e?(this._diffStyle(e,r),this):(this._localIdeographFontFamily=r.localIdeographFontFamily,this._updateStyle(e,r))},i.prototype._updateStyle=function(t,e){return this.style&&(this.style.setEventedParent(null),this.style._remove()),t?(this.style=new De(this,e||{}),this.style.setEventedParent(this,{style:this.style}),\"string\"==typeof t?this.style.loadURL(t):this.style.loadJSON(t),this):(delete this.style,this)},i.prototype._diffStyle=function(e,r){var n=this;if(\"string\"==typeof e){var i=this._requestManager.normalizeStyleURL(e),a=this._requestManager.transformRequest(i,t.ResourceType.Style);t.getJSON(a,function(e,i){e?n.fire(new t.ErrorEvent(e)):i&&n._updateDiff(i,r)})}else\"object\"==typeof e&&this._updateDiff(e,r)},i.prototype._updateDiff=function(e,r){try{this.style.setState(e)&&this._update(!0)}catch(n){t.warnOnce(\"Unable to perform style diff: \"+(n.message||n.error||n)+\".  Rebuilding the style from scratch.\"),this._updateStyle(e,r)}},i.prototype.getStyle=function(){if(this.style)return this.style.serialize()},i.prototype.isStyleLoaded=function(){return this.style?this.style.loaded():t.warnOnce(\"There is no style added to the map.\")},i.prototype.addSource=function(t,e){return this.style.addSource(t,e),this._update(!0)},i.prototype.isSourceLoaded=function(e){var r=this.style&&this.style.sourceCaches[e];if(void 0!==r)return r.loaded();this.fire(new t.ErrorEvent(new Error(\"There is no source with ID '\"+e+\"'\")))},i.prototype.areTilesLoaded=function(){var t=this.style&&this.style.sourceCaches;for(var e in t){var r=t[e]._tiles;for(var n in r){var i=r[n];if(\"loaded\"!==i.state&&\"errored\"!==i.state)return!1}}return!0},i.prototype.addSourceType=function(t,e,r){return this.style.addSourceType(t,e,r)},i.prototype.removeSource=function(t){return this.style.removeSource(t),this._update(!0)},i.prototype.getSource=function(t){return this.style.getSource(t)},i.prototype.addImage=function(e,r,n){void 0===n&&(n={});var i=n.pixelRatio;void 0===i&&(i=1);var a=n.sdf;if(void 0===a&&(a=!1),r instanceof Cn){var o=t.browser.getImageData(r),s=o.width,l=o.height,c=o.data;this.style.addImage(e,{data:new t.RGBAImage({width:s,height:l},c),pixelRatio:i,sdf:a,version:0})}else{if(void 0===r.width||void 0===r.height)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.addImage(). The second argument must be an `HTMLImageElement`, `ImageData`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));var u=r.width,h=r.height,f=r.data,p=r;this.style.addImage(e,{data:new t.RGBAImage({width:u,height:h},new Uint8Array(f)),pixelRatio:i,sdf:a,version:0,userImage:p}),p.onAdd&&p.onAdd(this,e)}},i.prototype.updateImage=function(e,r){var n=this.style.getImage(e);if(!n)return this.fire(new t.ErrorEvent(new Error(\"The map has no image with that id. If you are adding a new image use `map.addImage(...)` instead.\")));var i=r instanceof Cn?t.browser.getImageData(r):r,a=i.width,o=i.height,s=i.data;if(void 0===a||void 0===o)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.updateImage(). The second argument must be an `HTMLImageElement`, `ImageData`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));if(a!==n.data.width||o!==n.data.height)return this.fire(new t.ErrorEvent(new Error(\"The width and height of the updated image must be that same as the previous version of the image\")));var l=!(r instanceof Cn);n.data.replace(s,l),this.style.updateImage(e,n)},i.prototype.hasImage=function(e){return e?!!this.style.getImage(e):(this.fire(new t.ErrorEvent(new Error(\"Missing required image id\"))),!1)},i.prototype.removeImage=function(t){this.style.removeImage(t)},i.prototype.loadImage=function(e,r){t.getImage(this._requestManager.transformRequest(e,t.ResourceType.Image),r)},i.prototype.listImages=function(){return this.style.listImages()},i.prototype.addLayer=function(t,e){return this.style.addLayer(t,e),this._update(!0)},i.prototype.moveLayer=function(t,e){return this.style.moveLayer(t,e),this._update(!0)},i.prototype.removeLayer=function(t){return this.style.removeLayer(t),this._update(!0)},i.prototype.getLayer=function(t){return this.style.getLayer(t)},i.prototype.setFilter=function(t,e,r){return void 0===r&&(r={}),this.style.setFilter(t,e,r),this._update(!0)},i.prototype.setLayerZoomRange=function(t,e,r){return this.style.setLayerZoomRange(t,e,r),this._update(!0)},i.prototype.getFilter=function(t){return this.style.getFilter(t)},i.prototype.setPaintProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setPaintProperty(t,e,r,n),this._update(!0)},i.prototype.getPaintProperty=function(t,e){return this.style.getPaintProperty(t,e)},i.prototype.setLayoutProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setLayoutProperty(t,e,r,n),this._update(!0)},i.prototype.getLayoutProperty=function(t,e){return this.style.getLayoutProperty(t,e)},i.prototype.setLight=function(t,e){return void 0===e&&(e={}),this.style.setLight(t,e),this._update(!0)},i.prototype.getLight=function(){return this.style.getLight()},i.prototype.setFeatureState=function(t,e){return this.style.setFeatureState(t,e),this._update()},i.prototype.removeFeatureState=function(t,e){return this.style.removeFeatureState(t,e),this._update()},i.prototype.getFeatureState=function(t){return this.style.getFeatureState(t)},i.prototype.getContainer=function(){return this._container},i.prototype.getCanvasContainer=function(){return this._canvasContainer},i.prototype.getCanvas=function(){return this._canvas},i.prototype._containerDimensions=function(){var t=0,e=0;return this._container&&(t=this._container.clientWidth||400,e=this._container.clientHeight||300),[t,e]},i.prototype._detectMissingCSS=function(){\"rgb(250, 128, 114)\"!==t.window.getComputedStyle(this._missingCSSCanary).getPropertyValue(\"background-color\")&&t.warnOnce(\"This page appears to be missing CSS declarations for Mapbox GL JS, which may cause the map to display incorrectly. Please ensure your page includes mapbox-gl.css, as described in https://www.mapbox.com/mapbox-gl-js/api/.\")},i.prototype._setupContainer=function(){var t=this._container;t.classList.add(\"mapboxgl-map\"),(this._missingCSSCanary=r.create(\"div\",\"mapboxgl-canary\",t)).style.visibility=\"hidden\",this._detectMissingCSS();var e=this._canvasContainer=r.create(\"div\",\"mapboxgl-canvas-container\",t);this._interactive&&e.classList.add(\"mapboxgl-interactive\"),this._canvas=r.create(\"canvas\",\"mapboxgl-canvas\",e),this._canvas.style.position=\"absolute\",this._canvas.addEventListener(\"webglcontextlost\",this._contextLost,!1),this._canvas.addEventListener(\"webglcontextrestored\",this._contextRestored,!1),this._canvas.setAttribute(\"tabindex\",\"0\"),this._canvas.setAttribute(\"aria-label\",\"Map\");var n=this._containerDimensions();this._resizeCanvas(n[0],n[1]);var i=this._controlContainer=r.create(\"div\",\"mapboxgl-control-container\",t),a=this._controlPositions={};[\"top-left\",\"top-right\",\"bottom-left\",\"bottom-right\"].forEach(function(t){a[t]=r.create(\"div\",\"mapboxgl-ctrl-\"+t,i)})},i.prototype._resizeCanvas=function(e,r){var n=t.window.devicePixelRatio||1;this._canvas.width=n*e,this._canvas.height=n*r,this._canvas.style.width=e+\"px\",this._canvas.style.height=r+\"px\"},i.prototype._setupPainter=function(){var r=t.extend({},e.webGLContextAttributes,{failIfMajorPerformanceCaveat:this._failIfMajorPerformanceCaveat,preserveDrawingBuffer:this._preserveDrawingBuffer,antialias:this._antialias||!1}),n=this._canvas.getContext(\"webgl\",r)||this._canvas.getContext(\"experimental-webgl\",r);n?(this.painter=new rn(n,this.transform),t.webpSupported.testSupport(n)):this.fire(new t.ErrorEvent(new Error(\"Failed to initialize WebGL\")))},i.prototype._contextLost=function(e){e.preventDefault(),this._frame&&(this._frame.cancel(),this._frame=null),this.fire(new t.Event(\"webglcontextlost\",{originalEvent:e}))},i.prototype._contextRestored=function(e){this._setupPainter(),this.resize(),this._update(),this.fire(new t.Event(\"webglcontextrestored\",{originalEvent:e}))},i.prototype.loaded=function(){return!this._styleDirty&&!this._sourcesDirty&&!!this.style&&this.style.loaded()},i.prototype._update=function(t){return this.style?(this._styleDirty=this._styleDirty||t,this._sourcesDirty=!0,this.triggerRepaint(),this):this},i.prototype._requestRenderFrame=function(t){return this._update(),this._renderTaskQueue.add(t)},i.prototype._cancelRenderFrame=function(t){this._renderTaskQueue.remove(t)},i.prototype._render=function(){this.painter.context.setDirty(),this.painter.setBaseState(),this._renderTaskQueue.run();var e=!1;if(this.style&&this._styleDirty){this._styleDirty=!1;var r=this.transform.zoom,n=t.browser.now();this.style.zoomHistory.update(r,n);var i=new t.EvaluationParameters(r,{now:n,fadeDuration:this._fadeDuration,zoomHistory:this.style.zoomHistory,transition:this.style.getTransition()}),a=i.crossFadingFactor();1===a&&a===this._crossFadingFactor||(e=!0,this._crossFadingFactor=a),this.style.update(i)}return this.style&&this._sourcesDirty&&(this._sourcesDirty=!1,this.style._updateSources(this.transform)),this._placementDirty=this.style&&this.style._updatePlacement(this.painter.transform,this.showCollisionBoxes,this._fadeDuration,this._crossSourceCollisions),this.painter.render(this.style,{showTileBoundaries:this.showTileBoundaries,showOverdrawInspector:this._showOverdrawInspector,rotating:this.isRotating(),zooming:this.isZooming(),moving:this.isMoving(),fadeDuration:this._fadeDuration}),this.fire(new t.Event(\"render\")),this.loaded()&&!this._loaded&&(this._loaded=!0,this.fire(new t.Event(\"load\"))),this.style&&(this.style.hasTransitions()||e)&&(this._styleDirty=!0),this.style&&!this._placementDirty&&this.style._releaseSymbolFadeTiles(),this._sourcesDirty||this._repaint||this._styleDirty||this._placementDirty?this.triggerRepaint():!this.isMoving()&&this.loaded()&&this.fire(new t.Event(\"idle\")),this},i.prototype.remove=function(){this._hash&&this._hash.remove();for(var e=0,r=this._controls;e<r.length;e+=1)r[e].onRemove(this);this._controls=[],this._frame&&(this._frame.cancel(),this._frame=null),this._renderTaskQueue.clear(),this.setStyle(null),void 0!==t.window&&(t.window.removeEventListener(\"resize\",this._onWindowResize,!1),t.window.removeEventListener(\"online\",this._onWindowOnline,!1));var n=this.painter.context.gl.getExtension(\"WEBGL_lose_context\");n&&n.loseContext(),zn(this._canvasContainer),zn(this._controlContainer),zn(this._missingCSSCanary),this._container.classList.remove(\"mapboxgl-map\"),this.fire(new t.Event(\"remove\"))},i.prototype.triggerRepaint=function(){var e=this;this.style&&!this._frame&&(this._frame=t.browser.frame(function(){e._frame=null,e._render()}))},i.prototype._onWindowOnline=function(){this._update()},i.prototype._onWindowResize=function(){this._trackResize&&this.resize()._update()},a.showTileBoundaries.get=function(){return!!this._showTileBoundaries},a.showTileBoundaries.set=function(t){this._showTileBoundaries!==t&&(this._showTileBoundaries=t,this._update())},a.showCollisionBoxes.get=function(){return!!this._showCollisionBoxes},a.showCollisionBoxes.set=function(t){this._showCollisionBoxes!==t&&(this._showCollisionBoxes=t,t?this.style._generateCollisionBoxes():this._update())},a.showOverdrawInspector.get=function(){return!!this._showOverdrawInspector},a.showOverdrawInspector.set=function(t){this._showOverdrawInspector!==t&&(this._showOverdrawInspector=t,this._update())},a.repaint.get=function(){return!!this._repaint},a.repaint.set=function(t){this._repaint!==t&&(this._repaint=t,this.triggerRepaint())},a.vertices.get=function(){return!!this._vertices},a.vertices.set=function(t){this._vertices=t,this._update()},i.prototype._setCacheLimits=function(e,r){t.setCacheLimits(e,r)},Object.defineProperties(i.prototype,a),i}(An);function zn(t){t.parentNode&&t.parentNode.removeChild(t)}var In={showCompass:!0,showZoom:!0},Dn=function(e){var n=this;this.options=t.extend({},In,e),this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),this._container.addEventListener(\"contextmenu\",function(t){return t.preventDefault()}),this.options.showZoom&&(t.bindAll([\"_updateZoomButtons\"],this),this._zoomInButton=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-zoom-in\",\"Zoom in\",function(){return n._map.zoomIn()}),this._zoomOutButton=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-zoom-out\",\"Zoom out\",function(){return n._map.zoomOut()})),this.options.showCompass&&(t.bindAll([\"_rotateCompassArrow\"],this),this._compass=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-compass\",\"Reset bearing to north\",function(){return n._map.resetNorth()}),this._compassArrow=r.create(\"span\",\"mapboxgl-ctrl-compass-arrow\",this._compass))};function Rn(e,r,n){if(e=new t.LngLat(e.lng,e.lat),r){var i=new t.LngLat(e.lng-360,e.lat),a=new t.LngLat(e.lng+360,e.lat),o=n.locationPoint(e).distSqr(r);n.locationPoint(i).distSqr(r)<o?e=i:n.locationPoint(a).distSqr(r)<o&&(e=a)}for(;Math.abs(e.lng-n.center.lng)>180;){var s=n.locationPoint(e);if(s.x>=0&&s.y>=0&&s.x<=n.width&&s.y<=n.height)break;e.lng>n.center.lng?e.lng-=360:e.lng+=360}return e}Dn.prototype._updateZoomButtons=function(){var t=this._map.getZoom();this._zoomInButton.classList.toggle(\"mapboxgl-ctrl-icon-disabled\",t===this._map.getMaxZoom()),this._zoomOutButton.classList.toggle(\"mapboxgl-ctrl-icon-disabled\",t===this._map.getMinZoom())},Dn.prototype._rotateCompassArrow=function(){var t=\"rotate(\"+this._map.transform.angle*(180/Math.PI)+\"deg)\";this._compassArrow.style.transform=t},Dn.prototype.onAdd=function(t){return this._map=t,this.options.showZoom&&(this._map.on(\"zoom\",this._updateZoomButtons),this._updateZoomButtons()),this.options.showCompass&&(this._map.on(\"rotate\",this._rotateCompassArrow),this._rotateCompassArrow(),this._handler=new vn(t,{button:\"left\",element:this._compass}),r.addEventListener(this._compass,\"mousedown\",this._handler.onMouseDown),this._handler.enable()),this._container},Dn.prototype.onRemove=function(){r.remove(this._container),this.options.showZoom&&this._map.off(\"zoom\",this._updateZoomButtons),this.options.showCompass&&(this._map.off(\"rotate\",this._rotateCompassArrow),r.removeEventListener(this._compass,\"mousedown\",this._handler.onMouseDown),this._handler.disable(),delete this._handler),delete this._map},Dn.prototype._createButton=function(t,e,n){var i=r.create(\"button\",t,this._container);return i.type=\"button\",i.title=e,i.setAttribute(\"aria-label\",e),i.addEventListener(\"click\",n),i};var Fn={center:\"translate(-50%,-50%)\",top:\"translate(-50%,0)\",\"top-left\":\"translate(0,0)\",\"top-right\":\"translate(-100%,0)\",bottom:\"translate(-50%,-100%)\",\"bottom-left\":\"translate(0,-100%)\",\"bottom-right\":\"translate(-100%,-100%)\",left:\"translate(0,-50%)\",right:\"translate(-100%,-50%)\"};function Bn(t,e,r){var n=t.classList;for(var i in Fn)n.remove(\"mapboxgl-\"+r+\"-anchor-\"+i);n.add(\"mapboxgl-\"+r+\"-anchor-\"+e)}var Nn,jn=function(e){function n(n,i){if(e.call(this),(n instanceof t.window.HTMLElement||i)&&(n=t.extend({element:n},i)),t.bindAll([\"_update\",\"_onMove\",\"_onUp\",\"_addDragHandler\",\"_onMapClick\"],this),this._anchor=n&&n.anchor||\"center\",this._color=n&&n.color||\"#3FB1CE\",this._draggable=n&&n.draggable||!1,this._state=\"inactive\",n&&n.element)this._element=n.element,this._offset=t.Point.convert(n&&n.offset||[0,0]);else{this._defaultMarker=!0,this._element=r.create(\"div\");var a=r.createNS(\"http://www.w3.org/2000/svg\",\"svg\");a.setAttributeNS(null,\"display\",\"block\"),a.setAttributeNS(null,\"height\",\"41px\"),a.setAttributeNS(null,\"width\",\"27px\"),a.setAttributeNS(null,\"viewBox\",\"0 0 27 41\");var o=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");o.setAttributeNS(null,\"stroke\",\"none\"),o.setAttributeNS(null,\"stroke-width\",\"1\"),o.setAttributeNS(null,\"fill\",\"none\"),o.setAttributeNS(null,\"fill-rule\",\"evenodd\");var s=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");s.setAttributeNS(null,\"fill-rule\",\"nonzero\");var l=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");l.setAttributeNS(null,\"transform\",\"translate(3.0, 29.0)\"),l.setAttributeNS(null,\"fill\",\"#000000\");for(var c=0,u=[{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"9.5\",ry:\"4.77275007\"},{rx:\"8.5\",ry:\"4.29549936\"},{rx:\"7.5\",ry:\"3.81822308\"},{rx:\"6.5\",ry:\"3.34094679\"},{rx:\"5.5\",ry:\"2.86367051\"},{rx:\"4.5\",ry:\"2.38636864\"}];c<u.length;c+=1){var h=u[c],f=r.createNS(\"http://www.w3.org/2000/svg\",\"ellipse\");f.setAttributeNS(null,\"opacity\",\"0.04\"),f.setAttributeNS(null,\"cx\",\"10.5\"),f.setAttributeNS(null,\"cy\",\"5.80029008\"),f.setAttributeNS(null,\"rx\",h.rx),f.setAttributeNS(null,\"ry\",h.ry),l.appendChild(f)}var p=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");p.setAttributeNS(null,\"fill\",this._color);var d=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");d.setAttributeNS(null,\"d\",\"M27,13.5 C27,19.074644 20.250001,27.000002 14.75,34.500002 C14.016665,35.500004 12.983335,35.500004 12.25,34.500002 C6.7499993,27.000002 0,19.222562 0,13.5 C0,6.0441559 6.0441559,0 13.5,0 C20.955844,0 27,6.0441559 27,13.5 Z\"),p.appendChild(d);var g=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");g.setAttributeNS(null,\"opacity\",\"0.25\"),g.setAttributeNS(null,\"fill\",\"#000000\");var v=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");v.setAttributeNS(null,\"d\",\"M13.5,0 C6.0441559,0 0,6.0441559 0,13.5 C0,19.222562 6.7499993,27 12.25,34.5 C13,35.522727 14.016664,35.500004 14.75,34.5 C20.250001,27 27,19.074644 27,13.5 C27,6.0441559 20.955844,0 13.5,0 Z M13.5,1 C20.415404,1 26,6.584596 26,13.5 C26,15.898657 24.495584,19.181431 22.220703,22.738281 C19.945823,26.295132 16.705119,30.142167 13.943359,33.908203 C13.743445,34.180814 13.612715,34.322738 13.5,34.441406 C13.387285,34.322738 13.256555,34.180814 13.056641,33.908203 C10.284481,30.127985 7.4148684,26.314159 5.015625,22.773438 C2.6163816,19.232715 1,15.953538 1,13.5 C1,6.584596 6.584596,1 13.5,1 Z\"),g.appendChild(v);var m=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");m.setAttributeNS(null,\"transform\",\"translate(6.0, 7.0)\"),m.setAttributeNS(null,\"fill\",\"#FFFFFF\");var y=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");y.setAttributeNS(null,\"transform\",\"translate(8.0, 8.0)\");var x=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");x.setAttributeNS(null,\"fill\",\"#000000\"),x.setAttributeNS(null,\"opacity\",\"0.25\"),x.setAttributeNS(null,\"cx\",\"5.5\"),x.setAttributeNS(null,\"cy\",\"5.5\"),x.setAttributeNS(null,\"r\",\"5.4999962\");var b=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");b.setAttributeNS(null,\"fill\",\"#FFFFFF\"),b.setAttributeNS(null,\"cx\",\"5.5\"),b.setAttributeNS(null,\"cy\",\"5.5\"),b.setAttributeNS(null,\"r\",\"5.4999962\"),y.appendChild(x),y.appendChild(b),s.appendChild(l),s.appendChild(p),s.appendChild(g),s.appendChild(m),s.appendChild(y),a.appendChild(s),this._element.appendChild(a),this._offset=t.Point.convert(n&&n.offset||[0,-14])}this._element.classList.add(\"mapboxgl-marker\"),this._element.addEventListener(\"dragstart\",function(t){t.preventDefault()}),Bn(this._element,this._anchor,\"marker\"),this._popup=null}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.addTo=function(t){return this.remove(),this._map=t,t.getCanvasContainer().appendChild(this._element),t.on(\"move\",this._update),t.on(\"moveend\",this._update),this.setDraggable(this._draggable),this._update(),this._map.on(\"click\",this._onMapClick),this},n.prototype.remove=function(){return this._map&&(this._map.off(\"click\",this._onMapClick),this._map.off(\"move\",this._update),this._map.off(\"moveend\",this._update),this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler),this._map.off(\"mouseup\",this._onUp),this._map.off(\"touchend\",this._onUp),delete this._map),r.remove(this._element),this._popup&&this._popup.remove(),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._popup&&this._popup.setLngLat(this._lngLat),this._update(),this},n.prototype.getElement=function(){return this._element},n.prototype.setPopup=function(t){if(this._popup&&(this._popup.remove(),this._popup=null),t){if(!(\"offset\"in t.options)){var e=Math.sqrt(Math.pow(13.5,2)/2);t.options.offset=this._defaultMarker?{top:[0,0],\"top-left\":[0,0],\"top-right\":[0,0],bottom:[0,-38.1],\"bottom-left\":[e,-1*(24.6+e)],\"bottom-right\":[-e,-1*(24.6+e)],left:[13.5,-24.6],right:[-13.5,-24.6]}:this._offset}this._popup=t,this._lngLat&&this._popup.setLngLat(this._lngLat)}return this},n.prototype._onMapClick=function(t){var e=t.originalEvent.target,r=this._element;this._popup&&(e===r||r.contains(e))&&this.togglePopup()},n.prototype.getPopup=function(){return this._popup},n.prototype.togglePopup=function(){var t=this._popup;return t?(t.isOpen()?t.remove():t.addTo(this._map),this):this},n.prototype._update=function(t){this._map&&(this._map.transform.renderWorldCopies&&(this._lngLat=Rn(this._lngLat,this._pos,this._map.transform)),this._pos=this._map.project(this._lngLat)._add(this._offset),t&&\"moveend\"!==t.type||(this._pos=this._pos.round()),r.setTransform(this._element,Fn[this._anchor]+\" translate(\"+this._pos.x+\"px, \"+this._pos.y+\"px)\"))},n.prototype.getOffset=function(){return this._offset},n.prototype.setOffset=function(e){return this._offset=t.Point.convert(e),this._update(),this},n.prototype._onMove=function(e){this._pos=e.point.sub(this._positionDelta),this._lngLat=this._map.unproject(this._pos),this.setLngLat(this._lngLat),this._element.style.pointerEvents=\"none\",\"pending\"===this._state&&(this._state=\"active\",this.fire(new t.Event(\"dragstart\"))),this.fire(new t.Event(\"drag\"))},n.prototype._onUp=function(){this._element.style.pointerEvents=\"auto\",this._positionDelta=null,this._map.off(\"mousemove\",this._onMove),this._map.off(\"touchmove\",this._onMove),\"active\"===this._state&&this.fire(new t.Event(\"dragend\")),this._state=\"inactive\"},n.prototype._addDragHandler=function(t){this._element.contains(t.originalEvent.target)&&(t.preventDefault(),this._positionDelta=t.point.sub(this._pos).add(this._offset),this._state=\"pending\",this._map.on(\"mousemove\",this._onMove),this._map.on(\"touchmove\",this._onMove),this._map.once(\"mouseup\",this._onUp),this._map.once(\"touchend\",this._onUp))},n.prototype.setDraggable=function(t){return this._draggable=!!t,this._map&&(t?(this._map.on(\"mousedown\",this._addDragHandler),this._map.on(\"touchstart\",this._addDragHandler)):(this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler))),this},n.prototype.isDraggable=function(){return this._draggable},n}(t.Evented),Un={positionOptions:{enableHighAccuracy:!1,maximumAge:0,timeout:6e3},fitBoundsOptions:{maxZoom:15},trackUserLocation:!1,showUserLocation:!0},Vn=function(e){function n(r){e.call(this),this.options=t.extend({},Un,r),t.bindAll([\"_onSuccess\",\"_onError\",\"_finish\",\"_setupUI\",\"_updateCamera\",\"_updateMarker\"],this)}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.onAdd=function(e){var n;return this._map=e,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),n=this._setupUI,void 0!==Nn?n(Nn):void 0!==t.window.navigator.permissions?t.window.navigator.permissions.query({name:\"geolocation\"}).then(function(t){Nn=\"denied\"!==t.state,n(Nn)}):(Nn=!!t.window.navigator.geolocation,n(Nn)),this._container},n.prototype.onRemove=function(){void 0!==this._geolocationWatchID&&(t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0),this.options.showUserLocation&&this._userLocationDotMarker&&this._userLocationDotMarker.remove(),r.remove(this._container),this._map=void 0},n.prototype._onSuccess=function(e){if(this.options.trackUserLocation)switch(this._lastKnownPosition=e,this._watchState){case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"BACKGROUND\":case\"BACKGROUND_ERROR\":this._watchState=\"BACKGROUND\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\")}this.options.showUserLocation&&\"OFF\"!==this._watchState&&this._updateMarker(e),this.options.trackUserLocation&&\"ACTIVE_LOCK\"!==this._watchState||this._updateCamera(e),this.options.showUserLocation&&this._dotElement.classList.remove(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"geolocate\",e)),this._finish()},n.prototype._updateCamera=function(e){var r=new t.LngLat(e.coords.longitude,e.coords.latitude),n=e.coords.accuracy,i=this._map.getBearing(),a=t.extend({bearing:i},this.options.fitBoundsOptions);this._map.fitBounds(r.toBounds(n),a,{geolocateSource:!0})},n.prototype._updateMarker=function(t){t?this._userLocationDotMarker.setLngLat([t.coords.longitude,t.coords.latitude]).addTo(this._map):this._userLocationDotMarker.remove()},n.prototype._onError=function(e){if(this.options.trackUserLocation)if(1===e.code)this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),void 0!==this._geolocationWatchID&&this._clearWatch();else switch(this._watchState){case\"WAITING_ACTIVE\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"ACTIVE_LOCK\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\");break;case\"BACKGROUND\":this._watchState=\"BACKGROUND_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\")}\"OFF\"!==this._watchState&&this.options.showUserLocation&&this._dotElement.classList.add(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"error\",e)),this._finish()},n.prototype._finish=function(){this._timeoutId&&clearTimeout(this._timeoutId),this._timeoutId=void 0},n.prototype._setupUI=function(e){var n=this;!1!==e?(this._container.addEventListener(\"contextmenu\",function(t){return t.preventDefault()}),this._geolocateButton=r.create(\"button\",\"mapboxgl-ctrl-icon mapboxgl-ctrl-geolocate\",this._container),this._geolocateButton.type=\"button\",this._geolocateButton.setAttribute(\"aria-label\",\"Geolocate\"),this.options.trackUserLocation&&(this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this._watchState=\"OFF\"),this.options.showUserLocation&&(this._dotElement=r.create(\"div\",\"mapboxgl-user-location-dot\"),this._userLocationDotMarker=new jn(this._dotElement),this.options.trackUserLocation&&(this._watchState=\"OFF\")),this._geolocateButton.addEventListener(\"click\",this.trigger.bind(this)),this._setup=!0,this.options.trackUserLocation&&this._map.on(\"movestart\",function(e){e.geolocateSource||\"ACTIVE_LOCK\"!==n._watchState||(n._watchState=\"BACKGROUND\",n._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\"),n._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),n.fire(new t.Event(\"trackuserlocationend\")))})):t.warnOnce(\"Geolocation support is not available, the GeolocateControl will not be visible.\")},n.prototype.trigger=function(){if(!this._setup)return t.warnOnce(\"Geolocate control triggered before added to a map\"),!1;if(this.options.trackUserLocation){switch(this._watchState){case\"OFF\":this._watchState=\"WAITING_ACTIVE\",this.fire(new t.Event(\"trackuserlocationstart\"));break;case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":case\"BACKGROUND_ERROR\":this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this.fire(new t.Event(\"trackuserlocationend\"));break;case\"BACKGROUND\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._lastKnownPosition&&this._updateCamera(this._lastKnownPosition),this.fire(new t.Event(\"trackuserlocationstart\"))}switch(this._watchState){case\"WAITING_ACTIVE\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_LOCK\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"BACKGROUND\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\");break;case\"BACKGROUND_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\")}\"OFF\"===this._watchState&&void 0!==this._geolocationWatchID?this._clearWatch():void 0===this._geolocationWatchID&&(this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"true\"),this._geolocationWatchID=t.window.navigator.geolocation.watchPosition(this._onSuccess,this._onError,this.options.positionOptions))}else t.window.navigator.geolocation.getCurrentPosition(this._onSuccess,this._onError,this.options.positionOptions),this._timeoutId=setTimeout(this._finish,1e4);return!0},n.prototype._clearWatch=function(){t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0,this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this.options.showUserLocation&&this._updateMarker(null)},n}(t.Evented),qn={maxWidth:100,unit:\"metric\"},Hn=function(e){this.options=t.extend({},qn,e),t.bindAll([\"_onMove\",\"setUnit\"],this)};function Gn(t,e,r){var n,i,a,o,s,l,c=r&&r.maxWidth||100,u=t._container.clientHeight/2,h=(n=t.unproject([0,u]),i=t.unproject([c,u]),a=Math.PI/180,o=n.lat*a,s=i.lat*a,l=Math.sin(o)*Math.sin(s)+Math.cos(o)*Math.cos(s)*Math.cos((i.lng-n.lng)*a),6371e3*Math.acos(Math.min(l,1)));if(r&&\"imperial\"===r.unit){var f=3.2808*h;f>5280?Yn(e,c,f/5280,\"mi\"):Yn(e,c,f,\"ft\")}else r&&\"nautical\"===r.unit?Yn(e,c,h/1852,\"nm\"):Yn(e,c,h,\"m\")}function Yn(t,e,r,n){var i,a,o,s=(i=r,(a=Math.pow(10,(\"\"+Math.floor(i)).length-1))*(o=(o=i/a)>=10?10:o>=5?5:o>=3?3:o>=2?2:o>=1?1:function(t){var e=Math.pow(10,Math.ceil(-Math.log(t)/Math.LN10));return Math.round(t*e)/e}(o))),l=s/r;\"m\"===n&&s>=1e3&&(s/=1e3,n=\"km\"),t.style.width=e*l+\"px\",t.innerHTML=s+n}Hn.prototype.getDefaultPosition=function(){return\"bottom-left\"},Hn.prototype._onMove=function(){Gn(this._map,this._container,this.options)},Hn.prototype.onAdd=function(t){return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-scale\",t.getContainer()),this._map.on(\"move\",this._onMove),this._onMove(),this._container},Hn.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"move\",this._onMove),this._map=void 0},Hn.prototype.setUnit=function(t){this.options.unit=t,Gn(this._map,this._container,this.options)};var Wn=function(e){this._fullscreen=!1,e&&e.container&&(e.container instanceof t.window.HTMLElement?this._container=e.container:t.warnOnce(\"Full screen control 'container' must be a DOM element.\")),t.bindAll([\"_onClickFullscreen\",\"_changeIcon\"],this),\"onfullscreenchange\"in t.window.document?this._fullscreenchange=\"fullscreenchange\":\"onmozfullscreenchange\"in t.window.document?this._fullscreenchange=\"mozfullscreenchange\":\"onwebkitfullscreenchange\"in t.window.document?this._fullscreenchange=\"webkitfullscreenchange\":\"onmsfullscreenchange\"in t.window.document&&(this._fullscreenchange=\"MSFullscreenChange\"),this._className=\"mapboxgl-ctrl\"};Wn.prototype.onAdd=function(e){return this._map=e,this._container||(this._container=this._map.getContainer()),this._controlContainer=r.create(\"div\",this._className+\" mapboxgl-ctrl-group\"),this._checkFullscreenSupport()?this._setupUI():(this._controlContainer.style.display=\"none\",t.warnOnce(\"This device does not support fullscreen mode.\")),this._controlContainer},Wn.prototype.onRemove=function(){r.remove(this._controlContainer),this._map=null,t.window.document.removeEventListener(this._fullscreenchange,this._changeIcon)},Wn.prototype._checkFullscreenSupport=function(){return!!(t.window.document.fullscreenEnabled||t.window.document.mozFullScreenEnabled||t.window.document.msFullscreenEnabled||t.window.document.webkitFullscreenEnabled)},Wn.prototype._setupUI=function(){(this._fullscreenButton=r.create(\"button\",this._className+\"-icon \"+this._className+\"-fullscreen\",this._controlContainer)).type=\"button\",this._updateTitle(),this._fullscreenButton.addEventListener(\"click\",this._onClickFullscreen),t.window.document.addEventListener(this._fullscreenchange,this._changeIcon)},Wn.prototype._updateTitle=function(){var t=this._isFullscreen()?\"Exit fullscreen\":\"Enter fullscreen\";this._fullscreenButton.setAttribute(\"aria-label\",t),this._fullscreenButton.title=t},Wn.prototype._isFullscreen=function(){return this._fullscreen},Wn.prototype._changeIcon=function(){(t.window.document.fullscreenElement||t.window.document.mozFullScreenElement||t.window.document.webkitFullscreenElement||t.window.document.msFullscreenElement)===this._container!==this._fullscreen&&(this._fullscreen=!this._fullscreen,this._fullscreenButton.classList.toggle(this._className+\"-shrink\"),this._fullscreenButton.classList.toggle(this._className+\"-fullscreen\"),this._updateTitle())},Wn.prototype._onClickFullscreen=function(){this._isFullscreen()?t.window.document.exitFullscreen?t.window.document.exitFullscreen():t.window.document.mozCancelFullScreen?t.window.document.mozCancelFullScreen():t.window.document.msExitFullscreen?t.window.document.msExitFullscreen():t.window.document.webkitCancelFullScreen&&t.window.document.webkitCancelFullScreen():this._container.requestFullscreen?this._container.requestFullscreen():this._container.mozRequestFullScreen?this._container.mozRequestFullScreen():this._container.msRequestFullscreen?this._container.msRequestFullscreen():this._container.webkitRequestFullscreen&&this._container.webkitRequestFullscreen()};var Xn={closeButton:!0,closeOnClick:!0,className:\"\",maxWidth:\"240px\"},Zn=function(e){function n(r){e.call(this),this.options=t.extend(Object.create(Xn),r),t.bindAll([\"_update\",\"_onClickClose\",\"remove\"],this)}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.addTo=function(e){var r=this;return this._map=e,this.options.closeOnClick&&this._map.on(\"click\",this._onClickClose),this._map.on(\"remove\",this.remove),this._update(),this._trackPointer?(this._map.on(\"mousemove\",function(t){r._update(t.point)}),this._map.on(\"mouseup\",function(t){r._update(t.point)}),this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")):this._map.on(\"move\",this._update),this.fire(new t.Event(\"open\")),this},n.prototype.isOpen=function(){return!!this._map},n.prototype.remove=function(){return this._content&&r.remove(this._content),this._container&&(r.remove(this._container),delete this._container),this._map&&(this._map.off(\"move\",this._update),this._map.off(\"click\",this._onClickClose),this._map.off(\"remove\",this.remove),this._map.off(\"mousemove\"),delete this._map),this.fire(new t.Event(\"close\")),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._map&&(this._map.on(\"move\",this._update),this._map.off(\"mousemove\"),this._container.classList.remove(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.remove(\"mapboxgl-track-pointer\")),this._trackPointer=!1,this._update(),this},n.prototype.trackPointer=function(){var t=this;return this._trackPointer=!0,this._pos=null,this._map&&(this._map.off(\"move\",this._update),this._map.on(\"mousemove\",function(e){t._update(e.point)}),this._map.on(\"drag\",function(e){t._update(e.point)}),this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")),this},n.prototype.getElement=function(){return this._container},n.prototype.setText=function(e){return this.setDOMContent(t.window.document.createTextNode(e))},n.prototype.setHTML=function(e){var r,n=t.window.document.createDocumentFragment(),i=t.window.document.createElement(\"body\");for(i.innerHTML=e;r=i.firstChild;)n.appendChild(r);return this.setDOMContent(n)},n.prototype.getMaxWidth=function(){return this._container.style.maxWidth},n.prototype.setMaxWidth=function(t){return this.options.maxWidth=t,this._update(),this},n.prototype.setDOMContent=function(t){return this._createContent(),this._content.appendChild(t),this._update(),this},n.prototype._createContent=function(){this._content&&r.remove(this._content),this._content=r.create(\"div\",\"mapboxgl-popup-content\",this._container),this.options.closeButton&&(this._closeButton=r.create(\"button\",\"mapboxgl-popup-close-button\",this._content),this._closeButton.type=\"button\",this._closeButton.setAttribute(\"aria-label\",\"Close popup\"),this._closeButton.innerHTML=\"&#215;\",this._closeButton.addEventListener(\"click\",this._onClickClose))},n.prototype._update=function(e){var n=this,i=this._lngLat||this._trackPointer;if(this._map&&i&&this._content&&(this._container||(this._container=r.create(\"div\",\"mapboxgl-popup\",this._map.getContainer()),this._tip=r.create(\"div\",\"mapboxgl-popup-tip\",this._container),this._container.appendChild(this._content),this.options.className&&this.options.className.split(\" \").forEach(function(t){return n._container.classList.add(t)})),this.options.maxWidth&&this._container.style.maxWidth!==this.options.maxWidth&&(this._container.style.maxWidth=this.options.maxWidth),this._map.transform.renderWorldCopies&&!this._trackPointer&&(this._lngLat=Rn(this._lngLat,this._pos,this._map.transform)),!this._trackPointer||e)){var a=this._pos=this._trackPointer&&e?e:this._map.project(this._lngLat),o=this.options.anchor,s=function e(r){if(r){if(\"number\"==typeof r){var n=Math.round(Math.sqrt(.5*Math.pow(r,2)));return{center:new t.Point(0,0),top:new t.Point(0,r),\"top-left\":new t.Point(n,n),\"top-right\":new t.Point(-n,n),bottom:new t.Point(0,-r),\"bottom-left\":new t.Point(n,-n),\"bottom-right\":new t.Point(-n,-n),left:new t.Point(r,0),right:new t.Point(-r,0)}}if(r instanceof t.Point||Array.isArray(r)){var i=t.Point.convert(r);return{center:i,top:i,\"top-left\":i,\"top-right\":i,bottom:i,\"bottom-left\":i,\"bottom-right\":i,left:i,right:i}}return{center:t.Point.convert(r.center||[0,0]),top:t.Point.convert(r.top||[0,0]),\"top-left\":t.Point.convert(r[\"top-left\"]||[0,0]),\"top-right\":t.Point.convert(r[\"top-right\"]||[0,0]),bottom:t.Point.convert(r.bottom||[0,0]),\"bottom-left\":t.Point.convert(r[\"bottom-left\"]||[0,0]),\"bottom-right\":t.Point.convert(r[\"bottom-right\"]||[0,0]),left:t.Point.convert(r.left||[0,0]),right:t.Point.convert(r.right||[0,0])}}return e(new t.Point(0,0))}(this.options.offset);if(!o){var l,c=this._container.offsetWidth,u=this._container.offsetHeight;l=a.y+s.bottom.y<u?[\"top\"]:a.y>this._map.transform.height-u?[\"bottom\"]:[],a.x<c/2?l.push(\"left\"):a.x>this._map.transform.width-c/2&&l.push(\"right\"),o=0===l.length?\"bottom\":l.join(\"-\")}var h=a.add(s[o]).round();r.setTransform(this._container,Fn[o]+\" translate(\"+h.x+\"px,\"+h.y+\"px)\"),Bn(this._container,o,\"popup\")}},n.prototype._onClickClose=function(){this.remove()},n}(t.Evented),Jn={version:t.version,supported:e,setRTLTextPlugin:t.setRTLTextPlugin,Map:On,NavigationControl:Dn,GeolocateControl:Vn,AttributionControl:Mn,ScaleControl:Hn,FullscreenControl:Wn,Popup:Zn,Marker:jn,Style:De,LngLat:t.LngLat,LngLatBounds:t.LngLatBounds,Point:t.Point,MercatorCoordinate:t.MercatorCoordinate,Evented:t.Evented,config:t.config,get accessToken(){return t.config.ACCESS_TOKEN},set accessToken(e){t.config.ACCESS_TOKEN=e},get baseApiUrl(){return t.config.API_URL},set baseApiUrl(e){t.config.API_URL=e},get workerCount(){return zt.workerCount},set workerCount(t){zt.workerCount=t},get maxParallelImageRequests(){return t.config.MAX_PARALLEL_IMAGE_REQUESTS},set maxParallelImageRequests(e){t.config.MAX_PARALLEL_IMAGE_REQUESTS=e},clearStorage:function(e){t.clearTileCache(e)},workerUrl:\"\"};return Jn}),r},\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=i():(n=n||self).mapboxgl=i()},{}],427:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1<<t+1,r=new Array(e),n=0;n<e;++n)r[n]=a(t,n);return r};var n=t(\"convex-hull\");function i(t,e,r){for(var n=new Array(t),i=0;i<t;++i)n[i]=0,i===e&&(n[i]+=.5),i===r&&(n[i]+=.5);return n}function a(t,e){if(0===e||e===(1<<t+1)-1)return[];for(var r=[],a=[],o=0;o<=t;++o)if(e&1<<o){r.push(i(t,o-1,o-1)),a.push(null);for(var s=0;s<=t;++s)~e&1<<s&&(r.push(i(t,o-1,s-1)),a.push([o,s]))}var l=n(r),c=[];t:for(o=0;o<l.length;++o){var u=l[o],h=[];for(s=0;s<u.length;++s){if(!a[u[s]])continue t;h.push(a[u[s]].slice())}c.push(h)}return c}},{\"convex-hull\":130}],428:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"gl-mat4/create\"),a=t(\"gl-mat4/clone\"),o=t(\"gl-mat4/determinant\"),s=t(\"gl-mat4/invert\"),l=t(\"gl-mat4/transpose\"),c={length:t(\"gl-vec3/length\"),normalize:t(\"gl-vec3/normalize\"),dot:t(\"gl-vec3/dot\"),cross:t(\"gl-vec3/cross\")},u=i(),h=i(),f=[0,0,0,0],p=[[0,0,0],[0,0,0],[0,0,0]],d=[0,0,0];function g(t,e,r,n,i){t[0]=e[0]*n+r[0]*i,t[1]=e[1]*n+r[1]*i,t[2]=e[2]*n+r[2]*i}e.exports=function(t,e,r,i,v,m){if(e||(e=[0,0,0]),r||(r=[0,0,0]),i||(i=[0,0,0]),v||(v=[0,0,0,1]),m||(m=[0,0,0,1]),!n(u,t))return!1;if(a(h,u),h[3]=0,h[7]=0,h[11]=0,h[15]=1,Math.abs(o(h)<1e-8))return!1;var y,x,b,_,w,k,T,A=u[3],M=u[7],S=u[11],E=u[12],C=u[13],L=u[14],P=u[15];if(0!==A||0!==M||0!==S){if(f[0]=A,f[1]=M,f[2]=S,f[3]=P,!s(h,h))return!1;l(h,h),y=v,b=h,_=(x=f)[0],w=x[1],k=x[2],T=x[3],y[0]=b[0]*_+b[4]*w+b[8]*k+b[12]*T,y[1]=b[1]*_+b[5]*w+b[9]*k+b[13]*T,y[2]=b[2]*_+b[6]*w+b[10]*k+b[14]*T,y[3]=b[3]*_+b[7]*w+b[11]*k+b[15]*T}else v[0]=v[1]=v[2]=0,v[3]=1;if(e[0]=E,e[1]=C,e[2]=L,function(t,e){t[0][0]=e[0],t[0][1]=e[1],t[0][2]=e[2],t[1][0]=e[4],t[1][1]=e[5],t[1][2]=e[6],t[2][0]=e[8],t[2][1]=e[9],t[2][2]=e[10]}(p,u),r[0]=c.length(p[0]),c.normalize(p[0],p[0]),i[0]=c.dot(p[0],p[1]),g(p[1],p[1],p[0],1,-i[0]),r[1]=c.length(p[1]),c.normalize(p[1],p[1]),i[0]/=r[1],i[1]=c.dot(p[0],p[2]),g(p[2],p[2],p[0],1,-i[1]),i[2]=c.dot(p[1],p[2]),g(p[2],p[2],p[1],1,-i[2]),r[2]=c.length(p[2]),c.normalize(p[2],p[2]),i[1]/=r[2],i[2]/=r[2],c.cross(d,p[1],p[2]),c.dot(p[0],d)<0)for(var O=0;O<3;O++)r[O]*=-1,p[O][0]*=-1,p[O][1]*=-1,p[O][2]*=-1;return m[0]=.5*Math.sqrt(Math.max(1+p[0][0]-p[1][1]-p[2][2],0)),m[1]=.5*Math.sqrt(Math.max(1-p[0][0]+p[1][1]-p[2][2],0)),m[2]=.5*Math.sqrt(Math.max(1-p[0][0]-p[1][1]+p[2][2],0)),m[3]=.5*Math.sqrt(Math.max(1+p[0][0]+p[1][1]+p[2][2],0)),p[2][1]>p[1][2]&&(m[0]=-m[0]),p[0][2]>p[2][0]&&(m[1]=-m[1]),p[1][0]>p[0][1]&&(m[2]=-m[2]),!0}},{\"./normalize\":429,\"gl-mat4/clone\":259,\"gl-mat4/create\":260,\"gl-mat4/determinant\":261,\"gl-mat4/invert\":265,\"gl-mat4/transpose\":276,\"gl-vec3/cross\":334,\"gl-vec3/dot\":339,\"gl-vec3/length\":349,\"gl-vec3/normalize\":356}],429:[function(t,e,r){e.exports=function(t,e){var r=e[15];if(0===r)return!1;for(var n=1/r,i=0;i<16;i++)t[i]=e[i]*n;return!0}},{}],430:[function(t,e,r){var n=t(\"gl-vec3/lerp\"),i=t(\"mat4-recompose\"),a=t(\"mat4-decompose\"),o=t(\"gl-mat4/determinant\"),s=t(\"quat-slerp\"),l=h(),c=h(),u=h();function h(){return{translate:f(),scale:f(1),skew:f(),perspective:[0,0,0,1],quaternion:[0,0,0,1]}}function f(t){return[t||0,t||0,t||0]}e.exports=function(t,e,r,h){if(0===o(e)||0===o(r))return!1;var f=a(e,l.translate,l.scale,l.skew,l.perspective,l.quaternion),p=a(r,c.translate,c.scale,c.skew,c.perspective,c.quaternion);return!(!f||!p||(n(u.translate,l.translate,c.translate,h),n(u.skew,l.skew,c.skew,h),n(u.scale,l.scale,c.scale,h),n(u.perspective,l.perspective,c.perspective,h),s(u.quaternion,l.quaternion,c.quaternion,h),i(t,u.translate,u.scale,u.skew,u.perspective,u.quaternion),0))}},{\"gl-mat4/determinant\":261,\"gl-vec3/lerp\":350,\"mat4-decompose\":428,\"mat4-recompose\":431,\"quat-slerp\":483}],431:[function(t,e,r){var n={identity:t(\"gl-mat4/identity\"),translate:t(\"gl-mat4/translate\"),multiply:t(\"gl-mat4/multiply\"),create:t(\"gl-mat4/create\"),scale:t(\"gl-mat4/scale\"),fromRotationTranslation:t(\"gl-mat4/fromRotationTranslation\")},i=(n.create(),n.create());e.exports=function(t,e,r,a,o,s){return n.identity(t),n.fromRotationTranslation(t,s,e),t[3]=o[0],t[7]=o[1],t[11]=o[2],t[15]=o[3],n.identity(i),0!==a[2]&&(i[9]=a[2],n.multiply(t,t,i)),0!==a[1]&&(i[9]=0,i[8]=a[1],n.multiply(t,t,i)),0!==a[0]&&(i[8]=0,i[4]=a[0],n.multiply(t,t,i)),n.scale(t,t,r),t}},{\"gl-mat4/create\":260,\"gl-mat4/fromRotationTranslation\":263,\"gl-mat4/identity\":264,\"gl-mat4/multiply\":267,\"gl-mat4/scale\":274,\"gl-mat4/translate\":275}],432:[function(t,e,r){\"use strict\";e.exports=Math.log2||function(t){return Math.log(t)*Math.LOG2E}},{}],433:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"mat4-interpolate\"),a=t(\"gl-mat4/invert\"),o=t(\"gl-mat4/rotateX\"),s=t(\"gl-mat4/rotateY\"),l=t(\"gl-mat4/rotateZ\"),c=t(\"gl-mat4/lookAt\"),u=t(\"gl-mat4/translate\"),h=(t(\"gl-mat4/scale\"),t(\"gl-vec3/normalize\")),f=[0,0,0];function p(t){this._components=t.slice(),this._time=[0],this.prevMatrix=t.slice(),this.nextMatrix=t.slice(),this.computedMatrix=t.slice(),this.computedInverse=t.slice(),this.computedEye=[0,0,0],this.computedUp=[0,0,0],this.computedCenter=[0,0,0],this.computedRadius=[0],this._limits=[-1/0,1/0]}e.exports=function(t){return new p((t=t||{}).matrix||[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1])};var d=p.prototype;d.recalcMatrix=function(t){var e=this._time,r=n.le(e,t),o=this.computedMatrix;if(!(r<0)){var s=this._components;if(r===e.length-1)for(var l=16*r,c=0;c<16;++c)o[c]=s[l++];else{var u=e[r+1]-e[r],f=(l=16*r,this.prevMatrix),p=!0;for(c=0;c<16;++c)f[c]=s[l++];var d=this.nextMatrix;for(c=0;c<16;++c)d[c]=s[l++],p=p&&f[c]===d[c];if(u<1e-6||p)for(c=0;c<16;++c)o[c]=f[c];else i(o,f,d,(t-e[r])/u)}var g=this.computedUp;g[0]=o[1],g[1]=o[5],g[2]=o[9],h(g,g);var v=this.computedInverse;a(v,o);var m=this.computedEye,y=v[15];m[0]=v[12]/y,m[1]=v[13]/y,m[2]=v[14]/y;var x=this.computedCenter,b=Math.exp(this.computedRadius[0]);for(c=0;c<3;++c)x[c]=m[c]-o[2+4*c]*b}},d.idle=function(t){if(!(t<this.lastT())){for(var e=this._components,r=e.length-16,n=0;n<16;++n)e.push(e[r++]);this._time.push(t)}},d.flush=function(t){var e=n.gt(this._time,t)-2;e<0||(this._time.splice(0,e),this._components.splice(0,16*e))},d.lastT=function(){return this._time[this._time.length-1]},d.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||f,n=n||this.computedUp,this.setMatrix(t,c(this.computedMatrix,e,r,n));for(var i=0,a=0;a<3;++a)i+=Math.pow(r[a]-e[a],2);i=Math.log(Math.sqrt(i)),this.computedRadius[0]=i},d.rotate=function(t,e,r,n){this.recalcMatrix(t);var i=this.computedInverse;e&&s(i,i,e),r&&o(i,i,r),n&&l(i,i,n),this.setMatrix(t,a(this.computedMatrix,i))};var g=[0,0,0];d.pan=function(t,e,r,n){g[0]=-(e||0),g[1]=-(r||0),g[2]=-(n||0),this.recalcMatrix(t);var i=this.computedInverse;u(i,i,g),this.setMatrix(t,a(i,i))},d.translate=function(t,e,r,n){g[0]=e||0,g[1]=r||0,g[2]=n||0,this.recalcMatrix(t);var i=this.computedMatrix;u(i,i,g),this.setMatrix(t,i)},d.setMatrix=function(t,e){if(!(t<this.lastT())){this._time.push(t);for(var r=0;r<16;++r)this._components.push(e[r])}},d.setDistance=function(t,e){this.computedRadius[0]=e},d.setDistanceLimits=function(t,e){var r=this._limits;r[0]=t,r[1]=e},d.getDistanceLimits=function(t){var e=this._limits;return t?(t[0]=e[0],t[1]=e[1],t):e}},{\"binary-search-bounds\":91,\"gl-mat4/invert\":265,\"gl-mat4/lookAt\":266,\"gl-mat4/rotateX\":271,\"gl-mat4/rotateY\":272,\"gl-mat4/rotateZ\":273,\"gl-mat4/scale\":274,\"gl-mat4/translate\":275,\"gl-vec3/normalize\":356,\"mat4-interpolate\":430}],434:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<3){for(var r=new Array(e),i=0;i<e;++i)r[i]=i;return 2===e&&t[0][0]===t[1][0]&&t[0][1]===t[1][1]?[0]:r}for(var a=new Array(e),i=0;i<e;++i)a[i]=i;a.sort(function(e,r){var n=t[e][0]-t[r][0];return n||t[e][1]-t[r][1]});for(var o=[a[0],a[1]],s=[a[0],a[1]],i=2;i<e;++i){for(var l=a[i],c=t[l],u=o.length;u>1&&n(t[o[u-2]],t[o[u-1]],c)<=0;)u-=1,o.pop();for(o.push(l),u=s.length;u>1&&n(t[s[u-2]],t[s[u-1]],c)>=0;)u-=1,s.pop();s.push(l)}for(var r=new Array(s.length+o.length-2),h=0,i=0,f=o.length;i<f;++i)r[h++]=o[i];for(var p=s.length-2;p>0;--p)r[h++]=s[p];return r};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":510}],435:[function(t,e,r){\"use strict\";e.exports=function(t,e){e||(e=t,t=window);var r=0,i=0,a=0,o={shift:!1,alt:!1,control:!1,meta:!1},s=!1;function l(t){var e=!1;return\"altKey\"in t&&(e=e||t.altKey!==o.alt,o.alt=!!t.altKey),\"shiftKey\"in t&&(e=e||t.shiftKey!==o.shift,o.shift=!!t.shiftKey),\"ctrlKey\"in t&&(e=e||t.ctrlKey!==o.control,o.control=!!t.ctrlKey),\"metaKey\"in t&&(e=e||t.metaKey!==o.meta,o.meta=!!t.metaKey),e}function c(t,s){var c=n.x(s),u=n.y(s);\"buttons\"in s&&(t=0|s.buttons),(t!==r||c!==i||u!==a||l(s))&&(r=0|t,i=c||0,a=u||0,e&&e(r,i,a,o))}function u(t){c(0,t)}function h(){(r||i||a||o.shift||o.alt||o.meta||o.control)&&(i=a=0,r=0,o.shift=o.alt=o.control=o.meta=!1,e&&e(0,0,0,o))}function f(t){l(t)&&e&&e(r,i,a,o)}function p(t){0===n.buttons(t)?c(0,t):c(r,t)}function d(t){c(r|n.buttons(t),t)}function g(t){c(r&~n.buttons(t),t)}function v(){s||(s=!0,t.addEventListener(\"mousemove\",p),t.addEventListener(\"mousedown\",d),t.addEventListener(\"mouseup\",g),t.addEventListener(\"mouseleave\",u),t.addEventListener(\"mouseenter\",u),t.addEventListener(\"mouseout\",u),t.addEventListener(\"mouseover\",u),t.addEventListener(\"blur\",h),t.addEventListener(\"keyup\",f),t.addEventListener(\"keydown\",f),t.addEventListener(\"keypress\",f),t!==window&&(window.addEventListener(\"blur\",h),window.addEventListener(\"keyup\",f),window.addEventListener(\"keydown\",f),window.addEventListener(\"keypress\",f)))}v();var m={element:t};return Object.defineProperties(m,{enabled:{get:function(){return s},set:function(e){e?v():s&&(s=!1,t.removeEventListener(\"mousemove\",p),t.removeEventListener(\"mousedown\",d),t.removeEventListener(\"mouseup\",g),t.removeEventListener(\"mouseleave\",u),t.removeEventListener(\"mouseenter\",u),t.removeEventListener(\"mouseout\",u),t.removeEventListener(\"mouseover\",u),t.removeEventListener(\"blur\",h),t.removeEventListener(\"keyup\",f),t.removeEventListener(\"keydown\",f),t.removeEventListener(\"keypress\",f),t!==window&&(window.removeEventListener(\"blur\",h),window.removeEventListener(\"keyup\",f),window.removeEventListener(\"keydown\",f),window.removeEventListener(\"keypress\",f)))},enumerable:!0},buttons:{get:function(){return r},enumerable:!0},x:{get:function(){return i},enumerable:!0},y:{get:function(){return a},enumerable:!0},mods:{get:function(){return o},enumerable:!0}}),m};var n=t(\"mouse-event\")},{\"mouse-event\":437}],436:[function(t,e,r){var n={left:0,top:0};e.exports=function(t,e,r){e=e||t.currentTarget||t.srcElement,Array.isArray(r)||(r=[0,0]);var i=t.clientX||0,a=t.clientY||0,o=(s=e,s===window||s===document||s===document.body?n:s.getBoundingClientRect());var s;return r[0]=i-o.left,r[1]=a-o.top,r}},{}],437:[function(t,e,r){\"use strict\";function n(t){return t.target||t.srcElement||window}r.buttons=function(t){if(\"object\"==typeof t){if(\"buttons\"in t)return t.buttons;if(\"which\"in t){if(2===(e=t.which))return 4;if(3===e)return 2;if(e>0)return 1<<e-1}else if(\"button\"in t){var e;if(1===(e=t.button))return 4;if(2===e)return 2;if(e>=0)return 1<<e}}return 0},r.element=n,r.x=function(t){if(\"object\"==typeof t){if(\"offsetX\"in t)return t.offsetX;var e=n(t).getBoundingClientRect();return t.clientX-e.left}return 0},r.y=function(t){if(\"object\"==typeof t){if(\"offsetY\"in t)return t.offsetY;var e=n(t).getBoundingClientRect();return t.clientY-e.top}return 0}},{}],438:[function(t,e,r){\"use strict\";var n=t(\"to-px\");e.exports=function(t,e,r){\"function\"==typeof t&&(r=!!e,e=t,t=window);var i=n(\"ex\",t),a=function(t){r&&t.preventDefault();var n=t.deltaX||0,a=t.deltaY||0,o=t.deltaZ||0,s=t.deltaMode,l=1;switch(s){case 1:l=i;break;case 2:l=window.innerHeight}if(a*=l,o*=l,(n*=l)||a||o)return e(n,a,o,t)};return t.addEventListener(\"wheel\",a),a}},{\"to-px\":539}],439:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\");function i(t){return\"a\"+t}function a(t){return\"d\"+t}function o(t,e){return\"c\"+t+\"_\"+e}function s(t){return\"s\"+t}function l(t,e){return\"t\"+t+\"_\"+e}function c(t){return\"o\"+t}function u(t){return\"x\"+t}function h(t){return\"p\"+t}function f(t,e){return\"d\"+t+\"_\"+e}function p(t){return\"i\"+t}function d(t,e){return\"u\"+t+\"_\"+e}function g(t){return\"b\"+t}function v(t){return\"y\"+t}function m(t){return\"e\"+t}function y(t){return\"v\"+t}e.exports=function(t){function e(t){throw new Error(\"ndarray-extract-contour: \"+t)}\"object\"!=typeof t&&e(\"Must specify arguments\");var r=t.order;Array.isArray(r)||e(\"Must specify order\");var M=t.arrayArguments||1;M<1&&e(\"Must have at least one array argument\");var S=t.scalarArguments||0;S<0&&e(\"Scalar arg count must be > 0\");\"function\"!=typeof t.vertex&&e(\"Must specify vertex creation function\");\"function\"!=typeof t.cell&&e(\"Must specify cell creation function\");\"function\"!=typeof t.phase&&e(\"Must specify phase function\");for(var E=t.getters||[],C=new Array(M),L=0;L<M;++L)E.indexOf(L)>=0?C[L]=!0:C[L]=!1;return function(t,e,r,M,S,E){var C=E.length,L=S.length;if(L<2)throw new Error(\"ndarray-extract-contour: Dimension must be at least 2\");for(var P=\"extractContour\"+S.join(\"_\"),O=[],z=[],I=[],D=0;D<C;++D)I.push(i(D));for(var D=0;D<M;++D)I.push(u(D));for(var D=0;D<L;++D)z.push(s(D)+\"=\"+i(0)+\".shape[\"+D+\"]|0\");for(var D=0;D<C;++D){z.push(a(D)+\"=\"+i(D)+\".data\",c(D)+\"=\"+i(D)+\".offset|0\");for(var R=0;R<L;++R)z.push(l(D,R)+\"=\"+i(D)+\".stride[\"+R+\"]|0\")}for(var D=0;D<C;++D){z.push(h(D)+\"=\"+c(D)),z.push(o(D,0));for(var R=1;R<1<<L;++R){for(var F=[],B=0;B<L;++B)R&1<<B&&F.push(\"-\"+l(D,B));z.push(f(D,R)+\"=(\"+F.join(\"\")+\")|0\"),z.push(o(D,R)+\"=0\")}}for(var D=0;D<C;++D)for(var R=0;R<L;++R){var N=[l(D,S[R])];R>0&&N.push(l(D,S[R-1])+\"*\"+s(S[R-1])),z.push(d(D,S[R])+\"=(\"+N.join(\"-\")+\")|0\")}for(var D=0;D<L;++D)z.push(p(D)+\"=0\");z.push(_+\"=0\");for(var j=[\"2\"],D=L-2;D>=0;--D)j.push(s(S[D]));z.push(w+\"=(\"+j.join(\"*\")+\")|0\",b+\"=mallocUint32(\"+w+\")\",x+\"=mallocUint32(\"+w+\")\",k+\"=0\"),z.push(g(0)+\"=0\");for(var R=1;R<1<<L;++R){for(var U=[],V=[],B=0;B<L;++B)R&1<<B&&(0===V.length?U.push(\"1\"):U.unshift(V.join(\"*\"))),V.push(s(S[B]));var q=\"\";U[0].indexOf(s(S[L-2]))<0&&(q=\"-\");var H=A(L,R,S);z.push(m(H)+\"=(-\"+U.join(\"-\")+\")|0\",v(H)+\"=(\"+q+U.join(\"-\")+\")|0\",g(H)+\"=0\")}function G(t,e){O.push(\"for(\",p(S[t]),\"=\",e,\";\",p(S[t]),\"<\",s(S[t]),\";\",\"++\",p(S[t]),\"){\")}function Y(t){for(var e=0;e<C;++e)O.push(h(e),\"+=\",d(e,S[t]),\";\");O.push(\"}\")}function W(){for(var t=1;t<1<<L;++t)O.push(T,\"=\",m(t),\";\",m(t),\"=\",v(t),\";\",v(t),\"=\",T,\";\")}z.push(y(0)+\"=0\",T+\"=0\"),function t(e,r){if(e<0)return void function(t){for(var e=0;e<C;++e)E[e]?O.push(o(e,0),\"=\",a(e),\".get(\",h(e),\");\"):O.push(o(e,0),\"=\",a(e),\"[\",h(e),\"];\");for(var r=[],e=0;e<C;++e)r.push(o(e,0));for(var e=0;e<M;++e)r.push(u(e));O.push(g(0),\"=\",b,\"[\",k,\"]=phase(\",r.join(),\");\");for(var n=1;n<1<<L;++n)O.push(g(n),\"=\",b,\"[\",k,\"+\",m(n),\"];\");for(var i=[],n=1;n<1<<L;++n)i.push(\"(\"+g(0)+\"!==\"+g(n)+\")\");O.push(\"if(\",i.join(\"||\"),\"){\");for(var s=[],e=0;e<L;++e)s.push(p(e));for(var e=0;e<C;++e){s.push(o(e,0));for(var n=1;n<1<<L;++n)E[e]?O.push(o(e,n),\"=\",a(e),\".get(\",h(e),\"+\",f(e,n),\");\"):O.push(o(e,n),\"=\",a(e),\"[\",h(e),\"+\",f(e,n),\"];\"),s.push(o(e,n))}for(var e=0;e<1<<L;++e)s.push(g(e));for(var e=0;e<M;++e)s.push(u(e));O.push(\"vertex(\",s.join(),\");\",y(0),\"=\",x,\"[\",k,\"]=\",_,\"++;\");for(var l=(1<<L)-1,c=g(l),n=0;n<L;++n)if(0==(t&~(1<<n))){for(var d=l^1<<n,v=g(d),w=[],T=d;T>0;T=T-1&d)w.push(x+\"[\"+k+\"+\"+m(T)+\"]\");w.push(y(0));for(var T=0;T<C;++T)1&n?w.push(o(T,l),o(T,d)):w.push(o(T,d),o(T,l));1&n?w.push(c,v):w.push(v,c);for(var T=0;T<M;++T)w.push(u(T));O.push(\"if(\",c,\"!==\",v,\"){\",\"face(\",w.join(),\")}\")}O.push(\"}\",k,\"+=1;\")}(r);!function(t){for(var e=t-1;e>=0;--e)G(e,0);for(var r=[],e=0;e<C;++e)E[e]?r.push(a(e)+\".get(\"+h(e)+\")\"):r.push(a(e)+\"[\"+h(e)+\"]\");for(var e=0;e<M;++e)r.push(u(e));O.push(b,\"[\",k,\"++]=phase(\",r.join(),\");\");for(var e=0;e<t;++e)Y(e);for(var n=0;n<C;++n)O.push(h(n),\"+=\",d(n,S[t]),\";\")}(e);O.push(\"if(\",s(S[e]),\">0){\",p(S[e]),\"=1;\");t(e-1,r|1<<S[e]);for(var n=0;n<C;++n)O.push(h(n),\"+=\",d(n,S[e]),\";\");e===L-1&&(O.push(k,\"=0;\"),W());G(e,2);t(e-1,r);e===L-1&&(O.push(\"if(\",p(S[L-1]),\"&1){\",k,\"=0;}\"),W());Y(e);O.push(\"}\")}(L-1,0),O.push(\"freeUint32(\",x,\");freeUint32(\",b,\");\");var X=[\"'use strict';\",\"function \",P,\"(\",I.join(),\"){\",\"var \",z.join(),\";\",O.join(\"\"),\"}\",\"return \",P].join(\"\");return new Function(\"vertex\",\"face\",\"phase\",\"mallocUint32\",\"freeUint32\",X)(t,e,r,n.mallocUint32,n.freeUint32)}(t.vertex,t.cell,t.phase,S,r,C)};var x=\"V\",b=\"P\",_=\"N\",w=\"Q\",k=\"X\",T=\"T\";function A(t,e,r){for(var n=0,i=0;i<t;++i)e&1<<i&&(n|=1<<r[i]);return n}},{\"typedarray-pool\":545}],440:[function(t,e,r){\"use strict\";var n=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{_inline_1_arg1_=_inline_1_arg2_.apply(void 0,_inline_1_arg0_)}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"cwise\",blockSize:64});e.exports=function(t,e){return n(t,e),t}},{\"cwise/lib/wrapper\":149}],441:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(Array.isArray(r)){if(r.length!==e.dimension)throw new Error(\"ndarray-gradient: invalid boundary conditions\")}else r=n(e.dimension,\"string\"==typeof r?r:\"clamp\");if(t.dimension!==e.dimension+1)throw new Error(\"ndarray-gradient: output dimension must be +1 input dimension\");if(t.shape[e.dimension]!==e.dimension)throw new Error(\"ndarray-gradient: output shape must match input shape\");for(var i=0;i<e.dimension;++i)if(t.shape[i]!==e.shape[i])throw new Error(\"ndarray-gradient: shape mismatch\");if(0===e.size)return t;if(e.dimension<=0)return t.set(0),t;return function(t){var e=t.join();if(m=o[e])return m;var r=t.length,n=[\"function gradient(dst,src){var s=src.shape.slice();\"];function i(e){for(var i=r-e.length,a=[],o=[],s=[],l=0;l<r;++l)e.indexOf(l+1)>=0?s.push(\"0\"):e.indexOf(-(l+1))>=0?s.push(\"s[\"+l+\"]-1\"):(s.push(\"-1\"),a.push(\"1\"),o.push(\"s[\"+l+\"]-2\"));var c=\".lo(\"+a.join()+\").hi(\"+o.join()+\")\";if(0===a.length&&(c=\"\"),i>0){n.push(\"if(1\");for(var l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\"&&s[\",l,\"]>2\");n.push(\"){grad\",i,\"(src.pick(\",s.join(),\")\",c);for(var l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\",dst.pick(\",s.join(),\",\",l,\")\",c);n.push(\");\")}for(var l=0;l<e.length;++l){var u=Math.abs(e[l])-1,h=\"dst.pick(\"+s.join()+\",\"+u+\")\"+c;switch(t[u]){case\"clamp\":var f=s.slice(),p=s.slice();e[l]<0?f[u]=\"s[\"+u+\"]-2\":p[u]=\"1\",0===i?n.push(\"if(s[\",u,\"]>1){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",f.join(),\")-src.get(\",p.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>1){diff(\",h,\",src.pick(\",f.join(),\")\",c,\",src.pick(\",p.join(),\")\",c,\");}else{zero(\",h,\");};\");break;case\"mirror\":0===i?n.push(\"dst.set(\",s.join(),\",\",u,\",0);\"):n.push(\"zero(\",h,\");\");break;case\"wrap\":var d=s.slice(),g=s.slice();e[l]<0?(d[u]=\"s[\"+u+\"]-2\",g[u]=\"0\"):(d[u]=\"s[\"+u+\"]-1\",g[u]=\"1\"),0===i?n.push(\"if(s[\",u,\"]>2){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",d.join(),\")-src.get(\",g.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>2){diff(\",h,\",src.pick(\",d.join(),\")\",c,\",src.pick(\",g.join(),\")\",c,\");}else{zero(\",h,\");};\");break;default:throw new Error(\"ndarray-gradient: Invalid boundary condition\")}}i>0&&n.push(\"};\")}for(var s=0;s<1<<r;++s){for(var h=[],f=0;f<r;++f)s&1<<f&&h.push(f+1);for(var p=0;p<1<<h.length;++p){for(var d=h.slice(),f=0;f<h.length;++f)p&1<<f&&(d[f]=-d[f]);i(d)}}n.push(\"return dst;};return gradient\");for(var g=[\"diff\",\"zero\"],v=[l,c],s=1;s<=r;++s)g.push(\"grad\"+s),v.push(u(s));g.push(n.join(\"\"));var m=Function.apply(void 0,g).apply(void 0,v);return a[e]=m,m}(r)(t,e)};var n=t(\"dup\"),i=t(\"cwise-compiler\"),a={},o={},s={body:\"\",args:[],thisVars:[],localVars:[]},l=i({args:[\"array\",\"array\",\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1},{name:\"left\",lvalue:!1,rvalue:!0,count:1},{name:\"right\",lvalue:!1,rvalue:!0,count:1}],body:\"out=0.5*(left-right)\",thisVars:[],localVars:[]},funcName:\"cdiff\"}),c=i({args:[\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1}],body:\"out=0\",thisVars:[],localVars:[]},funcName:\"zero\"});function u(t){if(t in a)return a[t];for(var e=[],r=0;r<t;++r)e.push(\"out\",r,\"s=0.5*(inp\",r,\"l-inp\",r,\"r);\");var o=[\"array\"],l=[\"junk\"];for(r=0;r<t;++r){o.push(\"array\"),l.push(\"out\"+r+\"s\");var c=n(t);c[r]=-1,o.push({array:0,offset:c.slice()}),c[r]=1,o.push({array:0,offset:c.slice()}),l.push(\"inp\"+r+\"l\",\"inp\"+r+\"r\")}return a[t]=i({args:o,pre:s,post:s,body:{body:e.join(\"\"),args:l.map(function(t){return{name:t,lvalue:0===t.indexOf(\"out\"),rvalue:0===t.indexOf(\"inp\"),count:\"junk\"!==t|0}}),thisVars:[],localVars:[]},funcName:\"fdTemplate\"+t})}},{\"cwise-compiler\":146,dup:170}],442:[function(t,e,r){\"use strict\";var n=t(\"ndarray-warp\"),i=t(\"gl-matrix-invert\");e.exports=function(t,e,r){var a=e.dimension,o=i([],r);return n(t,e,function(t,e){for(var r=0;r<a;++r){t[r]=o[(a+1)*a+r];for(var n=0;n<a;++n)t[r]+=o[(a+1)*n+r]*e[n]}var i=o[(a+1)*(a+1)-1];for(n=0;n<a;++n)i+=o[(a+1)*n+a]*e[n];var s=1/i;for(r=0;r<a;++r)t[r]*=s;return t}),t}},{\"gl-matrix-invert\":277,\"ndarray-warp\":449}],443:[function(t,e,r){\"use strict\";function n(t,e){var r=Math.floor(e),n=e-r,i=0<=r&&r<t.shape[0],a=0<=r+1&&r+1<t.shape[0];return(1-n)*(i?+t.get(r):0)+n*(a?+t.get(r+1):0)}function i(t,e,r){var n=Math.floor(e),i=e-n,a=0<=n&&n<t.shape[0],o=0<=n+1&&n+1<t.shape[0],s=Math.floor(r),l=r-s,c=0<=s&&s<t.shape[1],u=0<=s+1&&s+1<t.shape[1],h=a&&c?t.get(n,s):0,f=a&&u?t.get(n,s+1):0;return(1-l)*((1-i)*h+i*(o&&c?t.get(n+1,s):0))+l*((1-i)*f+i*(o&&u?t.get(n+1,s+1):0))}function a(t,e,r,n){var i=Math.floor(e),a=e-i,o=0<=i&&i<t.shape[0],s=0<=i+1&&i+1<t.shape[0],l=Math.floor(r),c=r-l,u=0<=l&&l<t.shape[1],h=0<=l+1&&l+1<t.shape[1],f=Math.floor(n),p=n-f,d=0<=f&&f<t.shape[2],g=0<=f+1&&f+1<t.shape[2],v=o&&u&&d?t.get(i,l,f):0,m=o&&h&&d?t.get(i,l+1,f):0,y=s&&u&&d?t.get(i+1,l,f):0,x=s&&h&&d?t.get(i+1,l+1,f):0,b=o&&u&&g?t.get(i,l,f+1):0,_=o&&h&&g?t.get(i,l+1,f+1):0;return(1-p)*((1-c)*((1-a)*v+a*y)+c*((1-a)*m+a*x))+p*((1-c)*((1-a)*b+a*(s&&u&&g?t.get(i+1,l,f+1):0))+c*((1-a)*_+a*(s&&h&&g?t.get(i+1,l+1,f+1):0)))}e.exports=function(t,e,r,o){switch(t.shape.length){case 0:return 0;case 1:return n(t,e);case 2:return i(t,e,r);case 3:return a(t,e,r,o);default:return function(t){var e,r,n=0|t.shape.length,i=new Array(n),a=new Array(n),o=new Array(n),s=new Array(n);for(e=0;e<n;++e)r=+arguments[e+1],i[e]=Math.floor(r),a[e]=r-i[e],o[e]=0<=i[e]&&i[e]<t.shape[e],s[e]=0<=i[e]+1&&i[e]+1<t.shape[e];var l,c,u,h=0;t:for(e=0;e<1<<n;++e){for(c=1,u=t.offset,l=0;l<n;++l)if(e&1<<l){if(!s[l])continue t;c*=a[l],u+=t.stride[l]*(i[l]+1)}else{if(!o[l])continue t;c*=1-a[l],u+=t.stride[l]*i[l]}h+=c*t.data[u]}return h}.apply(void 0,arguments)}},e.exports.d1=n,e.exports.d2=i,e.exports.d3=a},{}],444:[function(t,e,r){\"use strict\";var n=t(\"cwise-compiler\"),i={body:\"\",args:[],thisVars:[],localVars:[]};function a(t){if(!t)return i;for(var e=0;e<t.args.length;++e){var r=t.args[e];t.args[e]=0===e?{name:r,lvalue:!0,rvalue:!!t.rvalue,count:t.count||1}:{name:r,lvalue:!1,rvalue:!0,count:1}}return t.thisVars||(t.thisVars=[]),t.localVars||(t.localVars=[]),t}function o(t){for(var e=[],r=0;r<t.args.length;++r)e.push(\"a\"+r);return new Function(\"P\",[\"return function \",t.funcName,\"_ndarrayops(\",e.join(\",\"),\") {P(\",e.join(\",\"),\");return a0}\"].join(\"\"))(function(t){return n({args:t.args,pre:a(t.pre),body:a(t.body),post:a(t.proc),funcName:t.funcName})}(t))}var s={add:\"+\",sub:\"-\",mul:\"*\",div:\"/\",mod:\"%\",band:\"&\",bor:\"|\",bxor:\"^\",lshift:\"<<\",rshift:\">>\",rrshift:\">>>\"};!function(){for(var t in s){var e=s[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a\"+e+\"=b\"},rvalue:!0,funcName:t+\"eq\"}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a\"+e+\"=s\"},rvalue:!0,funcName:t+\"seq\"})}}();var l={not:\"!\",bnot:\"~\",neg:\"-\",recip:\"1.0/\"};!function(){for(var t in l){var e=l[t];r[t]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=\"+e+\"b\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\"],body:{args:[\"a\"],body:\"a=\"+e+\"a\"},rvalue:!0,count:2,funcName:t+\"eq\"})}}();var c={and:\"&&\",or:\"||\",eq:\"===\",neq:\"!==\",lt:\"<\",gt:\">\",leq:\"<=\",geq:\">=\"};!function(){for(var t in c){var e=c[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=a\"+e+\"b\"},rvalue:!0,count:2,funcName:t+\"eq\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a=a\"+e+\"s\"},rvalue:!0,count:2,funcName:t+\"seq\"})}}();var u=[\"abs\",\"acos\",\"asin\",\"atan\",\"ceil\",\"cos\",\"exp\",\"floor\",\"log\",\"round\",\"sin\",\"sqrt\",\"tan\"];!function(){for(var t=0;t<u.length;++t){var e=u[t];r[e]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"eq\"]=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f(a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"})}}();var h=[\"max\",\"min\",\"atan2\",\"pow\"];!function(){for(var t=0;t<h.length;++t){var e=h[t];r[e]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e+\"s\"}),r[e+\"eq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"}),r[e+\"seq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"seq\"})}}();var f=[\"atan2\",\"pow\"];!function(){for(var t=0;t<f.length;++t){var e=f[t];r[e+\"op\"]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"op\"}),r[e+\"ops\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"ops\"}),r[e+\"opeq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opeq\"}),r[e+\"opseq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opseq\"})}}(),r.any=n({args:[\"array\"],pre:i,body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"if(a){return true}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return false\"},funcName:\"any\"}),r.all=n({args:[\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1}],body:\"if(!x){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"all\"}),r.sum=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s+=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"sum\"}),r.prod=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=1\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s*=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"prod\"}),r.norm2squared=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm2squared\"}),r.norm2=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return Math.sqrt(this_s)\"},funcName:\"norm2\"}),r.norminf=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:4}],body:\"if(-a>this_s){this_s=-a}else if(a>this_s){this_s=a}\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norminf\"}),r.norm1=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:3}],body:\"this_s+=a<0?-a:a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm1\"}),r.sup=n({args:[\"array\"],pre:{body:\"this_h=-Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_>this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.inf=n({args:[\"array\"],pre:{body:\"this_h=Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_<this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.argmin=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_<this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.argmax=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=-Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_>this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.random=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.random\",thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f()\",thisVars:[\"this_f\"]},funcName:\"random\"}),r.assign=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assign\"}),r.assigns=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assigns\"}),r.equals=n({args:[\"array\",\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1},{name:\"y\",lvalue:!1,rvalue:!0,count:1}],body:\"if(x!==y){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"equals\"})},{\"cwise-compiler\":146}],445:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"./doConvert.js\");e.exports=function(t,e){for(var r=[],a=t,o=1;Array.isArray(a);)r.push(a.length),o*=a.length,a=a[0];return 0===r.length?n():(e||(e=n(new Float64Array(o),r)),i(e,t),e)}},{\"./doConvert.js\":446,ndarray:450}],446:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\nvar _inline_1_v=_inline_1_arg1_,_inline_1_i\\nfor(_inline_1_i=0;_inline_1_i<_inline_1_arg2_.length-1;++_inline_1_i) {\\n_inline_1_v=_inline_1_v[_inline_1_arg2_[_inline_1_i]]\\n}\\n_inline_1_arg0_=_inline_1_v[_inline_1_arg2_[_inline_1_arg2_.length-1]]\\n}\",args:[{name:\"_inline_1_arg0_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:4}],thisVars:[],localVars:[\"_inline_1_i\",\"_inline_1_v\"]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},funcName:\"convert\",blockSize:64})},{\"cwise-compiler\":146}],447:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=32;function a(t){switch(t){case\"uint8\":return[n.mallocUint8,n.freeUint8];case\"uint16\":return[n.mallocUint16,n.freeUint16];case\"uint32\":return[n.mallocUint32,n.freeUint32];case\"int8\":return[n.mallocInt8,n.freeInt8];case\"int16\":return[n.mallocInt16,n.freeInt16];case\"int32\":return[n.mallocInt32,n.freeInt32];case\"float32\":return[n.mallocFloat,n.freeFloat];case\"float64\":return[n.mallocDouble,n.freeDouble];default:return null}}function o(t){for(var e=[],r=0;r<t;++r)e.push(\"s\"+r);for(r=0;r<t;++r)e.push(\"n\"+r);for(r=1;r<t;++r)e.push(\"d\"+r);for(r=1;r<t;++r)e.push(\"e\"+r);for(r=1;r<t;++r)e.push(\"f\"+r);return e}e.exports=function(t,e){var r=[\"'use strict'\"],n=[\"ndarraySortWrapper\",t.join(\"d\"),e].join(\"\");r.push([\"function \",n,\"(\",[\"array\"].join(\",\"),\"){\"].join(\"\"));for(var s=[\"data=array.data,offset=array.offset|0,shape=array.shape,stride=array.stride\"],l=0;l<t.length;++l)s.push([\"s\",l,\"=stride[\",l,\"]|0,n\",l,\"=shape[\",l,\"]|0\"].join(\"\"));var c=new Array(t.length),u=[];for(l=0;l<t.length;++l)0!==(p=t[l])&&(0===u.length?c[p]=\"1\":c[p]=u.join(\"*\"),u.push(\"n\"+p));var h=-1,f=-1;for(l=0;l<t.length;++l){var p,d=t[l];0!==d&&(h>0?s.push([\"d\",d,\"=s\",d,\"-d\",h,\"*n\",h].join(\"\")):s.push([\"d\",d,\"=s\",d].join(\"\")),h=d),0!=(p=t.length-1-l)&&(f>0?s.push([\"e\",p,\"=s\",p,\"-e\",f,\"*n\",f,\",f\",p,\"=\",c[p],\"-f\",f,\"*n\",f].join(\"\")):s.push([\"e\",p,\"=s\",p,\",f\",p,\"=\",c[p]].join(\"\")),f=p)}r.push(\"var \"+s.join(\",\"));var g=[\"0\",\"n0-1\",\"data\",\"offset\"].concat(o(t.length));r.push([\"if(n0<=\",i,\"){\",\"insertionSort(\",g.join(\",\"),\")}else{\",\"quickSort(\",g.join(\",\"),\")}\"].join(\"\")),r.push(\"}return \"+n);var v=new Function(\"insertionSort\",\"quickSort\",r.join(\"\\n\")),m=function(t,e){var r=[\"'use strict'\"],n=[\"ndarrayInsertionSort\",t.join(\"d\"),e].join(\"\"),i=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),s=a(e),l=[\"i,j,cptr,ptr=left*s0+offset\"];if(t.length>1){for(var c=[],u=1;u<t.length;++u)l.push(\"i\"+u),c.push(\"n\"+u);s?l.push(\"scratch=malloc(\"+c.join(\"*\")+\")\"):l.push(\"scratch=new Array(\"+c.join(\"*\")+\")\"),l.push(\"dptr\",\"sptr\",\"a\",\"b\")}else l.push(\"scratch\");function h(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function f(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}if(r.push([\"function \",n,\"(\",i.join(\",\"),\"){var \",l.join(\",\")].join(\"\"),\"for(i=left+1;i<=right;++i){\",\"j=i;ptr+=s0\",\"cptr=ptr\"),t.length>1){for(r.push(\"dptr=0;sptr=ptr\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(\"scratch[dptr++]=\",h(\"sptr\")),u=0;u<t.length;++u)0!==(p=t[u])&&r.push(\"sptr+=d\"+p,\"}\");for(r.push(\"__g:while(j--\\x3eleft){\",\"dptr=0\",\"sptr=cptr-s0\"),u=1;u<t.length;++u)1===u&&r.push(\"__l:\"),r.push([\"for(i\",u,\"=0;i\",u,\"<n\",u,\";++i\",u,\"){\"].join(\"\"));for(r.push([\"a=\",h(\"sptr\"),\"\\nb=scratch[dptr]\\nif(a<b){break __g}\\nif(a>b){break __l}\"].join(\"\")),u=t.length-1;u>=1;--u)r.push(\"sptr+=e\"+u,\"dptr+=f\"+u,\"}\");for(r.push(\"dptr=cptr;sptr=cptr-s0\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(f(\"dptr\",h(\"sptr\"))),u=0;u<t.length;++u)0!==(p=t[u])&&r.push([\"dptr+=d\",p,\";sptr+=d\",p].join(\"\"),\"}\");for(r.push(\"cptr-=s0\\n}\"),r.push(\"dptr=cptr;sptr=0\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(f(\"dptr\",\"scratch[sptr++]\")),u=0;u<t.length;++u){var p;0!==(p=t[u])&&r.push(\"dptr+=d\"+p,\"}\")}}else r.push(\"scratch=\"+h(\"ptr\"),\"while((j--\\x3eleft)&&(\"+h(\"cptr-s0\")+\">scratch)){\",f(\"cptr\",h(\"cptr-s0\")),\"cptr-=s0\",\"}\",f(\"cptr\",\"scratch\"));return r.push(\"}\"),t.length>1&&s&&r.push(\"free(scratch)\"),r.push(\"} return \"+n),s?new Function(\"malloc\",\"free\",r.join(\"\\n\"))(s[0],s[1]):new Function(r.join(\"\\n\"))()}(t,e),y=function(t,e,r){var n=[\"'use strict'\"],s=[\"ndarrayQuickSort\",t.join(\"d\"),e].join(\"\"),l=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),c=a(e),u=0;n.push([\"function \",s,\"(\",l.join(\",\"),\"){\"].join(\"\"));var h=[\"sixth=((right-left+1)/6)|0\",\"index1=left+sixth\",\"index5=right-sixth\",\"index3=(left+right)>>1\",\"index2=index3-sixth\",\"index4=index3+sixth\",\"el1=index1\",\"el2=index2\",\"el3=index3\",\"el4=index4\",\"el5=index5\",\"less=left+1\",\"great=right-1\",\"pivots_are_equal=true\",\"tmp\",\"tmp0\",\"x\",\"y\",\"z\",\"k\",\"ptr0\",\"ptr1\",\"ptr2\",\"comp_pivot1=0\",\"comp_pivot2=0\",\"comp=0\"];if(t.length>1){for(var f=[],p=1;p<t.length;++p)f.push(\"n\"+p),h.push(\"i\"+p);for(p=0;p<8;++p)h.push(\"b_ptr\"+p);h.push(\"ptr3\",\"ptr4\",\"ptr5\",\"ptr6\",\"ptr7\",\"pivot_ptr\",\"ptr_shift\",\"elementSize=\"+f.join(\"*\")),c?h.push(\"pivot1=malloc(elementSize)\",\"pivot2=malloc(elementSize)\"):h.push(\"pivot1=new Array(elementSize),pivot2=new Array(elementSize)\")}else h.push(\"pivot1\",\"pivot2\");function d(t){return[\"(offset+\",t,\"*s0)\"].join(\"\")}function g(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function v(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}function m(e,r,i){if(1===e.length)n.push(\"ptr0=\"+d(e[0]));else for(var a=0;a<e.length;++a)n.push([\"b_ptr\",a,\"=s0*\",e[a]].join(\"\"));for(r&&n.push(\"pivot_ptr=0\"),n.push(\"ptr_shift=offset\"),a=t.length-1;a>=0;--a)0!==(o=t[a])&&n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"));if(e.length>1)for(a=0;a<e.length;++a)n.push([\"ptr\",a,\"=b_ptr\",a,\"+ptr_shift\"].join(\"\"));for(n.push(i),r&&n.push(\"++pivot_ptr\"),a=0;a<t.length;++a){var o;0!==(o=t[a])&&(e.length>1?n.push(\"ptr_shift+=d\"+o):n.push(\"ptr0+=d\"+o),n.push(\"}\"))}}function y(e,r,i,a){if(1===r.length)n.push(\"ptr0=\"+d(r[0]));else{for(var o=0;o<r.length;++o)n.push([\"b_ptr\",o,\"=s0*\",r[o]].join(\"\"));n.push(\"ptr_shift=offset\")}for(i&&n.push(\"pivot_ptr=0\"),e&&n.push(e+\":\"),o=1;o<t.length;++o)n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"));if(r.length>1)for(o=0;o<r.length;++o)n.push([\"ptr\",o,\"=b_ptr\",o,\"+ptr_shift\"].join(\"\"));for(n.push(a),o=t.length-1;o>=1;--o)i&&n.push(\"pivot_ptr+=f\"+o),r.length>1?n.push(\"ptr_shift+=e\"+o):n.push(\"ptr0+=e\"+o),n.push(\"}\")}function x(){t.length>1&&c&&n.push(\"free(pivot1)\",\"free(pivot2)\")}function b(e,r){var i=\"el\"+e,a=\"el\"+r;if(t.length>1){var o=\"__l\"+ ++u;y(o,[i,a],!1,[\"comp=\",g(\"ptr0\"),\"-\",g(\"ptr1\"),\"\\n\",\"if(comp>0){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0;break \",o,\"}\\n\",\"if(comp<0){break \",o,\"}\"].join(\"\"))}else n.push([\"if(\",g(d(i)),\">\",g(d(a)),\"){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0}\"].join(\"\"))}function _(e,r){t.length>1?m([e,r],!1,v(\"ptr0\",g(\"ptr1\"))):n.push(v(d(e),g(d(r))))}function w(e,r,i){if(t.length>1){var a=\"__l\"+ ++u;y(a,[r],!0,[e,\"=\",g(\"ptr0\"),\"-pivot\",i,\"[pivot_ptr]\\n\",\"if(\",e,\"!==0){break \",a,\"}\"].join(\"\"))}else n.push([e,\"=\",g(d(r)),\"-pivot\",i].join(\"\"))}function k(e,r){t.length>1?m([e,r],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",\"tmp\")].join(\"\")):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",\"tmp\")].join(\"\"))}function T(e,r,i){t.length>1?(m([e,r,i],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",g(\"ptr2\")),\"\\n\",v(\"ptr2\",\"tmp\")].join(\"\")),n.push(\"++\"+r,\"--\"+i)):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"ptr2=\",d(i),\"\\n\",\"++\",r,\"\\n\",\"--\",i,\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",g(\"ptr2\")),\"\\n\",v(\"ptr2\",\"tmp\")].join(\"\"))}function A(t,e){k(t,e),n.push(\"--\"+e)}function M(e,r,i){t.length>1?m([e,r],!0,[v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",[\"pivot\",i,\"[pivot_ptr]\"].join(\"\"))].join(\"\")):n.push(v(d(e),g(d(r))),v(d(r),\"pivot\"+i))}function S(e,r){n.push([\"if((\",r,\"-\",e,\")<=\",i,\"){\\n\",\"insertionSort(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}else{\\n\",s,\"(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}\"].join(\"\"))}function E(e,r,i){t.length>1?(n.push([\"__l\",++u,\":while(true){\"].join(\"\")),m([e],!0,[\"if(\",g(\"ptr0\"),\"!==pivot\",r,\"[pivot_ptr]){break __l\",u,\"}\"].join(\"\")),n.push(i,\"}\")):n.push([\"while(\",g(d(e)),\"===pivot\",r,\"){\",i,\"}\"].join(\"\"))}return n.push(\"var \"+h.join(\",\")),b(1,2),b(4,5),b(1,3),b(2,3),b(1,4),b(3,4),b(2,5),b(2,3),b(4,5),t.length>1?m([\"el1\",\"el2\",\"el3\",\"el4\",\"el5\",\"index1\",\"index3\",\"index5\"],!0,[\"pivot1[pivot_ptr]=\",g(\"ptr1\"),\"\\n\",\"pivot2[pivot_ptr]=\",g(\"ptr3\"),\"\\n\",\"pivots_are_equal=pivots_are_equal&&(pivot1[pivot_ptr]===pivot2[pivot_ptr])\\n\",\"x=\",g(\"ptr0\"),\"\\n\",\"y=\",g(\"ptr2\"),\"\\n\",\"z=\",g(\"ptr4\"),\"\\n\",v(\"ptr5\",\"x\"),\"\\n\",v(\"ptr6\",\"y\"),\"\\n\",v(\"ptr7\",\"z\")].join(\"\")):n.push([\"pivot1=\",g(d(\"el2\")),\"\\n\",\"pivot2=\",g(d(\"el4\")),\"\\n\",\"pivots_are_equal=pivot1===pivot2\\n\",\"x=\",g(d(\"el1\")),\"\\n\",\"y=\",g(d(\"el3\")),\"\\n\",\"z=\",g(d(\"el5\")),\"\\n\",v(d(\"index1\"),\"x\"),\"\\n\",v(d(\"index3\"),\"y\"),\"\\n\",v(d(\"index5\"),\"z\")].join(\"\")),_(\"index2\",\"left\"),_(\"index4\",\"right\"),n.push(\"if(pivots_are_equal){\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp\",\"k\",1),n.push(\"if(comp===0){continue}\"),n.push(\"if(comp<0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),n.push(\"while(true){\"),w(\"comp\",\"great\",1),n.push(\"if(comp>0){\"),n.push(\"great--\"),n.push(\"}else if(comp<0){\"),T(\"k\",\"less\",\"great\"),n.push(\"break\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}else{\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1<0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2>0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp>0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),T(\"k\",\"less\",\"great\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),M(\"left\",\"(less-1)\",1),M(\"right\",\"(great+1)\",2),S(\"left\",\"(less-2)\"),S(\"(great+2)\",\"right\"),n.push(\"if(pivots_are_equal){\"),x(),n.push(\"return\"),n.push(\"}\"),n.push(\"if(less<index1&&great>index5){\"),E(\"less\",1,\"++less\"),E(\"great\",2,\"--great\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1===0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2===0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp===0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),T(\"k\",\"less\",\"great\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),x(),S(\"less\",\"great\"),n.push(\"}return \"+s),t.length>1&&c?new Function(\"insertionSort\",\"malloc\",\"free\",n.join(\"\\n\"))(r,c[0],c[1]):new Function(\"insertionSort\",n.join(\"\\n\"))(r)}(t,e,m);return v(m,y)}},{\"typedarray-pool\":545}],448:[function(t,e,r){\"use strict\";var n=t(\"./lib/compile_sort.js\"),i={};e.exports=function(t){var e=t.order,r=t.dtype,a=[e,r].join(\":\"),o=i[a];return o||(i[a]=o=n(e,r)),o(t),t}},{\"./lib/compile_sort.js\":447}],449:[function(t,e,r){\"use strict\";var n=t(\"ndarray-linear-interpolate\"),i=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=new Array(_inline_3_arg4_)}\",args:[{name:\"_inline_3_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg2_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg3_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_4_arg2_(this_warped,_inline_4_arg0_),_inline_4_arg1_=_inline_4_arg3_.apply(void 0,this_warped)}\",args:[{name:\"_inline_4_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_4_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg4_\",lvalue:!1,rvalue:!1,count:0}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warpND\",blockSize:64}),a=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_7_arg2_(this_warped,_inline_7_arg0_),_inline_7_arg1_=_inline_7_arg3_(_inline_7_arg4_,this_warped[0])}\",args:[{name:\"_inline_7_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_7_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp1D\",blockSize:64}),o=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0,0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_10_arg2_(this_warped,_inline_10_arg0_),_inline_10_arg1_=_inline_10_arg3_(_inline_10_arg4_,this_warped[0],this_warped[1])}\",args:[{name:\"_inline_10_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_10_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp2D\",blockSize:64}),s=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0,0,0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_13_arg2_(this_warped,_inline_13_arg0_),_inline_13_arg1_=_inline_13_arg3_(_inline_13_arg4_,this_warped[0],this_warped[1],this_warped[2])}\",args:[{name:\"_inline_13_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_13_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp3D\",blockSize:64});e.exports=function(t,e,r){switch(e.shape.length){case 1:a(t,r,n.d1,e);break;case 2:o(t,r,n.d2,e);break;case 3:s(t,r,n.d3,e);break;default:i(t,r,n.bind(void 0,e),e.shape.length)}return t}},{\"cwise/lib/wrapper\":149,\"ndarray-linear-interpolate\":443}],450:[function(t,e,r){var n=t(\"iota-array\"),i=t(\"is-buffer\"),a=\"undefined\"!=typeof Float64Array;function o(t,e){return t[0]-e[0]}function s(){var t,e=this.stride,r=new Array(e.length);for(t=0;t<r.length;++t)r[t]=[Math.abs(e[t]),t];r.sort(o);var n=new Array(r.length);for(t=0;t<n.length;++t)n[t]=r[t][1];return n}function l(t,e){var r=[\"View\",e,\"d\",t].join(\"\");e<0&&(r=\"View_Nil\"+t);var i=\"generic\"===t;if(-1===e){var a=\"function \"+r+\"(a){this.data=a;};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return -1};proto.size=0;proto.dimension=-1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function(){return new \"+r+\"(this.data);};proto.get=proto.set=function(){};proto.pick=function(){return null};return function construct_\"+r+\"(a){return new \"+r+\"(a);}\";return new Function(a)()}if(0===e){a=\"function \"+r+\"(a,d) {this.data = a;this.offset = d};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return this.offset};proto.dimension=0;proto.size=1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function \"+r+\"_copy() {return new \"+r+\"(this.data,this.offset)};proto.pick=function \"+r+\"_pick(){return TrivialArray(this.data);};proto.valueOf=proto.get=function \"+r+\"_get(){return \"+(i?\"this.data.get(this.offset)\":\"this.data[this.offset]\")+\"};proto.set=function \"+r+\"_set(v){return \"+(i?\"this.data.set(this.offset,v)\":\"this.data[this.offset]=v\")+\"};return function construct_\"+r+\"(a,b,c,d){return new \"+r+\"(a,d)}\";return new Function(\"TrivialArray\",a)(c[t][0])}a=[\"'use strict'\"];var o=n(e),l=o.map(function(t){return\"i\"+t}),u=\"this.offset+\"+o.map(function(t){return\"this.stride[\"+t+\"]*i\"+t}).join(\"+\"),h=o.map(function(t){return\"b\"+t}).join(\",\"),f=o.map(function(t){return\"c\"+t}).join(\",\");a.push(\"function \"+r+\"(a,\"+h+\",\"+f+\",d){this.data=a\",\"this.shape=[\"+h+\"]\",\"this.stride=[\"+f+\"]\",\"this.offset=d|0}\",\"var proto=\"+r+\".prototype\",\"proto.dtype='\"+t+\"'\",\"proto.dimension=\"+e),a.push(\"Object.defineProperty(proto,'size',{get:function \"+r+\"_size(){return \"+o.map(function(t){return\"this.shape[\"+t+\"]\"}).join(\"*\"),\"}})\"),1===e?a.push(\"proto.order=[0]\"):(a.push(\"Object.defineProperty(proto,'order',{get:\"),e<4?(a.push(\"function \"+r+\"_order(){\"),2===e?a.push(\"return (Math.abs(this.stride[0])>Math.abs(this.stride[1]))?[1,0]:[0,1]}})\"):3===e&&a.push(\"var s0=Math.abs(this.stride[0]),s1=Math.abs(this.stride[1]),s2=Math.abs(this.stride[2]);if(s0>s1){if(s1>s2){return [2,1,0];}else if(s0>s2){return [1,2,0];}else{return [1,0,2];}}else if(s0>s2){return [2,0,1];}else if(s2>s1){return [0,1,2];}else{return [0,2,1];}}})\")):a.push(\"ORDER})\")),a.push(\"proto.set=function \"+r+\"_set(\"+l.join(\",\")+\",v){\"),i?a.push(\"return this.data.set(\"+u+\",v)}\"):a.push(\"return this.data[\"+u+\"]=v}\"),a.push(\"proto.get=function \"+r+\"_get(\"+l.join(\",\")+\"){\"),i?a.push(\"return this.data.get(\"+u+\")}\"):a.push(\"return this.data[\"+u+\"]}\"),a.push(\"proto.index=function \"+r+\"_index(\",l.join(),\"){return \"+u+\"}\"),a.push(\"proto.hi=function \"+r+\"_hi(\"+l.join(\",\")+\"){return new \"+r+\"(this.data,\"+o.map(function(t){return[\"(typeof i\",t,\"!=='number'||i\",t,\"<0)?this.shape[\",t,\"]:i\",t,\"|0\"].join(\"\")}).join(\",\")+\",\"+o.map(function(t){return\"this.stride[\"+t+\"]\"}).join(\",\")+\",this.offset)}\");var p=o.map(function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"}),d=o.map(function(t){return\"c\"+t+\"=this.stride[\"+t+\"]\"});a.push(\"proto.lo=function \"+r+\"_lo(\"+l.join(\",\")+\"){var b=this.offset,d=0,\"+p.join(\",\")+\",\"+d.join(\",\"));for(var g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){d=i\"+g+\"|0;b+=c\"+g+\"*d;a\"+g+\"-=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map(function(t){return\"a\"+t}).join(\",\")+\",\"+o.map(function(t){return\"c\"+t}).join(\",\")+\",b)}\"),a.push(\"proto.step=function \"+r+\"_step(\"+l.join(\",\")+\"){var \"+o.map(function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"}).join(\",\")+\",\"+o.map(function(t){return\"b\"+t+\"=this.stride[\"+t+\"]\"}).join(\",\")+\",c=this.offset,d=0,ceil=Math.ceil\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'){d=i\"+g+\"|0;if(d<0){c+=b\"+g+\"*(a\"+g+\"-1);a\"+g+\"=ceil(-a\"+g+\"/d)}else{a\"+g+\"=ceil(a\"+g+\"/d)}b\"+g+\"*=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map(function(t){return\"a\"+t}).join(\",\")+\",\"+o.map(function(t){return\"b\"+t}).join(\",\")+\",c)}\");var v=new Array(e),m=new Array(e);for(g=0;g<e;++g)v[g]=\"a[i\"+g+\"]\",m[g]=\"b[i\"+g+\"]\";a.push(\"proto.transpose=function \"+r+\"_transpose(\"+l+\"){\"+l.map(function(t,e){return t+\"=(\"+t+\"===undefined?\"+e+\":\"+t+\"|0)\"}).join(\";\"),\"var a=this.shape,b=this.stride;return new \"+r+\"(this.data,\"+v.join(\",\")+\",\"+m.join(\",\")+\",this.offset)}\"),a.push(\"proto.pick=function \"+r+\"_pick(\"+l+\"){var a=[],b=[],c=this.offset\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){c=(c+this.stride[\"+g+\"]*i\"+g+\")|0}else{a.push(this.shape[\"+g+\"]);b.push(this.stride[\"+g+\"])}\");return a.push(\"var ctor=CTOR_LIST[a.length+1];return ctor(this.data,a,b,c)}\"),a.push(\"return function construct_\"+r+\"(data,shape,stride,offset){return new \"+r+\"(data,\"+o.map(function(t){return\"shape[\"+t+\"]\"}).join(\",\")+\",\"+o.map(function(t){return\"stride[\"+t+\"]\"}).join(\",\")+\",offset)}\"),new Function(\"CTOR_LIST\",\"ORDER\",a.join(\"\\n\"))(c[t],s)}var c={float32:[],float64:[],int8:[],int16:[],int32:[],uint8:[],uint16:[],uint32:[],array:[],uint8_clamped:[],buffer:[],generic:[]};e.exports=function(t,e,r,n){if(void 0===t)return(0,c.array[0])([]);\"number\"==typeof t&&(t=[t]),void 0===e&&(e=[t.length]);var o=e.length;if(void 0===r){r=new Array(o);for(var s=o-1,u=1;s>=0;--s)r[s]=u,u*=e[s]}if(void 0===n)for(n=0,s=0;s<o;++s)r[s]<0&&(n-=(e[s]-1)*r[s]);for(var h=function(t){if(i(t))return\"buffer\";if(a)switch(Object.prototype.toString.call(t)){case\"[object Float64Array]\":return\"float64\";case\"[object Float32Array]\":return\"float32\";case\"[object Int8Array]\":return\"int8\";case\"[object Int16Array]\":return\"int16\";case\"[object Int32Array]\":return\"int32\";case\"[object Uint8Array]\":return\"uint8\";case\"[object Uint16Array]\":return\"uint16\";case\"[object Uint32Array]\":return\"uint32\";case\"[object Uint8ClampedArray]\":return\"uint8_clamped\"}return Array.isArray(t)?\"array\":\"generic\"}(t),f=c[h];f.length<=o+1;)f.push(l(h,f.length-1));return(0,f[o+1])(t,e,r,n)}},{\"iota-array\":416,\"is-buffer\":418}],451:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=Math.pow(2,-1074),a=-1>>>0;e.exports=function(t,e){if(isNaN(t)||isNaN(e))return NaN;if(t===e)return t;if(0===t)return e<0?-i:i;var r=n.hi(t),o=n.lo(t);e>t==t>0?o===a?(r+=1,o=0):o+=1:0===o?(o=a,r-=1):o-=1;return n.pack(o,r)}},{\"double-bits\":167}],452:[function(t,e,r){var n=Math.PI,i=c(120);function a(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function o(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}function s(t,e,r,a,o,c,u,h,f,p){if(p)k=p[0],T=p[1],_=p[2],w=p[3];else{var d=l(t,e,-o);t=d.x,e=d.y;var g=(t-(h=(d=l(h,f,-o)).x))/2,v=(e-(f=d.y))/2,m=g*g/(r*r)+v*v/(a*a);m>1&&(r*=m=Math.sqrt(m),a*=m);var y=r*r,x=a*a,b=(c==u?-1:1)*Math.sqrt(Math.abs((y*x-y*v*v-x*g*g)/(y*v*v+x*g*g)));b==1/0&&(b=1);var _=b*r*v/a+(t+h)/2,w=b*-a*g/r+(e+f)/2,k=Math.asin(((e-w)/a).toFixed(9)),T=Math.asin(((f-w)/a).toFixed(9));(k=t<_?n-k:k)<0&&(k=2*n+k),(T=h<_?n-T:T)<0&&(T=2*n+T),u&&k>T&&(k-=2*n),!u&&T>k&&(T-=2*n)}if(Math.abs(T-k)>i){var A=T,M=h,S=f;T=k+i*(u&&T>k?1:-1);var E=s(h=_+r*Math.cos(T),f=w+a*Math.sin(T),r,a,o,0,u,M,S,[T,A,_,w])}var C=Math.tan((T-k)/4),L=4/3*r*C,P=4/3*a*C,O=[2*t-(t+L*Math.sin(k)),2*e-(e-P*Math.cos(k)),h+L*Math.sin(T),f-P*Math.cos(T),h,f];if(p)return O;E&&(O=O.concat(E));for(var z=0;z<O.length;){var I=l(O[z],O[z+1],o);O[z++]=I.x,O[z++]=I.y}return O}function l(t,e,r){return{x:t*Math.cos(r)-e*Math.sin(r),y:t*Math.sin(r)+e*Math.cos(r)}}function c(t){return t*(n/180)}e.exports=function(t){for(var e,r=[],n=0,i=0,l=0,u=0,h=null,f=null,p=0,d=0,g=0,v=t.length;g<v;g++){var m=t[g],y=m[0];switch(y){case\"M\":l=m[1],u=m[2];break;case\"A\":(m=s(p,d,m[1],m[2],c(m[3]),m[4],m[5],m[6],m[7])).unshift(\"C\"),m.length>7&&(r.push(m.splice(0,7)),m.unshift(\"C\"));break;case\"S\":var x=p,b=d;\"C\"!=e&&\"S\"!=e||(x+=x-n,b+=b-i),m=[\"C\",x,b,m[1],m[2],m[3],m[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(h=2*p-h,f=2*d-f):(h=p,f=d),m=o(p,d,h,f,m[1],m[2]);break;case\"Q\":h=m[1],f=m[2],m=o(p,d,m[1],m[2],m[3],m[4]);break;case\"L\":m=a(p,d,m[1],m[2]);break;case\"H\":m=a(p,d,m[1],d);break;case\"V\":m=a(p,d,p,m[1]);break;case\"Z\":m=a(p,d,l,u)}e=y,p=m[m.length-2],d=m[m.length-1],m.length>4?(n=m[m.length-4],i=m[m.length-3]):(n=p,i=d),r.push(m)}return r}},{}],453:[function(t,e,r){r.vertexNormals=function(t,e,r){for(var n=e.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o)i[o]=[0,0,0];for(o=0;o<t.length;++o)for(var s=t[o],l=0,c=s[s.length-1],u=s[0],h=0;h<s.length;++h){l=c,c=u,u=s[(h+1)%s.length];for(var f=e[l],p=e[c],d=e[u],g=new Array(3),v=0,m=new Array(3),y=0,x=0;x<3;++x)g[x]=f[x]-p[x],v+=g[x]*g[x],m[x]=d[x]-p[x],y+=m[x]*m[x];if(v*y>a){var b=i[c],_=1/Math.sqrt(v*y);for(x=0;x<3;++x){var w=(x+1)%3,k=(x+2)%3;b[x]+=_*(m[w]*g[k]-m[k]*g[w])}}}for(o=0;o<n;++o){b=i[o];var T=0;for(x=0;x<3;++x)T+=b[x]*b[x];if(T>a)for(_=1/Math.sqrt(T),x=0;x<3;++x)b[x]*=_;else for(x=0;x<3;++x)b[x]=0}return i},r.faceNormals=function(t,e,r){for(var n=t.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o){for(var s=t[o],l=new Array(3),c=0;c<3;++c)l[c]=e[s[c]];var u=new Array(3),h=new Array(3);for(c=0;c<3;++c)u[c]=l[1][c]-l[0][c],h[c]=l[2][c]-l[0][c];var f=new Array(3),p=0;for(c=0;c<3;++c){var d=(c+1)%3,g=(c+2)%3;f[c]=u[d]*h[g]-u[g]*h[d],p+=f[c]*f[c]}p=p>a?1/Math.sqrt(p):0;for(c=0;c<3;++c)f[c]*=p;i[o]=f}return i}},{}],454:[function(t,e,r){\"use strict\";var n=Object.getOwnPropertySymbols,i=Object.prototype.hasOwnProperty,a=Object.prototype.propertyIsEnumerable;e.exports=function(){try{if(!Object.assign)return!1;var t=new String(\"abc\");if(t[5]=\"de\",\"5\"===Object.getOwnPropertyNames(t)[0])return!1;for(var e={},r=0;r<10;r++)e[\"_\"+String.fromCharCode(r)]=r;if(\"0123456789\"!==Object.getOwnPropertyNames(e).map(function(t){return e[t]}).join(\"\"))return!1;var n={};return\"abcdefghijklmnopqrst\".split(\"\").forEach(function(t){n[t]=t}),\"abcdefghijklmnopqrst\"===Object.keys(Object.assign({},n)).join(\"\")}catch(t){return!1}}()?Object.assign:function(t,e){for(var r,o,s=function(t){if(null==t)throw new TypeError(\"Object.assign cannot be called with null or undefined\");return Object(t)}(t),l=1;l<arguments.length;l++){for(var c in r=Object(arguments[l]))i.call(r,c)&&(s[c]=r[c]);if(n){o=n(r);for(var u=0;u<o.length;u++)a.call(r,o[u])&&(s[o[u]]=r[o[u]])}}return s}},{}],455:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a,o,s,l,c){var u=e+a+c;if(h>0){var h=Math.sqrt(u+1);t[0]=.5*(o-l)/h,t[1]=.5*(s-n)/h,t[2]=.5*(r-a)/h,t[3]=.5*h}else{var f=Math.max(e,a,c),h=Math.sqrt(2*f-u+1);e>=f?(t[0]=.5*h,t[1]=.5*(i+r)/h,t[2]=.5*(s+n)/h,t[3]=.5*(o-l)/h):a>=f?(t[0]=.5*(r+i)/h,t[1]=.5*h,t[2]=.5*(l+o)/h,t[3]=.5*(s-n)/h):(t[0]=.5*(n+s)/h,t[1]=.5*(o+l)/h,t[2]=.5*h,t[3]=.5*(r-i)/h)}return t}},{}],456:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.rotation||[0,0,0,1],n=t.radius||1;e=[].slice.call(e,0,3),u(r=[].slice.call(r,0,4),r);var i=new h(r,e,Math.log(n));i.setDistanceLimits(t.zoomMin,t.zoomMax),(\"eye\"in t||\"up\"in t)&&i.lookAt(0,t.eye,t.center,t.up);return i};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/lookAt\"),a=t(\"gl-mat4/fromQuat\"),o=t(\"gl-mat4/invert\"),s=t(\"./lib/quatFromFrame\");function l(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function c(t,e,r,n){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2)+Math.pow(n,2))}function u(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=c(r,n,i,a);o>1e-6?(t[0]=r/o,t[1]=n/o,t[2]=i/o,t[3]=a/o):(t[0]=t[1]=t[2]=0,t[3]=1)}function h(t,e,r){this.radius=n([r]),this.center=n(e),this.rotation=n(t),this.computedRadius=this.radius.curve(0),this.computedCenter=this.center.curve(0),this.computedRotation=this.rotation.curve(0),this.computedUp=[.1,0,0],this.computedEye=[.1,0,0],this.computedMatrix=[.1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],this.recalcMatrix(0)}var f=h.prototype;f.lastT=function(){return Math.max(this.radius.lastT(),this.center.lastT(),this.rotation.lastT())},f.recalcMatrix=function(t){this.radius.curve(t),this.center.curve(t),this.rotation.curve(t);var e=this.computedRotation;u(e,e);var r=this.computedMatrix;a(r,e);var n=this.computedCenter,i=this.computedEye,o=this.computedUp,s=Math.exp(this.computedRadius[0]);i[0]=n[0]+s*r[2],i[1]=n[1]+s*r[6],i[2]=n[2]+s*r[10],o[0]=r[1],o[1]=r[5],o[2]=r[9];for(var l=0;l<3;++l){for(var c=0,h=0;h<3;++h)c+=r[l+4*h]*i[h];r[12+l]=-c}},f.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r},f.idle=function(t){this.center.idle(t),this.radius.idle(t),this.rotation.idle(t)},f.flush=function(t){this.center.flush(t),this.radius.flush(t),this.rotation.flush(t)},f.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=i[1],o=i[5],s=i[9],c=l(a,o,s);a/=c,o/=c,s/=c;var u=i[0],h=i[4],f=i[8],p=u*a+h*o+f*s,d=l(u-=a*p,h-=o*p,f-=s*p);u/=d,h/=d,f/=d;var g=i[2],v=i[6],m=i[10],y=g*a+v*o+m*s,x=g*u+v*h+m*f,b=l(g-=y*a+x*u,v-=y*o+x*h,m-=y*s+x*f);g/=b,v/=b,m/=b;var _=u*e+a*r,w=h*e+o*r,k=f*e+s*r;this.center.move(t,_,w,k);var T=Math.exp(this.computedRadius[0]);T=Math.max(1e-4,T+n),this.radius.set(t,Math.log(T))},f.rotate=function(t,e,r,n){this.recalcMatrix(t),e=e||0,r=r||0;var i=this.computedMatrix,a=i[0],o=i[4],s=i[8],u=i[1],h=i[5],f=i[9],p=i[2],d=i[6],g=i[10],v=e*a+r*u,m=e*o+r*h,y=e*s+r*f,x=-(d*y-g*m),b=-(g*v-p*y),_=-(p*m-d*v),w=Math.sqrt(Math.max(0,1-Math.pow(x,2)-Math.pow(b,2)-Math.pow(_,2))),k=c(x,b,_,w);k>1e-6?(x/=k,b/=k,_/=k,w/=k):(x=b=_=0,w=1);var T=this.computedRotation,A=T[0],M=T[1],S=T[2],E=T[3],C=A*w+E*x+M*_-S*b,L=M*w+E*b+S*x-A*_,P=S*w+E*_+A*b-M*x,O=E*w-A*x-M*b-S*_;if(n){x=p,b=d,_=g;var z=Math.sin(n)/l(x,b,_);x*=z,b*=z,_*=z,O=O*(w=Math.cos(e))-(C=C*w+O*x+L*_-P*b)*x-(L=L*w+O*b+P*x-C*_)*b-(P=P*w+O*_+C*b-L*x)*_}var I=c(C,L,P,O);I>1e-6?(C/=I,L/=I,P/=I,O/=I):(C=L=P=0,O=1),this.rotation.set(t,C,L,P,O)},f.lookAt=function(t,e,r,n){this.recalcMatrix(t),r=r||this.computedCenter,e=e||this.computedEye,n=n||this.computedUp;var a=this.computedMatrix;i(a,e,r,n);var o=this.computedRotation;s(o,a[0],a[1],a[2],a[4],a[5],a[6],a[8],a[9],a[10]),u(o,o),this.rotation.set(t,o[0],o[1],o[2],o[3]);for(var l=0,c=0;c<3;++c)l+=Math.pow(r[c]-e[c],2);this.radius.set(t,.5*Math.log(Math.max(l,1e-6))),this.center.set(t,r[0],r[1],r[2])},f.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},f.setMatrix=function(t,e){var r=this.computedRotation;s(r,e[0],e[1],e[2],e[4],e[5],e[6],e[8],e[9],e[10]),u(r,r),this.rotation.set(t,r[0],r[1],r[2],r[3]);var n=this.computedMatrix;o(n,e);var i=n[15];if(Math.abs(i)>1e-6){var a=n[12]/i,l=n[13]/i,c=n[14]/i;this.recalcMatrix(t);var h=Math.exp(this.computedRadius[0]);this.center.set(t,a-n[2]*h,l-n[6]*h,c-n[10]*h),this.radius.idle(t)}else this.center.idle(t),this.radius.idle(t)},f.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},f.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},f.getDistanceLimits=function(t){var e=this.radius.bounds;return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},f.toJSON=function(){return this.recalcMatrix(this.lastT()),{center:this.computedCenter.slice(),rotation:this.computedRotation.slice(),distance:Math.log(this.computedRadius[0]),zoomMin:this.radius.bounds[0][0],zoomMax:this.radius.bounds[1][0]}},f.fromJSON=function(t){var e=this.lastT(),r=t.center;r&&this.center.set(e,r[0],r[1],r[2]);var n=t.rotation;n&&this.rotation.set(e,n[0],n[1],n[2],n[3]);var i=t.distance;i&&i>0&&this.radius.set(e,Math.log(i)),this.setDistanceLimits(t.zoomMin,t.zoomMax)}},{\"./lib/quatFromFrame\":455,\"filtered-vector\":226,\"gl-mat4/fromQuat\":262,\"gl-mat4/invert\":265,\"gl-mat4/lookAt\":266}],457:[function(t,e,r){\"use strict\";var n=t(\"repeat-string\");e.exports=function(t,e,r){return n(r=\"undefined\"!=typeof r?r+\"\":\" \",e)+t}},{\"repeat-string\":503}],458:[function(t,e,r){\"use strict\";function n(t,e){if(\"string\"!=typeof t)return[t];var r=[t];\"string\"==typeof e||Array.isArray(e)?e={brackets:e}:e||(e={});var n=e.brackets?Array.isArray(e.brackets)?e.brackets:[e.brackets]:[\"{}\",\"[]\",\"()\"],i=e.escape||\"___\",a=!!e.flat;n.forEach(function(t){var e=new RegExp([\"\\\\\",t[0],\"[^\\\\\",t[0],\"\\\\\",t[1],\"]*\\\\\",t[1]].join(\"\")),n=[];function a(e,a,o){var s=r.push(e.slice(t[0].length,-t[1].length))-1;return n.push(s),i+s+i}r.forEach(function(t,n){for(var i,o=0;t!=i;)if(i=t,t=t.replace(e,a),o++>1e4)throw Error(\"References have circular dependency. Please, check them.\");r[n]=t}),n=n.reverse(),r=r.map(function(e){return n.forEach(function(r){e=e.replace(new RegExp(\"(\\\\\"+i+r+\"\\\\\"+i+\")\",\"g\"),t[0]+\"$1\"+t[1])}),e})});var o=new RegExp(\"\\\\\"+i+\"([0-9]+)\\\\\"+i);return a?r:function t(e,r,n){for(var i,a=[],s=0;i=o.exec(e);){if(s++>1e4)throw Error(\"Circular references in parenthesis\");a.push(e.slice(0,i.index)),a.push(t(r[i[1]],r)),e=e.slice(i.index+i[0].length)}return a.push(e),a}(r[0],r)}function i(t,e){if(e&&e.flat){var r,n=e&&e.escape||\"___\",i=t[0];if(!i)return\"\";for(var a=new RegExp(\"\\\\\"+n+\"([0-9]+)\\\\\"+n),o=0;i!=r;){if(o++>1e4)throw Error(\"Circular references in \"+t);r=i,i=i.replace(a,s)}return i}return t.reduce(function t(e,r){return Array.isArray(r)&&(r=r.reduce(t,\"\")),e+r},\"\");function s(e,r){if(null==t[r])throw Error(\"Reference \"+r+\"is undefined\");return t[r]}}function a(t,e){return Array.isArray(t)?i(t,e):n(t,e)}a.parse=n,a.stringify=i,e.exports=a},{}],459:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\");e.exports=function(t){var e;arguments.length>1&&(t=arguments);\"string\"==typeof t?t=t.split(/\\s/).map(parseFloat):\"number\"==typeof t&&(t=[t]);t.length&&\"number\"==typeof t[0]?e=1===t.length?{width:t[0],height:t[0],x:0,y:0}:2===t.length?{width:t[0],height:t[1],x:0,y:0}:{x:t[0],y:t[1],width:t[2]-t[0]||0,height:t[3]-t[1]||0}:t&&(t=n(t,{left:\"x l left Left\",top:\"y t top Top\",width:\"w width W Width\",height:\"h height W Width\",bottom:\"b bottom Bottom\",right:\"r right Right\"}),e={x:t.left||0,y:t.top||0},null==t.width?t.right?e.width=t.right-e.x:e.width=0:e.width=t.width,null==t.height?t.bottom?e.height=t.bottom-e.y:e.height=0:e.height=t.height);return e}},{\"pick-by-alias\":465}],460:[function(t,e,r){e.exports=function(t){var e=[];return t.replace(i,function(t,r,i){var o=r.toLowerCase();for(i=function(t){var e=t.match(a);return e?e.map(Number):[]}(i),\"m\"==o&&i.length>2&&(e.push([r].concat(i.splice(0,2))),o=\"l\",r=\"m\"==r?\"l\":\"L\");;){if(i.length==n[o])return i.unshift(r),e.push(i);if(i.length<n[o])throw new Error(\"malformed path data\");e.push([r].concat(i.splice(0,n[o])))}}),e};var n={a:7,c:6,h:1,l:2,m:2,q:4,s:4,t:2,v:1,z:0},i=/([astvzqmhlc])([^astvzqmhlc]*)/gi;var a=/-?[0-9]*\\.?[0-9]+(?:e[-+]?\\d+)?/gi},{}],461:[function(t,e,r){e.exports=function(t,e){e||(e=[0,\"\"]),t=String(t);var r=parseFloat(t,10);return e[0]=r,e[1]=t.match(/[\\d.\\-\\+]*\\s*(.*)/)[1]||\"\",e}},{}],462:[function(t,e,r){(function(t){(function(){var r,n,i,a,o,s;\"undefined\"!=typeof performance&&null!==performance&&performance.now?e.exports=function(){return performance.now()}:\"undefined\"!=typeof t&&null!==t&&t.hrtime?(e.exports=function(){return(r()-o)/1e6},n=t.hrtime,a=(r=function(){var t;return 1e9*(t=n())[0]+t[1]})(),s=1e9*t.uptime(),o=a-s):Date.now?(e.exports=function(){return Date.now()-i},i=Date.now()):(e.exports=function(){return(new Date).getTime()-i},i=(new Date).getTime())}).call(this)}).call(this,t(\"_process\"))},{_process:482}],463:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<n){for(var r=1,a=0;a<e;++a)for(var o=0;o<a;++o)if(t[a]<t[o])r=-r;else if(t[a]===t[o])return 0;return r}for(var s=i.mallocUint8(e),a=0;a<e;++a)s[a]=0;for(var r=1,a=0;a<e;++a)if(!s[a]){var l=1;s[a]=1;for(var o=t[a];o!==a;o=t[o]){if(s[o])return i.freeUint8(s),0;l+=1,s[o]=1}1&l||(r=-r)}return i.freeUint8(s),r};var n=32,i=t(\"typedarray-pool\")},{\"typedarray-pool\":545}],464:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"invert-permutation\");r.rank=function(t){var e=t.length;switch(e){case 0:case 1:return 0;case 2:return t[1]}var r,a,o,s=n.mallocUint32(e),l=n.mallocUint32(e),c=0;for(i(t,l),o=0;o<e;++o)s[o]=t[o];for(o=e-1;o>0;--o)a=l[o],r=s[o],s[o]=s[a],s[a]=r,l[o]=l[r],l[r]=a,c=(c+r)*o;return n.freeUint32(l),n.freeUint32(s),c},r.unrank=function(t,e,r){switch(t){case 0:return r||[];case 1:return r?(r[0]=0,r):[0];case 2:return r?(e?(r[0]=0,r[1]=1):(r[0]=1,r[1]=0),r):e?[0,1]:[1,0]}var n,i,a,o=1;for((r=r||new Array(t))[0]=0,a=1;a<t;++a)r[a]=a,o=o*a|0;for(a=t-1;a>0;--a)e=e-(n=e/o|0)*o|0,o=o/a|0,i=0|r[a],r[a]=0|r[n],r[n]=0|i;return r}},{\"invert-permutation\":415,\"typedarray-pool\":545}],465:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n,a,o={};if(\"string\"==typeof e&&(e=i(e)),Array.isArray(e)){var s={};for(a=0;a<e.length;a++)s[e[a]]=!0;e=s}for(n in e)e[n]=i(e[n]);var l={};for(n in e){var c=e[n];if(Array.isArray(c))for(a=0;a<c.length;a++){var u=c[a];if(r&&(l[u]=!0),u in t){if(o[n]=t[u],r)for(var h=a;h<c.length;h++)l[c[h]]=!0;break}}else n in t&&(e[n]&&(o[n]=t[n]),r&&(l[n]=!0))}if(r)for(n in t)l[n]||(o[n]=t[n]);return o};var n={};function i(t){return n[t]?n[t]:(\"string\"==typeof t&&(t=n[t]=t.split(/\\s*,\\s*|\\s+/)),t)}},{}],466:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=0|e.length,i=t.length,a=[new Array(r),new Array(r)],o=0;o<r;++o)a[0][o]=[],a[1][o]=[];for(var o=0;o<i;++o){var s=t[o];a[0][s[0]].push(s),a[1][s[1]].push(s)}for(var l=[],o=0;o<r;++o)a[0][o].length+a[1][o].length===0&&l.push([o]);function c(t,e){var r=a[e][t[e]];r.splice(r.indexOf(t),1)}function u(t,r,i){for(var o,s,l,u=0;u<2;++u)if(a[u][r].length>0){o=a[u][r][0],l=u;break}s=o[1^l];for(var h=0;h<2;++h)for(var f=a[h][r],p=0;p<f.length;++p){var d=f[p],g=d[1^h],v=n(e[t],e[r],e[s],e[g]);v>0&&(o=d,s=g,l=h)}return i?s:(o&&c(o,l),s)}function h(t,r){var i=a[r][t][0],o=[t];c(i,r);for(var s=i[1^r];;){for(;s!==t;)o.push(s),s=u(o[o.length-2],s,!1);if(a[0][t].length+a[1][t].length===0)break;var l=o[o.length-1],h=t,f=o[1],p=u(l,h,!0);if(n(e[l],e[h],e[f],e[p])<0)break;o.push(t),s=u(l,h)}return o}function f(t,e){return e[1]===e[e.length-1]}for(var o=0;o<r;++o)for(var p=0;p<2;++p){for(var d=[];a[p][o].length>0;){a[0][o].length;var g=h(o,p);f(d,g)?d.push.apply(d,g):(d.length>0&&l.push(d),d=g)}d.length>0&&l.push(d)}return l};var n=t(\"compare-angle\")},{\"compare-angle\":127}],467:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=n(t,e.length),i=new Array(e.length),a=new Array(e.length),o=[],s=0;s<e.length;++s){var l=r[s].length;a[s]=l,i[s]=!0,l<=1&&o.push(s)}for(;o.length>0;){var c=o.pop();i[c]=!1;for(var u=r[c],s=0;s<u.length;++s){var h=u[s];0==--a[h]&&o.push(h)}}for(var f=new Array(e.length),p=[],s=0;s<e.length;++s)if(i[s]){var c=p.length;f[s]=c,p.push(e[s])}else f[s]=-1;for(var d=[],s=0;s<t.length;++s){var g=t[s];i[g[0]]&&i[g[1]]&&d.push([f[g[0]],f[g[1]]])}return[d,p]};var n=t(\"edges-to-adjacency-list\")},{\"edges-to-adjacency-list\":171}],468:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=c(t,e);t=r[0];for(var h=(e=r[1]).length,f=(t.length,n(t,e.length)),p=0;p<h;++p)if(f[p].length%2==1)throw new Error(\"planar-graph-to-polyline: graph must be manifold\");var d=i(t,e);for(var g=(d=d.filter(function(t){for(var r=t.length,n=[0],i=0;i<r;++i){var a=e[t[i]],l=e[t[(i+1)%r]],c=o(-a[0],a[1]),u=o(-a[0],l[1]),h=o(l[0],a[1]),f=o(l[0],l[1]);n=s(n,s(s(c,u),s(h,f)))}return n[n.length-1]>0})).length,v=new Array(g),m=new Array(g),p=0;p<g;++p){v[p]=p;var y=new Array(g),x=d[p].map(function(t){return e[t]}),b=a([x]),_=0;t:for(var w=0;w<g;++w)if(y[w]=0,p!==w){for(var k=d[w],T=k.length,A=0;A<T;++A){var M=b(e[k[A]]);if(0!==M){M<0&&(y[w]=1,_+=1);continue t}}y[w]=1,_+=1}m[p]=[_,p,y]}m.sort(function(t,e){return e[0]-t[0]});for(var p=0;p<g;++p)for(var y=m[p],S=y[1],E=y[2],w=0;w<g;++w)E[w]&&(v[w]=S);for(var C=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=[];return e}(g),p=0;p<g;++p)C[p].push(v[p]),C[v[p]].push(p);for(var L={},P=u(h,!1),p=0;p<g;++p)for(var k=d[p],T=k.length,w=0;w<T;++w){var O=k[w],z=k[(w+1)%T],I=Math.min(O,z)+\":\"+Math.max(O,z);if(I in L){var D=L[I];C[D].push(p),C[p].push(D),P[O]=P[z]=!0}else L[I]=p}function R(t){for(var e=t.length,r=0;r<e;++r)if(!P[t[r]])return!1;return!0}for(var F=[],B=u(g,-1),p=0;p<g;++p)v[p]!==p||R(d[p])?B[p]=-1:(F.push(p),B[p]=0);var r=[];for(;F.length>0;){var N=F.pop(),j=C[N];l(j,function(t,e){return t-e});var U,V=j.length,q=B[N];if(0===q){var k=d[N];U=[k]}for(var p=0;p<V;++p){var H=j[p];if(!(B[H]>=0)&&(B[H]=1^q,F.push(H),0===q)){var k=d[H];R(k)||(k.reverse(),U.push(k))}}0===q&&r.push(U)}return r};var n=t(\"edges-to-adjacency-list\"),i=t(\"planar-dual\"),a=t(\"point-in-big-polygon\"),o=t(\"two-product\"),s=t(\"robust-sum\"),l=t(\"uniq\"),c=t(\"./lib/trim-leaves\");function u(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}},{\"./lib/trim-leaves\":467,\"edges-to-adjacency-list\":171,\"planar-dual\":466,\"point-in-big-polygon\":472,\"robust-sum\":515,\"two-product\":543,uniq:547}],469:[function(t,e,r){\"use strict\";e.exports=t(\"./quad\")},{\"./quad\":471}],470:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],471:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"clamp\"),a=t(\"parse-rect\"),o=t(\"array-bounds\"),s=t(\"pick-by-alias\"),l=t(\"defined\"),c=t(\"flatten-vertex-data\"),u=t(\"is-obj\"),h=t(\"dtype\"),f=t(\"math-log2\");function p(t,e){for(var r=e[0],n=e[1],a=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=i((t[2*l]-r)*a,0,1),s[2*l+1]=i((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,\"float64\"),e=s(e,{bounds:\"range bounds dataBox databox\",maxDepth:\"depth maxDepth maxdepth level maxLevel maxlevel levels\",dtype:\"type dtype format out dst output destination\"});var r=l(e.maxDepth,255),i=l(e.bounds,o(t,2));i[0]===i[2]&&i[2]++,i[1]===i[3]&&i[3]++;var d,g=p(t,i),v=t.length>>>1;e.dtype||(e.dtype=\"array\"),\"string\"==typeof e.dtype?d=new(h(e.dtype))(v):e.dtype&&(d=e.dtype,Array.isArray(d)&&(d.length=v));for(var m=0;m<v;++m)d[m]=m;var y=[],x=[],b=[],_=[];!function t(e,n,i,a,o,s){if(!a.length)return null;var l=y[o]||(y[o]=[]);var c=b[o]||(b[o]=[]);var u=x[o]||(x[o]=[]);var h=l.length;o++;if(o>r){for(var f=0;f<a.length;f++)l.push(a[f]),c.push(s),u.push(null,null,null,null);return h}l.push(a[0]);c.push(s);if(a.length<=1)return u.push(null,null,null,null),h;var p=.5*i;var d=e+p,v=n+p;var m=[],_=[],w=[],k=[];for(var T=1,A=a.length;T<A;T++){var M=a[T],S=g[2*M],E=g[2*M+1];S<d?E<v?m.push(M):_.push(M):E<v?w.push(M):k.push(M)}s<<=2;u.push(t(e,n,p,m,o,s),t(e,v,p,_,o,s+1),t(d,n,p,w,o,s+2),t(d,v,p,k,o,s+3));return h}(0,0,1,d,0,1);for(var w=0,k=0;k<y.length;k++){var T=y[k];if(d.set)d.set(T,w);else for(var A=0,M=T.length;A<M;A++)d[A+w]=T[A];var S=w+y[k].length;_[k]=[w,S],w=S}return d.range=function(){var e,r=[],o=arguments.length;for(;o--;)r[o]=arguments[o];if(u(r[r.length-1])){var c=r.pop();r.length||null==c.x&&null==c.l&&null==c.left||(r=[c],e={}),e=s(c,{level:\"level maxLevel\",d:\"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize\",lod:\"lod details ranges offsets\"})}else e={};r.length||(r=i);var h=a.apply(void 0,r),d=[Math.min(h.x,h.x+h.width),Math.min(h.y,h.y+h.height),Math.max(h.x,h.x+h.width),Math.max(h.y,h.y+h.height)],g=d[0],v=d[1],m=d[2],w=d[3],k=p([g,v,m,w],i),T=k[0],A=k[1],M=k[2],S=k[3],C=l(e.level,y.length);if(null!=e.d){var L;\"number\"==typeof e.d?L=[e.d,e.d]:e.d.length&&(L=e.d),C=Math.min(Math.max(Math.ceil(-f(Math.abs(L[0])/(i[2]-i[0]))),Math.ceil(-f(Math.abs(L[1])/(i[3]-i[1])))),C)}if(C=Math.min(C,y.length),e.lod)return function(t,e,r,i,a){for(var o=[],s=0;s<a;s++){var l=b[s],c=_[s][0],u=E(t,e,s),h=E(r,i,s),f=n.ge(l,u),p=n.gt(l,h,f,l.length-1);o[s]=[f+c,p+c]}return o}(T,A,M,S,C);var P=[];return function e(r,n,i,a,o,s){if(null!==o&&null!==s){var l=r+i,c=n+i;if(!(T>l||A>c||M<r||S<n||a>=C||o===s)){var u=y[a];void 0===s&&(s=u.length);for(var h=o;h<s;h++){var f=u[h],p=t[2*f],d=t[2*f+1];p>=g&&p<=m&&d>=v&&d<=w&&P.push(f)}var b=x[a],_=b[4*o+0],k=b[4*o+1],E=b[4*o+2],L=b[4*o+3],O=function(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}(b,o+1),z=.5*i,I=a+1;e(r,n,z,I,_,k||E||L||O),e(r,n+z,z,I,k,E||L||O),e(r+z,n,z,I,E,L||O),e(r+z,n+z,z,I,L,O)}}}(0,0,1,0,0,1),P},d;function E(t,e,r){for(var n=1,i=.5,a=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<i?e<a?0:1:e<a?2:3,o*=.5,i+=t<i?-o:o,a+=e<a?-o:o;return n}}},{\"array-bounds\":65,\"binary-search-bounds\":470,clamp:115,defined:164,dtype:169,\"flatten-vertex-data\":227,\"is-obj\":421,\"math-log2\":432,\"parse-rect\":459,\"pick-by-alias\":465}],472:[function(t,e,r){e.exports=function(t){for(var e=t.length,r=[],a=[],s=0;s<e;++s)for(var u=t[s],h=u.length,f=h-1,p=0;p<h;f=p++){var d=u[f],g=u[p];d[0]===g[0]?a.push([d,g]):r.push([d,g])}if(0===r.length)return 0===a.length?c:(v=l(a),function(t){return v(t[0],t[1])?0:1});var v;var m=i(r),y=function(t,e){return function(r){var i=o.le(e,r[0]);if(i<0)return 1;var a=t[i];if(!a){if(!(i>0&&e[i]===r[0]))return 1;a=t[i-1]}for(var s=1;a;){var l=a.key,c=n(r,l[0],l[1]);if(l[0][0]<l[1][0])if(c<0)a=a.left;else{if(!(c>0))return 0;s=-1,a=a.right}else if(c>0)a=a.left;else{if(!(c<0))return 0;s=1,a=a.right}}return s}}(m.slabs,m.coordinates);return 0===a.length?y:function(t,e){return function(r){return t(r[0],r[1])?0:e(r)}}(l(a),y)};var n=t(\"robust-orientation\")[3],i=t(\"slab-decomposition\"),a=t(\"interval-tree-1d\"),o=t(\"binary-search-bounds\");function s(){return!0}function l(t){for(var e={},r=0;r<t.length;++r){var n=t[r],i=n[0][0],o=n[0][1],l=n[1][1],c=[Math.min(o,l),Math.max(o,l)];i in e?e[i].push(c):e[i]=[c]}var u={},h=Object.keys(e);for(r=0;r<h.length;++r){var f=e[h[r]];u[h[r]]=a(f)}return function(t){return function(e,r){var n=t[e];return!!n&&!!n.queryPoint(r,s)}}(u)}function c(t){return 1}},{\"binary-search-bounds\":91,\"interval-tree-1d\":414,\"robust-orientation\":510,\"slab-decomposition\":526}],473:[function(t,e,r){var n,i=t(\"./lib/build-log\"),a=t(\"./lib/epsilon\"),o=t(\"./lib/intersecter\"),s=t(\"./lib/segment-chainer\"),l=t(\"./lib/segment-selector\"),c=t(\"./lib/geojson\"),u=!1,h=a();function f(t,e,r){var i=n.segments(t),a=n.segments(e),o=r(n.combine(i,a));return n.polygon(o)}n={buildLog:function(t){return!0===t?u=i():!1===t&&(u=!1),!1!==u&&u.list},epsilon:function(t){return h.epsilon(t)},segments:function(t){var e=o(!0,h,u);return t.regions.forEach(e.addRegion),{segments:e.calculate(t.inverted),inverted:t.inverted}},combine:function(t,e){return{combined:o(!1,h,u).calculate(t.segments,t.inverted,e.segments,e.inverted),inverted1:t.inverted,inverted2:e.inverted}},selectUnion:function(t){return{segments:l.union(t.combined,u),inverted:t.inverted1||t.inverted2}},selectIntersect:function(t){return{segments:l.intersect(t.combined,u),inverted:t.inverted1&&t.inverted2}},selectDifference:function(t){return{segments:l.difference(t.combined,u),inverted:t.inverted1&&!t.inverted2}},selectDifferenceRev:function(t){return{segments:l.differenceRev(t.combined,u),inverted:!t.inverted1&&t.inverted2}},selectXor:function(t){return{segments:l.xor(t.combined,u),inverted:t.inverted1!==t.inverted2}},polygon:function(t){return{regions:s(t.segments,h,u),inverted:t.inverted}},polygonFromGeoJSON:function(t){return c.toPolygon(n,t)},polygonToGeoJSON:function(t){return c.fromPolygon(n,h,t)},union:function(t,e){return f(t,e,n.selectUnion)},intersect:function(t,e){return f(t,e,n.selectIntersect)},difference:function(t,e){return f(t,e,n.selectDifference)},differenceRev:function(t,e){return f(t,e,n.selectDifferenceRev)},xor:function(t,e){return f(t,e,n.selectXor)}},\"object\"==typeof window&&(window.PolyBool=n),e.exports=n},{\"./lib/build-log\":474,\"./lib/epsilon\":475,\"./lib/geojson\":476,\"./lib/intersecter\":477,\"./lib/segment-chainer\":479,\"./lib/segment-selector\":480}],474:[function(t,e,r){e.exports=function(){var t,e=0,r=!1;function n(e,r){return t.list.push({type:e,data:r?JSON.parse(JSON.stringify(r)):void 0}),t}return t={list:[],segmentId:function(){return e++},checkIntersection:function(t,e){return n(\"check\",{seg1:t,seg2:e})},segmentChop:function(t,e){return n(\"div_seg\",{seg:t,pt:e}),n(\"chop\",{seg:t,pt:e})},statusRemove:function(t){return n(\"pop_seg\",{seg:t})},segmentUpdate:function(t){return n(\"seg_update\",{seg:t})},segmentNew:function(t,e){return n(\"new_seg\",{seg:t,primary:e})},segmentRemove:function(t){return n(\"rem_seg\",{seg:t})},tempStatus:function(t,e,r){return n(\"temp_status\",{seg:t,above:e,below:r})},rewind:function(t){return n(\"rewind\",{seg:t})},status:function(t,e,r){return n(\"status\",{seg:t,above:e,below:r})},vert:function(e){return e===r?t:(r=e,n(\"vert\",{x:e}))},log:function(t){return\"string\"!=typeof t&&(t=JSON.stringify(t,!1,\"  \")),n(\"log\",{txt:t})},reset:function(){return n(\"reset\")},selected:function(t){return n(\"selected\",{segs:t})},chainStart:function(t){return n(\"chain_start\",{seg:t})},chainRemoveHead:function(t,e){return n(\"chain_rem_head\",{index:t,pt:e})},chainRemoveTail:function(t,e){return n(\"chain_rem_tail\",{index:t,pt:e})},chainNew:function(t,e){return n(\"chain_new\",{pt1:t,pt2:e})},chainMatch:function(t){return n(\"chain_match\",{index:t})},chainClose:function(t){return n(\"chain_close\",{index:t})},chainAddHead:function(t,e){return n(\"chain_add_head\",{index:t,pt:e})},chainAddTail:function(t,e){return n(\"chain_add_tail\",{index:t,pt:e})},chainConnect:function(t,e){return n(\"chain_con\",{index1:t,index2:e})},chainReverse:function(t){return n(\"chain_rev\",{index:t})},chainJoin:function(t,e){return n(\"chain_join\",{index1:t,index2:e})},done:function(){return n(\"done\")}}}},{}],475:[function(t,e,r){e.exports=function(t){\"number\"!=typeof t&&(t=1e-10);var e={epsilon:function(e){return\"number\"==typeof e&&(t=e),t},pointAboveOrOnLine:function(e,r,n){var i=r[0],a=r[1],o=n[0],s=n[1],l=e[0];return(o-i)*(e[1]-a)-(s-a)*(l-i)>=-t},pointBetween:function(e,r,n){var i=e[1]-r[1],a=n[0]-r[0],o=e[0]-r[0],s=n[1]-r[1],l=o*a+i*s;return!(l<t||l-(a*a+s*s)>-t)},pointsSameX:function(e,r){return Math.abs(e[0]-r[0])<t},pointsSameY:function(e,r){return Math.abs(e[1]-r[1])<t},pointsSame:function(t,r){return e.pointsSameX(t,r)&&e.pointsSameY(t,r)},pointsCompare:function(t,r){return e.pointsSameX(t,r)?e.pointsSameY(t,r)?0:t[1]<r[1]?-1:1:t[0]<r[0]?-1:1},pointsCollinear:function(e,r,n){var i=e[0]-r[0],a=e[1]-r[1],o=r[0]-n[0],s=r[1]-n[1];return Math.abs(i*s-o*a)<t},linesIntersect:function(e,r,n,i){var a=r[0]-e[0],o=r[1]-e[1],s=i[0]-n[0],l=i[1]-n[1],c=a*l-o*s;if(Math.abs(c)<t)return!1;var u=e[0]-n[0],h=e[1]-n[1],f=(s*h-l*u)/c,p=(a*h-o*u)/c,d={alongA:0,alongB:0,pt:[e[0]+f*a,e[1]+f*o]};return d.alongA=f<=-t?-2:f<t?-1:f-1<=-t?0:f-1<t?1:2,d.alongB=p<=-t?-2:p<t?-1:p-1<=-t?0:p-1<t?1:2,d},pointInsideRegion:function(e,r){for(var n=e[0],i=e[1],a=r[r.length-1][0],o=r[r.length-1][1],s=!1,l=0;l<r.length;l++){var c=r[l][0],u=r[l][1];u-i>t!=o-i>t&&(a-c)*(i-u)/(o-u)+c-n>t&&(s=!s),a=c,o=u}return s}};return e}},{}],476:[function(t,e,r){var n={toPolygon:function(t,e){function r(e){if(e.length<=0)return t.segments({inverted:!1,regions:[]});function r(e){var r=e.slice(0,e.length-1);return t.segments({inverted:!1,regions:[r]})}for(var n=r(e[0]),i=1;i<e.length;i++)n=t.selectDifference(t.combine(n,r(e[i])));return n}if(\"Polygon\"===e.type)return t.polygon(r(e.coordinates));if(\"MultiPolygon\"===e.type){for(var n=t.segments({inverted:!1,regions:[]}),i=0;i<e.coordinates.length;i++)n=t.selectUnion(t.combine(n,r(e.coordinates[i])));return t.polygon(n)}throw new Error(\"PolyBool: Cannot convert GeoJSON object to PolyBool polygon\")},fromPolygon:function(t,e,r){function n(t,r){return e.pointInsideRegion([.5*(t[0][0]+t[1][0]),.5*(t[0][1]+t[1][1])],r)}function i(t){return{region:t,children:[]}}r=t.polygon(t.segments(r));var a=i(null);function o(t,e){for(var r=0;r<t.children.length;r++){if(n(e,(s=t.children[r]).region))return void o(s,e)}var a=i(e);for(r=0;r<t.children.length;r++){var s;n((s=t.children[r]).region,e)&&(a.children.push(s),t.children.splice(r,1),r--)}t.children.push(a)}for(var s=0;s<r.regions.length;s++){var l=r.regions[s];l.length<3||o(a,l)}function c(t,e){for(var r=0,n=t[t.length-1][0],i=t[t.length-1][1],a=[],o=0;o<t.length;o++){var s=t[o][0],l=t[o][1];a.push([s,l]),r+=l*n-s*i,n=s,i=l}return r<0!==e&&a.reverse(),a.push([a[0][0],a[0][1]]),a}var u=[];function h(t){var e=[c(t.region,!1)];u.push(e);for(var r=0;r<t.children.length;r++)e.push(f(t.children[r]))}function f(t){for(var e=0;e<t.children.length;e++)h(t.children[e]);return c(t.region,!0)}for(s=0;s<a.children.length;s++)h(a.children[s]);return u.length<=0?{type:\"Polygon\",coordinates:[]}:1==u.length?{type:\"Polygon\",coordinates:u[0]}:{type:\"MultiPolygon\",coordinates:u}}};e.exports=n},{}],477:[function(t,e,r){var n=t(\"./linked-list\");e.exports=function(t,e,r){function i(t,e,n){return{id:r?r.segmentId():-1,start:t,end:e,myFill:{above:n.myFill.above,below:n.myFill.below},otherFill:null}}var a=n.create();function o(t,r){a.insertBefore(t,function(n){return function(t,r,n,i,a,o){var s=e.pointsCompare(r,a);return 0!==s?s:e.pointsSame(n,o)?0:t!==i?t?1:-1:e.pointAboveOrOnLine(n,i?a:o,i?o:a)?1:-1}(t.isStart,t.pt,r,n.isStart,n.pt,n.other.pt)<0})}function s(t,e){var r=function(t,e){var r=n.node({isStart:!0,pt:t.start,seg:t,primary:e,other:null,status:null});return o(r,t.end),r}(t,e);return function(t,e,r){var i=n.node({isStart:!1,pt:e.end,seg:e,primary:r,other:t,status:null});t.other=i,o(i,t.pt)}(r,t,e),r}function l(t,e){var n=i(e,t.seg.end,t.seg);return function(t,e){r&&r.segmentChop(t.seg,e),t.other.remove(),t.seg.end=e,t.other.pt=e,o(t.other,t.pt)}(t,e),s(n,t.primary)}function c(i,o){var s=n.create();function c(t){return s.findTransition(function(r){var n,i,a,o,s,l;return n=t,i=r.ev,a=n.seg.start,o=n.seg.end,s=i.seg.start,l=i.seg.end,(e.pointsCollinear(a,s,l)?e.pointsCollinear(o,s,l)?1:e.pointAboveOrOnLine(o,s,l)?1:-1:e.pointAboveOrOnLine(a,s,l)?1:-1)>0})}function u(t,n){var i=t.seg,a=n.seg,o=i.start,s=i.end,c=a.start,u=a.end;r&&r.checkIntersection(i,a);var h=e.linesIntersect(o,s,c,u);if(!1===h){if(!e.pointsCollinear(o,s,c))return!1;if(e.pointsSame(o,u)||e.pointsSame(s,c))return!1;var f=e.pointsSame(o,c),p=e.pointsSame(s,u);if(f&&p)return n;var d=!f&&e.pointBetween(o,c,u),g=!p&&e.pointBetween(s,c,u);if(f)return g?l(n,s):l(t,u),n;d&&(p||(g?l(n,s):l(t,u)),l(n,o))}else 0===h.alongA&&(-1===h.alongB?l(t,c):0===h.alongB?l(t,h.pt):1===h.alongB&&l(t,u)),0===h.alongB&&(-1===h.alongA?l(n,o):0===h.alongA?l(n,h.pt):1===h.alongA&&l(n,s));return!1}for(var h=[];!a.isEmpty();){var f=a.getHead();if(r&&r.vert(f.pt[0]),f.isStart){r&&r.segmentNew(f.seg,f.primary);var p=c(f),d=p.before?p.before.ev:null,g=p.after?p.after.ev:null;function v(){if(d){var t=u(f,d);if(t)return t}return!!g&&u(f,g)}r&&r.tempStatus(f.seg,!!d&&d.seg,!!g&&g.seg);var m,y,x=v();if(x)t?(y=null===f.seg.myFill.below||f.seg.myFill.above!==f.seg.myFill.below)&&(x.seg.myFill.above=!x.seg.myFill.above):x.seg.otherFill=f.seg.myFill,r&&r.segmentUpdate(x.seg),f.other.remove(),f.remove();if(a.getHead()!==f){r&&r.rewind(f.seg);continue}t?(y=null===f.seg.myFill.below||f.seg.myFill.above!==f.seg.myFill.below,f.seg.myFill.below=g?g.seg.myFill.above:i,f.seg.myFill.above=y?!f.seg.myFill.below:f.seg.myFill.below):null===f.seg.otherFill&&(m=g?f.primary===g.primary?g.seg.otherFill.above:g.seg.myFill.above:f.primary?o:i,f.seg.otherFill={above:m,below:m}),r&&r.status(f.seg,!!d&&d.seg,!!g&&g.seg),f.other.status=p.insert(n.node({ev:f}))}else{var b=f.status;if(null===b)throw new Error(\"PolyBool: Zero-length segment detected; your epsilon is probably too small or too large\");if(s.exists(b.prev)&&s.exists(b.next)&&u(b.prev.ev,b.next.ev),r&&r.statusRemove(b.ev.seg),b.remove(),!f.primary){var _=f.seg.myFill;f.seg.myFill=f.seg.otherFill,f.seg.otherFill=_}h.push(f.seg)}a.getHead().remove()}return r&&r.done(),h}return t?{addRegion:function(t){for(var n,i,a,o=t[t.length-1],l=0;l<t.length;l++){n=o,o=t[l];var c=e.pointsCompare(n,o);0!==c&&s((i=c<0?n:o,a=c<0?o:n,{id:r?r.segmentId():-1,start:i,end:a,myFill:{above:null,below:null},otherFill:null}),!0)}},calculate:function(t){return c(t,!1)}}:{calculate:function(t,e,r,n){return t.forEach(function(t){s(i(t.start,t.end,t),!0)}),r.forEach(function(t){s(i(t.start,t.end,t),!1)}),c(e,n)}}}},{\"./linked-list\":478}],478:[function(t,e,r){e.exports={create:function(){var t={root:{root:!0,next:null},exists:function(e){return null!==e&&e!==t.root},isEmpty:function(){return null===t.root.next},getHead:function(){return t.root.next},insertBefore:function(e,r){for(var n=t.root,i=t.root.next;null!==i;){if(r(i))return e.prev=i.prev,e.next=i,i.prev.next=e,void(i.prev=e);n=i,i=i.next}n.next=e,e.prev=n,e.next=null},findTransition:function(e){for(var r=t.root,n=t.root.next;null!==n&&!e(n);)r=n,n=n.next;return{before:r===t.root?null:r,after:n,insert:function(t){return t.prev=r,t.next=n,r.next=t,null!==n&&(n.prev=t),t}}}};return t},node:function(t){return t.prev=null,t.next=null,t.remove=function(){t.prev.next=t.next,t.next&&(t.next.prev=t.prev),t.prev=null,t.next=null},t}}},{}],479:[function(t,e,r){e.exports=function(t,e,r){var n=[],i=[];return t.forEach(function(t){var a=t.start,o=t.end;if(e.pointsSame(a,o))console.warn(\"PolyBool: Warning: Zero-length segment detected; your epsilon is probably too small or too large\");else{r&&r.chainStart(t);for(var s={index:0,matches_head:!1,matches_pt1:!1},l={index:0,matches_head:!1,matches_pt1:!1},c=s,u=0;u<n.length;u++){var h=(v=n[u])[0],f=(v[1],v[v.length-1]);if(v[v.length-2],e.pointsSame(h,a)){if(T(u,!0,!0))break}else if(e.pointsSame(h,o)){if(T(u,!0,!1))break}else if(e.pointsSame(f,a)){if(T(u,!1,!0))break}else if(e.pointsSame(f,o)&&T(u,!1,!1))break}if(c===s)return n.push([a,o]),void(r&&r.chainNew(a,o));if(c===l){r&&r.chainMatch(s.index);var p=s.index,d=s.matches_pt1?o:a,g=s.matches_head,v=n[p],m=g?v[0]:v[v.length-1],y=g?v[1]:v[v.length-2],x=g?v[v.length-1]:v[0],b=g?v[v.length-2]:v[1];return e.pointsCollinear(y,m,d)&&(g?(r&&r.chainRemoveHead(s.index,d),v.shift()):(r&&r.chainRemoveTail(s.index,d),v.pop()),m=y),e.pointsSame(x,d)?(n.splice(p,1),e.pointsCollinear(b,x,m)&&(g?(r&&r.chainRemoveTail(s.index,m),v.pop()):(r&&r.chainRemoveHead(s.index,m),v.shift())),r&&r.chainClose(s.index),void i.push(v)):void(g?(r&&r.chainAddHead(s.index,d),v.unshift(d)):(r&&r.chainAddTail(s.index,d),v.push(d)))}var _=s.index,w=l.index;r&&r.chainConnect(_,w);var k=n[_].length<n[w].length;s.matches_head?l.matches_head?k?(A(_),M(_,w)):(A(w),M(w,_)):M(w,_):l.matches_head?M(_,w):k?(A(_),M(w,_)):(A(w),M(_,w))}function T(t,e,r){return c.index=t,c.matches_head=e,c.matches_pt1=r,c===s?(c=l,!1):(c=null,!0)}function A(t){r&&r.chainReverse(t),n[t].reverse()}function M(t,i){var a=n[t],o=n[i],s=a[a.length-1],l=a[a.length-2],c=o[0],u=o[1];e.pointsCollinear(l,s,c)&&(r&&r.chainRemoveTail(t,s),a.pop(),s=l),e.pointsCollinear(s,c,u)&&(r&&r.chainRemoveHead(i,c),o.shift()),r&&r.chainJoin(t,i),n[t]=a.concat(o),n.splice(i,1)}}),i}},{}],480:[function(t,e,r){function n(t,e,r){var n=[];return t.forEach(function(t){var i=(t.myFill.above?8:0)+(t.myFill.below?4:0)+(t.otherFill&&t.otherFill.above?2:0)+(t.otherFill&&t.otherFill.below?1:0);0!==e[i]&&n.push({id:r?r.segmentId():-1,start:t.start,end:t.end,myFill:{above:1===e[i],below:2===e[i]},otherFill:null})}),r&&r.selected(n),n}var i={union:function(t,e){return n(t,[0,2,1,0,2,2,0,0,1,0,1,0,0,0,0,0],e)},intersect:function(t,e){return n(t,[0,0,0,0,0,2,0,2,0,0,1,1,0,2,1,0],e)},difference:function(t,e){return n(t,[0,0,0,0,2,0,2,0,1,1,0,0,0,1,2,0],e)},differenceRev:function(t,e){return n(t,[0,2,1,0,0,0,1,1,0,2,0,2,0,0,0,0],e)},xor:function(t,e){return n(t,[0,2,1,0,2,0,0,1,1,0,0,2,0,1,2,0],e)}};e.exports=i},{}],481:[function(t,e,r){\"use strict\";var n=new Float64Array(4),i=new Float64Array(4),a=new Float64Array(4);e.exports=function(t,e,r,o,s){n.length<o.length&&(n=new Float64Array(o.length),i=new Float64Array(o.length),a=new Float64Array(o.length));for(var l=0;l<o.length;++l)n[l]=t[l]-o[l],i[l]=e[l]-t[l],a[l]=r[l]-t[l];var c=0,u=0,h=0,f=0,p=0,d=0;for(l=0;l<o.length;++l){var g=i[l],v=a[l],m=n[l];c+=g*g,u+=g*v,h+=v*v,f+=m*g,p+=m*v,d+=m*m}var y,x,b,_,w,k=Math.abs(c*h-u*u),T=u*p-h*f,A=u*f-c*p;if(T+A<=k)if(T<0)A<0&&f<0?(A=0,-f>=c?(T=1,y=c+2*f+d):y=f*(T=-f/c)+d):(T=0,p>=0?(A=0,y=d):-p>=h?(A=1,y=h+2*p+d):y=p*(A=-p/h)+d);else if(A<0)A=0,f>=0?(T=0,y=d):-f>=c?(T=1,y=c+2*f+d):y=f*(T=-f/c)+d;else{var M=1/k;y=(T*=M)*(c*T+u*(A*=M)+2*f)+A*(u*T+h*A+2*p)+d}else T<0?(b=h+p)>(x=u+f)?(_=b-x)>=(w=c-2*u+h)?(T=1,A=0,y=c+2*f+d):y=(T=_/w)*(c*T+u*(A=1-T)+2*f)+A*(u*T+h*A+2*p)+d:(T=0,b<=0?(A=1,y=h+2*p+d):p>=0?(A=0,y=d):y=p*(A=-p/h)+d):A<0?(b=c+f)>(x=u+p)?(_=b-x)>=(w=c-2*u+h)?(A=1,T=0,y=h+2*p+d):y=(T=1-(A=_/w))*(c*T+u*A+2*f)+A*(u*T+h*A+2*p)+d:(A=0,b<=0?(T=1,y=c+2*f+d):f>=0?(T=0,y=d):y=f*(T=-f/c)+d):(_=h+p-u-f)<=0?(T=0,A=1,y=h+2*p+d):_>=(w=c-2*u+h)?(T=1,A=0,y=c+2*f+d):y=(T=_/w)*(c*T+u*(A=1-T)+2*f)+A*(u*T+h*A+2*p)+d;var S=1-T-A;for(l=0;l<o.length;++l)s[l]=S*t[l]+T*e[l]+A*r[l];return y<0?0:y}},{}],482:[function(t,e,r){var n,i,a=e.exports={};function o(){throw new Error(\"setTimeout has not been defined\")}function s(){throw new Error(\"clearTimeout has not been defined\")}function l(t){if(n===setTimeout)return setTimeout(t,0);if((n===o||!n)&&setTimeout)return n=setTimeout,setTimeout(t,0);try{return n(t,0)}catch(e){try{return n.call(null,t,0)}catch(e){return n.call(this,t,0)}}}!function(){try{n=\"function\"==typeof setTimeout?setTimeout:o}catch(t){n=o}try{i=\"function\"==typeof clearTimeout?clearTimeout:s}catch(t){i=s}}();var c,u=[],h=!1,f=-1;function p(){h&&c&&(h=!1,c.length?u=c.concat(u):f=-1,u.length&&d())}function d(){if(!h){var t=l(p);h=!0;for(var e=u.length;e;){for(c=u,u=[];++f<e;)c&&c[f].run();f=-1,e=u.length}c=null,h=!1,function(t){if(i===clearTimeout)return clearTimeout(t);if((i===s||!i)&&clearTimeout)return i=clearTimeout,clearTimeout(t);try{i(t)}catch(e){try{return i.call(null,t)}catch(e){return i.call(this,t)}}}(t)}}function g(t,e){this.fun=t,this.array=e}function v(){}a.nextTick=function(t){var e=new Array(arguments.length-1);if(arguments.length>1)for(var r=1;r<arguments.length;r++)e[r-1]=arguments[r];u.push(new g(t,e)),1!==u.length||h||l(d)},g.prototype.run=function(){this.fun.apply(null,this.array)},a.title=\"browser\",a.browser=!0,a.env={},a.argv=[],a.version=\"\",a.versions={},a.on=v,a.addListener=v,a.once=v,a.off=v,a.removeListener=v,a.removeAllListeners=v,a.emit=v,a.prependListener=v,a.prependOnceListener=v,a.listeners=function(t){return[]},a.binding=function(t){throw new Error(\"process.binding is not supported\")},a.cwd=function(){return\"/\"},a.chdir=function(t){throw new Error(\"process.chdir is not supported\")},a.umask=function(){return 0}},{}],483:[function(t,e,r){e.exports=t(\"gl-quat/slerp\")},{\"gl-quat/slerp\":293}],484:[function(t,e,r){(function(r){for(var n=t(\"performance-now\"),i=\"undefined\"==typeof window?r:window,a=[\"moz\",\"webkit\"],o=\"AnimationFrame\",s=i[\"request\"+o],l=i[\"cancel\"+o]||i[\"cancelRequest\"+o],c=0;!s&&c<a.length;c++)s=i[a[c]+\"Request\"+o],l=i[a[c]+\"Cancel\"+o]||i[a[c]+\"CancelRequest\"+o];if(!s||!l){var u=0,h=0,f=[];s=function(t){if(0===f.length){var e=n(),r=Math.max(0,1e3/60-(e-u));u=r+e,setTimeout(function(){var t=f.slice(0);f.length=0;for(var e=0;e<t.length;e++)if(!t[e].cancelled)try{t[e].callback(u)}catch(t){setTimeout(function(){throw t},0)}},Math.round(r))}return f.push({handle:++h,callback:t,cancelled:!1}),h},l=function(t){for(var e=0;e<f.length;e++)f[e].handle===t&&(f[e].cancelled=!0)}}e.exports=function(t){return s.call(i,t)},e.exports.cancel=function(){l.apply(i,arguments)},e.exports.polyfill=function(t){t||(t=i),t.requestAnimationFrame=s,t.cancelAnimationFrame=l}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"performance-now\":462}],485:[function(t,e,r){\"use strict\";var n=t(\"big-rat/add\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/add\":75}],486:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t.length),r=0;r<t.length;++r)e[r]=n(t[r]);return e};var n=t(\"big-rat\")},{\"big-rat\":78}],487:[function(t,e,r){\"use strict\";var n=t(\"big-rat\"),i=t(\"big-rat/mul\");e.exports=function(t,e){for(var r=n(e),a=t.length,o=new Array(a),s=0;s<a;++s)o[s]=i(t[s],r);return o}},{\"big-rat\":78,\"big-rat/mul\":87}],488:[function(t,e,r){\"use strict\";var n=t(\"big-rat/sub\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/sub\":89}],489:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"compare-oriented-cell\"),a=t(\"cell-orientation\");e.exports=function(t){t.sort(i);for(var e=t.length,r=0,o=0;o<e;++o){var s=t[o],l=a(s);if(0!==l){if(r>0){var c=t[r-1];if(0===n(s,c)&&a(c)!==l){r-=1;continue}}t[r++]=s}}return t.length=r,t}},{\"cell-orientation\":112,\"compare-cell\":128,\"compare-oriented-cell\":129}],490:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\"),i=t(\"color-normalize\"),a=t(\"update-diff\"),o=t(\"pick-by-alias\"),s=t(\"object-assign\"),l=t(\"flatten-vertex-data\"),c=t(\"to-float32\"),u=c.float32,h=c.fract32;e.exports=function(t,e){\"function\"==typeof t?(e||(e={}),e.regl=t):e=t;e.length&&(e.positions=e);if(!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");var r,c,p,d,g,v,m=t._gl,y={color:\"black\",capSize:5,lineWidth:1,opacity:1,viewport:null,range:null,offset:0,count:0,bounds:null,positions:[],errors:[]},x=[];return d=t.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array(0)}),c=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),p=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),g=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),v=t.buffer({usage:\"static\",type:\"float\",data:f}),k(e),r=t({vert:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tattribute vec2 position, positionFract;\\n\\t\\tattribute vec4 error;\\n\\t\\tattribute vec4 color;\\n\\n\\t\\tattribute vec2 direction, lineOffset, capOffset;\\n\\n\\t\\tuniform vec4 viewport;\\n\\t\\tuniform float lineWidth, capSize;\\n\\t\\tuniform vec2 scale, scaleFract, translate, translateFract;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tfragColor = color / 255.;\\n\\n\\t\\t\\tvec2 pixelOffset = lineWidth * lineOffset + (capSize + lineWidth) * capOffset;\\n\\n\\t\\t\\tvec2 dxy = -step(.5, direction.xy) * error.xz + step(direction.xy, vec2(-.5)) * error.yw;\\n\\n\\t\\t\\tvec2 position = position + dxy;\\n\\n\\t\\t\\tvec2 pos = (position + translate) * scale\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scale\\n\\t\\t\\t\\t+ (position + translate) * scaleFract\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scaleFract;\\n\\n\\t\\t\\tpos += pixelOffset / viewport.zw;\\n\\n\\t\\t\\tgl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\t\\t}\\n\\t\\t\",frag:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tuniform float opacity;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tgl_FragColor = fragColor;\\n\\t\\t\\tgl_FragColor.a *= opacity;\\n\\t\\t}\\n\\t\\t\",uniforms:{range:t.prop(\"range\"),lineWidth:t.prop(\"lineWidth\"),capSize:t.prop(\"capSize\"),opacity:t.prop(\"opacity\"),scale:t.prop(\"scale\"),translate:t.prop(\"translate\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{color:{buffer:d,offset:function(t,e){return 4*e.offset},divisor:1},position:{buffer:c,offset:function(t,e){return 8*e.offset},divisor:1},positionFract:{buffer:p,offset:function(t,e){return 8*e.offset},divisor:1},error:{buffer:g,offset:function(t,e){return 16*e.offset},divisor:1},direction:{buffer:v,stride:24,offset:0},lineOffset:{buffer:v,stride:24,offset:8},capOffset:{buffer:v,stride:24,offset:16}},primitive:\"triangles\",blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:!1,instances:t.prop(\"count\"),count:f.length}),s(b,{update:k,draw:_,destroy:T,regl:t,gl:m,canvas:m.canvas,groups:x}),b;function b(t){t?k(t):null===t&&T(),_()}function _(e){if(\"number\"==typeof e)return w(e);e&&!Array.isArray(e)&&(e=[e]),t._refresh(),x.forEach(function(t,r){t&&(e&&(e[r]?t.draw=!0:t.draw=!1),t.draw?w(r):t.draw=!0)})}function w(t){\"number\"==typeof t&&(t=x[t]),null!=t&&t&&t.count&&t.color&&t.opacity&&t.positions&&t.positions.length>1&&(t.scaleRatio=[t.scale[0]*t.viewport.width,t.scale[1]*t.viewport.height],r(t),t.after&&t.after(t))}function k(t){if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var e=0,r=0;if(b.groups=x=t.map(function(t,c){var u=x[c];return t?(\"function\"==typeof t?t={after:t}:\"number\"==typeof t[0]&&(t={positions:t}),t=o(t,{color:\"color colors fill\",capSize:\"capSize cap capsize cap-size\",lineWidth:\"lineWidth line-width width line thickness\",opacity:\"opacity alpha\",range:\"range dataBox\",viewport:\"viewport viewBox\",errors:\"errors error\",positions:\"positions position data points\"}),u||(x[c]=u={id:c,scale:null,translate:null,scaleFract:null,translateFract:null,draw:!0},t=s({},y,t)),a(u,t,[{lineWidth:function(t){return.5*+t},capSize:function(t){return.5*+t},opacity:parseFloat,errors:function(t){return t=l(t),r+=t.length,t},positions:function(t,r){return t=l(t,\"float64\"),r.count=Math.floor(t.length/2),r.bounds=n(t,2),r.offset=e,e+=r.count,t}},{color:function(t,e){var r=e.count;if(t||(t=\"transparent\"),!Array.isArray(t)||\"number\"==typeof t[0]){var n=t;t=Array(r);for(var a=0;a<r;a++)t[a]=n}if(t.length<r)throw Error(\"Not enough colors\");for(var o=new Uint8Array(4*r),s=0;s<r;s++){var l=i(t[s],\"uint8\");o.set(l,4*s)}return o},range:function(t,e,r){var n=e.bounds;return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=h(e.scale),e.translateFract=h(e.translate),t},viewport:function(t){var e;return Array.isArray(t)?e={x:t[0],y:t[1],width:t[2]-t[0],height:t[3]-t[1]}:t?(e={x:t.x||t.left||0,y:t.y||t.top||0},t.right?e.width=t.right-e.x:e.width=t.w||t.width||0,t.bottom?e.height=t.bottom-e.y:e.height=t.h||t.height||0):e={x:0,y:0,width:m.drawingBufferWidth,height:m.drawingBufferHeight},e}}]),u):u}),e||r){var f=x.reduce(function(t,e,r){return t+(e?e.count:0)},0),v=new Float64Array(2*f),_=new Uint8Array(4*f),w=new Float32Array(4*f);x.forEach(function(t,e){if(t){var r=t.positions,n=t.count,i=t.offset,a=t.color,o=t.errors;n&&(_.set(a,4*i),w.set(o,4*i),v.set(r,2*i))}}),c(u(v)),p(h(v)),d(_),g(w)}}}function T(){c.destroy(),p.destroy(),d.destroy(),g.destroy(),v.destroy()}};var f=[[1,0,0,1,0,0],[1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,1,0,0],[1,0,0,1,0,0],[1,0,-1,0,0,1],[1,0,-1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,1],[1,0,-1,0,0,1],[-1,0,-1,0,0,1],[-1,0,-1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,1],[-1,0,-1,0,0,1],[0,1,1,0,0,0],[0,1,-1,0,0,0],[0,-1,-1,0,0,0],[0,-1,-1,0,0,0],[0,1,1,0,0,0],[0,-1,1,0,0,0],[0,1,0,-1,1,0],[0,1,0,-1,-1,0],[0,1,0,1,-1,0],[0,1,0,1,1,0],[0,1,0,-1,1,0],[0,1,0,1,-1,0],[0,-1,0,-1,1,0],[0,-1,0,-1,-1,0],[0,-1,0,1,-1,0],[0,-1,0,1,1,0],[0,-1,0,-1,1,0],[0,-1,0,1,-1,0]]},{\"array-bounds\":65,\"color-normalize\":120,\"flatten-vertex-data\":227,\"object-assign\":454,\"pick-by-alias\":465,\"to-float32\":538,\"update-diff\":549}],491:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\"),i=t(\"array-bounds\"),a=t(\"object-assign\"),o=t(\"glslify\"),s=t(\"pick-by-alias\"),l=t(\"flatten-vertex-data\"),c=t(\"earcut\"),u=t(\"array-normalize\"),h=t(\"to-float32\"),f=h.float32,p=h.fract32,d=t(\"es6-weak-map\"),g=t(\"parse-rect\");function v(t,e){if(!(this instanceof v))return new v(t,e);if(\"function\"==typeof t?(e||(e={}),e.regl=t):e=t,e.length&&(e.positions=e),!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");this.gl=t._gl,this.regl=t,this.passes=[],this.shaders=v.shaders.has(t)?v.shaders.get(t):v.shaders.set(t,v.createShaders(t)).get(t),this.update(e)}e.exports=v,v.dashMult=2,v.maxPatternLength=256,v.precisionThreshold=3e6,v.maxPoints=1e4,v.maxLines=2048,v.shaders=new d,v.createShaders=function(t){var e,r=t.buffer({usage:\"static\",type:\"float\",data:[0,1,0,0,1,1,1,0]}),n={primitive:\"triangle strip\",instances:t.prop(\"count\"),count:4,offset:0,uniforms:{miterMode:function(t,e){return\"round\"===e.join?2:1},miterLimit:t.prop(\"miterLimit\"),scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),thickness:t.prop(\"thickness\"),dashPattern:t.prop(\"dashTexture\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),dashSize:t.prop(\"dashLength\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]},depth:t.prop(\"depth\")},blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:function(t,e){return!e.overlay}},stencil:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\")},i=t(a({vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, aCoordFract, bCoordFract;\\nattribute vec4 color;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvec2 project(vec2 position, vec2 positionFract, vec2 scale, vec2 scaleFract, vec2 translate, vec2 translateFract) {\\n\\t// the order is important\\n\\treturn position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n}\\n\\nvoid main() {\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineOffset = lineTop * 2. - 1.;\\n\\n\\tvec2 diff = (bCoord + bCoordFract - aCoord - aCoordFract);\\n\\ttangent = normalize(diff * scale * viewport.zw);\\n\\tvec2 normal = vec2(-tangent.y, tangent.x);\\n\\n\\tvec2 position = project(aCoord, aCoordFract, scale, scaleFract, translate, translateFract) * lineStart\\n\\t\\t+ project(bCoord, bCoordFract, scale, scaleFract, translate, translateFract) * lineEnd\\n\\n\\t\\t+ thickness * normal * .5 * lineOffset / viewport.zw;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\n\\nuniform float dashSize, pixelRatio, thickness, opacity, id;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvoid main() {\\n\\tfloat alpha = 1.;\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},aCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8,divisor:1},bCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:16,divisor:1},color:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1}}},n));try{e=t(a({cull:{enable:!0,face:\"back\"},vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, nextCoord, prevCoord;\\nattribute vec4 aColor, bColor;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, translate;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\nuniform float miterLimit, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 tangent;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nconst float REVERSE_THRESHOLD = -.875;\\nconst float MIN_DIFF = 1e-6;\\n\\n// TODO: possible optimizations: avoid overcalculating all for vertices and calc just one instead\\n// TODO: precalculate dot products, normalize things beforehead etc.\\n// TODO: refactor to rectangular algorithm\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nbool isNaN( float val ){\\n  return ( val < 0.0 || 0.0 < val || val == 0.0 ) ? false : true;\\n}\\n\\nvoid main() {\\n\\tvec2 aCoord = aCoord, bCoord = bCoord, prevCoord = prevCoord, nextCoord = nextCoord;\\n\\n  vec2 adjustedScale;\\n  adjustedScale.x = (abs(scale.x) < MIN_DIFF) ? MIN_DIFF : scale.x;\\n  adjustedScale.y = (abs(scale.y) < MIN_DIFF) ? MIN_DIFF : scale.y;\\n\\n  vec2 scaleRatio = adjustedScale * viewport.zw;\\n\\tvec2 normalWidth = thickness / scaleRatio;\\n\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineBot = 1. - lineTop;\\n\\n\\tfragColor = (lineStart * aColor + lineEnd * bColor) / 255.;\\n\\n\\tif (isNaN(aCoord.x) || isNaN(aCoord.y) || isNaN(bCoord.x) || isNaN(bCoord.y)) return;\\n\\n\\tif (aCoord == prevCoord) prevCoord = aCoord + normalize(bCoord - aCoord);\\n\\tif (bCoord == nextCoord) nextCoord = bCoord - normalize(bCoord - aCoord);\\n\\n\\tvec2 prevDiff = aCoord - prevCoord;\\n\\tvec2 currDiff = bCoord - aCoord;\\n\\tvec2 nextDiff = nextCoord - bCoord;\\n\\n\\tvec2 prevTangent = normalize(prevDiff * scaleRatio);\\n\\tvec2 currTangent = normalize(currDiff * scaleRatio);\\n\\tvec2 nextTangent = normalize(nextDiff * scaleRatio);\\n\\n\\tvec2 prevNormal = vec2(-prevTangent.y, prevTangent.x);\\n\\tvec2 currNormal = vec2(-currTangent.y, currTangent.x);\\n\\tvec2 nextNormal = vec2(-nextTangent.y, nextTangent.x);\\n\\n\\tvec2 startJoinDirection = normalize(prevTangent - currTangent);\\n\\tvec2 endJoinDirection = normalize(currTangent - nextTangent);\\n\\n\\t// collapsed/unidirectional segment cases\\n\\t// FIXME: there should be more elegant solution\\n\\tvec2 prevTanDiff = abs(prevTangent - currTangent);\\n\\tvec2 nextTanDiff = abs(nextTangent - currTangent);\\n\\tif (max(prevTanDiff.x, prevTanDiff.y) < MIN_DIFF) {\\n\\t\\tstartJoinDirection = currNormal;\\n\\t}\\n\\tif (max(nextTanDiff.x, nextTanDiff.y) < MIN_DIFF) {\\n\\t\\tendJoinDirection = currNormal;\\n\\t}\\n\\tif (aCoord == bCoord) {\\n\\t\\tendJoinDirection = startJoinDirection;\\n\\t\\tcurrNormal = prevNormal;\\n\\t\\tcurrTangent = prevTangent;\\n\\t}\\n\\n\\ttangent = currTangent;\\n\\n\\t//calculate join shifts relative to normals\\n\\tfloat startJoinShift = dot(currNormal, startJoinDirection);\\n\\tfloat endJoinShift = dot(currNormal, endJoinDirection);\\n\\n\\tfloat startMiterRatio = abs(1. / startJoinShift);\\n\\tfloat endMiterRatio = abs(1. / endJoinShift);\\n\\n\\tvec2 startJoin = startJoinDirection * startMiterRatio;\\n\\tvec2 endJoin = endJoinDirection * endMiterRatio;\\n\\n\\tvec2 startTopJoin, startBotJoin, endTopJoin, endBotJoin;\\n\\tstartTopJoin = sign(startJoinShift) * startJoin * .5;\\n\\tstartBotJoin = -startTopJoin;\\n\\n\\tendTopJoin = sign(endJoinShift) * endJoin * .5;\\n\\tendBotJoin = -endTopJoin;\\n\\n\\tvec2 aTopCoord = aCoord + normalWidth * startTopJoin;\\n\\tvec2 bTopCoord = bCoord + normalWidth * endTopJoin;\\n\\tvec2 aBotCoord = aCoord + normalWidth * startBotJoin;\\n\\tvec2 bBotCoord = bCoord + normalWidth * endBotJoin;\\n\\n\\t//miter anti-clipping\\n\\tfloat baClipping = distToLine(bCoord, aCoord, aBotCoord) / dot(normalize(normalWidth * endBotJoin), normalize(normalWidth.yx * vec2(-startBotJoin.y, startBotJoin.x)));\\n\\tfloat abClipping = distToLine(aCoord, bCoord, bTopCoord) / dot(normalize(normalWidth * startBotJoin), normalize(normalWidth.yx * vec2(-endBotJoin.y, endBotJoin.x)));\\n\\n\\t//prevent close to reverse direction switch\\n\\tbool prevReverse = dot(currTangent, prevTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, prevNormal)) * min(length(prevDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\tbool nextReverse = dot(currTangent, nextTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, nextNormal)) * min(length(nextDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\n\\tif (prevReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * startJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / startMiterRatio, 1.);\\n\\t\\taBotCoord = aCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\taTopCoord = aCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!nextReverse && baClipping > 0. && baClipping < length(normalWidth * endBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\tbTopCoord -= normalWidth * endTopJoin;\\n\\t\\tbTopCoord += normalize(endTopJoin * normalWidth) * baClipping;\\n\\t}\\n\\n\\tif (nextReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * endJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / endMiterRatio, 1.);\\n\\t\\tbBotCoord = bCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\tbTopCoord = bCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!prevReverse && abClipping > 0. && abClipping < length(normalWidth * startBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\taBotCoord -= normalWidth * startBotJoin;\\n\\t\\taBotCoord += normalize(startBotJoin * normalWidth) * abClipping;\\n\\t}\\n\\n\\tvec2 aTopPosition = (aTopCoord) * adjustedScale + translate;\\n\\tvec2 aBotPosition = (aBotCoord) * adjustedScale + translate;\\n\\n\\tvec2 bTopPosition = (bTopCoord) * adjustedScale + translate;\\n\\tvec2 bBotPosition = (bBotCoord) * adjustedScale + translate;\\n\\n\\t//position is normalized 0..1 coord on the screen\\n\\tvec2 position = (aTopPosition * lineTop + aBotPosition * lineBot) * lineStart + (bTopPosition * lineTop + bBotPosition * lineBot) * lineEnd;\\n\\n\\tstartCoord = aCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\tendCoord = bCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\n\\tgl_Position = vec4(position  * 2.0 - 1.0, depth, 1);\\n\\n\\tenableStartMiter = step(dot(currTangent, prevTangent), .5);\\n\\tenableEndMiter = step(dot(currTangent, nextTangent), .5);\\n\\n\\t//bevel miter cutoffs\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n\\n\\t//round miter cutoffs\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * abs(dot(startJoinDirection, currNormal)) * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * abs(dot(endJoinDirection, currNormal)) * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\nuniform float dashSize, pixelRatio, thickness, opacity, id, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nvoid main() {\\n\\tfloat alpha = 1., distToStart, distToEnd;\\n\\tfloat cutoff = thickness * .5;\\n\\n\\t//bevel miter\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToStart + 1., 0.), 1.);\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToEnd + 1., 0.), 1.);\\n\\t\\t}\\n\\t}\\n\\n\\t// round miter\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - startCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - endCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\t}\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1},bColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:4,divisor:1},prevCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:0,divisor:1},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},nextCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:24,divisor:1}}},n))}catch(t){e=i}return{fill:t({primitive:\"triangle\",elements:function(t,e){return e.triangles},offset:0,vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position, positionFract;\\n\\nuniform vec4 color;\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio, id;\\nuniform vec4 viewport;\\nuniform float opacity;\\n\\nvarying vec4 fragColor;\\n\\nconst float MAX_LINES = 256.;\\n\\nvoid main() {\\n\\tfloat depth = (MAX_LINES - 4. - id) / (MAX_LINES);\\n\\n\\tvec2 position = position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n\\tfragColor.a *= opacity;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n\\tgl_FragColor = fragColor;\\n}\\n\"]),uniforms:{scale:t.prop(\"scale\"),color:t.prop(\"fill\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{position:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8},positionFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8}},blend:n.blend,depth:{enable:!1},scissor:n.scissor,stencil:n.stencil,viewport:n.viewport}),rect:i,miter:e}},v.defaults={dashes:null,join:\"miter\",miterLimit:1,thickness:10,cap:\"square\",color:\"black\",opacity:1,overlay:!1,viewport:null,range:null,close:!1,fill:null},v.prototype.render=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];e.length&&(t=this).update.apply(t,e),this.draw()},v.prototype.draw=function(){for(var t=this,e=[],r=arguments.length;r--;)e[r]=arguments[r];return(e.length?e:this.passes).forEach(function(e,r){var n;if(e&&Array.isArray(e))return(n=t).draw.apply(n,e);\"number\"==typeof e&&(e=t.passes[e]),e&&e.count>1&&e.opacity&&(t.regl._refresh(),e.fill&&e.triangles&&e.triangles.length>2&&t.shaders.fill(e),e.thickness&&(e.scale[0]*e.viewport.width>v.precisionThreshold||e.scale[1]*e.viewport.height>v.precisionThreshold?t.shaders.rect(e):\"rect\"===e.join||!e.join&&(e.thickness<=2||e.count>=v.maxPoints)?t.shaders.rect(e):t.shaders.miter(e)))}),this},v.prototype.update=function(t){var e=this;if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var r=this.regl,o=this.gl;if(t.forEach(function(t,h){var d=e.passes[h];if(void 0!==t)if(null!==t){if(\"number\"==typeof t[0]&&(t={positions:t}),t=s(t,{positions:\"positions points data coords\",thickness:\"thickness lineWidth lineWidths line-width linewidth width stroke-width strokewidth strokeWidth\",join:\"lineJoin linejoin join type mode\",miterLimit:\"miterlimit miterLimit\",dashes:\"dash dashes dasharray dash-array dashArray\",color:\"color colour stroke colors colours stroke-color strokeColor\",fill:\"fill fill-color fillColor\",opacity:\"alpha opacity\",overlay:\"overlay crease overlap intersect\",close:\"closed close closed-path closePath\",range:\"range dataBox\",viewport:\"viewport viewBox\",hole:\"holes hole hollow\"}),d||(e.passes[h]=d={id:h,scale:null,scaleFract:null,translate:null,translateFract:null,count:0,hole:[],depth:0,dashLength:1,dashTexture:r.texture({channels:1,data:new Uint8Array([255]),width:1,height:1,mag:\"linear\",min:\"linear\"}),colorBuffer:r.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array}),positionBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),positionFractBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array})},t=a({},v.defaults,t)),null!=t.thickness&&(d.thickness=parseFloat(t.thickness)),null!=t.opacity&&(d.opacity=parseFloat(t.opacity)),null!=t.miterLimit&&(d.miterLimit=parseFloat(t.miterLimit)),null!=t.overlay&&(d.overlay=!!t.overlay,h<v.maxLines&&(d.depth=2*(v.maxLines-1-h%v.maxLines)/v.maxLines-1)),null!=t.join&&(d.join=t.join),null!=t.hole&&(d.hole=t.hole),null!=t.fill&&(d.fill=t.fill?n(t.fill,\"uint8\"):null),null!=t.viewport&&(d.viewport=g(t.viewport)),d.viewport||(d.viewport=g([o.drawingBufferWidth,o.drawingBufferHeight])),null!=t.close&&(d.close=t.close),null===t.positions&&(t.positions=[]),t.positions){var m,y;if(t.positions.x&&t.positions.y){var x=t.positions.x,b=t.positions.y;y=d.count=Math.max(x.length,b.length),m=new Float64Array(2*y);for(var _=0;_<y;_++)m[2*_]=x[_],m[2*_+1]=b[_]}else m=l(t.positions,\"float64\"),y=d.count=Math.floor(m.length/2);var w=d.bounds=i(m,2);if(d.fill){for(var k=[],T={},A=0,M=0,S=0,E=d.count;M<E;M++){var C=m[2*M],L=m[2*M+1];isNaN(C)||isNaN(L)||null==C||null==L?(C=m[2*A],L=m[2*A+1],T[M]=A):A=M,k[S++]=C,k[S++]=L}for(var P=c(k,d.hole||[]),O=0,z=P.length;O<z;O++)null!=T[P[O]]&&(P[O]=T[P[O]]);d.triangles=P}var I=new Float64Array(m);u(I,2,w);var D=new Float64Array(2*y+6);d.close?m[0]===m[2*y-2]&&m[1]===m[2*y-1]?(D[0]=I[2*y-4],D[1]=I[2*y-3]):(D[0]=I[2*y-2],D[1]=I[2*y-1]):(D[0]=I[0],D[1]=I[1]),D.set(I,2),d.close?m[0]===m[2*y-2]&&m[1]===m[2*y-1]?(D[2*y+2]=I[2],D[2*y+3]=I[3],d.count-=1):(D[2*y+2]=I[0],D[2*y+3]=I[1],D[2*y+4]=I[2],D[2*y+5]=I[3]):(D[2*y+2]=I[2*y-2],D[2*y+3]=I[2*y-1],D[2*y+4]=I[2*y-2],D[2*y+5]=I[2*y-1]),d.positionBuffer(f(D)),d.positionFractBuffer(p(D))}if(t.range?d.range=t.range:d.range||(d.range=d.bounds),(t.range||t.positions)&&d.count){var R=d.bounds,F=R[2]-R[0],B=R[3]-R[1],N=d.range[2]-d.range[0],j=d.range[3]-d.range[1];d.scale=[F/N,B/j],d.translate=[-d.range[0]/N+R[0]/N||0,-d.range[1]/j+R[1]/j||0],d.scaleFract=p(d.scale),d.translateFract=p(d.translate)}if(t.dashes){var U,V=0;if(!t.dashes||t.dashes.length<2)V=1,U=new Uint8Array([255,255,255,255,255,255,255,255]);else{V=0;for(var q=0;q<t.dashes.length;++q)V+=t.dashes[q];U=new Uint8Array(V*v.dashMult);for(var H=0,G=255,Y=0;Y<2;Y++)for(var W=0;W<t.dashes.length;++W){for(var X=0,Z=t.dashes[W]*v.dashMult*.5;X<Z;++X)U[H++]=G;G^=255}}d.dashLength=V,d.dashTexture({channels:1,data:U,width:U.length,height:1,mag:\"linear\",min:\"linear\"},0,0)}if(t.color){var J=d.count,K=t.color;K||(K=\"transparent\");var $=new Uint8Array(4*J+4);if(Array.isArray(K)&&\"number\"!=typeof K[0]){for(var Q=0;Q<J;Q++){var tt=n(K[Q],\"uint8\");$.set(tt,4*Q)}$.set(n(K[0],\"uint8\"),4*J)}else for(var et=n(K,\"uint8\"),rt=0;rt<J+1;rt++)$.set(et,4*rt);d.colorBuffer({usage:\"dynamic\",type:\"uint8\",data:$})}}else e.passes[h]=null}),t.length<this.passes.length){for(var h=t.length;h<this.passes.length;h++){var d=e.passes[h];d&&(d.colorBuffer.destroy(),d.positionBuffer.destroy(),d.dashTexture.destroy())}this.passes.length=t.length}for(var m=[],y=0;y<this.passes.length;y++)null!==e.passes[y]&&m.push(e.passes[y]);return this.passes=m,this}},v.prototype.destroy=function(){return this.passes.forEach(function(t){t.colorBuffer.destroy(),t.positionBuffer.destroy(),t.dashTexture.destroy()}),this.passes.length=0,this}},{\"array-bounds\":65,\"array-normalize\":66,\"color-normalize\":120,earcut:492,\"es6-weak-map\":493,\"flatten-vertex-data\":227,glslify:409,\"object-assign\":454,\"parse-rect\":459,\"pick-by-alias\":465,\"to-float32\":538}],492:[function(t,e,r){\"use strict\";function n(t,e,r){r=r||2;var n,s,l,c,u,p,g,v=e&&e.length,m=v?e[0]*r:t.length,y=i(t,0,m,r,!0),x=[];if(!y||y.next===y.prev)return x;if(v&&(y=function(t,e,r,n){var o,s,l,c,u,p=[];for(o=0,s=e.length;o<s;o++)l=e[o]*n,c=o<s-1?e[o+1]*n:t.length,(u=i(t,l,c,n,!1))===u.next&&(u.steiner=!0),p.push(d(u));for(p.sort(h),o=0;o<p.length;o++)f(p[o],r),r=a(r,r.next);return r}(t,e,y,r)),t.length>80*r){n=l=t[0],s=c=t[1];for(var b=r;b<m;b+=r)(u=t[b])<n&&(n=u),(p=t[b+1])<s&&(s=p),u>l&&(l=u),p>c&&(c=p);g=0!==(g=Math.max(l-n,c-s))?1/g:0}return o(y,x,r,n,s,g),x}function i(t,e,r,n,i){var a,o;if(i===A(t,e,r,n)>0)for(a=e;a<r;a+=n)o=w(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=w(a,t[a],t[a+1],o);return o&&y(o,o.next)&&(k(o),o=o.next),o}function a(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!y(n,n.next)&&0!==m(n.prev,n,n.next))n=n.next;else{if(k(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function o(t,e,r,n,i,h,f){if(t){!f&&h&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=p(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,h);for(var d,g,v=t;t.prev!==t.next;)if(d=t.prev,g=t.next,h?l(t,n,i,h):s(t))e.push(d.i/r),e.push(t.i/r),e.push(g.i/r),k(t),t=g.next,v=g.next;else if((t=g)===v){f?1===f?o(t=c(t,e,r),e,r,n,i,h,2):2===f&&u(t,e,r,n,i,h):o(a(t),e,r,n,i,h,1);break}}}function s(t){var e=t.prev,r=t,n=t.next;if(m(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(g(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&m(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function l(t,e,r,n){var i=t.prev,a=t,o=t.next;if(m(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,h=p(s,l,e,r,n),f=p(c,u,e,r,n),d=t.prevZ,v=t.nextZ;d&&d.z>=h&&v&&v.z<=f;){if(d!==t.prev&&d!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&m(d.prev,d,d.next)>=0)return!1;if(d=d.prevZ,v!==t.prev&&v!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,v.x,v.y)&&m(v.prev,v,v.next)>=0)return!1;v=v.nextZ}for(;d&&d.z>=h;){if(d!==t.prev&&d!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&m(d.prev,d,d.next)>=0)return!1;d=d.prevZ}for(;v&&v.z<=f;){if(v!==t.prev&&v!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,v.x,v.y)&&m(v.prev,v,v.next)>=0)return!1;v=v.nextZ}return!0}function c(t,e,r){var n=t;do{var i=n.prev,a=n.next.next;!y(i,a)&&x(i,n,n.next,a)&&b(i,a)&&b(a,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(a.i/r),k(n),k(n.next),n=t=a),n=n.next}while(n!==t);return n}function u(t,e,r,n,i,s){var l=t;do{for(var c=l.next.next;c!==l.prev;){if(l.i!==c.i&&v(l,c)){var u=_(l,c);return l=a(l,l.next),u=a(u,u.next),o(l,e,r,n,i,s),void o(u,e,r,n,i,s)}c=c.next}l=l.next}while(l!==t)}function h(t,e){return t.x-e.x}function f(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r.prev;var l,c=r,u=r.x,h=r.y,f=1/0;n=r.next;for(;n!==c;)i>=n.x&&n.x>=u&&i!==n.x&&g(a<h?i:o,a,u,h,a<h?o:i,a,n.x,n.y)&&((l=Math.abs(a-n.y)/(i-n.x))<f||l===f&&n.x>r.x)&&b(n,t)&&(r=n,f=l),n=n.next;return r}(t,e)){var r=_(e,t);a(r,r.next)}}function p(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function d(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function g(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function v(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&x(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&b(t,e)&&b(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)}function m(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function y(t,e){return t.x===e.x&&t.y===e.y}function x(t,e,r,n){return!!(y(t,e)&&y(r,n)||y(t,n)&&y(r,e))||m(t,e,r)>0!=m(t,e,n)>0&&m(r,n,t)>0!=m(r,n,e)>0}function b(t,e){return m(t.prev,t,t.next)<0?m(t,e,t.next)>=0&&m(t,t.prev,e)>=0:m(t,e,t.prev)<0||m(t,t.next,e)<0}function _(t,e){var r=new T(t.i,t.x,t.y),n=new T(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function w(t,e,r,n){var i=new T(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function k(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function T(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function A(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}e.exports=n,e.exports.default=n,n.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(A(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(A(t,c,u,r))}var h=0;for(s=0;s<n.length;s+=3){var f=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;h+=Math.abs((t[f]-t[d])*(t[p+1]-t[f+1])-(t[f]-t[p])*(t[d+1]-t[f+1]))}return 0===o&&0===h?0:Math.abs((h-o)/o)},n.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r}},{}],493:[function(t,e,r){arguments[4][318][0].apply(r,arguments)},{\"./is-implemented\":494,\"./polyfill\":496,dup:318}],494:[function(t,e,r){arguments[4][319][0].apply(r,arguments)},{dup:319}],495:[function(t,e,r){arguments[4][320][0].apply(r,arguments)},{dup:320}],496:[function(t,e,r){arguments[4][321][0].apply(r,arguments)},{\"./is-native-implemented\":495,d:151,dup:321,\"es5-ext/object/is-value\":194,\"es5-ext/object/set-prototype-of\":200,\"es5-ext/object/valid-object\":204,\"es5-ext/object/valid-value\":205,\"es5-ext/string/random-uniq\":210,\"es6-iterator/for-of\":212,\"es6-iterator/get\":213,\"es6-symbol\":219}],497:[function(t,e,r){\"use strict\";function n(t,e){return function(t){if(Array.isArray(t))return t}(t)||function(t,e){var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{n||null==s.return||s.return()}finally{if(i)throw a}}return r}(t,e)||function(){throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")}()}function i(t){return function(t){if(Array.isArray(t)){for(var e=0,r=new Array(t.length);e<t.length;e++)r[e]=t[e];return r}}(t)||function(t){if(Symbol.iterator in Object(t)||\"[object Arguments]\"===Object.prototype.toString.call(t))return Array.from(t)}(t)||function(){throw new TypeError(\"Invalid attempt to spread non-iterable instance\")}()}var a=t(\"color-normalize\"),o=t(\"array-bounds\"),s=t(\"color-id\"),l=t(\"point-cluster\"),c=t(\"object-assign\"),u=t(\"glslify\"),h=t(\"pick-by-alias\"),f=t(\"update-diff\"),p=t(\"flatten-vertex-data\"),d=t(\"is-iexplorer\"),g=t(\"to-float32\"),v=t(\"parse-rect\"),m=y;function y(t,e){var r=this;if(!(this instanceof y))return new y(t,e);\"function\"==typeof t?(e||(e={}),e.regl=t):(e=t,t=null),e&&e.length&&(e.positions=e);var n,i=(t=e.regl)._gl,a=[];this.tooManyColors=d,n=t.texture({data:new Uint8Array(1020),width:255,height:1,type:\"uint8\",format:\"rgba\",wrapS:\"clamp\",wrapT:\"clamp\",mag:\"nearest\",min:\"nearest\"}),c(this,{regl:t,gl:i,groups:[],markerCache:[null],markerTextures:[null],palette:a,paletteIds:{},paletteTexture:n,maxColors:255,maxSize:100,canvas:i.canvas}),this.update(e);var o={uniforms:{pixelRatio:t.context(\"pixelRatio\"),palette:n,paletteSize:function(t,e){return[r.tooManyColors?0:255,n.height]},scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translate:t.prop(\"translate\"),translateFract:t.prop(\"translateFract\"),opacity:t.prop(\"opacity\"),marker:t.prop(\"markerTexture\")},attributes:{x:function(t,e){return e.xAttr||{buffer:e.positionBuffer,stride:8,offset:0}},y:function(t,e){return e.yAttr||{buffer:e.positionBuffer,stride:8,offset:4}},xFract:function(t,e){return e.xAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:0}},yFract:function(t,e){return e.yAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:4}},size:function(t,e){return e.size.length?{buffer:e.sizeBuffer,stride:2,offset:0}:{constant:[Math.round(255*e.size/r.maxSize)]}},borderSize:function(t,e){return e.borderSize.length?{buffer:e.sizeBuffer,stride:2,offset:1}:{constant:[Math.round(255*e.borderSize/r.maxSize)]}},colorId:function(t,e){return e.color.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:0}:{constant:r.tooManyColors?a.slice(4*e.color,4*e.color+4):[e.color]}},borderColorId:function(t,e){return e.borderColor.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:r.tooManyColors?4:2}:{constant:r.tooManyColors?a.slice(4*e.borderColor,4*e.borderColor+4):[e.borderColor]}},isActive:function(t,e){return!0===e.activation?{constant:[1]}:e.activation?e.activation:{constant:[0]}}},blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:{enable:!1},depth:{enable:!1},elements:t.prop(\"elements\"),count:t.prop(\"count\"),offset:t.prop(\"offset\"),primitive:\"points\"},s=c({},o);s.frag=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nuniform sampler2D marker;\\nuniform float pixelRatio, opacity;\\n\\nfloat smoothStep(float x, float y) {\\n  return 1.0 / (1.0 + exp(50.0*(x - y)));\\n}\\n\\nvoid main() {\\n  float dist = texture2D(marker, gl_PointCoord).r, delta = fragWidth;\\n\\n  // max-distance alpha\\n  if (dist < 0.003) discard;\\n\\n  // null-border case\\n  if (fragBorderColorLevel == fragColorLevel || fragBorderColor.a == 0.) {\\n    float colorAmt = smoothstep(.5 - delta, .5 + delta, dist);\\n    gl_FragColor = vec4(fragColor.rgb, colorAmt * fragColor.a * opacity);\\n  }\\n  else {\\n    float borderColorAmt = smoothstep(fragBorderColorLevel - delta, fragBorderColorLevel + delta, dist);\\n    float colorAmt = smoothstep(fragColorLevel - delta, fragColorLevel + delta, dist);\\n\\n    vec4 color = fragBorderColor;\\n    color.a *= borderColorAmt;\\n    color = mix(color, fragColor, colorAmt);\\n    color.a *= opacity;\\n\\n    gl_FragColor = color;\\n  }\\n\\n}\\n\"]),s.vert=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract, paletteSize;\\nuniform float pixelRatio;\\nuniform sampler2D palette;\\n\\nconst float maxSize = 100.;\\nconst float borderLevel = .5;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragPointSize, fragBorderRadius, fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = 2. * size * pixelRatio;\\n  fragPointSize = size * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\n  fragColor = color;\\n  fragBorderColor = borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n\\n  fragBorderColorLevel = clamp(borderLevel - borderLevel * borderSize / size, 0., 1.);\\n  fragColorLevel = clamp(borderLevel + (1. - borderLevel) * borderSize / size, 0., 1.);\\n}\"]),this.drawMarker=t(s);var l=c({},o);l.frag=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\n\\nuniform float opacity;\\nvarying float fragBorderRadius, fragWidth;\\n\\nfloat smoothStep(float edge0, float edge1, float x) {\\n\\tfloat t;\\n\\tt = clamp((x - edge0) / (edge1 - edge0), 0.0, 1.0);\\n\\treturn t * t * (3.0 - 2.0 * t);\\n}\\n\\nvoid main() {\\n\\tfloat radius, alpha = 1.0, delta = fragWidth;\\n\\n\\tradius = length(2.0 * gl_PointCoord.xy - 1.0);\\n\\n\\tif (radius > 1.0 + delta) {\\n\\t\\tdiscard;\\n\\t}\\n\\n\\talpha -= smoothstep(1.0 - delta, 1.0 + delta, radius);\\n\\n\\tfloat borderRadius = fragBorderRadius;\\n\\tfloat ratio = smoothstep(borderRadius - delta, borderRadius + delta, radius);\\n\\tvec4 color = mix(fragColor, fragBorderColor, ratio);\\n\\tcolor.a *= alpha * opacity;\\n\\tgl_FragColor = color;\\n}\\n\"]),l.vert=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio;\\nuniform sampler2D palette;\\nuniform vec2 paletteSize;\\n\\nconst float maxSize = 100.;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragBorderRadius, fragWidth;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  // ignore inactive points\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = (size + borderSize) * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\n  fragBorderRadius = 1. - 2. * borderSize / (size + borderSize);\\n  fragColor = color;\\n  fragBorderColor = borderColor.a == 0. || borderSize == 0. ? vec4(color.rgb, 0.) : borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n}\\n\"]),d&&(l.frag=l.frag.replace(\"smoothstep\",\"smoothStep\"),s.frag=s.frag.replace(\"smoothstep\",\"smoothStep\")),this.drawCircle=t(l)}y.defaults={color:\"black\",borderColor:\"transparent\",borderSize:0,size:12,opacity:1,marker:void 0,viewport:null,range:null,pixelSize:null,count:0,offset:0,bounds:null,positions:[],snap:1e4},y.prototype.render=function(){return arguments.length&&this.update.apply(this,arguments),this.draw(),this},y.prototype.draw=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var i=this.groups;if(1===r.length&&Array.isArray(r[0])&&(null===r[0][0]||Array.isArray(r[0][0]))&&(r=r[0]),this.regl._refresh(),r.length)for(var a=0;a<r.length;a++)this.drawItem(a,r[a]);else i.forEach(function(e,r){t.drawItem(r)});return this},y.prototype.drawItem=function(t,e){var r=this.groups,n=r[t];if(\"number\"==typeof e&&(t=e,n=r[e],e=null),n&&n.count&&n.opacity){n.activation[0]&&this.drawCircle(this.getMarkerDrawOptions(0,n,e));for(var a=[],o=1;o<n.activation.length;o++)n.activation[o]&&(!0===n.activation[o]||n.activation[o].data.length)&&a.push.apply(a,i(this.getMarkerDrawOptions(o,n,e)));a.length&&this.drawMarker(a)}},y.prototype.getMarkerDrawOptions=function(t,e,r){var i=e.range,a=e.tree,o=e.viewport,s=e.activation,l=e.selectionBuffer,u=e.count;this.regl;if(!a)return r?[c({},e,{markerTexture:this.markerTextures[t],activation:s[t],count:r.length,elements:r,offset:0})]:[c({},e,{markerTexture:this.markerTextures[t],activation:s[t],offset:0})];var h=[],f=a.range(i,{lod:!0,px:[(i[2]-i[0])/o.width,(i[3]-i[1])/o.height]});if(r){for(var p=s[t].data,d=new Uint8Array(u),g=0;g<r.length;g++){var v=r[g];d[v]=p?p[v]:1}l.subdata(d)}for(var m=f.length;m--;){var y=n(f[m],2),x=y[0],b=y[1];h.push(c({},e,{markerTexture:this.markerTextures[t],activation:r?l:s[t],offset:x,count:b-x}))}return h},y.prototype.update=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];if(r.length){1===r.length&&Array.isArray(r[0])&&(r=r[0]);var i=this.groups,a=this.gl,s=this.regl,u=this.maxSize,d=this.maxColors,m=this.palette;this.groups=i=r.map(function(e,r){var n=i[r];if(void 0===e)return n;null===e?e={positions:null}:\"function\"==typeof e?e={ondraw:e}:\"number\"==typeof e[0]&&(e={positions:e}),null===(e=h(e,{positions:\"positions data points\",snap:\"snap cluster lod tree\",size:\"sizes size radius\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",color:\"colors color fill fill-color fillColor\",borderColor:\"borderColors borderColor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range dataBox databox\",viewport:\"viewport viewPort viewBox viewbox\",opacity:\"opacity alpha transparency\",bounds:\"bound bounds boundaries limits\",tooManyColors:\"tooManyColors palette paletteMode optimizePalette enablePalette\"})).positions&&(e.positions=[]),null!=e.tooManyColors&&(t.tooManyColors=e.tooManyColors),n||(i[r]=n={id:r,scale:null,translate:null,scaleFract:null,translateFract:null,activation:[],selectionBuffer:s.buffer({data:new Uint8Array(0),usage:\"stream\",type:\"uint8\"}),sizeBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),colorBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),positionBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"}),positionFractBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"})},e=c({},y.defaults,e)),!e.positions||\"marker\"in e||(e.marker=n.marker,delete n.marker),!e.marker||\"positions\"in e||(e.positions=n.positions,delete n.positions);var x=0,b=0;if(f(n,e,[{snap:!0,size:function(t,e){return null==t&&(t=y.defaults.size),x+=t&&t.length?1:0,t},borderSize:function(t,e){return null==t&&(t=y.defaults.borderSize),x+=t&&t.length?1:0,t},opacity:parseFloat,color:function(e,r){return null==e&&(e=y.defaults.color),e=t.updateColor(e),b++,e},borderColor:function(e,r){return null==e&&(e=y.defaults.borderColor),e=t.updateColor(e),b++,e},bounds:function(t,e,r){return\"range\"in r||(r.range=null),t},positions:function(t,e,r){var n=e.snap,i=e.positionBuffer,a=e.positionFractBuffer,c=e.selectionBuffer;if(t.x||t.y)return t.x.length?e.xAttr={buffer:s.buffer(t.x),offset:0,stride:4,count:t.x.length}:e.xAttr={buffer:t.x.buffer,offset:4*t.x.offset||0,stride:4*(t.x.stride||1),count:t.x.count},t.y.length?e.yAttr={buffer:s.buffer(t.y),offset:0,stride:4,count:t.y.length}:e.yAttr={buffer:t.y.buffer,offset:4*t.y.offset||0,stride:4*(t.y.stride||1),count:t.y.count},e.count=Math.max(e.xAttr.count,e.yAttr.count),t;t=p(t,\"float64\");var u=e.count=Math.floor(t.length/2),h=e.bounds=u?o(t,2):null;if(r.range||e.range||(delete e.range,r.range=h),r.marker||e.marker||(delete e.marker,r.marker=null),n&&(!0===n||u>n)?e.tree=l(t,{bounds:h}):n&&n.length&&(e.tree=n),e.tree){var f={primitive:\"points\",usage:\"static\",data:e.tree,type:\"uint32\"};e.elements?e.elements(f):e.elements=s.elements(f)}return i({data:g.float(t),usage:\"dynamic\"}),a({data:g.fract(t),usage:\"dynamic\"}),c({data:new Uint8Array(u),type:\"uint8\",usage:\"stream\"}),t}},{marker:function(e,r,n){var i=r.activation;if(i.forEach(function(t){return t&&t.destroy&&t.destroy()}),i.length=0,e&&\"number\"!=typeof e[0]){for(var a=[],o=0,l=Math.min(e.length,r.count);o<l;o++){var c=t.addMarker(e[o]);a[c]||(a[c]=new Uint8Array(r.count)),a[c][o]=1}for(var u=0;u<a.length;u++)if(a[u]){var h={data:a[u],type:\"uint8\",usage:\"static\"};i[u]?i[u](h):i[u]=s.buffer(h),i[u].data=a[u]}}else{i[t.addMarker(e)]=!0}return e},range:function(t,e,r){var n=e.bounds;if(n)return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=g.fract(e.scale),e.translateFract=g.fract(e.translate),t},viewport:function(t){return v(t||[a.drawingBufferWidth,a.drawingBufferHeight])}}]),x){var _=n,w=_.count,k=_.size,T=_.borderSize,A=_.sizeBuffer,M=new Uint8Array(2*w);if(k.length||T.length)for(var S=0;S<w;S++)M[2*S]=Math.round(255*(null==k[S]?k:k[S])/u),M[2*S+1]=Math.round(255*(null==T[S]?T:T[S])/u);A({data:M,usage:\"dynamic\"})}if(b){var E,C=n,L=C.count,P=C.color,O=C.borderColor,z=C.colorBuffer;if(t.tooManyColors){if(P.length||O.length){E=new Uint8Array(8*L);for(var I=0;I<L;I++){var D=P[I];E[8*I]=m[4*D],E[8*I+1]=m[4*D+1],E[8*I+2]=m[4*D+2],E[8*I+3]=m[4*D+3];var R=O[I];E[8*I+4]=m[4*R],E[8*I+5]=m[4*R+1],E[8*I+6]=m[4*R+2],E[8*I+7]=m[4*R+3]}}}else if(P.length||O.length){E=new Uint8Array(4*L+2);for(var F=0;F<L;F++)null!=P[F]&&(E[4*F]=P[F]%d,E[4*F+1]=Math.floor(P[F]/d)),null!=O[F]&&(E[4*F+2]=O[F]%d,E[4*F+3]=Math.floor(O[F]/d))}z({data:E||new Uint8Array(0),type:\"uint8\",usage:\"dynamic\"})}return n})}},y.prototype.addMarker=function(t){var e,r=this.markerTextures,n=this.regl,i=this.markerCache,a=null==t?0:i.indexOf(t);if(a>=0)return a;if(t instanceof Uint8Array||t instanceof Uint8ClampedArray)e=t;else{e=new Uint8Array(t.length);for(var o=0,s=t.length;o<s;o++)e[o]=255*t[o]}var l=Math.floor(Math.sqrt(e.length));return a=r.length,i.push(t),r.push(n.texture({channels:1,data:e,radius:l,mag:\"linear\",min:\"linear\"})),a},y.prototype.updateColor=function(t){var e=this.paletteIds,r=this.palette,n=this.maxColors;Array.isArray(t)||(t=[t]);var i=[];if(\"number\"==typeof t[0]){var o=[];if(Array.isArray(t))for(var l=0;l<t.length;l+=4)o.push(t.slice(l,l+4));else for(var c=0;c<t.length;c+=4)o.push(t.subarray(c,c+4));t=o}for(var u=0;u<t.length;u++){var h=t[u];h=a(h,\"uint8\");var f=s(h,!1);if(null==e[f]){var p=r.length;e[f]=Math.floor(p/4),r[p]=h[0],r[p+1]=h[1],r[p+2]=h[2],r[p+3]=h[3]}i[u]=e[f]}return!this.tooManyColors&&r.length>4*n&&(this.tooManyColors=!0),this.updatePalette(r),1===i.length?i[0]:i},y.prototype.updatePalette=function(t){if(!this.tooManyColors){var e=this.maxColors,r=this.paletteTexture,n=Math.ceil(.25*t.length/e);if(n>1)for(var i=.25*(t=t.slice()).length%e;i<n*e;i++)t.push(0,0,0,0);r.height<n&&r.resize(e,n),r.subimage({width:Math.min(.25*t.length,e),height:n,data:t},0,0)}},y.prototype.destroy=function(){return this.groups.forEach(function(t){t.sizeBuffer.destroy(),t.positionBuffer.destroy(),t.positionFractBuffer.destroy(),t.colorBuffer.destroy(),t.activation.forEach(function(t){return t&&t.destroy&&t.destroy()}),t.selectionBuffer.destroy(),t.elements&&t.elements.destroy()}),this.groups.length=0,this.paletteTexture.destroy(),this.markerTextures.forEach(function(t){return t&&t.destroy&&t.destroy()}),this};var x=t(\"object-assign\");e.exports=function(t,e){var r=new m(t,e),n=r.render.bind(r);return x(n,{render:n,update:r.update.bind(r),draw:r.draw.bind(r),destroy:r.destroy.bind(r),regl:r.regl,gl:r.gl,canvas:r.gl.canvas,groups:r.groups,markers:r.markerCache,palette:r.palette}),n}},{\"array-bounds\":65,\"color-id\":118,\"color-normalize\":120,\"flatten-vertex-data\":227,glslify:409,\"is-iexplorer\":419,\"object-assign\":454,\"parse-rect\":459,\"pick-by-alias\":465,\"point-cluster\":499,\"to-float32\":538,\"update-diff\":549}],498:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],499:[function(t,e,r){\"use strict\";e.exports=t(\"./quad\")},{\"./quad\":500}],500:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"clamp\"),a=t(\"parse-rect\"),o=t(\"array-bounds\"),s=t(\"pick-by-alias\"),l=t(\"defined\"),c=t(\"flatten-vertex-data\"),u=t(\"is-obj\"),h=t(\"dtype\"),f=t(\"math-log2\"),p=1073741824;function d(t,e){for(var r=e[0],n=e[1],a=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=i((t[2*l]-r)*a,0,1),s[2*l+1]=i((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,\"float64\"),e=s(e,{bounds:\"range bounds dataBox databox\",maxDepth:\"depth maxDepth maxdepth level maxLevel maxlevel levels\",dtype:\"type dtype format out dst output destination\"});var r=l(e.maxDepth,255),i=l(e.bounds,o(t,2));i[0]===i[2]&&i[2]++,i[1]===i[3]&&i[3]++;var g,v=d(t,i),m=t.length>>>1;e.dtype||(e.dtype=\"array\"),\"string\"==typeof e.dtype?g=new(h(e.dtype))(m):e.dtype&&(g=e.dtype,Array.isArray(g)&&(g.length=m));for(var y=0;y<m;++y)g[y]=y;var x=[],b=[],_=[],w=[];!function t(e,n,i,a,o,s){if(!a.length)return null;var l=x[o]||(x[o]=[]);var c=_[o]||(_[o]=[]);var u=b[o]||(b[o]=[]);var h=l.length;o++;if(o>r||s>p){for(var f=0;f<a.length;f++)l.push(a[f]),c.push(s),u.push(null,null,null,null);return h}l.push(a[0]);c.push(s);if(a.length<=1)return u.push(null,null,null,null),h;var d=.5*i;var g=e+d,m=n+d;var y=[],w=[],k=[],T=[];for(var A=1,M=a.length;A<M;A++){var S=a[A],E=v[2*S],C=v[2*S+1];E<g?C<m?y.push(S):w.push(S):C<m?k.push(S):T.push(S)}s<<=2;u.push(t(e,n,d,y,o,s),t(e,m,d,w,o,s+1),t(g,n,d,k,o,s+2),t(g,m,d,T,o,s+3));return h}(0,0,1,g,0,1);for(var k=0,T=0;T<x.length;T++){var A=x[T];if(g.set)g.set(A,k);else for(var M=0,S=A.length;M<S;M++)g[M+k]=A[M];var E=k+x[T].length;w[T]=[k,E],k=E}return g.range=function(){var e,r=[],o=arguments.length;for(;o--;)r[o]=arguments[o];if(u(r[r.length-1])){var c=r.pop();r.length||null==c.x&&null==c.l&&null==c.left||(r=[c],e={}),e=s(c,{level:\"level maxLevel\",d:\"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize\",lod:\"lod details ranges offsets\"})}else e={};r.length||(r=i);var h=a.apply(void 0,r),p=[Math.min(h.x,h.x+h.width),Math.min(h.y,h.y+h.height),Math.max(h.x,h.x+h.width),Math.max(h.y,h.y+h.height)],g=p[0],v=p[1],m=p[2],y=p[3],k=d([g,v,m,y],i),T=k[0],A=k[1],M=k[2],S=k[3],E=l(e.level,x.length);if(null!=e.d){var L;\"number\"==typeof e.d?L=[e.d,e.d]:e.d.length&&(L=e.d),E=Math.min(Math.max(Math.ceil(-f(Math.abs(L[0])/(i[2]-i[0]))),Math.ceil(-f(Math.abs(L[1])/(i[3]-i[1])))),E)}if(E=Math.min(E,x.length),e.lod)return function(t,e,r,i,a){for(var o=[],s=0;s<a;s++){var l=_[s],c=w[s][0],u=C(t,e,s),h=C(r,i,s),f=n.ge(l,u),p=n.gt(l,h,f,l.length-1);o[s]=[f+c,p+c]}return o}(T,A,M,S,E);var P=[];return function e(r,n,i,a,o,s){if(null!==o&&null!==s){var l=r+i,c=n+i;if(!(T>l||A>c||M<r||S<n||a>=E||o===s)){var u=x[a];void 0===s&&(s=u.length);for(var h=o;h<s;h++){var f=u[h],p=t[2*f],d=t[2*f+1];p>=g&&p<=m&&d>=v&&d<=y&&P.push(f)}var _=b[a],w=_[4*o+0],k=_[4*o+1],C=_[4*o+2],L=_[4*o+3],O=function(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}(_,o+1),z=.5*i,I=a+1;e(r,n,z,I,w,k||C||L||O),e(r,n+z,z,I,k,C||L||O),e(r+z,n,z,I,C,L||O),e(r+z,n+z,z,I,L,O)}}}(0,0,1,0,0,1),P},g;function C(t,e,r){for(var n=1,i=.5,a=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<i?e<a?0:1:e<a?2:3,o*=.5,i+=t<i?-o:o,a+=e<a?-o:o;return n}}},{\"array-bounds\":65,\"binary-search-bounds\":498,clamp:115,defined:164,dtype:169,\"flatten-vertex-data\":227,\"is-obj\":421,\"math-log2\":432,\"parse-rect\":459,\"pick-by-alias\":465}],501:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"pick-by-alias\"),a=t(\"array-bounds\"),o=t(\"raf\"),s=t(\"array-range\"),l=t(\"parse-rect\"),c=t(\"flatten-vertex-data\");function u(t,e){if(!(this instanceof u))return new u(t,e);this.traces=[],this.passes={},this.regl=t,this.scatter=n(t),this.canvas=this.scatter.canvas}function h(t,e,r){return(null!=t.id?t.id:t)<<16|(255&e)<<8|255&r}function f(t,e,r){var n,i,a,o,s=t[e],l=t[r];return s.length>2?(s[0],s[2],n=s[1],i=s[3]):s.length?(n=s[0],i=s[1]):(s.x,n=s.y,s.x+s.width,i=s.y+s.height),l.length>2?(a=l[0],o=l[2],l[1],l[3]):l.length?(a=l[0],o=l[1]):(a=l.x,l.y,o=l.x+l.width,l.y+l.height),[a,n,o,i]}function p(t){if(\"number\"==typeof t)return[t,t,t,t];if(2===t.length)return[t[0],t[1],t[0],t[1]];var e=l(t);return[e.x,e.y,e.x+e.width,e.y+e.height]}e.exports=u,u.prototype.render=function(){for(var t,e=this,r=[],n=arguments.length;n--;)r[n]=arguments[n];return r.length&&(t=this).update.apply(t,r),this.regl.attributes.preserveDrawingBuffer?this.draw():(this.dirty?null==this.planned&&(this.planned=o(function(){e.draw(),e.dirty=!0,e.planned=null})):(this.draw(),this.dirty=!0,o(function(){e.dirty=!1})),this)},u.prototype.update=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=0;n<e.length;n++)this.updateItem(n,e[n]);this.traces=this.traces.filter(Boolean);for(var i=[],a=0,o=0;o<this.traces.length;o++){for(var s=this.traces[o],l=this.traces[o].passes,c=0;c<l.length;c++)i.push(this.passes[l[c]]);s.passOffset=a,a+=s.passes.length}return(t=this.scatter).update.apply(t,i),this}},u.prototype.updateItem=function(t,e){var r=this.regl;if(null===e)return this.traces[t]=null,this;if(!e)return this;var n,o=i(e,{data:\"data items columns rows values dimensions samples x\",snap:\"snap cluster\",size:\"sizes size radius\",color:\"colors color fill fill-color fillColor\",opacity:\"opacity alpha transparency opaque\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",borderColor:\"borderColors borderColor bordercolor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range ranges databox dataBox\",viewport:\"viewport viewBox viewbox\",domain:\"domain domains area areas\",padding:\"pad padding paddings pads margin margins\",transpose:\"transpose transposed\",diagonal:\"diagonal diag showDiagonal\",upper:\"upper up top upperhalf upperHalf showupperhalf showUpper showUpperHalf\",lower:\"lower low bottom lowerhalf lowerHalf showlowerhalf showLowerHalf showLower\"}),s=this.traces[t]||(this.traces[t]={id:t,buffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),color:\"black\",marker:null,size:12,borderColor:\"transparent\",borderSize:1,viewport:l([r._gl.drawingBufferWidth,r._gl.drawingBufferHeight]),padding:[0,0,0,0],opacity:1,diagonal:!0,upper:!0,lower:!0});if(null!=o.color&&(s.color=o.color),null!=o.size&&(s.size=o.size),null!=o.marker&&(s.marker=o.marker),null!=o.borderColor&&(s.borderColor=o.borderColor),null!=o.borderSize&&(s.borderSize=o.borderSize),null!=o.opacity&&(s.opacity=o.opacity),o.viewport&&(s.viewport=l(o.viewport)),null!=o.diagonal&&(s.diagonal=o.diagonal),null!=o.upper&&(s.upper=o.upper),null!=o.lower&&(s.lower=o.lower),o.data){s.buffer(c(o.data)),s.columns=o.data.length,s.count=o.data[0].length,s.bounds=[];for(var u=0;u<s.columns;u++)s.bounds[u]=a(o.data[u],1)}o.range&&(s.range=o.range,n=s.range&&\"number\"!=typeof s.range[0]),o.domain&&(s.domain=o.domain);var d=!1;null!=o.padding&&(Array.isArray(o.padding)&&o.padding.length===s.columns&&\"number\"==typeof o.padding[o.padding.length-1]?(s.padding=o.padding.map(p),d=!0):s.padding=p(o.padding));var g=s.columns,v=s.count,m=s.viewport.width,y=s.viewport.height,x=s.viewport.x,b=s.viewport.y,_=m/g,w=y/g;s.passes=[];for(var k=0;k<g;k++)for(var T=0;T<g;T++)if((s.diagonal||T!==k)&&(s.upper||!(k>T))&&(s.lower||!(k<T))){var A=h(s.id,k,T),M=this.passes[A]||(this.passes[A]={});if(o.data&&(o.transpose?M.positions={x:{buffer:s.buffer,offset:T,count:v,stride:g},y:{buffer:s.buffer,offset:k,count:v,stride:g}}:M.positions={x:{buffer:s.buffer,offset:T*v,count:v},y:{buffer:s.buffer,offset:k*v,count:v}},M.bounds=f(s.bounds,k,T)),o.domain||o.viewport||o.data){var S=d?f(s.padding,k,T):s.padding;if(s.domain){var E=f(s.domain,k,T),C=E[0],L=E[1],P=E[2],O=E[3];M.viewport=[x+C*m+S[0],b+L*y+S[1],x+P*m-S[2],b+O*y-S[3]]}else M.viewport=[x+T*_+_*S[0],b+k*w+w*S[1],x+(T+1)*_-_*S[2],b+(k+1)*w-w*S[3]]}o.color&&(M.color=s.color),o.size&&(M.size=s.size),o.marker&&(M.marker=s.marker),o.borderSize&&(M.borderSize=s.borderSize),o.borderColor&&(M.borderColor=s.borderColor),o.opacity&&(M.opacity=s.opacity),o.range&&(M.range=n?f(s.range,k,T):s.range||M.bounds),s.passes.push(A)}return this},u.prototype.draw=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=[],i=0;i<e.length;i++)if(\"number\"==typeof e[i]){var a=this.traces[e[i]],o=a.passes,l=a.passOffset;n.push.apply(n,s(l,l+o.length))}else if(e[i].length){var c=e[i],u=this.traces[i],h=u.passes,f=u.passOffset;h=h.map(function(t,e){n[f+e]=c})}(t=this.scatter).draw.apply(t,n)}else this.scatter.draw();return this},u.prototype.destroy=function(){return this.traces.forEach(function(t){t.buffer&&t.buffer.destroy&&t.buffer.destroy()}),this.traces=null,this.passes=null,this.scatter.destroy(),this}},{\"array-bounds\":65,\"array-range\":67,\"flatten-vertex-data\":227,\"parse-rect\":459,\"pick-by-alias\":465,raf:484,\"regl-scatter2d\":497}],502:[function(t,e,r){var n,i;n=this,i=function(){function t(t,e){this.id=U++,this.type=t,this.data=e}function e(t){return\"[\"+function t(e){if(0===e.length)return[];var r=e.charAt(0),n=e.charAt(e.length-1);if(1<e.length&&r===n&&('\"'===r||\"'\"===r))return['\"'+e.substr(1,e.length-2).replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];if(r=/\\[(false|true|null|\\d+|'[^']*'|\"[^\"]*\")\\]/.exec(e))return t(e.substr(0,r.index)).concat(t(r[1])).concat(t(e.substr(r.index+r[0].length)));if(1===(r=e.split(\".\")).length)return['\"'+e.replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];for(e=[],n=0;n<r.length;++n)e=e.concat(t(r[n]));return e}(t).join(\"][\")+\"]\"}function r(t){return\"string\"==typeof t?t.split():t}function n(t){return\"string\"==typeof t?document.querySelector(t):t}function i(t){var e,i,a,o,s=t||{};t={};var l=[],c=[],u=\"undefined\"==typeof window?1:window.devicePixelRatio,h=!1,f=function(t){},p=function(){};if(\"string\"==typeof s?e=document.querySelector(s):\"object\"==typeof s&&(\"string\"==typeof s.nodeName&&\"function\"==typeof s.appendChild&&\"function\"==typeof s.getBoundingClientRect?e=s:\"function\"==typeof s.drawArrays||\"function\"==typeof s.drawElements?a=(o=s).canvas:(\"gl\"in s?o=s.gl:\"canvas\"in s?a=n(s.canvas):\"container\"in s&&(i=n(s.container)),\"attributes\"in s&&(t=s.attributes),\"extensions\"in s&&(l=r(s.extensions)),\"optionalExtensions\"in s&&(c=r(s.optionalExtensions)),\"onDone\"in s&&(f=s.onDone),\"profile\"in s&&(h=!!s.profile),\"pixelRatio\"in s&&(u=+s.pixelRatio))),e&&(\"canvas\"===e.nodeName.toLowerCase()?a=e:i=e),!o){if(!a){if(!(e=function(t,e,r){function n(){var e=window.innerWidth,n=window.innerHeight;t!==document.body&&(e=(n=t.getBoundingClientRect()).right-n.left,n=n.bottom-n.top),i.width=r*e,i.height=r*n,j(i.style,{width:e+\"px\",height:n+\"px\"})}var i=document.createElement(\"canvas\");return j(i.style,{border:0,margin:0,padding:0,top:0,left:0}),t.appendChild(i),t===document.body&&(i.style.position=\"absolute\",j(t.style,{margin:0,padding:0})),window.addEventListener(\"resize\",n,!1),n(),{canvas:i,onDestroy:function(){window.removeEventListener(\"resize\",n),t.removeChild(i)}}}(i||document.body,0,u)))return null;a=e.canvas,p=e.onDestroy}o=function(t,e){function r(r){try{return t.getContext(r,e)}catch(t){return null}}return r(\"webgl\")||r(\"experimental-webgl\")||r(\"webgl-experimental\")}(a,t)}return o?{gl:o,canvas:a,container:i,extensions:l,optionalExtensions:c,pixelRatio:u,profile:h,onDone:f,onDestroy:p}:(p(),f(\"webgl not supported, try upgrading your browser or graphics drivers http://get.webgl.org\"),null)}function a(t,e){for(var r=Array(t),n=0;n<t;++n)r[n]=e(n);return r}function o(t){var e,r;return e=(65535<t)<<4,e|=r=(255<(t>>>=e))<<3,(e|=r=(15<(t>>>=r))<<2)|(r=(3<(t>>>=r))<<1)|t>>>r>>1}function s(){function t(t){t:{for(var e=16;268435456>=e;e*=16)if(t<=e){t=e;break t}t=0}return 0<(e=r[o(t)>>2]).length?e.pop():new ArrayBuffer(t)}function e(t){r[o(t.byteLength)>>2].push(t)}var r=a(8,function(){return[]});return{alloc:t,free:e,allocType:function(e,r){var n=null;switch(e){case 5120:n=new Int8Array(t(r),0,r);break;case 5121:n=new Uint8Array(t(r),0,r);break;case 5122:n=new Int16Array(t(2*r),0,r);break;case 5123:n=new Uint16Array(t(2*r),0,r);break;case 5124:n=new Int32Array(t(4*r),0,r);break;case 5125:n=new Uint32Array(t(4*r),0,r);break;case 5126:n=new Float32Array(t(4*r),0,r);break;default:return null}return n.length!==r?n.subarray(0,r):n},freeType:function(t){e(t.buffer)}}}function l(t){return!!t&&\"object\"==typeof t&&Array.isArray(t.shape)&&Array.isArray(t.stride)&&\"number\"==typeof t.offset&&t.shape.length===t.stride.length&&(Array.isArray(t.data)||W(t.data))}function c(t,e,r,n,i,a){for(var o=0;o<e;++o)for(var s=t[o],l=0;l<r;++l)for(var c=s[l],u=0;u<n;++u)i[a++]=c[u]}function u(t){return 0|J[Object.prototype.toString.call(t)]}function h(t,e){for(var r=0;r<e.length;++r)t[r]=e[r]}function f(t,e,r,n,i,a,o){for(var s=0,l=0;l<r;++l)for(var c=0;c<n;++c)t[s++]=e[i*l+a*c+o]}function p(t,e,r,n){function i(e){this.id=c++,this.buffer=t.createBuffer(),this.type=e,this.usage=35044,this.byteLength=0,this.dimension=1,this.dtype=5121,this.persistentData=null,r.profile&&(this.stats={size:0})}function a(e,r,n){e.byteLength=r.byteLength,t.bufferData(e.type,r,n)}function o(t,e,r,n,i,o){if(t.usage=r,Array.isArray(e)){if(t.dtype=n||5126,0<e.length)if(Array.isArray(e[0])){i=tt(e);for(var s=n=1;s<i.length;++s)n*=i[s];t.dimension=n,a(t,e=Q(e,i,t.dtype),r),o?t.persistentData=e:G.freeType(e)}else\"number\"==typeof e[0]?(t.dimension=i,h(i=G.allocType(t.dtype,e.length),e),a(t,i,r),o?t.persistentData=i:G.freeType(i)):W(e[0])&&(t.dimension=e[0].length,t.dtype=n||u(e[0])||5126,a(t,e=Q(e,[e.length,e[0].length],t.dtype),r),o?t.persistentData=e:G.freeType(e))}else if(W(e))t.dtype=n||u(e),t.dimension=i,a(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e.buffer)));else if(l(e)){i=e.shape;var c=e.stride,p=(s=e.offset,0),d=0,g=0,v=0;1===i.length?(p=i[0],d=1,g=c[0],v=0):2===i.length&&(p=i[0],d=i[1],g=c[0],v=c[1]),t.dtype=n||u(e.data)||5126,t.dimension=d,f(i=G.allocType(t.dtype,p*d),e.data,p,d,g,v,s),a(t,i,r),o?t.persistentData=i:G.freeType(i)}}function s(r){e.bufferCount--;for(var i=0;i<n.state.length;++i){var a=n.state[i];a.buffer===r&&(t.disableVertexAttribArray(i),a.buffer=null)}t.deleteBuffer(r.buffer),r.buffer=null,delete p[r.id]}var c=0,p={};i.prototype.bind=function(){t.bindBuffer(this.type,this.buffer)},i.prototype.destroy=function(){s(this)};var d=[];return r.profile&&(e.getTotalBufferSize=function(){var t=0;return Object.keys(p).forEach(function(e){t+=p[e].stats.size}),t}),{create:function(n,a,c,d){function g(e){var n=35044,i=null,a=0,s=0,c=1;return Array.isArray(e)||W(e)||l(e)?i=e:\"number\"==typeof e?a=0|e:e&&(\"data\"in e&&(i=e.data),\"usage\"in e&&(n=$[e.usage]),\"type\"in e&&(s=K[e.type]),\"dimension\"in e&&(c=0|e.dimension),\"length\"in e&&(a=0|e.length)),v.bind(),i?o(v,i,n,s,c,d):(a&&t.bufferData(v.type,a,n),v.dtype=s||5121,v.usage=n,v.dimension=c,v.byteLength=a),r.profile&&(v.stats.size=v.byteLength*et[v.dtype]),g}e.bufferCount++;var v=new i(a);return p[v.id]=v,c||g(n),g._reglType=\"buffer\",g._buffer=v,g.subdata=function(e,r){var n,i=0|(r||0);if(v.bind(),W(e))t.bufferSubData(v.type,i,e);else if(Array.isArray(e)){if(0<e.length)if(\"number\"==typeof e[0]){var a=G.allocType(v.dtype,e.length);h(a,e),t.bufferSubData(v.type,i,a),G.freeType(a)}else(Array.isArray(e[0])||W(e[0]))&&(n=tt(e),a=Q(e,n,v.dtype),t.bufferSubData(v.type,i,a),G.freeType(a))}else if(l(e)){n=e.shape;var o=e.stride,s=a=0,c=0,p=0;1===n.length?(a=n[0],s=1,c=o[0],p=0):2===n.length&&(a=n[0],s=n[1],c=o[0],p=o[1]),n=Array.isArray(e.data)?v.dtype:u(e.data),f(n=G.allocType(n,a*s),e.data,a,s,c,p,e.offset),t.bufferSubData(v.type,i,n),G.freeType(n)}return g},r.profile&&(g.stats=v.stats),g.destroy=function(){s(v)},g},createStream:function(t,e){var r=d.pop();return r||(r=new i(t)),r.bind(),o(r,e,35040,0,1,!1),r},destroyStream:function(t){d.push(t)},clear:function(){X(p).forEach(s),d.forEach(s)},getBuffer:function(t){return t&&t._buffer instanceof i?t._buffer:null},restore:function(){X(p).forEach(function(e){e.buffer=t.createBuffer(),t.bindBuffer(e.type,e.buffer),t.bufferData(e.type,e.persistentData||e.byteLength,e.usage)})},_initBuffer:o}}function d(t,e,r,n){function i(t){this.id=c++,s[this.id]=this,this.buffer=t,this.primType=4,this.type=this.vertCount=0}function a(n,i,a,o,s,c,u){if(n.buffer.bind(),i){var h=u;u||W(i)&&(!l(i)||W(i.data))||(h=e.oes_element_index_uint?5125:5123),r._initBuffer(n.buffer,i,a,h,3)}else t.bufferData(34963,c,a),n.buffer.dtype=h||5121,n.buffer.usage=a,n.buffer.dimension=3,n.buffer.byteLength=c;if(h=u,!u){switch(n.buffer.dtype){case 5121:case 5120:h=5121;break;case 5123:case 5122:h=5123;break;case 5125:case 5124:h=5125}n.buffer.dtype=h}n.type=h,0>(i=s)&&(i=n.buffer.byteLength,5123===h?i>>=1:5125===h&&(i>>=2)),n.vertCount=i,i=o,0>o&&(i=4,1===(o=n.buffer.dimension)&&(i=0),2===o&&(i=1),3===o&&(i=4)),n.primType=i}function o(t){n.elementsCount--,delete s[t.id],t.buffer.destroy(),t.buffer=null}var s={},c=0,u={uint8:5121,uint16:5123};e.oes_element_index_uint&&(u.uint32=5125),i.prototype.bind=function(){this.buffer.bind()};var h=[];return{create:function(t,e){function s(t){if(t)if(\"number\"==typeof t)c(t),h.primType=4,h.vertCount=0|t,h.type=5121;else{var e=null,r=35044,n=-1,i=-1,o=0,f=0;Array.isArray(t)||W(t)||l(t)?e=t:(\"data\"in t&&(e=t.data),\"usage\"in t&&(r=$[t.usage]),\"primitive\"in t&&(n=rt[t.primitive]),\"count\"in t&&(i=0|t.count),\"type\"in t&&(f=u[t.type]),\"length\"in t?o=0|t.length:(o=i,5123===f||5122===f?o*=2:5125!==f&&5124!==f||(o*=4))),a(h,e,r,n,i,o,f)}else c(),h.primType=4,h.vertCount=0,h.type=5121;return s}var c=r.create(null,34963,!0),h=new i(c._buffer);return n.elementsCount++,s(t),s._reglType=\"elements\",s._elements=h,s.subdata=function(t,e){return c.subdata(t,e),s},s.destroy=function(){o(h)},s},createStream:function(t){var e=h.pop();return e||(e=new i(r.create(null,34963,!0,!1)._buffer)),a(e,t,35040,-1,-1,0,0),e},destroyStream:function(t){h.push(t)},getElements:function(t){return\"function\"==typeof t&&t._elements instanceof i?t._elements:null},clear:function(){X(s).forEach(o)}}}function g(t){for(var e=G.allocType(5123,t.length),r=0;r<t.length;++r)if(isNaN(t[r]))e[r]=65535;else if(1/0===t[r])e[r]=31744;else if(-1/0===t[r])e[r]=64512;else{nt[0]=t[r];var n=(a=it[0])>>>31<<15,i=(a<<1>>>24)-127,a=a>>13&1023;e[r]=-24>i?n:-14>i?n+(a+1024>>-14-i):15<i?n+31744:n+(i+15<<10)+a}return e}function v(t){return Array.isArray(t)||W(t)}function m(t){return\"[object \"+t+\"]\"}function y(t){return Array.isArray(t)&&(0===t.length||\"number\"==typeof t[0])}function x(t){return!(!Array.isArray(t)||0===t.length||!v(t[0]))}function b(t){return Object.prototype.toString.call(t)}function _(t){if(!t)return!1;var e=b(t);return 0<=pt.indexOf(e)||(y(t)||x(t)||l(t))}function w(t,e){36193===t.type?(t.data=g(e),G.freeType(e)):t.data=e}function k(t,e,r,n,i,a){if(t=\"undefined\"!=typeof gt[t]?gt[t]:st[t]*dt[e],a&&(t*=6),i){for(n=0;1<=r;)n+=t*r*r,r/=2;return n}return t*r*n}function T(t,e,r,n,i,a,o){function s(){this.format=this.internalformat=6408,this.type=5121,this.flipY=this.premultiplyAlpha=this.compressed=!1,this.unpackAlignment=1,this.colorSpace=37444,this.channels=this.height=this.width=0}function c(t,e){t.internalformat=e.internalformat,t.format=e.format,t.type=e.type,t.compressed=e.compressed,t.premultiplyAlpha=e.premultiplyAlpha,t.flipY=e.flipY,t.unpackAlignment=e.unpackAlignment,t.colorSpace=e.colorSpace,t.width=e.width,t.height=e.height,t.channels=e.channels}function u(t,e){if(\"object\"==typeof e&&e){\"premultiplyAlpha\"in e&&(t.premultiplyAlpha=e.premultiplyAlpha),\"flipY\"in e&&(t.flipY=e.flipY),\"alignment\"in e&&(t.unpackAlignment=e.alignment),\"colorSpace\"in e&&(t.colorSpace=q[e.colorSpace]),\"type\"in e&&(t.type=H[e.type]);var r=t.width,n=t.height,i=t.channels,a=!1;\"shape\"in e?(r=e.shape[0],n=e.shape[1],3===e.shape.length&&(i=e.shape[2],a=!0)):(\"radius\"in e&&(r=n=e.radius),\"width\"in e&&(r=e.width),\"height\"in e&&(n=e.height),\"channels\"in e&&(i=e.channels,a=!0)),t.width=0|r,t.height=0|n,t.channels=0|i,r=!1,\"format\"in e&&(r=e.format,n=t.internalformat=Y[r],t.format=pt[n],r in H&&!(\"type\"in e)&&(t.type=H[r]),r in K&&(t.compressed=!0),r=!0),!a&&r?t.channels=st[t.format]:a&&!r&&t.channels!==ot[t.format]&&(t.format=t.internalformat=ot[t.channels])}}function h(e){t.pixelStorei(37440,e.flipY),t.pixelStorei(37441,e.premultiplyAlpha),t.pixelStorei(37443,e.colorSpace),t.pixelStorei(3317,e.unpackAlignment)}function f(){s.call(this),this.yOffset=this.xOffset=0,this.data=null,this.needsFree=!1,this.element=null,this.needsCopy=!1}function p(t,e){var r=null;if(_(e)?r=e:e&&(u(t,e),\"x\"in e&&(t.xOffset=0|e.x),\"y\"in e&&(t.yOffset=0|e.y),_(e.data)&&(r=e.data)),e.copy){var n=i.viewportWidth,a=i.viewportHeight;t.width=t.width||n-t.xOffset,t.height=t.height||a-t.yOffset,t.needsCopy=!0}else if(r){if(W(r))t.channels=t.channels||4,t.data=r,\"type\"in e||5121!==t.type||(t.type=0|J[Object.prototype.toString.call(r)]);else if(y(r)){switch(t.channels=t.channels||4,a=(n=r).length,t.type){case 5121:case 5123:case 5125:case 5126:(a=G.allocType(t.type,a)).set(n),t.data=a;break;case 36193:t.data=g(n)}t.alignment=1,t.needsFree=!0}else if(l(r)){n=r.data,Array.isArray(n)||5121!==t.type||(t.type=0|J[Object.prototype.toString.call(n)]);a=r.shape;var o,s,c,h,f=r.stride;3===a.length?(c=a[2],h=f[2]):h=c=1,o=a[0],s=a[1],a=f[0],f=f[1],t.alignment=1,t.width=o,t.height=s,t.channels=c,t.format=t.internalformat=ot[c],t.needsFree=!0,o=h,r=r.offset,c=t.width,h=t.height,s=t.channels;for(var p=G.allocType(36193===t.type?5126:t.type,c*h*s),d=0,m=0;m<h;++m)for(var k=0;k<c;++k)for(var T=0;T<s;++T)p[d++]=n[a*k+f*m+o*T+r];w(t,p)}else if(b(r)===lt||b(r)===ct)b(r)===lt?t.element=r:t.element=r.canvas,t.width=t.element.width,t.height=t.element.height,t.channels=4;else if(b(r)===ut)t.element=r,t.width=r.width,t.height=r.height,t.channels=4;else if(b(r)===ht)t.element=r,t.width=r.naturalWidth,t.height=r.naturalHeight,t.channels=4;else if(b(r)===ft)t.element=r,t.width=r.videoWidth,t.height=r.videoHeight,t.channels=4;else if(x(r)){for(n=t.width||r[0].length,a=t.height||r.length,f=t.channels,f=v(r[0][0])?f||r[0][0].length:f||1,o=Z.shape(r),c=1,h=0;h<o.length;++h)c*=o[h];c=G.allocType(36193===t.type?5126:t.type,c),Z.flatten(r,o,\"\",c),w(t,c),t.alignment=1,t.width=n,t.height=a,t.channels=f,t.format=t.internalformat=ot[f],t.needsFree=!0}}else t.width=t.width||1,t.height=t.height||1,t.channels=t.channels||4}function d(e,r,i,a,o){var s=e.element,l=e.data,c=e.internalformat,u=e.format,f=e.type,p=e.width,d=e.height;h(e),s?t.texSubImage2D(r,o,i,a,u,f,s):e.compressed?t.compressedTexSubImage2D(r,o,i,a,c,p,d,l):e.needsCopy?(n(),t.copyTexSubImage2D(r,o,i,a,e.xOffset,e.yOffset,p,d)):t.texSubImage2D(r,o,i,a,p,d,u,f,l)}function m(){return dt.pop()||new f}function T(t){t.needsFree&&G.freeType(t.data),f.call(t),dt.push(t)}function A(){s.call(this),this.genMipmaps=!1,this.mipmapHint=4352,this.mipmask=0,this.images=Array(16)}function M(t,e,r){var n=t.images[0]=m();t.mipmask=1,n.width=t.width=e,n.height=t.height=r,n.channels=t.channels=4}function S(t,e){var r=null;if(_(e))c(r=t.images[0]=m(),t),p(r,e),t.mipmask=1;else if(u(t,e),Array.isArray(e.mipmap))for(var n=e.mipmap,i=0;i<n.length;++i)c(r=t.images[i]=m(),t),r.width>>=i,r.height>>=i,p(r,n[i]),t.mipmask|=1<<i;else c(r=t.images[0]=m(),t),p(r,e),t.mipmask=1;c(t,t.images[0])}function E(e,r){for(var i=e.images,a=0;a<i.length&&i[a];++a){var o=i[a],s=r,l=a,c=o.element,u=o.data,f=o.internalformat,p=o.format,d=o.type,g=o.width,v=o.height,m=o.channels;h(o),c?t.texImage2D(s,l,p,p,d,c):o.compressed?t.compressedTexImage2D(s,l,f,g,v,0,u):o.needsCopy?(n(),t.copyTexImage2D(s,l,p,o.xOffset,o.yOffset,g,v,0)):((o=!u)&&(u=G.zero.allocType(d,g*v*m)),t.texImage2D(s,l,p,g,v,0,p,d,u),o&&u&&G.zero.freeType(u))}}function C(){var t=gt.pop()||new A;s.call(t);for(var e=t.mipmask=0;16>e;++e)t.images[e]=null;return t}function L(t){for(var e=t.images,r=0;r<e.length;++r)e[r]&&T(e[r]),e[r]=null;gt.push(t)}function P(){this.magFilter=this.minFilter=9728,this.wrapT=this.wrapS=33071,this.anisotropic=1,this.genMipmaps=!1,this.mipmapHint=4352}function O(t,e){\"min\"in e&&(t.minFilter=V[e.min],0<=at.indexOf(t.minFilter)&&!(\"faces\"in e)&&(t.genMipmaps=!0)),\"mag\"in e&&(t.magFilter=U[e.mag]);var r=t.wrapS,n=t.wrapT;if(\"wrap\"in e){var i=e.wrap;\"string\"==typeof i?r=n=N[i]:Array.isArray(i)&&(r=N[i[0]],n=N[i[1]])}else\"wrapS\"in e&&(r=N[e.wrapS]),\"wrapT\"in e&&(n=N[e.wrapT]);if(t.wrapS=r,t.wrapT=n,\"anisotropic\"in e&&(t.anisotropic=e.anisotropic),\"mipmap\"in e){switch(r=!1,typeof e.mipmap){case\"string\":t.mipmapHint=B[e.mipmap],r=t.genMipmaps=!0;break;case\"boolean\":r=t.genMipmaps=e.mipmap;break;case\"object\":t.genMipmaps=!1,r=!0}!r||\"min\"in e||(t.minFilter=9984)}}function z(r,n){t.texParameteri(n,10241,r.minFilter),t.texParameteri(n,10240,r.magFilter),t.texParameteri(n,10242,r.wrapS),t.texParameteri(n,10243,r.wrapT),e.ext_texture_filter_anisotropic&&t.texParameteri(n,34046,r.anisotropic),r.genMipmaps&&(t.hint(33170,r.mipmapHint),t.generateMipmap(n))}function I(e){s.call(this),this.mipmask=0,this.internalformat=6408,this.id=vt++,this.refCount=1,this.target=e,this.texture=t.createTexture(),this.unit=-1,this.bindCount=0,this.texInfo=new P,o.profile&&(this.stats={size:0})}function D(e){t.activeTexture(33984),t.bindTexture(e.target,e.texture)}function R(){var e=xt[0];e?t.bindTexture(e.target,e.texture):t.bindTexture(3553,null)}function F(e){var r=e.texture,n=e.unit,i=e.target;0<=n&&(t.activeTexture(33984+n),t.bindTexture(i,null),xt[n]=null),t.deleteTexture(r),e.texture=null,e.params=null,e.pixels=null,e.refCount=0,delete mt[e.id],a.textureCount--}var B={\"don't care\":4352,\"dont care\":4352,nice:4354,fast:4353},N={repeat:10497,clamp:33071,mirror:33648},U={nearest:9728,linear:9729},V=j({mipmap:9987,\"nearest mipmap nearest\":9984,\"linear mipmap nearest\":9985,\"nearest mipmap linear\":9986,\"linear mipmap linear\":9987},U),q={none:0,browser:37444},H={uint8:5121,rgba4:32819,rgb565:33635,\"rgb5 a1\":32820},Y={alpha:6406,luminance:6409,\"luminance alpha\":6410,rgb:6407,rgba:6408,rgba4:32854,\"rgb5 a1\":32855,rgb565:36194},K={};e.ext_srgb&&(Y.srgb=35904,Y.srgba=35906),e.oes_texture_float&&(H.float32=H.float=5126),e.oes_texture_half_float&&(H.float16=H[\"half float\"]=36193),e.webgl_depth_texture&&(j(Y,{depth:6402,\"depth stencil\":34041}),j(H,{uint16:5123,uint32:5125,\"depth stencil\":34042})),e.webgl_compressed_texture_s3tc&&j(K,{\"rgb s3tc dxt1\":33776,\"rgba s3tc dxt1\":33777,\"rgba s3tc dxt3\":33778,\"rgba s3tc dxt5\":33779}),e.webgl_compressed_texture_atc&&j(K,{\"rgb atc\":35986,\"rgba atc explicit alpha\":35987,\"rgba atc interpolated alpha\":34798}),e.webgl_compressed_texture_pvrtc&&j(K,{\"rgb pvrtc 4bppv1\":35840,\"rgb pvrtc 2bppv1\":35841,\"rgba pvrtc 4bppv1\":35842,\"rgba pvrtc 2bppv1\":35843}),e.webgl_compressed_texture_etc1&&(K[\"rgb etc1\"]=36196);var $=Array.prototype.slice.call(t.getParameter(34467));Object.keys(K).forEach(function(t){var e=K[t];0<=$.indexOf(e)&&(Y[t]=e)});var Q=Object.keys(Y);r.textureFormats=Q;var tt=[];Object.keys(Y).forEach(function(t){tt[Y[t]]=t});var et=[];Object.keys(H).forEach(function(t){et[H[t]]=t});var rt=[];Object.keys(U).forEach(function(t){rt[U[t]]=t});var nt=[];Object.keys(V).forEach(function(t){nt[V[t]]=t});var it=[];Object.keys(N).forEach(function(t){it[N[t]]=t});var pt=Q.reduce(function(t,e){var r=Y[e];return 6409===r||6406===r||6409===r||6410===r||6402===r||34041===r?t[r]=r:32855===r||0<=e.indexOf(\"rgba\")?t[r]=6408:t[r]=6407,t},{}),dt=[],gt=[],vt=0,mt={},yt=r.maxTextureUnits,xt=Array(yt).map(function(){return null});return j(I.prototype,{bind:function(){this.bindCount+=1;var e=this.unit;if(0>e){for(var r=0;r<yt;++r){var n=xt[r];if(n){if(0<n.bindCount)continue;n.unit=-1}xt[r]=this,e=r;break}o.profile&&a.maxTextureUnits<e+1&&(a.maxTextureUnits=e+1),this.unit=e,t.activeTexture(33984+e),t.bindTexture(this.target,this.texture)}return e},unbind:function(){--this.bindCount},decRef:function(){0>=--this.refCount&&F(this)}}),o.profile&&(a.getTotalTextureSize=function(){var t=0;return Object.keys(mt).forEach(function(e){t+=mt[e].stats.size}),t}),{create2D:function(e,r){function n(t,e){var r=i.texInfo;P.call(r);var a=C();return\"number\"==typeof t?M(a,0|t,\"number\"==typeof e?0|e:0|t):t?(O(r,t),S(a,t)):M(a,1,1),r.genMipmaps&&(a.mipmask=(a.width<<1)-1),i.mipmask=a.mipmask,c(i,a),i.internalformat=a.internalformat,n.width=a.width,n.height=a.height,D(i),E(a,3553),z(r,3553),R(),L(a),o.profile&&(i.stats.size=k(i.internalformat,i.type,a.width,a.height,r.genMipmaps,!1)),n.format=tt[i.internalformat],n.type=et[i.type],n.mag=rt[r.magFilter],n.min=nt[r.minFilter],n.wrapS=it[r.wrapS],n.wrapT=it[r.wrapT],n}var i=new I(3553);return mt[i.id]=i,a.textureCount++,n(e,r),n.subimage=function(t,e,r,a){e|=0,r|=0,a|=0;var o=m();return c(o,i),o.width=0,o.height=0,p(o,t),o.width=o.width||(i.width>>a)-e,o.height=o.height||(i.height>>a)-r,D(i),d(o,3553,e,r,a),R(),T(o),n},n.resize=function(e,r){var a=0|e,s=0|r||a;if(a===i.width&&s===i.height)return n;n.width=i.width=a,n.height=i.height=s,D(i);for(var l,c=i.channels,u=i.type,h=0;i.mipmask>>h;++h){var f=a>>h,p=s>>h;if(!f||!p)break;l=G.zero.allocType(u,f*p*c),t.texImage2D(3553,h,i.format,f,p,0,i.format,i.type,l),l&&G.zero.freeType(l)}return R(),o.profile&&(i.stats.size=k(i.internalformat,i.type,a,s,!1,!1)),n},n._reglType=\"texture2d\",n._texture=i,o.profile&&(n.stats=i.stats),n.destroy=function(){i.decRef()},n},createCube:function(e,r,n,i,s,l){function h(t,e,r,n,i,a){var s,l=f.texInfo;for(P.call(l),s=0;6>s;++s)g[s]=C();if(\"number\"!=typeof t&&t){if(\"object\"==typeof t)if(e)S(g[0],t),S(g[1],e),S(g[2],r),S(g[3],n),S(g[4],i),S(g[5],a);else if(O(l,t),u(f,t),\"faces\"in t)for(t=t.faces,s=0;6>s;++s)c(g[s],f),S(g[s],t[s]);else for(s=0;6>s;++s)S(g[s],t)}else for(t=0|t||1,s=0;6>s;++s)M(g[s],t,t);for(c(f,g[0]),f.mipmask=l.genMipmaps?(g[0].width<<1)-1:g[0].mipmask,f.internalformat=g[0].internalformat,h.width=g[0].width,h.height=g[0].height,D(f),s=0;6>s;++s)E(g[s],34069+s);for(z(l,34067),R(),o.profile&&(f.stats.size=k(f.internalformat,f.type,h.width,h.height,l.genMipmaps,!0)),h.format=tt[f.internalformat],h.type=et[f.type],h.mag=rt[l.magFilter],h.min=nt[l.minFilter],h.wrapS=it[l.wrapS],h.wrapT=it[l.wrapT],s=0;6>s;++s)L(g[s]);return h}var f=new I(34067);mt[f.id]=f,a.cubeCount++;var g=Array(6);return h(e,r,n,i,s,l),h.subimage=function(t,e,r,n,i){r|=0,n|=0,i|=0;var a=m();return c(a,f),a.width=0,a.height=0,p(a,e),a.width=a.width||(f.width>>i)-r,a.height=a.height||(f.height>>i)-n,D(f),d(a,34069+t,r,n,i),R(),T(a),h},h.resize=function(e){if((e|=0)!==f.width){h.width=f.width=e,h.height=f.height=e,D(f);for(var r=0;6>r;++r)for(var n=0;f.mipmask>>n;++n)t.texImage2D(34069+r,n,f.format,e>>n,e>>n,0,f.format,f.type,null);return R(),o.profile&&(f.stats.size=k(f.internalformat,f.type,h.width,h.height,!1,!0)),h}},h._reglType=\"textureCube\",h._texture=f,o.profile&&(h.stats=f.stats),h.destroy=function(){f.decRef()},h},clear:function(){for(var e=0;e<yt;++e)t.activeTexture(33984+e),t.bindTexture(3553,null),xt[e]=null;X(mt).forEach(F),a.cubeCount=0,a.textureCount=0},getTexture:function(t){return null},restore:function(){for(var e=0;e<yt;++e){var r=xt[e];r&&(r.bindCount=0,r.unit=-1,xt[e]=null)}X(mt).forEach(function(e){e.texture=t.createTexture(),t.bindTexture(e.target,e.texture);for(var r=0;32>r;++r)if(0!=(e.mipmask&1<<r))if(3553===e.target)t.texImage2D(3553,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);else for(var n=0;6>n;++n)t.texImage2D(34069+n,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);z(e.texInfo,e.target)})}}}function A(t,e,r,n,i,a){function o(t,e,r){this.target=t,this.texture=e,this.renderbuffer=r;var n=t=0;e?(t=e.width,n=e.height):r&&(t=r.width,n=r.height),this.width=t,this.height=n}function s(t){t&&(t.texture&&t.texture._texture.decRef(),t.renderbuffer&&t.renderbuffer._renderbuffer.decRef())}function l(t,e,r){t&&(t.texture?t.texture._texture.refCount+=1:t.renderbuffer._renderbuffer.refCount+=1)}function c(e,r){r&&(r.texture?t.framebufferTexture2D(36160,e,r.target,r.texture._texture.texture,0):t.framebufferRenderbuffer(36160,e,36161,r.renderbuffer._renderbuffer.renderbuffer))}function u(t){var e=3553,r=null,n=null,i=t;return\"object\"==typeof t&&(i=t.data,\"target\"in t&&(e=0|t.target)),\"texture2d\"===(t=i._reglType)?r=i:\"textureCube\"===t?r=i:\"renderbuffer\"===t&&(n=i,e=36161),new o(e,r,n)}function h(t,e,r,a,s){return r?((t=n.create2D({width:t,height:e,format:a,type:s}))._texture.refCount=0,new o(3553,t,null)):((t=i.create({width:t,height:e,format:a}))._renderbuffer.refCount=0,new o(36161,null,t))}function f(t){return t&&(t.texture||t.renderbuffer)}function p(t,e,r){t&&(t.texture?t.texture.resize(e,r):t.renderbuffer&&t.renderbuffer.resize(e,r),t.width=e,t.height=r)}function d(){this.id=k++,T[this.id]=this,this.framebuffer=t.createFramebuffer(),this.height=this.width=0,this.colorAttachments=[],this.depthStencilAttachment=this.stencilAttachment=this.depthAttachment=null}function g(t){t.colorAttachments.forEach(s),s(t.depthAttachment),s(t.stencilAttachment),s(t.depthStencilAttachment)}function v(e){t.deleteFramebuffer(e.framebuffer),e.framebuffer=null,a.framebufferCount--,delete T[e.id]}function m(e){var n;t.bindFramebuffer(36160,e.framebuffer);var i=e.colorAttachments;for(n=0;n<i.length;++n)c(36064+n,i[n]);for(n=i.length;n<r.maxColorAttachments;++n)t.framebufferTexture2D(36160,36064+n,3553,null,0);t.framebufferTexture2D(36160,33306,3553,null,0),t.framebufferTexture2D(36160,36096,3553,null,0),t.framebufferTexture2D(36160,36128,3553,null,0),c(36096,e.depthAttachment),c(36128,e.stencilAttachment),c(33306,e.depthStencilAttachment),t.checkFramebufferStatus(36160),t.isContextLost(),t.bindFramebuffer(36160,x.next?x.next.framebuffer:null),x.cur=x.next,t.getError()}function y(t,e){function r(t,e){var i,a=0,o=0,s=!0,c=!0;i=null;var p=!0,d=\"rgba\",v=\"uint8\",y=1,x=null,w=null,k=null,T=!1;\"number\"==typeof t?(a=0|t,o=0|e||a):t?(\"shape\"in t?(a=(o=t.shape)[0],o=o[1]):(\"radius\"in t&&(a=o=t.radius),\"width\"in t&&(a=t.width),\"height\"in t&&(o=t.height)),(\"color\"in t||\"colors\"in t)&&(i=t.color||t.colors,Array.isArray(i)),i||(\"colorCount\"in t&&(y=0|t.colorCount),\"colorTexture\"in t&&(p=!!t.colorTexture,d=\"rgba4\"),\"colorType\"in t&&(v=t.colorType,!p)&&(\"half float\"===v||\"float16\"===v?d=\"rgba16f\":\"float\"!==v&&\"float32\"!==v||(d=\"rgba32f\")),\"colorFormat\"in t&&(d=t.colorFormat,0<=b.indexOf(d)?p=!0:0<=_.indexOf(d)&&(p=!1))),(\"depthTexture\"in t||\"depthStencilTexture\"in t)&&(T=!(!t.depthTexture&&!t.depthStencilTexture)),\"depth\"in t&&(\"boolean\"==typeof t.depth?s=t.depth:(x=t.depth,c=!1)),\"stencil\"in t&&(\"boolean\"==typeof t.stencil?c=t.stencil:(w=t.stencil,s=!1)),\"depthStencil\"in t&&(\"boolean\"==typeof t.depthStencil?s=c=t.depthStencil:(k=t.depthStencil,c=s=!1))):a=o=1;var A=null,M=null,S=null,E=null;if(Array.isArray(i))A=i.map(u);else if(i)A=[u(i)];else for(A=Array(y),i=0;i<y;++i)A[i]=h(a,o,p,d,v);for(a=a||A[0].width,o=o||A[0].height,x?M=u(x):s&&!c&&(M=h(a,o,T,\"depth\",\"uint32\")),w?S=u(w):c&&!s&&(S=h(a,o,!1,\"stencil\",\"uint8\")),k?E=u(k):!x&&!w&&c&&s&&(E=h(a,o,T,\"depth stencil\",\"depth stencil\")),s=null,i=0;i<A.length;++i)l(A[i]),A[i]&&A[i].texture&&(c=yt[A[i].texture._texture.format]*xt[A[i].texture._texture.type],null===s&&(s=c));return l(M),l(S),l(E),g(n),n.width=a,n.height=o,n.colorAttachments=A,n.depthAttachment=M,n.stencilAttachment=S,n.depthStencilAttachment=E,r.color=A.map(f),r.depth=f(M),r.stencil=f(S),r.depthStencil=f(E),r.width=n.width,r.height=n.height,m(n),r}var n=new d;return a.framebufferCount++,r(t,e),j(r,{resize:function(t,e){var i=Math.max(0|t,1),a=Math.max(0|e||i,1);if(i===n.width&&a===n.height)return r;for(var o=n.colorAttachments,s=0;s<o.length;++s)p(o[s],i,a);return p(n.depthAttachment,i,a),p(n.stencilAttachment,i,a),p(n.depthStencilAttachment,i,a),n.width=r.width=i,n.height=r.height=a,m(n),r},_reglType:\"framebuffer\",_framebuffer:n,destroy:function(){v(n),g(n)},use:function(t){x.setFBO({framebuffer:r},t)}})}var x={cur:null,next:null,dirty:!1,setFBO:null},b=[\"rgba\"],_=[\"rgba4\",\"rgb565\",\"rgb5 a1\"];e.ext_srgb&&_.push(\"srgba\"),e.ext_color_buffer_half_float&&_.push(\"rgba16f\",\"rgb16f\"),e.webgl_color_buffer_float&&_.push(\"rgba32f\");var w=[\"uint8\"];e.oes_texture_half_float&&w.push(\"half float\",\"float16\"),e.oes_texture_float&&w.push(\"float\",\"float32\");var k=0,T={};return j(x,{getFramebuffer:function(t){return\"function\"==typeof t&&\"framebuffer\"===t._reglType&&(t=t._framebuffer)instanceof d?t:null},create:y,createCube:function(t){function e(t){var i,a={color:null},o=0,s=null;i=\"rgba\";var l=\"uint8\",c=1;if(\"number\"==typeof t?o=0|t:t?(\"shape\"in t?o=t.shape[0]:(\"radius\"in t&&(o=0|t.radius),\"width\"in t?o=0|t.width:\"height\"in t&&(o=0|t.height)),(\"color\"in t||\"colors\"in t)&&(s=t.color||t.colors,Array.isArray(s)),s||(\"colorCount\"in t&&(c=0|t.colorCount),\"colorType\"in t&&(l=t.colorType),\"colorFormat\"in t&&(i=t.colorFormat)),\"depth\"in t&&(a.depth=t.depth),\"stencil\"in t&&(a.stencil=t.stencil),\"depthStencil\"in t&&(a.depthStencil=t.depthStencil)):o=1,s)if(Array.isArray(s))for(t=[],i=0;i<s.length;++i)t[i]=s[i];else t=[s];else for(t=Array(c),s={radius:o,format:i,type:l},i=0;i<c;++i)t[i]=n.createCube(s);for(a.color=Array(t.length),i=0;i<t.length;++i)c=t[i],o=o||c.width,a.color[i]={target:34069,data:t[i]};for(i=0;6>i;++i){for(c=0;c<t.length;++c)a.color[c].target=34069+i;0<i&&(a.depth=r[0].depth,a.stencil=r[0].stencil,a.depthStencil=r[0].depthStencil),r[i]?r[i](a):r[i]=y(a)}return j(e,{width:o,height:o,color:t})}var r=Array(6);return e(t),j(e,{faces:r,resize:function(t){var n=0|t;if(n===e.width)return e;var i=e.color;for(t=0;t<i.length;++t)i[t].resize(n);for(t=0;6>t;++t)r[t].resize(n);return e.width=e.height=n,e},_reglType:\"framebufferCube\",destroy:function(){r.forEach(function(t){t.destroy()})}})},clear:function(){X(T).forEach(v)},restore:function(){x.cur=null,x.next=null,x.dirty=!0,X(T).forEach(function(e){e.framebuffer=t.createFramebuffer(),m(e)})}})}function M(){this.w=this.z=this.y=this.x=this.state=0,this.buffer=null,this.size=0,this.normalized=!1,this.type=5126,this.divisor=this.stride=this.offset=0}function S(t,e,r,n){function i(t,e,r,n){this.name=t,this.id=e,this.location=r,this.info=n}function a(t,e){for(var r=0;r<t.length;++r)if(t[r].id===e.id)return void(t[r].location=e.location);t.push(e)}function o(r,n,i){if(!(o=(i=35632===r?c:u)[n])){var a=e.str(n),o=t.createShader(r);t.shaderSource(o,a),t.compileShader(o),i[n]=o}return o}function s(t,e){this.id=p++,this.fragId=t,this.vertId=e,this.program=null,this.uniforms=[],this.attributes=[],n.profile&&(this.stats={uniformsCount:0,attributesCount:0})}function l(r,s){var l,c;l=o(35632,r.fragId),c=o(35633,r.vertId);var u=r.program=t.createProgram();t.attachShader(u,l),t.attachShader(u,c),t.linkProgram(u);var h=t.getProgramParameter(u,35718);n.profile&&(r.stats.uniformsCount=h);var f=r.uniforms;for(l=0;l<h;++l)if(c=t.getActiveUniform(u,l))if(1<c.size)for(var p=0;p<c.size;++p){var d=c.name.replace(\"[0]\",\"[\"+p+\"]\");a(f,new i(d,e.id(d),t.getUniformLocation(u,d),c))}else a(f,new i(c.name,e.id(c.name),t.getUniformLocation(u,c.name),c));for(h=t.getProgramParameter(u,35721),n.profile&&(r.stats.attributesCount=h),f=r.attributes,l=0;l<h;++l)(c=t.getActiveAttrib(u,l))&&a(f,new i(c.name,e.id(c.name),t.getAttribLocation(u,c.name),c))}var c={},u={},h={},f=[],p=0;return n.profile&&(r.getMaxUniformsCount=function(){var t=0;return f.forEach(function(e){e.stats.uniformsCount>t&&(t=e.stats.uniformsCount)}),t},r.getMaxAttributesCount=function(){var t=0;return f.forEach(function(e){e.stats.attributesCount>t&&(t=e.stats.attributesCount)}),t}),{clear:function(){var e=t.deleteShader.bind(t);X(c).forEach(e),c={},X(u).forEach(e),u={},f.forEach(function(e){t.deleteProgram(e.program)}),f.length=0,h={},r.shaderCount=0},program:function(t,e,n){var i=h[e];i||(i=h[e]={});var a=i[t];return a||(a=new s(e,t),r.shaderCount++,l(a),i[t]=a,f.push(a)),a},restore:function(){c={},u={};for(var t=0;t<f.length;++t)l(f[t])},shader:o,frag:-1,vert:-1}}function E(t,e,r,n,i,a,o){function s(i){var a;a=null===e.next?5121:e.next.colorAttachments[0].texture._texture.type;var o=0,s=0,l=n.framebufferWidth,c=n.framebufferHeight,u=null;return W(i)?u=i:i&&(o=0|i.x,s=0|i.y,l=0|(i.width||n.framebufferWidth-o),c=0|(i.height||n.framebufferHeight-s),u=i.data||null),r(),i=l*c*4,u||(5121===a?u=new Uint8Array(i):5126===a&&(u=u||new Float32Array(i))),t.pixelStorei(3333,4),t.readPixels(o,s,l,c,6408,a,u),u}return function(t){return t&&\"framebuffer\"in t?function(t){var r;return e.setFBO({framebuffer:t.framebuffer},function(){r=s(t)}),r}(t):s(t)}}function C(t){return Array.prototype.slice.call(t)}function L(t){return C(t).join(\"\")}function P(){function t(){var t=[],e=[];return j(function(){t.push.apply(t,C(arguments))},{def:function(){var n=\"v\"+r++;return e.push(n),0<arguments.length&&(t.push(n,\"=\"),t.push.apply(t,C(arguments)),t.push(\";\")),n},toString:function(){return L([0<e.length?\"var \"+e+\";\":\"\",L(t)])}})}function e(){function e(t,e){n(t,e,\"=\",r.def(t,e),\";\")}var r=t(),n=t(),i=r.toString,a=n.toString;return j(function(){r.apply(r,C(arguments))},{def:r.def,entry:r,exit:n,save:e,set:function(t,n,i){e(t,n),r(t,n,\"=\",i,\";\")},toString:function(){return i()+a()}})}var r=0,n=[],i=[],a=t(),o={};return{global:a,link:function(t){for(var e=0;e<i.length;++e)if(i[e]===t)return n[e];return e=\"g\"+r++,n.push(e),i.push(t),e},block:t,proc:function(t,r){function n(){var t=\"a\"+i.length;return i.push(t),t}var i=[];r=r||0;for(var a=0;a<r;++a)n();var s=(a=e()).toString;return o[t]=j(a,{arg:n,toString:function(){return L([\"function(\",i.join(),\"){\",s(),\"}\"])}})},scope:e,cond:function(){var t=L(arguments),r=e(),n=e(),i=r.toString,a=n.toString;return j(r,{then:function(){return r.apply(r,C(arguments)),this},else:function(){return n.apply(n,C(arguments)),this},toString:function(){var e=a();return e&&(e=\"else{\"+e+\"}\"),L([\"if(\",t,\"){\",i(),\"}\",e])}})},compile:function(){var t=['\"use strict\";',a,\"return {\"];Object.keys(o).forEach(function(e){t.push('\"',e,'\":',o[e].toString(),\",\")}),t.push(\"}\");var e=L(t).replace(/;/g,\";\\n\").replace(/}/g,\"}\\n\").replace(/{/g,\"{\\n\");return Function.apply(null,n.concat(e)).apply(null,i)}}}function O(t){return Array.isArray(t)||W(t)||l(t)}function z(t){return t.sort(function(t,e){return\"viewport\"===t?-1:\"viewport\"===e?1:t<e?-1:1})}function I(t,e,r,n){this.thisDep=t,this.contextDep=e,this.propDep=r,this.append=n}function D(t){return t&&!(t.thisDep||t.contextDep||t.propDep)}function R(t){return new I(!1,!1,!1,t)}function F(t,e){var r=t.type;return 0===r?new I(!0,1<=(r=t.data.length),2<=r,e):4===r?new I((r=t.data).thisDep,r.contextDep,r.propDep,e):new I(3===r,2===r,1===r,e)}function B(t,e,r,n,i,o,s,l,c,u,h,f,p,d,g){function m(t){return t.replace(\".\",\"_\")}function y(t,e,r){var n=m(t);nt.push(t),et[n]=tt[n]=!!r,it[n]=e}function x(t,e,r){var n=m(t);nt.push(t),Array.isArray(r)?(tt[n]=r.slice(),et[n]=r.slice()):tt[n]=et[n]=r,at[n]=e}function b(){var t=P(),r=t.link,n=t.global;t.id=lt++,t.batchId=\"0\";var i=r(ot),a=t.shared={props:\"a0\"};Object.keys(ot).forEach(function(t){a[t]=n.def(i,\".\",t)});var o=t.next={},s=t.current={};Object.keys(at).forEach(function(t){Array.isArray(tt[t])&&(o[t]=n.def(a.next,\".\",t),s[t]=n.def(a.current,\".\",t))});var l=t.constants={};Object.keys(st).forEach(function(t){l[t]=n.def(JSON.stringify(st[t]))}),t.invoke=function(e,n){switch(n.type){case 0:var i=[\"this\",a.context,a.props,t.batchId];return e.def(r(n.data),\".call(\",i.slice(0,Math.max(n.data.length+1,4)),\")\");case 1:return e.def(a.props,n.data);case 2:return e.def(a.context,n.data);case 3:return e.def(\"this\",n.data);case 4:return n.data.append(t,e),n.data.ref}},t.attribCache={};var c={};return t.scopeAttrib=function(t){if((t=e.id(t))in c)return c[t];var n=u.scope[t];return n||(n=u.scope[t]=new Z),c[t]=r(n)},t}function _(t,e){var r=t.static,n=t.dynamic;if(\"framebuffer\"in r){var i=r.framebuffer;return i?(i=l.getFramebuffer(i),R(function(t,e){var r=t.link(i),n=t.shared;return e.set(n.framebuffer,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\".width\"),e.set(n,\".framebufferHeight\",r+\".height\"),r})):R(function(t,e){var r=t.shared;return e.set(r.framebuffer,\".next\",\"null\"),r=r.context,e.set(r,\".framebufferWidth\",r+\".drawingBufferWidth\"),e.set(r,\".framebufferHeight\",r+\".drawingBufferHeight\"),\"null\"})}if(\"framebuffer\"in n){var a=n.framebuffer;return F(a,function(t,e){var r=t.invoke(e,a),n=t.shared,i=n.framebuffer;r=e.def(i,\".getFramebuffer(\",r,\")\");return e.set(i,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\"?\"+r+\".width:\"+n+\".drawingBufferWidth\"),e.set(n,\".framebufferHeight\",r+\"?\"+r+\".height:\"+n+\".drawingBufferHeight\"),r})}return null}function w(t){function r(t){if(t in n){var r=e.id(n[t]);return(t=R(function(){return r})).id=r,t}if(t in i){var a=i[t];return F(a,function(t,e){var r=t.invoke(e,a);return e.def(t.shared.strings,\".id(\",r,\")\")})}return null}var n=t.static,i=t.dynamic,a=r(\"frag\"),o=r(\"vert\"),s=null;return D(a)&&D(o)?(s=h.program(o.id,a.id),t=R(function(t,e){return t.link(s)})):t=new I(a&&a.thisDep||o&&o.thisDep,a&&a.contextDep||o&&o.contextDep,a&&a.propDep||o&&o.propDep,function(t,e){var r,n,i=t.shared.shader;return r=a?a.append(t,e):e.def(i,\".\",\"frag\"),n=o?o.append(t,e):e.def(i,\".\",\"vert\"),e.def(i+\".program(\"+n+\",\"+r+\")\")}),{frag:a,vert:o,progVar:t,program:s}}function k(t,e){function r(t,e){if(t in n){var r=0|n[t];return R(function(t,n){return e&&(t.OFFSET=r),r})}if(t in i){var o=i[t];return F(o,function(t,r){var n=t.invoke(r,o);return e&&(t.OFFSET=n),n})}return e&&a?R(function(t,e){return t.OFFSET=\"0\",0}):null}var n=t.static,i=t.dynamic,a=function(){if(\"elements\"in n){var t=n.elements;O(t)?t=o.getElements(o.create(t,!0)):t&&(t=o.getElements(t));var e=R(function(e,r){if(t){var n=e.link(t);return e.ELEMENTS=n}return e.ELEMENTS=null});return e.value=t,e}if(\"elements\"in i){var r=i.elements;return F(r,function(t,e){var n=(i=t.shared).isBufferArgs,i=i.elements,a=t.invoke(e,r),o=e.def(\"null\");n=e.def(n,\"(\",a,\")\"),a=t.cond(n).then(o,\"=\",i,\".createStream(\",a,\");\").else(o,\"=\",i,\".getElements(\",a,\");\");return e.entry(a),e.exit(t.cond(n).then(i,\".destroyStream(\",o,\");\")),t.ELEMENTS=o})}return null}(),s=r(\"offset\",!0);return{elements:a,primitive:function(){if(\"primitive\"in n){var t=n.primitive;return R(function(e,r){return rt[t]})}if(\"primitive\"in i){var e=i.primitive;return F(e,function(t,r){var n=t.constants.primTypes,i=t.invoke(r,e);return r.def(n,\"[\",i,\"]\")})}return a?D(a)?a.value?R(function(t,e){return e.def(t.ELEMENTS,\".primType\")}):R(function(){return 4}):new I(a.thisDep,a.contextDep,a.propDep,function(t,e){var r=t.ELEMENTS;return e.def(r,\"?\",r,\".primType:\",4)}):null}(),count:function(){if(\"count\"in n){var t=0|n.count;return R(function(){return t})}if(\"count\"in i){var e=i.count;return F(e,function(t,r){return t.invoke(r,e)})}return a?D(a)?a?s?new I(s.thisDep,s.contextDep,s.propDep,function(t,e){return e.def(t.ELEMENTS,\".vertCount-\",t.OFFSET)}):R(function(t,e){return e.def(t.ELEMENTS,\".vertCount\")}):R(function(){return-1}):new I(a.thisDep||s.thisDep,a.contextDep||s.contextDep,a.propDep||s.propDep,function(t,e){var r=t.ELEMENTS;return t.OFFSET?e.def(r,\"?\",r,\".vertCount-\",t.OFFSET,\":-1\"):e.def(r,\"?\",r,\".vertCount:-1\")}):null}(),instances:r(\"instances\",!1),offset:s}}function T(t,r){var n=t.static,a=t.dynamic,o={};return Object.keys(n).forEach(function(t){var r=n[t],a=e.id(t),s=new Z;if(O(r))s.state=1,s.buffer=i.getBuffer(i.create(r,34962,!1,!0)),s.type=0;else if(c=i.getBuffer(r))s.state=1,s.buffer=c,s.type=0;else if(\"constant\"in r){var l=r.constant;s.buffer=\"null\",s.state=2,\"number\"==typeof l?s.x=l:bt.forEach(function(t,e){e<l.length&&(s[t]=l[e])})}else{var c=O(r.buffer)?i.getBuffer(i.create(r.buffer,34962,!1,!0)):i.getBuffer(r.buffer),u=0|r.offset,h=0|r.stride,f=0|r.size,p=!!r.normalized,d=0;\"type\"in r&&(d=K[r.type]),r=0|r.divisor,s.buffer=c,s.state=1,s.size=f,s.normalized=p,s.type=d||c.dtype,s.offset=u,s.stride=h,s.divisor=r}o[t]=R(function(t,e){var r=t.attribCache;if(a in r)return r[a];var n={isStream:!1};return Object.keys(s).forEach(function(t){n[t]=s[t]}),s.buffer&&(n.buffer=t.link(s.buffer),n.type=n.type||n.buffer+\".dtype\"),r[a]=n})}),Object.keys(a).forEach(function(t){var e=a[t];o[t]=F(e,function(t,r){function n(t){r(l[t],\"=\",i,\".\",t,\"|0;\")}var i=t.invoke(r,e),a=t.shared,o=a.isBufferArgs,s=a.buffer,l={isStream:r.def(!1)},c=new Z;c.state=1,Object.keys(c).forEach(function(t){l[t]=r.def(\"\"+c[t])});var u=l.buffer,h=l.type;return r(\"if(\",o,\"(\",i,\")){\",l.isStream,\"=true;\",u,\"=\",s,\".createStream(\",34962,\",\",i,\");\",h,\"=\",u,\".dtype;\",\"}else{\",u,\"=\",s,\".getBuffer(\",i,\");\",\"if(\",u,\"){\",h,\"=\",u,\".dtype;\",'}else if(\"constant\" in ',i,\"){\",l.state,\"=\",2,\";\",\"if(typeof \"+i+'.constant === \"number\"){',l[bt[0]],\"=\",i,\".constant;\",bt.slice(1).map(function(t){return l[t]}).join(\"=\"),\"=0;\",\"}else{\",bt.map(function(t,e){return l[t]+\"=\"+i+\".constant.length>\"+e+\"?\"+i+\".constant[\"+e+\"]:0;\"}).join(\"\"),\"}}else{\",\"if(\",o,\"(\",i,\".buffer)){\",u,\"=\",s,\".createStream(\",34962,\",\",i,\".buffer);\",\"}else{\",u,\"=\",s,\".getBuffer(\",i,\".buffer);\",\"}\",h,'=\"type\" in ',i,\"?\",a.glTypes,\"[\",i,\".type]:\",u,\".dtype;\",l.normalized,\"=!!\",i,\".normalized;\"),n(\"size\"),n(\"offset\"),n(\"stride\"),n(\"divisor\"),r(\"}}\"),r.exit(\"if(\",l.isStream,\"){\",s,\".destroyStream(\",u,\");\",\"}\"),l})}),o}function A(t,e,r,n,i){var o=_(t),s=function(t,e,r){function n(t){if(t in i){var r=i[t];t=!0;var n,o,s=0|r.x,l=0|r.y;return\"width\"in r?n=0|r.width:t=!1,\"height\"in r?o=0|r.height:t=!1,new I(!t&&e&&e.thisDep,!t&&e&&e.contextDep,!t&&e&&e.propDep,function(t,e){var i=t.shared.context,a=n;\"width\"in r||(a=e.def(i,\".\",\"framebufferWidth\",\"-\",s));var c=o;return\"height\"in r||(c=e.def(i,\".\",\"framebufferHeight\",\"-\",l)),[s,l,a,c]})}if(t in a){var c=a[t];return t=F(c,function(t,e){var r=t.invoke(e,c),n=t.shared.context,i=e.def(r,\".x|0\"),a=e.def(r,\".y|0\");return[i,a,e.def('\"width\" in ',r,\"?\",r,\".width|0:\",\"(\",n,\".\",\"framebufferWidth\",\"-\",i,\")\"),r=e.def('\"height\" in ',r,\"?\",r,\".height|0:\",\"(\",n,\".\",\"framebufferHeight\",\"-\",a,\")\")]}),e&&(t.thisDep=t.thisDep||e.thisDep,t.contextDep=t.contextDep||e.contextDep,t.propDep=t.propDep||e.propDep),t}return e?new I(e.thisDep,e.contextDep,e.propDep,function(t,e){var r=t.shared.context;return[0,0,e.def(r,\".\",\"framebufferWidth\"),e.def(r,\".\",\"framebufferHeight\")]}):null}var i=t.static,a=t.dynamic;if(t=n(\"viewport\")){var o=t;t=new I(t.thisDep,t.contextDep,t.propDep,function(t,e){var r=o.append(t,e),n=t.shared.context;return e.set(n,\".viewportWidth\",r[2]),e.set(n,\".viewportHeight\",r[3]),r})}return{viewport:t,scissor_box:n(\"scissor.box\")}}(t,o),l=k(t),c=function(t,e){var r=t.static,n=t.dynamic,i={};return nt.forEach(function(t){function e(e,a){if(t in r){var s=e(r[t]);i[o]=R(function(){return s})}else if(t in n){var l=n[t];i[o]=F(l,function(t,e){return a(t,e,t.invoke(e,l))})}}var o=m(t);switch(t){case\"cull.enable\":case\"blend.enable\":case\"dither\":case\"stencil.enable\":case\"depth.enable\":case\"scissor.enable\":case\"polygonOffset.enable\":case\"sample.alpha\":case\"sample.enable\":case\"depth.mask\":return e(function(t){return t},function(t,e,r){return r});case\"depth.func\":return e(function(t){return kt[t]},function(t,e,r){return e.def(t.constants.compareFuncs,\"[\",r,\"]\")});case\"depth.range\":return e(function(t){return t},function(t,e,r){return[e.def(\"+\",r,\"[0]\"),e=e.def(\"+\",r,\"[1]\")]});case\"blend.func\":return e(function(t){return[wt[\"srcRGB\"in t?t.srcRGB:t.src],wt[\"dstRGB\"in t?t.dstRGB:t.dst],wt[\"srcAlpha\"in t?t.srcAlpha:t.src],wt[\"dstAlpha\"in t?t.dstAlpha:t.dst]]},function(t,e,r){function n(t,n){return e.def('\"',t,n,'\" in ',r,\"?\",r,\".\",t,n,\":\",r,\".\",t)}t=t.constants.blendFuncs;var i=n(\"src\",\"RGB\"),a=n(\"dst\",\"RGB\"),o=(i=e.def(t,\"[\",i,\"]\"),e.def(t,\"[\",n(\"src\",\"Alpha\"),\"]\"));return[i,a=e.def(t,\"[\",a,\"]\"),o,t=e.def(t,\"[\",n(\"dst\",\"Alpha\"),\"]\")]});case\"blend.equation\":return e(function(t){return\"string\"==typeof t?[J[t],J[t]]:\"object\"==typeof t?[J[t.rgb],J[t.alpha]]:void 0},function(t,e,r){var n=t.constants.blendEquations,i=e.def(),a=e.def();return(t=t.cond(\"typeof \",r,'===\"string\"')).then(i,\"=\",a,\"=\",n,\"[\",r,\"];\"),t.else(i,\"=\",n,\"[\",r,\".rgb];\",a,\"=\",n,\"[\",r,\".alpha];\"),e(t),[i,a]});case\"blend.color\":return e(function(t){return a(4,function(e){return+t[e]})},function(t,e,r){return a(4,function(t){return e.def(\"+\",r,\"[\",t,\"]\")})});case\"stencil.mask\":return e(function(t){return 0|t},function(t,e,r){return e.def(r,\"|0\")});case\"stencil.func\":return e(function(t){return[kt[t.cmp||\"keep\"],t.ref||0,\"mask\"in t?t.mask:-1]},function(t,e,r){return[t=e.def('\"cmp\" in ',r,\"?\",t.constants.compareFuncs,\"[\",r,\".cmp]\",\":\",7680),e.def(r,\".ref|0\"),e=e.def('\"mask\" in ',r,\"?\",r,\".mask|0:-1\")]});case\"stencil.opFront\":case\"stencil.opBack\":return e(function(e){return[\"stencil.opBack\"===t?1029:1028,Tt[e.fail||\"keep\"],Tt[e.zfail||\"keep\"],Tt[e.zpass||\"keep\"]]},function(e,r,n){function i(t){return r.def('\"',t,'\" in ',n,\"?\",a,\"[\",n,\".\",t,\"]:\",7680)}var a=e.constants.stencilOps;return[\"stencil.opBack\"===t?1029:1028,i(\"fail\"),i(\"zfail\"),i(\"zpass\")]});case\"polygonOffset.offset\":return e(function(t){return[0|t.factor,0|t.units]},function(t,e,r){return[e.def(r,\".factor|0\"),e=e.def(r,\".units|0\")]});case\"cull.face\":return e(function(t){var e=0;return\"front\"===t?e=1028:\"back\"===t&&(e=1029),e},function(t,e,r){return e.def(r,'===\"front\"?',1028,\":\",1029)});case\"lineWidth\":return e(function(t){return t},function(t,e,r){return r});case\"frontFace\":return e(function(t){return At[t]},function(t,e,r){return e.def(r+'===\"cw\"?2304:2305')});case\"colorMask\":return e(function(t){return t.map(function(t){return!!t})},function(t,e,r){return a(4,function(t){return\"!!\"+r+\"[\"+t+\"]\"})});case\"sample.coverage\":return e(function(t){return[\"value\"in t?t.value:1,!!t.invert]},function(t,e,r){return[e.def('\"value\" in ',r,\"?+\",r,\".value:1\"),e=e.def(\"!!\",r,\".invert\")]})}}),i}(t),u=w(t),h=s.viewport;return h&&(c.viewport=h),(s=s[h=m(\"scissor.box\")])&&(c[h]=s),(o={framebuffer:o,draw:l,shader:u,state:c,dirty:s=0<Object.keys(c).length}).profile=function(t){var e,r=t.static;if(t=t.dynamic,\"profile\"in r){var n=!!r.profile;(e=R(function(t,e){return n})).enable=n}else if(\"profile\"in t){var i=t.profile;e=F(i,function(t,e){return t.invoke(e,i)})}return e}(t),o.uniforms=function(t,e){var r=t.static,n=t.dynamic,i={};return Object.keys(r).forEach(function(t){var e,n=r[t];if(\"number\"==typeof n||\"boolean\"==typeof n)e=R(function(){return n});else if(\"function\"==typeof n){var o=n._reglType;\"texture2d\"===o||\"textureCube\"===o?e=R(function(t){return t.link(n)}):\"framebuffer\"!==o&&\"framebufferCube\"!==o||(e=R(function(t){return t.link(n.color[0])}))}else v(n)&&(e=R(function(t){return t.global.def(\"[\",a(n.length,function(t){return n[t]}),\"]\")}));e.value=n,i[t]=e}),Object.keys(n).forEach(function(t){var e=n[t];i[t]=F(e,function(t,r){return t.invoke(r,e)})}),i}(r),o.attributes=T(e),o.context=function(t){var e=t.static,r=t.dynamic,n={};return Object.keys(e).forEach(function(t){var r=e[t];n[t]=R(function(t,e){return\"number\"==typeof r||\"boolean\"==typeof r?\"\"+r:t.link(r)})}),Object.keys(r).forEach(function(t){var e=r[t];n[t]=F(e,function(t,r){return t.invoke(r,e)})}),n}(n),o}function M(t,e,r){var n=t.shared.context,i=t.scope();Object.keys(r).forEach(function(a){e.save(n,\".\"+a),i(n,\".\",a,\"=\",r[a].append(t,e),\";\")}),e(i)}function S(t,e,r,n){var i,a=(s=t.shared).gl,o=s.framebuffer;Q&&(i=e.def(s.extensions,\".webgl_draw_buffers\"));var s=(l=t.constants).drawBuffer,l=l.backBuffer;t=r?r.append(t,e):e.def(o,\".next\"),n||e(\"if(\",t,\"!==\",o,\".cur){\"),e(\"if(\",t,\"){\",a,\".bindFramebuffer(\",36160,\",\",t,\".framebuffer);\"),Q&&e(i,\".drawBuffersWEBGL(\",s,\"[\",t,\".colorAttachments.length]);\"),e(\"}else{\",a,\".bindFramebuffer(\",36160,\",null);\"),Q&&e(i,\".drawBuffersWEBGL(\",l,\");\"),e(\"}\",o,\".cur=\",t,\";\"),n||e(\"}\")}function E(t,e,r){var n=t.shared,i=n.gl,o=t.current,s=t.next,l=n.current,c=n.next,u=t.cond(l,\".dirty\");nt.forEach(function(e){var n,h;if(!((e=m(e))in r.state))if(e in s){n=s[e],h=o[e];var f=a(tt[e].length,function(t){return u.def(n,\"[\",t,\"]\")});u(t.cond(f.map(function(t,e){return t+\"!==\"+h+\"[\"+e+\"]\"}).join(\"||\")).then(i,\".\",at[e],\"(\",f,\");\",f.map(function(t,e){return h+\"[\"+e+\"]=\"+t}).join(\";\"),\";\"))}else n=u.def(c,\".\",e),f=t.cond(n,\"!==\",l,\".\",e),u(f),e in it?f(t.cond(n).then(i,\".enable(\",it[e],\");\").else(i,\".disable(\",it[e],\");\"),l,\".\",e,\"=\",n,\";\"):f(i,\".\",at[e],\"(\",n,\");\",l,\".\",e,\"=\",n,\";\")}),0===Object.keys(r.state).length&&u(l,\".dirty=false;\"),e(u)}function C(t,e,r,n){var i=t.shared,a=t.current,o=i.current,s=i.gl;z(Object.keys(r)).forEach(function(i){var l=r[i];if(!n||n(l)){var c=l.append(t,e);if(it[i]){var u=it[i];D(l)?e(s,c?\".enable(\":\".disable(\",u,\");\"):e(t.cond(c).then(s,\".enable(\",u,\");\").else(s,\".disable(\",u,\");\")),e(o,\".\",i,\"=\",c,\";\")}else if(v(c)){var h=a[i];e(s,\".\",at[i],\"(\",c,\");\",c.map(function(t,e){return h+\"[\"+e+\"]=\"+t}).join(\";\"),\";\")}else e(s,\".\",at[i],\"(\",c,\");\",o,\".\",i,\"=\",c,\";\")}})}function L(t,e){$&&(t.instancing=e.def(t.shared.extensions,\".angle_instanced_arrays\"))}function B(t,e,r,n,i){function a(){return\"undefined\"==typeof performance?\"Date.now()\":\"performance.now()\"}function o(t){t(c=e.def(),\"=\",a(),\";\"),\"string\"==typeof i?t(f,\".count+=\",i,\";\"):t(f,\".count++;\"),d&&(n?t(u=e.def(),\"=\",g,\".getNumPendingQueries();\"):t(g,\".beginQuery(\",f,\");\"))}function s(t){t(f,\".cpuTime+=\",a(),\"-\",c,\";\"),d&&(n?t(g,\".pushScopeStats(\",u,\",\",g,\".getNumPendingQueries(),\",f,\");\"):t(g,\".endQuery();\"))}function l(t){var r=e.def(p,\".profile\");e(p,\".profile=\",t,\";\"),e.exit(p,\".profile=\",r,\";\")}var c,u,h=t.shared,f=t.stats,p=h.current,g=h.timer;if(r=r.profile){if(D(r))return void(r.enable?(o(e),s(e.exit),l(\"true\")):l(\"false\"));l(r=r.append(t,e))}else r=e.def(p,\".profile\");o(h=t.block()),e(\"if(\",r,\"){\",h,\"}\"),s(t=t.block()),e.exit(\"if(\",r,\"){\",t,\"}\")}function N(t,e,r,n,i){function a(r,n,i){function a(){e(\"if(!\",u,\".buffer){\",l,\".enableVertexAttribArray(\",c,\");}\");var r,a=i.type;r=i.size?e.def(i.size,\"||\",n):n,e(\"if(\",u,\".type!==\",a,\"||\",u,\".size!==\",r,\"||\",p.map(function(t){return u+\".\"+t+\"!==\"+i[t]}).join(\"||\"),\"){\",l,\".bindBuffer(\",34962,\",\",h,\".buffer);\",l,\".vertexAttribPointer(\",[c,r,a,i.normalized,i.stride,i.offset],\");\",u,\".type=\",a,\";\",u,\".size=\",r,\";\",p.map(function(t){return u+\".\"+t+\"=\"+i[t]+\";\"}).join(\"\"),\"}\"),$&&(a=i.divisor,e(\"if(\",u,\".divisor!==\",a,\"){\",t.instancing,\".vertexAttribDivisorANGLE(\",[c,a],\");\",u,\".divisor=\",a,\";}\"))}function s(){e(\"if(\",u,\".buffer){\",l,\".disableVertexAttribArray(\",c,\");\",\"}if(\",bt.map(function(t,e){return u+\".\"+t+\"!==\"+f[e]}).join(\"||\"),\"){\",l,\".vertexAttrib4f(\",c,\",\",f,\");\",bt.map(function(t,e){return u+\".\"+t+\"=\"+f[e]+\";\"}).join(\"\"),\"}\")}var l=o.gl,c=e.def(r,\".location\"),u=e.def(o.attributes,\"[\",c,\"]\");r=i.state;var h=i.buffer,f=[i.x,i.y,i.z,i.w],p=[\"buffer\",\"normalized\",\"offset\",\"stride\"];1===r?a():2===r?s():(e(\"if(\",r,\"===\",1,\"){\"),a(),e(\"}else{\"),s(),e(\"}\"))}var o=t.shared;n.forEach(function(n){var o,s=n.name,l=r.attributes[s];if(l){if(!i(l))return;o=l.append(t,e)}else{if(!i(Mt))return;var c=t.scopeAttrib(s);o={},Object.keys(new Z).forEach(function(t){o[t]=e.def(c,\".\",t)})}a(t.link(n),function(t){switch(t){case 35664:case 35667:case 35671:return 2;case 35665:case 35668:case 35672:return 3;case 35666:case 35669:case 35673:return 4;default:return 1}}(n.info.type),o)})}function j(t,r,n,i,o){for(var s,l=t.shared,c=l.gl,u=0;u<i.length;++u){var h,f=(g=i[u]).name,p=g.info.type,d=n.uniforms[f],g=t.link(g)+\".location\";if(d){if(!o(d))continue;if(D(d)){if(f=d.value,35678===p||35680===p)r(c,\".uniform1i(\",g,\",\",(p=t.link(f._texture||f.color[0]._texture))+\".bind());\"),r.exit(p,\".unbind();\");else if(35674===p||35675===p||35676===p)d=2,35675===p?d=3:35676===p&&(d=4),r(c,\".uniformMatrix\",d,\"fv(\",g,\",false,\",f=t.global.def(\"new Float32Array([\"+Array.prototype.slice.call(f)+\"])\"),\");\");else{switch(p){case 5126:s=\"1f\";break;case 35664:s=\"2f\";break;case 35665:s=\"3f\";break;case 35666:s=\"4f\";break;case 35670:case 5124:s=\"1i\";break;case 35671:case 35667:s=\"2i\";break;case 35672:case 35668:s=\"3i\";break;case 35673:s=\"4i\";break;case 35669:s=\"4i\"}r(c,\".uniform\",s,\"(\",g,\",\",v(f)?Array.prototype.slice.call(f):f,\");\")}continue}h=d.append(t,r)}else{if(!o(Mt))continue;h=r.def(l.uniforms,\"[\",e.id(f),\"]\")}switch(35678===p?r(\"if(\",h,\"&&\",h,'._reglType===\"framebuffer\"){',h,\"=\",h,\".color[0];\",\"}\"):35680===p&&r(\"if(\",h,\"&&\",h,'._reglType===\"framebufferCube\"){',h,\"=\",h,\".color[0];\",\"}\"),f=1,p){case 35678:case 35680:p=r.def(h,\"._texture\"),r(c,\".uniform1i(\",g,\",\",p,\".bind());\"),r.exit(p,\".unbind();\");continue;case 5124:case 35670:s=\"1i\";break;case 35667:case 35671:s=\"2i\",f=2;break;case 35668:case 35672:s=\"3i\",f=3;break;case 35669:case 35673:s=\"4i\",f=4;break;case 5126:s=\"1f\";break;case 35664:s=\"2f\",f=2;break;case 35665:s=\"3f\",f=3;break;case 35666:s=\"4f\",f=4;break;case 35674:s=\"Matrix2fv\";break;case 35675:s=\"Matrix3fv\";break;case 35676:s=\"Matrix4fv\"}if(r(c,\".uniform\",s,\"(\",g,\",\"),\"M\"===s.charAt(0)){g=Math.pow(p-35674+2,2);var m=t.global.def(\"new Float32Array(\",g,\")\");r(\"false,(Array.isArray(\",h,\")||\",h,\" instanceof Float32Array)?\",h,\":(\",a(g,function(t){return m+\"[\"+t+\"]=\"+h+\"[\"+t+\"]\"}),\",\",m,\")\")}else r(1<f?a(f,function(t){return h+\"[\"+t+\"]\"}):h);r(\");\")}}function U(t,e,r,n){function i(i){var a=f[i];return a?a.contextDep&&n.contextDynamic||a.propDep?a.append(t,r):a.append(t,e):e.def(h,\".\",i)}function a(){function t(){r(l,\".drawElementsInstancedANGLE(\",[d,v,m,g+\"<<((\"+m+\"-5121)>>1)\",s],\");\")}function e(){r(l,\".drawArraysInstancedANGLE(\",[d,g,v,s],\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}function o(){function t(){r(u+\".drawElements(\"+[d,v,m,g+\"<<((\"+m+\"-5121)>>1)\"]+\");\")}function e(){r(u+\".drawArrays(\"+[d,g,v]+\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}var s,l,c=t.shared,u=c.gl,h=c.draw,f=n.draw,p=function(){var i=f.elements,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(h,\".\",\"elements\"),i&&a(\"if(\"+i+\")\"+u+\".bindBuffer(34963,\"+i+\".buffer.buffer);\"),i}(),d=i(\"primitive\"),g=i(\"offset\"),v=function(){var i=f.count,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(h,\".\",\"count\"),i}();if(\"number\"==typeof v){if(0===v)return}else r(\"if(\",v,\"){\"),r.exit(\"}\");$&&(s=i(\"instances\"),l=t.instancing);var m=p+\".type\",y=f.elements&&D(f.elements);$&&(\"number\"!=typeof s||0<=s)?\"string\"==typeof s?(r(\"if(\",s,\">0){\"),a(),r(\"}else if(\",s,\"<0){\"),o(),r(\"}\")):a():o()}function q(t,e,r,n,i){return i=(e=b()).proc(\"body\",i),$&&(e.instancing=i.def(e.shared.extensions,\".angle_instanced_arrays\")),t(e,i,r,n),e.compile().body}function H(t,e,r,n){L(t,e),N(t,e,r,n.attributes,function(){return!0}),j(t,e,r,n.uniforms,function(){return!0}),U(t,e,e,r)}function G(t,e,r,n){function i(){return!0}t.batchId=\"a1\",L(t,e),N(t,e,r,n.attributes,i),j(t,e,r,n.uniforms,i),U(t,e,e,r)}function Y(t,e,r,n){function i(t){return t.contextDep&&o||t.propDep}function a(t){return!i(t)}L(t,e);var o=r.contextDep,s=e.def(),l=e.def();t.shared.props=l,t.batchId=s;var c=t.scope(),u=t.scope();e(c.entry,\"for(\",s,\"=0;\",s,\"<\",\"a1\",\";++\",s,\"){\",l,\"=\",\"a0\",\"[\",s,\"];\",u,\"}\",c.exit),r.needsContext&&M(t,u,r.context),r.needsFramebuffer&&S(t,u,r.framebuffer),C(t,u,r.state,i),r.profile&&i(r.profile)&&B(t,u,r,!1,!0),n?(N(t,c,r,n.attributes,a),N(t,u,r,n.attributes,i),j(t,c,r,n.uniforms,a),j(t,u,r,n.uniforms,i),U(t,c,u,r)):(e=t.global.def(\"{}\"),n=r.shader.progVar.append(t,u),l=u.def(n,\".id\"),c=u.def(e,\"[\",l,\"]\"),u(t.shared.gl,\".useProgram(\",n,\".program);\",\"if(!\",c,\"){\",c,\"=\",e,\"[\",l,\"]=\",t.link(function(e){return q(G,t,r,e,2)}),\"(\",n,\");}\",c,\".call(this,a0[\",s,\"],\",s,\");\"))}function W(t,r){function n(e){var n=r.shader[e];n&&i.set(a.shader,\".\"+e,n.append(t,i))}var i=t.proc(\"scope\",3);t.batchId=\"a2\";var a=t.shared,o=a.current;M(t,i,r.context),r.framebuffer&&r.framebuffer.append(t,i),z(Object.keys(r.state)).forEach(function(e){var n=r.state[e].append(t,i);v(n)?n.forEach(function(r,n){i.set(t.next[e],\"[\"+n+\"]\",r)}):i.set(a.next,\".\"+e,n)}),B(t,i,r,!0,!0),[\"elements\",\"offset\",\"count\",\"instances\",\"primitive\"].forEach(function(e){var n=r.draw[e];n&&i.set(a.draw,\".\"+e,\"\"+n.append(t,i))}),Object.keys(r.uniforms).forEach(function(n){i.set(a.uniforms,\"[\"+e.id(n)+\"]\",r.uniforms[n].append(t,i))}),Object.keys(r.attributes).forEach(function(e){var n=r.attributes[e].append(t,i),a=t.scopeAttrib(e);Object.keys(new Z).forEach(function(t){i.set(a,\".\"+t,n[t])})}),n(\"vert\"),n(\"frag\"),0<Object.keys(r.state).length&&(i(o,\".dirty=true;\"),i.exit(o,\".dirty=true;\")),i(\"a1(\",t.shared.context,\",a0,\",t.batchId,\");\")}function X(t,e,r){var n=e.static[r];if(n&&function(t){if(\"object\"==typeof t&&!v(t)){for(var e=Object.keys(t),r=0;r<e.length;++r)if(V.isDynamic(t[e[r]]))return!0;return!1}}(n)){var i=t.global,a=Object.keys(n),o=!1,s=!1,l=!1,c=t.global.def(\"{}\");a.forEach(function(e){var r=n[e];if(V.isDynamic(r))\"function\"==typeof r&&(r=n[e]=V.unbox(r)),e=F(r,null),o=o||e.thisDep,l=l||e.propDep,s=s||e.contextDep;else{switch(i(c,\".\",e,\"=\"),typeof r){case\"number\":i(r);break;case\"string\":i('\"',r,'\"');break;case\"object\":Array.isArray(r)&&i(\"[\",r.join(),\"]\");break;default:i(t.link(r))}i(\";\")}}),e.dynamic[r]=new V.DynamicVariable(4,{thisDep:o,contextDep:s,propDep:l,ref:c,append:function(t,e){a.forEach(function(r){var i=n[r];V.isDynamic(i)&&(i=t.invoke(e,i),e(c,\".\",r,\"=\",i,\";\"))})}}),delete e.static[r]}}var Z=u.Record,J={add:32774,subtract:32778,\"reverse subtract\":32779};r.ext_blend_minmax&&(J.min=32775,J.max=32776);var $=r.angle_instanced_arrays,Q=r.webgl_draw_buffers,tt={dirty:!0,profile:g.profile},et={},nt=[],it={},at={};y(\"dither\",3024),y(\"blend.enable\",3042),x(\"blend.color\",\"blendColor\",[0,0,0,0]),x(\"blend.equation\",\"blendEquationSeparate\",[32774,32774]),x(\"blend.func\",\"blendFuncSeparate\",[1,0,1,0]),y(\"depth.enable\",2929,!0),x(\"depth.func\",\"depthFunc\",513),x(\"depth.range\",\"depthRange\",[0,1]),x(\"depth.mask\",\"depthMask\",!0),x(\"colorMask\",\"colorMask\",[!0,!0,!0,!0]),y(\"cull.enable\",2884),x(\"cull.face\",\"cullFace\",1029),x(\"frontFace\",\"frontFace\",2305),x(\"lineWidth\",\"lineWidth\",1),y(\"polygonOffset.enable\",32823),x(\"polygonOffset.offset\",\"polygonOffset\",[0,0]),y(\"sample.alpha\",32926),y(\"sample.enable\",32928),x(\"sample.coverage\",\"sampleCoverage\",[1,!1]),y(\"stencil.enable\",2960),x(\"stencil.mask\",\"stencilMask\",-1),x(\"stencil.func\",\"stencilFunc\",[519,0,-1]),x(\"stencil.opFront\",\"stencilOpSeparate\",[1028,7680,7680,7680]),x(\"stencil.opBack\",\"stencilOpSeparate\",[1029,7680,7680,7680]),y(\"scissor.enable\",3089),x(\"scissor.box\",\"scissor\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]),x(\"viewport\",\"viewport\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]);var ot={gl:t,context:p,strings:e,next:et,current:tt,draw:f,elements:o,buffer:i,shader:h,attributes:u.state,uniforms:c,framebuffer:l,extensions:r,timer:d,isBufferArgs:O},st={primTypes:rt,compareFuncs:kt,blendFuncs:wt,blendEquations:J,stencilOps:Tt,glTypes:K,orientationType:At};Q&&(st.backBuffer=[1029],st.drawBuffer=a(n.maxDrawbuffers,function(t){return 0===t?[0]:a(t,function(t){return 36064+t})}));var lt=0;return{next:et,current:tt,procs:function(){var t=b(),e=t.proc(\"poll\"),r=t.proc(\"refresh\"),i=t.block();e(i),r(i);var o,s=t.shared,l=s.gl,c=s.next,u=s.current;i(u,\".dirty=false;\"),S(t,e),S(t,r,null,!0),$&&(o=t.link($));for(var h=0;h<n.maxAttributes;++h){var f=r.def(s.attributes,\"[\",h,\"]\"),p=t.cond(f,\".buffer\");p.then(l,\".enableVertexAttribArray(\",h,\");\",l,\".bindBuffer(\",34962,\",\",f,\".buffer.buffer);\",l,\".vertexAttribPointer(\",h,\",\",f,\".size,\",f,\".type,\",f,\".normalized,\",f,\".stride,\",f,\".offset);\").else(l,\".disableVertexAttribArray(\",h,\");\",l,\".vertexAttrib4f(\",h,\",\",f,\".x,\",f,\".y,\",f,\".z,\",f,\".w);\",f,\".buffer=null;\"),r(p),$&&r(o,\".vertexAttribDivisorANGLE(\",h,\",\",f,\".divisor);\")}return Object.keys(it).forEach(function(n){var a=it[n],o=i.def(c,\".\",n),s=t.block();s(\"if(\",o,\"){\",l,\".enable(\",a,\")}else{\",l,\".disable(\",a,\")}\",u,\".\",n,\"=\",o,\";\"),r(s),e(\"if(\",o,\"!==\",u,\".\",n,\"){\",s,\"}\")}),Object.keys(at).forEach(function(n){var o,s,h=at[n],f=tt[n],p=t.block();p(l,\".\",h,\"(\"),v(f)?(h=f.length,o=t.global.def(c,\".\",n),s=t.global.def(u,\".\",n),p(a(h,function(t){return o+\"[\"+t+\"]\"}),\");\",a(h,function(t){return s+\"[\"+t+\"]=\"+o+\"[\"+t+\"];\"}).join(\"\")),e(\"if(\",a(h,function(t){return o+\"[\"+t+\"]!==\"+s+\"[\"+t+\"]\"}).join(\"||\"),\"){\",p,\"}\")):(o=i.def(c,\".\",n),s=i.def(u,\".\",n),p(o,\");\",u,\".\",n,\"=\",o,\";\"),e(\"if(\",o,\"!==\",s,\"){\",p,\"}\")),r(p)}),t.compile()}(),compile:function(t,e,r,n,i){var a=b();return a.stats=a.link(i),Object.keys(e.static).forEach(function(t){X(a,e,t)}),_t.forEach(function(e){X(a,t,e)}),r=A(t,e,r,n),function(t,e){var r=t.proc(\"draw\",1);L(t,r),M(t,r,e.context),S(t,r,e.framebuffer),E(t,r,e),C(t,r,e.state),B(t,r,e,!1,!0);var n=e.shader.progVar.append(t,r);if(r(t.shared.gl,\".useProgram(\",n,\".program);\"),e.shader.program)H(t,r,e,e.shader.program);else{var i=t.global.def(\"{}\"),a=r.def(n,\".id\"),o=r.def(i,\"[\",a,\"]\");r(t.cond(o).then(o,\".call(this,a0);\").else(o,\"=\",i,\"[\",a,\"]=\",t.link(function(r){return q(H,t,e,r,1)}),\"(\",n,\");\",o,\".call(this,a0);\"))}0<Object.keys(e.state).length&&r(t.shared.current,\".dirty=true;\")}(a,r),W(a,r),function(t,e){function r(t){return t.contextDep&&i||t.propDep}var n=t.proc(\"batch\",2);t.batchId=\"0\",L(t,n);var i=!1,a=!0;Object.keys(e.context).forEach(function(t){i=i||e.context[t].propDep}),i||(M(t,n,e.context),a=!1);var o=!1;if((s=e.framebuffer)?(s.propDep?i=o=!0:s.contextDep&&i&&(o=!0),o||S(t,n,s)):S(t,n,null),e.state.viewport&&e.state.viewport.propDep&&(i=!0),E(t,n,e),C(t,n,e.state,function(t){return!r(t)}),e.profile&&r(e.profile)||B(t,n,e,!1,\"a1\"),e.contextDep=i,e.needsContext=a,e.needsFramebuffer=o,(a=e.shader.progVar).contextDep&&i||a.propDep)Y(t,n,e,null);else if(a=a.append(t,n),n(t.shared.gl,\".useProgram(\",a,\".program);\"),e.shader.program)Y(t,n,e,e.shader.program);else{var s=t.global.def(\"{}\"),l=(o=n.def(a,\".id\"),n.def(s,\"[\",o,\"]\"));n(t.cond(l).then(l,\".call(this,a0,a1);\").else(l,\"=\",s,\"[\",o,\"]=\",t.link(function(r){return q(Y,t,e,r,2)}),\"(\",a,\");\",l,\".call(this,a0,a1);\"))}0<Object.keys(e.state).length&&n(t.shared.current,\".dirty=true;\")}(a,r),a.compile()}}}function N(t,e){for(var r=0;r<t.length;++r)if(t[r]===e)return r;return-1}var j=function(t,e){for(var r=Object.keys(e),n=0;n<r.length;++n)t[r[n]]=e[r[n]];return t},U=0,V={DynamicVariable:t,define:function(r,n){return new t(r,e(n+\"\"))},isDynamic:function(e){return\"function\"==typeof e&&!e._reglType||e instanceof t},unbox:function(e,r){return\"function\"==typeof e?new t(0,e):e},accessor:e},q={next:\"function\"==typeof requestAnimationFrame?function(t){return requestAnimationFrame(t)}:function(t){return setTimeout(t,16)},cancel:\"function\"==typeof cancelAnimationFrame?function(t){return cancelAnimationFrame(t)}:clearTimeout},H=\"undefined\"!=typeof performance&&performance.now?function(){return performance.now()}:function(){return+new Date},G=s();G.zero=s();var Y=function(t,e){var r=1;e.ext_texture_filter_anisotropic&&(r=t.getParameter(34047));var n=1,i=1;e.webgl_draw_buffers&&(n=t.getParameter(34852),i=t.getParameter(36063));var a=!!e.oes_texture_float;if(a){a=t.createTexture(),t.bindTexture(3553,a),t.texImage2D(3553,0,6408,1,1,0,6408,5126,null);var o=t.createFramebuffer();if(t.bindFramebuffer(36160,o),t.framebufferTexture2D(36160,36064,3553,a,0),t.bindTexture(3553,null),36053!==t.checkFramebufferStatus(36160))a=!1;else{t.viewport(0,0,1,1),t.clearColor(1,0,0,1),t.clear(16384);var s=G.allocType(5126,4);t.readPixels(0,0,1,1,6408,5126,s),t.getError()?a=!1:(t.deleteFramebuffer(o),t.deleteTexture(a),a=1===s[0]),G.freeType(s)}}return s=!0,\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion)||/Edge/.test(navigator.userAgent))||(s=t.createTexture(),o=G.allocType(5121,36),t.activeTexture(33984),t.bindTexture(34067,s),t.texImage2D(34069,0,6408,3,3,0,6408,5121,o),G.freeType(o),t.bindTexture(34067,null),t.deleteTexture(s),s=!t.getError()),{colorBits:[t.getParameter(3410),t.getParameter(3411),t.getParameter(3412),t.getParameter(3413)],depthBits:t.getParameter(3414),stencilBits:t.getParameter(3415),subpixelBits:t.getParameter(3408),extensions:Object.keys(e).filter(function(t){return!!e[t]}),maxAnisotropic:r,maxDrawbuffers:n,maxColorAttachments:i,pointSizeDims:t.getParameter(33901),lineWidthDims:t.getParameter(33902),maxViewportDims:t.getParameter(3386),maxCombinedTextureUnits:t.getParameter(35661),maxCubeMapSize:t.getParameter(34076),maxRenderbufferSize:t.getParameter(34024),maxTextureUnits:t.getParameter(34930),maxTextureSize:t.getParameter(3379),maxAttributes:t.getParameter(34921),maxVertexUniforms:t.getParameter(36347),maxVertexTextureUnits:t.getParameter(35660),maxVaryingVectors:t.getParameter(36348),maxFragmentUniforms:t.getParameter(36349),glsl:t.getParameter(35724),renderer:t.getParameter(7937),vendor:t.getParameter(7936),version:t.getParameter(7938),readFloat:a,npotTextureCube:s}},W=function(t){return t instanceof Uint8Array||t instanceof Uint16Array||t instanceof Uint32Array||t instanceof Int8Array||t instanceof Int16Array||t instanceof Int32Array||t instanceof Float32Array||t instanceof Float64Array||t instanceof Uint8ClampedArray},X=function(t){return Object.keys(t).map(function(e){return t[e]})},Z={shape:function(t){for(var e=[];t.length;t=t[0])e.push(t.length);return e},flatten:function(t,e,r,n){var i=1;if(e.length)for(var a=0;a<e.length;++a)i*=e[a];else i=0;switch(r=n||G.allocType(r,i),e.length){case 0:break;case 1:for(n=e[0],e=0;e<n;++e)r[e]=t[e];break;case 2:for(n=e[0],e=e[1],a=i=0;a<n;++a)for(var o=t[a],s=0;s<e;++s)r[i++]=o[s];break;case 3:c(t,e[0],e[1],e[2],r,0);break;default:!function t(e,r,n,i,a){for(var o=1,s=n+1;s<r.length;++s)o*=r[s];var l=r[n];if(4==r.length-n){var u=r[n+1],h=r[n+2];for(r=r[n+3],s=0;s<l;++s)c(e[s],u,h,r,i,a),a+=o}else for(s=0;s<l;++s)t(e[s],r,n+1,i,a),a+=o}(t,e,0,r,0)}return r}},J={\"[object Int8Array]\":5120,\"[object Int16Array]\":5122,\"[object Int32Array]\":5124,\"[object Uint8Array]\":5121,\"[object Uint8ClampedArray]\":5121,\"[object Uint16Array]\":5123,\"[object Uint32Array]\":5125,\"[object Float32Array]\":5126,\"[object Float64Array]\":5121,\"[object ArrayBuffer]\":5121},K={int8:5120,int16:5122,int32:5124,uint8:5121,uint16:5123,uint32:5125,float:5126,float32:5126},$={dynamic:35048,stream:35040,static:35044},Q=Z.flatten,tt=Z.shape,et=[];et[5120]=1,et[5122]=2,et[5124]=4,et[5121]=1,et[5123]=2,et[5125]=4,et[5126]=4;var rt={points:0,point:0,lines:1,line:1,triangles:4,triangle:4,\"line loop\":2,\"line strip\":3,\"triangle strip\":5,\"triangle fan\":6},nt=new Float32Array(1),it=new Uint32Array(nt.buffer),at=[9984,9986,9985,9987],ot=[0,6409,6410,6407,6408],st={};st[6409]=st[6406]=st[6402]=1,st[34041]=st[6410]=2,st[6407]=st[35904]=3,st[6408]=st[35906]=4;var lt=m(\"HTMLCanvasElement\"),ct=m(\"CanvasRenderingContext2D\"),ut=m(\"ImageBitmap\"),ht=m(\"HTMLImageElement\"),ft=m(\"HTMLVideoElement\"),pt=Object.keys(J).concat([lt,ct,ut,ht,ft]),dt=[];dt[5121]=1,dt[5126]=4,dt[36193]=2,dt[5123]=2,dt[5125]=4;var gt=[];gt[32854]=2,gt[32855]=2,gt[36194]=2,gt[34041]=4,gt[33776]=.5,gt[33777]=.5,gt[33778]=1,gt[33779]=1,gt[35986]=.5,gt[35987]=1,gt[34798]=1,gt[35840]=.5,gt[35841]=.25,gt[35842]=.5,gt[35843]=.25,gt[36196]=.5;var vt=[];vt[32854]=2,vt[32855]=2,vt[36194]=2,vt[33189]=2,vt[36168]=1,vt[34041]=4,vt[35907]=4,vt[34836]=16,vt[34842]=8,vt[34843]=6;var mt=function(t,e,r,n,i){function a(t){this.id=c++,this.refCount=1,this.renderbuffer=t,this.format=32854,this.height=this.width=0,i.profile&&(this.stats={size:0})}function o(e){var r=e.renderbuffer;t.bindRenderbuffer(36161,null),t.deleteRenderbuffer(r),e.renderbuffer=null,e.refCount=0,delete u[e.id],n.renderbufferCount--}var s={rgba4:32854,rgb565:36194,\"rgb5 a1\":32855,depth:33189,stencil:36168,\"depth stencil\":34041};e.ext_srgb&&(s.srgba=35907),e.ext_color_buffer_half_float&&(s.rgba16f=34842,s.rgb16f=34843),e.webgl_color_buffer_float&&(s.rgba32f=34836);var l=[];Object.keys(s).forEach(function(t){l[s[t]]=t});var c=0,u={};return a.prototype.decRef=function(){0>=--this.refCount&&o(this)},i.profile&&(n.getTotalRenderbufferSize=function(){var t=0;return Object.keys(u).forEach(function(e){t+=u[e].stats.size}),t}),{create:function(e,r){function o(e,r){var n=0,a=0,u=32854;if(\"object\"==typeof e&&e?(\"shape\"in e?(n=0|(a=e.shape)[0],a=0|a[1]):(\"radius\"in e&&(n=a=0|e.radius),\"width\"in e&&(n=0|e.width),\"height\"in e&&(a=0|e.height)),\"format\"in e&&(u=s[e.format])):\"number\"==typeof e?(n=0|e,a=\"number\"==typeof r?0|r:n):e||(n=a=1),n!==c.width||a!==c.height||u!==c.format)return o.width=c.width=n,o.height=c.height=a,c.format=u,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,u,n,a),i.profile&&(c.stats.size=vt[c.format]*c.width*c.height),o.format=l[c.format],o}var c=new a(t.createRenderbuffer());return u[c.id]=c,n.renderbufferCount++,o(e,r),o.resize=function(e,r){var n=0|e,a=0|r||n;return n===c.width&&a===c.height?o:(o.width=c.width=n,o.height=c.height=a,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,c.format,n,a),i.profile&&(c.stats.size=vt[c.format]*c.width*c.height),o)},o._reglType=\"renderbuffer\",o._renderbuffer=c,i.profile&&(o.stats=c.stats),o.destroy=function(){c.decRef()},o},clear:function(){X(u).forEach(o)},restore:function(){X(u).forEach(function(e){e.renderbuffer=t.createRenderbuffer(),t.bindRenderbuffer(36161,e.renderbuffer),t.renderbufferStorage(36161,e.format,e.width,e.height)}),t.bindRenderbuffer(36161,null)}}},yt=[];yt[6408]=4,yt[6407]=3;var xt=[];xt[5121]=1,xt[5126]=4,xt[36193]=2;var bt=[\"x\",\"y\",\"z\",\"w\"],_t=\"blend.func blend.equation stencil.func stencil.opFront stencil.opBack sample.coverage viewport scissor.box polygonOffset.offset\".split(\" \"),wt={0:0,1:1,zero:0,one:1,\"src color\":768,\"one minus src color\":769,\"src alpha\":770,\"one minus src alpha\":771,\"dst color\":774,\"one minus dst color\":775,\"dst alpha\":772,\"one minus dst alpha\":773,\"constant color\":32769,\"one minus constant color\":32770,\"constant alpha\":32771,\"one minus constant alpha\":32772,\"src alpha saturate\":776},kt={never:512,less:513,\"<\":513,equal:514,\"=\":514,\"==\":514,\"===\":514,lequal:515,\"<=\":515,greater:516,\">\":516,notequal:517,\"!=\":517,\"!==\":517,gequal:518,\">=\":518,always:519},Tt={0:0,zero:0,keep:7680,replace:7681,increment:7682,decrement:7683,\"increment wrap\":34055,\"decrement wrap\":34056,invert:5386},At={cw:2304,ccw:2305},Mt=new I(!1,!1,!1,function(){});return function(t){function e(){if(0===Z.length)w&&w.update(),Q=null;else{Q=q.next(e),h();for(var t=Z.length-1;0<=t;--t){var r=Z[t];r&&r(P,null,0)}v.flush(),w&&w.update()}}function r(){!Q&&0<Z.length&&(Q=q.next(e))}function n(){Q&&(q.cancel(e),Q=null)}function a(t){t.preventDefault(),n(),J.forEach(function(t){t()})}function o(t){v.getError(),y.restore(),D.restore(),z.restore(),R.restore(),F.restore(),U.restore(),w&&w.restore(),G.procs.refresh(),r(),K.forEach(function(t){t()})}function s(t){function e(t){var e={},r={};return Object.keys(t).forEach(function(n){var i=t[n];V.isDynamic(i)?r[n]=V.unbox(i,n):e[n]=i}),{dynamic:r,static:e}}var r=e(t.context||{}),n=e(t.uniforms||{}),i=e(t.attributes||{}),a=e(function(t){function e(t){if(t in r){var e=r[t];delete r[t],Object.keys(e).forEach(function(n){r[t+\".\"+n]=e[n]})}}var r=j({},t);return delete r.uniforms,delete r.attributes,delete r.context,\"stencil\"in r&&r.stencil.op&&(r.stencil.opBack=r.stencil.opFront=r.stencil.op,delete r.stencil.op),e(\"blend\"),e(\"depth\"),e(\"cull\"),e(\"stencil\"),e(\"polygonOffset\"),e(\"scissor\"),e(\"sample\"),r}(t));t={gpuTime:0,cpuTime:0,count:0};var o=(r=G.compile(a,i,n,r,t)).draw,s=r.batch,l=r.scope,c=[];return j(function(t,e){var r;if(\"function\"==typeof t)return l.call(this,null,t,0);if(\"function\"==typeof e)if(\"number\"==typeof t)for(r=0;r<t;++r)l.call(this,null,e,r);else{if(!Array.isArray(t))return l.call(this,t,e,0);for(r=0;r<t.length;++r)l.call(this,t[r],e,r)}else if(\"number\"==typeof t){if(0<t)return s.call(this,function(t){for(;c.length<t;)c.push(null);return c}(0|t),0|t)}else{if(!Array.isArray(t))return o.call(this,t);if(t.length)return s.call(this,t,t.length)}},{stats:t})}function l(t,e){var r=0;G.procs.poll();var n=e.color;n&&(v.clearColor(+n[0]||0,+n[1]||0,+n[2]||0,+n[3]||0),r|=16384),\"depth\"in e&&(v.clearDepth(+e.depth),r|=256),\"stencil\"in e&&(v.clearStencil(0|e.stencil),r|=1024),v.clear(r)}function c(t){return Z.push(t),r(),{cancel:function(){var e=N(Z,t);Z[e]=function t(){var e=N(Z,t);Z[e]=Z[Z.length-1],--Z.length,0>=Z.length&&n()}}}}function u(){var t=W.viewport,e=W.scissor_box;t[0]=t[1]=e[0]=e[1]=0,P.viewportWidth=P.framebufferWidth=P.drawingBufferWidth=t[2]=e[2]=v.drawingBufferWidth,P.viewportHeight=P.framebufferHeight=P.drawingBufferHeight=t[3]=e[3]=v.drawingBufferHeight}function h(){P.tick+=1,P.time=g(),u(),G.procs.poll()}function f(){u(),G.procs.refresh(),w&&w.update()}function g(){return(H()-k)/1e3}if(!(t=i(t)))return null;var v=t.gl,m=v.getContextAttributes();v.isContextLost();var y=function(t,e){function r(e){var r;e=e.toLowerCase();try{r=n[e]=t.getExtension(e)}catch(t){}return!!r}for(var n={},i=0;i<e.extensions.length;++i){var a=e.extensions[i];if(!r(a))return e.onDestroy(),e.onDone('\"'+a+'\" extension is not supported by the current WebGL context, try upgrading your system or a different browser'),null}return e.optionalExtensions.forEach(r),{extensions:n,restore:function(){Object.keys(n).forEach(function(t){if(n[t]&&!r(t))throw Error(\"(regl): error restoring extension \"+t)})}}}(v,t);if(!y)return null;var x=function(){var t={\"\":0},e=[\"\"];return{id:function(r){var n=t[r];return n||(n=t[r]=e.length,e.push(r),n)},str:function(t){return e[t]}}}(),b={bufferCount:0,elementsCount:0,framebufferCount:0,shaderCount:0,textureCount:0,cubeCount:0,renderbufferCount:0,maxTextureUnits:0},_=y.extensions,w=function(t,e){function r(){this.endQueryIndex=this.startQueryIndex=-1,this.sum=0,this.stats=null}function n(t,e,n){var i=o.pop()||new r;i.startQueryIndex=t,i.endQueryIndex=e,i.sum=0,i.stats=n,s.push(i)}if(!e.ext_disjoint_timer_query)return null;var i=[],a=[],o=[],s=[],l=[],c=[];return{beginQuery:function(t){var r=i.pop()||e.ext_disjoint_timer_query.createQueryEXT();e.ext_disjoint_timer_query.beginQueryEXT(35007,r),a.push(r),n(a.length-1,a.length,t)},endQuery:function(){e.ext_disjoint_timer_query.endQueryEXT(35007)},pushScopeStats:n,update:function(){var t,r;if(0!==(t=a.length)){c.length=Math.max(c.length,t+1),l.length=Math.max(l.length,t+1),l[0]=0;var n=c[0]=0;for(r=t=0;r<a.length;++r){var u=a[r];e.ext_disjoint_timer_query.getQueryObjectEXT(u,34919)?(n+=e.ext_disjoint_timer_query.getQueryObjectEXT(u,34918),i.push(u)):a[t++]=u,l[r+1]=n,c[r+1]=t}for(a.length=t,r=t=0;r<s.length;++r){var h=(n=s[r]).startQueryIndex;u=n.endQueryIndex,n.sum+=l[u]-l[h],h=c[h],(u=c[u])===h?(n.stats.gpuTime+=n.sum/1e6,o.push(n)):(n.startQueryIndex=h,n.endQueryIndex=u,s[t++]=n)}s.length=t}},getNumPendingQueries:function(){return a.length},clear:function(){i.push.apply(i,a);for(var t=0;t<i.length;t++)e.ext_disjoint_timer_query.deleteQueryEXT(i[t]);a.length=0,i.length=0},restore:function(){a.length=0,i.length=0}}}(0,_),k=H(),C=v.drawingBufferWidth,L=v.drawingBufferHeight,P={tick:0,time:0,viewportWidth:C,viewportHeight:L,framebufferWidth:C,framebufferHeight:L,drawingBufferWidth:C,drawingBufferHeight:L,pixelRatio:t.pixelRatio},O=Y(v,_),z=(C=function(t,e,r,n){for(t=r.maxAttributes,e=Array(t),r=0;r<t;++r)e[r]=new M;return{Record:M,scope:{},state:e}}(v,_,O),p(v,b,t,C)),I=d(v,_,z,b),D=S(v,x,b,t),R=T(v,_,O,function(){G.procs.poll()},P,b,t),F=mt(v,_,0,b,t),U=A(v,_,O,R,F,b),G=B(v,x,_,O,z,I,0,U,{},C,D,{elements:null,primitive:4,count:-1,offset:0,instances:-1},P,w,t),W=(x=E(v,U,G.procs.poll,P),G.next),X=v.canvas,Z=[],J=[],K=[],$=[t.onDestroy],Q=null;X&&(X.addEventListener(\"webglcontextlost\",a,!1),X.addEventListener(\"webglcontextrestored\",o,!1));var tt=U.setFBO=s({framebuffer:V.define.call(null,1,\"framebuffer\")});return f(),m=j(s,{clear:function(t){if(\"framebuffer\"in t)if(t.framebuffer&&\"framebufferCube\"===t.framebuffer_reglType)for(var e=0;6>e;++e)tt(j({framebuffer:t.framebuffer.faces[e]},t),l);else tt(t,l);else l(0,t)},prop:V.define.bind(null,1),context:V.define.bind(null,2),this:V.define.bind(null,3),draw:s({}),buffer:function(t){return z.create(t,34962,!1,!1)},elements:function(t){return I.create(t,!1)},texture:R.create2D,cube:R.createCube,renderbuffer:F.create,framebuffer:U.create,framebufferCube:U.createCube,attributes:m,frame:c,on:function(t,e){var r;switch(t){case\"frame\":return c(e);case\"lost\":r=J;break;case\"restore\":r=K;break;case\"destroy\":r=$}return r.push(e),{cancel:function(){for(var t=0;t<r.length;++t)if(r[t]===e){r[t]=r[r.length-1],r.pop();break}}}},limits:O,hasExtension:function(t){return 0<=O.extensions.indexOf(t.toLowerCase())},read:x,destroy:function(){Z.length=0,n(),X&&(X.removeEventListener(\"webglcontextlost\",a),X.removeEventListener(\"webglcontextrestored\",o)),D.clear(),U.clear(),F.clear(),R.clear(),I.clear(),z.clear(),w&&w.clear(),$.forEach(function(t){t()})},_gl:v,_refresh:f,poll:function(){h(),w&&w.update()},now:g,stats:b}),t.onDone(null,m),m}},\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=i():n.createREGL=i()},{}],503:[function(t,e,r){\"use strict\";var n,i=\"\";e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"expected a string\");if(1===e)return t;if(2===e)return t+t;var r=t.length*e;if(n!==t||\"undefined\"==typeof n)n=t,i=\"\";else if(i.length>=r)return i.substr(0,r);for(;r>i.length&&e>1;)1&e&&(i+=t),e>>=1,t+=t;return i=(i+=t).substr(0,r)}},{}],504:[function(t,e,r){(function(t){e.exports=t.performance&&t.performance.now?function(){return performance.now()}:Date.now||function(){return+new Date}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{}],505:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=t[t.length-1],n=e,i=e-2;i>=0;--i){var a=r,o=t[i],s=(r=a+o)-a,l=o-s;l&&(t[--n]=r,r=l)}for(var c=0,i=n;i<e;++i){var a=t[i],o=r,s=(r=a+o)-a,l=o-s;l&&(t[c++]=l)}return t[c++]=r,t.length=c,t}},{}],506:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-compress\"),s=6;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(2===t.length)return[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\");for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(l(t,r)),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return function t(e){if(1===e.length)return e[0];if(2===e.length)return[\"sum(\",e[0],\",\",e[1],\")\"].join(\"\");var r=e.length>>1;return[\"sum(\",t(e.slice(0,r)),\",\",t(e.slice(r)),\")\"].join(\"\")}(e);var n}function u(t){return new Function(\"sum\",\"scale\",\"prod\",\"compress\",[\"function robustDeterminant\",t,\"(m){return compress(\",c(function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m[\",r,\"][\",n,\"]\"].join(\"\")}return e}(t)),\")};return robustDeterminant\",t].join(\"\"))(i,a,n,o)}var h=[function(){return[0]},function(t){return[t[0][0]]}];!function(){for(;h.length<s;)h.push(u(h.length));for(var t=[],r=[\"function robustDeterminant(m){switch(m.length){\"],n=0;n<s;++n)t.push(\"det\"+n),r.push(\"case \",n,\":return det\",n,\"(m);\");r.push(\"}var det=CACHE[m.length];if(!det)det=CACHE[m.length]=gen(m.length);return det(m);}return robustDeterminant\"),t.push(\"CACHE\",\"gen\",r.join(\"\"));var i=Function.apply(void 0,t);for(e.exports=i.apply(void 0,h.concat([h,u])),n=0;n<h.length;++n)e.exports[n]=h[n]}()},{\"robust-compress\":505,\"robust-scale\":512,\"robust-sum\":515,\"two-product\":543}],507:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\");e.exports=function(t,e){for(var r=n(t[0],e[0]),a=1;a<t.length;++a)r=i(r,n(t[a],e[a]));return r}},{\"robust-sum\":515,\"two-product\":543}],508:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-subtract\"),o=t(\"robust-scale\"),s=6;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",c(t.slice(0,e)),\",\",c(t.slice(e)),\")\"].join(\"\")}function u(t,e){if(\"m\"===t.charAt(0)){if(\"w\"===e.charAt(0)){var r=t.split(\"[\");return[\"w\",e.substr(1),\"m\",r[0].substr(1)].join(\"\")}return[\"prod(\",t,\",\",e,\")\"].join(\"\")}return u(e,t)}function h(t){if(2===t.length)return[[\"diff(\",u(t[0][0],t[1][1]),\",\",u(t[1][0],t[0][1]),\")\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(h(l(t,r))),\",\",(n=r,!0&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function f(t,e){for(var r=[],n=0;n<e-2;++n)r.push([\"prod(m\",t,\"[\",n,\"],m\",t,\"[\",n,\"])\"].join(\"\"));return c(r)}function p(t){for(var e=[],r=[],s=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-2,\"]\"].join(\"\")}return e}(t),u=0;u<t;++u)s[0][u]=\"1\",s[t-1][u]=\"w\"+u;for(u=0;u<t;++u)0==(1&u)?e.push.apply(e,h(l(s,u))):r.push.apply(r,h(l(s,u)));var p=c(e),d=c(r),g=\"exactInSphere\"+t,v=[];for(u=0;u<t;++u)v.push(\"m\"+u);var m=[\"function \",g,\"(\",v.join(),\"){\"];for(u=0;u<t;++u){m.push(\"var w\",u,\"=\",f(u,t),\";\");for(var y=0;y<t;++y)y!==u&&m.push(\"var w\",u,\"m\",y,\"=scale(w\",u,\",m\",y,\"[0]);\")}return m.push(\"var p=\",p,\",n=\",d,\",d=diff(p,n);return d[d.length-1];}return \",g),new Function(\"sum\",\"diff\",\"prod\",\"scale\",m.join(\"\"))(i,a,n,o)}var d=[function(){return 0},function(){return 0},function(){return 0}];!function(){for(;d.length<=s;)d.push(p(d.length));for(var t=[],r=[\"slow\"],n=0;n<=s;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function testInSphere(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=s;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return testInSphere\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[function(t){var e=d[t.length];return e||(e=d[t.length]=p(t.length)),e.apply(void 0,t)}].concat(d)),n=0;n<=s;++n)e.exports[n]=d[n]}()},{\"robust-scale\":512,\"robust-subtract\":514,\"robust-sum\":515,\"two-product\":543}],509:[function(t,e,r){\"use strict\";var n=t(\"robust-determinant\"),i=6;function a(t){for(var e=\"robustLinearSolve\"+t+\"d\",r=[\"function \",e,\"(A,b){return [\"],i=0;i<t;++i){r.push(\"det([\");for(var a=0;a<t;++a){a>0&&r.push(\",\"),r.push(\"[\");for(var o=0;o<t;++o)o>0&&r.push(\",\"),o===i?r.push(\"+b[\",a,\"]\"):r.push(\"+A[\",a,\"][\",o,\"]\");r.push(\"]\")}r.push(\"]),\")}r.push(\"det(A)]}return \",e);var s=new Function(\"det\",r.join(\"\"));return s(t<6?n[t]:n)}var o=[function(){return[0]},function(t,e){return[[e[0]],[t[0][0]]]}];!function(){for(;o.length<i;)o.push(a(o.length));for(var t=[],r=[\"function dispatchLinearSolve(A,b){switch(A.length){\"],n=0;n<i;++n)t.push(\"s\"+n),r.push(\"case \",n,\":return s\",n,\"(A,b);\");r.push(\"}var s=CACHE[A.length];if(!s)s=CACHE[A.length]=g(A.length);return s(A,b)}return dispatchLinearSolve\"),t.push(\"CACHE\",\"g\",r.join(\"\"));var s=Function.apply(void 0,t);for(e.exports=s.apply(void 0,o.concat([o,a])),n=0;n<i;++n)e.exports[n]=o[n]}()},{\"robust-determinant\":506}],510:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-subtract\"),s=5;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",c(t.slice(0,e)),\",\",c(t.slice(e)),\")\"].join(\"\")}function u(t){if(2===t.length)return[[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(u(l(t,r))),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function h(t){for(var e=[],r=[],s=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-1,\"]\"].join(\"\")}return e}(t),h=[],f=0;f<t;++f)0==(1&f)?e.push.apply(e,u(l(s,f))):r.push.apply(r,u(l(s,f))),h.push(\"m\"+f);var p=c(e),d=c(r),g=\"orientation\"+t+\"Exact\",v=[\"function \",g,\"(\",h.join(),\"){var p=\",p,\",n=\",d,\",d=sub(p,n);return d[d.length-1];};return \",g].join(\"\");return new Function(\"sum\",\"prod\",\"scale\",\"sub\",v)(i,n,a,o)}var f=h(3),p=h(4),d=[function(){return 0},function(){return 0},function(t,e){return e[0]-t[0]},function(t,e,r){var n,i=(t[1]-r[1])*(e[0]-r[0]),a=(t[0]-r[0])*(e[1]-r[1]),o=i-a;if(i>0){if(a<=0)return o;n=i+a}else{if(!(i<0))return o;if(a>=0)return o;n=-(i+a)}var s=3.3306690738754716e-16*n;return o>=s||o<=-s?o:f(t,e,r)},function(t,e,r,n){var i=t[0]-n[0],a=e[0]-n[0],o=r[0]-n[0],s=t[1]-n[1],l=e[1]-n[1],c=r[1]-n[1],u=t[2]-n[2],h=e[2]-n[2],f=r[2]-n[2],d=a*c,g=o*l,v=o*s,m=i*c,y=i*l,x=a*s,b=u*(d-g)+h*(v-m)+f*(y-x),_=7.771561172376103e-16*((Math.abs(d)+Math.abs(g))*Math.abs(u)+(Math.abs(v)+Math.abs(m))*Math.abs(h)+(Math.abs(y)+Math.abs(x))*Math.abs(f));return b>_||-b>_?b:p(t,e,r,n)}];!function(){for(;d.length<=s;)d.push(h(d.length));for(var t=[],r=[\"slow\"],n=0;n<=s;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function getOrientation(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=s;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return getOrientation\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[function(t){var e=d[t.length];return e||(e=d[t.length]=h(t.length)),e.apply(void 0,t)}].concat(d)),n=0;n<=s;++n)e.exports[n]=d[n]}()},{\"robust-scale\":512,\"robust-subtract\":514,\"robust-sum\":515,\"two-product\":543}],511:[function(t,e,r){\"use strict\";var n=t(\"robust-sum\"),i=t(\"robust-scale\");e.exports=function(t,e){if(1===t.length)return i(e,t[0]);if(1===e.length)return i(t,e[0]);if(0===t.length||0===e.length)return[0];var r=[0];if(t.length<e.length)for(var a=0;a<t.length;++a)r=n(r,i(e,t[a]));else for(var a=0;a<e.length;++a)r=n(r,i(t,e[a]));return r}},{\"robust-scale\":512,\"robust-sum\":515}],512:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"two-sum\");e.exports=function(t,e){var r=t.length;if(1===r){var a=n(t[0],e);return a[0]?a:[a[1]]}var o=new Array(2*r),s=[.1,.1],l=[.1,.1],c=0;n(t[0],e,s),s[0]&&(o[c++]=s[0]);for(var u=1;u<r;++u){n(t[u],e,l);var h=s[1];i(h,l[0],s),s[0]&&(o[c++]=s[0]);var f=l[1],p=s[1],d=f+p,g=d-f,v=p-g;s[1]=d,v&&(o[c++]=v)}s[1]&&(o[c++]=s[1]);0===c&&(o[c++]=0);return o.length=c,o}},{\"two-product\":543,\"two-sum\":544}],513:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){var a=n(t,r,i),o=n(e,r,i);if(a>0&&o>0||a<0&&o<0)return!1;var s=n(r,t,e),l=n(i,t,e);if(s>0&&l>0||s<0&&l<0)return!1;if(0===a&&0===o&&0===s&&0===l)return function(t,e,r,n){for(var i=0;i<2;++i){var a=t[i],o=e[i],s=Math.min(a,o),l=Math.max(a,o),c=r[i],u=n[i],h=Math.min(c,u),f=Math.max(c,u);if(f<s||l<h)return!1}return!0}(t,e,r,i);return!0};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":510}],514:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],-e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,h=t[l],f=u(h),p=-e[c],d=u(p);f<d?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=-e[c],d=u(p)));l<r&&f<d||c>=n?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p)));var g,v,m=i+a,y=m-i,x=a-y,b=x,_=m;for(;l<r&&c<n;)f<d?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p))),(x=(a=b)-(y=(m=i+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g;for(;l<r;)(x=(a=b)-(y=(m=(i=h)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(l+=1)<r&&(h=t[l]);for(;c<n;)(x=(a=b)-(y=(m=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(c+=1)<n&&(p=-e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],515:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,h=t[l],f=u(h),p=e[c],d=u(p);f<d?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=e[c],d=u(p)));l<r&&f<d||c>=n?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=e[c],d=u(p)));var g,v,m=i+a,y=m-i,x=a-y,b=x,_=m;for(;l<r&&c<n;)f<d?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=e[c],d=u(p))),(x=(a=b)-(y=(m=i+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g;for(;l<r;)(x=(a=b)-(y=(m=(i=h)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(l+=1)<r&&(h=t[l]);for(;c<n;)(x=(a=b)-(y=(m=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(c+=1)<n&&(p=e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],516:[function(t,e,r){\"use strict\";e.exports=function(t){return t<0?-1:t>0?1:0}},{}],517:[function(t,e,r){\"use strict\";e.exports=function(t){return i(n(t))};var n=t(\"boundary-cells\"),i=t(\"reduce-simplicial-complex\")},{\"boundary-cells\":95,\"reduce-simplicial-complex\":489}],518:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,s){r=r||0,\"undefined\"==typeof s&&(s=function(t){for(var e=t.length,r=0,n=0;n<e;++n)r=0|Math.max(r,t[n].length);return r-1}(t));if(0===t.length||s<1)return{cells:[],vertexIds:[],vertexWeights:[]};var l=function(t,e){for(var r=t.length,n=i.mallocUint8(r),a=0;a<r;++a)n[a]=t[a]<e|0;return n}(e,+r),c=function(t,e){for(var r=t.length,o=e*(e+1)/2*r|0,s=i.mallocUint32(2*o),l=0,c=0;c<r;++c)for(var u=t[c],e=u.length,h=0;h<e;++h)for(var f=0;f<h;++f){var p=u[f],d=u[h];s[l++]=0|Math.min(p,d),s[l++]=0|Math.max(p,d)}a(n(s,[l/2|0,2]));for(var g=2,c=2;c<l;c+=2)s[c-2]===s[c]&&s[c-1]===s[c+1]||(s[g++]=s[c],s[g++]=s[c+1]);return n(s,[g/2|0,2])}(t,s),u=function(t,e,r,a){for(var o=t.data,s=t.shape[0],l=i.mallocDouble(s),c=0,u=0;u<s;++u){var h=o[2*u],f=o[2*u+1];if(r[h]!==r[f]){var p=e[h],d=e[f];o[2*c]=h,o[2*c+1]=f,l[c++]=(d-a)/(d-p)}}return t.shape[0]=c,n(l,[c])}(c,e,l,+r),h=function(t,e){var r=i.mallocInt32(2*e),n=t.shape[0],a=t.data;r[0]=0;for(var o=0,s=0;s<n;++s){var l=a[2*s];if(l!==o){for(r[2*o+1]=s;++o<l;)r[2*o]=s,r[2*o+1]=s;r[2*o]=s}}r[2*o+1]=n;for(;++o<e;)r[2*o]=r[2*o+1]=n;return r}(c,0|e.length),f=o(s)(t,c.data,h,l),p=function(t){for(var e=0|t.shape[0],r=t.data,n=new Array(e),i=0;i<e;++i)n[i]=[r[2*i],r[2*i+1]];return n}(c),d=[].slice.call(u.data,0,u.shape[0]);return i.free(l),i.free(c.data),i.free(u.data),i.free(h),{cells:f,vertexIds:p,vertexWeights:d}};var n=t(\"ndarray\"),i=t(\"typedarray-pool\"),a=t(\"ndarray-sort\"),o=t(\"./lib/codegen\")},{\"./lib/codegen\":519,ndarray:450,\"ndarray-sort\":448,\"typedarray-pool\":545}],519:[function(t,e,r){\"use strict\";e.exports=function(t){var e=a[t];e||(e=a[t]=function(t){var e=0,r=new Array(t+1);r[0]=[[]];for(var a=1;a<=t;++a)for(var o=r[a]=i(a),s=0;s<o.length;++s)e=Math.max(e,o[a].length);var l=[\"function B(C,E,i,j){\",\"var a=Math.min(i,j)|0,b=Math.max(i,j)|0,l=C[2*a],h=C[2*a+1];\",\"while(l<h){\",\"var m=(l+h)>>1,v=E[2*m+1];\",\"if(v===b){return m}\",\"if(b<v){h=m}else{l=m+1}\",\"}\",\"return l;\",\"};\",\"function getContour\",t,\"d(F,E,C,S){\",\"var n=F.length,R=[];\",\"for(var i=0;i<n;++i){var c=F[i],l=c.length;\"];function c(t){if(!(t.length<=0)){l.push(\"R.push(\");for(var e=0;e<t.length;++e){var r=t[e];e>0&&l.push(\",\"),l.push(\"[\");for(var n=0;n<r.length;++n){var i=r[n];n>0&&l.push(\",\"),l.push(\"B(C,E,c[\",i[0],\"],c[\",i[1],\"])\")}l.push(\"]\")}l.push(\");\")}}for(var a=t+1;a>1;--a){a<t+1&&l.push(\"else \"),l.push(\"if(l===\",a,\"){\");for(var u=[],s=0;s<a;++s)u.push(\"(S[c[\"+s+\"]]<<\"+s+\")\");l.push(\"var M=\",u.join(\"+\"),\";if(M===0||M===\",(1<<a)-1,\"){continue}switch(M){\");for(var o=r[a-1],s=0;s<o.length;++s)l.push(\"case \",s,\":\"),c(o[s]),l.push(\"break;\");l.push(\"}}\")}return l.push(\"}return R;};return getContour\",t,\"d\"),new Function(\"pool\",l.join(\"\"))(n)}(t));return e};var n=t(\"typedarray-pool\"),i=t(\"marching-simplex-table\"),a={}},{\"marching-simplex-table\":427,\"typedarray-pool\":545}],520:[function(t,e,r){\"use strict\";var n=t(\"bit-twiddle\"),i=t(\"union-find\");function a(t,e){var r=t.length,n=t.length-e.length,i=Math.min;if(n)return n;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return(s=t[0]+t[1]-e[0]-e[1])||i(t[0],t[1])-i(e[0],e[1]);case 3:var a=t[0]+t[1],o=e[0]+e[1];if(s=a+t[2]-(o+e[2]))return s;var s,l=i(t[0],t[1]),c=i(e[0],e[1]);return(s=i(l,t[2])-i(c,e[2]))||i(l+t[2],a)-i(c+e[2],o);default:var u=t.slice(0);u.sort();var h=e.slice(0);h.sort();for(var f=0;f<r;++f)if(n=u[f]-h[f])return n;return 0}}function o(t,e){return a(t[0],e[0])}function s(t,e){if(e){for(var r=t.length,n=new Array(r),i=0;i<r;++i)n[i]=[t[i],e[i]];n.sort(o);for(i=0;i<r;++i)t[i]=n[i][0],e[i]=n[i][1];return t}return t.sort(a),t}function l(t){if(0===t.length)return[];for(var e=1,r=t.length,n=1;n<r;++n){var i=t[n];if(a(i,t[n-1])){if(n===e){e++;continue}t[e++]=i}}return t.length=e,t}function c(t,e){for(var r=0,n=t.length-1,i=-1;r<=n;){var o=r+n>>1,s=a(t[o],e);s<=0?(0===s&&(i=o),r=o+1):s>0&&(n=o-1)}return i}function u(t,e){for(var r=new Array(t.length),i=0,o=r.length;i<o;++i)r[i]=[];for(var s=[],l=(i=0,e.length);i<l;++i)for(var u=e[i],h=u.length,f=1,p=1<<h;f<p;++f){s.length=n.popCount(f);for(var d=0,g=0;g<h;++g)f&1<<g&&(s[d++]=u[g]);var v=c(t,s);if(!(v<0))for(;r[v++].push(i),!(v>=t.length||0!==a(t[v],s)););}return r}function h(t,e){if(e<0)return[];for(var r=[],i=(1<<e+1)-1,a=0;a<t.length;++a)for(var o=t[a],l=i;l<1<<o.length;l=n.nextCombination(l)){for(var c=new Array(e+1),u=0,h=0;h<o.length;++h)l&1<<h&&(c[u++]=o[h]);r.push(c)}return s(r)}r.dimension=function(t){for(var e=0,r=Math.max,n=0,i=t.length;n<i;++n)e=r(e,t[n].length);return e-1},r.countVertices=function(t){for(var e=-1,r=Math.max,n=0,i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)e=r(e,a[o]);return e+1},r.cloneCells=function(t){for(var e=new Array(t.length),r=0,n=t.length;r<n;++r)e[r]=t[r].slice(0);return e},r.compareCells=a,r.normalize=s,r.unique=l,r.findCell=c,r.incidence=u,r.dual=function(t,e){if(!e)return u(l(h(t,0)),t);for(var r=new Array(e),n=0;n<e;++n)r[n]=[];n=0;for(var i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)r[a[o]].push(n);return r},r.explode=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0|i.length,o=1,l=1<<a;o<l;++o){for(var c=[],u=0;u<a;++u)o>>>u&1&&c.push(i[u]);e.push(c)}return s(e)},r.skeleton=h,r.boundary=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;++a){for(var l=new Array(i.length-1),c=0,u=0;c<o;++c)c!==a&&(l[u++]=i[c]);e.push(l)}return s(e)},r.connectedComponents=function(t,e){return e?function(t,e){for(var r=new i(e),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var s=o+1;s<a.length;++s)r.link(a[o],a[s]);var l=[],c=r.ranks;for(n=0;n<c.length;++n)c[n]=-1;for(n=0;n<t.length;++n){var u=r.find(t[n][0]);c[u]<0?(c[u]=l.length,l.push([t[n].slice(0)])):l[c[u]].push(t[n].slice(0))}return l}(t,e):function(t){for(var e=l(s(h(t,0))),r=new i(e.length),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var u=c(e,[a[o]]),f=o+1;f<a.length;++f)r.link(u,c(e,[a[f]]));var p=[],d=r.ranks;for(n=0;n<d.length;++n)d[n]=-1;for(n=0;n<t.length;++n){var g=r.find(c(e,[t[n][0]]));d[g]<0?(d[g]=p.length,p.push([t[n].slice(0)])):p[d[g]].push(t[n].slice(0))}return p}(t)}},{\"bit-twiddle\":92,\"union-find\":546}],521:[function(t,e,r){arguments[4][92][0].apply(r,arguments)},{dup:92}],522:[function(t,e,r){arguments[4][520][0].apply(r,arguments)},{\"bit-twiddle\":521,dup:520,\"union-find\":523}],523:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n,n.prototype.length=function(){return this.roots.length},n.prototype.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},n.prototype.find=function(t){for(var e=this.roots;e[t]!==t;){var r=e[t];e[t]=e[r],t=r}return t},n.prototype.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],524:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){for(var a=e.length,o=t.length,s=new Array(a),l=new Array(a),c=new Array(a),u=new Array(a),h=0;h<a;++h)s[h]=l[h]=-1,c[h]=1/0,u[h]=!1;for(var h=0;h<o;++h){var f=t[h];if(2!==f.length)throw new Error(\"Input must be a graph\");var p=f[1],d=f[0];-1!==l[d]?l[d]=-2:l[d]=p,-1!==s[p]?s[p]=-2:s[p]=d}function g(t){if(u[t])return 1/0;var r,i,a,o,c,h=s[t],f=l[t];return h<0||f<0?1/0:(r=e[t],i=e[h],a=e[f],o=Math.abs(n(r,i,a)),c=Math.sqrt(Math.pow(i[0]-a[0],2)+Math.pow(i[1]-a[1],2)),o/c)}function v(t,e){var r=T[t],n=T[e];T[t]=n,T[e]=r,A[r]=e,A[n]=t}function m(t){return c[T[t]]}function y(t){return 1&t?t-1>>1:(t>>1)-1}function x(t){for(var e=m(t);;){var r=e,n=2*t+1,i=2*(t+1),a=t;if(n<S){var o=m(n);o<r&&(a=n,r=o)}if(i<S){var s=m(i);s<r&&(a=i)}if(a===t)return t;v(t,a),t=a}}function b(t){for(var e=m(t);t>0;){var r=y(t);if(r>=0){var n=m(r);if(e<n){v(t,r),t=r;continue}}return t}}function _(){if(S>0){var t=T[0];return v(0,S-1),S-=1,x(0),t}return-1}function w(t,e){var r=T[t];return c[r]===e?t:(c[r]=-1/0,b(t),_(),c[r]=e,b((S+=1)-1))}function k(t){if(!u[t]){u[t]=!0;var e=s[t],r=l[t];s[r]>=0&&(s[r]=e),l[e]>=0&&(l[e]=r),A[e]>=0&&w(A[e],g(e)),A[r]>=0&&w(A[r],g(r))}}for(var T=[],A=new Array(a),h=0;h<a;++h){var M=c[h]=g(h);M<1/0?(A[h]=T.length,T.push(h)):A[h]=-1}for(var S=T.length,h=S>>1;h>=0;--h)x(h);for(;;){var E=_();if(E<0||c[E]>r)break;k(E)}for(var C=[],h=0;h<a;++h)u[h]||(A[h]=C.length,C.push(e[h].slice()));C.length;function L(t,e){if(t[e]<0)return e;var r=e,n=e;do{var i=t[n];if(!u[n]||i<0||i===n)break;if(i=t[n=i],!u[n]||i<0||i===n)break;n=i,r=t[r]}while(r!==n);for(var a=e;a!==n;a=t[a])t[a]=n;return n}var P=[];return t.forEach(function(t){var e=L(s,t[0]),r=L(l,t[1]);if(e>=0&&r>=0&&e!==r){var n=A[e],i=A[r];n!==i&&P.push([n,i])}}),i.unique(i.normalize(P)),{positions:C,edges:P}};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\")},{\"robust-orientation\":510,\"simplicial-complex\":522}],525:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,a,o,s;if(e[0][0]<e[1][0])r=e[0],a=e[1];else{if(!(e[0][0]>e[1][0]))return i(e,t);r=e[1],a=e[0]}if(t[0][0]<t[1][0])o=t[0],s=t[1];else{if(!(t[0][0]>t[1][0]))return-i(t,e);o=t[1],s=t[0]}var l=n(r,a,s),c=n(r,a,o);if(l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;if(l=n(s,o,a),c=n(s,o,r),l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;return a[0]-s[0]};var n=t(\"robust-orientation\");function i(t,e){var r,i,a,o;if(e[0][0]<e[1][0])r=e[0],i=e[1];else{if(!(e[0][0]>e[1][0])){var s=Math.min(t[0][1],t[1][1]),l=Math.max(t[0][1],t[1][1]),c=Math.min(e[0][1],e[1][1]),u=Math.max(e[0][1],e[1][1]);return l<c?l-c:s>u?s-u:l-u}r=e[1],i=e[0]}t[0][1]<t[1][1]?(a=t[0],o=t[1]):(a=t[1],o=t[0]);var h=n(i,r,a);return h||((h=n(i,r,o))||o-i)}},{\"robust-orientation\":510}],526:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=2*e,n=new Array(r),a=0;a<e;++a){var l=t[a],c=l[0][0]<l[1][0];n[2*a]=new h(l[0][0],l,c,a),n[2*a+1]=new h(l[1][0],l,!c,a)}n.sort(function(t,e){var r=t.x-e.x;return r||((r=t.create-e.create)||Math.min(t.segment[0][1],t.segment[1][1])-Math.min(e.segment[0][1],e.segment[1][1]))});for(var f=i(o),p=[],d=[],g=[],a=0;a<r;){for(var v=n[a].x,m=[];a<r;){var y=n[a];if(y.x!==v)break;a+=1,y.segment[0][0]===y.x&&y.segment[1][0]===y.x?y.create&&(y.segment[0][1]<y.segment[1][1]?(m.push(new u(y.segment[0][1],y.index,!0,!0)),m.push(new u(y.segment[1][1],y.index,!1,!1))):(m.push(new u(y.segment[1][1],y.index,!0,!1)),m.push(new u(y.segment[0][1],y.index,!1,!0)))):f=y.create?f.insert(y.segment,y.index):f.remove(y.segment)}p.push(f.root),d.push(v),g.push(m)}return new s(p,d,g)};var n=t(\"binary-search-bounds\"),i=t(\"functional-red-black-tree\"),a=t(\"robust-orientation\"),o=t(\"./lib/order-segments\");function s(t,e,r){this.slabs=t,this.coordinates=e,this.horizontal=r}function l(t,e){return t.y-e}function c(t,e){for(var r=null;t;){var n,i,o=t.key;o[0][0]<o[1][0]?(n=o[0],i=o[1]):(n=o[1],i=o[0]);var s=a(n,i,e);if(s<0)t=t.left;else if(s>0)if(e[0]!==o[1][0])r=t,t=t.right;else{if(l=c(t.right,e))return l;t=t.left}else{if(e[0]!==o[1][0])return t;var l;if(l=c(t.right,e))return l;t=t.left}}return r}function u(t,e,r,n){this.y=t,this.index=e,this.start=r,this.closed=n}function h(t,e,r,n){this.x=t,this.segment=e,this.create=r,this.index=n}s.prototype.castUp=function(t){var e=n.le(this.coordinates,t[0]);if(e<0)return-1;this.slabs[e];var r=c(this.slabs[e],t),i=-1;if(r&&(i=r.value),this.coordinates[e]===t[0]){var s=null;if(r&&(s=r.key),e>0){var u=c(this.slabs[e-1],t);u&&(s?o(u.key,s)>0&&(s=u.key,i=u.value):(i=u.value,s=u.key))}var h=this.horizontal[e];if(h.length>0){var f=n.ge(h,t[1],l);if(f<h.length){var p=h[f];if(t[1]===p.y){if(p.closed)return p.index;for(;f<h.length-1&&h[f+1].y===t[1];)if((p=h[f+=1]).closed)return p.index;if(p.y===t[1]&&!p.start){if((f+=1)>=h.length)return i;p=h[f]}}if(p.start)if(s){var d=a(s[0],s[1],[t[0],p.y]);s[0][0]>s[1][0]&&(d=-d),d>0&&(i=p.index)}else i=p.index;else p.y!==t[1]&&(i=p.index)}}}return i}},{\"./lib/order-segments\":525,\"binary-search-bounds\":91,\"functional-red-black-tree\":230,\"robust-orientation\":510}],527:[function(t,e,r){\"use strict\";var n=t(\"robust-dot-product\"),i=t(\"robust-sum\");function a(t,e){var r=i(n(t,e),[e[e.length-1]]);return r[r.length-1]}function o(t,e,r,n){var i=-e/(n-e);i<0?i=0:i>1&&(i=1);for(var a=1-i,o=t.length,s=new Array(o),l=0;l<o;++l)s[l]=i*t[l]+a*r[l];return s}e.exports=function(t,e){for(var r=[],n=[],i=a(t[t.length-1],e),s=t[t.length-1],l=t[0],c=0;c<t.length;++c,s=l){var u=a(l=t[c],e);if(i<0&&u>0||i>0&&u<0){var h=o(s,u,l,i);r.push(h),n.push(h.slice())}u<0?n.push(l.slice()):u>0?r.push(l.slice()):(r.push(l.slice()),n.push(l.slice())),i=u}return{positive:r,negative:n}},e.exports.positive=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c>=0&&r.push(s.slice()),n=c}return r},e.exports.negative=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c<=0&&r.push(s.slice()),n=c}return r}},{\"robust-dot-product\":507,\"robust-sum\":515}],528:[function(t,e,r){!function(){\"use strict\";var t={not_string:/[^s]/,not_bool:/[^t]/,not_type:/[^T]/,not_primitive:/[^v]/,number:/[diefg]/,numeric_arg:/[bcdiefguxX]/,json:/[j]/,not_json:/[^j]/,text:/^[^\\x25]+/,modulo:/^\\x25{2}/,placeholder:/^\\x25(?:([1-9]\\d*)\\$|\\(([^)]+)\\))?(\\+)?(0|'[^$])?(-)?(\\d+)?(?:\\.(\\d+))?([b-gijostTuvxX])/,key:/^([a-z_][a-z_\\d]*)/i,key_access:/^\\.([a-z_][a-z_\\d]*)/i,index_access:/^\\[(\\d+)\\]/,sign:/^[+-]/};function e(r){return function(r,n){var i,a,o,s,l,c,u,h,f,p=1,d=r.length,g=\"\";for(a=0;a<d;a++)if(\"string\"==typeof r[a])g+=r[a];else if(\"object\"==typeof r[a]){if((s=r[a]).keys)for(i=n[p],o=0;o<s.keys.length;o++){if(null==i)throw new Error(e('[sprintf] Cannot access property \"%s\" of undefined value \"%s\"',s.keys[o],s.keys[o-1]));i=i[s.keys[o]]}else i=s.param_no?n[s.param_no]:n[p++];if(t.not_type.test(s.type)&&t.not_primitive.test(s.type)&&i instanceof Function&&(i=i()),t.numeric_arg.test(s.type)&&\"number\"!=typeof i&&isNaN(i))throw new TypeError(e(\"[sprintf] expecting number but found %T\",i));switch(t.number.test(s.type)&&(h=i>=0),s.type){case\"b\":i=parseInt(i,10).toString(2);break;case\"c\":i=String.fromCharCode(parseInt(i,10));break;case\"d\":case\"i\":i=parseInt(i,10);break;case\"j\":i=JSON.stringify(i,null,s.width?parseInt(s.width):0);break;case\"e\":i=s.precision?parseFloat(i).toExponential(s.precision):parseFloat(i).toExponential();break;case\"f\":i=s.precision?parseFloat(i).toFixed(s.precision):parseFloat(i);break;case\"g\":i=s.precision?String(Number(i.toPrecision(s.precision))):parseFloat(i);break;case\"o\":i=(parseInt(i,10)>>>0).toString(8);break;case\"s\":i=String(i),i=s.precision?i.substring(0,s.precision):i;break;case\"t\":i=String(!!i),i=s.precision?i.substring(0,s.precision):i;break;case\"T\":i=Object.prototype.toString.call(i).slice(8,-1).toLowerCase(),i=s.precision?i.substring(0,s.precision):i;break;case\"u\":i=parseInt(i,10)>>>0;break;case\"v\":i=i.valueOf(),i=s.precision?i.substring(0,s.precision):i;break;case\"x\":i=(parseInt(i,10)>>>0).toString(16);break;case\"X\":i=(parseInt(i,10)>>>0).toString(16).toUpperCase()}t.json.test(s.type)?g+=i:(!t.number.test(s.type)||h&&!s.sign?f=\"\":(f=h?\"+\":\"-\",i=i.toString().replace(t.sign,\"\")),c=s.pad_char?\"0\"===s.pad_char?\"0\":s.pad_char.charAt(1):\" \",u=s.width-(f+i).length,l=s.width&&u>0?c.repeat(u):\"\",g+=s.align?f+i+l:\"0\"===c?f+l+i:l+f+i)}return g}(function(e){if(i[e])return i[e];var r,n=e,a=[],o=0;for(;n;){if(null!==(r=t.text.exec(n)))a.push(r[0]);else if(null!==(r=t.modulo.exec(n)))a.push(\"%\");else{if(null===(r=t.placeholder.exec(n)))throw new SyntaxError(\"[sprintf] unexpected placeholder\");if(r[2]){o|=1;var s=[],l=r[2],c=[];if(null===(c=t.key.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");for(s.push(c[1]);\"\"!==(l=l.substring(c[0].length));)if(null!==(c=t.key_access.exec(l)))s.push(c[1]);else{if(null===(c=t.index_access.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");s.push(c[1])}r[2]=s}else o|=2;if(3===o)throw new Error(\"[sprintf] mixing positional and named placeholders is not (yet) supported\");a.push({placeholder:r[0],param_no:r[1],keys:r[2],sign:r[3],pad_char:r[4],align:r[5],width:r[6],precision:r[7],type:r[8]})}n=n.substring(r[0].length)}return i[e]=a}(r),arguments)}function n(t,r){return e.apply(null,[t].concat(r||[]))}var i=Object.create(null);\"undefined\"!=typeof r&&(r.sprintf=e,r.vsprintf=n),\"undefined\"!=typeof window&&(window.sprintf=e,window.vsprintf=n)}()},{}],529:[function(t,e,r){\"use strict\";var n=t(\"parenthesis\");e.exports=function(t,e,r){if(null==t)throw Error(\"First argument should be a string\");if(null==e)throw Error(\"Separator should be a string or a RegExp\");r?(\"string\"==typeof r||Array.isArray(r))&&(r={ignore:r}):r={},null==r.escape&&(r.escape=!0),null==r.ignore?r.ignore=[\"[]\",\"()\",\"{}\",\"<>\",'\"\"',\"''\",\"``\",\"\\u201c\\u201d\",\"\\xab\\xbb\"]:(\"string\"==typeof r.ignore&&(r.ignore=[r.ignore]),r.ignore=r.ignore.map(function(t){return 1===t.length&&(t+=t),t}));var i=n.parse(t,{flat:!0,brackets:r.ignore}),a=i[0].split(e);if(r.escape){for(var o=[],s=0;s<a.length;s++){var l=a[s],c=a[s+1];\"\\\\\"===l[l.length-1]&&\"\\\\\"!==l[l.length-2]?(o.push(l+e+c),s++):o.push(l)}a=o}for(s=0;s<a.length;s++)i[0]=a[s],a[s]=n.stringify(i,{flat:!0});return a}},{parenthesis:458}],530:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=new Array(e),n=new Array(e),i=new Array(e),a=new Array(e),o=new Array(e),s=new Array(e),l=0;l<e;++l)r[l]=-1,n[l]=0,i[l]=!1,a[l]=0,o[l]=-1,s[l]=[];var c,u=0,h=[],f=[];function p(e){var l=[e],c=[e];for(r[e]=n[e]=u,i[e]=!0,u+=1;c.length>0;){e=c[c.length-1];var p=t[e];if(a[e]<p.length){for(var d=a[e];d<p.length;++d){var g=p[d];if(r[g]<0){r[g]=n[g]=u,i[g]=!0,u+=1,l.push(g),c.push(g);break}i[g]&&(n[e]=0|Math.min(n[e],n[g])),o[g]>=0&&s[e].push(o[g])}a[e]=d}else{if(n[e]===r[e]){for(var v=[],m=[],y=0,d=l.length-1;d>=0;--d){var x=l[d];if(i[x]=!1,v.push(x),m.push(s[x]),y+=s[x].length,o[x]=h.length,x===e){l.length=d;break}}h.push(v);for(var b=new Array(y),d=0;d<m.length;d++)for(var _=0;_<m[d].length;_++)b[--y]=m[d][_];f.push(b)}c.pop()}}}for(var l=0;l<e;++l)r[l]<0&&p(l);for(var l=0;l<f.length;l++){var d=f[l];if(0!==d.length){d.sort(function(t,e){return t-e}),c=[d[0]];for(var g=1;g<d.length;g++)d[g]!==d[g-1]&&c.push(d[g]);f[l]=c}}return{components:h,adjacencyList:f}}},{}],531:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(t.dimension<=0)return{positions:[],cells:[]};if(1===t.dimension)return function(t,e){for(var r=a(t,e),n=r.length,i=new Array(n),o=new Array(n),s=0;s<n;++s)i[s]=[r[s]],o[s]=[s];return{positions:i,cells:o}}(t,e);var r=t.order.join()+\"-\"+t.dtype,s=o[r],e=+e||0;s||(s=o[r]=function(t,e){var r=t.length,a=[\"'use strict';\"],o=\"surfaceNets\"+t.join(\"_\")+\"d\"+e;a.push(\"var contour=genContour({\",\"order:[\",t.join(),\"],\",\"scalarArguments: 3,\",\"phase:function phaseFunc(p,a,b,c) { return (p > c)|0 },\"),\"generic\"===e&&a.push(\"getters:[0],\");for(var s=[],l=[],c=0;c<r;++c)s.push(\"d\"+c),l.push(\"d\"+c);for(var c=0;c<1<<r;++c)s.push(\"v\"+c),l.push(\"v\"+c);for(var c=0;c<1<<r;++c)s.push(\"p\"+c),l.push(\"p\"+c);s.push(\"a\",\"b\",\"c\"),l.push(\"a\",\"c\"),a.push(\"vertex:function vertexFunc(\",s.join(),\"){\");for(var u=[],c=0;c<1<<r;++c)u.push(\"(p\"+c+\"<<\"+c+\")\");a.push(\"var m=(\",u.join(\"+\"),\")|0;if(m===0||m===\",(1<<(1<<r))-1,\"){return}\");var h=[],f=[];1<<(1<<r)<=128?(a.push(\"switch(m){\"),f=a):a.push(\"switch(m>>>7){\");for(var c=0;c<1<<(1<<r);++c){if(1<<(1<<r)>128&&c%128==0){h.length>0&&f.push(\"}}\");var p=\"vExtra\"+h.length;a.push(\"case \",c>>>7,\":\",p,\"(m&0x7f,\",l.join(),\");break;\"),f=[\"function \",p,\"(m,\",l.join(),\"){switch(m){\"],h.push(f)}f.push(\"case \",127&c,\":\");for(var d=new Array(r),g=new Array(r),v=new Array(r),m=new Array(r),y=0,x=0;x<r;++x)d[x]=[],g[x]=[],v[x]=0,m[x]=0;for(var x=0;x<1<<r;++x)for(var b=0;b<r;++b){var _=x^1<<b;if(!(_>x)&&!(c&1<<_)!=!(c&1<<x)){var w=1;c&1<<_?g[b].push(\"v\"+_+\"-v\"+x):(g[b].push(\"v\"+x+\"-v\"+_),w=-w),w<0?(d[b].push(\"-v\"+x+\"-v\"+_),v[b]+=2):(d[b].push(\"v\"+x+\"+v\"+_),v[b]-=2),y+=1;for(var k=0;k<r;++k)k!==b&&(_&1<<k?m[k]+=1:m[k]-=1)}}for(var T=[],b=0;b<r;++b)if(0===d[b].length)T.push(\"d\"+b+\"-0.5\");else{var A=\"\";v[b]<0?A=v[b]+\"*c\":v[b]>0&&(A=\"+\"+v[b]+\"*c\");var M=d[b].length/y*.5,S=.5+m[b]/y*.5;T.push(\"d\"+b+\"-\"+S+\"-\"+M+\"*(\"+d[b].join(\"+\")+A+\")/(\"+g[b].join(\"+\")+\")\")}f.push(\"a.push([\",T.join(),\"]);\",\"break;\")}a.push(\"}},\"),h.length>0&&f.push(\"}}\");for(var E=[],c=0;c<1<<r-1;++c)E.push(\"v\"+c);E.push(\"c0\",\"c1\",\"p0\",\"p1\",\"a\",\"b\",\"c\"),a.push(\"cell:function cellFunc(\",E.join(),\"){\");var C=i(r-1);a.push(\"if(p0){b.push(\",C.map(function(t){return\"[\"+t.map(function(t){return\"v\"+t})+\"]\"}).join(),\")}else{b.push(\",C.map(function(t){var e=t.slice();return e.reverse(),\"[\"+e.map(function(t){return\"v\"+t})+\"]\"}).join(),\")}}});function \",o,\"(array,level){var verts=[],cells=[];contour(array,verts,cells,level);return {positions:verts,cells:cells};} return \",o,\";\");for(var c=0;c<h.length;++c)a.push(h[c].join(\"\"));return new Function(\"genContour\",a.join(\"\"))(n)}(t.order,t.dtype));return s(t,e)};var n=t(\"ndarray-extract-contour\"),i=t(\"triangulate-hypercube\"),a=t(\"zero-crossings\");var o={}},{\"ndarray-extract-contour\":439,\"triangulate-hypercube\":541,\"zero-crossings\":574}],532:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=function(){return function(t,e){if(Array.isArray(t))return t;if(Symbol.iterator in Object(t))return function(t,e){var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{!n&&s.return&&s.return()}finally{if(i)throw a}}return r}(t,e);throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")}}(),i=2*Math.PI,a=function(t,e,r,n,i,a,o){var s=t.x,l=t.y;return{x:n*(s*=e)-i*(l*=r)+a,y:i*s+n*l+o}},o=function(t,e){var r=.551915024494*(e<0?-1:1),n=Math.cos(t),i=Math.sin(t),a=Math.cos(t+e),o=Math.sin(t+e);return[{x:n-i*r,y:i+n*r},{x:a+o*r,y:o-a*r},{x:a,y:o}]},s=function(t,e,r,n){var i=t*n-e*r<0?-1:1,a=(t*r+e*n)/(Math.sqrt(t*t+e*e)*Math.sqrt(t*t+e*e));return a>1&&(a=1),a<-1&&(a=-1),i*Math.acos(a)};r.default=function(t){var e=t.px,r=t.py,l=t.cx,c=t.cy,u=t.rx,h=t.ry,f=t.xAxisRotation,p=void 0===f?0:f,d=t.largeArcFlag,g=void 0===d?0:d,v=t.sweepFlag,m=void 0===v?0:v,y=[];if(0===u||0===h)return[];var x=Math.sin(p*i/360),b=Math.cos(p*i/360),_=b*(e-l)/2+x*(r-c)/2,w=-x*(e-l)/2+b*(r-c)/2;if(0===_&&0===w)return[];u=Math.abs(u),h=Math.abs(h);var k=Math.pow(_,2)/Math.pow(u,2)+Math.pow(w,2)/Math.pow(h,2);k>1&&(u*=Math.sqrt(k),h*=Math.sqrt(k));var T=function(t,e,r,n,a,o,l,c,u,h,f,p){var d=Math.pow(a,2),g=Math.pow(o,2),v=Math.pow(f,2),m=Math.pow(p,2),y=d*g-d*m-g*v;y<0&&(y=0),y/=d*m+g*v;var x=(y=Math.sqrt(y)*(l===c?-1:1))*a/o*p,b=y*-o/a*f,_=h*x-u*b+(t+r)/2,w=u*x+h*b+(e+n)/2,k=(f-x)/a,T=(p-b)/o,A=(-f-x)/a,M=(-p-b)/o,S=s(1,0,k,T),E=s(k,T,A,M);return 0===c&&E>0&&(E-=i),1===c&&E<0&&(E+=i),[_,w,S,E]}(e,r,l,c,u,h,g,m,x,b,_,w),A=n(T,4),M=A[0],S=A[1],E=A[2],C=A[3],L=Math.abs(C)/(i/4);Math.abs(1-L)<1e-7&&(L=1);var P=Math.max(Math.ceil(L),1);C/=P;for(var O=0;O<P;O++)y.push(o(E,C)),E+=C;return y.map(function(t){var e=a(t[0],u,h,b,x,M,S),r=e.x,n=e.y,i=a(t[1],u,h,b,x,M,S),o=i.x,s=i.y,l=a(t[2],u,h,b,x,M,S);return{x1:r,y1:n,x2:o,y2:s,x:l.x,y:l.y}})},e.exports=r.default},{}],533:[function(t,e,r){\"use strict\";var n=t(\"parse-svg-path\"),i=t(\"abs-svg-path\"),a=t(\"normalize-svg-path\"),o=t(\"is-svg-path\"),s=t(\"assert\");e.exports=function(t){Array.isArray(t)&&1===t.length&&\"string\"==typeof t[0]&&(t=t[0]);\"string\"==typeof t&&(s(o(t),\"String is not an SVG path.\"),t=n(t));if(s(Array.isArray(t),\"Argument should be a string or an array of path segments.\"),t=i(t),!(t=a(t)).length)return[0,0,0,0];for(var e=[1/0,1/0,-1/0,-1/0],r=0,l=t.length;r<l;r++)for(var c=t[r].slice(1),u=0;u<c.length;u+=2)c[u+0]<e[0]&&(e[0]=c[u+0]),c[u+1]<e[1]&&(e[1]=c[u+1]),c[u+0]>e[2]&&(e[2]=c[u+0]),c[u+1]>e[3]&&(e[3]=c[u+1]);return e}},{\"abs-svg-path\":60,assert:68,\"is-svg-path\":424,\"normalize-svg-path\":534,\"parse-svg-path\":460}],534:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=[],o=0,s=0,l=0,c=0,u=null,h=null,f=0,p=0,d=0,g=t.length;d<g;d++){var v=t[d],m=v[0];switch(m){case\"M\":l=v[1],c=v[2];break;case\"A\":var y=n({px:f,py:p,cx:v[6],cy:v[7],rx:v[1],ry:v[2],xAxisRotation:v[3],largeArcFlag:v[4],sweepFlag:v[5]});if(!y.length)continue;for(var x,b=0;b<y.length;b++)x=y[b],v=[\"C\",x.x1,x.y1,x.x2,x.y2,x.x,x.y],b<y.length-1&&r.push(v);break;case\"S\":var _=f,w=p;\"C\"!=e&&\"S\"!=e||(_+=_-o,w+=w-s),v=[\"C\",_,w,v[1],v[2],v[3],v[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(u=2*f-u,h=2*p-h):(u=f,h=p),v=a(f,p,u,h,v[1],v[2]);break;case\"Q\":u=v[1],h=v[2],v=a(f,p,v[1],v[2],v[3],v[4]);break;case\"L\":v=i(f,p,v[1],v[2]);break;case\"H\":v=i(f,p,v[1],p);break;case\"V\":v=i(f,p,f,v[1]);break;case\"Z\":v=i(f,p,l,c)}e=m,f=v[v.length-2],p=v[v.length-1],v.length>4?(o=v[v.length-4],s=v[v.length-3]):(o=f,s=p),r.push(v)}return r};var n=t(\"svg-arc-to-cubic-bezier\");function i(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function a(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}},{\"svg-arc-to-cubic-bezier\":532}],535:[function(t,e,r){\"use strict\";var n,i=t(\"svg-path-bounds\"),a=t(\"parse-svg-path\"),o=t(\"draw-svg-path\"),s=t(\"is-svg-path\"),l=t(\"bitmap-sdf\"),c=document.createElement(\"canvas\"),u=c.getContext(\"2d\");e.exports=function(t,e){if(!s(t))throw Error(\"Argument should be valid svg path string\");e||(e={});var r,h;e.shape?(r=e.shape[0],h=e.shape[1]):(r=c.width=e.w||e.width||200,h=c.height=e.h||e.height||200);var f=Math.min(r,h),p=e.stroke||0,d=e.viewbox||e.viewBox||i(t),g=[r/(d[2]-d[0]),h/(d[3]-d[1])],v=Math.min(g[0]||0,g[1]||0)/2;u.fillStyle=\"black\",u.fillRect(0,0,r,h),u.fillStyle=\"white\",p&&(\"number\"!=typeof p&&(p=1),u.strokeStyle=p>0?\"white\":\"black\",u.lineWidth=Math.abs(p));if(u.translate(.5*r,.5*h),u.scale(v,v),function(){if(null!=n)return n;var t=document.createElement(\"canvas\").getContext(\"2d\");if(t.canvas.width=t.canvas.height=1,!window.Path2D)return n=!1;var e=new Path2D(\"M0,0h1v1h-1v-1Z\");t.fillStyle=\"black\",t.fill(e);var r=t.getImageData(0,0,1,1);return n=r&&r.data&&255===r.data[3]}()){var m=new Path2D(t);u.fill(m),p&&u.stroke(m)}else{var y=a(t);o(u,y),u.fill(),p&&u.stroke()}return u.setTransform(1,0,0,1,0,0),l(u,{cutoff:null!=e.cutoff?e.cutoff:.5,radius:null!=e.radius?e.radius:.5*f})}},{\"bitmap-sdf\":93,\"draw-svg-path\":168,\"is-svg-path\":424,\"parse-svg-path\":460,\"svg-path-bounds\":533}],536:[function(t,e,r){(function(r){\"use strict\";e.exports=function t(e,r,i){var i=i||{};var o=a[e];o||(o=a[e]={\" \":{data:new Float32Array(0),shape:.2}});var s=o[r];if(!s)if(r.length<=1||!/\\d/.test(r))s=o[r]=function(t){for(var e=t.cells,r=t.positions,n=new Float32Array(6*e.length),i=0,a=0,o=0;o<e.length;++o)for(var s=e[o],l=0;l<3;++l){var c=r[s[l]];n[i++]=c[0],n[i++]=c[1]+1.4,a=Math.max(c[0],a)}return{data:n,shape:a}}(n(r,{triangles:!0,font:e,textAlign:i.textAlign||\"left\",textBaseline:\"alphabetic\",styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0}}));else{for(var l=r.split(/(\\d|\\s)/),c=new Array(l.length),u=0,h=0,f=0;f<l.length;++f)c[f]=t(e,l[f]),u+=c[f].data.length,h+=c[f].shape,f>0&&(h+=.02);for(var p=new Float32Array(u),d=0,g=-.5*h,f=0;f<c.length;++f){for(var v=c[f].data,m=0;m<v.length;m+=2)p[d++]=v[m]+g,p[d++]=v[m+1];g+=c[f].shape+.02}s=o[r]={data:p,shape:h}}return s};var n=t(\"vectorize-text\"),i=window||r.global||{},a=i.__TEXT_CACHE||{};i.__TEXT_CACHE={}}).call(this,t(\"_process\"))},{_process:482,\"vectorize-text\":550}],537:[function(t,e,r){!function(t){var r=/^\\s+/,n=/\\s+$/,i=0,a=t.round,o=t.min,s=t.max,l=t.random;function c(e,l){if(l=l||{},(e=e||\"\")instanceof c)return e;if(!(this instanceof c))return new c(e,l);var u=function(e){var i={r:0,g:0,b:0},a=1,l=null,c=null,u=null,h=!1,f=!1;\"string\"==typeof e&&(e=function(t){t=t.replace(r,\"\").replace(n,\"\").toLowerCase();var e,i=!1;if(S[t])t=S[t],i=!0;else if(\"transparent\"==t)return{r:0,g:0,b:0,a:0,format:\"name\"};if(e=j.rgb.exec(t))return{r:e[1],g:e[2],b:e[3]};if(e=j.rgba.exec(t))return{r:e[1],g:e[2],b:e[3],a:e[4]};if(e=j.hsl.exec(t))return{h:e[1],s:e[2],l:e[3]};if(e=j.hsla.exec(t))return{h:e[1],s:e[2],l:e[3],a:e[4]};if(e=j.hsv.exec(t))return{h:e[1],s:e[2],v:e[3]};if(e=j.hsva.exec(t))return{h:e[1],s:e[2],v:e[3],a:e[4]};if(e=j.hex8.exec(t))return{r:O(e[1]),g:O(e[2]),b:O(e[3]),a:R(e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex6.exec(t))return{r:O(e[1]),g:O(e[2]),b:O(e[3]),format:i?\"name\":\"hex\"};if(e=j.hex4.exec(t))return{r:O(e[1]+\"\"+e[1]),g:O(e[2]+\"\"+e[2]),b:O(e[3]+\"\"+e[3]),a:R(e[4]+\"\"+e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex3.exec(t))return{r:O(e[1]+\"\"+e[1]),g:O(e[2]+\"\"+e[2]),b:O(e[3]+\"\"+e[3]),format:i?\"name\":\"hex\"};return!1}(e));\"object\"==typeof e&&(U(e.r)&&U(e.g)&&U(e.b)?(p=e.r,d=e.g,g=e.b,i={r:255*L(p,255),g:255*L(d,255),b:255*L(g,255)},h=!0,f=\"%\"===String(e.r).substr(-1)?\"prgb\":\"rgb\"):U(e.h)&&U(e.s)&&U(e.v)?(l=I(e.s),c=I(e.v),i=function(e,r,n){e=6*L(e,360),r=L(r,100),n=L(n,100);var i=t.floor(e),a=e-i,o=n*(1-r),s=n*(1-a*r),l=n*(1-(1-a)*r),c=i%6;return{r:255*[n,s,o,o,l,n][c],g:255*[l,n,n,s,o,o][c],b:255*[o,o,l,n,n,s][c]}}(e.h,l,c),h=!0,f=\"hsv\"):U(e.h)&&U(e.s)&&U(e.l)&&(l=I(e.s),u=I(e.l),i=function(t,e,r){var n,i,a;function o(t,e,r){return r<0&&(r+=1),r>1&&(r-=1),r<1/6?t+6*(e-t)*r:r<.5?e:r<2/3?t+(e-t)*(2/3-r)*6:t}if(t=L(t,360),e=L(e,100),r=L(r,100),0===e)n=i=a=r;else{var s=r<.5?r*(1+e):r+e-r*e,l=2*r-s;n=o(l,s,t+1/3),i=o(l,s,t),a=o(l,s,t-1/3)}return{r:255*n,g:255*i,b:255*a}}(e.h,l,u),h=!0,f=\"hsl\"),e.hasOwnProperty(\"a\")&&(a=e.a));var p,d,g;return a=C(a),{ok:h,format:e.format||f,r:o(255,s(i.r,0)),g:o(255,s(i.g,0)),b:o(255,s(i.b,0)),a:a}}(e);this._originalInput=e,this._r=u.r,this._g=u.g,this._b=u.b,this._a=u.a,this._roundA=a(100*this._a)/100,this._format=l.format||u.format,this._gradientType=l.gradientType,this._r<1&&(this._r=a(this._r)),this._g<1&&(this._g=a(this._g)),this._b<1&&(this._b=a(this._b)),this._ok=u.ok,this._tc_id=i++}function u(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=(a+l)/2;if(a==l)n=i=0;else{var u=a-l;switch(i=c>.5?u/(2-a-l):u/(a+l),a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,l:c}}function h(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=a,u=a-l;if(i=0===a?0:u/a,a==l)n=0;else{switch(a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,v:c}}function f(t,e,r,n){var i=[z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16))];return n&&i[0].charAt(0)==i[0].charAt(1)&&i[1].charAt(0)==i[1].charAt(1)&&i[2].charAt(0)==i[2].charAt(1)?i[0].charAt(0)+i[1].charAt(0)+i[2].charAt(0):i.join(\"\")}function p(t,e,r,n){return[z(D(n)),z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16))].join(\"\")}function d(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s-=e/100,r.s=P(r.s),c(r)}function g(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s+=e/100,r.s=P(r.s),c(r)}function v(t){return c(t).desaturate(100)}function m(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l+=e/100,r.l=P(r.l),c(r)}function y(t,e){e=0===e?0:e||10;var r=c(t).toRgb();return r.r=s(0,o(255,r.r-a(-e/100*255))),r.g=s(0,o(255,r.g-a(-e/100*255))),r.b=s(0,o(255,r.b-a(-e/100*255))),c(r)}function x(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l-=e/100,r.l=P(r.l),c(r)}function b(t,e){var r=c(t).toHsl(),n=(r.h+e)%360;return r.h=n<0?360+n:n,c(r)}function _(t){var e=c(t).toHsl();return e.h=(e.h+180)%360,c(e)}function w(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+120)%360,s:e.s,l:e.l}),c({h:(r+240)%360,s:e.s,l:e.l})]}function k(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+90)%360,s:e.s,l:e.l}),c({h:(r+180)%360,s:e.s,l:e.l}),c({h:(r+270)%360,s:e.s,l:e.l})]}function T(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+72)%360,s:e.s,l:e.l}),c({h:(r+216)%360,s:e.s,l:e.l})]}function A(t,e,r){e=e||6,r=r||30;var n=c(t).toHsl(),i=360/r,a=[c(t)];for(n.h=(n.h-(i*e>>1)+720)%360;--e;)n.h=(n.h+i)%360,a.push(c(n));return a}function M(t,e){e=e||6;for(var r=c(t).toHsv(),n=r.h,i=r.s,a=r.v,o=[],s=1/e;e--;)o.push(c({h:n,s:i,v:a})),a=(a+s)%1;return o}c.prototype={isDark:function(){return this.getBrightness()<128},isLight:function(){return!this.isDark()},isValid:function(){return this._ok},getOriginalInput:function(){return this._originalInput},getFormat:function(){return this._format},getAlpha:function(){return this._a},getBrightness:function(){var t=this.toRgb();return(299*t.r+587*t.g+114*t.b)/1e3},getLuminance:function(){var e,r,n,i=this.toRgb();return e=i.r/255,r=i.g/255,n=i.b/255,.2126*(e<=.03928?e/12.92:t.pow((e+.055)/1.055,2.4))+.7152*(r<=.03928?r/12.92:t.pow((r+.055)/1.055,2.4))+.0722*(n<=.03928?n/12.92:t.pow((n+.055)/1.055,2.4))},setAlpha:function(t){return this._a=C(t),this._roundA=a(100*this._a)/100,this},toHsv:function(){var t=h(this._r,this._g,this._b);return{h:360*t.h,s:t.s,v:t.v,a:this._a}},toHsvString:function(){var t=h(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.v);return 1==this._a?\"hsv(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsva(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHsl:function(){var t=u(this._r,this._g,this._b);return{h:360*t.h,s:t.s,l:t.l,a:this._a}},toHslString:function(){var t=u(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.l);return 1==this._a?\"hsl(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsla(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHex:function(t){return f(this._r,this._g,this._b,t)},toHexString:function(t){return\"#\"+this.toHex(t)},toHex8:function(t){return function(t,e,r,n,i){var o=[z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16)),z(D(n))];if(i&&o[0].charAt(0)==o[0].charAt(1)&&o[1].charAt(0)==o[1].charAt(1)&&o[2].charAt(0)==o[2].charAt(1)&&o[3].charAt(0)==o[3].charAt(1))return o[0].charAt(0)+o[1].charAt(0)+o[2].charAt(0)+o[3].charAt(0);return o.join(\"\")}(this._r,this._g,this._b,this._a,t)},toHex8String:function(t){return\"#\"+this.toHex8(t)},toRgb:function(){return{r:a(this._r),g:a(this._g),b:a(this._b),a:this._a}},toRgbString:function(){return 1==this._a?\"rgb(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\")\":\"rgba(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\", \"+this._roundA+\")\"},toPercentageRgb:function(){return{r:a(100*L(this._r,255))+\"%\",g:a(100*L(this._g,255))+\"%\",b:a(100*L(this._b,255))+\"%\",a:this._a}},toPercentageRgbString:function(){return 1==this._a?\"rgb(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%)\":\"rgba(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%, \"+this._roundA+\")\"},toName:function(){return 0===this._a?\"transparent\":!(this._a<1)&&(E[f(this._r,this._g,this._b,!0)]||!1)},toFilter:function(t){var e=\"#\"+p(this._r,this._g,this._b,this._a),r=e,n=this._gradientType?\"GradientType = 1, \":\"\";if(t){var i=c(t);r=\"#\"+p(i._r,i._g,i._b,i._a)}return\"progid:DXImageTransform.Microsoft.gradient(\"+n+\"startColorstr=\"+e+\",endColorstr=\"+r+\")\"},toString:function(t){var e=!!t;t=t||this._format;var r=!1,n=this._a<1&&this._a>=0;return e||!n||\"hex\"!==t&&\"hex6\"!==t&&\"hex3\"!==t&&\"hex4\"!==t&&\"hex8\"!==t&&\"name\"!==t?(\"rgb\"===t&&(r=this.toRgbString()),\"prgb\"===t&&(r=this.toPercentageRgbString()),\"hex\"!==t&&\"hex6\"!==t||(r=this.toHexString()),\"hex3\"===t&&(r=this.toHexString(!0)),\"hex4\"===t&&(r=this.toHex8String(!0)),\"hex8\"===t&&(r=this.toHex8String()),\"name\"===t&&(r=this.toName()),\"hsl\"===t&&(r=this.toHslString()),\"hsv\"===t&&(r=this.toHsvString()),r||this.toHexString()):\"name\"===t&&0===this._a?this.toName():this.toRgbString()},clone:function(){return c(this.toString())},_applyModification:function(t,e){var r=t.apply(null,[this].concat([].slice.call(e)));return this._r=r._r,this._g=r._g,this._b=r._b,this.setAlpha(r._a),this},lighten:function(){return this._applyModification(m,arguments)},brighten:function(){return this._applyModification(y,arguments)},darken:function(){return this._applyModification(x,arguments)},desaturate:function(){return this._applyModification(d,arguments)},saturate:function(){return this._applyModification(g,arguments)},greyscale:function(){return this._applyModification(v,arguments)},spin:function(){return this._applyModification(b,arguments)},_applyCombination:function(t,e){return t.apply(null,[this].concat([].slice.call(e)))},analogous:function(){return this._applyCombination(A,arguments)},complement:function(){return this._applyCombination(_,arguments)},monochromatic:function(){return this._applyCombination(M,arguments)},splitcomplement:function(){return this._applyCombination(T,arguments)},triad:function(){return this._applyCombination(w,arguments)},tetrad:function(){return this._applyCombination(k,arguments)}},c.fromRatio=function(t,e){if(\"object\"==typeof t){var r={};for(var n in t)t.hasOwnProperty(n)&&(r[n]=\"a\"===n?t[n]:I(t[n]));t=r}return c(t,e)},c.equals=function(t,e){return!(!t||!e)&&c(t).toRgbString()==c(e).toRgbString()},c.random=function(){return c.fromRatio({r:l(),g:l(),b:l()})},c.mix=function(t,e,r){r=0===r?0:r||50;var n=c(t).toRgb(),i=c(e).toRgb(),a=r/100;return c({r:(i.r-n.r)*a+n.r,g:(i.g-n.g)*a+n.g,b:(i.b-n.b)*a+n.b,a:(i.a-n.a)*a+n.a})},c.readability=function(e,r){var n=c(e),i=c(r);return(t.max(n.getLuminance(),i.getLuminance())+.05)/(t.min(n.getLuminance(),i.getLuminance())+.05)},c.isReadable=function(t,e,r){var n,i,a=c.readability(t,e);switch(i=!1,(n=function(t){var e,r;e=((t=t||{level:\"AA\",size:\"small\"}).level||\"AA\").toUpperCase(),r=(t.size||\"small\").toLowerCase(),\"AA\"!==e&&\"AAA\"!==e&&(e=\"AA\");\"small\"!==r&&\"large\"!==r&&(r=\"small\");return{level:e,size:r}}(r)).level+n.size){case\"AAsmall\":case\"AAAlarge\":i=a>=4.5;break;case\"AAlarge\":i=a>=3;break;case\"AAAsmall\":i=a>=7}return i},c.mostReadable=function(t,e,r){var n,i,a,o,s=null,l=0;i=(r=r||{}).includeFallbackColors,a=r.level,o=r.size;for(var u=0;u<e.length;u++)(n=c.readability(t,e[u]))>l&&(l=n,s=c(e[u]));return c.isReadable(t,s,{level:a,size:o})||!i?s:(r.includeFallbackColors=!1,c.mostReadable(t,[\"#fff\",\"#000\"],r))};var S=c.names={aliceblue:\"f0f8ff\",antiquewhite:\"faebd7\",aqua:\"0ff\",aquamarine:\"7fffd4\",azure:\"f0ffff\",beige:\"f5f5dc\",bisque:\"ffe4c4\",black:\"000\",blanchedalmond:\"ffebcd\",blue:\"00f\",blueviolet:\"8a2be2\",brown:\"a52a2a\",burlywood:\"deb887\",burntsienna:\"ea7e5d\",cadetblue:\"5f9ea0\",chartreuse:\"7fff00\",chocolate:\"d2691e\",coral:\"ff7f50\",cornflowerblue:\"6495ed\",cornsilk:\"fff8dc\",crimson:\"dc143c\",cyan:\"0ff\",darkblue:\"00008b\",darkcyan:\"008b8b\",darkgoldenrod:\"b8860b\",darkgray:\"a9a9a9\",darkgreen:\"006400\",darkgrey:\"a9a9a9\",darkkhaki:\"bdb76b\",darkmagenta:\"8b008b\",darkolivegreen:\"556b2f\",darkorange:\"ff8c00\",darkorchid:\"9932cc\",darkred:\"8b0000\",darksalmon:\"e9967a\",darkseagreen:\"8fbc8f\",darkslateblue:\"483d8b\",darkslategray:\"2f4f4f\",darkslategrey:\"2f4f4f\",darkturquoise:\"00ced1\",darkviolet:\"9400d3\",deeppink:\"ff1493\",deepskyblue:\"00bfff\",dimgray:\"696969\",dimgrey:\"696969\",dodgerblue:\"1e90ff\",firebrick:\"b22222\",floralwhite:\"fffaf0\",forestgreen:\"228b22\",fuchsia:\"f0f\",gainsboro:\"dcdcdc\",ghostwhite:\"f8f8ff\",gold:\"ffd700\",goldenrod:\"daa520\",gray:\"808080\",green:\"008000\",greenyellow:\"adff2f\",grey:\"808080\",honeydew:\"f0fff0\",hotpink:\"ff69b4\",indianred:\"cd5c5c\",indigo:\"4b0082\",ivory:\"fffff0\",khaki:\"f0e68c\",lavender:\"e6e6fa\",lavenderblush:\"fff0f5\",lawngreen:\"7cfc00\",lemonchiffon:\"fffacd\",lightblue:\"add8e6\",lightcoral:\"f08080\",lightcyan:\"e0ffff\",lightgoldenrodyellow:\"fafad2\",lightgray:\"d3d3d3\",lightgreen:\"90ee90\",lightgrey:\"d3d3d3\",lightpink:\"ffb6c1\",lightsalmon:\"ffa07a\",lightseagreen:\"20b2aa\",lightskyblue:\"87cefa\",lightslategray:\"789\",lightslategrey:\"789\",lightsteelblue:\"b0c4de\",lightyellow:\"ffffe0\",lime:\"0f0\",limegreen:\"32cd32\",linen:\"faf0e6\",magenta:\"f0f\",maroon:\"800000\",mediumaquamarine:\"66cdaa\",mediumblue:\"0000cd\",mediumorchid:\"ba55d3\",mediumpurple:\"9370db\",mediumseagreen:\"3cb371\",mediumslateblue:\"7b68ee\",mediumspringgreen:\"00fa9a\",mediumturquoise:\"48d1cc\",mediumvioletred:\"c71585\",midnightblue:\"191970\",mintcream:\"f5fffa\",mistyrose:\"ffe4e1\",moccasin:\"ffe4b5\",navajowhite:\"ffdead\",navy:\"000080\",oldlace:\"fdf5e6\",olive:\"808000\",olivedrab:\"6b8e23\",orange:\"ffa500\",orangered:\"ff4500\",orchid:\"da70d6\",palegoldenrod:\"eee8aa\",palegreen:\"98fb98\",paleturquoise:\"afeeee\",palevioletred:\"db7093\",papayawhip:\"ffefd5\",peachpuff:\"ffdab9\",peru:\"cd853f\",pink:\"ffc0cb\",plum:\"dda0dd\",powderblue:\"b0e0e6\",purple:\"800080\",rebeccapurple:\"663399\",red:\"f00\",rosybrown:\"bc8f8f\",royalblue:\"4169e1\",saddlebrown:\"8b4513\",salmon:\"fa8072\",sandybrown:\"f4a460\",seagreen:\"2e8b57\",seashell:\"fff5ee\",sienna:\"a0522d\",silver:\"c0c0c0\",skyblue:\"87ceeb\",slateblue:\"6a5acd\",slategray:\"708090\",slategrey:\"708090\",snow:\"fffafa\",springgreen:\"00ff7f\",steelblue:\"4682b4\",tan:\"d2b48c\",teal:\"008080\",thistle:\"d8bfd8\",tomato:\"ff6347\",turquoise:\"40e0d0\",violet:\"ee82ee\",wheat:\"f5deb3\",white:\"fff\",whitesmoke:\"f5f5f5\",yellow:\"ff0\",yellowgreen:\"9acd32\"},E=c.hexNames=function(t){var e={};for(var r in t)t.hasOwnProperty(r)&&(e[t[r]]=r);return e}(S);function C(t){return t=parseFloat(t),(isNaN(t)||t<0||t>1)&&(t=1),t}function L(e,r){(function(t){return\"string\"==typeof t&&-1!=t.indexOf(\".\")&&1===parseFloat(t)})(e)&&(e=\"100%\");var n=function(t){return\"string\"==typeof t&&-1!=t.indexOf(\"%\")}(e);return e=o(r,s(0,parseFloat(e))),n&&(e=parseInt(e*r,10)/100),t.abs(e-r)<1e-6?1:e%r/parseFloat(r)}function P(t){return o(1,s(0,t))}function O(t){return parseInt(t,16)}function z(t){return 1==t.length?\"0\"+t:\"\"+t}function I(t){return t<=1&&(t=100*t+\"%\"),t}function D(e){return t.round(255*parseFloat(e)).toString(16)}function R(t){return O(t)/255}var F,B,N,j=(B=\"[\\\\s|\\\\(]+(\"+(F=\"(?:[-\\\\+]?\\\\d*\\\\.\\\\d+%?)|(?:[-\\\\+]?\\\\d+%?)\")+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",N=\"[\\\\s|\\\\(]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",{CSS_UNIT:new RegExp(F),rgb:new RegExp(\"rgb\"+B),rgba:new RegExp(\"rgba\"+N),hsl:new RegExp(\"hsl\"+B),hsla:new RegExp(\"hsla\"+N),hsv:new RegExp(\"hsv\"+B),hsva:new RegExp(\"hsva\"+N),hex3:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex6:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/,hex4:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex8:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/});function U(t){return!!j.CSS_UNIT.exec(t)}\"undefined\"!=typeof e&&e.exports?e.exports=c:window.tinycolor=c}(Math)},{}],538:[function(t,e,r){\"use strict\";e.exports=i,e.exports.float32=e.exports.float=i,e.exports.fract32=e.exports.fract=function(t){if(t.length){for(var e=i(t),r=0,n=e.length;r<n;r++)e[r]=t[r]-e[r];return e}return i(t-i(t))};var n=new Float32Array(1);function i(t){if(t.length){if(t instanceof Float32Array)return t;var e=new Float32Array(t);return e.set(t),e}return n[0]=t,n[0]}},{}],539:[function(t,e,r){\"use strict\";var n=t(\"parse-unit\");e.exports=o;var i=96;function a(t,e){var r=n(getComputedStyle(t).getPropertyValue(e));return r[0]*o(r[1],t)}function o(t,e){switch(e=e||document.body,t=(t||\"px\").trim().toLowerCase(),e!==window&&e!==document||(e=document.body),t){case\"%\":return e.clientHeight/100;case\"ch\":case\"ex\":return function(t,e){var r=document.createElement(\"div\");r.style[\"font-size\"]=\"128\"+t,e.appendChild(r);var n=a(r,\"font-size\")/128;return e.removeChild(r),n}(t,e);case\"em\":return a(e,\"font-size\");case\"rem\":return a(document.body,\"font-size\");case\"vw\":return window.innerWidth/100;case\"vh\":return window.innerHeight/100;case\"vmin\":return Math.min(window.innerWidth,window.innerHeight)/100;case\"vmax\":return Math.max(window.innerWidth,window.innerHeight)/100;case\"in\":return i;case\"cm\":return i/2.54;case\"mm\":return i/25.4;case\"pt\":return i/72;case\"pc\":return i/6}return 1}},{\"parse-unit\":461}],540:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e=function(t){return t},r=function(t){if(null==(r=t.transform))return e;var r,n,i,a=r.scale[0],o=r.scale[1],s=r.translate[0],l=r.translate[1];return function(t,e){return e||(n=i=0),t[0]=(n+=t[0])*a+s,t[1]=(i+=t[1])*o+l,t}},n=function(t){var e=t.bbox;function n(t){l[0]=t[0],l[1]=t[1],s(l),l[0]<c&&(c=l[0]),l[0]>h&&(h=l[0]),l[1]<u&&(u=l[1]),l[1]>f&&(f=l[1])}function i(t){switch(t.type){case\"GeometryCollection\":t.geometries.forEach(i);break;case\"Point\":n(t.coordinates);break;case\"MultiPoint\":t.coordinates.forEach(n)}}if(!e){var a,o,s=r(t),l=new Array(2),c=1/0,u=c,h=-c,f=-c;for(o in t.arcs.forEach(function(t){for(var e=-1,r=t.length;++e<r;)a=t[e],l[0]=a[0],l[1]=a[1],s(l,e),l[0]<c&&(c=l[0]),l[0]>h&&(h=l[0]),l[1]<u&&(u=l[1]),l[1]>f&&(f=l[1])}),t.objects)i(t.objects[o]);e=t.bbox=[c,u,h,f]}return e},i=function(t,e){for(var r,n=t.length,i=n-e;i<--n;)r=t[i],t[i++]=t[n],t[n]=r};function a(t,e){var r=e.id,n=e.bbox,i=null==e.properties?{}:e.properties,a=o(t,e);return null==r&&null==n?{type:\"Feature\",properties:i,geometry:a}:null==n?{type:\"Feature\",id:r,properties:i,geometry:a}:{type:\"Feature\",id:r,bbox:n,properties:i,geometry:a}}function o(t,e){var n=r(t),a=t.arcs;function o(t,e){e.length&&e.pop();for(var r=a[t<0?~t:t],o=0,s=r.length;o<s;++o)e.push(n(r[o].slice(),o));t<0&&i(e,s)}function s(t){return n(t.slice())}function l(t){for(var e=[],r=0,n=t.length;r<n;++r)o(t[r],e);return e.length<2&&e.push(e[0].slice()),e}function c(t){for(var e=l(t);e.length<4;)e.push(e[0].slice());return e}function u(t){return t.map(c)}return function t(e){var r,n=e.type;switch(n){case\"GeometryCollection\":return{type:n,geometries:e.geometries.map(t)};case\"Point\":r=s(e.coordinates);break;case\"MultiPoint\":r=e.coordinates.map(s);break;case\"LineString\":r=l(e.arcs);break;case\"MultiLineString\":r=e.arcs.map(l);break;case\"Polygon\":r=u(e.arcs);break;case\"MultiPolygon\":r=e.arcs.map(u);break;default:return null}return{type:n,coordinates:r}}(e)}var s=function(t,e){var r={},n={},i={},a=[],o=-1;function s(t,e){for(var n in t){var i=t[n];delete e[i.start],delete i.start,delete i.end,i.forEach(function(t){r[t<0?~t:t]=1}),a.push(i)}}return e.forEach(function(r,n){var i,a=t.arcs[r<0?~r:r];a.length<3&&!a[1][0]&&!a[1][1]&&(i=e[++o],e[o]=r,e[n]=i)}),e.forEach(function(e){var r,a,o=function(e){var r,n=t.arcs[e<0?~e:e],i=n[0];t.transform?(r=[0,0],n.forEach(function(t){r[0]+=t[0],r[1]+=t[1]})):r=n[n.length-1];return e<0?[r,i]:[i,r]}(e),s=o[0],l=o[1];if(r=i[s])if(delete i[r.end],r.push(e),r.end=l,a=n[l]){delete n[a.start];var c=a===r?r:r.concat(a);n[c.start=r.start]=i[c.end=a.end]=c}else n[r.start]=i[r.end]=r;else if(r=n[l])if(delete n[r.start],r.unshift(e),r.start=s,a=i[s]){delete i[a.end];var u=a===r?r:a.concat(r);n[u.start=a.start]=i[u.end=r.end]=u}else n[r.start]=i[r.end]=r;else n[(r=[e]).start=s]=i[r.end=l]=r}),s(i,n),s(n,i),e.forEach(function(t){r[t<0?~t:t]||a.push([t])}),a};function l(t,e,r){var n,i,a;if(arguments.length>1)n=function(t,e,r){var n,i=[],a=[];function o(t){var e=t<0?~t:t;(a[e]||(a[e]=[])).push({i:t,g:n})}function s(t){t.forEach(o)}function l(t){t.forEach(s)}return function t(e){switch(n=e,e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"LineString\":s(e.arcs);break;case\"MultiLineString\":case\"Polygon\":l(e.arcs);break;case\"MultiPolygon\":e.arcs.forEach(l)}}(e),a.forEach(null==r?function(t){i.push(t[0].i)}:function(t){r(t[0].g,t[t.length-1].g)&&i.push(t[0].i)}),i}(0,e,r);else for(i=0,n=new Array(a=t.arcs.length);i<a;++i)n[i]=i;return{type:\"MultiLineString\",arcs:s(t,n)}}function c(t,e){var r={},n=[],i=[];function a(t){t.forEach(function(e){e.forEach(function(e){(r[e=e<0?~e:e]||(r[e]=[])).push(t)})}),n.push(t)}function l(e){return function(t){for(var e,r=-1,n=t.length,i=t[n-1],a=0;++r<n;)e=i,i=t[r],a+=e[0]*i[1]-e[1]*i[0];return Math.abs(a)}(o(t,{type:\"Polygon\",arcs:[e]}).coordinates[0])}return e.forEach(function t(e){switch(e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"Polygon\":a(e.arcs);break;case\"MultiPolygon\":e.arcs.forEach(a)}}),n.forEach(function(t){if(!t._){var e=[],n=[t];for(t._=1,i.push(e);t=n.pop();)e.push(t),t.forEach(function(t){t.forEach(function(t){r[t<0?~t:t].forEach(function(t){t._||(t._=1,n.push(t))})})})}}),n.forEach(function(t){delete t._}),{type:\"MultiPolygon\",arcs:i.map(function(e){var n,i=[];if(e.forEach(function(t){t.forEach(function(t){t.forEach(function(t){r[t<0?~t:t].length<2&&i.push(t)})})}),(n=(i=s(t,i)).length)>1)for(var a,o,c=1,u=l(i[0]);c<n;++c)(a=l(i[c]))>u&&(o=i[0],i[0]=i[c],i[c]=o,u=a);return i})}}var u=function(t,e){for(var r=0,n=t.length;r<n;){var i=r+n>>>1;t[i]<e?r=i+1:n=i}return r};t.bbox=n,t.feature=function(t,e){return\"GeometryCollection\"===e.type?{type:\"FeatureCollection\",features:e.geometries.map(function(e){return a(t,e)})}:a(t,e)},t.mesh=function(t){return o(t,l.apply(this,arguments))},t.meshArcs=l,t.merge=function(t){return o(t,c.apply(this,arguments))},t.mergeArcs=c,t.neighbors=function(t){var e={},r=t.map(function(){return[]});function n(t,r){t.forEach(function(t){t<0&&(t=~t);var n=e[t];n?n.push(r):e[t]=[r]})}function i(t,e){t.forEach(function(t){n(t,e)})}var a={LineString:n,MultiLineString:i,Polygon:i,MultiPolygon:function(t,e){t.forEach(function(t){i(t,e)})}};for(var o in t.forEach(function t(e,r){\"GeometryCollection\"===e.type?e.geometries.forEach(function(e){t(e,r)}):e.type in a&&a[e.type](e.arcs,r)}),e)for(var s=e[o],l=s.length,c=0;c<l;++c)for(var h=c+1;h<l;++h){var f,p=s[c],d=s[h];(f=r[p])[o=u(f,d)]!==d&&f.splice(o,0,d),(f=r[d])[o=u(f,p)]!==p&&f.splice(o,0,p)}return r},t.quantize=function(t,e){if(!((e=Math.floor(e))>=2))throw new Error(\"n must be \\u22652\");if(t.transform)throw new Error(\"already quantized\");var r,i=n(t),a=i[0],o=(i[2]-a)/(e-1)||1,s=i[1],l=(i[3]-s)/(e-1)||1;function c(t){t[0]=Math.round((t[0]-a)/o),t[1]=Math.round((t[1]-s)/l)}function u(t){switch(t.type){case\"GeometryCollection\":t.geometries.forEach(u);break;case\"Point\":c(t.coordinates);break;case\"MultiPoint\":t.coordinates.forEach(c)}}for(r in t.arcs.forEach(function(t){for(var e,r,n,i=1,c=1,u=t.length,h=t[0],f=h[0]=Math.round((h[0]-a)/o),p=h[1]=Math.round((h[1]-s)/l);i<u;++i)h=t[i],r=Math.round((h[0]-a)/o),n=Math.round((h[1]-s)/l),r===f&&n===p||((e=t[c++])[0]=r-f,f=r,e[1]=n-p,p=n);c<2&&((e=t[c++])[0]=0,e[1]=0),t.length=c}),t.objects)u(t.objects[r]);return t.transform={scale:[o,l],translate:[a,s]},t},t.transform=r,t.untransform=function(t){if(null==(r=t.transform))return e;var r,n,i,a=r.scale[0],o=r.scale[1],s=r.translate[0],l=r.translate[1];return function(t,e){e||(n=i=0);var r=Math.round((t[0]-s)/a),c=Math.round((t[1]-l)/o);return t[0]=r-n,n=r,t[1]=c-i,i=c,t}},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.topojson=n.topojson||{})},{}],541:[function(t,e,r){\"use strict\";e.exports=function(t){if(t<0)return[];if(0===t)return[[0]];for(var e=0|Math.round(a(t+1)),r=[],o=0;o<e;++o){for(var s=n.unrank(t,o),l=[0],c=0,u=0;u<s.length;++u)c+=1<<s[u],l.push(c);i(s)<1&&(l[0]=c,l[t]=0),r.push(l)}return r};var n=t(\"permutation-rank\"),i=t(\"permutation-parity\"),a=t(\"gamma\")},{gamma:231,\"permutation-parity\":463,\"permutation-rank\":464}],542:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.up||[0,1,0],n=t.right||h(r),i=t.radius||1,a=t.theta||0,u=t.phi||0;if(e=[].slice.call(e,0,3),r=[].slice.call(r,0,3),s(r,r),n=[].slice.call(n,0,3),s(n,n),\"eye\"in t){var p=t.eye,d=[p[0]-e[0],p[1]-e[1],p[2]-e[2]];o(n,d,r),c(n[0],n[1],n[2])<1e-6?n=h(r):s(n,n),i=c(d[0],d[1],d[2]);var g=l(r,d)/i,v=l(n,d)/i;u=Math.acos(g),a=Math.acos(v)}return i=Math.log(i),new f(t.zoomMin,t.zoomMax,e,r,n,i,a,u)};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/invert\"),a=t(\"gl-mat4/rotate\"),o=t(\"gl-vec3/cross\"),s=t(\"gl-vec3/normalize\"),l=t(\"gl-vec3/dot\");function c(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function u(t){return Math.min(1,Math.max(-1,t))}function h(t){var e=Math.abs(t[0]),r=Math.abs(t[1]),n=Math.abs(t[2]),i=[0,0,0];e>Math.max(r,n)?i[2]=1:r>Math.max(e,n)?i[0]=1:i[1]=1;for(var a=0,o=0,l=0;l<3;++l)a+=t[l]*t[l],o+=i[l]*t[l];for(l=0;l<3;++l)i[l]-=o/a*t[l];return s(i,i),i}function f(t,e,r,i,a,o,s,l){this.center=n(r),this.up=n(i),this.right=n(a),this.radius=n([o]),this.angle=n([s,l]),this.angle.bounds=[[-1/0,-Math.PI/2],[1/0,Math.PI/2]],this.setDistanceLimits(t,e),this.computedCenter=this.center.curve(0),this.computedUp=this.up.curve(0),this.computedRight=this.right.curve(0),this.computedRadius=this.radius.curve(0),this.computedAngle=this.angle.curve(0),this.computedToward=[0,0,0],this.computedEye=[0,0,0],this.computedMatrix=new Array(16);for(var c=0;c<16;++c)this.computedMatrix[c]=.5;this.recalcMatrix(0)}var p=f.prototype;p.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},p.getDistanceLimits=function(t){var e=this.radius.bounds[0];return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},p.recalcMatrix=function(t){this.center.curve(t),this.up.curve(t),this.right.curve(t),this.radius.curve(t),this.angle.curve(t);for(var e=this.computedUp,r=this.computedRight,n=0,i=0,a=0;a<3;++a)i+=e[a]*r[a],n+=e[a]*e[a];var l=Math.sqrt(n),u=0;for(a=0;a<3;++a)r[a]-=e[a]*i/n,u+=r[a]*r[a],e[a]/=l;var h=Math.sqrt(u);for(a=0;a<3;++a)r[a]/=h;var f=this.computedToward;o(f,e,r),s(f,f);var p=Math.exp(this.computedRadius[0]),d=this.computedAngle[0],g=this.computedAngle[1],v=Math.cos(d),m=Math.sin(d),y=Math.cos(g),x=Math.sin(g),b=this.computedCenter,_=v*y,w=m*y,k=x,T=-v*x,A=-m*x,M=y,S=this.computedEye,E=this.computedMatrix;for(a=0;a<3;++a){var C=_*r[a]+w*f[a]+k*e[a];E[4*a+1]=T*r[a]+A*f[a]+M*e[a],E[4*a+2]=C,E[4*a+3]=0}var L=E[1],P=E[5],O=E[9],z=E[2],I=E[6],D=E[10],R=P*D-O*I,F=O*z-L*D,B=L*I-P*z,N=c(R,F,B);R/=N,F/=N,B/=N,E[0]=R,E[4]=F,E[8]=B;for(a=0;a<3;++a)S[a]=b[a]+E[2+4*a]*p;for(a=0;a<3;++a){u=0;for(var j=0;j<3;++j)u+=E[a+4*j]*S[j];E[12+a]=-u}E[15]=1},p.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r};var d=[0,0,0];p.rotate=function(t,e,r,n){if(this.angle.move(t,e,r),n){this.recalcMatrix(t);var i=this.computedMatrix;d[0]=i[2],d[1]=i[6],d[2]=i[10];for(var o=this.computedUp,s=this.computedRight,l=this.computedToward,c=0;c<3;++c)i[4*c]=o[c],i[4*c+1]=s[c],i[4*c+2]=l[c];a(i,i,n,d);for(c=0;c<3;++c)o[c]=i[4*c],s[c]=i[4*c+1];this.up.set(t,o[0],o[1],o[2]),this.right.set(t,s[0],s[1],s[2])}},p.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=(Math.exp(this.computedRadius[0]),i[1]),o=i[5],s=i[9],l=c(a,o,s);a/=l,o/=l,s/=l;var u=i[0],h=i[4],f=i[8],p=u*a+h*o+f*s,d=c(u-=a*p,h-=o*p,f-=s*p),g=(u/=d)*e+a*r,v=(h/=d)*e+o*r,m=(f/=d)*e+s*r;this.center.move(t,g,v,m);var y=Math.exp(this.computedRadius[0]);y=Math.max(1e-4,y+n),this.radius.set(t,Math.log(y))},p.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},p.setMatrix=function(t,e,r,n){var a=1;\"number\"==typeof r&&(a=0|r),(a<0||a>3)&&(a=1);var o=(a+2)%3;e||(this.recalcMatrix(t),e=this.computedMatrix);var s=e[a],l=e[a+4],h=e[a+8];if(n){var f=Math.abs(s),p=Math.abs(l),d=Math.abs(h),g=Math.max(f,p,d);f===g?(s=s<0?-1:1,l=h=0):d===g?(h=h<0?-1:1,s=l=0):(l=l<0?-1:1,s=h=0)}else{var v=c(s,l,h);s/=v,l/=v,h/=v}var m,y,x=e[o],b=e[o+4],_=e[o+8],w=x*s+b*l+_*h,k=c(x-=s*w,b-=l*w,_-=h*w),T=l*(_/=k)-h*(b/=k),A=h*(x/=k)-s*_,M=s*b-l*x,S=c(T,A,M);if(T/=S,A/=S,M/=S,this.center.jump(t,H,G,Y),this.radius.idle(t),this.up.jump(t,s,l,h),this.right.jump(t,x,b,_),2===a){var E=e[1],C=e[5],L=e[9],P=E*x+C*b+L*_,O=E*T+C*A+L*M;m=R<0?-Math.PI/2:Math.PI/2,y=Math.atan2(O,P)}else{var z=e[2],I=e[6],D=e[10],R=z*s+I*l+D*h,F=z*x+I*b+D*_,B=z*T+I*A+D*M;m=Math.asin(u(R)),y=Math.atan2(B,F)}this.angle.jump(t,y,m),this.recalcMatrix(t);var N=e[2],j=e[6],U=e[10],V=this.computedMatrix;i(V,e);var q=V[15],H=V[12]/q,G=V[13]/q,Y=V[14]/q,W=Math.exp(this.computedRadius[0]);this.center.jump(t,H-N*W,G-j*W,Y-U*W)},p.lastT=function(){return Math.max(this.center.lastT(),this.up.lastT(),this.right.lastT(),this.radius.lastT(),this.angle.lastT())},p.idle=function(t){this.center.idle(t),this.up.idle(t),this.right.idle(t),this.radius.idle(t),this.angle.idle(t)},p.flush=function(t){this.center.flush(t),this.up.flush(t),this.right.flush(t),this.radius.flush(t),this.angle.flush(t)},p.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},p.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||this.computedCenter;var i=(n=n||this.computedUp)[0],a=n[1],o=n[2],s=c(i,a,o);if(!(s<1e-6)){i/=s,a/=s,o/=s;var l=e[0]-r[0],h=e[1]-r[1],f=e[2]-r[2],p=c(l,h,f);if(!(p<1e-6)){l/=p,h/=p,f/=p;var d=this.computedRight,g=d[0],v=d[1],m=d[2],y=i*g+a*v+o*m,x=c(g-=y*i,v-=y*a,m-=y*o);if(!(x<.01&&(x=c(g=a*f-o*h,v=o*l-i*f,m=i*h-a*l))<1e-6)){g/=x,v/=x,m/=x,this.up.set(t,i,a,o),this.right.set(t,g,v,m),this.center.set(t,r[0],r[1],r[2]),this.radius.set(t,Math.log(p));var b=a*m-o*v,_=o*g-i*m,w=i*v-a*g,k=c(b,_,w),T=i*l+a*h+o*f,A=g*l+v*h+m*f,M=(b/=k)*l+(_/=k)*h+(w/=k)*f,S=Math.asin(u(T)),E=Math.atan2(M,A),C=this.angle._state,L=C[C.length-1],P=C[C.length-2];L%=2*Math.PI;var O=Math.abs(L+2*Math.PI-E),z=Math.abs(L-E),I=Math.abs(L-2*Math.PI-E);O<z&&(L+=2*Math.PI),I<z&&(L-=2*Math.PI),this.angle.jump(this.angle.lastT(),L,P),this.angle.set(t,E,S)}}}}},{\"filtered-vector\":226,\"gl-mat4/invert\":265,\"gl-mat4/rotate\":270,\"gl-vec3/cross\":334,\"gl-vec3/dot\":339,\"gl-vec3/normalize\":356}],543:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var i=t*e,a=n*t,o=a-(a-t),s=t-o,l=n*e,c=l-(l-e),u=e-c,h=s*u-(i-o*c-s*c-o*u);if(r)return r[0]=h,r[1]=i,r;return[h,i]};var n=+(Math.pow(2,27)+1)},{}],544:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=t+e,i=n-t,a=e-i,o=t-(n-i);if(r)return r[0]=o+a,r[1]=n,r;return[o+a,n]}},{}],545:[function(t,e,r){(function(e,n){\"use strict\";var i=t(\"bit-twiddle\"),a=t(\"dup\");e.__TYPEDARRAY_POOL||(e.__TYPEDARRAY_POOL={UINT8:a([32,0]),UINT16:a([32,0]),UINT32:a([32,0]),INT8:a([32,0]),INT16:a([32,0]),INT32:a([32,0]),FLOAT:a([32,0]),DOUBLE:a([32,0]),DATA:a([32,0]),UINT8C:a([32,0]),BUFFER:a([32,0])});var o=\"undefined\"!=typeof Uint8ClampedArray,s=e.__TYPEDARRAY_POOL;s.UINT8C||(s.UINT8C=a([32,0])),s.BUFFER||(s.BUFFER=a([32,0]));var l=s.DATA,c=s.BUFFER;function u(t){if(t){var e=t.length||t.byteLength,r=i.log2(e);l[r].push(t)}}function h(t){t=i.nextPow2(t);var e=i.log2(t),r=l[e];return r.length>0?r.pop():new ArrayBuffer(t)}function f(t){return new Uint8Array(h(t),0,t)}function p(t){return new Uint16Array(h(2*t),0,t)}function d(t){return new Uint32Array(h(4*t),0,t)}function g(t){return new Int8Array(h(t),0,t)}function v(t){return new Int16Array(h(2*t),0,t)}function m(t){return new Int32Array(h(4*t),0,t)}function y(t){return new Float32Array(h(4*t),0,t)}function x(t){return new Float64Array(h(8*t),0,t)}function b(t){return o?new Uint8ClampedArray(h(t),0,t):f(t)}function _(t){return new DataView(h(t),0,t)}function w(t){t=i.nextPow2(t);var e=i.log2(t),r=c[e];return r.length>0?r.pop():new n(t)}r.free=function(t){if(n.isBuffer(t))c[i.log2(t.length)].push(t);else{if(\"[object ArrayBuffer]\"!==Object.prototype.toString.call(t)&&(t=t.buffer),!t)return;var e=t.length||t.byteLength,r=0|i.log2(e);l[r].push(t)}},r.freeUint8=r.freeUint16=r.freeUint32=r.freeInt8=r.freeInt16=r.freeInt32=r.freeFloat32=r.freeFloat=r.freeFloat64=r.freeDouble=r.freeUint8Clamped=r.freeDataView=function(t){u(t.buffer)},r.freeArrayBuffer=u,r.freeBuffer=function(t){c[i.log2(t.length)].push(t)},r.malloc=function(t,e){if(void 0===e||\"arraybuffer\"===e)return h(t);switch(e){case\"uint8\":return f(t);case\"uint16\":return p(t);case\"uint32\":return d(t);case\"int8\":return g(t);case\"int16\":return v(t);case\"int32\":return m(t);case\"float\":case\"float32\":return y(t);case\"double\":case\"float64\":return x(t);case\"uint8_clamped\":return b(t);case\"buffer\":return w(t);case\"data\":case\"dataview\":return _(t);default:return null}return null},r.mallocArrayBuffer=h,r.mallocUint8=f,r.mallocUint16=p,r.mallocUint32=d,r.mallocInt8=g,r.mallocInt16=v,r.mallocInt32=m,r.mallocFloat32=r.mallocFloat=y,r.mallocFloat64=r.mallocDouble=x,r.mallocUint8Clamped=b,r.mallocDataView=_,r.mallocBuffer=w,r.clearCache=function(){for(var t=0;t<32;++t)s.UINT8[t].length=0,s.UINT16[t].length=0,s.UINT32[t].length=0,s.INT8[t].length=0,s.INT16[t].length=0,s.INT32[t].length=0,s.FLOAT[t].length=0,s.DOUBLE[t].length=0,s.UINT8C[t].length=0,l[t].length=0,c[t].length=0}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{},t(\"buffer\").Buffer)},{\"bit-twiddle\":92,buffer:105,dup:170}],546:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n;var i=n.prototype;Object.defineProperty(i,\"length\",{get:function(){return this.roots.length}}),i.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},i.find=function(t){for(var e=t,r=this.roots;r[t]!==t;)t=r[t];for(;r[e]!==t;){var n=r[e];r[e]=t,e=n}return t},i.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],547:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return 0===t.length?t:e?(r||t.sort(e),function(t,e){for(var r=1,n=t.length,i=t[0],a=t[0],o=1;o<n;++o)if(a=i,e(i=t[o],a)){if(o===r){r++;continue}t[r++]=i}return t.length=r,t}(t,e)):(r||t.sort(),function(t){for(var e=1,r=t.length,n=t[0],i=t[0],a=1;a<r;++a,i=n)if(i=n,(n=t[a])!==i){if(a===e){e++;continue}t[e++]=n}return t.length=e,t}(t))}},{}],548:[function(t,e,r){var n=/[\\'\\\"]/;e.exports=function(t){return t?(n.test(t.charAt(0))&&(t=t.substr(1)),n.test(t.charAt(t.length-1))&&(t=t.substr(0,t.length-1)),t):\"\"}},{}],549:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){Array.isArray(r)||(r=[].slice.call(arguments,2));for(var n=0,i=r.length;n<i;n++){var a=r[n];for(var o in a)if((void 0===e[o]||Array.isArray(e[o])||t[o]!==e[o])&&o in e){var s;if(!0===a[o])s=e[o];else{if(!1===a[o])continue;if(\"function\"==typeof a[o]&&void 0===(s=a[o](e[o],t,e)))continue}t[o]=s}}return t}},{}],550:[function(t,e,r){\"use strict\";e.exports=function(t,e){\"object\"==typeof e&&null!==e||(e={});return n(t,e.canvas||i,e.context||a,e)};var n=t(\"./lib/vtext\"),i=null,a=null;\"undefined\"!=typeof document&&((i=document.createElement(\"canvas\")).width=8192,i.height=1024,a=i.getContext(\"2d\"))},{\"./lib/vtext\":551}],551:[function(t,e,r){e.exports=function(t,e,r,n){var a=64,o=1.25,s={breaklines:!1,bolds:!1,italics:!1,subscripts:!1,superscripts:!1};n&&(n.size&&n.size>0&&(a=n.size),n.lineSpacing&&n.lineSpacing>0&&(o=n.lineSpacing),n.styletags&&n.styletags.breaklines&&(s.breaklines=!!n.styletags.breaklines),n.styletags&&n.styletags.bolds&&(s.bolds=!!n.styletags.bolds),n.styletags&&n.styletags.italics&&(s.italics=!!n.styletags.italics),n.styletags&&n.styletags.subscripts&&(s.subscripts=!!n.styletags.subscripts),n.styletags&&n.styletags.superscripts&&(s.superscripts=!!n.styletags.superscripts));return r.font=[n.fontStyle,n.fontVariant,n.fontWeight,a+\"px\",n.font].filter(function(t){return t}).join(\" \"),r.textAlign=\"start\",r.textBaseline=\"alphabetic\",r.direction=\"ltr\",w(function(t,e,r,n,a,o){r=r.replace(/\\n/g,\"\"),r=!0===o.breaklines?r.replace(/\\<br\\>/g,\"\\n\"):r.replace(/\\<br\\>/g,\" \");var s=\"\",l=[];for(k=0;k<r.length;++k)l[k]=s;!0===o.bolds&&(l=x(c,u,r,l)),!0===o.italics&&(l=x(h,f,r,l)),!0===o.superscripts&&(l=x(p,g,r,l)),!0===o.subscripts&&(l=x(v,y,r,l));var b=[],_=\"\";for(k=0;k<r.length;++k)null!==l[k]&&(_+=r[k],b.push(l[k]));var w,k,T,A,M,S=_.split(\"\\n\"),E=S.length,C=Math.round(a*n),L=n,P=2*n,O=0,z=E*C+P;t.height<z&&(t.height=z),e.fillStyle=\"#000\",e.fillRect(0,0,t.width,t.height),e.fillStyle=\"#fff\";var I=0,D=\"\";function R(){if(\"\"!==D){var t=e.measureText(D).width;e.fillText(D,L+T,P+A),T+=t}}function F(){return Math.round(M)+\"px \"}function B(t,r){var n=\"\"+e.font;if(!0===o.subscripts){var i=t.indexOf(m),a=r.indexOf(m),s=i>-1?parseInt(t[1+i]):0,l=a>-1?parseInt(r[1+a]):0;s!==l&&(n=n.replace(F(),\"?px \"),M*=Math.pow(.75,l-s),n=n.replace(\"?px \",F())),A+=.25*C*(l-s)}if(!0===o.superscripts){var c=t.indexOf(d),h=r.indexOf(d),p=c>-1?parseInt(t[1+c]):0,g=h>-1?parseInt(r[1+h]):0;p!==g&&(n=n.replace(F(),\"?px \"),M*=Math.pow(.75,g-p),n=n.replace(\"?px \",F())),A-=.25*C*(g-p)}if(!0===o.bolds){var v=t.indexOf(u)>-1,y=r.indexOf(u)>-1;!v&&y&&(n=x?n.replace(\"italic \",\"italic bold \"):\"bold \"+n),v&&!y&&(n=n.replace(\"bold \",\"\"))}if(!0===o.italics){var x=t.indexOf(f)>-1,b=r.indexOf(f)>-1;!x&&b&&(n=\"italic \"+n),x&&!b&&(n=n.replace(\"italic \",\"\"))}e.font=n}for(w=0;w<E;++w){var N=S[w]+\"\\n\";for(T=0,A=w*C,M=n,D=\"\",k=0;k<N.length;++k){var j=k+I<b.length?b[k+I]:b[b.length-1];s===j?D+=N[k]:(R(),D=N[k],void 0!==j&&(B(s,j),s=j))}R(),I+=N.length;var U=0|Math.round(T+2*L);O<U&&(O=U)}var V=O,q=P+C*E;return i(e.getImageData(0,0,V,q).data,[q,V,4]).pick(-1,-1,0).transpose(1,0)}(e,r,t,a,o,s),n,a)},e.exports.processPixels=w;var n=t(\"surface-nets\"),i=t(\"ndarray\"),a=t(\"simplify-planar-graph\"),o=t(\"clean-pslg\"),s=t(\"cdt2d\"),l=t(\"planar-graph-to-polyline\"),c=\"b\",u=\"b|\",h=\"i\",f=\"i|\",p=\"sup\",d=\"+\",g=\"+1\",v=\"sub\",m=\"-\",y=\"-1\";function x(t,e,r,n){for(var i=\"<\"+t+\">\",a=\"</\"+t+\">\",o=i.length,s=a.length,l=e[0]===d||e[0]===m,c=0,u=-s;c>-1&&-1!==(c=r.indexOf(i,c))&&-1!==(u=r.indexOf(a,c+o))&&!(u<=c);){for(var h=c;h<u+s;++h)if(h<c+o||h>=u)n[h]=null,r=r.substr(0,h)+\" \"+r.substr(h+1);else if(null!==n[h]){var f=n[h].indexOf(e[0]);-1===f?n[h]+=e:l&&(n[h]=n[h].substr(0,f+1)+(1+parseInt(n[h][f+1]))+n[h].substr(f+2))}var p=c+o,g=r.substr(p,u-p).indexOf(i);c=-1!==g?g:u+s}return n}function b(t,e){var r=n(t,128);return e?a(r.cells,r.positions,.25):{edges:r.cells,positions:r.positions}}function _(t,e,r,n){var i=b(t,n),a=function(t,e,r){for(var n=e.textAlign||\"start\",i=e.textBaseline||\"alphabetic\",a=[1<<30,1<<30],o=[0,0],s=t.length,l=0;l<s;++l)for(var c=t[l],u=0;u<2;++u)a[u]=0|Math.min(a[u],c[u]),o[u]=0|Math.max(o[u],c[u]);var h=0;switch(n){case\"center\":h=-.5*(a[0]+o[0]);break;case\"right\":case\"end\":h=-o[0];break;case\"left\":case\"start\":h=-a[0];break;default:throw new Error(\"vectorize-text: Unrecognized textAlign: '\"+n+\"'\")}var f=0;switch(i){case\"hanging\":case\"top\":f=-a[1];break;case\"middle\":f=-.5*(a[1]+o[1]);break;case\"alphabetic\":case\"ideographic\":f=-3*r;break;case\"bottom\":f=-o[1];break;default:throw new Error(\"vectorize-text: Unrecoginized textBaseline: '\"+i+\"'\")}var p=1/r;return\"lineHeight\"in e?p*=+e.lineHeight:\"width\"in e?p=e.width/(o[0]-a[0]):\"height\"in e&&(p=e.height/(o[1]-a[1])),t.map(function(t){return[p*(t[0]+h),p*(t[1]+f)]})}(i.positions,e,r),c=i.edges,u=\"ccw\"===e.orientation;if(o(a,c),e.polygons||e.polygon||e.polyline){for(var h=l(c,a),f=new Array(h.length),p=0;p<h.length;++p){for(var d=h[p],g=new Array(d.length),v=0;v<d.length;++v){for(var m=d[v],y=new Array(m.length),x=0;x<m.length;++x)y[x]=a[m[x]].slice();u&&y.reverse(),g[v]=y}f[p]=g}return f}return e.triangles||e.triangulate||e.triangle?{cells:s(a,c,{delaunay:!1,exterior:!1,interior:!0}),positions:a}:{edges:c,positions:a}}function w(t,e,r){try{return _(t,e,r,!0)}catch(t){}try{return _(t,e,r,!1)}catch(t){}return e.polygons||e.polyline||e.polygon?[]:e.triangles||e.triangulate||e.triangle?{cells:[],positions:[]}:{edges:[],positions:[]}}},{cdt2d:106,\"clean-pslg\":116,ndarray:450,\"planar-graph-to-polyline\":468,\"simplify-planar-graph\":524,\"surface-nets\":531}],552:[function(t,e,r){!function(){\"use strict\";if(\"undefined\"==typeof ses||!ses.ok||ses.ok()){\"undefined\"!=typeof ses&&(ses.weakMapPermitHostObjects=v);var t=!1;if(\"function\"==typeof WeakMap){var r=WeakMap;if(\"undefined\"!=typeof navigator&&/Firefox/.test(navigator.userAgent));else{var n=new r,i=Object.freeze({});if(n.set(i,1),1===n.get(i))return void(e.exports=WeakMap);t=!0}}Object.prototype.hasOwnProperty;var a=Object.getOwnPropertyNames,o=Object.defineProperty,s=Object.isExtensible,l=\"weakmap:\",c=l+\"ident:\"+Math.random()+\"___\";if(\"undefined\"!=typeof crypto&&\"function\"==typeof crypto.getRandomValues&&\"function\"==typeof ArrayBuffer&&\"function\"==typeof Uint8Array){var u=new ArrayBuffer(25),h=new Uint8Array(u);crypto.getRandomValues(h),c=l+\"rand:\"+Array.prototype.map.call(h,function(t){return(t%36).toString(36)}).join(\"\")+\"___\"}if(o(Object,\"getOwnPropertyNames\",{value:function(t){return a(t).filter(m)}}),\"getPropertyNames\"in Object){var f=Object.getPropertyNames;o(Object,\"getPropertyNames\",{value:function(t){return f(t).filter(m)}})}!function(){var t=Object.freeze;o(Object,\"freeze\",{value:function(e){return y(e),t(e)}});var e=Object.seal;o(Object,\"seal\",{value:function(t){return y(t),e(t)}});var r=Object.preventExtensions;o(Object,\"preventExtensions\",{value:function(t){return y(t),r(t)}})}();var p=!1,d=0,g=function(){this instanceof g||b();var t=[],e=[],r=d++;return Object.create(g.prototype,{get___:{value:x(function(n,i){var a,o=y(n);return o?r in o?o[r]:i:(a=t.indexOf(n))>=0?e[a]:i})},has___:{value:x(function(e){var n=y(e);return n?r in n:t.indexOf(e)>=0})},set___:{value:x(function(n,i){var a,o=y(n);return o?o[r]=i:(a=t.indexOf(n))>=0?e[a]=i:(a=t.length,e[a]=i,t[a]=n),this})},delete___:{value:x(function(n){var i,a,o=y(n);return o?r in o&&delete o[r]:!((i=t.indexOf(n))<0||(a=t.length-1,t[i]=void 0,e[i]=e[a],t[i]=t[a],t.length=a,e.length=a,0))})}})};g.prototype=Object.create(Object.prototype,{get:{value:function(t,e){return this.get___(t,e)},writable:!0,configurable:!0},has:{value:function(t){return this.has___(t)},writable:!0,configurable:!0},set:{value:function(t,e){return this.set___(t,e)},writable:!0,configurable:!0},delete:{value:function(t){return this.delete___(t)},writable:!0,configurable:!0}}),\"function\"==typeof r?function(){function n(){this instanceof g||b();var e,n=new r,i=void 0,a=!1;return e=t?function(t,e){return n.set(t,e),n.has(t)||(i||(i=new g),i.set(t,e)),this}:function(t,e){if(a)try{n.set(t,e)}catch(r){i||(i=new g),i.set___(t,e)}else n.set(t,e);return this},Object.create(g.prototype,{get___:{value:x(function(t,e){return i?n.has(t)?n.get(t):i.get___(t,e):n.get(t,e)})},has___:{value:x(function(t){return n.has(t)||!!i&&i.has___(t)})},set___:{value:x(e)},delete___:{value:x(function(t){var e=!!n.delete(t);return i&&i.delete___(t)||e})},permitHostObjects___:{value:x(function(t){if(t!==v)throw new Error(\"bogus call to permitHostObjects___\");a=!0})}})}t&&\"undefined\"!=typeof Proxy&&(Proxy=void 0),n.prototype=g.prototype,e.exports=n,Object.defineProperty(WeakMap.prototype,\"constructor\",{value:WeakMap,enumerable:!1,configurable:!0,writable:!0})}():(\"undefined\"!=typeof Proxy&&(Proxy=void 0),e.exports=g)}function v(t){t.permitHostObjects___&&t.permitHostObjects___(v)}function m(t){return!(t.substr(0,l.length)==l&&\"___\"===t.substr(t.length-3))}function y(t){if(t!==Object(t))throw new TypeError(\"Not an object: \"+t);var e=t[c];if(e&&e.key===t)return e;if(s(t)){e={key:t};try{return o(t,c,{value:e,writable:!1,enumerable:!1,configurable:!1}),e}catch(t){return}}}function x(t){return t.prototype=null,Object.freeze(t)}function b(){p||\"undefined\"==typeof console||(p=!0,console.warn(\"WeakMap should be invoked as new WeakMap(), not WeakMap(). This will be an error in the future.\"))}}()},{}],553:[function(t,e,r){var n=t(\"./hidden-store.js\");e.exports=function(){var t={};return function(e){if((\"object\"!=typeof e||null===e)&&\"function\"!=typeof e)throw new Error(\"Weakmap-shim: Key must be object\");var r=e.valueOf(t);return r&&r.identity===t?r:n(e,t)}}},{\"./hidden-store.js\":554}],554:[function(t,e,r){e.exports=function(t,e){var r={identity:e},n=t.valueOf;return Object.defineProperty(t,\"valueOf\",{value:function(t){return t!==e?n.apply(this,arguments):r},writable:!0}),r}},{}],555:[function(t,e,r){var n=t(\"./create-store.js\");e.exports=function(){var t=n();return{get:function(e,r){var n=t(e);return n.hasOwnProperty(\"value\")?n.value:r},set:function(e,r){return t(e).value=r,this},has:function(e){return\"value\"in t(e)},delete:function(e){return delete t(e).value}}}},{\"./create-store.js\":553}],556:[function(t,e,r){var n=t(\"get-canvas-context\");e.exports=function(t){return n(\"webgl\",t)}},{\"get-canvas-context\":232}],557:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Chinese\",jdEpoch:1721425.5,hasYearZero:!1,minMonth:0,firstMonth:0,minDay:1,regionalOptions:{\"\":{name:\"Chinese\",epochs:[\"BEC\",\"EC\"],monthNumbers:function(t,e){if(\"string\"==typeof t){var r=t.match(l);return r?r[0]:\"\"}var n=this._validateYear(t),i=t.month(),a=\"\"+this.toChineseMonth(n,i);return e&&a.length<2&&(a=\"0\"+a),this.isIntercalaryMonth(n,i)&&(a+=\"i\"),a},monthNames:function(t){if(\"string\"==typeof t){var e=t.match(c);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\\u6708\",\"\\u4e8c\\u6708\",\"\\u4e09\\u6708\",\"\\u56db\\u6708\",\"\\u4e94\\u6708\",\"\\u516d\\u6708\",\"\\u4e03\\u6708\",\"\\u516b\\u6708\",\"\\u4e5d\\u6708\",\"\\u5341\\u6708\",\"\\u5341\\u4e00\\u6708\",\"\\u5341\\u4e8c\\u6708\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},monthNamesShort:function(t){if(\"string\"==typeof t){var e=t.match(u);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},parseMonth:function(t,e){t=this._validateYear(t);var r,n=parseInt(e);if(isNaN(n))\"\\u95f0\"===e[0]&&(r=!0,e=e.substring(1)),\"\\u6708\"===e[e.length-1]&&(e=e.substring(0,e.length-1)),n=1+[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"].indexOf(e);else{var i=e[e.length-1];r=\"i\"===i||\"I\"===i}return this.toMonthIndex(t,n,r)},dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},_validateYear:function(t,e){if(t.year&&(t=t.year()),\"number\"!=typeof t||t<1888||t>2111)throw e.replace(/\\{0\\}/,this.local.name);return t},toMonthIndex:function(t,e,r){var i=this.intercalaryMonth(t);if(r&&e!==i||e<1||e>12)throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return i?!r&&e<=i?e-1:e:e-1},toChineseMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);if(e<0||e>(r?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r?e<r?e+1:e:e+1},intercalaryMonth:function(t){return t=this._validateYear(t),h[t-h[0]]>>13},isIntercalaryMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);return!!r&&r===e},leapYear:function(t){return 0!==this.intercalaryMonth(t)},weekOfYear:function(t,e,r){var i,o=this._validateYear(t,n.local.invalidyear),s=f[o-f[0]],l=s>>9&4095,c=s>>5&15,u=31&s;(i=a.newDate(l,c,u)).add(4-(i.dayOfWeek()||7),\"d\");var h=this.toJD(t,e,r)-i.toJD();return 1+Math.floor(h/7)},monthsInYear:function(t){return this.leapYear(t)?13:12},daysInMonth:function(t,e){t.year&&(e=t.month(),t=t.year()),t=this._validateYear(t);var r=h[t-h[0]];if(e>(r>>13?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r&1<<12-e?30:29},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,s,r,n.local.invalidDate);t=this._validateYear(i.year()),e=i.month(),r=i.day();var o=this.isIntercalaryMonth(t,e),s=this.toChineseMonth(t,e),l=function(t,e,r,n,i){var a,o,s;if(\"object\"==typeof t)o=t,a=e||{};else{var l=\"number\"==typeof t&&t>=1888&&t<=2111;if(!l)throw new Error(\"Lunar year outside range 1888-2111\");var c=\"number\"==typeof e&&e>=1&&e<=12;if(!c)throw new Error(\"Lunar month outside range 1 - 12\");var u,p=\"number\"==typeof r&&r>=1&&r<=30;if(!p)throw new Error(\"Lunar day outside range 1 - 30\");\"object\"==typeof n?(u=!1,a=n):(u=!!n,a=i||{}),o={year:t,month:e,day:r,isIntercalary:u}}s=o.day-1;var d,g=h[o.year-h[0]],v=g>>13;d=v?o.month>v?o.month:o.isIntercalary?o.month:o.month-1:o.month-1;for(var m=0;m<d;m++){var y=g&1<<12-m?30:29;s+=y}var x=f[o.year-f[0]],b=new Date(x>>9&4095,(x>>5&15)-1,(31&x)+s);return a.year=b.getFullYear(),a.month=1+b.getMonth(),a.day=b.getDate(),a}(t,s,r,o);return a.toJD(l.year,l.month,l.day)},fromJD:function(t){var e=a.fromJD(t),r=function(t,e,r,n){var i,a;if(\"object\"==typeof t)i=t,a=e||{};else{var o=\"number\"==typeof t&&t>=1888&&t<=2111;if(!o)throw new Error(\"Solar year outside range 1888-2111\");var s=\"number\"==typeof e&&e>=1&&e<=12;if(!s)throw new Error(\"Solar month outside range 1 - 12\");var l=\"number\"==typeof r&&r>=1&&r<=31;if(!l)throw new Error(\"Solar day outside range 1 - 31\");i={year:t,month:e,day:r},a=n||{}}var c=f[i.year-f[0]],u=i.year<<9|i.month<<5|i.day;a.year=u>=c?i.year:i.year-1,c=f[a.year-f[0]];var p,d=new Date(c>>9&4095,(c>>5&15)-1,31&c),g=new Date(i.year,i.month-1,i.day);p=Math.round((g-d)/864e5);var v,m=h[a.year-h[0]];for(v=0;v<13;v++){var y=m&1<<12-v?30:29;if(p<y)break;p-=y}var x=m>>13;!x||v<x?(a.isIntercalary=!1,a.month=1+v):v===x?(a.isIntercalary=!0,a.month=v):(a.isIntercalary=!1,a.month=v);return a.day=1+p,a}(e.year(),e.month(),e.day()),n=this.toMonthIndex(r.year,r.month,r.isIntercalary);return this.newDate(r.year,n,r.day)},fromString:function(t){var e=t.match(s),r=this._validateYear(+e[1]),n=+e[2],i=!!e[3],a=this.toMonthIndex(r,n,i),o=+e[4];return this.newDate(r,a,o)},add:function(t,e,r){var n=t.year(),i=t.month(),a=this.isIntercalaryMonth(n,i),s=this.toChineseMonth(n,i),l=Object.getPrototypeOf(o.prototype).add.call(this,t,e,r);if(\"y\"===r){var c=l.year(),u=l.month(),h=this.isIntercalaryMonth(c,s),f=a&&h?this.toMonthIndex(c,s,!0):this.toMonthIndex(c,s,!1);f!==u&&l.month(f)}return l}});var s=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)[-\\/](\\d?\\d)([iI]?)[-\\/](\\d?\\d)/m,l=/^\\d?\\d[iI]?/m,c=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?\\u6708/m,u=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?/m;n.calendars.chinese=o;var h=[1887,5780,5802,19157,2742,50359,1198,2646,46378,7466,3412,30122,5482,67949,2396,5294,43597,6732,6954,36181,2772,4954,18781,2396,54427,5274,6730,47781,5800,6868,21210,4790,59703,2350,5270,46667,3402,3496,38325,1388,4782,18735,2350,52374,6804,7498,44457,2906,1388,29294,4700,63789,6442,6804,56138,5802,2772,38235,1210,4698,22827,5418,63125,3476,5802,43701,2484,5302,27223,2646,70954,7466,3412,54698,5482,2412,38062,5294,2636,32038,6954,60245,2772,4826,43357,2394,5274,39501,6730,72357,5800,5844,53978,4790,2358,38039,5270,87627,3402,3496,54708,5484,4782,43311,2350,3222,27978,7498,68965,2904,5484,45677,4700,6444,39573,6804,6986,19285,2772,62811,1210,4698,47403,5418,5780,38570,5546,76469,2420,5302,51799,2646,5414,36501,3412,5546,18869,2412,54446,5276,6732,48422,6822,2900,28010,4826,92509,2394,5274,55883,6730,6820,47956,5812,2778,18779,2358,62615,5270,5450,46757,3492,5556,27318,4718,67887,2350,3222,52554,7498,3428,38252,5468,4700,31022,6444,64149,6804,6986,43861,2772,5338,35421,2650,70955,5418,5780,54954,5546,2740,38074,5302,2646,29991,3366,61011,3412,5546,43445,2412,5294,35406,6732,72998,6820,6996,52586,2778,2396,38045,5274,6698,23333,6820,64338,5812,2746,43355,2358,5270,39499,5450,79525,3492,5548],f=[1887,966732,967231,967733,968265,968766,969297,969798,970298,970829,971330,971830,972362,972863,973395,973896,974397,974928,975428,975929,976461,976962,977462,977994,978494,979026,979526,980026,980558,981059,981559,982091,982593,983124,983624,984124,984656,985157,985656,986189,986690,987191,987722,988222,988753,989254,989754,990286,990788,991288,991819,992319,992851,993352,993851,994383,994885,995385,995917,996418,996918,997450,997949,998481,998982,999483,1000014,1000515,1001016,1001548,1002047,1002578,1003080,1003580,1004111,1004613,1005113,1005645,1006146,1006645,1007177,1007678,1008209,1008710,1009211,1009743,1010243,1010743,1011275,1011775,1012306,1012807,1013308,1013840,1014341,1014841,1015373,1015874,1016404,1016905,1017405,1017937,1018438,1018939,1019471,1019972,1020471,1021002,1021503,1022035,1022535,1023036,1023568,1024069,1024568,1025100,1025601,1026102,1026633,1027133,1027666,1028167,1028666,1029198,1029699,1030199,1030730,1031231,1031763,1032264,1032764,1033296,1033797,1034297,1034828,1035329,1035830,1036362,1036861,1037393,1037894,1038394,1038925,1039427,1039927,1040459,1040959,1041491,1041992,1042492,1043023,1043524,1044024,1044556,1045057,1045558,1046090,1046590,1047121,1047622,1048122,1048654,1049154,1049655,1050187,1050689,1051219,1051720,1052220,1052751,1053252,1053752,1054284,1054786,1055285,1055817,1056317,1056849,1057349,1057850,1058382,1058883,1059383,1059915,1060415,1060947,1061447,1061947,1062479,1062981,1063480,1064012,1064514,1065014,1065545,1066045,1066577,1067078,1067578,1068110,1068611,1069112,1069642,1070142,1070674,1071175,1071675,1072207,1072709,1073209,1073740,1074241,1074741,1075273,1075773,1076305,1076807,1077308,1077839,1078340,1078840,1079372,1079871,1080403,1080904]},{\"../main\":571,\"object-assign\":454}],558:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Coptic\",jdEpoch:1825029.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Coptic\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Thout\",\"Paopi\",\"Hathor\",\"Koiak\",\"Tobi\",\"Meshir\",\"Paremhat\",\"Paremoude\",\"Pashons\",\"Paoni\",\"Epip\",\"Mesori\",\"Pi Kogi Enavot\"],monthNamesShort:[\"Tho\",\"Pao\",\"Hath\",\"Koi\",\"Tob\",\"Mesh\",\"Pat\",\"Pad\",\"Pash\",\"Pao\",\"Epi\",\"Meso\",\"PiK\"],dayNames:[\"Tkyriaka\",\"Pesnau\",\"Pshoment\",\"Peftoou\",\"Ptiou\",\"Psoou\",\"Psabbaton\"],dayNamesShort:[\"Tky\",\"Pes\",\"Psh\",\"Pef\",\"Pti\",\"Pso\",\"Psa\"],dayNamesMin:[\"Tk\",\"Pes\",\"Psh\",\"Pef\",\"Pt\",\"Pso\",\"Psa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.coptic=a},{\"../main\":571,\"object-assign\":454}],559:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Discworld\",jdEpoch:1721425.5,daysPerMonth:[16,32,32,32,32,32,32,32,32,32,32,32,32],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Discworld\",epochs:[\"BUC\",\"UC\"],monthNames:[\"Ick\",\"Offle\",\"February\",\"March\",\"April\",\"May\",\"June\",\"Grune\",\"August\",\"Spune\",\"Sektober\",\"Ember\",\"December\"],monthNamesShort:[\"Ick\",\"Off\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Gru\",\"Aug\",\"Spu\",\"Sek\",\"Emb\",\"Dec\"],dayNames:[\"Sunday\",\"Octeday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Oct\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Oc\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:2,isRTL:!1}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),13},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),400},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/8)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]},daysInWeek:function(){return 8},dayOfWeek:function(t,e,r){return(this._validate(t,e,r,n.local.invalidDate).day()+1)%8},weekDay:function(t,e,r){var n=this.dayOfWeek(t,e,r);return n>=2&&n<=6},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{century:o[Math.floor((i.year()-1)/100)+1]||\"\"}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year()+(i.year()<0?1:0),e=i.month(),(r=i.day())+(e>1?16:0)+(e>2?32*(e-2):0)+400*(t-1)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t+.5)-Math.floor(this.jdEpoch)-1;var e=Math.floor(t/400)+1;t-=400*(e-1),t+=t>15?16:0;var r=Math.floor(t/32)+1,n=t-32*(r-1)+1;return this.newDate(e<=0?e-1:e,r,n)}});var o={20:\"Fruitbat\",21:\"Anchovy\"};n.calendars.discworld=a},{\"../main\":571,\"object-assign\":454}],560:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Ethiopian\",jdEpoch:1724220.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Ethiopian\",epochs:[\"BEE\",\"EE\"],monthNames:[\"Meskerem\",\"Tikemet\",\"Hidar\",\"Tahesas\",\"Tir\",\"Yekatit\",\"Megabit\",\"Miazia\",\"Genbot\",\"Sene\",\"Hamle\",\"Nehase\",\"Pagume\"],monthNamesShort:[\"Mes\",\"Tik\",\"Hid\",\"Tah\",\"Tir\",\"Yek\",\"Meg\",\"Mia\",\"Gen\",\"Sen\",\"Ham\",\"Neh\",\"Pag\"],dayNames:[\"Ehud\",\"Segno\",\"Maksegno\",\"Irob\",\"Hamus\",\"Arb\",\"Kidame\"],dayNamesShort:[\"Ehu\",\"Seg\",\"Mak\",\"Iro\",\"Ham\",\"Arb\",\"Kid\"],dayNamesMin:[\"Eh\",\"Se\",\"Ma\",\"Ir\",\"Ha\",\"Ar\",\"Ki\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.ethiopian=a},{\"../main\":571,\"object-assign\":454}],561:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Hebrew\",jdEpoch:347995.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29,29],hasYearZero:!1,minMonth:1,firstMonth:7,minDay:1,regionalOptions:{\"\":{name:\"Hebrew\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Nisan\",\"Iyar\",\"Sivan\",\"Tammuz\",\"Av\",\"Elul\",\"Tishrei\",\"Cheshvan\",\"Kislev\",\"Tevet\",\"Shevat\",\"Adar\",\"Adar II\"],monthNamesShort:[\"Nis\",\"Iya\",\"Siv\",\"Tam\",\"Av\",\"Elu\",\"Tis\",\"Che\",\"Kis\",\"Tev\",\"She\",\"Ada\",\"Ad2\"],dayNames:[\"Yom Rishon\",\"Yom Sheni\",\"Yom Shlishi\",\"Yom Revi'i\",\"Yom Chamishi\",\"Yom Shishi\",\"Yom Shabbat\"],dayNamesShort:[\"Ris\",\"She\",\"Shl\",\"Rev\",\"Cha\",\"Shi\",\"Sha\"],dayNamesMin:[\"Ri\",\"She\",\"Shl\",\"Re\",\"Ch\",\"Shi\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return this._leapYear(e.year())},_leapYear:function(t){return o(7*(t=t<0?t+1:t)+1,19)<7},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),this._leapYear(t.year?t.year():t)?13:12},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),this.toJD(-1===t?1:t+1,7,1)-this.toJD(t,7,1)},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),12===e&&this.leapYear(t)?30:8===e&&5===o(this.daysInYear(t),10)?30:9===e&&3===o(this.daysInYear(t),10)?29:this.daysPerMonth[e-1]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{yearType:(this.leapYear(i)?\"embolismic\":\"common\")+\" \"+[\"deficient\",\"regular\",\"complete\"][this.daysInYear(i)%10-3]}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t<=0?t+1:t,o=this.jdEpoch+this._delay1(a)+this._delay2(a)+r+1;if(e<7){for(var s=7;s<=this.monthsInYear(t);s++)o+=this.daysInMonth(t,s);for(s=1;s<e;s++)o+=this.daysInMonth(t,s)}else for(s=7;s<e;s++)o+=this.daysInMonth(t,s);return o},_delay1:function(t){var e=Math.floor((235*t-234)/19),r=12084+13753*e,n=29*e+Math.floor(r/25920);return o(3*(n+1),7)<3&&n++,n},_delay2:function(t){var e=this._delay1(t-1),r=this._delay1(t);return this._delay1(t+1)-r==356?2:r-e==382?1:0},fromJD:function(t){t=Math.floor(t)+.5;for(var e=Math.floor(98496*(t-this.jdEpoch)/35975351)-1;t>=this.toJD(-1===e?1:e+1,7,1);)e++;for(var r=t<this.toJD(e,1,1)?7:1;t>this.toJD(e,r,this.daysInMonth(e,r));)r++;var n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.hebrew=a},{\"../main\":571,\"object-assign\":454}],562:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Islamic\",jdEpoch:1948439.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Islamic\",epochs:[\"BH\",\"AH\"],monthNames:[\"Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' al-thani\",\"Jumada al-awwal\",\"Jumada al-thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-ahad\",\"Yawm al-ithnayn\",\"Yawm ath-thulaathaa'\",\"Yawm al-arbi'aa'\",\"Yawm al-kham\\u012bs\",\"Yawm al-jum'a\",\"Yawm as-sabt\"],dayNamesShort:[\"Aha\",\"Ith\",\"Thu\",\"Arb\",\"Kha\",\"Jum\",\"Sab\"],dayNamesMin:[\"Ah\",\"It\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){return(11*this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year()+14)%30<11},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return this.leapYear(t)?355:354},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),t=t<=0?t+1:t,(r=i.day())+Math.ceil(29.5*(e-1))+354*(t-1)+Math.floor((3+11*t)/30)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t)+.5;var e=Math.floor((30*(t-this.jdEpoch)+10646)/10631);e=e<=0?e-1:e;var r=Math.min(12,Math.ceil((t-29-this.toJD(e,1,1))/29.5)+1),n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.islamic=a},{\"../main\":571,\"object-assign\":454}],563:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Julian\",jdEpoch:1721423.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Julian\",epochs:[\"BC\",\"AD\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()<0?e.year()+1:e.year())%4==0},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),r=i.day(),t<0&&t++,e<=2&&(t--,e+=12),Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r-1524.5},fromJD:function(t){var e=Math.floor(t+.5)+1524,r=Math.floor((e-122.1)/365.25),n=Math.floor(365.25*r),i=Math.floor((e-n)/30.6001),a=i-Math.floor(i<14?1:13),o=r-Math.floor(a>2?4716:4715),s=e-n-Math.floor(30.6001*i);return o<=0&&o--,this.newDate(o,a,s)}}),n.calendars.julian=a},{\"../main\":571,\"object-assign\":454}],564:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}function s(t,e){return o(t-1,e)+1}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Mayan\",jdEpoch:584282.5,hasYearZero:!0,minMonth:0,firstMonth:0,minDay:0,regionalOptions:{\"\":{name:\"Mayan\",epochs:[\"\",\"\"],monthNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],monthNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],dayNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesMin:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],digits:null,dateFormat:\"YYYY.m.d\",firstDay:0,isRTL:!1,haabMonths:[\"Pop\",\"Uo\",\"Zip\",\"Zotz\",\"Tzec\",\"Xul\",\"Yaxkin\",\"Mol\",\"Chen\",\"Yax\",\"Zac\",\"Ceh\",\"Mac\",\"Kankin\",\"Muan\",\"Pax\",\"Kayab\",\"Cumku\",\"Uayeb\"],tzolkinMonths:[\"Imix\",\"Ik\",\"Akbal\",\"Kan\",\"Chicchan\",\"Cimi\",\"Manik\",\"Lamat\",\"Muluc\",\"Oc\",\"Chuen\",\"Eb\",\"Ben\",\"Ix\",\"Men\",\"Cib\",\"Caban\",\"Etznab\",\"Cauac\",\"Ahau\"]}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},formatYear:function(t){t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year();var e=Math.floor(t/400);return t%=400,t+=t<0?400:0,e+\".\"+Math.floor(t/20)+\".\"+t%20},forYear:function(t){if((t=t.split(\".\")).length<3)throw\"Invalid Mayan year\";for(var e=0,r=0;r<t.length;r++){var n=parseInt(t[r],10);if(Math.abs(n)>19||r>0&&n<0)throw\"Invalid Mayan year\";e=20*e+n}return e},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),18},weekOfYear:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),0},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),360},daysInMonth:function(t,e){return this._validate(t,e,this.minDay,n.local.invalidMonth),20},daysInWeek:function(){return 5},dayOfWeek:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate).day()},weekDay:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),!0},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate).toJD(),a=this._toHaab(i),o=this._toTzolkin(i);return{haabMonthName:this.local.haabMonths[a[0]-1],haabMonth:a[0],haabDay:a[1],tzolkinDayName:this.local.tzolkinMonths[o[0]-1],tzolkinDay:o[0],tzolkinTrecena:o[1]}},_toHaab:function(t){var e=o((t-=this.jdEpoch)+8+340,365);return[Math.floor(e/20)+1,o(e,20)]},_toTzolkin:function(t){return[s((t-=this.jdEpoch)+20,20),s(t+4,13)]},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return i.day()+20*i.month()+360*i.year()+this.jdEpoch},fromJD:function(t){t=Math.floor(t)+.5-this.jdEpoch;var e=Math.floor(t/360);t%=360,t+=t<0?360:0;var r=Math.floor(t/20),n=t%20;return this.newDate(e,r,n)}}),n.calendars.mayan=a},{\"../main\":571,\"object-assign\":454}],565:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar;var o=n.instance(\"gregorian\");i(a.prototype,{name:\"Nanakshahi\",jdEpoch:2257673.5,daysPerMonth:[31,31,31,31,31,30,30,30,30,30,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Nanakshahi\",epochs:[\"BN\",\"AN\"],monthNames:[\"Chet\",\"Vaisakh\",\"Jeth\",\"Harh\",\"Sawan\",\"Bhadon\",\"Assu\",\"Katak\",\"Maghar\",\"Poh\",\"Magh\",\"Phagun\"],monthNamesShort:[\"Che\",\"Vai\",\"Jet\",\"Har\",\"Saw\",\"Bha\",\"Ass\",\"Kat\",\"Mgr\",\"Poh\",\"Mgh\",\"Pha\"],dayNames:[\"Somvaar\",\"Mangalvar\",\"Budhvaar\",\"Veervaar\",\"Shukarvaar\",\"Sanicharvaar\",\"Etvaar\"],dayNamesShort:[\"Som\",\"Mangal\",\"Budh\",\"Veer\",\"Shukar\",\"Sanichar\",\"Et\"],dayNamesMin:[\"So\",\"Ma\",\"Bu\",\"Ve\",\"Sh\",\"Sa\",\"Et\"],digits:null,dateFormat:\"dd-mm-yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear);return o.leapYear(e.year()+(e.year()<1?1:0)+1469)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(1-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidMonth);(t=i.year())<0&&t++;for(var a=i.day(),s=1;s<i.month();s++)a+=this.daysPerMonth[s-1];return a+o.toJD(t+1468,3,13)},fromJD:function(t){t=Math.floor(t+.5);for(var e=Math.floor((t-(this.jdEpoch-1))/366);t>=this.toJD(e+1,1,1);)e++;for(var r=t-Math.floor(this.toJD(e,1,1)+.5)+1,n=1;r>this.daysInMonth(e,n);)r-=this.daysInMonth(e,n),n++;return this.newDate(e,n,r)}}),n.calendars.nanakshahi=a},{\"../main\":571,\"object-assign\":454}],566:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Nepali\",jdEpoch:1700709.5,daysPerMonth:[31,31,32,32,31,30,30,29,30,29,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,daysPerYear:365,regionalOptions:{\"\":{name:\"Nepali\",epochs:[\"BBS\",\"ABS\"],monthNames:[\"Baisakh\",\"Jestha\",\"Ashadh\",\"Shrawan\",\"Bhadra\",\"Ashwin\",\"Kartik\",\"Mangsir\",\"Paush\",\"Mangh\",\"Falgun\",\"Chaitra\"],monthNamesShort:[\"Bai\",\"Je\",\"As\",\"Shra\",\"Bha\",\"Ash\",\"Kar\",\"Mang\",\"Pau\",\"Ma\",\"Fal\",\"Chai\"],dayNames:[\"Aaitabaar\",\"Sombaar\",\"Manglbaar\",\"Budhabaar\",\"Bihibaar\",\"Shukrabaar\",\"Shanibaar\"],dayNamesShort:[\"Aaita\",\"Som\",\"Mangl\",\"Budha\",\"Bihi\",\"Shukra\",\"Shani\"],dayNamesMin:[\"Aai\",\"So\",\"Man\",\"Bu\",\"Bi\",\"Shu\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:1,isRTL:!1}},leapYear:function(t){return this.daysInYear(t)!==this.daysPerYear},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){if(t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t])return this.daysPerYear;for(var e=0,r=this.minMonth;r<=12;r++)e+=this.NEPALI_CALENDAR_DATA[t][r];return e},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t]?this.daysPerMonth[e-1]:this.NEPALI_CALENDAR_DATA[t][e]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=n.instance(),o=0,s=e,l=t;this._createMissingCalendarData(t);var c=t-(s>9||9===s&&r>=this.NEPALI_CALENDAR_DATA[l][0]?56:57);for(9!==e&&(o=r,s--);9!==s;)s<=0&&(s=12,l--),o+=this.NEPALI_CALENDAR_DATA[l][s],s--;return 9===e?(o+=r-this.NEPALI_CALENDAR_DATA[l][0])<0&&(o+=a.daysInYear(c)):o+=this.NEPALI_CALENDAR_DATA[l][9]-this.NEPALI_CALENDAR_DATA[l][0],a.newDate(c,1,1).add(o,\"d\").toJD()},fromJD:function(t){var e=n.instance().fromJD(t),r=e.year(),i=e.dayOfYear(),a=r+56;this._createMissingCalendarData(a);for(var o=9,s=this.NEPALI_CALENDAR_DATA[a][0],l=this.NEPALI_CALENDAR_DATA[a][o]-s+1;i>l;)++o>12&&(o=1,a++),l+=this.NEPALI_CALENDAR_DATA[a][o];var c=this.NEPALI_CALENDAR_DATA[a][o]-(l-i);return this.newDate(a,o,c)},_createMissingCalendarData:function(t){var e=this.daysPerMonth.slice(0);e.unshift(17);for(var r=t-1;r<t+2;r++)\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[r]&&(this.NEPALI_CALENDAR_DATA[r]=e)},NEPALI_CALENDAR_DATA:{1970:[18,31,31,32,31,31,31,30,29,30,29,30,30],1971:[18,31,31,32,31,32,30,30,29,30,29,30,30],1972:[17,31,32,31,32,31,30,30,30,29,29,30,30],1973:[19,30,32,31,32,31,30,30,30,29,30,29,31],1974:[19,31,31,32,30,31,31,30,29,30,29,30,30],1975:[18,31,31,32,32,30,31,30,29,30,29,30,30],1976:[17,31,32,31,32,31,30,30,30,29,29,30,31],1977:[18,31,32,31,32,31,31,29,30,29,30,29,31],1978:[18,31,31,32,31,31,31,30,29,30,29,30,30],1979:[18,31,31,32,32,31,30,30,29,30,29,30,30],1980:[17,31,32,31,32,31,30,30,30,29,29,30,31],1981:[18,31,31,31,32,31,31,29,30,30,29,30,30],1982:[18,31,31,32,31,31,31,30,29,30,29,30,30],1983:[18,31,31,32,32,31,30,30,29,30,29,30,30],1984:[17,31,32,31,32,31,30,30,30,29,29,30,31],1985:[18,31,31,31,32,31,31,29,30,30,29,30,30],1986:[18,31,31,32,31,31,31,30,29,30,29,30,30],1987:[18,31,32,31,32,31,30,30,29,30,29,30,30],1988:[17,31,32,31,32,31,30,30,30,29,29,30,31],1989:[18,31,31,31,32,31,31,30,29,30,29,30,30],1990:[18,31,31,32,31,31,31,30,29,30,29,30,30],1991:[18,31,32,31,32,31,30,30,29,30,29,30,30],1992:[17,31,32,31,32,31,30,30,30,29,30,29,31],1993:[18,31,31,31,32,31,31,30,29,30,29,30,30],1994:[18,31,31,32,31,31,31,30,29,30,29,30,30],1995:[17,31,32,31,32,31,30,30,30,29,29,30,30],1996:[17,31,32,31,32,31,30,30,30,29,30,29,31],1997:[18,31,31,32,31,31,31,30,29,30,29,30,30],1998:[18,31,31,32,31,31,31,30,29,30,29,30,30],1999:[17,31,32,31,32,31,30,30,30,29,29,30,31],2000:[17,30,32,31,32,31,30,30,30,29,30,29,31],2001:[18,31,31,32,31,31,31,30,29,30,29,30,30],2002:[18,31,31,32,32,31,30,30,29,30,29,30,30],2003:[17,31,32,31,32,31,30,30,30,29,29,30,31],2004:[17,30,32,31,32,31,30,30,30,29,30,29,31],2005:[18,31,31,32,31,31,31,30,29,30,29,30,30],2006:[18,31,31,32,32,31,30,30,29,30,29,30,30],2007:[17,31,32,31,32,31,30,30,30,29,29,30,31],2008:[17,31,31,31,32,31,31,29,30,30,29,29,31],2009:[18,31,31,32,31,31,31,30,29,30,29,30,30],2010:[18,31,31,32,32,31,30,30,29,30,29,30,30],2011:[17,31,32,31,32,31,30,30,30,29,29,30,31],2012:[17,31,31,31,32,31,31,29,30,30,29,30,30],2013:[18,31,31,32,31,31,31,30,29,30,29,30,30],2014:[18,31,31,32,32,31,30,30,29,30,29,30,30],2015:[17,31,32,31,32,31,30,30,30,29,29,30,31],2016:[17,31,31,31,32,31,31,29,30,30,29,30,30],2017:[18,31,31,32,31,31,31,30,29,30,29,30,30],2018:[18,31,32,31,32,31,30,30,29,30,29,30,30],2019:[17,31,32,31,32,31,30,30,30,29,30,29,31],2020:[17,31,31,31,32,31,31,30,29,30,29,30,30],2021:[18,31,31,32,31,31,31,30,29,30,29,30,30],2022:[17,31,32,31,32,31,30,30,30,29,29,30,30],2023:[17,31,32,31,32,31,30,30,30,29,30,29,31],2024:[17,31,31,31,32,31,31,30,29,30,29,30,30],2025:[18,31,31,32,31,31,31,30,29,30,29,30,30],2026:[17,31,32,31,32,31,30,30,30,29,29,30,31],2027:[17,30,32,31,32,31,30,30,30,29,30,29,31],2028:[17,31,31,32,31,31,31,30,29,30,29,30,30],2029:[18,31,31,32,31,32,30,30,29,30,29,30,30],2030:[17,31,32,31,32,31,30,30,30,30,30,30,31],2031:[17,31,32,31,32,31,31,31,31,31,31,31,31],2032:[17,32,32,32,32,32,32,32,32,32,32,32,32],2033:[18,31,31,32,32,31,30,30,29,30,29,30,30],2034:[17,31,32,31,32,31,30,30,30,29,29,30,31],2035:[17,30,32,31,32,31,31,29,30,30,29,29,31],2036:[17,31,31,32,31,31,31,30,29,30,29,30,30],2037:[18,31,31,32,32,31,30,30,29,30,29,30,30],2038:[17,31,32,31,32,31,30,30,30,29,29,30,31],2039:[17,31,31,31,32,31,31,29,30,30,29,30,30],2040:[17,31,31,32,31,31,31,30,29,30,29,30,30],2041:[18,31,31,32,32,31,30,30,29,30,29,30,30],2042:[17,31,32,31,32,31,30,30,30,29,29,30,31],2043:[17,31,31,31,32,31,31,29,30,30,29,30,30],2044:[17,31,31,32,31,31,31,30,29,30,29,30,30],2045:[18,31,32,31,32,31,30,30,29,30,29,30,30],2046:[17,31,32,31,32,31,30,30,30,29,29,30,31],2047:[17,31,31,31,32,31,31,30,29,30,29,30,30],2048:[17,31,31,32,31,31,31,30,29,30,29,30,30],2049:[17,31,32,31,32,31,30,30,30,29,29,30,30],2050:[17,31,32,31,32,31,30,30,30,29,30,29,31],2051:[17,31,31,31,32,31,31,30,29,30,29,30,30],2052:[17,31,31,32,31,31,31,30,29,30,29,30,30],2053:[17,31,32,31,32,31,30,30,30,29,29,30,30],2054:[17,31,32,31,32,31,30,30,30,29,30,29,31],2055:[17,31,31,32,31,31,31,30,29,30,30,29,30],2056:[17,31,31,32,31,32,30,30,29,30,29,30,30],2057:[17,31,32,31,32,31,30,30,30,29,29,30,31],2058:[17,30,32,31,32,31,30,30,30,29,30,29,31],2059:[17,31,31,32,31,31,31,30,29,30,29,30,30],2060:[17,31,31,32,32,31,30,30,29,30,29,30,30],2061:[17,31,32,31,32,31,30,30,30,29,29,30,31],2062:[17,30,32,31,32,31,31,29,30,29,30,29,31],2063:[17,31,31,32,31,31,31,30,29,30,29,30,30],2064:[17,31,31,32,32,31,30,30,29,30,29,30,30],2065:[17,31,32,31,32,31,30,30,30,29,29,30,31],2066:[17,31,31,31,32,31,31,29,30,30,29,29,31],2067:[17,31,31,32,31,31,31,30,29,30,29,30,30],2068:[17,31,31,32,32,31,30,30,29,30,29,30,30],2069:[17,31,32,31,32,31,30,30,30,29,29,30,31],2070:[17,31,31,31,32,31,31,29,30,30,29,30,30],2071:[17,31,31,32,31,31,31,30,29,30,29,30,30],2072:[17,31,32,31,32,31,30,30,29,30,29,30,30],2073:[17,31,32,31,32,31,30,30,30,29,29,30,31],2074:[17,31,31,31,32,31,31,30,29,30,29,30,30],2075:[17,31,31,32,31,31,31,30,29,30,29,30,30],2076:[16,31,32,31,32,31,30,30,30,29,29,30,30],2077:[17,31,32,31,32,31,30,30,30,29,30,29,31],2078:[17,31,31,31,32,31,31,30,29,30,29,30,30],2079:[17,31,31,32,31,31,31,30,29,30,29,30,30],2080:[16,31,32,31,32,31,30,30,30,29,29,30,30],2081:[17,31,31,32,32,31,30,30,30,29,30,30,30],2082:[17,31,32,31,32,31,30,30,30,29,30,30,30],2083:[17,31,31,32,31,31,30,30,30,29,30,30,30],2084:[17,31,31,32,31,31,30,30,30,29,30,30,30],2085:[17,31,32,31,32,31,31,30,30,29,30,30,30],2086:[17,31,32,31,32,31,30,30,30,29,30,30,30],2087:[16,31,31,32,31,31,31,30,30,29,30,30,30],2088:[16,30,31,32,32,30,31,30,30,29,30,30,30],2089:[17,31,32,31,32,31,30,30,30,29,30,30,30],2090:[17,31,32,31,32,31,30,30,30,29,30,30,30],2091:[16,31,31,32,31,31,31,30,30,29,30,30,30],2092:[16,31,31,32,32,31,30,30,30,29,30,30,30],2093:[17,31,32,31,32,31,30,30,30,29,30,30,30],2094:[17,31,31,32,31,31,30,30,30,29,30,30,30],2095:[17,31,31,32,31,31,31,30,29,30,30,30,30],2096:[17,30,31,32,32,31,30,30,29,30,29,30,30],2097:[17,31,32,31,32,31,30,30,30,29,30,30,30],2098:[17,31,31,32,31,31,31,29,30,29,30,30,31],2099:[17,31,31,32,31,31,31,30,29,29,30,30,30],2100:[17,31,32,31,32,30,31,30,29,30,29,30,30]}}),n.calendars.nepali=a},{\"../main\":571,\"object-assign\":454}],567:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Persian\",jdEpoch:1948320.5,daysPerMonth:[31,31,31,31,31,31,30,30,30,30,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Persian\",epochs:[\"BP\",\"AP\"],monthNames:[\"Farvardin\",\"Ordibehesht\",\"Khordad\",\"Tir\",\"Mordad\",\"Shahrivar\",\"Mehr\",\"Aban\",\"Azar\",\"Day\",\"Bahman\",\"Esfand\"],monthNamesShort:[\"Far\",\"Ord\",\"Kho\",\"Tir\",\"Mor\",\"Sha\",\"Meh\",\"Aba\",\"Aza\",\"Day\",\"Bah\",\"Esf\"],dayNames:[\"Yekshambe\",\"Doshambe\",\"Seshambe\",\"Ch\\xe6harshambe\",\"Panjshambe\",\"Jom'e\",\"Shambe\"],dayNamesShort:[\"Yek\",\"Do\",\"Se\",\"Ch\\xe6\",\"Panj\",\"Jom\",\"Sha\"],dayNamesMin:[\"Ye\",\"Do\",\"Se\",\"Ch\",\"Pa\",\"Jo\",\"Sh\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 682*((e.year()-(e.year()>0?474:473))%2820+474+38)%2816<682},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-(n.dayOfWeek()+1)%7,\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t-(t>=0?474:473),s=474+o(a,2820);return r+(e<=7?31*(e-1):30*(e-1)+6)+Math.floor((682*s-110)/2816)+365*(s-1)+1029983*Math.floor(a/2820)+this.jdEpoch-1},fromJD:function(t){var e=(t=Math.floor(t)+.5)-this.toJD(475,1,1),r=Math.floor(e/1029983),n=o(e,1029983),i=2820;if(1029982!==n){var a=Math.floor(n/366),s=o(n,366);i=Math.floor((2134*a+2816*s+2815)/1028522)+a+1}var l=i+2820*r+474;l=l<=0?l-1:l;var c=t-this.toJD(l,1,1)+1,u=c<=186?Math.ceil(c/31):Math.ceil((c-6)/30),h=t-this.toJD(l,u,1)+1;return this.newDate(l,u,h)}}),n.calendars.persian=a,n.calendars.jalali=a},{\"../main\":571,\"object-assign\":454}],568:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Taiwan\",jdEpoch:2419402.5,yearsOffset:1911,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Taiwan\",epochs:[\"BROC\",\"ROC\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)},_g2tYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)}}),n.calendars.taiwan=o},{\"../main\":571,\"object-assign\":454}],569:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Thai\",jdEpoch:1523098.5,yearsOffset:543,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Thai\",epochs:[\"BBE\",\"BE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)},_g2tYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)}}),n.calendars.thai=o},{\"../main\":571,\"object-assign\":454}],570:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"UmmAlQura\",hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Umm al-Qura\",epochs:[\"BH\",\"AH\"],monthNames:[\"Al-Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' Al-Thani\",\"Jumada Al-Awwal\",\"Jumada Al-Thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-Ahad\",\"Yawm al-Ithnain\",\"Yawm al-Thal\\u0101th\\u0101\\u2019\",\"Yawm al-Arba\\u2018\\u0101\\u2019\",\"Yawm al-Kham\\u012bs\",\"Yawm al-Jum\\u2018a\",\"Yawm al-Sabt\"],dayNamesMin:[\"Ah\",\"Ith\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!0}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 355===this.daysInYear(e.year())},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){for(var e=0,r=1;r<=12;r++)e+=this.daysInMonth(t,r);return e},daysInMonth:function(t,e){for(var r=this._validate(t,e,this.minDay,n.local.invalidMonth).toJD()-24e5+.5,i=0,a=0;a<o.length;a++){if(o[a]>r)return o[i]-o[i-1];i++}return 30},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate),a=12*(i.year()-1)+i.month()-15292;return i.day()+o[a-1]-1+24e5-.5},fromJD:function(t){for(var e=t-24e5+.5,r=0,n=0;n<o.length&&!(o[n]>e);n++)r++;var i=r+15292,a=Math.floor((i-1)/12),s=a+1,l=i-12*a,c=e-o[r-1]+1;return this.newDate(s,l,c)},isValid:function(t,e,r){var i=n.baseCalendar.prototype.isValid.apply(this,arguments);return i&&(i=(t=null!=t.year?t.year:t)>=1276&&t<=1500),i},_validate:function(t,e,r,i){var a=n.baseCalendar.prototype._validate.apply(this,arguments);if(a.year<1276||a.year>1500)throw i.replace(/\\{0\\}/,this.local.name);return a}}),n.calendars.ummalqura=a;var o=[20,50,79,109,138,168,197,227,256,286,315,345,374,404,433,463,492,522,551,581,611,641,670,700,729,759,788,818,847,877,906,936,965,995,1024,1054,1083,1113,1142,1172,1201,1231,1260,1290,1320,1350,1379,1409,1438,1468,1497,1527,1556,1586,1615,1645,1674,1704,1733,1763,1792,1822,1851,1881,1910,1940,1969,1999,2028,2058,2087,2117,2146,2176,2205,2235,2264,2294,2323,2353,2383,2413,2442,2472,2501,2531,2560,2590,2619,2649,2678,2708,2737,2767,2796,2826,2855,2885,2914,2944,2973,3003,3032,3062,3091,3121,3150,3180,3209,3239,3268,3298,3327,3357,3386,3416,3446,3476,3505,3535,3564,3594,3623,3653,3682,3712,3741,3771,3800,3830,3859,3889,3918,3948,3977,4007,4036,4066,4095,4125,4155,4185,4214,4244,4273,4303,4332,4362,4391,4421,4450,4480,4509,4539,4568,4598,4627,4657,4686,4716,4745,4775,4804,4834,4863,4893,4922,4952,4981,5011,5040,5070,5099,5129,5158,5188,5218,5248,5277,5307,5336,5366,5395,5425,5454,5484,5513,5543,5572,5602,5631,5661,5690,5720,5749,5779,5808,5838,5867,5897,5926,5956,5985,6015,6044,6074,6103,6133,6162,6192,6221,6251,6281,6311,6340,6370,6399,6429,6458,6488,6517,6547,6576,6606,6635,6665,6694,6724,6753,6783,6812,6842,6871,6901,6930,6960,6989,7019,7048,7078,7107,7137,7166,7196,7225,7255,7284,7314,7344,7374,7403,7433,7462,7492,7521,7551,7580,7610,7639,7669,7698,7728,7757,7787,7816,7846,7875,7905,7934,7964,7993,8023,8053,8083,8112,8142,8171,8201,8230,8260,8289,8319,8348,8378,8407,8437,8466,8496,8525,8555,8584,8614,8643,8673,8702,8732,8761,8791,8821,8850,8880,8909,8938,8968,8997,9027,9056,9086,9115,9145,9175,9205,9234,9264,9293,9322,9352,9381,9410,9440,9470,9499,9529,9559,9589,9618,9648,9677,9706,9736,9765,9794,9824,9853,9883,9913,9943,9972,10002,10032,10061,10090,10120,10149,10178,10208,10237,10267,10297,10326,10356,10386,10415,10445,10474,10504,10533,10562,10592,10621,10651,10680,10710,10740,10770,10799,10829,10858,10888,10917,10947,10976,11005,11035,11064,11094,11124,11153,11183,11213,11242,11272,11301,11331,11360,11389,11419,11448,11478,11507,11537,11567,11596,11626,11655,11685,11715,11744,11774,11803,11832,11862,11891,11921,11950,11980,12010,12039,12069,12099,12128,12158,12187,12216,12246,12275,12304,12334,12364,12393,12423,12453,12483,12512,12542,12571,12600,12630,12659,12688,12718,12747,12777,12807,12837,12866,12896,12926,12955,12984,13014,13043,13072,13102,13131,13161,13191,13220,13250,13280,13310,13339,13368,13398,13427,13456,13486,13515,13545,13574,13604,13634,13664,13693,13723,13752,13782,13811,13840,13870,13899,13929,13958,13988,14018,14047,14077,14107,14136,14166,14195,14224,14254,14283,14313,14342,14372,14401,14431,14461,14490,14520,14550,14579,14609,14638,14667,14697,14726,14756,14785,14815,14844,14874,14904,14933,14963,14993,15021,15051,15081,15110,15140,15169,15199,15228,15258,15287,15317,15347,15377,15406,15436,15465,15494,15524,15553,15582,15612,15641,15671,15701,15731,15760,15790,15820,15849,15878,15908,15937,15966,15996,16025,16055,16085,16114,16144,16174,16204,16233,16262,16292,16321,16350,16380,16409,16439,16468,16498,16528,16558,16587,16617,16646,16676,16705,16734,16764,16793,16823,16852,16882,16912,16941,16971,17001,17030,17060,17089,17118,17148,17177,17207,17236,17266,17295,17325,17355,17384,17414,17444,17473,17502,17532,17561,17591,17620,17650,17679,17709,17738,17768,17798,17827,17857,17886,17916,17945,17975,18004,18034,18063,18093,18122,18152,18181,18211,18241,18270,18300,18330,18359,18388,18418,18447,18476,18506,18535,18565,18595,18625,18654,18684,18714,18743,18772,18802,18831,18860,18890,18919,18949,18979,19008,19038,19068,19098,19127,19156,19186,19215,19244,19274,19303,19333,19362,19392,19422,19452,19481,19511,19540,19570,19599,19628,19658,19687,19717,19746,19776,19806,19836,19865,19895,19924,19954,19983,20012,20042,20071,20101,20130,20160,20190,20219,20249,20279,20308,20338,20367,20396,20426,20455,20485,20514,20544,20573,20603,20633,20662,20692,20721,20751,20780,20810,20839,20869,20898,20928,20957,20987,21016,21046,21076,21105,21135,21164,21194,21223,21253,21282,21312,21341,21371,21400,21430,21459,21489,21519,21548,21578,21607,21637,21666,21696,21725,21754,21784,21813,21843,21873,21902,21932,21962,21991,22021,22050,22080,22109,22138,22168,22197,22227,22256,22286,22316,22346,22375,22405,22434,22464,22493,22522,22552,22581,22611,22640,22670,22700,22730,22759,22789,22818,22848,22877,22906,22936,22965,22994,23024,23054,23083,23113,23143,23173,23202,23232,23261,23290,23320,23349,23379,23408,23438,23467,23497,23527,23556,23586,23616,23645,23674,23704,23733,23763,23792,23822,23851,23881,23910,23940,23970,23999,24029,24058,24088,24117,24147,24176,24206,24235,24265,24294,24324,24353,24383,24413,24442,24472,24501,24531,24560,24590,24619,24648,24678,24707,24737,24767,24796,24826,24856,24885,24915,24944,24974,25003,25032,25062,25091,25121,25150,25180,25210,25240,25269,25299,25328,25358,25387,25416,25446,25475,25505,25534,25564,25594,25624,25653,25683,25712,25742,25771,25800,25830,25859,25888,25918,25948,25977,26007,26037,26067,26096,26126,26155,26184,26214,26243,26272,26302,26332,26361,26391,26421,26451,26480,26510,26539,26568,26598,26627,26656,26686,26715,26745,26775,26805,26834,26864,26893,26923,26952,26982,27011,27041,27070,27099,27129,27159,27188,27218,27248,27277,27307,27336,27366,27395,27425,27454,27484,27513,27542,27572,27602,27631,27661,27691,27720,27750,27779,27809,27838,27868,27897,27926,27956,27985,28015,28045,28074,28104,28134,28163,28193,28222,28252,28281,28310,28340,28369,28399,28428,28458,28488,28517,28547,28577,28607,28636,28665,28695,28724,28754,28783,28813,28843,28872,28901,28931,28960,28990,29019,29049,29078,29108,29137,29167,29196,29226,29255,29285,29315,29345,29375,29404,29434,29463,29492,29522,29551,29580,29610,29640,29669,29699,29729,29759,29788,29818,29847,29876,29906,29935,29964,29994,30023,30053,30082,30112,30141,30171,30200,30230,30259,30289,30318,30348,30378,30408,30437,30467,30496,30526,30555,30585,30614,30644,30673,30703,30732,30762,30791,30821,30850,30880,30909,30939,30968,30998,31027,31057,31086,31116,31145,31175,31204,31234,31263,31293,31322,31352,31381,31411,31441,31471,31500,31530,31559,31589,31618,31648,31676,31706,31736,31766,31795,31825,31854,31884,31913,31943,31972,32002,32031,32061,32090,32120,32150,32180,32209,32239,32268,32298,32327,32357,32386,32416,32445,32475,32504,32534,32563,32593,32622,32652,32681,32711,32740,32770,32799,32829,32858,32888,32917,32947,32976,33006,33035,33065,33094,33124,33153,33183,33213,33243,33272,33302,33331,33361,33390,33420,33450,33479,33509,33539,33568,33598,33627,33657,33686,33716,33745,33775,33804,33834,33863,33893,33922,33952,33981,34011,34040,34069,34099,34128,34158,34187,34217,34247,34277,34306,34336,34365,34395,34424,34454,34483,34512,34542,34571,34601,34631,34660,34690,34719,34749,34778,34808,34837,34867,34896,34926,34955,34985,35015,35044,35074,35103,35133,35162,35192,35222,35251,35280,35310,35340,35370,35399,35429,35458,35488,35517,35547,35576,35605,35635,35665,35694,35723,35753,35782,35811,35841,35871,35901,35930,35960,35989,36019,36048,36078,36107,36136,36166,36195,36225,36254,36284,36314,36343,36373,36403,36433,36462,36492,36521,36551,36580,36610,36639,36669,36698,36728,36757,36786,36816,36845,36875,36904,36934,36963,36993,37022,37052,37081,37111,37141,37170,37200,37229,37259,37288,37318,37347,37377,37406,37436,37465,37495,37524,37554,37584,37613,37643,37672,37701,37731,37760,37790,37819,37849,37878,37908,37938,37967,37997,38027,38056,38085,38115,38144,38174,38203,38233,38262,38292,38322,38351,38381,38410,38440,38469,38499,38528,38558,38587,38617,38646,38676,38705,38735,38764,38794,38823,38853,38882,38912,38941,38971,39001,39030,39059,39089,39118,39148,39178,39208,39237,39267,39297,39326,39355,39385,39414,39444,39473,39503,39532,39562,39592,39621,39650,39680,39709,39739,39768,39798,39827,39857,39886,39916,39946,39975,40005,40035,40064,40094,40123,40153,40182,40212,40241,40271,40300,40330,40359,40389,40418,40448,40477,40507,40536,40566,40595,40625,40655,40685,40714,40744,40773,40803,40832,40862,40892,40921,40951,40980,41009,41039,41068,41098,41127,41157,41186,41216,41245,41275,41304,41334,41364,41393,41422,41452,41481,41511,41540,41570,41599,41629,41658,41688,41718,41748,41777,41807,41836,41865,41894,41924,41953,41983,42012,42042,42072,42102,42131,42161,42190,42220,42249,42279,42308,42337,42367,42397,42426,42456,42485,42515,42545,42574,42604,42633,42662,42692,42721,42751,42780,42810,42839,42869,42899,42929,42958,42988,43017,43046,43076,43105,43135,43164,43194,43223,43253,43283,43312,43342,43371,43401,43430,43460,43489,43519,43548,43578,43607,43637,43666,43696,43726,43755,43785,43814,43844,43873,43903,43932,43962,43991,44021,44050,44080,44109,44139,44169,44198,44228,44258,44287,44317,44346,44375,44405,44434,44464,44493,44523,44553,44582,44612,44641,44671,44700,44730,44759,44788,44818,44847,44877,44906,44936,44966,44996,45025,45055,45084,45114,45143,45172,45202,45231,45261,45290,45320,45350,45380,45409,45439,45468,45498,45527,45556,45586,45615,45644,45674,45704,45733,45763,45793,45823,45852,45882,45911,45940,45970,45999,46028,46058,46088,46117,46147,46177,46206,46236,46265,46295,46324,46354,46383,46413,46442,46472,46501,46531,46560,46590,46620,46649,46679,46708,46738,46767,46797,46826,46856,46885,46915,46944,46974,47003,47033,47063,47092,47122,47151,47181,47210,47240,47269,47298,47328,47357,47387,47417,47446,47476,47506,47535,47565,47594,47624,47653,47682,47712,47741,47771,47800,47830,47860,47890,47919,47949,47978,48008,48037,48066,48096,48125,48155,48184,48214,48244,48273,48303,48333,48362,48392,48421,48450,48480,48509,48538,48568,48598,48627,48657,48687,48717,48746,48776,48805,48834,48864,48893,48922,48952,48982,49011,49041,49071,49100,49130,49160,49189,49218,49248,49277,49306,49336,49365,49395,49425,49455,49484,49514,49543,49573,49602,49632,49661,49690,49720,49749,49779,49809,49838,49868,49898,49927,49957,49986,50016,50045,50075,50104,50133,50163,50192,50222,50252,50281,50311,50340,50370,50400,50429,50459,50488,50518,50547,50576,50606,50635,50665,50694,50724,50754,50784,50813,50843,50872,50902,50931,50960,50990,51019,51049,51078,51108,51138,51167,51197,51227,51256,51286,51315,51345,51374,51403,51433,51462,51492,51522,51552,51582,51611,51641,51670,51699,51729,51758,51787,51816,51846,51876,51906,51936,51965,51995,52025,52054,52083,52113,52142,52171,52200,52230,52260,52290,52319,52349,52379,52408,52438,52467,52497,52526,52555,52585,52614,52644,52673,52703,52733,52762,52792,52822,52851,52881,52910,52939,52969,52998,53028,53057,53087,53116,53146,53176,53205,53235,53264,53294,53324,53353,53383,53412,53441,53471,53500,53530,53559,53589,53619,53648,53678,53708,53737,53767,53796,53825,53855,53884,53913,53943,53973,54003,54032,54062,54092,54121,54151,54180,54209,54239,54268,54297,54327,54357,54387,54416,54446,54476,54505,54535,54564,54593,54623,54652,54681,54711,54741,54770,54800,54830,54859,54889,54919,54948,54977,55007,55036,55066,55095,55125,55154,55184,55213,55243,55273,55302,55332,55361,55391,55420,55450,55479,55508,55538,55567,55597,55627,55657,55686,55716,55745,55775,55804,55834,55863,55892,55922,55951,55981,56011,56040,56070,56100,56129,56159,56188,56218,56247,56276,56306,56335,56365,56394,56424,56454,56483,56513,56543,56572,56601,56631,56660,56690,56719,56749,56778,56808,56837,56867,56897,56926,56956,56985,57015,57044,57074,57103,57133,57162,57192,57221,57251,57280,57310,57340,57369,57399,57429,57458,57487,57517,57546,57576,57605,57634,57664,57694,57723,57753,57783,57813,57842,57871,57901,57930,57959,57989,58018,58048,58077,58107,58137,58167,58196,58226,58255,58285,58314,58343,58373,58402,58432,58461,58491,58521,58551,58580,58610,58639,58669,58698,58727,58757,58786,58816,58845,58875,58905,58934,58964,58994,59023,59053,59082,59111,59141,59170,59200,59229,59259,59288,59318,59348,59377,59407,59436,59466,59495,59525,59554,59584,59613,59643,59672,59702,59731,59761,59791,59820,59850,59879,59909,59939,59968,59997,60027,60056,60086,60115,60145,60174,60204,60234,60264,60293,60323,60352,60381,60411,60440,60469,60499,60528,60558,60588,60618,60648,60677,60707,60736,60765,60795,60824,60853,60883,60912,60942,60972,61002,61031,61061,61090,61120,61149,61179,61208,61237,61267,61296,61326,61356,61385,61415,61445,61474,61504,61533,61563,61592,61621,61651,61680,61710,61739,61769,61799,61828,61858,61888,61917,61947,61976,62006,62035,62064,62094,62123,62153,62182,62212,62242,62271,62301,62331,62360,62390,62419,62448,62478,62507,62537,62566,62596,62625,62655,62685,62715,62744,62774,62803,62832,62862,62891,62921,62950,62980,63009,63039,63069,63099,63128,63157,63187,63216,63246,63275,63305,63334,63363,63393,63423,63453,63482,63512,63541,63571,63600,63630,63659,63689,63718,63747,63777,63807,63836,63866,63895,63925,63955,63984,64014,64043,64073,64102,64131,64161,64190,64220,64249,64279,64309,64339,64368,64398,64427,64457,64486,64515,64545,64574,64603,64633,64663,64692,64722,64752,64782,64811,64841,64870,64899,64929,64958,64987,65017,65047,65076,65106,65136,65166,65195,65225,65254,65283,65313,65342,65371,65401,65431,65460,65490,65520,65549,65579,65608,65638,65667,65697,65726,65755,65785,65815,65844,65874,65903,65933,65963,65992,66022,66051,66081,66110,66140,66169,66199,66228,66258,66287,66317,66346,66376,66405,66435,66465,66494,66524,66553,66583,66612,66641,66671,66700,66730,66760,66789,66819,66849,66878,66908,66937,66967,66996,67025,67055,67084,67114,67143,67173,67203,67233,67262,67292,67321,67351,67380,67409,67439,67468,67497,67527,67557,67587,67617,67646,67676,67705,67735,67764,67793,67823,67852,67882,67911,67941,67971,68e3,68030,68060,68089,68119,68148,68177,68207,68236,68266,68295,68325,68354,68384,68414,68443,68473,68502,68532,68561,68591,68620,68650,68679,68708,68738,68768,68797,68827,68857,68886,68916,68946,68975,69004,69034,69063,69092,69122,69152,69181,69211,69240,69270,69300,69330,69359,69388,69418,69447,69476,69506,69535,69565,69595,69624,69654,69684,69713,69743,69772,69802,69831,69861,69890,69919,69949,69978,70008,70038,70067,70097,70126,70156,70186,70215,70245,70274,70303,70333,70362,70392,70421,70451,70481,70510,70540,70570,70599,70629,70658,70687,70717,70746,70776,70805,70835,70864,70894,70924,70954,70983,71013,71042,71071,71101,71130,71159,71189,71218,71248,71278,71308,71337,71367,71397,71426,71455,71485,71514,71543,71573,71602,71632,71662,71691,71721,71751,71781,71810,71839,71869,71898,71927,71957,71986,72016,72046,72075,72105,72135,72164,72194,72223,72253,72282,72311,72341,72370,72400,72429,72459,72489,72518,72548,72577,72607,72637,72666,72695,72725,72754,72784,72813,72843,72872,72902,72931,72961,72991,73020,73050,73080,73109,73139,73168,73197,73227,73256,73286,73315,73345,73375,73404,73434,73464,73493,73523,73552,73581,73611,73640,73669,73699,73729,73758,73788,73818,73848,73877,73907,73936,73965,73995,74024,74053,74083,74113,74142,74172,74202,74231,74261,74291,74320,74349,74379,74408,74437,74467,74497,74526,74556,74586,74615,74645,74675,74704,74733,74763,74792,74822,74851,74881,74910,74940,74969,74999,75029,75058,75088,75117,75147,75176,75206,75235,75264,75294,75323,75353,75383,75412,75442,75472,75501,75531,75560,75590,75619,75648,75678,75707,75737,75766,75796,75826,75856,75885,75915,75944,75974,76003,76032,76062,76091,76121,76150,76180,76210,76239,76269,76299,76328,76358,76387,76416,76446,76475,76505,76534,76564,76593,76623,76653,76682,76712,76741,76771,76801,76830,76859,76889,76918,76948,76977,77007,77036,77066,77096,77125,77155,77185,77214,77243,77273,77302,77332,77361,77390,77420,77450,77479,77509,77539,77569,77598,77627,77657,77686,77715,77745,77774,77804,77833,77863,77893,77923,77952,77982,78011,78041,78070,78099,78129,78158,78188,78217,78247,78277,78307,78336,78366,78395,78425,78454,78483,78513,78542,78572,78601,78631,78661,78690,78720,78750,78779,78808,78838,78867,78897,78926,78956,78985,79015,79044,79074,79104,79133,79163,79192,79222,79251,79281,79310,79340,79369,79399,79428,79458,79487,79517,79546,79576,79606,79635,79665,79695,79724,79753,79783,79812,79841,79871,79900,79930,79960,79990]},{\"../main\":571,\"object-assign\":454}],571:[function(t,e,r){var n=t(\"object-assign\");function i(){this.regionalOptions=[],this.regionalOptions[\"\"]={invalidCalendar:\"Calendar {0} not found\",invalidDate:\"Invalid {0} date\",invalidMonth:\"Invalid {0} month\",invalidYear:\"Invalid {0} year\",differentCalendars:\"Cannot mix {0} and {1} dates\"},this.local=this.regionalOptions[\"\"],this.calendars={},this._localCals={}}function a(t,e,r,n){if(this._calendar=t,this._year=e,this._month=r,this._day=n,0===this._calendar._validateLevel&&!this._calendar.isValid(this._year,this._month,this._day))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name)}function o(t,e){return\"000000\".substring(0,e-(t=\"\"+t).length)+t}function s(){this.shortYearCutoff=\"+10\"}function l(t){this.local=this.regionalOptions[t]||this.regionalOptions[\"\"]}n(i.prototype,{instance:function(t,e){t=(t||\"gregorian\").toLowerCase(),e=e||\"\";var r=this._localCals[t+\"-\"+e];if(!r&&this.calendars[t]&&(r=new this.calendars[t](e),this._localCals[t+\"-\"+e]=r),!r)throw(this.local.invalidCalendar||this.regionalOptions[\"\"].invalidCalendar).replace(/\\{0\\}/,t);return r},newDate:function(t,e,r,n,i){return(n=(null!=t&&t.year?t.calendar():\"string\"==typeof n?this.instance(n,i):n)||this.instance()).newDate(t,e,r)},substituteDigits:function(t){return function(e){return(e+\"\").replace(/[0-9]/g,function(e){return t[e]})}},substituteChineseDigits:function(t,e){return function(r){for(var n=\"\",i=0;r>0;){var a=r%10;n=(0===a?\"\":t[a]+e[i])+n,i++,r=Math.floor(r/10)}return 0===n.indexOf(t[1]+e[1])&&(n=n.substr(1)),n||t[0]}}}),n(a.prototype,{newDate:function(t,e,r){return this._calendar.newDate(null==t?this:t,e,r)},year:function(t){return 0===arguments.length?this._year:this.set(t,\"y\")},month:function(t){return 0===arguments.length?this._month:this.set(t,\"m\")},day:function(t){return 0===arguments.length?this._day:this.set(t,\"d\")},date:function(t,e,r){if(!this._calendar.isValid(t,e,r))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name);return this._year=t,this._month=e,this._day=r,this},leapYear:function(){return this._calendar.leapYear(this)},epoch:function(){return this._calendar.epoch(this)},formatYear:function(){return this._calendar.formatYear(this)},monthOfYear:function(){return this._calendar.monthOfYear(this)},weekOfYear:function(){return this._calendar.weekOfYear(this)},daysInYear:function(){return this._calendar.daysInYear(this)},dayOfYear:function(){return this._calendar.dayOfYear(this)},daysInMonth:function(){return this._calendar.daysInMonth(this)},dayOfWeek:function(){return this._calendar.dayOfWeek(this)},weekDay:function(){return this._calendar.weekDay(this)},extraInfo:function(){return this._calendar.extraInfo(this)},add:function(t,e){return this._calendar.add(this,t,e)},set:function(t,e){return this._calendar.set(this,t,e)},compareTo:function(t){if(this._calendar.name!==t._calendar.name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this._calendar.local.name).replace(/\\{1\\}/,t._calendar.local.name);var e=this._year!==t._year?this._year-t._year:this._month!==t._month?this.monthOfYear()-t.monthOfYear():this._day-t._day;return 0===e?0:e<0?-1:1},calendar:function(){return this._calendar},toJD:function(){return this._calendar.toJD(this)},fromJD:function(t){return this._calendar.fromJD(t)},toJSDate:function(){return this._calendar.toJSDate(this)},fromJSDate:function(t){return this._calendar.fromJSDate(t)},toString:function(){return(this.year()<0?\"-\":\"\")+o(Math.abs(this.year()),4)+\"-\"+o(this.month(),2)+\"-\"+o(this.day(),2)}}),n(s.prototype,{_validateLevel:0,newDate:function(t,e,r){return null==t?this.today():(t.year&&(this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),r=t.day(),e=t.month(),t=t.year()),new a(this,t,e,r))},today:function(){return this.fromJSDate(new Date)},epoch:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear).year()<0?this.local.epochs[0]:this.local.epochs[1]},formatYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(e.year()<0?\"-\":\"\")+o(Math.abs(e.year()),4)},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear),12},monthOfYear:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return(r.month()+this.monthsInYear(r)-this.firstMonth)%this.monthsInYear(r)+this.minMonth},fromMonthOfYear:function(t,e){var r=(e+this.firstMonth-2*this.minMonth)%this.monthsInYear(t)+this.minMonth;return this._validate(t,r,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth),r},daysInYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return this.leapYear(e)?366:365},dayOfYear:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return n.toJD()-this.newDate(n.year(),this.fromMonthOfYear(n.year(),this.minMonth),this.minDay).toJD()+1},daysInWeek:function(){return 7},dayOfWeek:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return(Math.floor(this.toJD(n))+2)%this.daysInWeek()},extraInfo:function(t,e,r){return this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),{}},add:function(t,e,r){return this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),this._correctAdd(t,this._add(t,e,r),e,r)},_add:function(t,e,r){if(this._validateLevel++,\"d\"===r||\"w\"===r){var n=t.toJD()+e*(\"w\"===r?this.daysInWeek():1),i=t.calendar().fromJD(n);return this._validateLevel--,[i.year(),i.month(),i.day()]}try{var a=t.year()+(\"y\"===r?e:0),o=t.monthOfYear()+(\"m\"===r?e:0);i=t.day();\"y\"===r?(t.month()!==this.fromMonthOfYear(a,o)&&(o=this.newDate(a,t.month(),this.minDay).monthOfYear()),o=Math.min(o,this.monthsInYear(a)),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o)))):\"m\"===r&&(!function(t){for(;o<t.minMonth;)a--,o+=t.monthsInYear(a);for(var e=t.monthsInYear(a);o>e-1+t.minMonth;)a++,o-=e,e=t.monthsInYear(a)}(this),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o))));var s=[a,this.fromMonthOfYear(a,o),i];return this._validateLevel--,s}catch(t){throw this._validateLevel--,t}},_correctAdd:function(t,e,r,n){if(!(this.hasYearZero||\"y\"!==n&&\"m\"!==n||0!==e[0]&&t.year()>0==e[0]>0)){var i={y:[1,1,\"y\"],m:[1,this.monthsInYear(-1),\"m\"],w:[this.daysInWeek(),this.daysInYear(-1),\"d\"],d:[1,this.daysInYear(-1),\"d\"]}[n],a=r<0?-1:1;e=this._add(t,r*i[0]+a*i[1],i[2])}return t.date(e[0],e[1],e[2])},set:function(t,e,r){this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);var n=\"y\"===r?e:t.year(),i=\"m\"===r?e:t.month(),a=\"d\"===r?e:t.day();return\"y\"!==r&&\"m\"!==r||(a=Math.min(a,this.daysInMonth(n,i))),t.date(n,i,a)},isValid:function(t,e,r){this._validateLevel++;var n=this.hasYearZero||0!==t;if(n){var i=this.newDate(t,e,this.minDay);n=e>=this.minMonth&&e-this.minMonth<this.monthsInYear(i)&&r>=this.minDay&&r-this.minDay<this.daysInMonth(i)}return this._validateLevel--,n},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return c.instance().fromJD(this.toJD(n)).toJSDate()},fromJSDate:function(t){return this.fromJD(c.instance().fromJSDate(t).toJD())},_validate:function(t,e,r,n){if(t.year){if(0===this._validateLevel&&this.name!==t.calendar().name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this.local.name).replace(/\\{1\\}/,t.calendar().local.name);return t}try{if(this._validateLevel++,1===this._validateLevel&&!this.isValid(t,e,r))throw n.replace(/\\{0\\}/,this.local.name);var i=this.newDate(t,e,r);return this._validateLevel--,i}catch(t){throw this._validateLevel--,t}}}),l.prototype=new s,n(l.prototype,{name:\"Gregorian\",jdEpoch:1721425.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Gregorian\",epochs:[\"BCE\",\"CE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==0&&(t%100!=0||t%400==0)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);t=n.year(),e=n.month(),r=n.day(),t<0&&t++,e<3&&(e+=12,t--);var i=Math.floor(t/100),a=2-i+Math.floor(i/4);return Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r+a-1524.5},fromJD:function(t){var e=Math.floor(t+.5),r=Math.floor((e-1867216.25)/36524.25),n=(r=e+1+r-Math.floor(r/4))+1524,i=Math.floor((n-122.1)/365.25),a=Math.floor(365.25*i),o=Math.floor((n-a)/30.6001),s=n-a-Math.floor(30.6001*o),l=o-(o>13.5?13:1),c=i-(l>2.5?4716:4715);return c<=0&&c--,this.newDate(c,l,s)},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),i=new Date(n.year(),n.month()-1,n.day());return i.setHours(0),i.setMinutes(0),i.setSeconds(0),i.setMilliseconds(0),i.setHours(i.getHours()>12?i.getHours()+2:0),i},fromJSDate:function(t){return this.newDate(t.getFullYear(),t.getMonth()+1,t.getDate())}});var c=e.exports=new i;c.cdate=a,c.baseCalendar=s,c.calendars.gregorian=l},{\"object-assign\":454}],572:[function(t,e,r){var n=t(\"object-assign\"),i=t(\"./main\");n(i.regionalOptions[\"\"],{invalidArguments:\"Invalid arguments\",invalidFormat:\"Cannot format a date from another calendar\",missingNumberAt:\"Missing number at position {0}\",unknownNameAt:\"Unknown name at position {0}\",unexpectedLiteralAt:\"Unexpected literal at position {0}\",unexpectedText:\"Additional text found at end\"}),i.local=i.regionalOptions[\"\"],n(i.cdate.prototype,{formatDate:function(t,e){return\"string\"!=typeof t&&(e=t,t=\"\"),this._calendar.formatDate(t||\"\",this,e)}}),n(i.baseCalendar.prototype,{UNIX_EPOCH:i.instance().newDate(1970,1,1).toJD(),SECS_PER_DAY:86400,TICKS_EPOCH:i.instance().jdEpoch,TICKS_PER_DAY:864e9,ATOM:\"yyyy-mm-dd\",COOKIE:\"D, dd M yyyy\",FULL:\"DD, MM d, yyyy\",ISO_8601:\"yyyy-mm-dd\",JULIAN:\"J\",RFC_822:\"D, d M yy\",RFC_850:\"DD, dd-M-yy\",RFC_1036:\"D, d M yy\",RFC_1123:\"D, d M yyyy\",RFC_2822:\"D, d M yyyy\",RSS:\"D, d M yy\",TICKS:\"!\",TIMESTAMP:\"@\",W3C:\"yyyy-mm-dd\",formatDate:function(t,e,r){if(\"string\"!=typeof t&&(r=e,e=t,t=\"\"),!e)return\"\";if(e.calendar()!==this)throw i.local.invalidFormat||i.regionalOptions[\"\"].invalidFormat;t=t||this.local.dateFormat;for(var n,a,o,s,l=(r=r||{}).dayNamesShort||this.local.dayNamesShort,c=r.dayNames||this.local.dayNames,u=r.monthNumbers||this.local.monthNumbers,h=r.monthNamesShort||this.local.monthNamesShort,f=r.monthNames||this.local.monthNames,p=(r.calculateWeek||this.local.calculateWeek,function(e,r){for(var n=1;w+n<t.length&&t.charAt(w+n)===e;)n++;return w+=n-1,Math.floor(n/(r||1))>1}),d=function(t,e,r,n){var i=\"\"+e;if(p(t,n))for(;i.length<r;)i=\"0\"+i;return i},g=this,v=function(t){return\"function\"==typeof u?u.call(g,t,p(\"m\")):x(d(\"m\",t.month(),2))},m=function(t,e){return e?\"function\"==typeof f?f.call(g,t):f[t.month()-g.minMonth]:\"function\"==typeof h?h.call(g,t):h[t.month()-g.minMonth]},y=this.local.digits,x=function(t){return r.localNumbers&&y?y(t):t},b=\"\",_=!1,w=0;w<t.length;w++)if(_)\"'\"!==t.charAt(w)||p(\"'\")?b+=t.charAt(w):_=!1;else switch(t.charAt(w)){case\"d\":b+=x(d(\"d\",e.day(),2));break;case\"D\":b+=(n=\"D\",a=e.dayOfWeek(),o=l,s=c,p(n)?s[a]:o[a]);break;case\"o\":b+=d(\"o\",e.dayOfYear(),3);break;case\"w\":b+=d(\"w\",e.weekOfYear(),2);break;case\"m\":b+=v(e);break;case\"M\":b+=m(e,p(\"M\"));break;case\"y\":b+=p(\"y\",2)?e.year():(e.year()%100<10?\"0\":\"\")+e.year()%100;break;case\"Y\":p(\"Y\",2),b+=e.formatYear();break;case\"J\":b+=e.toJD();break;case\"@\":b+=(e.toJD()-this.UNIX_EPOCH)*this.SECS_PER_DAY;break;case\"!\":b+=(e.toJD()-this.TICKS_EPOCH)*this.TICKS_PER_DAY;break;case\"'\":p(\"'\")?b+=\"'\":_=!0;break;default:b+=t.charAt(w)}return b},parseDate:function(t,e,r){if(null==e)throw i.local.invalidArguments||i.regionalOptions[\"\"].invalidArguments;if(\"\"===(e=\"object\"==typeof e?e.toString():e+\"\"))return null;t=t||this.local.dateFormat;var n=(r=r||{}).shortYearCutoff||this.shortYearCutoff;n=\"string\"!=typeof n?n:this.today().year()%100+parseInt(n,10);for(var a=r.dayNamesShort||this.local.dayNamesShort,o=r.dayNames||this.local.dayNames,s=r.parseMonth||this.local.parseMonth,l=r.monthNumbers||this.local.monthNumbers,c=r.monthNamesShort||this.local.monthNamesShort,u=r.monthNames||this.local.monthNames,h=-1,f=-1,p=-1,d=-1,g=-1,v=!1,m=!1,y=function(e,r){for(var n=1;M+n<t.length&&t.charAt(M+n)===e;)n++;return M+=n-1,Math.floor(n/(r||1))>1},x=function(t,r){var n=y(t,r),a=[2,3,n?4:2,n?4:2,10,11,20][\"oyYJ@!\".indexOf(t)+1],o=new RegExp(\"^-?\\\\d{1,\"+a+\"}\"),s=e.substring(A).match(o);if(!s)throw(i.local.missingNumberAt||i.regionalOptions[\"\"].missingNumberAt).replace(/\\{0\\}/,A);return A+=s[0].length,parseInt(s[0],10)},b=this,_=function(){if(\"function\"==typeof l){y(\"m\");var t=l.call(b,e.substring(A));return A+=t.length,t}return x(\"m\")},w=function(t,r,n,a){for(var o=y(t,a)?n:r,s=0;s<o.length;s++)if(e.substr(A,o[s].length).toLowerCase()===o[s].toLowerCase())return A+=o[s].length,s+b.minMonth;throw(i.local.unknownNameAt||i.regionalOptions[\"\"].unknownNameAt).replace(/\\{0\\}/,A)},k=function(){if(\"function\"==typeof u){var t=y(\"M\")?u.call(b,e.substring(A)):c.call(b,e.substring(A));return A+=t.length,t}return w(\"M\",c,u)},T=function(){if(e.charAt(A)!==t.charAt(M))throw(i.local.unexpectedLiteralAt||i.regionalOptions[\"\"].unexpectedLiteralAt).replace(/\\{0\\}/,A);A++},A=0,M=0;M<t.length;M++)if(m)\"'\"!==t.charAt(M)||y(\"'\")?T():m=!1;else switch(t.charAt(M)){case\"d\":d=x(\"d\");break;case\"D\":w(\"D\",a,o);break;case\"o\":g=x(\"o\");break;case\"w\":x(\"w\");break;case\"m\":p=_();break;case\"M\":p=k();break;case\"y\":var S=M;v=!y(\"y\",2),M=S,f=x(\"y\",2);break;case\"Y\":f=x(\"Y\",2);break;case\"J\":h=x(\"J\")+.5,\".\"===e.charAt(A)&&(A++,x(\"J\"));break;case\"@\":h=x(\"@\")/this.SECS_PER_DAY+this.UNIX_EPOCH;break;case\"!\":h=x(\"!\")/this.TICKS_PER_DAY+this.TICKS_EPOCH;break;case\"*\":A=e.length;break;case\"'\":y(\"'\")?T():m=!0;break;default:T()}if(A<e.length)throw i.local.unexpectedText||i.regionalOptions[\"\"].unexpectedText;if(-1===f?f=this.today().year():f<100&&v&&(f+=-1===n?1900:this.today().year()-this.today().year()%100-(f<=n?0:100)),\"string\"==typeof p&&(p=s.call(this,f,p)),g>-1){p=1,d=g;for(var E=this.daysInMonth(f,p);d>E;E=this.daysInMonth(f,p))p++,d-=E}return h>-1?this.fromJD(h):this.newDate(f,p,d)},determineDate:function(t,e,r,n,i){r&&\"object\"!=typeof r&&(i=n,n=r,r=null),\"string\"!=typeof n&&(i=n,n=\"\");var a=this;return e=e?e.newDate():null,t=null==t?e:\"string\"==typeof t?function(t){try{return a.parseDate(n,t,i)}catch(t){}for(var e=((t=t.toLowerCase()).match(/^c/)&&r?r.newDate():null)||a.today(),o=/([+-]?[0-9]+)\\s*(d|w|m|y)?/g,s=o.exec(t);s;)e.add(parseInt(s[1],10),s[2]||\"d\"),s=o.exec(t);return e}(t):\"number\"==typeof t?isNaN(t)||t===1/0||t===-1/0?e:a.today().add(t,\"d\"):a.newDate(t)}})},{\"./main\":571,\"object-assign\":454}],573:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",{offset:[1],array:0},\"scalar\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\n        var _inline_1_da = _inline_1_arg0_ - _inline_1_arg3_\\n        var _inline_1_db = _inline_1_arg1_ - _inline_1_arg3_\\n        if((_inline_1_da >= 0) !== (_inline_1_db >= 0)) {\\n          _inline_1_arg2_.push(_inline_1_arg4_[0] + 0.5 + 0.5 * (_inline_1_da + _inline_1_db) / (_inline_1_da - _inline_1_db))\\n        }\\n      }\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg3_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[\"_inline_1_da\",\"_inline_1_db\"]},funcName:\"zeroCrossings\"})},{\"cwise-compiler\":146}],574:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=[];return e=+e||0,n(t.hi(t.shape[0]-1),r,e),r};var n=t(\"./lib/zc-core\")},{\"./lib/zc-core\":573}],575:[function(t,e,r){\"use strict\";e.exports=[{path:\"\",backoff:0},{path:\"M-2.4,-3V3L0.6,0Z\",backoff:.6},{path:\"M-3.7,-2.5V2.5L1.3,0Z\",backoff:1.3},{path:\"M-4.45,-3L-1.65,-0.2V0.2L-4.45,3L1.55,0Z\",backoff:1.55},{path:\"M-2.2,-2.2L-0.2,-0.2V0.2L-2.2,2.2L-1.4,3L1.6,0L-1.4,-3Z\",backoff:1.6},{path:\"M-4.4,-2.1L-0.6,-0.2V0.2L-4.4,2.1L-4,3L2,0L-4,-3Z\",backoff:2},{path:\"M2,0A2,2 0 1,1 0,-2A2,2 0 0,1 2,0Z\",backoff:0,noRotate:!0},{path:\"M2,2V-2H-2V2Z\",backoff:0,noRotate:!0}]},{}],576:[function(t,e,r){\"use strict\";var n=t(\"./arrow_paths\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../plots/cartesian/constants\"),o=t(\"../../plot_api/plot_template\").templatedArray;e.exports=o(\"annotation\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},text:{valType:\"string\",editType:\"calc+arraydraw\"},textangle:{valType:\"angle\",dflt:0,editType:\"calc+arraydraw\"},font:i({editType:\"calc+arraydraw\",colorEditType:\"arraydraw\"}),width:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},height:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"center\",editType:\"arraydraw\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"arraydraw\"},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},borderpad:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},showarrow:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},arrowcolor:{valType:\"color\",editType:\"arraydraw\"},arrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},startarrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},arrowside:{valType:\"flaglist\",flags:[\"end\",\"start\"],extras:[\"none\"],dflt:\"end\",editType:\"arraydraw\"},arrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},startarrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},arrowwidth:{valType:\"number\",min:.1,editType:\"calc+arraydraw\"},standoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},startstandoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},ax:{valType:\"any\",editType:\"calc+arraydraw\"},ay:{valType:\"any\",editType:\"calc+arraydraw\"},axref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.x.toString()],editType:\"calc\"},ayref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.y.toString()],editType:\"calc\"},xref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.x.toString()],editType:\"calc\"},x:{valType:\"any\",editType:\"calc+arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"auto\",editType:\"calc+arraydraw\"},xshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.y.toString()],editType:\"calc\"},y:{valType:\"any\",editType:\"calc+arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"calc+arraydraw\"},yshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},clicktoshow:{valType:\"enumerated\",values:[!1,\"onoff\",\"onout\"],dflt:!1,editType:\"arraydraw\"},xclick:{valType:\"any\",editType:\"arraydraw\"},yclick:{valType:\"any\",editType:\"arraydraw\"},hovertext:{valType:\"string\",editType:\"arraydraw\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",editType:\"arraydraw\"},font:i({editType:\"arraydraw\"}),editType:\"arraydraw\"},captureevents:{valType:\"boolean\",editType:\"arraydraw\"},editType:\"calc\",_deprecated:{ref:{valType:\"string\",editType:\"calc\"}}})},{\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773,\"../../plots/font_attributes\":793,\"./arrow_paths\":575}],577:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./draw\").draw;function o(t){var e=t._fullLayout;n.filterVisible(e.annotations).forEach(function(e){var r=i.getFromId(t,e.xref),n=i.getFromId(t,e.yref);e._extremes={},r&&s(e,r),n&&s(e,n)})}function s(t,e){var r,n=e._id,a=n.charAt(0),o=t[a],s=t[\"a\"+a],l=t[a+\"ref\"],c=t[\"a\"+a+\"ref\"],u=t[\"_\"+a+\"padplus\"],h=t[\"_\"+a+\"padminus\"],f={x:1,y:-1}[a]*t[a+\"shift\"],p=3*t.arrowsize*t.arrowwidth||0,d=p+f,g=p-f,v=3*t.startarrowsize*t.arrowwidth||0,m=v+f,y=v-f;if(c===l){var x=i.findExtremes(e,[e.r2c(o)],{ppadplus:d,ppadminus:g}),b=i.findExtremes(e,[e.r2c(s)],{ppadplus:Math.max(u,m),ppadminus:Math.max(h,y)});r={min:[x.min[0],b.min[0]],max:[x.max[0],b.max[0]]}}else m=s?m+s:m,y=s?y-s:y,r=i.findExtremes(e,[e.r2c(o)],{ppadplus:Math.max(u,d,m),ppadminus:Math.max(h,g,y)});t._extremes[n]=r}e.exports=function(t){var e=t._fullLayout;if(n.filterVisible(e.annotations).length&&t._fullData.length)return n.syncOrAsync([a,o],t)}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./draw\":582}],578:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../plot_api/plot_template\").arrayEditor;function o(t,e){var r,n,i,a,o,l,c,u=t._fullLayout.annotations,h=[],f=[],p=[],d=(e||[]).length;for(r=0;r<u.length;r++)if(a=(i=u[r]).clicktoshow){for(n=0;n<d;n++)if(l=(o=e[n]).xaxis,c=o.yaxis,l._id===i.xref&&c._id===i.yref&&l.d2r(o.x)===s(i._xclick,l)&&c.d2r(o.y)===s(i._yclick,c)){(i.visible?\"onout\"===a?f:p:h).push(r);break}n===d&&i.visible&&\"onout\"===a&&f.push(r)}return{on:h,off:f,explicitOff:p}}function s(t,e){return\"log\"===e.type?e.l2r(t):e.d2r(t)}e.exports={hasClickToShow:function(t,e){var r=o(t,e);return r.on.length>0||r.explicitOff.length>0},onClick:function(t,e){var r,s,l=o(t,e),c=l.on,u=l.off.concat(l.explicitOff),h={},f=t._fullLayout.annotations;if(!c.length&&!u.length)return;for(r=0;r<c.length;r++)(s=a(t.layout,\"annotations\",f[c[r]])).modifyItem(\"visible\",!0),n.extendFlat(h,s.getUpdateObj());for(r=0;r<u.length;r++)(s=a(t.layout,\"annotations\",f[u[r]])).modifyItem(\"visible\",!1),n.extendFlat(h,s.getUpdateObj());return i.call(\"update\",t,{},h)}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../registry\":847}],579:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\");e.exports=function(t,e,r,a){a(\"opacity\");var o=a(\"bgcolor\"),s=a(\"bordercolor\"),l=i.opacity(s);a(\"borderpad\");var c=a(\"borderwidth\"),u=a(\"showarrow\");if(a(\"text\",u?\" \":r._dfltTitle.annotation),a(\"textangle\"),n.coerceFont(a,\"font\",r.font),a(\"width\"),a(\"align\"),a(\"height\")&&a(\"valign\"),u){var h,f,p=a(\"arrowside\");-1!==p.indexOf(\"end\")&&(h=a(\"arrowhead\"),f=a(\"arrowsize\")),-1!==p.indexOf(\"start\")&&(a(\"startarrowhead\",h),a(\"startarrowsize\",f)),a(\"arrowcolor\",l?e.bordercolor:i.defaultLine),a(\"arrowwidth\",2*(l&&c||1)),a(\"standoff\"),a(\"startstandoff\")}var d=a(\"hovertext\"),g=r.hoverlabel||{};if(d){var v=a(\"hoverlabel.bgcolor\",g.bgcolor||(i.opacity(o)?i.rgb(o):i.defaultLine)),m=a(\"hoverlabel.bordercolor\",g.bordercolor||i.contrast(v));n.coerceFont(a,\"hoverlabel.font\",{family:g.font.family,size:g.font.size,color:g.font.color||m})}a(\"captureevents\",!!d)}},{\"../../lib\":719,\"../color\":593}],580:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.annotations,h=e._id.charAt(0),f=0;f<u.length;f++)l=u[f],c=\"annotations[\"+f+\"].\",l[h+\"ref\"]===e._id&&p(h),l[\"a\"+h+\"ref\"]===e._id&&p(\"a\"+h);function p(t){var r=l[t],s=null;s=o?i(r,e.range):Math.pow(10,r),n(s)||(s=null),a(c+t,s)}}},{\"../../lib/to_log_range\":745,\"fast-isnumeric\":225}],581:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./common_defaults\"),s=t(\"./attributes\");function l(t,e,r){function a(r,i){return n.coerce(t,e,s,r,i)}var l=a(\"visible\"),c=a(\"clicktoshow\");if(l||c){o(t,e,r,a);for(var u=e.showarrow,h=[\"x\",\"y\"],f=[-10,-30],p={_fullLayout:r},d=0;d<2;d++){var g=h[d],v=i.coerceRef(t,e,p,g,\"\",\"paper\");if(\"paper\"!==v)i.getFromId(p,v)._annIndices.push(e._index);if(i.coercePosition(e,p,a,v,g,.5),u){var m=\"a\"+g,y=i.coerceRef(t,e,p,m,\"pixel\");\"pixel\"!==y&&y!==v&&(y=e[m]=\"pixel\");var x=\"pixel\"===y?f[d]:.4;i.coercePosition(e,p,a,y,m,x)}a(g+\"anchor\"),a(g+\"shift\")}if(n.noneOrAll(t,e,[\"x\",\"y\"]),u&&n.noneOrAll(t,e,[\"ax\",\"ay\"]),c){var b=a(\"xclick\"),_=a(\"yclick\");e._xclick=void 0===b?e.x:i.cleanPosition(b,p,e.xref),e._yclick=void 0===_?e.y:i.cleanPosition(_,p,e.yref)}}}e.exports=function(t,e){a(t,e,{name:\"annotations\",handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"./attributes\":576,\"./common_defaults\":579}],582:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../color\"),c=t(\"../drawing\"),u=t(\"../fx\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"../../lib/setcursor\"),p=t(\"../dragelement\"),d=t(\"../../plot_api/plot_template\").arrayEditor,g=t(\"./draw_arrow_head\");function v(t,e){var r=t._fullLayout.annotations[e]||{},n=s.getFromId(t,r.xref),i=s.getFromId(t,r.yref);n&&n.setScale(),i&&i.setScale(),m(t,r,e,!1,n,i)}function m(t,e,r,a,s,v){var m,y,x=t._fullLayout,b=t._fullLayout._size,_=t._context.edits;a?(m=\"annotation-\"+a,y=a+\".annotations\"):(m=\"annotation\",y=\"annotations\");var w=d(t.layout,y,e),k=w.modifyBase,T=w.modifyItem,A=w.getUpdateObj;x._infolayer.selectAll(\".\"+m+'[data-index=\"'+r+'\"]').remove();var M=\"clip\"+x._uid+\"_ann\"+r;if(e._input&&!1!==e.visible){var S={x:{},y:{}},E=+e.textangle||0,C=x._infolayer.append(\"g\").classed(m,!0).attr(\"data-index\",String(r)).style(\"opacity\",e.opacity),L=C.append(\"g\").classed(\"annotation-text-g\",!0),P=_[e.showarrow?\"annotationTail\":\"annotationPosition\"],O=e.captureevents||_.annotationText||P,z=L.append(\"g\").style(\"pointer-events\",O?\"all\":null).call(f,\"pointer\").on(\"click\",function(){t._dragging=!1,t.emit(\"plotly_clickannotation\",q(n.event))});e.hovertext&&z.on(\"mouseover\",function(){var r=e.hoverlabel,n=r.font,i=this.getBoundingClientRect(),a=t.getBoundingClientRect();u.loneHover({x0:i.left-a.left,x1:i.right-a.left,y:(i.top+i.bottom)/2-a.top,text:e.hovertext,color:r.bgcolor,borderColor:r.bordercolor,fontFamily:n.family,fontSize:n.size,fontColor:n.color},{container:x._hoverlayer.node(),outerContainer:x._paper.node(),gd:t})}).on(\"mouseout\",function(){u.loneUnhover(x._hoverlayer.node())});var I=e.borderwidth,D=e.borderpad,R=I+D,F=z.append(\"rect\").attr(\"class\",\"bg\").style(\"stroke-width\",I+\"px\").call(l.stroke,e.bordercolor).call(l.fill,e.bgcolor),B=e.width||e.height,N=x._topclips.selectAll(\"#\"+M).data(B?[0]:[]);N.enter().append(\"clipPath\").classed(\"annclip\",!0).attr(\"id\",M).append(\"rect\"),N.exit().remove();var j=e.font,U=x._meta?o.templateString(e.text,x._meta):e.text,V=z.append(\"text\").classed(\"annotation-text\",!0).text(U);_.annotationText?V.call(h.makeEditable,{delegate:z,gd:t}).call(H).on(\"edit\",function(r){e.text=r,this.call(H),T(\"text\",r),s&&s.autorange&&k(s._name+\".autorange\",!0),v&&v.autorange&&k(v._name+\".autorange\",!0),i.call(\"_guiRelayout\",t,A())}):V.call(H)}else n.selectAll(\"#\"+M).remove();function q(t){var n={index:r,annotation:e._input,fullAnnotation:e,event:t};return a&&(n.subplotId=a),n}function H(r){return r.call(c.font,j).attr({\"text-anchor\":{left:\"start\",right:\"end\"}[e.align]||\"middle\"}),h.convertToTspans(r,t,G),r}function G(){var r=V.selectAll(\"a\");1===r.size()&&r.text()===V.text()&&z.insert(\"a\",\":first-child\").attr({\"xlink:xlink:href\":r.attr(\"xlink:href\"),\"xlink:xlink:show\":r.attr(\"xlink:show\")}).style({cursor:\"pointer\"}).node().appendChild(F.node());var n=z.select(\".annotation-text-math-group\"),u=!n.empty(),d=c.bBox((u?n:V).node()),m=d.width,y=d.height,w=e.width||m,O=e.height||y,D=Math.round(w+2*R),j=Math.round(O+2*R);function U(t,e){return\"auto\"===e&&(e=t<1/3?\"left\":t>2/3?\"right\":\"center\"),{center:0,middle:0,left:.5,bottom:-.5,right:-.5,top:.5}[e]}for(var H=!1,G=[\"x\",\"y\"],Y=0;Y<G.length;Y++){var W,X,Z,J,K,$=G[Y],Q=e[$+\"ref\"]||$,tt=e[\"a\"+$+\"ref\"],et={x:s,y:v}[$],rt=(E+(\"x\"===$?0:-90))*Math.PI/180,nt=D*Math.cos(rt),it=j*Math.sin(rt),at=Math.abs(nt)+Math.abs(it),ot=e[$+\"anchor\"],st=e[$+\"shift\"]*(\"x\"===$?1:-1),lt=S[$];if(et){var ct=et.r2fraction(e[$]);(ct<0||ct>1)&&(tt===Q?((ct=et.r2fraction(e[\"a\"+$]))<0||ct>1)&&(H=!0):H=!0),W=et._offset+et.r2p(e[$]),J=.5}else\"x\"===$?(Z=e[$],W=b.l+b.w*Z):(Z=1-e[$],W=b.t+b.h*Z),J=e.showarrow?.5:Z;if(e.showarrow){lt.head=W;var ut=e[\"a\"+$];K=nt*U(.5,e.xanchor)-it*U(.5,e.yanchor),tt===Q?(lt.tail=et._offset+et.r2p(ut),X=K):(lt.tail=W+ut,X=K+ut),lt.text=lt.tail+K;var ht=x[\"x\"===$?\"width\":\"height\"];if(\"paper\"===Q&&(lt.head=o.constrain(lt.head,1,ht-1)),\"pixel\"===tt){var ft=-Math.max(lt.tail-3,lt.text),pt=Math.min(lt.tail+3,lt.text)-ht;ft>0?(lt.tail+=ft,lt.text+=ft):pt>0&&(lt.tail-=pt,lt.text-=pt)}lt.tail+=st,lt.head+=st}else X=K=at*U(J,ot),lt.text=W+K;lt.text+=st,K+=st,X+=st,e[\"_\"+$+\"padplus\"]=at/2+X,e[\"_\"+$+\"padminus\"]=at/2-X,e[\"_\"+$+\"size\"]=at,e[\"_\"+$+\"shift\"]=K}if(t._dragging||!H){var dt=0,gt=0;if(\"left\"!==e.align&&(dt=(w-m)*(\"center\"===e.align?.5:1)),\"top\"!==e.valign&&(gt=(O-y)*(\"middle\"===e.valign?.5:1)),u)n.select(\"svg\").attr({x:R+dt-1,y:R+gt}).call(c.setClipUrl,B?M:null,t);else{var vt=R+gt-d.top,mt=R+dt-d.left;V.call(h.positionText,mt,vt).call(c.setClipUrl,B?M:null,t)}N.select(\"rect\").call(c.setRect,R,R,w,O),F.call(c.setRect,I/2,I/2,D-I,j-I),z.call(c.setTranslate,Math.round(S.x.text-D/2),Math.round(S.y.text-j/2)),L.attr({transform:\"rotate(\"+E+\",\"+S.x.text+\",\"+S.y.text+\")\"});var yt,xt=function(r,n){C.selectAll(\".annotation-arrow-g\").remove();var u=S.x.head,h=S.y.head,f=S.x.tail+r,d=S.y.tail+n,m=S.x.text+r,y=S.y.text+n,x=o.rotationXYMatrix(E,m,y),w=o.apply2DTransform(x),M=o.apply2DTransform2(x),P=+F.attr(\"width\"),O=+F.attr(\"height\"),I=m-.5*P,D=I+P,R=y-.5*O,B=R+O,N=[[I,R,I,B],[I,B,D,B],[D,B,D,R],[D,R,I,R]].map(M);if(!N.reduce(function(t,e){return t^!!o.segmentsIntersect(u,h,u+1e6,h+1e6,e[0],e[1],e[2],e[3])},!1)){N.forEach(function(t){var e=o.segmentsIntersect(f,d,u,h,t[0],t[1],t[2],t[3]);e&&(f=e.x,d=e.y)});var j=e.arrowwidth,U=e.arrowcolor,V=e.arrowside,q=C.append(\"g\").style({opacity:l.opacity(U)}).classed(\"annotation-arrow-g\",!0),H=q.append(\"path\").attr(\"d\",\"M\"+f+\",\"+d+\"L\"+u+\",\"+h).style(\"stroke-width\",j+\"px\").call(l.stroke,l.rgb(U));if(g(H,V,e),_.annotationPosition&&H.node().parentNode&&!a){var G=u,Y=h;if(e.standoff){var W=Math.sqrt(Math.pow(u-f,2)+Math.pow(h-d,2));G+=e.standoff*(f-u)/W,Y+=e.standoff*(d-h)/W}var X,Z,J=q.append(\"path\").classed(\"annotation-arrow\",!0).classed(\"anndrag\",!0).classed(\"cursor-move\",!0).attr({d:\"M3,3H-3V-3H3ZM0,0L\"+(f-G)+\",\"+(d-Y),transform:\"translate(\"+G+\",\"+Y+\")\"}).style(\"stroke-width\",j+6+\"px\").call(l.stroke,\"rgba(0,0,0,0)\").call(l.fill,\"rgba(0,0,0,0)\");p.init({element:J.node(),gd:t,prepFn:function(){var t=c.getTranslate(z);X=t.x,Z=t.y,s&&s.autorange&&k(s._name+\".autorange\",!0),v&&v.autorange&&k(v._name+\".autorange\",!0)},moveFn:function(t,r){var n=w(X,Z),i=n[0]+t,a=n[1]+r;z.call(c.setTranslate,i,a),T(\"x\",s?s.p2r(s.r2p(e.x)+t):e.x+t/b.w),T(\"y\",v?v.p2r(v.r2p(e.y)+r):e.y-r/b.h),e.axref===e.xref&&T(\"ax\",s.p2r(s.r2p(e.ax)+t)),e.ayref===e.yref&&T(\"ay\",v.p2r(v.r2p(e.ay)+r)),q.attr(\"transform\",\"translate(\"+t+\",\"+r+\")\"),L.attr({transform:\"rotate(\"+E+\",\"+i+\",\"+a+\")\"})},doneFn:function(){i.call(\"_guiRelayout\",t,A());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}}};if(e.showarrow&&xt(0,0),P)p.init({element:z.node(),gd:t,prepFn:function(){yt=L.attr(\"transform\")},moveFn:function(t,r){var n=\"pointer\";if(e.showarrow)e.axref===e.xref?T(\"ax\",s.p2r(s.r2p(e.ax)+t)):T(\"ax\",e.ax+t),e.ayref===e.yref?T(\"ay\",v.p2r(v.r2p(e.ay)+r)):T(\"ay\",e.ay+r),xt(t,r);else{if(a)return;var i,o;if(s)i=s.p2r(s.r2p(e.x)+t);else{var l=e._xsize/b.w,c=e.x+(e._xshift-e.xshift)/b.w-l/2;i=p.align(c+t/b.w,l,0,1,e.xanchor)}if(v)o=v.p2r(v.r2p(e.y)+r);else{var u=e._ysize/b.h,h=e.y-(e._yshift+e.yshift)/b.h-u/2;o=p.align(h-r/b.h,u,0,1,e.yanchor)}T(\"x\",i),T(\"y\",o),s&&v||(n=p.getCursor(s?.5:i,v?.5:o,e.xanchor,e.yanchor))}L.attr({transform:\"translate(\"+t+\",\"+r+\")\"+yt}),f(z,n)},clickFn:function(r,n){e.captureevents&&t.emit(\"plotly_clickannotation\",q(n))},doneFn:function(){f(z),i.call(\"_guiRelayout\",t,A());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}else z.remove()}}e.exports={draw:function(t){var e=t._fullLayout;e._infolayer.selectAll(\".annotation\").remove();for(var r=0;r<e.annotations.length;r++)e.annotations[r].visible&&v(t,r);return a.previousPromises(t)},drawOne:v,drawRaw:m}},{\"../../lib\":719,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/axes\":767,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"../fx\":632,\"./draw_arrow_head\":583,d3:163}],583:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\"),a=t(\"./arrow_paths\");e.exports=function(t,e,r){var o,s,l,c,u=t.node(),h=a[r.arrowhead||0],f=a[r.startarrowhead||0],p=(r.arrowwidth||1)*(r.arrowsize||1),d=(r.arrowwidth||1)*(r.startarrowsize||1),g=e.indexOf(\"start\")>=0,v=e.indexOf(\"end\")>=0,m=h.backoff*p+r.standoff,y=f.backoff*d+r.startstandoff;if(\"line\"===u.nodeName){o={x:+t.attr(\"x1\"),y:+t.attr(\"y1\")},s={x:+t.attr(\"x2\"),y:+t.attr(\"y2\")};var x=o.x-s.x,b=o.y-s.y;if(c=(l=Math.atan2(b,x))+Math.PI,m&&y&&m+y>Math.sqrt(x*x+b*b))return void P();if(m){if(m*m>x*x+b*b)return void P();var _=m*Math.cos(l),w=m*Math.sin(l);s.x+=_,s.y+=w,t.attr({x2:s.x,y2:s.y})}if(y){if(y*y>x*x+b*b)return void P();var k=y*Math.cos(l),T=y*Math.sin(l);o.x-=k,o.y-=T,t.attr({x1:o.x,y1:o.y})}}else if(\"path\"===u.nodeName){var A=u.getTotalLength(),M=\"\";if(A<m+y)return void P();var S=u.getPointAtLength(0),E=u.getPointAtLength(.1);l=Math.atan2(S.y-E.y,S.x-E.x),o=u.getPointAtLength(Math.min(y,A)),M=\"0px,\"+y+\"px,\";var C=u.getPointAtLength(A),L=u.getPointAtLength(A-.1);c=Math.atan2(C.y-L.y,C.x-L.x),s=u.getPointAtLength(Math.max(0,A-m)),M+=A-(M?y+m:m)+\"px,\"+A+\"px\",t.style(\"stroke-dasharray\",M)}function P(){t.style(\"stroke-dasharray\",\"0px,100px\")}function O(e,a,o,s){e.path&&(e.noRotate&&(o=0),n.select(u.parentNode).append(\"path\").attr({class:t.attr(\"class\"),d:e.path,transform:\"translate(\"+a.x+\",\"+a.y+\")\"+(o?\"rotate(\"+180*o/Math.PI+\")\":\"\")+\"scale(\"+s+\")\"}).style({fill:i.rgb(r.arrowcolor),\"stroke-width\":0}))}g&&O(f,o,l,d),v&&O(h,s,c,p)}},{\"../color\":593,\"./arrow_paths\":575,d3:163}],584:[function(t,e,r){\"use strict\";var n=t(\"./draw\"),i=t(\"./click\");e.exports={moduleType:\"component\",name:\"annotations\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"annotations\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne,drawRaw:n.drawRaw,hasClickToShow:i.hasClickToShow,onClick:i.onClick,convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":777,\"./attributes\":576,\"./calc_autorange\":577,\"./click\":578,\"./convert_coords\":580,\"./defaults\":581,\"./draw\":582}],585:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"../../plot_api/plot_template\").templatedArray;e.exports=i(a(\"annotation\",{visible:n.visible,x:{valType:\"any\"},y:{valType:\"any\"},z:{valType:\"any\"},ax:{valType:\"number\"},ay:{valType:\"number\"},xanchor:n.xanchor,xshift:n.xshift,yanchor:n.yanchor,yshift:n.yshift,text:n.text,textangle:n.textangle,font:n.font,width:n.width,height:n.height,opacity:n.opacity,align:n.align,valign:n.valign,bgcolor:n.bgcolor,bordercolor:n.bordercolor,borderpad:n.borderpad,borderwidth:n.borderwidth,showarrow:n.showarrow,arrowcolor:n.arrowcolor,arrowhead:n.arrowhead,startarrowhead:n.startarrowhead,arrowside:n.arrowside,arrowsize:n.arrowsize,startarrowsize:n.startarrowsize,arrowwidth:n.arrowwidth,standoff:n.standoff,startstandoff:n.startstandoff,hovertext:n.hovertext,hoverlabel:n.hoverlabel,captureevents:n.captureevents}),\"calc\",\"from-root\")},{\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../annotations/attributes\":576}],586:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\");function a(t,e){var r=e.fullSceneLayout.domain,a=e.fullLayout._size,o={pdata:null,type:\"linear\",autorange:!1,range:[-1/0,1/0]};t._xa={},n.extendFlat(t._xa,o),i.setConvert(t._xa),t._xa._offset=a.l+r.x[0]*a.w,t._xa.l2p=function(){return.5*(1+t._pdata[0]/t._pdata[3])*a.w*(r.x[1]-r.x[0])},t._ya={},n.extendFlat(t._ya,o),i.setConvert(t._ya),t._ya._offset=a.t+(1-r.y[1])*a.h,t._ya.l2p=function(){return.5*(1-t._pdata[1]/t._pdata[3])*a.h*(r.y[1]-r.y[0])}}e.exports=function(t){for(var e=t.fullSceneLayout.annotations,r=0;r<e.length;r++)a(e[r],t);t.fullLayout._infolayer.selectAll(\".annotation-\"+t.id).remove()}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767}],587:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"../annotations/common_defaults\"),s=t(\"./attributes\");function l(t,e,r,a){function l(r,i){return n.coerce(t,e,s,r,i)}function c(t){var n=t+\"axis\",a={_fullLayout:{}};return a._fullLayout[n]=r[n],i.coercePosition(e,a,l,t,t,.5)}l(\"visible\")&&(o(t,e,a.fullLayout,l),c(\"x\"),c(\"y\"),c(\"z\"),n.noneOrAll(t,e,[\"x\",\"y\",\"z\"]),e.xref=\"x\",e.yref=\"y\",e.zref=\"z\",l(\"xanchor\"),l(\"yanchor\"),l(\"xshift\"),l(\"yshift\"),e.showarrow&&(e.axref=\"pixel\",e.ayref=\"pixel\",l(\"ax\",-10),l(\"ay\",-30),n.noneOrAll(t,e,[\"ax\",\"ay\"])))}e.exports=function(t,e,r){a(t,e,{name:\"annotations\",handleItemDefaults:l,fullLayout:r.fullLayout})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"../annotations/common_defaults\":579,\"./attributes\":585}],588:[function(t,e,r){\"use strict\";var n=t(\"../annotations/draw\").drawRaw,i=t(\"../../plots/gl3d/project\"),a=[\"x\",\"y\",\"z\"];e.exports=function(t){for(var e=t.fullSceneLayout,r=t.dataScale,o=e.annotations,s=0;s<o.length;s++){for(var l=o[s],c=!1,u=0;u<3;u++){var h=a[u],f=l[h],p=e[h+\"axis\"].r2fraction(f);if(p<0||p>1){c=!0;break}}c?t.fullLayout._infolayer.select(\".annotation-\"+t.id+'[data-index=\"'+s+'\"]').remove():(l._pdata=i(t.glplot.cameraParams,[e.xaxis.r2l(l.x)*r[0],e.yaxis.r2l(l.y)*r[1],e.zaxis.r2l(l.z)*r[2]]),n(t.graphDiv,l,s,t.id,l._xa,l._ya))}}},{\"../../plots/gl3d/project\":816,\"../annotations/draw\":582}],589:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports={moduleType:\"component\",name:\"annotations3d\",schema:{subplots:{scene:{annotations:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),includeBasePlot:function(t,e){var r=n.subplotsRegistry.gl3d;if(!r)return;for(var a=r.attrRegex,o=Object.keys(t),s=0;s<o.length;s++){var l=o[s];a.test(l)&&(t[l].annotations||[]).length&&(i.pushUnique(e._basePlotModules,r),i.pushUnique(e._subplots.gl3d,l))}},convert:t(\"./convert\"),draw:t(\"./draw\")}},{\"../../lib\":719,\"../../registry\":847,\"./attributes\":585,\"./convert\":586,\"./defaults\":587,\"./draw\":588}],590:[function(t,e,r){\"use strict\";e.exports=t(\"world-calendars/dist/main\"),t(\"world-calendars/dist/plus\"),t(\"world-calendars/dist/calendars/chinese\"),t(\"world-calendars/dist/calendars/coptic\"),t(\"world-calendars/dist/calendars/discworld\"),t(\"world-calendars/dist/calendars/ethiopian\"),t(\"world-calendars/dist/calendars/hebrew\"),t(\"world-calendars/dist/calendars/islamic\"),t(\"world-calendars/dist/calendars/julian\"),t(\"world-calendars/dist/calendars/mayan\"),t(\"world-calendars/dist/calendars/nanakshahi\"),t(\"world-calendars/dist/calendars/nepali\"),t(\"world-calendars/dist/calendars/persian\"),t(\"world-calendars/dist/calendars/taiwan\"),t(\"world-calendars/dist/calendars/thai\"),t(\"world-calendars/dist/calendars/ummalqura\")},{\"world-calendars/dist/calendars/chinese\":557,\"world-calendars/dist/calendars/coptic\":558,\"world-calendars/dist/calendars/discworld\":559,\"world-calendars/dist/calendars/ethiopian\":560,\"world-calendars/dist/calendars/hebrew\":561,\"world-calendars/dist/calendars/islamic\":562,\"world-calendars/dist/calendars/julian\":563,\"world-calendars/dist/calendars/mayan\":564,\"world-calendars/dist/calendars/nanakshahi\":565,\"world-calendars/dist/calendars/nepali\":566,\"world-calendars/dist/calendars/persian\":567,\"world-calendars/dist/calendars/taiwan\":568,\"world-calendars/dist/calendars/thai\":569,\"world-calendars/dist/calendars/ummalqura\":570,\"world-calendars/dist/main\":571,\"world-calendars/dist/plus\":572}],591:[function(t,e,r){\"use strict\";var n=t(\"./calendars\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\"),o=a.EPOCHJD,s=a.ONEDAY,l={valType:\"enumerated\",values:Object.keys(n.calendars),editType:\"calc\",dflt:\"gregorian\"},c=function(t,e,r,n){var a={};return a[r]=l,i.coerce(t,e,a,r,n)},u=\"##\",h={d:{0:\"dd\",\"-\":\"d\"},e:{0:\"d\",\"-\":\"d\"},a:{0:\"D\",\"-\":\"D\"},A:{0:\"DD\",\"-\":\"DD\"},j:{0:\"oo\",\"-\":\"o\"},W:{0:\"ww\",\"-\":\"w\"},m:{0:\"mm\",\"-\":\"m\"},b:{0:\"M\",\"-\":\"M\"},B:{0:\"MM\",\"-\":\"MM\"},y:{0:\"yy\",\"-\":\"yy\"},Y:{0:\"yyyy\",\"-\":\"yyyy\"},U:u,w:u,c:{0:\"D M d %X yyyy\",\"-\":\"D M d %X yyyy\"},x:{0:\"mm/dd/yyyy\",\"-\":\"mm/dd/yyyy\"}};var f={};function p(t){var e=f[t];return e||(e=f[t]=n.instance(t))}function d(t){return i.extendFlat({},l,{description:t})}function g(t){return\"Sets the calendar system to use with `\"+t+\"` date data.\"}var v={xcalendar:d(g(\"x\"))},m=i.extendFlat({},v,{ycalendar:d(g(\"y\"))}),y=i.extendFlat({},m,{zcalendar:d(g(\"z\"))}),x=d([\"Sets the calendar system to use for `range` and `tick0`\",\"if this is a date axis. This does not set the calendar for\",\"interpreting data on this axis, that's specified in the trace\",\"or via the global `layout.calendar`\"].join(\" \"));e.exports={moduleType:\"component\",name:\"calendars\",schema:{traces:{scatter:m,bar:m,box:m,heatmap:m,contour:m,histogram:m,histogram2d:m,histogram2dcontour:m,scatter3d:y,surface:y,mesh3d:y,scattergl:m,ohlc:v,candlestick:v},layout:{calendar:d([\"Sets the default calendar system to use for interpreting and\",\"displaying dates throughout the plot.\"].join(\" \"))},subplots:{xaxis:{calendar:x},yaxis:{calendar:x},scene:{xaxis:{calendar:x},yaxis:{calendar:x},zaxis:{calendar:x}},polar:{radialaxis:{calendar:x}}},transforms:{filter:{valuecalendar:d([\"Sets the calendar system to use for `value`, if it is a date.\"].join(\" \")),targetcalendar:d([\"Sets the calendar system to use for `target`, if it is an\",\"array of dates. If `target` is a string (eg *x*) we use the\",\"corresponding trace attribute (eg `xcalendar`) if it exists,\",\"even if `targetcalendar` is provided.\"].join(\" \"))}}},layoutAttributes:l,handleDefaults:c,handleTraceDefaults:function(t,e,r,n){for(var i=0;i<r.length;i++)c(t,e,r[i]+\"calendar\",n.calendar)},CANONICAL_SUNDAY:{chinese:\"2000-01-02\",coptic:\"2000-01-03\",discworld:\"2000-01-03\",ethiopian:\"2000-01-05\",hebrew:\"5000-01-01\",islamic:\"1000-01-02\",julian:\"2000-01-03\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-05\",nepali:\"2000-01-05\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-04\",thai:\"2000-01-04\",ummalqura:\"1400-01-06\"},CANONICAL_TICK:{chinese:\"2000-01-01\",coptic:\"2000-01-01\",discworld:\"2000-01-01\",ethiopian:\"2000-01-01\",hebrew:\"5000-01-01\",islamic:\"1000-01-01\",julian:\"2000-01-01\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-01\",nepali:\"2000-01-01\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-01\",thai:\"2000-01-01\",ummalqura:\"1400-01-01\"},DFLTRANGE:{chinese:[\"2000-01-01\",\"2001-01-01\"],coptic:[\"1700-01-01\",\"1701-01-01\"],discworld:[\"1800-01-01\",\"1801-01-01\"],ethiopian:[\"2000-01-01\",\"2001-01-01\"],hebrew:[\"5700-01-01\",\"5701-01-01\"],islamic:[\"1400-01-01\",\"1401-01-01\"],julian:[\"2000-01-01\",\"2001-01-01\"],mayan:[\"5200-01-01\",\"5201-01-01\"],nanakshahi:[\"0500-01-01\",\"0501-01-01\"],nepali:[\"2000-01-01\",\"2001-01-01\"],persian:[\"1400-01-01\",\"1401-01-01\"],jalali:[\"1400-01-01\",\"1401-01-01\"],taiwan:[\"0100-01-01\",\"0101-01-01\"],thai:[\"2500-01-01\",\"2501-01-01\"],ummalqura:[\"1400-01-01\",\"1401-01-01\"]},getCal:p,worldCalFmt:function(t,e,r){for(var n,i,a,l,c,f=Math.floor((e+.05)/s)+o,d=p(r).fromJD(f),g=0;-1!==(g=t.indexOf(\"%\",g));)\"0\"===(n=t.charAt(g+1))||\"-\"===n||\"_\"===n?(a=3,i=t.charAt(g+2),\"_\"===n&&(n=\"-\")):(i=n,n=\"0\",a=2),(l=h[i])?(c=l===u?u:d.formatDate(l[n]),t=t.substr(0,g)+c+t.substr(g+a),g+=c.length):g+=a;return t}}},{\"../../constants/numerical\":695,\"../../lib\":719,\"./calendars\":590}],592:[function(t,e,r){\"use strict\";r.defaults=[\"#1f77b4\",\"#ff7f0e\",\"#2ca02c\",\"#d62728\",\"#9467bd\",\"#8c564b\",\"#e377c2\",\"#7f7f7f\",\"#bcbd22\",\"#17becf\"],r.defaultLine=\"#444\",r.lightLine=\"#eee\",r.background=\"#fff\",r.borderLine=\"#BEC8D9\",r.lightFraction=1e3/11},{}],593:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i=t(\"fast-isnumeric\"),a=e.exports={},o=t(\"./attributes\");a.defaults=o.defaults;var s=a.defaultLine=o.defaultLine;a.lightLine=o.lightLine;var l=a.background=o.background;function c(t){if(i(t)||\"string\"!=typeof t)return t;var e=t.trim();if(\"rgb\"!==e.substr(0,3))return t;var r=e.match(/^rgba?\\s*\\(([^()]*)\\)$/);if(!r)return t;var n=r[1].trim().split(/\\s*[\\s,]\\s*/),a=\"a\"===e.charAt(3)&&4===n.length;if(!a&&3!==n.length)return t;for(var o=0;o<n.length;o++){if(!n[o].length)return t;if(n[o]=Number(n[o]),!(n[o]>=0))return t;if(3===o)n[o]>1&&(n[o]=1);else if(n[o]>=1)return t}var s=Math.round(255*n[0])+\", \"+Math.round(255*n[1])+\", \"+Math.round(255*n[2]);return a?\"rgba(\"+s+\", \"+n[3]+\")\":\"rgb(\"+s+\")\"}a.tinyRGB=function(t){var e=t.toRgb();return\"rgb(\"+Math.round(e.r)+\", \"+Math.round(e.g)+\", \"+Math.round(e.b)+\")\"},a.rgb=function(t){return a.tinyRGB(n(t))},a.opacity=function(t){return t?n(t).getAlpha():0},a.addOpacity=function(t,e){var r=n(t).toRgb();return\"rgba(\"+Math.round(r.r)+\", \"+Math.round(r.g)+\", \"+Math.round(r.b)+\", \"+e+\")\"},a.combine=function(t,e){var r=n(t).toRgb();if(1===r.a)return n(t).toRgbString();var i=n(e||l).toRgb(),a=1===i.a?i:{r:255*(1-i.a)+i.r*i.a,g:255*(1-i.a)+i.g*i.a,b:255*(1-i.a)+i.b*i.a},o={r:a.r*(1-r.a)+r.r*r.a,g:a.g*(1-r.a)+r.g*r.a,b:a.b*(1-r.a)+r.b*r.a};return n(o).toRgbString()},a.contrast=function(t,e,r){var i=n(t);return 1!==i.getAlpha()&&(i=n(a.combine(t,l))),(i.isDark()?e?i.lighten(e):l:r?i.darken(r):s).toString()},a.stroke=function(t,e){var r=n(e);t.style({stroke:a.tinyRGB(r),\"stroke-opacity\":r.getAlpha()})},a.fill=function(t,e){var r=n(e);t.style({fill:a.tinyRGB(r),\"fill-opacity\":r.getAlpha()})},a.clean=function(t){if(t&&\"object\"==typeof t){var e,r,n,i,o=Object.keys(t);for(e=0;e<o.length;e++)if(i=t[n=o[e]],\"color\"===n.substr(n.length-5))if(Array.isArray(i))for(r=0;r<i.length;r++)i[r]=c(i[r]);else t[n]=c(i);else if(\"colorscale\"===n.substr(n.length-10)&&Array.isArray(i))for(r=0;r<i.length;r++)Array.isArray(i[r])&&(i[r][1]=c(i[r][1]));else if(Array.isArray(i)){var s=i[0];if(!Array.isArray(s)&&s&&\"object\"==typeof s)for(r=0;r<i.length;r++)a.clean(i[r])}else i&&\"object\"==typeof i&&a.clean(i)}}},{\"./attributes\":592,\"fast-isnumeric\":225,tinycolor2:537}],594:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/layout_attributes\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll;e.exports=o({thicknessmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"pixels\"},thickness:{valType:\"number\",min:0,dflt:30},lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",dflt:1.02,min:-2,max:3},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},xpad:{valType:\"number\",min:0,dflt:10},y:{valType:\"number\",dflt:.5,min:-2,max:3},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\"},ypad:{valType:\"number\",min:0,dflt:10},outlinecolor:n.linecolor,outlinewidth:n.linewidth,bordercolor:n.linecolor,borderwidth:{valType:\"number\",min:0,dflt:0},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\"},tickmode:n.tickmode,nticks:n.nticks,tick0:n.tick0,dtick:n.dtick,tickvals:n.tickvals,ticktext:n.ticktext,ticks:a({},n.ticks,{dflt:\"\"}),ticklen:n.ticklen,tickwidth:n.tickwidth,tickcolor:n.tickcolor,showticklabels:n.showticklabels,tickfont:i({}),tickangle:n.tickangle,tickformat:n.tickformat,tickformatstops:n.tickformatstops,tickprefix:n.tickprefix,showtickprefix:n.showtickprefix,ticksuffix:n.ticksuffix,showticksuffix:n.showticksuffix,separatethousands:n.separatethousands,exponentformat:n.exponentformat,showexponent:n.showexponent,title:{text:{valType:\"string\"},font:i({}),side:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}},_deprecated:{title:{valType:\"string\"},titlefont:i({}),titleside:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}}},\"colorbars\",\"from-root\")},{\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/font_attributes\":793}],595:[function(t,e,r){\"use strict\";e.exports={cn:{colorbar:\"colorbar\",cbbg:\"cbbg\",cbfill:\"cbfill\",cbfills:\"cbfills\",cbline:\"cbline\",cblines:\"cblines\",cbaxis:\"cbaxis\",cbtitleunshift:\"cbtitleunshift\",cbtitle:\"cbtitle\",cboutline:\"cboutline\",crisp:\"crisp\",jsPlaceholder:\"js-placeholder\"}}},{}],596:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/tick_value_defaults\"),o=t(\"../../plots/cartesian/tick_mark_defaults\"),s=t(\"../../plots/cartesian/tick_label_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r){var c=i.newContainer(e,\"colorbar\"),u=t.colorbar||{};function h(t,e){return n.coerce(u,c,l,t,e)}var f=h(\"thicknessmode\");h(\"thickness\",\"fraction\"===f?30/(r.width-r.margin.l-r.margin.r):30);var p=h(\"lenmode\");h(\"len\",\"fraction\"===p?1:r.height-r.margin.t-r.margin.b),h(\"x\"),h(\"xanchor\"),h(\"xpad\"),h(\"y\"),h(\"yanchor\"),h(\"ypad\"),n.noneOrAll(u,c,[\"x\",\"y\"]),h(\"outlinecolor\"),h(\"outlinewidth\"),h(\"bordercolor\"),h(\"borderwidth\"),h(\"bgcolor\"),a(u,c,h,\"linear\");var d={outerTicks:!1,font:r.font};s(u,c,h,\"linear\",d),o(u,c,h,\"linear\",d),h(\"title.text\",r._dfltTitle.colorbar),n.coerceFont(h,\"title.font\",r.font),h(\"title.side\")}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/tick_label_defaults\":786,\"../../plots/cartesian/tick_mark_defaults\":787,\"../../plots/cartesian/tick_value_defaults\":788,\"./attributes\":594}],597:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../dragelement\"),c=t(\"../../lib\"),u=t(\"../../lib/extend\").extendFlat,h=t(\"../../lib/setcursor\"),f=t(\"../drawing\"),p=t(\"../color\"),d=t(\"../titles\"),g=t(\"../../lib/svg_text_utils\"),v=t(\"../colorscale/helpers\").flipScale,m=t(\"../../plots/cartesian/axis_defaults\"),y=t(\"../../plots/cartesian/position_defaults\"),x=t(\"../../plots/cartesian/layout_attributes\"),b=t(\"../../constants/alignment\"),_=b.LINE_SPACING,w=b.FROM_TL,k=b.FROM_BR,T=t(\"./constants\").cn;e.exports={draw:function(t){var e=t._fullLayout._infolayer.selectAll(\"g.\"+T.colorbar).data(function(t){var e,r,n,i,a=t._fullLayout,o=t.calcdata,s=[];function l(t){return u(t,{_fillcolor:null,_line:{color:null,width:null,dash:null},_levels:{start:null,end:null,size:null},_filllevels:null,_fillgradient:null,_zrange:null})}function c(){\"function\"==typeof i.calc?i.calc(t,n,e):(e._fillgradient=r.reversescale?v(r.colorscale):r.colorscale,e._zrange=[r[i.min],r[i.max]])}for(var h=0;h<o.length;h++){var f=o[h],p=(n=f[0].trace)._module.colorbar;if(!0===n.visible&&p)for(var d=Array.isArray(p),g=d?p:[p],m=0;m<g.length;m++){var y=(i=g[m]).container;(r=y?n[y]:n)&&r.showscale&&((e=l(r.colorbar))._id=\"cb\"+n.uid+(d&&y?\"-\"+y:\"\"),e._traceIndex=n.index,e._propPrefix=(y?y+\".\":\"\")+\"colorbar.\",e._meta=n._meta,c(),s.push(e))}}for(var x in a._colorAxes)if((r=a[x]).showscale){var b=a._colorAxes[x];(e=l(r.colorbar))._id=\"cb\"+x,e._propPrefix=x+\".colorbar.\",e._meta=a._meta,i={min:\"cmin\",max:\"cmax\"},\"heatmap\"!==b[0]&&(n=b[1],i.calc=n._module.colorbar.calc),c(),s.push(e)}return s}(t),function(t){return t._id});e.enter().append(\"g\").attr(\"class\",function(t){return t._id}).classed(T.colorbar,!0),e.each(function(e){var r=n.select(this);c.ensureSingle(r,\"rect\",T.cbbg),c.ensureSingle(r,\"g\",T.cbfills),c.ensureSingle(r,\"g\",T.cblines),c.ensureSingle(r,\"g\",T.cbaxis,function(t){t.classed(T.crisp,!0)}),c.ensureSingle(r,\"g\",T.cbtitleunshift,function(t){t.append(\"g\").classed(T.cbtitle,!0)}),c.ensureSingle(r,\"rect\",T.cboutline);var v=function(t,e,r){var o=r._fullLayout,l=o._size,h=e._fillcolor,v=e._line,b=e.title,A=b.side,M=e._zrange||n.extent((\"function\"==typeof h?h:v.color).domain()),S=\"function\"==typeof v.color?v.color:function(){return v.color},E=\"function\"==typeof h?h:function(){return h},C=e._levels,L=function(t,e,r){var n,i,a=e._levels,o=[],s=[],l=a.end+a.size/100,c=a.size,u=1.001*r[0]-.001*r[1],h=1.001*r[1]-.001*r[0];for(i=0;i<1e5&&(n=a.start+i*c,!(c>0?n>=l:n<=l));i++)n>u&&n<h&&o.push(n);if(e._fillgradient)s=[0];else if(\"function\"==typeof e._fillcolor){var f=e._filllevels;if(f)for(l=f.end+f.size/100,c=f.size,i=0;i<1e5&&(n=f.start+i*c,!(c>0?n>=l:n<=l));i++)n>r[0]&&n<r[1]&&s.push(n);else(s=o.map(function(t){return t-a.size/2})).push(s[s.length-1]+a.size)}else e._fillcolor&&\"string\"==typeof e._fillcolor&&(s=[0]);return a.size<0&&(o.reverse(),s.reverse()),{line:o,fill:s}}(0,e,M),P=L.fill,O=L.line,z=Math.round(e.thickness*(\"fraction\"===e.thicknessmode?l.w:1)),I=z/l.w,D=Math.round(e.len*(\"fraction\"===e.lenmode?l.h:1)),R=D/l.h,F=e.xpad/l.w,B=(e.borderwidth+e.outlinewidth)/2,N=e.ypad/l.h,j=Math.round(e.x*l.w+e.xpad),U=e.x-I*({middle:.5,right:1}[e.xanchor]||0),V=e.y+R*(({top:-.5,bottom:.5}[e.yanchor]||0)-.5),q=Math.round(l.h*(1-V)),H=q-D;e._lenFrac=R,e._thickFrac=I,e._xLeftFrac=U,e._yBottomFrac=V;var G=function(t,e,r){var n=t._fullLayout,i={type:\"linear\",range:r,tickmode:e.tickmode,nticks:e.nticks,tick0:e.tick0,dtick:e.dtick,tickvals:e.tickvals,ticktext:e.ticktext,ticks:e.ticks,ticklen:e.ticklen,tickwidth:e.tickwidth,tickcolor:e.tickcolor,showticklabels:e.showticklabels,tickfont:e.tickfont,tickangle:e.tickangle,tickformat:e.tickformat,exponentformat:e.exponentformat,separatethousands:e.separatethousands,showexponent:e.showexponent,showtickprefix:e.showtickprefix,tickprefix:e.tickprefix,showticksuffix:e.showticksuffix,ticksuffix:e.ticksuffix,title:e.title,showline:!0,anchor:\"free\",side:\"right\",position:1},a={type:\"linear\",_id:\"y\"+e._id},o={letter:\"y\",font:n.font,noHover:!0,noTickson:!0,calendar:n.calendar};function s(t,e){return c.coerce(i,a,x,t,e)}return m(i,a,s,o,n),y(i,a,s,o),a}(r,e,M);if(G.position=e.x+F+I,-1!==[\"top\",\"bottom\"].indexOf(A)&&(G.title.side=A,G.titlex=e.x+F,G.titley=V+(\"top\"===b.side?R-N:N)),v.color&&\"auto\"===e.tickmode){G.tickmode=\"linear\",G.tick0=C.start;var Y=C.size,W=c.constrain((q-H)/50,4,15)+1,X=(M[1]-M[0])/((e.nticks||W)*Y);if(X>1){var Z=Math.pow(10,Math.floor(Math.log(X)/Math.LN10));Y*=Z*c.roundUp(X/Z,[2,5,10]),(Math.abs(C.start)/C.size+1e-6)%1<2e-6&&(G.tick0=0)}G.dtick=Y}G.domain=[V+N,V+R-N],G.setScale(),t.attr(\"transform\",\"translate(\"+Math.round(l.l)+\",\"+Math.round(l.t)+\")\");var J,K=t.select(\".\"+T.cbtitleunshift).attr(\"transform\",\"translate(-\"+Math.round(l.l)+\",-\"+Math.round(l.t)+\")\"),$=t.select(\".\"+T.cbaxis),Q=0;function tt(n,i){var a={propContainer:G,propName:e._propPrefix+\"title\",traceIndex:e._traceIndex,_meta:e._meta,placeholder:o._dfltTitle.colorbar,containerGroup:t.select(\".\"+T.cbtitle)},s=\"h\"===n.charAt(0)?n.substr(1):\"h\"+n;t.selectAll(\".\"+s+\",.\"+s+\"-math-group\").remove(),d.draw(r,n,u(a,i||{}))}return c.syncOrAsync([a.previousPromises,function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var t,r=l.l+(e.x+F)*l.w,n=G.title.font.size;t=\"top\"===A?(1-(V+R-N))*l.h+l.t+3+.75*n:(1-(V+N))*l.h+l.t-3-.25*n,tt(G._id+\"title\",{attributes:{x:r,y:t,\"text-anchor\":\"start\"}})}},function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var a=t.select(\".\"+T.cbtitle),o=a.select(\"text\"),u=[-e.outlinewidth/2,e.outlinewidth/2],h=a.select(\".h\"+G._id+\"title-math-group\").node(),p=15.6;if(o.node()&&(p=parseInt(o.node().style.fontSize,10)*_),h?(Q=f.bBox(h).height)>p&&(u[1]-=(Q-p)/2):o.node()&&!o.classed(T.jsPlaceholder)&&(Q=f.bBox(o.node()).height),Q){if(Q+=5,\"top\"===A)G.domain[1]-=Q/l.h,u[1]*=-1;else{G.domain[0]+=Q/l.h;var d=g.lineCount(o);u[1]+=(1-d)*p}a.attr(\"transform\",\"translate(\"+u+\")\"),G.setScale()}}t.selectAll(\".\"+T.cbfills+\",.\"+T.cblines).attr(\"transform\",\"translate(0,\"+Math.round(l.h*(1-G.domain[1]))+\")\"),$.attr(\"transform\",\"translate(0,\"+Math.round(-l.t)+\")\");var m=t.select(\".\"+T.cbfills).selectAll(\"rect.\"+T.cbfill).data(P);m.enter().append(\"rect\").classed(T.cbfill,!0).style(\"stroke\",\"none\"),m.exit().remove();var y=M.map(G.c2p).map(Math.round).sort(function(t,e){return t-e});m.each(function(t,a){var o=[0===a?M[0]:(P[a]+P[a-1])/2,a===P.length-1?M[1]:(P[a]+P[a+1])/2].map(G.c2p).map(Math.round);o[1]=c.constrain(o[1]+(o[1]>o[0])?1:-1,y[0],y[1]);var s=n.select(this).attr({x:j,width:Math.max(z,2),y:n.min(o),height:Math.max(n.max(o)-n.min(o),2)});if(e._fillgradient)f.gradient(s,r,e._id,\"vertical\",e._fillgradient,\"fill\");else{var l=E(t).replace(\"e-\",\"\");s.attr(\"fill\",i(l).toHexString())}});var x=t.select(\".\"+T.cblines).selectAll(\"path.\"+T.cbline).data(v.color&&v.width?O:[]);x.enter().append(\"path\").classed(T.cbline,!0),x.exit().remove(),x.each(function(t){n.select(this).attr(\"d\",\"M\"+j+\",\"+(Math.round(G.c2p(t))+v.width/2%1)+\"h\"+z).call(f.lineGroupStyle,v.width,S(t),v.dash)}),$.selectAll(\"g.\"+G._id+\"tick,path\").remove();var b=j+z+(e.outlinewidth||0)/2-(\"outside\"===e.ticks?1:0),w=s.calcTicks(G),k=s.makeTransFn(G),C=s.getTickSigns(G)[2];return s.drawTicks(r,G,{vals:\"inside\"===G.ticks?s.clipEnds(G,w):w,layer:$,path:s.makeTickPath(G,b,C),transFn:k}),s.drawLabels(r,G,{vals:w,layer:$,transFn:k,labelFns:s.makeLabelFns(G,b)})},function(){if(-1===[\"top\",\"bottom\"].indexOf(A)){var t=G.title.font.size,e=G._offset+G._length/2,i=l.l+(G.position||0)*l.w+(\"right\"===G.side?10+t*(G.showticklabels?1:.5):-10-t*(G.showticklabels?.5:0));tt(\"h\"+G._id+\"title\",{avoid:{selection:n.select(r).selectAll(\"g.\"+G._id+\"tick\"),side:A,offsetLeft:l.l,offsetTop:0,maxShift:o.width},attributes:{x:i,y:e,\"text-anchor\":\"middle\"},transform:{rotate:\"-90\",offset:0}})}},a.previousPromises,function(){var n=z+e.outlinewidth/2+f.bBox($.node()).width;if((J=K.select(\"text\")).node()&&!J.classed(T.jsPlaceholder)){var i,o=K.select(\".h\"+G._id+\"title-math-group\").node();i=o&&-1!==[\"top\",\"bottom\"].indexOf(A)?f.bBox(o).width:f.bBox(K.node()).right-j-l.l,n=Math.max(n,i)}var s=2*e.xpad+n+e.borderwidth+e.outlinewidth/2,c=q-H;t.select(\".\"+T.cbbg).attr({x:j-e.xpad-(e.borderwidth+e.outlinewidth)/2,y:H-B,width:Math.max(s,2),height:Math.max(c+2*B,2)}).call(p.fill,e.bgcolor).call(p.stroke,e.bordercolor).style(\"stroke-width\",e.borderwidth),t.selectAll(\".\"+T.cboutline).attr({x:j,y:H+e.ypad+(\"top\"===A?Q:0),width:Math.max(z,2),height:Math.max(c-2*e.ypad-Q,2)}).call(p.stroke,e.outlinecolor).style({fill:\"none\",\"stroke-width\":e.outlinewidth});var u=({center:.5,right:1}[e.xanchor]||0)*s;t.attr(\"transform\",\"translate(\"+(l.l-u)+\",\"+l.t+\")\");var h={},d=w[e.yanchor],g=k[e.yanchor];\"pixels\"===e.lenmode?(h.y=e.y,h.t=c*d,h.b=c*g):(h.t=h.b=0,h.yt=e.y+e.len*d,h.yb=e.y-e.len*g);var v=w[e.xanchor],m=k[e.xanchor];if(\"pixels\"===e.thicknessmode)h.x=e.x,h.l=s*v,h.r=s*m;else{var y=s-z;h.l=y*v,h.r=y*m,h.xl=e.x-e.thickness*v,h.xr=e.x+e.thickness*m}a.autoMargin(r,e._id,h)}],r)}(r,e,t);v&&v.then&&(t._promises||[]).push(v),t._context.edits.colorbarPosition&&function(t,e,r){var n,i,a,s=r._fullLayout._size;l.init({element:t.node(),gd:r,prepFn:function(){n=t.attr(\"transform\"),h(t)},moveFn:function(r,o){t.attr(\"transform\",n+\" translate(\"+r+\",\"+o+\")\"),i=l.align(e._xLeftFrac+r/s.w,e._thickFrac,0,1,e.xanchor),a=l.align(e._yBottomFrac-o/s.h,e._lenFrac,0,1,e.yanchor);var c=l.getCursor(i,a,e.xanchor,e.yanchor);h(t,c)},doneFn:function(){if(h(t),void 0!==i&&void 0!==a){var n={};n[e._propPrefix+\"x\"]=i,n[e._propPrefix+\"y\"]=a,void 0!==e._traceIndex?o.call(\"_guiRestyle\",r,n,e._traceIndex):o.call(\"_guiRelayout\",r,n)}}})}(r,e,t)}),e.exit().each(function(e){a.autoMargin(t,e._id)}).remove(),e.order()}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/extend\":710,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_defaults\":769,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/cartesian/position_defaults\":782,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../colorscale/helpers\":604,\"../dragelement\":611,\"../drawing\":614,\"../titles\":681,\"./constants\":595,d3:163,tinycolor2:537}],598:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t){return n.isPlainObject(t.colorbar)}},{\"../../lib\":719}],599:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"colorbar\",attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),draw:t(\"./draw\").draw,hasColorbar:t(\"./has_colorbar\")}},{\"./attributes\":594,\"./defaults\":596,\"./draw\":597,\"./has_colorbar\":598}],600:[function(t,e,r){\"use strict\";var n=t(\"../colorbar/attributes\"),i=t(\"../../lib/regex\").counter,a=t(\"./scales.js\").scales;Object.keys(a);function o(t){return\"`\"+t+\"`\"}e.exports=function(t,e){t=t||\"\";var r,s=(e=e||{}).cLetter||\"c\",l=(\"onlyIfNumerical\"in e?e.onlyIfNumerical:Boolean(t),\"noScale\"in e?e.noScale:\"marker.line\"===t),c=\"showScaleDflt\"in e?e.showScaleDflt:\"z\"===s,u=\"string\"==typeof e.colorscaleDflt?a[e.colorscaleDflt]:null,h=e.editTypeOverride||\"\",f=t?t+\".\":\"\";\"colorAttr\"in e?(r=e.colorAttr,e.colorAttr):o(f+(r={z:\"z\",c:\"color\"}[s]));var p=s+\"auto\",d=s+\"min\",g=s+\"max\",v=s+\"mid\",m=(o(f+p),o(f+d),o(f+g),{});m[d]=m[g]=void 0;var y={};y[p]=!1;var x={};return\"color\"===r&&(x.color={valType:\"color\",arrayOk:!0,editType:h||\"style\"},e.anim&&(x.color.anim=!0)),x[p]={valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:m},x[d]={valType:\"number\",dflt:null,editType:h||\"plot\",impliedEdits:y},x[g]={valType:\"number\",dflt:null,editType:h||\"plot\",impliedEdits:y},x[v]={valType:\"number\",dflt:null,editType:\"calc\",impliedEdits:m},x.colorscale={valType:\"colorscale\",editType:\"calc\",dflt:u,impliedEdits:{autocolorscale:!1}},x.autocolorscale={valType:\"boolean\",dflt:!1!==e.autoColorDflt,editType:\"calc\",impliedEdits:{colorscale:void 0}},x.reversescale={valType:\"boolean\",dflt:!1,editType:\"plot\"},l||(x.showscale={valType:\"boolean\",dflt:c,editType:\"calc\"},x.colorbar=n),e.noColorAxis||(x.coloraxis={valType:\"subplotid\",regex:i(\"coloraxis\"),dflt:null,editType:\"calc\"}),x}},{\"../../lib/regex\":735,\"../colorbar/attributes\":594,\"./scales.js\":608}],601:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"./helpers\").extractOpts;e.exports=function(t,e,r){var o,s=t._fullLayout,l=r.vals,c=r.containerStr,u=c?i.nestedProperty(e,c).get():e,h=a(u),f=!1!==h.auto,p=h.min,d=h.max,g=h.mid,v=function(){return i.aggNums(Math.min,null,l)},m=function(){return i.aggNums(Math.max,null,l)};(void 0===p?p=v():f&&(p=u._colorAx&&n(p)?Math.min(p,v()):v()),void 0===d?d=m():f&&(d=u._colorAx&&n(d)?Math.max(d,m()):m()),f&&void 0!==g&&(d-g>g-p?p=g-(d-g):d-g<g-p&&(d=g+(g-p))),p===d&&(p-=.5,d+=.5),h._sync(\"min\",p),h._sync(\"max\",d),h.autocolorscale)&&(o=p*d<0?s.colorscale.diverging:p>=0?s.colorscale.sequential:s.colorscale.sequentialminus,h._sync(\"colorscale\",o))}},{\"../../lib\":719,\"./helpers\":604,\"fast-isnumeric\":225}],602:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./helpers\").hasColorscale,a=t(\"./helpers\").extractOpts;e.exports=function(t,e){function r(t,e){var r=t[\"_\"+e];void 0!==r&&(t[e]=r)}function o(t,i){var o=i.container?n.nestedProperty(t,i.container).get():t;if(o)if(o.coloraxis)o._colorAx=e[o.coloraxis];else{var s=a(o),l=s.auto;(l||void 0===s.min)&&r(o,i.min),(l||void 0===s.max)&&r(o,i.max),s.autocolorscale&&r(o,\"colorscale\")}}for(var s=0;s<t.length;s++){var l=t[s],c=l._module.colorbar;if(c)if(Array.isArray(c))for(var u=0;u<c.length;u++)o(l,c[u]);else o(l,c);i(l,\"marker.line\")&&o(l,{container:\"marker.line\",min:\"cmin\",max:\"cmax\"})}for(var h in e._colorAxes)o(e[h],{min:\"cmin\",max:\"cmax\"})}},{\"../../lib\":719,\"./helpers\":604}],603:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../colorbar/has_colorbar\"),o=t(\"../colorbar/defaults\"),s=t(\"./scales\").isValid,l=t(\"../../registry\").traceIs;function c(t,e){var r=e.slice(0,e.length-1);return e?i.nestedProperty(t,r).get()||{}:t}e.exports=function t(e,r,u,h,f){var p=f.prefix,d=f.cLetter,g=\"_module\"in r,v=c(e,p),m=c(r,p),y=c(r._template||{},p)||{},x=function(){return delete e.coloraxis,delete r.coloraxis,t(e,r,u,h,f)};if(g){var b=u._colorAxes||{},_=h(p+\"coloraxis\");if(_){var w=l(r,\"contour\")&&i.nestedProperty(r,\"contours.coloring\").get()||\"heatmap\",k=b[_];return void(k?(k[2].push(x),k[0]!==w&&(k[0]=!1,i.warn([\"Ignoring coloraxis:\",_,\"setting\",\"as it is linked to incompatible colorscales.\"].join(\" \")))):b[_]=[w,r,[x]])}}var T=v[d+\"min\"],A=v[d+\"max\"],M=n(T)&&n(A)&&T<A;h(p+d+\"auto\",!M)?h(p+d+\"mid\"):(h(p+d+\"min\"),h(p+d+\"max\"));var S,E,C=v.colorscale,L=y.colorscale;(void 0!==C&&(S=!s(C)),void 0!==L&&(S=!s(L)),h(p+\"autocolorscale\",S),h(p+\"colorscale\"),h(p+\"reversescale\"),\"marker.line.\"!==p)&&(p&&g&&(E=a(v)),h(p+\"showscale\",E)&&o(v,m,u))}},{\"../../lib\":719,\"../../registry\":847,\"../colorbar/defaults\":596,\"../colorbar/has_colorbar\":598,\"./scales\":608,\"fast-isnumeric\":225}],604:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"fast-isnumeric\"),o=t(\"../../lib\"),s=t(\"../color\"),l=t(\"./scales\").isValid;var c=[\"showscale\",\"autocolorscale\",\"colorscale\",\"reversescale\",\"colorbar\"],u=[\"min\",\"max\",\"mid\",\"auto\"];function h(t){var e,r,n,i=t._colorAx,a=i||t,o={};for(r=0;r<c.length;r++)o[n=c[r]]=a[n];if(i)for(e=\"c\",r=0;r<u.length;r++)o[n=u[r]]=a[\"c\"+n];else{var s;for(r=0;r<u.length;r++)(s=\"c\"+(n=u[r]))in a?o[n]=a[s]:(s=\"z\"+n)in a&&(o[n]=a[s]);e=s.charAt(0)}return o._sync=function(t,r){var n=-1!==u.indexOf(t)?e+t:t;a[n]=a[\"_\"+n]=r},o}function f(t){for(var e=h(t),r=e.min,n=e.max,i=e.reversescale?p(e.colorscale):e.colorscale,a=i.length,o=new Array(a),s=new Array(a),l=0;l<a;l++){var c=i[l];o[l]=r+c[0]*(n-r),s[l]=c[1]}return{domain:o,range:s}}function p(t){for(var e=t.length,r=new Array(e),n=e-1,i=0;n>=0;n--,i++){var a=t[n];r[i]=[1-a[0],a[1]]}return r}function d(t,e){e=e||{};for(var r=t.domain,o=t.range,l=o.length,c=new Array(l),u=0;u<l;u++){var h=i(o[u]).toRgb();c[u]=[h.r,h.g,h.b,h.a]}var f,p=n.scale.linear().domain(r).range(c).clamp(!0),d=e.noNumericCheck,v=e.returnArray;return(f=d&&v?p:d?function(t){return g(p(t))}:v?function(t){return a(t)?p(t):i(t).isValid()?t:s.defaultLine}:function(t){return a(t)?g(p(t)):i(t).isValid()?t:s.defaultLine}).domain=p.domain,f.range=function(){return o},f}function g(t){var e={r:t[0],g:t[1],b:t[2],a:t[3]};return i(e).toRgbString()}e.exports={hasColorscale:function(t,e){var r=e?o.nestedProperty(t,e).get()||{}:t,n=r.color,i=!1;if(o.isArrayOrTypedArray(n))for(var s=0;s<n.length;s++)if(a(n[s])){i=!0;break}return o.isPlainObject(r)&&(i||!0===r.showscale||a(r.cmin)&&a(r.cmax)||l(r.colorscale)||o.isPlainObject(r.colorbar))},extractOpts:h,extractScale:f,flipScale:p,makeColorScaleFunc:d,makeColorScaleFuncFromTrace:function(t,e){return d(f(t),e)}}},{\"../../lib\":719,\"../color\":593,\"./scales\":608,d3:163,\"fast-isnumeric\":225,tinycolor2:537}],605:[function(t,e,r){\"use strict\";var n=t(\"./scales\"),i=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"colorscale\",attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),handleDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\"),scales:n.scales,defaultScale:n.defaultScale,getScale:n.get,isValidScale:n.isValid,hasColorscale:i.hasColorscale,extractOpts:i.extractOpts,extractScale:i.extractScale,flipScale:i.flipScale,makeColorScaleFunc:i.makeColorScaleFunc,makeColorScaleFuncFromTrace:i.makeColorScaleFuncFromTrace}},{\"./attributes\":600,\"./calc\":601,\"./cross_trace_defaults\":602,\"./defaults\":603,\"./helpers\":604,\"./layout_attributes\":606,\"./layout_defaults\":607,\"./scales\":608}],606:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"./attributes\"),a=t(\"./scales\").scales;e.exports={editType:\"calc\",colorscale:{editType:\"calc\",sequential:{valType:\"colorscale\",dflt:a.Reds,editType:\"calc\"},sequentialminus:{valType:\"colorscale\",dflt:a.Blues,editType:\"calc\"},diverging:{valType:\"colorscale\",dflt:a.RdBu,editType:\"calc\"}},coloraxis:n({_isSubplotObj:!0,editType:\"calc\"},i(\"\",{colorAttr:\"corresponding trace color array(s)\",noColorAxis:!0,showScaleDflt:!0}))}},{\"../../lib/extend\":710,\"./attributes\":600,\"./scales\":608}],607:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"./layout_attributes\"),o=t(\"./defaults\");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r(\"colorscale.sequential\"),r(\"colorscale.sequentialminus\"),r(\"colorscale.diverging\");var s,l,c=e._colorAxes;function u(t,e){return n.coerce(s,l,a.coloraxis,t,e)}for(var h in c){var f=c[h];if(f[0])s=t[h]||{},(l=i.newContainer(e,h,\"coloraxis\"))._name=h,o(s,l,e,u,{prefix:\"\",cLetter:\"c\"});else{for(var p=0;p<f[2].length;p++)f[2][p]();delete e._colorAxes[h]}}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"./defaults\":603,\"./layout_attributes\":606}],608:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i={Greys:[[0,\"rgb(0,0,0)\"],[1,\"rgb(255,255,255)\"]],YlGnBu:[[0,\"rgb(8,29,88)\"],[.125,\"rgb(37,52,148)\"],[.25,\"rgb(34,94,168)\"],[.375,\"rgb(29,145,192)\"],[.5,\"rgb(65,182,196)\"],[.625,\"rgb(127,205,187)\"],[.75,\"rgb(199,233,180)\"],[.875,\"rgb(237,248,217)\"],[1,\"rgb(255,255,217)\"]],Greens:[[0,\"rgb(0,68,27)\"],[.125,\"rgb(0,109,44)\"],[.25,\"rgb(35,139,69)\"],[.375,\"rgb(65,171,93)\"],[.5,\"rgb(116,196,118)\"],[.625,\"rgb(161,217,155)\"],[.75,\"rgb(199,233,192)\"],[.875,\"rgb(229,245,224)\"],[1,\"rgb(247,252,245)\"]],YlOrRd:[[0,\"rgb(128,0,38)\"],[.125,\"rgb(189,0,38)\"],[.25,\"rgb(227,26,28)\"],[.375,\"rgb(252,78,42)\"],[.5,\"rgb(253,141,60)\"],[.625,\"rgb(254,178,76)\"],[.75,\"rgb(254,217,118)\"],[.875,\"rgb(255,237,160)\"],[1,\"rgb(255,255,204)\"]],Bluered:[[0,\"rgb(0,0,255)\"],[1,\"rgb(255,0,0)\"]],RdBu:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(106,137,247)\"],[.5,\"rgb(190,190,190)\"],[.6,\"rgb(220,170,132)\"],[.7,\"rgb(230,145,90)\"],[1,\"rgb(178,10,28)\"]],Reds:[[0,\"rgb(220,220,220)\"],[.2,\"rgb(245,195,157)\"],[.4,\"rgb(245,160,105)\"],[1,\"rgb(178,10,28)\"]],Blues:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(40,60,190)\"],[.5,\"rgb(70,100,245)\"],[.6,\"rgb(90,120,245)\"],[.7,\"rgb(106,137,247)\"],[1,\"rgb(220,220,220)\"]],Picnic:[[0,\"rgb(0,0,255)\"],[.1,\"rgb(51,153,255)\"],[.2,\"rgb(102,204,255)\"],[.3,\"rgb(153,204,255)\"],[.4,\"rgb(204,204,255)\"],[.5,\"rgb(255,255,255)\"],[.6,\"rgb(255,204,255)\"],[.7,\"rgb(255,153,255)\"],[.8,\"rgb(255,102,204)\"],[.9,\"rgb(255,102,102)\"],[1,\"rgb(255,0,0)\"]],Rainbow:[[0,\"rgb(150,0,90)\"],[.125,\"rgb(0,0,200)\"],[.25,\"rgb(0,25,255)\"],[.375,\"rgb(0,152,255)\"],[.5,\"rgb(44,255,150)\"],[.625,\"rgb(151,255,0)\"],[.75,\"rgb(255,234,0)\"],[.875,\"rgb(255,111,0)\"],[1,\"rgb(255,0,0)\"]],Portland:[[0,\"rgb(12,51,131)\"],[.25,\"rgb(10,136,186)\"],[.5,\"rgb(242,211,56)\"],[.75,\"rgb(242,143,56)\"],[1,\"rgb(217,30,30)\"]],Jet:[[0,\"rgb(0,0,131)\"],[.125,\"rgb(0,60,170)\"],[.375,\"rgb(5,255,255)\"],[.625,\"rgb(255,255,0)\"],[.875,\"rgb(250,0,0)\"],[1,\"rgb(128,0,0)\"]],Hot:[[0,\"rgb(0,0,0)\"],[.3,\"rgb(230,0,0)\"],[.6,\"rgb(255,210,0)\"],[1,\"rgb(255,255,255)\"]],Blackbody:[[0,\"rgb(0,0,0)\"],[.2,\"rgb(230,0,0)\"],[.4,\"rgb(230,210,0)\"],[.7,\"rgb(255,255,255)\"],[1,\"rgb(160,200,255)\"]],Earth:[[0,\"rgb(0,0,130)\"],[.1,\"rgb(0,180,180)\"],[.2,\"rgb(40,210,40)\"],[.4,\"rgb(230,230,50)\"],[.6,\"rgb(120,70,20)\"],[1,\"rgb(255,255,255)\"]],Electric:[[0,\"rgb(0,0,0)\"],[.15,\"rgb(30,0,100)\"],[.4,\"rgb(120,0,100)\"],[.6,\"rgb(160,90,0)\"],[.8,\"rgb(230,200,0)\"],[1,\"rgb(255,250,220)\"]],Viridis:[[0,\"#440154\"],[.06274509803921569,\"#48186a\"],[.12549019607843137,\"#472d7b\"],[.18823529411764706,\"#424086\"],[.25098039215686274,\"#3b528b\"],[.3137254901960784,\"#33638d\"],[.3764705882352941,\"#2c728e\"],[.4392156862745098,\"#26828e\"],[.5019607843137255,\"#21918c\"],[.5647058823529412,\"#1fa088\"],[.6274509803921569,\"#28ae80\"],[.6901960784313725,\"#3fbc73\"],[.7529411764705882,\"#5ec962\"],[.8156862745098039,\"#84d44b\"],[.8784313725490196,\"#addc30\"],[.9411764705882353,\"#d8e219\"],[1,\"#fde725\"]],Cividis:[[0,\"rgb(0,32,76)\"],[.058824,\"rgb(0,42,102)\"],[.117647,\"rgb(0,52,110)\"],[.176471,\"rgb(39,63,108)\"],[.235294,\"rgb(60,74,107)\"],[.294118,\"rgb(76,85,107)\"],[.352941,\"rgb(91,95,109)\"],[.411765,\"rgb(104,106,112)\"],[.470588,\"rgb(117,117,117)\"],[.529412,\"rgb(131,129,120)\"],[.588235,\"rgb(146,140,120)\"],[.647059,\"rgb(161,152,118)\"],[.705882,\"rgb(176,165,114)\"],[.764706,\"rgb(192,177,109)\"],[.823529,\"rgb(209,191,102)\"],[.882353,\"rgb(225,204,92)\"],[.941176,\"rgb(243,219,79)\"],[1,\"rgb(255,233,69)\"]]},a=i.RdBu;function o(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var i=t[r];if(2!==i.length||+i[0]<e||!n(i[1]).isValid())return!1;e=+i[0]}return!0}e.exports={scales:i,defaultScale:a,get:function(t,e){if(e||(e=a),!t)return e;function r(){try{t=i[t]||JSON.parse(t)}catch(r){t=e}}return\"string\"==typeof t&&(r(),\"string\"==typeof t&&r()),o(t)?t:e},isValid:function(t){return void 0!==i[t]||o(t)}}},{tinycolor2:537}],609:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=(t-r)/(n-r),o=a+e/(n-r),s=(a+o)/2;return\"left\"===i||\"bottom\"===i?a:\"center\"===i||\"middle\"===i?s:\"right\"===i||\"top\"===i?o:a<2/3-s?a:o>4/3-s?o:s}},{}],610:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[\"sw-resize\",\"s-resize\",\"se-resize\"],[\"w-resize\",\"move\",\"e-resize\"],[\"nw-resize\",\"n-resize\",\"ne-resize\"]];e.exports=function(t,e,r,a){return t=\"left\"===r?0:\"center\"===r?1:\"right\"===r?2:n.constrain(Math.floor(3*t),0,2),e=\"bottom\"===a?0:\"middle\"===a?1:\"top\"===a?2:n.constrain(Math.floor(3*e),0,2),i[e][t]}},{\"../../lib\":719}],611:[function(t,e,r){\"use strict\";var n=t(\"mouse-event-offset\"),i=t(\"has-hover\"),a=t(\"has-passive-events\"),o=t(\"../../lib\").removeElement,s=t(\"../../plots/cartesian/constants\"),l=e.exports={};l.align=t(\"./align\"),l.getCursor=t(\"./cursor\");var c=t(\"./unhover\");function u(){var t=document.createElement(\"div\");t.className=\"dragcover\";var e=t.style;return e.position=\"fixed\",e.left=0,e.right=0,e.top=0,e.bottom=0,e.zIndex=999999999,e.background=\"none\",document.body.appendChild(t),t}function h(t){return n(t.changedTouches?t.changedTouches[0]:t,document.body)}l.unhover=c.wrapped,l.unhoverRaw=c.raw,l.init=function(t){var e,r,n,c,f,p,d,g,v=t.gd,m=1,y=v._context.doubleClickDelay,x=t.element;v._mouseDownTime||(v._mouseDownTime=0),x.style.pointerEvents=\"all\",x.onmousedown=_,a?(x._ontouchstart&&x.removeEventListener(\"touchstart\",x._ontouchstart),x._ontouchstart=_,x.addEventListener(\"touchstart\",_,{passive:!1})):x.ontouchstart=_;var b=t.clampFn||function(t,e,r){return Math.abs(t)<r&&(t=0),Math.abs(e)<r&&(e=0),[t,e]};function _(a){v._dragged=!1,v._dragging=!0;var o=h(a);e=o[0],r=o[1],d=a.target,p=a,g=2===a.buttons||a.ctrlKey,\"undefined\"==typeof a.clientX&&\"undefined\"==typeof a.clientY&&(a.clientX=e,a.clientY=r),(n=(new Date).getTime())-v._mouseDownTime<y?m+=1:(m=1,v._mouseDownTime=n),t.prepFn&&t.prepFn(a,e,r),i&&!g?(f=u()).style.cursor=window.getComputedStyle(x).cursor:i||(f=document,c=window.getComputedStyle(document.documentElement).cursor,document.documentElement.style.cursor=window.getComputedStyle(x).cursor),document.addEventListener(\"mouseup\",k),document.addEventListener(\"touchend\",k),!1!==t.dragmode&&(a.preventDefault(),document.addEventListener(\"mousemove\",w),document.addEventListener(\"touchmove\",w))}function w(n){n.preventDefault();var i=h(n),a=t.minDrag||s.MINDRAG,o=b(i[0]-e,i[1]-r,a),c=o[0],u=o[1];(c||u)&&(v._dragged=!0,l.unhover(v)),v._dragged&&t.moveFn&&!g&&(v._dragdata={element:x,dx:c,dy:u},t.moveFn(c,u))}function k(e){if(delete v._dragdata,!1!==t.dragmode&&(e.preventDefault(),document.removeEventListener(\"mousemove\",w),document.removeEventListener(\"touchmove\",w)),document.removeEventListener(\"mouseup\",k),document.removeEventListener(\"touchend\",k),i?o(f):c&&(f.documentElement.style.cursor=c,c=null),v._dragging){if(v._dragging=!1,(new Date).getTime()-v._mouseDownTime>y&&(m=Math.max(m-1,1)),v._dragged)t.doneFn&&t.doneFn();else if(t.clickFn&&t.clickFn(m,p),!g){var r;try{r=new MouseEvent(\"click\",e)}catch(t){var n=h(e);(r=document.createEvent(\"MouseEvents\")).initMouseEvent(\"click\",e.bubbles,e.cancelable,e.view,e.detail,e.screenX,e.screenY,n[0],n[1],e.ctrlKey,e.altKey,e.shiftKey,e.metaKey,e.button,e.relatedTarget)}d.dispatchEvent(r)}v._dragging=!1,v._dragged=!1}else v._dragged=!1}},l.coverSlip=u},{\"../../lib\":719,\"../../plots/cartesian/constants\":773,\"./align\":609,\"./cursor\":610,\"./unhover\":612,\"has-hover\":410,\"has-passive-events\":411,\"mouse-event-offset\":436}],612:[function(t,e,r){\"use strict\";var n=t(\"../../lib/events\"),i=t(\"../../lib/throttle\"),a=t(\"../../lib/dom\").getGraphDiv,o=t(\"../fx/constants\"),s=e.exports={};s.wrapped=function(t,e,r){(t=a(t))._fullLayout&&i.clear(t._fullLayout._uid+o.HOVERID),s.raw(t,e,r)},s.raw=function(t,e){var r=t._fullLayout,i=t._hoverdata;e||(e={}),e.target&&!1===n.triggerHandler(t,\"plotly_beforehover\",e)||(r._hoverlayer.selectAll(\"g\").remove(),r._hoverlayer.selectAll(\"line\").remove(),r._hoverlayer.selectAll(\"circle\").remove(),t._hoverdata=void 0,e.target&&i&&t.emit(\"plotly_unhover\",{event:e,points:i}))}},{\"../../lib/dom\":708,\"../../lib/events\":709,\"../../lib/throttle\":744,\"../fx/constants\":626}],613:[function(t,e,r){\"use strict\";r.dash={valType:\"string\",values:[\"solid\",\"dot\",\"dash\",\"longdash\",\"dashdot\",\"longdashdot\"],dflt:\"solid\",editType:\"style\"}},{}],614:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../registry\"),s=t(\"../color\"),l=t(\"../colorscale\"),c=t(\"../../lib\"),u=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/xmlns_namespaces\"),f=t(\"../../constants/alignment\").LINE_SPACING,p=t(\"../../constants/interactions\").DESELECTDIM,d=t(\"../../traces/scatter/subtypes\"),g=t(\"../../traces/scatter/make_bubble_size_func\"),v=e.exports={};v.font=function(t,e,r,n){c.isPlainObject(e)&&(n=e.color,r=e.size,e=e.family),e&&t.style(\"font-family\",e),r+1&&t.style(\"font-size\",r+\"px\"),n&&t.call(s.fill,n)},v.setPosition=function(t,e,r){t.attr(\"x\",e).attr(\"y\",r)},v.setSize=function(t,e,r){t.attr(\"width\",e).attr(\"height\",r)},v.setRect=function(t,e,r,n,i){t.call(v.setPosition,e,r).call(v.setSize,n,i)},v.translatePoint=function(t,e,r,n){var a=r.c2p(t.x),o=n.c2p(t.y);return!!(i(a)&&i(o)&&e.node())&&(\"text\"===e.node().nodeName?e.attr(\"x\",a).attr(\"y\",o):e.attr(\"transform\",\"translate(\"+a+\",\"+o+\")\"),!0)},v.translatePoints=function(t,e,r){t.each(function(t){var i=n.select(this);v.translatePoint(t,i,e,r)})},v.hideOutsideRangePoint=function(t,e,r,n,i,a){e.attr(\"display\",r.isPtWithinRange(t,i)&&n.isPtWithinRange(t,a)?null:\"none\")},v.hideOutsideRangePoints=function(t,e){if(e._hasClipOnAxisFalse){var r=e.xaxis,i=e.yaxis;t.each(function(e){var a=e[0].trace,s=a.xcalendar,l=a.ycalendar,c=o.traceIs(a,\"bar-like\")?\".bartext\":\".point,.textpoint\";t.selectAll(c).each(function(t){v.hideOutsideRangePoint(t,n.select(this),r,i,s,l)})})}},v.crispRound=function(t,e,r){return e&&i(e)?t._context.staticPlot?e:e<1?1:Math.round(e):r||0},v.singleLineStyle=function(t,e,r,n,i){e.style(\"fill\",\"none\");var a=(((t||[])[0]||{}).trace||{}).line||{},o=r||a.width||0,l=i||a.dash||\"\";s.stroke(e,n||a.color),v.dashLine(e,l,o)},v.lineGroupStyle=function(t,e,r,i){t.style(\"fill\",\"none\").each(function(t){var a=(((t||[])[0]||{}).trace||{}).line||{},o=e||a.width||0,l=i||a.dash||\"\";n.select(this).call(s.stroke,r||a.color).call(v.dashLine,l,o)})},v.dashLine=function(t,e,r){r=+r||0,e=v.dashStyle(e,r),t.style({\"stroke-dasharray\":e,\"stroke-width\":r+\"px\"})},v.dashStyle=function(t,e){e=+e||1;var r=Math.max(e,3);return\"solid\"===t?t=\"\":\"dot\"===t?t=r+\"px,\"+r+\"px\":\"dash\"===t?t=3*r+\"px,\"+3*r+\"px\":\"longdash\"===t?t=5*r+\"px,\"+5*r+\"px\":\"dashdot\"===t?t=3*r+\"px,\"+r+\"px,\"+r+\"px,\"+r+\"px\":\"longdashdot\"===t&&(t=5*r+\"px,\"+2*r+\"px,\"+r+\"px,\"+2*r+\"px\"),t},v.singleFillStyle=function(t){var e=(((n.select(t.node()).data()[0]||[])[0]||{}).trace||{}).fillcolor;e&&t.call(s.fill,e)},v.fillGroupStyle=function(t){t.style(\"stroke-width\",0).each(function(t){var e=n.select(this);t[0].trace&&e.call(s.fill,t[0].trace.fillcolor)})};var m=t(\"./symbol_defs\");v.symbolNames=[],v.symbolFuncs=[],v.symbolNeedLines={},v.symbolNoDot={},v.symbolNoFill={},v.symbolList=[],Object.keys(m).forEach(function(t){var e=m[t];v.symbolList=v.symbolList.concat([e.n,t,e.n+100,t+\"-open\"]),v.symbolNames[e.n]=t,v.symbolFuncs[e.n]=e.f,e.needLine&&(v.symbolNeedLines[e.n]=!0),e.noDot?v.symbolNoDot[e.n]=!0:v.symbolList=v.symbolList.concat([e.n+200,t+\"-dot\",e.n+300,t+\"-open-dot\"]),e.noFill&&(v.symbolNoFill[e.n]=!0)});var y=v.symbolNames.length,x=\"M0,0.5L0.5,0L0,-0.5L-0.5,0Z\";function b(t,e){var r=t%100;return v.symbolFuncs[r](e)+(t>=200?x:\"\")}v.symbolNumber=function(t){if(\"string\"==typeof t){var e=0;t.indexOf(\"-open\")>0&&(e=100,t=t.replace(\"-open\",\"\")),t.indexOf(\"-dot\")>0&&(e+=200,t=t.replace(\"-dot\",\"\")),(t=v.symbolNames.indexOf(t))>=0&&(t+=e)}return t%100>=y||t>=400?0:Math.floor(Math.max(t,0))};var _={x1:1,x2:0,y1:0,y2:0},w={x1:0,x2:0,y1:1,y2:0},k=n.format(\"~.1f\"),T={radial:{node:\"radialGradient\"},radialreversed:{node:\"radialGradient\",reversed:!0},horizontal:{node:\"linearGradient\",attrs:_},horizontalreversed:{node:\"linearGradient\",attrs:_,reversed:!0},vertical:{node:\"linearGradient\",attrs:w},verticalreversed:{node:\"linearGradient\",attrs:w,reversed:!0}};v.gradient=function(t,e,r,i,o,l){for(var u=o.length,h=T[i],f=new Array(u),p=0;p<u;p++)h.reversed?f[u-1-p]=[k(100*(1-o[p][0])),o[p][1]]:f[p]=[k(100*o[p][0]),o[p][1]];var d=\"g\"+e._fullLayout._uid+\"-\"+r,g=e._fullLayout._defs.select(\".gradients\").selectAll(\"#\"+d).data([i+f.join(\";\")],c.identity);g.exit().remove(),g.enter().append(h.node).each(function(){var t=n.select(this);h.attrs&&t.attr(h.attrs),t.attr(\"id\",d);var e=t.selectAll(\"stop\").data(f);e.exit().remove(),e.enter().append(\"stop\"),e.each(function(t){var e=a(t[1]);n.select(this).attr({offset:t[0]+\"%\",\"stop-color\":s.tinyRGB(e),\"stop-opacity\":e.getAlpha()})})}),t.style(l,I(d,e)).style(l+\"-opacity\",null)},v.initGradients=function(t){c.ensureSingle(t._fullLayout._defs,\"g\",\"gradients\").selectAll(\"linearGradient,radialGradient\").remove()},v.pointStyle=function(t,e,r){if(t.size()){var i=v.makePointStyleFns(e);t.each(function(t){v.singlePointStyle(t,n.select(this),e,i,r)})}},v.singlePointStyle=function(t,e,r,n,i){var a=r.marker,o=a.line;if(e.style(\"opacity\",n.selectedOpacityFn?n.selectedOpacityFn(t):void 0===t.mo?a.opacity:t.mo),n.ms2mrc){var l;l=\"various\"===t.ms||\"various\"===a.size?3:n.ms2mrc(t.ms),t.mrc=l,n.selectedSizeFn&&(l=t.mrc=n.selectedSizeFn(t));var u=v.symbolNumber(t.mx||a.symbol)||0;t.om=u%200>=100,e.attr(\"d\",b(u,l))}var h,f,p,d=!1;if(t.so)p=o.outlierwidth,f=o.outliercolor,h=a.outliercolor;else{var g=(o||{}).width;p=(t.mlw+1||g+1||(t.trace?(t.trace.marker.line||{}).width:0)+1)-1||0,f=\"mlc\"in t?t.mlcc=n.lineScale(t.mlc):c.isArrayOrTypedArray(o.color)?s.defaultLine:o.color,c.isArrayOrTypedArray(a.color)&&(h=s.defaultLine,d=!0),h=\"mc\"in t?t.mcc=n.markerScale(t.mc):a.color||\"rgba(0,0,0,0)\",n.selectedColorFn&&(h=n.selectedColorFn(t))}if(t.om)e.call(s.stroke,h).style({\"stroke-width\":(p||1)+\"px\",fill:\"none\"});else{e.style(\"stroke-width\",p+\"px\");var m=a.gradient,y=t.mgt;if(y?d=!0:y=m&&m.type,Array.isArray(y)&&(y=y[0],T[y]||(y=0)),y&&\"none\"!==y){var x=t.mgc;x?d=!0:x=m.color;var _=r.uid;d&&(_+=\"-\"+t.i),v.gradient(e,i,_,y,[[0,x],[1,h]],\"fill\")}else s.fill(e,h);p&&s.stroke(e,f)}},v.makePointStyleFns=function(t){var e={},r=t.marker;return e.markerScale=v.tryColorscale(r,\"\"),e.lineScale=v.tryColorscale(r,\"line\"),o.traceIs(t,\"symbols\")&&(e.ms2mrc=d.isBubble(t)?g(t):function(){return(r.size||6)/2}),t.selectedpoints&&c.extendFlat(e,v.makeSelectedPointStyleFns(t)),e},v.makeSelectedPointStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.marker||{},a=r.marker||{},s=n.marker||{},l=i.opacity,u=a.opacity,h=s.opacity,f=void 0!==u,d=void 0!==h;(c.isArrayOrTypedArray(l)||f||d)&&(e.selectedOpacityFn=function(t){var e=void 0===t.mo?i.opacity:t.mo;return t.selected?f?u:e:d?h:p*e});var g=i.color,v=a.color,m=s.color;(v||m)&&(e.selectedColorFn=function(t){var e=t.mcc||g;return t.selected?v||e:m||e});var y=i.size,x=a.size,b=s.size,_=void 0!==x,w=void 0!==b;return o.traceIs(t,\"symbols\")&&(_||w)&&(e.selectedSizeFn=function(t){var e=t.mrc||y/2;return t.selected?_?x/2:e:w?b/2:e}),e},v.makeSelectedTextStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.textfont||{},a=r.textfont||{},o=n.textfont||{},l=i.color,c=a.color,u=o.color;return e.selectedTextColorFn=function(t){var e=t.tc||l;return t.selected?c||e:u||(c?e:s.addOpacity(e,p))},e},v.selectedPointStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=v.makeSelectedPointStyleFns(e),i=e.marker||{},a=[];r.selectedOpacityFn&&a.push(function(t,e){t.style(\"opacity\",r.selectedOpacityFn(e))}),r.selectedColorFn&&a.push(function(t,e){s.fill(t,r.selectedColorFn(e))}),r.selectedSizeFn&&a.push(function(t,e){var n=e.mx||i.symbol||0,a=r.selectedSizeFn(e);t.attr(\"d\",b(v.symbolNumber(n),a)),e.mrc2=a}),a.length&&t.each(function(t){for(var e=n.select(this),r=0;r<a.length;r++)a[r](e,t)})}},v.tryColorscale=function(t,e){var r=e?c.nestedProperty(t,e).get():t;if(r){var n=r.color;if((r.colorscale||r._colorAx)&&c.isArrayOrTypedArray(n))return l.makeColorScaleFuncFromTrace(r)}return c.identity};var A={start:1,end:-1,middle:0,bottom:1,top:-1};function M(t,e,r,i){var a=n.select(t.node().parentNode),o=-1!==e.indexOf(\"top\")?\"top\":-1!==e.indexOf(\"bottom\")?\"bottom\":\"middle\",s=-1!==e.indexOf(\"left\")?\"end\":-1!==e.indexOf(\"right\")?\"start\":\"middle\",l=i?i/.8+1:0,c=(u.lineCount(t)-1)*f+1,h=A[s]*l,p=.75*r+A[o]*l+(A[o]-1)*c*r/2;t.attr(\"text-anchor\",s),a.attr(\"transform\",\"translate(\"+h+\",\"+p+\")\")}function S(t,e){var r=t.ts||e.textfont.size;return i(r)&&r>0?r:0}v.textPointStyle=function(t,e,r){if(t.size()){var i;if(e.selectedpoints){var a=v.makeSelectedTextStyleFns(e);i=a.selectedTextColorFn}t.each(function(t){var a=n.select(this),o=c.extractOption(t,e,\"tx\",\"text\");if(o||0===o){var s=t.tp||e.textposition,l=S(t,e),h=i?i(t):t.tc||e.textfont.color;a.call(v.font,t.tf||e.textfont.family,l,h).text(o).call(u.convertToTspans,r).call(M,s,l,t.mrc)}else a.remove()})}},v.selectedTextStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=v.makeSelectedTextStyleFns(e);t.each(function(t){var i=n.select(this),a=r.selectedTextColorFn(t),o=t.tp||e.textposition,l=S(t,e);s.fill(i,a),M(i,o,l,t.mrc2||t.mrc)})}};var E=.5;function C(t,e,r,i){var a=t[0]-e[0],o=t[1]-e[1],s=r[0]-e[0],l=r[1]-e[1],c=Math.pow(a*a+o*o,E/2),u=Math.pow(s*s+l*l,E/2),h=(u*u*a-c*c*s)*i,f=(u*u*o-c*c*l)*i,p=3*u*(c+u),d=3*c*(c+u);return[[n.round(e[0]+(p&&h/p),2),n.round(e[1]+(p&&f/p),2)],[n.round(e[0]-(d&&h/d),2),n.round(e[1]-(d&&f/d),2)]]}v.smoothopen=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\");var r,n=\"M\"+t[0],i=[];for(r=1;r<t.length-1;r++)i.push(C(t[r-1],t[r],t[r+1],e));for(n+=\"Q\"+i[0][0]+\" \"+t[1],r=2;r<t.length-1;r++)n+=\"C\"+i[r-2][1]+\" \"+i[r-1][0]+\" \"+t[r];return n+=\"Q\"+i[t.length-3][1]+\" \"+t[t.length-1]},v.smoothclosed=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\")+\"Z\";var r,n=\"M\"+t[0],i=t.length-1,a=[C(t[i],t[0],t[1],e)];for(r=1;r<i;r++)a.push(C(t[r-1],t[r],t[r+1],e));for(a.push(C(t[i-1],t[i],t[0],e)),r=1;r<=i;r++)n+=\"C\"+a[r-1][1]+\" \"+a[r][0]+\" \"+t[r];return n+=\"C\"+a[i][1]+\" \"+a[0][0]+\" \"+t[0]+\"Z\"};var L={hv:function(t,e){return\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)},vh:function(t,e){return\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},hvh:function(t,e){return\"H\"+n.round((t[0]+e[0])/2,2)+\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},vhv:function(t,e){return\"V\"+n.round((t[1]+e[1])/2,2)+\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)}},P=function(t,e){return\"L\"+n.round(e[0],2)+\",\"+n.round(e[1],2)};v.steps=function(t){var e=L[t]||P;return function(t){for(var r=\"M\"+n.round(t[0][0],2)+\",\"+n.round(t[0][1],2),i=1;i<t.length;i++)r+=e(t[i-1],t[i]);return r}},v.makeTester=function(){var t=c.ensureSingleById(n.select(\"body\"),\"svg\",\"js-plotly-tester\",function(t){t.attr(h.svgAttrs).style({position:\"absolute\",left:\"-10000px\",top:\"-10000px\",width:\"9000px\",height:\"9000px\",\"z-index\":\"1\"})}),e=c.ensureSingle(t,\"path\",\"js-reference-point\",function(t){t.attr(\"d\",\"M0,0H1V1H0Z\").style({\"stroke-width\":0,fill:\"black\"})});v.tester=t,v.testref=e},v.savedBBoxes={};var O=0;function z(t){var e=t.getAttribute(\"data-unformatted\");if(null!==e)return e+t.getAttribute(\"data-math\")+t.getAttribute(\"text-anchor\")+t.getAttribute(\"style\")}function I(t,e){if(!t)return null;var r=e._context;return\"url('\"+(r._exportedPlot?\"\":r._baseUrl||\"\")+\"#\"+t+\"')\"}v.bBox=function(t,e,r){var i,a,o;if(r||(r=z(t)),r){if(i=v.savedBBoxes[r])return c.extendFlat({},i)}else if(1===t.childNodes.length){var s=t.childNodes[0];if(r=z(s)){var l=+s.getAttribute(\"x\")||0,h=+s.getAttribute(\"y\")||0,f=s.getAttribute(\"transform\");if(!f){var p=v.bBox(s,!1,r);return l&&(p.left+=l,p.right+=l),h&&(p.top+=h,p.bottom+=h),p}if(r+=\"~\"+l+\"~\"+h+\"~\"+f,i=v.savedBBoxes[r])return c.extendFlat({},i)}}e?a=t:(o=v.tester.node(),a=t.cloneNode(!0),o.appendChild(a)),n.select(a).attr(\"transform\",null).call(u.positionText,0,0);var d=a.getBoundingClientRect(),g=v.testref.node().getBoundingClientRect();e||o.removeChild(a);var m={height:d.height,width:d.width,left:d.left-g.left,top:d.top-g.top,right:d.right-g.left,bottom:d.bottom-g.top};return O>=1e4&&(v.savedBBoxes={},O=0),r&&(v.savedBBoxes[r]=m),O++,c.extendFlat({},m)},v.setClipUrl=function(t,e,r){t.attr(\"clip-path\",I(e,r))},v.getTranslate=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\btranslate\\((-?\\d*\\.?\\d*)[^-\\d]*(-?\\d*\\.?\\d*)[^\\d].*/,function(t,e,r){return[e,r].join(\" \")}).split(\" \");return{x:+e[0]||0,y:+e[1]||0}},v.setTranslate=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||0,r=r||0,a=a.replace(/(\\btranslate\\(.*?\\);?)/,\"\").trim(),a=(a+=\" translate(\"+e+\", \"+r+\")\").trim(),t[i](\"transform\",a),a},v.getScale=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\bscale\\((\\d*\\.?\\d*)[^\\d]*(\\d*\\.?\\d*)[^\\d].*/,function(t,e,r){return[e,r].join(\" \")}).split(\" \");return{x:+e[0]||1,y:+e[1]||1}},v.setScale=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||1,r=r||1,a=a.replace(/(\\bscale\\(.*?\\);?)/,\"\").trim(),a=(a+=\" scale(\"+e+\", \"+r+\")\").trim(),t[i](\"transform\",a),a};var D=/\\s*sc.*/;v.setPointGroupScale=function(t,e,r){if(e=e||1,r=r||1,t){var n=1===e&&1===r?\"\":\" scale(\"+e+\",\"+r+\")\";t.each(function(){var t=(this.getAttribute(\"transform\")||\"\").replace(D,\"\");t=(t+=n).trim(),this.setAttribute(\"transform\",t)})}};var R=/translate\\([^)]*\\)\\s*$/;v.setTextPointsScale=function(t,e,r){t&&t.each(function(){var t,i=n.select(this),a=i.select(\"text\");if(a.node()){var o=parseFloat(a.attr(\"x\")||0),s=parseFloat(a.attr(\"y\")||0),l=(i.attr(\"transform\")||\"\").match(R);t=1===e&&1===r?[]:[\"translate(\"+o+\",\"+s+\")\",\"scale(\"+e+\",\"+r+\")\",\"translate(\"+-o+\",\"+-s+\")\"],l&&t.push(l),i.attr(\"transform\",t.join(\" \"))}})}},{\"../../constants/alignment\":688,\"../../constants/interactions\":694,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../registry\":847,\"../../traces/scatter/make_bubble_size_func\":1128,\"../../traces/scatter/subtypes\":1135,\"../color\":593,\"../colorscale\":605,\"./symbol_defs\":615,d3:163,\"fast-isnumeric\":225,tinycolor2:537}],615:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports={circle:{n:0,f:function(t){var e=n.round(t,2);return\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"}},square:{n:1,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"}},diamond:{n:2,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"Z\"}},cross:{n:3,f:function(t){var e=n.round(.4*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H\"+e+\"V\"+r+\"H-\"+e+\"V\"+e+\"H-\"+r+\"V-\"+e+\"H-\"+e+\"V-\"+r+\"H\"+e+\"V-\"+e+\"H\"+r+\"Z\"}},x:{n:4,f:function(t){var e=n.round(.8*t/Math.sqrt(2),2),r=\"l\"+e+\",\"+e,i=\"l\"+e+\",-\"+e,a=\"l-\"+e+\",-\"+e,o=\"l-\"+e+\",\"+e;return\"M0,\"+e+r+i+a+i+a+o+a+o+r+o+r+\"Z\"}},\"triangle-up\":{n:5,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",\"+n.round(t/2,2)+\"H\"+e+\"L0,-\"+n.round(t,2)+\"Z\"}},\"triangle-down\":{n:6,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",-\"+n.round(t/2,2)+\"H\"+e+\"L0,\"+n.round(t,2)+\"Z\"}},\"triangle-left\":{n:7,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L-\"+n.round(t,2)+\",0Z\"}},\"triangle-right\":{n:8,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L\"+n.round(t,2)+\",0Z\"}},\"triangle-ne\":{n:9,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+r+\",-\"+e+\"H\"+e+\"V\"+r+\"Z\"}},\"triangle-se\":{n:10,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+e+\",-\"+r+\"V\"+e+\"H-\"+r+\"Z\"}},\"triangle-sw\":{n:11,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H-\"+e+\"V-\"+r+\"Z\"}},\"triangle-nw\":{n:12,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+e+\",\"+r+\"V-\"+e+\"H\"+r+\"Z\"}},pentagon:{n:13,f:function(t){var e=n.round(.951*t,2),r=n.round(.588*t,2),i=n.round(-t,2),a=n.round(-.309*t,2);return\"M\"+e+\",\"+a+\"L\"+r+\",\"+n.round(.809*t,2)+\"H-\"+r+\"L-\"+e+\",\"+a+\"L0,\"+i+\"Z\"}},hexagon:{n:14,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M\"+i+\",-\"+r+\"V\"+r+\"L0,\"+e+\"L-\"+i+\",\"+r+\"V-\"+r+\"L0,-\"+e+\"Z\"}},hexagon2:{n:15,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M-\"+r+\",\"+i+\"H\"+r+\"L\"+e+\",0L\"+r+\",-\"+i+\"H-\"+r+\"L-\"+e+\",0Z\"}},octagon:{n:16,f:function(t){var e=n.round(.924*t,2),r=n.round(.383*t,2);return\"M-\"+r+\",-\"+e+\"H\"+r+\"L\"+e+\",-\"+r+\"V\"+r+\"L\"+r+\",\"+e+\"H-\"+r+\"L-\"+e+\",\"+r+\"V-\"+r+\"Z\"}},star:{n:17,f:function(t){var e=1.4*t,r=n.round(.225*e,2),i=n.round(.951*e,2),a=n.round(.363*e,2),o=n.round(.588*e,2),s=n.round(-e,2),l=n.round(-.309*e,2),c=n.round(.118*e,2),u=n.round(.809*e,2);return\"M\"+r+\",\"+l+\"H\"+i+\"L\"+a+\",\"+c+\"L\"+o+\",\"+u+\"L0,\"+n.round(.382*e,2)+\"L-\"+o+\",\"+u+\"L-\"+a+\",\"+c+\"L-\"+i+\",\"+l+\"H-\"+r+\"L0,\"+s+\"Z\"}},hexagram:{n:18,f:function(t){var e=n.round(.66*t,2),r=n.round(.38*t,2),i=n.round(.76*t,2);return\"M-\"+i+\",0l-\"+r+\",-\"+e+\"h\"+i+\"l\"+r+\",-\"+e+\"l\"+r+\",\"+e+\"h\"+i+\"l-\"+r+\",\"+e+\"l\"+r+\",\"+e+\"h-\"+i+\"l-\"+r+\",\"+e+\"l-\"+r+\",-\"+e+\"h-\"+i+\"Z\"}},\"star-triangle-up\":{n:19,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M-\"+e+\",\"+r+o+e+\",\"+r+o+\"0,-\"+i+o+\"-\"+e+\",\"+r+\"Z\"}},\"star-triangle-down\":{n:20,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M\"+e+\",-\"+r+o+\"-\"+e+\",-\"+r+o+\"0,\"+i+o+e+\",-\"+r+\"Z\"}},\"star-square\":{n:21,f:function(t){var e=n.round(1.1*t,2),r=n.round(2*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",-\"+e+i+\"-\"+e+\",\"+e+i+e+\",\"+e+i+e+\",-\"+e+i+\"-\"+e+\",-\"+e+\"Z\"}},\"star-diamond\":{n:22,f:function(t){var e=n.round(1.4*t,2),r=n.round(1.9*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",0\"+i+\"0,\"+e+i+e+\",0\"+i+\"0,-\"+e+i+\"-\"+e+\",0Z\"}},\"diamond-tall\":{n:23,f:function(t){var e=n.round(.7*t,2),r=n.round(1.4*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},\"diamond-wide\":{n:24,f:function(t){var e=n.round(1.4*t,2),r=n.round(.7*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},hourglass:{n:25,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"L\"+e+\",-\"+e+\"H-\"+e+\"Z\"},noDot:!0},bowtie:{n:26,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"V-\"+e+\"L-\"+e+\",\"+e+\"V-\"+e+\"Z\"},noDot:!0},\"circle-cross\":{n:27,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"circle-x\":{n:28,f:function(t){var e=n.round(t,2),r=n.round(t/Math.sqrt(2),2);return\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"square-cross\":{n:29,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"square-x\":{n:30,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"diamond-cross\":{n:31,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM0,-\"+e+\"V\"+e+\"M-\"+e+\",0H\"+e},needLine:!0,noDot:!0},\"diamond-x\":{n:32,f:function(t){var e=n.round(1.3*t,2),r=n.round(.65*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM-\"+r+\",-\"+r+\"L\"+r+\",\"+r+\"M-\"+r+\",\"+r+\"L\"+r+\",-\"+r},needLine:!0,noDot:!0},\"cross-thin\":{n:33,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"x-thin\":{n:34,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},asterisk:{n:35,f:function(t){var e=n.round(1.2*t,2),r=n.round(.85*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r},needLine:!0,noDot:!0,noFill:!0},hash:{n:36,f:function(t){var e=n.round(t/2,2),r=n.round(t,2);return\"M\"+e+\",\"+r+\"V-\"+r+\"m-\"+r+\",0V\"+r+\"M\"+r+\",\"+e+\"H-\"+r+\"m0,-\"+r+\"H\"+r},needLine:!0,noFill:!0},\"y-up\":{n:37,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",\"+i+\"L0,0M\"+e+\",\"+i+\"L0,0M0,-\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-down\":{n:38,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",-\"+i+\"L0,0M\"+e+\",-\"+i+\"L0,0M0,\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-left\":{n:39,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M\"+i+\",\"+e+\"L0,0M\"+i+\",-\"+e+\"L0,0M-\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-right\":{n:40,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+i+\",\"+e+\"L0,0M-\"+i+\",-\"+e+\"L0,0M\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"line-ew\":{n:41,f:function(t){var e=n.round(1.4*t,2);return\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ns\":{n:42,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ne\":{n:43,f:function(t){var e=n.round(t,2);return\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-nw\":{n:44,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e},needLine:!0,noDot:!0,noFill:!0}}},{d3:163}],616:[function(t,e,r){\"use strict\";e.exports={visible:{valType:\"boolean\",editType:\"calc\"},type:{valType:\"enumerated\",values:[\"percent\",\"constant\",\"sqrt\",\"data\"],editType:\"calc\"},symmetric:{valType:\"boolean\",editType:\"calc\"},array:{valType:\"data_array\",editType:\"calc\"},arrayminus:{valType:\"data_array\",editType:\"calc\"},value:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},valueminus:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},traceref:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},tracerefminus:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},copy_ystyle:{valType:\"boolean\",editType:\"plot\"},copy_zstyle:{valType:\"boolean\",editType:\"style\"},color:{valType:\"color\",editType:\"style\"},thickness:{valType:\"number\",min:0,dflt:2,editType:\"style\"},width:{valType:\"number\",min:0,editType:\"plot\"},editType:\"calc\",_deprecated:{opacity:{valType:\"number\",editType:\"style\"}}}},{}],617:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=t(\"./compute_error\");function l(t,e,r,i){var l=e[\"error_\"+i]||{},c=[];if(l.visible&&-1!==[\"linear\",\"log\"].indexOf(r.type)){for(var u=s(l),h=0;h<t.length;h++){var f=t[h],p=f.i;if(void 0===p)p=h;else if(null===p)continue;var d=f[i];if(n(r.c2l(d))){var g=u(d,p);if(n(g[0])&&n(g[1])){var v=f[i+\"s\"]=d-g[0],m=f[i+\"h\"]=d+g[1];c.push(v,m)}}}var y=r._id,x=e._extremes[y],b=a.findExtremes(r,c,o.extendFlat({tozero:x.opts.tozero},{padded:!0}));x.min=x.min.concat(b.min),x.max=x.max.concat(b.max)}}e.exports=function(t){for(var e=t.calcdata,r=0;r<e.length;r++){var n=e[r],o=n[0].trace;if(!0===o.visible&&i.traceIs(o,\"errorBarsOK\")){var s=a.getFromId(t,o.xaxis),c=a.getFromId(t,o.yaxis);l(n,o,s,\"x\"),l(n,o,c,\"y\")}}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./compute_error\":618,\"fast-isnumeric\":225}],618:[function(t,e,r){\"use strict\";function n(t,e){return\"percent\"===t?function(t){return Math.abs(t*e/100)}:\"constant\"===t?function(){return Math.abs(e)}:\"sqrt\"===t?function(t){return Math.sqrt(Math.abs(t))}:void 0}e.exports=function(t){var e=t.type,r=t.symmetric;if(\"data\"===e){var i=t.array||[];if(r)return function(t,e){var r=+i[e];return[r,r]};var a=t.arrayminus||[];return function(t,e){var r=+i[e],n=+a[e];return isNaN(r)&&isNaN(n)?[NaN,NaN]:[n||0,r||0]}}var o=n(e,t.value),s=n(e,t.valueminus);return r||void 0===t.valueminus?function(t){var e=o(t);return[e,e]}:function(t){return[s(t),o(t)]}}},{}],619:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../plot_api/plot_template\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){var c=\"error_\"+l.axis,u=o.newContainer(e,c),h=t[c]||{};function f(t,e){return a.coerce(h,u,s,t,e)}if(!1!==f(\"visible\",void 0!==h.array||void 0!==h.value||\"sqrt\"===h.type)){var p=f(\"type\",\"array\"in h?\"data\":\"percent\"),d=!0;\"sqrt\"!==p&&(d=f(\"symmetric\",!((\"data\"===p?\"arrayminus\":\"valueminus\")in h))),\"data\"===p?(f(\"array\"),f(\"traceref\"),d||(f(\"arrayminus\"),f(\"tracerefminus\"))):\"percent\"!==p&&\"constant\"!==p||(f(\"value\"),d||f(\"valueminus\"));var g=\"copy_\"+l.inherit+\"style\";if(l.inherit)(e[\"error_\"+l.inherit]||{}).visible&&f(g,!(h.color||n(h.thickness)||n(h.width)));l.inherit&&u[g]||(f(\"color\",r),f(\"thickness\"),f(\"width\",i.traceIs(e,\"gl3d\")?0:4))}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../registry\":847,\"./attributes\":616,\"fast-isnumeric\":225}],620:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"./attributes\"),o={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a)};delete o.error_x.copy_zstyle,delete o.error_y.copy_zstyle,delete o.error_y.copy_ystyle;var s={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a),error_z:n.extendFlat({},a)};delete s.error_x.copy_ystyle,delete s.error_y.copy_ystyle,delete s.error_z.copy_ystyle,delete s.error_z.copy_zstyle,e.exports={moduleType:\"component\",name:\"errorbars\",schema:{traces:{scatter:o,bar:o,histogram:o,scatter3d:i(s,\"calc\",\"nested\"),scattergl:i(o,\"calc\",\"nested\")}},supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),makeComputeError:t(\"./compute_error\"),plot:t(\"./plot\"),style:t(\"./style\"),hoverInfo:function(t,e,r){(e.error_y||{}).visible&&(r.yerr=t.yh-t.y,e.error_y.symmetric||(r.yerrneg=t.y-t.ys));(e.error_x||{}).visible&&(r.xerr=t.xh-t.x,e.error_x.symmetric||(r.xerrneg=t.x-t.xs))}}},{\"../../lib\":719,\"../../plot_api/edit_types\":750,\"./attributes\":616,\"./calc\":617,\"./compute_error\":618,\"./defaults\":619,\"./plot\":621,\"./style\":622}],621:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../drawing\"),o=t(\"../../traces/scatter/subtypes\");e.exports=function(t,e,r,s){var l=r.xaxis,c=r.yaxis,u=s&&s.duration>0;e.each(function(e){var h,f=e[0].trace,p=f.error_x||{},d=f.error_y||{};f.ids&&(h=function(t){return t.id});var g=o.hasMarkers(f)&&f.marker.maxdisplayed>0;d.visible||p.visible||(e=[]);var v=n.select(this).selectAll(\"g.errorbar\").data(e,h);if(v.exit().remove(),e.length){p.visible||v.selectAll(\"path.xerror\").remove(),d.visible||v.selectAll(\"path.yerror\").remove(),v.style(\"opacity\",1);var m=v.enter().append(\"g\").classed(\"errorbar\",!0);u&&m.style(\"opacity\",0).transition().duration(s.duration).style(\"opacity\",1),a.setClipUrl(v,r.layerClipId,t),v.each(function(t){var e=n.select(this),r=function(t,e,r){var n={x:e.c2p(t.x),y:r.c2p(t.y)};void 0!==t.yh&&(n.yh=r.c2p(t.yh),n.ys=r.c2p(t.ys),i(n.ys)||(n.noYS=!0,n.ys=r.c2p(t.ys,!0)));void 0!==t.xh&&(n.xh=e.c2p(t.xh),n.xs=e.c2p(t.xs),i(n.xs)||(n.noXS=!0,n.xs=e.c2p(t.xs,!0)));return n}(t,l,c);if(!g||t.vis){var a,o=e.select(\"path.yerror\");if(d.visible&&i(r.x)&&i(r.yh)&&i(r.ys)){var h=d.width;a=\"M\"+(r.x-h)+\",\"+r.yh+\"h\"+2*h+\"m-\"+h+\",0V\"+r.ys,r.noYS||(a+=\"m-\"+h+\",0h\"+2*h),!o.size()?o=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"yerror\",!0):u&&(o=o.transition().duration(s.duration).ease(s.easing)),o.attr(\"d\",a)}else o.remove();var f=e.select(\"path.xerror\");if(p.visible&&i(r.y)&&i(r.xh)&&i(r.xs)){var v=(p.copy_ystyle?d:p).width;a=\"M\"+r.xh+\",\"+(r.y-v)+\"v\"+2*v+\"m0,-\"+v+\"H\"+r.xs,r.noXS||(a+=\"m0,-\"+v+\"v\"+2*v),!f.size()?f=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"xerror\",!0):u&&(f=f.transition().duration(s.duration).ease(s.easing)),f.attr(\"d\",a)}else f.remove()}})}})}},{\"../../traces/scatter/subtypes\":1135,\"../drawing\":614,d3:163,\"fast-isnumeric\":225}],622:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\");e.exports=function(t){t.each(function(t){var e=t[0].trace,r=e.error_y||{},a=e.error_x||{},o=n.select(this);o.selectAll(\"path.yerror\").style(\"stroke-width\",r.thickness+\"px\").call(i.stroke,r.color),a.copy_ystyle&&(a=r),o.selectAll(\"path.xerror\").style(\"stroke-width\",a.thickness+\"px\").call(i.stroke,a.color)})}},{\"../color\":593,d3:163}],623:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./layout_attributes\").hoverlabel,a=t(\"../../lib/extend\").extendFlat;e.exports={hoverlabel:{bgcolor:a({},i.bgcolor,{arrayOk:!0}),bordercolor:a({},i.bordercolor,{arrayOk:!0}),font:n({arrayOk:!0,editType:\"none\"}),align:a({},i.align,{arrayOk:!0}),namelength:a({},i.namelength,{arrayOk:!0}),editType:\"none\"}}},{\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"./layout_attributes\":633}],624:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");function a(t,e,r,i){i=i||n.identity,Array.isArray(t)&&(e[0][r]=i(t))}e.exports=function(t){var e=t.calcdata,r=t._fullLayout;function o(t){return function(e){return n.coerceHoverinfo({hoverinfo:e},{_module:t._module},r)}}for(var s=0;s<e.length;s++){var l=e[s],c=l[0].trace;if(!i.traceIs(c,\"pie-like\")){var u=i.traceIs(c,\"2dMap\")?a:n.fillArray;u(c.hoverinfo,l,\"hi\",o(c)),c.hovertemplate&&u(c.hovertemplate,l,\"ht\"),c.hoverlabel&&(u(c.hoverlabel.bgcolor,l,\"hbg\"),u(c.hoverlabel.bordercolor,l,\"hbc\"),u(c.hoverlabel.font.size,l,\"hts\"),u(c.hoverlabel.font.color,l,\"htc\"),u(c.hoverlabel.font.family,l,\"htf\"),u(c.hoverlabel.namelength,l,\"hnl\"),u(c.hoverlabel.align,l,\"hta\"))}}}},{\"../../lib\":719,\"../../registry\":847}],625:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./hover\").hover;e.exports=function(t,e,r){var a=n.getComponentMethod(\"annotations\",\"onClick\")(t,t._hoverdata);function o(){t.emit(\"plotly_click\",{points:t._hoverdata,event:e})}void 0!==r&&i(t,e,r,!0),t._hoverdata&&e&&e.target&&(a&&a.then?a.then(o):o(),e.stopImmediatePropagation&&e.stopImmediatePropagation())}},{\"../../registry\":847,\"./hover\":629}],626:[function(t,e,r){\"use strict\";e.exports={YANGLE:60,HOVERARROWSIZE:6,HOVERTEXTPAD:3,HOVERFONTSIZE:13,HOVERFONT:\"Arial, sans-serif\",HOVERMINTIME:50,HOVERID:\"-hover\"}},{}],627:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./hoverlabel_defaults\");e.exports=function(t,e,r,o){var s=n.extendFlat({},o.hoverlabel);e.hovertemplate&&(s.namelength=-1),a(t,e,function(r,a){return n.coerce(t,e,i,r,a)},s)}},{\"../../lib\":719,\"./attributes\":623,\"./hoverlabel_defaults\":630}],628:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");r.getSubplot=function(t){return t.subplot||t.xaxis+t.yaxis||t.geo},r.isTraceInSubplots=function(t,e){if(\"splom\"===t.type){for(var n=t.xaxes||[],i=t.yaxes||[],a=0;a<n.length;a++)for(var o=0;o<i.length;o++)if(-1!==e.indexOf(n[a]+i[o]))return!0;return!1}return-1!==e.indexOf(r.getSubplot(t))},r.flat=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=e;return r},r.p2c=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=t[n].p2c(e);return r},r.getDistanceFunction=function(t,e,n,i){return\"closest\"===t?i||r.quadrature(e,n):\"x\"===t?e:n},r.getClosest=function(t,e,r){if(!1!==r.index)r.index>=0&&r.index<t.length?r.distance=0:r.index=!1;else for(var n=0;n<t.length;n++){var i=e(t[n]);i<=r.distance&&(r.index=n,r.distance=i)}return r},r.inbox=function(t,e,r){return t*e<0||0===t?r:1/0},r.quadrature=function(t,e){return function(r){var n=t(r),i=e(r);return Math.sqrt(n*n+i*i)}},r.makeEventData=function(t,e,n){var i=\"index\"in t?t.index:t.pointNumber,a={data:e._input,fullData:e,curveNumber:e.index,pointNumber:i};if(e._indexToPoints){var o=e._indexToPoints[i];1===o.length?a.pointIndex=o[0]:a.pointIndices=o}else a.pointIndex=i;return e._module.eventData?a=e._module.eventData(a,t,e,n,i):(\"xVal\"in t?a.x=t.xVal:\"x\"in t&&(a.x=t.x),\"yVal\"in t?a.y=t.yVal:\"y\"in t&&(a.y=t.y),t.xa&&(a.xaxis=t.xa),t.ya&&(a.yaxis=t.ya),void 0!==t.zLabelVal&&(a.z=t.zLabelVal)),r.appendArrayPointValue(a,e,i),a},r.appendArrayPointValue=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){var u=o(n.nestedProperty(e,l).get(),r);void 0!==u&&(t[c]=u)}}},r.appendArrayMultiPointValues=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){for(var u=n.nestedProperty(e,l).get(),h=new Array(r.length),f=0;f<r.length;f++)h[f]=o(u,r[f]);t[c]=h}}};var i={ids:\"id\",locations:\"location\",labels:\"label\",values:\"value\",\"marker.colors\":\"color\",parents:\"parent\"};function a(t){return i[t]||t}function o(t,e){return Array.isArray(e)?Array.isArray(t)&&Array.isArray(t[e[0]])?t[e[0]][e[1]]:void 0:t[e]}},{\"../../lib\":719}],629:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../lib\"),s=t(\"../../lib/events\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib/override_cursor\"),u=t(\"../drawing\"),h=t(\"../color\"),f=t(\"../dragelement\"),p=t(\"../../plots/cartesian/axes\"),d=t(\"../../registry\"),g=t(\"./helpers\"),v=t(\"./constants\"),m=v.YANGLE,y=Math.PI*m/180,x=1/Math.sin(y),b=Math.cos(y),_=Math.sin(y),w=v.HOVERARROWSIZE,k=v.HOVERTEXTPAD;r.hover=function(t,e,r,a){t=o.getGraphDiv(t),o.throttle(t._fullLayout._uid+v.HOVERID,v.HOVERMINTIME,function(){!function(t,e,r,a){r||(r=\"xy\");var l=Array.isArray(r)?r:[r],u=t._fullLayout,v=u._plots||[],m=v[r],y=u._has(\"cartesian\");if(m){var b=m.overlays.map(function(t){return t.id});l=l.concat(b)}for(var _=l.length,w=new Array(_),k=new Array(_),T=!1,L=0;L<_;L++){var P=l[L],O=v[P];if(O)T=!0,w[L]=p.getFromId(t,O.xaxis._id),k[L]=p.getFromId(t,O.yaxis._id);else{var z=u[P]._subplot;w[L]=z.xaxis,k[L]=z.yaxis}}var I=e.hovermode||u.hovermode;I&&!T&&(I=\"closest\");if(-1===[\"x\",\"y\",\"closest\"].indexOf(I)||!t.calcdata||t.querySelector(\".zoombox\")||t._dragging)return f.unhoverRaw(t,e);var D,R,F,B,N,j,U,V,q,H,G,Y,W,X=-1===u.hoverdistance?1/0:u.hoverdistance,Z=-1===u.spikedistance?1/0:u.spikedistance,J=[],K=[],$={hLinePoint:null,vLinePoint:null},Q=!1;if(Array.isArray(e))for(I=\"array\",F=0;F<e.length;F++)(N=t.calcdata[e[F].curveNumber||0])&&(j=N[0].trace,\"skip\"!==N[0].trace.hoverinfo&&(K.push(N),\"h\"===j.orientation&&(Q=!0)));else{for(B=0;B<t.calcdata.length;B++)N=t.calcdata[B],\"skip\"!==(j=N[0].trace).hoverinfo&&g.isTraceInSubplots(j,l)&&(K.push(N),\"h\"===j.orientation&&(Q=!0));var tt,et,rt=!e.target;if(rt)tt=\"xpx\"in e?e.xpx:w[0]._length/2,et=\"ypx\"in e?e.ypx:k[0]._length/2;else{if(!1===s.triggerHandler(t,\"plotly_beforehover\",e))return;var nt=e.target.getBoundingClientRect();if(tt=e.clientX-nt.left,et=e.clientY-nt.top,tt<0||tt>w[0]._length||et<0||et>k[0]._length)return f.unhoverRaw(t,e)}if(e.pointerX=tt+w[0]._offset,e.pointerY=et+k[0]._offset,D=\"xval\"in e?g.flat(l,e.xval):g.p2c(w,tt),R=\"yval\"in e?g.flat(l,e.yval):g.p2c(k,et),!i(D[0])||!i(R[0]))return o.warn(\"Fx.hover failed\",e,t),f.unhoverRaw(t,e)}var it=1/0;for(B=0;B<K.length;B++)if((N=K[B])&&N[0]&&N[0].trace&&!0===(j=N[0].trace).visible&&0!==j._length&&-1===[\"carpet\",\"contourcarpet\"].indexOf(j._module.name)){if(\"splom\"===j.type?U=l[V=0]:(U=g.getSubplot(j),V=l.indexOf(U)),q=I,Y={cd:N,trace:j,xa:w[V],ya:k[V],maxHoverDistance:X,maxSpikeDistance:Z,index:!1,distance:Math.min(it,X),spikeDistance:1/0,xSpike:void 0,ySpike:void 0,color:h.defaultLine,name:j.name,x0:void 0,x1:void 0,y0:void 0,y1:void 0,xLabelVal:void 0,yLabelVal:void 0,zLabelVal:void 0,text:void 0},u[U]&&(Y.subplot=u[U]._subplot),u._splomScenes&&u._splomScenes[j.uid]&&(Y.scene=u._splomScenes[j.uid]),W=J.length,\"array\"===q){var at=e[B];\"pointNumber\"in at?(Y.index=at.pointNumber,q=\"closest\"):(q=\"\",\"xval\"in at&&(H=at.xval,q=\"x\"),\"yval\"in at&&(G=at.yval,q=q?\"closest\":\"y\"))}else H=D[V],G=R[V];if(0!==X)if(j._module&&j._module.hoverPoints){var ot=j._module.hoverPoints(Y,H,G,q,u._hoverlayer);if(ot)for(var st,lt=0;lt<ot.length;lt++)st=ot[lt],i(st.x0)&&i(st.y0)&&J.push(S(st,I))}else o.log(\"Unrecognized trace type in hover:\",j);if(\"closest\"===I&&J.length>W&&(J.splice(0,W),it=J[0].distance),y&&0!==Z&&0===J.length){Y.distance=Z,Y.index=!1;var ct=j._module.hoverPoints(Y,H,G,\"closest\",u._hoverlayer);if(ct&&(ct=ct.filter(function(t){return t.spikeDistance<=Z})),ct&&ct.length){var ut,ht=ct.filter(function(t){return t.xa.showspikes});if(ht.length){var ft=ht[0];i(ft.x0)&&i(ft.y0)&&(ut=vt(ft),(!$.vLinePoint||$.vLinePoint.spikeDistance>ut.spikeDistance)&&($.vLinePoint=ut))}var pt=ct.filter(function(t){return t.ya.showspikes});if(pt.length){var dt=pt[0];i(dt.x0)&&i(dt.y0)&&(ut=vt(dt),(!$.hLinePoint||$.hLinePoint.spikeDistance>ut.spikeDistance)&&($.hLinePoint=ut))}}}}function gt(t,e){for(var r,n=null,i=1/0,a=0;a<t.length;a++)(r=t[a].spikeDistance)<i&&r<=e&&(n=t[a],i=r);return n}function vt(t){return t?{xa:t.xa,ya:t.ya,x:void 0!==t.xSpike?t.xSpike:(t.x0+t.x1)/2,y:void 0!==t.ySpike?t.ySpike:(t.y0+t.y1)/2,distance:t.distance,spikeDistance:t.spikeDistance,curveNumber:t.trace.index,color:t.color,pointNumber:t.index}:null}var mt={fullLayout:u,container:u._hoverlayer,outerContainer:u._paperdiv,event:e},yt=t._spikepoints,xt={vLinePoint:$.vLinePoint,hLinePoint:$.hLinePoint};if(t._spikepoints=xt,y&&0!==Z&&0!==J.length){var bt=J.filter(function(t){return t.ya.showspikes}),_t=gt(bt,Z);$.hLinePoint=vt(_t);var wt=J.filter(function(t){return t.xa.showspikes}),kt=gt(wt,Z);$.vLinePoint=vt(kt)}if(0===J.length){var Tt=f.unhoverRaw(t,e);return!y||null===$.hLinePoint&&null===$.vLinePoint||C(yt)&&E($,mt),Tt}y&&C(yt)&&E($,mt);J.sort(function(t,e){return t.distance-e.distance});var At=t._hoverdata,Mt=[];for(F=0;F<J.length;F++){var St=J[F],Et=g.makeEventData(St,St.trace,St.cd);if(!1!==St.hovertemplate){var Ct=!1;St.cd[St.index]&&St.cd[St.index].ht&&(Ct=St.cd[St.index].ht),St.hovertemplate=Ct||St.trace.hovertemplate||!1}St.eventData=[Et],Mt.push(Et)}t._hoverdata=Mt;var Lt=\"y\"===I&&(K.length>1||J.length>1)||\"closest\"===I&&Q&&J.length>1,Pt=h.combine(u.plot_bgcolor||h.background,u.paper_bgcolor),Ot={hovermode:I,rotateLabels:Lt,bgColor:Pt,container:u._hoverlayer,outerContainer:u._paperdiv,commonLabelOpts:u.hoverlabel,hoverdistance:u.hoverdistance},zt=A(J,Ot,t);if(function(t,e,r){var n,i,a,o,s,l,c,u=0,h=1,f=t.size(),p=new Array(f),d=0;function g(t){var e=t[0],r=t[t.length-1];if(i=e.pmin-e.pos-e.dp+e.size,a=r.pos+r.dp+r.size-e.pmax,i>.01){for(s=t.length-1;s>=0;s--)t[s].dp+=i;n=!1}if(!(a<.01)){if(i<-.01){for(s=t.length-1;s>=0;s--)t[s].dp-=a;n=!1}if(n){var c=0;for(o=0;o<t.length;o++)(l=t[o]).pos+l.dp+l.size>e.pmax&&c++;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos>e.pmax-1&&(l.del=!0,c--);for(o=0;o<t.length&&!(c<=0);o++)if((l=t[o]).pos<e.pmin+1)for(l.del=!0,c--,a=2*l.size,s=t.length-1;s>=0;s--)t[s].dp-=a;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos+l.dp+l.size>e.pmax&&(l.del=!0,c--)}}}for(t.each(function(t){var n=t[e],i=\"x\"===n._id.charAt(0),a=n.range;0===d&&a&&a[0]>a[1]!==i&&(h=-1),p[d++]=[{datum:t,traceIndex:t.trace.index,dp:0,pos:t.pos,posref:t.posref,size:t.by*(i?x:1)/2,pmin:0,pmax:i?r.width:r.height}]}),p.sort(function(t,e){return t[0].posref-e[0].posref||h*(e[0].traceIndex-t[0].traceIndex)});!n&&u<=f;){for(u++,n=!0,o=0;o<p.length-1;){var v=p[o],m=p[o+1],y=v[v.length-1],b=m[0];if((i=y.pos+y.dp+y.size-b.pos-b.dp+b.size)>.01&&y.pmin===b.pmin&&y.pmax===b.pmax){for(s=m.length-1;s>=0;s--)m[s].dp+=i;for(v.push.apply(v,m),p.splice(o+1,1),c=0,s=v.length-1;s>=0;s--)c+=v[s].dp;for(a=c/v.length,s=v.length-1;s>=0;s--)v[s].dp-=a;n=!1}else o++}p.forEach(g)}for(o=p.length-1;o>=0;o--){var _=p[o];for(s=_.length-1;s>=0;s--){var w=_[s],k=w.datum;k.offset=w.dp,k.del=w.del}}}(zt,Lt?\"xa\":\"ya\",u),M(zt,Lt),e.target&&e.target.tagName){var It=d.getComponentMethod(\"annotations\",\"hasClickToShow\")(t,Mt);c(n.select(e.target),It?\"pointer\":\"\")}if(!e.target||a||!function(t,e,r){if(!r||r.length!==t._hoverdata.length)return!0;for(var n=r.length-1;n>=0;n--){var i=r[n],a=t._hoverdata[n];if(i.curveNumber!==a.curveNumber||String(i.pointNumber)!==String(a.pointNumber)||String(i.pointNumbers)!==String(a.pointNumbers))return!0}return!1}(t,0,At))return;At&&t.emit(\"plotly_unhover\",{event:e,points:At});t.emit(\"plotly_hover\",{event:e,points:t._hoverdata,xaxes:w,yaxes:k,xvals:D,yvals:R})}(t,e,r,a)})},r.loneHover=function(t,e){var r=!0;Array.isArray(t)||(r=!1,t=[t]);var i=t.map(function(t){return{color:t.color||h.defaultLine,x0:t.x0||t.x||0,x1:t.x1||t.x||0,y0:t.y0||t.y||0,y1:t.y1||t.y||0,xLabel:t.xLabel,yLabel:t.yLabel,zLabel:t.zLabel,text:t.text,name:t.name,idealAlign:t.idealAlign,borderColor:t.borderColor,fontFamily:t.fontFamily,fontSize:t.fontSize,fontColor:t.fontColor,nameLength:t.nameLength,textAlign:t.textAlign,trace:t.trace||{index:0,hoverinfo:\"\"},xa:{_offset:0},ya:{_offset:0},index:0,hovertemplate:t.hovertemplate||!1,eventData:t.eventData||!1,hovertemplateLabels:t.hovertemplateLabels||!1}}),a=n.select(e.container),o=e.outerContainer?n.select(e.outerContainer):a,s={hovermode:\"closest\",rotateLabels:!1,bgColor:e.bgColor||h.background,container:a,outerContainer:o},l=A(i,s,e.gd),c=0,u=0;return l.sort(function(t,e){return t.y0-e.y0}).each(function(t,r){var n=t.y0-t.by/2;t.offset=n-5<c?c-n+5:0,c=n+t.by+t.offset,r===e.anchorIndex&&(u=t.offset)}).each(function(t){t.offset-=u}),M(l,s.rotateLabels),r?l:l.node()};var T=/<extra>([\\s\\S]*)<\\/extra>/;function A(t,e,r){var i=r._fullLayout,a=e.hovermode,s=e.rotateLabels,c=e.bgColor,f=e.container,p=e.outerContainer,d=e.commonLabelOpts||{},g=e.fontFamily||v.HOVERFONT,y=e.fontSize||v.HOVERFONTSIZE,x=t[0],b=x.xa,_=x.ya,A=\"y\"===a?\"yLabel\":\"xLabel\",M=x[A],S=(String(M)||\"\").split(\" \")[0],E=p.node().getBoundingClientRect(),C=E.top,P=E.width,O=E.height,z=void 0!==M&&x.distance<=e.hoverdistance&&(\"x\"===a||\"y\"===a);if(z){var I,D,R=!0;for(I=0;I<t.length;I++)if(R&&void 0===t[I].zLabel&&(R=!1),D=t[I].hoverinfo||t[I].trace.hoverinfo){var F=Array.isArray(D)?D:D.split(\"+\");if(-1===F.indexOf(\"all\")&&-1===F.indexOf(a)){z=!1;break}}R&&(z=!1)}var B=f.selectAll(\"g.axistext\").data(z?[0]:[]);B.enter().append(\"g\").classed(\"axistext\",!0),B.exit().remove(),B.each(function(){var e=n.select(this),i=o.ensureSingle(e,\"path\",\"\",function(t){t.style({\"stroke-width\":\"1px\"})}),s=o.ensureSingle(e,\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),c=d.bgcolor||h.defaultLine,f=d.bordercolor||h.contrast(c),p=h.contrast(c);i.style({fill:c,stroke:f}),s.text(M).call(u.font,d.font.family||g,d.font.size||y,d.font.color||p).call(l.positionText,0,0).call(l.convertToTspans,r),e.attr(\"transform\",\"\");var v=s.node().getBoundingClientRect();if(\"x\"===a){s.attr(\"text-anchor\",\"middle\").call(l.positionText,0,\"top\"===b.side?C-v.bottom-w-k:C-v.top+w+k);var m=\"top\"===b.side?\"-\":\"\";i.attr(\"d\",\"M0,0L\"+w+\",\"+m+w+\"H\"+(k+v.width/2)+\"v\"+m+(2*k+v.height)+\"H-\"+(k+v.width/2)+\"V\"+m+w+\"H-\"+w+\"Z\"),e.attr(\"transform\",\"translate(\"+(b._offset+(x.x0+x.x1)/2)+\",\"+(_._offset+(\"top\"===b.side?0:_._length))+\")\")}else{s.attr(\"text-anchor\",\"right\"===_.side?\"start\":\"end\").call(l.positionText,(\"right\"===_.side?1:-1)*(k+w),C-v.top-v.height/2);var T=\"right\"===_.side?\"\":\"-\";i.attr(\"d\",\"M0,0L\"+T+w+\",\"+w+\"V\"+(k+v.height/2)+\"h\"+T+(2*k+v.width)+\"V-\"+(k+v.height/2)+\"H\"+T+w+\"V-\"+w+\"Z\"),e.attr(\"transform\",\"translate(\"+(b._offset+(\"right\"===_.side?b._length:0))+\",\"+(_._offset+(x.y0+x.y1)/2)+\")\")}t=t.filter(function(t){return void 0!==t.zLabelVal||(t[A]||\"\").split(\" \")[0]===S})});var N=f.selectAll(\"g.hovertext\").data(t,function(t){return[t.trace.index,t.index,t.x0,t.y0,t.name,t.attr,t.xa,t.ya||\"\"].join(\",\")});return N.enter().append(\"g\").classed(\"hovertext\",!0).each(function(){var t=n.select(this);t.append(\"rect\").call(h.fill,h.addOpacity(c,.8)),t.append(\"text\").classed(\"name\",!0),t.append(\"path\").style(\"stroke-width\",\"1px\"),t.append(\"text\").classed(\"nums\",!0).call(u.font,g,y)}),N.exit().remove(),N.each(function(t){var e=n.select(this).attr(\"transform\",\"\"),f=\"\",p=\"\",d=t.bgcolor||t.color,v=h.combine(h.opacity(d)?d:h.defaultLine,c),x=h.combine(h.opacity(t.color)?t.color:h.defaultLine,c),b=t.borderColor||h.contrast(v);void 0!==t.nameOverride&&(t.name=t.nameOverride),t.name&&(t.trace._meta&&(t.name=o.templateString(t.name,t.trace._meta)),f=L(t.name,t.nameLength)),void 0!==t.zLabel?(void 0!==t.xLabel&&(p+=\"x: \"+t.xLabel+\"<br>\"),void 0!==t.yLabel&&(p+=\"y: \"+t.yLabel+\"<br>\"),\"choropleth\"!==t.trace.type&&\"choroplethmapbox\"!==t.trace.type&&(p+=(p?\"z: \":\"\")+t.zLabel)):z&&t[a+\"Label\"]===M?p=t[(\"x\"===a?\"y\":\"x\")+\"Label\"]||\"\":void 0===t.xLabel?void 0!==t.yLabel&&\"scattercarpet\"!==t.trace.type&&(p=t.yLabel):p=void 0===t.yLabel?t.xLabel:\"(\"+t.xLabel+\", \"+t.yLabel+\")\",!t.text&&0!==t.text||Array.isArray(t.text)||(p+=(p?\"<br>\":\"\")+t.text),void 0!==t.extraText&&(p+=(p?\"<br>\":\"\")+t.extraText),\"\"!==p||t.hovertemplate||(\"\"===f&&e.remove(),p=f);var _=i._d3locale,A=t.hovertemplate||!1,S=t.hovertemplateLabels||t,E=t.eventData[0]||{};A&&(p=(p=o.hovertemplateString(A,S,_,E,t.trace._meta)).replace(T,function(e,r){return f=L(r,t.nameLength),\"\"}));var I=e.select(\"text.nums\").call(u.font,t.fontFamily||g,t.fontSize||y,t.fontColor||b).text(p).attr(\"data-notex\",1).call(l.positionText,0,0).call(l.convertToTspans,r),D=e.select(\"text.name\"),R=0,F=0;if(f&&f!==p){D.call(u.font,t.fontFamily||g,t.fontSize||y,x).text(f).attr(\"data-notex\",1).call(l.positionText,0,0).call(l.convertToTspans,r);var B=D.node().getBoundingClientRect();R=B.width+2*k,F=B.height+2*k}else D.remove(),e.select(\"rect\").remove();e.select(\"path\").style({fill:v,stroke:b});var N,j,U=I.node().getBoundingClientRect(),V=t.xa._offset+(t.x0+t.x1)/2,q=t.ya._offset+(t.y0+t.y1)/2,H=Math.abs(t.x1-t.x0),G=Math.abs(t.y1-t.y0),Y=U.width+w+k+R;if(t.ty0=C-U.top,t.bx=U.width+2*k,t.by=Math.max(U.height+2*k,F),t.anchor=\"start\",t.txwidth=U.width,t.tx2width=R,t.offset=0,s)t.pos=V,N=q+G/2+Y<=O,j=q-G/2-Y>=0,\"top\"!==t.idealAlign&&N||!j?N?(q+=G/2,t.anchor=\"start\"):t.anchor=\"middle\":(q-=G/2,t.anchor=\"end\");else if(t.pos=q,N=V+H/2+Y<=P,j=V-H/2-Y>=0,\"left\"!==t.idealAlign&&N||!j)if(N)V+=H/2,t.anchor=\"start\";else{t.anchor=\"middle\";var W=Y/2,X=V+W-P,Z=V-W;X>0&&(V-=X),Z<0&&(V+=-Z)}else V-=H/2,t.anchor=\"end\";I.attr(\"text-anchor\",t.anchor),R&&D.attr(\"text-anchor\",t.anchor),e.attr(\"transform\",\"translate(\"+V+\",\"+q+\")\"+(s?\"rotate(\"+m+\")\":\"\"))}),N}function M(t,e){t.each(function(t){var r=n.select(this);if(t.del)return r.remove();var i=r.select(\"text.nums\"),a=t.anchor,o=\"end\"===a?-1:1,s={start:1,end:-1,middle:0}[a],c=s*(w+k),h=c+s*(t.txwidth+k),f=0,p=t.offset;\"middle\"===a&&(c-=t.tx2width/2,h+=t.txwidth/2+k),e&&(p*=-_,f=t.offset*b),r.select(\"path\").attr(\"d\",\"middle\"===a?\"M-\"+(t.bx/2+t.tx2width/2)+\",\"+(p-t.by/2)+\"h\"+t.bx+\"v\"+t.by+\"h-\"+t.bx+\"Z\":\"M0,0L\"+(o*w+f)+\",\"+(w+p)+\"v\"+(t.by/2-w)+\"h\"+o*t.bx+\"v-\"+t.by+\"H\"+(o*w+f)+\"V\"+(p-w)+\"Z\");var d=c+f,g=p+t.ty0-t.by/2+k,v=t.textAlign||\"auto\";\"auto\"!==v&&(\"left\"===v&&\"start\"!==a?(i.attr(\"text-anchor\",\"start\"),d=\"middle\"===a?-t.bx/2-t.tx2width/2+k:-t.bx-k):\"right\"===v&&\"end\"!==a&&(i.attr(\"text-anchor\",\"end\"),d=\"middle\"===a?t.bx/2-t.tx2width/2-k:t.bx+k)),i.call(l.positionText,d,g),t.tx2width&&(r.select(\"text.name\").call(l.positionText,h+s*k+f,p+t.ty0-t.by/2+k),r.select(\"rect\").call(u.setRect,h+(s-1)*t.tx2width/2+f,p-t.by/2-1,t.tx2width,t.by+2))})}function S(t,e){var r=t.index,n=t.trace||{},a=t.cd[0],s=t.cd[r]||{};function l(t){return t||i(t)&&0===t}var c=Array.isArray(r)?function(t,e){var i=o.castOption(a,r,t);return l(i)?i:o.extractOption({},n,\"\",e)}:function(t,e){return o.extractOption(s,n,t,e)};function u(e,r,n){var i=c(r,n);l(i)&&(t[e]=i)}if(u(\"hoverinfo\",\"hi\",\"hoverinfo\"),u(\"bgcolor\",\"hbg\",\"hoverlabel.bgcolor\"),u(\"borderColor\",\"hbc\",\"hoverlabel.bordercolor\"),u(\"fontFamily\",\"htf\",\"hoverlabel.font.family\"),u(\"fontSize\",\"hts\",\"hoverlabel.font.size\"),u(\"fontColor\",\"htc\",\"hoverlabel.font.color\"),u(\"nameLength\",\"hnl\",\"hoverlabel.namelength\"),u(\"textAlign\",\"hta\",\"hoverlabel.align\"),t.posref=\"y\"===e||\"closest\"===e&&\"h\"===n.orientation?t.xa._offset+(t.x0+t.x1)/2:t.ya._offset+(t.y0+t.y1)/2,t.x0=o.constrain(t.x0,0,t.xa._length),t.x1=o.constrain(t.x1,0,t.xa._length),t.y0=o.constrain(t.y0,0,t.ya._length),t.y1=o.constrain(t.y1,0,t.ya._length),void 0!==t.xLabelVal&&(t.xLabel=\"xLabel\"in t?t.xLabel:p.hoverLabelText(t.xa,t.xLabelVal),t.xVal=t.xa.c2d(t.xLabelVal)),void 0!==t.yLabelVal&&(t.yLabel=\"yLabel\"in t?t.yLabel:p.hoverLabelText(t.ya,t.yLabelVal),t.yVal=t.ya.c2d(t.yLabelVal)),void 0!==t.zLabelVal&&void 0===t.zLabel&&(t.zLabel=String(t.zLabelVal)),!(isNaN(t.xerr)||\"log\"===t.xa.type&&t.xerr<=0)){var h=p.tickText(t.xa,t.xa.c2l(t.xerr),\"hover\").text;void 0!==t.xerrneg?t.xLabel+=\" +\"+h+\" / -\"+p.tickText(t.xa,t.xa.c2l(t.xerrneg),\"hover\").text:t.xLabel+=\" \\xb1 \"+h,\"x\"===e&&(t.distance+=1)}if(!(isNaN(t.yerr)||\"log\"===t.ya.type&&t.yerr<=0)){var f=p.tickText(t.ya,t.ya.c2l(t.yerr),\"hover\").text;void 0!==t.yerrneg?t.yLabel+=\" +\"+f+\" / -\"+p.tickText(t.ya,t.ya.c2l(t.yerrneg),\"hover\").text:t.yLabel+=\" \\xb1 \"+f,\"y\"===e&&(t.distance+=1)}var d=t.hoverinfo||t.trace.hoverinfo;return d&&\"all\"!==d&&(-1===(d=Array.isArray(d)?d:d.split(\"+\")).indexOf(\"x\")&&(t.xLabel=void 0),-1===d.indexOf(\"y\")&&(t.yLabel=void 0),-1===d.indexOf(\"z\")&&(t.zLabel=void 0),-1===d.indexOf(\"text\")&&(t.text=void 0),-1===d.indexOf(\"name\")&&(t.name=void 0)),t}function E(t,e){var r,n,i=e.container,o=e.fullLayout,s=e.event,l=!!t.hLinePoint,c=!!t.vLinePoint;if(i.selectAll(\".spikeline\").remove(),c||l){var f=h.combine(o.plot_bgcolor,o.paper_bgcolor);if(l){var p,d,g=t.hLinePoint;r=g&&g.xa,\"cursor\"===(n=g&&g.ya).spikesnap?(p=s.pointerX,d=s.pointerY):(p=r._offset+g.x,d=n._offset+g.y);var v,m,y=a.readability(g.color,f)<1.5?h.contrast(f):g.color,x=n.spikemode,b=n.spikethickness,_=n.spikecolor||y,w=n._boundingBox,k=(w.left+w.right)/2<p?w.right:w.left;-1===x.indexOf(\"toaxis\")&&-1===x.indexOf(\"across\")||(-1!==x.indexOf(\"toaxis\")&&(v=k,m=p),-1!==x.indexOf(\"across\")&&(v=n._counterSpan[0],m=n._counterSpan[1]),i.insert(\"line\",\":first-child\").attr({x1:v,x2:m,y1:d,y2:d,\"stroke-width\":b,stroke:_,\"stroke-dasharray\":u.dashStyle(n.spikedash,b)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),i.insert(\"line\",\":first-child\").attr({x1:v,x2:m,y1:d,y2:d,\"stroke-width\":b+2,stroke:f}).classed(\"spikeline\",!0).classed(\"crisp\",!0)),-1!==x.indexOf(\"marker\")&&i.insert(\"circle\",\":first-child\").attr({cx:k+(\"right\"!==n.side?b:-b),cy:d,r:b,fill:_}).classed(\"spikeline\",!0)}if(c){var T,A,M=t.vLinePoint;r=M&&M.xa,n=M&&M.ya,\"cursor\"===r.spikesnap?(T=s.pointerX,A=s.pointerY):(T=r._offset+M.x,A=n._offset+M.y);var S,E,C=a.readability(M.color,f)<1.5?h.contrast(f):M.color,L=r.spikemode,P=r.spikethickness,O=r.spikecolor||C,z=r._boundingBox,I=(z.top+z.bottom)/2<A?z.bottom:z.top;-1===L.indexOf(\"toaxis\")&&-1===L.indexOf(\"across\")||(-1!==L.indexOf(\"toaxis\")&&(S=I,E=A),-1!==L.indexOf(\"across\")&&(S=r._counterSpan[0],E=r._counterSpan[1]),i.insert(\"line\",\":first-child\").attr({x1:T,x2:T,y1:S,y2:E,\"stroke-width\":P,stroke:O,\"stroke-dasharray\":u.dashStyle(r.spikedash,P)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),i.insert(\"line\",\":first-child\").attr({x1:T,x2:T,y1:S,y2:E,\"stroke-width\":P+2,stroke:f}).classed(\"spikeline\",!0).classed(\"crisp\",!0)),-1!==L.indexOf(\"marker\")&&i.insert(\"circle\",\":first-child\").attr({cx:T,cy:I-(\"top\"!==r.side?P:-P),r:P,fill:O}).classed(\"spikeline\",!0)}}}function C(t,e){return!e||(e.vLinePoint!==t._spikepoints.vLinePoint||e.hLinePoint!==t._spikepoints.hLinePoint)}function L(t,e){return l.plainText(t||\"\",{len:e,allowedTags:[\"br\",\"sub\",\"sup\",\"b\",\"i\",\"em\"]})}},{\"../../lib\":719,\"../../lib/events\":709,\"../../lib/override_cursor\":730,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"./constants\":626,\"./helpers\":628,d3:163,\"fast-isnumeric\":225,tinycolor2:537}],630:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i){r(\"hoverlabel.bgcolor\",(i=i||{}).bgcolor),r(\"hoverlabel.bordercolor\",i.bordercolor),r(\"hoverlabel.namelength\",i.namelength),n.coerceFont(r,\"hoverlabel.font\",i.font),r(\"hoverlabel.align\",i.align)}},{\"../../lib\":719}],631:[function(t,e,r){\"use strict\";t(\"../../constants/docs\").FORMAT_LINK;e.exports=function(t,e){t=t||{};(e=e||{}).description&&e.description;var r=e.keys||[];if(r.length>0){for(var n=[],i=0;i<r.length;i++)n[i]=\"`\"+r[i]+\"`\";\"Finally, the template string has access to \",1===r.length?\"variable \"+n[0]:\"variables \"+n.slice(0,-1).join(\", \")+\" and \"+n.slice(-1)+\".\"}var a={valType:\"string\",dflt:\"\",editType:t.editType||\"none\"};return!1!==t.arrayOk&&(a.arrayOk=!0),a}},{\"../../constants/docs\":690}],632:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../dragelement\"),o=t(\"./helpers\"),s=t(\"./layout_attributes\"),l=t(\"./hover\");e.exports={moduleType:\"component\",name:\"fx\",constants:t(\"./constants\"),schema:{layout:s},attributes:t(\"./attributes\"),layoutAttributes:s,supplyLayoutGlobalDefaults:t(\"./layout_global_defaults\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),getDistanceFunction:o.getDistanceFunction,getClosest:o.getClosest,inbox:o.inbox,quadrature:o.quadrature,appendArrayPointValue:o.appendArrayPointValue,castHoverOption:function(t,e,r){return i.castOption(t,e,\"hoverlabel.\"+r)},castHoverinfo:function(t,e,r){return i.castOption(t,r,\"hoverinfo\",function(r){return i.coerceHoverinfo({hoverinfo:r},{_module:t._module},e)})},hover:l.hover,unhover:a.unhover,loneHover:l.loneHover,loneUnhover:function(t){var e=i.isD3Selection(t)?t:n.select(t);e.selectAll(\"g.hovertext\").remove(),e.selectAll(\".spikeline\").remove()},click:t(\"./click\")}},{\"../../lib\":719,\"../dragelement\":611,\"./attributes\":623,\"./calc\":624,\"./click\":625,\"./constants\":626,\"./defaults\":627,\"./helpers\":628,\"./hover\":629,\"./layout_attributes\":633,\"./layout_defaults\":634,\"./layout_global_defaults\":635,d3:163}],633:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../plots/font_attributes\")({editType:\"none\"});i.family.dflt=n.HOVERFONT,i.size.dflt=n.HOVERFONTSIZE,e.exports={clickmode:{valType:\"flaglist\",flags:[\"event\",\"select\"],dflt:\"event\",editType:\"plot\",extras:[\"none\"]},dragmode:{valType:\"enumerated\",values:[\"zoom\",\"pan\",\"select\",\"lasso\",\"orbit\",\"turntable\",!1],dflt:\"zoom\",editType:\"modebar\"},hovermode:{valType:\"enumerated\",values:[\"x\",\"y\",\"closest\",!1],editType:\"modebar\"},hoverdistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},spikedistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"none\"},bordercolor:{valType:\"color\",editType:\"none\"},font:i,align:{valType:\"enumerated\",values:[\"left\",\"right\",\"auto\"],dflt:\"auto\",editType:\"none\"},namelength:{valType:\"integer\",min:-1,dflt:15,editType:\"none\"},editType:\"none\"},selectdirection:{valType:\"enumerated\",values:[\"h\",\"v\",\"d\",\"any\"],dflt:\"any\",editType:\"none\"}}},{\"../../plots/font_attributes\":793,\"./constants\":626}],634:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){function a(r,a){return n.coerce(t,e,i,r,a)}var o,s=a(\"clickmode\");\"select\"===a(\"dragmode\")&&a(\"selectdirection\"),e._has(\"cartesian\")?s.indexOf(\"select\")>-1?o=\"closest\":(e._isHoriz=function(t,e){for(var r=e._scatterStackOpts||{},n=0;n<t.length;n++){var i=t[n],a=i.xaxis+i.yaxis,o=r[a]||{},s=o[i.stackgroup]||{};if(\"h\"!==i.orientation&&\"h\"!==s.orientation)return!1}return!0}(r,e),o=e._isHoriz?\"y\":\"x\"):o=\"closest\",a(\"hovermode\",o)&&(a(\"hoverdistance\"),a(\"spikedistance\"));var l=e._has(\"mapbox\"),c=e._has(\"geo\"),u=e._basePlotModules.length;\"zoom\"===e.dragmode&&((l||c)&&1===u||l&&c&&2===u)&&(e.dragmode=\"pan\")}},{\"../../lib\":719,\"./layout_attributes\":633}],635:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./hoverlabel_defaults\"),a=t(\"./layout_attributes\");e.exports=function(t,e){i(t,e,function(r,i){return n.coerce(t,e,a,r,i)})}},{\"../../lib\":719,\"./hoverlabel_defaults\":630,\"./layout_attributes\":633}],636:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/regex\").counter,a=t(\"../../plots/domain\").attributes,o=t(\"../../plots/cartesian/constants\").idRegex,s=t(\"../../plot_api/plot_template\"),l={rows:{valType:\"integer\",min:1,editType:\"plot\"},roworder:{valType:\"enumerated\",values:[\"top to bottom\",\"bottom to top\"],dflt:\"top to bottom\",editType:\"plot\"},columns:{valType:\"integer\",min:1,editType:\"plot\"},subplots:{valType:\"info_array\",freeLength:!0,dimensions:2,items:{valType:\"enumerated\",values:[i(\"xy\").toString(),\"\"],editType:\"plot\"},editType:\"plot\"},xaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.x.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},yaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.y.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},pattern:{valType:\"enumerated\",values:[\"independent\",\"coupled\"],dflt:\"coupled\",editType:\"plot\"},xgap:{valType:\"number\",min:0,max:1,editType:\"plot\"},ygap:{valType:\"number\",min:0,max:1,editType:\"plot\"},domain:a({name:\"grid\",editType:\"plot\",noGridCell:!0},{}),xside:{valType:\"enumerated\",values:[\"bottom\",\"bottom plot\",\"top plot\",\"top\"],dflt:\"bottom plot\",editType:\"plot\"},yside:{valType:\"enumerated\",values:[\"left\",\"left plot\",\"right plot\",\"right\"],dflt:\"left plot\",editType:\"plot\"},editType:\"plot\"};function c(t,e,r){var n=e[r+\"axes\"],i=Object.keys((t._splomAxes||{})[r]||{});return Array.isArray(n)?n:i.length?i:void 0}function u(t,e,r,n,i,a){var o=e(t+\"gap\",r),s=e(\"domain.\"+t);e(t+\"side\",n);for(var l=new Array(i),c=s[0],u=(s[1]-c)/(i-o),h=u*(1-o),f=0;f<i;f++){var p=c+u*f;l[a?i-1-f:f]=[p,p+h]}return l}function h(t,e,r,n,i){var a,o=new Array(r);function s(t,r){-1!==e.indexOf(r)&&void 0===n[r]?(o[t]=r,n[r]=t):o[t]=\"\"}if(Array.isArray(t))for(a=0;a<r;a++)s(a,t[a]);else for(s(0,i),a=1;a<r;a++)s(a,i+(a+1));return o}e.exports={moduleType:\"component\",name:\"grid\",schema:{layout:{grid:l}},layoutAttributes:l,sizeDefaults:function(t,e){var r=t.grid||{},i=c(e,r,\"x\"),a=c(e,r,\"y\");if(t.grid||i||a){var o,h,f=Array.isArray(r.subplots)&&Array.isArray(r.subplots[0]),p=Array.isArray(i),d=Array.isArray(a),g=p&&i!==r.xaxes&&d&&a!==r.yaxes;f?(o=r.subplots.length,h=r.subplots[0].length):(d&&(o=a.length),p&&(h=i.length));var v=s.newContainer(e,\"grid\"),m=T(\"rows\",o),y=T(\"columns\",h);if(m*y>1){f||p||d||\"independent\"===T(\"pattern\")&&(f=!0),v._hasSubplotGrid=f;var x,b,_=\"top to bottom\"===T(\"roworder\"),w=f?.2:.1,k=f?.3:.1;g&&e._splomGridDflt&&(x=e._splomGridDflt.xside,b=e._splomGridDflt.yside),v._domains={x:u(\"x\",T,w,x,y),y:u(\"y\",T,k,b,m,_)}}else delete e.grid}function T(t,e){return n.coerce(r,v,l,t,e)}},contentDefaults:function(t,e){var r=e.grid;if(r&&r._domains){var n,i,a,o,s,l,u,f=t.grid||{},p=e._subplots,d=r._hasSubplotGrid,g=r.rows,v=r.columns,m=\"independent\"===r.pattern,y=r._axisMap={};if(d){var x=f.subplots||[];l=r.subplots=new Array(g);var b=1;for(n=0;n<g;n++){var _=l[n]=new Array(v),w=x[n]||[];for(i=0;i<v;i++)if(m?(s=1===b?\"xy\":\"x\"+b+\"y\"+b,b++):s=w[i],_[i]=\"\",-1!==p.cartesian.indexOf(s)){if(u=s.indexOf(\"y\"),a=s.slice(0,u),o=s.slice(u),void 0!==y[a]&&y[a]!==i||void 0!==y[o]&&y[o]!==n)continue;_[i]=s,y[a]=i,y[o]=n}}}else{var k=c(e,f,\"x\"),T=c(e,f,\"y\");r.xaxes=h(k,p.xaxis,v,y,\"x\"),r.yaxes=h(T,p.yaxis,g,y,\"y\")}var A=r._anchors={},M=\"top to bottom\"===r.roworder;for(var S in y){var E,C,L,P=S.charAt(0),O=r[P+\"side\"];if(O.length<8)A[S]=\"free\";else if(\"x\"===P){if(\"t\"===O.charAt(0)===M?(E=0,C=1,L=g):(E=g-1,C=-1,L=-1),d){var z=y[S];for(n=E;n!==L;n+=C)if((s=l[n][z])&&(u=s.indexOf(\"y\"),s.slice(0,u)===S)){A[S]=s.slice(u);break}}else for(n=E;n!==L;n+=C)if(o=r.yaxes[n],-1!==p.cartesian.indexOf(S+o)){A[S]=o;break}}else if(\"l\"===O.charAt(0)?(E=0,C=1,L=v):(E=v-1,C=-1,L=-1),d){var I=y[S];for(n=E;n!==L;n+=C)if((s=l[I][n])&&(u=s.indexOf(\"y\"),s.slice(u)===S)){A[S]=s.slice(0,u);break}}else for(n=E;n!==L;n+=C)if(a=r.xaxes[n],-1!==p.cartesian.indexOf(a+S)){A[S]=a;break}}}}}},{\"../../lib\":719,\"../../lib/regex\":735,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773,\"../../plots/domain\":792}],637:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/constants\"),i=t(\"../../plot_api/plot_template\").templatedArray;e.exports=i(\"image\",{visible:{valType:\"boolean\",dflt:!0,editType:\"arraydraw\"},source:{valType:\"string\",editType:\"arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},sizex:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizey:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizing:{valType:\"enumerated\",values:[\"fill\",\"contain\",\"stretch\"],dflt:\"contain\",editType:\"arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},x:{valType:\"any\",dflt:0,editType:\"arraydraw\"},y:{valType:\"any\",dflt:0,editType:\"arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"top\",editType:\"arraydraw\"},xref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.x.toString()],dflt:\"paper\",editType:\"arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.y.toString()],dflt:\"paper\",editType:\"arraydraw\"},editType:\"arraydraw\"})},{\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773}],638:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.images,h=e._id.charAt(0),f=0;f<u.length;f++)if(c=\"images[\"+f+\"].\",(l=u[f])[h+\"ref\"]===e._id){var p=l[h],d=l[\"size\"+h],g=null,v=null;if(o){g=i(p,e.range);var m=d/Math.pow(10,g)/2;v=2*Math.log(m+Math.sqrt(1+m*m))/Math.LN10}else v=(g=Math.pow(10,p))*(Math.pow(10,d/2)-Math.pow(10,-d/2));n(g)?n(v)||(v=null):(g=null,v=null),a(c+h,g),a(c+\"size\"+h,v)}}},{\"../../lib/to_log_range\":745,\"fast-isnumeric\":225}],639:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\");function s(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}var s=a(\"source\");if(!a(\"visible\",!!s))return e;a(\"layer\"),a(\"xanchor\"),a(\"yanchor\"),a(\"sizex\"),a(\"sizey\"),a(\"sizing\"),a(\"opacity\");for(var l={_fullLayout:r},c=[\"x\",\"y\"],u=0;u<2;u++){var h=c[u],f=i.coerceRef(t,e,l,h,\"paper\");if(\"paper\"!==f)i.getFromId(l,f)._imgIndices.push(e._index);i.coercePosition(e,l,a,f,h,0)}return e}e.exports=function(t,e){a(t,e,{name:\"images\",handleItemDefaults:s})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"./attributes\":637}],640:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../drawing\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/xmlns_namespaces\");e.exports=function(t){var e,r,s=t._fullLayout,l=[],c={},u=[];for(r=0;r<s.images.length;r++){var h=s.images[r];if(h.visible)if(\"below\"===h.layer&&\"paper\"!==h.xref&&\"paper\"!==h.yref){e=h.xref+h.yref;var f=s._plots[e];if(!f){u.push(h);continue}f.mainplot&&(e=f.mainplot.id),c[e]||(c[e]=[]),c[e].push(h)}else\"above\"===h.layer?l.push(h):u.push(h)}var p={x:{left:{sizing:\"xMin\",offset:0},center:{sizing:\"xMid\",offset:-.5},right:{sizing:\"xMax\",offset:-1}},y:{top:{sizing:\"YMin\",offset:0},middle:{sizing:\"YMid\",offset:-.5},bottom:{sizing:\"YMax\",offset:-1}}};function d(e){var r=n.select(this);if(!this.img||this.img.src!==e.source){r.attr(\"xmlns\",o.svg);var i=new Promise(function(t){var n=new Image;function i(){r.remove(),t()}this.img=n,n.setAttribute(\"crossOrigin\",\"anonymous\"),n.onerror=i,n.onload=function(){var e=document.createElement(\"canvas\");e.width=this.width,e.height=this.height,e.getContext(\"2d\").drawImage(this,0,0);var n=e.toDataURL(\"image/png\");r.attr(\"xlink:href\",n),t()},r.on(\"error\",i),n.src=e.source}.bind(this));t._promises.push(i)}}function g(e){var r=n.select(this),o=a.getFromId(t,e.xref),l=a.getFromId(t,e.yref),c=s._size,u=o?Math.abs(o.l2p(e.sizex)-o.l2p(0)):e.sizex*c.w,h=l?Math.abs(l.l2p(e.sizey)-l.l2p(0)):e.sizey*c.h,f=u*p.x[e.xanchor].offset,d=h*p.y[e.yanchor].offset,g=p.x[e.xanchor].sizing+p.y[e.yanchor].sizing,v=(o?o.r2p(e.x)+o._offset:e.x*c.w+c.l)+f,m=(l?l.r2p(e.y)+l._offset:c.h-e.y*c.h+c.t)+d;switch(e.sizing){case\"fill\":g+=\" slice\";break;case\"stretch\":g=\"none\"}r.attr({x:v,y:m,width:u,height:h,preserveAspectRatio:g,opacity:e.opacity});var y=(o?o._id:\"\")+(l?l._id:\"\");i.setClipUrl(r,y?\"clip\"+s._uid+y:null,t)}var v=s._imageLowerLayer.selectAll(\"image\").data(u),m=s._imageUpperLayer.selectAll(\"image\").data(l);v.enter().append(\"image\"),m.enter().append(\"image\"),v.exit().remove(),m.exit().remove(),v.each(function(t){d.bind(this)(t),g.bind(this)(t)}),m.each(function(t){d.bind(this)(t),g.bind(this)(t)});var y=Object.keys(s._plots);for(r=0;r<y.length;r++){e=y[r];var x=s._plots[e];if(x.imagelayer){var b=x.imagelayer.selectAll(\"image\").data(c[e]||[]);b.enter().append(\"image\"),b.exit().remove(),b.each(function(t){d.bind(this)(t),g.bind(this)(t)})}}}},{\"../../constants/xmlns_namespaces\":696,\"../../plots/cartesian/axes\":767,\"../drawing\":614,d3:163}],641:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"images\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"images\"),draw:t(\"./draw\"),convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":777,\"./attributes\":637,\"./convert_coords\":638,\"./defaults\":639,\"./draw\":640}],642:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",editType:\"legend\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"legend\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"legend\"},font:n({editType:\"legend\"}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"v\",editType:\"legend\"},traceorder:{valType:\"flaglist\",flags:[\"reversed\",\"grouped\"],extras:[\"normal\"],editType:\"legend\"},tracegroupgap:{valType:\"number\",min:0,dflt:10,editType:\"legend\"},itemsizing:{valType:\"enumerated\",values:[\"trace\",\"constant\"],dflt:\"trace\",editType:\"legend\"},itemclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggle\",editType:\"legend\"},itemdoubleclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggleothers\",editType:\"legend\"},x:{valType:\"number\",min:-2,max:3,dflt:1.02,editType:\"legend\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"legend\"},y:{valType:\"number\",min:-2,max:3,dflt:1,editType:\"legend\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"legend\"},uirevision:{valType:\"any\",editType:\"none\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"legend\"},editType:\"legend\"}},{\"../../plots/font_attributes\":793,\"../color/attributes\":592}],643:[function(t,e,r){\"use strict\";e.exports={scrollBarWidth:6,scrollBarMinHeight:20,scrollBarColor:\"#808BA4\",scrollBarMargin:4,textOffsetX:40}},{}],644:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plot_api/plot_template\"),o=t(\"./attributes\"),s=t(\"../../plots/layout_attributes\"),l=t(\"./helpers\");e.exports=function(t,e,r){for(var c,u,h,f,p=t.legend||{},d=0,g=!1,v=\"normal\",m=0;m<r.length;m++){var y=r[m];y.visible&&((y.showlegend||y._dfltShowLegend)&&(d++,y.showlegend&&(g=!0,(n.traceIs(y,\"pie-like\")||!0===y._input.showlegend)&&d++)),(n.traceIs(y,\"bar\")&&\"stack\"===e.barmode||-1!==[\"tonextx\",\"tonexty\"].indexOf(y.fill))&&(v=l.isGrouped({traceorder:v})?\"grouped+reversed\":\"reversed\"),void 0!==y.legendgroup&&\"\"!==y.legendgroup&&(v=l.isReversed({traceorder:v})?\"reversed+grouped\":\"grouped\"))}var x=i.coerce(t,e,s,\"showlegend\",g&&d>1);if(!1!==x||p.uirevision){var b=a.newContainer(e,\"legend\");if(w(\"uirevision\",e.uirevision),!1!==x){if(w(\"bgcolor\",e.paper_bgcolor),w(\"bordercolor\"),w(\"borderwidth\"),i.coerceFont(w,\"font\",e.font),w(\"orientation\"),\"h\"===b.orientation){var _=t.xaxis;n.getComponentMethod(\"rangeslider\",\"isVisible\")(_)?(c=0,h=\"left\",u=1.1,f=\"bottom\"):(c=0,h=\"left\",u=-.1,f=\"top\")}w(\"traceorder\",v),l.isGrouped(e.legend)&&w(\"tracegroupgap\"),w(\"itemsizing\"),w(\"itemclick\"),w(\"itemdoubleclick\"),w(\"x\",c),w(\"xanchor\",h),w(\"y\",u),w(\"yanchor\",f),w(\"valign\"),i.noneOrAll(p,b,[\"x\",\"y\"])}}function w(t,e){return i.coerce(p,b,o,t,e)}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/layout_attributes\":819,\"../../registry\":847,\"./attributes\":642,\"./helpers\":648}],645:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib/events\"),l=t(\"../dragelement\"),c=t(\"../drawing\"),u=t(\"../color\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"./handle_click\"),p=t(\"./constants\"),d=t(\"../../constants/alignment\"),g=d.LINE_SPACING,v=d.FROM_TL,m=d.FROM_BR,y=t(\"./get_legend_data\"),x=t(\"./style\"),b=t(\"./helpers\");function _(t,e,r,n,i){var a=r.data()[0][0].trace,l={event:i,node:r.node(),curveNumber:a.index,expandedIndex:a._expandedIndex,data:t.data,layout:t.layout,frames:t._transitionData._frames,config:t._context,fullData:t._fullData,fullLayout:t._fullLayout};if(a._group&&(l.group=a._group),o.traceIs(a,\"pie-like\")&&(l.label=r.datum()[0].label),!1!==s.triggerHandler(t,\"plotly_legendclick\",l))if(1===n)e._clickTimeout=setTimeout(function(){f(r,t,n)},t._context.doubleClickDelay);else if(2===n){e._clickTimeout&&clearTimeout(e._clickTimeout),t._legendMouseDownTime=0,!1!==s.triggerHandler(t,\"plotly_legenddoubleclick\",l)&&f(r,t,n)}}function w(t,e,r){var n=t.data()[0][0],a=e._fullLayout,s=n.trace,l=o.traceIs(s,\"pie-like\"),u=s.index,f=e._context.edits.legendText&&!l,d=l?n.label:s.name;s._meta&&(d=i.templateString(d,s._meta));var v=i.ensureSingle(t,\"text\",\"legendtext\");function m(r){h.convertToTspans(r,e,function(){!function(t,e){var r=t.data()[0][0];if(!r.trace.showlegend)return void t.remove();var n,i,a=t.select(\"g[class*=math-group]\"),o=a.node(),s=e._fullLayout.legend.font.size*g;if(o){var l=c.bBox(o);n=l.height,i=l.width,c.setTranslate(a,0,n/4)}else{var u=t.select(\".legendtext\"),f=h.lineCount(u),d=u.node();n=s*f,i=d?c.bBox(d).width:0;var v=s*(.3+(1-f)/2);h.positionText(u,p.textOffsetX,v)}r.lineHeight=s,r.height=Math.max(n,16)+3,r.width=i}(t,e)})}v.attr(\"text-anchor\",\"start\").classed(\"user-select-none\",!0).call(c.font,a.legend.font).text(f?k(d,r):d),h.positionText(v,p.textOffsetX,0),f?v.call(h.makeEditable,{gd:e,text:d}).call(m).on(\"edit\",function(t){this.text(k(t,r)).call(m);var a=n.trace._fullInput||{},s={};if(o.hasTransform(a,\"groupby\")){var l=o.getTransformIndices(a,\"groupby\"),c=l[l.length-1],h=i.keyedContainer(a,\"transforms[\"+c+\"].styles\",\"target\",\"value.name\");h.set(n.trace._group,t),s=h.constructUpdate()}else s.name=t;return o.call(\"_guiRestyle\",e,s,u)}):m(v)}function k(t,e){var r=Math.max(4,e);if(t&&t.trim().length>=r/2)return t;for(var n=r-(t=t||\"\").length;n>0;n--)t+=\" \";return t}function T(t,e){var r,a=e._context.doubleClickDelay,o=1,s=i.ensureSingle(t,\"rect\",\"legendtoggle\",function(t){t.style(\"cursor\",\"pointer\").attr(\"pointer-events\",\"all\").call(u.fill,\"rgba(0,0,0,0)\")});s.on(\"mousedown\",function(){(r=(new Date).getTime())-e._legendMouseDownTime<a?o+=1:(o=1,e._legendMouseDownTime=r)}),s.on(\"mouseup\",function(){if(!e._dragged&&!e._editing){var r=e._fullLayout.legend;(new Date).getTime()-e._legendMouseDownTime>a&&(o=Math.max(o-1,1)),_(e,r,t,o,n.event)}})}function A(t,e,r){var a=t._fullLayout,o=a.legend,s=o.borderwidth,l=b.isGrouped(o),u=0;if(o._width=0,o._height=0,b.isVertical(o))l&&e.each(function(t,e){c.setTranslate(this,0,e*o.tracegroupgap)}),r.each(function(t){var e=t[0],r=e.height,n=e.width;c.setTranslate(this,s,5+s+o._height+r/2),o._height+=r,o._width=Math.max(o._width,n)}),o._width+=45+2*s,o._height+=10+2*s,l&&(o._height+=(o._lgroupsLength-1)*o.tracegroupgap),u=40;else if(l){var h,f=0,p=0,d=e.data(),g=0;for(h=0;h<d.length;h++){var v=d[h],m=v.map(function(t){return t[0].width}),y=i.aggNums(Math.max,null,m),x=v.reduce(function(t,e){return t+e[0].height},0);p=Math.max(p,y),f=Math.max(f,x),g=Math.max(g,v.length)}p+=5,p+=40;var _=[o._width],w=[],k=0;for(h=0;h<d.length;h++){a._size.w<s+o._width+5+p?(_[_.length-1]=_[0],o._width=p,k++):o._width+=p+s;var T=k*f;T+=k>0?o.tracegroupgap:0,w.push(T),_.push(o._width)}e.each(function(t,e){c.setTranslate(this,_[e],w[e])}),e.each(function(){var t=n.select(this).selectAll(\"g.traces\"),e=0;t.each(function(t){var r=t[0].height;c.setTranslate(this,0,5+s+e+r/2),e+=r})});var A=w[w.length-1]+f;o._height=10+2*s+A;var M=Math.max.apply(null,_);o._width=M+p+40,o._width+=2*s}else{var S=0,E=0,C=0,L=0,P=0;r.each(function(t){C=Math.max(40+t[0].width,C),P+=40+t[0].width+5});var O=a._size.w>s+P-5;r.each(function(t){var e=t[0],r=O?40+t[0].width:C;s+L+5+r>a._size.w&&(L=0,S+=E,o._height+=E,E=0),c.setTranslate(this,s+L,5+s+e.height/2+S),o._width+=5+r,L+=5+r,E=Math.max(e.height,E)}),O?o._height=E:o._height+=E,o._width+=2*s,o._height+=10+2*s}o._width=Math.ceil(o._width),o._height=Math.ceil(o._height);var z=t._context.edits.legendText||t._context.edits.legendPosition;r.each(function(t){var e=t[0],r=n.select(this).select(\".legendtoggle\");c.setRect(r,0,-e.height/2,(z?0:o._width)+u,e.height)})}function M(t){var e=t._fullLayout.legend,r=\"left\";i.isRightAnchor(e)?r=\"right\":i.isCenterAnchor(e)&&(r=\"center\");var n=\"top\";i.isBottomAnchor(e)?n=\"bottom\":i.isMiddleAnchor(e)&&(n=\"middle\"),a.autoMargin(t,\"legend\",{x:e.x,y:e.y,l:e._width*v[r],r:e._width*m[r],b:e._height*m[n],t:e._height*v[n]})}e.exports=function(t){var e=t._fullLayout,r=\"legend\"+e._uid;if(e._infolayer&&t.calcdata){t._legendMouseDownTime||(t._legendMouseDownTime=0);var s=e.legend,h=e.showlegend&&y(t.calcdata,s),f=e.hiddenlabels||[];if(!e.showlegend||!h.length)return e._infolayer.selectAll(\".legend\").remove(),e._topdefs.select(\"#\"+r).remove(),void a.autoMargin(t,\"legend\");for(var d=0,g=0;g<h.length;g++)for(var b=0;b<h[g].length;b++){var k=h[g][b][0],S=k.trace,E=o.traceIs(S,\"pie-like\")?k.label:S.name;d=Math.max(d,E&&E.length||0)}var C=!1,L=i.ensureSingle(e._infolayer,\"g\",\"legend\",function(t){t.attr(\"pointer-events\",\"all\"),C=!0}),P=i.ensureSingleById(e._topdefs,\"clipPath\",r,function(t){t.append(\"rect\")}),O=i.ensureSingle(L,\"rect\",\"bg\",function(t){t.attr(\"shape-rendering\",\"crispEdges\")});O.call(u.stroke,s.bordercolor).call(u.fill,s.bgcolor).style(\"stroke-width\",s.borderwidth+\"px\");var z=i.ensureSingle(L,\"g\",\"scrollbox\"),I=i.ensureSingle(L,\"rect\",\"scrollbar\",function(t){t.attr({rx:20,ry:3,width:0,height:0}).call(u.fill,\"#808BA4\")}),D=z.selectAll(\"g.groups\").data(h);D.enter().append(\"g\").attr(\"class\",\"groups\"),D.exit().remove();var R=D.selectAll(\"g.traces\").data(i.identity);R.enter().append(\"g\").attr(\"class\",\"traces\"),R.exit().remove(),R.style(\"opacity\",function(t){var e=t[0].trace;return o.traceIs(e,\"pie-like\")?-1!==f.indexOf(t[0].label)?.5:1:\"legendonly\"===e.visible?.5:1}).each(function(){n.select(this).call(w,t,d)}).call(x,t).each(function(){n.select(this).call(T,t)}),i.syncOrAsync([a.previousPromises,function(){C&&(A(t,D,R),M(t));var u=e.width,h=e.height;A(t,D,R),s._height>h?function(t){var e=t._fullLayout.legend,r=\"left\";i.isRightAnchor(e)?r=\"right\":i.isCenterAnchor(e)&&(r=\"center\");a.autoMargin(t,\"legend\",{x:e.x,y:.5,l:e._width*v[r],r:e._width*m[r],b:0,t:0})}(t):M(t);var f=e._size,d=f.l+f.w*s.x,g=f.t+f.h*(1-s.y);i.isRightAnchor(s)?d-=s._width:i.isCenterAnchor(s)&&(d-=s._width/2),i.isBottomAnchor(s)?g-=s._height:i.isMiddleAnchor(s)&&(g-=s._height/2);var y=s._width,x=f.w;y>x?(d=f.l,y=x):(d+y>u&&(d=u-y),d<0&&(d=0),y=Math.min(u-d,s._width));var b,w,k,T,S=s._height,E=f.h;if(S>E?(g=f.t,S=E):(g+S>h&&(g=h-S),g<0&&(g=0),S=Math.min(h-g,s._height)),c.setTranslate(L,d,g),I.on(\".drag\",null),L.on(\"wheel\",null),s._height<=S||t._context.staticPlot)O.attr({width:y-s.borderwidth,height:S-s.borderwidth,x:s.borderwidth/2,y:s.borderwidth/2}),c.setTranslate(z,0,0),P.select(\"rect\").attr({width:y-2*s.borderwidth,height:S-2*s.borderwidth,x:s.borderwidth,y:s.borderwidth}),c.setClipUrl(z,r,t),c.setRect(I,0,0,0,0),delete s._scrollY;else{var F,B,N=Math.max(p.scrollBarMinHeight,S*S/s._height),j=S-N-2*p.scrollBarMargin,U=s._height-S,V=j/U,q=Math.min(s._scrollY||0,U);O.attr({width:y-2*s.borderwidth+p.scrollBarWidth+p.scrollBarMargin,height:S-s.borderwidth,x:s.borderwidth/2,y:s.borderwidth/2}),P.select(\"rect\").attr({width:y-2*s.borderwidth+p.scrollBarWidth+p.scrollBarMargin,height:S-2*s.borderwidth,x:s.borderwidth,y:s.borderwidth+q}),c.setClipUrl(z,r,t),G(q,N,V),L.on(\"wheel\",function(){G(q=i.constrain(s._scrollY+n.event.deltaY/j*U,0,U),N,V),0!==q&&q!==U&&n.event.preventDefault()});var H=n.behavior.drag().on(\"dragstart\",function(){F=n.event.sourceEvent.clientY,B=q}).on(\"drag\",function(){var t=n.event.sourceEvent;2===t.buttons||t.ctrlKey||G(q=i.constrain((t.clientY-F)/V+B,0,U),N,V)});I.call(H)}function G(e,r,n){s._scrollY=t._fullLayout.legend._scrollY=e,c.setTranslate(z,0,-e),c.setRect(I,y,p.scrollBarMargin+e*n,p.scrollBarWidth,r),P.select(\"rect\").attr({y:s.borderwidth+e})}t._context.edits.legendPosition&&(L.classed(\"cursor-move\",!0),l.init({element:L.node(),gd:t,prepFn:function(){var t=c.getTranslate(L);k=t.x,T=t.y},moveFn:function(t,e){var r=k+t,n=T+e;c.setTranslate(L,r,n),b=l.align(r,0,f.l,f.l+f.w,s.xanchor),w=l.align(n,0,f.t+f.h,f.t,s.yanchor)},doneFn:function(){void 0!==b&&void 0!==w&&o.call(\"_guiRelayout\",t,{\"legend.x\":b,\"legend.y\":w})},clickFn:function(r,n){var i=e._infolayer.selectAll(\"g.traces\").filter(function(){var t=this.getBoundingClientRect();return n.clientX>=t.left&&n.clientX<=t.right&&n.clientY>=t.top&&n.clientY<=t.bottom});i.size()>0&&_(t,L,i,r,n)}}))}],t)}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/events\":709,\"../../lib/svg_text_utils\":743,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"./constants\":643,\"./get_legend_data\":646,\"./handle_click\":647,\"./helpers\":648,\"./style\":650,d3:163}],646:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./helpers\");e.exports=function(t,e){var r,a,o={},s=[],l=!1,c={},u=0;function h(t,r){if(\"\"!==t&&i.isGrouped(e))-1===s.indexOf(t)?(s.push(t),l=!0,o[t]=[[r]]):o[t].push([r]);else{var n=\"~~i\"+u;s.push(n),o[n]=[[r]],u++}}for(r=0;r<t.length;r++){var f=t[r],p=f[0],d=p.trace,g=d.legendgroup;if(d.visible&&d.showlegend)if(n.traceIs(d,\"pie-like\"))for(c[g]||(c[g]={}),a=0;a<f.length;a++){var v=f[a].label;c[g][v]||(h(g,{label:v,color:f[a].color,i:f[a].i,trace:d,pts:f[a].pts}),c[g][v]=!0)}else h(g,p)}if(!s.length)return[];var m,y,x=s.length;if(l&&i.isGrouped(e))for(y=new Array(x),r=0;r<x;r++)m=o[s[r]],y[r]=i.isReversed(e)?m.reverse():m;else{for(y=[new Array(x)],r=0;r<x;r++)m=o[s[r]][0],y[0][i.isReversed(e)?x-r-1:r]=m;x=1}return e._lgroupsLength=x,y}},{\"../../registry\":847,\"./helpers\":648}],647:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=!0;e.exports=function(t,e,r){var o=e._fullLayout;if(!e._dragged&&!e._editing){var s,l=o.legend.itemclick,c=o.legend.itemdoubleclick;if(1===r&&\"toggle\"===l&&\"toggleothers\"===c&&a&&e.data&&e._context.showTips?(n.notifier(n._(e,\"Double-click on legend to isolate one trace\"),\"long\"),a=!1):a=!1,1===r?s=l:2===r&&(s=c),s){var u,h,f,p,d,g=o.hiddenlabels?o.hiddenlabels.slice():[],v=t.data()[0][0],m=e._fullData,y=v.trace,x=y.legendgroup,b={},_=[],w=[],k=[];if(i.traceIs(y,\"pie-like\")){var T=v.label,A=g.indexOf(T);\"toggle\"===s?-1===A?g.push(T):g.splice(A,1):\"toggleothers\"===s&&(g=[],e.calcdata[0].forEach(function(t){T!==t.label&&g.push(t.label)}),e._fullLayout.hiddenlabels&&e._fullLayout.hiddenlabels.length===g.length&&-1===A&&(g=[])),i.call(\"_guiRelayout\",e,\"hiddenlabels\",g)}else{var M,S=x&&x.length,E=[];if(S)for(u=0;u<m.length;u++)(M=m[u]).visible&&M.legendgroup===x&&E.push(u);if(\"toggle\"===s){var C;switch(y.visible){case!0:C=\"legendonly\";break;case!1:C=!1;break;case\"legendonly\":C=!0}if(S)for(u=0;u<m.length;u++)!1!==m[u].visible&&m[u].legendgroup===x&&R(m[u],C);else R(y,C)}else if(\"toggleothers\"===s){var L,P,O=!0;for(u=0;u<m.length;u++)if(!(m[u]===y)&&!(L=S&&m[u].legendgroup===x)&&!0===m[u].visible&&!i.traceIs(m[u],\"notLegendIsolatable\")){O=!1;break}for(u=0;u<m.length;u++)if(!1!==m[u].visible&&!i.traceIs(m[u],\"notLegendIsolatable\"))switch(y.visible){case\"legendonly\":R(m[u],!0);break;case!0:P=!!O||\"legendonly\",L=m[u]===y||S&&m[u].legendgroup===x,R(m[u],!!L||P)}}for(u=0;u<w.length;u++)if(f=w[u]){var z=f.constructUpdate(),I=Object.keys(z);for(h=0;h<I.length;h++)p=I[h],(b[p]=b[p]||[])[k[u]]=z[p]}for(d=Object.keys(b),u=0;u<d.length;u++)for(p=d[u],h=0;h<_.length;h++)b[p].hasOwnProperty(h)||(b[p][h]=void 0);i.call(\"_guiRestyle\",e,b,_)}}}function D(t,e,r){var n=_.indexOf(t),i=b[e];return i||(i=b[e]=[]),-1===_.indexOf(t)&&(_.push(t),n=_.length-1),i[n]=r,n}function R(t,e){var r=t._fullInput;if(i.hasTransform(r,\"groupby\")){var a=w[r.index];if(!a){var o=i.getTransformIndices(r,\"groupby\"),s=o[o.length-1];a=n.keyedContainer(r,\"transforms[\"+s+\"].styles\",\"target\",\"value.visible\"),w[r.index]=a}var l=a.get(t._group);void 0===l&&(l=!0),!1!==l&&a.set(t._group,e),k[r.index]=D(r.index,\"visible\",!1!==r.visible)}else{var c=!1!==r.visible&&e;D(r.index,\"visible\",c)}}}},{\"../../lib\":719,\"../../registry\":847}],648:[function(t,e,r){\"use strict\";r.isGrouped=function(t){return-1!==(t.traceorder||\"\").indexOf(\"grouped\")},r.isVertical=function(t){return\"h\"!==t.orientation},r.isReversed=function(t){return-1!==(t.traceorder||\"\").indexOf(\"reversed\")}},{}],649:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"legend\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\"),style:t(\"./style\")}},{\"./attributes\":642,\"./defaults\":644,\"./draw\":645,\"./style\":650}],650:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../drawing\"),s=t(\"../color\"),l=t(\"../../traces/scatter/subtypes\"),c=t(\"../../traces/pie/style_one\"),u=t(\"../../traces/pie/helpers\").castOption,h=12,f=5,p=2,d=10,g=5;e.exports=function(t,e){var r=e._fullLayout.legend,v=\"constant\"===r.itemsizing;function m(t,e,r,n){var i;if(t+1)i=t;else{if(!(e&&e.width>0))return 0;i=e.width}return v?n:Math.min(i,r)}function y(t,e,r){var a=t[0].trace,o=a.marker||{},l=o.line||{},c=r?a.type===r&&a.visible:i.traceIs(a,\"bar\"),u=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(c?[t]:[]);u.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),u.exit().remove(),u.each(function(t){var e=n.select(this),r=t[0],i=m(r.mlw,o.line,g,p);e.style(\"stroke-width\",i+\"px\").call(s.fill,r.mc||o.color),i&&s.stroke(e,r.mlc||l.color)})}function x(t,e,r){var o=t[0],s=o.trace,l=r?s.type===r&&s.visible:i.traceIs(s,r),h=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(l?[t]:[]);if(h.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),h.exit().remove(),h.size()){var f=(s.marker||{}).line,d=m(u(f.width,o.pts),f,g,p),v=a.minExtend(s,{marker:{line:{width:d}}});v.marker.line.color=f.color;var y=a.minExtend(o,{trace:v});c(h,y,v)}}t.each(function(t){var e=n.select(this),i=a.ensureSingle(e,\"g\",\"layers\");i.style(\"opacity\",t[0].trace.opacity);var o=r.valign,s=t[0].lineHeight,l=t[0].height;if(\"middle\"!==o&&s&&l){var c={top:1,bottom:-1}[o]*(.5*(s-l+3));i.attr(\"transform\",\"translate(0,\"+c+\")\")}else i.attr(\"transform\",null);i.selectAll(\"g.legendfill\").data([t]).enter().append(\"g\").classed(\"legendfill\",!0),i.selectAll(\"g.legendlines\").data([t]).enter().append(\"g\").classed(\"legendlines\",!0);var u=i.selectAll(\"g.legendsymbols\").data([t]);u.enter().append(\"g\").classed(\"legendsymbols\",!0),u.selectAll(\"g.legendpoints\").data([t]).enter().append(\"g\").classed(\"legendpoints\",!0)}).each(function(t){var e=t[0].trace,r=[];\"waterfall\"===e.type&&e.visible&&(r=t[0].hasTotals?[[\"increasing\",\"M-6,-6V6H0Z\"],[\"totals\",\"M6,6H0L-6,-6H-0Z\"],[\"decreasing\",\"M6,6V-6H0Z\"]]:[[\"increasing\",\"M-6,-6V6H6Z\"],[\"decreasing\",\"M6,6V-6H-6Z\"]]);var i=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendwaterfall\").data(r);i.enter().append(\"path\").classed(\"legendwaterfall\",!0).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),i.exit().remove(),i.each(function(t){var r=n.select(this),i=e[t[0]].marker,a=m(void 0,i.line,g,p);r.attr(\"d\",t[1]).style(\"stroke-width\",a+\"px\").call(s.fill,i.color),a&&r.call(s.stroke,i.line.color)})}).each(function(t){y(t,this,\"funnel\")}).each(function(t){y(t,this)}).each(function(t){var r=t[0].trace,l=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendbox\").data(i.traceIs(r,\"box-violin\")&&r.visible?[t]:[]);l.enter().append(\"path\").classed(\"legendbox\",!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),l.exit().remove(),l.each(function(){var t=n.select(this);if(\"all\"!==r.boxpoints&&\"all\"!==r.points||0!==s.opacity(r.fillcolor)||0!==s.opacity((r.line||{}).color)){var i=m(void 0,r.line,g,p);t.style(\"stroke-width\",i+\"px\").call(s.fill,r.fillcolor),i&&s.stroke(t,r.line.color)}else{var c=a.minExtend(r,{marker:{size:v?h:a.constrain(r.marker.size,2,16),sizeref:1,sizemin:1,sizemode:\"diameter\"}});l.call(o.pointStyle,c,e)}})}).each(function(t){x(t,this,\"funnelarea\")}).each(function(t){x(t,this,\"pie\")}).each(function(t){var r,i,s=t[0],c=s.trace,u=c.visible&&c.fill&&\"none\"!==c.fill,h=l.hasLines(c),p=c.contours,g=!1,v=!1;if(p){var y=p.coloring;\"lines\"===y?g=!0:h=\"none\"===y||\"heatmap\"===y||p.showlines,\"constraint\"===p.type?u=\"=\"!==p._operation:\"fill\"!==y&&\"heatmap\"!==y||(v=!0)}var x=l.hasMarkers(c)||l.hasText(c),b=u||v,_=h||g,w=x||!b?\"M5,0\":_?\"M5,-2\":\"M5,-3\",k=n.select(this),T=k.select(\".legendfill\").selectAll(\"path\").data(u||v?[t]:[]);if(T.enter().append(\"path\").classed(\"js-fill\",!0),T.exit().remove(),T.attr(\"d\",w+\"h30v6h-30z\").call(u?o.fillGroupStyle:function(t){if(t.size()){var r=\"legendfill-\"+c.uid;o.gradient(t,e,r,\"horizontalreversed\",c.colorscale,\"fill\")}}),h||g){var A=m(void 0,c.line,d,f);i=a.minExtend(c,{line:{width:A}}),r=[a.minExtend(s,{trace:i})]}var M=k.select(\".legendlines\").selectAll(\"path\").data(h||g?[r]:[]);M.enter().append(\"path\").classed(\"js-line\",!0),M.exit().remove(),M.attr(\"d\",w+(g?\"l30,0.0001\":\"h30\")).call(h?o.lineGroupStyle:function(t){if(t.size()){var r=\"legendline-\"+c.uid;o.lineGroupStyle(t),o.gradient(t,e,r,\"horizontalreversed\",c.colorscale,\"stroke\")}})}).each(function(t){var r,i,s=t[0],c=s.trace,u=l.hasMarkers(c),d=l.hasText(c),g=l.hasLines(c);function m(t,e,r,n){var i=a.nestedProperty(c,t).get(),o=a.isArrayOrTypedArray(i)&&e?e(i):i;if(v&&o&&void 0!==n&&(o=n),r){if(o<r[0])return r[0];if(o>r[1])return r[1]}return o}function y(t){return t[0]}if(u||d||g){var x={},b={};if(u){x.mc=m(\"marker.color\",y),x.mx=m(\"marker.symbol\",y),x.mo=m(\"marker.opacity\",a.mean,[.2,1]),x.mlc=m(\"marker.line.color\",y),x.mlw=m(\"marker.line.width\",a.mean,[0,5],p),b.marker={sizeref:1,sizemin:1,sizemode:\"diameter\"};var _=m(\"marker.size\",a.mean,[2,16],h);x.ms=_,b.marker.size=_}g&&(b.line={width:m(\"line.width\",y,[0,10],f)}),d&&(x.tx=\"Aa\",x.tp=m(\"textposition\",y),x.ts=10,x.tc=m(\"textfont.color\",y),x.tf=m(\"textfont.family\",y)),r=[a.minExtend(s,x)],(i=a.minExtend(c,b)).selectedpoints=null}var w=n.select(this).select(\"g.legendpoints\"),k=w.selectAll(\"path.scatterpts\").data(u?r:[]);k.enter().insert(\"path\",\":first-child\").classed(\"scatterpts\",!0).attr(\"transform\",\"translate(20,0)\"),k.exit().remove(),k.call(o.pointStyle,i,e),u&&(r[0].mrc=3);var T=w.selectAll(\"g.pointtext\").data(d?r:[]);T.enter().append(\"g\").classed(\"pointtext\",!0).append(\"text\").attr(\"transform\",\"translate(20,0)\"),T.exit().remove(),T.selectAll(\"text\").call(o.textPointStyle,i,e)}).each(function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendcandle\").data(\"candlestick\"===e.type&&e.visible?[t,t]:[]);r.enter().append(\"path\").classed(\"legendcandle\",!0).attr(\"d\",function(t,e){return e?\"M-15,0H-8M-8,6V-6H8Z\":\"M15,0H8M8,-6V6H-8Z\"}).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),r.exit().remove(),r.each(function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],o=m(void 0,a.line,g,p);i.style(\"stroke-width\",o+\"px\").call(s.fill,a.fillcolor),o&&s.stroke(i,a.line.color)})}).each(function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendohlc\").data(\"ohlc\"===e.type&&e.visible?[t,t]:[]);r.enter().append(\"path\").classed(\"legendohlc\",!0).attr(\"d\",function(t,e){return e?\"M-15,0H0M-8,-6V0\":\"M15,0H0M8,6V0\"}).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),r.exit().remove(),r.each(function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],l=m(void 0,a.line,g,p);i.style(\"fill\",\"none\").call(o.dashLine,a.line.dash,l),l&&s.stroke(i,a.line.color)})})}},{\"../../lib\":719,\"../../registry\":847,\"../../traces/pie/helpers\":1091,\"../../traces/pie/style_one\":1097,\"../../traces/scatter/subtypes\":1135,\"../color\":593,\"../drawing\":614,d3:163}],651:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/plots\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../lib\"),s=t(\"../../fonts/ploticon\"),l=o._,c=e.exports={};function u(t,e){var r,i,o=e.currentTarget,s=o.getAttribute(\"data-attr\"),l=o.getAttribute(\"data-val\")||!0,c=t._fullLayout,u={},h=a.list(t,null,!0),f=\"on\";if(\"zoom\"===s){var p,d=\"in\"===l?.5:2,g=(1+d)/2,v=(1-d)/2;for(i=0;i<h.length;i++)if(!(r=h[i]).fixedrange)if(p=r._name,\"auto\"===l)u[p+\".autorange\"]=!0;else if(\"reset\"===l){if(void 0===r._rangeInitial)u[p+\".autorange\"]=!0;else{var m=r._rangeInitial.slice();u[p+\".range[0]\"]=m[0],u[p+\".range[1]\"]=m[1]}void 0!==r._showSpikeInitial&&(u[p+\".showspikes\"]=r._showSpikeInitial,\"on\"!==f||r._showSpikeInitial||(f=\"off\"))}else{var y=[r.r2l(r.range[0]),r.r2l(r.range[1])],x=[g*y[0]+v*y[1],g*y[1]+v*y[0]];u[p+\".range[0]\"]=r.l2r(x[0]),u[p+\".range[1]\"]=r.l2r(x[1])}c._cartesianSpikesEnabled=f}else{if(\"hovermode\"!==s||\"x\"!==l&&\"y\"!==l){if(\"hovermode\"===s&&\"closest\"===l){for(i=0;i<h.length;i++)r=h[i],\"on\"!==f||r.showspikes||(f=\"off\");c._cartesianSpikesEnabled=f}}else l=c._isHoriz?\"y\":\"x\",o.setAttribute(\"data-val\",l);u[s]=l}n.call(\"_guiRelayout\",t,u)}function h(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout._subplots.gl3d,s={},l=i.split(\".\"),c=0;c<o.length;c++)s[o[c]+\".\"+l[1]]=a;var u=\"pan\"===a?a:\"zoom\";s.dragmode=u,n.call(\"_guiRelayout\",t,s)}function f(t,e){for(var r=e.currentTarget.getAttribute(\"data-attr\"),i=t._fullLayout,a=i._subplots.gl3d,o={},s=0;s<a.length;s++){var l=a[s],c=l+\".camera\",u=i[l]._scene;\"resetLastSave\"===r?(o[c+\".up\"]=u.viewInitial.up,o[c+\".eye\"]=u.viewInitial.eye,o[c+\".center\"]=u.viewInitial.center):\"resetDefault\"===r&&(o[c+\".up\"]=null,o[c+\".eye\"]=null,o[c+\".center\"]=null)}n.call(\"_guiRelayout\",t,o)}function p(t,e){var r=e.currentTarget,n=r._previousVal,i=t._fullLayout,a=i._subplots.gl3d,o=[\"xaxis\",\"yaxis\",\"zaxis\"],s={},l={};if(n)l=n,r._previousVal=null;else{for(var c=0;c<a.length;c++){var u=a[c],h=i[u],f=u+\".hovermode\";s[f]=h.hovermode,l[f]=!1;for(var p=0;p<3;p++){var d=o[p],g=u+\".\"+d+\".showspikes\";l[g]=!1,s[g]=h[d].showspikes}}r._previousVal=s}return l}function d(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout,s=o._subplots.geo,l=0;l<s.length;l++){var c=s[l],u=o[c];if(\"zoom\"===i){var h=u.projection.scale,f=\"in\"===a?2*h:.5*h;n.call(\"_guiRelayout\",t,c+\".projection.scale\",f)}else\"reset\"===i&&m(t,\"geo\")}}function g(t){var e=t._fullLayout;return!e.hovermode&&(e._has(\"cartesian\")?e._isHoriz?\"y\":\"x\":\"closest\")}function v(t){var e=g(t);n.call(\"_guiRelayout\",t,\"hovermode\",e)}function m(t,e){for(var r=t._fullLayout,i=r._subplots[e],a={},o=0;o<i.length;o++)for(var s=i[o],l=r[s]._subplot.viewInitial,c=Object.keys(l),u=0;u<c.length;u++){var h=c[u];a[s+\".\"+h]=l[h]}n.call(\"_guiRelayout\",t,a)}c.toImage={name:\"toImage\",title:function(t){var e=(t._context.toImageButtonOptions||{}).format||\"png\";return l(t,\"png\"===e?\"Download plot as a png\":\"Download plot\")},icon:s.camera,click:function(t){var e=t._context.toImageButtonOptions,r={format:e.format||\"png\"};o.notifier(l(t,\"Taking snapshot - this may take a few seconds\"),\"long\"),\"svg\"!==r.format&&o.isIE()&&(o.notifier(l(t,\"IE only supports svg.  Changing format to svg.\"),\"long\"),r.format=\"svg\"),[\"filename\",\"width\",\"height\",\"scale\"].forEach(function(t){t in e&&(r[t]=e[t])}),n.call(\"downloadImage\",t,r).then(function(e){o.notifier(l(t,\"Snapshot succeeded\")+\" - \"+e,\"long\")}).catch(function(){o.notifier(l(t,\"Sorry, there was a problem downloading your snapshot!\"),\"long\")})}},c.sendDataToCloud={name:\"sendDataToCloud\",title:function(t){return l(t,\"Edit in Chart Studio\")},icon:s.disk,click:function(t){i.sendDataToCloud(t)}},c.editInChartStudio={name:\"editInChartStudio\",title:function(t){return l(t,\"Edit in Chart Studio\")},icon:s.pencil,click:function(t){i.sendDataToCloud(t)}},c.zoom2d={name:\"zoom2d\",title:function(t){return l(t,\"Zoom\")},attr:\"dragmode\",val:\"zoom\",icon:s.zoombox,click:u},c.pan2d={name:\"pan2d\",title:function(t){return l(t,\"Pan\")},attr:\"dragmode\",val:\"pan\",icon:s.pan,click:u},c.select2d={name:\"select2d\",title:function(t){return l(t,\"Box Select\")},attr:\"dragmode\",val:\"select\",icon:s.selectbox,click:u},c.lasso2d={name:\"lasso2d\",title:function(t){return l(t,\"Lasso Select\")},attr:\"dragmode\",val:\"lasso\",icon:s.lasso,click:u},c.zoomIn2d={name:\"zoomIn2d\",title:function(t){return l(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:s.zoom_plus,click:u},c.zoomOut2d={name:\"zoomOut2d\",title:function(t){return l(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:s.zoom_minus,click:u},c.autoScale2d={name:\"autoScale2d\",title:function(t){return l(t,\"Autoscale\")},attr:\"zoom\",val:\"auto\",icon:s.autoscale,click:u},c.resetScale2d={name:\"resetScale2d\",title:function(t){return l(t,\"Reset axes\")},attr:\"zoom\",val:\"reset\",icon:s.home,click:u},c.hoverClosestCartesian={name:\"hoverClosestCartesian\",title:function(t){return l(t,\"Show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:s.tooltip_basic,gravity:\"ne\",click:u},c.hoverCompareCartesian={name:\"hoverCompareCartesian\",title:function(t){return l(t,\"Compare data on hover\")},attr:\"hovermode\",val:function(t){return t._fullLayout._isHoriz?\"y\":\"x\"},icon:s.tooltip_compare,gravity:\"ne\",click:u},c.zoom3d={name:\"zoom3d\",title:function(t){return l(t,\"Zoom\")},attr:\"scene.dragmode\",val:\"zoom\",icon:s.zoombox,click:h},c.pan3d={name:\"pan3d\",title:function(t){return l(t,\"Pan\")},attr:\"scene.dragmode\",val:\"pan\",icon:s.pan,click:h},c.orbitRotation={name:\"orbitRotation\",title:function(t){return l(t,\"Orbital rotation\")},attr:\"scene.dragmode\",val:\"orbit\",icon:s[\"3d_rotate\"],click:h},c.tableRotation={name:\"tableRotation\",title:function(t){return l(t,\"Turntable rotation\")},attr:\"scene.dragmode\",val:\"turntable\",icon:s[\"z-axis\"],click:h},c.resetCameraDefault3d={name:\"resetCameraDefault3d\",title:function(t){return l(t,\"Reset camera to default\")},attr:\"resetDefault\",icon:s.home,click:f},c.resetCameraLastSave3d={name:\"resetCameraLastSave3d\",title:function(t){return l(t,\"Reset camera to last save\")},attr:\"resetLastSave\",icon:s.movie,click:f},c.hoverClosest3d={name:\"hoverClosest3d\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=p(t,e);n.call(\"_guiRelayout\",t,r)}},c.zoomInGeo={name:\"zoomInGeo\",title:function(t){return l(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:s.zoom_plus,click:d},c.zoomOutGeo={name:\"zoomOutGeo\",title:function(t){return l(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:s.zoom_minus,click:d},c.resetGeo={name:\"resetGeo\",title:function(t){return l(t,\"Reset\")},attr:\"reset\",val:null,icon:s.autoscale,click:d},c.hoverClosestGeo={name:\"hoverClosestGeo\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:v},c.hoverClosestGl2d={name:\"hoverClosestGl2d\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:v},c.hoverClosestPie={name:\"hoverClosestPie\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:s.tooltip_basic,gravity:\"ne\",click:v},c.resetViewSankey={name:\"resetSankeyGroup\",title:function(t){return l(t,\"Reset view\")},icon:s.home,click:function(t){for(var e={\"node.groups\":[],\"node.x\":[],\"node.y\":[]},r=0;r<t._fullData.length;r++){var i=t._fullData[r]._viewInitial;e[\"node.groups\"].push(i.node.groups.slice()),e[\"node.x\"].push(i.node.x.slice()),e[\"node.y\"].push(i.node.y.slice())}n.call(\"restyle\",t,e)}},c.toggleHover={name:\"toggleHover\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=p(t,e);r.hovermode=g(t),n.call(\"_guiRelayout\",t,r)}},c.resetViews={name:\"resetViews\",title:function(t){return l(t,\"Reset views\")},icon:s.home,click:function(t,e){var r=e.currentTarget;r.setAttribute(\"data-attr\",\"zoom\"),r.setAttribute(\"data-val\",\"reset\"),u(t,e),r.setAttribute(\"data-attr\",\"resetLastSave\"),f(t,e),m(t,\"geo\"),m(t,\"mapbox\")}},c.toggleSpikelines={name:\"toggleSpikelines\",title:function(t){return l(t,\"Toggle Spike Lines\")},icon:s.spikeline,attr:\"_cartesianSpikesEnabled\",val:\"on\",click:function(t){var e=t._fullLayout;e._cartesianSpikesEnabled=\"on\"===e._cartesianSpikesEnabled?\"off\":\"on\";var r=function(t){for(var e,r,n=t._fullLayout,i=a.list(t,null,!0),o={},s=0;s<i.length;s++)e=i[s],r=e._name,o[r+\".showspikes\"]=\"on\"===n._cartesianSpikesEnabled||e._showSpikeInitial;return o}(t);n.call(\"_guiRelayout\",t,r)}},c.resetViewMapbox={name:\"resetViewMapbox\",title:function(t){return l(t,\"Reset view\")},attr:\"reset\",icon:s.home,click:function(t){m(t,\"mapbox\")}}},{\"../../fonts/ploticon\":699,\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../../plots/plots\":828,\"../../registry\":847}],652:[function(t,e,r){\"use strict\";r.manage=t(\"./manage\")},{\"./manage\":653}],653:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"../../traces/scatter/subtypes\"),a=t(\"../../registry\"),o=t(\"./modebar\"),s=t(\"./buttons\");e.exports=function(t){var e=t._fullLayout,r=t._context,l=e._modeBar;if(r.displayModeBar||r.watermark){if(!Array.isArray(r.modeBarButtonsToRemove))throw new Error([\"*modeBarButtonsToRemove* configuration options\",\"must be an array.\"].join(\" \"));if(!Array.isArray(r.modeBarButtonsToAdd))throw new Error([\"*modeBarButtonsToAdd* configuration options\",\"must be an array.\"].join(\" \"));var c,u=r.modeBarButtons;c=Array.isArray(u)&&u.length?function(t){for(var e=0;e<t.length;e++)for(var r=t[e],n=0;n<r.length;n++){var i=r[n];if(\"string\"==typeof i){if(void 0===s[i])throw new Error([\"*modeBarButtons* configuration options\",\"invalid button name\"].join(\" \"));t[e][n]=s[i]}}return t}(u):!r.displayModeBar&&r.watermark?[]:function(t){var e=t._fullLayout,r=t._fullData,o=t._context,l=o.modeBarButtonsToRemove,c=o.modeBarButtonsToAdd,u=e._has(\"cartesian\"),h=e._has(\"gl3d\"),f=e._has(\"geo\"),p=e._has(\"pie\"),d=e._has(\"funnelarea\"),g=e._has(\"gl2d\"),v=e._has(\"ternary\"),m=e._has(\"mapbox\"),y=e._has(\"polar\"),x=e._has(\"sankey\"),b=function(t){for(var e=n.list({_fullLayout:t},null,!0),r=0;r<e.length;r++)if(!e[r].fixedrange)return!1;return!0}(e),_=[];function w(t){if(t.length){for(var e=[],r=0;r<t.length;r++){var n=t[r];-1===l.indexOf(n)&&e.push(s[n])}_.push(e)}}var k=[\"toImage\"];o.showEditInChartStudio?k.push(\"editInChartStudio\"):o.showSendToCloud&&k.push(\"sendDataToCloud\");w(k);var T=[],A=[],M=[],S=[];(u||g||p||d||v)+f+h+m+y>1?(A=[\"toggleHover\"],M=[\"resetViews\"]):f?(T=[\"zoomInGeo\",\"zoomOutGeo\"],A=[\"hoverClosestGeo\"],M=[\"resetGeo\"]):h?(A=[\"hoverClosest3d\"],M=[\"resetCameraDefault3d\",\"resetCameraLastSave3d\"]):m?(A=[\"toggleHover\"],M=[\"resetViewMapbox\"]):g?A=[\"hoverClosestGl2d\"]:p?A=[\"hoverClosestPie\"]:x?(A=[\"hoverClosestCartesian\",\"hoverCompareCartesian\"],M=[\"resetViewSankey\"]):A=[\"toggleHover\"];u&&(A=[\"toggleSpikelines\",\"hoverClosestCartesian\",\"hoverCompareCartesian\"]);(function(t){for(var e=0;e<t.length;e++)if(!a.traceIs(t[e],\"noHover\"))return!1;return!0})(r)&&(A=[]);!u&&!g||b||(T=[\"zoomIn2d\",\"zoomOut2d\",\"autoScale2d\"],\"resetViews\"!==M[0]&&(M=[\"resetScale2d\"]));h?S=[\"zoom3d\",\"pan3d\",\"orbitRotation\",\"tableRotation\"]:(u||g)&&!b||v?S=[\"zoom2d\",\"pan2d\"]:m||f?S=[\"pan2d\"]:y&&(S=[\"zoom2d\"]);(function(t){for(var e=!1,r=0;r<t.length&&!e;r++){var n=t[r];n._module&&n._module.selectPoints&&(a.traceIs(n,\"scatter-like\")?(i.hasMarkers(n)||i.hasText(n))&&(e=!0):a.traceIs(n,\"box-violin\")&&\"all\"!==n.boxpoints&&\"all\"!==n.points||(e=!0))}return e})(r)&&S.push(\"select2d\",\"lasso2d\");return w(S),w(T.concat(M)),w(A),function(t,e){if(e.length)if(Array.isArray(e[0]))for(var r=0;r<e.length;r++)t.push(e[r]);else t.push(e);return t}(_,c)}(t),l?l.update(t,c):e._modeBar=o(t,c)}else l&&(l.destroy(),delete e._modeBar)}},{\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../../traces/scatter/subtypes\":1135,\"./buttons\":651,\"./modebar\":654}],654:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../fonts/ploticon\"),s=new DOMParser;function l(t){this.container=t.container,this.element=document.createElement(\"div\"),this.update(t.graphInfo,t.buttons),this.container.appendChild(this.element)}var c=l.prototype;c.update=function(t,e){this.graphInfo=t;var r=this.graphInfo._context,n=this.graphInfo._fullLayout,i=\"modebar-\"+n._uid;this.element.setAttribute(\"id\",i),this._uid=i,this.element.className=\"modebar\",\"hover\"===r.displayModeBar&&(this.element.className+=\" modebar--hover ease-bg\"),\"v\"===n.modebar.orientation&&(this.element.className+=\" vertical\",e=e.reverse());var o=n.modebar,s=\"hover\"===r.displayModeBar?\".js-plotly-plot .plotly:hover \":\"\";a.deleteRelatedStyleRule(i),a.addRelatedStyleRule(i,s+\"#\"+i+\" .modebar-group\",\"background-color: \"+o.bgcolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn .icon path\",\"fill: \"+o.color),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn:hover .icon path\",\"fill: \"+o.activecolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn.active .icon path\",\"fill: \"+o.activecolor);var l=!this.hasButtons(e),c=this.hasLogo!==r.displaylogo,u=this.locale!==r.locale;if(this.locale=r.locale,(l||c||u)&&(this.removeAllButtons(),this.updateButtons(e),r.watermark||r.displaylogo)){var h=this.getLogo();r.watermark&&(h.className=h.className+\" watermark\"),\"v\"===n.modebar.orientation?this.element.insertBefore(h,this.element.childNodes[0]):this.element.appendChild(h),this.hasLogo=!0}this.updateActiveButton()},c.updateButtons=function(t){var e=this;this.buttons=t,this.buttonElements=[],this.buttonsNames=[],this.buttons.forEach(function(t){var r=e.createGroup();t.forEach(function(t){var n=t.name;if(!n)throw new Error(\"must provide button 'name' in button config\");if(-1!==e.buttonsNames.indexOf(n))throw new Error(\"button name '\"+n+\"' is taken\");e.buttonsNames.push(n);var i=e.createButton(t);e.buttonElements.push(i),r.appendChild(i)}),e.element.appendChild(r)})},c.createGroup=function(){var t=document.createElement(\"div\");return t.className=\"modebar-group\",t},c.createButton=function(t){var e=this,r=document.createElement(\"a\");r.setAttribute(\"rel\",\"tooltip\"),r.className=\"modebar-btn\";var i=t.title;void 0===i?i=t.name:\"function\"==typeof i&&(i=i(this.graphInfo)),(i||0===i)&&r.setAttribute(\"data-title\",i),void 0!==t.attr&&r.setAttribute(\"data-attr\",t.attr);var a=t.val;if(void 0!==a&&(\"function\"==typeof a&&(a=a(this.graphInfo)),r.setAttribute(\"data-val\",a)),\"function\"!=typeof t.click)throw new Error(\"must provide button 'click' function in button config\");r.addEventListener(\"click\",function(r){t.click(e.graphInfo,r),e.updateActiveButton(r.currentTarget)}),r.setAttribute(\"data-toggle\",t.toggle||!1),t.toggle&&n.select(r).classed(\"active\",!0);var s=t.icon;return\"function\"==typeof s?r.appendChild(s()):r.appendChild(this.createIcon(s||o.question)),r.setAttribute(\"data-gravity\",t.gravity||\"n\"),r},c.createIcon=function(t){var e,r=i(t.height)?Number(t.height):t.ascent-t.descent,n=\"http://www.w3.org/2000/svg\";if(t.path){(e=document.createElementNS(n,\"svg\")).setAttribute(\"viewBox\",[0,0,t.width,r].join(\" \")),e.setAttribute(\"class\",\"icon\");var a=document.createElementNS(n,\"path\");a.setAttribute(\"d\",t.path),t.transform?a.setAttribute(\"transform\",t.transform):void 0!==t.ascent&&a.setAttribute(\"transform\",\"matrix(1 0 0 -1 0 \"+t.ascent+\")\"),e.appendChild(a)}t.svg&&(e=s.parseFromString(t.svg,\"application/xml\").childNodes[0]);return e.setAttribute(\"height\",\"1em\"),e.setAttribute(\"width\",\"1em\"),e},c.updateActiveButton=function(t){var e=this.graphInfo._fullLayout,r=void 0!==t?t.getAttribute(\"data-attr\"):null;this.buttonElements.forEach(function(t){var i=t.getAttribute(\"data-val\")||!0,o=t.getAttribute(\"data-attr\"),s=\"true\"===t.getAttribute(\"data-toggle\"),l=n.select(t);if(s)o===r&&l.classed(\"active\",!l.classed(\"active\"));else{var c=null===o?o:a.nestedProperty(e,o).get();l.classed(\"active\",c===i)}})},c.hasButtons=function(t){var e=this.buttons;if(!e)return!1;if(t.length!==e.length)return!1;for(var r=0;r<t.length;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;n++)if(t[r][n].name!==e[r][n].name)return!1}return!0},c.getLogo=function(){var t=this.createGroup(),e=document.createElement(\"a\");return e.href=\"https://plot.ly/\",e.target=\"_blank\",e.setAttribute(\"data-title\",a._(this.graphInfo,\"Produced with Plotly\")),e.className=\"modebar-btn plotlyjsicon modebar-btn--logo\",e.appendChild(this.createIcon(o.newplotlylogo)),t.appendChild(e),t},c.removeAllButtons=function(){for(;this.element.firstChild;)this.element.removeChild(this.element.firstChild);this.hasLogo=!1},c.destroy=function(){a.removeElement(this.container.querySelector(\".modebar\")),a.deleteRelatedStyleRule(this._uid)},e.exports=function(t,e){var r=t._fullLayout,i=new l({graphInfo:t,container:r._modebardiv.node(),buttons:e});return r._privateplot&&n.select(i.element).append(\"span\").classed(\"badge-private float--left\",!0).text(\"PRIVATE\"),i}},{\"../../fonts/ploticon\":699,\"../../lib\":719,d3:163,\"fast-isnumeric\":225}],655:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=(0,t(\"../../plot_api/plot_template\").templatedArray)(\"button\",{visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},step:{valType:\"enumerated\",values:[\"month\",\"year\",\"day\",\"hour\",\"minute\",\"second\",\"all\"],dflt:\"month\",editType:\"plot\"},stepmode:{valType:\"enumerated\",values:[\"backward\",\"todate\"],dflt:\"backward\",editType:\"plot\"},count:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},label:{valType:\"string\",editType:\"plot\"},editType:\"plot\"});e.exports={visible:{valType:\"boolean\",editType:\"plot\"},buttons:a,x:{valType:\"number\",min:-2,max:3,editType:\"plot\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"plot\"},y:{valType:\"number\",min:-2,max:3,editType:\"plot\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"bottom\",editType:\"plot\"},font:n({editType:\"plot\"}),bgcolor:{valType:\"color\",dflt:i.lightLine,editType:\"plot\"},activecolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"plot\"}},{\"../../plot_api/plot_template\":757,\"../../plots/font_attributes\":793,\"../color/attributes\":592}],656:[function(t,e,r){\"use strict\";e.exports={yPad:.02,minButtonWidth:30,rx:3,ry:3,lightAmount:25,darkAmount:10}},{}],657:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../../plots/array_container_defaults\"),s=t(\"./attributes\"),l=t(\"./constants\");function c(t,e,r,i){var a=i.calendar;function o(r,i){return n.coerce(t,e,s.buttons,r,i)}if(o(\"visible\")){var l=o(\"step\");\"all\"!==l&&(!a||\"gregorian\"===a||\"month\"!==l&&\"year\"!==l?o(\"stepmode\"):e.stepmode=\"backward\",o(\"count\")),o(\"label\")}}e.exports=function(t,e,r,u,h){var f=t.rangeselector||{},p=a.newContainer(e,\"rangeselector\");function d(t,e){return n.coerce(f,p,s,t,e)}if(d(\"visible\",o(f,p,{name:\"buttons\",handleItemDefaults:c,calendar:h}).length>0)){var g=function(t,e,r){for(var n=r.filter(function(r){return e[r].anchor===t._id}),i=0,a=0;a<n.length;a++){var o=e[n[a]].domain;o&&(i=Math.max(o[1],i))}return[t.domain[0],i+l.yPad]}(e,r,u);d(\"x\",g[0]),d(\"y\",g[1]),n.noneOrAll(t,e,[\"x\",\"y\"]),d(\"xanchor\"),d(\"yanchor\"),n.coerceFont(d,\"font\",r.font);var v=d(\"bgcolor\");d(\"activecolor\",i.contrast(v,l.lightAmount,l.darkAmount)),d(\"bordercolor\"),d(\"borderwidth\")}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/array_container_defaults\":763,\"../color\":593,\"./attributes\":655,\"./constants\":656}],658:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../color\"),s=t(\"../drawing\"),l=t(\"../../lib\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"../../plots/cartesian/axis_ids\"),h=t(\"../../constants/alignment\"),f=h.LINE_SPACING,p=h.FROM_TL,d=h.FROM_BR,g=t(\"./constants\"),v=t(\"./get_update_object\");function m(t){return t._id}function y(t,e,r){var n=l.ensureSingle(t,\"rect\",\"selector-rect\",function(t){t.attr(\"shape-rendering\",\"crispEdges\")});n.attr({rx:g.rx,ry:g.ry}),n.call(o.stroke,e.bordercolor).call(o.fill,function(t,e){return e._isActive||e._isHovered?t.activecolor:t.bgcolor}(e,r)).style(\"stroke-width\",e.borderwidth+\"px\")}function x(t,e,r,n){l.ensureSingle(t,\"text\",\"selector-text\",function(t){t.classed(\"user-select-none\",!0).attr(\"text-anchor\",\"middle\")}).call(s.font,e.font).text(function(t,e){if(t.label)return e?l.templateString(t.label,e):t.label;return\"all\"===t.step?\"all\":t.count+t.step.charAt(0)}(r,n._fullLayout._meta)).call(function(t){c.convertToTspans(t,n)})}e.exports=function(t){var e=t._fullLayout._infolayer.selectAll(\".rangeselector\").data(function(t){for(var e=u.list(t,\"x\",!0),r=[],n=0;n<e.length;n++){var i=e[n];i.rangeselector&&i.rangeselector.visible&&r.push(i)}return r}(t),m);e.enter().append(\"g\").classed(\"rangeselector\",!0),e.exit().remove(),e.style({cursor:\"pointer\",\"pointer-events\":\"all\"}),e.each(function(e){var r=n.select(this),o=e,u=o.rangeselector,h=r.selectAll(\"g.button\").data(l.filterVisible(u.buttons));h.enter().append(\"g\").classed(\"button\",!0),h.exit().remove(),h.each(function(e){var r=n.select(this),a=v(o,e);e._isActive=function(t,e,r){if(\"all\"===e.step)return!0===t.autorange;var n=Object.keys(r);return t.range[0]===r[n[0]]&&t.range[1]===r[n[1]]}(o,e,a),r.call(y,u,e),r.call(x,u,e,t),r.on(\"click\",function(){t._dragged||i.call(\"_guiRelayout\",t,a)}),r.on(\"mouseover\",function(){e._isHovered=!0,r.call(y,u,e)}),r.on(\"mouseout\",function(){e._isHovered=!1,r.call(y,u,e)})}),function(t,e,r,i,o){var u=0,h=0,v=r.borderwidth;e.each(function(){var t=n.select(this),e=t.select(\".selector-text\"),i=r.font.size*f,a=Math.max(i*c.lineCount(e),16)+3;h=Math.max(h,a)}),e.each(function(){var t=n.select(this),e=t.select(\".selector-rect\"),i=t.select(\".selector-text\"),a=i.node()&&s.bBox(i.node()).width,o=r.font.size*f,l=c.lineCount(i),p=Math.max(a+10,g.minButtonWidth);t.attr(\"transform\",\"translate(\"+(v+u)+\",\"+v+\")\"),e.attr({x:0,y:0,width:p,height:h}),c.positionText(i,p/2,h/2-(l-1)*o/2+3),u+=p+5});var m=t._fullLayout._size,y=m.l+m.w*r.x,x=m.t+m.h*(1-r.y),b=\"left\";l.isRightAnchor(r)&&(y-=u,b=\"right\");l.isCenterAnchor(r)&&(y-=u/2,b=\"center\");var _=\"top\";l.isBottomAnchor(r)&&(x-=h,_=\"bottom\");l.isMiddleAnchor(r)&&(x-=h/2,_=\"middle\");u=Math.ceil(u),h=Math.ceil(h),y=Math.round(y),x=Math.round(x),a.autoMargin(t,i+\"-range-selector\",{x:r.x,y:r.y,l:u*p[b],r:u*d[b],b:h*d[_],t:h*p[_]}),o.attr(\"transform\",\"translate(\"+y+\",\"+x+\")\")}(t,h,u,o._name,r)})}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axis_ids\":770,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../drawing\":614,\"./constants\":656,\"./get_update_object\":659,d3:163}],659:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e){var r=t._name,i={};if(\"all\"===e.step)i[r+\".autorange\"]=!0;else{var a=function(t,e){var r,i=t.range,a=new Date(t.r2l(i[1])),o=e.step,s=e.count;switch(e.stepmode){case\"backward\":r=t.l2r(+n.time[o].utc.offset(a,-s));break;case\"todate\":var l=n.time[o].utc.offset(a,-s);r=t.l2r(+n.time[o].utc.ceil(l))}var c=i[1];return[r,c]}(t,e);i[r+\".range[0]\"]=a[0],i[r+\".range[1]\"]=a[1]}return i}},{d3:163}],660:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"rangeselector\",schema:{subplots:{xaxis:{rangeselector:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":655,\"./defaults\":657,\"./draw\":658}],661:[function(t,e,r){\"use strict\";var n=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",dflt:n.background,editType:\"plot\"},bordercolor:{valType:\"color\",dflt:n.defaultLine,editType:\"plot\"},borderwidth:{valType:\"integer\",dflt:0,min:0,editType:\"plot\"},autorange:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}}],editType:\"calc\",impliedEdits:{autorange:!1}},thickness:{valType:\"number\",dflt:.15,min:0,max:1,editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"}},{\"../color/attributes\":592}],662:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\").list,i=t(\"../../plots/cartesian/autorange\").getAutoRange,a=t(\"./constants\");e.exports=function(t){for(var e=n(t,\"x\",!0),r=0;r<e.length;r++){var o=e[r],s=o[a.name];s&&s.visible&&s.autorange&&(s._input.autorange=!0,s._input.range=s.range=i(t,o))}}},{\"../../plots/cartesian/autorange\":766,\"../../plots/cartesian/axis_ids\":770,\"./constants\":663}],663:[function(t,e,r){\"use strict\";e.exports={name:\"rangeslider\",containerClassName:\"rangeslider-container\",bgClassName:\"rangeslider-bg\",rangePlotClassName:\"rangeslider-rangeplot\",maskMinClassName:\"rangeslider-mask-min\",maskMaxClassName:\"rangeslider-mask-max\",slideBoxClassName:\"rangeslider-slidebox\",grabberMinClassName:\"rangeslider-grabber-min\",grabAreaMinClassName:\"rangeslider-grabarea-min\",handleMinClassName:\"rangeslider-handle-min\",grabberMaxClassName:\"rangeslider-grabber-max\",grabAreaMaxClassName:\"rangeslider-grabarea-max\",handleMaxClassName:\"rangeslider-handle-max\",maskMinOppAxisClassName:\"rangeslider-mask-min-opp-axis\",maskMaxOppAxisClassName:\"rangeslider-mask-max-opp-axis\",maskColor:\"rgba(0,0,0,0.4)\",maskOppAxisColor:\"rgba(0,0,0,0.2)\",slideBoxFill:\"transparent\",slideBoxCursor:\"ew-resize\",grabAreaFill:\"transparent\",grabAreaCursor:\"col-resize\",grabAreaWidth:10,handleWidth:4,handleRadius:1,handleStrokeWidth:1,extraPad:15}},{}],664:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"./attributes\"),s=t(\"./oppaxis_attributes\");e.exports=function(t,e,r){var l=t[r],c=e[r];if(l.rangeslider||e._requestRangeslider[c._id]){n.isPlainObject(l.rangeslider)||(l.rangeslider={});var u,h,f=l.rangeslider,p=i.newContainer(c,\"rangeslider\");if(_(\"visible\")){_(\"bgcolor\",e.plot_bgcolor),_(\"bordercolor\"),_(\"borderwidth\"),_(\"thickness\"),_(\"autorange\",!c.isValidRange(f.range)),_(\"range\");var d=e._subplots;if(d)for(var g=d.cartesian.filter(function(t){return t.substr(0,t.indexOf(\"y\"))===a.name2id(r)}).map(function(t){return t.substr(t.indexOf(\"y\"),t.length)}),v=n.simpleMap(g,a.id2name),m=0;m<v.length;m++){var y=v[m];u=f[y]||{},h=i.newContainer(p,y,\"yaxis\");var x,b=e[y];u.range&&b.isValidRange(u.range)&&(x=\"fixed\"),\"match\"!==w(\"rangemode\",x)&&w(\"range\",b.range.slice())}p._input=f}}function _(t,e){return n.coerce(f,p,o,t,e)}function w(t,e){return n.coerce(u,h,s,t,e)}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/axis_ids\":770,\"./attributes\":661,\"./oppaxis_attributes\":668}],665:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=t(\"../drawing\"),l=t(\"../color\"),c=t(\"../titles\"),u=t(\"../../plots/cartesian\"),h=t(\"../../plots/cartesian/axis_ids\"),f=t(\"../dragelement\"),p=t(\"../../lib/setcursor\"),d=t(\"./constants\");function g(t,e,r,n){var i=o.ensureSingle(t,\"rect\",d.bgClassName,function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})}),a=n.borderwidth%2==0?n.borderwidth:n.borderwidth-1,l=-n._offsetShift,c=s.crispRound(e,n.borderwidth);i.attr({width:n._width+a,height:n._height+a,transform:\"translate(\"+l+\",\"+l+\")\",fill:n.bgcolor,stroke:n.bordercolor,\"stroke-width\":c})}function v(t,e,r,n){var i=e._fullLayout;o.ensureSingleById(i._topdefs,\"clipPath\",n._clipId,function(t){t.append(\"rect\").attr({x:0,y:0})}).select(\"rect\").attr({width:n._width,height:n._height})}function m(t,e,r,i){var l,c=e.calcdata,f=t.selectAll(\"g.\"+d.rangePlotClassName).data(r._subplotsWith,o.identity);f.enter().append(\"g\").attr(\"class\",function(t){return d.rangePlotClassName+\" \"+t}).call(s.setClipUrl,i._clipId,e),f.order(),f.exit().remove(),f.each(function(t,o){var s=n.select(this),f=0===o,p=h.getFromId(e,t,\"y\"),d=p._name,g=i[d],v={data:[],layout:{xaxis:{type:r.type,domain:[0,1],range:i.range.slice(),calendar:r.calendar},width:i._width,height:i._height,margin:{t:0,b:0,l:0,r:0}},_context:e._context};v.layout[d]={type:p.type,domain:[0,1],range:\"match\"!==g.rangemode?g.range.slice():p.range.slice(),calendar:p.calendar},a.supplyDefaults(v);var m=v._fullLayout.xaxis,y=v._fullLayout[d];m.clearCalc(),m.setScale(),y.clearCalc(),y.setScale();var x={id:t,plotgroup:s,xaxis:m,yaxis:y,isRangePlot:!0};f?l=x:(x.mainplot=\"xy\",x.mainplotinfo=l),u.rangePlot(e,x,function(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n],a=i[0].trace;a.xaxis+a.yaxis===e&&r.push(i)}return r}(c,t))})}function y(t,e,r,n,i){(o.ensureSingle(t,\"rect\",d.maskMinClassName,function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"height\",n._height).call(l.fill,d.maskColor),o.ensureSingle(t,\"rect\",d.maskMaxClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"height\",n._height).call(l.fill,d.maskColor),\"match\"!==i.rangemode)&&(o.ensureSingle(t,\"rect\",d.maskMinOppAxisClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"width\",n._width).call(l.fill,d.maskOppAxisColor),o.ensureSingle(t,\"rect\",d.maskMaxOppAxisClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"width\",n._width).style(\"border-top\",d.maskOppBorder).call(l.fill,d.maskOppAxisColor))}function x(t,e,r,n){e._context.staticPlot||o.ensureSingle(t,\"rect\",d.slideBoxClassName,function(t){t.attr({y:0,cursor:d.slideBoxCursor,\"shape-rendering\":\"crispEdges\"})}).attr({height:n._height,fill:d.slideBoxFill})}function b(t,e,r,n){var i=o.ensureSingle(t,\"g\",d.grabberMinClassName),a=o.ensureSingle(t,\"g\",d.grabberMaxClassName),s={x:0,width:d.handleWidth,rx:d.handleRadius,fill:l.background,stroke:l.defaultLine,\"stroke-width\":d.handleStrokeWidth,\"shape-rendering\":\"crispEdges\"},c={y:Math.round(n._height/4),height:Math.round(n._height/2)};if(o.ensureSingle(i,\"rect\",d.handleMinClassName,function(t){t.attr(s)}).attr(c),o.ensureSingle(a,\"rect\",d.handleMaxClassName,function(t){t.attr(s)}).attr(c),!e._context.staticPlot){var u={width:d.grabAreaWidth,x:0,y:0,fill:d.grabAreaFill,cursor:d.grabAreaCursor};o.ensureSingle(i,\"rect\",d.grabAreaMinClassName,function(t){t.attr(u)}).attr(\"height\",n._height),o.ensureSingle(a,\"rect\",d.grabAreaMaxClassName,function(t){t.attr(u)}).attr(\"height\",n._height)}}e.exports=function(t){for(var e=t._fullLayout,r=e._rangeSliderData,a=0;a<r.length;a++){var s=r[a][d.name];s._clipId=s._id+\"-\"+e._uid}var l=e._infolayer.selectAll(\"g.\"+d.containerClassName).data(r,function(t){return t._name});l.exit().each(function(t){var r=t[d.name];e._topdefs.select(\"#\"+r._clipId).remove()}).remove(),0!==r.length&&(l.enter().append(\"g\").classed(d.containerClassName,!0).attr(\"pointer-events\",\"all\"),l.each(function(r){var a=n.select(this),s=r[d.name],l=e[h.id2name(r.anchor)],u=s[h.id2name(r.anchor)];if(s.range){var _,w=o.simpleMap(s.range,r.r2l),k=o.simpleMap(r.range,r.r2l);_=k[0]<k[1]?[Math.min(w[0],k[0]),Math.max(w[1],k[1])]:[Math.max(w[0],k[0]),Math.min(w[1],k[1])],s.range=s._input.range=o.simpleMap(_,r.l2r)}r.cleanRange(\"rangeslider.range\");var T=e.margin,A=e._size,M=r.domain,S=s._tickHeight,E=s._oppBottom;s._width=A.w*(M[1]-M[0]);var C=Math.round(T.l+A.w*M[0]),L=Math.round(A.t+A.h*(1-E)+S+s._offsetShift+d.extraPad);a.attr(\"transform\",\"translate(\"+C+\",\"+L+\")\");var P=r.r2l(s.range[0]),O=r.r2l(s.range[1]),z=O-P;if(s.p2d=function(t){return t/s._width*z+P},s.d2p=function(t){return(t-P)/z*s._width},s._rl=[P,O],\"match\"!==u.rangemode){var I=l.r2l(u.range[0]),D=l.r2l(u.range[1])-I;s.d2pOppAxis=function(t){return(t-I)/D*s._height}}a.call(g,t,r,s).call(v,t,r,s).call(m,t,r,s).call(y,t,r,s,u).call(x,t,r,s).call(b,t,r,s),function(t,e,r,a){var s=t.select(\"rect.\"+d.slideBoxClassName).node(),l=t.select(\"rect.\"+d.grabAreaMinClassName).node(),c=t.select(\"rect.\"+d.grabAreaMaxClassName).node();t.on(\"mousedown\",function(){var u=n.event,h=u.target,d=u.clientX,g=d-t.node().getBoundingClientRect().left,v=a.d2p(r._rl[0]),m=a.d2p(r._rl[1]),y=f.coverSlip();function x(t){var u,f,x,b=+t.clientX-d;switch(h){case s:x=\"ew-resize\",u=v+b,f=m+b;break;case l:x=\"col-resize\",u=v+b,f=m;break;case c:x=\"col-resize\",u=v,f=m+b;break;default:x=\"ew-resize\",u=g,f=g+b}if(f<u){var _=f;f=u,u=_}a._pixelMin=u,a._pixelMax=f,p(n.select(y),x),function(t,e,r,n){function a(t){return r.l2r(o.constrain(t,n._rl[0],n._rl[1]))}var s=a(n.p2d(n._pixelMin)),l=a(n.p2d(n._pixelMax));window.requestAnimationFrame(function(){i.call(\"_guiRelayout\",e,r._name+\".range\",[s,l])})}(0,e,r,a)}y.addEventListener(\"mousemove\",x),y.addEventListener(\"mouseup\",function t(){y.removeEventListener(\"mousemove\",x);y.removeEventListener(\"mouseup\",t);o.removeElement(y)})})}(a,t,r,s),function(t,e,r,n,i,a){var s=d.handleWidth/2;function l(t){return o.constrain(t,0,n._width)}function c(t){return o.constrain(t,0,n._height)}function u(t){return o.constrain(t,-s,n._width+s)}var h=l(n.d2p(r._rl[0])),f=l(n.d2p(r._rl[1]));if(t.select(\"rect.\"+d.slideBoxClassName).attr(\"x\",h).attr(\"width\",f-h),t.select(\"rect.\"+d.maskMinClassName).attr(\"width\",h),t.select(\"rect.\"+d.maskMaxClassName).attr(\"x\",f).attr(\"width\",n._width-f),\"match\"!==a.rangemode){var p=n._height-c(n.d2pOppAxis(i._rl[1])),g=n._height-c(n.d2pOppAxis(i._rl[0]));t.select(\"rect.\"+d.maskMinOppAxisClassName).attr(\"x\",h).attr(\"height\",p).attr(\"width\",f-h),t.select(\"rect.\"+d.maskMaxOppAxisClassName).attr(\"x\",h).attr(\"y\",g).attr(\"height\",n._height-g).attr(\"width\",f-h),t.select(\"rect.\"+d.slideBoxClassName).attr(\"y\",p).attr(\"height\",g-p)}var v=Math.round(u(h-s))-.5,m=Math.round(u(f-s))+.5;t.select(\"g.\"+d.grabberMinClassName).attr(\"transform\",\"translate(\"+v+\",0.5)\"),t.select(\"g.\"+d.grabberMaxClassName).attr(\"transform\",\"translate(\"+m+\",0.5)\")}(a,0,r,s,l,u),\"bottom\"===r.side&&c.draw(t,r._id+\"title\",{propContainer:r,propName:r._name+\".title\",placeholder:e._dfltTitle.x,attributes:{x:r._offset+r._length/2,y:L+s._height+s._offsetShift+10+1.5*r.title.font.size,\"text-anchor\":\"middle\"}})}))}},{\"../../lib\":719,\"../../lib/setcursor\":739,\"../../plots/cartesian\":778,\"../../plots/cartesian/axis_ids\":770,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"../titles\":681,\"./constants\":663,d3:163}],666:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"./constants\"),a=i.name;function o(t){var e=t&&t[a];return e&&e.visible}r.isVisible=o,r.makeData=function(t){var e=n.list({_fullLayout:t},\"x\",!0),r=t.margin,i=[];if(!t._has(\"gl2d\"))for(var s=0;s<e.length;s++){var l=e[s];if(o(l)){i.push(l);var c=l[a];c._id=a+l._id,c._height=(t.height-r.b-r.t)*c.thickness,c._offsetShift=Math.floor(c.borderwidth/2)}}t._rangeSliderData=i},r.autoMarginOpts=function(t,e){for(var r=e[a],o=1/0,s=e._counterAxes,l=0;l<s.length;l++){var c=s[l],u=n.getFromId(t,c);o=Math.min(o,u.domain[0])}r._oppBottom=o;var h=\"bottom\"===e.side&&e._boundingBox.height||0;return r._tickHeight=h,{x:0,y:o,l:0,r:0,t:0,b:r._height+t._fullLayout.margin.b+h,pad:i.extraPad+2*r._offsetShift}}},{\"../../plots/cartesian/axis_ids\":770,\"./constants\":663}],667:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./oppaxis_attributes\"),o=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"rangeslider\",schema:{subplots:{xaxis:{rangeslider:n.extendFlat({},i,{yaxis:a})}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),calcAutorange:t(\"./calc_autorange\"),draw:t(\"./draw\"),isVisible:o.isVisible,makeData:o.makeData,autoMarginOpts:o.autoMarginOpts}},{\"../../lib\":719,\"./attributes\":661,\"./calc_autorange\":662,\"./defaults\":664,\"./draw\":665,\"./helpers\":666,\"./oppaxis_attributes\":668}],668:[function(t,e,r){\"use strict\";e.exports={_isSubplotObj:!0,rangemode:{valType:\"enumerated\",values:[\"auto\",\"fixed\",\"match\"],dflt:\"match\",editType:\"calc\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"plot\"},{valType:\"any\",editType:\"plot\"}],editType:\"plot\"},editType:\"calc\"}},{}],669:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../traces/scatter/attributes\").line,a=t(\"../drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray;e.exports=s(\"shape\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},type:{valType:\"enumerated\",values:[\"circle\",\"rect\",\"path\",\"line\"],editType:\"calc+arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},xref:o({},n.xref,{}),xsizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},xanchor:{valType:\"any\",editType:\"calc+arraydraw\"},x0:{valType:\"any\",editType:\"calc+arraydraw\"},x1:{valType:\"any\",editType:\"calc+arraydraw\"},yref:o({},n.yref,{}),ysizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},yanchor:{valType:\"any\",editType:\"calc+arraydraw\"},y0:{valType:\"any\",editType:\"calc+arraydraw\"},y1:{valType:\"any\",editType:\"calc+arraydraw\"},path:{valType:\"string\",editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},line:{color:o({},i.color,{editType:\"arraydraw\"}),width:o({},i.width,{editType:\"calc+arraydraw\"}),dash:o({},a,{editType:\"arraydraw\"}),editType:\"calc+arraydraw\"},fillcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},editType:\"arraydraw\"})},{\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../../traces/scatter/attributes\":1112,\"../annotations/attributes\":576,\"../drawing/attributes\":613}],670:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./constants\"),o=t(\"./helpers\");function s(t){return c(t.line.width,t.xsizemode,t.x0,t.x1,t.path,!1)}function l(t){return c(t.line.width,t.ysizemode,t.y0,t.y1,t.path,!0)}function c(t,e,r,i,s,l){var c=t/2,u=l;if(\"pixel\"===e){var h=s?o.extractPathCoords(s,l?a.paramIsY:a.paramIsX):[r,i],f=n.aggNums(Math.max,null,h),p=n.aggNums(Math.min,null,h),d=p<0?Math.abs(p)+c:c,g=f>0?f+c:c;return{ppad:c,ppadplus:u?d:g,ppadminus:u?g:d}}return{ppad:c}}function u(t,e,r,n,i){var s=\"category\"===t.type||\"multicategory\"===t.type?t.r2c:t.d2c;if(void 0!==e)return[s(e),s(r)];if(n){var l,c,u,h,f=1/0,p=-1/0,d=n.match(a.segmentRE);for(\"date\"===t.type&&(s=o.decodeDate(s)),l=0;l<d.length;l++)void 0!==(c=i[d[l].charAt(0)].drawn)&&(!(u=d[l].substr(1).match(a.paramRE))||u.length<c||((h=s(u[c]))<f&&(f=h),h>p&&(p=h)));return p>=f?[f,p]:void 0}}e.exports=function(t){var e=t._fullLayout,r=n.filterVisible(e.shapes);if(r.length&&t._fullData.length)for(var o=0;o<r.length;o++){var c,h,f=r[o];if(f._extremes={},\"paper\"!==f.xref){var p=\"pixel\"===f.xsizemode?f.xanchor:f.x0,d=\"pixel\"===f.xsizemode?f.xanchor:f.x1;(h=u(c=i.getFromId(t,f.xref),p,d,f.path,a.paramIsX))&&(f._extremes[c._id]=i.findExtremes(c,h,s(f)))}if(\"paper\"!==f.yref){var g=\"pixel\"===f.ysizemode?f.yanchor:f.y0,v=\"pixel\"===f.ysizemode?f.yanchor:f.y1;(h=u(c=i.getFromId(t,f.yref),g,v,f.path,a.paramIsY))&&(f._extremes[c._id]=i.findExtremes(c,h,l(f)))}}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./constants\":671,\"./helpers\":674}],671:[function(t,e,r){\"use strict\";e.exports={segmentRE:/[MLHVQCTSZ][^MLHVQCTSZ]*/g,paramRE:/[^\\s,]+/g,paramIsX:{M:{0:!0,drawn:0},L:{0:!0,drawn:0},H:{0:!0,drawn:0},V:{},Q:{0:!0,2:!0,drawn:2},C:{0:!0,2:!0,4:!0,drawn:4},T:{0:!0,drawn:0},S:{0:!0,2:!0,drawn:2},Z:{}},paramIsY:{M:{1:!0,drawn:1},L:{1:!0,drawn:1},H:{},V:{0:!0,drawn:0},Q:{1:!0,3:!0,drawn:3},C:{1:!0,3:!0,5:!0,drawn:5},T:{1:!0,drawn:1},S:{1:!0,3:!0,drawn:5},Z:{}},numParams:{M:2,L:2,H:1,V:1,Q:4,C:6,T:2,S:4,Z:0}}},{}],672:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\"),s=t(\"./helpers\");function l(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}if(a(\"visible\")){a(\"layer\"),a(\"opacity\"),a(\"fillcolor\"),a(\"line.color\"),a(\"line.width\"),a(\"line.dash\");for(var l=a(\"type\",t.path?\"path\":\"rect\"),c=a(\"xsizemode\"),u=a(\"ysizemode\"),h=[\"x\",\"y\"],f=0;f<2;f++){var p,d,g,v=h[f],m=v+\"anchor\",y=\"x\"===v?c:u,x={_fullLayout:r},b=i.coerceRef(t,e,x,v,\"\",\"paper\");if(\"paper\"!==b?((p=i.getFromId(x,b))._shapeIndices.push(e._index),g=s.rangeToShapePosition(p),d=s.shapePositionToRange(p)):d=g=n.identity,\"path\"!==l){var _=v+\"0\",w=v+\"1\",k=t[_],T=t[w];t[_]=d(t[_],!0),t[w]=d(t[w],!0),\"pixel\"===y?(a(_,0),a(w,10)):(i.coercePosition(e,x,a,b,_,.25),i.coercePosition(e,x,a,b,w,.75)),e[_]=g(e[_]),e[w]=g(e[w]),t[_]=k,t[w]=T}if(\"pixel\"===y){var A=t[m];t[m]=d(t[m],!0),i.coercePosition(e,x,a,b,m,.25),e[m]=g(e[m]),t[m]=A}}\"path\"===l?a(\"path\"):n.noneOrAll(t,e,[\"x0\",\"x1\",\"y0\",\"y1\"])}}e.exports=function(t,e){a(t,e,{name:\"shapes\",handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"./attributes\":669,\"./helpers\":674}],673:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../color\"),s=t(\"../drawing\"),l=t(\"../../plot_api/plot_template\").arrayEditor,c=t(\"../dragelement\"),u=t(\"../../lib/setcursor\"),h=t(\"./constants\"),f=t(\"./helpers\");function p(t,e){t._fullLayout._paperdiv.selectAll('.shapelayer [data-index=\"'+e+'\"]').remove();var r=t._fullLayout.shapes[e]||{};if(r._input&&!1!==r.visible)if(\"below\"!==r.layer)m(t._fullLayout._shapeUpperLayer);else if(\"paper\"===r.xref||\"paper\"===r.yref)m(t._fullLayout._shapeLowerLayer);else{var p=t._fullLayout._plots[r.xref+r.yref];if(p)m((p.mainplotinfo||p).shapelayer);else m(t._fullLayout._shapeLowerLayer)}function m(p){var m={\"data-index\":e,\"fill-rule\":\"evenodd\",d:g(t,r)},y=r.line.width?r.line.color:\"rgba(0,0,0,0)\",x=p.append(\"path\").attr(m).style(\"opacity\",r.opacity).call(o.stroke,y).call(o.fill,r.fillcolor).call(s.dashLine,r.line.dash,r.line.width);d(x,t,r),t._context.edits.shapePosition&&function(t,e,r,o,p){var m,y,x,b,_,w,k,T,A,M,S,E,C,L,P,O,z=10,I=10,D=\"pixel\"===r.xsizemode,R=\"pixel\"===r.ysizemode,F=\"line\"===r.type,B=\"path\"===r.type,N=l(t.layout,\"shapes\",r),j=N.modifyItem,U=a.getFromId(t,r.xref),V=a.getFromId(t,r.yref),q=f.getDataToPixel(t,U),H=f.getDataToPixel(t,V,!0),G=f.getPixelToData(t,U),Y=f.getPixelToData(t,V,!0),W=F?function(){var t=Math.max(r.line.width,10),n=p.append(\"g\").attr(\"data-index\",o);n.append(\"path\").attr(\"d\",e.attr(\"d\")).style({cursor:\"move\",\"stroke-width\":t,\"stroke-opacity\":\"0\"});var i={\"fill-opacity\":\"0\"},a=t/2>10?t/2:10;return n.append(\"circle\").attr({\"data-line-point\":\"start-point\",cx:D?q(r.xanchor)+r.x0:q(r.x0),cy:R?H(r.yanchor)-r.y0:H(r.y0),r:a}).style(i).classed(\"cursor-grab\",!0),n.append(\"circle\").attr({\"data-line-point\":\"end-point\",cx:D?q(r.xanchor)+r.x1:q(r.x1),cy:R?H(r.yanchor)-r.y1:H(r.y1),r:a}).style(i).classed(\"cursor-grab\",!0),n}():e,X={element:W.node(),gd:t,prepFn:function(n){D&&(_=q(r.xanchor));R&&(w=H(r.yanchor));\"path\"===r.type?P=r.path:(m=D?r.x0:q(r.x0),y=R?r.y0:H(r.y0),x=D?r.x1:q(r.x1),b=R?r.y1:H(r.y1));m<x?(A=m,C=\"x0\",M=x,L=\"x1\"):(A=x,C=\"x1\",M=m,L=\"x0\");!R&&y<b||R&&y>b?(k=y,S=\"y0\",T=b,E=\"y1\"):(k=b,S=\"y1\",T=y,E=\"y0\");Z(n),$(p,r),function(t,e,r){var n=e.xref,i=e.yref,o=a.getFromId(r,n),l=a.getFromId(r,i),c=\"\";\"paper\"===n||o.autorange||(c+=n);\"paper\"===i||l.autorange||(c+=i);s.setClipUrl(t,c?\"clip\"+r._fullLayout._uid+c:null,r)}(e,r,t),X.moveFn=\"move\"===O?J:K},doneFn:function(){u(e),Q(p),d(e,t,r),n.call(\"_guiRelayout\",t,N.getUpdateObj())},clickFn:function(){Q(p)}};function Z(t){if(F)O=\"path\"===t.target.tagName?\"move\":\"start-point\"===t.target.attributes[\"data-line-point\"].value?\"resize-over-start-point\":\"resize-over-end-point\";else{var r=X.element.getBoundingClientRect(),n=r.right-r.left,i=r.bottom-r.top,a=t.clientX-r.left,o=t.clientY-r.top,s=!B&&n>z&&i>I&&!t.shiftKey?c.getCursor(a/n,1-o/i):\"move\";u(e,s),O=s.split(\"-\")[0]}}function J(n,i){if(\"path\"===r.type){var a=function(t){return t},o=a,s=a;D?j(\"xanchor\",r.xanchor=G(_+n)):(o=function(t){return G(q(t)+n)},U&&\"date\"===U.type&&(o=f.encodeDate(o))),R?j(\"yanchor\",r.yanchor=Y(w+i)):(s=function(t){return Y(H(t)+i)},V&&\"date\"===V.type&&(s=f.encodeDate(s))),j(\"path\",r.path=v(P,o,s))}else D?j(\"xanchor\",r.xanchor=G(_+n)):(j(\"x0\",r.x0=G(m+n)),j(\"x1\",r.x1=G(x+n))),R?j(\"yanchor\",r.yanchor=Y(w+i)):(j(\"y0\",r.y0=Y(y+i)),j(\"y1\",r.y1=Y(b+i)));e.attr(\"d\",g(t,r)),$(p,r)}function K(n,i){if(B){var a=function(t){return t},o=a,s=a;D?j(\"xanchor\",r.xanchor=G(_+n)):(o=function(t){return G(q(t)+n)},U&&\"date\"===U.type&&(o=f.encodeDate(o))),R?j(\"yanchor\",r.yanchor=Y(w+i)):(s=function(t){return Y(H(t)+i)},V&&\"date\"===V.type&&(s=f.encodeDate(s))),j(\"path\",r.path=v(P,o,s))}else if(F){if(\"resize-over-start-point\"===O){var l=m+n,c=R?y-i:y+i;j(\"x0\",r.x0=D?l:G(l)),j(\"y0\",r.y0=R?c:Y(c))}else if(\"resize-over-end-point\"===O){var u=x+n,h=R?b-i:b+i;j(\"x1\",r.x1=D?u:G(u)),j(\"y1\",r.y1=R?h:Y(h))}}else{var d=~O.indexOf(\"n\")?k+i:k,N=~O.indexOf(\"s\")?T+i:T,W=~O.indexOf(\"w\")?A+n:A,X=~O.indexOf(\"e\")?M+n:M;~O.indexOf(\"n\")&&R&&(d=k-i),~O.indexOf(\"s\")&&R&&(N=T-i),(!R&&N-d>I||R&&d-N>I)&&(j(S,r[S]=R?d:Y(d)),j(E,r[E]=R?N:Y(N))),X-W>z&&(j(C,r[C]=D?W:G(W)),j(L,r[L]=D?X:G(X)))}e.attr(\"d\",g(t,r)),$(p,r)}function $(t,e){(D||R)&&function(){var r=\"path\"!==e.type,n=t.selectAll(\".visual-cue\").data([0]);n.enter().append(\"path\").attr({fill:\"#fff\",\"fill-rule\":\"evenodd\",stroke:\"#000\",\"stroke-width\":1}).classed(\"visual-cue\",!0);var a=q(D?e.xanchor:i.midRange(r?[e.x0,e.x1]:f.extractPathCoords(e.path,h.paramIsX))),o=H(R?e.yanchor:i.midRange(r?[e.y0,e.y1]:f.extractPathCoords(e.path,h.paramIsY)));if(a=f.roundPositionForSharpStrokeRendering(a,1),o=f.roundPositionForSharpStrokeRendering(o,1),D&&R){var s=\"M\"+(a-1-1)+\",\"+(o-1-1)+\"h-8v2h8 v8h2v-8 h8v-2h-8 v-8h-2 Z\";n.attr(\"d\",s)}else if(D){var l=\"M\"+(a-1-1)+\",\"+(o-9-1)+\"v18 h2 v-18 Z\";n.attr(\"d\",l)}else{var c=\"M\"+(a-9-1)+\",\"+(o-1-1)+\"h18 v2 h-18 Z\";n.attr(\"d\",c)}}()}function Q(t){t.selectAll(\".visual-cue\").remove()}c.init(X),W.node().onmousemove=Z}(t,x,r,e,p)}}function d(t,e,r){var n=(r.xref+r.yref).replace(/paper/g,\"\");s.setClipUrl(t,n?\"clip\"+e._fullLayout._uid+n:null,e)}function g(t,e){var r,n,o,s,l,c,u,p,d=e.type,g=a.getFromId(t,e.xref),v=a.getFromId(t,e.yref),m=t._fullLayout._size;if(g?(r=f.shapePositionToRange(g),n=function(t){return g._offset+g.r2p(r(t,!0))}):n=function(t){return m.l+m.w*t},v?(o=f.shapePositionToRange(v),s=function(t){return v._offset+v.r2p(o(t,!0))}):s=function(t){return m.t+m.h*(1-t)},\"path\"===d)return g&&\"date\"===g.type&&(n=f.decodeDate(n)),v&&\"date\"===v.type&&(s=f.decodeDate(s)),function(t,e,r){var n=t.path,a=t.xsizemode,o=t.ysizemode,s=t.xanchor,l=t.yanchor;return n.replace(h.segmentRE,function(t){var n=0,c=t.charAt(0),u=h.paramIsX[c],f=h.paramIsY[c],p=h.numParams[c],d=t.substr(1).replace(h.paramRE,function(t){return u[n]?t=\"pixel\"===a?e(s)+Number(t):e(t):f[n]&&(t=\"pixel\"===o?r(l)-Number(t):r(t)),++n>p&&(t=\"X\"),t});return n>p&&(d=d.replace(/[\\s,]*X.*/,\"\"),i.log(\"Ignoring extra params in segment \"+t)),c+d})}(e,n,s);if(\"pixel\"===e.xsizemode){var y=n(e.xanchor);l=y+e.x0,c=y+e.x1}else l=n(e.x0),c=n(e.x1);if(\"pixel\"===e.ysizemode){var x=s(e.yanchor);u=x-e.y0,p=x-e.y1}else u=s(e.y0),p=s(e.y1);if(\"line\"===d)return\"M\"+l+\",\"+u+\"L\"+c+\",\"+p;if(\"rect\"===d)return\"M\"+l+\",\"+u+\"H\"+c+\"V\"+p+\"H\"+l+\"Z\";var b=(l+c)/2,_=(u+p)/2,w=Math.abs(b-l),k=Math.abs(_-u),T=\"A\"+w+\",\"+k,A=b+w+\",\"+_;return\"M\"+A+T+\" 0 1,1 \"+(b+\",\"+(_-k))+T+\" 0 0,1 \"+A+\"Z\"}function v(t,e,r){return t.replace(h.segmentRE,function(t){var n=0,i=t.charAt(0),a=h.paramIsX[i],o=h.paramIsY[i],s=h.numParams[i];return i+t.substr(1).replace(h.paramRE,function(t){return n>=s?t:(a[n]?t=e(t):o[n]&&(t=r(t)),n++,t)})})}e.exports={draw:function(t){var e=t._fullLayout;for(var r in e._shapeUpperLayer.selectAll(\"path\").remove(),e._shapeLowerLayer.selectAll(\"path\").remove(),e._plots){var n=e._plots[r].shapelayer;n&&n.selectAll(\"path\").remove()}for(var i=0;i<e.shapes.length;i++)e.shapes[i].visible&&p(t,i)},drawOne:p}},{\"../../lib\":719,\"../../lib/setcursor\":739,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"./constants\":671,\"./helpers\":674}],674:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib\");r.rangeToShapePosition=function(t){return\"log\"===t.type?t.r2d:function(t){return t}},r.shapePositionToRange=function(t){return\"log\"===t.type?t.d2r:function(t){return t}},r.decodeDate=function(t){return function(e){return e.replace&&(e=e.replace(\"_\",\" \")),t(e)}},r.encodeDate=function(t){return function(e){return t(e).replace(\" \",\"_\")}},r.extractPathCoords=function(t,e){var r=[];return t.match(n.segmentRE).forEach(function(t){var a=e[t.charAt(0)].drawn;if(void 0!==a){var o=t.substr(1).match(n.paramRE);!o||o.length<a||r.push(i.cleanNumber(o[a]))}}),r},r.getDataToPixel=function(t,e,n){var i,a=t._fullLayout._size;if(e){var o=r.shapePositionToRange(e);i=function(t){return e._offset+e.r2p(o(t,!0))},\"date\"===e.type&&(i=r.decodeDate(i))}else i=n?function(t){return a.t+a.h*(1-t)}:function(t){return a.l+a.w*t};return i},r.getPixelToData=function(t,e,n){var i,a=t._fullLayout._size;if(e){var o=r.rangeToShapePosition(e);i=function(t){return o(e.p2r(t-e._offset))}}else i=n?function(t){return 1-(t-a.t)/a.h}:function(t){return(t-a.l)/a.w};return i},r.roundPositionForSharpStrokeRendering=function(t,e){var r=1===Math.round(e%2),n=Math.round(t);return r?n+.5:n}},{\"../../lib\":719,\"./constants\":671}],675:[function(t,e,r){\"use strict\";var n=t(\"./draw\");e.exports={moduleType:\"component\",name:\"shapes\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"shapes\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne}},{\"../../plots/cartesian/include_components\":777,\"./attributes\":669,\"./calc_autorange\":670,\"./defaults\":672,\"./draw\":673}],676:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/pad_attributes\"),a=t(\"../../lib/extend\").extendDeepAll,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/animation_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"./constants\"),u=l(\"step\",{visible:{valType:\"boolean\",dflt:!0},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\"},value:{valType:\"string\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"slider\",{visible:{valType:\"boolean\",dflt:!0},active:{valType:\"number\",min:0,dflt:0},steps:u,lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",min:-2,max:3,dflt:0},pad:a(i({editType:\"arraydraw\"}),{},{t:{dflt:20}}),xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\"},y:{valType:\"number\",min:-2,max:3,dflt:0},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},transition:{duration:{valType:\"number\",min:0,dflt:150},easing:{valType:\"enumerated\",values:s.transition.easing.values,dflt:\"cubic-in-out\"}},currentvalue:{visible:{valType:\"boolean\",dflt:!0},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},offset:{valType:\"number\",dflt:10},prefix:{valType:\"string\"},suffix:{valType:\"string\"},font:n({})},font:n({}),activebgcolor:{valType:\"color\",dflt:c.gripBgActiveColor},bgcolor:{valType:\"color\",dflt:c.railBgColor},bordercolor:{valType:\"color\",dflt:c.railBorderColor},borderwidth:{valType:\"number\",min:0,dflt:c.railBorderWidth},ticklen:{valType:\"number\",min:0,dflt:c.tickLength},tickcolor:{valType:\"color\",dflt:c.tickColor},tickwidth:{valType:\"number\",min:0,dflt:1},minorticklen:{valType:\"number\",min:0,dflt:c.minorTickLength}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/animation_attributes\":762,\"../../plots/font_attributes\":793,\"../../plots/pad_attributes\":827,\"./constants\":677}],677:[function(t,e,r){\"use strict\";e.exports={name:\"sliders\",containerClassName:\"slider-container\",groupClassName:\"slider-group\",inputAreaClass:\"slider-input-area\",railRectClass:\"slider-rail-rect\",railTouchRectClass:\"slider-rail-touch-rect\",gripRectClass:\"slider-grip-rect\",tickRectClass:\"slider-tick-rect\",inputProxyClass:\"slider-input-proxy\",labelsClass:\"slider-labels\",labelGroupClass:\"slider-label-group\",labelClass:\"slider-label\",currentValueClass:\"slider-current-value\",railHeight:5,menuIndexAttrName:\"slider-active-index\",autoMarginIdRoot:\"slider-\",minWidth:30,minHeight:30,textPadX:40,arrowOffsetX:4,railRadius:2,railWidth:5,railBorder:4,railBorderWidth:1,railBorderColor:\"#bec8d9\",railBgColor:\"#f8fafc\",railInset:8,stepInset:10,gripRadius:10,gripWidth:20,gripHeight:20,gripBorder:20,gripBorderWidth:1,gripBorderColor:\"#bec8d9\",gripBgColor:\"#f6f8fa\",gripBgActiveColor:\"#dbdde0\",labelPadding:8,labelOffset:0,tickWidth:1,tickColor:\"#333\",tickOffset:25,tickLength:7,minorTickOffset:25,minorTickColor:\"#333\",minorTickLength:4,currentValuePadding:8,currentValueInset:0}},{}],678:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.steps;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}for(var s=i(t,e,{name:\"steps\",handleItemDefaults:c}),l=0,u=0;u<s.length;u++)s[u].visible&&l++;if(l<2?e.visible=!1:o(\"visible\")){e._stepCount=l;var h=e._visibleSteps=n.filterVisible(s);(s[o(\"active\")]||{}).visible||(e.active=h[0]._index),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"len\"),o(\"lenmode\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"currentvalue.visible\")&&(o(\"currentvalue.xanchor\"),o(\"currentvalue.prefix\"),o(\"currentvalue.suffix\"),o(\"currentvalue.offset\"),n.coerceFont(o,\"currentvalue.font\",e.font)),o(\"transition.duration\"),o(\"transition.easing\"),o(\"bgcolor\"),o(\"activebgcolor\"),o(\"bordercolor\"),o(\"borderwidth\"),o(\"ticklen\"),o(\"tickwidth\"),o(\"tickcolor\"),o(\"minorticklen\")}}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}if(\"skip\"===t.method||Array.isArray(t.args)?r(\"visible\"):e.visible=!1){r(\"method\"),r(\"args\");var i=r(\"label\",\"step-\"+e._index);r(\"value\",i),r(\"execute\")}}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"./attributes\":676,\"./constants\":677}],679:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"./constants\"),h=t(\"../../constants/alignment\"),f=h.LINE_SPACING,p=h.FROM_TL,d=h.FROM_BR;function g(t){return u.autoMarginIdRoot+t._index}function v(t){return t._index}function m(t,e){var r=o.tester.selectAll(\"g.\"+u.labelGroupClass).data(e._visibleSteps);r.enter().append(\"g\").classed(u.labelGroupClass,!0);var a=0,c=0;r.each(function(t){var r=b(n.select(this),{step:t},e).node();if(r){var i=o.bBox(r);c=Math.max(c,i.height),a=Math.max(a,i.width)}}),r.remove();var h=e._dims={};h.inputAreaWidth=Math.max(u.railWidth,u.gripHeight);var f=t._fullLayout._size;h.lx=f.l+f.w*e.x,h.ly=f.t+f.h*(1-e.y),\"fraction\"===e.lenmode?h.outerLength=Math.round(f.w*e.len):h.outerLength=e.len,h.inputAreaStart=0,h.inputAreaLength=Math.round(h.outerLength-e.pad.l-e.pad.r);var v=(h.inputAreaLength-2*u.stepInset)/(e._stepCount-1),m=a+u.labelPadding;if(h.labelStride=Math.max(1,Math.ceil(m/v)),h.labelHeight=c,h.currentValueMaxWidth=0,h.currentValueHeight=0,h.currentValueTotalHeight=0,h.currentValueMaxLines=1,e.currentvalue.visible){var x=o.tester.append(\"g\");r.each(function(t){var r=y(x,e,t.label),n=r.node()&&o.bBox(r.node())||{width:0,height:0},i=l.lineCount(r);h.currentValueMaxWidth=Math.max(h.currentValueMaxWidth,Math.ceil(n.width)),h.currentValueHeight=Math.max(h.currentValueHeight,Math.ceil(n.height)),h.currentValueMaxLines=Math.max(h.currentValueMaxLines,i)}),h.currentValueTotalHeight=h.currentValueHeight+e.currentvalue.offset,x.remove()}h.height=h.currentValueTotalHeight+u.tickOffset+e.ticklen+u.labelOffset+h.labelHeight+e.pad.t+e.pad.b;var _=\"left\";s.isRightAnchor(e)&&(h.lx-=h.outerLength,_=\"right\"),s.isCenterAnchor(e)&&(h.lx-=h.outerLength/2,_=\"center\");var w=\"top\";s.isBottomAnchor(e)&&(h.ly-=h.height,w=\"bottom\"),s.isMiddleAnchor(e)&&(h.ly-=h.height/2,w=\"middle\"),h.outerLength=Math.ceil(h.outerLength),h.height=Math.ceil(h.height),h.lx=Math.round(h.lx),h.ly=Math.round(h.ly);var k={y:e.y,b:h.height*d[w],t:h.height*p[w]};\"fraction\"===e.lenmode?(k.l=0,k.xl=e.x-e.len*p[_],k.r=0,k.xr=e.x+e.len*d[_]):(k.x=e.x,k.l=h.outerLength*p[_],k.r=h.outerLength*d[_]),i.autoMargin(t,g(e),k)}function y(t,e,r){if(e.currentvalue.visible){var n,i,a=e._dims;switch(e.currentvalue.xanchor){case\"right\":n=a.inputAreaLength-u.currentValueInset-a.currentValueMaxWidth,i=\"left\";break;case\"center\":n=.5*a.inputAreaLength,i=\"middle\";break;default:n=u.currentValueInset,i=\"left\"}var c=s.ensureSingle(t,\"text\",u.labelClass,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":i,\"data-notex\":1})}),h=e.currentvalue.prefix?e.currentvalue.prefix:\"\";if(\"string\"==typeof r)h+=r;else{var p=e.steps[e.active].label,d=e._gd._fullLayout._meta;d&&(p=s.templateString(p,d)),h+=p}e.currentvalue.suffix&&(h+=e.currentvalue.suffix),c.call(o.font,e.currentvalue.font).text(h).call(l.convertToTspans,e._gd);var g=l.lineCount(c),v=(a.currentValueMaxLines+1-g)*e.currentvalue.font.size*f;return l.positionText(c,n,v),c}}function x(t,e,r){s.ensureSingle(t,\"rect\",u.gripRectClass,function(n){n.call(T,e,t,r).style(\"pointer-events\",\"all\")}).attr({width:u.gripWidth,height:u.gripHeight,rx:u.gripRadius,ry:u.gripRadius}).call(a.stroke,r.bordercolor).call(a.fill,r.bgcolor).style(\"stroke-width\",r.borderwidth+\"px\")}function b(t,e,r){var n=s.ensureSingle(t,\"text\",u.labelClass,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":\"middle\",\"data-notex\":1})}),i=e.step.label,a=r._gd._fullLayout._meta;return a&&(i=s.templateString(i,a)),n.call(o.font,r.font).text(i).call(l.convertToTspans,r._gd),n}function _(t,e){var r=s.ensureSingle(t,\"g\",u.labelsClass),i=e._dims,a=r.selectAll(\"g.\"+u.labelGroupClass).data(i.labelSteps);a.enter().append(\"g\").classed(u.labelGroupClass,!0),a.exit().remove(),a.each(function(t){var r=n.select(this);r.call(b,t,e),o.setTranslate(r,S(e,t.fraction),u.tickOffset+e.ticklen+e.font.size*f+u.labelOffset+i.currentValueTotalHeight)})}function w(t,e,r,n,i){var a=Math.round(n*(r._stepCount-1)),o=r._visibleSteps[a]._index;o!==r.active&&k(t,e,r,o,!0,i)}function k(t,e,r,n,a,o){var s=r.active;r.active=n,c(t.layout,u.name,r).applyUpdate(\"active\",n);var l=r.steps[r.active];e.call(M,r,o),e.call(y,r),t.emit(\"plotly_sliderchange\",{slider:r,step:r.steps[r.active],interaction:a,previousActive:s}),l&&l.method&&a&&(e._nextMethod?(e._nextMethod.step=l,e._nextMethod.doCallback=a,e._nextMethod.doTransition=o):(e._nextMethod={step:l,doCallback:a,doTransition:o},e._nextMethodRaf=window.requestAnimationFrame(function(){var r=e._nextMethod.step;r.method&&(r.execute&&i.executeAPICommand(t,r.method,r.args),e._nextMethod=null,e._nextMethodRaf=null)})))}function T(t,e,r){var i=r.node(),o=n.select(e);function s(){return r.data()[0]}t.on(\"mousedown\",function(){var t=s();e.emit(\"plotly_sliderstart\",{slider:t});var l=r.select(\".\"+u.gripRectClass);n.event.stopPropagation(),n.event.preventDefault(),l.call(a.fill,t.activebgcolor);var c=E(t,n.mouse(i)[0]);w(e,r,t,c,!0),t._dragging=!0,o.on(\"mousemove\",function(){var t=s(),a=E(t,n.mouse(i)[0]);w(e,r,t,a,!1)}),o.on(\"mouseup\",function(){var t=s();t._dragging=!1,l.call(a.fill,t.bgcolor),o.on(\"mouseup\",null),o.on(\"mousemove\",null),e.emit(\"plotly_sliderend\",{slider:t,step:t.steps[t.active]})})})}function A(t,e){var r=t.selectAll(\"rect.\"+u.tickRectClass).data(e._visibleSteps),i=e._dims;r.enter().append(\"rect\").classed(u.tickRectClass,!0),r.exit().remove(),r.attr({width:e.tickwidth+\"px\",\"shape-rendering\":\"crispEdges\"}),r.each(function(t,r){var s=r%i.labelStride==0,l=n.select(this);l.attr({height:s?e.ticklen:e.minorticklen}).call(a.fill,e.tickcolor),o.setTranslate(l,S(e,r/(e._stepCount-1))-.5*e.tickwidth,(s?u.tickOffset:u.minorTickOffset)+i.currentValueTotalHeight)})}function M(t,e,r){for(var n=t.select(\"rect.\"+u.gripRectClass),i=0,a=0;a<e._stepCount;a++)if(e._visibleSteps[a]._index===e.active){i=a;break}var o=S(e,i/(e._stepCount-1));if(!e._invokingCommand){var s=n;r&&e.transition.duration>0&&(s=s.transition().duration(e.transition.duration).ease(e.transition.easing)),s.attr(\"transform\",\"translate(\"+(o-.5*u.gripWidth)+\",\"+e._dims.currentValueTotalHeight+\")\")}}function S(t,e){var r=t._dims;return r.inputAreaStart+u.stepInset+(r.inputAreaLength-2*u.stepInset)*Math.min(1,Math.max(0,e))}function E(t,e){var r=t._dims;return Math.min(1,Math.max(0,(e-u.stepInset-r.inputAreaStart)/(r.inputAreaLength-2*u.stepInset-2*r.inputAreaStart)))}function C(t,e,r){var n=r._dims,i=s.ensureSingle(t,\"rect\",u.railTouchRectClass,function(n){n.call(T,e,t,r).style(\"pointer-events\",\"all\")});i.attr({width:n.inputAreaLength,height:Math.max(n.inputAreaWidth,u.tickOffset+r.ticklen+n.labelHeight)}).call(a.fill,r.bgcolor).attr(\"opacity\",0),o.setTranslate(i,0,n.currentValueTotalHeight)}function L(t,e){var r=e._dims,n=r.inputAreaLength-2*u.railInset,i=s.ensureSingle(t,\"rect\",u.railRectClass);i.attr({width:n,height:u.railWidth,rx:u.railRadius,ry:u.railRadius,\"shape-rendering\":\"crispEdges\"}).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\"),o.setTranslate(i,u.railInset,.5*(r.inputAreaWidth-u.railWidth)+r.currentValueTotalHeight)}e.exports=function(t){var e=t._fullLayout,r=function(t,e){for(var r=t[u.name],n=[],i=0;i<r.length;i++){var a=r[i];a.visible&&(a._gd=e,n.push(a))}return n}(e,t),a=e._infolayer.selectAll(\"g.\"+u.containerClassName).data(r.length>0?[0]:[]);function s(e){e._commandObserver&&(e._commandObserver.remove(),delete e._commandObserver),i.autoMargin(t,g(e))}if(a.enter().append(\"g\").classed(u.containerClassName,!0).style(\"cursor\",\"ew-resize\"),a.exit().each(function(){n.select(this).selectAll(\"g.\"+u.groupClassName).each(s)}).remove(),0!==r.length){var l=a.selectAll(\"g.\"+u.groupClassName).data(r,v);l.enter().append(\"g\").classed(u.groupClassName,!0),l.exit().each(s).remove();for(var c=0;c<r.length;c++){var h=r[c];m(t,h)}l.each(function(e){var r=n.select(this);!function(t){var e=t._dims;e.labelSteps=[];for(var r=t._stepCount,n=0;n<r;n+=e.labelStride)e.labelSteps.push({fraction:n/(r-1),step:t._visibleSteps[n]})}(e),i.manageCommandObserver(t,e,e._visibleSteps,function(e){var n=r.data()[0];n.active!==e.index&&(n._dragging||k(t,r,n,e.index,!1,!0))}),function(t,e,r){(r.steps[r.active]||{}).visible||(r.active=r._visibleSteps[0]._index);e.call(y,r).call(L,r).call(_,r).call(A,r).call(C,t,r).call(x,t,r);var n=r._dims;o.setTranslate(e,n.lx+r.pad.l,n.ly+r.pad.t),e.call(M,r,!1),e.call(y,r)}(t,n.select(this),e)})}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_template\":757,\"../../plots/plots\":828,\"../color\":593,\"../drawing\":614,\"./constants\":677,d3:163}],680:[function(t,e,r){\"use strict\";var n=t(\"./constants\");e.exports={moduleType:\"component\",name:n.name,layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":676,\"./constants\":677,\"./defaults\":678,\"./draw\":679}],681:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../drawing\"),c=t(\"../color\"),u=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/interactions\");e.exports={draw:function(t,e,r){var p,d=r.propContainer,g=r.propName,v=r.placeholder,m=r.traceIndex,y=r.avoid||{},x=r.attributes,b=r.transform,_=r.containerGroup,w=t._fullLayout,k=1,T=!1,A=d.title,M=(A&&A.text?A.text:\"\").trim(),S=A&&A.font?A.font:{},E=S.family,C=S.size,L=S.color;\"title.text\"===g?p=\"titleText\":-1!==g.indexOf(\"axis\")?p=\"axisTitleText\":g.indexOf(!0)&&(p=\"colorbarTitleText\");var P=t._context.edits[p];\"\"===M?k=0:M.replace(f,\" % \")===v.replace(f,\" % \")&&(k=.2,T=!0,P||(M=\"\"));r._meta?M=s.templateString(M,r._meta):w._meta&&(M=s.templateString(M,w._meta));var O=M||P;_||(_=s.ensureSingle(w._infolayer,\"g\",\"g-\"+e));var z=_.selectAll(\"text\").data(O?[0]:[]);if(z.enter().append(\"text\"),z.text(M).attr(\"class\",e),z.exit().remove(),!O)return _;function I(t){s.syncOrAsync([D,R],t)}function D(e){var r;return b?(r=\"\",b.rotate&&(r+=\"rotate(\"+[b.rotate,x.x,x.y]+\")\"),b.offset&&(r+=\"translate(0, \"+b.offset+\")\")):r=null,e.attr(\"transform\",r),e.style({\"font-family\":E,\"font-size\":n.round(C,2)+\"px\",fill:c.rgb(L),opacity:k*c.opacity(L),\"font-weight\":a.fontWeight}).attr(x).call(u.convertToTspans,t),a.previousPromises(t)}function R(t){var e=n.select(t.node().parentNode);if(y&&y.selection&&y.side&&M){e.attr(\"transform\",null);var r=0,a={left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}[y.side],o=-1!==[\"left\",\"top\"].indexOf(y.side)?-1:1,c=i(y.pad)?y.pad:2,u=l.bBox(e.node()),h={left:0,top:0,right:w.width,bottom:w.height},f=y.maxShift||(h[y.side]-u[y.side])*(\"left\"===y.side||\"top\"===y.side?-1:1);if(f<0)r=f;else{var p=y.offsetLeft||0,d=y.offsetTop||0;u.left-=p,u.right-=p,u.top-=d,u.bottom-=d,y.selection.each(function(){var t=l.bBox(this);s.bBoxIntersect(u,t,c)&&(r=Math.max(r,o*(t[y.side]-u[a])+c))}),r=Math.min(f,r)}if(r>0||f<0){var g={left:[-r,0],right:[r,0],top:[0,-r],bottom:[0,r]}[y.side];e.attr(\"transform\",\"translate(\"+g+\")\")}}}z.call(I),P&&(M?z.on(\".opacity\",null):(k=0,T=!0,z.text(v).on(\"mouseover.opacity\",function(){n.select(this).transition().duration(h.SHOW_PLACEHOLDER).style(\"opacity\",1)}).on(\"mouseout.opacity\",function(){n.select(this).transition().duration(h.HIDE_PLACEHOLDER).style(\"opacity\",0)})),z.call(u.makeEditable,{gd:t}).on(\"edit\",function(e){void 0!==m?o.call(\"_guiRestyle\",t,g,e,m):o.call(\"_guiRelayout\",t,g,e)}).on(\"cancel\",function(){this.text(this.attr(\"data-unformatted\")).call(I)}).on(\"input\",function(t){this.text(t||\" \").call(u.positionText,x.x,x.y)}));return z.classed(\"js-placeholder\",T),_}};var f=/ [XY][0-9]* /},{\"../../constants/interactions\":694,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../drawing\":614,d3:163,\"fast-isnumeric\":225}],682:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/pad_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=l(\"button\",{visible:{valType:\"boolean\"},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\",dflt:\"\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"updatemenu\",{_arrayAttrRegexps:[/^updatemenus\\[(0|[1-9][0-9]+)\\]\\.buttons/],visible:{valType:\"boolean\"},type:{valType:\"enumerated\",values:[\"dropdown\",\"buttons\"],dflt:\"dropdown\"},direction:{valType:\"enumerated\",values:[\"left\",\"right\",\"up\",\"down\"],dflt:\"down\"},active:{valType:\"integer\",min:-1,dflt:0},showactive:{valType:\"boolean\",dflt:!0},buttons:c,x:{valType:\"number\",min:-2,max:3,dflt:-.05},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"right\"},y:{valType:\"number\",min:-2,max:3,dflt:1},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},pad:a(s({editType:\"arraydraw\"}),{}),font:n({}),bgcolor:{valType:\"color\"},bordercolor:{valType:\"color\",dflt:i.borderLine},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"arraydraw\"}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/font_attributes\":793,\"../../plots/pad_attributes\":827,\"../color/attributes\":592}],683:[function(t,e,r){\"use strict\";e.exports={name:\"updatemenus\",containerClassName:\"updatemenu-container\",headerGroupClassName:\"updatemenu-header-group\",headerClassName:\"updatemenu-header\",headerArrowClassName:\"updatemenu-header-arrow\",dropdownButtonGroupClassName:\"updatemenu-dropdown-button-group\",dropdownButtonClassName:\"updatemenu-dropdown-button\",buttonClassName:\"updatemenu-button\",itemRectClassName:\"updatemenu-item-rect\",itemTextClassName:\"updatemenu-item-text\",menuIndexAttrName:\"updatemenu-active-index\",autoMarginIdRoot:\"updatemenu-\",blankHeaderOpts:{label:\"  \"},minWidth:30,minHeight:30,textPadX:24,arrowPadX:16,rx:2,ry:2,textOffsetX:12,textOffsetY:3,arrowOffsetX:4,gapButtonHeader:5,gapButton:2,activeColor:\"#F4FAFF\",hoverColor:\"#F4FAFF\",arrowSymbol:{left:\"\\u25c4\",right:\"\\u25ba\",up:\"\\u25b2\",down:\"\\u25bc\"}}},{}],684:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.buttons;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}o(\"visible\",i(t,e,{name:\"buttons\",handleItemDefaults:c}).length>0)&&(o(\"active\"),o(\"direction\"),o(\"type\"),o(\"showactive\"),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"bgcolor\",r.paper_bgcolor),o(\"bordercolor\"),o(\"borderwidth\"))}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}r(\"visible\",\"skip\"===t.method||Array.isArray(t.args))&&(r(\"method\"),r(\"args\"),r(\"label\"),r(\"execute\"))}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"./attributes\":682,\"./constants\":683}],685:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"../../constants/alignment\").LINE_SPACING,h=t(\"./constants\"),f=t(\"./scrollbox\");function p(t){return t._index}function d(t,e){return+t.attr(h.menuIndexAttrName)===e._index}function g(t,e,r,n,i,a,o,s){e.active=o,c(t.layout,h.name,e).applyUpdate(\"active\",o),\"buttons\"===e.type?m(t,n,null,null,e):\"dropdown\"===e.type&&(i.attr(h.menuIndexAttrName,\"-1\"),v(t,n,i,a,e),s||m(t,n,i,a,e))}function v(t,e,r,n,i){var a=s.ensureSingle(e,\"g\",h.headerClassName,function(t){t.style(\"pointer-events\",\"all\")}),l=i._dims,c=i.active,u=i.buttons[c]||h.blankHeaderOpts,f={y:i.pad.t,yPad:0,x:i.pad.l,xPad:0,index:0},p={width:l.headerWidth,height:l.headerHeight};a.call(y,i,u,t).call(M,i,f,p),s.ensureSingle(e,\"text\",h.headerArrowClassName,function(t){t.classed(\"user-select-none\",!0).attr(\"text-anchor\",\"end\").call(o.font,i.font).text(h.arrowSymbol[i.direction])}).attr({x:l.headerWidth-h.arrowOffsetX+i.pad.l,y:l.headerHeight/2+h.textOffsetY+i.pad.t}),a.on(\"click\",function(){r.call(S,String(d(r,i)?-1:i._index)),m(t,e,r,n,i)}),a.on(\"mouseover\",function(){a.call(w)}),a.on(\"mouseout\",function(){a.call(k,i)}),o.setTranslate(e,l.lx,l.ly)}function m(t,e,r,a,o){r||(r=e).attr(\"pointer-events\",\"all\");var l=function(t){return-1==+t.attr(h.menuIndexAttrName)}(r)&&\"buttons\"!==o.type?[]:o.buttons,c=\"dropdown\"===o.type?h.dropdownButtonClassName:h.buttonClassName,u=r.selectAll(\"g.\"+c).data(s.filterVisible(l)),f=u.enter().append(\"g\").classed(c,!0),p=u.exit();\"dropdown\"===o.type?(f.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\"),p.transition().attr(\"opacity\",\"0\").remove()):p.remove();var d=0,v=0,m=o._dims,x=-1!==[\"up\",\"down\"].indexOf(o.direction);\"dropdown\"===o.type&&(x?v=m.headerHeight+h.gapButtonHeader:d=m.headerWidth+h.gapButtonHeader),\"dropdown\"===o.type&&\"up\"===o.direction&&(v=-h.gapButtonHeader+h.gapButton-m.openHeight),\"dropdown\"===o.type&&\"left\"===o.direction&&(d=-h.gapButtonHeader+h.gapButton-m.openWidth);var b={x:m.lx+d+o.pad.l,y:m.ly+v+o.pad.t,yPad:h.gapButton,xPad:h.gapButton,index:0},T={l:b.x+o.borderwidth,t:b.y+o.borderwidth};u.each(function(s,l){var c=n.select(this);c.call(y,o,s,t).call(M,o,b),c.on(\"click\",function(){n.event.defaultPrevented||(g(t,o,0,e,r,a,l),s.execute&&i.executeAPICommand(t,s.method,s.args),t.emit(\"plotly_buttonclicked\",{menu:o,button:s,active:o.active}))}),c.on(\"mouseover\",function(){c.call(w)}),c.on(\"mouseout\",function(){c.call(k,o),u.call(_,o)})}),u.call(_,o),x?(T.w=Math.max(m.openWidth,m.headerWidth),T.h=b.y-T.t):(T.w=b.x-T.l,T.h=Math.max(m.openHeight,m.headerHeight)),T.direction=o.direction,a&&(u.size()?function(t,e,r,n,i,a){var o,s,l,c=i.direction,u=\"up\"===c||\"down\"===c,f=i._dims,p=i.active;if(u)for(s=0,l=0;l<p;l++)s+=f.heights[l]+h.gapButton;else for(o=0,l=0;l<p;l++)o+=f.widths[l]+h.gapButton;n.enable(a,o,s),n.hbar&&n.hbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\");n.vbar&&n.vbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\")}(0,0,0,a,o,T):function(t){var e=!!t.hbar,r=!!t.vbar;e&&t.hbar.transition().attr(\"opacity\",\"0\").each(\"end\",function(){e=!1,r||t.disable()});r&&t.vbar.transition().attr(\"opacity\",\"0\").each(\"end\",function(){r=!1,e||t.disable()})}(a))}function y(t,e,r,n){t.call(x,e).call(b,e,r,n)}function x(t,e){s.ensureSingle(t,\"rect\",h.itemRectClassName,function(t){t.attr({rx:h.rx,ry:h.ry,\"shape-rendering\":\"crispEdges\"})}).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\")}function b(t,e,r,n){var i=s.ensureSingle(t,\"text\",h.itemTextClassName,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":\"start\",\"data-notex\":1})}),a=r.label,c=n._fullLayout._meta;c&&(a=s.templateString(a,c)),i.call(o.font,e.font).text(a).call(l.convertToTspans,n)}function _(t,e){var r=e.active;t.each(function(t,i){var o=n.select(this);i===r&&e.showactive&&o.select(\"rect.\"+h.itemRectClassName).call(a.fill,h.activeColor)})}function w(t){t.select(\"rect.\"+h.itemRectClassName).call(a.fill,h.hoverColor)}function k(t,e){t.select(\"rect.\"+h.itemRectClassName).call(a.fill,e.bgcolor)}function T(t,e){var r=e._dims={width1:0,height1:0,heights:[],widths:[],totalWidth:0,totalHeight:0,openWidth:0,openHeight:0,lx:0,ly:0},a=o.tester.selectAll(\"g.\"+h.dropdownButtonClassName).data(s.filterVisible(e.buttons));a.enter().append(\"g\").classed(h.dropdownButtonClassName,!0);var c=-1!==[\"up\",\"down\"].indexOf(e.direction);a.each(function(i,a){var s=n.select(this);s.call(y,e,i,t);var f=s.select(\".\"+h.itemTextClassName),p=f.node()&&o.bBox(f.node()).width,d=Math.max(p+h.textPadX,h.minWidth),g=e.font.size*u,v=l.lineCount(f),m=Math.max(g*v,h.minHeight)+h.textOffsetY;m=Math.ceil(m),d=Math.ceil(d),r.widths[a]=d,r.heights[a]=m,r.height1=Math.max(r.height1,m),r.width1=Math.max(r.width1,d),c?(r.totalWidth=Math.max(r.totalWidth,d),r.openWidth=r.totalWidth,r.totalHeight+=m+h.gapButton,r.openHeight+=m+h.gapButton):(r.totalWidth+=d+h.gapButton,r.openWidth+=d+h.gapButton,r.totalHeight=Math.max(r.totalHeight,m),r.openHeight=r.totalHeight)}),c?r.totalHeight-=h.gapButton:r.totalWidth-=h.gapButton,r.headerWidth=r.width1+h.arrowPadX,r.headerHeight=r.height1,\"dropdown\"===e.type&&(c?(r.width1+=h.arrowPadX,r.totalHeight=r.height1):r.totalWidth=r.width1,r.totalWidth+=h.arrowPadX),a.remove();var f=r.totalWidth+e.pad.l+e.pad.r,p=r.totalHeight+e.pad.t+e.pad.b,d=t._fullLayout._size;r.lx=d.l+d.w*e.x,r.ly=d.t+d.h*(1-e.y);var g=\"left\";s.isRightAnchor(e)&&(r.lx-=f,g=\"right\"),s.isCenterAnchor(e)&&(r.lx-=f/2,g=\"center\");var v=\"top\";s.isBottomAnchor(e)&&(r.ly-=p,v=\"bottom\"),s.isMiddleAnchor(e)&&(r.ly-=p/2,v=\"middle\"),r.totalWidth=Math.ceil(r.totalWidth),r.totalHeight=Math.ceil(r.totalHeight),r.lx=Math.round(r.lx),r.ly=Math.round(r.ly),i.autoMargin(t,A(e),{x:e.x,y:e.y,l:f*({right:1,center:.5}[g]||0),r:f*({left:1,center:.5}[g]||0),b:p*({top:1,middle:.5}[v]||0),t:p*({bottom:1,middle:.5}[v]||0)})}function A(t){return h.autoMarginIdRoot+t._index}function M(t,e,r,n){n=n||{};var i=t.select(\".\"+h.itemRectClassName),a=t.select(\".\"+h.itemTextClassName),s=e.borderwidth,c=r.index,f=e._dims;o.setTranslate(t,s+r.x,s+r.y);var p=-1!==[\"up\",\"down\"].indexOf(e.direction),d=n.height||(p?f.heights[c]:f.height1);i.attr({x:0,y:0,width:n.width||(p?f.width1:f.widths[c]),height:d});var g=e.font.size*u,v=(l.lineCount(a)-1)*g/2;l.positionText(a,h.textOffsetX,d/2-v+h.textOffsetY),p?r.y+=f.heights[c]+r.yPad:r.x+=f.widths[c]+r.xPad,r.index++}function S(t,e){t.attr(h.menuIndexAttrName,e||\"-1\").selectAll(\"g.\"+h.dropdownButtonClassName).remove()}e.exports=function(t){var e=t._fullLayout,r=s.filterVisible(e[h.name]);function a(e){i.autoMargin(t,A(e))}var o=e._menulayer.selectAll(\"g.\"+h.containerClassName).data(r.length>0?[0]:[]);if(o.enter().append(\"g\").classed(h.containerClassName,!0).style(\"cursor\",\"pointer\"),o.exit().each(function(){n.select(this).selectAll(\"g.\"+h.headerGroupClassName).each(a)}).remove(),0!==r.length){var l=o.selectAll(\"g.\"+h.headerGroupClassName).data(r,p);l.enter().append(\"g\").classed(h.headerGroupClassName,!0);for(var c=s.ensureSingle(o,\"g\",h.dropdownButtonGroupClassName,function(t){t.style(\"pointer-events\",\"all\")}),u=0;u<r.length;u++){var y=r[u];T(t,y)}var x=\"updatemenus\"+e._uid,b=new f(t,c,x);l.enter().size()&&(c.node().parentNode.appendChild(c.node()),c.call(S)),l.exit().each(function(t){c.call(S),a(t)}).remove(),l.each(function(e){var r=n.select(this),a=\"dropdown\"===e.type?c:null;i.manageCommandObserver(t,e,e.buttons,function(n){g(t,e,e.buttons[n.index],r,a,b,n.index,!0)}),\"dropdown\"===e.type?(v(t,r,c,b,e),d(c,e)&&m(t,r,c,b,e)):m(t,r,null,null,e)})}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_template\":757,\"../../plots/plots\":828,\"../color\":593,\"../drawing\":614,\"./constants\":683,\"./scrollbox\":687,d3:163}],686:[function(t,e,r){arguments[4][680][0].apply(r,arguments)},{\"./attributes\":682,\"./constants\":683,\"./defaults\":684,\"./draw\":685,dup:680}],687:[function(t,e,r){\"use strict\";e.exports=s;var n=t(\"d3\"),i=t(\"../color\"),a=t(\"../drawing\"),o=t(\"../../lib\");function s(t,e,r){this.gd=t,this.container=e,this.id=r,this.position=null,this.translateX=null,this.translateY=null,this.hbar=null,this.vbar=null,this.bg=this.container.selectAll(\"rect.scrollbox-bg\").data([0]),this.bg.exit().on(\".drag\",null).on(\"wheel\",null).remove(),this.bg.enter().append(\"rect\").classed(\"scrollbox-bg\",!0).style(\"pointer-events\",\"all\").attr({opacity:0,x:0,y:0,width:0,height:0})}s.barWidth=2,s.barLength=20,s.barRadius=2,s.barPad=1,s.barColor=\"#808BA4\",s.prototype.enable=function(t,e,r){var o=this.gd._fullLayout,l=o.width,c=o.height;this.position=t;var u,h,f,p,d=this.position.l,g=this.position.w,v=this.position.t,m=this.position.h,y=this.position.direction,x=\"down\"===y,b=\"left\"===y,_=\"up\"===y,w=g,k=m;x||b||\"right\"===y||_||(this.position.direction=\"down\",x=!0),x||_?(h=(u=d)+w,x?(f=v,k=(p=Math.min(f+k,c))-f):k=(p=v+k)-(f=Math.max(p-k,0))):(p=(f=v)+k,b?w=(h=d+w)-(u=Math.max(h-w,0)):(u=d,w=(h=Math.min(u+w,l))-u)),this._box={l:u,t:f,w:w,h:k};var T=g>w,A=s.barLength+2*s.barPad,M=s.barWidth+2*s.barPad,S=d,E=v+m;E+M>c&&(E=c-M);var C=this.container.selectAll(\"rect.scrollbar-horizontal\").data(T?[0]:[]);C.exit().on(\".drag\",null).remove(),C.enter().append(\"rect\").classed(\"scrollbar-horizontal\",!0).call(i.fill,s.barColor),T?(this.hbar=C.attr({rx:s.barRadius,ry:s.barRadius,x:S,y:E,width:A,height:M}),this._hbarXMin=S+A/2,this._hbarTranslateMax=w-A):(delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax);var L=m>k,P=s.barWidth+2*s.barPad,O=s.barLength+2*s.barPad,z=d+g,I=v;z+P>l&&(z=l-P);var D=this.container.selectAll(\"rect.scrollbar-vertical\").data(L?[0]:[]);D.exit().on(\".drag\",null).remove(),D.enter().append(\"rect\").classed(\"scrollbar-vertical\",!0).call(i.fill,s.barColor),L?(this.vbar=D.attr({rx:s.barRadius,ry:s.barRadius,x:z,y:I,width:P,height:O}),this._vbarYMin=I+O/2,this._vbarTranslateMax=k-O):(delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax);var R=this.id,F=u-.5,B=L?h+P+.5:h+.5,N=f-.5,j=T?p+M+.5:p+.5,U=o._topdefs.selectAll(\"#\"+R).data(T||L?[0]:[]);if(U.exit().remove(),U.enter().append(\"clipPath\").attr(\"id\",R).append(\"rect\"),T||L?(this._clipRect=U.select(\"rect\").attr({x:Math.floor(F),y:Math.floor(N),width:Math.ceil(B)-Math.floor(F),height:Math.ceil(j)-Math.floor(N)}),this.container.call(a.setClipUrl,R,this.gd),this.bg.attr({x:d,y:v,width:g,height:m})):(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),T||L){var V=n.behavior.drag().on(\"dragstart\",function(){n.event.sourceEvent.preventDefault()}).on(\"drag\",this._onBoxDrag.bind(this));this.container.on(\"wheel\",null).on(\"wheel\",this._onBoxWheel.bind(this)).on(\".drag\",null).call(V);var q=n.behavior.drag().on(\"dragstart\",function(){n.event.sourceEvent.preventDefault(),n.event.sourceEvent.stopPropagation()}).on(\"drag\",this._onBarDrag.bind(this));T&&this.hbar.on(\".drag\",null).call(q),L&&this.vbar.on(\".drag\",null).call(q)}this.setTranslate(e,r)},s.prototype.disable=function(){(this.hbar||this.vbar)&&(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),this.hbar&&(this.hbar.on(\".drag\",null),this.hbar.remove(),delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax),this.vbar&&(this.vbar.on(\".drag\",null),this.vbar.remove(),delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax)},s.prototype._onBoxDrag=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t-=n.event.dx),this.vbar&&(e-=n.event.dy),this.setTranslate(t,e)},s.prototype._onBoxWheel=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t+=n.event.deltaY),this.vbar&&(e+=n.event.deltaY),this.setTranslate(t,e)},s.prototype._onBarDrag=function(){var t=this.translateX,e=this.translateY;if(this.hbar){var r=t+this._hbarXMin,i=r+this._hbarTranslateMax;t=(o.constrain(n.event.x,r,i)-r)/(i-r)*(this.position.w-this._box.w)}if(this.vbar){var a=e+this._vbarYMin,s=a+this._vbarTranslateMax;e=(o.constrain(n.event.y,a,s)-a)/(s-a)*(this.position.h-this._box.h)}this.setTranslate(t,e)},s.prototype.setTranslate=function(t,e){var r=this.position.w-this._box.w,n=this.position.h-this._box.h;if(t=o.constrain(t||0,0,r),e=o.constrain(e||0,0,n),this.translateX=t,this.translateY=e,this.container.call(a.setTranslate,this._box.l-this.position.l-t,this._box.t-this.position.t-e),this._clipRect&&this._clipRect.attr({x:Math.floor(this.position.l+t-.5),y:Math.floor(this.position.t+e-.5)}),this.hbar){var i=t/r;this.hbar.call(a.setTranslate,t+i*this._hbarTranslateMax,e)}if(this.vbar){var s=e/n;this.vbar.call(a.setTranslate,t,e+s*this._vbarTranslateMax)}}},{\"../../lib\":719,\"../color\":593,\"../drawing\":614,d3:163}],688:[function(t,e,r){\"use strict\";e.exports={FROM_BL:{left:0,center:.5,right:1,bottom:0,middle:.5,top:1},FROM_TL:{left:0,center:.5,right:1,bottom:1,middle:.5,top:0},FROM_BR:{left:1,center:.5,right:0,bottom:0,middle:.5,top:1},LINE_SPACING:1.3,CAP_SHIFT:.7,MID_SHIFT:.35,OPPOSITE_SIDE:{left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}}},{}],689:[function(t,e,r){\"use strict\";e.exports={INCREASING:{COLOR:\"#3D9970\",SYMBOL:\"\\u25b2\"},DECREASING:{COLOR:\"#FF4136\",SYMBOL:\"\\u25bc\"}}},{}],690:[function(t,e,r){\"use strict\";e.exports={FORMAT_LINK:\"https://github.com/d3/d3-3.x-api-reference/blob/master/Formatting.md#d3_format\",DATE_FORMAT_LINK:\"https://github.com/d3/d3-3.x-api-reference/blob/master/Time-Formatting.md#format\"}},{}],691:[function(t,e,r){\"use strict\";e.exports={COMPARISON_OPS:[\"=\",\"!=\",\"<\",\">=\",\">\",\"<=\"],COMPARISON_OPS2:[\"=\",\"<\",\">=\",\">\",\"<=\"],INTERVAL_OPS:[\"[]\",\"()\",\"[)\",\"(]\",\"][\",\")(\",\"](\",\")[\"],SET_OPS:[\"{}\",\"}{\"],CONSTRAINT_REDUCTION:{\"=\":\"=\",\"<\":\"<\",\"<=\":\"<\",\">\":\">\",\">=\":\">\",\"[]\":\"[]\",\"()\":\"[]\",\"[)\":\"[]\",\"(]\":\"[]\",\"][\":\"][\",\")(\":\"][\",\"](\":\"][\",\")[\":\"][\"}}},{}],692:[function(t,e,r){\"use strict\";e.exports={solid:[[],0],dot:[[.5,1],200],dash:[[.5,1],50],longdash:[[.5,1],10],dashdot:[[.5,.625,.875,1],50],longdashdot:[[.5,.7,.8,1],10]}},{}],693:[function(t,e,r){\"use strict\";e.exports={circle:\"\\u25cf\",\"circle-open\":\"\\u25cb\",square:\"\\u25a0\",\"square-open\":\"\\u25a1\",diamond:\"\\u25c6\",\"diamond-open\":\"\\u25c7\",cross:\"+\",x:\"\\u274c\"}},{}],694:[function(t,e,r){\"use strict\";e.exports={SHOW_PLACEHOLDER:100,HIDE_PLACEHOLDER:1e3,DESELECTDIM:.2}},{}],695:[function(t,e,r){\"use strict\";e.exports={BADNUM:void 0,FP_SAFE:Number.MAX_VALUE/1e4,ONEAVGYEAR:315576e5,ONEAVGMONTH:26298e5,ONEDAY:864e5,ONEHOUR:36e5,ONEMIN:6e4,ONESEC:1e3,EPOCHJD:2440587.5,ALMOST_EQUAL:1-1e-6,LOG_CLIP:10,MINUS_SIGN:\"\\u2212\"}},{}],696:[function(t,e,r){\"use strict\";r.xmlns=\"http://www.w3.org/2000/xmlns/\",r.svg=\"http://www.w3.org/2000/svg\",r.xlink=\"http://www.w3.org/1999/xlink\",r.svgAttrs={xmlns:r.svg,\"xmlns:xlink\":r.xlink}},{}],697:[function(t,e,r){\"use strict\";r.version=\"1.49.1\",t(\"es6-promise\").polyfill(),t(\"../build/plotcss\"),t(\"./fonts/mathjax_config\")();for(var n=t(\"./registry\"),i=r.register=n.register,a=t(\"./plot_api\"),o=Object.keys(a),s=0;s<o.length;s++){var l=o[s];\"_\"!==l.charAt(0)&&(r[l]=a[l]),i({moduleType:\"apiMethod\",name:l,fn:a[l]})}i(t(\"./traces/scatter\")),i([t(\"./components/fx\"),t(\"./components/legend\"),t(\"./components/annotations\"),t(\"./components/annotations3d\"),t(\"./components/shapes\"),t(\"./components/images\"),t(\"./components/updatemenus\"),t(\"./components/sliders\"),t(\"./components/rangeslider\"),t(\"./components/rangeselector\"),t(\"./components/grid\"),t(\"./components/errorbars\"),t(\"./components/colorscale\"),t(\"./components/colorbar\")]),i([t(\"./locale-en\"),t(\"./locale-en-us\")]),r.Icons=t(\"./fonts/ploticon\"),r.Plots=t(\"./plots/plots\"),r.Fx=t(\"./components/fx\"),r.Snapshot=t(\"./snapshot\"),r.PlotSchema=t(\"./plot_api/plot_schema\"),r.Queue=t(\"./lib/queue\"),r.d3=t(\"d3\")},{\"../build/plotcss\":1,\"./components/annotations\":584,\"./components/annotations3d\":589,\"./components/colorbar\":599,\"./components/colorscale\":605,\"./components/errorbars\":620,\"./components/fx\":632,\"./components/grid\":636,\"./components/images\":641,\"./components/legend\":649,\"./components/rangeselector\":660,\"./components/rangeslider\":667,\"./components/shapes\":675,\"./components/sliders\":680,\"./components/updatemenus\":686,\"./fonts/mathjax_config\":698,\"./fonts/ploticon\":699,\"./lib/queue\":734,\"./locale-en\":748,\"./locale-en-us\":747,\"./plot_api\":752,\"./plot_api/plot_schema\":756,\"./plots/plots\":828,\"./registry\":847,\"./snapshot\":852,\"./traces/scatter\":1123,d3:163,\"es6-promise\":218}],698:[function(t,e,r){\"use strict\";e.exports=function(){\"undefined\"!=typeof MathJax&&(\"local\"!==(window.PlotlyConfig||{}).MathJaxConfig&&(MathJax.Hub.Config({messageStyle:\"none\",skipStartupTypeset:!0,displayAlign:\"left\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]}}),MathJax.Hub.Configured()))}},{}],699:[function(t,e,r){\"use strict\";e.exports={undo:{width:857.1,height:1e3,path:\"m857 350q0-87-34-166t-91-137-137-92-166-34q-96 0-183 41t-147 114q-4 6-4 13t5 11l76 77q6 5 14 5 9-1 13-7 41-53 100-82t126-29q58 0 110 23t92 61 61 91 22 111-22 111-61 91-92 61-110 23q-55 0-105-20t-90-57l77-77q17-16 8-38-10-23-33-23h-250q-15 0-25 11t-11 25v250q0 24 22 33 22 10 39-8l72-72q60 57 137 88t159 31q87 0 166-34t137-92 91-137 34-166z\",transform:\"matrix(1 0 0 -1 0 850)\"},home:{width:928.6,height:1e3,path:\"m786 296v-267q0-15-11-26t-25-10h-214v214h-143v-214h-214q-15 0-25 10t-11 26v267q0 1 0 2t0 2l321 264 321-264q1-1 1-4z m124 39l-34-41q-5-5-12-6h-2q-7 0-12 3l-386 322-386-322q-7-4-13-4-7 2-12 7l-35 41q-4 5-3 13t6 12l401 334q18 15 42 15t43-15l136-114v109q0 8 5 13t13 5h107q8 0 13-5t5-13v-227l122-102q5-5 6-12t-4-13z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"camera-retro\":{width:1e3,height:1e3,path:\"m518 386q0 8-5 13t-13 5q-37 0-63-27t-26-63q0-8 5-13t13-5 12 5 5 13q0 23 16 38t38 16q8 0 13 5t5 13z m125-73q0-59-42-101t-101-42-101 42-42 101 42 101 101 42 101-42 42-101z m-572-320h858v71h-858v-71z m643 320q0 89-62 152t-152 62-151-62-63-152 63-151 151-63 152 63 62 151z m-571 358h214v72h-214v-72z m-72-107h858v143h-462l-36-71h-360v-72z m929 143v-714q0-30-21-51t-50-21h-858q-29 0-50 21t-21 51v714q0 30 21 51t50 21h858q29 0 50-21t21-51z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoombox:{width:1e3,height:1e3,path:\"m1000-25l-250 251c40 63 63 138 63 218 0 224-182 406-407 406-224 0-406-182-406-406s183-406 407-406c80 0 155 22 218 62l250-250 125 125z m-812 250l0 438 437 0 0-438-437 0z m62 375l313 0 0-312-313 0 0 312z\",transform:\"matrix(1 0 0 -1 0 850)\"},pan:{width:1e3,height:1e3,path:\"m1000 350l-187 188 0-125-250 0 0 250 125 0-188 187-187-187 125 0 0-250-250 0 0 125-188-188 186-187 0 125 252 0 0-250-125 0 187-188 188 188-125 0 0 250 250 0 0-126 187 188z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_plus:{width:875,height:1e3,path:\"m1 787l0-875 875 0 0 875-875 0z m687-500l-187 0 0-187-125 0 0 187-188 0 0 125 188 0 0 187 125 0 0-187 187 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_minus:{width:875,height:1e3,path:\"m0 788l0-876 875 0 0 876-875 0z m688-500l-500 0 0 125 500 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},autoscale:{width:1e3,height:1e3,path:\"m250 850l-187 0-63 0 0-62 0-188 63 0 0 188 187 0 0 62z m688 0l-188 0 0-62 188 0 0-188 62 0 0 188 0 62-62 0z m-875-938l0 188-63 0 0-188 0-62 63 0 187 0 0 62-187 0z m875 188l0-188-188 0 0-62 188 0 62 0 0 62 0 188-62 0z m-125 188l-1 0-93-94-156 156 156 156 92-93 2 0 0 250-250 0 0-2 93-92-156-156-156 156 94 92 0 2-250 0 0-250 0 0 93 93 157-156-157-156-93 94 0 0 0-250 250 0 0 0-94 93 156 157 156-157-93-93 0 0 250 0 0 250z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_basic:{width:1500,height:1e3,path:\"m375 725l0 0-375-375 375-374 0-1 1125 0 0 750-1125 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_compare:{width:1125,height:1e3,path:\"m187 786l0 2-187-188 188-187 0 0 937 0 0 373-938 0z m0-499l0 1-187-188 188-188 0 0 937 0 0 376-938-1z\",transform:\"matrix(1 0 0 -1 0 850)\"},plotlylogo:{width:1542,height:1e3,path:\"m0-10h182v-140h-182v140z m228 146h183v-286h-183v286z m225 714h182v-1000h-182v1000z m225-285h182v-715h-182v715z m225 142h183v-857h-183v857z m231-428h182v-429h-182v429z m225-291h183v-138h-183v138z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"z-axis\":{width:1e3,height:1e3,path:\"m833 5l-17 108v41l-130-65 130-66c0 0 0 38 0 39 0-1 36-14 39-25 4-15-6-22-16-30-15-12-39-16-56-20-90-22-187-23-279-23-261 0-341 34-353 59 3 60 228 110 228 110-140-8-351-35-351-116 0-120 293-142 474-142 155 0 477 22 477 142 0 50-74 79-163 96z m-374 94c-58-5-99-21-99-40 0-24 65-43 144-43 79 0 143 19 143 43 0 19-42 34-98 40v216h87l-132 135-133-135h88v-216z m167 515h-136v1c16 16 31 34 46 52l84 109v54h-230v-71h124v-1c-16-17-28-32-44-51l-89-114v-51h245v72z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"3d_rotate\":{width:1e3,height:1e3,path:\"m922 660c-5 4-9 7-14 11-359 263-580-31-580-31l-102 28 58-400c0 1 1 1 2 2 118 108 351 249 351 249s-62 27-100 42c88 83 222 183 347 122 16-8 30-17 44-27-2 1-4 2-6 4z m36-329c0 0 64 229-88 296-62 27-124 14-175-11 157-78 225-208 249-266 8-19 11-31 11-31 2 5 6 15 11 32-5-13-8-20-8-20z m-775-239c70-31 117-50 198-32-121 80-199 346-199 346l-96-15-58-12c0 0 55-226 155-287z m603 133l-317-139c0 0 4-4 19-14 7-5 24-15 24-15s-177-147-389 4c235-287 536-112 536-112l31-22 100 299-4-1z m-298-153c6-4 14-9 24-15 0 0-17 10-24 15z\",transform:\"matrix(1 0 0 -1 0 850)\"},camera:{width:1e3,height:1e3,path:\"m500 450c-83 0-150-67-150-150 0-83 67-150 150-150 83 0 150 67 150 150 0 83-67 150-150 150z m400 150h-120c-16 0-34 13-39 29l-31 93c-6 15-23 28-40 28h-340c-16 0-34-13-39-28l-31-94c-6-15-23-28-40-28h-120c-55 0-100-45-100-100v-450c0-55 45-100 100-100h800c55 0 100 45 100 100v450c0 55-45 100-100 100z m-400-550c-138 0-250 112-250 250 0 138 112 250 250 250 138 0 250-112 250-250 0-138-112-250-250-250z m365 380c-19 0-35 16-35 35 0 19 16 35 35 35 19 0 35-16 35-35 0-19-16-35-35-35z\",transform:\"matrix(1 0 0 -1 0 850)\"},movie:{width:1e3,height:1e3,path:\"m938 413l-188-125c0 37-17 71-44 94 64 38 107 107 107 187 0 121-98 219-219 219-121 0-219-98-219-219 0-61 25-117 66-156h-115c30 33 49 76 49 125 0 103-84 187-187 187s-188-84-188-187c0-57 26-107 65-141-38-22-65-62-65-109v-250c0-70 56-126 125-126h500c69 0 125 56 125 126l188-126c34 0 62 28 62 63v375c0 35-28 63-62 63z m-750 0c-69 0-125 56-125 125s56 125 125 125 125-56 125-125-56-125-125-125z m406-1c-87 0-157 70-157 157 0 86 70 156 157 156s156-70 156-156-70-157-156-157z\",transform:\"matrix(1 0 0 -1 0 850)\"},question:{width:857.1,height:1e3,path:\"m500 82v107q0 8-5 13t-13 5h-107q-8 0-13-5t-5-13v-107q0-8 5-13t13-5h107q8 0 13 5t5 13z m143 375q0 49-31 91t-77 65-95 23q-136 0-207-119-9-14 4-24l74-55q4-4 10-4 9 0 14 7 30 38 48 51 19 14 48 14 27 0 48-15t21-33q0-21-11-34t-38-25q-35-16-65-48t-29-70v-20q0-8 5-13t13-5h107q8 0 13 5t5 13q0 10 12 27t30 28q18 10 28 16t25 19 25 27 16 34 7 45z m214-107q0-117-57-215t-156-156-215-58-216 58-155 156-58 215 58 215 155 156 216 58 215-58 156-156 57-215z\",transform:\"matrix(1 0 0 -1 0 850)\"},disk:{width:857.1,height:1e3,path:\"m214-7h429v214h-429v-214z m500 0h72v500q0 8-6 21t-11 20l-157 156q-5 6-19 12t-22 5v-232q0-22-15-38t-38-16h-322q-22 0-37 16t-16 38v232h-72v-714h72v232q0 22 16 38t37 16h465q22 0 38-16t15-38v-232z m-214 518v178q0 8-5 13t-13 5h-107q-7 0-13-5t-5-13v-178q0-8 5-13t13-5h107q7 0 13 5t5 13z m357-18v-518q0-22-15-38t-38-16h-750q-23 0-38 16t-16 38v750q0 22 16 38t38 16h517q23 0 50-12t42-26l156-157q16-15 27-42t11-49z\",transform:\"matrix(1 0 0 -1 0 850)\"},lasso:{width:1031,height:1e3,path:\"m1018 538c-36 207-290 336-568 286-277-48-473-256-436-463 10-57 36-108 76-151-13-66 11-137 68-183 34-28 75-41 114-42l-55-70 0 0c-2-1-3-2-4-3-10-14-8-34 5-45 14-11 34-8 45 4 1 1 2 3 2 5l0 0 113 140c16 11 31 24 45 40 4 3 6 7 8 11 48-3 100 0 151 9 278 48 473 255 436 462z m-624-379c-80 14-149 48-197 96 42 42 109 47 156 9 33-26 47-66 41-105z m-187-74c-19 16-33 37-39 60 50-32 109-55 174-68-42-25-95-24-135 8z m360 75c-34-7-69-9-102-8 8 62-16 128-68 170-73 59-175 54-244-5-9 20-16 40-20 61-28 159 121 317 333 354s407-60 434-217c28-159-121-318-333-355z\",transform:\"matrix(1 0 0 -1 0 850)\"},selectbox:{width:1e3,height:1e3,path:\"m0 850l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-285l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},spikeline:{width:1e3,height:1e3,path:\"M512 409c0-57-46-104-103-104-57 0-104 47-104 104 0 57 47 103 104 103 57 0 103-46 103-103z m-327-39l92 0 0 92-92 0z m-185 0l92 0 0 92-92 0z m370-186l92 0 0 93-92 0z m0-184l92 0 0 92-92 0z\",transform:\"matrix(1.5 0 0 -1.5 0 850)\"},pencil:{width:1792,height:1792,path:\"M491 1536l91-91-235-235-91 91v107h128v128h107zm523-928q0-22-22-22-10 0-17 7l-542 542q-7 7-7 17 0 22 22 22 10 0 17-7l542-542q7-7 7-17zm-54-192l416 416-832 832h-416v-416zm683 96q0 53-37 90l-166 166-416-416 166-165q36-38 90-38 53 0 91 38l235 234q37 39 37 91z\",transform:\"matrix(1 0 0 1 0 1)\"},newplotlylogo:{name:\"newplotlylogo\",svg:\"<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 132 132'><defs><style>.cls-1 {fill: #119dff;} .cls-2 {fill: #25fefd;} .cls-3 {fill: #fff;}</style></defs><title>plotly-logomark</title><g id='symbol'><rect class='cls-1' width='132' height='132' rx='6' ry='6'/><circle class='cls-2' cx='78' cy='54' r='6'/><circle class='cls-2' cx='102' cy='30' r='6'/><circle class='cls-2' cx='78' cy='30' r='6'/><circle class='cls-2' cx='54' cy='30' r='6'/><circle class='cls-2' cx='30' cy='30' r='6'/><circle class='cls-2' cx='30' cy='54' r='6'/><path class='cls-3' d='M30,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,30,72Z'/><path class='cls-3' d='M78,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,78,72Z'/><path class='cls-3' d='M54,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,54,48Z'/><path class='cls-3' d='M102,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,102,48Z'/></g></svg>\"}}},{}],700:[function(t,e,r){\"use strict\";r.isLeftAnchor=function(t){return\"left\"===t.xanchor||\"auto\"===t.xanchor&&t.x<=1/3},r.isCenterAnchor=function(t){return\"center\"===t.xanchor||\"auto\"===t.xanchor&&t.x>1/3&&t.x<2/3},r.isRightAnchor=function(t){return\"right\"===t.xanchor||\"auto\"===t.xanchor&&t.x>=2/3},r.isTopAnchor=function(t){return\"top\"===t.yanchor||\"auto\"===t.yanchor&&t.y>=2/3},r.isMiddleAnchor=function(t){return\"middle\"===t.yanchor||\"auto\"===t.yanchor&&t.y>1/3&&t.y<2/3},r.isBottomAnchor=function(t){return\"bottom\"===t.yanchor||\"auto\"===t.yanchor&&t.y<=1/3}},{}],701:[function(t,e,r){\"use strict\";var n=t(\"./mod\"),i=n.mod,a=n.modHalf,o=Math.PI,s=2*o;function l(t){return Math.abs(t[1]-t[0])>s-1e-14}function c(t,e){return a(e-t,s)}function u(t,e){if(l(e))return!0;var r,n;e[0]<e[1]?(r=e[0],n=e[1]):(r=e[1],n=e[0]),(r=i(r,s))>(n=i(n,s))&&(n+=s);var a=i(t,s),o=a+s;return a>=r&&a<=n||o>=r&&o<=n}function h(t,e,r,n,i,a,c){i=i||0,a=a||0;var u,h,f,p,d,g=l([r,n]);function v(t,e){return[t*Math.cos(e)+i,a-t*Math.sin(e)]}g?(u=0,h=o,f=s):r<n?(u=r,f=n):(u=n,f=r),t<e?(p=t,d=e):(p=e,d=t);var m,y=Math.abs(f-u)<=o?0:1;function x(t,e,r){return\"A\"+[t,t]+\" \"+[0,y,r]+\" \"+v(t,e)}return g?m=null===p?\"M\"+v(d,u)+x(d,h,0)+x(d,f,0)+\"Z\":\"M\"+v(p,u)+x(p,h,0)+x(p,f,0)+\"ZM\"+v(d,u)+x(d,h,1)+x(d,f,1)+\"Z\":null===p?(m=\"M\"+v(d,u)+x(d,f,0),c&&(m+=\"L0,0Z\")):m=\"M\"+v(p,u)+\"L\"+v(d,u)+x(d,f,0)+\"L\"+v(p,f)+x(p,u,1)+\"Z\",m}e.exports={deg2rad:function(t){return t/180*o},rad2deg:function(t){return t/o*180},angleDelta:c,angleDist:function(t,e){return Math.abs(c(t,e))},isFullCircle:l,isAngleInsideSector:u,isPtInsideSector:function(t,e,r,n){return!!u(e,n)&&(r[0]<r[1]?(i=r[0],a=r[1]):(i=r[1],a=r[0]),t>=i&&t<=a);var i,a},pathArc:function(t,e,r,n,i){return h(null,t,e,r,n,i,0)},pathSector:function(t,e,r,n,i){return h(null,t,e,r,n,i,1)},pathAnnulus:function(t,e,r,n,i,a){return h(t,e,r,n,i,a,1)}}},{\"./mod\":726}],702:[function(t,e,r){\"use strict\";var n=Array.isArray,i=\"undefined\"!=typeof ArrayBuffer&&ArrayBuffer.isView?ArrayBuffer:{isView:function(){return!1}},a=\"undefined\"==typeof DataView?function(){}:DataView;function o(t){return i.isView(t)&&!(t instanceof a)}function s(t){return n(t)||o(t)}function l(t,e,r){if(s(t)){if(s(t[0])){for(var n=r,i=0;i<t.length;i++)n=e(n,t[i].length);return n}return t.length}return 0}r.isTypedArray=o,r.isArrayOrTypedArray=s,r.isArray1D=function(t){return!s(t[0])},r.ensureArray=function(t,e){return n(t)||(t=[]),t.length=e,t},r.concat=function(){var t,e,r,i,a,o,s,l,c=[],u=!0,h=0;for(r=0;r<arguments.length;r++)(o=(i=arguments[r]).length)&&(e?c.push(i):(e=i,a=o),n(i)?t=!1:(u=!1,h?t!==i.constructor&&(t=!1):t=i.constructor),h+=o);if(!h)return[];if(!c.length)return e;if(u)return e.concat.apply(e,c);if(t){for((s=new t(h)).set(e),r=0;r<c.length;r++)i=c[r],s.set(i,a),a+=i.length;return s}for(s=new Array(h),l=0;l<e.length;l++)s[l]=e[l];for(r=0;r<c.length;r++){for(i=c[r],l=0;l<i.length;l++)s[a+l]=i[l];a+=l}return s},r.maxRowLength=function(t){return l(t,Math.max,0)},r.minRowLength=function(t){return l(t,Math.min,1/0)}},{}],703:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../constants/numerical\").BADNUM,a=/^['\"%,$#\\s']+|[, ]|['\"%,$#\\s']+$/g;e.exports=function(t){return\"string\"==typeof t&&(t=t.replace(a,\"\")),n(t)?Number(t):i}},{\"../constants/numerical\":695,\"fast-isnumeric\":225}],704:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t._fullLayout;e._glcanvas&&e._glcanvas.size()&&e._glcanvas.each(function(t){t.regl&&t.regl.clear({color:!0,depth:!0})})}},{}],705:[function(t,e,r){\"use strict\";e.exports=function(t){t._responsiveChartHandler&&(window.removeEventListener(\"resize\",t._responsiveChartHandler),delete t._responsiveChartHandler)}},{}],706:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../plots/attributes\"),o=t(\"../components/colorscale/scales\"),s=t(\"../constants/interactions\").DESELECTDIM,l=t(\"./nested_property\"),c=t(\"./regex\").counter,u=t(\"./mod\").modHalf,h=t(\"./array\").isArrayOrTypedArray;function f(t,e){var n=r.valObjectMeta[e.valType];if(e.arrayOk&&h(t))return!0;if(n.validateFunction)return n.validateFunction(t,e);var i={},a=i,o={set:function(t){a=t}};return n.coerceFunction(t,o,i,e),a!==i}r.valObjectMeta={data_array:{coerceFunction:function(t,e,r){h(t)?e.set(t):void 0!==r&&e.set(r)}},enumerated:{coerceFunction:function(t,e,r,n){n.coerceNumber&&(t=+t),-1===n.values.indexOf(t)?e.set(r):e.set(t)},validateFunction:function(t,e){e.coerceNumber&&(t=+t);for(var r=e.values,n=0;n<r.length;n++){var i=String(r[n]);if(\"/\"===i.charAt(0)&&\"/\"===i.charAt(i.length-1)){if(new RegExp(i.substr(1,i.length-2)).test(t))return!0}else if(t===r[n])return!0}return!1}},boolean:{coerceFunction:function(t,e,r){!0===t||!1===t?e.set(t):e.set(r)}},number:{coerceFunction:function(t,e,r,i){!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},integer:{coerceFunction:function(t,e,r,i){t%1||!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},string:{coerceFunction:function(t,e,r,n){if(\"string\"!=typeof t){var i=\"number\"==typeof t;!0!==n.strict&&i?e.set(String(t)):e.set(r)}else n.noBlank&&!t?e.set(r):e.set(t)}},color:{coerceFunction:function(t,e,r){i(t).isValid()?e.set(t):e.set(r)}},colorlist:{coerceFunction:function(t,e,r){Array.isArray(t)&&t.length&&t.every(function(t){return i(t).isValid()})?e.set(t):e.set(r)}},colorscale:{coerceFunction:function(t,e,r){e.set(o.get(t,r))}},angle:{coerceFunction:function(t,e,r){\"auto\"===t?e.set(\"auto\"):n(t)?e.set(u(+t,360)):e.set(r)}},subplotid:{coerceFunction:function(t,e,r,n){var i=n.regex||c(r);\"string\"==typeof t&&i.test(t)?e.set(t):e.set(r)},validateFunction:function(t,e){var r=e.dflt;return t===r||\"string\"==typeof t&&!!c(r).test(t)}},flaglist:{coerceFunction:function(t,e,r,n){if(\"string\"==typeof t)if(-1===(n.extras||[]).indexOf(t)){for(var i=t.split(\"+\"),a=0;a<i.length;){var o=i[a];-1===n.flags.indexOf(o)||i.indexOf(o)<a?i.splice(a,1):a++}i.length?e.set(i.join(\"+\")):e.set(r)}else e.set(t);else e.set(r)}},any:{coerceFunction:function(t,e,r){void 0===t?e.set(r):e.set(t)}},info_array:{coerceFunction:function(t,e,n,i){function a(t,e,n){var i,a={set:function(t){i=t}};return void 0===n&&(n=e.dflt),r.valObjectMeta[e.valType].coerceFunction(t,a,n,e),i}var o=2===i.dimensions||\"1-2\"===i.dimensions&&Array.isArray(t)&&Array.isArray(t[0]);if(Array.isArray(t)){var s,l,c,u,h,f,p=i.items,d=[],g=Array.isArray(p),v=g&&o&&Array.isArray(p[0]),m=o&&g&&!v,y=g&&!m?p.length:t.length;if(n=Array.isArray(n)?n:[],o)for(s=0;s<y;s++)for(d[s]=[],c=Array.isArray(t[s])?t[s]:[],h=m?p.length:g?p[s].length:c.length,l=0;l<h;l++)u=m?p[l]:g?p[s][l]:p,void 0!==(f=a(c[l],u,(n[s]||[])[l]))&&(d[s][l]=f);else for(s=0;s<y;s++)void 0!==(f=a(t[s],g?p[s]:p,n[s]))&&(d[s]=f);e.set(d)}else e.set(n)},validateFunction:function(t,e){if(!Array.isArray(t))return!1;var r=e.items,n=Array.isArray(r),i=2===e.dimensions;if(!e.freeLength&&t.length!==r.length)return!1;for(var a=0;a<t.length;a++)if(i){if(!Array.isArray(t[a])||!e.freeLength&&t[a].length!==r[a].length)return!1;for(var o=0;o<t[a].length;o++)if(!f(t[a][o],n?r[a][o]:r))return!1}else if(!f(t[a],n?r[a]:r))return!1;return!0}}},r.coerce=function(t,e,n,i,a){var o=l(n,i).get(),s=l(t,i),c=l(e,i),u=s.get(),p=e._template;if(void 0===u&&p&&(u=l(p,i).get(),p=0),void 0===a&&(a=o.dflt),o.arrayOk&&h(u))return c.set(u),u;var d=r.valObjectMeta[o.valType].coerceFunction;d(u,c,a,o);var g=c.get();return p&&g===a&&!f(u,o)&&(d(u=l(p,i).get(),c,a,o),g=c.get()),g},r.coerce2=function(t,e,n,i,a){var o=l(t,i),s=r.coerce(t,e,n,i,a),c=o.get();return null!=c&&s},r.coerceFont=function(t,e,r){var n={};return r=r||{},n.family=t(e+\".family\",r.family),n.size=t(e+\".size\",r.size),n.color=t(e+\".color\",r.color),n},r.coerceHoverinfo=function(t,e,n){var i,o=e._module.attributes,s=o.hoverinfo?o:a,l=s.hoverinfo;if(1===n._dataLength){var c=\"all\"===l.dflt?l.flags.slice():l.dflt.split(\"+\");c.splice(c.indexOf(\"name\"),1),i=c.join(\"+\")}return r.coerce(t,e,s,\"hoverinfo\",i)},r.coerceSelectionMarkerOpacity=function(t,e){if(t.marker){var r,n,i=t.marker.opacity;if(void 0!==i)h(i)||t.selected||t.unselected||(r=i,n=s*i),e(\"selected.marker.opacity\",r),e(\"unselected.marker.opacity\",n)}},r.validate=f},{\"../components/colorscale/scales\":608,\"../constants/interactions\":694,\"../plots/attributes\":764,\"./array\":702,\"./mod\":726,\"./nested_property\":727,\"./regex\":735,\"fast-isnumeric\":225,tinycolor2:537}],707:[function(t,e,r){\"use strict\";var n,i,a=t(\"d3\"),o=t(\"fast-isnumeric\"),s=t(\"./loggers\"),l=t(\"./mod\").mod,c=t(\"../constants/numerical\"),u=c.BADNUM,h=c.ONEDAY,f=c.ONEHOUR,p=c.ONEMIN,d=c.ONESEC,g=c.EPOCHJD,v=t(\"../registry\"),m=a.time.format.utc,y=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\d)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d:?\\d\\d)?)?)?)?)?\\s*$/m,x=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\di?)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d:?\\d\\d)?)?)?)?)?\\s*$/m,b=(new Date).getFullYear()-70;function _(t){return t&&v.componentsRegistry.calendars&&\"string\"==typeof t&&\"gregorian\"!==t}function w(t,e){return String(t+Math.pow(10,e)).substr(1)}r.dateTick0=function(t,e){return _(t)?e?v.getComponentMethod(\"calendars\",\"CANONICAL_SUNDAY\")[t]:v.getComponentMethod(\"calendars\",\"CANONICAL_TICK\")[t]:e?\"2000-01-02\":\"2000-01-01\"},r.dfltRange=function(t){return _(t)?v.getComponentMethod(\"calendars\",\"DFLTRANGE\")[t]:[\"2000-01-01\",\"2001-01-01\"]},r.isJSDate=function(t){return\"object\"==typeof t&&null!==t&&\"function\"==typeof t.getTime},r.dateTime2ms=function(t,e){if(r.isJSDate(t)){var a=t.getTimezoneOffset()*p,o=(t.getUTCMinutes()-t.getMinutes())*p+(t.getUTCSeconds()-t.getSeconds())*d+(t.getUTCMilliseconds()-t.getMilliseconds());if(o){var s=3*p;a=a-s/2+l(o-a+s/2,s)}return(t=Number(t)-a)>=n&&t<=i?t:u}if(\"string\"!=typeof t&&\"number\"!=typeof t)return u;t=String(t);var c=_(e),m=t.charAt(0);!c||\"G\"!==m&&\"g\"!==m||(t=t.substr(1),e=\"\");var w=c&&\"chinese\"===e.substr(0,7),k=t.match(w?x:y);if(!k)return u;var T=k[1],A=k[3]||\"1\",M=Number(k[5]||1),S=Number(k[7]||0),E=Number(k[9]||0),C=Number(k[11]||0);if(c){if(2===T.length)return u;var L;T=Number(T);try{var P=v.getComponentMethod(\"calendars\",\"getCal\")(e);if(w){var O=\"i\"===A.charAt(A.length-1);A=parseInt(A,10),L=P.newDate(T,P.toMonthIndex(T,A,O),M)}else L=P.newDate(T,Number(A),M)}catch(t){return u}return L?(L.toJD()-g)*h+S*f+E*p+C*d:u}T=2===T.length?(Number(T)+2e3-b)%100+b:Number(T),A-=1;var z=new Date(Date.UTC(2e3,A,M,S,E));return z.setUTCFullYear(T),z.getUTCMonth()!==A?u:z.getUTCDate()!==M?u:z.getTime()+C*d},n=r.MIN_MS=r.dateTime2ms(\"-9999\"),i=r.MAX_MS=r.dateTime2ms(\"9999-12-31 23:59:59.9999\"),r.isDateTime=function(t,e){return r.dateTime2ms(t,e)!==u};var k=90*h,T=3*f,A=5*p;function M(t,e,r,n,i){if((e||r||n||i)&&(t+=\" \"+w(e,2)+\":\"+w(r,2),(n||i)&&(t+=\":\"+w(n,2),i))){for(var a=4;i%10==0;)a-=1,i/=10;t+=\".\"+w(i,a)}return t}r.ms2DateTime=function(t,e,r){if(\"number\"!=typeof t||!(t>=n&&t<=i))return u;e||(e=0);var a,o,s,c,y,x,b=Math.floor(10*l(t+.05,1)),w=Math.round(t-b/10);if(_(r)){var S=Math.floor(w/h)+g,E=Math.floor(l(t,h));try{a=v.getComponentMethod(\"calendars\",\"getCal\")(r).fromJD(S).formatDate(\"yyyy-mm-dd\")}catch(t){a=m(\"G%Y-%m-%d\")(new Date(w))}if(\"-\"===a.charAt(0))for(;a.length<11;)a=\"-0\"+a.substr(1);else for(;a.length<10;)a=\"0\"+a;o=e<k?Math.floor(E/f):0,s=e<k?Math.floor(E%f/p):0,c=e<T?Math.floor(E%p/d):0,y=e<A?E%d*10+b:0}else x=new Date(w),a=m(\"%Y-%m-%d\")(x),o=e<k?x.getUTCHours():0,s=e<k?x.getUTCMinutes():0,c=e<T?x.getUTCSeconds():0,y=e<A?10*x.getUTCMilliseconds()+b:0;return M(a,o,s,c,y)},r.ms2DateTimeLocal=function(t){if(!(t>=n+h&&t<=i-h))return u;var e=Math.floor(10*l(t+.05,1)),r=new Date(Math.round(t-e/10));return M(a.time.format(\"%Y-%m-%d\")(r),r.getHours(),r.getMinutes(),r.getSeconds(),10*r.getUTCMilliseconds()+e)},r.cleanDate=function(t,e,n){if(t===u)return e;if(r.isJSDate(t)||\"number\"==typeof t&&isFinite(t)){if(_(n))return s.error(\"JS Dates and milliseconds are incompatible with world calendars\",t),e;if(!(t=r.ms2DateTimeLocal(+t))&&void 0!==e)return e}else if(!r.isDateTime(t,n))return s.error(\"unrecognized date\",t),e;return t};var S=/%\\d?f/g;function E(t,e,r,n){t=t.replace(S,function(t){var r=Math.min(+t.charAt(1)||6,6);return(e/1e3%1+2).toFixed(r).substr(2).replace(/0+$/,\"\")||\"0\"});var i=new Date(Math.floor(e+.05));if(_(n))try{t=v.getComponentMethod(\"calendars\",\"worldCalFmt\")(t,e,n)}catch(t){return\"Invalid\"}return r(t)(i)}var C=[59,59.9,59.99,59.999,59.9999];r.formatDate=function(t,e,r,n,i,a){if(i=_(i)&&i,!e)if(\"y\"===r)e=a.year;else if(\"m\"===r)e=a.month;else{if(\"d\"!==r)return function(t,e){var r=l(t+.05,h),n=w(Math.floor(r/f),2)+\":\"+w(l(Math.floor(r/p),60),2);if(\"M\"!==e){o(e)||(e=0);var i=(100+Math.min(l(t/d,60),C[e])).toFixed(e).substr(1);e>0&&(i=i.replace(/0+$/,\"\").replace(/[\\.]$/,\"\")),n+=\":\"+i}return n}(t,r)+\"\\n\"+E(a.dayMonthYear,t,n,i);e=a.dayMonth+\"\\n\"+a.year}return E(e,t,n,i)};var L=3*h;r.incrementMonth=function(t,e,r){r=_(r)&&r;var n=l(t,h);if(t=Math.round(t-n),r)try{var i=Math.round(t/h)+g,a=v.getComponentMethod(\"calendars\",\"getCal\")(r),o=a.fromJD(i);return e%12?a.add(o,e,\"m\"):a.add(o,e/12,\"y\"),(o.toJD()-g)*h+n}catch(e){s.error(\"invalid ms \"+t+\" in calendar \"+r)}var c=new Date(t+L);return c.setUTCMonth(c.getUTCMonth()+e)+n-L},r.findExactDates=function(t,e){for(var r,n,i=0,a=0,s=0,l=0,c=_(e)&&v.getComponentMethod(\"calendars\",\"getCal\")(e),u=0;u<t.length;u++)if(n=t[u],o(n)){if(!(n%h))if(c)try{1===(r=c.fromJD(n/h+g)).day()?1===r.month()?i++:a++:s++}catch(t){}else 1===(r=new Date(n)).getUTCDate()?0===r.getUTCMonth()?i++:a++:s++}else l++;s+=a+=i;var f=t.length-l;return{exactYears:i/f,exactMonths:a/f,exactDays:s/f}}},{\"../constants/numerical\":695,\"../registry\":847,\"./loggers\":723,\"./mod\":726,d3:163,\"fast-isnumeric\":225}],708:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./loggers\");function a(t){var e=t&&t.parentNode;e&&e.removeChild(t)}function o(t,e,r){var n=\"plotly.js-style-\"+t,a=document.getElementById(n);a||((a=document.createElement(\"style\")).setAttribute(\"id\",n),a.appendChild(document.createTextNode(\"\")),document.head.appendChild(a));var o=a.sheet;o.insertRule?o.insertRule(e+\"{\"+r+\"}\",0):o.addRule?o.addRule(e,r,0):i.warn(\"addStyleRule failed\")}e.exports={getGraphDiv:function(t){var e;if(\"string\"==typeof t){if(null===(e=document.getElementById(t)))throw new Error(\"No DOM element with id '\"+t+\"' exists on the page.\");return e}if(null==t)throw new Error(\"DOM element provided is null or undefined\");return t},isPlotDiv:function(t){var e=n.select(t);return e.node()instanceof HTMLElement&&e.size()&&e.classed(\"js-plotly-plot\")},removeElement:a,addStyleRule:function(t,e){o(\"global\",t,e)},addRelatedStyleRule:o,deleteRelatedStyleRule:function(t){var e=\"plotly.js-style-\"+t,r=document.getElementById(e);r&&a(r)}}},{\"./loggers\":723,d3:163}],709:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i={init:function(t){if(t._ev instanceof n)return t;var e=new n,r=new n;return t._ev=e,t._internalEv=r,t.on=e.on.bind(e),t.once=e.once.bind(e),t.removeListener=e.removeListener.bind(e),t.removeAllListeners=e.removeAllListeners.bind(e),t._internalOn=r.on.bind(r),t._internalOnce=r.once.bind(r),t._removeInternalListener=r.removeListener.bind(r),t._removeAllInternalListeners=r.removeAllListeners.bind(r),t.emit=function(n,i){\"undefined\"!=typeof jQuery&&jQuery(t).trigger(n,i),e.emit(n,i),r.emit(n,i)},t},triggerHandler:function(t,e,r){var n,i;\"undefined\"!=typeof jQuery&&(n=jQuery(t).triggerHandler(e,r));var a=t._ev;if(!a)return n;var o,s=a._events[e];if(!s)return n;function l(t){return t.listener?(a.removeListener(e,t.listener),t.fired?void 0:(t.fired=!0,t.listener.apply(a,[r]))):t.apply(a,[r])}for(s=Array.isArray(s)?s:[s],o=0;o<s.length-1;o++)l(s[o]);return i=l(s[o]),void 0!==n?n:i},purge:function(t){return delete t._ev,delete t.on,delete t.once,delete t.removeListener,delete t.removeAllListeners,delete t.emit,delete t._ev,delete t._internalEv,delete t._internalOn,delete t._internalOnce,delete t._removeInternalListener,delete t._removeAllInternalListeners,t}};e.exports=i},{events:104}],710:[function(t,e,r){\"use strict\";var n=t(\"./is_plain_object.js\"),i=Array.isArray;function a(t,e,r,o){var s,l,c,u,h,f,p=t[0],d=t.length;if(2===d&&i(p)&&i(t[1])&&0===p.length){if(function(t,e){var r,n;for(r=0;r<t.length;r++){if(null!==(n=t[r])&&\"object\"==typeof n)return!1;void 0!==n&&(e[r]=n)}return!0}(t[1],p))return p;p.splice(0,p.length)}for(var g=1;g<d;g++)for(l in s=t[g])c=p[l],u=s[l],o&&i(u)?p[l]=u:e&&u&&(n(u)||(h=i(u)))?(h?(h=!1,f=c&&i(c)?c:[]):f=c&&n(c)?c:{},p[l]=a([f,u],e,r,o)):(\"undefined\"!=typeof u||r)&&(p[l]=u);return p}r.extendFlat=function(){return a(arguments,!1,!1,!1)},r.extendDeep=function(){return a(arguments,!0,!1,!1)},r.extendDeepAll=function(){return a(arguments,!0,!0,!1)},r.extendDeepNoArrays=function(){return a(arguments,!0,!1,!0)}},{\"./is_plain_object.js\":720}],711:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e={},r=[],n=0,i=0;i<t.length;i++){var a=t[i];1!==e[a]&&(e[a]=1,r[n++]=a)}return r}},{}],712:[function(t,e,r){\"use strict\";function n(t){return!0===t.visible}function i(t){var e=t[0].trace;return!0===e.visible&&0!==e._length}e.exports=function(t){for(var e,r=(e=t,Array.isArray(e)&&Array.isArray(e[0])&&e[0][0]&&e[0][0].trace?i:n),a=[],o=0;o<t.length;o++){var s=t[o];r(s)&&a.push(s)}return a}},{}],713:[function(t,e,r){\"use strict\";var n=t(\"country-regex\"),i=t(\"../lib\"),a=Object.keys(n),o={\"ISO-3\":i.identity,\"USA-states\":i.identity,\"country names\":function(t){for(var e=0;e<a.length;e++){var r=a[e],o=new RegExp(n[r]);if(o.test(t.trim().toLowerCase()))return r}return i.log(\"Unrecognized country name: \"+t+\".\"),!1}};e.exports={locationToFeature:function(t,e,r){if(!e||\"string\"!=typeof e)return!1;var n,a,s,l=o[t](e);if(l){if(\"USA-states\"===t)for(n=[],s=0;s<r.length;s++)(a=r[s]).properties&&a.properties.gu&&\"USA\"===a.properties.gu&&n.push(a);else n=r;for(s=0;s<n.length;s++)if((a=n[s]).id===l)return a;i.log([\"Location with id\",l,\"does not have a matching topojson feature at this resolution.\"].join(\" \"))}return!1}}},{\"../lib\":719,\"country-regex\":134}],714:[function(t,e,r){\"use strict\";var n=t(\"../constants/numerical\").BADNUM;r.calcTraceToLineCoords=function(t){for(var e=t[0].trace.connectgaps,r=[],i=[],a=0;a<t.length;a++){var o=t[a].lonlat;o[0]!==n?i.push(o):!e&&i.length>0&&(r.push(i),i=[])}return i.length>0&&r.push(i),r},r.makeLine=function(t){return 1===t.length?{type:\"LineString\",coordinates:t[0]}:{type:\"MultiLineString\",coordinates:t}},r.makePolygon=function(t){if(1===t.length)return{type:\"Polygon\",coordinates:t};for(var e=new Array(t.length),r=0;r<t.length;r++)e[r]=[t[r]];return{type:\"MultiPolygon\",coordinates:e}},r.makeBlank=function(){return{type:\"Point\",coordinates:[]}}},{\"../constants/numerical\":695}],715:[function(t,e,r){\"use strict\";var n,i,a,o=t(\"./mod\").mod;function s(t,e,r,n,i,a,o,s){var l=r-t,c=i-t,u=o-i,h=n-e,f=a-e,p=s-a,d=l*p-u*h;if(0===d)return null;var g=(c*p-u*f)/d,v=(c*h-l*f)/d;return v<0||v>1||g<0||g>1?null:{x:t+l*g,y:e+h*g}}function l(t,e,r,n,i){var a=n*t+i*e;if(a<0)return n*n+i*i;if(a>r){var o=n-t,s=i-e;return o*o+s*s}var l=n*e-i*t;return l*l/r}r.segmentsIntersect=s,r.segmentDistance=function(t,e,r,n,i,a,o,c){if(s(t,e,r,n,i,a,o,c))return 0;var u=r-t,h=n-e,f=o-i,p=c-a,d=u*u+h*h,g=f*f+p*p,v=Math.min(l(u,h,d,i-t,a-e),l(u,h,d,o-t,c-e),l(f,p,g,t-i,e-a),l(f,p,g,r-i,n-a));return Math.sqrt(v)},r.getTextLocation=function(t,e,r,s){if(t===i&&s===a||(n={},i=t,a=s),n[r])return n[r];var l=t.getPointAtLength(o(r-s/2,e)),c=t.getPointAtLength(o(r+s/2,e)),u=Math.atan((c.y-l.y)/(c.x-l.x)),h=t.getPointAtLength(o(r,e)),f={x:(4*h.x+l.x+c.x)/6,y:(4*h.y+l.y+c.y)/6,theta:u};return n[r]=f,f},r.clearLocationCache=function(){i=null},r.getVisibleSegment=function(t,e,r){var n,i,a=e.left,o=e.right,s=e.top,l=e.bottom,c=0,u=t.getTotalLength(),h=u;function f(e){var r=t.getPointAtLength(e);0===e?n=r:e===u&&(i=r);var c=r.x<a?a-r.x:r.x>o?r.x-o:0,h=r.y<s?s-r.y:r.y>l?r.y-l:0;return Math.sqrt(c*c+h*h)}for(var p=f(c);p;){if((c+=p+r)>h)return;p=f(c)}for(p=f(h);p;){if(c>(h-=p+r))return;p=f(h)}return{min:c,max:h,len:h-c,total:u,isClosed:0===c&&h===u&&Math.abs(n.x-i.x)<.1&&Math.abs(n.y-i.y)<.1}},r.findPointOnPath=function(t,e,r,n){for(var i,a,o,s=(n=n||{}).pathLength||t.getTotalLength(),l=n.tolerance||.001,c=n.iterationLimit||30,u=t.getPointAtLength(0)[r]>t.getPointAtLength(s)[r]?-1:1,h=0,f=0,p=s;h<c;){if(i=(f+p)/2,o=(a=t.getPointAtLength(i))[r]-e,Math.abs(o)<l)return a;u*o>0?p=i:f=i,h++}return a}},{\"./mod\":726}],716:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"color-normalize\"),o=t(\"../components/colorscale\"),s=t(\"../components/color/attributes\").defaultLine,l=t(\"./array\").isArrayOrTypedArray,c=a(s),u=1;function h(t,e){var r=t;return r[3]*=e,r}function f(t){if(n(t))return c;var e=a(t);return e.length?e:c}function p(t){return n(t)?t:u}e.exports={formatColor:function(t,e,r){var n,i,s,d,g,v=t.color,m=l(v),y=l(e),x=o.extractOpts(t),b=[];if(n=void 0!==x.colorscale?o.makeColorScaleFuncFromTrace(t):f,i=m?function(t,e){return void 0===t[e]?c:a(n(t[e]))}:f,s=y?function(t,e){return void 0===t[e]?u:p(t[e])}:p,m||y)for(var _=0;_<r;_++)d=i(v,_),g=s(e,_),b[_]=h(d,g);else b=h(a(v),e);return b},parseColorScale:function(t,e){void 0===e&&(e=1);var r=o.extractOpts(t);return(r.reversescale?o.flipScale(r.colorscale):r.colorscale).map(function(t){var r=t[0],n=i(t[1]).toRgb();return{index:r,rgb:[n.r,n.g,n.b,e]}})}}},{\"../components/color/attributes\":592,\"../components/colorscale\":605,\"./array\":702,\"color-normalize\":120,\"fast-isnumeric\":225,tinycolor2:537}],717:[function(t,e,r){\"use strict\";var n=t(\"./identity\");function i(t){return[t]}e.exports={keyFun:function(t){return t.key},repeat:i,descend:n,wrap:i,unwrap:function(t){return t[0]}}},{\"./identity\":718}],718:[function(t,e,r){\"use strict\";e.exports=function(t){return t}},{}],719:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../constants/numerical\"),o=a.FP_SAFE,s=a.BADNUM,l=e.exports={};l.nestedProperty=t(\"./nested_property\"),l.keyedContainer=t(\"./keyed_container\"),l.relativeAttr=t(\"./relative_attr\"),l.isPlainObject=t(\"./is_plain_object\"),l.toLogRange=t(\"./to_log_range\"),l.relinkPrivateKeys=t(\"./relink_private\");var c=t(\"./array\");l.isTypedArray=c.isTypedArray,l.isArrayOrTypedArray=c.isArrayOrTypedArray,l.isArray1D=c.isArray1D,l.ensureArray=c.ensureArray,l.concat=c.concat,l.maxRowLength=c.maxRowLength,l.minRowLength=c.minRowLength;var u=t(\"./mod\");l.mod=u.mod,l.modHalf=u.modHalf;var h=t(\"./coerce\");l.valObjectMeta=h.valObjectMeta,l.coerce=h.coerce,l.coerce2=h.coerce2,l.coerceFont=h.coerceFont,l.coerceHoverinfo=h.coerceHoverinfo,l.coerceSelectionMarkerOpacity=h.coerceSelectionMarkerOpacity,l.validate=h.validate;var f=t(\"./dates\");l.dateTime2ms=f.dateTime2ms,l.isDateTime=f.isDateTime,l.ms2DateTime=f.ms2DateTime,l.ms2DateTimeLocal=f.ms2DateTimeLocal,l.cleanDate=f.cleanDate,l.isJSDate=f.isJSDate,l.formatDate=f.formatDate,l.incrementMonth=f.incrementMonth,l.dateTick0=f.dateTick0,l.dfltRange=f.dfltRange,l.findExactDates=f.findExactDates,l.MIN_MS=f.MIN_MS,l.MAX_MS=f.MAX_MS;var p=t(\"./search\");l.findBin=p.findBin,l.sorterAsc=p.sorterAsc,l.sorterDes=p.sorterDes,l.distinctVals=p.distinctVals,l.roundUp=p.roundUp,l.sort=p.sort,l.findIndexOfMin=p.findIndexOfMin;var d=t(\"./stats\");l.aggNums=d.aggNums,l.len=d.len,l.mean=d.mean,l.median=d.median,l.midRange=d.midRange,l.variance=d.variance,l.stdev=d.stdev,l.interp=d.interp;var g=t(\"./matrix\");l.init2dArray=g.init2dArray,l.transposeRagged=g.transposeRagged,l.dot=g.dot,l.translationMatrix=g.translationMatrix,l.rotationMatrix=g.rotationMatrix,l.rotationXYMatrix=g.rotationXYMatrix,l.apply2DTransform=g.apply2DTransform,l.apply2DTransform2=g.apply2DTransform2;var v=t(\"./angles\");l.deg2rad=v.deg2rad,l.rad2deg=v.rad2deg,l.angleDelta=v.angleDelta,l.angleDist=v.angleDist,l.isFullCircle=v.isFullCircle,l.isAngleInsideSector=v.isAngleInsideSector,l.isPtInsideSector=v.isPtInsideSector,l.pathArc=v.pathArc,l.pathSector=v.pathSector,l.pathAnnulus=v.pathAnnulus;var m=t(\"./anchor_utils\");l.isLeftAnchor=m.isLeftAnchor,l.isCenterAnchor=m.isCenterAnchor,l.isRightAnchor=m.isRightAnchor,l.isTopAnchor=m.isTopAnchor,l.isMiddleAnchor=m.isMiddleAnchor,l.isBottomAnchor=m.isBottomAnchor;var y=t(\"./geometry2d\");l.segmentsIntersect=y.segmentsIntersect,l.segmentDistance=y.segmentDistance,l.getTextLocation=y.getTextLocation,l.clearLocationCache=y.clearLocationCache,l.getVisibleSegment=y.getVisibleSegment,l.findPointOnPath=y.findPointOnPath;var x=t(\"./extend\");l.extendFlat=x.extendFlat,l.extendDeep=x.extendDeep,l.extendDeepAll=x.extendDeepAll,l.extendDeepNoArrays=x.extendDeepNoArrays;var b=t(\"./loggers\");l.log=b.log,l.warn=b.warn,l.error=b.error;var _=t(\"./regex\");l.counterRegex=_.counter;var w=t(\"./throttle\");l.throttle=w.throttle,l.throttleDone=w.done,l.clearThrottle=w.clear;var k=t(\"./dom\");function T(t){var e={};for(var r in t)for(var n=t[r],i=0;i<n.length;i++)e[n[i]]=+r;return e}l.getGraphDiv=k.getGraphDiv,l.isPlotDiv=k.isPlotDiv,l.removeElement=k.removeElement,l.addStyleRule=k.addStyleRule,l.addRelatedStyleRule=k.addRelatedStyleRule,l.deleteRelatedStyleRule=k.deleteRelatedStyleRule,l.clearResponsive=t(\"./clear_responsive\"),l.makeTraceGroups=t(\"./make_trace_groups\"),l._=t(\"./localize\"),l.notifier=t(\"./notifier\"),l.filterUnique=t(\"./filter_unique\"),l.filterVisible=t(\"./filter_visible\"),l.pushUnique=t(\"./push_unique\"),l.cleanNumber=t(\"./clean_number\"),l.ensureNumber=function(t){return i(t)?(t=Number(t))<-o||t>o?s:i(t)?Number(t):s:s},l.isIndex=function(t,e){return!(void 0!==e&&t>=e)&&(i(t)&&t>=0&&t%1==0)},l.noop=t(\"./noop\"),l.identity=t(\"./identity\"),l.repeat=function(t,e){for(var r=new Array(e),n=0;n<e;n++)r[n]=t;return r},l.swapAttrs=function(t,e,r,n){r||(r=\"x\"),n||(n=\"y\");for(var i=0;i<e.length;i++){var a=e[i],o=l.nestedProperty(t,a.replace(\"?\",r)),s=l.nestedProperty(t,a.replace(\"?\",n)),c=o.get();o.set(s.get()),s.set(c)}},l.raiseToTop=function(t){t.parentNode.appendChild(t)},l.cancelTransition=function(t){return t.transition().duration(0)},l.constrain=function(t,e,r){return e>r?Math.max(r,Math.min(e,t)):Math.max(e,Math.min(r,t))},l.bBoxIntersect=function(t,e,r){return r=r||0,t.left<=e.right+r&&e.left<=t.right+r&&t.top<=e.bottom+r&&e.top<=t.bottom+r},l.simpleMap=function(t,e,r,n){for(var i=t.length,a=new Array(i),o=0;o<i;o++)a[o]=e(t[o],r,n);return a},l.randstr=function t(e,r,n,i){if(n||(n=16),void 0===r&&(r=24),r<=0)return\"0\";var a,o,s=Math.log(Math.pow(2,r))/Math.log(n),c=\"\";for(a=2;s===1/0;a*=2)s=Math.log(Math.pow(2,r/a))/Math.log(n)*a;var u=s-Math.floor(s);for(a=0;a<Math.floor(s);a++)c=Math.floor(Math.random()*n).toString(n)+c;u&&(o=Math.pow(n,u),c=Math.floor(Math.random()*o).toString(n)+c);var h=parseInt(c,n);return e&&e[c]||h!==1/0&&h>=Math.pow(2,r)?i>10?(l.warn(\"randstr failed uniqueness\"),c):t(e,r,n,(i||0)+1):c},l.OptionControl=function(t,e){t||(t={}),e||(e=\"opt\");var r={optionList:[],_newoption:function(n){n[e]=t,r[n.name]=n,r.optionList.push(n)}};return r[\"_\"+e]=t,r},l.smooth=function(t,e){if((e=Math.round(e)||0)<2)return t;var r,n,i,a,o=t.length,s=2*o,l=2*e-1,c=new Array(l),u=new Array(o);for(r=0;r<l;r++)c[r]=(1-Math.cos(Math.PI*(r+1)/e))/(2*e);for(r=0;r<o;r++){for(a=0,n=0;n<l;n++)(i=r+n+1-e)<-o?i-=s*Math.round(i/s):i>=s&&(i-=s*Math.floor(i/s)),i<0?i=-1-i:i>=o&&(i=s-1-i),a+=t[i]*c[n];u[r]=a}return u},l.syncOrAsync=function(t,e,r){var n;function i(){return l.syncOrAsync(t,e,r)}for(;t.length;)if((n=(0,t.splice(0,1)[0])(e))&&n.then)return n.then(i).then(void 0,l.promiseError);return r&&r(e)},l.stripTrailingSlash=function(t){return\"/\"===t.substr(-1)?t.substr(0,t.length-1):t},l.noneOrAll=function(t,e,r){if(t){var n,i=!1,a=!0;for(n=0;n<r.length;n++)null!=t[r[n]]?i=!0:a=!1;if(i&&!a)for(n=0;n<r.length;n++)t[r[n]]=e[r[n]]}},l.mergeArray=function(t,e,r,n){var i=\"function\"==typeof n;if(l.isArrayOrTypedArray(t))for(var a=Math.min(t.length,e.length),o=0;o<a;o++){var s=t[o];e[o][r]=i?n(s):s}},l.mergeArrayCastPositive=function(t,e,r){return l.mergeArray(t,e,r,function(t){var e=+t;return isFinite(e)&&e>0?e:0})},l.fillArray=function(t,e,r,n){if(n=n||l.identity,l.isArrayOrTypedArray(t))for(var i=0;i<e.length;i++)e[i][r]=n(t[i])},l.castOption=function(t,e,r,n){n=n||l.identity;var i=l.nestedProperty(t,r).get();return l.isArrayOrTypedArray(i)?Array.isArray(e)&&l.isArrayOrTypedArray(i[e[0]])?n(i[e[0]][e[1]]):n(i[e]):i},l.extractOption=function(t,e,r,n){if(r in t)return t[r];var i=l.nestedProperty(e,n).get();return Array.isArray(i)?void 0:i},l.tagSelected=function(t,e,r){var n,i,a=e.selectedpoints,o=e._indexToPoints;o&&(n=T(o));for(var s=0;s<a.length;s++){var c=a[s];if(l.isIndex(c)){var u=n?n[c]:c,h=r?r[u]:u;void 0!==(i=h)&&i<t.length&&(t[h].selected=1)}}},l.selIndices2selPoints=function(t){var e=t.selectedpoints,r=t._indexToPoints;if(r){for(var n=T(r),i=[],a=0;a<e.length;a++){var o=e[a];if(l.isIndex(o)){var s=n[o];l.isIndex(s)&&i.push(s)}}return i}return e},l.getTargetArray=function(t,e){var r=e.target;if(\"string\"==typeof r&&r){var n=l.nestedProperty(t,r).get();return!!Array.isArray(n)&&n}return!!Array.isArray(r)&&r},l.minExtend=function(t,e){var r={};\"object\"!=typeof e&&(e={});var n,i,a,o=Object.keys(t);for(n=0;n<o.length;n++)a=t[i=o[n]],\"_\"!==i.charAt(0)&&\"function\"!=typeof a&&(\"module\"===i?r[i]=a:Array.isArray(a)?r[i]=\"colorscale\"===i?a.slice():a.slice(0,3):r[i]=a&&\"object\"==typeof a?l.minExtend(t[i],e[i]):a);for(o=Object.keys(e),n=0;n<o.length;n++)\"object\"==typeof(a=e[i=o[n]])&&i in r&&\"object\"==typeof r[i]||(r[i]=a);return r},l.titleCase=function(t){return t.charAt(0).toUpperCase()+t.substr(1)},l.containsAny=function(t,e){for(var r=0;r<e.length;r++)if(-1!==t.indexOf(e[r]))return!0;return!1},l.isIE=function(){return\"undefined\"!=typeof window.navigator.msSaveBlob};var A=/MSIE [1-9]\\./;l.isIE9orBelow=function(){return l.isIE()&&A.test(window.navigator.userAgent)};var M=/Version\\/[\\d\\.]+.*Safari/;l.isSafari=function(){return M.test(window.navigator.userAgent)},l.isD3Selection=function(t){return t&&\"function\"==typeof t.classed},l.ensureSingle=function(t,e,r,n){var i=t.select(e+(r?\".\"+r:\"\"));if(i.size())return i;var a=t.append(e);return r&&a.classed(r,!0),n&&a.call(n),a},l.ensureSingleById=function(t,e,r,n){var i=t.select(e+\"#\"+r);if(i.size())return i;var a=t.append(e).attr(\"id\",r);return n&&a.call(n),a},l.objectFromPath=function(t,e){for(var r,n=t.split(\".\"),i=r={},a=0;a<n.length;a++){var o=n[a],s=null,l=n[a].match(/(.*)\\[([0-9]+)\\]/);l?(o=l[1],s=l[2],r=r[o]=[],a===n.length-1?r[s]=e:r[s]={},r=r[s]):(a===n.length-1?r[o]=e:r[o]={},r=r[o])}return i};var S=/^([^\\[\\.]+)\\.(.+)?/,E=/^([^\\.]+)\\[([0-9]+)\\](\\.)?(.+)?/;l.expandObjectPaths=function(t){var e,r,n,i,a,o,s;if(\"object\"==typeof t&&!Array.isArray(t))for(r in t)t.hasOwnProperty(r)&&((e=r.match(S))?(i=t[r],n=e[1],delete t[r],t[n]=l.extendDeepNoArrays(t[n]||{},l.objectFromPath(r,l.expandObjectPaths(i))[n])):(e=r.match(E))?(i=t[r],n=e[1],a=parseInt(e[2]),delete t[r],t[n]=t[n]||[],\".\"===e[3]?(s=e[4],o=t[n][a]=t[n][a]||{},l.extendDeepNoArrays(o,l.objectFromPath(s,l.expandObjectPaths(i)))):t[n][a]=l.expandObjectPaths(i)):t[r]=l.expandObjectPaths(t[r]));return t},l.numSeparate=function(t,e,r){if(r||(r=!1),\"string\"!=typeof e||0===e.length)throw new Error(\"Separator string required for formatting!\");\"number\"==typeof t&&(t=String(t));var n=/(\\d+)(\\d{3})/,i=e.charAt(0),a=e.charAt(1),o=t.split(\".\"),s=o[0],l=o.length>1?i+o[1]:\"\";if(a&&(o.length>1||s.length>4||r))for(;n.test(s);)s=s.replace(n,\"$1\"+a+\"$2\");return s+l},l.TEMPLATE_STRING_REGEX=/%{([^\\s%{}:]*)(:[^}]*)?}/g;var C=/^\\w*$/;l.templateString=function(t,e){var r={};return t.replace(l.TEMPLATE_STRING_REGEX,function(t,n){return C.test(n)?e[n]||\"\":(r[n]=r[n]||l.nestedProperty(e,n).get,r[n]()||\"\")})};var L=/^:/,P=0;l.hovertemplateString=function(t,e,r){var i=arguments,a={};return t.replace(l.TEMPLATE_STRING_REGEX,function(t,o,s){var c,u,h;for(h=3;h<i.length;h++){if((c=i[h]).hasOwnProperty(o)){u=c[o];break}if(C.test(o)||(u=a[o]||l.nestedProperty(c,o).get())&&(a[o]=u),void 0!==u)break}(void 0===u&&(P<10&&(l.warn(\"Variable '\"+o+\"' in hovertemplate could not be found!\"),u=t),10===P&&l.warn(\"Too many hovertemplate warnings - additional warnings will be suppressed\"),P++),s)?u=(r?r.numberFormat:n.format)(s.replace(L,\"\"))(u):e.hasOwnProperty(o+\"Label\")&&(u=e[o+\"Label\"]);return u})};l.subplotSort=function(t,e){for(var r=Math.min(t.length,e.length)+1,n=0,i=0,a=0;a<r;a++){var o=t.charCodeAt(a)||0,s=e.charCodeAt(a)||0,l=o>=48&&o<=57,c=s>=48&&s<=57;if(l&&(n=10*n+o-48),c&&(i=10*i+s-48),!l||!c){if(n!==i)return n-i;if(o!==s)return o-s}}return i-n};var O=2e9;l.seedPseudoRandom=function(){O=2e9},l.pseudoRandom=function(){var t=O;return O=(69069*O+1)%4294967296,Math.abs(O-t)<429496729?l.pseudoRandom():O/4294967296},l.fillText=function(t,e,r){var n=Array.isArray(r)?function(t){r.push(t)}:function(t){r.text=t},i=l.extractOption(t,e,\"htx\",\"hovertext\");if(l.isValidTextValue(i))return n(i);var a=l.extractOption(t,e,\"tx\",\"text\");return l.isValidTextValue(a)?n(a):void 0},l.isValidTextValue=function(t){return t||0===t},l.formatPercent=function(t,e){e=e||0;for(var r=(Math.round(100*t*Math.pow(10,e))*Math.pow(.1,e)).toFixed(e)+\"%\",n=0;n<e;n++)-1!==r.indexOf(\".\")&&(r=(r=r.replace(\"0%\",\"%\")).replace(\".%\",\"%\"));return r},l.isHidden=function(t){var e=window.getComputedStyle(t).display;return!e||\"none\"===e}},{\"../constants/numerical\":695,\"./anchor_utils\":700,\"./angles\":701,\"./array\":702,\"./clean_number\":703,\"./clear_responsive\":705,\"./coerce\":706,\"./dates\":707,\"./dom\":708,\"./extend\":710,\"./filter_unique\":711,\"./filter_visible\":712,\"./geometry2d\":715,\"./identity\":718,\"./is_plain_object\":720,\"./keyed_container\":721,\"./localize\":722,\"./loggers\":723,\"./make_trace_groups\":724,\"./matrix\":725,\"./mod\":726,\"./nested_property\":727,\"./noop\":728,\"./notifier\":729,\"./push_unique\":733,\"./regex\":735,\"./relative_attr\":736,\"./relink_private\":737,\"./search\":738,\"./stats\":741,\"./throttle\":744,\"./to_log_range\":745,d3:163,\"fast-isnumeric\":225}],720:[function(t,e,r){\"use strict\";e.exports=function(t){return window&&window.process&&window.process.versions?\"[object Object]\"===Object.prototype.toString.call(t):\"[object Object]\"===Object.prototype.toString.call(t)&&Object.getPrototypeOf(t)===Object.prototype}},{}],721:[function(t,e,r){\"use strict\";var n=t(\"./nested_property\"),i=/^\\w*$/;e.exports=function(t,e,r,a){var o,s,l;r=r||\"name\",a=a||\"value\";var c={};e&&e.length?(l=n(t,e),s=l.get()):s=t,e=e||\"\";var u={};if(s)for(o=0;o<s.length;o++)u[s[o][r]]=o;var h=i.test(a),f={set:function(t,e){var i=null===e?4:0;if(!s){if(!l||4===i)return;s=[],l.set(s)}var o=u[t];if(void 0===o){if(4===i)return;i|=3,o=s.length,u[t]=o}else e!==(h?s[o][a]:n(s[o],a).get())&&(i|=2);var p=s[o]=s[o]||{};return p[r]=t,h?p[a]=e:n(p,a).set(e),null!==e&&(i&=-5),c[o]=c[o]|i,f},get:function(t){if(s){var e=u[t];return void 0===e?void 0:h?s[e][a]:n(s[e],a).get()}},rename:function(t,e){var n=u[t];return void 0===n?f:(c[n]=1|c[n],u[e]=n,delete u[t],s[n][r]=e,f)},remove:function(t){var e=u[t];if(void 0===e)return f;var i=s[e];if(Object.keys(i).length>2)return c[e]=2|c[e],f.set(t,null);if(h){for(o=e;o<s.length;o++)c[o]=3|c[o];for(o=e;o<s.length;o++)u[s[o][r]]--;s.splice(e,1),delete u[t]}else n(i,a).set(null),c[e]=6|c[e];return f},constructUpdate:function(){for(var t,i,o={},l=Object.keys(c),u=0;u<l.length;u++)i=l[u],t=e+\"[\"+i+\"]\",s[i]?(1&c[i]&&(o[t+\".\"+r]=s[i][r]),2&c[i]&&(o[t+\".\"+a]=h?4&c[i]?null:s[i][a]:4&c[i]?null:n(s[i],a).get())):o[t]=null;return o}};return f}},{\"./nested_property\":727}],722:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t,e){for(var r=t._context.locale,i=0;i<2;i++){for(var a=t._context.locales,o=0;o<2;o++){var s=(a[r]||{}).dictionary;if(s){var l=s[e];if(l)return l}a=n.localeRegistry}var c=r.split(\"-\")[0];if(c===r)break;r=c}return e}},{\"../registry\":847}],723:[function(t,e,r){\"use strict\";var n=t(\"../plot_api/plot_config\").dfltConfig,i=e.exports={};function a(t,e){if(t&&t.apply)try{return void t.apply(console,e)}catch(t){}for(var r=0;r<e.length;r++)try{t(e[r])}catch(t){console.log(e[r])}}i.log=function(){if(n.logging>1){for(var t=[\"LOG:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.trace||console.log,t)}},i.warn=function(){if(n.logging>0){for(var t=[\"WARN:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.trace||console.log,t)}},i.error=function(){if(n.logging>0){for(var t=[\"ERROR:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.error,t)}}},{\"../plot_api/plot_config\":755}],724:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e,r){var i=t.selectAll(\"g.\"+r.replace(/\\s/g,\".\")).data(e,function(t){return t[0].trace.uid});i.exit().remove(),i.enter().append(\"g\").attr(\"class\",r),i.order();var a=t.classed(\"rangeplot\")?\"nodeRangePlot3\":\"node3\";return i.each(function(t){t[0][a]=n.select(this)}),i}},{d3:163}],725:[function(t,e,r){\"use strict\";r.init2dArray=function(t,e){for(var r=new Array(t),n=0;n<t;n++)r[n]=new Array(e);return r},r.transposeRagged=function(t){var e,r,n=0,i=t.length;for(e=0;e<i;e++)n=Math.max(n,t[e].length);var a=new Array(n);for(e=0;e<n;e++)for(a[e]=new Array(i),r=0;r<i;r++)a[e][r]=t[r][e];return a},r.dot=function(t,e){if(!t.length||!e.length||t.length!==e.length)return null;var n,i,a=t.length;if(t[0].length)for(n=new Array(a),i=0;i<a;i++)n[i]=r.dot(t[i],e);else if(e[0].length){var o=r.transposeRagged(e);for(n=new Array(o.length),i=0;i<o.length;i++)n[i]=r.dot(t,o[i])}else for(n=0,i=0;i<a;i++)n+=t[i]*e[i];return n},r.translationMatrix=function(t,e){return[[1,0,t],[0,1,e],[0,0,1]]},r.rotationMatrix=function(t){var e=t*Math.PI/180;return[[Math.cos(e),-Math.sin(e),0],[Math.sin(e),Math.cos(e),0],[0,0,1]]},r.rotationXYMatrix=function(t,e,n){return r.dot(r.dot(r.translationMatrix(e,n),r.rotationMatrix(t)),r.translationMatrix(-e,-n))},r.apply2DTransform=function(t){return function(){var e=arguments;3===e.length&&(e=e[0]);var n=1===arguments.length?e[0]:[e[0],e[1]];return r.dot(t,[n[0],n[1],1]).slice(0,2)}},r.apply2DTransform2=function(t){var e=r.apply2DTransform(t);return function(t){return e(t.slice(0,2)).concat(e(t.slice(2,4)))}}},{}],726:[function(t,e,r){\"use strict\";e.exports={mod:function(t,e){var r=t%e;return r<0?r+e:r},modHalf:function(t,e){return Math.abs(t)>e/2?t-Math.round(t/e)*e:t}}},{}],727:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;e.exports=function(t,e){if(n(e))e=String(e);else if(\"string\"!=typeof e||\"[-1]\"===e.substr(e.length-4))throw\"bad property string\";for(var r,a,o,l=0,c=e.split(\".\");l<c.length;){if(r=String(c[l]).match(/^([^\\[\\]]*)((\\[\\-?[0-9]*\\])+)$/)){if(r[1])c[l]=r[1];else{if(0!==l)throw\"bad property string\";c.splice(0,1)}for(a=r[2].substr(1,r[2].length-2).split(\"][\"),o=0;o<a.length;o++)l++,c.splice(l,0,Number(a[o]))}l++}return\"object\"!=typeof t?function(t,e,r){return{set:function(){throw\"bad container\"},get:function(){},astr:e,parts:r,obj:t}}(t,e,c):{set:s(t,c,e),get:function t(e,r){return function(){var n,a,o,s,l,c=e;for(s=0;s<r.length-1;s++){if(-1===(n=r[s])){for(a=!0,o=[],l=0;l<c.length;l++)o[l]=t(c[l],r.slice(s+1))(),o[l]!==o[0]&&(a=!1);return a?o[0]:o}if(\"number\"==typeof n&&!i(c))return;if(\"object\"!=typeof(c=c[n])||null===c)return}if(\"object\"==typeof c&&null!==c&&null!==(o=c[r[s]]))return o}}(t,c),astr:e,parts:c,obj:t}};var a=/(^|\\.)args\\[/;function o(t,e){return void 0===t||null===t&&!e.match(a)}function s(t,e,r){return function(n){var a,s,h=t,f=\"\",p=[[t,f]],d=o(n,r);for(s=0;s<e.length-1;s++){if(\"number\"==typeof(a=e[s])&&!i(h))throw\"array index but container is not an array\";if(-1===a){if(d=!c(h,e.slice(s+1),n,r))break;return}if(!u(h,a,e[s+1],d))break;if(\"object\"!=typeof(h=h[a])||null===h)throw\"container is not an object\";f=l(f,a),p.push([h,f])}if(d){if(s===e.length-1&&(delete h[e[s]],Array.isArray(h)&&+e[s]==h.length-1))for(;h.length&&void 0===h[h.length-1];)h.pop()}else h[e[s]]=n}}function l(t,e){var r=e;return n(e)?r=\"[\"+e+\"]\":t&&(r=\".\"+e),t+r}function c(t,e,r,n){var a,l=i(r),c=!0,h=r,f=n.replace(\"-1\",0),p=!l&&o(r,f),d=e[0];for(a=0;a<t.length;a++)f=n.replace(\"-1\",a),l&&(p=o(h=r[a%r.length],f)),p&&(c=!1),u(t,a,d,p)&&s(t[a],e,n.replace(\"-1\",a))(h);return c}function u(t,e,r,n){if(void 0===t[e]){if(n)return!1;t[e]=\"number\"==typeof r?[]:{}}return!0}},{\"./array\":702,\"fast-isnumeric\":225}],728:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],729:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=[];e.exports=function(t,e){if(-1===a.indexOf(t)){a.push(t);var r=1e3;i(e)?r=e:\"long\"===e&&(r=3e3);var o=n.select(\"body\").selectAll(\".plotly-notifier\").data([0]);o.enter().append(\"div\").classed(\"plotly-notifier\",!0),o.selectAll(\".notifier-note\").data(a).enter().append(\"div\").classed(\"notifier-note\",!0).style(\"opacity\",0).each(function(t){var e=n.select(this);e.append(\"button\").classed(\"notifier-close\",!0).html(\"&times;\").on(\"click\",function(){e.transition().call(s)});for(var i=e.append(\"p\"),a=t.split(/<br\\s*\\/?>/g),o=0;o<a.length;o++)o&&i.append(\"br\"),i.append(\"span\").text(a[o]);e.transition().duration(700).style(\"opacity\",1).transition().delay(r).call(s)})}function s(t){t.duration(700).style(\"opacity\",0).each(\"end\",function(t){var e=a.indexOf(t);-1!==e&&a.splice(e,1),n.select(this).remove()})}}},{d3:163,\"fast-isnumeric\":225}],730:[function(t,e,r){\"use strict\";var n=t(\"./setcursor\"),i=\"data-savedcursor\";e.exports=function(t,e){var r=t.attr(i);if(e){if(!r){for(var a=(t.attr(\"class\")||\"\").split(\" \"),o=0;o<a.length;o++){var s=a[o];0===s.indexOf(\"cursor-\")&&t.attr(i,s.substr(7)).classed(s,!1)}t.attr(i)||t.attr(i,\"!!\")}n(t,e)}else r&&(t.attr(i,null),\"!!\"===r?n(t):n(t,r))}},{\"./setcursor\":739}],731:[function(t,e,r){\"use strict\";var n=t(\"./matrix\").dot,i=t(\"../constants/numerical\").BADNUM,a=e.exports={};a.tester=function(t){var e,r=t.slice(),n=r[0][0],a=n,o=r[0][1],s=o;for(r.push(r[0]),e=1;e<r.length;e++)n=Math.min(n,r[e][0]),a=Math.max(a,r[e][0]),o=Math.min(o,r[e][1]),s=Math.max(s,r[e][1]);var l,c=!1;5===r.length&&(r[0][0]===r[1][0]?r[2][0]===r[3][0]&&r[0][1]===r[3][1]&&r[1][1]===r[2][1]&&(c=!0,l=function(t){return t[0]===r[0][0]}):r[0][1]===r[1][1]&&r[2][1]===r[3][1]&&r[0][0]===r[3][0]&&r[1][0]===r[2][0]&&(c=!0,l=function(t){return t[1]===r[0][1]}));var u=!0,h=r[0];for(e=1;e<r.length;e++)if(h[0]!==r[e][0]||h[1]!==r[e][1]){u=!1;break}return{xmin:n,xmax:a,ymin:o,ymax:s,pts:r,contains:c?function(t,e){var r=t[0],c=t[1];return!(r===i||r<n||r>a||c===i||c<o||c>s||e&&l(t))}:function(t,e){var l=t[0],c=t[1];if(l===i||l<n||l>a||c===i||c<o||c>s)return!1;var u,h,f,p,d,g=r.length,v=r[0][0],m=r[0][1],y=0;for(u=1;u<g;u++)if(h=v,f=m,v=r[u][0],m=r[u][1],!(l<(p=Math.min(h,v))||l>Math.max(h,v)||c>Math.max(f,m)))if(c<Math.min(f,m))l!==p&&y++;else{if(c===(d=v===h?c:f+(l-h)*(m-f)/(v-h)))return 1!==u||!e;c<=d&&l!==p&&y++}return y%2==1},isRect:c,degenerate:u}},a.isSegmentBent=function(t,e,r,i){var a,o,s,l=t[e],c=[t[r][0]-l[0],t[r][1]-l[1]],u=n(c,c),h=Math.sqrt(u),f=[-c[1]/h,c[0]/h];for(a=e+1;a<r;a++)if(o=[t[a][0]-l[0],t[a][1]-l[1]],(s=n(o,c))<0||s>u||Math.abs(n(o,f))>i)return!0;return!1},a.filter=function(t,e){var r=[t[0]],n=0,i=0;function o(o){t.push(o);var s=r.length,l=n;r.splice(i+1);for(var c=l+1;c<t.length;c++)(c===t.length-1||a.isSegmentBent(t,l,c+1,e))&&(r.push(t[c]),r.length<s-2&&(n=c,i=r.length-1),l=c)}t.length>1&&o(t.pop());return{addPt:o,raw:t,filtered:r}}},{\"../constants/numerical\":695,\"./matrix\":725}],732:[function(t,e,r){(function(r){\"use strict\";var n=t(\"./show_no_webgl_msg\"),i=t(\"regl\");e.exports=function(t,e){var a=t._fullLayout,o=!0;return a._glcanvas.each(function(n){if(!n.regl&&(!n.pick||a._has(\"parcoords\"))){try{n.regl=i({canvas:this,attributes:{antialias:!n.pick,preserveDrawingBuffer:!0},pixelRatio:t._context.plotGlPixelRatio||r.devicePixelRatio,extensions:e||[]})}catch(t){o=!1}o&&this.addEventListener(\"webglcontextlost\",function(e){t&&t.emit&&t.emit(\"plotly_webglcontextlost\",{event:e,layer:n.key})},!1)}}),o||n({container:a._glcontainer.node()}),o}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./show_no_webgl_msg\":740,regl:502}],733:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(e instanceof RegExp){for(var r=e.toString(),n=0;n<t.length;n++)if(t[n]instanceof RegExp&&t[n].toString()===r)return t;t.push(e)}else!e&&0!==e||-1!==t.indexOf(e)||t.push(e);return t}},{}],734:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_config\").dfltConfig;var a={add:function(t,e,r,n,a){var o,s;t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},s=t.undoQueue.index,t.autoplay?t.undoQueue.inSequence||(t.autoplay=!1):(!t.undoQueue.sequence||t.undoQueue.beginSequence?(o={undo:{calls:[],args:[]},redo:{calls:[],args:[]}},t.undoQueue.queue.splice(s,t.undoQueue.queue.length-s,o),t.undoQueue.index+=1):o=t.undoQueue.queue[s-1],t.undoQueue.beginSequence=!1,o&&(o.undo.calls.unshift(e),o.undo.args.unshift(r),o.redo.calls.push(n),o.redo.args.push(a)),t.undoQueue.queue.length>i.queueLength&&(t.undoQueue.queue.shift(),t.undoQueue.index--))},startSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!0,t.undoQueue.beginSequence=!0},stopSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!1,t.undoQueue.beginSequence=!1},undo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.undo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index<=0)){for(t.undoQueue.index--,e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.undo.calls.length;r++)a.plotDo(t,e.undo.calls[r],e.undo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1}},redo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.redo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index>=t.undoQueue.queue.length)){for(e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.redo.calls.length;r++)a.plotDo(t,e.redo.calls[r],e.redo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1,t.undoQueue.index++}}};a.plotDo=function(t,e,r){t.autoplay=!0,r=function(t,e){for(var r,i=[],a=0;a<e.length;a++)r=e[a],i[a]=r===t?r:\"object\"==typeof r?Array.isArray(r)?n.extendDeep([],r):n.extendDeepAll({},r):r;return i}(t,r),e.apply(null,r)},e.exports=a},{\"../lib\":719,\"../plot_api/plot_config\":755}],735:[function(t,e,r){\"use strict\";r.counter=function(t,e,r,n){var i=(e||\"\")+(r?\"\":\"$\"),a=!1===n?\"\":\"^\";return\"xy\"===t?new RegExp(a+\"x([2-9]|[1-9][0-9]+)?y([2-9]|[1-9][0-9]+)?\"+i):new RegExp(a+t+\"([2-9]|[1-9][0-9]+)?\"+i)}},{}],736:[function(t,e,r){\"use strict\";var n=/^(.*)(\\.[^\\.\\[\\]]+|\\[\\d\\])$/,i=/^[^\\.\\[\\]]+$/;e.exports=function(t,e){for(;e;){var r=t.match(n);if(r)t=r[1];else{if(!t.match(i))throw new Error(\"bad relativeAttr call:\"+[t,e]);t=\"\"}if(\"^\"!==e.charAt(0))break;e=e.slice(1)}return t&&\"[\"!==e.charAt(0)?t+\".\"+e:t+e}},{}],737:[function(t,e,r){\"use strict\";var n=t(\"./array\").isArrayOrTypedArray,i=t(\"./is_plain_object\");e.exports=function t(e,r){for(var a in r){var o=r[a],s=e[a];if(s!==o)if(\"_\"===a.charAt(0)||\"function\"==typeof o){if(a in e)continue;e[a]=o}else if(n(o)&&n(s)&&i(o[0])){if(\"customdata\"===a||\"ids\"===a)continue;for(var l=Math.min(o.length,s.length),c=0;c<l;c++)s[c]!==o[c]&&i(o[c])&&i(s[c])&&t(s[c],o[c])}else i(o)&&i(s)&&(t(s,o),Object.keys(s).length||delete e[a])}}},{\"./array\":702,\"./is_plain_object\":720}],738:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./loggers\"),a=t(\"./identity\");function o(t,e){return t<e}function s(t,e){return t<=e}function l(t,e){return t>e}function c(t,e){return t>=e}r.findBin=function(t,e,r){if(n(e.start))return r?Math.ceil((t-e.start)/e.size-1e-9)-1:Math.floor((t-e.start)/e.size+1e-9);var a,u,h=0,f=e.length,p=0,d=f>1?(e[f-1]-e[0])/(f-1):1;for(u=d>=0?r?o:s:r?c:l,t+=1e-9*d*(r?-1:1)*(d>=0?1:-1);h<f&&p++<100;)u(e[a=Math.floor((h+f)/2)],t)?h=a+1:f=a;return p>90&&i.log(\"Long binary search...\"),h-1},r.sorterAsc=function(t,e){return t-e},r.sorterDes=function(t,e){return e-t},r.distinctVals=function(t){var e=t.slice();e.sort(r.sorterAsc);for(var n=e.length-1,i=e[n]-e[0]||1,a=i/(n||1)/1e4,o=[e[0]],s=0;s<n;s++)e[s+1]>e[s]+a&&(i=Math.min(i,e[s+1]-e[s]),o.push(e[s+1]));return{vals:o,minDiff:i}},r.roundUp=function(t,e,r){for(var n,i=0,a=e.length-1,o=0,s=r?0:1,l=r?1:0,c=r?Math.ceil:Math.floor;i<a&&o++<100;)e[n=c((i+a)/2)]<=t?i=n+s:a=n-l;return e[i]},r.sort=function(t,e){for(var r=0,n=0,i=1;i<t.length;i++){var a=e(t[i],t[i-1]);if(a<0?r=1:a>0&&(n=1),r&&n)return t.sort(e)}return n?t:t.reverse()},r.findIndexOfMin=function(t,e){e=e||a;for(var r,n=1/0,i=0;i<t.length;i++){var o=e(t[i]);o<n&&(n=o,r=i)}return r}},{\"./identity\":718,\"./loggers\":723,\"fast-isnumeric\":225}],739:[function(t,e,r){\"use strict\";e.exports=function(t,e){(t.attr(\"class\")||\"\").split(\" \").forEach(function(e){0===e.indexOf(\"cursor-\")&&t.classed(e,!1)}),e&&t.classed(\"cursor-\"+e,!0)}},{}],740:[function(t,e,r){\"use strict\";var n=t(\"../components/color\"),i=function(){};e.exports=function(t){for(var e in t)\"function\"==typeof t[e]&&(t[e]=i);t.destroy=function(){t.container.parentNode.removeChild(t.container)};var r=document.createElement(\"div\");r.className=\"no-webgl\",r.style.cursor=\"pointer\",r.style.fontSize=\"24px\",r.style.color=n.defaults[0],r.style.position=\"absolute\",r.style.left=r.style.top=\"0px\",r.style.width=r.style.height=\"100%\",r.style[\"background-color\"]=n.lightLine,r.style[\"z-index\"]=30;var a=document.createElement(\"p\");return a.textContent=\"WebGL is not supported by your browser - visit https://get.webgl.org for more info\",a.style.position=\"relative\",a.style.top=\"50%\",a.style.left=\"50%\",a.style.height=\"30%\",a.style.width=\"50%\",a.style.margin=\"-15% 0 0 -25%\",r.appendChild(a),t.container.appendChild(r),t.container.style.background=\"#FFFFFF\",t.container.onclick=function(){window.open(\"https://get.webgl.org\")},!1}},{\"../components/color\":593}],741:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;r.aggNums=function(t,e,a,o){var s,l;if((!o||o>a.length)&&(o=a.length),n(e)||(e=!1),i(a[0])){for(l=new Array(o),s=0;s<o;s++)l[s]=r.aggNums(t,e,a[s]);a=l}for(s=0;s<o;s++)n(e)?n(a[s])&&(e=t(+e,+a[s])):e=a[s];return e},r.len=function(t){return r.aggNums(function(t){return t+1},0,t)},r.mean=function(t,e){return e||(e=r.len(t)),r.aggNums(function(t,e){return t+e},0,t)/e},r.midRange=function(t){if(void 0!==t&&0!==t.length)return(r.aggNums(Math.max,null,t)+r.aggNums(Math.min,null,t))/2},r.variance=function(t,e,i){return e||(e=r.len(t)),n(i)||(i=r.mean(t,e)),r.aggNums(function(t,e){return t+Math.pow(e-i,2)},0,t)/e},r.stdev=function(t,e,n){return Math.sqrt(r.variance(t,e,n))},r.median=function(t){var e=t.slice().sort();return r.interp(e,.5)},r.interp=function(t,e){if(!n(e))throw\"n should be a finite number\";if((e=e*t.length-.5)<0)return t[0];if(e>t.length-1)return t[t.length-1];var r=e%1;return r*t[Math.ceil(e)]+(1-r)*t[Math.floor(e)]}},{\"./array\":702,\"fast-isnumeric\":225}],742:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\");e.exports=function(t){return t?n(t):[0,0,0,1]}},{\"color-normalize\":120}],743:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=t(\"../constants/xmlns_namespaces\"),o=t(\"../constants/alignment\").LINE_SPACING;function s(t,e){return t.node().getBoundingClientRect()[e]}var l=/([^$]*)([$]+[^$]*[$]+)([^$]*)/;r.convertToTspans=function(t,e,M){var S=t.text(),C=!t.attr(\"data-notex\")&&\"undefined\"!=typeof MathJax&&S.match(l),L=n.select(t.node().parentNode);if(!L.empty()){var P=t.attr(\"class\")?t.attr(\"class\").split(\" \")[0]:\"text\";return P+=\"-math\",L.selectAll(\"svg.\"+P).remove(),L.selectAll(\"g.\"+P+\"-group\").remove(),t.style(\"display\",null).attr({\"data-unformatted\":S,\"data-math\":\"N\"}),C?(e&&e._promises||[]).push(new Promise(function(e){t.style(\"display\",\"none\");var r=parseInt(t.node().style.fontSize,10),a={fontSize:r};!function(t,e,r){var a,o,s,l;MathJax.Hub.Queue(function(){return o=i.extendDeepAll({},MathJax.Hub.config),s=MathJax.Hub.processSectionDelay,void 0!==MathJax.Hub.processSectionDelay&&(MathJax.Hub.processSectionDelay=0),MathJax.Hub.Config({messageStyle:\"none\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]},displayAlign:\"left\"})},function(){if(\"SVG\"!==(a=MathJax.Hub.config.menuSettings.renderer))return MathJax.Hub.setRenderer(\"SVG\")},function(){var r=\"math-output-\"+i.randstr({},64);return l=n.select(\"body\").append(\"div\").attr({id:r}).style({visibility:\"hidden\",position:\"absolute\"}).style({\"font-size\":e.fontSize+\"px\"}).text(t.replace(c,\"\\\\lt \").replace(u,\"\\\\gt \")),MathJax.Hub.Typeset(l.node())},function(){var e=n.select(\"body\").select(\"#MathJax_SVG_glyphs\");if(l.select(\".MathJax_SVG\").empty()||!l.select(\"svg\").node())i.log(\"There was an error in the tex syntax.\",t),r();else{var o=l.select(\"svg\").node().getBoundingClientRect();r(l.select(\".MathJax_SVG\"),e,o)}if(l.remove(),\"SVG\"!==a)return MathJax.Hub.setRenderer(a)},function(){return void 0!==s&&(MathJax.Hub.processSectionDelay=s),MathJax.Hub.Config(o)})}(C[2],a,function(n,i,a){L.selectAll(\"svg.\"+P).remove(),L.selectAll(\"g.\"+P+\"-group\").remove();var o=n&&n.select(\"svg\");if(!o||!o.node())return O(),void e();var l=L.append(\"g\").classed(P+\"-group\",!0).attr({\"pointer-events\":\"none\",\"data-unformatted\":S,\"data-math\":\"Y\"});l.node().appendChild(o.node()),i&&i.node()&&o.node().insertBefore(i.node().cloneNode(!0),o.node().firstChild),o.attr({class:P,height:a.height,preserveAspectRatio:\"xMinYMin meet\"}).style({overflow:\"visible\",\"pointer-events\":\"none\"});var c=t.node().style.fill||\"black\",u=o.select(\"g\");u.attr({fill:c,stroke:c});var h=s(u,\"width\"),f=s(u,\"height\"),p=+t.attr(\"x\")-h*{start:0,middle:.5,end:1}[t.attr(\"text-anchor\")||\"start\"],d=-(r||s(t,\"height\"))/4;\"y\"===P[0]?(l.attr({transform:\"rotate(\"+[-90,+t.attr(\"x\"),+t.attr(\"y\")]+\") translate(\"+[-h/2,d-f/2]+\")\"}),o.attr({x:+t.attr(\"x\"),y:+t.attr(\"y\")})):\"l\"===P[0]?o.attr({x:t.attr(\"x\"),y:d-f/2}):\"a\"===P[0]&&0!==P.indexOf(\"atitle\")?o.attr({x:0,y:d}):o.attr({x:p,y:+t.attr(\"y\")+d-f/2}),M&&M.call(t,l),e(l)})})):O(),t}function O(){L.empty()||(P=t.attr(\"class\")+\"-math\",L.select(\"svg.\"+P).remove()),t.text(\"\").style(\"white-space\",\"pre\"),function(t,e){e=e.replace(v,\" \");var r,s=!1,l=[],c=-1;function u(){c++;var e=document.createElementNS(a.svg,\"tspan\");n.select(e).attr({class:\"line\",dy:c*o+\"em\"}),t.appendChild(e),r=e;var i=l;if(l=[{node:e}],i.length>1)for(var s=1;s<i.length;s++)M(i[s])}function M(t){var e,i=t.type,o={};if(\"a\"===i){e=\"a\";var s=t.target,c=t.href,u=t.popup;c&&(o={\"xlink:xlink:show\":\"_blank\"===s||\"_\"!==s.charAt(0)?\"new\":\"replace\",target:s,\"xlink:xlink:href\":c},u&&(o.onclick='window.open(this.href.baseVal,this.target.baseVal,\"'+u+'\");return false;'))}else e=\"tspan\";t.style&&(o.style=t.style);var h=document.createElementNS(a.svg,e);if(\"sup\"===i||\"sub\"===i){S(r,d),r.appendChild(h);var g=document.createElementNS(a.svg,\"tspan\");S(g,d),n.select(g).attr(\"dy\",p[i]),o.dy=f[i],r.appendChild(h),r.appendChild(g)}else r.appendChild(h);n.select(h).attr(o),r=t.node=h,l.push(t)}function S(t,e){t.appendChild(document.createTextNode(e))}function C(t){if(1!==l.length){var n=l.pop();t!==n.type&&i.log(\"Start tag <\"+n.type+\"> doesnt match end tag <\"+t+\">. Pretending it did match.\",e),r=l[l.length-1].node}else i.log(\"Ignoring unexpected end tag </\"+t+\">.\",e)}x.test(e)?u():(r=t,l=[{node:t}]);for(var L=e.split(m),P=0;P<L.length;P++){var O=L[P],z=O.match(y),I=z&&z[2].toLowerCase(),D=h[I];if(\"br\"===I)u();else if(void 0===D)S(r,E(O));else if(z[1])C(I);else{var R=z[4],F={type:I},B=T(R,b);if(B?(B=B.replace(A,\"$1 fill:\"),D&&(B+=\";\"+D)):D&&(B=D),B&&(F.style=B),\"a\"===I){s=!0;var N=T(R,_);if(N){var j=document.createElement(\"a\");j.href=N,-1!==g.indexOf(j.protocol)&&(F.href=encodeURI(decodeURI(N)),F.target=T(R,w)||\"_blank\",F.popup=T(R,k))}}M(F)}}return s}(t.node(),S)&&t.style(\"pointer-events\",\"all\"),r.positionText(t),M&&M.call(t)}};var c=/(<|&lt;|&#60;)/g,u=/(>|&gt;|&#62;)/g;var h={sup:\"font-size:70%\",sub:\"font-size:70%\",b:\"font-weight:bold\",i:\"font-style:italic\",a:\"cursor:pointer\",span:\"\",em:\"font-style:italic;font-weight:bold\"},f={sub:\"0.3em\",sup:\"-0.6em\"},p={sub:\"-0.21em\",sup:\"0.42em\"},d=\"\\u200b\",g=[\"http:\",\"https:\",\"mailto:\",\"\",void 0,\":\"],v=/(\\r\\n?|\\n)/g,m=/(<[^<>]*>)/,y=/<(\\/?)([^ >]*)(\\s+(.*))?>/i,x=/<br(\\s+.*)?>/i,b=/(^|[\\s\"'])style\\s*=\\s*(\"([^\"]*);?\"|'([^']*);?')/i,_=/(^|[\\s\"'])href\\s*=\\s*(\"([^\"]*)\"|'([^']*)')/i,w=/(^|[\\s\"'])target\\s*=\\s*(\"([^\"\\s]*)\"|'([^'\\s]*)')/i,k=/(^|[\\s\"'])popup\\s*=\\s*(\"([\\w=,]*)\"|'([\\w=,]*)')/i;function T(t,e){if(!t)return null;var r=t.match(e),n=r&&(r[3]||r[4]);return n&&E(n)}var A=/(^|;)\\s*color:/;r.plainText=function(t,e){for(var r=void 0!==(e=e||{}).len&&-1!==e.len?e.len:1/0,n=void 0!==e.allowedTags?e.allowedTags:[\"br\"],i=\"...\".length,a=t.split(m),o=[],s=\"\",l=0,c=0;c<a.length;c++){var u=a[c],h=u.match(y),f=h&&h[2].toLowerCase();if(f)-1!==n.indexOf(f)&&(o.push(u),s=f);else{var p=u.length;if(l+p<r)o.push(u),l+=p;else if(l<r){var d=r-l;s&&(\"br\"!==s||d<=i||p<=i)&&o.pop(),r>i?o.push(u.substr(0,d-i)+\"...\"):o.push(u.substr(0,d));break}s=\"\"}}return o.join(\"\")};var M={mu:\"\\u03bc\",amp:\"&\",lt:\"<\",gt:\">\",nbsp:\"\\xa0\",times:\"\\xd7\",plusmn:\"\\xb1\",deg:\"\\xb0\"},S=/&(#\\d+|#x[\\da-fA-F]+|[a-z]+);/g;function E(t){return t.replace(S,function(t,e){return(\"#\"===e.charAt(0)?function(t){if(t>1114111)return;var e=String.fromCodePoint;if(e)return e(t);var r=String.fromCharCode;return t<=65535?r(t):r(55232+(t>>10),t%1024+56320)}(\"x\"===e.charAt(1)?parseInt(e.substr(2),16):parseInt(e.substr(1),10)):M[e])||t})}function C(t,e,r){var n,i,a,o=r.horizontalAlign,s=r.verticalAlign||\"top\",l=t.node().getBoundingClientRect(),c=e.node().getBoundingClientRect();return i=\"bottom\"===s?function(){return l.bottom-n.height}:\"middle\"===s?function(){return l.top+(l.height-n.height)/2}:function(){return l.top},a=\"right\"===o?function(){return l.right-n.width}:\"center\"===o?function(){return l.left+(l.width-n.width)/2}:function(){return l.left},function(){return n=this.node().getBoundingClientRect(),this.style({top:i()-c.top+\"px\",left:a()-c.left+\"px\",\"z-index\":1e3}),this}}r.convertEntities=E,r.lineCount=function(t){return t.selectAll(\"tspan.line\").size()||1},r.positionText=function(t,e,r){return t.each(function(){var t=n.select(this);function i(e,r){return void 0===r?null===(r=t.attr(e))&&(t.attr(e,0),r=0):t.attr(e,r),r}var a=i(\"x\",e),o=i(\"y\",r);\"text\"===this.nodeName&&t.selectAll(\"tspan.line\").attr({x:a,y:o})})},r.makeEditable=function(t,e){var r=e.gd,i=e.delegate,a=n.dispatch(\"edit\",\"input\",\"cancel\"),o=i||t;if(t.style({\"pointer-events\":i?\"none\":\"all\"}),1!==t.size())throw new Error(\"boo\");function s(){!function(){var i=n.select(r).select(\".svg-container\"),o=i.append(\"div\"),s=t.node().style,c=parseFloat(s.fontSize||12),u=e.text;void 0===u&&(u=t.attr(\"data-unformatted\"));o.classed(\"plugin-editable editable\",!0).style({position:\"absolute\",\"font-family\":s.fontFamily||\"Arial\",\"font-size\":c,color:e.fill||s.fill||\"black\",opacity:1,\"background-color\":e.background||\"transparent\",outline:\"#ffffff33 1px solid\",margin:[-c/8+1,0,0,-1].join(\"px \")+\"px\",padding:\"0\",\"box-sizing\":\"border-box\"}).attr({contenteditable:!0}).text(u).call(C(t,i,e)).on(\"blur\",function(){r._editing=!1,t.text(this.textContent).style({opacity:1});var e,i=n.select(this).attr(\"class\");(e=i?\".\"+i.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(e).style({opacity:0});var o=this.textContent;n.select(this).transition().duration(0).remove(),n.select(document).on(\"mouseup\",null),a.edit.call(t,o)}).on(\"focus\",function(){var t=this;r._editing=!0,n.select(document).on(\"mouseup\",function(){if(n.event.target===t)return!1;document.activeElement===o.node()&&o.node().blur()})}).on(\"keyup\",function(){27===n.event.which?(r._editing=!1,t.style({opacity:1}),n.select(this).style({opacity:0}).on(\"blur\",function(){return!1}).transition().remove(),a.cancel.call(t,this.textContent)):(a.input.call(t,this.textContent),n.select(this).call(C(t,i,e)))}).on(\"keydown\",function(){13===n.event.which&&this.blur()}).call(l)}(),t.style({opacity:0});var i,s=o.attr(\"class\");(i=s?\".\"+s.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(i).style({opacity:0})}function l(t){var e=t.node(),r=document.createRange();r.selectNodeContents(e);var n=window.getSelection();n.removeAllRanges(),n.addRange(r),e.focus()}return e.immediate?s():o.on(\"click\",s),n.rebind(t,a,\"on\")}},{\"../constants/alignment\":688,\"../constants/xmlns_namespaces\":696,\"../lib\":719,d3:163}],744:[function(t,e,r){\"use strict\";var n={};function i(t){t&&null!==t.timer&&(clearTimeout(t.timer),t.timer=null)}r.throttle=function(t,e,r){var a=n[t],o=Date.now();if(!a){for(var s in n)n[s].ts<o-6e4&&delete n[s];a=n[t]={ts:0,timer:null}}function l(){r(),a.ts=Date.now(),a.onDone&&(a.onDone(),a.onDone=null)}i(a),o>a.ts+e?l():a.timer=setTimeout(function(){l(),a.timer=null},e)},r.done=function(t){var e=n[t];return e&&e.timer?new Promise(function(t){var r=e.onDone;e.onDone=function(){r&&r(),t(),e.onDone=null}}):Promise.resolve()},r.clear=function(t){if(t)i(n[t]),delete n[t];else for(var e in n)r.clear(e)}},{}],745:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t,e){if(t>0)return Math.log(t)/Math.LN10;var r=Math.log(Math.min(e[0],e[1]))/Math.LN10;return n(r)||(r=Math.log(Math.max(e[0],e[1]))/Math.LN10-6),r}},{\"fast-isnumeric\":225}],746:[function(t,e,r){\"use strict\";var n=e.exports={},i=t(\"../plots/geo/constants\").locationmodeToLayer,a=t(\"topojson-client\").feature;n.getTopojsonName=function(t){return[t.scope.replace(/ /g,\"-\"),\"_\",t.resolution.toString(),\"m\"].join(\"\")},n.getTopojsonPath=function(t,e){return t+e+\".json\"},n.getTopojsonFeatures=function(t,e){var r=i[t.locationmode],n=e.objects[r];return a(e,n).features}},{\"../plots/geo/constants\":795,\"topojson-client\":540}],747:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en-US\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colorscale title\"},format:{date:\"%m/%d/%Y\"}}},{}],748:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colourscale title\"},format:{days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],periods:[\"AM\",\"PM\"],dateTime:\"%a %b %e %X %Y\",date:\"%d/%m/%Y\",time:\"%H:%M:%S\",decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],year:\"%Y\",month:\"%b %Y\",dayMonth:\"%b %-d\",dayMonthYear:\"%b %-d, %Y\"}}},{}],749:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t){for(var e,r,i=n.layoutArrayContainers,a=n.layoutArrayRegexes,o=t.split(\"[\")[0],s=0;s<a.length;s++)if((r=t.match(a[s]))&&0===r.index){e=r[0];break}if(e||(e=i[i.indexOf(o)]),!e)return!1;var l=t.substr(e.length);return l?!!(r=l.match(/^\\[(0|[1-9][0-9]*)\\](\\.(.+))?$/))&&{array:e,index:Number(r[1]),property:r[3]||\"\"}:{array:e,index:\"\",property:\"\"}}},{\"../registry\":847}],750:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.extendFlat,a=n.isPlainObject,o={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"clearAxisTypes\",\"plot\",\"style\",\"markerSize\",\"colorbars\"]},s={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"plot\",\"legend\",\"ticks\",\"axrange\",\"layoutstyle\",\"modebar\",\"camera\",\"arraydraw\",\"colorbars\"]},l=o.flags.slice().concat([\"fullReplot\"]),c=s.flags.slice().concat(\"layoutReplot\");function u(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=!1;return e}function h(t,e,r){var n=i({},t);for(var o in n){var s=n[o];a(s)&&(n[o]=f(s,e,r,o))}return\"from-root\"===r&&(n.editType=e),n}function f(t,e,r,n){if(t.valType){var a=i({},t);if(a.editType=e,Array.isArray(t.items)){a.items=new Array(t.items.length);for(var o=0;o<t.items.length;o++)a.items[o]=f(t.items[o],e,\"from-root\")}return a}return h(t,e,\"_\"===n.charAt(0)?\"nested\":\"from-root\")}e.exports={traces:o,layout:s,traceFlags:function(){return u(l)},layoutFlags:function(){return u(c)},update:function(t,e){var r=e.editType;if(r&&\"none\"!==r)for(var n=r.split(\"+\"),i=0;i<n.length;i++)t[n[i]]=!0},overrideAll:h}},{\"../lib\":719}],751:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"gl-mat4/fromQuat\"),a=t(\"../registry\"),o=t(\"../lib\"),s=t(\"../plots/plots\"),l=t(\"../plots/cartesian/axis_ids\"),c=t(\"../components/color\"),u=l.cleanId,h=l.getFromTrace,f=a.traceIs;function p(t,e){var r=t[e],n=e.charAt(0);r&&\"paper\"!==r&&(t[e]=u(r,n))}function d(t){function e(e,r){var n=t[e],i=t.title&&t.title[r];n&&!i&&(t.title||(t.title={}),t.title[r]=t[e],delete t[e])}t&&(\"string\"!=typeof t.title&&\"number\"!=typeof t.title||(t.title={text:t.title}),e(\"titlefont\",\"font\"),e(\"titleposition\",\"position\"),e(\"titleside\",\"side\"),e(\"titleoffset\",\"offset\"))}function g(t){if(!o.isPlainObject(t))return!1;var e=t.name;return delete t.name,delete t.showlegend,(\"string\"==typeof e||\"number\"==typeof e)&&String(e)}function v(t,e,r,n){if(r&&!n)return t;if(n&&!r)return e;if(!t.trim())return e;if(!e.trim())return t;var i,a=Math.min(t.length,e.length);for(i=0;i<a&&t.charAt(i)===e.charAt(i);i++);return t.substr(0,i).trim()}function m(t){var e=\"middle\",r=\"center\";return\"string\"==typeof t&&(-1!==t.indexOf(\"top\")?e=\"top\":-1!==t.indexOf(\"bottom\")&&(e=\"bottom\"),-1!==t.indexOf(\"left\")?r=\"left\":-1!==t.indexOf(\"right\")&&(r=\"right\")),e+\" \"+r}function y(t,e){return e in t&&\"object\"==typeof t[e]&&0===Object.keys(t[e]).length}r.clearPromiseQueue=function(t){Array.isArray(t._promises)&&t._promises.length>0&&o.log(\"Clearing previous rejected promises from queue.\"),t._promises=[]},r.cleanLayout=function(t){var e,n;t||(t={}),t.xaxis1&&(t.xaxis||(t.xaxis=t.xaxis1),delete t.xaxis1),t.yaxis1&&(t.yaxis||(t.yaxis=t.yaxis1),delete t.yaxis1),t.scene1&&(t.scene||(t.scene=t.scene1),delete t.scene1);var a=(s.subplotsRegistry.cartesian||{}).attrRegex,l=(s.subplotsRegistry.polar||{}).attrRegex,h=(s.subplotsRegistry.ternary||{}).attrRegex,f=(s.subplotsRegistry.gl3d||{}).attrRegex,g=Object.keys(t);for(e=0;e<g.length;e++){var v=g[e];if(a&&a.test(v)){var m=t[v];m.anchor&&\"free\"!==m.anchor&&(m.anchor=u(m.anchor)),m.overlaying&&(m.overlaying=u(m.overlaying)),m.type||(m.isdate?m.type=\"date\":m.islog?m.type=\"log\":!1===m.isdate&&!1===m.islog&&(m.type=\"linear\")),\"withzero\"!==m.autorange&&\"tozero\"!==m.autorange||(m.autorange=!0,m.rangemode=\"tozero\"),delete m.islog,delete m.isdate,delete m.categories,y(m,\"domain\")&&delete m.domain,void 0!==m.autotick&&(void 0===m.tickmode&&(m.tickmode=m.autotick?\"auto\":\"linear\"),delete m.autotick),d(m)}else if(l&&l.test(v)){d(t[v].radialaxis)}else if(h&&h.test(v)){var x=t[v];d(x.aaxis),d(x.baxis),d(x.caxis)}else if(f&&f.test(v)){var b=t[v],_=b.cameraposition;if(Array.isArray(_)&&4===_[0].length){var w=_[0],k=_[1],T=_[2],A=i([],w),M=[];for(n=0;n<3;++n)M[n]=k[n]+T*A[2+4*n];b.camera={eye:{x:M[0],y:M[1],z:M[2]},center:{x:k[0],y:k[1],z:k[2]},up:{x:0,y:0,z:1}},delete b.cameraposition}d(b.xaxis),d(b.yaxis),d(b.zaxis)}}var S=Array.isArray(t.annotations)?t.annotations.length:0;for(e=0;e<S;e++){var E=t.annotations[e];o.isPlainObject(E)&&(E.ref&&(\"paper\"===E.ref?(E.xref=\"paper\",E.yref=\"paper\"):\"data\"===E.ref&&(E.xref=\"x\",E.yref=\"y\"),delete E.ref),p(E,\"xref\"),p(E,\"yref\"))}var C=Array.isArray(t.shapes)?t.shapes.length:0;for(e=0;e<C;e++){var L=t.shapes[e];o.isPlainObject(L)&&(p(L,\"xref\"),p(L,\"yref\"))}var P=t.legend;return P&&(P.x>3?(P.x=1.02,P.xanchor=\"left\"):P.x<-2&&(P.x=-.02,P.xanchor=\"right\"),P.y>3?(P.y=1.02,P.yanchor=\"bottom\"):P.y<-2&&(P.y=-.02,P.yanchor=\"top\")),d(t),\"rotate\"===t.dragmode&&(t.dragmode=\"orbit\"),c.clean(t),t.template&&t.template.layout&&r.cleanLayout(t.template.layout),t},r.cleanData=function(t){for(var e=0;e<t.length;e++){var n,i=t[e];if(\"histogramy\"===i.type&&\"xbins\"in i&&!(\"ybins\"in i)&&(i.ybins=i.xbins,delete i.xbins),i.error_y&&\"opacity\"in i.error_y){var l=c.defaults,h=i.error_y.color||(f(i,\"bar\")?c.defaultLine:l[e%l.length]);i.error_y.color=c.addOpacity(c.rgb(h),c.opacity(h)*i.error_y.opacity),delete i.error_y.opacity}if(\"bardir\"in i&&(\"h\"!==i.bardir||!f(i,\"bar\")&&\"histogram\"!==i.type.substr(0,9)||(i.orientation=\"h\",r.swapXYData(i)),delete i.bardir),\"histogramy\"===i.type&&r.swapXYData(i),\"histogramx\"!==i.type&&\"histogramy\"!==i.type||(i.type=\"histogram\"),\"scl\"in i&&!(\"colorscale\"in i)&&(i.colorscale=i.scl,delete i.scl),\"reversescl\"in i&&!(\"reversescale\"in i)&&(i.reversescale=i.reversescl,delete i.reversescl),i.xaxis&&(i.xaxis=u(i.xaxis,\"x\")),i.yaxis&&(i.yaxis=u(i.yaxis,\"y\")),f(i,\"gl3d\")&&i.scene&&(i.scene=s.subplotsRegistry.gl3d.cleanId(i.scene)),!f(i,\"pie-like\")&&!f(i,\"bar-like\"))if(Array.isArray(i.textposition))for(n=0;n<i.textposition.length;n++)i.textposition[n]=m(i.textposition[n]);else i.textposition&&(i.textposition=m(i.textposition));var p=a.getModule(i);if(p&&p.colorbar){var x=p.colorbar.container,b=x?i[x]:i;b&&b.colorscale&&(\"YIGnBu\"===b.colorscale&&(b.colorscale=\"YlGnBu\"),\"YIOrRd\"===b.colorscale&&(b.colorscale=\"YlOrRd\"))}if(\"surface\"===i.type&&o.isPlainObject(i.contours)){var _=[\"x\",\"y\",\"z\"];for(n=0;n<_.length;n++){var w=i.contours[_[n]];o.isPlainObject(w)&&(w.highlightColor&&(w.highlightcolor=w.highlightColor,delete w.highlightColor),w.highlightWidth&&(w.highlightwidth=w.highlightWidth,delete w.highlightWidth))}}if(\"candlestick\"===i.type||\"ohlc\"===i.type){var k=!1!==(i.increasing||{}).showlegend,T=!1!==(i.decreasing||{}).showlegend,A=g(i.increasing),M=g(i.decreasing);if(!1!==A&&!1!==M){var S=v(A,M,k,T);S&&(i.name=S)}else!A&&!M||i.name||(i.name=A||M)}if(Array.isArray(i.transforms)){var E=i.transforms;for(n=0;n<E.length;n++){var C=E[n];if(o.isPlainObject(C))switch(C.type){case\"filter\":C.filtersrc&&(C.target=C.filtersrc,delete C.filtersrc),C.calendar&&(C.valuecalendar||(C.valuecalendar=C.calendar),delete C.calendar);break;case\"groupby\":if(C.styles=C.styles||C.style,C.styles&&!Array.isArray(C.styles)){var L=C.styles,P=Object.keys(L);C.styles=[];for(var O=0;O<P.length;O++)C.styles.push({target:P[O],value:L[P[O]]})}}}}y(i,\"line\")&&delete i.line,\"marker\"in i&&(y(i.marker,\"line\")&&delete i.marker.line,y(i,\"marker\")&&delete i.marker),c.clean(i),i.autobinx&&(delete i.autobinx,delete i.xbins),i.autobiny&&(delete i.autobiny,delete i.ybins),d(i),i.colorbar&&d(i.colorbar),i.marker&&i.marker.colorbar&&d(i.marker.colorbar),i.line&&i.line.colorbar&&d(i.line.colorbar),i.aaxis&&d(i.aaxis),i.baxis&&d(i.baxis)}},r.swapXYData=function(t){var e;if(o.swapAttrs(t,[\"?\",\"?0\",\"d?\",\"?bins\",\"nbins?\",\"autobin?\",\"?src\",\"error_?\"]),Array.isArray(t.z)&&Array.isArray(t.z[0])&&(t.transpose?delete t.transpose:t.transpose=!0),t.error_x&&t.error_y){var r=t.error_y,n=\"copy_ystyle\"in r?r.copy_ystyle:!(r.color||r.thickness||r.width);o.swapAttrs(t,[\"error_?.copy_ystyle\"]),n&&o.swapAttrs(t,[\"error_?.color\",\"error_?.thickness\",\"error_?.width\"])}if(\"string\"==typeof t.hoverinfo){var i=t.hoverinfo.split(\"+\");for(e=0;e<i.length;e++)\"x\"===i[e]?i[e]=\"y\":\"y\"===i[e]&&(i[e]=\"x\");t.hoverinfo=i.join(\"+\")}},r.coerceTraceIndices=function(t,e){if(n(e))return[e];if(!Array.isArray(e)||!e.length)return t.data.map(function(t,e){return e});if(Array.isArray(e)){for(var r=[],i=0;i<e.length;i++)o.isIndex(e[i],t.data.length)?r.push(e[i]):o.warn(\"trace index (\",e[i],\") is not a number or is out of bounds\");return r}return e},r.manageArrayContainers=function(t,e,r){var i=t.obj,a=t.parts,s=a.length,l=a[s-1],c=n(l);if(c&&null===e){var u=a.slice(0,s-1).join(\".\");o.nestedProperty(i,u).get().splice(l,1)}else c&&void 0===t.get()?(void 0===t.get()&&(r[t.astr]=null),t.set(e)):t.set(e)};var x=/(\\.[^\\[\\]\\.]+|\\[[^\\[\\]\\.]+\\])$/;function b(t){var e=t.search(x);if(e>0)return t.substr(0,e)}r.hasParent=function(t,e){for(var r=b(e);r;){if(r in t)return!0;r=b(r)}return!1};var _=[\"x\",\"y\",\"z\"];r.clearAxisTypes=function(t,e,r){for(var n=0;n<e.length;n++)for(var i=t._fullData[n],a=0;a<3;a++){var s=h(t,i,_[a]);if(s&&\"log\"!==s.type){var l=s._name,c=s._id.substr(1);if(\"scene\"===c.substr(0,5)){if(void 0!==r[c])continue;l=c+\".\"+l}var u=l+\".type\";void 0===r[l]&&void 0===r[u]&&o.nestedProperty(t.layout,u).set(null)}}}},{\"../components/color\":593,\"../lib\":719,\"../plots/cartesian/axis_ids\":770,\"../plots/plots\":828,\"../registry\":847,\"fast-isnumeric\":225,\"gl-mat4/fromQuat\":262}],752:[function(t,e,r){\"use strict\";var n=t(\"./plot_api\");r.plot=n.plot,r.newPlot=n.newPlot,r.restyle=n.restyle,r.relayout=n.relayout,r.redraw=n.redraw,r.update=n.update,r._guiRestyle=n._guiRestyle,r._guiRelayout=n._guiRelayout,r._guiUpdate=n._guiUpdate,r._storeDirectGUIEdit=n._storeDirectGUIEdit,r.react=n.react,r.extendTraces=n.extendTraces,r.prependTraces=n.prependTraces,r.addTraces=n.addTraces,r.deleteTraces=n.deleteTraces,r.moveTraces=n.moveTraces,r.purge=n.purge,r.addFrames=n.addFrames,r.deleteFrames=n.deleteFrames,r.animate=n.animate,r.setPlotConfig=n.setPlotConfig,r.toImage=t(\"./to_image\"),r.validate=t(\"./validate\"),r.downloadImage=t(\"../snapshot/download\");var i=t(\"./template_api\");r.makeTemplate=i.makeTemplate,r.validateTemplate=i.validateTemplate},{\"../snapshot/download\":849,\"./plot_api\":754,\"./template_api\":759,\"./to_image\":760,\"./validate\":761}],753:[function(t,e,r){\"use strict\";var n=t(\"../lib/is_plain_object\"),i=t(\"../lib/noop\"),a=t(\"../lib/loggers\"),o=t(\"../lib/search\").sorterAsc,s=t(\"../registry\");r.containerArrayMatch=t(\"./container_array_match\");var l=r.isAddVal=function(t){return\"add\"===t||n(t)},c=r.isRemoveVal=function(t){return null===t||\"remove\"===t};r.applyContainerArrayChanges=function(t,e,r,n,u){var h=e.astr,f=s.getComponentMethod(h,\"supplyLayoutDefaults\"),p=s.getComponentMethod(h,\"draw\"),d=s.getComponentMethod(h,\"drawOne\"),g=n.replot||n.recalc||f===i||p===i,v=t.layout,m=t._fullLayout;if(r[\"\"]){Object.keys(r).length>1&&a.warn(\"Full array edits are incompatible with other edits\",h);var y=r[\"\"][\"\"];if(c(y))e.set(null);else{if(!Array.isArray(y))return a.warn(\"Unrecognized full array edit value\",h,y),!0;e.set(y)}return!g&&(f(v,m),p(t),!0)}var x,b,_,w,k,T,A,M,S=Object.keys(r).map(Number).sort(o),E=e.get(),C=E||[],L=u(m,h).get(),P=[],O=-1,z=C.length;for(x=0;x<S.length;x++)if(w=r[_=S[x]],k=Object.keys(w),T=w[\"\"],A=l(T),_<0||_>C.length-(A?0:1))a.warn(\"index out of range\",h,_);else if(void 0!==T)k.length>1&&a.warn(\"Insertion & removal are incompatible with edits to the same index.\",h,_),c(T)?P.push(_):A?(\"add\"===T&&(T={}),C.splice(_,0,T),L&&L.splice(_,0,{})):a.warn(\"Unrecognized full object edit value\",h,_,T),-1===O&&(O=_);else for(b=0;b<k.length;b++)M=h+\"[\"+_+\"].\",u(C[_],k[b],M).set(w[k[b]]);for(x=P.length-1;x>=0;x--)C.splice(P[x],1),L&&L.splice(P[x],1);if(C.length?E||e.set(C):e.set(null),g)return!1;if(f(v,m),d!==i){var I;if(-1===O)I=S;else{for(z=Math.max(C.length,z),I=[],x=0;x<S.length&&!((_=S[x])>=O);x++)I.push(_);for(x=O;x<z;x++)I.push(x)}for(x=0;x<I.length;x++)d(t,I[x])}else p(t);return!0}},{\"../lib/is_plain_object\":720,\"../lib/loggers\":723,\"../lib/noop\":728,\"../lib/search\":738,\"../registry\":847,\"./container_array_match\":749}],754:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"has-hover\"),o=t(\"../lib\"),s=o.nestedProperty,l=t(\"../lib/events\"),c=t(\"../lib/queue\"),u=t(\"../registry\"),h=t(\"./plot_schema\"),f=t(\"../plots/plots\"),p=t(\"../plots/polar/legacy\"),d=t(\"../plots/cartesian/axes\"),g=t(\"../components/drawing\"),v=t(\"../components/color\"),m=t(\"../plots/cartesian/graph_interact\").initInteractions,y=t(\"../constants/xmlns_namespaces\"),x=t(\"../lib/svg_text_utils\"),b=t(\"../plots/cartesian/select\").clearSelect,_=t(\"./plot_config\").dfltConfig,w=t(\"./manage_arrays\"),k=t(\"./helpers\"),T=t(\"./subroutines\"),A=t(\"./edit_types\"),M=t(\"../plots/cartesian/constants\").AX_NAME_PATTERN,S=0,E=5;function C(t){var e=t._fullLayout;e._redrawFromAutoMarginCount?e._redrawFromAutoMarginCount--:t.emit(\"plotly_afterplot\")}function L(t,e){try{t._fullLayout._paper.style(\"background\",e)}catch(t){o.error(t)}}function P(t,e){L(t,v.combine(e,\"white\"))}function O(t,e){if(!t._context){t._context=o.extendDeep({},_);var r=n.select(\"base\");t._context._baseUrl=r.size()&&r.attr(\"href\")?window.location.href.split(\"#\")[0]:\"\"}var i,s,l,c=t._context;if(e){for(s=Object.keys(e),i=0;i<s.length;i++)\"editable\"!==(l=s[i])&&\"edits\"!==l&&l in c&&(\"setBackground\"===l&&\"opaque\"===e[l]?c[l]=P:c[l]=e[l]);e.plot3dPixelRatio&&!c.plotGlPixelRatio&&(c.plotGlPixelRatio=c.plot3dPixelRatio);var u=e.editable;if(void 0!==u)for(c.editable=u,s=Object.keys(c.edits),i=0;i<s.length;i++)c.edits[s[i]]=u;if(e.edits)for(s=Object.keys(e.edits),i=0;i<s.length;i++)(l=s[i])in c.edits&&(c.edits[l]=e.edits[l]);c._exportedPlot=e._exportedPlot}c.staticPlot&&(c.editable=!1,c.edits={},c.autosizable=!1,c.scrollZoom=!1,c.doubleClick=!1,c.showTips=!1,c.showLink=!1,c.displayModeBar=!1),\"hover\"!==c.displayModeBar||a||(c.displayModeBar=!0),\"transparent\"!==c.setBackground&&\"function\"==typeof c.setBackground||(c.setBackground=L),c._hasZeroHeight=c._hasZeroHeight||0===t.clientHeight,c._hasZeroWidth=c._hasZeroWidth||0===t.clientWidth;var h=c.scrollZoom,f=c._scrollZoom={};if(!0===h)f.cartesian=1,f.gl3d=1,f.geo=1,f.mapbox=1;else if(\"string\"==typeof h){var p=h.split(\"+\");for(i=0;i<p.length;i++)f[p[i]]=1}else!1!==h&&(f.gl3d=1,f.geo=1,f.mapbox=1)}function z(t,e){var r,n,i=e+1,a=[];for(r=0;r<t.length;r++)(n=t[r])<0?a.push(i+n):a.push(n);return a}function I(t,e,r){var n,i;for(n=0;n<e.length;n++){if((i=e[n])!==parseInt(i,10))throw new Error(\"all values in \"+r+\" must be integers\");if(i>=t.data.length||i<-t.data.length)throw new Error(r+\" must be valid indices for gd.data.\");if(e.indexOf(i,n+1)>-1||i>=0&&e.indexOf(-t.data.length+i)>-1||i<0&&e.indexOf(t.data.length+i)>-1)throw new Error(\"each index in \"+r+\" must be unique.\")}}function D(t,e,r){if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"currentIndices is a required argument.\");if(Array.isArray(e)||(e=[e]),I(t,e,\"currentIndices\"),\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&I(t,r,\"newIndices\"),\"undefined\"!=typeof r&&e.length!==r.length)throw new Error(\"current and new indices must be of equal length.\")}function R(t,e,r,n,a){!function(t,e,r,n){var i=o.isPlainObject(n);if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array\");if(!o.isPlainObject(e))throw new Error(\"update must be a key:value object\");if(\"undefined\"==typeof r)throw new Error(\"indices must be an integer or array of integers\");for(var a in I(t,r,\"indices\"),e){if(!Array.isArray(e[a])||e[a].length!==r.length)throw new Error(\"attribute \"+a+\" must be an array of length equal to indices array length\");if(i&&(!(a in n)||!Array.isArray(n[a])||n[a].length!==e[a].length))throw new Error(\"when maxPoints is set as a key:value object it must contain a 1:1 corrispondence with the keys and number of traces in the update object\")}}(t,e,r,n);for(var l=function(t,e,r,n){var a,l,c,u,h,f=o.isPlainObject(n),p=[];for(var d in Array.isArray(r)||(r=[r]),r=z(r,t.data.length-1),e)for(var g=0;g<r.length;g++){if(a=t.data[r[g]],l=(c=s(a,d)).get(),u=e[d][g],!o.isArrayOrTypedArray(u))throw new Error(\"attribute: \"+d+\" index: \"+g+\" must be an array\");if(!o.isArrayOrTypedArray(l))throw new Error(\"cannot extend missing or non-array attribute: \"+d);if(l.constructor!==u.constructor)throw new Error(\"cannot extend array with an array of a different type: \"+d);h=f?n[d][g]:n,i(h)||(h=-1),p.push({prop:c,target:l,insert:u,maxp:Math.floor(h)})}return p}(t,e,r,n),c={},u={},h=0;h<l.length;h++){var f=l[h].prop,p=l[h].maxp,d=a(l[h].target,l[h].insert,p);f.set(d[0]),Array.isArray(c[f.astr])||(c[f.astr]=[]),c[f.astr].push(d[1]),Array.isArray(u[f.astr])||(u[f.astr]=[]),u[f.astr].push(l[h].target.length)}return{update:c,maxPoints:u}}function F(t,e){var r=new t.constructor(t.length+e.length);return r.set(t),r.set(e,t.length),r}function B(t,e,n,i){t=o.getGraphDiv(t),k.clearPromiseQueue(t);var a={};if(\"string\"==typeof e)a[e]=n;else{if(!o.isPlainObject(e))return o.warn(\"Restyle fail.\",e,n,i),Promise.reject();a=o.extendFlat({},e),void 0===i&&(i=n)}Object.keys(a).length&&(t.changed=!0);var s=k.coerceTraceIndices(t,i),l=V(t,a,s),u=l.flags;u.calc&&(t.calcdata=void 0),u.clearAxisTypes&&k.clearAxisTypes(t,s,{});var h=[];u.fullReplot?h.push(r.plot):(h.push(f.previousPromises),f.supplyDefaults(t),u.markerSize&&(f.doCalcdata(t),Y(h)),u.style&&h.push(T.doTraceStyle),u.colorbars&&h.push(T.doColorBars),h.push(C)),h.push(f.rehover,f.redrag),c.add(t,B,[t,l.undoit,l.traces],B,[t,l.redoit,l.traces]);var p=o.syncOrAsync(h,t);return p&&p.then||(p=Promise.resolve()),p.then(function(){return t.emit(\"plotly_restyle\",l.eventData),t})}function N(t){return void 0===t?null:t}function j(t,e){return e?function(e,r,n){var i=s(e,r),a=i.set;return i.set=function(e){U((n||\"\")+r,i.get(),e,t),a(e)},i}:s}function U(t,e,r,n){if(Array.isArray(e)||Array.isArray(r))for(var i=Array.isArray(e)?e:[],a=Array.isArray(r)?r:[],s=Math.max(i.length,a.length),l=0;l<s;l++)U(t+\"[\"+l+\"]\",i[l],a[l],n);else if(o.isPlainObject(e)||o.isPlainObject(r)){var c=o.isPlainObject(e)?e:{},u=o.isPlainObject(r)?r:{},h=o.extendFlat({},c,u);for(var f in h)U(t+\".\"+f,c[f],u[f],n)}else void 0===n[t]&&(n[t]=N(e))}function V(t,e,r){var n,i=t._fullLayout,a=t._fullData,l=t.data,c=i._guiEditing,p=j(i._preGUI,c),g=o.extendDeepAll({},e);q(e);var v,m=A.traceFlags(),y={},x={};function b(){return r.map(function(){})}function _(t){var e=d.id2name(t);-1===v.indexOf(e)&&v.push(e)}function w(t){return\"LAYOUT\"+t+\".autorange\"}function T(t){return\"LAYOUT\"+t+\".range\"}function M(t){for(var e=t;e<a.length;e++)if(a[e]._input===l[t])return a[e]}function S(n,a,o){if(Array.isArray(n))n.forEach(function(t){S(t,a,o)});else if(!(n in e||k.hasParent(e,n))){var s;if(\"LAYOUT\"===n.substr(0,6))s=p(t.layout,n.replace(\"LAYOUT\",\"\"));else{var u=r[o];s=j(i._tracePreGUI[M(u)._fullInput.uid],c)(l[u],n)}n in x||(x[n]=b()),void 0===x[n][o]&&(x[n][o]=N(s.get())),void 0!==a&&s.set(a)}}function E(t){return function(e){return a[e][t]}}function C(t){return function(e,n){return!1===e?a[r[n]][t]:null}}for(var L in e){if(k.hasParent(e,L))throw new Error(\"cannot set \"+L+\" and a parent attribute simultaneously\");var P,O,z,I,D,R,F=e[L];if(\"autobinx\"!==L&&\"autobiny\"!==L||(L=L.charAt(L.length-1)+\"bins\",F=Array.isArray(F)?F.map(C(L)):!1===F?r.map(E(L)):null),y[L]=F,\"LAYOUT\"!==L.substr(0,6)){for(x[L]=b(),n=0;n<r.length;n++){if(P=l[r[n]],O=M(r[n]),I=(z=j(i._tracePreGUI[O._fullInput.uid],c)(P,L)).get(),void 0!==(D=Array.isArray(F)?F[n%F.length]:F)){var B=z.parts[z.parts.length-1],U=L.substr(0,L.length-B.length-1),V=U?U+\".\":\"\",H=U?s(O,U).get():O;if((R=h.getTraceValObject(O,z.parts))&&R.impliedEdits&&null!==D)for(var G in R.impliedEdits)S(o.relativeAttr(L,G),R.impliedEdits[G],n);else if(\"thicknessmode\"!==B&&\"lenmode\"!==B||I===D||\"fraction\"!==D&&\"pixels\"!==D||!H){if(\"type\"===L&&(\"pie\"===D!=(\"pie\"===I)||\"funnelarea\"===D!=(\"funnelarea\"===I))){var Y=\"x\",W=\"y\";\"bar\"!==D&&\"bar\"!==I||\"h\"!==P.orientation||(Y=\"y\",W=\"x\"),o.swapAttrs(P,[\"?\",\"?src\"],\"labels\",Y),o.swapAttrs(P,[\"d?\",\"?0\"],\"label\",Y),o.swapAttrs(P,[\"?\",\"?src\"],\"values\",W),\"pie\"===I||\"funnelarea\"===I?(s(P,\"marker.color\").set(s(P,\"marker.colors\").get()),i._pielayer.selectAll(\"g.trace\").remove()):u.traceIs(P,\"cartesian\")&&s(P,\"marker.colors\").set(s(P,\"marker.color\").get())}}else{var X=i._size,Z=H.orient,J=\"top\"===Z||\"bottom\"===Z;if(\"thicknessmode\"===B){var K=J?X.h:X.w;S(V+\"thickness\",H.thickness*(\"fraction\"===D?1/K:K),n)}else{var $=J?X.w:X.h;S(V+\"len\",H.len*(\"fraction\"===D?1/$:$),n)}}x[L][n]=N(I);if(-1!==[\"swapxy\",\"swapxyaxes\",\"orientation\",\"orientationaxes\"].indexOf(L)){if(\"orientation\"===L){z.set(D);var Q=P.x&&!P.y?\"h\":\"v\";if((z.get()||Q)===O.orientation)continue}else\"orientationaxes\"===L&&(P.orientation={v:\"h\",h:\"v\"}[O.orientation]);k.swapXYData(P),m.calc=m.clearAxisTypes=!0}else-1!==f.dataArrayContainers.indexOf(z.parts[0])?(k.manageArrayContainers(z,D,x),m.calc=!0):(R?R.arrayOk&&!u.traceIs(O,\"regl\")&&(o.isArrayOrTypedArray(D)||o.isArrayOrTypedArray(I))?m.calc=!0:A.update(m,R):m.calc=!0,z.set(D))}}if(-1!==[\"swapxyaxes\",\"orientationaxes\"].indexOf(L)&&d.swap(t,r),\"orientationaxes\"===L){var tt=s(t.layout,\"hovermode\");\"x\"===tt.get()?tt.set(\"y\"):\"y\"===tt.get()&&tt.set(\"x\")}if(-1!==[\"orientation\",\"type\"].indexOf(L)){for(v=[],n=0;n<r.length;n++){var et=l[r[n]];u.traceIs(et,\"cartesian\")&&(_(et.xaxis||\"x\"),_(et.yaxis||\"y\"))}S(v.map(w),!0,0),S(v.map(T),[0,1],0)}}else z=p(t.layout,L.replace(\"LAYOUT\",\"\")),x[L]=[N(z.get())],z.set(Array.isArray(F)?F[0]:F),m.calc=!0}return(m.calc||m.plot)&&(m.fullReplot=!0),{flags:m,undoit:x,redoit:y,traces:r,eventData:o.extendDeepNoArrays([],[g,r])}}function q(t){var e,r,n,i=o.counterRegex(\"axis\",\".title\",!1,!1),a=/colorbar\\.title$/,s=Object.keys(t);for(e=0;e<s.length;e++)r=s[e],n=t[r],\"title\"!==r&&!i.test(r)&&!a.test(r)||\"string\"!=typeof n&&\"number\"!=typeof n?r.indexOf(\"titlefont\")>-1?l(r,r.replace(\"titlefont\",\"title.font\")):r.indexOf(\"titleposition\")>-1?l(r,r.replace(\"titleposition\",\"title.position\")):r.indexOf(\"titleside\")>-1?l(r,r.replace(\"titleside\",\"title.side\")):r.indexOf(\"titleoffset\")>-1&&l(r,r.replace(\"titleoffset\",\"title.offset\")):l(r,r.replace(\"title\",\"title.text\"));function l(e,r){t[r]=t[e],delete t[e]}}function H(t,e,r){if(t=o.getGraphDiv(t),k.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);var n={};if(\"string\"==typeof e)n[e]=r;else{if(!o.isPlainObject(e))return o.warn(\"Relayout fail.\",e,r),Promise.reject();n=o.extendFlat({},e)}Object.keys(n).length&&(t.changed=!0);var i=J(t,n),a=i.flags;a.calc&&(t.calcdata=void 0);var s=[f.previousPromises];a.layoutReplot?s.push(T.layoutReplot):Object.keys(n).length&&(G(t,a,i)||f.supplyDefaults(t),a.legend&&s.push(T.doLegend),a.layoutstyle&&s.push(T.layoutStyles),a.axrange&&Y(s,i.rangesAltered),a.ticks&&s.push(T.doTicksRelayout),a.modebar&&s.push(T.doModeBar),a.camera&&s.push(T.doCamera),a.colorbars&&s.push(T.doColorBars),s.push(C)),s.push(f.rehover,f.redrag),c.add(t,H,[t,i.undoit],H,[t,i.redoit]);var l=o.syncOrAsync(s,t);return l&&l.then||(l=Promise.resolve(t)),l.then(function(){return t.emit(\"plotly_relayout\",i.eventData),t})}function G(t,e,r){var n=t._fullLayout;if(!e.axrange)return!1;for(var i in e)if(\"axrange\"!==i&&e[i])return!1;for(var a in r.rangesAltered){var o=d.id2name(a),s=t.layout[o],l=n[o];if(l.autorange=s.autorange,l.range=s.range.slice(),l.cleanRange(),l._matchGroup)for(var c in l._matchGroup)if(c!==a){var u=n[d.id2name(c)];u.autorange=l.autorange,u.range=l.range.slice(),u._input.range=l.range.slice()}}return!0}function Y(t,e){var r=e?function(t){var r=[],n=!0;for(var i in e){var a=d.getFromId(t,i);if(r.push(i),a._matchGroup)for(var o in a._matchGroup)e[o]||r.push(o);a.automargin&&(n=!1)}return d.draw(t,r,{skipTitle:n})}:function(t){return d.draw(t,\"redraw\")};t.push(b,T.doAutoRangeAndConstraints,r,T.drawData,T.finalDraw)}var W=/^[xyz]axis[0-9]*\\.range(\\[[0|1]\\])?$/,X=/^[xyz]axis[0-9]*\\.autorange$/,Z=/^[xyz]axis[0-9]*\\.domain(\\[[0|1]\\])?$/;function J(t,e){var r,n,i,a=t.layout,l=t._fullLayout,c=l._guiEditing,f=j(l._preGUI,c),p=Object.keys(e),g=d.list(t),v=o.extendDeepAll({},e),m={};for(q(e),p=Object.keys(e),n=0;n<p.length;n++)if(0===p[n].indexOf(\"allaxes\")){for(i=0;i<g.length;i++){var y=g[i]._id.substr(1),x=-1!==y.indexOf(\"scene\")?y+\".\":\"\",b=p[n].replace(\"allaxes\",x+g[i]._name);e[b]||(e[b]=e[p[n]])}delete e[p[n]]}var _=A.layoutFlags(),T={},S={};function E(t,r){if(Array.isArray(t))t.forEach(function(t){E(t,r)});else if(!(t in e||k.hasParent(e,t))){var n=f(a,t);t in S||(S[t]=N(n.get())),void 0!==r&&n.set(r)}}var C,L={};function P(t){var e=d.name2id(t.split(\".\")[0]);return L[e]=1,e}for(var O in e){if(k.hasParent(e,O))throw new Error(\"cannot set \"+O+\" and a parent attribute simultaneously\");for(var z=f(a,O),I=e[O],D=z.parts.length-1;D>0&&\"string\"!=typeof z.parts[D];)D--;var R=z.parts[D],F=z.parts[D-1]+\".\"+R,B=z.parts.slice(0,D).join(\".\"),U=s(t.layout,B).get(),V=s(l,B).get(),H=z.get();if(void 0!==I){T[O]=I,S[O]=\"reverse\"===R?I:N(H);var G=h.getLayoutValObject(l,z.parts);if(G&&G.impliedEdits&&null!==I)for(var Y in G.impliedEdits)E(o.relativeAttr(O,Y),G.impliedEdits[Y]);if(-1!==[\"width\",\"height\"].indexOf(O))if(I){E(\"autosize\",null);var J=\"height\"===O?\"width\":\"height\";E(J,l[J])}else l[O]=t._initialAutoSize[O];else if(\"autosize\"===O)E(\"width\",I?null:l.width),E(\"height\",I?null:l.height);else if(F.match(W))P(F),s(l,B+\"._inputRange\").set(null);else if(F.match(X)){P(F),s(l,B+\"._inputRange\").set(null);var $=s(l,B).get();$._inputDomain&&($._input.domain=$._inputDomain.slice())}else F.match(Z)&&s(l,B+\"._inputDomain\").set(null);if(\"type\"===R){var Q=U,tt=\"linear\"===V.type&&\"log\"===I,et=\"log\"===V.type&&\"linear\"===I;if(tt||et){if(Q&&Q.range)if(V.autorange)tt&&(Q.range=Q.range[1]>Q.range[0]?[1,2]:[2,1]);else{var rt=Q.range[0],nt=Q.range[1];tt?(rt<=0&&nt<=0&&E(B+\".autorange\",!0),rt<=0?rt=nt/1e6:nt<=0&&(nt=rt/1e6),E(B+\".range[0]\",Math.log(rt)/Math.LN10),E(B+\".range[1]\",Math.log(nt)/Math.LN10)):(E(B+\".range[0]\",Math.pow(10,rt)),E(B+\".range[1]\",Math.pow(10,nt)))}else E(B+\".autorange\",!0);Array.isArray(l._subplots.polar)&&l._subplots.polar.length&&l[z.parts[0]]&&\"radialaxis\"===z.parts[1]&&delete l[z.parts[0]]._subplot.viewInitial[\"radialaxis.range\"],u.getComponentMethod(\"annotations\",\"convertCoords\")(t,V,I,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,V,I,E)}else E(B+\".autorange\",!0),E(B+\".range\",null);s(l,B+\"._inputRange\").set(null)}else if(R.match(M)){var it=s(l,O).get(),at=(I||{}).type;at&&\"-\"!==at||(at=\"linear\"),u.getComponentMethod(\"annotations\",\"convertCoords\")(t,it,at,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,it,at,E)}var ot=w.containerArrayMatch(O);if(ot){r=ot.array,n=ot.index;var st=ot.property,lt=G||{editType:\"calc\"};\"\"!==n&&\"\"===st&&(w.isAddVal(I)?S[O]=null:w.isRemoveVal(I)?S[O]=(s(a,r).get()||[])[n]:o.warn(\"unrecognized full object value\",e)),A.update(_,lt),m[r]||(m[r]={});var ct=m[r][n];ct||(ct=m[r][n]={}),ct[st]=I,delete e[O]}else\"reverse\"===R?(U.range?U.range.reverse():(E(B+\".autorange\",!0),U.range=[1,0]),V.autorange?_.calc=!0:_.plot=!0):(l._has(\"scatter-like\")&&l._has(\"regl\")&&\"dragmode\"===O&&(\"lasso\"===I||\"select\"===I)&&\"lasso\"!==H&&\"select\"!==H?_.plot=!0:l._has(\"gl2d\")?_.plot=!0:G?A.update(_,G):_.calc=!0,z.set(I))}}for(r in m){w.applyContainerArrayChanges(t,f(a,r),m[r],_,f)||(_.plot=!0)}var ut=l._axisConstraintGroups||[];for(C in L)for(n=0;n<ut.length;n++){var ht=ut[n];if(ht[C])for(var ft in _.calc=!0,ht)L[ft]||(d.getFromId(t,ft)._constraintShrinkable=!0)}return(K(t)||e.height||e.width)&&(_.plot=!0),(_.plot||_.calc)&&(_.layoutReplot=!0),{flags:_,rangesAltered:L,undoit:S,redoit:T,eventData:v}}function K(t){var e=t._fullLayout,r=e.width,n=e.height;return t.layout.autosize&&f.plotAutoSize(t,t.layout,e),e.width!==r||e.height!==n}function $(t,e,n,i){if(t=o.getGraphDiv(t),k.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);o.isPlainObject(e)||(e={}),o.isPlainObject(n)||(n={}),Object.keys(e).length&&(t.changed=!0),Object.keys(n).length&&(t.changed=!0);var a=k.coerceTraceIndices(t,i),s=V(t,o.extendFlat({},e),a),l=s.flags,u=J(t,o.extendFlat({},n)),h=u.flags;(l.calc||h.calc)&&(t.calcdata=void 0),l.clearAxisTypes&&k.clearAxisTypes(t,a,n);var p=[];h.layoutReplot?p.push(T.layoutReplot):l.fullReplot?p.push(r.plot):(p.push(f.previousPromises),G(t,h,u)||f.supplyDefaults(t),l.style&&p.push(T.doTraceStyle),(l.colorbars||h.colorbars)&&p.push(T.doColorBars),h.legend&&p.push(T.doLegend),h.layoutstyle&&p.push(T.layoutStyles),h.axrange&&Y(p,u.rangesAltered),h.ticks&&p.push(T.doTicksRelayout),h.modebar&&p.push(T.doModeBar),h.camera&&p.push(T.doCamera),p.push(C)),p.push(f.rehover,f.redrag),c.add(t,$,[t,s.undoit,u.undoit,s.traces],$,[t,s.redoit,u.redoit,s.traces]);var d=o.syncOrAsync(p,t);return d&&d.then||(d=Promise.resolve(t)),d.then(function(){return t.emit(\"plotly_update\",{data:s.eventData,layout:u.eventData}),t})}function Q(t){return function(e){e._fullLayout._guiEditing=!0;var r=t.apply(null,arguments);return e._fullLayout._guiEditing=!1,r}}var tt=[{pattern:/^hiddenlabels/,attr:\"legend.uirevision\"},{pattern:/^((x|y)axis\\d*)\\.((auto)?range|title\\.text)/},{pattern:/axis\\d*\\.showspikes$/,attr:\"modebar.uirevision\"},{pattern:/(hover|drag)mode$/,attr:\"modebar.uirevision\"},{pattern:/^(scene\\d*)\\.camera/},{pattern:/^(geo\\d*)\\.(projection|center)/},{pattern:/^(ternary\\d*\\.[abc]axis)\\.(min|title\\.text)$/},{pattern:/^(polar\\d*\\.radialaxis)\\.((auto)?range|angle|title\\.text)/},{pattern:/^(polar\\d*\\.angularaxis)\\.rotation/},{pattern:/^(mapbox\\d*)\\.(center|zoom|bearing|pitch)/},{pattern:/^legend\\.(x|y)$/,attr:\"editrevision\"},{pattern:/^(shapes|annotations)/,attr:\"editrevision\"},{pattern:/^title\\.text$/,attr:\"editrevision\"}],et=[{pattern:/^selectedpoints$/,attr:\"selectionrevision\"},{pattern:/(^|value\\.)visible$/,attr:\"legend.uirevision\"},{pattern:/^dimensions\\[\\d+\\]\\.constraintrange/},{pattern:/^node\\.(x|y|groups)/},{pattern:/^level$/},{pattern:/(^|value\\.)name$/},{pattern:/colorbar\\.title\\.text$/},{pattern:/colorbar\\.(x|y)$/,attr:\"editrevision\"}];function rt(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=t.match(n.pattern);if(i)return{head:i[1],attr:n.attr}}}function nt(t,e){var r=s(e,t).get();if(void 0!==r)return r;var n=t.split(\".\");for(n.pop();n.length>1;)if(n.pop(),void 0!==(r=s(e,n.join(\".\")+\".uirevision\").get()))return r;return e.uirevision}function it(t,e){for(var r=0;r<e.length;r++)if(e[r]._fullInput.uid===t)return r;return-1}function at(t,e,r){for(var n=0;n<e.length;n++)if(e[n].uid===t)return n;return!e[r]||e[r].uid?-1:r}function ot(t,e){var r=o.isPlainObject(t),n=Array.isArray(t);return r||n?(r&&o.isPlainObject(e)||n&&Array.isArray(e))&&JSON.stringify(t)===JSON.stringify(e):t===e}function st(t,e,r,n){var i,a,l,c=n.getValObject,u=n.flags,h=n.immutable,f=n.inArray,p=n.arrayIndex;function d(){var t=i.editType;f&&-1!==t.indexOf(\"arraydraw\")?o.pushUnique(u.arrays[f],p):(A.update(u,i),\"none\"!==t&&u.nChanges++,n.transition&&i.anim&&u.nChangesAnim++,(W.test(l)||X.test(l))&&(u.rangesAltered[r[0]]=1),Z.test(l)&&s(e,\"_inputDomain\").set(null),\"datarevision\"===a&&(u.newDataRevision=1))}function g(t){return\"data_array\"===t.valType||t.arrayOk}for(a in t){if(u.calc&&!n.transition)return;var v=t[a],m=e[a],y=r.concat(a);if(l=y.join(\".\"),\"_\"!==a.charAt(0)&&\"function\"!=typeof v&&v!==m){if((\"tick0\"===a||\"dtick\"===a)&&\"geo\"!==r[0]){var x=e.tickmode;if(\"auto\"===x||\"array\"===x||!x)continue}if((\"range\"!==a||!e.autorange)&&(\"zmin\"!==a&&\"zmax\"!==a||\"contourcarpet\"!==e.type)&&(i=c(y))&&(!i._compareAsJSON||JSON.stringify(v)!==JSON.stringify(m))){var b,_=i.valType,w=g(i),k=Array.isArray(v),T=Array.isArray(m);if(k&&T){var M=\"_input_\"+a,S=t[M],E=e[M];if(Array.isArray(S)&&S===E)continue}if(void 0===m)w&&k?u.calc=!0:d();else if(i._isLinkedToArray){var C=[],L=!1;f||(u.arrays[a]=C);var P=Math.min(v.length,m.length),O=Math.max(v.length,m.length);if(P!==O){if(\"arraydraw\"!==i.editType){d();continue}L=!0}for(b=0;b<P;b++)st(v[b],m[b],y.concat(b),o.extendFlat({inArray:a,arrayIndex:b},n));if(L)for(b=P;b<O;b++)C.push(b)}else!_&&o.isPlainObject(v)?st(v,m,y,n):w?k&&T?(h&&(u.calc=!0),(h||n.newDataRevision)&&d()):k!==T?u.calc=!0:d():k&&T&&v.length===m.length&&String(v)===String(m)||d()}}}for(a in e)if(!(a in t||\"_\"===a.charAt(0)||\"function\"==typeof e[a])){if(g(i=c(r.concat(a)))&&Array.isArray(e[a]))return void(u.calc=!0);d()}}function lt(t){var e=n.select(t),r=t._fullLayout;if(r._container=e.selectAll(\".plot-container\").data([0]),r._container.enter().insert(\"div\",\":first-child\").classed(\"plot-container\",!0).classed(\"plotly\",!0),r._paperdiv=r._container.selectAll(\".svg-container\").data([0]),r._paperdiv.enter().append(\"div\").classed(\"svg-container\",!0).style(\"position\",\"relative\"),r._glcontainer=r._paperdiv.selectAll(\".gl-container\").data([{}]),r._glcontainer.enter().append(\"div\").classed(\"gl-container\",!0),r._paperdiv.selectAll(\".main-svg\").remove(),r._paperdiv.select(\".modebar-container\").remove(),r._paper=r._paperdiv.insert(\"svg\",\":first-child\").classed(\"main-svg\",!0),r._toppaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),r._modebardiv=r._paperdiv.append(\"div\"),r._hoverpaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),!r._uid){var i={};n.selectAll(\"defs\").each(function(){this.id&&(i[this.id.split(\"-\")[1]]=1)}),r._uid=o.randstr(i)}r._paperdiv.selectAll(\".main-svg\").attr(y.svgAttrs),r._defs=r._paper.append(\"defs\").attr(\"id\",\"defs-\"+r._uid),r._clips=r._defs.append(\"g\").classed(\"clips\",!0),r._topdefs=r._toppaper.append(\"defs\").attr(\"id\",\"topdefs-\"+r._uid),r._topclips=r._topdefs.append(\"g\").classed(\"clips\",!0),r._bgLayer=r._paper.append(\"g\").classed(\"bglayer\",!0),r._draggers=r._paper.append(\"g\").classed(\"draglayer\",!0);var a=r._paper.append(\"g\").classed(\"layer-below\",!0);r._imageLowerLayer=a.append(\"g\").classed(\"imagelayer\",!0),r._shapeLowerLayer=a.append(\"g\").classed(\"shapelayer\",!0),r._cartesianlayer=r._paper.append(\"g\").classed(\"cartesianlayer\",!0),r._polarlayer=r._paper.append(\"g\").classed(\"polarlayer\",!0),r._ternarylayer=r._paper.append(\"g\").classed(\"ternarylayer\",!0),r._geolayer=r._paper.append(\"g\").classed(\"geolayer\",!0),r._funnelarealayer=r._paper.append(\"g\").classed(\"funnelarealayer\",!0),r._pielayer=r._paper.append(\"g\").classed(\"pielayer\",!0),r._sunburstlayer=r._paper.append(\"g\").classed(\"sunburstlayer\",!0),r._indicatorlayer=r._toppaper.append(\"g\").classed(\"indicatorlayer\",!0),r._glimages=r._paper.append(\"g\").classed(\"glimages\",!0);var s=r._toppaper.append(\"g\").classed(\"layer-above\",!0);r._imageUpperLayer=s.append(\"g\").classed(\"imagelayer\",!0),r._shapeUpperLayer=s.append(\"g\").classed(\"shapelayer\",!0),r._infolayer=r._toppaper.append(\"g\").classed(\"infolayer\",!0),r._menulayer=r._toppaper.append(\"g\").classed(\"menulayer\",!0),r._zoomlayer=r._toppaper.append(\"g\").classed(\"zoomlayer\",!0),r._hoverlayer=r._hoverpaper.append(\"g\").classed(\"hoverlayer\",!0),r._modebardiv.classed(\"modebar-container\",!0).style(\"position\",\"absolute\").style(\"top\",\"0px\").style(\"right\",\"0px\"),t.emit(\"plotly_framework\")}r.animate=function(t,e,r){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before animating it. For more details, see https://plot.ly/javascript/animations/\");var n=t._transitionData;n._frameQueue||(n._frameQueue=[]);var i=(r=f.supplyAnimationDefaults(r)).transition,a=r.frame;function s(t){return Array.isArray(i)?t>=i.length?i[0]:i[t]:i}function l(t){return Array.isArray(a)?t>=a.length?a[0]:a[t]:a}function c(t,e){var r=0;return function(){if(t&&++r===e)return t()}}return void 0===n._frameWaitingCnt&&(n._frameWaitingCnt=0),new Promise(function(a,u){function h(){n._currentFrame&&n._currentFrame.onComplete&&n._currentFrame.onComplete();var e=n._currentFrame=n._frameQueue.shift();if(e){var r=e.name?e.name.toString():null;t._fullLayout._currentFrame=r,n._lastFrameAt=Date.now(),n._timeToNext=e.frameOpts.duration,f.transition(t,e.frame.data,e.frame.layout,k.coerceTraceIndices(t,e.frame.traces),e.frameOpts,e.transitionOpts).then(function(){e.onComplete&&e.onComplete()}),t.emit(\"plotly_animatingframe\",{name:r,frame:e.frame,animation:{frame:e.frameOpts,transition:e.transitionOpts}})}else t.emit(\"plotly_animated\"),window.cancelAnimationFrame(n._animationRaf),n._animationRaf=null}function p(){t.emit(\"plotly_animating\"),n._lastFrameAt=-1/0,n._timeToNext=0,n._runningTransitions=0,n._currentFrame=null;var e=function(){n._animationRaf=window.requestAnimationFrame(e),Date.now()-n._lastFrameAt>n._timeToNext&&h()};e()}var d,g,v=0;function m(t){return Array.isArray(i)?v>=i.length?t.transitionOpts=i[v]:t.transitionOpts=i[0]:t.transitionOpts=i,v++,t}var y=[],x=null==e,b=Array.isArray(e);if(x||b||!o.isPlainObject(e)){if(x||-1!==[\"string\",\"number\"].indexOf(typeof e))for(d=0;d<n._frames.length;d++)(g=n._frames[d])&&(x||String(g.group)===String(e))&&y.push({type:\"byname\",name:String(g.name),data:m({name:g.name})});else if(b)for(d=0;d<e.length;d++){var _=e[d];-1!==[\"number\",\"string\"].indexOf(typeof _)?(_=String(_),y.push({type:\"byname\",name:_,data:m({name:_})})):o.isPlainObject(_)&&y.push({type:\"object\",data:m(o.extendFlat({},_))})}}else y.push({type:\"object\",data:m(o.extendFlat({},e))});for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&!n._frameHash[g.data.name])return o.warn('animate failure: frame not found: \"'+g.data.name+'\"'),void u();-1!==[\"next\",\"immediate\"].indexOf(r.mode)&&function(){if(0!==n._frameQueue.length){for(;n._frameQueue.length;){var e=n._frameQueue.pop();e.onInterrupt&&e.onInterrupt()}t.emit(\"plotly_animationinterrupted\",[])}}(),\"reverse\"===r.direction&&y.reverse();var w=t._fullLayout._currentFrame;if(w&&r.fromcurrent){var T=-1;for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&g.name===w){T=d;break}if(T>0&&T<y.length-1){var A=[];for(d=0;d<y.length;d++)g=y[d],(\"byname\"!==y[d].type||d>T)&&A.push(g);y=A}}y.length>0?function(e){if(0!==e.length){for(var i=0;i<e.length;i++){var o;o=\"byname\"===e[i].type?f.computeFrame(t,e[i].name):e[i].data;var h=l(i),d=s(i);d.duration=Math.min(d.duration,h.duration);var g={frame:o,name:e[i].name,frameOpts:h,transitionOpts:d};i===e.length-1&&(g.onComplete=c(a,2),g.onInterrupt=u),n._frameQueue.push(g)}\"immediate\"===r.mode&&(n._lastFrameAt=-1/0),n._animationRaf||p()}}(y):(t.emit(\"plotly_animated\"),a())})},r.addFrames=function(t,e,r){if(t=o.getGraphDiv(t),null==e)return Promise.resolve();if(!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before adding frames. For more details, see https://plot.ly/javascript/animations/\");var n,i,a,s,l=t._transitionData._frames,u=t._transitionData._frameHash;if(!Array.isArray(e))throw new Error(\"addFrames failure: frameList must be an Array of frame definitions\"+e);var h=l.length+2*e.length,p=[],d={};for(n=e.length-1;n>=0;n--)if(o.isPlainObject(e[n])){var g=e[n].name,v=(u[g]||d[g]||{}).name,m=e[n].name,y=u[v]||d[v];v&&m&&\"number\"==typeof m&&y&&S<E&&(S++,o.warn('addFrames: overwriting frame \"'+(u[v]||d[v]).name+'\" with a frame whose name of type \"number\" also equates to \"'+v+'\". This is valid but may potentially lead to unexpected behavior since all plotly.js frame names are stored internally as strings.'),S===E&&o.warn(\"addFrames: This API call has yielded too many of these warnings. For the rest of this call, further warnings about numeric frame names will be suppressed.\")),d[g]={name:g},p.push({frame:f.supplyFrameDefaults(e[n]),index:r&&void 0!==r[n]&&null!==r[n]?r[n]:h+n})}p.sort(function(t,e){return t.index>e.index?-1:t.index<e.index?1:0});var x=[],b=[],_=l.length;for(n=p.length-1;n>=0;n--){if(\"number\"==typeof(i=p[n].frame).name&&o.warn(\"Warning: addFrames accepts frames with numeric names, but the numbers areimplicitly cast to strings\"),!i.name)for(;u[i.name=\"frame \"+t._transitionData._counter++];);if(u[i.name]){for(a=0;a<l.length&&(l[a]||{}).name!==i.name;a++);x.push({type:\"replace\",index:a,value:i}),b.unshift({type:\"replace\",index:a,value:l[a]})}else s=Math.max(0,Math.min(p[n].index,_)),x.push({type:\"insert\",index:s,value:i}),b.unshift({type:\"delete\",index:s}),_++}var w=f.modifyFrames,k=f.modifyFrames,T=[t,b],A=[t,x];return c&&c.add(t,w,T,k,A),f.modifyFrames(t,x)},r.deleteFrames=function(t,e){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);var r,n,i=t._transitionData._frames,a=[],s=[];if(!e)for(e=[],r=0;r<i.length;r++)e.push(r);for((e=e.slice()).sort(),r=e.length-1;r>=0;r--)n=e[r],a.push({type:\"delete\",index:n}),s.unshift({type:\"insert\",index:n,value:i[n]});var l=f.modifyFrames,u=f.modifyFrames,h=[t,s],p=[t,a];return c&&c.add(t,l,h,u,p),f.modifyFrames(t,a)},r.addTraces=function t(e,n,i){e=o.getGraphDiv(e);var a,s,l=[],u=r.deleteTraces,h=t,f=[e,l],p=[e,n];for(function(t,e,r){var n,i;if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"traces must be defined.\");for(Array.isArray(e)||(e=[e]),n=0;n<e.length;n++)if(\"object\"!=typeof(i=e[n])||Array.isArray(i)||null===i)throw new Error(\"all values in traces array must be non-array objects\");if(\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&r.length!==e.length)throw new Error(\"if indices is specified, traces.length must equal indices.length\")}(e,n,i),Array.isArray(n)||(n=[n]),n=n.map(function(t){return o.extendFlat({},t)}),k.cleanData(n),a=0;a<n.length;a++)e.data.push(n[a]);for(a=0;a<n.length;a++)l.push(-n.length+a);if(\"undefined\"==typeof i)return s=r.redraw(e),c.add(e,u,f,h,p),s;Array.isArray(i)||(i=[i]);try{D(e,l,i)}catch(t){throw e.data.splice(e.data.length-n.length,n.length),t}return c.startSequence(e),c.add(e,u,f,h,p),s=r.moveTraces(e,l,i),c.stopSequence(e),s},r.deleteTraces=function t(e,n){e=o.getGraphDiv(e);var i,a,s=[],l=r.addTraces,u=t,h=[e,s,n],f=[e,n];if(\"undefined\"==typeof n)throw new Error(\"indices must be an integer or array of integers.\");for(Array.isArray(n)||(n=[n]),I(e,n,\"indices\"),(n=z(n,e.data.length-1)).sort(o.sorterDes),i=0;i<n.length;i+=1)a=e.data.splice(n[i],1)[0],s.push(a);var p=r.redraw(e);return c.add(e,l,h,u,f),p},r.extendTraces=function t(e,n,i,a){var s=R(e=o.getGraphDiv(e),n,i,a,function(t,e,r){var n,i;if(o.isTypedArray(t))if(r<0){var a=new t.constructor(0),s=F(t,e);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(l)),i.set(t),i.set(e.subarray(0,l),t.length)}else{var c=r-e.length,u=t.length-c;n.set(t.subarray(u)),n.set(e,c),i.set(t.subarray(0,u))}else n=t.concat(e),i=r>=0&&r<n.length?n.splice(0,n.length-r):[];return[n,i]}),l=r.redraw(e),u=[e,s.update,i,s.maxPoints];return c.add(e,r.prependTraces,u,t,arguments),l},r.moveTraces=function t(e,n,i){var a,s=[],l=[],u=t,h=t,f=[e=o.getGraphDiv(e),i,n],p=[e,n,i];if(D(e,n,i),n=Array.isArray(n)?n:[n],\"undefined\"==typeof i)for(i=[],a=0;a<n.length;a++)i.push(-n.length+a);for(i=Array.isArray(i)?i:[i],n=z(n,e.data.length-1),i=z(i,e.data.length-1),a=0;a<e.data.length;a++)-1===n.indexOf(a)&&s.push(e.data[a]);for(a=0;a<n.length;a++)l.push({newIndex:i[a],trace:e.data[n[a]]});for(l.sort(function(t,e){return t.newIndex-e.newIndex}),a=0;a<l.length;a+=1)s.splice(l[a].newIndex,0,l[a].trace);e.data=s;var d=r.redraw(e);return c.add(e,u,f,h,p),d},r.prependTraces=function t(e,n,i,a){var s=R(e=o.getGraphDiv(e),n,i,a,function(t,e,r){var n,i;if(o.isTypedArray(t))if(r<=0){var a=new t.constructor(0),s=F(e,t);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(0,l)),i.set(e.subarray(l)),i.set(t,l)}else{var c=r-e.length;n.set(e),n.set(t.subarray(0,c),e.length),i.set(t.subarray(c))}else n=e.concat(t),i=r>=0&&r<n.length?n.splice(r,n.length):[];return[n,i]}),l=r.redraw(e),u=[e,s.update,i,s.maxPoints];return c.add(e,r.extendTraces,u,t,arguments),l},r.newPlot=function(t,e,n,i){return t=o.getGraphDiv(t),f.cleanPlot([],{},t._fullData||[],t._fullLayout||{}),f.purge(t),r.plot(t,e,n,i)},r.plot=function(t,e,i,a){var s;if(t=o.getGraphDiv(t),l.init(t),o.isPlainObject(e)){var c=e;e=c.data,i=c.layout,a=c.config,s=c.frames}if(!1===l.triggerHandler(t,\"plotly_beforeplot\",[e,i,a]))return Promise.reject();e||i||o.isPlotDiv(t)||o.warn(\"Calling Plotly.plot as if redrawing but this container doesn't yet have a plot.\",t),O(t,a),i||(i={}),n.select(t).classed(\"js-plotly-plot\",!0),g.makeTester(),Array.isArray(t._promises)||(t._promises=[]);var h=0===(t.data||[]).length&&Array.isArray(e);Array.isArray(e)&&(k.cleanData(e),h?t.data=e:t.data.push.apply(t.data,e),t.empty=!1),t.layout&&!h||(t.layout=k.cleanLayout(i)),f.supplyDefaults(t);var v=t._fullLayout,y=v._has(\"cartesian\");if(!v._has(\"polar\")&&e&&e[0]&&e[0].r)return o.log(\"Legacy polar charts are deprecated!\"),function(t,e,r){var i=n.select(t).selectAll(\".plot-container\").data([0]);i.enter().insert(\"div\",\":first-child\").classed(\"plot-container plotly\",!0);var a=i.selectAll(\".svg-container\").data([0]);a.enter().append(\"div\").classed(\"svg-container\",!0).style(\"position\",\"relative\"),a.html(\"\"),e&&(t.data=e),r&&(t.layout=r),p.manager.fillLayout(t),a.style({width:t._fullLayout.width+\"px\",height:t._fullLayout.height+\"px\"}),t.framework=p.manager.framework(t),t.framework({data:t.data,layout:t.layout},a.node()),t.framework.setUndoPoint();var s=t.framework.svg(),l=1,c=t._fullLayout.title?t._fullLayout.title.text:\"\";\"\"!==c&&c||(l=0);var u=function(){this.call(x.convertToTspans,t)},h=s.select(\".title-group text\").call(u);if(t._context.edits.titleText){var d=o._(t,\"Click to enter Plot title\");c&&c!==d||(l=.2,h.attr({\"data-unformatted\":d}).text(d).style({opacity:l}).on(\"mouseover.opacity\",function(){n.select(this).transition().duration(100).style(\"opacity\",1)}).on(\"mouseout.opacity\",function(){n.select(this).transition().duration(1e3).style(\"opacity\",0)}));var g=function(){this.call(x.makeEditable,{gd:t}).on(\"edit\",function(e){t.framework({layout:{title:{text:e}}}),this.text(e).call(u),this.call(g)}).on(\"cancel\",function(){var t=this.attr(\"data-unformatted\");this.text(t).call(u)})};h.call(g)}return t._context.setBackground(t,t._fullLayout.paper_bgcolor),f.addLinks(t),Promise.resolve()}(t,e,i);v._replotting=!0,h&&lt(t),t.framework!==lt&&(t.framework=lt,lt(t)),g.initGradients(t),h&&d.saveShowSpikeInitial(t);var b=!t.calcdata||t.calcdata.length!==(t._fullData||[]).length;b&&f.doCalcdata(t);for(var _=0;_<t.calcdata.length;_++)t.calcdata[_][0].trace=t._fullData[_];t._context.responsive?t._responsiveChartHandler||(t._responsiveChartHandler=function(){o.isHidden(t)||f.resize(t)},window.addEventListener(\"resize\",t._responsiveChartHandler)):o.clearResponsive(t);var w=o.extendFlat({},v._size),A=0;function M(){return f.clearAutoMarginIds(t),T.drawMarginPushers(t),d.allowAutoMargin(t),f.doAutoMargin(t),f.previousPromises(t)}function S(){t._transitioning||(T.doAutoRangeAndConstraints(t),h&&d.saveRangeInitial(t),u.getComponentMethod(\"rangeslider\",\"calcAutorange\")(t))}var E=[f.previousPromises,function(){if(s)return r.addFrames(t,s)},function e(){for(var r=v._basePlotModules,n=0;n<r.length;n++)r[n].drawFramework&&r[n].drawFramework(t);if(!v._glcanvas&&v._has(\"gl\")&&(v._glcanvas=v._glcontainer.selectAll(\".gl-canvas\").data([{key:\"contextLayer\",context:!0,pick:!1},{key:\"focusLayer\",context:!1,pick:!1},{key:\"pickLayer\",context:!1,pick:!0}],function(t){return t.key}),v._glcanvas.enter().append(\"canvas\").attr(\"class\",function(t){return\"gl-canvas gl-canvas-\"+t.key.replace(\"Layer\",\"\")}).style({position:\"absolute\",top:0,left:0,overflow:\"visible\",\"pointer-events\":\"none\"})),v._glcanvas){v._glcanvas.attr(\"width\",v.width).attr(\"height\",v.height);var i=v._glcanvas.data()[0].regl;if(i&&(Math.floor(v.width)!==i._gl.drawingBufferWidth||Math.floor(v.height)!==i._gl.drawingBufferHeight)){var a=\"WebGL context buffer and canvas dimensions do not match due to browser/WebGL bug.\";if(!A)return o.log(a+\" Clearing graph and plotting again.\"),f.cleanPlot([],{},t._fullData,v),f.supplyDefaults(t),v=t._fullLayout,f.doCalcdata(t),A++,e();o.error(a)}}return\"h\"===v.modebar.orientation?v._modebardiv.style(\"height\",null).style(\"width\",\"100%\"):v._modebardiv.style(\"width\",null).style(\"height\",v.height+\"px\"),f.previousPromises(t)},M,function(){if(f.didMarginChange(w,v._size))return o.syncOrAsync([M,T.layoutStyles],t)}];y&&E.push(function(){if(b)return o.syncOrAsync([u.getComponentMethod(\"shapes\",\"calcAutorange\"),u.getComponentMethod(\"annotations\",\"calcAutorange\"),S],t);S()}),E.push(T.layoutStyles),y&&E.push(function(){return d.draw(t,h?\"\":\"redraw\")}),E.push(T.drawData,T.finalDraw,m,f.addLinks,f.rehover,f.redrag,f.doAutoMargin,f.previousPromises);var L=o.syncOrAsync(E,t);return L&&L.then||(L=Promise.resolve()),L.then(function(){return C(t),t})},r.purge=function(t){var e=(t=o.getGraphDiv(t))._fullLayout||{},r=t._fullData||[];return f.cleanPlot([],{},r,e),f.purge(t),l.purge(t),e._container&&e._container.remove(),delete t._context,t},r.react=function(t,e,n,i){var a,l,c=(t=o.getGraphDiv(t))._fullData,p=t._fullLayout;if(o.isPlotDiv(t)&&c&&p){if(o.isPlainObject(e)){var d=e;e=d.data,n=d.layout,i=d.config,a=d.frames}var g=!1;if(i){var v=o.extendDeep({},t._context);t._context=void 0,O(t,i),g=function t(e,r){var n;for(n in e)if(\"_\"!==n.charAt(0)){var i=e[n],a=r[n];if(i!==a)if(o.isPlainObject(i)&&o.isPlainObject(a)){if(t(i,a))return!0}else{if(!Array.isArray(i)||!Array.isArray(a))return!0;if(i.length!==a.length)return!0;for(var s=0;s<i.length;s++)if(i[s]!==a[s]){if(!o.isPlainObject(i[s])||!o.isPlainObject(a[s]))return!0;if(t(i[s],a[s]))return!0}}}}(v,t._context)}t.data=e||[],k.cleanData(t.data),t.layout=n||{},k.cleanLayout(t.layout),function(t,e,r,n){var i,a,l,c,u,h,f,p,d=n._preGUI,g=[],v={};for(i in d){if(u=rt(i,tt)){if(a=u.attr||u.head+\".uirevision\",(c=(l=s(n,a).get())&&nt(a,e))&&c===l&&(null===(h=d[i])&&(h=void 0),ot(p=(f=s(e,i)).get(),h))){void 0===p&&\"autorange\"===i.substr(i.length-9)&&g.push(i.substr(0,i.length-10)),f.set(N(s(n,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i);delete d[i],\"range[\"===i.substr(i.length-8,6)&&(v[i.substr(0,i.length-9)]=1)}for(var m=0;m<g.length;m++){var y=g[m];if(v[y]){var x=s(e,y).get();x&&delete x.autorange}}var b=n._tracePreGUI;for(var _ in b){var w,k=b[_],T=null;for(i in k){if(!T){var A=it(_,r);if(A<0){delete b[_];break}var M=at(_,t,(w=r[A]._fullInput).index);if(M<0){delete b[_];break}T=t[M]}if(u=rt(i,et)){if(u.attr?c=(l=s(n,u.attr).get())&&nt(u.attr,e):(l=w.uirevision,void 0===(c=T.uirevision)&&(c=e.uirevision)),c&&c===l&&(null===(h=k[i])&&(h=void 0),ot(p=(f=s(T,i)).get(),h))){f.set(N(s(w,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i+\" in trace uid \"+_);delete k[i]}}}(t.data,t.layout,c,p),f.supplyDefaults(t,{skipUpdateCalc:!0});var m=t._fullData,y=t._fullLayout,x=void 0===y.datarevision,b=y.transition,_=function(t,e,r,n,i){var a=A.layoutFlags();return a.arrays={},a.rangesAltered={},a.nChanges=0,a.nChangesAnim=0,st(e,r,[],{getValObject:function(t){return h.getLayoutValObject(r,t)},flags:a,immutable:n,transition:i,gd:t}),(a.plot||a.calc)&&(a.layoutReplot=!0),i&&a.nChanges&&a.nChangesAnim&&(a.anim=a.nChanges===a.nChangesAnim?\"all\":\"some\"),a}(t,p,y,x,b),w=_.newDataRevision,M=function(t,e,r,n,i,a){var o=e.length===r.length;if(!i&&!o)return{fullReplot:!0,calc:!0};var s,l,c=A.traceFlags();c.arrays={},c.nChanges=0,c.nChangesAnim=0;var u={getValObject:function(t){var e=h.getTraceValObject(l,t);return!l._module.animatable&&e.anim&&(e.anim=!1),e},flags:c,immutable:n,transition:i,newDataRevision:a,gd:t},p={};for(s=0;s<e.length;s++)if(r[s]){if(l=r[s]._fullInput,f.hasMakesDataTransform(l)&&(l=r[s]),p[l.uid])continue;p[l.uid]=1,st(e[s]._fullInput,l,[],u)}return(c.calc||c.plot)&&(c.fullReplot=!0),i&&c.nChanges&&c.nChangesAnim&&(c.anim=c.nChanges===c.nChangesAnim&&o?\"all\":\"some\"),c}(t,c,m,x,b,w);K(t)&&(_.layoutReplot=!0),M.calc||_.calc?t.calcdata=void 0:f.supplyDefaultsUpdateCalc(t.calcdata,m);var S=[];if(a&&(t._transitionData={},f.createTransitionData(t),S.push(function(){return r.addFrames(t,a)})),y.transition&&!g&&(M.anim||_.anim))f.doCalcdata(t),T.doAutoRangeAndConstraints(t),S.push(function(){return f.transitionFromReact(t,M,_,p)});else if(M.fullReplot||_.layoutReplot||g)t._fullLayout._skipDefaults=!0,S.push(r.plot);else{for(var E in _.arrays){var L=_.arrays[E];if(L.length){var P=u.getComponentMethod(E,\"drawOne\");if(P!==o.noop)for(var z=0;z<L.length;z++)P(t,L[z]);else{var I=u.getComponentMethod(E,\"draw\");if(I===o.noop)throw new Error(\"cannot draw components: \"+E);I(t)}}}S.push(f.previousPromises),M.style&&S.push(T.doTraceStyle),(M.colorbars||_.colorbars)&&S.push(T.doColorBars),_.legend&&S.push(T.doLegend),_.layoutstyle&&S.push(T.layoutStyles),_.axrange&&Y(S),_.ticks&&S.push(T.doTicksRelayout),_.modebar&&S.push(T.doModeBar),_.camera&&S.push(T.doCamera),S.push(C)}S.push(f.rehover,f.redrag),(l=o.syncOrAsync(S,t))&&l.then||(l=Promise.resolve(t))}else l=r.newPlot(t,e,n,i);return l.then(function(){return t.emit(\"plotly_react\",{data:e,layout:n}),t})},r.redraw=function(t){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);return k.cleanData(t.data),k.cleanLayout(t.layout),t.calcdata=void 0,r.plot(t).then(function(){return t.emit(\"plotly_redraw\"),t})},r.relayout=H,r.restyle=B,r.setPlotConfig=function(t){return o.extendFlat(_,t)},r.update=$,r._guiRelayout=Q(H),r._guiRestyle=Q(B),r._guiUpdate=Q($),r._storeDirectGUIEdit=function(t,e,r){for(var n in r)U(n,s(t,n).get(),r[n],e)}},{\"../components/color\":593,\"../components/drawing\":614,\"../constants/xmlns_namespaces\":696,\"../lib\":719,\"../lib/events\":709,\"../lib/queue\":734,\"../lib/svg_text_utils\":743,\"../plots/cartesian/axes\":767,\"../plots/cartesian/constants\":773,\"../plots/cartesian/graph_interact\":776,\"../plots/cartesian/select\":784,\"../plots/plots\":828,\"../plots/polar/legacy\":836,\"../registry\":847,\"./edit_types\":750,\"./helpers\":751,\"./manage_arrays\":753,\"./plot_config\":755,\"./plot_schema\":756,\"./subroutines\":758,d3:163,\"fast-isnumeric\":225,\"has-hover\":410}],755:[function(t,e,r){\"use strict\";var n={staticPlot:{valType:\"boolean\",dflt:!1},plotlyServerURL:{valType:\"string\",dflt:\"https://plot.ly\"},editable:{valType:\"boolean\",dflt:!1},edits:{annotationPosition:{valType:\"boolean\",dflt:!1},annotationTail:{valType:\"boolean\",dflt:!1},annotationText:{valType:\"boolean\",dflt:!1},axisTitleText:{valType:\"boolean\",dflt:!1},colorbarPosition:{valType:\"boolean\",dflt:!1},colorbarTitleText:{valType:\"boolean\",dflt:!1},legendPosition:{valType:\"boolean\",dflt:!1},legendText:{valType:\"boolean\",dflt:!1},shapePosition:{valType:\"boolean\",dflt:!1},titleText:{valType:\"boolean\",dflt:!1}},autosizable:{valType:\"boolean\",dflt:!1},responsive:{valType:\"boolean\",dflt:!1},fillFrame:{valType:\"boolean\",dflt:!1},frameMargins:{valType:\"number\",dflt:0,min:0,max:.5},scrollZoom:{valType:\"flaglist\",flags:[\"cartesian\",\"gl3d\",\"geo\",\"mapbox\"],extras:[!0,!1],dflt:\"gl3d+geo+mapbox\"},doubleClick:{valType:\"enumerated\",values:[!1,\"reset\",\"autosize\",\"reset+autosize\"],dflt:\"reset+autosize\"},doubleClickDelay:{valType:\"number\",dflt:300,min:0},showAxisDragHandles:{valType:\"boolean\",dflt:!0},showAxisRangeEntryBoxes:{valType:\"boolean\",dflt:!0},showTips:{valType:\"boolean\",dflt:!0},showLink:{valType:\"boolean\",dflt:!1},linkText:{valType:\"string\",dflt:\"Edit chart\",noBlank:!0},sendData:{valType:\"boolean\",dflt:!0},showSources:{valType:\"any\",dflt:!1},displayModeBar:{valType:\"enumerated\",values:[\"hover\",!0,!1],dflt:\"hover\"},showSendToCloud:{valType:\"boolean\",dflt:!1},showEditInChartStudio:{valType:\"boolean\",dflt:!1},modeBarButtonsToRemove:{valType:\"any\",dflt:[]},modeBarButtonsToAdd:{valType:\"any\",dflt:[]},modeBarButtons:{valType:\"any\",dflt:!1},toImageButtonOptions:{valType:\"any\",dflt:{}},displaylogo:{valType:\"boolean\",dflt:!0},watermark:{valType:\"boolean\",dflt:!1},plotGlPixelRatio:{valType:\"number\",dflt:2,min:1,max:4},setBackground:{valType:\"any\",dflt:\"transparent\"},topojsonURL:{valType:\"string\",noBlank:!0,dflt:\"https://cdn.plot.ly/\"},mapboxAccessToken:{valType:\"string\",dflt:null},logging:{valType:\"boolean\",dflt:1},queueLength:{valType:\"integer\",min:0,dflt:0},globalTransforms:{valType:\"any\",dflt:[]},locale:{valType:\"string\",dflt:\"en-US\"},locales:{valType:\"any\",dflt:{}}},i={};!function t(e,r){for(var n in e){var i=e[n];i.valType?r[n]=i.dflt:(r[n]||(r[n]={}),t(i,r[n]))}}(n,i),e.exports={configAttributes:n,dfltConfig:i}},{}],756:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=t(\"../plots/attributes\"),o=t(\"../plots/layout_attributes\"),s=t(\"../plots/frame_attributes\"),l=t(\"../plots/animation_attributes\"),c=t(\"./plot_config\").configAttributes,u=t(\"../plots/polar/legacy/area_attributes\"),h=t(\"../plots/polar/legacy/axis_attributes\"),f=t(\"./edit_types\"),p=i.extendFlat,d=i.extendDeepAll,g=i.isPlainObject,v=i.isArrayOrTypedArray,m=i.nestedProperty,y=i.valObjectMeta,x=\"_isSubplotObj\",b=\"_isLinkedToArray\",_=[x,b,\"_arrayAttrRegexps\",\"_deprecated\"];function w(t,e,r){if(!t)return!1;if(t._isLinkedToArray)if(k(e[r]))r++;else if(r<e.length)return!1;for(;r<e.length;r++){var n=t[e[r]];if(!g(n))break;if(t=n,r===e.length-1)break;if(t._isLinkedToArray){if(!k(e[++r]))return!1}else if(\"info_array\"===t.valType){var i=e[++r];if(!k(i))return!1;var a=t.items;if(Array.isArray(a)){if(i>=a.length)return!1;if(2===t.dimensions){if(r++,e.length===r)return t;var o=e[r];if(!k(o))return!1;t=a[i][o]}else t=a[i]}else t=a}}return t}function k(t){return t===Math.round(t)&&t>=0}function T(t){return function(t){r.crawl(t,function(t,e,n){r.isValObject(t)?\"data_array\"===t.valType?(t.role=\"data\",n[e+\"src\"]={valType:\"string\",editType:\"none\"}):!0===t.arrayOk&&(n[e+\"src\"]={valType:\"string\",editType:\"none\"}):g(t)&&(t.role=\"object\")})}(t),function(t){r.crawl(t,function(t,e,r){if(!t)return;var n=t[b];if(!n)return;delete t[b],r[e]={items:{}},r[e].items[n]=t,r[e].role=\"object\"})}(t),function(t){!function t(e){for(var r in e)if(g(e[r]))t(e[r]);else if(Array.isArray(e[r]))for(var n=0;n<e[r].length;n++)t(e[r][n]);else e[r]instanceof RegExp&&(e[r]=e[r].toString())}(t)}(t),t}function A(t,e,r){var n=m(t,r),i=d({},e.layoutAttributes);i[x]=!0,n.set(i)}function M(t,e,r){var n=m(t,r);n.set(d(n.get()||{},e))}r.IS_SUBPLOT_OBJ=x,r.IS_LINKED_TO_ARRAY=b,r.DEPRECATED=\"_deprecated\",r.UNDERSCORE_ATTRS=_,r.get=function(){var t={};n.allTypes.concat(\"area\").forEach(function(e){t[e]=function(t){var e,i;\"area\"===t?(e={attributes:u},i={}):(e=n.modules[t]._module,i=e.basePlotModule);var o={type:null},s=d({},a),l=d({},e.attributes);r.crawl(l,function(t,e,r,n,i){m(s,i).set(void 0),void 0===t&&m(l,i).set(void 0)}),d(o,s),n.traceIs(t,\"noOpacity\")&&delete o.opacity;n.traceIs(t,\"showLegend\")||(delete o.showlegend,delete o.legendgroup);n.traceIs(t,\"noHover\")&&(delete o.hoverinfo,delete o.hoverlabel);e.selectPoints||delete o.selectedpoints;d(o,l),i.attributes&&d(o,i.attributes);o.type=t;var c={meta:e.meta||{},categories:e.categories||{},animatable:Boolean(e.animatable),type:t,attributes:T(o)};if(e.layoutAttributes){var h={};d(h,e.layoutAttributes),c.layoutAttributes=T(h)}e.animatable||r.crawl(c,function(t){r.isValObject(t)&&\"anim\"in t&&delete t.anim});return c}(e)});var e,i={};return Object.keys(n.transformsRegistry).forEach(function(t){i[t]=function(t){var e=n.transformsRegistry[t],r=d({},e.attributes);return Object.keys(n.componentsRegistry).forEach(function(e){var i=n.componentsRegistry[e];i.schema&&i.schema.transforms&&i.schema.transforms[t]&&Object.keys(i.schema.transforms[t]).forEach(function(e){M(r,i.schema.transforms[t][e],e)})}),{attributes:T(r)}}(t)}),{defs:{valObjects:y,metaKeys:_.concat([\"description\",\"role\",\"editType\",\"impliedEdits\"]),editType:{traces:f.traces,layout:f.layout},impliedEdits:{}},traces:t,layout:function(){var t,e,r={};for(t in d(r,o),n.subplotsRegistry)if((e=n.subplotsRegistry[t]).layoutAttributes)if(Array.isArray(e.attr))for(var i=0;i<e.attr.length;i++)A(r,e,e.attr[i]);else{var a=\"subplot\"===e.attr?e.name:e.attr;A(r,e,a)}for(t in r=function(t){return p(t,{radialaxis:h.radialaxis,angularaxis:h.angularaxis}),p(t,h.layout),t}(r),n.componentsRegistry){var s=(e=n.componentsRegistry[t]).schema;if(s&&(s.subplots||s.layout)){var l=s.subplots;if(l&&l.xaxis&&!l.yaxis)for(var c in l.xaxis)delete r.yaxis[c]}else\"colorscale\"===e.name?d(r,e.layoutAttributes):e.layoutAttributes&&M(r,e.layoutAttributes,e.name)}return{layoutAttributes:T(r)}}(),transforms:i,frames:(e={frames:d({},s)},T(e),e.frames),animation:T(l),config:T(c)}},r.crawl=function(t,e,n,i){var a=n||0;i=i||\"\",Object.keys(t).forEach(function(n){var o=t[n];if(-1===_.indexOf(n)){var s=(i?i+\".\":\"\")+n;e(o,n,t,a,s),r.isValObject(o)||g(o)&&\"impliedEdits\"!==n&&r.crawl(o,e,a+1,s)}})},r.isValObject=function(t){return t&&void 0!==t.valType},r.findArrayAttributes=function(t){var e,n,i=[],o=[],s=[];function l(t,r,a,l){o=o.slice(0,l).concat([r]),s=s.slice(0,l).concat([t&&t._isLinkedToArray]),t&&(\"data_array\"===t.valType||!0===t.arrayOk)&&!(\"colorbar\"===o[l-1]&&(\"ticktext\"===r||\"tickvals\"===r))&&function t(e,r,a){var l=e[o[r]];var c=a+o[r];if(r===o.length-1)v(l)&&i.push(n+c);else if(s[r]){if(Array.isArray(l))for(var u=0;u<l.length;u++)g(l[u])&&t(l[u],r+1,c+\"[\"+u+\"].\")}else g(l)&&t(l,r+1,c+\".\")}(e,0,\"\")}e=t,n=\"\",r.crawl(a,l),t._module&&t._module.attributes&&r.crawl(t._module.attributes,l);var c=t.transforms;if(c)for(var u=0;u<c.length;u++){var h=c[u],f=h._module;f&&(n=\"transforms[\"+u+\"].\",e=h,r.crawl(f.attributes,l))}return i},r.getTraceValObject=function(t,e){var r,i,o=e[0],s=1;if(\"transforms\"===o){if(1===e.length)return a.transforms;var l=t.transforms;if(!Array.isArray(l)||!l.length)return!1;var c=e[1];if(!k(c)||c>=l.length)return!1;i=(r=(n.transformsRegistry[l[c].type]||{}).attributes)&&r[e[2]],s=3}else if(\"area\"===t.type)i=u[o];else{var h=t._module;if(h||(h=(n.modules[t.type||a.type.dflt]||{})._module),!h)return!1;if(!(i=(r=h.attributes)&&r[o])){var f=h.basePlotModule;f&&f.attributes&&(i=f.attributes[o])}i||(i=a[o])}return w(i,e,s)},r.getLayoutValObject=function(t,e){return w(function(t,e){var r,i,a,s,l=t._basePlotModules;if(l){var c;for(r=0;r<l.length;r++){if((a=l[r]).attrRegex&&a.attrRegex.test(e)){if(a.layoutAttrOverrides)return a.layoutAttrOverrides;!c&&a.layoutAttributes&&(c=a.layoutAttributes)}var u=a.baseLayoutAttrOverrides;if(u&&e in u)return u[e]}if(c)return c}var f=t._modules;if(f)for(r=0;r<f.length;r++)if((s=f[r].layoutAttributes)&&e in s)return s[e];for(i in n.componentsRegistry){if(\"colorscale\"===(a=n.componentsRegistry[i]).name&&0===e.indexOf(\"coloraxis\"))return a.layoutAttributes[e];if(!a.schema&&e===a.name)return a.layoutAttributes}if(e in o)return o[e];if(\"radialaxis\"===e||\"angularaxis\"===e)return h[e];return h.layout[e]||!1}(t,e[0]),e,1)}},{\"../lib\":719,\"../plots/animation_attributes\":762,\"../plots/attributes\":764,\"../plots/frame_attributes\":794,\"../plots/layout_attributes\":819,\"../plots/polar/legacy/area_attributes\":834,\"../plots/polar/legacy/axis_attributes\":835,\"../registry\":847,\"./edit_types\":750,\"./plot_config\":755}],757:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/attributes\"),a=\"templateitemname\",o={name:{valType:\"string\",editType:\"none\"}};function s(t){return t&&\"string\"==typeof t}function l(t){var e=t.length-1;return\"s\"!==t.charAt(e)&&n.warn(\"bad argument to arrayDefaultKey: \"+t),t.substr(0,t.length-1)+\"defaults\"}o[a]={valType:\"string\",editType:\"calc\"},r.templatedArray=function(t,e){return e._isLinkedToArray=t,e.name=o.name,e[a]=o[a],e},r.traceTemplater=function(t){var e,r,a={};for(e in t)r=t[e],Array.isArray(r)&&r.length&&(a[e]=0);return{newTrace:function(o){var s={type:e=n.coerce(o,{},i,\"type\"),_template:null};if(e in a){r=t[e];var l=a[e]%r.length;a[e]++,s._template=r[l]}return s}}},r.newContainer=function(t,e,r){var i=t._template,a=i&&(i[e]||r&&i[r]);return n.isPlainObject(a)||(a=null),t[e]={_template:a}},r.arrayTemplater=function(t,e,r){var n=t._template,i=n&&n[l(e)],o=n&&n[e];Array.isArray(o)&&o.length||(o=[]);var c={};return{newItem:function(t){var e={name:t.name,_input:t},n=e[a]=t[a];if(!s(n))return e._template=i,e;for(var l=0;l<o.length;l++){var u=o[l];if(u.name===n)return c[n]=1,e._template=u,e}return e[r]=t[r]||!1,e._template=!1,e},defaultItems:function(){for(var t=[],e=0;e<o.length;e++){var r=o[e],n=r.name;if(s(n)&&!c[n]){var i={_template:r,name:n,_input:{_templateitemname:n}};i[a]=r[a],t.push(i),c[n]=1}}return t}}},r.arrayDefaultKey=l,r.arrayEditor=function(t,e,r){var i=(n.nestedProperty(t,e).get()||[]).length,o=r._index,s=o>=i&&(r._input||{})._templateitemname;s&&(o=i);var l,c=e+\"[\"+o+\"]\";function u(){l={},s&&(l[c]={},l[c][a]=s)}function h(t,e){s?n.nestedProperty(l[c],t).set(e):l[c+\".\"+t]=e}function f(){var t=l;return u(),t}return u(),{modifyBase:function(t,e){l[t]=e},modifyItem:h,getUpdateObj:f,applyUpdate:function(e,r){e&&h(e,r);var i=f();for(var a in i)n.nestedProperty(t,a).set(i[a])}}}},{\"../lib\":719,\"../plots/attributes\":764}],758:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../registry\"),a=t(\"../plots/plots\"),o=t(\"../lib\"),s=t(\"../lib/clear_gl_canvases\"),l=t(\"../components/color\"),c=t(\"../components/drawing\"),u=t(\"../components/titles\"),h=t(\"../components/modebar\"),f=t(\"../plots/cartesian/axes\"),p=t(\"../constants/alignment\"),d=t(\"../plots/cartesian/constraints\"),g=d.enforce,v=d.clean,m=t(\"../plots/cartesian/autorange\").doAutoRange,y=\"start\",x=\"middle\",b=\"end\";function _(t,e,r){for(var n=0;n<r.length;n++){var i=r[n][0],a=r[n][1];if(!(i[0]>=t[1]||i[1]<=t[0])&&(a[0]<e[1]&&a[1]>e[0]))return!0}return!1}function w(t){var e,i,a,s,u,d,g=t._fullLayout,v=g._size,m=v.p,y=f.list(t,\"\",!0);if(g._paperdiv.style({width:t._context.responsive&&g.autosize&&!t._context._hasZeroWidth&&!t.layout.width?\"100%\":g.width+\"px\",height:t._context.responsive&&g.autosize&&!t._context._hasZeroHeight&&!t.layout.height?\"100%\":g.height+\"px\"}).selectAll(\".main-svg\").call(c.setSize,g.width,g.height),t._context.setBackground(t,g.paper_bgcolor),r.drawMainTitle(t),h.manage(t),!g._has(\"cartesian\"))return t._promises.length&&Promise.all(t._promises);function x(t,e,r){var n=t._lw/2;return\"x\"===t._id.charAt(0)?e?\"top\"===r?e._offset-m-n:e._offset+e._length+m+n:v.t+v.h*(1-(t.position||0))+n%1:e?\"right\"===r?e._offset+e._length+m+n:e._offset-m-n:v.l+v.w*(t.position||0)+n%1}for(e=0;e<y.length;e++){var b=(s=y[e])._anchorAxis;s._linepositions={},s._lw=c.crispRound(t,s.linewidth,1),s._mainLinePosition=x(s,b,s.side),s._mainMirrorPosition=s.mirror&&b?x(s,b,p.OPPOSITE_SIDE[s.side]):null}var w=[],T=[],M=[],S=1===l.opacity(g.paper_bgcolor)&&1===l.opacity(g.plot_bgcolor)&&g.paper_bgcolor===g.plot_bgcolor;for(i in g._plots)if((a=g._plots[i]).mainplot)a.bg&&a.bg.remove(),a.bg=void 0;else{var E=a.xaxis.domain,C=a.yaxis.domain,L=a.plotgroup;if(_(E,C,M)){var P=L.node(),O=a.bg=o.ensureSingle(L,\"rect\",\"bg\");P.insertBefore(O.node(),P.childNodes[0]),T.push(i)}else L.select(\"rect.bg\").remove(),M.push([E,C]),S||(w.push(i),T.push(i))}var z,I,D,R,F,B,N,j,U,V,q,H,G,Y=g._bgLayer.selectAll(\".bg\").data(w);for(Y.enter().append(\"rect\").classed(\"bg\",!0),Y.exit().remove(),Y.each(function(t){g._plots[t].bg=n.select(this)}),e=0;e<T.length;e++)a=g._plots[T[e]],u=a.xaxis,d=a.yaxis,a.bg&&a.bg.call(c.setRect,u._offset-m,d._offset-m,u._length+2*m,d._length+2*m).call(l.fill,g.plot_bgcolor).style(\"stroke-width\",0);if(!g._hasOnlyLargeSploms)for(i in g._plots){a=g._plots[i],u=a.xaxis,d=a.yaxis;var W,X,Z=a.clipId=\"clip\"+g._uid+i+\"plot\",J=o.ensureSingleById(g._clips,\"clipPath\",Z,function(t){t.classed(\"plotclip\",!0).append(\"rect\")});a.clipRect=J.select(\"rect\").attr({width:u._length,height:d._length}),c.setTranslate(a.plot,u._offset,d._offset),a._hasClipOnAxisFalse?(W=null,X=Z):(W=Z,X=null),c.setClipUrl(a.plot,W,t),a.layerClipId=X}function K(t){return\"M\"+z+\",\"+t+\"H\"+I}function $(t){return\"M\"+u._offset+\",\"+t+\"h\"+u._length}function Q(t){return\"M\"+t+\",\"+j+\"V\"+N}function tt(t){return\"M\"+t+\",\"+d._offset+\"v\"+d._length}function et(t,e,r){if(!t.showline||i!==t._mainSubplot)return\"\";if(!t._anchorAxis)return r(t._mainLinePosition);var n=e(t._mainLinePosition);return t.mirror&&(n+=e(t._mainMirrorPosition)),n}for(i in g._plots){a=g._plots[i],u=a.xaxis,d=a.yaxis;var rt=\"M0,0\";k(u,i)&&(F=A(u,\"left\",d,y),z=u._offset-(F?m+F:0),B=A(u,\"right\",d,y),I=u._offset+u._length+(B?m+B:0),D=x(u,d,\"bottom\"),R=x(u,d,\"top\"),!(G=!u._anchorAxis||i!==u._mainSubplot)||\"allticks\"!==u.mirror&&\"all\"!==u.mirror||(u._linepositions[i]=[D,R]),rt=et(u,K,$),G&&u.showline&&(\"all\"===u.mirror||\"allticks\"===u.mirror)&&(rt+=K(D)+K(R)),a.xlines.style(\"stroke-width\",u._lw+\"px\").call(l.stroke,u.showline?u.linecolor:\"rgba(0,0,0,0)\")),a.xlines.attr(\"d\",rt);var nt=\"M0,0\";k(d,i)&&(q=A(d,\"bottom\",u,y),N=d._offset+d._length+(q?m:0),H=A(d,\"top\",u,y),j=d._offset-(H?m:0),U=x(d,u,\"left\"),V=x(d,u,\"right\"),!(G=!d._anchorAxis||i!==d._mainSubplot)||\"allticks\"!==d.mirror&&\"all\"!==d.mirror||(d._linepositions[i]=[U,V]),nt=et(d,Q,tt),G&&d.showline&&(\"all\"===d.mirror||\"allticks\"===d.mirror)&&(nt+=Q(U)+Q(V)),a.ylines.style(\"stroke-width\",d._lw+\"px\").call(l.stroke,d.showline?d.linecolor:\"rgba(0,0,0,0)\")),a.ylines.attr(\"d\",nt)}return f.makeClipPaths(t),t._promises.length&&Promise.all(t._promises)}function k(t,e){return(t.ticks||t.showline)&&(e===t._mainSubplot||\"all\"===t.mirror||\"allticks\"===t.mirror)}function T(t,e,r){if(!r.showline||!r._lw)return!1;if(\"all\"===r.mirror||\"allticks\"===r.mirror)return!0;var n=r._anchorAxis;if(!n)return!1;var i=p.FROM_BL[e];return r.side===e?n.domain[i]===t.domain[i]:r.mirror&&n.domain[1-i]===t.domain[1-i]}function A(t,e,r,n){if(T(t,e,r))return r._lw;for(var i=0;i<n.length;i++){var a=n[i];if(a._mainAxis===r._mainAxis&&T(t,e,a))return a._lw}return 0}r.layoutStyles=function(t){return o.syncOrAsync([a.doAutoMargin,w],t)},r.drawMainTitle=function(t){var e=t._fullLayout,r=function(t){var e=t.title,r=x;o.isRightAnchor(e)?r=b:o.isLeftAnchor(e)&&(r=y);return r}(e),n=function(t){var e=t.title,r=\"0em\";o.isTopAnchor(e)?r=p.CAP_SHIFT+\"em\":o.isMiddleAnchor(e)&&(r=p.MID_SHIFT+\"em\");return r}(e);u.draw(t,\"gtitle\",{propContainer:e,propName:\"title.text\",placeholder:e._dfltTitle.plot,attributes:{x:function(t,e){var r=t.title,n=t._size,i=0;e===y?i=r.pad.l:e===b&&(i=-r.pad.r);switch(r.xref){case\"paper\":return n.l+n.w*r.x+i;case\"container\":default:return t.width*r.x+i}}(e,r),y:function(t,e){var r=t.title,n=t._size,i=0;\"0em\"!==e&&e?e===p.CAP_SHIFT+\"em\"&&(i=r.pad.t):i=-r.pad.b;if(\"auto\"===r.y)return n.t/2;switch(r.yref){case\"paper\":return n.t+n.h-n.h*r.y+i;case\"container\":default:return t.height-t.height*r.y+i}}(e,n),\"text-anchor\":r,dy:n}})},r.doTraceStyle=function(t){var e,n=t.calcdata,o=[];for(e=0;e<n.length;e++){var l=n[e],c=l[0]||{},u=c.trace||{},h=u._module||{},f=h.arraysToCalcdata;f&&f(l,u);var p=h.editStyle;p&&o.push({fn:p,cd0:c})}if(o.length){for(e=0;e<o.length;e++){var d=o[e];d.fn(t,d.cd0)}s(t),r.redrawReglTraces(t)}return a.style(t),i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doColorBars=function(t){return i.getComponentMethod(\"colorbar\",\"draw\")(t),a.previousPromises(t)},r.layoutReplot=function(t){var e=t.layout;return t.layout=void 0,i.call(\"plot\",t,\"\",e)},r.doLegend=function(t){return i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doTicksRelayout=function(t){return f.draw(t,\"redraw\"),t._fullLayout._hasOnlyLargeSploms&&(i.subplotsRegistry.splom.updateGrid(t),s(t),r.redrawReglTraces(t)),r.drawMainTitle(t),a.previousPromises(t)},r.doModeBar=function(t){var e=t._fullLayout;h.manage(t);for(var r=0;r<e._basePlotModules.length;r++){var n=e._basePlotModules[r].updateFx;n&&n(t)}return a.previousPromises(t)},r.doCamera=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){var i=e[r[n]],a=i._scene,o=i.camera;a.setCamera(o)}},r.drawData=function(t){var e=t._fullLayout;s(t);for(var n=e._basePlotModules,o=0;o<n.length;o++)n[o].plot(t);return r.redrawReglTraces(t),a.style(t),i.getComponentMethod(\"shapes\",\"draw\")(t),i.getComponentMethod(\"annotations\",\"draw\")(t),e._replotting=!1,a.previousPromises(t)},r.redrawReglTraces=function(t){var e=t._fullLayout;if(e._has(\"regl\")){var r,n,i=t._fullData,a=[],s=[];for(e._hasOnlyLargeSploms&&e._splomGrid.draw(),r=0;r<i.length;r++){var l=i[r];!0===l.visible&&0!==l._length&&(\"splom\"===l.type?e._splomScenes[l.uid].draw():\"scattergl\"===l.type?o.pushUnique(a,l.xaxis+l.yaxis):\"scatterpolargl\"===l.type&&o.pushUnique(s,l.subplot))}for(r=0;r<a.length;r++)(n=e._plots[a[r]])._scene&&n._scene.draw();for(r=0;r<s.length;r++)(n=e[s[r]]._subplot)._scene&&n._scene.draw()}},r.doAutoRangeAndConstraints=function(t){for(var e,r,n=t._fullLayout,i=f.list(t,\"\",!0),a=n._axisMatchGroups||[],s=0;s<i.length;s++)e=i[s],v(t,e),m(t,e);g(t);t:for(var l=0;l<a.length;l++){var c,u=a[l],h=null;for(c in u){if(!1===(e=f.getFromId(t,c)).autorange)continue t;r=o.simpleMap(e.range,e.r2l),h?h[0]<h[1]?(h[0]=Math.min(h[0],r[0]),h[1]=Math.max(h[1],r[1])):(h[0]=Math.max(h[0],r[0]),h[1]=Math.min(h[1],r[1])):h=r}for(c in u)(e=f.getFromId(t,c)).range=o.simpleMap(h,e.l2r),e._input.range=e.range.slice(),e.setScale()}},r.finalDraw=function(t){i.getComponentMethod(\"shapes\",\"draw\")(t),i.getComponentMethod(\"images\",\"draw\")(t),i.getComponentMethod(\"annotations\",\"draw\")(t),i.getComponentMethod(\"rangeslider\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t)},r.drawMarginPushers=function(t){i.getComponentMethod(\"legend\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t),i.getComponentMethod(\"sliders\",\"draw\")(t),i.getComponentMethod(\"updatemenus\",\"draw\")(t),i.getComponentMethod(\"colorbar\",\"draw\")(t)}},{\"../components/color\":593,\"../components/drawing\":614,\"../components/modebar\":652,\"../components/titles\":681,\"../constants/alignment\":688,\"../lib\":719,\"../lib/clear_gl_canvases\":704,\"../plots/cartesian/autorange\":766,\"../plots/cartesian/axes\":767,\"../plots/cartesian/constraints\":774,\"../plots/plots\":828,\"../registry\":847,d3:163}],759:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.isPlainObject,a=t(\"./plot_schema\"),o=t(\"../plots/plots\"),s=t(\"../plots/attributes\"),l=t(\"./plot_template\"),c=t(\"./plot_config\").dfltConfig;function u(t,e){t=n.extendDeep({},t);var r,a,o=Object.keys(t).sort();function s(e,r,n){if(i(r)&&i(e))u(e,r);else if(Array.isArray(r)&&Array.isArray(e)){var o=l.arrayTemplater({_template:t},n);for(a=0;a<r.length;a++){var s=r[a],c=o.newItem(s)._template;c&&u(c,s)}var h=o.defaultItems();for(a=0;a<h.length;a++)r.push(h[a]._template);for(a=0;a<r.length;a++)delete r[a].templateitemname}}for(r=0;r<o.length;r++){var c=o[r],f=t[c];if(c in e?s(f,e[c],c):e[c]=f,h(c)===c)for(var p in e){var d=h(p);p===d||d!==c||p in t||s(f,e[p],c)}}}function h(t){return t.replace(/[0-9]+$/,\"\")}function f(t,e,r,a,o){var s=o&&r(o);for(var c in t){var u=t[c],d=p(t,c,a),g=p(t,c,o),v=r(g);if(!v){var m=h(c);m!==c&&(v=r(g=p(t,m,o)))}if((!s||s!==v)&&!(!v||v._noTemplating||\"data_array\"===v.valType||v.arrayOk&&Array.isArray(u)))if(!v.valType&&i(u))f(u,e,r,d,g);else if(v._isLinkedToArray&&Array.isArray(u))for(var y=!1,x=0,b={},_=0;_<u.length;_++){var w=u[_];if(i(w)){var k=w.name;if(k)b[k]||(f(w,e,r,p(u,x,d),p(u,x,g)),x++,b[k]=1);else if(!y){var T=p(t,l.arrayDefaultKey(c),a),A=p(u,x,d);f(w,e,r,A,p(u,x,g));var M=n.nestedProperty(e,A);n.nestedProperty(e,T).set(M.get()),M.set(null),y=!0}}}else{n.nestedProperty(e,d).set(u)}}}function p(t,e,r){return r?Array.isArray(t)?r+\"[\"+e+\"]\":r+\".\"+e:e}function d(t){for(var e=0;e<t.length;e++)if(i(t[e]))return!0}function g(t){var e;switch(t.code){case\"data\":e=\"The template has no key data.\";break;case\"layout\":e=\"The template has no key layout.\";break;case\"missing\":e=t.path?\"There are no templates for item \"+t.path+\" with name \"+t.templateitemname:\"There are no templates for trace \"+t.index+\", of type \"+t.traceType+\".\";break;case\"unused\":e=t.path?\"The template item at \"+t.path+\" was not used in constructing the plot.\":t.dataCount?\"Some of the templates of type \"+t.traceType+\" were not used. The template has \"+t.templateCount+\" traces, the data only has \"+t.dataCount+\" of this type.\":\"The template has \"+t.templateCount+\" traces of type \"+t.traceType+\" but there are none in the data.\";break;case\"reused\":e=\"Some of the templates of type \"+t.traceType+\" were used more than once. The template has \"+t.templateCount+\" traces, the data has \"+t.dataCount+\" of this type.\"}return t.msg=e,t}r.makeTemplate=function(t){t=n.isPlainObject(t)?t:n.getGraphDiv(t),t=n.extendDeep({_context:c},{data:t.data,layout:t.layout}),o.supplyDefaults(t);var e=t.data||[],r=t.layout||{};r._basePlotModules=t._fullLayout._basePlotModules,r._modules=t._fullLayout._modules;var l={data:{},layout:{}};e.forEach(function(t){var e={};f(t,e,function(t,e){return a.getTraceValObject(t,n.nestedProperty({},e).parts)}.bind(null,t));var r=n.coerce(t,{},s,\"type\"),i=l.data[r];i||(i=l.data[r]=[]),i.push(e)}),f(r,l.layout,function(t,e){return a.getLayoutValObject(t,n.nestedProperty({},e).parts)}.bind(null,r)),delete l.layout.template;var h=r.template;if(i(h)){var p,d,g,v,m,y,x=h.layout;i(x)&&u(x,l.layout);var b=h.data;if(i(b)){for(d in l.data)if(g=b[d],Array.isArray(g)){for(y=(m=l.data[d]).length,v=g.length,p=0;p<y;p++)u(g[p%v],m[p]);for(p=y;p<v;p++)m.push(n.extendDeep({},g[p]))}for(d in b)d in l.data||(l.data[d]=n.extendDeep([],b[d]))}}return l},r.validateTemplate=function(t,e){var r=n.extendDeep({},{_context:c,data:t.data,layout:t.layout}),a=r.layout||{};i(e)||(e=a.template||{});var s=e.layout,l=e.data,u=[];r.layout=a,r.layout.template=e,o.supplyDefaults(r);var f=r._fullLayout,v=r._fullData,m={};if(i(s)?(!function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)&&i(e[n])){var a,o=h(n),s=[];for(a=0;a<r.length;a++)s.push(p(e,n,r[a])),o!==n&&s.push(p(e,o,r[a]));for(a=0;a<s.length;a++)m[s[a]]=1;t(e[n],s)}}(f,[\"layout\"]),function t(e,r){for(var n in e)if(-1===n.indexOf(\"defaults\")&&i(e[n])){var a=p(e,n,r);m[a]?t(e[n],a):u.push({code:\"unused\",path:a})}}(s,\"layout\")):u.push({code:\"layout\"}),i(l)){for(var y,x={},b=0;b<v.length;b++){var _=v[b];x[y=_.type]=(x[y]||0)+1,_._fullInput._template||u.push({code:\"missing\",index:_._fullInput.index,traceType:y})}for(y in l){var w=l[y].length,k=x[y]||0;w>k?u.push({code:\"unused\",traceType:y,templateCount:w,dataCount:k}):k>w&&u.push({code:\"reused\",traceType:y,templateCount:w,dataCount:k})}}else u.push({code:\"data\"});if(function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)){var a=e[n],o=p(e,n,r);i(a)?(Array.isArray(e)&&!1===a._template&&a.templateitemname&&u.push({code:\"missing\",path:o,templateitemname:a.templateitemname}),t(a,o)):Array.isArray(a)&&d(a)&&t(a,o)}}({data:v,layout:f},\"\"),u.length)return u.map(g)}},{\"../lib\":719,\"../plots/attributes\":764,\"../plots/plots\":828,\"./plot_config\":755,\"./plot_schema\":756,\"./plot_template\":757}],760:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./plot_api\"),a=t(\"../lib\"),o=t(\"../snapshot/helpers\"),s=t(\"../snapshot/tosvg\"),l=t(\"../snapshot/svgtoimg\"),c={format:{valType:\"enumerated\",values:[\"png\",\"jpeg\",\"webp\",\"svg\"],dflt:\"png\"},width:{valType:\"number\",min:1},height:{valType:\"number\",min:1},scale:{valType:\"number\",min:0,dflt:1},setBackground:{valType:\"any\",dflt:!1},imageDataOnly:{valType:\"boolean\",dflt:!1}};e.exports=function(t,e){var r,u,h,f;function p(t){return!(t in e)||a.validate(e[t],c[t])}if(e=e||{},a.isPlainObject(t)?(r=t.data||[],u=t.layout||{},h=t.config||{},f={}):(t=a.getGraphDiv(t),r=a.extendDeep([],t.data),u=a.extendDeep({},t.layout),h=t._context,f=t._fullLayout||{}),!p(\"width\")&&null!==e.width||!p(\"height\")&&null!==e.height)throw new Error(\"Height and width should be pixel values.\");if(!p(\"format\"))throw new Error(\"Image format is not jpeg, png, svg or webp.\");var d={};function g(t,r){return a.coerce(e,d,c,t,r)}var v=g(\"format\"),m=g(\"width\"),y=g(\"height\"),x=g(\"scale\"),b=g(\"setBackground\"),_=g(\"imageDataOnly\"),w=document.createElement(\"div\");w.style.position=\"absolute\",w.style.left=\"-5000px\",document.body.appendChild(w);var k=a.extendFlat({},u);m?k.width=m:null===e.width&&n(f.width)&&(k.width=f.width),y?k.height=y:null===e.height&&n(f.height)&&(k.height=f.height);var T=a.extendFlat({},h,{_exportedPlot:!0,staticPlot:!0,setBackground:b}),A=o.getRedrawFunc(w);function M(){return new Promise(function(t){setTimeout(t,o.getDelay(w._fullLayout))})}function S(){return new Promise(function(t,e){var r=s(w,v,x),n=w._fullLayout.width,c=w._fullLayout.height;if(i.purge(w),document.body.removeChild(w),\"svg\"===v)return t(_?r:o.encodeSVG(r));var u=document.createElement(\"canvas\");u.id=a.randstr(),l({format:v,width:n,height:c,scale:x,canvas:u,svg:r,promise:!0}).then(t).catch(e)})}return new Promise(function(t,e){i.plot(w,r,k,T).then(A).then(M).then(S).then(function(e){t(function(t){return _?t.replace(o.IMAGE_URL_PREFIX,\"\"):t}(e))}).catch(function(t){e(t)})})}},{\"../lib\":719,\"../snapshot/helpers\":851,\"../snapshot/svgtoimg\":853,\"../snapshot/tosvg\":855,\"./plot_api\":754,\"fast-isnumeric\":225}],761:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/plots\"),a=t(\"./plot_schema\"),o=t(\"./plot_config\").dfltConfig,s=n.isPlainObject,l=Array.isArray,c=n.isArrayOrTypedArray;function u(t,e,r,i,a,o){o=o||[];for(var h=Object.keys(t),f=0;f<h.length;f++){var v=h[f];if(\"transforms\"!==v){var m=o.slice();m.push(v);var y=t[v],x=e[v],b=g(r,v),_=\"info_array\"===(b||{}).valType,w=\"colorscale\"===(b||{}).valType,k=(b||{}).items;if(d(r,v))if(s(y)&&s(x))u(y,x,b,i,a,m);else if(_&&l(y)){y.length>x.length&&i.push(p(\"unused\",a,m.concat(x.length)));var T,A,M,S,E,C=x.length,L=Array.isArray(k);if(L&&(C=Math.min(C,k.length)),2===b.dimensions)for(A=0;A<C;A++)if(l(y[A])){y[A].length>x[A].length&&i.push(p(\"unused\",a,m.concat(A,x[A].length)));var P=x[A].length;for(T=0;T<(L?Math.min(P,k[A].length):P);T++)M=L?k[A][T]:k,S=y[A][T],E=x[A][T],n.validate(S,M)?E!==S&&E!==+S&&i.push(p(\"dynamic\",a,m.concat(A,T),S,E)):i.push(p(\"value\",a,m.concat(A,T),S))}else i.push(p(\"array\",a,m.concat(A),y[A]));else for(A=0;A<C;A++)M=L?k[A]:k,S=y[A],E=x[A],n.validate(S,M)?E!==S&&E!==+S&&i.push(p(\"dynamic\",a,m.concat(A),S,E)):i.push(p(\"value\",a,m.concat(A),S))}else if(b.items&&!_&&l(y)){var O,z,I=k[Object.keys(k)[0]],D=[];for(O=0;O<x.length;O++){var R=x[O]._index||O;if((z=m.slice()).push(R),s(y[R])&&s(x[O])){D.push(R);var F=y[R],B=x[O];s(F)&&!1!==F.visible&&!1===B.visible?i.push(p(\"invisible\",a,z)):u(F,B,I,i,a,z)}}for(O=0;O<y.length;O++)(z=m.slice()).push(O),s(y[O])?-1===D.indexOf(O)&&i.push(p(\"unused\",a,z)):i.push(p(\"object\",a,z,y[O]))}else!s(y)&&s(x)?i.push(p(\"object\",a,m,y)):c(y)||!c(x)||_||w?v in e?n.validate(y,b)?\"enumerated\"===b.valType&&(b.coerceNumber&&y!==+x||y!==x)&&i.push(p(\"dynamic\",a,m,y,x)):i.push(p(\"value\",a,m,y)):i.push(p(\"unused\",a,m,y)):i.push(p(\"array\",a,m,y));else i.push(p(\"schema\",a,m))}}return i}e.exports=function(t,e){var r,c,h=a.get(),f=[],d={_context:n.extendFlat({},o)};l(t)?(d.data=n.extendDeep([],t),r=t):(d.data=[],r=[],f.push(p(\"array\",\"data\"))),s(e)?(d.layout=n.extendDeep({},e),c=e):(d.layout={},c={},arguments.length>1&&f.push(p(\"object\",\"layout\"))),i.supplyDefaults(d);for(var g=d._fullData,v=r.length,m=0;m<v;m++){var y=r[m],x=[\"data\",m];if(s(y)){var b=g[m],_=b.type,w=h.traces[_].attributes;w.type={valType:\"enumerated\",values:[_]},!1===b.visible&&!1!==y.visible&&f.push(p(\"invisible\",x)),u(y,b,w,f,x);var k=y.transforms,T=b.transforms;if(k){l(k)||f.push(p(\"array\",x,[\"transforms\"])),x.push(\"transforms\");for(var A=0;A<k.length;A++){var M=[\"transforms\",A],S=k[A].type;if(s(k[A])){var E=h.transforms[S]?h.transforms[S].attributes:{};E.type={valType:\"enumerated\",values:Object.keys(h.transforms)},u(k[A],T[A],E,f,x,M)}else f.push(p(\"object\",x,M))}}}else f.push(p(\"object\",x))}return u(c,d._fullLayout,function(t,e){for(var r=t.layout.layoutAttributes,i=0;i<e.length;i++){var a=e[i],o=t.traces[a.type],s=o.layoutAttributes;s&&(a.subplot?n.extendFlat(r[o.attributes.subplot.dflt],s):n.extendFlat(r,s))}return r}(h,g),f,\"layout\"),0===f.length?void 0:f};var h={object:function(t,e){return(\"layout\"===t&&\"\"===e?\"The layout argument\":\"data\"===t[0]&&\"\"===e?\"Trace \"+t[1]+\" in the data argument\":f(t)+\"key \"+e)+\" must be linked to an object container\"},array:function(t,e){return(\"data\"===t?\"The data argument\":f(t)+\"key \"+e)+\" must be linked to an array container\"},schema:function(t,e){return f(t)+\"key \"+e+\" is not part of the schema\"},unused:function(t,e,r){var n=s(r)?\"container\":\"key\";return f(t)+n+\" \"+e+\" did not get coerced\"},dynamic:function(t,e,r,n){return[f(t)+\"key\",e,\"(set to '\"+r+\"')\",\"got reset to\",\"'\"+n+\"'\",\"during defaults.\"].join(\" \")},invisible:function(t,e){return(e?f(t)+\"item \"+e:\"Trace \"+t[1])+\" got defaulted to be not visible\"},value:function(t,e,r){return[f(t)+\"key \"+e,\"is set to an invalid value (\"+r+\")\"].join(\" \")}};function f(t){return l(t)?\"In data trace \"+t[1]+\", \":\"In \"+t+\", \"}function p(t,e,r,i,a){var o,s;r=r||\"\",l(e)?(o=e[0],s=e[1]):(o=e,s=null);var c=function(t){if(!l(t))return String(t);for(var e=\"\",r=0;r<t.length;r++){var n=t[r];\"number\"==typeof n?e=e.substr(0,e.length-1)+\"[\"+n+\"]\":e+=n,r<t.length-1&&(e+=\".\")}return e}(r),u=h[t](e,c,i,a);return n.log(u),{code:t,container:o,trace:s,path:r,astr:c,msg:u}}function d(t,e){var r=m(e),n=r.keyMinusId,i=r.id;return!!(n in t&&t[n]._isSubplotObj&&i)||e in t}function g(t,e){return e in t?t[e]:t[m(e).keyMinusId]}var v=n.counterRegex(\"([a-z]+)\");function m(t){var e=t.match(v);return{keyMinusId:e&&e[1],id:e&&e[2]}}},{\"../lib\":719,\"../plots/plots\":828,\"./plot_config\":755,\"./plot_schema\":756}],762:[function(t,e,r){\"use strict\";e.exports={mode:{valType:\"enumerated\",dflt:\"afterall\",values:[\"immediate\",\"next\",\"afterall\"]},direction:{valType:\"enumerated\",values:[\"forward\",\"reverse\"],dflt:\"forward\"},fromcurrent:{valType:\"boolean\",dflt:!1},frame:{duration:{valType:\"number\",min:0,dflt:500},redraw:{valType:\"boolean\",dflt:!0}},transition:{duration:{valType:\"number\",min:0,dflt:500,editType:\"none\"},easing:{valType:\"enumerated\",dflt:\"cubic-in-out\",values:[\"linear\",\"quad\",\"cubic\",\"sin\",\"exp\",\"circle\",\"elastic\",\"back\",\"bounce\",\"linear-in\",\"quad-in\",\"cubic-in\",\"sin-in\",\"exp-in\",\"circle-in\",\"elastic-in\",\"back-in\",\"bounce-in\",\"linear-out\",\"quad-out\",\"cubic-out\",\"sin-out\",\"exp-out\",\"circle-out\",\"elastic-out\",\"back-out\",\"bounce-out\",\"linear-in-out\",\"quad-in-out\",\"cubic-in-out\",\"sin-in-out\",\"exp-in-out\",\"circle-in-out\",\"elastic-in-out\",\"back-in-out\",\"bounce-in-out\"],editType:\"none\"},ordering:{valType:\"enumerated\",values:[\"layout first\",\"traces first\"],dflt:\"layout first\",editType:\"none\"}}}},{}],763:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\");e.exports=function(t,e,r){var a,o,s=r.name,l=r.inclusionAttr||\"visible\",c=e[s],u=n.isArrayOrTypedArray(t[s])?t[s]:[],h=e[s]=[],f=i.arrayTemplater(e,s,l);for(a=0;a<u.length;a++){var p=u[a];n.isPlainObject(p)?o=f.newItem(p):(o=f.newItem({}))[l]=!1,o._index=a,!1!==o[l]&&r.handleItemDefaults(p,o,e,r),h.push(o)}var d=f.defaultItems();for(a=0;a<d.length;a++)(o=d[a])._index=h.length,r.handleItemDefaults({},o,e,r,{}),h.push(o);if(n.isArrayOrTypedArray(c)){var g=Math.min(c.length,h.length);for(a=0;a<g;a++)n.relinkPrivateKeys(h[a],c[a])}return h}},{\"../lib\":719,\"../plot_api/plot_template\":757}],764:[function(t,e,r){\"use strict\";var n=t(\"../components/fx/attributes\");e.exports={type:{valType:\"enumerated\",values:[],dflt:\"scatter\",editType:\"calc+clearAxisTypes\",_noTemplating:!0},visible:{valType:\"enumerated\",values:[!0,!1,\"legendonly\"],dflt:!0,editType:\"calc\"},showlegend:{valType:\"boolean\",dflt:!0,editType:\"style\"},legendgroup:{valType:\"string\",dflt:\"\",editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"style\"},name:{valType:\"string\",editType:\"style\"},uid:{valType:\"string\",editType:\"plot\",anim:!0},ids:{valType:\"data_array\",editType:\"calc\",anim:!0},customdata:{valType:\"data_array\",editType:\"calc\"},meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},selectedpoints:{valType:\"any\",editType:\"calc\"},hoverinfo:{valType:\"flaglist\",flags:[\"x\",\"y\",\"z\",\"text\",\"name\"],extras:[\"all\",\"none\",\"skip\"],arrayOk:!0,dflt:\"all\",editType:\"none\"},hoverlabel:n.hoverlabel,stream:{token:{valType:\"string\",noBlank:!0,strict:!0,editType:\"calc\"},maxpoints:{valType:\"number\",min:0,max:1e4,dflt:500,editType:\"calc\"},editType:\"calc\"},transforms:{_isLinkedToArray:\"transform\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"}}},{\"../components/fx/attributes\":623}],765:[function(t,e,r){\"use strict\";e.exports={xaxis:{valType:\"subplotid\",dflt:\"x\",editType:\"calc+clearAxisTypes\"},yaxis:{valType:\"subplotid\",dflt:\"y\",editType:\"calc+clearAxisTypes\"}}},{}],766:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").FP_SAFE,o=t(\"../../registry\");function s(t,e){var r,n,a=[],o=l(e),s=c(t,e),u=s.min,h=s.max;if(0===u.length||0===h.length)return i.simpleMap(e.range,e.r2l);var f=u[0].val,p=h[0].val;for(r=1;r<u.length&&f===p;r++)f=Math.min(f,u[r].val);for(r=1;r<h.length&&f===p;r++)p=Math.max(p,h[r].val);var d=!1;if(e.range){var g=i.simpleMap(e.range,e.r2l);d=g[1]<g[0]}\"reversed\"===e.autorange&&(d=!0,e.autorange=!0);var v,m,y,x,b,_,w=e.rangemode,k=\"tozero\"===w,T=\"nonnegative\"===w,A=e._length,M=A/10,S=0;for(r=0;r<u.length;r++)for(v=u[r],n=0;n<h.length;n++)(_=(m=h[n]).val-v.val)>0&&((b=A-o(v)-o(m))>M?_/b>S&&(y=v,x=m,S=_/b):_/A>S&&(y={val:v.val,pad:0},x={val:m.val,pad:0},S=_/A));if(f===p){var E=f-1,C=f+1;if(k)if(0===f)a=[0,1];else{var L=(f>0?h:u).reduce(function(t,e){return Math.max(t,o(e))},0),P=f/(1-Math.min(.5,L/A));a=f>0?[0,P]:[P,0]}else a=T?[Math.max(0,E),Math.max(1,C)]:[E,C]}else k?(y.val>=0&&(y={val:0,pad:0}),x.val<=0&&(x={val:0,pad:0})):T&&(y.val-S*o(y)<0&&(y={val:0,pad:0}),x.val<=0&&(x={val:1,pad:0})),S=(x.val-y.val)/(A-o(y)-o(x)),a=[y.val-S*o(y),x.val+S*o(x)];return d&&a.reverse(),i.simpleMap(a,e.l2r||Number)}function l(t){var e=t._length/20;return\"domain\"===t.constrain&&t._inputDomain&&(e*=(t._inputDomain[1]-t._inputDomain[0])/(t.domain[1]-t.domain[0])),function(t){return t.pad+(t.extrapad?e:0)}}function c(t,e){var r,n,i,a=e._id,o=t._fullData,s=t._fullLayout,l=[],c=[];function f(t,e){for(r=0;r<e.length;r++){var o=t[e[r]],s=(o._extremes||{})[a];if(!0===o.visible&&s){for(n=0;n<s.min.length;n++)i=s.min[n],u(l,i.val,i.pad,{extrapad:i.extrapad});for(n=0;n<s.max.length;n++)i=s.max[n],h(c,i.val,i.pad,{extrapad:i.extrapad})}}}return f(o,e._traceIndices),f(s.annotations||[],e._annIndices||[]),f(s.shapes||[],e._shapeIndices||[]),{min:l,max:c}}function u(t,e,r,n){f(t,e,r,n,d)}function h(t,e,r,n){f(t,e,r,n,g)}function f(t,e,r,n,i){for(var a=n.tozero,o=n.extrapad,s=!0,l=0;l<t.length&&s;l++){var c=t[l];if(i(c.val,e)&&c.pad>=r&&(c.extrapad||!o)){s=!1;break}i(e,c.val)&&c.pad<=r&&(o||!c.extrapad)&&(t.splice(l,1),l--)}if(s){var u=a&&0===e;t.push({val:e,pad:u?0:r,extrapad:!u&&o})}}function p(t){return n(t)&&Math.abs(t)<a}function d(t,e){return t<=e}function g(t,e){return t>=e}e.exports={getAutoRange:s,makePadFn:l,doAutoRange:function(t,e){if(e.setScale(),e.autorange){e.range=s(t,e),e._r=e.range.slice(),e._rl=i.simpleMap(e._r,e.r2l);var r=e._input,n={};n[e._attr+\".range\"]=e.range,n[e._attr+\".autorange\"]=e.autorange,o.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,n),r.range=e.range.slice(),r.autorange=e.autorange}var a=e._anchorAxis;if(a&&a.rangeslider){var l=a.rangeslider[e._name];l&&\"auto\"===l.rangemode&&(l.range=s(t,e)),a._input.rangeslider[e._name]=i.extendFlat({},l)}},findExtremes:function(t,e,r){r||(r={});t._m||t.setScale();var i,o,s,l,c,f,d,g,v,m=[],y=[],x=e.length,b=r.padded||!1,_=r.tozero&&(\"linear\"===t.type||\"-\"===t.type),w=\"log\"===t.type,k=!1;function T(t){if(Array.isArray(t))return k=!0,function(e){return Math.max(Number(t[e]||0),0)};var e=Math.max(Number(t||0),0);return function(){return e}}var A=T((t._m>0?r.ppadplus:r.ppadminus)||r.ppad||0),M=T((t._m>0?r.ppadminus:r.ppadplus)||r.ppad||0),S=T(r.vpadplus||r.vpad),E=T(r.vpadminus||r.vpad);if(!k){if(g=1/0,v=-1/0,w)for(i=0;i<x;i++)(o=e[i])<g&&o>0&&(g=o),o>v&&o<a&&(v=o);else for(i=0;i<x;i++)(o=e[i])<g&&o>-a&&(g=o),o>v&&o<a&&(v=o);e=[g,v],x=2}var C={tozero:_,extrapad:b};function L(r){s=e[r],n(s)&&(f=A(r),d=M(r),g=s-E(r),v=s+S(r),w&&g<v/10&&(g=v/10),l=t.c2l(g),c=t.c2l(v),_&&(l=Math.min(0,l),c=Math.max(0,c)),p(l)&&u(m,l,d,C),p(c)&&h(y,c,f,C))}var P=Math.min(6,x);for(i=0;i<P;i++)L(i);for(i=x-1;i>=P;i--)L(i);return{min:m,max:y,opts:r}},concatExtremes:c}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../registry\":847,\"fast-isnumeric\":225}],767:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../components/titles\"),u=t(\"../../components/color\"),h=t(\"../../components/drawing\"),f=t(\"./layout_attributes\"),p=t(\"./clean_ticks\"),d=t(\"../../constants/numerical\"),g=d.ONEAVGYEAR,v=d.ONEAVGMONTH,m=d.ONEDAY,y=d.ONEHOUR,x=d.ONEMIN,b=d.ONESEC,_=d.MINUS_SIGN,w=d.BADNUM,k=t(\"../../constants/alignment\").MID_SHIFT,T=t(\"../../constants/alignment\").LINE_SPACING,A=e.exports={};A.setConvert=t(\"./set_convert\");var M=t(\"./axis_autotype\"),S=t(\"./axis_ids\");A.id2name=S.id2name,A.name2id=S.name2id,A.cleanId=S.cleanId,A.list=S.list,A.listIds=S.listIds,A.getFromId=S.getFromId,A.getFromTrace=S.getFromTrace;var E=t(\"./autorange\");A.getAutoRange=E.getAutoRange,A.findExtremes=E.findExtremes,A.coerceRef=function(t,e,r,n,i,a){var o=n.charAt(n.length-1),l=r._fullLayout._subplots[o+\"axis\"],c=n+\"ref\",u={};return i||(i=l[0]||a),a||(a=i),u[c]={valType:\"enumerated\",values:l.concat(a?[a]:[]),dflt:i},s.coerce(t,e,u,c)},A.coercePosition=function(t,e,r,n,i,a){var o,l;if(\"paper\"===n||\"pixel\"===n)o=s.ensureNumber,l=r(i,a);else{var c=A.getFromId(e,n);l=r(i,a=c.fraction2r(a)),o=c.cleanPos}t[i]=o(l)},A.cleanPosition=function(t,e,r){return(\"paper\"===r||\"pixel\"===r?s.ensureNumber:A.getFromId(e,r).cleanPos)(t)},A.redrawComponents=function(t,e){e=e||A.listIds(t);var r=t._fullLayout;function n(n,i,a,s){for(var l=o.getComponentMethod(n,i),c={},u=0;u<e.length;u++)for(var h=r[A.id2name(e[u])][a],f=0;f<h.length;f++){var p=h[f];if(!c[p]&&(l(t,p),c[p]=1,s))return}}n(\"annotations\",\"drawOne\",\"_annIndices\"),n(\"shapes\",\"drawOne\",\"_shapeIndices\"),n(\"images\",\"draw\",\"_imgIndices\",!0)};var C=A.getDataConversions=function(t,e,r,n){var i,a=\"x\"===r||\"y\"===r||\"z\"===r?r:n;if(Array.isArray(a)){if(i={type:M(n),_categories:[]},A.setConvert(i),\"category\"===i.type)for(var o=0;o<n.length;o++)i.d2c(n[o])}else i=A.getFromTrace(t,e,a);return i?{d2c:i.d2c,c2d:i.c2d}:\"ids\"===a?{d2c:P,c2d:P}:{d2c:L,c2d:L}};function L(t){return+t}function P(t){return String(t)}A.getDataToCoordFunc=function(t,e,r,n){return C(t,e,r,n).d2c},A.counterLetter=function(t){var e=t.charAt(0);return\"x\"===e?\"y\":\"y\"===e?\"x\":void 0},A.minDtick=function(t,e,r,n){-1===[\"log\",\"category\",\"multicategory\"].indexOf(t.type)&&n?void 0===t._minDtick?(t._minDtick=e,t._forceTick0=r):t._minDtick&&((t._minDtick/e+1e-6)%1<2e-6&&((r-t._forceTick0)/e%1+1.000001)%1<2e-6?(t._minDtick=e,t._forceTick0=r):((e/t._minDtick+1e-6)%1>2e-6||((r-t._forceTick0)/t._minDtick%1+1.000001)%1>2e-6)&&(t._minDtick=0)):t._minDtick=0},A.saveRangeInitial=function(t,e){for(var r=A.list(t,\"\",!0),n=!1,i=0;i<r.length;i++){var a=r[i],o=void 0===a._rangeInitial,s=o||!(a.range[0]===a._rangeInitial[0]&&a.range[1]===a._rangeInitial[1]);(o&&!1===a.autorange||e&&s)&&(a._rangeInitial=a.range.slice(),n=!0)}return n},A.saveShowSpikeInitial=function(t,e){for(var r=A.list(t,\"\",!0),n=!1,i=\"on\",a=0;a<r.length;a++){var o=r[a],s=void 0===o._showSpikeInitial,l=s||!(o.showspikes===o._showspikes);(s||e&&l)&&(o._showSpikeInitial=o.showspikes,n=!0),\"on\"!==i||o.showspikes||(i=\"off\")}return t._fullLayout._cartesianSpikesEnabled=i,n},A.autoBin=function(t,e,r,n,a,o){var l,c=s.aggNums(Math.min,null,t),u=s.aggNums(Math.max,null,t);if(\"category\"===e.type||\"multicategory\"===e.type)return{start:c-.5,end:u+.5,size:Math.max(1,Math.round(o)||1),_dataSpan:u-c};if(a||(a=e.calendar),l=\"log\"===e.type?{type:\"linear\",range:[c,u]}:{type:e.type,range:s.simpleMap([c,u],e.c2r,0,a),calendar:a},A.setConvert(l),o=o&&p.dtick(o,l.type))l.dtick=o,l.tick0=p.tick0(void 0,l.type,a);else{var h;if(r)h=(u-c)/r;else{var f=s.distinctVals(t),d=Math.pow(10,Math.floor(Math.log(f.minDiff)/Math.LN10)),g=d*s.roundUp(f.minDiff/d,[.9,1.9,4.9,9.9],!0);h=Math.max(g,2*s.stdev(t)/Math.pow(t.length,n?.25:.4)),i(h)||(h=1)}A.autoTicks(l,h)}var v,y=l.dtick,x=A.tickIncrement(A.tickFirst(l),y,\"reverse\",a);if(\"number\"==typeof y)v=(x=function(t,e,r,n,a){var o=0,s=0,l=0,c=0;function u(e){return(1+100*(e-t)/r.dtick)%100<2}for(var h=0;h<e.length;h++)e[h]%1==0?l++:i(e[h])||c++,u(e[h])&&o++,u(e[h]+r.dtick/2)&&s++;var f=e.length-c;if(l===f&&\"date\"!==r.type)r.dtick<1?t=n-.5*r.dtick:(t-=.5)+r.dtick<n&&(t+=r.dtick);else if(s<.1*f&&(o>.3*f||u(n)||u(a))){var p=r.dtick/2;t+=t+p<n?p:-p}return t}(x,t,l,c,u))+(1+Math.floor((u-x)/y))*y;else for(\"M\"===l.dtick.charAt(0)&&(x=function(t,e,r,n,i){var a=s.findExactDates(e,i);if(a.exactDays>.8){var o=Number(r.substr(1));a.exactYears>.8&&o%12==0?t=A.tickIncrement(t,\"M6\",\"reverse\")+1.5*m:a.exactMonths>.8?t=A.tickIncrement(t,\"M1\",\"reverse\")+15.5*m:t-=m/2;var l=A.tickIncrement(t,r);if(l<=n)return l}return t}(x,t,y,c,a)),v=x,0;v<=u;)v=A.tickIncrement(v,y,!1,a),0;return{start:e.c2r(x,0,a),end:e.c2r(v,0,a),size:y,_dataSpan:u-c}},A.prepTicks=function(t){var e=s.simpleMap(t.range,t.r2l);if(\"auto\"===t.tickmode||!t.dtick){var r,n=t.nticks;n||(\"category\"===t.type||\"multicategory\"===t.type?(r=t.tickfont?1.2*(t.tickfont.size||12):15,n=t._length/r):(r=\"y\"===t._id.charAt(0)?40:80,n=s.constrain(t._length/r,4,9)+1),\"radialaxis\"===t._name&&(n*=2)),\"array\"===t.tickmode&&(n*=100),A.autoTicks(t,Math.abs(e[1]-e[0])/n),t._minDtick>0&&t.dtick<2*t._minDtick&&(t.dtick=t._minDtick,t.tick0=t.l2r(t._forceTick0))}t.tick0||(t.tick0=\"date\"===t.type?\"2000-01-01\":0),\"date\"===t.type&&t.dtick<.1&&(t.dtick=.1),j(t)},A.calcTicks=function(t){A.prepTicks(t);var e=s.simpleMap(t.range,t.r2l);if(\"array\"===t.tickmode)return function(t){var e=t.tickvals,r=t.ticktext,n=new Array(e.length),i=s.simpleMap(t.range,t.r2l),a=1.0001*i[0]-1e-4*i[1],o=1.0001*i[1]-1e-4*i[0],l=Math.min(a,o),c=Math.max(a,o),u=0;Array.isArray(r)||(r=[]);var h=\"category\"===t.type?t.d2l_noadd:t.d2l;\"log\"===t.type&&\"L\"!==String(t.dtick).charAt(0)&&(t.dtick=\"L\"+Math.pow(10,Math.floor(Math.min(t.range[0],t.range[1]))-1));for(var f=0;f<e.length;f++){var p=h(e[f]);p>l&&p<c&&(void 0===r[f]?n[u]=A.tickText(t,p):n[u]=U(t,p,String(r[f])),u++)}u<e.length&&n.splice(u,e.length-u);return n}(t);t._tmin=A.tickFirst(t);var r=1.0001*e[0]-1e-4*e[1],n=1.0001*e[1]-1e-4*e[0],a=e[1]<e[0];if(t._tmin<r!==a)return[];var o=[];\"category\"!==t.type&&\"multicategory\"!==t.type||(n=a?Math.max(-.5,n):Math.min(t._categories.length-.5,n));for(var l=\"log\"===t.type&&!(i(t.dtick)||\"L\"===t.dtick.charAt(0)),c=null,u=Math.max(1e3,t._length||0),h=t._tmin;(a?h>=n:h<=n)&&!(o.length>u||h===c);h=A.tickIncrement(h,t.dtick,a,t.calendar)){c=h;var f=!1;l&&h!==(0|h)&&(f=!0),o.push({minor:f,value:h})}rt(t)&&360===Math.abs(e[1]-e[0])&&o.pop(),t._tmax=(o[o.length-1]||{}).value,t._prevDateHead=\"\",t._inCalcTicks=!0;for(var p=new Array(o.length),d=0;d<o.length;d++)p[d]=A.tickText(t,o[d].value,!1,o[d].minor);return t._inCalcTicks=!1,p};var O=[2,5,10],z=[1,2,3,6,12],I=[1,2,5,10,15,30],D=[1,2,3,7,14],R=[-.046,0,.301,.477,.602,.699,.778,.845,.903,.954,1],F=[-.301,0,.301,.699,1],B=[15,30,45,90,180];function N(t,e,r){return e*s.roundUp(t/e,r)}function j(t){var e=t.dtick;if(t._tickexponent=0,i(e)||\"string\"==typeof e||(e=1),\"category\"!==t.type&&\"multicategory\"!==t.type||(t._tickround=null),\"date\"===t.type){var r=t.r2l(t.tick0),n=t.l2r(r).replace(/(^-|i)/g,\"\"),a=n.length;if(\"M\"===String(e).charAt(0))a>10||\"01-01\"!==n.substr(5)?t._tickround=\"d\":t._tickround=+e.substr(1)%12==0?\"y\":\"m\";else if(e>=m&&a<=10||e>=15*m)t._tickround=\"d\";else if(e>=x&&a<=16||e>=y)t._tickround=\"M\";else if(e>=b&&a<=19||e>=x)t._tickround=\"S\";else{var o=t.l2r(r+e).replace(/^-/,\"\").length;t._tickround=Math.max(a,o)-20,t._tickround<0&&(t._tickround=4)}}else if(i(e)||\"L\"===e.charAt(0)){var s=t.range.map(t.r2d||Number);i(e)||(e=Number(e.substr(1))),t._tickround=2-Math.floor(Math.log(e)/Math.LN10+.01);var l=Math.max(Math.abs(s[0]),Math.abs(s[1])),c=Math.floor(Math.log(l)/Math.LN10+.01);Math.abs(c)>3&&(q(t.exponentformat)&&!H(c)?t._tickexponent=3*Math.round((c-1)/3):t._tickexponent=c)}else t._tickround=null}function U(t,e,r){var n=t.tickfont||{};return{x:e,dx:0,dy:0,text:r||\"\",fontSize:n.size,font:n.family,fontColor:n.color}}A.autoTicks=function(t,e){var r;function n(t){return Math.pow(t,Math.floor(Math.log(e)/Math.LN10))}if(\"date\"===t.type){t.tick0=s.dateTick0(t.calendar);var a=2*e;a>g?(e/=g,r=n(10),t.dtick=\"M\"+12*N(e,r,O)):a>v?(e/=v,t.dtick=\"M\"+N(e,1,z)):a>m?(t.dtick=N(e,m,D),t.tick0=s.dateTick0(t.calendar,!0)):a>y?t.dtick=N(e,y,z):a>x?t.dtick=N(e,x,I):a>b?t.dtick=N(e,b,I):(r=n(10),t.dtick=N(e,r,O))}else if(\"log\"===t.type){t.tick0=0;var o=s.simpleMap(t.range,t.r2l);if(e>.7)t.dtick=Math.ceil(e);else if(Math.abs(o[1]-o[0])<1){var l=1.5*Math.abs((o[1]-o[0])/e);e=Math.abs(Math.pow(10,o[1])-Math.pow(10,o[0]))/l,r=n(10),t.dtick=\"L\"+N(e,r,O)}else t.dtick=e>.3?\"D2\":\"D1\"}else\"category\"===t.type||\"multicategory\"===t.type?(t.tick0=0,t.dtick=Math.ceil(Math.max(e,1))):rt(t)?(t.tick0=0,r=1,t.dtick=N(e,r,B)):(t.tick0=0,r=n(10),t.dtick=N(e,r,O));if(0===t.dtick&&(t.dtick=1),!i(t.dtick)&&\"string\"!=typeof t.dtick){var c=t.dtick;throw t.dtick=1,\"ax.dtick error: \"+String(c)}},A.tickIncrement=function(t,e,r,a){var o=r?-1:1;if(i(e))return t+o*e;var l=e.charAt(0),c=o*Number(e.substr(1));if(\"M\"===l)return s.incrementMonth(t,c,a);if(\"L\"===l)return Math.log(Math.pow(10,t)+c)/Math.LN10;if(\"D\"===l){var u=\"D2\"===e?F:R,h=t+.01*o,f=s.roundUp(s.mod(h,1),u,r);return Math.floor(h)+Math.log(n.round(Math.pow(10,f),1))/Math.LN10}throw\"unrecognized dtick \"+String(e)},A.tickFirst=function(t){var e=t.r2l||Number,r=s.simpleMap(t.range,e),a=r[1]<r[0],o=a?Math.floor:Math.ceil,l=1.0001*r[0]-1e-4*r[1],c=t.dtick,u=e(t.tick0);if(i(c)){var h=o((l-u)/c)*c+u;return\"category\"!==t.type&&\"multicategory\"!==t.type||(h=s.constrain(h,0,t._categories.length-1)),h}var f=c.charAt(0),p=Number(c.substr(1));if(\"M\"===f){for(var d,g,v,m=0,y=u;m<10;){if(((d=A.tickIncrement(y,c,a,t.calendar))-l)*(y-l)<=0)return a?Math.min(y,d):Math.max(y,d);g=(l-(y+d)/2)/(d-y),v=f+(Math.abs(Math.round(g))||1)*p,y=A.tickIncrement(y,v,g<0?!a:a,t.calendar),m++}return s.error(\"tickFirst did not converge\",t),y}if(\"L\"===f)return Math.log(o((Math.pow(10,l)-u)/p)*p+u)/Math.LN10;if(\"D\"===f){var x=\"D2\"===c?F:R,b=s.roundUp(s.mod(l,1),x,a);return Math.floor(l)+Math.log(n.round(Math.pow(10,b),1))/Math.LN10}throw\"unrecognized dtick \"+String(c)},A.tickText=function(t,e,r,n){var a,o=U(t,e),l=\"array\"===t.tickmode,c=r||l,u=t.type,h=\"category\"===u?t.d2l_noadd:t.d2l;if(l&&Array.isArray(t.ticktext)){var f=s.simpleMap(t.range,t.r2l),p=Math.abs(f[1]-f[0])/1e4;for(a=0;a<t.ticktext.length&&!(Math.abs(e-h(t.tickvals[a]))<p);a++);if(a<t.ticktext.length)return o.text=String(t.ticktext[a]),o}function d(n){if(void 0===n)return!0;if(r)return\"none\"===n;var i={first:t._tmin,last:t._tmax}[n];return\"all\"!==n&&e!==i}var g=r?\"never\":\"none\"!==t.exponentformat&&d(t.showexponent)?\"hide\":\"\";if(\"date\"===u?function(t,e,r,n){var a=t._tickround,o=r&&t.hoverformat||A.getTickFormat(t);n&&(a=i(a)?4:{y:\"m\",m:\"d\",d:\"M\",M:\"S\",S:4}[a]);var l,c=s.formatDate(e.x,o,a,t._dateFormat,t.calendar,t._extraFormat),u=c.indexOf(\"\\n\");-1!==u&&(l=c.substr(u+1),c=c.substr(0,u));n&&(\"00:00:00\"===c||\"00:00\"===c?(c=l,l=\"\"):8===c.length&&(c=c.replace(/:00$/,\"\")));l&&(r?\"d\"===a?c+=\", \"+l:c=l+(c?\", \"+c:\"\"):t._inCalcTicks&&l===t._prevDateHead||(c+=\"<br>\"+l,t._prevDateHead=l));e.text=c}(t,o,r,c):\"log\"===u?function(t,e,r,n,a){var o=t.dtick,l=e.x,c=t.tickformat,u=\"string\"==typeof o&&o.charAt(0);\"never\"===a&&(a=\"\");n&&\"L\"!==u&&(o=\"L3\",u=\"L\");if(c||\"L\"===u)e.text=G(Math.pow(10,l),t,a,n);else if(i(o)||\"D\"===u&&s.mod(l+.01,1)<.1){var h=Math.round(l),f=Math.abs(h),p=t.exponentformat;\"power\"===p||q(p)&&H(h)?(e.text=0===h?1:1===h?\"10\":\"10<sup>\"+(h>1?\"\":_)+f+\"</sup>\",e.fontSize*=1.25):(\"e\"===p||\"E\"===p)&&f>2?e.text=\"1\"+p+(h>0?\"+\":_)+f:(e.text=G(Math.pow(10,l),t,\"\",\"fakehover\"),\"D1\"===o&&\"y\"===t._id.charAt(0)&&(e.dy-=e.fontSize/6))}else{if(\"D\"!==u)throw\"unrecognized dtick \"+String(o);e.text=String(Math.round(Math.pow(10,s.mod(l,1)))),e.fontSize*=.75}if(\"D1\"===t.dtick){var d=String(e.text).charAt(0);\"0\"!==d&&\"1\"!==d||(\"y\"===t._id.charAt(0)?e.dx-=e.fontSize/4:(e.dy+=e.fontSize/2,e.dx+=(t.range[1]>t.range[0]?1:-1)*e.fontSize*(l<0?.5:.25)))}}(t,o,0,c,g):\"category\"===u?function(t,e){var r=t._categories[Math.round(e.x)];void 0===r&&(r=\"\");e.text=String(r)}(t,o):\"multicategory\"===u?function(t,e,r){var n=Math.round(e.x),i=t._categories[n]||[],a=void 0===i[1]?\"\":String(i[1]),o=void 0===i[0]?\"\":String(i[0]);r?e.text=o+\" - \"+a:(e.text=a,e.text2=o)}(t,o,r):rt(t)?function(t,e,r,n,i){if(\"radians\"!==t.thetaunit||r)e.text=G(e.x,t,i,n);else{var a=e.x/180;if(0===a)e.text=\"0\";else{var o=function(t){function e(t,e){return Math.abs(t-e)<=1e-6}var r=function(t){var r=1;for(;!e(Math.round(t*r)/r,t);)r*=10;return r}(t),n=t*r,i=Math.abs(function t(r,n){return e(n,0)?r:t(n,r%n)}(n,r));return[Math.round(n/i),Math.round(r/i)]}(a);if(o[1]>=100)e.text=G(s.deg2rad(e.x),t,i,n);else{var l=e.x<0;1===o[1]?1===o[0]?e.text=\"\\u03c0\":e.text=o[0]+\"\\u03c0\":e.text=[\"<sup>\",o[0],\"</sup>\",\"\\u2044\",\"<sub>\",o[1],\"</sub>\",\"\\u03c0\"].join(\"\"),l&&(e.text=_+e.text)}}}}(t,o,r,c,g):function(t,e,r,n,i){\"never\"===i?i=\"\":\"all\"===t.showexponent&&Math.abs(e.x/t.dtick)<1e-6&&(i=\"hide\");e.text=G(e.x,t,i,n)}(t,o,0,c,g),n||(t.tickprefix&&!d(t.showtickprefix)&&(o.text=t.tickprefix+o.text),t.ticksuffix&&!d(t.showticksuffix)&&(o.text+=t.ticksuffix)),\"boundaries\"===t.tickson||t.showdividers){var v=function(e){var r=t.l2p(e);return r>=0&&r<=t._length?e:null};o.xbnd=[v(o.x-.5),v(o.x+t.dtick-.5)]}return o},A.hoverLabelText=function(t,e,r){if(r!==w&&r!==e)return A.hoverLabelText(t,e)+\" - \"+A.hoverLabelText(t,r);var n=\"log\"===t.type&&e<=0,i=A.tickText(t,t.c2l(n?-e:e),\"hover\").text;return n?0===e?\"0\":_+i:i};var V=[\"f\",\"p\",\"n\",\"\\u03bc\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\"];function q(t){return\"SI\"===t||\"B\"===t}function H(t){return t>14||t<-15}function G(t,e,r,n){var a=t<0,o=e._tickround,l=r||e.exponentformat||\"B\",c=e._tickexponent,u=A.getTickFormat(e),h=e.separatethousands;if(n){var f={exponentformat:l,dtick:\"none\"===e.showexponent?e.dtick:i(t)&&Math.abs(t)||1,range:\"none\"===e.showexponent?e.range.map(e.r2d):[0,t||1]};j(f),o=(Number(f._tickround)||0)+4,c=f._tickexponent,e.hoverformat&&(u=e.hoverformat)}if(u)return e._numFormat(u)(t).replace(/-/g,_);var p,d=Math.pow(10,-o)/2;if(\"none\"===l&&(c=0),(t=Math.abs(t))<d)t=\"0\",a=!1;else{if(t+=d,c&&(t*=Math.pow(10,-c),o+=c),0===o)t=String(Math.floor(t));else if(o<0){t=(t=String(Math.round(t))).substr(0,t.length+o);for(var g=o;g<0;g++)t+=\"0\"}else{var v=(t=String(t)).indexOf(\".\")+1;v&&(t=t.substr(0,v+o).replace(/\\.?0+$/,\"\"))}t=s.numSeparate(t,e._separators,h)}c&&\"hide\"!==l&&(q(l)&&H(c)&&(l=\"power\"),p=c<0?_+-c:\"power\"!==l?\"+\"+c:String(c),\"e\"===l||\"E\"===l?t+=l+p:\"power\"===l?t+=\"\\xd710<sup>\"+p+\"</sup>\":\"B\"===l&&9===c?t+=\"B\":q(l)&&(t+=V[c/3+5]));return a?_+t:t}function Y(t,e){var r=t._id.charAt(0),n=t._tickAngles[e]||0,i=s.deg2rad(n),a=Math.sin(i),o=Math.cos(i),l=0,c=0;return t._selections[e].each(function(){var t=J(this),e=h.bBox(t.node()),r=e.width,n=e.height;l=Math.max(l,o*r,a*n),c=Math.max(c,a*r,o*n)}),{x:c,y:l}[r]}function W(t){return[t.text,t.x,t.axInfo,t.font,t.fontSize,t.fontColor].join(\"_\")}function X(t,e){var r,n=t._fullLayout._size,i=e._id.charAt(0),a=e.side;return\"free\"!==e.anchor?r=S.getFromId(t,e.anchor):\"x\"===i?r={_offset:n.t+(1-(e.position||0))*n.h,_length:0}:\"y\"===i&&(r={_offset:n.l+(e.position||0)*n.w,_length:0}),\"top\"===a||\"left\"===a?r._offset:\"bottom\"===a||\"right\"===a?r._offset+r._length:void 0}function Z(t,e){var r=t.l2p(e);return r>1&&r<t._length-1}function J(t){var e=n.select(t),r=e.select(\".text-math-group\");return r.empty()?e.select(\"text\"):r}function K(t){return t._id+\".automargin\"}function $(t){return t._id+\".rangeslider\"}function Q(t,e){for(var r=0;r<e.length;r++)-1===t.indexOf(e[r])&&t.push(e[r])}function tt(t,e,r){var n,i,a=[],o=[],l=t.layout;for(n=0;n<e.length;n++)a.push(A.getFromId(t,e[n]));for(n=0;n<r.length;n++)o.push(A.getFromId(t,r[n]));var c=Object.keys(f),u=[\"anchor\",\"domain\",\"overlaying\",\"position\",\"side\",\"tickangle\",\"editType\"],h=[\"linear\",\"log\"];for(n=0;n<c.length;n++){var p=c[n],d=a[0][p],g=o[0][p],v=!0,m=!1,y=!1;if(\"_\"!==p.charAt(0)&&\"function\"!=typeof d&&-1===u.indexOf(p)){for(i=1;i<a.length&&v;i++){var x=a[i][p];\"type\"===p&&-1!==h.indexOf(d)&&-1!==h.indexOf(x)&&d!==x?m=!0:x!==d&&(v=!1)}for(i=1;i<o.length&&v;i++){var b=o[i][p];\"type\"===p&&-1!==h.indexOf(g)&&-1!==h.indexOf(b)&&g!==b?y=!0:o[i][p]!==g&&(v=!1)}v&&(m&&(l[a[0]._name].type=\"linear\"),y&&(l[o[0]._name].type=\"linear\"),et(l,p,a,o,t._fullLayout._dfltTitle))}}for(n=0;n<t._fullLayout.annotations.length;n++){var _=t._fullLayout.annotations[n];-1!==e.indexOf(_.xref)&&-1!==r.indexOf(_.yref)&&s.swapAttrs(l.annotations[n],[\"?\"])}}function et(t,e,r,n,i){var a,o=s.nestedProperty,l=o(t[r[0]._name],e).get(),c=o(t[n[0]._name],e).get();for(\"title\"===e&&(l&&l.text===i.x&&(l.text=i.y),c&&c.text===i.y&&(c.text=i.x)),a=0;a<r.length;a++)o(t,r[a]._name+\".\"+e).set(c);for(a=0;a<n.length;a++)o(t,n[a]._name+\".\"+e).set(l)}function rt(t){return\"angularaxis\"===t._id}A.getTickFormat=function(t){var e,r,n,i,a,o,s,l;function c(t){return\"string\"!=typeof t?t:Number(t.replace(\"M\",\"\"))*v}function u(t,e){var r=[\"L\",\"D\"];if(typeof t==typeof e){if(\"number\"==typeof t)return t-e;var n=r.indexOf(t.charAt(0)),i=r.indexOf(e.charAt(0));return n===i?Number(t.replace(/(L|D)/g,\"\"))-Number(e.replace(/(L|D)/g,\"\")):n-i}return\"number\"==typeof t?1:-1}function h(t,e){var r=null===e[0],n=null===e[1],i=u(t,e[0])>=0,a=u(t,e[1])<=0;return(r||i)&&(n||a)}if(t.tickformatstops&&t.tickformatstops.length>0)switch(t.type){case\"date\":case\"linear\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&(i=t.dtick,a=n.dtickrange,o=void 0,void 0,void 0,o=c||function(t){return t},s=a[0],l=a[1],(!s&&\"number\"!=typeof s||o(s)<=o(i))&&(!l&&\"number\"!=typeof l||o(l)>=o(i)))){r=n;break}break;case\"log\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&h(t.dtick,n.dtickrange)){r=n;break}}return r?r.value:t.tickformat},A.getSubplots=function(t,e){var r=t._fullLayout._subplots,n=r.cartesian.concat(r.gl2d||[]),i=e?A.findSubplotsWithAxis(n,e):n;return i.sort(function(t,e){var r=t.substr(1).split(\"y\"),n=e.substr(1).split(\"y\");return r[0]===n[0]?+r[1]-+n[1]:+r[0]-+n[0]}),i},A.findSubplotsWithAxis=function(t,e){for(var r=new RegExp(\"x\"===e._id.charAt(0)?\"^\"+e._id+\"y\":e._id+\"$\"),n=[],i=0;i<t.length;i++){var a=t[i];r.test(a)&&n.push(a)}return n},A.makeClipPaths=function(t){var e=t._fullLayout;if(!e._hasOnlyLargeSploms){var r,i,a={_offset:0,_length:e.width,_id:\"\"},o={_offset:0,_length:e.height,_id:\"\"},s=A.list(t,\"x\",!0),l=A.list(t,\"y\",!0),c=[];for(r=0;r<s.length;r++)for(c.push({x:s[r],y:o}),i=0;i<l.length;i++)0===r&&c.push({x:a,y:l[i]}),c.push({x:s[r],y:l[i]});var u=e._clips.selectAll(\".axesclip\").data(c,function(t){return t.x._id+t.y._id});u.enter().append(\"clipPath\").classed(\"axesclip\",!0).attr(\"id\",function(t){return\"clip\"+e._uid+t.x._id+t.y._id}).append(\"rect\"),u.exit().remove(),u.each(function(t){n.select(this).select(\"rect\").attr({x:t.x._offset||0,y:t.y._offset||0,width:t.x._length||1,height:t.y._length||1})})}},A.draw=function(t,e,r){var n=t._fullLayout;\"redraw\"===e&&n._paper.selectAll(\"g.subplot\").each(function(t){var e=t[0],r=n._plots[e],i=r.xaxis,a=r.yaxis;r.xaxislayer.selectAll(\".\"+i._id+\"tick\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"tick2\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick2\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"divider\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"divider\").remove(),r.gridlayer&&r.gridlayer.selectAll(\"path\").remove(),r.zerolinelayer&&r.zerolinelayer.selectAll(\"path\").remove(),n._infolayer.select(\".g-\"+i._id+\"title\").remove(),n._infolayer.select(\".g-\"+a._id+\"title\").remove()});var i=e&&\"redraw\"!==e?e:A.listIds(t);return s.syncOrAsync(i.map(function(e){return function(){if(e){var n=A.getFromId(t,e),i=A.drawOne(t,n,r);return n._r=n.range.slice(),n._rl=s.simpleMap(n._r,n.r2l),i}}}))},A.drawOne=function(t,e,r){var n,i,l;r=r||{},e.setScale();var f=t._fullLayout,p=e._id,d=p.charAt(0),g=A.counterLetter(p),v=e._mainSubplot,m=e._mainLinePosition,y=e._mainMirrorPosition,x=f._plots[v][d+\"axislayer\"],b=e._subplotsWith,_=e._vals=A.calcTicks(e),w=[e.mirror,m,y].join(\"_\");for(n=0;n<_.length;n++)_[n].axInfo=w;if(e.visible){e._selections={},e._tickAngles={};var k,M,S=A.makeTransFn(e);if(\"boundaries\"===e.tickson){var E=function(t,e){var r,n=[],i=function(t,e){var r=t.xbnd[e];null!==r&&n.push(s.extendFlat({},t,{x:r}))};if(e.length){for(r=0;r<e.length;r++)i(e[r],0);i(e[r-1],1)}return n}(0,_);M=A.clipEnds(e,E),k=\"inside\"===e.ticks?M:E}else M=A.clipEnds(e,_),k=\"inside\"===e.ticks?M:_;var C=e._gridVals=M,L=function(t,e){var r,n,i=[],a=function(t,e){var r=t.xbnd[e];null!==r&&i.push(s.extendFlat({},t,{x:r}))};if(t.showdividers&&e.length){for(r=0;r<e.length;r++){var o=e[r];o.text2!==n&&a(o,0),n=o.text2}a(e[r-1],1)}return i}(e,_);if(!f._hasOnlyLargeSploms){var P={};for(n=0;n<b.length;n++){i=b[n];var O=(l=f._plots[i])[g+\"axis\"],z=O._mainAxis._id;if(!P[z]){P[z]=1;var I=\"x\"===d?\"M0,\"+O._offset+\"v\"+O._length:\"M\"+O._offset+\",0h\"+O._length;A.drawGrid(t,e,{vals:C,counterAxis:O,layer:l.gridlayer.select(\".\"+p),path:I,transFn:S}),A.drawZeroLine(t,e,{counterAxis:O,layer:l.zerolinelayer,path:I,transFn:S})}}}var D=A.getTickSigns(e),R=[];if(e.ticks){var F,B,N,j=A.makeTickPath(e,m,D[2]);if(e._anchorAxis&&e.mirror&&!0!==e.mirror?(F=A.makeTickPath(e,y,D[3]),B=j+F):(F=\"\",B=j),e.showdividers&&\"outside\"===e.ticks&&\"boundaries\"===e.tickson){var V={};for(n=0;n<L.length;n++)V[L[n].x]=1;N=function(t){return V[t.x]?F:B}}else N=B;A.drawTicks(t,e,{vals:k,layer:x,path:N,transFn:S}),R=Object.keys(e._linepositions||{})}for(n=0;n<R.length;n++){i=R[n],l=f._plots[i];var q=e._linepositions[i]||[],H=A.makeTickPath(e,q[0],D[0])+A.makeTickPath(e,q[1],D[1]);A.drawTicks(t,e,{vals:k,layer:l[d+\"axislayer\"],path:H,transFn:S})}var G=[];if(G.push(function(){return A.drawLabels(t,e,{vals:_,layer:x,transFn:S,labelFns:A.makeLabelFns(e,m)})}),\"multicategory\"===e.type){var Z=0,J={x:2,y:10}[d],Q=D[2]*(\"inside\"===e.ticks?-1:1);G.push(function(){return Z+=Y(e,p+\"tick\")+J,Z+=e._tickAngles[p+\"tick\"]?e.tickfont.size*T:0,A.drawLabels(t,e,{vals:function(t,e){for(var r=[],n={},i=0;i<e.length;i++){var a=e[i];n[a.text2]?n[a.text2].push(a.x):n[a.text2]=[a.x]}for(var o in n)r.push(U(t,s.interp(n[o],.5),o));return r}(e,_),layer:x,cls:p+\"tick2\",repositionOnUpdate:!0,secondary:!0,transFn:S,labelFns:A.makeLabelFns(e,m+Z*Q)})}),G.push(function(){return Z+=Y(e,p+\"tick2\"),e._labelLength=Z,function(t,e,r){var n=e._id+\"divider\",i=r.vals,a=r.layer.selectAll(\"path.\"+n).data(i,W);a.exit().remove(),a.enter().insert(\"path\",\":first-child\").classed(n,1).classed(\"crisp\",1).call(u.stroke,e.dividercolor).style(\"stroke-width\",h.crispRound(t,e.dividerwidth,1)+\"px\"),a.attr(\"transform\",r.transFn).attr(\"d\",r.path)}(t,e,{vals:L,layer:x,path:A.makeTickPath(e,m,Q,Z),transFn:S})})}var tt=o.getComponentMethod(\"rangeslider\",\"isVisible\")(e);return G.push(function(){if(e.showticklabels){var r=t.getBoundingClientRect(),n=x.node().getBoundingClientRect();e._boundingBox={width:n.width,height:n.height,left:n.left-r.left,right:n.right-r.left,top:n.top-r.top,bottom:n.bottom-r.top}}else{var i,a=f._size;\"x\"===d?(i=\"free\"===e.anchor?a.t+a.h*(1-e.position):a.t+a.h*(1-e._anchorAxis.domain[{bottom:0,top:1}[e.side]]),e._boundingBox={top:i,bottom:i,left:e._offset,right:e._offset+e._length,width:e._length,height:0}):(i=\"free\"===e.anchor?a.l+a.w*e.position:a.l+a.w*e._anchorAxis.domain[{left:0,right:1}[e.side]],e._boundingBox={left:i,right:i,bottom:e._offset+e._length,top:e._offset,height:e._length,width:0})}if(b){for(var o=e._counterSpan=[1/0,-1/0],s=0;s<b.length;s++){var l=f._plots[b[s]][\"x\"===d?\"yaxis\":\"xaxis\"];et(o,[l._offset,l._offset+l._length])}\"free\"===e.anchor&&et(o,\"x\"===d?[e._boundingBox.bottom,e._boundingBox.top]:[e._boundingBox.right,e._boundingBox.left])}},function(){var r,n,i=e.side.charAt(0);if(tt&&(n=o.getComponentMethod(\"rangeslider\",\"autoMarginOpts\")(t,e)),a.autoMargin(t,$(e),n),e.automargin&&(!tt||\"b\"!==i)){r={x:0,y:0,r:0,l:0,t:0,b:0};var s,l,c=e._boundingBox,u=X(t,e);switch(d+i){case\"xb\":s=0,l=c.top-u,r[i]=c.height;break;case\"xt\":s=1,l=u-c.bottom,r[i]=c.height;break;case\"yl\":s=0,l=u-c.right,r[i]=c.width;break;case\"yr\":s=1,l=c.left-u,r[i]=c.width}if(r[g]=\"free\"===e.anchor?e.position:e._anchorAxis.domain[s],r[i]>0&&(r[i]+=l),e.title.text!==f._dfltTitle[d]&&(r[i]+=e.title.font.size),\"x\"===d&&c.width>0){var h=c.right-(e._offset+e._length);h>0&&(r.x=1,r.r=h);var p=e._offset-c.left;p>0&&(r.x=0,r.l=p)}else if(\"y\"===d&&c.height>0){var v=c.bottom-(e._offset+e._length);v>0&&(r.y=0,r.b=v);var m=e._offset-c.top;m>0&&(r.y=1,r.t=m)}}a.autoMargin(t,K(e),r)}),r.skipTitle||tt&&e._boundingBox&&\"bottom\"===e.side||G.push(function(){return function(t,e){var r,n=t._fullLayout,i=e._id,a=i.charAt(0),o=e.title.font.size;if(\"multicategory\"===e.type)r=e._labelLength;else{r=10+1.5*o+(e.linewidth?e.linewidth-1:0)}var s,l,u,f,p=X(t,e);\"x\"===a?(l=e._offset+e._length/2,u=\"top\"===e.side?-r-o*(e.showticklabels?1:0):r+o*(e.showticklabels?1.5:.5),u+=p):(u=e._offset+e._length/2,l=\"right\"===e.side?r+o*(e.showticklabels?1:.5):-r-o*(e.showticklabels?.5:0),l+=p,s={rotate:\"-90\",offset:0});if(\"multicategory\"!==e.type){var d=e._selections[e._id+\"tick\"];if(f={selection:d,side:e.side},d&&d.node()&&d.node().parentNode){var g=h.getTranslate(d.node().parentNode);f.offsetLeft=g.x,f.offsetTop=g.y}}return c.draw(t,i+\"title\",{propContainer:e,propName:e._name+\".title.text\",placeholder:n._dfltTitle[a],avoid:f,transform:s,attributes:{x:l,y:u,\"text-anchor\":\"middle\"}})}(t,e)}),s.syncOrAsync(G)}function et(t,e){t[0]=Math.min(t[0],e[0]),t[1]=Math.max(t[1],e[1])}},A.getTickSigns=function(t){var e=t._id.charAt(0),r={x:\"top\",y:\"right\"}[e],n=t.side===r?1:-1,i=[-1,1,n,-n];return\"inside\"!==t.ticks==(\"x\"===e)&&(i=i.map(function(t){return-t})),i},A.makeTransFn=function(t){var e=t._id.charAt(0),r=t._offset;return\"x\"===e?function(e){return\"translate(\"+(r+t.l2p(e.x))+\",0)\"}:function(e){return\"translate(0,\"+(r+t.l2p(e.x))+\")\"}},A.makeTickPath=function(t,e,r,n){n=void 0!==n?n:t.ticklen;var i=t._id.charAt(0),a=(t.linewidth||1)/2;return\"x\"===i?\"M0,\"+(e+a*r)+\"v\"+n*r:\"M\"+(e+a*r)+\",0h\"+n*r},A.makeLabelFns=function(t,e,r){var n=t._id.charAt(0),a=\"boundaries\"!==t.tickson&&\"outside\"===t.ticks,o=0,l=0;if(a&&(o+=t.ticklen),r&&\"outside\"===t.ticks){var c=s.deg2rad(r);o=t.ticklen*Math.cos(c)+1,l=t.ticklen*Math.sin(c)}t.showticklabels&&(a||t.showline)&&(o+=.2*t.tickfont.size);var u,h,f,p,d={labelStandoff:o+=(t.linewidth||1)/2,labelShift:l};return\"x\"===n?(p=\"bottom\"===t.side?1:-1,u=l*p,h=e+o*p,f=\"bottom\"===t.side?1:-.2,d.xFn=function(t){return t.dx+u},d.yFn=function(t){return t.dy+h+t.fontSize*f},d.anchorFn=function(t,e){return i(e)&&0!==e&&180!==e?e*p<0?\"end\":\"start\":\"middle\"},d.heightFn=function(e,r,n){return r<-60||r>60?-.5*n:\"top\"===t.side?-n:0}):\"y\"===n&&(p=\"right\"===t.side?1:-1,u=o,h=-l*p,f=90===Math.abs(t.tickangle)?.5:0,d.xFn=function(t){return t.dx+e+(u+t.fontSize*f)*p},d.yFn=function(t){return t.dy+h+t.fontSize*k},d.anchorFn=function(e,r){return i(r)&&90===Math.abs(r)?\"middle\":\"right\"===t.side?\"start\":\"end\"},d.heightFn=function(e,r,n){return(r*=\"left\"===t.side?1:-1)<-30?-n:r<30?-.5*n:0}),d},A.drawTicks=function(t,e,r){r=r||{};var n=e._id+\"tick\",i=r.layer.selectAll(\"path.\"+n).data(e.ticks?r.vals:[],W);i.exit().remove(),i.enter().append(\"path\").classed(n,1).classed(\"ticks\",1).classed(\"crisp\",!1!==r.crisp).call(u.stroke,e.tickcolor).style(\"stroke-width\",h.crispRound(t,e.tickwidth,1)+\"px\").attr(\"d\",r.path),i.attr(\"transform\",r.transFn)},A.drawGrid=function(t,e,r){r=r||{};var n=e._id+\"grid\",i=r.vals,a=r.counterAxis;if(!1===e.showgrid)i=[];else if(a&&A.shouldShowZeroLine(t,e,a))for(var o=\"array\"===e.tickmode,s=0;s<i.length;s++){var l=i[s].x;if(o?!l:Math.abs(l)<e.dtick/100){if(i=i.slice(0,s).concat(i.slice(s+1)),!o)break;s--}}var c=r.layer.selectAll(\"path.\"+n).data(i,W);c.exit().remove(),c.enter().append(\"path\").classed(n,1).classed(\"crisp\",!1!==r.crisp),e._gw=h.crispRound(t,e.gridwidth,1),c.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(u.stroke,e.gridcolor||\"#ddd\").style(\"stroke-width\",e._gw+\"px\"),\"function\"==typeof r.path&&c.attr(\"d\",r.path)},A.drawZeroLine=function(t,e,r){r=r||r;var n=e._id+\"zl\",i=A.shouldShowZeroLine(t,e,r.counterAxis),a=r.layer.selectAll(\"path.\"+n).data(i?[{x:0,id:e._id}]:[]);a.exit().remove(),a.enter().append(\"path\").classed(n,1).classed(\"zl\",1).classed(\"crisp\",!1!==r.crisp).each(function(){r.layer.selectAll(\"path\").sort(function(t,e){return S.idSort(t.id,e.id)})}),a.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(u.stroke,e.zerolinecolor||u.defaultLine).style(\"stroke-width\",h.crispRound(t,e.zerolinewidth,e._gw||1)+\"px\")},A.drawLabels=function(t,e,r){r=r||{};var a=e._id,o=a.charAt(0),c=r.cls||a+\"tick\",u=r.vals,f=r.labelFns,p=r.secondary?0:e.tickangle,d=(e._tickAngles||{})[c],g=r.layer.selectAll(\"g.\"+c).data(e.showticklabels?u:[],W),v=[];function m(t,e){t.each(function(t){var a=n.select(this),o=a.select(\".text-math-group\"),s=f.anchorFn(t,e),c=r.transFn.call(a.node(),t)+(i(e)&&0!=+e?\" rotate(\"+e+\",\"+f.xFn(t)+\",\"+(f.yFn(t)-t.fontSize/2)+\")\":\"\"),u=l.lineCount(a),p=T*t.fontSize,d=f.heightFn(t,i(e)?+e:0,(u-1)*p);if(d&&(c+=\" translate(0, \"+d+\")\"),o.empty())a.select(\"text\").attr({transform:c,\"text-anchor\":s});else{var g=h.bBox(o.node()).width*{end:-.5,start:.5}[s];o.attr(\"transform\",c+(g?\"translate(\"+g+\",0)\":\"\"))}})}g.enter().append(\"g\").classed(c,1).append(\"text\").attr(\"text-anchor\",\"middle\").each(function(e){var r=n.select(this),i=t._promises.length;r.call(l.positionText,f.xFn(e),f.yFn(e)).call(h.font,e.font,e.fontSize,e.fontColor).text(e.text).call(l.convertToTspans,t),t._promises[i]?v.push(t._promises.pop().then(function(){m(r,p)})):m(r,p)}),g.exit().remove(),r.repositionOnUpdate&&g.each(function(t){n.select(this).select(\"text\").call(l.positionText,f.xFn(t),f.yFn(t))}),m(g,d||p),e._selections&&(e._selections[c]=g);var y=s.syncOrAsync([function(){return v.length&&Promise.all(v)},function(){m(g,p);var t=null;if(u.length&&\"x\"===o&&!i(p)&&(\"log\"!==e.type||\"D\"!==String(e.dtick).charAt(0))){t=0;var n,a=0,l=[];if(g.each(function(t){a=Math.max(a,t.fontSize);var r=e.l2p(t.x),n=J(this),i=h.bBox(n.node());l.push({top:0,bottom:10,height:10,left:r-i.width/2,right:r+i.width/2+2,width:i.width+2})}),\"boundaries\"!==e.tickson&&!e.showdividers||r.secondary){var f=u.length,d=Math.abs((u[f-1].x-u[0].x)*e._m)/(f-1)<2.5*a||\"multicategory\"===e.type;for(n=0;n<l.length-1;n++)if(s.bBoxIntersect(l[n],l[n+1])){t=d?90:30;break}}else{var v=2;for(e.ticks&&(v+=e.tickwidth/2),n=0;n<l.length;n++){var y=u[n].xbnd,x=l[n];if(null!==y[0]&&x.left-e.l2p(y[0])<v||null!==y[1]&&e.l2p(y[1])-x.right<v){t=90;break}}}t&&m(g,t)}e._tickAngles&&(e._tickAngles[c]=null===t?i(p)?p:0:t)}]);return y&&y.then&&t._promises.push(y),y},A.shouldShowZeroLine=function(t,e,r){var n=s.simpleMap(e.range,e.r2l);return n[0]*n[1]<=0&&e.zeroline&&(\"linear\"===e.type||\"-\"===e.type)&&e._gridVals.length&&(Z(e,0)||!function(t,e,r,n){var i=r._mainAxis;if(!i)return;var a=t._fullLayout,o=e._id.charAt(0),s=A.counterLetter(e._id),l=e._offset+(Math.abs(n[0])<Math.abs(n[1])==(\"x\"===o)?0:e._length);function c(t){if(!t.showline||!t.linewidth)return!1;var r=Math.max((t.linewidth+e.zerolinewidth)/2,1);function n(t){return\"number\"==typeof t&&Math.abs(t-l)<r}if(n(t._mainLinePosition)||n(t._mainMirrorPosition))return!0;var i=t._linepositions||{};for(var a in i)if(n(i[a][0])||n(i[a][1]))return!0}var u=a._plots[r._mainSubplot];if(!(u.mainplotinfo||u).overlays.length)return c(r);for(var h=A.list(t,s),f=0;f<h.length;f++){var p=h[f];if(p._mainAxis===i&&c(p))return!0}}(t,e,r,n)||function(t,e){for(var r=t._fullData,n=e._mainSubplot,i=e._id.charAt(0),a=0;a<r.length;a++){var s=r[a];if(!0===s.visible&&s.xaxis+s.yaxis===n){if(o.traceIs(s,\"bar-like\")&&s.orientation==={x:\"h\",y:\"v\"}[i])return!0;if(s.fill&&s.fill.charAt(s.fill.length-1)===i)return!0}}return!1}(t,e))},A.clipEnds=function(t,e){return e.filter(function(e){return Z(t,e.x)})},A.allowAutoMargin=function(t){for(var e=A.list(t,\"\",!0),r=0;r<e.length;r++){var n=e[r];n.automargin&&a.allowAutoMargin(t,K(n)),o.getComponentMethod(\"rangeslider\",\"isVisible\")(n)&&a.allowAutoMargin(t,$(n))}},A.swap=function(t,e){for(var r=function(t,e){var r,n,i=[];for(r=0;r<e.length;r++){var a=[],o=t._fullData[e[r]].xaxis,s=t._fullData[e[r]].yaxis;if(o&&s){for(n=0;n<i.length;n++)-1===i[n].x.indexOf(o)&&-1===i[n].y.indexOf(s)||a.push(n);if(a.length){var l,c=i[a[0]];if(a.length>1)for(n=1;n<a.length;n++)l=i[a[n]],Q(c.x,l.x),Q(c.y,l.y);Q(c.x,[o]),Q(c.y,[s])}else i.push({x:[o],y:[s]})}}return i}(t,e),n=0;n<r.length;n++)tt(t,r[n].x,r[n].y)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../components/titles\":681,\"../../constants/alignment\":688,\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/plots\":828,\"../../registry\":847,\"./autorange\":766,\"./axis_autotype\":768,\"./axis_ids\":770,\"./clean_ticks\":772,\"./layout_attributes\":779,\"./set_convert\":785,d3:163,\"fast-isnumeric\":225}],768:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){return!(r=r||{}).noMultiCategory&&(o=t,i.isArrayOrTypedArray(o[0])&&i.isArrayOrTypedArray(o[1]))?\"multicategory\":function(t,e){for(var r=Math.max(1,(t.length-1)/1e3),a=0,o=0,s={},l=0;l<t.length;l+=r){var c=t[Math.round(l)],u=String(c);s[u]||(s[u]=1,i.isDateTime(c,e)&&(a+=1),n(c)&&(o+=1))}return a>2*o}(t,e)?\"date\":function(t){for(var e=Math.max(1,(t.length-1)/1e3),r=0,n=0,o={},s=0;s<t.length;s+=e){var l=t[Math.round(s)],c=String(l);o[c]||(o[c]=1,\"boolean\"==typeof l?n++:i.cleanNumber(l)!==a?r++:\"string\"==typeof l&&n++)}return n>2*r}(t)?\"category\":function(t){if(!t)return!1;for(var e=0;e<t.length;e++)if(n(t[e]))return!0;return!1}(t)?\"linear\":\"-\";var o}},{\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],769:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./layout_attributes\"),o=t(\"./tick_value_defaults\"),s=t(\"./tick_mark_defaults\"),l=t(\"./tick_label_defaults\"),c=t(\"./category_order_defaults\"),u=t(\"./line_grid_defaults\"),h=t(\"./set_convert\");e.exports=function(t,e,r,f,p){var d=f.letter,g=f.font||{},v=f.splomStash||{},m=r(\"visible\",!f.visibleDflt),y=e.type;\"date\"===y&&n.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",f.calendar);h(e,p);var x=!e.isValidRange(t.range);x&&f.reverseDflt&&(x=\"reversed\"),!r(\"autorange\",x)||\"linear\"!==y&&\"-\"!==y||r(\"rangemode\"),r(\"range\"),e.cleanRange(),c(t,e,r,f),\"category\"===y||f.noHover||r(\"hoverformat\");var b=r(\"color\"),_=b!==a.color.dflt?b:g.color,w=v.label||p._dfltTitle[d];if(l(t,e,r,y,f,{pass:1}),!m)return e;r(\"title.text\",w),i.coerceFont(r,\"title.font\",{family:g.family,size:Math.round(1.2*g.size),color:_}),o(t,e,r,y),l(t,e,r,y,f,{pass:2}),s(t,e,r,f),u(t,e,r,{dfltColor:b,bgColor:f.bgColor,showGrid:f.showGrid,attributes:a}),(e.showline||e.ticks)&&r(\"mirror\"),f.automargin&&r(\"automargin\");var k,T=\"multicategory\"===e.type;f.noTickson||\"category\"!==e.type&&!T||!e.ticks&&!e.showgrid||(T&&(k=\"boundaries\"),r(\"tickson\",k));T&&(r(\"showdividers\")&&(r(\"dividercolor\"),r(\"dividerwidth\")));return e}},{\"../../lib\":719,\"../../registry\":847,\"./category_order_defaults\":771,\"./layout_attributes\":779,\"./line_grid_defaults\":781,\"./set_convert\":785,\"./tick_label_defaults\":786,\"./tick_mark_defaults\":787,\"./tick_value_defaults\":788}],770:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./constants\");r.id2name=function(t){if(\"string\"==typeof t&&t.match(i.AX_ID_PATTERN)){var e=t.substr(1);return\"1\"===e&&(e=\"\"),t.charAt(0)+\"axis\"+e}},r.name2id=function(t){if(t.match(i.AX_NAME_PATTERN)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),t.charAt(0)+e}},r.cleanId=function(t,e){if(t.match(i.AX_ID_PATTERN)&&(!e||t.charAt(0)===e)){var r=t.substr(1).replace(/^0+/,\"\");return\"1\"===r&&(r=\"\"),t.charAt(0)+r}},r.list=function(t,e,n){var i=t._fullLayout;if(!i)return[];var a,o=r.listIds(t,e),s=new Array(o.length);for(a=0;a<o.length;a++){var l=o[a];s[a]=i[l.charAt(0)+\"axis\"+l.substr(1)]}if(!n){var c=i._subplots.gl3d||[];for(a=0;a<c.length;a++){var u=i[c[a]];e?s.push(u[e+\"axis\"]):s.push(u.xaxis,u.yaxis,u.zaxis)}}return s},r.listIds=function(t,e){var r=t._fullLayout;if(!r)return[];var n=r._subplots;return e?n[e+\"axis\"]:n.xaxis.concat(n.yaxis)},r.getFromId=function(t,e,n){var i=t._fullLayout;return\"x\"===n?e=e.replace(/y[0-9]*/,\"\"):\"y\"===n&&(e=e.replace(/x[0-9]*/,\"\")),i[r.id2name(e)]},r.getFromTrace=function(t,e,i){var a=t._fullLayout,o=null;if(n.traceIs(e,\"gl3d\")){var s=e.scene;\"scene\"===s.substr(0,5)&&(o=a[s][i+\"axis\"])}else o=r.getFromId(t,e[i+\"axis\"]||i);return o},r.idSort=function(t,e){var r=t.charAt(0),n=e.charAt(0);return r!==n?r>n?1:-1:+(t.substr(1)||1)-+(e.substr(1)||1)},r.getAxisGroup=function(t,e){for(var r=t._axisMatchGroups,n=0;n<r.length;n++){if(r[n][e])return\"g\"+n}return e}},{\"../../registry\":847,\"./constants\":773}],771:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){if(\"category\"===e.type){var i,a=t.categoryarray,o=Array.isArray(a)&&a.length>0;o&&(i=\"array\");var s,l=r(\"categoryorder\",i);\"array\"===l&&(s=r(\"categoryarray\")),o||\"array\"!==l||(l=e.categoryorder=\"trace\"),\"trace\"===l?e._initialCategories=[]:\"array\"===l?e._initialCategories=s.slice():(s=function(t,e){var r,n,i,a=e.dataAttr||t._id.charAt(0),o={};if(e.axData)r=e.axData;else for(r=[],n=0;n<e.data.length;n++){var s=e.data[n];s[a+\"axis\"]===t._id&&r.push(s)}for(n=0;n<r.length;n++){var l=r[n][a];for(i=0;i<l.length;i++){var c=l[i];null!=c&&(o[c]=1)}}return Object.keys(o)}(e,n).sort(),\"category ascending\"===l?e._initialCategories=s:\"category descending\"===l&&(e._initialCategories=s.reverse()))}}},{}],772:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").ONEDAY;r.dtick=function(t,e){var r=\"log\"===e,i=\"date\"===e,o=\"category\"===e,s=i?a:1;if(!t)return s;if(n(t))return(t=Number(t))<=0?s:o?Math.max(1,Math.round(t)):i?Math.max(.1,t):t;if(\"string\"!=typeof t||!i&&!r)return s;var l=t.charAt(0),c=t.substr(1);return(c=n(c)?Number(c):0)<=0||!(i&&\"M\"===l&&c===Math.round(c)||r&&\"L\"===l||r&&\"D\"===l&&(1===c||2===c))?s:t},r.tick0=function(t,e,r,a){return\"date\"===e?i.cleanDate(t,i.dateTick0(r)):\"D1\"!==a&&\"D2\"!==a?n(t)?Number(t):0:void 0}},{\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],773:[function(t,e,r){\"use strict\";var n=t(\"../../lib/regex\").counter;e.exports={idRegex:{x:n(\"x\"),y:n(\"y\")},attrRegex:n(\"[xy]axis\"),xAxisMatch:n(\"xaxis\"),yAxisMatch:n(\"yaxis\"),AX_ID_PATTERN:/^[xyz][0-9]*$/,AX_NAME_PATTERN:/^[xyz]axis[0-9]*$/,SUBPLOT_PATTERN:/^x([0-9]*)y([0-9]*)$/,MINDRAG:8,MINSELECT:12,MINZOOM:20,DRAGGERSIZE:20,BENDPX:1.5,REDRAWDELAY:50,SELECTDELAY:100,SELECTID:\"-select\",DFLTRANGEX:[-1,6],DFLTRANGEY:[-1,4],traceLayerClasses:[\"heatmaplayer\",\"contourcarpetlayer\",\"contourlayer\",\"funnellayer\",\"waterfalllayer\",\"barlayer\",\"carpetlayer\",\"violinlayer\",\"boxlayer\",\"ohlclayer\",\"scattercarpetlayer\",\"scatterlayer\"],clipOnAxisFalseQuery:[\".scatterlayer\",\".barlayer\",\".funnellayer\",\".waterfalllayer\"],layerValue2layerClass:{\"above traces\":\"above\",\"below traces\":\"below\"}}},{\"../../lib/regex\":735}],774:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./axis_ids\").id2name,a=t(\"./scale_zoom\"),o=t(\"./autorange\").makePadFn,s=t(\"./autorange\").concatExtremes,l=t(\"../../constants/numerical\").ALMOST_EQUAL,c=t(\"../../constants/alignment\").FROM_BL;function u(t,e,r,n,a){var o,s,l,c,u=\"range\"!==a,h=n[i(e)].type,f=[];for(s=0;s<r.length;s++)if((l=r[s])!==e&&(c=n[i(l)]).type===h)if(c.fixedrange){if(u&&c.anchor){n[i(c.anchor)].fixedrange&&f.push(l)}}else f.push(l);for(o=0;o<t.length;o++)if(t[o][e]){var p=t[o],d=[];for(s=0;s<f.length;s++)p[l=f[s]]||d.push(l);return{linkableAxes:d,thisGroup:p}}return{linkableAxes:f,thisGroup:null}}function h(t,e,r,n,i){var a,o,s,l,c;null===e?((e={})[r]=1,c=t.length,t.push(e)):c=t.indexOf(e);var u=Object.keys(e);for(a=0;a<t.length;a++)if(s=t[a],a!==c&&s[n]){var h=s[n];for(o=0;o<u.length;o++)s[l=u[o]]=h*i*e[l];return void t.splice(c,1)}if(1!==i)for(o=0;o<u.length;o++)e[u[o]]*=i;e[n]=1}function f(t,e){var r=t._inputDomain,n=c[t.constraintoward],i=r[0]+(r[1]-r[0])*n;t.domain=t._input.domain=[i+(r[0]-i)/e,i+(r[1]-i)/e],t.setScale()}r.handleConstraintDefaults=function(t,e,r,i,a){var o,s,l,c,f=a._axisConstraintGroups,p=a._axisMatchGroups,d=e._id,g=d.charAt(0),v=((a._splomAxes||{})[g]||{})[d]||{},m=e._id,y=m.charAt(0),x=r(\"constrain\");if(n.coerce(t,e,{constraintoward:{valType:\"enumerated\",values:\"x\"===y?[\"left\",\"center\",\"right\"]:[\"bottom\",\"middle\",\"top\"],dflt:\"x\"===y?\"center\":\"middle\"}},\"constraintoward\"),!t.matches&&!v.matches||e.fixedrange||(s=u(p,m,i,a),o=n.coerce(t,e,{matches:{valType:\"enumerated\",values:s.linkableAxes||[],dflt:v.matches}},\"matches\")),o||!t.scaleanchor||e.fixedrange&&\"domain\"!==x||(c=u(f,m,i,a,x),l=n.coerce(t,e,{scaleanchor:{valType:\"enumerated\",values:c.linkableAxes||[]}},\"scaleanchor\")),o?(delete e.constrain,h(p,s.thisGroup,m,o,1)):-1!==i.indexOf(t.matches)&&n.warn(\"ignored \"+e._name+'.matches: \"'+t.matches+'\" to avoid either an infinite loop or because the target axis has fixed range.'),l){var b=r(\"scaleratio\");b||(b=e.scaleratio=1),h(f,c.thisGroup,m,l,b)}else-1!==i.indexOf(t.scaleanchor)&&n.warn(\"ignored \"+e._name+'.scaleanchor: \"'+t.scaleanchor+'\" to avoid either an infinite loop and possibly inconsistent scaleratios, or because the target axis has fixed range or this axis declares a *matches* constraint.')},r.enforce=function(t){var e,r,n,c,u,h,p,d=t._fullLayout,g=d._axisConstraintGroups||[];for(e=0;e<g.length;e++){var v=g[e],m=Object.keys(v),y=1/0,x=0,b=1/0,_={},w={},k=!1;for(r=0;r<m.length;r++)w[n=m[r]]=c=d[i(n)],c._inputDomain?c.domain=c._inputDomain.slice():c._inputDomain=c.domain.slice(),c._inputRange||(c._inputRange=c.range.slice()),c.setScale(),_[n]=u=Math.abs(c._m)/v[n],y=Math.min(y,u),\"domain\"!==c.constrain&&c._constraintShrinkable||(b=Math.min(b,u)),delete c._constraintShrinkable,x=Math.max(x,u),\"domain\"===c.constrain&&(k=!0);if(!(y>l*x)||k)for(r=0;r<m.length;r++)if(u=_[n=m[r]],h=(c=w[n]).constrain,u!==b||\"domain\"===h)if(p=u/b,\"range\"===h)a(c,p);else{var T=c._inputDomain,A=(c.domain[1]-c.domain[0])/(T[1]-T[0]),M=(c.r2l(c.range[1])-c.r2l(c.range[0]))/(c.r2l(c._inputRange[1])-c.r2l(c._inputRange[0]));if((p/=A)*M<1){c.domain=c._input.domain=T.slice(),a(c,p);continue}if(M<1&&(c.range=c._input.range=c._inputRange.slice(),p*=M),c.autorange){var S=c.r2l(c.range[0]),E=c.r2l(c.range[1]),C=(S+E)/2,L=C,P=C,O=Math.abs(E-C),z=C-O*p*1.0001,I=C+O*p*1.0001,D=o(c);f(c,p);var R,F,B=Math.abs(c._m),N=s(t,c),j=N.min,U=N.max;for(F=0;F<j.length;F++)(R=j[F].val-D(j[F])/B)>z&&R<L&&(L=R);for(F=0;F<U.length;F++)(R=U[F].val+D(U[F])/B)<I&&R>P&&(P=R);p/=(P-L)/(2*O),L=c.l2r(L),P=c.l2r(P),c.range=c._input.range=S<E?[L,P]:[P,L]}f(c,p)}}},r.clean=function(t,e){if(e._inputDomain){for(var r=!1,n=e._id,i=t._fullLayout._axisConstraintGroups,a=0;a<i.length;a++)if(i[a][n]){r=!0;break}r&&\"domain\"===e.constrain||(e._input.domain=e.domain=e._inputDomain,delete e._inputDomain)}}},{\"../../constants/alignment\":688,\"../../constants/numerical\":695,\"../../lib\":719,\"./autorange\":766,\"./axis_ids\":770,\"./scale_zoom\":783}],775:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"has-passive-events\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../components/color\"),u=t(\"../../components/drawing\"),h=t(\"../../components/fx\"),f=t(\"./axes\"),p=t(\"../../lib/setcursor\"),d=t(\"../../components/dragelement\"),g=t(\"../../constants/alignment\").FROM_TL,v=t(\"../../lib/clear_gl_canvases\"),m=t(\"../../plot_api/subroutines\").redrawReglTraces,y=t(\"../plots\"),x=t(\"./axis_ids\").getFromId,b=t(\"./select\").prepSelect,_=t(\"./select\").clearSelect,w=t(\"./select\").selectOnClick,k=t(\"./scale_zoom\"),T=t(\"./constants\"),A=T.MINDRAG,M=T.MINZOOM,S=!0;function E(t,e,r,n){var i=s.ensureSingle(t.draglayer,e,r,function(e){e.classed(\"drag\",!0).style({fill:\"transparent\",\"stroke-width\":0}).attr(\"data-subplot\",t.id)});return i.call(p,n),i.node()}function C(t,e,r,i,a,o,s){var l=E(t,\"rect\",e,r);return n.select(l).call(u.setRect,i,a,o,s),l}function L(t,e){for(var r=0;r<t.length;r++)if(!t[r].fixedrange)return e;return\"\"}function P(t,e,r,n,i){for(var a=0;a<t.length;a++){var o=t[a];if(!o.fixedrange){var s=o._rl[0],l=o._rl[1]-s;n[o._name+\".range[0]\"]=o.l2r(s+l*e),n[o._name+\".range[1]\"]=o.l2r(s+l*r)}}if(i&&i.length){var c=(e+(1-r))/2;P(i,c,1-c,n,[])}}function O(t,e){for(var r=0;r<t.length;r++){var n=t[r];n.fixedrange||(n.range=[n.l2r(n._rl[0]-e/n._m),n.l2r(n._rl[1]-e/n._m)])}}function z(t){return 1-(t>=0?Math.min(t,.9):1/(1/Math.max(t,-.3)+3.222))}function I(t,e,r,n,i){return t.append(\"path\").attr(\"class\",\"zoombox\").style({fill:e>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"transform\",\"translate(\"+r+\", \"+n+\")\").attr(\"d\",i+\"Z\")}function D(t,e,r){return t.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:c.background,stroke:c.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"transform\",\"translate(\"+e+\", \"+r+\")\").attr(\"d\",\"M0,0Z\")}function R(t,e,r,n,i,a){t.attr(\"d\",n+\"M\"+r.l+\",\"+r.t+\"v\"+r.h+\"h\"+r.w+\"v-\"+r.h+\"h-\"+r.w+\"Z\"),F(t,e,i,a)}function F(t,e,r,n){r||(t.transition().style(\"fill\",n>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),e.transition().style(\"opacity\",1).duration(200))}function B(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}function N(t){S&&t.data&&t._context.showTips&&(s.notifier(s._(t,\"Double-click to zoom back out\"),\"long\"),S=!1)}function j(t){return\"lasso\"===t||\"select\"===t}function U(t){var e=Math.floor(Math.min(t.b-t.t,t.r-t.l,M)/2);return\"M\"+(t.l-3.5)+\",\"+(t.t-.5+e)+\"h3v\"+-e+\"h\"+e+\"v-3h-\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.t-.5+e)+\"h-3v\"+-e+\"h\"+-e+\"v-3h\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.b+.5-e)+\"h-3v\"+e+\"h\"+-e+\"v3h\"+(e+3)+\"ZM\"+(t.l-3.5)+\",\"+(t.b+.5-e)+\"h3v\"+e+\"h\"+e+\"v3h-\"+(e+3)+\"Z\"}function V(t,e,r,n){for(var i,a,o,l,c=!1,u={},h={},f=0;f<e.length;f++){var p=e[f];for(i in r)if(p[i]){for(o in p)(\"x\"===o.charAt(0)?r:n)[o]||(u[o]=i);for(a in n)p[a]&&(c=!0)}for(a in n)if(p[a])for(l in p)(\"x\"===l.charAt(0)?r:n)[l]||(h[l]=a)}c&&(s.extendFlat(u,h),h={});var d={},g=[];for(o in u){var v=x(t,o);g.push(v),d[v._id]=v}var m={},y=[];for(l in h){var b=x(t,l);y.push(b),m[b._id]=b}return{xaHash:d,yaHash:m,xaxes:g,yaxes:y,xLinks:u,yLinks:h,isSubplotConstrained:c}}function q(t,e){if(a){var r=void 0!==t.onwheel?\"wheel\":\"mousewheel\";t._onwheel&&t.removeEventListener(r,t._onwheel),t._onwheel=e,t.addEventListener(r,e,{passive:!1})}else void 0!==t.onwheel?t.onwheel=e:void 0!==t.onmousewheel&&(t.onmousewheel=e)}function H(t){var e=[];for(var r in t)e.push(t[r]);return e}e.exports={makeDragBox:function(t,e,r,a,c,p,S,E){var F,G,Y,W,X,Z,J,K,$,Q,tt,et,rt,nt,it,at,ot,st,lt,ct,ut,ht=t._fullLayout._zoomlayer,ft=S+E===\"nsew\",pt=1===(S+E).length;function dt(){if(F=e.xaxis,G=e.yaxis,$=F._length,Q=G._length,J=F._offset,K=G._offset,(Y={})[F._id]=F,(W={})[G._id]=G,S&&E)for(var r=e.overlays,n=0;n<r.length;n++){var i=r[n].xaxis;Y[i._id]=i;var a=r[n].yaxis;W[a._id]=a}X=H(Y),Z=H(W),rt=L(X,E),nt=L(Z,S),it=!nt&&!rt,tt=V(t,t._fullLayout._axisConstraintGroups,Y,W),et=V(t,t._fullLayout._axisMatchGroups,Y,W),at=E||tt.isSubplotConstrained||et.isSubplotConstrained,ot=S||tt.isSubplotConstrained||et.isSubplotConstrained;var o=t._fullLayout;st=o._has(\"scattergl\"),lt=o._has(\"splom\"),ct=o._has(\"svg\")}dt();var gt=function(t,e,r){return t?\"nsew\"===t?r?\"\":\"pan\"===e?\"move\":\"crosshair\":t.toLowerCase()+\"-resize\":\"pointer\"}(nt+rt,t._fullLayout.dragmode,ft),vt=C(e,S+E+\"drag\",gt,r,a,c,p);if(it&&!ft)return vt.onmousedown=null,vt.style.pointerEvents=\"none\",vt;var mt,yt,xt,bt,_t,wt,kt,Tt,At,Mt,St={element:vt,gd:t,plotinfo:e};function Et(){St.plotinfo.selection=!1,_(t)}function Ct(r,i){var a=t._fullLayout.clickmode;if(B(t),2!==r||pt||function(){if(!t._transitioningWithDuration){var e=t._context.doubleClick,r=[];rt&&(r=r.concat(X)),nt&&(r=r.concat(Z)),et.xaxes&&(r=r.concat(et.xaxes)),et.yaxes&&(r=r.concat(et.yaxes));var n,i,a,s={};if(\"reset+autosize\"===e)for(e=\"autosize\",i=0;i<r.length;i++)if((n=r[i])._rangeInitial&&(n.range[0]!==n._rangeInitial[0]||n.range[1]!==n._rangeInitial[1])||!n._rangeInitial&&!n.autorange){e=\"reset\";break}if(\"autosize\"===e)for(i=0;i<r.length;i++)(n=r[i]).fixedrange||(s[n._name+\".autorange\"]=!0);else if(\"reset\"===e)for((rt||tt.isSubplotConstrained)&&(r=r.concat(tt.xaxes)),nt&&!tt.isSubplotConstrained&&(r=r.concat(tt.yaxes)),tt.isSubplotConstrained&&(rt?nt||(r=r.concat(Z)):r=r.concat(X)),i=0;i<r.length;i++)(n=r[i]).fixedrange||(n._rangeInitial?(a=n._rangeInitial,s[n._name+\".range[0]\"]=a[0],s[n._name+\".range[1]\"]=a[1]):s[n._name+\".autorange\"]=!0);t.emit(\"plotly_doubleclick\",null),o.call(\"_guiRelayout\",t,s)}}(),ft)a.indexOf(\"select\")>-1&&w(i,t,X,Z,e.id,St),a.indexOf(\"event\")>-1&&h.click(t,i,e.id);else if(1===r&&pt){var s=S?G:F,c=\"s\"===S||\"w\"===E?0:1,u=s._name+\".range[\"+c+\"]\",f=function(t,e){var r,i=t.range[e],a=Math.abs(i-t.range[1-e]);return\"date\"===t.type?i:\"log\"===t.type?(r=Math.ceil(Math.max(0,-Math.log(a)/Math.LN10))+3,n.format(\".\"+r+\"g\")(Math.pow(10,i))):(r=Math.floor(Math.log(Math.abs(i))/Math.LN10)-Math.floor(Math.log(a)/Math.LN10)+4,n.format(\".\"+String(r)+\"g\")(i))}(s,c),p=\"left\",d=\"middle\";if(s.fixedrange)return;S?(d=\"n\"===S?\"top\":\"bottom\",\"right\"===s.side&&(p=\"right\")):\"e\"===E&&(p=\"right\"),t._context.showAxisRangeEntryBoxes&&n.select(vt).call(l.makeEditable,{gd:t,immediate:!0,background:t._fullLayout.paper_bgcolor,text:String(f),fill:s.tickfont?s.tickfont.color:\"#444\",horizontalAlign:p,verticalAlign:d}).on(\"edit\",function(e){var r=s.d2r(e);void 0!==r&&o.call(\"_guiRelayout\",t,u,r)})}}function Lt(e,r){if(t._transitioningWithDuration)return!1;var n=Math.max(0,Math.min($,e+mt)),i=Math.max(0,Math.min(Q,r+yt)),a=Math.abs(n-mt),o=Math.abs(i-yt);function s(){kt=\"\",xt.r=xt.l,xt.t=xt.b,At.attr(\"d\",\"M0,0Z\")}if(xt.l=Math.min(mt,n),xt.r=Math.max(mt,n),xt.t=Math.min(yt,i),xt.b=Math.max(yt,i),tt.isSubplotConstrained)a>M||o>M?(kt=\"xy\",a/$>o/Q?(o=a*Q/$,yt>i?xt.t=yt-o:xt.b=yt+o):(a=o*$/Q,mt>n?xt.l=mt-a:xt.r=mt+a),At.attr(\"d\",U(xt))):s();else if(et.isSubplotConstrained)if(a>M||o>M){kt=\"xy\";var l=Math.min(xt.l/$,(Q-xt.b)/Q),c=Math.max(xt.r/$,(Q-xt.t)/Q);xt.l=l*$,xt.r=c*$,xt.b=(1-l)*Q,xt.t=(1-c)*Q,At.attr(\"d\",U(xt))}else s();else!nt||o<Math.min(Math.max(.6*a,A),M)?a<A||!rt?s():(xt.t=0,xt.b=Q,kt=\"x\",At.attr(\"d\",function(t,e){return\"M\"+(t.l-.5)+\",\"+(e-M-.5)+\"h-3v\"+(2*M+1)+\"h3ZM\"+(t.r+.5)+\",\"+(e-M-.5)+\"h3v\"+(2*M+1)+\"h-3Z\"}(xt,yt))):!rt||a<Math.min(.6*o,M)?(xt.l=0,xt.r=$,kt=\"y\",At.attr(\"d\",function(t,e){return\"M\"+(e-M-.5)+\",\"+(t.t-.5)+\"v-3h\"+(2*M+1)+\"v3ZM\"+(e-M-.5)+\",\"+(t.b+.5)+\"v3h\"+(2*M+1)+\"v-3Z\"}(xt,mt))):(kt=\"xy\",At.attr(\"d\",U(xt)));xt.w=xt.r-xt.l,xt.h=xt.b-xt.t,kt&&(Mt=!0),t._dragged=Mt,R(Tt,At,xt,_t,wt,bt),Pt(),t.emit(\"plotly_relayouting\",ut),wt=!0}function Pt(){ut={},\"xy\"!==kt&&\"x\"!==kt||(P(X,xt.l/$,xt.r/$,ut,tt.xaxes),Bt(\"x\",ut)),\"xy\"!==kt&&\"y\"!==kt||(P(Z,(Q-xt.b)/Q,(Q-xt.t)/Q,ut,tt.yaxes),Bt(\"y\",ut))}function Ot(){if(Math.min(xt.h,xt.w)<2*A)return B(t);Pt(),B(t),jt(),N(t)}St.prepFn=function(e,r,n){var a=St.dragmode,o=t._fullLayout.dragmode;o!==a&&(St.dragmode=o),dt(),it||(ft?e.shiftKey?\"pan\"===o?o=\"zoom\":j(o)||(o=\"pan\"):e.ctrlKey&&(o=\"pan\"):o=\"pan\"),St.minDrag=\"lasso\"===o?1:void 0,j(o)?(St.xaxes=X,St.yaxes=Z,b(e,r,n,St,o)):(St.clickFn=Ct,j(a)&&Et(),it||(\"zoom\"===o?(St.moveFn=Lt,St.doneFn=Ot,St.minDrag=1,function(e,r,n){var a=vt.getBoundingClientRect();mt=r-a.left,yt=n-a.top,xt={l:mt,r:mt,w:0,t:yt,b:yt,h:0},bt=t._hmpixcount?t._hmlumcount/t._hmpixcount:i(t._fullLayout.plot_bgcolor).getLuminance(),wt=!1,kt=\"xy\",Mt=!1,Tt=I(ht,bt,J,K,_t=\"M0,0H\"+$+\"V\"+Q+\"H0V0\"),At=D(ht,J,K)}(0,r,n)):\"pan\"===o&&(St.moveFn=Ft,St.doneFn=jt))),t._fullLayout._redrag=function(){var e=t._dragdata;e&&e.element===vt&&(j(t._fullLayout.dragmode)||(dt(),Ut([0,0,$,Q]),St.moveFn(e.dx,e.dy)))}},d.init(St);var zt=[0,0,$,Q],It=null,Dt=T.REDRAWDELAY,Rt=e.mainplot?t._fullLayout._plots[e.mainplot]:e;function Ft(e,r){if(!t._transitioningWithDuration){if(t._fullLayout._replotting=!0,\"ew\"===rt||\"ns\"===nt)return rt&&(O(X,e),Bt(\"x\")),nt&&(O(Z,r),Bt(\"y\")),Ut([rt?-e:0,nt?-r:0,$,Q]),Nt(),void t.emit(\"plotly_relayouting\",ut);if(tt.isSubplotConstrained&&rt&&nt){var n=\"w\"===rt==(\"n\"===nt)?1:-1,i=(e/$+n*r/Q)/2;e=i*$,r=n*i*Q}\"w\"===rt?e=l(X,0,e):\"e\"===rt?e=l(X,1,-e):rt||(e=0),\"n\"===nt?r=l(Z,1,r):\"s\"===nt?r=l(Z,0,-r):nt||(r=0);var a=\"w\"===rt?e:0,o=\"n\"===nt?r:0;if(tt.isSubplotConstrained){var s;if(!rt&&1===nt.length){for(s=0;s<X.length;s++)X[s].range=X[s]._r.slice(),k(X[s],1-r/Q);a=(e=r*$/Q)/2}if(!nt&&1===rt.length){for(s=0;s<Z.length;s++)Z[s].range=Z[s]._r.slice(),k(Z[s],1-e/$);o=(r=e*Q/$)/2}}Bt(\"x\"),Bt(\"y\"),Ut([a,o,$-e,Q-r]),Nt(),t.emit(\"plotly_relayouting\",ut)}function l(t,e,r){for(var n,i,a=1-e,o=0;o<t.length;o++){var s=t[o];if(!s.fixedrange){n=s,i=s._rl[a]+(s._rl[e]-s._rl[a])/z(r/s._length);var l=s.l2r(i);!1!==l&&void 0!==l&&(s.range[e]=l)}}return n._length*(n._rl[e]-i)/(n._rl[e]-n._rl[a])}}function Bt(t,e){for(var r=et.isSubplotConstrained?{x:Z,y:X}[t]:et[t+\"axes\"],n=et.isSubplotConstrained?{x:X,y:Z}[t]:[],i=0;i<r.length;i++){var a=r[i],o=a._id,s=et.xLinks[o]||et.yLinks[o],l=n[0]||Y[s]||W[s];l&&(e?(e[a._name+\".range[0]\"]=e[l._name+\".range[0]\"],e[a._name+\".range[1]\"]=e[l._name+\".range[1]\"]):a.range=l.range.slice())}}function Nt(){var e,r=[];function n(t){for(e=0;e<t.length;e++)t[e].fixedrange||r.push(t[e]._id)}for(at&&(n(X),n(tt.xaxes),n(et.xaxes)),ot&&(n(Z),n(tt.yaxes),n(et.yaxes)),ut={},e=0;e<r.length;e++){var i=r[e],a=x(t,i);f.drawOne(t,a,{skipTitle:!0}),ut[a._name+\".range[0]\"]=a.range[0],ut[a._name+\".range[1]\"]=a.range[1]}f.redrawComponents(t,r)}function jt(){Ut([0,0,$,Q]),s.syncOrAsync([y.previousPromises,function(){t._fullLayout._replotting=!1,o.call(\"_guiRelayout\",t,ut)}],t)}function Ut(e){var r,n,i,a,l=t._fullLayout,c=l._plots,h=l._subplots.cartesian;if(lt&&o.subplotsRegistry.splom.drag(t),st)for(r=0;r<h.length;r++)if(i=(n=c[h[r]]).xaxis,a=n.yaxis,n._scene){var f=s.simpleMap(i.range,i.r2l),p=s.simpleMap(a.range,a.r2l);n._scene.update({range:[f[0],p[0],f[1],p[1]]})}if((lt||st)&&(v(t),m(t)),ct){var d=e[2]/F._length,g=e[3]/G._length;for(r=0;r<h.length;r++){i=(n=c[h[r]]).xaxis,a=n.yaxis;var y,x,b,_,w=at&&!i.fixedrange&&Y[i._id],k=ot&&!a.fixedrange&&W[a._id];if(w?(y=d,b=E?e[0]:Ht(i,y)):et.xaHash[i._id]?(y=d,b=e[0]*i._length/F._length):et.yaHash[i._id]?(y=g,b=\"ns\"===nt?-e[1]*i._length/G._length:Ht(i,y,{n:\"top\",s:\"bottom\"}[nt])):b=qt(i,y=Vt(i,d,g)),k?(x=g,_=S?e[1]:Ht(a,x)):et.yaHash[a._id]?(x=g,_=e[1]*a._length/G._length):et.xaHash[a._id]?(x=d,_=\"ew\"===rt?-e[0]*a._length/F._length:Ht(a,x,{e:\"right\",w:\"left\"}[rt])):_=qt(a,x=Vt(a,d,g)),y||x){y||(y=1),x||(x=1);var T=i._offset-b/y,A=a._offset-_/x;n.clipRect.call(u.setTranslate,b,_).call(u.setScale,y,x),n.plot.call(u.setTranslate,T,A).call(u.setScale,1/y,1/x),y===n.xScaleFactor&&x===n.yScaleFactor||(u.setPointGroupScale(n.zoomScalePts,y,x),u.setTextPointsScale(n.zoomScaleTxt,y,x)),u.hideOutsideRangePoints(n.clipOnAxisFalseTraces,n),n.xScaleFactor=y,n.yScaleFactor=x}}}}function Vt(t,e,r){return t.fixedrange?0:at&&tt.xaHash[t._id]?e:ot&&(tt.isSubplotConstrained?tt.xaHash:tt.yaHash)[t._id]?r:0}function qt(t,e){return e?(t.range=t._r.slice(),k(t,e),Ht(t,e)):0}function Ht(t,e,r){return t._length*(1-e)*g[r||t.constraintoward||\"middle\"]}return S.length*E.length!=1&&q(vt,function(e){if(t._context._scrollZoom.cartesian||t._fullLayout._enablescrollzoom){if(Et(),t._transitioningWithDuration)return e.preventDefault(),void e.stopPropagation();dt(),clearTimeout(It);var r=-e.deltaY;if(isFinite(r)||(r=e.wheelDelta/10),isFinite(r)){var n,i=Math.exp(-Math.min(Math.max(r,-20),20)/200),a=Rt.draglayer.select(\".nsewdrag\").node().getBoundingClientRect(),o=(e.clientX-a.left)/a.width,l=(a.bottom-e.clientY)/a.height;if(at){for(E||(o=.5),n=0;n<X.length;n++)c(X[n],o,i);Bt(\"x\"),zt[2]*=i,zt[0]+=zt[2]*o*(1/i-1)}if(ot){for(S||(l=.5),n=0;n<Z.length;n++)c(Z[n],l,i);Bt(\"y\"),zt[3]*=i,zt[1]+=zt[3]*(1-l)*(1/i-1)}Ut(zt),Nt(),t.emit(\"plotly_relayouting\",ut),It=setTimeout(function(){zt=[0,0,$,Q],jt()},Dt),e.preventDefault()}else s.log(\"Did not find wheel motion attributes: \",e)}function c(t,e,r){if(!t.fixedrange){var n=s.simpleMap(t.range,t.r2l),i=n[0]+(n[1]-n[0])*e;t.range=n.map(function(e){return t.l2r(i+(e-i)*r)})}}}),vt},makeDragger:E,makeRectDragger:C,makeZoombox:I,makeCorners:D,updateZoombox:R,xyCorners:U,transitionZoombox:F,removeZoombox:B,showDoubleClickNotifier:N,attachWheelEventHandler:q}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/clear_gl_canvases\":704,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../plot_api/subroutines\":758,\"../../registry\":847,\"../plots\":828,\"./axes\":767,\"./axis_ids\":770,\"./constants\":773,\"./scale_zoom\":783,\"./select\":784,d3:163,\"has-passive-events\":411,tinycolor2:537}],776:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/fx\"),a=t(\"../../components/dragelement\"),o=t(\"../../lib/setcursor\"),s=t(\"./dragbox\").makeDragBox,l=t(\"./constants\").DRAGGERSIZE;r.initInteractions=function(t){var e=t._fullLayout;if(t._context.staticPlot)n.select(t).selectAll(\".drag\").remove();else if(e._has(\"cartesian\")||e._has(\"splom\")){Object.keys(e._plots||{}).sort(function(t,r){if((e._plots[t].mainplot&&!0)===(e._plots[r].mainplot&&!0)){var n=t.split(\"y\"),i=r.split(\"y\");return n[0]===i[0]?Number(n[1]||1)-Number(i[1]||1):Number(n[0]||1)-Number(i[0]||1)}return e._plots[t].mainplot?1:-1}).forEach(function(r){var n=e._plots[r],o=n.xaxis,c=n.yaxis;if(!n.mainplot){var u=s(t,n,o._offset,c._offset,o._length,c._length,\"ns\",\"ew\");u.onmousemove=function(e){t._fullLayout._rehover=function(){t._fullLayout._hoversubplot===r&&i.hover(t,e,r)},i.hover(t,e,r),t._fullLayout._lasthover=u,t._fullLayout._hoversubplot=r},u.onmouseout=function(e){t._dragging||(t._fullLayout._hoversubplot=null,a.unhover(t,e))},t._context.showAxisDragHandles&&(s(t,n,o._offset-l,c._offset-l,l,l,\"n\",\"w\"),s(t,n,o._offset+o._length,c._offset-l,l,l,\"n\",\"e\"),s(t,n,o._offset-l,c._offset+c._length,l,l,\"s\",\"w\"),s(t,n,o._offset+o._length,c._offset+c._length,l,l,\"s\",\"e\"))}if(t._context.showAxisDragHandles){if(r===o._mainSubplot){var h=o._mainLinePosition;\"top\"===o.side&&(h-=l),s(t,n,o._offset+.1*o._length,h,.8*o._length,l,\"\",\"ew\"),s(t,n,o._offset,h,.1*o._length,l,\"\",\"w\"),s(t,n,o._offset+.9*o._length,h,.1*o._length,l,\"\",\"e\")}if(r===c._mainSubplot){var f=c._mainLinePosition;\"right\"!==c.side&&(f-=l),s(t,n,f,c._offset+.1*c._length,l,.8*c._length,\"ns\",\"\"),s(t,n,f,c._offset+.9*c._length,l,.1*c._length,\"s\",\"\"),s(t,n,f,c._offset,l,.1*c._length,\"n\",\"\")}}});var o=e._hoverlayer.node();o.onmousemove=function(r){r.target=t._fullLayout._lasthover,i.hover(t,r,e._hoversubplot)},o.onclick=function(e){e.target=t._fullLayout._lasthover,i.click(t,e)},o.onmousedown=function(e){t._fullLayout._lasthover.onmousedown(e)},r.updateFx(t)}},r.updateFx=function(t){var e=t._fullLayout,r=\"pan\"===e.dragmode?\"move\":\"crosshair\";o(e._draggers,r)}},{\"../../components/dragelement\":611,\"../../components/fx\":632,\"../../lib/setcursor\":739,\"./constants\":773,\"./dragbox\":775,d3:163}],777:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t){return function(e,r){var a=e[t];if(Array.isArray(a))for(var o=n.subplotsRegistry.cartesian,s=o.idRegex,l=r._subplots,c=l.xaxis,u=l.yaxis,h=l.cartesian,f=r._has(\"cartesian\")||r._has(\"gl2d\"),p=0;p<a.length;p++){var d=a[p];if(i.isPlainObject(d)){var g=d.xref,v=d.yref,m=s.x.test(g),y=s.y.test(v);if(m||y){f||i.pushUnique(r._basePlotModules,o);var x=!1;m&&-1===c.indexOf(g)&&(c.push(g),x=!0),y&&-1===u.indexOf(v)&&(u.push(v),x=!0),x&&m&&y&&h.push(g+v)}}}}}},{\"../../lib\":719,\"../../registry\":847}],778:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../plots\"),s=t(\"../../components/drawing\"),l=t(\"../get_data\").getModuleCalcData,c=t(\"./axis_ids\"),u=t(\"./constants\"),h=t(\"../../constants/xmlns_namespaces\"),f=a.ensureSingle;function p(t,e,r){return a.ensureSingle(t,e,r,function(t){t.datum(r)})}function d(t,e,r,a,o){for(var c,h,f,p=u.traceLayerClasses,d=t._fullLayout,g=d._modules,v=[],m=[],y=0;y<g.length;y++){var x=(c=g[y]).name,b=i.modules[x].categories;if(b.svg){var _=c.layerName||x+\"layer\",w=c.plot;f=(h=l(r,w))[0],r=h[1],f.length&&v.push({i:p.indexOf(_),className:_,plotMethod:w,cdModule:f}),b.zoomScale&&m.push(\".\"+_)}}v.sort(function(t,e){return t.i-e.i});var k=e.plot.selectAll(\"g.mlayer\").data(v,function(t){return t.className});if(k.enter().append(\"g\").attr(\"class\",function(t){return t.className}).classed(\"mlayer\",!0).classed(\"rangeplot\",e.isRangePlot),k.exit().remove(),k.order(),k.each(function(r){var i=n.select(this),l=r.className;r.plotMethod(t,e,r.cdModule,i,a,o),-1===u.clipOnAxisFalseQuery.indexOf(\".\"+l)&&s.setClipUrl(i,e.layerClipId,t)}),d._has(\"scattergl\")&&(c=i.getModule(\"scattergl\"),f=l(r,c)[0],c.plot(t,e,f)),!t._context.staticPlot&&(e._hasClipOnAxisFalse&&(e.clipOnAxisFalseTraces=e.plot.selectAll(u.clipOnAxisFalseQuery.join(\",\")).selectAll(\".trace\")),m.length)){var T=e.plot.selectAll(m.join(\",\")).selectAll(\".trace\");e.zoomScalePts=T.selectAll(\"path.point\"),e.zoomScaleTxt=T.selectAll(\".textpoint\")}}function g(t,e){var r=e.plotgroup,n=e.id,i=u.layerValue2layerClass[e.xaxis.layer],a=u.layerValue2layerClass[e.yaxis.layer],o=t._fullLayout._hasOnlyLargeSploms;if(e.mainplot){var s=e.mainplotinfo,l=s.plotgroup,h=n+\"-x\",d=n+\"-y\";e.gridlayer=s.gridlayer,e.zerolinelayer=s.zerolinelayer,f(s.overlinesBelow,\"path\",h),f(s.overlinesBelow,\"path\",d),f(s.overaxesBelow,\"g\",h),f(s.overaxesBelow,\"g\",d),e.plot=f(s.overplot,\"g\",n),f(s.overlinesAbove,\"path\",h),f(s.overlinesAbove,\"path\",d),f(s.overaxesAbove,\"g\",h),f(s.overaxesAbove,\"g\",d),e.xlines=l.select(\".overlines-\"+i).select(\".\"+h),e.ylines=l.select(\".overlines-\"+a).select(\".\"+d),e.xaxislayer=l.select(\".overaxes-\"+i).select(\".\"+h),e.yaxislayer=l.select(\".overaxes-\"+a).select(\".\"+d)}else if(o)e.xlines=f(r,\"path\",\"xlines-above\"),e.ylines=f(r,\"path\",\"ylines-above\"),e.xaxislayer=f(r,\"g\",\"xaxislayer-above\"),e.yaxislayer=f(r,\"g\",\"yaxislayer-above\");else{var g=f(r,\"g\",\"layer-subplot\");e.shapelayer=f(g,\"g\",\"shapelayer\"),e.imagelayer=f(g,\"g\",\"imagelayer\"),e.gridlayer=f(r,\"g\",\"gridlayer\"),e.zerolinelayer=f(r,\"g\",\"zerolinelayer\"),f(r,\"path\",\"xlines-below\"),f(r,\"path\",\"ylines-below\"),e.overlinesBelow=f(r,\"g\",\"overlines-below\"),f(r,\"g\",\"xaxislayer-below\"),f(r,\"g\",\"yaxislayer-below\"),e.overaxesBelow=f(r,\"g\",\"overaxes-below\"),e.plot=f(r,\"g\",\"plot\"),e.overplot=f(r,\"g\",\"overplot\"),e.xlines=f(r,\"path\",\"xlines-above\"),e.ylines=f(r,\"path\",\"ylines-above\"),e.overlinesAbove=f(r,\"g\",\"overlines-above\"),f(r,\"g\",\"xaxislayer-above\"),f(r,\"g\",\"yaxislayer-above\"),e.overaxesAbove=f(r,\"g\",\"overaxes-above\"),e.xlines=r.select(\".xlines-\"+i),e.ylines=r.select(\".ylines-\"+a),e.xaxislayer=r.select(\".xaxislayer-\"+i),e.yaxislayer=r.select(\".yaxislayer-\"+a)}o||(p(e.gridlayer,\"g\",e.xaxis._id),p(e.gridlayer,\"g\",e.yaxis._id),e.gridlayer.selectAll(\"g\").map(function(t){return t[0]}).sort(c.idSort)),e.xlines.style(\"fill\",\"none\").classed(\"crisp\",!0),e.ylines.style(\"fill\",\"none\").classed(\"crisp\",!0)}function v(t,e){if(t){var r={};for(var i in t.each(function(t){var i=t[0];n.select(this).remove(),m(i,e),r[i]=!0}),e._plots)for(var a=e._plots[i].overlays||[],o=0;o<a.length;o++){var s=a[o];r[s.id]&&s.plot.selectAll(\".trace\").remove()}}}function m(t,e){e._draggers.selectAll(\"g.\"+t).remove(),e._defs.select(\"#clip\"+e._uid+t+\"plot\").remove()}r.name=\"cartesian\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=u.idRegex,r.attrRegex=u.attrRegex,r.attributes=t(\"./attributes\"),r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.transitionAxes=t(\"./transition_axes\"),r.finalizeSubplots=function(t,e){var r,n,i,o=e._subplots,s=o.xaxis,l=o.yaxis,h=o.cartesian,f=h.concat(o.gl2d||[]),p={},d={};for(r=0;r<f.length;r++){var g=f[r].split(\"y\");p[g[0]]=1,d[\"y\"+g[1]]=1}for(r=0;r<s.length;r++)p[n=s[r]]||(i=(t[c.id2name(n)]||{}).anchor,u.idRegex.y.test(i)||(i=\"y\"),h.push(n+i),f.push(n+i),d[i]||(d[i]=1,a.pushUnique(l,i)));for(r=0;r<l.length;r++)d[i=l[r]]||(n=(t[c.id2name(i)]||{}).anchor,u.idRegex.x.test(n)||(n=\"x\"),h.push(n+i),f.push(n+i),p[n]||(p[n]=1,a.pushUnique(s,n)));if(!f.length){for(var v in n=\"\",i=\"\",t){if(u.attrRegex.test(v))\"x\"===v.charAt(0)?(!n||+v.substr(5)<+n.substr(5))&&(n=v):(!i||+v.substr(5)<+i.substr(5))&&(i=v)}n=n?c.name2id(n):\"x\",i=i?c.name2id(i):\"y\",s.push(n),l.push(i),h.push(n+i)}},r.plot=function(t,e,r,n){var i,a=t._fullLayout,o=a._subplots.cartesian,s=t.calcdata;if(!Array.isArray(e))for(e=[],i=0;i<s.length;i++)e.push(i);for(i=0;i<o.length;i++){for(var l,c=o[i],u=a._plots[c],h=[],f=0;f<s.length;f++){var p=s[f],g=p[0].trace;g.xaxis+g.yaxis===c&&((-1!==e.indexOf(g.index)||g.carpet)&&(l&&l[0].trace.xaxis+l[0].trace.yaxis===c&&-1!==[\"tonextx\",\"tonexty\",\"tonext\"].indexOf(g.fill)&&-1===h.indexOf(l)&&h.push(l),h.push(p)),l=p)}d(t,u,h,r,n)}},r.clean=function(t,e,r,n){var i,a,o,s=n._plots||{},l=e._plots||{},u=n._subplots||{};if(n._hasOnlyLargeSploms&&!e._hasOnlyLargeSploms)for(o in s)(i=s[o]).plotgroup&&i.plotgroup.remove();var h=n._has&&n._has(\"gl\"),f=e._has&&e._has(\"gl\");if(h&&!f)for(o in s)(i=s[o])._scene&&i._scene.destroy();if(u.xaxis&&u.yaxis){var p=c.listIds({_fullLayout:n});for(a=0;a<p.length;a++){var d=p[a];e[c.id2name(d)]||n._infolayer.selectAll(\".g-\"+d+\"title\").remove()}}var g=n._has&&n._has(\"cartesian\"),y=e._has&&e._has(\"cartesian\");if(g&&!y)v(n._cartesianlayer.selectAll(\".subplot\"),n),n._defs.selectAll(\".axesclip\").remove(),delete n._axisConstraintGroups;else if(u.cartesian)for(a=0;a<u.cartesian.length;a++){var x=u.cartesian[a];if(!l[x]){var b=\".\"+x+\",.\"+x+\"-x,.\"+x+\"-y\";n._cartesianlayer.selectAll(b).remove(),m(x,n)}}},r.drawFramework=function(t){var e=t._fullLayout,r=function(t){var e,r,n,i,a,o,s=t._fullLayout,l=s._subplots.cartesian,c=l.length,u=[],h=[];for(e=0;e<c;e++){n=l[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var f=a._mainAxis,p=o._mainAxis,d=f._id+p._id,g=s._plots[d];i.overlays=[],d!==n&&g?(i.mainplot=d,i.mainplotinfo=g,h.push(n)):(i.mainplot=void 0,i.mainPlotinfo=void 0,u.push(n))}for(e=0;e<h.length;e++)n=h[e],(i=s._plots[n]).mainplotinfo.overlays.push(i);var v=u.concat(h),m=new Array(c);for(e=0;e<c;e++){n=v[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var y=[n,a.layer,o.layer,a.overlaying||\"\",o.overlaying||\"\"];for(r=0;r<i.overlays.length;r++)y.push(i.overlays[r].id);m[e]=y}return m}(t),i=e._cartesianlayer.selectAll(\".subplot\").data(r,String);i.enter().append(\"g\").attr(\"class\",function(t){return\"subplot \"+t[0]}),i.order(),i.exit().call(v,e),i.each(function(r){var i=r[0],a=e._plots[i];a.plotgroup=n.select(this),g(t,a),a.draglayer=f(e._draggers,\"g\",i)})},r.rangePlot=function(t,e,r){g(t,e),d(t,e,r),o.style(t)},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter(function(t,e){return e===r.size()-1}).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each(function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:h.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})})},r.updateFx=t(\"./graph_interact\").updateFx},{\"../../components/drawing\":614,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../registry\":847,\"../get_data\":802,\"../plots\":828,\"./attributes\":765,\"./axis_ids\":770,\"./constants\":773,\"./graph_interact\":776,\"./layout_attributes\":779,\"./layout_defaults\":780,\"./transition_axes\":789,d3:163}],779:[function(t,e,r){\"use strict\";var n=t(\"../font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray,l=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").DATE_FORMAT_LINK,t(\"./constants\"));e.exports={visible:{valType:\"boolean\",editType:\"plot\"},color:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},title:{text:{valType:\"string\",editType:\"ticks\"},font:n({editType:\"ticks\"}),editType:\"ticks\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"log\",\"date\",\"category\",\"multicategory\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"axrange\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0},{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0}],editType:\"axrange\",impliedEdits:{autorange:!1},anim:!0},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},scaleanchor:{valType:\"enumerated\",values:[l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},scaleratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},constrain:{valType:\"enumerated\",values:[\"range\",\"domain\"],dflt:\"range\",editType:\"plot\"},constraintoward:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\",\"top\",\"middle\",\"bottom\"],editType:\"plot\"},matches:{valType:\"enumerated\",values:[l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"calc\"},tickmode:{valType:\"enumerated\",values:[\"auto\",\"linear\",\"array\"],editType:\"ticks\",impliedEdits:{tick0:void 0,dtick:void 0}},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"ticks\"},tick0:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},dtick:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},tickvals:{valType:\"data_array\",editType:\"ticks\"},ticktext:{valType:\"data_array\",editType:\"ticks\"},ticks:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"\"],editType:\"ticks\"},tickson:{valType:\"enumerated\",values:[\"labels\",\"boundaries\"],dflt:\"labels\",editType:\"ticks\"},mirror:{valType:\"enumerated\",values:[!0,\"ticks\",!1,\"all\",\"allticks\"],dflt:!1,editType:\"ticks+layoutstyle\"},ticklen:{valType:\"number\",min:0,dflt:5,editType:\"ticks\"},tickwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},tickcolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},showticklabels:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},automargin:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},showspikes:{valType:\"boolean\",dflt:!1,editType:\"modebar\"},spikecolor:{valType:\"color\",dflt:null,editType:\"none\"},spikethickness:{valType:\"number\",dflt:3,editType:\"none\"},spikedash:o({},a,{dflt:\"dash\",editType:\"none\"}),spikemode:{valType:\"flaglist\",flags:[\"toaxis\",\"across\",\"marker\"],dflt:\"toaxis\",editType:\"none\"},spikesnap:{valType:\"enumerated\",values:[\"data\",\"cursor\"],dflt:\"data\",editType:\"none\"},tickfont:n({editType:\"ticks\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"ticks\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"ticks\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"ticks\"},tickformatstops:s(\"tickformatstop\",{enabled:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dtickrange:{valType:\"info_array\",items:[{valType:\"any\",editType:\"ticks\"},{valType:\"any\",editType:\"ticks\"}],editType:\"ticks\"},value:{valType:\"string\",dflt:\"\",editType:\"ticks\"},editType:\"ticks\"}),hoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},showline:{valType:\"boolean\",dflt:!1,editType:\"ticks+layoutstyle\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"layoutstyle\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks+layoutstyle\"},showgrid:{valType:\"boolean\",editType:\"ticks\"},gridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"ticks\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},zeroline:{valType:\"boolean\",editType:\"ticks\"},zerolinecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},zerolinewidth:{valType:\"number\",dflt:1,editType:\"ticks\"},showdividers:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dividercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},dividerwidth:{valType:\"number\",dflt:1,editType:\"ticks\"},anchor:{valType:\"enumerated\",values:[\"free\",l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},side:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],editType:\"plot\"},overlaying:{valType:\"enumerated\",values:[\"free\",l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},layer:{valType:\"enumerated\",values:[\"above traces\",\"below traces\"],dflt:\"above traces\",editType:\"plot\"},domain:{valType:\"info_array\",items:[{valType:\"number\",min:0,max:1,editType:\"plot\"},{valType:\"number\",min:0,max:1,editType:\"plot\"}],dflt:[0,1],editType:\"plot\"},position:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\",\"total ascending\",\"total descending\",\"min ascending\",\"min descending\",\"max ascending\",\"max descending\",\"sum ascending\",\"sum descending\",\"mean ascending\",\"mean descending\",\"median ascending\",\"median descending\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{autotick:{valType:\"boolean\",editType:\"ticks\"},title:{valType:\"string\",editType:\"ticks\"},titlefont:n({editType:\"ticks\"})}}},{\"../../components/color/attributes\":592,\"../../components/drawing/attributes\":613,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../font_attributes\":793,\"./constants\":773}],780:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../layout_attributes\"),s=t(\"./layout_attributes\"),l=t(\"./type_defaults\"),c=t(\"./axis_defaults\"),u=t(\"./constraints\").handleConstraintDefaults,h=t(\"./position_defaults\"),f=t(\"./axis_ids\"),p=f.id2name,d=f.name2id,g=t(\"../../registry\"),v=g.traceIs,m=g.getComponentMethod;function y(t,e,r){Array.isArray(t[e])?t[e].push(r):t[e]=[r]}e.exports=function(t,e,r){var f,g,x={},b={},_={},w={},k={},T={},A={},M={},S={};for(f=0;f<r.length;f++){var E=r[f];if(v(E,\"cartesian\")||v(E,\"gl2d\")){var C,L;if(E.xaxis)y(x,C=p(E.xaxis),E);else if(E.xaxes)for(g=0;g<E.xaxes.length;g++)y(x,p(E.xaxes[g]),E);if(E.yaxis)y(x,L=p(E.yaxis),E);else if(E.yaxes)for(g=0;g<E.yaxes.length;g++)y(x,p(E.yaxes[g]),E);if(\"funnel\"===E.type?\"h\"===E.orientation?(C&&(b[C]=!0),L&&(A[L]=!0)):L&&(_[L]=!0):(L&&(k[L]=!0,T[L]=!0),v(E,\"carpet\")&&(\"carpet\"!==E.type||E._cheater)||C&&(w[C]=!0)),\"carpet\"===E.type&&E._cheater&&C&&(b[C]=!0),v(E,\"2dMap\")&&(M[C]=!0,M[L]=!0),v(E,\"oriented\"))S[\"h\"===E.orientation?L:C]=!0}}var P=e._subplots,O=P.xaxis,z=P.yaxis,I=n.simpleMap(O,p),D=n.simpleMap(z,p),R=I.concat(D),F=i.background;O.length&&z.length&&(F=n.coerce(t,e,o,\"plot_bgcolor\"));var B,N,j,U,V=i.combine(F,e.paper_bgcolor);function q(t,e){return n.coerce(j,U,s,t,e)}function H(t,e){return n.coerce2(j,U,s,t,e)}function G(t){return\"x\"===t?z:O}var Y={x:G(\"x\"),y:G(\"y\")},W=Y.x.concat(Y.y);function X(e,r){for(var n=\"x\"===e?I:D,i=[],a=0;a<n.length;a++){var o=n[a];o===r||(t[o]||{}).overlaying||i.push(d(o))}return i}for(f=0;f<R.length;f++){N=(B=R[f]).charAt(0),n.isPlainObject(t[B])||(t[B]={}),j=t[B],U=a.newContainer(e,B,N+\"axis\");var Z=x[B]||[];U._traceIndices=Z.map(function(t){return t._expandedIndex}),U._annIndices=[],U._shapeIndices=[],U._imgIndices=[],U._subplotsWith=[],U._counterAxes=[],U._name=U._attr=B;var J=U._id=d(B),K=X(N,B),$=\"x\"===N&&!w[B]&&b[B]||\"y\"===N&&!k[B]&&_[B],Q=\"y\"===N&&!T[B]&&A[B],tt={letter:N,font:e.font,outerTicks:M[B],showGrid:!S[B],data:Z,bgColor:V,calendar:e.calendar,automargin:!0,visibleDflt:$,reverseDflt:Q,splomStash:((e._splomAxes||{})[N]||{})[J]};q(\"uirevision\",e.uirevision),l(j,U,q,tt),c(j,U,q,tt,e);var et=H(\"spikecolor\"),rt=H(\"spikethickness\"),nt=H(\"spikedash\"),it=H(\"spikemode\"),at=H(\"spikesnap\");q(\"showspikes\",!!(et||rt||nt||it||at))||(delete U.spikecolor,delete U.spikethickness,delete U.spikedash,delete U.spikemode,delete U.spikesnap),h(j,U,q,{letter:N,counterAxes:Y[N],overlayableAxes:K,grid:e.grid}),U._input=j}var ot=m(\"rangeslider\",\"handleDefaults\"),st=m(\"rangeselector\",\"handleDefaults\");for(f=0;f<I.length;f++)B=I[f],j=t[B],U=e[B],ot(t,e,B),\"date\"===U.type&&st(j,U,e,D,U.calendar),q(\"fixedrange\");for(f=0;f<D.length;f++){B=D[f],j=t[B],U=e[B];var lt=e[p(U.anchor)];q(\"fixedrange\",m(\"rangeslider\",\"isVisible\")(lt))}var ct=e._axisConstraintGroups=[],ut=e._axisMatchGroups=[];for(f=0;f<R.length;f++)N=(B=R[f]).charAt(0),j=t[B],U=e[B],u(j,U,q,W,e);for(f=0;f<ut.length;f++){var ht,ft=ut[f],pt=null,dt=null;for(ht in ft)(U=e[p(ht)]).matches||(pt=U.range,dt=U.autorange);if(null===pt||null===dt)for(ht in ft){pt=(U=e[p(ht)]).range,dt=U.autorange;break}for(ht in ft)(U=e[p(ht)]).matches&&(U.range=pt.slice(),U.autorange=dt),U._matchGroup=ft;if(ct.length)for(ht in ft)for(g=0;g<ct.length;g++){var gt=ct[g];for(var vt in gt)ht===vt&&(n.warn(\"Axis \"+vt+\" is set with both a *scaleanchor* and *matches* constraint; ignoring the scale constraint.\"),delete gt[vt],Object.keys(gt).length<2&&ct.splice(g,1))}}}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../registry\":847,\"../layout_attributes\":819,\"./axis_defaults\":769,\"./axis_ids\":770,\"./constraints\":774,\"./layout_attributes\":779,\"./position_defaults\":782,\"./type_defaults\":790}],781:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../components/color/attributes\").lightFraction,a=t(\"../../lib\");e.exports=function(t,e,r,o){var s=(o=o||{}).dfltColor;function l(r,n){return a.coerce2(t,e,o.attributes,r,n)}var c=l(\"linecolor\",s),u=l(\"linewidth\");r(\"showline\",o.showLine||!!c||!!u)||(delete e.linecolor,delete e.linewidth);var h=l(\"gridcolor\",n(s,o.bgColor,o.blend||i).toRgbString()),f=l(\"gridwidth\");if(r(\"showgrid\",o.showGrid||!!h||!!f)||(delete e.gridcolor,delete e.gridwidth),!o.noZeroLine){var p=l(\"zerolinecolor\",s),d=l(\"zerolinewidth\");r(\"zeroline\",o.showGrid||!!p||!!d)||(delete e.zerolinecolor,delete e.zerolinewidth)}}},{\"../../components/color/attributes\":592,\"../../lib\":719,tinycolor2:537}],782:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o,s,l,c,u=a.counterAxes||[],h=a.overlayableAxes||[],f=a.letter,p=a.grid;p&&(s=p._domains[f][p._axisMap[e._id]],o=p._anchors[e._id],s&&(l=p[f+\"side\"].split(\" \")[0],c=p.domain[f][\"right\"===l||\"top\"===l?1:0])),s=s||[0,1],o=o||(n(t.position)?\"free\":u[0]||\"free\"),l=l||(\"x\"===f?\"bottom\":\"left\"),c=c||0,\"free\"===i.coerce(t,e,{anchor:{valType:\"enumerated\",values:[\"free\"].concat(u),dflt:o}},\"anchor\")&&r(\"position\",c),i.coerce(t,e,{side:{valType:\"enumerated\",values:\"x\"===f?[\"bottom\",\"top\"]:[\"left\",\"right\"],dflt:l}},\"side\");var d=!1;if(h.length&&(d=i.coerce(t,e,{overlaying:{valType:\"enumerated\",values:[!1].concat(h),dflt:!1}},\"overlaying\")),!d){var g=r(\"domain\",s);g[0]>g[1]-1/4096&&(e.domain=s),i.noneOrAll(t.domain,e.domain,s)}return r(\"layer\"),e}},{\"../../lib\":719,\"fast-isnumeric\":225}],783:[function(t,e,r){\"use strict\";var n=t(\"../../constants/alignment\").FROM_BL;e.exports=function(t,e,r){void 0===r&&(r=n[t.constraintoward||\"center\"]);var i=[t.r2l(t.range[0]),t.r2l(t.range[1])],a=i[0]+(i[1]-i[0])*r;t.range=t._input.range=[t.l2r(a+(i[0]-a)*e),t.l2r(a+(i[1]-a)*e)]}},{\"../../constants/alignment\":688}],784:[function(t,e,r){\"use strict\";var n=t(\"polybooljs\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../../components/fx\"),s=t(\"../../lib\"),l=t(\"../../lib/polygon\"),c=t(\"../../lib/throttle\"),u=t(\"../../components/fx/helpers\").makeEventData,h=t(\"./axis_ids\").getFromId,f=t(\"../../lib/clear_gl_canvases\"),p=t(\"../../plot_api/subroutines\").redrawReglTraces,d=t(\"./constants\"),g=d.MINSELECT,v=l.filter,m=l.tester;function y(t){return t._id}function x(t,e,r,n,i,a,o){var s,l,c,u,h,f,p,d,g,v=e._hoverdata,m=e._fullLayout.clickmode.indexOf(\"event\")>-1,y=[];if(function(t){return t&&Array.isArray(t)&&!0!==t[0].hoverOnBox}(v)){k(t,e,a);var x=function(t,e){var r,n,i=t[0],a=-1,o=[];for(n=0;n<e.length;n++)if(r=e[n],i.fullData._expandedIndex===r.cd[0].trace._expandedIndex){if(!0===i.hoverOnBox)break;void 0!==i.pointNumber?a=i.pointNumber:void 0!==i.binNumber&&(a=i.binNumber,o=i.pointNumbers);break}return{pointNumber:a,pointNumbers:o,searchInfo:r}}(v,s=A(e,r,n,i));if(x.pointNumbers.length>0?function(t,e){var r,n,i,a=[];for(i=0;i<t.length;i++)(r=t[i]).cd[0].trace.selectedpoints&&r.cd[0].trace.selectedpoints.length>0&&a.push(r);if(1===a.length&&a[0]===e.searchInfo&&(n=e.searchInfo.cd[0].trace).selectedpoints.length===e.pointNumbers.length){for(i=0;i<e.pointNumbers.length;i++)if(n.selectedpoints.indexOf(e.pointNumbers[i])<0)return!1;return!0}return!1}(s,x):function(t){var e,r,n,i=0;for(n=0;n<t.length;n++)if(e=t[n],(r=e.cd[0].trace).selectedpoints){if(r.selectedpoints.length>1)return!1;if((i+=r.selectedpoints.length)>1)return!1}return 1===i}(s)&&(f=S(x))){for(o&&o.remove(),g=0;g<s.length;g++)(l=s[g])._module.selectPoints(l,!1);E(e,s),T(a),m&&e.emit(\"plotly_deselect\",null)}else{for(p=t.shiftKey&&(void 0!==f?f:S(x)),c=function(t,e,r){return{pointNumber:t,searchInfo:e,subtract:r}}(x.pointNumber,x.searchInfo,p),u=w(a.selectionDefs.concat([c])),g=0;g<s.length;g++)if(h=C(s[g]._module.selectPoints(s[g],u),s[g]),y.length)for(var b=0;b<h.length;b++)y.push(h[b]);else y=h;E(e,s,d={points:y}),c&&a&&a.selectionDefs.push(c),o&&M(a.mergedPolygons,o),m&&e.emit(\"plotly_selected\",d)}}}function b(t){return\"pointNumber\"in t&&\"searchInfo\"in t}function _(t){return{xmin:0,xmax:0,ymin:0,ymax:0,pts:[],contains:function(e,r,n,i){var a=t.searchInfo.cd[0].trace._expandedIndex;return i.cd[0].trace._expandedIndex===a&&n===t.pointNumber},isRect:!1,degenerate:!1,subtract:t.subtract}}function w(t){for(var e=[],r=b(t[0])?0:t[0][0][0],n=r,i=b(t[0])?0:t[0][0][1],a=i,o=0;o<t.length;o++)if(b(t[o]))e.push(_(t[o]));else{var s=l.tester(t[o]);s.subtract=t[o].subtract,e.push(s),r=Math.min(r,s.xmin),n=Math.max(n,s.xmax),i=Math.min(i,s.ymin),a=Math.max(a,s.ymax)}return{xmin:r,xmax:n,ymin:i,ymax:a,pts:[],contains:function(t,r,n,i){for(var a=!1,o=0;o<e.length;o++)e[o].contains(t,r,n,i)&&(a=!1===e[o].subtract);return a},isRect:!1,degenerate:!1}}function k(t,e,r){var n=e._fullLayout,i=r.plotinfo,a=n._lastSelectedSubplot&&n._lastSelectedSubplot===i.id,o=t.shiftKey||t.altKey;a&&o&&i.selection&&i.selection.selectionDefs&&!r.selectionDefs?(r.selectionDefs=i.selection.selectionDefs,r.mergedPolygons=i.selection.mergedPolygons):o&&i.selection||T(r),a||(L(e),n._lastSelectedSubplot=i.id)}function T(t){var e=t.plotinfo;e.selection={},e.selection.selectionDefs=t.selectionDefs=[],e.selection.mergedPolygons=t.mergedPolygons=[]}function A(t,e,r,n){var i,a,o,s=[],l=e.map(y),c=r.map(y);for(o=0;o<t.calcdata.length;o++)if(!0===(a=(i=t.calcdata[o])[0].trace).visible&&a._module&&a._module.selectPoints)if(!n||a.subplot!==n&&a.geo!==n)if(\"splom\"===a.type&&a._xaxes[l[0]]&&a._yaxes[c[0]]){var u=p(a._module,i,e[0],r[0]);u.scene=t._fullLayout._splomScenes[a.uid],s.push(u)}else if(\"sankey\"===a.type){var f=p(a._module,i,e[0],r[0]);s.push(f)}else{if(-1===l.indexOf(a.xaxis))continue;if(-1===c.indexOf(a.yaxis))continue;s.push(p(a._module,i,h(t,a.xaxis),h(t,a.yaxis)))}else s.push(p(a._module,i,e[0],r[0]));return s;function p(t,e,r,n){return{_module:t,cd:e,xaxis:r,yaxis:n}}}function M(t,e){var r,n,i=[];for(r=0;r<t.length;r++){var a=t[r];i.push(a.join(\"L\")+\"L\"+a[0])}n=t.length>0?\"M\"+i.join(\"M\")+\"Z\":\"M0,0Z\",e.attr(\"d\",n)}function S(t){var e=t.searchInfo.cd[0].trace,r=t.pointNumber,n=t.pointNumbers,i=n.length>0?n[0]:r;return!!e.selectedpoints&&e.selectedpoints.indexOf(i)>-1}function E(t,e,r){var n,a,o,s;for(n=0;n<e.length;n++){var l=e[n].cd[0].trace._fullInput,c=t._fullLayout._tracePreGUI[l.uid]||{};void 0===c.selectedpoints&&(c.selectedpoints=l._input.selectedpoints||null)}if(r){var u=r.points||[];for(n=0;n<e.length;n++)(s=e[n].cd[0].trace)._input.selectedpoints=s._fullInput.selectedpoints=[],s._fullInput!==s&&(s.selectedpoints=[]);for(n=0;n<u.length;n++){var h=u[n],d=h.data,g=h.fullData;h.pointIndices?([].push.apply(d.selectedpoints,h.pointIndices),s._fullInput!==s&&[].push.apply(g.selectedpoints,h.pointIndices)):(d.selectedpoints.push(h.pointIndex),s._fullInput!==s&&g.selectedpoints.push(h.pointIndex))}}else for(n=0;n<e.length;n++)delete(s=e[n].cd[0].trace).selectedpoints,delete s._input.selectedpoints,s._fullInput!==s&&delete s._fullInput.selectedpoints;var v=!1;for(n=0;n<e.length;n++){s=(o=(a=e[n]).cd)[0].trace,i.traceIs(s,\"regl\")&&(v=!0);var m=a._module,y=m.styleOnSelect||m.style;y&&(y(t,o,o[0].node3),o[0].nodeRangePlot3&&y(t,o,o[0].nodeRangePlot3))}v&&(f(t),p(t))}function C(t,e){if(Array.isArray(t))for(var r=e.cd,n=e.cd[0].trace,i=0;i<t.length;i++)t[i]=u(t[i],n,r);return t}function L(t){var e=(t._fullLayout||{})._zoomlayer;e&&e.selectAll(\".select-outline\").remove()}e.exports={prepSelect:function(t,e,r,i,l){var u,h,f,p,y,b,_,S=i.gd,L=S._fullLayout,P=L._zoomlayer,O=i.element.getBoundingClientRect(),z=i.plotinfo,I=z.xaxis._offset,D=z.yaxis._offset,R=e-O.left,F=r-O.top,B=R,N=F,j=\"M\"+R+\",\"+F,U=i.xaxes[0]._length,V=i.yaxes[0]._length,q=i.xaxes.concat(i.yaxes),H=t.altKey;k(t,S,i),\"lasso\"===l&&(u=v([[R,F]],d.BENDPX));var G=P.selectAll(\"path.select-outline-\"+z.id).data([1,2]);G.enter().append(\"path\").attr(\"class\",function(t){return\"select-outline select-outline-\"+t+\" select-outline-\"+z.id}).attr(\"transform\",\"translate(\"+I+\", \"+D+\")\").attr(\"d\",j+\"Z\");var Y,W=P.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:a.background,stroke:a.defaultLine,\"stroke-width\":1}).attr(\"transform\",\"translate(\"+I+\", \"+D+\")\").attr(\"d\",\"M0,0Z\"),X=L._uid+d.SELECTID,Z=[],J=A(S,i.xaxes,i.yaxes,i.subplot);function K(t,e){return\"log\"===t.type?t.p2d(e):t.p2r(e)}function $(t){var e=\"y\"===t._id.charAt(0)?1:0;return function(r){return K(t,r[e])}}function Q(t,e){return t-e}Y=z.fillRangeItems?z.fillRangeItems:\"select\"===l?function(t,e){var r=t.range={};for(y=0;y<q.length;y++){var n=q[y],i=n._id.charAt(0);r[n._id]=[K(n,e[i+\"min\"]),K(n,e[i+\"max\"])].sort(Q)}}:function(t,e,r){var n=t.lassoPoints={};for(y=0;y<q.length;y++){var i=q[y];n[i._id]=r.filtered.map($(i))}},i.moveFn=function(t,e){B=Math.max(0,Math.min(U,t+R)),N=Math.max(0,Math.min(V,e+F));var r=Math.abs(B-R),a=Math.abs(N-F);if(\"select\"===l){var o=L.selectdirection;\"h\"===(o=\"any\"===L.selectdirection?a<Math.min(.6*r,g)?\"h\":r<Math.min(.6*a,g)?\"v\":\"d\":L.selectdirection)?((p=[[R,0],[R,V],[B,V],[B,0]]).xmin=Math.min(R,B),p.xmax=Math.max(R,B),p.ymin=Math.min(0,V),p.ymax=Math.max(0,V),W.attr(\"d\",\"M\"+p.xmin+\",\"+(F-g)+\"h-4v\"+2*g+\"h4ZM\"+(p.xmax-1)+\",\"+(F-g)+\"h4v\"+2*g+\"h-4Z\")):\"v\"===o?((p=[[0,F],[0,N],[U,N],[U,F]]).xmin=Math.min(0,U),p.xmax=Math.max(0,U),p.ymin=Math.min(F,N),p.ymax=Math.max(F,N),W.attr(\"d\",\"M\"+(R-g)+\",\"+p.ymin+\"v-4h\"+2*g+\"v4ZM\"+(R-g)+\",\"+(p.ymax-1)+\"v4h\"+2*g+\"v-4Z\")):\"d\"===o&&((p=[[R,F],[R,N],[B,N],[B,F]]).xmin=Math.min(R,B),p.xmax=Math.max(R,B),p.ymin=Math.min(F,N),p.ymax=Math.max(F,N),W.attr(\"d\",\"M0,0Z\"))}else\"lasso\"===l&&(u.addPt([B,N]),p=u.filtered);i.selectionDefs&&i.selectionDefs.length?(f=function(t,e,r){return r?n.difference({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions:n.union({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions}(i.mergedPolygons,p,H),p.subtract=H,h=w(i.selectionDefs.concat([p]))):(f=[p],h=m(p)),M(f,G),c.throttle(X,d.SELECTDELAY,function(){var t;Z=[];var e,r=[];for(y=0;y<J.length;y++)if(e=(b=J[y])._module.selectPoints(b,h),r.push(e),t=C(e,b),Z.length)for(var n=0;n<t.length;n++)Z.push(t[n]);else Z=t;E(S,J,_={points:Z}),Y(_,p,u),i.gd.emit(\"plotly_selecting\",_)})},i.clickFn=function(t,e){var r=L.clickmode;W.remove(),c.done(X).then(function(){if(c.clear(X),2===t){for(G.remove(),y=0;y<J.length;y++)(b=J[y])._module.selectPoints(b,!1);E(S,J),T(i),S.emit(\"plotly_deselect\",null)}else r.indexOf(\"select\")>-1&&x(e,S,i.xaxes,i.yaxes,i.subplot,i,G),\"event\"===r&&S.emit(\"plotly_selected\",void 0);o.click(S,e)}).catch(s.error)},i.doneFn=function(){W.remove(),c.done(X).then(function(){c.clear(X),i.gd.emit(\"plotly_selected\",_),p&&i.selectionDefs&&(p.subtract=H,i.selectionDefs.push(p),i.mergedPolygons.length=0,[].push.apply(i.mergedPolygons,f)),i.doneFnCompleted&&i.doneFnCompleted(Z)}).catch(s.error)}},clearSelect:L,selectOnClick:x}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../components/fx/helpers\":628,\"../../lib\":719,\"../../lib/clear_gl_canvases\":704,\"../../lib/polygon\":731,\"../../lib/throttle\":744,\"../../plot_api/subroutines\":758,\"../../registry\":847,\"./axis_ids\":770,\"./constants\":773,polybooljs:473}],785:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=a.cleanNumber,s=a.ms2DateTime,l=a.dateTime2ms,c=a.ensureNumber,u=a.isArrayOrTypedArray,h=t(\"../../constants/numerical\"),f=h.FP_SAFE,p=h.BADNUM,d=h.LOG_CLIP,g=t(\"./constants\"),v=t(\"./axis_ids\");function m(t){return Math.pow(10,t)}function y(t){return null!=t}e.exports=function(t,e){e=e||{};var r=t._id||\"x\",h=r.charAt(0);function x(e,r){if(e>0)return Math.log(e)/Math.LN10;if(e<=0&&r&&t.range&&2===t.range.length){var n=t.range[0],i=t.range[1];return.5*(n+i-2*d*Math.abs(n-i))}return p}function b(e,r,n){var o=l(e,n||t.calendar);if(o===p){if(!i(e))return p;e=+e;var s=Math.floor(10*a.mod(e+.05,1)),c=Math.round(e-s/10);o=l(new Date(c))+s/10}return o}function _(e,r,n){return s(e,r,n||t.calendar)}function w(e){return t._categories[Math.round(e)]}function k(e){if(y(e)){if(void 0===t._categoriesMap&&(t._categoriesMap={}),void 0!==t._categoriesMap[e])return t._categoriesMap[e];t._categories.push(\"number\"==typeof e?String(e):e);var r=t._categories.length-1;return t._categoriesMap[e]=r,r}return p}function T(e){if(t._categoriesMap)return t._categoriesMap[e]}function A(t){var e=T(t);return void 0!==e?e:i(t)?+t:void 0}function M(e){return i(e)?n.round(t._b+t._m*e,2):p}function S(e){return(e-t._b)/t._m}t.c2l=\"log\"===t.type?x:c,t.l2c=\"log\"===t.type?m:c,t.l2p=M,t.p2l=S,t.c2p=\"log\"===t.type?function(t,e){return M(x(t,e))}:M,t.p2c=\"log\"===t.type?function(t){return m(S(t))}:S,-1!==[\"linear\",\"-\"].indexOf(t.type)?(t.d2r=t.r2d=t.d2c=t.r2c=t.d2l=t.r2l=o,t.c2d=t.c2r=t.l2d=t.l2r=c,t.d2p=t.r2p=function(e){return t.l2p(o(e))},t.p2d=t.p2r=S,t.cleanPos=c):\"log\"===t.type?(t.d2r=t.d2l=function(t,e){return x(o(t),e)},t.r2d=t.r2c=function(t){return m(o(t))},t.d2c=t.r2l=o,t.c2d=t.l2r=c,t.c2r=x,t.l2d=m,t.d2p=function(e,r){return t.l2p(t.d2r(e,r))},t.p2d=function(t){return m(S(t))},t.r2p=function(e){return t.l2p(o(e))},t.p2r=S,t.cleanPos=c):\"date\"===t.type?(t.d2r=t.r2d=a.identity,t.d2c=t.r2c=t.d2l=t.r2l=b,t.c2d=t.c2r=t.l2d=t.l2r=_,t.d2p=t.r2p=function(e,r,n){return t.l2p(b(e,0,n))},t.p2d=t.p2r=function(t,e,r){return _(S(t),e,r)},t.cleanPos=function(e){return a.cleanDate(e,p,t.calendar)}):\"category\"===t.type?(t.d2c=t.d2l=k,t.r2d=t.c2d=t.l2d=w,t.d2r=t.d2l_noadd=A,t.r2c=function(e){var r=A(e);return void 0!==r?r:t.fraction2r(.5)},t.l2r=t.c2r=c,t.r2l=A,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return w(S(t))},t.r2p=t.d2p,t.p2r=S,t.cleanPos=function(t){return\"string\"==typeof t&&\"\"!==t?t:c(t)}):\"multicategory\"===t.type&&(t.r2d=t.c2d=t.l2d=w,t.d2r=t.d2l_noadd=A,t.r2c=function(e){var r=A(e);return void 0!==r?r:t.fraction2r(.5)},t.r2c_just_indices=T,t.l2r=t.c2r=c,t.r2l=A,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return w(S(t))},t.r2p=t.d2p,t.p2r=S,t.cleanPos=function(t){return Array.isArray(t)||\"string\"==typeof t&&\"\"!==t?t:c(t)},t.setupMultiCategory=function(n){var i,o,s=t._traceIndices,l=e._axisMatchGroups;if(l&&l.length&&0===t._categories.length)for(i=0;i<l.length;i++){var c=l[i];if(c[r])for(var f in c)if(f!==r){var p=e[v.id2name(f)];s=s.concat(p._traceIndices)}}var d=[[0,{}],[0,{}]],g=[];for(i=0;i<s.length;i++){var m=n[s[i]];if(h in m){var x=m[h],b=m._length||a.minRowLength(x);if(u(x[0])&&u(x[1]))for(o=0;o<b;o++){var _=x[0][o],w=x[1][o];y(_)&&y(w)&&(g.push([_,w]),_ in d[0][1]||(d[0][1][_]=d[0][0]++),w in d[1][1]||(d[1][1][w]=d[1][0]++))}}}for(g.sort(function(t,e){var r=d[0][1],n=r[t[0]]-r[e[0]];if(n)return n;var i=d[1][1];return i[t[1]]-i[e[1]]}),i=0;i<g.length;i++)k(g[i])}),t.fraction2r=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return t.l2r(r+e*(n-r))},t.r2fraction=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return(t.r2l(e)-r)/(n-r)},t.cleanRange=function(e,r){r||(r={}),e||(e=\"range\");var n,o,s=a.nestedProperty(t,e).get();if(o=(o=\"date\"===t.type?a.dfltRange(t.calendar):\"y\"===h?g.DFLTRANGEY:r.dfltRange||g.DFLTRANGEX).slice(),s&&2===s.length)for(\"date\"!==t.type||t.autorange||(s[0]=a.cleanDate(s[0],p,t.calendar),s[1]=a.cleanDate(s[1],p,t.calendar)),n=0;n<2;n++)if(\"date\"===t.type){if(!a.isDateTime(s[n],t.calendar)){t[e]=o;break}if(t.r2l(s[0])===t.r2l(s[1])){var l=a.constrain(t.r2l(s[0]),a.MIN_MS+1e3,a.MAX_MS-1e3);s[0]=t.l2r(l-1e3),s[1]=t.l2r(l+1e3);break}}else{if(!i(s[n])){if(!i(s[1-n])){t[e]=o;break}s[n]=s[1-n]*(n?10:.1)}if(s[n]<-f?s[n]=-f:s[n]>f&&(s[n]=f),s[0]===s[1]){var c=Math.max(1,Math.abs(1e-6*s[0]));s[0]-=c,s[1]+=c}}else a.nestedProperty(t,e).set(o)},t.setScale=function(r){var n=e._size;if(t.overlaying){var i=v.getFromId({_fullLayout:e},t.overlaying);t.domain=i.domain}var a=r&&t._r?\"_r\":\"range\",o=t.calendar;t.cleanRange(a);var s=t.r2l(t[a][0],o),l=t.r2l(t[a][1],o);if(\"y\"===h?(t._offset=n.t+(1-t.domain[1])*n.h,t._length=n.h*(t.domain[1]-t.domain[0]),t._m=t._length/(s-l),t._b=-t._m*l):(t._offset=n.l+t.domain[0]*n.w,t._length=n.w*(t.domain[1]-t.domain[0]),t._m=t._length/(l-s),t._b=-t._m*s),!isFinite(t._m)||!isFinite(t._b)||t._length<0)throw e._replotting=!1,new Error(\"Something went wrong with axis scaling\")},t.makeCalcdata=function(e,r){var n,i,o,s,l=t.type,c=\"date\"===l&&e[r+\"calendar\"];if(r in e){if(n=e[r],s=e._length||a.minRowLength(n),a.isTypedArray(n)&&(\"linear\"===l||\"log\"===l)){if(s===n.length)return n;if(n.subarray)return n.subarray(0,s)}if(\"multicategory\"===l)return function(t,e){for(var r=new Array(e),n=0;n<e;n++){var i=(t[0]||[])[n],a=(t[1]||[])[n];r[n]=T([i,a])}return r}(n,s);for(i=new Array(s),o=0;o<s;o++)i[o]=t.d2c(n[o],0,c)}else{var u=r+\"0\"in e?t.d2c(e[r+\"0\"],0,c):0,h=e[\"d\"+r]?Number(e[\"d\"+r]):1;for(n=e[{x:\"y\",y:\"x\"}[r]],s=e._length||n.length,i=new Array(s),o=0;o<s;o++)i[o]=u+o*h}return i},t.isValidRange=function(e){return Array.isArray(e)&&2===e.length&&i(t.r2l(e[0]))&&i(t.r2l(e[1]))},t.isPtWithinRange=function(e,r){var n=t.c2l(e[h],null,r),i=t.r2l(t.range[0]),a=t.r2l(t.range[1]);return i<a?i<=n&&n<=a:a<=n&&n<=i},t.clearCalc=function(){var n=function(){t._categories=[],t._categoriesMap={}},i=e._axisMatchGroups;if(i&&i.length){for(var a=!1,o=0;o<i.length;o++){var s=i[o];if(s[r]){a=!0;var l=null,c=null;for(var u in s){var h=e[v.id2name(u)];if(h._categories){l=h._categories,c=h._categoriesMap;break}}l&&c?(t._categories=l,t._categoriesMap=c):n();break}}a||n()}else n();if(t._initialCategories)for(var f=0;f<t._initialCategories.length;f++)k(t._initialCategories[f])},t.sortByInitialCategories=function(){var n=[];if(t._categories=[],t._categoriesMap={},t._initialCategories)for(var i=0;i<t._initialCategories.length;i++)k(t._initialCategories[i]);n=n.concat(t._traceIndices);var a=t._matchGroup;for(var o in a)if(r!==o){var s=e[v.id2name(o)];s._categories=t._categories,s._categoriesMap=t._categoriesMap,n=n.concat(s._traceIndices)}return n};var E=e._d3locale;\"date\"===t.type&&(t._dateFormat=E?E.timeFormat.utc:n.time.format.utc,t._extraFormat=e._extraFormat),t._separators=e.separators,t._numFormat=E?E.numberFormat:n.format,delete t._minDtick,delete t._forceTick0}},{\"../../constants/numerical\":695,\"../../lib\":719,\"./axis_ids\":770,\"./constants\":773,d3:163,\"fast-isnumeric\":225}],786:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"../array_container_defaults\");function o(t){var e=[\"showexponent\",\"showtickprefix\",\"showticksuffix\"].filter(function(e){return void 0!==t[e]});if(e.every(function(r){return t[r]===t[e[0]]})||1===e.length)return t[e[0]]}function s(t,e){function r(r,a){return n.coerce(t,e,i.tickformatstops,r,a)}r(\"enabled\")&&(r(\"dtickrange\"),r(\"value\"))}e.exports=function(t,e,r,l,c,u){u&&1!==u.pass||function(t,e,r,n,i){var a=o(t);r(\"tickprefix\")&&r(\"showtickprefix\",a);r(\"ticksuffix\",i.tickSuffixDflt)&&r(\"showticksuffix\",a)}(t,0,r,0,c),u&&2!==u.pass||function(t,e,r,l,c){var u=o(t);r(\"tickprefix\")&&r(\"showtickprefix\",u);r(\"ticksuffix\",c.tickSuffixDflt)&&r(\"showticksuffix\",u);if(r(\"showticklabels\")){var h=c.font||{},f=e.color,p=f&&f!==i.color.dflt?f:h.color;if(n.coerceFont(r,\"tickfont\",{family:h.family,size:h.size,color:p}),r(\"tickangle\"),\"category\"!==l){var d=r(\"tickformat\"),g=t.tickformatstops;Array.isArray(g)&&g.length&&a(t,e,{name:\"tickformatstops\",inclusionAttr:\"enabled\",handleItemDefaults:s}),d||\"date\"===l||(r(\"showexponent\",u),r(\"exponentformat\"),r(\"separatethousands\"))}}}(t,e,r,l,c)}},{\"../../lib\":719,\"../array_container_defaults\":763,\"./layout_attributes\":779}],787:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r,a){var o=n.coerce2(t,e,i,\"ticklen\"),s=n.coerce2(t,e,i,\"tickwidth\"),l=n.coerce2(t,e,i,\"tickcolor\",e.color);r(\"ticks\",a.outerTicks||o||s||l?\"outside\":\"\")||(delete e.ticklen,delete e.tickwidth,delete e.tickcolor)}},{\"../../lib\":719,\"./layout_attributes\":779}],788:[function(t,e,r){\"use strict\";var n=t(\"./clean_ticks\");e.exports=function(t,e,r,i){var a;\"array\"!==t.tickmode||\"log\"!==i&&\"date\"!==i?a=r(\"tickmode\",Array.isArray(t.tickvals)?\"array\":t.dtick?\"linear\":\"auto\"):a=e.tickmode=\"auto\";if(\"auto\"===a)r(\"nticks\");else if(\"linear\"===a){var o=e.dtick=n.dtick(t.dtick,i);e.tick0=n.tick0(t.tick0,i,e.calendar,o)}else if(\"multicategory\"!==i){void 0===r(\"tickvals\")?e.tickmode=\"auto\":r(\"ticktext\")}}},{\"./clean_ticks\":772}],789:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../components/drawing\"),o=t(\"./axes\");e.exports=function(t,e,r,s){var l=t._fullLayout;if(0!==e.length){var c,u,h,f;s&&(c=s());var p=n.ease(r.easing);return t._transitionData._interruptCallbacks.push(function(){return window.cancelAnimationFrame(f),f=null,function(){for(var r={},n=0;n<e.length;n++){var a=e[n];a.xr0&&(r[a.plotinfo.xaxis._name+\".range\"]=a.xr0.slice()),a.yr0&&(r[a.plotinfo.yaxis._name+\".range\"]=a.yr0.slice())}return i.call(\"relayout\",t,r).then(function(){for(var t=0;t<e.length;t++)d(e[t].plotinfo)})}()}),u=Date.now(),f=window.requestAnimationFrame(function n(){h=Date.now();for(var a=Math.min(1,(h-u)/r.duration),o=p(a),s=0;s<e.length;s++)g(e[s],o);h-u>r.duration?(function(){for(var r={},n=0;n<e.length;n++){var a=e[n];a.xr1&&(r[a.plotinfo.xaxis._name+\".range\"]=a.xr1.slice()),a.yr1&&(r[a.plotinfo.yaxis._name+\".range\"]=a.yr1.slice())}c&&c(),i.call(\"relayout\",t,r).then(function(){for(var t=0;t<e.length;t++)d(e[t].plotinfo)})}(),f=window.cancelAnimationFrame(n)):f=window.requestAnimationFrame(n)}),Promise.resolve()}function d(t){var e=t.xaxis,r=t.yaxis;l._defs.select(\"#\"+t.clipId+\"> rect\").call(a.setTranslate,0,0).call(a.setScale,1,1),t.plot.call(a.setTranslate,e._offset,r._offset).call(a.setScale,1,1);var n=t.plot.selectAll(\".scatterlayer .trace\");n.selectAll(\".point\").call(a.setPointGroupScale,1,1),n.selectAll(\".textpoint\").call(a.setTextPointsScale,1,1),n.call(a.hideOutsideRangePoints,t)}function g(e,r){var n=e.plotinfo,i=n.xaxis,s=n.yaxis,l=e.xr0,c=e.xr1,u=i._length,h=e.yr0,f=e.yr1,p=s._length,d=!!c,g=!!f,v=[];if(d){var m=l[1]-l[0],y=c[1]-c[0];v[0]=(l[0]*(1-r)+r*c[0]-l[0])/(l[1]-l[0])*u,v[2]=u*(1-r+r*y/m),i.range[0]=l[0]*(1-r)+r*c[0],i.range[1]=l[1]*(1-r)+r*c[1]}else v[0]=0,v[2]=u;if(g){var x=h[1]-h[0],b=f[1]-f[0];v[1]=(h[1]*(1-r)+r*f[1]-h[1])/(h[0]-h[1])*p,v[3]=p*(1-r+r*b/x),s.range[0]=h[0]*(1-r)+r*f[0],s.range[1]=h[1]*(1-r)+r*f[1]}else v[1]=0,v[3]=p;o.drawOne(t,i,{skipTitle:!0}),o.drawOne(t,s,{skipTitle:!0}),o.redrawComponents(t,[i._id,s._id]);var _=d?u/v[2]:1,w=g?p/v[3]:1,k=d?v[0]:0,T=g?v[1]:0,A=d?v[0]/v[2]*u:0,M=g?v[1]/v[3]*p:0,S=i._offset-A,E=s._offset-M;n.clipRect.call(a.setTranslate,k,T).call(a.setScale,1/_,1/w),n.plot.call(a.setTranslate,S,E).call(a.setScale,_,w),a.setPointGroupScale(n.zoomScalePts,1/_,1/w),a.setTextPointsScale(n.zoomScaleTxt,1/_,1/w)}o.redrawComponents(t)}},{\"../../components/drawing\":614,\"../../registry\":847,\"./axes\":767,d3:163}],790:[function(t,e,r){\"use strict\";var n=t(\"../../registry\").traceIs,i=t(\"./axis_autotype\");function a(t){return{v:\"x\",h:\"y\"}[t.orientation||\"v\"]}function o(t,e){var r=a(t),i=n(t,\"box-violin\"),o=n(t._fullInput||{},\"candlestick\");return i&&!o&&e===r&&void 0===t[r]&&void 0===t[r+\"0\"]}e.exports=function(t,e,r,s){\"-\"===r(\"type\",(s.splomStash||{}).type)&&(!function(t,e){if(\"-\"!==t.type)return;var r=t._id,s=r.charAt(0);-1!==r.indexOf(\"scene\")&&(r=s);var l=function(t,e,r){for(var n=0;n<t.length;n++){var i=t[n];if(\"splom\"===i.type&&i._length>0&&(i[\"_\"+r+\"axes\"]||{})[e])return i;if((i[r+\"axis\"]||r)===e){if(o(i,r))return i;if((i[r]||[]).length||i[r+\"0\"])return i}}}(e,r,s);if(!l)return;if(\"histogram\"===l.type&&s==={v:\"y\",h:\"x\"}[l.orientation||\"v\"])return void(t.type=\"linear\");var c,u=s+\"calendar\",h=l[u],f={noMultiCategory:!n(l,\"cartesian\")||n(l,\"noMultiCategory\")};if(o(l,s)){var p=a(l),d=[];for(c=0;c<e.length;c++){var g=e[c];n(g,\"box-violin\")&&(g[s+\"axis\"]||s)===r&&(void 0!==g[p]?d.push(g[p][0]):void 0!==g.name?d.push(g.name):d.push(\"text\"),g[u]!==h&&(h=void 0))}t.type=i(d,h,f)}else if(\"splom\"===l.type){var v=l.dimensions,m=v[l._axesDim[r]];m.visible&&(t.type=i(m.values,h,f))}else t.type=i(l[s]||[l[s+\"0\"]],h,f)}(e,s.data),\"-\"===e.type?e.type=\"linear\":t.type=e.type)}},{\"../../registry\":847,\"./axis_autotype\":768}],791:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\");function a(t,e,r){var n,a,o,s=!1;if(\"data\"===e.type)n=t._fullData[null!==e.traces?e.traces[0]:0];else{if(\"layout\"!==e.type)return!1;n=t._fullLayout}return a=i.nestedProperty(n,e.prop).get(),(o=r[e.type]=r[e.type]||{}).hasOwnProperty(e.prop)&&o[e.prop]!==a&&(s=!0),o[e.prop]=a,{changed:s,value:a}}function o(t,e){var r=[],n=e[0],a={};if(\"string\"==typeof n)a[n]=e[1];else{if(!i.isPlainObject(n))return r;a=n}return l(a,function(t,e,n){r.push({type:\"layout\",prop:t,value:n})},\"\",0),r}function s(t,e){var r,n,a,o,s=[];if(n=e[0],a=e[1],r=e[2],o={},\"string\"==typeof n)o[n]=a;else{if(!i.isPlainObject(n))return s;o=n,void 0===r&&(r=a)}return void 0===r&&(r=null),l(o,function(e,n,i){var a,o;if(Array.isArray(i)){o=i.slice();var l=Math.min(o.length,t.data.length);r&&(l=Math.min(l,r.length)),a=[];for(var c=0;c<l;c++)a[c]=r?r[c]:c}else o=i,a=r?r.slice():null;if(null===a)Array.isArray(o)&&(o=o[0]);else if(Array.isArray(a)){if(!Array.isArray(o)){var u=o;o=[];for(var h=0;h<a.length;h++)o[h]=u}o.length=Math.min(a.length,o.length)}s.push({type:\"data\",prop:e,traces:a,value:o})},\"\",0),s}function l(t,e,r,n){Object.keys(t).forEach(function(a){var o=t[a];if(\"_\"!==a[0]){var s=r+(n>0?\".\":\"\")+a;i.isPlainObject(o)?l(o,e,s,n+1):e(s,a,o)}})}r.manageCommandObserver=function(t,e,n,o){var s={},l=!0;e&&e._commandObserver&&(s=e._commandObserver),s.cache||(s.cache={}),s.lookupTable={};var c=r.hasSimpleAPICommandBindings(t,n,s.lookupTable);if(e&&e._commandObserver){if(c)return s;if(e._commandObserver.remove)return e._commandObserver.remove(),e._commandObserver=null,s}if(c){a(t,c,s.cache),s.check=function(){if(l){var e=a(t,c,s.cache);return e.changed&&o&&void 0!==s.lookupTable[e.value]&&(s.disable(),Promise.resolve(o({value:e.value,type:c.type,prop:c.prop,traces:c.traces,index:s.lookupTable[e.value]})).then(s.enable,s.enable)),e.changed}};for(var u=[\"plotly_relayout\",\"plotly_redraw\",\"plotly_restyle\",\"plotly_update\",\"plotly_animatingframe\",\"plotly_afterplot\"],h=0;h<u.length;h++)t._internalOn(u[h],s.check);s.remove=function(){for(var e=0;e<u.length;e++)t._removeInternalListener(u[e],s.check)}}else i.log(\"Unable to automatically bind plot updates to API command\"),s.lookupTable={},s.remove=function(){};return s.disable=function(){l=!1},s.enable=function(){l=!0},e&&(e._commandObserver=s),s},r.hasSimpleAPICommandBindings=function(t,e,n){var i,a,o=e.length;for(i=0;i<o;i++){var s,l=e[i],c=l.method,u=l.args;if(Array.isArray(u)||(u=[]),!c)return!1;var h=r.computeAPICommandBindings(t,c,u);if(1!==h.length)return!1;if(a){if((s=h[0]).type!==a.type)return!1;if(s.prop!==a.prop)return!1;if(Array.isArray(a.traces)){if(!Array.isArray(s.traces))return!1;s.traces.sort();for(var f=0;f<a.traces.length;f++)if(a.traces[f]!==s.traces[f])return!1}else if(s.prop!==a.prop)return!1}else a=h[0],Array.isArray(a.traces)&&a.traces.sort();var p=(s=h[0]).value;if(Array.isArray(p)){if(1!==p.length)return!1;p=p[0]}n&&(n[p]=i)}return a},r.executeAPICommand=function(t,e,r){if(\"skip\"===e)return Promise.resolve();var a=n.apiMethodRegistry[e],o=[t];Array.isArray(r)||(r=[]);for(var s=0;s<r.length;s++)o.push(r[s]);return a.apply(null,o).catch(function(t){return i.warn(\"API call to Plotly.\"+e+\" rejected.\",t),Promise.reject(t)})},r.computeAPICommandBindings=function(t,e,r){var n;switch(Array.isArray(r)||(r=[]),e){case\"restyle\":n=s(t,r);break;case\"relayout\":n=o(t,r);break;case\"update\":n=s(t,[r[0],r[2]]).concat(o(t,[r[1]]));break;case\"animate\":n=function(t,e){return Array.isArray(e[0])&&1===e[0].length&&-1!==[\"string\",\"number\"].indexOf(typeof e[0][0])?[{type:\"layout\",prop:\"_currentFrame\",value:e[0][0].toString()}]:[]}(0,r);break;default:n=[]}return n}},{\"../lib\":719,\"../registry\":847}],792:[function(t,e,r){\"use strict\";var n=t(\"../lib/extend\").extendFlat;r.attributes=function(t,e){e=e||{};var r={valType:\"info_array\",editType:(t=t||{}).editType,items:[{valType:\"number\",min:0,max:1,editType:t.editType},{valType:\"number\",min:0,max:1,editType:t.editType}],dflt:[0,1]},i=(t.name&&t.name,t.trace,e.description&&e.description,{x:n({},r,{}),y:n({},r,{}),editType:t.editType});return t.noGridCell||(i.row={valType:\"integer\",min:0,dflt:0,editType:t.editType},i.column={valType:\"integer\",min:0,dflt:0,editType:t.editType}),i},r.defaults=function(t,e,r,n){var i=n&&n.x||[0,1],a=n&&n.y||[0,1],o=e.grid;if(o){var s=r(\"domain.column\");void 0!==s&&(s<o.columns?i=o._domains.x[s]:delete t.domain.column);var l=r(\"domain.row\");void 0!==l&&(l<o.rows?a=o._domains.y[l]:delete t.domain.row)}r(\"domain.x\",i),r(\"domain.y\",a)}},{\"../lib/extend\":710}],793:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType,r=t.colorEditType;void 0===r&&(r=e);var n={family:{valType:\"string\",noBlank:!0,strict:!0,editType:e},size:{valType:\"number\",min:1,editType:e},color:{valType:\"color\",editType:r},editType:e};return t.arrayOk&&(n.family.arrayOk=!0,n.size.arrayOk=!0,n.color.arrayOk=!0),n}},{}],794:[function(t,e,r){\"use strict\";e.exports={_isLinkedToArray:\"frames_entry\",group:{valType:\"string\"},name:{valType:\"string\"},traces:{valType:\"any\"},baseframe:{valType:\"string\"},data:{valType:\"any\"},layout:{valType:\"any\"}}},{}],795:[function(t,e,r){\"use strict\";r.projNames={equirectangular:\"equirectangular\",mercator:\"mercator\",orthographic:\"orthographic\",\"natural earth\":\"naturalEarth\",kavrayskiy7:\"kavrayskiy7\",miller:\"miller\",robinson:\"robinson\",eckert4:\"eckert4\",\"azimuthal equal area\":\"azimuthalEqualArea\",\"azimuthal equidistant\":\"azimuthalEquidistant\",\"conic equal area\":\"conicEqualArea\",\"conic conformal\":\"conicConformal\",\"conic equidistant\":\"conicEquidistant\",gnomonic:\"gnomonic\",stereographic:\"stereographic\",mollweide:\"mollweide\",hammer:\"hammer\",\"transverse mercator\":\"transverseMercator\",\"albers usa\":\"albersUsa\",\"winkel tripel\":\"winkel3\",aitoff:\"aitoff\",sinusoidal:\"sinusoidal\"},r.axesNames=[\"lonaxis\",\"lataxis\"],r.lonaxisSpan={orthographic:180,\"azimuthal equal area\":360,\"azimuthal equidistant\":360,\"conic conformal\":180,gnomonic:160,stereographic:180,\"transverse mercator\":180,\"*\":360},r.lataxisSpan={\"conic conformal\":150,stereographic:179.5,\"*\":180},r.scopeDefaults={world:{lonaxisRange:[-180,180],lataxisRange:[-90,90],projType:\"equirectangular\",projRotate:[0,0,0]},usa:{lonaxisRange:[-180,-50],lataxisRange:[15,80],projType:\"albers usa\"},europe:{lonaxisRange:[-30,60],lataxisRange:[30,85],projType:\"conic conformal\",projRotate:[15,0,0],projParallels:[0,60]},asia:{lonaxisRange:[22,160],lataxisRange:[-15,55],projType:\"mercator\",projRotate:[0,0,0]},africa:{lonaxisRange:[-30,60],lataxisRange:[-40,40],projType:\"mercator\",projRotate:[0,0,0]},\"north america\":{lonaxisRange:[-180,-45],lataxisRange:[5,85],projType:\"conic conformal\",projRotate:[-100,0,0],projParallels:[29.5,45.5]},\"south america\":{lonaxisRange:[-100,-30],lataxisRange:[-60,15],projType:\"mercator\",projRotate:[0,0,0]}},r.clipPad=.001,r.precision=.1,r.landColor=\"#F0DC82\",r.waterColor=\"#3399FF\",r.locationmodeToLayer={\"ISO-3\":\"countries\",\"USA-states\":\"subunits\",\"country names\":\"countries\"},r.sphereSVG={type:\"Sphere\"},r.fillLayers={ocean:1,land:1,lakes:1},r.lineLayers={subunits:1,countries:1,coastlines:1,rivers:1,frame:1},r.layers=[\"bg\",\"ocean\",\"land\",\"lakes\",\"subunits\",\"countries\",\"coastlines\",\"rivers\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"frontplot\"],r.layersForChoropleth=[\"bg\",\"ocean\",\"land\",\"subunits\",\"countries\",\"coastlines\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"rivers\",\"lakes\",\"frontplot\"],r.layerNameToAdjective={ocean:\"ocean\",land:\"land\",lakes:\"lake\",subunits:\"subunit\",countries:\"country\",coastlines:\"coastline\",rivers:\"river\",frame:\"frame\"}},{}],796:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"../../components/fx\"),c=t(\"../plots\"),u=t(\"../cartesian/axes\"),h=t(\"../../components/dragelement\"),f=t(\"../cartesian/select\").prepSelect,p=t(\"../cartesian/select\").selectOnClick,d=t(\"./zoom\"),g=t(\"./constants\"),v=t(\"../../lib/topojson_utils\"),m=t(\"topojson-client\").feature;function y(t){this.id=t.id,this.graphDiv=t.graphDiv,this.container=t.container,this.topojsonURL=t.topojsonURL,this.isStatic=t.staticPlot,this.topojsonName=null,this.topojson=null,this.projection=null,this.scope=null,this.viewInitial=null,this.fitScale=null,this.bounds=null,this.midPt=null,this.hasChoropleth=!1,this.traceHash={},this.layers={},this.basePaths={},this.dataPaths={},this.dataPoints={},this.clipDef=null,this.clipRect=null,this.bgRect=null,this.makeFramework()}t(\"./projections\")(n);var x=y.prototype;e.exports=function(t){return new y(t)},x.plot=function(t,e,r){var n=this,i=e[this.id],a=!1;for(var o in g.layerNameToAdjective)if(\"frame\"!==o&&i[\"show\"+o]){a=!0;break}for(var s=0;s<t.length;s++)if(t[0][0].trace.locationmode){a=!0;break}if(!a)return n.update(t,e);var l=v.getTopojsonName(i);null===n.topojson||l!==n.topojsonName?(n.topojsonName=l,void 0===PlotlyGeoAssets.topojson[n.topojsonName]?r.push(n.fetchTopojson().then(function(r){PlotlyGeoAssets.topojson[n.topojsonName]=r,n.topojson=r,n.update(t,e)})):(n.topojson=PlotlyGeoAssets.topojson[n.topojsonName],n.update(t,e))):n.update(t,e)},x.fetchTopojson=function(){var t=v.getTopojsonPath(this.topojsonURL,this.topojsonName);return new Promise(function(e,r){n.json(t,function(n,i){if(n)return 404===n.status?r(new Error([\"plotly.js could not find topojson file at\",t,\".\",\"Make sure the *topojsonURL* plot config option\",\"is set properly.\"].join(\" \"))):r(new Error([\"unexpected error while fetching topojson file at\",t].join(\" \")));e(i)})})},x.update=function(t,e){var r=e[this.id];if(!this.updateProjection(e,r)){this.hasChoropleth=!1;for(var n=0;n<t.length;n++)if(\"choropleth\"===t[n][0].trace.type){this.hasChoropleth=!0;break}this.viewInitial&&this.scope===r.scope||this.saveViewInitial(r),this.scope=r.scope,this.updateBaseLayers(e,r),this.updateDims(e,r),this.updateFx(e,r),c.generalUpdatePerTraceModule(this.graphDiv,this,t,r);var i=this.layers.frontplot.select(\".scatterlayer\");this.dataPoints.point=i.selectAll(\".point\"),this.dataPoints.text=i.selectAll(\"text\"),this.dataPaths.line=i.selectAll(\".js-line\");var a=this.layers.backplot.select(\".choroplethlayer\");this.dataPaths.choropleth=a.selectAll(\"path\"),this.render()}},x.updateProjection=function(t,e){var r=t._size,o=e.domain,s=e.projection,l=s.rotation||{},c=e.center||{},u=this.projection=function(t){for(var e=t.projection.type,r=n.geo[g.projNames[e]](),i=t._isClipped?g.lonaxisSpan[e]/2:null,a=[\"center\",\"rotate\",\"parallels\",\"clipExtent\"],o=function(t){return t?r:[]},s=0;s<a.length;s++){var l=a[s];\"function\"!=typeof r[l]&&(r[l]=o)}r.isLonLatOverEdges=function(t){if(null===r(t))return!0;if(i){var e=r.rotate();return n.geo.distance(t,[-e[0],-e[1]])>i*Math.PI/180}return!1},r.getPath=function(){return n.geo.path().projection(r)},r.getBounds=function(t){return r.getPath().bounds(t)},r.fitExtent=function(t,e){var n=t[1][0]-t[0][0],i=t[1][1]-t[0][1],a=r.clipExtent&&r.clipExtent();r.scale(150).translate([0,0]),a&&r.clipExtent(null);var o=r.getBounds(e),s=Math.min(n/(o[1][0]-o[0][0]),i/(o[1][1]-o[0][1])),l=+t[0][0]+(n-s*(o[1][0]+o[0][0]))/2,c=+t[0][1]+(i-s*(o[1][1]+o[0][1]))/2;return a&&r.clipExtent(a),r.scale(150*s).translate([l,c])},r.precision(g.precision),i&&r.clipAngle(i-g.clipPad);return r}(e);u.center([c.lon-l.lon,c.lat-l.lat]).rotate([-l.lon,-l.lat,l.roll]).parallels(s.parallels);var h=[[r.l+r.w*o.x[0],r.t+r.h*(1-o.y[1])],[r.l+r.w*o.x[1],r.t+r.h*(1-o.y[0])]],f=e.lonaxis,p=e.lataxis,d=function(t,e){var r=g.clipPad,n=t[0]+r,i=t[1]-r,a=e[0]+r,o=e[1]-r;n>0&&i<0&&(i+=360);var s=(i-n)/4;return{type:\"Polygon\",coordinates:[[[n,a],[n,o],[n+s,o],[n+2*s,o],[n+3*s,o],[i,o],[i,a],[i-s,a],[i-2*s,a],[i-3*s,a],[n,a]]]}}(f.range,p.range);u.fitExtent(h,d);var v=this.bounds=u.getBounds(d),m=this.fitScale=u.scale(),y=u.translate();if(!isFinite(v[0][0])||!isFinite(v[0][1])||!isFinite(v[1][0])||!isFinite(v[1][1])||isNaN(y[0])||isNaN(y[0])){for(var x=this.graphDiv,b=[\"projection.rotation\",\"center\",\"lonaxis.range\",\"lataxis.range\"],_=\"Invalid geo settings, relayout'ing to default view.\",w={},k=0;k<b.length;k++)w[this.id+\".\"+b[k]]=null;return this.viewInitial=null,a.warn(_),x._promises.push(i.call(\"relayout\",x,w)),_}var T=this.midPt=[(v[0][0]+v[1][0])/2,(v[0][1]+v[1][1])/2];if(u.scale(s.scale*m).translate([y[0]+(T[0]-y[0]),y[1]+(T[1]-y[1])]).clipExtent(v),e._isAlbersUsa){var A=u([c.lon,c.lat]),M=u.translate();u.translate([M[0]-(A[0]-M[0]),M[1]-(A[1]-M[1])])}},x.updateBaseLayers=function(t,e){var r=this,i=r.topojson,a=r.layers,l=r.basePaths;function c(t){return\"lonaxis\"===t||\"lataxis\"===t}function h(t){return Boolean(g.lineLayers[t])}function f(t){return Boolean(g.fillLayers[t])}var p=(this.hasChoropleth?g.layersForChoropleth:g.layers).filter(function(t){return h(t)||f(t)?e[\"show\"+t]:!c(t)||e[t].showgrid}),d=r.framework.selectAll(\".layer\").data(p,String);d.exit().each(function(t){delete a[t],delete l[t],n.select(this).remove()}),d.enter().append(\"g\").attr(\"class\",function(t){return\"layer \"+t}).each(function(t){var e=a[t]=n.select(this);\"bg\"===t?r.bgRect=e.append(\"rect\").style(\"pointer-events\",\"all\"):c(t)?l[t]=e.append(\"path\").style(\"fill\",\"none\"):\"backplot\"===t?e.append(\"g\").classed(\"choroplethlayer\",!0):\"frontplot\"===t?e.append(\"g\").classed(\"scatterlayer\",!0):h(t)?l[t]=e.append(\"path\").style(\"fill\",\"none\").style(\"stroke-miterlimit\",2):f(t)&&(l[t]=e.append(\"path\").style(\"stroke\",\"none\"))}),d.order(),d.each(function(r){var n=l[r],a=g.layerNameToAdjective[r];\"frame\"===r?n.datum(g.sphereSVG):h(r)||f(r)?n.datum(m(i,i.objects[r])):c(r)&&n.datum(function(t,e,r){var n,i,a,o=e[t],s=g.scopeDefaults[e.scope];\"lonaxis\"===t?(n=s.lonaxisRange,i=s.lataxisRange,a=function(t,e){return[t,e]}):\"lataxis\"===t&&(n=s.lataxisRange,i=s.lonaxisRange,a=function(t,e){return[e,t]});var l={type:\"linear\",range:[n[0],n[1]-1e-6],tick0:o.tick0,dtick:o.dtick};u.setConvert(l,r);var c=u.calcTicks(l);e.isScoped||\"lonaxis\"!==t||c.pop();for(var h=c.length,f=new Array(h),p=0;p<h;p++)for(var d=c[p].x,v=f[p]=[],m=i[0];m<i[1]+2.5;m+=2.5)v.push(a(d,m));return{type:\"MultiLineString\",coordinates:f}}(r,e,t)).call(o.stroke,e[r].gridcolor).call(s.dashLine,\"\",e[r].gridwidth),h(r)?n.call(o.stroke,e[a+\"color\"]).call(s.dashLine,\"\",e[a+\"width\"]):f(r)&&n.call(o.fill,e[a+\"color\"])})},x.updateDims=function(t,e){var r=this.bounds,n=(e.framewidth||0)/2,i=r[0][0]-n,a=r[0][1]-n,l=r[1][0]-i+n,c=r[1][1]-a+n;s.setRect(this.clipRect,i,a,l,c),this.bgRect.call(s.setRect,i,a,l,c).call(o.fill,e.bgcolor),this.xaxis._offset=i,this.xaxis._length=l,this.yaxis._offset=a,this.yaxis._length=c},x.updateFx=function(t,e){var r=this,a=r.graphDiv,o=r.bgRect,s=t.dragmode,c=t.clickmode;if(!r.isStatic){var u;\"select\"===s?u=function(t,e){(t.range={})[r.id]=[v([e.xmin,e.ymin]),v([e.xmax,e.ymax])]}:\"lasso\"===s&&(u=function(t,e,n){(t.lassoPoints={})[r.id]=n.filtered.map(v)});var g={element:r.bgRect.node(),gd:a,plotinfo:{id:r.id,xaxis:r.xaxis,yaxis:r.yaxis,fillRangeItems:u},xaxes:[r.xaxis],yaxes:[r.yaxis],subplot:r.id,clickFn:function(e){2===e&&t._zoomlayer.selectAll(\".select-outline\").remove()}};\"pan\"===s?(o.node().onmousedown=null,o.call(d(r,e)),o.on(\"dblclick.zoom\",function(){var t=r.viewInitial,e={};for(var n in t)e[r.id+\".\"+n]=t[n];i.call(\"_guiRelayout\",a,e),a.emit(\"plotly_doubleclick\",null)}),a._context._scrollZoom.geo||o.on(\"wheel.zoom\",null)):\"select\"!==s&&\"lasso\"!==s||(o.on(\".zoom\",null),g.prepFn=function(t,e,r){f(t,e,r,g,s)},h.init(g)),o.on(\"mousemove\",function(){var t=r.projection.invert(n.mouse(this));if(!t||isNaN(t[0])||isNaN(t[1]))return h.unhover(a,n.event);r.xaxis.p2c=function(){return t[0]},r.yaxis.p2c=function(){return t[1]},l.hover(a,n.event,r.id)}),o.on(\"mouseout\",function(){a._dragging||h.unhover(a,n.event)}),o.on(\"click\",function(){\"select\"!==s&&\"lasso\"!==s&&(c.indexOf(\"select\")>-1&&p(n.event,a,[r.xaxis],[r.yaxis],r.id,g),c.indexOf(\"event\")>-1&&l.click(a,n.event))})}function v(t){return r.projection.invert([t[0]+r.xaxis._offset,t[1]+r.yaxis._offset])}},x.makeFramework=function(){var t=this,e=t.graphDiv,r=e._fullLayout,i=\"clip\"+r._uid+t.id;t.clipDef=r._clips.append(\"clipPath\").attr(\"id\",i),t.clipRect=t.clipDef.append(\"rect\"),t.framework=n.select(t.container).append(\"g\").attr(\"class\",\"geo \"+t.id).call(s.setClipUrl,i,e),t.project=function(e){var r=t.projection(e);return r?[r[0]-t.xaxis._offset,r[1]-t.yaxis._offset]:[null,null]},t.xaxis={_id:\"x\",c2p:function(e){return t.project(e)[0]}},t.yaxis={_id:\"y\",c2p:function(e){return t.project(e)[1]}},t.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},u.setConvert(t.mockAxis,r)},x.saveViewInitial=function(t){var e=t.center||{},r=t.projection,n=r.rotation||{};t._isScoped?this.viewInitial={\"center.lon\":e.lon,\"center.lat\":e.lat,\"projection.scale\":r.scale}:t._isClipped?this.viewInitial={\"projection.scale\":r.scale,\"projection.rotation.lon\":n.lon,\"projection.rotation.lat\":n.lat}:this.viewInitial={\"center.lon\":e.lon,\"center.lat\":e.lat,\"projection.scale\":r.scale,\"projection.rotation.lon\":n.lon}},x.render=function(){var t,e=this.projection,r=e.getPath();function n(t){var r=e(t.lonlat);return r?\"translate(\"+r[0]+\",\"+r[1]+\")\":null}function i(t){return e.isLonLatOverEdges(t.lonlat)?\"none\":null}for(t in this.basePaths)this.basePaths[t].attr(\"d\",r);for(t in this.dataPaths)this.dataPaths[t].attr(\"d\",function(t){return r(t.geojson)});for(t in this.dataPoints)this.dataPoints[t].attr(\"display\",i).attr(\"transform\",n)}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../lib\":719,\"../../lib/topojson_utils\":746,\"../../registry\":847,\"../cartesian/axes\":767,\"../cartesian/select\":784,\"../plots\":828,\"./constants\":795,\"./projections\":800,\"./zoom\":801,d3:163,\"topojson-client\":540}],797:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./geo\"),o=\"geo\",s=i(o),l={};l[o]={valType:\"subplotid\",dflt:o,editType:\"calc\"},e.exports={attr:o,name:o,idRoot:o,idRegex:s,attrRegex:s,attributes:l,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[o],s=0;s<i.length;s++){var l=i[s],c=n(r,o,l),u=e[l]._subplot;u||(u=a({id:l,graphDiv:t,container:e._geolayer.node(),topojsonURL:t._context.topojsonURL,staticPlot:t._context.staticPlot}),e[l]._subplot=u),u.plot(c,e,t._promises)}},updateFx:function(t){for(var e=t._fullLayout,r=e._subplots[o],n=0;n<r.length;n++){var i=e[r[n]];i._subplot.updateFx(e,i)}},clean:function(t,e,r,n){for(var i=n._subplots[o]||[],a=0;a<i.length;a++){var s=i[a],l=n[s]._subplot;!e[s]&&l&&(l.framework.remove(),l.clipDef.remove())}}}},{\"../../lib\":719,\"../../plots/get_data\":802,\"./geo\":796,\"./layout_attributes\":798,\"./layout_defaults\":799}],798:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"./constants\"),o=t(\"../../plot_api/edit_types\").overrideAll,s={range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},showgrid:{valType:\"boolean\",dflt:!1},tick0:{valType:\"number\",dflt:0},dtick:{valType:\"number\"},gridcolor:{valType:\"color\",dflt:n.lightLine},gridwidth:{valType:\"number\",min:0,dflt:1}};(e.exports=o({domain:i({name:\"geo\"},{}),resolution:{valType:\"enumerated\",values:[110,50],dflt:110,coerceNumber:!0},scope:{valType:\"enumerated\",values:Object.keys(a.scopeDefaults),dflt:\"world\"},projection:{type:{valType:\"enumerated\",values:Object.keys(a.projNames)},rotation:{lon:{valType:\"number\"},lat:{valType:\"number\"},roll:{valType:\"number\"}},parallels:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},scale:{valType:\"number\",min:0,dflt:1}},center:{lon:{valType:\"number\"},lat:{valType:\"number\"}},showcoastlines:{valType:\"boolean\"},coastlinecolor:{valType:\"color\",dflt:n.defaultLine},coastlinewidth:{valType:\"number\",min:0,dflt:1},showland:{valType:\"boolean\",dflt:!1},landcolor:{valType:\"color\",dflt:a.landColor},showocean:{valType:\"boolean\",dflt:!1},oceancolor:{valType:\"color\",dflt:a.waterColor},showlakes:{valType:\"boolean\",dflt:!1},lakecolor:{valType:\"color\",dflt:a.waterColor},showrivers:{valType:\"boolean\",dflt:!1},rivercolor:{valType:\"color\",dflt:a.waterColor},riverwidth:{valType:\"number\",min:0,dflt:1},showcountries:{valType:\"boolean\"},countrycolor:{valType:\"color\",dflt:n.defaultLine},countrywidth:{valType:\"number\",min:0,dflt:1},showsubunits:{valType:\"boolean\"},subunitcolor:{valType:\"color\",dflt:n.defaultLine},subunitwidth:{valType:\"number\",min:0,dflt:1},showframe:{valType:\"boolean\"},framecolor:{valType:\"color\",dflt:n.defaultLine},framewidth:{valType:\"number\",min:0,dflt:1},bgcolor:{valType:\"color\",dflt:n.background},lonaxis:s,lataxis:s},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":592,\"../../plot_api/edit_types\":750,\"../domain\":792,\"./constants\":795}],799:[function(t,e,r){\"use strict\";var n=t(\"../subplot_defaults\"),i=t(\"./constants\"),a=t(\"./layout_attributes\"),o=i.axesNames;function s(t,e,r){var n=r(\"resolution\"),a=r(\"scope\"),s=i.scopeDefaults[a],l=r(\"projection.type\",s.projType),c=e._isAlbersUsa=\"albers usa\"===l;c&&(a=e.scope=\"usa\");var u=e._isScoped=\"world\"!==a,h=e._isConic=-1!==l.indexOf(\"conic\");e._isClipped=!!i.lonaxisSpan[l];for(var f=0;f<o.length;f++){var p,d=o[f],g=[30,10][f];if(u)p=s[d+\"Range\"];else{var v=i[d+\"Span\"],m=(v[l]||v[\"*\"])/2,y=r(\"projection.rotation.\"+d.substr(0,3),s.projRotate[f]);p=[y-m,y+m]}r(d+\".range\",p),r(d+\".tick0\"),r(d+\".dtick\",g),r(d+\".showgrid\")&&(r(d+\".gridcolor\"),r(d+\".gridwidth\"))}var x=e.lonaxis.range,b=e.lataxis.range,_=x[0],w=x[1];_>0&&w<0&&(w+=360);var k,T,A,M=(_+w)/2;if(!c){var S=u?s.projRotate:[M,0,0];k=r(\"projection.rotation.lon\",S[0]),r(\"projection.rotation.lat\",S[1]),r(\"projection.rotation.roll\",S[2]),r(\"showcoastlines\",!u)&&(r(\"coastlinecolor\"),r(\"coastlinewidth\")),r(\"showocean\")&&r(\"oceancolor\")}(c?(T=-96.6,A=38.7):(T=u?M:k,A=(b[0]+b[1])/2),r(\"center.lon\",T),r(\"center.lat\",A),h)&&r(\"projection.parallels\",s.projParallels||[0,60]);r(\"projection.scale\"),r(\"showland\")&&r(\"landcolor\"),r(\"showlakes\")&&r(\"lakecolor\"),r(\"showrivers\")&&(r(\"rivercolor\"),r(\"riverwidth\")),r(\"showcountries\",u&&\"usa\"!==a)&&(r(\"countrycolor\"),r(\"countrywidth\")),(\"usa\"===a||\"north america\"===a&&50===n)&&(r(\"showsubunits\",!0),r(\"subunitcolor\"),r(\"subunitwidth\")),u||r(\"showframe\",!0)&&(r(\"framecolor\"),r(\"framewidth\")),r(\"bgcolor\")}e.exports=function(t,e,r){n(t,e,r,{type:\"geo\",attributes:a,handleDefaults:s,partition:\"y\"})}},{\"../subplot_defaults\":842,\"./constants\":795,\"./layout_attributes\":798}],800:[function(t,e,r){\"use strict\";e.exports=function(t){function e(t,e){return{type:\"Feature\",id:t.id,properties:t.properties,geometry:r(t.geometry,e)}}function r(e,n){if(!e)return null;if(\"GeometryCollection\"===e.type)return{type:\"GeometryCollection\",geometries:object.geometries.map(function(t){return r(t,n)})};if(!c.hasOwnProperty(e.type))return null;var i=c[e.type];return t.geo.stream(e,n(i)),i.result()}t.geo.project=function(t,e){var i=e.stream;if(!i)throw new Error(\"not yet supported\");return(t&&n.hasOwnProperty(t.type)?n[t.type]:r)(t,i)};var n={Feature:e,FeatureCollection:function(t,r){return{type:\"FeatureCollection\",features:t.features.map(function(t){return e(t,r)})}}},i=[],a=[],o={point:function(t,e){i.push([t,e])},result:function(){var t=i.length?i.length<2?{type:\"Point\",coordinates:i[0]}:{type:\"MultiPoint\",coordinates:i}:null;return i=[],t}},s={lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){i.length&&(a.push(i),i=[])},result:function(){var t=a.length?a.length<2?{type:\"LineString\",coordinates:a[0]}:{type:\"MultiLineString\",coordinates:a}:null;return a=[],t}},l={polygonStart:u,lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){var t=i.length;if(t){do{i.push(i[0].slice())}while(++t<4);a.push(i),i=[]}},polygonEnd:u,result:function(){if(!a.length)return null;var t=[],e=[];return a.forEach(function(r){!function(t){if((e=t.length)<4)return!1;for(var e,r=0,n=t[e-1][1]*t[0][0]-t[e-1][0]*t[0][1];++r<e;)n+=t[r-1][1]*t[r][0]-t[r-1][0]*t[r][1];return n<=0}(r)?e.push(r):t.push([r])}),e.forEach(function(e){var r=e[0];t.some(function(t){if(function(t,e){for(var r=e[0],n=e[1],i=!1,a=0,o=t.length,s=o-1;a<o;s=a++){var l=t[a],c=l[0],u=l[1],h=t[s],f=h[0],p=h[1];u>n^p>n&&r<(f-c)*(n-u)/(p-u)+c&&(i=!i)}return i}(t[0],r))return t.push(e),!0})||t.push([e])}),a=[],t.length?t.length>1?{type:\"MultiPolygon\",coordinates:t}:{type:\"Polygon\",coordinates:t[0]}:null}},c={Point:o,MultiPoint:o,LineString:s,MultiLineString:s,Polygon:l,MultiPolygon:l,Sphere:l};function u(){}var h=1e-6,f=h*h,p=Math.PI,d=p/2,g=(Math.sqrt(p),p/180),v=180/p;function m(t){return t>1?d:t<-1?-d:Math.asin(t)}function y(t){return t>1?0:t<-1?p:Math.acos(t)}var x=t.geo.projection,b=t.geo.projectionMutator;function _(t,e){var r=(2+d)*Math.sin(e);e/=2;for(var n=0,i=1/0;n<10&&Math.abs(i)>h;n++){var a=Math.cos(e);e-=i=(e+Math.sin(e)*(a+2)-r)/(2*a*(1+a))}return[2/Math.sqrt(p*(4+p))*t*(1+Math.cos(e)),2*Math.sqrt(p/(4+p))*Math.sin(e)]}t.geo.interrupt=function(e){var r,n=[[[[-p,0],[0,d],[p,0]]],[[[-p,0],[0,-d],[p,0]]]];function i(t,r){for(var i=r<0?-1:1,a=n[+(r<0)],o=0,s=a.length-1;o<s&&t>a[o][2][0];++o);var l=e(t-a[o][1][0],r);return l[0]+=e(a[o][1][0],i*r>i*a[o][0][1]?a[o][0][1]:r)[0],l}e.invert&&(i.invert=function(t,a){for(var o=r[+(a<0)],s=n[+(a<0)],c=0,u=o.length;c<u;++c){var h=o[c];if(h[0][0]<=t&&t<h[1][0]&&h[0][1]<=a&&a<h[1][1]){var f=e.invert(t-e(s[c][1][0],0)[0],a);return f[0]+=s[c][1][0],l(i(f[0],f[1]),[t,a])?f:null}}});var a=t.geo.projection(i),o=a.stream;function s(t,e){for(var r,n,i,a=-1,o=t.length,s=t[0],l=[];++a<o;){n=((r=t[a])[0]-s[0])/e,i=(r[1]-s[1])/e;for(var c=0;c<e;++c)l.push([s[0]+c*n,s[1]+c*i]);s=r}return l.push(r),l}function l(t,e){return Math.abs(t[0]-e[0])<h&&Math.abs(t[1]-e[1])<h}return a.stream=function(e){var r=a.rotate(),i=o(e),l=(a.rotate([0,0]),o(e));return a.rotate(r),i.sphere=function(){t.geo.stream(function(){for(var e=1e-6,r=[],i=0,a=n[0].length;i<a;++i){var o=n[0][i],l=180*o[0][0]/p,c=180*o[0][1]/p,u=180*o[1][1]/p,h=180*o[2][0]/p,f=180*o[2][1]/p;r.push(s([[l+e,c+e],[l+e,u-e],[h-e,u-e],[h-e,f+e]],30))}for(var i=n[1].length-1;i>=0;--i){var o=n[1][i],l=180*o[0][0]/p,c=180*o[0][1]/p,u=180*o[1][1]/p,h=180*o[2][0]/p,f=180*o[2][1]/p;r.push(s([[h-e,f-e],[h-e,u+e],[l+e,u+e],[l+e,c-e]],30))}return{type:\"Polygon\",coordinates:[t.merge(r)]}}(),l)},i},a.lobes=function(t){return arguments.length?(n=t.map(function(t){return t.map(function(t){return[[t[0][0]*p/180,t[0][1]*p/180],[t[1][0]*p/180,t[1][1]*p/180],[t[2][0]*p/180,t[2][1]*p/180]]})}),r=n.map(function(t){return t.map(function(t){var r,n=e(t[0][0],t[0][1])[0],i=e(t[2][0],t[2][1])[0],a=e(t[1][0],t[0][1])[1],o=e(t[1][0],t[1][1])[1];return a>o&&(r=a,a=o,o=r),[[n,a],[i,o]]})}),a):n.map(function(t){return t.map(function(t){return[[180*t[0][0]/p,180*t[0][1]/p],[180*t[1][0]/p,180*t[1][1]/p],[180*t[2][0]/p,180*t[2][1]/p]]})})},a},_.invert=function(t,e){var r=.5*e*Math.sqrt((4+p)/p),n=m(r),i=Math.cos(n);return[t/(2/Math.sqrt(p*(4+p))*(1+i)),m((n+r*(i+2))/(2+d))]},(t.geo.eckert4=function(){return x(_)}).raw=_;var w=t.geo.azimuthalEqualArea.raw;function k(t,e){if(arguments.length<2&&(e=t),1===e)return w;if(e===1/0)return T;function r(r,n){var i=w(r/e,n);return i[0]*=t,i}return r.invert=function(r,n){var i=w.invert(r/t,n);return i[0]*=e,i},r}function T(t,e){return[t*Math.cos(e)/Math.cos(e/=2),2*Math.sin(e)]}function A(t,e){return[3*t/(2*p)*Math.sqrt(p*p/3-e*e),e]}function M(t,e){return[t,1.25*Math.log(Math.tan(p/4+.4*e))]}function S(t){return function(e){var r,n=t*Math.sin(e),i=30;do{e-=r=(e+Math.sin(e)-n)/(1+Math.cos(e))}while(Math.abs(r)>h&&--i>0);return e/2}}T.invert=function(t,e){var r=2*m(e/2);return[t*Math.cos(r/2)/Math.cos(r),r]},(t.geo.hammer=function(){var t=2,e=b(k),r=e(t);return r.coefficient=function(r){return arguments.length?e(t=+r):t},r}).raw=k,A.invert=function(t,e){return[2/3*p*t/Math.sqrt(p*p/3-e*e),e]},(t.geo.kavrayskiy7=function(){return x(A)}).raw=A,M.invert=function(t,e){return[t,2.5*Math.atan(Math.exp(.8*e))-.625*p]},(t.geo.miller=function(){return x(M)}).raw=M,S(p);var E=function(t,e,r){var n=S(r);function i(r,i){return[t*r*Math.cos(i=n(i)),e*Math.sin(i)]}return i.invert=function(n,i){var a=m(i/e);return[n/(t*Math.cos(a)),m((2*a+Math.sin(2*a))/r)]},i}(Math.SQRT2/d,Math.SQRT2,p);function C(t,e){var r=e*e,n=r*r;return[t*(.8707-.131979*r+n*(n*(.003971*r-.001529*n)-.013791)),e*(1.007226+r*(.015085+n*(.028874*r-.044475-.005916*n)))]}(t.geo.mollweide=function(){return x(E)}).raw=E,C.invert=function(t,e){var r,n=e,i=25;do{var a=n*n,o=a*a;n-=r=(n*(1.007226+a*(.015085+o*(.028874*a-.044475-.005916*o)))-e)/(1.007226+a*(.045255+o*(.259866*a-.311325-.005916*11*o)))}while(Math.abs(r)>h&&--i>0);return[t/(.8707+(a=n*n)*(a*(a*a*a*(.003971-.001529*a)-.013791)-.131979)),n]},(t.geo.naturalEarth=function(){return x(C)}).raw=C;var L=[[.9986,-.062],[1,0],[.9986,.062],[.9954,.124],[.99,.186],[.9822,.248],[.973,.31],[.96,.372],[.9427,.434],[.9216,.4958],[.8962,.5571],[.8679,.6176],[.835,.6769],[.7986,.7346],[.7597,.7903],[.7186,.8435],[.6732,.8936],[.6213,.9394],[.5722,.9761],[.5322,1]];function P(t,e){var r,n=Math.min(18,36*Math.abs(e)/p),i=Math.floor(n),a=n-i,o=(r=L[i])[0],s=r[1],l=(r=L[++i])[0],c=r[1],u=(r=L[Math.min(19,++i)])[0],h=r[1];return[t*(l+a*(u-o)/2+a*a*(u-2*l+o)/2),(e>0?d:-d)*(c+a*(h-s)/2+a*a*(h-2*c+s)/2)]}function O(t,e){return[t*Math.cos(e),e]}function z(t,e){var r,n=Math.cos(e),i=(r=y(n*Math.cos(t/=2)))?r/Math.sin(r):1;return[2*n*Math.sin(t)*i,Math.sin(e)*i]}function I(t,e){var r=z(t,e);return[(r[0]+t/d)/2,(r[1]+e)/2]}L.forEach(function(t){t[1]*=1.0144}),P.invert=function(t,e){var r=e/d,n=90*r,i=Math.min(18,Math.abs(n/5)),a=Math.max(0,Math.floor(i));do{var o=L[a][1],s=L[a+1][1],l=L[Math.min(19,a+2)][1],c=l-o,u=l-2*s+o,h=2*(Math.abs(r)-s)/c,p=u/c,m=h*(1-p*h*(1-2*p*h));if(m>=0||1===a){n=(e>=0?5:-5)*(m+i);var y,x=50;do{m=(i=Math.min(18,Math.abs(n)/5))-(a=Math.floor(i)),o=L[a][1],s=L[a+1][1],l=L[Math.min(19,a+2)][1],n-=(y=(e>=0?d:-d)*(s+m*(l-o)/2+m*m*(l-2*s+o)/2)-e)*v}while(Math.abs(y)>f&&--x>0);break}}while(--a>=0);var b=L[a][0],_=L[a+1][0],w=L[Math.min(19,a+2)][0];return[t/(_+m*(w-b)/2+m*m*(w-2*_+b)/2),n*g]},(t.geo.robinson=function(){return x(P)}).raw=P,O.invert=function(t,e){return[t/Math.cos(e),e]},(t.geo.sinusoidal=function(){return x(O)}).raw=O,z.invert=function(t,e){if(!(t*t+4*e*e>p*p+h)){var r=t,n=e,i=25;do{var a,o=Math.sin(r),s=Math.sin(r/2),l=Math.cos(r/2),c=Math.sin(n),u=Math.cos(n),f=Math.sin(2*n),d=c*c,g=u*u,v=s*s,m=1-g*l*l,x=m?y(u*l)*Math.sqrt(a=1/m):a=0,b=2*x*u*s-t,_=x*c-e,w=a*(g*v+x*u*l*d),k=a*(.5*o*f-2*x*c*s),T=.25*a*(f*s-x*c*g*o),A=a*(d*l+x*v*u),M=k*T-A*w;if(!M)break;var S=(_*k-b*A)/M,E=(b*T-_*w)/M;r-=S,n-=E}while((Math.abs(S)>h||Math.abs(E)>h)&&--i>0);return[r,n]}},(t.geo.aitoff=function(){return x(z)}).raw=z,I.invert=function(t,e){var r=t,n=e,i=25;do{var a,o=Math.cos(n),s=Math.sin(n),l=Math.sin(2*n),c=s*s,u=o*o,f=Math.sin(r),p=Math.cos(r/2),g=Math.sin(r/2),v=g*g,m=1-u*p*p,x=m?y(o*p)*Math.sqrt(a=1/m):a=0,b=.5*(2*x*o*g+r/d)-t,_=.5*(x*s+n)-e,w=.5*a*(u*v+x*o*p*c)+.5/d,k=a*(f*l/4-x*s*g),T=.125*a*(l*g-x*s*u*f),A=.5*a*(c*p+x*v*o)+.5,M=k*T-A*w,S=(_*k-b*A)/M,E=(b*T-_*w)/M;r-=S,n-=E}while((Math.abs(S)>h||Math.abs(E)>h)&&--i>0);return[r,n]},(t.geo.winkel3=function(){return x(I)}).raw=I}},{}],801:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=Math.PI/180,s=180/Math.PI,l={cursor:\"pointer\"},c={cursor:\"auto\"};function u(t,e){return n.behavior.zoom().translate(e.translate()).scale(e.scale())}function h(t,e,r){var n=t.id,o=t.graphDiv,s=o.layout,l=s[n],c=o._fullLayout,u=c[n],h={},f={};function p(t,e){h[n+\".\"+t]=i.nestedProperty(l,t).get(),a.call(\"_storeDirectGUIEdit\",s,c._preGUI,h);var r=i.nestedProperty(u,t);r.get()!==e&&(r.set(e),i.nestedProperty(l,t).set(e),f[n+\".\"+t]=e)}r(p),p(\"projection.scale\",e.scale()/t.fitScale),o.emit(\"plotly_relayout\",f)}function f(t,e){var r=u(0,e);function i(r){var n=e.invert(t.midPt);r(\"center.lon\",n[0]),r(\"center.lat\",n[1])}return r.on(\"zoomstart\",function(){n.select(this).style(l)}).on(\"zoom\",function(){e.scale(n.event.scale).translate(n.event.translate),t.render();var r=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":r[0],\"geo.center.lat\":r[1]})}).on(\"zoomend\",function(){n.select(this).style(c),h(t,e,i)}),r}function p(t,e){var r,i,a,o,s,f,p,d,g,v=u(0,e),m=2;function y(t){return e.invert(t)}function x(r){var n=e.rotate(),i=e.invert(t.midPt);r(\"projection.rotation.lon\",-n[0]),r(\"center.lon\",i[0]),r(\"center.lat\",i[1])}return v.on(\"zoomstart\",function(){n.select(this).style(l),r=n.mouse(this),i=e.rotate(),a=e.translate(),o=i,s=y(r)}).on(\"zoom\",function(){if(f=n.mouse(this),function(t){var r=y(t);if(!r)return!0;var n=e(r);return Math.abs(n[0]-t[0])>m||Math.abs(n[1]-t[1])>m}(r))return v.scale(e.scale()),void v.translate(e.translate());e.scale(n.event.scale),e.translate([a[0],n.event.translate[1]]),s?y(f)&&(d=y(f),p=[o[0]+(d[0]-s[0]),i[1],i[2]],e.rotate(p),o=p):s=y(r=f),g=!0,t.render();var l=e.rotate(),c=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":c[0],\"geo.center.lat\":c[1],\"geo.projection.rotation.lon\":-l[0]})}).on(\"zoomend\",function(){n.select(this).style(c),g&&h(t,e,x)}),v}function d(t,e){var r,i={r:e.rotate(),k:e.scale()},a=u(0,e),f=function(t){var e=0,r=arguments.length,i=[];for(;++e<r;)i.push(arguments[e]);var a=n.dispatch.apply(null,i);return a.of=function(e,r){return function(i){var o;try{o=i.sourceEvent=n.event,i.target=t,n.event=i,a[i.type].apply(e,r)}finally{n.event=o}}},a}(a,\"zoomstart\",\"zoom\",\"zoomend\"),p=0,d=a.on;function m(t){var r=e.rotate();t(\"projection.rotation.lon\",-r[0]),t(\"projection.rotation.lat\",-r[1])}return a.on(\"zoomstart\",function(){n.select(this).style(l);var t,c,u,h,m,b,_,w,k,T,A,M=n.mouse(this),S=e.rotate(),E=S,C=e.translate(),L=(c=.5*(t=S)[0]*o,u=.5*t[1]*o,h=.5*t[2]*o,m=Math.sin(c),b=Math.cos(c),_=Math.sin(u),w=Math.cos(u),k=Math.sin(h),T=Math.cos(h),[b*w*T+m*_*k,m*w*T-b*_*k,b*_*T+m*w*k,b*w*k-m*_*T]);r=g(e,M),d.call(a,\"zoom\",function(){var t,a,o,l,c,u,h,p,d,m,b=n.mouse(this);if(e.scale(i.k=n.event.scale),r){if(g(e,b)){e.rotate(S).translate(C);var _=g(e,b),w=function(t,e){if(!t||!e)return;var r=function(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}(t,e),n=Math.sqrt(x(r,r)),i=.5*Math.acos(Math.max(-1,Math.min(1,x(t,e)))),a=Math.sin(i)/n;return n&&[Math.cos(i),r[2]*a,-r[1]*a,r[0]*a]}(r,_),k=function(t){return[Math.atan2(2*(t[0]*t[1]+t[2]*t[3]),1-2*(t[1]*t[1]+t[2]*t[2]))*s,Math.asin(Math.max(-1,Math.min(1,2*(t[0]*t[2]-t[3]*t[1]))))*s,Math.atan2(2*(t[0]*t[3]+t[1]*t[2]),1-2*(t[2]*t[2]+t[3]*t[3]))*s]}((a=w,o=(t=L)[0],l=t[1],c=t[2],u=t[3],h=a[0],p=a[1],d=a[2],m=a[3],[o*h-l*p-c*d-u*m,o*p+l*h+c*m-u*d,o*d-l*m+c*h+u*p,o*m+l*d-c*p+u*h])),T=i.r=function(t,e,r){var n=y(e,2,t[0]);n=y(n,1,t[1]),n=y(n,0,t[2]-r[2]);var i,a,o=e[0],l=e[1],c=e[2],u=n[0],h=n[1],f=n[2],p=Math.atan2(l,o)*s,d=Math.sqrt(o*o+l*l);Math.abs(h)>d?(a=(h>0?90:-90)-p,i=0):(a=Math.asin(h/d)*s-p,i=Math.sqrt(d*d-h*h));var g=180-a-2*p,m=(Math.atan2(f,u)-Math.atan2(c,i))*s,x=(Math.atan2(f,u)-Math.atan2(c,-i))*s,b=v(r[0],r[1],a,m),_=v(r[0],r[1],g,x);return b<=_?[a,m,r[2]]:[g,x,r[2]]}(k,r,E);isFinite(T[0])&&isFinite(T[1])&&isFinite(T[2])||(T=E),e.rotate(T),E=T}}else r=g(e,M=b);f.of(this,arguments)({type:\"zoom\"})}),A=f.of(this,arguments),p++||A({type:\"zoomstart\"})}).on(\"zoomend\",function(){var r;n.select(this).style(c),d.call(a,\"zoom\",null),r=f.of(this,arguments),--p||r({type:\"zoomend\"}),h(t,e,m)}).on(\"zoom.redraw\",function(){t.render();var r=e.rotate();t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.projection.rotation.lon\":-r[0],\"geo.projection.rotation.lat\":-r[1]})}),n.rebind(a,f,\"on\")}function g(t,e){var r=t.invert(e);return r&&isFinite(r[0])&&isFinite(r[1])&&function(t){var e=t[0]*o,r=t[1]*o,n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}(r)}function v(t,e,r,n){var i=m(r-t),a=m(n-e);return Math.sqrt(i*i+a*a)}function m(t){return(t%360+540)%360-180}function y(t,e,r){var n=r*o,i=t.slice(),a=0===e?1:0,s=2===e?1:2,l=Math.cos(n),c=Math.sin(n);return i[a]=t[a]*l-t[s]*c,i[s]=t[s]*l+t[a]*c,i}function x(t,e){for(var r=0,n=0,i=t.length;n<i;++n)r+=t[n]*e[n];return r}e.exports=function(t,e){var r=t.projection;return(e._isScoped?f:e._isClipped?d:p)(t,r)}},{\"../../lib\":719,\"../../registry\":847,d3:163}],802:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"./cartesian/constants\").SUBPLOT_PATTERN;r.getSubplotCalcData=function(t,e,r){var i=n.subplotsRegistry[e];if(!i)return[];for(var a=i.attr,o=[],s=0;s<t.length;s++){var l=t[s];l[0].trace[a]===r&&o.push(l)}return o},r.getModuleCalcData=function(t,e){var r,i=[],a=[];if(!(r=\"string\"==typeof e?n.getModule(e).plot:\"function\"==typeof e?e:e.plot))return[i,t];for(var o=0;o<t.length;o++){var s=t[o],l=s[0].trace;!0===l.visible&&0!==l._length&&(l._module.plot===r?i.push(s):a.push(s))}return[i,a]},r.getSubplotData=function(t,e,r){if(!n.subplotsRegistry[e])return[];var a,o,s,l=n.subplotsRegistry[e].attr,c=[];if(\"gl2d\"===e){var u=r.match(i);o=\"x\"+u[1],s=\"y\"+u[2]}for(var h=0;h<t.length;h++)a=t[h],\"gl2d\"===e&&n.traceIs(a,\"gl2d\")?a[l[0]]===o&&a[l[1]]===s&&c.push(a):a[l]===r&&c.push(a);return c}},{\"../registry\":847,\"./cartesian/constants\":773}],803:[function(t,e,r){\"use strict\";var n=t(\"mouse-change\"),i=t(\"mouse-wheel\"),a=t(\"mouse-event-offset\"),o=t(\"../cartesian/constants\"),s=t(\"has-passive-events\");function l(t,e){this.element=t,this.plot=e,this.mouseListener=null,this.wheelListener=null,this.lastInputTime=Date.now(),this.lastPos=[0,0],this.boxEnabled=!1,this.boxInited=!1,this.boxStart=[0,0],this.boxEnd=[0,0],this.dragStart=[0,0]}e.exports=function(t){var e=t.mouseContainer,r=t.glplot,c=new l(e,r);function u(){t.xaxis.autorange=!1,t.yaxis.autorange=!1}function h(e,n,i){var a,s,l=t.calcDataBox(),h=r.viewBox,f=c.lastPos[0],p=c.lastPos[1],d=o.MINDRAG*r.pixelRatio,g=o.MINZOOM*r.pixelRatio;function v(e,r,n){var i=Math.min(r,n),a=Math.max(r,n);i!==a?(l[e]=i,l[e+2]=a,c.dataBox=l,t.setRanges(l)):(t.selectBox.selectBox=[0,0,1,1],t.glplot.setDirty())}switch(n*=r.pixelRatio,i*=r.pixelRatio,i=h[3]-h[1]-i,t.fullLayout.dragmode){case\"zoom\":if(e){var m=n/(h[2]-h[0])*(l[2]-l[0])+l[0],y=i/(h[3]-h[1])*(l[3]-l[1])+l[1];c.boxInited||(c.boxStart[0]=m,c.boxStart[1]=y,c.dragStart[0]=n,c.dragStart[1]=i),c.boxEnd[0]=m,c.boxEnd[1]=y,c.boxInited=!0,c.boxEnabled||c.boxStart[0]===c.boxEnd[0]&&c.boxStart[1]===c.boxEnd[1]||(c.boxEnabled=!0);var x=Math.abs(c.dragStart[0]-n)<g,b=Math.abs(c.dragStart[1]-i)<g;if(!function(){for(var e=t.graphDiv._fullLayout._axisConstraintGroups,r=t.xaxis._id,n=t.yaxis._id,i=0;i<e.length;i++)if(-1!==e[i][r]){if(-1!==e[i][n])return!0;break}return!1}()||x&&b)x&&(c.boxEnd[0]=c.boxStart[0]),b&&(c.boxEnd[1]=c.boxStart[1]);else{a=c.boxEnd[0]-c.boxStart[0],s=c.boxEnd[1]-c.boxStart[1];var _=(l[3]-l[1])/(l[2]-l[0]);Math.abs(a*_)>Math.abs(s)?(c.boxEnd[1]=c.boxStart[1]+Math.abs(a)*_*(s>=0?1:-1),c.boxEnd[1]<l[1]?(c.boxEnd[1]=l[1],c.boxEnd[0]=c.boxStart[0]+(l[1]-c.boxStart[1])/Math.abs(_)):c.boxEnd[1]>l[3]&&(c.boxEnd[1]=l[3],c.boxEnd[0]=c.boxStart[0]+(l[3]-c.boxStart[1])/Math.abs(_))):(c.boxEnd[0]=c.boxStart[0]+Math.abs(s)/_*(a>=0?1:-1),c.boxEnd[0]<l[0]?(c.boxEnd[0]=l[0],c.boxEnd[1]=c.boxStart[1]+(l[0]-c.boxStart[0])*Math.abs(_)):c.boxEnd[0]>l[2]&&(c.boxEnd[0]=l[2],c.boxEnd[1]=c.boxStart[1]+(l[2]-c.boxStart[0])*Math.abs(_)))}}else c.boxEnabled?(a=c.boxStart[0]!==c.boxEnd[0],s=c.boxStart[1]!==c.boxEnd[1],a||s?(a&&(v(0,c.boxStart[0],c.boxEnd[0]),t.xaxis.autorange=!1),s&&(v(1,c.boxStart[1],c.boxEnd[1]),t.yaxis.autorange=!1),t.relayoutCallback()):t.glplot.setDirty(),c.boxEnabled=!1,c.boxInited=!1):c.boxInited&&(c.boxInited=!1);break;case\"pan\":c.boxEnabled=!1,c.boxInited=!1,e?(c.panning||(c.dragStart[0]=n,c.dragStart[1]=i),Math.abs(c.dragStart[0]-n)<d&&(n=c.dragStart[0]),Math.abs(c.dragStart[1]-i)<d&&(i=c.dragStart[1]),a=(f-n)*(l[2]-l[0])/(r.viewBox[2]-r.viewBox[0]),s=(p-i)*(l[3]-l[1])/(r.viewBox[3]-r.viewBox[1]),l[0]+=a,l[2]+=a,l[1]+=s,l[3]+=s,t.setRanges(l),c.panning=!0,c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations()):c.panning&&(c.panning=!1,t.relayoutCallback())}c.lastPos[0]=n,c.lastPos[1]=i}return c.mouseListener=n(e,h),e.addEventListener(\"touchstart\",function(t){var r=a(t.changedTouches[0],e);h(0,r[0],r[1]),h(1,r[0],r[1]),t.preventDefault()},!!s&&{passive:!1}),e.addEventListener(\"touchmove\",function(t){t.preventDefault();var r=a(t.changedTouches[0],e);h(1,r[0],r[1]),t.preventDefault()},!!s&&{passive:!1}),e.addEventListener(\"touchend\",function(t){h(0,c.lastPos[0],c.lastPos[1]),t.preventDefault()},!!s&&{passive:!1}),c.wheelListener=i(e,function(e,n){if(!t.scrollZoom)return!1;var i=t.calcDataBox(),a=r.viewBox,o=c.lastPos[0],s=c.lastPos[1],l=Math.exp(5*n/(a[3]-a[1])),h=o/(a[2]-a[0])*(i[2]-i[0])+i[0],f=s/(a[3]-a[1])*(i[3]-i[1])+i[1];return i[0]=(i[0]-h)*l+h,i[2]=(i[2]-h)*l+h,i[1]=(i[1]-f)*l+f,i[3]=(i[3]-f)*l+f,t.setRanges(i),c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations(),t.relayoutCallback(),!0},!0),c}},{\"../cartesian/constants\":773,\"has-passive-events\":411,\"mouse-change\":435,\"mouse-event-offset\":436,\"mouse-wheel\":438}],804:[function(t,e,r){\"use strict\";var n=t(\"../cartesian/axes\"),i=t(\"../../lib/str2rgbarray\");function a(t){this.scene=t,this.gl=t.gl,this.pixelRatio=t.pixelRatio,this.screenBox=[0,0,1,1],this.viewBox=[0,0,1,1],this.dataBox=[-1,-1,1,1],this.borderLineEnable=[!1,!1,!1,!1],this.borderLineWidth=[1,1,1,1],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.ticks=[[],[]],this.tickEnable=[!0,!0,!1,!1],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labels=[\"x\",\"y\"],this.labelEnable=[!0,!0,!1,!1],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelPad=[15,15,15,15],this.labelSize=[12,12],this.labelFont=[\"sans-serif\",\"sans-serif\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.title=\"\",this.titleEnable=!0,this.titleCenter=[0,0,0,0],this.titleAngle=0,this.titleColor=[0,0,0,1],this.titleFont=\"sans-serif\",this.titleSize=18,this.gridLineEnable=[!0,!0],this.gridLineColor=[[0,0,0,.5],[0,0,0,.5]],this.gridLineWidth=[1,1],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[1,1],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.static=this.scene.staticPlot}var o=a.prototype,s=[\"xaxis\",\"yaxis\"];o.merge=function(t){var e,r,n,a,o,l,c,u,h,f,p;for(this.titleEnable=!1,this.backgroundColor=i(t.plot_bgcolor),f=0;f<2;++f){var d=(e=s[f]).charAt(0);for(n=(r=t[this.scene[e]._name]).title.text===this.scene.fullLayout._dfltTitle[d]?\"\":r.title.text,p=0;p<=2;p+=2)this.labelEnable[f+p]=!1,this.labels[f+p]=n,this.labelColor[f+p]=i(r.title.font.color),this.labelFont[f+p]=r.title.font.family,this.labelSize[f+p]=r.title.font.size,this.labelPad[f+p]=this.getLabelPad(e,r),this.tickEnable[f+p]=!1,this.tickColor[f+p]=i((r.tickfont||{}).color),this.tickAngle[f+p]=\"auto\"===r.tickangle?0:Math.PI*-r.tickangle/180,this.tickPad[f+p]=this.getTickPad(r),this.tickMarkLength[f+p]=0,this.tickMarkWidth[f+p]=r.tickwidth||0,this.tickMarkColor[f+p]=i(r.tickcolor),this.borderLineEnable[f+p]=!1,this.borderLineColor[f+p]=i(r.linecolor),this.borderLineWidth[f+p]=r.linewidth||0;c=this.hasSharedAxis(r),o=this.hasAxisInDfltPos(e,r)&&!c,l=this.hasAxisInAltrPos(e,r)&&!c,a=r.mirror||!1,u=c?-1!==String(a).indexOf(\"all\"):!!a,h=c?\"allticks\"===a:-1!==String(a).indexOf(\"ticks\"),o?this.labelEnable[f]=!0:l&&(this.labelEnable[f+2]=!0),o?this.tickEnable[f]=r.showticklabels:l&&(this.tickEnable[f+2]=r.showticklabels),(o||u)&&(this.borderLineEnable[f]=r.showline),(l||u)&&(this.borderLineEnable[f+2]=r.showline),(o||h)&&(this.tickMarkLength[f]=this.getTickMarkLength(r)),(l||h)&&(this.tickMarkLength[f+2]=this.getTickMarkLength(r)),this.gridLineEnable[f]=r.showgrid,this.gridLineColor[f]=i(r.gridcolor),this.gridLineWidth[f]=r.gridwidth,this.zeroLineEnable[f]=r.zeroline,this.zeroLineColor[f]=i(r.zerolinecolor),this.zeroLineWidth[f]=r.zerolinewidth}},o.hasSharedAxis=function(t){var e=this.scene,r=e.fullLayout._subplots.gl2d;return 0!==n.findSubplotsWithAxis(r,t).indexOf(e.id)},o.hasAxisInDfltPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"bottom\"===r:\"yaxis\"===t?\"left\"===r:void 0},o.hasAxisInAltrPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"top\"===r:\"yaxis\"===t?\"right\"===r:void 0},o.getLabelPad=function(t,e){var r=e.title.font.size,n=e.showticklabels;return\"xaxis\"===t?\"top\"===e.side?r*(1.5+(n?1:0))-10:r*(1.5+(n?.5:0))-10:\"yaxis\"===t?\"right\"===e.side?10+r*(1.5+(n?1:.5)):10+r*(1.5+(n?.5:0)):void 0},o.getTickPad=function(t){return\"outside\"===t.ticks?10+t.ticklen:15},o.getTickMarkLength=function(t){if(!t.ticks)return 0;var e=t.ticklen;return\"inside\"===t.ticks?-e:e},e.exports=function(t){return new a(t)}},{\"../../lib/str2rgbarray\":742,\"../cartesian/axes\":767}],805:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"./scene2d\"),a=t(\"../layout_attributes\"),o=t(\"../../constants/xmlns_namespaces\"),s=t(\"../cartesian/constants\"),l=t(\"../cartesian\"),c=t(\"../../components/fx/layout_attributes\"),u=t(\"../get_data\").getSubplotData;r.name=\"gl2d\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=s.idRegex,r.attrRegex=s.attrRegex,r.attributes=t(\"../cartesian/attributes\"),r.supplyLayoutDefaults=function(t,e,r){e._has(\"cartesian\")||l.supplyLayoutDefaults(t,e,r)},r.layoutAttrOverrides=n(l.layoutAttributes,\"plot\",\"from-root\"),r.baseLayoutAttrOverrides=n({plot_bgcolor:a.plot_bgcolor,hoverlabel:c.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl2d,a=0;a<n.length;a++){var o=n[a],s=e._plots[o],l=u(r,\"gl2d\",o),c=s._scene2d;void 0===c&&(c=new i({id:o,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio},e),s._scene2d=c),c.plot(l,t.calcdata,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl2d||[],a=0;a<i.length;a++){var o=i[a],s=n._plots[o];if(s._scene2d)0===u(t,\"gl2d\",o).length&&(s._scene2d.destroy(),delete n._plots[o])}l.clean.apply(this,arguments)},r.drawFramework=function(t){t._context.staticPlot||l.drawFramework(t)},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){var i=e._plots[r[n]]._scene2d,a=i.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":a,x:0,y:0,width:\"100%\",height:\"100%\",preserveAspectRatio:\"none\"}),i.destroy()}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){e._plots[r[n]]._scene2d.updateFx(e.dragmode)}}},{\"../../components/fx/layout_attributes\":633,\"../../constants/xmlns_namespaces\":696,\"../../plot_api/edit_types\":750,\"../cartesian\":778,\"../cartesian/attributes\":765,\"../cartesian/constants\":773,\"../get_data\":802,\"../layout_attributes\":819,\"./scene2d\":806}],806:[function(t,e,r){\"use strict\";var n,i,a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../../components/fx\"),l=t(\"gl-plot2d\"),c=t(\"gl-spikes2d\"),u=t(\"gl-select-box\"),h=t(\"webgl-context\"),f=t(\"./convert\"),p=t(\"./camera\"),d=t(\"../../lib/show_no_webgl_msg\"),g=t(\"../cartesian/constraints\"),v=g.enforce,m=g.clean,y=t(\"../cartesian/autorange\").doAutoRange,x=[\"xaxis\",\"yaxis\"],b=t(\"../cartesian/constants\").SUBPLOT_PATTERN;function _(t,e){this.container=t.container,this.graphDiv=t.graphDiv,this.pixelRatio=t.plotGlPixelRatio||window.devicePixelRatio,this.id=t.id,this.staticPlot=!!t.staticPlot,this.scrollZoom=this.graphDiv._context._scrollZoom.cartesian,this.fullData=null,this.updateRefs(e),this.makeFramework(),this.stopped||(this.glplotOptions=f(this),this.glplotOptions.merge(e),this.glplot=l(this.glplotOptions),this.camera=p(this),this.traces={},this.spikes=c(this.glplot),this.selectBox=u(this.glplot,{innerFill:!1,outerFill:!0}),this.lastButtonState=0,this.pickResult=null,this.isMouseOver=!0,this.stopped=!1,this.redraw=this.draw.bind(this),this.redraw())}e.exports=_;var w=_.prototype;w.makeFramework=function(){if(this.staticPlot){if(!(i||(n=document.createElement(\"canvas\"),i=h({canvas:n,preserveDrawingBuffer:!1,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"Error creating static canvas/context for image server\");this.canvas=n,this.gl=i}else{var t=this.container.querySelector(\".gl-canvas-focus\"),e=h({canvas:t,preserveDrawingBuffer:!0,premultipliedAlpha:!0});if(!e)return d(this),void(this.stopped=!0);this.canvas=t,this.gl=e}var r=this.canvas;r.style.width=\"100%\",r.style.height=\"100%\",r.style.position=\"absolute\",r.style.top=\"0px\",r.style.left=\"0px\",r.style[\"pointer-events\"]=\"none\",this.updateSize(r),r.className+=\" user-select-none\";var a=this.svgContainer=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");a.style.position=\"absolute\",a.style.top=a.style.left=\"0px\",a.style.width=a.style.height=\"100%\",a.style[\"z-index\"]=20,a.style[\"pointer-events\"]=\"none\";var o=this.mouseContainer=document.createElement(\"div\");o.style.position=\"absolute\",o.style[\"pointer-events\"]=\"auto\",this.pickCanvas=this.container.querySelector(\".gl-canvas-pick\");var s=this.container;s.appendChild(a),s.appendChild(o);var l=this;o.addEventListener(\"mouseout\",function(){l.isMouseOver=!1,l.unhover()}),o.addEventListener(\"mouseover\",function(){l.isMouseOver=!0})},w.toImage=function(t){t||(t=\"png\"),this.stopped=!0,this.staticPlot&&this.container.appendChild(n),this.updateSize(this.canvas);var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.clearColor(1,1,1,0),e.clear(e.COLOR_BUFFER_BIT|e.DEPTH_BUFFER_BIT),this.glplot.setDirty(),this.glplot.draw(),e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a);for(var o=0,s=i-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=a[4*(r*o+l)+c];a[4*(r*o+l)+c]=a[4*(r*s+l)+c],a[4*(r*s+l)+c]=u}var h=document.createElement(\"canvas\");h.width=r,h.height=i;var f,p=h.getContext(\"2d\"),d=p.createImageData(r,i);switch(d.data.set(a),p.putImageData(d,0,0),t){case\"jpeg\":f=h.toDataURL(\"image/jpeg\");break;case\"webp\":f=h.toDataURL(\"image/webp\");break;default:f=h.toDataURL(\"image/png\")}return this.staticPlot&&this.container.removeChild(n),f},w.updateSize=function(t){t||(t=this.canvas);var e=this.pixelRatio,r=this.fullLayout,n=r.width,i=r.height,a=0|Math.ceil(e*n),o=0|Math.ceil(e*i);return t.width===a&&t.height===o||(t.width=a,t.height=o),t},w.computeTickMarks=function(){this.xaxis.setScale(),this.yaxis.setScale();for(var t=[o.calcTicks(this.xaxis),o.calcTicks(this.yaxis)],e=0;e<2;++e)for(var r=0;r<t[e].length;++r)t[e][r].text=t[e][r].text+\"\";return t},w.updateRefs=function(t){this.fullLayout=t;var e=this.id.match(b),r=\"xaxis\"+e[1],n=\"yaxis\"+e[2];this.xaxis=this.fullLayout[r],this.yaxis=this.fullLayout[n]},w.relayoutCallback=function(){var t=this.graphDiv,e=this.xaxis,r=this.yaxis,n=t.layout,i={},o=i[e._name+\".range\"]=e.range.slice(),s=i[r._name+\".range\"]=r.range.slice();i[e._name+\".autorange\"]=e.autorange,i[r._name+\".autorange\"]=r.autorange,a.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,i);var l=n[e._name];l.range=o,l.autorange=e.autorange;var c=n[r._name];c.range=s,c.autorange=r.autorange,i.lastInputTime=this.camera.lastInputTime,t.emit(\"plotly_relayout\",i)},w.cameraChanged=function(){var t=this.camera;this.glplot.setDataBox(this.calcDataBox());var e=this.computeTickMarks();(function(t,e){for(var r=0;r<2;++r){var n=t[r],i=e[r];if(n.length!==i.length)return!0;for(var a=0;a<n.length;++a)if(n[a].x!==i[a].x)return!0}return!1})(e,this.glplotOptions.ticks)&&(this.glplotOptions.ticks=e,this.glplotOptions.dataBox=t.dataBox,this.glplot.update(this.glplotOptions),this.handleAnnotations())},w.handleAnnotations=function(){for(var t=this.graphDiv,e=this.fullLayout.annotations,r=0;r<e.length;r++){var n=e[r];n.xref===this.xaxis._id&&n.yref===this.yaxis._id&&a.getComponentMethod(\"annotations\",\"drawOne\")(t,r)}},w.destroy=function(){if(this.glplot){var t=this.traces;t&&Object.keys(t).map(function(e){t[e].dispose(),delete t[e]}),this.glplot.dispose(),this.container.removeChild(this.svgContainer),this.container.removeChild(this.mouseContainer),this.fullData=null,this.glplot=null,this.stopped=!0,this.camera.mouseListener.enabled=!1,this.mouseContainer.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=null}},w.plot=function(t,e,r){var n=this.glplot;this.updateRefs(r),this.xaxis.clearCalc(),this.yaxis.clearCalc(),this.updateTraces(t,e),this.updateFx(r.dragmode);var i=r.width,a=r.height;this.updateSize(this.canvas);var o=this.glplotOptions;o.merge(r),o.screenBox=[0,0,i,a];var s={_fullLayout:{_axisConstraintGroups:this.graphDiv._fullLayout._axisConstraintGroups,xaxis:this.xaxis,yaxis:this.yaxis}};m(s,this.xaxis),m(s,this.yaxis);var l,c,u=r._size,h=this.xaxis.domain,f=this.yaxis.domain;for(o.viewBox=[u.l+h[0]*u.w,u.b+f[0]*u.h,i-u.r-(1-h[1])*u.w,a-u.t-(1-f[1])*u.h],this.mouseContainer.style.width=u.w*(h[1]-h[0])+\"px\",this.mouseContainer.style.height=u.h*(f[1]-f[0])+\"px\",this.mouseContainer.height=u.h*(f[1]-f[0]),this.mouseContainer.style.left=u.l+h[0]*u.w+\"px\",this.mouseContainer.style.top=u.t+(1-f[1])*u.h+\"px\",c=0;c<2;++c)(l=this[x[c]])._length=o.viewBox[c+2]-o.viewBox[c],y(this.graphDiv,l),l.setScale();v(s),o.ticks=this.computeTickMarks(),o.dataBox=this.calcDataBox(),o.merge(r),n.update(o),this.glplot.draw()},w.calcDataBox=function(){var t=this.xaxis,e=this.yaxis,r=t.range,n=e.range,i=t.r2l,a=e.r2l;return[i(r[0]),a(n[0]),i(r[1]),a(n[1])]},w.setRanges=function(t){var e=this.xaxis,r=this.yaxis,n=e.l2r,i=r.l2r;e.range=[n(t[0]),n(t[2])],r.range=[i(t[1]),i(t[3])]},w.updateTraces=function(t,e){var r,n,i,a=Object.keys(this.traces);this.fullData=t;t:for(r=0;r<a.length;r++){var o=a[r],s=this.traces[o];for(n=0;n<t.length;n++)if((i=t[n]).uid===o&&i.type===s.type)continue t;s.dispose(),delete this.traces[o]}for(r=0;r<t.length;r++){i=t[r];var l=e[r],c=this.traces[i.uid];c?c.update(i,l):(c=i._module.plot(this,i,l),this.traces[i.uid]=c)}this.glplot.objects.sort(function(t,e){return t._trace.index-e._trace.index})},w.updateFx=function(t){\"lasso\"===t||\"select\"===t?(this.pickCanvas.style[\"pointer-events\"]=\"none\",this.mouseContainer.style[\"pointer-events\"]=\"none\"):(this.pickCanvas.style[\"pointer-events\"]=\"auto\",this.mouseContainer.style[\"pointer-events\"]=\"auto\"),this.mouseContainer.style.cursor=\"pan\"===t?\"move\":\"zoom\"===t?\"crosshair\":null},w.emitPointAction=function(t,e){for(var r,n=t.trace.uid,i=t.pointIndex,a=0;a<this.fullData.length;a++)this.fullData[a].uid===n&&(r=this.fullData[a]);var o={x:t.traceCoord[0],y:t.traceCoord[1],curveNumber:r.index,pointNumber:i,data:r._input,fullData:this.fullData,xaxis:this.xaxis,yaxis:this.yaxis};s.appendArrayPointValue(o,r,i),this.graphDiv.emit(e,{points:[o]})},w.draw=function(){if(!this.stopped){requestAnimationFrame(this.redraw);var t=this.glplot,e=this.camera,r=e.mouseListener,n=1===this.lastButtonState&&0===r.buttons,i=this.fullLayout;this.lastButtonState=r.buttons,this.cameraChanged();var a,o=r.x*t.pixelRatio,l=this.canvas.height-t.pixelRatio*r.y;if(e.boxEnabled&&\"zoom\"===i.dragmode){this.selectBox.enabled=!0;for(var c=this.selectBox.selectBox=[Math.min(e.boxStart[0],e.boxEnd[0]),Math.min(e.boxStart[1],e.boxEnd[1]),Math.max(e.boxStart[0],e.boxEnd[0]),Math.max(e.boxStart[1],e.boxEnd[1])],u=0;u<2;u++)e.boxStart[u]===e.boxEnd[u]&&(c[u]=t.dataBox[u],c[u+2]=t.dataBox[u+2]);t.setDirty()}else if(!e.panning&&this.isMouseOver){this.selectBox.enabled=!1;var h=i._size,f=this.xaxis.domain,p=this.yaxis.domain,d=(a=t.pick(o/t.pixelRatio+h.l+f[0]*h.w,l/t.pixelRatio-(h.t+(1-p[1])*h.h)))&&a.object._trace.handlePick(a);if(d&&n&&this.emitPointAction(d,\"plotly_click\"),a&&\"skip\"!==a.object._trace.hoverinfo&&i.hovermode&&d&&(!this.lastPickResult||this.lastPickResult.traceUid!==d.trace.uid||this.lastPickResult.dataCoord[0]!==d.dataCoord[0]||this.lastPickResult.dataCoord[1]!==d.dataCoord[1])){var g=d;this.lastPickResult={traceUid:d.trace?d.trace.uid:null,dataCoord:d.dataCoord.slice()},this.spikes.update({center:a.dataCoord}),g.screenCoord=[((t.viewBox[2]-t.viewBox[0])*(a.dataCoord[0]-t.dataBox[0])/(t.dataBox[2]-t.dataBox[0])+t.viewBox[0])/t.pixelRatio,(this.canvas.height-(t.viewBox[3]-t.viewBox[1])*(a.dataCoord[1]-t.dataBox[1])/(t.dataBox[3]-t.dataBox[1])-t.viewBox[1])/t.pixelRatio],this.emitPointAction(d,\"plotly_hover\");var v=this.fullData[g.trace.index]||{},m=g.pointIndex,y=s.castHoverinfo(v,i,m);if(y&&\"all\"!==y){var x=y.split(\"+\");-1===x.indexOf(\"x\")&&(g.traceCoord[0]=void 0),-1===x.indexOf(\"y\")&&(g.traceCoord[1]=void 0),-1===x.indexOf(\"z\")&&(g.traceCoord[2]=void 0),-1===x.indexOf(\"text\")&&(g.textLabel=void 0),-1===x.indexOf(\"name\")&&(g.name=void 0)}s.loneHover({x:g.screenCoord[0],y:g.screenCoord[1],xLabel:this.hoverFormatter(\"xaxis\",g.traceCoord[0]),yLabel:this.hoverFormatter(\"yaxis\",g.traceCoord[1]),zLabel:g.traceCoord[2],text:g.textLabel,name:g.name,color:s.castHoverOption(v,m,\"bgcolor\")||g.color,borderColor:s.castHoverOption(v,m,\"bordercolor\"),fontFamily:s.castHoverOption(v,m,\"font.family\"),fontSize:s.castHoverOption(v,m,\"font.size\"),fontColor:s.castHoverOption(v,m,\"font.color\"),nameLength:s.castHoverOption(v,m,\"namelength\"),textAlign:s.castHoverOption(v,m,\"align\")},{container:this.svgContainer,gd:this.graphDiv})}}a||this.unhover(),t.draw()}},w.unhover=function(){this.lastPickResult&&(this.spikes.update({}),this.lastPickResult=null,this.graphDiv.emit(\"plotly_unhover\"),s.loneUnhover(this.svgContainer))},w.hoverFormatter=function(t,e){if(void 0!==e){var r=this[t];return o.tickText(r,r.c2l(e),\"hover\").text}}},{\"../../components/fx\":632,\"../../lib/show_no_webgl_msg\":740,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../cartesian/autorange\":766,\"../cartesian/constants\":773,\"../cartesian/constraints\":774,\"./camera\":803,\"./convert\":804,\"gl-plot2d\":287,\"gl-select-box\":299,\"gl-spikes2d\":308,\"webgl-context\":556}],807:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../components/fx/layout_attributes\"),a=t(\"./scene\"),o=t(\"../get_data\").getSubplotData,s=t(\"../../lib\"),l=t(\"../../constants/xmlns_namespaces\");r.name=\"gl3d\",r.attr=\"scene\",r.idRoot=\"scene\",r.idRegex=r.attrRegex=s.counterRegex(\"scene\"),r.attributes=t(\"./layout/attributes\"),r.layoutAttributes=t(\"./layout/layout_attributes\"),r.baseLayoutAttrOverrides=n({hoverlabel:i.hoverlabel},\"plot\",\"nested\"),r.supplyLayoutDefaults=t(\"./layout/defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl3d,i=0;i<n.length;i++){var s=n[i],l=o(r,\"gl3d\",s),c=e[s],u=c.camera,h=c._scene;h||(h=new a({id:s,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio,camera:u},e),c._scene=h),h.viewInitial||(h.viewInitial={up:{x:u.up.x,y:u.up.y,z:u.up.z},eye:{x:u.eye.x,y:u.eye.y,z:u.eye.z},center:{x:u.center.x,y:u.center.y,z:u.center.z}}),h.plot(l,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl3d||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._scene&&(n[o]._scene.destroy(),n._infolayer&&n._infolayer.selectAll(\".annotation-\"+o).remove())}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=e._size,i=0;i<r.length;i++){var a=e[r[i]],o=a.domain,s=a._scene,c=s.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:l.svg,\"xlink:href\":c,x:n.l+n.w*o.x[0],y:n.t+n.h*(1-o.y[1]),width:n.w*(o.x[1]-o.x[0]),height:n.h*(o.y[1]-o.y[0]),preserveAspectRatio:\"none\"}),s.destroy()}},r.cleanId=function(t){if(t.match(/^scene[0-9]*$/)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),\"scene\"+e}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){e[r[n]]._scene.updateFx(e.dragmode,e.hovermode)}}},{\"../../components/fx/layout_attributes\":633,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../plot_api/edit_types\":750,\"../get_data\":802,\"./layout/attributes\":808,\"./layout/defaults\":812,\"./layout/layout_attributes\":813,\"./scene\":817}],808:[function(t,e,r){\"use strict\";e.exports={scene:{valType:\"subplotid\",dflt:\"scene\",editType:\"calc+clearAxisTypes\"}}},{}],809:[function(t,e,r){\"use strict\";var n=t(\"../../../components/color\"),i=t(\"../../cartesian/layout_attributes\"),a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../plot_api/edit_types\").overrideAll;e.exports=o({visible:i.visible,showspikes:{valType:\"boolean\",dflt:!0},spikesides:{valType:\"boolean\",dflt:!0},spikethickness:{valType:\"number\",min:0,dflt:2},spikecolor:{valType:\"color\",dflt:n.defaultLine},showbackground:{valType:\"boolean\",dflt:!1},backgroundcolor:{valType:\"color\",dflt:\"rgba(204, 204, 204, 0.5)\"},showaxeslabels:{valType:\"boolean\",dflt:!0},color:i.color,categoryorder:i.categoryorder,categoryarray:i.categoryarray,title:i.title,type:a({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autorange:i.autorange,rangemode:i.rangemode,range:a({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],anim:!1}),tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,mirror:i.mirror,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,tickfont:i.tickfont,tickangle:i.tickangle,tickprefix:i.tickprefix,showtickprefix:i.showtickprefix,ticksuffix:i.ticksuffix,showticksuffix:i.showticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,separatethousands:i.separatethousands,tickformat:i.tickformat,tickformatstops:i.tickformatstops,hoverformat:i.hoverformat,showline:i.showline,linecolor:i.linecolor,linewidth:i.linewidth,showgrid:i.showgrid,gridcolor:a({},i.gridcolor,{dflt:\"rgb(204, 204, 204)\"}),gridwidth:i.gridwidth,zeroline:i.zeroline,zerolinecolor:i.zerolinecolor,zerolinewidth:i.zerolinewidth,_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}},\"plot\",\"from-root\")},{\"../../../components/color\":593,\"../../../lib/extend\":710,\"../../../plot_api/edit_types\":750,\"../../cartesian/layout_attributes\":779}],810:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../../lib\"),a=t(\"../../../plot_api/plot_template\"),o=t(\"./axis_attributes\"),s=t(\"../../cartesian/type_defaults\"),l=t(\"../../cartesian/axis_defaults\"),c=[\"xaxis\",\"yaxis\",\"zaxis\"];e.exports=function(t,e,r){var u,h;function f(t,e){return i.coerce(u,h,o,t,e)}for(var p=0;p<c.length;p++){var d=c[p];u=t[d]||{},(h=a.newContainer(e,d))._id=d[0]+r.scene,h._name=d,s(u,h,f,r),l(u,h,f,{font:r.font,letter:d[0],data:r.data,showGrid:!0,noTickson:!0,bgColor:r.bgColor,calendar:r.calendar},r.fullLayout),f(\"gridcolor\",n(h.color,r.bgColor,13600/187).toRgbString()),f(\"title.text\",d[0]),h.setScale=i.noop,f(\"showspikes\")&&(f(\"spikesides\"),f(\"spikethickness\"),f(\"spikecolor\",h.color)),f(\"showaxeslabels\"),f(\"showbackground\")&&f(\"backgroundcolor\")}}},{\"../../../lib\":719,\"../../../plot_api/plot_template\":757,\"../../cartesian/axis_defaults\":769,\"../../cartesian/type_defaults\":790,\"./axis_attributes\":809,tinycolor2:537}],811:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"];function o(){this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[18,18,18],this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=[\"Open Sans\",\"Open Sans\",\"Open Sans\"],this.labelSize=[20,20,20],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[30,30,30],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[10,10,10],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!0,!0,!0],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._defaultTickPad=this.tickPad.slice(),this._defaultLabelPad=this.labelPad.slice(),this._defaultLineTickLength=this.lineTickLength.slice()}o.prototype.merge=function(t,e){for(var r=0;r<3;++r){var o=e[a[r]];o.visible?(this.labels[r]=t._meta?i.templateString(o.title.text,t._meta):o.title.text,\"font\"in o.title&&(o.title.font.color&&(this.labelColor[r]=n(o.title.font.color)),o.title.font.family&&(this.labelFont[r]=o.title.font.family),o.title.font.size&&(this.labelSize[r]=o.title.font.size)),\"showline\"in o&&(this.lineEnable[r]=o.showline),\"linecolor\"in o&&(this.lineColor[r]=n(o.linecolor)),\"linewidth\"in o&&(this.lineWidth[r]=o.linewidth),\"showgrid\"in o&&(this.gridEnable[r]=o.showgrid),\"gridcolor\"in o&&(this.gridColor[r]=n(o.gridcolor)),\"gridwidth\"in o&&(this.gridWidth[r]=o.gridwidth),\"log\"===o.type?this.zeroEnable[r]=!1:\"zeroline\"in o&&(this.zeroEnable[r]=o.zeroline),\"zerolinecolor\"in o&&(this.zeroLineColor[r]=n(o.zerolinecolor)),\"zerolinewidth\"in o&&(this.zeroLineWidth[r]=o.zerolinewidth),\"ticks\"in o&&o.ticks?this.lineTickEnable[r]=!0:this.lineTickEnable[r]=!1,\"ticklen\"in o&&(this.lineTickLength[r]=this._defaultLineTickLength[r]=o.ticklen),\"tickcolor\"in o&&(this.lineTickColor[r]=n(o.tickcolor)),\"tickwidth\"in o&&(this.lineTickWidth[r]=o.tickwidth),\"tickangle\"in o&&(this.tickAngle[r]=\"auto\"===o.tickangle?-3600:Math.PI*-o.tickangle/180),\"showticklabels\"in o&&(this.tickEnable[r]=o.showticklabels),\"tickfont\"in o&&(o.tickfont.color&&(this.tickColor[r]=n(o.tickfont.color)),o.tickfont.family&&(this.tickFont[r]=o.tickfont.family),o.tickfont.size&&(this.tickSize[r]=o.tickfont.size)),\"mirror\"in o?-1!==[\"ticks\",\"all\",\"allticks\"].indexOf(o.mirror)?(this.lineTickMirror[r]=!0,this.lineMirror[r]=!0):!0===o.mirror?(this.lineTickMirror[r]=!1,this.lineMirror[r]=!0):(this.lineTickMirror[r]=!1,this.lineMirror[r]=!1):this.lineMirror[r]=!1,\"showbackground\"in o&&!1!==o.showbackground?(this.backgroundEnable[r]=!0,this.backgroundColor[r]=n(o.backgroundcolor)):this.backgroundEnable[r]=!1):(this.tickEnable[r]=!1,this.labelEnable[r]=!1,this.lineEnable[r]=!1,this.lineTickEnable[r]=!1,this.gridEnable[r]=!1,this.zeroEnable[r]=!1,this.backgroundEnable[r]=!1)}},e.exports=function(t,e){var r=new o;return r.merge(t,e),r}},{\"../../../lib\":719,\"../../../lib/str2rgbarray\":742}],812:[function(t,e,r){\"use strict\";var n=t(\"../../../lib\"),i=t(\"../../../components/color\"),a=t(\"../../../registry\"),o=t(\"../../subplot_defaults\"),s=t(\"./axis_defaults\"),l=t(\"./layout_attributes\"),c=t(\"../../get_data\").getSubplotData,u=\"gl3d\";function h(t,e,r,n){for(var o=r(\"bgcolor\"),l=i.combine(o,n.paper_bgcolor),h=[\"up\",\"center\",\"eye\"],f=0;f<h.length;f++)r(\"camera.\"+h[f]+\".x\"),r(\"camera.\"+h[f]+\".y\"),r(\"camera.\"+h[f]+\".z\");r(\"camera.projection.type\");var p=!!r(\"aspectratio.x\")&&!!r(\"aspectratio.y\")&&!!r(\"aspectratio.z\"),d=r(\"aspectmode\",p?\"manual\":\"auto\");p||(t.aspectratio=e.aspectratio={x:1,y:1,z:1},\"manual\"===d&&(e.aspectmode=\"auto\"),t.aspectmode=e.aspectmode);var g=c(n.fullData,u,n.id);s(t,e,{font:n.font,scene:n.id,data:g,bgColor:l,calendar:n.calendar,fullLayout:n.fullLayout}),a.getComponentMethod(\"annotations3d\",\"handleDefaults\")(t,e,n);var v=n.getDfltFromLayout(\"dragmode\");if(!1!==v&&!v)if(v=\"orbit\",t.camera&&t.camera.up){var m=t.camera.up.x,y=t.camera.up.y,x=t.camera.up.z;0!==x&&(m&&y&&x?x/Math.sqrt(m*m+y*y+x*x)>.999&&(v=\"turntable\"):v=\"turntable\")}else v=\"turntable\";r(\"dragmode\",v),r(\"hovermode\",n.getDfltFromLayout(\"hovermode\"))}e.exports=function(t,e,r){var i=e._basePlotModules.length>1;o(t,e,r,{type:u,attributes:l,handleDefaults:h,fullLayout:e,font:e.font,fullData:r,getDfltFromLayout:function(e){if(!i)return n.validate(t[e],l[e])?t[e]:void 0},paper_bgcolor:e.paper_bgcolor,calendar:e.calendar})}},{\"../../../components/color\":593,\"../../../lib\":719,\"../../../registry\":847,\"../../get_data\":802,\"../../subplot_defaults\":842,\"./axis_defaults\":810,\"./layout_attributes\":813}],813:[function(t,e,r){\"use strict\";var n=t(\"./axis_attributes\"),i=t(\"../../domain\").attributes,a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../lib\").counterRegex;function s(t,e,r){return{x:{valType:\"number\",dflt:t,editType:\"camera\"},y:{valType:\"number\",dflt:e,editType:\"camera\"},z:{valType:\"number\",dflt:r,editType:\"camera\"},editType:\"camera\"}}e.exports={_arrayAttrRegexps:[o(\"scene\",\".annotations\",!0)],bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"plot\"},camera:{up:a(s(0,0,1),{}),center:a(s(0,0,0),{}),eye:a(s(1.25,1.25,1.25),{}),projection:{type:{valType:\"enumerated\",values:[\"perspective\",\"orthographic\"],dflt:\"perspective\",editType:\"calc\"},editType:\"calc\"},editType:\"camera\"},domain:i({name:\"scene\",editType:\"plot\"}),aspectmode:{valType:\"enumerated\",values:[\"auto\",\"cube\",\"data\",\"manual\"],dflt:\"auto\",editType:\"plot\",impliedEdits:{\"aspectratio.x\":void 0,\"aspectratio.y\":void 0,\"aspectratio.z\":void 0}},aspectratio:{x:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},y:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},z:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},editType:\"plot\",impliedEdits:{aspectmode:\"manual\"}},xaxis:n,yaxis:n,zaxis:n,dragmode:{valType:\"enumerated\",values:[\"orbit\",\"turntable\",\"zoom\",\"pan\",!1],editType:\"plot\"},hovermode:{valType:\"enumerated\",values:[\"closest\",!1],dflt:\"closest\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"plot\",_deprecated:{cameraposition:{valType:\"info_array\",editType:\"camera\"}}}},{\"../../../lib\":719,\"../../../lib/extend\":710,\"../../domain\":792,\"./axis_attributes\":809}],814:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=[\"xaxis\",\"yaxis\",\"zaxis\"];function a(){this.enabled=[!0,!0,!0],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.drawSides=[!0,!0,!0],this.lineWidth=[1,1,1]}a.prototype.merge=function(t){for(var e=0;e<3;++e){var r=t[i[e]];r.visible?(this.enabled[e]=r.showspikes,this.colors[e]=n(r.spikecolor),this.drawSides[e]=r.spikesides,this.lineWidth[e]=r.spikethickness):(this.enabled[e]=!1,this.drawSides[e]=!1)}},e.exports=function(t){var e=new a;return e.merge(t),e}},{\"../../../lib/str2rgbarray\":742}],815:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.axesOptions,r=t.glplot.axesPixels,s=t.fullSceneLayout,l=[[],[],[]],c=0;c<3;++c){var u=s[a[c]];if(u._length=(r[c].hi-r[c].lo)*r[c].pixelsPerDataUnit/t.dataScale[c],Math.abs(u._length)===1/0||isNaN(u._length))l[c]=[];else{u._input_range=u.range.slice(),u.range[0]=r[c].lo/t.dataScale[c],u.range[1]=r[c].hi/t.dataScale[c],u._m=1/(t.dataScale[c]*r[c].pixelsPerDataUnit),u.range[0]===u.range[1]&&(u.range[0]-=1,u.range[1]+=1);var h=u.tickmode;if(\"auto\"===u.tickmode){u.tickmode=\"linear\";var f=u.nticks||i.constrain(u._length/40,4,9);n.autoTicks(u,Math.abs(u.range[1]-u.range[0])/f)}for(var p=n.calcTicks(u),d=0;d<p.length;++d)p[d].x=p[d].x*t.dataScale[c],\"date\"===u.type&&(p[d].text=p[d].text.replace(/\\<br\\>/g,\" \"));l[c]=p,u.tickmode=h}}e.ticks=l;for(var c=0;c<3;++c){o[c]=.5*(t.glplot.bounds[0][c]+t.glplot.bounds[1][c]);for(var d=0;d<2;++d)e.bounds[d][c]=t.glplot.bounds[d][c]}t.contourLevels=function(t){for(var e=new Array(3),r=0;r<3;++r){for(var n=t[r],i=new Array(n.length),a=0;a<n.length;++a)i[a]=n[a].x;e[r]=i}return e}(l)};var n=t(\"../../cartesian/axes\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"],o=[0,0,0]},{\"../../../lib\":719,\"../../cartesian/axes\":767}],816:[function(t,e,r){\"use strict\";function n(t,e){var r,n,i=[0,0,0,0];for(r=0;r<4;++r)for(n=0;n<4;++n)i[n]+=t[4*r+n]*e[r];return i}e.exports=function(t,e){return n(t.projection,n(t.view,n(t.model,[e[0],e[1],e[2],1])))}},{}],817:[function(t,e,r){\"use strict\";var n,i,a=t(\"gl-plot3d\").createCamera,o=t(\"gl-plot3d\").createScene,s=t(\"webgl-context\"),l=t(\"has-passive-events\"),c=t(\"../../registry\"),u=t(\"../../lib\"),h=t(\"../../plots/cartesian/axes\"),f=t(\"../../components/fx\"),p=t(\"../../lib/str2rgbarray\"),d=t(\"../../lib/show_no_webgl_msg\"),g=t(\"./project\"),v=t(\"./layout/convert\"),m=t(\"./layout/spikes\"),y=t(\"./layout/tick_marks\");function x(t,e,r,a){if(t.initializeGLCamera(),!function(t,e,r,a,l){var c={canvas:a,gl:l,container:t.container,axes:t.axesOptions,spikes:t.spikeOptions,pickRadius:10,snapToData:!0,autoScale:!0,autoBounds:!1,cameraObject:e,pixelRatio:r};if(t.staticMode){if(!(i||(n=document.createElement(\"canvas\"),i=s({canvas:n,preserveDrawingBuffer:!0,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"error creating static canvas/context for image server\");c.pixelRatio=t.pixelRatio,c.gl=i,c.canvas=n}try{t.glplot=o(c)}catch(t){return!1}return!0}(t,t.camera,e,r,a))return d(t);var c=t.graphDiv,p=function(t){if(!1!==t.fullSceneLayout.dragmode){var e={};e[t.id+\".camera\"]=T(t.camera),t.saveCamera(c.layout),t.graphDiv.emit(\"plotly_relayout\",e)}};return t.glplot.canvas.addEventListener(\"mouseup\",function(){p(t)}),t.glplot.canvas.addEventListener(\"wheel\",function(){c._context._scrollZoom.gl3d&&p(t)},!!l&&{passive:!1}),t.glplot.canvas.addEventListener(\"mousemove\",function(){if(!1!==t.fullSceneLayout.dragmode&&0!==t.camera.mouseListener.buttons){var e={};e[t.id+\".camera\"]=T(t.camera),t.graphDiv.emit(\"plotly_relayouting\",e)}}),t.staticMode||t.glplot.canvas.addEventListener(\"webglcontextlost\",function(e){c&&c.emit&&c.emit(\"plotly_webglcontextlost\",{event:e,layer:t.id})},!1),t.glplot.camera=t.camera,t.glplot.oncontextloss=function(){t.recoverContext()},t.glplot.onrender=function(t){var e,r=t.graphDiv,n=t.svgContainer,i=t.container.getBoundingClientRect(),a=i.width,o=i.height;n.setAttributeNS(null,\"viewBox\",\"0 0 \"+a+\" \"+o),n.setAttributeNS(null,\"width\",a),n.setAttributeNS(null,\"height\",o),y(t),t.glplot.axes.update(t.axesOptions);for(var s,l=Object.keys(t.traces),c=null,p=t.glplot.selection,d=0;d<l.length;++d)\"skip\"!==(e=t.traces[l[d]]).data.hoverinfo&&e.handlePick(p)&&(c=e),e.setContourLevels&&e.setContourLevels();function v(e,r){var n=t.fullSceneLayout[e];return h.tickText(n,n.d2l(r),\"hover\").text}if(null!==c){var m=g(t.glplot.cameraParams,p.dataCoordinate);e=c.data;var x,b=r._fullData[e.index],_=p.index,w={xLabel:v(\"xaxis\",p.traceCoordinate[0]),yLabel:v(\"yaxis\",p.traceCoordinate[1]),zLabel:v(\"zaxis\",p.traceCoordinate[2])},k=f.castHoverinfo(b,t.fullLayout,_),T=(k||\"\").split(\"+\"),A=k&&\"all\"===k;b.hovertemplate||A||(-1===T.indexOf(\"x\")&&(w.xLabel=void 0),-1===T.indexOf(\"y\")&&(w.yLabel=void 0),-1===T.indexOf(\"z\")&&(w.zLabel=void 0),-1===T.indexOf(\"text\")&&(p.textLabel=void 0),-1===T.indexOf(\"name\")&&(c.name=void 0));var M=[];\"cone\"===e.type||\"streamtube\"===e.type?(w.uLabel=v(\"xaxis\",p.traceCoordinate[3]),(A||-1!==T.indexOf(\"u\"))&&M.push(\"u: \"+w.uLabel),w.vLabel=v(\"yaxis\",p.traceCoordinate[4]),(A||-1!==T.indexOf(\"v\"))&&M.push(\"v: \"+w.vLabel),w.wLabel=v(\"zaxis\",p.traceCoordinate[5]),(A||-1!==T.indexOf(\"w\"))&&M.push(\"w: \"+w.wLabel),w.normLabel=p.traceCoordinate[6].toPrecision(3),(A||-1!==T.indexOf(\"norm\"))&&M.push(\"norm: \"+w.normLabel),\"streamtube\"===e.type&&(w.divergenceLabel=p.traceCoordinate[7].toPrecision(3),(A||-1!==T.indexOf(\"divergence\"))&&M.push(\"divergence: \"+w.divergenceLabel)),p.textLabel&&M.push(p.textLabel),x=M.join(\"<br>\")):\"isosurface\"===e.type||\"volume\"===e.type?(w.valueLabel=h.tickText(t.mockAxis,t.mockAxis.d2l(p.traceCoordinate[3]),\"hover\").text,M.push(\"value: \"+w.valueLabel),p.textLabel&&M.push(p.textLabel),x=M.join(\"<br>\")):x=p.textLabel;var S={x:p.traceCoordinate[0],y:p.traceCoordinate[1],z:p.traceCoordinate[2],data:b._input,fullData:b,curveNumber:b.index,pointNumber:_};f.appendArrayPointValue(S,b,_),e._module.eventData&&(S=b._module.eventData(S,p,b,{},_));var E={points:[S]};t.fullSceneLayout.hovermode&&f.loneHover({trace:b,x:(.5+.5*m[0]/m[3])*a,y:(.5-.5*m[1]/m[3])*o,xLabel:w.xLabel,yLabel:w.yLabel,zLabel:w.zLabel,text:x,name:c.name,color:f.castHoverOption(b,_,\"bgcolor\")||c.color,borderColor:f.castHoverOption(b,_,\"bordercolor\"),fontFamily:f.castHoverOption(b,_,\"font.family\"),fontSize:f.castHoverOption(b,_,\"font.size\"),fontColor:f.castHoverOption(b,_,\"font.color\"),nameLength:f.castHoverOption(b,_,\"namelength\"),textAlign:f.castHoverOption(b,_,\"align\"),hovertemplate:u.castOption(b,_,\"hovertemplate\"),hovertemplateLabels:u.extendFlat({},S,w),eventData:[S]},{container:n,gd:r}),p.buttons&&p.distance<5?r.emit(\"plotly_click\",E):r.emit(\"plotly_hover\",E),s=E}else f.loneUnhover(n),r.emit(\"plotly_unhover\",s);t.drawAnnotations(t)}.bind(null,t),t.traces={},t.make4thDimension(),!0}function b(t,e){var r=document.createElement(\"div\"),n=t.container;this.graphDiv=t.graphDiv;var i=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");i.style.position=\"absolute\",i.style.top=i.style.left=\"0px\",i.style.width=i.style.height=\"100%\",i.style[\"z-index\"]=20,i.style[\"pointer-events\"]=\"none\",r.appendChild(i),this.svgContainer=i,r.id=t.id,r.style.position=\"absolute\",r.style.top=r.style.left=\"0px\",r.style.width=r.style.height=\"100%\",n.appendChild(r),this.fullLayout=e,this.id=t.id||\"scene\",this.fullSceneLayout=e[this.id],this.plotArgs=[[],{},{}],this.axesOptions=v(e,e[this.id]),this.spikeOptions=m(e[this.id]),this.container=r,this.staticMode=!!t.staticPlot,this.pixelRatio=this.pixelRatio||t.plotGlPixelRatio||2,this.dataScale=[1,1,1],this.contourLevels=[[],[],[]],this.convertAnnotations=c.getComponentMethod(\"annotations3d\",\"convert\"),this.drawAnnotations=c.getComponentMethod(\"annotations3d\",\"draw\"),x(this,this.pixelRatio)}var _=b.prototype;_.initializeGLCamera=function(){var t=this.fullSceneLayout.camera,e=\"orthographic\"===t.projection.type;this.camera=a(this.container,{center:[t.center.x,t.center.y,t.center.z],eye:[t.eye.x,t.eye.y,t.eye.z],up:[t.up.x,t.up.y,t.up.z],_ortho:e,zoomMin:.01,zoomMax:100,mode:\"orbit\"})},_.recoverContext=function(){var t=this,e=this.glplot.gl,r=this.glplot.canvas,n=this.glplot.camera,i=this.glplot.pixelRatio;this.glplot.dispose(),requestAnimationFrame(function a(){e.isContextLost()?requestAnimationFrame(a):x(t,n,i,r)?t.plot.apply(t,t.plotArgs):u.error(\"Catastrophic and unrecoverable WebGL error. Context lost.\")})};var w=[\"xaxis\",\"yaxis\",\"zaxis\"];function k(t,e,r){for(var n=t.fullSceneLayout,i=0;i<3;i++){var a=w[i],o=a.charAt(0),s=n[a],l=e[o],c=e[o+\"calendar\"],h=e[\"_\"+o+\"length\"];if(u.isArrayOrTypedArray(l))for(var f,p=0;p<(h||l.length);p++)if(u.isArrayOrTypedArray(l[p]))for(var d=0;d<l[p].length;++d)f=s.d2l(l[p][d],0,c),!isNaN(f)&&isFinite(f)&&(r[0][i]=Math.min(r[0][i],f),r[1][i]=Math.max(r[1][i],f));else f=s.d2l(l[p],0,c),!isNaN(f)&&isFinite(f)&&(r[0][i]=Math.min(r[0][i],f),r[1][i]=Math.max(r[1][i],f));else r[0][i]=Math.min(r[0][i],0),r[1][i]=Math.max(r[1][i],h-1)}}function T(t){return{up:{x:t.up[0],y:t.up[1],z:t.up[2]},center:{x:t.center[0],y:t.center[1],z:t.center[2]},eye:{x:t.eye[0],y:t.eye[1],z:t.eye[2]},projection:{type:!0===t._ortho?\"orthographic\":\"perspective\"}}}_.plot=function(t,e,r){if(this.plotArgs=[t,e,r],!this.glplot.contextLost){var n,i,a,o,s,l,c=e[this.id],u=r[this.id];c.bgcolor?this.glplot.clearColor=p(c.bgcolor):this.glplot.clearColor=[0,0,0,0],this.glplot.snapToData=!0,this.fullLayout=e,this.fullSceneLayout=c,this.glplotLayout=c,this.axesOptions.merge(e,c),this.spikeOptions.merge(c),this.setCamera(c.camera),this.updateFx(c.dragmode,c.hovermode),this.camera.enableWheel=this.graphDiv._context._scrollZoom.gl3d,this.glplot.update({}),this.setConvert(s),t?Array.isArray(t)||(t=[t]):t=[];var h=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&k(this,n,h);!function(t,e){for(var r=t.fullSceneLayout,n=r.annotations||[],i=0;i<3;i++)for(var a=w[i],o=a.charAt(0),s=r[a],l=0;l<n.length;l++){var c=n[l];if(c.visible){var u=s.r2l(c[o]);!isNaN(u)&&isFinite(u)&&(e[0][i]=Math.min(e[0][i],u),e[1][i]=Math.max(e[1][i],u))}}}(this,h);var f=[1,1,1];for(o=0;o<3;++o)h[1][o]===h[0][o]?f[o]=1:f[o]=1/(h[1][o]-h[0][o]);for(this.dataScale=f,this.convertAnnotations(this),a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&((i=this.traces[n.uid])?i.data.type===n.type?i.update(n):(i.dispose(),i=n._module.plot(this,n),this.traces[n.uid]=i):(i=n._module.plot(this,n),this.traces[n.uid]=i),i.name=n.name);var d=Object.keys(this.traces);t:for(a=0;a<d.length;++a){for(o=0;o<t.length;++o)if(t[o].uid===d[a]&&!0===t[o].visible&&0!==t[o]._length)continue t;(i=this.traces[d[a]]).dispose(),delete this.traces[d[a]]}this.glplot.objects.sort(function(t,e){return t._trace.data.index-e._trace.data.index});var g=[[0,0,0],[0,0,0]],v=[],m={};for(a=0;a<3;++a){if((l=(s=c[w[a]]).type)in m?(m[l].acc*=f[a],m[l].count+=1):m[l]={acc:f[a],count:1},s.autorange){g[0][a]=1/0,g[1][a]=-1/0;var y=this.glplot.objects,x=this.fullSceneLayout.annotations||[],b=s._name.charAt(0);for(o=0;o<y.length;o++){var _=y[o],T=_.bounds,A=_._trace.data._pad||0;\"ErrorBars\"===_.constructor.name&&s._lowerLogErrorBound?g[0][a]=Math.min(g[0][a],s._lowerLogErrorBound):g[0][a]=Math.min(g[0][a],T[0][a]/f[a]-A),g[1][a]=Math.max(g[1][a],T[1][a]/f[a]+A)}for(o=0;o<x.length;o++){var M=x[o];if(M.visible){var S=s.r2l(M[b]);g[0][a]=Math.min(g[0][a],S),g[1][a]=Math.max(g[1][a],S)}}if(\"rangemode\"in s&&\"tozero\"===s.rangemode&&(g[0][a]=Math.min(g[0][a],0),g[1][a]=Math.max(g[1][a],0)),g[0][a]>g[1][a])g[0][a]=-1,g[1][a]=1;else{var E=g[1][a]-g[0][a];g[0][a]-=E/32,g[1][a]+=E/32}if(\"reversed\"===s.autorange){var C=g[0][a];g[0][a]=g[1][a],g[1][a]=C}}else{var L=s.range;g[0][a]=s.r2l(L[0]),g[1][a]=s.r2l(L[1])}g[0][a]===g[1][a]&&(g[0][a]-=1,g[1][a]+=1),v[a]=g[1][a]-g[0][a],this.glplot.bounds[0][a]=g[0][a]*f[a],this.glplot.bounds[1][a]=g[1][a]*f[a]}var P=[1,1,1];for(a=0;a<3;++a){var O=m[l=(s=c[w[a]]).type];P[a]=Math.pow(O.acc,1/O.count)/f[a]}var z;if(\"auto\"===c.aspectmode)z=Math.max.apply(null,P)/Math.min.apply(null,P)<=4?P:[1,1,1];else if(\"cube\"===c.aspectmode)z=[1,1,1];else if(\"data\"===c.aspectmode)z=P;else{if(\"manual\"!==c.aspectmode)throw new Error(\"scene.js aspectRatio was not one of the enumerated types\");var I=c.aspectratio;z=[I.x,I.y,I.z]}c.aspectratio.x=u.aspectratio.x=z[0],c.aspectratio.y=u.aspectratio.y=z[1],c.aspectratio.z=u.aspectratio.z=z[2],this.glplot.aspect=z;var D=c.domain||null,R=e._size||null;if(D&&R){var F=this.container.style;F.position=\"absolute\",F.left=R.l+D.x[0]*R.w+\"px\",F.top=R.t+(1-D.y[1])*R.h+\"px\",F.width=R.w*(D.x[1]-D.x[0])+\"px\",F.height=R.h*(D.y[1]-D.y[0])+\"px\"}this.glplot.redraw()}},_.destroy=function(){this.glplot&&(this.camera.mouseListener.enabled=!1,this.container.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=this.glplot.camera=null,this.glplot.dispose(),this.container.parentNode.removeChild(this.container),this.glplot=null)},_.getCamera=function(){return this.glplot.camera.view.recalcMatrix(this.camera.view.lastT()),T(this.glplot.camera)},_.setCamera=function(t){var e;this.glplot.camera.lookAt.apply(this,[[(e=t).eye.x,e.eye.y,e.eye.z],[e.center.x,e.center.y,e.center.z],[e.up.x,e.up.y,e.up.z]]);var r=\"orthographic\"===t.projection.type;if(r!==this.glplot.camera._ortho){this.glplot.redraw();var n=this.glplot.pixelRatio,i=this.glplot.clearColor;this.glplot.gl.clearColor(i[0],i[1],i[2],i[3]),this.glplot.gl.clear(this.glplot.gl.DEPTH_BUFFER_BIT|this.glplot.gl.COLOR_BUFFER_BIT),this.glplot.dispose(),x(this,n),this.glplot.camera._ortho=r}},_.saveCamera=function(t){var e=this.fullLayout,r=this.getCamera(),n=u.nestedProperty(t,this.id+\".camera\"),i=n.get(),a=!1;function o(t,e,r,n){var i=[\"up\",\"center\",\"eye\"],a=[\"x\",\"y\",\"z\"];return e[i[r]]&&t[i[r]][a[n]]===e[i[r]][a[n]]}if(void 0===i)a=!0;else{for(var s=0;s<3;s++)for(var l=0;l<3;l++)if(!o(r,i,s,l)){a=!0;break}(!i.projection||r.projection&&r.projection.type!==i.projection.type)&&(a=!0)}if(a){var h={};h[this.id+\".camera\"]=i,c.call(\"_storeDirectGUIEdit\",t,e._preGUI,h),n.set(r),u.nestedProperty(e,this.id+\".camera\").set(r)}return a},_.updateFx=function(t,e){var r=this.camera;if(r)if(\"orbit\"===t)r.mode=\"orbit\",r.keyBindingMode=\"rotate\";else if(\"turntable\"===t){r.up=[0,0,1],r.mode=\"turntable\",r.keyBindingMode=\"rotate\";var n=this.graphDiv,i=n._fullLayout,a=this.fullSceneLayout.camera,o=a.up.x,s=a.up.y,l=a.up.z;if(l/Math.sqrt(o*o+s*s+l*l)<.999){var h=this.id+\".camera.up\",f={x:0,y:0,z:1},p={};p[h]=f;var d=n.layout;c.call(\"_storeDirectGUIEdit\",d,i._preGUI,p),a.up=f,u.nestedProperty(d,h).set(f)}}else r.keyBindingMode=t;this.fullSceneLayout.hovermode=e},_.toImage=function(t){t||(t=\"png\"),this.staticMode&&this.container.appendChild(n),this.glplot.redraw();var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a);for(var o=0,s=i-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=a[4*(r*o+l)+c];a[4*(r*o+l)+c]=a[4*(r*s+l)+c],a[4*(r*s+l)+c]=u}var h=document.createElement(\"canvas\");h.width=r,h.height=i;var f,p=h.getContext(\"2d\"),d=p.createImageData(r,i);switch(d.data.set(a),p.putImageData(d,0,0),t){case\"jpeg\":f=h.toDataURL(\"image/jpeg\");break;case\"webp\":f=h.toDataURL(\"image/webp\");break;default:f=h.toDataURL(\"image/png\")}return this.staticMode&&this.container.removeChild(n),f},_.setConvert=function(){for(var t=0;t<3;t++){var e=this.fullSceneLayout[w[t]];h.setConvert(e,this.fullLayout),e.setScale=u.noop}},_.make4thDimension=function(){var t=this.graphDiv._fullLayout;this.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},h.setConvert(this.mockAxis,t)},e.exports=b},{\"../../components/fx\":632,\"../../lib\":719,\"../../lib/show_no_webgl_msg\":740,\"../../lib/str2rgbarray\":742,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./layout/convert\":811,\"./layout/spikes\":814,\"./layout/tick_marks\":815,\"./project\":816,\"gl-plot3d\":290,\"has-passive-events\":411,\"webgl-context\":556}],818:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){n=n||t.length;for(var i=new Array(n),a=0;a<n;a++)i[a]=[t[a],e[a],r[a]];return i}},{}],819:[function(t,e,r){\"use strict\";var n=t(\"./font_attributes\"),i=t(\"./animation_attributes\"),a=t(\"../components/color/attributes\"),o=t(\"./pad_attributes\"),s=t(\"../lib/extend\").extendFlat,l=n({editType:\"calc\"});l.family.dflt='\"Open Sans\", verdana, arial, sans-serif',l.size.dflt=12,l.color.dflt=a.defaultLine,e.exports={font:l,title:{text:{valType:\"string\",editType:\"layoutstyle\"},font:n({editType:\"layoutstyle\"}),xref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},yref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},x:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"layoutstyle\"},y:{valType:\"number\",min:0,max:1,dflt:\"auto\",editType:\"layoutstyle\"},xanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"left\",\"center\",\"right\"],editType:\"layoutstyle\"},yanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],editType:\"layoutstyle\"},pad:s(o({editType:\"layoutstyle\"}),{}),editType:\"layoutstyle\"},autosize:{valType:\"boolean\",dflt:!1,editType:\"none\"},width:{valType:\"number\",min:10,dflt:700,editType:\"plot\"},height:{valType:\"number\",min:10,dflt:450,editType:\"plot\"},margin:{l:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},r:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},t:{valType:\"number\",min:0,dflt:100,editType:\"plot\"},b:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},pad:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},autoexpand:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},paper_bgcolor:{valType:\"color\",dflt:a.background,editType:\"plot\"},plot_bgcolor:{valType:\"color\",dflt:a.background,editType:\"layoutstyle\"},separators:{valType:\"string\",editType:\"plot\"},hidesources:{valType:\"boolean\",dflt:!1,editType:\"plot\"},showlegend:{valType:\"boolean\",editType:\"legend\"},colorway:{valType:\"colorlist\",dflt:a.defaults,editType:\"calc\"},datarevision:{valType:\"any\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editrevision:{valType:\"any\",editType:\"none\"},selectionrevision:{valType:\"any\",editType:\"none\"},template:{valType:\"any\",editType:\"calc\"},modebar:{orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\",editType:\"modebar\"},bgcolor:{valType:\"color\",editType:\"modebar\"},color:{valType:\"color\",editType:\"modebar\"},activecolor:{valType:\"color\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"modebar\"},meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},transition:s({},i.transition,{editType:\"none\"}),_deprecated:{title:{valType:\"string\",editType:\"layoutstyle\"},titlefont:n({editType:\"layoutstyle\"})}}},{\"../components/color/attributes\":592,\"../lib/extend\":710,\"./animation_attributes\":762,\"./font_attributes\":793,\"./pad_attributes\":827}],820:[function(t,e,r){\"use strict\";var n={\"open-street-map\":{id:\"osm\",version:8,sources:{\"plotly-osm-tiles\":{type:\"raster\",attribution:'<a href=\"http://www.openstreetmap.org/about/\" target=\"_blank\">\\xa9 OpenStreetMap</a>',tiles:[\"https://a.tile.openstreetmap.org/{z}/{x}/{y}.png\",\"https://b.tile.openstreetmap.org/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-osm-tiles\",type:\"raster\",source:\"plotly-osm-tiles\",minzoom:0,maxzoom:22}]},\"white-bg\":{id:\"white-bg\",version:8,sources:{},layers:[{id:\"white-bg\",type:\"background\",paint:{\"background-color\":\"#FFFFFF\"},minzoom:0,maxzoom:22}]},\"carto-positron\":{id:\"carto-positron\",version:8,sources:{\"plotly-carto-positron\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/light_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-positron\",type:\"raster\",source:\"plotly-carto-positron\",minzoom:0,maxzoom:22}]},\"carto-darkmatter\":{id:\"carto-darkmatter\",version:8,sources:{\"plotly-carto-darkmatter\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/dark_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-darkmatter\",type:\"raster\",source:\"plotly-carto-darkmatter\",minzoom:0,maxzoom:22}]},\"stamen-terrain\":{id:\"stamen-terrain\",version:8,sources:{\"plotly-stamen-terrain\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/terrain/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-terrain\",type:\"raster\",source:\"plotly-stamen-terrain\",minzoom:0,maxzoom:22}]},\"stamen-toner\":{id:\"stamen-toner\",version:8,sources:{\"plotly-stamen-toner\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/toner/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-toner\",type:\"raster\",source:\"plotly-stamen-toner\",minzoom:0,maxzoom:22}]},\"stamen-watercolor\":{id:\"stamen-watercolor\",version:8,sources:{\"plotly-stamen-watercolor\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://creativecommons.org/licenses/by-sa/3.0\">CC BY SA</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/watercolor/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-watercolor\",type:\"raster\",source:\"plotly-stamen-watercolor\",minzoom:0,maxzoom:22}]}},i=Object.keys(n);e.exports={requiredVersion:\"1.1.1\",styleUrlPrefix:\"mapbox://styles/mapbox/\",styleUrlSuffix:\"v9\",styleValuesMapbox:[\"basic\",\"streets\",\"outdoors\",\"light\",\"dark\",\"satellite\",\"satellite-streets\"],styleValueDflt:\"basic\",stylesNonMapbox:n,styleValuesNonMapbox:i,traceLayerPrefix:\"plotly-trace-layer-\",layoutLayerPrefix:\"plotly-layout-layer-\",wrongVersionErrorMsg:[\"Your custom plotly.js bundle is not using the correct mapbox-gl version\",\"Please install mapbox-gl@1.1.1.\"].join(\"\\n\"),noAccessTokenErrorMsg:[\"Missing Mapbox access token.\",\"Mapbox trace type require a Mapbox access token to be registered.\",\"For example:\",\"  Plotly.plot(gd, data, layout, { mapboxAccessToken: 'my-access-token' });\",\"More info here: https://www.mapbox.com/help/define-access-token/\"].join(\"\\n\"),missingStyleErrorMsg:[\"No valid mapbox style found, please set `mapbox.style` to one of:\",i.join(\", \"),\"or register a Mapbox access token to use a Mapbox-served style.\"].join(\"\\n\"),multipleTokensErrorMsg:[\"Set multiple mapbox access token across different mapbox subplot,\",\"using first token found as mapbox-gl does not allow multipleaccess tokens on the same page.\"].join(\"\\n\"),mapOnErrorMsg:\"Mapbox error.\",mapboxLogo:{path0:\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\",path1:\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\",path2:\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\",polygon:\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34\"},styleRules:{map:\"overflow:hidden;position:relative;\",\"missing-css\":\"display:none;\",canary:\"background-color:salmon;\",\"ctrl-bottom-left\":\"position: absolute; pointer-events: none; z-index: 2; bottom: 0; left: 0;\",\"ctrl-bottom-right\":\"position: absolute; pointer-events: none; z-index: 2; right: 0; bottom: 0;\",ctrl:\"clear: both; pointer-events: auto; transform: translate(0, 0);\",\"ctrl-attrib.mapboxgl-compact .mapboxgl-ctrl-attrib-inner\":\"display: none;\",\"ctrl-attrib.mapboxgl-compact:hover .mapboxgl-ctrl-attrib-inner\":\"display: block; margin-top:2px\",\"ctrl-attrib.mapboxgl-compact:hover\":\"padding: 2px 24px 2px 4px; visibility: visible; margin-top: 6px;\",\"ctrl-attrib.mapboxgl-compact::after\":'content: \"\"; cursor: pointer; position: absolute; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3Csvg viewBox=\"0 0 20 20\" xmlns=\"http://www.w3.org/2000/svg\"%3E %3Cpath fill=\"%23333333\" fill-rule=\"evenodd\" d=\"M4,10a6,6 0 1,0 12,0a6,6 0 1,0 -12,0 M9,7a1,1 0 1,0 2,0a1,1 0 1,0 -2,0 M9,10a1,1 0 1,1 2,0l0,3a1,1 0 1,1 -2,0\"/%3E %3C/svg%3E\\'); background-color: rgba(255, 255, 255, 0.5); width: 24px; height: 24px; box-sizing: border-box; border-radius: 12px;',\"ctrl-attrib.mapboxgl-compact\":\"min-height: 20px; padding: 0; margin: 10px; position: relative; background-color: #fff; border-radius: 3px 12px 12px 3px;\",\"ctrl-bottom-right > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; right: 0\",\"ctrl-bottom-left > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; left: 0\",\"ctrl-bottom-left .mapboxgl-ctrl\":\"margin: 0 0 10px 10px; float: left;\",\"ctrl-bottom-right .mapboxgl-ctrl\":\"margin: 0 10px 10px 0; float: right;\",\"ctrl-attrib\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a:hover\":\"color: inherit; text-decoration: underline;\",\"ctrl-attrib .mapbox-improve-map\":\"font-weight: bold; margin-left: 2px;\",\"attrib-empty\":\"display: none;\",\"ctrl-logo\":'display:block; width: 21px; height: 21px; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3C?xml version=\"1.0\" encoding=\"utf-8\"?%3E %3Csvg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\" viewBox=\"0 0 21 21\" style=\"enable-background:new 0 0 21 21;\" xml:space=\"preserve\"%3E%3Cg transform=\"translate(0,0.01)\"%3E%3Cpath d=\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3Cpath d=\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpath d=\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpolygon points=\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34 \" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3C/g%3E%3C/svg%3E\\')'}}},{}],821:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t.split(\" \"),i=r[0],a=r[1],o=n.isArrayOrTypedArray(e)?n.mean(e):e,s=.5+o/100,l=1.5+o/100,c=[\"\",\"\"],u=[0,0];switch(i){case\"top\":c[0]=\"top\",u[1]=-l;break;case\"bottom\":c[0]=\"bottom\",u[1]=l}switch(a){case\"left\":c[1]=\"right\",u[0]=-s;break;case\"right\":c[1]=\"left\",u[0]=s}return{anchor:c[0]&&c[1]?c.join(\"-\"):c[0]?c[0]:c[1]?c[1]:\"center\",offset:u}}},{\"../../lib\":719}],822:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"../../lib\"),a=t(\"../../plots/get_data\").getSubplotCalcData,o=t(\"../../constants/xmlns_namespaces\"),s=t(\"d3\"),l=t(\"../../components/drawing\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"./mapbox\"),h=r.constants=t(\"./constants\");function f(t){return\"string\"==typeof t&&-1!==h.styleValuesMapbox.indexOf(t)}r.name=\"mapbox\",r.attr=\"subplot\",r.idRoot=\"mapbox\",r.idRegex=r.attrRegex=i.counterRegex(\"mapbox\"),r.attributes={subplot:{valType:\"subplotid\",dflt:\"mapbox\",editType:\"calc\"}},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){var e=t._fullLayout,r=t.calcdata,o=e._subplots.mapbox;if(n.version!==h.requiredVersion)throw new Error(h.wrongVersionErrorMsg);var s=function(t,e){var r=t._fullLayout;if(\"\"===t._context.mapboxAccessToken)return\"\";for(var n=[],a=[],o=!1,s=!1,l=0;l<e.length;l++){var c=r[e[l]],u=c.accesstoken;f(c.style)&&(u?i.pushUnique(n,u):(f(c._input.style)&&(i.error(\"Uses Mapbox map style, but did not set an access token.\"),o=!0),s=!0)),u&&i.pushUnique(a,u)}if(s){var p=o?h.noAccessTokenErrorMsg:h.missingStyleErrorMsg;throw new Error(p)}return n.length?(n.length>1&&i.warn(h.multipleTokensErrorMsg),n[0]):(a.length&&i.log([\"Listed mapbox access token(s)\",a.join(\",\"),\"but did not use a Mapbox map style, ignoring token(s).\"].join(\" \")),\"\")}(t,o);n.accessToken=s;for(var l=0;l<o.length;l++){var c=o[l],p=a(r,\"mapbox\",c),d=e[c],g=d._subplot;g||(g=new u(t,c),e[c]._subplot=g),g.viewInitial||(g.viewInitial={center:i.extendFlat({},d.center),zoom:d.zoom,bearing:d.bearing,pitch:d.pitch}),g.plot(p,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.mapbox||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._subplot&&n[o]._subplot.destroy()}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=e._size,i=0;i<r.length;i++){var a=e[r[i]],u=a.domain,f=a._subplot.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":f,x:n.l+n.w*u.x[0],y:n.t+n.h*(1-u.y[1]),width:n.w*(u.x[1]-u.x[0]),height:n.h*(u.y[1]-u.y[0]),preserveAspectRatio:\"none\"});var p=s.select(a._subplot.div);if(!(null===p.select(\".mapboxgl-ctrl-logo\").node().offsetParent)){var d=e._glimages.append(\"g\");d.attr(\"transform\",\"translate(\"+(n.l+n.w*u.x[0]+10)+\", \"+(n.t+n.h*(1-u.y[0])-31)+\")\"),d.append(\"path\").attr(\"d\",h.mapboxLogo.path0).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"}),d.append(\"path\").attr(\"d\",h.mapboxLogo.path1).style(\"opacity\",.35).style(\"enable-background\",\"new\"),d.append(\"path\").attr(\"d\",h.mapboxLogo.path2).style(\"opacity\",.35).style(\"enable-background\",\"new\"),d.append(\"polygon\").attr(\"points\",h.mapboxLogo.polygon).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"})}var g=p.select(\".mapboxgl-ctrl-attrib\").text().replace(\"Improve this map\",\"\"),v=e._glimages.append(\"g\"),m=v.append(\"text\");m.text(g).classed(\"static-attribution\",!0).attr({\"font-size\":12,\"font-family\":\"Arial\",color:\"rgba(0, 0, 0, 0.75)\",\"text-anchor\":\"end\",\"data-unformatted\":g});var y=l.bBox(m.node()),x=n.w*(u.x[1]-u.x[0]);if(y.width>x/2){var b=g.split(\"|\").join(\"<br>\");m.text(b).attr(\"data-unformatted\",b).call(c.convertToTspans,t),y=l.bBox(m.node())}m.attr(\"transform\",\"translate(-3, \"+(8-y.height)+\")\"),v.insert(\"rect\",\".static-attribution\").attr({x:-y.width-6,y:-y.height-3,width:y.width+6,height:y.height+3,fill:\"rgba(255, 255, 255, 0.75)\"});var _=1;y.width+6>x&&(_=x/(y.width+6));var w=[n.l+n.w*u.x[1],n.t+n.h*(1-u.y[0])];v.attr(\"transform\",\"translate(\"+w[0]+\",\"+w[1]+\") scale(\"+_+\")\")}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=0;n<r.length;n++){e[r[n]]._subplot.updateFx(e)}}},{\"../../components/drawing\":614,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/get_data\":802,\"./constants\":820,\"./layout_attributes\":824,\"./layout_defaults\":825,\"./mapbox\":826,d3:163,\"mapbox-gl\":426}],823:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./convert_text_opts\"),a=t(\"./constants\");function o(t,e){this.subplot=t,this.uid=t.uid+\"-\"+e,this.index=e,this.idSource=\"source-\"+this.uid,this.idLayer=a.layoutLayerPrefix+this.uid,this.sourceType=null,this.source=null,this.layerType=null,this.below=null,this.visible=!1}var s=o.prototype;function l(t){var e=t.source;return t.visible&&(n.isPlainObject(e)||(\"string\"==typeof e||Array.isArray(e))&&e.length>0)}function c(t){var e={},r={};switch(t.type){case\"circle\":n.extendFlat(r,{\"circle-radius\":t.circle.radius,\"circle-color\":t.color,\"circle-opacity\":t.opacity});break;case\"line\":n.extendFlat(r,{\"line-width\":t.line.width,\"line-color\":t.color,\"line-opacity\":t.opacity,\"line-dasharray\":t.line.dash});break;case\"fill\":n.extendFlat(r,{\"fill-color\":t.color,\"fill-outline-color\":t.fill.outlinecolor,\"fill-opacity\":t.opacity});break;case\"symbol\":var a=t.symbol,o=i(a.textposition,a.iconsize);n.extendFlat(e,{\"icon-image\":a.icon+\"-15\",\"icon-size\":a.iconsize/10,\"text-field\":a.text,\"text-size\":a.textfont.size,\"text-anchor\":o.anchor,\"text-offset\":o.offset,\"symbol-placement\":a.placement}),n.extendFlat(r,{\"icon-color\":t.color,\"text-color\":a.textfont.color,\"text-opacity\":t.opacity})}return{layout:e,paint:r}}s.update=function(t){this.visible?this.needsNewSource(t)?(this.removeLayer(),this.updateSource(t),this.updateLayer(t)):this.needsNewLayer(t)?this.updateLayer(t):this.updateStyle(t):(this.updateSource(t),this.updateLayer(t)),this.visible=l(t)},s.needsNewSource=function(t){return this.sourceType!==t.sourcetype||this.source!==t.source||this.layerType!==t.type},s.needsNewLayer=function(t){return this.layerType!==t.type||this.below!==this.subplot.belowLookup[\"layout-\"+this.index]},s.updateSource=function(t){var e=this.subplot.map;if(e.getSource(this.idSource)&&e.removeSource(this.idSource),this.sourceType=t.sourcetype,this.source=t.source,l(t)){var r=function(t){var e,r=t.sourcetype,n=t.source,i={type:r};\"geojson\"===r?e=\"data\":\"vector\"===r?e=\"string\"==typeof n?\"url\":\"tiles\":\"raster\"===r?(e=\"tiles\",i.tileSize=256):\"image\"===r&&(e=\"url\",i.coordinates=t.coordinates);i[e]=n,t.sourceattribution&&(i.attribution=t.sourceattribution);return i}(t);e.addSource(this.idSource,r)}},s.updateLayer=function(t){var e,r=this.subplot,n=c(t),i=this.subplot.belowLookup[\"layout-\"+this.index];if(\"traces\"===i)for(var o=r.getMapLayers(),s=0;s<o.length;s++){var u=o[s].id;if(\"string\"==typeof u&&0===u.indexOf(a.traceLayerPrefix)){e=u;break}}else e=i;this.removeLayer(),l(t)&&r.addLayer({id:this.idLayer,source:this.idSource,\"source-layer\":t.sourcelayer||\"\",type:t.type,minzoom:t.minzoom,maxzoom:t.maxzoom,layout:n.layout,paint:n.paint},e),this.layerType=t.type,this.below=i},s.updateStyle=function(t){if(l(t)){var e=c(t);this.subplot.setOptions(this.idLayer,\"setLayoutProperty\",e.layout),this.subplot.setOptions(this.idLayer,\"setPaintProperty\",e.paint)}},s.removeLayer=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer)},s.dispose=function(){var t=this.subplot.map;t.removeLayer(this.idLayer),t.removeSource(this.idSource)},e.exports=function(t,e,r){var n=new o(t,e);return n.update(r),n}},{\"../../lib\":719,\"./constants\":820,\"./convert_text_opts\":821}],824:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\").defaultLine,a=t(\"../domain\").attributes,o=t(\"../font_attributes\"),s=t(\"../../traces/scatter/attributes\").textposition,l=t(\"../../plot_api/edit_types\").overrideAll,c=t(\"../../plot_api/plot_template\").templatedArray,u=t(\"./constants\"),h=o({});h.family.dflt=\"Open Sans Regular, Arial Unicode MS Regular\",(e.exports=l({_arrayAttrRegexps:[n.counterRegex(\"mapbox\",\".layers\",!0)],domain:a({name:\"mapbox\"}),accesstoken:{valType:\"string\",noBlank:!0,strict:!0},style:{valType:\"any\",values:u.styleValuesMapbox.concat(u.styleValuesNonMapbox),dflt:u.styleValueDflt},center:{lon:{valType:\"number\",dflt:0},lat:{valType:\"number\",dflt:0}},zoom:{valType:\"number\",dflt:1},bearing:{valType:\"number\",dflt:0},pitch:{valType:\"number\",dflt:0},layers:c(\"layer\",{visible:{valType:\"boolean\",dflt:!0},sourcetype:{valType:\"enumerated\",values:[\"geojson\",\"vector\",\"raster\",\"image\"],dflt:\"geojson\"},source:{valType:\"any\"},sourcelayer:{valType:\"string\",dflt:\"\"},sourceattribution:{valType:\"string\"},type:{valType:\"enumerated\",values:[\"circle\",\"line\",\"fill\",\"symbol\",\"raster\"],dflt:\"circle\"},coordinates:{valType:\"any\"},below:{valType:\"string\"},color:{valType:\"color\",dflt:i},opacity:{valType:\"number\",min:0,max:1,dflt:1},minzoom:{valType:\"number\",min:0,max:24,dflt:0},maxzoom:{valType:\"number\",min:0,max:24,dflt:24},circle:{radius:{valType:\"number\",dflt:15}},line:{width:{valType:\"number\",dflt:2},dash:{valType:\"data_array\"}},fill:{outlinecolor:{valType:\"color\",dflt:i}},symbol:{icon:{valType:\"string\",dflt:\"marker\"},iconsize:{valType:\"number\",dflt:10},text:{valType:\"string\",dflt:\"\"},placement:{valType:\"enumerated\",values:[\"point\",\"line\",\"line-center\"],dflt:\"point\"},textfont:h,textposition:n.extendFlat({},s,{arrayOk:!1})}})},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../traces/scatter/attributes\":1112,\"../domain\":792,\"../font_attributes\":793,\"./constants\":820}],825:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../subplot_defaults\"),a=t(\"../array_container_defaults\"),o=t(\"./layout_attributes\");function s(t,e,r,n){r(\"accesstoken\",n.accessToken),r(\"style\"),r(\"center.lon\"),r(\"center.lat\"),r(\"zoom\"),r(\"bearing\"),r(\"pitch\"),a(t,e,{name:\"layers\",handleItemDefaults:l}),e._input=t}function l(t,e){function r(r,i){return n.coerce(t,e,o.layers,r,i)}if(r(\"visible\")){var i,a=r(\"sourcetype\"),s=\"raster\"===a||\"image\"===a;r(\"source\"),r(\"sourceattribution\"),\"vector\"===a&&r(\"sourcelayer\"),\"image\"===a&&r(\"coordinates\"),s&&(i=\"raster\");var l=r(\"type\",i);s&&\"raster\"!==l&&(l=e.type=\"raster\",n.log(\"Source types *raster* and *image* must drawn *raster* layer type.\")),r(\"below\"),r(\"color\"),r(\"opacity\"),r(\"minzoom\"),r(\"maxzoom\"),\"circle\"===l&&r(\"circle.radius\"),\"line\"===l&&(r(\"line.width\"),r(\"line.dash\")),\"fill\"===l&&r(\"fill.outlinecolor\"),\"symbol\"===l&&(r(\"symbol.icon\"),r(\"symbol.iconsize\"),r(\"symbol.text\"),n.coerceFont(r,\"symbol.textfont\"),r(\"symbol.textposition\"),r(\"symbol.placement\"))}}e.exports=function(t,e,r){i(t,e,r,{type:\"mapbox\",attributes:o,handleDefaults:s,partition:\"y\",accessToken:e._mapboxAccessToken})}},{\"../../lib\":719,\"../array_container_defaults\":763,\"../subplot_defaults\":842,\"./layout_attributes\":824}],826:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"d3\"),a=t(\"../../components/fx\"),o=t(\"../../lib\"),s=t(\"../../registry\"),l=t(\"../cartesian/axes\"),c=t(\"../../components/dragelement\"),u=t(\"../cartesian/select\").prepSelect,h=t(\"../cartesian/select\").selectOnClick,f=t(\"./constants\"),p=t(\"./layers\");function d(t,e){this.id=e,this.gd=t;var r=t._fullLayout,n=t._context;this.container=r._glcontainer.node(),this.isStatic=n.staticPlot,this.uid=r._uid+\"-\"+this.id,this.div=null,this.xaxis=null,this.yaxis=null,this.createFramework(r),this.map=null,this.accessToken=null,this.styleObj=null,this.traceHash={},this.layerList=[],this.belowLookup={}}var g=d.prototype;g.plot=function(t,e,r){var n,i=this,a=e[i.id];i.map&&a.accesstoken!==i.accessToken&&(i.map.remove(),i.map=null,i.styleObj=null,i.traceHash=[],i.layerList={}),n=i.map?new Promise(function(r,n){i.updateMap(t,e,r,n)}):new Promise(function(r,n){i.createMap(t,e,r,n)}),r.push(n)},g.createMap=function(t,e,r,i){var a=this,o=e[a.id],s=a.styleObj=m(o.style);a.accessToken=o.accesstoken;var l=a.map=new n.Map({container:a.div,style:s.style,center:x(o.center),zoom:o.zoom,bearing:o.bearing,pitch:o.pitch,interactive:!a.isStatic,preserveDrawingBuffer:a.isStatic,doubleClickZoom:!1,boxZoom:!1,attributionControl:!1}).addControl(new n.AttributionControl({compact:!0}));l._canvas.style.left=\"0px\",l._canvas.style.top=\"0px\",a.rejectOnError(i),a.isStatic||a.initFx(t,e);var c=[];c.push(new Promise(function(t){l.once(\"load\",t)})),c=c.concat(a.fetchMapData(t,e)),Promise.all(c).then(function(){a.fillBelowLookup(t,e),a.updateData(t),a.updateLayout(e),a.resolveOnRender(r)}).catch(i)},g.fetchMapData=function(t){var e=[];function r(t){return new Promise(function(e,r){i.json(t,function(n,i){if(n){delete PlotlyGeoAssets[t];var a=404===n.status?'GeoJSON at URL \"'+t+'\" does not exist.':\"Unexpected error while fetching from \"+t;return r(new Error(a))}PlotlyGeoAssets[t]=i,e(i)})})}for(var n=0;n<t.length;n++){var a=t[n][0].trace.geojson;\"string\"!=typeof a||PlotlyGeoAssets[a]||(PlotlyGeoAssets[a]=\"pending\",e.push(r(a)))}return e},g.updateMap=function(t,e,r,n){var i=this,a=i.map,o=e[this.id];i.rejectOnError(n);var s=[],l=m(o.style);i.styleObj.id!==l.id&&(i.styleObj=l,a.setStyle(l.style),i.traceHash={},s.push(new Promise(function(t){a.once(\"styledata\",t)}))),s=s.concat(i.fetchMapData(t,e)),Promise.all(s).then(function(){i.fillBelowLookup(t,e),i.updateData(t),i.updateLayout(e),i.resolveOnRender(r)}).catch(n)},g.fillBelowLookup=function(t,e){var r,n,i=e[this.id].layers,a=this.belowLookup={},o=!1;for(r=0;r<t.length;r++){var s=t[r][0].trace,l=s._module;\"string\"==typeof s.below?n=s.below:l.getBelow&&(n=l.getBelow(s,this)),\"\"===n&&(o=!0),a[\"trace-\"+s.uid]=n||\"\"}for(r=0;r<i.length;r++){var c=i[r];n=\"string\"==typeof c.below?c.below:o?\"traces\":\"\",a[\"layout-\"+r]=n}var u,h,f={};for(u in a)f[n=a[u]]?f[n].push(u):f[n]=[u];for(n in f){var p=f[n];if(p.length>1)for(r=0;r<p.length;r++)0===(u=p[r]).indexOf(\"trace-\")?(h=u.split(\"trace-\")[1],this.traceHash[h]&&(this.traceHash[h].below=null)):0===u.indexOf(\"layout-\")&&(h=u.split(\"layout-\")[1],this.layerList[h]&&(this.layerList[h].below=null))}};var v={choroplethmapbox:0,densitymapbox:1,scattermapbox:2};function m(t){var e={};return o.isPlainObject(t)?(e.id=t.id,e.style=t):\"string\"==typeof t?(e.id=t,-1!==f.styleValuesMapbox.indexOf(t)?e.style=y(t):f.stylesNonMapbox[t]?e.style=f.stylesNonMapbox[t]:e.style=t):(e.id=f.styleValueDflt,e.style=y(f.styleValueDflt)),e.transition={duration:0,delay:0},e}function y(t){return f.styleUrlPrefix+t+\"-\"+f.styleUrlSuffix}function x(t){return[t.lon,t.lat]}g.updateData=function(t){var e,r,n,i,a=this.traceHash,o=t.slice().sort(function(t,e){return v[t[0].trace.type]-v[e[0].trace.type]});for(n=0;n<o.length;n++){var s=o[n];(e=a[(r=s[0].trace).uid])?e.update(s):r._module&&(a[r.uid]=r._module.plot(this,s))}var l=Object.keys(a);t:for(n=0;n<l.length;n++){var c=l[n];for(i=0;i<t.length;i++)if(c===(r=t[i][0].trace).uid)continue t;(e=a[c]).dispose(),delete a[c]}},g.updateLayout=function(t){var e=this.map,r=t[this.id];e.setCenter(x(r.center)),e.setZoom(r.zoom),e.setBearing(r.bearing),e.setPitch(r.pitch),this.updateLayers(t),this.updateFramework(t),this.updateFx(t),this.map.resize(),this.gd._context._scrollZoom.mapbox?e.scrollZoom.enable():e.scrollZoom.disable()},g.resolveOnRender=function(t){var e=this.map;e.on(\"render\",function r(){e.loaded()&&(e.off(\"render\",r),setTimeout(t,0))})},g.rejectOnError=function(t){var e=this.map;function r(){t(new Error(f.mapOnErrorMsg))}e.once(\"error\",r),e.once(\"style.error\",r),e.once(\"source.error\",r),e.once(\"tile.error\",r),e.once(\"layer.error\",r)},g.createFramework=function(t){var e=this,r=e.div=document.createElement(\"div\");r.id=e.uid,r.style.position=\"absolute\",e.container.appendChild(r),e.xaxis={_id:\"x\",c2p:function(t){return e.project(t).x}},e.yaxis={_id:\"y\",c2p:function(t){return e.project(t).y}},e.updateFramework(t),e.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},l.setConvert(e.mockAxis,t)},g.initFx=function(t,e){var r=this,n=r.gd,i=r.map,o=!1;function l(){a.loneUnhover(e._hoverlayer)}function c(){var t=r.getView();n.emit(\"plotly_relayouting\",r.getViewEdits(t))}i.on(\"moveend\",function(t){if(r.map){var e=n._fullLayout;if(t.originalEvent||o){var i=e[r.id];s.call(\"_storeDirectGUIEdit\",n.layout,e._preGUI,r.getViewEdits(i));var a=r.getView();i._input.center=i.center=a.center,i._input.zoom=i.zoom=a.zoom,i._input.bearing=i.bearing=a.bearing,i._input.pitch=i.pitch=a.pitch,n.emit(\"plotly_relayout\",r.getViewEdits(a))}o=!1,e._rehover&&e._rehover()}}),i.on(\"wheel\",function(){o=!0}),i.on(\"mousemove\",function(t){var e=r.div.getBoundingClientRect();t.clientX=t.point.x+e.left,t.clientY=t.point.y+e.top,t.target.getBoundingClientRect=function(){return e},r.xaxis.p2c=function(){return t.lngLat.lng},r.yaxis.p2c=function(){return t.lngLat.lat},n._fullLayout._rehover=function(){n._fullLayout._hoversubplot===r.id&&a.hover(n,t,r.id)},a.hover(n,t,r.id),n._fullLayout._hoversubplot=r.id}),i.on(\"dragstart\",l),i.on(\"zoomstart\",l),i.on(\"mouseout\",function(){n._fullLayout._hoversubplot=null}),i.on(\"drag\",c),i.on(\"zoom\",c),i.on(\"dblclick\",function(){var t=n._fullLayout[r.id];s.call(\"_storeDirectGUIEdit\",n.layout,n._fullLayout._preGUI,r.getViewEdits(t));var e=r.viewInitial;i.setCenter(x(e.center)),i.setZoom(e.zoom),i.setBearing(e.bearing),i.setPitch(e.pitch);var a=r.getView();t._input.center=t.center=a.center,t._input.zoom=t.zoom=a.zoom,t._input.bearing=t.bearing=a.bearing,t._input.pitch=t.pitch=a.pitch,n.emit(\"plotly_doubleclick\",null),n.emit(\"plotly_relayout\",r.getViewEdits(a))}),r.clearSelect=function(){n._fullLayout._zoomlayer.selectAll(\".select-outline\").remove()},r.onClickInPanFn=function(t){return function(e){var i=n._fullLayout.clickmode;i.indexOf(\"select\")>-1&&h(e.originalEvent,n,[r.xaxis],[r.yaxis],r.id,t),i.indexOf(\"event\")>-1&&a.click(n,e.originalEvent)}}},g.updateFx=function(t){var e=this,r=e.map,n=e.gd;if(!e.isStatic){var i,a=t.dragmode;i=\"select\"===a?function(t,r){(t.range={})[e.id]=[l([r.xmin,r.ymin]),l([r.xmax,r.ymax])]}:function(t,r,n){(t.lassoPoints={})[e.id]=n.filtered.map(l)};var s=e.dragOptions;e.dragOptions=o.extendDeep(s||{},{element:e.div,gd:n,plotinfo:{id:e.id,xaxis:e.xaxis,yaxis:e.yaxis,fillRangeItems:i},xaxes:[e.xaxis],yaxes:[e.yaxis],subplot:e.id}),r.off(\"click\",e.onClickInPanHandler),\"select\"===a||\"lasso\"===a?(r.dragPan.disable(),r.on(\"zoomstart\",e.clearSelect),e.dragOptions.prepFn=function(t,r,n){u(t,r,n,e.dragOptions,a)},c.init(e.dragOptions)):(r.dragPan.enable(),r.off(\"zoomstart\",e.clearSelect),e.div.onmousedown=null,e.onClickInPanHandler=e.onClickInPanFn(e.dragOptions),r.on(\"click\",e.onClickInPanHandler))}function l(t){var r=e.map.unproject(t);return[r.lng,r.lat]}},g.updateFramework=function(t){var e=t[this.id].domain,r=t._size,n=this.div.style;n.width=r.w*(e.x[1]-e.x[0])+\"px\",n.height=r.h*(e.y[1]-e.y[0])+\"px\",n.left=r.l+e.x[0]*r.w+\"px\",n.top=r.t+(1-e.y[1])*r.h+\"px\",this.xaxis._offset=r.l+e.x[0]*r.w,this.xaxis._length=r.w*(e.x[1]-e.x[0]),this.yaxis._offset=r.t+(1-e.y[1])*r.h,this.yaxis._length=r.h*(e.y[1]-e.y[0])},g.updateLayers=function(t){var e,r=t[this.id].layers,n=this.layerList;if(r.length!==n.length){for(e=0;e<n.length;e++)n[e].dispose();for(n=this.layerList=[],e=0;e<r.length;e++)n.push(p(this,e,r[e]))}else for(e=0;e<r.length;e++)n[e].update(r[e])},g.destroy=function(){this.map&&(this.map.remove(),this.map=null,this.container.removeChild(this.div))},g.toImage=function(){return this.map.stop(),this.map.getCanvas().toDataURL()},g.setOptions=function(t,e,r){for(var n in r)this.map[e](t,n,r[n])},g.getMapLayers=function(){return this.map.getStyle().layers},g.addLayer=function(t,e){var r=this.map;if(\"string\"==typeof e){if(\"\"===e)return void r.addLayer(t,e);for(var n=this.getMapLayers(),i=0;i<n.length;i++)if(e===n[i].id)return void r.addLayer(t,e);o.warn([\"Trying to add layer with *below* value\",e,\"referencing a layer that does not exist\",\"or that does not yet exist.\"].join(\" \"))}r.addLayer(t)},g.project=function(t){return this.map.project(new n.LngLat(t[0],t[1]))},g.getView=function(){var t=this.map,e=t.getCenter();return{center:{lon:e.lng,lat:e.lat},zoom:t.getZoom(),bearing:t.getBearing(),pitch:t.getPitch()}},g.getViewEdits=function(t){for(var e=this.id,r=[\"center\",\"zoom\",\"bearing\",\"pitch\"],n={},i=0;i<r.length;i++){var a=r[i];n[e+\".\"+a]=t[a]}return n},e.exports=d},{\"../../components/dragelement\":611,\"../../components/fx\":632,\"../../lib\":719,\"../../registry\":847,\"../cartesian/axes\":767,\"../cartesian/select\":784,\"./constants\":820,\"./layers\":823,d3:163,\"mapbox-gl\":426}],827:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType;return{t:{valType:\"number\",dflt:0,editType:e},r:{valType:\"number\",dflt:0,editType:e},b:{valType:\"number\",dflt:0,editType:e},l:{valType:\"number\",dflt:0,editType:e},editType:e}}},{}],828:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../registry\"),o=t(\"../plot_api/plot_schema\"),s=t(\"../plot_api/plot_template\"),l=t(\"../lib\"),c=t(\"../components/color\"),u=t(\"../constants/numerical\").BADNUM,h=t(\"./cartesian/axis_ids\"),f=t(\"./animation_attributes\"),p=t(\"./frame_attributes\"),d=l.relinkPrivateKeys,g=l._,v=e.exports={};l.extendFlat(v,a),v.attributes=t(\"./attributes\"),v.attributes.type.values=v.allTypes,v.fontAttrs=t(\"./font_attributes\"),v.layoutAttributes=t(\"./layout_attributes\"),v.fontWeight=\"normal\";var m=v.transformsRegistry,y=t(\"./command\");v.executeAPICommand=y.executeAPICommand,v.computeAPICommandBindings=y.computeAPICommandBindings,v.manageCommandObserver=y.manageCommandObserver,v.hasSimpleAPICommandBindings=y.hasSimpleAPICommandBindings,v.redrawText=function(t){var e=(t=l.getGraphDiv(t))._fullLayout||{};if(!(!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r))return new Promise(function(e){setTimeout(function(){a.getComponentMethod(\"annotations\",\"draw\")(t),a.getComponentMethod(\"legend\",\"draw\")(t),a.getComponentMethod(\"colorbar\",\"draw\")(t),e(v.previousPromises(t))},300)})},v.resize=function(t){return t=l.getGraphDiv(t),new Promise(function(e,r){t&&!l.isHidden(t)||r(new Error(\"Resize must be passed a displayed plot div element.\")),t._redrawTimer&&clearTimeout(t._redrawTimer),t._redrawTimer=setTimeout(function(){if(!t.layout||t.layout.width&&t.layout.height||l.isHidden(t))e(t);else{delete t.layout.width,delete t.layout.height;var r=t.changed;t.autoplay=!0,a.call(\"relayout\",t,{autosize:!0}).then(function(){t.changed=r,e(t)})}},100)})},v.previousPromises=function(t){if((t._promises||[]).length)return Promise.all(t._promises).then(function(){t._promises=[]})},v.addLinks=function(t){if(t._context.showLink||t._context.showSources){var e=t._fullLayout,r=l.ensureSingle(e._paper,\"text\",\"js-plot-link-container\",function(t){t.style({\"font-family\":'\"Open Sans\", Arial, sans-serif',\"font-size\":\"12px\",fill:c.defaultLine,\"pointer-events\":\"all\"}).each(function(){var t=n.select(this);t.append(\"tspan\").classed(\"js-link-to-tool\",!0),t.append(\"tspan\").classed(\"js-link-spacer\",!0),t.append(\"tspan\").classed(\"js-sourcelinks\",!0)})}),i=r.node(),a={y:e._paper.attr(\"height\")-9};document.body.contains(i)&&i.getComputedTextLength()>=e.width-20?(a[\"text-anchor\"]=\"start\",a.x=5):(a[\"text-anchor\"]=\"end\",a.x=e._paper.attr(\"width\")-7),r.attr(a);var o=r.select(\".js-link-to-tool\"),s=r.select(\".js-link-spacer\"),u=r.select(\".js-sourcelinks\");t._context.showSources&&t._context.showSources(t),t._context.showLink&&function(t,e){e.text(\"\");var r=e.append(\"a\").attr({\"xlink:xlink:href\":\"#\",class:\"link--impt link--embedview\",\"font-weight\":\"bold\"}).text(t._context.linkText+\" \"+String.fromCharCode(187));if(t._context.sendData)r.on(\"click\",function(){v.sendDataToCloud(t)});else{var n=window.location.pathname.split(\"/\"),i=window.location.search;r.attr({\"xlink:xlink:show\":\"new\",\"xlink:xlink:href\":\"/\"+n[2].split(\".\")[0]+\"/\"+n[1]+i})}}(t,o),s.text(o.text()&&u.text()?\" - \":\"\")}},v.sendDataToCloud=function(t){t.emit(\"plotly_beforeexport\");var e=(window.PLOTLYENV||{}).BASE_URL||t._context.plotlyServerURL,r=n.select(t).append(\"div\").attr(\"id\",\"hiddenform\").style(\"display\",\"none\"),i=r.append(\"form\").attr({action:e+\"/external\",method:\"post\",target:\"_blank\"});return i.append(\"input\").attr({type:\"text\",name:\"data\"}).node().value=v.graphJson(t,!1,\"keepdata\"),i.node().submit(),r.remove(),t.emit(\"plotly_afterexport\"),!1};var x=[\"days\",\"shortDays\",\"months\",\"shortMonths\",\"periods\",\"dateTime\",\"date\",\"time\",\"decimal\",\"thousands\",\"grouping\",\"currency\"],b=[\"year\",\"month\",\"dayMonth\",\"dayMonthYear\"];function _(t,e){var r=t._context.locale,n=!1,i={};function o(t){for(var r=!0,a=0;a<e.length;a++){var o=e[a];i[o]||(t[o]?i[o]=t[o]:r=!1)}r&&(n=!0)}for(var s=0;s<2;s++){for(var l=t._context.locales,c=0;c<2;c++){var u=(l[r]||{}).format;if(u&&(o(u),n))break;l=a.localeRegistry}var h=r.split(\"-\")[0];if(n||h===r)break;r=h}return n||o(a.localeRegistry.en.format),i}function w(t,e){var r={_fullLayout:e},n=\"x\"===t._id.charAt(0),i=t._mainAxis._anchorAxis,a=\"\",o=\"\",s=\"\";if(i&&(s=i._mainAxis._id,a=n?t._id+s:s+t._id),!a||!e._plots[a]){a=\"\";for(var l=t._counterAxes,c=0;c<l.length;c++){var u=l[c],f=n?t._id+u:u+t._id;o||(o=f);var p=h.getFromId(r,u);if(s&&p.overlaying===s){a=f;break}}}return a||o}function k(t){var e=t.transforms;if(Array.isArray(e)&&e.length)for(var r=0;r<e.length;r++){var n=e[r],i=n._module||m[n.type];if(i&&i.makesData)return!0}return!1}function T(t,e,r,n){for(var i=t.transforms,a=[t],o=0;o<i.length;o++){var s=i[o],l=m[s.type];l&&l.transform&&(a=l.transform(a,{transform:s,fullTrace:t,fullData:e,layout:r,fullLayout:n,transformIndex:o}))}return a}function A(t){var e=t.margin;if(!t._size){var r=t._size={l:Math.round(e.l),r:Math.round(e.r),t:Math.round(e.t),b:Math.round(e.b),p:Math.round(e.pad)};r.w=Math.round(t.width)-r.l-r.r,r.h=Math.round(t.height)-r.t-r.b}t._pushmargin||(t._pushmargin={}),t._pushmarginIds||(t._pushmarginIds={})}v.supplyDefaults=function(t,e){var r=e&&e.skipUpdateCalc,i=t._fullLayout||{};if(i._skipDefaults)delete i._skipDefaults;else{var o,s=t._fullLayout={},c=t.layout||{},u=t._fullData||[],h=t._fullData=[],f=t.data||[],p=t.calcdata||[],m=t._context||{};t._transitionData||v.createTransitionData(t),s._dfltTitle={plot:g(t,\"Click to enter Plot title\"),x:g(t,\"Click to enter X axis title\"),y:g(t,\"Click to enter Y axis title\"),colorbar:g(t,\"Click to enter Colorscale title\"),annotation:g(t,\"new text\")},s._traceWord=g(t,\"trace\");var y=_(t,x);if(s._mapboxAccessToken=m.mapboxAccessToken,i._initialAutoSizeIsDone){var w=i.width,k=i.height;v.supplyLayoutGlobalDefaults(c,s,y),c.width||(s.width=w),c.height||(s.height=k),v.sanitizeMargins(s)}else{v.supplyLayoutGlobalDefaults(c,s,y);var T=!c.width||!c.height,M=s.autosize,S=m.autosizable;T&&(M||S)?v.plotAutoSize(t,c,s):T&&v.sanitizeMargins(s),!M&&T&&(c.width=s.width,c.height=s.height)}s._d3locale=function(t,e){return t.decimal=e.charAt(0),t.thousands=e.charAt(1),n.locale(t)}(y,s.separators),s._extraFormat=_(t,b),s._initialAutoSizeIsDone=!0,s._dataLength=f.length,s._modules=[],s._visibleModules=[],s._basePlotModules=[];var E=s._subplots=function(){var t,e,r=a.collectableSubplotTypes,n={};if(!r){r=[];var i=a.subplotsRegistry;for(var o in i){var s=i[o],c=s.attr;if(c&&(r.push(o),Array.isArray(c)))for(e=0;e<c.length;e++)l.pushUnique(r,c[e])}}for(t=0;t<r.length;t++)n[r[t]]=[];return n}(),C=s._splomAxes={x:{},y:{}},L=s._splomSubplots={};s._splomGridDflt={},s._scatterStackOpts={},s._firstScatter={},s._alignmentOpts={},s._colorAxes={},s._requestRangeslider={},s._traceUids=function(t,e){var r,n,i=e.length,a=[];for(r=0;r<t.length;r++){var o=t[r]._fullInput;o!==n&&a.push(o),n=o}var s=a.length,c=new Array(i),u={};function h(t,e){c[e]=t,u[t]=1}function f(t,e){if(t&&\"string\"==typeof t&&!u[t])return h(t,e),!0}for(r=0;r<i;r++){var p=e[r].uid;\"number\"==typeof p&&(p=String(p)),f(p,r)||(r<s&&f(a[r].uid,r)||h(l.randstr(u),r))}return c}(u,f),s._globalTransforms=(t._context||{}).globalTransforms,v.supplyDataDefaults(f,h,c,s);var P=Object.keys(C.x),O=Object.keys(C.y);if(P.length>1&&O.length>1){for(a.getComponentMethod(\"grid\",\"sizeDefaults\")(c,s),o=0;o<P.length;o++)l.pushUnique(E.xaxis,P[o]);for(o=0;o<O.length;o++)l.pushUnique(E.yaxis,O[o]);for(var z in L)l.pushUnique(E.cartesian,z)}if(s._has=v._hasPlotType.bind(s),u.length===h.length)for(o=0;o<h.length;o++)d(h[o],u[o]);v.supplyLayoutModuleDefaults(c,s,h,t._transitionData);var I=s._visibleModules,D=[];for(o=0;o<I.length;o++){var R=I[o].crossTraceDefaults;R&&l.pushUnique(D,R)}for(o=0;o<D.length;o++)D[o](h,s);s._hasOnlyLargeSploms=1===s._basePlotModules.length&&\"splom\"===s._basePlotModules[0].name&&P.length>15&&O.length>15&&0===s.shapes.length&&0===s.images.length,s._hasCartesian=s._has(\"cartesian\"),s._hasGeo=s._has(\"geo\"),s._hasGL3D=s._has(\"gl3d\"),s._hasGL2D=s._has(\"gl2d\"),s._hasTernary=s._has(\"ternary\"),s._hasPie=s._has(\"pie\"),v.linkSubplots(h,s,u,i),v.cleanPlot(h,s,u,i),i._zoomlayer&&!t._dragging&&i._zoomlayer.selectAll(\".select-outline\").remove(),function(t,e){var r,n=[];e.meta&&(r=e._meta={meta:e.meta,layout:{meta:e.meta}});for(var i=0;i<t.length;i++){var a=t[i];a.meta?n[a.index]=a._meta={meta:a.meta}:e.meta&&(a._meta={meta:e.meta}),e.meta&&(a._meta.layout={meta:e.meta})}n.length&&(r||(r=e._meta={}),r.data=n)}(h,s),d(s,i),a.getComponentMethod(\"colorscale\",\"crossTraceDefaults\")(h,s),s._preGUI||(s._preGUI={}),s._tracePreGUI||(s._tracePreGUI={});var F,B=s._tracePreGUI,N={};for(F in B)N[F]=\"old\";for(o=0;o<h.length;o++)N[F=h[o]._fullInput.uid]||(B[F]={}),N[F]=\"new\";for(F in N)\"old\"===N[F]&&delete B[F];A(s),a.getComponentMethod(\"rangeslider\",\"makeData\")(s),r||p.length!==h.length||v.supplyDefaultsUpdateCalc(p,h)}},v.supplyDefaultsUpdateCalc=function(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=(t[r]||[])[0];if(i&&i.trace){var a=i.trace;if(a._hasCalcTransform){var o,s,c,u=a._arrayAttrs;for(o=0;o<u.length;o++)s=u[o],c=l.nestedProperty(a,s).get().slice(),l.nestedProperty(n,s).set(c)}i.trace=n}}},v.createTransitionData=function(t){t._transitionData||(t._transitionData={}),t._transitionData._frames||(t._transitionData._frames=[]),t._transitionData._frameHash||(t._transitionData._frameHash={}),t._transitionData._counter||(t._transitionData._counter=0),t._transitionData._interruptCallbacks||(t._transitionData._interruptCallbacks=[])},v._hasPlotType=function(t){var e,r=this._basePlotModules||[];for(e=0;e<r.length;e++)if(r[e].name===t)return!0;var n=this._modules||[];for(e=0;e<n.length;e++){var i=n[e].name;if(i===t)return!0;var o=a.modules[i];if(o&&o.categories[t])return!0}return!1},v.cleanPlot=function(t,e,r,n){var i,a,o=n._basePlotModules||[];for(i=0;i<o.length;i++){var s=o[i];s.clean&&s.clean(t,e,r,n)}var l=n._has&&n._has(\"gl\"),c=e._has&&e._has(\"gl\");l&&!c&&void 0!==n._glcontainer&&(n._glcontainer.selectAll(\".gl-canvas\").remove(),n._glcontainer.selectAll(\".no-webgl\").remove(),n._glcanvas=null);var u=!!n._infolayer;t:for(i=0;i<r.length;i++){var h=r[i].uid;for(a=0;a<t.length;a++){if(h===t[a].uid)continue t}u&&n._infolayer.select(\".cb\"+h).remove()}},v.linkSubplots=function(t,e,r,n){var i,a,o=n._plots||{},s=e._plots={},c=e._subplots,u={_fullData:t,_fullLayout:e},f=c.cartesian.concat(c.gl2d||[]);for(i=0;i<f.length;i++){var p,d=f[i],g=o[d],v=h.getFromId(u,d,\"x\"),m=h.getFromId(u,d,\"y\");for(g?p=s[d]=g:(p=s[d]={}).id=d,v._counterAxes.push(m._id),m._counterAxes.push(v._id),v._subplotsWith.push(d),m._subplotsWith.push(d),p.xaxis=v,p.yaxis=m,p._hasClipOnAxisFalse=!1,a=0;a<t.length;a++){var y=t[a];if(y.xaxis===p.xaxis._id&&y.yaxis===p.yaxis._id&&!1===y.cliponaxis){p._hasClipOnAxisFalse=!0;break}}}var x,b=h.list(u,null,!0);for(i=0;i<b.length;i++){var _=null;(x=b[i]).overlaying&&(_=h.getFromId(u,x.overlaying))&&_.overlaying&&(x.overlaying=!1,_=null),x._mainAxis=_||x,_&&(x.domain=_.domain.slice()),x._anchorAxis=\"free\"===x.anchor?null:h.getFromId(u,x.anchor)}for(i=0;i<b.length;i++)(x=b[i])._counterAxes.sort(h.idSort),x._subplotsWith.sort(l.subplotSort),x._mainSubplot=w(x,e)},v.clearExpandedTraceDefaultColors=function(t){var e,r,n;for(r=[],(e=t._module._colorAttrs)||(t._module._colorAttrs=e=[],o.crawl(t._module.attributes,function(t,n,i,a){r[a]=n,r.length=a+1,\"color\"===t.valType&&void 0===t.dflt&&e.push(r.join(\".\"))})),n=0;n<e.length;n++){l.nestedProperty(t,\"_input.\"+e[n]).get()||l.nestedProperty(t,e[n]).set(null)}},v.supplyDataDefaults=function(t,e,r,n){var i,o,c,u=n._modules,h=n._visibleModules,f=n._basePlotModules,p=0,g=0;function m(t){e.push(t);var r=t._module;r&&(l.pushUnique(u,r),!0===t.visible&&l.pushUnique(h,r),l.pushUnique(f,t._module.basePlotModule),p++,!1!==t._input.visible&&g++)}n._transformModules=[];var y={},x=[],b=(r.template||{}).data||{},_=s.traceTemplater(b);for(i=0;i<t.length;i++){if(c=t[i],(o=_.newTrace(c)).uid=n._traceUids[i],v.supplyTraceDefaults(c,o,g,n,i),o.index=i,o._input=c,o._expandedIndex=p,o.transforms&&o.transforms.length)for(var w=!1!==c.visible&&!1===o.visible,k=T(o,e,r,n),A=0;A<k.length;A++){var M=k[A],S={_template:o._template,type:o.type,uid:o.uid+A};w&&!1===M.visible&&delete M.visible,v.supplyTraceDefaults(M,S,p,n,i),d(S,M),S.index=i,S._input=c,S._fullInput=o,S._expandedIndex=p,S._expandedInput=M,m(S)}else o._fullInput=o,o._expandedInput=o,m(o);a.traceIs(o,\"carpetAxis\")&&(y[o.carpet]=o),a.traceIs(o,\"carpetDependent\")&&x.push(i)}for(i=0;i<x.length;i++)if((o=e[x[i]]).visible){var E=y[o.carpet];o._carpet=E,E&&E.visible?(o.xaxis=E.xaxis,o.yaxis=E.yaxis):o.visible=!1}},v.supplyAnimationDefaults=function(t){var e;t=t||{};var r={};function n(e,n){return l.coerce(t||{},r,f,e,n)}if(n(\"mode\"),n(\"direction\"),n(\"fromcurrent\"),Array.isArray(t.frame))for(r.frame=[],e=0;e<t.frame.length;e++)r.frame[e]=v.supplyAnimationFrameDefaults(t.frame[e]||{});else r.frame=v.supplyAnimationFrameDefaults(t.frame||{});if(Array.isArray(t.transition))for(r.transition=[],e=0;e<t.transition.length;e++)r.transition[e]=v.supplyAnimationTransitionDefaults(t.transition[e]||{});else r.transition=v.supplyAnimationTransitionDefaults(t.transition||{});return r},v.supplyAnimationFrameDefaults=function(t){var e={};function r(r,n){return l.coerce(t||{},e,f.frame,r,n)}return r(\"duration\"),r(\"redraw\"),e},v.supplyAnimationTransitionDefaults=function(t){var e={};function r(r,n){return l.coerce(t||{},e,f.transition,r,n)}return r(\"duration\"),r(\"easing\"),e},v.supplyFrameDefaults=function(t){var e={};function r(r,n){return l.coerce(t,e,p,r,n)}return r(\"group\"),r(\"name\"),r(\"traces\"),r(\"baseframe\"),r(\"data\"),r(\"layout\"),e},v.supplyTraceDefaults=function(t,e,r,n,i){var o,s=n.colorway||c.defaults,u=s[r%s.length];function h(r,n){return l.coerce(t,e,v.attributes,r,n)}var f=h(\"visible\");h(\"type\"),h(\"name\",n._traceWord+\" \"+i),h(\"uirevision\",n.uirevision);var p=v.getModule(e);if(e._module=p,p){var d=p.basePlotModule,g=d.attr,m=d.attributes;if(g&&m){var y=n._subplots,x=\"\";if(\"gl2d\"!==d.name||f){if(Array.isArray(g))for(o=0;o<g.length;o++){var b=g[o],_=l.coerce(t,e,m,b);y[b]&&l.pushUnique(y[b],_),x+=_}else x=l.coerce(t,e,m,g);y[d.name]&&l.pushUnique(y[d.name],x)}}}return f&&(h(\"customdata\"),h(\"ids\"),h(\"meta\"),a.traceIs(e,\"showLegend\")?(e._dfltShowLegend=!0,h(\"showlegend\"),h(\"legendgroup\")):e._dfltShowLegend=!1,p&&p.supplyDefaults(t,e,u,n),a.traceIs(e,\"noOpacity\")||h(\"opacity\"),a.traceIs(e,\"notLegendIsolatable\")&&(e.visible=!!e.visible),a.traceIs(e,\"noHover\")||(e.hovertemplate||l.coerceHoverinfo(t,e,n),\"parcats\"!==e.type&&a.getComponentMethod(\"fx\",\"supplyDefaults\")(t,e,u,n)),p&&p.selectPoints&&h(\"selectedpoints\"),v.supplyTransformDefaults(t,e,n)),e},v.hasMakesDataTransform=k,v.supplyTransformDefaults=function(t,e,r){if(e._length||k(t)){var n=r._globalTransforms||[],i=r._transformModules||[];if(Array.isArray(t.transforms)||0!==n.length)for(var a=t.transforms||[],o=n.concat(a),s=e.transforms=[],c=0;c<o.length;c++){var u,h=o[c],f=h.type,p=m[f],d=!(h._module&&h._module===p),g=p&&\"function\"==typeof p.transform;p||l.warn(\"Unrecognized transform type \"+f+\".\"),p&&p.supplyDefaults&&(d||g)?((u=p.supplyDefaults(h,e,r,t)).type=f,u._module=p,l.pushUnique(i,p)):u=l.extendFlat({},h),s.push(u)}}},v.supplyLayoutGlobalDefaults=function(t,e,r){function n(r,n){return l.coerce(t,e,v.layoutAttributes,r,n)}var i=t.template;l.isPlainObject(i)&&(e.template=i,e._template=i.layout,e._dataTemplate=i.data);var o=l.coerceFont(n,\"font\");n(\"title.text\",e._dfltTitle.plot),l.coerceFont(n,\"title.font\",{family:o.family,size:Math.round(1.4*o.size),color:o.color}),n(\"title.xref\"),n(\"title.yref\"),n(\"title.x\"),n(\"title.y\"),n(\"title.xanchor\"),n(\"title.yanchor\"),n(\"title.pad.t\"),n(\"title.pad.r\"),n(\"title.pad.b\"),n(\"title.pad.l\"),n(\"autosize\",!(t.width&&t.height)),n(\"width\"),n(\"height\"),n(\"margin.l\"),n(\"margin.r\"),n(\"margin.t\"),n(\"margin.b\"),n(\"margin.pad\"),n(\"margin.autoexpand\"),t.width&&t.height&&v.sanitizeMargins(e),a.getComponentMethod(\"grid\",\"sizeDefaults\")(t,e),n(\"paper_bgcolor\"),n(\"separators\",r.decimal+r.thousands),n(\"hidesources\"),n(\"colorway\"),n(\"datarevision\");var s=n(\"uirevision\");n(\"editrevision\",s),n(\"selectionrevision\",s),n(\"modebar.orientation\"),n(\"modebar.bgcolor\",c.addOpacity(e.paper_bgcolor,.5));var u=c.contrast(c.rgb(e.modebar.bgcolor));n(\"modebar.color\",c.addOpacity(u,.3)),n(\"modebar.activecolor\",c.addOpacity(u,.7)),n(\"modebar.uirevision\",s),n(\"meta\"),l.isPlainObject(t.transition)&&(n(\"transition.duration\"),n(\"transition.easing\"),n(\"transition.ordering\")),a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\"),a.getComponentMethod(\"fx\",\"supplyLayoutGlobalDefaults\")(t,e,n)},v.plotAutoSize=function(t,e,r){var n,a,o=t._context||{},s=o.frameMargins,c=l.isPlotDiv(t);if(c&&t.emit(\"plotly_autosize\"),o.fillFrame)n=window.innerWidth,a=window.innerHeight,document.body.style.overflow=\"hidden\";else{var u=c?window.getComputedStyle(t):{};if(n=parseFloat(u.width)||parseFloat(u.maxWidth)||r.width,a=parseFloat(u.height)||parseFloat(u.maxHeight)||r.height,i(s)&&s>0){var h=1-2*s;n=Math.round(h*n),a=Math.round(h*a)}}var f=v.layoutAttributes.width.min,p=v.layoutAttributes.height.min;n<f&&(n=f),a<p&&(a=p);var d=!e.width&&Math.abs(r.width-n)>1,g=!e.height&&Math.abs(r.height-a)>1;(g||d)&&(d&&(r.width=n),g&&(r.height=a)),t._initialAutoSize||(t._initialAutoSize={width:n,height:a}),v.sanitizeMargins(r)},v.supplyLayoutModuleDefaults=function(t,e,r,n){var i,o,s,c=a.componentsRegistry,u=e._basePlotModules,h=a.subplotsRegistry.cartesian;for(i in c)(s=c[i]).includeBasePlot&&s.includeBasePlot(t,e);for(var f in u.length||u.push(h),e._has(\"cartesian\")&&(a.getComponentMethod(\"grid\",\"contentDefaults\")(t,e),h.finalizeSubplots(t,e)),e._subplots)e._subplots[f].sort(l.subplotSort);for(o=0;o<u.length;o++)(s=u[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var p=e._modules;for(o=0;o<p.length;o++)(s=p[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var d=e._transformModules;for(o=0;o<d.length;o++)(s=d[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r,n);for(i in c)(s=c[i]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r)},v.purge=function(t){var e=t._fullLayout||{};void 0!==e._glcontainer&&(e._glcontainer.selectAll(\".gl-canvas\").remove(),e._glcontainer.remove(),e._glcanvas=null),void 0!==e._geocontainer&&e._geocontainer.remove(),e._modeBar&&e._modeBar.destroy(),t._transitionData&&(t._transitionData._interruptCallbacks&&(t._transitionData._interruptCallbacks.length=0),t._transitionData._animationRaf&&window.cancelAnimationFrame(t._transitionData._animationRaf)),l.clearThrottle(),l.clearResponsive(t),delete t.data,delete t.layout,delete t._fullData,delete t._fullLayout,delete t.calcdata,delete t.framework,delete t.empty,delete t.fid,delete t.undoqueue,delete t.undonum,delete t.autoplay,delete t.changed,delete t._promises,delete t._redrawTimer,delete t._hmlumcount,delete t._hmpixcount,delete t._transitionData,delete t._transitioning,delete t._initialAutoSize,delete t._transitioningWithDuration,delete t._dragging,delete t._dragged,delete t._dragdata,delete t._hoverdata,delete t._snapshotInProgress,delete t._editing,delete t._mouseDownTime,delete t._legendMouseDownTime,t.removeAllListeners&&t.removeAllListeners()},v.style=function(t){var e,r=t._fullLayout._visibleModules,n=[];for(e=0;e<r.length;e++){var i=r[e];i.style&&l.pushUnique(n,i.style)}for(e=0;e<n.length;e++)n[e](t)},v.sanitizeMargins=function(t){if(t&&t.margin){var e,r=t.width,n=t.height,i=t.margin,a=r-(i.l+i.r),o=n-(i.t+i.b);a<0&&(e=(r-1)/(i.l+i.r),i.l=Math.floor(e*i.l),i.r=Math.floor(e*i.r)),o<0&&(e=(n-1)/(i.t+i.b),i.t=Math.floor(e*i.t),i.b=Math.floor(e*i.b))}},v.clearAutoMarginIds=function(t){t._fullLayout._pushmarginIds={}},v.allowAutoMargin=function(t,e){t._fullLayout._pushmarginIds[e]=1},v.autoMargin=function(t,e,r){var n=t._fullLayout,i=n._pushmargin,a=n._pushmarginIds;if(!1!==n.margin.autoexpand){if(r){var o=r.pad;if(void 0===o){var s=n.margin;o=Math.min(12,s.l,s.r,s.t,s.b)}r.l+r.r>.5*n.width&&(r.l=r.r=0),r.b+r.t>.5*n.height&&(r.b=r.t=0);var l=void 0!==r.xl?r.xl:r.x,c=void 0!==r.xr?r.xr:r.x,u=void 0!==r.yt?r.yt:r.y,h=void 0!==r.yb?r.yb:r.y;i[e]={l:{val:l,size:r.l+o},r:{val:c,size:r.r+o},b:{val:h,size:r.b+o},t:{val:u,size:r.t+o}},a[e]=1}else delete i[e],delete a[e];n._replotting||v.doAutoMargin(t)}},v.doAutoMargin=function(t){var e=t._fullLayout;e._size||(e._size={}),A(e);var r=e._size,n=e.margin,o=l.extendFlat({},r),s=n.l,c=n.r,u=n.t,h=n.b,f=e.width,p=e.height,d=e._pushmargin,g=e._pushmarginIds;if(!1!==e.margin.autoexpand){for(var m in d)g[m]||delete d[m];for(var y in d.base={l:{val:0,size:s},r:{val:1,size:c},t:{val:1,size:u},b:{val:0,size:h}},d){var x=d[y].l||{},b=d[y].b||{},_=x.val,w=x.size,k=b.val,T=b.size;for(var M in d){if(i(w)&&d[M].r){var S=d[M].r.val,E=d[M].r.size;if(S>_){var C=(w*S+(E-f)*_)/(S-_),L=(E*(1-_)+(w-f)*(1-S))/(S-_);C>=0&&L>=0&&f-(C+L)>0&&C+L>s+c&&(s=C,c=L)}}if(i(T)&&d[M].t){var P=d[M].t.val,O=d[M].t.size;if(P>k){var z=(T*P+(O-p)*k)/(P-k),I=(O*(1-k)+(T-p)*(1-P))/(P-k);z>=0&&I>=0&&p-(I+z)>0&&z+I>h+u&&(h=z,u=I)}}}}}if(r.l=Math.round(s),r.r=Math.round(c),r.t=Math.round(u),r.b=Math.round(h),r.p=Math.round(n.pad),r.w=Math.round(f)-r.l-r.r,r.h=Math.round(p)-r.t-r.b,!e._replotting&&v.didMarginChange(o,r))return\"_redrawFromAutoMarginCount\"in e?e._redrawFromAutoMarginCount++:e._redrawFromAutoMarginCount=1,a.call(\"plot\",t)};var M=[\"l\",\"r\",\"t\",\"b\",\"p\",\"w\",\"h\"];function S(t,e,r){var n=!1;var i=[v.previousPromises,function(){if(t._transitionData)return t._transitioning=!1,function(t){var e=Promise.resolve();if(!t)return e;for(;t.length;)e=e.then(t.shift());return e}(t._transitionData._interruptCallbacks)},r.prepareFn,v.rehover,function(){return t.emit(\"plotly_transitioning\",[]),new Promise(function(i){t._transitioning=!0,e.duration>0&&(t._transitioningWithDuration=!0),t._transitionData._interruptCallbacks.push(function(){n=!0}),r.redraw&&t._transitionData._interruptCallbacks.push(function(){return a.call(\"redraw\",t)}),t._transitionData._interruptCallbacks.push(function(){t.emit(\"plotly_transitioninterrupted\",[])});var o=0,s=0;function l(){return o++,function(){var e;s++,n||s!==o||(e=i,t._transitionData&&(function(t){if(t)for(;t.length;)t.shift()}(t._transitionData._interruptCallbacks),Promise.resolve().then(function(){if(r.redraw)return a.call(\"redraw\",t)}).then(function(){t._transitioning=!1,t._transitioningWithDuration=!1,t.emit(\"plotly_transitioned\",[])}).then(e)))}}r.runFn(l),setTimeout(l())})}],o=l.syncOrAsync(i,t);return o&&o.then||(o=Promise.resolve()),o.then(function(){return t})}v.didMarginChange=function(t,e){for(var r=0;r<M.length;r++){var n=M[r],a=t[n],o=e[n];if(!i(a)||Math.abs(o-a)>1)return!0}return!1},v.graphJson=function(t,e,r,n,i){(i&&e&&!t._fullData||i&&!e&&!t._fullLayout)&&v.supplyDefaults(t);var a=i?t._fullData:t.data,o=i?t._fullLayout:t.layout,s=(t._transitionData||{})._frames;function c(t){if(\"function\"==typeof t)return null;if(l.isPlainObject(t)){var e,n,i={};for(e in t)if(\"function\"!=typeof t[e]&&-1===[\"_\",\"[\"].indexOf(e.charAt(0))){if(\"keepdata\"===r){if(\"src\"===e.substr(e.length-3))continue}else if(\"keepstream\"===r){if(\"string\"==typeof(n=t[e+\"src\"])&&n.indexOf(\":\")>0&&!l.isPlainObject(t.stream))continue}else if(\"keepall\"!==r&&\"string\"==typeof(n=t[e+\"src\"])&&n.indexOf(\":\")>0)continue;i[e]=c(t[e])}return i}return Array.isArray(t)?t.map(c):l.isTypedArray(t)?l.simpleMap(t,l.identity):l.isJSDate(t)?l.ms2DateTimeLocal(+t):t}var u={data:(a||[]).map(function(t){var r=c(t);return e&&delete r.fit,r})};return e||(u.layout=c(o)),t.framework&&t.framework.isPolar&&(u=t.framework.getConfig()),s&&(u.frames=c(s)),\"object\"===n?u:JSON.stringify(u)},v.modifyFrames=function(t,e){var r,n,i,a=t._transitionData._frames,o=t._transitionData._frameHash;for(r=0;r<e.length;r++)switch((n=e[r]).type){case\"replace\":i=n.value;var s=(a[n.index]||{}).name,l=i.name;a[n.index]=o[l]=i,l!==s&&(delete o[s],o[l]=i);break;case\"insert\":o[(i=n.value).name]=i,a.splice(n.index,0,i);break;case\"delete\":delete o[(i=a[n.index]).name],a.splice(n.index,1)}return Promise.resolve()},v.computeFrame=function(t,e){var r,n,i,a,o=t._transitionData._frameHash;if(!e)throw new Error(\"computeFrame must be given a string frame name\");var s=o[e.toString()];if(!s)return!1;for(var l=[s],c=[s.name];s.baseframe&&(s=o[s.baseframe.toString()])&&-1===c.indexOf(s.name);)l.push(s),c.push(s.name);for(var u={};s=l.pop();)if(s.layout&&(u.layout=v.extendLayout(u.layout,s.layout)),s.data){if(u.data||(u.data=[]),!(n=s.traces))for(n=[],r=0;r<s.data.length;r++)n[r]=r;for(u.traces||(u.traces=[]),r=0;r<s.data.length;r++)null!=(i=n[r])&&(-1===(a=u.traces.indexOf(i))&&(a=u.data.length,u.traces[a]=i),u.data[a]=v.extendTrace(u.data[a],s.data[r]))}return u},v.recomputeFrameHash=function(t){for(var e=t._transitionData._frameHash={},r=t._transitionData._frames,n=0;n<r.length;n++){var i=r[n];i&&i.name&&(e[i.name]=i)}},v.extendObjectWithContainers=function(t,e,r){var n,i,a,o,s,c,u,h=l.extendDeepNoArrays({},e||{}),f=l.expandObjectPaths(h),p={};if(r&&r.length)for(a=0;a<r.length;a++)void 0===(i=(n=l.nestedProperty(f,r[a])).get())?l.nestedProperty(p,r[a]).set(null):(n.set(null),l.nestedProperty(p,r[a]).set(i));if(t=l.extendDeepNoArrays(t||{},f),r&&r.length)for(a=0;a<r.length;a++)if(c=l.nestedProperty(p,r[a]).get()){for(u=(s=l.nestedProperty(t,r[a])).get(),Array.isArray(u)||(u=[],s.set(u)),o=0;o<c.length;o++){var d=c[o];u[o]=null===d?null:v.extendObjectWithContainers(u[o],d)}s.set(u)}return t},v.dataArrayContainers=[\"transforms\",\"dimensions\"],v.layoutArrayContainers=a.layoutArrayContainers,v.extendTrace=function(t,e){return v.extendObjectWithContainers(t,e,v.dataArrayContainers)},v.extendLayout=function(t,e){return v.extendObjectWithContainers(t,e,v.layoutArrayContainers)},v.transition=function(t,e,r,n,i,a){var o={redraw:i.redraw},s={},c=[];return o.prepareFn=function(){for(var i=Array.isArray(e)?e.length:0,a=n.slice(0,i),o=0;o<a.length;o++){var u=a[o],h=t._fullData[u]._module;if(h){if(h.animatable){var f=h.basePlotModule.name;s[f]||(s[f]=[]),s[f].push(u)}t.data[a[o]]=v.extendTrace(t.data[a[o]],e[o])}}var p=l.expandObjectPaths(l.extendDeepNoArrays({},r)),d=/^[xy]axis[0-9]*$/;for(var g in p)d.test(g)&&delete p[g].range;v.extendLayout(t.layout,p),delete t.calcdata,v.supplyDefaults(t),v.doCalcdata(t);var m=l.expandObjectPaths(r);if(m){var y=t._fullLayout._plots;for(var x in y){var b,_,w,k,T=y[x],A=T.xaxis,M=T.yaxis,S=A.range.slice(),E=M.range.slice();Array.isArray(m[A._name+\".range\"])?b=m[A._name+\".range\"].slice():Array.isArray((m[A._name]||{}).range)&&(b=m[A._name].range.slice()),Array.isArray(m[M._name+\".range\"])?_=m[M._name+\".range\"].slice():Array.isArray((m[M._name]||{}).range)&&(_=m[M._name].range.slice()),S&&b&&(S[0]!==b[0]||S[1]!==b[1])&&(w={xr0:S,xr1:b}),E&&_&&(E[0]!==_[0]||E[1]!==_[1])&&(k={yr0:E,yr1:_}),(w||k)&&c.push(l.extendFlat({plotinfo:T},w,k))}}return Promise.resolve()},o.runFn=function(e){var n,i,o=t._fullLayout._basePlotModules,u=c.length;if(r)for(i=0;i<o.length;i++)o[i].transitionAxes&&o[i].transitionAxes(t,c,a,e);for(var h in u?((n=l.extendFlat({},a)).duration=0,delete s.cartesian):n=a,s){var f=s[h];t._fullData[f[0]]._module.basePlotModule.plot(t,f,n,e)}},S(t,a,o)},v.transitionFromReact=function(t,e,r,n){var i=t._fullLayout,a=i.transition,o={},s=[];return o.prepareFn=function(){var t=i._plots;for(var a in o.redraw=!1,\"some\"===e.anim&&(o.redraw=!0),\"some\"===r.anim&&(o.redraw=!0),t){var c,u,h=t[a],f=h.xaxis,p=h.yaxis,d=n[f._name].range.slice(),g=n[p._name].range.slice(),v=f.range.slice(),m=p.range.slice();f.setScale(),p.setScale(),d[0]===v[0]&&d[1]===v[1]||(c={xr0:d,xr1:v}),g[0]===m[0]&&g[1]===m[1]||(u={yr0:g,yr1:m}),(c||u)&&s.push(l.extendFlat({plotinfo:h},c,u))}return Promise.resolve()},o.runFn=function(r){for(var n,i,o,c=t._fullData,u=t._fullLayout._basePlotModules,h=[],f=0;f<c.length;f++)h.push(f);function p(){for(var e=0;e<u.length;e++)u[e].transitionAxes&&u[e].transitionAxes(t,s,n,r)}function d(){for(var e=0;e<u.length;e++)u[e].plot(t,o,i,r)}s.length&&e.anim?\"traces first\"===a.ordering?(n=l.extendFlat({},a,{duration:0}),o=h,i=a,d(),setTimeout(p,a.duration)):(n=a,o=null,i=l.extendFlat({},a,{duration:0}),p(),d()):s.length?(n=a,p()):e.anim&&(o=h,i=a,d())},S(t,a,o)},v.doCalcdata=function(t,e){var r,n,i,s,c=h.list(t),f=t._fullData,p=t._fullLayout,d=new Array(f.length),g=(t.calcdata||[]).slice();for(t.calcdata=d,p._numBoxes=0,p._numViolins=0,p._violinScaleGroupStats={},t._hmpixcount=0,t._hmlumcount=0,p._piecolormap={},p._sunburstcolormap={},p._funnelareacolormap={},i=0;i<f.length;i++)Array.isArray(e)&&-1===e.indexOf(i)&&(d[i]=g[i]);for(i=0;i<f.length;i++)(r=f[i])._arrayAttrs=o.findArrayAttributes(r),r._extremes={};var v=p._subplots.polar||[];for(i=0;i<v.length;i++)c.push(p[v[i]].radialaxis,p[v[i]].angularaxis);var y=!1;function x(e){if(r=f[e],n=r._module,!0===r.visible&&r.transforms){if(n&&n.calc){var i=n.calc(t,r);i[0]&&i[0].t&&i[0].t._scene&&delete i[0].t._scene.dirty}for(s=0;s<r.transforms.length;s++){var a=r.transforms[s];(n=m[a.type])&&n.calcTransform&&(r._hasCalcTransform=!0,y=!0,n.calcTransform(t,r,a))}}}function b(e,i){if(r=f[e],!!(n=r._module).isContainer===i){var a=[];if(!0===r.visible&&0!==r._length){delete r._indexToPoints;var o=r.transforms||[];for(s=o.length-1;s>=0;s--)if(o[s].enabled){r._indexToPoints=o[s]._indexToPoints;break}n&&n.calc&&(a=n.calc(t,r))}Array.isArray(a)&&a[0]||(a=[{x:u,y:u}]),a[0].t||(a[0].t={}),a[0].trace=r,d[e]=a}}for(C(c,f),i=0;i<f.length;i++)b(i,!0);for(i=0;i<f.length;i++)x(i);for(y&&C(c,f),i=0;i<f.length;i++)b(i,!0);for(i=0;i<f.length;i++)b(i,!1);L(t);var _=function(t,e){var r,n,i,o,s,c=[];function u(t,r,n){var i=r._id.charAt(0);if(\"histogram2dcontour\"===t){var a=r._counterAxes[0],o=h.getFromId(e,a),s=\"x\"===i||\"x\"===a&&\"category\"===o.type,l=\"y\"===i||\"y\"===a&&\"category\"===o.type;return function(t,e){return 0===t||0===e?-1:s&&t===n[e].length-1?-1:l&&e===n.length-1?-1:(\"y\"===i?e:t)-1}}return function(t,e){return\"y\"===i?e:t}}var f={min:function(t){return l.aggNums(Math.min,null,t)},max:function(t){return l.aggNums(Math.max,null,t)},sum:function(t){return l.aggNums(function(t,e){return t+e},null,t)},total:function(t){return l.aggNums(function(t,e){return t+e},null,t)},mean:function(t){return l.mean(t)},median:function(t){return l.median(t)}};for(r=0;r<t.length;r++){var p=t[r];if(\"category\"===p.type){var d=p.categoryorder.match(E);if(d){var g=d[1],v=d[2],m=[];for(n=0;n<p._categories.length;n++)m.push([p._categories[n],[]]);for(n=0;n<p._traceIndices.length;n++){var y=p._traceIndices[n],x=e._fullData[y],b=p._id.charAt(0);if(!0===x.visible){var _=x.type;a.traceIs(x,\"histogram\")&&(delete x._xautoBinFinished,delete x._yautoBinFinished);var w=e.calcdata[y];for(i=0;i<w.length;i++){var k,T,A,M=w[i];if(\"splom\"===_){var S=x._axesDim[p._id];if(\"y\"===b){var C=x._diag[S][0];C&&(p=e._fullLayout[h.id2name(C)])}var L=M.trace.dimensions[S].values;for(o=0;o<L.length;o++)for(k=L[o],T=p._categoriesMap[k],s=0;s<M.trace.dimensions.length;s++)if(s!==S){var P=M.trace.dimensions[s];m[T][1].push(P.values[o])}}else if(\"scattergl\"===_){for(o=0;o<M.t.x.length;o++)\"x\"===b&&(k=M.t.x[o],T=k,A=M.t.y[o]),\"y\"===b&&(k=M.t.y[o],T=k,A=M.t.x[o]),m[T][1].push(A);M.t&&M.t._scene&&delete M.t._scene.dirty}else if(M.hasOwnProperty(\"z\")){A=M.z;var O=u(x.type,p,A);for(o=0;o<A.length;o++)for(s=0;s<A[o].length;s++)(T=O(s,o))+1&&m[T][1].push(A[o][s])}else for(\"x\"===b?(k=M.p+1?M.p:M.x,A=M.s||M.v||M.y):\"y\"===b&&(k=M.p+1?M.p:M.y,A=M.s||M.v||M.x),Array.isArray(A)||(A=[A]),o=0;o<A.length;o++)m[k][1].push(A[o])}}}p._categoriesValue=m;var z=[];for(n=0;n<m.length;n++)z.push([m[n][0],f[g](m[n][1])]);z.sort(function(t,e){return t[1]-e[1]}),p._categoriesAggregatedValue=z,p._initialCategories=z.map(function(t){return t[0]}),\"descending\"===v&&p._initialCategories.reverse(),c=c.concat(p.sortByInitialCategories())}}}return c}(c,t);if(_.length){for(p._numBoxes=0,p._numViolins=0,i=0;i<_.length;i++)b(_[i],!0);for(i=0;i<_.length;i++)b(_[i],!1);L(t)}a.getComponentMethod(\"fx\",\"calc\")(t),a.getComponentMethod(\"errorbars\",\"calc\")(t)};var E=/(total|sum|min|max|mean|median) (ascending|descending)/;function C(t,e){for(var r=0;r<t.length;r++){var n=t[r];n.clearCalc(),\"multicategory\"===n.type&&n.setupMultiCategory(e)}}function L(t){var e,r,n,i=t._fullLayout,a=i._visibleModules,o={};for(r=0;r<a.length;r++){var s=a[r],c=s.crossTraceCalc;if(c){var u=s.basePlotModule.name;o[u]?l.pushUnique(o[u],c):o[u]=[c]}}for(n in o){var h=o[n],f=i._subplots[n];if(Array.isArray(f))for(e=0;e<f.length;e++){var p=f[e],d=\"cartesian\"===n?i._plots[p]:i[p];for(r=0;r<h.length;r++)h[r](t,d,p)}else for(r=0;r<h.length;r++)h[r](t)}}v.rehover=function(t){t._fullLayout._rehover&&t._fullLayout._rehover()},v.redrag=function(t){t._fullLayout._redrag&&t._fullLayout._redrag()},v.generalUpdatePerTraceModule=function(t,e,r,n){var i,a=e.traceHash,o={};for(i=0;i<r.length;i++){var s=r[i],c=s[0].trace;c.visible&&(o[c.type]=o[c.type]||[],o[c.type].push(s))}for(var u in a)if(!o[u]){var h=a[u][0];h[0].trace.visible=!1,o[u]=[h]}for(var f in o){var p=o[f];p[0][0].trace._module.plot(t,e,l.filterVisible(p),n)}e.traceHash=o}},{\"../components/color\":593,\"../constants/numerical\":695,\"../lib\":719,\"../plot_api/plot_schema\":756,\"../plot_api/plot_template\":757,\"../registry\":847,\"./animation_attributes\":762,\"./attributes\":764,\"./cartesian/axis_ids\":770,\"./command\":791,\"./font_attributes\":793,\"./frame_attributes\":794,\"./layout_attributes\":819,d3:163,\"fast-isnumeric\":225}],829:[function(t,e,r){\"use strict\";e.exports={attr:\"subplot\",name:\"polar\",axisNames:[\"angularaxis\",\"radialaxis\"],axisName2dataArray:{angularaxis:\"theta\",radialaxis:\"r\"},layerNames:[\"draglayer\",\"plotbg\",\"backplot\",\"angular-grid\",\"radial-grid\",\"frontplot\",\"angular-line\",\"radial-line\",\"angular-axis\",\"radial-axis\"],radialDragBoxSize:50,angularDragBoxSize:30,cornerLen:25,cornerHalfWidth:2,MINDRAG:8,MINZOOM:20,OFFEDGE:20}},{}],830:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/polygon\").tester,a=n.findIndexOfMin,o=n.isAngleInsideSector,s=n.angleDelta,l=n.angleDist;function c(t,e,r,n){var i,a,o=n[0],s=n[1],l=h(Math.sin(e)-Math.sin(t)),c=h(Math.cos(e)-Math.cos(t)),u=Math.tan(r),f=h(1/u),p=l/c,d=s-p*o;return f?l&&c?a=u*(i=d/(u-p)):c?(i=s*f,a=s):(i=o,a=o*u):l&&c?(i=0,a=d):c?(i=0,a=s):i=a=NaN,[i,a]}function u(t,e,r,i){return n.isFullCircle([e,r])?function(t,e){var r,n=e.length,i=new Array(n+1);for(r=0;r<n;r++){var a=e[r];i[r]=[t*Math.cos(a),t*Math.sin(a)]}return i[r]=i[0].slice(),i}(t,i):function(t,e,r,i){var s,u,h=i.length,f=[];function p(e){return[t*Math.cos(e),t*Math.sin(e)]}function d(t,e,r){return c(t,e,r,p(t))}function g(t){return n.mod(t,h)}function v(t){return o(t,[e,r])}var m=a(i,function(t){return v(t)?l(t,e):1/0}),y=d(i[m],i[g(m-1)],e);for(f.push(y),s=m,u=0;u<h;s++,u++){var x=i[g(s)];if(!v(x))break;f.push(p(x))}var b=a(i,function(t){return v(t)?l(t,r):1/0}),_=d(i[b],i[g(b+1)],r);return f.push(_),f.push([0,0]),f.push(f[0].slice()),f}(t,e,r,i)}function h(t){return Math.abs(t)>1e-10?t:0}function f(t,e,r){e=e||0,r=r||0;for(var n=t.length,i=new Array(n),a=0;a<n;a++){var o=t[a];i[a]=[e+o[0],r-o[1]]}return i}e.exports={isPtInsidePolygon:function(t,e,r,n,a){if(!o(e,n))return!1;var s,l;r[0]<r[1]?(s=r[0],l=r[1]):(s=r[1],l=r[0]);var c=i(u(s,n[0],n[1],a)),h=i(u(l,n[0],n[1],a)),f=[t*Math.cos(e),t*Math.sin(e)];return h.contains(f)&&!c.contains(f)},findPolygonOffset:function(t,e,r,n){for(var i=1/0,a=1/0,o=u(t,e,r,n),s=0;s<o.length;s++){var l=o[s];i=Math.min(i,l[0]),a=Math.min(a,-l[1])}return[i,a]},findEnclosingVertexAngles:function(t,e){var r=a(e,function(e){var r=s(e,t);return r>0?r:1/0}),i=n.mod(r+1,e.length);return[e[r],e[i]]},findIntersectionXY:c,findXYatLength:function(t,e,r,n){var i=-e*r,a=e*e+1,o=2*(e*i-r),s=i*i+r*r-t*t,l=Math.sqrt(o*o-4*a*s),c=(-o+l)/(2*a),u=(-o-l)/(2*a);return[[c,e*c+i+n],[u,e*u+i+n]]},clampTiny:h,pathPolygon:function(t,e,r,n,i,a){return\"M\"+f(u(t,e,r,n),i,a).join(\"L\")},pathPolygonAnnulus:function(t,e,r,n,i,a,o){var s,l;t<e?(s=t,l=e):(s=e,l=t);var c=f(u(s,r,n,i),a,o);return\"M\"+f(u(l,r,n,i),a,o).reverse().join(\"L\")+\"M\"+c.join(\"L\")}}},{\"../../lib\":719,\"../../lib/polygon\":731}],831:[function(t,e,r){\"use strict\";var n=t(\"../get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./polar\"),o=t(\"./constants\"),s=o.attr,l=o.name,c=i(l),u={};u[s]={valType:\"subplotid\",dflt:l,editType:\"calc\"},e.exports={attr:s,name:l,idRoot:l,idRegex:c,attrRegex:c,attributes:u,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[l],o=0;o<i.length;o++){var s=i[o],c=n(r,l,s),u=e[s]._subplot;u||(u=a(t,s),e[s]._subplot=u),u.plot(c,e,t._promises)}},clean:function(t,e,r,n){for(var i=n._subplots[l]||[],a=n._has&&n._has(\"gl\"),o=e._has&&e._has(\"gl\"),s=a&&!o,c=0;c<i.length;c++){var u=i[c],h=n[u]._subplot;if(!e[u]&&h)for(var f in h.framework.remove(),h.layers[\"radial-axis-title\"].remove(),h.clipPaths)h.clipPaths[f].remove();s&&h._scene&&(h._scene.destroy(),h._scene=null)}},toSVG:t(\"../cartesian\").toSVG}},{\"../../lib\":719,\"../cartesian\":778,\"../get_data\":802,\"./constants\":829,\"./layout_attributes\":832,\"./layout_defaults\":833,\"./polar\":840}],832:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../cartesian/layout_attributes\"),a=t(\"../domain\").attributes,o=t(\"../../lib\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=s({color:i.color,showline:o({},i.showline,{dflt:!0}),linecolor:i.linecolor,linewidth:i.linewidth,showgrid:o({},i.showgrid,{dflt:!0}),gridcolor:i.gridcolor,gridwidth:i.gridwidth},\"plot\",\"from-root\"),c=s({tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,showtickprefix:i.showtickprefix,tickprefix:i.tickprefix,showticksuffix:i.showticksuffix,ticksuffix:i.ticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,separatethousands:i.separatethousands,tickfont:i.tickfont,tickangle:i.tickangle,tickformat:i.tickformat,tickformatstops:i.tickformatstops,layer:i.layer},\"plot\",\"from-root\"),u={visible:o({},i.visible,{dflt:!0}),type:o({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autorange:o({},i.autorange,{editType:\"plot\"}),rangemode:{valType:\"enumerated\",values:[\"tozero\",\"nonnegative\",\"normal\"],dflt:\"tozero\",editType:\"calc\"},range:o({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],editType:\"plot\"}),categoryorder:i.categoryorder,categoryarray:i.categoryarray,angle:{valType:\"angle\",editType:\"plot\"},side:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"clockwise\",editType:\"plot\"},title:s(i.title,\"plot\",\"from-root\"),hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}};u.title.text.dflt=\"\",o(u,l,c);var h={visible:o({},i.visible,{dflt:!0}),type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"category\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},categoryorder:i.categoryorder,categoryarray:i.categoryarray,thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\"],dflt:\"degrees\",editType:\"calc\"},period:{valType:\"number\",editType:\"calc\",min:0},direction:{valType:\"enumerated\",values:[\"counterclockwise\",\"clockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"angle\",editType:\"calc\"},hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"};o(h,l,c),e.exports={domain:a({name:\"polar\",editType:\"plot\"}),sector:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],dflt:[0,360],editType:\"plot\"},hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},bgcolor:{valType:\"color\",editType:\"plot\",dflt:n.background},radialaxis:u,angularaxis:h,gridshape:{valType:\"enumerated\",values:[\"circular\",\"linear\"],dflt:\"circular\",editType:\"plot\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"}},{\"../../components/color/attributes\":592,\"../../lib\":719,\"../../plot_api/edit_types\":750,\"../cartesian/layout_attributes\":779,\"../domain\":792}],833:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../subplot_defaults\"),s=t(\"../get_data\").getSubplotData,l=t(\"../cartesian/tick_value_defaults\"),c=t(\"../cartesian/tick_mark_defaults\"),u=t(\"../cartesian/tick_label_defaults\"),h=t(\"../cartesian/category_order_defaults\"),f=t(\"../cartesian/line_grid_defaults\"),p=t(\"../cartesian/axis_autotype\"),d=t(\"./layout_attributes\"),g=t(\"./set_convert\"),v=t(\"./constants\"),m=v.axisNames;function y(t,e,r,o){var p=r(\"bgcolor\");o.bgColor=i.combine(p,o.paper_bgcolor);var y=r(\"sector\");r(\"hole\");var b,_=s(o.fullData,v.name,o.id),w=o.layoutOut;function k(t,e){return r(b+\".\"+t,e)}for(var T=0;T<m.length;T++){b=m[T],n.isPlainObject(t[b])||(t[b]={});var A=t[b],M=a.newContainer(e,b);M._id=M._name=b,M._attr=o.id+\".\"+b,M._traceIndices=_.map(function(t){return t._expandedIndex});var S=v.axisName2dataArray[b],E=x(A,M,k,_,S);h(A,M,k,{axData:_,dataAttr:S});var C,L,P=k(\"visible\");switch(g(M,e,w),k(\"uirevision\",e.uirevision),P&&(L=(C=k(\"color\"))===A.color?C:o.font.color),M._m=1,b){case\"radialaxis\":var O=k(\"autorange\",!M.isValidRange(A.range));A.autorange=O,!O||\"linear\"!==E&&\"-\"!==E||k(\"rangemode\"),\"reversed\"===O&&(M._m=-1),k(\"range\"),M.cleanRange(\"range\",{dfltRange:[0,1]}),P&&(k(\"side\"),k(\"angle\",y[0]),k(\"title.text\"),n.coerceFont(k,\"title.font\",{family:o.font.family,size:Math.round(1.2*o.font.size),color:L}));break;case\"angularaxis\":if(\"date\"===E){n.log(\"Polar plots do not support date angular axes yet.\");for(var z=0;z<_.length;z++)_[z].visible=!1;E=A.type=M.type=\"linear\"}k(\"linear\"===E?\"thetaunit\":\"period\");var I=k(\"direction\");k(\"rotation\",{counterclockwise:0,clockwise:90}[I])}if(P)l(A,M,k,M.type),u(A,M,k,M.type,{tickSuffixDflt:\"degrees\"===M.thetaunit?\"\\xb0\":void 0}),c(A,M,k,{outerTicks:!0}),k(\"showticklabels\")&&(n.coerceFont(k,\"tickfont\",{family:o.font.family,size:o.font.size,color:L}),k(\"tickangle\"),k(\"tickformat\")),f(A,M,k,{dfltColor:C,bgColor:o.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:d[b]}),k(\"layer\");\"category\"!==E&&k(\"hoverformat\"),M._input=A}\"category\"===e.angularaxis.type&&r(\"gridshape\")}function x(t,e,r,n,i){if(\"-\"===r(\"type\")){for(var a,o=0;o<n.length;o++)if(n[o].visible){a=n[o];break}a&&a[i]&&(e.type=p(a[i],\"gregorian\")),\"-\"===e.type?e.type=\"linear\":t.type=e.type}return e.type}e.exports=function(t,e,r){o(t,e,r,{type:v.name,attributes:d,handleDefaults:y,font:e.font,paper_bgcolor:e.paper_bgcolor,fullData:r,layoutOut:e})}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../cartesian/axis_autotype\":768,\"../cartesian/category_order_defaults\":771,\"../cartesian/line_grid_defaults\":781,\"../cartesian/tick_label_defaults\":786,\"../cartesian/tick_mark_defaults\":787,\"../cartesian/tick_value_defaults\":788,\"../get_data\":802,\"../subplot_defaults\":842,\"./constants\":829,\"./layout_attributes\":832,\"./set_convert\":841}],834:[function(t,e,r){\"use strict\";var n=t(\"../../../traces/scatter/attributes\"),i=n.marker,a=t(\"../../../lib/extend\").extendFlat;[\"Area traces are deprecated!\",\"Please switch to the *barpolar* trace type.\"].join(\" \");e.exports={r:a({},n.r,{}),t:a({},n.t,{}),marker:{color:a({},i.color,{}),size:a({},i.size,{}),symbol:a({},i.symbol,{}),opacity:a({},i.opacity,{}),editType:\"calc\"}}},{\"../../../lib/extend\":710,\"../../../traces/scatter/attributes\":1112}],835:[function(t,e,r){\"use strict\";var n=t(\"../../cartesian/layout_attributes\"),i=t(\"../../../lib/extend\").extendFlat,a=t(\"../../../plot_api/edit_types\").overrideAll,o=[\"Legacy polar charts are deprecated!\",\"Please switch to *polar* subplots.\"].join(\" \"),s=i({},n.domain,{});function l(t,e){return i({},e,{showline:{valType:\"boolean\"},showticklabels:{valType:\"boolean\"},tickorientation:{valType:\"enumerated\",values:[\"horizontal\",\"vertical\"]},ticklen:{valType:\"number\",min:0},tickcolor:{valType:\"color\"},ticksuffix:{valType:\"string\"},endpadding:{valType:\"number\",description:o},visible:{valType:\"boolean\"}})}e.exports=a({radialaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},domain:s,orientation:{valType:\"number\"}}),angularaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\",dflt:0},{valType:\"number\",dflt:360}]},domain:s}),layout:{direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"]},orientation:{valType:\"angle\"}}},\"plot\",\"nested\")},{\"../../../lib/extend\":710,\"../../../plot_api/edit_types\":750,\"../../cartesian/layout_attributes\":779}],836:[function(t,e,r){\"use strict\";(e.exports=t(\"./micropolar\")).manager=t(\"./micropolar_manager\")},{\"./micropolar\":837,\"./micropolar_manager\":838}],837:[function(t,e,r){var n=t(\"d3\"),i=t(\"../../../lib\").extendDeepAll,a=t(\"../../../constants/alignment\").MID_SHIFT,o=e.exports={version:\"0.2.2\"};o.Axis=function(){var t,e,r,s,l={data:[],layout:{}},c={},u={},h=n.dispatch(\"hover\"),f={};return f.render=function(c){return function(c){e=c||e;var h=l.data,f=l.layout;(\"string\"==typeof e||e.nodeName)&&(e=n.select(e)),e.datum(h).each(function(e,l){var c=e.slice();u={data:o.util.cloneJson(c),layout:o.util.cloneJson(f)};var h=0;c.forEach(function(t,e){t.color||(t.color=f.defaultColorRange[h],h=(h+1)%f.defaultColorRange.length),t.strokeColor||(t.strokeColor=\"LinePlot\"===t.geometry?t.color:n.rgb(t.color).darker().toString()),u.data[e].color=t.color,u.data[e].strokeColor=t.strokeColor,u.data[e].strokeDash=t.strokeDash,u.data[e].strokeSize=t.strokeSize});var p=c.filter(function(t,e){var r=t.visible;return\"undefined\"==typeof r||!0===r}),d=!1,g=p.map(function(t,e){return d=d||\"undefined\"!=typeof t.groupId,t});if(d){var v=n.nest().key(function(t,e){return\"undefined\"!=typeof t.groupId?t.groupId:\"unstacked\"}).entries(g),m=[],y=v.map(function(t,e){if(\"unstacked\"===t.key)return t.values;var r=t.values[0].r.map(function(t,e){return 0});return t.values.forEach(function(t,e,n){t.yStack=[r],m.push(r),r=o.util.sumArrays(t.r,r)}),t.values});p=n.merge(y)}p.forEach(function(t,e){t.t=Array.isArray(t.t[0])?t.t:[t.t],t.r=Array.isArray(t.r[0])?t.r:[t.r]});var x=Math.min(f.width-f.margin.left-f.margin.right,f.height-f.margin.top-f.margin.bottom)/2;x=Math.max(10,x);var b,_=[f.margin.left+x,f.margin.top+x];b=d?[0,n.max(o.util.sumArrays(o.util.arrayLast(p).r[0],o.util.arrayLast(m)))]:n.extent(o.util.flattenArray(p.map(function(t,e){return t.r}))),f.radialAxis.domain!=o.DATAEXTENT&&(b[0]=0),r=n.scale.linear().domain(f.radialAxis.domain!=o.DATAEXTENT&&f.radialAxis.domain?f.radialAxis.domain:b).range([0,x]),u.layout.radialAxis.domain=r.domain();var w,k=o.util.flattenArray(p.map(function(t,e){return t.t})),T=\"string\"==typeof k[0];T&&(k=o.util.deduplicate(k),w=k.slice(),k=n.range(k.length),p=p.map(function(t,e){var r=t;return t.t=[k],d&&(r.yStack=t.yStack),r}));var A=p.filter(function(t,e){return\"LinePlot\"===t.geometry||\"DotPlot\"===t.geometry}).length===p.length,M=null===f.needsEndSpacing?T||!A:f.needsEndSpacing,S=f.angularAxis.domain&&f.angularAxis.domain!=o.DATAEXTENT&&!T&&f.angularAxis.domain[0]>=0?f.angularAxis.domain:n.extent(k),E=Math.abs(k[1]-k[0]);A&&!T&&(E=0);var C=S.slice();M&&T&&(C[1]+=E);var L=f.angularAxis.ticksCount||4;L>8&&(L=L/(L/8)+L%8),f.angularAxis.ticksStep&&(L=(C[1]-C[0])/L);var P=f.angularAxis.ticksStep||(C[1]-C[0])/(L*(f.minorTicks+1));w&&(P=Math.max(Math.round(P),1)),C[2]||(C[2]=P);var O=n.range.apply(this,C);if(O=O.map(function(t,e){return parseFloat(t.toPrecision(12))}),s=n.scale.linear().domain(C.slice(0,2)).range(\"clockwise\"===f.direction?[0,360]:[360,0]),u.layout.angularAxis.domain=s.domain(),u.layout.angularAxis.endPadding=M?E:0,\"undefined\"==typeof(t=n.select(this).select(\"svg.chart-root\"))||t.empty()){var z=(new DOMParser).parseFromString(\"<svg xmlns='http://www.w3.org/2000/svg' class='chart-root'>' + '<g class='outer-group'>' + '<g class='chart-group'>' + '<circle class='background-circle'></circle>' + '<g class='geometry-group'></g>' + '<g class='radial axis-group'>' + '<circle class='outside-circle'></circle>' + '</g>' + '<g class='angular axis-group'></g>' + '<g class='guides-group'><line></line><circle r='0'></circle></g>' + '</g>' + '<g class='legend-group'></g>' + '<g class='tooltips-group'></g>' + '<g class='title-group'><text></text></g>' + '</g>' + '</svg>\",\"application/xml\"),I=this.appendChild(this.ownerDocument.importNode(z.documentElement,!0));t=n.select(I)}t.select(\".guides-group\").style({\"pointer-events\":\"none\"}),t.select(\".angular.axis-group\").style({\"pointer-events\":\"none\"}),t.select(\".radial.axis-group\").style({\"pointer-events\":\"none\"});var D,R=t.select(\".chart-group\"),F={fill:\"none\",stroke:f.tickColor},B={\"font-size\":f.font.size,\"font-family\":f.font.family,fill:f.font.color,\"text-shadow\":[\"-1px 0px\",\"1px -1px\",\"-1px 1px\",\"1px 1px\"].map(function(t,e){return\" \"+t+\" 0 \"+f.font.outlineColor}).join(\",\")};if(f.showLegend){D=t.select(\".legend-group\").attr({transform:\"translate(\"+[x,f.margin.top]+\")\"}).style({display:\"block\"});var N=p.map(function(t,e){var r=o.util.cloneJson(t);return r.symbol=\"DotPlot\"===t.geometry?t.dotType||\"circle\":\"LinePlot\"!=t.geometry?\"square\":\"line\",r.visibleInLegend=\"undefined\"==typeof t.visibleInLegend||t.visibleInLegend,r.color=\"LinePlot\"===t.geometry?t.strokeColor:t.color,r});o.Legend().config({data:p.map(function(t,e){return t.name||\"Element\"+e}),legendConfig:i({},o.Legend.defaultConfig().legendConfig,{container:D,elements:N,reverseOrder:f.legend.reverseOrder})})();var j=D.node().getBBox();x=Math.min(f.width-j.width-f.margin.left-f.margin.right,f.height-f.margin.top-f.margin.bottom)/2,x=Math.max(10,x),_=[f.margin.left+x,f.margin.top+x],r.range([0,x]),u.layout.radialAxis.domain=r.domain(),D.attr(\"transform\",\"translate(\"+[_[0]+x,_[1]-x]+\")\")}else D=t.select(\".legend-group\").style({display:\"none\"});t.attr({width:f.width,height:f.height}).style({opacity:f.opacity}),R.attr(\"transform\",\"translate(\"+_+\")\").style({cursor:\"crosshair\"});var U=[(f.width-(f.margin.left+f.margin.right+2*x+(j?j.width:0)))/2,(f.height-(f.margin.top+f.margin.bottom+2*x))/2];if(U[0]=Math.max(0,U[0]),U[1]=Math.max(0,U[1]),t.select(\".outer-group\").attr(\"transform\",\"translate(\"+U+\")\"),f.title&&f.title.text){var V=t.select(\"g.title-group text\").style(B).text(f.title.text),q=V.node().getBBox();V.attr({x:_[0]-q.width/2,y:_[1]-x-20})}var H=t.select(\".radial.axis-group\");if(f.radialAxis.gridLinesVisible){var G=H.selectAll(\"circle.grid-circle\").data(r.ticks(5));G.enter().append(\"circle\").attr({class:\"grid-circle\"}).style(F),G.attr(\"r\",r),G.exit().remove()}H.select(\"circle.outside-circle\").attr({r:x}).style(F);var Y=t.select(\"circle.background-circle\").attr({r:x}).style({fill:f.backgroundColor,stroke:f.stroke});function W(t,e){return s(t)%360+f.orientation}if(f.radialAxis.visible){var X=n.svg.axis().scale(r).ticks(5).tickSize(5);H.call(X).attr({transform:\"rotate(\"+f.radialAxis.orientation+\")\"}),H.selectAll(\".domain\").style(F),H.selectAll(\"g>text\").text(function(t,e){return this.textContent+f.radialAxis.ticksSuffix}).style(B).style({\"text-anchor\":\"start\"}).attr({x:0,y:0,dx:0,dy:0,transform:function(t,e){return\"horizontal\"===f.radialAxis.tickOrientation?\"rotate(\"+-f.radialAxis.orientation+\") translate(\"+[0,B[\"font-size\"]]+\")\":\"translate(\"+[0,B[\"font-size\"]]+\")\"}}),H.selectAll(\"g>line\").style({stroke:\"black\"})}var Z=t.select(\".angular.axis-group\").selectAll(\"g.angular-tick\").data(O),J=Z.enter().append(\"g\").classed(\"angular-tick\",!0);Z.attr({transform:function(t,e){return\"rotate(\"+W(t)+\")\"}}).style({display:f.angularAxis.visible?\"block\":\"none\"}),Z.exit().remove(),J.append(\"line\").classed(\"grid-line\",!0).classed(\"major\",function(t,e){return e%(f.minorTicks+1)==0}).classed(\"minor\",function(t,e){return!(e%(f.minorTicks+1)==0)}).style(F),J.selectAll(\".minor\").style({stroke:f.minorTickColor}),Z.select(\"line.grid-line\").attr({x1:f.tickLength?x-f.tickLength:0,x2:x}).style({display:f.angularAxis.gridLinesVisible?\"block\":\"none\"}),J.append(\"text\").classed(\"axis-text\",!0).style(B);var K=Z.select(\"text.axis-text\").attr({x:x+f.labelOffset,dy:a+\"em\",transform:function(t,e){var r=W(t),n=x+f.labelOffset,i=f.angularAxis.tickOrientation;return\"horizontal\"==i?\"rotate(\"+-r+\" \"+n+\" 0)\":\"radial\"==i?r<270&&r>90?\"rotate(180 \"+n+\" 0)\":null:\"rotate(\"+(r<=180&&r>0?-90:90)+\" \"+n+\" 0)\"}}).style({\"text-anchor\":\"middle\",display:f.angularAxis.labelsVisible?\"block\":\"none\"}).text(function(t,e){return e%(f.minorTicks+1)!=0?\"\":w?w[t]+f.angularAxis.ticksSuffix:t+f.angularAxis.ticksSuffix}).style(B);f.angularAxis.rewriteTicks&&K.text(function(t,e){return e%(f.minorTicks+1)!=0?\"\":f.angularAxis.rewriteTicks(this.textContent,e)});var $=n.max(R.selectAll(\".angular-tick text\")[0].map(function(t,e){return t.getCTM().e+t.getBBox().width}));D.attr({transform:\"translate(\"+[x+$,f.margin.top]+\")\"});var Q=t.select(\"g.geometry-group\").selectAll(\"g\").size()>0,tt=t.select(\"g.geometry-group\").selectAll(\"g.geometry\").data(p);if(tt.enter().append(\"g\").attr({class:function(t,e){return\"geometry geometry\"+e}}),tt.exit().remove(),p[0]||Q){var et=[];p.forEach(function(t,e){var n={};n.radialScale=r,n.angularScale=s,n.container=tt.filter(function(t,r){return r==e}),n.geometry=t.geometry,n.orientation=f.orientation,n.direction=f.direction,n.index=e,et.push({data:t,geometryConfig:n})});var rt=n.nest().key(function(t,e){return\"undefined\"!=typeof t.data.groupId||\"unstacked\"}).entries(et),nt=[];rt.forEach(function(t,e){\"unstacked\"===t.key?nt=nt.concat(t.values.map(function(t,e){return[t]})):nt.push(t.values)}),nt.forEach(function(t,e){var r;r=Array.isArray(t)?t[0].geometryConfig.geometry:t.geometryConfig.geometry;var n=t.map(function(t,e){return i(o[r].defaultConfig(),t)});o[r]().config(n)()})}var it,at,ot=t.select(\".guides-group\"),st=t.select(\".tooltips-group\"),lt=o.tooltipPanel().config({container:st,fontSize:8})(),ct=o.tooltipPanel().config({container:st,fontSize:8})(),ut=o.tooltipPanel().config({container:st,hasTick:!0})();if(!T){var ht=ot.select(\"line\").attr({x1:0,y1:0,y2:0}).style({stroke:\"grey\",\"pointer-events\":\"none\"});R.on(\"mousemove.angular-guide\",function(t,e){var r=o.util.getMousePos(Y).angle;ht.attr({x2:-x,transform:\"rotate(\"+r+\")\"}).style({opacity:.5});var n=(r+180+360-f.orientation)%360;it=s.invert(n);var i=o.util.convertToCartesian(x+12,r+180);lt.text(o.util.round(it)).move([i[0]+_[0],i[1]+_[1]])}).on(\"mouseout.angular-guide\",function(t,e){ot.select(\"line\").style({opacity:0})})}var ft=ot.select(\"circle\").style({stroke:\"grey\",fill:\"none\"});R.on(\"mousemove.radial-guide\",function(t,e){var n=o.util.getMousePos(Y).radius;ft.attr({r:n}).style({opacity:.5}),at=r.invert(o.util.getMousePos(Y).radius);var i=o.util.convertToCartesian(n,f.radialAxis.orientation);ct.text(o.util.round(at)).move([i[0]+_[0],i[1]+_[1]])}).on(\"mouseout.radial-guide\",function(t,e){ft.style({opacity:0}),ut.hide(),lt.hide(),ct.hide()}),t.selectAll(\".geometry-group .mark\").on(\"mouseover.tooltip\",function(e,r){var i=n.select(this),a=this.style.fill,s=\"black\",l=this.style.opacity||1;if(i.attr({\"data-opacity\":l}),a&&\"none\"!==a){i.attr({\"data-fill\":a}),s=n.hsl(a).darker().toString(),i.style({fill:s,opacity:1});var c={t:o.util.round(e[0]),r:o.util.round(e[1])};T&&(c.t=w[e[0]]);var u=\"t: \"+c.t+\", r: \"+c.r,h=this.getBoundingClientRect(),f=t.node().getBoundingClientRect(),p=[h.left+h.width/2-U[0]-f.left,h.top+h.height/2-U[1]-f.top];ut.config({color:s}).text(u),ut.move(p)}else a=this.style.stroke||\"black\",i.attr({\"data-stroke\":a}),s=n.hsl(a).darker().toString(),i.style({stroke:s,opacity:1})}).on(\"mousemove.tooltip\",function(t,e){if(0!=n.event.which)return!1;n.select(this).attr(\"data-fill\")&&ut.show()}).on(\"mouseout.tooltip\",function(t,e){ut.hide();var r=n.select(this),i=r.attr(\"data-fill\");i?r.style({fill:i,opacity:r.attr(\"data-opacity\")}):r.style({stroke:r.attr(\"data-stroke\"),opacity:r.attr(\"data-opacity\")})})})}(c),this},f.config=function(t){if(!arguments.length)return l;var e=o.util.cloneJson(t);return e.data.forEach(function(t,e){l.data[e]||(l.data[e]={}),i(l.data[e],o.Axis.defaultConfig().data[0]),i(l.data[e],t)}),i(l.layout,o.Axis.defaultConfig().layout),i(l.layout,e.layout),this},f.getLiveConfig=function(){return u},f.getinputConfig=function(){return c},f.radialScale=function(t){return r},f.angularScale=function(t){return s},f.svg=function(){return t},n.rebind(f,h,\"on\"),f},o.Axis.defaultConfig=function(t,e){return{data:[{t:[1,2,3,4],r:[10,11,12,13],name:\"Line1\",geometry:\"LinePlot\",color:null,strokeDash:\"solid\",strokeColor:null,strokeSize:\"1\",visibleInLegend:!0,opacity:1}],layout:{defaultColorRange:n.scale.category10().range(),title:null,height:450,width:500,margin:{top:40,right:40,bottom:40,left:40},font:{size:12,color:\"gray\",outlineColor:\"white\",family:\"Tahoma, sans-serif\"},direction:\"clockwise\",orientation:0,labelOffset:10,radialAxis:{domain:null,orientation:-45,ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null},angularAxis:{domain:[0,360],ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,labelsVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null,ticksCount:null,ticksStep:null},minorTicks:0,tickLength:null,tickColor:\"silver\",minorTickColor:\"#eee\",backgroundColor:\"none\",needsEndSpacing:null,showLegend:!0,legend:{reverseOrder:!1},opacity:1}}},o.util={},o.DATAEXTENT=\"dataExtent\",o.AREA=\"AreaChart\",o.LINE=\"LinePlot\",o.DOT=\"DotPlot\",o.BAR=\"BarChart\",o.util._override=function(t,e){for(var r in t)r in e&&(e[r]=t[r])},o.util._extend=function(t,e){for(var r in t)e[r]=t[r]},o.util._rndSnd=function(){return 2*Math.random()-1+(2*Math.random()-1)+(2*Math.random()-1)},o.util.dataFromEquation2=function(t,e){var r=e||6;return n.range(0,360+r,r).map(function(e,r){var n=e*Math.PI/180;return[e,t(n)]})},o.util.dataFromEquation=function(t,e,r){var i=e||6,a=[],o=[];n.range(0,360+i,i).forEach(function(e,r){var n=e*Math.PI/180,i=t(n);a.push(e),o.push(i)});var s={t:a,r:o};return r&&(s.name=r),s},o.util.ensureArray=function(t,e){if(\"undefined\"==typeof t)return null;var r=[].concat(t);return n.range(e).map(function(t,e){return r[e]||r[0]})},o.util.fillArrays=function(t,e,r){return e.forEach(function(e,n){t[e]=o.util.ensureArray(t[e],r)}),t},o.util.cloneJson=function(t){return JSON.parse(JSON.stringify(t))},o.util.validateKeys=function(t,e){\"string\"==typeof e&&(e=e.split(\".\"));var r=e.shift();return t[r]&&(!e.length||objHasKeys(t[r],e))},o.util.sumArrays=function(t,e){return n.zip(t,e).map(function(t,e){return n.sum(t)})},o.util.arrayLast=function(t){return t[t.length-1]},o.util.arrayEqual=function(t,e){for(var r=Math.max(t.length,e.length,1);r-- >=0&&t[r]===e[r];);return-2===r},o.util.flattenArray=function(t){for(var e=[];!o.util.arrayEqual(e,t);)e=t,t=[].concat.apply([],t);return t},o.util.deduplicate=function(t){return t.filter(function(t,e,r){return r.indexOf(t)==e})},o.util.convertToCartesian=function(t,e){var r=e*Math.PI/180;return[t*Math.cos(r),t*Math.sin(r)]},o.util.round=function(t,e){var r=e||2,n=Math.pow(10,r);return Math.round(t*n)/n},o.util.getMousePos=function(t){var e=n.mouse(t.node()),r=e[0],i=e[1],a={};return a.x=r,a.y=i,a.pos=e,a.angle=180*(Math.atan2(i,r)+Math.PI)/Math.PI,a.radius=Math.sqrt(r*r+i*i),a},o.util.duplicatesCount=function(t){for(var e,r={},n={},i=0,a=t.length;i<a;i++)(e=t[i])in r?(r[e]++,n[e]=r[e]):r[e]=1;return n},o.util.duplicates=function(t){return Object.keys(o.util.duplicatesCount(t))},o.util.translator=function(t,e,r,n){if(n){var i=r.slice();r=e,e=i}var a=e.reduce(function(t,e){if(\"undefined\"!=typeof t)return t[e]},t);\"undefined\"!=typeof a&&(e.reduce(function(t,r,n){if(\"undefined\"!=typeof t)return n===e.length-1&&delete t[r],t[r]},t),r.reduce(function(t,e,n){return\"undefined\"==typeof t[e]&&(t[e]={}),n===r.length-1&&(t[e]=a),t[e]},t))},o.PolyChart=function(){var t=[o.PolyChart.defaultConfig()],e=n.dispatch(\"hover\"),r={solid:\"none\",dash:[5,2],dot:[2,5]};function a(){var e=t[0].geometryConfig,i=e.container;\"string\"==typeof i&&(i=n.select(i)),i.datum(t).each(function(t,i){var a=!!t[0].data.yStack,o=t.map(function(t,e){return a?n.zip(t.data.t[0],t.data.r[0],t.data.yStack[0]):n.zip(t.data.t[0],t.data.r[0])}),s=e.angularScale,l=e.radialScale.domain()[0],c={bar:function(r,i,a){var o=t[a].data,l=e.radialScale(r[1])-e.radialScale(0),c=e.radialScale(r[2]||0),u=o.barWidth;n.select(this).attr({class:\"mark bar\",d:\"M\"+[[l+c,-u/2],[l+c,u/2],[c,u/2],[c,-u/2]].join(\"L\")+\"Z\",transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0]))+\")\"}})}};c.dot=function(r,i,a){var o=r[2]?[r[0],r[1]+r[2]]:r,s=n.svg.symbol().size(t[a].data.dotSize).type(t[a].data.dotType)(r,i);n.select(this).attr({class:\"mark dot\",d:s,transform:function(t,r){var n,i,a,s=(n=function(t,r){var n=e.radialScale(t[1]),i=(e.angularScale(t[0])+e.orientation)*Math.PI/180;return{r:n,t:i}}(o),i=n.r*Math.cos(n.t),a=n.r*Math.sin(n.t),{x:i,y:a});return\"translate(\"+[s.x,s.y]+\")\"}})};var u=n.svg.line.radial().interpolate(t[0].data.lineInterpolation).radius(function(t){return e.radialScale(t[1])}).angle(function(t){return e.angularScale(t[0])*Math.PI/180});c.line=function(r,i,a){var s=r[2]?o[a].map(function(t,e){return[t[0],t[1]+t[2]]}):o[a];if(n.select(this).each(c.dot).style({opacity:function(e,r){return+t[a].data.dotVisible},fill:d.stroke(r,i,a)}).attr({class:\"mark dot\"}),!(i>0)){var l=n.select(this.parentNode).selectAll(\"path.line\").data([0]);l.enter().insert(\"path\"),l.attr({class:\"line\",d:u(s),transform:function(t,r){return\"rotate(\"+(e.orientation+90)+\")\"},\"pointer-events\":\"none\"}).style({fill:function(t,e){return d.fill(r,i,a)},\"fill-opacity\":0,stroke:function(t,e){return d.stroke(r,i,a)},\"stroke-width\":function(t,e){return d[\"stroke-width\"](r,i,a)},\"stroke-dasharray\":function(t,e){return d[\"stroke-dasharray\"](r,i,a)},opacity:function(t,e){return d.opacity(r,i,a)},display:function(t,e){return d.display(r,i,a)}})}};var h=e.angularScale.range(),f=Math.abs(h[1]-h[0])/o[0].length*Math.PI/180,p=n.svg.arc().startAngle(function(t){return-f/2}).endAngle(function(t){return f/2}).innerRadius(function(t){return e.radialScale(l+(t[2]||0))}).outerRadius(function(t){return e.radialScale(l+(t[2]||0))+e.radialScale(t[1])});c.arc=function(t,r,i){n.select(this).attr({class:\"mark arc\",d:p,transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0])+90)+\")\"}})};var d={fill:function(e,r,n){return t[n].data.color},stroke:function(e,r,n){return t[n].data.strokeColor},\"stroke-width\":function(e,r,n){return t[n].data.strokeSize+\"px\"},\"stroke-dasharray\":function(e,n,i){return r[t[i].data.strokeDash]},opacity:function(e,r,n){return t[n].data.opacity},display:function(e,r,n){return\"undefined\"==typeof t[n].data.visible||t[n].data.visible?\"block\":\"none\"}},g=n.select(this).selectAll(\"g.layer\").data(o);g.enter().append(\"g\").attr({class:\"layer\"});var v=g.selectAll(\"path.mark\").data(function(t,e){return t});v.enter().append(\"path\").attr({class:\"mark\"}),v.style(d).each(c[e.geometryType]),v.exit().remove(),g.exit().remove()})}return a.config=function(e){return arguments.length?(e.forEach(function(e,r){t[r]||(t[r]={}),i(t[r],o.PolyChart.defaultConfig()),i(t[r],e)}),this):t},a.getColorScale=function(){},n.rebind(a,e,\"on\"),a},o.PolyChart.defaultConfig=function(){return{data:{name:\"geom1\",t:[[1,2,3,4]],r:[[1,2,3,4]],dotType:\"circle\",dotSize:64,dotVisible:!1,barWidth:20,color:\"#ffa500\",strokeSize:1,strokeColor:\"silver\",strokeDash:\"solid\",opacity:1,index:0,visible:!0,visibleInLegend:!0},geometryConfig:{geometry:\"LinePlot\",geometryType:\"arc\",direction:\"clockwise\",orientation:0,container:\"body\",radialScale:null,angularScale:null,colorScale:n.scale.category20()}}},o.BarChart=function(){return o.PolyChart()},o.BarChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"bar\"}}},o.AreaChart=function(){return o.PolyChart()},o.AreaChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"arc\"}}},o.DotPlot=function(){return o.PolyChart()},o.DotPlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"dot\",dotType:\"circle\"}}},o.LinePlot=function(){return o.PolyChart()},o.LinePlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"line\"}}},o.Legend=function(){var t=o.Legend.defaultConfig(),e=n.dispatch(\"hover\");function r(){var e=t.legendConfig,a=t.data.map(function(t,r){return[].concat(t).map(function(t,n){var a=i({},e.elements[r]);return a.name=t,a.color=[].concat(e.elements[r].color)[n],a})}),o=n.merge(a);o=o.filter(function(t,r){return e.elements[r]&&(e.elements[r].visibleInLegend||\"undefined\"==typeof e.elements[r].visibleInLegend)}),e.reverseOrder&&(o=o.reverse());var s=e.container;(\"string\"==typeof s||s.nodeName)&&(s=n.select(s));var l=o.map(function(t,e){return t.color}),c=e.fontSize,u=null==e.isContinuous?\"number\"==typeof o[0]:e.isContinuous,h=u?e.height:c*o.length,f=s.classed(\"legend-group\",!0).selectAll(\"svg\").data([0]),p=f.enter().append(\"svg\").attr({width:300,height:h+c,xmlns:\"http://www.w3.org/2000/svg\",\"xmlns:xlink\":\"http://www.w3.org/1999/xlink\",version:\"1.1\"});p.append(\"g\").classed(\"legend-axis\",!0),p.append(\"g\").classed(\"legend-marks\",!0);var d=n.range(o.length),g=n.scale[u?\"linear\":\"ordinal\"]().domain(d).range(l),v=n.scale[u?\"linear\":\"ordinal\"]().domain(d)[u?\"range\":\"rangePoints\"]([0,h]);if(u){var m=f.select(\".legend-marks\").append(\"defs\").append(\"linearGradient\").attr({id:\"grad1\",x1:\"0%\",y1:\"0%\",x2:\"0%\",y2:\"100%\"}).selectAll(\"stop\").data(l);m.enter().append(\"stop\"),m.attr({offset:function(t,e){return e/(l.length-1)*100+\"%\"}}).style({\"stop-color\":function(t,e){return t}}),f.append(\"rect\").classed(\"legend-mark\",!0).attr({height:e.height,width:e.colorBandWidth,fill:\"url(#grad1)\"})}else{var y=f.select(\".legend-marks\").selectAll(\"path.legend-mark\").data(o);y.enter().append(\"path\").classed(\"legend-mark\",!0),y.attr({transform:function(t,e){return\"translate(\"+[c/2,v(e)+c/2]+\")\"},d:function(t,e){var r,i,a,o=t.symbol;return a=3*(i=c),\"line\"===(r=o)?\"M\"+[[-i/2,-i/12],[i/2,-i/12],[i/2,i/12],[-i/2,i/12]]+\"Z\":-1!=n.svg.symbolTypes.indexOf(r)?n.svg.symbol().type(r).size(a)():n.svg.symbol().type(\"square\").size(a)()},fill:function(t,e){return g(e)}}),y.exit().remove()}var x=n.svg.axis().scale(v).orient(\"right\"),b=f.select(\"g.legend-axis\").attr({transform:\"translate(\"+[u?e.colorBandWidth:c,c/2]+\")\"}).call(x);return b.selectAll(\".domain\").style({fill:\"none\",stroke:\"none\"}),b.selectAll(\"line\").style({fill:\"none\",stroke:u?e.textColor:\"none\"}),b.selectAll(\"text\").style({fill:e.textColor,\"font-size\":e.fontSize}).text(function(t,e){return o[e].name}),r}return r.config=function(e){return arguments.length?(i(t,e),this):t},n.rebind(r,e,\"on\"),r},o.Legend.defaultConfig=function(t,e){return{data:[\"a\",\"b\",\"c\"],legendConfig:{elements:[{symbol:\"line\",color:\"red\"},{symbol:\"square\",color:\"yellow\"},{symbol:\"diamond\",color:\"limegreen\"}],height:150,colorBandWidth:30,fontSize:12,container:\"body\",isContinuous:null,textColor:\"grey\",reverseOrder:!1}}},o.tooltipPanel=function(){var t,e,r,a={container:null,hasTick:!1,fontSize:12,color:\"white\",padding:5},s=\"tooltip-\"+o.tooltipPanel.uid++,l=10,c=function(){var n=(t=a.container.selectAll(\"g.\"+s).data([0])).enter().append(\"g\").classed(s,!0).style({\"pointer-events\":\"none\",display:\"none\"});return r=n.append(\"path\").style({fill:\"white\",\"fill-opacity\":.9}).attr({d:\"M0 0\"}),e=n.append(\"text\").attr({dx:a.padding+l,dy:.3*+a.fontSize}),c};return c.text=function(i){var o=n.hsl(a.color).l,s=o>=.5?\"#aaa\":\"white\",u=o>=.5?\"black\":\"white\",h=i||\"\";e.style({fill:u,\"font-size\":a.fontSize+\"px\"}).text(h);var f=a.padding,p=e.node().getBBox(),d={fill:a.color,stroke:s,\"stroke-width\":\"2px\"},g=p.width+2*f+l,v=p.height+2*f;return r.attr({d:\"M\"+[[l,-v/2],[l,-v/4],[a.hasTick?0:l,0],[l,v/4],[l,v/2],[g,v/2],[g,-v/2]].join(\"L\")+\"Z\"}).style(d),t.attr({transform:\"translate(\"+[l,-v/2+2*f]+\")\"}),t.style({display:\"block\"}),c},c.move=function(e){if(t)return t.attr({transform:\"translate(\"+[e[0],e[1]]+\")\"}).style({display:\"block\"}),c},c.hide=function(){if(t)return t.style({display:\"none\"}),c},c.show=function(){if(t)return t.style({display:\"block\"}),c},c.config=function(t){return i(a,t),c},c},o.tooltipPanel.uid=1,o.adapter={},o.adapter.plotly=function(){var t={convert:function(t,e){var r={};if(t.data&&(r.data=t.data.map(function(t,r){var n=i({},t);return[[n,[\"marker\",\"color\"],[\"color\"]],[n,[\"marker\",\"opacity\"],[\"opacity\"]],[n,[\"marker\",\"line\",\"color\"],[\"strokeColor\"]],[n,[\"marker\",\"line\",\"dash\"],[\"strokeDash\"]],[n,[\"marker\",\"line\",\"width\"],[\"strokeSize\"]],[n,[\"marker\",\"symbol\"],[\"dotType\"]],[n,[\"marker\",\"size\"],[\"dotSize\"]],[n,[\"marker\",\"barWidth\"],[\"barWidth\"]],[n,[\"line\",\"interpolation\"],[\"lineInterpolation\"]],[n,[\"showlegend\"],[\"visibleInLegend\"]]].forEach(function(t,r){o.util.translator.apply(null,t.concat(e))}),e||delete n.marker,e&&delete n.groupId,e?(\"LinePlot\"===n.geometry?(n.type=\"scatter\",!0===n.dotVisible?(delete n.dotVisible,n.mode=\"lines+markers\"):n.mode=\"lines\"):\"DotPlot\"===n.geometry?(n.type=\"scatter\",n.mode=\"markers\"):\"AreaChart\"===n.geometry?n.type=\"area\":\"BarChart\"===n.geometry&&(n.type=\"bar\"),delete n.geometry):(\"scatter\"===n.type?\"lines\"===n.mode?n.geometry=\"LinePlot\":\"markers\"===n.mode?n.geometry=\"DotPlot\":\"lines+markers\"===n.mode&&(n.geometry=\"LinePlot\",n.dotVisible=!0):\"area\"===n.type?n.geometry=\"AreaChart\":\"bar\"===n.type&&(n.geometry=\"BarChart\"),delete n.mode,delete n.type),n}),!e&&t.layout&&\"stack\"===t.layout.barmode)){var a=o.util.duplicates(r.data.map(function(t,e){return t.geometry}));r.data.forEach(function(t,e){var n=a.indexOf(t.geometry);-1!=n&&(r.data[e].groupId=n)})}if(t.layout){var s=i({},t.layout);if([[s,[\"plot_bgcolor\"],[\"backgroundColor\"]],[s,[\"showlegend\"],[\"showLegend\"]],[s,[\"radialaxis\"],[\"radialAxis\"]],[s,[\"angularaxis\"],[\"angularAxis\"]],[s.angularaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularaxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularaxis,[\"nticks\"],[\"ticksCount\"]],[s.angularaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularaxis,[\"range\"],[\"domain\"]],[s.angularaxis,[\"endpadding\"],[\"endPadding\"]],[s.radialaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialaxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularAxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularAxis,[\"nticks\"],[\"ticksCount\"]],[s.angularAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularAxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"endpadding\"],[\"endPadding\"]],[s.radialAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialAxis,[\"range\"],[\"domain\"]],[s.font,[\"outlinecolor\"],[\"outlineColor\"]],[s.legend,[\"traceorder\"],[\"reverseOrder\"]],[s,[\"labeloffset\"],[\"labelOffset\"]],[s,[\"defaultcolorrange\"],[\"defaultColorRange\"]]].forEach(function(t,r){o.util.translator.apply(null,t.concat(e))}),e?(\"undefined\"!=typeof s.tickLength&&(s.angularaxis.ticklen=s.tickLength,delete s.tickLength),s.tickColor&&(s.angularaxis.tickcolor=s.tickColor,delete s.tickColor)):(s.angularAxis&&\"undefined\"!=typeof s.angularAxis.ticklen&&(s.tickLength=s.angularAxis.ticklen),s.angularAxis&&\"undefined\"!=typeof s.angularAxis.tickcolor&&(s.tickColor=s.angularAxis.tickcolor)),s.legend&&\"boolean\"!=typeof s.legend.reverseOrder&&(s.legend.reverseOrder=\"normal\"!=s.legend.reverseOrder),s.legend&&\"boolean\"==typeof s.legend.traceorder&&(s.legend.traceorder=s.legend.traceorder?\"reversed\":\"normal\",delete s.legend.reverseOrder),s.margin&&\"undefined\"!=typeof s.margin.t){var l=[\"t\",\"r\",\"b\",\"l\",\"pad\"],c=[\"top\",\"right\",\"bottom\",\"left\",\"pad\"],u={};n.entries(s.margin).forEach(function(t,e){u[c[l.indexOf(t.key)]]=t.value}),s.margin=u}e&&(delete s.needsEndSpacing,delete s.minorTickColor,delete s.minorTicks,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksStep,delete s.angularaxis.rewriteTicks,delete s.angularaxis.nticks,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksStep,delete s.radialaxis.rewriteTicks,delete s.radialaxis.nticks),r.layout=s}return r}};return t}},{\"../../../constants/alignment\":688,\"../../../lib\":719,d3:163}],838:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../../lib\"),a=t(\"../../../components/color\"),o=t(\"./micropolar\"),s=t(\"./undo_manager\"),l=i.extendDeepAll,c=e.exports={};c.framework=function(t){var e,r,i,a,u,h=new s;function f(r,s){return s&&(u=s),n.select(n.select(u).node().parentNode).selectAll(\".svg-container>*:not(.chart-root)\").remove(),e=e?l(e,r):r,i||(i=o.Axis()),a=o.adapter.plotly().convert(e),i.config(a).render(u),t.data=e.data,t.layout=e.layout,c.fillLayout(t),e}return f.isPolar=!0,f.svg=function(){return i.svg()},f.getConfig=function(){return e},f.getLiveConfig=function(){return o.adapter.plotly().convert(i.getLiveConfig(),!0)},f.getLiveScales=function(){return{t:i.angularScale(),r:i.radialScale()}},f.setUndoPoint=function(){var t,n,i=this,a=o.util.cloneJson(e);t=a,n=r,h.add({undo:function(){n&&i(n)},redo:function(){i(t)}}),r=o.util.cloneJson(a)},f.undo=function(){h.undo()},f.redo=function(){h.redo()},f},c.fillLayout=function(t){var e=n.select(t).selectAll(\".plot-container\"),r=e.selectAll(\".svg-container\"),i=t.framework&&t.framework.svg&&t.framework.svg(),o={width:800,height:600,paper_bgcolor:a.background,_container:e,_paperdiv:r,_paper:i};t._fullLayout=l(o,t.layout)}},{\"../../../components/color\":593,\"../../../lib\":719,\"./micropolar\":837,\"./undo_manager\":839,d3:163}],839:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=[],r=-1,n=!1;function i(t,e){return t?(n=!0,t[e](),n=!1,this):this}return{add:function(t){return n?this:(e.splice(r+1,e.length-r),e.push(t),r=e.length-1,this)},setCallback:function(e){t=e},undo:function(){var n=e[r];return n?(i(n,\"undo\"),r-=1,t&&t(n.undo),this):this},redo:function(){var n=e[r+1];return n?(i(n,\"redo\"),r+=1,t&&t(n.redo),this):this},clear:function(){e=[],r=-1},hasUndo:function(){return-1!==r},hasRedo:function(){return r<e.length-1},getCommands:function(){return e},getPreviousCommand:function(){return e[r-1]},getIndex:function(){return r}}}},{}],840:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../plots\"),u=t(\"../../plots/cartesian/axes\"),h=t(\"../cartesian/set_convert\"),f=t(\"./set_convert\"),p=t(\"../cartesian/autorange\").doAutoRange,d=t(\"../cartesian/dragbox\"),g=t(\"../../components/dragelement\"),v=t(\"../../components/fx\"),m=t(\"../../components/titles\"),y=t(\"../cartesian/select\").prepSelect,x=t(\"../cartesian/select\").selectOnClick,b=t(\"../cartesian/select\").clearSelect,_=t(\"../../lib/setcursor\"),w=t(\"../../lib/clear_gl_canvases\"),k=t(\"../../plot_api/subroutines\").redrawReglTraces,T=t(\"../../constants/alignment\").MID_SHIFT,A=t(\"./constants\"),M=t(\"./helpers\"),S=o._,E=o.mod,C=o.deg2rad,L=o.rad2deg;function P(t,e){this.id=e,this.gd=t,this._hasClipOnAxisFalse=null,this.vangles=null,this.radialAxisAngle=null,this.traceHash={},this.layers={},this.clipPaths={},this.clipIds={},this.viewInitial={};var r=t._fullLayout,n=\"clip\"+r._uid+e;this.clipIds.forTraces=n+\"-for-traces\",this.clipPaths.forTraces=r._clips.append(\"clipPath\").attr(\"id\",this.clipIds.forTraces),this.clipPaths.forTraces.append(\"path\"),this.framework=r._polarlayer.append(\"g\").attr(\"class\",e),this.radialTickLayout=null,this.angularTickLayout=null}var O=P.prototype;function z(t){var e=t.ticks+String(t.ticklen)+String(t.showticklabels);return\"side\"in t&&(e+=t.side),e}function I(t,e){return e[o.findIndexOfMin(e,function(e){return o.angleDist(t,e)})]}function D(t,e,r){return e?(t.attr(\"display\",null),t.attr(r)):t&&t.attr(\"display\",\"none\"),t}function R(t,e){return\"translate(\"+t+\",\"+e+\")\"}function F(t){return\"rotate(\"+t+\")\"}e.exports=function(t,e){return new P(t,e)},O.plot=function(t,e){var r=e[this.id];this._hasClipOnAxisFalse=!1;for(var n=0;n<t.length;n++){if(!1===t[n][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(e,r),this.updateLayout(e,r),c.generalUpdatePerTraceModule(this.gd,this,t,r),this.updateFx(e,r)},O.updateLayers=function(t,e){var r=this.layers,i=e.radialaxis,a=e.angularaxis,o=A.layerNames,s=o.indexOf(\"frontplot\"),l=o.slice(0,s),c=\"below traces\"===a.layer,u=\"below traces\"===i.layer;c&&l.push(\"angular-line\"),u&&l.push(\"radial-line\"),c&&l.push(\"angular-axis\"),u&&l.push(\"radial-axis\"),l.push(\"frontplot\"),c||l.push(\"angular-line\"),u||l.push(\"radial-line\"),c||l.push(\"angular-axis\"),u||l.push(\"radial-axis\");var h=this.framework.selectAll(\".polarsublayer\").data(l,String);h.enter().append(\"g\").attr(\"class\",function(t){return\"polarsublayer \"+t}).each(function(t){var e=r[t]=n.select(this);switch(t){case\"frontplot\":e.append(\"g\").classed(\"barlayer\",!0),e.append(\"g\").classed(\"scatterlayer\",!0);break;case\"backplot\":e.append(\"g\").classed(\"maplayer\",!0);break;case\"plotbg\":r.bg=e.append(\"path\");break;case\"radial-grid\":case\"angular-grid\":e.style(\"fill\",\"none\");break;case\"radial-line\":e.append(\"line\").style(\"fill\",\"none\");break;case\"angular-line\":e.append(\"path\").style(\"fill\",\"none\")}}),h.order()},O.updateLayout=function(t,e){var r=this.layers,n=t._size,i=e.radialaxis,a=e.angularaxis,o=e.domain.x,c=e.domain.y;this.xOffset=n.l+n.w*o[0],this.yOffset=n.t+n.h*(1-c[1]);var u=this.xLength=n.w*(o[1]-o[0]),h=this.yLength=n.h*(c[1]-c[0]),f=e.sector;this.sectorInRad=f.map(C);var p,d,g,v,m,y=this.sectorBBox=function(t){var e,r,n,i,a=t[0],o=t[1]-a,s=E(a,360),l=s+o,c=Math.cos(C(s)),u=Math.sin(C(s)),h=Math.cos(C(l)),f=Math.sin(C(l));i=s<=90&&l>=90||s>90&&l>=450?1:u<=0&&f<=0?0:Math.max(u,f);e=s<=180&&l>=180||s>180&&l>=540?-1:c>=0&&h>=0?0:Math.min(c,h);r=s<=270&&l>=270||s>270&&l>=630?-1:u>=0&&f>=0?0:Math.min(u,f);n=l>=360?1:c<=0&&h<=0?0:Math.max(c,h);return[e,r,n,i]}(f),x=y[2]-y[0],b=y[3]-y[1],_=h/u,w=Math.abs(b/x);_>w?(p=u,m=(h-(d=u*w))/n.h/2,g=[o[0],o[1]],v=[c[0]+m,c[1]-m]):(d=h,m=(u-(p=h/w))/n.w/2,g=[o[0]+m,o[1]-m],v=[c[0],c[1]]),this.xLength2=p,this.yLength2=d,this.xDomain2=g,this.yDomain2=v;var k=this.xOffset2=n.l+n.w*g[0],T=this.yOffset2=n.t+n.h*(1-v[1]),A=this.radius=p/x,M=this.innerRadius=e.hole*A,S=this.cx=k-A*y[0],L=this.cy=T+A*y[3],P=this.cxx=S-k,O=this.cyy=L-T;this.radialAxis=this.mockAxis(t,e,i,{_id:\"x\",side:{counterclockwise:\"top\",clockwise:\"bottom\"}[i.side],domain:[M/n.w,A/n.w]}),this.angularAxis=this.mockAxis(t,e,a,{side:\"right\",domain:[0,Math.PI],autorange:!1}),this.doAutoRange(t,e),this.updateAngularAxis(t,e),this.updateRadialAxis(t,e),this.updateRadialAxisTitle(t,e),this.xaxis=this.mockCartesianAxis(t,e,{_id:\"x\",domain:g}),this.yaxis=this.mockCartesianAxis(t,e,{_id:\"y\",domain:v});var z=this.pathSubplot();this.clipPaths.forTraces.select(\"path\").attr(\"d\",z).attr(\"transform\",R(P,O)),r.frontplot.attr(\"transform\",R(k,T)).call(l.setClipUrl,this._hasClipOnAxisFalse?null:this.clipIds.forTraces,this.gd),r.bg.attr(\"d\",z).attr(\"transform\",R(S,L)).call(s.fill,e.bgcolor)},O.mockAxis=function(t,e,r,n){var i=o.extendFlat({anchor:\"free\",position:0},r,n);return f(i,e,t),i},O.mockCartesianAxis=function(t,e,r){var n=this,i=r._id,a=o.extendFlat({type:\"linear\"},r);h(a,t);var s={x:[0,2],y:[1,3]};return a.setRange=function(){var t=n.sectorBBox,r=s[i],o=n.radialAxis._rl,l=(o[1]-o[0])/(1-e.hole);a.range=[t[r[0]]*l,t[r[1]]*l]},a.isPtWithinRange=\"x\"===i?function(t){return n.isPtInside(t)}:function(){return!0},a.setRange(),a.setScale(),a},O.doAutoRange=function(t,e){var r=this.gd,n=this.radialAxis,i=e.radialaxis;n.setScale(),p(r,n);var a=n.range;i.range=a.slice(),i._input.range=a.slice(),n._rl=[n.r2l(a[0],null,\"gregorian\"),n.r2l(a[1],null,\"gregorian\")]},O.updateRadialAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,l=r.innerRadius,c=r.cx,h=r.cy,f=e.radialaxis,p=E(e.sector[0],360),d=r.radialAxis,g=l<a;r.fillViewInitialKey(\"radialaxis.angle\",f.angle),r.fillViewInitialKey(\"radialaxis.range\",d.range.slice()),d.setGeometry(),\"auto\"===d.tickangle&&p>90&&p<=270&&(d.tickangle=180);var v=function(t){return\"translate(\"+(d.l2p(t.x)+l)+\",0)\"},m=z(f);if(r.radialTickLayout!==m&&(i[\"radial-axis\"].selectAll(\".xtick\").remove(),r.radialTickLayout=m),g){d.setScale();var y=u.calcTicks(d),x=u.clipEnds(d,y),b=u.getTickSigns(d)[2];u.drawTicks(n,d,{vals:y,layer:i[\"radial-axis\"],path:u.makeTickPath(d,0,b),transFn:v,crisp:!1}),u.drawGrid(n,d,{vals:x,layer:i[\"radial-grid\"],path:function(t){return r.pathArc(d.r2p(t.x)+l)},transFn:o.noop,crisp:!1}),u.drawLabels(n,d,{vals:y,layer:i[\"radial-axis\"],transFn:v,labelFns:u.makeLabelFns(d,0)})}var _=r.radialAxisAngle=r.vangles?L(I(C(f.angle),r.vangles)):f.angle,w=R(c,h),k=w+F(-_);D(i[\"radial-axis\"],g&&(f.showticklabels||f.ticks),{transform:k}),D(i[\"radial-grid\"],g&&f.showgrid,{transform:w}),D(i[\"radial-line\"].select(\"line\"),g&&f.showline,{x1:l,y1:0,x2:a,y2:0,transform:k}).attr(\"stroke-width\",f.linewidth).call(s.stroke,f.linecolor)},O.updateRadialAxisTitle=function(t,e,r){var n=this.gd,i=this.radius,a=this.cx,o=this.cy,s=e.radialaxis,c=this.id+\"title\",u=void 0!==r?r:this.radialAxisAngle,h=C(u),f=Math.cos(h),p=Math.sin(h),d=0;if(s.title){var g=l.bBox(this.layers[\"radial-axis\"].node()).height,v=s.title.font.size;d=\"counterclockwise\"===s.side?-g-.4*v:g+.8*v}this.layers[\"radial-axis-title\"]=m.draw(n,c,{propContainer:s,propName:this.id+\".radialaxis.title\",placeholder:S(n,\"Click to enter radial axis title\"),attributes:{x:a+i/2*f+d*p,y:o-i/2*p+d*f,\"text-anchor\":\"middle\"},transform:{rotate:-u}})},O.updateAngularAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,l=r.innerRadius,c=r.cx,h=r.cy,f=e.angularaxis,p=r.angularAxis;r.fillViewInitialKey(\"angularaxis.rotation\",f.rotation),p.setGeometry(),p.setScale();var d=function(t){return p.t2g(t.x)};\"linear\"===p.type&&\"radians\"===p.thetaunit&&(p.tick0=L(p.tick0),p.dtick=L(p.dtick));var g=function(t){return R(c+a*Math.cos(t),h-a*Math.sin(t))},v=u.makeLabelFns(p,0).labelStandoff,m={xFn:function(t){var e=d(t);return Math.cos(e)*v},yFn:function(t){var e=d(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(v+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*T)},anchorFn:function(t){var e=d(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},heightFn:function(t,e,r){var n=d(t);return-.5*(1+Math.sin(n))*r}},y=z(f);r.angularTickLayout!==y&&(i[\"angular-axis\"].selectAll(\".\"+p._id+\"tick\").remove(),r.angularTickLayout=y);var x,b=u.calcTicks(p);if(\"linear\"===e.gridshape?(x=b.map(d),o.angleDelta(x[0],x[1])<0&&(x=x.slice().reverse())):x=null,r.vangles=x,\"category\"===p.type&&(b=b.filter(function(t){return o.isAngleInsideSector(d(t),r.sectorInRad)})),p.visible){var _=\"inside\"===p.ticks?-1:1,w=(p.linewidth||1)/2;u.drawTicks(n,p,{vals:b,layer:i[\"angular-axis\"],path:\"M\"+_*w+\",0h\"+_*p.ticklen,transFn:function(t){var e=d(t);return g(e)+F(-L(e))},crisp:!1}),u.drawGrid(n,p,{vals:b,layer:i[\"angular-grid\"],path:function(t){var e=d(t),r=Math.cos(e),n=Math.sin(e);return\"M\"+[c+l*r,h-l*n]+\"L\"+[c+a*r,h-a*n]},transFn:o.noop,crisp:!1}),u.drawLabels(n,p,{vals:b,layer:i[\"angular-axis\"],repositionOnUpdate:!0,transFn:function(t){return g(d(t))},labelFns:m})}D(i[\"angular-line\"].select(\"path\"),f.showline,{d:r.pathSubplot(),transform:R(c,h)}).attr(\"stroke-width\",f.linewidth).call(s.stroke,f.linecolor)},O.updateFx=function(t,e){this.gd._context.staticPlot||(this.updateAngularDrag(t),this.updateRadialDrag(t,e,0),this.updateRadialDrag(t,e,1),this.updateMainDrag(t))},O.updateMainDrag=function(t){var e=this,r=e.gd,o=e.layers,s=t._zoomlayer,l=A.MINZOOM,c=A.OFFEDGE,u=e.radius,h=e.innerRadius,f=e.cx,p=e.cy,m=e.cxx,_=e.cyy,w=e.sectorInRad,k=e.vangles,T=e.radialAxis,S=M.clampTiny,E=M.findXYatLength,C=M.findEnclosingVertexAngles,L=A.cornerHalfWidth,P=A.cornerLen/2,O=d.makeDragger(o,\"path\",\"maindrag\",\"crosshair\");n.select(O).attr(\"d\",e.pathSubplot()).attr(\"transform\",R(f,p));var z,I,D,F,B,N,j,U,V,q={element:O,gd:r,subplot:e.id,plotinfo:{id:e.id,xaxis:e.xaxis,yaxis:e.yaxis},xaxes:[e.xaxis],yaxes:[e.yaxis]};function H(t,e){return Math.sqrt(t*t+e*e)}function G(t,e){return H(t-m,e-_)}function Y(t,e){return Math.atan2(_-e,t-m)}function W(t,e){return[t*Math.cos(e),t*Math.sin(-e)]}function X(t,r){if(0===t)return e.pathSector(2*L);var n=P/t,i=r-n,a=r+n,o=Math.max(0,Math.min(t,u)),s=o-L,l=o+L;return\"M\"+W(s,i)+\"A\"+[s,s]+\" 0,0,0 \"+W(s,a)+\"L\"+W(l,a)+\"A\"+[l,l]+\" 0,0,1 \"+W(l,i)+\"Z\"}function Z(t,r,n){if(0===t)return e.pathSector(2*L);var i,a,o=W(t,r),s=W(t,n),l=S((o[0]+s[0])/2),c=S((o[1]+s[1])/2);if(l&&c){var u=c/l,h=-1/u,f=E(L,u,l,c);i=E(P,h,f[0][0],f[0][1]),a=E(P,h,f[1][0],f[1][1])}else{var p,d;c?(p=P,d=L):(p=L,d=P),i=[[l-p,c-d],[l+p,c-d]],a=[[l-p,c+d],[l+p,c+d]]}return\"M\"+i.join(\"L\")+\"L\"+a.reverse().join(\"L\")+\"Z\"}function J(t,e){return e=Math.max(Math.min(e,u),h),t<c?t=0:u-t<c?t=u:e<c?e=0:u-e<c&&(e=u),Math.abs(e-t)>l?(t<e?(D=t,F=e):(D=e,F=t),!0):(D=null,F=null,!1)}function K(t,e){t=t||B,e=e||\"M0,0Z\",U.attr(\"d\",t),V.attr(\"d\",e),d.transitionZoombox(U,V,N,j),N=!0;var n={};rt(n),r.emit(\"plotly_relayouting\",n)}function $(t,r){var n,i,a=z+t,o=I+r,s=G(z,I),l=Math.min(G(a,o),u),c=Y(z,I);J(s,l)&&(n=B+e.pathSector(F),D&&(n+=e.pathSector(D)),i=X(D,c)+X(F,c)),K(n,i)}function Q(t,e,r,n){var i=M.findIntersectionXY(r,n,r,[t-m,_-e]);return H(i[0],i[1])}function tt(t,r){var n,i,a=z+t,o=I+r,s=Y(z,I),l=Y(a,o),c=C(s,k),h=C(l,k);J(Q(z,I,c[0],c[1]),Math.min(Q(a,o,h[0],h[1]),u))&&(n=B+e.pathSector(F),D&&(n+=e.pathSector(D)),i=[Z(D,c[0],c[1]),Z(F,c[0],c[1])].join(\" \")),K(n,i)}function et(){if(d.removeZoombox(r),null!==D&&null!==F){var t={};rt(t),d.showDoubleClickNotifier(r),a.call(\"_guiRelayout\",r,t)}}function rt(t){var r=T._rl,n=(r[1]-r[0])/(1-h/u)/u,i=[r[0]+(D-h)*n,r[0]+(F-h)*n];t[e.id+\".radialaxis.range\"]=i}function nt(t,n){var i=r._fullLayout.clickmode;if(d.removeZoombox(r),2===t){var o={};for(var s in e.viewInitial)o[e.id+\".\"+s]=e.viewInitial[s];r.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",r,o)}i.indexOf(\"select\")>-1&&1===t&&x(n,r,[e.xaxis],[e.yaxis],e.id,q),i.indexOf(\"event\")>-1&&v.click(r,n,e.id)}q.prepFn=function(t,n,a){var o=r._fullLayout.dragmode,l=O.getBoundingClientRect();if(z=n-l.left,I=a-l.top,k){var c=M.findPolygonOffset(u,w[0],w[1],k);z+=m+c[0],I+=_+c[1]}switch(o){case\"zoom\":q.moveFn=k?tt:$,q.clickFn=nt,q.doneFn=et,function(){D=null,F=null,B=e.pathSubplot(),N=!1;var t=r._fullLayout[e.id];j=i(t.bgcolor).getLuminance(),(U=d.makeZoombox(s,j,f,p,B)).attr(\"fill-rule\",\"evenodd\"),V=d.makeCorners(s,f,p),b(r)}();break;case\"select\":case\"lasso\":y(t,n,a,q,o)}},O.onmousemove=function(t){v.hover(r,t,e.id),r._fullLayout._lasthover=O,r._fullLayout._hoversubplot=e.id},O.onmouseout=function(t){r._dragging||g.unhover(r,t)},g.init(q)},O.updateRadialDrag=function(t,e,r){var i=this,s=i.gd,l=i.layers,c=i.radius,u=i.innerRadius,h=i.cx,f=i.cy,p=i.radialAxis,v=A.radialDragBoxSize,m=v/2;if(p.visible){var y,x,_,T=C(i.radialAxisAngle),M=p._rl,S=M[0],E=M[1],P=M[r],O=.75*(M[1]-M[0])/(1-e.hole)/c;r?(y=h+(c+m)*Math.cos(T),x=f-(c+m)*Math.sin(T),_=\"radialdrag\"):(y=h+(u-m)*Math.cos(T),x=f-(u-m)*Math.sin(T),_=\"radialdrag-inner\");var z,B,N,j=d.makeRectDragger(l,_,\"crosshair\",-m,-m,v,v),U={element:j,gd:s};D(n.select(j),p.visible&&u<c,{transform:R(y,x)}),U.prepFn=function(){z=null,B=null,N=null,U.moveFn=V,U.doneFn=q,b(s)},U.clampFn=function(t,e){return Math.sqrt(t*t+e*e)<A.MINDRAG&&(t=0,e=0),[t,e]},g.init(U)}function V(t,e){if(z)z(t,e);else{var n=[t,-e],a=[Math.cos(T),Math.sin(T)],l=Math.abs(o.dot(n,a)/Math.sqrt(o.dot(n,n)));isNaN(l)||(z=l<.5?H:G)}var c={};!function(t){null!==B?t[i.id+\".radialaxis.angle\"]=B:null!==N&&(t[i.id+\".radialaxis.range[\"+r+\"]\"]=N)}(c),s.emit(\"plotly_relayouting\",c)}function q(){null!==B?a.call(\"_guiRelayout\",s,i.id+\".radialaxis.angle\",B):null!==N&&a.call(\"_guiRelayout\",s,i.id+\".radialaxis.range[\"+r+\"]\",N)}function H(t,e){if(0!==r){var n=y+t,a=x+e;B=Math.atan2(f-a,n-h),i.vangles&&(B=I(B,i.vangles)),B=L(B);var o=R(h,f)+F(-B);l[\"radial-axis\"].attr(\"transform\",o),l[\"radial-line\"].select(\"line\").attr(\"transform\",o);var s=i.gd._fullLayout,c=s[i.id];i.updateRadialAxisTitle(s,c,B)}}function G(t,e){var n=o.dot([t,-e],[Math.cos(T),Math.sin(T)]);if(N=P-O*n,O>0==(r?N>S:N<E)){var l=s._fullLayout,c=l[i.id];p.range[r]=N,p._rl[r]=N,i.updateRadialAxis(l,c),i.xaxis.setRange(),i.xaxis.setScale(),i.yaxis.setRange(),i.yaxis.setScale();var u=!1;for(var h in i.traceHash){var f=i.traceHash[h],d=o.filterVisible(f);f[0][0].trace._module.plot(s,i,d,c),a.traceIs(h,\"gl\")&&d.length&&(u=!0)}u&&(w(s),k(s))}else N=null}},O.updateAngularDrag=function(t){var e=this,r=e.gd,i=e.layers,s=e.radius,c=e.angularAxis,u=e.cx,h=e.cy,f=e.cxx,p=e.cyy,v=A.angularDragBoxSize,m=d.makeDragger(i,\"path\",\"angulardrag\",\"move\"),y={element:m,gd:r};function x(t,e){return Math.atan2(p+v-e,t-f-v)}n.select(m).attr(\"d\",e.pathAnnulus(s,s+v)).attr(\"transform\",R(u,h)).call(_,\"move\");var T,M,S,E,C,P,O=i.frontplot.select(\".scatterlayer\").selectAll(\".trace\"),z=O.selectAll(\".point\"),I=O.selectAll(\".textpoint\");function D(t,s){var d=e.gd._fullLayout,g=d[e.id],v=x(T+t,M+s),m=L(v-P);if(E=S+m,i.frontplot.attr(\"transform\",R(e.xOffset2,e.yOffset2)+F([-m,f,p])),e.vangles){C=e.radialAxisAngle+m;var y=R(u,h)+F(-m),b=R(u,h)+F(-C);i.bg.attr(\"transform\",y),i[\"radial-grid\"].attr(\"transform\",y),i[\"radial-axis\"].attr(\"transform\",b),i[\"radial-line\"].select(\"line\").attr(\"transform\",b),e.updateRadialAxisTitle(d,g,C)}else e.clipPaths.forTraces.select(\"path\").attr(\"transform\",R(f,p)+F(m));z.each(function(){var t=n.select(this),e=l.getTranslate(t);t.attr(\"transform\",R(e.x,e.y)+F([m]))}),I.each(function(){var t=n.select(this),e=t.select(\"text\"),r=l.getTranslate(t);t.attr(\"transform\",F([m,e.attr(\"x\"),e.attr(\"y\")])+R(r.x,r.y))}),c.rotation=o.modHalf(E,360),e.updateAngularAxis(d,g),e._hasClipOnAxisFalse&&!o.isFullCircle(e.sectorInRad)&&O.call(l.hideOutsideRangePoints,e);var _=!1;for(var A in e.traceHash)if(a.traceIs(A,\"gl\")){var D=e.traceHash[A],N=o.filterVisible(D);D[0][0].trace._module.plot(r,e,N,g),N.length&&(_=!0)}_&&(w(r),k(r));var j={};B(j),r.emit(\"plotly_relayouting\",j)}function B(t){t[e.id+\".angularaxis.rotation\"]=E,e.vangles&&(t[e.id+\".radialaxis.angle\"]=C)}function N(){I.select(\"text\").attr(\"transform\",null);var t={};B(t),a.call(\"_guiRelayout\",r,t)}y.prepFn=function(n,i,a){var o=t[e.id];S=o.angularaxis.rotation;var s=m.getBoundingClientRect();T=i-s.left,M=a-s.top,P=x(T,M),y.moveFn=D,y.doneFn=N,b(r)},e.vangles&&!o.isFullCircle(e.sectorInRad)&&(y.prepFn=o.noop,_(n.select(m),null)),g.init(y)},O.isPtInside=function(t){var e=this.sectorInRad,r=this.vangles,n=this.angularAxis.c2g(t.theta),i=this.radialAxis,a=i.c2l(t.r),s=i._rl;return(r?M.isPtInsidePolygon:o.isPtInsideSector)(a,n,s,e,r)},O.pathArc=function(t){var e=this.sectorInRad,r=this.vangles;return(r?M.pathPolygon:o.pathArc)(t,e[0],e[1],r)},O.pathSector=function(t){var e=this.sectorInRad,r=this.vangles;return(r?M.pathPolygon:o.pathSector)(t,e[0],e[1],r)},O.pathAnnulus=function(t,e){var r=this.sectorInRad,n=this.vangles;return(n?M.pathPolygonAnnulus:o.pathAnnulus)(t,e,r[0],r[1],n)},O.pathSubplot=function(){var t=this.innerRadius,e=this.radius;return t?this.pathAnnulus(t,e):this.pathSector(e)},O.fillViewInitialKey=function(t,e){t in this.viewInitial||(this.viewInitial[t]=e)}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../components/titles\":681,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/clear_gl_canvases\":704,\"../../lib/setcursor\":739,\"../../plot_api/subroutines\":758,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../cartesian/autorange\":766,\"../cartesian/dragbox\":775,\"../cartesian/select\":784,\"../cartesian/set_convert\":785,\"../plots\":828,\"./constants\":829,\"./helpers\":830,\"./set_convert\":841,d3:163,tinycolor2:537}],841:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../cartesian/set_convert\"),a=n.deg2rad,o=n.rad2deg;e.exports=function(t,e,r){switch(i(t,r),t._id){case\"x\":case\"radialaxis\":!function(t,e){var r=e._subplot;t.setGeometry=function(){var e=t._rl[0],n=t._rl[1],i=r.innerRadius,a=(r.radius-i)/(n-e),o=i/a,s=e>n?function(t){return t<=0}:function(t){return t>=0};t.c2g=function(r){var n=t.c2l(r)-e;return(s(n)?n:0)+o},t.g2c=function(r){return t.l2c(r+e-o)},t.g2p=function(t){return t*a},t.c2p=function(e){return t.g2p(t.c2g(e))}}}(t,e);break;case\"angularaxis\":!function(t,e){var r=t.type;if(\"linear\"===r){var i=t.d2c,s=t.c2d;t.d2c=function(t,e){return function(t,e){return\"degrees\"===e?a(t):t}(i(t),e)},t.c2d=function(t,e){return s(function(t,e){return\"degrees\"===e?o(t):t}(t,e))}}t.makeCalcdata=function(e,i){var a,o,s=e[i],l=e._length,c=function(r){return t.d2c(r,e.thetaunit)};if(s){if(n.isTypedArray(s)&&\"linear\"===r){if(l===s.length)return s;if(s.subarray)return s.subarray(0,l)}for(a=new Array(l),o=0;o<l;o++)a[o]=c(s[o])}else{var u=i+\"0\",h=\"d\"+i,f=u in e?c(e[u]):0,p=e[h]?c(e[h]):(t.period||2*Math.PI)/l;for(a=new Array(l),o=0;o<l;o++)a[o]=f+o*p}return a},t.setGeometry=function(){var i,s,l,c,u=e.sector,h=u.map(a),f={clockwise:-1,counterclockwise:1}[t.direction],p=a(t.rotation),d=function(t){return f*t+p},g=function(t){return(t-p)/f};switch(r){case\"linear\":s=i=n.identity,c=a,l=o,t.range=n.isFullCircle(h)?[u[0],u[0]+360]:h.map(g).map(o);break;case\"category\":var v=t._categories.length,m=t.period?Math.max(t.period,v):v;0===m&&(m=1),s=c=function(t){return 2*t*Math.PI/m},i=l=function(t){return t*m/Math.PI/2},t.range=[0,m]}t.c2g=function(t){return d(s(t))},t.g2c=function(t){return i(g(t))},t.t2g=function(t){return d(c(t))},t.g2t=function(t){return l(g(t))}}}(t,e)}}},{\"../../lib\":719,\"../cartesian/set_convert\":785}],842:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\"),a=t(\"./domain\").defaults;e.exports=function(t,e,r,o){var s,l,c=o.type,u=o.attributes,h=o.handleDefaults,f=o.partition||\"x\",p=e._subplots[c],d=p.length,g=d&&p[0].replace(/\\d+$/,\"\");function v(t,e){return n.coerce(s,l,u,t,e)}for(var m=0;m<d;m++){var y=p[m];s=t[y]?t[y]:t[y]={},l=i.newContainer(e,y,g),v(\"uirevision\",e.uirevision);var x={};x[f]=[m/d,(m+1)/d],a(l,e,v,x),o.id=y,h(s,l,v,o)}}},{\"../lib\":719,\"../plot_api/plot_template\":757,\"./domain\":792}],843:[function(t,e,r){\"use strict\";var n=t(\"./ternary\"),i=t(\"../../plots/get_data\").getSubplotCalcData,a=t(\"../../lib\").counterRegex;r.name=\"ternary\";var o=r.attr=\"subplot\";r.idRoot=\"ternary\",r.idRegex=r.attrRegex=a(\"ternary\"),(r.attributes={})[o]={valType:\"subplotid\",dflt:\"ternary\",editType:\"calc\"},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t.calcdata,a=e._subplots.ternary,o=0;o<a.length;o++){var s=a[o],l=i(r,\"ternary\",s),c=e[s]._subplot;c||(c=new n({id:s,graphDiv:t,container:e._ternarylayer.node()},e),e[s]._subplot=c),c.plot(l,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.ternary||[],a=0;a<i.length;a++){var o=i[a],s=n[o]._subplot;!e[o]&&s&&(s.plotContainer.remove(),s.clipDef.remove(),s.clipDefRelative.remove(),s.layers[\"a-title\"].remove(),s.layers[\"b-title\"].remove(),s.layers[\"c-title\"].remove())}}},{\"../../lib\":719,\"../../plots/get_data\":802,\"./layout_attributes\":844,\"./layout_defaults\":845,\"./ternary\":846}],844:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"../cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../lib/extend\").extendFlat,l={title:a.title,color:a.color,tickmode:a.tickmode,nticks:s({},a.nticks,{dflt:6,min:1}),tick0:a.tick0,dtick:a.dtick,tickvals:a.tickvals,ticktext:a.ticktext,ticks:a.ticks,ticklen:a.ticklen,tickwidth:a.tickwidth,tickcolor:a.tickcolor,showticklabels:a.showticklabels,showtickprefix:a.showtickprefix,tickprefix:a.tickprefix,showticksuffix:a.showticksuffix,ticksuffix:a.ticksuffix,showexponent:a.showexponent,exponentformat:a.exponentformat,separatethousands:a.separatethousands,tickfont:a.tickfont,tickangle:a.tickangle,tickformat:a.tickformat,tickformatstops:a.tickformatstops,hoverformat:a.hoverformat,showline:s({},a.showline,{dflt:!0}),linecolor:a.linecolor,linewidth:a.linewidth,showgrid:s({},a.showgrid,{dflt:!0}),gridcolor:a.gridcolor,gridwidth:a.gridwidth,layer:a.layer,min:{valType:\"number\",dflt:0,min:0},_deprecated:{title:a._deprecated.title,titlefont:a._deprecated.titlefont}},c=e.exports=o({domain:i({name:\"ternary\"}),bgcolor:{valType:\"color\",dflt:n.background},sum:{valType:\"number\",dflt:1,min:0},aaxis:l,baxis:l,caxis:l},\"plot\",\"from-root\");c.uirevision={valType:\"any\",editType:\"none\"},c.aaxis.uirevision=c.baxis.uirevision=c.caxis.uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":592,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../cartesian/layout_attributes\":779,\"../domain\":792}],845:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../lib\"),o=t(\"../subplot_defaults\"),s=t(\"../cartesian/tick_label_defaults\"),l=t(\"../cartesian/tick_mark_defaults\"),c=t(\"../cartesian/tick_value_defaults\"),u=t(\"../cartesian/line_grid_defaults\"),h=t(\"./layout_attributes\"),f=[\"aaxis\",\"baxis\",\"caxis\"];function p(t,e,r,a){var o,s,l,c=r(\"bgcolor\"),u=r(\"sum\");a.bgColor=n.combine(c,a.paper_bgcolor);for(var h=0;h<f.length;h++)s=t[o=f[h]]||{},(l=i.newContainer(e,o))._name=o,d(s,l,a,e);var p=e.aaxis,g=e.baxis,v=e.caxis;p.min+g.min+v.min>=u&&(p.min=0,g.min=0,v.min=0,t.aaxis&&delete t.aaxis.min,t.baxis&&delete t.baxis.min,t.caxis&&delete t.caxis.min)}function d(t,e,r,n){var i=h[e._name];function o(r,n){return a.coerce(t,e,i,r,n)}o(\"uirevision\",n.uirevision),e.type=\"linear\";var f=o(\"color\"),p=f!==i.color.dflt?f:r.font.color,d=e._name.charAt(0).toUpperCase(),g=\"Component \"+d,v=o(\"title.text\",g);e._hovertitle=v===g?v:d,a.coerceFont(o,\"title.font\",{family:r.font.family,size:Math.round(1.2*r.font.size),color:p}),o(\"min\"),c(t,e,o,\"linear\"),s(t,e,o,\"linear\",{}),l(t,e,o,{outerTicks:!0}),o(\"showticklabels\")&&(a.coerceFont(o,\"tickfont\",{family:r.font.family,size:r.font.size,color:p}),o(\"tickangle\"),o(\"tickformat\")),u(t,e,o,{dfltColor:f,bgColor:r.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:i}),o(\"hoverformat\"),o(\"layer\")}e.exports=function(t,e,r){o(t,e,r,{type:\"ternary\",attributes:h,handleDefaults:p,font:e.font,paper_bgcolor:e.paper_bgcolor})}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../cartesian/line_grid_defaults\":781,\"../cartesian/tick_label_defaults\":786,\"../cartesian/tick_mark_defaults\":787,\"../cartesian/tick_value_defaults\":788,\"../subplot_defaults\":842,\"./layout_attributes\":844}],846:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=o._,l=t(\"../../components/color\"),c=t(\"../../components/drawing\"),u=t(\"../cartesian/set_convert\"),h=t(\"../../lib/extend\").extendFlat,f=t(\"../plots\"),p=t(\"../cartesian/axes\"),d=t(\"../../components/dragelement\"),g=t(\"../../components/fx\"),v=t(\"../../components/titles\"),m=t(\"../cartesian/select\").prepSelect,y=t(\"../cartesian/select\").selectOnClick,x=t(\"../cartesian/select\").clearSelect,b=t(\"../cartesian/constants\");function _(t,e){this.id=t.id,this.graphDiv=t.graphDiv,this.init(e),this.makeFramework(e),this.aTickLayout=null,this.bTickLayout=null,this.cTickLayout=null}e.exports=_;var w=_.prototype;w.init=function(t){this.container=t._ternarylayer,this.defs=t._defs,this.layoutId=t._uid,this.traceHash={},this.layers={}},w.plot=function(t,e){var r=e[this.id],n=e._size;this._hasClipOnAxisFalse=!1;for(var i=0;i<t.length;i++){if(!1===t[i][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(r),this.adjustLayout(r,n),f.generalUpdatePerTraceModule(this.graphDiv,this,t,r),this.layers.plotbg.select(\"path\").call(l.fill,r.bgcolor)},w.makeFramework=function(t){var e=this.graphDiv,r=t[this.id],n=this.clipId=\"clip\"+this.layoutId+this.id,i=this.clipIdRelative=\"clip-relative\"+this.layoutId+this.id;this.clipDef=o.ensureSingleById(t._clips,\"clipPath\",n,function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")}),this.clipDefRelative=o.ensureSingleById(t._clips,\"clipPath\",i,function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")}),this.plotContainer=o.ensureSingle(this.container,\"g\",this.id),this.updateLayers(r),c.setClipUrl(this.layers.backplot,n,e),c.setClipUrl(this.layers.grids,n,e)},w.updateLayers=function(t){var e=this.layers,r=[\"draglayer\",\"plotbg\",\"backplot\",\"grids\"];\"below traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"below traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"below traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\"),r.push(\"frontplot\"),\"above traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"above traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"above traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\");var i=this.plotContainer.selectAll(\"g.toplevel\").data(r,String),a=[\"agrid\",\"bgrid\",\"cgrid\"];i.enter().append(\"g\").attr(\"class\",function(t){return\"toplevel \"+t}).each(function(t){var r=n.select(this);e[t]=r,\"frontplot\"===t?r.append(\"g\").classed(\"scatterlayer\",!0):\"backplot\"===t?r.append(\"g\").classed(\"maplayer\",!0):\"plotbg\"===t?r.append(\"path\").attr(\"d\",\"M0,0Z\"):\"aline\"===t||\"bline\"===t||\"cline\"===t?r.append(\"path\"):\"grids\"===t&&a.forEach(function(t){e[t]=r.append(\"g\").classed(\"grid \"+t,!0)})}),i.order()};var k=Math.sqrt(4/3);w.adjustLayout=function(t,e){var r,n,i,a,o,s,f=this,p=t.domain,d=(p.x[0]+p.x[1])/2,g=(p.y[0]+p.y[1])/2,v=p.x[1]-p.x[0],m=p.y[1]-p.y[0],y=v*e.w,x=m*e.h,b=t.sum,_=t.aaxis.min,w=t.baxis.min,T=t.caxis.min;y>k*x?i=(a=x)*k:a=(i=y)/k,o=v*i/y,s=m*a/x,r=e.l+e.w*d-i/2,n=e.t+e.h*(1-g)-a/2,f.x0=r,f.y0=n,f.w=i,f.h=a,f.sum=b,f.xaxis={type:\"linear\",range:[_+2*T-b,b-_-2*w],domain:[d-o/2,d+o/2],_id:\"x\"},u(f.xaxis,f.graphDiv._fullLayout),f.xaxis.setScale(),f.xaxis.isPtWithinRange=function(t){return t.a>=f.aaxis.range[0]&&t.a<=f.aaxis.range[1]&&t.b>=f.baxis.range[1]&&t.b<=f.baxis.range[0]&&t.c>=f.caxis.range[1]&&t.c<=f.caxis.range[0]},f.yaxis={type:\"linear\",range:[_,b-w-T],domain:[g-s/2,g+s/2],_id:\"y\"},u(f.yaxis,f.graphDiv._fullLayout),f.yaxis.setScale(),f.yaxis.isPtWithinRange=function(){return!0};var A=f.yaxis.domain[0],M=f.aaxis=h({},t.aaxis,{range:[_,b-w-T],side:\"left\",tickangle:(+t.aaxis.tickangle||0)-30,domain:[A,A+s*k],anchor:\"free\",position:0,_id:\"y\",_length:i});u(M,f.graphDiv._fullLayout),M.setScale();var S=f.baxis=h({},t.baxis,{range:[b-_-T,w],side:\"bottom\",domain:f.xaxis.domain,anchor:\"free\",position:0,_id:\"x\",_length:i});u(S,f.graphDiv._fullLayout),S.setScale();var E=f.caxis=h({},t.caxis,{range:[b-_-w,T],side:\"right\",tickangle:(+t.caxis.tickangle||0)+30,domain:[A,A+s*k],anchor:\"free\",position:0,_id:\"y\",_length:i});u(E,f.graphDiv._fullLayout),E.setScale();var C=\"M\"+r+\",\"+(n+a)+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";f.clipDef.select(\"path\").attr(\"d\",C),f.layers.plotbg.select(\"path\").attr(\"d\",C);var L=\"M0,\"+a+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";f.clipDefRelative.select(\"path\").attr(\"d\",L);var P=\"translate(\"+r+\",\"+n+\")\";f.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",P),f.clipDefRelative.select(\"path\").attr(\"transform\",null);var O=\"translate(\"+(r-S._offset)+\",\"+(n+a)+\")\";f.layers.baxis.attr(\"transform\",O),f.layers.bgrid.attr(\"transform\",O);var z=\"translate(\"+(r+i/2)+\",\"+n+\")rotate(30)translate(0,\"+-M._offset+\")\";f.layers.aaxis.attr(\"transform\",z),f.layers.agrid.attr(\"transform\",z);var I=\"translate(\"+(r+i/2)+\",\"+n+\")rotate(-30)translate(0,\"+-E._offset+\")\";f.layers.caxis.attr(\"transform\",I),f.layers.cgrid.attr(\"transform\",I),f.drawAxes(!0),f.layers.aline.select(\"path\").attr(\"d\",M.showline?\"M\"+r+\",\"+(n+a)+\"l\"+i/2+\",-\"+a:\"M0,0\").call(l.stroke,M.linecolor||\"#000\").style(\"stroke-width\",(M.linewidth||0)+\"px\"),f.layers.bline.select(\"path\").attr(\"d\",S.showline?\"M\"+r+\",\"+(n+a)+\"h\"+i:\"M0,0\").call(l.stroke,S.linecolor||\"#000\").style(\"stroke-width\",(S.linewidth||0)+\"px\"),f.layers.cline.select(\"path\").attr(\"d\",E.showline?\"M\"+(r+i/2)+\",\"+n+\"l\"+i/2+\",\"+a:\"M0,0\").call(l.stroke,E.linecolor||\"#000\").style(\"stroke-width\",(E.linewidth||0)+\"px\"),f.graphDiv._context.staticPlot||f.initInteractions(),c.setClipUrl(f.layers.frontplot,f._hasClipOnAxisFalse?null:f.clipId,f.graphDiv)},w.drawAxes=function(t){var e=this.graphDiv,r=this.id.substr(7)+\"title\",n=this.layers,i=this.aaxis,a=this.baxis,o=this.caxis;if(this.drawAx(i),this.drawAx(a),this.drawAx(o),t){var l=Math.max(i.showticklabels?i.tickfont.size/2:0,(o.showticklabels?.75*o.tickfont.size:0)+(\"outside\"===o.ticks?.87*o.ticklen:0)),c=(a.showticklabels?a.tickfont.size:0)+(\"outside\"===a.ticks?a.ticklen:0)+3;n[\"a-title\"]=v.draw(e,\"a\"+r,{propContainer:i,propName:this.id+\".aaxis.title\",placeholder:s(e,\"Click to enter Component A title\"),attributes:{x:this.x0+this.w/2,y:this.y0-i.title.font.size/3-l,\"text-anchor\":\"middle\"}}),n[\"b-title\"]=v.draw(e,\"b\"+r,{propContainer:a,propName:this.id+\".baxis.title\",placeholder:s(e,\"Click to enter Component B title\"),attributes:{x:this.x0-c,y:this.y0+this.h+.83*a.title.font.size+c,\"text-anchor\":\"middle\"}}),n[\"c-title\"]=v.draw(e,\"c\"+r,{propContainer:o,propName:this.id+\".caxis.title\",placeholder:s(e,\"Click to enter Component C title\"),attributes:{x:this.x0+this.w+c,y:this.y0+this.h+.83*o.title.font.size+c,\"text-anchor\":\"middle\"}})}},w.drawAx=function(t){var e,r=this.graphDiv,n=t._name,i=n.charAt(0),a=t._id,s=this.layers[n],l=i+\"tickLayout\",c=(e=t).ticks+String(e.ticklen)+String(e.showticklabels);this[l]!==c&&(s.selectAll(\".\"+a+\"tick\").remove(),this[l]=c),t.setScale();var u=p.calcTicks(t),h=p.clipEnds(t,u),f=p.makeTransFn(t),d=p.getTickSigns(t)[2],g=o.deg2rad(30),v=d*(t.linewidth||1)/2,m=d*t.ticklen,y=this.w,x=this.h,b=\"b\"===i?\"M0,\"+v+\"l\"+Math.sin(g)*m+\",\"+Math.cos(g)*m:\"M\"+v+\",0l\"+Math.cos(g)*m+\",\"+-Math.sin(g)*m,_={a:\"M0,0l\"+x+\",-\"+y/2,b:\"M0,0l-\"+y/2+\",-\"+x,c:\"M0,0l-\"+x+\",\"+y/2}[i];p.drawTicks(r,t,{vals:\"inside\"===t.ticks?h:u,layer:s,path:b,transFn:f,crisp:!1}),p.drawGrid(r,t,{vals:h,layer:this.layers[i+\"grid\"],path:_,transFn:f,crisp:!1}),p.drawLabels(r,t,{vals:u,layer:s,transFn:f,labelFns:p.makeLabelFns(t,0,30)})};var T=b.MINZOOM/2+.87,A=\"m-0.87,.5h\"+T+\"v3h-\"+(T+5.2)+\"l\"+(T/2+2.6)+\",-\"+(.87*T+4.5)+\"l2.6,1.5l-\"+T/2+\",\"+.87*T+\"Z\",M=\"m0.87,.5h-\"+T+\"v3h\"+(T+5.2)+\"l-\"+(T/2+2.6)+\",-\"+(.87*T+4.5)+\"l-2.6,1.5l\"+T/2+\",\"+.87*T+\"Z\",S=\"m0,1l\"+T/2+\",\"+.87*T+\"l2.6,-1.5l-\"+(T/2+2.6)+\",-\"+(.87*T+4.5)+\"l-\"+(T/2+2.6)+\",\"+(.87*T+4.5)+\"l2.6,1.5l\"+T/2+\",-\"+.87*T+\"Z\",E=\"m0.5,0.5h5v-2h-5v-5h-2v5h-5v2h5v5h2Z\",C=!0;function L(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}w.initInteractions=function(){var t,e,r,n,u,h,f,p,v,_,w=this,T=w.layers.plotbg.select(\"path\").node(),P=w.graphDiv,O=P._fullLayout._zoomlayer,z={element:T,gd:P,plotinfo:{id:w.id,xaxis:w.xaxis,yaxis:w.yaxis},subplot:w.id,prepFn:function(a,o,s){z.xaxes=[w.xaxis],z.yaxes=[w.yaxis];var c=P._fullLayout.dragmode;z.minDrag=\"lasso\"===c?1:void 0,\"zoom\"===c?(z.moveFn=N,z.clickFn=D,z.doneFn=j,function(a,o,s){var c=T.getBoundingClientRect();t=o-c.left,e=s-c.top,r={a:w.aaxis.range[0],b:w.baxis.range[1],c:w.caxis.range[1]},u=r,n=w.aaxis.range[1]-r.a,h=i(w.graphDiv._fullLayout[w.id].bgcolor).getLuminance(),f=\"M0,\"+w.h+\"L\"+w.w/2+\", 0L\"+w.w+\",\"+w.h+\"Z\",p=!1,v=O.append(\"path\").attr(\"class\",\"zoombox\").attr(\"transform\",\"translate(\"+w.x0+\", \"+w.y0+\")\").style({fill:h>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"d\",f),_=O.append(\"path\").attr(\"class\",\"zoombox-corners\").attr(\"transform\",\"translate(\"+w.x0+\", \"+w.y0+\")\").style({fill:l.background,stroke:l.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"d\",\"M0,0Z\"),x(P)}(0,o,s)):\"pan\"===c?(z.moveFn=U,z.clickFn=D,z.doneFn=V,r={a:w.aaxis.range[0],b:w.baxis.range[1],c:w.caxis.range[1]},u=r,x(P)):\"select\"!==c&&\"lasso\"!==c||m(a,o,s,z,c)}};function I(t){var e={};return e[w.id+\".aaxis.min\"]=t.a,e[w.id+\".baxis.min\"]=t.b,e[w.id+\".caxis.min\"]=t.c,e}function D(t,e){var r=P._fullLayout.clickmode;L(P),2===t&&(P.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",P,I({a:0,b:0,c:0}))),r.indexOf(\"select\")>-1&&1===t&&y(e,P,[w.xaxis],[w.yaxis],w.id,z),r.indexOf(\"event\")>-1&&g.click(P,e,w.id)}function R(t,e){return 1-e/w.h}function F(t,e){return 1-(t+(w.h-e)/Math.sqrt(3))/w.w}function B(t,e){return(t-(w.h-e)/Math.sqrt(3))/w.w}function N(i,a){var o=t+i,s=e+a,l=Math.max(0,Math.min(1,R(0,e),R(0,s))),c=Math.max(0,Math.min(1,F(t,e),F(o,s))),d=Math.max(0,Math.min(1,B(t,e),B(o,s))),g=(l/2+d)*w.w,m=(1-l/2-c)*w.w,y=(g+m)/2,x=m-g,T=(1-l)*w.h,C=T-x/k;x<b.MINZOOM?(u=r,v.attr(\"d\",f),_.attr(\"d\",\"M0,0Z\")):(u={a:r.a+l*n,b:r.b+c*n,c:r.c+d*n},v.attr(\"d\",f+\"M\"+g+\",\"+T+\"H\"+m+\"L\"+y+\",\"+C+\"L\"+g+\",\"+T+\"Z\"),_.attr(\"d\",\"M\"+t+\",\"+e+E+\"M\"+g+\",\"+T+A+\"M\"+m+\",\"+T+M+\"M\"+y+\",\"+C+S)),p||(v.transition().style(\"fill\",h>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),_.transition().style(\"opacity\",1).duration(200),p=!0),P.emit(\"plotly_relayouting\",I(u))}function j(){L(P),u!==r&&(a.call(\"_guiRelayout\",P,I(u)),C&&P.data&&P._context.showTips&&(o.notifier(s(P,\"Double-click to zoom back out\"),\"long\"),C=!1))}function U(t,e){var n=t/w.xaxis._m,i=e/w.yaxis._m,a=[(u={a:r.a-i,b:r.b+(n+i)/2,c:r.c-(n-i)/2}).a,u.b,u.c].sort(),o=a.indexOf(u.a),s=a.indexOf(u.b),l=a.indexOf(u.c);a[0]<0&&(a[1]+a[0]/2<0?(a[2]+=a[0]+a[1],a[0]=a[1]=0):(a[2]+=a[0]/2,a[1]+=a[0]/2,a[0]=0),u={a:a[o],b:a[s],c:a[l]},e=(r.a-u.a)*w.yaxis._m,t=(r.c-u.c-r.b+u.b)*w.xaxis._m);var h=\"translate(\"+(w.x0+t)+\",\"+(w.y0+e)+\")\";w.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",h);var f=\"translate(\"+-t+\",\"+-e+\")\";w.clipDefRelative.select(\"path\").attr(\"transform\",f),w.aaxis.range=[u.a,w.sum-u.b-u.c],w.baxis.range=[w.sum-u.a-u.c,u.b],w.caxis.range=[w.sum-u.a-u.b,u.c],w.drawAxes(!1),w._hasClipOnAxisFalse&&w.plotContainer.select(\".scatterlayer\").selectAll(\".trace\").call(c.hideOutsideRangePoints,w),P.emit(\"plotly_relayouting\",I(u))}function V(){a.call(\"_guiRelayout\",P,I(u))}T.onmousemove=function(t){g.hover(P,t,w.id),P._fullLayout._lasthover=T,P._fullLayout._hoversubplot=w.id},T.onmouseout=function(t){P._dragging||d.unhover(P,t)},d.init(z)}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../components/titles\":681,\"../../lib\":719,\"../../lib/extend\":710,\"../../registry\":847,\"../cartesian/axes\":767,\"../cartesian/constants\":773,\"../cartesian/select\":784,\"../cartesian/set_convert\":785,\"../plots\":828,d3:163,tinycolor2:537}],847:[function(t,e,r){\"use strict\";var n=t(\"./lib/loggers\"),i=t(\"./lib/noop\"),a=t(\"./lib/push_unique\"),o=t(\"./lib/is_plain_object\"),s=t(\"./lib/dom\").addStyleRule,l=t(\"./lib/extend\"),c=t(\"./plots/attributes\"),u=t(\"./plots/layout_attributes\"),h=l.extendFlat,f=l.extendDeepAll;function p(t){var e=t.name,i=t.categories,a=t.meta;if(r.modules[e])n.log(\"Type \"+e+\" already registered\");else{r.subplotsRegistry[t.basePlotModule.name]||function(t){var e=t.name;if(r.subplotsRegistry[e])return void n.log(\"Plot type \"+e+\" already registered.\");for(var i in m(t),r.subplotsRegistry[e]=t,r.componentsRegistry)b(i,t.name)}(t.basePlotModule);for(var o={},l=0;l<i.length;l++)o[i[l]]=!0,r.allCategories[i[l]]=!0;for(var c in r.modules[e]={_module:t,categories:o},a&&Object.keys(a).length&&(r.modules[e].meta=a),r.allTypes.push(e),r.componentsRegistry)y(c,e);t.layoutAttributes&&h(r.traceLayoutAttributes,t.layoutAttributes);var u=t.basePlotModule,f=u.name;if(\"mapbox\"===f){var p=u.constants.styleRules;for(var d in p)s(\".js-plotly-plot .plotly .mapboxgl-\"+d,p[d])}\"geo\"!==f&&\"mapbox\"!==f||void 0===typeof window||void 0!==window.PlotlyGeoAssets||(window.PlotlyGeoAssets={topojson:{}})}}function d(t){if(\"string\"!=typeof t.name)throw new Error(\"Component module *name* must be a string.\");var e=t.name;for(var n in r.componentsRegistry[e]=t,t.layoutAttributes&&(t.layoutAttributes._isLinkedToArray&&a(r.layoutArrayContainers,e),m(t)),r.modules)y(e,n);for(var i in r.subplotsRegistry)b(e,i);for(var o in r.transformsRegistry)x(e,o);t.schema&&t.schema.layout&&f(u,t.schema.layout)}function g(t){if(\"string\"!=typeof t.name)throw new Error(\"Transform module *name* must be a string.\");var e=\"Transform module \"+t.name,i=\"function\"==typeof t.transform,a=\"function\"==typeof t.calcTransform;if(!i&&!a)throw new Error(e+\" is missing a *transform* or *calcTransform* method.\");for(var s in i&&a&&n.log([e+\" has both a *transform* and *calcTransform* methods.\",\"Please note that all *transform* methods are executed\",\"before all *calcTransform* methods.\"].join(\" \")),o(t.attributes)||n.log(e+\" registered without an *attributes* object.\"),\"function\"!=typeof t.supplyDefaults&&n.log(e+\" registered without a *supplyDefaults* method.\"),r.transformsRegistry[t.name]=t,r.componentsRegistry)x(s,t.name)}function v(t){var e=t.name,n=e.split(\"-\")[0],i=t.dictionary,a=t.format,o=i&&Object.keys(i).length,s=a&&Object.keys(a).length,l=r.localeRegistry,c=l[e];if(c||(l[e]=c={}),n!==e){var u=l[n];u||(l[n]=u={}),o&&u.dictionary===c.dictionary&&(u.dictionary=i),s&&u.format===c.format&&(u.format=a)}o&&(c.dictionary=i),s&&(c.format=a)}function m(t){if(t.layoutAttributes){var e=t.layoutAttributes._arrayAttrRegexps;if(e)for(var n=0;n<e.length;n++)a(r.layoutArrayRegexes,e[n])}}function y(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.traces){var i=n.traces[e];i&&f(r.modules[e]._module.attributes,i)}}function x(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.transforms){var i=n.transforms[e];i&&f(r.transformsRegistry[e].attributes,i)}}function b(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.subplots){var i=r.subplotsRegistry[e],a=i.layoutAttributes,o=\"subplot\"===i.attr?i.name:i.attr;Array.isArray(o)&&(o=o[0]);var s=n.subplots[o];a&&s&&f(a,s)}}function _(t){return\"object\"==typeof t&&(t=t.type),t}r.modules={},r.allCategories={},r.allTypes=[],r.subplotsRegistry={},r.transformsRegistry={},r.componentsRegistry={},r.layoutArrayContainers=[],r.layoutArrayRegexes=[],r.traceLayoutAttributes={},r.localeRegistry={},r.apiMethodRegistry={},r.collectableSubplotTypes=null,r.register=function(t){if(r.collectableSubplotTypes=null,!t)throw new Error(\"No argument passed to Plotly.register.\");t&&!Array.isArray(t)&&(t=[t]);for(var e=0;e<t.length;e++){var n=t[e];if(!n)throw new Error(\"Invalid module was attempted to be registered!\");switch(n.moduleType){case\"trace\":p(n);break;case\"transform\":g(n);break;case\"component\":d(n);break;case\"locale\":v(n);break;case\"apiMethod\":var i=n.name;r.apiMethodRegistry[i]=n.fn;break;default:throw new Error(\"Invalid module was attempted to be registered!\")}}},r.getModule=function(t){var e=r.modules[_(t)];return!!e&&e._module},r.traceIs=function(t,e){if(\"various\"===(t=_(t)))return!1;var i=r.modules[t];return i||(t&&\"area\"!==t&&n.log(\"Unrecognized trace type \"+t+\".\"),i=r.modules[c.type.dflt]),!!i.categories[e]},r.getTransformIndices=function(t,e){for(var r=[],n=t.transforms||[],i=0;i<n.length;i++)n[i].type===e&&r.push(i);return r},r.hasTransform=function(t,e){for(var r=t.transforms||[],n=0;n<r.length;n++)if(r[n].type===e)return!0;return!1},r.getComponentMethod=function(t,e){var n=r.componentsRegistry[t];return n&&n[e]||i},r.call=function(){var t=arguments[0],e=[].slice.call(arguments,1);return r.apiMethodRegistry[t].apply(null,e)}},{\"./lib/dom\":708,\"./lib/extend\":710,\"./lib/is_plain_object\":720,\"./lib/loggers\":723,\"./lib/noop\":728,\"./lib/push_unique\":733,\"./plots/attributes\":764,\"./plots/layout_attributes\":819}],848:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=i.extendFlat,o=i.extendDeep;function s(t){var e;switch(t){case\"themes__thumb\":e={autosize:!0,width:150,height:150,title:{text:\"\"},showlegend:!1,margin:{l:5,r:5,t:5,b:5,pad:0},annotations:[]};break;case\"thumbnail\":e={title:{text:\"\"},hidesources:!0,showlegend:!1,borderwidth:0,bordercolor:\"\",margin:{l:1,r:1,t:1,b:1,pad:0},annotations:[]};break;default:e={}}return e}e.exports=function(t,e){var r;t.framework&&t.framework.isPolar&&(t=t.framework.getConfig());var i,l=t.data,c=t.layout,u=o([],l),h=o({},c,s(e.tileClass)),f=t._context||{};if(e.width&&(h.width=e.width),e.height&&(h.height=e.height),\"thumbnail\"===e.tileClass||\"themes__thumb\"===e.tileClass){h.annotations=[];var p=Object.keys(h);for(r=0;r<p.length;r++)i=p[r],[\"xaxis\",\"yaxis\",\"zaxis\"].indexOf(i.slice(0,5))>-1&&(h[p[r]].title={text:\"\"});for(r=0;r<u.length;r++){var d=u[r];d.showscale=!1,d.marker&&(d.marker.showscale=!1),n.traceIs(d,\"pie-like\")&&(d.textposition=\"none\")}}if(Array.isArray(e.annotations))for(r=0;r<e.annotations.length;r++)h.annotations.push(e.annotations[r]);var g=Object.keys(h).filter(function(t){return t.match(/^scene\\d*$/)});if(g.length){var v={};for(\"thumbnail\"===e.tileClass&&(v={title:{text:\"\"},showaxeslabels:!1,showticklabels:!1,linetickenable:!1}),r=0;r<g.length;r++){var m=h[g[r]];m.xaxis||(m.xaxis={}),m.yaxis||(m.yaxis={}),m.zaxis||(m.zaxis={}),a(m.xaxis,v),a(m.yaxis,v),a(m.zaxis,v),m._scene=null}}var y=document.createElement(\"div\");e.tileClass&&(y.className=e.tileClass);var x={gd:y,td:y,layout:h,data:u,config:{staticPlot:void 0===e.staticPlot||e.staticPlot,plotGlPixelRatio:void 0===e.plotGlPixelRatio?2:e.plotGlPixelRatio,displaylogo:e.displaylogo||!1,showLink:e.showLink||!1,showTips:e.showTips||!1,mapboxAccessToken:f.mapboxAccessToken}};return\"transparent\"!==e.setBackground&&(x.config.setBackground=e.setBackground||\"opaque\"),x.gd.defaultLayout=s(e.tileClass),x}},{\"../lib\":719,\"../registry\":847}],849:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/to_image\"),a=t(\"./filesaver\"),o=t(\"./helpers\");e.exports=function(t,e){var r;return n.isPlainObject(t)||(r=n.getGraphDiv(t)),(e=e||{}).format=e.format||\"png\",e.imageDataOnly=!0,new Promise(function(s,l){r&&r._snapshotInProgress&&l(new Error(\"Snapshotting already in progress.\")),n.isIE()&&\"svg\"!==e.format&&l(new Error(o.MSG_IE_BAD_FORMAT)),r&&(r._snapshotInProgress=!0);var c=i(t,e),u=e.filename||t.fn||\"newplot\";u+=\".\"+e.format,c.then(function(t){return r&&(r._snapshotInProgress=!1),a(t,u,e.format)}).then(function(t){s(t)}).catch(function(t){r&&(r._snapshotInProgress=!1),l(t)})})}},{\"../lib\":719,\"../plot_api/to_image\":760,\"./filesaver\":850,\"./helpers\":851}],850:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"./helpers\");e.exports=function(t,e,r){var a=document.createElement(\"a\"),o=\"download\"in a;return new Promise(function(s,l){var c,u;if(n.isIE9orBelow()&&l(new Error(\"IE < 10 unsupported\")),n.isSafari()){var h=\"svg\"===r?\",\":\";base64,\";return i.octetStream(h+encodeURIComponent(t)),s(e)}return n.isIE()?(c=i.createBlob(t,\"svg\"),window.navigator.msSaveBlob(c,e),c=null,s(e)):o?(c=i.createBlob(t,r),u=i.createObjectURL(c),a.href=u,a.download=e,document.body.appendChild(a),a.click(),document.body.removeChild(a),i.revokeObjectURL(u),c=null,s(e)):void l(new Error(\"download error\"))})}},{\"../lib\":719,\"./helpers\":851}],851:[function(t,e,r){\"use strict\";var n=t(\"../registry\");r.getDelay=function(t){return t._has&&(t._has(\"gl3d\")||t._has(\"gl2d\")||t._has(\"mapbox\"))?500:0},r.getRedrawFunc=function(t){return function(){var e=t._fullLayout||{};!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r||n.getComponentMethod(\"colorbar\",\"draw\")(t)}},r.encodeSVG=function(t){return\"data:image/svg+xml,\"+encodeURIComponent(t)};var i=window.URL||window.webkitURL;r.createObjectURL=function(t){return i.createObjectURL(t)},r.revokeObjectURL=function(t){return i.revokeObjectURL(t)},r.createBlob=function(t,e){if(\"svg\"===e)return new window.Blob([t],{type:\"image/svg+xml;charset=utf-8\"});var r=function(t){for(var e=t.length,r=new ArrayBuffer(e),n=new Uint8Array(r),i=0;i<e;i++)n[i]=t.charCodeAt(i);return r}(window.atob(t));return new window.Blob([r],{type:\"image/\"+e})},r.octetStream=function(t){document.location.href=\"data:application/octet-stream\"+t},r.IMAGE_URL_PREFIX=/^data:image\\/\\w+;base64,/,r.MSG_IE_BAD_FORMAT=\"Sorry IE does not support downloading from canvas. Try {format:'svg'} instead.\"},{\"../registry\":847}],852:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i={getDelay:n.getDelay,getRedrawFunc:n.getRedrawFunc,clone:t(\"./cloneplot\"),toSVG:t(\"./tosvg\"),svgToImg:t(\"./svgtoimg\"),toImage:t(\"./toimage\"),downloadImage:t(\"./download\")};e.exports=i},{\"./cloneplot\":848,\"./download\":849,\"./helpers\":851,\"./svgtoimg\":853,\"./toimage\":854,\"./tosvg\":855}],853:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"events\").EventEmitter,a=t(\"./helpers\");e.exports=function(t){var e=t.emitter||new i,r=new Promise(function(i,o){var s=window.Image,l=t.svg,c=t.format||\"png\";if(n.isIE()&&\"svg\"!==c){var u=new Error(a.MSG_IE_BAD_FORMAT);return o(u),t.promise?r:e.emit(\"error\",u)}var h,f,p=t.canvas,d=t.scale||1,g=t.width||300,v=t.height||150,m=d*g,y=d*v,x=p.getContext(\"2d\"),b=new s;\"svg\"===c||n.isIE9orBelow()||n.isSafari()?f=a.encodeSVG(l):(h=a.createBlob(l,\"svg\"),f=a.createObjectURL(h)),p.width=m,p.height=y,b.onload=function(){var r;switch(h=null,a.revokeObjectURL(f),\"svg\"!==c&&x.drawImage(b,0,0,m,y),c){case\"jpeg\":r=p.toDataURL(\"image/jpeg\");break;case\"png\":r=p.toDataURL(\"image/png\");break;case\"webp\":r=p.toDataURL(\"image/webp\");break;case\"svg\":r=f;break;default:var n=\"Image format is not jpeg, png, svg or webp.\";if(o(new Error(n)),!t.promise)return e.emit(\"error\",n)}i(r),t.promise||e.emit(\"success\",r)},b.onerror=function(r){if(h=null,a.revokeObjectURL(f),o(r),!t.promise)return e.emit(\"error\",r)},b.src=f});return t.promise?r:e}},{\"../lib\":719,\"./helpers\":851,events:104}],854:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i=t(\"../registry\"),a=t(\"../lib\"),o=t(\"./helpers\"),s=t(\"./cloneplot\"),l=t(\"./tosvg\"),c=t(\"./svgtoimg\");e.exports=function(t,e){var r=new n,u=s(t,{format:\"png\"}),h=u.gd;h.style.position=\"absolute\",h.style.left=\"-5000px\",document.body.appendChild(h);var f=o.getRedrawFunc(h);return i.call(\"plot\",h,u.data,u.layout,u.config).then(f).then(function(){var t=o.getDelay(h._fullLayout);setTimeout(function(){var t=l(h),n=document.createElement(\"canvas\");n.id=a.randstr(),(r=c({format:e.format,width:h._fullLayout.width,height:h._fullLayout.height,canvas:n,emitter:r,svg:t})).clean=function(){h&&document.body.removeChild(h)}},t)}).catch(function(t){r.emit(\"error\",t)}),r}},{\"../lib\":719,\"../registry\":847,\"./cloneplot\":848,\"./helpers\":851,\"./svgtoimg\":853,\"./tosvg\":855,events:104}],855:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=t(\"../components/drawing\"),o=t(\"../components/color\"),s=t(\"../constants/xmlns_namespaces\"),l=/\"/g,c=new RegExp('(\"TOBESTRIPPED)|(TOBESTRIPPED\")',\"g\");e.exports=function(t,e,r){var u,h=t._fullLayout,f=h._paper,p=h._toppaper,d=h.width,g=h.height;f.insert(\"rect\",\":first-child\").call(a.setRect,0,0,d,g).call(o.fill,h.paper_bgcolor);var v=h._basePlotModules||[];for(u=0;u<v.length;u++){var m=v[u];m.toSVG&&m.toSVG(t)}if(p){var y=p.node().childNodes,x=Array.prototype.slice.call(y);for(u=0;u<x.length;u++){var b=x[u];b.childNodes.length&&f.node().appendChild(b)}}h._draggers&&h._draggers.remove(),f.node().style.background=\"\",f.selectAll(\"text\").attr({\"data-unformatted\":null,\"data-math\":null}).each(function(){var t=n.select(this);if(\"hidden\"!==this.style.visibility&&\"none\"!==this.style.display){t.style({visibility:null,display:null});var e=this.style.fontFamily;e&&-1!==e.indexOf('\"')&&t.style(\"font-family\",e.replace(l,\"TOBESTRIPPED\"))}else t.remove()}),f.selectAll(\".point, .scatterpts, .legendfill>path, .legendlines>path, .cbfill\").each(function(){var t=n.select(this),e=this.style.fill;e&&-1!==e.indexOf(\"url(\")&&t.style(\"fill\",e.replace(l,\"TOBESTRIPPED\"));var r=this.style.stroke;r&&-1!==r.indexOf(\"url(\")&&t.style(\"stroke\",r.replace(l,\"TOBESTRIPPED\"))}),\"pdf\"!==e&&\"eps\"!==e||f.selectAll(\"#MathJax_SVG_glyphs path\").attr(\"stroke-width\",0),f.node().setAttributeNS(s.xmlns,\"xmlns\",s.svg),f.node().setAttributeNS(s.xmlns,\"xmlns:xlink\",s.xlink),\"svg\"===e&&r&&(f.attr(\"width\",r*d),f.attr(\"height\",r*g),f.attr(\"viewBox\",\"0 0 \"+d+\" \"+g));var _=(new window.XMLSerializer).serializeToString(f.node());return _=function(t){var e=n.select(\"body\").append(\"div\").style({display:\"none\"}).html(\"\"),r=t.replace(/(&[^;]*;)/gi,function(t){return\"&lt;\"===t?\"&#60;\":\"&rt;\"===t?\"&#62;\":-1!==t.indexOf(\"<\")||-1!==t.indexOf(\">\")?\"\":e.html(t).text()});return e.remove(),r}(_),_=(_=_.replace(/&(?!\\w+;|\\#[0-9]+;| \\#x[0-9A-F]+;)/g,\"&amp;\")).replace(c,\"'\"),i.isIE()&&(_=(_=(_=_.replace(/\"/gi,\"'\")).replace(/(\\('#)([^']*)('\\))/gi,'(\"#$2\")')).replace(/(\\\\')/gi,'\"')),_}},{\"../components/color\":593,\"../components/drawing\":614,\"../constants/xmlns_namespaces\":696,\"../lib\":719,d3:163}],856:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\",!0),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":719}],857:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/font_attributes\"),s=t(\"./constants.js\"),l=t(\"../../lib/extend\").extendFlat,c=o({editType:\"calc\",arrayOk:!0,colorEditType:\"style\"}),u=l({},n.marker.line.width,{dflt:0}),h=l({width:u,editType:\"calc\"},a(\"marker.line\")),f=l({line:h,editType:\"calc\"},a(\"marker\"),{opacity:{valType:\"number\",arrayOk:!0,dflt:1,min:0,max:1,editType:\"style\"}});e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,text:n.text,hovertext:n.hovertext,hovertemplate:i({},{keys:s.eventDataKeys}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"none\",arrayOk:!0,editType:\"calc\"},insidetextanchor:{valType:\"enumerated\",values:[\"end\",\"middle\",\"start\"],dflt:\"end\",editType:\"plot\"},textangle:{valType:\"angle\",dflt:\"auto\",editType:\"plot\"},textfont:l({},c,{}),insidetextfont:l({},c,{}),outsidetextfont:l({},c,{}),constraintext:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"both\",\"none\"],dflt:\"both\",editType:\"calc\"},cliponaxis:l({},n.cliponaxis,{}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},base:{valType:\"any\",dflt:null,arrayOk:!0,editType:\"calc\"},offset:{valType:\"number\",dflt:null,arrayOk:!0,editType:\"calc\"},width:{valType:\"number\",dflt:null,min:0,arrayOk:!0,editType:\"calc\"},marker:f,offsetgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},alignmentgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},selected:{marker:{opacity:n.selected.marker.opacity,color:n.selected.marker.color,editType:\"style\"},textfont:n.selected.textfont,editType:\"style\"},unselected:{marker:{opacity:n.unselected.marker.opacity,color:n.unselected.marker.color,editType:\"style\"},textfont:n.unselected.textfont,editType:\"style\"},r:n.r,t:n.t,_deprecated:{bardir:{valType:\"enumerated\",editType:\"calc\",values:[\"v\",\"h\"]}}}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"../scatter/attributes\":1112,\"./constants.js\":859}],858:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),o=t(\"./arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\");e.exports=function(t,e){var r,l,c=n.getFromId(t,e.xaxis||\"x\"),u=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=c.makeCalcdata(e,\"x\"),l=u.makeCalcdata(e,\"y\")):(r=u.makeCalcdata(e,\"y\"),l=c.makeCalcdata(e,\"x\"));for(var h=Math.min(l.length,r.length),f=new Array(h),p=0;p<h;p++)f[p]={p:l[p],s:r[p]},e.ids&&(f[p].id=String(e.ids[p]));return i(e,\"marker\")&&a(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),i(e,\"marker.line\")&&a(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),o(f,e),s(f,e),f}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"../../plots/cartesian/axes\":767,\"../scatter/calc_selection\":1114,\"./arrays_to_calcdata\":856}],859:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[]}},{}],860:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,c=t(\"./sieve.js\");function u(t,e,r,o,u){if(o.length){var b,_,w,k;switch(function(t,e){var r,a;for(r=0;r<e.length;r++){var o,s=e[r],l=s[0].trace,c=\"funnel\"===l.type?l._base:l.base,u=\"h\"===l.orientation?l.xcalendar:l.ycalendar,h=\"category\"===t.type||\"multicategory\"===t.type?function(){return null}:t.d2c;if(i(c)){for(a=0;a<Math.min(c.length,s.length);a++)o=h(c[a],0,u),n(o)?(s[a].b=+o,s[a].hasB=1):s[a].b=0;for(;a<s.length;a++)s[a].b=0}else{o=h(c,0,u);var f=n(o);for(o=f?o:0,a=0;a<s.length;a++)s[a].b=o,f&&(s[a].hasB=1)}}}(r,o),u.mode){case\"overlay\":h(e,r,o,u);break;case\"group\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(k=o[w])[0].trace.offset?_.push(k):b.push(k);_.length&&function(t,e,r,n,i){var o=new c(n,{sepNegVal:!1,overlapNoMerge:!i.norm});(function(t,e,r,n){for(var i=t._fullLayout,a=r.positions,o=r.distinctPositions,s=r.minDiff,c=r.traces,u=c.length,h=a.length!==o.length,f=s*(1-n.gap),v=l(i,e._id)+c[0][0].trace.orientation,m=i._alignmentOpts[v]||{},y=0;y<u;y++){var x,b,_=c[y],w=_[0].trace,k=m[w.alignmentgroup]||{},T=Object.keys(k.offsetGroups||{}).length,A=(x=T?f/T:h?f/u:f)*(1-(n.groupgap||0));b=T?((2*w._offsetIndex+1-T)*x-A)/2:h?((2*y+1-u)*x-A)/2:-A/2;var M=_[0].t;M.barwidth=A,M.poffset=b,M.bargroupwidth=f,M.bardelta=s}r.binWidth=c[0][0].t.barwidth/100,p(r),d(e,r),g(e,r,h)})(t,e,o,i),function(t){for(var e=t.traces,r=0;r<e.length;r++){var n=e[r],i=n[0].trace;if(void 0===i.base)for(var o=new c([n],{sepNegVal:!0,overlapNoMerge:!0}),s=0;s<n.length;s++){var l=n[s];if(l.p!==a){var u=o.put(l.p,l.b+l.s);u&&(l.b=u)}}}}(o),i.norm?(m(o),y(r,o,i)):v(r,o)}(t,e,r,_,u),b.length&&h(e,r,b,u);break;case\"stack\":case\"relative\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(k=o[w])[0].trace.base?_.push(k):b.push(k);_.length&&function(t,e,r,n,i){var o=new c(n,{sepNegVal:\"relative\"===i.mode,overlapNoMerge:!(i.norm||\"stack\"===i.mode||\"relative\"===i.mode)});f(e,o,i),function(t,e,r){var n,i,o,l,c,u,h=x(t),f=e.traces;for(l=0;l<f.length;l++)if(n=f[l],\"funnel\"===(i=n[0].trace).type)for(c=0;c<n.length;c++)(u=n[c]).s!==a&&e.put(u.p,-.5*u.s);for(l=0;l<f.length;l++){n=f[l],i=n[0].trace,o=\"funnel\"===i.type;var p=[];for(c=0;c<n.length;c++)if((u=n[c]).s!==a){var d;d=o?u.s:u.s+u.b;var g=e.put(u.p,d),v=g+d;u.b=g,u[h]=v,r.norm||(p.push(v),u.hasB&&p.push(g))}r.norm||(i._extremes[t._id]=s.findExtremes(t,p,{tozero:!0,padded:!0}))}}(r,o,i);for(var l=0;l<n.length;l++)for(var u=n[l],h=0;h<u.length;h++){var p=u[h];if(p.s!==a){var d=p.b+p.s===o.get(p.p,p.s);d&&(p._outmost=!0)}}i.norm&&y(r,o,i)}(0,e,r,_,u),b.length&&h(e,r,b,u)}!function(t,e){var r,i,a,o=x(e),s={},l=1/0,c=-1/0;for(r=0;r<t.length;r++)for(a=t[r],i=0;i<a.length;i++){var u=a[i].p;n(u)&&(l=Math.min(l,u),c=Math.max(c,u))}var h=1e4/(c-l),f=s.round=function(t){return String(Math.round(h*(t-l)))};for(r=0;r<t.length;r++){(a=t[r])[0].t.extents=s;var p=a[0].t.poffset,d=Array.isArray(p);for(i=0;i<a.length;i++){var g=a[i],v=g[o]-g.w/2;if(n(v)){var m=g[o]+g.w/2,y=f(g.p);s[y]?s[y]=[Math.min(v,s[y][0]),Math.max(m,s[y][1])]:s[y]=[v,m]}g.p0=g.p+(d?p[i]:p),g.p1=g.p0+g.w,g.s0=g.b,g.s1=g.s0+g.s}}}(o,e)}}function h(t,e,r,n){for(var i=0;i<r.length;i++){var a=r[i],o=new c([a],{sepNegVal:!1,overlapNoMerge:!n.norm});f(t,o,n),n.norm?(m(o),y(e,o,n)):v(e,o)}}function f(t,e,r){for(var n=e.minDiff,i=e.traces,a=n*(1-r.gap),o=a*(1-(r.groupgap||0)),s=-o/2,l=0;l<i.length;l++){var c=i[l][0].t;c.barwidth=o,c.poffset=s,c.bargroupwidth=a,c.bardelta=n}e.binWidth=i[0][0].t.barwidth/100,p(e),d(t,e),g(t,e)}function p(t){var e,r,a=t.traces;for(e=0;e<a.length;e++){var o,s=a[e],l=s[0],c=l.trace,u=l.t,h=c._offset||c.offset,f=u.poffset;if(i(h)){for(o=Array.prototype.slice.call(h,0,s.length),r=0;r<o.length;r++)n(o[r])||(o[r]=f);for(r=o.length;r<s.length;r++)o.push(f);u.poffset=o}else void 0!==h&&(u.poffset=h);var p=c._width||c.width,d=u.barwidth;if(i(p)){var g=Array.prototype.slice.call(p,0,s.length);for(r=0;r<g.length;r++)n(g[r])||(g[r]=d);for(r=g.length;r<s.length;r++)g.push(d);if(u.barwidth=g,void 0===h){for(o=[],r=0;r<s.length;r++)o.push(f+(d-g[r])/2);u.poffset=o}}else void 0!==p&&(u.barwidth=p,void 0===h&&(u.poffset=f+(d-p)/2))}}function d(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++)for(var a=r[i],o=a[0].t,s=o.poffset,l=Array.isArray(s),c=o.barwidth,u=Array.isArray(c),h=0;h<a.length;h++){var f=a[h],p=f.w=u?c[h]:c;f[n]=f.p+(l?s[h]:s)+p/2}}function g(t,e,r){var n=e.traces,i=e.minDiff/2;s.minDtick(t,e.minDiff,e.distinctPositions[0],r);for(var a=0;a<n.length;a++){var o,l,c,u,h=n[a],f=h[0],p=f.trace,d=[];for(u=0;u<h.length;u++)l=(o=h[u]).p-i,c=o.p+i,d.push(l,c);if(p.width||p.offset){var g=f.t,v=g.poffset,m=g.barwidth,y=Array.isArray(v),x=Array.isArray(m);for(u=0;u<h.length;u++){o=h[u];var b=y?v[u]:v,_=x?m[u]:m;c=(l=o.p+b)+_,d.push(l,c)}}p._extremes[t._id]=s.findExtremes(t,d,{padded:!1})}}function v(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++){for(var a=r[i],o=a[0].trace,l=[],c=!0,u=0;u<a.length;u++){var h=a[u],f=h.b,p=f+h.s;h[n]=p,l.push(p),h.hasB&&l.push(f),h.hasB&&h.b>0&&h.s>0||(c=!1)}o._extremes[t._id]=s.findExtremes(t,l,{tozero:!c,padded:!0})}}function m(t){for(var e=t.traces,r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++){var o=n[i];o.s!==a&&t.put(o.p,o.b+o.s)}}function y(t,e,r){var i=e.traces,o=x(t),l=\"fraction\"===r.norm?1:100,c=l/1e9,u=t.l2c(t.c2l(0)),h=\"stack\"===r.mode?l:u;function f(e){return n(t.c2l(e))&&(e<u-c||e>h+c||!n(u))}for(var p=0;p<i.length;p++){for(var d=i[p],g=d[0].trace,v=[],m=!0,y=!1,b=0;b<d.length;b++){var _=d[b];if(_.s!==a){var w=Math.abs(l/e.get(_.p,_.s));_.b*=w,_.s*=w;var k=_.b,T=k+_.s;_[o]=T,v.push(T),y=y||f(T),_.hasB&&(v.push(k),y=y||f(k)),_.hasB&&_.b>0&&_.s>0||(m=!1)}}g._extremes[t._id]=s.findExtremes(t,v,{tozero:!m,padded:y})}}function x(t){return t._id.charAt(0)}e.exports={crossTraceCalc:function(t,e){for(var r=e.xaxis,n=e.yaxis,i=t._fullLayout,a=t._fullData,s=t.calcdata,l=[],c=[],h=0;h<a.length;h++){var f=a[h];!0===f.visible&&o.traceIs(f,\"bar\")&&f.xaxis===r._id&&f.yaxis===n._id&&(\"h\"===f.orientation?l.push(s[h]):c.push(s[h]))}var p={mode:i.barmode,norm:i.barnorm,gap:i.bargap,groupgap:i.bargroupgap};u(t,r,n,c,p),u(t,n,r,l,p)},setGroupPositions:u}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"./sieve.js\":869,\"fast-isnumeric\":225}],861:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../registry\"),o=t(\"../scatter/xy_defaults\"),s=t(\"./style_defaults\"),l=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,c=t(\"./attributes\"),u=n.coerceFont;function h(t,e,r,n){var i=e.orientation,a=e[{v:\"x\",h:\"y\"}[i]+\"axis\"],o=l(r,a)+i,s=r._alignmentOpts||{},c=n(\"alignmentgroup\"),u=s[o];u||(u=s[o]={});var h=u[c];h?h.traces.push(e):h=u[c]={traces:[e],alignmentIndex:Object.keys(u).length,offsetGroups:{}};var f=n(\"offsetgroup\"),p=h.offsetGroups,d=p[f];f&&(d||(d=p[f]={offsetIndex:Object.keys(p).length}),e._offsetIndex=d.offsetIndex)}function f(t,e,r,i,a,o){var s=!(!1===(o=o||{}).moduleHasSelected),l=!(!1===o.moduleHasUnselected),c=!(!1===o.moduleHasConstrain),h=!(!1===o.moduleHasCliponaxis),f=!(!1===o.moduleHasTextangle),p=!(!1===o.moduleHasInsideanchor),d=Array.isArray(a)||\"auto\"===a,g=d||\"inside\"===a,v=d||\"outside\"===a;if(g||v){var m=u(i,\"textfont\",r.font),y=n.extendFlat({},m);!(t.textfont&&t.textfont.color)&&delete y.color,u(i,\"insidetextfont\",y),v&&u(i,\"outsidetextfont\",m),s&&i(\"selected.textfont.color\"),l&&i(\"unselected.textfont.color\"),c&&i(\"constraintext\"),h&&i(\"cliponaxis\"),f&&i(\"textangle\")}g&&p&&i(\"insidetextanchor\")}e.exports={supplyDefaults:function(t,e,r,l){function u(r,i){return n.coerce(t,e,c,r,i)}if(o(t,e,l,u)){u(\"orientation\",e.x&&!e.y?\"h\":\"v\"),u(\"base\"),u(\"offset\"),u(\"width\"),u(\"text\"),u(\"hovertext\"),u(\"hovertemplate\");var h=u(\"textposition\");f(t,0,l,u,h,{moduleHasSelected:!0,moduleHasUnselected:!0,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),s(t,e,u,r,l);var p=(e.marker.line||{}).color,d=a.getComponentMethod(\"errorbars\",\"supplyDefaults\");d(t,e,p||i.defaultLine,{axis:\"y\"}),d(t,e,p||i.defaultLine,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,u)}else e.visible=!1},crossTraceDefaults:function(t,e){var r;function i(t){return n.coerce(r._input,r,c,t)}if(\"group\"===e.barmode)for(var a=0;a<t.length;a++)\"bar\"===(r=t[a]).type&&(r._input,h(0,r,e,i))},handleGroupingDefaults:h,handleText:f}},{\"../../components/color\":593,\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../scatter/xy_defaults\":1137,\"./attributes\":857,\"./style_defaults\":871}],862:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../../lib\").isArrayOrTypedArray;r.coerceString=function(t,e,r){if(\"string\"==typeof e){if(e||!t.noBlank)return e}else if((\"number\"==typeof e||!0===e)&&!t.strict)return String(e);return void 0!==r?r:t.dflt},r.coerceNumber=function(t,e,r){if(n(e)){e=+e;var i=t.min,a=t.max;if(!(void 0!==i&&e<i||void 0!==a&&e>a))return e}return void 0!==r?r:t.dflt},r.coerceColor=function(t,e,r){return i(e).isValid()?e:void 0!==r?r:t.dflt},r.coerceEnumerated=function(t,e,r){return t.coerceNumber&&(e=+e),-1!==t.values.indexOf(e)?e:void 0!==r?r:t.dflt},r.getValue=function(t,e){var r;return Array.isArray(t)?e<t.length&&(r=t[e]):r=t,r},r.getLineWidth=function(t,e){return 0<e.mlw?e.mlw:a(t.marker.line.width)?0:t.marker.line.width}},{\"../../lib\":719,\"fast-isnumeric\":225,tinycolor2:537}],863:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../../lib\").fillText,s=t(\"./helpers\").getLineWidth;function l(t,e,r,i){var a,s,l,c,u,h,f,p=t.cd,d=p[0].trace,g=p[0].t,v=\"closest\"===i,m=\"waterfall\"===d.type,y=t.maxHoverDistance,x=t.maxSpikeDistance;function b(t){return t[l]-t.w/2}function _(t){return t[l]+t.w/2}var w=v?b:function(t){return Math.min(b(t),t.p-g.bardelta/2)},k=v?_:function(t){return Math.max(_(t),t.p+g.bardelta/2)};function T(t,e){return n.inbox(t-a,e-a,y+Math.min(1,Math.abs(e-t)/f)-1)}function A(t){return T(w(t),k(t))}function M(t){var e=s,r=t.b,i=t[c];return m&&(i+=Math.abs(t.rawS||0)),n.inbox(r-e,i-e,y+(i-e)/(i-r)-1)}\"h\"===d.orientation?(a=r,s=e,l=\"y\",c=\"x\",u=M,h=A):(a=e,s=r,l=\"x\",c=\"y\",h=M,u=A);var S=t[l+\"a\"],E=t[c+\"a\"];f=Math.abs(S.r2c(S.range[1])-S.r2c(S.range[0]));var C=n.getDistanceFunction(i,u,h,function(t){return(u(t)+h(t))/2});if(n.getClosest(p,C,t),!1!==t.index){v||(w=function(t){return Math.min(b(t),t.p-g.bargroupwidth/2)},k=function(t){return Math.max(_(t),t.p+g.bargroupwidth/2)});var L=p[t.index],P=d.base?L.b+L.s:L.s;t[c+\"0\"]=t[c+\"1\"]=E.c2p(L[c],!0),t[c+\"LabelVal\"]=P;var O=g.extents[g.extents.round(L.p)];return t[l+\"0\"]=S.c2p(v?w(L):O[0],!0),t[l+\"1\"]=S.c2p(v?k(L):O[1],!0),t[l+\"LabelVal\"]=L.p,t.spikeDistance=(M(L)+function(t){return T(b(t),_(t))}(L))/2+x-y,t[l+\"Spike\"]=S.c2p(L.p,!0),o(L,d,t),t.hovertemplate=d.hovertemplate,t}}function c(t,e){var r=e.mcc||t.marker.color,n=e.mlcc||t.marker.line.color,i=s(t,e);return a.opacity(r)?r:a.opacity(n)&&i?n:void 0}e.exports={hoverPoints:function(t,e,r,n){var a=l(t,e,r,n);if(a){var o=a.cd,s=o[0].trace,u=o[a.index];return a.color=c(s,u),i.getComponentMethod(\"errorbars\",\"hoverInfo\")(u,s,a),[a]}},hoverOnBars:l,getTraceColor:c}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"../../registry\":847,\"./helpers\":862}],864:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,colorbar:t(\"../scatter/marker_colorbar\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"bar\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"oriented\",\"errorBarsOK\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../scatter/marker_colorbar\":1129,\"./arrays_to_calcdata\":856,\"./attributes\":857,\"./calc\":858,\"./cross_trace_calc\":860,\"./defaults\":861,\"./hover\":863,\"./layout_attributes\":865,\"./layout_defaults\":866,\"./plot\":867,\"./select\":868,\"./style\":870}],865:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\",\"relative\"],dflt:\"group\",editType:\"calc\"},barnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},bargap:{valType:\"number\",min:0,max:1,editType:\"calc\"},bargroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],866:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\"),o=t(\"./layout_attributes\");e.exports=function(t,e,r){function s(r,n){return a.coerce(t,e,o,r,n)}for(var l=!1,c=!1,u=!1,h={},f=s(\"barmode\"),p=0;p<r.length;p++){var d=r[p];if(n.traceIs(d,\"bar\")&&d.visible){if(l=!0,\"group\"===f){var g=d.xaxis+d.yaxis;h[g]&&(u=!0),h[g]=!0}if(d.visible&&\"histogram\"===d.type)\"category\"!==i.getFromId({_fullLayout:e},d[\"v\"===d.orientation?\"xaxis\":\"yaxis\"]).type&&(c=!0)}}l?(\"overlay\"!==f&&s(\"barnorm\"),s(\"bargap\",c&&!u?0:.2),s(\"bargroupgap\")):delete e.barmode}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./layout_attributes\":865}],867:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../registry\"),u=t(\"../../plots/cartesian/axes\").tickText,h=t(\"./style\"),f=t(\"./helpers\"),p=t(\"./attributes\"),d=p.text,g=p.textposition,v=3;function m(t,e){return t<e?1:-1}function y(t){return\"auto\"===t?0:t}function x(t,e,r,n,i,a){var o=!!a.isHorizontal,s=!!a.constrained,l=a.angle||0,c=a.anchor||0,u=i.width,h=i.height,f=Math.abs(e-t),p=Math.abs(n-r),d=f>2*v&&p>2*v?v:0;f-=2*d,p-=2*d;var g=!1;if(!(\"auto\"===l)||u<=f&&h<=p||!(u>f||h>p)||(u>p||h>f)&&u<h==f<p||(g=!0),g){var x=p;p=f,f=x}var b=y(l),_=Math.abs(Math.sin(Math.PI/180*b)),w=Math.abs(Math.cos(Math.PI/180*b)),k=Math.max(f*w,p*_),T=Math.max(f*_,p*w),A=s?Math.min(k/u,T/h):Math.max(w,_);A=Math.min(1,A);var M=(t+e)/2,S=(r+n)/2;\"middle\"!==c&&(d+=.5*(A*(o!==g?h:u)*_+A*(o!==g?u:h)*w),o?(d*=m(t,e),M=\"start\"===c?t+d:e-d):(d*=m(r,n),S=\"start\"===c?r+d:n-d));return g&&(b+=90),{textX:(i.left+i.right)/2,textY:(i.top+i.bottom)/2,targetX:M,targetY:S,scale:A,rotate:b}}function b(t,e,r,n,i,a){var o,s=!!a.isHorizontal,l=!!a.constrained,c=a.angle||0,u=i.width,h=i.height,f=Math.abs(e-t),p=Math.abs(n-r);o=s?p>2*v?v:0:f>2*v?v:0;var d=1;l&&(d=s?Math.min(1,p/h):Math.min(1,f/u));var g=y(c);o+=.5*(d*(s?h:u)*Math.abs(Math.sin(Math.PI/180*g))+d*(s?u:h)*Math.abs(Math.cos(Math.PI/180*g)));var x=(t+e)/2,b=(r+n)/2;return s?x=e-o*m(e,t):b=n+o*m(r,n),{textX:(i.left+i.right)/2,textY:(i.top+i.bottom)/2,targetX:x,targetY:b,scale:d,rotate:g}}function _(t){var e,r=t.textX,n=t.textY,i=t.targetX,a=t.targetY,o=t.scale,s=t.rotate;return o<1?e=\"scale(\"+o+\") \":(o=1,e=\"\"),\"translate(\"+(i-o*r)+\" \"+(a-o*n)+\")\"+e+(s?\"rotate(\"+s+\" \"+r+\" \"+n+\") \":\"\")}e.exports={plot:function(t,e,r,p,y){var w=e.xaxis,k=e.yaxis,T=t._fullLayout;y||(y={mode:T.barmode,norm:T.barmode,gap:T.bargap,groupgap:T.bargroupgap});var A=a.makeTraceGroups(p,r,\"trace bars\").each(function(r){var c=n.select(this),p=r[0].trace,T=\"waterfall\"===p.type,A=\"funnel\"===p.type,M=\"bar\"===p.type||A,S=0;T&&p.connector.visible&&\"between\"===p.connector.mode&&(S=p.connector.line.width/2);var E=\"h\"===p.orientation,C=a.ensureSingle(c,\"g\",\"points\").selectAll(\"g.point\").data(a.identity);C.enter().append(\"g\").classed(\"point\",!0),C.exit().remove(),C.each(function(c,T){var A,C,L=n.select(this),P=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),n?[i,a]:[a,i]}(c,w,k,E),O=P[0][0],z=P[0][1],I=P[1][0],D=P[1][1],R=!(O!==z&&I!==D&&i(O)&&i(z)&&i(I)&&i(D));if(R&&M&&f.getLineWidth(p,c)&&(E?z-O==0:D-I==0)&&(R=!1),c.isBlank=R,S&&(E?(O-=m(O,z)*S,z+=m(O,z)*S):(I-=m(I,D)*S,D+=m(I,D)*S)),\"waterfall\"===p.type){if(!R){var F=p[c.dir].marker;A=F.line.width,C=F.color}}else A=f.getLineWidth(p,c),C=c.mc||p.marker.color;var B=n.round(A/2%1,2);function N(t){return 0===y.gap&&0===y.groupgap?n.round(Math.round(t)-B,2):t}if(!t._context.staticPlot){var j=s.opacity(C)<1||A>.01?N:function(t,e){return Math.abs(t-e)>=2?N(t):t>e?Math.ceil(t):Math.floor(t)};O=j(O,z),z=j(z,O),I=j(I,D),D=j(D,I)}a.ensureSingle(L,\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"d\",R?\"M0,0Z\":\"M\"+O+\",\"+I+\"V\"+D+\"H\"+z+\"V\"+I+\"Z\").call(l.setClipUrl,e.layerClipId,t),function(t,e,r,n,i,s,c,p,m,y){var w,k=e.xaxis,T=e.yaxis,A=t._fullLayout;function M(e,r,n){var i=a.ensureSingle(e,\"text\").text(r).attr({class:\"bartext bartext-\"+w,transform:\"\",\"text-anchor\":\"middle\",\"data-notex\":1}).call(l.font,n).call(o.convertToTspans,t);return i}var S=n[0].trace,E=\"h\"===S.orientation,C=function(t,e,r,n){var i,o=t[0].trace;return i=o.textinfo?function(t,e,r,n){var i=t[0].trace,o=\"h\"===i.orientation,s=\"waterfall\"===i.type,l=\"funnel\"===i.type;function c(t){var e=o?r:n;return u(e,+t,!0).text}var h,f,p=i.textinfo,d=t[e],g=p.split(\"+\"),v=[],m=function(t){return-1!==g.indexOf(t)};if(m(\"label\")&&v.push((f=t[e].p,u(o?n:r,f,!0).text)),m(\"text\")&&(0===(h=a.castOption(i,d.i,\"text\"))||h)&&v.push(h),s){var y=+d.rawS||d.s,x=d.v,b=x-y;m(\"initial\")&&v.push(c(b)),m(\"delta\")&&v.push(c(y)),m(\"final\")&&v.push(c(x))}if(l){m(\"value\")&&v.push(c(d.s));var _=0;m(\"percent initial\")&&_++,m(\"percent previous\")&&_++,m(\"percent total\")&&_++;var w=_>1;m(\"percent initial\")&&(h=a.formatPercent(d.begR),w&&(h+=\" of initial\"),v.push(h)),m(\"percent previous\")&&(h=a.formatPercent(d.difR),w&&(h+=\" of previous\"),v.push(h)),m(\"percent total\")&&(h=a.formatPercent(d.sumR),w&&(h+=\" of total\"),v.push(h))}return v.join(\"<br>\")}(t,e,r,n):f.getValue(o.text,e),f.coerceString(d,i)}(n,i,k,T);w=function(t,e){var r=f.getValue(t.textposition,e);return f.coerceEnumerated(g,r)}(S,i);var L=\"stack\"===y.mode||\"relative\"===y.mode,P=n[i],O=!L||P._outmost;if(C&&\"none\"!==w&&(!P.isBlank&&s!==c&&p!==m||\"auto\"!==w&&\"inside\"!==w)){var z=A.font,I=h.getBarColor(n[i],S),D=h.getInsideTextFont(S,i,z,I),R=h.getOutsideTextFont(S,i,z),F=r.datum();E?\"log\"===k.type&&F.s0<=0&&(s=k.range[0]<k.range[1]?0:k._length):\"log\"===T.type&&F.s0<=0&&(p=T.range[0]<T.range[1]?T._length:0);var B,N,j,U,V,q,H=Math.abs(c-s)-2*v,G=Math.abs(m-p)-2*v;if(\"outside\"===w&&(O||P.hasB||(w=\"inside\")),\"auto\"===w)if(O){w=\"inside\",B=M(r,C,D),N=l.bBox(B.node()),j=N.width,U=N.height;var Y=j>0&&U>0,W=j<=H&&U<=G,X=j<=G&&U<=H,Z=E?H>=j*(G/U):G>=U*(H/j);Y&&(W||X||Z)?w=\"inside\":(w=\"outside\",B.remove(),B=null)}else w=\"inside\";!B&&(B=M(r,C,\"outside\"===w?R:D),N=l.bBox(B.node()),j=N.width,U=N.height,j<=0||U<=0)?B.remove():(\"outside\"===w?(q=\"both\"===S.constraintext||\"outside\"===S.constraintext,V=_(b(s,c,p,m,N,{isHorizontal:E,constrained:q,angle:S.textangle}))):(q=\"both\"===S.constraintext||\"inside\"===S.constraintext,V=_(x(s,c,p,m,N,{isHorizontal:E,constrained:q,angle:S.textangle,anchor:S.insidetextanchor}))),B.attr(\"transform\",V))}else r.select(\"text\").remove()}(t,e,L,r,T,O,z,I,D,y),e.layerClipId&&l.hideOutsideRangePoint(c,L.select(\"text\"),w,k,p.xcalendar,p.ycalendar)});var L=!1===p.cliponaxis;l.setClipUrl(c,L?null:e.layerClipId,t)});c.getComponentMethod(\"errorbars\",\"plot\")(t,A,e)},getTransform:_,toMoveInsideBar:x,toMoveOutsideBar:b}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./attributes\":857,\"./helpers\":862,\"./style\":870,d3:163,\"fast-isnumeric\":225}],868:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=e.c2p(n?t.s0:t.p0,!0),o=e.c2p(n?t.s1:t.p1,!0),s=r.c2p(n?t.p0:t.s0,!0),l=r.c2p(n?t.p1:t.s1,!0);return i?[(a+o)/2,(s+l)/2]:n?[o,(s+l)/2]:[(a+o)/2,l]}e.exports=function(t,e){var r,i=t.cd,a=t.xaxis,o=t.yaxis,s=i[0].trace,l=\"funnel\"===s.type,c=\"h\"===s.orientation,u=[];if(!1===e)for(r=0;r<i.length;r++)i[r].selected=0;else for(r=0;r<i.length;r++){var h=i[r],f=\"ct\"in h?h.ct:n(h,a,o,c,l);e.contains(f,!1,r,t)?(u.push({pointNumber:r,x:a.c2d(h.x),y:o.c2d(h.y)}),h.selected=1):h.selected=0}return u}},{}],869:[function(t,e,r){\"use strict\";e.exports=a;var n=t(\"../../lib\").distinctVals,i=t(\"../../constants/numerical\").BADNUM;function a(t,e){this.traces=t,this.sepNegVal=e.sepNegVal,this.overlapNoMerge=e.overlapNoMerge;for(var r=1/0,a=[],o=0;o<t.length;o++){for(var s=t[o],l=0;l<s.length;l++){var c=s[l];c.p!==i&&a.push(c.p)}s[0]&&s[0].width1&&(r=Math.min(s[0].width1,r))}this.positions=a;var u=n(a);this.distinctPositions=u.vals,1===u.vals.length&&r!==1/0?this.minDiff=r:this.minDiff=Math.min(u.minDiff,r),this.binWidth=this.minDiff,this.bins={}}a.prototype.put=function(t,e){var r=this.getLabel(t,e),n=this.bins[r]||0;return this.bins[r]=n+e,n},a.prototype.get=function(t,e){var r=this.getLabel(t,e);return this.bins[r]||0},a.prototype.getLabel=function(t,e){return(e<0&&this.sepNegVal?\"v\":\"^\")+(this.overlapNoMerge?t:Math.round(t/this.binWidth))}},{\"../../constants/numerical\":695,\"../../lib\":719}],870:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../lib\"),s=t(\"../../registry\"),l=t(\"./attributes\"),c=l.textfont,u=l.insidetextfont,h=l.outsidetextfont,f=t(\"./helpers\");function p(t,e,r){a.pointStyle(t.selectAll(\"path\"),e,r),d(t,e,r)}function d(t,e,r){t.selectAll(\"text\").each(function(t){var i=n.select(this),o=g(i,t,e,r);a.font(i,o)})}function g(t,e,r,n){var i=n._fullLayout.font,a=r.textfont;if(t.classed(\"bartext-inside\")){var o=b(e,r);a=m(r,e.i,i,o)}else t.classed(\"bartext-outside\")&&(a=y(r,e.i,i));return a}function v(t,e,r){return x(c,t.textfont,e,r)}function m(t,e,r,n){var a=v(t,e,r);return(void 0===t._input.textfont||void 0===t._input.textfont.color||Array.isArray(t.textfont.color)&&void 0===t.textfont.color[e])&&(a={color:i.contrast(n),family:a.family,size:a.size}),x(u,t.insidetextfont,e,a)}function y(t,e,r){var n=v(t,e,r);return x(h,t.outsidetextfont,e,n)}function x(t,e,r,n){e=e||{};var i=f.getValue(e.family,r),a=f.getValue(e.size,r),o=f.getValue(e.color,r);return{family:f.coerceString(t.family,i,n.family),size:f.coerceNumber(t.size,a,n.size),color:f.coerceColor(t.color,o,n.color)}}function b(t,e){return\"waterfall\"===e.type?e[t.dir].marker.color:t.mc||e.marker.color}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.barlayer\").selectAll(\"g.trace\"),r=e.size(),i=t._fullLayout;e.style(\"opacity\",function(t){return t[0].trace.opacity}).each(function(t){(\"stack\"===i.barmode&&r>1||0===i.bargap&&0===i.bargroupgap&&!t[0].trace.marker.line.width)&&n.select(this).attr(\"shape-rendering\",\"crispEdges\")}),e.selectAll(\"g.points\").each(function(e){p(n.select(this),e[0].trace,t)}),s.getComponentMethod(\"errorbars\",\"style\")(e)},styleTextPoints:d,styleOnSelect:function(t,e,r){var i=e[0].trace;i.selectedpoints?function(t,e,r){a.selectedPointStyle(t.selectAll(\"path\"),e),function(t,e,r){t.each(function(t){var i,s=n.select(this);if(t.selected){i=o.extendFlat({},g(s,t,e,r));var l=e.selected.textfont&&e.selected.textfont.color;l&&(i.color=l),a.font(s,i)}else a.selectedTextStyle(s,e)})}(t.selectAll(\"text\"),e,r)}(r,i,t):(p(r,i,t),s.getComponentMethod(\"errorbars\",\"style\")(r))},getInsideTextFont:m,getOutsideTextFont:y,getBarColor:b}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../registry\":847,\"./attributes\":857,\"./helpers\":862,d3:163}],871:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s){r(\"marker.color\",o),i(t,\"marker\")&&a(t,e,s,r,{prefix:\"marker.\",cLetter:\"c\"}),r(\"marker.line.color\",n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,r,{prefix:\"marker.line.\",cLetter:\"c\"}),r(\"marker.line.width\"),r(\"marker.opacity\"),r(\"selected.marker.color\"),r(\"unselected.marker.color\")}},{\"../../components/color\":593,\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604}],872:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../scatterpolar/attributes\"),o=t(\"../bar/attributes\");e.exports={r:a.r,theta:a.theta,r0:a.r0,dr:a.dr,theta0:a.theta0,dtheta:a.dtheta,thetaunit:a.thetaunit,base:i({},o.base,{}),offset:i({},o.offset,{}),width:i({},o.width,{}),text:i({},o.text,{}),hovertext:i({},o.hovertext,{}),marker:o.marker,hoverinfo:a.hoverinfo,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../bar/attributes\":857,\"../scatterpolar/attributes\":1179}],873:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"../bar/arrays_to_calcdata\"),o=t(\"../bar/cross_trace_calc\").setGroupPositions,s=t(\"../scatter/calc_selection\"),l=t(\"../../registry\").traceIs,c=t(\"../../lib\").extendFlat;e.exports={calc:function(t,e){for(var r=t._fullLayout,o=e.subplot,l=r[o].radialaxis,c=r[o].angularaxis,u=l.makeCalcdata(e,\"r\"),h=c.makeCalcdata(e,\"theta\"),f=e._length,p=new Array(f),d=u,g=h,v=0;v<f;v++)p[v]={p:g[v],s:d[v]};function m(t){var r=e[t];void 0!==r&&(e[\"_\"+t]=Array.isArray(r)?c.makeCalcdata(e,t):c.d2c(r,e.thetaunit))}return\"linear\"===c.type&&(m(\"width\"),m(\"offset\")),n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),a(p,e),s(p,e),p},crossTraceCalc:function(t,e,r){for(var n=t.calcdata,i=[],a=0;a<n.length;a++){var s=n[a],u=s[0].trace;!0===u.visible&&l(u,\"bar\")&&u.subplot===r&&i.push(s)}var h=c({},e.radialaxis,{_id:\"x\"}),f=e.angularaxis;o(t,f,h,i,{mode:e.barmode,norm:e.barnorm,gap:e.bargap,groupgap:e.bargroupgap})}}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"../../lib\":719,\"../../registry\":847,\"../bar/arrays_to_calcdata\":856,\"../bar/cross_trace_calc\":860,\"../scatter/calc_selection\":1114}],874:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatterpolar/defaults\").handleRThetaDefaults,a=t(\"../bar/style_defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}i(t,e,s,l)?(l(\"thetaunit\"),l(\"base\"),l(\"offset\"),l(\"width\"),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),a(t,e,l,r,s),n.coerceSelectionMarkerOpacity(e,l)):e.visible=!1}},{\"../../lib\":719,\"../bar/style_defaults\":871,\"../scatterpolar/defaults\":1181,\"./attributes\":872}],875:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../bar/hover\").getTraceColor,o=i.fillText,s=t(\"../scatterpolar/hover\").makeHoverPointText,l=t(\"../../plots/polar/helpers\").isPtInsidePolygon;e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,h=t.subplot,f=h.radialAxis,p=h.angularAxis,d=h.vangles,g=d?l:i.isPtInsideSector,v=t.maxHoverDistance,m=p._period||2*Math.PI,y=Math.abs(f.g2p(Math.sqrt(e*e+r*r))),x=Math.atan2(r,e);f.range[0]>f.range[1]&&(x+=Math.PI);if(n.getClosest(c,function(t){return g(y,x,[t.rp0,t.rp1],[t.thetag0,t.thetag1],d)?v+Math.min(1,Math.abs(t.thetag1-t.thetag0)/m)-1+(t.rp1-y)/(t.rp1-t.rp0)-1:1/0},t),!1!==t.index){var b=c[t.index];t.x0=t.x1=b.ct[0],t.y0=t.y1=b.ct[1];var _=i.extendFlat({},b,{r:b.s,theta:b.p});return o(b,u,t),s(_,u,h,t),t.hovertemplate=u.hovertemplate,t.color=a(u,b),t.xLabelVal=t.yLabelVal=void 0,b.s<0&&(t.idealAlign=\"left\"),[t]}}},{\"../../components/fx\":632,\"../../lib\":719,\"../../plots/polar/helpers\":830,\"../bar/hover\":863,\"../scatterpolar/hover\":1182}],876:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"barpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"bar\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),colorbar:t(\"../scatter/marker_colorbar\"),style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),meta:{}}},{\"../../plots/polar\":831,\"../bar/select\":868,\"../bar/style\":870,\"../scatter/marker_colorbar\":1129,\"./attributes\":872,\"./calc\":873,\"./defaults\":874,\"./hover\":875,\"./layout_attributes\":877,\"./layout_defaults\":878,\"./plot\":879}],877:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},bargap:{valType:\"number\",dflt:.1,min:0,max:1,editType:\"calc\"}}},{}],878:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a,o={};function s(r,o){return n.coerce(t[a]||{},e[a],i,r,o)}for(var l=0;l<r.length;l++){var c=r[l];\"barpolar\"===c.type&&!0===c.visible&&(o[a=c.subplot]||(s(\"barmode\"),s(\"bargap\"),o[a]=1))}}},{\"../../lib\":719,\"./layout_attributes\":877}],879:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../components/drawing\"),s=t(\"../../plots/polar/helpers\");e.exports=function(t,e,r){var l=e.xaxis,c=e.yaxis,u=e.radialAxis,h=e.angularAxis,f=function(t){var e=t.cxx,r=t.cyy;if(t.vangles)return function(n,i,o,l){var c,u;a.angleDelta(o,l)>0?(c=o,u=l):(c=l,u=o);var h=s.findEnclosingVertexAngles(c,t.vangles)[0],f=s.findEnclosingVertexAngles(u,t.vangles)[1],p=[h,(c+u)/2,f];return s.pathPolygonAnnulus(n,i,c,u,p,e,r)};return function(t,n,i,o){return a.pathAnnulus(t,n,i,o,e,r)}}(e),p=e.layers.frontplot.select(\"g.barlayer\");a.makeTraceGroups(p,r,\"trace bars\").each(function(){var r=n.select(this),s=a.ensureSingle(r,\"g\",\"points\").selectAll(\"g.point\").data(a.identity);s.enter().append(\"g\").style(\"vector-effect\",\"non-scaling-stroke\").style(\"stroke-miterlimit\",2).classed(\"point\",!0),s.exit().remove(),s.each(function(t){var e,r=n.select(this),o=t.rp0=u.c2p(t.s0),s=t.rp1=u.c2p(t.s1),p=t.thetag0=h.c2g(t.p0),d=t.thetag1=h.c2g(t.p1);if(i(o)&&i(s)&&i(p)&&i(d)&&o!==s&&p!==d){var g=u.c2g(t.s1),v=(p+d)/2;t.ct=[l.c2p(g*Math.cos(v)),c.c2p(g*Math.sin(v))],e=f(o,s,p,d)}else e=\"M0,0Z\";a.ensureSingle(r,\"path\").attr(\"d\",e)}),o.setClipUrl(r,e._hasClipOnAxisFalse?e.clipIds.forTraces:null,t)})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../plots/polar/helpers\":830,d3:163,\"fast-isnumeric\":225}],880:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../bar/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../lib/extend\").extendFlat,l=n.marker,c=l.line;e.exports={y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},y0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},name:{valType:\"string\",editType:\"calc+clearAxisTypes\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),hovertemplate:o({}),whiskerwidth:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"calc\"},notched:{valType:\"boolean\",editType:\"calc\"},notchwidth:{valType:\"number\",min:0,max:.5,dflt:.25,editType:\"calc\"},boxpoints:{valType:\"enumerated\",values:[\"all\",\"outliers\",\"suspectedoutliers\",!1],dflt:\"outliers\",editType:\"calc\"},boxmean:{valType:\"enumerated\",values:[!0,\"sd\",!1],dflt:!1,editType:\"calc\"},jitter:{valType:\"number\",min:0,max:1,editType:\"calc\"},pointpos:{valType:\"number\",min:-2,max:2,editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},width:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},marker:{outliercolor:{valType:\"color\",dflt:\"rgba(0, 0, 0, 0)\",editType:\"style\"},symbol:s({},l.symbol,{arrayOk:!1,editType:\"plot\"}),opacity:s({},l.opacity,{arrayOk:!1,dflt:1,editType:\"style\"}),size:s({},l.size,{arrayOk:!1,editType:\"calc\"}),color:s({},l.color,{arrayOk:!1,editType:\"style\"}),line:{color:s({},c.color,{arrayOk:!1,dflt:a.defaultLine,editType:\"style\"}),width:s({},c.width,{arrayOk:!1,dflt:0,editType:\"style\"}),outliercolor:{valType:\"color\",editType:\"style\"},outlierwidth:{valType:\"number\",min:0,dflt:1,editType:\"style\"},editType:\"style\"},editType:\"plot\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,offsetgroup:i.offsetgroup,alignmentgroup:i.alignmentgroup,selected:{marker:n.selected.marker,editType:\"style\"},unselected:{marker:n.unselected.marker,editType:\"style\"},hoveron:{valType:\"flaglist\",flags:[\"boxes\",\"points\"],dflt:\"boxes+points\",editType:\"style\"}}},{\"../../components/color/attributes\":592,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../bar/attributes\":857,\"../scatter/attributes\":1112}],881:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=i._,o=t(\"../../plots/cartesian/axes\");function s(t,e,r){var n={text:\"tx\",hovertext:\"htx\"};for(var i in n)Array.isArray(e[i])&&(t[n[i]]=e[i][r])}function l(t,e){return t.v-e.v}function c(t){return t.v}e.exports=function(t,e){var r,u,h,f,p,d=t._fullLayout,g=o.getFromId(t,e.xaxis||\"x\"),v=o.getFromId(t,e.yaxis||\"y\"),m=[],y=\"violin\"===e.type?\"_numViolins\":\"_numBoxes\";\"h\"===e.orientation?(u=g,h=\"x\",f=v,p=\"y\"):(u=v,h=\"y\",f=g,p=\"x\");var x,b=u.makeCalcdata(e,h),_=function(t,e,r,a,o){if(e in t)return r.makeCalcdata(t,e);var s;s=e+\"0\"in t?t[e+\"0\"]:\"name\"in t&&(\"category\"===r.type||n(t.name)&&-1!==[\"linear\",\"log\"].indexOf(r.type)||i.isDateTime(t.name)&&\"date\"===r.type)?t.name:o;var l=\"multicategory\"===r.type?r.r2c_just_indices(s):r.d2c(s,0,t[e+\"calendar\"]);return a.map(function(){return l})}(e,p,f,b,d[y]),w=i.distinctVals(_),k=w.vals,T=w.minDiff/2,A=function(t,e){for(var r=t.length,n=new Array(r+1),i=0;i<r;i++)n[i]=t[i]-e;return n[r]=t[r-1]+e,n}(k,T),M=k.length,S=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=[];return e}(M);for(r=0;r<e._length;r++){var E=b[r];if(n(E)){var C=i.findBin(_[r],A);if(C>=0&&C<M){var L={v:E,i:r};s(L,e,r),S[C].push(L)}}}var P=\"all\"===(e.boxpoints||e.points)?i.identity:function(t){return t.v<x.lf||t.v>x.uf};for(r=0;r<M;r++)if(S[r].length>0){var O=S[r].sort(l),z=O.map(c),I=z.length;(x={}).pos=k[r],x.pts=O,x[p]=x.pos,x[h]=x.pts.map(function(t){return t.v}),x.min=z[0],x.max=z[I-1],x.mean=i.mean(z,I),x.sd=i.stdev(z,I,x.mean),x.q1=i.interp(z,.25),x.med=i.interp(z,.5),x.q3=i.interp(z,.75),x.lf=Math.min(x.q1,z[Math.min(i.findBin(2.5*x.q1-1.5*x.q3,z,!0)+1,I-1)]),x.uf=Math.max(x.q3,z[Math.max(i.findBin(2.5*x.q3-1.5*x.q1,z),0)]),x.lo=4*x.q1-3*x.q3,x.uo=4*x.q3-3*x.q1;var D=1.57*(x.q3-x.q1)/Math.sqrt(I);x.ln=x.med-D,x.un=x.med+D,x.pts2=O.filter(P),m.push(x)}!function(t,e){if(i.isArrayOrTypedArray(e.selectedpoints))for(var r=0;r<t.length;r++){for(var n=t[r].pts||[],a={},o=0;o<n.length;o++)a[n[o].i]=o;i.tagSelected(n,e,a)}}(m,e);var R=o.findExtremes(u,b,{padded:!0});return e._extremes[u._id]=R,m.length>0?(m[0].t={num:d[y],dPos:T,posLetter:p,valLetter:h,labels:{med:a(t,\"median:\"),min:a(t,\"min:\"),q1:a(t,\"q1:\"),q3:a(t,\"q3:\"),max:a(t,\"max:\"),mean:\"sd\"===e.boxmean?a(t,\"mean \\xb1 \\u03c3:\"):a(t,\"mean:\"),lf:a(t,\"lower fence:\"),uf:a(t,\"upper fence:\")}},d[y]++,m):[{t:{empty:!0}}]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"fast-isnumeric\":225}],882:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,o=[\"v\",\"h\"];function s(t,e,r,o){var s,l,c,u=e.calcdata,h=e._fullLayout,f=o._id,p=f.charAt(0),d=[],g=0;for(s=0;s<r.length;s++)for(c=u[r[s]],l=0;l<c.length;l++)d.push(c[l].pos),g+=(c[l].pts2||[]).length;if(d.length){var v=i.distinctVals(d),m=v.minDiff/2;n.minDtick(o,v.minDiff,v.vals[0],!0);var y=h[\"violin\"===t?\"_numViolins\":\"_numBoxes\"],x=\"group\"===h[t+\"mode\"]&&y>1,b=1-h[t+\"gap\"],_=1-h[t+\"groupgap\"];for(s=0;s<r.length;s++){var w,k,T,A,M,S,E=(c=u[r[s]])[0].trace,C=c[0].t,L=E.width,P=E.side;if(L)w=k=A=L/2,T=0;else if(w=m,x){var O=a(h,o._id)+E.orientation,z=(h._alignmentOpts[O]||{})[E.alignmentgroup]||{},I=Object.keys(z.offsetGroups||{}).length,D=I||y;k=w*b*_/D,T=2*w*(((I?E._offsetIndex:C.num)+.5)/D-.5)*b,A=w*b/D}else k=w*b*_,T=0,A=w;C.dPos=w,C.bPos=T,C.bdPos=k,C.wHover=A;var R,F,B,N,j,U,V=T+k,q=Boolean(L);if(\"positive\"===P?(M=w*(L?1:.5),R=V,S=R=T):\"negative\"===P?(M=R=T,S=w*(L?1:.5),F=V):(M=S=w,R=F=V),(E.boxpoints||E.points)&&g>0){var H=E.pointpos,G=E.jitter,Y=E.marker.size/2,W=0;H+G>=0&&((W=V*(H+G))>M?(q=!0,j=Y,B=W):W>R&&(j=Y,B=M)),W<=M&&(B=M);var X=0;H-G<=0&&((X=-V*(H-G))>S?(q=!0,U=Y,N=X):X>F&&(U=Y,N=S)),X<=S&&(N=S)}else B=M,N=S;var Z=new Array(c.length);for(l=0;l<c.length;l++)Z[l]=c[l].pos;E._extremes[f]=n.findExtremes(o,Z,{padded:q,vpadminus:N,vpadplus:B,ppadminus:{x:U,y:j}[p],ppadplus:{x:j,y:U}[p]})}}}e.exports={crossTraceCalc:function(t,e){for(var r=t.calcdata,n=e.xaxis,i=e.yaxis,a=0;a<o.length;a++){for(var l=o[a],c=\"h\"===l?i:n,u=[],h=0;h<r.length;h++){var f=r[h],p=f[0].t,d=f[0].trace;!0!==d.visible||\"box\"!==d.type&&\"candlestick\"!==d.type||p.empty||(d.orientation||\"v\")!==l||d.xaxis!==n._id||d.yaxis!==i._id||u.push(h)}s(\"box\",t,u,c)}},setPositionOffset:s}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_ids\":770}],883:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../bar/defaults\").handleGroupingDefaults,s=t(\"./attributes\");function l(t,e,r,a){var o,s,l=r(\"y\"),c=r(\"x\"),u=c&&c.length;if(l&&l.length)o=\"v\",u?s=Math.min(n.minRowLength(c),n.minRowLength(l)):(r(\"x0\"),s=n.minRowLength(l));else{if(!u)return void(e.visible=!1);o=\"h\",r(\"y0\"),s=n.minRowLength(c)}e._length=s,i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a),r(\"orientation\",o)}function c(t,e,r,i){var a=i.prefix,o=n.coerce2(t,e,s,\"marker.outliercolor\"),l=r(\"marker.line.outliercolor\"),c=r(a+\"points\",o||l?\"suspectedoutliers\":void 0);c?(r(\"jitter\",\"all\"===c?.3:0),r(\"pointpos\",\"all\"===c?-1.5:0),r(\"marker.symbol\"),r(\"marker.opacity\"),r(\"marker.size\"),r(\"marker.color\",e.line.color),r(\"marker.line.color\"),r(\"marker.line.width\"),\"suspectedoutliers\"===c&&(r(\"marker.line.outliercolor\",e.marker.color),r(\"marker.line.outlierwidth\")),r(\"selected.marker.color\"),r(\"unselected.marker.color\"),r(\"selected.marker.size\"),r(\"unselected.marker.size\"),r(\"text\"),r(\"hovertext\")):delete e.marker;var u=r(\"hoveron\");\"all\"!==u&&-1===u.indexOf(\"points\")||r(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,r)}e.exports={supplyDefaults:function(t,e,r,i){function o(r,i){return n.coerce(t,e,s,r,i)}l(t,e,o,i),!1!==e.visible&&(o(\"line.color\",(t.marker||{}).color||r),o(\"line.width\"),o(\"fillcolor\",a.addOpacity(e.line.color,.5)),o(\"whiskerwidth\"),o(\"boxmean\"),o(\"width\"),o(\"notched\",void 0!==t.notchwidth)&&o(\"notchwidth\"),c(t,e,o,{prefix:\"box\"}))},crossTraceDefaults:function(t,e){var r,i;function a(t){return n.coerce(i._input,i,s,t)}for(var l=0;l<t.length;l++){var c=(i=t[l]).type;\"box\"!==c&&\"violin\"!==c||(r=i._input,\"group\"===e[c+\"mode\"]&&o(r,i,e,a))}},handleSampleDefaults:l,handlePointsDefaults:c}},{\"../../components/color\":593,\"../../lib\":719,\"../../registry\":847,\"../bar/defaults\":861,\"./attributes\":880}],884:[function(t,e,r){\"use strict\";e.exports=function(t,e){return e.hoverOnBox&&(t.hoverOnBox=e.hoverOnBox),\"xVal\"in e&&(t.x=e.xVal),\"yVal\"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],885:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=i.fillText;function l(t,e,r,s){var l,c,u,h,f,p,d,g,v,m,y,x,b,_,w=t.cd,k=t.xa,T=t.ya,A=w[0].trace,M=w[0].t,S=\"violin\"===A.type,E=[],C=M.bdPos,L=M.wHover,P=function(t){return t.pos+M.bPos-p};S&&\"both\"!==A.side?(\"positive\"===A.side&&(v=function(t){var e=P(t);return a.inbox(e,e+L,m)},x=C,b=0),\"negative\"===A.side&&(v=function(t){var e=P(t);return a.inbox(e-L,e,m)},x=0,b=C)):(v=function(t){var e=P(t);return a.inbox(e-L,e+L,m)},x=b=C),_=S?function(t){return a.inbox(t.span[0]-f,t.span[1]-f,m)}:function(t){return a.inbox(t.min-f,t.max-f,m)},\"h\"===A.orientation?(f=e,p=r,d=_,g=v,l=\"y\",u=T,c=\"x\",h=k):(f=r,p=e,d=v,g=_,l=\"x\",u=k,c=\"y\",h=T);var O=Math.min(1,C/Math.abs(u.r2c(u.range[1])-u.r2c(u.range[0])));function z(t){return(d(t)+g(t))/2}m=t.maxHoverDistance-O,y=t.maxSpikeDistance-O;var I=a.getDistanceFunction(s,d,g,z);if(a.getClosest(w,I,t),!1===t.index)return[];var D=w[t.index],R=A.line.color,F=(A.marker||{}).color;o.opacity(R)&&A.line.width?t.color=R:o.opacity(F)&&A.boxpoints?t.color=F:t.color=A.fillcolor,t[l+\"0\"]=u.c2p(D.pos+M.bPos-b,!0),t[l+\"1\"]=u.c2p(D.pos+M.bPos+x,!0),t[l+\"LabelVal\"]=D.pos;var B=l+\"Spike\";t.spikeDistance=z(D)*y/m,t[B]=u.c2p(D.pos,!0);var N={},j=[\"med\",\"q1\",\"q3\",\"min\",\"max\"];(A.boxmean||(A.meanline||{}).visible)&&j.push(\"mean\"),(A.boxpoints||A.points)&&j.push(\"lf\",\"uf\");for(var U=0;U<j.length;U++){var V=j[U];if(V in D&&!(D[V]in N)){N[D[V]]=!0;var q=D[V],H=h.c2p(q,!0),G=i.extendFlat({},t);G.attr=V,G[c+\"0\"]=G[c+\"1\"]=H,G[c+\"LabelVal\"]=q,G[c+\"Label\"]=(M.labels?M.labels[V]+\" \":\"\")+n.hoverLabelText(h,q),G.hoverOnBox=!0,\"mean\"===V&&\"sd\"in D&&\"sd\"===A.boxmean&&(G[c+\"err\"]=D.sd),t.name=\"\",t.spikeDistance=void 0,t[B]=void 0,G.hovertemplate=!1,E.push(G)}}return E}function c(t,e,r){for(var n,o,l,c=t.cd,u=t.xa,h=t.ya,f=c[0].trace,p=u.c2p(e),d=h.c2p(r),g=a.quadrature(function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(u.c2p(t.x)-p)-e,1-3/e)},function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(h.c2p(t.y)-d)-e,1-3/e)}),v=!1,m=0;m<c.length;m++){o=c[m];for(var y=0;y<(o.pts||[]).length;y++){var x=g(l=o.pts[y]);x<=t.distance&&(t.distance=x,v=[m,y])}}if(!v)return!1;l=(o=c[v[0]]).pts[v[1]];var b,_=u.c2p(l.x,!0),w=h.c2p(l.y,!0),k=l.mrc||1;return n=i.extendFlat({},t,{index:l.i,color:(f.marker||{}).color,name:f.name,x0:_-k,x1:_+k,y0:w-k,y1:w+k,spikeDistance:t.distance,hovertemplate:f.hovertemplate}),\"h\"===f.orientation?(b=h,n.xLabelVal=l.x,n.yLabelVal=o.pos):(b=u,n.xLabelVal=o.pos,n.yLabelVal=l.y),n[b._id.charAt(0)+\"Spike\"]=b.c2p(o.pos,!0),s(l,f,n),n}e.exports={hoverPoints:function(t,e,r,n){var i,a=t.cd[0].trace.hoveron,o=[];return-1!==a.indexOf(\"boxes\")&&(o=o.concat(l(t,e,r,n))),-1!==a.indexOf(\"points\")&&(i=c(t,e,r)),\"closest\"===n?i?[i]:o:i?(o.push(i),o):o},hoverOnBoxes:l,hoverOnPoints:c}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],886:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\").supplyLayoutDefaults,calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"box\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"boxLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":880,\"./calc\":881,\"./cross_trace_calc\":882,\"./defaults\":883,\"./event_data\":884,\"./hover\":885,\"./layout_attributes\":887,\"./layout_defaults\":888,\"./plot\":889,\"./select\":890,\"./style\":891}],887:[function(t,e,r){\"use strict\";e.exports={boxmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"overlay\",editType:\"calc\"},boxgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"},boxgroupgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"}}},{}],888:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./layout_attributes\");function o(t,e,r,i,a){for(var o=a+\"Layout\",s=!1,l=0;l<r.length;l++){var c=r[l];if(n.traceIs(c,o)){s=!0;break}}s&&(i(a+\"mode\"),i(a+\"gap\"),i(a+\"groupgap\"))}e.exports={supplyLayoutDefaults:function(t,e,r){o(0,0,r,function(r,n){return i.coerce(t,e,a,r,n)},\"box\")},_supply:o}},{\"../../lib\":719,\"../../registry\":847,\"./layout_attributes\":887}],889:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=5,s=.01;function l(t,e,r,a){var o,s,l=e.pos,c=e.val,u=a.bPos,h=a.wdPos||0,f=a.bPosPxOffset||0,p=r.whiskerwidth||0,d=r.notched||!1,g=d?1-2*r.notchwidth:1;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var v=t.selectAll(\"path.box\").data(\"violin\"!==r.type||r.box.visible?i.identity:[]);v.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"box\"),v.exit().remove(),v.each(function(t){if(t.empty)return\"M0,0Z\";var e=t.pos,a=l.c2p(e+u,!0)+f,v=l.c2p(e+u-o,!0)+f,m=l.c2p(e+u+s,!0)+f,y=l.c2p(e+u-h,!0)+f,x=l.c2p(e+u+h,!0)+f,b=l.c2p(e+u-o*g,!0)+f,_=l.c2p(e+u+s*g,!0)+f,w=c.c2p(t.q1,!0),k=c.c2p(t.q3,!0),T=i.constrain(c.c2p(t.med,!0),Math.min(w,k)+1,Math.max(w,k)-1),A=void 0===t.lf||!1===r.boxpoints,M=c.c2p(A?t.min:t.lf,!0),S=c.c2p(A?t.max:t.uf,!0),E=c.c2p(t.ln,!0),C=c.c2p(t.un,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+T+\",\"+b+\"V\"+_+\"M\"+w+\",\"+v+\"V\"+m+(d?\"H\"+E+\"L\"+T+\",\"+_+\"L\"+C+\",\"+m:\"\")+\"H\"+k+\"V\"+v+(d?\"H\"+C+\"L\"+T+\",\"+b+\"L\"+E+\",\"+v:\"\")+\"ZM\"+w+\",\"+a+\"H\"+M+\"M\"+k+\",\"+a+\"H\"+S+(0===p?\"\":\"M\"+M+\",\"+y+\"V\"+x+\"M\"+S+\",\"+y+\"V\"+x)):n.select(this).attr(\"d\",\"M\"+b+\",\"+T+\"H\"+_+\"M\"+v+\",\"+w+\"H\"+m+(d?\"V\"+E+\"L\"+_+\",\"+T+\"L\"+m+\",\"+C:\"\")+\"V\"+k+\"H\"+v+(d?\"V\"+C+\"L\"+b+\",\"+T+\"L\"+v+\",\"+E:\"\")+\"ZM\"+a+\",\"+w+\"V\"+M+\"M\"+a+\",\"+k+\"V\"+S+(0===p?\"\":\"M\"+y+\",\"+M+\"H\"+x+\"M\"+y+\",\"+S+\"H\"+x))})}function c(t,e,r,n){var l=e.x,c=e.y,u=n.bdPos,h=n.bPos,f=r.boxpoints||r.points;i.seedPseudoRandom();var p=t.selectAll(\"g.points\").data(f?function(t){return t.forEach(function(t){t.t=n,t.trace=r}),t}:[]);p.enter().append(\"g\").attr(\"class\",\"points\"),p.exit().remove();var d=p.selectAll(\"path\").data(function(t){var e,n,a=t.pts2,l=Math.max((t.max-t.min)/10,t.q3-t.q1),c=1e-9*l,p=l*s,d=[],g=0;if(r.jitter){if(0===l)for(g=1,d=new Array(a.length),e=0;e<a.length;e++)d[e]=1;else for(e=0;e<a.length;e++){var v=Math.max(0,e-o),m=a[v].v,y=Math.min(a.length-1,e+o),x=a[y].v;\"all\"!==f&&(a[e].v<t.lf?x=Math.min(x,t.lf):m=Math.max(m,t.uf));var b=Math.sqrt(p*(y-v)/(x-m+c))||0;b=i.constrain(Math.abs(b),0,1),d.push(b),g=Math.max(b,g)}n=2*r.jitter/(g||1)}for(e=0;e<a.length;e++){var _=a[e],w=_.v,k=r.jitter?n*d[e]*(i.pseudoRandom()-.5):0,T=t.pos+h+u*(r.pointpos+k);\"h\"===r.orientation?(_.y=T,_.x=w):(_.x=T,_.y=w),\"suspectedoutliers\"===f&&w<t.uo&&w>t.lo&&(_.so=!0)}return a});d.enter().append(\"path\").classed(\"point\",!0),d.exit().remove(),d.call(a.translatePoints,l,c)}function u(t,e,r,a){var o,s,l=e.pos,c=e.val,u=a.bPos,h=a.bPosPxOffset||0,f=r.boxmean||(r.meanline||{}).visible;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var p=t.selectAll(\"path.mean\").data(\"box\"===r.type&&r.boxmean||\"violin\"===r.type&&r.box.visible&&r.meanline.visible?i.identity:[]);p.enter().append(\"path\").attr(\"class\",\"mean\").style({fill:\"none\",\"vector-effect\":\"non-scaling-stroke\"}),p.exit().remove(),p.each(function(t){var e=l.c2p(t.pos+u,!0)+h,i=l.c2p(t.pos+u-o,!0)+h,a=l.c2p(t.pos+u+s,!0)+h,p=c.c2p(t.mean,!0),d=c.c2p(t.mean-t.sd,!0),g=c.c2p(t.mean+t.sd,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+p+\",\"+i+\"V\"+a+(\"sd\"===f?\"m0,0L\"+d+\",\"+e+\"L\"+p+\",\"+i+\"L\"+g+\",\"+e+\"Z\":\"\")):n.select(this).attr(\"d\",\"M\"+i+\",\"+p+\"H\"+a+(\"sd\"===f?\"m0,0L\"+e+\",\"+d+\"L\"+i+\",\"+p+\"L\"+e+\",\"+g+\"Z\":\"\"))})}e.exports={plot:function(t,e,r,a){var o=e.xaxis,s=e.yaxis;i.makeTraceGroups(a,r,\"trace boxes\").each(function(t){var e,r,i=n.select(this),a=t[0],h=a.t,f=a.trace;h.wdPos=h.bdPos*f.whiskerwidth,!0!==f.visible||h.empty?i.remove():(\"h\"===f.orientation?(e=s,r=o):(e=o,r=s),l(i,{pos:e,val:r},f,h),c(i,{x:o,y:s},f,h),u(i,{pos:e,val:r},f,h))})},plotBoxAndWhiskers:l,plotPoints:c,plotBoxMean:u}},{\"../../components/drawing\":614,\"../../lib\":719,d3:163}],890:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i=t.cd,a=t.xaxis,o=t.yaxis,s=[];if(!1===e)for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++)i[r].pts[n].selected=0;else for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++){var l=i[r].pts[n],c=a.c2p(l.x),u=o.c2p(l.y);e.contains([c,u],null,l.i,t)?(s.push({pointNumber:l.i,x:a.c2d(l.x),y:o.c2d(l.y)}),l.selected=1):l.selected=0}return s}},{}],891:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\");e.exports={style:function(t,e,r){var o=r||n.select(t).selectAll(\"g.trace.boxes\");o.style(\"opacity\",function(t){return t[0].trace.opacity}),o.each(function(e){var r=n.select(this),o=e[0].trace,s=o.line.width;function l(t,e,r,n){t.style(\"stroke-width\",e+\"px\").call(i.stroke,r).call(i.fill,n)}var c=r.selectAll(\"path.box\");if(\"candlestick\"===o.type)c.each(function(t){if(!t.empty){var e=n.select(this),r=o[t.dir];l(e,r.line.width,r.line.color,r.fillcolor),e.style(\"opacity\",o.selectedpoints&&!t.selected?.3:1)}});else{l(c,s,o.line.color,o.fillcolor),r.selectAll(\"path.mean\").style({\"stroke-width\":s,\"stroke-dasharray\":2*s+\"px,\"+s+\"px\"}).call(i.stroke,o.line.color);var u=r.selectAll(\"path.point\");a.pointStyle(u,o,t)}})},styleOnSelect:function(t,e,r){var n=e[0].trace,i=r.selectAll(\"path.point\");n.selectedpoints?a.selectedPointStyle(i,n):a.pointStyle(i,n,t)}}},{\"../../components/color\":593,\"../../components/drawing\":614,d3:163}],892:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../ohlc/attributes\"),a=t(\"../box/attributes\");function o(t){return{line:{color:n({},a.line.color,{dflt:t}),width:a.line.width,editType:\"style\"},fillcolor:a.fillcolor,editType:\"style\"}}e.exports={x:i.x,open:i.open,high:i.high,low:i.low,close:i.close,line:{width:n({},a.line.width,{}),editType:\"style\"},increasing:o(i.increasing.line.color.dflt),decreasing:o(i.decreasing.line.color.dflt),text:i.text,hovertext:i.hovertext,whiskerwidth:n({},a.whiskerwidth,{dflt:0}),hoverlabel:i.hoverlabel}},{\"../../lib\":719,\"../box/attributes\":880,\"../ohlc/attributes\":1058}],893:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../ohlc/calc\").calcCommon;function o(t,e,r,n){return{min:r,q1:Math.min(t,n),med:n,q3:Math.max(t,n),max:e}}e.exports=function(t,e){var r=t._fullLayout,s=i.getFromId(t,e.xaxis),l=i.getFromId(t,e.yaxis),c=s.makeCalcdata(e,\"x\"),u=a(t,e,c,l,o);return u.length?(n.extendFlat(u[0].t,{num:r._numBoxes,dPos:n.distinctVals(c).minDiff/2,posLetter:\"x\",valLetter:\"y\"}),r._numBoxes++,u):[{t:{empty:!0}}]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../ohlc/calc\":1059}],894:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../ohlc/ohlc_defaults\"),o=t(\"./attributes\");function s(t,e,r,n){var a=r(n+\".line.color\");r(n+\".line.width\",e.line.width),r(n+\".fillcolor\",i.addOpacity(a,.5))}e.exports=function(t,e,r,i){function l(r,i){return n.coerce(t,e,o,r,i)}a(t,e,l,i)?(l(\"line.width\"),s(t,e,l,\"increasing\"),s(t,e,l,\"decreasing\"),l(\"text\"),l(\"hovertext\"),l(\"whiskerwidth\"),i._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../components/color\":593,\"../../lib\":719,\"../ohlc/ohlc_defaults\":1063,\"./attributes\":892}],895:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"candlestick\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\",\"candlestick\",\"boxLayout\"],meta:{},attributes:t(\"./attributes\"),layoutAttributes:t(\"../box/layout_attributes\"),supplyLayoutDefaults:t(\"../box/layout_defaults\").supplyLayoutDefaults,crossTraceCalc:t(\"../box/cross_trace_calc\").crossTraceCalc,supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"../box/plot\").plot,layerName:\"boxlayer\",style:t(\"../box/style\").style,hoverPoints:t(\"../ohlc/hover\").hoverPoints,selectPoints:t(\"../ohlc/select\")}},{\"../../plots/cartesian\":778,\"../box/cross_trace_calc\":882,\"../box/layout_attributes\":887,\"../box/layout_defaults\":888,\"../box/plot\":889,\"../box/style\":891,\"../ohlc/hover\":1061,\"../ohlc/select\":1065,\"./attributes\":892,\"./calc\":893,\"./defaults\":894}],896:[function(t,e,r){\"use strict\";var n=t(\"./axis_defaults\"),i=t(\"../../plot_api/plot_template\");e.exports=function(t,e,r,a,o){a(\"a\")||(a(\"da\"),a(\"a0\")),a(\"b\")||(a(\"db\"),a(\"b0\")),function(t,e,r,a){[\"aaxis\",\"baxis\"].forEach(function(o){var s=o.charAt(0),l=t[o]||{},c=i.newContainer(e,o),u={tickfont:\"x\",id:s+\"axis\",letter:s,font:e.font,name:o,data:t[s],calendar:e.calendar,dfltColor:a,bgColor:r.paper_bgcolor,fullLayout:r};n(l,c,u),c._categories=c._categories||[],t[o]||\"-\"===l.type||(t[o]={type:l.type})})}(t,e,r,o)}},{\"../../plot_api/plot_template\":757,\"./axis_defaults\":901}],897:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t){return function t(e,r){if(!n(e)||r>=10)return null;var i=1/0;var a=-1/0;var o=e.length;for(var s=0;s<o;s++){var l=e[s];if(n(l)){var c=t(l,r+1);c&&(i=Math.min(c[0],i),a=Math.max(c[1],a))}else i=Math.min(l,i),a=Math.max(l,a)}return[i,a]}(t,0)}},{\"../../lib\":719}],898:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./axis_attributes\"),a=t(\"../../components/color/attributes\"),o=n({editType:\"calc\"});o.family.dflt='\"Open Sans\", verdana, arial, sans-serif',o.size.dflt=12,o.color.dflt=a.defaultLine,e.exports={carpet:{valType:\"string\",editType:\"calc\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},a:{valType:\"data_array\",editType:\"calc\"},a0:{valType:\"number\",dflt:0,editType:\"calc\"},da:{valType:\"number\",dflt:1,editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},b0:{valType:\"number\",dflt:0,editType:\"calc\"},db:{valType:\"number\",dflt:1,editType:\"calc\"},cheaterslope:{valType:\"number\",dflt:1,editType:\"calc\"},aaxis:i,baxis:i,font:o,color:{valType:\"color\",dflt:a.defaultLine,editType:\"plot\"},transforms:void 0}},{\"../../components/color/attributes\":592,\"../../plots/font_attributes\":793,\"./axis_attributes\":900}],899:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,i){var a,o,s,l,c,u,h,f,p,d,g,v,m,y=n(r)?\"a\":\"b\",x=(\"a\"===y?t.aaxis:t.baxis).smoothing,b=\"a\"===y?t.a2i:t.b2j,_=\"a\"===y?r:i,w=\"a\"===y?i:r,k=\"a\"===y?e.a.length:e.b.length,T=\"a\"===y?e.b.length:e.a.length,A=Math.floor(\"a\"===y?t.b2j(w):t.a2i(w)),M=\"a\"===y?function(e){return t.evalxy([],e,A)}:function(e){return t.evalxy([],A,e)};x&&(s=Math.max(0,Math.min(T-2,A)),l=A-s,o=\"a\"===y?function(e,r){return t.dxydi([],e,s,r,l)}:function(e,r){return t.dxydj([],s,e,l,r)});var S=b(_[0]),E=b(_[1]),C=S<E?1:-1,L=1e-8*(E-S),P=C>0?Math.floor:Math.ceil,O=C>0?Math.ceil:Math.floor,z=C>0?Math.min:Math.max,I=C>0?Math.max:Math.min,D=P(S+L),R=O(E-L),F=[[h=M(S)]];for(a=D;a*C<R*C;a+=C)c=[],g=I(S,a),m=(v=z(E,a+C))-g,u=Math.max(0,Math.min(k-2,Math.floor(.5*(g+v)))),f=M(v),x&&(p=o(u,g-u),d=o(u,v-u),c.push([h[0]+p[0]/3*m,h[1]+p[1]/3*m]),c.push([f[0]-d[0]/3*m,f[1]-d[1]/3*m])),c.push(f),F.push(c),h=f;return F}},{\"../../lib\":719}],900:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../plots/cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").TIME_FORMAT_LINK;e.exports={color:{valType:\"color\",editType:\"calc\"},smoothing:{valType:\"number\",dflt:1,min:0,max:1.3,editType:\"calc\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"calc\"},font:n({editType:\"calc\"}),offset:{valType:\"number\",dflt:10,editType:\"calc\"},editType:\"calc\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"date\",\"category\"],dflt:\"-\",editType:\"calc\"},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"calc\"},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"calc\"},range:{valType:\"info_array\",editType:\"calc\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}]},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cheatertype:{valType:\"enumerated\",values:[\"index\",\"value\"],dflt:\"value\",editType:\"calc\"},tickmode:{valType:\"enumerated\",values:[\"linear\",\"array\"],dflt:\"array\",editType:\"calc\"},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},tickvals:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},showticklabels:{valType:\"enumerated\",values:[\"start\",\"end\",\"both\",\"none\"],dflt:\"start\",editType:\"calc\"},tickfont:n({editType:\"calc\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"calc\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"calc\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"calc\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"calc\"},tickformatstops:o(a.tickformatstops,\"calc\",\"from-root\"),categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},labelpadding:{valType:\"integer\",dflt:10,editType:\"calc\"},labelprefix:{valType:\"string\",editType:\"calc\"},labelsuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showline:{valType:\"boolean\",dflt:!1,editType:\"calc\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"calc\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},gridcolor:{valType:\"color\",editType:\"calc\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},showgrid:{valType:\"boolean\",dflt:!0,editType:\"calc\"},minorgridcount:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},minorgridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},minorgridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"calc\"},startline:{valType:\"boolean\",editType:\"calc\"},startlinecolor:{valType:\"color\",editType:\"calc\"},startlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endline:{valType:\"boolean\",editType:\"calc\"},endlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endlinecolor:{valType:\"color\",editType:\"calc\"},tick0:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},dtick:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},arraytick0:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},arraydtick:{valType:\"integer\",min:1,dflt:1,editType:\"calc\"},_deprecated:{title:{valType:\"string\",editType:\"calc\"},titlefont:n({editType:\"calc\"}),titleoffset:{valType:\"number\",dflt:10,editType:\"calc\"}},editType:\"calc\"}},{\"../../components/color/attributes\":592,\"../../constants/docs\":690,\"../../plot_api/edit_types\":750,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/font_attributes\":793}],901:[function(t,e,r){\"use strict\";var n=t(\"./attributes\"),i=t(\"../../components/color\").addOpacity,a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/tick_value_defaults\"),l=t(\"../../plots/cartesian/tick_label_defaults\"),c=t(\"../../plots/cartesian/category_order_defaults\"),u=t(\"../../plots/cartesian/set_convert\"),h=t(\"../../plots/cartesian/axis_autotype\");e.exports=function(t,e,r){var f=r.letter,p=r.font||{},d=n[f+\"axis\"];function g(r,n){return o.coerce(t,e,d,r,n)}function v(r,n){return o.coerce2(t,e,d,r,n)}r.name&&(e._name=r.name,e._id=r.name);var m=g(\"type\");(\"-\"===m&&(r.data&&function(t,e){if(\"-\"!==t.type)return;var r=t._id.charAt(0),n=t[r+\"calendar\"];t.type=h(e,n)}(e,r.data),\"-\"===e.type?e.type=\"linear\":m=t.type=e.type),g(\"smoothing\"),g(\"cheatertype\"),g(\"showticklabels\"),g(\"labelprefix\",f+\" = \"),g(\"labelsuffix\"),g(\"showtickprefix\"),g(\"showticksuffix\"),g(\"separatethousands\"),g(\"tickformat\"),g(\"exponentformat\"),g(\"showexponent\"),g(\"categoryorder\"),g(\"tickmode\"),g(\"tickvals\"),g(\"ticktext\"),g(\"tick0\"),g(\"dtick\"),\"array\"===e.tickmode&&(g(\"arraytick0\"),g(\"arraydtick\")),g(\"labelpadding\"),e._hovertitle=f,\"date\"===m)&&a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",r.calendar);u(e,r.fullLayout),e.c2p=o.identity;var y=g(\"color\",r.dfltColor),x=y===t.color?y:p.color;g(\"title.text\")&&(o.coerceFont(g,\"title.font\",{family:p.family,size:Math.round(1.2*p.size),color:x}),g(\"title.offset\")),g(\"tickangle\"),g(\"autorange\",!e.isValidRange(t.range))&&g(\"rangemode\"),g(\"range\"),e.cleanRange(),g(\"fixedrange\"),s(t,e,g,m),l(t,e,g,m,r),c(t,e,g,{data:r.data,dataAttr:f});var b=v(\"gridcolor\",i(y,.3)),_=v(\"gridwidth\"),w=g(\"showgrid\");w||(delete e.gridcolor,delete e.gridwidth);var k=v(\"startlinecolor\",y),T=v(\"startlinewidth\",_);g(\"startline\",e.showgrid||!!k||!!T)||(delete e.startlinecolor,delete e.startlinewidth);var A=v(\"endlinecolor\",y),M=v(\"endlinewidth\",_);return g(\"endline\",e.showgrid||!!A||!!M)||(delete e.endlinecolor,delete e.endlinewidth),w?(g(\"minorgridcount\"),g(\"minorgridwidth\",_),g(\"minorgridcolor\",i(b,.06)),e.minorgridcount||(delete e.minorgridwidth,delete e.minorgridcolor)):(delete e.gridcolor,delete e.gridWidth),\"none\"===e.showticklabels&&(delete e.tickfont,delete e.tickangle,delete e.showexponent,delete e.exponentformat,delete e.tickformat,delete e.showticksuffix,delete e.showtickprefix),e.showticksuffix||delete e.ticksuffix,e.showtickprefix||delete e.tickprefix,g(\"tickmode\"),e}},{\"../../components/color\":593,\"../../lib\":719,\"../../plots/cartesian/axis_autotype\":768,\"../../plots/cartesian/category_order_defaults\":771,\"../../plots/cartesian/set_convert\":785,\"../../plots/cartesian/tick_label_defaults\":786,\"../../plots/cartesian/tick_value_defaults\":788,\"../../registry\":847,\"./attributes\":898}],902:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\").isArray1D,a=t(\"./cheater_basis\"),o=t(\"./array_minmax\"),s=t(\"./calc_gridlines\"),l=t(\"./calc_labels\"),c=t(\"./calc_clippath\"),u=t(\"../heatmap/clean_2d_array\"),h=t(\"./smooth_fill_2d_array\"),f=t(\"../heatmap/convert_column_xyz\"),p=t(\"./set_convert\");e.exports=function(t,e){var r=n.getFromId(t,e.xaxis),d=n.getFromId(t,e.yaxis),g=e.aaxis,v=e.baxis,m=e.x,y=e.y,x=[];m&&i(m)&&x.push(\"x\"),y&&i(y)&&x.push(\"y\"),x.length&&f(e,g,v,\"a\",\"b\",x);var b=e._a=e._a||e.a,_=e._b=e._b||e.b;m=e._x||e.x,y=e._y||e.y;var w={};if(e._cheater){var k=\"index\"===g.cheatertype?b.length:b,T=\"index\"===v.cheatertype?_.length:_;m=a(k,T,e.cheaterslope)}e._x=m=u(m),e._y=y=u(y),h(m,b,_),h(y,b,_),p(e),e.setScale();var A=o(m),M=o(y),S=.5*(A[1]-A[0]),E=.5*(A[1]+A[0]),C=.5*(M[1]-M[0]),L=.5*(M[1]+M[0]);return A=[E-1.3*S,E+1.3*S],M=[L-1.3*C,L+1.3*C],e._extremes[r._id]=n.findExtremes(r,A,{padded:!0}),e._extremes[d._id]=n.findExtremes(d,M,{padded:!0}),s(e,\"a\",\"b\"),s(e,\"b\",\"a\"),l(e,g),l(e,v),w.clipsegments=c(e._xctrl,e._yctrl,g,v),w.x=m,w.y=y,w.a=b,w.b=_,[w]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../heatmap/clean_2d_array\":1003,\"../heatmap/convert_column_xyz\":1005,\"./array_minmax\":897,\"./calc_clippath\":903,\"./calc_gridlines\":904,\"./calc_labels\":905,\"./cheater_basis\":907,\"./set_convert\":920,\"./smooth_fill_2d_array\":921}],903:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a,o,s=[],l=!!r.smoothing,c=!!n.smoothing,u=t[0].length-1,h=t.length-1;for(i=0,a=[],o=[];i<=u;i++)a[i]=t[0][i],o[i]=e[0][i];for(s.push({x:a,y:o,bicubic:l}),i=0,a=[],o=[];i<=h;i++)a[i]=t[i][u],o[i]=e[i][u];for(s.push({x:a,y:o,bicubic:c}),i=u,a=[],o=[];i>=0;i--)a[u-i]=t[h][i],o[u-i]=e[h][i];for(s.push({x:a,y:o,bicubic:l}),i=h,a=[],o=[];i>=0;i--)a[h-i]=t[i][0],o[h-i]=e[i][0];return s.push({x:a,y:o,bicubic:c}),s}},{}],904:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e,r){var a,o,s,l,c,u,h,f,p,d,g,v,m,y,x=t[\"_\"+e],b=t[e+\"axis\"],_=b._gridlines=[],w=b._minorgridlines=[],k=b._boundarylines=[],T=t[\"_\"+r],A=t[r+\"axis\"];\"array\"===b.tickmode&&(b.tickvals=x.slice());var M=t._xctrl,S=t._yctrl,E=M[0].length,C=M.length,L=t._a.length,P=t._b.length;n.prepTicks(b),\"array\"===b.tickmode&&delete b.tickvals;var O=b.smoothing?3:1;function z(n){var i,a,o,s,l,c,u,h,p,d,g,v,m=[],y=[],x={};if(\"b\"===e)for(a=t.b2j(n),o=Math.floor(Math.max(0,Math.min(P-2,a))),s=a-o,x.length=P,x.crossLength=L,x.xy=function(e){return t.evalxy([],e,a)},x.dxy=function(e,r){return t.dxydi([],e,o,r,s)},i=0;i<L;i++)c=Math.min(L-2,i),u=i-c,h=t.evalxy([],i,a),A.smoothing&&i>0&&(p=t.dxydi([],i-1,o,0,s),m.push(l[0]+p[0]/3),y.push(l[1]+p[1]/3),d=t.dxydi([],i-1,o,1,s),m.push(h[0]-d[0]/3),y.push(h[1]-d[1]/3)),m.push(h[0]),y.push(h[1]),l=h;else for(i=t.a2i(n),c=Math.floor(Math.max(0,Math.min(L-2,i))),u=i-c,x.length=L,x.crossLength=P,x.xy=function(e){return t.evalxy([],i,e)},x.dxy=function(e,r){return t.dxydj([],c,e,u,r)},a=0;a<P;a++)o=Math.min(P-2,a),s=a-o,h=t.evalxy([],i,a),A.smoothing&&a>0&&(g=t.dxydj([],c,a-1,u,0),m.push(l[0]+g[0]/3),y.push(l[1]+g[1]/3),v=t.dxydj([],c,a-1,u,1),m.push(h[0]-v[0]/3),y.push(h[1]-v[1]/3)),m.push(h[0]),y.push(h[1]),l=h;return x.axisLetter=e,x.axis=b,x.crossAxis=A,x.value=n,x.constvar=r,x.index=f,x.x=m,x.y=y,x.smoothing=A.smoothing,x}function I(n){var i,a,o,s,l,c=[],u=[],h={};if(h.length=x.length,h.crossLength=T.length,\"b\"===e)for(o=Math.max(0,Math.min(P-2,n)),l=Math.min(1,Math.max(0,n-o)),h.xy=function(e){return t.evalxy([],e,n)},h.dxy=function(e,r){return t.dxydi([],e,o,r,l)},i=0;i<E;i++)c[i]=M[n*O][i],u[i]=S[n*O][i];else for(a=Math.max(0,Math.min(L-2,n)),s=Math.min(1,Math.max(0,n-a)),h.xy=function(e){return t.evalxy([],n,e)},h.dxy=function(e,r){return t.dxydj([],a,e,s,r)},i=0;i<C;i++)c[i]=M[i][n*O],u[i]=S[i][n*O];return h.axisLetter=e,h.axis=b,h.crossAxis=A,h.value=x[n],h.constvar=r,h.index=n,h.x=c,h.y=u,h.smoothing=A.smoothing,h}if(\"array\"===b.tickmode){for(l=5e-15,u=(c=[Math.floor((x.length-1-b.arraytick0)/b.arraydtick*(1+l)),Math.ceil(-b.arraytick0/b.arraydtick/(1+l))].sort(function(t,e){return t-e}))[0]-1,h=c[1]+1,f=u;f<h;f++)(o=b.arraytick0+b.arraydtick*f)<0||o>x.length-1||_.push(i(I(o),{color:b.gridcolor,width:b.gridwidth}));for(f=u;f<h;f++)if(s=b.arraytick0+b.arraydtick*f,g=Math.min(s+b.arraydtick,x.length-1),!(s<0||s>x.length-1||g<0||g>x.length-1))for(v=x[s],m=x[g],a=0;a<b.minorgridcount;a++)(y=g-s)<=0||(d=v+(m-v)*(a+1)/(b.minorgridcount+1)*(b.arraydtick/y))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&k.push(i(I(0),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&k.push(i(I(x.length-1),{color:b.endlinecolor,width:b.endlinewidth}))}else{for(l=5e-15,u=(c=[Math.floor((x[x.length-1]-b.tick0)/b.dtick*(1+l)),Math.ceil((x[0]-b.tick0)/b.dtick/(1+l))].sort(function(t,e){return t-e}))[0],h=c[1],f=u;f<=h;f++)p=b.tick0+b.dtick*f,_.push(i(z(p),{color:b.gridcolor,width:b.gridwidth}));for(f=u-1;f<h+1;f++)for(p=b.tick0+b.dtick*f,a=0;a<b.minorgridcount;a++)(d=p+b.dtick*(a+1)/(b.minorgridcount+1))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&k.push(i(z(x[0]),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&k.push(i(z(x[x.length-1]),{color:b.endlinecolor,width:b.endlinewidth}))}}},{\"../../lib/extend\":710,\"../../plots/cartesian/axes\":767}],905:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e){var r,a,o,s=e._labels=[],l=e._gridlines;for(r=0;r<l.length;r++)o=l[r],-1!==[\"start\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{prefix:void 0,suffix:void 0,endAnchor:!0,xy:o.xy(0),dxy:o.dxy(0,0),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a)),-1!==[\"end\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{endAnchor:!1,xy:o.xy(o.crossLength-1),dxy:o.dxy(o.crossLength-2,1),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a))}},{\"../../lib/extend\":710,\"../../plots/cartesian/axes\":767}],906:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=t[0]-e[0],a=t[1]-e[1],o=r[0]-e[0],s=r[1]-e[1],l=Math.pow(i*i+a*a,.25),c=Math.pow(o*o+s*s,.25),u=(c*c*i-l*l*o)*n,h=(c*c*a-l*l*s)*n,f=c*(l+c)*3,p=l*(l+c)*3;return[[e[0]+(f&&u/f),e[1]+(f&&h/f)],[e[0]-(p&&u/p),e[1]-(p&&h/p)]]}},{}],907:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i,a,o,s,l,c,u=[],h=n(t)?t.length:t,f=n(e)?e.length:e,p=n(t)?t:null,d=n(e)?e:null;p&&(o=(p.length-1)/(p[p.length-1]-p[0])/(h-1)),d&&(s=(d.length-1)/(d[d.length-1]-d[0])/(f-1));var g=1/0,v=-1/0;for(a=0;a<f;a++)for(u[a]=[],l=d?(d[a]-d[0])*s:a/(f-1),i=0;i<h;i++)c=(p?(p[i]-p[0])*o:i/(h-1))-l*r,g=Math.min(c,g),v=Math.max(c,v),u[a][i]=c;var m=1/(v-g),y=-g*m;for(a=0;a<f;a++)for(i=0;i<h;i++)u[a][i]=m*u[a][i]+y;return u}},{\"../../lib\":719}],908:[function(t,e,r){\"use strict\";var n=t(\"./catmull_rom\"),i=t(\"../../lib\").ensureArray;function a(t,e,r){var n=-.5*r[0]+1.5*e[0],i=-.5*r[1]+1.5*e[1];return[(2*n+t[0])/3,(2*i+t[1])/3]}e.exports=function(t,e,r,o,s,l){var c,u,h,f,p,d,g,v,m,y,x=r[0].length,b=r.length,_=s?3*x-2:x,w=l?3*b-2:b;for(t=i(t,w),e=i(e,w),h=0;h<w;h++)t[h]=i(t[h],_),e[h]=i(e[h],_);for(u=0,f=0;u<b;u++,f+=l?3:1)for(p=t[f],d=e[f],g=r[u],v=o[u],c=0,h=0;c<x;c++,h+=s?3:1)p[h]=g[c],d[h]=v[c];if(s)for(u=0,f=0;u<b;u++,f+=l?3:1){for(c=1,h=3;c<x-1;c++,h+=3)m=n([r[u][c-1],o[u][c-1]],[r[u][c],o[u][c]],[r[u][c+1],o[u][c+1]],s),t[f][h-1]=m[0][0],e[f][h-1]=m[0][1],t[f][h+1]=m[1][0],e[f][h+1]=m[1][1];y=a([t[f][0],e[f][0]],[t[f][2],e[f][2]],[t[f][3],e[f][3]]),t[f][1]=y[0],e[f][1]=y[1],y=a([t[f][_-1],e[f][_-1]],[t[f][_-3],e[f][_-3]],[t[f][_-4],e[f][_-4]]),t[f][_-2]=y[0],e[f][_-2]=y[1]}if(l)for(h=0;h<_;h++){for(f=3;f<w-3;f+=3)m=n([t[f-3][h],e[f-3][h]],[t[f][h],e[f][h]],[t[f+3][h],e[f+3][h]],l),t[f-1][h]=m[0][0],e[f-1][h]=m[0][1],t[f+1][h]=m[1][0],e[f+1][h]=m[1][1];y=a([t[0][h],e[0][h]],[t[2][h],e[2][h]],[t[3][h],e[3][h]]),t[1][h]=y[0],e[1][h]=y[1],y=a([t[w-1][h],e[w-1][h]],[t[w-3][h],e[w-3][h]],[t[w-4][h],e[w-4][h]]),t[w-2][h]=y[0],e[w-2][h]=y[1]}if(s&&l)for(f=1;f<w;f+=(f+1)%3==0?2:1){for(h=3;h<_-3;h+=3)m=n([t[f][h-3],e[f][h-3]],[t[f][h],e[f][h]],[t[f][h+3],e[f][h+3]],s),t[f][h-1]=.5*(t[f][h-1]+m[0][0]),e[f][h-1]=.5*(e[f][h-1]+m[0][1]),t[f][h+1]=.5*(t[f][h+1]+m[1][0]),e[f][h+1]=.5*(e[f][h+1]+m[1][1]);y=a([t[f][0],e[f][0]],[t[f][2],e[f][2]],[t[f][3],e[f][3]]),t[f][1]=.5*(t[f][1]+y[0]),e[f][1]=.5*(e[f][1]+y[1]),y=a([t[f][_-1],e[f][_-1]],[t[f][_-3],e[f][_-3]],[t[f][_-4],e[f][_-4]]),t[f][_-2]=.5*(t[f][_-2]+y[0]),e[f][_-2]=.5*(e[f][_-2]+y[1])}return[t,e]}},{\"../../lib\":719,\"./catmull_rom\":906}],909:[function(t,e,r){\"use strict\";e.exports={RELATIVE_CULL_TOLERANCE:1e-6}},{}],910:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3,n*=3;var f=i*i,p=1-i,d=p*p,g=p*i*2,v=-3*d,m=3*(d-g),y=3*(g-f),x=3*f,b=a*a,_=b*a,w=1-a,k=w*w,T=k*w;for(h=0;h<t.length;h++)o=v*(u=t[h])[n][r]+m*u[n][r+1]+y*u[n][r+2]+x*u[n][r+3],s=v*u[n+1][r]+m*u[n+1][r+1]+y*u[n+1][r+2]+x*u[n+1][r+3],l=v*u[n+2][r]+m*u[n+2][r+1]+y*u[n+2][r+2]+x*u[n+2][r+3],c=v*u[n+3][r]+m*u[n+3][r+1]+y*u[n+3][r+2]+x*u[n+3][r+3],e[h]=T*o+3*(k*a*s+w*b*l)+_*c;return e}:e?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),r*=3;var u=i*i,h=1-i,f=h*h,p=h*i*2,d=-3*f,g=3*(f-p),v=3*(p-u),m=3*u,y=1-a;for(l=0;l<t.length;l++)o=d*(c=t[l])[n][r]+g*c[n][r+1]+v*c[n][r+2]+m*c[n][r+3],s=d*c[n+1][r]+g*c[n+1][r+1]+v*c[n+1][r+2]+m*c[n+1][r+3],e[l]=y*o+a*s;return e}:r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),n*=3;var f=a*a,p=f*a,d=1-a,g=d*d,v=g*d;for(u=0;u<t.length;u++)o=(h=t[u])[n][r+1]-h[n][r],s=h[n+1][r+1]-h[n+1][r],l=h[n+2][r+1]-h[n+2][r],c=h[n+3][r+1]-h[n+3][r],e[u]=v*o+3*(g*a*s+d*f*l)+p*c;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-a;for(l=0;l<t.length;l++)o=(c=t[l])[n][r+1]-c[n][r],s=c[n+1][r+1]-c[n+1][r],e[l]=u*o+a*s;return e}}},{}],911:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3,n*=3;var f=i*i,p=f*i,d=1-i,g=d*d,v=g*d,m=a*a,y=1-a,x=y*y,b=y*a*2,_=-3*x,w=3*(x-b),k=3*(b-m),T=3*m;for(h=0;h<t.length;h++)o=_*(u=t[h])[n][r]+w*u[n+1][r]+k*u[n+2][r]+T*u[n+3][r],s=_*u[n][r+1]+w*u[n+1][r+1]+k*u[n+2][r+1]+T*u[n+3][r+1],l=_*u[n][r+2]+w*u[n+1][r+2]+k*u[n+2][r+2]+T*u[n+3][r+2],c=_*u[n][r+3]+w*u[n+1][r+3]+k*u[n+2][r+3]+T*u[n+3][r+3],e[h]=v*o+3*(g*i*s+d*f*l)+p*c;return e}:e?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3;var f=a*a,p=f*a,d=1-a,g=d*d,v=g*d;for(u=0;u<t.length;u++)o=(h=t[u])[n+1][r]-h[n][r],s=h[n+1][r+1]-h[n][r+1],l=h[n+1][r+2]-h[n][r+2],c=h[n+1][r+3]-h[n][r+3],e[u]=v*o+3*(g*a*s+d*f*l)+p*c;return e}:r?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),n*=3;var u=1-i,h=a*a,f=1-a,p=f*f,d=f*a*2,g=-3*p,v=3*(p-d),m=3*(d-h),y=3*h;for(l=0;l<t.length;l++)o=g*(c=t[l])[n][r]+v*c[n+1][r]+m*c[n+2][r]+y*c[n+3][r],s=g*c[n][r+1]+v*c[n+1][r+1]+m*c[n+2][r+1]+y*c[n+3][r+1],e[l]=u*o+i*s;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-i;for(l=0;l<t.length;l++)o=(c=t[l])[n+1][r]-c[n][r],s=c[n+1][r+1]-c[n][r+1],e[l]=u*o+i*s;return e}}},{}],912:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=e-2,o=r-2;return n&&i?function(e,r,n){var i,s,l,c,u,h;e||(e=[]);var f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));f*=3,p*=3;var v=d*d,m=v*d,y=1-d,x=y*y,b=x*y,_=g*g,w=_*g,k=1-g,T=k*k,A=T*k;for(h=0;h<t.length;h++)i=b*(u=t[h])[p][f]+3*(x*d*u[p][f+1]+y*v*u[p][f+2])+m*u[p][f+3],s=b*u[p+1][f]+3*(x*d*u[p+1][f+1]+y*v*u[p+1][f+2])+m*u[p+1][f+3],l=b*u[p+2][f]+3*(x*d*u[p+2][f+1]+y*v*u[p+2][f+2])+m*u[p+2][f+3],c=b*u[p+3][f]+3*(x*d*u[p+3][f+1]+y*v*u[p+3][f+2])+m*u[p+3][f+3],e[h]=A*i+3*(T*g*s+k*_*l)+w*c;return e}:n?function(e,r,n){e||(e=[]);var i,s,l,c,u,h,f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));f*=3;var v=d*d,m=v*d,y=1-d,x=y*y,b=x*y,_=1-g;for(u=0;u<t.length;u++)i=_*(h=t[u])[p][f]+g*h[p+1][f],s=_*h[p][f+1]+g*h[p+1][f+1],l=_*h[p][f+2]+g*h[p+1][f+1],c=_*h[p][f+3]+g*h[p+1][f+1],e[u]=b*i+3*(x*d*s+y*v*l)+m*c;return e}:i?function(e,r,n){e||(e=[]);var i,s,l,c,u,h,f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));p*=3;var v=g*g,m=v*g,y=1-g,x=y*y,b=x*y,_=1-d;for(u=0;u<t.length;u++)i=_*(h=t[u])[p][f]+d*h[p][f+1],s=_*h[p+1][f]+d*h[p+1][f+1],l=_*h[p+2][f]+d*h[p+2][f+1],c=_*h[p+3][f]+d*h[p+3][f+1],e[u]=b*i+3*(x*g*s+y*v*l)+m*c;return e}:function(e,r,n){e||(e=[]);var i,s,l,c,u=Math.max(0,Math.min(Math.floor(r),a)),h=Math.max(0,Math.min(Math.floor(n),o)),f=Math.max(0,Math.min(1,r-u)),p=Math.max(0,Math.min(1,n-h)),d=1-p,g=1-f;for(l=0;l<t.length;l++)i=g*(c=t[l])[h][u]+f*c[h][u+1],s=g*c[h+1][u]+f*c[h+1][u+1],e[l]=d*i+p*s;return e}}},{}],913:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xy_defaults\"),a=t(\"./ab_defaults\"),o=t(\"./attributes\"),s=t(\"../../components/color/attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,o,r,i)}e._clipPathId=\"clip\"+e.uid+\"carpet\";var u=c(\"color\",s.defaultLine);(n.coerceFont(c,\"font\"),c(\"carpet\"),a(t,e,l,c,u),e.a&&e.b)?(e.a.length<3&&(e.aaxis.smoothing=0),e.b.length<3&&(e.baxis.smoothing=0),i(t,e,c)||(e.visible=!1),e._cheater&&c(\"cheaterslope\")):e.visible=!1}},{\"../../components/color/attributes\":592,\"../../lib\":719,\"./ab_defaults\":896,\"./attributes\":898,\"./xy_defaults\":922}],914:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),plot:t(\"./plot\"),calc:t(\"./calc\"),animatable:!0,isContainer:!0,moduleType:\"trace\",name:\"carpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"carpetAxis\",\"notLegendIsolatable\",\"noMultiCategory\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":898,\"./calc\":902,\"./defaults\":913,\"./plot\":919}],915:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r,n=t._fullData.length,i=0;i<n;i++){var a=t._fullData[i];if(a.index!==e.index&&(\"carpet\"===a.type&&(r||(r=a),a.carpet===e.carpet)))return a}return r}},{}],916:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(0===t.length)return\"\";var n,i=[],a=r?3:1;for(n=0;n<t.length;n+=a)i.push(t[n]+\",\"+e[n]),r&&n<t.length-a&&(i.push(\"C\"),i.push([t[n+1]+\",\"+e[n+1],t[n+2]+\",\"+e[n+2]+\" \"].join(\" \")));return i.join(r?\"\":\"L\")}},{}],917:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i;for(n(t)?t.length>e.length&&(t=t.slice(0,e.length)):t=[],i=0;i<e.length;i++)t[i]=r(e[i]);return t}},{\"../../lib\":719}],918:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i[0]*t.dpdx(e),s=i[1]*t.dpdy(r),l=1,c=1;if(a){var u=Math.sqrt(i[0]*i[0]+i[1]*i[1]),h=Math.sqrt(a[0]*a[0]+a[1]*a[1]),f=(i[0]*a[0]+i[1]*a[1])/u/h;c=Math.max(0,f)}var p=180*Math.atan2(s,o)/Math.PI;return p<-90?(p+=180,l=-l):p>90&&(p-=180,l=-l),{angle:p,flip:l,p:t.c2p(n,e,r),offsetMultplier:c}}},{}],919:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"./map_1d_array\"),o=t(\"./makepath\"),s=t(\"./orient_text\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib\"),u=t(\"../../constants/alignment\");function h(t,e,r,i,s,l){var c=\"const-\"+s+\"-lines\",u=r.selectAll(\".\"+c).data(l);u.enter().append(\"path\").classed(c,!0).style(\"vector-effect\",\"non-scaling-stroke\"),u.each(function(r){var i=r,s=i.x,l=i.y,c=a([],s,t.c2p),u=a([],l,e.c2p),h=\"M\"+o(c,u,i.smoothing);n.select(this).attr(\"d\",h).style(\"stroke-width\",i.width).style(\"stroke\",i.color).style(\"fill\",\"none\")}),u.exit().remove()}function f(t,e,r,a,o,c,u,h){var f=c.selectAll(\"text.\"+h).data(u);f.enter().append(\"text\").classed(h,!0);var p=0,d={};return f.each(function(o,c){var u;if(\"auto\"===o.axis.tickangle)u=s(a,e,r,o.xy,o.dxy);else{var h=(o.axis.tickangle+180)*Math.PI/180;u=s(a,e,r,o.xy,[Math.cos(h),Math.sin(h)])}c||(d={angle:u.angle,flip:u.flip});var f=(o.endAnchor?-1:1)*u.flip,g=n.select(this).attr({\"text-anchor\":f>0?\"start\":\"end\",\"data-notex\":1}).call(i.font,o.font).text(o.text).call(l.convertToTspans,t),v=i.bBox(this);g.attr(\"transform\",\"translate(\"+u.p[0]+\",\"+u.p[1]+\") rotate(\"+u.angle+\")translate(\"+o.axis.labelpadding*f+\",\"+.3*v.height+\")\"),p=Math.max(p,v.width+o.axis.labelpadding)}),f.exit().remove(),d.maxExtent=p,d}e.exports=function(t,e,r,i){var l=e.xaxis,u=e.yaxis,p=t._fullLayout._clips;c.makeTraceGroups(i,r,\"trace\").each(function(e){var r=n.select(this),i=e[0],d=i.trace,v=d.aaxis,m=d.baxis,y=c.ensureSingle(r,\"g\",\"minorlayer\"),x=c.ensureSingle(r,\"g\",\"majorlayer\"),b=c.ensureSingle(r,\"g\",\"boundarylayer\"),_=c.ensureSingle(r,\"g\",\"labellayer\");r.style(\"opacity\",d.opacity),h(l,u,x,v,\"a\",v._gridlines),h(l,u,x,m,\"b\",m._gridlines),h(l,u,y,v,\"a\",v._minorgridlines),h(l,u,y,m,\"b\",m._minorgridlines),h(l,u,b,v,\"a-boundary\",v._boundarylines),h(l,u,b,m,\"b-boundary\",m._boundarylines);var w=f(t,l,u,d,i,_,v._labels,\"a-label\"),k=f(t,l,u,d,i,_,m._labels,\"b-label\");!function(t,e,r,n,i,a,o,l){var u,h,f,p,d=c.aggNums(Math.min,null,r.a),v=c.aggNums(Math.max,null,r.a),m=c.aggNums(Math.min,null,r.b),y=c.aggNums(Math.max,null,r.b);u=.5*(d+v),h=m,f=r.ab2xy(u,h,!0),p=r.dxyda_rough(u,h),void 0===o.angle&&c.extendFlat(o,s(r,i,a,f,r.dxydb_rough(u,h)));g(t,e,r,n,f,p,r.aaxis,i,a,o,\"a-title\"),u=d,h=.5*(m+y),f=r.ab2xy(u,h,!0),p=r.dxydb_rough(u,h),void 0===l.angle&&c.extendFlat(l,s(r,i,a,f,r.dxyda_rough(u,h)));g(t,e,r,n,f,p,r.baxis,i,a,l,\"b-title\")}(t,_,d,i,l,u,w,k),function(t,e,r,n,i){var s,l,u,h,f=r.select(\"#\"+t._clipPathId);f.size()||(f=r.append(\"clipPath\").classed(\"carpetclip\",!0));var p=c.ensureSingle(f,\"path\",\"carpetboundary\"),d=e.clipsegments,g=[];for(h=0;h<d.length;h++)s=d[h],l=a([],s.x,n.c2p),u=a([],s.y,i.c2p),g.push(o(l,u,s.bicubic));var v=\"M\"+g.join(\"L\")+\"Z\";f.attr(\"id\",t._clipPathId),p.attr(\"d\",v)}(d,i,p,l,u)})};var p=u.LINE_SPACING,d=(1-u.MID_SHIFT)/p+1;function g(t,e,r,a,o,c,u,h,f,g,v){var m=[];u.title.text&&m.push(u.title.text);var y=e.selectAll(\"text.\"+v).data(m),x=g.maxExtent;y.enter().append(\"text\").classed(v,!0),y.each(function(){var e=s(r,h,f,o,c);-1===[\"start\",\"both\"].indexOf(u.showticklabels)&&(x=0);var a=u.title.font.size;x+=a+u.title.offset;var v=(g.angle+(g.flip<0?180:0)-e.angle+450)%360,m=v>90&&v<270,y=n.select(this);y.text(u.title.text).call(l.convertToTspans,t),m&&(x=(-l.lineCount(y)+d)*p*a-x),y.attr(\"transform\",\"translate(\"+e.p[0]+\",\"+e.p[1]+\") rotate(\"+e.angle+\") translate(0,\"+x+\")\").classed(\"user-select-none\",!0).attr(\"text-anchor\",\"middle\").call(i.font,u.title.font)}),y.exit().remove()}},{\"../../components/drawing\":614,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"./makepath\":916,\"./map_1d_array\":917,\"./orient_text\":918,d3:163}],920:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/search\").findBin,a=t(\"./compute_control_points\"),o=t(\"./create_spline_evaluator\"),s=t(\"./create_i_derivative_evaluator\"),l=t(\"./create_j_derivative_evaluator\");e.exports=function(t){var e=t._a,r=t._b,c=e.length,u=r.length,h=t.aaxis,f=t.baxis,p=e[0],d=e[c-1],g=r[0],v=r[u-1],m=e[e.length-1]-e[0],y=r[r.length-1]-r[0],x=m*n.RELATIVE_CULL_TOLERANCE,b=y*n.RELATIVE_CULL_TOLERANCE;p-=x,d+=x,g-=b,v+=b,t.isVisible=function(t,e){return t>p&&t<d&&e>g&&e<v},t.isOccluded=function(t,e){return t<p||t>d||e<g||e>v},t.setScale=function(){var e=t._x,r=t._y,n=a(t._xctrl,t._yctrl,e,r,h.smoothing,f.smoothing);t._xctrl=n[0],t._yctrl=n[1],t.evalxy=o([t._xctrl,t._yctrl],c,u,h.smoothing,f.smoothing),t.dxydi=s([t._xctrl,t._yctrl],h.smoothing,f.smoothing),t.dxydj=l([t._xctrl,t._yctrl],h.smoothing,f.smoothing)},t.i2a=function(t){var r=Math.max(0,Math.floor(t[0]),c-2),n=t[0]-r;return(1-n)*e[r]+n*e[r+1]},t.j2b=function(t){var e=Math.max(0,Math.floor(t[1]),c-2),n=t[1]-e;return(1-n)*r[e]+n*r[e+1]},t.ij2ab=function(e){return[t.i2a(e[0]),t.j2b(e[1])]},t.a2i=function(t){var r=Math.max(0,Math.min(i(t,e),c-2)),n=e[r],a=e[r+1];return Math.max(0,Math.min(c-1,r+(t-n)/(a-n)))},t.b2j=function(t){var e=Math.max(0,Math.min(i(t,r),u-2)),n=r[e],a=r[e+1];return Math.max(0,Math.min(u-1,e+(t-n)/(a-n)))},t.ab2ij=function(e){return[t.a2i(e[0]),t.b2j(e[1])]},t.i2c=function(e,r){return t.evalxy([],e,r)},t.ab2xy=function(n,i,a){if(!a&&(n<e[0]||n>e[c-1]|i<r[0]||i>r[u-1]))return[!1,!1];var o=t.a2i(n),s=t.b2j(i),l=t.evalxy([],o,s);if(a){var h,f,p,d,g=0,v=0,m=[];n<e[0]?(h=0,f=0,g=(n-e[0])/(e[1]-e[0])):n>e[c-1]?(h=c-2,f=1,g=(n-e[c-1])/(e[c-1]-e[c-2])):f=o-(h=Math.max(0,Math.min(c-2,Math.floor(o)))),i<r[0]?(p=0,d=0,v=(i-r[0])/(r[1]-r[0])):i>r[u-1]?(p=u-2,d=1,v=(i-r[u-1])/(r[u-1]-r[u-2])):d=s-(p=Math.max(0,Math.min(u-2,Math.floor(s)))),g&&(t.dxydi(m,h,p,f,d),l[0]+=m[0]*g,l[1]+=m[1]*g),v&&(t.dxydj(m,h,p,f,d),l[0]+=m[0]*v,l[1]+=m[1]*v)}return l},t.c2p=function(t,e,r){return[e.c2p(t[0]),r.c2p(t[1])]},t.p2x=function(t,e,r){return[e.p2c(t[0]),r.p2c(t[1])]},t.dadi=function(t){var r=Math.max(0,Math.min(e.length-2,t));return e[r+1]-e[r]},t.dbdj=function(t){var e=Math.max(0,Math.min(r.length-2,t));return r[e+1]-r[e]},t.dxyda=function(e,r,n,i){var a=t.dxydi(null,e,r,n,i),o=t.dadi(e,n);return[a[0]/o,a[1]/o]},t.dxydb=function(e,r,n,i){var a=t.dxydj(null,e,r,n,i),o=t.dbdj(r,i);return[a[0]/o,a[1]/o]},t.dxyda_rough=function(e,r,n){var i=m*(n||.1),a=t.ab2xy(e+i,r,!0),o=t.ab2xy(e-i,r,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dxydb_rough=function(e,r,n){var i=y*(n||.1),a=t.ab2xy(e,r+i,!0),o=t.ab2xy(e,r-i,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dpdx=function(t){return t._m},t.dpdy=function(t){return t._m}}},{\"../../lib/search\":738,\"./compute_control_points\":908,\"./constants\":909,\"./create_i_derivative_evaluator\":910,\"./create_j_derivative_evaluator\":911,\"./create_spline_evaluator\":912}],921:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r){var i,a,o,s=[],l=[],c=t[0].length,u=t.length;function h(e,r){var n,i=0,a=0;return e>0&&void 0!==(n=t[r][e-1])&&(a++,i+=n),e<c-1&&void 0!==(n=t[r][e+1])&&(a++,i+=n),r>0&&void 0!==(n=t[r-1][e])&&(a++,i+=n),r<u-1&&void 0!==(n=t[r+1][e])&&(a++,i+=n),i/Math.max(1,a)}var f,p,d,g,v,m,y,x,b,_,w,k=0;for(i=0;i<c;i++)for(a=0;a<u;a++)void 0===t[a][i]&&(s.push(i),l.push(a),t[a][i]=h(i,a)),k=Math.max(k,Math.abs(t[a][i]));if(!s.length)return t;var T=0,A=0,M=s.length;do{for(T=0,o=0;o<M;o++){i=s[o],a=l[o];var S,E,C,L,P,O,z=0,I=0;0===i?(C=e[P=Math.min(c-1,2)],L=e[1],S=t[a][P],I+=(E=t[a][1])+(E-S)*(e[0]-L)/(L-C),z++):i===c-1&&(C=e[P=Math.max(0,c-3)],L=e[c-2],S=t[a][P],I+=(E=t[a][c-2])+(E-S)*(e[c-1]-L)/(L-C),z++),(0===i||i===c-1)&&a>0&&a<u-1&&(f=r[a+1]-r[a],I+=((p=r[a]-r[a-1])*t[a+1][i]+f*t[a-1][i])/(p+f),z++),0===a?(C=r[O=Math.min(u-1,2)],L=r[1],S=t[O][i],I+=(E=t[1][i])+(E-S)*(r[0]-L)/(L-C),z++):a===u-1&&(C=r[O=Math.max(0,u-3)],L=r[u-2],S=t[O][i],I+=(E=t[u-2][i])+(E-S)*(r[u-1]-L)/(L-C),z++),(0===a||a===u-1)&&i>0&&i<c-1&&(f=e[i+1]-e[i],I+=((p=e[i]-e[i-1])*t[a][i+1]+f*t[a][i-1])/(p+f),z++),z?I/=z:(d=e[i+1]-e[i],g=e[i]-e[i-1],x=(v=r[a+1]-r[a])*(m=r[a]-r[a-1])*(v+m),I=((y=d*g*(d+g))*(m*t[a+1][i]+v*t[a-1][i])+x*(g*t[a][i+1]+d*t[a][i-1]))/(x*(g+d)+y*(m+v))),T+=(_=(b=I-t[a][i])/k)*_,w=z?0:.85,t[a][i]+=b*(1+w)}T=Math.sqrt(T)}while(A++<100&&T>1e-5);return n.log(\"Smoother converged to\",T,\"after\",A,\"iterations\"),t}},{\"../../lib\":719}],922:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArray1D;e.exports=function(t,e,r){var i=r(\"x\"),a=i&&i.length,o=r(\"y\"),s=o&&o.length;if(!a&&!s)return!1;if(e._cheater=!i,a&&!n(i)||s&&!n(o))e._length=null;else{var l=a?i.length:1/0;s&&(l=Math.min(l,o.length)),e.a&&e.a.length&&(l=Math.min(l,e.a.length)),e.b&&e.b.length&&(l=Math.min(l,e.b.length)),e._length=l}return!0}},{\"../../lib\":719}],923:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scattergeo/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/color/attributes\").defaultLine,l=t(\"../../lib/extend\").extendFlat,c=i.marker.line;e.exports=l({locations:{valType:\"data_array\",editType:\"calc\"},locationmode:i.locationmode,z:{valType:\"data_array\",editType:\"calc\"},text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),marker:{line:{color:l({},c.color,{dflt:s}),width:l({},c.width,{dflt:1}),editType:\"calc\"},opacity:{valType:\"number\",arrayOk:!0,min:0,max:1,dflt:1,editType:\"style\"},editType:\"calc\"},selected:{marker:{opacity:i.selected.marker.opacity,editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:i.unselected.marker.opacity,editType:\"plot\"},editType:\"plot\"},hoverinfo:l({},o.hoverinfo,{editType:\"calc\",flags:[\"location\",\"z\",\"text\",\"name\"]}),hovertemplate:n()},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/color/attributes\":592,\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scattergeo/attributes\":1151}],924:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../components/colorscale/calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\");function l(t){return t&&\"string\"==typeof t}e.exports=function(t,e){var r,c=e._length,u=new Array(c);r=e.geojson?function(t){return l(t)||n(t)}:l;for(var h=0;h<c;h++){var f=u[h]={},p=e.locations[h],d=e.z[h];r(p)&&n(d)?(f.loc=p,f.z=d):(f.loc=null,f.z=i),f.index=h}return o(u,e),a(t,e,{vals:e.z,containerStr:\"\",cLetter:\"z\"}),s(u,e),u}},{\"../../components/colorscale/calc\":601,\"../../constants/numerical\":695,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc_selection\":1114,\"fast-isnumeric\":225}],925:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\");l&&l.length&&n.isArrayOrTypedArray(c)&&c.length?(e._length=Math.min(l.length,c.length),s(\"locationmode\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":923}],926:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){t.location=e.location,t.z=e.z;var a=n[i];return a.fIn&&(t.properties=a.fIn.properties),t}},{}],927:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"./attributes\"),a=t(\"../../lib\").fillText;e.exports=function(t,e,r){var o,s,l,c,u=t.cd,h=u[0].trace,f=t.subplot;for(s=0;s<u.length;s++)if(c=!1,(o=u[s])._polygons){for(l=0;l<o._polygons.length;l++)o._polygons[l].contains([e,r])&&(c=!c),o._polygons[l].contains([e+360,r])&&(c=!c);if(c)break}if(c&&o)return t.x0=t.x1=t.xa.c2p(o.ct),t.y0=t.y1=t.ya.c2p(o.ct),t.index=o.index,t.location=o.loc,t.z=o.z,t.zLabel=n.tickText(f.mockAxis,f.mockAxis.c2l(o.z),\"hover\").text,t.hovertemplate=o.hovertemplate,function(t,e,r){if(e.hovertemplate)return;var n=r.hi||e.hoverinfo,o=\"all\"===n?i.hoverinfo.flags:n.split(\"+\"),s=-1!==o.indexOf(\"name\"),l=-1!==o.indexOf(\"location\"),c=-1!==o.indexOf(\"z\"),u=-1!==o.indexOf(\"text\"),h=[];!s&&l?t.nameOverride=r.loc:(s&&(t.nameOverride=e.name),l&&h.push(r.loc));c&&h.push(t.zLabel);u&&a(r,e,h);t.extraText=h.join(\"<br>\")}(t,h,o,f.mockAxis),[t]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./attributes\":923}],928:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"choropleth\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"noOpacity\"],meta:{}}},{\"../../plots/geo\":797,\"../heatmap/colorbar\":1004,\"./attributes\":923,\"./calc\":924,\"./defaults\":925,\"./event_data\":926,\"./hover\":927,\"./plot\":929,\"./select\":930,\"./style\":931}],929:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../lib/polygon\"),o=t(\"../../lib/topojson_utils\").getTopojsonFeatures,s=t(\"../../lib/geo_location_utils\").locationToFeature,l=t(\"./style\").style;function c(t,e){for(var r=t[0].trace,n=t.length,i=o(r,e),a=0;a<n;a++){var l=t[a],c=s(r.locationmode,l.loc,i);c?(l.geojson=c,l.ct=c.properties.ct,l._polygons=u(c)):l.geojson=null}}function u(t){var e,r,n,i,o=t.geometry,s=o.coordinates,l=t.id,c=[];function u(t){for(var e=0;e<t.length-1;e++)if(t[e][0]>0&&t[e+1][0]<0)return e;return null}switch(e=\"RUS\"===l||\"FJI\"===l?function(t){var e;if(null===u(t))e=t;else for(e=new Array(t.length),i=0;i<t.length;i++)e[i]=[t[i][0]<0?t[i][0]+360:t[i][0],t[i][1]];c.push(a.tester(e))}:\"ATA\"===l?function(t){var e=u(t);if(null===e)return c.push(a.tester(t));var r=new Array(t.length+1),n=0;for(i=0;i<t.length;i++)i>e?r[n++]=[t[i][0]+360,t[i][1]]:i===e?(r[n++]=t[i],r[n++]=[t[i][0],-90]):r[n++]=t[i];var o=a.tester(r);o.pts.pop(),c.push(o)}:function(t){c.push(a.tester(t))},o.type){case\"MultiPolygon\":for(r=0;r<s.length;r++)for(n=0;n<s[r].length;n++)e(s[r][n]);break;case\"Polygon\":for(r=0;r<s.length;r++)e(s[r])}return c}e.exports={plot:function(t,e,r){for(var a=0;a<r.length;a++)c(r[a],e.topojson);var o=e.layers.backplot.select(\".choroplethlayer\");i.makeTraceGroups(o,r,\"trace choropleth\").each(function(e){var r=n.select(this).selectAll(\"path.choroplethlocation\").data(i.identity);r.enter().append(\"path\").classed(\"choroplethlocation\",!0),r.exit().remove(),l(t,e)})},feature2polygons:u}},{\"../../lib\":719,\"../../lib/geo_location_utils\":713,\"../../lib/polygon\":731,\"../../lib/topojson_utils\":746,\"./style\":931,d3:163}],930:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)(i=(n=s[r]).ct)&&(a=l.c2p(i),o=c.c2p(i),e.contains([a,o],null,r,t)?(u.push({pointNumber:r,lon:i[0],lat:i[1]}),n.selected=1):n.selected=0);return u}},{}],931:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../components/colorscale\");function s(t,e){var r=e[0].trace,s=e[0].node3.selectAll(\".choroplethlocation\"),l=r.marker||{},c=l.line||{},u=o.makeColorScaleFuncFromTrace(r);s.each(function(t){n.select(this).attr(\"fill\",u(t.z)).call(i.stroke,t.mlc||c.color).call(a.dashLine,\"\",t.mlw||c.width||0).style(\"opacity\",l.opacity)}),a.selectedPointStyle(s,r,t)}e.exports={style:function(t,e){e&&s(t,e)},styleOnSelect:function(t,e){var r=e[0].node3,n=e[0].trace;n.selectedpoints?a.selectedPointStyle(r.selectAll(\".choroplethlocation\"),n,t):s(t,e)}}},{\"../../components/color\":593,\"../../components/colorscale\":605,\"../../components/drawing\":614,d3:163}],932:[function(t,e,r){\"use strict\";var n=t(\"../choropleth/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../lib/extend\").extendFlat;e.exports=o({locations:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},geojson:{valType:\"any\",editType:\"calc\"},below:{valType:\"string\",editType:\"plot\"},text:n.text,hovertext:n.hovertext,marker:{line:{color:o({},n.marker.line.color,{editType:\"plot\"}),width:o({},n.marker.line.width,{editType:\"plot\"}),editType:\"calc\"},opacity:o({},n.marker.opacity,{editType:\"plot\"}),editType:\"calc\"},selected:{marker:{opacity:o({},n.selected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:o({},n.unselected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},hoverinfo:n.hoverinfo,hovertemplate:a({},{keys:[\"properties\"]})},i(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../choropleth/attributes\":923}],933:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"@turf/area\"),a=t(\"@turf/centroid\"),o=t(\"../../lib\"),s=t(\"../../components/colorscale\"),l=t(\"../../components/drawing\"),c=t(\"../../lib/geojson_utils\").makeBlank,u=t(\"../choropleth/plot\").feature2polygons;function h(t){var e,r=t[0].trace,n=r._opts;if(r.selectedpoints){for(var i=l.makeSelectedPointStyleFns(r),a=0;a<t.length;a++){var s=t[a];s.fOut&&(s.fOut.properties.mo2=i.selectedOpacityFn(s))}e={type:\"identity\",property:\"mo2\"}}else e=o.isArrayOrTypedArray(r.marker.opacity)?{type:\"identity\",property:\"mo\"}:r.marker.opacity;return o.extendFlat(n.fill.paint,{\"fill-opacity\":e}),o.extendFlat(n.line.paint,{\"line-opacity\":e}),n}e.exports={convert:function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,l={layout:{visibility:\"none\"},paint:{}},f={layout:{visibility:\"none\"},paint:{}},p=e._opts={fill:l,line:f,geojson:c()};if(!r)return p;var d=\"string\"==typeof e.geojson?(window.PlotlyGeoAssets||{})[e.geojson]:e.geojson;if(!o.isPlainObject(d))return o.error(\"Oops ... something when wrong when fetching \"+e.geojson),p;var g,v={},m=[];for(g=0;g<t.length;g++){var y=t[g];y.loc&&(v[y.loc]=y)}var x,b,_,w=s.makeColorScaleFuncFromTrace(e),k=e.marker,T=k.line||{};function A(t){var e=v[t.id];if(e){var r=t.geometry;if(\"Polygon\"===r.type||\"MultiPolygon\"===r.type){var n={fc:w(e.z)};x&&(n.mo=x(e)),b&&(n.mlc=b(e)),_&&(n.mlw=_(e));var s={type:\"Feature\",geometry:r,properties:n};e._polygons=u(s),e.ct=function(t){var e,r=t.geometry;if(\"MultiPolygon\"===r.type)for(var n=r.coordinates,o=0,s=0;s<n.length;s++){var l={type:\"Polygon\",coordinates:n[s]},c=i.default(l);c>o&&(o=c,e=l)}else e=r;return a.default(e).geometry.coordinates}(s),e.fIn=t,e.fOut=s,m.push(s)}else o.log([\"Location with id\",e.loc,\"does not have a valid GeoJSON geometry,\",\"choroplethmapbox traces only support *Polygon* and *MultiPolygon* geometries.\"].join(\" \"))}delete v[t.id]}switch(o.isArrayOrTypedArray(k.opacity)&&(x=function(t){var e=t.mo;return n(e)?+o.constrain(e,0,1):0}),o.isArrayOrTypedArray(T.color)&&(b=function(t){return t.mlc}),o.isArrayOrTypedArray(T.width)&&(_=function(t){return t.mlw}),d.type){case\"FeatureCollection\":var M=d.features;for(g=0;g<M.length;g++)A(M[g]);break;case\"Feature\":A(d);break;default:return o.warn([\"Invalid GeoJSON type\",(d.type||\"none\")+\",\",\"choroplethmapbox traces only support *FeatureCollection* and *Feature* types.\"].join(\" \")),p}for(var S in v)o.log(\"Location with id \"+S+\" does not have a matching feature\");var E=x?{type:\"identity\",property:\"mo\"}:k.opacity;return o.extendFlat(l.paint,{\"fill-color\":{type:\"identity\",property:\"fc\"},\"fill-opacity\":E}),o.extendFlat(f.paint,{\"line-color\":b?{type:\"identity\",property:\"mlc\"}:T.color,\"line-width\":_?{type:\"identity\",property:\"mlw\"}:T.width,\"line-opacity\":E}),l.layout.visibility=\"visible\",f.layout.visibility=\"visible\",p.geojson={type:\"FeatureCollection\",features:m},h(t),p},convertOnSelect:h}},{\"../../components/colorscale\":605,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/geojson_utils\":714,\"../choropleth/plot\":929,\"@turf/area\":55,\"@turf/centroid\":56,\"fast-isnumeric\":225}],934:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\"),u=s(\"geojson\");n.isArrayOrTypedArray(l)&&l.length&&n.isArrayOrTypedArray(c)&&c.length&&(\"string\"==typeof u&&\"\"!==u||n.isPlainObject(u))?(e._length=Math.min(l.length,c.length),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":932}],935:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../choropleth/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"../choropleth/hover\"),eventData:t(\"../choropleth/event_data\"),selectPoints:t(\"../choropleth/select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.updateOnSelect(e)},getBelow:function(t,e){for(var r=e.getMapLayers(),n=r.length-2;n>=0;n--){var i=r[n].id;if(\"string\"==typeof i&&0===i.indexOf(\"water\"))for(var a=n+1;a<r.length;a++)if(\"string\"==typeof(i=r[a].id)&&-1===i.indexOf(\"plotly-\"))return i}},moduleType:\"trace\",name:\"choroplethmapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"noOpacity\"],meta:{hr_name:\"choropleth_mapbox\"}}},{\"../../plots/mapbox\":822,\"../choropleth/calc\":924,\"../choropleth/event_data\":926,\"../choropleth/hover\":927,\"../choropleth/select\":930,\"../heatmap/colorbar\":1004,\"./attributes\":932,\"./defaults\":934,\"./plot\":936}],936:[function(t,e,r){\"use strict\";var n=t(\"./convert\").convert,i=t(\"./convert\").convertOnSelect,a=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function o(t,e){this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"fill\",a+e+\"-fill\"],[\"line\",a+e+\"-line\"]],this.below=null}var s=o.prototype;s.update=function(t){this._update(n(t))},s.updateOnSelect=function(t){this._update(i(t))},s._update=function(t){var e=this.subplot,r=this.layerList,n=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(t.geojson),n!==this.below&&(this._removeLayers(),this._addLayers(t,n),this.below=n);for(var i=0;i<r.length;i++){var a=r[i],o=a[0],s=a[1],l=t[o];e.setOptions(s,\"setLayoutProperty\",l.layout),\"visible\"===l.layout.visibility&&e.setOptions(s,\"setPaintProperty\",l.paint)}},s._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},s._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},s.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new o(t,r.uid),a=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(a,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":820,\"./convert\":933}],937:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"scaled\",\"absolute\"],editType:\"calc\",dflt:\"scaled\"},sizeref:{valType:\"number\",editType:\"calc\",min:0},anchor:{valType:\"enumerated\",editType:\"calc\",values:[\"tip\",\"tail\",\"cm\",\"center\"],dflt:\"cm\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:i({editType:\"calc\"},{keys:[\"norm\"]})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach(function(t){l[t]=a[t]}),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../mesh3d/attributes\":1053}],938:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){for(var r=e.u,i=e.v,a=e.w,o=Math.min(e.x.length,e.y.length,e.z.length,r.length,i.length,a.length),s=-1/0,l=1/0,c=0;c<o;c++){var u=r[c],h=i[c],f=a[c],p=Math.sqrt(u*u+h*h+f*f);s=Math.max(s,p),l=Math.min(l,p)}e._len=o,e._normMax=s,n(t,e,{vals:[l,s],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],939:[function(t,e,r){\"use strict\";var n=t(\"gl-cone3d\"),i=t(\"gl-cone3d\").createConeMesh,a=t(\"../../lib\").simpleMap,o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\");function c(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var u=c.prototype;u.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index,r=this.data.x[e],n=this.data.y[e],i=this.data.z[e],a=this.data.u[e],o=this.data.v[e],s=this.data.w[e];t.traceCoordinate=[r,n,i,a,o,s,Math.sqrt(a*a+o*o+s*s)];var l=this.data.hovertext||this.data.text;return Array.isArray(l)&&void 0!==l[e]?t.textLabel=l[e]:l&&(t.textLabel=l),!0}};var h={xaxis:0,yaxis:1,zaxis:2},f={tip:1,tail:0,cm:.25,center:.5},p={tip:1,tail:1,cm:.75,center:.5};function d(t,e){var r=t.fullSceneLayout,i=t.dataScale,c={};function u(t,e){var n=r[e],o=i[h[e]];return a(t,function(t){return n.d2l(t)*o})}c.vectors=l(u(e.u,\"xaxis\"),u(e.v,\"yaxis\"),u(e.w,\"zaxis\"),e._len),c.positions=l(u(e.x,\"xaxis\"),u(e.y,\"yaxis\"),u(e.z,\"zaxis\"),e._len);var d=s(e);c.colormap=o(e),c.vertexIntensityBounds=[d.min/e._normMax,d.max/e._normMax],c.coneOffset=f[e.anchor],\"scaled\"===e.sizemode?c.coneSize=e.sizeref||.5:c.coneSize=e.sizeref&&e._normMax?e.sizeref/e._normMax:.5;var g=n(c),v=e.lightposition;return g.lightPosition=[v.x,v.y,v.z],g.ambient=e.lighting.ambient,g.diffuse=e.lighting.diffuse,g.specular=e.lighting.specular,g.roughness=e.lighting.roughness,g.fresnel=e.lighting.fresnel,g.opacity=e.opacity,e._pad=p[e.anchor]*g.vectorScale*g.coneScale*e._normMax,g}u.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),a=i(r,n),o=new c(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../plots/gl3d/zip3\":818,\"gl-cone3d\":242}],940:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),h=s(\"x\"),f=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length&&p&&p.length?(s(\"sizeref\"),s(\"sizemode\"),s(\"anchor\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":937}],941:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"cone\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),eventData:function(t,e){return t.norm=e.traceCoordinate[6],t},meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":937,\"./calc\":938,\"./convert\":939,\"./defaults\":940}],942:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../components/drawing/attributes\").dash,s=t(\"../../plots/font_attributes\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../constants/filter_ops\"),u=c.COMPARISON_OPS2,h=c.INTERVAL_OPS,f=(t(\"../../constants/docs\").FORMAT_LINK,i.line);e.exports=l({z:n.z,x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,xtype:n.xtype,ytype:n.ytype,zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate,connectgaps:n.connectgaps,fillcolor:{valType:\"color\",editType:\"calc\"},autocontour:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"contours.start\":void 0,\"contours.end\":void 0,\"contours.size\":void 0}},ncontours:{valType:\"integer\",dflt:15,min:1,editType:\"calc\"},contours:{type:{valType:\"enumerated\",values:[\"levels\",\"constraint\"],dflt:\"levels\",editType:\"calc\"},start:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},end:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},coloring:{valType:\"enumerated\",values:[\"fill\",\"heatmap\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:{valType:\"boolean\",dflt:!0,editType:\"plot\"},showlabels:{valType:\"boolean\",dflt:!1,editType:\"plot\"},labelfont:s({editType:\"plot\",colorEditType:\"style\"}),labelformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},operation:{valType:\"enumerated\",values:[].concat(u).concat(h),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:l({},f.color,{editType:\"style+colorbars\"}),width:l({},f.width,{editType:\"style+colorbars\"}),dash:o,smoothing:l({},f.smoothing,{}),editType:\"plot\"}},a(\"\",{cLetter:\"z\",autoColorDflt:!1,editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../components/drawing/attributes\":613,\"../../constants/docs\":690,\"../../constants/filter_ops\":691,\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"../heatmap/attributes\":1001,\"../scatter/attributes\":1112}],943:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\"),i=t(\"../heatmap/calc\"),a=t(\"./set_contours\"),o=t(\"./end_plus\");e.exports=function(t,e){var r=i(t,e),s=r[0].z;a(e,s);var l,c=e.contours,u=n.extractOpts(e);if(\"heatmap\"===c.coloring&&u.auto&&!1===e.autocontour){var h=c.start,f=o(c),p=c.size||1,d=Math.floor((f-h)/p)+1;isFinite(p)||(p=1,d=1);var g=h-p/2;l=[g,g+d*p]}else l=s;return n.calc(t,e,{vals:l,cLetter:\"z\"}),r}},{\"../../components/colorscale\":605,\"../heatmap/calc\":1002,\"./end_plus\":953,\"./set_contours\":961}],944:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a,o,s=t[0],l=s.x.length,c=s.y.length,u=s.z,h=n.contours,f=-1/0,p=1/0;for(i=0;i<c;i++)p=Math.min(p,u[i][0]),p=Math.min(p,u[i][l-1]),f=Math.max(f,u[i][0]),f=Math.max(f,u[i][l-1]);for(i=1;i<l-1;i++)p=Math.min(p,u[0][i]),p=Math.min(p,u[c-1][i]),f=Math.max(f,u[0][i]),f=Math.max(f,u[c-1][i]);switch(s.prefixBoundary=!1,e){case\">\":h.value>f&&(s.prefixBoundary=!0);break;case\"<\":h.value<p&&(s.prefixBoundary=!0);break;case\"[]\":a=Math.min.apply(null,h.value),((o=Math.max.apply(null,h.value))<p||a>f)&&(s.prefixBoundary=!0);break;case\"][\":a=Math.min.apply(null,h.value),o=Math.max.apply(null,h.value),a<p&&o>f&&(s.prefixBoundary=!0)}}},{}],945:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\").extractOpts,i=t(\"./make_color_map\"),a=t(\"./end_plus\");e.exports={min:\"zmin\",max:\"zmax\",calc:function(t,e,r){var o=e.contours,s=e.line,l=o.size||1,c=o.coloring,u=i(e,{isColorbar:!0});if(\"heatmap\"===c){var h=n(e);r._fillgradient=e.colorscale,r._zrange=[h.min,h.max]}else\"fill\"===c&&(r._fillcolor=u);r._line={color:\"lines\"===c?u:s.color,width:!1!==o.showlines?s.width:0,dash:s.dash},r._levels={start:o.start,end:a(o),size:l}}}},{\"../../components/colorscale\":605,\"./end_plus\":953,\"./make_color_map\":958}],946:[function(t,e,r){\"use strict\";e.exports={BOTTOMSTART:[1,9,13,104,713],TOPSTART:[4,6,7,104,713],LEFTSTART:[8,12,14,208,1114],RIGHTSTART:[2,3,11,208,1114],NEWDELTA:[null,[-1,0],[0,-1],[-1,0],[1,0],null,[0,-1],[-1,0],[0,1],[0,1],null,[0,1],[1,0],[1,0],[0,-1]],CHOOSESADDLE:{104:[4,1],208:[2,8],713:[7,13],1114:[11,14]},SADDLEREMAINDER:{1:4,2:8,4:1,7:13,8:2,11:14,13:7,14:11},LABELDISTANCE:2,LABELINCREASE:10,LABELMIN:3,LABELMAX:10,LABELOPTIMIZER:{EDGECOST:1,ANGLECOST:1,NEIGHBORCOST:5,SAMELEVELFACTOR:10,SAMELEVELDISTANCE:5,MAXCOST:100,INITIALSEARCHPOINTS:10,ITERATIONS:5}}},{}],947:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./label_defaults\"),a=t(\"../../components/color\"),o=a.addOpacity,s=a.opacity,l=t(\"../../constants/filter_ops\"),c=l.CONSTRAINT_REDUCTION,u=l.COMPARISON_OPS2;e.exports=function(t,e,r,a,l,h){var f,p,d,g=e.contours,v=r(\"contours.operation\");(g._operation=c[v],function(t,e){var r;-1===u.indexOf(e.operation)?(t(\"contours.value\",[0,1]),Array.isArray(e.value)?e.value.length>2?e.value=e.value.slice(2):0===e.length?e.value=[0,1]:e.length<2?(r=parseFloat(e.value[0]),e.value=[r,r+1]):e.value=[parseFloat(e.value[0]),parseFloat(e.value[1])]:n(e.value)&&(r=parseFloat(e.value),e.value=[r,r+1])):(t(\"contours.value\",0),n(e.value)||(Array.isArray(e.value)?e.value=parseFloat(e.value[0]):e.value=0))}(r,g),\"=\"===v?f=g.showlines=!0:(f=r(\"contours.showlines\"),d=r(\"fillcolor\",o((t.line||{}).color||l,.5))),f)&&(p=r(\"line.color\",d&&s(d)?o(e.fillcolor,1):l),r(\"line.width\",2),r(\"line.dash\"));r(\"line.smoothing\"),i(r,a,p,h)}},{\"../../components/color\":593,\"../../constants/filter_ops\":691,\"./label_defaults\":957,\"fast-isnumeric\":225}],948:[function(t,e,r){\"use strict\";var n=t(\"../../constants/filter_ops\"),i=t(\"fast-isnumeric\");function a(t,e){var r,a=Array.isArray(e);function o(t){return i(t)?+t:null}return-1!==n.COMPARISON_OPS2.indexOf(t)?r=o(a?e[0]:e):-1!==n.INTERVAL_OPS.indexOf(t)?r=a?[o(e[0]),o(e[1])]:[o(e),o(e)]:-1!==n.SET_OPS.indexOf(t)&&(r=a?e.map(o):[o(e)]),r}function o(t){return function(e){e=a(t,e);var r=Math.min(e[0],e[1]),n=Math.max(e[0],e[1]);return{start:r,end:n,size:n-r}}}function s(t){return function(e){return{start:e=a(t,e),end:1/0,size:1/0}}}e.exports={\"[]\":o(\"[]\"),\"][\":o(\"][\"),\">\":s(\">\"),\"<\":s(\"<\"),\"=\":s(\"=\")}},{\"../../constants/filter_ops\":691,\"fast-isnumeric\":225}],949:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=n(\"contours.start\"),a=n(\"contours.end\"),o=!1===i||!1===a,s=r(\"contours.size\");!(o?e.autocontour=!0:r(\"autocontour\",!1))&&s||r(\"ncontours\")}},{}],950:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");function i(t){return n.extendFlat({},t,{edgepaths:n.extendDeep([],t.edgepaths),paths:n.extendDeep([],t.paths)})}e.exports=function(t,e){var r,a,o,s=function(t){return t.reverse()},l=function(t){return t};switch(e){case\"=\":case\"<\":return t;case\">\":for(1!==t.length&&n.warn(\"Contour data invalid for the specified inequality operation.\"),a=t[0],r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);return t;case\"][\":var c=s;s=l,l=c;case\"[]\":for(2!==t.length&&n.warn(\"Contour data invalid for the specified inequality range operation.\"),a=i(t[0]),o=i(t[1]),r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);for(;o.edgepaths.length;)a.edgepaths.push(l(o.edgepaths.shift()));for(;o.paths.length;)a.paths.push(l(o.paths.shift()));return[a]}}},{\"../../lib\":719}],951:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"./constraint_defaults\"),o=t(\"./contours_defaults\"),s=t(\"./style_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,l,r,i)}if(i(t,e,u,c)){u(\"text\"),u(\"hovertext\"),u(\"hovertemplate\");var h=\"constraint\"===u(\"contours.type\");u(\"connectgaps\",n.isArray1D(e.z)),h?a(t,e,u,c,r):(o(t,e,u,function(r){return n.coerce2(t,e,l,r)}),s(t,e,u,c))}else e.visible=!1}},{\"../../lib\":719,\"../heatmap/xyz_defaults\":1015,\"./attributes\":942,\"./constraint_defaults\":947,\"./contours_defaults\":949,\"./style_defaults\":963}],952:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constraint_mapping\"),a=t(\"./end_plus\");e.exports=function(t,e,r){for(var o=\"constraint\"===t.type?i[t._operation](t.value):t,s=o.size,l=[],c=a(o),u=r.trace._carpetTrace,h=u?{xaxis:u.aaxis,yaxis:u.baxis,x:r.a,y:r.b}:{xaxis:e.xaxis,yaxis:e.yaxis,x:r.x,y:r.y},f=o.start;f<c;f+=s)if(l.push(n.extendFlat({level:f,crossings:{},starts:[],edgepaths:[],paths:[],z:r.z,smoothing:r.trace.line.smoothing},h)),l.length>1e3){n.warn(\"Too many contours, clipping at 1000\",t);break}return l}},{\"../../lib\":719,\"./constraint_mapping\":948,\"./end_plus\":953}],953:[function(t,e,r){\"use strict\";e.exports=function(t){return t.end+t.size/1e6}},{}],954:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constants\");function a(t,e,r,n){return Math.abs(t[0]-e[0])<r&&Math.abs(t[1]-e[1])<n}function o(t,e,r,o,l){var c,u=e.join(\",\"),h=u,f=t.crossings[h],p=function(t,e,r){var n=0,a=0;t>20&&e?208===t||1114===t?n=0===r[0]?1:-1:a=0===r[1]?1:-1:-1!==i.BOTTOMSTART.indexOf(t)?a=1:-1!==i.LEFTSTART.indexOf(t)?n=1:-1!==i.TOPSTART.indexOf(t)?a=-1:n=-1;return[n,a]}(f,r,e),d=[s(t,e,[-p[0],-p[1]])],g=p.join(\",\"),v=t.z.length,m=t.z[0].length;for(c=0;c<1e4;c++){if(f>20?(f=i.CHOOSESADDLE[f][(p[0]||p[1])<0?0:1],t.crossings[h]=i.SADDLEREMAINDER[f]):delete t.crossings[h],!(p=i.NEWDELTA[f])){n.log(\"Found bad marching index:\",f,e,t.level);break}d.push(s(t,e,p)),e[0]+=p[0],e[1]+=p[1],a(d[d.length-1],d[d.length-2],o,l)&&d.pop(),h=e.join(\",\");var y=p[0]&&(e[0]<0||e[0]>m-2)||p[1]&&(e[1]<0||e[1]>v-2);if(h===u&&p.join(\",\")===g||r&&y)break;f=t.crossings[h]}1e4===c&&n.log(\"Infinite loop in contour?\");var x,b,_,w,k,T,A,M,S,E,C,L,P,O,z,I=a(d[0],d[d.length-1],o,l),D=0,R=.2*t.smoothing,F=[],B=0;for(c=1;c<d.length;c++)L=d[c],P=d[c-1],void 0,void 0,O=L[2]-P[2],z=L[3]-P[3],D+=A=Math.sqrt(O*O+z*z),F.push(A);var N=D/F.length*R;function j(t){return d[t%d.length]}for(c=d.length-2;c>=B;c--)if((x=F[c])<N){for(_=0,b=c-1;b>=B&&x+F[b]<N;b--)x+=F[b];if(I&&c===d.length-2)for(_=0;_<b&&x+F[_]<N;_++)x+=F[_];k=c-b+_+1,T=Math.floor((c+b+_+2)/2),w=I||c!==d.length-2?I||-1!==b?k%2?j(T):[(j(T)[0]+j(T+1)[0])/2,(j(T)[1]+j(T+1)[1])/2]:d[0]:d[d.length-1],d.splice(b+1,c-b+1,w),c=b+1,_&&(B=_),I&&(c===d.length-2?d[_]=d[d.length-1]:0===c&&(d[d.length-1]=d[0]))}for(d.splice(0,B),c=0;c<d.length;c++)d[c].length=2;if(!(d.length<2))if(I)d.pop(),t.paths.push(d);else{r||n.log(\"Unclosed interior contour?\",t.level,u,d.join(\"L\"));var U=!1;for(M=0;M<t.edgepaths.length;M++)if(E=t.edgepaths[M],!U&&a(E[0],d[d.length-1],o,l)){d.pop(),U=!0;var V=!1;for(S=0;S<t.edgepaths.length;S++)if(a((C=t.edgepaths[S])[C.length-1],d[0],o,l)){V=!0,d.shift(),t.edgepaths.splice(M,1),S===M?t.paths.push(d.concat(C)):(S>M&&S--,t.edgepaths[S]=C.concat(d,E));break}V||(t.edgepaths[M]=d.concat(E))}for(M=0;M<t.edgepaths.length&&!U;M++)a((E=t.edgepaths[M])[E.length-1],d[0],o,l)&&(d.shift(),t.edgepaths[M]=E.concat(d),U=!0);U||t.edgepaths.push(d)}}function s(t,e,r){var n=e[0]+Math.max(r[0],0),i=e[1]+Math.max(r[1],0),a=t.z[i][n],o=t.xaxis,s=t.yaxis;if(r[1]){var l=(t.level-a)/(t.z[i][n+1]-a);return[o.c2p((1-l)*t.x[n]+l*t.x[n+1],!0),s.c2p(t.y[i],!0),n+l,i]}var c=(t.level-a)/(t.z[i+1][n]-a);return[o.c2p(t.x[n],!0),s.c2p((1-c)*t.y[i]+c*t.y[i+1],!0),n,i+c]}e.exports=function(t,e,r){var i,a,s,l;for(e=e||.01,r=r||.01,a=0;a<t.length;a++){for(s=t[a],l=0;l<s.starts.length;l++)o(s,s.starts[l],\"edge\",e,r);for(i=0;Object.keys(s.crossings).length&&i<1e4;)i++,o(s,Object.keys(s.crossings)[0].split(\",\").map(Number),void 0,e,r);1e4===i&&n.log(\"Infinite loop in contour?\")}}},{\"../../lib\":719,\"./constants\":946}],955:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../heatmap/hover\");e.exports=function(t,e,r,a,o){var s=i(t,e,r,a,o,!0);return s&&s.forEach(function(t){var e=t.trace;\"constraint\"===e.contours.type&&(e.fillcolor&&n.opacity(e.fillcolor)?t.color=n.addOpacity(e.fillcolor,1):e.contours.showlines&&n.opacity(e.line.color)&&(t.color=n.addOpacity(e.line.color,1)))}),s}},{\"../../components/color\":593,\"../heatmap/hover\":1008}],956:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\").plot,style:t(\"./style\"),colorbar:t(\"./colorbar\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"contour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":942,\"./calc\":943,\"./colorbar\":945,\"./defaults\":951,\"./hover\":955,\"./plot\":960,\"./style\":962}],957:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i){if(i||(i={}),t(\"contours.showlabels\")){var a=e.font;n.coerceFont(t,\"contours.labelfont\",{family:a.family,size:a.size,color:r}),t(\"contours.labelformat\")}!1!==i.hasHover&&t(\"zhoverformat\")}},{\"../../lib\":719}],958:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/colorscale\"),a=t(\"./end_plus\");e.exports=function(t){var e=t.contours,r=e.start,o=a(e),s=e.size||1,l=Math.floor((o-r)/s)+1,c=\"lines\"===e.coloring?0:1,u=i.extractOpts(t);isFinite(s)||(s=1,l=1);var h,f,p=u.reversescale?i.flipScale(u.colorscale):u.colorscale,d=p.length,g=new Array(d),v=new Array(d);if(\"heatmap\"===e.coloring){var m=u.min,y=u.max;for(f=0;f<d;f++)h=p[f],g[f]=h[0]*(y-m)+m,v[f]=h[1];var x=n.extent([m,y,e.start,e.start+s*(l-1)]),b=x[m<y?0:1],_=x[m<y?1:0];b!==m&&(g.splice(0,0,b),v.splice(0,0,v[0])),_!==y&&(g.push(_),v.push(v[v.length-1]))}else for(f=0;f<d;f++)h=p[f],g[f]=(h[0]*(l+c-1)-c/2)*s+r,v[f]=h[1];return i.makeColorScaleFunc({domain:g,range:v},{noNumericCheck:!0})}},{\"../../components/colorscale\":605,\"./end_plus\":953,d3:163}],959:[function(t,e,r){\"use strict\";var n=t(\"./constants\");function i(t,e){var r=(e[0][0]>t?0:1)+(e[0][1]>t?0:2)+(e[1][1]>t?0:4)+(e[1][0]>t?0:8);return 5===r||10===r?t>(e[0][0]+e[0][1]+e[1][0]+e[1][1])/4?5===r?713:1114:5===r?104:208:15===r?0:r}e.exports=function(t){var e,r,a,o,s,l,c,u,h,f=t[0].z,p=f.length,d=f[0].length,g=2===p||2===d;for(r=0;r<p-1;r++)for(o=[],0===r&&(o=o.concat(n.BOTTOMSTART)),r===p-2&&(o=o.concat(n.TOPSTART)),e=0;e<d-1;e++)for(a=o.slice(),0===e&&(a=a.concat(n.LEFTSTART)),e===d-2&&(a=a.concat(n.RIGHTSTART)),s=e+\",\"+r,l=[[f[r][e],f[r][e+1]],[f[r+1][e],f[r+1][e+1]]],h=0;h<t.length;h++)(c=i((u=t[h]).level,l))&&(u.crossings[s]=c,-1!==a.indexOf(c)&&(u.starts.push([e,r]),g&&-1!==a.indexOf(c,a.indexOf(c)+1)&&u.starts.push([e,r])))}},{\"./constants\":946}],960:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../../plots/cartesian/set_convert\"),c=t(\"../heatmap/plot\"),u=t(\"./make_crossings\"),h=t(\"./find_all_paths\"),f=t(\"./empty_pathinfo\"),p=t(\"./convert_to_constraints\"),d=t(\"./close_boundaries\"),g=t(\"./constants\"),v=g.LABELOPTIMIZER;function m(t,e){var r,n,o,s,l,c,u,h=function(t,e){var r=t.prefixBoundary;if(void 0===r){var n=Math.min(t.z[0][0],t.z[0][1]);r=!t.edgepaths.length&&n>t.level}return r?\"M\"+e.join(\"L\")+\"Z\":\"\"}(t,e),f=0,p=t.edgepaths.map(function(t,e){return e}),d=!0;function g(t){return Math.abs(t[1]-e[2][1])<.01}function v(t){return Math.abs(t[0]-e[0][0])<.01}function m(t){return Math.abs(t[0]-e[2][0])<.01}for(;p.length;){for(c=a.smoothopen(t.edgepaths[f],t.smoothing),h+=d?c:c.replace(/^M/,\"L\"),p.splice(p.indexOf(f),1),r=t.edgepaths[f][t.edgepaths[f].length-1],s=-1,o=0;o<4;o++){if(!r){i.log(\"Missing end?\",f,t);break}for(u=r,Math.abs(u[1]-e[0][1])<.01&&!m(r)?n=e[1]:v(r)?n=e[0]:g(r)?n=e[3]:m(r)&&(n=e[2]),l=0;l<t.edgepaths.length;l++){var y=t.edgepaths[l][0];Math.abs(r[0]-n[0])<.01?Math.abs(r[0]-y[0])<.01&&(y[1]-r[1])*(n[1]-y[1])>=0&&(n=y,s=l):Math.abs(r[1]-n[1])<.01?Math.abs(r[1]-y[1])<.01&&(y[0]-r[0])*(n[0]-y[0])>=0&&(n=y,s=l):i.log(\"endpt to newendpt is not vert. or horz.\",r,n,y)}if(r=n,s>=0)break;h+=\"L\"+n}if(s===t.edgepaths.length){i.log(\"unclosed perimeter path\");break}f=s,(d=-1===p.indexOf(f))&&(f=p[0],h+=\"Z\")}for(f=0;f<t.paths.length;f++)h+=a.smoothclosed(t.paths[f],t.smoothing);return h}function y(t,e,r,n){var a=e.width/2,o=e.height/2,s=t.x,l=t.y,c=t.theta,u=Math.cos(c)*a,h=Math.sin(c)*a,f=(s>n.center?n.right-s:s-n.left)/(u+Math.abs(Math.sin(c)*o)),p=(l>n.middle?n.bottom-l:l-n.top)/(Math.abs(h)+Math.cos(c)*o);if(f<1||p<1)return 1/0;var d=v.EDGECOST*(1/(f-1)+1/(p-1));d+=v.ANGLECOST*c*c;for(var g=s-u,m=l-h,y=s+u,x=l+h,b=0;b<r.length;b++){var _=r[b],w=Math.cos(_.theta)*_.width/2,k=Math.sin(_.theta)*_.width/2,T=2*i.segmentDistance(g,m,y,x,_.x-w,_.y-k,_.x+w,_.y+k)/(e.height+_.height),A=_.level===e.level,M=A?v.SAMELEVELDISTANCE:1;if(T<=M)return 1/0;d+=v.NEIGHBORCOST*(A?v.SAMELEVELFACTOR:1)/(T-M)}return d}r.plot=function(t,e,o,s){var l=e.xaxis,v=e.yaxis;i.makeTraceGroups(s,o,\"contour\").each(function(o){var s=n.select(this),y=o[0],x=y.trace,b=y.x,_=y.y,w=x.contours,k=f(w,e,y),T=i.ensureSingle(s,\"g\",\"heatmapcoloring\"),A=[];\"heatmap\"===w.coloring&&(A=[o]),c(t,e,A,T),u(k),h(k);var M=l.c2p(b[0],!0),S=l.c2p(b[b.length-1],!0),E=v.c2p(_[0],!0),C=v.c2p(_[_.length-1],!0),L=[[M,C],[S,C],[S,E],[M,E]],P=k;\"constraint\"===w.type&&(P=p(k,w._operation),d(P,w._operation,L,x)),function(t,e,r){var n=i.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"===r.coloring?[0]:[]);n.enter().append(\"path\"),n.exit().remove(),n.attr(\"d\",\"M\"+e.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(s,L,w),function(t,e,r,a){var o=i.ensureSingle(t,\"g\",\"contourfill\").selectAll(\"path\").data(\"fill\"===a.coloring||\"constraint\"===a.type&&\"=\"!==a._operation?e:[]);o.enter().append(\"path\"),o.exit().remove(),o.each(function(t){var e=m(t,r);e?n.select(this).attr(\"d\",e).style(\"stroke\",\"none\"):n.select(this).remove()})}(s,P,L,w),function(t,e,o,s,l){var c=i.ensureSingle(t,\"g\",\"contourlines\"),u=!1!==l.showlines,h=l.showlabels,f=u&&h,p=r.createLines(c,u||h,e),d=r.createLineClip(c,f,o,s.trace.uid),v=t.selectAll(\"g.contourlabels\").data(h?[0]:[]);if(v.exit().remove(),v.enter().append(\"g\").classed(\"contourlabels\",!0),h){var m=[],y=[];i.clearLocationCache();var x=r.labelFormatter(l,s.t.cb,o._fullLayout),b=a.tester.append(\"text\").attr(\"data-notex\",1).call(a.font,l.labelfont),_=e[0].xaxis,w=e[0].yaxis,k=_._length,T=w._length,A=_.range,M=w.range,S=i.aggNums(Math.min,null,s.x),E=i.aggNums(Math.max,null,s.x),C=i.aggNums(Math.min,null,s.y),L=i.aggNums(Math.max,null,s.y),P=Math.max(_.c2p(S,!0),0),O=Math.min(_.c2p(E,!0),k),z=Math.max(w.c2p(L,!0),0),I=Math.min(w.c2p(C,!0),T),D={};A[0]<A[1]?(D.left=P,D.right=O):(D.left=O,D.right=P),M[0]<M[1]?(D.top=z,D.bottom=I):(D.top=I,D.bottom=z),D.middle=(D.top+D.bottom)/2,D.center=(D.left+D.right)/2,m.push([[D.left,D.top],[D.right,D.top],[D.right,D.bottom],[D.left,D.bottom]]);var R=Math.sqrt(k*k+T*T),F=g.LABELDISTANCE*R/Math.max(1,e.length/g.LABELINCREASE);p.each(function(t){var e=r.calcTextOpts(t.level,x,b,o);n.select(this).selectAll(\"path\").each(function(){var t=i.getVisibleSegment(this,D,e.height/2);if(t&&!(t.len<(e.width+e.height)*g.LABELMIN))for(var n=Math.min(Math.ceil(t.len/F),g.LABELMAX),a=0;a<n;a++){var o=r.findBestTextLocation(this,t,e,y,D);if(!o)break;r.addLabelData(o,e,y,m)}})}),b.remove(),r.drawLabels(v,y,o,d,f?m:null)}h&&!u&&p.remove()}(s,k,t,y,w),function(t,e,r,n,o){var s=r._fullLayout._clips,l=\"clip\"+n.trace.uid,c=s.selectAll(\"#\"+l).data(n.trace.connectgaps?[]:[0]);if(c.enter().append(\"clipPath\").classed(\"contourclip\",!0).attr(\"id\",l),c.exit().remove(),!1===n.trace.connectgaps){var f={level:.9,crossings:{},starts:[],edgepaths:[],paths:[],xaxis:e.xaxis,yaxis:e.yaxis,x:n.x,y:n.y,z:function(t){var e,r,n=t.trace._emptypoints,i=[],a=t.z.length,o=t.z[0].length,s=[];for(e=0;e<o;e++)s.push(1);for(e=0;e<a;e++)i.push(s.slice());for(e=0;e<n.length;e++)r=n[e],i[r[0]][r[1]]=0;return t.zmask=i,i}(n),smoothing:0};u([f]),h([f]);var p=m(f,o),d=i.ensureSingle(c,\"path\",\"\");d.attr(\"d\",p)}else l=null;a.setClipUrl(t,l,r)}(s,e,t,y,L)})},r.createLines=function(t,e,r){var n=r[0].smoothing,i=t.selectAll(\"g.contourlevel\").data(e?r:[]);if(i.exit().remove(),i.enter().append(\"g\").classed(\"contourlevel\",!0),e){var o=i.selectAll(\"path.openline\").data(function(t){return t.pedgepaths||t.edgepaths});o.exit().remove(),o.enter().append(\"path\").classed(\"openline\",!0),o.attr(\"d\",function(t){return a.smoothopen(t,n)}).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\");var s=i.selectAll(\"path.closedline\").data(function(t){return t.ppaths||t.paths});s.exit().remove(),s.enter().append(\"path\").classed(\"closedline\",!0),s.attr(\"d\",function(t){return a.smoothclosed(t,n)}).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\")}return i},r.createLineClip=function(t,e,r,n){var i=e?\"clipline\"+n:null,o=r._fullLayout._clips.selectAll(\"#\"+i).data(e?[0]:[]);return o.exit().remove(),o.enter().append(\"clipPath\").classed(\"contourlineclip\",!0).attr(\"id\",i),a.setClipUrl(t,i,r),o},r.labelFormatter=function(t,e,r){if(t.labelformat)return r._d3locale.numberFormat(t.labelformat);var n;if(e)n=e.axis;else{if(n={type:\"linear\",_id:\"ycontour\",showexponent:\"all\",exponentformat:\"B\"},\"constraint\"===t.type){var i=t.value;Array.isArray(i)?n.range=[i[0],i[i.length-1]]:n.range=[i,i]}else n.range=[t.start,t.end],n.nticks=(t.end-t.start)/t.size;n.range[0]===n.range[1]&&(n.range[1]+=n.range[0]||1),n.nticks||(n.nticks=1e3),l(n,r),s.prepTicks(n),n._tmin=null,n._tmax=null}return function(t){return s.tickText(n,t).text}},r.calcTextOpts=function(t,e,r,n){var i=e(t);r.text(i).call(o.convertToTspans,n);var s=a.bBox(r.node(),!0);return{text:i,width:s.width,height:s.height,level:t,dy:(s.top+s.bottom)/2}},r.findBestTextLocation=function(t,e,r,n,a){var o,s,l,c,u,h=r.width;e.isClosed?(s=e.len/v.INITIALSEARCHPOINTS,o=e.min+s/2,l=e.max):(s=(e.len-h)/(v.INITIALSEARCHPOINTS+1),o=e.min+s+h/2,l=e.max-(s+h)/2);for(var f=1/0,p=0;p<v.ITERATIONS;p++){for(var d=o;d<l;d+=s){var g=i.getTextLocation(t,e.total,d,h),m=y(g,r,n,a);m<f&&(f=m,u=g,c=d)}if(f>2*v.MAXCOST)break;p&&(s/=2),l=(o=c-s/2)+1.5*s}if(f<=v.MAXCOST)return u},r.addLabelData=function(t,e,r,n){var i=e.width/2,a=e.height/2,o=t.x,s=t.y,l=t.theta,c=Math.sin(l),u=Math.cos(l),h=i*u,f=a*c,p=i*c,d=-a*u,g=[[o-h-f,s-p-d],[o+h-f,s+p-d],[o+h+f,s+p+d],[o-h+f,s-p+d]];r.push({text:e.text,x:o,y:s,dy:e.dy,theta:l,level:e.level,width:e.width,height:e.height}),n.push(g)},r.drawLabels=function(t,e,r,a,s){var l=t.selectAll(\"text\").data(e,function(t){return t.text+\",\"+t.x+\",\"+t.y+\",\"+t.theta});if(l.exit().remove(),l.enter().append(\"text\").attr({\"data-notex\":1,\"text-anchor\":\"middle\"}).each(function(t){var e=t.x+Math.sin(t.theta)*t.dy,i=t.y-Math.cos(t.theta)*t.dy;n.select(this).text(t.text).attr({x:e,y:i,transform:\"rotate(\"+180*t.theta/Math.PI+\" \"+e+\" \"+i+\")\"}).call(o.convertToTspans,r)}),s){for(var c=\"\",u=0;u<s.length;u++)c+=\"M\"+s[u].join(\"L\")+\"Z\";i.ensureSingle(a,\"path\",\"\").attr(\"d\",c)}}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/set_convert\":785,\"../heatmap/plot\":1012,\"./close_boundaries\":944,\"./constants\":946,\"./convert_to_constraints\":950,\"./empty_pathinfo\":952,\"./find_all_paths\":954,\"./make_crossings\":959,d3:163}],961:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\");function a(t,e,r){var i={type:\"linear\",range:[t,e]};return n.autoTicks(i,(e-t)/(r||15)),i}e.exports=function(t,e){var r=t.contours;if(t.autocontour){var o=t.zmin,s=t.zmax;(t.zauto||void 0===o)&&(o=i.aggNums(Math.min,null,e)),(t.zauto||void 0===s)&&(s=i.aggNums(Math.max,null,e));var l=a(o,s,t.ncontours);r.size=l.dtick,r.start=n.tickFirst(l),l.range.reverse(),r.end=n.tickFirst(l),r.start===o&&(r.start+=r.size),r.end===s&&(r.end-=r.size),r.start>r.end&&(r.start=r.end=(r.start+r.end)/2),t._input.contours||(t._input.contours={}),i.extendFlat(t._input.contours,{start:r.start,end:r.end,size:r.size}),t._input.autocontour=!0}else if(\"constraint\"!==r.type){var c,u=r.start,h=r.end,f=t._input.contours;if(u>h&&(r.start=f.start=h,h=r.end=f.end=u,u=r.start),!(r.size>0))c=u===h?1:a(u,h,t.ncontours).dtick,f.size=r.size=c}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767}],962:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../heatmap/style\"),o=t(\"./make_color_map\");e.exports=function(t){var e=n.select(t).selectAll(\"g.contour\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.each(function(t){var e=n.select(this),r=t[0].trace,a=r.contours,s=r.line,l=a.size||1,c=a.start,u=\"constraint\"===a.type,h=!u&&\"lines\"===a.coloring,f=!u&&\"fill\"===a.coloring,p=h||f?o(r):null;e.selectAll(\"g.contourlevel\").each(function(t){n.select(this).selectAll(\"path\").call(i.lineGroupStyle,s.width,h?p(t.level):s.color,s.dash)});var d=a.labelfont;if(e.selectAll(\"g.contourlabels text\").each(function(t){i.font(n.select(this),{family:d.family,size:d.size,color:d.color||(h?p(t.level):s.color)})}),u)e.selectAll(\"g.contourfill path\").style(\"fill\",r.fillcolor);else if(f){var g;e.selectAll(\"g.contourfill path\").style(\"fill\",function(t){return void 0===g&&(g=t.level),p(t.level+.5*l)}),void 0===g&&(g=c),e.selectAll(\"g.contourbg path\").style(\"fill\",p(g-.5*l))}}),a(t)}},{\"../../components/drawing\":614,\"../heatmap/style\":1013,\"./make_color_map\":958,d3:163}],963:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/defaults\"),i=t(\"./label_defaults\");e.exports=function(t,e,r,a,o){var s,l=r(\"contours.coloring\"),c=\"\";\"fill\"===l&&(s=r(\"contours.showlines\")),!1!==s&&(\"lines\"!==l&&(c=r(\"line.color\",\"#000\")),r(\"line.width\",.5),r(\"line.dash\")),\"none\"!==l&&(!0!==t.showlegend&&(e.showlegend=!1),e._dfltShowLegend=!1,n(t,e,a,r,{prefix:\"\",cLetter:\"z\"})),r(\"line.smoothing\"),i(r,a,c,o)}},{\"../../components/colorscale/defaults\":603,\"./label_defaults\":957}],964:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../contour/attributes\"),a=i.contours,o=t(\"../scatter/attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../lib/extend\").extendFlat,c=o.line;e.exports=l({carpet:{valType:\"string\",editType:\"calc\"},z:n.z,a:n.x,a0:n.x0,da:n.dx,b:n.y,b0:n.y0,db:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,atype:n.xtype,btype:n.ytype,fillcolor:i.fillcolor,autocontour:i.autocontour,ncontours:i.ncontours,contours:{type:a.type,start:a.start,end:a.end,size:a.size,coloring:{valType:\"enumerated\",values:[\"fill\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:a.showlines,showlabels:a.showlabels,labelfont:a.labelfont,labelformat:a.labelformat,operation:a.operation,value:a.value,editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:l({},c.color,{}),width:c.width,dash:c.dash,smoothing:l({},c.smoothing,{}),editType:\"plot\"},transforms:void 0},s(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../contour/attributes\":942,\"../heatmap/attributes\":1001,\"../scatter/attributes\":1112}],965:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\"),i=t(\"../../lib\"),a=t(\"../heatmap/convert_column_xyz\"),o=t(\"../heatmap/clean_2d_array\"),s=t(\"../heatmap/interp2d\"),l=t(\"../heatmap/find_empties\"),c=t(\"../heatmap/make_bound_array\"),u=t(\"./defaults\"),h=t(\"../carpet/lookup_carpetid\"),f=t(\"../contour/set_contours\");e.exports=function(t,e){var r=e._carpetTrace=h(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){if(!e.a||!e.b){var p=t.data[r.index],d=t.data[e.index];d.a||(d.a=p.a),d.b||(d.b=p.b),u(d,e,e._defaultColor,t._fullLayout)}var g=function(t,e){var r,u,h,f,p,d,g,v=e._carpetTrace,m=v.aaxis,y=v.baxis;m._minDtick=0,y._minDtick=0,i.isArray1D(e.z)&&a(e,m,y,\"a\",\"b\",[\"z\"]);r=e._a=e._a||e.a,f=e._b=e._b||e.b,r=r?m.makeCalcdata(e,\"_a\"):[],f=f?y.makeCalcdata(e,\"_b\"):[],u=e.a0||0,h=e.da||1,p=e.b0||0,d=e.db||1,g=e._z=o(e._z||e.z,e.transpose),e._emptypoints=l(g),s(g,e._emptypoints);var x=i.maxRowLength(g),b=\"scaled\"===e.xtype?\"\":r,_=c(e,b,u,h,x,m),w=\"scaled\"===e.ytype?\"\":f,k=c(e,w,p,d,g.length,y),T={a:_,b:k,z:g};\"levels\"===e.contours.type&&\"none\"!==e.contours.coloring&&n(t,e,{vals:g,containerStr:\"\",cLetter:\"z\"});return[T]}(t,e);return f(e,e._z),g}}},{\"../../components/colorscale/calc\":601,\"../../lib\":719,\"../carpet/lookup_carpetid\":915,\"../contour/set_contours\":961,\"../heatmap/clean_2d_array\":1003,\"../heatmap/convert_column_xyz\":1005,\"../heatmap/find_empties\":1007,\"../heatmap/interp2d\":1010,\"../heatmap/make_bound_array\":1011,\"./defaults\":966}],966:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"./attributes\"),o=t(\"../contour/constraint_defaults\"),s=t(\"../contour/contours_defaults\"),l=t(\"../contour/style_defaults\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,a,r,i)}if(u(\"carpet\"),t.a&&t.b){if(!i(t,e,u,c,\"a\",\"b\"))return void(e.visible=!1);u(\"text\"),\"constraint\"===u(\"contours.type\")?o(t,e,u,c,r,{hasHover:!1}):(s(t,e,u,function(r){return n.coerce2(t,e,a,r)}),l(t,e,u,c,{hasHover:!1}))}else e._defaultColor=r,e._length=null}},{\"../../lib\":719,\"../contour/constraint_defaults\":947,\"../contour/contours_defaults\":949,\"../contour/style_defaults\":963,\"../heatmap/xyz_defaults\":1015,\"./attributes\":964}],967:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../contour/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../contour/style\"),moduleType:\"trace\",name:\"contourcarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"contour\",\"symbols\",\"showLegend\",\"hasLines\",\"carpetDependent\"],meta:{}}},{\"../../plots/cartesian\":778,\"../contour/colorbar\":945,\"../contour/style\":962,\"./attributes\":964,\"./calc\":965,\"./defaults\":966,\"./plot\":970}],968:[function(t,e,r){\"use strict\";var n=t(\"../../components/drawing\"),i=t(\"../carpet/axis_aligned_line\"),a=t(\"../../lib\");e.exports=function(t,e,r,o,s,l,c,u){var h,f,p,d,g,v,m,y=\"\",x=e.edgepaths.map(function(t,e){return e}),b=!0,_=1e-4*Math.abs(r[0][0]-r[2][0]),w=1e-4*Math.abs(r[0][1]-r[2][1]);function k(t){return Math.abs(t[1]-r[0][1])<w}function T(t){return Math.abs(t[1]-r[2][1])<w}function A(t){return Math.abs(t[0]-r[0][0])<_}function M(t){return Math.abs(t[0]-r[2][0])<_}function S(t,e){var r,n,a,o,h=\"\";for(k(t)&&!M(t)||T(t)&&!A(t)?(o=s.aaxis,a=i(s,l,[t[0],e[0]],.5*(t[1]+e[1]))):(o=s.baxis,a=i(s,l,.5*(t[0]+e[0]),[t[1],e[1]])),r=1;r<a.length;r++)for(h+=o.smoothing?\"C\":\"L\",n=0;n<a[r].length;n++){var f=a[r][n];h+=[c.c2p(f[0]),u.c2p(f[1])]+\" \"}return h}for(h=0,f=null;x.length;){var E=e.edgepaths[h][0];for(f&&(y+=S(f,E)),m=n.smoothopen(e.edgepaths[h].map(o),e.smoothing),y+=b?m:m.replace(/^M/,\"L\"),x.splice(x.indexOf(h),1),f=e.edgepaths[h][e.edgepaths[h].length-1],g=-1,d=0;d<4;d++){if(!f){a.log(\"Missing end?\",h,e);break}for(k(f)&&!M(f)?p=r[1]:A(f)?p=r[0]:T(f)?p=r[3]:M(f)&&(p=r[2]),v=0;v<e.edgepaths.length;v++){var C=e.edgepaths[v][0];Math.abs(f[0]-p[0])<_?Math.abs(f[0]-C[0])<_&&(C[1]-f[1])*(p[1]-C[1])>=0&&(p=C,g=v):Math.abs(f[1]-p[1])<w?Math.abs(f[1]-C[1])<w&&(C[0]-f[0])*(p[0]-C[0])>=0&&(p=C,g=v):a.log(\"endpt to newendpt is not vert. or horz.\",f,p,C)}if(g>=0)break;y+=S(f,p),f=p}if(g===e.edgepaths.length){a.log(\"unclosed perimeter path\");break}h=g,(b=-1===x.indexOf(h))&&(h=x[0],y+=S(f,p)+\"Z\",f=null)}for(h=0;h<e.paths.length;h++)y+=n.smoothclosed(e.paths[h].map(o),e.smoothing);return y}},{\"../../components/drawing\":614,\"../../lib\":719,\"../carpet/axis_aligned_line\":899}],969:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i,a,o,s,l,c,u;for(r=0;r<t.length;r++){for(o=(a=t[r]).pedgepaths=[],s=a.ppaths=[],n=0;n<a.edgepaths.length;n++){for(u=a.edgepaths[n],l=[],i=0;i<u.length;i++)l[i]=e(u[i]);o.push(l)}for(n=0;n<a.paths.length;n++){for(u=a.paths[n],c=[],i=0;i<u.length;i++)c[i]=e(u[i]);s.push(c)}}}},{}],970:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../carpet/map_1d_array\"),a=t(\"../carpet/makepath\"),o=t(\"../../components/drawing\"),s=t(\"../../lib\"),l=t(\"../contour/make_crossings\"),c=t(\"../contour/find_all_paths\"),u=t(\"../contour/plot\"),h=t(\"../contour/constants\"),f=t(\"../contour/convert_to_constraints\"),p=t(\"./join_all_paths\"),d=t(\"../contour/empty_pathinfo\"),g=t(\"./map_pathinfo\"),v=t(\"../carpet/lookup_carpetid\"),m=t(\"../contour/close_boundaries\");function y(t,e,r){var n=t.getPointAtLength(e),i=t.getPointAtLength(r),a=i.x-n.x,o=i.y-n.y,s=Math.sqrt(a*a+o*o);return[a/s,o/s]}function x(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]);return[t[0]/e,t[1]/e]}function b(t,e){var r=Math.abs(t[0]*e[0]+t[1]*e[1]);return Math.sqrt(1-r*r)/r}e.exports=function(t,e,r,_){var w=e.xaxis,k=e.yaxis;s.makeTraceGroups(_,r,\"contour\").each(function(r){var _=n.select(this),T=r[0],A=T.trace,M=A._carpetTrace=v(t,A),S=t.calcdata[M.index][0];if(M.visible&&\"legendonly\"!==M.visible){var E=T.a,C=T.b,L=A.contours,P=d(L,e,T),O=\"constraint\"===L.type,z=L._operation,I=O?\"=\"===z?\"lines\":\"fill\":L.coloring,D=[[E[0],C[C.length-1]],[E[E.length-1],C[C.length-1]],[E[E.length-1],C[0]],[E[0],C[0]]];l(P);var R=1e-8*(E[E.length-1]-E[0]),F=1e-8*(C[C.length-1]-C[0]);c(P,R,F);var B,N,j,U,V=P;\"constraint\"===L.type&&(V=f(P,z),m(V,z,D,A)),g(P,G);var q=[];for(U=S.clipsegments.length-1;U>=0;U--)B=S.clipsegments[U],N=i([],B.x,w.c2p),j=i([],B.y,k.c2p),N.reverse(),j.reverse(),q.push(a(N,j,B.bicubic));var H=\"M\"+q.join(\"L\")+\"Z\";!function(t,e,r,n,o,l){var c,u,h,f,p=s.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"!==l||o?[]:[0]);p.enter().append(\"path\"),p.exit().remove();var d=[];for(f=0;f<e.length;f++)c=e[f],u=i([],c.x,r.c2p),h=i([],c.y,n.c2p),d.push(a(u,h,c.bicubic));p.attr(\"d\",\"M\"+d.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(_,S.clipsegments,w,k,O,I),function(t,e,r,i,a,o,l,c,u,h,f){var d=s.ensureSingle(e,\"g\",\"contourfill\").selectAll(\"path\").data(\"fill\"===h?a:[]);d.enter().append(\"path\"),d.exit().remove(),d.each(function(e){var a=p(t,e,o,l,c,u,r,i);e.prefixBoundary&&(a=f+a),a?n.select(this).attr(\"d\",a).style(\"stroke\",\"none\"):n.select(this).remove()})}(A,_,w,k,V,D,G,M,S,I,H),function(t,e,r,i,a,l,c){var f=s.ensureSingle(t,\"g\",\"contourlines\"),p=!1!==a.showlines,d=a.showlabels,g=p&&d,v=u.createLines(f,p||d,e),m=u.createLineClip(f,g,r,i.trace.uid),_=t.selectAll(\"g.contourlabels\").data(d?[0]:[]);if(_.exit().remove(),_.enter().append(\"g\").classed(\"contourlabels\",!0),d){var w=l.xaxis,k=l.yaxis,T=w._length,A=k._length,M=[[[0,0],[T,0],[T,A],[0,A]]],S=[];s.clearLocationCache();var E=u.labelFormatter(a,i.t.cb,r._fullLayout),C=o.tester.append(\"text\").attr(\"data-notex\",1).call(o.font,a.labelfont),L={left:0,right:T,center:T/2,top:0,bottom:A,middle:A/2},P=Math.sqrt(T*T+A*A),O=h.LABELDISTANCE*P/Math.max(1,e.length/h.LABELINCREASE);v.each(function(t){var e=u.calcTextOpts(t.level,E,C,r);n.select(this).selectAll(\"path\").each(function(r){var n=s.getVisibleSegment(this,L,e.height/2);if(n&&(function(t,e,r,n,i,a){for(var o,s=0;s<r.pedgepaths.length;s++)e===r.pedgepaths[s]&&(o=r.edgepaths[s]);if(!o)return;var l=i.a[0],c=i.a[i.a.length-1],u=i.b[0],h=i.b[i.b.length-1];function f(t,e){var r,n=0;return(Math.abs(t[0]-l)<.1||Math.abs(t[0]-c)<.1)&&(r=x(i.dxydb_rough(t[0],t[1],.1)),n=Math.max(n,a*b(e,r)/2)),(Math.abs(t[1]-u)<.1||Math.abs(t[1]-h)<.1)&&(r=x(i.dxyda_rough(t[0],t[1],.1)),n=Math.max(n,a*b(e,r)/2)),n}var p=y(t,0,1),d=y(t,n.total,n.total-1),g=f(o[0],p),v=n.total-f(o[o.length-1],d);n.min<g&&(n.min=g);n.max>v&&(n.max=v);n.len=n.max-n.min}(this,r,t,n,c,e.height),!(n.len<(e.width+e.height)*h.LABELMIN)))for(var i=Math.min(Math.ceil(n.len/O),h.LABELMAX),a=0;a<i;a++){var o=u.findBestTextLocation(this,n,e,S,L);if(!o)break;u.addLabelData(o,e,S,M)}})}),C.remove(),u.drawLabels(_,S,r,m,g?M:null)}d&&!p&&v.remove()}(_,P,t,T,L,e,M),o.setClipUrl(_,M._clipPathId,t)}function G(t){var e=M.ab2xy(t[0],t[1],!0);return[w.c2p(e[0]),k.c2p(e[1])]}})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../carpet/lookup_carpetid\":915,\"../carpet/makepath\":916,\"../carpet/map_1d_array\":917,\"../contour/close_boundaries\":944,\"../contour/constants\":946,\"../contour/convert_to_constraints\":950,\"../contour/empty_pathinfo\":952,\"../contour/find_all_paths\":954,\"../contour/make_crossings\":959,\"../contour/plot\":960,\"./join_all_paths\":968,\"./map_pathinfo\":969,d3:163}],971:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../scattermapbox/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({lon:o.lon,lat:o.lat,z:{valType:\"data_array\",editType:\"calc\"},radius:{valType:\"number\",editType:\"plot\",arrayOk:!0,min:1,dflt:30},below:{valType:\"string\",editType:\"plot\"},text:o.text,hovertext:o.hovertext,hoverinfo:s({},a.hoverinfo,{flags:[\"lon\",\"lat\",\"z\",\"text\",\"name\"]}),hovertemplate:i()},n(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scattermapbox/attributes\":1171}],972:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../components/colorscale/calc\"),s=t(\"../../lib\")._;e.exports=function(t,e){for(var r=e._length,l=new Array(r),c=e.z,u=i(c)&&c.length,h=0;h<r;h++){var f=l[h]={},p=e.lon[h],d=e.lat[h];if(f.lonlat=n(p)&&n(d)?[+p,+d]:[a,a],u){var g=c[h];f.z=n(g)?g:a}}return o(t,e,{vals:u?c:[0,1],containerStr:\"\",cLetter:\"z\"}),r&&(l[0].t={labels:{lat:s(t,\"lat:\")+\" \",lon:s(t,\"lon:\")+\" \"}}),l}},{\"../../components/colorscale/calc\":601,\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],973:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../../components/colorscale\"),s=t(\"../../constants/numerical\").BADNUM,l=t(\"../../lib/geojson_utils\").makeBlank;e.exports=function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,c=e._opts={heatmap:{layout:{visibility:\"none\"},paint:{}},geojson:l()};if(!r)return c;var u,h=[],f=e.z,p=e.radius,d=i.isArrayOrTypedArray(f)&&f.length,g=i.isArrayOrTypedArray(p);for(u=0;u<t.length;u++){var v=t[u],m=v.lonlat;if(m[0]!==s){var y={};if(d){var x=v.z;y.z=x!==s?x:0}g&&(y.r=n(p[u])&&p[u]>0?+p[u]:0),h.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:m},properties:y})}}var b=o.extractOpts(e),_=b.reversescale?o.flipScale(b.colorscale):b.colorscale,w=_[0][1],k=[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,a.opacity(w)<1?w:a.addOpacity(w,0)];for(u=1;u<_.length;u++)k.push(_[u][0],_[u][1]);var T=[\"interpolate\",[\"linear\"],[\"get\",\"z\"],b.min,0,b.max,1];return i.extendFlat(c.heatmap.paint,{\"heatmap-weight\":d?T:1/(b.max-b.min),\"heatmap-color\":k,\"heatmap-radius\":g?{type:\"identity\",property:\"r\"}:e.radius,\"heatmap-opacity\":e.opacity}),c.geojson={type:\"FeatureCollection\",features:h},c.heatmap.layout.visibility=\"visible\",c}},{\"../../components/color\":593,\"../../components/colorscale\":605,\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/geojson_utils\":714,\"fast-isnumeric\":225}],974:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"lon\")||[],c=s(\"lat\")||[],u=Math.min(l.length,c.length);u?(e._length=u,s(\"z\"),s(\"radius\"),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":971}],975:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.z=e.z,t}},{}],976:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../scattermapbox/hover\");e.exports=function(t,e,r){var o=a(t,e,r);if(o){var s=o[0],l=s.cd,c=l[0].trace,u=l[s.index];if(delete s.color,\"z\"in u){var h=s.subplot.mockAxis;s.z=u.z,s.zLabel=i.tickText(h,h.c2l(u.z),\"hover\").text}return s.extraText=function(t,e,r){if(t.hovertemplate)return;var i=(e.hi||t.hoverinfo).split(\"+\"),a=-1!==i.indexOf(\"all\"),o=-1!==i.indexOf(\"lon\"),s=-1!==i.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}a||o&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):o?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(a||-1!==i.indexOf(\"text\"))&&n.fillText(e,t,c);return c.join(\"<br>\")}(c,u,l[0].t.labels),[s]}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scattermapbox/hover\":1175}],977:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),getBelow:function(t,e){for(var r=e.getMapLayers(),n=0;n<r.length;n++){var i=r[n],a=i.id;if(\"symbol\"===i.type&&\"string\"==typeof a&&-1===a.indexOf(\"plotly-\"))return a}},moduleType:\"trace\",name:\"densitymapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\"],meta:{hr_name:\"density_mapbox\"}}},{\"../../plots/mapbox\":822,\"../heatmap/colorbar\":1004,\"./attributes\":971,\"./calc\":972,\"./defaults\":974,\"./event_data\":975,\"./hover\":976,\"./plot\":978}],978:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function a(t,e){this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"heatmap\",i+e+\"-heatmap\"]],this.below=null}var o=a.prototype;o.update=function(t){var e=this.subplot,r=this.layerList,i=n(t),a=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(i.geojson),a!==this.below&&(this._removeLayers(),this._addLayers(i,a),this.below=a);for(var o=0;o<r.length;o++){var s=r[o],l=s[0],c=s[1],u=i[l];e.setOptions(c,\"setLayoutProperty\",u.layout),\"visible\"===u.layout.visibility&&e.setOptions(c,\"setPaintProperty\",u.paint)}},o._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},o._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},o.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new a(t,r.uid),o=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(o,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),i}},{\"../../plots/mapbox/constants\":820,\"./convert\":973}],979:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":719}],980:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"./constants\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../components/color\");e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,hovertext:n.hovertext,hovertemplate:o({},{keys:s.eventDataKeys}),hoverinfo:l({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"percent initial\",\"percent previous\",\"percent total\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"percent initial\",\"percent previous\",\"percent total\",\"value\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},text:n.text,textposition:l({},n.textposition,{dflt:\"auto\"}),insidetextanchor:l({},n.insidetextanchor,{dflt:\"middle\"}),textangle:l({},n.textangle,{dflt:0}),textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:l({},n.orientation,{}),offset:l({},n.offset,{arrayOk:!1}),width:l({},n.width,{arrayOk:!1}),marker:n.marker,connector:{fillcolor:{valType:\"color\",editType:\"style\"},line:{color:l({},i.color,{dflt:c.defaultLine}),width:l({},i.width,{dflt:0,editType:\"plot\"}),dash:i.dash,editType:\"style\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":593,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../bar/attributes\":857,\"../scatter/attributes\":1112,\"./constants\":982}],981:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"./arrays_to_calcdata\"),a=t(\"../scatter/calc_selection\"),o=t(\"../../constants/numerical\").BADNUM;function s(t){return t===o?0:t}e.exports=function(t,e){var r,l,c,u,h=n.getFromId(t,e.xaxis||\"x\"),f=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=h.makeCalcdata(e,\"x\"),l=f.makeCalcdata(e,\"y\")):(r=f.makeCalcdata(e,\"y\"),l=h.makeCalcdata(e,\"x\"));var p,d=Math.min(l.length,r.length),g=new Array(d);for(e._base=[],c=0;c<d;c++){r[c]<0&&(r[c]=o);var v=!1;r[c]!==o&&c+1<d&&r[c+1]!==o&&(v=!0),u=g[c]={p:l[c],s:r[c],cNext:v},e._base[c]=-.5*u.s,e.ids&&(u.id=String(e.ids[c])),0===c&&(g[0].vTotal=0),g[0].vTotal+=s(u.s),u.begR=s(u.s)/s(g[0].s)}for(c=0;c<d;c++)(u=g[c]).s!==o&&(u.sumR=u.s/g[0].vTotal,u.difR=void 0!==p?u.s/p:1,p=u.s);return i(g,e),a(g,e),g}},{\"../../constants/numerical\":695,\"../../plots/cartesian/axes\":767,\"../scatter/calc_selection\":1114,\"./arrays_to_calcdata\":979}],982:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"percentInitial\",\"percentPrevious\",\"percentTotal\"]}},{}],983:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],h=[],f=[];for(i=0;i<o.length;i++){var p=o[i],d=\"h\"===p.orientation;!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"funnel\"===p.type&&(r=s[i],d?f.push(r):h.push(r),u.push(r))}var g={mode:a.funnelmode,norm:a.funnelnorm,gap:a.funnelgap,groupgap:a.funnelgroupgap};for(n(t,l,c,h,g),n(t,c,l,f,g),i=0;i<u.length;i++){r=u[i];for(var v=0;v<r.length;v++)v+1<r.length&&(r[v].nextP0=r[v+1].p0,r[v].nextS0=r[v+1].s0,r[v].nextP1=r[v+1].p1,r[v].nextS1=r[v+1].s1)}}},{\"../bar/cross_trace_calc\":860}],984:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"./attributes\"),l=t(\"../../components/color\");e.exports={supplyDefaults:function(t,e,r,i){function c(r,i){return n.coerce(t,e,s,r,i)}if(o(t,e,i,c)){c(\"orientation\",e.y&&!e.x?\"v\":\"h\"),c(\"offset\"),c(\"width\");var u=c(\"text\");c(\"hovertext\"),c(\"hovertemplate\");var h=c(\"textposition\");a(t,e,i,c,h,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"!==e.textposition&&c(\"textinfo\",Array.isArray(u)?\"text+value\":\"value\");var f=c(\"marker.color\",r);c(\"marker.line.color\",l.defaultLine),c(\"marker.line.width\"),c(\"connector.visible\")&&(c(\"connector.fillcolor\",function(t){var e=n.isArrayOrTypedArray(t)?\"#000\":t;return l.addOpacity(e,.5*l.opacity(e))}(f)),c(\"connector.line.width\")&&(c(\"connector.line.color\"),c(\"connector.line.dash\")))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,s,t)}if(\"group\"===e.funnelmode)for(var l=0;l<t.length;l++)r=(a=t[l])._input,i(r,a,e,o)}}},{\"../../components/color\":593,\"../../lib\":719,\"../bar/defaults\":861,\"../scatter/xy_defaults\":1137,\"./attributes\":980}],985:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"percentInitial\"in e&&(t.percentInitial=e.percentInitial),\"percentPrevious\"in e&&(t.percentPrevious=e.percentPrevious),\"percentTotal\"in e&&(t.percentTotal=e.percentTotal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],986:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\").opacity,i=t(\"../bar/hover\").hoverOnBars,a=t(\"../../lib\").formatPercent;e.exports=function(t,e,r,o){var s=i(t,e,r,o);if(s){var l=s.cd,c=l[0].trace,u=\"h\"===c.orientation,h=l[s.index];s[(u?\"x\":\"y\")+\"LabelVal\"]=h.s,s.percentInitial=h.begR,s.percentInitialLabel=a(h.begR,1),s.percentPrevious=h.difR,s.percentPreviousLabel=a(h.difR,1),s.percentTotal=h.sumR,s.percentTotalLabel=a(h.sumR,1);var f=h.hi||c.hoverinfo,p=[];if(f&&\"none\"!==f&&\"skip\"!==f){var d=\"all\"===f,g=f.split(\"+\"),v=function(t){return d||-1!==g.indexOf(t)};v(\"percent initial\")&&p.push(s.percentInitialLabel+\" of initial\"),v(\"percent previous\")&&p.push(s.percentPreviousLabel+\" of previous\"),v(\"percent total\")&&p.push(s.percentTotalLabel+\" of total\")}return s.extraText=p.join(\"<br>\"),s.color=function(t,e){var r=t.marker,i=e.mc||r.color,a=e.mlc||r.line.color,o=e.mlw||r.line.width;if(n(i))return i;if(n(a)&&o)return a}(c,h),[s]}}},{\"../../components/color\":593,\"../../lib\":719,\"../bar/hover\":863}],987:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"funnel\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../bar/select\":868,\"./attributes\":980,\"./calc\":981,\"./cross_trace_calc\":983,\"./defaults\":984,\"./event_data\":985,\"./hover\":986,\"./layout_attributes\":988,\"./layout_defaults\":989,\"./plot\":990,\"./style\":991}],988:[function(t,e,r){\"use strict\";e.exports={funnelmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},funnelgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},funnelgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],989:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"funnel\"===l.type){a=!0;break}}a&&(o(\"funnelmode\"),o(\"funnelgap\",.2),o(\"funnelgroupgap\"))}},{\"../../lib\":719,\"./layout_attributes\":988}],990:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../bar/plot\").plot;function s(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),i[3]=o.c2p(t.nextS1,!0),a[3]=s.c2p(t.nextP1,!0),n?[i,a]:[a,i]}e.exports=function(t,e,r,l){var c=t._fullLayout;!function(t,e,r,o){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each(function(r){var o=n.select(this),u=r[0].trace,h=i.ensureSingle(o,\"g\",\"regions\");if(u.connector&&u.connector.visible){var f=\"h\"===u.orientation,p=h.selectAll(\"g.region\").data(i.identity);p.enter().append(\"g\").classed(\"region\",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var u=s(r,l,c,f),h=u[0],p=u[1],g=\"\";void 0!==h[3]&&void 0!==p[3]&&(g+=f?\"M\"+h[0]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[2]+\"H\"+h[3]+\"L\"+h[1]+\",\"+p[1]+\"Z\":\"M\"+h[1]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[3]+\"V\"+p[2]+\"L\"+h[1]+\",\"+p[0]+\"Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}})}else h.remove()})}(t,e,r,l),function(t,e,r,o){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each(function(r){var o=n.select(this),u=r[0].trace,h=i.ensureSingle(o,\"g\",\"lines\");if(u.connector&&u.connector.visible&&u.connector.line.width){var f=\"h\"===u.orientation,p=h.selectAll(\"g.line\").data(i.identity);p.enter().append(\"g\").classed(\"line\",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var u=s(r,l,c,f),h=u[0],p=u[1],g=\"\";void 0!==h[3]&&void 0!==p[3]&&(f?(g+=\"M\"+h[0]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[2],g+=\"M\"+h[1]+\",\"+p[1]+\"L\"+h[3]+\",\"+p[2]):(g+=\"M\"+h[1]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[3],g+=\"M\"+h[1]+\",\"+p[0]+\"L\"+h[2]+\",\"+p[2])),\"\"===g&&(g=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}})}else h.remove()})}(t,e,r,l),o(t,e,r,l,{mode:c.funnelmode,norm:c.funnelmode,gap:c.funnelgap,groupgap:c.funnelgroupgap})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../bar/plot\":867,d3:163}],991:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\").styleTextPoints;e.exports={style:function(t,e,r){var l=r||n.select(t).selectAll(\"g.funnellayer\").selectAll(\"g.trace\");l.style(\"opacity\",function(t){return t[0].trace.opacity}),l.each(function(e){var r=n.select(this),l=e[0].trace;r.selectAll(\".point > path\").each(function(t){if(!t.isBlank){var e=l.marker;n.select(this).call(a.fill,t.mc||e.color).call(a.stroke,t.mlc||e.line.color).call(i.dashLine,e.line.dash,t.mlw||e.line.width).style(\"opacity\",l.selectedpoints&&!t.selected?o:1)}}),s(r,l,t),r.selectAll(\".regions\").each(function(){n.select(this).selectAll(\"path\").style(\"stroke-width\",0).call(a.fill,l.connector.fillcolor)}),r.selectAll(\".lines\").each(function(){var t=l.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)})})}}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../constants/interactions\":694,\"../bar/style\":870,d3:163}],992:[function(t,e,r){\"use strict\";var n=t(\"../pie/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../plots/domain\").attributes,o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports={labels:n.labels,label0:n.label0,dlabel:n.dlabel,values:n.values,marker:{colors:n.marker.colors,line:{color:s({},n.marker.line.color,{dflt:null}),width:s({},n.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},text:n.text,hovertext:n.hovertext,scalegroup:s({},n.scalegroup,{}),textinfo:s({},n.textinfo,{flags:[\"label\",\"text\",\"value\",\"percent\"]}),hoverinfo:s({},i.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:o({},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),textposition:s({},n.textposition,{values:[\"inside\",\"none\"],dflt:\"inside\"}),textfont:n.textfont,insidetextfont:n.insidetextfont,title:{text:n.title.text,font:n.title.font,position:s({},n.title.position,{values:[\"top left\",\"top center\",\"top right\"],dflt:\"top center\"}),editType:\"plot\"},domain:a({name:\"funnelarea\",trace:!0,editType:\"calc\"}),aspectratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},baseratio:{valType:\"number\",min:0,max:1,dflt:.333,editType:\"plot\"}}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../pie/attributes\":1086}],993:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData;r.name=\"funnelarea\",r.plot=function(t){var e=n.getModule(\"funnelarea\"),r=i(t.calcdata,e)[0];e.plot(t,r)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"funnelarea\"),a=e._has&&e._has(\"funnelarea\");i&&!a&&n._funnelarealayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],994:[function(t,e,r){\"use strict\";var n=t(\"../pie/calc\");e.exports={calc:function(t,e){return n.calc(t,e)},crossTraceCalc:function(t){n.crossTraceCalc(t,{type:\"funnelarea\"})}}},{\"../pie/calc\":1088}],995:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}var c,u=l(\"values\"),h=n.isArrayOrTypedArray(u),f=l(\"labels\");if(Array.isArray(f)?(c=f.length,h&&(c=Math.min(c,u.length))):h&&(c=u.length,l(\"label0\"),l(\"dlabel\")),c){e._length=c,l(\"marker.line.width\")&&l(\"marker.line.color\",s.paper_bgcolor),l(\"marker.colors\"),l(\"scalegroup\");var p=l(\"text\"),d=l(\"textinfo\",Array.isArray(p)?\"text+percent\":\"percent\");if(l(\"hovertext\"),l(\"hovertemplate\"),d&&\"none\"!==d){var g=l(\"textposition\");o(t,e,s,l,g,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}a(e,s,l),l(\"title.text\")&&(l(\"title.position\"),n.coerceFont(l,\"title.font\",s.font)),l(\"aspectratio\"),l(\"baseratio\")}else e.visible=!1}},{\"../../lib\":719,\"../../plots/domain\":792,\"../bar/defaults\":861,\"./attributes\":992}],996:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"funnelarea\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"funnelarea\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\"),styleOne:t(\"../pie/style_one\"),meta:{}}},{\"../pie/style_one\":1097,\"./attributes\":992,\"./base_plot\":993,\"./calc\":994,\"./defaults\":995,\"./layout_attributes\":997,\"./layout_defaults\":998,\"./plot\":999,\"./style\":1e3}],997:[function(t,e,r){\"use strict\";var n=t(\"../pie/layout_attributes\").hiddenlabels;e.exports={hiddenlabels:n,funnelareacolorway:{valType:\"colorlist\",editType:\"calc\"},extendfunnelareacolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{\"../pie/layout_attributes\":1093}],998:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"funnelareacolorway\",e.colorway),r(\"extendfunnelareacolors\")}},{\"../../lib\":719,\"./layout_attributes\":997}],999:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../lib\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../bar/plot\"),l=s.getTransform,c=s.toMoveInsideBar,u=t(\"../pie/helpers\"),h=t(\"../pie/plot\"),f=h.attachFxHandlers,p=h.determineInsideTextFont,d=h.layoutAreas,g=h.prerenderTitles,v=h.positionTitleOutside;function m(t,e){return\"l\"+(e[0]-t[0])+\",\"+(e[1]-t[1])}e.exports=function(t,e){var r=t._fullLayout;g(e,t),d(e,r._size),a.makeTraceGroups(r._funnelarealayer,e,\"trace\").each(function(e){var s=n.select(this),h=e[0],d=h.trace;!function(t){if(!t.length)return;var e=t[0],r=e.trace,n=r.aspectratio,i=r.baseratio;i>.999&&(i=.999);var a,o=Math.pow(i,2),s=e.vTotal,l=s,c=s*o/(1-o)/s;function u(){var t,e={x:t=Math.sqrt(c),y:-t};return[e.x,e.y]}var h,f,p=[];for(p.push(u()),h=t.length-1;h>-1;h--)if(!(f=t[h]).hidden){var d=f.v/l;c+=d,p.push(u())}var g=1/0,v=-1/0;for(h=0;h<p.length;h++)a=p[h],g=Math.min(g,a[1]),v=Math.max(v,a[1]);for(h=0;h<p.length;h++)p[h][1]-=(v+g)/2;var m=p[p.length-1][0],y=e.r,x=(v-g)/2,b=y/m,_=y/x*n;for(e.r=_*x,h=0;h<p.length;h++)p[h][0]*=b,p[h][1]*=_;var w=[-(a=p[0])[0],a[1]],k=[a[0],a[1]],T=0;for(h=t.length-1;h>-1;h--)if(!(f=t[h]).hidden){var A=p[T+=1][0],M=p[T][1];f.TL=[-A,M],f.TR=[A,M],f.BL=w,f.BR=k,f.pxmid=(S=f.TR,E=f.BR,[.5*(S[0]+E[0]),.5*(S[1]+E[1])]),w=f.TL,k=f.TR}var S,E}(e),s.each(function(){var s=n.select(this).selectAll(\"g.slice\").data(e);s.enter().append(\"g\").classed(\"slice\",!0),s.exit().remove(),s.each(function(r){if(r.hidden)n.select(this).selectAll(\"path,g\").remove();else{r.pointNumber=r.i,r.curveNumber=d.index;var s=h.cx,g=h.cy,v=n.select(this),y=v.selectAll(\"path.surface\").data([r]);y.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),v.call(f,t,e);var x=\"M\"+(s+r.TR[0])+\",\"+(g+r.TR[1])+m(r.TR,r.BR)+m(r.BR,r.BL)+m(r.BL,r.TL)+\"Z\";y.attr(\"d\",x);var b=u.castOption(d.textposition,r.pts),_=v.selectAll(\"g.slicetext\").data(r.text&&\"none\"!==b?[0]:[]);_.enter().append(\"g\").classed(\"slicetext\",!0),_.exit().remove(),_.each(function(){var e=a.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)});e.text(r.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,p(d,r,t._fullLayout.font)).call(o.convertToTspans,t);var u,h,f,v=i.bBox(e.node()),m=Math.min(r.BL[1],r.BR[1]),y=Math.max(r.TL[1],r.TR[1]);h=Math.max(r.TL[0],r.BL[0]),f=Math.min(r.TR[0],r.BR[0]),u=l(c(h,f,m,y,v,{isHorizontal:!0,constrained:!0,angle:0,anchor:\"middle\"})),e.attr(\"transform\",\"translate(\"+s+\",\"+g+\")\"+u)})}});var g=n.select(this).selectAll(\"g.titletext\").data(d.title.text?[0]:[]);g.enter().append(\"g\").classed(\"titletext\",!0),g.exit().remove(),g.each(function(){var e=a.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),s=d.title.text;d._meta&&(s=a.templateString(s,d._meta)),e.text(s).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,d.title.font).call(o.convertToTspans,t);var l=v(h,r._size);e.attr(\"transform\",\"translate(\"+l.x+\",\"+l.y+\")\"+(l.scale<1?\"scale(\"+l.scale+\")\":\"\")+\"translate(\"+l.tx+\",\"+l.ty+\")\")})})})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../bar/plot\":867,\"../pie/helpers\":1091,\"../pie/plot\":1095,d3:163}],1000:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../pie/style_one\");e.exports=function(t){t._fullLayout._funnelarealayer.selectAll(\".trace\").each(function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each(function(t){n.select(this).call(i,t,e)})})}},{\"../pie/style_one\":1097,d3:163}],1001:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../components/colorscale/attributes\"),o=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../lib/extend\").extendFlat);e.exports=o({z:{valType:\"data_array\",editType:\"calc\"},x:o({},n.x,{impliedEdits:{xtype:\"array\"}}),x0:o({},n.x0,{impliedEdits:{xtype:\"scaled\"}}),dx:o({},n.dx,{impliedEdits:{xtype:\"scaled\"}}),y:o({},n.y,{impliedEdits:{ytype:\"array\"}}),y0:o({},n.y0,{impliedEdits:{ytype:\"scaled\"}}),dy:o({},n.dy,{impliedEdits:{ytype:\"scaled\"}}),text:{valType:\"data_array\",editType:\"calc\"},hovertext:{valType:\"data_array\",editType:\"calc\"},transpose:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xtype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},ytype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},zsmooth:{valType:\"enumerated\",values:[\"fast\",\"best\",!1],dflt:!1,editType:\"calc\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xgap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},ygap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},zhoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},hovertemplate:i()},{transforms:void 0},a(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../scatter/attributes\":1112}],1002:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../histogram2d/calc\"),s=t(\"../../components/colorscale/calc\"),l=t(\"./convert_column_xyz\"),c=t(\"./clean_2d_array\"),u=t(\"./interp2d\"),h=t(\"./find_empties\"),f=t(\"./make_bound_array\");e.exports=function(t,e){var r,p,d,g,v,m,y,x,b,_=a.getFromId(t,e.xaxis||\"x\"),w=a.getFromId(t,e.yaxis||\"y\"),k=n.traceIs(e,\"contour\"),T=n.traceIs(e,\"histogram\"),A=n.traceIs(e,\"gl2d\"),M=k?\"best\":e.zsmooth;if(_._minDtick=0,w._minDtick=0,T)r=(b=o(t,e)).x,p=b.x0,d=b.dx,g=b.y,v=b.y0,m=b.dy,y=b.z;else{var S=e.z;i.isArray1D(S)?(l(e,_,w,\"x\",\"y\",[\"z\"]),r=e._x,g=e._y,S=e._z):(r=e._x=e.x?_.makeCalcdata(e,\"x\"):[],g=e._y=e.y?w.makeCalcdata(e,\"y\"):[]),p=e.x0,d=e.dx,v=e.y0,m=e.dy,y=c(S,e,_,w),(k||e.connectgaps)&&(e._emptypoints=h(y),u(y,e._emptypoints))}function E(t){M=e._input.zsmooth=e.zsmooth=!1,i.warn('cannot use zsmooth: \"fast\": '+t)}if(\"fast\"===M)if(\"log\"===_.type||\"log\"===w.type)E(\"log axis found\");else if(!T){if(r.length){var C=(r[r.length-1]-r[0])/(r.length-1),L=Math.abs(C/100);for(x=0;x<r.length-1;x++)if(Math.abs(r[x+1]-r[x]-C)>L){E(\"x scale is not linear\");break}}if(g.length&&\"fast\"===M){var P=(g[g.length-1]-g[0])/(g.length-1),O=Math.abs(P/100);for(x=0;x<g.length-1;x++)if(Math.abs(g[x+1]-g[x]-P)>O){E(\"y scale is not linear\");break}}}var z=i.maxRowLength(y),I=\"scaled\"===e.xtype?\"\":r,D=f(e,I,p,d,z,_),R=\"scaled\"===e.ytype?\"\":g,F=f(e,R,v,m,y.length,w);A||(e._extremes[_._id]=a.findExtremes(_,D),e._extremes[w._id]=a.findExtremes(w,F));var B={x:D,y:F,z:y,text:e._text||e.text,hovertext:e._hovertext||e.hovertext};if(I&&I.length===D.length-1&&(B.xCenter=I),R&&R.length===F.length-1&&(B.yCenter=R),T&&(B.xRanges=b.xRanges,B.yRanges=b.yRanges,B.pts=b.pts),k||s(t,e,{vals:y,cLetter:\"z\"}),k&&e.contours&&\"heatmap\"===e.contours.coloring){var N={type:\"contour\"===e.type?\"heatmap\":\"histogram2d\",xcalendar:e.xcalendar,ycalendar:e.ycalendar};B.xfill=f(N,I,p,d,z,_),B.yfill=f(N,R,v,m,y.length,w)}return[B]}},{\"../../components/colorscale/calc\":601,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../histogram2d/calc\":1033,\"./clean_2d_array\":1003,\"./convert_column_xyz\":1005,\"./find_empties\":1007,\"./interp2d\":1010,\"./make_bound_array\":1011}],1003:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r,o){var s,l,c,u,h,f;function p(t){if(n(t))return+t}if(e&&e.transpose){for(s=0,h=0;h<t.length;h++)s=Math.max(s,t[h].length);if(0===s)return!1;c=function(t){return t.length},u=function(t,e,r){return(t[r]||[])[e]}}else s=t.length,c=function(t,e){return t[e].length},u=function(t,e,r){return(t[e]||[])[r]};var d=function(t,e,r){return e===a||r===a?a:u(t,e,r)};function g(t){if(e&&\"carpet\"!==e.type&&\"contourcarpet\"!==e.type&&t&&\"category\"===t.type&&e[\"_\"+t._id.charAt(0)].length){var r=t._id.charAt(0),n={},o=e[\"_\"+r+\"CategoryMap\"]||e[r];for(h=0;h<o.length;h++)n[o[h]]=h;return function(e){var r=n[t._categories[e]];return r+1?r:a}}return i.identity}var v=g(r),m=g(o);o&&\"category\"===o.type&&(s=o._categories.length);var y=new Array(s);for(h=0;h<s;h++)for(l=r&&\"category\"===r.type?r._categories.length:c(t,h),y[h]=new Array(l),f=0;f<l;f++)y[h][f]=p(d(t,m(h),v(f)));return y}},{\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],1004:[function(t,e,r){\"use strict\";e.exports={min:\"zmin\",max:\"zmax\"}},{}],1005:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r,a,o,s){var l,c,u,h,f=t._length,p=e.makeCalcdata(t,a),d=r.makeCalcdata(t,o),g=t.text,v=void 0!==g&&n.isArray1D(g),m=t.hovertext,y=void 0!==m&&n.isArray1D(m),x=n.distinctVals(p),b=x.vals,_=n.distinctVals(d),w=_.vals,k=[];for(l=0;l<s.length;l++)k[l]=n.init2dArray(w.length,b.length);for(v&&(u=n.init2dArray(w.length,b.length)),y&&(h=n.init2dArray(w.length,b.length)),l=0;l<f;l++)if(p[l]!==i&&d[l]!==i){var T=n.findBin(p[l]+x.minDiff/2,b),A=n.findBin(d[l]+_.minDiff/2,w);for(c=0;c<s.length;c++){var M=t[s[c]];k[c][A][T]=M[l]}v&&(u[A][T]=g[l]),y&&(h[A][T]=m[l])}for(t[\"_\"+a]=b,t[\"_\"+o]=w,c=0;c<s.length;c++)t[\"_\"+s[c]]=k[c];v&&(t._text=u),y&&(t._hovertext=h),e&&\"category\"===e.type&&(t[\"_\"+a+\"CategoryMap\"]=b.map(function(t){return e._categories[t]})),r&&\"category\"===r.type&&(t[\"_\"+o+\"CategoryMap\"]=w.map(function(t){return r._categories[t]}))}},{\"../../constants/numerical\":695,\"../../lib\":719}],1006:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xyz_defaults\"),a=t(\"./style_defaults\"),o=t(\"../../components/colorscale/defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l)?(c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\"),a(t,e,c,l),c(\"connectgaps\",n.isArray1D(e.z)&&!1!==e.zsmooth),o(t,e,l,c,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":1001,\"./style_defaults\":1014,\"./xyz_defaults\":1015}],1007:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").maxRowLength;e.exports=function(t){var e,r,i,a,o,s,l,c,u=[],h={},f=[],p=t[0],d=[],g=[0,0,0],v=n(t);for(r=0;r<t.length;r++)for(e=d,d=p,p=t[r+1]||[],i=0;i<v;i++)void 0===d[i]&&((s=(void 0!==d[i-1]?1:0)+(void 0!==d[i+1]?1:0)+(void 0!==e[i]?1:0)+(void 0!==p[i]?1:0))?(0===r&&s++,0===i&&s++,r===t.length-1&&s++,i===d.length-1&&s++,s<4&&(h[[r,i]]=[r,i,s]),u.push([r,i,s])):f.push([r,i]));for(;f.length;){for(l={},c=!1,o=f.length-1;o>=0;o--)(s=((h[[(r=(a=f[o])[0])-1,i=a[1]]]||g)[2]+(h[[r+1,i]]||g)[2]+(h[[r,i-1]]||g)[2]+(h[[r,i+1]]||g)[2])/20)&&(l[a]=[r,i,s],f.splice(o,1),c=!0);if(!c)throw\"findEmpties iterated with no new neighbors\";for(a in l)h[a]=l[a],u.push(l[a])}return u.sort(function(t,e){return e[2]-t[2]})}},{\"../../lib\":719}],1008:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../components/colorscale\").extractOpts;e.exports=function(t,e,r,s,l,c){var u,h,f,p,d=t.cd[0],g=d.trace,v=t.xa,m=t.ya,y=d.x,x=d.y,b=d.z,_=d.xCenter,w=d.yCenter,k=d.zmask,T=g.zhoverformat,A=y,M=x;if(!1!==t.index){try{f=Math.round(t.index[1]),p=Math.round(t.index[0])}catch(e){return void i.error(\"Error hovering on heatmap, pointNumber must be [row,col], found:\",t.index)}if(f<0||f>=b[0].length||p<0||p>b.length)return}else{if(n.inbox(e-y[0],e-y[y.length-1],0)>0||n.inbox(r-x[0],r-x[x.length-1],0)>0)return;if(c){var S;for(A=[2*y[0]-y[1]],S=1;S<y.length;S++)A.push((y[S]+y[S-1])/2);for(A.push([2*y[y.length-1]-y[y.length-2]]),M=[2*x[0]-x[1]],S=1;S<x.length;S++)M.push((x[S]+x[S-1])/2);M.push([2*x[x.length-1]-x[x.length-2]])}f=Math.max(0,Math.min(A.length-2,i.findBin(e,A))),p=Math.max(0,Math.min(M.length-2,i.findBin(r,M)))}var E=v.c2p(y[f]),C=v.c2p(y[f+1]),L=m.c2p(x[p]),P=m.c2p(x[p+1]);c?(C=E,u=y[f],P=L,h=x[p]):(u=_?_[f]:(y[f]+y[f+1])/2,h=w?w[p]:(x[p]+x[p+1])/2,v&&\"category\"===v.type&&(u=y[f]),m&&\"category\"===m.type&&(h=x[p]),g.zsmooth&&(E=C=v.c2p(u),L=P=m.c2p(h)));var O,z=b[p][f];k&&!k[p][f]&&(z=void 0),Array.isArray(d.hovertext)&&Array.isArray(d.hovertext[p])?O=d.hovertext[p][f]:Array.isArray(d.text)&&Array.isArray(d.text[p])&&(O=d.text[p][f]);var I=o(g),D={type:\"linear\",range:[I.min,I.max],hoverformat:T,_separators:v._separators,_numFormat:v._numFormat},R=a.tickText(D,z,\"hover\").text;return[i.extendFlat(t,{index:[p,f],distance:t.maxHoverDistance,spikeDistance:t.maxSpikeDistance,x0:E,x1:C,y0:L,y1:P,xLabelVal:u,yLabelVal:h,zLabelVal:z,zLabel:R,text:O})]}},{\"../../components/colorscale\":605,\"../../components/fx\":632,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],1009:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:t(\"./colorbar\"),style:t(\"./style\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"heatmap\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":1001,\"./calc\":1002,\"./colorbar\":1004,\"./defaults\":1006,\"./hover\":1008,\"./plot\":1012,\"./style\":1013}],1010:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[-1,0],[1,0],[0,-1],[0,1]];function a(t){return.5-.25*Math.min(1,.5*t)}function o(t,e,r){var n,a,o,s,l,c,u,h,f,p,d,g,v,m=0;for(s=0;s<e.length;s++){for(a=(n=e[s])[0],o=n[1],d=t[a][o],p=0,f=0,l=0;l<4;l++)(u=t[a+(c=i[l])[0]])&&void 0!==(h=u[o+c[1]])&&(0===p?g=v=h:(g=Math.min(g,h),v=Math.max(v,h)),f++,p+=h);if(0===f)throw\"iterateInterp2d order is wrong: no defined neighbors\";t[a][o]=p/f,void 0===d?f<4&&(m=1):(t[a][o]=(1+r)*t[a][o]-r*d,v>g&&(m=Math.max(m,Math.abs(t[a][o]-d)/(v-g))))}return m}e.exports=function(t,e){var r,i=1;for(o(t,e),r=0;r<e.length&&!(e[r][2]<4);r++);for(e=e.slice(r),r=0;r<100&&i>.01;r++)i=o(t,e,a(i));return i>.01&&n.log(\"interp2d didn't converge quickly\",i),t}},{\"../../lib\":719}],1011:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a,o,s){var l,c,u,h=[],f=n.traceIs(t,\"contour\"),p=n.traceIs(t,\"histogram\"),d=n.traceIs(t,\"gl2d\");if(i(e)&&e.length>1&&!p&&\"category\"!==s.type){var g=e.length;if(!(g<=o))return f?e.slice(0,o):e.slice(0,o+1);if(f||d)h=e.slice(0,o);else if(1===o)h=[e[0]-.5,e[0]+.5];else{for(h=[1.5*e[0]-.5*e[1]],u=1;u<g;u++)h.push(.5*(e[u-1]+e[u]));h.push(1.5*e[g-1]-.5*e[g-2])}if(g<o){var v=h[h.length-1],m=v-h[h.length-2];for(u=g;u<o;u++)v+=m,h.push(v)}}else{var y=t[s._id.charAt(0)+\"calendar\"];if(p)l=s.r2c(r,0,y);else if(i(e)&&1===e.length)l=e[0];else if(void 0===r)l=0;else{l=(\"log\"===s.type?s.d2c:s.r2c)(r,0,y)}for(c=a||1,u=f||d?0:-.5;u<o;u++)h.push(l+c*u)}return h}},{\"../../lib\":719,\"../../registry\":847}],1012:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/colorscale\").makeColorScaleFuncFromTrace,l=t(\"../../constants/xmlns_namespaces\");function c(t,e){var r=e.length-2,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=e[n+1],s=o.constrain(n+(t-i)/(a-i)-.5,0,r),l=Math.round(s),c=Math.abs(s-l);return s&&s!==r&&c?{bin0:l,frac:c,bin1:Math.round(l+c/(s-l))}:{bin0:l,bin1:l,frac:0}}function u(t,e){var r=e.length-1,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=(t-i)/(e[n+1]-i)||0;return a<=0?{bin0:n,bin1:n,frac:0}:a<.5?{bin0:n,bin1:n+1,frac:a}:{bin0:n+1,bin1:n,frac:1-a}}function h(t,e,r){t[e]=r[0],t[e+1]=r[1],t[e+2]=r[2],t[e+3]=Math.round(255*r[3])}e.exports=function(t,e,r,f){var p=e.xaxis,d=e.yaxis;o.makeTraceGroups(f,r,\"hm\").each(function(e){var r,f,g,v,m,y,x=n.select(this),b=e[0],_=b.trace,w=b.z,k=b.x,T=b.y,A=b.xCenter,M=b.yCenter,S=a.traceIs(_,\"contour\"),E=S?\"best\":_.zsmooth,C=w.length,L=o.maxRowLength(w),P=!1,O=!1;for(y=0;void 0===r&&y<k.length-1;)r=p.c2p(k[y]),y++;for(y=k.length-1;void 0===f&&y>0;)f=p.c2p(k[y]),y--;for(f<r&&(g=f,f=r,r=g,P=!0),y=0;void 0===v&&y<T.length-1;)v=d.c2p(T[y]),y++;for(y=T.length-1;void 0===m&&y>0;)m=d.c2p(T[y]),y--;if(m<v&&(g=v,v=m,m=g,O=!0),S&&(A=k,M=T,k=b.xfill,T=b.yfill),\"fast\"!==E){var z=\"best\"===E?0:.5;r=Math.max(-z*p._length,r),f=Math.min((1+z)*p._length,f),v=Math.max(-z*d._length,v),m=Math.min((1+z)*d._length,m)}var I=Math.round(f-r),D=Math.round(m-v);if(I<=0||D<=0){x.selectAll(\"image\").data([]).exit().remove()}else{var R,F;\"fast\"===E?(R=L,F=C):(R=I,F=D);var B=document.createElement(\"canvas\");B.width=R,B.height=F;var N,j,U=B.getContext(\"2d\"),V=s(_,{noNumericCheck:!0,returnArray:!0});\"fast\"===E?(N=P?function(t){return L-1-t}:o.identity,j=O?function(t){return C-1-t}:o.identity):(N=function(t){return o.constrain(Math.round(p.c2p(k[t])-r),0,I)},j=function(t){return o.constrain(Math.round(d.c2p(T[t])-v),0,D)});var q,H,G,Y,W,X=j(0),Z=[X,X],J=P?0:1,K=O?0:1,$=0,Q=0,tt=0,et=0;if(E){var rt,nt=0;try{rt=new Uint8Array(I*D*4)}catch(t){rt=new Array(I*D*4)}if(\"best\"===E){var it,at,ot,st=A||k,lt=M||T,ct=new Array(st.length),ut=new Array(lt.length),ht=new Array(I),ft=A?u:c,pt=M?u:c;for(y=0;y<st.length;y++)ct[y]=Math.round(p.c2p(st[y])-r);for(y=0;y<lt.length;y++)ut[y]=Math.round(d.c2p(lt[y])-v);for(y=0;y<I;y++)ht[y]=ft(y,ct);for(H=0;H<D;H++)for(at=w[(it=pt(H,ut)).bin0],ot=w[it.bin1],y=0;y<I;y++,nt+=4)h(rt,nt,W=Tt(at,ot,ht[y],it))}else for(H=0;H<C;H++)for(Y=w[H],Z=j(H),y=0;y<I;y++)W=kt(Y[y],1),h(rt,nt=4*(Z*I+N(y)),W);var dt=U.createImageData(I,D);try{dt.data.set(rt)}catch(t){var gt=dt.data,vt=gt.length;for(H=0;H<vt;H++)gt[H]=rt[H]}U.putImageData(dt,0,0)}else{var mt=_.xgap,yt=_.ygap,xt=Math.floor(mt/2),bt=Math.floor(yt/2);for(H=0;H<C;H++)if(Y=w[H],Z.reverse(),Z[K]=j(H+1),Z[0]!==Z[1]&&void 0!==Z[0]&&void 0!==Z[1])for(q=[G=N(0),G],y=0;y<L;y++)q.reverse(),q[J]=N(y+1),q[0]!==q[1]&&void 0!==q[0]&&void 0!==q[1]&&(W=kt(Y[y],(q[1]-q[0])*(Z[1]-Z[0])),U.fillStyle=\"rgba(\"+W.join(\",\")+\")\",U.fillRect(q[0]+xt,Z[0]+bt,q[1]-q[0]-mt,Z[1]-Z[0]-yt))}Q=Math.round(Q/$),tt=Math.round(tt/$),et=Math.round(et/$);var _t=i(\"rgb(\"+Q+\",\"+tt+\",\"+et+\")\");t._hmpixcount=(t._hmpixcount||0)+$,t._hmlumcount=(t._hmlumcount||0)+$*_t.getLuminance();var wt=x.selectAll(\"image\").data(e);wt.enter().append(\"svg:image\").attr({xmlns:l.svg,preserveAspectRatio:\"none\"}),wt.attr({height:D,width:I,x:r,y:v,\"xlink:href\":B.toDataURL(\"image/png\")})}function kt(t,e){if(void 0!==t){var r=V(t);return r[0]=Math.round(r[0]),r[1]=Math.round(r[1]),r[2]=Math.round(r[2]),$+=e,Q+=r[0]*e,tt+=r[1]*e,et+=r[2]*e,r}return[0,0,0,0]}function Tt(t,e,r,n){var i=t[r.bin0];if(void 0===i)return kt(void 0,1);var a,o=t[r.bin1],s=e[r.bin0],l=e[r.bin1],c=o-i||0,u=s-i||0;return a=void 0===o?void 0===l?0:void 0===s?2*(l-i):2*(2*l-s-i)/3:void 0===l?void 0===s?0:2*(2*i-o-s)/3:void 0===s?2*(2*l-o-i)/3:l+i-o-s,kt(i+r.frac*c+n.frac*(u+r.frac*a))}})}},{\"../../components/colorscale\":605,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../registry\":847,d3:163,tinycolor2:537}],1013:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t){n.select(t).selectAll(\".hm image\").style(\"opacity\",function(t){return t.trace.opacity})}},{d3:163}],1014:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){!1===r(\"zsmooth\")&&(r(\"xgap\"),r(\"ygap\")),r(\"zhoverformat\")}},{}],1015:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\");function o(t,e){var r=e(t);return\"scaled\"===(r?e(t+\"type\",\"array\"):\"scaled\")&&(e(t+\"0\"),e(\"d\"+t)),r}e.exports=function(t,e,r,s,l,c){var u,h,f=r(\"z\");if(l=l||\"x\",c=c||\"y\",void 0===f||!f.length)return 0;if(i.isArray1D(t.z)){u=r(l),h=r(c);var p=i.minRowLength(u),d=i.minRowLength(h);if(0===p||0===d)return 0;e._length=Math.min(p,d,f.length)}else{if(u=o(l,r),h=o(c,r),!function(t){for(var e,r=!0,a=!1,o=!1,s=0;s<t.length;s++){if(e=t[s],!i.isArrayOrTypedArray(e)){r=!1;break}e.length>0&&(a=!0);for(var l=0;l<e.length;l++)if(n(e[l])){o=!0;break}}return r&&a&&o}(f))return 0;r(\"transpose\"),e._length=null}return a.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[l,c],s),!0}},{\"../../lib\":719,\"../../registry\":847,\"fast-isnumeric\":225}],1016:[function(t,e,r){\"use strict\";for(var n=t(\"../heatmap/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=[\"z\",\"x\",\"x0\",\"dx\",\"y\",\"y0\",\"dy\",\"text\",\"transpose\",\"xtype\",\"ytype\"],l={},c=0;c<s.length;c++){var u=s[c];l[u]=n[u]}a(l,i(\"\",{cLetter:\"z\",autoColorDflt:!1})),e.exports=o(l,\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../heatmap/attributes\":1001}],1017:[function(t,e,r){\"use strict\";var n=t(\"gl-heatmap2d\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib/str2rgbarray\");function o(t,e){this.scene=t,this.uid=e,this.type=\"heatmapgl\",this.name=\"\",this.hoverinfo=\"all\",this.xData=[],this.yData=[],this.zData=[],this.textLabels=[],this.idToIndex=[],this.bounds=[0,0,0,0],this.options={z:[],x:[],y:[],shape:[0,0],colorLevels:[0],colorValues:[0,0,0,1]},this.heatmap=n(t.glplot,this.options),this.heatmap._trace=this}var s=o.prototype;s.handlePick=function(t){var e=this.options,r=e.shape,n=t.pointId,i=n%r[0],a=Math.floor(n/r[0]),o=n;return{trace:this,dataCoord:t.dataCoord,traceCoord:[e.x[i],e.y[a],e.z[o]],textLabel:this.textLabels[n],name:this.name,pointIndex:[a,i],hoverinfo:this.hoverinfo}},s.update=function(t,e){var r=e[0];this.index=t.index,this.name=t.name,this.hoverinfo=t.hoverinfo;var n=r.z;this.options.z=[].concat.apply([],n);var o=n[0].length,s=n.length;this.options.shape=[o,s],this.options.x=r.x,this.options.y=r.y;var l=function(t){for(var e=t.colorscale,r=t.zmin,n=t.zmax,i=e.length,o=new Array(i),s=new Array(4*i),l=0;l<i;l++){var c=e[l],u=a(c[1]);o[l]=r+c[0]*(n-r);for(var h=0;h<4;h++)s[4*l+h]=u[h]}return{colorLevels:o,colorValues:s}}(t);this.options.colorLevels=l.colorLevels,this.options.colorValues=l.colorValues,this.textLabels=[].concat.apply([],t.text),this.heatmap.update(this.options);var c=this.scene.xaxis,u=this.scene.yaxis;t._extremes[c._id]=i.findExtremes(c,r.x),t._extremes[u._id]=i.findExtremes(u,r.y)},s.dispose=function(){this.heatmap.dispose()},e.exports=function(t,e,r){var n=new o(t,e.uid);return n.update(e,r),n}},{\"../../lib/str2rgbarray\":742,\"../../plots/cartesian/axes\":767,\"gl-heatmap2d\":251}],1018:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"../heatmap/defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../heatmap/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"heatmapgl\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"2dMap\"],meta:{}}},{\"../../plots/gl2d\":805,\"../heatmap/calc\":1002,\"../heatmap/colorbar\":1004,\"../heatmap/defaults\":1006,\"./attributes\":1016,\"./convert\":1017}],1019:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"./bin_attributes\"),o=t(\"./constants\"),s=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),orientation:n.orientation,histfunc:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"min\",\"max\"],dflt:\"count\",editType:\"calc\"},histnorm:{valType:\"enumerated\",values:[\"\",\"percent\",\"probability\",\"density\",\"probability density\"],dflt:\"\",editType:\"calc\"},cumulative:{enabled:{valType:\"boolean\",dflt:!1,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"increasing\",\"decreasing\"],dflt:\"increasing\",editType:\"calc\"},currentbin:{valType:\"enumerated\",values:[\"include\",\"exclude\",\"half\"],dflt:\"include\",editType:\"calc\"},editType:\"calc\"},nbinsx:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},xbins:a(\"x\",!0),nbinsy:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},ybins:a(\"y\",!0),autobinx:{valType:\"boolean\",dflt:null,editType:\"calc\"},autobiny:{valType:\"boolean\",dflt:null,editType:\"calc\"},bingroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:i({},{keys:o.eventDataKeys}),marker:n.marker,offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,_deprecated:{bardir:n._deprecated.bardir}}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../bar/attributes\":857,\"./bin_attributes\":1021,\"./constants\":1025}],1020:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=t.length,n=0,i=0;i<r;i++)e[i]?(t[i]/=e[i],n+=t[i]):t[i]=null;return n}},{}],1021:[function(t,e,r){\"use strict\";e.exports=function(t,e){return{start:{valType:\"any\",editType:\"calc\"},end:{valType:\"any\",editType:\"calc\"},size:{valType:\"any\",editType:\"calc\"},editType:\"calc\"}}},{}],1022:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports={count:function(t,e,r){return r[t]++,1},sum:function(t,e,r,i){var a=i[e];return n(a)?(a=Number(a),r[t]+=a,a):0},avg:function(t,e,r,i,a){var o=i[e];return n(o)&&(o=Number(o),r[t]+=o,a[t]++),0},min:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]>a){var o=a-r[t];return r[t]=a,o}}return 0},max:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]<a){var o=a-r[t];return r[t]=a,o}}return 0}}},{\"fast-isnumeric\":225}],1023:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.ONEAVGYEAR,a=n.ONEAVGMONTH,o=n.ONEDAY,s=n.ONEHOUR,l=n.ONEMIN,c=n.ONESEC,u=t(\"../../plots/cartesian/axes\").tickIncrement;function h(t,e,r,n){if(t*e<=0)return 1/0;for(var i=Math.abs(e-t),a=\"date\"===r.type,o=f(i,a),s=0;s<10;s++){var l=f(80*o,a);if(o===l)break;if(!p(l,t,e,a,r,n))break;o=l}return o}function f(t,e){return e&&t>c?t>o?t>1.1*i?i:t>1.1*a?a:o:t>s?s:t>l?l:c:Math.pow(10,Math.floor(Math.log(t)/Math.LN10))}function p(t,e,r,n,a,s){if(n&&t>o){var l=d(e,a,s),c=d(r,a,s),u=t===i?0:1;return l[u]!==c[u]}return Math.floor(r/t)-Math.floor(e/t)>.1}function d(t,e,r){var n=e.c2d(t,i,r).split(\"-\");return\"\"===n[0]&&(n.unshift(),n[0]=\"-\"+n[0]),n}e.exports=function(t,e,r,n,a){var s,l,c=-1.1*e,f=-.1*e,p=t-f,d=r[0],g=r[1],v=Math.min(h(d+f,d+p,n,a),h(g+f,g+p,n,a)),m=Math.min(h(d+c,d+f,n,a),h(g+c,g+f,n,a));if(v>m&&m<Math.abs(g-d)/4e3?(s=v,l=!1):(s=Math.min(v,m),l=!0),\"date\"===n.type&&s>o){var y=s===i?1:6,x=s===i?\"M12\":\"M1\";return function(e,r){var o=n.c2d(e,i,a),s=o.indexOf(\"-\",y);s>0&&(o=o.substr(0,s));var c=n.d2c(o,0,a);if(c<e){var h=u(c,x,!1,a);(c+h)/2<e+t&&(c=h)}return r&&l?u(c,x,!0,a):c}}return function(e,r){var n=s*Math.round(e/s);return n+s/10<e&&n+.9*s<e+t&&(n+=s),r&&l&&(n-=s),n}}},{\"../../constants/numerical\":695,\"../../plots/cartesian/axes\":767}],1024:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../bar/arrays_to_calcdata\"),l=t(\"./bin_functions\"),c=t(\"./norm_functions\"),u=t(\"./average\"),h=t(\"./bin_label_vals\");function f(t,e,r,s,l){var c,u,h,p,d,g,v,m=s+\"bins\",y=t._fullLayout,x=e[\"_\"+s+\"bingroup\"],b=y._histogramBinOpts[x],_=\"overlay\"===y.barmode,w=function(t){return r.r2c(t,0,p)},k=function(t){return r.c2r(t,0,p)},T=\"date\"===r.type?function(t){return t||0===t?i.cleanDate(t,null,p):null}:function(t){return n(t)?Number(t):null};function A(t,e,r){e[t+\"Found\"]?(e[t]=T(e[t]),null===e[t]&&(e[t]=r[t])):(g[t]=e[t]=r[t],i.nestedProperty(u[0],m+\".\"+t).set(r[t]))}if(e[\"_\"+s+\"autoBinFinished\"])delete e[\"_\"+s+\"autoBinFinished\"];else{u=b.traces;var M=[],S=!0,E=!1,C=!1;for(c=0;c<u.length;c++)if((h=u[c]).visible){var L=b.dirs[c];d=h[\"_\"+L+\"pos0\"]=r.makeCalcdata(h,L),M=i.concat(M,d),delete h[\"_\"+s+\"autoBinFinished\"],!0===e.visible&&(S?S=!1:(delete h._autoBin,h[\"_\"+s+\"autoBinFinished\"]=1),a.traceIs(h,\"2dMap\")&&(E=!0),\"histogram2dcontour\"===h.type&&(C=!0))}p=u[0][s+\"calendar\"];var P=o.autoBin(M,r,b.nbins,E,p,b.sizeFound&&b.size),O=u[0]._autoBin={};if(g=O[b.dirs[0]]={},C&&(b.size||(P.start=k(o.tickIncrement(w(P.start),P.size,!0,p))),void 0===b.end&&(P.end=k(o.tickIncrement(w(P.end),P.size,!1,p)))),_&&!a.traceIs(e,\"2dMap\")&&0===P._dataSpan&&\"category\"!==r.type&&\"multicategory\"!==r.type){if(l)return[P,d,!0];P=function(t,e,r,n,a){var o,s,l,c=t._fullLayout,u=function(t,e){for(var r=e.xaxis,n=e.yaxis,i=e.orientation,a=[],o=t._fullData,s=0;s<o.length;s++){var l=o[s];\"histogram\"===l.type&&!0===l.visible&&l.orientation===i&&l.xaxis===r&&l.yaxis===n&&a.push(l)}return a}(t,e),h=!1,p=1/0,d=[e];for(o=0;o<u.length;o++)if((s=u[o])===e)h=!0;else if(h){var g=f(t,s,r,n,!0),v=g[0],m=g[2];s[\"_\"+n+\"autoBinFinished\"]=1,s[\"_\"+n+\"pos0\"]=g[1],m?d.push(s):p=Math.min(p,v.size)}else l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]],p=Math.min(p,l.size||s[a].size);var y=new Array(d.length);for(o=0;o<d.length;o++)for(var x=d[o][\"_\"+n+\"pos0\"],b=0;b<x.length;b++)if(void 0!==x[b]){y[o]=x[b];break}isFinite(p)||(p=i.distinctVals(y).minDiff);for(o=0;o<d.length;o++){var _=(s=d[o])[n+\"calendar\"],w={start:r.c2r(y[o]-p/2,0,_),end:r.c2r(y[o]+p/2,0,_),size:p};s._input[a]=s[a]=w,(l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]])&&i.extendFlat(l,w)}return e[a]}(t,e,r,s,m)}(v=h.cumulative||{}).enabled&&\"include\"!==v.currentbin&&(\"decreasing\"===v.direction?P.start=k(o.tickIncrement(w(P.start),P.size,!0,p)):P.end=k(o.tickIncrement(w(P.end),P.size,!1,p))),b.size=P.size,b.sizeFound||(g.size=P.size,i.nestedProperty(u[0],m+\".size\").set(P.size)),A(\"start\",b,P),A(\"end\",b,P)}d=e[\"_\"+s+\"pos0\"],delete e[\"_\"+s+\"pos0\"];var z=e._input[m]||{},I=i.extendFlat({},b),D=b.start,R=r.r2l(z.start),F=void 0!==R;if((b.startFound||F)&&R!==r.r2l(D)){var B=F?R:i.aggNums(Math.min,null,d),N={type:\"category\"===r.type||\"multicategory\"===r.type?\"linear\":r.type,r2l:r.r2l,dtick:b.size,tick0:D,calendar:p,range:[B,o.tickIncrement(B,b.size,!1,p)].map(r.l2r)},j=o.tickFirst(N);j>r.r2l(B)&&(j=o.tickIncrement(j,b.size,!0,p)),I.start=r.l2r(j),F||i.nestedProperty(e,m+\".start\").set(I.start)}var U=b.end,V=r.r2l(z.end),q=void 0!==V;if((b.endFound||q)&&V!==r.r2l(U)){var H=q?V:i.aggNums(Math.max,null,d);I.end=r.l2r(H),q||i.nestedProperty(e,m+\".start\").set(I.end)}var G=\"autobin\"+s;return!1===e._input[G]&&(e._input[m]=i.extendFlat({},e[m]||{}),delete e._input[G],delete e[G]),[I,d]}e.exports={calc:function(t,e){var r,a,p,d,g=[],v=[],m=o.getFromId(t,\"h\"===e.orientation?e.yaxis:e.xaxis),y=\"h\"===e.orientation?\"y\":\"x\",x={x:\"y\",y:\"x\"}[y],b=e[y+\"calendar\"],_=e.cumulative,w=f(t,e,m,y),k=w[0],T=w[1],A=\"string\"==typeof k.size,M=[],S=A?M:k,E=[],C=[],L=[],P=0,O=e.histnorm,z=e.histfunc,I=-1!==O.indexOf(\"density\");_.enabled&&I&&(O=O.replace(/ ?density$/,\"\"),I=!1);var D,R=\"max\"===z||\"min\"===z?null:0,F=l.count,B=c[O],N=!1,j=function(t){return m.r2c(t,0,b)};for(i.isArrayOrTypedArray(e[x])&&\"count\"!==z&&(D=e[x],N=\"avg\"===z,F=l[z]),r=j(k.start),p=j(k.end)+(r-o.tickIncrement(r,k.size,!1,b))/1e6;r<p&&g.length<1e6&&(a=o.tickIncrement(r,k.size,!1,b),g.push((r+a)/2),v.push(R),L.push([]),M.push(r),I&&E.push(1/(a-r)),N&&C.push(0),!(a<=r));)r=a;M.push(r),A||\"date\"!==m.type||(S={start:j(S.start),end:j(S.end),size:S.size});var U,V=v.length,q=!0,H=1/0,G=1/0,Y={};for(r=0;r<T.length;r++){var W=T[r];(d=i.findBin(W,S))>=0&&d<V&&(P+=F(d,r,v,D,C),q&&L[d].length&&W!==T[L[d][0]]&&(q=!1),L[d].push(r),Y[r]=d,H=Math.min(H,W-M[d]),G=Math.min(G,M[d+1]-W))}q||(U=h(H,G,M,m,b)),N&&(P=u(v,C)),B&&B(v,P,E),_.enabled&&function(t,e,r){var n,i,a;function o(e){a=t[e],t[e]/=2}function s(e){i=t[e],t[e]=a+i/2,a+=i}if(\"half\"===r)if(\"increasing\"===e)for(o(0),n=1;n<t.length;n++)s(n);else for(o(t.length-1),n=t.length-2;n>=0;n--)s(n);else if(\"increasing\"===e){for(n=1;n<t.length;n++)t[n]+=t[n-1];\"exclude\"===r&&(t.unshift(0),t.pop())}else{for(n=t.length-2;n>=0;n--)t[n]+=t[n+1];\"exclude\"===r&&(t.push(0),t.shift())}}(v,_.direction,_.currentbin);var X=Math.min(g.length,v.length),Z=[],J=0,K=X-1;for(r=0;r<X;r++)if(v[r]){J=r;break}for(r=X-1;r>=J;r--)if(v[r]){K=r;break}for(r=J;r<=K;r++)if(n(g[r])&&n(v[r])){var $={p:g[r],s:v[r],b:0};_.enabled||($.pts=L[r],q?$.ph0=$.ph1=L[r].length?T[L[r][0]]:g[r]:($.ph0=U(M[r]),$.ph1=U(M[r+1],!0))),Z.push($)}return 1===Z.length&&(Z[0].width1=o.tickIncrement(Z[0].p,k.size,!1,b)-Z[0].p),s(Z,e),i.isArrayOrTypedArray(e.selectedpoints)&&i.tagSelected(Z,e,Y),Z},calcAllAutoBins:f}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../bar/arrays_to_calcdata\":856,\"./average\":1020,\"./bin_functions\":1022,\"./bin_label_vals\":1023,\"./norm_functions\":1031,\"fast-isnumeric\":225}],1025:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"binNumber\"]}},{}],1026:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../../registry\").traceIs,o=t(\"../bar/defaults\").handleGroupingDefaults,s=n.nestedProperty,l=i.getAxisGroup,c=[{aStr:{x:\"xbins.start\",y:\"ybins.start\"},name:\"start\"},{aStr:{x:\"xbins.end\",y:\"ybins.end\"},name:\"end\"},{aStr:{x:\"xbins.size\",y:\"ybins.size\"},name:\"size\"},{aStr:{x:\"nbinsx\",y:\"nbinsy\"},name:\"nbins\"}],u=[\"x\",\"y\"];e.exports=function(t,e){var r,h,f,p,d,g,v,m=e._histogramBinOpts={},y=[],x={},b=[];function _(t,e){return n.coerce(r._input,r,r._module.attributes,t,e)}function w(t){return\"v\"===t.orientation?\"x\":\"y\"}function k(t,r,a){var o=t.uid+\"__\"+a;r||(r=o);var s=function(t,r){return i.getFromTrace({_fullLayout:e},t,r).type}(t,a),l=t[a+\"calendar\"],c=m[r],u=!0;c&&(s===c.axType&&l===c.calendar?(u=!1,c.traces.push(t),c.dirs.push(a)):(r=o,s!==c.axType&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set on a\",\"type:\"+s,\"axis\",\"with bins on\",\"type:\"+c.axType,\"axis.\"].join(\" \")),l!==c.calendar&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set with a\",l,\"calendar\",\"with bins\",c.calendar?\"on a \"+c.calendar+\" calendar\":\"w/o a set calendar\"].join(\" \")))),u&&(m[r]={traces:[t],dirs:[a],axType:s,calendar:t[a+\"calendar\"]||\"\"}),t[\"_\"+a+\"bingroup\"]=r}for(d=0;d<t.length;d++)r=t[d],a(r,\"histogram\")&&(y.push(r),delete r._xautoBinFinished,delete r._yautoBinFinished,a(r,\"2dMap\")||o(r._input,r,e,_));var T=e._alignmentOpts||{};for(d=0;d<y.length;d++){if(r=y[d],f=\"\",!a(r,\"2dMap\")){if(p=w(r),\"group\"===e.barmode&&r.alignmentgroup){var A=r[p+\"axis\"],M=l(e,A)+r.orientation;(T[M]||{})[r.alignmentgroup]&&(f=M)}f||\"overlay\"===e.barmode||(f=l(e,r.xaxis)+l(e,r.yaxis)+w(r))}f?(x[f]||(x[f]=[]),x[f].push(r)):b.push(r)}for(f in x)if(1!==(h=x[f]).length){var S=!1;for(d=0;d<h.length;d++){r=h[d],S=_(\"bingroup\");break}for(f=S||f,d=0;d<h.length;d++){var E=(r=h[d])._input.bingroup;E&&E!==f&&n.warn([\"Trace\",r.index,\"must match\",\"within bingroup\",f+\".\",\"Ignoring its bingroup:\",E,\"setting.\"].join(\" \")),r.bingroup=f,k(r,f,w(r))}}else b.push(h[0]);for(d=0;d<b.length;d++){r=b[d];var C=_(\"bingroup\");if(a(r,\"2dMap\"))for(v=0;v<2;v++){var L=_((p=u[v])+\"bingroup\",C?C+\"__\"+p:null);k(r,L,p)}else k(r,C,w(r))}for(f in m){var P=m[f];for(h=P.traces,g=0;g<c.length;g++){var O,z,I=c[g],D=I.name;if(\"nbins\"!==D||!P.sizeFound){for(d=0;d<h.length;d++){if(r=h[d],p=P.dirs[d],O=I.aStr[p],void 0!==s(r._input,O).get()){P[D]=_(O),P[D+\"Found\"]=!0;break}(z=(r._autoBin||{})[p]||{})[D]&&s(r,O).set(z[D])}if(\"start\"===D||\"end\"===D)for(;d<h.length;d++)(r=h[d])[\"_\"+p+\"bingroup\"]&&_(O,(z=(r._autoBin||{})[p]||{})[D]);\"nbins\"!==D||P.sizeFound||P.nbinsFound||(r=h[0],P[D]=_(O))}}}}},{\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../bar/defaults\":861}],1027:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../bar/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,n){return i.coerce(t,e,s,r,n)}var u=c(\"x\"),h=c(\"y\");c(\"cumulative.enabled\")&&(c(\"cumulative.direction\"),c(\"cumulative.currentbin\")),c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\");var f=c(\"orientation\",h&&!u?\"h\":\"v\"),p=\"v\"===f?\"x\":\"y\",d=\"v\"===f?\"y\":\"x\",g=u&&h?Math.min(i.minRowLength(u)&&i.minRowLength(h)):i.minRowLength(e[p]||[]);if(g){e._length=g,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],l),e[d]&&c(\"histfunc\"),c(\"histnorm\"),c(\"autobin\"+p),o(t,e,c,r,l),i.coerceSelectionMarkerOpacity(e,c);var v=(e.marker.line||{}).color,m=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");m(t,e,v||a.defaultLine,{axis:\"y\"}),m(t,e,v||a.defaultLine,{axis:\"x\",inherit:\"y\"})}else e.visible=!1}},{\"../../components/color\":593,\"../../lib\":719,\"../../registry\":847,\"../bar/style_defaults\":871,\"./attributes\":1019}],1028:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"zLabelVal\"in e&&(t.z=e.zLabelVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),!(r.cumulative||{}).enabled){var a,o=Array.isArray(i)?n[0].pts[i[0]][i[1]]:n[i].pts;if(t.pointNumbers=o,t.binNumber=t.pointNumber,delete t.pointNumber,delete t.pointIndex,r._indexToPoints){a=[];for(var s=0;s<o.length;s++)a=a.concat(r._indexToPoints[o[s]])}else a=o;t.pointIndices=a}return t}},{}],1029:[function(t,e,r){\"use strict\";var n=t(\"../bar/hover\").hoverPoints,i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o){var s=(t=o[0]).cd[t.index],l=t.cd[0].trace;if(!l.cumulative.enabled){var c=\"h\"===l.orientation?\"y\":\"x\";t[c+\"Label\"]=i(t[c+\"a\"],s.ph0,s.ph1)}return l.hovermplate&&(t.hovertemplate=l.hovertemplate),o}}},{\"../../plots/cartesian/axes\":767,\"../bar/hover\":863}],1030:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"../bar/layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),supplyLayoutDefaults:t(\"../bar/layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"../bar/cross_trace_calc\").crossTraceCalc,plot:t(\"../bar/plot\").plot,layerName:\"barlayer\",style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,colorbar:t(\"../scatter/marker_colorbar\"),hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"histogram\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"histogram\",\"oriented\",\"errorBarsOK\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":778,\"../bar/cross_trace_calc\":860,\"../bar/layout_attributes\":865,\"../bar/layout_defaults\":866,\"../bar/plot\":867,\"../bar/select\":868,\"../bar/style\":870,\"../scatter/marker_colorbar\":1129,\"./attributes\":1019,\"./calc\":1024,\"./cross_trace_defaults\":1026,\"./defaults\":1027,\"./event_data\":1028,\"./hover\":1029}],1031:[function(t,e,r){\"use strict\";e.exports={percent:function(t,e){for(var r=t.length,n=100/e,i=0;i<r;i++)t[i]*=n},probability:function(t,e){for(var r=t.length,n=0;n<r;n++)t[n]/=e},density:function(t,e,r,n){var i=t.length;n=n||1;for(var a=0;a<i;a++)t[a]*=r[a]*n},\"probability density\":function(t,e,r,n){var i=t.length;n&&(e/=n);for(var a=0;a<i;a++)t[a]*=r[a]/e}}},{}],1032:[function(t,e,r){\"use strict\";var n=t(\"../histogram/attributes\"),i=t(\"../histogram/bin_attributes\"),a=t(\"../heatmap/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../lib/extend\").extendFlat;e.exports=l({x:n.x,y:n.y,z:{valType:\"data_array\",editType:\"calc\"},marker:{color:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:i(\"x\"),nbinsy:n.nbinsy,ybins:i(\"y\"),autobinx:n.autobinx,autobiny:n.autobiny,bingroup:l({},n.bingroup,{}),xbingroup:l({},n.bingroup,{}),ybingroup:l({},n.bingroup,{}),xgap:a.xgap,ygap:a.ygap,zsmooth:a.zsmooth,zhoverformat:a.zhoverformat,hovertemplate:o({},{keys:\"z\"})},s(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../heatmap/attributes\":1001,\"../histogram/attributes\":1019,\"../histogram/bin_attributes\":1021}],1033:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../histogram/bin_functions\"),o=t(\"../histogram/norm_functions\"),s=t(\"../histogram/average\"),l=t(\"../histogram/bin_label_vals\"),c=t(\"../histogram/calc\").calcAllAutoBins;function u(t,e,r,n){var i,a=new Array(t);if(n)for(i=0;i<t;i++)a[i]=1/(e[i+1]-e[i]);else{var o=1/r;for(i=0;i<t;i++)a[i]=o}return a}function h(t,e){return{start:t(e.start),end:t(e.end),size:e.size}}function f(t,e,r,n,i,a){var o,s=t.length-1,c=new Array(s),u=l(r,n,t,i,a);for(o=0;o<s;o++){var h=(e||[])[o];c[o]=void 0===h?[u(t[o]),u(t[o+1],!0)]:[h,h]}return c}e.exports=function(t,e){var r,l,p,d,g=i.getFromId(t,e.xaxis),v=i.getFromId(t,e.yaxis),m=e.xcalendar,y=e.ycalendar,x=function(t){return g.r2c(t,0,m)},b=function(t){return v.r2c(t,0,y)},_=c(t,e,g,\"x\"),w=_[0],k=_[1],T=c(t,e,v,\"y\"),A=T[0],M=T[1],S=e._length;k.length>S&&k.splice(S,k.length-S),M.length>S&&M.splice(S,M.length-S);var E=[],C=[],L=[],P=\"string\"==typeof w.size,O=\"string\"==typeof A.size,z=[],I=[],D=P?z:w,R=O?I:A,F=0,B=[],N=[],j=e.histnorm,U=e.histfunc,V=-1!==j.indexOf(\"density\"),q=\"max\"===U||\"min\"===U?null:0,H=a.count,G=o[j],Y=!1,W=[],X=[],Z=\"z\"in e?e.z:\"marker\"in e&&Array.isArray(e.marker.color)?e.marker.color:\"\";Z&&\"count\"!==U&&(Y=\"avg\"===U,H=a[U]);var J=w.size,K=x(w.start),$=x(w.end)+(K-i.tickIncrement(K,J,!1,m))/1e6;for(r=K;r<$;r=i.tickIncrement(r,J,!1,m))C.push(q),z.push(r),Y&&L.push(0);z.push(r);var Q,tt=C.length,et=(r-K)/tt,rt=(Q=K+et/2,g.c2r(Q,0,m)),nt=A.size,it=b(A.start),at=b(A.end)+(it-i.tickIncrement(it,nt,!1,y))/1e6;for(r=it;r<at;r=i.tickIncrement(r,nt,!1,y)){E.push(C.slice()),I.push(r);var ot=new Array(tt);for(l=0;l<tt;l++)ot[l]=[];N.push(ot),Y&&B.push(L.slice())}I.push(r);var st=E.length,lt=(r-it)/st,ct=function(t){return v.c2r(t,0,y)}(it+lt/2);V&&(W=u(C.length,D,et,P),X=u(E.length,R,lt,O)),P||\"date\"!==g.type||(D=h(x,D)),O||\"date\"!==v.type||(R=h(b,R));var ut=!0,ht=!0,ft=new Array(tt),pt=new Array(st),dt=1/0,gt=1/0,vt=1/0,mt=1/0;for(r=0;r<S;r++){var yt=k[r],xt=M[r];p=n.findBin(yt,D),d=n.findBin(xt,R),p>=0&&p<tt&&d>=0&&d<st&&(F+=H(p,r,E[d],Z,B[d]),N[d][p].push(r),ut&&(void 0===ft[p]?ft[p]=yt:ft[p]!==yt&&(ut=!1)),ht&&(void 0===pt[d]?pt[d]=xt:pt[d]!==xt&&(ht=!1)),dt=Math.min(dt,yt-z[p]),gt=Math.min(gt,z[p+1]-yt),vt=Math.min(vt,xt-I[d]),mt=Math.min(mt,I[d+1]-xt))}if(Y)for(d=0;d<st;d++)F+=s(E[d],B[d]);if(G)for(d=0;d<st;d++)G(E[d],F,W,X[d]);return{x:k,xRanges:f(z,ut&&ft,dt,gt,g,m),x0:rt,dx:et,y:M,yRanges:f(I,ht&&pt,vt,mt,v,y),y0:ct,dy:lt,z:E,pts:N}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../histogram/average\":1020,\"../histogram/bin_functions\":1022,\"../histogram/bin_label_vals\":1023,\"../histogram/calc\":1024,\"../histogram/norm_functions\":1031}],1034:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./sample_defaults\"),a=t(\"../heatmap/style_defaults\"),o=t(\"../../components/colorscale/defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,l),o(t,e,l,c,{prefix:\"\",cLetter:\"z\"}),c(\"hovertemplate\"))}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../heatmap/style_defaults\":1014,\"./attributes\":1032,\"./sample_defaults\":1037}],1035:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/hover\"),i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a,o,s){var l=n(t,e,r,a,o,s);if(l){var c=(t=l[0]).index,u=c[0],h=c[1],f=t.cd[0],p=f.xRanges[h],d=f.yRanges[u];return t.xLabel=i(t.xa,p[0],p[1]),t.yLabel=i(t.ya,d[0],d[1]),l}}},{\"../../plots/cartesian/axes\":767,\"../heatmap/hover\":1008}],1036:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../heatmap/calc\"),plot:t(\"../heatmap/plot\"),layerName:\"heatmaplayer\",colorbar:t(\"../heatmap/colorbar\"),style:t(\"../heatmap/style\"),hoverPoints:t(\"./hover\"),eventData:t(\"../histogram/event_data\"),moduleType:\"trace\",name:\"histogram2d\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"histogram\"],meta:{}}},{\"../../plots/cartesian\":778,\"../heatmap/calc\":1002,\"../heatmap/colorbar\":1004,\"../heatmap/plot\":1012,\"../heatmap/style\":1013,\"../histogram/cross_trace_defaults\":1026,\"../histogram/event_data\":1028,\"./attributes\":1032,\"./defaults\":1034,\"./hover\":1035}],1037:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"y\"),l=i.minRowLength(o),c=i.minRowLength(s);l&&c?(e._length=Math.min(l,c),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a),(r(\"z\")||r(\"marker.color\"))&&r(\"histfunc\"),r(\"histnorm\"),r(\"autobinx\"),r(\"autobiny\")):e.visible=!1}},{\"../../lib\":719,\"../../registry\":847}],1038:[function(t,e,r){\"use strict\";var n=t(\"../histogram2d/attributes\"),i=t(\"../contour/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat;e.exports=o({x:n.x,y:n.y,z:n.z,marker:n.marker,histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:n.xbins,nbinsy:n.nbinsy,ybins:n.ybins,autobinx:n.autobinx,autobiny:n.autobiny,bingroup:n.bingroup,xbingroup:n.xbingroup,ybingroup:n.ybingroup,autocontour:i.autocontour,ncontours:i.ncontours,contours:i.contours,line:i.line,zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../contour/attributes\":942,\"../histogram2d/attributes\":1032}],1039:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../histogram2d/sample_defaults\"),a=t(\"../contour/contours_defaults\"),o=t(\"../contour/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,function(r){return n.coerce2(t,e,s,r)}),o(t,e,c,l),c(\"hovertemplate\"))}},{\"../../lib\":719,\"../contour/contours_defaults\":949,\"../contour/style_defaults\":963,\"../histogram2d/sample_defaults\":1037,\"./attributes\":1038}],1040:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../contour/calc\"),plot:t(\"../contour/plot\").plot,layerName:\"contourlayer\",style:t(\"../contour/style\"),colorbar:t(\"../contour/colorbar\"),hoverPoints:t(\"../contour/hover\"),moduleType:\"trace\",name:\"histogram2dcontour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"histogram\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":778,\"../contour/calc\":943,\"../contour/colorbar\":945,\"../contour/hover\":955,\"../contour/plot\":960,\"../contour/style\":962,\"../histogram/cross_trace_defaults\":1026,\"./attributes\":1038,\"./defaults\":1039}],1041:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../lib/extend\").extendDeep,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../components/color/attributes\"),l=t(\"../../plots/domain\").attributes,c=t(\"../../plots/cartesian/layout_attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,h=t(\"../../constants/delta.js\"),f=(t(\"../../constants/docs\").FORMAT_LINK,o({editType:\"plot\",colorEditType:\"plot\"})),p={color:{valType:\"color\",editType:\"plot\"},line:{color:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},width:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"calc\"},thickness:{valType:\"number\",min:0,max:1,dflt:1,editType:\"plot\"},editType:\"calc\"},d={valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},g=u(\"steps\",i({},p,{range:d}));e.exports={mode:{valType:\"flaglist\",editType:\"calc\",flags:[\"number\",\"delta\",\"gauge\"],dflt:\"number\"},value:{valType:\"number\",editType:\"calc\",anim:!0},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},domain:l({name:\"indicator\",trace:!0,editType:\"calc\"}),title:{text:{valType:\"string\",editType:\"plot\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},font:n({},f,{}),editType:\"plot\"},number:{valueformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:n({},f,{}),prefix:{valType:\"string\",dflt:\"\",editType:\"plot\"},suffix:{valType:\"string\",dflt:\"\",editType:\"plot\"},editType:\"plot\"},delta:{reference:{valType:\"number\",editType:\"calc\"},position:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],dflt:\"bottom\",editType:\"plot\"},relative:{valType:\"boolean\",editType:\"plot\",dflt:!1},valueformat:{valType:\"string\",editType:\"plot\"},increasing:{symbol:{valType:\"string\",dflt:h.INCREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:h.INCREASING.COLOR,editType:\"plot\"},editType:\"plot\"},decreasing:{symbol:{valType:\"string\",dflt:h.DECREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:h.DECREASING.COLOR,editType:\"plot\"},editType:\"plot\"},font:n({},f,{}),editType:\"calc\"},gauge:{shape:{valType:\"enumerated\",editType:\"plot\",dflt:\"angular\",values:[\"angular\",\"bullet\"]},bar:i({},p,{color:{dflt:\"green\"}}),bgcolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},axis:a({range:d,visible:n({},c.visible,{dflt:!0}),tickmode:c.tickmode,nticks:c.nticks,tick0:c.tick0,dtick:c.dtick,tickvals:c.tickvals,ticktext:c.ticktext,ticks:n({},c.ticks,{dflt:\"outside\"}),ticklen:c.ticklen,tickwidth:c.tickwidth,tickcolor:c.tickcolor,showticklabels:c.showticklabels,tickfont:o({}),tickangle:c.tickangle,tickformat:c.tickformat,tickformatstops:c.tickformatstops,tickprefix:c.tickprefix,showtickprefix:c.showtickprefix,ticksuffix:c.ticksuffix,showticksuffix:c.showticksuffix,separatethousands:c.separatethousands,exponentformat:c.exponentformat,showexponent:c.showexponent,editType:\"plot\"},\"plot\"),steps:g,threshold:{line:{color:n({},p.line.color,{}),width:n({},p.line.width,{dflt:1}),editType:\"plot\"},thickness:n({},p.thickness,{dflt:.85}),value:{valType:\"number\",editType:\"calc\",dflt:!1},editType:\"plot\"},editType:\"plot\"}}},{\"../../components/color/attributes\":592,\"../../constants/delta.js\":689,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1042:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=r.name=\"indicator\";r.plot=function(t,e,r,o){var s=n.getModule(a),l=i(t.calcdata,s)[0];s.plot(t,l,r,o)},r.clean=function(t,e,r,n){var i=n._has&&n._has(a),o=e._has&&e._has(a);i&&!o&&n._indicatorlayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],1043:[function(t,e,r){\"use strict\";e.exports={calc:function(t,e){var r=[],n=e.value;\"number\"!=typeof e._lastValue&&(e._lastValue=e.value);var i=e._lastValue,a=i;return e._hasDelta&&\"number\"==typeof e.delta.reference&&(a=e.delta.reference),r[0]={y:n,lastY:i,delta:n-a,relativeDelta:(n-a)/a},r}}},{}],1044:[function(t,e,r){\"use strict\";e.exports={defaultNumberFontSize:80,bulletNumberDomainSize:.25,bulletPadding:.025,innerRadius:.75,valueThickness:.5,titlePadding:5,horizontalPadding:10}},{}],1045:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../../plot_api/plot_template\"),s=t(\"../../plots/array_container_defaults\"),l=t(\"./constants.js\"),c=t(\"../../plots/cartesian/tick_value_defaults\"),u=t(\"../../plots/cartesian/tick_mark_defaults\"),h=t(\"../../plots/cartesian/tick_label_defaults\");function f(t,e){function r(r,a){return n.coerce(t,e,i.gauge.steps,r,a)}r(\"color\"),r(\"line.color\"),r(\"line.width\"),r(\"range\"),r(\"thickness\")}e.exports={supplyDefaults:function(t,e,r,p){function d(r,a){return n.coerce(t,e,i,r,a)}a(e,p,d),d(\"mode\"),e._hasNumber=-1!==e.mode.indexOf(\"number\"),e._hasDelta=-1!==e.mode.indexOf(\"delta\"),e._hasGauge=-1!==e.mode.indexOf(\"gauge\");var g=d(\"value\");e._range=[0,\"number\"==typeof g?1.5*g:1];var v,m,y,x,b,_,w=new Array(2);function k(t,e){return n.coerce(y,x,i.gauge,t,e)}function T(t,e){return n.coerce(b,_,i.gauge.axis,t,e)}if(e._hasNumber&&(d(\"number.valueformat\"),d(\"number.font.color\",p.font.color),d(\"number.font.family\",p.font.family),d(\"number.font.size\"),void 0===e.number.font.size&&(e.number.font.size=l.defaultNumberFontSize,w[0]=!0),d(\"number.prefix\"),d(\"number.suffix\"),v=e.number.font.size),e._hasDelta&&(d(\"delta.font.color\",p.font.color),d(\"delta.font.family\",p.font.family),d(\"delta.font.size\"),void 0===e.delta.font.size&&(e.delta.font.size=(e._hasNumber?.5:1)*(v||l.defaultNumberFontSize),w[1]=!0),d(\"delta.reference\",e.value),d(\"delta.relative\"),d(\"delta.valueformat\",e.delta.relative?\"2%\":\"\"),d(\"delta.increasing.symbol\"),d(\"delta.increasing.color\"),d(\"delta.decreasing.symbol\"),d(\"delta.decreasing.color\"),d(\"delta.position\"),m=e.delta.font.size),e._scaleNumbers=(!e._hasNumber||w[0])&&(!e._hasDelta||w[1])||!1,d(\"title.font.color\",p.font.color),d(\"title.font.family\",p.font.family),d(\"title.font.size\",.25*(v||m||l.defaultNumberFontSize)),d(\"title.text\"),e._hasGauge){(y=t.gauge)||(y={}),x=o.newContainer(e,\"gauge\"),k(\"shape\"),(e._isBullet=\"bullet\"===e.gauge.shape)||d(\"title.align\",\"center\"),(e._isAngular=\"angular\"===e.gauge.shape)||d(\"align\",\"center\"),k(\"bgcolor\",p.paper_bgcolor),k(\"borderwidth\"),k(\"bordercolor\"),k(\"bar.color\"),k(\"bar.line.color\"),k(\"bar.line.width\"),k(\"bar.thickness\",l.valueThickness*(\"bullet\"===e.gauge.shape?.5:1)),s(y,x,{name:\"steps\",handleItemDefaults:f}),k(\"threshold.value\"),k(\"threshold.thickness\"),k(\"threshold.line.width\"),k(\"threshold.line.color\"),b={},y&&(b=y.axis||{}),_=o.newContainer(x,\"axis\"),T(\"visible\"),e._range=T(\"range\",e._range);var A={outerTicks:!0};c(b,_,T,\"linear\"),h(b,_,T,\"linear\",A),u(b,_,T,A)}else d(\"title.align\",\"center\"),d(\"align\",\"center\"),e._isAngular=e._isBullet=!1;e._length=null}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/tick_label_defaults\":786,\"../../plots/cartesian/tick_mark_defaults\":787,\"../../plots/cartesian/tick_value_defaults\":788,\"../../plots/domain\":792,\"./attributes\":1041,\"./constants.js\":1044}],1046:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"indicator\",basePlotModule:t(\"./base_plot\"),categories:[\"svg\",\"noOpacity\",\"noHover\"],animatable:!0,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\").calc,plot:t(\"./plot\"),meta:{}}},{\"./attributes\":1041,\"./base_plot\":1042,\"./calc\":1043,\"./defaults\":1045,\"./plot\":1047}],1047:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=i.rad2deg,o=t(\"../../constants/alignment\").MID_SHIFT,s=t(\"../../components/drawing\"),l=t(\"./constants\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"../../plots/cartesian/axes\"),h=t(\"../../plots/cartesian/axis_defaults\"),f=t(\"../../plots/cartesian/position_defaults\"),p=t(\"../../plots/cartesian/layout_attributes\"),d=t(\"../../components/color\"),g={left:\"start\",center:\"middle\",right:\"end\"},v={left:0,center:.5,right:1},m=/[yzafpn\\xb5mkMGTPEZY]/;function y(t){return t&&t.duration>0}function x(t){t.each(function(t){d.stroke(n.select(this),t.line.color)}).each(function(t){d.fill(n.select(this),t.color)}).style(\"stroke-width\",function(t){return t.line.width})}function b(t,e,r){var n=t._fullLayout,a=i.extendFlat({type:\"linear\",ticks:\"outside\",range:r,showline:!0},e),o={type:\"linear\",_id:\"x\"+e._id},s={letter:\"x\",font:n.font,noHover:!0,noTickson:!0};function l(t,e){return i.coerce(a,o,p,t,e)}return h(a,o,l,s,n),f(a,o,l,s),o}function _(t,e){return\"translate(\"+t+\",\"+e+\")\"}function w(t,e,r){return[Math.min(e/t.width,r/t.height),t,e+\"x\"+r]}function k(t,e,r,i){var a=document.createElementNS(\"http://www.w3.org/2000/svg\",\"text\"),o=n.select(a);return o.text(t).attr(\"x\",0).attr(\"y\",0).attr(\"text-anchor\",r).attr(\"data-unformatted\",t).call(c.convertToTspans,i).call(s.font,e),s.bBox(o.node())}function T(t,e,r,n,a,o){var s=\"_cache\"+e;t[s]&&t[s].key===a||(t[s]={key:a,value:r});var l=i.aggNums(o,null,[t[s].value,n],2);return t[s].value=l,l}e.exports=function(t,e,r,h){var f,p=t._fullLayout;y(r)&&h&&(f=h()),i.makeTraceGroups(p._indicatorlayer,e,\"trace\").each(function(e){var h,A,M,S,E,C=e[0].trace,L=n.select(this),P=C._hasGauge,O=C._isAngular,z=C._isBullet,I=C.domain,D={w:p._size.w*(I.x[1]-I.x[0]),h:p._size.h*(I.y[1]-I.y[0]),l:p._size.l+p._size.w*I.x[0],r:p._size.r+p._size.w*(1-I.x[1]),t:p._size.t+p._size.h*(1-I.y[1]),b:p._size.b+p._size.h*I.y[0]},R=D.l+D.w/2,F=D.t+D.h/2,B=Math.min(D.w/2,D.h),N=l.innerRadius*B,j=C.align||\"center\";if(A=F,P){if(O&&(h=R,A=F+B/2,M=function(t){return e=t,r=.9*N,n=Math.sqrt(e.width/2*(e.width/2)+e.height*e.height),[r/n,e,r];var e,r,n}),z){var U=l.bulletPadding,V=1-l.bulletNumberDomainSize+U;h=D.l+(V+(1-V)*v[j])*D.w,M=function(t){return w(t,(l.bulletNumberDomainSize-U)*D.w,D.h)}}}else h=D.l+v[j]*D.w,M=function(t){return w(t,D.w,D.h)};!function(t,e,r,a){var o,l,h,f=r[0].trace,p=a.numbersX,x=a.numbersY,w=f.align||\"center\",A=g[w],M=a.transitionOpts,S=a.onComplete,E=i.ensureSingle(e,\"g\",\"numbers\"),C=[];f._hasNumber&&C.push(\"number\");f._hasDelta&&(C.push(\"delta\"),\"left\"===f.delta.position&&C.reverse());var L=E.selectAll(\"text\").data(C);function P(e,r,n,i){if(!e.match(\"s\")||n>=0==i>=0||r(n).slice(-1).match(m)||r(i).slice(-1).match(m))return r;var a=e.slice().replace(\"s\",\"f\").replace(/\\d+/,function(t){return parseInt(t)-1}),o=b(t,{tickformat:a});return function(t){return Math.abs(t)<1?u.tickText(o,t).text:r(t)}}L.enter().append(\"text\"),L.attr(\"text-anchor\",function(){return A}).attr(\"class\",function(t){return t}).attr(\"x\",null).attr(\"y\",null).attr(\"dx\",null).attr(\"dy\",null),L.exit().remove();var O,z=f.mode+f.align;f._hasDelta&&(O=function(){var e=b(t,{tickformat:f.delta.valueformat},f._range);e.setScale(),u.calcTicks(e);var i=function(t){return u.tickText(e,t).text},a=function(t){var e=f.delta.relative?t.relativeDelta:t.delta;return e},o=function(t,e){return 0===t||\"number\"!=typeof t||isNaN(t)?\"-\":(t>0?f.delta.increasing.symbol:f.delta.decreasing.symbol)+e(t)},h=function(t){return t.delta>=0?f.delta.increasing.color:f.delta.decreasing.color};void 0===f._deltaLastValue&&(f._deltaLastValue=a(r[0]));var p=E.select(\"text.delta\");function g(){p.text(o(a(r[0]),i)).call(d.fill,h(r[0])).call(c.convertToTspans,t)}p.call(s.font,f.delta.font).call(d.fill,h({delta:f._deltaLastValue})),y(M)?p.transition().duration(M.duration).ease(M.easing).tween(\"text\",function(){var t=n.select(this),e=a(r[0]),s=f._deltaLastValue,l=P(f.delta.valueformat,i,s,e),c=n.interpolateNumber(s,e);return f._deltaLastValue=e,function(e){t.text(o(c(e),l)),t.call(d.fill,h({delta:c(e)}))}}).each(\"end\",function(){g(),S&&S()}).each(\"interrupt\",function(){g(),S&&S()}):g();return l=k(o(a(r[0]),i),f.delta.font,A,t),p}(),z+=f.delta.position+f.delta.font.size+f.delta.font.family+f.delta.valueformat,z+=f.delta.increasing.symbol+f.delta.decreasing.symbol,h=l);f._hasNumber&&(!function(){var e=b(t,{tickformat:f.number.valueformat},f._range);e.setScale(),u.calcTicks(e);var i=function(t){return u.tickText(e,t).text},a=f.number.suffix,l=f.number.prefix,h=E.select(\"text.number\");function p(){var e=\"number\"==typeof r[0].y?l+i(r[0].y)+a:\"-\";h.text(e).call(s.font,f.number.font).call(c.convertToTspans,t)}y(M)?h.transition().duration(M.duration).ease(M.easing).each(\"end\",function(){p(),S&&S()}).each(\"interrupt\",function(){p(),S&&S()}).attrTween(\"text\",function(){var t=n.select(this),e=n.interpolateNumber(r[0].lastY,r[0].y);f._lastValue=r[0].y;var o=P(f.number.valueformat,i,r[0].lastY,r[0].y);return function(r){t.text(l+o(e(r))+a)}}):p();o=k(l+i(r[0].y)+a,f.number.font,A,t)}(),z+=f.number.font.size+f.number.font.family+f.number.valueformat+f.number.suffix+f.number.prefix,h=o);if(f._hasDelta&&f._hasNumber){var I,D,R=[(o.left+o.right)/2,(o.top+o.bottom)/2],F=[(l.left+l.right)/2,(l.top+l.bottom)/2],B=.75*f.delta.font.size;\"left\"===f.delta.position&&(I=T(f,\"deltaPos\",0,-1*(o.width*v[f.align]+l.width*(1-v[f.align])+B),z,Math.min),D=R[1]-F[1],h={width:o.width+l.width+B,height:Math.max(o.height,l.height),left:l.left+I,right:o.right,top:Math.min(o.top,l.top+D),bottom:Math.max(o.bottom,l.bottom+D)}),\"right\"===f.delta.position&&(I=T(f,\"deltaPos\",0,o.width*(1-v[f.align])+l.width*v[f.align]+B,z,Math.max),D=R[1]-F[1],h={width:o.width+l.width+B,height:Math.max(o.height,l.height),left:o.left,right:l.right+I,top:Math.min(o.top,l.top+D),bottom:Math.max(o.bottom,l.bottom+D)}),\"bottom\"===f.delta.position&&(I=null,D=l.height,h={width:Math.max(o.width,l.width),height:o.height+l.height,left:Math.min(o.left,l.left),right:Math.max(o.right,l.right),top:o.bottom-o.height,bottom:o.bottom+l.height}),\"top\"===f.delta.position&&(I=null,D=o.top,h={width:Math.max(o.width,l.width),height:o.height+l.height,left:Math.min(o.left,l.left),right:Math.max(o.right,l.right),top:o.bottom-o.height-l.height,bottom:o.bottom}),O.attr({dx:I,dy:D})}(f._hasNumber||f._hasDelta)&&E.attr(\"transform\",function(){var t=a.numbersScaler(h);z+=t[2];var e,r=T(f,\"numbersScale\",1,t[0],z,Math.min);f._scaleNumbers||(r=1),e=f._isAngular?x-r*h.bottom:x-r*(h.top+h.bottom)/2,f._numbersTop=r*h.top+e;var n=h[w];\"center\"===w&&(n=(h.left+h.right)/2);var i=p-r*n;return _(i=T(f,\"numbersTranslate\",0,i,z,Math.max),e)+\" scale(\"+r+\")\"})}(t,L,e,{numbersX:h,numbersY:A,numbersScaler:M,transitionOpts:r,onComplete:f}),P&&(S={range:C.gauge.axis.range,color:C.gauge.bgcolor,line:{color:C.gauge.bordercolor,width:0},thickness:1},E={range:C.gauge.axis.range,color:\"rgba(0, 0, 0, 0)\",line:{color:C.gauge.bordercolor,width:C.gauge.borderwidth},thickness:1});var q=L.selectAll(\"g.angular\").data(O?e:[]);q.exit().remove();var H=L.selectAll(\"g.angularaxis\").data(O?e:[]);H.exit().remove(),O&&function(t,e,r,i){var s,l,c,h,f=r[0].trace,p=i.size,d=i.radius,g=i.innerRadius,v=i.gaugeBg,m=i.gaugeOutline,w=[p.l+p.w/2,p.t+p.h/2+d/2],k=i.gauge,T=i.layer,A=i.transitionOpts,M=i.onComplete,S=Math.PI/2;function E(t){var e=f.gauge.axis.range[0],r=f.gauge.axis.range[1],n=(t-e)/(r-e)*Math.PI-S;return n<-S?-S:n>S?S:n}function C(t){return n.svg.arc().innerRadius((g+d)/2-t/2*(d-g)).outerRadius((g+d)/2+t/2*(d-g)).startAngle(-S)}function L(t){t.attr(\"d\",function(t){return C(t.thickness).startAngle(E(t.range[0])).endAngle(E(t.range[1]))()})}k.enter().append(\"g\").classed(\"angular\",!0),k.attr(\"transform\",_(w[0],w[1])),T.enter().append(\"g\").classed(\"angularaxis\",!0).classed(\"crisp\",!0),T.selectAll(\"g.xangularaxistick,path,text\").remove(),(s=b(t,f.gauge.axis)).type=\"linear\",s.range=f.gauge.axis.range,s._id=\"xangularaxis\",s.setScale();var P=function(t){return(s.range[0]-t.x)/(s.range[1]-s.range[0])*Math.PI+Math.PI},O={},z=u.makeLabelFns(s,0).labelStandoff;O.xFn=function(t){var e=P(t);return Math.cos(e)*z},O.yFn=function(t){var e=P(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(z+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*o)},O.anchorFn=function(t){var e=P(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},O.heightFn=function(t,e,r){var n=P(t);return-.5*(1+Math.sin(n))*r};var I=function(t){return _(w[0]+d*Math.cos(t),w[1]-d*Math.sin(t))};c=function(t){return I(P(t))};if(l=u.calcTicks(s),h=u.getTickSigns(s)[2],s.visible){h=\"inside\"===s.ticks?-1:1;var D=(s.linewidth||1)/2;u.drawTicks(t,s,{vals:l,layer:T,path:\"M\"+h*D+\",0h\"+h*s.ticklen,transFn:function(t){var e=P(t);return I(e)+\"rotate(\"+-a(e)+\")\"}}),u.drawLabels(t,s,{vals:l,layer:T,transFn:c,labelFns:O})}var R=[v].concat(f.gauge.steps),F=k.selectAll(\"g.bg-arc\").data(R);F.enter().append(\"g\").classed(\"bg-arc\",!0).append(\"path\"),F.select(\"path\").call(L).call(x),F.exit().remove();var B=C(f.gauge.bar.thickness),N=k.selectAll(\"g.value-arc\").data([f.gauge.bar]);N.enter().append(\"g\").classed(\"value-arc\",!0).append(\"path\");var j=N.select(\"path\");y(A)?(j.transition().duration(A.duration).ease(A.easing).each(\"end\",function(){M&&M()}).each(\"interrupt\",function(){M&&M()}).attrTween(\"d\",(U=B,V=E(r[0].lastY),q=E(r[0].y),function(){var t=n.interpolate(V,q);return function(e){return U.endAngle(t(e))()}})),f._lastValue=r[0].y):j.attr(\"d\",\"number\"==typeof r[0].y?B.endAngle(E(r[0].y)):\"M0,0Z\");var U,V,q;j.call(x),N.exit().remove(),R=[];var H=f.gauge.threshold.value;H&&R.push({range:[H,H],color:f.gauge.threshold.color,line:{color:f.gauge.threshold.line.color,width:f.gauge.threshold.line.width},thickness:f.gauge.threshold.thickness});var G=k.selectAll(\"g.threshold-arc\").data(R);G.enter().append(\"g\").classed(\"threshold-arc\",!0).append(\"path\"),G.select(\"path\").call(L).call(x),G.exit().remove();var Y=k.selectAll(\"g.gauge-outline\").data([m]);Y.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"path\"),Y.select(\"path\").call(L).call(x),Y.exit().remove()}(t,0,e,{radius:B,innerRadius:N,gauge:q,layer:H,size:D,gaugeBg:S,gaugeOutline:E,transitionOpts:r,onComplete:f});var G=L.selectAll(\"g.bullet\").data(z?e:[]);G.exit().remove();var Y=L.selectAll(\"g.bulletaxis\").data(z?e:[]);Y.exit().remove(),z&&function(t,e,r,n){var i,a,o,s,c,h=r[0].trace,f=n.gauge,p=n.layer,g=n.gaugeBg,v=n.gaugeOutline,m=n.size,_=h.domain,w=n.transitionOpts,k=n.onComplete;f.enter().append(\"g\").classed(\"bullet\",!0),f.attr(\"transform\",\"translate(\"+m.l+\", \"+m.t+\")\"),p.enter().append(\"g\").classed(\"bulletaxis\",!0).classed(\"crisp\",!0),p.selectAll(\"g.xbulletaxistick,path,text\").remove();var T=m.h,A=h.gauge.bar.thickness*T,M=_.x[0],S=_.x[0]+(_.x[1]-_.x[0])*(h._hasNumber||h._hasDelta?1-l.bulletNumberDomainSize:1);(i=b(t,h.gauge.axis))._id=\"xbulletaxis\",i.domain=[M,S],i.setScale(),a=u.calcTicks(i),o=u.makeTransFn(i),s=u.getTickSigns(i)[2],c=m.t+m.h,i.visible&&(u.drawTicks(t,i,{vals:\"inside\"===i.ticks?u.clipEnds(i,a):a,layer:p,path:u.makeTickPath(i,c,s),transFn:o}),u.drawLabels(t,i,{vals:a,layer:p,transFn:o,labelFns:u.makeLabelFns(i,c)}));function E(t){t.attr(\"width\",function(t){return Math.max(0,i.c2p(t.range[1])-i.c2p(t.range[0]))}).attr(\"x\",function(t){return i.c2p(t.range[0])}).attr(\"y\",function(t){return.5*(1-t.thickness)*T}).attr(\"height\",function(t){return t.thickness*T})}var C=[g].concat(h.gauge.steps),L=f.selectAll(\"g.bg-bullet\").data(C);L.enter().append(\"g\").classed(\"bg-bullet\",!0).append(\"rect\"),L.select(\"rect\").call(E).call(x),L.exit().remove();var P=f.selectAll(\"g.value-bullet\").data([h.gauge.bar]);P.enter().append(\"g\").classed(\"value-bullet\",!0).append(\"rect\"),P.select(\"rect\").attr(\"height\",A).attr(\"y\",(T-A)/2).call(x),y(w)?P.select(\"rect\").transition().duration(w.duration).ease(w.easing).each(\"end\",function(){k&&k()}).each(\"interrupt\",function(){k&&k()}).attr(\"width\",Math.max(0,i.c2p(Math.min(h.gauge.axis.range[1],r[0].y)))):P.select(\"rect\").attr(\"width\",\"number\"==typeof r[0].y?Math.max(0,i.c2p(Math.min(h.gauge.axis.range[1],r[0].y))):0);P.exit().remove();var O=r.filter(function(){return h.gauge.threshold.value}),z=f.selectAll(\"g.threshold-bullet\").data(O);z.enter().append(\"g\").classed(\"threshold-bullet\",!0).append(\"line\"),z.select(\"line\").attr(\"x1\",i.c2p(h.gauge.threshold.value)).attr(\"x2\",i.c2p(h.gauge.threshold.value)).attr(\"y1\",(1-h.gauge.threshold.thickness)/2*T).attr(\"y2\",(1-(1-h.gauge.threshold.thickness)/2)*T).call(d.stroke,h.gauge.threshold.line.color).style(\"stroke-width\",h.gauge.threshold.line.width),z.exit().remove();var I=f.selectAll(\"g.gauge-outline\").data([v]);I.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"rect\"),I.select(\"rect\").call(E).call(x),I.exit().remove()}(t,0,e,{gauge:G,layer:Y,size:D,gaugeBg:S,gaugeOutline:E,transitionOpts:r,onComplete:f});var W=L.selectAll(\"text.title\").data(e);W.exit().remove(),W.enter().append(\"text\").classed(\"title\",!0),W.attr(\"text-anchor\",function(){return z?g.right:g[C.title.align]}).text(C.title.text).call(s.font,C.title.font).call(c.convertToTspans,t),W.attr(\"transform\",function(){var t,e=D.l+D.w*v[C.title.align],r=l.titlePadding,n=s.bBox(W.node());if(P){if(O)if(C.gauge.axis.visible)t=s.bBox(H.node()).top-r-n.bottom;else t=D.t+D.h/2-B/2-n.bottom-r;z&&(t=A-(n.top+n.bottom)/2,e=D.l-l.bulletPadding*D.w)}else t=C._numbersTop-r-n.bottom;return _(e,t)})})}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_defaults\":769,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/cartesian/position_defaults\":782,\"./constants\":1044,d3:163}],1048:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;var c=e.exports=l(s({x:{valType:\"data_array\"},y:{valType:\"data_array\"},z:{valType:\"data_array\"},value:{valType:\"data_array\"},isomin:{valType:\"number\"},isomax:{valType:\"number\"},surface:{show:{valType:\"boolean\",dflt:!0},count:{valType:\"integer\",dflt:2,min:1},fill:{valType:\"number\",min:0,max:1,dflt:1},pattern:{valType:\"flaglist\",flags:[\"A\",\"B\",\"C\",\"D\",\"E\"],extras:[\"all\",\"odd\",\"even\"],dflt:\"all\"}},spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:.15}},slices:{x:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}}},caps:{x:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}}},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:i()},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:a.opacity,lightposition:a.lightposition,lighting:a.lighting,flatshading:a.flatshading,contour:a.contour,hoverinfo:s({},o.hoverinfo)}),\"calc\",\"nested\");c.flatshading.dflt=!0,c.lighting.facenormalsepsilon.dflt=0,c.x.editType=c.y.editType=c.z.editType=c.value.editType=\"calc+clearAxisTypes\",c.transforms=void 0},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../mesh3d/attributes\":1053}],1049:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e._len=Math.min(e.x.length,e.y.length,e.z.length,e.value.length);for(var r=1/0,i=-1/0,a=e.value.length,o=0;o<a;o++){var s=e.value[o];r=Math.min(r,s),i=Math.max(i,s)}e._minValues=r,e._maxValues=i,e._vMin=void 0===e.isomin||null===e.isomin?r:e.isomin,e._vMax=void 0===e.isomax||null===e.isomin?i:e.isomax,n(t,e,{vals:[e._vMin,e._vMax],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],1050:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib\"),a=t(\"../../lib/gl_format_color\").parseColorScale,o=t(\"../../lib/str2rgbarray\"),s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\");function c(t){return i.distinctVals(t).vals}var u=function(t,e){for(var r=e.length-1;r>0;r--){var n=Math.min(e[r],e[r-1]),i=Math.max(e[r],e[r-1]);if(i>n&&n<t&&t<=i)return{id:r,distRatio:(i-t)/(i-n)}}return{id:0,distRatio:0}};function h(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var f=h.prototype;function p(t){t._i=[],t._j=[],t._k=[];var e,r,n=t.surface.show,i=t.spaceframe.show,a=t.surface.fill,o=t.spaceframe.fill,s=!1,l=!1,h=0,f=c(t.x.slice(0,t._len)),p=c(t.y.slice(0,t._len)),d=c(t.z.slice(0,t._len)),g=f.length,v=p.length,m=d.length;function y(t,e,r){return r+m*e+m*v*t}var x,b,_,w,k,T=t._minValues,A=t._maxValues,M=t._vMin,S=t._vMax;function E(t,e,n){for(var i=w.length,a=r;a<i;a++)if(t===x[a]&&e===b[a]&&n===_[a])return a;return-1}function C(){r=e}function L(){x=[],b=[],_=[],w=[],e=0,C()}function P(t,r,n,i){return x.push(t),b.push(r),_.push(n),w.push(i),++e-1}function O(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=t[i]*(1-r)+r*e[i];return n}function z(t){k=t}function I(t,e){return\"all\"===t||null===t||t.indexOf(e)>-1}function D(t,e){return null===t?e:t}function R(e,r,n){C();var i,a,o,s=[r],l=[n];if(k>=1)s=[r],l=[n];else if(k>0){var c=function(t,e){var r=t[0],n=t[1],i=t[2],a=function(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=(t[i]+e[i]+r[i])/3;return n}(r,n,i),o=Math.sqrt(1-k),s=O(a,r,o),l=O(a,n,o),c=O(a,i,o),u=e[0],h=e[1],f=e[2];return{xyzv:[[r,n,l],[l,s,r],[n,i,c],[c,l,n],[i,r,s],[s,c,i]],abc:[[u,h,-1],[-1,-1,u],[h,f,-1],[-1,-1,h],[f,u,-1],[-1,-1,f]]}}(r,n);s=c.xyzv,l=c.abc}for(var u=0;u<s.length;u++){r=s[u],n=l[u];for(var f=[],p=0;p<3;p++){var d=r[p][0],g=r[p][1],v=r[p][2],m=r[p][3],y=n[p]>-1?n[p]:E(d,g,v);f[p]=y>-1?y:P(d,g,v,D(e,m))}i=f[0],a=f[1],o=f[2],t._i.push(i),t._j.push(a),t._k.push(o),++h}}function F(t,e,r,n){var i=t[3];i<r&&(i=r),i>n&&(i=n);for(var a=(t[3]-i)/(t[3]-e[3]+1e-9),o=[],s=0;s<4;s++)o[s]=(1-a)*t[s]+a*e[s];return o}function B(t,e,r){return t>=e&&t<=r}function N(t){var e=.001*(S-M);return t>=M-e&&t<=S+e}function j(e){for(var r=[],n=0;n<4;n++){var i=e[n];r.push([t.x[i],t.y[i],t.z[i],t.value[i]])}return r}var U=3;function V(t,e,r,n,i,a){a||(a=1),r=[-1,-1,-1];var o=!1,s=[B(e[0][3],n,i),B(e[1][3],n,i),B(e[2][3],n,i)];if(!s[0]&&!s[1]&&!s[2])return!1;var l=function(t,e,r){return N(e[0][3])&&N(e[1][3])&&N(e[2][3])?(R(t,e,r),!0):a<U&&V(t,e,r,M,S,++a)};if(s[0]&&s[1]&&s[2])return l(t,e,r)||o;var c=!1;return[[0,1,2],[2,0,1],[1,2,0]].forEach(function(a){if(s[a[0]]&&s[a[1]]&&!s[a[2]]){var u=e[a[0]],h=e[a[1]],f=e[a[2]],p=F(f,u,n,i),d=F(f,h,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,o=l(t,[u,h,d],[r[a[0]],r[a[1]],-1])||o,c=!0}}),c?o:([[0,1,2],[1,2,0],[2,0,1]].forEach(function(a){if(s[a[0]]&&!s[a[1]]&&!s[a[2]]){var u=e[a[0]],h=e[a[1]],f=e[a[2]],p=F(h,u,n,i),d=F(f,u,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,c=!0}}),o)}function q(t,e,r,n){var i=!1,a=j(e),o=[B(a[0][3],r,n),B(a[1][3],r,n),B(a[2][3],r,n),B(a[3][3],r,n)];if(!(o[0]||o[1]||o[2]||o[3]))return i;if(o[0]&&o[1]&&o[2]&&o[3])return l&&(i=function(t,e,r){var n=function(n,i,a){R(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(3,0,1),n(2,3,0),n(1,2,3)}(t,a,e)||i),i;var s=!1;return[[0,1,2,3],[3,0,1,2],[2,3,0,1],[1,2,3,0]].forEach(function(c){if(o[c[0]]&&o[c[1]]&&o[c[2]]&&!o[c[3]]){var u=a[c[0]],h=a[c[1]],f=a[c[2]],p=a[c[3]];if(l)i=R(t,[u,h,f],[e[c[0]],e[c[1]],e[c[2]]])||i;else{var d=F(p,u,r,n),g=F(p,h,r,n),v=F(p,f,r,n);i=R(null,[d,g,v],[-1,-1,-1])||i}s=!0}}),s?i:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2],[0,2,3,1],[1,3,2,0]].forEach(function(c){if(o[c[0]]&&o[c[1]]&&!o[c[2]]&&!o[c[3]]){var u=a[c[0]],h=a[c[1]],f=a[c[2]],p=a[c[3]],d=F(f,u,r,n),g=F(f,h,r,n),v=F(p,h,r,n),m=F(p,u,r,n);l?(i=R(t,[u,m,d],[e[c[0]],-1,-1])||i,i=R(t,[h,g,v],[e[c[1]],-1,-1])||i):i=function(t,e,r){var n=function(n,i,a){R(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(2,3,0)}(null,[d,g,v,m],[-1,-1,-1,-1])||i,s=!0}}),s?i:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2]].forEach(function(c){if(o[c[0]]&&!o[c[1]]&&!o[c[2]]&&!o[c[3]]){var u=a[c[0]],h=a[c[1]],f=a[c[2]],p=a[c[3]],d=F(h,u,r,n),g=F(f,u,r,n),v=F(p,u,r,n);l?(i=R(t,[u,d,g],[e[c[0]],-1,-1])||i,i=R(t,[u,g,v],[e[c[0]],-1,-1])||i,i=R(t,[u,v,d],[e[c[0]],-1,-1])||i):i=R(null,[d,g,v],[-1,-1,-1])||i,s=!0}}),i))}function H(t,e,r,n,i,a,o,c,u,h,f){var p=!1;return s&&(I(t,\"A\")&&(p=q(null,[e,r,n,a],h,f)||p),I(t,\"B\")&&(p=q(null,[r,n,i,u],h,f)||p),I(t,\"C\")&&(p=q(null,[r,a,o,u],h,f)||p),I(t,\"D\")&&(p=q(null,[n,a,c,u],h,f)||p),I(t,\"E\")&&(p=q(null,[r,n,a,u],h,f)||p)),l&&(p=q(t,[r,n,a,u],h,f)||p),p}function G(t,e,r,n,i,a,o,s){return[!0===s[0]||V(t,j([e,r,n]),[e,r,n],a,o),!0===s[1]||V(t,j([n,i,e]),[n,i,e],a,o)]}function Y(t,e,r,n,i,a,o,s,l){return s?G(t,e,r,i,n,a,o,l):G(t,r,i,n,e,a,o,l)}function W(t,e,r,n,i,a,o){var s,l,c,u,h=!1,f=function(){h=V(t,[s,l,c],[-1,-1,-1],i,a)||h,h=V(t,[c,u,s],[-1,-1,-1],i,a)||h},p=o[0],d=o[1],g=o[2];return p&&(s=O(j([y(e,r-0,n-0)])[0],j([y(e-1,r-0,n-0)])[0],p),l=O(j([y(e,r-0,n-1)])[0],j([y(e-1,r-0,n-1)])[0],p),c=O(j([y(e,r-1,n-1)])[0],j([y(e-1,r-1,n-1)])[0],p),u=O(j([y(e,r-1,n-0)])[0],j([y(e-1,r-1,n-0)])[0],p),f()),d&&(s=O(j([y(e-0,r,n-0)])[0],j([y(e-0,r-1,n-0)])[0],d),l=O(j([y(e-0,r,n-1)])[0],j([y(e-0,r-1,n-1)])[0],d),c=O(j([y(e-1,r,n-1)])[0],j([y(e-1,r-1,n-1)])[0],d),u=O(j([y(e-1,r,n-0)])[0],j([y(e-1,r-1,n-0)])[0],d),f()),g&&(s=O(j([y(e-0,r-0,n)])[0],j([y(e-0,r-0,n-1)])[0],g),l=O(j([y(e-0,r-1,n)])[0],j([y(e-0,r-1,n-1)])[0],g),c=O(j([y(e-1,r-1,n)])[0],j([y(e-1,r-1,n-1)])[0],g),u=O(j([y(e-1,r-0,n)])[0],j([y(e-1,r-0,n-1)])[0],g),f()),h}function X(t,e,r,n,i,a,o,l,c,u,h,f){var p=t;return f?(s&&\"even\"===t&&(p=null),H(p,e,r,n,i,a,o,l,c,u,h)):(s&&\"odd\"===t&&(p=null),H(p,c,l,o,a,i,n,r,e,u,h))}function Z(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<m;c++)for(var u=1;u<v;u++)a.push(Y(t,y(l,u-1,c-1),y(l,u-1,c),y(l,u,c-1),y(l,u,c),r,n,(l+u+c)%2,i&&i[o]?i[o]:[])),o++;return a}function J(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<g;c++)for(var u=1;u<m;u++)a.push(Y(t,y(c-1,l,u-1),y(c,l,u-1),y(c-1,l,u),y(c,l,u),r,n,(c+l+u)%2,i&&i[o]?i[o]:[])),o++;return a}function K(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<v;c++)for(var u=1;u<g;u++)a.push(Y(t,y(u-1,c-1,l),y(u-1,c,l),y(u,c-1,l),y(u,c,l),r,n,(u+c+l)%2,i&&i[o]?i[o]:[])),o++;return a}function $(t,e,r){for(var n=1;n<m;n++)for(var i=1;i<v;i++)for(var a=1;a<g;a++)X(t,y(a-1,i-1,n-1),y(a-1,i-1,n),y(a-1,i,n-1),y(a-1,i,n),y(a,i-1,n-1),y(a,i-1,n),y(a,i,n-1),y(a,i,n),e,r,(a+i+n)%2)}function Q(t,e,r){s=!0,$(t,e,r),s=!1}function tt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<m;u++)for(var h=1;h<v;h++)o.push(W(t,c,h,u,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function et(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<g;u++)for(var h=1;h<m;h++)o.push(W(t,u,c,h,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function rt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<v;u++)for(var h=1;h<g;h++)o.push(W(t,h,u,c,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function nt(t,e){for(var r=[],n=t;n<e;n++)r.push(n);return r}return function(){if(L(),function(){for(var e=0;e<g;e++)for(var r=0;r<v;r++)for(var n=0;n<m;n++){var i=y(e,r,n);P(t.x[i],t.y[i],t.z[i],t.value[i])}}(),i&&o&&(z(o),l=!0,$(null,M,S),l=!1),n&&a){z(a);for(var e=t.surface.pattern,r=t.surface.count,s=0;s<r;s++){var c=1===r?.5:s/(r-1),k=(1-c)*M+c*S,E=Math.abs(k-T)>Math.abs(k-A)?[T,k]:[k,A];Q(e,E[0],E[1])}}var C=[[Math.min(M,A),Math.max(M,A)],[Math.min(T,S),Math.max(T,S)]];[\"x\",\"y\",\"z\"].forEach(function(e){for(var r=[],n=0;n<C.length;n++){var i=0,a=C[n][0],o=C[n][1],s=t.slices[e];if(s.show&&s.fill){z(s.fill);var l=[],c=[],h=[];if(s.locations.length)for(var y=0;y<s.locations.length;y++){var x=u(s.locations[y],\"x\"===e?f:\"y\"===e?p:d);0===x.distRatio?l.push(x.id):x.id>0&&(c.push(x.id),\"x\"===e?h.push([x.distRatio,0,0]):\"y\"===e?h.push([0,x.distRatio,0]):h.push([0,0,x.distRatio]))}else l=nt(1,\"x\"===e?g-1:\"y\"===e?v-1:m-1);c.length>0&&(r[i]=\"x\"===e?tt(null,c,a,o,h,r[i]):\"y\"===e?et(null,c,a,o,h,r[i]):rt(null,c,a,o,h,r[i]),i++),l.length>0&&(r[i]=\"x\"===e?Z(null,l,a,o,r[i]):\"y\"===e?J(null,l,a,o,r[i]):K(null,l,a,o,r[i]),i++)}var b=t.caps[e];b.show&&b.fill&&(z(b.fill),r[i]=\"x\"===e?Z(null,[0,g-1],a,o,r[i]):\"y\"===e?J(null,[0,v-1],a,o,r[i]):K(null,[0,m-1],a,o,r[i]),i++)}}),0===h&&L(),t._x=x,t._y=b,t._z=_,t._intensity=w,t._Xs=f,t._Ys=p,t._Zs=d}(),t}f.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._x[e],n=this.data._y[e],i=this.data._z[e],a=this.data._Ys.length,o=this.data._Zs.length,s=u(r,this.data._Xs).id,l=u(n,this.data._Ys).id,c=u(i,this.data._Zs).id,h=t.index=c+o*l+o*a*s;t.traceCoordinate=[this.data._x[h],this.data._y[h],this.data._z[h],this.data.value[h]];var f=this.data.hovertext||this.data.text;return Array.isArray(f)&&void 0!==f[h]?t.textLabel=f[h]:f&&(t.textLabel=f),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map(function(e){return t.d2l(e,0,n)*r})}this.data=p(t);var i={positions:l(n(r.xaxis,t._x,e.dataScale[0],t.xcalendar),n(r.yaxis,t._y,e.dataScale[1],t.ycalendar),n(r.zaxis,t._z,e.dataScale[2],t.zcalendar)),cells:l(t._i,t._j,t._k),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:o(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},c=s(t);i.vertexIntensity=t._intensity,i.vertexIntensityBounds=[c.min,c.max],i.colormap=a(t),this.mesh.update(i)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports={findNearestOnAxis:u,generateIsoMeshes:p,createIsosurfaceTrace:function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new h(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../../plots/gl3d/zip3\":818,\"gl-mesh3d\":280}],1051:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"../../components/colorscale/defaults\");function s(t,e,r,n,a){var s=a(\"isomin\"),l=a(\"isomax\");null!=l&&null!=s&&s>l&&(e.isomin=null,e.isomax=null);var c=a(\"x\"),u=a(\"y\"),h=a(\"z\"),f=a(\"value\");c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length?(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],n),[\"x\",\"y\",\"z\"].forEach(function(t){var e=\"caps.\"+t;a(e+\".show\")&&a(e+\".fill\");var r=\"slices.\"+t;a(r+\".show\")&&(a(r+\".fill\"),a(r+\".locations\"))}),a(\"spaceframe.show\")&&a(\"spaceframe.fill\"),a(\"surface.show\")&&(a(\"surface.count\"),a(\"surface.fill\"),a(\"surface.pattern\")),a(\"contour.show\")&&(a(\"contour.color\"),a(\"contour.width\")),[\"text\",\"hovertext\",\"hovertemplate\",\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"flatshading\",\"opacity\"].forEach(function(t){a(t)}),o(t,e,n,a,{prefix:\"\",cLetter:\"c\"}),e._length=null):e.visible=!1}e.exports={supplyDefaults:function(t,e,r,i){s(t,e,0,i,function(r,i){return n.coerce(t,e,a,r,i)})},supplyIsoDefaults:s}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../../registry\":847,\"./attributes\":1048}],1052:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\").createIsosurfaceTrace,moduleType:\"trace\",name:\"isosurface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1048,\"./calc\":1049,\"./convert\":1050,\"./defaults\":1051}],1053:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../surface/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},i:{valType:\"data_array\",editType:\"calc\"},j:{valType:\"data_array\",editType:\"calc\"},k:{valType:\"data_array\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:i({editType:\"calc\"}),delaunayaxis:{valType:\"enumerated\",values:[\"x\",\"y\",\"z\"],dflt:\"z\",editType:\"calc\"},alphahull:{valType:\"number\",dflt:-1,editType:\"calc\"},intensity:{valType:\"data_array\",editType:\"calc\"},color:{valType:\"color\",editType:\"calc\"},vertexcolor:{valType:\"data_array\",editType:\"calc\"},facecolor:{valType:\"data_array\",editType:\"calc\"},transforms:void 0},n(\"\",{colorAttr:\"`intensity`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:a.opacity,flatshading:{valType:\"boolean\",dflt:!1,editType:\"calc\"},contour:{show:s({},a.contours.x.show,{}),color:a.contours.x.color,width:a.contours.x.width,editType:\"calc\"},lightposition:{x:s({},a.lightposition.x,{dflt:1e5}),y:s({},a.lightposition.y,{dflt:1e5}),z:s({},a.lightposition.z,{dflt:0}),editType:\"calc\"},lighting:s({vertexnormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-12,editType:\"calc\"},facenormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-6,editType:\"calc\"},editType:\"calc\"},a.lighting),hoverinfo:s({},o.hoverinfo,{editType:\"calc\"})})},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../surface/attributes\":1224}],1054:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.intensity&&n(t,e,{vals:e.intensity,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],1055:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"delaunay-triangulate\"),a=t(\"alpha-shape\"),o=t(\"convex-hull\"),s=t(\"../../lib/gl_format_color\").parseColorScale,l=t(\"../../lib/str2rgbarray\"),c=t(\"../../components/colorscale\").extractOpts,u=t(\"../../plots/gl3d/zip3\");function h(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.color=\"#fff\",this.data=null,this.showContour=!1}var f=h.prototype;function p(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=l(t[n]);return e}function d(t,e,r,n){for(var i=[],a=e.length,o=0;o<a;o++)i[o]=t.d2l(e[o],0,n)*r;return i}function g(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=Math.round(t[n]);return e}function v(t,e){for(var r=t.length,n=0;n<r;n++)if(t[n]<=-.5||t[n]>=e-.5)return!1;return!0}f.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index;t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]];var r=this.data.hovertext||this.data.text;return Array.isArray(r)&&void 0!==r[e]?t.textLabel=r[e]:r&&(t.textLabel=r),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;this.data=t;var n,h=t.x.length,f=u(d(r.xaxis,t.x,e.dataScale[0],t.xcalendar),d(r.yaxis,t.y,e.dataScale[1],t.ycalendar),d(r.zaxis,t.z,e.dataScale[2],t.zcalendar));if(t.i&&t.j&&t.k){if(t.i.length!==t.j.length||t.j.length!==t.k.length||!v(t.i,h)||!v(t.j,h)||!v(t.k,h))return;n=u(g(t.i),g(t.j),g(t.k))}else n=0===t.alphahull?o(f):t.alphahull>0?a(t.alphahull,f):function(t,e){for(var r=[\"x\",\"y\",\"z\"].indexOf(t),n=[],a=e.length,o=0;o<a;o++)n[o]=[e[o][(r+1)%3],e[o][(r+2)%3]];return i(n)}(t.delaunayaxis,f);var m={positions:f,cells:n,lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:l(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading};if(t.intensity){var y=c(t);this.color=\"#fff\",m.vertexIntensity=t.intensity,m.vertexIntensityBounds=[y.min,y.max],m.colormap=s(t)}else t.vertexcolor?(this.color=t.vertexcolor[0],m.vertexColors=p(t.vertexcolor)):t.facecolor?(this.color=t.facecolor[0],m.cellColors=p(t.facecolor)):(this.color=t.color,m.meshColor=l(t.color));this.mesh.update(m)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new h(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":605,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../../plots/gl3d/zip3\":818,\"alpha-shape\":64,\"convex-hull\":130,\"delaunay-triangulate\":165,\"gl-mesh3d\":280}],1056:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,n){return i.coerce(t,e,o,r,n)}function c(t){var e=t.map(function(t){var e=l(t);return e&&i.isArrayOrTypedArray(e)?e:null});return e.every(function(t){return t&&t.length===e[0].length})&&e}c([\"x\",\"y\",\"z\"])?(c([\"i\",\"j\",\"k\"]),(!e.i||e.j&&e.k)&&(!e.j||e.k&&e.i)&&(!e.k||e.i&&e.j)?(n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],s),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"contour.show\",\"contour.color\",\"contour.width\",\"colorscale\",\"reversescale\",\"flatshading\",\"alphahull\",\"delaunayaxis\",\"opacity\"].forEach(function(t){l(t)}),\"intensity\"in t?(l(\"intensity\"),a(t,e,s,l,{prefix:\"\",cLetter:\"c\"})):(e.showscale=!1,\"facecolor\"in t?l(\"facecolor\"):\"vertexcolor\"in t?l(\"vertexcolor\"):l(\"color\",r)),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),e._length=null):e.visible=!1):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../../registry\":847,\"./attributes\":1053}],1057:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"mesh3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1053,\"./calc\":1054,\"./convert\":1055,\"./defaults\":1056}],1058:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../scatter/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../components/fx/attributes\"),s=t(\"../../constants/delta.js\"),l=s.INCREASING.COLOR,c=s.DECREASING.COLOR,u=i.line;function h(t){return{line:{color:n({},u.color,{dflt:t}),width:u.width,dash:a,editType:\"style\"},editType:\"style\"}}e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},open:{valType:\"data_array\",editType:\"calc\"},high:{valType:\"data_array\",editType:\"calc\"},low:{valType:\"data_array\",editType:\"calc\"},close:{valType:\"data_array\",editType:\"calc\"},line:{width:n({},u.width,{}),dash:n({},a,{}),editType:\"style\"},increasing:h(l),decreasing:h(c),text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},tickwidth:{valType:\"number\",min:0,max:.5,dflt:.3,editType:\"calc\"},hoverlabel:n({},o.hoverlabel,{split:{valType:\"boolean\",dflt:!1,editType:\"style\"}})}},{\"../../components/drawing/attributes\":613,\"../../components/fx/attributes\":623,\"../../constants/delta.js\":689,\"../../lib\":719,\"../scatter/attributes\":1112}],1059:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=n._,a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/numerical\").BADNUM;function s(t,e,r,n){return{o:t,h:e,l:r,c:n}}function l(t,e,r,s,l){for(var c=s.makeCalcdata(e,\"open\"),u=s.makeCalcdata(e,\"high\"),h=s.makeCalcdata(e,\"low\"),f=s.makeCalcdata(e,\"close\"),p=Array.isArray(e.text),d=Array.isArray(e.hovertext),g=!0,v=null,m=[],y=0;y<r.length;y++){var x=r[y],b=c[y],_=u[y],w=h[y],k=f[y];if(x!==o&&b!==o&&_!==o&&w!==o&&k!==o){k===b?null!==v&&k!==v&&(g=k>v):g=k>b,v=k;var T=l(b,_,w,k);T.pos=x,T.yc=(b+k)/2,T.i=y,T.dir=g?\"increasing\":\"decreasing\",T.x=T.pos,T.y=[w,_],p&&(T.tx=e.text[y]),d&&(T.htx=e.hovertext[y]),m.push(T)}else m.push({pos:x,empty:!0})}return e._extremes[s._id]=a.findExtremes(s,n.concat(h,u),{padded:!0}),m.length&&(m[0].t={labels:{open:i(t,\"open:\")+\" \",high:i(t,\"high:\")+\" \",low:i(t,\"low:\")+\" \",close:i(t,\"close:\")+\" \"}}),m}e.exports={calc:function(t,e){var r=a.getFromId(t,e.xaxis),i=a.getFromId(t,e.yaxis),o=function(t,e,r){var i=r._minDiff;if(!i){var a,o=t._fullData,s=[];for(i=1/0,a=0;a<o.length;a++){var l=o[a];if(\"ohlc\"===l.type&&!0===l.visible&&l.xaxis===e._id){s.push(l);var c=e.makeCalcdata(l,\"x\");l._xcalc=c;var u=n.distinctVals(c).minDiff;u&&isFinite(u)&&(i=Math.min(i,u))}}for(i===1/0&&(i=1),a=0;a<s.length;a++)s[a]._minDiff=i}return i*r.tickwidth}(t,r,e),c=e._minDiff;e._minDiff=null;var u=e._xcalc;e._xcalc=null;var h=l(t,e,u,i,s);return e._extremes[r._id]=a.findExtremes(r,u,{vpad:c/2}),h.length?(n.extendFlat(h[0].t,{wHover:c/2,tickLen:o}),h):[{t:{empty:!0}}]},calcCommon:l}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],1060:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./ohlc_defaults\"),a=t(\"./attributes\");function o(t,e,r,n){r(n+\".line.color\"),r(n+\".line.width\",e.line.width),r(n+\".line.dash\",e.line.dash)}e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,a,r,i)}i(t,e,l,s)?(l(\"line.width\"),l(\"line.dash\"),o(t,e,l,\"increasing\"),o(t,e,l,\"decreasing\"),l(\"text\"),l(\"hovertext\"),l(\"tickwidth\"),s._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../lib\":719,\"./attributes\":1058,\"./ohlc_defaults\":1063}],1061:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\").fillText,l=t(\"../../constants/delta.js\"),c={increasing:l.INCREASING.SYMBOL,decreasing:l.DECREASING.SYMBOL};function u(t,e,r,n){var i,s,l=t.cd,c=t.xa,u=l[0].trace,h=l[0].t,f=u.type,p=\"ohlc\"===f?\"l\":\"min\",d=\"ohlc\"===f?\"h\":\"max\",g=h.bPos||0,v=function(t){return t.pos+g-e},m=h.bdPos||h.tickLen,y=h.wHover,x=Math.min(1,m/Math.abs(c.r2c(c.range[1])-c.r2c(c.range[0])));function b(t){var e=v(t);return a.inbox(e-y,e+y,i)}function _(t){var e=t[p],n=t[d];return e===n||a.inbox(e-r,n-r,i)}function w(t){return(b(t)+_(t))/2}i=t.maxHoverDistance-x,s=t.maxSpikeDistance-x;var k=a.getDistanceFunction(n,b,_,w);if(a.getClosest(l,k,t),!1===t.index)return null;var T=l[t.index];if(T.empty)return null;var A=u[T.dir],M=A.line.color;return o.opacity(M)&&A.line.width?t.color=M:t.color=A.fillcolor,t.x0=c.c2p(T.pos+g-m,!0),t.x1=c.c2p(T.pos+g+m,!0),t.xLabelVal=T.pos,t.spikeDistance=w(T)*s/i,t.xSpike=c.c2p(T.pos,!0),t}function h(t,e,r,a){var o=t.cd,s=t.ya,l=o[0].trace,c=o[0].t,h=[],f=u(t,e,r,a);if(!f)return[];var p=o[f.index].hi||l.hoverinfo,d=p.split(\"+\");if(!(\"all\"===p||-1!==d.indexOf(\"y\")))return[];for(var g=[\"high\",\"open\",\"close\",\"low\"],v={},m=0;m<g.length;m++){var y,x=g[m],b=l[x][f.index],_=s.c2p(b,!0);b in v?(y=v[b]).yLabel+=\"<br>\"+c.labels[x]+n.hoverLabelText(s,b):((y=i.extendFlat({},f)).y0=y.y1=_,y.yLabelVal=b,y.yLabel=c.labels[x]+n.hoverLabelText(s,b),y.name=\"\",h.push(y),v[b]=y)}return h}function f(t,e,r,i){var a=t.cd,o=t.ya,l=a[0].trace,h=a[0].t,f=u(t,e,r,i);if(!f)return[];var p=a[f.index],d=f.index=p.i,g=p.dir;function v(t){return h.labels[t]+n.hoverLabelText(o,l[t][d])}var m=p.hi||l.hoverinfo,y=m.split(\"+\"),x=\"all\"===m,b=x||-1!==y.indexOf(\"y\"),_=x||-1!==y.indexOf(\"text\"),w=b?[v(\"open\"),v(\"high\"),v(\"low\"),v(\"close\")+\"  \"+c[g]]:[];return _&&s(p,l,w),f.extraText=w.join(\"<br>\"),f.y0=f.y1=o.c2p(p.yc,!0),[f]}e.exports={hoverPoints:function(t,e,r,n){return t.cd[0].trace.hoverlabel.split?h(t,e,r,n):f(t,e,r,n)},hoverSplit:h,hoverOnPoints:f}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../constants/delta.js\":689,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],1062:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"ohlc\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\"],meta:{},attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\").calc,plot:t(\"./plot\"),style:t(\"./style\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\")}},{\"../../plots/cartesian\":778,\"./attributes\":1058,\"./calc\":1059,\"./defaults\":1060,\"./hover\":1061,\"./plot\":1064,\"./select\":1065,\"./style\":1066}],1063:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"open\"),l=r(\"high\"),c=r(\"low\"),u=r(\"close\");if(r(\"hoverlabel.split\"),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\"],a),s&&l&&c&&u){var h=Math.min(s.length,l.length,c.length,u.length);return o&&(h=Math.min(h,i.minRowLength(o))),e._length=h,h}}},{\"../../lib\":719,\"../../registry\":847}],1064:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=e.xaxis,s=e.yaxis;i.makeTraceGroups(a,r,\"trace ohlc\").each(function(t){var e=n.select(this),r=t[0],a=r.t;if(!0!==r.trace.visible||a.empty)e.remove();else{var l=a.tickLen,c=e.selectAll(\"path\").data(i.identity);c.enter().append(\"path\"),c.exit().remove(),c.attr(\"d\",function(t){if(t.empty)return\"M0,0Z\";var e=o.c2p(t.pos,!0),r=o.c2p(t.pos-l,!0),n=o.c2p(t.pos+l,!0);return\"M\"+r+\",\"+s.c2p(t.o,!0)+\"H\"+e+\"M\"+e+\",\"+s.c2p(t.h,!0)+\"V\"+s.c2p(t.l,!0)+\"M\"+n+\",\"+s.c2p(t.c,!0)+\"H\"+e})}})}},{\"../../lib\":719,d3:163}],1065:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n=t.cd,i=t.xaxis,a=t.yaxis,o=[],s=n[0].t.bPos||0;if(!1===e)for(r=0;r<n.length;r++)n[r].selected=0;else for(r=0;r<n.length;r++){var l=n[r];e.contains([i.c2p(l.pos+s),a.c2p(l.yc)],null,l.i,t)?(o.push({pointNumber:l.i,x:i.c2d(l.pos),y:a.c2d(l.yc)}),l.selected=1):l.selected=0}return o}},{}],1066:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\");e.exports=function(t,e,r){var o=r||n.select(t).selectAll(\"g.ohlclayer\").selectAll(\"g.trace\");o.style(\"opacity\",function(t){return t[0].trace.opacity}),o.each(function(t){var e=t[0].trace;n.select(this).selectAll(\"path\").each(function(t){if(!t.empty){var r=e[t.dir].line;n.select(this).style(\"fill\",\"none\").call(a.stroke,r.color).call(i.dashLine,r.dash,r.width).style(\"opacity\",e.selectedpoints&&!t.selected?.3:1)}})})}},{\"../../components/color\":593,\"../../components/drawing\":614,d3:163}],1067:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../plots/attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/fx/hovertemplate_attributes\"),l=t(\"../../plots/domain\").attributes,c=n({editType:\"calc\"},o(\"line\",{editTypeOverride:\"calc\"}),{shape:{valType:\"enumerated\",values:[\"linear\",\"hspline\"],dflt:\"linear\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\"]})});e.exports={domain:l({name:\"parcats\",trace:!0,editType:\"calc\"}),hoverinfo:n({},i.hoverinfo,{flags:[\"count\",\"probability\"],editType:\"plot\",arrayOk:!1}),hoveron:{valType:\"enumerated\",values:[\"category\",\"color\",\"dimension\"],dflt:\"category\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\",\"category\",\"categorycount\",\"colorcount\",\"bandcolorcount\"]}),arrangement:{valType:\"enumerated\",values:[\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"perpendicular\",editType:\"plot\"},bundlecolors:{valType:\"boolean\",dflt:!0,editType:\"plot\"},sortpaths:{valType:\"enumerated\",values:[\"forward\",\"backward\"],dflt:\"forward\",editType:\"plot\"},labelfont:a({editType:\"calc\"}),tickfont:a({editType:\"calc\"}),dimensions:{_isLinkedToArray:\"dimension\",label:{valType:\"string\",editType:\"calc\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",dflt:[],editType:\"calc\"},displayindex:{valType:\"integer\",editType:\"calc\"},editType:\"calc\",visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"}},line:c,counts:{valType:\"number\",min:0,dflt:1,arrayOk:!0,editType:\"calc\"},customdata:void 0,hoverlabel:void 0,ids:void 0,legendgroup:void 0,opacity:void 0,selectedpoints:void 0,showlegend:void 0}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1068:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"parcats\",r.plot=function(t,e,r,a){var o=n(t.calcdata,\"parcats\");if(o.length){var s=o[0];i(t,s,r,a)}},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcats\"),a=e._has&&e._has(\"parcats\");i&&!a&&n._paperdiv.selectAll(\".parcats\").remove()}},{\"../../plots/get_data\":802,\"./plot\":1073}],1069:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),o=t(\"../../lib/filter_unique.js\"),s=t(\"../../components/drawing\"),l=t(\"../../lib\");function c(t,e,r){t.valueInds.push(e),t.count+=r}function u(t,e,r){t.valueInds.push(e),t.count+=r}e.exports=function(t,e){var r=l.filterVisible(e.dimensions);if(0===r.length)return[];var h,f,p,d=r.map(function(t){var e;return\"trace\"===t.categoryorder?e=null:\"array\"===t.categoryorder?e=t.categoryarray:(e=o(t.values).sort(),\"category descending\"===t.categoryorder&&(e=e.reverse())),function(t,e){e=null==e?[]:e.map(function(t){return t});var r={},n={},i=[];e.forEach(function(t,e){r[t]=0,n[t]=e});for(var a=0;a<t.length;a++){var o,s=t[a];void 0===r[s]?(r[s]=1,o=e.push(s)-1,n[s]=o):(r[s]++,o=n[s]),i.push(o)}var l=e.map(function(t){return r[t]});return{uniqueValues:e,uniqueCounts:l,inds:i}}(t.values,e)});h=l.isArrayOrTypedArray(e.counts)?e.counts:[e.counts],function(t){var e;if(function(t){for(var e=new Array(t.length),r=0;r<t.length;r++){if(t[r]<0||t[r]>=t.length)return!1;if(void 0!==e[t[r]])return!1;e[t[r]]=!0}return!0}(t.map(function(t){return t.displayindex})))for(e=0;e<t.length;e++)t[e]._displayindex=t[e].displayindex;else for(e=0;e<t.length;e++)t[e]._displayindex=e}(r),r.forEach(function(t,e){!function(t,e){t._categoryarray=e.uniqueValues,null===t.ticktext||void 0===t.ticktext?t._ticktext=[]:t._ticktext=t.ticktext.slice();for(var r=t._ticktext.length;r<e.uniqueValues.length;r++)t._ticktext.push(e.uniqueValues[r])}(t,d[e])});var g,v=e.line;v?(i(e,\"line\")&&a(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),g=s.tryColorscale(v)):g=l.identity;var m,y,x,b,_=r[0].values.length,w={},k=d.map(function(t){return t.inds});for(p=0,m=0;m<_;m++){var T=[];for(y=0;y<k.length;y++)T.push(k[y][m]);f=h[m%h.length],p+=f;var A=(x=m,b=void 0,b=l.isArrayOrTypedArray(v.color)?v.color[x%v.color.length]:v.color,{color:g(b),rawColor:b}),M=T+\"-\"+A.rawColor;void 0===w[M]&&(w[M]={categoryInds:T,color:A.color,rawColor:A.rawColor,valueInds:[],count:0}),u(w[M],m,f)}var S,E=r.map(function(t,e){return r=e,n=t._index,i=t._displayindex,a=t.label,{dimensionInd:r,containerInd:n,displayInd:i,dimensionLabel:a,count:p,categories:[],dragX:null};var r,n,i,a});for(m=0;m<_;m++)for(f=h[m%h.length],y=0;y<E.length;y++){var C=E[y].containerInd,L=d[y].inds[m],P=E[y].categories;if(void 0===P[L]){var O=e.dimensions[C]._categoryarray[L],z=e.dimensions[C]._ticktext[L];P[L]={dimensionInd:y,categoryInd:S=L,categoryValue:O,displayInd:S,categoryLabel:z,valueInds:[],count:0,dragY:null}}c(P[L],m,f)}return n(function(t,e,r){var n=t.map(function(t){return t.categories.length}).reduce(function(t,e){return Math.max(t,e)});return{dimensions:t,paths:e,trace:void 0,maxCats:n,count:r}}(E,w,p))}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/filter_unique.js\":711,\"../../lib/gup\":717}],1070:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"./attributes\"),c=t(\"../parcoords/merge_length\");function u(t,e){function r(r,i){return n.coerce(t,e,l.dimensions,r,i)}var i=r(\"values\"),a=r(\"visible\");if(i&&i.length||(a=e.visible=!1),a){r(\"label\"),r(\"displayindex\",e._index);var o,s=t.categoryarray,c=Array.isArray(s)&&s.length>0;c&&(o=\"array\");var u=r(\"categoryorder\",o);\"array\"===u?(r(\"categoryarray\"),r(\"ticktext\")):(delete t.categoryarray,delete t.ticktext),c||\"array\"!==u||(e.categoryorder=\"trace\")}}e.exports=function(t,e,r,h){function f(r,i){return n.coerce(t,e,l,r,i)}var p=s(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=function(t,e,r,o,s){s(\"line.shape\"),s(\"line.hovertemplate\");var l=s(\"line.color\",o.colorway[0]);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,h,f);o(e,h,f),Array.isArray(p)&&p.length||(e.visible=!1),c(e,p,\"values\",d),f(\"hoveron\"),f(\"hovertemplate\"),f(\"arrangement\"),f(\"bundlecolors\"),f(\"sortpaths\"),f(\"counts\");var g={family:h.font.family,size:Math.round(h.font.size),color:h.font.color};n.coerceFont(f,\"labelfont\",g);var v={family:h.font.family,size:Math.round(h.font.size/1.2),color:h.font.color};n.coerceFont(f,\"tickfont\",v)}},{\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/domain\":792,\"../parcoords/merge_length\":1083,\"./attributes\":1067}],1071:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcats\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1067,\"./base_plot\":1068,\"./calc\":1069,\"./defaults\":1070,\"./plot\":1073}],1072:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plot_api/plot_api\"),a=t(\"../../components/fx\"),o=t(\"../../lib\"),s=t(\"../../components/drawing\"),l=t(\"tinycolor2\"),c=t(\"../../lib/svg_text_utils\");function u(t,e,r,i){var a=t.map(function(t,e,r){var n,i=r[0],a=e.margin||{l:80,r:80,t:100,b:80},o=i.trace,s=o.domain,l=e.width,c=e.height,u=Math.floor(l*(s.x[1]-s.x[0])),h=Math.floor(c*(s.y[1]-s.y[0])),f=s.x[0]*l+a.l,p=e.height-s.y[1]*e.height+a.t,d=o.line.shape;n=\"all\"===o.hoverinfo?[\"count\",\"probability\"]:(o.hoverinfo||\"\").split(\"+\");var g={trace:o,key:o.uid,model:i,x:f,y:p,width:u,height:h,hoveron:o.hoveron,hoverinfoItems:n,arrangement:o.arrangement,bundlecolors:o.bundlecolors,sortpaths:o.sortpaths,labelfont:o.labelfont,categorylabelfont:o.tickfont,pathShape:d,dragDimension:null,margin:a,paths:[],dimensions:[],graphDiv:t,traceSelection:null,pathSelection:null,dimensionSelection:null};i.dimensions&&(R(g),D(g));return g}.bind(0,e,r)),l=i.selectAll(\"g.parcatslayer\").data([null]);l.enter().append(\"g\").attr(\"class\",\"parcatslayer\").style(\"pointer-events\",\"all\");var u=l.selectAll(\"g.trace.parcats\").data(a,h),v=u.enter().append(\"g\").attr(\"class\",\"trace parcats\");u.attr(\"transform\",function(t){return\"translate(\"+t.x+\", \"+t.y+\")\"}),v.append(\"g\").attr(\"class\",\"paths\");var x=u.select(\"g.paths\").selectAll(\"path.path\").data(function(t){return t.paths},h);x.attr(\"fill\",function(t){return t.model.color});var w=x.enter().append(\"path\").attr(\"class\",\"path\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.model.color}).attr(\"fill-opacity\",0);y(w),x.attr(\"d\",function(t){return t.svgD}),w.empty()||x.sort(p),x.exit().remove(),x.on(\"mouseover\",d).on(\"mouseout\",g).on(\"click\",m),v.append(\"g\").attr(\"class\",\"dimensions\");var k=u.select(\"g.dimensions\").selectAll(\"g.dimension\").data(function(t){return t.dimensions},h);k.enter().append(\"g\").attr(\"class\",\"dimension\"),k.attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),k.exit().remove();var T=k.selectAll(\"g.category\").data(function(t){return t.categories},h),A=T.enter().append(\"g\").attr(\"class\",\"category\");T.attr(\"transform\",function(t){return\"translate(0, \"+t.y+\")\"}),A.append(\"rect\").attr(\"class\",\"catrect\").attr(\"pointer-events\",\"none\"),T.select(\"rect.catrect\").attr(\"fill\",\"none\").attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}),b(A);var P=T.selectAll(\"rect.bandrect\").data(function(t){return t.bands},h);P.each(function(){o.raiseToTop(this)}),P.attr(\"fill\",function(t){return t.color});var O=P.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.color}).attr(\"fill-opacity\",0);P.attr(\"fill\",function(t){return t.color}).attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}).attr(\"y\",function(t){return t.y}).attr(\"cursor\",function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"perpendicular\"===t.parcatsViewModel.arrangement?\"ns-resize\":\"move\"}),_(O),P.exit().remove(),A.append(\"text\").attr(\"class\",\"catlabel\").attr(\"pointer-events\",\"none\");var z=e._fullLayout.paper_bgcolor;T.select(\"text.catlabel\").attr(\"text-anchor\",function(t){return f(t)?\"start\":\"end\"}).attr(\"alignment-baseline\",\"middle\").style(\"text-shadow\",z+\" -1px  1px 2px, \"+z+\" 1px  1px 2px, \"+z+\"  1px -1px 2px, \"+z+\" -1px -1px 2px\").style(\"fill\",\"rgb(0, 0, 0)\").attr(\"x\",function(t){return f(t)?t.width+5:-5}).attr(\"y\",function(t){return t.height/2}).text(function(t){return t.model.categoryLabel}).each(function(t){s.font(n.select(this),t.parcatsViewModel.categorylabelfont),c.convertToTspans(n.select(this),e)}),A.append(\"text\").attr(\"class\",\"dimlabel\"),T.select(\"text.dimlabel\").attr(\"text-anchor\",\"middle\").attr(\"alignment-baseline\",\"baseline\").attr(\"cursor\",function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"ew-resize\"}).attr(\"x\",function(t){return t.width/2}).attr(\"y\",-5).text(function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null}).each(function(t){s.font(n.select(this),t.parcatsViewModel.labelfont)}),T.selectAll(\"rect.bandrect\").on(\"mouseover\",M).on(\"mouseout\",S),T.exit().remove(),k.call(n.behavior.drag().origin(function(t){return{x:t.x,y:0}}).on(\"dragstart\",E).on(\"drag\",C).on(\"dragend\",L)),u.each(function(t){t.traceSelection=n.select(this),t.pathSelection=n.select(this).selectAll(\"g.paths\").selectAll(\"path.path\"),t.dimensionSelection=n.select(this).selectAll(\"g.dimensions\").selectAll(\"g.dimension\")}),u.exit().remove()}function h(t){return t.key}function f(t){var e=t.parcatsViewModel.dimensions.length,r=t.parcatsViewModel.dimensions[e-1].model.dimensionInd;return t.model.dimensionInd===r}function p(t,e){return t.model.rawColor>e.model.rawColor?1:t.model.rawColor<e.model.rawColor?-1:0}function d(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){o.raiseToTop(this),x(n.select(this));var e=v(t);if(t.parcatsViewModel.graphDiv.emit(\"plotly_hover\",{points:e,event:n.event}),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\")){var r,i,s,c=n.mouse(this)[0],u=t.parcatsViewModel.graphDiv,h=t.parcatsViewModel.trace,f=u._fullLayout,p=f._paperdiv.node().getBoundingClientRect(),d=t.parcatsViewModel.graphDiv.getBoundingClientRect();for(s=0;s<t.leftXs.length-1;s++)if(t.leftXs[s]+t.dimWidths[s]-2<=c&&c<=t.leftXs[s+1]+2){var g=t.parcatsViewModel.dimensions[s],m=t.parcatsViewModel.dimensions[s+1];r=(g.x+g.width+m.x)/2,i=(t.topYs[s]+t.topYs[s+1]+t.height)/2;break}var y=t.parcatsViewModel.x+r,b=t.parcatsViewModel.y+i,_=l.mostReadable(t.model.color,[\"black\",\"white\"]),w=t.model.count,k=w/t.parcatsViewModel.model.count,T={countLabel:w,probabilityLabel:k.toFixed(3)},A=[];-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&A.push([\"Count:\",T.countLabel].join(\" \")),-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&A.push([\"P:\",T.probabilityLabel].join(\" \"));var M=A.join(\"<br>\"),S=n.mouse(u)[0];a.loneHover({trace:h,x:y-p.left+d.left,y:b-p.top+d.top,text:M,color:t.model.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:10,fontColor:_,idealAlign:S<y?\"right\":\"left\",hovertemplate:(h.line||{}).hovertemplate,hovertemplateLabels:T,eventData:[{data:h._input,fullData:h,count:w,probability:k}]},{container:f._hoverlayer.node(),outerContainer:f._paper.node(),gd:u})}}}function g(t){if(!t.parcatsViewModel.dragDimension&&(y(n.select(this)),a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()),t.parcatsViewModel.pathSelection.sort(p),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\"))){var e=v(t);t.parcatsViewModel.graphDiv.emit(\"plotly_unhover\",{points:e,event:n.event})}}function v(t){for(var e=[],r=P(t.parcatsViewModel),n=0;n<t.model.valueInds.length;n++){var i=t.model.valueInds[n];e.push({curveNumber:r,pointNumber:i})}return e}function m(t){if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){var e=v(t);t.parcatsViewModel.graphDiv.emit(\"plotly_click\",{points:e,event:n.event})}}function y(t){t.attr(\"fill\",function(t){return t.model.color}).attr(\"fill-opacity\",.6).attr(\"stroke\",\"lightgray\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1)}function x(t){t.attr(\"fill-opacity\",.8).attr(\"stroke\",function(t){return l.mostReadable(t.model.color,[\"black\",\"white\"])}).attr(\"stroke-width\",.3)}function b(t){t.select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",1).attr(\"stroke-opacity\",1)}function _(t){t.attr(\"stroke\",\"black\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1).attr(\"fill-opacity\",1)}function w(t){var e=t.parcatsViewModel.pathSelection,r=t.categoryViewModel.model.dimensionInd,n=t.categoryViewModel.model.categoryInd;return e.filter(function(e){return e.model.categoryInds[r]===n&&e.model.color===t.color})}function k(t,e,r){var i=n.select(t).datum().parcatsViewModel.graphDiv,a=n.select(t.parentNode).selectAll(\"rect.bandrect\"),o=[];a.each(function(t){w(t).each(function(t){Array.prototype.push.apply(o,v(t))})}),i.emit(e,{points:o,event:r})}function T(t,e,r){var i=n.select(t).datum(),a=i.parcatsViewModel.graphDiv,o=w(i),s=[];o.each(function(t){Array.prototype.push.apply(s,v(t))}),a.emit(e,{points:s,event:r})}function A(t,e){var r,i,a=n.select(e.parentNode).select(\"rect.catrect\"),o=a.node().getBoundingClientRect(),s=a.datum(),l=s.parcatsViewModel,c=l.model.dimensions[s.model.dimensionInd],u=l.trace,h=o.top+o.height/2;l.dimensions.length>1&&c.displayInd===l.dimensions.length-1?(r=o.left,i=\"left\"):(r=o.left+o.width,i=\"right\");var f=s.model.count,p=s.model.categoryLabel,d=f/s.parcatsViewModel.model.count,g={countLabel:f,categoryLabel:p,probabilityLabel:d.toFixed(3)},v=[];-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&v.push([\"Count:\",g.countLabel].join(\" \")),-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&v.push([\"P(\"+g.categoryLabel+\"):\",g.probabilityLabel].join(\" \"));var m=v.join(\"<br>\");return{trace:u,x:r-t.left,y:h-t.top,text:m,color:\"lightgray\",borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:12,fontColor:\"black\",idealAlign:i,hovertemplate:u.hovertemplate,hovertemplateLabels:g,eventData:[{data:u._input,fullData:u,count:f,category:p,probability:d}]}}function M(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){if(n.mouse(this)[1]<-1)return;var e,r=t.parcatsViewModel.graphDiv,i=r._fullLayout,s=i._paperdiv.node().getBoundingClientRect(),c=t.parcatsViewModel.hoveron;if(\"color\"===c?(!function(t){var e=n.select(t).datum(),r=w(e);x(r),r.each(function(){o.raiseToTop(this)}),n.select(t.parentNode).selectAll(\"rect.bandrect\").filter(function(t){return t.color===e.color}).each(function(){o.raiseToTop(this),n.select(this).attr(\"stroke\",\"black\").attr(\"stroke-width\",1.5)})}(this),T(this,\"plotly_hover\",n.event)):(!function(t){n.select(t.parentNode).selectAll(\"rect.bandrect\").each(function(t){var e=w(t);x(e),e.each(function(){o.raiseToTop(this)})}),n.select(t.parentNode).select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",2.5)}(this),k(this,\"plotly_hover\",n.event)),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\"))\"category\"===c?e=A(s,this):\"color\"===c?e=function(t,e){var r,i,a=e.getBoundingClientRect(),o=n.select(e).datum(),s=o.categoryViewModel,c=s.parcatsViewModel,u=c.model.dimensions[s.model.dimensionInd],h=c.trace,f=a.y+a.height/2;c.dimensions.length>1&&u.displayInd===c.dimensions.length-1?(r=a.left,i=\"left\"):(r=a.left+a.width,i=\"right\");var p=s.model.categoryLabel,d=o.parcatsViewModel.model.count,g=0;o.categoryViewModel.bands.forEach(function(t){t.color===o.color&&(g+=t.count)});var v=s.model.count,m=0;c.pathSelection.each(function(t){t.model.color===o.color&&(m+=t.model.count)});var y=g/d,x=g/m,b=g/v,_={countLabel:d,categoryLabel:p,probabilityLabel:y.toFixed(3)},w=[];-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&w.push([\"Count:\",_.countLabel].join(\" \")),-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&(w.push(\"P(color \\u2229 \"+p+\"): \"+_.probabilityLabel),w.push(\"P(\"+p+\" | color): \"+x.toFixed(3)),w.push(\"P(color | \"+p+\"): \"+b.toFixed(3)));var k=w.join(\"<br>\"),T=l.mostReadable(o.color,[\"black\",\"white\"]);return{trace:h,x:r-t.left,y:f-t.top,text:k,color:o.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontColor:T,fontSize:10,idealAlign:i,hovertemplate:h.hovertemplate,hovertemplateLabels:_,eventData:[{data:h._input,fullData:h,category:p,count:d,probability:y,categorycount:v,colorcount:m,bandcolorcount:g}]}}(s,this):\"dimension\"===c&&(e=function(t,e){var r=[];return n.select(e.parentNode.parentNode).selectAll(\"g.category\").select(\"rect.catrect\").each(function(){r.push(A(t,this))}),r}(s,this)),e&&a.loneHover(e,{container:i._hoverlayer.node(),outerContainer:i._paper.node(),gd:r})}}function S(t){var e=t.parcatsViewModel;if(!e.dragDimension&&(y(e.pathSelection),b(e.dimensionSelection.selectAll(\"g.category\")),_(e.dimensionSelection.selectAll(\"g.category\").selectAll(\"rect.bandrect\")),a.loneUnhover(e.graphDiv._fullLayout._hoverlayer.node()),e.pathSelection.sort(p),-1===e.hoverinfoItems.indexOf(\"skip\"))){\"color\"===t.parcatsViewModel.hoveron?T(this,\"plotly_unhover\",n.event):k(this,\"plotly_unhover\",n.event)}}function E(t){\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragDimensionDisplayInd=t.model.displayInd,t.initialDragDimensionDisplayInds=t.parcatsViewModel.model.dimensions.map(function(t){return t.displayInd}),t.dragHasMoved=!1,t.dragCategoryDisplayInd=null,n.select(this).selectAll(\"g.category\").select(\"rect.catrect\").each(function(e){var r=n.mouse(this)[0],i=n.mouse(this)[1];-2<=r&&r<=e.width+2&&-2<=i&&i<=e.height+2&&(t.dragCategoryDisplayInd=e.model.displayInd,t.initialDragCategoryDisplayInds=t.model.categories.map(function(t){return t.displayInd}),e.model.dragY=e.y,o.raiseToTop(this.parentNode),n.select(this.parentNode).selectAll(\"rect.bandrect\").each(function(e){e.y<i&&i<=e.y+e.height&&(t.potentialClickBand=this)}))}),t.parcatsViewModel.dragDimension=t,a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()))}function C(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragHasMoved=!0,null!==t.dragDimensionDisplayInd)){var e=t.dragDimensionDisplayInd,r=e-1,i=e+1,a=t.parcatsViewModel.dimensions[e];if(null!==t.dragCategoryDisplayInd){var o=a.categories[t.dragCategoryDisplayInd];o.model.dragY+=n.event.dy;var s=o.model.dragY,l=o.model.displayInd,c=a.categories,u=c[l-1],h=c[l+1];void 0!==u&&s<u.y+u.height/2&&(o.model.displayInd=u.model.displayInd,u.model.displayInd=l),void 0!==h&&s+o.height>h.y+h.height/2&&(o.model.displayInd=h.model.displayInd,h.model.displayInd=l),t.dragCategoryDisplayInd=o.model.displayInd}if(null===t.dragCategoryDisplayInd||\"freeform\"===t.parcatsViewModel.arrangement){a.model.dragX=n.event.x;var f=t.parcatsViewModel.dimensions[r],p=t.parcatsViewModel.dimensions[i];void 0!==f&&a.model.dragX<f.x+f.width&&(a.model.displayInd=f.model.displayInd,f.model.displayInd=e),void 0!==p&&a.model.dragX+a.width>p.x&&(a.model.displayInd=p.model.displayInd,p.model.displayInd=t.dragDimensionDisplayInd),t.dragDimensionDisplayInd=a.model.displayInd}R(t.parcatsViewModel),D(t.parcatsViewModel),z(t.parcatsViewModel),O(t.parcatsViewModel)}}function L(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&null!==t.dragDimensionDisplayInd){n.select(this).selectAll(\"text\").attr(\"font-weight\",\"normal\");var e={},r=P(t.parcatsViewModel),a=t.parcatsViewModel.model.dimensions.map(function(t){return t.displayInd}),o=t.initialDragDimensionDisplayInds.some(function(t,e){return t!==a[e]});o&&a.forEach(function(r,n){var i=t.parcatsViewModel.model.dimensions[n].containerInd;e[\"dimensions[\"+i+\"].displayindex\"]=r});var s=!1;if(null!==t.dragCategoryDisplayInd){var l=t.model.categories.map(function(t){return t.displayInd});if(s=t.initialDragCategoryDisplayInds.some(function(t,e){return t!==l[e]})){var c=t.model.categories.slice().sort(function(t,e){return t.displayInd-e.displayInd}),u=c.map(function(t){return t.categoryValue}),h=c.map(function(t){return t.categoryLabel});e[\"dimensions[\"+t.model.containerInd+\"].categoryarray\"]=[u],e[\"dimensions[\"+t.model.containerInd+\"].ticktext\"]=[h],e[\"dimensions[\"+t.model.containerInd+\"].categoryorder\"]=\"array\"}}if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")&&!t.dragHasMoved&&t.potentialClickBand&&(\"color\"===t.parcatsViewModel.hoveron?T(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent):k(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent)),t.model.dragX=null,null!==t.dragCategoryDisplayInd)t.parcatsViewModel.dimensions[t.dragDimensionDisplayInd].categories[t.dragCategoryDisplayInd].model.dragY=null,t.dragCategoryDisplayInd=null;t.dragDimensionDisplayInd=null,t.parcatsViewModel.dragDimension=null,t.dragHasMoved=null,t.potentialClickBand=null,R(t.parcatsViewModel),D(t.parcatsViewModel),n.transition().duration(300).ease(\"cubic-in-out\").each(function(){z(t.parcatsViewModel,!0),O(t.parcatsViewModel,!0)}).each(\"end\",function(){(o||s)&&i.restyle(t.parcatsViewModel.graphDiv,e,[r])})}}function P(t){for(var e,r=t.graphDiv._fullData,n=0;n<r.length;n++)if(t.key===r[n].uid){e=n;break}return e}function O(t,e){var r;void 0===e&&(e=!1),t.pathSelection.data(function(t){return t.paths},h),(r=t.pathSelection,e?r.transition():r).attr(\"d\",function(t){return t.svgD})}function z(t,e){function r(t){return e?t.transition():t}void 0===e&&(e=!1),t.dimensionSelection.data(function(t){return t.dimensions},h);var i=t.dimensionSelection.selectAll(\"g.category\").data(function(t){return t.categories},h);r(t.dimensionSelection).attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),r(i).attr(\"transform\",function(t){return\"translate(0, \"+t.y+\")\"}),i.select(\".dimlabel\").text(function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null}),i.select(\".catlabel\").attr(\"text-anchor\",function(t){return f(t)?\"start\":\"end\"}).attr(\"x\",function(t){return f(t)?t.width+5:-5}).each(function(t){var e,r;f(t)?(e=t.width+5,r=\"start\"):(e=-5,r=\"end\"),n.select(this).selectAll(\"tspan\").attr(\"x\",e).attr(\"text-anchor\",r)});var a=i.selectAll(\"rect.bandrect\").data(function(t){return t.bands},h),s=a.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"cursor\",\"move\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.color}).attr(\"fill-opacity\",0);a.attr(\"fill\",function(t){return t.color}).attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}).attr(\"y\",function(t){return t.y}),_(s),a.each(function(){o.raiseToTop(this)}),a.exit().remove()}function I(t,e,r,i,a){var o,s,l=[],c=[];for(s=0;s<r.length-1;s++)o=n.interpolateNumber(r[s]+t[s],t[s+1]),l.push(o(a)),c.push(o(1-a));var u=\"M \"+t[0]+\",\"+e[0];for(u+=\"l\"+r[0]+\",0 \",s=1;s<r.length;s++)u+=\"C\"+l[s-1]+\",\"+e[s-1]+\" \"+c[s-1]+\",\"+e[s]+\" \"+t[s]+\",\"+e[s],u+=\"l\"+r[s]+\",0 \";for(u+=\"l0,\"+i+\" \",u+=\"l -\"+r[r.length-1]+\",0 \",s=r.length-2;s>=0;s--)u+=\"C\"+c[s]+\",\"+(e[s+1]+i)+\" \"+l[s]+\",\"+(e[s]+i)+\" \"+(t[s]+r[s])+\",\"+(e[s]+i),u+=\"l-\"+r[s]+\",0 \";return u+=\"Z\"}function D(t){var e=t.dimensions,r=t.model,n=e.map(function(t){return t.categories.map(function(t){return t.y})}),i=t.model.dimensions.map(function(t){return t.categories.map(function(t){return t.displayInd})}),a=t.model.dimensions.map(function(t){return t.displayInd}),o=t.dimensions.map(function(t){return t.model.dimensionInd}),s=e.map(function(t){return t.x}),l=e.map(function(t){return t.width}),c=[];for(var u in r.paths)r.paths.hasOwnProperty(u)&&c.push(r.paths[u]);function h(t){var e=t.categoryInds.map(function(t,e){return i[e][t]});return o.map(function(t){return e[t]})}c.sort(function(e,r){var n=h(e),i=h(r);return\"backward\"===t.sortpaths&&(n.reverse(),i.reverse()),n.push(e.valueInds[0]),i.push(r.valueInds[0]),t.bundlecolors&&(n.unshift(e.rawColor),i.unshift(r.rawColor)),n<i?-1:n>i?1:0});for(var f=new Array(c.length),p=e[0].model.count,d=e[0].categories.map(function(t){return t.height}).reduce(function(t,e){return t+e}),g=0;g<c.length;g++){var v,m=c[g];v=p>0?d*(m.count/p):0;for(var y,x=new Array(n.length),b=0;b<m.categoryInds.length;b++){var _=m.categoryInds[b],w=i[b][_],k=a[b];x[k]=n[k][w],n[k][w]+=v;var T=t.dimensions[k].categories[w],A=T.bands.length,M=T.bands[A-1];if(void 0===M||m.rawColor!==M.rawColor){var S=void 0===M?0:M.y+M.height;T.bands.push({key:S,color:m.color,rawColor:m.rawColor,height:v,width:T.width,count:m.count,y:S,categoryViewModel:T,parcatsViewModel:t})}else{var E=T.bands[A-1];E.height+=v,E.count+=m.count}}y=\"hspline\"===t.pathShape?I(s,x,l,v,.5):I(s,x,l,v,0),f[g]={key:m.valueInds[0],model:m,height:v,leftXs:s,topYs:x,dimWidths:l,svgD:y,parcatsViewModel:t}}t.paths=f}function R(t){var e=t.model.dimensions.map(function(t){return{displayInd:t.displayInd,dimensionInd:t.dimensionInd}});e.sort(function(t,e){return t.displayInd-e.displayInd});var r=[];for(var n in e){var i=e[n].dimensionInd,a=t.model.dimensions[i];r.push(F(t,a))}t.dimensions=r}function F(t,e){var r,n=t.model.dimensions.length,i=e.displayInd;r=40+(n>1?(t.width-80-16)/(n-1):0)*i;var a,o,s,l,c,u=[],h=t.model.maxCats,f=e.categories.length,p=e.count,d=t.height-8*(h-1),g=8*(h-f)/2,v=e.categories.map(function(t){return{displayInd:t.displayInd,categoryInd:t.categoryInd}});for(v.sort(function(t,e){return t.displayInd-e.displayInd}),c=0;c<f;c++)l=v[c].categoryInd,o=e.categories[l],a=p>0?o.count/p*d:0,s={key:o.valueInds[0],model:o,width:16,height:a,y:null!==o.dragY?o.dragY:g,bands:[],parcatsViewModel:t},g=g+a+8,u.push(s);return{key:e.dimensionInd,x:null!==e.dragX?e.dragX:r,y:0,width:16,model:e,categories:u,parcatsViewModel:t,dragCategoryDisplayInd:null,dragDimensionDisplayInd:null,initialDragDimensionDisplayInds:null,initialDragCategoryDisplayInds:null,dragHasMoved:null,potentialClickBand:null}}e.exports=function(t,e,r,n){u(r,t,n,e)}},{\"../../components/drawing\":614,\"../../components/fx\":632,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_api\":754,d3:163,tinycolor2:537}],1073:[function(t,e,r){\"use strict\";var n=t(\"./parcats\");e.exports=function(t,e,r,i){var a=t._fullLayout,o=a._paper,s=a._size;n(t,o,e,{width:s.w,height:s.h,margin:{t:s.t,r:s.r,b:s.b,l:s.l}},r,i)}},{\"./parcats\":1072}],1074:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/cartesian/layout_attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../plots/domain\").attributes,s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/plot_template\").templatedArray;e.exports={domain:o({name:\"parcoords\",trace:!0,editType:\"plot\"}),labelangle:{valType:\"angle\",dflt:0,editType:\"plot\"},labelside:{valType:\"enumerated\",values:[\"top\",\"bottom\"],dflt:\"top\",editType:\"plot\"},labelfont:a({editType:\"plot\"}),tickfont:a({editType:\"plot\"}),rangefont:a({editType:\"plot\"}),dimensions:l(\"dimension\",{label:{valType:\"string\",editType:\"plot\"},tickvals:s({},i.tickvals,{editType:\"plot\"}),ticktext:s({},i.ticktext,{editType:\"plot\"}),tickformat:s({},i.tickformat,{editType:\"plot\"}),visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},constraintrange:{valType:\"info_array\",freeLength:!0,dimensions:\"1-2\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},multiselect:{valType:\"boolean\",dflt:!0,editType:\"plot\"},values:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"}),line:s({editType:\"calc\"},n(\"line\",{colorscaleDflt:\"Viridis\",autoColorDflt:!1,editTypeOverride:\"calc\"}))}},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1075:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\").keyFun,o=t(\"../../lib/gup\").repeat,s=t(\"../../lib\").sorterAsc,l=n.bar.snapRatio;function c(t,e){return t*(1-l)+e*l}var u=n.bar.snapClose;function h(t,e){return t*(1-u)+e*u}function f(t,e,r,n){if(function(t,e){for(var r=0;r<e.length;r++)if(t>=e[r][0]&&t<=e[r][1])return!0;return!1}(r,n))return r;var i=t?-1:1,a=0,o=e.length-1;if(i<0){var s=a;a=o,o=s}for(var l=e[a],u=l,f=a;i*f<i*o;f+=i){var p=f+i,d=e[p];if(i*r<i*h(l,d))return c(l,u);if(i*r<i*d||p===o)return c(d,l);u=l,l=d}}function p(t){t.attr(\"x\",-n.bar.captureWidth/2).attr(\"width\",n.bar.captureWidth)}function d(t){t.attr(\"visibility\",\"visible\").style(\"visibility\",\"visible\").attr(\"fill\",\"yellow\").attr(\"opacity\",0)}function g(t){if(!t.brush.filterSpecified)return\"0,\"+t.height;for(var e,r,n,i=v(t.brush.filter.getConsolidated(),t.height),a=[0],o=i.length?i[0][0]:null,s=0;s<i.length;s++)r=(e=i[s])[1]-e[0],a.push(o),a.push(r),(n=s+1)<i.length&&(o=i[n][0]-e[1]);return a.push(t.height),a}function v(t,e){return t.map(function(t){return t.map(function(t){return Math.max(0,t*e)}).sort(s)})}function m(){i.select(document.body).style(\"cursor\",null)}function y(t){t.attr(\"stroke-dasharray\",g)}function x(t,e){var r=i.select(t).selectAll(\".highlight, .highlight-shadow\");y(e?r.transition().duration(n.bar.snapDuration).each(\"end\",e):r)}function b(t,e){var r,i=t.brush,a=NaN,o={};if(i.filterSpecified){var s=t.height,l=i.filter.getConsolidated(),c=v(l,s),u=NaN,h=NaN,f=NaN;for(r=0;r<=c.length;r++){var p=c[r];if(p&&p[0]<=e&&e<=p[1]){u=r;break}if(h=r?r-1:NaN,p&&p[0]>e){f=r;break}}if(a=u,isNaN(a)&&(a=isNaN(h)||isNaN(f)?isNaN(h)?f:h:e-c[h][1]<c[f][0]-e?h:f),!isNaN(a)){var d=c[a],g=function(t,e){var r=n.bar.handleHeight;if(!(e>t[1]+r||e<t[0]-r))return e>=.9*t[1]+.1*t[0]?\"n\":e<=.9*t[0]+.1*t[1]?\"s\":\"ns\"}(d,e);g&&(o.interval=l[a],o.intervalPix=d,o.region=g)}}if(t.ordinal&&!o.region){var m=t.unitTickvals,y=t.unitToPaddedPx.invert(e);for(r=0;r<m.length;r++){var x=[.25*m[Math.max(r-1,0)]+.75*m[r],.25*m[Math.min(r+1,m.length-1)]+.75*m[r]];if(y>=x[0]&&y<=x[1]){o.clickableOrdinalRange=x;break}}}return o}function _(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.brush.svgBrush;a.wasDragged=!0,a._dragging=!0,a.grabbingBar?a.newExtent=[r-a.grabPoint,r+a.barLength-a.grabPoint].map(e.unitToPaddedPx.invert):a.newExtent=[a.startExtent,e.unitToPaddedPx.invert(r)].sort(s),e.brush.filterSpecified=!0,a.extent=a.stayingIntervals.concat([a.newExtent]),a.brushCallback(e),x(t.parentNode)}function w(t,e){var r=b(e,e.height-i.mouse(t)[1]-2*n.verticalPadding),a=\"crosshair\";r.clickableOrdinalRange?a=\"pointer\":r.region&&(a=r.region+\"-resize\"),i.select(document.body).style(\"cursor\",a)}function k(t){t.on(\"mousemove\",function(t){i.event.preventDefault(),t.parent.inBrushDrag||w(this,t)}).on(\"mouseleave\",function(t){t.parent.inBrushDrag||m()}).call(i.behavior.drag().on(\"dragstart\",function(t){!function(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.unitToPaddedPx.invert(r),o=e.brush,s=b(e,r),l=s.interval,c=o.svgBrush;if(c.wasDragged=!1,c.grabbingBar=\"ns\"===s.region,c.grabbingBar){var u=l.map(e.unitToPaddedPx);c.grabPoint=r-u[0]-n.verticalPadding,c.barLength=u[1]-u[0]}c.clickableOrdinalRange=s.clickableOrdinalRange,c.stayingIntervals=e.multiselect&&o.filterSpecified?o.filter.getConsolidated():[],l&&(c.stayingIntervals=c.stayingIntervals.filter(function(t){return t[0]!==l[0]&&t[1]!==l[1]})),c.startExtent=s.region?l[\"s\"===s.region?1:0]:a,e.parent.inBrushDrag=!0,c.brushStartCallback()}(this,t)}).on(\"drag\",function(t){_(this,t)}).on(\"dragend\",function(t){!function(t,e){var r=e.brush,n=r.filter,a=r.svgBrush;a._dragging||(w(t,e),_(t,e),e.brush.svgBrush.wasDragged=!1),a._dragging=!1,i.event.sourceEvent.stopPropagation();var o=a.grabbingBar;if(a.grabbingBar=!1,a.grabLocation=void 0,e.parent.inBrushDrag=!1,m(),!a.wasDragged)return a.wasDragged=void 0,a.clickableOrdinalRange?r.filterSpecified&&e.multiselect?a.extent.push(a.clickableOrdinalRange):(a.extent=[a.clickableOrdinalRange],r.filterSpecified=!0):o?(a.extent=a.stayingIntervals,0===a.extent.length&&A(r)):A(r),a.brushCallback(e),x(t.parentNode),void a.brushEndCallback(r.filterSpecified?n.getConsolidated():[]);var s=function(){n.set(n.getConsolidated())};if(e.ordinal){var l=e.unitTickvals;l[l.length-1]<l[0]&&l.reverse(),a.newExtent=[f(0,l,a.newExtent[0],a.stayingIntervals),f(1,l,a.newExtent[1],a.stayingIntervals)];var c=a.newExtent[1]>a.newExtent[0];a.extent=a.stayingIntervals.concat(c?[a.newExtent]:[]),a.extent.length||A(r),a.brushCallback(e),c?x(t.parentNode,s):(s(),x(t.parentNode))}else s();a.brushEndCallback(r.filterSpecified?n.getConsolidated():[])}(this,t)}))}function T(t,e){return t[0]-e[0]}function A(t){t.filterSpecified=!1,t.svgBrush.extent=[[-1/0,1/0]]}function M(t){for(var e,r=t.slice(),n=[],i=r.shift();i;){for(e=i.slice();(i=r.shift())&&i[0]<=e[1];)e[1]=Math.max(e[1],i[1]);n.push(e)}return n}e.exports={makeBrush:function(t,e,r,n,i,a){var o,l=function(){var t,e,r=[];return{set:function(n){1===(r=n.map(function(t){return t.slice().sort(s)}).sort(T)).length&&r[0][0]===-1/0&&r[0][1]===1/0&&(r=[[0,-1]]),t=M(r),e=r.reduce(function(t,e){return[Math.min(t[0],e[0]),Math.max(t[1],e[1])]},[1/0,-1/0])},get:function(){return r.slice()},getConsolidated:function(){return t},getBounds:function(){return e}}}();return l.set(r),{filter:l,filterSpecified:e,svgBrush:{extent:[],brushStartCallback:n,brushCallback:(o=i,function(t){var e=t.brush,r=function(t){return t.svgBrush.extent.map(function(t){return t.slice()})}(e).slice();e.filter.set(r),o()}),brushEndCallback:a}}},ensureAxisBrush:function(t){var e=t.selectAll(\".\"+n.cn.axisBrush).data(o,a);e.enter().append(\"g\").classed(n.cn.axisBrush,!0),function(t){var e=t.selectAll(\".background\").data(o);e.enter().append(\"rect\").classed(\"background\",!0).call(p).call(d).style(\"pointer-events\",\"auto\").attr(\"transform\",\"translate(0 \"+n.verticalPadding+\")\"),e.call(k).attr(\"height\",function(t){return t.height-n.verticalPadding});var r=t.selectAll(\".highlight-shadow\").data(o);r.enter().append(\"line\").classed(\"highlight-shadow\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width+n.bar.strokeWidth).attr(\"stroke\",n.bar.strokeColor).attr(\"opacity\",n.bar.strokeOpacity).attr(\"stroke-linecap\",\"butt\"),r.attr(\"y1\",function(t){return t.height}).call(y);var i=t.selectAll(\".highlight\").data(o);i.enter().append(\"line\").classed(\"highlight\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width-n.bar.strokeWidth).attr(\"stroke\",n.bar.fillColor).attr(\"opacity\",n.bar.fillOpacity).attr(\"stroke-linecap\",\"butt\"),i.attr(\"y1\",function(t){return t.height}).call(y)}(e)},cleanRanges:function(t,e){if(Array.isArray(t[0])?(t=t.map(function(t){return t.sort(s)}),t=e.multiselect?M(t.sort(T)):[t[0]]):t=[t.sort(s)],e.tickvals){var r=e.tickvals.slice().sort(s);if(!(t=t.map(function(t){var e=[f(0,r,t[0],[]),f(1,r,t[1],[])];if(e[1]>e[0])return e}).filter(function(t){return t})).length)return}return t.length>1?t:t[0]}}},{\"../../lib\":719,\"../../lib/gup\":717,\"./constants\":1078,d3:163}],1076:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../constants/xmlns_namespaces\");r.name=\"parcoords\",r.plot=function(t){var e=i(t.calcdata,\"parcoords\")[0];e.length&&a(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcoords\"),a=e._has&&e._has(\"parcoords\");i&&!a&&(n._paperdiv.selectAll(\".parcoords\").remove(),n._glimages.selectAll(\"*\").remove())},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter(function(t,e){return e===r.size()-1}).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each(function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})}),window.setTimeout(function(){n.selectAll(\"#filterBarPattern\").attr(\"id\",\"filterBarPattern\")},60)}},{\"../../constants/xmlns_namespaces\":696,\"../../plots/get_data\":802,\"./plot\":1085,d3:163}],1077:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale\"),a=t(\"../../lib/gup\").wrap;e.exports=function(t,e){var r,o;return i.hasColorscale(e,\"line\")&&n(e.line.color)?(r=e.line.color,o=i.extractOpts(e.line).colorscale,i.calc(t,e,{vals:r,containerStr:\"line\",cLetter:\"c\"})):(r=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=.5;return e}(e._length),o=[[0,e.line.color],[1,e.line.color]]),a({lineColor:r,cscale:o})}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gup\":717}],1078:[function(t,e,r){\"use strict\";e.exports={maxDimensionCount:60,overdrag:45,verticalPadding:2,tickDistance:50,canvasPixelRatio:1,blockLineCount:5e3,layers:[\"contextLineLayer\",\"focusLineLayer\",\"pickLineLayer\"],axisTitleOffset:28,axisExtentOffset:10,deselectedLineColor:\"#777\",bar:{width:4,captureWidth:10,fillColor:\"magenta\",fillOpacity:1,snapDuration:150,snapRatio:.25,snapClose:.01,strokeColor:\"white\",strokeOpacity:1,strokeWidth:1,handleHeight:8,handleOpacity:1,handleOverlap:0},cn:{axisExtentText:\"axis-extent-text\",parcoordsLineLayers:\"parcoords-line-layers\",parcoordsLineLayer:\"parcoords-lines\",parcoords:\"parcoords\",parcoordsControlView:\"parcoords-control-view\",yAxis:\"y-axis\",axisOverlays:\"axis-overlays\",axis:\"axis\",axisHeading:\"axis-heading\",axisTitle:\"axis-title\",axisExtent:\"axis-extent\",axisExtentTop:\"axis-extent-top\",axisExtentTopText:\"axis-extent-top-text\",axisExtentBottom:\"axis-extent-bottom\",axisExtentBottomText:\"axis-extent-bottom-text\",axisBrush:\"axis-brush\"},id:{filterBarPattern:\"filter-bar-pattern\"}}},{}],1079:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"../../plots/cartesian/axes\"),c=t(\"./attributes\"),u=t(\"./axisbrush\"),h=t(\"./constants\").maxDimensionCount,f=t(\"./merge_length\");function p(t,e,r,i){function a(r,i){return n.coerce(t,e,c.dimensions,r,i)}var o=a(\"values\"),s=a(\"visible\");if(o&&o.length||(s=e.visible=!1),s){a(\"label\"),a(\"tickvals\"),a(\"ticktext\"),a(\"tickformat\");var h=a(\"range\");e._ax={_id:\"y\",type:\"linear\",showexponent:\"all\",exponentformat:\"B\",range:h},l.setConvert(e._ax,i.layout),a(\"multiselect\");var f=a(\"constraintrange\");f&&(e.constraintrange=u.cleanRanges(f,e))}}e.exports=function(t,e,r,l){function u(r,i){return n.coerce(t,e,c,r,i)}var d=t.dimensions;Array.isArray(d)&&d.length>h&&(n.log(\"parcoords traces support up to \"+h+\" dimensions at the moment\"),d.splice(h));var g=s(t,e,{name:\"dimensions\",layout:l,handleItemDefaults:p}),v=function(t,e,r,o,s){var l=s(\"line.color\",r);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,l,u);o(e,l,u),Array.isArray(g)&&g.length||(e.visible=!1),f(e,g,\"values\",v);var m={family:l.font.family,size:Math.round(l.font.size/1.2),color:l.font.color};n.coerceFont(u,\"labelfont\",m),n.coerceFont(u,\"tickfont\",m),n.coerceFont(u,\"rangefont\",m),u(\"labelangle\"),u(\"labelside\")}},{\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"../../plots/domain\":792,\"./attributes\":1074,\"./axisbrush\":1075,\"./constants\":1078,\"./merge_length\":1083}],1080:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isTypedArray;r.convertTypedArray=function(t){return n(t)?Array.prototype.slice.call(t):t},r.isOrdinal=function(t){return!!t.tickvals},r.isVisible=function(t){return t.visible||!(\"visible\"in t)}},{\"../../lib\":719}],1081:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcoords\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"noOpacity\",\"noHover\"],meta:{}}},{\"./attributes\":1074,\"./base_plot\":1076,\"./calc\":1077,\"./defaults\":1079,\"./plot\":1085}],1082:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nattribute vec4 p01_04, p05_08, p09_12, p13_16,\\n               p17_20, p21_24, p25_28, p29_32,\\n               p33_36, p37_40, p41_44, p45_48,\\n               p49_52, p53_56, p57_60, colors;\\n\\nuniform mat4 dim0A, dim1A, dim0B, dim1B, dim0C, dim1C, dim0D, dim1D,\\n             loA, hiA, loB, hiB, loC, hiC, loD, hiD;\\n\\nuniform vec2 resolution, viewBoxPos, viewBoxSize;\\nuniform sampler2D mask, palette;\\nuniform float maskHeight;\\nuniform float drwLayer; // 0: context, 1: focus, 2: pick\\nuniform vec4 contextColor;\\n\\nbool isPick    = (drwLayer > 1.5);\\nbool isContext = (drwLayer < 0.5);\\n\\nconst vec4 ZEROS = vec4(0.0, 0.0, 0.0, 0.0);\\nconst vec4 UNITS = vec4(1.0, 1.0, 1.0, 1.0);\\n\\nfloat val(mat4 p, mat4 v) {\\n    return dot(matrixCompMult(p, v) * UNITS, UNITS);\\n}\\n\\nfloat axisY(float ratio, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float y1 = val(A, dim0A) + val(B, dim0B) + val(C, dim0C) + val(D, dim0D);\\n    float y2 = val(A, dim1A) + val(B, dim1B) + val(C, dim1C) + val(D, dim1D);\\n    return y1 * (1.0 - ratio) + y2 * ratio;\\n}\\n\\nint iMod(int a, int b) {\\n    return a - b * (a / b);\\n}\\n\\nbool fOutside(float p, float lo, float hi) {\\n    return (lo < hi) && (lo > p || p > hi);\\n}\\n\\nbool vOutside(vec4 p, vec4 lo, vec4 hi) {\\n    return (\\n        fOutside(p[0], lo[0], hi[0]) ||\\n        fOutside(p[1], lo[1], hi[1]) ||\\n        fOutside(p[2], lo[2], hi[2]) ||\\n        fOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool mOutside(mat4 p, mat4 lo, mat4 hi) {\\n    return (\\n        vOutside(p[0], lo[0], hi[0]) ||\\n        vOutside(p[1], lo[1], hi[1]) ||\\n        vOutside(p[2], lo[2], hi[2]) ||\\n        vOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool outsideBoundingBox(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    return mOutside(A, loA, hiA) ||\\n           mOutside(B, loB, hiB) ||\\n           mOutside(C, loC, hiC) ||\\n           mOutside(D, loD, hiD);\\n}\\n\\nbool outsideRasterMask(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    mat4 pnts[4];\\n    pnts[0] = A;\\n    pnts[1] = B;\\n    pnts[2] = C;\\n    pnts[3] = D;\\n\\n    for(int i = 0; i < 4; ++i) {\\n        for(int j = 0; j < 4; ++j) {\\n            for(int k = 0; k < 4; ++k) {\\n                if(0 == iMod(\\n                    int(255.0 * texture2D(mask,\\n                        vec2(\\n                            (float(i * 2 + j / 2) + 0.5) / 8.0,\\n                            (pnts[i][j][k] * (maskHeight - 1.0) + 1.0) / maskHeight\\n                        ))[3]\\n                    ) / int(pow(2.0, float(iMod(j * 4 + k, 8)))),\\n                    2\\n                )) return true;\\n            }\\n        }\\n    }\\n    return false;\\n}\\n\\nvec4 position(bool isContext, float v, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float x = 0.5 * sign(v) + 0.5;\\n    float y = axisY(x, A, B, C, D);\\n    float z = 1.0 - abs(v);\\n\\n    z += isContext ? 0.0 : 2.0 * float(\\n        outsideBoundingBox(A, B, C, D) ||\\n        outsideRasterMask(A, B, C, D)\\n    );\\n\\n    return vec4(\\n        2.0 * (vec2(x, y) * viewBoxSize + viewBoxPos) / resolution - 1.0,\\n        z,\\n        1.0\\n    );\\n}\\n\\nvoid main() {\\n    mat4 A = mat4(p01_04, p05_08, p09_12, p13_16);\\n    mat4 B = mat4(p17_20, p21_24, p25_28, p29_32);\\n    mat4 C = mat4(p33_36, p37_40, p41_44, p45_48);\\n    mat4 D = mat4(p49_52, p53_56, p57_60, ZEROS);\\n\\n    float v = colors[3];\\n\\n    gl_Position = position(isContext, v, A, B, C, D);\\n\\n    fragColor =\\n        isContext ? vec4(contextColor) :\\n        isPick ? vec4(colors.rgb, 1.0) : texture2D(palette, vec2(abs(v), 0.5));\\n}\\n\"]),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n    gl_FragColor = fragColor;\\n}\\n\"]),o=t(\"./constants\").maxDimensionCount,s=t(\"../../lib\"),l=1e-6,c=2048,u=new Uint8Array(4),h=new Uint8Array(4),f={shape:[256,1],format:\"rgba\",type:\"uint8\",mag:\"nearest\",min:\"nearest\"};function p(t,e,r,n,i){var a=t._gl;a.enable(a.SCISSOR_TEST),a.scissor(e,r,n,i),t.clear({color:[0,0,0,0],depth:1})}function d(t,e,r,n,i,a){var o=a.key;r.drawCompleted||(!function(t){t.read({x:0,y:0,width:1,height:1,data:u})}(t),r.drawCompleted=!0),function s(l){var c=Math.min(n,i-l*n);0===l&&(window.cancelAnimationFrame(r.currentRafs[o]),delete r.currentRafs[o],p(t,a.scissorX,a.scissorY,a.scissorWidth,a.viewBoxSize[1])),r.clearOnly||(a.count=2*c,a.offset=2*l*n,e(a),l*n+c<i&&(r.currentRafs[o]=window.requestAnimationFrame(function(){s(l+1)})),r.drawCompleted=!1)}(0)}function g(t,e){return(t>>>8*e)%256/255}function v(t,e,r){for(var n=new Array(8*e),i=0,a=0;a<e;a++)for(var o=0;o<2;o++)for(var s=0;s<4;s++){var l=4*t+s,c=r[64*a+l];63===l&&0===o&&(c*=-1),n[i++]=c}return n}function m(t){var e=\"0\"+t;return e.substr(e.length-2)}function y(t){return t<o?\"p\"+m(t+1)+\"_\"+m(t+4):\"colors\"}function x(t,e,r,n,i,a,o,l,c,u,h,f,p){for(var d=[[],[]],g=0;g<64;g++)d[0][g]=g===i?1:0,d[1][g]=g===a?1:0;var v=t.lines.canvasOverdrag,m=t.domain,y=t.canvasWidth,x=t.canvasHeight,b=t.deselectedLines.color;return s.extendFlat({key:h,resolution:[y,x],viewBoxPos:[o+v,l],viewBoxSize:[c,u],i0:i,i1:a,dim0A:d[0].slice(0,16),dim0B:d[0].slice(16,32),dim0C:d[0].slice(32,48),dim0D:d[0].slice(48,64),dim1A:d[1].slice(0,16),dim1B:d[1].slice(16,32),dim1C:d[1].slice(32,48),dim1D:d[1].slice(48,64),drwLayer:f,contextColor:[b[0]/255,b[1]/255,b[2]/255,b[3]<1?b[3]:Math.max(1/255,Math.pow(1/t.lines.color.length,1/3))],scissorX:(n===e?0:o+v)+(t.pad.l-v)+t.layoutWidth*m.x[0],scissorWidth:(n===r?y-o+v:c+.5)+(n===e?o+v:0),scissorY:l+t.pad.b+t.layoutHeight*m.y[0],scissorHeight:u,viewportX:t.pad.l-v+t.layoutWidth*m.x[0],viewportY:t.pad.b+t.layoutHeight*m.y[0],viewportWidth:y,viewportHeight:x},p)}function b(t){var e=c-1,r=Math.max(0,Math.floor(t[0]*e),0),n=Math.min(e,Math.ceil(t[1]*e),e);return[Math.min(r,n),Math.max(r,n)]}e.exports=function(t,e){var r,n,u,m,_,w=e.context,k=e.pick,T=e.regl,A={currentRafs:{},drawCompleted:!0,clearOnly:!1},M=function(t){for(var e={},r=0;r<=o;r+=4)e[y(r)]=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)});return e}(T),S=T.texture(f),E=[];L(e);var C=T({profile:!1,blend:{enable:w,func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:1,dstAlpha:1},equation:{rgb:\"add\",alpha:\"add\"},color:[0,0,0,0]},depth:{enable:!w,mask:!0,func:\"less\",range:[0,1]},cull:{enable:!0,face:\"back\"},scissor:{enable:!0,box:{x:T.prop(\"scissorX\"),y:T.prop(\"scissorY\"),width:T.prop(\"scissorWidth\"),height:T.prop(\"scissorHeight\")}},viewport:{x:T.prop(\"viewportX\"),y:T.prop(\"viewportY\"),width:T.prop(\"viewportWidth\"),height:T.prop(\"viewportHeight\")},dither:!1,vert:i,frag:a,primitive:\"lines\",lineWidth:1,attributes:M,uniforms:{resolution:T.prop(\"resolution\"),viewBoxPos:T.prop(\"viewBoxPos\"),viewBoxSize:T.prop(\"viewBoxSize\"),dim0A:T.prop(\"dim0A\"),dim1A:T.prop(\"dim1A\"),dim0B:T.prop(\"dim0B\"),dim1B:T.prop(\"dim1B\"),dim0C:T.prop(\"dim0C\"),dim1C:T.prop(\"dim1C\"),dim0D:T.prop(\"dim0D\"),dim1D:T.prop(\"dim1D\"),loA:T.prop(\"loA\"),hiA:T.prop(\"hiA\"),loB:T.prop(\"loB\"),hiB:T.prop(\"hiB\"),loC:T.prop(\"loC\"),hiC:T.prop(\"hiC\"),loD:T.prop(\"loD\"),hiD:T.prop(\"hiD\"),palette:S,contextColor:T.prop(\"contextColor\"),mask:T.prop(\"maskTexture\"),drwLayer:T.prop(\"drwLayer\"),maskHeight:T.prop(\"maskHeight\")},offset:T.prop(\"offset\"),count:T.prop(\"count\")});function L(t){r=t.model,n=t.viewModel,u=n.dimensions.slice(),m=u[0]?u[0].values.length:0;var e=r.lines,i=k?e.color.map(function(t,r){return r/e.color.length}):e.color,a=function(t,e,r){for(var n,i=new Array(t*(o+4)),a=0,s=0;s<t;s++){for(var c=0;c<o;c++)i[a++]=c<e.length?e[c].paddedUnitValues[s]:.5;i[a++]=g(s,2),i[a++]=g(s,1),i[a++]=g(s,0),i[a++]=(n=r[s],Math.max(l,Math.min(1-l,n)))}return i}(m,u,i);!function(t,e,r){for(var n=0;n<=o;n+=4)t[y(n)](v(n/4,e,r))}(M,m,a),w||k||(S=T.texture(s.extendFlat({data:function(t,e){for(var r=new Array(256),n=0;n<256;n++)r[n]=t(n/255).concat(e);return r}(r.unitToColor,255)},f)))}return{render:function(t,e,n){var i,a,o,s=t.length,l=1/0,h=-1/0;for(i=0;i<s;i++)t[i].dim0.canvasX<l&&(l=t[i].dim0.canvasX,a=i),t[i].dim1.canvasX>h&&(h=t[i].dim1.canvasX,o=i);0===s&&p(T,0,0,r.canvasWidth,r.canvasHeight);var f=function(t){var e,r,n,i=[[],[]];for(n=0;n<64;n++){var a=!t&&n<u.length?u[n].brush.filter.getBounds():[-1/0,1/0];i[0][n]=a[0],i[1][n]=a[1]}var o=8*c,s=new Array(o);for(e=0;e<o;e++)s[e]=255;if(!t)for(e=0;e<u.length;e++){var l=e%8,h=(e-l)/8,f=Math.pow(2,l),p=u[e].brush.filter.get();if(!(p.length<2)){var d=b(p[0])[1];for(r=1;r<p.length;r++){var g=b(p[r]);for(n=d+1;n<g[0];n++)s[8*n+h]&=~f;d=Math.max(d,g[1])}}}var v={shape:[8,c],format:\"alpha\",type:\"uint8\",mag:\"nearest\",min:\"nearest\",data:s};return _?_(v):_=T.texture(v),{maskTexture:_,maskHeight:c,loA:i[0].slice(0,16),loB:i[0].slice(16,32),loC:i[0].slice(32,48),loD:i[0].slice(48,64),hiA:i[1].slice(0,16),hiB:i[1].slice(16,32),hiC:i[1].slice(32,48),hiD:i[1].slice(48,64)}}(w);for(i=0;i<s;i++){var g=t[i],v=g.dim0.crossfilterDimensionIndex,y=g.dim1.crossfilterDimensionIndex,M=g.canvasX,S=g.canvasY,L=M+g.panelSizeX;if(e||!E[v]||E[v][0]!==M||E[v][1]!==L){E[v]=[M,L];var P=x(r,a,o,i,v,y,M,S,g.panelSizeX,g.panelSizeY,g.dim0.crossfilterDimensionIndex,w?0:k?2:1,f);A.clearOnly=n;var O=e?r.lines.blockLineCount:m;d(T,C,A,O,m,P)}}},readPixel:function(t,e){return T.read({x:t,y:e,width:1,height:1,data:h}),h},readPixels:function(t,e,r,n){var i=new Uint8Array(4*r*n);return T.read({x:t,y:e,width:r,height:n,data:i}),i},destroy:function(){for(var e in t.style[\"pointer-events\"]=\"none\",S.destroy(),_&&_.destroy(),M)M[e].destroy()},update:L}}},{\"../../lib\":719,\"./constants\":1078,glslify:409}],1083:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a;for(n||(n=1/0),i=0;i<e.length;i++)(a=e[i]).visible&&(n=Math.min(n,a[r].length));for(n===1/0&&(n=0),t._length=n,i=0;i<e.length;i++)(a=e[i]).visible&&(a._length=n);return n}},{}],1084:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"color-rgba\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../components/drawing\"),c=t(\"../../components/colorscale\"),u=t(\"../../lib/gup\"),h=u.keyFun,f=u.repeat,p=u.unwrap,d=t(\"./helpers\"),g=t(\"./constants\"),v=t(\"./axisbrush\"),m=t(\"./lines\");function y(t,e,r){return o.aggNums(t,null,e,r)}function x(t,e){return _(y(Math.min,t,e),y(Math.max,t,e))}function b(t){var e=t.range;return e?_(e[0],e[1]):x(t.values,t._length)}function _(t,e){return!isNaN(t)&&isFinite(t)||(t=0),!isNaN(e)&&isFinite(e)||(e=0),t===e&&(0===t?(t-=1,e+=1):(t*=.9,e*=1.1)),[t,e]}function w(t){return t.dimensions.some(function(t){return t.brush.filterSpecified})}function k(t,e,r){var a=p(e),s=a.trace,l=d.convertTypedArray(a.lineColor),u=s.line,h={color:i(g.deselectedLineColor)},f=c.extractOpts(u),v=f.reversescale?c.flipScale(a.cscale):a.cscale,m=s.domain,y=s.dimensions,x=t.width,_=s.labelangle,w=s.labelside,k=s.labelfont,T=s.tickfont,A=s.rangefont,M=o.extendDeepNoArrays({},u,{color:l.map(n.scale.linear().domain(b({values:l,range:[f.min,f.max],_length:s._length}))),blockLineCount:g.blockLineCount,canvasOverdrag:g.overdrag*g.canvasPixelRatio}),S=Math.floor(x*(m.x[1]-m.x[0])),E=Math.floor(t.height*(m.y[1]-m.y[0])),C=t.margin||{l:80,r:80,t:100,b:80},L=S,P=E;return{key:r,colCount:y.filter(d.isVisible).length,dimensions:y,tickDistance:g.tickDistance,unitToColor:function(t){var e=t.map(function(t){return t[0]}),r=t.map(function(t){var e=i(t[1]);return n.rgb(\"rgb(\"+e[0]+\",\"+e[1]+\",\"+e[2]+\")\")}),a=\"rgb\".split(\"\").map(function(t){return n.scale.linear().clamp(!0).domain(e).range(r.map((i=t,function(t){return t[i]})));var i});return function(t){return a.map(function(e){return e(t)})}}(v),lines:M,deselectedLines:h,labelAngle:_,labelSide:w,labelFont:k,tickFont:T,rangeFont:A,layoutWidth:x,layoutHeight:t.height,domain:m,translateX:m.x[0]*x,translateY:t.height-m.y[1]*t.height,pad:C,canvasWidth:L*g.canvasPixelRatio+2*M.canvasOverdrag,canvasHeight:P*g.canvasPixelRatio,width:L,height:P,canvasPixelRatio:g.canvasPixelRatio}}function T(t,e,r){var i=r.width,a=r.height,s=r.dimensions,l=r.canvasPixelRatio,c=function(t){return i*t/Math.max(1,r.colCount-1)},u=g.verticalPadding/a,h=function(t,e){return n.scale.linear().range([e,t-e])}(a,g.verticalPadding),f={key:r.key,xScale:c,model:r,inBrushDrag:!1},p={};return f.dimensions=s.filter(d.isVisible).map(function(i,s){var m=function(t,e){return n.scale.linear().domain(b(t)).range([e,1-e])}(i,u),y=p[i.label];p[i.label]=(y||0)+1;var x=i.label+(y?\"__\"+y:\"\"),_=i.constraintrange,k=_&&_.length;k&&!Array.isArray(_[0])&&(_=[_]);var T=k?_.map(function(t){return t.map(m)}):[[-1/0,1/0]],A=i.values;A.length>i._length&&(A=A.slice(0,i._length));var M,S=i.tickvals;function E(t,e){return{val:t,text:M[e]}}function C(t,e){return t.val-e.val}if(Array.isArray(S)&&S.length){M=i.ticktext,Array.isArray(M)&&M.length?M.length>S.length?M=M.slice(0,S.length):S.length>M.length&&(S=S.slice(0,M.length)):M=S.map(n.format(i.tickformat));for(var L=1;L<S.length;L++)if(S[L]<S[L-1]){for(var P=S.map(E).sort(C),O=0;O<S.length;O++)S[O]=P[O].val,M[O]=P[O].text;break}}else S=void 0;return A=d.convertTypedArray(A),A=d.convertTypedArray(A),{key:x,label:i.label,tickFormat:i.tickformat,tickvals:S,ticktext:M,ordinal:d.isOrdinal(i),multiselect:i.multiselect,xIndex:s,crossfilterDimensionIndex:s,visibleIndex:i._index,height:a,values:A,paddedUnitValues:A.map(m),unitTickvals:S&&S.map(m),xScale:c,x:c(s),canvasX:c(s)*l,unitToPaddedPx:h,domainScale:function(t,e,r,i,a){var o,s,l=b(r);return i?n.scale.ordinal().domain(i.map((o=n.format(r.tickformat),s=a,s?function(t,e){var r=s[e];return null==r?o(t):r}:o))).range(i.map(function(r){var n=(r-l[0])/(l[1]-l[0]);return t-e+n*(2*e-t)})):n.scale.linear().domain(l).range([t-e,e])}(a,g.verticalPadding,i,S,M),ordinalScale:function(t){if(t.tickvals){var e=b(t);return n.scale.ordinal().domain(t.tickvals).range(t.tickvals.map(function(t){return(t-e[0])/(e[1]-e[0])}))}}(i),parent:f,model:r,brush:v.makeBrush(t,k,T,function(){t.linePickActive(!1)},function(){var e=f;e.focusLayer&&e.focusLayer.render(e.panels,!0);var r=w(e);!t.contextShown()&&r?(e.contextLayer&&e.contextLayer.render(e.panels,!0),t.contextShown(!0)):t.contextShown()&&!r&&(e.contextLayer&&e.contextLayer.render(e.panels,!0,!0),t.contextShown(!1))},function(r){if(f.focusLayer.render(f.panels,!0),f.pickLayer&&f.pickLayer.render(f.panels,!0),t.linePickActive(!0),e&&e.filterChanged){var n=m.invert,a=r.map(function(t){return t.map(n).sort(o.sorterAsc)}).sort(function(t,e){return t[0]-e[0]});e.filterChanged(f.key,i._index,a)}})}}),f}function A(t){t.classed(g.cn.axisExtentText,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"default\").style(\"user-select\",\"none\")}function M(t,e){var r=\"top\"===e?1:-1,n=t*Math.PI/180;return{dir:r,dx:Math.sin(n),dy:Math.cos(n),degrees:t}}function S(t,e){for(var r=e.panels||(e.panels=[]),n=t.data(),i=0;i<n.length-1;i++){var a=r[i]||(r[i]={}),o=n[i],s=n[i+1];a.dim0=o,a.dim1=s,a.canvasX=o.canvasX,a.panelSizeX=s.canvasX-o.canvasX,a.panelSizeY=e.model.canvasHeight,a.y=0,a.canvasY=0}}function E(t,e){return a.tickText(t._ax,e,!1).text}function C(t,e){if(t.ordinal)return\"\";var r=t.domainScale.domain(),n=r[e?r.length-1:0];return E(t.model.dimensions[t.visibleIndex],n)}e.exports=function(t,e,r,i){var c=t._fullLayout,u=c._toppaper,y=c._glcontainer;!function(t){for(var e=0;e<t.length;e++)for(var r=0;r<t[e].length;r++)for(var n=t[e][r].trace,i=n.dimensions,o=0;o<i.length;o++){var s=i[o].values,l=i[o]._ax;l&&(l.range?l.range=_(l.range[0],l.range[1]):l.range=x(s,n._length),l.dtick||(l.dtick=.01*(Math.abs(l.range[1]-l.range[0])||1)),l.tickformat=i[o].tickformat,a.calcTicks(l),l.cleanRange())}}(e);var b,L,P=(b=!0,L=!1,{linePickActive:function(t){return arguments.length?b=!!t:b},contextShown:function(t){return arguments.length?L=!!t:L}}),O=e.filter(function(t){return p(t).trace.visible}).map(k.bind(0,r)).map(T.bind(0,P,i));y.each(function(t,e){return o.extendFlat(t,O[e])});var z=y.selectAll(\".gl-canvas\").each(function(t){t.viewModel=O[0],t.model=t.viewModel?t.viewModel.model:null}),I=null;z.filter(function(t){return t.pick}).style(\"pointer-events\",\"auto\").on(\"mousemove\",function(t){if(P.linePickActive()&&t.lineLayer&&i&&i.hover){var e=n.event,r=this.width,a=this.height,o=n.mouse(this),s=o[0],l=o[1];if(s<0||l<0||s>=r||l>=a)return;var c=t.lineLayer.readPixel(s,a-1-l),u=0!==c[3],h=u?c[2]+256*(c[1]+256*c[0]):null,f={x:s,y:l,clientX:e.clientX,clientY:e.clientY,dataIndex:t.model.key,curveNumber:h};h!==I&&(u?i.hover(f):i.unhover&&i.unhover(f),I=h)}}),z.style(\"opacity\",function(t){return t.pick?0:1}),u.style(\"background\",\"rgba(255, 255, 255, 0)\");var D=u.selectAll(\".\"+g.cn.parcoords).data(O,h);D.exit().remove(),D.enter().append(\"g\").classed(g.cn.parcoords,!0).style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"none\"),D.attr(\"transform\",function(t){return\"translate(\"+t.model.translateX+\",\"+t.model.translateY+\")\"});var R=D.selectAll(\".\"+g.cn.parcoordsControlView).data(f,h);R.enter().append(\"g\").classed(g.cn.parcoordsControlView,!0),R.attr(\"transform\",function(t){return\"translate(\"+t.model.pad.l+\",\"+t.model.pad.t+\")\"});var F=R.selectAll(\".\"+g.cn.yAxis).data(function(t){return t.dimensions},h);F.enter().append(\"g\").classed(g.cn.yAxis,!0),R.each(function(t){S(F,t)}),z.each(function(t){if(t.viewModel){!t.lineLayer||i?t.lineLayer=m(this,t):t.lineLayer.update(t),(t.key||0===t.key)&&(t.viewModel[t.key]=t.lineLayer);var e=!t.context||i;t.lineLayer.render(t.viewModel.panels,e)}}),F.attr(\"transform\",function(t){return\"translate(\"+t.xScale(t.xIndex)+\", 0)\"}),F.call(n.behavior.drag().origin(function(t){return t}).on(\"drag\",function(t){var e=t.parent;P.linePickActive(!1),t.x=Math.max(-g.overdrag,Math.min(t.model.width+g.overdrag,n.event.x)),t.canvasX=t.x*t.model.canvasPixelRatio,F.sort(function(t,e){return t.x-e.x}).each(function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e.xIndex),e.canvasX=e.x*e.model.canvasPixelRatio}),S(F,e),F.filter(function(e){return 0!==Math.abs(t.xIndex-e.xIndex)}).attr(\"transform\",function(t){return\"translate(\"+t.xScale(t.xIndex)+\", 0)\"}),n.select(this).attr(\"transform\",\"translate(\"+t.x+\", 0)\"),F.each(function(r,n,i){i===t.parent.key&&(e.dimensions[n]=r)}),e.contextLayer&&e.contextLayer.render(e.panels,!1,!w(e)),e.focusLayer.render&&e.focusLayer.render(e.panels)}).on(\"dragend\",function(t){var e=t.parent;t.x=t.xScale(t.xIndex),t.canvasX=t.x*t.model.canvasPixelRatio,S(F,e),n.select(this).attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),e.contextLayer&&e.contextLayer.render(e.panels,!1,!w(e)),e.focusLayer&&e.focusLayer.render(e.panels),e.pickLayer&&e.pickLayer.render(e.panels,!0),P.linePickActive(!0),i&&i.axesMoved&&i.axesMoved(e.key,e.dimensions.map(function(t){return t.crossfilterDimensionIndex}))})),F.exit().remove();var B=F.selectAll(\".\"+g.cn.axisOverlays).data(f,h);B.enter().append(\"g\").classed(g.cn.axisOverlays,!0),B.selectAll(\".\"+g.cn.axis).remove();var N=B.selectAll(\".\"+g.cn.axis).data(f,h);N.enter().append(\"g\").classed(g.cn.axis,!0),N.each(function(t){var e=t.model.height/t.model.tickDistance,r=t.domainScale,i=r.domain();n.select(this).call(n.svg.axis().orient(\"left\").tickSize(4).outerTickSize(2).ticks(e,t.tickFormat).tickValues(t.ordinal?i:null).tickFormat(function(e){return d.isOrdinal(t)?e:E(t.model.dimensions[t.visibleIndex],e)}).scale(r)),l.font(N.selectAll(\"text\"),t.model.tickFont)}),N.selectAll(\".domain, .tick>line\").attr(\"fill\",\"none\").attr(\"stroke\",\"black\").attr(\"stroke-opacity\",.25).attr(\"stroke-width\",\"1px\"),N.selectAll(\"text\").style(\"text-shadow\",\"1px 1px 1px #fff, -1px -1px 1px #fff, 1px -1px 1px #fff, -1px 1px 1px #fff\").style(\"cursor\",\"default\").style(\"user-select\",\"none\");var j=B.selectAll(\".\"+g.cn.axisHeading).data(f,h);j.enter().append(\"g\").classed(g.cn.axisHeading,!0);var U=j.selectAll(\".\"+g.cn.axisTitle).data(f,h);U.enter().append(\"text\").classed(g.cn.axisTitle,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"ew-resize\").style(\"user-select\",\"none\").style(\"pointer-events\",\"auto\"),U.text(function(t){return t.label}).each(function(e){var r=n.select(this);l.font(r,e.model.labelFont),s.convertToTspans(r,t)}).attr(\"transform\",function(t){var e=M(t.model.labelAngle,t.model.labelSide),r=g.axisTitleOffset;return(e.dir>0?\"\":\"translate(0,\"+(2*r+t.model.height)+\")\")+\"rotate(\"+e.degrees+\")translate(\"+-r*e.dx+\",\"+-r*e.dy+\")\"}).attr(\"text-anchor\",function(t){var e=M(t.model.labelAngle,t.model.labelSide);return 2*Math.abs(e.dx)>Math.abs(e.dy)?e.dir*e.dx<0?\"start\":\"end\":\"middle\"});var V=B.selectAll(\".\"+g.cn.axisExtent).data(f,h);V.enter().append(\"g\").classed(g.cn.axisExtent,!0);var q=V.selectAll(\".\"+g.cn.axisExtentTop).data(f,h);q.enter().append(\"g\").classed(g.cn.axisExtentTop,!0),q.attr(\"transform\",\"translate(0,\"+-g.axisExtentOffset+\")\");var H=q.selectAll(\".\"+g.cn.axisExtentTopText).data(f,h);H.enter().append(\"text\").classed(g.cn.axisExtentTopText,!0).call(A),H.text(function(t){return C(t,!0)}).each(function(t){l.font(n.select(this),t.model.rangeFont)});var G=V.selectAll(\".\"+g.cn.axisExtentBottom).data(f,h);G.enter().append(\"g\").classed(g.cn.axisExtentBottom,!0),G.attr(\"transform\",function(t){return\"translate(0,\"+(t.model.height+g.axisExtentOffset)+\")\"});var Y=G.selectAll(\".\"+g.cn.axisExtentBottomText).data(f,h);Y.enter().append(\"text\").classed(g.cn.axisExtentBottomText,!0).attr(\"dy\",\"0.75em\").call(A),Y.text(function(t){return C(t,!1)}).each(function(t){l.font(n.select(this),t.model.rangeFont)}),v.ensureAxisBrush(B)}},{\"../../components/colorscale\":605,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/gup\":717,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"./axisbrush\":1075,\"./constants\":1078,\"./helpers\":1080,\"./lines\":1082,\"color-rgba\":122,d3:163}],1085:[function(t,e,r){\"use strict\";var n=t(\"./parcoords\"),i=t(\"../../lib/prepare_regl\"),a=t(\"./helpers\").isVisible;function o(t,e,r){var n=e.indexOf(r),i=t.indexOf(n);return-1===i&&(i+=e.length),i}e.exports=function(t,e){var r=t._fullLayout;if(i(t)){var s={},l={},c={},u={},h=r._size;e.forEach(function(e,r){var n=e[0].trace;c[r]=n.index;var i=u[r]=n._fullInput.index;s[r]=t.data[i].dimensions,l[r]=t.data[i].dimensions.slice()});n(t,e,{width:h.w,height:h.h,margin:{t:h.t,r:h.r,b:h.b,l:h.l}},{filterChanged:function(e,n,i){var a=l[e][n],o=i.map(function(t){return t.slice()}),s=\"dimensions[\"+n+\"].constraintrange\",h=r._tracePreGUI[t._fullData[c[e]]._fullInput.uid];if(void 0===h[s]){var f=a.constraintrange;h[s]=f||null}var p=t._fullData[c[e]].dimensions[n];o.length?(1===o.length&&(o=o[0]),a.constraintrange=o,p.constraintrange=o.slice(),o=[o]):(delete a.constraintrange,delete p.constraintrange,o=null);var d={};d[s]=o,t.emit(\"plotly_restyle\",[d,[u[e]]])},hover:function(e){t.emit(\"plotly_hover\",e)},unhover:function(e){t.emit(\"plotly_unhover\",e)},axesMoved:function(e,r){var n=function(t,e){return function(r,n){return o(t,e,r)-o(t,e,n)}}(r,l[e].filter(a));s[e].sort(n),l[e].filter(function(t){return!a(t)}).sort(function(t){return l[e].indexOf(t)}).forEach(function(t){s[e].splice(s[e].indexOf(t),1),s[e].splice(l[e].indexOf(t),0,t)}),t.emit(\"plotly_restyle\",[{dimensions:[s[e]]},[u[e]]])}})}}},{\"../../lib/prepare_regl\":732,\"./helpers\":1080,\"./parcoords\":1084}],1086:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../plots/domain\").attributes,a=t(\"../../plots/font_attributes\"),o=t(\"../../components/color/attributes\"),s=t(\"../../components/fx/hovertemplate_attributes\"),l=t(\"../../lib/extend\").extendFlat,c=a({editType:\"plot\",arrayOk:!0,colorEditType:\"plot\"});e.exports={labels:{valType:\"data_array\",editType:\"calc\"},label0:{valType:\"number\",dflt:0,editType:\"calc\"},dlabel:{valType:\"number\",dflt:1,editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},marker:{colors:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:o.defaultLine,arrayOk:!0,editType:\"style\"},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0,editType:\"style\"},editType:\"calc\"},editType:\"calc\"},text:{valType:\"data_array\",editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"value\",\"percent\"],extras:[\"none\"],editType:\"calc\"},hoverinfo:l({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:s({},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"auto\",arrayOk:!0,editType:\"plot\"},textfont:l({},c,{}),insidetextfont:l({},c,{}),outsidetextfont:l({},c,{}),title:{text:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:l({},c,{}),position:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"plot\"},editType:\"plot\"},domain:i({name:\"pie\",trace:!0,editType:\"calc\"}),hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},sort:{valType:\"boolean\",dflt:!0,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"number\",min:-360,max:360,dflt:0,editType:\"calc\"},pull:{valType:\"number\",min:0,max:1,dflt:0,arrayOk:!0,editType:\"calc\"},_deprecated:{title:{valType:\"string\",dflt:\"\",editType:\"calc\"},titlefont:l({},c,{}),titleposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"calc\"}}}},{\"../../components/color/attributes\":592,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1087:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData;r.name=\"pie\",r.plot=function(t){var e=n.getModule(\"pie\"),r=i(t.calcdata,e)[0];e.plot(t,r)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"pie\"),a=e._has&&e._has(\"pie\");i&&!a&&n._pielayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],1088:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"tinycolor2\"),o=t(\"../../components/color\"),s=t(\"./helpers\"),l=t(\"../../lib\").isValidTextValue,c={};function u(t){return function(e,r){return!!e&&(!!(e=a(e)).isValid()&&(e=o.addOpacity(e,e.getAlpha()),t[r]||(t[r]=e),e))}}function h(t,e){var r,n=JSON.stringify(t),i=e[n];if(!i){for(i=t.slice(),r=0;r<t.length;r++)i.push(a(t[r]).lighten(20).toHexString());for(r=0;r<t.length;r++)i.push(a(t[r]).darken(20).toHexString());e[n]=i}return i}e.exports={calc:function(t,e){var r,a,o=[],c=t._fullLayout,h=c.hiddenlabels||[],f=e.labels,p=e.marker.colors||[],d=e.values,g=i(d)&&d.length;if(e.dlabel)for(f=new Array(d.length),r=0;r<d.length;r++)f[r]=String(e.label0+r*e.dlabel);var v={},m=u(c[\"_\"+e.type+\"colormap\"]),y=(g?d:f).length,x=0,b=!1;for(r=0;r<y;r++){var _,w,k;if(g){if(_=d[r],!n(_))continue;if((_=+_)<0)continue}else _=1;void 0!==(w=f[r])&&\"\"!==w||(w=r);var T=v[w=String(w)];void 0===T?(v[w]=o.length,(k=-1!==h.indexOf(w))||(x+=_),o.push({v:_,label:w,color:m(p[r],w),i:r,pts:[r],hidden:k})):(b=!0,(a=o[T]).v+=_,a.pts.push(r),a.hidden||(x+=_),!1===a.color&&p[r]&&(a.color=m(p[r],w)))}(\"funnelarea\"===e.type?b:e.sort)&&o.sort(function(t,e){return e.v-t.v}),o[0]&&(o[0].vTotal=x);var A=e.textinfo;if(A&&\"none\"!==A){var M,S=A.split(\"+\"),E=function(t){return-1!==S.indexOf(t)},C=E(\"label\"),L=E(\"text\"),P=E(\"value\"),O=E(\"percent\"),z=c.separators;for(r=0;r<o.length;r++){if(a=o[r],M=C?[a.label]:[],L){var I=s.getFirstFilled(e.text,a.pts);l(I)&&M.push(I)}P&&M.push(s.formatPieValue(a.v,z)),O&&M.push(s.formatPiePercent(a.v/x,z)),a.text=M.join(\"<br>\")}}return o},crossTraceCalc:function(t,e){var r=(e||{}).type;r||(r=\"pie\");var n=t._fullLayout,i=t.calcdata,a=n[r+\"colorway\"],o=n[\"_\"+r+\"colormap\"];n[\"extend\"+r+\"colors\"]&&(a=h(a,c));for(var s=0,l=0;l<i.length;l++){var u=i[l];if(u[0].trace.type===r)for(var f=0;f<u.length;f++){var p=u[f];!1===p.color&&(o[p.label]?p.color=o[p.label]:(o[p.label]=p.color=a[s%a.length],s++))}}},makePullColorFn:u,generateExtendedColors:h}},{\"../../components/color\":593,\"../../lib\":719,\"./helpers\":1091,\"fast-isnumeric\":225,tinycolor2:537}],1089:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}var c,u=l(\"values\"),h=n.isArrayOrTypedArray(u),f=l(\"labels\");if(Array.isArray(f)?(c=f.length,h&&(c=Math.min(c,u.length))):h&&(c=u.length,l(\"label0\"),l(\"dlabel\")),c){e._length=c,l(\"marker.line.width\")&&l(\"marker.line.color\"),l(\"marker.colors\"),l(\"scalegroup\");var p=l(\"text\"),d=l(\"textinfo\",Array.isArray(p)?\"text+percent\":\"percent\");if(l(\"hovertext\"),l(\"hovertemplate\"),d&&\"none\"!==d){var g=l(\"textposition\");o(t,e,s,l,g,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}a(e,s,l);var v=l(\"hole\");if(l(\"title.text\")){var m=l(\"title.position\",v?\"middle center\":\"top center\");v||\"middle center\"!==m||(e.title.position=\"top center\"),n.coerceFont(l,\"title.font\",s.font)}l(\"sort\"),l(\"direction\"),l(\"rotation\"),l(\"pull\")}else e.visible=!1}},{\"../../lib\":719,\"../../plots/domain\":792,\"../bar/defaults\":861,\"./attributes\":1086}],1090:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/helpers\").appendArrayMultiPointValues;e.exports=function(t,e){var r={curveNumber:e.index,pointNumbers:t.pts,data:e._input,fullData:e,label:t.label,color:t.color,value:t.v,percent:t.percent,text:t.text,v:t.v};return 1===t.pts.length&&(r.pointNumber=r.i=t.pts[0]),n(r,e,t.pts),\"funnelarea\"===e.type&&(delete r.v,delete r.i),r}},{\"../../components/fx/helpers\":628}],1091:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");r.formatPiePercent=function(t,e){var r=(100*t).toPrecision(3);return-1!==r.lastIndexOf(\".\")&&(r=r.replace(/[.]?0+$/,\"\")),n.numSeparate(r,e)+\"%\"},r.formatPieValue=function(t,e){var r=t.toPrecision(10);return-1!==r.lastIndexOf(\".\")&&(r=r.replace(/[.]?0+$/,\"\")),n.numSeparate(r,e)},r.getFirstFilled=function(t,e){if(Array.isArray(t))for(var r=0;r<e.length;r++){var n=t[e[r]];if(n||0===n)return n}},r.castOption=function(t,e){return Array.isArray(t)?r.getFirstFilled(t,e):t||void 0}},{\"../../lib\":719}],1092:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),layoutAttributes:t(\"./layout_attributes\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\"),styleOne:t(\"./style_one\"),moduleType:\"trace\",name:\"pie\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"pie\",\"showLegend\"],meta:{}}},{\"./attributes\":1086,\"./base_plot\":1087,\"./calc\":1088,\"./defaults\":1089,\"./layout_attributes\":1093,\"./layout_defaults\":1094,\"./plot\":1095,\"./style\":1096,\"./style_one\":1097}],1093:[function(t,e,r){\"use strict\";e.exports={hiddenlabels:{valType:\"data_array\",editType:\"calc\"},piecolorway:{valType:\"colorlist\",editType:\"calc\"},extendpiecolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1094:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"piecolorway\",e.colorway),r(\"extendpiecolors\")}},{\"../../lib\":719,\"./layout_attributes\":1093}],1095:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/fx\"),a=t(\"../../components/color\"),o=t(\"../../components/drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"./helpers\"),u=t(\"./event_data\");function h(t,e,r){var a=r[0],o=a.trace,l=a.cx,h=a.cy;\"_hasHoverLabel\"in o||(o._hasHoverLabel=!1),\"_hasHoverEvent\"in o||(o._hasHoverEvent=!1),t.on(\"mouseover\",function(t){var r=e._fullLayout,f=e._fullData[o.index];if(!e._dragging&&!1!==r.hovermode){var p=f.hoverinfo;if(Array.isArray(p)&&(p=i.castHoverinfo({hoverinfo:[c.castOption(p,t.pts)],_module:o._module},r,0)),\"all\"===p&&(p=\"label+text+value+percent+name\"),f.hovertemplate||\"none\"!==p&&\"skip\"!==p&&p){var d=t.rInscribed||0,g=l+t.pxmid[0]*(1-d),v=h+t.pxmid[1]*(1-d),m=r.separators,y=[];if(p&&-1!==p.indexOf(\"label\")&&y.push(t.label),t.text=c.castOption(f.hovertext||f.text,t.pts),p&&-1!==p.indexOf(\"text\")){var x=t.text;s.isValidTextValue(x)&&y.push(x)}t.value=t.v,t.valueLabel=c.formatPieValue(t.v,m),p&&-1!==p.indexOf(\"value\")&&y.push(t.valueLabel),t.percent=t.v/a.vTotal,t.percentLabel=c.formatPiePercent(t.percent,m),p&&-1!==p.indexOf(\"percent\")&&y.push(t.percentLabel);var b=f.hoverlabel,_=b.font;i.loneHover({trace:o,x0:g-d*a.r,x1:g+d*a.r,y:v,text:y.join(\"<br>\"),name:f.hovertemplate||-1!==p.indexOf(\"name\")?f.name:void 0,idealAlign:t.pxmid[0]<0?\"left\":\"right\",color:c.castOption(b.bgcolor,t.pts)||t.color,borderColor:c.castOption(b.bordercolor,t.pts),fontFamily:c.castOption(_.family,t.pts),fontSize:c.castOption(_.size,t.pts),fontColor:c.castOption(_.color,t.pts),nameLength:c.castOption(b.namelength,t.pts),textAlign:c.castOption(b.align,t.pts),hovertemplate:c.castOption(f.hovertemplate,t.pts),hovertemplateLabels:t,eventData:[u(t,f)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e}),o._hasHoverLabel=!0}o._hasHoverEvent=!0,e.emit(\"plotly_hover\",{points:[u(t,f)],event:n.event})}}),t.on(\"mouseout\",function(t){var r=e._fullLayout,a=e._fullData[o.index],s=n.select(this).datum();o._hasHoverEvent&&(t.originalEvent=n.event,e.emit(\"plotly_unhover\",{points:[u(s,a)],event:n.event}),o._hasHoverEvent=!1),o._hasHoverLabel&&(i.loneUnhover(r._hoverlayer.node()),o._hasHoverLabel=!1)}),t.on(\"click\",function(t){var r=e._fullLayout,a=e._fullData[o.index];e._dragging||!1===r.hovermode||(e._hoverdata=[u(t,a)],i.click(e,n.event))})}function f(t,e,r){var n=c.castOption(t.insidetextfont.color,e.pts);!n&&t._input.textfont&&(n=c.castOption(t._input.textfont.color,e.pts));var i=c.castOption(t.insidetextfont.family,e.pts)||c.castOption(t.textfont.family,e.pts)||r.family,o=c.castOption(t.insidetextfont.size,e.pts)||c.castOption(t.textfont.size,e.pts)||r.size;return{color:n||a.contrast(e.color),family:i,size:o}}function p(t,e){for(var r,n,i=0;i<t.length;i++)if((n=(r=t[i][0]).trace).title.text){var a=n.title.text;n._meta&&(a=s.templateString(a,n._meta));var c=o.tester.append(\"text\").attr(\"data-notex\",1).text(a).call(o.font,n.title.font).call(l.convertToTspans,e),u=o.bBox(c.node(),!0);r.titleBox={width:u.width,height:u.height},c.remove()}}function d(t,e,r){var n=Math.sqrt(t.width*t.width+t.height*t.height),i=t.width/t.height,a=e.halfangle,o=e.ring,s=e.rInscribed,l=r.r||e.rpx1,c={scale:s*l*2/n,rCenter:1-s,rotate:0};if(c.scale>=1)return c;var u=i+1/(2*Math.tan(a)),h=l*Math.min(1/(Math.sqrt(u*u+.5)+u),o/(Math.sqrt(i*i+o/2)+i)),f={scale:2*h/t.height,rCenter:Math.cos(h/l)-h*i/l,rotate:(180/Math.PI*e.midangle+720)%180-90},p=1/i,d=p+1/(2*Math.tan(a)),g=l*Math.min(1/(Math.sqrt(d*d+.5)+d),o/(Math.sqrt(p*p+o/2)+p)),v={scale:2*g/t.width,rCenter:Math.cos(g/l)-g/i/l,rotate:(180/Math.PI*e.midangle+810)%180-90},m=v.scale>f.scale?v:f;return c.scale<1&&m.scale>c.scale?m:c}function g(t,e){return t.v!==e.vTotal||e.trace.hole?Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2):1}function v(t,e){var r=e.pxmid[0],n=e.pxmid[1],i=t.width/2,a=t.height/2;return r<0&&(i*=-1),n<0&&(a*=-1),{scale:1,rCenter:1,rotate:0,x:i+Math.abs(a)*(i>0?1:-1)/2,y:a/(1+r*r/(n*n)),outside:!0}}function m(t,e){var r,n,i,a=t.trace,o={x:t.cx,y:t.cy},s={tx:0,ty:0};s.ty+=a.title.font.size,i=x(a),-1!==a.title.position.indexOf(\"top\")?(o.y-=(1+i)*t.r,s.ty-=t.titleBox.height):-1!==a.title.position.indexOf(\"bottom\")&&(o.y+=(1+i)*t.r);var l,c,u=(l=t.r,c=t.trace.aspectratio,l/(void 0===c?1:c)),h=e.w*(a.domain.x[1]-a.domain.x[0])/2;return-1!==a.title.position.indexOf(\"left\")?(h+=u,o.x-=(1+i)*u,s.tx+=t.titleBox.width/2):-1!==a.title.position.indexOf(\"center\")?h*=2:-1!==a.title.position.indexOf(\"right\")&&(h+=u,o.x+=(1+i)*u,s.tx-=t.titleBox.width/2),r=h/t.titleBox.width,n=y(t,e)/t.titleBox.height,{x:o.x,y:o.y,scale:Math.min(r,n),tx:s.tx,ty:s.ty}}function y(t,e){var r=t.trace,n=e.h*(r.domain.y[1]-r.domain.y[0]);return Math.min(t.titleBox.height,n/2)}function x(t){var e,r=t.pull;if(!r)return 0;if(Array.isArray(r))for(r=0,e=0;e<t.pull.length;e++)t.pull[e]>r&&(r=t.pull[e]);return r}function b(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n][0],a=i.trace,o=a.domain,s=e.w*(o.x[1]-o.x[0]),l=e.h*(o.y[1]-o.y[0]);a.title.text&&\"middle center\"!==a.title.position&&(l-=y(i,e));var c=s/2,u=l/2;\"funnelarea\"!==a.type||a.scalegroup||(u/=a.aspectratio),i.r=Math.min(c,u)/(1+x(a)),i.cx=e.l+e.w*(a.domain.x[1]+a.domain.x[0])/2,i.cy=e.t+e.h*(1-a.domain.y[0])-l/2,a.title.text&&-1!==a.title.position.indexOf(\"bottom\")&&(i.cy-=y(i,e)),a.scalegroup&&-1===r.indexOf(a.scalegroup)&&r.push(a.scalegroup)}!function(t,e){for(var r,n,i,a=0;a<e.length;a++){var o=1/0,s=e[a];for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var l;if(\"pie\"===i.type)l=r.r*r.r;else if(\"funnelarea\"===i.type){var c,u;i.aspectratio>1?(c=r.r,u=c/i.aspectratio):(u=r.r,c=u*i.aspectratio),c*=(1+i.baseratio)/2,l=c*u}o=Math.min(o,l/r.vTotal)}for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var h=o*r.vTotal;\"funnelarea\"===i.type&&(h/=(1+i.baseratio)/2,h/=i.aspectratio),r.r=Math.sqrt(h)}}}(t,r)}e.exports={plot:function(t,e){var r=t._fullLayout;p(e,t),b(e,r._size);var i=s.makeTraceGroups(r._pielayer,e,\"trace\").each(function(e){var i=n.select(this),u=e[0],p=u.trace;!function(t){var e,r,n,i=t[0],a=i.trace,o=a.rotation*Math.PI/180,s=2*Math.PI/i.vTotal,l=\"px0\",c=\"px1\";if(\"counterclockwise\"===a.direction){for(e=0;e<t.length&&t[e].hidden;e++);if(e===t.length)return;o+=s*t[e].v,s*=-1,l=\"px1\",c=\"px0\"}function u(t){return[i.r*Math.sin(t),-i.r*Math.cos(t)]}for(n=u(o),e=0;e<t.length;e++)(r=t[e]).hidden||(r[l]=n,o+=s*r.v/2,r.pxmid=u(o),r.midangle=o,o+=s*r.v/2,n=u(o),r[c]=n,r.largeArc=r.v>i.vTotal/2?1:0,r.halfangle=Math.PI*Math.min(r.v/i.vTotal,.5),r.ring=1-a.hole,r.rInscribed=g(r,i))}(e),i.attr(\"stroke-linejoin\",\"round\"),i.each(function(){var i=n.select(this).selectAll(\"g.slice\").data(e);i.enter().append(\"g\").classed(\"slice\",!0),i.exit().remove();var g=[[[],[]],[[],[]]],y=!1;i.each(function(r){if(r.hidden)n.select(this).selectAll(\"path,g\").remove();else{r.pointNumber=r.i,r.curveNumber=p.index,g[r.pxmid[1]<0?0:1][r.pxmid[0]<0?0:1].push(r);var i=u.cx,a=u.cy,m=n.select(this),x=m.selectAll(\"path.surface\").data([r]);if(x.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),m.call(h,t,e),p.pull){var b=+c.castOption(p.pull,r.pts)||0;b>0&&(i+=b*r.pxmid[0],a+=b*r.pxmid[1])}r.cxFinal=i,r.cyFinal=a;var _=p.hole;if(r.v===u.vTotal){var w=\"M\"+(i+r.px0[0])+\",\"+(a+r.px0[1])+S(r.px0,r.pxmid,!0,1)+S(r.pxmid,r.px0,!0,1)+\"Z\";_?x.attr(\"d\",\"M\"+(i+_*r.px0[0])+\",\"+(a+_*r.px0[1])+S(r.px0,r.pxmid,!1,_)+S(r.pxmid,r.px0,!1,_)+\"Z\"+w):x.attr(\"d\",w)}else{var k=S(r.px0,r.px1,!0,1);if(_){var T=1-_;x.attr(\"d\",\"M\"+(i+_*r.px1[0])+\",\"+(a+_*r.px1[1])+S(r.px1,r.px0,!1,_)+\"l\"+T*r.px0[0]+\",\"+T*r.px0[1]+k+\"Z\")}else x.attr(\"d\",\"M\"+i+\",\"+a+\"l\"+r.px0[0]+\",\"+r.px0[1]+k+\"Z\")}var A=c.castOption(p.textposition,r.pts),M=m.selectAll(\"g.slicetext\").data(r.text&&\"none\"!==A?[0]:[]);M.enter().append(\"g\").classed(\"slicetext\",!0),M.exit().remove(),M.each(function(){var e=s.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)});e.text(r.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(o.font,\"outside\"===A?function(t,e,r){var n=c.castOption(t.outsidetextfont.color,e.pts)||c.castOption(t.textfont.color,e.pts)||r.color,i=c.castOption(t.outsidetextfont.family,e.pts)||c.castOption(t.textfont.family,e.pts)||r.family,a=c.castOption(t.outsidetextfont.size,e.pts)||c.castOption(t.textfont.size,e.pts)||r.size;return{color:n,family:i,size:a}}(p,r,t._fullLayout.font):f(p,r,t._fullLayout.font)).call(l.convertToTspans,t);var h,g=o.bBox(e.node());\"outside\"===A?h=v(g,r):(h=d(g,r,u),\"auto\"===A&&h.scale<1&&(e.call(o.font,p.outsidetextfont),p.outsidetextfont.family===p.insidetextfont.family&&p.outsidetextfont.size===p.insidetextfont.size||(g=o.bBox(e.node())),h=v(g,r)));var m=i+r.pxmid[0]*h.rCenter+(h.x||0),x=a+r.pxmid[1]*h.rCenter+(h.y||0);h.outside&&(r.yLabelMin=x-g.height/2,r.yLabelMid=x,r.yLabelMax=x+g.height/2,r.labelExtraX=0,r.labelExtraY=0,y=!0),e.attr(\"transform\",\"translate(\"+m+\",\"+x+\")\"+(h.scale<1?\"scale(\"+h.scale+\")\":\"\")+(h.rotate?\"rotate(\"+h.rotate+\")\":\"\")+\"translate(\"+-(g.left+g.right)/2+\",\"+-(g.top+g.bottom)/2+\")\")})}function S(t,e,n,i){var a=i*(e[0]-t[0]),o=i*(e[1]-t[1]);return\"a\"+i*u.r+\",\"+i*u.r+\" 0 \"+r.largeArc+(n?\" 1 \":\" 0 \")+a+\",\"+o}});var x=n.select(this).selectAll(\"g.titletext\").data(p.title.text?[0]:[]);x.enter().append(\"g\").classed(\"titletext\",!0),x.exit().remove(),x.each(function(){var e,i=s.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),a=p.title.text;p._meta&&(a=s.templateString(a,p._meta)),i.text(a).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(o.font,p.title.font).call(l.convertToTspans,t),e=\"middle center\"===p.title.position?function(t){var e=Math.sqrt(t.titleBox.width*t.titleBox.width+t.titleBox.height*t.titleBox.height);return{x:t.cx,y:t.cy,scale:t.trace.hole*t.r*2/e,tx:0,ty:-t.titleBox.height/2+t.trace.title.font.size}}(u):m(u,r._size),i.attr(\"transform\",\"translate(\"+e.x+\",\"+e.y+\")\"+(e.scale<1?\"scale(\"+e.scale+\")\":\"\")+\"translate(\"+e.tx+\",\"+e.ty+\")\")}),y&&function(t,e){var r,n,i,a,o,s,l,u,h,f,p,d,g;function v(t,e){return t.pxmid[1]-e.pxmid[1]}function m(t,e){return e.pxmid[1]-t.pxmid[1]}function y(t,r){r||(r={});var i,u,h,p,d,g,v=r.labelExtraY+(n?r.yLabelMax:r.yLabelMin),m=n?t.yLabelMin:t.yLabelMax,y=n?t.yLabelMax:t.yLabelMin,x=t.cyFinal+o(t.px0[1],t.px1[1]),b=v-m;if(b*l>0&&(t.labelExtraY=b),Array.isArray(e.pull))for(u=0;u<f.length;u++)(h=f[u])===t||(c.castOption(e.pull,t.pts)||0)>=(c.castOption(e.pull,h.pts)||0)||((t.pxmid[1]-h.pxmid[1])*l>0?(p=h.cyFinal+o(h.px0[1],h.px1[1]),(b=p-m-t.labelExtraY)*l>0&&(t.labelExtraY+=b)):(y+t.labelExtraY-x)*l>0&&(i=3*s*Math.abs(u-f.indexOf(t)),d=h.cxFinal+a(h.px0[0],h.px1[0]),(g=d+i-(t.cxFinal+t.pxmid[0])-t.labelExtraX)*s>0&&(t.labelExtraX+=g)))}for(n=0;n<2;n++)for(i=n?v:m,o=n?Math.max:Math.min,l=n?1:-1,r=0;r<2;r++){for(a=r?Math.max:Math.min,s=r?1:-1,(u=t[n][r]).sort(i),h=t[1-n][r],f=h.concat(u),d=[],p=0;p<u.length;p++)void 0!==u[p].yLabelMid&&d.push(u[p]);for(g=!1,p=0;n&&p<h.length;p++)if(void 0!==h[p].yLabelMid){g=h[p];break}for(p=0;p<d.length;p++){var x=p&&d[p-1];g&&!p&&(x=g),y(d[p],x)}}}(g,p),function(t,e){t.each(function(t){var r=n.select(this);if(t.labelExtraX||t.labelExtraY){var i=r.select(\"g.slicetext text\");i.attr(\"transform\",\"translate(\"+t.labelExtraX+\",\"+t.labelExtraY+\")\"+i.attr(\"transform\"));var o=t.cxFinal+t.pxmid[0],l=t.cyFinal+t.pxmid[1],c=\"M\"+o+\",\"+l,u=(t.yLabelMax-t.yLabelMin)*(t.pxmid[0]<0?-1:1)/4;if(t.labelExtraX){var h=t.labelExtraX*t.pxmid[1]/t.pxmid[0],f=t.yLabelMid+t.labelExtraY-(t.cyFinal+t.pxmid[1]);Math.abs(h)>Math.abs(f)?c+=\"l\"+f*t.pxmid[0]/t.pxmid[1]+\",\"+f+\"H\"+(o+t.labelExtraX+u):c+=\"l\"+t.labelExtraX+\",\"+h+\"v\"+(f-h)+\"h\"+u}else c+=\"V\"+(t.yLabelMid+t.labelExtraY)+\"h\"+u;s.ensureSingle(r,\"path\",\"textline\").call(a.stroke,e.outsidetextfont.color).attr({\"stroke-width\":Math.min(2,e.outsidetextfont.size/8),d:c,fill:\"none\"})}else r.select(\"path.textline\").remove()})}(i,p)})});setTimeout(function(){i.selectAll(\"tspan\").each(function(){var t=n.select(this);t.attr(\"dy\")&&t.attr(\"dy\",t.attr(\"dy\"))})},0)},transformInsideText:d,determineInsideTextFont:f,positionTitleOutside:m,prerenderTitles:p,layoutAreas:b,attachFxHandlers:h}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"./event_data\":1090,\"./helpers\":1091,d3:163}],1096:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./style_one\");e.exports=function(t){t._fullLayout._pielayer.selectAll(\".trace\").each(function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each(function(t){n.select(this).call(i,t,e)})})}},{\"./style_one\":1097,d3:163}],1097:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./helpers\").castOption;e.exports=function(t,e,r){var a=r.marker.line,o=i(a.color,e.pts)||n.defaultLine,s=i(a.width,e.pts)||0;t.style(\"stroke-width\",s).call(n.fill,e.color).call(n.stroke,o)}},{\"../../components/color\":593,\"./helpers\":1091}],1098:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\");e.exports={x:n.x,y:n.y,xy:{valType:\"data_array\",editType:\"calc\"},indices:{valType:\"data_array\",editType:\"calc\"},xbounds:{valType:\"data_array\",editType:\"calc\"},ybounds:{valType:\"data_array\",editType:\"calc\"},text:n.text,marker:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,arrayOk:!1,editType:\"calc\"},blend:{valType:\"boolean\",dflt:null,editType:\"calc\"},sizemin:{valType:\"number\",min:.1,max:2,dflt:.5,editType:\"calc\"},sizemax:{valType:\"number\",min:.1,dflt:20,editType:\"calc\"},border:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},arearatio:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},transforms:void 0}},{\"../scatter/attributes\":1112}],1099:[function(t,e,r){\"use strict\";var n=t(\"gl-pointcloud2d\"),i=t(\"../../lib/str2rgbarray\"),a=t(\"../../plots/cartesian/autorange\").findExtremes,o=t(\"../scatter/get_trace_color\");function s(t,e){this.scene=t,this.uid=e,this.type=\"pointcloud\",this.pickXData=[],this.pickYData=[],this.xData=[],this.yData=[],this.textLabels=[],this.color=\"rgb(0, 0, 0)\",this.name=\"\",this.hoverinfo=\"all\",this.idToIndex=new Int32Array(0),this.bounds=[0,0,0,0],this.pointcloudOptions={positions:new Float32Array(0),idToIndex:this.idToIndex,sizemin:.5,sizemax:12,color:[0,0,0,1],areaRatio:1,borderColor:[0,0,0,1]},this.pointcloud=n(t.glplot,this.pointcloudOptions),this.pointcloud._trace=this}var l=s.prototype;l.handlePick=function(t){var e=this.idToIndex[t.pointId];return{trace:this,dataCoord:t.dataCoord,traceCoord:this.pickXYData?[this.pickXYData[2*e],this.pickXYData[2*e+1]]:[this.pickXData[e],this.pickYData[e]],textLabel:Array.isArray(this.textLabels)?this.textLabels[e]:this.textLabels,color:this.color,name:this.name,pointIndex:e,hoverinfo:this.hoverinfo}},l.update=function(t){this.index=t.index,this.textLabels=t.text,this.name=t.name,this.hoverinfo=t.hoverinfo,this.bounds=[1/0,1/0,-1/0,-1/0],this.updateFast(t),this.color=o(t,{})},l.updateFast=function(t){var e,r,n,o,s,l,c=this.xData=this.pickXData=t.x,u=this.yData=this.pickYData=t.y,h=this.pickXYData=t.xy,f=t.xbounds&&t.ybounds,p=t.indices,d=this.bounds;if(h){if(n=h,e=h.length>>>1,f)d[0]=t.xbounds[0],d[2]=t.xbounds[1],d[1]=t.ybounds[0],d[3]=t.ybounds[1];else for(l=0;l<e;l++)o=n[2*l],s=n[2*l+1],o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);if(p)r=p;else for(r=new Int32Array(e),l=0;l<e;l++)r[l]=l}else for(e=c.length,n=new Float32Array(2*e),r=new Int32Array(e),l=0;l<e;l++)o=c[l],s=u[l],r[l]=l,n[2*l]=o,n[2*l+1]=s,o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);this.idToIndex=r,this.pointcloudOptions.idToIndex=r,this.pointcloudOptions.positions=n;var g=i(t.marker.color),v=i(t.marker.border.color),m=t.opacity*t.marker.opacity;g[3]*=m,this.pointcloudOptions.color=g;var y=t.marker.blend;if(null===y){y=c.length<100||u.length<100}this.pointcloudOptions.blend=y,v[3]*=m,this.pointcloudOptions.borderColor=v;var x=t.marker.sizemin,b=Math.max(t.marker.sizemax,t.marker.sizemin);this.pointcloudOptions.sizeMin=x,this.pointcloudOptions.sizeMax=b,this.pointcloudOptions.areaRatio=t.marker.border.arearatio,this.pointcloud.update(this.pointcloudOptions);var _=this.scene.xaxis,w=this.scene.yaxis,k=b/2||.5;t._extremes[_._id]=a(_,[d[0],d[2]],{ppad:k}),t._extremes[w._id]=a(w,[d[1],d[3]],{ppad:k})},l.dispose=function(){this.pointcloud.dispose()},e.exports=function(t,e){var r=new s(t,e.uid);return r.update(e),r}},{\"../../lib/str2rgbarray\":742,\"../../plots/cartesian/autorange\":766,\"../scatter/get_trace_color\":1121,\"gl-pointcloud2d\":292}],1100:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\");e.exports=function(t,e,r){function a(r,a){return n.coerce(t,e,i,r,a)}a(\"x\"),a(\"y\"),a(\"xbounds\"),a(\"ybounds\"),t.xy&&t.xy instanceof Float32Array&&(e.xy=t.xy),t.indices&&t.indices instanceof Int32Array&&(e.indices=t.indices),a(\"text\"),a(\"marker.color\",r),a(\"marker.opacity\"),a(\"marker.blend\"),a(\"marker.sizemin\"),a(\"marker.sizemax\"),a(\"marker.border.color\",r),a(\"marker.border.arearatio\"),e._length=null}},{\"../../lib\":719,\"./attributes\":1098}],1101:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../scatter3d/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"pointcloud\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"showLegend\"],meta:{}}},{\"../../plots/gl2d\":805,\"../scatter3d/calc\":1139,\"./attributes\":1098,\"./convert\":1099,\"./defaults\":1100}],1102:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../components/fx/attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../../components/fx/hovertemplate_attributes\"),c=t(\"../../components/colorscale/attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,h=t(\"../../lib/extend\").extendFlat,f=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=f({hoverinfo:h({},i.hoverinfo,{flags:[],arrayOk:!1}),hoverlabel:o.hoverlabel,domain:s({name:\"sankey\",trace:!0}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\"},valueformat:{valType:\"string\",dflt:\".3s\"},valuesuffix:{valType:\"string\",dflt:\"\"},arrangement:{valType:\"enumerated\",values:[\"snap\",\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"snap\"},textfont:n({}),node:{label:{valType:\"data_array\",dflt:[]},groups:{valType:\"info_array\",impliedEdits:{x:[],y:[]},dimensions:2,freeLength:!0,dflt:[],items:{valType:\"number\",editType:\"calc\"}},x:{valType:\"data_array\",dflt:[]},y:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:.5,arrayOk:!0}},pad:{valType:\"number\",arrayOk:!1,min:0,dflt:20},thickness:{valType:\"number\",arrayOk:!1,min:1,dflt:20},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]})},link:{label:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0}},source:{valType:\"data_array\",dflt:[]},target:{valType:\"data_array\",dflt:[]},value:{valType:\"data_array\",dflt:[]},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]}),colorscales:u(\"concentrationscales\",{editType:\"calc\",label:{valType:\"string\",editType:\"calc\",dflt:\"\"},cmax:{valType:\"number\",editType:\"calc\",dflt:1},cmin:{valType:\"number\",editType:\"calc\",dflt:0},colorscale:h(c().colorscale,{dflt:[[0,\"white\"],[1,\"black\"]]})})}},\"calc\",\"nested\")).transforms=void 0},{\"../../components/color/attributes\":592,\"../../components/colorscale/attributes\":600,\"../../components/fx/attributes\":623,\"../../components/fx/hovertemplate_attributes\":631,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1103:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../components/fx/layout_attributes\"),s=t(\"../../lib/setcursor\"),l=t(\"../../components/dragelement\"),c=t(\"../../plots/cartesian/select\").prepSelect,u=t(\"../../lib\"),h=t(\"../../registry\");function f(t,e){var r=t._fullData[e],n=t._fullLayout,i=n.dragmode,a=\"pan\"===n.dragmode?\"move\":\"crosshair\",o=r._bgRect;if(\"pan\"!==i&&\"zoom\"!==i){s(o,a);var f={_id:\"x\",c2p:u.identity,_offset:r._sankey.translateX,_length:r._sankey.width},p={_id:\"y\",c2p:u.identity,_offset:r._sankey.translateY,_length:r._sankey.height},d={gd:t,element:o.node(),plotinfo:{id:e,xaxis:f,yaxis:p,fillRangeItems:u.noop},subplot:e,xaxes:[f],yaxes:[p],doneFnCompleted:function(r){var n,i=t._fullData[e],a=i.node.groups.slice(),o=[];function s(t){for(var e=i._sankey.graph.nodes,r=0;r<e.length;r++)if(e[r].pointNumber===t)return e[r]}for(var l=0;l<r.length;l++){var c=s(r[l].pointNumber);if(c)if(c.group){for(var u=0;u<c.childrenNodes.length;u++)o.push(c.childrenNodes[u].pointNumber);a[c.pointNumber-i.node._count]=!1}else o.push(c.pointNumber)}n=a.filter(Boolean).concat([o]),h.call(\"_guiRestyle\",t,{\"node.groups\":[n]},e)},prepFn:function(t,e,r){c(t,e,r,d,i)}};l.init(d)}}r.name=\"sankey\",r.baseLayoutAttrOverrides=n({hoverlabel:o.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){var e=i(t.calcdata,\"sankey\")[0];a(t,e),r.updateFx(t)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"sankey\"),a=e._has&&e._has(\"sankey\");i&&!a&&(n._paperdiv.selectAll(\".sankey\").remove(),n._paperdiv.selectAll(\".bgsankey\").remove())},r.updateFx=function(t){for(var e=0;e<t._fullData.length;e++)f(t,e)}},{\"../../components/dragelement\":611,\"../../components/fx/layout_attributes\":633,\"../../lib\":719,\"../../lib/setcursor\":739,\"../../plot_api/edit_types\":750,\"../../plots/cartesian/select\":784,\"../../plots/get_data\":802,\"../../registry\":847,\"./plot\":1108}],1104:[function(t,e,r){\"use strict\";var n=t(\"strongly-connected-components\"),i=t(\"../../lib\"),a=t(\"../../lib/gup\").wrap,o=i.isArrayOrTypedArray,s=i.isIndex,l=t(\"../../components/colorscale\");function c(t){var e,r=t.node,a=t.link,c=[],u=o(a.color),h={},f={},p=a.colorscales.length;for(e=0;e<p;e++){var d=a.colorscales[e],g=l.extractScale(d,{cLetter:\"c\"}),v=l.makeColorScaleFunc(g);f[d.label]=v}var m=0;for(e=0;e<a.value.length;e++)a.source[e]>m&&(m=a.source[e]),a.target[e]>m&&(m=a.target[e]);var y,x=m+1;t.node._count=x;var b=t.node.groups,_={};for(e=0;e<b.length;e++){var w=b[e];for(y=0;y<w.length;y++){var k=w[y],T=x+e;_.hasOwnProperty(k)?i.warn(\"Node \"+k+\" is already part of a group.\"):_[k]=T}}var A={source:[],target:[]};for(e=0;e<a.value.length;e++){var M=a.value[e],S=a.source[e],E=a.target[e];if(M>0&&s(S,x)&&s(E,x)&&(!_.hasOwnProperty(S)||!_.hasOwnProperty(E)||_[S]!==_[E])){_.hasOwnProperty(E)&&(E=_[E]),_.hasOwnProperty(S)&&(S=_[S]),E=+E,h[S=+S]=h[E]=!0;var C=\"\";a.label&&a.label[e]&&(C=a.label[e]);var L=null;C&&f.hasOwnProperty(C)&&(L=f[C]),c.push({pointNumber:e,label:C,color:u?a.color[e]:a.color,concentrationscale:L,source:S,target:E,value:+M}),A.source.push(S),A.target.push(E)}}var P=x+b.length,O=o(r.color),z=[];for(e=0;e<P;e++)if(h[e]){var I=r.label[e];z.push({group:e>x-1,childrenNodes:[],pointNumber:e,label:I,color:O?r.color[e]:r.color})}var D=!1;return function(t,e,r){for(var a=i.init2dArray(t,0),o=0;o<Math.min(e.length,r.length);o++)if(i.isIndex(e[o],t)&&i.isIndex(r[o],t)){if(e[o]===r[o])return!0;a[e[o]].push(r[o])}return n(a).components.some(function(t){return t.length>1})}(P,A.source,A.target)&&(D=!0),{circular:D,links:c,nodes:z,groups:b,groupLookup:_}}e.exports=function(t,e){var r=c(e);return a({circular:r.circular,_nodes:r.nodes,_links:r.links,_groups:r.groups,_groupLookup:r.groupLookup})}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gup\":717,\"strongly-connected-components\":530}],1105:[function(t,e,r){\"use strict\";e.exports={nodeTextOffsetHorizontal:4,nodeTextOffsetVertical:3,nodePadAcross:10,sankeyIterations:50,forceIterations:5,forceTicksPerFrame:10,duration:500,ease:\"linear\",cn:{sankey:\"sankey\",sankeyLinks:\"sankey-links\",sankeyLink:\"sankey-link\",sankeyNodeSet:\"sankey-node-set\",sankeyNode:\"sankey-node\",nodeRect:\"node-rect\",nodeCapture:\"node-capture\",nodeCentered:\"node-entered\",nodeLabelGuide:\"node-label-guide\",nodeLabel:\"node-label\",nodeLabelTextPath:\"node-label-text-path\"}}},{}],1106:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../components/color\"),o=t(\"tinycolor2\"),s=t(\"../../plots/domain\").defaults,l=t(\"../../components/fx/hoverlabel_defaults\"),c=t(\"../../plot_api/plot_template\"),u=t(\"../../plots/array_container_defaults\");function h(t,e){function r(r,a){return n.coerce(t,e,i.link.colorscales,r,a)}r(\"label\"),r(\"cmin\"),r(\"cmax\"),r(\"colorscale\")}e.exports=function(t,e,r,f){function p(r,a){return n.coerce(t,e,i,r,a)}var d=n.extendDeep(f.hoverlabel,t.hoverlabel),g=t.node,v=c.newContainer(e,\"node\");function m(t,e){return n.coerce(g,v,i.node,t,e)}m(\"label\"),m(\"groups\"),m(\"x\"),m(\"y\"),m(\"pad\"),m(\"thickness\"),m(\"line.color\"),m(\"line.width\"),m(\"hoverinfo\",t.hoverinfo),l(g,v,m,d),m(\"hovertemplate\");var y=f.colorway;m(\"color\",v.label.map(function(t,e){return a.addOpacity(function(t){return y[t%y.length]}(e),.8)}));var x=t.link||{},b=c.newContainer(e,\"link\");function _(t,e){return n.coerce(x,b,i.link,t,e)}_(\"label\"),_(\"source\"),_(\"target\"),_(\"value\"),_(\"line.color\"),_(\"line.width\"),_(\"hoverinfo\",t.hoverinfo),l(x,b,_,d),_(\"hovertemplate\");var w,k=o(f.paper_bgcolor).getLuminance()<.333?\"rgba(255, 255, 255, 0.6)\":\"rgba(0, 0, 0, 0.2)\";_(\"color\",n.repeat(k,b.value.length)),u(x,b,{name:\"colorscales\",handleItemDefaults:h}),s(e,f,p),p(\"orientation\"),p(\"valueformat\"),p(\"valuesuffix\"),v.x.length&&v.y.length&&(w=\"freeform\"),p(\"arrangement\",w),n.coerceFont(p,\"textfont\",n.extendFlat({},f.font)),e._length=null}},{\"../../components/color\":593,\"../../components/fx/hoverlabel_defaults\":630,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/array_container_defaults\":763,\"../../plots/domain\":792,\"./attributes\":1102,tinycolor2:537}],1107:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"sankey\",basePlotModule:t(\"./base_plot\"),selectPoints:t(\"./select.js\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1102,\"./base_plot\":1103,\"./calc\":1104,\"./defaults\":1106,\"./plot\":1108,\"./select.js\":1110}],1108:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./render\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\"),l=t(\"./constants\").cn,c=s._;function u(t){return\"\"!==t}function h(t,e){return t.filter(function(t){return t.key===e.traceId})}function f(t,e){n.select(t).select(\"path\").style(\"fill-opacity\",e),n.select(t).select(\"rect\").style(\"fill-opacity\",e)}function p(t){n.select(t).select(\"text.name\").style(\"fill\",\"black\")}function d(t){return function(e){return-1!==t.node.sourceLinks.indexOf(e.link)||-1!==t.node.targetLinks.indexOf(e.link)}}function g(t){return function(e){return-1!==e.node.sourceLinks.indexOf(t.link)||-1!==e.node.targetLinks.indexOf(t.link)}}function v(t,e,r){e&&r&&h(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(y.bind(0,e,r,!1))}function m(t,e,r){e&&r&&h(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(x.bind(0,e,r,!1))}function y(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",function(t){if(!t.link.concentrationscale)return.4}),i&&h(e,t).selectAll(\".\"+l.sankeyLink).filter(function(t){return t.link.label===i}).style(\"fill-opacity\",function(t){if(!t.link.concentrationscale)return.4}),r&&h(e,t).selectAll(\".\"+l.sankeyNode).filter(g(t)).call(v)}function x(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),i&&h(e,t).selectAll(\".\"+l.sankeyLink).filter(function(t){return t.link.label===i}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),r&&h(e,t).selectAll(l.sankeyNode).filter(g(t)).call(m)}function b(t,e){var r=t.hoverlabel||{},n=s.nestedProperty(r,e).get();return!Array.isArray(n)&&n}e.exports=function(t,e){for(var r=t._fullLayout,s=r._paper,h=r._size,d=0;d<t._fullData.length;d++)if(t._fullData[d].type===l.sankey&&!t._fullData[d]._viewInitial){var g=t._fullData[d].node;t._fullData[d]._viewInitial={node:{groups:g.groups.slice(),x:g.x.slice(),y:g.y.slice()}}}var _=c(t,\"source:\")+\" \",w=c(t,\"target:\")+\" \",k=c(t,\"concentration:\")+\" \",T=c(t,\"incoming flow count:\")+\" \",A=c(t,\"outgoing flow count:\")+\" \";i(t,s,e,{width:h.w,height:h.h,margin:{t:h.t,r:h.r,b:h.b,l:h.l}},{linkEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(y.bind(0,r,i,!0)),\"skip\"!==r.link.trace.link.hoverinfo&&(r.link.fullData=r.link.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.link]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var s=i.link.trace.link;if(\"none\"!==s.hoverinfo&&\"skip\"!==s.hoverinfo){for(var l=[],c=0,h=0;h<i.flow.links.length;h++){var d=i.flow.links[h];if(\"closest\"!==t._fullLayout.hovermode||i.link.pointNumber===d.pointNumber){i.link.pointNumber===d.pointNumber&&(c=h),d.fullData=d.trace,s=i.link.trace.link;var g=m(d),v={valueLabel:n.format(i.valueFormat)(d.value)+i.valueSuffix};l.push({x:g[0],y:g[1],name:v.valueLabel,text:[d.label||\"\",_+d.source.label,w+d.target.label,d.concentrationscale?k+n.format(\"%0.2f\")(d.flow.labelConcentration):\"\"].filter(u).join(\"<br>\"),color:b(s,\"bgcolor\")||o.addOpacity(d.color,1),borderColor:b(s,\"bordercolor\"),fontFamily:b(s,\"font.family\"),fontSize:b(s,\"font.size\"),fontColor:b(s,\"font.color\"),nameLength:b(s,\"namelength\"),textAlign:b(s,\"align\"),idealAlign:n.event.x<g[0]?\"right\":\"left\",hovertemplate:s.hovertemplate,hovertemplateLabels:v,eventData:[d]})}}a.loneHover(l,{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t,anchorIndex:c}).each(function(){i.link.concentrationscale||f(this,.65),p(this)})}}function m(t){var e,r;return t.circular?(e=(t.circularPathData.leftInnerExtent+t.circularPathData.rightInnerExtent)/2+i.parent.translateX,r=t.circularPathData.verticalFullExtent+i.parent.translateY):(e=(t.source.x1+t.target.x0)/2+i.parent.translateX,r=(t.y0+t.y1)/2+i.parent.translateY),[e,r]}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(x.bind(0,i,o,!0)),\"skip\"!==i.link.trace.link.hoverinfo&&(i.link.fullData=i.link.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.link]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r){var i=r.link;i.originalEvent=n.event,t._hoverdata=[i],a.click(t,{target:!0})}},nodeEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(v,r,i),\"skip\"!==r.node.trace.node.hoverinfo&&(r.node.fullData=r.node.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.node]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var o=i.node.trace.node;if(\"none\"!==o.hoverinfo&&\"skip\"!==o.hoverinfo){var s=n.select(e).select(\".\"+l.nodeRect),c=t._fullLayout._paperdiv.node().getBoundingClientRect(),h=s.node().getBoundingClientRect(),d=h.left-2-c.left,g=h.right+2-c.left,v=h.top+h.height/4-c.top,m={valueLabel:n.format(i.valueFormat)(i.node.value)+i.valueSuffix};i.node.fullData=i.node.trace;var y=a.loneHover({x0:d,x1:g,y:v,name:n.format(i.valueFormat)(i.node.value)+i.valueSuffix,text:[i.node.label,T+i.node.targetLinks.length,A+i.node.sourceLinks.length].filter(u).join(\"<br>\"),color:b(o,\"bgcolor\")||i.tinyColorHue,borderColor:b(o,\"bordercolor\"),fontFamily:b(o,\"font.family\"),fontSize:b(o,\"font.size\"),fontColor:b(o,\"font.color\"),nameLength:b(o,\"namelength\"),textAlign:b(o,\"align\"),idealAlign:\"left\",hovertemplate:o.hovertemplate,hovertemplateLabels:m,eventData:[i.node]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t});f(y,.85),p(y)}}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(m,i,o),\"skip\"!==i.node.trace.node.hoverinfo&&(i.node.fullData=i.node.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.node]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r,i){var o=r.node;o.originalEvent=n.event,t._hoverdata=[o],n.select(e).call(m,r,i),a.click(t,{target:!0})}}})}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"./constants\":1105,\"./render\":1109,d3:163}],1109:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"tinycolor2\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"@plotly/d3-sankey\"),c=t(\"@plotly/d3-sankey-circular\"),u=t(\"d3-force\"),h=t(\"../../lib\"),f=t(\"../../lib/gup\"),p=f.keyFun,d=f.repeat,g=f.unwrap,v=t(\"d3-interpolate\").interpolateNumber,m=t(\"../../registry\");function y(){var t=.5;return function(e){if(e.link.circular)return r=e.link,n=r.width/2,i=r.circularPathData,\"top\"===r.circularLinkType?\"M \"+i.targetX+\" \"+(i.targetY+n)+\" L\"+i.rightInnerExtent+\" \"+(i.targetY+n)+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightSmallArcRadius+n)+\" 0 0 1 \"+(i.rightFullExtent-n)+\" \"+(i.targetY-i.rightSmallArcRadius)+\"L\"+(i.rightFullExtent-n)+\" \"+i.verticalRightInnerExtent+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightLargeArcRadius+n)+\" 0 0 1 \"+i.rightInnerExtent+\" \"+(i.verticalFullExtent-n)+\"L\"+i.leftInnerExtent+\" \"+(i.verticalFullExtent-n)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftLargeArcRadius+n)+\" 0 0 1 \"+(i.leftFullExtent+n)+\" \"+i.verticalLeftInnerExtent+\"L\"+(i.leftFullExtent+n)+\" \"+(i.sourceY-i.leftSmallArcRadius)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftSmallArcRadius+n)+\" 0 0 1 \"+i.leftInnerExtent+\" \"+(i.sourceY+n)+\"L\"+i.sourceX+\" \"+(i.sourceY+n)+\"L\"+i.sourceX+\" \"+(i.sourceY-n)+\"L\"+i.leftInnerExtent+\" \"+(i.sourceY-n)+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftSmallArcRadius-n)+\" 0 0 0 \"+(i.leftFullExtent-n)+\" \"+(i.sourceY-i.leftSmallArcRadius)+\"L\"+(i.leftFullExtent-n)+\" \"+i.verticalLeftInnerExtent+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftLargeArcRadius-n)+\" 0 0 0 \"+i.leftInnerExtent+\" \"+(i.verticalFullExtent+n)+\"L\"+i.rightInnerExtent+\" \"+(i.verticalFullExtent+n)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightLargeArcRadius-n)+\" 0 0 0 \"+(i.rightFullExtent+n)+\" \"+i.verticalRightInnerExtent+\"L\"+(i.rightFullExtent+n)+\" \"+(i.targetY-i.rightSmallArcRadius)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightSmallArcRadius-n)+\" 0 0 0 \"+i.rightInnerExtent+\" \"+(i.targetY-n)+\"L\"+i.targetX+\" \"+(i.targetY-n)+\"Z\":\"M \"+i.targetX+\" \"+(i.targetY-n)+\" L\"+i.rightInnerExtent+\" \"+(i.targetY-n)+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightSmallArcRadius+n)+\" 0 0 0 \"+(i.rightFullExtent-n)+\" \"+(i.targetY+i.rightSmallArcRadius)+\"L\"+(i.rightFullExtent-n)+\" \"+i.verticalRightInnerExtent+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightLargeArcRadius+n)+\" 0 0 0 \"+i.rightInnerExtent+\" \"+(i.verticalFullExtent+n)+\"L\"+i.leftInnerExtent+\" \"+(i.verticalFullExtent+n)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftLargeArcRadius+n)+\" 0 0 0 \"+(i.leftFullExtent+n)+\" \"+i.verticalLeftInnerExtent+\"L\"+(i.leftFullExtent+n)+\" \"+(i.sourceY+i.leftSmallArcRadius)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftSmallArcRadius+n)+\" 0 0 0 \"+i.leftInnerExtent+\" \"+(i.sourceY-n)+\"L\"+i.sourceX+\" \"+(i.sourceY-n)+\"L\"+i.sourceX+\" \"+(i.sourceY+n)+\"L\"+i.leftInnerExtent+\" \"+(i.sourceY+n)+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftSmallArcRadius-n)+\" 0 0 1 \"+(i.leftFullExtent-n)+\" \"+(i.sourceY+i.leftSmallArcRadius)+\"L\"+(i.leftFullExtent-n)+\" \"+i.verticalLeftInnerExtent+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftLargeArcRadius-n)+\" 0 0 1 \"+i.leftInnerExtent+\" \"+(i.verticalFullExtent-n)+\"L\"+i.rightInnerExtent+\" \"+(i.verticalFullExtent-n)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightLargeArcRadius-n)+\" 0 0 1 \"+(i.rightFullExtent+n)+\" \"+i.verticalRightInnerExtent+\"L\"+(i.rightFullExtent+n)+\" \"+(i.targetY+i.rightSmallArcRadius)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightSmallArcRadius-n)+\" 0 0 1 \"+i.rightInnerExtent+\" \"+(i.targetY+n)+\"L\"+i.targetX+\" \"+(i.targetY+n)+\"Z\";var r,n,i,a=e.link.source.x1,o=e.link.target.x0,s=v(a,o),l=s(t),c=s(1-t),u=e.link.y0-e.link.width/2,h=e.link.y0+e.link.width/2,f=e.link.y1-e.link.width/2,p=e.link.y1+e.link.width/2;return\"M\"+a+\",\"+u+\"C\"+l+\",\"+u+\" \"+c+\",\"+f+\" \"+o+\",\"+f+\"L\"+o+\",\"+p+\"C\"+c+\",\"+p+\" \"+l+\",\"+h+\" \"+a+\",\"+h+\"Z\"}}function x(t){t.attr(\"transform\",function(t){return\"translate(\"+t.node.x0.toFixed(3)+\", \"+t.node.y0.toFixed(3)+\")\"})}function b(t){t.call(x)}function _(t,e){t.call(b),e.attr(\"d\",y())}function w(t){t.attr(\"width\",function(t){return t.node.x1-t.node.x0}).attr(\"height\",function(t){return t.visibleHeight})}function k(t){return t.link.width>1||t.linkLineWidth>0}function T(t){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"+(t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\")}function A(t){return\"translate(\"+(t.horizontal?0:t.labelY)+\" \"+(t.horizontal?t.labelY:0)+\")\"}function M(t){return i.svg.line()([[t.horizontal?t.left?-t.sizeAcross:t.visibleWidth+n.nodeTextOffsetHorizontal:n.nodeTextOffsetHorizontal,0],[t.horizontal?t.left?-n.nodeTextOffsetHorizontal:t.sizeAcross:t.visibleHeight-n.nodeTextOffsetHorizontal,0]])}function S(t){return t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\"}function E(t){return t.horizontal?\"scale(1 1)\":\"scale(-1 1)\"}function C(t){return t.darkBackground&&!t.horizontal?\"rgb(255,255,255)\":\"rgb(0,0,0)\"}function L(t){return t.horizontal&&t.left?\"100%\":\"0%\"}function P(t,e,r){t.on(\".basic\",null).on(\"mouseover.basic\",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.hover(this,t,e),t.interactionState.hovered=[this,t])}).on(\"mousemove.basic\",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.follow(this,t),t.interactionState.hovered=[this,t])}).on(\"mouseout.basic\",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.unhover(this,t,e),t.interactionState.hovered=!1)}).on(\"click.basic\",function(t){t.interactionState.hovered&&(r.unhover(this,t,e),t.interactionState.hovered=!1),t.interactionState.dragInProgress||t.partOfGroup||r.select(this,t,e)})}function O(t,e,r,a){var o=i.behavior.drag().origin(function(t){return{x:t.node.x0+t.visibleWidth/2,y:t.node.y0+t.visibleHeight/2}}).on(\"dragstart\",function(i){if(\"fixed\"!==i.arrangement&&(h.ensureSingle(a._fullLayout._infolayer,\"g\",\"dragcover\",function(t){a._fullLayout._dragCover=t}),h.raiseToTop(this),i.interactionState.dragInProgress=i.node,I(i.node),i.interactionState.hovered&&(r.nodeEvents.unhover.apply(0,i.interactionState.hovered),i.interactionState.hovered=!1),\"snap\"===i.arrangement)){var o=i.traceId+\"|\"+i.key;i.forceLayouts[o]?i.forceLayouts[o].alpha(1):function(t,e,r,i){!function(t){for(var e=0;e<t.length;e++)t[e].y=(t[e].y0+t[e].y1)/2,t[e].x=(t[e].x0+t[e].x1)/2}(r.graph.nodes);var a=r.graph.nodes.filter(function(t){return t.originalX===r.node.originalX}).filter(function(t){return!t.partOfGroup});r.forceLayouts[e]=u.forceSimulation(a).alphaDecay(0).force(\"collide\",u.forceCollide().radius(function(t){return t.dy/2+r.nodePad/2}).strength(1).iterations(n.forceIterations)).force(\"constrain\",function(t,e,r,i){return function(){for(var t=0,a=0;a<r.length;a++){var o=r[a];o===i.interactionState.dragInProgress?(o.x=o.lastDraggedX,o.y=o.lastDraggedY):(o.vx=(o.originalX-o.x)/n.forceTicksPerFrame,o.y=Math.min(i.size-o.dy/2,Math.max(o.dy/2,o.y))),t=Math.max(t,Math.abs(o.vx),Math.abs(o.vy))}!i.interactionState.dragInProgress&&t<.1&&i.forceLayouts[e].alpha()>0&&i.forceLayouts[e].alpha(0)}}(0,e,a,r)).stop()}(0,o,i),function(t,e,r,i,a){window.requestAnimationFrame(function o(){var s;for(s=0;s<n.forceTicksPerFrame;s++)r.forceLayouts[i].tick();var l=r.graph.nodes;if(function(t){for(var e=0;e<t.length;e++)t[e].y0=t[e].y-t[e].dy/2,t[e].y1=t[e].y0+t[e].dy,t[e].x0=t[e].x-t[e].dx/2,t[e].x1=t[e].x0+t[e].dx}(l),r.sankey.update(r.graph),_(t.filter(D(r)),e),r.forceLayouts[i].alpha()>0)window.requestAnimationFrame(o);else{var c=r.node.originalX;r.node.x0=c-r.visibleWidth/2,r.node.x1=c+r.visibleWidth/2,z(r,a)}})}(t,e,i,o,a)}}).on(\"drag\",function(r){if(\"fixed\"!==r.arrangement){var n=i.event.x,a=i.event.y;\"snap\"===r.arrangement?(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2,r.node.y0=a-r.visibleHeight/2,r.node.y1=a+r.visibleHeight/2):(\"freeform\"===r.arrangement&&(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2),a=Math.max(0,Math.min(r.size-r.visibleHeight/2,a)),r.node.y0=a-r.visibleHeight/2,r.node.y1=a+r.visibleHeight/2),I(r.node),\"snap\"!==r.arrangement&&(r.sankey.update(r.graph),_(t.filter(D(r)),e))}}).on(\"dragend\",function(t){if(\"fixed\"!==t.arrangement){t.interactionState.dragInProgress=!1;for(var e=0;e<t.node.childrenNodes.length;e++)t.node.childrenNodes[e].x=t.node.x,t.node.childrenNodes[e].y=t.node.y;\"snap\"!==t.arrangement&&z(t,a)}});t.on(\".drag\",null).call(o)}function z(t,e){for(var r=[],n=[],i=0;i<t.graph.nodes.length;i++){var a=(t.graph.nodes[i].x0+t.graph.nodes[i].x1)/2,o=(t.graph.nodes[i].y0+t.graph.nodes[i].y1)/2;r.push(a/t.figure.width),n.push(o/t.figure.height)}m.call(\"_guiRestyle\",e,{\"node.x\":[r],\"node.y\":[n]},t.trace.index).then(function(){e._fullLayout._dragCover&&e._fullLayout._dragCover.remove()})}function I(t){t.lastDraggedX=t.x0+t.dx/2,t.lastDraggedY=t.y0+t.dy/2}function D(t){return function(e){return e.node.originalX===t.node.originalX}}e.exports=function(t,e,r,u,f){var v=!1;h.ensureSingle(t._fullLayout._infolayer,\"g\",\"first-render\",function(){v=!0});var m=t._fullLayout._dragCover,b=r.filter(function(t){return g(t).trace.visible}).map(function(t,e,r){var i,o=g(e),s=o.trace,u=s.domain,f=\"h\"===s.orientation,p=s.node.pad,d=s.node.thickness,v=t.width*(u.x[1]-u.x[0]),m=t.height*(u.y[1]-u.y[0]),y=o._nodes,x=o._links,b=o.circular;(i=b?c.sankeyCircular().circularLinkGap(0):l.sankey()).iterations(n.sankeyIterations).size(f?[v,m]:[m,v]).nodeWidth(d).nodePadding(p).nodeId(function(t){return t.pointNumber}).nodes(y).links(x);var _,w,k,T=i();for(var A in i.nodePadding()<p&&h.warn(\"node.pad was reduced to \",i.nodePadding(),\" to fit within the figure.\"),o._groupLookup){var M,S=parseInt(o._groupLookup[A]);for(_=0;_<T.nodes.length;_++)if(T.nodes[_].pointNumber===S){M=T.nodes[_];break}if(M){var E={pointNumber:parseInt(A),x0:M.x0,x1:M.x1,y0:M.y0,y1:M.y1,partOfGroup:!0,sourceLinks:[],targetLinks:[]};T.nodes.unshift(E),M.childrenNodes.unshift(E)}}if(function(){for(_=0;_<T.nodes.length;_++){var t,e,r=T.nodes[_],n={};for(w=0;w<r.targetLinks.length;w++)t=(e=r.targetLinks[w]).source.pointNumber+\":\"+e.target.pointNumber,n.hasOwnProperty(t)||(n[t]=[]),n[t].push(e);var i=Object.keys(n);for(w=0;w<i.length;w++){var o=n[t=i[w]],s=0,l={};for(k=0;k<o.length;k++)l[(e=o[k]).label]||(l[e.label]=0),l[e.label]+=e.value,s+=e.value;for(k=0;k<o.length;k++)(e=o[k]).flow={value:s,labelConcentration:l[e.label]/s,concentration:e.value/s,links:o},e.concentrationscale&&(e.color=a(e.concentrationscale(e.flow.labelConcentration)))}var c=0;for(w=0;w<r.sourceLinks.length;w++)c+=r.sourceLinks[w].value;for(w=0;w<r.sourceLinks.length;w++)(e=r.sourceLinks[w]).concentrationOut=e.value/c;var u=0;for(w=0;w<r.targetLinks.length;w++)u+=r.targetLinks[w].value;for(w=0;w<r.targetLinks.length;w++)(e=r.targetLinks[w]).concenrationIn=e.value/u}}(),s.node.x.length&&s.node.y.length){for(_=0;_<Math.min(s.node.x.length,s.node.y.length,T.nodes.length);_++)if(s.node.x[_]&&s.node.y[_]){var C=[s.node.x[_]*v,s.node.y[_]*m];T.nodes[_].x0=C[0]-d/2,T.nodes[_].x1=C[0]+d/2;var L=T.nodes[_].y1-T.nodes[_].y0;T.nodes[_].y0=C[1]-L/2,T.nodes[_].y1=C[1]+L/2}\"snap\"===s.arrangement&&function(t){t.forEach(function(t){var e,r,n,i=0,a=t.length;for(t.sort(function(t,e){return t.y0-e.y0}),n=0;n<a;++n)(e=t[n]).y0>=i||(r=i-e.y0)>1e-6&&(e.y0+=r,e.y1+=r),i=e.y1+p})}(function(t){var e,r,n=t.map(function(t,e){return{x0:t.x0,index:e}}).sort(function(t,e){return t.x0-e.x0}),i=[],a=-1,o=-1/0;for(_=0;_<n.length;_++){var s=t[n[_].index];s.x0>o+d&&(a+=1,e=s.x0),o=s.x0,i[a]||(i[a]=[]),i[a].push(s),r=e-s.x0,s.x0+=r,s.x1+=r}return i}(y=T.nodes)),i.update(T)}return{circular:b,key:r,trace:s,guid:h.randstr(),horizontal:f,width:v,height:m,nodePad:s.node.pad,nodeLineColor:s.node.line.color,nodeLineWidth:s.node.line.width,linkLineColor:s.link.line.color,linkLineWidth:s.link.line.width,valueFormat:s.valueformat,valueSuffix:s.valuesuffix,textFont:s.textfont,translateX:u.x[0]*t.width+t.margin.l,translateY:t.height-u.y[1]*t.height+t.margin.t,dragParallel:f?m:v,dragPerpendicular:f?v:m,arrangement:s.arrangement,sankey:i,graph:T,forceLayouts:{},interactionState:{dragInProgress:!1,hovered:!1}}}.bind(null,u)),_=e.selectAll(\".\"+n.cn.sankey).data(b,p);_.exit().remove(),_.enter().append(\"g\").classed(n.cn.sankey,!0).style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"shape-rendering\",\"geometricPrecision\").style(\"pointer-events\",\"auto\").attr(\"transform\",T),_.each(function(e,r){t._fullData[r]._sankey=e;var n=\"bgsankey-\"+e.trace.uid+\"-\"+r;h.ensureSingle(t._fullLayout._draggers,\"rect\",n),t._fullData[r]._bgRect=i.select(\".\"+n),t._fullData[r]._bgRect.style(\"pointer-events\",\"all\").attr(\"width\",e.width).attr(\"height\",e.height).attr(\"x\",e.translateX).attr(\"y\",e.translateY).classed(\"bgsankey\",!0).style({fill:\"transparent\",\"stroke-width\":0})}),_.transition().ease(n.ease).duration(n.duration).attr(\"transform\",T);var z=_.selectAll(\".\"+n.cn.sankeyLinks).data(d,p);z.enter().append(\"g\").classed(n.cn.sankeyLinks,!0).style(\"fill\",\"none\");var I=z.selectAll(\".\"+n.cn.sankeyLink).data(function(t){return t.graph.links.filter(function(t){return t.value}).map(function(t,e,r){var n=a(e.color),i=e.source.label+\"|\"+e.target.label+\"__\"+r;return e.trace=t.trace,e.curveNumber=t.trace.index,{circular:t.circular,key:i,traceId:t.key,pointNumber:e.pointNumber,link:e,tinyColorHue:o.tinyRGB(n),tinyColorAlpha:n.getAlpha(),linkPath:y,linkLineColor:t.linkLineColor,linkLineWidth:t.linkLineWidth,valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,parent:t,interactionState:t.interactionState,flow:e.flow}}.bind(null,t))},p);I.enter().append(\"path\").classed(n.cn.sankeyLink,!0).call(P,_,f.linkEvents),I.style(\"stroke\",function(t){return k(t)?o.tinyRGB(a(t.linkLineColor)):t.tinyColorHue}).style(\"stroke-opacity\",function(t){return k(t)?o.opacity(t.linkLineColor):t.tinyColorAlpha}).style(\"fill\",function(t){return t.tinyColorHue}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}).style(\"stroke-width\",function(t){return k(t)?t.linkLineWidth:1}).attr(\"d\",y()),I.style(\"opacity\",function(){return t._context.staticPlot||v||m?1:0}).transition().ease(n.ease).duration(n.duration).style(\"opacity\",1),I.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var D=_.selectAll(\".\"+n.cn.sankeyNodeSet).data(d,p);D.enter().append(\"g\").classed(n.cn.sankeyNodeSet,!0),D.style(\"cursor\",function(t){switch(t.arrangement){case\"fixed\":return\"default\";case\"perpendicular\":return\"ns-resize\";default:return\"move\"}});var R=D.selectAll(\".\"+n.cn.sankeyNode).data(function(t){var e=t.graph.nodes;return function(t){var e,r=[];for(e=0;e<t.length;e++)t[e].originalX=(t[e].x0+t[e].x1)/2,t[e].originalY=(t[e].y0+t[e].y1)/2,-1===r.indexOf(t[e].originalX)&&r.push(t[e].originalX);for(r.sort(function(t,e){return t-e}),e=0;e<t.length;e++)t[e].originalLayerIndex=r.indexOf(t[e].originalX),t[e].originalLayer=t[e].originalLayerIndex/(r.length-1)}(e),e.map(function(t,e){var r=a(e.color),i=n.nodePadAcross,s=t.nodePad/2;e.dx=e.x1-e.x0,e.dy=e.y1-e.y0;var l=e.dx,c=Math.max(.5,e.dy),u=\"node_\"+e.pointNumber;return e.group&&(u=h.randstr()),e.trace=t.trace,e.curveNumber=t.trace.index,{index:e.pointNumber,key:u,partOfGroup:e.partOfGroup||!1,group:e.group,traceId:t.key,trace:t.trace,node:e,nodePad:t.nodePad,nodeLineColor:t.nodeLineColor,nodeLineWidth:t.nodeLineWidth,textFont:t.textFont,size:t.horizontal?t.height:t.width,visibleWidth:Math.ceil(l),visibleHeight:c,zoneX:-i,zoneY:-s,zoneWidth:l+2*i,zoneHeight:c+2*s,labelY:t.horizontal?e.dy/2+1:e.dx/2+1,left:1===e.originalLayer,sizeAcross:t.width,forceLayouts:t.forceLayouts,horizontal:t.horizontal,darkBackground:r.getBrightness()<=128,tinyColorHue:o.tinyRGB(r),tinyColorAlpha:r.getAlpha(),valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,graph:t.graph,arrangement:t.arrangement,uniqueNodeLabelPathId:[t.guid,t.key,u].join(\"_\"),interactionState:t.interactionState,figure:t}}.bind(null,t))},p);R.enter().append(\"g\").classed(n.cn.sankeyNode,!0).call(x).style(\"opacity\",function(e){return!t._context.staticPlot&&!v||e.partOfGroup?0:1}),R.call(P,_,f.nodeEvents).call(O,I,f,t),R.transition().ease(n.ease).duration(n.duration).call(x).style(\"opacity\",function(t){return t.partOfGroup?0:1}),R.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var F=R.selectAll(\".\"+n.cn.nodeRect).data(d);F.enter().append(\"rect\").classed(n.cn.nodeRect,!0).call(w),F.style(\"stroke-width\",function(t){return t.nodeLineWidth}).style(\"stroke\",function(t){return o.tinyRGB(a(t.nodeLineColor))}).style(\"stroke-opacity\",function(t){return o.opacity(t.nodeLineColor)}).style(\"fill\",function(t){return t.tinyColorHue}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),F.transition().ease(n.ease).duration(n.duration).call(w);var B=R.selectAll(\".\"+n.cn.nodeCapture).data(d);B.enter().append(\"rect\").classed(n.cn.nodeCapture,!0).style(\"fill-opacity\",0),B.attr(\"x\",function(t){return t.zoneX}).attr(\"y\",function(t){return t.zoneY}).attr(\"width\",function(t){return t.zoneWidth}).attr(\"height\",function(t){return t.zoneHeight});var N=R.selectAll(\".\"+n.cn.nodeCentered).data(d);N.enter().append(\"g\").classed(n.cn.nodeCentered,!0).attr(\"transform\",A),N.transition().ease(n.ease).duration(n.duration).attr(\"transform\",A);var j=N.selectAll(\".\"+n.cn.nodeLabelGuide).data(d);j.enter().append(\"path\").classed(n.cn.nodeLabelGuide,!0).attr(\"id\",function(t){return t.uniqueNodeLabelPathId}).attr(\"d\",M).attr(\"transform\",S),j.transition().ease(n.ease).duration(n.duration).attr(\"d\",M).attr(\"transform\",S);var U=N.selectAll(\".\"+n.cn.nodeLabel).data(d);U.enter().append(\"text\").classed(n.cn.nodeLabel,!0).attr(\"transform\",E).style(\"user-select\",\"none\").style(\"cursor\",\"default\").style(\"fill\",\"black\"),U.style(\"text-shadow\",function(t){return t.horizontal?\"-1px 1px 1px #fff, 1px 1px 1px #fff, 1px -1px 1px #fff, -1px -1px 1px #fff\":\"none\"}).each(function(t){s.font(U,t.textFont)}),U.transition().ease(n.ease).duration(n.duration).attr(\"transform\",E);var V=U.selectAll(\".\"+n.cn.nodeLabelTextPath).data(d);V.enter().append(\"textPath\").classed(n.cn.nodeLabelTextPath,!0).attr(\"alignment-baseline\",\"middle\").attr(\"xlink:href\",function(t){return\"#\"+t.uniqueNodeLabelPathId}).attr(\"startOffset\",L).style(\"fill\",C),V.text(function(t){return t.horizontal||t.node.dy>5?t.node.label:\"\"}).attr(\"text-anchor\",function(t){return t.horizontal&&t.left?\"end\":\"start\"}),V.transition().ease(n.ease).duration(n.duration).attr(\"startOffset\",L).style(\"fill\",C)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/gup\":717,\"../../registry\":847,\"./constants\":1105,\"@plotly/d3-sankey\":54,\"@plotly/d3-sankey-circular\":53,d3:163,\"d3-force\":156,\"d3-interpolate\":158,tinycolor2:537}],1110:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=[],n=t.cd[0].trace,i=n._sankey.graph.nodes,a=0;a<i.length;a++){var o=i[a];if(!o.partOfGroup){var s=[(o.x0+o.x1)/2,(o.y0+o.y1)/2];\"v\"===n.orientation&&s.reverse(),e&&e.contains(s,!1,a,t)&&r.push({pointNumber:o.pointNumber})}}return r}},{}],1111:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\"),n.mergeArray(e.customdata,t,\"data\"),n.mergeArray(e.textposition,t,\"tp\"),e.textfont&&(n.mergeArrayCastPositive(e.textfont.size,t,\"ts\"),n.mergeArray(e.textfont.color,t,\"tc\"),n.mergeArray(e.textfont.family,t,\"tf\"));var i=e.marker;if(i){n.mergeArrayCastPositive(i.size,t,\"ms\"),n.mergeArrayCastPositive(i.opacity,t,\"mo\"),n.mergeArray(i.symbol,t,\"mx\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;i.line&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"));var o=i.gradient;o&&\"none\"!==o.type&&(n.mergeArray(o.type,t,\"mgt\"),n.mergeArray(o.color,t,\"mgc\"))}}},{\"../../lib\":719}],1112:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../components/drawing/attributes\").dash,s=t(\"../../components/drawing\"),l=t(\"./constants\"),c=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},x0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dx:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},y0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dy:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},stackgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc\"},groupnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},stackgaps:{valType:\"enumerated\",values:[\"infer zero\",\"interpolate\"],dflt:\"infer zero\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"],editType:\"calc\"},hoveron:{valType:\"flaglist\",flags:[\"points\",\"fills\"],editType:\"style\"},hovertemplate:n({},{keys:l.eventDataKeys}),line:{color:{valType:\"color\",editType:\"style\",anim:!0},width:{valType:\"number\",min:0,dflt:2,editType:\"style\",anim:!0},shape:{valType:\"enumerated\",values:[\"linear\",\"spline\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},smoothing:{valType:\"number\",min:0,max:1.3,dflt:1,editType:\"plot\"},dash:c({},o,{editType:\"style\"}),simplify:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cliponaxis:{valType:\"boolean\",dflt:!0,editType:\"plot\"},fill:{valType:\"enumerated\",values:[\"none\",\"tozeroy\",\"tozerox\",\"tonexty\",\"tonextx\",\"toself\",\"tonext\"],editType:\"calc\"},fillcolor:{valType:\"color\",editType:\"style\",anim:!0},marker:c({symbol:{valType:\"enumerated\",values:s.symbolList,dflt:\"circle\",arrayOk:!0,editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,arrayOk:!0,editType:\"style\",anim:!0},size:{valType:\"number\",min:0,dflt:6,arrayOk:!0,editType:\"calc\",anim:!0},maxdisplayed:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},sizeref:{valType:\"number\",dflt:1,editType:\"calc\"},sizemin:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"diameter\",\"area\"],dflt:\"diameter\",editType:\"calc\"},line:c({width:{valType:\"number\",min:0,arrayOk:!0,editType:\"style\",anim:!0},editType:\"calc\"},i(\"marker.line\",{anim:!0})),gradient:{type:{valType:\"enumerated\",values:[\"radial\",\"horizontal\",\"vertical\",\"none\"],arrayOk:!0,dflt:\"none\",editType:\"calc\"},color:{valType:\"color\",arrayOk:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},i(\"marker\",{anim:!0})),selected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},unselected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\"],dflt:\"middle center\",arrayOk:!0,editType:\"calc\"},textfont:a({editType:\"calc\",colorEditType:\"style\",arrayOk:!0}),r:{valType:\"data_array\",editType:\"calc\"},t:{valType:\"data_array\",editType:\"calc\"}}},{\"../../components/colorscale/attributes\":600,\"../../components/drawing\":614,\"../../components/drawing/attributes\":613,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"./constants\":1116}],1113:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/numerical\").BADNUM,s=t(\"./subtypes\"),l=t(\"./colorscale_calc\"),c=t(\"./arrays_to_calcdata\"),u=t(\"./calc_selection\");function h(t,e,r,n,i,o,l){var c=e._length,u=t._fullLayout,h=r._id,f=n._id,p=u._firstScatter[d(e)]===e.uid,v=(g(e,u,r,n)||{}).orientation,m=e.fill;r._minDtick=0,n._minDtick=0;var y={padded:!0},x={padded:!0};l&&(y.ppad=x.ppad=l);var b=c<2||i[0]!==i[c-1]||o[0]!==o[c-1];b&&(\"tozerox\"===m||\"tonextx\"===m&&(p||\"h\"===v))?y.tozero=!0:(e.error_y||{}).visible||\"tonexty\"!==m&&\"tozeroy\"!==m&&(s.hasMarkers(e)||s.hasText(e))||(y.padded=!1,y.ppad=0),b&&(\"tozeroy\"===m||\"tonexty\"===m&&(p||\"v\"===v))?x.tozero=!0:\"tonextx\"!==m&&\"tozerox\"!==m||(x.padded=!1),h&&(e._extremes[h]=a.findExtremes(r,i,y)),f&&(e._extremes[f]=a.findExtremes(n,o,x))}function f(t,e){if(s.hasMarkers(t)){var r,n=t.marker,o=1.6*(t.marker.sizeref||1);if(r=\"area\"===t.marker.sizemode?function(t){return Math.max(Math.sqrt((t||0)/o),3)}:function(t){return Math.max((t||0)/o,3)},i.isArrayOrTypedArray(n.size)){var l={type:\"linear\"};a.setConvert(l);for(var c=l.makeCalcdata(t.marker,\"size\"),u=new Array(e),h=0;h<e;h++)u[h]=r(c[h]);return u}return r(n.size)}}function p(t,e){var r=d(e),n=t._firstScatter;n[r]||(n[r]=e.uid)}function d(t){var e=t.stackgroup;return t.xaxis+t.yaxis+t.type+(e?\"-\"+e:\"\")}function g(t,e,r,n){var i=t.stackgroup;if(i){var a=e._scatterStackOpts[r._id+n._id][i],o=\"v\"===a.orientation?n:r;return\"linear\"===o.type||\"log\"===o.type?a:void 0}}e.exports={calc:function(t,e){var r,s,d,v,m,y,x=t._fullLayout,b=a.getFromId(t,e.xaxis||\"x\"),_=a.getFromId(t,e.yaxis||\"y\"),w=b.makeCalcdata(e,\"x\"),k=_.makeCalcdata(e,\"y\"),T=e._length,A=new Array(T),M=e.ids,S=g(e,x,b,_),E=!1;p(x,e);var C,L=\"x\",P=\"y\";for(S?(i.pushUnique(S.traceIndices,e._expandedIndex),(r=\"v\"===S.orientation)?(P=\"s\",C=\"x\"):(L=\"s\",C=\"y\"),m=\"interpolate\"===S.stackgaps):h(t,e,b,_,w,k,f(e,T)),s=0;s<T;s++){var O=A[s]={},z=n(w[s]),I=n(k[s]);z&&I?(O[L]=w[s],O[P]=k[s]):S&&(r?z:I)?(O[C]=r?w[s]:k[s],O.gap=!0,m?(O.s=o,E=!0):O.s=0):O[L]=O[P]=o,M&&(O.id=String(M[s]))}if(c(A,e),l(t,e),u(A,e),S){for(s=0;s<A.length;)A[s][C]===o?A.splice(s,1):s++;if(i.sort(A,function(t,e){return t[C]-e[C]||t.i-e.i}),E){for(s=0;s<A.length-1&&A[s].gap;)s++;for((y=A[s].s)||(y=A[s].s=0),d=0;d<s;d++)A[d].s=y;for(v=A.length-1;v>s&&A[v].gap;)v--;for(y=A[v].s,d=A.length-1;d>v;d--)A[d].s=y;for(;s<v;)if(A[++s].gap){for(d=s+1;A[d].gap;)d++;for(var D=A[s-1][C],R=A[s-1].s,F=(A[d].s-R)/(A[d][C]-D);s<d;)A[s].s=R+(A[s][C]-D)*F,s++}}}return A},calcMarkerSize:f,calcAxisExpansion:h,setFirstScatter:p,getStackOpts:g}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./arrays_to_calcdata\":1111,\"./calc_selection\":1114,\"./colorscale_calc\":1115,\"./subtypes\":1135,\"fast-isnumeric\":225}],1114:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){n.isArrayOrTypedArray(e.selectedpoints)&&n.tagSelected(t,e)}},{\"../../lib\":719}],1115:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"./subtypes\");e.exports=function(t,e){a.hasLines(e)&&n(e,\"line\")&&i(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),a.hasMarkers(e)&&(n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}))}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"./subtypes\":1135}],1116:[function(t,e,r){\"use strict\";e.exports={PTS_LINESONLY:20,minTolerance:.2,toleranceGrowth:10,maxScreensAway:20,eventDataKeys:[]}},{}],1117:[function(t,e,r){\"use strict\";var n=t(\"./calc\");function i(t,e,r,n,i,a,o){i[n]=!0;var s={i:null,gap:!0,s:0};if(s[o]=r,t.splice(e,0,s),e&&r===t[e-1][o]){var l=t[e-1];s.s=l.s,s.i=l.i,s.gap=l.gap}else a&&(s.s=function(t,e,r,n){var i=t[e-1],a=t[e+1];return a?i?i.s+(a.s-i.s)*(r-i[n])/(a[n]-i[n]):a.s:i.s}(t,e,r,o));e||(t[0].t=t[1].t,t[0].trace=t[1].trace,delete t[1].t,delete t[1].trace)}e.exports=function(t,e){var r=e.xaxis,a=e.yaxis,o=r._id+a._id,s=t._fullLayout._scatterStackOpts[o];if(s){var l,c,u,h,f,p,d,g,v,m,y,x,b,_,w,k=t.calcdata;for(var T in s){var A=(m=s[T]).traceIndices;if(A.length){for(y=\"interpolate\"===m.stackgaps,x=m.groupnorm,\"v\"===m.orientation?(b=\"x\",_=\"y\"):(b=\"y\",_=\"x\"),w=new Array(A.length),l=0;l<w.length;l++)w[l]=!1;p=k[A[0]];var M=new Array(p.length);for(l=0;l<p.length;l++)M[l]=p[l][b];for(l=1;l<A.length;l++){for(f=k[A[l]],c=u=0;c<f.length;c++){for(d=f[c][b];d>M[u]&&u<M.length;u++)i(f,c,M[u],l,w,y,b),c++;if(d!==M[u]){for(h=0;h<l;h++)i(k[A[h]],u,d,h,w,y,b);M.splice(u,0,d)}u++}for(;u<M.length;u++)i(f,c,M[u],l,w,y,b),c++}var S=M.length;for(c=0;c<p.length;c++){for(g=p[c][_]=p[c].s,l=1;l<A.length;l++)(f=k[A[l]])[0].trace._rawLength=f[0].trace._length,f[0].trace._length=S,g+=f[c].s,f[c][_]=g;if(x)for(v=(\"fraction\"===x?g:g/100)||1,l=0;l<A.length;l++){var E=k[A[l]][c];E[_]/=v,E.sNorm=E.s/v}}for(l=0;l<A.length;l++){var C=(f=k[A[l]])[0].trace,L=n.calcMarkerSize(C,C._rawLength),P=Array.isArray(L);if(L&&w[l]||P){var O=L;for(L=new Array(S),c=0;c<S;c++)L[c]=f[c].gap?0:P?O[f[c].i]:O}var z=new Array(S),I=new Array(S);for(c=0;c<S;c++)z[c]=f[c].x,I[c]=f[c].y;n.calcAxisExpansion(t,C,r,a,z,I,L),f[0].t.orientation=m.orientation}}}}}},{\"./calc\":1113}],1118:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0;e<t.length;e++){var r=t[e];if(\"scatter\"===r.type){var n=r.fill;if(\"none\"!==n&&\"toself\"!==n&&(r.opacity=void 0,\"tonexty\"===n||\"tonextx\"===n))for(var i=e-1;i>=0;i--){var a=t[i];if(\"scatter\"===a.type&&a.xaxis===r.xaxis&&a.yaxis===r.yaxis){a.opacity=void 0;break}}}}}},{}],1119:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"./constants\"),s=t(\"./subtypes\"),l=t(\"./xy_defaults\"),c=t(\"./stack_defaults\"),u=t(\"./marker_defaults\"),h=t(\"./line_defaults\"),f=t(\"./line_shape_defaults\"),p=t(\"./text_defaults\"),d=t(\"./fillcolor_defaults\");e.exports=function(t,e,r,g){function v(r,i){return n.coerce(t,e,a,r,i)}var m=l(t,e,g,v);if(m||(e.visible=!1),e.visible){var y=c(t,e,g,v),x=!y&&m<o.PTS_LINESONLY?\"lines+markers\":\"lines\";v(\"text\"),v(\"hovertext\"),v(\"mode\",x),s.hasLines(e)&&(h(t,e,r,g,v),f(t,e,v),v(\"connectgaps\"),v(\"line.simplify\")),s.hasMarkers(e)&&u(t,e,r,g,v,{gradient:!0}),s.hasText(e)&&p(t,e,g,v);var b=[];(s.hasMarkers(e)||s.hasText(e))&&(v(\"cliponaxis\"),v(\"marker.maxdisplayed\"),b.push(\"points\")),v(\"fill\",y?y.fillDflt:\"none\"),\"none\"!==e.fill&&(d(t,e,r,v),s.hasLines(e)||f(t,e,v));var _=(e.line||{}).color,w=(e.marker||{}).color;\"tonext\"!==e.fill&&\"toself\"!==e.fill||b.push(\"fills\"),v(\"hoveron\",b.join(\"+\")||\"points\"),\"fills\"!==e.hoveron&&v(\"hovertemplate\");var k=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");k(t,e,_||w||r,{axis:\"y\"}),k(t,e,_||w||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,v)}}},{\"../../lib\":719,\"../../registry\":847,\"./attributes\":1112,\"./constants\":1116,\"./fillcolor_defaults\":1120,\"./line_defaults\":1124,\"./line_shape_defaults\":1126,\"./marker_defaults\":1130,\"./stack_defaults\":1133,\"./subtypes\":1135,\"./text_defaults\":1136,\"./xy_defaults\":1137}],1120:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a){var o=!1;if(e.marker){var s=e.marker.color,l=(e.marker.line||{}).color;s&&!i(s)?o=s:l&&!i(l)&&(o=l)}a(\"fillcolor\",n.addOpacity((e.line||{}).color||o||r,.5))}},{\"../../components/color\":593,\"../../lib\":719}],1121:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./subtypes\");e.exports=function(t,e){var r,a;if(\"lines\"===t.mode)return(r=t.line.color)&&n.opacity(r)?r:t.fillcolor;if(\"none\"===t.mode)return t.fill?t.fillcolor:\"\";var o=e.mcc||(t.marker||{}).color,s=e.mlcc||((t.marker||{}).line||{}).color;return(a=o&&n.opacity(o)?o:s&&n.opacity(s)&&(e.mlw||((t.marker||{}).line||{}).width)?s:\"\")?n.opacity(a)<.3?n.addOpacity(a,.3):a:(r=(t.line||{}).color)&&n.opacity(r)&&i.hasLines(t)&&t.line.width?r:t.fillcolor}},{\"../../components/color\":593,\"./subtypes\":1135}],1122:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/fx\"),a=t(\"../../registry\"),o=t(\"./get_trace_color\"),s=t(\"../../components/color\"),l=n.fillText;e.exports=function(t,e,r,c){var u=t.cd,h=u[0].trace,f=t.xa,p=t.ya,d=f.c2p(e),g=p.c2p(r),v=[d,g],m=h.hoveron||\"\",y=-1!==h.mode.indexOf(\"markers\")?3:.5;if(-1!==m.indexOf(\"points\")){var x=function(t){var e=Math.max(y,t.mrc||0),r=f.c2p(t.x)-d,n=p.c2p(t.y)-g;return Math.max(Math.sqrt(r*r+n*n)-e,1-y/e)},b=i.getDistanceFunction(c,function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(f.c2p(t.x)-d);return n<e?r*n/e:n-e+r},function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(p.c2p(t.y)-g);return n<e?r*n/e:n-e+r},x);if(i.getClosest(u,b,t),!1!==t.index){var _=u[t.index],w=f.c2p(_.x,!0),k=p.c2p(_.y,!0),T=_.mrc||1;t.index=_.i;var A=u[0].t.orientation,M=A&&(_.sNorm||_.s),S=\"h\"===A?M:_.x,E=\"v\"===A?M:_.y;return n.extendFlat(t,{color:o(h,_),x0:w-T,x1:w+T,xLabelVal:S,y0:k-T,y1:k+T,yLabelVal:E,spikeDistance:x(_),hovertemplate:h.hovertemplate}),l(_,h,t),a.getComponentMethod(\"errorbars\",\"hoverInfo\")(_,h,t),[t]}}if(-1!==m.indexOf(\"fills\")&&h._polygons){var C,L,P,O,z,I,D,R,F,B=h._polygons,N=[],j=!1,U=1/0,V=-1/0,q=1/0,H=-1/0;for(C=0;C<B.length;C++)(P=B[C]).contains(v)&&(j=!j,N.push(P),q=Math.min(q,P.ymin),H=Math.max(H,P.ymax));if(j){var G=((q=Math.max(q,0))+(H=Math.min(H,p._length)))/2;for(C=0;C<N.length;C++)for(O=N[C].pts,L=1;L<O.length;L++)(R=O[L-1][1])>G!=(F=O[L][1])>=G&&(I=O[L-1][0],D=O[L][0],F-R&&(z=I+(D-I)*(G-R)/(F-R),U=Math.min(U,z),V=Math.max(V,z)));U=Math.max(U,0),V=Math.min(V,f._length);var Y=s.defaultLine;return s.opacity(h.fillcolor)?Y=h.fillcolor:s.opacity((h.line||{}).color)&&(Y=h.line.color),n.extendFlat(t,{distance:t.maxHoverDistance,x0:U,x1:V,y0:G,y1:G,color:Y,hovertemplate:!1}),delete t.index,h.text&&!Array.isArray(h.text)?t.text=String(h.text):t.text=h.name,[t]}}}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"../../registry\":847,\"./get_trace_color\":1121}],1123:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports={hasLines:n.hasLines,hasMarkers:n.hasMarkers,hasText:n.hasText,isBubble:n.isBubble,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./cross_trace_calc\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\"),colorbar:t(\"./marker_colorbar\"),style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"./select\"),animatable:!0,moduleType:\"trace\",name:\"scatter\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"./arrays_to_calcdata\":1111,\"./attributes\":1112,\"./calc\":1113,\"./cross_trace_calc\":1117,\"./cross_trace_defaults\":1118,\"./defaults\":1119,\"./hover\":1122,\"./marker_colorbar\":1129,\"./plot\":1131,\"./select\":1132,\"./style\":1134,\"./subtypes\":1135}],1124:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s,l){var c=(t.marker||{}).color;(s(\"line.color\",r),i(t,\"line\"))?a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}):s(\"line.color\",!n(c)&&c||r);s(\"line.width\"),(l||{}).noDash||s(\"line.dash\")}},{\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"../../lib\":719}],1125:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.BADNUM,a=n.LOG_CLIP,o=a+.5,s=a-.5,l=t(\"../../lib\"),c=l.segmentsIntersect,u=l.constrain,h=t(\"./constants\");e.exports=function(t,e){var r,n,a,f,p,d,g,v,m,y,x,b,_,w,k,T,A,M,S=e.xaxis,E=e.yaxis,C=\"log\"===S.type,L=\"log\"===E.type,P=S._length,O=E._length,z=e.connectGaps,I=e.baseTolerance,D=e.shape,R=\"linear\"===D,F=e.fill&&\"none\"!==e.fill,B=[],N=h.minTolerance,j=t.length,U=new Array(j),V=0;function q(e){var r=t[e];if(!r)return!1;var n=S.c2p(r.x),a=E.c2p(r.y);if(n===i){if(C&&(n=S.c2p(r.x,!0)),n===i)return!1;L&&a===i&&(n*=Math.abs(S._m*O*(S._m>0?o:s)/(E._m*P*(E._m>0?o:s)))),n*=1e3}if(a===i){if(L&&(a=E.c2p(r.y,!0)),a===i)return!1;a*=1e3}return[n,a]}function H(t,e,r,n){var i=r-t,a=n-e,o=.5-t,s=.5-e,l=i*i+a*a,c=i*o+a*s;if(c>0&&c<l){var u=o*a-s*i;if(u*u<l)return!0}}function G(t,e){var r=t[0]/P,n=t[1]/O,i=Math.max(0,-r,r-1,-n,n-1);return i&&void 0!==A&&H(r,n,A,M)&&(i=0),i&&e&&H(r,n,e[0]/P,e[1]/O)&&(i=0),(1+h.toleranceGrowth*i)*I}function Y(t,e){var r=t[0]-e[0],n=t[1]-e[1];return Math.sqrt(r*r+n*n)}var W,X,Z,J,K,$,Q,tt=h.maxScreensAway,et=-P*tt,rt=P*(1+tt),nt=-O*tt,it=O*(1+tt),at=[[et,nt,rt,nt],[rt,nt,rt,it],[rt,it,et,it],[et,it,et,nt]];function ot(t){if(t[0]<et||t[0]>rt||t[1]<nt||t[1]>it)return[u(t[0],et,rt),u(t[1],nt,it)]}function st(t,e){return t[0]===e[0]&&(t[0]===et||t[0]===rt)||(t[1]===e[1]&&(t[1]===nt||t[1]===it)||void 0)}function lt(t,e,r){return function(n,i){var a=ot(n),o=ot(i),s=[];if(a&&o&&st(a,o))return s;a&&s.push(a),o&&s.push(o);var c=2*l.constrain((n[t]+i[t])/2,e,r)-((a||n)[t]+(o||i)[t]);c&&((a&&o?c>0==a[t]>o[t]?a:o:a||o)[t]+=c);return s}}function ct(t){var e=t[0],r=t[1],n=e===U[V-1][0],i=r===U[V-1][1];if(!n||!i)if(V>1){var a=e===U[V-2][0],o=r===U[V-2][1];n&&(e===et||e===rt)&&a?o?V--:U[V-1]=t:i&&(r===nt||r===it)&&o?a?V--:U[V-1]=t:U[V++]=t}else U[V++]=t}function ut(t){U[V-1][0]!==t[0]&&U[V-1][1]!==t[1]&&ct([Z,J]),ct(t),K=null,Z=J=0}function ht(t){if(A=t[0]/P,M=t[1]/O,W=t[0]<et?et:t[0]>rt?rt:0,X=t[1]<nt?nt:t[1]>it?it:0,W||X){if(V)if(K){var e=Q(K,t);e.length>1&&(ut(e[0]),U[V++]=e[1])}else $=Q(U[V-1],t)[0],U[V++]=$;else U[V++]=[W||t[0],X||t[1]];var r=U[V-1];W&&X&&(r[0]!==W||r[1]!==X)?(K&&(Z!==W&&J!==X?ct(Z&&J?(n=K,a=(i=t)[0]-n[0],o=(i[1]-n[1])/a,(n[1]*i[0]-i[1]*n[0])/a>0?[o>0?et:rt,it]:[o>0?rt:et,nt]):[Z||W,J||X]):Z&&J&&ct([Z,J])),ct([W,X])):Z-W&&J-X&&ct([W||Z,X||J]),K=t,Z=W,J=X}else K&&ut(Q(K,t)[0]),U[V++]=t;var n,i,a,o}for(\"linear\"===D||\"spline\"===D?Q=function(t,e){for(var r=[],n=0,i=0;i<4;i++){var a=at[i],o=c(t[0],t[1],e[0],e[1],a[0],a[1],a[2],a[3]);o&&(!n||Math.abs(o.x-r[0][0])>1||Math.abs(o.y-r[0][1])>1)&&(o=[o.x,o.y],n&&Y(o,t)<Y(r[0],t)?r.unshift(o):r.push(o),n++)}return r}:\"hv\"===D||\"vh\"===D?Q=function(t,e){var r=[],n=ot(t),i=ot(e);return n&&i&&st(n,i)?r:(n&&r.push(n),i&&r.push(i),r)}:\"hvh\"===D?Q=lt(0,et,rt):\"vhv\"===D&&(Q=lt(1,nt,it)),r=0;r<j;r++)if(n=q(r)){for(V=0,K=null,ht(n),r++;r<j;r++){if(!(f=q(r))){if(z)continue;break}if(R&&e.simplify){var ft=q(r+1);if(y=Y(f,n),F&&(0===V||V===j-1)||!(y<G(f,ft)*N)){for(v=[(f[0]-n[0])/y,(f[1]-n[1])/y],p=n,x=y,b=w=k=0,g=!1,a=f,r++;r<t.length;r++){if(d=ft,ft=q(r+1),!d){if(z)continue;break}if(T=(m=[d[0]-n[0],d[1]-n[1]])[0]*v[1]-m[1]*v[0],w=Math.min(w,T),(k=Math.max(k,T))-w>G(d,ft))break;a=d,(_=m[0]*v[0]+m[1]*v[1])>x?(x=_,f=d,g=!1):_<b&&(b=_,p=d,g=!0)}if(g?(ht(f),a!==p&&ht(p)):(p!==n&&ht(p),a!==f&&ht(f)),ht(a),r>=t.length||!d)break;ht(d),n=d}}else ht(f)}K&&ct([Z||K[0],J||K[1]]),B.push(U.slice(0,V))}return B}},{\"../../constants/numerical\":695,\"../../lib\":719,\"./constants\":1116}],1126:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){\"spline\"===r(\"line.shape\")&&r(\"line.smoothing\")}},{}],1127:[function(t,e,r){\"use strict\";var n={tonextx:1,tonexty:1,tonext:1};e.exports=function(t,e,r){var i,a,o,s,l,c={},u=!1,h=-1,f=0,p=-1;for(a=0;a<r.length;a++)(o=(i=r[a][0].trace).stackgroup||\"\")?o in c?l=c[o]:(l=c[o]=f,f++):i.fill in n&&p>=0?l=p:(l=p=f,f++),l<h&&(u=!0),i._groupIndex=h=l;var d=r.slice();u&&d.sort(function(t,e){var r=t[0].trace,n=e[0].trace;return r._groupIndex-n._groupIndex||r.index-n.index});var g={};for(a=0;a<d.length;a++)o=(i=d[a][0].trace).stackgroup||\"\",!0===i.visible?(i._nexttrace=null,i.fill in n&&(s=g[o],i._prevtrace=s||null,s&&(s._nexttrace=i)),i._ownfill=i.fill&&(\"tozero\"===i.fill.substr(0,6)||\"toself\"===i.fill||\"to\"===i.fill.substr(0,2)&&!i._prevtrace),g[o]=i):i._prevtrace=i._nexttrace=i._ownfill=null;return d}},{}],1128:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t){var e=t.marker,r=e.sizeref||1,i=e.sizemin||0,a=\"area\"===e.sizemode?function(t){return Math.sqrt(t/r)}:function(t){return t/r};return function(t){var e=a(t/2);return n(e)&&e>0?Math.max(e,i):0}}},{\"fast-isnumeric\":225}],1129:[function(t,e,r){\"use strict\";e.exports={container:\"marker\",min:\"cmin\",max:\"cmax\"}},{}],1130:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"./subtypes\");e.exports=function(t,e,r,s,l,c){var u=o.isBubble(t),h=(t.line||{}).color;(c=c||{},h&&(r=h),l(\"marker.symbol\"),l(\"marker.opacity\",u?.7:1),l(\"marker.size\"),l(\"marker.color\",r),i(t,\"marker\")&&a(t,e,s,l,{prefix:\"marker.\",cLetter:\"c\"}),c.noSelect||(l(\"selected.marker.color\"),l(\"unselected.marker.color\"),l(\"selected.marker.size\"),l(\"unselected.marker.size\")),c.noLine||(l(\"marker.line.color\",h&&!Array.isArray(h)&&e.marker.color!==h?h:u?n.background:n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,l,{prefix:\"marker.line.\",cLetter:\"c\"}),l(\"marker.line.width\",u?1:0)),u&&(l(\"marker.sizeref\"),l(\"marker.sizemin\"),l(\"marker.sizemode\")),c.gradient)&&(\"none\"!==l(\"marker.gradient.type\")&&l(\"marker.gradient.color\"))}},{\"../../components/color\":593,\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"./subtypes\":1135}],1131:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=a.ensureSingle,s=a.identity,l=t(\"../../components/drawing\"),c=t(\"./subtypes\"),u=t(\"./line_points\"),h=t(\"./link_traces\"),f=t(\"../../lib/polygon\").tester;function p(t,e,r,h,p,d,g){var v;!function(t,e,r,i,o){var s=r.xaxis,l=r.yaxis,u=n.extent(a.simpleMap(s.range,s.r2c)),h=n.extent(a.simpleMap(l.range,l.r2c)),f=i[0].trace;if(!c.hasMarkers(f))return;var p=f.marker.maxdisplayed;if(0===p)return;var d=i.filter(function(t){return t.x>=u[0]&&t.x<=u[1]&&t.y>=h[0]&&t.y<=h[1]}),g=Math.ceil(d.length/p),v=0;o.forEach(function(t,r){var n=t[0].trace;c.hasMarkers(n)&&n.marker.maxdisplayed>0&&r<e&&v++});var m=Math.round(v*g/3+Math.floor(v/3)*g/7.1);i.forEach(function(t){delete t.vis}),d.forEach(function(t,e){0===Math.round((e+m)%g)&&(t.vis=!0)})}(0,e,r,h,p);var m=!!g&&g.duration>0;function y(t){return m?t.transition():t}var x=r.xaxis,b=r.yaxis,_=h[0].trace,w=_.line,k=n.select(d),T=o(k,\"g\",\"errorbars\"),A=o(k,\"g\",\"lines\"),M=o(k,\"g\",\"points\"),S=o(k,\"g\",\"text\");if(i.getComponentMethod(\"errorbars\",\"plot\")(t,T,r,g),!0===_.visible){var E,C;y(k).style(\"opacity\",_.opacity);var L=_.fill.charAt(_.fill.length-1);\"x\"!==L&&\"y\"!==L&&(L=\"\"),h[0][r.isRangePlot?\"nodeRangePlot3\":\"node3\"]=k;var P,O,z=\"\",I=[],D=_._prevtrace;D&&(z=D._prevRevpath||\"\",C=D._nextFill,I=D._polygons);var R,F,B,N,j,U,V,q=\"\",H=\"\",G=[],Y=a.noop;if(E=_._ownFill,c.hasLines(_)||\"none\"!==_.fill){for(C&&C.datum(h),-1!==[\"hv\",\"vh\",\"hvh\",\"vhv\"].indexOf(w.shape)?(R=l.steps(w.shape),F=l.steps(w.shape.split(\"\").reverse().join(\"\"))):R=F=\"spline\"===w.shape?function(t){var e=t[t.length-1];return t.length>1&&t[0][0]===e[0]&&t[0][1]===e[1]?l.smoothclosed(t.slice(1),w.smoothing):l.smoothopen(t,w.smoothing)}:function(t){return\"M\"+t.join(\"L\")},B=function(t){return F(t.reverse())},G=u(h,{xaxis:x,yaxis:b,connectGaps:_.connectgaps,baseTolerance:Math.max(w.width||1,3)/4,shape:w.shape,simplify:w.simplify,fill:_.fill}),V=_._polygons=new Array(G.length),v=0;v<G.length;v++)_._polygons[v]=f(G[v]);G.length&&(N=G[0][0],U=(j=G[G.length-1])[j.length-1]),Y=function(t){return function(e){if(P=R(e),O=B(e),q?L?(q+=\"L\"+P.substr(1),H=O+\"L\"+H.substr(1)):(q+=\"Z\"+P,H=O+\"Z\"+H):(q=P,H=O),c.hasLines(_)&&e.length>1){var r=n.select(this);if(r.datum(h),t)y(r.style(\"opacity\",0).attr(\"d\",P).call(l.lineGroupStyle)).style(\"opacity\",1);else{var i=y(r);i.attr(\"d\",P),l.singleLineStyle(h,i)}}}}}var W=A.selectAll(\".js-line\").data(G);y(W.exit()).style(\"opacity\",0).remove(),W.each(Y(!1)),W.enter().append(\"path\").classed(\"js-line\",!0).style(\"vector-effect\",\"non-scaling-stroke\").call(l.lineGroupStyle).each(Y(!0)),l.setClipUrl(W,r.layerClipId,t),G.length?(E?(E.datum(h),N&&U&&(L?(\"y\"===L?N[1]=U[1]=b.c2p(0,!0):\"x\"===L&&(N[0]=U[0]=x.c2p(0,!0)),y(E).attr(\"d\",\"M\"+U+\"L\"+N+\"L\"+q.substr(1)).call(l.singleFillStyle)):y(E).attr(\"d\",q+\"Z\").call(l.singleFillStyle))):C&&(\"tonext\"===_.fill.substr(0,6)&&q&&z?(\"tonext\"===_.fill?y(C).attr(\"d\",q+\"Z\"+z+\"Z\").call(l.singleFillStyle):y(C).attr(\"d\",q+\"L\"+z.substr(1)+\"Z\").call(l.singleFillStyle),_._polygons=_._polygons.concat(I)):(Z(C),_._polygons=null)),_._prevRevpath=H,_._prevPolygons=V):(E?Z(E):C&&Z(C),_._polygons=_._prevRevpath=_._prevPolygons=null),M.datum(h),S.datum(h),function(e,i,a){var o,u=a[0].trace,h=c.hasMarkers(u),f=c.hasText(u),p=tt(u),d=et,g=et;if(h||f){var v=s,_=u.stackgroup,w=_&&\"infer zero\"===t._fullLayout._scatterStackOpts[x._id+b._id][_].stackgaps;u.marker.maxdisplayed||u._needsCull?v=w?K:J:_&&!w&&(v=$),h&&(d=v),f&&(g=v)}var k,T=(o=e.selectAll(\"path.point\").data(d,p)).enter().append(\"path\").classed(\"point\",!0);m&&T.call(l.pointStyle,u,t).call(l.translatePoints,x,b).style(\"opacity\",0).transition().style(\"opacity\",1),o.order(),h&&(k=l.makePointStyleFns(u)),o.each(function(e){var i=n.select(this),a=y(i);l.translatePoint(e,a,x,b)?(l.singlePointStyle(e,a,u,k,t),r.layerClipId&&l.hideOutsideRangePoint(e,a,x,b,u.xcalendar,u.ycalendar),u.customdata&&i.classed(\"plotly-customdata\",null!==e.data&&void 0!==e.data)):a.remove()}),m?o.exit().transition().style(\"opacity\",0).remove():o.exit().remove(),(o=i.selectAll(\"g\").data(g,p)).enter().append(\"g\").classed(\"textpoint\",!0).append(\"text\"),o.order(),o.each(function(t){var e=n.select(this),i=y(e.select(\"text\"));l.translatePoint(t,i,x,b)?r.layerClipId&&l.hideOutsideRangePoint(t,e,x,b,u.xcalendar,u.ycalendar):e.remove()}),o.selectAll(\"text\").call(l.textPointStyle,u,t).each(function(t){var e=x.c2p(t.x),r=b.c2p(t.y);n.select(this).selectAll(\"tspan.line\").each(function(){y(n.select(this)).attr({x:e,y:r})})}),o.exit().remove()}(M,S,h);var X=!1===_.cliponaxis?null:r.layerClipId;l.setClipUrl(M,X,t),l.setClipUrl(S,X,t)}function Z(t){y(t).attr(\"d\",\"M0,0Z\")}function J(t){return t.filter(function(t){return!t.gap&&t.vis})}function K(t){return t.filter(function(t){return t.vis})}function $(t){return t.filter(function(t){return!t.gap})}function Q(t){return t.id}function tt(t){if(t.ids)return Q}function et(){return!1}}e.exports=function(t,e,r,i,a,c){var u,f,d=!a,g=!!a&&a.duration>0,v=h(t,e,r);((u=i.selectAll(\"g.trace\").data(v,function(t){return t[0].trace.uid})).enter().append(\"g\").attr(\"class\",function(t){return\"trace scatter trace\"+t[0].trace.uid}).style(\"stroke-miterlimit\",2),u.order(),function(t,e,r){e.each(function(e){var i=o(n.select(this),\"g\",\"fills\");l.setClipUrl(i,r.layerClipId,t);var a=e[0].trace,c=[];a._ownfill&&c.push(\"_ownFill\"),a._nexttrace&&c.push(\"_nextFill\");var u=i.selectAll(\"g\").data(c,s);u.enter().append(\"g\"),u.exit().each(function(t){a[t]=null}).remove(),u.order().each(function(t){a[t]=o(n.select(this),\"path\",\"js-fill\")})})}(t,u,e),g)?(c&&(f=c()),n.transition().duration(a.duration).ease(a.easing).each(\"end\",function(){f&&f()}).each(\"interrupt\",function(){f&&f()}).each(function(){i.selectAll(\"g.trace\").each(function(r,n){p(t,n,e,r,v,this,a)})})):u.each(function(r,n){p(t,n,e,r,v,this,a)});d&&u.exit().remove(),i.selectAll(\"path:not([d])\").remove()}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/polygon\":731,\"../../registry\":847,\"./line_points\":1125,\"./link_traces\":1127,\"./subtypes\":1135,d3:163}],1132:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports=function(t,e){var r,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[],h=s[0].trace;if(!n.hasMarkers(h)&&!n.hasText(h))return[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)i=s[r],a=l.c2p(i.x),o=c.c2p(i.y),null!==i.i&&e.contains([a,o],!1,r,t)?(u.push({pointNumber:i.i,x:l.c2d(i.x),y:c.c2d(i.y)}),i.selected=1):i.selected=0;return u}},{\"./subtypes\":1135}],1133:[function(t,e,r){\"use strict\";var n=[\"orientation\",\"groupnorm\",\"stackgaps\"];e.exports=function(t,e,r,i){var a=r._scatterStackOpts,o=i(\"stackgroup\");if(o){var s=e.xaxis+e.yaxis,l=a[s];l||(l=a[s]={});var c=l[o],u=!1;c?c.traces.push(e):(c=l[o]={traceIndices:[],traces:[e]},u=!0);for(var h={orientation:e.x&&!e.y?\"h\":\"v\"},f=0;f<n.length;f++){var p=n[f],d=p+\"Found\";if(!c[d]){var g=void 0!==t[p],v=\"orientation\"===p;if((g||u)&&(c[p]=i(p,h[p]),v&&(c.fillDflt=\"h\"===c[p]?\"tonextx\":\"tonexty\"),g&&(c[d]=!0,!u&&(delete c.traces[0][p],v))))for(var m=0;m<c.traces.length-1;m++){var y=c.traces[m];y._input.fill!==y.fill&&(y.fill=c.fillDflt)}}}return c}}},{}],1134:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../registry\");function o(t,e,r){i.pointStyle(t.selectAll(\"path.point\"),e,r)}function s(t,e,r){i.textPointStyle(t.selectAll(\"text\"),e,r)}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.trace.scatter\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.selectAll(\"g.points\").each(function(e){o(n.select(this),e.trace||e[0].trace,t)}),e.selectAll(\"g.text\").each(function(e){s(n.select(this),e.trace||e[0].trace,t)}),e.selectAll(\"g.trace path.js-line\").call(i.lineGroupStyle),e.selectAll(\"g.trace path.js-fill\").call(i.fillGroupStyle),a.getComponentMethod(\"errorbars\",\"style\")(e)},stylePoints:o,styleText:s,styleOnSelect:function(t,e,r){var n=e[0].trace;n.selectedpoints?(i.selectedPointStyle(r.selectAll(\"path.point\"),n),i.selectedTextStyle(r.selectAll(\"text\"),n)):(o(r,n,t),s(r,n,t))}}},{\"../../components/drawing\":614,\"../../registry\":847,d3:163}],1135:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports={hasLines:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"lines\")},hasMarkers:function(t){return t.visible&&(t.mode&&-1!==t.mode.indexOf(\"markers\")||\"splom\"===t.type)},hasText:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"text\")},isBubble:function(t){return n.isPlainObject(t.marker)&&n.isArrayOrTypedArray(t.marker.size)}}},{\"../../lib\":719}],1136:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i,a){a=a||{},i(\"textposition\"),n.coerceFont(i,\"textfont\",r.font),a.noSelect||(i(\"selected.textfont.color\"),i(\"unselected.textfont.color\"))}},{\"../../lib\":719}],1137:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");e.exports=function(t,e,r,a){var o,s=a(\"x\"),l=a(\"y\");if(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],r),s){var c=n.minRowLength(s);l?o=Math.min(c,n.minRowLength(l)):(o=c,a(\"y0\"),a(\"dy\"))}else{if(!l)return 0;o=n.minRowLength(l),a(\"x0\"),a(\"dx\")}return e._length=o,o}},{\"../../lib\":719,\"../../registry\":847}],1138:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../constants/gl3d_dashes\"),l=t(\"../../constants/gl3d_markers\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../plot_api/edit_types\").overrideAll,h=n.line,f=n.marker,p=f.line,d=c({width:h.width,dash:{valType:\"enumerated\",values:Object.keys(s),dflt:\"solid\"}},i(\"line\"));var g=e.exports=u({x:n.x,y:n.y,z:{valType:\"data_array\"},text:c({},n.text,{}),hovertext:c({},n.hovertext,{}),hovertemplate:a(),mode:c({},n.mode,{dflt:\"lines+markers\"}),surfaceaxis:{valType:\"enumerated\",values:[-1,0,1,2],dflt:-1},surfacecolor:{valType:\"color\"},projection:{x:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},y:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},z:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}}},connectgaps:n.connectgaps,line:d,marker:c({symbol:{valType:\"enumerated\",values:Object.keys(l),dflt:\"circle\",arrayOk:!0},size:c({},f.size,{dflt:8}),sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode,opacity:c({},f.opacity,{arrayOk:!1}),colorbar:f.colorbar,line:c({width:c({},p.width,{arrayOk:!1})},i(\"marker.line\"))},i(\"marker\")),textposition:c({},n.textposition,{dflt:\"top center\"}),textfont:{color:n.textfont.color,size:n.textfont.size,family:c({},n.textfont.family,{arrayOk:!1})},hoverinfo:c({},o.hoverinfo)},\"calc\",\"nested\");g.x.editType=g.y.editType=g.z.editType=\"calc+clearAxisTypes\"},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../constants/gl3d_dashes\":692,\"../../constants/gl3d_markers\":693,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1139:[function(t,e,r){\"use strict\";var n=t(\"../scatter/arrays_to_calcdata\"),i=t(\"../scatter/colorscale_calc\");e.exports=function(t,e){var r=[{x:!1,y:!1,trace:e,t:{}}];return n(r,e),i(t,e),r}},{\"../scatter/arrays_to_calcdata\":1111,\"../scatter/colorscale_calc\":1115}],1140:[function(t,e,r){\"use strict\";var n=t(\"../../registry\");function i(t,e,r,i){if(!e||!e.visible)return null;for(var a=n.getComponentMethod(\"errorbars\",\"makeComputeError\")(e),o=new Array(t.length),s=0;s<t.length;s++){var l=a(+t[s],s);if(\"log\"===i.type){var c=i.c2l(t[s]),u=t[s]-l[0],h=t[s]+l[1];if(o[s]=[(i.c2l(u,!0)-c)*r,(i.c2l(h,!0)-c)*r],u>0){var f=i.c2l(u);i._lowerLogErrorBound||(i._lowerLogErrorBound=f),i._lowerErrorBound=Math.min(i._lowerLogErrorBound,f)}}else o[s]=[-l[0]*r,l[1]*r]}return o}e.exports=function(t,e,r){var n=[i(t.x,t.error_x,e[0],r.xaxis),i(t.y,t.error_y,e[1],r.yaxis),i(t.z,t.error_z,e[2],r.zaxis)],a=function(t){for(var e=0;e<t.length;e++)if(t[e])return t[e].length;return 0}(n);if(0===a)return null;for(var o=new Array(a),s=0;s<a;s++){for(var l=[[0,0,0],[0,0,0]],c=0;c<3;c++)if(n[c])for(var u=0;u<2;u++)l[u][c]=n[c][s][u];o[s]=l}return o}},{\"../../registry\":847}],1141:[function(t,e,r){\"use strict\";var n=t(\"gl-line3d\"),i=t(\"gl-scatter3d\"),a=t(\"gl-error3d\"),o=t(\"gl-mesh3d\"),s=t(\"delaunay-triangulate\"),l=t(\"../../lib\"),c=t(\"../../lib/str2rgbarray\"),u=t(\"../../lib/gl_format_color\").formatColor,h=t(\"../scatter/make_bubble_size_func\"),f=t(\"../../constants/gl3d_dashes\"),p=t(\"../../constants/gl3d_markers\"),d=t(\"./calc_errors\");function g(t,e){this.scene=t,this.uid=e,this.linePlot=null,this.scatterPlot=null,this.errorBars=null,this.textMarkers=null,this.delaunayMesh=null,this.color=null,this.mode=\"\",this.dataPoints=[],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.textLabels=null,this.data=null}var v=g.prototype;function m(t){return null==t?0:t.indexOf(\"left\")>-1?-1:t.indexOf(\"right\")>-1?1:0}function y(t){return null==t?0:t.indexOf(\"top\")>-1?-1:t.indexOf(\"bottom\")>-1?1:0}function x(t,e){return e(4*t)}function b(t){return p[t]}function _(t,e,r,n,i){var a=null;if(l.isArrayOrTypedArray(t)){a=[];for(var o=0;o<e;o++)void 0===t[o]?a[o]=n:a[o]=r(t[o],i)}else a=r(t,l.identity);return a}function w(t,e){var r,n,i,a,o,s,f=[],p=t.fullSceneLayout,g=t.dataScale,v=p.xaxis,w=p.yaxis,k=p.zaxis,T=e.marker,A=e.line,M=e.x||[],S=e.y||[],E=e.z||[],C=M.length,L=e.xcalendar,P=e.ycalendar,O=e.zcalendar;for(o=0;o<C;o++)r=v.d2l(M[o],0,L)*g[0],n=w.d2l(S[o],0,P)*g[1],i=k.d2l(E[o],0,O)*g[2],f[o]=[r,n,i];if(Array.isArray(e.text))s=e.text;else if(void 0!==e.text)for(s=new Array(C),o=0;o<C;o++)s[o]=e.text;if(a={position:f,mode:e.mode,text:s},\"line\"in e&&(a.lineColor=u(A,1,C),a.lineWidth=A.width,a.lineDashes=A.dash),\"marker\"in e){var z=h(e);a.scatterColor=u(T,1,C),a.scatterSize=_(T.size,C,x,20,z),a.scatterMarker=_(T.symbol,C,b,\"\\u25cf\"),a.scatterLineWidth=T.line.width,a.scatterLineColor=u(T.line,1,C),a.scatterAngle=0}\"textposition\"in e&&(a.textOffset=function(t){var e=[0,0];if(Array.isArray(t))for(var r=0;r<t.length;r++)e[r]=[0,0],t[r]&&(e[r][0]=m(t[r]),e[r][1]=y(t[r]));else e[0]=m(t),e[1]=y(t);return e}(e.textposition),a.textColor=u(e.textfont,1,C),a.textSize=_(e.textfont.size,C,l.identity,12),a.textFont=e.textfont.family,a.textAngle=0);var I=[\"x\",\"y\",\"z\"];for(a.project=[!1,!1,!1],a.projectScale=[1,1,1],a.projectOpacity=[1,1,1],o=0;o<3;++o){var D=e.projection[I[o]];(a.project[o]=D.show)&&(a.projectOpacity[o]=D.opacity,a.projectScale[o]=D.scale)}a.errorBounds=d(e,g,p);var R=function(t){for(var e=[0,0,0],r=[[0,0,0],[0,0,0],[0,0,0]],n=[1,1,1],i=0;i<3;i++){var a=t[i];a&&!1!==a.copy_zstyle&&!1!==t[2].visible&&(a=t[2]),a&&a.visible&&(e[i]=a.width/2,r[i]=c(a.color),n[i]=a.thickness)}return{capSize:e,color:r,lineWidth:n}}([e.error_x,e.error_y,e.error_z]);return a.errorColor=R.color,a.errorLineWidth=R.lineWidth,a.errorCapSize=R.capSize,a.delaunayAxis=e.surfaceaxis,a.delaunayColor=c(e.surfacecolor),a}function k(t){if(Array.isArray(t)){var e=t[0];return Array.isArray(e)&&(t=e),\"rgb(\"+t.slice(0,3).map(function(t){return Math.round(255*t)})+\")\"}return null}v.handlePick=function(t){if(t.object&&(t.object===this.linePlot||t.object===this.delaunayMesh||t.object===this.textMarkers||t.object===this.scatterPlot)){var e=t.index=t.data.index;return t.object.highlight&&t.object.highlight(null),this.scatterPlot&&(t.object=this.scatterPlot,this.scatterPlot.highlight(t.data)),t.textLabel=\"\",this.textLabels&&(Array.isArray(this.textLabels)?(this.textLabels[e]||0===this.textLabels[e])&&(t.textLabel=this.textLabels[e]):t.textLabel=this.textLabels),t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]],!0}},v.update=function(t){var e,r,l,c,u=this.scene.glplot.gl,h=f.solid;this.data=t;var p=w(this.scene,t);\"mode\"in p&&(this.mode=p.mode),\"lineDashes\"in p&&p.lineDashes in f&&(h=f[p.lineDashes]),this.color=k(p.scatterColor)||k(p.lineColor),this.dataPoints=p.position,e={gl:this.scene.glplot.gl,position:p.position,color:p.lineColor,lineWidth:p.lineWidth||1,dashes:h[0],dashScale:h[1],opacity:t.opacity,connectGaps:t.connectgaps},-1!==this.mode.indexOf(\"lines\")?this.linePlot?this.linePlot.update(e):(this.linePlot=n(e),this.linePlot._trace=this,this.scene.glplot.add(this.linePlot)):this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose(),this.linePlot=null);var d=t.opacity;if(t.marker&&t.marker.opacity&&(d*=t.marker.opacity),r={gl:this.scene.glplot.gl,position:p.position,color:p.scatterColor,size:p.scatterSize,glyph:p.scatterMarker,opacity:d,orthographic:!0,lineWidth:p.scatterLineWidth,lineColor:p.scatterLineColor,project:p.project,projectScale:p.projectScale,projectOpacity:p.projectOpacity},-1!==this.mode.indexOf(\"markers\")?this.scatterPlot?this.scatterPlot.update(r):(this.scatterPlot=i(r),this.scatterPlot._trace=this,this.scatterPlot.highlightScale=1,this.scene.glplot.add(this.scatterPlot)):this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose(),this.scatterPlot=null),c={gl:this.scene.glplot.gl,position:p.position,glyph:p.text,color:p.textColor,size:p.textSize,angle:p.textAngle,alignment:p.textOffset,font:p.textFont,orthographic:!0,lineWidth:0,project:!1,opacity:t.opacity},this.textLabels=t.hovertext||t.text,-1!==this.mode.indexOf(\"text\")?this.textMarkers?this.textMarkers.update(c):(this.textMarkers=i(c),this.textMarkers._trace=this,this.textMarkers.highlightScale=1,this.scene.glplot.add(this.textMarkers)):this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose(),this.textMarkers=null),l={gl:this.scene.glplot.gl,position:p.position,color:p.errorColor,error:p.errorBounds,lineWidth:p.errorLineWidth,capSize:p.errorCapSize,opacity:t.opacity},this.errorBars?p.errorBounds?this.errorBars.update(l):(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose(),this.errorBars=null):p.errorBounds&&(this.errorBars=a(l),this.errorBars._trace=this,this.scene.glplot.add(this.errorBars)),p.delaunayAxis>=0){var g=function(t,e,r){var n,i=(r+1)%3,a=(r+2)%3,o=[],l=[];for(n=0;n<t.length;++n){var c=t[n];!isNaN(c[i])&&isFinite(c[i])&&!isNaN(c[a])&&isFinite(c[a])&&(o.push([c[i],c[a]]),l.push(n))}var u=s(o);for(n=0;n<u.length;++n)for(var h=u[n],f=0;f<h.length;++f)h[f]=l[h[f]];return{positions:t,cells:u,meshColor:e}}(p.position,p.delaunayColor,p.delaunayAxis);g.opacity=t.opacity,this.delaunayMesh?this.delaunayMesh.update(g):(g.gl=u,this.delaunayMesh=o(g),this.delaunayMesh._trace=this,this.scene.glplot.add(this.delaunayMesh))}else this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose(),this.delaunayMesh=null)},v.dispose=function(){this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose()),this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose()),this.errorBars&&(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose()),this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose()),this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose())},e.exports=function(t,e){var r=new g(t,e.uid);return r.update(e),r}},{\"../../constants/gl3d_dashes\":692,\"../../constants/gl3d_markers\":693,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../scatter/make_bubble_size_func\":1128,\"./calc_errors\":1140,\"delaunay-triangulate\":165,\"gl-error3d\":247,\"gl-line3d\":255,\"gl-mesh3d\":280,\"gl-scatter3d\":297}],1142:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,n){return i.coerce(t,e,c,r,n)}if(function(t,e,r,i){var a=0,o=r(\"x\"),s=r(\"y\"),l=r(\"z\");n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],i),o&&s&&l&&(a=Math.min(o.length,s.length,l.length),e._length=e._xlength=e._ylength=e._zlength=a);return a}(t,e,h,u)){h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),a.hasLines(e)&&(h(\"connectgaps\"),s(t,e,r,u,h)),a.hasMarkers(e)&&o(t,e,r,u,h,{noSelect:!0}),a.hasText(e)&&l(t,e,u,h,{noSelect:!0});var f=(e.line||{}).color,p=(e.marker||{}).color;h(\"surfaceaxis\")>=0&&h(\"surfacecolor\",f||p);for(var d=[\"x\",\"y\",\"z\"],g=0;g<3;++g){var v=\"projection.\"+d[g];h(v+\".show\")&&(h(v+\".opacity\"),h(v+\".scale\"))}var m=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");m(t,e,f||p||r,{axis:\"z\"}),m(t,e,f||p||r,{axis:\"y\",inherit:\"z\"}),m(t,e,f||p||r,{axis:\"x\",inherit:\"z\"})}else e.visible=!1}},{\"../../lib\":719,\"../../registry\":847,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1138}],1143:[function(t,e,r){\"use strict\";e.exports={plot:t(\"./convert\"),attributes:t(\"./attributes\"),markerSymbols:t(\"../../constants/gl3d_markers\"),supplyDefaults:t(\"./defaults\"),colorbar:[{container:\"marker\",min:\"cmin\",max:\"cmax\"},{container:\"line\",min:\"cmin\",max:\"cmax\"}],calc:t(\"./calc\"),moduleType:\"trace\",name:\"scatter3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"symbols\",\"showLegend\"],meta:{}}},{\"../../constants/gl3d_markers\":693,\"../../plots/gl3d\":807,\"./attributes\":1138,\"./calc\":1139,\"./convert\":1141,\"./defaults\":1142}],1144:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=n.marker,c=n.line,u=l.line;e.exports={carpet:{valType:\"string\",editType:\"calc\"},a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},mode:s({},n.mode,{dflt:\"markers\"}),text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),line:{color:c.color,width:c.width,dash:c.dash,shape:s({},c.shape,{values:[\"linear\",\"spline\"]}),smoothing:c.smoothing,editType:\"calc\"},connectgaps:n.connectgaps,fill:s({},n.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:n.fillcolor,marker:s({symbol:l.symbol,opacity:l.opacity,maxdisplayed:l.maxdisplayed,size:l.size,sizeref:l.sizeref,sizemin:l.sizemin,sizemode:l.sizemode,line:s({width:u.width,editType:\"calc\"},o(\"marker.line\")),gradient:l.gradient,editType:\"calc\"},o(\"marker\")),textfont:n.textfont,textposition:n.textposition,selected:n.selected,unselected:n.unselected,hoverinfo:s({},i.hoverinfo,{flags:[\"a\",\"b\",\"text\",\"name\"]}),hoveron:n.hoveron,hovertemplate:a()}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1145:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=t(\"../carpet/lookup_carpetid\");e.exports=function(t,e){var r=e._carpetTrace=l(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){var c;e.xaxis=r.xaxis,e.yaxis=r.yaxis;var u,h,f=e._length,p=new Array(f),d=!1;for(c=0;c<f;c++)if(u=e.a[c],h=e.b[c],n(u)&&n(h)){var g=r.ab2xy(+u,+h,!0),v=r.isVisible(+u,+h);v||(d=!0),p[c]={x:g[0],y:g[1],a:u,b:h,vis:v}}else p[c]={x:!1,y:!1};return e._needsCull=d,p[0].carpet=r,p[0].trace=e,s(e,f),i(t,e),a(p,e),o(p,e),p}}},{\"../carpet/lookup_carpetid\":915,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc\":1113,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1146:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}p(\"carpet\"),e.xaxis=\"x\",e.yaxis=\"y\";var d=p(\"a\"),g=p(\"b\"),v=Math.min(d.length,g.length);if(v){e._length=v,p(\"text\"),p(\"hovertext\"),p(\"mode\",v<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,f,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,f,p,{gradient:!0}),a.hasText(e)&&c(t,e,f,p);var m=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"marker.maxdisplayed\"),m.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||m.push(\"fills\"),\"fills\"!==p(\"hoveron\",m.join(\"+\")||\"points\")&&p(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/line_shape_defaults\":1126,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1144}],1147:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=n[i];return t.a=a.a,t.b=a.b,t.y=a.y,t}},{}],1148:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../lib\").fillText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,h=c-u;return s.x0=Math.max(Math.min(s.x0,h),u),s.x1=Math.max(Math.min(s.x1,h),u),o}var f=s.cd[s.index];s.a=f.a,s.b=f.b,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.trace,d=p._carpet,g=d.ab2ij([f.a,f.b]),v=Math.floor(g[0]),m=g[0]-v,y=Math.floor(g[1]),x=g[1]-y,b=d.evalxy([],v,y,m,x);s.yLabel=b[1].toFixed(3),delete s.text;var _=[];if(!p.hovertemplate){var w=(f.hi||p.hoverinfo).split(\"+\");-1!==w.indexOf(\"all\")&&(w=[\"a\",\"b\",\"text\"]),-1!==w.indexOf(\"a\")&&k(d.aaxis,f.a),-1!==w.indexOf(\"b\")&&k(d.baxis,f.b),_.push(\"y: \"+s.yLabel),-1!==w.indexOf(\"text\")&&i(f,p,_),s.extraText=_.join(\"<br>\")}return o}function k(t,e){var r;r=t.labelprefix&&t.labelprefix.length>0?t.labelprefix.replace(/ = $/,\"\"):t._hovertitle,_.push(r+\": \"+e.toFixed(3)+t.labelsuffix)}}},{\"../../lib\":719,\"../scatter/hover\":1122}],1149:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scattercarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"svg\",\"carpet\",\"symbols\",\"showLegend\",\"carpetDependent\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../scatter/marker_colorbar\":1129,\"../scatter/select\":1132,\"../scatter/style\":1134,\"./attributes\":1144,\"./calc\":1145,\"./defaults\":1146,\"./event_data\":1147,\"./hover\":1148,\"./plot\":1150}],1150:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../components/drawing\");e.exports=function(t,e,r,o){var s,l,c,u=r[0][0].carpet,h={xaxis:i.getFromId(t,u.xaxis||\"x\"),yaxis:i.getFromId(t,u.yaxis||\"y\"),plot:e.plot};for(n(t,h,r,o),s=0;s<r.length;s++)l=r[s][0].trace,c=o.selectAll(\"g.trace\"+l.uid+\" .js-line\"),a.setClipUrl(c,r[s][0].carpet._clipPathId,t)}},{\"../../components/drawing\":614,\"../../plots/cartesian/axes\":767,\"../scatter/plot\":1131}],1151:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/drawing/attributes\").dash,l=t(\"../../lib/extend\").extendFlat,c=t(\"../../plot_api/edit_types\").overrideAll,u=i.marker,h=i.line,f=u.line;e.exports=c({lon:{valType:\"data_array\"},lat:{valType:\"data_array\"},locations:{valType:\"data_array\"},locationmode:{valType:\"enumerated\",values:[\"ISO-3\",\"USA-states\",\"country names\"],dflt:\"ISO-3\"},mode:l({},i.mode,{dflt:\"markers\"}),text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),textfont:i.textfont,textposition:i.textposition,line:{color:h.color,width:h.width,dash:s},connectgaps:i.connectgaps,marker:l({symbol:u.symbol,opacity:u.opacity,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,colorbar:u.colorbar,line:l({width:f.width},o(\"marker.line\")),gradient:u.gradient},o(\"marker\")),fill:{valType:\"enumerated\",values:[\"none\",\"toself\"],dflt:\"none\"},fillcolor:i.fillcolor,selected:i.selected,unselected:i.unselected,hoverinfo:l({},a.hoverinfo,{flags:[\"lon\",\"lat\",\"location\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":600,\"../../components/drawing/attributes\":613,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1152:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../scatter/colorscale_calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\"),l=t(\"../../lib\")._;e.exports=function(t,e){for(var r=Array.isArray(e.locations),c=r?e.locations.length:e._length,u=new Array(c),h=0;h<c;h++){var f=u[h]={};if(r){var p=e.locations[h];f.loc=\"string\"==typeof p?p:null}else{var d=e.lon[h],g=e.lat[h];n(d)&&n(g)?f.lonlat=[+d,+g]:f.lonlat=[i,i]}}return o(u,e),a(t,e),s(u,e),c&&(u[0].t={labels:{lat:l(t,\"lat:\")+\" \",lon:l(t,\"lon:\")+\" \"}}),u}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1153:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,i){return n.coerce(t,e,c,r,i)}!function(t,e,r){var n,i,a=0,o=r(\"locations\");if(o)return r(\"locationmode\"),a=o.length;return n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length),e._length=a,a}(0,e,h)?e.visible=!1:(h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),i.hasLines(e)&&(o(t,e,r,u,h),h(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,u,h,{gradient:!0}),i.hasText(e)&&s(t,e,u,h),h(\"fill\"),\"none\"!==e.fill&&l(t,e,r,h),n.coerceSelectionMarkerOpacity(e,h))}},{\"../../lib\":719,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1151}],1154:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.location=e.loc?e.loc:null,t}},{}],1155:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../scatter/get_trace_color\"),s=t(\"../../lib\").fillText,l=t(\"./attributes\");e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,h=t.xa,f=t.ya,p=t.subplot,d=p.projection.isLonLatOverEdges,g=p.project;if(n.getClosest(c,function(t){var n=t.lonlat;if(n[0]===a)return 1/0;if(d(n))return 1/0;var i=g(n),o=g([e,r]),s=Math.abs(i[0]-o[0]),l=Math.abs(i[1]-o[1]),c=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(s*s+l*l)-c,1-3/c)},t),!1!==t.index){var v=c[t.index],m=v.lonlat,y=[h.c2p(m),f.c2p(m)],x=v.mrc||1;t.x0=y[0]-x,t.x1=y[0]+x,t.y0=y[1]-x,t.y1=y[1]+x,t.loc=v.loc,t.lon=m[0],t.lat=m[1];var b=p.mockAxis;return t.lonLabel=i.tickText(b,b.c2l(t.lon),\"hover\").text,t.latLabel=i.tickText(b,b.c2l(t.lat),\"hover\").text,t.color=o(u,v),t.extraText=function(t,e,r,n){if(t.hovertemplate)return;var i=e.hi||t.hoverinfo,a=\"all\"===i?l.hoverinfo.flags:i.split(\"+\"),o=-1!==a.indexOf(\"location\")&&Array.isArray(t.locations),c=-1!==a.indexOf(\"lon\"),u=-1!==a.indexOf(\"lat\"),h=-1!==a.indexOf(\"text\"),f=[];function p(t){return t+\"\\xb0\"}o?f.push(e.loc):c&&u?f.push(\"(\"+p(r.lonLabel)+\", \"+p(r.latLabel)+\")\"):c?f.push(n.lon+p(r.lonLabel)):u&&f.push(n.lat+p(r.latLabel));h&&s(e,t,f);return f.join(\"<br>\")}(u,v,t,c[0].t.labels),t.hovertemplate=u.hovertemplate,[t]}}},{\"../../components/fx\":632,\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scatter/get_trace_color\":1121,\"./attributes\":1151}],1156:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"scattergeo\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/geo\":797,\"../scatter/marker_colorbar\":1129,\"../scatter/style\":1134,\"./attributes\":1151,\"./calc\":1152,\"./defaults\":1153,\"./event_data\":1154,\"./hover\":1155,\"./plot\":1157,\"./select\":1158,\"./style\":1159}],1157:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../lib/topojson_utils\").getTopojsonFeatures,s=t(\"../../lib/geo_location_utils\").locationToFeature,l=t(\"../../lib/geojson_utils\"),c=t(\"../scatter/subtypes\"),u=t(\"./style\");function h(t,e){var r=t[0].trace;if(Array.isArray(r.locations))for(var n=o(r,e),i=r.locationmode,l=0;l<t.length;l++){var c=t[l],u=s(i,c.loc,n);c.lonlat=u?u.properties.ct:[a,a]}}e.exports=function(t,e,r){for(var o=0;o<r.length;o++)h(r[o],e.topojson);function s(t,e){t.lonlat[0]===a&&n.select(e).remove()}var f=e.layers.frontplot.select(\".scatterlayer\"),p=i.makeTraceGroups(f,r,\"trace scattergeo\");p.selectAll(\"*\").remove(),p.each(function(e){var r=n.select(this),a=e[0].trace;if(c.hasLines(a)||\"none\"!==a.fill){var o=l.calcTraceToLineCoords(e),h=\"none\"!==a.fill?l.makePolygon(o):l.makeLine(o);r.selectAll(\"path.js-line\").data([{geojson:h,trace:a}]).enter().append(\"path\").classed(\"js-line\",!0).style(\"stroke-miterlimit\",2)}c.hasMarkers(a)&&r.selectAll(\"path.point\").data(i.identity).enter().append(\"path\").classed(\"point\",!0).each(function(t){s(t,this)}),c.hasText(a)&&r.selectAll(\"g\").data(i.identity).enter().append(\"g\").append(\"text\").each(function(t){s(t,this)}),u(t,e)})}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/geo_location_utils\":713,\"../../lib/geojson_utils\":714,\"../../lib/topojson_utils\":746,\"../scatter/subtypes\":1135,\"./style\":1159,d3:163}],1158:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,a,o,s,l,c=t.cd,u=t.xaxis,h=t.yaxis,f=[],p=c[0].trace;if(!n.hasMarkers(p)&&!n.hasText(p))return[];if(!1===e)for(l=0;l<c.length;l++)c[l].selected=0;else for(l=0;l<c.length;l++)(a=(r=c[l]).lonlat)[0]!==i&&(o=u.c2p(a),s=h.c2p(a),e.contains([o,s],null,l,t)?(f.push({pointNumber:l,lon:a[0],lat:a[1]}),r.selected=1):r.selected=0);return f}},{\"../../constants/numerical\":695,\"../scatter/subtypes\":1135}],1159:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../scatter/style\"),s=o.stylePoints,l=o.styleText;e.exports=function(t,e){e&&function(t,e){var r=e[0].trace,o=e[0].node3;o.style(\"opacity\",e[0].trace.opacity),s(o,r,t),l(o,r,t),o.selectAll(\"path.js-line\").style(\"fill\",\"none\").each(function(t){var e=n.select(this),r=t.trace,o=r.line||{};e.call(a.stroke,o.color).call(i.dashLine,o.dash||\"\",o.width||0),\"none\"!==r.fill&&e.call(a.fill,r.fillcolor)})}(t,e)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../scatter/style\":1134,d3:163}],1160:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=t(\"./constants\").DASHES,c=i.line,u=i.marker,h=u.line,f=e.exports=s({x:i.x,x0:i.x0,dx:i.dx,y:i.y,y0:i.y0,dy:i.dy,text:i.text,hovertext:i.hovertext,textposition:i.textposition,textfont:i.textfont,mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"]},line:{color:c.color,width:c.width,shape:{valType:\"enumerated\",values:[\"linear\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},dash:{valType:\"enumerated\",values:Object.keys(l),dflt:\"solid\"}},marker:o({},a(\"marker\"),{symbol:u.symbol,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:o({},a(\"marker.line\"),{width:h.width})}),connectgaps:i.connectgaps,fill:o({},i.fill,{dflt:\"none\"}),fillcolor:i.fillcolor,selected:{marker:i.selected.marker,textfont:i.selected.textfont},unselected:{marker:i.unselected.marker,textfont:i.unselected.textfont},opacity:n.opacity},\"calc\",\"nested\");f.x.editType=f.y.editType=f.x0.editType=f.y0.editType=\"calc+clearAxisTypes\",f.hovertemplate=i.hovertemplate},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../scatter/attributes\":1112,\"./constants\":1162}],1161:[function(t,e,r){\"use strict\";var n=t(\"point-cluster\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../plots/cartesian/autorange\").findExtremes,s=t(\"../scatter/calc\"),l=s.calcMarkerSize,c=s.calcAxisExpansion,u=s.setFirstScatter,h=t(\"../scatter/colorscale_calc\"),f=t(\"./convert\"),p=t(\"./scene_update\"),d=t(\"../../constants/numerical\").BADNUM,g=t(\"./constants\").TOO_MANY_POINTS;function v(t,e,r){var n=t._extremes[e._id],i=o(e,r._bnds,{padded:!0});n.min=n.min.concat(i.min),n.max=n.max.concat(i.max)}e.exports=function(t,e){var r,o,s,m=t._fullLayout,y=a.getFromId(t,e.xaxis),x=a.getFromId(t,e.yaxis),b=m._plots[e.xaxis+e.yaxis],_=e._length,w=_>=g,k=2*_,T={},A=y.makeCalcdata(e,\"x\"),M=x.makeCalcdata(e,\"y\"),S=new Array(k);for(r=0;r<_;r++)o=A[r],s=M[r],S[2*r]=o===d?NaN:o,S[2*r+1]=s===d?NaN:s;if(\"log\"===y.type)for(r=0;r<k;r+=2)S[r]=y.c2l(S[r]);if(\"log\"===x.type)for(r=1;r<k;r+=2)S[r]=x.c2l(S[r]);if(w&&\"log\"!==y.type&&\"log\"!==x.type)T.tree=n(S);else{var E=T.ids=new Array(_);for(r=0;r<_;r++)E[r]=r}h(t,e);var C,L=function(t,e,r,n,a,o){var s=f.style(t,r);s.marker&&(s.marker.positions=n);s.line&&n.length>1&&i.extendFlat(s.line,f.linePositions(t,r,n));if(s.errorX||s.errorY){var l=f.errorBarPositions(t,r,n,a,o);s.errorX&&i.extendFlat(s.errorX,l.x),s.errorY&&i.extendFlat(s.errorY,l.y)}s.text&&(i.extendFlat(s.text,{positions:n},f.textPosition(t,r,s.text,s.marker)),i.extendFlat(s.textSel,{positions:n},f.textPosition(t,r,s.text,s.markerSel)),i.extendFlat(s.textUnsel,{positions:n},f.textPosition(t,r,s.text,s.markerUnsel)));return s}(t,0,e,S,A,M),P=p(t,b);return u(m,e),w?L.marker&&(C=2*(L.marker.sizeAvg||Math.max(L.marker.size,3))):C=l(e,_),c(t,e,y,x,A,M,C),L.errorX&&v(e,y,L.errorX),L.errorY&&v(e,x,L.errorY),L.fill&&!P.fill2d&&(P.fill2d=!0),L.marker&&!P.scatter2d&&(P.scatter2d=!0),L.line&&!P.line2d&&(P.line2d=!0),!L.errorX&&!L.errorY||P.error2d||(P.error2d=!0),L.text&&!P.glText&&(P.glText=!0),L.marker&&(L.marker.snap=T.tree||g),P.lineOptions.push(L.line),P.errorXOptions.push(L.errorX),P.errorYOptions.push(L.errorY),P.fillOptions.push(L.fill),P.markerOptions.push(L.marker),P.markerSelectedOptions.push(L.markerSel),P.markerUnselectedOptions.push(L.markerUnsel),P.textOptions.push(L.text),P.textSelectedOptions.push(L.textSel),P.textUnselectedOptions.push(L.textUnsel),P.selectBatch.push([]),P.unselectBatch.push([]),T._scene=P,T.index=P.count,T.x=A,T.y=M,T.positions=S,P.count++,[{x:!1,y:!1,t:T,trace:e}]}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/autorange\":766,\"../../plots/cartesian/axis_ids\":770,\"../scatter/calc\":1113,\"../scatter/colorscale_calc\":1115,\"./constants\":1162,\"./convert\":1163,\"./scene_update\":1169,\"point-cluster\":469}],1162:[function(t,e,r){\"use strict\";e.exports={TOO_MANY_POINTS:1e5,SYMBOL_SDF_SIZE:200,SYMBOL_SIZE:20,SYMBOL_STROKE:1,DOT_RE:/-dot/,OPEN_RE:/-open/,DASHES:{solid:[1],dot:[1,1],dash:[4,1],longdash:[8,1],dashdot:[4,1,1,1],longdashdot:[8,1,1,1]}}},{}],1163:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"svg-path-sdf\"),a=t(\"color-normalize\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../components/drawing\"),c=t(\"../../plots/cartesian/axis_ids\"),u=t(\"../../lib/gl_format_color\").formatColor,h=t(\"../scatter/subtypes\"),f=t(\"../scatter/make_bubble_size_func\"),p=t(\"./constants\"),d=t(\"../../constants/interactions\").DESELECTDIM,g={start:1,left:1,end:-1,right:-1,middle:0,center:0,bottom:1,top:-1};function v(t){var e,r=t._length,i=t.textfont,a=t.textposition,o=Array.isArray(a)?a:[a],s=i.color,l=i.size,c=i.family,u={};for(u.text=t.text,u.opacity=t.opacity,u.font={},u.align=[],u.baseline=[],e=0;e<o.length;e++){var h=o[e].split(/\\s+/);switch(h[1]){case\"left\":u.align.push(\"right\");break;case\"right\":u.align.push(\"left\");break;default:u.align.push(h[1])}switch(h[0]){case\"top\":u.baseline.push(\"bottom\");break;case\"bottom\":u.baseline.push(\"top\");break;default:u.baseline.push(h[0])}}if(Array.isArray(s))for(u.color=new Array(r),e=0;e<r;e++)u.color[e]=s[e];else u.color=s;if(Array.isArray(l)||Array.isArray(c))for(u.font=new Array(r),e=0;e<r;e++){var f=u.font[e]={};f.size=Array.isArray(l)?n(l[e])?l[e]:0:l,f.family=Array.isArray(c)?c[e]:c}else u.font={size:l,family:c};return u}function m(t){var e,r,n=t._length,i=t.marker,o={},l=Array.isArray(i.symbol),c=s.isArrayOrTypedArray(i.color),h=s.isArrayOrTypedArray(i.line.color),d=s.isArrayOrTypedArray(i.opacity),g=s.isArrayOrTypedArray(i.size),v=s.isArrayOrTypedArray(i.line.width);if(l||(r=p.OPEN_RE.test(i.symbol)),l||c||h||d){o.colors=new Array(n),o.borderColors=new Array(n);var m=u(i,i.opacity,n),y=u(i.line,i.opacity,n);if(!Array.isArray(y[0])){var x=y;for(y=Array(n),e=0;e<n;e++)y[e]=x}if(!Array.isArray(m[0])){var b=m;for(m=Array(n),e=0;e<n;e++)m[e]=b}for(o.colors=m,o.borderColors=y,e=0;e<n;e++){if(l){var _=i.symbol[e];r=p.OPEN_RE.test(_)}r&&(y[e]=m[e].slice(),m[e]=m[e].slice(),m[e][3]=0)}o.opacity=t.opacity}else r?(o.color=a(i.color,\"uint8\"),o.color[3]=0,o.borderColor=a(i.color,\"uint8\")):(o.color=a(i.color,\"uint8\"),o.borderColor=a(i.line.color,\"uint8\")),o.opacity=t.opacity*i.opacity;if(l)for(o.markers=new Array(n),e=0;e<n;e++)o.markers[e]=M(i.symbol[e]);else o.marker=M(i.symbol);var w,k=f(t);if(g||v){var T,A=o.sizes=new Array(n),S=o.borderSizes=new Array(n),E=0;if(g){for(e=0;e<n;e++)A[e]=k(i.size[e]),E+=A[e];T=E/n}else for(w=k(i.size),e=0;e<n;e++)A[e]=w;if(v)for(e=0;e<n;e++)S[e]=i.line.width[e]/2;else for(w=i.line.width/2,e=0;e<n;e++)S[e]=w;o.sizeAvg=T}else o.size=k(i&&i.size||10),o.borderSizes=k(i.line.width);return o}function y(t,e){var r=t.marker,n={};return e?(e.marker&&e.marker.symbol?n=m(s.extendFlat({},r,e.marker)):e.marker&&(e.marker.size&&(n.size=e.marker.size/2),e.marker.color&&(n.colors=e.marker.color),void 0!==e.marker.opacity&&(n.opacity=e.marker.opacity)),n):n}function x(t,e){var r={};if(!e)return r;if(e.textfont){var n={opacity:1,text:t.text,textposition:t.textposition,textfont:s.extendFlat({},t.textfont)};e.textfont&&s.extendFlat(n.textfont,e.textfont),r=v(n)}return r}function b(t,e){var r={capSize:2*e.width,lineWidth:e.thickness,color:e.color};return e.copy_ystyle&&(r=t.error_y),r}var _=p.SYMBOL_SDF_SIZE,w=p.SYMBOL_SIZE,k=p.SYMBOL_STROKE,T={},A=l.symbolFuncs[0](.05*w);function M(t){if(\"circle\"===t)return null;var e,r,n=l.symbolNumber(t),a=l.symbolFuncs[n%100],o=!!l.symbolNoDot[n%100],s=!!l.symbolNoFill[n%100],c=p.DOT_RE.test(t);return T[t]?T[t]:(e=c&&!o?a(1.1*w)+A:a(w),r=i(e,{w:_,h:_,viewBox:[-w,-w,w,w],stroke:s?k:-k}),T[t]=r,r||null)}e.exports={style:function(t,e){var r,n={marker:void 0,markerSel:void 0,markerUnsel:void 0,line:void 0,fill:void 0,errorX:void 0,errorY:void 0,text:void 0,textSel:void 0,textUnsel:void 0};if(!0!==e.visible)return n;if(h.hasText(e)&&(n.text=v(e),n.textSel=x(e,e.selected),n.textUnsel=x(e,e.unselected)),h.hasMarkers(e)&&(n.marker=m(e),n.markerSel=y(e,e.selected),n.markerUnsel=y(e,e.unselected),!e.unselected&&Array.isArray(e.marker.opacity))){var i=e.marker.opacity;for(n.markerUnsel.opacity=new Array(i.length),r=0;r<i.length;r++)n.markerUnsel.opacity[r]=d*i[r]}if(h.hasLines(e)){n.line={overlay:!0,thickness:e.line.width,color:e.line.color,opacity:e.opacity};var a=(p.DASHES[e.line.dash]||[1]).slice();for(r=0;r<a.length;++r)a[r]*=e.line.width;n.line.dashes=a}return e.error_x&&e.error_x.visible&&(n.errorX=b(e,e.error_x)),e.error_y&&e.error_y.visible&&(n.errorY=b(e,e.error_y)),e.fill&&\"none\"!==e.fill&&(n.fill={closed:!0,fill:e.fillcolor,thickness:0}),n},markerStyle:m,markerSelection:y,linePositions:function(t,e,r){var n,i,a=r.length,o=a/2;if(h.hasLines(e)&&o)if(\"hv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i+2],r[2*i+1]));n.push(r[a-2],r[a-1])}else if(\"hvh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var s=(r[2*i]+r[2*i+2])/2;n.push(r[2*i],r[2*i+1],s,r[2*i+1],s,r[2*i+3])}n.push(r[a-2],r[a-1])}else if(\"vhv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var l=(r[2*i+1]+r[2*i+3])/2;n.push(r[2*i],r[2*i+1],r[2*i],l,r[2*i+2],l)}n.push(r[a-2],r[a-1])}else if(\"vh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+3]));n.push(r[a-2],r[a-1])}else n=r;var c=!1;for(i=0;i<n.length;i++)if(isNaN(n[i])){c=!0;break}var u=c||n.length>p.TOO_MANY_POINTS?\"rect\":h.hasMarkers(e)?\"rect\":\"round\";if(c&&e.connectgaps){var f=n[0],d=n[1];for(i=0;i<n.length;i+=2)isNaN(n[i])||isNaN(n[i+1])?(n[i]=f,n[i+1]=d):(f=n[i],d=n[i+1])}return{join:u,positions:n}},errorBarPositions:function(t,e,r,i,a){var s=o.getComponentMethod(\"errorbars\",\"makeComputeError\"),l=c.getFromId(t,e.xaxis),u=c.getFromId(t,e.yaxis),h=r.length/2,f={};function p(t,i){var a=i._id.charAt(0),o=e[\"error_\"+a];if(o&&o.visible&&(\"linear\"===i.type||\"log\"===i.type)){for(var l=s(o),c={x:0,y:1}[a],u={x:[0,1,2,3],y:[2,3,0,1]}[a],p=new Float64Array(4*h),d=1/0,g=-1/0,v=0,m=0;v<h;v++,m+=4){var y=t[v];if(n(y)){var x=r[2*v+c],b=l(y,v),_=b[0],w=b[1];if(n(_)&&n(w)){var k=y-_,T=y+w;p[m+u[0]]=x-i.c2l(k),p[m+u[1]]=i.c2l(T)-x,p[m+u[2]]=0,p[m+u[3]]=0,d=Math.min(d,y-_),g=Math.max(g,y+w)}}}f[a]={positions:r,errors:p,_bnds:[d,g]}}}return p(i,l),p(a,u),f},textPosition:function(t,e,r,n){var i,a=e._length,o={};if(h.hasMarkers(e)){var s=r.font,l=r.align,c=r.baseline;for(o.offset=new Array(a),i=0;i<a;i++){var u=n.sizes?n.sizes[i]:n.size,f=Array.isArray(s)?s[i].size:s.size,p=Array.isArray(l)?l.length>1?l[i]:l[0]:l,d=Array.isArray(c)?c.length>1?c[i]:c[0]:c,v=g[p],m=g[d],y=u?u/.8+1:0,x=-m*y-.5*m;o.offset[i]=[v*y/f,x/f]}}return o}}},{\"../../components/drawing\":614,\"../../constants/interactions\":694,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../scatter/make_bubble_size_func\":1128,\"../scatter/subtypes\":1135,\"./constants\":1162,\"color-normalize\":120,\"fast-isnumeric\":225,\"svg-path-sdf\":535}],1164:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"../scatter/constants\"),s=t(\"../scatter/subtypes\"),l=t(\"../scatter/xy_defaults\"),c=t(\"../scatter/marker_defaults\"),u=t(\"../scatter/line_defaults\"),h=t(\"../scatter/fillcolor_defaults\"),f=t(\"../scatter/text_defaults\");e.exports=function(t,e,r,p){function d(r,i){return n.coerce(t,e,a,r,i)}var g=!!t.marker&&/-open/.test(t.marker.symbol),v=s.isBubble(t),m=l(t,e,p,d);if(m){var y=m<o.PTS_LINESONLY?\"lines+markers\":\"lines\";d(\"text\"),d(\"hovertext\"),d(\"hovertemplate\"),d(\"mode\",y),s.hasLines(e)&&(d(\"connectgaps\"),u(t,e,r,p,d),d(\"line.shape\")),s.hasMarkers(e)&&(c(t,e,r,p,d),d(\"marker.line.width\",g||v?1:0)),s.hasText(e)&&f(t,e,p,d);var x=(e.line||{}).color,b=(e.marker||{}).color;d(\"fill\"),\"none\"!==e.fill&&h(t,e,r,d);var _=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");_(t,e,x||b||r,{axis:\"y\"}),_(t,e,x||b||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}},{\"../../lib\":719,\"../../registry\":847,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"../scatter/xy_defaults\":1137,\"./attributes\":1160}],1165:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../constants/interactions\").DESELECTDIM;e.exports={styleTextSelection:function(t){var e,r,o=t[0],s=o.trace,l=o.t,c=l._scene,u=l.index,h=c.selectBatch[u],f=c.unselectBatch[u],p=c.textOptions[u],d=c.textSelectedOptions[u]||{},g=c.textUnselectedOptions[u]||{},v=n.extendFlat({},p);if(h.length||f.length){var m=d.color,y=g.color,x=p.color,b=Array.isArray(x);for(v.color=new Array(s._length),e=0;e<h.length;e++)r=h[e],v.color[r]=m||(b?x[r]:x);for(e=0;e<f.length;e++){r=f[e];var _=b?x[r]:x;v.color[r]=y||(m?_:i.addOpacity(_,a))}}c.glText[u].update(v)}}},{\"../../components/color\":593,\"../../constants/interactions\":694,\"../../lib\":719}],1166:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\");function o(t,e,r,o){var s=t.xa,l=t.ya,c=t.distance,u=t.dxy,h=t.index,f={pointNumber:h,x:e[h],y:r[h]};f.tx=Array.isArray(o.text)?o.text[h]:o.text,f.htx=Array.isArray(o.hovertext)?o.hovertext[h]:o.hovertext,f.data=Array.isArray(o.customdata)?o.customdata[h]:o.customdata,f.tp=Array.isArray(o.textposition)?o.textposition[h]:o.textposition;var p=o.textfont;p&&(f.ts=Array.isArray(p.size)?p.size[h]:p.size,f.tc=Array.isArray(p.color)?p.color[h]:p.color,f.tf=Array.isArray(p.family)?p.family[h]:p.family);var d=o.marker;d&&(f.ms=i.isArrayOrTypedArray(d.size)?d.size[h]:d.size,f.mo=i.isArrayOrTypedArray(d.opacity)?d.opacity[h]:d.opacity,f.mx=Array.isArray(d.symbol)?d.symbol[h]:d.symbol,f.mc=i.isArrayOrTypedArray(d.color)?d.color[h]:d.color);var g=d&&d.line;g&&(f.mlc=Array.isArray(g.color)?g.color[h]:g.color,f.mlw=i.isArrayOrTypedArray(g.width)?g.width[h]:g.width);var v=d&&d.gradient;v&&\"none\"!==v.type&&(f.mgt=Array.isArray(v.type)?v.type[h]:v.type,f.mgc=Array.isArray(v.color)?v.color[h]:v.color);var m=s.c2p(f.x,!0),y=l.c2p(f.y,!0),x=f.mrc||1,b=o.hoverlabel;b&&(f.hbg=Array.isArray(b.bgcolor)?b.bgcolor[h]:b.bgcolor,f.hbc=Array.isArray(b.bordercolor)?b.bordercolor[h]:b.bordercolor,f.hts=Array.isArray(b.font.size)?b.font.size[h]:b.font.size,f.htc=Array.isArray(b.font.color)?b.font.color[h]:b.font.color,f.htf=Array.isArray(b.font.family)?b.font.family[h]:b.font.family,f.hnl=Array.isArray(b.namelength)?b.namelength[h]:b.namelength);var _=o.hoverinfo;_&&(f.hi=Array.isArray(_)?_[h]:_);var w=o.hovertemplate;w&&(f.ht=Array.isArray(w)?w[h]:w);var k={};return k[t.index]=f,i.extendFlat(t,{color:a(o,f),x0:m-x,x1:m+x,xLabelVal:f.x,y0:y-x,y1:y+x,yLabelVal:f.y,cd:k,distance:c,spikeDistance:u,hovertemplate:f.ht}),f.htx?t.text=f.htx:f.tx?t.text=f.tx:o.text&&(t.text=o.text),i.fillText(f,o,t),n.getComponentMethod(\"errorbars\",\"hoverInfo\")(f,o,t),t}e.exports={hoverPoints:function(t,e,r,n){var i,a,s,l,c,u,h,f,p,d=t.cd,g=d[0].t,v=d[0].trace,m=t.xa,y=t.ya,x=g.x,b=g.y,_=m.c2p(e),w=y.c2p(r),k=t.distance;if(g.tree){var T=m.p2c(_-k),A=m.p2c(_+k),M=y.p2c(w-k),S=y.p2c(w+k);i=\"x\"===n?g.tree.range(Math.min(T,A),Math.min(y._rl[0],y._rl[1]),Math.max(T,A),Math.max(y._rl[0],y._rl[1])):g.tree.range(Math.min(T,A),Math.min(M,S),Math.max(T,A),Math.max(M,S))}else{if(!g.ids)return[t];i=g.ids}var E=k;if(\"x\"===n)for(c=0;c<i.length;c++)s=x[i[c]],(u=Math.abs(m.c2p(s)-_))<E&&(E=u,h=y.c2p(b[i[c]])-w,p=Math.sqrt(u*u+h*h),a=i[c]);else for(c=i.length-1;c>-1;c--)s=x[i[c]],l=b[i[c]],u=m.c2p(s)-_,h=y.c2p(l)-w,(f=Math.sqrt(u*u+h*h))<E&&(E=p=f,a=i[c]);return t.index=a,t.distance=E,t.dxy=p,void 0===a?[t]:(o(t,x,b,v),[t])},calcHover:o}},{\"../../lib\":719,\"../../registry\":847,\"../scatter/get_trace_color\":1121}],1167:[function(t,e,r){\"use strict\";var n=t(\"./hover\");e.exports={moduleType:\"trace\",name:\"scattergl\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../scatter/cross_trace_defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:n.hoverPoints,selectPoints:t(\"./select\"),meta:{}}},{\"../../plots/cartesian\":778,\"../scatter/cross_trace_defaults\":1118,\"../scatter/marker_colorbar\":1129,\"./attributes\":1160,\"./calc\":1161,\"./defaults\":1164,\"./hover\":1166,\"./plot\":1168,\"./select\":1170}],1168:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"regl-line2d\"),a=t(\"regl-error2d\"),o=t(\"gl-text\"),s=t(\"../../lib\"),l=t(\"../../lib/prepare_regl\"),c=t(\"../scatter/subtypes\"),u=t(\"../scatter/link_traces\"),h=t(\"./edit_style\").styleTextSelection;e.exports=function(t,e,r){if(r.length){var f,p,d=t._fullLayout,g=e._scene,v=e.xaxis,m=e.yaxis;if(g)if(l(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])){var y=g.count,x=d._glcanvas.data()[0].regl;if(u(t,e,r),g.dirty){if(!0===g.error2d&&(g.error2d=a(x)),!0===g.line2d&&(g.line2d=i(x)),!0===g.scatter2d&&(g.scatter2d=n(x)),!0===g.fill2d&&(g.fill2d=i(x)),!0===g.glText)for(g.glText=new Array(y),f=0;f<y;f++)g.glText[f]=new o(x);if(g.glText){if(y>g.glText.length){var b=y-g.glText.length;for(f=0;f<b;f++)g.glText.push(new o(x))}else if(y<g.glText.length){var _=g.glText.length-y;g.glText.splice(y,_).forEach(function(t){t.destroy()})}for(f=0;f<y;f++)g.glText[f].update(g.textOptions[f])}if(g.line2d&&(g.line2d.update(g.lineOptions),g.lineOptions=g.lineOptions.map(function(t){if(t&&t.positions){for(var e=t.positions,r=0;r<e.length&&(isNaN(e[r])||isNaN(e[r+1]));)r+=2;for(var n=e.length-2;n>r&&(isNaN(e[n])||isNaN(e[n+1]));)n-=2;t.positions=e.slice(r,n+2)}return t}),g.line2d.update(g.lineOptions)),g.error2d){var w=(g.errorXOptions||[]).concat(g.errorYOptions||[]);g.error2d.update(w)}g.scatter2d&&g.scatter2d.update(g.markerOptions),g.fillOrder=s.repeat(null,y),g.fill2d&&(g.fillOptions=g.fillOptions.map(function(t,e){var n=r[e];if(t&&n&&n[0]&&n[0].trace){var i,a,o=n[0],s=o.trace,l=o.t,c=g.lineOptions[e],u=[];s._ownfill&&u.push(e),s._nexttrace&&u.push(e+1),u.length&&(g.fillOrder[e]=u);var h,f,p=[],d=c&&c.positions||l.positions;if(\"tozeroy\"===s.fill){for(h=0;h<d.length&&isNaN(d[h+1]);)h+=2;for(f=d.length-2;f>h&&isNaN(d[f+1]);)f-=2;0!==d[h+1]&&(p=[d[h],0]),p=p.concat(d.slice(h,f+2)),0!==d[f+1]&&(p=p.concat([d[f],0]))}else if(\"tozerox\"===s.fill){for(h=0;h<d.length&&isNaN(d[h]);)h+=2;for(f=d.length-2;f>h&&isNaN(d[f]);)f-=2;0!==d[h]&&(p=[0,d[h+1]]),p=p.concat(d.slice(h,f+2)),0!==d[f]&&(p=p.concat([0,d[f+1]]))}else if(\"toself\"===s.fill||\"tonext\"===s.fill){for(p=[],i=0,a=0;a<d.length;a+=2)(isNaN(d[a])||isNaN(d[a+1]))&&((p=p.concat(d.slice(i,a))).push(d[i],d[i+1]),i=a+2);p=p.concat(d.slice(i)),i&&p.push(d[i],d[i+1])}else{var v=s._nexttrace;if(v){var m=g.lineOptions[e+1];if(m){var y=m.positions;if(\"tonexty\"===s.fill){for(p=d.slice(),e=Math.floor(y.length/2);e--;){var x=y[2*e],b=y[2*e+1];isNaN(x)||isNaN(b)||p.push(x,b)}t.fill=v.fillcolor}}}}if(s._prevtrace&&\"tonext\"===s._prevtrace.fill){var _=g.lineOptions[e-1].positions,w=p.length/2,k=[i=w];for(a=0;a<_.length;a+=2)(isNaN(_[a])||isNaN(_[a+1]))&&(k.push(a/2+w+1),i=a+2);p=p.concat(_),t.hole=k}return t.fillmode=s.fill,t.opacity=s.opacity,t.positions=p,t}}),g.fill2d.update(g.fillOptions))}var k=d.dragmode,T=\"lasso\"===k||\"select\"===k,A=d.clickmode.indexOf(\"select\")>-1;for(f=0;f<y;f++){var M=r[f][0],S=M.trace,E=M.t,C=E.index,L=S._length,P=E.x,O=E.y;if(S.selectedpoints||T||A){if(T||(T=!0),S.selectedpoints){var z=g.selectBatch[C]=s.selIndices2selPoints(S),I={};for(p=0;p<z.length;p++)I[z[p]]=1;var D=[];for(p=0;p<L;p++)I[p]||D.push(p);g.unselectBatch[C]=D}var R=E.xpx=new Array(L),F=E.ypx=new Array(L);for(p=0;p<L;p++)R[p]=v.c2p(P[p]),F[p]=m.c2p(O[p])}else E.xpx=E.ypx=null}if(T){if(g.select2d||(g.select2d=n(d._glcanvas.data()[1].regl)),g.scatter2d){var B=new Array(y);for(f=0;f<y;f++)B[f]=g.selectBatch[f].length||g.unselectBatch[f].length?g.markerUnselectedOptions[f]:{};g.scatter2d.update(B)}g.select2d&&(g.select2d.update(g.markerOptions),g.select2d.update(g.markerSelectedOptions)),g.glText&&r.forEach(function(t){var e=((t||[])[0]||{}).trace||{};c.hasText(e)&&h(t)})}else g.scatter2d&&g.scatter2d.update(g.markerOptions);var N={viewport:function(t,e,r){var n=t._size,i=t.width,a=t.height;return[n.l+e.domain[0]*n.w,n.b+r.domain[0]*n.h,i-n.r-(1-e.domain[1])*n.w,a-n.t-(1-r.domain[1])*n.h]}(d,v,m),range:[(v._rl||v.range)[0],(m._rl||m.range)[0],(v._rl||v.range)[1],(m._rl||m.range)[1]]},j=s.repeat(N,g.count);g.fill2d&&g.fill2d.update(j),g.line2d&&g.line2d.update(j),g.error2d&&g.error2d.update(j.concat(j)),g.scatter2d&&g.scatter2d.update(j),g.select2d&&g.select2d.update(j),g.glText&&g.glText.forEach(function(t){t.update(N)})}else g.init()}}},{\"../../lib\":719,\"../../lib/prepare_regl\":732,\"../scatter/link_traces\":1127,\"../scatter/subtypes\":1135,\"./edit_style\":1165,\"gl-text\":317,\"regl-error2d\":490,\"regl-line2d\":491,\"regl-scatter2d\":497}],1169:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=e._scene,i={count:0,dirty:!0,lineOptions:[],fillOptions:[],markerOptions:[],markerSelectedOptions:[],markerUnselectedOptions:[],errorXOptions:[],errorYOptions:[],textOptions:[],textSelectedOptions:[],textUnselectedOptions:[],selectBatch:[],unselectBatch:[]},a={fill2d:!1,scatter2d:!1,error2d:!1,line2d:!1,glText:!1,select2d:!1};return e._scene||((r=e._scene={}).init=function(){n.extendFlat(r,a,i)},r.init(),r.update=function(t){var e=n.repeat(t,r.count);if(r.fill2d&&r.fill2d.update(e),r.scatter2d&&r.scatter2d.update(e),r.line2d&&r.line2d.update(e),r.error2d&&r.error2d.update(e.concat(e)),r.select2d&&r.select2d.update(e),r.glText)for(var i=0;i<r.count;i++)r.glText[i].update(t)},r.draw=function(){for(var t=r.count,e=r.fill2d,i=r.error2d,a=r.line2d,o=r.scatter2d,s=r.glText,l=r.select2d,c=r.selectBatch,u=r.unselectBatch,h=0;h<t;h++){if(e&&r.fillOrder[h]&&e.draw(r.fillOrder[h]),a&&r.lineOptions[h]&&a.draw(h),i&&(r.errorXOptions[h]&&i.draw(h),r.errorYOptions[h]&&i.draw(h+t)),o&&r.markerOptions[h])if(u[h].length){var f=n.repeat([],r.count);f[h]=u[h],o.draw(f)}else c[h].length||o.draw(h);s[h]&&r.textOptions[h]&&s[h].render()}l&&l.draw(c),r.dirty=!1},r.destroy=function(){r.fill2d&&r.fill2d.destroy&&r.fill2d.destroy(),r.scatter2d&&r.scatter2d.destroy&&r.scatter2d.destroy(),r.error2d&&r.error2d.destroy&&r.error2d.destroy(),r.line2d&&r.line2d.destroy&&r.line2d.destroy(),r.select2d&&r.select2d.destroy&&r.select2d.destroy(),r.glText&&r.glText.forEach(function(t){t.destroy&&t.destroy()}),r.lineOptions=null,r.fillOptions=null,r.markerOptions=null,r.markerSelectedOptions=null,r.markerUnselectedOptions=null,r.errorXOptions=null,r.errorYOptions=null,r.textOptions=null,r.textSelectedOptions=null,r.textUnselectedOptions=null,r.selectBatch=null,r.unselectBatch=null,e._scene=null}),r.dirty||n.extendFlat(r,i),r}},{\"../../lib\":719}],1170:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"./edit_style\").styleTextSelection;e.exports=function(t,e){var r=t.cd,a=[],o=r[0].trace,s=r[0].t,l=o._length,c=s.x,u=s.y,h=s._scene,f=s.index;if(!h)return a;var p=n.hasText(o),d=n.hasMarkers(o),g=!d&&!p;if(!0!==o.visible||g)return a;var v=[],m=[];if(!1!==e&&!e.degenerate)for(var y=0;y<l;y++)e.contains([s.xpx[y],s.ypx[y]],!1,y,t)?(v.push(y),a.push({pointNumber:y,x:c[y],y:u[y]})):m.push(y);if(d){var x=h.scatter2d;if(v.length||m.length){if(!h.selectBatch[f].length&&!h.unselectBatch[f].length){var b=new Array(h.count);b[f]=h.markerUnselectedOptions[f],x.update.apply(x,b)}}else{var _=new Array(h.count);_[f]=h.markerOptions[f],x.update.apply(x,_)}}return h.selectBatch[f]=v,h.unselectBatch[f]=m,p&&i(r),a}},{\"../scatter/subtypes\":1135,\"./edit_style\":1165}],1171:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scattergeo/attributes\"),a=t(\"../scatter/attributes\"),o=t(\"../../plots/mapbox/layout_attributes\"),s=t(\"../../plots/attributes\"),l=t(\"../../components/colorscale/attributes\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../plot_api/edit_types\").overrideAll,h=i.line,f=i.marker;e.exports=u({lon:i.lon,lat:i.lat,mode:c({},a.mode,{dflt:\"markers\"}),text:c({},a.text,{}),hovertext:c({},a.hovertext,{}),line:{color:h.color,width:h.width},connectgaps:a.connectgaps,marker:c({symbol:{valType:\"string\",dflt:\"circle\",arrayOk:!0},opacity:f.opacity,size:f.size,sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode},l(\"marker\")),fill:i.fill,fillcolor:a.fillcolor,textfont:o.layers.symbol.textfont,textposition:o.layers.symbol.textposition,below:{valType:\"string\"},selected:{marker:a.selected.marker},unselected:{marker:a.unselected.marker},hoverinfo:c({},s.hoverinfo,{flags:[\"lon\",\"lat\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../../plots/mapbox/layout_attributes\":824,\"../scatter/attributes\":1112,\"../scattergeo/attributes\":1151}],1172:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../lib/geojson_utils\"),s=t(\"../../components/colorscale\"),l=t(\"../../components/drawing\"),c=t(\"../scatter/make_bubble_size_func\"),u=t(\"../scatter/subtypes\"),h=t(\"../../plots/mapbox/convert_text_opts\");function f(){return{geojson:o.makeBlank(),layout:{visibility:\"none\"},paint:{}}}function p(t){return i.isArrayOrTypedArray(t)?function(t){return t}:t?function(){return t}:d}function d(){return\"\"}function g(t){return t[0]===a}e.exports=function(t){var e,r=t[0].trace,a=!0===r.visible&&0!==r._length,v=\"none\"!==r.fill,m=u.hasLines(r),y=u.hasMarkers(r),x=u.hasText(r),b=y&&\"circle\"===r.marker.symbol,_=y&&\"circle\"!==r.marker.symbol,w=f(),k=f(),T=f(),A=f(),M={fill:w,line:k,circle:T,symbol:A};if(!a)return M;if((v||m)&&(e=o.calcTraceToLineCoords(t)),v&&(w.geojson=o.makePolygon(e),w.layout.visibility=\"visible\",i.extendFlat(w.paint,{\"fill-color\":r.fillcolor})),m&&(k.geojson=o.makeLine(e),k.layout.visibility=\"visible\",i.extendFlat(k.paint,{\"line-width\":r.line.width,\"line-color\":r.line.color,\"line-opacity\":r.opacity})),b){var S=function(t){var e,r,a,o,u=t[0].trace,h=u.marker,f=u.selectedpoints,p=i.isArrayOrTypedArray(h.color),d=i.isArrayOrTypedArray(h.size),v=i.isArrayOrTypedArray(h.opacity);function m(t){return u.opacity*t}p&&(r=s.hasColorscale(u,\"marker\")?s.makeColorScaleFuncFromTrace(h):i.identity);d&&(a=c(u));v&&(o=function(t){var e=n(t)?+i.constrain(t,0,1):0;return m(e)});var y,x=[];for(e=0;e<t.length;e++){var b=t[e],_=b.lonlat;if(!g(_)){var w={};r&&(w.mcc=b.mcc=r(b.mc)),a&&(w.mrc=b.mrc=a(b.ms)),o&&(w.mo=o(b.mo)),f&&(w.selected=b.selected||0),x.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:_},properties:w})}}if(f)for(y=l.makeSelectedPointStyleFns(u),e=0;e<x.length;e++){var k=x[e].properties;y.selectedOpacityFn&&(k.mo=m(y.selectedOpacityFn(k))),y.selectedColorFn&&(k.mcc=y.selectedColorFn(k)),y.selectedSizeFn&&(k.mrc=y.selectedSizeFn(k))}return{geojson:{type:\"FeatureCollection\",features:x},mcc:p||y&&y.selectedColorFn?{type:\"identity\",property:\"mcc\"}:h.color,mrc:d||y&&y.selectedSizeFn?{type:\"identity\",property:\"mrc\"}:(T=h.size,T/2),mo:v||y&&y.selectedOpacityFn?{type:\"identity\",property:\"mo\"}:m(h.opacity)};var T}(t);T.geojson=S.geojson,T.layout.visibility=\"visible\",i.extendFlat(T.paint,{\"circle-color\":S.mcc,\"circle-radius\":S.mrc,\"circle-opacity\":S.mo})}if((_||x)&&(A.geojson=function(t){for(var e=t[0].trace,r=(e.marker||{}).symbol,n=e.text,i=\"circle\"!==r?p(r):d,a=u.hasText(e)?p(n):d,o=[],s=0;s<t.length;s++){var l=t[s];g(l.lonlat)||o.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:l.lonlat},properties:{symbol:i(l.mx),text:a(l.tx)}})}return{type:\"FeatureCollection\",features:o}}(t),i.extendFlat(A.layout,{visibility:\"visible\",\"icon-image\":\"{symbol}-15\",\"text-field\":\"{text}\"}),_&&(i.extendFlat(A.layout,{\"icon-size\":r.marker.size/10}),i.extendFlat(A.paint,{\"icon-opacity\":r.opacity*r.marker.opacity,\"icon-color\":r.marker.color})),x)){var E=(r.marker||{}).size,C=h(r.textposition,E);i.extendFlat(A.layout,{\"text-size\":r.textfont.size,\"text-anchor\":C.anchor,\"text-offset\":C.offset}),i.extendFlat(A.paint,{\"text-color\":r.textfont.color,\"text-opacity\":r.opacity})}return M}},{\"../../components/colorscale\":605,\"../../components/drawing\":614,\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/geojson_utils\":714,\"../../plots/mapbox/convert_text_opts\":821,\"../scatter/make_bubble_size_func\":1128,\"../scatter/subtypes\":1135,\"fast-isnumeric\":225}],1173:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,i){return n.coerce(t,e,c,r,i)}if(function(t,e,r){var n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length);return e._length=a,a}(0,e,h)){if(h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),h(\"below\"),i.hasLines(e)&&(o(t,e,r,u,h,{noDash:!0}),h(\"connectgaps\")),i.hasMarkers(e)){a(t,e,r,u,h,{noLine:!0});var f=e.marker;\"circle\"!==f.symbol&&(n.isArrayOrTypedArray(f.size)&&(f.size=f.size[0]),n.isArrayOrTypedArray(f.color)&&(f.color=f.color[0]))}i.hasText(e)&&s(t,e,u,h,{noSelect:!0}),h(\"fill\"),\"none\"!==e.fill&&l(t,e,r,h),n.coerceSelectionMarkerOpacity(e,h)}else e.visible=!1}},{\"../../lib\":719,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1171}],1174:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t}},{}],1175:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\"),o=i.fillText,s=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,h=t.ya,f=t.subplot,p=360*(e>=0?Math.floor((e+180)/360):Math.ceil((e-180)/360)),d=e-p;if(n.getClosest(l,function(t){var e=t.lonlat;if(e[0]===s)return 1/0;var n=i.modHalf(e[0],360),a=e[1],o=f.project([n,a]),l=o.x-u.c2p([d,a]),c=o.y-h.c2p([n,r]),p=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(l*l+c*c)-p,1-3/p)},t),!1!==t.index){var g=l[t.index],v=g.lonlat,m=[i.modHalf(v[0],360)+p,v[1]],y=u.c2p(m),x=h.c2p(m),b=g.mrc||1;return t.x0=y-b,t.x1=y+b,t.y0=x-b,t.y1=x+b,t.color=a(c,g),t.extraText=function(t,e,r){if(t.hovertemplate)return;var n=(e.hi||t.hoverinfo).split(\"+\"),i=-1!==n.indexOf(\"all\"),a=-1!==n.indexOf(\"lon\"),s=-1!==n.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}i||a&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):a?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(i||-1!==n.indexOf(\"text\"))&&o(e,t,c);return c.join(\"<br>\")}(c,g,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},{\"../../components/fx\":632,\"../../constants/numerical\":695,\"../../lib\":719,\"../scatter/get_trace_color\":1121}],1176:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"../scattergeo/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.update(e)},moduleType:\"trace\",name:\"scattermapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"symbols\",\"showLegend\",\"scatterlike\"],meta:{}}},{\"../../plots/mapbox\":822,\"../scatter/marker_colorbar\":1129,\"../scattergeo/calc\":1152,\"./attributes\":1171,\"./defaults\":1173,\"./event_data\":1174,\"./hover\":1175,\"./plot\":1177,\"./select\":1178}],1177:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix,a=[\"fill\",\"line\",\"circle\",\"symbol\"];function o(t,e){this.subplot=t,this.uid=e,this.sourceIds={fill:\"source-\"+e+\"-fill\",line:\"source-\"+e+\"-line\",circle:\"source-\"+e+\"-circle\",symbol:\"source-\"+e+\"-symbol\"},this.layerIds={fill:i+e+\"-fill\",line:i+e+\"-line\",circle:i+e+\"-circle\",symbol:i+e+\"-symbol\"},this.below=null}var s=o.prototype;s.addSource=function(t,e){this.subplot.map.addSource(this.sourceIds[t],{type:\"geojson\",data:e.geojson})},s.setSourceData=function(t,e){this.subplot.map.getSource(this.sourceIds[t]).setData(e.geojson)},s.addLayer=function(t,e,r){this.subplot.addLayer({type:t,id:this.layerIds[t],source:this.sourceIds[t],layout:e.layout,paint:e.paint},r)},s.update=function(t){var e,r,i,o=this.subplot,s=o.map,l=n(t),c=o.belowLookup[\"trace-\"+this.uid];if(c!==this.below){for(e=a.length-1;e>=0;e--)r=a[e],s.removeLayer(this.layerIds[r]);for(e=0;e<a.length;e++)i=l[r=a[e]],this.addLayer(r,i,c);this.below=c}for(e=0;e<a.length;e++)i=l[r=a[e]],o.setOptions(this.layerIds[r],\"setLayoutProperty\",i.layout),\"visible\"===i.layout.visibility&&(this.setSourceData(r,i),o.setOptions(this.layerIds[r],\"setPaintProperty\",i.paint));t[0].trace._glTrace=this},s.dispose=function(){for(var t=this.subplot.map,e=a.length-1;e>=0;e--){var r=a[e];t.removeLayer(this.layerIds[r]),t.removeSource(this.sourceIds[r])}},e.exports=function(t,e){for(var r=e[0].trace,i=new o(t,r.uid),s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid],c=0;c<a.length;c++){var u=a[c],h=s[u];i.addSource(u,h),i.addLayer(u,h,l)}return e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":820,\"./convert\":1172}],1178:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,o=t.cd,s=t.xaxis,l=t.yaxis,c=[],u=o[0].trace;if(!i.hasMarkers(u))return[];if(!1===e)for(r=0;r<o.length;r++)o[r].selected=0;else for(r=0;r<o.length;r++){var h=o[r],f=h.lonlat;if(f[0]!==a){var p=[n.modHalf(f[0],360),f[1]],d=[s.c2p(p),l.c2p(p)];e.contains(d,null,r,t)?(c.push({pointNumber:r,lon:f[0],lat:f[1]}),h.selected=1):h.selected=0}}return c}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../scatter/subtypes\":1135}],1179:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../scatter/attributes\"),o=t(\"../../plots/attributes\"),s=a.line;e.exports={mode:a.mode,r:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},theta:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},r0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dr:{valType:\"number\",dflt:1,editType:\"calc\"},theta0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dtheta:{valType:\"number\",editType:\"calc\"},thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\",\"gradians\"],dflt:\"degrees\",editType:\"calc+clearAxisTypes\"},text:a.text,hovertext:a.hovertext,line:{color:s.color,width:s.width,dash:s.dash,shape:i({},s.shape,{values:[\"linear\",\"spline\"]}),smoothing:s.smoothing,editType:\"calc\"},connectgaps:a.connectgaps,marker:a.marker,cliponaxis:i({},a.cliponaxis,{dflt:!1}),textposition:a.textposition,textfont:a.textfont,fill:i({},a.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:a.fillcolor,hoverinfo:i({},o.hoverinfo,{flags:[\"r\",\"theta\",\"text\",\"name\"]}),hoveron:a.hoveron,hovertemplate:n(),selected:a.selected,unselected:a.unselected}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1180:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../plots/cartesian/axes\"),o=t(\"../scatter/colorscale_calc\"),s=t(\"../scatter/arrays_to_calcdata\"),l=t(\"../scatter/calc_selection\"),c=t(\"../scatter/calc\").calcMarkerSize;e.exports=function(t,e){for(var r=t._fullLayout,u=e.subplot,h=r[u].radialaxis,f=r[u].angularaxis,p=h.makeCalcdata(e,\"r\"),d=f.makeCalcdata(e,\"theta\"),g=e._length,v=new Array(g),m=0;m<g;m++){var y=p[m],x=d[m],b=v[m]={};n(y)&&n(x)?(b.r=y,b.theta=x):b.r=i}var _=c(e,g);return e._extremes.x=a.findExtremes(h,p,{ppad:_}),o(t,e),s(v,e),l(v,e),v}},{\"../../constants/numerical\":695,\"../../plots/cartesian/axes\":767,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc\":1113,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1181:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/line_shape_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,h=t(\"./attributes\");function f(t,e,r,n){var i,a=n(\"r\"),o=n(\"theta\");if(a)o?i=Math.min(a.length,o.length):(i=a.length,n(\"theta0\"),n(\"dtheta\"));else{if(!o)return 0;i=e.theta.length,n(\"r0\"),n(\"dr\")}return e._length=i,i}e.exports={handleRThetaDefaults:f,supplyDefaults:function(t,e,r,p){function d(r,i){return n.coerce(t,e,h,r,i)}var g=f(0,e,0,d);if(g){d(\"thetaunit\"),d(\"mode\",g<u?\"lines+markers\":\"lines\"),d(\"text\"),d(\"hovertext\"),\"fills\"!==e.hoveron&&d(\"hovertemplate\"),i.hasLines(e)&&(o(t,e,r,p,d),s(t,e,d),d(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,p,d,{gradient:!0}),i.hasText(e)&&l(t,e,p,d);var v=[];(i.hasMarkers(e)||i.hasText(e))&&(d(\"cliponaxis\"),d(\"marker.maxdisplayed\"),v.push(\"points\")),d(\"fill\"),\"none\"!==e.fill&&(c(t,e,r,d),i.hasLines(e)||s(t,e,d)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||v.push(\"fills\"),d(\"hoveron\",v.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/line_shape_defaults\":1126,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1179}],1182:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\");function o(t,e,r,n){var o=r.radialAxis,s=r.angularAxis;o._hovertitle=\"r\",s._hovertitle=\"\\u03b8\";var l=o.c2l(t.r);n.rLabel=i.tickText(o,l,\"hover\").text;var c=\"degrees\"===s.thetaunit?a.rad2deg(t.theta):t.theta;n.thetaLabel=i.tickText(s,c,\"hover\").text;var u=t.hi||e.hoverinfo,h=[];function f(t,e){h.push(t._hovertitle+\": \"+e)}if(!e.hovertemplate){var p=u.split(\"+\");-1!==p.indexOf(\"all\")&&(p=[\"r\",\"theta\",\"text\"]),-1!==p.indexOf(\"r\")&&f(o,n.rLabel),-1!==p.indexOf(\"theta\")&&f(s,n.thetaLabel),-1!==p.indexOf(\"text\")&&n.text&&(h.push(n.text),delete n.text),n.extraText=h.join(\"<br>\")}}e.exports={hoverPoints:function(t,e,r,i){var a=n(t,e,r,i);if(a&&!1!==a[0].index){var s=a[0];if(void 0===s.index)return a;var l=t.subplot,c=s.cd[s.index],u=s.trace;if(l.isPtInside(c))return s.xLabelVal=void 0,s.yLabelVal=void 0,o(c,u,l,s),s.hovertemplate=u.hovertemplate,a}},makeHoverPointText:o}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scatter/hover\":1122}],1183:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scatter/select\"),meta:{}}},{\"../../plots/polar\":831,\"../scatter/marker_colorbar\":1129,\"../scatter/select\":1132,\"../scatter/style\":1134,\"./attributes\":1179,\"./calc\":1180,\"./defaults\":1181,\"./hover\":1182,\"./plot\":1184}],1184:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){for(var a=e.layers.frontplot.select(\"g.scatterlayer\"),o={xaxis:e.xaxis,yaxis:e.yaxis,plot:e.framework,layerClipId:e._hasClipOnAxisFalse?e.clipIds.forTraces:null},s=e.radialAxis,l=e.angularAxis,c=0;c<r.length;c++)for(var u=r[c],h=0;h<u.length;h++){var f=u[h],p=f.r;if(p===i)f.x=f.y=i;else{var d=s.c2g(p),g=l.c2g(f.theta);f.x=d*Math.cos(g),f.y=d*Math.sin(g)}}n(t,o,r,a)}},{\"../../constants/numerical\":695,\"../scatter/plot\":1131}],1185:[function(t,e,r){\"use strict\";var n=t(\"../scatterpolar/attributes\"),i=t(\"../scattergl/attributes\");e.exports={mode:n.mode,r:n.r,theta:n.theta,r0:n.r0,dr:n.dr,theta0:n.theta0,dtheta:n.dtheta,thetaunit:n.thetaunit,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,line:i.line,connectgaps:i.connectgaps,marker:i.marker,fill:i.fill,fillcolor:i.fillcolor,textposition:i.textposition,textfont:i.textfont,hoverinfo:n.hoverinfo,selected:n.selected,unselected:n.unselected}},{\"../scattergl/attributes\":1160,\"../scatterpolar/attributes\":1179}],1186:[function(t,e,r){\"use strict\";var n=t(\"../scatter/colorscale_calc\"),i=t(\"../scatter/calc\").calcMarkerSize,a=t(\"../scattergl/convert\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r=t._fullLayout,l=e.subplot,c=r[l].radialaxis,u=r[l].angularaxis,h=c.makeCalcdata(e,\"r\"),f=u.makeCalcdata(e,\"theta\"),p=e._length,d={};p<h.length&&(h=h.slice(0,p)),p<f.length&&(f=f.slice(0,p)),d.r=h,d.theta=f,n(t,e);var g,v=d.opts=a.style(t,e);return p<s?g=i(e,p):v.marker&&(g=2*(v.marker.sizeAvg||Math.max(v.marker.size,3))),e._extremes.x=o.findExtremes(c,h,{ppad:g}),[{x:!1,y:!1,t:d,trace:e}]}},{\"../../plots/cartesian/axes\":767,\"../scatter/calc\":1113,\"../scatter/colorscale_calc\":1115,\"../scattergl/constants\":1162,\"../scattergl/convert\":1163}],1187:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatterpolar/defaults\").handleRThetaDefaults,o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}var d=a(t,e,f,p);d?(p(\"thetaunit\"),p(\"mode\",d<u?\"lines+markers\":\"lines\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),i.hasLines(e)&&(s(t,e,r,f,p),p(\"connectgaps\")),i.hasMarkers(e)&&o(t,e,r,f,p),i.hasText(e)&&l(t,e,f,p),p(\"fill\"),\"none\"!==e.fill&&c(t,e,r,p),n.coerceSelectionMarkerOpacity(e,p)):e.visible=!1}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"../scatterpolar/defaults\":1181,\"./attributes\":1185}],1188:[function(t,e,r){\"use strict\";var n=t(\"../scattergl/hover\"),i=t(\"../scatterpolar/hover\").makeHoverPointText;e.exports={hoverPoints:function(t,e,r,a){var o=t.cd[0].t,s=o.r,l=o.theta,c=n.hoverPoints(t,e,r,a);if(c&&!1!==c[0].index){var u=c[0];if(void 0===u.index)return c;var h=t.subplot,f=u.cd[u.index],p=u.trace;if(f.r=s[u.index],f.theta=l[u.index],h.isPtInside(f))return u.xLabelVal=void 0,u.yLabelVal=void 0,i(f,p,h,u),c}}}},{\"../scattergl/hover\":1166,\"../scatterpolar/hover\":1182}],1189:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolargl\",basePlotModule:t(\"../../plots/polar\"),categories:[\"gl\",\"regl\",\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scattergl/select\"),meta:{}}},{\"../../plots/polar\":831,\"../scatter/marker_colorbar\":1129,\"../scattergl/select\":1170,\"./attributes\":1185,\"./calc\":1186,\"./defaults\":1187,\"./hover\":1188,\"./plot\":1190}],1190:[function(t,e,r){\"use strict\";var n=t(\"point-cluster\"),i=t(\"fast-isnumeric\"),a=t(\"../scattergl/plot\"),o=t(\"../scattergl/scene_update\"),s=t(\"../scattergl/convert\"),l=t(\"../../lib\"),c=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e,r){if(r.length){var u=e.radialAxis,h=e.angularAxis,f=o(t,e);return r.forEach(function(r){if(r&&r[0]&&r[0].trace){var a,o=r[0],p=o.trace,d=o.t,g=p._length,v=d.r,m=d.theta,y=d.opts,x=v.slice(),b=m.slice();for(a=0;a<v.length;a++)e.isPtInside({r:v[a],theta:m[a]})||(x[a]=NaN,b[a]=NaN);var _=new Array(2*g),w=Array(g),k=Array(g);for(a=0;a<g;a++){var T,A,M=x[a];if(i(M)){var S=u.c2g(M),E=h.c2g(b[a],p.thetaunit);T=S*Math.cos(E),A=S*Math.sin(E)}else T=A=NaN;w[a]=_[2*a]=T,k[a]=_[2*a+1]=A}d.tree=n(_),y.marker&&g>=c&&(y.marker.cluster=d.tree),y.marker&&(y.markerSel.positions=y.markerUnsel.positions=y.marker.positions=_),y.line&&_.length>1&&l.extendFlat(y.line,s.linePositions(t,p,_)),y.text&&(l.extendFlat(y.text,{positions:_},s.textPosition(t,p,y.text,y.marker)),l.extendFlat(y.textSel,{positions:_},s.textPosition(t,p,y.text,y.markerSel)),l.extendFlat(y.textUnsel,{positions:_},s.textPosition(t,p,y.text,y.markerUnsel))),y.fill&&!f.fill2d&&(f.fill2d=!0),y.marker&&!f.scatter2d&&(f.scatter2d=!0),y.line&&!f.line2d&&(f.line2d=!0),y.text&&!f.glText&&(f.glText=!0),f.lineOptions.push(y.line),f.fillOptions.push(y.fill),f.markerOptions.push(y.marker),f.markerSelectedOptions.push(y.markerSel),f.markerUnselectedOptions.push(y.markerUnsel),f.textOptions.push(y.text),f.textSelectedOptions.push(y.textSel),f.textUnselectedOptions.push(y.textUnsel),f.selectBatch.push([]),f.unselectBatch.push([]),d.x=w,d.y=k,d.rawx=w,d.rawy=k,d.r=v,d.theta=m,d.positions=_,d._scene=f,d.index=f.count,f.count++}}),a(t,e,r)}}},{\"../../lib\":719,\"../scattergl/constants\":1162,\"../scattergl/convert\":1163,\"../scattergl/plot\":1168,\"../scattergl/scene_update\":1169,\"fast-isnumeric\":225,\"point-cluster\":469}],1191:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/drawing/attributes\").dash,l=t(\"../../lib/extend\").extendFlat,c=i.marker,u=i.line,h=c.line;e.exports={a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},c:{valType:\"data_array\",editType:\"calc\"},sum:{valType:\"number\",dflt:0,min:0,editType:\"calc\"},mode:l({},i.mode,{dflt:\"markers\"}),text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),line:{color:u.color,width:u.width,dash:s,shape:l({},u.shape,{values:[\"linear\",\"spline\"]}),smoothing:u.smoothing,editType:\"calc\"},connectgaps:i.connectgaps,cliponaxis:i.cliponaxis,fill:l({},i.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:i.fillcolor,marker:l({symbol:c.symbol,opacity:c.opacity,maxdisplayed:c.maxdisplayed,size:c.size,sizeref:c.sizeref,sizemin:c.sizemin,sizemode:c.sizemode,line:l({width:h.width,editType:\"calc\"},o(\"marker.line\")),gradient:c.gradient,editType:\"calc\"},o(\"marker\")),textfont:i.textfont,textposition:i.textposition,selected:i.selected,unselected:i.unselected,hoverinfo:l({},a.hoverinfo,{flags:[\"a\",\"b\",\"c\",\"text\",\"name\"]}),hoveron:i.hoveron,hovertemplate:n()}},{\"../../components/colorscale/attributes\":600,\"../../components/drawing/attributes\":613,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1192:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=[\"a\",\"b\",\"c\"],c={a:[\"b\",\"c\"],b:[\"a\",\"c\"],c:[\"a\",\"b\"]};e.exports=function(t,e){var r,u,h,f,p,d,g=t._fullLayout[e.subplot].sum,v=e.sum||g,m={a:e.a,b:e.b,c:e.c};for(r=0;r<l.length;r++)if(!m[h=l[r]]){for(p=m[c[h][0]],d=m[c[h][1]],f=new Array(p.length),u=0;u<p.length;u++)f[u]=v-p[u]-d[u];m[h]=f}var y,x,b,_,w,k,T=e._length,A=new Array(T);for(r=0;r<T;r++)y=m.a[r],x=m.b[r],b=m.c[r],n(y)&&n(x)&&n(b)?(1!==(_=g/((y=+y)+(x=+x)+(b=+b)))&&(y*=_,x*=_,b*=_),k=y,w=b-x,A[r]={x:w,y:k,a:y,b:x,c:b}):A[r]={x:!1,y:!1};return s(e,T),i(t,e),a(A,e),o(A,e),A}},{\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc\":1113,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1193:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}var d,g=p(\"a\"),v=p(\"b\"),m=p(\"c\");if(g?(d=g.length,v?(d=Math.min(d,v.length),m&&(d=Math.min(d,m.length))):d=m?Math.min(d,m.length):0):v&&m&&(d=Math.min(v.length,m.length)),d){e._length=d,p(\"sum\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),p(\"mode\",d<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,f,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,f,p,{gradient:!0}),a.hasText(e)&&c(t,e,f,p);var y=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"cliponaxis\"),p(\"marker.maxdisplayed\"),y.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||y.push(\"fills\"),p(\"hoveron\",y.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/line_shape_defaults\":1126,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1191}],1194:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),n[i]){var a=n[i];t.a=a.a,t.b=a.b,t.c=a.c}else t.a=e.a,t.b=e.b,t.c=e.c;return t}},{}],1195:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,h=c-u;return s.x0=Math.max(Math.min(s.x0,h),u),s.x1=Math.max(Math.min(s.x1,h),u),o}var f=s.cd[s.index];s.a=f.a,s.b=f.b,s.c=f.c,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.subplot;s.aLabel=i.tickText(p.aaxis,f.a,\"hover\").text,s.bLabel=i.tickText(p.baxis,f.b,\"hover\").text,s.cLabel=i.tickText(p.caxis,f.c,\"hover\").text;var d=s.trace,g=f.hi||d.hoverinfo,v=[];if(!d.hovertemplate){var m=g.split(\"+\");-1!==m.indexOf(\"all\")&&(m=[\"a\",\"b\",\"c\"]),-1!==m.indexOf(\"a\")&&y(p.aaxis,s.aLabel),-1!==m.indexOf(\"b\")&&y(p.baxis,s.bLabel),-1!==m.indexOf(\"c\")&&y(p.caxis,s.cLabel)}return s.extraText=v.join(\"<br>\"),s.hovertemplate=d.hovertemplate,o}function y(t,e){v.push(t._hovertitle+\": \"+e)}}},{\"../../plots/cartesian/axes\":767,\"../scatter/hover\":1122}],1196:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scatterternary\",basePlotModule:t(\"../../plots/ternary\"),categories:[\"ternary\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/ternary\":843,\"../scatter/marker_colorbar\":1129,\"../scatter/select\":1132,\"../scatter/style\":1134,\"./attributes\":1191,\"./calc\":1192,\"./defaults\":1193,\"./event_data\":1194,\"./hover\":1195,\"./plot\":1197}],1197:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\");e.exports=function(t,e,r){var i=e.plotContainer;i.select(\".scatterlayer\").selectAll(\"*\").remove();var a={xaxis:e.xaxis,yaxis:e.yaxis,plot:i,layerClipId:e._hasClipOnAxisFalse?e.clipIdRelative:null},o=e.layers.frontplot.select(\"g.scatterlayer\");n(t,a,r,o)}},{\"../scatter/plot\":1131}],1198:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../scattergl/attributes\"),s=t(\"../../plots/cartesian/constants\").idRegex,l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"../../lib/extend\").extendFlat,u=n.marker,h=u.line,f=c(i(\"marker.line\",{editTypeOverride:\"calc\"}),{width:c({},h.width,{editType:\"calc\"}),editType:\"calc\"}),p=c(i(\"marker\"),{symbol:u.symbol,size:c({},u.size,{editType:\"markerSize\"}),sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:f,editType:\"calc\"});function d(t){return{valType:\"info_array\",freeLength:!0,editType:\"calc\",items:{valType:\"subplotid\",regex:s[t],editType:\"plot\"}}}p.color.editType=p.cmin.editType=p.cmax.editType=\"style\",e.exports={dimensions:l(\"dimension\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},label:{valType:\"string\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},axis:{type:{valType:\"enumerated\",values:[\"linear\",\"log\",\"date\",\"category\"],editType:\"calc+clearAxisTypes\"},matches:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc+clearAxisTypes\"},editType:\"calc+clearAxisTypes\"}),text:c({},o.text,{}),hovertext:c({},o.hovertext,{}),hovertemplate:a(),marker:p,xaxes:d(\"x\"),yaxes:d(\"y\"),diagonal:{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},showupperhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},showlowerhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},selected:{marker:o.selected.marker,editType:\"calc\"},unselected:{marker:o.unselected.marker,editType:\"calc\"},opacity:o.opacity}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773,\"../scatter/attributes\":1112,\"../scattergl/attributes\":1160}],1199:[function(t,e,r){\"use strict\";var n=t(\"regl-line2d\"),i=t(\"../../registry\"),a=t(\"../../lib/prepare_regl\"),o=t(\"../../plots/get_data\").getModuleCalcData,s=t(\"../../plots/cartesian\"),l=t(\"../../plots/cartesian/axis_ids\").getFromId,c=t(\"../../plots/cartesian/axes\").shouldShowZeroLine,u=\"splom\";function h(t,e,r){for(var n=r.matrixOptions.data.length,i=e._visibleDims,a=r.viewOpts.ranges=new Array(n),o=0;o<i.length;o++){var s=i[o],c=a[o]=new Array(4),u=l(t,e._diag[s][0]);u&&(c[0]=u.r2l(u.range[0]),c[2]=u.r2l(u.range[1]));var h=l(t,e._diag[s][1]);h&&(c[1]=h.r2l(h.range[0]),c[3]=h.r2l(h.range[1]))}r.selectBatch.length||r.unselectBatch.length?r.matrix.update({ranges:a},{ranges:a}):r.matrix.update({ranges:a})}function f(t){var e=t._fullLayout,r=e._glcanvas.data()[0].regl,i=e._splomGrid;i||(i=e._splomGrid=n(r)),i.update(function(t){var e,r=t._fullLayout,n=r._size,i=[0,0,r.width,r.height],a={};function o(t,e,r,n,o,s){var l=e[t+\"color\"],c=e[t+\"width\"],u=String(l+c);u in a?a[u].data.push(NaN,NaN,r,n,o,s):a[u]={data:[r,n,o,s],join:\"rect\",thickness:c,color:l,viewport:i,range:i,overlay:!1}}for(e in r._splomSubplots){var s,l,u=r._plots[e],h=u.xaxis,f=u.yaxis,p=h._vals,d=f._vals,g=n.b+f.domain[0]*n.h,v=-f._m,m=-v*f.r2l(f.range[0],f.calendar);if(h.showgrid)for(e=0;e<p.length;e++)s=h._offset+h.l2p(p[e].x),o(\"grid\",h,s,g,s,g+f._length);if(f.showgrid)for(e=0;e<d.length;e++)l=g+m+v*d[e].x,o(\"grid\",f,h._offset,l,h._offset+h._length,l);c(t,h,f)&&(s=h._offset+h.l2p(0),o(\"zeroline\",h,s,g,s,g+f._length)),c(t,f,h)&&(l=g+m+0,o(\"zeroline\",f,h._offset,l,h._offset+h._length,l))}var y=[];for(e in a)y.push(a[e]);return y}(t))}e.exports={name:u,attr:s.attr,attrRegex:s.attrRegex,layoutAttributes:s.layoutAttributes,supplyLayoutDefaults:s.supplyLayoutDefaults,drawFramework:s.drawFramework,plot:function(t){var e=t._fullLayout,r=i.getModule(u),n=o(t.calcdata,r)[0];a(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])&&(e._hasOnlyLargeSploms&&f(t),r.plot(t,{},n))},drag:function(t){var e=t.calcdata,r=t._fullLayout;r._hasOnlyLargeSploms&&f(t);for(var n=0;n<e.length;n++){var i=e[n][0].trace,a=r._splomScenes[i.uid];\"splom\"===i.type&&a&&a.matrix&&h(t,i,a)}},updateGrid:f,clean:function(t,e,r,n){var i,a={};if(n._splomScenes){for(i=0;i<t.length;i++){var o=t[i];\"splom\"===o.type&&(a[o.uid]=1)}for(i=0;i<r.length;i++){var l=r[i];if(!a[l.uid]){var c=n._splomScenes[l.uid];c&&c.destroy&&c.destroy(),n._splomScenes[l.uid]=null,delete n._splomScenes[l.uid]}}}0===Object.keys(n._splomScenes||{}).length&&delete n._splomScenes,n._splomGrid&&!e._hasOnlyLargeSploms&&n._hasOnlyLargeSploms&&(n._splomGrid.destroy(),n._splomGrid=null,delete n._splomGrid),s.clean(t,e,r,n)},updateFx:s.updateFx,toSVG:s.toSVG}},{\"../../lib/prepare_regl\":732,\"../../plots/cartesian\":778,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_ids\":770,\"../../plots/get_data\":802,\"../../registry\":847,\"regl-line2d\":491}],1200:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../scatter/calc\").calcMarkerSize,o=t(\"../scatter/calc\").calcAxisExpansion,s=t(\"../scatter/colorscale_calc\"),l=t(\"../scattergl/convert\").markerSelection,c=t(\"../scattergl/convert\").markerStyle,u=t(\"./scene_update\"),h=t(\"../../constants/numerical\").BADNUM,f=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r,p,d,g,v,m,y=e.dimensions,x=e._length,b={},_=b.cdata=[],w=b.data=[],k=e._visibleDims=[];function T(t,r){for(var i=t.makeCalcdata({v:r.values,vcalendar:e.calendar},\"v\"),a=0;a<i.length;a++)i[a]=i[a]===h?NaN:i[a];_.push(i),w.push(\"log\"===t.type?n.simpleMap(i,t.c2l):i)}for(r=0;r<y.length;r++)if((d=y[r]).visible){if(g=i.getFromId(t,e._diag[r][0]),v=i.getFromId(t,e._diag[r][1]),g&&v&&g.type!==v.type){n.log(\"Skipping splom dimension \"+r+\" with conflicting axis types\");continue}g?(T(g,d),v&&\"category\"===v.type&&(v._categories=g._categories.slice())):T(v,d),k.push(r)}for(s(t,e),n.extendFlat(b,c(e)),m=_.length*x>f?2*(b.sizeAvg||Math.max(b.size,3)):a(e,x),p=0;p<k.length;p++)d=y[r=k[p]],g=i.getFromId(t,e._diag[r][0])||{},v=i.getFromId(t,e._diag[r][1])||{},o(t,e,g,v,_[p],_[p],m);var A=u(t,e);return A.matrix||(A.matrix=!0),A.matrixOptions=b,A.selectedOptions=l(e,e.selected),A.unselectedOptions=l(e,e.unselected),[{x:!1,y:!1,t:{},trace:e}]}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../scatter/calc\":1113,\"../scatter/colorscale_calc\":1115,\"../scattergl/constants\":1162,\"../scattergl/convert\":1163,\"./scene_update\":1207}],1201:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"../scatter/subtypes\"),s=t(\"../scatter/marker_defaults\"),l=t(\"../parcoords/merge_length\"),c=/-open/;function u(t,e){function r(r,i){return n.coerce(t,e,a.dimensions,r,i)}r(\"label\");var i=r(\"values\");i&&i.length?r(\"visible\"):e.visible=!1,r(\"axis.type\"),r(\"axis.matches\")}e.exports=function(t,e,r,h){function f(r,i){return n.coerce(t,e,a,r,i)}var p=i(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=f(\"diagonal.visible\"),g=f(\"showupperhalf\"),v=f(\"showlowerhalf\");if(l(e,p,\"values\")&&(d||g||v)){f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),s(t,e,r,h,f);var m=c.test(e.marker.symbol),y=o.isBubble(e);f(\"marker.line.width\",m||y?1:0),function(t,e,r,n){var i,a,o=e.dimensions,s=o.length,l=e.showupperhalf,c=e.showlowerhalf,u=e.diagonal.visible,h=new Array(s),f=new Array(s);for(i=0;i<s;i++){var p=i?i+1:\"\";h[i]=\"x\"+p,f[i]=\"y\"+p}var d=n(\"xaxes\",h),g=n(\"yaxes\",f),v=e._diag=new Array(s);e._xaxes={},e._yaxes={};var m=[],y=[];function x(t,n,i,a){if(t){var o=t.charAt(0),s=r._splomAxes[o];if(e[\"_\"+o+\"axes\"][t]=1,a.push(t),!(t in s)){var l=s[t]={};i&&(l.label=i.label||\"\",i.visible&&i.axis&&(i.axis.type&&(l.type=i.axis.type),i.axis.matches&&(l.matches=n)))}}}var b=!u&&!c,_=!u&&!l;for(e._axesDim={},i=0;i<s;i++){var w=o[i],k=0===i,T=i===s-1,A=k&&b||T&&_?void 0:d[i],M=k&&_||T&&b?void 0:g[i];x(A,M,w,m),x(M,A,w,y),v[i]=[A,M],e._axesDim[A]=i,e._axesDim[M]=i}for(i=0;i<m.length;i++)for(a=0;a<y.length;a++){var S=m[i]+y[a];i>a&&l?r._splomSubplots[S]=1:i<a&&c?r._splomSubplots[S]=1:i!==a||!u&&c&&l||(r._splomSubplots[S]=1)}(!c||!u&&l&&c)&&(r._splomGridDflt.xside=\"bottom\",r._splomGridDflt.yside=\"left\")}(0,e,h,f),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../parcoords/merge_length\":1083,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"./attributes\":1198}],1202:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scattergl/convert\").markerStyle;e.exports=function(t,e){var r=e.trace,o=t._fullLayout._splomScenes[r.uid];if(o){i(t,r),n.extendFlat(o.matrixOptions,a(r));var s=n.extendFlat({},o.matrixOptions,o.viewOpts);o.matrix.update(s,null)}}},{\"../../lib\":719,\"../scatter/colorscale_calc\":1115,\"../scattergl/convert\":1163}],1203:[function(t,e,r){\"use strict\";r.getDimIndex=function(t,e){for(var r=e._id,n={x:0,y:1}[r.charAt(0)],i=t._visibleDims,a=0;a<i.length;a++){var o=i[a];if(t._diag[o][n]===r)return a}return!1}},{}],1204:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i=t(\"../scattergl/hover\").calcHover;e.exports={hoverPoints:function(t,e,r){var a=t.cd[0].trace,o=t.scene.matrixOptions.cdata,s=t.xa,l=t.ya,c=s.c2p(e),u=l.c2p(r),h=t.distance,f=n.getDimIndex(a,s),p=n.getDimIndex(a,l);if(!1===f||!1===p)return[t];for(var d,g,v=o[f],m=o[p],y=h,x=0;x<v.length;x++){var b=v[x],_=m[x],w=s.c2p(b)-c,k=l.c2p(_)-u,T=Math.sqrt(w*w+k*k);T<y&&(y=g=T,d=x)}return t.index=d,t.distance=y,t.dxy=g,void 0===d?[t]:(i(t,v,m,a),[t])}}},{\"../scattergl/hover\":1166,\"./helpers\":1203}],1205:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../components/grid\");e.exports={moduleType:\"trace\",name:\"splom\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\"),editStyle:t(\"./edit_style\"),meta:{}},n.register(i)},{\"../../components/grid\":636,\"../../registry\":847,\"../scatter/marker_colorbar\":1129,\"./attributes\":1198,\"./base_plot\":1199,\"./calc\":1200,\"./defaults\":1201,\"./edit_style\":1202,\"./hover\":1204,\"./plot\":1206,\"./select\":1208}],1206:[function(t,e,r){\"use strict\";var n=t(\"regl-splom\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\");function o(t,e){var r,o,s,l,c,u=t._fullLayout,h=u._size,f=e.trace,p=e.t,d=u._splomScenes[f.uid],g=d.matrixOptions,v=g.cdata,m=u._glcanvas.data()[0].regl,y=u.dragmode;if(0!==v.length){g.lower=f.showupperhalf,g.upper=f.showlowerhalf,g.diagonal=f.diagonal.visible;var x=f._visibleDims,b=v.length,_=d.viewOpts={};for(_.ranges=new Array(b),_.domains=new Array(b),c=0;c<x.length;c++){s=x[c];var w=_.ranges[c]=new Array(4),k=_.domains[c]=new Array(4);(r=a.getFromId(t,f._diag[s][0]))&&(w[0]=r._rl[0],w[2]=r._rl[1],k[0]=r.domain[0],k[2]=r.domain[1]),(o=a.getFromId(t,f._diag[s][1]))&&(w[1]=o._rl[0],w[3]=o._rl[1],k[1]=o.domain[0],k[3]=o.domain[1])}_.viewport=[h.l,h.b,h.w+h.l,h.h+h.b],!0===d.matrix&&(d.matrix=n(m));var T=u.clickmode.indexOf(\"select\")>-1,A=!0;if(\"lasso\"===y||\"select\"===y||!!f.selectedpoints||T){var M=f._length;if(f.selectedpoints){d.selectBatch=f.selectedpoints;var S=f.selectedpoints,E={};for(s=0;s<S.length;s++)E[S[s]]=!0;var C=[];for(s=0;s<M;s++)E[s]||C.push(s);d.unselectBatch=C}var L=p.xpx=new Array(b),P=p.ypx=new Array(b);for(c=0;c<x.length;c++){if(s=x[c],r=a.getFromId(t,f._diag[s][0]))for(L[c]=new Array(M),l=0;l<M;l++)L[c][l]=r.c2p(v[c][l]);if(o=a.getFromId(t,f._diag[s][1]))for(P[c]=new Array(M),l=0;l<M;l++)P[c][l]=o.c2p(v[c][l])}if(d.selectBatch.length||d.unselectBatch.length){var O=i.extendFlat({},g,d.unselectedOptions,_),z=i.extendFlat({},g,d.selectedOptions,_);d.matrix.update(O,z),A=!1}}else p.xpx=p.ypx=null;if(A){var I=i.extendFlat({},g,_);d.matrix.update(I,null)}}}e.exports=function(t,e,r){if(r.length)for(var n=0;n<r.length;n++)o(t,r[n][0])}},{\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"regl-splom\":501}],1207:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t._fullLayout,i=e.uid,a=r._splomScenes;a||(a=r._splomScenes={});var o={dirty:!0},s=a[e.uid];return s||((s=a[i]=n.extendFlat({},o,{matrix:!1,selectBatch:[],unselectBatch:[]})).draw=function(){s.matrix&&s.matrix.draw&&(s.selectBatch.length||s.unselectBatch.length?s.matrix.draw(s.unselectBatch,s.selectBatch):s.matrix.draw()),s.dirty=!1},s.destroy=function(){s.matrix&&s.matrix.destroy&&s.matrix.destroy(),s.matrixOptions=null,s.selectBatch=null,s.unselectBatch=null,s=null}),s.dirty||n.extendFlat(s,o),s}},{\"../../lib\":719}],1208:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"./helpers\");e.exports=function(t,e){var r=t.cd,o=r[0].trace,s=r[0].t,l=t.scene,c=l.matrixOptions.cdata,u=t.xaxis,h=t.yaxis,f=[];if(!l)return f;var p=!i.hasMarkers(o)&&!i.hasText(o);if(!0!==o.visible||p)return f;var d=a.getDimIndex(o,u),g=a.getDimIndex(o,h);if(!1===d||!1===g)return f;var v=s.xpx[d],m=s.ypx[g],y=c[d],x=c[g],b=[],_=[];if(!1!==e&&!e.degenerate)for(var w=0;w<y.length;w++)e.contains([v[w],m[w]],null,w,t)?(b.push(w),f.push({pointNumber:w,x:y[w],y:x[w]})):_.push(w);var k=l.matrixOptions;return b.length||_.length?l.selectBatch.length||l.unselectBatch.length||l.matrix.update(l.unselectedOptions,n.extendFlat({},k,l.selectedOptions,l.viewOpts)):l.matrix.update(k,null),l.selectBatch=b,l.unselectBatch=_,f}},{\"../../lib\":719,\"../scatter/subtypes\":1135,\"./helpers\":1203}],1209:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},starts:{x:{valType:\"data_array\",editType:\"calc\"},y:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},maxdisplayed:{valType:\"integer\",min:0,dflt:1e3,editType:\"calc\"},sizeref:{valType:\"number\",editType:\"calc\",min:0,dflt:1},text:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:i({editType:\"calc\"},{keys:[\"tubex\",\"tubey\",\"tubez\",\"tubeu\",\"tubev\",\"tubew\",\"norm\",\"divergence\"]})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach(function(t){l[t]=a[t]}),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"divergence\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../mesh3d/attributes\":1053}],1210:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){var r,i,a,o,s=e.u,l=e.v,c=e.w,u=e.x,h=e.y,f=e.z,p=Math.min(u.length,h.length,f.length,s.length,l.length,c.length),d=0;e.starts&&(i=e.starts.x||[],a=e.starts.y||[],o=e.starts.z||[],d=Math.min(i.length,a.length,o.length));var g=0,v=1/0;for(r=0;r<p;r++){var m=s[r],y=l[r],x=c[r],b=Math.sqrt(m*m+y*y+x*x);g=Math.max(g,b),v=Math.min(v,b)}n(t,e,{vals:[v,g],containerStr:\"\",cLetter:\"c\"});var _=-1/0,w=1/0,k=-1/0,T=1/0,A=-1/0,M=1/0;for(r=0;r<p;r++){var S=u[r];_=Math.max(_,S),w=Math.min(w,S);var E=h[r];k=Math.max(k,E),T=Math.min(T,E);var C=f[r];A=Math.max(A,C),M=Math.min(M,C)}for(r=0;r<d;r++){var L=i[r];_=Math.max(_,L),w=Math.min(w,L);var P=a[r];k=Math.max(k,P),T=Math.min(T,P);var O=o[r];A=Math.max(A,O),M=Math.min(M,O)}e._len=p,e._slen=d,e._normMax=g,e._xbnds=[w,_],e._ybnds=[T,k],e._zbnds=[M,A]}},{\"../../components/colorscale/calc\":601}],1211:[function(t,e,r){\"use strict\";var n=t(\"gl-streamtube3d\"),i=n.createTubeMesh,a=t(\"../../lib\"),o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\"),c={xaxis:0,yaxis:1,zaxis:2};function u(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var h=u.prototype;function f(t){return a.distinctVals(t).vals}function p(t){var e=t.length;return e>2?t.slice(1,e-1):2===e?[(t[0]+t[1])/2]:t}function d(t){var e=t.length;return 1===e?[.5,.5]:[t[1]-t[0],t[e-1]-t[e-2]]}function g(t,e){var r=t.fullSceneLayout,i=t.dataScale,u=e._len,h={};function g(t,e){var n=r[e],o=i[c[e]];return a.simpleMap(t,function(t){return n.d2l(t)*o})}h.vectors=l(g(e.u,\"xaxis\"),g(e.v,\"yaxis\"),g(e.w,\"zaxis\"),u);var v=f(e.x.slice(0,u)),m=f(e.y.slice(0,u)),y=f(e.z.slice(0,u));if(v.length*m.length*y.length>u)return{positions:[],cells:[]};var x=g(v,\"xaxis\"),b=g(m,\"yaxis\"),_=g(y,\"zaxis\");if(h.meshgrid=[x,b,_],e.starts){var w=e._slen;h.startingPositions=l(g(e.starts.x.slice(0,w),\"xaxis\"),g(e.starts.y.slice(0,w),\"yaxis\"),g(e.starts.z.slice(0,w),\"zaxis\"))}else{for(var k=b[0],T=p(x),A=p(_),M=new Array(T.length*A.length),S=0,E=0;E<T.length;E++)for(var C=0;C<A.length;C++)M[S++]=[T[E],k,A[C]];h.startingPositions=M}h.colormap=o(e),h.tubeSize=e.sizeref,h.maxLength=e.maxdisplayed;var L=g(e._xbnds,\"xaxis\"),P=g(e._ybnds,\"yaxis\"),O=g(e._zbnds,\"zaxis\"),z=d(x),I=d(b),D=d(_),R=[[L[0]-z[0],P[0]-I[0],O[0]-D[0]],[L[1]+z[1],P[1]+I[1],O[1]+D[1]]],F=n(h,R),B=s(e);F.vertexIntensityBounds=[B.min/e._normMax,B.max/e._normMax];var N=e.lightposition;return F.lightPosition=[N.x,N.y,N.z],F.ambient=e.lighting.ambient,F.diffuse=e.lighting.diffuse,F.specular=e.lighting.specular,F.roughness=e.lighting.roughness,F.fresnel=e.lighting.fresnel,F.opacity=e.opacity,e._pad=F.tubeScale*e.sizeref*2,F}h.handlePick=function(t){var e=this.scene.fullSceneLayout,r=this.scene.dataScale;function n(t,n){var i=e[n],a=r[c[n]];return i.l2c(t)/a}if(t.object===this.mesh){var i=t.data.position,a=t.data.velocity;return t.traceCoordinate=[n(i[0],\"xaxis\"),n(i[1],\"yaxis\"),n(i[2],\"zaxis\"),n(a[0],\"xaxis\"),n(a[1],\"yaxis\"),n(a[2],\"zaxis\"),t.data.intensity*this.data._normMax,t.data.divergence],t.textLabel=this.data.hovertext||this.data.text,!0}},h.update=function(t){this.data=t;var e=g(this.scene,t);this.mesh.update(e)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=g(t,e),a=i(r,n),o=new u(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../plots/gl3d/zip3\":818,\"gl-streamtube3d\":313}],1212:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),h=s(\"x\"),f=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length&&p&&p.length?(s(\"starts.x\"),s(\"starts.y\"),s(\"starts.z\"),s(\"maxdisplayed\"),s(\"sizeref\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":1209}],1213:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"streamtube\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),eventData:function(t,e){return t.tubex=t.x,t.tubey=t.y,t.tubez=t.z,t.tubeu=e.traceCoordinate[3],t.tubev=e.traceCoordinate[4],t.tubew=e.traceCoordinate[5],t.norm=e.traceCoordinate[6],t.divergence=e.traceCoordinate[7],delete t.x,delete t.y,delete t.z,t},meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1209,\"./calc\":1210,\"./convert\":1211,\"./defaults\":1212}],1214:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../plots/domain\").attributes,o=t(\"../pie/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports={labels:{valType:\"data_array\",editType:\"calc\"},parents:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},branchvalues:{valType:\"enumerated\",values:[\"remainder\",\"total\"],dflt:\"remainder\",editType:\"calc\"},level:{valType:\"any\",editType:\"plot\",anim:!0},maxdepth:{valType:\"integer\",editType:\"plot\",dflt:-1},marker:{colors:{valType:\"data_array\",editType:\"calc\"},line:{color:s({},o.marker.line.color,{dflt:null}),width:s({},o.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},leaf:{opacity:{valType:\"number\",editType:\"style\",min:0,max:1,dflt:.7},editType:\"plot\"},text:o.text,textinfo:s({},o.textinfo,{editType:\"plot\",flags:[\"label\",\"text\",\"value\"]}),textfont:o.textfont,hovertext:o.hovertext,hoverinfo:s({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"name\"]}),hovertemplate:i(),insidetextfont:o.insidetextfont,outsidetextfont:o.outsidetextfont,domain:a({name:\"sunburst\",trace:!0,editType:\"calc\"})}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../pie/attributes\":1086}],1215:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=r.name=\"sunburst\";r.plot=function(t,e,r,o){var s=n.getModule(a),l=i(t.calcdata,s)[0];s.plot(t,l,r,o)},r.clean=function(t,e,r,n){var i=n._has&&n._has(a),o=e._has&&e._has(a);i&&!o&&n._sunburstlayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],1216:[function(t,e,r){\"use strict\";var n=t(\"d3-hierarchy\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../pie/calc\").makePullColorFn,s=t(\"../pie/calc\").generateExtendedColors,l=a.isArrayOrTypedArray,c={};r.calc=function(t,e){var r,s,c,u,h,f,p=t._fullLayout,d=e.ids,g=l(d),v=e.labels,m=e.parents,y=e.values,x=l(y),b=[],_={},w={},k=function(t){return t||\"number\"==typeof t},T=function(t){return!x||i(y[t])&&y[t]>=0};g?(r=Math.min(d.length,m.length),s=function(t){return k(d[t])&&T(t)},c=function(t){return String(d[t])}):(r=Math.min(v.length,m.length),s=function(t){return k(v[t])&&T(t)},c=function(t){return String(v[t])}),x&&(r=Math.min(r,y.length));for(var A=0;A<r;A++)if(s(A)){var M=c(A),S=k(m[A])?String(m[A]):\"\",E={i:A,id:M,pid:S,label:k(v[A])?String(v[A]):\"\"};x&&(E.v=+y[A]),b.push(E),h=M,_[u=S]?_[u].push(h):_[u]=[h],w[h]=1}if(_[\"\"]){if(_[\"\"].length>1){for(var C=a.randstr(),L=0;L<b.length;L++)\"\"===b[L].pid&&(b[L].pid=C);b.unshift({hasMultipleRoots:!0,id:C,pid:\"\"})}}else{var P,O=[];for(P in _)w[P]||O.push(P);if(1!==O.length)return a.warn(\"Multiple implied roots, cannot build sunburst hierarchy.\");P=O[0],b.unshift({id:P,pid:\"\",label:P})}try{f=n.stratify().id(function(t){return t.id}).parentId(function(t){return t.pid})(b)}catch(t){return a.warn(\"Failed to build sunburst hierarchy. Error: \"+t.message)}var z=n.hierarchy(f),I=!1;if(x)switch(e.branchvalues){case\"remainder\":z.sum(function(t){return t.data.v});break;case\"total\":z.each(function(t){var e=t.data.data.v;if(t.children&&e<t.children.reduce(function(t,e){return t+e.data.data.v},0))return I=!0,a.warn([\"Total value for node\",t.data.data.id,\"is smaller than the sum of its children.\"].join(\" \"));t.value=e})}else z.count();if(!I){z.sort(function(t,e){return e.value-t.value});var D=e.marker.colors||[],R=o(p._sunburstcolormap);return z.each(function(t){var e=t.data.data,r=e.id;e.color=R(D[e.i],r)}),b[0].hierarchy=z,b}},r.crossTraceCalc=function(t){var e=t._fullLayout,r=t.calcdata,n=e.sunburstcolorway,i=e._sunburstcolormap;e.extendsunburstcolors&&(n=s(n,c));var a=0;function o(t){var e=t.data.data,r=e.id;!1===e.color&&(i[r]?e.color=i[r]:t.parent?t.parent.parent?e.color=t.parent.data.data.color:(i[r]=e.color=n[a%n.length],a++):e.color=\"rgba(0,0,0,0)\")}for(var l=0;l<r.length;l++){var u=r[l][0];\"sunburst\"===u.trace.type&&u.hierarchy&&u.hierarchy.each(o)}}},{\"../../lib\":719,\"../pie/calc\":1088,\"d3-hierarchy\":157,\"fast-isnumeric\":225}],1217:[function(t,e,r){\"use strict\";e.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:\"linear\"}},{}],1218:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}var c=l(\"labels\"),u=l(\"parents\");if(c&&c.length&&u&&u.length){var h=l(\"values\");h&&h.length&&l(\"branchvalues\"),l(\"level\"),l(\"maxdepth\"),l(\"marker.line.width\")&&l(\"marker.line.color\",s.paper_bgcolor),l(\"marker.colors\"),l(\"leaf.opacity\");var f=l(\"text\");l(\"textinfo\",Array.isArray(f)?\"text+label\":\"label\"),l(\"hovertext\"),l(\"hovertemplate\");o(t,e,s,l,\"auto\",{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),a(e,s,l),e._length=null}else e.visible=!1}},{\"../../lib\":719,\"../../plots/domain\":792,\"../bar/defaults\":861,\"./attributes\":1214}],1219:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"sunburst\",basePlotModule:t(\"./base_plot\"),categories:[],animatable:!0,attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\").style,meta:{}}},{\"./attributes\":1214,\"./base_plot\":1215,\"./calc\":1216,\"./defaults\":1218,\"./layout_attributes\":1220,\"./layout_defaults\":1221,\"./plot\":1222,\"./style\":1223}],1220:[function(t,e,r){\"use strict\";e.exports={sunburstcolorway:{valType:\"colorlist\",editType:\"calc\"},extendsunburstcolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1221:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"sunburstcolorway\",e.colorway),r(\"extendsunburstcolors\")}},{\"../../lib\":719,\"./layout_attributes\":1220}],1222:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"d3-hierarchy\"),a=t(\"../../registry\"),o=t(\"../../components/fx\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../lib\"),u=t(\"../../lib/events\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"../../lib/setcursor\"),p=t(\"../../components/fx/helpers\").appendArrayPointValue,d=t(\"../pie/plot\").transformInsideText,g=t(\"../pie/helpers\").formatPieValue,v=t(\"./style\").styleOne,m=t(\"./constants\");function y(t,e,r,a){var o=t._fullLayout,u=a&&a.duration>0,f=n.select(r).selectAll(\"g.slice\"),p=e[0],m=p.trace,y=x(p.hierarchy,m.level),w=m.maxdepth>=0?m.maxdepth:1/0,M=o._size,S=m.domain,E=M.w*(S.x[1]-S.x[0]),C=M.h*(S.y[1]-S.y[0]),L=.5*Math.min(E,C),P=p.cx=M.l+M.w*(S.x[1]+S.x[0])/2,O=p.cy=M.t+M.h*(1-S.y[0])-C/2;if(!y)return f.remove();var z=null,I={};u&&f.each(function(t){I[k(t)]={rpx0:t.rpx0,rpx1:t.rpx1,x0:t.x0,x1:t.x1,transform:t.transform},!z&&_(t)&&(z=t)});var D=function(t){return i.partition().size([2*Math.PI,t.height+1])(t)}(y).descendants(),R=y.height+1,F=0,B=w;p.hasMultipleRoots&&b(y)&&(D=D.slice(1),R-=1,F=1,B+=1),D=D.filter(function(t){return t.y1<=B});var N=Math.min(R,w),j=function(t){return(t-F)/N*L},U=function(t,e){return[t*Math.cos(e),-t*Math.sin(e)]},V=function(t){return c.pathAnnulus(t.rpx0,t.rpx1,t.x0,t.x1,P,O)},q=function(t){return P+t.pxmid[0]*t.transform.rCenter+(t.transform.x||0)},H=function(t){return O+t.pxmid[1]*t.transform.rCenter+(t.transform.y||0)};(f=f.data(D,function(t){return k(t)})).enter().append(\"g\").classed(\"slice\",!0),u?f.exit().transition().each(function(){var t=n.select(this);t.select(\"path.surface\").transition().attrTween(\"d\",function(t){var e=function(t){var e,r=k(t),i=I[r],a=I[k(y)];if(a){var o=t.x1>a.x1?2*Math.PI:0;e=t.rpx1<a.rpx1?{rpx0:0,rpx1:0}:{x0:o,x1:o}}else{var s,l=k(t.parent);f.each(function(t){if(k(t)===l)return s=t});var c,u=s.children;u.forEach(function(t,e){if(k(t)===r)return c=e});var h=u.length,p=n.interpolate(s.x0,s.x1);e={rpx0:L,rpx1:L,x0:p(c/h),x1:p((c+1)/h)}}return n.interpolate(i,e)}(t);return function(t){return V(e(t))}}),t.select(\"g.slicetext\").attr(\"opacity\",0)}).remove():f.exit().remove(),f.order();var G=null;if(u&&z){var Y=k(z);f.each(function(t){null===G&&k(t)===Y&&(G=t.x1)})}var W=f;function X(t){var e=t.parent,r=I[k(e)],i={};if(r){var a=e.children,o=a.indexOf(t),s=a.length,l=n.interpolate(r.x0,r.x1);i.x0=l(o/s),i.x1=l(o/s)}else i.x0=i.x1=0;return i}u&&(W=W.transition().each(\"end\",function(){T(n.select(this),t,{isTransitioning:!1})})),W.each(function(r){var i=n.select(this),a=c.ensureSingle(i,\"path\",\"surface\",function(t){t.style(\"pointer-events\",\"all\")});r.rpx0=j(r.y0),r.rpx1=j(r.y1),r.xmid=(r.x0+r.x1)/2,r.pxmid=U(r.rpx1,r.xmid),r.midangle=-(r.xmid-Math.PI/2),r.halfangle=.5*Math.min(c.angleDelta(r.x0,r.x1)||Math.PI,Math.PI),r.ring=1-r.rpx0/r.rpx1,r.rInscribed=function(t){return 0===t.rpx0&&c.isFullCircle([t.x0,t.x1])?1:Math.max(0,Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2))}(r),u?a.transition().attrTween(\"d\",function(t){var e=function(t){var e,r=I[k(t)],i={x0:t.x0,x1:t.x1,rpx0:t.rpx0,rpx1:t.rpx1};if(r)e=r;else if(z)if(t.parent)if(G){var a=t.x1>G?2*Math.PI:0;e={x0:a,x1:a}}else e={rpx0:L,rpx1:L},c.extendFlat(e,X(t));else e={rpx0:0,rpx1:0};else e={x0:0,x1:0};return n.interpolate(e,i)}(t);return function(t){return V(e(t))}}):a.attr(\"d\",V),i.call(A,t,e).call(T,t,{isTransitioning:t._transitioning}),a.call(v,r,m);var f=c.ensureSingle(i,\"g\",\"slicetext\"),y=c.ensureSingle(f,\"text\",\"\",function(t){t.attr(\"data-notex\",1)});y.text(function(t,e,r){var n=e.textinfo;if(!n||\"none\"===n)return\"\";var i=t.data.data,a=r.separators,o=n.split(\"+\"),s=function(t){return-1!==o.indexOf(t)},l=[];s(\"label\")&&i.label&&l.push(i.label);i.hasOwnProperty(\"v\")&&s(\"value\")&&l.push(g(i.v,a));if(s(\"text\")){var u=c.castOption(e,i.i,\"text\");c.isValidTextValue(u)&&l.push(u)}return l.join(\"<br>\")}(r,m,o)).classed(\"slicetext\",!0).attr(\"text-anchor\",\"middle\").call(l.font,b(r)?function(t,e,r){var n=e.data.data.i,i=c.castOption(t,n,\"outsidetextfont.color\")||c.castOption(t,n,\"textfont.color\")||r.color,a=c.castOption(t,n,\"outsidetextfont.family\")||c.castOption(t,n,\"textfont.family\")||r.family,o=c.castOption(t,n,\"outsidetextfont.size\")||c.castOption(t,n,\"textfont.size\")||r.size;return{color:i,family:a,size:o}}(m,r,o.font):function(t,e,r){var n=e.data.data,i=n.i,a=c.castOption(t,i,\"insidetextfont.color\");!a&&t._input.textfont&&(a=c.castOption(t._input,i,\"textfont.color\"));var o=c.castOption(t,i,\"insidetextfont.family\")||c.castOption(t,i,\"textfont.family\")||r.family,l=c.castOption(t,i,\"insidetextfont.size\")||c.castOption(t,i,\"textfont.size\")||r.size;return{color:a||s.contrast(n.color),family:o,size:l}}(m,r,o.font)).call(h.convertToTspans,t);var x=l.bBox(y.node());r.transform=d(x,r,p),r.translateX=q(r),r.translateY=H(r);var _=function(t,e){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"+(t.transform.scale<1?\"scale(\"+t.transform.scale+\")\":\"\")+(t.transform.rotate?\"rotate(\"+t.transform.rotate+\")\":\"\")+\"translate(\"+-(e.left+e.right)/2+\",\"+-(e.top+e.bottom)/2+\")\"};u?y.transition().attrTween(\"transform\",function(t){var e=function(t){var e,r=I[k(t)],i=t.transform;if(r)e=r;else if(e={rpx1:t.rpx1,transform:{scale:0,rotate:i.rotate,rCenter:i.rCenter,x:i.x,y:i.y}},z)if(t.parent)if(G){var a=t.x1>G?2*Math.PI:0;e.x0=e.x1=a}else c.extendFlat(e,X(t));else e.x0=e.x1=0;else e.x0=e.x1=0;var o=n.interpolate(e.rpx1,t.rpx1),s=n.interpolate(e.x0,t.x0),l=n.interpolate(e.x1,t.x1),u=n.interpolate(e.transform.scale,i.scale),h=n.interpolate(e.transform.rotate,i.rotate),f=0===i.rCenter?3:0===e.transform.rCenter?1/3:1,p=n.interpolate(e.transform.rCenter,i.rCenter);return function(t){var e=o(t),r=s(t),n=l(t),a=function(t){return p(Math.pow(t,f))}(t),c={pxmid:U(e,(r+n)/2),transform:{rCenter:a,x:i.x,y:i.y}},d={rpx1:o(t),translateX:q(c),translateY:H(c),transform:{scale:u(t),rotate:h(t),rCenter:a}};return d}}(t);return function(t){return _(e(t),x)}}):y.attr(\"transform\",_(r,x))})}function x(t,e){var r;return e&&t.eachAfter(function(t){if(k(t)===e)return r=t.copy()}),r||t}function b(t){return\"\"===t.data.data.pid}function _(t){return!t.parent}function w(t){return!t.children}function k(t){return t.data.data.id}function T(t,e,r){var n=t.datum(),i=(r||{}).isTransitioning;f(t,i||w(n)||b(n)?null:\"pointer\")}function A(t,e,r){var i=r[0],s=i.trace;\"_hasHoverLabel\"in s||(s._hasHoverLabel=!1),\"_hasHoverEvent\"in s||(s._hasHoverEvent=!1),t.on(\"mouseover\",function(t){var r=e._fullLayout;if(!e._dragging&&!1!==r.hovermode){var a=e._fullData[s.index],l=t.data.data,u=l.i,h=function(t){return c.castOption(a,u,t)},f=h(\"hovertemplate\"),p=o.castHoverinfo(a,r,u),d=r.separators;if(f||p&&\"none\"!==p&&\"skip\"!==p){var v=t.rInscribed,m=i.cx+t.pxmid[0]*(1-v),y=i.cy+t.pxmid[1]*(1-v),x={},b=[],_=[],w=function(t){return-1!==b.indexOf(t)};if(p&&(b=\"all\"===p?a._module.attributes.hoverinfo.flags:p.split(\"+\")),x.label=l.label,w(\"label\")&&x.label&&_.push(x.label),l.hasOwnProperty(\"v\")&&(x.value=l.v,x.valueLabel=g(x.value,d),w(\"value\")&&_.push(x.valueLabel)),x.text=h(\"hovertext\")||h(\"text\"),w(\"text\")){var k=x.text;c.isValidTextValue(k)&&_.push(k)}o.loneHover({trace:a,x0:m-v*t.rpx1,x1:m+v*t.rpx1,y:y,idealAlign:t.pxmid[0]<0?\"left\":\"right\",text:_.join(\"<br>\"),name:f||w(\"name\")?a.name:void 0,color:h(\"hoverlabel.bgcolor\")||l.color,borderColor:h(\"hoverlabel.bordercolor\"),fontFamily:h(\"hoverlabel.font.family\"),fontSize:h(\"hoverlabel.font.size\"),fontColor:h(\"hoverlabel.font.color\"),nameLength:h(\"hoverlabel.namelength\"),textAlign:h(\"hoverlabel.align\"),hovertemplate:f,hovertemplateLabels:x,eventData:[M(t,a)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e}),s._hasHoverLabel=!0}s._hasHoverEvent=!0,e.emit(\"plotly_hover\",{points:[M(t,a)],event:n.event})}}),t.on(\"mouseout\",function(t){var r=e._fullLayout,i=e._fullData[s.index],a=n.select(this).datum();s._hasHoverEvent&&(t.originalEvent=n.event,e.emit(\"plotly_unhover\",{points:[M(a,i)],event:n.event}),s._hasHoverEvent=!1),s._hasHoverLabel&&(o.loneUnhover(r._hoverlayer.node()),s._hasHoverLabel=!1)}),t.on(\"click\",function(t){var r=e._fullLayout,l=e._fullData[s.index];if(!1===u.triggerHandler(e,\"plotly_sunburstclick\",{points:[M(t,l)],event:n.event})||w(t)||b(t))r.hovermode&&(e._hoverdata=[M(t,l)],o.click(e,n.event));else if(!e._dragging&&!e._transitioning){a.call(\"_storeDirectGUIEdit\",l,r._tracePreGUI[l.uid],{level:l.level});var c=i.hierarchy,h=k(t),f=_(t)?function(t,e){var r;return t.eachAfter(function(t){for(var n=t.children||[],i=0;i<n.length;i++)if(k(n[i])===e)return r=t.copy()}),r||t}(c,h):x(c,h),p={data:[{level:k(f)}],traces:[s.index]},d={frame:{redraw:!1,duration:m.CLICK_TRANSITION_TIME},transition:{duration:m.CLICK_TRANSITION_TIME,easing:m.CLICK_TRANSITION_EASING},mode:\"immediate\",fromcurrent:!0};o.loneUnhover(r._hoverlayer.node()),a.call(\"animate\",e,p,d)}})}function M(t,e){var r=t.data.data,n={curveNumber:e.index,pointNumber:r.i,data:e._input,fullData:e};return p(n,e,r.i),n}e.exports=function(t,e,r,i){var a,o,s=t._fullLayout._sunburstlayer,l=!r,c=r&&r.duration>0;((a=s.selectAll(\"g.trace.sunburst\").data(e,function(t){return t[0].trace.uid})).enter().append(\"g\").classed(\"trace\",!0).classed(\"sunburst\",!0).attr(\"stroke-linejoin\",\"round\"),a.order(),c)?(i&&(o=i()),n.transition().duration(r.duration).ease(r.easing).each(\"end\",function(){o&&o()}).each(\"interrupt\",function(){o&&o()}).each(function(){s.selectAll(\"g.trace\").each(function(e){y(t,e,this,r)})})):a.each(function(e){y(t,e,this,r)});l&&a.exit().remove()}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../components/fx/helpers\":628,\"../../lib\":719,\"../../lib/events\":709,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../registry\":847,\"../pie/helpers\":1091,\"../pie/plot\":1095,\"./constants\":1217,\"./style\":1223,d3:163,\"d3-hierarchy\":157}],1223:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../lib\");function o(t,e,r){var n=e.data.data,o=!e.children,s=n.i,l=a.castOption(r,s,\"marker.line.color\")||i.defaultLine,c=a.castOption(r,s,\"marker.line.width\")||0;t.style(\"stroke-width\",c).call(i.fill,n.color).call(i.stroke,l).style(\"opacity\",o?r.leaf.opacity:null)}e.exports={style:function(t){t._fullLayout._sunburstlayer.selectAll(\".trace\").each(function(t){var e=n.select(this),r=t[0].trace;e.style(\"opacity\",r.opacity),e.selectAll(\"path.surface\").each(function(t){n.select(this).call(o,t,r)})})},styleOne:o}},{\"../../components/color\":593,\"../../lib\":719,d3:163}],1224:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;function c(t){return{show:{valType:\"boolean\",dflt:!1},start:{valType:\"number\",dflt:null,editType:\"plot\"},end:{valType:\"number\",dflt:null,editType:\"plot\"},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\"},project:{x:{valType:\"boolean\",dflt:!1},y:{valType:\"boolean\",dflt:!1},z:{valType:\"boolean\",dflt:!1}},color:{valType:\"color\",dflt:n.defaultLine},usecolormap:{valType:\"boolean\",dflt:!1},width:{valType:\"number\",min:1,max:16,dflt:2},highlight:{valType:\"boolean\",dflt:!0},highlightcolor:{valType:\"color\",dflt:n.defaultLine},highlightwidth:{valType:\"number\",min:1,max:16,dflt:2}}}var u=e.exports=l(s({z:{valType:\"data_array\"},x:{valType:\"data_array\"},y:{valType:\"data_array\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:a(),connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},surfacecolor:{valType:\"data_array\"}},i(\"\",{colorAttr:\"z or surfacecolor\",showScaleDflt:!0,autoColorDflt:!1,editTypeOverride:\"calc\"}),{contours:{x:c(),y:c(),z:c()},hidesurface:{valType:\"boolean\",dflt:!1},lightposition:{x:{valType:\"number\",min:-1e5,max:1e5,dflt:10},y:{valType:\"number\",min:-1e5,max:1e5,dflt:1e4},z:{valType:\"number\",min:-1e5,max:1e5,dflt:0}},lighting:{ambient:{valType:\"number\",min:0,max:1,dflt:.8},diffuse:{valType:\"number\",min:0,max:1,dflt:.8},specular:{valType:\"number\",min:0,max:2,dflt:.05},roughness:{valType:\"number\",min:0,max:1,dflt:.5},fresnel:{valType:\"number\",min:0,max:5,dflt:.2}},opacity:{valType:\"number\",min:0,max:1,dflt:1},_deprecated:{zauto:s({},i.zauto,{}),zmin:s({},i.zmin,{}),zmax:s({},i.zmax,{})},hoverinfo:s({},o.hoverinfo)}),\"calc\",\"nested\");u.x.editType=u.y.editType=u.z.editType=\"calc+clearAxisTypes\",u.transforms=void 0},{\"../../components/color\":593,\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764}],1225:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.surfacecolor?n(t,e,{vals:e.surfacecolor,containerStr:\"\",cLetter:\"c\"}):n(t,e,{vals:e.z,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],1226:[function(t,e,r){\"use strict\";var n=t(\"gl-surface3d\"),i=t(\"ndarray\"),a=t(\"ndarray-homography\"),o=t(\"ndarray-fill\"),s=t(\"../../lib\").isArrayOrTypedArray,l=t(\"../../lib/gl_format_color\").parseColorScale,c=t(\"../../lib/str2rgbarray\"),u=t(\"../../components/colorscale\").extractOpts,h=t(\"../heatmap/interp2d\"),f=t(\"../heatmap/find_empties\");function p(t,e,r){this.scene=t,this.uid=r,this.surface=e,this.data=null,this.showContour=[!1,!1,!1],this.contourStart=[null,null,null],this.contourEnd=[null,null,null],this.contourSize=[0,0,0],this.minValues=[1/0,1/0,1/0],this.maxValues=[-1/0,-1/0,-1/0],this.dataScaleX=1,this.dataScaleY=1,this.refineData=!0,this.objectOffset=[0,0,0]}var d=p.prototype;d.getXat=function(t,e,r,n){var i=s(this.data.x)?s(this.data.x[0])?this.data.x[e][t]:this.data.x[t]:t;return void 0===r?i:n.d2l(i,0,r)},d.getYat=function(t,e,r,n){var i=s(this.data.y)?s(this.data.y[0])?this.data.y[e][t]:this.data.y[e]:e;return void 0===r?i:n.d2l(i,0,r)},d.getZat=function(t,e,r,n){var i=this.data.z[e][t];return null===i&&this.data.connectgaps&&this.data._interpolatedZ&&(i=this.data._interpolatedZ[e][t]),void 0===r?i:n.d2l(i,0,r)},d.handlePick=function(t){if(t.object===this.surface){var e=(t.data.index[0]-1)/this.dataScaleX-1,r=(t.data.index[1]-1)/this.dataScaleY-1,n=Math.max(Math.min(Math.round(e),this.data.z[0].length-1),0),i=Math.max(Math.min(Math.round(r),this.data._ylength-1),0);t.index=[n,i],t.traceCoordinate=[this.getXat(n,i),this.getYat(n,i),this.getZat(n,i)],t.dataCoordinate=[this.getXat(n,i,this.data.xcalendar,this.scene.fullSceneLayout.xaxis),this.getYat(n,i,this.data.ycalendar,this.scene.fullSceneLayout.yaxis),this.getZat(n,i,this.data.zcalendar,this.scene.fullSceneLayout.zaxis)];for(var a=0;a<3;a++){var o=t.dataCoordinate[a];null!=o&&(t.dataCoordinate[a]*=this.scene.dataScale[a])}var s=this.data.hovertext||this.data.text;return Array.isArray(s)&&s[i]&&void 0!==s[i][n]?t.textLabel=s[i][n]:t.textLabel=s||\"\",t.data.dataCoordinate=t.dataCoordinate.slice(),this.surface.highlight(t.data),this.scene.glplot.spikes.position=t.dataCoordinate,!0}};var g=[2,3,5,7,11,13,17,19,23,29,31,37,41,43,47,53,59,61,67,71,73,79,83,89,97,101,103,107,109,113,127,131,137,139,149,151,157,163,167,173,179,181,191,193,197,199,211,223,227,229,233,239,241,251,257,263,269,271,277,281,283,293,307,311,313,317,331,337,347,349,353,359,367,373,379,383,389,397,401,409,419,421,431,433,439,443,449,457,461,463,467,479,487,491,499,503,509,521,523,541,547,557,563,569,571,577,587,593,599,601,607,613,617,619,631,641,643,647,653,659,661,673,677,683,691,701,709,719,727,733,739,743,751,757,761,769,773,787,797,809,811,821,823,827,829,839,853,857,859,863,877,881,883,887,907,911,919,929,937,941,947,953,967,971,977,983,991,997,1009,1013,1019,1021,1031,1033,1039,1049,1051,1061,1063,1069,1087,1091,1093,1097,1103,1109,1117,1123,1129,1151,1153,1163,1171,1181,1187,1193,1201,1213,1217,1223,1229,1231,1237,1249,1259,1277,1279,1283,1289,1291,1297,1301,1303,1307,1319,1321,1327,1361,1367,1373,1381,1399,1409,1423,1427,1429,1433,1439,1447,1451,1453,1459,1471,1481,1483,1487,1489,1493,1499,1511,1523,1531,1543,1549,1553,1559,1567,1571,1579,1583,1597,1601,1607,1609,1613,1619,1621,1627,1637,1657,1663,1667,1669,1693,1697,1699,1709,1721,1723,1733,1741,1747,1753,1759,1777,1783,1787,1789,1801,1811,1823,1831,1847,1861,1867,1871,1873,1877,1879,1889,1901,1907,1913,1931,1933,1949,1951,1973,1979,1987,1993,1997,1999,2003,2011,2017,2027,2029,2039,2053,2063,2069,2081,2083,2087,2089,2099,2111,2113,2129,2131,2137,2141,2143,2153,2161,2179,2203,2207,2213,2221,2237,2239,2243,2251,2267,2269,2273,2281,2287,2293,2297,2309,2311,2333,2339,2341,2347,2351,2357,2371,2377,2381,2383,2389,2393,2399,2411,2417,2423,2437,2441,2447,2459,2467,2473,2477,2503,2521,2531,2539,2543,2549,2551,2557,2579,2591,2593,2609,2617,2621,2633,2647,2657,2659,2663,2671,2677,2683,2687,2689,2693,2699,2707,2711,2713,2719,2729,2731,2741,2749,2753,2767,2777,2789,2791,2797,2801,2803,2819,2833,2837,2843,2851,2857,2861,2879,2887,2897,2903,2909,2917,2927,2939,2953,2957,2963,2969,2971,2999];function v(t,e){if(t<e)return 0;for(var r=0;0===Math.floor(t%e);)t/=e,r++;return r}function m(t){for(var e=[],r=0;r<g.length;r++){var n=g[r];e.push(v(t,n))}return e}function y(t){for(var e=m(t),r=t,n=0;n<g.length;n++)if(e[n]>0){r=g[n];break}return r}function x(t,e){if(!(t<1||e<1)){for(var r=m(t),n=m(e),i=1,a=0;a<g.length;a++)i*=Math.pow(g[a],Math.max(r[a],n[a]));return i}}d.calcXnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getXat(e-1,0),i=this.getXat(e,0);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r},d.calcYnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getYat(0,e-1),i=this.getYat(0,e);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r};var b=[1,2,4,6,12,24,36,48,60,120,180,240,360,720,840,1260],_=b[9],w=b[13];function k(t,e){for(var r=!1,n=0;n<t.length;n++)if(e===t[n]){r=!0;break}!1===r&&t.push(e)}d.estimateScale=function(t,e){for(var r=1+function(t){if(0!==t.length){for(var e=1,r=0;r<t.length;r++)e=x(e,t[r]);return e}}(0===e?this.calcXnums(t):this.calcYnums(t));r<_;)r*=2;for(;r>w;)r--,r/=y(r),++r<_&&(r=w);var n=Math.round(r/t);return n>1?n:1},d.refineCoords=function(t){for(var e=this.dataScaleX,r=this.dataScaleY,n=t[0].shape[0],o=t[0].shape[1],s=0|Math.floor(t[0].shape[0]*e+1),l=0|Math.floor(t[0].shape[1]*r+1),c=1+n+1,u=1+o+1,h=i(new Float32Array(c*u),[c,u]),f=0;f<t.length;++f){this.surface.padField(h,t[f]);var p=i(new Float32Array(s*l),[s,l]);a(p,h,[e,0,0,0,r,0,0,0,1]),t[f]=p}},d.setContourLevels=function(){var t,e,r,n=[[],[],[]],i=[!1,!1,!1],a=!1;for(t=0;t<3;++t)if(this.showContour[t]&&(a=!0,this.contourSize[t]>0&&null!==this.contourStart[t]&&null!==this.contourEnd[t]&&this.contourEnd[t]>this.contourStart[t]))for(i[t]=!0,e=this.contourStart[t];e<this.contourEnd[t];e+=this.contourSize[t])r=e*this.scene.dataScale[t],k(n[t],r);if(a){var o=[[],[],[]];for(t=0;t<3;++t)this.showContour[t]&&(o[t]=i[t]?n[t]:this.scene.contourLevels[t]);this.surface.update({levels:o})}},d.update=function(t){var e,r,n,a,s=this.scene,p=s.fullSceneLayout,d=this.surface,g=t.opacity,v=l(t,g),m=s.dataScale,y=t.z[0].length,x=t._ylength,b=s.contourLevels;this.data=t;var _=[];for(e=0;e<3;e++)for(_[e]=[],r=0;r<y;r++)_[e][r]=[];for(r=0;r<y;r++)for(n=0;n<x;n++)_[0][r][n]=this.getXat(r,n,t.xcalendar,p.xaxis),_[1][r][n]=this.getYat(r,n,t.ycalendar,p.yaxis),_[2][r][n]=this.getZat(r,n,t.zcalendar,p.zaxis);if(t.connectgaps)for(t._emptypoints=f(_[2]),h(_[2],t._emptypoints),t._interpolatedZ=[],r=0;r<y;r++)for(t._interpolatedZ[r]=[],n=0;n<x;n++)t._interpolatedZ[r][n]=_[2][r][n];for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null==(a=_[e][r][n])?_[e][r][n]=NaN:a=_[e][r][n]*=m[e];for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null!=(a=_[e][r][n])&&(this.minValues[e]>a&&(this.minValues[e]=a),this.maxValues[e]<a&&(this.maxValues[e]=a));for(e=0;e<3;e++)this.objectOffset[e]=.5*(this.minValues[e]+this.maxValues[e]);for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null!=(a=_[e][r][n])&&(_[e][r][n]-=this.objectOffset[e]);var k=[i(new Float32Array(y*x),[y,x]),i(new Float32Array(y*x),[y,x]),i(new Float32Array(y*x),[y,x])];o(k[0],function(t,e){return _[0][t][e]}),o(k[1],function(t,e){return _[1][t][e]}),o(k[2],function(t,e){return _[2][t][e]}),_=[];var T={colormap:v,levels:[[],[],[]],showContour:[!0,!0,!0],showSurface:!t.hidesurface,contourProject:[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],contourWidth:[1,1,1],contourColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],contourTint:[1,1,1],dynamicColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],dynamicWidth:[1,1,1],dynamicTint:[1,1,1],opacity:t.opacity},A=u(t);if(T.intensityBounds=[A.min,A.max],t.surfacecolor){var M=i(new Float32Array(y*x),[y,x]);o(M,function(e,r){return t.surfacecolor[r][e]}),k.push(M)}else T.intensityBounds[0]*=m[2],T.intensityBounds[1]*=m[2];(w<k[0].shape[0]||w<k[0].shape[1])&&(this.refineData=!1),!0===this.refineData&&(this.dataScaleX=this.estimateScale(k[0].shape[0],0),this.dataScaleY=this.estimateScale(k[0].shape[1],1),1===this.dataScaleX&&1===this.dataScaleY||this.refineCoords(k)),t.surfacecolor&&(T.intensity=k.pop());var S=[!0,!0,!0],E=[\"x\",\"y\",\"z\"];for(e=0;e<3;++e){var C=t.contours[E[e]];S[e]=C.highlight,T.showContour[e]=C.show||C.highlight,T.showContour[e]&&(T.contourProject[e]=[C.project.x,C.project.y,C.project.z],C.show?(this.showContour[e]=!0,T.levels[e]=b[e],d.highlightColor[e]=T.contourColor[e]=c(C.color),C.usecolormap?d.highlightTint[e]=T.contourTint[e]=0:d.highlightTint[e]=T.contourTint[e]=1,T.contourWidth[e]=C.width,this.contourStart[e]=C.start,this.contourEnd[e]=C.end,this.contourSize[e]=C.size):(this.showContour[e]=!1,this.contourStart[e]=null,this.contourEnd[e]=null,this.contourSize[e]=0),C.highlight&&(T.dynamicColor[e]=c(C.highlightcolor),T.dynamicWidth[e]=C.highlightwidth))}(function(t){var e=t[0].rgb,r=t[t.length-1].rgb;return e[0]===r[0]&&e[1]===r[1]&&e[2]===r[2]&&e[3]===r[3]})(v)&&(T.vertexColor=!0),T.objectOffset=this.objectOffset,T.coords=k,d.update(T),d.visible=t.visible,d.enableDynamic=S,d.enableHighlight=S,d.snapToData=!0,\"lighting\"in t&&(d.ambientLight=t.lighting.ambient,d.diffuseLight=t.lighting.diffuse,d.specularLight=t.lighting.specular,d.roughness=t.lighting.roughness,d.fresnel=t.lighting.fresnel),\"lightposition\"in t&&(d.lightPosition=[t.lightposition.x,t.lightposition.y,t.lightposition.z]),g&&g<1&&(d.supportsTransparency=!0)},d.dispose=function(){this.scene.glplot.remove(this.surface),this.surface.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new p(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../heatmap/find_empties\":1007,\"../heatmap/interp2d\":1010,\"gl-surface3d\":316,ndarray:450,\"ndarray-fill\":440,\"ndarray-homography\":442}],1227:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");function s(t,e,r){e in t&&!(r in t)&&(t[r]=t[e])}e.exports=function(t,e,r,l){var c,u;function h(r,n){return i.coerce(t,e,o,r,n)}var f=h(\"x\"),p=h(\"y\"),d=h(\"z\");if(!d||!d.length||f&&f.length<1||p&&p.length<1)e.visible=!1;else{e._xlength=Array.isArray(f)&&i.isArrayOrTypedArray(f[0])?d.length:d[0].length,e._ylength=d.length,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],l),h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"hidesurface\",\"connectgaps\",\"opacity\"].forEach(function(t){h(t)});var g=h(\"surfacecolor\"),v=[\"x\",\"y\",\"z\"];for(c=0;c<3;++c){var m=\"contours.\"+v[c],y=h(m+\".show\"),x=h(m+\".highlight\");if(y||x)for(u=0;u<3;++u)h(m+\".project.\"+v[u]);y&&(h(m+\".color\"),h(m+\".width\"),h(m+\".usecolormap\")),x&&(h(m+\".highlightcolor\"),h(m+\".highlightwidth\")),h(m+\".start\"),h(m+\".end\"),h(m+\".size\")}g||(s(t,\"zmin\",\"cmin\"),s(t,\"zmax\",\"cmax\"),s(t,\"zauto\",\"cauto\")),a(t,e,l,h,{prefix:\"\",cLetter:\"c\"}),e._length=null}}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../../registry\":847,\"./attributes\":1224}],1228:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"surface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"2dMap\",\"noOpacity\"],meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1224,\"./calc\":1225,\"./convert\":1226,\"./defaults\":1227}],1229:[function(t,e,r){\"use strict\";var n=t(\"../../components/annotations/attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../plots/domain\").attributes;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=a({domain:s({name:\"table\",trace:!0}),columnwidth:{valType:\"number\",arrayOk:!0,dflt:null},columnorder:{valType:\"data_array\"},header:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:28},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))},cells:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:20},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))}},\"calc\",\"from-root\")).transforms=void 0},{\"../../components/annotations/attributes\":576,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1230:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"table\",r.plot=function(t){var e=n(t.calcdata,\"table\")[0];e.length&&i(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"table\"),a=e._has&&e._has(\"table\");i&&!a&&n._paperdiv.selectAll(\".table\").remove()}},{\"../../plots/get_data\":802,\"./plot\":1237}],1231:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap;e.exports=function(){return n({})}},{\"../../lib/gup\":717}],1232:[function(t,e,r){\"use strict\";e.exports={cellPad:8,columnExtentOffset:10,columnTitleOffset:28,emptyHeaderHeight:16,latexCheck:/^\\$.*\\$$/,goldenRatio:1.618,lineBreaker:\"<br>\",maxDimensionCount:60,overdrag:45,releaseTransitionDuration:120,releaseTransitionEase:\"cubic-out\",scrollbarCaptureWidth:18,scrollbarHideDelay:1e3,scrollbarHideDuration:1e3,scrollbarOffset:5,scrollbarWidth:8,transitionDuration:100,transitionEase:\"cubic-out\",uplift:5,wrapSpacer:\" \",wrapSplitCharacter:\" \",cn:{table:\"table\",tableControlView:\"table-control-view\",scrollBackground:\"scroll-background\",yColumn:\"y-column\",columnBlock:\"column-block\",scrollAreaClip:\"scroll-area-clip\",scrollAreaClipRect:\"scroll-area-clip-rect\",columnBoundary:\"column-boundary\",columnBoundaryClippath:\"column-boundary-clippath\",columnBoundaryRect:\"column-boundary-rect\",columnCells:\"column-cells\",columnCell:\"column-cell\",cellRect:\"cell-rect\",cellText:\"cell-text\",cellTextHolder:\"cell-text-holder\",scrollbarKit:\"scrollbar-kit\",scrollbar:\"scrollbar\",scrollbarSlider:\"scrollbar-slider\",scrollbarGlyph:\"scrollbar-glyph\",scrollbarCaptureZone:\"scrollbar-capture-zone\"}}},{}],1233:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"fast-isnumeric\");function o(t){if(Array.isArray(t)){for(var e=0,r=0;r<t.length;r++)e=Math.max(e,o(t[r]));return e}return t}function s(t,e){return t+e}function l(t){var e,r=t.slice(),n=1/0,i=0;for(e=0;e<r.length;e++)Array.isArray(r[e])||(r[e]=[r[e]]),n=Math.min(n,r[e].length),i=Math.max(i,r[e].length);if(n!==i)for(e=0;e<r.length;e++){var a=i-r[e].length;a&&(r[e]=r[e].concat(c(a)))}return r}function c(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=\"\";return e}function u(t){return t.calcdata.columns.reduce(function(e,r){return r.xIndex<t.xIndex?e+r.columnWidth:e},0)}function h(t,e){return Object.keys(t).map(function(r){return i({},t[r],{auxiliaryBlocks:e})})}function f(t,e){for(var r,n={},i=0,a=0,o={firstRowIndex:null,lastRowIndex:null,rows:[]},s=0,l=0,c=0;c<t.length;c++)r=t[c],o.rows.push({rowIndex:c,rowHeight:r}),((a+=r)>=e||c===t.length-1)&&(n[i]=o,o.key=l++,o.firstRowIndex=s,o.lastRowIndex=c,o={firstRowIndex:null,lastRowIndex:null,rows:[]},i+=a,s=c+1,a=0);return n}e.exports=function(t,e){var r=l(e.cells.values),p=function(t){return t.slice(e.header.values.length,t.length)},d=l(e.header.values);d.length&&!d[0].length&&(d[0]=[\"\"],d=l(d));var g=d.concat(p(r).map(function(){return c((d[0]||[\"\"]).length)})),v=e.domain,m=Math.floor(t._fullLayout._size.w*(v.x[1]-v.x[0])),y=Math.floor(t._fullLayout._size.h*(v.y[1]-v.y[0])),x=e.header.values.length?g[0].map(function(){return e.header.height}):[n.emptyHeaderHeight],b=r.length?r[0].map(function(){return e.cells.height}):[],_=x.reduce(s,0),w=f(b,y-_+n.uplift),k=h(f(x,_),[]),T=h(w,k),A={},M=e._fullInput.columnorder.concat(p(r.map(function(t,e){return e}))),S=g.map(function(t,r){var n=Array.isArray(e.columnwidth)?e.columnwidth[Math.min(r,e.columnwidth.length-1)]:e.columnwidth;return a(n)?Number(n):1}),E=S.reduce(s,0);S=S.map(function(t){return t/E*m});var C=Math.max(o(e.header.line.width),o(e.cells.line.width)),L={key:e.uid+t._context.staticPlot,translateX:v.x[0]*t._fullLayout._size.w,translateY:t._fullLayout._size.h*(1-v.y[1]),size:t._fullLayout._size,width:m,maxLineWidth:C,height:y,columnOrder:M,groupHeight:y,rowBlocks:T,headerRowBlocks:k,scrollY:0,cells:i({},e.cells,{values:r}),headerCells:i({},e.header,{values:g}),gdColumns:g.map(function(t){return t[0]}),gdColumnsOriginalOrder:g.map(function(t){return t[0]}),prevPages:[0,0],scrollbarState:{scrollbarScrollInProgress:!1},columns:g.map(function(t,e){var r=A[t];return A[t]=(r||0)+1,{key:t+\"__\"+A[t],label:t,specIndex:e,xIndex:M[e],xScale:u,x:void 0,calcdata:void 0,columnWidth:S[e]}})};return L.columns.forEach(function(t){t.calcdata=L,t.x=u(t)}),L}},{\"../../lib/extend\":710,\"./constants\":1232,\"fast-isnumeric\":225}],1234:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat;r.splitToPanels=function(t){var e=[0,0],r=n({},t,{key:\"header\",type:\"header\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!0,values:t.calcdata.headerCells.values[t.specIndex],rowBlocks:t.calcdata.headerRowBlocks,calcdata:n({},t.calcdata,{cells:t.calcdata.headerCells})});return[n({},t,{key:\"cells1\",type:\"cells\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),n({},t,{key:\"cells2\",type:\"cells\",page:1,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),r]},r.splitToCells=function(t){var e=function(t){var e=t.rowBlocks[t.page],r=e?e.rows[0].rowIndex:0,n=e?r+e.rows.length:0;return[r,n]}(t);return(t.values||[]).slice(e[0],e[1]).map(function(r,n){return{keyWithinBlock:n+(\"string\"==typeof r&&r.match(/[<$&> ]/)?\"_keybuster_\"+Math.random():\"\"),key:e[0]+n,column:t,calcdata:t.calcdata,page:t.page,rowBlocks:t.rowBlocks,value:r}})}},{\"../../lib/extend\":710}],1235:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults;e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}a(e,o,s),s(\"columnwidth\"),s(\"header.values\"),s(\"header.format\"),s(\"header.align\"),s(\"header.prefix\"),s(\"header.suffix\"),s(\"header.height\"),s(\"header.line.width\"),s(\"header.line.color\"),s(\"header.fill.color\"),n.coerceFont(s,\"header.font\",n.extendFlat({},o.font)),function(t,e){for(var r=t.columnorder||[],n=t.header.values.length,i=r.slice(0,n),a=i.slice().sort(function(t,e){return t-e}),o=i.map(function(t){return a.indexOf(t)}),s=o.length;s<n;s++)o.push(s);e(\"columnorder\",o)}(e,s),s(\"cells.values\"),s(\"cells.format\"),s(\"cells.align\"),s(\"cells.prefix\"),s(\"cells.suffix\"),s(\"cells.height\"),s(\"cells.line.width\"),s(\"cells.line.color\"),s(\"cells.fill.color\"),n.coerceFont(s,\"cells.font\",n.extendFlat({},o.font)),e._length=null}},{\"../../lib\":719,\"../../plots/domain\":792,\"./attributes\":1229}],1236:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"table\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1229,\"./base_plot\":1230,\"./calc\":1231,\"./defaults\":1235,\"./plot\":1237}],1237:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\"),o=t(\"../../components/drawing\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../lib\").raiseToTop,c=t(\"../../lib\").cancelTransition,u=t(\"./data_preparation_helper\"),h=t(\"./data_split_helpers\"),f=t(\"../../components/color\");function p(t){return Math.ceil(t.calcdata.maxLineWidth/2)}function d(t,e){return\"clip\"+t._fullLayout._uid+\"_scrollAreaBottomClip_\"+e.key}function g(t,e){return\"clip\"+t._fullLayout._uid+\"_columnBoundaryClippath_\"+e.calcdata.key+\"_\"+e.specIndex}function v(t){return[].concat.apply([],t.map(function(t){return t})).map(function(t){return t.__data__})}function m(t,e,r){var o=t.selectAll(\".\"+n.cn.scrollbarKit).data(a.repeat,a.keyFun);o.enter().append(\"g\").classed(n.cn.scrollbarKit,!0).style(\"shape-rendering\",\"geometricPrecision\"),o.each(function(t){var e=t.scrollbarState;e.totalHeight=function(t){var e=t.rowBlocks;return z(e,e.length-1)+(e.length?I(e[e.length-1],1/0):1)}(t),e.scrollableAreaHeight=t.groupHeight-A(t),e.currentlyVisibleHeight=Math.min(e.totalHeight,e.scrollableAreaHeight),e.ratio=e.currentlyVisibleHeight/e.totalHeight,e.barLength=Math.max(e.ratio*e.currentlyVisibleHeight,n.goldenRatio*n.scrollbarWidth),e.barWiggleRoom=e.currentlyVisibleHeight-e.barLength,e.wiggleRoom=Math.max(0,e.totalHeight-e.scrollableAreaHeight),e.topY=0===e.barWiggleRoom?0:t.scrollY/e.wiggleRoom*e.barWiggleRoom,e.bottomY=e.topY+e.barLength,e.dragMultiplier=e.wiggleRoom/e.barWiggleRoom}).attr(\"transform\",function(t){return\"translate(\"+(t.width+n.scrollbarWidth/2+n.scrollbarOffset)+\" \"+A(t)+\")\"});var s=o.selectAll(\".\"+n.cn.scrollbar).data(a.repeat,a.keyFun);s.enter().append(\"g\").classed(n.cn.scrollbar,!0);var l=s.selectAll(\".\"+n.cn.scrollbarSlider).data(a.repeat,a.keyFun);l.enter().append(\"g\").classed(n.cn.scrollbarSlider,!0),l.attr(\"transform\",function(t){return\"translate(0 \"+(t.scrollbarState.topY||0)+\")\"});var c=l.selectAll(\".\"+n.cn.scrollbarGlyph).data(a.repeat,a.keyFun);c.enter().append(\"line\").classed(n.cn.scrollbarGlyph,!0).attr(\"stroke\",\"black\").attr(\"stroke-width\",n.scrollbarWidth).attr(\"stroke-linecap\",\"round\").attr(\"y1\",n.scrollbarWidth/2),c.attr(\"y2\",function(t){return t.scrollbarState.barLength-n.scrollbarWidth/2}).attr(\"stroke-opacity\",function(t){return t.columnDragInProgress||!t.scrollbarState.barWiggleRoom||r?0:.4}),c.transition().delay(0).duration(0),c.transition().delay(n.scrollbarHideDelay).duration(n.scrollbarHideDuration).attr(\"stroke-opacity\",0);var u=s.selectAll(\".\"+n.cn.scrollbarCaptureZone).data(a.repeat,a.keyFun);u.enter().append(\"line\").classed(n.cn.scrollbarCaptureZone,!0).attr(\"stroke\",\"white\").attr(\"stroke-opacity\",.01).attr(\"stroke-width\",n.scrollbarCaptureWidth).attr(\"stroke-linecap\",\"butt\").attr(\"y1\",0).on(\"mousedown\",function(r){var n=i.event.y,a=this.getBoundingClientRect(),o=r.scrollbarState,s=n-a.top,l=i.scale.linear().domain([0,o.scrollableAreaHeight]).range([0,o.totalHeight]).clamp(!0);o.topY<=s&&s<=o.bottomY||S(e,t,null,l(s-o.barLength/2))(r)}).call(i.behavior.drag().origin(function(t){return i.event.stopPropagation(),t.scrollbarState.scrollbarScrollInProgress=!0,t}).on(\"drag\",S(e,t)).on(\"dragend\",function(){})),u.attr(\"y2\",function(t){return t.scrollbarState.scrollableAreaHeight}),e._context.staticPlot&&(c.remove(),u.remove())}function y(t,e,r,s){var l=function(t){var e=t.selectAll(\".\"+n.cn.columnCell).data(h.splitToCells,function(t){return t.keyWithinBlock});return e.enter().append(\"g\").classed(n.cn.columnCell,!0),e.exit().remove(),e}(function(t){var e=t.selectAll(\".\"+n.cn.columnCells).data(a.repeat,a.keyFun);return e.enter().append(\"g\").classed(n.cn.columnCells,!0),e.exit().remove(),e}(r));!function(t){t.each(function(t,e){var r=t.calcdata.cells.font,n=t.column.specIndex,i={size:_(r.size,n,e),color:_(r.color,n,e),family:_(r.family,n,e)};t.rowNumber=t.key,t.align=_(t.calcdata.cells.align,n,e),t.cellBorderWidth=_(t.calcdata.cells.line.width,n,e),t.font=i})}(l),function(t){t.attr(\"width\",function(t){return t.column.columnWidth}).attr(\"stroke-width\",function(t){return t.cellBorderWidth}).each(function(t){var e=i.select(this);f.stroke(e,_(t.calcdata.cells.line.color,t.column.specIndex,t.rowNumber)),f.fill(e,_(t.calcdata.cells.fill.color,t.column.specIndex,t.rowNumber))})}(function(t){var e=t.selectAll(\".\"+n.cn.cellRect).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"rect\").classed(n.cn.cellRect,!0),e}(l));var c=function(t){var e=t.selectAll(\".\"+n.cn.cellText).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"text\").classed(n.cn.cellText,!0).style(\"cursor\",function(){return\"auto\"}).on(\"mousedown\",function(){i.event.stopPropagation()}),e}(function(t){var e=t.selectAll(\".\"+n.cn.cellTextHolder).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"g\").classed(n.cn.cellTextHolder,!0).style(\"shape-rendering\",\"geometricPrecision\"),e}(l));!function(t){t.each(function(t){o.font(i.select(this),t.font)})}(c),x(c,e,s,t),O(l)}function x(t,e,r,a){t.text(function(t){var e=t.column.specIndex,r=t.rowNumber,a=t.value,o=\"string\"==typeof a,s=o&&a.match(/<br>/i),l=!o||s;t.mayHaveMarkup=o&&a.match(/[<&>]/);var c,u=\"string\"==typeof(c=a)&&c.match(n.latexCheck);t.latex=u;var h,f,p=u?\"\":_(t.calcdata.cells.prefix,e,r)||\"\",d=u?\"\":_(t.calcdata.cells.suffix,e,r)||\"\",g=u?null:_(t.calcdata.cells.format,e,r)||null,v=p+(g?i.format(g)(t.value):t.value)+d;if(t.wrappingNeeded=!t.wrapped&&!l&&!u&&(h=b(v)),t.cellHeightMayIncrease=s||u||t.mayHaveMarkup||(void 0===h?b(v):h),t.needsConvertToTspans=t.mayHaveMarkup||t.wrappingNeeded||t.latex,t.wrappingNeeded){var m=(\" \"===n.wrapSplitCharacter?v.replace(/<a href=/gi,\"<a_href=\"):v).split(n.wrapSplitCharacter),y=\" \"===n.wrapSplitCharacter?m.map(function(t){return t.replace(/<a_href=/gi,\"<a href=\")}):m;t.fragments=y.map(function(t){return{text:t,width:null}}),t.fragments.push({fragment:n.wrapSpacer,width:null}),f=y.join(n.lineBreaker)+n.lineBreaker+n.wrapSpacer}else delete t.fragments,f=v;return f}).attr(\"dy\",function(t){return t.needsConvertToTspans?0:\"0.75em\"}).each(function(t){var o=i.select(this),l=t.wrappingNeeded?C:L;t.needsConvertToTspans?s.convertToTspans(o,a,l(r,this,e,a,t)):i.select(this.parentNode).attr(\"transform\",function(t){return\"translate(\"+P(t)+\" \"+n.cellPad+\")\"}).attr(\"text-anchor\",function(t){return{left:\"start\",center:\"middle\",right:\"end\"}[t.align]})})}function b(t){return-1!==t.indexOf(n.wrapSplitCharacter)}function _(t,e,r){if(Array.isArray(t)){var n=t[Math.min(e,t.length-1)];return Array.isArray(n)?n[Math.min(r,n.length-1)]:n}return t}function w(t,e,r){t.transition().ease(n.releaseTransitionEase).duration(n.releaseTransitionDuration).attr(\"transform\",\"translate(\"+e.x+\" \"+r+\")\")}function k(t){return\"cells\"===t.type}function T(t){return\"header\"===t.type}function A(t){return(t.rowBlocks.length?t.rowBlocks[0].auxiliaryBlocks:[]).reduce(function(t,e){return t+I(e,1/0)},0)}function M(t,e,r){var n=v(e)[0];if(void 0!==n){var i=n.rowBlocks,a=n.calcdata,o=z(i,i.length),s=n.calcdata.groupHeight-A(n),l=a.scrollY=Math.max(0,Math.min(o-s,a.scrollY)),c=function(t,e,r){for(var n=[],i=0,a=0;a<t.length;a++){for(var o=t[a],s=o.rows,l=0,c=0;c<s.length;c++)l+=s[c].rowHeight;o.allRowsHeight=l,e<i+l&&e+r>i&&n.push(a),i+=l}return n}(i,l,s);1===c.length&&(c[0]===i.length-1?c.unshift(c[0]-1):c.push(c[0]+1)),c[0]%2&&c.reverse(),e.each(function(t,e){t.page=c[e],t.scrollY=l}),e.attr(\"transform\",function(t){return\"translate(0 \"+(z(t.rowBlocks,t.page)-t.scrollY)+\")\"}),t&&(E(t,r,e,c,n.prevPages,n,0),E(t,r,e,c,n.prevPages,n,1),m(r,t))}}function S(t,e,r,a){return function(o){var s=o.calcdata?o.calcdata:o,l=e.filter(function(t){return s.key===t.key}),c=r||s.scrollbarState.dragMultiplier,u=s.scrollY;s.scrollY=void 0===a?s.scrollY+c*i.event.dy:a;var h=l.selectAll(\".\"+n.cn.yColumn).selectAll(\".\"+n.cn.columnBlock).filter(k);return M(t,h,l),s.scrollY===u}}function E(t,e,r,n,i,a,o){n[o]!==i[o]&&(clearTimeout(a.currentRepaint[o]),a.currentRepaint[o]=setTimeout(function(){var a=r.filter(function(t,e){return e===o&&n[e]!==i[e]});y(t,e,a,r),i[o]=n[o]}))}function C(t,e,r,a){return function(){var o=i.select(e.parentNode);o.each(function(t){var e=t.fragments;o.selectAll(\"tspan.line\").each(function(t,r){e[r].width=this.getComputedTextLength()});var r,i,a=e[e.length-1].width,s=e.slice(0,-1),l=[],c=0,u=t.column.columnWidth-2*n.cellPad;for(t.value=\"\";s.length;)c+(i=(r=s.shift()).width+a)>u&&(t.value+=l.join(n.wrapSpacer)+n.lineBreaker,l=[],c=0),l.push(r.text),c+=i;c&&(t.value+=l.join(n.wrapSpacer)),t.wrapped=!0}),o.selectAll(\"tspan.line\").remove(),x(o.select(\".\"+n.cn.cellText),r,t,a),i.select(e.parentNode.parentNode).call(O)}}function L(t,e,r,a,o){return function(){if(!o.settledY){var s=i.select(e.parentNode),l=R(o),c=o.key-l.firstRowIndex,u=l.rows[c].rowHeight,h=o.cellHeightMayIncrease?e.parentNode.getBoundingClientRect().height+2*n.cellPad:u,f=Math.max(h,u);f-l.rows[c].rowHeight&&(l.rows[c].rowHeight=f,t.selectAll(\".\"+n.cn.columnCell).call(O),M(null,t.filter(k),0),m(r,a,!0)),s.attr(\"transform\",function(){var t=this.parentNode.getBoundingClientRect(),e=i.select(this.parentNode).select(\".\"+n.cn.cellRect).node().getBoundingClientRect(),r=this.transform.baseVal.consolidate(),a=e.top-t.top+(r?r.matrix.f:n.cellPad);return\"translate(\"+P(o,i.select(this.parentNode).select(\".\"+n.cn.cellTextHolder).node().getBoundingClientRect().width)+\" \"+a+\")\"}),o.settledY=!0}}}function P(t,e){switch(t.align){case\"left\":return n.cellPad;case\"right\":return t.column.columnWidth-(e||0)-n.cellPad;case\"center\":return(t.column.columnWidth-(e||0))/2;default:return n.cellPad}}function O(t){t.attr(\"transform\",function(t){var e=t.rowBlocks[0].auxiliaryBlocks.reduce(function(t,e){return t+I(e,1/0)},0);return\"translate(0 \"+(I(R(t),t.key)+e)+\")\"}).selectAll(\".\"+n.cn.cellRect).attr(\"height\",function(t){return(e=R(t),r=t.key,e.rows[r-e.firstRowIndex]).rowHeight;var e,r})}function z(t,e){for(var r=0,n=e-1;n>=0;n--)r+=D(t[n]);return r}function I(t,e){for(var r=0,n=0;n<t.rows.length&&t.rows[n].rowIndex<e;n++)r+=t.rows[n].rowHeight;return r}function D(t){var e=t.allRowsHeight;if(void 0!==e)return e;for(var r=0,n=0;n<t.rows.length;n++)r+=t.rows[n].rowHeight;return t.allRowsHeight=r,r}function R(t){return t.rowBlocks[t.page]}e.exports=function(t,e){var r=!t._context.staticPlot,s=t._fullLayout._paper.selectAll(\".\"+n.cn.table).data(e.map(function(e){var r=a.unwrap(e).trace;return u(t,r)}),a.keyFun);s.exit().remove(),s.enter().append(\"g\").classed(n.cn.table,!0).attr(\"overflow\",\"visible\").style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"overflow\",\"visible\").style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"all\"),s.attr(\"width\",function(t){return t.width+t.size.l+t.size.r}).attr(\"height\",function(t){return t.height+t.size.t+t.size.b}).attr(\"transform\",function(t){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"});var f=s.selectAll(\".\"+n.cn.tableControlView).data(a.repeat,a.keyFun),x=f.enter().append(\"g\").classed(n.cn.tableControlView,!0).style(\"box-sizing\",\"content-box\");r&&x.on(\"mousemove\",function(e){f.filter(function(t){return e===t}).call(m,t)}).on(\"mousewheel\",function(e){if(!e.scrollbarState.wheeling){e.scrollbarState.wheeling=!0;var r=e.scrollY+i.event.deltaY;S(t,f,null,r)(e)||(i.event.stopPropagation(),i.event.preventDefault()),e.scrollbarState.wheeling=!1}}).call(m,t,!0),f.attr(\"transform\",function(t){return\"translate(\"+t.size.l+\" \"+t.size.t+\")\"});var b=f.selectAll(\".\"+n.cn.scrollBackground).data(a.repeat,a.keyFun);b.enter().append(\"rect\").classed(n.cn.scrollBackground,!0).attr(\"fill\",\"none\"),b.attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}),f.each(function(e){o.setClipUrl(i.select(this),d(t,e),t)});var _=f.selectAll(\".\"+n.cn.yColumn).data(function(t){return t.columns},a.keyFun);_.enter().append(\"g\").classed(n.cn.yColumn,!0),_.exit().remove(),_.attr(\"transform\",function(t){return\"translate(\"+t.x+\" 0)\"}),r&&_.call(i.behavior.drag().origin(function(e){return w(i.select(this),e,-n.uplift),l(this),e.calcdata.columnDragInProgress=!0,m(f.filter(function(t){return e.calcdata.key===t.key}),t),e}).on(\"drag\",function(t){var e=i.select(this),r=function(e){return(t===e?i.event.x:e.x)+e.columnWidth/2};t.x=Math.max(-n.overdrag,Math.min(t.calcdata.width+n.overdrag-t.columnWidth,i.event.x)),v(_).filter(function(e){return e.calcdata.key===t.calcdata.key}).sort(function(t,e){return r(t)-r(e)}).forEach(function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e)}),_.filter(function(e){return t!==e}).transition().ease(n.transitionEase).duration(n.transitionDuration).attr(\"transform\",function(t){return\"translate(\"+t.x+\" 0)\"}),e.call(c).attr(\"transform\",\"translate(\"+t.x+\" -\"+n.uplift+\" )\")}).on(\"dragend\",function(e){var r=i.select(this),n=e.calcdata;e.x=e.xScale(e),e.calcdata.columnDragInProgress=!1,w(r,e,0),function(t,e,r){var n=e.gdColumnsOriginalOrder;e.gdColumns.sort(function(t,e){return r[n.indexOf(t)]-r[n.indexOf(e)]}),e.columnorder=r,t.emit(\"plotly_restyle\")}(t,n,n.columns.map(function(t){return t.xIndex}))})),_.each(function(e){o.setClipUrl(i.select(this),g(t,e),t)});var A=_.selectAll(\".\"+n.cn.columnBlock).data(h.splitToPanels,a.keyFun);A.enter().append(\"g\").classed(n.cn.columnBlock,!0).attr(\"id\",function(t){return t.key}),A.style(\"cursor\",function(t){return t.dragHandle?\"ew-resize\":t.calcdata.scrollbarState.barWiggleRoom?\"ns-resize\":\"default\"});var E=A.filter(T),C=A.filter(k);r&&C.call(i.behavior.drag().origin(function(t){return i.event.stopPropagation(),t}).on(\"drag\",S(t,f,-1)).on(\"dragend\",function(){})),y(t,f,E,A),y(t,f,C,A);var L=f.selectAll(\".\"+n.cn.scrollAreaClip).data(a.repeat,a.keyFun);L.enter().append(\"clipPath\").classed(n.cn.scrollAreaClip,!0).attr(\"id\",function(e){return d(t,e)});var P=L.selectAll(\".\"+n.cn.scrollAreaClipRect).data(a.repeat,a.keyFun);P.enter().append(\"rect\").classed(n.cn.scrollAreaClipRect,!0).attr(\"x\",-n.overdrag).attr(\"y\",-n.uplift).attr(\"fill\",\"none\"),P.attr(\"width\",function(t){return t.width+2*n.overdrag}).attr(\"height\",function(t){return t.height+n.uplift}),_.selectAll(\".\"+n.cn.columnBoundary).data(a.repeat,a.keyFun).enter().append(\"g\").classed(n.cn.columnBoundary,!0);var O=_.selectAll(\".\"+n.cn.columnBoundaryClippath).data(a.repeat,a.keyFun);O.enter().append(\"clipPath\").classed(n.cn.columnBoundaryClippath,!0),O.attr(\"id\",function(e){return g(t,e)});var z=O.selectAll(\".\"+n.cn.columnBoundaryRect).data(a.repeat,a.keyFun);z.enter().append(\"rect\").classed(n.cn.columnBoundaryRect,!0).attr(\"fill\",\"none\"),z.attr(\"width\",function(t){return t.columnWidth+2*p(t)}).attr(\"height\",function(t){return t.calcdata.height+2*p(t)+n.uplift}).attr(\"x\",function(t){return-p(t)}).attr(\"y\",function(t){return-p(t)}),M(null,C,f)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/gup\":717,\"../../lib/svg_text_utils\":743,\"./constants\":1232,\"./data_preparation_helper\":1233,\"./data_split_helpers\":1234,d3:163}],1238:[function(t,e,r){\"use strict\";var n=t(\"../box/attributes\"),i=t(\"../../lib/extend\").extendFlat;e.exports={y:n.y,x:n.x,x0:n.x0,y0:n.y0,name:i({},n.name,{}),orientation:i({},n.orientation,{}),bandwidth:{valType:\"number\",min:0,editType:\"calc\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},scalemode:{valType:\"enumerated\",values:[\"width\",\"count\"],dflt:\"width\",editType:\"calc\"},spanmode:{valType:\"enumerated\",values:[\"soft\",\"hard\",\"manual\"],dflt:\"soft\",editType:\"calc\"},span:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}],editType:\"calc\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,points:i({},n.boxpoints,{}),jitter:i({},n.jitter,{}),pointpos:i({},n.pointpos,{}),width:i({},n.width,{}),marker:n.marker,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,box:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},width:{valType:\"number\",min:0,max:1,dflt:.25,editType:\"plot\"},fillcolor:{valType:\"color\",editType:\"style\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},editType:\"plot\"},meanline:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"plot\"},side:{valType:\"enumerated\",values:[\"both\",\"positive\",\"negative\"],dflt:\"both\",editType:\"calc\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,hoveron:{valType:\"flaglist\",flags:[\"violins\",\"points\",\"kde\"],dflt:\"violins+points+kde\",extras:[\"all\"],editType:\"style\"}}},{\"../../lib/extend\":710,\"../box/attributes\":880}],1239:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/calc\"),o=t(\"./helpers\"),s=t(\"../../constants/numerical\").BADNUM;function l(t,e,r){var i=e.max-e.min;if(!i)return t.bandwidth?t.bandwidth:0;if(t.bandwidth)return Math.max(t.bandwidth,i/1e4);var a=r.length,o=n.stdev(r,a-1,e.mean);return Math.max(function(t,e,r){return 1.059*Math.min(e,r/1.349)*Math.pow(t,-.2)}(a,o,e.q3-e.q1),i/100)}function c(t,e,r,n){var a,o=t.spanmode,l=t.span||[],c=[e.min,e.max],u=[e.min-2*n,e.max+2*n];function h(n){var i=l[n],a=\"multicategory\"===r.type?r.r2c(i):r.d2c(i,0,t[e.valLetter+\"calendar\"]);return a===s?u[n]:a}var f={type:\"linear\",range:a=\"soft\"===o?u:\"hard\"===o?c:[h(0),h(1)]};return i.setConvert(f),f.cleanRange(),a}e.exports=function(t,e){var r=a(t,e);if(r[0].t.empty)return r;for(var s=t._fullLayout,u=i.getFromId(t,e[\"h\"===e.orientation?\"xaxis\":\"yaxis\"]),h=1/0,f=-1/0,p=0,d=0,g=0;g<r.length;g++){var v=r[g],m=v.pts.map(o.extractVal),y=v.bandwidth=l(e,v,m),x=v.span=c(e,v,u,y);if(v.min===v.max&&0===y)x=v.span=[v.min,v.max],v.density=[{v:1,t:x[0]}],v.bandwidth=y,p=Math.max(p,1);else{var b=x[1]-x[0],_=Math.ceil(b/(y/3)),w=b/_;if(!isFinite(w)||!isFinite(_))return n.error(\"Something went wrong with computing the violin span\"),r[0].t.empty=!0,r;var k=o.makeKDE(v,e,m);v.density=new Array(_);for(var T=0,A=x[0];A<x[1]+w/2;T++,A+=w){var M=k(A);v.density[T]={v:M,t:A},p=Math.max(p,M)}}d=Math.max(d,m.length),h=Math.min(h,x[0]),f=Math.max(f,x[1])}var S=i.findExtremes(u,[h,f],{padded:!0});if(e._extremes[u._id]=S,e.width)r[0].t.maxKDE=p;else{var E=s._violinScaleGroupStats,C=e.scalegroup,L=E[C];L?(L.maxKDE=Math.max(L.maxKDE,p),L.maxCount=Math.max(L.maxCount,d)):E[C]={maxKDE:p,maxCount:d}}return r[0].t.labels.kde=n._(t,\"kde:\"),r}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../box/calc\":881,\"./helpers\":1242}],1240:[function(t,e,r){\"use strict\";var n=t(\"../box/cross_trace_calc\").setPositionOffset,i=[\"v\",\"h\"];e.exports=function(t,e){for(var r=t.calcdata,a=e.xaxis,o=e.yaxis,s=0;s<i.length;s++){for(var l=i[s],c=\"h\"===l?o:a,u=[],h=0;h<r.length;h++){var f=r[h],p=f[0].t,d=f[0].trace;!0!==d.visible||\"violin\"!==d.type||p.empty||d.orientation!==l||d.xaxis!==a._id||d.yaxis!==o._id||u.push(h)}n(\"violin\",t,u,c)}}},{\"../box/cross_trace_calc\":882}],1241:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../box/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}function c(r,i){return n.coerce2(t,e,o,r,i)}if(a.handleSampleDefaults(t,e,l,s),!1!==e.visible){l(\"bandwidth\"),l(\"side\"),l(\"width\")||(l(\"scalegroup\",e.name),l(\"scalemode\"));var u,h=l(\"span\");Array.isArray(h)&&(u=\"manual\"),l(\"spanmode\",u);var f=l(\"line.color\",(t.marker||{}).color||r),p=l(\"line.width\"),d=l(\"fillcolor\",i.addOpacity(e.line.color,.5));a.handlePointsDefaults(t,e,l,{prefix:\"\"});var g=c(\"box.width\"),v=c(\"box.fillcolor\",d),m=c(\"box.line.color\",f),y=c(\"box.line.width\",p);l(\"box.visible\",Boolean(g||v||m||y))||(e.box={visible:!1});var x=c(\"meanline.color\",f),b=c(\"meanline.width\",p);l(\"meanline.visible\",Boolean(x||b))||(e.meanline={visible:!1})}}},{\"../../components/color\":593,\"../../lib\":719,\"../box/defaults\":883,\"./attributes\":1238}],1242:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=function(t){return 1/Math.sqrt(2*Math.PI)*Math.exp(-.5*t*t)};r.makeKDE=function(t,e,r){var n=r.length,a=i,o=t.bandwidth,s=1/(n*o);return function(t){for(var e=0,i=0;i<n;i++)e+=a((t-r[i])/o);return s*e}},r.getPositionOnKdePath=function(t,e,r){var i,a;\"h\"===e.orientation?(i=\"y\",a=\"x\"):(i=\"x\",a=\"y\");var o=n.findPointOnPath(t.path,r,a,{pathLength:t.pathLength}),s=t.posCenterPx,l=o[i];return[l,\"both\"===e.side?2*s-l:s]},r.getKdeValue=function(t,e,n){var i=t.pts.map(r.extractVal);return r.makeKDE(t,e,i)(n)/t.posDensityScale},r.extractVal=function(t){return t.v}},{\"../../lib\":719}],1243:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/hover\"),o=t(\"./helpers\");e.exports=function(t,e,r,s,l){var c,u,h=t.cd,f=h[0].trace,p=f.hoveron,d=-1!==p.indexOf(\"violins\"),g=-1!==p.indexOf(\"kde\"),v=[];if(d||g){var m=a.hoverOnBoxes(t,e,r,s);if(g&&m.length>0){var y,x,b,_,w,k=t.xa,T=t.ya;\"h\"===f.orientation?(w=e,y=\"y\",b=T,x=\"x\",_=k):(w=r,y=\"x\",b=k,x=\"y\",_=T);var A=h[t.index];if(w>=A.span[0]&&w<=A.span[1]){var M=n.extendFlat({},t),S=_.c2p(w,!0),E=o.getKdeValue(A,f,w),C=o.getPositionOnKdePath(A,f,S),L=b._offset,P=b._length;M[y+\"0\"]=C[0],M[y+\"1\"]=C[1],M[x+\"0\"]=M[x+\"1\"]=S,M[x+\"Label\"]=x+\": \"+i.hoverLabelText(_,w)+\", \"+h[0].t.labels.kde+\" \"+E.toFixed(3),M.spikeDistance=m[0].spikeDistance;var O=y+\"Spike\";M[O]=m[0][O],m[0].spikeDistance=void 0,m[0][O]=void 0,M.hovertemplate=!1,v.push(M),(u={stroke:t.color})[y+\"1\"]=n.constrain(L+C[0],L,L+P),u[y+\"2\"]=n.constrain(L+C[1],L,L+P),u[x+\"1\"]=u[x+\"2\"]=_._offset+S}}d&&(v=v.concat(m))}-1!==p.indexOf(\"points\")&&(c=a.hoverOnPoints(t,e,r));var z=l.selectAll(\".violinline-\"+f.uid).data(u?[0]:[]);return z.enter().append(\"line\").classed(\"violinline-\"+f.uid,!0).attr(\"stroke-width\",1.5),z.exit().remove(),z.attr(u),\"closest\"===s?c?[c]:v:c?(v.push(c),v):v}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../box/hover\":885,\"./helpers\":1242}],1244:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../box/defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../box/select\"),moduleType:\"trace\",name:\"violin\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"violinLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../box/defaults\":883,\"../box/select\":890,\"../scatter/style\":1134,\"./attributes\":1238,\"./calc\":1239,\"./cross_trace_calc\":1240,\"./defaults\":1241,\"./hover\":1243,\"./layout_attributes\":1245,\"./layout_defaults\":1246,\"./plot\":1247,\"./style\":1248}],1245:[function(t,e,r){\"use strict\";var n=t(\"../box/layout_attributes\"),i=t(\"../../lib\").extendFlat;e.exports={violinmode:i({},n.boxmode,{}),violingap:i({},n.boxgap,{}),violingroupgap:i({},n.boxgroupgap,{})}},{\"../../lib\":719,\"../box/layout_attributes\":887}],1246:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"../box/layout_defaults\");e.exports=function(t,e,r){a._supply(t,e,r,function(r,a){return n.coerce(t,e,i,r,a)},\"violin\")}},{\"../../lib\":719,\"../box/layout_defaults\":888,\"./layout_attributes\":1245}],1247:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../box/plot\"),s=t(\"../scatter/line_points\"),l=t(\"./helpers\");e.exports=function(t,e,r,c){var u=t._fullLayout,h=e.xaxis,f=e.yaxis;function p(t){var e=s(t,{xaxis:h,yaxis:f,connectGaps:!0,baseTolerance:.75,shape:\"spline\",simplify:!0});return a.smoothopen(e[0],1)}i.makeTraceGroups(c,r,\"trace violins\").each(function(t){var r=n.select(this),a=t[0],s=a.t,c=a.trace;if(!0!==c.visible||s.empty)r.remove();else{var d=s.bPos,g=s.bdPos,v=e[s.valLetter+\"axis\"],m=e[s.posLetter+\"axis\"],y=\"both\"===c.side,x=y||\"positive\"===c.side,b=y||\"negative\"===c.side,_=r.selectAll(\"path.violin\").data(i.identity);_.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"violin\"),_.exit().remove(),_.each(function(t){var e,r,i,a,o,l,h,f,_=n.select(this),w=t.density,k=w.length,T=t.pos+d,A=m.c2p(T);if(c.width)e=s.maxKDE/g;else{var M=u._violinScaleGroupStats[c.scalegroup];e=\"count\"===c.scalemode?M.maxKDE/g*(M.maxCount/t.pts.length):M.maxKDE/g}if(x){for(h=new Array(k),o=0;o<k;o++)(f=h[o]={})[s.posLetter]=T+w[o].v/e,f[s.valLetter]=w[o].t;r=p(h)}if(b){for(h=new Array(k),l=0,o=k-1;l<k;l++,o--)(f=h[l]={})[s.posLetter]=T-w[o].v/e,f[s.valLetter]=w[o].t;i=p(h)}if(y)a=r+\"L\"+i.substr(1)+\"Z\";else{var S=[A,v.c2p(w[0].t)],E=[A,v.c2p(w[k-1].t)];\"h\"===c.orientation&&(S.reverse(),E.reverse()),a=x?\"M\"+S+\"L\"+r.substr(1)+\"L\"+E:\"M\"+E+\"L\"+i.substr(1)+\"L\"+S}_.attr(\"d\",a),t.posCenterPx=A,t.posDensityScale=e*g,t.path=_.node(),t.pathLength=t.path.getTotalLength()/(y?2:1)});var w,k,T,A=c.box,M=A.width,S=(A.line||{}).width;y?(w=g*M,k=0):x?(w=[0,g*M/2],k=-S):(w=[g*M/2,0],k=S),o.plotBoxAndWhiskers(r,{pos:m,val:v},c,{bPos:d,bdPos:w,bPosPxOffset:k}),o.plotBoxMean(r,{pos:m,val:v},c,{bPos:d,bdPos:w,bPosPxOffset:k}),!c.box.visible&&c.meanline.visible&&(T=i.identity);var E=r.selectAll(\"path.meanline\").data(T||[]);E.enter().append(\"path\").attr(\"class\",\"meanline\").style(\"fill\",\"none\").style(\"vector-effect\",\"non-scaling-stroke\"),E.exit().remove(),E.each(function(t){var e=v.c2p(t.mean,!0),r=l.getPositionOnKdePath(t,c,e);n.select(this).attr(\"d\",\"h\"===c.orientation?\"M\"+e+\",\"+r[0]+\"V\"+r[1]:\"M\"+r[0]+\",\"+e+\"H\"+r[1])}),o.plotPoints(r,{x:h,y:f},c,s)}})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../box/plot\":889,\"../scatter/line_points\":1125,\"./helpers\":1242,d3:163}],1248:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../scatter/style\").stylePoints;e.exports=function(t){var e=n.select(t).selectAll(\"g.trace.violins\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.each(function(e){var r=e[0].trace,o=n.select(this),s=r.box||{},l=s.line||{},c=r.meanline||{},u=c.width;o.selectAll(\"path.violin\").style(\"stroke-width\",r.line.width+\"px\").call(i.stroke,r.line.color).call(i.fill,r.fillcolor),o.selectAll(\"path.box\").style(\"stroke-width\",l.width+\"px\").call(i.stroke,l.color).call(i.fill,s.fillcolor);var h={\"stroke-width\":u+\"px\",\"stroke-dasharray\":2*u+\"px,\"+u+\"px\"};o.selectAll(\"path.mean\").style(h).call(i.stroke,c.color),o.selectAll(\"path.meanline\").style(h).call(i.stroke,c.color),a(o,r,t)})}},{\"../../components/color\":593,\"../scatter/style\":1134,d3:163}],1249:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../isosurface/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=e.exports=s(o({x:i.x,y:i.y,z:i.z,value:i.value,isomin:i.isomin,isomax:i.isomax,surface:i.surface,spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:1}},slices:i.slices,caps:i.caps,text:i.text,hovertext:i.hovertext,hovertemplate:i.hovertemplate},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{colorbar:i.colorbar,opacity:i.opacity,opacityscale:{valType:\"any\",editType:\"calc\"},lightposition:i.lightposition,lighting:i.lighting,flatshading:i.flatshading,contour:i.contour,hoverinfo:o({},a.hoverinfo)}),\"calc\",\"nested\");l.x.editType=l.y.editType=l.z.editType=l.value.editType=\"calc+clearAxisTypes\",l.transforms=void 0},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../isosurface/attributes\":1048}],1250:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib/gl_format_color\").parseColorScale,a=t(\"../../lib/str2rgbarray\"),o=t(\"../../components/colorscale\").extractOpts,s=t(\"../../plots/gl3d/zip3\"),l=t(\"../isosurface/convert\").findNearestOnAxis,c=t(\"../isosurface/convert\").generateIsoMeshes;function u(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var h=u.prototype;h.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._x[e],n=this.data._y[e],i=this.data._z[e],a=this.data._Ys.length,o=this.data._Zs.length,s=l(r,this.data._Xs).id,c=l(n,this.data._Ys).id,u=l(i,this.data._Zs).id,h=t.index=u+o*c+o*a*s;t.traceCoordinate=[this.data._x[h],this.data._y[h],this.data._z[h],this.data.value[h]];var f=this.data.hovertext||this.data.text;return Array.isArray(f)&&void 0!==f[h]?t.textLabel=f[h]:f&&(t.textLabel=f),!0}},h.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map(function(e){return t.d2l(e,0,n)*r})}this.data=c(t);var l={positions:s(n(r.xaxis,t._x,e.dataScale[0],t.xcalendar),n(r.yaxis,t._y,e.dataScale[1],t.ycalendar),n(r.zaxis,t._z,e.dataScale[2],t.zcalendar)),cells:s(t._i,t._j,t._k),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,opacityscale:t.opacityscale,contourEnable:t.contour.show,contourColor:a(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},u=o(t);l.vertexIntensity=t._intensity,l.vertexIntensityBounds=[u.min,u.max],l.colormap=i(t),this.mesh.update(l)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new u(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":605,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../../plots/gl3d/zip3\":818,\"../isosurface/convert\":1050,\"gl-mesh3d\":280}],1251:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../isosurface/defaults\").supplyIsoDefaults;e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}a(t,e,r,o,s);var l=s(\"opacityscale\");\"max\"===l?e.opacityscale=[[0,.1],[1,1]]:\"min\"===l?e.opacityscale=[[0,1],[1,.1]]:\"extremes\"===l?e.opacityscale=function(t,e){for(var r=[],n=0;n<32;n++){var i=n/31,a=e+(1-e)*(1-Math.pow(Math.sin(t*i*Math.PI),2));r.push([i,Math.max(1,Math.min(0,a))])}return r}(1,.1):function(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var n=t[r];if(2!==n.length||+n[0]<e)return!1;e=+n[0]}return!0}(l)||(e.opacityscale=void 0)}},{\"../../lib\":719,\"../isosurface/defaults\":1051,\"./attributes\":1249}],1252:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../isosurface/calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"volume\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],meta:{}}},{\"../../plots/gl3d\":807,\"../isosurface/calc\":1049,\"./attributes\":1249,\"./convert\":1250,\"./defaults\":1251}],1253:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"./constants\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../components/color\");function u(t){return{marker:{color:l({},n.marker.color,{arrayOk:!1,editType:\"style\"}),line:{color:l({},n.marker.line.color,{arrayOk:!1,editType:\"style\"}),width:l({},n.marker.line.width,{arrayOk:!1,editType:\"style\"}),editType:\"style\"},editType:\"style\"},editType:\"style\"}}e.exports={measure:{valType:\"data_array\",dflt:[],editType:\"calc\"},base:{valType:\"number\",dflt:null,arrayOk:!1,editType:\"calc\"},x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,hovertext:n.hovertext,hovertemplate:o({},{keys:s.eventDataKeys}),hoverinfo:l({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"initial\",\"delta\",\"final\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"initial\",\"delta\",\"final\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},text:n.text,textposition:n.textposition,insidetextanchor:n.insidetextanchor,textangle:n.textangle,textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:n.orientation,offset:n.offset,width:n.width,increasing:u(),decreasing:u(),totals:u(),connector:{line:{color:l({},i.color,{dflt:c.defaultLine}),width:l({},i.width,{editType:\"plot\"}),dash:i.dash,editType:\"plot\"},mode:{valType:\"enumerated\",values:[\"spanning\",\"between\"],dflt:\"between\",editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":593,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../bar/attributes\":857,\"../scatter/attributes\":1112,\"./constants\":1255}],1254:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\").mergeArray,a=t(\"../scatter/calc_selection\"),o=t(\"../../constants/numerical\").BADNUM;function s(t){return\"a\"===t||\"absolute\"===t}function l(t){return\"t\"===t||\"total\"===t}e.exports=function(t,e){var r,c,u=n.getFromId(t,e.xaxis||\"x\"),h=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=u.makeCalcdata(e,\"x\"),c=h.makeCalcdata(e,\"y\")):(r=h.makeCalcdata(e,\"y\"),c=u.makeCalcdata(e,\"x\"));for(var f,p=Math.min(c.length,r.length),d=new Array(p),g=0,v=!1,m=0;m<p;m++){var y=r[m]||0,x=!1;(r[m]!==o||l(e.measure[m])||s(e.measure[m]))&&m+1<p&&(r[m+1]!==o||l(e.measure[m+1])||s(e.measure[m+1]))&&(x=!0);var b=d[m]={i:m,p:c[m],s:y,rawS:y,cNext:x};s(e.measure[m])?(g=b.s,b.isSum=!0,b.dir=\"totals\",b.s=g):l(e.measure[m])?(b.isSum=!0,b.dir=\"totals\",b.s=g):(b.isSum=!1,b.dir=b.rawS<0?\"decreasing\":\"increasing\",f=b.s,b.s=g+f,g+=f),\"totals\"===b.dir&&(v=!0),e.ids&&(b.id=String(e.ids[m])),b.v=(e.base||0)+g}return d.length&&(d[0].hasTotals=v),i(e.text,d,\"tx\"),i(e.hovertext,d,\"htx\"),a(d,e),d}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scatter/calc_selection\":1114}],1255:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"initial\",\"delta\",\"final\"]}},{}],1256:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],h=[],f=[];for(i=0;i<o.length;i++){var p=o[i];!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"waterfall\"===p.type&&(r=s[i],\"h\"===p.orientation?f.push(r):h.push(r),u.push(r))}var d={mode:a.waterfallmode,norm:a.waterfallnorm,gap:a.waterfallgap,groupgap:a.waterfallgroupgap};for(n(t,l,c,h,d),n(t,c,l,f,d),i=0;i<u.length;i++){r=u[i];for(var g=0;g<r.length;g++){var v=r[g];!1===v.isSum&&(v.s0+=0===g?0:r[g-1].s),g+1<r.length&&(r[g].nextP0=r[g+1].p0,r[g].nextS0=r[g+1].s0)}}}},{\"../bar/cross_trace_calc\":860}],1257:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"./attributes\"),l=t(\"../../components/color\"),c=t(\"../../constants/delta.js\"),u=c.INCREASING.COLOR,h=c.DECREASING.COLOR,f=\"#4499FF\";function p(t,e,r){t(e+\".marker.color\",r),t(e+\".marker.line.color\",l.defaultLine),t(e+\".marker.line.width\")}e.exports={supplyDefaults:function(t,e,r,i){function l(r,i){return n.coerce(t,e,s,r,i)}if(o(t,e,i,l)){l(\"measure\"),l(\"orientation\",e.x&&!e.y?\"h\":\"v\"),l(\"base\"),l(\"offset\"),l(\"width\"),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\");var c=l(\"textposition\");a(t,e,i,l,c,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"!==e.textposition&&l(\"textinfo\"),p(l,\"increasing\",u),p(l,\"decreasing\",h),p(l,\"totals\",f),l(\"connector.visible\")&&(l(\"connector.mode\"),l(\"connector.line.width\")&&(l(\"connector.line.color\"),l(\"connector.line.dash\")))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,s,t)}if(\"group\"===e.waterfallmode)for(var l=0;l<t.length;l++)r=(a=t[l])._input,i(r,a,e,o)}}},{\"../../components/color\":593,\"../../constants/delta.js\":689,\"../../lib\":719,\"../bar/defaults\":861,\"../scatter/xy_defaults\":1137,\"./attributes\":1253}],1258:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"initial\"in e&&(t.initial=e.initial),\"delta\"in e&&(t.delta=e.delta),\"final\"in e&&(t.final=e.final),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],1259:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\").hoverLabelText,i=t(\"../../components/color\").opacity,a=t(\"../bar/hover\").hoverOnBars,o=t(\"../../constants/delta.js\"),s=o.INCREASING.SYMBOL,l=o.DECREASING.SYMBOL;e.exports=function(t,e,r,o){var c=a(t,e,r,o);if(c){var u=c.cd,h=u[0].trace,f=\"h\"===h.orientation,p=f?t.xa:t.ya,d=u[c.index],g=d.isSum?d.b+d.s:d.rawS;if(!d.isSum){c.initial=d.b+d.s-g,c.delta=g,c.final=c.initial+c.delta;var v=w(Math.abs(c.delta));c.deltaLabel=g<0?\"(\"+v+\")\":v,c.finalLabel=w(c.final),c.initialLabel=w(c.initial)}var m=d.hi||h.hoverinfo,y=[];if(m&&\"none\"!==m&&\"skip\"!==m){var x=\"all\"===m,b=m.split(\"+\"),_=function(t){return x||-1!==b.indexOf(t)};d.isSum||(!_(\"final\")||_(f?\"x\":\"y\")||y.push(c.finalLabel),_(\"delta\")&&(g<0?y.push(c.deltaLabel+\" \"+l):y.push(c.deltaLabel+\" \"+s)),_(\"initial\")&&y.push(\"Initial: \"+c.initialLabel))}return y.length&&(c.extraText=y.join(\"<br>\")),c.color=function(t,e){var r=t[e.dir].marker,n=r.color,a=r.line.color,o=r.line.width;if(i(n))return n;if(i(a)&&o)return a}(h,d),[c]}function w(t){return n(p,t)}}},{\"../../components/color\":593,\"../../constants/delta.js\":689,\"../../plots/cartesian/axes\":767,\"../bar/hover\":863}],1260:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"waterfall\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../bar/select\":868,\"./attributes\":1253,\"./calc\":1254,\"./cross_trace_calc\":1256,\"./defaults\":1257,\"./event_data\":1258,\"./hover\":1259,\"./layout_attributes\":1261,\"./layout_defaults\":1262,\"./plot\":1263,\"./style\":1264}],1261:[function(t,e,r){\"use strict\";e.exports={waterfallmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"group\",editType:\"calc\"},waterfallgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},waterfallgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],1262:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"waterfall\"===l.type){a=!0;break}}a&&(o(\"waterfallmode\"),o(\"waterfallgap\",.2),o(\"waterfallgroupgap\"))}},{\"../../lib\":719,\"./layout_attributes\":1261}],1263:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../bar/plot\").plot;e.exports=function(t,e,r,s){var l=t._fullLayout;o(t,e,r,s,{mode:l.waterfallmode,norm:l.waterfallmode,gap:l.waterfallgap,groupgap:l.waterfallgroupgap}),function(t,e,r,o){var s=e.xaxis,l=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each(function(r){var o=n.select(this),c=r[0].trace,u=i.ensureSingle(o,\"g\",\"lines\");if(c.connector&&c.connector.visible){var h=\"h\"===c.orientation,f=c.connector.mode,p=u.selectAll(\"g.line\").data(i.identity);p.enter().append(\"g\").classed(\"line\",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var c=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),n?[i,a]:[a,i]}(r,s,l,h),u=c[0],p=c[1],g=\"\";\"spanning\"===f&&!r.isSum&&o>0&&(g+=h?\"M\"+u[0]+\",\"+p[1]+\"V\"+p[0]:\"M\"+u[1]+\",\"+p[0]+\"H\"+u[0]),\"between\"!==f&&(r.isSum||o<d-1)&&(g+=h?\"M\"+u[1]+\",\"+p[0]+\"V\"+p[1]:\"M\"+u[0]+\",\"+p[1]+\"H\"+u[1]),void 0!==u[2]&&void 0!==p[2]&&(g+=h?\"M\"+u[1]+\",\"+p[1]+\"V\"+p[2]:\"M\"+u[1]+\",\"+p[1]+\"H\"+u[2]),\"\"===g&&(g=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}})}else u.remove()})}(t,e,r,s)}},{\"../../components/drawing\":614,\"../../lib\":719,\"../bar/plot\":867,d3:163}],1264:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\").styleTextPoints;e.exports={style:function(t,e,r){var l=r||n.select(t).selectAll(\"g.waterfalllayer\").selectAll(\"g.trace\");l.style(\"opacity\",function(t){return t[0].trace.opacity}),l.each(function(e){var r=n.select(this),l=e[0].trace;r.selectAll(\".point > path\").each(function(t){if(!t.isBlank){var e=l[t.dir].marker;n.select(this).call(a.fill,e.color).call(a.stroke,e.line.color).call(i.dashLine,e.line.dash,e.line.width).style(\"opacity\",l.selectedpoints&&!t.selected?o:1)}}),s(r,l,t),r.selectAll(\".lines\").each(function(){var t=l.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)})})}}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../constants/interactions\":694,\"../bar/style\":870,d3:163}],1265:[function(t,e,r){\"use strict\";var n=t(\"../plots/cartesian/axes\"),i=t(\"../lib\"),a=t(\"../plot_api/plot_schema\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/numerical\").BADNUM;r.moduleType=\"transform\",r.name=\"aggregate\";var l=r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},aggregations:{_isLinkedToArray:\"aggregation\",target:{valType:\"string\",editType:\"calc\"},func:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"median\",\"mode\",\"rms\",\"stddev\",\"min\",\"max\",\"first\",\"last\",\"change\",\"range\"],dflt:\"first\",editType:\"calc\"},funcmode:{valType:\"enumerated\",values:[\"sample\",\"population\"],dflt:\"sample\",editType:\"calc\"},enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},c=l.aggregations;function u(t,e,r,a){if(a.enabled){for(var o=a.target,l=i.nestedProperty(e,o),c=l.get(),u=function(t,e){var r=t.func,n=e.d2c,i=e.c2d;switch(r){case\"count\":return h;case\"first\":return f;case\"last\":return p;case\"sum\":return function(t,e){for(var r=0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r+=o)}return i(r)};case\"avg\":return function(t,e){for(var r=0,a=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l,a++)}return a?i(r/a):s};case\"min\":return function(t,e){for(var r=1/0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r=Math.min(r,o))}return r===1/0?s:i(r)};case\"max\":return function(t,e){for(var r=-1/0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r=Math.max(r,o))}return r===-1/0?s:i(r)};case\"range\":return function(t,e){for(var r=1/0,a=-1/0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r=Math.min(r,l),a=Math.max(a,l))}return a===-1/0||r===1/0?s:i(a-r)};case\"change\":return function(t,e){var r=n(t[e[0]]),a=n(t[e[e.length-1]]);return r===s||a===s?s:i(a-r)};case\"median\":return function(t,e){for(var r=[],a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&r.push(o)}if(!r.length)return s;r.sort();var l=(r.length-1)/2;return i((r[Math.floor(l)]+r[Math.ceil(l)])/2)};case\"mode\":return function(t,e){for(var r={},a=0,o=s,l=0;l<e.length;l++){var c=n(t[e[l]]);if(c!==s){var u=r[c]=(r[c]||0)+1;u>a&&(a=u,o=c)}}return a?i(o):s};case\"rms\":return function(t,e){for(var r=0,a=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l*l,a++)}return a?i(Math.sqrt(r/a)):s};case\"stddev\":return function(e,r){var i,a=0,o=0,l=1,c=s;for(i=0;i<r.length&&c===s;i++)c=n(e[r[i]]);if(c===s)return s;for(;i<r.length;i++){var u=n(e[r[i]]);if(u!==s){var h=u-c;a+=h,o+=h*h,l++}}var f=\"sample\"===t.funcmode?l-1:l;return f?Math.sqrt((o-a*a/l)/f):0}}}(a,n.getDataConversions(t,e,o,c)),d=new Array(r.length),g=0;g<r.length;g++)d[g]=u(c,r[g]);l.set(d),\"count\"===a.func&&i.pushUnique(e._arrayAttrs,o)}}function h(t,e){return e.length}function f(t,e){return t[e[0]]}function p(t,e){return t[e[e.length-1]]}r.supplyDefaults=function(t,e){var r,n={};function o(e,r){return i.coerce(t,n,l,e,r)}if(!o(\"enabled\"))return n;var s=a.findArrayAttributes(e),u={};for(r=0;r<s.length;r++)u[s[r]]=1;var h=o(\"groups\");if(!Array.isArray(h)){if(!u[h])return n.enabled=!1,n;u[h]=0}var f,p=t.aggregations||[],d=n.aggregations=new Array(p.length);function g(t,e){return i.coerce(p[r],f,c,t,e)}for(r=0;r<p.length;r++){f={_index:r};var v=g(\"target\"),m=g(\"func\");g(\"enabled\")&&v&&(u[v]||\"count\"===m&&void 0===u[v])?(\"stddev\"===m&&g(\"funcmode\"),u[v]=0,d[r]=f):d[r]={enabled:!1,_index:r}}for(r=0;r<s.length;r++)u[s[r]]&&d.push({target:s[r],func:c.func.dflt,enabled:!0,_index:-1});return n},r.calcTransform=function(t,e,r){if(r.enabled){var n=r.groups,a=i.getTargetArray(e,{target:n});if(a){var s,l,c,h,f={},p={},d=[],g=o(e.transforms,r),v=a.length;for(e._length&&(v=Math.min(v,e._length)),s=0;s<v;s++)void 0===(c=f[l=a[s]])?(f[l]=d.length,h=[s],d.push(h),p[f[l]]=g(s)):(d[c].push(s),p[f[l]]=(p[f[l]]||[]).concat(g(s)));r._indexToPoints=p;var m=r.aggregations;for(s=0;s<m.length;s++)u(t,e,d,m[s]);\"string\"==typeof n&&u(t,e,d,{target:n,func:\"first\",enabled:!0}),e._length=d.length}}}},{\"../constants/numerical\":695,\"../lib\":719,\"../plot_api/plot_schema\":756,\"../plots/cartesian/axes\":767,\"./helpers\":1268}],1266:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../registry\"),a=t(\"../plots/cartesian/axes\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/filter_ops\"),l=s.COMPARISON_OPS,c=s.INTERVAL_OPS,u=s.SET_OPS;r.moduleType=\"transform\",r.name=\"filter\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},operation:{valType:\"enumerated\",values:[].concat(l).concat(c).concat(u),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},preservegaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function a(i,a){return n.coerce(t,e,r.attributes,i,a)}if(a(\"enabled\")){var o=a(\"target\");if(n.isArrayOrTypedArray(o)&&0===o.length)return e.enabled=!1,e;a(\"preservegaps\"),a(\"operation\"),a(\"value\");var s=i.getComponentMethod(\"calendars\",\"handleDefaults\");s(t,e,\"valuecalendar\",null),s(t,e,\"targetcalendar\",null)}return e},r.calcTransform=function(t,e,r){if(r.enabled){var i=n.getTargetArray(e,r);if(i){var s=r.target,h=i.length;e._length&&(h=Math.min(h,e._length));var f=r.targetcalendar,p=e._arrayAttrs,d=r.preservegaps;if(\"string\"==typeof s){var g=n.nestedProperty(e,s+\"calendar\").get();g&&(f=g)}var v,m,y=function(t,e,r){var n=t.operation,i=t.value,a=Array.isArray(i);function o(t){return-1!==t.indexOf(n)}var s,h=function(r){return e(r,0,t.valuecalendar)},f=function(t){return e(t,0,r)};o(l)?s=h(a?i[0]:i):o(c)?s=a?[h(i[0]),h(i[1])]:[h(i),h(i)]:o(u)&&(s=a?i.map(h):[h(i)]);switch(n){case\"=\":return function(t){return f(t)===s};case\"!=\":return function(t){return f(t)!==s};case\"<\":return function(t){return f(t)<s};case\"<=\":return function(t){return f(t)<=s};case\">\":return function(t){return f(t)>s};case\">=\":return function(t){return f(t)>=s};case\"[]\":return function(t){var e=f(t);return e>=s[0]&&e<=s[1]};case\"()\":return function(t){var e=f(t);return e>s[0]&&e<s[1]};case\"[)\":return function(t){var e=f(t);return e>=s[0]&&e<s[1]};case\"(]\":return function(t){var e=f(t);return e>s[0]&&e<=s[1]};case\"][\":return function(t){var e=f(t);return e<=s[0]||e>=s[1]};case\")(\":return function(t){var e=f(t);return e<s[0]||e>s[1]};case\"](\":return function(t){var e=f(t);return e<=s[0]||e>s[1]};case\")[\":return function(t){var e=f(t);return e<s[0]||e>=s[1]};case\"{}\":return function(t){return-1!==s.indexOf(f(t))};case\"}{\":return function(t){return-1===s.indexOf(f(t))}}}(r,a.getDataToCoordFunc(t,e,s,i),f),x={},b={},_=0;d?(v=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set(new Array(h))},m=function(t,e){var r=x[t.astr][e];t.get()[e]=r}):(v=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set([])},m=function(t,e){var r=x[t.astr][e];t.get().push(r)}),T(v);for(var w=o(e.transforms,r),k=0;k<h;k++){y(i[k])?(T(m,k),b[_++]=w(k)):d&&_++}r._indexToPoints=b,e._length=_}}function T(t,r){for(var i=0;i<p.length;i++){t(n.nestedProperty(e,p[i]),r)}}}},{\"../constants/filter_ops\":691,\"../lib\":719,\"../plots/cartesian/axes\":767,\"../registry\":847,\"./helpers\":1268}],1267:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_schema\"),a=t(\"../plots/plots\"),o=t(\"./helpers\").pointsAccessorFunction;function s(t,e){var r,s,l,c,u,h,f,p,d,g,v=e.transform,m=e.transformIndex,y=t.transforms[m].groups,x=o(t.transforms,v);if(!Array.isArray(y)||0===y.length)return[t];var b=n.filterUnique(y),_=new Array(b.length),w=y.length,k=i.findArrayAttributes(t),T=v.styles||[],A={};for(r=0;r<T.length;r++)A[T[r].target]=T[r].value;v.styles&&(g=n.keyedContainer(v,\"styles\",\"target\",\"value.name\"));var M={},S={};for(r=0;r<b.length;r++){M[h=b[r]]=r,S[h]=0,(f=_[r]=n.extendDeepNoArrays({},t))._group=h,f.transforms[m]._indexToPoints={};var E=null;for(g&&(E=g.get(h)),f.name=E||\"\"===E?E:n.templateString(v.nameformat,{trace:t.name,group:h}),p=f.transforms,f.transforms=[],s=0;s<p.length;s++)f.transforms[s]=n.extendDeepNoArrays({},p[s]);for(s=0;s<k.length;s++)n.nestedProperty(f,k[s]).set([])}for(l=0;l<k.length;l++){for(c=k[l],s=0,d=[];s<b.length;s++)d[s]=n.nestedProperty(_[s],c).get();for(u=n.nestedProperty(t,c).get(),s=0;s<w;s++)d[M[y[s]]].push(u[s])}for(s=0;s<w;s++){(f=_[M[y[s]]]).transforms[m]._indexToPoints[S[y[s]]]=x(s),S[y[s]]++}for(r=0;r<b.length;r++)h=b[r],f=_[r],a.clearExpandedTraceDefaultColors(f),f=n.extendDeepNoArrays(f,A[h]||{});return _}r.moduleType=\"transform\",r.name=\"groupby\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"data_array\",dflt:[],editType:\"calc\"},nameformat:{valType:\"string\",editType:\"calc\"},styles:{_isLinkedToArray:\"style\",target:{valType:\"string\",editType:\"calc\"},value:{valType:\"any\",dflt:{},editType:\"calc\",_compareAsJSON:!0},editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t,e,i){var a,o={};function s(e,i){return n.coerce(t,o,r.attributes,e,i)}if(!s(\"enabled\"))return o;s(\"groups\"),s(\"nameformat\",i._dataLength>1?\"%{group} (%{trace})\":\"%{group}\");var l=t.styles,c=o.styles=[];if(l)for(a=0;a<l.length;a++){var u=c[a]={};n.coerce(l[a],c[a],r.attributes.styles,\"target\");var h=n.coerce(l[a],c[a],r.attributes.styles,\"value\");n.isPlainObject(h)?u.value=n.extendDeep({},h):h&&delete u.value}return o},r.transform=function(t,e){var r,n,i,a=[];for(n=0;n<t.length;n++)for(r=s(t[n],e),i=0;i<r.length;i++)a.push(r[i]);return a}},{\"../lib\":719,\"../plot_api/plot_schema\":756,\"../plots/plots\":828,\"./helpers\":1268}],1268:[function(t,e,r){\"use strict\";r.pointsAccessorFunction=function(t,e){for(var r,n,i=0;i<t.length&&(r=t[i])!==e;i++)r._indexToPoints&&!1!==r.enabled&&(n=r._indexToPoints);return n?function(t){return n[t]}:function(t){return[t]}}},{}],1269:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/cartesian/axes\"),a=t(\"./helpers\").pointsAccessorFunction;r.moduleType=\"transform\",r.name=\"sort\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},order:{valType:\"enumerated\",values:[\"ascending\",\"descending\"],dflt:\"ascending\",editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function i(i,a){return n.coerce(t,e,r.attributes,i,a)}return i(\"enabled\")&&(i(\"target\"),i(\"order\")),e},r.calcTransform=function(t,e,r){if(r.enabled){var o=n.getTargetArray(e,r);if(o){var s=r.target,l=o.length;e._length&&(l=Math.min(l,e._length));var c,u,h=e._arrayAttrs,f=function(t,e,r,n){var i,a=new Array(n),o=new Array(n);for(i=0;i<n;i++)a[i]={v:e[i],i:i};for(a.sort(function(t,e){switch(t.order){case\"ascending\":return function(t,r){return e(t.v)-e(r.v)};case\"descending\":return function(t,r){return e(r.v)-e(t.v)}}}(t,r)),i=0;i<n;i++)o[i]=a[i].i;return o}(r,o,i.getDataToCoordFunc(t,e,s,o),l),p=a(e.transforms,r),d={};for(c=0;c<h.length;c++){var g=n.nestedProperty(e,h[c]),v=g.get(),m=new Array(l);for(u=0;u<l;u++)m[u]=v[f[u]];g.set(m)}for(u=0;u<l;u++)d[u]=p(f[u]);r._indexToPoints=d,e._length=l}}}},{\"../lib\":719,\"../plots/cartesian/axes\":767,\"./helpers\":1268}]},{},[25])(25)});</script>    \n",
       "            <div id=\"70518565-ae2b-43ec-aec9-f67ceff5f0a8\" class=\"plotly-graph-div\" style=\"height:600px; width:500px;\"></div>\n",
       "            <script type=\"text/javascript\">\n",
       "                \n",
       "                    window.PLOTLYENV=window.PLOTLYENV || {};\n",
       "                    \n",
       "                if (document.getElementById(\"70518565-ae2b-43ec-aec9-f67ceff5f0a8\")) {\n",
       "                    Plotly.newPlot(\n",
       "                        '70518565-ae2b-43ec-aec9-f67ceff5f0a8',\n",
       "                        [{\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"A = 0.5\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.05, 0.07071067811865475, 0.08660254037844388, 0.1, 0.1118033988749895, 0.12247448713915891, 0.13228756555322954, 0.1414213562373095, 0.15, 0.15811388300841897, 0.16583123951777, 0.17320508075688776, 0.18027756377319948, 0.18708286933869708, 0.19364916731037082, 0.2, 0.20615528128088303, 0.21213203435596426, 0.21794494717703372, 0.223606797749979, 0.22912878474779202, 0.2345207879911715, 0.239791576165636, 0.24494897427831783, 0.25, 0.25495097567963926, 0.2598076211353316, 0.2645751311064591, 0.26925824035672524, 0.27386127875258304, 0.2783882181415011, 0.282842712474619, 0.2872281323269015, 0.29154759474226505, 0.2958039891549808, 0.3, 0.304138126514911, 0.3082207001484488, 0.31224989991991997, 0.31622776601683794, 0.32015621187164245, 0.32403703492039304, 0.32787192621510003, 0.33166247903554, 0.33541019662496846, 0.3391164991562634, 0.3427827300200522, 0.3464101615137755, 0.35000000000000003, 0.3535533905932738, 0.35707142142714254, 0.36055512754639896, 0.36400549446402597, 0.3674234614174767, 0.37080992435478316, 0.37416573867739417, 0.3774917217635375, 0.38078865529319544, 0.3840572873934304, 0.38729833462074165, 0.3905124837953327, 0.3937003937005905, 0.3968626966596886, 0.4, 0.40311288741492746, 0.406201920231798, 0.40926763859362253, 0.41231056256176607, 0.4153311931459038, 0.4183300132670378, 0.42130748865881795, 0.4242640687119285, 0.42720018726587655, 0.4301162633521313, 0.43301270189221935, 0.43588989435406744, 0.4387482193696061, 0.4415880433163924, 0.44440972086577946, 0.447213595499958, 0.45, 0.45276925690687087, 0.45552167895721496, 0.45825756949558405, 0.4609772228646444, 0.46368092477478523, 0.4663689526544408, 0.469041575982343, 0.4716990566028302, 0.4743416490252569, 0.47696960070847283, 0.479583152331272, 0.4821825380496478, 0.48476798574163293, 0.48733971724044817, 0.48989794855663565, 0.4924428900898053, 0.4949747468305833, 0.49749371855331004, 0.5, 0.5024937810560446], [0.0, 0.07071067811865475, 0.09999999999999999, 0.12247448713915891, 0.1414213562373095, 0.15811388300841897, 0.17320508075688773, 0.18708286933869706, 0.19999999999999998, 0.21213203435596426, 0.22360679774997896, 0.2345207879911715, 0.24494897427831783, 0.25495097567963926, 0.264575131106459, 0.27386127875258304, 0.282842712474619, 0.291547594742265, 0.3, 0.3082207001484488, 0.31622776601683794, 0.32403703492039304, 0.33166247903553997, 0.3391164991562634, 0.34641016151377546, 0.3535533905932738, 0.36055512754639896, 0.3674234614174767, 0.3741657386773941, 0.38078865529319544, 0.38729833462074165, 0.39370039370059057, 0.39999999999999997, 0.406201920231798, 0.41231056256176607, 0.4183300132670378, 0.4242640687119285, 0.4301162633521313, 0.4358898943540674, 0.44158804331639234, 0.4472135954999579, 0.45276925690687087, 0.45825756949558405, 0.4636809247747851, 0.469041575982343, 0.47434164902525683, 0.47958315233127197, 0.4847679857416329, 0.48989794855663565, 0.49497474683058323, 0.5, 0.5049752469181039, 0.5099019513592785, 0.5147815070493501, 0.5196152422706632, 0.5244044240850758, 0.529150262212918, 0.5338539126015656, 0.5385164807134504, 0.5431390245600107, 0.5477225575051661, 0.552268050859363, 0.5567764362830021, 0.5612486080160912, 0.565685424949238, 0.5700877125495689, 0.5744562646538028, 0.5787918451395112, 0.58309518948453, 0.5873670062235365, 0.5916079783099616, 0.5958187643906492, 0.6, 0.6041522986797286, 0.6082762530298219, 0.6123724356957945, 0.6164414002968976, 0.6204836822995429, 0.6244997998398398, 0.6284902544988268, 0.6324555320336759, 0.6363961030678927, 0.6403124237432849, 0.6442049363362562, 0.6480740698407861, 0.6519202405202649, 0.6557438524302001, 0.6595452979136459, 0.6633249580710799, 0.6670832032063166, 0.6708203932499369, 0.674536878161602, 0.6782329983125268, 0.6819090848492928, 0.6855654600401044, 0.689202437604511, 0.6928203230275509, 0.696419413859206, 0.7, 0.7035623639735145, 0.7071067811865476, 0.7106335201775948], [0.0, 0.08660254037844388, 0.12247448713915891, 0.15000000000000005, 0.17320508075688776, 0.19364916731037088, 0.21213203435596428, 0.22912878474779202, 0.24494897427831783, 0.2598076211353316, 0.2738612787525831, 0.2872281323269015, 0.3000000000000001, 0.31224989991991997, 0.32403703492039304, 0.33541019662496846, 0.3464101615137755, 0.35707142142714254, 0.3674234614174768, 0.37749172176353757, 0.38729833462074176, 0.39686269665968865, 0.4062019202317981, 0.41533119314590383, 0.42426406871192857, 0.4330127018922194, 0.44158804331639245, 0.45000000000000007, 0.45825756949558405, 0.46636895265444084, 0.47434164902525694, 0.48218253804964784, 0.48989794855663565, 0.4974937185533101, 0.504975246918104, 0.51234753829798, 0.5196152422706632, 0.526782687642637, 0.5338539126015657, 0.5408326913195985, 0.5477225575051662, 0.5545268253204709, 0.5612486080160913, 0.5678908345800274, 0.574456264653803, 0.5809475019311126, 0.5873670062235367, 0.593717104351896, 0.6000000000000002, 0.6062177826491071, 0.6123724356957946, 0.6184658438426492, 0.6244997998398399, 0.6304760106459247, 0.6363961030678928, 0.6422616289332566, 0.6480740698407861, 0.6538348415311012, 0.6595452979136461, 0.6652067347825036, 0.6708203932499369, 0.6763874629234342, 0.6819090848492928, 0.6873863542433761, 0.692820323027551, 0.6982120021884471, 0.7035623639735146, 0.7088723439378913, 0.7141428428542851, 0.7193747284969081, 0.7245688373094721, 0.7297259759663213, 0.7348469228349536, 0.7399324293474372, 0.744983221287567, 0.7500000000000001, 0.7549834435270751, 0.7599342076785333, 0.7648529270389179, 0.7697402159170328, 0.7745966692414835, 0.7794228634059949, 0.7842193570679062, 0.7889866919029751, 0.7937253933193773, 0.7984359711335658, 0.8031189202104506, 0.8077747210701758, 0.8124038404635961, 0.8170067319184097, 0.8215838362577492, 0.8261355820929154, 0.8306623862918077, 0.8351646544245035, 0.8396427811873334, 0.8440971508067067, 0.8485281374238571, 0.8529361054615993, 0.8573214099741124, 0.8616843969807044, 0.8660254037844388, 0.8703447592764607], [0.0, 0.1, 0.1414213562373095, 0.17320508075688776, 0.2, 0.223606797749979, 0.24494897427831783, 0.2645751311064591, 0.282842712474619, 0.3, 0.31622776601683794, 0.33166247903554, 0.3464101615137755, 0.36055512754639896, 0.37416573867739417, 0.38729833462074165, 0.4, 0.41231056256176607, 0.4242640687119285, 0.43588989435406744, 0.447213595499958, 0.45825756949558405, 0.469041575982343, 0.479583152331272, 0.48989794855663565, 0.5, 0.5099019513592785, 0.5196152422706632, 0.5291502622129182, 0.5385164807134505, 0.5477225575051661, 0.5567764362830022, 0.565685424949238, 0.574456264653803, 0.5830951894845301, 0.5916079783099616, 0.6, 0.608276253029822, 0.6164414002968976, 0.6244997998398399, 0.6324555320336759, 0.6403124237432849, 0.6480740698407861, 0.6557438524302001, 0.66332495807108, 0.6708203932499369, 0.6782329983125268, 0.6855654600401044, 0.692820323027551, 0.7000000000000001, 0.7071067811865476, 0.7141428428542851, 0.7211102550927979, 0.7280109889280519, 0.7348469228349535, 0.7416198487095663, 0.7483314773547883, 0.754983443527075, 0.7615773105863909, 0.7681145747868608, 0.7745966692414833, 0.7810249675906654, 0.787400787401181, 0.7937253933193772, 0.8, 0.8062257748298549, 0.812403840463596, 0.8185352771872451, 0.8246211251235321, 0.8306623862918076, 0.8366600265340756, 0.8426149773176359, 0.848528137423857, 0.8544003745317531, 0.8602325267042626, 0.8660254037844387, 0.8717797887081349, 0.8774964387392122, 0.8831760866327848, 0.8888194417315589, 0.894427190999916, 0.9, 0.9055385138137417, 0.9110433579144299, 0.9165151389911681, 0.9219544457292888, 0.9273618495495705, 0.9327379053088816, 0.938083151964686, 0.9433981132056604, 0.9486832980505138, 0.9539392014169457, 0.959166304662544, 0.9643650760992956, 0.9695359714832659, 0.9746794344808963, 0.9797958971132713, 0.9848857801796106, 0.9899494936611666, 0.9949874371066201, 1.0, 1.0049875621120892], [0.0, 0.1118033988749895, 0.15811388300841897, 0.19364916731037088, 0.223606797749979, 0.25000000000000006, 0.2738612787525831, 0.29580398915498085, 0.31622776601683794, 0.33541019662496846, 0.3535533905932738, 0.3708099243547832, 0.38729833462074176, 0.4031128874149275, 0.4183300132670378, 0.4330127018922193, 0.447213595499958, 0.4609772228646444, 0.47434164902525694, 0.4873397172404483, 0.5000000000000001, 0.51234753829798, 0.5244044240850758, 0.5361902647381805, 0.5477225575051662, 0.5590169943749475, 0.570087712549569, 0.5809475019311127, 0.5916079783099617, 0.6020797289396148, 0.6123724356957946, 0.6224949798994367, 0.6324555320336759, 0.6422616289332566, 0.651920240520265, 0.6614378277661477, 0.6708203932499369, 0.6800735254367722, 0.6892024376045112, 0.6982120021884471, 0.7071067811865476, 0.7158910531638177, 0.7245688373094721, 0.733143914930759, 0.7416198487095664, 0.75, 0.7582875444051551, 0.7664854858377946, 0.7745966692414835, 0.7826237921249265, 0.7905694150420949, 0.7984359711335658, 0.806225774829855, 0.8139410298049855, 0.8215838362577492, 0.8291561975888501, 0.8366600265340756, 0.8440971508067067, 0.8514693182963202, 0.8587782018658834, 0.8660254037844386, 0.873212459828649, 0.8803408430829505, 0.8874119674649424, 0.894427190999916, 0.9013878188659973, 0.9082951062292476, 0.9151502608861564, 0.9219544457292888, 0.9287087810503356, 0.9354143466934854, 0.9420721840708387, 0.9486832980505139, 0.95524865872714, 0.9617692030835673, 0.9682458365518543, 0.9746794344808966, 0.9810708435174292, 0.9874208829065751, 0.9937303457175897, 1.0000000000000002, 1.0062305898749055, 1.0124228365658294, 1.0185774393731681, 1.02469507659596, 1.0307764064044151, 1.0368220676663862, 1.0428326807307107, 1.0488088481701516, 1.0547511554864493, 1.0606601717798214, 1.0665364503850772, 1.072380529476361, 1.0781929326423914, 1.0839741694339402, 1.0897247358851685, 1.0954451150103324, 1.1011357772772623, 1.1067971810589328, 1.1124297730643495, 1.118033988749895, 1.1236102527122118], [0.0, 0.12247448713915891, 0.17320508075688773, 0.21213203435596428, 0.24494897427831783, 0.2738612787525831, 0.30000000000000004, 0.32403703492039304, 0.34641016151377546, 0.3674234614174767, 0.3872983346207417, 0.4062019202317981, 0.42426406871192857, 0.4415880433163924, 0.458257569495584, 0.4743416490252569, 0.48989794855663565, 0.5049752469181039, 0.5196152422706632, 0.5338539126015657, 0.5477225575051662, 0.5612486080160912, 0.574456264653803, 0.5873670062235365, 0.6000000000000001, 0.6123724356957946, 0.6244997998398399, 0.6363961030678928, 0.6480740698407861, 0.659545297913646, 0.6708203932499369, 0.6819090848492928, 0.6928203230275509, 0.7035623639735146, 0.7141428428542851, 0.724568837309472, 0.7348469228349535, 0.744983221287567, 0.754983443527075, 0.7648529270389178, 0.7745966692414834, 0.7842193570679062, 0.7937253933193773, 0.8031189202104505, 0.8124038404635961, 0.8215838362577491, 0.8306623862918076, 0.8396427811873333, 0.8485281374238571, 0.8573214099741123, 0.8660254037844387, 0.8746427842267952, 0.8831760866327848, 0.8916277250063506, 0.9, 0.9082951062292476, 0.916515138991168, 0.9246621004453465, 0.9327379053088816, 0.9407443861113389, 0.9486832980505138, 0.9565563234854496, 0.9643650760992954, 0.9721111047611791, 0.9797958971132713, 0.9874208829065749, 0.99498743710662, 1.002496882788171, 1.0099504938362078, 1.0173494974687902, 1.02469507659596, 1.0319883720275147, 1.0392304845413265, 1.0464224768228174, 1.0535653752852738, 1.0606601717798214, 1.0677078252031313, 1.074709263010234, 1.0816653826391969, 1.088577052853862, 1.0954451150103324, 1.1022703842524302, 1.1090536506409419, 1.1157956802210698, 1.1224972160321824, 1.1291589790636216, 1.1357816691600549, 1.1423659658795864, 1.148912529307606, 1.1554220008291343, 1.161895003862225, 1.1683321445547923, 1.174734012447073, 1.1811011811017718, 1.187434208703792, 1.1937336386313322, 1.2000000000000002, 1.206233808181482, 1.2124355652982142, 1.2186057606953942, 1.2247448713915892, 1.2308533625091174], [0.0, 0.13228756555322954, 0.18708286933869706, 0.22912878474779202, 0.2645751311064591, 0.29580398915498085, 0.32403703492039304, 0.35000000000000003, 0.3741657386773941, 0.3968626966596886, 0.4183300132670378, 0.4387482193696061, 0.45825756949558405, 0.4769696007084729, 0.4949747468305833, 0.5123475382979799, 0.5291502622129182, 0.5454356057317857, 0.5612486080160912, 0.5766281297335398, 0.5916079783099617, 0.6062177826491071, 0.6204836822995429, 0.6344288770224761, 0.6480740698407861, 0.6614378277661477, 0.6745368781616021, 0.687386354243376, 0.7000000000000001, 0.7123903424387504, 0.7245688373094719, 0.7365459931328118, 0.7483314773547882, 0.7599342076785333, 0.7713624310270757, 0.7826237921249264, 0.7937253933193772, 0.8046738469715541, 0.8154753215150046, 0.8261355820929154, 0.8366600265340756, 0.8470537173048709, 0.8573214099741124, 0.8674675786448736, 0.8774964387392122, 0.8874119674649423, 0.8972179222463181, 0.9069178573608527, 0.9165151389911681, 0.9260129588726067, 0.9354143466934854, 0.9447221813845593, 0.9539392014169458, 0.9630680142129112, 0.9721111047611791, 0.9810708435174292, 0.9899494936611666, 0.998749217771909, 1.0074720839804943, 1.0161200716450787, 1.0246950765959597, 1.0331989159885913, 1.041633332799983, 1.05, 1.0583005244258363, 1.066536450385077, 1.074709263010234, 1.0828203913853858, 1.0908712114635715, 1.0988630487917956, 1.1067971810589328, 1.1146748404803977, 1.1224972160321824, 1.1302654555457314, 1.1379806676741042, 1.14564392373896, 1.1532562594670797, 1.16081867662439, 1.1683321445547925, 1.1757976016304847, 1.1832159566199234, 1.1905880899790657, 1.197914855071094, 1.205197079319395, 1.2124355652982142, 1.2196310917650468, 1.2267844146385298, 1.2338962679253067, 1.2409673645990857, 1.2479983974348685, 1.2549900398011133, 1.2619429464123963, 1.2688577540449522, 1.2757350822173075, 1.2825755338380662, 1.2893796958227626, 1.2961481396815722, 1.3028814220795384, 1.3095800853708794, 1.3162446581088185, 1.3228756555322954, 1.3294735800308333], [0.0, 0.1414213562373095, 0.19999999999999998, 0.24494897427831783, 0.282842712474619, 0.31622776601683794, 0.34641016151377546, 0.3741657386773941, 0.39999999999999997, 0.4242640687119285, 0.4472135954999579, 0.469041575982343, 0.48989794855663565, 0.5099019513592785, 0.529150262212918, 0.5477225575051661, 0.565685424949238, 0.58309518948453, 0.6, 0.6164414002968976, 0.6324555320336759, 0.6480740698407861, 0.6633249580710799, 0.6782329983125268, 0.6928203230275509, 0.7071067811865476, 0.7211102550927979, 0.7348469228349535, 0.7483314773547882, 0.7615773105863909, 0.7745966692414833, 0.7874007874011811, 0.7999999999999999, 0.812403840463596, 0.8246211251235321, 0.8366600265340756, 0.848528137423857, 0.8602325267042626, 0.8717797887081348, 0.8831760866327847, 0.8944271909999159, 0.9055385138137417, 0.9165151389911681, 0.9273618495495702, 0.938083151964686, 0.9486832980505137, 0.9591663046625439, 0.9695359714832658, 0.9797958971132713, 0.9899494936611665, 1.0, 1.0099504938362078, 1.019803902718557, 1.0295630140987002, 1.0392304845413265, 1.0488088481701516, 1.058300524425836, 1.0677078252031311, 1.0770329614269007, 1.0862780491200215, 1.0954451150103321, 1.104536101718726, 1.1135528725660042, 1.1224972160321824, 1.131370849898476, 1.1401754250991378, 1.1489125293076057, 1.1575836902790224, 1.16619037896906, 1.174734012447073, 1.1832159566199232, 1.1916375287812984, 1.2, 1.2083045973594573, 1.2165525060596438, 1.224744871391589, 1.2328828005937953, 1.2409673645990857, 1.2489995996796797, 1.2569805089976536, 1.2649110640673518, 1.2727922061357855, 1.2806248474865698, 1.2884098726725124, 1.2961481396815722, 1.3038404810405297, 1.3114877048604001, 1.3190905958272918, 1.3266499161421599, 1.3341664064126333, 1.3416407864998738, 1.349073756323204, 1.3564659966250536, 1.3638181696985856, 1.3711309200802089, 1.378404875209022, 1.3856406460551018, 1.392838827718412, 1.4, 1.407124727947029, 1.4142135623730951, 1.4212670403551897], [0.0, 0.15, 0.21213203435596426, 0.2598076211353316, 0.3, 0.33541019662496846, 0.3674234614174767, 0.3968626966596886, 0.4242640687119285, 0.44999999999999996, 0.4743416490252569, 0.49749371855331, 0.5196152422706632, 0.5408326913195984, 0.5612486080160912, 0.5809475019311124, 0.6, 0.618465843842649, 0.6363961030678927, 0.653834841531101, 0.6708203932499369, 0.687386354243376, 0.7035623639735145, 0.719374728496908, 0.7348469228349535, 0.75, 0.7648529270389177, 0.7794228634059948, 0.7937253933193772, 0.8077747210701757, 0.8215838362577491, 0.8351646544245033, 0.848528137423857, 0.8616843969807043, 0.8746427842267951, 0.8874119674649423, 0.8999999999999999, 0.9124143795447329, 0.9246621004453465, 0.9367496997597597, 0.9486832980505138, 0.9604686356149273, 0.9721111047611791, 0.9836157786453, 0.99498743710662, 1.0062305898749053, 1.0173494974687902, 1.0283481900601565, 1.0392304845413265, 1.05, 1.0606601717798212, 1.0712142642814275, 1.0816653826391969, 1.0920164833920778, 1.1022703842524302, 1.1124297730643495, 1.1224972160321824, 1.1324751652906124, 1.1423659658795862, 1.1521718621802912, 1.1618950038622249, 1.1715374513859982, 1.1811011811017715, 1.1905880899790657, 1.2, 1.2093386622447824, 1.218605760695394, 1.2278029157808674, 1.236931687685298, 1.2459935794377113, 1.2549900398011133, 1.2639224659764536, 1.2727922061357855, 1.2816005617976296, 1.290348790056394, 1.299038105676658, 1.307669683062202, 1.3162446581088183, 1.3247641299491772, 1.3332291625973383, 1.3416407864998738, 1.35, 1.3583077707206126, 1.3665650368716447, 1.374772708486752, 1.382931668593933, 1.3910427743243556, 1.3991068579633223, 1.407124727947029, 1.4150971698084904, 1.4230249470757705, 1.4309088021254184, 1.438749456993816, 1.4465476141489433, 1.4543039572248988, 1.4620191517213443, 1.469693845669907, 1.4773286702694157, 1.4849242404917498, 1.49248115565993, 1.5, 1.5074813431681338], [0.0, 0.15811388300841897, 0.22360679774997896, 0.2738612787525831, 0.31622776601683794, 0.3535533905932738, 0.3872983346207417, 0.4183300132670378, 0.4472135954999579, 0.4743416490252569, 0.5, 0.5244044240850758, 0.5477225575051662, 0.570087712549569, 0.5916079783099616, 0.6123724356957945, 0.6324555320336759, 0.6519202405202649, 0.6708203932499369, 0.6892024376045112, 0.7071067811865476, 0.724568837309472, 0.7416198487095663, 0.7582875444051551, 0.7745966692414834, 0.7905694150420949, 0.806225774829855, 0.8215838362577492, 0.8366600265340756, 0.8514693182963201, 0.8660254037844386, 0.8803408430829505, 0.8944271909999159, 0.9082951062292476, 0.9219544457292888, 0.9354143466934853, 0.9486832980505138, 0.9617692030835673, 0.9746794344808964, 0.987420882906575, 1.0, 1.0124228365658294, 1.02469507659596, 1.036822067666386, 1.0488088481701516, 1.0606601717798212, 1.0723805294763609, 1.08397416943394, 1.0954451150103324, 1.1067971810589328, 1.118033988749895, 1.1291589790636216, 1.140175425099138, 1.151086443322134, 1.161895003862225, 1.1726039399558574, 1.1832159566199232, 1.1937336386313322, 1.2041594578792296, 1.2144957801491119, 1.224744871391589, 1.2349089035228469, 1.2449899597988732, 1.2549900398011133, 1.2649110640673518, 1.2747548783981961, 1.284523257866513, 1.2942179105544784, 1.3038404810405297, 1.3133925536563698, 1.3228756555322954, 1.3322912594474228, 1.3416407864998738, 1.3509256086106296, 1.3601470508735443, 1.3693063937629153, 1.3784048752090223, 1.3874436925511608, 1.3964240043768943, 1.4053469322555197, 1.4142135623730951, 1.4230249470757708, 1.4317821063276355, 1.4404860290887933, 1.449137674618944, 1.4577379737113252, 1.466287829861518, 1.4747881203752626, 1.4832396974191326, 1.4916433890176297, 1.5, 1.5083103128998356, 1.5165750888103102, 1.5247950681976907, 1.5329709716755893, 1.541103500742244, 1.5491933384829668, 1.5572411502397439, 1.5652475842498528, 1.5732132722552274, 1.5811388300841898, 1.5890248582070705], [0.0, 0.16583123951777, 0.2345207879911715, 0.2872281323269015, 0.33166247903554, 0.3708099243547832, 0.4062019202317981, 0.4387482193696061, 0.469041575982343, 0.49749371855331, 0.5244044240850758, 0.55, 0.574456264653803, 0.5979130371550699, 0.6204836822995429, 0.6422616289332564, 0.66332495807108, 0.6837397165588672, 0.7035623639735145, 0.7228416147400482, 0.7416198487095664, 0.7599342076785333, 0.7778174593052024, 0.7952986860293434, 0.8124038404635961, 0.8291561975888501, 0.8455767262643883, 0.8616843969807044, 0.8774964387392122, 0.8930285549745877, 0.9082951062292475, 0.9233092656309695, 0.938083151964686, 0.9526279441628827, 0.9669539802906859, 0.9810708435174292, 0.99498743710662, 1.008712050091601, 1.0222524150130439, 1.0356157588603991, 1.0488088481701516, 1.0618380290797653, 1.074709263010234, 1.0874281585465773, 1.1, 1.1124297730643495, 1.1247221879201994, 1.1368817000902074, 1.148912529307606, 1.16081867662439, 1.1726039399558574, 1.1842719282327014, 1.1958260743101399, 1.2072696467649637, 1.2186057606953942, 1.2298373876248845, 1.2409673645990857, 1.2519984025548916, 1.262933094031509, 1.2737739202856997, 1.284523257866513, 1.2951833846988619, 1.3057564857200596, 1.3162446581088185, 1.32664991614216, 1.3369741957120937, 1.3472193585307481, 1.357387196049823, 1.3674794331177345, 1.3774977313955912, 1.387443692551161, 1.3973188612482121, 1.407124727947029, 1.4168627315304756, 1.4265342617687107, 1.4361406616345074, 1.4456832294800963, 1.455163221085525, 1.4645818515876812, 1.4739402972983677, 1.4832396974191329, 1.4924811556599302, 1.501665741768121, 1.5107944929738129, 1.5198684153570665, 1.5288884851420657, 1.53785564992297, 1.546770829825802, 1.5556349186104048, 1.5644487847162016, 1.5732132722552274, 1.5819292019556377, 1.5905973720586868, 1.5992185591719479, 1.6077935190813528, 1.6163229875244614, 1.6248076809271923, 1.6332482971061077, 1.6416455159382004, 1.6500000000000004, 1.6583123951777001, 1.666583331249896], [0.0, 0.17320508075688776, 0.24494897427831783, 0.3000000000000001, 0.3464101615137755, 0.38729833462074176, 0.42426406871192857, 0.45825756949558405, 0.48989794855663565, 0.5196152422706632, 0.5477225575051662, 0.574456264653803, 0.6000000000000002, 0.6244997998398399, 0.6480740698407861, 0.6708203932499369, 0.692820323027551, 0.7141428428542851, 0.7348469228349536, 0.7549834435270751, 0.7745966692414835, 0.7937253933193773, 0.8124038404635961, 0.8306623862918077, 0.8485281374238571, 0.8660254037844388, 0.8831760866327849, 0.9000000000000001, 0.9165151389911681, 0.9327379053088817, 0.9486832980505139, 0.9643650760992957, 0.9797958971132713, 0.9949874371066202, 1.009950493836208, 1.02469507659596, 1.0392304845413265, 1.053565375285274, 1.0677078252031313, 1.081665382639197, 1.0954451150103324, 1.1090536506409419, 1.1224972160321827, 1.1357816691600549, 1.148912529307606, 1.161895003862225, 1.1747340124470733, 1.187434208703792, 1.2000000000000004, 1.2124355652982142, 1.2247448713915892, 1.2369316876852985, 1.2489995996796799, 1.2609520212918495, 1.2727922061357857, 1.2845232578665131, 1.2961481396815722, 1.3076696830622023, 1.3190905958272923, 1.3304134695650072, 1.3416407864998738, 1.3527749258468684, 1.3638181696985856, 1.3747727084867523, 1.385640646055102, 1.3964240043768943, 1.4071247279470291, 1.4177446878757827, 1.4282856857085702, 1.4387494569938162, 1.4491376746189442, 1.4594519519326425, 1.4696938456699071, 1.4798648586948744, 1.489966442575134, 1.5000000000000002, 1.5099668870541503, 1.5198684153570665, 1.5297058540778359, 1.5394804318340656, 1.549193338482967, 1.5588457268119897, 1.5684387141358125, 1.5779733838059502, 1.5874507866387546, 1.5968719422671316, 1.6062378404209012, 1.6155494421403516, 1.6248076809271923, 1.6340134638368193, 1.6431676725154984, 1.6522711641858308, 1.6613247725836153, 1.670329308849007, 1.6792855623746668, 1.6881943016134133, 1.6970562748477143, 1.7058722109231985, 1.7146428199482249, 1.7233687939614089, 1.7320508075688776, 1.7406895185529214], [0.0, 0.18027756377319948, 0.25495097567963926, 0.31224989991991997, 0.36055512754639896, 0.4031128874149275, 0.4415880433163924, 0.4769696007084729, 0.5099019513592785, 0.5408326913195984, 0.570087712549569, 0.5979130371550699, 0.6244997998398399, 0.6500000000000001, 0.6745368781616021, 0.698212002188447, 0.7211102550927979, 0.7433034373659253, 0.7648529270389178, 0.7858116822750857, 0.806225774829855, 0.8261355820929154, 0.8455767262643882, 0.8645808232895292, 0.8831760866327848, 0.9013878188659974, 0.9192388155425119, 0.9367496997597599, 0.9539392014169458, 0.97082439194738, 0.9874208829065749, 1.0037429949942367, 1.019803902718557, 1.0356157588603991, 1.051189802081432, 1.0665364503850772, 1.0816653826391969, 1.0965856099730655, 1.1113055385446435, 1.1258330249197703, 1.140175425099138, 1.1543396380615198, 1.1683321445547925, 1.182159041753689, 1.1958260743101399, 1.2093386622447824, 1.2227019260637484, 1.2359207094308275, 1.2489995996796799, 1.2619429464123963, 1.2747548783981963, 1.2874393189583735, 1.3000000000000003, 1.312440474840669, 1.3247641299491772, 1.336974195712094, 1.3490737563232043, 1.36106575888162, 1.3729530217745982, 1.3847382424126229, 1.396424004376894, 1.4080127840328724, 1.419506956657839, 1.4309088021254186, 1.4422205101855958, 1.4534441853748632, 1.4645818515876812, 1.4756354563373706, 1.4866068747318506, 1.497497913187194, 1.5083103128998359, 1.5190457530963313, 1.5297058540778357, 1.5402921800749363, 1.5508062419270823, 1.5612494995995996, 1.5716233645501714, 1.5819292019556377, 1.5921683328090661, 1.6023420358962066, 1.61245154965971, 1.6224980739587953, 1.632482771731451, 1.6424067705656842, 1.6522711641858308, 1.6620770138594663, 1.671825349730049, 1.681517172080024, 1.6911534525287764, 1.7007351351694948, 1.710263137648707, 1.719738352191984, 1.7291616465790585, 1.7385338650713713, 1.7478558292948536, 1.7571283390805579, 1.7663521732655696, 1.7755280904564708, 1.7846568297574747, 1.79373911146521, 1.8027756377319948, 1.8117670931993441], [0.0, 0.18708286933869708, 0.264575131106459, 0.32403703492039304, 0.37416573867739417, 0.4183300132670378, 0.458257569495584, 0.4949747468305833, 0.529150262212918, 0.5612486080160912, 0.5916079783099616, 0.6204836822995429, 0.6480740698407861, 0.6745368781616021, 0.7, 0.7245688373094719, 0.7483314773547883, 0.7713624310270756, 0.7937253933193772, 0.8154753215150046, 0.8366600265340756, 0.8573214099741123, 0.8774964387392122, 0.8972179222463181, 0.916515138991168, 0.9354143466934853, 0.9539392014169457, 0.9721111047611791, 0.9899494936611666, 1.0074720839804943, 1.0246950765959597, 1.041633332799983, 1.058300524425836, 1.074709263010234, 1.0908712114635715, 1.1067971810589328, 1.1224972160321824, 1.1379806676741042, 1.1532562594670797, 1.1683321445547923, 1.1832159566199232, 1.197914855071094, 1.2124355652982142, 1.2267844146385296, 1.2409673645990857, 1.2549900398011131, 1.2688577540449522, 1.282575533838066, 1.2961481396815722, 1.3095800853708794, 1.3228756555322954, 1.336038921588739, 1.3490737563232043, 1.3619838471876238, 1.374772708486752, 1.3874436925511608, 1.4, 1.4124446891825535, 1.4247806848775009, 1.4370107863199912, 1.4491376746189437, 1.4611639196202457, 1.4730919862656233, 1.4849242404917498, 1.4966629547095767, 1.5083103128998354, 1.5198684153570663, 1.5313392831113555, 1.5427248620541512, 1.5540270267920053, 1.5652475842498528, 1.5763882770434445, 1.5874507866387544, 1.598436736314578, 1.609347693943108, 1.620185174601965, 1.6309506430300091, 1.6416455159382004, 1.6522711641858308, 1.6628289148315891, 1.6733200530681511, 1.6837458240482737, 1.6941074346097418, 1.704406054905931, 1.7146428199482247, 1.724818831066034, 1.7349351572897473, 1.7449928366615148, 1.7549928774784245, 1.764936259472279, 1.7748239349298847, 1.7846568297574747, 1.7944358444926363, 1.8041618552668717, 1.8138357147217055, 1.8234582528810468, 1.833030277982336, 1.842552577268828, 1.8520259177452134, 1.8614510468986285, 1.8708286933869707, 1.8801595676963168], [0.0, 0.19364916731037082, 0.27386127875258304, 0.33541019662496846, 0.38729833462074165, 0.4330127018922193, 0.4743416490252569, 0.5123475382979799, 0.5477225575051661, 0.5809475019311124, 0.6123724356957945, 0.6422616289332564, 0.6708203932499369, 0.698212002188447, 0.7245688373094719, 0.7499999999999999, 0.7745966692414833, 0.7984359711335656, 0.8215838362577491, 0.8440971508067067, 0.8660254037844386, 0.8874119674649423, 0.9082951062292475, 0.9287087810503355, 0.9486832980505138, 0.9682458365518541, 0.9874208829065749, 1.0062305898749053, 1.0246950765959597, 1.0428326807307104, 1.0606601717798212, 1.0781929326423911, 1.0954451150103321, 1.1124297730643495, 1.1291589790636214, 1.14564392373896, 1.1618950038622249, 1.1779218989389746, 1.1937336386313322, 1.2093386622447824, 1.224744871391589, 1.2399596767637244, 1.2549900398011133, 1.2698425099200292, 1.284523257866513, 1.2990381056766578, 1.3133925536563695, 1.3275918047351754, 1.3416407864998738, 1.3555441711725957, 1.3693063937629153, 1.382931668593933, 1.396424004376894, 1.4097872179871684, 1.4230249470757705, 1.4361406616345072, 1.4491376746189437, 1.4620191517213446, 1.4747881203752626, 1.4874474780643514, 1.4999999999999998, 1.5124483462254172, 1.5247950681976905, 1.5370426148939396, 1.5491933384829666, 1.5612494995995994, 1.5732132722552272, 1.5850867484147357, 1.5968719422671311, 1.608570794214541, 1.620185174601965, 1.6317168872080718, 1.6431676725154982, 1.6545392107774295, 1.6658331248957678, 1.6770509831248421, 1.6881943016134133, 1.6992645467966427, 1.710263137648707, 1.7211914478058505, 1.7320508075688772, 1.7428425057933374, 1.7535677916750183, 1.7642278764377348, 1.7748239349298847, 1.7853571071357124, 1.795828499606797, 1.8062391868188443, 1.816590212458495, 1.8268825906445108, 1.8371173070873834, 1.8472953201911164, 1.857417562100671, 1.8674849396983098, 1.8774983355518586, 1.8874586088176872, 1.8973665961010275, 1.9072231122760652, 1.9170289512680811, 1.9267848867997694, 1.9364916731037083, 1.9461500456028564], [0.0, 0.2, 0.282842712474619, 0.3464101615137755, 0.4, 0.447213595499958, 0.48989794855663565, 0.5291502622129182, 0.565685424949238, 0.6, 0.6324555320336759, 0.66332495807108, 0.692820323027551, 0.7211102550927979, 0.7483314773547883, 0.7745966692414833, 0.8, 0.8246211251235321, 0.848528137423857, 0.8717797887081349, 0.894427190999916, 0.9165151389911681, 0.938083151964686, 0.959166304662544, 0.9797958971132713, 1.0, 1.019803902718557, 1.0392304845413265, 1.0583005244258363, 1.077032961426901, 1.0954451150103321, 1.1135528725660044, 1.131370849898476, 1.148912529307606, 1.1661903789690602, 1.1832159566199232, 1.2, 1.216552506059644, 1.2328828005937953, 1.2489995996796799, 1.2649110640673518, 1.2806248474865698, 1.2961481396815722, 1.3114877048604001, 1.32664991614216, 1.3416407864998738, 1.3564659966250536, 1.3711309200802089, 1.385640646055102, 1.4000000000000001, 1.4142135623730951, 1.4282856857085702, 1.4422205101855958, 1.4560219778561039, 1.469693845669907, 1.4832396974191326, 1.4966629547095767, 1.50996688705415, 1.5231546211727818, 1.5362291495737217, 1.5491933384829666, 1.5620499351813308, 1.574801574802362, 1.5874507866387544, 1.6, 1.6124515496597098, 1.624807680927192, 1.6370705543744901, 1.6492422502470643, 1.661324772583615, 1.6733200530681511, 1.6852299546352718, 1.697056274847714, 1.7088007490635062, 1.7204650534085253, 1.7320508075688774, 1.7435595774162698, 1.7549928774784245, 1.7663521732655696, 1.7776388834631178, 1.788854381999832, 1.8, 1.8110770276274835, 1.8220867158288598, 1.8330302779823362, 1.8439088914585775, 1.854723699099141, 1.8654758106177631, 1.876166303929372, 1.8867962264113207, 1.8973665961010275, 1.9078784028338913, 1.918332609325088, 1.9287301521985911, 1.9390719429665317, 1.9493588689617927, 1.9595917942265426, 1.9697715603592212, 1.9798989873223332, 1.9899748742132402, 2.0, 2.0099751242241783], [0.0, 0.20615528128088303, 0.291547594742265, 0.35707142142714254, 0.41231056256176607, 0.4609772228646444, 0.5049752469181039, 0.5454356057317857, 0.58309518948453, 0.618465843842649, 0.6519202405202649, 0.6837397165588672, 0.7141428428542851, 0.7433034373659253, 0.7713624310270756, 0.7984359711335656, 0.8246211251235321, 0.85, 0.8746427842267951, 0.8986100377805715, 0.9219544457292888, 0.9447221813845592, 0.9669539802906858, 0.9886859966642595, 1.0099504938362078, 1.0307764064044151, 1.051189802081432, 1.0712142642814275, 1.0908712114635715, 1.110180165558726, 1.1291589790636214, 1.1478240283248997, 1.16619037896906, 1.1842719282327012, 1.2020815280171309, 1.2196310917650468, 1.236931687685298, 1.2539936203984452, 1.2708265027138834, 1.2874393189583735, 1.3038404810405297, 1.3200378782444087, 1.336038921588739, 1.3518505834595773, 1.3674794331177345, 1.382931668593933, 1.3982131454109563, 1.413329402510257, 1.4282856857085702, 1.4430869689661812, 1.4577379737113252, 1.472243186433546, 1.4866068747318506, 1.5008331019803636, 1.5149257407543117, 1.5288884851420657, 1.5427248620541512, 1.5564382416273381, 1.5700318468107584, 1.5835087622113115, 1.5968719422671311, 1.6101242188104619, 1.6232683080747925, 1.6363068171953572, 1.6492422502470643, 1.662077013859466, 1.6748134224444227, 1.6874537030686205, 1.7, 1.712454378954371, 1.7248188310660342, 1.7370952766040209, 1.7492855684535902, 1.7613914953808536, 1.7734147850968198, 1.7853571071357126, 1.797220075561143, 1.8090052515125543, 1.8207141456033127, 1.8323482201808694, 1.8439088914585775, 1.8553975315279474, 1.866815470259447, 1.8781639970992947, 1.8894443627691184, 1.9006577808748213, 1.9118054294305162, 1.922888452302941, 1.9339079605813716, 1.9448650338776723, 1.9557607215607946, 1.9665960439297137, 1.977371993328519, 1.9880895352071044, 1.9987496091306687, 2.0093531297410117, 2.0199009876724157, 2.0303940504246953, 2.040833163195855, 2.0512191496766015, 2.0615528128088303, 2.0718349355100663], [0.0, 0.21213203435596426, 0.3, 0.3674234614174768, 0.4242640687119285, 0.47434164902525694, 0.5196152422706632, 0.5612486080160912, 0.6, 0.6363961030678927, 0.6708203932499369, 0.7035623639735145, 0.7348469228349536, 0.7648529270389178, 0.7937253933193772, 0.8215838362577491, 0.848528137423857, 0.8746427842267951, 0.9, 0.9246621004453466, 0.9486832980505139, 0.9721111047611791, 0.99498743710662, 1.0173494974687902, 1.0392304845413265, 1.0606601717798214, 1.0816653826391969, 1.1022703842524302, 1.1224972160321824, 1.1423659658795864, 1.161895003862225, 1.1811011811017718, 1.2, 1.2186057606953942, 1.2369316876852983, 1.2549900398011133, 1.2727922061357855, 1.2903487900563941, 1.307669683062202, 1.3247641299491772, 1.3416407864998738, 1.3583077707206126, 1.374772708486752, 1.3910427743243554, 1.407124727947029, 1.4230249470757705, 1.438749456993816, 1.4543039572248988, 1.4696938456699071, 1.4849242404917498, 1.5, 1.514925740754312, 1.5297058540778357, 1.5443445211480502, 1.5588457268119897, 1.5732132722552274, 1.5874507866387544, 1.6015617378046967, 1.6155494421403513, 1.6294170736800322, 1.6431676725154982, 1.6568041525780892, 1.6703293088490065, 1.6837458240482737, 1.697056274847714, 1.710263137648707, 1.7233687939614086, 1.7363755354185337, 1.7492855684535902, 1.7621010186706096, 1.7748239349298849, 1.7874562931719478, 1.8, 1.8124568960391858, 1.8248287590894658, 1.8371173070873836, 1.8493242008906932, 1.8614510468986285, 1.8734993995195197, 1.8854707634964802, 1.8973665961010278, 1.9091883092036783, 1.920937271229855, 1.9326148090087687, 1.9442222095223582, 1.9557607215607948, 1.9672315572906003, 1.978635893740938, 1.98997487421324, 2.00124960961895, 2.0124611797498106, 2.023610634484806, 2.0346989949375804, 2.0457272545478786, 2.0566963801203135, 2.067607312813533, 2.078460969082653, 2.089258241577618, 2.1, 2.1106870919205436, 2.121320343559643, 2.1319005605327845], [0.0, 0.21794494717703372, 0.3082207001484488, 0.37749172176353757, 0.43588989435406744, 0.4873397172404483, 0.5338539126015657, 0.5766281297335398, 0.6164414002968976, 0.653834841531101, 0.6892024376045112, 0.7228416147400482, 0.7549834435270751, 0.7858116822750857, 0.8154753215150046, 0.8440971508067067, 0.8717797887081349, 0.8986100377805715, 0.9246621004453466, 0.9500000000000002, 0.9746794344808966, 0.9987492177719091, 1.0222524150130439, 1.0452272480183438, 1.0677078252031313, 1.0897247358851685, 1.1113055385446438, 1.1324751652906127, 1.1532562594670797, 1.1736694594305503, 1.1937336386313322, 1.2134661099511599, 1.2328828005937953, 1.2519984025548916, 1.2708265027138836, 1.2893796958227628, 1.307669683062202, 1.3257073583562855, 1.3435028842544405, 1.3610657588816202, 1.3784048752090223, 1.3955285736952865, 1.4124446891825537, 1.4291605927956452, 1.4456832294800963, 1.4620191517213446, 1.4781745499094485, 1.4941552797483937, 1.5099668870541503, 1.525614630239236, 1.5411035007422444, 1.5564382416273383, 1.5716233645501714, 1.5866631652622434, 1.601561737804697, 1.6163229875244616, 1.6309506430300091, 1.6454482671904336, 1.6598192672697836, 1.6740669042783207, 1.6881943016134133, 1.7022044530549203, 1.7161002301730515, 1.7298843892006197, 1.7435595774162698, 1.7571283390805579, 1.7705931209625776, 1.7839562774911275, 1.797220075561143, 1.8103866990231676, 1.8234582528810472, 1.836436767220696, 1.8493242008906932, 1.8621224449536073, 1.8748333259252674, 1.8874586088176877, 1.9000000000000004, 1.912459149890528, 1.9248376554920161, 1.937137062781052, 1.9493588689617931, 1.9615045245933034, 1.9735754355990556, 1.9855729651664782, 1.9974984355438181, 2.009353129741012, 2.021138293140774, 2.0328551350256125, 2.0445048300260877, 2.056088519495209, 2.0676073128135335, 2.079062288629179, 2.0904544960366875, 2.1017849556983705, 2.113054660911544, 2.1242645786248002, 2.1354156504062627, 2.1465087933665683, 2.157544901039142, 2.1685248442201446, 2.179449471770337, 2.1903196113809513], [0.0, 0.223606797749979, 0.31622776601683794, 0.38729833462074176, 0.447213595499958, 0.5000000000000001, 0.5477225575051662, 0.5916079783099617, 0.6324555320336759, 0.6708203932499369, 0.7071067811865476, 0.7416198487095664, 0.7745966692414835, 0.806225774829855, 0.8366600265340756, 0.8660254037844386, 0.894427190999916, 0.9219544457292888, 0.9486832980505139, 0.9746794344808966, 1.0000000000000002, 1.02469507659596, 1.0488088481701516, 1.072380529476361, 1.0954451150103324, 1.118033988749895, 1.140175425099138, 1.1618950038622253, 1.1832159566199234, 1.2041594578792296, 1.2247448713915892, 1.2449899597988734, 1.2649110640673518, 1.2845232578665131, 1.30384048104053, 1.3228756555322954, 1.3416407864998738, 1.3601470508735445, 1.3784048752090223, 1.3964240043768943, 1.4142135623730951, 1.4317821063276355, 1.4491376746189442, 1.466287829861518, 1.4832396974191329, 1.5, 1.5165750888103102, 1.5329709716755893, 1.549193338482967, 1.565247584249853, 1.5811388300841898, 1.5968719422671316, 1.61245154965971, 1.627882059609971, 1.6431676725154984, 1.6583123951777001, 1.6733200530681511, 1.6881943016134133, 1.7029386365926404, 1.7175564037317668, 1.7320508075688772, 1.746424919657298, 1.760681686165901, 1.7748239349298849, 1.788854381999832, 1.8027756377319946, 1.8165902124584952, 1.8303005217723127, 1.8439088914585775, 1.8574175621006712, 1.8708286933869709, 1.8841443681416774, 1.8973665961010278, 1.91049731745428, 1.9235384061671346, 1.9364916731037085, 1.9493588689617931, 1.9621416870348585, 1.9748417658131503, 1.9874606914351793, 2.0000000000000004, 2.012461179749811, 2.024845673131659, 2.0371548787463363, 2.04939015319192, 2.0615528128088303, 2.0736441353327724, 2.0856653614614213, 2.0976176963403033, 2.1095023109728985, 2.121320343559643, 2.1330729007701543, 2.144761058952722, 2.1563858652847827, 2.1679483388678804, 2.179449471770337, 2.1908902300206647, 2.2022715545545246, 2.2135943621178655, 2.224859546128699, 2.23606797749979, 2.2472205054244236], [0.0, 0.22912878474779202, 0.32403703492039304, 0.39686269665968865, 0.45825756949558405, 0.51234753829798, 0.5612486080160912, 0.6062177826491071, 0.6480740698407861, 0.687386354243376, 0.724568837309472, 0.7599342076785333, 0.7937253933193773, 0.8261355820929154, 0.8573214099741123, 0.8874119674649423, 0.9165151389911681, 0.9447221813845592, 0.9721111047611791, 0.9987492177719091, 1.02469507659596, 1.05, 1.074709263010234, 1.0988630487917956, 1.1224972160321824, 1.1456439237389602, 1.1683321445547925, 1.190588089979066, 1.2124355652982142, 1.2338962679253067, 1.2549900398011133, 1.2757350822173075, 1.2961481396815722, 1.3162446581088185, 1.336038921588739, 1.355544171172596, 1.374772708486752, 1.3937359864766354, 1.4124446891825535, 1.4309088021254186, 1.449137674618944, 1.467140075112121, 1.48492424049175, 1.502497920131672, 1.5198684153570665, 1.5370426148939398, 1.5540270267920056, 1.5708278072405009, 1.5874507866387546, 1.6039014932345441, 1.6201851746019653, 1.6363068171953574, 1.6522711641858308, 1.668082731761228, 1.6837458240482739, 1.699264546796643, 1.7146428199482247, 1.7298843892006195, 1.744992836661515, 1.7599715906798041, 1.7748239349298847, 1.7895530168173281, 1.8041618552668715, 1.8186533479473213, 1.8330302779823362, 1.8472953201911166, 1.8614510468986285, 1.8754999333511053, 1.8894443627691184, 1.9032866310674281, 1.9170289512680816, 1.9306734576307825, 1.9442222095223582, 1.9576771950451894, 1.9710403344427023, 1.984313483298443, 1.9974984355438181, 2.01059692628831, 2.0236106344848066, 2.03654118544163, 2.04939015319192, 2.062159062730128, 2.0748493921246434, 2.0874625745148103, 2.1, 2.112463017427761, 2.124852936087578, 2.1371710273162514, 2.149418526020468, 2.1615966321217286, 2.173706511928416, 2.1857492994394394, 2.1977260975835913, 2.2096379793984355, 2.221485989152306, 2.2332711434127295, 2.244994432064365, 2.256656819279352, 2.2682592444427514, 2.2798026230355997, 2.2912878474779204, 2.302715787933891], [0.0, 0.2345207879911715, 0.33166247903553997, 0.4062019202317981, 0.469041575982343, 0.5244044240850758, 0.574456264653803, 0.6204836822995429, 0.6633249580710799, 0.7035623639735145, 0.7416198487095663, 0.7778174593052024, 0.8124038404635961, 0.8455767262643882, 0.8774964387392122, 0.9082951062292475, 0.938083151964686, 0.9669539802906858, 0.99498743710662, 1.0222524150130439, 1.0488088481701516, 1.074709263010234, 1.1, 1.1247221879201994, 1.148912529307606, 1.1726039399558574, 1.1958260743101399, 1.2186057606953942, 1.2409673645990857, 1.2629330940315089, 1.284523257866513, 1.3057564857200596, 1.3266499161421599, 1.3472193585307481, 1.3674794331177345, 1.3874436925511608, 1.407124727947029, 1.4265342617687107, 1.445683229480096, 1.4645818515876812, 1.4832396974191326, 1.5016657417681207, 1.5198684153570665, 1.5378556499229699, 1.5556349186104048, 1.5732132722552272, 1.5905973720586868, 1.6077935190813528, 1.6248076809271923, 1.6416455159382004, 1.6583123951777001, 1.6748134224444229, 1.6911534525287764, 1.7073371078963875, 1.7233687939614086, 1.7392527130926088, 1.7549928774784245, 1.7705931209625774, 1.7860571099491753, 1.801388353465182, 1.816590212458495, 1.8316659084014202, 1.8466185312619388, 1.8614510468986285, 1.876166303929372, 1.8907670401189036, 1.905255888325765, 1.9196353820452468, 1.9339079605813716, 1.9480759738778157, 1.9621416870348585, 1.9761072845369505, 1.98997487421324, 2.003746490951388, 2.0174241001832014, 2.03100960115899, 2.0445048300260877, 2.057911562725668, 2.0712315177207983, 2.084466358567583, 2.0976176963403033, 2.1106870919205436, 2.1236760581595306, 2.1365860619221495, 2.149418526020468, 2.1621748310439655, 2.1748563170931545, 2.187464285422736, 2.2, 2.2124646889837587, 2.224859546128699, 2.2371857321197095, 2.249444375840399, 2.2616365755797285, 2.273763400180415, 2.285825890132492, 2.297825058615212, 2.30976189249022, 2.32163735324878, 2.333452377915607, 2.345207879911715, 2.3569047498785354], [0.0, 0.239791576165636, 0.3391164991562634, 0.41533119314590383, 0.479583152331272, 0.5361902647381805, 0.5873670062235365, 0.6344288770224761, 0.6782329983125268, 0.719374728496908, 0.7582875444051551, 0.7952986860293434, 0.8306623862918077, 0.8645808232895292, 0.8972179222463181, 0.9287087810503355, 0.959166304662544, 0.9886859966642595, 1.0173494974687902, 1.0452272480183438, 1.072380529476361, 1.0988630487917956, 1.1247221879201994, 1.1500000000000001, 1.174734012447073, 1.19895788082818, 1.2227019260637486, 1.2459935794377115, 1.2688577540449522, 1.291317157014496, 1.3133925536563698, 1.335102992281869, 1.3564659966250536, 1.3774977313955914, 1.3982131454109563, 1.4186260959111108, 1.438749456993816, 1.4585952145814824, 1.4781745499094485, 1.497497913187194, 1.5165750888103102, 1.5354152532784089, 1.5540270267920056, 1.5724185193516387, 1.5905973720586868, 1.6085707942145413, 1.6263455967290594, 1.6439282222773597, 1.6613247725836153, 1.678541033159452, 1.6955824957813173, 1.7124543789543711, 1.7291616465790585, 1.7457090250096094, 1.7621010186706099, 1.7783419243778742, 1.7944358444926363, 1.8103866990231674, 1.8261982367749676, 1.8418740456393863, 1.857417562100671, 1.8728320800328044, 1.8881207588499207, 1.9032866310674281, 1.918332609325088, 1.9332614929181204, 1.9480759738778157, 1.9627786426390523, 1.977371993328519, 1.9918584287042091, 2.006240264773888, 2.0205197351176754, 2.0346989949375804, 2.048780124854788, 2.062765134473627, 2.0766559657295187, 2.0904544960366875, 2.1041625412500817, 2.1177818584547374, 2.131314148594712, 2.144761058952722, 2.158124185490724, 2.171405075060847, 2.184605227495348, 2.1977260975835913, 2.2107690969434146, 2.2237355957937086, 2.2366269246345043, 2.249444375840399, 2.262189205172724, 2.2748626332154656, 2.287465846739575, 2.3000000000000003, 2.312466215969436, 2.324865587512534, 2.337199178504049, 2.349468024894146, 2.361673135723909, 2.373815494093844, 2.38589605808803, 2.39791576165636, 2.4098755154571787], [0.0, 0.24494897427831783, 0.34641016151377546, 0.42426406871192857, 0.48989794855663565, 0.5477225575051662, 0.6000000000000001, 0.6480740698407861, 0.6928203230275509, 0.7348469228349535, 0.7745966692414834, 0.8124038404635961, 0.8485281374238571, 0.8831760866327848, 0.916515138991168, 0.9486832980505138, 0.9797958971132713, 1.0099504938362078, 1.0392304845413265, 1.0677078252031313, 1.0954451150103324, 1.1224972160321824, 1.148912529307606, 1.174734012447073, 1.2000000000000002, 1.2247448713915892, 1.2489995996796799, 1.2727922061357857, 1.2961481396815722, 1.319090595827292, 1.3416407864998738, 1.3638181696985856, 1.3856406460551018, 1.4071247279470291, 1.4282856857085702, 1.449137674618944, 1.469693845669907, 1.489966442575134, 1.50996688705415, 1.5297058540778357, 1.5491933384829668, 1.5684387141358125, 1.5874507866387546, 1.606237840420901, 1.6248076809271923, 1.6431676725154982, 1.661324772583615, 1.6792855623746665, 1.6970562748477143, 1.7146428199482247, 1.7320508075688774, 1.7492855684535904, 1.7663521732655696, 1.7832554500127011, 1.8, 1.8165902124584952, 1.833030277982336, 1.849324200890693, 1.8654758106177631, 1.8814887722226779, 1.8973665961010275, 1.9131126469708992, 1.928730152198591, 1.9442222095223582, 1.9595917942265426, 1.9748417658131499, 1.98997487421324, 2.004993765576342, 2.0199009876724157, 2.0346989949375804, 2.04939015319192, 2.0639767440550294, 2.078460969082653, 2.092844953645635, 2.1071307505705477, 2.121320343559643, 2.1354156504062627, 2.149418526020468, 2.1633307652783937, 2.177154105707724, 2.1908902300206647, 2.2045407685048604, 2.2181073012818837, 2.2315913604421396, 2.244994432064365, 2.2583179581272432, 2.2715633383201097, 2.2847319317591728, 2.297825058615212, 2.3108440016582685, 2.32379000772445, 2.3366642891095846, 2.349468024894146, 2.3622023622035435, 2.374868417407584, 2.3874672772626644, 2.4000000000000004, 2.412467616362964, 2.4248711305964283, 2.4372115213907883, 2.4494897427831783, 2.4617067250182347], [0.0, 0.25, 0.3535533905932738, 0.4330127018922194, 0.5, 0.5590169943749475, 0.6123724356957946, 0.6614378277661477, 0.7071067811865476, 0.75, 0.7905694150420949, 0.8291561975888501, 0.8660254037844388, 0.9013878188659974, 0.9354143466934853, 0.9682458365518541, 1.0, 1.0307764064044151, 1.0606601717798214, 1.0897247358851685, 1.118033988749895, 1.1456439237389602, 1.1726039399558574, 1.19895788082818, 1.2247448713915892, 1.2500000000000002, 1.2747548783981963, 1.2990381056766582, 1.3228756555322954, 1.3462912017836262, 1.3693063937629153, 1.3919410907075056, 1.4142135623730951, 1.4361406616345074, 1.4577379737113252, 1.479019945774904, 1.5, 1.520690632574555, 1.5411035007422442, 1.5612494995995998, 1.5811388300841898, 1.6007810593582124, 1.6201851746019653, 1.6393596310755, 1.6583123951777001, 1.6770509831248421, 1.6955824957813173, 1.7139136501002612, 1.7320508075688776, 1.75, 1.767766952966369, 1.7853571071357128, 1.8027756377319948, 1.82002747232013, 1.8371173070873839, 1.854049621773916, 1.8708286933869707, 1.8874586088176875, 1.9039432764659774, 1.920286436967152, 1.9364916731037083, 1.9525624189766637, 1.9685019685029528, 1.984313483298443, 2.0, 2.0155644370746373, 2.03100960115899, 2.0463381929681126, 2.0615528128088303, 2.0766559657295187, 2.091650066335189, 2.1065374432940898, 2.121320343559643, 2.136000936329383, 2.1505813167606567, 2.165063509461097, 2.179449471770337, 2.1937410968480306, 2.207940216581962, 2.2220486043288976, 2.23606797749979, 2.2500000000000004, 2.2638462845343543, 2.277608394786075, 2.2912878474779204, 2.304886114323222, 2.318404623873926, 2.331844763272204, 2.345207879911715, 2.358495283014151, 2.3717082451262845, 2.3848480035423645, 2.39791576165636, 2.410912690248239, 2.4238399287081647, 2.436698586202241, 2.4494897427831783, 2.4622144504490264, 2.4748737341529163, 2.4874685927665503, 2.5000000000000004, 2.512468905280223], [0.0, 0.25495097567963926, 0.36055512754639896, 0.44158804331639245, 0.5099019513592785, 0.570087712549569, 0.6244997998398399, 0.6745368781616021, 0.7211102550927979, 0.7648529270389177, 0.806225774829855, 0.8455767262643883, 0.8831760866327849, 0.9192388155425119, 0.9539392014169457, 0.9874208829065749, 1.019803902718557, 1.051189802081432, 1.0816653826391969, 1.1113055385446438, 1.140175425099138, 1.1683321445547925, 1.1958260743101399, 1.2227019260637486, 1.2489995996796799, 1.2747548783981963, 1.3000000000000003, 1.3247641299491772, 1.3490737563232043, 1.3729530217745982, 1.396424004376894, 1.419506956657839, 1.4422205101855958, 1.4645818515876812, 1.4866068747318506, 1.5083103128998356, 1.5297058540778354, 1.5508062419270825, 1.5716233645501714, 1.5921683328090661, 1.61245154965971, 1.632482771731451, 1.652271164185831, 1.6718253497300488, 1.6911534525287766, 1.710263137648707, 1.7291616465790585, 1.7478558292948536, 1.7663521732655698, 1.7846568297574747, 1.8027756377319948, 1.8207141456033127, 1.8384776310850237, 1.856071119327059, 1.8734993995195197, 1.8907670401189038, 1.9078784028338913, 1.924837655492016, 1.9416487838947603, 1.958315602756614, 1.9748417658131499, 1.9912307751739877, 2.007485989988473, 2.0236106344848066, 2.039607805437114, 2.0554804791094465, 2.071231517720798, 2.0868636754709207, 2.102379604162864, 2.1177818584547374, 2.1330729007701543, 2.1482551058940835, 2.1633307652783937, 2.1783020910791966, 2.193171219946131, 2.207940216581962, 2.2226110770892875, 2.2371857321197095, 2.251666049839541, 2.266053838724932, 2.280350850198276, 2.2945587811167534, 2.3086792761230397, 2.322713929867387, 2.336664289109585, 2.350531854708632, 2.3643180835073783, 2.3780243901188234, 2.3916521486202797, 2.405202694161139, 2.418677324489565, 2.432077301403062, 2.4454038521274972, 2.4586581706288495, 2.4718414188616555, 2.4849547279578355, 2.4979991993593598, 2.5109759058979444, 2.5238858928247927, 2.5367301787931646, 2.5495097567963927, 2.5622255950637918], [0.0, 0.2598076211353316, 0.3674234614174767, 0.45000000000000007, 0.5196152422706632, 0.5809475019311127, 0.6363961030678928, 0.687386354243376, 0.7348469228349535, 0.7794228634059948, 0.8215838362577492, 0.8616843969807044, 0.9000000000000001, 0.9367496997597599, 0.9721111047611791, 1.0062305898749053, 1.0392304845413265, 1.0712142642814275, 1.1022703842524302, 1.1324751652906127, 1.1618950038622253, 1.190588089979066, 1.2186057606953942, 1.2459935794377115, 1.2727922061357857, 1.2990381056766582, 1.3247641299491772, 1.35, 1.374772708486752, 1.3991068579633223, 1.4230249470757708, 1.4465476141489433, 1.469693845669907, 1.4924811556599302, 1.5149257407543117, 1.5370426148939398, 1.5588457268119895, 1.580348062927911, 1.601561737804697, 1.6224980739587955, 1.6431676725154984, 1.6635804759614128, 1.6837458240482739, 1.703672503740082, 1.7233687939614089, 1.7428425057933377, 1.7621010186706099, 1.7811513130556877, 1.8000000000000003, 1.8186533479473213, 1.8371173070873839, 1.8553975315279476, 1.8734993995195197, 1.891428031937774, 1.9091883092036785, 1.9267848867997694, 1.9442222095223582, 1.9615045245933032, 1.978635893740938, 1.9956202043475106, 2.0124611797498106, 2.0291623887703025, 2.045727254547878, 2.062159062730128, 2.078460969082653, 2.094636006565341, 2.1106870919205436, 2.126617031813674, 2.142428528562855, 2.158124185490724, 2.1737065119284162, 2.189177927898964, 2.2045407685048604, 2.2197972880423116, 2.234949663862701, 2.25, 2.2649503305812253, 2.2798026230355997, 2.294558781116754, 2.309220647751098, 2.3237900077244507, 2.3382685902179845, 2.352658071203719, 2.366960075708925, 2.381176179958132, 2.395307913400697, 2.409356760631352, 2.423324163210527, 2.4372115213907883, 2.4510201957552287, 2.4647515087732477, 2.478406746278746, 2.491987158875423, 2.5054939632735103, 2.518928343562, 2.53229145242012, 2.5455844122715714, 2.5588083163847974, 2.571964229922337, 2.585053190942113, 2.5980762113533165, 2.611034277829382], [0.0, 0.2645751311064591, 0.3741657386773941, 0.45825756949558405, 0.5291502622129182, 0.5916079783099617, 0.6480740698407861, 0.7000000000000001, 0.7483314773547882, 0.7937253933193772, 0.8366600265340756, 0.8774964387392122, 0.9165151389911681, 0.9539392014169458, 0.9899494936611666, 1.0246950765959597, 1.0583005244258363, 1.0908712114635715, 1.1224972160321824, 1.1532562594670797, 1.1832159566199234, 1.2124355652982142, 1.2409673645990857, 1.2688577540449522, 1.2961481396815722, 1.3228756555322954, 1.3490737563232043, 1.374772708486752, 1.4000000000000001, 1.4247806848775009, 1.4491376746189437, 1.4730919862656235, 1.4966629547095764, 1.5198684153570665, 1.5427248620541514, 1.5652475842498528, 1.5874507866387544, 1.6093476939431082, 1.6309506430300091, 1.6522711641858308, 1.6733200530681511, 1.6941074346097418, 1.7146428199482249, 1.7349351572897471, 1.7549928774784245, 1.7748239349298847, 1.7944358444926363, 1.8138357147217055, 1.8330302779823362, 1.8520259177452134, 1.8708286933869709, 1.8894443627691186, 1.9078784028338915, 1.9261360284258224, 1.9442222095223582, 1.9621416870348585, 1.9798989873223332, 1.997498435543818, 2.0149441679609885, 2.0322401432901573, 2.0493901531919194, 2.0663978319771825, 2.083266665599966, 2.1, 2.1166010488516727, 2.133072900770154, 2.149418526020468, 2.1656407827707715, 2.181742422927143, 2.1977260975835913, 2.2135943621178655, 2.2293496809607953, 2.244994432064365, 2.260530911091463, 2.2759613353482084, 2.29128784747792, 2.3065125189341593, 2.32163735324878, 2.336664289109585, 2.3515952032609695, 2.366431913239847, 2.3811761799581315, 2.395829710142188, 2.41039415863879, 2.4248711305964283, 2.4392621835300936, 2.4535688292770597, 2.4677925358506134, 2.4819347291981715, 2.495996794869737, 2.5099800796022267, 2.5238858928247927, 2.5377155080899043, 2.551470164434615, 2.5651510676761324, 2.578759391645525, 2.5922962793631443, 2.6057628441590768, 2.619160170741759, 2.632489316217637, 2.6457513110645907, 2.6589471600616665], [0.0, 0.26925824035672524, 0.38078865529319544, 0.46636895265444084, 0.5385164807134505, 0.6020797289396148, 0.659545297913646, 0.7123903424387504, 0.7615773105863909, 0.8077747210701757, 0.8514693182963201, 0.8930285549745877, 0.9327379053088817, 0.97082439194738, 1.0074720839804943, 1.0428326807307104, 1.077032961426901, 1.110180165558726, 1.1423659658795864, 1.1736694594305503, 1.2041594578792296, 1.2338962679253067, 1.2629330940315089, 1.291317157014496, 1.319090595827292, 1.3462912017836262, 1.3729530217745982, 1.3991068579633223, 1.4247806848775009, 1.4500000000000002, 1.4747881203752626, 1.499166435056495, 1.5231546211727818, 1.5467708298258023, 1.5700318468107584, 1.5929532322073992, 1.6155494421403513, 1.6378339354159202, 1.6598192672697833, 1.681517172080024, 1.7029386365926402, 1.724093964956667, 1.744992836661515, 1.7656443583009576, 1.7860571099491753, 1.8062391868188443, 1.8261982367749676, 1.8459414941974734, 1.8654758106177634, 1.8848076824970765, 1.9039432764659774, 1.9228884523029415, 1.94164878389476, 1.9602295783912662, 1.978635893740938, 1.996872554771586, 2.0149441679609885, 2.032855135025612, 2.050609665440988, 2.0682117879946436, 2.085665361461421, 2.102974084481309, 2.120141504711419, 2.1371710273162514, 2.154065922853802, 2.170829334609241, 2.187464285422736, 2.203973684053419, 2.220360331117452, 2.2366269246345043, 2.2527760652137623, 2.2688102609076854, 2.2847319317591728, 2.3005434140654684, 2.316246964380094, 2.331844763272204, 2.3473389188611007, 2.362731470142132, 2.3780243901188234, 2.393219588754864, 2.4083189157584592, 2.423324163210527, 2.438237068047322, 2.453059314407216, 2.4677925358506134, 2.4824383174612823, 2.4969981978367546, 2.511473670974872, 2.5258661880630178, 2.5401771591761078, 2.55440795488896, 2.5685599078082646, 2.582634314028992, 2.596632434519757, 2.610555496441323, 2.6244046944021417, 2.638181191654584, 2.6518861212352243, 2.665520587052368, 2.6790856649237633, 2.6925824035672523, 2.706011825546962], [0.0, 0.27386127875258304, 0.38729833462074165, 0.47434164902525694, 0.5477225575051661, 0.6123724356957946, 0.6708203932499369, 0.7245688373094719, 0.7745966692414833, 0.8215838362577491, 0.8660254037844386, 0.9082951062292475, 0.9486832980505139, 0.9874208829065749, 1.0246950765959597, 1.0606601717798212, 1.0954451150103321, 1.1291589790636214, 1.161895003862225, 1.1937336386313322, 1.2247448713915892, 1.2549900398011133, 1.284523257866513, 1.3133925536563698, 1.3416407864998738, 1.3693063937629153, 1.396424004376894, 1.4230249470757708, 1.4491376746189437, 1.4747881203752626, 1.4999999999999998, 1.5247950681976905, 1.5491933384829666, 1.5732132722552274, 1.5968719422671311, 1.6201851746019649, 1.6431676725154982, 1.665833124895768, 1.688194301613413, 1.710263137648707, 1.7320508075688772, 1.7535677916750183, 1.7748239349298849, 1.7958284996067968, 1.816590212458495, 1.8371173070873834, 1.857417562100671, 1.8774983355518586, 1.8973665961010278, 1.9170289512680814, 1.9364916731037085, 1.9557607215607946, 1.9748417658131499, 1.9937402037376888, 2.0124611797498106, 2.03100960115899, 2.0493901531919194, 2.067607312813533, 2.085665361461421, 2.1035683967962626, 2.1213203435596424, 2.1389249636207435, 2.1563858652847823, 2.173706511928416, 2.1908902300206643, 2.2079402165819615, 2.2248595461286986, 2.241651177145989, 2.258317958127243, 2.274862633215465, 2.29128784747792, 2.307596151842865, 2.32379000772445, 2.339871791359518, 2.355843797877949, 2.3717082451262845, 2.3874672772626644, 2.403122968139583, 2.418677324489565, 2.434132288927617, 2.4494897427831783, 2.4647515087732477, 2.479919353527449, 2.4949949899749297, 2.5099800796022267, 2.5248762345905194, 2.539685019840059, 2.55440795488896, 2.569046515733026, 2.5836021365527624, 2.598076211353316, 2.6124700955226263, 2.6267851073127395, 2.6410225292488514, 2.6551836094703507, 2.6692695630078274, 2.6832815729997477, 2.6972207918522355, 2.7110883423451915, 2.7248853186877424, 2.7386127875258306, 2.752271788904577], [0.0, 0.2783882181415011, 0.39370039370059057, 0.48218253804964784, 0.5567764362830022, 0.6224949798994367, 0.6819090848492928, 0.7365459931328118, 0.7874007874011811, 0.8351646544245033, 0.8803408430829505, 0.9233092656309695, 0.9643650760992957, 1.0037429949942367, 1.041633332799983, 1.0781929326423911, 1.1135528725660044, 1.1478240283248997, 1.1811011811017718, 1.2134661099511599, 1.2449899597988734, 1.2757350822173075, 1.3057564857200596, 1.335102992281869, 1.3638181696985856, 1.3919410907075056, 1.419506956657839, 1.4465476141489433, 1.4730919862656235, 1.499166435056495, 1.5247950681976905, 1.55, 1.5748015748023623, 1.5992185591719477, 1.6232683080747927, 1.6469669092000603, 1.6703293088490065, 1.69336942218761, 1.7161002301730515, 1.738533865071371, 1.760681686165901, 1.7825543469975889, 1.8041618552668717, 1.8255136263528682, 1.846618531261939, 1.8674849396983098, 1.8881207588499207, 1.9085334683992314, 1.9287301521985913, 1.9487175269905077, 1.9685019685029528, 1.9880895352071046, 2.0074859899884734, 2.0266968199511246, 2.0457272545478786, 2.064582282206258, 2.083266665599966, 2.10178495569837, 2.120141504711419, 2.1383404780343094, 2.1563858652847823, 2.17428149051589, 2.1920310216782974, 2.2096379793984355, 2.227105745132009, 2.244437568746344, 2.261636575579728, 2.2787057730211684, 2.2956480566497994, 2.312466215969436, 2.3291629397704234, 2.34574082114798, 2.3622023622035435, 2.3785499784532593, 2.3947860029656094, 2.4109126902482387, 2.4269322199023198, 2.4428467000612217, 2.4586581706288495, 2.4743686063317245, 2.489979919597747, 2.50549396327351, 2.5209125331911064, 2.5362373705944794, 2.551470164434615, 2.56661255354212, 2.5816661286851175, 2.596632434519757, 2.6115129714401193, 2.626309197333779, 2.6410225292488514, 2.6556543449779, 2.670205984563738, 2.68467875173176, 2.699073915253156, 2.713392710243027, 2.727636339397171, 2.741805974171039, 2.755902755904134, 2.7699277968929086, 2.783882181415011, 2.7977669667075564], [0.0, 0.282842712474619, 0.39999999999999997, 0.48989794855663565, 0.565685424949238, 0.6324555320336759, 0.6928203230275509, 0.7483314773547882, 0.7999999999999999, 0.848528137423857, 0.8944271909999159, 0.938083151964686, 0.9797958971132713, 1.019803902718557, 1.058300524425836, 1.0954451150103321, 1.131370849898476, 1.16619037896906, 1.2, 1.2328828005937953, 1.2649110640673518, 1.2961481396815722, 1.3266499161421599, 1.3564659966250536, 1.3856406460551018, 1.4142135623730951, 1.4422205101855958, 1.469693845669907, 1.4966629547095764, 1.5231546211727818, 1.5491933384829666, 1.5748015748023623, 1.5999999999999999, 1.624807680927192, 1.6492422502470643, 1.6733200530681511, 1.697056274847714, 1.7204650534085253, 1.7435595774162695, 1.7663521732655694, 1.7888543819998317, 1.8110770276274835, 1.8330302779823362, 1.8547236990991405, 1.876166303929372, 1.8973665961010273, 1.9183326093250879, 1.9390719429665315, 1.9595917942265426, 1.979898987322333, 2.0, 2.0199009876724157, 2.039607805437114, 2.0591260281974004, 2.078460969082653, 2.0976176963403033, 2.116601048851672, 2.1354156504062622, 2.1540659228538015, 2.172556098240043, 2.1908902300206643, 2.209072203437452, 2.2271057451320084, 2.244994432064365, 2.262741699796952, 2.2803508501982757, 2.2978250586152114, 2.315167380558045, 2.33238075793812, 2.349468024894146, 2.3664319132398464, 2.3832750575625967, 2.4, 2.4166091947189146, 2.4331050121192876, 2.449489742783178, 2.4657656011875906, 2.4819347291981715, 2.4979991993593593, 2.513961017995307, 2.5298221281347035, 2.545584412271571, 2.5612496949731396, 2.576819745345025, 2.5922962793631443, 2.6076809620810595, 2.6229754097208002, 2.6381811916545836, 2.6532998322843198, 2.6683328128252666, 2.6832815729997477, 2.698147512646408, 2.7129319932501073, 2.727636339397171, 2.7422618401604177, 2.756809750418044, 2.7712812921102037, 2.785677655436824, 2.8, 2.814249455894058, 2.8284271247461903, 2.8425340807103794], [0.0, 0.2872281323269015, 0.406201920231798, 0.4974937185533101, 0.574456264653803, 0.6422616289332566, 0.7035623639735146, 0.7599342076785333, 0.812403840463596, 0.8616843969807043, 0.9082951062292476, 0.9526279441628827, 0.9949874371066202, 1.0356157588603991, 1.074709263010234, 1.1124297730643495, 1.148912529307606, 1.1842719282327012, 1.2186057606953942, 1.2519984025548916, 1.2845232578665131, 1.3162446581088185, 1.3472193585307481, 1.3774977313955914, 1.4071247279470291, 1.4361406616345074, 1.4645818515876812, 1.4924811556599302, 1.5198684153570665, 1.5467708298258023, 1.5732132722552274, 1.5992185591719477, 1.624807680927192, 1.6500000000000004, 1.6748134224444229, 1.699264546796643, 1.7233687939614086, 1.747140520965615, 1.7705931209625776, 1.79373911146521, 1.8165902124584952, 1.8391574157749524, 1.8614510468986287, 1.8834808201837363, 1.9052558883257653, 1.9267848867997694, 1.948075973877816, 1.9691368667515219, 1.9899748742132404, 2.01059692628831, 2.03100960115899, 2.051219149676602, 2.0712315177207983, 2.091052366632649, 2.1106870919205436, 2.1301408404140796, 2.149418526020468, 2.168524844220144, 2.187464285422736, 2.206241147291021, 2.224859546128699, 2.243323427417456, 2.2616365755797285, 2.2798026230355997, 2.297825058615212, 2.315707235381882, 2.333452377915607, 2.3510635891017495, 2.3685438564654024, 2.38589605808803, 2.4031229681395834, 2.4202272620561898, 2.4372115213907883, 2.4540782383616055, 2.4708298201211676, 2.4874685927665503, 2.503996805109783, 2.520416632225712, 2.536730178793165, 2.552939482243949, 2.5690465157330262, 2.585053190942113, 2.600961360727991, 2.616772821625905, 2.632489316217637, 2.6481125353730723, 2.663644120373441, 2.679085664923763, 2.6944387170614963, 2.709704780967846, 2.724885318687743, 2.7399817517640517, 2.754995462791183, 2.7699277968929086, 2.7847800631288644, 2.799553535833884, 2.8142494558940583, 2.828869031963128, 2.8434134416225865, 2.857883832488648, 2.8722813232690148, 2.8866070047722125], [0.0, 0.29154759474226505, 0.41231056256176607, 0.504975246918104, 0.5830951894845301, 0.651920240520265, 0.7141428428542851, 0.7713624310270757, 0.8246211251235321, 0.8746427842267951, 0.9219544457292888, 0.9669539802906859, 1.009950493836208, 1.051189802081432, 1.0908712114635715, 1.1291589790636214, 1.1661903789690602, 1.2020815280171309, 1.2369316876852983, 1.2708265027138836, 1.30384048104053, 1.336038921588739, 1.3674794331177345, 1.3982131454109563, 1.4282856857085702, 1.4577379737113252, 1.4866068747318506, 1.5149257407543117, 1.5427248620541514, 1.5700318468107584, 1.5968719422671311, 1.6232683080747927, 1.6492422502470643, 1.6748134224444229, 1.7000000000000002, 1.724818831066034, 1.7492855684535902, 1.77341478509682, 1.797220075561143, 1.8207141456033127, 1.8439088914585775, 1.866815470259447, 1.8894443627691186, 1.911805429430516, 1.9339079605813718, 1.9557607215607944, 1.977371993328519, 1.9987496091306685, 2.019900987672416, 2.040833163195855, 2.0615528128088303, 2.0820662813657016, 2.102379604162864, 2.1224985276791126, 2.142428528562855, 2.1621748310439655, 2.181742422927143, 2.201136070305514, 2.220360331117452, 2.2394195676558692, 2.258317958127243, 2.2770595073471402, 2.295648056649799, 2.314087293081227, 2.3323807579381204, 2.3505318547086316, 2.3685438564654024, 2.386419912756345, 2.4041630560342617, 2.421776207662467, 2.4392621835300936, 2.4566236993076496, 2.4738633753705965, 2.49098374141623, 2.5079872407968904, 2.5248762345905194, 2.5416530054277673, 2.5583197610932062, 2.574878637916747, 2.591331703969988, 2.60768096208106, 2.6239283526803856, 2.6400757564888173, 2.656124997058685, 2.672077843177478, 2.6879360111431225, 2.703701166919155, 2.7193749281774298, 2.734958866235469, 2.750454507895013, 2.7658633371878665, 2.781186797034676, 2.7964262908219126, 2.81158318390191, 2.8266588050205144, 2.8416544476765644, 2.8565713714171403, 2.871410803072246, 2.8861739379323623, 2.9008619408720575, 2.9154759474226504, 2.9300170647967225], [0.0, 0.2958039891549808, 0.4183300132670378, 0.51234753829798, 0.5916079783099616, 0.6614378277661477, 0.724568837309472, 0.7826237921249264, 0.8366600265340756, 0.8874119674649423, 0.9354143466934853, 0.9810708435174292, 1.02469507659596, 1.0665364503850772, 1.1067971810589328, 1.14564392373896, 1.1832159566199232, 1.2196310917650468, 1.2549900398011133, 1.2893796958227628, 1.3228756555322954, 1.355544171172596, 1.3874436925511608, 1.4186260959111108, 1.449137674618944, 1.479019945774904, 1.5083103128998356, 1.5370426148939398, 1.5652475842498528, 1.5929532322073992, 1.6201851746019649, 1.6469669092000603, 1.6733200530681511, 1.699264546796643, 1.724818831066034, 1.75, 1.7748239349298847, 1.7993054215446582, 1.823458252881047, 1.8472953201911166, 1.8708286933869707, 1.8940696924875813, 1.9170289512680816, 1.939716474127082, 1.9621416870348585, 1.9843134832984428, 2.006240264773888, 2.027929979067325, 2.04939015319192, 2.0706279240848655, 2.091650066335189, 2.112463017427761, 2.1330729007701543, 2.153485546735803, 2.173706511928416, 2.1937410968480306, 2.2135943621178655, 2.2332711434127295, 2.2527760652137623, 2.2721135535003527, 2.29128784747792, 2.310303010429584, 2.329162939770423, 2.3478713763747794, 2.3664319132398464, 2.384848003542364, 2.403122968139583, 2.42126000256065, 2.4392621835300936, 2.457132475061123, 2.4748737341529163, 2.4924887161229035, 2.5099800796022267, 2.5273503912200224, 2.544602129999894, 2.5617376914898995, 2.5787593916455256, 2.595669470483482, 2.6124700955226268, 2.6291633650269812, 2.6457513110645907, 2.662235902394827, 2.678619047195775, 2.694902595642373, 2.711088342345192, 2.727178028658929, 2.7431733448690405, 2.759075932264279, 2.7748873851023217, 2.790609252475165, 2.806243040080456, 2.821790211904492, 2.8372521918222215, 2.8526303651191824, 2.8679260799399975, 2.8831406486676987, 2.898275349237888, 2.9133314263914434, 2.9283100928692645, 2.943212530552288, 2.958039891549808, 2.97279329923895], [0.0, 0.3, 0.4242640687119285, 0.5196152422706632, 0.6, 0.6708203932499369, 0.7348469228349535, 0.7937253933193772, 0.848528137423857, 0.8999999999999999, 0.9486832980505138, 0.99498743710662, 1.0392304845413265, 1.0816653826391969, 1.1224972160321824, 1.1618950038622249, 1.2, 1.236931687685298, 1.2727922061357855, 1.307669683062202, 1.3416407864998738, 1.374772708486752, 1.407124727947029, 1.438749456993816, 1.469693845669907, 1.5, 1.5297058540778354, 1.5588457268119895, 1.5874507866387544, 1.6155494421403513, 1.6431676725154982, 1.6703293088490065, 1.697056274847714, 1.7233687939614086, 1.7492855684535902, 1.7748239349298847, 1.7999999999999998, 1.8248287590894658, 1.849324200890693, 1.8734993995195195, 1.8973665961010275, 1.9209372712298547, 1.9442222095223582, 1.9672315572906, 1.98997487421324, 2.0124611797498106, 2.0346989949375804, 2.056696380120313, 2.078460969082653, 2.1, 2.1213203435596424, 2.142428528562855, 2.1633307652783937, 2.1840329667841556, 2.2045407685048604, 2.224859546128699, 2.244994432064365, 2.264950330581225, 2.2847319317591723, 2.3043437243605824, 2.3237900077244498, 2.3430749027719964, 2.362202362203543, 2.3811761799581315, 2.4, 2.4186773244895647, 2.437211521390788, 2.455605831561735, 2.473863375370596, 2.4919871588754225, 2.5099800796022267, 2.5278449319529073, 2.545584412271571, 2.563201123595259, 2.580697580112788, 2.598076211353316, 2.615339366124404, 2.6324893162176366, 2.6495282598983545, 2.6664583251946765, 2.6832815729997477, 2.7, 2.716615541441225, 2.7331300737432893, 2.749545416973504, 2.765863337187866, 2.7820855486487113, 2.7982137159266447, 2.814249455894058, 2.830194339616981, 2.846049894151541, 2.8618176042508368, 2.877498913987632, 2.8930952282978866, 2.9086079144497976, 2.9240383034426887, 2.939387691339814, 2.9546573405388314, 2.9698484809834995, 2.98496231131986, 3.0, 3.0149626863362675], [0.0, 0.304138126514911, 0.4301162633521313, 0.526782687642637, 0.608276253029822, 0.6800735254367722, 0.744983221287567, 0.8046738469715541, 0.8602325267042626, 0.9124143795447329, 0.9617692030835673, 1.008712050091601, 1.053565375285274, 1.0965856099730655, 1.1379806676741042, 1.1779218989389746, 1.216552506059644, 1.2539936203984452, 1.2903487900563941, 1.3257073583562855, 1.3601470508735445, 1.3937359864766354, 1.4265342617687107, 1.4585952145814824, 1.489966442575134, 1.520690632574555, 1.5508062419270825, 1.580348062927911, 1.6093476939431082, 1.6378339354159202, 1.665833124895768, 1.69336942218761, 1.7204650534085253, 1.747140520965615, 1.77341478509682, 1.7993054215446582, 1.8248287590894658, 1.85, 1.8748333259252676, 1.8993419913222582, 1.9235384061671346, 1.947434209415045, 1.9710403344427025, 1.994367067517913, 2.017424100183202, 2.0402205763103165, 2.062765134473627, 2.0850659461993044, 2.107130750570548, 2.128966885604377, 2.150581316760657, 2.1719806628973477, 2.193171219946131, 2.214158982548453, 2.234949663862701, 2.2555487137279924, 2.2759613353482084, 2.296192500641007, 2.316246964380094, 2.336129277244733, 2.355843797877949, 2.3753947040439405, 2.3947860029656094, 2.4140215409146624, 2.433105012119288, 2.4520399670478454, 2.4708298201211676, 2.4894778569009204, 2.5079872407968904, 2.526361019331956, 2.5446021299998947, 2.5627134057478997, 2.5806975801127883, 2.5985572920372566, 2.616295090390226, 2.633913438213185, 2.651414716712571, 2.6688012290165037, 2.686075203712659, 2.7032387981826544, 2.720294101747089, 2.737243138634199, 2.754087870784083, 2.770830200499482, 2.787471972953271, 2.8040149785619906, 2.820460955234091, 2.836811590500857, 2.8530685235374214, 2.8692333470807148, 2.885307609250702, 2.9012928152808017, 2.917190429162965, 2.933001875212493, 2.9487285395573464, 2.9643717715563276, 2.979932885150268, 2.9954131601500324, 3.0108138434649194, 3.0261361502748025, 3.04138126514911, 3.0565503431155854], [0.0, 0.3082207001484488, 0.4358898943540674, 0.5338539126015657, 0.6164414002968976, 0.6892024376045112, 0.754983443527075, 0.8154753215150046, 0.8717797887081348, 0.9246621004453465, 0.9746794344808964, 1.0222524150130439, 1.0677078252031313, 1.1113055385446435, 1.1532562594670797, 1.1937336386313322, 1.2328828005937953, 1.2708265027138834, 1.307669683062202, 1.3435028842544405, 1.3784048752090223, 1.4124446891825535, 1.445683229480096, 1.4781745499094485, 1.50996688705415, 1.5411035007422442, 1.5716233645501714, 1.601561737804697, 1.6309506430300091, 1.6598192672697833, 1.688194301613413, 1.7161002301730515, 1.7435595774162695, 1.7705931209625776, 1.797220075561143, 1.823458252881047, 1.849324200890693, 1.8748333259252676, 1.9000000000000001, 1.9248376554920161, 1.949358868961793, 1.9735754355990553, 1.9974984355438181, 2.0211382931407735, 2.0445048300260877, 2.067607312813533, 2.0904544960366875, 2.113054660911544, 2.1354156504062627, 2.157544901039142, 2.179449471770337, 2.2011360703055143, 2.222611077089287, 2.243880567231688, 2.2649503305812253, 2.285825890132492, 2.3065125189341593, 2.327015255644019, 2.3473389188611007, 2.367488120350343, 2.3874672772626644, 2.4072806234421447, 2.4269322199023193, 2.4464259645450137, 2.4657656011875906, 2.4849547279578355, 2.503996805109783, 2.522895162308573, 2.541653005427767, 2.5602734228984216, 2.5787593916455256, 2.5971137826441106, 2.615339366124404, 2.6334388164527387, 2.6514147167125706, 2.669269563007828, 2.687005768508881, 2.7046256672597044, 2.7221315177632404, 2.739525506360545, 2.7568097504180447, 2.7739863013360395, 2.791057147390573, 2.8080242164197946, 2.824889378365107, 2.841654447676565, 2.8583211855912904, 2.8748913022930105, 2.891366458960192, 2.9077482697097423, 2.924038303442689, 2.9402380855978314, 2.956349099818897, 2.9723727895403704, 2.9883105594967874, 3.0041637771599605, 3.0199337741083, 3.0356218473321084, 3.0512292604784714, 3.066757245039131, 3.0822070014844885, 3.0975797003467083], [0.0, 0.31224989991991997, 0.44158804331639234, 0.5408326913195985, 0.6244997998398399, 0.6982120021884471, 0.7648529270389178, 0.8261355820929154, 0.8831760866327847, 0.9367496997597597, 0.987420882906575, 1.0356157588603991, 1.081665382639197, 1.1258330249197703, 1.1683321445547923, 1.2093386622447824, 1.2489995996796799, 1.2874393189583735, 1.3247641299491772, 1.3610657588816202, 1.3964240043768943, 1.4309088021254186, 1.4645818515876812, 1.497497913187194, 1.5297058540778357, 1.5612494995995998, 1.5921683328090661, 1.6224980739587955, 1.6522711641858308, 1.681517172080024, 1.710263137648707, 1.738533865071371, 1.7663521732655694, 1.79373911146521, 1.8207141456033127, 1.8472953201911166, 1.8734993995195195, 1.8993419913222582, 1.9248376554920161, 1.9500000000000004, 1.97484176581315, 1.9993749023132208, 2.0236106344848066, 2.047559522944327, 2.0712315177207983, 2.094636006565341, 2.1177818584547374, 2.1406774628607645, 2.163330765278394, 2.1857492994394394, 2.207940216581962, 2.2299103120977763, 2.2516660498395407, 2.2732135843338614, 2.2945587811167534, 2.3157072353818826, 2.3366642891095846, 2.3574350468252567, 2.3780243901188234, 2.3984369910422916, 2.4186773244895647, 2.43874967965144, 2.4586581706288495, 2.478406746278746, 2.4979991993593598, 2.517439175034821, 2.5367301787931646, 2.5558755838264116, 2.574878637916747, 2.593742469868588, 2.6124700955226268, 2.631064423384574, 2.6495282598983545, 2.6678643143908203, 2.6860752037126585, 2.704163456597992, 2.7221315177632404, 2.7399817517640517, 2.757716446627536, 2.775337817275584, 2.7928480087537886, 2.8102490992792797, 2.827543103119739, 2.844731973314885, 2.861817604250837, 2.8788018340969566, 2.895686447114052, 2.9124731758421403, 2.9291637031753623, 2.9457596643310873, 2.962262648719725, 2.9786742017212964, 2.994995826374388, 3.01122898498271, 3.027375100644121, 3.04343555870664, 3.0594117081556713, 3.0753048629363566, 3.0911163032147466, 3.106847276581197, 3.1224989991991996, 3.1380726569026414], [0.0, 0.31622776601683794, 0.4472135954999579, 0.5477225575051662, 0.6324555320336759, 0.7071067811865476, 0.7745966692414834, 0.8366600265340756, 0.8944271909999159, 0.9486832980505138, 1.0, 1.0488088481701516, 1.0954451150103324, 1.140175425099138, 1.1832159566199232, 1.224744871391589, 1.2649110640673518, 1.3038404810405297, 1.3416407864998738, 1.3784048752090223, 1.4142135623730951, 1.449137674618944, 1.4832396974191326, 1.5165750888103102, 1.5491933384829668, 1.5811388300841898, 1.61245154965971, 1.6431676725154984, 1.6733200530681511, 1.7029386365926402, 1.7320508075688772, 1.760681686165901, 1.7888543819998317, 1.8165902124584952, 1.8439088914585775, 1.8708286933869707, 1.8973665961010275, 1.9235384061671346, 1.949358868961793, 1.97484176581315, 2.0, 2.024845673131659, 2.04939015319192, 2.073644135332772, 2.0976176963403033, 2.1213203435596424, 2.1447610589527217, 2.16794833886788, 2.1908902300206647, 2.2135943621178655, 2.23606797749979, 2.2583179581272432, 2.280350850198276, 2.302172886644268, 2.32379000772445, 2.345207879911715, 2.3664319132398464, 2.3874672772626644, 2.4083189157584592, 2.4289915602982237, 2.449489742783178, 2.4698178070456938, 2.4899799195977463, 2.5099800796022267, 2.5298221281347035, 2.5495097567963922, 2.569046515733026, 2.588435821108957, 2.6076809620810595, 2.6267851073127395, 2.6457513110645907, 2.6645825188948455, 2.6832815729997477, 2.701851217221259, 2.7202941017470885, 2.7386127875258306, 2.7568097504180447, 2.7748873851023217, 2.7928480087537886, 2.8106938645110393, 2.8284271247461903, 2.8460498941515415, 2.863564212655271, 2.8809720581775866, 2.898275349237888, 2.9154759474226504, 2.932575659723036, 2.9495762407505253, 2.9664793948382653, 2.9832867780352594, 3.0, 3.0166206257996713, 3.0331501776206204, 3.0495901363953815, 3.0659419433511785, 3.082207001484488, 3.0983866769659336, 3.1144823004794877, 3.1304951684997055, 3.146426544510455, 3.1622776601683795, 3.178049716414141], [0.0, 0.32015621187164245, 0.45276925690687087, 0.5545268253204709, 0.6403124237432849, 0.7158910531638177, 0.7842193570679062, 0.8470537173048709, 0.9055385138137417, 0.9604686356149273, 1.0124228365658294, 1.0618380290797653, 1.1090536506409419, 1.1543396380615198, 1.197914855071094, 1.2399596767637244, 1.2806248474865698, 1.3200378782444087, 1.3583077707206126, 1.3955285736952865, 1.4317821063276355, 1.467140075112121, 1.5016657417681207, 1.5354152532784089, 1.5684387141358125, 1.6007810593582124, 1.632482771731451, 1.6635804759614128, 1.6941074346097418, 1.724093964956667, 1.7535677916750183, 1.7825543469975889, 1.8110770276274835, 1.8391574157749524, 1.866815470259447, 1.8940696924875813, 1.9209372712298547, 1.947434209415045, 1.9735754355990553, 1.9993749023132208, 2.024845673131659, 2.0500000000000003, 2.0748493921246434, 2.0994046775217017, 2.1236760581595306, 2.147673159491453, 2.1714050750608465, 2.194880406764797, 2.2181073012818837, 2.2410934831014973, 2.2638462845343543, 2.2863726730347356, 2.3086792761230397, 2.3307724041613334, 2.3526580712037184, 2.3743420141167535, 2.395829710142188, 2.4171263930543643, 2.438237068047322, 2.4591665254715878, 2.479919353527449, 2.500499950009998, 2.5209125331911064, 2.5411611519146127, 2.5612496949731396, 2.5811818998280613, 2.600961360727991, 2.620591536275732, 2.6400757564888173, 2.6594172293944403, 2.678619047195775, 2.6976841920432424, 2.716615541441225, 2.735415873317986, 2.7540878707840823, 2.7726341266023544, 2.791057147390573, 2.80935935757603, 2.827543103119739, 2.8456106550264395, 2.863564212655271, 2.8814059068447824, 2.8991378028648453, 2.916761903207048, 2.934280150224242, 2.9516944286290885, 2.969006567860705, 2.9862183443278227, 3.0033314835362415, 3.0203476621077914, 3.0372685096974883, 3.0540956108150907, 3.0708305065568178, 3.087474696252587, 3.104029639033752, 3.120496755325985, 3.136877428271625, 3.1531730050855127, 3.169384798348096, 3.1855140872392957, 3.2015621187164247, 3.2175301086392345], [0.0, 0.32403703492039304, 0.45825756949558405, 0.5612486080160913, 0.6480740698407861, 0.7245688373094721, 0.7937253933193773, 0.8573214099741124, 0.9165151389911681, 0.9721111047611791, 1.02469507659596, 1.074709263010234, 1.1224972160321827, 1.1683321445547925, 1.2124355652982142, 1.2549900398011133, 1.2961481396815722, 1.336038921588739, 1.374772708486752, 1.4124446891825537, 1.4491376746189442, 1.48492424049175, 1.5198684153570665, 1.5540270267920056, 1.5874507866387546, 1.6201851746019653, 1.652271164185831, 1.6837458240482739, 1.7146428199482249, 1.744992836661515, 1.7748239349298849, 1.8041618552668717, 1.8330302779823362, 1.8614510468986287, 1.8894443627691186, 1.9170289512680816, 1.9442222095223582, 1.9710403344427025, 1.9974984355438181, 2.0236106344848066, 2.04939015319192, 2.0748493921246434, 2.1000000000000005, 2.124852936087578, 2.149418526020468, 2.173706511928416, 2.1977260975835913, 2.221485989152306, 2.2449944320643653, 2.2682592444427514, 2.2912878474779204, 2.3140872930812275, 2.336664289109585, 2.3590252224170905, 2.381176179958132, 2.4031229681395834, 2.4248711305964283, 2.4464259645450137, 2.4677925358506134, 2.4889756929307287, 2.5099800796022267, 2.530810146968753, 2.551470164434615, 2.571964229922337, 2.5922962793631443, 2.6124700955226263, 2.632489316217637, 2.652357441974969, 2.672077843177478, 2.6916537667389546, 2.7110883423451924, 2.73038458829521, 2.749545416973504, 2.7685736399814256, 2.787471972953271, 2.806243040080456, 2.8248893783651075, 2.8434134416225865, 2.8618176042508376, 2.880104164782934, 2.8982753492378883, 2.9163333142835377, 2.9342801502242426, 2.9521178838251023, 2.9698484809835, 2.9874738492579316, 3.0049958402633443, 3.022416251941483, 3.039736830714133, 3.0569592735265547, 3.0740852297878796, 3.0911163032147466, 3.108054053584011, 3.1248999983999495, 3.141655614481002, 3.1583223394707516, 3.174901573277509, 3.19139467944659, 3.2078029864690882, 3.2241277890307023, 3.2403703492039306, 3.2565318975867568], [0.0, 0.32787192621510003, 0.4636809247747851, 0.5678908345800274, 0.6557438524302001, 0.733143914930759, 0.8031189202104505, 0.8674675786448736, 0.9273618495495702, 0.9836157786453, 1.036822067666386, 1.0874281585465773, 1.1357816691600549, 1.182159041753689, 1.2267844146385296, 1.2698425099200292, 1.3114877048604001, 1.3518505834595773, 1.3910427743243554, 1.4291605927956452, 1.466287829861518, 1.502497920131672, 1.5378556499229699, 1.5724185193516387, 1.606237840420901, 1.6393596310755, 1.6718253497300488, 1.703672503740082, 1.7349351572897471, 1.7656443583009576, 1.7958284996067968, 1.8255136263528682, 1.8547236990991405, 1.8834808201837363, 1.911805429430516, 1.939716474127082, 1.9672315572906, 1.994367067517913, 2.0211382931407735, 2.047559522944327, 2.073644135332772, 2.0994046775217017, 2.124852936087578, 2.1499999999999995, 2.1748563170931545, 2.1994317447922764, 2.2237355957937086, 2.247776679298902, 2.2715633383201097, 2.2951034835057, 2.318404623873926, 2.3414738947936193, 2.364318083507378, 2.386943652456002, 2.4093567606313515, 2.4315632831575655, 2.453568829277059, 2.4753787588973126, 2.4969981978367546, 2.518432051892605, 2.5396850198400585, 2.5607616054603755, 2.581666128685117, 2.602402735934621, 2.6229754097208002, 2.64338797757726, 2.6636441203734402, 2.683747380063928, 2.7037011669191546, 2.7235087662792643, 2.7431733448690405, 2.762697956708261, 2.782085548648711, 2.8013389655662877, 2.8204609552340902, 2.839454172900137, 2.8583211855912904, 2.8770644761631603, 2.895686447114052, 2.9141894241795607, 2.932575659723036, 2.9508473359359, 2.9690065678607045, 2.987055406248769, 3.004995840263344, 3.0228298000383678, 3.040559159102154, 3.0581857366746052, 3.0757112998459397, 3.0931375656443083, 3.1104662029991577, 3.1276988346066825, 3.1448370387032774, 3.1618823507524754, 3.1788362650504665, 3.1957002362549582, 3.212475680841802, 3.2291639784935047, 3.245766473423496, 3.262284475639732, 3.278719262151, 3.295072078119081], [0.0, 0.33166247903554, 0.469041575982343, 0.574456264653803, 0.66332495807108, 0.7416198487095664, 0.8124038404635961, 0.8774964387392122, 0.938083151964686, 0.99498743710662, 1.0488088481701516, 1.1, 1.148912529307606, 1.1958260743101399, 1.2409673645990857, 1.284523257866513, 1.32664991614216, 1.3674794331177345, 1.407124727947029, 1.4456832294800963, 1.4832396974191329, 1.5198684153570665, 1.5556349186104048, 1.5905973720586868, 1.6248076809271923, 1.6583123951777001, 1.6911534525287766, 1.7233687939614089, 1.7549928774784245, 1.7860571099491753, 1.816590212458495, 1.846618531261939, 1.876166303929372, 1.9052558883257653, 1.9339079605813718, 1.9621416870348585, 1.98997487421324, 2.017424100183202, 2.0445048300260877, 2.0712315177207983, 2.0976176963403033, 2.1236760581595306, 2.149418526020468, 2.1748563170931545, 2.2, 2.224859546128699, 2.249444375840399, 2.273763400180415, 2.297825058615212, 2.32163735324878, 2.345207879911715, 2.368543856465403, 2.3916521486202797, 2.4145392935299275, 2.4372115213907883, 2.459674775249769, 2.4819347291981715, 2.503996805109783, 2.525866188063018, 2.5475478405713994, 2.569046515733026, 2.5903667693977237, 2.6115129714401193, 2.632489316217637, 2.65329983228432, 2.6739483914241875, 2.6944387170614963, 2.714774392099646, 2.734958866235469, 2.7549954627911823, 2.774887385102322, 2.7946377224964243, 2.814249455894058, 2.833725463060951, 2.8530685235374214, 2.8722813232690148, 2.8913664589601926, 2.91032644217105, 2.9291637031753623, 2.9478805945967355, 2.9664793948382657, 2.9849623113198605, 3.003331483536242, 3.0215889859476257, 3.039736830714133, 3.0577769702841313, 3.07571129984594, 3.093541659651604, 3.1112698372208096, 3.1288975694324033, 3.146426544510455, 3.1638584039112754, 3.1811947441173736, 3.1984371183438958, 3.2155870381627056, 3.2326459750489227, 3.2496153618543846, 3.2664965942122155, 3.283291031876401, 3.3000000000000007, 3.3166247903554003, 3.333166662499792], [0.0, 0.33541019662496846, 0.47434164902525683, 0.5809475019311126, 0.6708203932499369, 0.75, 0.8215838362577491, 0.8874119674649423, 0.9486832980505137, 1.0062305898749053, 1.0606601717798212, 1.1124297730643495, 1.161895003862225, 1.2093386622447824, 1.2549900398011131, 1.2990381056766578, 1.3416407864998738, 1.382931668593933, 1.4230249470757705, 1.4620191517213446, 1.5, 1.5370426148939398, 1.5732132722552272, 1.6085707942145413, 1.6431676725154982, 1.6770509831248421, 1.710263137648707, 1.7428425057933377, 1.7748239349298847, 1.8062391868188443, 1.8371173070873834, 1.8674849396983098, 1.8973665961010273, 1.9267848867997694, 1.9557607215607944, 1.9843134832984428, 2.0124611797498106, 2.0402205763103165, 2.067607312813533, 2.094636006565341, 2.1213203435596424, 2.147673159491453, 2.173706511928416, 2.1994317447922764, 2.224859546128699, 2.2499999999999996, 2.274862633215465, 2.299456457513384, 2.32379000772445, 2.347871376374779, 2.3717082451262845, 2.3953079134006967, 2.4186773244895647, 2.441823089414956, 2.4647515087732472, 2.48746859276655, 2.5099800796022262, 2.5322914524201194, 2.55440795488896, 2.57633460559765, 2.5980762113533156, 2.6196373794859467, 2.641022529248851, 2.662235902394827, 2.6832815729997477, 2.7041634565979917, 2.7248853186877424, 2.7454507826584686, 2.765863337187866, 2.786126343151006, 2.806243040080456, 2.8262165522125153, 2.846049894151541, 2.8657459761814197, 2.8853076092507015, 2.9047375096555625, 2.924038303442689, 2.9432125305522874, 2.962262648719725, 2.9811910371527683, 3.0, 3.018691769624716, 3.0372685096974883, 3.055732318119504, 3.0740852297878796, 3.092329219213245, 3.110466202999158, 3.1284980421921316, 3.1464265445104544, 3.1642534664593476, 3.181980515339464, 3.199609351155231, 3.2171415884290826, 3.2345787979271736, 3.2519225083018197, 3.269174207655505, 3.2863353450309964, 3.303407331831786, 3.320391543176798, 3.337289319193048, 3.3541019662496843, 3.370830758136635], [0.0, 0.3391164991562634, 0.47958315233127197, 0.5873670062235367, 0.6782329983125268, 0.7582875444051551, 0.8306623862918076, 0.8972179222463181, 0.9591663046625439, 1.0173494974687902, 1.0723805294763609, 1.1247221879201994, 1.1747340124470733, 1.2227019260637484, 1.2688577540449522, 1.3133925536563695, 1.3564659966250536, 1.3982131454109563, 1.438749456993816, 1.4781745499094485, 1.5165750888103102, 1.5540270267920056, 1.5905973720586868, 1.6263455967290594, 1.661324772583615, 1.6955824957813173, 1.7291616465790585, 1.7621010186706099, 1.7944358444926363, 1.8261982367749676, 1.857417562100671, 1.8881207588499207, 1.9183326093250879, 1.948075973877816, 1.977371993328519, 2.006240264773888, 2.0346989949375804, 2.062765134473627, 2.0904544960366875, 2.1177818584547374, 2.1447610589527217, 2.1714050750608465, 2.1977260975835913, 2.2237355957937086, 2.249444375840399, 2.274862633215465, 2.3000000000000003, 2.324865587512534, 2.3494680248941466, 2.373815494093844, 2.39791576165636, 2.421776207662467, 2.445403852127497, 2.468805379125702, 2.4919871588754225, 2.5149552679918585, 2.5377155080899043, 2.5602734228984216, 2.582634314028992, 2.604803255526221, 2.626785107312739, 2.6485845276298057, 2.670205984563738, 2.691653766738954, 2.7129319932501073, 2.734044622898463, 2.7549954627911823, 2.775788176356402, 2.7964262908219126, 2.816913204200655, 2.8372521918222215, 2.85744641244591, 2.877498913987632, 2.897412638890084, 2.9171904291629644, 2.936835031117683, 2.956349099818897, 2.9757352032733024, 2.994995826374388, 3.0141333746203074, 3.0331501776206204, 3.052048492406371, 3.0708305065568178, 3.0894983411550814, 3.108054053584011, 3.1264996401726965, 3.144837038703278, 3.163068130786942, 3.1811947441173736, 3.199218654609278, 3.2171415884290826, 3.2349652239243625, 3.252691193458119, 3.270321085153567, 3.28785644455472, 3.3052987762076818, 3.32264954516723, 3.3399101784329477, 3.357082066318904, 3.374166563760598, 3.3911649915626345, 3.408078637590395], [0.0, 0.3427827300200522, 0.4847679857416329, 0.593717104351896, 0.6855654600401044, 0.7664854858377946, 0.8396427811873333, 0.9069178573608527, 0.9695359714832658, 1.0283481900601565, 1.08397416943394, 1.1368817000902074, 1.187434208703792, 1.2359207094308275, 1.282575533838066, 1.3275918047351754, 1.3711309200802089, 1.413329402510257, 1.4543039572248988, 1.4941552797483937, 1.5329709716755893, 1.5708278072405009, 1.6077935190813528, 1.6439282222773597, 1.6792855623746665, 1.7139136501002612, 1.7478558292948536, 1.7811513130556877, 1.8138357147217055, 1.8459414941974734, 1.8774983355518586, 1.9085334683992314, 1.9390719429665315, 1.9691368667515219, 1.9987496091306685, 2.027929979067325, 2.056696380120313, 2.0850659461993044, 2.113054660911544, 2.1406774628607645, 2.16794833886788, 2.194880406764797, 2.221485989152306, 2.247776679298902, 2.273763400180415, 2.299456457513384, 2.324865587512534, 2.35, 2.374868417407584, 2.3994791101403656, 2.4238399287081647, 2.44795833297873, 2.471841418861655, 2.4954959426935566, 2.518928343562, 2.5421447637772325, 2.565151067676132, 2.587952858921507, 2.610555496441323, 2.632964109136317, 2.6551836094703507, 2.677218706045511, 2.6990739152531558, 2.7207535720825584, 2.7422618401604177, 2.7636027210870955, 2.784780063128864, 2.80579756931964, 2.826658805020514, 2.84736720498077, 2.8679260799399975, 2.888338622807236, 2.9086079144497976, 2.928736929121494, 2.948728539557346, 2.968585521759479, 2.9883105594967874, 3.007906248539007, 3.027375100644121, 3.046719547316425, 3.0659419433511785, 3.08504457018047, 3.1040296390337514, 3.122899293925438, 3.1416556144810017, 3.1603006186120965, 3.178836265050467, 3.1972644557496337, 3.2155870381627056, 3.2338058074040252, 3.2519225083018197, 3.269938837348491, 3.2878564445547194, 3.3056769352131194, 3.3234018715767735, 3.3410327744576227, 3.358571124749333, 3.3760183648789592, 3.3933759001914305, 3.410645100270622, 3.4278273002005224, 3.444923801769787], [0.0, 0.3464101615137755, 0.48989794855663565, 0.6000000000000002, 0.692820323027551, 0.7745966692414835, 0.8485281374238571, 0.9165151389911681, 0.9797958971132713, 1.0392304845413265, 1.0954451150103324, 1.148912529307606, 1.2000000000000004, 1.2489995996796799, 1.2961481396815722, 1.3416407864998738, 1.385640646055102, 1.4282856857085702, 1.4696938456699071, 1.5099668870541503, 1.549193338482967, 1.5874507866387546, 1.6248076809271923, 1.6613247725836153, 1.6970562748477143, 1.7320508075688776, 1.7663521732655698, 1.8000000000000003, 1.8330302779823362, 1.8654758106177634, 1.8973665961010278, 1.9287301521985913, 1.9595917942265426, 1.9899748742132404, 2.019900987672416, 2.04939015319192, 2.078460969082653, 2.107130750570548, 2.1354156504062627, 2.163330765278394, 2.1908902300206647, 2.2181073012818837, 2.2449944320643653, 2.2715633383201097, 2.297825058615212, 2.32379000772445, 2.3494680248941466, 2.374868417407584, 2.400000000000001, 2.4248711305964283, 2.4494897427831783, 2.473863375370597, 2.4979991993593598, 2.521904042583699, 2.5455844122715714, 2.5690465157330262, 2.5922962793631443, 2.6153393661244047, 2.6381811916545845, 2.6608269391300143, 2.6832815729997477, 2.705549851693737, 2.727636339397171, 2.7495454169735045, 2.771281292110204, 2.7928480087537886, 2.8142494558940583, 2.8354893757515653, 2.8565713714171403, 2.8774989139876324, 2.8982753492378883, 2.918903903865285, 2.9393876913398143, 2.9597297173897488, 2.979932885150268, 3.0000000000000004, 3.0199337741083006, 3.039736830714133, 3.0594117081556718, 3.078960863668131, 3.098386676965934, 3.1176914536239795, 3.136877428271625, 3.1559467676119004, 3.174901573277509, 3.193743884534263, 3.2124756808418025, 3.231098884280703, 3.2496153618543846, 3.2680269276736387, 3.286335345030997, 3.3045423283716615, 3.3226495451672307, 3.340658617698014, 3.3585711247493335, 3.3763886032268267, 3.3941125496954285, 3.411744421846397, 3.4292856398964497, 3.4467375879228177, 3.4641016151377553, 3.481379037105843], [0.0, 0.35000000000000003, 0.49497474683058323, 0.6062177826491071, 0.7000000000000001, 0.7826237921249265, 0.8573214099741123, 0.9260129588726067, 0.9899494936611665, 1.05, 1.1067971810589328, 1.16081867662439, 1.2124355652982142, 1.2619429464123963, 1.3095800853708794, 1.3555441711725957, 1.4000000000000001, 1.4430869689661812, 1.4849242404917498, 1.525614630239236, 1.565247584249853, 1.6039014932345441, 1.6416455159382004, 1.678541033159452, 1.7146428199482247, 1.75, 1.7846568297574747, 1.8186533479473213, 1.8520259177452134, 1.8848076824970765, 1.9170289512680814, 1.9487175269905077, 1.979898987322333, 2.01059692628831, 2.040833163195855, 2.0706279240848655, 2.1, 2.128966885604377, 2.157544901039142, 2.1857492994394394, 2.2135943621178655, 2.2410934831014973, 2.2682592444427514, 2.2951034835057, 2.32163735324878, 2.347871376374779, 2.373815494093844, 2.3994791101403656, 2.4248711305964283, 2.45, 2.4748737341529163, 2.499499949989998, 2.5238858928247927, 2.5480384612481815, 2.571964229922337, 2.595669470483482, 2.619160170741759, 2.6424420523447623, 2.665520587052368, 2.6884010117540127, 2.7110883423451915, 2.733587386567329, 2.755902755904134, 2.77803887661782, 2.8000000000000003, 2.821790211904492, 2.843413441622586, 2.8648734701553575, 2.8861739379323623, 2.9073183520213264, 2.9283100928692645, 2.9491524206117257, 2.9698484809834995, 2.990401310861136, 3.0108138434649194, 3.031088913245535, 3.051229260478472, 3.071237535587243, 3.0911163032147466, 3.1108680460604563, 3.130495168499706, 3.1500000000000004, 3.169384798348096, 3.1886517527005047, 3.2078029864690882, 3.2268405600525107, 3.2457664734234966, 3.2645826685810855, 3.283291031876401, 3.3018933962198114, 3.3203915431767985, 3.33878720495931, 3.357082066318904, 3.3752777663475344, 3.3933759001914305, 3.411378020683137, 3.4292856398964493, 3.447100230628637, 3.4648232278140827, 3.48245602987317, 3.5, 3.517456467392312], [0.0, 0.3535533905932738, 0.5, 0.6123724356957946, 0.7071067811865476, 0.7905694150420949, 0.8660254037844387, 0.9354143466934854, 1.0, 1.0606601717798212, 1.118033988749895, 1.1726039399558574, 1.2247448713915892, 1.2747548783981963, 1.3228756555322954, 1.3693063937629153, 1.4142135623730951, 1.4577379737113252, 1.5, 1.5411035007422444, 1.5811388300841898, 1.6201851746019653, 1.6583123951777001, 1.6955824957813173, 1.7320508075688774, 1.767766952966369, 1.8027756377319948, 1.8371173070873839, 1.8708286933869709, 1.9039432764659774, 1.9364916731037085, 1.9685019685029528, 2.0, 2.03100960115899, 2.0615528128088303, 2.091650066335189, 2.1213203435596424, 2.150581316760657, 2.179449471770337, 2.207940216581962, 2.23606797749979, 2.2638462845343543, 2.2912878474779204, 2.318404623873926, 2.345207879911715, 2.3717082451262845, 2.39791576165636, 2.4238399287081647, 2.4494897427831783, 2.4748737341529163, 2.5000000000000004, 2.52487623459052, 2.5495097567963927, 2.5739075352467506, 2.598076211353316, 2.6220221204253793, 2.6457513110645907, 2.669269563007828, 2.6925824035672523, 2.715695122800054, 2.7386127875258306, 2.7613402542968153, 2.7838821814150108, 2.806243040080456, 2.8284271247461903, 2.850438562747845, 2.8722813232690143, 2.8939592256975564, 2.9154759474226504, 2.936835031117683, 2.9580398915498085, 2.9790938219532466, 3.0, 3.020761493398643, 3.0413812651491097, 3.061862178478973, 3.082207001484489, 3.1024184114977142, 3.1224989991991996, 3.142451272494134, 3.1622776601683795, 3.1819805153394642, 3.2015621187164247, 3.2210246816812815, 3.2403703492039306, 3.2596012026013246, 3.2787192621510006, 3.29772648956823, 3.3166247903554003, 3.3354160160315836, 3.3541019662496847, 3.3726843908080104, 3.3911649915626345, 3.4095454242464642, 3.4278273002005224, 3.4460121880225554, 3.464101615137755, 3.4820970692960302, 3.5, 3.5178118198675725, 3.535533905932738, 3.5531676008879742], [0.0, 0.35707142142714254, 0.5049752469181039, 0.6184658438426492, 0.7141428428542851, 0.7984359711335658, 0.8746427842267952, 0.9447221813845593, 1.0099504938362078, 1.0712142642814275, 1.1291589790636216, 1.1842719282327014, 1.2369316876852985, 1.2874393189583735, 1.336038921588739, 1.382931668593933, 1.4282856857085702, 1.472243186433546, 1.514925740754312, 1.5564382416273383, 1.5968719422671316, 1.6363068171953574, 1.6748134224444229, 1.7124543789543711, 1.7492855684535904, 1.7853571071357128, 1.8207141456033127, 1.8553975315279476, 1.8894443627691186, 1.9228884523029415, 1.9557607215607946, 1.9880895352071046, 2.0199009876724157, 2.051219149676602, 2.0820662813657016, 2.112463017427761, 2.142428528562855, 2.1719806628973477, 2.2011360703055143, 2.2299103120977763, 2.2583179581272432, 2.2863726730347356, 2.3140872930812275, 2.3414738947936193, 2.368543856465403, 2.3953079134006967, 2.421776207662467, 2.44795833297873, 2.473863375370597, 2.499499949989998, 2.52487623459052, 2.5500000000000007, 2.574878637916747, 2.599519186311192, 2.6239283526803856, 2.6481125353730723, 2.672077843177478, 2.6958301133417146, 2.71937492817743, 2.7427176303804957, 2.765863337187866, 2.7888169534768683, 2.81158318390191, 2.834166544153678, 2.8565713714171403, 2.8788018340969566, 2.9008619408720575, 2.922755549135097, 2.944486372867092, 2.9660579899927786, 2.9874738492579316, 3.008737276666077, 3.029851481508624, 3.0508195620193606, 3.071644510681534, 3.0923292192132457, 3.1128764832546767, 3.1332890067786603, 3.1535694062442965, 3.1737202145116705, 3.193743884534263, 3.213642792844283, 3.233419242844949, 3.2530754679226246, 3.272613634390715, 3.2920358442763047, 3.31134413795969, 3.330540496676178, 3.3496268448888458, 3.368605052540295, 3.387476937190865, 3.40624426605022, 3.4249087579087423, 3.4434720849746996, 3.461935874622753, 3.480301711058971, 3.498571136907181, 3.516745654721138, 3.5348267284267276, 3.552815784698104, 3.5707142142714257, 3.5885233731996236], [0.0, 0.36055512754639896, 0.5099019513592785, 0.6244997998398399, 0.7211102550927979, 0.806225774829855, 0.8831760866327848, 0.9539392014169458, 1.019803902718557, 1.0816653826391969, 1.140175425099138, 1.1958260743101399, 1.2489995996796799, 1.3000000000000003, 1.3490737563232043, 1.396424004376894, 1.4422205101855958, 1.4866068747318506, 1.5297058540778357, 1.5716233645501714, 1.61245154965971, 1.6522711641858308, 1.6911534525287764, 1.7291616465790585, 1.7663521732655696, 1.8027756377319948, 1.8384776310850237, 1.8734993995195197, 1.9078784028338915, 1.94164878389476, 1.9748417658131499, 2.0074859899884734, 2.039607805437114, 2.0712315177207983, 2.102379604162864, 2.1330729007701543, 2.1633307652783937, 2.193171219946131, 2.222611077089287, 2.2516660498395407, 2.280350850198276, 2.3086792761230397, 2.336664289109585, 2.364318083507378, 2.3916521486202797, 2.4186773244895647, 2.445403852127497, 2.471841418861655, 2.4979991993593598, 2.5238858928247927, 2.5495097567963927, 2.574878637916747, 2.6000000000000005, 2.624880949681338, 2.6495282598983545, 2.673948391424188, 2.6981475126464085, 2.72213151776324, 2.7459060435491964, 2.7694764848252458, 2.792848008753788, 2.816025568065745, 2.839013913315678, 2.861817604250837, 2.8844410203711917, 2.9068883707497264, 2.9291637031753623, 2.951270912674741, 2.973213749463701, 2.994995826374388, 3.0166206257996717, 3.0380915061926625, 3.0594117081556713, 3.0805843601498726, 3.1016124838541645, 3.122498999199199, 3.1432467291003428, 3.1638584039112754, 3.1843366656181322, 3.204684071792413, 3.22490309931942, 3.2449961479175906, 3.264965543462902, 3.2848135411313684, 3.3045423283716615, 3.3241540277189325, 3.343650699460098, 3.363034344160048, 3.3823069050575527, 3.4014702703389896, 3.420526275297414, 3.439476704383968, 3.458323293158117, 3.4770677301427426, 3.4957116585897072, 3.5142566781611158, 3.532704346531139, 3.5510561809129415, 3.5693136595149495, 3.58747822293042, 3.6055512754639896, 3.6235341863986883], [0.0, 0.36400549446402597, 0.5147815070493501, 0.6304760106459247, 0.7280109889280519, 0.8139410298049855, 0.8916277250063506, 0.9630680142129112, 1.0295630140987002, 1.0920164833920778, 1.151086443322134, 1.2072696467649637, 1.2609520212918495, 1.312440474840669, 1.3619838471876238, 1.4097872179871684, 1.4560219778561039, 1.5008331019803636, 1.5443445211480502, 1.5866631652622434, 1.627882059609971, 1.668082731761228, 1.7073371078963875, 1.7457090250096094, 1.7832554500127011, 1.82002747232013, 1.856071119327059, 1.891428031937774, 1.9261360284258224, 1.9602295783912662, 1.9937402037376888, 2.0266968199511246, 2.0591260281974004, 2.091052366632649, 2.1224985276791126, 2.153485546735803, 2.1840329667841556, 2.214158982548453, 2.243880567231688, 2.2732135843338614, 2.302172886644268, 2.3307724041613334, 2.3590252224170905, 2.386943652456002, 2.4145392935299275, 2.441823089414956, 2.468805379125702, 2.4954959426935566, 2.521904042583699, 2.5480384612481815, 2.5739075352467506, 2.599519186311192, 2.624880949681338, 2.6500000000000004, 2.6748831750190516, 2.699536997338618, 2.7239676943752476, 2.7481812167322595, 2.7721832551258228, 2.795979256003163, 2.819574435974337, 2.8429737951659, 2.866182129593303, 2.8892040426387338, 2.9120439557122078, 2.934706118165838, 2.9571946165242493, 2.9795133830879164, 3.001666203960727, 3.0236567265481713, 3.0454884665682127, 3.0671648146130006, 3.0886890422961004, 3.110064308016798, 3.1312936623702354, 3.1523800532296233, 3.1733263305244868, 3.194135250736888, 3.2148094811357026, 3.235351603767356, 3.255764119219942, 3.2760494501762336, 3.2962099447699025, 3.316247879758086, 3.336165463522456, 3.3559648389099674, 3.3756480859236504, 3.3952172242729923, 3.414674215792775, 3.4340209667385553, 3.453259329966402, 3.4723911070039337, 3.491418050019219, 3.510341863693621, 3.5291642070042597, 3.5478866949213583, 3.5665109000254023, 3.585038354048671, 3.6034705493454506, 3.6218089402948914, 3.64005494464026, 3.65820994476807], [0.0, 0.3674234614174767, 0.5196152422706632, 0.6363961030678928, 0.7348469228349535, 0.8215838362577492, 0.9, 0.9721111047611791, 1.0392304845413265, 1.1022703842524302, 1.161895003862225, 1.2186057606953942, 1.2727922061357857, 1.3247641299491772, 1.374772708486752, 1.4230249470757705, 1.469693845669907, 1.5149257407543117, 1.5588457268119897, 1.601561737804697, 1.6431676725154984, 1.6837458240482739, 1.7233687939614086, 1.7621010186706099, 1.8, 1.8371173070873839, 1.8734993995195197, 1.9091883092036785, 1.9442222095223582, 1.978635893740938, 2.0124611797498106, 2.0457272545478786, 2.078460969082653, 2.1106870919205436, 2.142428528562855, 2.173706511928416, 2.2045407685048604, 2.234949663862701, 2.2649503305812253, 2.2945587811167534, 2.32379000772445, 2.3526580712037184, 2.381176179958132, 2.4093567606313515, 2.4372115213907883, 2.4647515087732472, 2.4919871588754225, 2.518928343562, 2.5455844122715714, 2.571964229922337, 2.598076211353316, 2.6239283526803856, 2.6495282598983545, 2.6748831750190516, 2.7, 2.724885318687743, 2.749545416973504, 2.7739863013360395, 2.7982137159266447, 2.822233158334017, 2.846049894151541, 2.8696689704563485, 2.8930952282978866, 2.9163333142835373, 2.939387691339814, 2.9622626487197246, 2.98496231131986, 3.0074906483645134, 3.0298514815086235, 3.052048492406371, 3.0740852297878796, 3.095965116082544, 3.1176914536239795, 3.1392674304684527, 3.1606961258558215, 3.181980515339464, 3.203123475609394, 3.224127789030702, 3.244996147917591, 3.2657311585615862, 3.286335345030997, 3.3068111527572905, 3.3271609519228256, 3.3473870406632096, 3.3674916480965478, 3.387476937190865, 3.4073450074801643, 3.427097897638759, 3.4467375879228173, 3.466266002487403, 3.4856850115866753, 3.504996433664377, 3.5242020373412197, 3.5433035433053153, 3.5623026261113755, 3.5812009158939966, 3.6, 3.618701424544446, 3.6373066958946425, 3.6558172820861827, 3.6742346141747677, 3.692560087527352], [0.0, 0.37080992435478316, 0.5244044240850758, 0.6422616289332566, 0.7416198487095663, 0.8291561975888501, 0.9082951062292476, 0.9810708435174292, 1.0488088481701516, 1.1124297730643495, 1.1726039399558574, 1.2298373876248845, 1.2845232578665131, 1.336974195712094, 1.3874436925511608, 1.4361406616345072, 1.4832396974191326, 1.5288884851420657, 1.5732132722552274, 1.6163229875244616, 1.6583123951777001, 1.699264546796643, 1.7392527130926088, 1.7783419243778742, 1.8165902124584952, 1.854049621773916, 1.8907670401189038, 1.9267848867997694, 1.9621416870348585, 1.996872554771586, 2.03100960115899, 2.064582282206258, 2.0976176963403033, 2.1301408404140796, 2.1621748310439655, 2.1937410968480306, 2.224859546128699, 2.2555487137279924, 2.285825890132492, 2.3157072353818826, 2.345207879911715, 2.3743420141167535, 2.4031229681395834, 2.4315632831575655, 2.459674775249769, 2.48746859276655, 2.5149552679918585, 2.5421447637772325, 2.5690465157330262, 2.595669470483482, 2.6220221204253793, 2.6481125353730723, 2.673948391424188, 2.699536997338618, 2.724885318687743, 2.75, 2.7748873851023217, 2.799553535833884, 2.824004249288588, 2.8482450737252227, 2.8722813232690143, 2.896118091514916, 2.9197602641312863, 2.943212530552288, 2.9664793948382653, 2.9895651857753496, 3.0124740662784135, 3.0352100421552377, 3.0577769702841313, 3.0801785662522883, 3.1024184114977142, 3.124499959993599, 3.146426544510455, 3.168201382488178, 3.1898275815473163, 3.2113081446662823, 3.232645975048923, 3.253843880704789, 3.2749045787625635, 3.2958306995353994, 3.3166247903554003, 3.3372893191930486, 3.3578266780761634, 3.378239186321774, 3.398529093593286, 3.418698582794336, 3.43874977280988, 3.4586847211042526, 3.4785054261852175, 3.498213829942361, 3.517811819867572, 3.5373012311647987, 3.5566838487557484, 3.575961409187745, 3.5951356024495102, 3.6142080737002398, 3.6331804249169903, 3.65205421646503, 3.6708309685955305, 3.6895121628746534, 3.708099243547832, 3.7265936188428173], [0.0, 0.37416573867739417, 0.529150262212918, 0.6480740698407861, 0.7483314773547883, 0.8366600265340756, 0.916515138991168, 0.9899494936611666, 1.058300524425836, 1.1224972160321824, 1.1832159566199232, 1.2409673645990857, 1.2961481396815722, 1.3490737563232043, 1.4, 1.4491376746189437, 1.4966629547095767, 1.5427248620541512, 1.5874507866387544, 1.6309506430300091, 1.6733200530681511, 1.7146428199482247, 1.7549928774784245, 1.7944358444926363, 1.833030277982336, 1.8708286933869707, 1.9078784028338913, 1.9442222095223582, 1.9798989873223332, 2.0149441679609885, 2.0493901531919194, 2.083266665599966, 2.116601048851672, 2.149418526020468, 2.181742422927143, 2.2135943621178655, 2.244994432064365, 2.2759613353482084, 2.3065125189341593, 2.3366642891095846, 2.3664319132398464, 2.395829710142188, 2.4248711305964283, 2.453568829277059, 2.4819347291981715, 2.5099800796022262, 2.5377155080899043, 2.565151067676132, 2.5922962793631443, 2.619160170741759, 2.6457513110645907, 2.672077843177478, 2.6981475126464085, 2.7239676943752476, 2.749545416973504, 2.7748873851023217, 2.8, 2.824889378365107, 2.8495613697550017, 2.8740215726399825, 2.8982753492378874, 2.9223278392404914, 2.9461839725312466, 2.9698484809834995, 2.9933259094191533, 3.016620625799671, 3.0397368307141326, 3.062678566222711, 3.0854497241083023, 3.1080540535840107, 3.1304951684997055, 3.152776554086889, 3.1749015732775088, 3.196873472629156, 3.218695387886216, 3.24037034920393, 3.2619012860600183, 3.283291031876401, 3.3045423283716615, 3.3256578296631782, 3.3466401061363023, 3.3674916480965473, 3.3882148692194836, 3.408812109811862, 3.4292856398964493, 3.449637662132068, 3.4698703145794947, 3.4899856733230297, 3.509985754956849, 3.529872518944558, 3.5496478698597693, 3.5693136595149495, 3.5888716889852725, 3.6083237105337433, 3.627671429443411, 3.6469165057620936, 3.666060555964672, 3.685105154537656, 3.704051835490427, 3.722902093797257, 3.7416573867739413, 3.7603191353926335], [0.0, 0.3774917217635375, 0.5338539126015656, 0.6538348415311012, 0.754983443527075, 0.8440971508067067, 0.9246621004453465, 0.998749217771909, 1.0677078252031311, 1.1324751652906124, 1.1937336386313322, 1.2519984025548916, 1.3076696830622023, 1.36106575888162, 1.4124446891825535, 1.4620191517213446, 1.50996688705415, 1.5564382416273381, 1.6015617378046967, 1.6454482671904336, 1.6881943016134133, 1.7298843892006195, 1.7705931209625774, 1.8103866990231674, 1.849324200890693, 1.8874586088176875, 1.924837655492016, 1.9615045245933032, 1.997498435543818, 2.032855135025612, 2.067607312813533, 2.10178495569837, 2.1354156504062622, 2.168524844220144, 2.201136070305514, 2.2332711434127295, 2.264950330581225, 2.296192500641007, 2.327015255644019, 2.3574350468252567, 2.3874672772626644, 2.4171263930543643, 2.4464259645450137, 2.4753787588973126, 2.503996805109783, 2.5322914524201194, 2.5602734228984216, 2.587952858921507, 2.6153393661244047, 2.6424420523447623, 2.669269563007828, 2.6958301133417146, 2.72213151776324, 2.7481812167322595, 2.7739863013360395, 2.799553535833884, 2.824889378365107, 2.85, 2.8748913022930105, 2.8995689334795953, 2.924038303442689, 2.9483045975611137, 2.9723727895403695, 2.9962476533157267, 3.0199337741083, 3.04343555870664, 3.0667572450391307, 3.089902911096075, 3.1128764832546763, 3.135681744055031, 3.1583223394707516, 3.1808017857137845, 3.2031234756093934, 3.2252906845740275, 3.2473065762259035, 3.2691742076555053, 3.290896534380867, 3.3124764150103774, 3.333916615633931, 3.3552198139615235, 3.3763886032268267, 3.3974254958718375, 3.4183329270274423, 3.4391132578035286, 3.459768778401239, 3.480301711058971, 3.500714212842859, 3.521008378291651, 3.5411862419251547, 3.561249780624774, 3.5812009158939966, 3.601041516006168, 3.620773398046335, 3.6403983298534794, 3.65991803186902, 3.679334178897046, 3.698648401781386, 3.7178622890042607, 3.736977388210959, 3.7559952076646748, 3.774917217635375, 3.793744851726326], [0.0, 0.38078865529319544, 0.5385164807134504, 0.6595452979136461, 0.7615773105863909, 0.8514693182963202, 0.9327379053088816, 1.0074720839804943, 1.0770329614269007, 1.1423659658795862, 1.2041594578792296, 1.262933094031509, 1.3190905958272923, 1.3729530217745982, 1.4247806848775009, 1.4747881203752626, 1.5231546211727818, 1.5700318468107584, 1.6155494421403513, 1.6598192672697836, 1.7029386365926404, 1.744992836661515, 1.7860571099491753, 1.8261982367749676, 1.8654758106177631, 1.9039432764659774, 1.9416487838947603, 1.978635893740938, 2.0149441679609885, 2.050609665440988, 2.085665361461421, 2.120141504711419, 2.1540659228538015, 2.187464285422736, 2.220360331117452, 2.2527760652137623, 2.2847319317591723, 2.316246964380094, 2.3473389188611007, 2.3780243901188234, 2.4083189157584592, 2.438237068047322, 2.4677925358506134, 2.4969981978367546, 2.525866188063018, 2.55440795488896, 2.582634314028992, 2.610555496441323, 2.6381811916545845, 2.665520587052368, 2.6925824035672523, 2.71937492817743, 2.7459060435491964, 2.7721832551258228, 2.7982137159266447, 2.824004249288588, 2.8495613697550017, 2.8748913022930105, 2.9000000000000004, 2.924893160441933, 2.9495762407505253, 2.9740544715926105, 2.99833287011299, 3.022416251941483, 3.0463092423455636, 3.07001628660175, 3.093541659651604, 3.11688947510174, 3.1400636936215167, 3.1630681307869426, 3.1859064644147987, 3.2085822414268894, 3.2310988842807027, 3.2534596969994882, 3.27566787083184, 3.29772648956823, 3.319638534539567, 3.3414068893207247, 3.363034344160048, 3.38452360015409, 3.405877273185281, 3.427097897638759, 3.4481879299133342, 3.469149751740331, 3.48998567332303, 3.510697936308392, 3.5312887166019156, 3.5517601270356085, 3.5721142198983507, 3.5923529893372117, 3.612478373637689, 3.6324922573902345, 3.6523964735499352, 3.6721928053957082, 3.691882988394947, 3.7114687119791268, 3.7309516212355263, 3.7503333185198358, 3.769615364994153, 3.7887992820945273, 3.8078865529319548, 3.8268786236304915], [0.0, 0.3840572873934304, 0.5431390245600107, 0.6652067347825036, 0.7681145747868608, 0.8587782018658834, 0.9407443861113389, 1.0161200716450787, 1.0862780491200215, 1.1521718621802912, 1.2144957801491119, 1.2737739202856997, 1.3304134695650072, 1.3847382424126229, 1.4370107863199912, 1.4874474780643514, 1.5362291495737217, 1.5835087622113115, 1.6294170736800322, 1.6740669042783207, 1.7175564037317668, 1.7599715906798041, 1.801388353465182, 1.8418740456393863, 1.8814887722226779, 1.920286436967152, 1.958315602756614, 1.9956202043475106, 2.0322401432901573, 2.0682117879946436, 2.1035683967962626, 2.1383404780343094, 2.172556098240043, 2.206241147291021, 2.2394195676558692, 2.2721135535003527, 2.3043437243605824, 2.336129277244733, 2.367488120350343, 2.3984369910422916, 2.4289915602982237, 2.4591665254715878, 2.4889756929307287, 2.518432051892605, 2.5475478405713994, 2.57633460559765, 2.604803255526221, 2.632964109136317, 2.6608269391300143, 2.6884010117540127, 2.715695122800054, 2.7427176303804957, 2.7694764848252458, 2.795979256003163, 2.822233158334017, 2.8482450737252227, 2.8740215726399825, 2.8995689334795953, 2.924893160441933, 2.9499999999999997, 2.974894956128703, 2.9995833043941285, 3.0240701050074876, 3.048360214935236, 3.0724582991474434, 3.0963688410782066, 3.1200961523645385, 3.1436443819236297, 3.167017524422623, 3.190219428189854, 3.2132538026119257, 3.236124225056881, 3.2588341473600644, 3.2813869019059605, 3.303785707336358, 3.3260336739125176, 3.3481338085566414, 3.370089019595773, 3.391902121229326, 3.413575837739657, 3.4351128074635335, 3.4565155865408737, 3.4777866524558405, 3.4989284073841804, 3.5199431813596083, 3.5408332352710428, 3.5616007637016254, 3.582247897619594, 3.602776706930364, 3.623189202898463, 3.6434873404473356, 3.663673020344474, 3.6837480912787726, 3.7037143518365454, 3.723573552382174, 3.743327396848958, 3.7629775444453557, 3.782525611281436, 3.8019731719200753, 3.8213217608570993, 3.840572873934304, 3.859727969689056], [0.0, 0.38729833462074165, 0.5477225575051661, 0.6708203932499369, 0.7745966692414833, 0.8660254037844386, 0.9486832980505138, 1.0246950765959597, 1.0954451150103321, 1.1618950038622249, 1.224744871391589, 1.284523257866513, 1.3416407864998738, 1.396424004376894, 1.4491376746189437, 1.4999999999999998, 1.5491933384829666, 1.5968719422671311, 1.6431676725154982, 1.6881943016134133, 1.7320508075688772, 1.7748239349298847, 1.816590212458495, 1.857417562100671, 1.8973665961010275, 1.9364916731037083, 1.9748417658131499, 2.0124611797498106, 2.0493901531919194, 2.085665361461421, 2.1213203435596424, 2.1563858652847823, 2.1908902300206643, 2.224859546128699, 2.258317958127243, 2.29128784747792, 2.3237900077244498, 2.355843797877949, 2.3874672772626644, 2.4186773244895647, 2.449489742783178, 2.479919353527449, 2.5099800796022267, 2.5396850198400585, 2.569046515733026, 2.5980762113533156, 2.626785107312739, 2.6551836094703507, 2.6832815729997477, 2.7110883423451915, 2.7386127875258306, 2.765863337187866, 2.792848008753788, 2.819574435974337, 2.846049894151541, 2.8722813232690143, 2.8982753492378874, 2.924038303442689, 2.9495762407505253, 2.974894956128703, 2.9999999999999996, 3.0248966924508345, 3.049590136395381, 3.074085229787879, 3.098386676965933, 3.1224989991991987, 3.1464265445104544, 3.1701734968294715, 3.1937438845342623, 3.217141588429082, 3.24037034920393, 3.2634337744161437, 3.2863353450309964, 3.309078421554859, 3.3316662497915357, 3.3541019662496843, 3.3763886032268267, 3.3985290935932855, 3.420526275297414, 3.442382895611701, 3.4641016151377544, 3.485685011586675, 3.5071355833500366, 3.5284557528754696, 3.5496478698597693, 3.5707142142714248, 3.591656999213594, 3.6124783736376886, 3.63318042491699, 3.6537651812890215, 3.674234614174767, 3.694590640382233, 3.714835124201342, 3.7349698793966195, 3.7549966711037173, 3.7749172176353745, 3.794733192202055, 3.8144462245521304, 3.8340579025361623, 3.853569773599539, 3.8729833462074166, 3.892300091205713], [0.0, 0.3905124837953327, 0.552268050859363, 0.6763874629234342, 0.7810249675906654, 0.873212459828649, 0.9565563234854496, 1.0331989159885913, 1.104536101718726, 1.1715374513859982, 1.2349089035228469, 1.2951833846988619, 1.3527749258468684, 1.4080127840328724, 1.4611639196202457, 1.5124483462254172, 1.5620499351813308, 1.6101242188104619, 1.6568041525780892, 1.7022044530549203, 1.746424919657298, 1.7895530168173281, 1.8316659084014202, 1.8728320800328044, 1.9131126469708992, 1.9525624189766637, 1.9912307751739877, 2.0291623887703025, 2.0663978319771825, 2.102974084481309, 2.1389249636207435, 2.17428149051589, 2.209072203437452, 2.243323427417456, 2.2770595073471402, 2.310303010429584, 2.3430749027719964, 2.3753947040439405, 2.4072806234421447, 2.43874967965144, 2.4698178070456938, 2.500499950009998, 2.530810146968753, 2.5607616054603755, 2.5903667693977237, 2.6196373794859467, 2.6485845276298057, 2.677218706045511, 2.705549851693737, 2.733587386567329, 2.7613402542968153, 2.7888169534768683, 2.816025568065745, 2.8429737951659, 2.8696689704563485, 2.896118091514916, 2.9223278392404914, 2.9483045975611137, 2.9740544715926105, 2.9995833043941285, 3.0248966924508345, 3.05, 3.0748983723043595, 3.099596747965774, 3.1240998703626617, 3.1484122982862326, 3.172538415843061, 3.1964824416849216, 3.2202484376209237, 3.2438403166617187, 3.2672618505409083, 3.2905166767545793, 3.3136083051561784, 3.3365401241405745, 3.359315406448165, 3.3819373146171707, 3.4044089061098406, 3.426733138136088, 3.4489128721961073, 3.470950878361721, 3.492849839314596, 3.5146123541579946, 3.536240942017385, 3.557738045444043, 3.5791060336346563, 3.6003472054789385, 3.621463792446364, 3.642457961322272, 3.6633318168028404, 3.684087403957729, 3.704726710568541, 3.7252516693506763, 3.745664160065609, 3.7659660115301095, 3.7861590035285104, 3.8062448686336507, 3.8262252939417984, 3.846101922726438, 3.865876356015541, 3.885550154096586, 3.9051248379533274, 3.9246018906380815], [0.0, 0.3937003937005905, 0.5567764362830021, 0.6819090848492928, 0.787400787401181, 0.8803408430829505, 0.9643650760992954, 1.041633332799983, 1.1135528725660042, 1.1811011811017715, 1.2449899597988732, 1.3057564857200596, 1.3638181696985856, 1.419506956657839, 1.4730919862656233, 1.5247950681976905, 1.574801574802362, 1.6232683080747925, 1.6703293088490065, 1.7161002301730515, 1.760681686165901, 1.8041618552668715, 1.8466185312619388, 1.8881207588499207, 1.928730152198591, 1.9685019685029528, 2.007485989988473, 2.045727254547878, 2.083266665599966, 2.120141504711419, 2.1563858652847823, 2.1920310216782974, 2.2271057451320084, 2.2616365755797285, 2.295648056649799, 2.329162939770423, 2.362202362203543, 2.3947860029656094, 2.4269322199023193, 2.4586581706288495, 2.4899799195977463, 2.5209125331911064, 2.551470164434615, 2.581666128685117, 2.6115129714401193, 2.641022529248851, 2.670205984563738, 2.6990739152531558, 2.727636339397171, 2.755902755904134, 2.7838821814150108, 2.81158318390191, 2.839013913315678, 2.866182129593303, 2.8930952282978866, 2.9197602641312863, 2.9461839725312466, 2.9723727895403695, 2.99833287011299, 3.0240701050074876, 3.049590136395381, 3.0748983723043595, 3.0999999999999996, 3.1248999983999486, 3.149603149604724, 3.1741140496207754, 3.198437118343895, 3.2225766088644034, 3.246536616149585, 3.2703210851535665, 3.2939338184001206, 3.3173784830796738, 3.340658617698013, 3.363777638310832, 3.3867388443752193, 3.409545424246464, 3.432200460346103, 3.45470693402494, 3.477067730142742, 3.4992856413845383, 3.521363372331802, 3.543303543305315, 3.5651086939951777, 3.5867812868921907, 3.608323710533743, 3.6297382825763074, 3.651027252705737, 3.672192805395708, 3.6932370625238775, 3.7141620858546274, 3.7349698793966195, 3.7556623916427845, 3.7762415176998414, 3.796709101313926, 3.817066936798463, 3.837316770869978, 3.857460304397182, 3.8774991940682595, 3.897435053981015, 3.9172694571601787, 3.9370039370059056, 3.956639988677262], [0.0, 0.3968626966596886, 0.5612486080160912, 0.6873863542433761, 0.7937253933193772, 0.8874119674649424, 0.9721111047611791, 1.05, 1.1224972160321824, 1.1905880899790657, 1.2549900398011133, 1.3162446581088185, 1.3747727084867523, 1.4309088021254186, 1.4849242404917498, 1.5370426148939396, 1.5874507866387544, 1.6363068171953572, 1.6837458240482737, 1.7298843892006197, 1.7748239349298849, 1.8186533479473213, 1.8614510468986285, 1.9032866310674281, 1.9442222095223582, 1.984313483298443, 2.0236106344848066, 2.062159062730128, 2.1, 2.1371710273162514, 2.173706511928416, 2.2096379793984355, 2.244994432064365, 2.2798026230355997, 2.314087293081227, 2.3478713763747794, 2.3811761799581315, 2.4140215409146624, 2.4464259645450137, 2.478406746278746, 2.5099800796022267, 2.5411611519146127, 2.571964229922337, 2.602402735934621, 2.632489316217637, 2.662235902394827, 2.691653766738954, 2.7207535720825584, 2.7495454169735045, 2.77803887661782, 2.806243040080456, 2.834166544153678, 2.861817604250837, 2.8892040426387338, 2.9163333142835373, 2.943212530552288, 2.9698484809834995, 2.9962476533157267, 3.022416251941483, 3.048360214935236, 3.074085229787879, 3.099596747965774, 3.1248999983999486, 3.15, 3.1749015732775088, 3.1996093511552313, 3.2241277890307014, 3.2484611741561573, 3.2726136343907144, 3.296589146375387, 3.3203915431767985, 3.344024521441193, 3.3674916480965473, 3.3907963666371947, 3.4139420030223127, 3.43693177121688, 3.4597687784012394, 3.48245602987317, 3.504996433664377, 3.5273928048914542, 3.5496478698597698, 3.5717642699371974, 3.5937445652132824, 3.615591237958185, 3.6373066958946425, 3.6588932752951404, 3.6803532439155893, 3.70168880377592, 3.722902093797257, 3.7439951923046055, 3.76497011940334, 3.785828839237189, 3.8065732621348563, 3.8272052466519226, 3.847726601514198, 3.868139087468288, 3.8884444190447165, 3.9086442662386154, 3.9287402561126386, 3.9487339743264553, 3.968626966596886, 3.9884207400925], [0.0, 0.4, 0.565685424949238, 0.692820323027551, 0.8, 0.894427190999916, 0.9797958971132713, 1.0583005244258363, 1.131370849898476, 1.2, 1.2649110640673518, 1.32664991614216, 1.385640646055102, 1.4422205101855958, 1.4966629547095767, 1.5491933384829666, 1.6, 1.6492422502470643, 1.697056274847714, 1.7435595774162698, 1.788854381999832, 1.8330302779823362, 1.876166303929372, 1.918332609325088, 1.9595917942265426, 2.0, 2.039607805437114, 2.078460969082653, 2.1166010488516727, 2.154065922853802, 2.1908902300206643, 2.227105745132009, 2.262741699796952, 2.297825058615212, 2.3323807579381204, 2.3664319132398464, 2.4, 2.433105012119288, 2.4657656011875906, 2.4979991993593598, 2.5298221281347035, 2.5612496949731396, 2.5922962793631443, 2.6229754097208002, 2.65329983228432, 2.6832815729997477, 2.7129319932501073, 2.7422618401604177, 2.771281292110204, 2.8000000000000003, 2.8284271247461903, 2.8565713714171403, 2.8844410203711917, 2.9120439557122078, 2.939387691339814, 2.9664793948382653, 2.9933259094191533, 3.0199337741083, 3.0463092423455636, 3.0724582991474434, 3.098386676965933, 3.1240998703626617, 3.149603149604724, 3.1749015732775088, 3.2, 3.2249030993194197, 3.249615361854384, 3.2741411087489802, 3.2984845004941286, 3.32264954516723, 3.3466401061363023, 3.3704599092705436, 3.394112549695428, 3.4176014981270124, 3.4409301068170506, 3.464101615137755, 3.4871191548325395, 3.509985754956849, 3.532704346531139, 3.5552777669262356, 3.577708763999664, 3.6, 3.622154055254967, 3.6441734316577197, 3.6660605559646724, 3.687817782917155, 3.709447398198282, 3.7309516212355263, 3.752332607858744, 3.7735924528226414, 3.794733192202055, 3.8157568056677826, 3.836665218650176, 3.8574603043971822, 3.8781438859330635, 3.8987177379235853, 3.9191835884530852, 3.9395431207184424, 3.9597979746446663, 3.9799497484264803, 4.0, 4.019950248448357], [0.0, 0.40311288741492746, 0.5700877125495689, 0.6982120021884471, 0.8062257748298549, 0.9013878188659973, 0.9874208829065749, 1.066536450385077, 1.1401754250991378, 1.2093386622447824, 1.2747548783981961, 1.3369741957120937, 1.3964240043768943, 1.4534441853748632, 1.5083103128998354, 1.5612494995995994, 1.6124515496597098, 1.662077013859466, 1.710263137648707, 1.7571283390805579, 1.8027756377319946, 1.8472953201911166, 1.8907670401189036, 1.9332614929181204, 1.9748417658131499, 2.0155644370746373, 2.0554804791094465, 2.094636006565341, 2.133072900770154, 2.170829334609241, 2.2079402165819615, 2.244437568746344, 2.2803508501982757, 2.315707235381882, 2.3505318547086316, 2.384848003542364, 2.4186773244895647, 2.4520399670478454, 2.4849547279578355, 2.517439175034821, 2.5495097567963922, 2.5811818998280613, 2.6124700955226263, 2.64338797757726, 2.6739483914241875, 2.7041634565979917, 2.734044622898463, 2.7636027210870955, 2.7928480087537886, 2.821790211904492, 2.850438562747845, 2.8788018340969566, 2.9068883707497264, 2.934706118165838, 2.9622626487197246, 2.9895651857753496, 3.016620625799671, 3.04343555870664, 3.07001628660175, 3.0963688410782066, 3.1224989991991987, 3.1484122982862326, 3.1741140496207754, 3.1996093511552313, 3.2249030993194197, 3.2499999999999996, 3.2749045787625626, 3.299621190379283, 3.324154027718932, 3.3485071300506437, 3.3726843908080104, 3.396689564855758, 3.420526275297414, 3.4441980198589044, 3.46770817687994, 3.491060010942235, 3.5142566781611158, 3.5373012311647987, 3.56019662378358, 3.582945715469326, 3.605551275463989, 3.628015986734347, 3.650342449688796, 3.6725331856907704, 3.6945906403822333, 3.7165171868296265, 3.7383151285037486, 3.759986702104144, 3.7815340802378072, 3.8029593739612833, 3.8242646351945884, 3.84545185901475, 3.866522985836241, 3.887479903485033, 3.908324449172561, 3.929058411375427, 3.9496835316262997, 3.9702015062210636, 3.9906139878469826, 4.010922587136282, 4.031128874149275, 4.05123437979093], [0.0, 0.406201920231798, 0.5744562646538028, 0.7035623639735146, 0.812403840463596, 0.9082951062292476, 0.99498743710662, 1.074709263010234, 1.1489125293076057, 1.218605760695394, 1.284523257866513, 1.3472193585307481, 1.4071247279470291, 1.4645818515876812, 1.5198684153570663, 1.5732132722552272, 1.624807680927192, 1.6748134224444227, 1.7233687939614086, 1.7705931209625776, 1.8165902124584952, 1.8614510468986285, 1.905255888325765, 1.9480759738778157, 1.98997487421324, 2.03100960115899, 2.071231517720798, 2.1106870919205436, 2.149418526020468, 2.187464285422736, 2.2248595461286986, 2.261636575579728, 2.2978250586152114, 2.333452377915607, 2.3685438564654024, 2.403122968139583, 2.437211521390788, 2.4708298201211676, 2.503996805109783, 2.5367301787931646, 2.569046515733026, 2.600961360727991, 2.632489316217637, 2.6636441203734402, 2.6944387170614963, 2.7248853186877424, 2.7549954627911823, 2.784780063128864, 2.8142494558940583, 2.843413441622586, 2.8722813232690143, 2.9008619408720575, 2.9291637031753623, 2.9571946165242493, 2.98496231131986, 3.0124740662784135, 3.0397368307141326, 3.0667572450391307, 3.093541659651604, 3.1200961523645385, 3.1464265445104544, 3.172538415843061, 3.198437118343895, 3.2241277890307014, 3.249615361854384, 3.2749045787625626, 3.3, 3.3249060137092594, 3.3496268448888453, 3.374166563760598, 3.398529093593286, 3.4227182180249662, 3.4467375879228173, 3.4705907278156554, 3.4942810419312296, 3.517811819867572, 3.541186241925155, 3.564407384124323, 3.58747822293042, 3.6104016397071392, 3.6331804249169903, 3.6558172820861823, 3.6783148315499044, 3.7006756139926664, 3.722902093797257, 3.744996662214801, 3.7669616403674726, 3.788799282094527, 3.81051177665153, 3.832101251271944, 3.8535697735995385, 3.8749193539995126, 3.8961519477556315, 3.9172694571601787, 3.9382737335030438, 3.9591665789658306, 3.97994974842648, 4.000624951179503, 4.02119385257662, 4.041658075592244, 4.06201920231798, 4.08227877539004], [0.0, 0.40926763859362253, 0.5787918451395112, 0.7088723439378913, 0.8185352771872451, 0.9151502608861564, 1.002496882788171, 1.0828203913853858, 1.1575836902790224, 1.2278029157808674, 1.2942179105544784, 1.357387196049823, 1.4177446878757827, 1.4756354563373706, 1.5313392831113555, 1.5850867484147357, 1.6370705543744901, 1.6874537030686205, 1.7363755354185337, 1.7839562774911275, 1.8303005217723127, 1.8754999333511053, 1.9196353820452468, 1.9627786426390523, 2.004993765576342, 2.0463381929681126, 2.0868636754709207, 2.126617031813674, 2.1656407827707715, 2.203973684053419, 2.241651177145989, 2.2787057730211684, 2.315167380558045, 2.3510635891017495, 2.386419912756345, 2.42126000256065, 2.455605831561735, 2.4894778569009204, 2.522895162308573, 2.5558755838264116, 2.588435821108957, 2.620591536275732, 2.652357441974969, 2.683747380063928, 2.714774392099646, 2.7454507826584686, 2.775788176356402, 2.80579756931964, 2.8354893757515653, 2.8648734701553575, 2.8939592256975564, 2.922755549135097, 2.951270912674741, 2.9795133830879164, 3.0074906483645134, 3.0352100421552377, 3.062678566222711, 3.089902911096075, 3.11688947510174, 3.1436443819236297, 3.1701734968294715, 3.1964824416849216, 3.2225766088644034, 3.2484611741561573, 3.2741411087489802, 3.299621190379283, 3.3249060137092594, 3.35, 3.374907406137241, 3.399632333061915, 3.4241787336527865, 3.448550420104076, 3.4727510708370675, 3.4967842369811724, 3.5206533484567886, 3.5443617196894563, 3.567912554982255, 3.591308953571107, 3.614553914385564, 3.6376503405357696, 3.6606010435446255, 3.6834087473426025, 3.7060760920412847, 3.7286056375004315, 3.7509998667022106, 3.773261188945181, 3.795391942869669, 3.817394399325278, 3.8392707640904935, 3.8610231804535955, 3.882653731663435, 3.9041644432579936, 3.9255572852781047, 3.9468341743731776, 3.9679969758052995, 3.989047505357638, 4.009987531152684, 4.030818775385468, 4.051542915976579, 4.072161588149468, 4.092676385936225, 4.113088863615762], [0.0, 0.41231056256176607, 0.58309518948453, 0.7141428428542851, 0.8246211251235321, 0.9219544457292888, 1.0099504938362078, 1.0908712114635715, 1.16619037896906, 1.236931687685298, 1.3038404810405297, 1.3674794331177345, 1.4282856857085702, 1.4866068747318506, 1.5427248620541512, 1.5968719422671311, 1.6492422502470643, 1.7, 1.7492855684535902, 1.797220075561143, 1.8439088914585775, 1.8894443627691184, 1.9339079605813716, 1.977371993328519, 2.0199009876724157, 2.0615528128088303, 2.102379604162864, 2.142428528562855, 2.181742422927143, 2.220360331117452, 2.258317958127243, 2.2956480566497994, 2.33238075793812, 2.3685438564654024, 2.4041630560342617, 2.4392621835300936, 2.473863375370596, 2.5079872407968904, 2.541653005427767, 2.574878637916747, 2.6076809620810595, 2.6400757564888173, 2.672077843177478, 2.7037011669191546, 2.734958866235469, 2.765863337187866, 2.7964262908219126, 2.826658805020514, 2.8565713714171403, 2.8861739379323623, 2.9154759474226504, 2.944486372867092, 2.973213749463701, 3.001666203960727, 3.0298514815086235, 3.0577769702841313, 3.0854497241083023, 3.1128764832546763, 3.1400636936215167, 3.167017524422623, 3.1937438845342623, 3.2202484376209237, 3.246536616149585, 3.2726136343907144, 3.2984845004941286, 3.324154027718932, 3.3496268448888453, 3.374907406137241, 3.4, 3.424908757908742, 3.4496376621320683, 3.4741905532080417, 3.4985711369071804, 3.522782990761707, 3.5468295701936396, 3.570714214271425, 3.594440151122286, 3.6180105030251086, 3.6414282912066254, 3.664696440361739, 3.687817782917155, 3.710795063055895, 3.733630940518894, 3.7563279941985894, 3.778888725538237, 3.8013155617496426, 3.8236108588610325, 3.845776904605882, 3.867815921162743, 3.8897300677553446, 3.9115214431215892, 3.9331920878594273, 3.954743986657038, 3.976179070414209, 3.9974992182613374, 4.018706259482023, 4.039801975344831, 4.060788100849391, 4.08166632639171, 4.102438299353203, 4.123105625617661, 4.1436698710201325], [0.0, 0.4153311931459038, 0.5873670062235365, 0.7193747284969081, 0.8306623862918076, 0.9287087810503356, 1.0173494974687902, 1.0988630487917956, 1.174734012447073, 1.2459935794377113, 1.3133925536563698, 1.3774977313955912, 1.4387494569938162, 1.497497913187194, 1.5540270267920053, 1.608570794214541, 1.661324772583615, 1.712454378954371, 1.7621010186706096, 1.8103866990231676, 1.8574175621006712, 1.9032866310674281, 1.9480759738778157, 1.9918584287042091, 2.0346989949375804, 2.0766559657295187, 2.1177818584547374, 2.158124185490724, 2.1977260975835913, 2.2366269246345043, 2.274862633215465, 2.312466215969436, 2.349468024894146, 2.38589605808803, 2.421776207662467, 2.457132475061123, 2.4919871588754225, 2.526361019331956, 2.5602734228984216, 2.593742469868588, 2.6267851073127395, 2.6594172293944403, 2.6916537667389546, 2.7235087662792643, 2.7549954627911823, 2.786126343151006, 2.816913204200655, 2.84736720498077, 2.8774989139876324, 2.9073183520213264, 2.936835031117683, 2.9660579899927786, 2.994995826374388, 3.0236567265481713, 3.052048492406371, 3.0801785662522883, 3.1080540535840107, 3.135681744055031, 3.1630681307869426, 3.190219428189854, 3.217141588429082, 3.2438403166617187, 3.2703210851535665, 3.296589146375387, 3.32264954516723, 3.3485071300506437, 3.374166563760598, 3.399632333061915, 3.424908757908742, 3.45, 3.474910070778811, 3.4996428389194234, 3.5242020373412193, 3.5485912697858004, 3.572814016989969, 3.59687364248454, 3.6207733980463352, 3.6445164288283847, 3.668105778191246, 3.6915443922564446, 3.7148351242013424, 3.737980738313134, 3.7609839138182983, 3.783847248502508, 3.8065732621348563, 3.8291643997091587, 3.8516230345141516, 3.8739514710434877, 3.8961519477556315, 3.918226639693013, 3.940177660969109, 3.9620070671315064, 3.9837168574084183, 4.005308976845607, 4.026785318340178, 4.048147724577254, 4.069397989875161, 4.09053786194432, 4.111569043564756, 4.1324931941867735, 4.153311931459037, 4.17402683268807], [0.0, 0.4183300132670378, 0.5916079783099616, 0.7245688373094721, 0.8366600265340756, 0.9354143466934854, 1.02469507659596, 1.1067971810589328, 1.1832159566199232, 1.2549900398011133, 1.3228756555322954, 1.387443692551161, 1.4491376746189442, 1.5083103128998359, 1.5652475842498528, 1.620185174601965, 1.6733200530681511, 1.7248188310660342, 1.7748239349298849, 1.8234582528810472, 1.8708286933869709, 1.9170289512680816, 1.9621416870348585, 2.006240264773888, 2.04939015319192, 2.091650066335189, 2.1330729007701543, 2.1737065119284162, 2.2135943621178655, 2.2527760652137623, 2.29128784747792, 2.3291629397704234, 2.3664319132398464, 2.4031229681395834, 2.4392621835300936, 2.4748737341529163, 2.5099800796022267, 2.5446021299998947, 2.5787593916455256, 2.6124700955226268, 2.6457513110645907, 2.678619047195775, 2.7110883423451924, 2.7431733448690405, 2.774887385102322, 2.806243040080456, 2.8372521918222215, 2.8679260799399975, 2.8982753492378883, 2.9283100928692645, 2.9580398915498085, 2.9874738492579316, 3.0166206257996717, 3.0454884665682127, 3.0740852297878796, 3.1024184114977142, 3.1304951684997055, 3.1583223394707516, 3.1859064644147987, 3.2132538026119257, 3.24037034920393, 3.2672618505409083, 3.2939338184001206, 3.3203915431767985, 3.3466401061363023, 3.3726843908080104, 3.398529093593286, 3.4241787336527865, 3.4496376621320683, 3.474910070778811, 3.5000000000000004, 3.5249113464029134, 3.5496478698597698, 3.5742132001323035, 3.5986108430893164, 3.62284418654736, 3.6469165057620945, 3.670830968595531, 3.6945906403822337, 3.718198488515642, 3.7416573867739418, 3.7649701194033405, 3.7881393849751626, 3.811167800031901, 3.834057902536163, 3.8568121551353785, 3.879432948254165, 3.9019226030253344, 3.924283374069717, 3.946517452134223, 3.968626966596886, 3.990613987846983, 4.012480529547776, 4.034228550788862, 4.05585995813465, 4.077376607575022, 4.09878030638384, 4.120072814890533, 4.141255848169731, 4.162331077653483, 4.183300132670378, 4.204164601915582], [0.0, 0.42130748865881795, 0.5958187643906492, 0.7297259759663213, 0.8426149773176359, 0.9420721840708387, 1.0319883720275147, 1.1146748404803977, 1.1916375287812984, 1.2639224659764536, 1.3322912594474228, 1.3973188612482121, 1.4594519519326425, 1.5190457530963313, 1.5763882770434445, 1.6317168872080718, 1.6852299546352718, 1.7370952766040209, 1.7874562931719478, 1.836436767220696, 1.8841443681416774, 1.9306734576307825, 1.9761072845369505, 2.0205197351176754, 2.0639767440550294, 2.1065374432940898, 2.1482551058940835, 2.189177927898964, 2.2293496809607953, 2.2688102609076854, 2.307596151842865, 2.34574082114798, 2.3832750575625967, 2.4202272620561898, 2.4566236993076496, 2.4924887161229035, 2.5278449319529073, 2.5627134057478997, 2.5971137826441106, 2.631064423384574, 2.6645825188948455, 2.6976841920432424, 2.73038458829521, 2.762697956708261, 2.7946377224964243, 2.8262165522125153, 2.85744641244591, 2.888338622807236, 2.918903903865285, 2.9491524206117257, 2.9790938219532466, 3.008737276666077, 3.0380915061926625, 3.0671648146130006, 3.095965116082544, 3.124499959993599, 3.152776554086889, 3.1808017857137845, 3.2085822414268894, 3.236124225056881, 3.2634337744161437, 3.2905166767545793, 3.3173784830796738, 3.344024521441193, 3.3704599092705436, 3.396689564855758, 3.4227182180249662, 3.448550420104076, 3.4741905532080417, 3.4996428389194234, 3.5249113464029134, 3.55, 3.5749125863438955, 3.5996527610312636, 3.6242240548840243, 3.648629879831606, 3.672873534441392, 3.6969582091227378, 3.720886991027812, 3.7446628686705563, 3.768288736283355, 3.7917673979293616, 3.8151015713870584, 3.8382938918222504, 3.861346915261565, 3.884263121880391, 3.9070449191172605, 3.929694644625712, 3.952214569073901, 3.9746068988014396, 3.9968737783422683, 4.019017292821717, 4.041039470235351, 4.062942283616641, 4.08472765310002, 4.106397447885433, 4.127953488110059, 4.149397546632524, 4.1707313507345445, 4.191956583744636, 4.2130748865881795, 4.2340878592679205], [0.0, 0.4242640687119285, 0.6, 0.7348469228349536, 0.848528137423857, 0.9486832980505139, 1.0392304845413265, 1.1224972160321824, 1.2, 1.2727922061357855, 1.3416407864998738, 1.407124727947029, 1.4696938456699071, 1.5297058540778357, 1.5874507866387544, 1.6431676725154982, 1.697056274847714, 1.7492855684535902, 1.8, 1.8493242008906932, 1.8973665961010278, 1.9442222095223582, 1.98997487421324, 2.0346989949375804, 2.078460969082653, 2.121320343559643, 2.1633307652783937, 2.2045407685048604, 2.244994432064365, 2.2847319317591728, 2.32379000772445, 2.3622023622035435, 2.4, 2.4372115213907883, 2.4738633753705965, 2.5099800796022267, 2.545584412271571, 2.5806975801127883, 2.615339366124404, 2.6495282598983545, 2.6832815729997477, 2.716615541441225, 2.749545416973504, 2.782085548648711, 2.814249455894058, 2.846049894151541, 2.877498913987632, 2.9086079144497976, 2.9393876913398143, 2.9698484809834995, 3.0, 3.029851481508624, 3.0594117081556713, 3.0886890422961004, 3.1176914536239795, 3.146426544510455, 3.1749015732775088, 3.2031234756093934, 3.2310988842807027, 3.2588341473600644, 3.2863353450309964, 3.3136083051561784, 3.340658617698013, 3.3674916480965473, 3.394112549695428, 3.420526275297414, 3.4467375879228173, 3.4727510708370675, 3.4985711369071804, 3.5242020373412193, 3.5496478698597698, 3.5749125863438955, 3.6, 3.6249137920783716, 3.6496575181789317, 3.6742346141747673, 3.6986484017813863, 3.722902093797257, 3.7469987990390394, 3.7709415269929605, 3.7947331922020555, 3.8183766184073566, 3.84187454245971, 3.8652296180175374, 3.8884444190447165, 3.9115214431215897, 3.9344631145812006, 3.957271787481876, 3.97994974842648, 4.0024992192379, 4.024922359499621, 4.047221268969612, 4.069397989875161, 4.091454509095757, 4.113392760240627, 4.135214625627066, 4.156921938165306, 4.178516483155236, 4.2, 4.221374183841087, 4.242640687119286, 4.263801121065569], [0.0, 0.42720018726587655, 0.6041522986797286, 0.7399324293474372, 0.8544003745317531, 0.95524865872714, 1.0464224768228174, 1.1302654555457314, 1.2083045973594573, 1.2816005617976296, 1.3509256086106296, 1.4168627315304756, 1.4798648586948744, 1.5402921800749363, 1.598436736314578, 1.6545392107774295, 1.7088007490635062, 1.7613914953808536, 1.8124568960391858, 1.8621224449536073, 1.91049731745428, 1.9576771950451894, 2.003746490951388, 2.048780124854788, 2.092844953645635, 2.136000936329383, 2.1783020910791966, 2.2197972880423116, 2.260530911091463, 2.3005434140654684, 2.339871791359518, 2.3785499784532593, 2.4166091947189146, 2.4540782383616055, 2.49098374141623, 2.5273503912200224, 2.563201123595259, 2.5985572920372566, 2.6334388164527387, 2.6678643143908203, 2.701851217221259, 2.735415873317986, 2.7685736399814256, 2.8013389655662877, 2.833725463060951, 2.8657459761814197, 2.897412638890084, 2.928736929121494, 2.9597297173897488, 2.990401310861136, 3.020761493398643, 3.0508195620193606, 3.0805843601498726, 3.110064308016798, 3.1392674304684527, 3.168201382488178, 3.196873472629156, 3.2252906845740275, 3.2534596969994882, 3.2813869019059605, 3.309078421554859, 3.3365401241405745, 3.363777638310832, 3.3907963666371947, 3.4176014981270124, 3.4441980198589044, 3.4705907278156554, 3.4967842369811724, 3.522782990761707, 3.5485912697858004, 3.5742132001323035, 3.5996527610312636, 3.6249137920783716, 3.65, 3.6749149650025914, 3.6996621467371855, 3.7242448899072147, 3.7486664295453123, 3.772929895982697, 3.797038319532738, 3.82099463490856, 3.844801685392889, 3.8684622267769404, 3.8919789310837745, 3.915354390090379, 3.938591118661596, 3.961691557908061, 3.9846580781793564, 4.007492981902776, 4.030198506277327, 4.052776825831889, 4.075230054855799, 4.097560249709576, 4.1197694110229035, 4.141859485786547, 4.163832369344376, 4.18568990729127, 4.207433897282286, 4.2290660907581, 4.250588194591426, 4.272001872658766, 4.293308747341612], [0.0, 0.4301162633521313, 0.6082762530298219, 0.744983221287567, 0.8602325267042626, 0.9617692030835673, 1.0535653752852738, 1.1379806676741042, 1.2165525060596438, 1.290348790056394, 1.3601470508735443, 1.4265342617687107, 1.489966442575134, 1.5508062419270823, 1.609347693943108, 1.6658331248957678, 1.7204650534085253, 1.7734147850968198, 1.8248287590894658, 1.8748333259252674, 1.9235384061671346, 1.9710403344427023, 2.0174241001832014, 2.062765134473627, 2.1071307505705477, 2.1505813167606567, 2.193171219946131, 2.234949663862701, 2.2759613353482084, 2.316246964380094, 2.355843797877949, 2.3947860029656094, 2.4331050121192876, 2.4708298201211676, 2.5079872407968904, 2.544602129999894, 2.580697580112788, 2.616295090390226, 2.6514147167125706, 2.6860752037126585, 2.7202941017470885, 2.7540878707840823, 2.787471972953271, 2.8204609552340902, 2.8530685235374214, 2.8853076092507015, 2.9171904291629644, 2.948728539557346, 2.979932885150268, 3.0108138434649194, 3.0413812651491097, 3.071644510681534, 3.1016124838541645, 3.1312936623702354, 3.1606961258558215, 3.1898275815473163, 3.218695387886216, 3.2473065762259035, 3.27566787083184, 3.303785707336358, 3.3316662497915357, 3.359315406448165, 3.3867388443752193, 3.4139420030223127, 3.4409301068170506, 3.46770817687994, 3.4942810419312296, 3.5206533484567886, 3.5468295701936396, 3.572814016989969, 3.5986108430893164, 3.6242240548840243, 3.6496575181789317, 3.6749149650025914, 3.6999999999999997, 3.724916106437835, 3.749666651850535, 3.774254893353124, 3.798683982644516, 3.8229569707230553, 3.847076812334269, 3.871046370169182, 3.8948684188300895, 3.9185456485793293, 3.9420806688854046, 3.9654760117796704, 3.988734135035826, 4.011857425183502, 4.034848200366403, 4.057708713054696, 4.080441152620633, 4.103047647785728, 4.125530268947254, 4.147891030391228, 4.170131892398609, 4.192254763250916, 4.214261501141095, 4.236153915995027, 4.257933771208753, 4.279602785306132, 4.301162633521313, 4.322614949310197], [0.0, 0.43301270189221935, 0.6123724356957945, 0.7500000000000001, 0.8660254037844387, 0.9682458365518543, 1.0606601717798214, 1.14564392373896, 1.224744871391589, 1.299038105676658, 1.3693063937629153, 1.4361406616345074, 1.5000000000000002, 1.5612494995995996, 1.620185174601965, 1.6770509831248421, 1.7320508075688774, 1.7853571071357126, 1.8371173070873836, 1.8874586088176877, 1.9364916731037085, 1.984313483298443, 2.03100960115899, 2.0766559657295187, 2.121320343559643, 2.165063509461097, 2.207940216581962, 2.25, 2.29128784747792, 2.331844763272204, 2.3717082451262845, 2.4109126902482387, 2.449489742783178, 2.4874685927665503, 2.5248762345905194, 2.5617376914898995, 2.598076211353316, 2.633913438213185, 2.669269563007828, 2.704163456597992, 2.7386127875258306, 2.7726341266023544, 2.806243040080456, 2.839454172900137, 2.8722813232690148, 2.9047375096555625, 2.936835031117683, 2.968585521759479, 3.0000000000000004, 3.031088913245535, 3.061862178478973, 3.0923292192132457, 3.122498999199199, 3.1523800532296233, 3.181980515339464, 3.2113081446662823, 3.24037034920393, 3.2691742076555053, 3.29772648956823, 3.3260336739125176, 3.3541019662496843, 3.3819373146171707, 3.409545424246464, 3.43693177121688, 3.464101615137755, 3.491060010942235, 3.517811819867572, 3.5443617196894563, 3.570714214271425, 3.59687364248454, 3.62284418654736, 3.648629879831606, 3.6742346141747673, 3.6996621467371855, 3.724916106437835, 3.75, 3.7749172176353754, 3.799671038392666, 3.8242646351945893, 3.8487010795851635, 3.872983346207417, 3.897114317029974, 3.921096785339531, 3.944933459514875, 3.968626966596886, 3.9921798556678283, 4.0155946010522525, 4.0388736053508785, 4.06201920231798, 4.085033659592048, 4.107919181288746, 4.130677910464577, 4.153311931459037, 4.175823272122517, 4.198213905936667, 4.2204857540335325, 4.242640687119286, 4.264680527307996, 4.286607049870562, 4.3084219849035215, 4.330127018922194, 4.351723796382303], [0.0, 0.43588989435406744, 0.6164414002968976, 0.7549834435270751, 0.8717797887081349, 0.9746794344808966, 1.0677078252031313, 1.1532562594670797, 1.2328828005937953, 1.307669683062202, 1.3784048752090223, 1.4456832294800963, 1.5099668870541503, 1.5716233645501714, 1.6309506430300091, 1.6881943016134133, 1.7435595774162698, 1.797220075561143, 1.8493242008906932, 1.9000000000000004, 1.9493588689617931, 1.9974984355438181, 2.0445048300260877, 2.0904544960366875, 2.1354156504062627, 2.179449471770337, 2.2226110770892875, 2.2649503305812253, 2.3065125189341593, 2.3473389188611007, 2.3874672772626644, 2.4269322199023198, 2.4657656011875906, 2.503996805109783, 2.5416530054277673, 2.5787593916455256, 2.615339366124404, 2.651414716712571, 2.687005768508881, 2.7221315177632404, 2.7568097504180447, 2.791057147390573, 2.8248893783651075, 2.8583211855912904, 2.8913664589601926, 2.924038303442689, 2.956349099818897, 2.9883105594967874, 3.0199337741083006, 3.051229260478472, 3.082207001484489, 3.1128764832546767, 3.1432467291003428, 3.1733263305244868, 3.203123475609394, 3.232645975048923, 3.2619012860600183, 3.290896534380867, 3.319638534539567, 3.3481338085566414, 3.3763886032268267, 3.4044089061098406, 3.432200460346103, 3.4597687784012394, 3.4871191548325395, 3.5142566781611158, 3.541186241925155, 3.567912554982255, 3.594440151122286, 3.6207733980463352, 3.6469165057620945, 3.672873534441392, 3.6986484017813863, 3.7242448899072147, 3.749666651850535, 3.7749172176353754, 3.8000000000000007, 3.824918299781056, 3.8496753109840323, 3.874274125562104, 3.8987177379235862, 3.9230090491866068, 3.947150871198111, 3.9711459303329564, 3.9949968710876362, 4.018706259482024, 4.042276586281548, 4.065710270051225, 4.0890096600521755, 4.112177038990418, 4.135214625627067, 4.158124577258358, 4.180908992073375, 4.203569911396741, 4.226109321823088, 4.2485291572496005, 4.270831300812525, 4.293017586733137, 4.315089802078284, 4.337049688440289, 4.358898943540674, 4.380639222761903], [0.0, 0.4387482193696061, 0.6204836822995429, 0.7599342076785333, 0.8774964387392122, 0.9810708435174292, 1.074709263010234, 1.16081867662439, 1.2409673645990857, 1.3162446581088183, 1.3874436925511608, 1.455163221085525, 1.5198684153570665, 1.5819292019556377, 1.6416455159382004, 1.6992645467966427, 1.7549928774784245, 1.8090052515125543, 1.8614510468986285, 1.912459149890528, 1.9621416870348585, 2.01059692628831, 2.057911562725668, 2.1041625412500817, 2.149418526020468, 2.1937410968480306, 2.2371857321197095, 2.2798026230355997, 2.32163735324878, 2.362731470142132, 2.403122968139583, 2.4428467000612217, 2.4819347291981715, 2.520416632225712, 2.5583197610932062, 2.595669470483482, 2.6324893162176366, 2.6688012290165037, 2.7046256672597044, 2.7399817517640517, 2.7748873851023217, 2.80935935757603, 2.8434134416225865, 2.8770644761631603, 2.91032644217105, 2.9432125305522874, 2.9757352032733024, 3.007906248539007, 3.039736830714133, 3.071237535587243, 3.1024184114977142, 3.1332890067786603, 3.1638584039112754, 3.194135250736888, 3.224127789030702, 3.253843880704789, 3.283291031876401, 3.3124764150103774, 3.3414068893207247, 3.370089019595773, 3.3985290935932855, 3.426733138136088, 3.45470693402494, 3.48245602987317, 3.509985754956849, 3.5373012311647987, 3.564407384124323, 3.591308953571107, 3.6180105030251086, 3.6445164288283847, 3.670830968595531, 3.6969582091227378, 3.722902093797257, 3.7486664295453123, 3.774254893353124, 3.799671038392666, 3.824918299781056, 3.85, 3.874919353999513, 3.8996794740080887, 3.924283374069717, 3.9487339743264553, 3.9730341050637867, 3.9971865105346285, 4.02119385257662, 4.045058714036176, 4.068783602011786, 4.092370950928081, 4.115823125451336, 4.1391424232562954, 4.162331077653483, 4.185391260085489, 4.2083250825001635, 4.231134599608006, 4.253821811030641, 4.27638866334668, 4.298837052040936, 4.321168823362495, 4.3433857760968, 4.365489663256575, 4.387482193696061, 4.409365033652805], [0.0, 0.4415880433163924, 0.6244997998398398, 0.7648529270389179, 0.8831760866327848, 0.9874208829065751, 1.0816653826391969, 1.1683321445547925, 1.2489995996796797, 1.3247641299491772, 1.3964240043768943, 1.4645818515876812, 1.5297058540778359, 1.5921683328090661, 1.6522711641858308, 1.710263137648707, 1.7663521732655696, 1.8207141456033127, 1.8734993995195197, 1.9248376554920161, 1.9748417658131503, 2.0236106344848066, 2.0712315177207983, 2.1177818584547374, 2.1633307652783937, 2.207940216581962, 2.251666049839541, 2.294558781116754, 2.336664289109585, 2.3780243901188234, 2.418677324489565, 2.4586581706288495, 2.4979991993593593, 2.536730178793165, 2.574878637916747, 2.6124700955226268, 2.6495282598983545, 2.686075203712659, 2.7221315177632404, 2.757716446627536, 2.7928480087537886, 2.827543103119739, 2.8618176042508376, 2.895686447114052, 2.9291637031753623, 2.962262648719725, 2.994995826374388, 3.027375100644121, 3.0594117081556718, 3.0911163032147466, 3.1224989991991996, 3.1535694062442965, 3.1843366656181322, 3.2148094811357026, 3.244996147917591, 3.2749045787625635, 3.3045423283716615, 3.333916615633931, 3.363034344160048, 3.391902121229326, 3.420526275297414, 3.4489128721961073, 3.477067730142742, 3.504996433664377, 3.532704346531139, 3.56019662378358, 3.58747822293042, 3.614553914385564, 3.6414282912066254, 3.668105778191246, 3.6945906403822337, 3.720886991027812, 3.7469987990390394, 3.772929895982697, 3.798683982644516, 3.8242646351945893, 3.8496753109840323, 3.874919353999513, 3.900000000000001, 3.9249203813580733, 3.9496835316263006, 3.9742923898475317, 3.998749804626442, 4.023058537978288, 4.047221268969613, 4.071240597164457, 4.095119045888655, 4.118859065323795, 4.1424630354415966, 4.16593326878864, 4.189272013130683, 4.212481453965109, 4.235563716909475, 4.258520869973518, 4.28135492572153, 4.3040678433314685, 4.3266615305567875, 4.349137845596528, 4.371498598878879, 4.3937455547630435, 4.415880433163924, 4.437904911103888], [0.0, 0.44440972086577946, 0.6284902544988268, 0.7697402159170328, 0.8888194417315589, 0.9937303457175897, 1.088577052853862, 1.1757976016304847, 1.2569805089976536, 1.3332291625973383, 1.4053469322555197, 1.4739402972983677, 1.5394804318340656, 1.6023420358962066, 1.6628289148315891, 1.7211914478058505, 1.7776388834631178, 1.8323482201808694, 1.8854707634964802, 1.937137062781052, 1.9874606914351793, 2.03654118544163, 2.084466358567583, 2.131314148594712, 2.177154105707724, 2.2220486043288976, 2.266053838724932, 2.309220647751098, 2.3515952032609695, 2.393219588754864, 2.434132288927617, 2.4743686063317245, 2.513961017995307, 2.552939482243949, 2.591331703969988, 2.6291633650269812, 2.6664583251946765, 2.7032387981826544, 2.739525506360545, 2.775337817275584, 2.8106938645110393, 2.8456106550264395, 2.880104164782934, 2.9141894241795607, 2.9478805945967355, 2.9811910371527683, 3.0141333746203074, 3.046719547316425, 3.078960863668131, 3.1108680460604563, 3.142451272494134, 3.1737202145116705, 3.204684071792413, 3.235351603767356, 3.2657311585615862, 3.2958306995353994, 3.3256578296631782, 3.3552198139615235, 3.38452360015409, 3.413575837739657, 3.442382895611701, 3.470950878361721, 3.4992856413845383, 3.5273928048914542, 3.5552777669262356, 3.582945715469326, 3.6104016397071392, 3.6376503405357696, 3.664696440361739, 3.6915443922564446, 3.718198488515642, 3.7446628686705563, 3.7709415269929605, 3.797038319532738, 3.8229569707230553, 3.8487010795851635, 3.874274125562104, 3.8996794740080887, 3.9249203813580733, 3.95, 3.9749213828703587, 3.9996874877920154, 4.0243011815717775, 4.048765243873742, 4.07308237088326, 4.0972551787751765, 4.121286206998976, 4.145177921392519, 4.168932717135166, 4.1925529215503055, 4.216040796766559, 4.239398542246294, 4.262628297189424, 4.285732142819941, 4.308712104562105, 4.331570154112709, 4.354308211415448, 4.376928146542961, 4.399431781491788, 4.421820891895103, 4.444097208657795, 4.466262419518137], [0.0, 0.447213595499958, 0.6324555320336759, 0.7745966692414835, 0.894427190999916, 1.0000000000000002, 1.0954451150103324, 1.1832159566199234, 1.2649110640673518, 1.3416407864998738, 1.4142135623730951, 1.4832396974191329, 1.549193338482967, 1.61245154965971, 1.6733200530681511, 1.7320508075688772, 1.788854381999832, 1.8439088914585775, 1.8973665961010278, 1.9493588689617931, 2.0000000000000004, 2.04939015319192, 2.0976176963403033, 2.144761058952722, 2.1908902300206647, 2.23606797749979, 2.280350850198276, 2.3237900077244507, 2.366431913239847, 2.4083189157584592, 2.4494897427831783, 2.489979919597747, 2.5298221281347035, 2.5690465157330262, 2.60768096208106, 2.6457513110645907, 2.6832815729997477, 2.720294101747089, 2.7568097504180447, 2.7928480087537886, 2.8284271247461903, 2.863564212655271, 2.8982753492378883, 2.932575659723036, 2.9664793948382657, 3.0, 3.0331501776206204, 3.0659419433511785, 3.098386676965934, 3.130495168499706, 3.1622776601683795, 3.193743884534263, 3.22490309931942, 3.255764119219942, 3.286335345030997, 3.3166247903554003, 3.3466401061363023, 3.3763886032268267, 3.405877273185281, 3.4351128074635335, 3.4641016151377544, 3.492849839314596, 3.521363372331802, 3.5496478698597698, 3.577708763999664, 3.605551275463989, 3.6331804249169903, 3.6606010435446255, 3.687817782917155, 3.7148351242013424, 3.7416573867739418, 3.768288736283355, 3.7947331922020555, 3.82099463490856, 3.847076812334269, 3.872983346207417, 3.8987177379235862, 3.924283374069717, 3.9496835316263006, 3.9749213828703587, 4.000000000000001, 4.024922359499622, 4.049691346263318, 4.0743097574926725, 4.09878030638384, 4.123105625617661, 4.147288270665545, 4.171330722922843, 4.1952353926806065, 4.219004621945797, 4.242640687119286, 4.266145801540309, 4.289522117905444, 4.312771730569565, 4.335896677735761, 4.358898943540674, 4.3817804600413295, 4.404543109109049, 4.427188724235731, 4.449719092257398, 4.47213595499958, 4.494441010848847], [0.0, 0.45, 0.6363961030678927, 0.7794228634059949, 0.9, 1.0062305898749055, 1.1022703842524302, 1.1905880899790657, 1.2727922061357855, 1.35, 1.4230249470757708, 1.4924811556599302, 1.5588457268119897, 1.6224980739587953, 1.6837458240482737, 1.7428425057933374, 1.8, 1.8553975315279474, 1.9091883092036783, 1.9615045245933034, 2.012461179749811, 2.062159062730128, 2.1106870919205436, 2.158124185490724, 2.2045407685048604, 2.2500000000000004, 2.2945587811167534, 2.3382685902179845, 2.3811761799581315, 2.423324163210527, 2.4647515087732477, 2.50549396327351, 2.545584412271571, 2.585053190942113, 2.6239283526803856, 2.662235902394827, 2.7, 2.737243138634199, 2.7739863013360395, 2.8102490992792797, 2.8460498941515415, 2.8814059068447824, 2.9163333142835377, 2.9508473359359, 2.9849623113198605, 3.018691769624716, 3.052048492406371, 3.08504457018047, 3.1176914536239795, 3.1500000000000004, 3.1819805153394642, 3.213642792844283, 3.2449961479175906, 3.2760494501762336, 3.3068111527572905, 3.3372893191930486, 3.3674916480965473, 3.3974254958718375, 3.427097897638759, 3.4565155865408737, 3.485685011586675, 3.5146123541579946, 3.543303543305315, 3.5717642699371974, 3.6, 3.628015986734347, 3.6558172820861823, 3.6834087473426025, 3.710795063055895, 3.737980738313134, 3.7649701194033405, 3.7917673979293616, 3.8183766184073566, 3.844801685392889, 3.871046370169182, 3.897114317029974, 3.9230090491866068, 3.9487339743264553, 3.9742923898475317, 3.9996874877920154, 4.024922359499622, 4.050000000000001, 4.074923312161838, 4.099695110614935, 4.124318125460256, 4.1487950057818, 4.173128322973067, 4.197320573889967, 4.221374183841087, 4.2452915094254715, 4.2690748412273125, 4.292726406376255, 4.316248370981448, 4.33964284244683, 4.362911871674696, 4.386057455164034, 4.409081537009721, 4.431986010808248, 4.4547727214752495, 4.47744346697979, 4.500000000000001, 4.522444029504402], [0.0, 0.45276925690687087, 0.6403124237432849, 0.7842193570679062, 0.9055385138137417, 1.0124228365658294, 1.1090536506409419, 1.197914855071094, 1.2806248474865698, 1.3583077707206126, 1.4317821063276355, 1.501665741768121, 1.5684387141358125, 1.632482771731451, 1.6941074346097418, 1.7535677916750183, 1.8110770276274835, 1.866815470259447, 1.920937271229855, 1.9735754355990556, 2.024845673131659, 2.0748493921246434, 2.1236760581595306, 2.171405075060847, 2.2181073012818837, 2.2638462845343543, 2.3086792761230397, 2.352658071203719, 2.395829710142188, 2.438237068047322, 2.479919353527449, 2.5209125331911064, 2.5612496949731396, 2.600961360727991, 2.6400757564888173, 2.678619047195775, 2.716615541441225, 2.754087870784083, 2.791057147390573, 2.827543103119739, 2.863564212655271, 2.8991378028648453, 2.9342801502242426, 2.9690065678607045, 3.003331483536242, 3.0372685096974883, 3.0708305065568178, 3.1040296390337514, 3.136877428271625, 3.169384798348096, 3.2015621187164247, 3.233419242844949, 3.264965543462902, 3.2962099447699025, 3.3271609519228256, 3.3578266780761634, 3.3882148692194836, 3.4183329270274423, 3.4481879299133342, 3.4777866524558405, 3.5071355833500366, 3.536240942017385, 3.5651086939951777, 3.5937445652132824, 3.622154055254967, 3.650342449688796, 3.6783148315499044, 3.7060760920412847, 3.733630940518894, 3.7609839138182983, 3.7881393849751626, 3.8151015713870584, 3.84187454245971, 3.8684622267769404, 3.8948684188300895, 3.921096785339531, 3.947150871198111, 3.9730341050637867, 3.998749804626442, 4.0243011815717775, 4.049691346263318, 4.074923312161838, 4.1000000000000005, 4.124924241728568, 4.149698784249287, 4.174326292948361, 4.198809355043404, 4.223150482755736, 4.247352116319061, 4.271416626834709, 4.295346318982906, 4.3191434335988435, 4.342810150121694, 4.3663485889241604, 4.389760813529595, 4.413048832723246, 4.436214602563767, 4.459260028300661, 4.4821869662029945, 4.504997225304363, 4.527692569068709, 4.5502747169813835], [0.0, 0.45552167895721496, 0.6442049363362562, 0.7889866919029751, 0.9110433579144299, 1.0185774393731681, 1.1157956802210698, 1.205197079319395, 1.2884098726725124, 1.3665650368716447, 1.4404860290887933, 1.5107944929738129, 1.5779733838059502, 1.6424067705656842, 1.704406054905931, 1.7642278764377348, 1.8220867158288598, 1.8781639970992947, 1.9326148090087687, 1.9855729651664782, 2.0371548787463363, 2.0874625745148103, 2.1365860619221495, 2.184605227495348, 2.2315913604421396, 2.277608394786075, 2.322713929867387, 2.366960075708925, 2.41039415863879, 2.453059314407216, 2.4949949899749297, 2.5362373705944794, 2.576819745345025, 2.616772821625905, 2.656124997058685, 2.694902595642373, 2.7331300737432893, 2.770830200499482, 2.8080242164197946, 2.844731973314885, 2.8809720581775866, 2.916761903207048, 2.9521178838251023, 2.987055406248769, 3.0215889859476257, 3.055732318119504, 3.0894983411550814, 3.122899293925438, 3.1559467676119004, 3.1886517527005047, 3.2210246816812815, 3.2530754679226246, 3.2848135411313684, 3.316247879758086, 3.3473870406632096, 3.378239186321774, 3.408812109811862, 3.4391132578035286, 3.469149751740331, 3.4989284073841804, 3.5284557528754696, 3.557738045444043, 3.5867812868921907, 3.615591237958185, 3.6441734316577197, 3.6725331856907704, 3.7006756139926664, 3.7286056375004315, 3.7563279941985894, 3.783847248502508, 3.811167800031901, 3.8382938918222504, 3.8652296180175374, 3.8919789310837745, 3.9185456485793293, 3.944933459514875, 3.9711459303329564, 3.9971865105346285, 4.023058537978288, 4.048765243873742, 4.0743097574926725, 4.099695110614935, 4.124924241728568, 4.1499999999999995, 4.174925149029621, 4.199702370406741, 4.224334267076885, 4.248823366533375, 4.273172123844299, 4.297382924525111, 4.32145808726638, 4.345399866525519, 4.369210454990696, 4.392891985924535, 4.4164465353947175, 4.439876124398067, 4.463182720884279, 4.486368241685027, 4.509434554353794, 4.532383478921439, 4.55521678957215, 4.577936216244171], [0.0, 0.45825756949558405, 0.6480740698407861, 0.7937253933193773, 0.9165151389911681, 1.02469507659596, 1.1224972160321824, 1.2124355652982142, 1.2961481396815722, 1.374772708486752, 1.449137674618944, 1.5198684153570665, 1.5874507866387546, 1.6522711641858308, 1.7146428199482247, 1.7748239349298847, 1.8330302779823362, 1.8894443627691184, 1.9442222095223582, 1.9974984355438181, 2.04939015319192, 2.1, 2.149418526020468, 2.1977260975835913, 2.244994432064365, 2.2912878474779204, 2.336664289109585, 2.381176179958132, 2.4248711305964283, 2.4677925358506134, 2.5099800796022267, 2.551470164434615, 2.5922962793631443, 2.632489316217637, 2.672077843177478, 2.711088342345192, 2.749545416973504, 2.787471972953271, 2.824889378365107, 2.861817604250837, 2.898275349237888, 2.934280150224242, 2.9698484809835, 3.004995840263344, 3.039736830714133, 3.0740852297878796, 3.108054053584011, 3.1416556144810017, 3.174901573277509, 3.2078029864690882, 3.2403703492039306, 3.272613634390715, 3.3045423283716615, 3.336165463522456, 3.3674916480965478, 3.398529093593286, 3.4292856398964493, 3.459768778401239, 3.48998567332303, 3.5199431813596083, 3.5496478698597693, 3.5791060336346563, 3.608323710533743, 3.6373066958946425, 3.6660605559646724, 3.6945906403822333, 3.722902093797257, 3.7509998667022106, 3.778888725538237, 3.8065732621348563, 3.834057902536163, 3.861346915261565, 3.8884444190447165, 3.915354390090379, 3.9420806688854046, 3.968626966596886, 3.9949968710876362, 4.02119385257662, 4.047221268969613, 4.07308237088326, 4.09878030638384, 4.124318125460256, 4.149698784249287, 4.174925149029621, 4.2, 4.224926034855522, 4.249705872175156, 4.274342054632503, 4.298837052040936, 4.323193264243457, 4.347413023856832, 4.371498598878879, 4.3954521951671826, 4.419275958796871, 4.442971978304612, 4.466542286825459, 4.48998886412873, 4.513313638558704, 4.536518488885503, 4.559605246071199, 4.582575694955841, 4.605431575867782], [0.0, 0.4609772228646444, 0.6519202405202649, 0.7984359711335658, 0.9219544457292888, 1.0307764064044151, 1.1291589790636216, 1.2196310917650468, 1.3038404810405297, 1.382931668593933, 1.4577379737113252, 1.5288884851420657, 1.5968719422671316, 1.6620770138594663, 1.724818831066034, 1.7853571071357124, 1.8439088914585775, 1.9006577808748213, 1.9557607215607948, 2.009353129741012, 2.0615528128088303, 2.112463017427761, 2.1621748310439655, 2.2107690969434146, 2.2583179581272432, 2.304886114323222, 2.350531854708632, 2.395307913400697, 2.4392621835300936, 2.4824383174612823, 2.5248762345905194, 2.56661255354212, 2.6076809620810595, 2.6481125353730723, 2.6879360111431225, 2.727178028658929, 2.765863337187866, 2.8040149785619906, 2.841654447676565, 2.8788018340969566, 2.9154759474226504, 2.9516944286290885, 2.9874738492579316, 3.0228298000383678, 3.0577769702841313, 3.092329219213245, 3.1264996401726965, 3.1603006186120965, 3.193743884534263, 3.2268405600525107, 3.2596012026013246, 3.2920358442763047, 3.3241540277189325, 3.3559648389099674, 3.387476937190865, 3.418698582794336, 3.449637662132068, 3.480301711058971, 3.510697936308392, 3.5408332352710428, 3.5707142142714248, 3.6003472054789385, 3.6297382825763074, 3.6588932752951404, 3.687817782917155, 3.7165171868296265, 3.744996662214801, 3.773261188945181, 3.8013155617496426, 3.8291643997091587, 3.8568121551353785, 3.884263121880391, 3.9115214431215897, 3.938591118661596, 3.9654760117796704, 3.9921798556678283, 4.018706259482024, 4.045058714036176, 4.071240597164457, 4.0972551787751765, 4.123105625617661, 4.1487950057818, 4.174326292948361, 4.199702370406741, 4.224926034855522, 4.25, 4.274926899959811, 4.299709292498739, 4.324349662087931, 4.348850422812907, 4.373213921133976, 4.397442438509002, 4.421538193886829, 4.445503346079047, 4.469339996017309, 4.493050188902857, 4.5166359162544865, 4.5400991178607555, 4.563441683641854, 4.586665455426197, 4.609772228646444, 4.632763753959401], [0.0, 0.46368092477478523, 0.6557438524302001, 0.8031189202104506, 0.9273618495495705, 1.0368220676663862, 1.1357816691600549, 1.2267844146385298, 1.3114877048604001, 1.3910427743243556, 1.466287829861518, 1.53785564992297, 1.6062378404209012, 1.671825349730049, 1.7349351572897473, 1.795828499606797, 1.854723699099141, 1.9118054294305162, 1.9672315572906003, 2.021138293140774, 2.0736441353327724, 2.124852936087578, 2.1748563170931545, 2.2237355957937086, 2.2715633383201097, 2.318404623873926, 2.3643180835073783, 2.409356760631352, 2.4535688292770597, 2.4969981978367546, 2.539685019840059, 2.5816661286851175, 2.6229754097208002, 2.663644120373441, 2.703701166919155, 2.7431733448690405, 2.7820855486487113, 2.820460955234091, 2.8583211855912904, 2.895686447114052, 2.932575659723036, 2.969006567860705, 3.0049958402633443, 3.040559159102154, 3.07571129984594, 3.110466202999158, 3.144837038703278, 3.178836265050467, 3.2124756808418025, 3.2457664734234966, 3.2787192621510006, 3.31134413795969, 3.343650699460098, 3.3756480859236504, 3.4073450074801643, 3.43874977280988, 3.4698703145794947, 3.500714212842859, 3.5312887166019156, 3.5616007637016254, 3.591656999213594, 3.621463792446364, 3.651027252705737, 3.6803532439155893, 3.709447398198282, 3.7383151285037486, 3.7669616403674726, 3.795391942869669, 3.8236108588610325, 3.8516230345141516, 3.879432948254165, 3.9070449191172605, 3.9344631145812006, 3.961691557908061, 3.988734135035826, 4.0155946010522525, 4.042276586281548, 4.068783602011786, 4.095119045888655, 4.121286206998976, 4.147288270665545, 4.173128322973067, 4.198809355043404, 4.224334267076885, 4.249705872175156, 4.274926899959811, 4.300000000000001, 4.324927745061182, 4.349712634186309, 4.374357095619881, 4.398863489584555, 4.423234110919295, 4.447471191587417, 4.4715769030622745, 4.495553358597805, 4.519402615390667, 4.543126676640219, 4.566727493512176, 4.590206967011401, 4.61356694976891, 4.636809247747852, 4.659935621872903], [0.0, 0.4663689526544408, 0.6595452979136459, 0.8077747210701758, 0.9327379053088816, 1.0428326807307107, 1.1423659658795864, 1.2338962679253067, 1.3190905958272918, 1.3991068579633223, 1.4747881203752626, 1.546770829825802, 1.6155494421403516, 1.681517172080024, 1.7449928366615148, 1.8062391868188443, 1.8654758106177631, 1.922888452302941, 1.978635893740938, 2.0328551350256125, 2.0856653614614213, 2.1371710273162514, 2.187464285422736, 2.2366269246345043, 2.2847319317591728, 2.331844763272204, 2.3780243901188234, 2.423324163210527, 2.4677925358506134, 2.511473670974872, 2.55440795488896, 2.596632434519757, 2.6381811916545836, 2.679085664923763, 2.7193749281774298, 2.759075932264279, 2.7982137159266447, 2.836811590500857, 2.8748913022930105, 2.9124731758421403, 2.9495762407505253, 2.9862183443278227, 3.022416251941483, 3.0581857366746052, 3.093541659651604, 3.1284980421921316, 3.163068130786942, 3.1972644557496337, 3.231098884280703, 3.2645826685810855, 3.29772648956823, 3.330540496676178, 3.363034344160048, 3.3952172242729923, 3.427097897638759, 3.4586847211042526, 3.4899856733230297, 3.521008378291651, 3.5517601270356085, 3.582247897619594, 3.6124783736376886, 3.642457961322272, 3.672192805395708, 3.70168880377592, 3.7309516212355263, 3.759986702104144, 3.788799282094527, 3.817394399325278, 3.845776904605882, 3.8739514710434877, 3.9019226030253344, 3.929694644625712, 3.957271787481876, 3.9846580781793564, 4.011857425183502, 4.0388736053508785, 4.065710270051225, 4.092370950928081, 4.118859065323795, 4.145177921392519, 4.171330722922843, 4.197320573889967, 4.223150482755736, 4.248823366533375, 4.274342054632503, 4.299709292498739, 4.324927745061182, 4.3500000000000005, 4.374928570845472, 4.399715899918994, 4.424364361125788, 4.448876262608346, 4.473253849269009, 4.497499305169486, 4.521614755814564, 4.545602270326782, 4.5694638635183455, 4.5932014978661675, 4.616817085395522, 4.640312489477407, 4.663689526544408, 4.686949967729547], [0.0, 0.469041575982343, 0.6633249580710799, 0.8124038404635961, 0.938083151964686, 1.0488088481701516, 1.148912529307606, 1.2409673645990857, 1.3266499161421599, 1.407124727947029, 1.4832396974191326, 1.5556349186104048, 1.6248076809271923, 1.6911534525287764, 1.7549928774784245, 1.816590212458495, 1.876166303929372, 1.9339079605813716, 1.98997487421324, 2.0445048300260877, 2.0976176963403033, 2.149418526020468, 2.2, 2.249444375840399, 2.297825058615212, 2.345207879911715, 2.3916521486202797, 2.4372115213907883, 2.4819347291981715, 2.5258661880630178, 2.569046515733026, 2.6115129714401193, 2.6532998322843198, 2.6944387170614963, 2.734958866235469, 2.7748873851023217, 2.814249455894058, 2.8530685235374214, 2.891366458960192, 2.9291637031753623, 2.9664793948382653, 3.0033314835362415, 3.039736830714133, 3.0757112998459397, 3.1112698372208096, 3.1464265445104544, 3.1811947441173736, 3.2155870381627056, 3.2496153618543846, 3.283291031876401, 3.3166247903554003, 3.3496268448888458, 3.3823069050575527, 3.414674215792775, 3.4467375879228173, 3.4785054261852175, 3.509985754956849, 3.5411862419251547, 3.5721142198983507, 3.602776706930364, 3.63318042491699, 3.6633318168028404, 3.6932370625238775, 3.722902093797257, 3.752332607858744, 3.7815340802378072, 3.81051177665153, 3.8392707640904935, 3.867815921162743, 3.8961519477556315, 3.924283374069717, 3.952214569073901, 3.97994974842648, 4.007492981902776, 4.034848200366403, 4.06201920231798, 4.0890096600521755, 4.115823125451336, 4.1424630354415966, 4.168932717135166, 4.1952353926806065, 4.221374183841087, 4.247352116319061, 4.273172123844299, 4.298837052040936, 4.324349662087931, 4.349712634186309, 4.374928570845472, 4.4, 4.424929377967517, 4.449719092257398, 4.474371464239419, 4.498888751680798, 4.523273151159457, 4.54752680036083, 4.571651780264984, 4.595650117230424, 4.61952378498044, 4.64327470649756, 4.666904755831214, 4.69041575982343, 4.713809499757071], [0.0, 0.4716990566028302, 0.6670832032063166, 0.8170067319184097, 0.9433981132056604, 1.0547511554864493, 1.1554220008291343, 1.2479983974348685, 1.3341664064126333, 1.4150971698084904, 1.4916433890176297, 1.5644487847162016, 1.6340134638368193, 1.7007351351694948, 1.764936259472279, 1.8268825906445108, 1.8867962264113207, 1.9448650338776723, 2.00124960961895, 2.056088519495209, 2.1095023109728985, 2.1615966321217286, 2.2124646889837587, 2.262189205172724, 2.3108440016582685, 2.358495283014151, 2.405202694161139, 2.4510201957552287, 2.495996794869737, 2.5401771591761078, 2.5836021365527624, 2.626309197333779, 2.6683328128252666, 2.709704780967846, 2.750454507895013, 2.790609252475165, 2.830194339616981, 2.8692333470807148, 2.9077482697097423, 2.9457596643310873, 2.9832867780352594, 3.0203476621077914, 3.0569592735265547, 3.0931375656443083, 3.1288975694324033, 3.1642534664593476, 3.199218654609278, 3.2338058074040252, 3.2680269276736387, 3.3018933962198114, 3.3354160160315836, 3.368605052540295, 3.4014702703389896, 3.4340209667385553, 3.466266002487403, 3.498213829942361, 3.529872518944558, 3.561249780624774, 3.5923529893372117, 3.623189202898463, 3.6537651812890215, 3.684087403957729, 3.7141620858546274, 3.7439951923046055, 3.7735924528226414, 3.8029593739612833, 3.832101251271944, 3.8610231804535955, 3.8897300677553446, 3.918226639693013, 3.946517452134223, 3.9746068988014396, 4.0024992192379, 4.030198506277327, 4.057708713054696, 4.085033659592048, 4.112177038990418, 4.1391424232562954, 4.16593326878864, 4.1925529215503055, 4.219004621945797, 4.2452915094254715, 4.271416626834709, 4.297382924525111, 4.323193264243457, 4.348850422812907, 4.374357095619881, 4.399715899918994, 4.424929377967517, 4.449999999999999, 4.474930167052889, 4.499722213648305, 4.524378410345448, 4.548900966167542, 4.57329203091165, 4.5975536973481885, 4.621688003316537, 4.645696933722647, 4.669582422444217, 4.693346354148605, 4.716990566028302, 4.740516849458507], [0.0, 0.4743416490252569, 0.6708203932499369, 0.8215838362577492, 0.9486832980505138, 1.0606601717798214, 1.161895003862225, 1.2549900398011133, 1.3416407864998738, 1.4230249470757705, 1.5, 1.5732132722552274, 1.6431676725154984, 1.710263137648707, 1.7748239349298847, 1.8371173070873834, 1.8973665961010275, 1.9557607215607946, 2.0124611797498106, 2.0676073128135335, 2.121320343559643, 2.173706511928416, 2.224859546128699, 2.2748626332154656, 2.32379000772445, 2.3717082451262845, 2.418677324489565, 2.4647515087732477, 2.5099800796022267, 2.55440795488896, 2.598076211353316, 2.6410225292488514, 2.6832815729997477, 2.724885318687743, 2.7658633371878665, 2.806243040080456, 2.846049894151541, 2.885307609250702, 2.924038303442689, 2.962262648719725, 3.0, 3.0372685096974883, 3.0740852297878796, 3.1104662029991577, 3.146426544510455, 3.181980515339464, 3.2171415884290826, 3.2519225083018197, 3.286335345030997, 3.3203915431767985, 3.3541019662496847, 3.387476937190865, 3.420526275297414, 3.453259329966402, 3.4856850115866753, 3.517811819867572, 3.5496478698597693, 3.5812009158939966, 3.612478373637689, 3.6434873404473356, 3.674234614174767, 3.704726710568541, 3.7349698793966195, 3.76497011940334, 3.794733192202055, 3.8242646351945884, 3.8535697735995385, 3.882653731663435, 3.9115214431215892, 3.940177660969109, 3.968626966596886, 3.9968737783422683, 4.024922359499621, 4.052776825831889, 4.080441152620633, 4.107919181288746, 4.135214625627067, 4.162331077653483, 4.189272013130683, 4.216040796766559, 4.242640687119286, 4.2690748412273125, 4.295346318982906, 4.32145808726638, 4.347413023856832, 4.373213921133976, 4.398863489584555, 4.424364361125788, 4.449719092257398, 4.474930167052889, 4.5, 4.524930938699507, 4.549725266430931, 4.574385204593073, 4.598912915026768, 4.623310502226732, 4.6475800154489, 4.671723450719232, 4.695742752749558, 4.719639816765683, 4.743416490252569, 4.767074574621212], [0.0, 0.47696960070847283, 0.674536878161602, 0.8261355820929154, 0.9539392014169457, 1.0665364503850772, 1.1683321445547923, 1.2619429464123963, 1.349073756323204, 1.4309088021254184, 1.5083103128998356, 1.5819292019556377, 1.6522711641858308, 1.719738352191984, 1.7846568297574747, 1.8472953201911164, 1.9078784028338913, 1.9665960439297137, 2.023610634484806, 2.079062288629179, 2.1330729007701543, 2.1857492994394394, 2.2371857321197095, 2.287465846739575, 2.3366642891095846, 2.3848480035423645, 2.432077301403062, 2.478406746278746, 2.5238858928247927, 2.5685599078082646, 2.6124700955226263, 2.6556543449779, 2.698147512646408, 2.7399817517640517, 2.781186797034676, 2.821790211904492, 2.8618176042508368, 2.9012928152808017, 2.9402380855978314, 2.9786742017212964, 3.0166206257996713, 3.0540956108150907, 3.0911163032147466, 3.1276988346066825, 3.1638584039112754, 3.199609351155231, 3.2349652239243625, 3.269938837348491, 3.3045423283716615, 3.33878720495931, 3.3726843908080104, 3.40624426605022, 3.439476704383968, 3.4723911070039337, 3.504996433664377, 3.5373012311647987, 3.5693136595149495, 3.601041516006168, 3.6324922573902345, 3.663673020344474, 3.694590640382233, 3.7252516693506763, 3.7556623916427845, 3.785828839237189, 3.8157568056677826, 3.84545185901475, 3.8749193539995126, 3.9041644432579936, 3.9331920878594273, 3.9620070671315064, 3.990613987846983, 4.019017292821717, 4.047221268969612, 4.075230054855799, 4.103047647785728, 4.130677910464577, 4.158124577258358, 4.185391260085489, 4.212481453965109, 4.239398542246294, 4.266145801540309, 4.292726406376255, 4.3191434335988435, 4.345399866525519, 4.371498598878879, 4.397442438509002, 4.423234110919295, 4.448876262608346, 4.474371464239419, 4.499722213648305, 4.524930938699507, 4.55, 4.57493169347915, 4.5997282528427705, 4.624391851908746, 4.648924606831132, 4.673328578219169, 4.697605773157216, 4.721758147131214, 4.745787605866913, 4.769696007084729, 4.7934851621758465], [0.0, 0.479583152331272, 0.6782329983125268, 0.8306623862918077, 0.959166304662544, 1.072380529476361, 1.174734012447073, 1.2688577540449522, 1.3564659966250536, 1.438749456993816, 1.5165750888103102, 1.5905973720586868, 1.6613247725836153, 1.7291616465790585, 1.7944358444926363, 1.857417562100671, 1.918332609325088, 1.977371993328519, 2.0346989949375804, 2.0904544960366875, 2.144761058952722, 2.1977260975835913, 2.249444375840399, 2.3000000000000003, 2.349468024894146, 2.39791576165636, 2.4454038521274972, 2.491987158875423, 2.5377155080899043, 2.582634314028992, 2.6267851073127395, 2.670205984563738, 2.7129319932501073, 2.754995462791183, 2.7964262908219126, 2.8372521918222215, 2.877498913987632, 2.917190429162965, 2.956349099818897, 2.994995826374388, 3.0331501776206204, 3.0708305065568178, 3.108054053584011, 3.1448370387032774, 3.1811947441173736, 3.2171415884290826, 3.252691193458119, 3.2878564445547194, 3.3226495451672307, 3.357082066318904, 3.3911649915626345, 3.4249087579087423, 3.458323293158117, 3.491418050019219, 3.5242020373412197, 3.5566838487557484, 3.5888716889852725, 3.620773398046335, 3.6523964735499352, 3.6837480912787726, 3.714835124201342, 3.745664160065609, 3.7762415176998414, 3.8065732621348563, 3.836665218650176, 3.866522985836241, 3.8961519477556315, 3.9255572852781047, 3.954743986657038, 3.9837168574084183, 4.012480529547776, 4.041039470235351, 4.069397989875161, 4.097560249709576, 4.125530268947254, 4.153311931459037, 4.180908992073375, 4.2083250825001635, 4.235563716909475, 4.262628297189424, 4.289522117905444, 4.316248370981448, 4.342810150121694, 4.369210454990696, 4.3954521951671826, 4.421538193886829, 4.447471191587417, 4.473253849269009, 4.498888751680798, 4.524378410345448, 4.549725266430931, 4.57493169347915, 4.6000000000000005, 4.624932431938872, 4.649731175025068, 4.674398357008098, 4.698936049788292, 4.723346271447818, 4.747630988187688, 4.77179211617606, 4.79583152331272, 4.819751030914357], [0.0, 0.4821825380496478, 0.6819090848492928, 0.8351646544245035, 0.9643650760992956, 1.0781929326423914, 1.1811011811017718, 1.2757350822173075, 1.3638181696985856, 1.4465476141489433, 1.5247950681976907, 1.5992185591719479, 1.670329308849007, 1.7385338650713713, 1.8041618552668717, 1.8674849396983098, 1.9287301521985911, 1.9880895352071044, 2.0457272545478786, 2.1017849556983705, 2.1563858652847827, 2.2096379793984355, 2.2616365755797285, 2.312466215969436, 2.3622023622035435, 2.410912690248239, 2.4586581706288495, 2.5054939632735103, 2.551470164434615, 2.596632434519757, 2.6410225292488514, 2.68467875173176, 2.727636339397171, 2.7699277968929086, 2.81158318390191, 2.8526303651191824, 2.8930952282978866, 2.933001875212493, 2.9723727895403704, 3.01122898498271, 3.0495901363953815, 3.087474696252587, 3.1248999983999495, 3.1618823507524754, 3.1984371183438958, 3.2345787979271736, 3.270321085153567, 3.3056769352131194, 3.340658617698014, 3.3752777663475344, 3.4095454242464642, 3.4434720849746996, 3.4770677301427426, 3.510341863693621, 3.5433035433053153, 3.575961409187745, 3.6083237105337433, 3.6403983298534794, 3.6721928053957082, 3.7037143518365454, 3.7349698793966195, 3.7659660115301095, 3.796709101313926, 3.8272052466519226, 3.8574603043971822, 3.887479903485033, 3.9172694571601787, 3.9468341743731776, 3.976179070414209, 4.005308976845607, 4.034228550788862, 4.062942283616641, 4.091454509095757, 4.1197694110229035, 4.147891030391228, 4.175823272122517, 4.203569911396741, 4.231134599608006, 4.258520869973518, 4.285732142819941, 4.312771730569565, 4.33964284244683, 4.3663485889241604, 4.392891985924535, 4.419275958796871, 4.445503346079047, 4.4715769030622745, 4.497499305169486, 4.523273151159457, 4.548900966167542, 4.574385204593073, 4.5997282528427705, 4.624932431938872, 4.65, 4.6749331546023205, 4.69973403502794, 4.724404724407087, 4.7489472517601214, 4.77336359394505, 4.797655677515843, 4.821825380496478, 4.845874534075352], [0.0, 0.48476798574163293, 0.6855654600401044, 0.8396427811873334, 0.9695359714832659, 1.0839741694339402, 1.187434208703792, 1.2825755338380662, 1.3711309200802089, 1.4543039572248988, 1.5329709716755893, 1.6077935190813528, 1.6792855623746668, 1.7478558292948536, 1.8138357147217055, 1.8774983355518586, 1.9390719429665317, 1.9987496091306687, 2.0566963801203135, 2.113054660911544, 2.1679483388678804, 2.221485989152306, 2.273763400180415, 2.324865587512534, 2.374868417407584, 2.4238399287081647, 2.4718414188616555, 2.518928343562, 2.5651510676761324, 2.610555496441323, 2.6551836094703507, 2.699073915253156, 2.7422618401604177, 2.7847800631288644, 2.8266588050205144, 2.8679260799399975, 2.9086079144497976, 2.9487285395573464, 2.9883105594967874, 3.027375100644121, 3.0659419433511785, 3.104029639033752, 3.141655614481002, 3.1788362650504665, 3.2155870381627056, 3.2519225083018197, 3.28785644455472, 3.3234018715767735, 3.3585711247493335, 3.3933759001914305, 3.4278273002005224, 3.461935874622753, 3.4957116585897072, 3.5291642070042597, 3.5623026261113755, 3.5951356024495102, 3.627671429443411, 3.65991803186902, 3.691882988394947, 3.723573552382174, 3.7549966711037173, 3.7861590035285104, 3.817066936798463, 3.847726601514198, 3.8781438859330635, 3.908324449172561, 3.9382737335030438, 3.9679969758052995, 3.9974992182613374, 4.026785318340178, 4.05585995813465, 4.08472765310002, 4.113392760240627, 4.141859485786547, 4.170131892398609, 4.198213905936667, 4.226109321823088, 4.253821811030641, 4.28135492572153, 4.308712104562105, 4.335896677735761, 4.362911871674696, 4.389760813529595, 4.4164465353947175, 4.442971978304612, 4.469339996017309, 4.495553358597805, 4.521614755814564, 4.54752680036083, 4.57329203091165, 4.598912915026768, 4.624391851908746, 4.649731175025068, 4.6749331546023205, 4.7, 4.72493386197098, 4.749736834815168, 4.7744109584324645, 4.798958220280731, 4.823380557244059, 4.847679857416329, 4.871857961804717], [0.0, 0.48733971724044817, 0.689202437604511, 0.8440971508067067, 0.9746794344808963, 1.0897247358851685, 1.1937336386313322, 1.2893796958227626, 1.378404875209022, 1.4620191517213443, 1.541103500742244, 1.6163229875244614, 1.6881943016134133, 1.7571283390805579, 1.8234582528810468, 1.8874586088176872, 1.9493588689617927, 2.0093531297410117, 2.067607312813533, 2.1242645786248002, 2.179449471770337, 2.2332711434127295, 2.285825890132492, 2.337199178504049, 2.3874672772626644, 2.436698586202241, 2.4849547279578355, 2.53229145242012, 2.578759391645525, 2.6244046944021417, 2.6692695630078274, 2.713392710243027, 2.756809750418044, 2.799553535833884, 2.8416544476765644, 2.8831406486676987, 2.9240383034426887, 2.9643717715563276, 3.0041637771599605, 3.04343555870664, 3.082207001484488, 3.120496755325985, 3.1583223394707516, 3.1957002362549582, 3.2326459750489227, 3.269174207655505, 3.3052987762076818, 3.3410327744576227, 3.3763886032268267, 3.411378020683137, 3.4460121880225554, 3.480301711058971, 3.5142566781611158, 3.5478866949213583, 3.5812009158939966, 3.6142080737002398, 3.6469165057620936, 3.679334178897046, 3.7114687119791268, 3.743327396848958, 3.7749172176353745, 3.8062448686336507, 3.837316770869978, 3.868139087468288, 3.8987177379235853, 3.929058411375427, 3.9591665789658306, 3.989047505357638, 4.018706259482023, 4.048147724577254, 4.077376607575022, 4.106397447885433, 4.135214625627066, 4.163832369344376, 4.192254763250916, 4.2204857540335325, 4.2485291572496005, 4.27638866334668, 4.3040678433314685, 4.331570154112709, 4.358898943540674, 4.386057455164034, 4.413048832723246, 4.439876124398067, 4.466542286825459, 4.493050188902857, 4.519402615390667, 4.545602270326782, 4.571651780264984, 4.5975536973481885, 4.623310502226732, 4.648924606831132, 4.674398357008098, 4.69973403502794, 4.72493386197098, 4.749999999999999, 4.774934554525329, 4.799739576268696, 4.824417063231577, 4.848968962573384, 4.873397172404482, 4.897703543498729], [0.0, 0.48989794855663565, 0.6928203230275509, 0.8485281374238571, 0.9797958971132713, 1.0954451150103324, 1.2000000000000002, 1.2961481396815722, 1.3856406460551018, 1.469693845669907, 1.5491933384829668, 1.6248076809271923, 1.6970562748477143, 1.7663521732655696, 1.833030277982336, 1.8973665961010275, 1.9595917942265426, 2.0199009876724157, 2.078460969082653, 2.1354156504062627, 2.1908902300206647, 2.244994432064365, 2.297825058615212, 2.349468024894146, 2.4000000000000004, 2.4494897427831783, 2.4979991993593598, 2.5455844122715714, 2.5922962793631443, 2.638181191654584, 2.6832815729997477, 2.727636339397171, 2.7712812921102037, 2.8142494558940583, 2.8565713714171403, 2.898275349237888, 2.939387691339814, 2.979932885150268, 3.0199337741083, 3.0594117081556713, 3.0983866769659336, 3.136877428271625, 3.174901573277509, 3.212475680841802, 3.2496153618543846, 3.2863353450309964, 3.32264954516723, 3.358571124749333, 3.3941125496954285, 3.4292856398964493, 3.464101615137755, 3.498571136907181, 3.532704346531139, 3.5665109000254023, 3.6, 3.6331804249169903, 3.666060555964672, 3.698648401781386, 3.7309516212355263, 3.7629775444453557, 3.794733192202055, 3.8262252939417984, 3.857460304397182, 3.8884444190447165, 3.9191835884530852, 3.9496835316262997, 3.97994974842648, 4.009987531152684, 4.039801975344831, 4.069397989875161, 4.09878030638384, 4.127953488110059, 4.156921938165306, 4.18568990729127, 4.214261501141095, 4.242640687119286, 4.270831300812525, 4.298837052040936, 4.3266615305567875, 4.354308211415448, 4.3817804600413295, 4.409081537009721, 4.436214602563767, 4.463182720884279, 4.48998886412873, 4.5166359162544865, 4.543126676640219, 4.5694638635183455, 4.595650117230424, 4.621688003316537, 4.6475800154489, 4.673328578219169, 4.698936049788292, 4.724404724407087, 4.749736834815168, 4.774934554525329, 4.800000000000001, 4.824935232725928, 4.849742261192857, 4.874423042781577, 4.898979485566357, 4.9234134500364695], [0.0, 0.4924428900898053, 0.696419413859206, 0.8529361054615993, 0.9848857801796106, 1.1011357772772623, 1.206233808181482, 1.3028814220795384, 1.392838827718412, 1.4773286702694157, 1.5572411502397439, 1.6332482971061077, 1.7058722109231985, 1.7755280904564708, 1.842552577268828, 1.9072231122760652, 1.9697715603592212, 2.0303940504246953, 2.089258241577618, 2.1465087933665683, 2.2022715545545246, 2.256656819279352, 2.30976189249022, 2.361673135723909, 2.412467616362964, 2.4622144504490264, 2.5109759058979444, 2.5588083163847974, 2.6057628441590768, 2.6518861212352243, 2.6972207918522355, 2.741805974171039, 2.785677655436824, 2.828869031963128, 2.871410803072246, 2.9133314263914434, 2.9546573405388314, 2.9954131601500324, 3.0356218473321084, 3.0753048629363566, 3.1144823004794877, 3.1531730050855127, 3.19139467944659, 3.2291639784935047, 3.2664965942122155, 3.303407331831786, 3.3399101784329477, 3.3760183648789592, 3.411744421846397, 3.447100230628637, 3.4820970692960302, 3.516745654721138, 3.5510561809129415, 3.585038354048671, 3.618701424544446, 3.65205421646503, 3.685105154537656, 3.7178622890042607, 3.7503333185198358, 3.782525611281436, 3.8144462245521304, 3.846101922726438, 3.8774991940682595, 3.9086442662386154, 3.9395431207184424, 3.9702015062210636, 4.000624951179503, 4.030818775385468, 4.060788100849391, 4.09053786194432, 4.120072814890533, 4.149397546632524, 4.178516483155236, 4.207433897282286, 4.236153915995027, 4.264680527307996, 4.293017586733137, 4.321168823362495, 4.349137845596528, 4.376928146542961, 4.404543109109049, 4.431986010808248, 4.459260028300661, 4.486368241685027, 4.513313638558704, 4.5400991178607555, 4.566727493512176, 4.5932014978661675, 4.61952378498044, 4.645696933722647, 4.671723450719232, 4.697605773157216, 4.723346271447818, 4.7489472517601214, 4.7744109584324645, 4.799739576268696, 4.824935232725928, 4.850000000000001, 4.874935897014442, 4.899744891318323, 4.924428900898053, 4.948989795907849], [0.0, 0.4949747468305833, 0.7, 0.8573214099741124, 0.9899494936611666, 1.1067971810589328, 1.2124355652982142, 1.3095800853708794, 1.4, 1.4849242404917498, 1.5652475842498528, 1.6416455159382004, 1.7146428199482249, 1.7846568297574747, 1.8520259177452134, 1.9170289512680811, 1.9798989873223332, 2.040833163195855, 2.1, 2.157544901039142, 2.2135943621178655, 2.2682592444427514, 2.32163735324878, 2.373815494093844, 2.4248711305964283, 2.4748737341529163, 2.5238858928247927, 2.571964229922337, 2.619160170741759, 2.665520587052368, 2.7110883423451915, 2.755902755904134, 2.8, 2.8434134416225865, 2.8861739379323623, 2.9283100928692645, 2.9698484809834995, 3.0108138434649194, 3.0512292604784714, 3.0911163032147466, 3.1304951684997055, 3.169384798348096, 3.2078029864690882, 3.245766473423496, 3.283291031876401, 3.320391543176798, 3.357082066318904, 3.3933759001914305, 3.4292856398964497, 3.4648232278140827, 3.5, 3.5348267284267276, 3.5693136595149495, 3.6034705493454506, 3.6373066958946425, 3.6708309685955305, 3.704051835490427, 3.736977388210959, 3.769615364994153, 3.8019731719200753, 3.8340579025361623, 3.865876356015541, 3.897435053981015, 3.9287402561126386, 3.9597979746446663, 3.9906139878469826, 4.02119385257662, 4.051542915976579, 4.08166632639171, 4.111569043564756, 4.141255848169731, 4.1707313507345445, 4.2, 4.2290660907581, 4.257933771208753, 4.286607049870562, 4.315089802078284, 4.3433857760968, 4.371498598878879, 4.399431781491788, 4.427188724235731, 4.4547727214752495, 4.4821869662029945, 4.509434554353794, 4.536518488885503, 4.563441683641854, 4.590206967011401, 4.616817085395522, 4.64327470649756, 4.669582422444217, 4.695742752749558, 4.721758147131214, 4.747630988187688, 4.77336359394505, 4.798958220280731, 4.824417063231577, 4.849742261192857, 4.874935897014442, 4.9, 4.924936547814601, 4.949747468305833, 4.974434641243164], [0.0, 0.49749371855331004, 0.7035623639735145, 0.8616843969807044, 0.9949874371066201, 1.1124297730643495, 1.2186057606953942, 1.3162446581088185, 1.407124727947029, 1.49248115565993, 1.5732132722552274, 1.6500000000000004, 1.7233687939614089, 1.79373911146521, 1.8614510468986285, 1.9267848867997694, 1.9899748742132402, 2.0512191496766015, 2.1106870919205436, 2.1685248442201446, 2.224859546128699, 2.2798026230355997, 2.333452377915607, 2.38589605808803, 2.4372115213907883, 2.4874685927665503, 2.5367301787931646, 2.585053190942113, 2.632489316217637, 2.6790856649237633, 2.7248853186877424, 2.7699277968929086, 2.814249455894058, 2.857883832488648, 2.9008619408720575, 2.943212530552288, 2.98496231131986, 3.0261361502748025, 3.066757245039131, 3.106847276581197, 3.146426544510455, 3.1855140872392957, 3.2241277890307023, 3.262284475639732, 3.3000000000000007, 3.337289319193048, 3.374166563760598, 3.410645100270622, 3.4467375879228177, 3.48245602987317, 3.5178118198675725, 3.552815784698104, 3.58747822293042, 3.6218089402948914, 3.6558172820861827, 3.6895121628746534, 3.722902093797257, 3.7559952076646748, 3.7887992820945273, 3.8213217608570993, 3.853569773599539, 3.885550154096586, 3.9172694571601787, 3.9487339743264553, 3.9799497484264803, 4.010922587136282, 4.041658075592244, 4.072161588149468, 4.102438299353203, 4.1324931941867735, 4.162331077653483, 4.191956583744636, 4.221374183841087, 4.250588194591426, 4.279602785306132, 4.3084219849035215, 4.337049688440289, 4.365489663256575, 4.3937455547630435, 4.421820891895103, 4.449719092257398, 4.47744346697979, 4.504997225304363, 4.532383478921439, 4.559605246071199, 4.586665455426197, 4.61356694976891, 4.640312489477407, 4.666904755831214, 4.693346354148605, 4.719639816765683, 4.745787605866913, 4.77179211617606, 4.797655677515843, 4.823380557244059, 4.848968962573384, 4.874423042781577, 4.899744891318323, 4.924936547814601, 4.950000000000001, 4.974937185533101, 4.999749993749688], [0.0, 0.5, 0.7071067811865476, 0.8660254037844388, 1.0, 1.118033988749895, 1.2247448713915892, 1.3228756555322954, 1.4142135623730951, 1.5, 1.5811388300841898, 1.6583123951777001, 1.7320508075688776, 1.8027756377319948, 1.8708286933869707, 1.9364916731037083, 2.0, 2.0615528128088303, 2.121320343559643, 2.179449471770337, 2.23606797749979, 2.2912878474779204, 2.345207879911715, 2.39791576165636, 2.4494897427831783, 2.5000000000000004, 2.5495097567963927, 2.5980762113533165, 2.6457513110645907, 2.6925824035672523, 2.7386127875258306, 2.783882181415011, 2.8284271247461903, 2.8722813232690148, 2.9154759474226504, 2.958039891549808, 3.0, 3.04138126514911, 3.0822070014844885, 3.1224989991991996, 3.1622776601683795, 3.2015621187164247, 3.2403703492039306, 3.278719262151, 3.3166247903554003, 3.3541019662496843, 3.3911649915626345, 3.4278273002005224, 3.4641016151377553, 3.5, 3.535533905932738, 3.5707142142714257, 3.6055512754639896, 3.64005494464026, 3.6742346141747677, 3.708099243547832, 3.7416573867739413, 3.774917217635375, 3.8078865529319548, 3.840572873934304, 3.8729833462074166, 3.9051248379533274, 3.9370039370059056, 3.968626966596886, 4.0, 4.031128874149275, 4.06201920231798, 4.092676385936225, 4.123105625617661, 4.153311931459037, 4.183300132670378, 4.2130748865881795, 4.242640687119286, 4.272001872658766, 4.301162633521313, 4.330127018922194, 4.358898943540674, 4.387482193696061, 4.415880433163924, 4.444097208657795, 4.47213595499958, 4.500000000000001, 4.527692569068709, 4.55521678957215, 4.582575694955841, 4.609772228646444, 4.636809247747852, 4.663689526544408, 4.69041575982343, 4.716990566028302, 4.743416490252569, 4.769696007084729, 4.79583152331272, 4.821825380496478, 4.847679857416329, 4.873397172404482, 4.898979485566357, 4.924428900898053, 4.949747468305833, 4.974937185533101, 5.000000000000001, 5.024937810560446], [0.0, 0.5024937810560446, 0.7106335201775948, 0.8703447592764607, 1.0049875621120892, 1.1236102527122118, 1.2308533625091174, 1.3294735800308333, 1.4212670403551897, 1.5074813431681338, 1.5890248582070705, 1.666583331249896, 1.7406895185529214, 1.8117670931993441, 1.8801595676963168, 1.9461500456028564, 2.0099751242241783, 2.0718349355100663, 2.1319005605327845, 2.1903196113809513, 2.2472205054244236, 2.302715787933891, 2.3569047498785354, 2.4098755154571787, 2.4617067250182347, 2.512468905280223, 2.5622255950637918, 2.611034277829382, 2.6589471600616665, 2.706011825546962, 2.752271788904577, 2.7977669667075564, 2.8425340807103794, 2.8866070047722125, 2.9300170647967225, 2.97279329923895, 3.0149626863362675, 3.0565503431155854, 3.0975797003467083, 3.1380726569026414, 3.178049716414141, 3.2175301086392345, 3.2565318975867568, 3.295072078119081, 3.333166662499792, 3.370830758136635, 3.408078637590395, 3.444923801769787, 3.481379037105843, 3.517456467392312, 3.5531676008879742, 3.5885233731996236, 3.6235341863986883, 3.65820994476807, 3.692560087527352, 3.7265936188428173, 3.7603191353926335, 3.793744851726326, 3.8268786236304915, 3.859727969689056, 3.892300091205713, 3.9246018906380815, 3.956639988677262, 3.9884207400925, 4.019950248448357, 4.05123437979093, 4.08227877539004, 4.113088863615762, 4.1436698710201325, 4.17402683268807, 4.204164601915582, 4.2340878592679205, 4.263801121065569, 4.293308747341612, 4.322614949310197, 4.351723796382303, 4.380639222761903, 4.409365033652805, 4.437904911103888, 4.466262419518137, 4.494441010848847, 4.522444029504402, 4.5502747169813835, 4.577936216244171, 4.605431575867782, 4.632763753959401, 4.659935621872903, 4.686949967729547, 4.713809499757071, 4.740516849458507, 4.767074574621212, 4.7934851621758465, 4.819751030914357, 4.845874534075352, 4.871857961804717, 4.897703543498729, 4.9234134500364695, 4.948989795907849, 4.974434641243164, 4.999749993749688, 5.024937810560446, 5.050000000000001]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"A = 1.0\", \"showscale\": false, \"type\": \"surface\", \"visible\": true, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.1, 0.1414213562373095, 0.17320508075688776, 0.2, 0.223606797749979, 0.24494897427831783, 0.2645751311064591, 0.282842712474619, 0.3, 0.31622776601683794, 0.33166247903554, 0.3464101615137755, 0.36055512754639896, 0.37416573867739417, 0.38729833462074165, 0.4, 0.41231056256176607, 0.4242640687119285, 0.43588989435406744, 0.447213595499958, 0.45825756949558405, 0.469041575982343, 0.479583152331272, 0.48989794855663565, 0.5, 0.5099019513592785, 0.5196152422706632, 0.5291502622129182, 0.5385164807134505, 0.5477225575051661, 0.5567764362830022, 0.565685424949238, 0.574456264653803, 0.5830951894845301, 0.5916079783099616, 0.6, 0.608276253029822, 0.6164414002968976, 0.6244997998398399, 0.6324555320336759, 0.6403124237432849, 0.6480740698407861, 0.6557438524302001, 0.66332495807108, 0.6708203932499369, 0.6782329983125268, 0.6855654600401044, 0.692820323027551, 0.7000000000000001, 0.7071067811865476, 0.7141428428542851, 0.7211102550927979, 0.7280109889280519, 0.7348469228349535, 0.7416198487095663, 0.7483314773547883, 0.754983443527075, 0.7615773105863909, 0.7681145747868608, 0.7745966692414833, 0.7810249675906654, 0.787400787401181, 0.7937253933193772, 0.8, 0.8062257748298549, 0.812403840463596, 0.8185352771872451, 0.8246211251235321, 0.8306623862918076, 0.8366600265340756, 0.8426149773176359, 0.848528137423857, 0.8544003745317531, 0.8602325267042626, 0.8660254037844387, 0.8717797887081349, 0.8774964387392122, 0.8831760866327848, 0.8888194417315589, 0.894427190999916, 0.9, 0.9055385138137417, 0.9110433579144299, 0.9165151389911681, 0.9219544457292888, 0.9273618495495705, 0.9327379053088816, 0.938083151964686, 0.9433981132056604, 0.9486832980505138, 0.9539392014169457, 0.959166304662544, 0.9643650760992956, 0.9695359714832659, 0.9746794344808963, 0.9797958971132713, 0.9848857801796106, 0.9899494936611666, 0.9949874371066201, 1.0, 1.0049875621120892], [0.0, 0.1414213562373095, 0.19999999999999998, 0.24494897427831783, 0.282842712474619, 0.31622776601683794, 0.34641016151377546, 0.3741657386773941, 0.39999999999999997, 0.4242640687119285, 0.4472135954999579, 0.469041575982343, 0.48989794855663565, 0.5099019513592785, 0.529150262212918, 0.5477225575051661, 0.565685424949238, 0.58309518948453, 0.6, 0.6164414002968976, 0.6324555320336759, 0.6480740698407861, 0.6633249580710799, 0.6782329983125268, 0.6928203230275509, 0.7071067811865476, 0.7211102550927979, 0.7348469228349535, 0.7483314773547882, 0.7615773105863909, 0.7745966692414833, 0.7874007874011811, 0.7999999999999999, 0.812403840463596, 0.8246211251235321, 0.8366600265340756, 0.848528137423857, 0.8602325267042626, 0.8717797887081348, 0.8831760866327847, 0.8944271909999159, 0.9055385138137417, 0.9165151389911681, 0.9273618495495702, 0.938083151964686, 0.9486832980505137, 0.9591663046625439, 0.9695359714832658, 0.9797958971132713, 0.9899494936611665, 1.0, 1.0099504938362078, 1.019803902718557, 1.0295630140987002, 1.0392304845413265, 1.0488088481701516, 1.058300524425836, 1.0677078252031311, 1.0770329614269007, 1.0862780491200215, 1.0954451150103321, 1.104536101718726, 1.1135528725660042, 1.1224972160321824, 1.131370849898476, 1.1401754250991378, 1.1489125293076057, 1.1575836902790224, 1.16619037896906, 1.174734012447073, 1.1832159566199232, 1.1916375287812984, 1.2, 1.2083045973594573, 1.2165525060596438, 1.224744871391589, 1.2328828005937953, 1.2409673645990857, 1.2489995996796797, 1.2569805089976536, 1.2649110640673518, 1.2727922061357855, 1.2806248474865698, 1.2884098726725124, 1.2961481396815722, 1.3038404810405297, 1.3114877048604001, 1.3190905958272918, 1.3266499161421599, 1.3341664064126333, 1.3416407864998738, 1.349073756323204, 1.3564659966250536, 1.3638181696985856, 1.3711309200802089, 1.378404875209022, 1.3856406460551018, 1.392838827718412, 1.4, 1.407124727947029, 1.4142135623730951, 1.4212670403551897], [0.0, 0.17320508075688776, 0.24494897427831783, 0.3000000000000001, 0.3464101615137755, 0.38729833462074176, 0.42426406871192857, 0.45825756949558405, 0.48989794855663565, 0.5196152422706632, 0.5477225575051662, 0.574456264653803, 0.6000000000000002, 0.6244997998398399, 0.6480740698407861, 0.6708203932499369, 0.692820323027551, 0.7141428428542851, 0.7348469228349536, 0.7549834435270751, 0.7745966692414835, 0.7937253933193773, 0.8124038404635961, 0.8306623862918077, 0.8485281374238571, 0.8660254037844388, 0.8831760866327849, 0.9000000000000001, 0.9165151389911681, 0.9327379053088817, 0.9486832980505139, 0.9643650760992957, 0.9797958971132713, 0.9949874371066202, 1.009950493836208, 1.02469507659596, 1.0392304845413265, 1.053565375285274, 1.0677078252031313, 1.081665382639197, 1.0954451150103324, 1.1090536506409419, 1.1224972160321827, 1.1357816691600549, 1.148912529307606, 1.161895003862225, 1.1747340124470733, 1.187434208703792, 1.2000000000000004, 1.2124355652982142, 1.2247448713915892, 1.2369316876852985, 1.2489995996796799, 1.2609520212918495, 1.2727922061357857, 1.2845232578665131, 1.2961481396815722, 1.3076696830622023, 1.3190905958272923, 1.3304134695650072, 1.3416407864998738, 1.3527749258468684, 1.3638181696985856, 1.3747727084867523, 1.385640646055102, 1.3964240043768943, 1.4071247279470291, 1.4177446878757827, 1.4282856857085702, 1.4387494569938162, 1.4491376746189442, 1.4594519519326425, 1.4696938456699071, 1.4798648586948744, 1.489966442575134, 1.5000000000000002, 1.5099668870541503, 1.5198684153570665, 1.5297058540778359, 1.5394804318340656, 1.549193338482967, 1.5588457268119897, 1.5684387141358125, 1.5779733838059502, 1.5874507866387546, 1.5968719422671316, 1.6062378404209012, 1.6155494421403516, 1.6248076809271923, 1.6340134638368193, 1.6431676725154984, 1.6522711641858308, 1.6613247725836153, 1.670329308849007, 1.6792855623746668, 1.6881943016134133, 1.6970562748477143, 1.7058722109231985, 1.7146428199482249, 1.7233687939614089, 1.7320508075688776, 1.7406895185529214], [0.0, 0.2, 0.282842712474619, 0.3464101615137755, 0.4, 0.447213595499958, 0.48989794855663565, 0.5291502622129182, 0.565685424949238, 0.6, 0.6324555320336759, 0.66332495807108, 0.692820323027551, 0.7211102550927979, 0.7483314773547883, 0.7745966692414833, 0.8, 0.8246211251235321, 0.848528137423857, 0.8717797887081349, 0.894427190999916, 0.9165151389911681, 0.938083151964686, 0.959166304662544, 0.9797958971132713, 1.0, 1.019803902718557, 1.0392304845413265, 1.0583005244258363, 1.077032961426901, 1.0954451150103321, 1.1135528725660044, 1.131370849898476, 1.148912529307606, 1.1661903789690602, 1.1832159566199232, 1.2, 1.216552506059644, 1.2328828005937953, 1.2489995996796799, 1.2649110640673518, 1.2806248474865698, 1.2961481396815722, 1.3114877048604001, 1.32664991614216, 1.3416407864998738, 1.3564659966250536, 1.3711309200802089, 1.385640646055102, 1.4000000000000001, 1.4142135623730951, 1.4282856857085702, 1.4422205101855958, 1.4560219778561039, 1.469693845669907, 1.4832396974191326, 1.4966629547095767, 1.50996688705415, 1.5231546211727818, 1.5362291495737217, 1.5491933384829666, 1.5620499351813308, 1.574801574802362, 1.5874507866387544, 1.6, 1.6124515496597098, 1.624807680927192, 1.6370705543744901, 1.6492422502470643, 1.661324772583615, 1.6733200530681511, 1.6852299546352718, 1.697056274847714, 1.7088007490635062, 1.7204650534085253, 1.7320508075688774, 1.7435595774162698, 1.7549928774784245, 1.7663521732655696, 1.7776388834631178, 1.788854381999832, 1.8, 1.8110770276274835, 1.8220867158288598, 1.8330302779823362, 1.8439088914585775, 1.854723699099141, 1.8654758106177631, 1.876166303929372, 1.8867962264113207, 1.8973665961010275, 1.9078784028338913, 1.918332609325088, 1.9287301521985911, 1.9390719429665317, 1.9493588689617927, 1.9595917942265426, 1.9697715603592212, 1.9798989873223332, 1.9899748742132402, 2.0, 2.0099751242241783], [0.0, 0.223606797749979, 0.31622776601683794, 0.38729833462074176, 0.447213595499958, 0.5000000000000001, 0.5477225575051662, 0.5916079783099617, 0.6324555320336759, 0.6708203932499369, 0.7071067811865476, 0.7416198487095664, 0.7745966692414835, 0.806225774829855, 0.8366600265340756, 0.8660254037844386, 0.894427190999916, 0.9219544457292888, 0.9486832980505139, 0.9746794344808966, 1.0000000000000002, 1.02469507659596, 1.0488088481701516, 1.072380529476361, 1.0954451150103324, 1.118033988749895, 1.140175425099138, 1.1618950038622253, 1.1832159566199234, 1.2041594578792296, 1.2247448713915892, 1.2449899597988734, 1.2649110640673518, 1.2845232578665131, 1.30384048104053, 1.3228756555322954, 1.3416407864998738, 1.3601470508735445, 1.3784048752090223, 1.3964240043768943, 1.4142135623730951, 1.4317821063276355, 1.4491376746189442, 1.466287829861518, 1.4832396974191329, 1.5, 1.5165750888103102, 1.5329709716755893, 1.549193338482967, 1.565247584249853, 1.5811388300841898, 1.5968719422671316, 1.61245154965971, 1.627882059609971, 1.6431676725154984, 1.6583123951777001, 1.6733200530681511, 1.6881943016134133, 1.7029386365926404, 1.7175564037317668, 1.7320508075688772, 1.746424919657298, 1.760681686165901, 1.7748239349298849, 1.788854381999832, 1.8027756377319946, 1.8165902124584952, 1.8303005217723127, 1.8439088914585775, 1.8574175621006712, 1.8708286933869709, 1.8841443681416774, 1.8973665961010278, 1.91049731745428, 1.9235384061671346, 1.9364916731037085, 1.9493588689617931, 1.9621416870348585, 1.9748417658131503, 1.9874606914351793, 2.0000000000000004, 2.012461179749811, 2.024845673131659, 2.0371548787463363, 2.04939015319192, 2.0615528128088303, 2.0736441353327724, 2.0856653614614213, 2.0976176963403033, 2.1095023109728985, 2.121320343559643, 2.1330729007701543, 2.144761058952722, 2.1563858652847827, 2.1679483388678804, 2.179449471770337, 2.1908902300206647, 2.2022715545545246, 2.2135943621178655, 2.224859546128699, 2.23606797749979, 2.2472205054244236], [0.0, 0.24494897427831783, 0.34641016151377546, 0.42426406871192857, 0.48989794855663565, 0.5477225575051662, 0.6000000000000001, 0.6480740698407861, 0.6928203230275509, 0.7348469228349535, 0.7745966692414834, 0.8124038404635961, 0.8485281374238571, 0.8831760866327848, 0.916515138991168, 0.9486832980505138, 0.9797958971132713, 1.0099504938362078, 1.0392304845413265, 1.0677078252031313, 1.0954451150103324, 1.1224972160321824, 1.148912529307606, 1.174734012447073, 1.2000000000000002, 1.2247448713915892, 1.2489995996796799, 1.2727922061357857, 1.2961481396815722, 1.319090595827292, 1.3416407864998738, 1.3638181696985856, 1.3856406460551018, 1.4071247279470291, 1.4282856857085702, 1.449137674618944, 1.469693845669907, 1.489966442575134, 1.50996688705415, 1.5297058540778357, 1.5491933384829668, 1.5684387141358125, 1.5874507866387546, 1.606237840420901, 1.6248076809271923, 1.6431676725154982, 1.661324772583615, 1.6792855623746665, 1.6970562748477143, 1.7146428199482247, 1.7320508075688774, 1.7492855684535904, 1.7663521732655696, 1.7832554500127011, 1.8, 1.8165902124584952, 1.833030277982336, 1.849324200890693, 1.8654758106177631, 1.8814887722226779, 1.8973665961010275, 1.9131126469708992, 1.928730152198591, 1.9442222095223582, 1.9595917942265426, 1.9748417658131499, 1.98997487421324, 2.004993765576342, 2.0199009876724157, 2.0346989949375804, 2.04939015319192, 2.0639767440550294, 2.078460969082653, 2.092844953645635, 2.1071307505705477, 2.121320343559643, 2.1354156504062627, 2.149418526020468, 2.1633307652783937, 2.177154105707724, 2.1908902300206647, 2.2045407685048604, 2.2181073012818837, 2.2315913604421396, 2.244994432064365, 2.2583179581272432, 2.2715633383201097, 2.2847319317591728, 2.297825058615212, 2.3108440016582685, 2.32379000772445, 2.3366642891095846, 2.349468024894146, 2.3622023622035435, 2.374868417407584, 2.3874672772626644, 2.4000000000000004, 2.412467616362964, 2.4248711305964283, 2.4372115213907883, 2.4494897427831783, 2.4617067250182347], [0.0, 0.2645751311064591, 0.3741657386773941, 0.45825756949558405, 0.5291502622129182, 0.5916079783099617, 0.6480740698407861, 0.7000000000000001, 0.7483314773547882, 0.7937253933193772, 0.8366600265340756, 0.8774964387392122, 0.9165151389911681, 0.9539392014169458, 0.9899494936611666, 1.0246950765959597, 1.0583005244258363, 1.0908712114635715, 1.1224972160321824, 1.1532562594670797, 1.1832159566199234, 1.2124355652982142, 1.2409673645990857, 1.2688577540449522, 1.2961481396815722, 1.3228756555322954, 1.3490737563232043, 1.374772708486752, 1.4000000000000001, 1.4247806848775009, 1.4491376746189437, 1.4730919862656235, 1.4966629547095764, 1.5198684153570665, 1.5427248620541514, 1.5652475842498528, 1.5874507866387544, 1.6093476939431082, 1.6309506430300091, 1.6522711641858308, 1.6733200530681511, 1.6941074346097418, 1.7146428199482249, 1.7349351572897471, 1.7549928774784245, 1.7748239349298847, 1.7944358444926363, 1.8138357147217055, 1.8330302779823362, 1.8520259177452134, 1.8708286933869709, 1.8894443627691186, 1.9078784028338915, 1.9261360284258224, 1.9442222095223582, 1.9621416870348585, 1.9798989873223332, 1.997498435543818, 2.0149441679609885, 2.0322401432901573, 2.0493901531919194, 2.0663978319771825, 2.083266665599966, 2.1, 2.1166010488516727, 2.133072900770154, 2.149418526020468, 2.1656407827707715, 2.181742422927143, 2.1977260975835913, 2.2135943621178655, 2.2293496809607953, 2.244994432064365, 2.260530911091463, 2.2759613353482084, 2.29128784747792, 2.3065125189341593, 2.32163735324878, 2.336664289109585, 2.3515952032609695, 2.366431913239847, 2.3811761799581315, 2.395829710142188, 2.41039415863879, 2.4248711305964283, 2.4392621835300936, 2.4535688292770597, 2.4677925358506134, 2.4819347291981715, 2.495996794869737, 2.5099800796022267, 2.5238858928247927, 2.5377155080899043, 2.551470164434615, 2.5651510676761324, 2.578759391645525, 2.5922962793631443, 2.6057628441590768, 2.619160170741759, 2.632489316217637, 2.6457513110645907, 2.6589471600616665], [0.0, 0.282842712474619, 0.39999999999999997, 0.48989794855663565, 0.565685424949238, 0.6324555320336759, 0.6928203230275509, 0.7483314773547882, 0.7999999999999999, 0.848528137423857, 0.8944271909999159, 0.938083151964686, 0.9797958971132713, 1.019803902718557, 1.058300524425836, 1.0954451150103321, 1.131370849898476, 1.16619037896906, 1.2, 1.2328828005937953, 1.2649110640673518, 1.2961481396815722, 1.3266499161421599, 1.3564659966250536, 1.3856406460551018, 1.4142135623730951, 1.4422205101855958, 1.469693845669907, 1.4966629547095764, 1.5231546211727818, 1.5491933384829666, 1.5748015748023623, 1.5999999999999999, 1.624807680927192, 1.6492422502470643, 1.6733200530681511, 1.697056274847714, 1.7204650534085253, 1.7435595774162695, 1.7663521732655694, 1.7888543819998317, 1.8110770276274835, 1.8330302779823362, 1.8547236990991405, 1.876166303929372, 1.8973665961010273, 1.9183326093250879, 1.9390719429665315, 1.9595917942265426, 1.979898987322333, 2.0, 2.0199009876724157, 2.039607805437114, 2.0591260281974004, 2.078460969082653, 2.0976176963403033, 2.116601048851672, 2.1354156504062622, 2.1540659228538015, 2.172556098240043, 2.1908902300206643, 2.209072203437452, 2.2271057451320084, 2.244994432064365, 2.262741699796952, 2.2803508501982757, 2.2978250586152114, 2.315167380558045, 2.33238075793812, 2.349468024894146, 2.3664319132398464, 2.3832750575625967, 2.4, 2.4166091947189146, 2.4331050121192876, 2.449489742783178, 2.4657656011875906, 2.4819347291981715, 2.4979991993593593, 2.513961017995307, 2.5298221281347035, 2.545584412271571, 2.5612496949731396, 2.576819745345025, 2.5922962793631443, 2.6076809620810595, 2.6229754097208002, 2.6381811916545836, 2.6532998322843198, 2.6683328128252666, 2.6832815729997477, 2.698147512646408, 2.7129319932501073, 2.727636339397171, 2.7422618401604177, 2.756809750418044, 2.7712812921102037, 2.785677655436824, 2.8, 2.814249455894058, 2.8284271247461903, 2.8425340807103794], [0.0, 0.3, 0.4242640687119285, 0.5196152422706632, 0.6, 0.6708203932499369, 0.7348469228349535, 0.7937253933193772, 0.848528137423857, 0.8999999999999999, 0.9486832980505138, 0.99498743710662, 1.0392304845413265, 1.0816653826391969, 1.1224972160321824, 1.1618950038622249, 1.2, 1.236931687685298, 1.2727922061357855, 1.307669683062202, 1.3416407864998738, 1.374772708486752, 1.407124727947029, 1.438749456993816, 1.469693845669907, 1.5, 1.5297058540778354, 1.5588457268119895, 1.5874507866387544, 1.6155494421403513, 1.6431676725154982, 1.6703293088490065, 1.697056274847714, 1.7233687939614086, 1.7492855684535902, 1.7748239349298847, 1.7999999999999998, 1.8248287590894658, 1.849324200890693, 1.8734993995195195, 1.8973665961010275, 1.9209372712298547, 1.9442222095223582, 1.9672315572906, 1.98997487421324, 2.0124611797498106, 2.0346989949375804, 2.056696380120313, 2.078460969082653, 2.1, 2.1213203435596424, 2.142428528562855, 2.1633307652783937, 2.1840329667841556, 2.2045407685048604, 2.224859546128699, 2.244994432064365, 2.264950330581225, 2.2847319317591723, 2.3043437243605824, 2.3237900077244498, 2.3430749027719964, 2.362202362203543, 2.3811761799581315, 2.4, 2.4186773244895647, 2.437211521390788, 2.455605831561735, 2.473863375370596, 2.4919871588754225, 2.5099800796022267, 2.5278449319529073, 2.545584412271571, 2.563201123595259, 2.580697580112788, 2.598076211353316, 2.615339366124404, 2.6324893162176366, 2.6495282598983545, 2.6664583251946765, 2.6832815729997477, 2.7, 2.716615541441225, 2.7331300737432893, 2.749545416973504, 2.765863337187866, 2.7820855486487113, 2.7982137159266447, 2.814249455894058, 2.830194339616981, 2.846049894151541, 2.8618176042508368, 2.877498913987632, 2.8930952282978866, 2.9086079144497976, 2.9240383034426887, 2.939387691339814, 2.9546573405388314, 2.9698484809834995, 2.98496231131986, 3.0, 3.0149626863362675], [0.0, 0.31622776601683794, 0.4472135954999579, 0.5477225575051662, 0.6324555320336759, 0.7071067811865476, 0.7745966692414834, 0.8366600265340756, 0.8944271909999159, 0.9486832980505138, 1.0, 1.0488088481701516, 1.0954451150103324, 1.140175425099138, 1.1832159566199232, 1.224744871391589, 1.2649110640673518, 1.3038404810405297, 1.3416407864998738, 1.3784048752090223, 1.4142135623730951, 1.449137674618944, 1.4832396974191326, 1.5165750888103102, 1.5491933384829668, 1.5811388300841898, 1.61245154965971, 1.6431676725154984, 1.6733200530681511, 1.7029386365926402, 1.7320508075688772, 1.760681686165901, 1.7888543819998317, 1.8165902124584952, 1.8439088914585775, 1.8708286933869707, 1.8973665961010275, 1.9235384061671346, 1.949358868961793, 1.97484176581315, 2.0, 2.024845673131659, 2.04939015319192, 2.073644135332772, 2.0976176963403033, 2.1213203435596424, 2.1447610589527217, 2.16794833886788, 2.1908902300206647, 2.2135943621178655, 2.23606797749979, 2.2583179581272432, 2.280350850198276, 2.302172886644268, 2.32379000772445, 2.345207879911715, 2.3664319132398464, 2.3874672772626644, 2.4083189157584592, 2.4289915602982237, 2.449489742783178, 2.4698178070456938, 2.4899799195977463, 2.5099800796022267, 2.5298221281347035, 2.5495097567963922, 2.569046515733026, 2.588435821108957, 2.6076809620810595, 2.6267851073127395, 2.6457513110645907, 2.6645825188948455, 2.6832815729997477, 2.701851217221259, 2.7202941017470885, 2.7386127875258306, 2.7568097504180447, 2.7748873851023217, 2.7928480087537886, 2.8106938645110393, 2.8284271247461903, 2.8460498941515415, 2.863564212655271, 2.8809720581775866, 2.898275349237888, 2.9154759474226504, 2.932575659723036, 2.9495762407505253, 2.9664793948382653, 2.9832867780352594, 3.0, 3.0166206257996713, 3.0331501776206204, 3.0495901363953815, 3.0659419433511785, 3.082207001484488, 3.0983866769659336, 3.1144823004794877, 3.1304951684997055, 3.146426544510455, 3.1622776601683795, 3.178049716414141], [0.0, 0.33166247903554, 0.469041575982343, 0.574456264653803, 0.66332495807108, 0.7416198487095664, 0.8124038404635961, 0.8774964387392122, 0.938083151964686, 0.99498743710662, 1.0488088481701516, 1.1, 1.148912529307606, 1.1958260743101399, 1.2409673645990857, 1.284523257866513, 1.32664991614216, 1.3674794331177345, 1.407124727947029, 1.4456832294800963, 1.4832396974191329, 1.5198684153570665, 1.5556349186104048, 1.5905973720586868, 1.6248076809271923, 1.6583123951777001, 1.6911534525287766, 1.7233687939614089, 1.7549928774784245, 1.7860571099491753, 1.816590212458495, 1.846618531261939, 1.876166303929372, 1.9052558883257653, 1.9339079605813718, 1.9621416870348585, 1.98997487421324, 2.017424100183202, 2.0445048300260877, 2.0712315177207983, 2.0976176963403033, 2.1236760581595306, 2.149418526020468, 2.1748563170931545, 2.2, 2.224859546128699, 2.249444375840399, 2.273763400180415, 2.297825058615212, 2.32163735324878, 2.345207879911715, 2.368543856465403, 2.3916521486202797, 2.4145392935299275, 2.4372115213907883, 2.459674775249769, 2.4819347291981715, 2.503996805109783, 2.525866188063018, 2.5475478405713994, 2.569046515733026, 2.5903667693977237, 2.6115129714401193, 2.632489316217637, 2.65329983228432, 2.6739483914241875, 2.6944387170614963, 2.714774392099646, 2.734958866235469, 2.7549954627911823, 2.774887385102322, 2.7946377224964243, 2.814249455894058, 2.833725463060951, 2.8530685235374214, 2.8722813232690148, 2.8913664589601926, 2.91032644217105, 2.9291637031753623, 2.9478805945967355, 2.9664793948382657, 2.9849623113198605, 3.003331483536242, 3.0215889859476257, 3.039736830714133, 3.0577769702841313, 3.07571129984594, 3.093541659651604, 3.1112698372208096, 3.1288975694324033, 3.146426544510455, 3.1638584039112754, 3.1811947441173736, 3.1984371183438958, 3.2155870381627056, 3.2326459750489227, 3.2496153618543846, 3.2664965942122155, 3.283291031876401, 3.3000000000000007, 3.3166247903554003, 3.333166662499792], [0.0, 0.3464101615137755, 0.48989794855663565, 0.6000000000000002, 0.692820323027551, 0.7745966692414835, 0.8485281374238571, 0.9165151389911681, 0.9797958971132713, 1.0392304845413265, 1.0954451150103324, 1.148912529307606, 1.2000000000000004, 1.2489995996796799, 1.2961481396815722, 1.3416407864998738, 1.385640646055102, 1.4282856857085702, 1.4696938456699071, 1.5099668870541503, 1.549193338482967, 1.5874507866387546, 1.6248076809271923, 1.6613247725836153, 1.6970562748477143, 1.7320508075688776, 1.7663521732655698, 1.8000000000000003, 1.8330302779823362, 1.8654758106177634, 1.8973665961010278, 1.9287301521985913, 1.9595917942265426, 1.9899748742132404, 2.019900987672416, 2.04939015319192, 2.078460969082653, 2.107130750570548, 2.1354156504062627, 2.163330765278394, 2.1908902300206647, 2.2181073012818837, 2.2449944320643653, 2.2715633383201097, 2.297825058615212, 2.32379000772445, 2.3494680248941466, 2.374868417407584, 2.400000000000001, 2.4248711305964283, 2.4494897427831783, 2.473863375370597, 2.4979991993593598, 2.521904042583699, 2.5455844122715714, 2.5690465157330262, 2.5922962793631443, 2.6153393661244047, 2.6381811916545845, 2.6608269391300143, 2.6832815729997477, 2.705549851693737, 2.727636339397171, 2.7495454169735045, 2.771281292110204, 2.7928480087537886, 2.8142494558940583, 2.8354893757515653, 2.8565713714171403, 2.8774989139876324, 2.8982753492378883, 2.918903903865285, 2.9393876913398143, 2.9597297173897488, 2.979932885150268, 3.0000000000000004, 3.0199337741083006, 3.039736830714133, 3.0594117081556718, 3.078960863668131, 3.098386676965934, 3.1176914536239795, 3.136877428271625, 3.1559467676119004, 3.174901573277509, 3.193743884534263, 3.2124756808418025, 3.231098884280703, 3.2496153618543846, 3.2680269276736387, 3.286335345030997, 3.3045423283716615, 3.3226495451672307, 3.340658617698014, 3.3585711247493335, 3.3763886032268267, 3.3941125496954285, 3.411744421846397, 3.4292856398964497, 3.4467375879228177, 3.4641016151377553, 3.481379037105843], [0.0, 0.36055512754639896, 0.5099019513592785, 0.6244997998398399, 0.7211102550927979, 0.806225774829855, 0.8831760866327848, 0.9539392014169458, 1.019803902718557, 1.0816653826391969, 1.140175425099138, 1.1958260743101399, 1.2489995996796799, 1.3000000000000003, 1.3490737563232043, 1.396424004376894, 1.4422205101855958, 1.4866068747318506, 1.5297058540778357, 1.5716233645501714, 1.61245154965971, 1.6522711641858308, 1.6911534525287764, 1.7291616465790585, 1.7663521732655696, 1.8027756377319948, 1.8384776310850237, 1.8734993995195197, 1.9078784028338915, 1.94164878389476, 1.9748417658131499, 2.0074859899884734, 2.039607805437114, 2.0712315177207983, 2.102379604162864, 2.1330729007701543, 2.1633307652783937, 2.193171219946131, 2.222611077089287, 2.2516660498395407, 2.280350850198276, 2.3086792761230397, 2.336664289109585, 2.364318083507378, 2.3916521486202797, 2.4186773244895647, 2.445403852127497, 2.471841418861655, 2.4979991993593598, 2.5238858928247927, 2.5495097567963927, 2.574878637916747, 2.6000000000000005, 2.624880949681338, 2.6495282598983545, 2.673948391424188, 2.6981475126464085, 2.72213151776324, 2.7459060435491964, 2.7694764848252458, 2.792848008753788, 2.816025568065745, 2.839013913315678, 2.861817604250837, 2.8844410203711917, 2.9068883707497264, 2.9291637031753623, 2.951270912674741, 2.973213749463701, 2.994995826374388, 3.0166206257996717, 3.0380915061926625, 3.0594117081556713, 3.0805843601498726, 3.1016124838541645, 3.122498999199199, 3.1432467291003428, 3.1638584039112754, 3.1843366656181322, 3.204684071792413, 3.22490309931942, 3.2449961479175906, 3.264965543462902, 3.2848135411313684, 3.3045423283716615, 3.3241540277189325, 3.343650699460098, 3.363034344160048, 3.3823069050575527, 3.4014702703389896, 3.420526275297414, 3.439476704383968, 3.458323293158117, 3.4770677301427426, 3.4957116585897072, 3.5142566781611158, 3.532704346531139, 3.5510561809129415, 3.5693136595149495, 3.58747822293042, 3.6055512754639896, 3.6235341863986883], [0.0, 0.37416573867739417, 0.529150262212918, 0.6480740698407861, 0.7483314773547883, 0.8366600265340756, 0.916515138991168, 0.9899494936611666, 1.058300524425836, 1.1224972160321824, 1.1832159566199232, 1.2409673645990857, 1.2961481396815722, 1.3490737563232043, 1.4, 1.4491376746189437, 1.4966629547095767, 1.5427248620541512, 1.5874507866387544, 1.6309506430300091, 1.6733200530681511, 1.7146428199482247, 1.7549928774784245, 1.7944358444926363, 1.833030277982336, 1.8708286933869707, 1.9078784028338913, 1.9442222095223582, 1.9798989873223332, 2.0149441679609885, 2.0493901531919194, 2.083266665599966, 2.116601048851672, 2.149418526020468, 2.181742422927143, 2.2135943621178655, 2.244994432064365, 2.2759613353482084, 2.3065125189341593, 2.3366642891095846, 2.3664319132398464, 2.395829710142188, 2.4248711305964283, 2.453568829277059, 2.4819347291981715, 2.5099800796022262, 2.5377155080899043, 2.565151067676132, 2.5922962793631443, 2.619160170741759, 2.6457513110645907, 2.672077843177478, 2.6981475126464085, 2.7239676943752476, 2.749545416973504, 2.7748873851023217, 2.8, 2.824889378365107, 2.8495613697550017, 2.8740215726399825, 2.8982753492378874, 2.9223278392404914, 2.9461839725312466, 2.9698484809834995, 2.9933259094191533, 3.016620625799671, 3.0397368307141326, 3.062678566222711, 3.0854497241083023, 3.1080540535840107, 3.1304951684997055, 3.152776554086889, 3.1749015732775088, 3.196873472629156, 3.218695387886216, 3.24037034920393, 3.2619012860600183, 3.283291031876401, 3.3045423283716615, 3.3256578296631782, 3.3466401061363023, 3.3674916480965473, 3.3882148692194836, 3.408812109811862, 3.4292856398964493, 3.449637662132068, 3.4698703145794947, 3.4899856733230297, 3.509985754956849, 3.529872518944558, 3.5496478698597693, 3.5693136595149495, 3.5888716889852725, 3.6083237105337433, 3.627671429443411, 3.6469165057620936, 3.666060555964672, 3.685105154537656, 3.704051835490427, 3.722902093797257, 3.7416573867739413, 3.7603191353926335], [0.0, 0.38729833462074165, 0.5477225575051661, 0.6708203932499369, 0.7745966692414833, 0.8660254037844386, 0.9486832980505138, 1.0246950765959597, 1.0954451150103321, 1.1618950038622249, 1.224744871391589, 1.284523257866513, 1.3416407864998738, 1.396424004376894, 1.4491376746189437, 1.4999999999999998, 1.5491933384829666, 1.5968719422671311, 1.6431676725154982, 1.6881943016134133, 1.7320508075688772, 1.7748239349298847, 1.816590212458495, 1.857417562100671, 1.8973665961010275, 1.9364916731037083, 1.9748417658131499, 2.0124611797498106, 2.0493901531919194, 2.085665361461421, 2.1213203435596424, 2.1563858652847823, 2.1908902300206643, 2.224859546128699, 2.258317958127243, 2.29128784747792, 2.3237900077244498, 2.355843797877949, 2.3874672772626644, 2.4186773244895647, 2.449489742783178, 2.479919353527449, 2.5099800796022267, 2.5396850198400585, 2.569046515733026, 2.5980762113533156, 2.626785107312739, 2.6551836094703507, 2.6832815729997477, 2.7110883423451915, 2.7386127875258306, 2.765863337187866, 2.792848008753788, 2.819574435974337, 2.846049894151541, 2.8722813232690143, 2.8982753492378874, 2.924038303442689, 2.9495762407505253, 2.974894956128703, 2.9999999999999996, 3.0248966924508345, 3.049590136395381, 3.074085229787879, 3.098386676965933, 3.1224989991991987, 3.1464265445104544, 3.1701734968294715, 3.1937438845342623, 3.217141588429082, 3.24037034920393, 3.2634337744161437, 3.2863353450309964, 3.309078421554859, 3.3316662497915357, 3.3541019662496843, 3.3763886032268267, 3.3985290935932855, 3.420526275297414, 3.442382895611701, 3.4641016151377544, 3.485685011586675, 3.5071355833500366, 3.5284557528754696, 3.5496478698597693, 3.5707142142714248, 3.591656999213594, 3.6124783736376886, 3.63318042491699, 3.6537651812890215, 3.674234614174767, 3.694590640382233, 3.714835124201342, 3.7349698793966195, 3.7549966711037173, 3.7749172176353745, 3.794733192202055, 3.8144462245521304, 3.8340579025361623, 3.853569773599539, 3.8729833462074166, 3.892300091205713], [0.0, 0.4, 0.565685424949238, 0.692820323027551, 0.8, 0.894427190999916, 0.9797958971132713, 1.0583005244258363, 1.131370849898476, 1.2, 1.2649110640673518, 1.32664991614216, 1.385640646055102, 1.4422205101855958, 1.4966629547095767, 1.5491933384829666, 1.6, 1.6492422502470643, 1.697056274847714, 1.7435595774162698, 1.788854381999832, 1.8330302779823362, 1.876166303929372, 1.918332609325088, 1.9595917942265426, 2.0, 2.039607805437114, 2.078460969082653, 2.1166010488516727, 2.154065922853802, 2.1908902300206643, 2.227105745132009, 2.262741699796952, 2.297825058615212, 2.3323807579381204, 2.3664319132398464, 2.4, 2.433105012119288, 2.4657656011875906, 2.4979991993593598, 2.5298221281347035, 2.5612496949731396, 2.5922962793631443, 2.6229754097208002, 2.65329983228432, 2.6832815729997477, 2.7129319932501073, 2.7422618401604177, 2.771281292110204, 2.8000000000000003, 2.8284271247461903, 2.8565713714171403, 2.8844410203711917, 2.9120439557122078, 2.939387691339814, 2.9664793948382653, 2.9933259094191533, 3.0199337741083, 3.0463092423455636, 3.0724582991474434, 3.098386676965933, 3.1240998703626617, 3.149603149604724, 3.1749015732775088, 3.2, 3.2249030993194197, 3.249615361854384, 3.2741411087489802, 3.2984845004941286, 3.32264954516723, 3.3466401061363023, 3.3704599092705436, 3.394112549695428, 3.4176014981270124, 3.4409301068170506, 3.464101615137755, 3.4871191548325395, 3.509985754956849, 3.532704346531139, 3.5552777669262356, 3.577708763999664, 3.6, 3.622154055254967, 3.6441734316577197, 3.6660605559646724, 3.687817782917155, 3.709447398198282, 3.7309516212355263, 3.752332607858744, 3.7735924528226414, 3.794733192202055, 3.8157568056677826, 3.836665218650176, 3.8574603043971822, 3.8781438859330635, 3.8987177379235853, 3.9191835884530852, 3.9395431207184424, 3.9597979746446663, 3.9799497484264803, 4.0, 4.019950248448357], [0.0, 0.41231056256176607, 0.58309518948453, 0.7141428428542851, 0.8246211251235321, 0.9219544457292888, 1.0099504938362078, 1.0908712114635715, 1.16619037896906, 1.236931687685298, 1.3038404810405297, 1.3674794331177345, 1.4282856857085702, 1.4866068747318506, 1.5427248620541512, 1.5968719422671311, 1.6492422502470643, 1.7, 1.7492855684535902, 1.797220075561143, 1.8439088914585775, 1.8894443627691184, 1.9339079605813716, 1.977371993328519, 2.0199009876724157, 2.0615528128088303, 2.102379604162864, 2.142428528562855, 2.181742422927143, 2.220360331117452, 2.258317958127243, 2.2956480566497994, 2.33238075793812, 2.3685438564654024, 2.4041630560342617, 2.4392621835300936, 2.473863375370596, 2.5079872407968904, 2.541653005427767, 2.574878637916747, 2.6076809620810595, 2.6400757564888173, 2.672077843177478, 2.7037011669191546, 2.734958866235469, 2.765863337187866, 2.7964262908219126, 2.826658805020514, 2.8565713714171403, 2.8861739379323623, 2.9154759474226504, 2.944486372867092, 2.973213749463701, 3.001666203960727, 3.0298514815086235, 3.0577769702841313, 3.0854497241083023, 3.1128764832546763, 3.1400636936215167, 3.167017524422623, 3.1937438845342623, 3.2202484376209237, 3.246536616149585, 3.2726136343907144, 3.2984845004941286, 3.324154027718932, 3.3496268448888453, 3.374907406137241, 3.4, 3.424908757908742, 3.4496376621320683, 3.4741905532080417, 3.4985711369071804, 3.522782990761707, 3.5468295701936396, 3.570714214271425, 3.594440151122286, 3.6180105030251086, 3.6414282912066254, 3.664696440361739, 3.687817782917155, 3.710795063055895, 3.733630940518894, 3.7563279941985894, 3.778888725538237, 3.8013155617496426, 3.8236108588610325, 3.845776904605882, 3.867815921162743, 3.8897300677553446, 3.9115214431215892, 3.9331920878594273, 3.954743986657038, 3.976179070414209, 3.9974992182613374, 4.018706259482023, 4.039801975344831, 4.060788100849391, 4.08166632639171, 4.102438299353203, 4.123105625617661, 4.1436698710201325], [0.0, 0.4242640687119285, 0.6, 0.7348469228349536, 0.848528137423857, 0.9486832980505139, 1.0392304845413265, 1.1224972160321824, 1.2, 1.2727922061357855, 1.3416407864998738, 1.407124727947029, 1.4696938456699071, 1.5297058540778357, 1.5874507866387544, 1.6431676725154982, 1.697056274847714, 1.7492855684535902, 1.8, 1.8493242008906932, 1.8973665961010278, 1.9442222095223582, 1.98997487421324, 2.0346989949375804, 2.078460969082653, 2.121320343559643, 2.1633307652783937, 2.2045407685048604, 2.244994432064365, 2.2847319317591728, 2.32379000772445, 2.3622023622035435, 2.4, 2.4372115213907883, 2.4738633753705965, 2.5099800796022267, 2.545584412271571, 2.5806975801127883, 2.615339366124404, 2.6495282598983545, 2.6832815729997477, 2.716615541441225, 2.749545416973504, 2.782085548648711, 2.814249455894058, 2.846049894151541, 2.877498913987632, 2.9086079144497976, 2.9393876913398143, 2.9698484809834995, 3.0, 3.029851481508624, 3.0594117081556713, 3.0886890422961004, 3.1176914536239795, 3.146426544510455, 3.1749015732775088, 3.2031234756093934, 3.2310988842807027, 3.2588341473600644, 3.2863353450309964, 3.3136083051561784, 3.340658617698013, 3.3674916480965473, 3.394112549695428, 3.420526275297414, 3.4467375879228173, 3.4727510708370675, 3.4985711369071804, 3.5242020373412193, 3.5496478698597698, 3.5749125863438955, 3.6, 3.6249137920783716, 3.6496575181789317, 3.6742346141747673, 3.6986484017813863, 3.722902093797257, 3.7469987990390394, 3.7709415269929605, 3.7947331922020555, 3.8183766184073566, 3.84187454245971, 3.8652296180175374, 3.8884444190447165, 3.9115214431215897, 3.9344631145812006, 3.957271787481876, 3.97994974842648, 4.0024992192379, 4.024922359499621, 4.047221268969612, 4.069397989875161, 4.091454509095757, 4.113392760240627, 4.135214625627066, 4.156921938165306, 4.178516483155236, 4.2, 4.221374183841087, 4.242640687119286, 4.263801121065569], [0.0, 0.43588989435406744, 0.6164414002968976, 0.7549834435270751, 0.8717797887081349, 0.9746794344808966, 1.0677078252031313, 1.1532562594670797, 1.2328828005937953, 1.307669683062202, 1.3784048752090223, 1.4456832294800963, 1.5099668870541503, 1.5716233645501714, 1.6309506430300091, 1.6881943016134133, 1.7435595774162698, 1.797220075561143, 1.8493242008906932, 1.9000000000000004, 1.9493588689617931, 1.9974984355438181, 2.0445048300260877, 2.0904544960366875, 2.1354156504062627, 2.179449471770337, 2.2226110770892875, 2.2649503305812253, 2.3065125189341593, 2.3473389188611007, 2.3874672772626644, 2.4269322199023198, 2.4657656011875906, 2.503996805109783, 2.5416530054277673, 2.5787593916455256, 2.615339366124404, 2.651414716712571, 2.687005768508881, 2.7221315177632404, 2.7568097504180447, 2.791057147390573, 2.8248893783651075, 2.8583211855912904, 2.8913664589601926, 2.924038303442689, 2.956349099818897, 2.9883105594967874, 3.0199337741083006, 3.051229260478472, 3.082207001484489, 3.1128764832546767, 3.1432467291003428, 3.1733263305244868, 3.203123475609394, 3.232645975048923, 3.2619012860600183, 3.290896534380867, 3.319638534539567, 3.3481338085566414, 3.3763886032268267, 3.4044089061098406, 3.432200460346103, 3.4597687784012394, 3.4871191548325395, 3.5142566781611158, 3.541186241925155, 3.567912554982255, 3.594440151122286, 3.6207733980463352, 3.6469165057620945, 3.672873534441392, 3.6986484017813863, 3.7242448899072147, 3.749666651850535, 3.7749172176353754, 3.8000000000000007, 3.824918299781056, 3.8496753109840323, 3.874274125562104, 3.8987177379235862, 3.9230090491866068, 3.947150871198111, 3.9711459303329564, 3.9949968710876362, 4.018706259482024, 4.042276586281548, 4.065710270051225, 4.0890096600521755, 4.112177038990418, 4.135214625627067, 4.158124577258358, 4.180908992073375, 4.203569911396741, 4.226109321823088, 4.2485291572496005, 4.270831300812525, 4.293017586733137, 4.315089802078284, 4.337049688440289, 4.358898943540674, 4.380639222761903], [0.0, 0.447213595499958, 0.6324555320336759, 0.7745966692414835, 0.894427190999916, 1.0000000000000002, 1.0954451150103324, 1.1832159566199234, 1.2649110640673518, 1.3416407864998738, 1.4142135623730951, 1.4832396974191329, 1.549193338482967, 1.61245154965971, 1.6733200530681511, 1.7320508075688772, 1.788854381999832, 1.8439088914585775, 1.8973665961010278, 1.9493588689617931, 2.0000000000000004, 2.04939015319192, 2.0976176963403033, 2.144761058952722, 2.1908902300206647, 2.23606797749979, 2.280350850198276, 2.3237900077244507, 2.366431913239847, 2.4083189157584592, 2.4494897427831783, 2.489979919597747, 2.5298221281347035, 2.5690465157330262, 2.60768096208106, 2.6457513110645907, 2.6832815729997477, 2.720294101747089, 2.7568097504180447, 2.7928480087537886, 2.8284271247461903, 2.863564212655271, 2.8982753492378883, 2.932575659723036, 2.9664793948382657, 3.0, 3.0331501776206204, 3.0659419433511785, 3.098386676965934, 3.130495168499706, 3.1622776601683795, 3.193743884534263, 3.22490309931942, 3.255764119219942, 3.286335345030997, 3.3166247903554003, 3.3466401061363023, 3.3763886032268267, 3.405877273185281, 3.4351128074635335, 3.4641016151377544, 3.492849839314596, 3.521363372331802, 3.5496478698597698, 3.577708763999664, 3.605551275463989, 3.6331804249169903, 3.6606010435446255, 3.687817782917155, 3.7148351242013424, 3.7416573867739418, 3.768288736283355, 3.7947331922020555, 3.82099463490856, 3.847076812334269, 3.872983346207417, 3.8987177379235862, 3.924283374069717, 3.9496835316263006, 3.9749213828703587, 4.000000000000001, 4.024922359499622, 4.049691346263318, 4.0743097574926725, 4.09878030638384, 4.123105625617661, 4.147288270665545, 4.171330722922843, 4.1952353926806065, 4.219004621945797, 4.242640687119286, 4.266145801540309, 4.289522117905444, 4.312771730569565, 4.335896677735761, 4.358898943540674, 4.3817804600413295, 4.404543109109049, 4.427188724235731, 4.449719092257398, 4.47213595499958, 4.494441010848847], [0.0, 0.45825756949558405, 0.6480740698407861, 0.7937253933193773, 0.9165151389911681, 1.02469507659596, 1.1224972160321824, 1.2124355652982142, 1.2961481396815722, 1.374772708486752, 1.449137674618944, 1.5198684153570665, 1.5874507866387546, 1.6522711641858308, 1.7146428199482247, 1.7748239349298847, 1.8330302779823362, 1.8894443627691184, 1.9442222095223582, 1.9974984355438181, 2.04939015319192, 2.1, 2.149418526020468, 2.1977260975835913, 2.244994432064365, 2.2912878474779204, 2.336664289109585, 2.381176179958132, 2.4248711305964283, 2.4677925358506134, 2.5099800796022267, 2.551470164434615, 2.5922962793631443, 2.632489316217637, 2.672077843177478, 2.711088342345192, 2.749545416973504, 2.787471972953271, 2.824889378365107, 2.861817604250837, 2.898275349237888, 2.934280150224242, 2.9698484809835, 3.004995840263344, 3.039736830714133, 3.0740852297878796, 3.108054053584011, 3.1416556144810017, 3.174901573277509, 3.2078029864690882, 3.2403703492039306, 3.272613634390715, 3.3045423283716615, 3.336165463522456, 3.3674916480965478, 3.398529093593286, 3.4292856398964493, 3.459768778401239, 3.48998567332303, 3.5199431813596083, 3.5496478698597693, 3.5791060336346563, 3.608323710533743, 3.6373066958946425, 3.6660605559646724, 3.6945906403822333, 3.722902093797257, 3.7509998667022106, 3.778888725538237, 3.8065732621348563, 3.834057902536163, 3.861346915261565, 3.8884444190447165, 3.915354390090379, 3.9420806688854046, 3.968626966596886, 3.9949968710876362, 4.02119385257662, 4.047221268969613, 4.07308237088326, 4.09878030638384, 4.124318125460256, 4.149698784249287, 4.174925149029621, 4.2, 4.224926034855522, 4.249705872175156, 4.274342054632503, 4.298837052040936, 4.323193264243457, 4.347413023856832, 4.371498598878879, 4.3954521951671826, 4.419275958796871, 4.442971978304612, 4.466542286825459, 4.48998886412873, 4.513313638558704, 4.536518488885503, 4.559605246071199, 4.582575694955841, 4.605431575867782], [0.0, 0.469041575982343, 0.6633249580710799, 0.8124038404635961, 0.938083151964686, 1.0488088481701516, 1.148912529307606, 1.2409673645990857, 1.3266499161421599, 1.407124727947029, 1.4832396974191326, 1.5556349186104048, 1.6248076809271923, 1.6911534525287764, 1.7549928774784245, 1.816590212458495, 1.876166303929372, 1.9339079605813716, 1.98997487421324, 2.0445048300260877, 2.0976176963403033, 2.149418526020468, 2.2, 2.249444375840399, 2.297825058615212, 2.345207879911715, 2.3916521486202797, 2.4372115213907883, 2.4819347291981715, 2.5258661880630178, 2.569046515733026, 2.6115129714401193, 2.6532998322843198, 2.6944387170614963, 2.734958866235469, 2.7748873851023217, 2.814249455894058, 2.8530685235374214, 2.891366458960192, 2.9291637031753623, 2.9664793948382653, 3.0033314835362415, 3.039736830714133, 3.0757112998459397, 3.1112698372208096, 3.1464265445104544, 3.1811947441173736, 3.2155870381627056, 3.2496153618543846, 3.283291031876401, 3.3166247903554003, 3.3496268448888458, 3.3823069050575527, 3.414674215792775, 3.4467375879228173, 3.4785054261852175, 3.509985754956849, 3.5411862419251547, 3.5721142198983507, 3.602776706930364, 3.63318042491699, 3.6633318168028404, 3.6932370625238775, 3.722902093797257, 3.752332607858744, 3.7815340802378072, 3.81051177665153, 3.8392707640904935, 3.867815921162743, 3.8961519477556315, 3.924283374069717, 3.952214569073901, 3.97994974842648, 4.007492981902776, 4.034848200366403, 4.06201920231798, 4.0890096600521755, 4.115823125451336, 4.1424630354415966, 4.168932717135166, 4.1952353926806065, 4.221374183841087, 4.247352116319061, 4.273172123844299, 4.298837052040936, 4.324349662087931, 4.349712634186309, 4.374928570845472, 4.4, 4.424929377967517, 4.449719092257398, 4.474371464239419, 4.498888751680798, 4.523273151159457, 4.54752680036083, 4.571651780264984, 4.595650117230424, 4.61952378498044, 4.64327470649756, 4.666904755831214, 4.69041575982343, 4.713809499757071], [0.0, 0.479583152331272, 0.6782329983125268, 0.8306623862918077, 0.959166304662544, 1.072380529476361, 1.174734012447073, 1.2688577540449522, 1.3564659966250536, 1.438749456993816, 1.5165750888103102, 1.5905973720586868, 1.6613247725836153, 1.7291616465790585, 1.7944358444926363, 1.857417562100671, 1.918332609325088, 1.977371993328519, 2.0346989949375804, 2.0904544960366875, 2.144761058952722, 2.1977260975835913, 2.249444375840399, 2.3000000000000003, 2.349468024894146, 2.39791576165636, 2.4454038521274972, 2.491987158875423, 2.5377155080899043, 2.582634314028992, 2.6267851073127395, 2.670205984563738, 2.7129319932501073, 2.754995462791183, 2.7964262908219126, 2.8372521918222215, 2.877498913987632, 2.917190429162965, 2.956349099818897, 2.994995826374388, 3.0331501776206204, 3.0708305065568178, 3.108054053584011, 3.1448370387032774, 3.1811947441173736, 3.2171415884290826, 3.252691193458119, 3.2878564445547194, 3.3226495451672307, 3.357082066318904, 3.3911649915626345, 3.4249087579087423, 3.458323293158117, 3.491418050019219, 3.5242020373412197, 3.5566838487557484, 3.5888716889852725, 3.620773398046335, 3.6523964735499352, 3.6837480912787726, 3.714835124201342, 3.745664160065609, 3.7762415176998414, 3.8065732621348563, 3.836665218650176, 3.866522985836241, 3.8961519477556315, 3.9255572852781047, 3.954743986657038, 3.9837168574084183, 4.012480529547776, 4.041039470235351, 4.069397989875161, 4.097560249709576, 4.125530268947254, 4.153311931459037, 4.180908992073375, 4.2083250825001635, 4.235563716909475, 4.262628297189424, 4.289522117905444, 4.316248370981448, 4.342810150121694, 4.369210454990696, 4.3954521951671826, 4.421538193886829, 4.447471191587417, 4.473253849269009, 4.498888751680798, 4.524378410345448, 4.549725266430931, 4.57493169347915, 4.6000000000000005, 4.624932431938872, 4.649731175025068, 4.674398357008098, 4.698936049788292, 4.723346271447818, 4.747630988187688, 4.77179211617606, 4.79583152331272, 4.819751030914357], [0.0, 0.48989794855663565, 0.6928203230275509, 0.8485281374238571, 0.9797958971132713, 1.0954451150103324, 1.2000000000000002, 1.2961481396815722, 1.3856406460551018, 1.469693845669907, 1.5491933384829668, 1.6248076809271923, 1.6970562748477143, 1.7663521732655696, 1.833030277982336, 1.8973665961010275, 1.9595917942265426, 2.0199009876724157, 2.078460969082653, 2.1354156504062627, 2.1908902300206647, 2.244994432064365, 2.297825058615212, 2.349468024894146, 2.4000000000000004, 2.4494897427831783, 2.4979991993593598, 2.5455844122715714, 2.5922962793631443, 2.638181191654584, 2.6832815729997477, 2.727636339397171, 2.7712812921102037, 2.8142494558940583, 2.8565713714171403, 2.898275349237888, 2.939387691339814, 2.979932885150268, 3.0199337741083, 3.0594117081556713, 3.0983866769659336, 3.136877428271625, 3.174901573277509, 3.212475680841802, 3.2496153618543846, 3.2863353450309964, 3.32264954516723, 3.358571124749333, 3.3941125496954285, 3.4292856398964493, 3.464101615137755, 3.498571136907181, 3.532704346531139, 3.5665109000254023, 3.6, 3.6331804249169903, 3.666060555964672, 3.698648401781386, 3.7309516212355263, 3.7629775444453557, 3.794733192202055, 3.8262252939417984, 3.857460304397182, 3.8884444190447165, 3.9191835884530852, 3.9496835316262997, 3.97994974842648, 4.009987531152684, 4.039801975344831, 4.069397989875161, 4.09878030638384, 4.127953488110059, 4.156921938165306, 4.18568990729127, 4.214261501141095, 4.242640687119286, 4.270831300812525, 4.298837052040936, 4.3266615305567875, 4.354308211415448, 4.3817804600413295, 4.409081537009721, 4.436214602563767, 4.463182720884279, 4.48998886412873, 4.5166359162544865, 4.543126676640219, 4.5694638635183455, 4.595650117230424, 4.621688003316537, 4.6475800154489, 4.673328578219169, 4.698936049788292, 4.724404724407087, 4.749736834815168, 4.774934554525329, 4.800000000000001, 4.824935232725928, 4.849742261192857, 4.874423042781577, 4.898979485566357, 4.9234134500364695], [0.0, 0.5, 0.7071067811865476, 0.8660254037844388, 1.0, 1.118033988749895, 1.2247448713915892, 1.3228756555322954, 1.4142135623730951, 1.5, 1.5811388300841898, 1.6583123951777001, 1.7320508075688776, 1.8027756377319948, 1.8708286933869707, 1.9364916731037083, 2.0, 2.0615528128088303, 2.121320343559643, 2.179449471770337, 2.23606797749979, 2.2912878474779204, 2.345207879911715, 2.39791576165636, 2.4494897427831783, 2.5000000000000004, 2.5495097567963927, 2.5980762113533165, 2.6457513110645907, 2.6925824035672523, 2.7386127875258306, 2.783882181415011, 2.8284271247461903, 2.8722813232690148, 2.9154759474226504, 2.958039891549808, 3.0, 3.04138126514911, 3.0822070014844885, 3.1224989991991996, 3.1622776601683795, 3.2015621187164247, 3.2403703492039306, 3.278719262151, 3.3166247903554003, 3.3541019662496843, 3.3911649915626345, 3.4278273002005224, 3.4641016151377553, 3.5, 3.535533905932738, 3.5707142142714257, 3.6055512754639896, 3.64005494464026, 3.6742346141747677, 3.708099243547832, 3.7416573867739413, 3.774917217635375, 3.8078865529319548, 3.840572873934304, 3.8729833462074166, 3.9051248379533274, 3.9370039370059056, 3.968626966596886, 4.0, 4.031128874149275, 4.06201920231798, 4.092676385936225, 4.123105625617661, 4.153311931459037, 4.183300132670378, 4.2130748865881795, 4.242640687119286, 4.272001872658766, 4.301162633521313, 4.330127018922194, 4.358898943540674, 4.387482193696061, 4.415880433163924, 4.444097208657795, 4.47213595499958, 4.500000000000001, 4.527692569068709, 4.55521678957215, 4.582575694955841, 4.609772228646444, 4.636809247747852, 4.663689526544408, 4.69041575982343, 4.716990566028302, 4.743416490252569, 4.769696007084729, 4.79583152331272, 4.821825380496478, 4.847679857416329, 4.873397172404482, 4.898979485566357, 4.924428900898053, 4.949747468305833, 4.974937185533101, 5.000000000000001, 5.024937810560446], [0.0, 0.5099019513592785, 0.7211102550927979, 0.8831760866327849, 1.019803902718557, 1.140175425099138, 1.2489995996796799, 1.3490737563232043, 1.4422205101855958, 1.5297058540778354, 1.61245154965971, 1.6911534525287766, 1.7663521732655698, 1.8384776310850237, 1.9078784028338913, 1.9748417658131499, 2.039607805437114, 2.102379604162864, 2.1633307652783937, 2.2226110770892875, 2.280350850198276, 2.336664289109585, 2.3916521486202797, 2.4454038521274972, 2.4979991993593598, 2.5495097567963927, 2.6000000000000005, 2.6495282598983545, 2.6981475126464085, 2.7459060435491964, 2.792848008753788, 2.839013913315678, 2.8844410203711917, 2.9291637031753623, 2.973213749463701, 3.0166206257996713, 3.059411708155671, 3.101612483854165, 3.1432467291003428, 3.1843366656181322, 3.22490309931942, 3.264965543462902, 3.304542328371662, 3.3436506994600976, 3.382306905057553, 3.420526275297414, 3.458323293158117, 3.4957116585897072, 3.5327043465311396, 3.5693136595149495, 3.6055512754639896, 3.6414282912066254, 3.6769552621700474, 3.712142238654118, 3.7469987990390394, 3.7815340802378077, 3.8157568056677826, 3.849675310984032, 3.8832975677895205, 3.916631205513228, 3.9496835316262997, 3.9824615503479754, 4.014971979976946, 4.047221268969613, 4.079215610874228, 4.110960958218893, 4.142463035441596, 4.173727350941841, 4.204759208325728, 4.235563716909475, 4.266145801540309, 4.296510211788167, 4.3266615305567875, 4.356604182158393, 4.386342439892262, 4.415880433163924, 4.445222154178575, 4.474371464239419, 4.503332099679082, 4.532107677449864, 4.560701700396552, 4.589117562233507, 4.617358552246079, 4.645427859734774, 4.67332857821917, 4.701063709417264, 4.7286361670147565, 4.756048780237647, 4.7833042972405595, 4.810405388322278, 4.83735464897913, 4.864154602806124, 4.8908077042549944, 4.917316341257699, 4.943682837723311, 4.969909455915671, 4.9959983987187195, 5.021951811795889, 5.047771785649585, 5.073460357586329, 5.099019513592785, 5.1244511901275835], [0.0, 0.5196152422706632, 0.7348469228349535, 0.9000000000000001, 1.0392304845413265, 1.1618950038622253, 1.2727922061357857, 1.374772708486752, 1.469693845669907, 1.5588457268119895, 1.6431676725154984, 1.7233687939614089, 1.8000000000000003, 1.8734993995195197, 1.9442222095223582, 2.0124611797498106, 2.078460969082653, 2.142428528562855, 2.2045407685048604, 2.2649503305812253, 2.3237900077244507, 2.381176179958132, 2.4372115213907883, 2.491987158875423, 2.5455844122715714, 2.5980762113533165, 2.6495282598983545, 2.7, 2.749545416973504, 2.7982137159266447, 2.8460498941515415, 2.8930952282978866, 2.939387691339814, 2.9849623113198605, 3.0298514815086235, 3.0740852297878796, 3.117691453623979, 3.160696125855822, 3.203123475609394, 3.244996147917591, 3.286335345030997, 3.3271609519228256, 3.3674916480965478, 3.407345007480164, 3.4467375879228177, 3.4856850115866753, 3.5242020373412197, 3.5623026261113755, 3.6000000000000005, 3.6373066958946425, 3.6742346141747677, 3.7107950630558952, 3.7469987990390394, 3.782856063875548, 3.818376618407357, 3.853569773599539, 3.8884444190447165, 3.9230090491866063, 3.957271787481876, 3.9912404086950213, 4.024922359499621, 4.058324777540605, 4.091454509095756, 4.124318125460256, 4.156921938165306, 4.189272013130682, 4.221374183841087, 4.253234063627348, 4.28485705712571, 4.316248370981448, 4.3474130238568325, 4.378355855797928, 4.409081537009721, 4.439594576084623, 4.469899327725402, 4.5, 4.529900661162451, 4.559605246071199, 4.589117562233508, 4.618441295502196, 4.647580015448901, 4.676537180435969, 4.705316142407438, 4.73392015141785, 4.762352359916264, 4.790615826801394, 4.818713521262704, 4.846648326421054, 4.874423042781577, 4.902040391510457, 4.929503017546495, 4.956813492557492, 4.983974317750846, 5.0109879265470205, 5.037856687124, 5.06458290484024, 5.091168824543143, 5.117616632769595, 5.143928459844674, 5.170106381884226, 5.196152422706633, 5.222068555658764], [0.0, 0.5291502622129182, 0.7483314773547882, 0.9165151389911681, 1.0583005244258363, 1.1832159566199234, 1.2961481396815722, 1.4000000000000001, 1.4966629547095764, 1.5874507866387544, 1.6733200530681511, 1.7549928774784245, 1.8330302779823362, 1.9078784028338915, 1.9798989873223332, 2.0493901531919194, 2.1166010488516727, 2.181742422927143, 2.244994432064365, 2.3065125189341593, 2.366431913239847, 2.4248711305964283, 2.4819347291981715, 2.5377155080899043, 2.5922962793631443, 2.6457513110645907, 2.6981475126464085, 2.749545416973504, 2.8000000000000003, 2.8495613697550017, 2.8982753492378874, 2.946183972531247, 2.993325909419153, 3.039736830714133, 3.0854497241083028, 3.1304951684997055, 3.1749015732775088, 3.2186953878862163, 3.2619012860600183, 3.3045423283716615, 3.3466401061363023, 3.3882148692194836, 3.4292856398964497, 3.4698703145794942, 3.509985754956849, 3.5496478698597693, 3.5888716889852725, 3.627671429443411, 3.6660605559646724, 3.704051835490427, 3.7416573867739418, 3.7788887255382373, 3.815756805667783, 3.852272056851645, 3.8884444190447165, 3.924283374069717, 3.9597979746446663, 3.994996871087636, 4.029888335921977, 4.064480286580315, 4.098780306383839, 4.132795663954365, 4.166533331199932, 4.2, 4.233202097703345, 4.266145801540308, 4.298837052040936, 4.331281565541543, 4.363484845854286, 4.3954521951671826, 4.427188724235731, 4.458699361921591, 4.48998886412873, 4.521061822182926, 4.551922670696417, 4.58257569495584, 4.613025037868319, 4.64327470649756, 4.67332857821917, 4.703190406521939, 4.732863826479694, 4.762352359916263, 4.791659420284376, 4.82078831727758, 4.849742261192857, 4.878524367060187, 4.907137658554119, 4.935585071701227, 4.963869458396343, 4.991993589739474, 5.019960159204453, 5.047771785649585, 5.075431016179809, 5.10294032886923, 5.130302135352265, 5.15751878329105, 5.184592558726289, 5.2115256883181535, 5.238320341483518, 5.264978632435274, 5.291502622129181, 5.317894320123333], [0.0, 0.5385164807134505, 0.7615773105863909, 0.9327379053088817, 1.077032961426901, 1.2041594578792296, 1.319090595827292, 1.4247806848775009, 1.5231546211727818, 1.6155494421403513, 1.7029386365926402, 1.7860571099491753, 1.8654758106177634, 1.94164878389476, 2.0149441679609885, 2.085665361461421, 2.154065922853802, 2.220360331117452, 2.2847319317591728, 2.3473389188611007, 2.4083189157584592, 2.4677925358506134, 2.5258661880630178, 2.582634314028992, 2.638181191654584, 2.6925824035672523, 2.7459060435491964, 2.7982137159266447, 2.8495613697550017, 2.9000000000000004, 2.9495762407505253, 2.99833287011299, 3.0463092423455636, 3.0935416596516045, 3.1400636936215167, 3.1859064644147983, 3.2310988842807027, 3.2756678708318403, 3.3196385345395667, 3.363034344160048, 3.4058772731852804, 3.448187929913334, 3.48998567332303, 3.531288716601915, 3.5721142198983507, 3.6124783736376886, 3.6523964735499352, 3.691882988394947, 3.7309516212355267, 3.769615364994153, 3.8078865529319548, 3.845776904605883, 3.88329756778952, 3.9204591567825324, 3.957271787481876, 3.993745109543172, 4.029888335921977, 4.065710270051224, 4.101219330881976, 4.136423575989287, 4.171330722922842, 4.205948168962618, 4.240283009422838, 4.274342054632503, 4.308131845707604, 4.341658669218482, 4.374928570845472, 4.407947368106838, 4.440720662234904, 4.473253849269009, 4.505552130427525, 4.537620521815371, 4.5694638635183455, 4.601086828130937, 4.632493928760188, 4.663689526544408, 4.694677837722201, 4.725462940284264, 4.756048780237647, 4.786439177509728, 4.8166378315169185, 4.846648326421054, 4.876474136094644, 4.906118628814432, 4.935585071701227, 4.964876634922565, 4.993996395673509, 5.022947341949744, 5.0517323761260355, 5.0803543183522155, 5.10881590977792, 5.137119815616529, 5.165268628057984, 5.193264869039514, 5.221110992882646, 5.2488093888042835, 5.276362383309168, 5.3037722424704485, 5.331041174104736, 5.358171329847527, 5.385164807134505, 5.412023651093924], [0.0, 0.5477225575051661, 0.7745966692414833, 0.9486832980505139, 1.0954451150103321, 1.2247448713915892, 1.3416407864998738, 1.4491376746189437, 1.5491933384829666, 1.6431676725154982, 1.7320508075688772, 1.816590212458495, 1.8973665961010278, 1.9748417658131499, 2.0493901531919194, 2.1213203435596424, 2.1908902300206643, 2.258317958127243, 2.32379000772445, 2.3874672772626644, 2.4494897427831783, 2.5099800796022267, 2.569046515733026, 2.6267851073127395, 2.6832815729997477, 2.7386127875258306, 2.792848008753788, 2.8460498941515415, 2.8982753492378874, 2.9495762407505253, 2.9999999999999996, 3.049590136395381, 3.098386676965933, 3.146426544510455, 3.1937438845342623, 3.2403703492039297, 3.2863353450309964, 3.331666249791536, 3.376388603226826, 3.420526275297414, 3.4641016151377544, 3.5071355833500366, 3.5496478698597698, 3.5916569992135936, 3.63318042491699, 3.674234614174767, 3.714835124201342, 3.7549966711037173, 3.7947331922020555, 3.8340579025361627, 3.872983346207417, 3.9115214431215892, 3.9496835316262997, 3.9874804074753776, 4.024922359499621, 4.06201920231798, 4.098780306383839, 4.135214625627066, 4.171330722922842, 4.207136793592525, 4.242640687119285, 4.277849927241487, 4.3127717305695645, 4.347413023856832, 4.381780460041329, 4.415880433163923, 4.449719092257397, 4.483302354291978, 4.516635916254486, 4.54972526643093, 4.58257569495584, 4.61519230368573, 4.6475800154489, 4.679743582719036, 4.711687595755898, 4.743416490252569, 4.774934554525329, 4.806245936279166, 4.83735464897913, 4.868264577855234, 4.898979485566357, 4.929503017546495, 4.959838707054898, 4.9899899799498595, 5.019960159204453, 5.049752469181039, 5.079370039680118, 5.10881590977792, 5.138093031466052, 5.167204273105525, 5.196152422706632, 5.224940191045253, 5.253570214625479, 5.282045058497703, 5.310367218940701, 5.338539126015655, 5.366563145999495, 5.394441583704471, 5.422176684690383, 5.449770637375485, 5.477225575051661, 5.504543577809154], [0.0, 0.5567764362830022, 0.7874007874011811, 0.9643650760992957, 1.1135528725660044, 1.2449899597988734, 1.3638181696985856, 1.4730919862656235, 1.5748015748023623, 1.6703293088490065, 1.760681686165901, 1.846618531261939, 1.9287301521985913, 2.0074859899884734, 2.083266665599966, 2.1563858652847823, 2.227105745132009, 2.2956480566497994, 2.3622023622035435, 2.4269322199023198, 2.489979919597747, 2.551470164434615, 2.6115129714401193, 2.670205984563738, 2.727636339397171, 2.783882181415011, 2.839013913315678, 2.8930952282978866, 2.946183972531247, 2.99833287011299, 3.049590136395381, 3.1, 3.1496031496047245, 3.1984371183438953, 3.2465366161495854, 3.2939338184001206, 3.340658617698013, 3.38673884437522, 3.432200460346103, 3.477067730142742, 3.521363372331802, 3.5651086939951777, 3.6083237105337433, 3.6510272527057364, 3.693237062523878, 3.7349698793966195, 3.7762415176998414, 3.817066936798463, 3.8574603043971827, 3.8974350539810154, 3.9370039370059056, 3.9761790704142093, 4.014971979976947, 4.053393639902249, 4.091454509095757, 4.129164564412516, 4.166533331199932, 4.20356991139674, 4.240283009422838, 4.276680956068619, 4.3127717305695645, 4.34856298103178, 4.384062043356595, 4.419275958796871, 4.454211490264018, 4.488875137492688, 4.523273151159456, 4.557411546042337, 4.591296113299599, 4.624932431938872, 4.658325879540847, 4.69148164229596, 4.724404724407087, 4.757099956906519, 4.789572005931219, 4.8218253804964775, 4.8538644398046396, 4.8856934001224435, 4.917316341257699, 4.948737212663449, 4.979959839195494, 5.01098792654702, 5.041825066382213, 5.072474741188959, 5.10294032886923, 5.13322510708424, 5.163332257370235, 5.193264869039514, 5.223025942880239, 5.252618394667558, 5.282045058497703, 5.3113086899558, 5.340411969127476, 5.36935750346352, 5.398147830506312, 5.426785420486054, 5.455272678794342, 5.483611948342078, 5.511805511808268, 5.539855593785817, 5.567764362830022, 5.595533933415113], [0.0, 0.565685424949238, 0.7999999999999999, 0.9797958971132713, 1.131370849898476, 1.2649110640673518, 1.3856406460551018, 1.4966629547095764, 1.5999999999999999, 1.697056274847714, 1.7888543819998317, 1.876166303929372, 1.9595917942265426, 2.039607805437114, 2.116601048851672, 2.1908902300206643, 2.262741699796952, 2.33238075793812, 2.4, 2.4657656011875906, 2.5298221281347035, 2.5922962793631443, 2.6532998322843198, 2.7129319932501073, 2.7712812921102037, 2.8284271247461903, 2.8844410203711917, 2.939387691339814, 2.993325909419153, 3.0463092423455636, 3.098386676965933, 3.1496031496047245, 3.1999999999999997, 3.249615361854384, 3.2984845004941286, 3.3466401061363023, 3.394112549695428, 3.4409301068170506, 3.487119154832539, 3.5327043465311387, 3.5777087639996634, 3.622154055254967, 3.6660605559646724, 3.709447398198281, 3.752332607858744, 3.7947331922020546, 3.8366652186501757, 3.878143885933063, 3.9191835884530852, 3.959797974644666, 4.0, 4.039801975344831, 4.079215610874228, 4.118252056394801, 4.156921938165306, 4.1952353926806065, 4.233202097703344, 4.2708313008125245, 4.308131845707603, 4.345112196480086, 4.381780460041329, 4.418144406874904, 4.454211490264017, 4.48998886412873, 4.525483399593904, 4.560701700396551, 4.595650117230423, 4.63033476111609, 4.66476151587624, 4.698936049788292, 4.732863826479693, 4.766550115125193, 4.8, 4.833218389437829, 4.866210024238575, 4.898979485566356, 4.931531202375181, 4.963869458396343, 4.995998398718719, 5.027922035990614, 5.059644256269407, 5.091168824543142, 5.122499389946279, 5.15363949069005, 5.184592558726289, 5.215361924162119, 5.2459508194416005, 5.276362383309167, 5.3065996645686395, 5.336665625650533, 5.366563145999495, 5.396295025292816, 5.4258639865002145, 5.455272678794342, 5.4845236803208355, 5.513619500836088, 5.542562584220407, 5.571355310873648, 5.6, 5.628498911788116, 5.656854249492381, 5.685068161420759], [0.0, 0.574456264653803, 0.812403840463596, 0.9949874371066202, 1.148912529307606, 1.2845232578665131, 1.4071247279470291, 1.5198684153570665, 1.624807680927192, 1.7233687939614086, 1.8165902124584952, 1.9052558883257653, 1.9899748742132404, 2.0712315177207983, 2.149418526020468, 2.224859546128699, 2.297825058615212, 2.3685438564654024, 2.4372115213907883, 2.503996805109783, 2.5690465157330262, 2.632489316217637, 2.6944387170614963, 2.754995462791183, 2.8142494558940583, 2.8722813232690148, 2.9291637031753623, 2.9849623113198605, 3.039736830714133, 3.0935416596516045, 3.146426544510455, 3.1984371183438953, 3.249615361854384, 3.3000000000000007, 3.3496268448888458, 3.398529093593286, 3.4467375879228173, 3.49428104193123, 3.541186241925155, 3.58747822293042, 3.6331804249169903, 3.678314831549905, 3.7229020937972575, 3.7669616403674726, 3.8105117766515306, 3.853569773599539, 3.896151947755632, 3.9382737335030438, 3.9799497484264807, 4.02119385257662, 4.06201920231798, 4.102438299353204, 4.1424630354415966, 4.182104733265298, 4.221374183841087, 4.260281680828159, 4.298837052040936, 4.337049688440288, 4.374928570845472, 4.412482294582042, 4.449719092257398, 4.486646854834912, 4.523273151159457, 4.559605246071199, 4.595650117230424, 4.631414470763764, 4.666904755831214, 4.702127178203499, 4.737087712930805, 4.77179211617606, 4.806245936279167, 4.8404545241123795, 4.874423042781577, 4.908156476723211, 4.941659640242335, 4.974937185533101, 5.007993610219566, 5.040833264451424, 5.07346035758633, 5.105878964487898, 5.1380930314660525, 5.170106381884226, 5.201922721455982, 5.23354564325181, 5.264978632435274, 5.296225070746145, 5.327288240746882, 5.358171329847526, 5.388877434122993, 5.419409561935692, 5.449770637375486, 5.479963503528103, 5.509990925582366, 5.539855593785817, 5.569560126257729, 5.599107071667768, 5.628498911788117, 5.657738063926256, 5.686826883245173, 5.715767664977296, 5.7445626465380295, 5.773214009544425], [0.0, 0.5830951894845301, 0.8246211251235321, 1.009950493836208, 1.1661903789690602, 1.30384048104053, 1.4282856857085702, 1.5427248620541514, 1.6492422502470643, 1.7492855684535902, 1.8439088914585775, 1.9339079605813718, 2.019900987672416, 2.102379604162864, 2.181742422927143, 2.258317958127243, 2.3323807579381204, 2.4041630560342617, 2.4738633753705965, 2.5416530054277673, 2.60768096208106, 2.672077843177478, 2.734958866235469, 2.7964262908219126, 2.8565713714171403, 2.9154759474226504, 2.973213749463701, 3.0298514815086235, 3.0854497241083028, 3.1400636936215167, 3.1937438845342623, 3.2465366161495854, 3.2984845004941286, 3.3496268448888458, 3.4000000000000004, 3.449637662132068, 3.4985711369071804, 3.54682957019364, 3.594440151122286, 3.6414282912066254, 3.687817782917155, 3.733630940518894, 3.7788887255382373, 3.823610858861032, 3.8678159211627436, 3.911521443121589, 3.954743986657038, 3.997499218261337, 4.039801975344832, 4.08166632639171, 4.123105625617661, 4.164132562731403, 4.204759208325728, 4.244997055358225, 4.28485705712571, 4.324349662087931, 4.363484845854286, 4.402272140611028, 4.440720662234904, 4.4788391353117385, 4.516635916254486, 4.5541190146942805, 4.591296113299598, 4.628174586162454, 4.664761515876241, 4.701063709417263, 4.737087712930805, 4.77283982551269, 4.8083261120685235, 4.843552415324934, 4.878524367060187, 4.913247398615299, 4.947726750741193, 4.98196748283246, 5.015974481593781, 5.049752469181039, 5.083306010855535, 5.1166395221864125, 5.149757275833494, 5.182663407939976, 5.21536192416212, 5.247856705360771, 5.280151512977635, 5.31224999411737, 5.344155686354956, 5.375872022286245, 5.40740233383831, 5.4387498563548595, 5.469917732470938, 5.500909015790026, 5.531726674375733, 5.562373594069352, 5.592852581643825, 5.62316636780382, 5.653317610041029, 5.683308895353129, 5.713142742834281, 5.742821606144492, 5.772347875864725, 5.801723881744115, 5.830951894845301, 5.860034129593445], [0.0, 0.5916079783099616, 0.8366600265340756, 1.02469507659596, 1.1832159566199232, 1.3228756555322954, 1.449137674618944, 1.5652475842498528, 1.6733200530681511, 1.7748239349298847, 1.8708286933869707, 1.9621416870348585, 2.04939015319192, 2.1330729007701543, 2.2135943621178655, 2.29128784747792, 2.3664319132398464, 2.4392621835300936, 2.5099800796022267, 2.5787593916455256, 2.6457513110645907, 2.711088342345192, 2.7748873851023217, 2.8372521918222215, 2.898275349237888, 2.958039891549808, 3.0166206257996713, 3.0740852297878796, 3.1304951684997055, 3.1859064644147983, 3.2403703492039297, 3.2939338184001206, 3.3466401061363023, 3.398529093593286, 3.449637662132068, 3.5, 3.5496478698597693, 3.5986108430893164, 3.646916505762094, 3.6945906403822333, 3.7416573867739413, 3.7881393849751626, 3.834057902536163, 3.879432948254164, 3.924283374069717, 3.9686269665968856, 4.012480529547776, 4.05585995813465, 4.09878030638384, 4.141255848169731, 4.183300132670378, 4.224926034855522, 4.266145801540309, 4.306971093471606, 4.347413023856832, 4.387482193696061, 4.427188724235731, 4.466542286825459, 4.505552130427525, 4.544227107000705, 4.58257569495584, 4.620606020859168, 4.658325879540846, 4.695742752749559, 4.732863826479693, 4.769696007084728, 4.806245936279166, 4.8425200051213, 4.878524367060187, 4.914264950122246, 4.949747468305833, 4.984977432245807, 5.019960159204453, 5.054700782440045, 5.089204259999788, 5.123475382979799, 5.157518783291051, 5.191338940966964, 5.2249401910452535, 5.2583267300539625, 5.291502622129181, 5.324471804789654, 5.35723809439155, 5.389805191284746, 5.422176684690384, 5.454356057317858, 5.486346689738081, 5.518151864528558, 5.549774770204643, 5.58121850495033, 5.612486080160912, 5.643580423808984, 5.674504383644443, 5.705260730238365, 5.735852159879995, 5.766281297335397, 5.796550698475776, 5.826662852782887, 5.856620185738529, 5.886425061104576, 5.916079783099616, 5.9455865984779], [0.0, 0.6, 0.848528137423857, 1.0392304845413265, 1.2, 1.3416407864998738, 1.469693845669907, 1.5874507866387544, 1.697056274847714, 1.7999999999999998, 1.8973665961010275, 1.98997487421324, 2.078460969082653, 2.1633307652783937, 2.244994432064365, 2.3237900077244498, 2.4, 2.473863375370596, 2.545584412271571, 2.615339366124404, 2.6832815729997477, 2.749545416973504, 2.814249455894058, 2.877498913987632, 2.939387691339814, 3.0, 3.059411708155671, 3.117691453623979, 3.1749015732775088, 3.2310988842807027, 3.2863353450309964, 3.340658617698013, 3.394112549695428, 3.4467375879228173, 3.4985711369071804, 3.5496478698597693, 3.5999999999999996, 3.6496575181789317, 3.698648401781386, 3.746998799039039, 3.794733192202055, 3.8418745424597094, 3.8884444190447165, 3.9344631145812, 3.97994974842648, 4.024922359499621, 4.069397989875161, 4.113392760240626, 4.156921938165306, 4.2, 4.242640687119285, 4.28485705712571, 4.3266615305567875, 4.368065933568311, 4.409081537009721, 4.449719092257398, 4.48998886412873, 4.52990066116245, 4.569463863518345, 4.608687448721165, 4.6475800154488995, 4.686149805543993, 4.724404724407086, 4.762352359916263, 4.8, 4.8373546489791295, 4.874423042781576, 4.91121166312347, 4.947726750741192, 4.983974317750845, 5.019960159204453, 5.0556898639058145, 5.091168824543142, 5.126402247190518, 5.161395160225576, 5.196152422706632, 5.230678732248808, 5.264978632435273, 5.299056519796709, 5.332916650389353, 5.366563145999495, 5.4, 5.43323108288245, 5.466260147486579, 5.499090833947008, 5.531726674375732, 5.5641710972974225, 5.596427431853289, 5.628498911788116, 5.660388679233962, 5.692099788303082, 5.7236352085016735, 5.754997827975264, 5.786190456595773, 5.817215828899595, 5.848076606885377, 5.878775382679628, 5.909314681077663, 5.939696961966999, 5.96992462263972, 6.0, 6.029925372672535], [0.0, 0.608276253029822, 0.8602325267042626, 1.053565375285274, 1.216552506059644, 1.3601470508735445, 1.489966442575134, 1.6093476939431082, 1.7204650534085253, 1.8248287590894658, 1.9235384061671346, 2.017424100183202, 2.107130750570548, 2.193171219946131, 2.2759613353482084, 2.355843797877949, 2.433105012119288, 2.5079872407968904, 2.5806975801127883, 2.651414716712571, 2.720294101747089, 2.787471972953271, 2.8530685235374214, 2.917190429162965, 2.979932885150268, 3.04138126514911, 3.101612483854165, 3.160696125855822, 3.2186953878862163, 3.2756678708318403, 3.331666249791536, 3.38673884437522, 3.4409301068170506, 3.49428104193123, 3.54682957019364, 3.5986108430893164, 3.6496575181789317, 3.7, 3.7496666518505353, 3.7986839826445165, 3.847076812334269, 3.89486841883009, 3.942080668885405, 3.988734135035826, 4.034848200366404, 4.080441152620633, 4.125530268947254, 4.170131892398609, 4.214261501141096, 4.257933771208754, 4.301162633521314, 4.343961325794695, 4.386342439892262, 4.428317965096906, 4.469899327725402, 4.511097427455985, 4.551922670696417, 4.592385001282014, 4.632493928760188, 4.672258554489466, 4.711687595755898, 4.750789408087881, 4.789572005931219, 4.828043081829325, 4.866210024238576, 4.904079934095691, 4.941659640242335, 4.978955713801841, 5.015974481593781, 5.052722038663912, 5.089204259999789, 5.1254268114957995, 5.1613951602255765, 5.197114584074513, 5.232590180780452, 5.26782687642637, 5.302829433425142, 5.3376024580330075, 5.372150407425318, 5.406477596365309, 5.440588203494178, 5.474486277268398, 5.508175741568166, 5.541660400998964, 5.574943945906542, 5.608029957123981, 5.640921910468182, 5.673623181001714, 5.706137047074843, 5.7384666941614295, 5.770615218501404, 5.8025856305616035, 5.83438085832593, 5.866003750424986, 5.897457079114693, 5.928743543112655, 5.959865770300536, 5.990826320300065, 6.021627686929839, 6.052272300549605, 6.08276253029822, 6.113100686231171], [0.0, 0.6164414002968976, 0.8717797887081348, 1.0677078252031313, 1.2328828005937953, 1.3784048752090223, 1.50996688705415, 1.6309506430300091, 1.7435595774162695, 1.849324200890693, 1.949358868961793, 2.0445048300260877, 2.1354156504062627, 2.222611077089287, 2.3065125189341593, 2.3874672772626644, 2.4657656011875906, 2.541653005427767, 2.615339366124404, 2.687005768508881, 2.7568097504180447, 2.824889378365107, 2.891366458960192, 2.956349099818897, 3.0199337741083, 3.0822070014844885, 3.1432467291003428, 3.203123475609394, 3.2619012860600183, 3.3196385345395667, 3.376388603226826, 3.432200460346103, 3.487119154832539, 3.541186241925155, 3.594440151122286, 3.646916505762094, 3.698648401781386, 3.7496666518505353, 3.8000000000000003, 3.8496753109840323, 3.898717737923586, 3.9471508711981107, 3.9949968710876362, 4.042276586281547, 4.0890096600521755, 4.135214625627066, 4.180908992073375, 4.226109321823088, 4.270831300812525, 4.315089802078284, 4.358898943540674, 4.402272140611029, 4.445222154178574, 4.487761134463376, 4.529900661162451, 4.571651780264984, 4.613025037868319, 4.654030511288038, 4.694677837722201, 4.734976240700686, 4.774934554525329, 4.814561246884289, 4.853864439804639, 4.892851929090027, 4.931531202375181, 4.969909455915671, 5.007993610219566, 5.045790324617146, 5.083306010855534, 5.120546845796843, 5.157518783291051, 5.194227565288221, 5.230678732248808, 5.266877632905477, 5.302829433425141, 5.338539126015656, 5.374011537017762, 5.409251334519409, 5.444263035526481, 5.47905101272109, 5.513619500836089, 5.547972602672079, 5.582114294781146, 5.616048432839589, 5.649778756730214, 5.68330889535313, 5.716642371182581, 5.749782604586021, 5.782732917920384, 5.815496539419485, 5.848076606885378, 5.880476171195663, 5.912698199637794, 5.944745579080741, 5.976621118993575, 6.008327554319921, 6.0398675482166, 6.071243694664217, 6.102458520956943, 6.133514490078262, 6.164414002968977, 6.1951594006934165], [0.0, 0.6244997998398399, 0.8831760866327847, 1.081665382639197, 1.2489995996796799, 1.3964240043768943, 1.5297058540778357, 1.6522711641858308, 1.7663521732655694, 1.8734993995195195, 1.97484176581315, 2.0712315177207983, 2.163330765278394, 2.2516660498395407, 2.3366642891095846, 2.4186773244895647, 2.4979991993593598, 2.574878637916747, 2.6495282598983545, 2.7221315177632404, 2.7928480087537886, 2.861817604250837, 2.9291637031753623, 2.994995826374388, 3.0594117081556713, 3.1224989991991996, 3.1843366656181322, 3.244996147917591, 3.3045423283716615, 3.363034344160048, 3.420526275297414, 3.477067730142742, 3.5327043465311387, 3.58747822293042, 3.6414282912066254, 3.6945906403822333, 3.746998799039039, 3.7986839826445165, 3.8496753109840323, 3.900000000000001, 3.9496835316263, 3.9987498046264416, 4.047221268969613, 4.095119045888654, 4.1424630354415966, 4.189272013130682, 4.235563716909475, 4.281354925721529, 4.326661530556788, 4.371498598878879, 4.415880433163924, 4.459820624195553, 4.503332099679081, 4.546427168667723, 4.589117562233507, 4.631414470763765, 4.673328578219169, 4.7148700936505135, 4.756048780237647, 4.796873982084583, 4.8373546489791295, 4.87749935930288, 4.917316341257699, 4.956813492557492, 4.9959983987187195, 5.034878350069642, 5.073460357586329, 5.111751167652823, 5.149757275833494, 5.187484939737176, 5.2249401910452535, 5.262128846769148, 5.299056519796709, 5.335728628781641, 5.372150407425317, 5.408326913195984, 5.444263035526481, 5.479963503528103, 5.515432893255072, 5.550675634551168, 5.585696017507577, 5.620498198558559, 5.655086206239478, 5.68946394662977, 5.723635208501674, 5.757603668193913, 5.791372894228104, 5.8249463516842805, 5.858327406350725, 5.8915193286621745, 5.92452529743945, 5.957348403442593, 5.989991652748776, 6.02245796996542, 6.054750201288242, 6.08687111741328, 6.118823416311343, 6.150609725872713, 6.182232606429493, 6.213694553162394, 6.244997998398399, 6.276145313805283], [0.0, 0.6324555320336759, 0.8944271909999159, 1.0954451150103324, 1.2649110640673518, 1.4142135623730951, 1.5491933384829668, 1.6733200530681511, 1.7888543819998317, 1.8973665961010275, 2.0, 2.0976176963403033, 2.1908902300206647, 2.280350850198276, 2.3664319132398464, 2.449489742783178, 2.5298221281347035, 2.6076809620810595, 2.6832815729997477, 2.7568097504180447, 2.8284271247461903, 2.898275349237888, 2.9664793948382653, 3.0331501776206204, 3.0983866769659336, 3.1622776601683795, 3.22490309931942, 3.286335345030997, 3.3466401061363023, 3.4058772731852804, 3.4641016151377544, 3.521363372331802, 3.5777087639996634, 3.6331804249169903, 3.687817782917155, 3.7416573867739413, 3.794733192202055, 3.847076812334269, 3.898717737923586, 3.9496835316263, 4.0, 4.049691346263318, 4.09878030638384, 4.147288270665544, 4.1952353926806065, 4.242640687119285, 4.2895221179054435, 4.33589667773576, 4.3817804600413295, 4.427188724235731, 4.47213595499958, 4.5166359162544865, 4.560701700396552, 4.604345773288536, 4.6475800154489, 4.69041575982343, 4.732863826479693, 4.774934554525329, 4.8166378315169185, 4.857983120596447, 4.898979485566356, 4.9396356140913875, 4.979959839195493, 5.019960159204453, 5.059644256269407, 5.0990195135927845, 5.138093031466052, 5.176871642217914, 5.215361924162119, 5.253570214625479, 5.291502622129181, 5.329165037789691, 5.366563145999495, 5.403702434442518, 5.440588203494177, 5.477225575051661, 5.513619500836089, 5.549774770204643, 5.585696017507577, 5.621387729022079, 5.656854249492381, 5.692099788303083, 5.727128425310542, 5.761944116355173, 5.796550698475776, 5.830951894845301, 5.865151319446072, 5.8991524815010505, 5.932958789676531, 5.966573556070519, 6.0, 6.0332412515993425, 6.066300355241241, 6.099180272790763, 6.131883886702357, 6.164414002968976, 6.196773353931867, 6.228964600958975, 6.260990336999411, 6.29285308902091, 6.324555320336759, 6.356099432828282], [0.0, 0.6403124237432849, 0.9055385138137417, 1.1090536506409419, 1.2806248474865698, 1.4317821063276355, 1.5684387141358125, 1.6941074346097418, 1.8110770276274835, 1.9209372712298547, 2.024845673131659, 2.1236760581595306, 2.2181073012818837, 2.3086792761230397, 2.395829710142188, 2.479919353527449, 2.5612496949731396, 2.6400757564888173, 2.716615541441225, 2.791057147390573, 2.863564212655271, 2.934280150224242, 3.0033314835362415, 3.0708305065568178, 3.136877428271625, 3.2015621187164247, 3.264965543462902, 3.3271609519228256, 3.3882148692194836, 3.448187929913334, 3.5071355833500366, 3.5651086939951777, 3.622154055254967, 3.678314831549905, 3.733630940518894, 3.7881393849751626, 3.8418745424597094, 3.89486841883009, 3.9471508711981107, 3.9987498046264416, 4.049691346263318, 4.1000000000000005, 4.149698784249287, 4.198809355043403, 4.247352116319061, 4.295346318982906, 4.342810150121693, 4.389760813529594, 4.436214602563767, 4.4821869662029945, 4.527692569068709, 4.572745346069471, 4.617358552246079, 4.661544808322667, 4.705316142407437, 4.748684028233507, 4.791659420284376, 4.8342527861087286, 4.876474136094644, 4.9183330509431755, 4.959838707054898, 5.000999900019996, 5.041825066382213, 5.082322303829225, 5.122499389946279, 5.162363799656123, 5.201922721455982, 5.241183072551464, 5.280151512977635, 5.3188344587888805, 5.35723809439155, 5.395368384086485, 5.43323108288245, 5.470831746635972, 5.508175741568165, 5.545268253204709, 5.582114294781146, 5.61871871515206, 5.655086206239478, 5.691221310052879, 5.727128425310542, 5.762811813689565, 5.798275605729691, 5.833523806414096, 5.868560300448484, 5.903388857258177, 5.93801313572141, 5.9724366886556455, 6.006662967072483, 6.040695324215583, 6.074537019394977, 6.1081912216301815, 6.1416610131136355, 6.174949392505174, 6.208059278067504, 6.24099351065197, 6.27375485654325, 6.306346010171025, 6.338769596696192, 6.3710281744785915, 6.403124237432849, 6.435060217278469], [0.0, 0.6480740698407861, 0.9165151389911681, 1.1224972160321827, 1.2961481396815722, 1.4491376746189442, 1.5874507866387546, 1.7146428199482249, 1.8330302779823362, 1.9442222095223582, 2.04939015319192, 2.149418526020468, 2.2449944320643653, 2.336664289109585, 2.4248711305964283, 2.5099800796022267, 2.5922962793631443, 2.672077843177478, 2.749545416973504, 2.8248893783651075, 2.8982753492378883, 2.9698484809835, 3.039736830714133, 3.108054053584011, 3.174901573277509, 3.2403703492039306, 3.304542328371662, 3.3674916480965478, 3.4292856398964497, 3.48998567332303, 3.5496478698597698, 3.6083237105337433, 3.6660605559646724, 3.7229020937972575, 3.7788887255382373, 3.834057902536163, 3.8884444190447165, 3.942080668885405, 3.9949968710876362, 4.047221268969613, 4.09878030638384, 4.149698784249287, 4.200000000000001, 4.249705872175156, 4.298837052040936, 4.347413023856832, 4.3954521951671826, 4.442971978304612, 4.489988864128731, 4.536518488885503, 4.582575694955841, 4.628174586162455, 4.67332857821917, 4.718050444834181, 4.762352359916264, 4.806245936279167, 4.849742261192857, 4.892851929090027, 4.935585071701227, 4.9779513858614575, 5.019960159204453, 5.061620293937506, 5.10294032886923, 5.143928459844674, 5.184592558726289, 5.224940191045253, 5.264978632435274, 5.304714883949938, 5.344155686354956, 5.383307533477909, 5.422176684690385, 5.46076917659042, 5.499090833947008, 5.537147279962851, 5.574943945906542, 5.612486080160912, 5.649778756730215, 5.686826883245173, 5.723635208501675, 5.760208329565868, 5.796550698475777, 5.832666628567075, 5.868560300448485, 5.904235767650205, 5.939696961967, 5.974947698515863, 6.009991680526689, 6.044832503882966, 6.079473661428266, 6.113918547053109, 6.148170459575759, 6.182232606429493, 6.216108107168022, 6.249799996799899, 6.283311228962004, 6.316644678941503, 6.349803146555018, 6.38278935889318, 6.4156059729381765, 6.448255578061405, 6.480740698407861, 6.5130637951735135], [0.0, 0.6557438524302001, 0.9273618495495702, 1.1357816691600549, 1.3114877048604001, 1.466287829861518, 1.606237840420901, 1.7349351572897471, 1.8547236990991405, 1.9672315572906, 2.073644135332772, 2.1748563170931545, 2.2715633383201097, 2.364318083507378, 2.453568829277059, 2.5396850198400585, 2.6229754097208002, 2.7037011669191546, 2.782085548648711, 2.8583211855912904, 2.932575659723036, 3.004995840263344, 3.0757112998459397, 3.1448370387032774, 3.212475680841802, 3.278719262151, 3.3436506994600976, 3.407345007480164, 3.4698703145794942, 3.531288716601915, 3.5916569992135936, 3.6510272527057364, 3.709447398198281, 3.7669616403674726, 3.823610858861032, 3.879432948254164, 3.9344631145812, 3.988734135035826, 4.042276586281547, 4.095119045888654, 4.147288270665544, 4.198809355043403, 4.249705872175156, 4.299999999999999, 4.349712634186309, 4.398863489584553, 4.447471191587417, 4.495553358597804, 4.543126676640219, 4.5902069670114, 4.636809247747852, 4.682947789587239, 4.728636167014756, 4.773887304912004, 4.818713521262703, 4.863126566315131, 4.907137658554118, 4.950757517794625, 4.993996395673509, 5.03686410378521, 5.079370039680117, 5.121523210920751, 5.163332257370234, 5.204805471869242, 5.2459508194416005, 5.28677595515452, 5.3272882407468805, 5.367494760127856, 5.407402333838309, 5.447017532558529, 5.486346689738081, 5.525395913416522, 5.564171097297422, 5.602677931132575, 5.6409219104681805, 5.678908345800274, 5.716642371182581, 5.754128952326321, 5.791372894228104, 5.8283788483591215, 5.865151319446072, 5.9016946718718, 5.938013135721409, 5.974110812497538, 6.009991680526688, 6.0456596000767355, 6.081118318204308, 6.1163714733492105, 6.151422599691879, 6.186275131288617, 6.220932405998315, 6.255397669213365, 6.289674077406555, 6.323764701504951, 6.357672530100933, 6.3914004725099165, 6.424951361683604, 6.458327956987009, 6.491532946846992, 6.524568951279464, 6.557438524302, 6.590144156238162], [0.0, 0.66332495807108, 0.938083151964686, 1.148912529307606, 1.32664991614216, 1.4832396974191329, 1.6248076809271923, 1.7549928774784245, 1.876166303929372, 1.98997487421324, 2.0976176963403033, 2.2, 2.297825058615212, 2.3916521486202797, 2.4819347291981715, 2.569046515733026, 2.65329983228432, 2.734958866235469, 2.814249455894058, 2.8913664589601926, 2.9664793948382657, 3.039736830714133, 3.1112698372208096, 3.1811947441173736, 3.2496153618543846, 3.3166247903554003, 3.382306905057553, 3.4467375879228177, 3.509985754956849, 3.5721142198983507, 3.63318042491699, 3.693237062523878, 3.752332607858744, 3.8105117766515306, 3.8678159211627436, 3.924283374069717, 3.97994974842648, 4.034848200366404, 4.0890096600521755, 4.1424630354415966, 4.1952353926806065, 4.247352116319061, 4.298837052040936, 4.349712634186309, 4.4, 4.449719092257398, 4.498888751680798, 4.54752680036083, 4.595650117230424, 4.64327470649756, 4.69041575982343, 4.737087712930806, 4.7833042972405595, 4.829078587059855, 4.874423042781577, 4.919349550499538, 4.963869458396343, 5.007993610219566, 5.051732376126036, 5.095095681142799, 5.138093031466052, 5.180733538795447, 5.223025942880239, 5.264978632435274, 5.30659966456864, 5.347896782848375, 5.388877434122993, 5.429548784199292, 5.469917732470938, 5.509990925582365, 5.549774770204644, 5.589275444992849, 5.628498911788116, 5.667450926121902, 5.706137047074843, 5.7445626465380295, 5.782732917920385, 5.8206528843421, 5.858327406350725, 5.895761189193471, 5.9329587896765315, 5.969924622639721, 6.006662967072484, 6.043177971895251, 6.079473661428266, 6.115553940568263, 6.15142259969188, 6.187083319303208, 6.222539674441619, 6.2577951388648065, 6.29285308902091, 6.327716807822551, 6.362389488234747, 6.3968742366877915, 6.431174076325411, 6.465291950097845, 6.499230723708769, 6.532993188424431, 6.566582063752802, 6.600000000000001, 6.6332495807108005, 6.666333324999584], [0.0, 0.6708203932499369, 0.9486832980505137, 1.161895003862225, 1.3416407864998738, 1.5, 1.6431676725154982, 1.7748239349298847, 1.8973665961010273, 2.0124611797498106, 2.1213203435596424, 2.224859546128699, 2.32379000772445, 2.4186773244895647, 2.5099800796022262, 2.5980762113533156, 2.6832815729997477, 2.765863337187866, 2.846049894151541, 2.924038303442689, 3.0, 3.0740852297878796, 3.1464265445104544, 3.2171415884290826, 3.2863353450309964, 3.3541019662496843, 3.420526275297414, 3.4856850115866753, 3.5496478698597693, 3.6124783736376886, 3.674234614174767, 3.7349698793966195, 3.7947331922020546, 3.853569773599539, 3.911521443121589, 3.9686269665968856, 4.024922359499621, 4.080441152620633, 4.135214625627066, 4.189272013130682, 4.242640687119285, 4.295346318982906, 4.347413023856832, 4.398863489584553, 4.449719092257398, 4.499999999999999, 4.54972526643093, 4.598912915026768, 4.6475800154489, 4.695742752749558, 4.743416490252569, 4.790615826801393, 4.8373546489791295, 4.883646178829912, 4.9295030175464944, 4.9749371855331, 5.0199601592044525, 5.064582904840239, 5.10881590977792, 5.1526692111953, 5.196152422706631, 5.239274758971893, 5.282045058497702, 5.324471804789654, 5.366563145999495, 5.4083269131959835, 5.449770637375485, 5.490901565316937, 5.531726674375732, 5.572252686302012, 5.612486080160912, 5.652433104425031, 5.692099788303082, 5.731491952362839, 5.770615218501403, 5.809475019311125, 5.848076606885378, 5.886425061104575, 5.92452529743945, 5.962382074305537, 6.0, 6.037383539249432, 6.074537019394977, 6.111464636239008, 6.148170459575759, 6.18465843842649, 6.220932405998316, 6.256996084384263, 6.292853089020909, 6.328506932918695, 6.363961030678928, 6.399218702310462, 6.434283176858165, 6.469157595854347, 6.5038450166036395, 6.53834841531101, 6.572670690061993, 6.606814663663572, 6.640783086353596, 6.674578638386096, 6.7082039324993685, 6.74166151627327], [0.0, 0.6782329983125268, 0.9591663046625439, 1.1747340124470733, 1.3564659966250536, 1.5165750888103102, 1.661324772583615, 1.7944358444926363, 1.9183326093250879, 2.0346989949375804, 2.1447610589527217, 2.249444375840399, 2.3494680248941466, 2.445403852127497, 2.5377155080899043, 2.626785107312739, 2.7129319932501073, 2.7964262908219126, 2.877498913987632, 2.956349099818897, 3.0331501776206204, 3.108054053584011, 3.1811947441173736, 3.252691193458119, 3.32264954516723, 3.3911649915626345, 3.458323293158117, 3.5242020373412197, 3.5888716889852725, 3.6523964735499352, 3.714835124201342, 3.7762415176998414, 3.8366652186501757, 3.896151947755632, 3.954743986657038, 4.012480529547776, 4.069397989875161, 4.125530268947254, 4.180908992073375, 4.235563716909475, 4.2895221179054435, 4.342810150121693, 4.3954521951671826, 4.447471191587417, 4.498888751680798, 4.54972526643093, 4.6000000000000005, 4.649731175025068, 4.698936049788293, 4.747630988187688, 4.79583152331272, 4.843552415324934, 4.890807704254994, 4.937610758251404, 4.983974317750845, 5.029910535983717, 5.075431016179809, 5.120546845796843, 5.165268628057984, 5.209606511052442, 5.253570214625478, 5.297169055259611, 5.340411969127476, 5.383307533477908, 5.4258639865002145, 5.468089245796926, 5.509990925582365, 5.551576352712804, 5.592852581643825, 5.63382640840131, 5.674504383644443, 5.71489282489182, 5.754997827975264, 5.794825277780168, 5.834380858325929, 5.873670062235366, 5.912698199637794, 5.951470406546605, 5.989991652748776, 6.028266749240615, 6.066300355241241, 6.104096984812742, 6.1416610131136355, 6.178996682310163, 6.216108107168022, 6.252999280345393, 6.289674077406556, 6.326136261573884, 6.362389488234747, 6.398437309218556, 6.434283176858165, 6.469930447848725, 6.505382386916238, 6.540642170307134, 6.57571288910944, 6.6105975524153635, 6.64529909033446, 6.679820356865895, 6.714164132637808, 6.748333127521196, 6.782329983125269, 6.81615727518079], [0.0, 0.6855654600401044, 0.9695359714832658, 1.187434208703792, 1.3711309200802089, 1.5329709716755893, 1.6792855623746665, 1.8138357147217055, 1.9390719429665315, 2.056696380120313, 2.16794833886788, 2.273763400180415, 2.374868417407584, 2.471841418861655, 2.565151067676132, 2.6551836094703507, 2.7422618401604177, 2.826658805020514, 2.9086079144497976, 2.9883105594967874, 3.0659419433511785, 3.1416556144810017, 3.2155870381627056, 3.2878564445547194, 3.358571124749333, 3.4278273002005224, 3.4957116585897072, 3.5623026261113755, 3.627671429443411, 3.691882988394947, 3.7549966711037173, 3.817066936798463, 3.878143885933063, 3.9382737335030438, 3.997499218261337, 4.05585995813465, 4.113392760240626, 4.170131892398609, 4.226109321823088, 4.281354925721529, 4.33589667773576, 4.389760813529594, 4.442971978304612, 4.495553358597804, 4.54752680036083, 4.598912915026768, 4.649731175025068, 4.7, 4.749736834815168, 4.798958220280731, 4.847679857416329, 4.89591666595746, 4.94368283772331, 4.990991885387113, 5.037856687124, 5.084289527554465, 5.130302135352264, 5.175905717843014, 5.221110992882646, 5.265928218272634, 5.310367218940701, 5.354437412091022, 5.3981478305063115, 5.441507144165117, 5.4845236803208355, 5.527205442174191, 5.569560126257728, 5.61159513863928, 5.653317610041028, 5.69473440996154, 5.735852159879995, 5.776677245614472, 5.817215828899595, 5.857473858242988, 5.897457079114692, 5.937171043518958, 5.976621118993575, 6.015812497078014, 6.054750201288242, 6.09343909463285, 6.131883886702357, 6.17008914036094, 6.208059278067503, 6.245798587850876, 6.2833112289620034, 6.320601237224193, 6.357672530100934, 6.394528911499267, 6.431174076325411, 6.4676116148080505, 6.5038450166036395, 6.539877674696982, 6.575712889109439, 6.611353870426239, 6.646803743153547, 6.682065548915245, 6.717142249498666, 6.7520367297579185, 6.786751800382861, 6.821290200541244, 6.855654600401045, 6.889847603539574], [0.0, 0.692820323027551, 0.9797958971132713, 1.2000000000000004, 1.385640646055102, 1.549193338482967, 1.6970562748477143, 1.8330302779823362, 1.9595917942265426, 2.078460969082653, 2.1908902300206647, 2.297825058615212, 2.400000000000001, 2.4979991993593598, 2.5922962793631443, 2.6832815729997477, 2.771281292110204, 2.8565713714171403, 2.9393876913398143, 3.0199337741083006, 3.098386676965934, 3.174901573277509, 3.2496153618543846, 3.3226495451672307, 3.3941125496954285, 3.4641016151377553, 3.5327043465311396, 3.6000000000000005, 3.6660605559646724, 3.7309516212355267, 3.7947331922020555, 3.8574603043971827, 3.9191835884530852, 3.9799497484264807, 4.039801975344832, 4.09878030638384, 4.156921938165306, 4.214261501141096, 4.270831300812525, 4.326661530556788, 4.3817804600413295, 4.436214602563767, 4.489988864128731, 4.543126676640219, 4.595650117230424, 4.6475800154489, 4.698936049788293, 4.749736834815168, 4.800000000000002, 4.849742261192857, 4.898979485566357, 4.947726750741194, 4.9959983987187195, 5.043808085167398, 5.091168824543143, 5.1380930314660525, 5.184592558726289, 5.230678732248809, 5.276362383309169, 5.321653878260029, 5.366563145999495, 5.411099703387474, 5.455272678794342, 5.499090833947009, 5.542562584220408, 5.585696017507577, 5.628498911788117, 5.670978751503131, 5.713142742834281, 5.754997827975265, 5.796550698475777, 5.83780780773057, 5.8787753826796285, 5.9194594347794975, 5.959865770300536, 6.000000000000001, 6.039867548216601, 6.079473661428266, 6.1188234163113435, 6.157921727336262, 6.196773353931868, 6.235382907247959, 6.27375485654325, 6.311893535223801, 6.349803146555018, 6.387487769068526, 6.424951361683605, 6.462197768561406, 6.499230723708769, 6.536053855347277, 6.572670690061994, 6.609084656743323, 6.645299090334461, 6.681317235396028, 6.717142249498667, 6.752777206453653, 6.788225099390857, 6.823488843692794, 6.8585712797928995, 6.893475175845635, 6.9282032302755105, 6.962758074211686], [0.0, 0.7000000000000001, 0.9899494936611665, 1.2124355652982142, 1.4000000000000001, 1.565247584249853, 1.7146428199482247, 1.8520259177452134, 1.979898987322333, 2.1, 2.2135943621178655, 2.32163735324878, 2.4248711305964283, 2.5238858928247927, 2.619160170741759, 2.7110883423451915, 2.8000000000000003, 2.8861739379323623, 2.9698484809834995, 3.051229260478472, 3.130495168499706, 3.2078029864690882, 3.283291031876401, 3.357082066318904, 3.4292856398964493, 3.5, 3.5693136595149495, 3.6373066958946425, 3.704051835490427, 3.769615364994153, 3.8340579025361627, 3.8974350539810154, 3.959797974644666, 4.02119385257662, 4.08166632639171, 4.141255848169731, 4.2, 4.257933771208754, 4.315089802078284, 4.371498598878879, 4.427188724235731, 4.4821869662029945, 4.536518488885503, 4.5902069670114, 4.64327470649756, 4.695742752749558, 4.747630988187688, 4.798958220280731, 4.849742261192857, 4.9, 4.949747468305833, 4.998999899979996, 5.047771785649585, 5.096076922496363, 5.143928459844674, 5.191338940966964, 5.238320341483518, 5.2848841046895245, 5.331041174104736, 5.376802023508025, 5.422176684690383, 5.467174773134658, 5.511805511808268, 5.55607775323564, 5.6000000000000005, 5.643580423808984, 5.686826883245172, 5.729746940310715, 5.772347875864725, 5.814636704042653, 5.856620185738529, 5.898304841223451, 5.939696961966999, 5.980802621722272, 6.021627686929839, 6.06217782649107, 6.102458520956944, 6.142475071174486, 6.182232606429493, 6.221736092120913, 6.260990336999412, 6.300000000000001, 6.338769596696192, 6.377303505401009, 6.4156059729381765, 6.4536811201050215, 6.491532946846993, 6.529165337162171, 6.566582063752802, 6.603786792439623, 6.640783086353597, 6.67757440991862, 6.714164132637808, 6.750555532695069, 6.786751800382861, 6.822756041366274, 6.858571279792899, 6.894200461257274, 6.929646455628165, 6.96491205974634, 7.0, 7.034912934784624], [0.0, 0.7071067811865476, 1.0, 1.2247448713915892, 1.4142135623730951, 1.5811388300841898, 1.7320508075688774, 1.8708286933869709, 2.0, 2.1213203435596424, 2.23606797749979, 2.345207879911715, 2.4494897427831783, 2.5495097567963927, 2.6457513110645907, 2.7386127875258306, 2.8284271247461903, 2.9154759474226504, 3.0, 3.082207001484489, 3.1622776601683795, 3.2403703492039306, 3.3166247903554003, 3.3911649915626345, 3.464101615137755, 3.535533905932738, 3.6055512754639896, 3.6742346141747677, 3.7416573867739418, 3.8078865529319548, 3.872983346207417, 3.9370039370059056, 4.0, 4.06201920231798, 4.123105625617661, 4.183300132670378, 4.242640687119285, 4.301162633521314, 4.358898943540674, 4.415880433163924, 4.47213595499958, 4.527692569068709, 4.582575694955841, 4.636809247747852, 4.69041575982343, 4.743416490252569, 4.79583152331272, 4.847679857416329, 4.898979485566357, 4.949747468305833, 5.000000000000001, 5.04975246918104, 5.099019513592785, 5.147815070493501, 5.196152422706632, 5.244044240850759, 5.291502622129181, 5.338539126015656, 5.385164807134505, 5.431390245600108, 5.477225575051661, 5.522680508593631, 5.5677643628300215, 5.612486080160912, 5.656854249492381, 5.70087712549569, 5.744562646538029, 5.787918451395113, 5.830951894845301, 5.873670062235366, 5.916079783099617, 5.958187643906493, 6.0, 6.041522986797286, 6.082762530298219, 6.123724356957946, 6.164414002968978, 6.2048368229954285, 6.244997998398399, 6.284902544988268, 6.324555320336759, 6.3639610306789285, 6.403124237432849, 6.442049363362563, 6.480740698407861, 6.519202405202649, 6.557438524302001, 6.59545297913646, 6.6332495807108005, 6.670832032063167, 6.708203932499369, 6.745368781616021, 6.782329983125269, 6.8190908484929285, 6.855654600401045, 6.892024376045111, 6.92820323027551, 6.9641941385920605, 7.0, 7.035623639735145, 7.071067811865476, 7.1063352017759485], [0.0, 0.7141428428542851, 1.0099504938362078, 1.2369316876852985, 1.4282856857085702, 1.5968719422671316, 1.7492855684535904, 1.8894443627691186, 2.0199009876724157, 2.142428528562855, 2.2583179581272432, 2.368543856465403, 2.473863375370597, 2.574878637916747, 2.672077843177478, 2.765863337187866, 2.8565713714171403, 2.944486372867092, 3.029851481508624, 3.1128764832546767, 3.193743884534263, 3.272613634390715, 3.3496268448888458, 3.4249087579087423, 3.498571136907181, 3.5707142142714257, 3.6414282912066254, 3.7107950630558952, 3.7788887255382373, 3.845776904605883, 3.9115214431215892, 3.9761790704142093, 4.039801975344831, 4.102438299353204, 4.164132562731403, 4.224926034855522, 4.28485705712571, 4.343961325794695, 4.402272140611029, 4.459820624195553, 4.5166359162544865, 4.572745346069471, 4.628174586162455, 4.682947789587239, 4.737087712930806, 4.790615826801393, 4.843552415324934, 4.89591666595746, 4.947726750741194, 4.998999899979996, 5.04975246918104, 5.100000000000001, 5.149757275833494, 5.199038372622384, 5.247856705360771, 5.296225070746145, 5.344155686354956, 5.391660226683429, 5.43874985635486, 5.485435260760991, 5.531726674375732, 5.577633906953737, 5.62316636780382, 5.668333088307356, 5.713142742834281, 5.757603668193913, 5.801723881744115, 5.845511098270194, 5.888972745734184, 5.932115979985557, 5.974947698515863, 6.017474553332154, 6.059702963017248, 6.101639124038721, 6.143289021363068, 6.184658438426491, 6.225752966509353, 6.266578013557321, 6.307138812488593, 6.347440429023341, 6.387487769068526, 6.427285585688566, 6.466838485689898, 6.506150935845249, 6.54522726878143, 6.584071688552609, 6.62268827591938, 6.661080993352356, 6.6992536897776915, 6.73721010508059, 6.77495387438173, 6.81248853210044, 6.8498175158174845, 6.886944169949399, 6.923871749245506, 6.960603422117942, 6.997142273814362, 7.033491309442276, 7.069653456853455, 7.105631569396208, 7.141428428542851, 7.177046746399247], [0.0, 0.7211102550927979, 1.019803902718557, 1.2489995996796799, 1.4422205101855958, 1.61245154965971, 1.7663521732655696, 1.9078784028338915, 2.039607805437114, 2.1633307652783937, 2.280350850198276, 2.3916521486202797, 2.4979991993593598, 2.6000000000000005, 2.6981475126464085, 2.792848008753788, 2.8844410203711917, 2.973213749463701, 3.0594117081556713, 3.1432467291003428, 3.22490309931942, 3.3045423283716615, 3.3823069050575527, 3.458323293158117, 3.532704346531139, 3.6055512754639896, 3.6769552621700474, 3.7469987990390394, 3.815756805667783, 3.88329756778952, 3.9496835316262997, 4.014971979976947, 4.079215610874228, 4.1424630354415966, 4.204759208325728, 4.266145801540309, 4.3266615305567875, 4.386342439892262, 4.445222154178574, 4.503332099679081, 4.560701700396552, 4.617358552246079, 4.67332857821917, 4.728636167014756, 4.7833042972405595, 4.8373546489791295, 4.890807704254994, 4.94368283772331, 4.9959983987187195, 5.047771785649585, 5.099019513592785, 5.149757275833494, 5.200000000000001, 5.249761899362676, 5.299056519796709, 5.347896782848376, 5.396295025292817, 5.44426303552648, 5.491812087098393, 5.5389529696504916, 5.585696017507576, 5.63205113613149, 5.678027826631356, 5.723635208501674, 5.768882040742383, 5.813776741499453, 5.858327406350725, 5.902541825349482, 5.946427498927402, 5.989991652748776, 6.033241251599343, 6.076183012385325, 6.118823416311343, 6.161168720299745, 6.203224967708329, 6.244997998398398, 6.2864934582006855, 6.327716807822551, 6.3686733312362644, 6.409368143584826, 6.44980619863884, 6.489992295835181, 6.529931086925804, 6.569627082262737, 6.609084656743323, 6.648308055437865, 6.687301398920196, 6.726068688320096, 6.764613810115105, 6.802940540677979, 6.841052550594828, 6.878953408767936, 6.916646586316234, 6.954135460285485, 6.9914233171794145, 7.0285133563222315, 7.065408693062278, 7.102112361825883, 7.138627319029899, 7.17495644586084, 7.211102550927979, 7.247068372797377], [0.0, 0.7280109889280519, 1.0295630140987002, 1.2609520212918495, 1.4560219778561039, 1.627882059609971, 1.7832554500127011, 1.9261360284258224, 2.0591260281974004, 2.1840329667841556, 2.302172886644268, 2.4145392935299275, 2.521904042583699, 2.624880949681338, 2.7239676943752476, 2.819574435974337, 2.9120439557122078, 3.001666203960727, 3.0886890422961004, 3.1733263305244868, 3.255764119219942, 3.336165463522456, 3.414674215792775, 3.491418050019219, 3.5665109000254023, 3.64005494464026, 3.712142238654118, 3.782856063875548, 3.852272056851645, 3.9204591567825324, 3.9874804074753776, 4.053393639902249, 4.118252056394801, 4.182104733265298, 4.244997055358225, 4.306971093471606, 4.368065933568311, 4.428317965096906, 4.487761134463376, 4.546427168667723, 4.604345773288536, 4.661544808322667, 4.718050444834181, 4.773887304912004, 4.829078587059855, 4.883646178829912, 4.937610758251404, 4.990991885387113, 5.043808085167398, 5.096076922496363, 5.147815070493501, 5.199038372622384, 5.249761899362676, 5.300000000000001, 5.349766350038103, 5.399073994677236, 5.447935388750495, 5.496362433464519, 5.5443665102516455, 5.591958512006326, 5.639148871948674, 5.6859475903318, 5.732364259186606, 5.7784080852774675, 5.8240879114244155, 5.869412236331676, 5.914389233048499, 5.959026766175833, 6.003332407921454, 6.047313453096343, 6.090976933136425, 6.134329629226001, 6.177378084592201, 6.220128616033596, 6.262587324740471, 6.304760106459247, 6.3466526610489735, 6.388270501473776, 6.429618962271405, 6.470703207534712, 6.511528238439884, 6.552098900352467, 6.592419889539805, 6.632495759516172, 6.672330927044912, 6.711929677819935, 6.751296171847301, 6.790434448545985, 6.82934843158555, 6.868041933477111, 6.906518659932804, 6.944782214007867, 6.982836100038438, 7.020683727387242, 7.058328414008519, 7.095773389842717, 7.1330218000508046, 7.170076708097342, 7.206941098690901, 7.243617880589783, 7.28010988928052, 7.31641988953614], [0.0, 0.7348469228349535, 1.0392304845413265, 1.2727922061357857, 1.469693845669907, 1.6431676725154984, 1.8, 1.9442222095223582, 2.078460969082653, 2.2045407685048604, 2.32379000772445, 2.4372115213907883, 2.5455844122715714, 2.6495282598983545, 2.749545416973504, 2.846049894151541, 2.939387691339814, 3.0298514815086235, 3.1176914536239795, 3.203123475609394, 3.286335345030997, 3.3674916480965478, 3.4467375879228173, 3.5242020373412197, 3.6, 3.6742346141747677, 3.7469987990390394, 3.818376618407357, 3.8884444190447165, 3.957271787481876, 4.024922359499621, 4.091454509095757, 4.156921938165306, 4.221374183841087, 4.28485705712571, 4.347413023856832, 4.409081537009721, 4.469899327725402, 4.529900661162451, 4.589117562233507, 4.6475800154489, 4.705316142407437, 4.762352359916264, 4.818713521262703, 4.874423042781577, 4.9295030175464944, 4.983974317750845, 5.037856687124, 5.091168824543143, 5.143928459844674, 5.196152422706632, 5.247856705360771, 5.299056519796709, 5.349766350038103, 5.4, 5.449770637375486, 5.499090833947008, 5.547972602672079, 5.596427431853289, 5.644466316668034, 5.692099788303082, 5.739337940912697, 5.786190456595773, 5.8326666285670745, 5.878775382679628, 5.924525297439449, 5.96992462263972, 6.014981296729027, 6.059702963017247, 6.104096984812742, 6.148170459575759, 6.191930232165088, 6.235382907247959, 6.278534860936905, 6.321392251711643, 6.363961030678928, 6.406246951218788, 6.448255578061404, 6.489992295835182, 6.5314623171231725, 6.572670690061994, 6.613622305514581, 6.654321903845651, 6.694774081326419, 6.7349832961930955, 6.77495387438173, 6.814690014960329, 6.854195795277518, 6.8934751758456345, 6.932532004974806, 6.971370023173351, 7.009992867328754, 7.0484040746824395, 7.0866070866106305, 7.124605252222751, 7.162401831787993, 7.2, 7.237402849088892, 7.274613391789285, 7.3116345641723655, 7.348469228349535, 7.385120175054704], [0.0, 0.7416198487095663, 1.0488088481701516, 1.2845232578665131, 1.4832396974191326, 1.6583123951777001, 1.8165902124584952, 1.9621416870348585, 2.0976176963403033, 2.224859546128699, 2.345207879911715, 2.459674775249769, 2.5690465157330262, 2.673948391424188, 2.7748873851023217, 2.8722813232690143, 2.9664793948382653, 3.0577769702841313, 3.146426544510455, 3.232645975048923, 3.3166247903554003, 3.398529093593286, 3.4785054261852175, 3.5566838487557484, 3.6331804249169903, 3.708099243547832, 3.7815340802378077, 3.853569773599539, 3.924283374069717, 3.993745109543172, 4.06201920231798, 4.129164564412516, 4.1952353926806065, 4.260281680828159, 4.324349662087931, 4.387482193696061, 4.449719092257398, 4.511097427455985, 4.571651780264984, 4.631414470763765, 4.69041575982343, 4.748684028233507, 4.806245936279167, 4.863126566315131, 4.919349550499538, 4.9749371855331, 5.029910535983717, 5.084289527554465, 5.1380930314660525, 5.191338940966964, 5.244044240850759, 5.296225070746145, 5.347896782848376, 5.399073994677236, 5.449770637375486, 5.5, 5.549774770204643, 5.599107071667768, 5.648008498577176, 5.6964901474504455, 5.744562646538029, 5.792236183029832, 5.839520528262573, 5.886425061104576, 5.932958789676531, 5.979130371550699, 6.024948132556827, 6.070420084310475, 6.115553940568263, 6.1603571325045765, 6.2048368229954285, 6.248999919987198, 6.29285308902091, 6.336402764976356, 6.3796551630946325, 6.422616289332565, 6.465291950097846, 6.507687761409578, 6.549809157525127, 6.591661399070799, 6.6332495807108005, 6.674578638386097, 6.715653356152327, 6.756478372643548, 6.797058187186572, 6.837397165588672, 6.87749954561976, 6.917369442208505, 6.957010852370435, 6.996427659884722, 7.035623639735144, 7.074602462329597, 7.113367697511497, 7.15192281837549, 7.1902712048990205, 7.2284161474004796, 7.266360849833981, 7.30410843293006, 7.341661937191061, 7.379024325749307, 7.416198487095664, 7.4531872376856345], [0.0, 0.7483314773547883, 1.058300524425836, 1.2961481396815722, 1.4966629547095767, 1.6733200530681511, 1.833030277982336, 1.9798989873223332, 2.116601048851672, 2.244994432064365, 2.3664319132398464, 2.4819347291981715, 2.5922962793631443, 2.6981475126464085, 2.8, 2.8982753492378874, 2.9933259094191533, 3.0854497241083023, 3.1749015732775088, 3.2619012860600183, 3.3466401061363023, 3.4292856398964493, 3.509985754956849, 3.5888716889852725, 3.666060555964672, 3.7416573867739413, 3.8157568056677826, 3.8884444190447165, 3.9597979746446663, 4.029888335921977, 4.098780306383839, 4.166533331199932, 4.233202097703344, 4.298837052040936, 4.363484845854286, 4.427188724235731, 4.48998886412873, 4.551922670696417, 4.613025037868319, 4.673328578219169, 4.732863826479693, 4.791659420284376, 4.849742261192857, 4.907137658554118, 4.963869458396343, 5.0199601592044525, 5.075431016179809, 5.130302135352264, 5.184592558726289, 5.238320341483518, 5.291502622129181, 5.344155686354956, 5.396295025292817, 5.447935388750495, 5.499090833947008, 5.549774770204643, 5.6, 5.649778756730214, 5.6991227395100035, 5.748043145279965, 5.796550698475775, 5.844655678480983, 5.892367945062493, 5.939696961966999, 5.986651818838307, 6.033241251599342, 6.079473661428265, 6.125357132445422, 6.170899448216605, 6.216108107168021, 6.260990336999411, 6.305553108173778, 6.3498031465550175, 6.393746945258312, 6.437390775772432, 6.48074069840786, 6.523802572120037, 6.566582063752802, 6.609084656743323, 6.6513156593263565, 6.6932802122726045, 6.734983296193095, 6.776429738438967, 6.817624219623724, 6.858571279792899, 6.899275324264136, 6.939740629158989, 6.979971346646059, 7.019971509913698, 7.059745037889116, 7.099295739719539, 7.138627319029899, 7.177743377970545, 7.216647421067487, 7.255342858886822, 7.293833011524187, 7.332121111929344, 7.370210309075312, 7.408103670980854, 7.445804187594514, 7.483314773547883, 7.520638270785267], [0.0, 0.754983443527075, 1.0677078252031311, 1.3076696830622023, 1.50996688705415, 1.6881943016134133, 1.849324200890693, 1.997498435543818, 2.1354156504062622, 2.264950330581225, 2.3874672772626644, 2.503996805109783, 2.6153393661244047, 2.72213151776324, 2.824889378365107, 2.924038303442689, 3.0199337741083, 3.1128764832546763, 3.2031234756093934, 3.290896534380867, 3.3763886032268267, 3.459768778401239, 3.5411862419251547, 3.620773398046335, 3.698648401781386, 3.774917217635375, 3.849675310984032, 3.9230090491866063, 3.994996871087636, 4.065710270051224, 4.135214625627066, 4.20356991139674, 4.2708313008125245, 4.337049688440288, 4.402272140611028, 4.466542286825459, 4.52990066116245, 4.592385001282014, 4.654030511288038, 4.7148700936505135, 4.774934554525329, 4.8342527861087286, 4.892851929090027, 4.950757517794625, 5.007993610219566, 5.064582904840239, 5.120546845796843, 5.175905717843014, 5.230678732248809, 5.2848841046895245, 5.338539126015656, 5.391660226683429, 5.44426303552648, 5.496362433464519, 5.547972602672079, 5.599107071667768, 5.649778756730214, 5.7, 5.749782604586021, 5.799137866959191, 5.848076606885378, 5.8966091951222275, 5.944745579080739, 5.9924953066314535, 6.0398675482166, 6.08687111741328, 6.133514490078261, 6.17980582219215, 6.2257529665093525, 6.271363488110062, 6.316644678941503, 6.361603571427569, 6.406246951218787, 6.450581369148055, 6.494613152451807, 6.5383484153110105, 6.581793068761734, 6.624952830020755, 6.667833231267862, 6.710439627923047, 6.752777206453653, 6.794850991743675, 6.836665854054885, 6.878226515607057, 6.919537556802478, 6.960603422117942, 7.001428425685718, 7.042016756583302, 7.0823724838503095, 7.122499561249548, 7.162401831787993, 7.202083032012336, 7.24154679609267, 7.280796659706959, 7.31983606373804, 7.358668357794092, 7.397296803562772, 7.4357245780085215, 7.473954776421918, 7.5119904153293495, 7.54983443527075, 7.587489703452652], [0.0, 0.7615773105863909, 1.0770329614269007, 1.3190905958272923, 1.5231546211727818, 1.7029386365926404, 1.8654758106177631, 2.0149441679609885, 2.1540659228538015, 2.2847319317591723, 2.4083189157584592, 2.525866188063018, 2.6381811916545845, 2.7459060435491964, 2.8495613697550017, 2.9495762407505253, 3.0463092423455636, 3.1400636936215167, 3.2310988842807027, 3.319638534539567, 3.405877273185281, 3.48998567332303, 3.5721142198983507, 3.6523964735499352, 3.7309516212355263, 3.8078865529319548, 3.8832975677895205, 3.957271787481876, 4.029888335921977, 4.101219330881976, 4.171330722922842, 4.240283009422838, 4.308131845707603, 4.374928570845472, 4.440720662234904, 4.505552130427525, 4.569463863518345, 4.632493928760188, 4.694677837722201, 4.756048780237647, 4.8166378315169185, 4.876474136094644, 4.935585071701227, 4.993996395673509, 5.051732376126036, 5.10881590977792, 5.165268628057984, 5.221110992882646, 5.276362383309169, 5.331041174104736, 5.385164807134505, 5.43874985635486, 5.491812087098393, 5.5443665102516455, 5.596427431853289, 5.648008498577176, 5.6991227395100035, 5.749782604586021, 5.800000000000001, 5.849786320883866, 5.8991524815010505, 5.948108943185221, 5.99666574022598, 6.044832503882966, 6.092618484691127, 6.1400325732035, 6.187083319303208, 6.23377895020348, 6.280127387243033, 6.326136261573885, 6.3718129288295975, 6.417164482853779, 6.462197768561405, 6.5069193939989765, 6.55133574166368, 6.59545297913646, 6.639277069079134, 6.682813778641449, 6.726068688320096, 6.76904720030818, 6.811754546370562, 6.854195795277518, 6.8963758598266685, 6.938299503480662, 6.97997134664606, 7.021395872616784, 7.062577433203831, 7.103520254071217, 7.144228439796701, 7.184705978674423, 7.224956747275378, 7.264984514780469, 7.3047929470998705, 7.3443856107914165, 7.383765976789894, 7.4229374239582535, 7.4619032424710525, 7.5006666370396715, 7.539230729988306, 7.577598564189055, 7.6157731058639095, 7.653757247260983], [0.0, 0.7681145747868608, 1.0862780491200215, 1.3304134695650072, 1.5362291495737217, 1.7175564037317668, 1.8814887722226779, 2.0322401432901573, 2.172556098240043, 2.3043437243605824, 2.4289915602982237, 2.5475478405713994, 2.6608269391300143, 2.7694764848252458, 2.8740215726399825, 2.974894956128703, 3.0724582991474434, 3.167017524422623, 3.2588341473600644, 3.3481338085566414, 3.4351128074635335, 3.5199431813596083, 3.602776706930364, 3.6837480912787726, 3.7629775444453557, 3.840572873934304, 3.916631205513228, 3.9912404086950213, 4.064480286580315, 4.136423575989287, 4.207136793592525, 4.276680956068619, 4.345112196480086, 4.412482294582042, 4.4788391353117385, 4.544227107000705, 4.608687448721165, 4.672258554489466, 4.734976240700686, 4.796873982084583, 4.857983120596447, 4.9183330509431755, 4.9779513858614575, 5.03686410378521, 5.095095681142799, 5.1526692111953, 5.209606511052442, 5.265928218272634, 5.321653878260029, 5.376802023508025, 5.431390245600108, 5.485435260760991, 5.5389529696504916, 5.591958512006326, 5.644466316668034, 5.6964901474504455, 5.748043145279965, 5.799137866959191, 5.849786320883866, 5.8999999999999995, 5.949789912257406, 5.999166608788257, 6.048140210014975, 6.096720429870472, 6.144916598294887, 6.192737682156413, 6.240192304729077, 6.287288763847259, 6.334035048845246, 6.380438856379708, 6.4265076052238514, 6.472248450113762, 6.517668294720129, 6.562773803811921, 6.607571414672716, 6.652067347825035, 6.696267617113283, 6.740178039191546, 6.783804242458652, 6.827151675479314, 6.870225614927067, 6.913031173081747, 6.955573304911681, 6.997856814768361, 7.0398863627192165, 7.0816664705420855, 7.123201527403251, 7.164495795239188, 7.205553413860728, 7.246378405796926, 7.286974680894671, 7.327346040688948, 7.367496182557545, 7.407428703673091, 7.447147104764348, 7.486654793697916, 7.525955088890711, 7.565051222562872, 7.603946343840151, 7.642643521714199, 7.681145747868608, 7.719455939378112], [0.0, 0.7745966692414833, 1.0954451150103321, 1.3416407864998738, 1.5491933384829666, 1.7320508075688772, 1.8973665961010275, 2.0493901531919194, 2.1908902300206643, 2.3237900077244498, 2.449489742783178, 2.569046515733026, 2.6832815729997477, 2.792848008753788, 2.8982753492378874, 2.9999999999999996, 3.098386676965933, 3.1937438845342623, 3.2863353450309964, 3.3763886032268267, 3.4641016151377544, 3.5496478698597693, 3.63318042491699, 3.714835124201342, 3.794733192202055, 3.8729833462074166, 3.9496835316262997, 4.024922359499621, 4.098780306383839, 4.171330722922842, 4.242640687119285, 4.3127717305695645, 4.381780460041329, 4.449719092257398, 4.516635916254486, 4.58257569495584, 4.6475800154488995, 4.711687595755898, 4.774934554525329, 4.8373546489791295, 4.898979485566356, 4.959838707054898, 5.019960159204453, 5.079370039680117, 5.138093031466052, 5.196152422706631, 5.253570214625478, 5.310367218940701, 5.366563145999495, 5.422176684690383, 5.477225575051661, 5.531726674375732, 5.585696017507576, 5.639148871948674, 5.692099788303082, 5.744562646538029, 5.796550698475775, 5.848076606885378, 5.8991524815010505, 5.949789912257406, 5.999999999999999, 6.049793384901669, 6.099180272790762, 6.148170459575758, 6.196773353931866, 6.244997998398397, 6.292853089020909, 6.340346993658943, 6.387487769068525, 6.434283176858164, 6.48074069840786, 6.526867548832287, 6.572670690061993, 6.618156843109718, 6.663332499583071, 6.7082039324993685, 6.752777206453653, 6.797058187186571, 6.841052550594828, 6.884765791223402, 6.928203230275509, 6.97137002317335, 7.014271166700073, 7.056911505750939, 7.099295739719539, 7.1414284285428495, 7.183313998427188, 7.224956747275377, 7.26636084983398, 7.307530362578043, 7.348469228349534, 7.389181280764466, 7.429670248402684, 7.469939758793239, 7.5099933422074345, 7.549834435270749, 7.58946638440411, 7.628892449104261, 7.668115805072325, 7.707139547199078, 7.745966692414833, 7.784600182411426], [0.0, 0.7810249675906654, 1.104536101718726, 1.3527749258468684, 1.5620499351813308, 1.746424919657298, 1.9131126469708992, 2.0663978319771825, 2.209072203437452, 2.3430749027719964, 2.4698178070456938, 2.5903667693977237, 2.705549851693737, 2.816025568065745, 2.9223278392404914, 3.0248966924508345, 3.1240998703626617, 3.2202484376209237, 3.3136083051561784, 3.4044089061098406, 3.492849839314596, 3.5791060336346563, 3.6633318168028404, 3.745664160065609, 3.8262252939417984, 3.9051248379533274, 3.9824615503479754, 4.058324777540605, 4.132795663954365, 4.205948168962618, 4.277849927241487, 4.34856298103178, 4.418144406874904, 4.486646854834912, 4.5541190146942805, 4.620606020859168, 4.686149805543993, 4.750789408087881, 4.814561246884289, 4.87749935930288, 4.9396356140913875, 5.000999900019996, 5.061620293937506, 5.121523210920751, 5.180733538795447, 5.239274758971893, 5.297169055259611, 5.354437412091022, 5.411099703387474, 5.467174773134658, 5.522680508593631, 5.577633906953737, 5.63205113613149, 5.6859475903318, 5.739337940912697, 5.792236183029832, 5.844655678480983, 5.8966091951222275, 5.948108943185221, 5.999166608788257, 6.049793384901669, 6.1, 6.149796744608719, 6.199193495931548, 6.248199740725323, 6.296824596572465, 6.345076831686122, 6.392964883369843, 6.440496875241847, 6.487680633323437, 6.534523701081817, 6.5810333535091585, 6.627216610312357, 6.673080248281149, 6.71863081289633, 6.7638746292343415, 6.808817812219681, 6.853466276272176, 6.897825744392215, 6.941901756723442, 6.985699678629192, 7.029224708315989, 7.07248188403477, 7.115476090888086, 7.158212067269313, 7.200694410957877, 7.242927584892728, 7.284915922644544, 7.326663633605681, 7.368174807915458, 7.409453421137082, 7.450503338701353, 7.491328320131218, 7.531932023060219, 7.572318007057021, 7.6124897372673015, 7.652450587883597, 7.692203845452876, 7.731752712031082, 7.771100308193172, 7.810249675906655, 7.849203781276163], [0.0, 0.787400787401181, 1.1135528725660042, 1.3638181696985856, 1.574801574802362, 1.760681686165901, 1.928730152198591, 2.083266665599966, 2.2271057451320084, 2.362202362203543, 2.4899799195977463, 2.6115129714401193, 2.727636339397171, 2.839013913315678, 2.9461839725312466, 3.049590136395381, 3.149603149604724, 3.246536616149585, 3.340658617698013, 3.432200460346103, 3.521363372331802, 3.608323710533743, 3.6932370625238775, 3.7762415176998414, 3.857460304397182, 3.9370039370059056, 4.014971979976946, 4.091454509095756, 4.166533331199932, 4.240283009422838, 4.3127717305695645, 4.384062043356595, 4.454211490264017, 4.523273151159457, 4.591296113299598, 4.658325879540846, 4.724404724407086, 4.789572005931219, 4.853864439804639, 4.917316341257699, 4.979959839195493, 5.041825066382213, 5.10294032886923, 5.163332257370234, 5.223025942880239, 5.282045058497702, 5.340411969127476, 5.3981478305063115, 5.455272678794342, 5.511805511808268, 5.5677643628300215, 5.62316636780382, 5.678027826631356, 5.732364259186606, 5.786190456595773, 5.839520528262573, 5.892367945062493, 5.944745579080739, 5.99666574022598, 6.048140210014975, 6.099180272790762, 6.149796744608719, 6.199999999999999, 6.249799996799897, 6.299206299209448, 6.348228099241551, 6.39687423668779, 6.445153217728807, 6.49307323229917, 6.540642170307133, 6.587867636800241, 6.6347569661593475, 6.681317235396026, 6.727555276621664, 6.773477688750439, 6.819090848492928, 6.864400920692206, 6.90941386804988, 6.954135460285484, 6.998571282769077, 7.042726744663604, 7.08660708661063, 7.130217387990355, 7.173562573784381, 7.216647421067486, 7.259476565152615, 7.302054505411474, 7.344385610791416, 7.386474125047755, 7.428324171709255, 7.469939758793239, 7.511324783285569, 7.552483035399683, 7.593418202627852, 7.634133873596926, 7.674633541739956, 7.714920608794364, 7.754998388136519, 7.79487010796203, 7.834538914320357, 7.874007874011811, 7.913279977354524], [0.0, 0.7937253933193772, 1.1224972160321824, 1.3747727084867523, 1.5874507866387544, 1.7748239349298849, 1.9442222095223582, 2.1, 2.244994432064365, 2.3811761799581315, 2.5099800796022267, 2.632489316217637, 2.7495454169735045, 2.861817604250837, 2.9698484809834995, 3.074085229787879, 3.1749015732775088, 3.2726136343907144, 3.3674916480965473, 3.4597687784012394, 3.5496478698597698, 3.6373066958946425, 3.722902093797257, 3.8065732621348563, 3.8884444190447165, 3.968626966596886, 4.047221268969613, 4.124318125460256, 4.2, 4.274342054632503, 4.347413023856832, 4.419275958796871, 4.48998886412873, 4.559605246071199, 4.628174586162454, 4.695742752749559, 4.762352359916263, 4.828043081829325, 4.892851929090027, 4.956813492557492, 5.019960159204453, 5.082322303829225, 5.143928459844674, 5.204805471869242, 5.264978632435274, 5.324471804789654, 5.383307533477908, 5.441507144165117, 5.499090833947009, 5.55607775323564, 5.612486080160912, 5.668333088307356, 5.723635208501674, 5.7784080852774675, 5.8326666285670745, 5.886425061104576, 5.939696961966999, 5.9924953066314535, 6.044832503882966, 6.096720429870472, 6.148170459575758, 6.199193495931548, 6.249799996799897, 6.3, 6.3498031465550175, 6.3992187023104625, 6.448255578061403, 6.496922348312315, 6.545227268781429, 6.593178292750774, 6.640783086353597, 6.688049042882386, 6.734983296193095, 6.7815927332743895, 6.827884006044625, 6.87386354243376, 6.919537556802479, 6.96491205974634, 7.009992867328754, 7.0547856097829085, 7.0992957397195395, 7.143528539874395, 7.187489130426565, 7.23118247591637, 7.274613391789285, 7.317786550590281, 7.3607064878311785, 7.40337760755184, 7.445804187594514, 7.487990384609211, 7.52994023880668, 7.571657678474378, 7.6131465242697125, 7.654410493303845, 7.695453203028396, 7.736278174936576, 7.776888838089433, 7.817288532477231, 7.857480512225277, 7.897467948652911, 7.937253933193772, 7.976841480185], [0.0, 0.8, 1.131370849898476, 1.385640646055102, 1.6, 1.788854381999832, 1.9595917942265426, 2.1166010488516727, 2.262741699796952, 2.4, 2.5298221281347035, 2.65329983228432, 2.771281292110204, 2.8844410203711917, 2.9933259094191533, 3.098386676965933, 3.2, 3.2984845004941286, 3.394112549695428, 3.4871191548325395, 3.577708763999664, 3.6660605559646724, 3.752332607858744, 3.836665218650176, 3.9191835884530852, 4.0, 4.079215610874228, 4.156921938165306, 4.233202097703345, 4.308131845707604, 4.381780460041329, 4.454211490264018, 4.525483399593904, 4.595650117230424, 4.664761515876241, 4.732863826479693, 4.8, 4.866210024238576, 4.931531202375181, 4.9959983987187195, 5.059644256269407, 5.122499389946279, 5.184592558726289, 5.2459508194416005, 5.30659966456864, 5.366563145999495, 5.4258639865002145, 5.4845236803208355, 5.542562584220408, 5.6000000000000005, 5.656854249492381, 5.713142742834281, 5.768882040742383, 5.8240879114244155, 5.878775382679628, 5.932958789676531, 5.986651818838307, 6.0398675482166, 6.092618484691127, 6.144916598294887, 6.196773353931866, 6.248199740725323, 6.299206299209448, 6.3498031465550175, 6.4, 6.449806198638839, 6.499230723708768, 6.5482822174979605, 6.596969000988257, 6.64529909033446, 6.6932802122726045, 6.740919818541087, 6.788225099390856, 6.835202996254025, 6.881860213634101, 6.92820323027551, 6.974238309665079, 7.019971509913698, 7.065408693062278, 7.110555533852471, 7.155417527999328, 7.2, 7.244308110509934, 7.288346863315439, 7.332121111929345, 7.37563556583431, 7.418894796396564, 7.4619032424710525, 7.504665215717488, 7.547184905645283, 7.58946638440411, 7.631513611335565, 7.673330437300352, 7.7149206087943645, 7.756287771866127, 7.797435475847171, 7.8383671769061705, 7.879086241436885, 7.919595949289333, 7.959899496852961, 8.0, 8.039900496896713], [0.0, 0.8062257748298549, 1.1401754250991378, 1.3964240043768943, 1.6124515496597098, 1.8027756377319946, 1.9748417658131499, 2.133072900770154, 2.2803508501982757, 2.4186773244895647, 2.5495097567963922, 2.6739483914241875, 2.7928480087537886, 2.9068883707497264, 3.016620625799671, 3.1224989991991987, 3.2249030993194197, 3.324154027718932, 3.420526275297414, 3.5142566781611158, 3.605551275463989, 3.6945906403822333, 3.7815340802378072, 3.866522985836241, 3.9496835316262997, 4.031128874149275, 4.110960958218893, 4.189272013130682, 4.266145801540308, 4.341658669218482, 4.415880433163923, 4.488875137492688, 4.560701700396551, 4.631414470763764, 4.701063709417263, 4.769696007084728, 4.8373546489791295, 4.904079934095691, 4.969909455915671, 5.034878350069642, 5.0990195135927845, 5.162363799656123, 5.224940191045253, 5.28677595515452, 5.347896782848375, 5.4083269131959835, 5.468089245796926, 5.527205442174191, 5.585696017507577, 5.643580423808984, 5.70087712549569, 5.757603668193913, 5.813776741499453, 5.869412236331676, 5.924525297439449, 5.979130371550699, 6.033241251599342, 6.08687111741328, 6.1400325732035, 6.192737682156413, 6.244997998398397, 6.296824596572465, 6.348228099241551, 6.3992187023104625, 6.449806198638839, 6.499999999999999, 6.549809157525125, 6.599242380758566, 6.648308055437864, 6.697014260101287, 6.745368781616021, 6.793379129711516, 6.841052550594828, 6.888396039717809, 6.93541635375988, 6.98212002188447, 7.0285133563222315, 7.074602462329597, 7.12039324756716, 7.165891430938652, 7.211102550927978, 7.256031973468694, 7.300684899377592, 7.345066371381541, 7.389181280764467, 7.433034373659253, 7.476630257007497, 7.519973404208288, 7.5630681604756145, 7.6059187479225665, 7.648529270389177, 7.6909037180295, 7.733045971672482, 7.774959806970066, 7.816648898345122, 7.858116822750854, 7.899367063252599, 7.940403012442127, 7.981227975693965, 8.021845174272563, 8.06225774829855, 8.10246875958186], [0.0, 0.812403840463596, 1.1489125293076057, 1.4071247279470291, 1.624807680927192, 1.8165902124584952, 1.98997487421324, 2.149418526020468, 2.2978250586152114, 2.437211521390788, 2.569046515733026, 2.6944387170614963, 2.8142494558940583, 2.9291637031753623, 3.0397368307141326, 3.1464265445104544, 3.249615361854384, 3.3496268448888453, 3.4467375879228173, 3.541186241925155, 3.6331804249169903, 3.722902093797257, 3.81051177665153, 3.8961519477556315, 3.97994974842648, 4.06201920231798, 4.142463035441596, 4.221374183841087, 4.298837052040936, 4.374928570845472, 4.449719092257397, 4.523273151159456, 4.595650117230423, 4.666904755831214, 4.737087712930805, 4.806245936279166, 4.874423042781576, 4.941659640242335, 5.007993610219566, 5.073460357586329, 5.138093031466052, 5.201922721455982, 5.264978632435274, 5.3272882407468805, 5.388877434122993, 5.449770637375485, 5.509990925582365, 5.569560126257728, 5.628498911788117, 5.686826883245172, 5.744562646538029, 5.801723881744115, 5.858327406350725, 5.914389233048499, 5.96992462263972, 6.024948132556827, 6.079473661428265, 6.133514490078261, 6.187083319303208, 6.240192304729077, 6.292853089020909, 6.345076831686122, 6.39687423668779, 6.448255578061403, 6.499230723708768, 6.549809157525125, 6.6, 6.649812027418519, 6.699253689777691, 6.748333127521196, 6.797058187186572, 6.8454364360499325, 6.8934751758456345, 6.941181455631311, 6.988562083862459, 7.035623639735144, 7.08237248385031, 7.128814768248646, 7.17495644586084, 7.2208032794142785, 7.266360849833981, 7.311634564172365, 7.356629663099809, 7.401351227985333, 7.445804187594514, 7.489993324429602, 7.533923280734945, 7.577598564189054, 7.62102355330306, 7.664202502543888, 7.707139547199077, 7.749838707999025, 7.792303895511263, 7.834538914320357, 7.8765474670060875, 7.918333157931661, 7.95989949685296, 8.001249902359007, 8.04238770515324, 8.083316151184489, 8.12403840463596, 8.16455755078008], [0.0, 0.8185352771872451, 1.1575836902790224, 1.4177446878757827, 1.6370705543744901, 1.8303005217723127, 2.004993765576342, 2.1656407827707715, 2.315167380558045, 2.455605831561735, 2.588435821108957, 2.714774392099646, 2.8354893757515653, 2.951270912674741, 3.062678566222711, 3.1701734968294715, 3.2741411087489802, 3.374907406137241, 3.4727510708370675, 3.567912554982255, 3.6606010435446255, 3.7509998667022106, 3.8392707640904935, 3.9255572852781047, 4.009987531152684, 4.092676385936225, 4.173727350941841, 4.253234063627348, 4.331281565541543, 4.407947368106838, 4.483302354291978, 4.557411546042337, 4.63033476111609, 4.702127178203499, 4.77283982551269, 4.8425200051213, 4.91121166312347, 4.978955713801841, 5.045790324617146, 5.111751167652823, 5.176871642217914, 5.241183072551464, 5.304714883949938, 5.367494760127856, 5.429548784199292, 5.490901565316937, 5.551576352712804, 5.61159513863928, 5.670978751503131, 5.729746940310715, 5.787918451395113, 5.845511098270194, 5.902541825349482, 5.959026766175833, 6.014981296729027, 6.070420084310475, 6.125357132445422, 6.17980582219215, 6.23377895020348, 6.287288763847259, 6.340346993658943, 6.392964883369843, 6.445153217728807, 6.496922348312315, 6.5482822174979605, 6.599242380758566, 6.649812027418519, 6.7, 6.749814812274482, 6.79926466612383, 6.848357467305573, 6.897100840208152, 6.945502141674135, 6.993568473962345, 7.041306696913577, 7.088723439378913, 7.13582510996451, 7.182617907142214, 7.229107828771128, 7.275300681071539, 7.321202087089251, 7.366817494685205, 7.4121521840825695, 7.457211275000863, 7.501999733404421, 7.546522377890362, 7.590783885739338, 7.634788798650556, 7.678541528180987, 7.722046360907191, 7.76530746332687, 7.808328886515987, 7.851114570556209, 7.893668348746355, 7.935993951610599, 7.978095010715276, 8.019975062305368, 8.061637550770936, 8.103085831953157, 8.144323176298936, 8.18535277187245, 8.226177727231525], [0.0, 0.8246211251235321, 1.16619037896906, 1.4282856857085702, 1.6492422502470643, 1.8439088914585775, 2.0199009876724157, 2.181742422927143, 2.33238075793812, 2.473863375370596, 2.6076809620810595, 2.734958866235469, 2.8565713714171403, 2.973213749463701, 3.0854497241083023, 3.1937438845342623, 3.2984845004941286, 3.4, 3.4985711369071804, 3.594440151122286, 3.687817782917155, 3.778888725538237, 3.867815921162743, 3.954743986657038, 4.039801975344831, 4.123105625617661, 4.204759208325728, 4.28485705712571, 4.363484845854286, 4.440720662234904, 4.516635916254486, 4.591296113299599, 4.66476151587624, 4.737087712930805, 4.8083261120685235, 4.878524367060187, 4.947726750741192, 5.015974481593781, 5.083306010855534, 5.149757275833494, 5.215361924162119, 5.280151512977635, 5.344155686354956, 5.407402333838309, 5.469917732470938, 5.531726674375732, 5.592852581643825, 5.653317610041028, 5.713142742834281, 5.772347875864725, 5.830951894845301, 5.888972745734184, 5.946427498927402, 6.003332407921454, 6.059702963017247, 6.115553940568263, 6.170899448216605, 6.2257529665093525, 6.280127387243033, 6.334035048845246, 6.387487769068525, 6.440496875241847, 6.49307323229917, 6.545227268781429, 6.596969000988257, 6.648308055437864, 6.699253689777691, 6.749814812274482, 6.8, 6.849817515817484, 6.899275324264137, 6.948381106416083, 6.997142273814361, 7.045565981523414, 7.093659140387279, 7.14142842854285, 7.188880302244572, 7.236021006050217, 7.282856582413251, 7.329392880723478, 7.37563556583431, 7.42159012611179, 7.467261881037788, 7.512655988397179, 7.557777451076474, 7.602631123499285, 7.647221717722065, 7.691553809211764, 7.735631842325486, 7.779460135510689, 7.8230428862431785, 7.866384175718855, 7.909487973314076, 7.952358140828418, 7.994998436522675, 8.037412518964047, 8.079603950689663, 8.121576201698781, 8.16333265278342, 8.204876598706406, 8.246211251235321, 8.287339742040265], [0.0, 0.8306623862918076, 1.174734012447073, 1.4387494569938162, 1.661324772583615, 1.8574175621006712, 2.0346989949375804, 2.1977260975835913, 2.349468024894146, 2.4919871588754225, 2.6267851073127395, 2.7549954627911823, 2.8774989139876324, 2.994995826374388, 3.1080540535840107, 3.217141588429082, 3.32264954516723, 3.424908757908742, 3.5242020373412193, 3.6207733980463352, 3.7148351242013424, 3.8065732621348563, 3.8961519477556315, 3.9837168574084183, 4.069397989875161, 4.153311931459037, 4.235563716909475, 4.316248370981448, 4.3954521951671826, 4.473253849269009, 4.54972526643093, 4.624932431938872, 4.698936049788292, 4.77179211617606, 4.843552415324934, 4.914264950122246, 4.983974317750845, 5.052722038663912, 5.120546845796843, 5.187484939737176, 5.253570214625479, 5.3188344587888805, 5.383307533477909, 5.447017532558529, 5.509990925582365, 5.572252686302012, 5.63382640840131, 5.69473440996154, 5.754997827975265, 5.814636704042653, 5.873670062235366, 5.932115979985557, 5.989991652748776, 6.047313453096343, 6.104096984812742, 6.1603571325045765, 6.216108107168021, 6.271363488110062, 6.326136261573885, 6.380438856379708, 6.434283176858164, 6.487680633323437, 6.540642170307133, 6.593178292750774, 6.64529909033446, 6.697014260101287, 6.748333127521196, 6.79926466612383, 6.849817515817484, 6.9, 6.949820141557622, 6.999285677838847, 7.048404074682439, 7.097182539571601, 7.145628033979938, 7.19374728496908, 7.2415467960926705, 7.289032857656769, 7.336211556382492, 7.383088784512889, 7.429670248402685, 7.475961476626268, 7.521967827636597, 7.567694497005016, 7.6131465242697125, 7.658328799418317, 7.703246069028303, 7.747902942086975, 7.792303895511263, 7.836453279386026, 7.880355321938218, 7.924014134263013, 7.967433714816837, 8.010617953691215, 8.053570636680355, 8.096295449154509, 8.138795979750322, 8.18107572388864, 8.223138087129511, 8.264986388373547, 8.306623862918075, 8.34805366537614], [0.0, 0.8366600265340756, 1.1832159566199232, 1.4491376746189442, 1.6733200530681511, 1.8708286933869709, 2.04939015319192, 2.2135943621178655, 2.3664319132398464, 2.5099800796022267, 2.6457513110645907, 2.774887385102322, 2.8982753492378883, 3.0166206257996717, 3.1304951684997055, 3.24037034920393, 3.3466401061363023, 3.4496376621320683, 3.5496478698597698, 3.6469165057620945, 3.7416573867739418, 3.834057902536163, 3.924283374069717, 4.012480529547776, 4.09878030638384, 4.183300132670378, 4.266145801540309, 4.3474130238568325, 4.427188724235731, 4.505552130427525, 4.58257569495584, 4.658325879540847, 4.732863826479693, 4.806245936279167, 4.878524367060187, 4.949747468305833, 5.019960159204453, 5.089204259999789, 5.157518783291051, 5.2249401910452535, 5.291502622129181, 5.35723809439155, 5.422176684690385, 5.486346689738081, 5.549774770204644, 5.612486080160912, 5.674504383644443, 5.735852159879995, 5.796550698475777, 5.856620185738529, 5.916079783099617, 5.974947698515863, 6.033241251599343, 6.090976933136425, 6.148170459575759, 6.2048368229954285, 6.260990336999411, 6.316644678941503, 6.3718129288295975, 6.4265076052238514, 6.48074069840786, 6.534523701081817, 6.587867636800241, 6.640783086353597, 6.6932802122726045, 6.745368781616021, 6.797058187186572, 6.848357467305573, 6.899275324264137, 6.949820141557622, 7.000000000000001, 7.049822692805827, 7.0992957397195395, 7.148426400264607, 7.197221686178633, 7.24568837309472, 7.293833011524189, 7.341661937191062, 7.3891812807644675, 7.436396977031284, 7.4833147735478835, 7.529940238806681, 7.576278769950325, 7.622335600063802, 7.668115805072326, 7.713624310270757, 7.75886589650833, 7.803845206050669, 7.848566748139434, 7.893034904268446, 7.937253933193772, 7.981227975693966, 8.024961059095553, 8.068457101577724, 8.1117199162693, 8.154753215150045, 8.19756061276768, 8.240145629781066, 8.282511696339462, 8.324662155306966, 8.366600265340756, 8.408329203831164], [0.0, 0.8426149773176359, 1.1916375287812984, 1.4594519519326425, 1.6852299546352718, 1.8841443681416774, 2.0639767440550294, 2.2293496809607953, 2.3832750575625967, 2.5278449319529073, 2.6645825188948455, 2.7946377224964243, 2.918903903865285, 3.0380915061926625, 3.152776554086889, 3.2634337744161437, 3.3704599092705436, 3.4741905532080417, 3.5749125863438955, 3.672873534441392, 3.768288736283355, 3.861346915261565, 3.952214569073901, 4.041039470235351, 4.127953488110059, 4.2130748865881795, 4.296510211788167, 4.378355855797928, 4.458699361921591, 4.537620521815371, 4.61519230368573, 4.69148164229596, 4.766550115125193, 4.8404545241123795, 4.913247398615299, 4.984977432245807, 5.0556898639058145, 5.1254268114957995, 5.194227565288221, 5.262128846769148, 5.329165037789691, 5.395368384086485, 5.46076917659042, 5.525395913416522, 5.589275444992849, 5.652433104425031, 5.71489282489182, 5.776677245614472, 5.83780780773057, 5.898304841223451, 5.958187643906493, 6.017474553332154, 6.076183012385325, 6.134329629226001, 6.191930232165088, 6.248999919987198, 6.305553108173778, 6.361603571427569, 6.417164482853779, 6.472248450113762, 6.526867548832287, 6.5810333535091585, 6.6347569661593475, 6.688049042882386, 6.740919818541087, 6.793379129711516, 6.8454364360499325, 6.897100840208152, 6.948381106416083, 6.999285677838847, 7.049822692805827, 7.1, 7.149825172687791, 7.199305522062527, 7.248448109768049, 7.297259759663212, 7.345747068882784, 7.3939164182454755, 7.441773982055624, 7.489325737341113, 7.53657747256671, 7.583534795858723, 7.630203142774117, 7.676587783644501, 7.72269383052313, 7.768526243760782, 7.814089838234521, 7.859389289251424, 7.904429138147802, 7.949213797602879, 7.993747556684537, 8.038034585643434, 8.082078940470701, 8.125884567233282, 8.16945530620004, 8.212794895770866, 8.255906976220118, 8.298795093265047, 8.341462701469089, 8.383913167489272, 8.426149773176359, 8.468175718535841], [0.0, 0.848528137423857, 1.2, 1.4696938456699071, 1.697056274847714, 1.8973665961010278, 2.078460969082653, 2.244994432064365, 2.4, 2.545584412271571, 2.6832815729997477, 2.814249455894058, 2.9393876913398143, 3.0594117081556713, 3.1749015732775088, 3.2863353450309964, 3.394112549695428, 3.4985711369071804, 3.6, 3.6986484017813863, 3.7947331922020555, 3.8884444190447165, 3.97994974842648, 4.069397989875161, 4.156921938165306, 4.242640687119286, 4.3266615305567875, 4.409081537009721, 4.48998886412873, 4.5694638635183455, 4.6475800154489, 4.724404724407087, 4.8, 4.874423042781577, 4.947726750741193, 5.019960159204453, 5.091168824543142, 5.1613951602255765, 5.230678732248808, 5.299056519796709, 5.366563145999495, 5.43323108288245, 5.499090833947008, 5.564171097297422, 5.628498911788116, 5.692099788303082, 5.754997827975264, 5.817215828899595, 5.8787753826796285, 5.939696961966999, 6.0, 6.059702963017248, 6.118823416311343, 6.177378084592201, 6.235382907247959, 6.29285308902091, 6.3498031465550175, 6.406246951218787, 6.462197768561405, 6.517668294720129, 6.572670690061993, 6.627216610312357, 6.681317235396026, 6.734983296193095, 6.788225099390856, 6.841052550594828, 6.8934751758456345, 6.945502141674135, 6.997142273814361, 7.048404074682439, 7.0992957397195395, 7.149825172687791, 7.2, 7.249827584156743, 7.299315036357863, 7.3484692283495345, 7.397296803562773, 7.445804187594514, 7.493997598078079, 7.541883053985921, 7.589466384404111, 7.636753236814713, 7.68374908491942, 7.730459236035075, 7.776888838089433, 7.823042886243179, 7.868926229162401, 7.914543574963752, 7.95989949685296, 8.0049984384758, 8.049844718999243, 8.094442537939225, 8.138795979750322, 8.182909018191515, 8.226785520481254, 8.270429251254132, 8.313843876330612, 8.357032966310472, 8.4, 8.442748367682174, 8.485281374238571, 8.527602242131138], [0.0, 0.8544003745317531, 1.2083045973594573, 1.4798648586948744, 1.7088007490635062, 1.91049731745428, 2.092844953645635, 2.260530911091463, 2.4166091947189146, 2.563201123595259, 2.701851217221259, 2.833725463060951, 2.9597297173897488, 3.0805843601498726, 3.196873472629156, 3.309078421554859, 3.4176014981270124, 3.522782990761707, 3.6249137920783716, 3.7242448899072147, 3.82099463490856, 3.915354390090379, 4.007492981902776, 4.097560249709576, 4.18568990729127, 4.272001872658766, 4.356604182158393, 4.439594576084623, 4.521061822182926, 4.601086828130937, 4.679743582719036, 4.757099956906519, 4.833218389437829, 4.908156476723211, 4.98196748283246, 5.054700782440045, 5.126402247190518, 5.197114584074513, 5.266877632905477, 5.335728628781641, 5.403702434442518, 5.470831746635972, 5.537147279962851, 5.602677931132575, 5.667450926121902, 5.731491952362839, 5.794825277780168, 5.857473858242988, 5.9194594347794975, 5.980802621722272, 6.041522986797286, 6.101639124038721, 6.161168720299745, 6.220128616033596, 6.278534860936905, 6.336402764976356, 6.393746945258312, 6.450581369148055, 6.5069193939989765, 6.562773803811921, 6.618156843109718, 6.673080248281149, 6.727555276621664, 6.7815927332743895, 6.835202996254025, 6.888396039717809, 6.941181455631311, 6.993568473962345, 7.045565981523414, 7.097182539571601, 7.148426400264607, 7.199305522062527, 7.249827584156743, 7.3, 7.349829930005183, 7.399324293474371, 7.448489779814429, 7.4973328590906245, 7.545859791965394, 7.594076639065476, 7.64198926981712, 7.689603370785778, 7.736924453553881, 7.783957862167549, 7.830708780180758, 7.877182237323192, 7.923383115816122, 7.969316156358713, 8.014985963805552, 8.060397012554654, 8.105553651663778, 8.150460109711599, 8.195120499419152, 8.239538822045807, 8.283718971573094, 8.327664738688751, 8.37137981458254, 8.414867794564572, 8.4581321815162, 8.501176389182852, 8.544003745317532, 8.586617494683225], [0.0, 0.8602325267042626, 1.2165525060596438, 1.489966442575134, 1.7204650534085253, 1.9235384061671346, 2.1071307505705477, 2.2759613353482084, 2.4331050121192876, 2.580697580112788, 2.7202941017470885, 2.8530685235374214, 2.979932885150268, 3.1016124838541645, 3.218695387886216, 3.3316662497915357, 3.4409301068170506, 3.5468295701936396, 3.6496575181789317, 3.749666651850535, 3.847076812334269, 3.9420806688854046, 4.034848200366403, 4.125530268947254, 4.214261501141095, 4.301162633521313, 4.386342439892262, 4.469899327725402, 4.551922670696417, 4.632493928760188, 4.711687595755898, 4.789572005931219, 4.866210024238575, 4.941659640242335, 5.015974481593781, 5.089204259999788, 5.161395160225576, 5.232590180780452, 5.302829433425141, 5.372150407425317, 5.440588203494177, 5.508175741568165, 5.574943945906542, 5.6409219104681805, 5.706137047074843, 5.770615218501403, 5.834380858325929, 5.897457079114692, 5.959865770300536, 6.021627686929839, 6.082762530298219, 6.143289021363068, 6.203224967708329, 6.262587324740471, 6.321392251711643, 6.3796551630946325, 6.437390775772432, 6.494613152451807, 6.55133574166368, 6.607571414672716, 6.663332499583071, 6.71863081289633, 6.773477688750439, 6.827884006044625, 6.881860213634101, 6.93541635375988, 6.988562083862459, 7.041306696913577, 7.093659140387279, 7.145628033979938, 7.197221686178633, 7.248448109768049, 7.299315036357863, 7.349829930005183, 7.3999999999999995, 7.44983221287567, 7.49933330370107, 7.548509786706248, 7.597367965289032, 7.645913941446111, 7.694153624668538, 7.742092740338364, 7.789736837660179, 7.837091297158659, 7.884161337770809, 7.930952023559341, 7.977468270071652, 8.023714850367003, 8.069696400732806, 8.115417426109392, 8.160882305241266, 8.206095295571457, 8.251060537894508, 8.295782060782456, 8.340263784797218, 8.384509526501832, 8.42852300228219, 8.472307831990054, 8.515867542417507, 8.559205570612264, 8.602325267042627, 8.645229898620395], [0.0, 0.8660254037844387, 1.224744871391589, 1.5000000000000002, 1.7320508075688774, 1.9364916731037085, 2.121320343559643, 2.29128784747792, 2.449489742783178, 2.598076211353316, 2.7386127875258306, 2.8722813232690148, 3.0000000000000004, 3.122498999199199, 3.24037034920393, 3.3541019662496843, 3.464101615137755, 3.570714214271425, 3.6742346141747673, 3.7749172176353754, 3.872983346207417, 3.968626966596886, 4.06201920231798, 4.153311931459037, 4.242640687119286, 4.330127018922194, 4.415880433163924, 4.5, 4.58257569495584, 4.663689526544408, 4.743416490252569, 4.8218253804964775, 4.898979485566356, 4.974937185533101, 5.049752469181039, 5.123475382979799, 5.196152422706632, 5.26782687642637, 5.338539126015656, 5.408326913195984, 5.477225575051661, 5.545268253204709, 5.612486080160912, 5.678908345800274, 5.7445626465380295, 5.809475019311125, 5.873670062235366, 5.937171043518958, 6.000000000000001, 6.06217782649107, 6.123724356957946, 6.184658438426491, 6.244997998398398, 6.304760106459247, 6.363961030678928, 6.422616289332565, 6.48074069840786, 6.5383484153110105, 6.59545297913646, 6.652067347825035, 6.7082039324993685, 6.7638746292343415, 6.819090848492928, 6.87386354243376, 6.92820323027551, 6.98212002188447, 7.035623639735144, 7.088723439378913, 7.14142842854285, 7.19374728496908, 7.24568837309472, 7.297259759663212, 7.3484692283495345, 7.399324293474371, 7.44983221287567, 7.5, 7.549834435270751, 7.599342076785332, 7.6485292703891785, 7.697402159170327, 7.745966692414834, 7.794228634059948, 7.842193570679062, 7.88986691902975, 7.937253933193772, 7.984359711335657, 8.031189202104505, 8.077747210701757, 8.12403840463596, 8.170067319184096, 8.215838362577491, 8.261355820929154, 8.306623862918075, 8.351646544245034, 8.396427811873334, 8.440971508067065, 8.485281374238571, 8.529361054615991, 8.573214099741124, 8.616843969807043, 8.660254037844387, 8.703447592764606], [0.0, 0.8717797887081349, 1.2328828005937953, 1.5099668870541503, 1.7435595774162698, 1.9493588689617931, 2.1354156504062627, 2.3065125189341593, 2.4657656011875906, 2.615339366124404, 2.7568097504180447, 2.8913664589601926, 3.0199337741083006, 3.1432467291003428, 3.2619012860600183, 3.3763886032268267, 3.4871191548325395, 3.594440151122286, 3.6986484017813863, 3.8000000000000007, 3.8987177379235862, 3.9949968710876362, 4.0890096600521755, 4.180908992073375, 4.270831300812525, 4.358898943540674, 4.445222154178575, 4.529900661162451, 4.613025037868319, 4.694677837722201, 4.774934554525329, 4.8538644398046396, 4.931531202375181, 5.007993610219566, 5.083306010855535, 5.157518783291051, 5.230678732248808, 5.302829433425142, 5.374011537017762, 5.444263035526481, 5.513619500836089, 5.582114294781146, 5.649778756730215, 5.716642371182581, 5.782732917920385, 5.848076606885378, 5.912698199637794, 5.976621118993575, 6.039867548216601, 6.102458520956944, 6.164414002968978, 6.225752966509353, 6.2864934582006855, 6.3466526610489735, 6.406246951218788, 6.465291950097846, 6.523802572120037, 6.581793068761734, 6.639277069079134, 6.696267617113283, 6.752777206453653, 6.808817812219681, 6.864400920692206, 6.919537556802479, 6.974238309665079, 7.0285133563222315, 7.08237248385031, 7.13582510996451, 7.188880302244572, 7.2415467960926705, 7.293833011524189, 7.345747068882784, 7.397296803562773, 7.448489779814429, 7.49933330370107, 7.549834435270751, 7.600000000000001, 7.649836599562112, 7.6993506219680645, 7.748548251124208, 7.7974354758471724, 7.8460180983732135, 7.894301742396222, 7.942291860665913, 7.9899937421752725, 8.037412518964048, 8.084553172563096, 8.13142054010245, 8.178019320104351, 8.224354077980836, 8.270429251254134, 8.316249154516717, 8.36181798414675, 8.407139822793482, 8.452218643646177, 8.497058314499201, 8.54166260162505, 8.586035173466273, 8.630179604156568, 8.674099376880578, 8.717797887081348, 8.761278445523805], [0.0, 0.8774964387392122, 1.2409673645990857, 1.5198684153570665, 1.7549928774784245, 1.9621416870348585, 2.149418526020468, 2.32163735324878, 2.4819347291981715, 2.6324893162176366, 2.7748873851023217, 2.91032644217105, 3.039736830714133, 3.1638584039112754, 3.283291031876401, 3.3985290935932855, 3.509985754956849, 3.6180105030251086, 3.722902093797257, 3.824918299781056, 3.924283374069717, 4.02119385257662, 4.115823125451336, 4.2083250825001635, 4.298837052040936, 4.387482193696061, 4.474371464239419, 4.559605246071199, 4.64327470649756, 4.725462940284264, 4.806245936279166, 4.8856934001224435, 4.963869458396343, 5.040833264451424, 5.1166395221864125, 5.191338940966964, 5.264978632435273, 5.3376024580330075, 5.409251334519409, 5.479963503528103, 5.549774770204643, 5.61871871515206, 5.686826883245173, 5.754128952326321, 5.8206528843421, 5.886425061104575, 5.951470406546605, 6.015812497078014, 6.079473661428266, 6.142475071174486, 6.2048368229954285, 6.266578013557321, 6.327716807822551, 6.388270501473776, 6.448255578061404, 6.507687761409578, 6.566582063752802, 6.624952830020755, 6.682813778641449, 6.740178039191546, 6.797058187186571, 6.853466276272176, 6.90941386804988, 6.96491205974634, 7.019971509913698, 7.074602462329597, 7.128814768248646, 7.182617907142214, 7.236021006050217, 7.289032857656769, 7.341661937191062, 7.3939164182454755, 7.445804187594514, 7.4973328590906245, 7.548509786706248, 7.599342076785332, 7.649836599562112, 7.7, 7.749838707999026, 7.799358948016177, 7.848566748139434, 7.897467948652911, 7.9460682101275735, 7.994373021069257, 8.04238770515324, 8.090117428072352, 8.137567204023572, 8.184741901856162, 8.231646250902672, 8.278284846512591, 8.324662155306966, 8.370782520170978, 8.416650165000327, 8.462269199216012, 8.507643622061282, 8.55277732669336, 8.597674104081872, 8.64233764672499, 8.6867715521936, 8.73097932651315, 8.774964387392123, 8.81873006730561], [0.0, 0.8831760866327848, 1.2489995996796797, 1.5297058540778359, 1.7663521732655696, 1.9748417658131503, 2.1633307652783937, 2.336664289109585, 2.4979991993593593, 2.6495282598983545, 2.7928480087537886, 2.9291637031753623, 3.0594117081556718, 3.1843366656181322, 3.3045423283716615, 3.420526275297414, 3.532704346531139, 3.6414282912066254, 3.7469987990390394, 3.8496753109840323, 3.9496835316263006, 4.047221268969613, 4.1424630354415966, 4.235563716909475, 4.3266615305567875, 4.415880433163924, 4.503332099679082, 4.589117562233508, 4.67332857821917, 4.756048780237647, 4.83735464897913, 4.917316341257699, 4.995998398718719, 5.07346035758633, 5.149757275833494, 5.2249401910452535, 5.299056519796709, 5.372150407425318, 5.444263035526481, 5.515432893255072, 5.585696017507577, 5.655086206239478, 5.723635208501675, 5.791372894228104, 5.858327406350725, 5.92452529743945, 5.989991652748776, 6.054750201288242, 6.1188234163113435, 6.182232606429493, 6.244997998398399, 6.307138812488593, 6.3686733312362644, 6.429618962271405, 6.489992295835182, 6.549809157525127, 6.609084656743323, 6.667833231267862, 6.726068688320096, 6.783804242458652, 6.841052550594828, 6.897825744392215, 6.954135460285484, 7.009992867328754, 7.065408693062278, 7.12039324756716, 7.17495644586084, 7.229107828771128, 7.282856582413251, 7.336211556382492, 7.3891812807644675, 7.441773982055624, 7.493997598078079, 7.545859791965394, 7.597367965289032, 7.6485292703891785, 7.6993506219680645, 7.749838707999026, 7.800000000000002, 7.849840762716147, 7.899367063252601, 7.9485847796950635, 7.997499609252884, 8.046117075956577, 8.094442537939226, 8.142481194328914, 8.19023809177731, 8.23771813064759, 8.284926070883193, 8.33186653757728, 8.378544026261366, 8.424962907930219, 8.47112743381895, 8.517041739947036, 8.56270985144306, 8.608135686662937, 8.653323061113575, 8.698275691193055, 8.742997197757758, 8.787491109526087, 8.831760866327848, 8.875809822207776], [0.0, 0.8888194417315589, 1.2569805089976536, 1.5394804318340656, 1.7776388834631178, 1.9874606914351793, 2.177154105707724, 2.3515952032609695, 2.513961017995307, 2.6664583251946765, 2.8106938645110393, 2.9478805945967355, 3.078960863668131, 3.204684071792413, 3.3256578296631782, 3.442382895611701, 3.5552777669262356, 3.664696440361739, 3.7709415269929605, 3.874274125562104, 3.9749213828703587, 4.07308237088326, 4.168932717135166, 4.262628297189424, 4.354308211415448, 4.444097208657795, 4.532107677449864, 4.618441295502196, 4.703190406521939, 4.786439177509728, 4.868264577855234, 4.948737212663449, 5.027922035990614, 5.105878964487898, 5.182663407939976, 5.2583267300539625, 5.332916650389353, 5.406477596365309, 5.47905101272109, 5.550675634551168, 5.621387729022079, 5.691221310052879, 5.760208329565868, 5.8283788483591215, 5.895761189193471, 5.962382074305537, 6.028266749240615, 6.09343909463285, 6.157921727336262, 6.221736092120913, 6.284902544988268, 6.347440429023341, 6.409368143584826, 6.470703207534712, 6.5314623171231725, 6.591661399070799, 6.6513156593263565, 6.710439627923047, 6.76904720030818, 6.827151675479314, 6.884765791223402, 6.941901756723442, 6.998571282769077, 7.0547856097829085, 7.110555533852471, 7.165891430938652, 7.2208032794142785, 7.275300681071539, 7.329392880723478, 7.383088784512889, 7.436396977031284, 7.489325737341113, 7.541883053985921, 7.594076639065476, 7.645913941446111, 7.697402159170327, 7.748548251124208, 7.799358948016177, 7.849840762716147, 7.9, 7.949842765740717, 7.999374975584031, 8.048602363143555, 8.097530487747484, 8.14616474176652, 8.194510357550353, 8.242572413997951, 8.290355842785038, 8.337865434270332, 8.385105843100611, 8.432081593533118, 8.478797084492587, 8.525256594378847, 8.571464285639882, 8.61742420912421, 8.663140308225419, 8.708616422830897, 8.753856293085923, 8.798863562983575, 8.843641783790206, 8.88819441731559, 8.932524839036274], [0.0, 0.894427190999916, 1.2649110640673518, 1.549193338482967, 1.788854381999832, 2.0000000000000004, 2.1908902300206647, 2.366431913239847, 2.5298221281347035, 2.6832815729997477, 2.8284271247461903, 2.9664793948382657, 3.098386676965934, 3.22490309931942, 3.3466401061363023, 3.4641016151377544, 3.577708763999664, 3.687817782917155, 3.7947331922020555, 3.8987177379235862, 4.000000000000001, 4.09878030638384, 4.1952353926806065, 4.289522117905444, 4.3817804600413295, 4.47213595499958, 4.560701700396552, 4.647580015448901, 4.732863826479694, 4.8166378315169185, 4.898979485566357, 4.979959839195494, 5.059644256269407, 5.1380930314660525, 5.21536192416212, 5.291502622129181, 5.366563145999495, 5.440588203494178, 5.513619500836089, 5.585696017507577, 5.656854249492381, 5.727128425310542, 5.796550698475777, 5.865151319446072, 5.9329587896765315, 6.0, 6.066300355241241, 6.131883886702357, 6.196773353931868, 6.260990336999412, 6.324555320336759, 6.387487769068526, 6.44980619863884, 6.511528238439884, 6.572670690061994, 6.6332495807108005, 6.6932802122726045, 6.752777206453653, 6.811754546370562, 6.870225614927067, 6.928203230275509, 6.985699678629192, 7.042726744663604, 7.0992957397195395, 7.155417527999328, 7.211102550927978, 7.266360849833981, 7.321202087089251, 7.37563556583431, 7.429670248402685, 7.4833147735478835, 7.53657747256671, 7.589466384404111, 7.64198926981712, 7.694153624668538, 7.745966692414834, 7.7974354758471724, 7.848566748139434, 7.899367063252601, 7.949842765740717, 8.000000000000002, 8.049844718999244, 8.099382692526635, 8.148619514985345, 8.19756061276768, 8.246211251235321, 8.29457654133109, 8.342661445845685, 8.390470785361213, 8.438009243891594, 8.485281374238571, 8.532291603080617, 8.579044235810889, 8.62554346113913, 8.671793355471522, 8.717797887081348, 8.763560920082659, 8.809086218218098, 8.854377448471462, 8.899438184514796, 8.94427190999916, 8.988882021697695], [0.0, 0.9, 1.2727922061357855, 1.5588457268119897, 1.8, 2.012461179749811, 2.2045407685048604, 2.3811761799581315, 2.545584412271571, 2.7, 2.8460498941515415, 2.9849623113198605, 3.1176914536239795, 3.2449961479175906, 3.3674916480965473, 3.485685011586675, 3.6, 3.710795063055895, 3.8183766184073566, 3.9230090491866068, 4.024922359499622, 4.124318125460256, 4.221374183841087, 4.316248370981448, 4.409081537009721, 4.500000000000001, 4.589117562233507, 4.676537180435969, 4.762352359916263, 4.846648326421054, 4.929503017546495, 5.01098792654702, 5.091168824543142, 5.170106381884226, 5.247856705360771, 5.324471804789654, 5.4, 5.474486277268398, 5.547972602672079, 5.620498198558559, 5.692099788303083, 5.762811813689565, 5.832666628567075, 5.9016946718718, 5.969924622639721, 6.037383539249432, 6.104096984812742, 6.17008914036094, 6.235382907247959, 6.300000000000001, 6.3639610306789285, 6.427285585688566, 6.489992295835181, 6.552098900352467, 6.613622305514581, 6.674578638386097, 6.734983296193095, 6.794850991743675, 6.854195795277518, 6.913031173081747, 6.97137002317335, 7.029224708315989, 7.08660708661063, 7.143528539874395, 7.2, 7.256031973468694, 7.311634564172365, 7.366817494685205, 7.42159012611179, 7.475961476626268, 7.529940238806681, 7.583534795858723, 7.636753236814713, 7.689603370785778, 7.742092740338364, 7.794228634059948, 7.8460180983732135, 7.897467948652911, 7.9485847796950635, 7.999374975584031, 8.049844718999244, 8.100000000000001, 8.149846624323676, 8.19939022122987, 8.248636250920512, 8.2975900115636, 8.346256645946134, 8.394641147779934, 8.442748367682174, 8.490583018850943, 8.538149682454625, 8.58545281275251, 8.632496741962896, 8.67928568489366, 8.725823743349393, 8.772114910328067, 8.818163074019441, 8.863972021616496, 8.909545442950499, 8.95488693395958, 9.000000000000002, 9.044888059008803], [0.0, 0.9055385138137417, 1.2806248474865698, 1.5684387141358125, 1.8110770276274835, 2.024845673131659, 2.2181073012818837, 2.395829710142188, 2.5612496949731396, 2.716615541441225, 2.863564212655271, 3.003331483536242, 3.136877428271625, 3.264965543462902, 3.3882148692194836, 3.5071355833500366, 3.622154055254967, 3.733630940518894, 3.84187454245971, 3.947150871198111, 4.049691346263318, 4.149698784249287, 4.247352116319061, 4.342810150121694, 4.436214602563767, 4.527692569068709, 4.617358552246079, 4.705316142407438, 4.791659420284376, 4.876474136094644, 4.959838707054898, 5.041825066382213, 5.122499389946279, 5.201922721455982, 5.280151512977635, 5.35723809439155, 5.43323108288245, 5.508175741568166, 5.582114294781146, 5.655086206239478, 5.727128425310542, 5.798275605729691, 5.868560300448485, 5.938013135721409, 6.006662967072484, 6.074537019394977, 6.1416610131136355, 6.208059278067503, 6.27375485654325, 6.338769596696192, 6.403124237432849, 6.466838485689898, 6.529931086925804, 6.592419889539805, 6.654321903845651, 6.715653356152327, 6.776429738438967, 6.836665854054885, 6.8963758598266685, 6.955573304911681, 7.014271166700073, 7.07248188403477, 7.130217387990355, 7.187489130426565, 7.244308110509934, 7.300684899377592, 7.356629663099809, 7.4121521840825695, 7.467261881037788, 7.521967827636597, 7.576278769950325, 7.630203142774117, 7.68374908491942, 7.736924453553881, 7.789736837660179, 7.842193570679062, 7.894301742396222, 7.9460682101275735, 7.997499609252884, 8.048602363143555, 8.099382692526635, 8.149846624323676, 8.200000000000001, 8.249848483457136, 8.299397568498573, 8.348652585896723, 8.397618710086808, 8.446300965511472, 8.494704232638123, 8.542833253669418, 8.590692637965812, 8.638286867197687, 8.685620300243388, 8.732697177848321, 8.77952162705919, 8.826097665446492, 8.872429205127535, 8.918520056601322, 8.964373932405989, 9.009994450608726, 9.055385138137417, 9.100549433962767], [0.0, 0.9110433579144299, 1.2884098726725124, 1.5779733838059502, 1.8220867158288598, 2.0371548787463363, 2.2315913604421396, 2.41039415863879, 2.576819745345025, 2.7331300737432893, 2.8809720581775866, 3.0215889859476257, 3.1559467676119004, 3.2848135411313684, 3.408812109811862, 3.5284557528754696, 3.6441734316577197, 3.7563279941985894, 3.8652296180175374, 3.9711459303329564, 4.0743097574926725, 4.174925149029621, 4.273172123844299, 4.369210454990696, 4.463182720884279, 4.55521678957215, 4.645427859734774, 4.73392015141785, 4.82078831727758, 4.906118628814432, 4.9899899799498595, 5.072474741188959, 5.15363949069005, 5.23354564325181, 5.31224999411737, 5.389805191284746, 5.466260147486579, 5.541660400998964, 5.616048432839589, 5.68946394662977, 5.761944116355173, 5.833523806414096, 5.904235767650205, 5.974110812497538, 6.043177971895251, 6.111464636239008, 6.178996682310163, 6.245798587850876, 6.311893535223801, 6.377303505401009, 6.442049363362563, 6.506150935845249, 6.569627082262737, 6.632495759516172, 6.694774081326419, 6.756478372643548, 6.817624219623724, 6.878226515607057, 6.938299503480662, 6.997856814768361, 7.056911505750939, 7.115476090888086, 7.173562573784381, 7.23118247591637, 7.288346863315439, 7.345066371381541, 7.401351227985333, 7.457211275000863, 7.512655988397179, 7.567694497005016, 7.622335600063802, 7.676587783644501, 7.730459236035075, 7.783957862167549, 7.837091297158659, 7.88986691902975, 7.942291860665913, 7.994373021069257, 8.046117075956577, 8.097530487747484, 8.148619514985345, 8.19939022122987, 8.249848483457136, 8.299999999999999, 8.349850298059241, 8.399404740813482, 8.44866853415377, 8.49764673306675, 8.546344247688598, 8.594765849050223, 8.64291617453276, 8.690799733051039, 8.738420909981391, 8.78578397184907, 8.832893070789435, 8.879752248796134, 8.926365441768558, 8.972736483370054, 9.018869108707587, 9.064766957842878, 9.1104335791443, 9.155872432488342], [0.0, 0.9165151389911681, 1.2961481396815722, 1.5874507866387546, 1.8330302779823362, 2.04939015319192, 2.244994432064365, 2.4248711305964283, 2.5922962793631443, 2.749545416973504, 2.898275349237888, 3.039736830714133, 3.174901573277509, 3.3045423283716615, 3.4292856398964493, 3.5496478698597693, 3.6660605559646724, 3.778888725538237, 3.8884444190447165, 3.9949968710876362, 4.09878030638384, 4.2, 4.298837052040936, 4.3954521951671826, 4.48998886412873, 4.582575694955841, 4.67332857821917, 4.762352359916264, 4.849742261192857, 4.935585071701227, 5.019960159204453, 5.10294032886923, 5.184592558726289, 5.264978632435274, 5.344155686354956, 5.422176684690384, 5.499090833947008, 5.574943945906542, 5.649778756730214, 5.723635208501674, 5.796550698475776, 5.868560300448484, 5.939696961967, 6.009991680526688, 6.079473661428266, 6.148170459575759, 6.216108107168022, 6.2833112289620034, 6.349803146555018, 6.4156059729381765, 6.480740698407861, 6.54522726878143, 6.609084656743323, 6.672330927044912, 6.7349832961930955, 6.797058187186572, 6.858571279792899, 6.919537556802478, 6.97997134664606, 7.0398863627192165, 7.099295739719539, 7.158212067269313, 7.216647421067486, 7.274613391789285, 7.332121111929345, 7.389181280764467, 7.445804187594514, 7.501999733404421, 7.557777451076474, 7.6131465242697125, 7.668115805072326, 7.72269383052313, 7.776888838089433, 7.830708780180758, 7.884161337770809, 7.937253933193772, 7.9899937421752725, 8.04238770515324, 8.094442537939226, 8.14616474176652, 8.19756061276768, 8.248636250920512, 8.299397568498573, 8.349850298059241, 8.4, 8.449852069711044, 8.499411744350311, 8.548684109265006, 8.597674104081872, 8.646386528486914, 8.694826047713663, 8.742997197757758, 8.790904390334365, 8.838551917593742, 8.885943956609225, 8.933084573650918, 8.97997772825746, 9.026627277117408, 9.073036977771006, 9.119210492142399, 9.165151389911681, 9.210863151735564], [0.0, 0.9219544457292888, 1.3038404810405297, 1.5968719422671316, 1.8439088914585775, 2.0615528128088303, 2.2583179581272432, 2.4392621835300936, 2.6076809620810595, 2.765863337187866, 2.9154759474226504, 3.0577769702841313, 3.193743884534263, 3.3241540277189325, 3.449637662132068, 3.5707142142714248, 3.687817782917155, 3.8013155617496426, 3.9115214431215897, 4.018706259482024, 4.123105625617661, 4.224926034855522, 4.324349662087931, 4.421538193886829, 4.5166359162544865, 4.609772228646444, 4.701063709417264, 4.790615826801394, 4.878524367060187, 4.964876634922565, 5.049752469181039, 5.13322510708424, 5.215361924162119, 5.296225070746145, 5.375872022286245, 5.454356057317858, 5.531726674375732, 5.608029957123981, 5.68330889535313, 5.757603668193913, 5.830951894845301, 5.903388857258177, 5.974947698515863, 6.0456596000767355, 6.115553940568263, 6.18465843842649, 6.252999280345393, 6.320601237224193, 6.387487769068526, 6.4536811201050215, 6.519202405202649, 6.584071688552609, 6.648308055437865, 6.711929677819935, 6.77495387438173, 6.837397165588672, 6.899275324264136, 6.960603422117942, 7.021395872616784, 7.0816664705420855, 7.1414284285428495, 7.200694410957877, 7.259476565152615, 7.317786550590281, 7.37563556583431, 7.433034373659253, 7.489993324429602, 7.546522377890362, 7.602631123499285, 7.658328799418317, 7.713624310270757, 7.768526243760782, 7.823042886243179, 7.877182237323192, 7.930952023559341, 7.984359711335657, 8.037412518964048, 8.090117428072352, 8.142481194328914, 8.194510357550353, 8.246211251235321, 8.2975900115636, 8.348652585896723, 8.399404740813482, 8.449852069711044, 8.5, 8.549853799919623, 8.599418584997478, 8.648699324175862, 8.697700845625814, 8.746427842267952, 8.794884877018005, 8.843076387773658, 8.891006692158093, 8.938679992034618, 8.986100377805714, 9.033271832508973, 9.080198235721511, 9.126883367283709, 9.173330910852394, 9.219544457292889, 9.265527507918803], [0.0, 0.9273618495495705, 1.3114877048604001, 1.6062378404209012, 1.854723699099141, 2.0736441353327724, 2.2715633383201097, 2.4535688292770597, 2.6229754097208002, 2.7820855486487113, 2.932575659723036, 3.07571129984594, 3.2124756808418025, 3.343650699460098, 3.4698703145794947, 3.591656999213594, 3.709447398198282, 3.8236108588610325, 3.9344631145812006, 4.042276586281548, 4.147288270665545, 4.249705872175156, 4.349712634186309, 4.447471191587417, 4.543126676640219, 4.636809247747852, 4.7286361670147565, 4.818713521262704, 4.907137658554119, 4.993996395673509, 5.079370039680118, 5.163332257370235, 5.2459508194416005, 5.327288240746882, 5.40740233383831, 5.486346689738081, 5.5641710972974225, 5.640921910468182, 5.716642371182581, 5.791372894228104, 5.865151319446072, 5.93801313572141, 6.009991680526689, 6.081118318204308, 6.15142259969188, 6.220932405998316, 6.289674077406556, 6.357672530100934, 6.424951361683605, 6.491532946846993, 6.557438524302001, 6.62268827591938, 6.687301398920196, 6.751296171847301, 6.814690014960329, 6.87749954561976, 6.939740629158989, 7.001428425685718, 7.062577433203831, 7.123201527403251, 7.183313998427188, 7.242927584892728, 7.302054505411474, 7.3607064878311785, 7.418894796396564, 7.476630257007497, 7.533923280734945, 7.590783885739338, 7.647221717722065, 7.703246069028303, 7.75886589650833, 7.814089838234521, 7.868926229162401, 7.923383115816122, 7.977468270071652, 8.031189202104505, 8.084553172563096, 8.137567204023572, 8.19023809177731, 8.242572413997951, 8.29457654133109, 8.346256645946134, 8.397618710086808, 8.44866853415377, 8.499411744350311, 8.549853799919623, 8.600000000000001, 8.649855490122365, 8.699425268372618, 8.748714191239761, 8.79772697916911, 8.84646822183859, 8.894942383174834, 8.943153806124549, 8.99110671719561, 9.038805230781334, 9.086253353280439, 9.133454987024352, 9.180413934022802, 9.22713389953782, 9.273618495495704, 9.319871243745807], [0.0, 0.9327379053088816, 1.3190905958272918, 1.6155494421403516, 1.8654758106177631, 2.0856653614614213, 2.2847319317591728, 2.4677925358506134, 2.6381811916545836, 2.7982137159266447, 2.9495762407505253, 3.093541659651604, 3.231098884280703, 3.363034344160048, 3.4899856733230297, 3.6124783736376886, 3.7309516212355263, 3.845776904605882, 3.957271787481876, 4.065710270051225, 4.171330722922843, 4.274342054632503, 4.374928570845472, 4.473253849269009, 4.5694638635183455, 4.663689526544408, 4.756048780237647, 4.846648326421054, 4.935585071701227, 5.022947341949744, 5.10881590977792, 5.193264869039514, 5.276362383309167, 5.358171329847526, 5.4387498563548595, 5.518151864528558, 5.596427431853289, 5.673623181001714, 5.749782604586021, 5.8249463516842805, 5.8991524815010505, 5.9724366886556455, 6.044832503882966, 6.1163714733492105, 6.187083319303208, 6.256996084384263, 6.326136261573884, 6.394528911499267, 6.462197768561406, 6.529165337162171, 6.59545297913646, 6.661080993352356, 6.726068688320096, 6.790434448545985, 6.854195795277518, 6.917369442208505, 6.979971346646059, 7.042016756583302, 7.103520254071217, 7.164495795239188, 7.224956747275377, 7.284915922644544, 7.344385610791416, 7.40337760755184, 7.4619032424710525, 7.519973404208288, 7.577598564189054, 7.634788798650556, 7.691553809211764, 7.747902942086975, 7.803845206050669, 7.859389289251424, 7.914543574963752, 7.969316156358713, 8.023714850367003, 8.077747210701757, 8.13142054010245, 8.184741901856162, 8.23771813064759, 8.290355842785038, 8.342661445845685, 8.394641147779934, 8.446300965511472, 8.49764673306675, 8.548684109265006, 8.599418584997478, 8.649855490122365, 8.700000000000001, 8.749857141690944, 8.799431799837988, 8.848728722251575, 8.897752525216692, 8.946507698538017, 8.994998610338971, 9.043229511629129, 9.091204540653564, 9.138927727036691, 9.186402995732335, 9.233634170791044, 9.280624978954814, 9.327379053088816, 9.373899935459095], [0.0, 0.938083151964686, 1.3266499161421599, 1.6248076809271923, 1.876166303929372, 2.0976176963403033, 2.297825058615212, 2.4819347291981715, 2.6532998322843198, 2.814249455894058, 2.9664793948382653, 3.1112698372208096, 3.2496153618543846, 3.3823069050575527, 3.509985754956849, 3.63318042491699, 3.752332607858744, 3.867815921162743, 3.97994974842648, 4.0890096600521755, 4.1952353926806065, 4.298837052040936, 4.4, 4.498888751680798, 4.595650117230424, 4.69041575982343, 4.7833042972405595, 4.874423042781577, 4.963869458396343, 5.0517323761260355, 5.138093031466052, 5.223025942880239, 5.3065996645686395, 5.388877434122993, 5.469917732470938, 5.549774770204643, 5.628498911788116, 5.706137047074843, 5.782732917920384, 5.858327406350725, 5.932958789676531, 6.006662967072483, 6.079473661428266, 6.151422599691879, 6.222539674441619, 6.292853089020909, 6.362389488234747, 6.431174076325411, 6.499230723708769, 6.566582063752802, 6.6332495807108005, 6.6992536897776915, 6.764613810115105, 6.82934843158555, 6.8934751758456345, 6.957010852370435, 7.019971509913698, 7.0823724838503095, 7.144228439796701, 7.205553413860728, 7.26636084983398, 7.326663633605681, 7.386474125047755, 7.445804187594514, 7.504665215717488, 7.5630681604756145, 7.62102355330306, 7.678541528180987, 7.735631842325486, 7.792303895511263, 7.848566748139434, 7.904429138147802, 7.95989949685296, 8.014985963805552, 8.069696400732806, 8.12403840463596, 8.178019320104351, 8.231646250902672, 8.284926070883193, 8.337865434270332, 8.390470785361213, 8.442748367682174, 8.494704232638123, 8.546344247688598, 8.597674104081872, 8.648699324175862, 8.699425268372618, 8.749857141690944, 8.8, 8.849858755935035, 8.899438184514796, 8.948742928478838, 8.997777503361595, 9.046546302318914, 9.09505360072166, 9.143303560529969, 9.191300234460847, 9.23904756996088, 9.28654941299512, 9.333809511662428, 9.38083151964686, 9.427618999514142], [0.0, 0.9433981132056604, 1.3341664064126333, 1.6340134638368193, 1.8867962264113207, 2.1095023109728985, 2.3108440016582685, 2.495996794869737, 2.6683328128252666, 2.830194339616981, 2.9832867780352594, 3.1288975694324033, 3.2680269276736387, 3.4014702703389896, 3.529872518944558, 3.6537651812890215, 3.7735924528226414, 3.8897300677553446, 4.0024992192379, 4.112177038990418, 4.219004621945797, 4.323193264243457, 4.424929377967517, 4.524378410345448, 4.621688003316537, 4.716990566028302, 4.810405388322278, 4.902040391510457, 4.991993589739474, 5.0803543183522155, 5.167204273105525, 5.252618394667558, 5.336665625650533, 5.419409561935692, 5.500909015790026, 5.58121850495033, 5.660388679233962, 5.7384666941614295, 5.815496539419485, 5.8915193286621745, 5.966573556070519, 6.040695324215583, 6.113918547053109, 6.186275131288617, 6.2577951388648065, 6.328506932918695, 6.398437309218556, 6.4676116148080505, 6.536053855347277, 6.603786792439623, 6.670832032063167, 6.73721010508059, 6.802940540677979, 6.868041933477111, 6.932532004974806, 6.996427659884722, 7.059745037889116, 7.122499561249548, 7.184705978674423, 7.246378405796926, 7.307530362578043, 7.368174807915458, 7.428324171709255, 7.487990384609211, 7.547184905645283, 7.6059187479225665, 7.664202502543888, 7.722046360907191, 7.779460135510689, 7.836453279386026, 7.893034904268446, 7.949213797602879, 8.0049984384758, 8.060397012554654, 8.115417426109392, 8.170067319184096, 8.224354077980836, 8.278284846512591, 8.33186653757728, 8.385105843100611, 8.438009243891594, 8.490583018850943, 8.542833253669418, 8.594765849050223, 8.646386528486914, 8.697700845625814, 8.748714191239761, 8.799431799837988, 8.849858755935035, 8.899999999999999, 8.949860334105779, 8.99944442729661, 9.048756820690896, 9.097801932335084, 9.1465840618233, 9.195107394696377, 9.243376006633074, 9.291393867445294, 9.339164844888433, 9.38669270829721, 9.433981132056603, 9.481033698917013], [0.0, 0.9486832980505138, 1.3416407864998738, 1.6431676725154984, 1.8973665961010275, 2.121320343559643, 2.32379000772445, 2.5099800796022267, 2.6832815729997477, 2.846049894151541, 3.0, 3.146426544510455, 3.286335345030997, 3.420526275297414, 3.5496478698597693, 3.674234614174767, 3.794733192202055, 3.9115214431215892, 4.024922359499621, 4.135214625627067, 4.242640687119286, 4.347413023856832, 4.449719092257398, 4.549725266430931, 4.6475800154489, 4.743416490252569, 4.83735464897913, 4.929503017546495, 5.019960159204453, 5.10881590977792, 5.196152422706632, 5.282045058497703, 5.366563145999495, 5.449770637375486, 5.531726674375733, 5.612486080160912, 5.692099788303082, 5.770615218501404, 5.848076606885378, 5.92452529743945, 6.0, 6.074537019394977, 6.148170459575759, 6.220932405998315, 6.29285308902091, 6.363961030678928, 6.434283176858165, 6.5038450166036395, 6.572670690061994, 6.640783086353597, 6.708203932499369, 6.77495387438173, 6.841052550594828, 6.906518659932804, 6.971370023173351, 7.035623639735144, 7.099295739719539, 7.162401831787993, 7.224956747275378, 7.286974680894671, 7.348469228349534, 7.409453421137082, 7.469939758793239, 7.52994023880668, 7.58946638440411, 7.648529270389177, 7.707139547199077, 7.76530746332687, 7.8230428862431785, 7.880355321938218, 7.937253933193772, 7.993747556684537, 8.049844718999243, 8.105553651663778, 8.160882305241266, 8.215838362577491, 8.270429251254134, 8.324662155306966, 8.378544026261366, 8.432081593533118, 8.485281374238571, 8.538149682454625, 8.590692637965812, 8.64291617453276, 8.694826047713663, 8.746427842267952, 8.79772697916911, 8.848728722251575, 8.899438184514796, 8.949860334105779, 9.0, 9.049861877399014, 9.099450532861862, 9.148770409186145, 9.197825830053535, 9.246621004453464, 9.2951600308978, 9.343446901438464, 9.391485505499116, 9.439279633531365, 9.486832980505138, 9.534149149242424], [0.0, 0.9539392014169457, 1.349073756323204, 1.6522711641858308, 1.9078784028338913, 2.1330729007701543, 2.3366642891095846, 2.5238858928247927, 2.698147512646408, 2.8618176042508368, 3.0166206257996713, 3.1638584039112754, 3.3045423283716615, 3.439476704383968, 3.5693136595149495, 3.694590640382233, 3.8157568056677826, 3.9331920878594273, 4.047221268969612, 4.158124577258358, 4.266145801540309, 4.371498598878879, 4.474371464239419, 4.57493169347915, 4.673328578219169, 4.769696007084729, 4.864154602806124, 4.956813492557492, 5.047771785649585, 5.137119815616529, 5.224940191045253, 5.3113086899558, 5.396295025292816, 5.479963503528103, 5.562373594069352, 5.643580423808984, 5.7236352085016735, 5.8025856305616035, 5.880476171195663, 5.957348403442593, 6.0332412515993425, 6.1081912216301815, 6.182232606429493, 6.255397669213365, 6.327716807822551, 6.399218702310462, 6.469930447848725, 6.539877674696982, 6.609084656743323, 6.67757440991862, 6.745368781616021, 6.81248853210044, 6.878953408767936, 6.944782214007867, 7.009992867328754, 7.074602462329597, 7.138627319029899, 7.202083032012336, 7.264984514780469, 7.327346040688948, 7.389181280764466, 7.450503338701353, 7.511324783285569, 7.571657678474378, 7.631513611335565, 7.6909037180295, 7.749838707999025, 7.808328886515987, 7.866384175718855, 7.924014134263013, 7.981227975693966, 8.038034585643434, 8.094442537939225, 8.150460109711599, 8.206095295571457, 8.261355820929154, 8.316249154516717, 8.370782520170978, 8.424962907930219, 8.478797084492587, 8.532291603080617, 8.58545281275251, 8.638286867197687, 8.690799733051039, 8.742997197757758, 8.794884877018005, 8.84646822183859, 8.897752525216692, 8.948742928478838, 8.99944442729661, 9.049861877399014, 9.1, 9.1498633869583, 9.199456505685541, 9.248783703817493, 9.297849213662264, 9.346657156438338, 9.395211546314432, 9.443516294262428, 9.491575211733826, 9.539392014169458, 9.586970324351693], [0.0, 0.959166304662544, 1.3564659966250536, 1.6613247725836153, 1.918332609325088, 2.144761058952722, 2.349468024894146, 2.5377155080899043, 2.7129319932501073, 2.877498913987632, 3.0331501776206204, 3.1811947441173736, 3.3226495451672307, 3.458323293158117, 3.5888716889852725, 3.714835124201342, 3.836665218650176, 3.954743986657038, 4.069397989875161, 4.180908992073375, 4.289522117905444, 4.3954521951671826, 4.498888751680798, 4.6000000000000005, 4.698936049788292, 4.79583152331272, 4.8908077042549944, 4.983974317750846, 5.075431016179809, 5.165268628057984, 5.253570214625479, 5.340411969127476, 5.4258639865002145, 5.509990925582366, 5.592852581643825, 5.674504383644443, 5.754997827975264, 5.83438085832593, 5.912698199637794, 5.989991652748776, 6.066300355241241, 6.1416610131136355, 6.216108107168022, 6.289674077406555, 6.362389488234747, 6.434283176858165, 6.505382386916238, 6.575712889109439, 6.645299090334461, 6.714164132637808, 6.782329983125269, 6.8498175158174845, 6.916646586316234, 6.982836100038438, 7.0484040746824395, 7.113367697511497, 7.177743377970545, 7.24154679609267, 7.3047929470998705, 7.367496182557545, 7.429670248402684, 7.491328320131218, 7.552483035399683, 7.6131465242697125, 7.673330437300352, 7.733045971672482, 7.792303895511263, 7.851114570556209, 7.909487973314076, 7.967433714816837, 8.024961059095553, 8.082078940470701, 8.138795979750322, 8.195120499419152, 8.251060537894508, 8.306623862918075, 8.36181798414675, 8.416650165000327, 8.47112743381895, 8.525256594378847, 8.579044235810889, 8.632496741962896, 8.685620300243388, 8.738420909981391, 8.790904390334365, 8.843076387773658, 8.894942383174834, 8.946507698538017, 8.997777503361595, 9.048756820690896, 9.099450532861862, 9.1498633869583, 9.200000000000001, 9.249864863877743, 9.299462350050137, 9.348796714016196, 9.397872099576585, 9.446692542895637, 9.495261976375376, 9.54358423235212, 9.59166304662544, 9.639502061828715], [0.0, 0.9643650760992956, 1.3638181696985856, 1.670329308849007, 1.9287301521985911, 2.1563858652847827, 2.3622023622035435, 2.551470164434615, 2.727636339397171, 2.8930952282978866, 3.0495901363953815, 3.1984371183438958, 3.340658617698014, 3.4770677301427426, 3.6083237105337433, 3.7349698793966195, 3.8574603043971822, 3.976179070414209, 4.091454509095757, 4.203569911396741, 4.312771730569565, 4.419275958796871, 4.523273151159457, 4.624932431938872, 4.724404724407087, 4.821825380496478, 4.917316341257699, 5.0109879265470205, 5.10294032886923, 5.193264869039514, 5.282045058497703, 5.36935750346352, 5.455272678794342, 5.539855593785817, 5.62316636780382, 5.705260730238365, 5.786190456595773, 5.866003750424986, 5.944745579080741, 6.02245796996542, 6.099180272790763, 6.174949392505174, 6.249799996799899, 6.323764701504951, 6.3968742366877915, 6.469157595854347, 6.540642170307134, 6.611353870426239, 6.681317235396028, 6.750555532695069, 6.8190908484929285, 6.886944169949399, 6.954135460285485, 7.020683727387242, 7.0866070866106305, 7.15192281837549, 7.216647421067487, 7.280796659706959, 7.3443856107914165, 7.407428703673091, 7.469939758793239, 7.531932023060219, 7.593418202627852, 7.654410493303845, 7.7149206087943645, 7.774959806970066, 7.834538914320357, 7.893668348746355, 7.952358140828418, 8.010617953691215, 8.068457101577724, 8.125884567233282, 8.182909018191515, 8.239538822045807, 8.295782060782456, 8.351646544245034, 8.407139822793482, 8.462269199216012, 8.517041739947036, 8.571464285639882, 8.62554346113913, 8.67928568489366, 8.732697177848321, 8.78578397184907, 8.838551917593742, 8.891006692158093, 8.943153806124549, 8.994998610338971, 9.046546302318914, 9.097801932335084, 9.148770409186145, 9.199456505685541, 9.249864863877743, 9.3, 9.349866309204641, 9.39946807005588, 9.448809448814174, 9.497894503520243, 9.5467271878901, 9.595311355031686, 9.643650760992957, 9.691749068150704], [0.0, 0.9695359714832659, 1.3711309200802089, 1.6792855623746668, 1.9390719429665317, 2.1679483388678804, 2.374868417407584, 2.5651510676761324, 2.7422618401604177, 2.9086079144497976, 3.0659419433511785, 3.2155870381627056, 3.3585711247493335, 3.4957116585897072, 3.627671429443411, 3.7549966711037173, 3.8781438859330635, 3.9974992182613374, 4.113392760240627, 4.226109321823088, 4.335896677735761, 4.442971978304612, 4.54752680036083, 4.649731175025068, 4.749736834815168, 4.847679857416329, 4.943682837723311, 5.037856687124, 5.130302135352265, 5.221110992882646, 5.310367218940701, 5.398147830506312, 5.4845236803208355, 5.569560126257729, 5.653317610041029, 5.735852159879995, 5.817215828899595, 5.897457079114693, 5.976621118993575, 6.054750201288242, 6.131883886702357, 6.208059278067504, 6.283311228962004, 6.357672530100933, 6.431174076325411, 6.5038450166036395, 6.57571288910944, 6.646803743153547, 6.717142249498667, 6.786751800382861, 6.855654600401045, 6.923871749245506, 6.9914233171794145, 7.058328414008519, 7.124605252222751, 7.1902712048990205, 7.255342858886822, 7.31983606373804, 7.383765976789894, 7.447147104764348, 7.5099933422074345, 7.572318007057021, 7.634133873596926, 7.695453203028396, 7.756287771866127, 7.816648898345122, 7.8765474670060875, 7.935993951610599, 7.994998436522675, 8.053570636680355, 8.1117199162693, 8.16945530620004, 8.226785520481254, 8.283718971573094, 8.340263784797218, 8.396427811873334, 8.452218643646177, 8.507643622061282, 8.56270985144306, 8.61742420912421, 8.671793355471522, 8.725823743349393, 8.77952162705919, 8.832893070789435, 8.885943956609225, 8.938679992034618, 8.99110671719561, 9.043229511629129, 9.09505360072166, 9.1465840618233, 9.197825830053535, 9.248783703817493, 9.299462350050137, 9.349866309204641, 9.4, 9.44986772394196, 9.499473669630335, 9.548821916864929, 9.597916440561463, 9.646761114488118, 9.695359714832659, 9.743715923609434], [0.0, 0.9746794344808963, 1.378404875209022, 1.6881943016134133, 1.9493588689617927, 2.179449471770337, 2.3874672772626644, 2.578759391645525, 2.756809750418044, 2.9240383034426887, 3.082207001484488, 3.2326459750489227, 3.3763886032268267, 3.5142566781611158, 3.6469165057620936, 3.7749172176353745, 3.8987177379235853, 4.018706259482023, 4.135214625627066, 4.2485291572496005, 4.358898943540674, 4.466542286825459, 4.571651780264984, 4.674398357008098, 4.774934554525329, 4.873397172404482, 4.969909455915671, 5.06458290484024, 5.15751878329105, 5.2488093888042835, 5.338539126015655, 5.426785420486054, 5.513619500836088, 5.599107071667768, 5.683308895353129, 5.766281297335397, 5.848076606885377, 5.928743543112655, 6.008327554319921, 6.08687111741328, 6.164414002968976, 6.24099351065197, 6.316644678941503, 6.3914004725099165, 6.465291950097845, 6.53834841531101, 6.6105975524153635, 6.682065548915245, 6.752777206453653, 6.822756041366274, 6.892024376045111, 6.960603422117942, 7.0285133563222315, 7.095773389842717, 7.162401831787993, 7.2284161474004796, 7.293833011524187, 7.358668357794092, 7.4229374239582535, 7.486654793697916, 7.549834435270749, 7.6124897372673015, 7.674633541739956, 7.736278174936576, 7.797435475847171, 7.858116822750854, 7.918333157931661, 7.978095010715276, 8.037412518964047, 8.096295449154509, 8.154753215150045, 8.212794895770866, 8.270429251254132, 8.327664738688751, 8.384509526501832, 8.440971508067065, 8.497058314499201, 8.55277732669336, 8.608135686662937, 8.663140308225419, 8.717797887081348, 8.772114910328067, 8.826097665446492, 8.879752248796134, 8.933084573650918, 8.986100377805714, 9.038805230781334, 9.091204540653564, 9.143303560529969, 9.195107394696377, 9.246621004453464, 9.297849213662264, 9.348796714016196, 9.39946807005588, 9.44986772394196, 9.499999999999998, 9.549869109050658, 9.599479152537391, 9.648834126463154, 9.697937925146768, 9.746794344808963, 9.795407086997457], [0.0, 0.9797958971132713, 1.3856406460551018, 1.6970562748477143, 1.9595917942265426, 2.1908902300206647, 2.4000000000000004, 2.5922962793631443, 2.7712812921102037, 2.939387691339814, 3.0983866769659336, 3.2496153618543846, 3.3941125496954285, 3.532704346531139, 3.666060555964672, 3.794733192202055, 3.9191835884530852, 4.039801975344831, 4.156921938165306, 4.270831300812525, 4.3817804600413295, 4.48998886412873, 4.595650117230424, 4.698936049788292, 4.800000000000001, 4.898979485566357, 4.9959983987187195, 5.091168824543143, 5.184592558726289, 5.276362383309168, 5.366563145999495, 5.455272678794342, 5.542562584220407, 5.628498911788117, 5.713142742834281, 5.796550698475776, 5.878775382679628, 5.959865770300536, 6.0398675482166, 6.118823416311343, 6.196773353931867, 6.27375485654325, 6.349803146555018, 6.424951361683604, 6.499230723708769, 6.572670690061993, 6.64529909033446, 6.717142249498666, 6.788225099390857, 6.858571279792899, 6.92820323027551, 6.997142273814362, 7.065408693062278, 7.1330218000508046, 7.2, 7.266360849833981, 7.332121111929344, 7.397296803562772, 7.4619032424710525, 7.525955088890711, 7.58946638440411, 7.652450587883597, 7.714920608794364, 7.776888838089433, 7.8383671769061705, 7.899367063252599, 7.95989949685296, 8.019975062305368, 8.079603950689663, 8.138795979750322, 8.19756061276768, 8.255906976220118, 8.313843876330612, 8.37137981458254, 8.42852300228219, 8.485281374238571, 8.54166260162505, 8.597674104081872, 8.653323061113575, 8.708616422830897, 8.763560920082659, 8.818163074019441, 8.872429205127535, 8.926365441768558, 8.97997772825746, 9.033271832508973, 9.086253353280439, 9.138927727036691, 9.191300234460847, 9.243376006633074, 9.2951600308978, 9.346657156438338, 9.397872099576585, 9.448809448814174, 9.499473669630335, 9.549869109050658, 9.600000000000001, 9.649870465451857, 9.699484522385713, 9.748846085563153, 9.797958971132713, 9.846826900072939], [0.0, 0.9848857801796106, 1.392838827718412, 1.7058722109231985, 1.9697715603592212, 2.2022715545545246, 2.412467616362964, 2.6057628441590768, 2.785677655436824, 2.9546573405388314, 3.1144823004794877, 3.2664965942122155, 3.411744421846397, 3.5510561809129415, 3.685105154537656, 3.8144462245521304, 3.9395431207184424, 4.060788100849391, 4.178516483155236, 4.293017586733137, 4.404543109109049, 4.513313638558704, 4.61952378498044, 4.723346271447818, 4.824935232725928, 4.924428900898053, 5.021951811795889, 5.117616632769595, 5.2115256883181535, 5.3037722424704485, 5.394441583704471, 5.483611948342078, 5.571355310873648, 5.657738063926256, 5.742821606144492, 5.826662852782887, 5.909314681077663, 5.990826320300065, 6.071243694664217, 6.150609725872713, 6.228964600958975, 6.306346010171025, 6.38278935889318, 6.458327956987009, 6.532993188424431, 6.606814663663572, 6.679820356865895, 6.7520367297579185, 6.823488843692794, 6.894200461257274, 6.9641941385920605, 7.033491309442276, 7.102112361825883, 7.170076708097342, 7.237402849088892, 7.30410843293006, 7.370210309075312, 7.4357245780085215, 7.5006666370396715, 7.565051222562872, 7.628892449104261, 7.692203845452876, 7.754998388136519, 7.817288532477231, 7.879086241436885, 7.940403012442127, 8.001249902359007, 8.061637550770936, 8.121576201698781, 8.18107572388864, 8.240145629781066, 8.298795093265047, 8.357032966310472, 8.414867794564572, 8.472307831990054, 8.529361054615991, 8.586035173466273, 8.64233764672499, 8.698275691193055, 8.753856293085923, 8.809086218218098, 8.863972021616496, 8.918520056601322, 8.972736483370054, 9.026627277117408, 9.080198235721511, 9.133454987024352, 9.186402995732335, 9.23904756996088, 9.291393867445294, 9.343446901438464, 9.395211546314432, 9.446692542895637, 9.497894503520243, 9.548821916864929, 9.599479152537391, 9.649870465451857, 9.700000000000003, 9.749871794028884, 9.799489782636646, 9.848857801796106, 9.897979591815698], [0.0, 0.9899494936611666, 1.4, 1.7146428199482249, 1.9798989873223332, 2.2135943621178655, 2.4248711305964283, 2.619160170741759, 2.8, 2.9698484809834995, 3.1304951684997055, 3.283291031876401, 3.4292856398964497, 3.5693136595149495, 3.704051835490427, 3.8340579025361623, 3.9597979746446663, 4.08166632639171, 4.2, 4.315089802078284, 4.427188724235731, 4.536518488885503, 4.64327470649756, 4.747630988187688, 4.849742261192857, 4.949747468305833, 5.047771785649585, 5.143928459844674, 5.238320341483518, 5.331041174104736, 5.422176684690383, 5.511805511808268, 5.6, 5.686826883245173, 5.772347875864725, 5.856620185738529, 5.939696961966999, 6.021627686929839, 6.102458520956943, 6.182232606429493, 6.260990336999411, 6.338769596696192, 6.4156059729381765, 6.491532946846992, 6.566582063752802, 6.640783086353596, 6.714164132637808, 6.786751800382861, 6.8585712797928995, 6.929646455628165, 7.0, 7.069653456853455, 7.138627319029899, 7.206941098690901, 7.274613391789285, 7.341661937191061, 7.408103670980854, 7.473954776421918, 7.539230729988306, 7.603946343840151, 7.668115805072325, 7.731752712031082, 7.79487010796203, 7.857480512225277, 7.919595949289333, 7.981227975693965, 8.04238770515324, 8.103085831953157, 8.16333265278342, 8.223138087129511, 8.282511696339462, 8.341462701469089, 8.4, 8.4581321815162, 8.515867542417507, 8.573214099741124, 8.630179604156568, 8.6867715521936, 8.742997197757758, 8.798863562983575, 8.854377448471462, 8.909545442950499, 8.964373932405989, 9.018869108707587, 9.073036977771006, 9.126883367283709, 9.180413934022802, 9.233634170791044, 9.28654941299512, 9.339164844888433, 9.391485505499116, 9.443516294262428, 9.495261976375376, 9.5467271878901, 9.597916440561463, 9.648834126463154, 9.699484522385713, 9.749871794028884, 9.8, 9.849873095629203, 9.899494936611665, 9.948869282486328], [0.0, 0.9949874371066201, 1.407124727947029, 1.7233687939614089, 1.9899748742132402, 2.224859546128699, 2.4372115213907883, 2.632489316217637, 2.814249455894058, 2.98496231131986, 3.146426544510455, 3.3000000000000007, 3.4467375879228177, 3.58747822293042, 3.722902093797257, 3.853569773599539, 3.9799497484264803, 4.102438299353203, 4.221374183841087, 4.337049688440289, 4.449719092257398, 4.559605246071199, 4.666904755831214, 4.77179211617606, 4.874423042781577, 4.974937185533101, 5.073460357586329, 5.170106381884226, 5.264978632435274, 5.358171329847527, 5.449770637375485, 5.539855593785817, 5.628498911788116, 5.715767664977296, 5.801723881744115, 5.886425061104576, 5.96992462263972, 6.052272300549605, 6.133514490078262, 6.213694553162394, 6.29285308902091, 6.3710281744785915, 6.448255578061405, 6.524568951279464, 6.600000000000001, 6.674578638386096, 6.748333127521196, 6.821290200541244, 6.893475175845635, 6.96491205974634, 7.035623639735145, 7.105631569396208, 7.17495644586084, 7.243617880589783, 7.3116345641723655, 7.379024325749307, 7.445804187594514, 7.5119904153293495, 7.577598564189055, 7.642643521714199, 7.707139547199078, 7.771100308193172, 7.834538914320357, 7.897467948652911, 7.959899496852961, 8.021845174272563, 8.083316151184489, 8.144323176298936, 8.204876598706406, 8.264986388373547, 8.324662155306966, 8.383913167489272, 8.442748367682174, 8.501176389182852, 8.559205570612264, 8.616843969807043, 8.674099376880578, 8.73097932651315, 8.787491109526087, 8.843641783790206, 8.899438184514796, 8.95488693395958, 9.009994450608726, 9.064766957842878, 9.119210492142399, 9.173330910852394, 9.22713389953782, 9.280624978954814, 9.333809511662428, 9.38669270829721, 9.439279633531365, 9.491575211733826, 9.54358423235212, 9.595311355031686, 9.646761114488118, 9.697937925146768, 9.748846085563153, 9.799489782636646, 9.849873095629203, 9.900000000000002, 9.949874371066201, 9.999499987499377], [0.0, 1.0, 1.4142135623730951, 1.7320508075688776, 2.0, 2.23606797749979, 2.4494897427831783, 2.6457513110645907, 2.8284271247461903, 3.0, 3.1622776601683795, 3.3166247903554003, 3.4641016151377553, 3.6055512754639896, 3.7416573867739413, 3.8729833462074166, 4.0, 4.123105625617661, 4.242640687119286, 4.358898943540674, 4.47213595499958, 4.582575694955841, 4.69041575982343, 4.79583152331272, 4.898979485566357, 5.000000000000001, 5.099019513592785, 5.196152422706633, 5.291502622129181, 5.385164807134505, 5.477225575051661, 5.567764362830022, 5.656854249492381, 5.7445626465380295, 5.830951894845301, 5.916079783099616, 6.0, 6.08276253029822, 6.164414002968977, 6.244997998398399, 6.324555320336759, 6.403124237432849, 6.480740698407861, 6.557438524302, 6.6332495807108005, 6.7082039324993685, 6.782329983125269, 6.855654600401045, 6.9282032302755105, 7.0, 7.071067811865476, 7.141428428542851, 7.211102550927979, 7.28010988928052, 7.348469228349535, 7.416198487095664, 7.483314773547883, 7.54983443527075, 7.6157731058639095, 7.681145747868608, 7.745966692414833, 7.810249675906655, 7.874007874011811, 7.937253933193772, 8.0, 8.06225774829855, 8.12403840463596, 8.18535277187245, 8.246211251235321, 8.306623862918075, 8.366600265340756, 8.426149773176359, 8.485281374238571, 8.544003745317532, 8.602325267042627, 8.660254037844387, 8.717797887081348, 8.774964387392123, 8.831760866327848, 8.88819441731559, 8.94427190999916, 9.000000000000002, 9.055385138137417, 9.1104335791443, 9.165151389911681, 9.219544457292889, 9.273618495495704, 9.327379053088816, 9.38083151964686, 9.433981132056603, 9.486832980505138, 9.539392014169458, 9.59166304662544, 9.643650760992957, 9.695359714832659, 9.746794344808963, 9.797958971132713, 9.848857801796106, 9.899494936611665, 9.949874371066201, 10.000000000000002, 10.049875621120892], [0.0, 1.0049875621120892, 1.4212670403551897, 1.7406895185529214, 2.0099751242241783, 2.2472205054244236, 2.4617067250182347, 2.6589471600616665, 2.8425340807103794, 3.0149626863362675, 3.178049716414141, 3.333166662499792, 3.481379037105843, 3.6235341863986883, 3.7603191353926335, 3.892300091205713, 4.019950248448357, 4.1436698710201325, 4.263801121065569, 4.380639222761903, 4.494441010848847, 4.605431575867782, 4.713809499757071, 4.819751030914357, 4.9234134500364695, 5.024937810560446, 5.1244511901275835, 5.222068555658764, 5.317894320123333, 5.412023651093924, 5.504543577809154, 5.595533933415113, 5.685068161420759, 5.773214009544425, 5.860034129593445, 5.9455865984779, 6.029925372672535, 6.113100686231171, 6.1951594006934165, 6.276145313805283, 6.356099432828282, 6.435060217278469, 6.5130637951735135, 6.590144156238162, 6.666333324999584, 6.74166151627327, 6.81615727518079, 6.889847603539574, 6.962758074211686, 7.034912934784624, 7.1063352017759485, 7.177046746399247, 7.247068372797377, 7.31641988953614, 7.385120175054704, 7.4531872376856345, 7.520638270785267, 7.587489703452652, 7.653757247260983, 7.719455939378112, 7.784600182411426, 7.849203781276163, 7.913279977354524, 7.976841480185, 8.039900496896713, 8.10246875958186, 8.16455755078008, 8.226177727231525, 8.287339742040265, 8.34805366537614, 8.408329203831164, 8.468175718535841, 8.527602242131138, 8.586617494683225, 8.645229898620395, 8.703447592764606, 8.761278445523805, 8.81873006730561, 8.875809822207776, 8.932524839036274, 8.988882021697695, 9.044888059008803, 9.100549433962767, 9.155872432488342, 9.210863151735564, 9.265527507918803, 9.319871243745807, 9.373899935459095, 9.427618999514142, 9.481033698917013, 9.534149149242424, 9.586970324351693, 9.639502061828715, 9.691749068150704, 9.743715923609434, 9.795407086997457, 9.846826900072939, 9.897979591815698, 9.948869282486328, 9.999499987499377, 10.049875621120892, 10.100000000000001]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"A = 1.5\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.15, 0.21213203435596426, 0.2598076211353316, 0.3, 0.3354101966249685, 0.3674234614174767, 0.3968626966596886, 0.4242640687119285, 0.44999999999999996, 0.4743416490252569, 0.49749371855331004, 0.5196152422706632, 0.5408326913195984, 0.5612486080160912, 0.5809475019311124, 0.6, 0.6184658438426491, 0.6363961030678927, 0.6538348415311012, 0.670820393249937, 0.687386354243376, 0.7035623639735145, 0.7193747284969081, 0.7348469228349535, 0.75, 0.7648529270389178, 0.7794228634059949, 0.7937253933193772, 0.8077747210701757, 0.8215838362577492, 0.8351646544245033, 0.848528137423857, 0.8616843969807044, 0.8746427842267952, 0.8874119674649424, 0.8999999999999999, 0.912414379544733, 0.9246621004453465, 0.9367496997597597, 0.9486832980505138, 0.9604686356149275, 0.9721111047611791, 0.9836157786452999, 0.9949874371066201, 1.0062305898749053, 1.0173494974687902, 1.0283481900601565, 1.0392304845413265, 1.05, 1.0606601717798214, 1.0712142642814277, 1.0816653826391969, 1.0920164833920778, 1.1022703842524302, 1.1124297730643495, 1.1224972160321824, 1.1324751652906124, 1.1423659658795864, 1.1521718621802912, 1.1618950038622249, 1.1715374513859982, 1.1811011811017715, 1.1905880899790657, 1.2, 1.2093386622447824, 1.218605760695394, 1.2278029157808674, 1.2369316876852983, 1.2459935794377113, 1.2549900398011133, 1.2639224659764539, 1.2727922061357855, 1.2816005617976296, 1.2903487900563941, 1.299038105676658, 1.3076696830622023, 1.3162446581088185, 1.3247641299491772, 1.3332291625973385, 1.341640786499874, 1.35, 1.3583077707206126, 1.3665650368716447, 1.374772708486752, 1.3829316685939332, 1.3910427743243559, 1.3991068579633223, 1.407124727947029, 1.4150971698084907, 1.4230249470757708, 1.4309088021254186, 1.4387494569938162, 1.4465476141489435, 1.4543039572248988, 1.4620191517213446, 1.469693845669907, 1.477328670269416, 1.4849242404917498, 1.4924811556599302, 1.5, 1.507481343168134], [0.0, 0.21213203435596426, 0.3, 0.3674234614174767, 0.4242640687119285, 0.47434164902525694, 0.5196152422706632, 0.5612486080160912, 0.6, 0.6363961030678927, 0.6708203932499369, 0.7035623639735145, 0.7348469228349535, 0.7648529270389177, 0.7937253933193771, 0.8215838362577491, 0.848528137423857, 0.8746427842267951, 0.8999999999999999, 0.9246621004453466, 0.9486832980505139, 0.972111104761179, 0.99498743710662, 1.0173494974687904, 1.0392304845413265, 1.0606601717798212, 1.0816653826391969, 1.1022703842524302, 1.1224972160321824, 1.1423659658795862, 1.161895003862225, 1.1811011811017715, 1.2, 1.2186057606953942, 1.2369316876852983, 1.2549900398011133, 1.2727922061357855, 1.2903487900563941, 1.307669683062202, 1.324764129949177, 1.3416407864998738, 1.3583077707206126, 1.374772708486752, 1.3910427743243554, 1.407124727947029, 1.4230249470757705, 1.438749456993816, 1.4543039572248986, 1.469693845669907, 1.4849242404917498, 1.5, 1.5149257407543117, 1.5297058540778354, 1.5443445211480502, 1.5588457268119895, 1.5732132722552272, 1.5874507866387542, 1.6015617378046967, 1.6155494421403513, 1.6294170736800322, 1.6431676725154982, 1.6568041525780892, 1.6703293088490065, 1.6837458240482737, 1.697056274847714, 1.7102631376487067, 1.7233687939614084, 1.7363755354185337, 1.7492855684535902, 1.7621010186706094, 1.7748239349298849, 1.7874562931719478, 1.7999999999999998, 1.8124568960391858, 1.8248287590894658, 1.8371173070873834, 1.8493242008906932, 1.8614510468986285, 1.8734993995195197, 1.8854707634964802, 1.8973665961010278, 1.9091883092036785, 1.9209372712298547, 1.9326148090087687, 1.944222209522358, 1.9557607215607948, 1.9672315572906005, 1.9786358937409378, 1.98997487421324, 2.00124960961895, 2.0124611797498106, 2.023610634484806, 2.034698994937581, 2.0457272545478786, 2.056696380120313, 2.067607312813533, 2.078460969082653, 2.089258241577618, 2.0999999999999996, 2.1106870919205436, 2.1213203435596424, 2.1319005605327845], [0.0, 0.2598076211353316, 0.3674234614174768, 0.45000000000000007, 0.5196152422706632, 0.5809475019311127, 0.6363961030678928, 0.6873863542433761, 0.7348469228349536, 0.7794228634059948, 0.8215838362577492, 0.8616843969807044, 0.9000000000000001, 0.9367496997597599, 0.9721111047611791, 1.0062305898749053, 1.0392304845413265, 1.0712142642814277, 1.1022703842524302, 1.1324751652906127, 1.1618950038622253, 1.190588089979066, 1.2186057606953944, 1.2459935794377115, 1.2727922061357857, 1.2990381056766582, 1.3247641299491772, 1.3500000000000003, 1.3747727084867523, 1.3991068579633226, 1.423024947075771, 1.4465476141489435, 1.4696938456699071, 1.4924811556599302, 1.514925740754312, 1.53704261489394, 1.5588457268119895, 1.5803480629279112, 1.601561737804697, 1.6224980739587955, 1.6431676725154984, 1.663580475961413, 1.6837458240482739, 1.703672503740082, 1.7233687939614089, 1.7428425057933379, 1.7621010186706099, 1.7811513130556877, 1.8000000000000003, 1.8186533479473215, 1.8371173070873839, 1.8553975315279476, 1.8734993995195197, 1.891428031937774, 1.9091883092036785, 1.9267848867997694, 1.9442222095223582, 1.9615045245933034, 1.9786358937409383, 1.9956202043475109, 2.0124611797498106, 2.029162388770303, 2.0457272545478786, 2.0621590627301285, 2.078460969082653, 2.094636006565341, 2.1106870919205436, 2.126617031813674, 2.1424285285628555, 2.158124185490724, 2.1737065119284162, 2.189177927898964, 2.2045407685048604, 2.2197972880423116, 2.234949663862701, 2.25, 2.2649503305812253, 2.2798026230356, 2.294558781116754, 2.3092206477510984, 2.3237900077244507, 2.338268590217985, 2.352658071203719, 2.366960075708925, 2.381176179958132, 2.3953079134006976, 2.4093567606313524, 2.423324163210527, 2.437211521390789, 2.451020195755229, 2.4647515087732477, 2.4784067462787465, 2.491987158875423, 2.5054939632735107, 2.518928343562, 2.53229145242012, 2.5455844122715714, 2.558808316384798, 2.571964229922337, 2.5850531909421135, 2.5980762113533165, 2.6110342778293822], [0.0, 0.3, 0.4242640687119285, 0.5196152422706632, 0.6, 0.670820393249937, 0.7348469228349535, 0.7937253933193772, 0.848528137423857, 0.8999999999999999, 0.9486832980505138, 0.9949874371066201, 1.0392304845413265, 1.0816653826391969, 1.1224972160321824, 1.1618950038622249, 1.2, 1.2369316876852983, 1.2727922061357855, 1.3076696830622023, 1.341640786499874, 1.374772708486752, 1.407124727947029, 1.4387494569938162, 1.469693845669907, 1.5, 1.5297058540778357, 1.5588457268119897, 1.5874507866387544, 1.6155494421403513, 1.6431676725154984, 1.6703293088490065, 1.697056274847714, 1.7233687939614089, 1.7492855684535904, 1.7748239349298849, 1.7999999999999998, 1.824828759089466, 1.849324200890693, 1.8734993995195195, 1.8973665961010275, 1.920937271229855, 1.9442222095223582, 1.9672315572905998, 1.9899748742132402, 2.0124611797498106, 2.0346989949375804, 2.056696380120313, 2.078460969082653, 2.1, 2.121320343559643, 2.1424285285628555, 2.1633307652783937, 2.1840329667841556, 2.2045407685048604, 2.224859546128699, 2.244994432064365, 2.264950330581225, 2.2847319317591728, 2.3043437243605824, 2.3237900077244498, 2.3430749027719964, 2.362202362203543, 2.3811761799581315, 2.4, 2.4186773244895647, 2.437211521390788, 2.455605831561735, 2.4738633753705965, 2.4919871588754225, 2.5099800796022267, 2.5278449319529077, 2.545584412271571, 2.563201123595259, 2.5806975801127883, 2.598076211353316, 2.6153393661244047, 2.632489316217637, 2.6495282598983545, 2.666458325194677, 2.683281572999748, 2.7, 2.716615541441225, 2.7331300737432893, 2.749545416973504, 2.7658633371878665, 2.7820855486487117, 2.7982137159266447, 2.814249455894058, 2.8301943396169813, 2.8460498941515415, 2.861817604250837, 2.8774989139876324, 2.893095228297887, 2.9086079144497976, 2.924038303442689, 2.939387691339814, 2.954657340538832, 2.9698484809834995, 2.9849623113198605, 3.0, 3.014962686336268], [0.0, 0.33541019662496846, 0.47434164902525694, 0.5809475019311127, 0.6708203932499369, 0.7500000000000001, 0.8215838362577492, 0.8874119674649424, 0.9486832980505139, 1.0062305898749053, 1.0606601717798214, 1.1124297730643495, 1.1618950038622253, 1.2093386622447826, 1.2549900398011133, 1.299038105676658, 1.3416407864998738, 1.3829316685939332, 1.4230249470757708, 1.4620191517213448, 1.5000000000000002, 1.5370426148939398, 1.5732132722552277, 1.6085707942145415, 1.6431676725154984, 1.6770509831248424, 1.7102631376487072, 1.7428425057933379, 1.7748239349298849, 1.8062391868188445, 1.8371173070873839, 1.86748493969831, 1.8973665961010278, 1.9267848867997697, 1.955760721560795, 1.984313483298443, 2.0124611797498106, 2.040220576310317, 2.0676073128135335, 2.0946360065653415, 2.121320343559643, 2.147673159491453, 2.173706511928416, 2.199431744792277, 2.224859546128699, 2.25, 2.2748626332154656, 2.299456457513384, 2.3237900077244507, 2.3478713763747794, 2.371708245126285, 2.395307913400697, 2.418677324489565, 2.441823089414956, 2.4647515087732477, 2.48746859276655, 2.5099800796022267, 2.53229145242012, 2.5544079548889607, 2.5763346055976504, 2.598076211353316, 2.6196373794859475, 2.6410225292488514, 2.6622359023948277, 2.6832815729997477, 2.704163456597992, 2.7248853186877424, 2.745450782658469, 2.7658633371878665, 2.7861263431510066, 2.8062430400804566, 2.8262165522125158, 2.8460498941515415, 2.86574597618142, 2.885307609250702, 2.9047375096555625, 2.9240383034426896, 2.943212530552288, 2.9622626487197254, 2.981191037152769, 3.0000000000000004, 3.0186917696247164, 3.0372685096974883, 3.0557323181195044, 3.0740852297878796, 3.092329219213246, 3.1104662029991585, 3.1284980421921316, 3.1464265445104553, 3.164253466459348, 3.1819805153394642, 3.1996093511552317, 3.217141588429083, 3.2345787979271745, 3.25192250830182, 3.2691742076555053, 3.286335345030997, 3.303407331831787, 3.320391543176798, 3.337289319193049, 3.3541019662496847, 3.370830758136636], [0.0, 0.3674234614174767, 0.5196152422706632, 0.6363961030678928, 0.7348469228349535, 0.8215838362577493, 0.9, 0.9721111047611791, 1.0392304845413265, 1.10227038425243, 1.161895003862225, 1.2186057606953942, 1.2727922061357857, 1.324764129949177, 1.374772708486752, 1.4230249470757705, 1.469693845669907, 1.5149257407543117, 1.5588457268119895, 1.601561737804697, 1.6431676725154987, 1.6837458240482737, 1.7233687939614089, 1.7621010186706099, 1.8, 1.8371173070873836, 1.8734993995195197, 1.9091883092036785, 1.9442222095223582, 1.978635893740938, 2.0124611797498106, 2.0457272545478786, 2.078460969082653, 2.1106870919205436, 2.1424285285628555, 2.173706511928416, 2.20454076850486, 2.234949663862701, 2.264950330581225, 2.2945587811167534, 2.32379000772445, 2.3526580712037184, 2.3811761799581315, 2.4093567606313515, 2.4372115213907883, 2.4647515087732477, 2.4919871588754225, 2.5189283435619996, 2.5455844122715714, 2.571964229922337, 2.598076211353316, 2.6239283526803856, 2.649528259898354, 2.6748831750190516, 2.7, 2.7248853186877424, 2.749545416973504, 2.7739863013360395, 2.798213715926645, 2.822233158334017, 2.846049894151541, 2.869668970456349, 2.8930952282978866, 2.9163333142835373, 2.939387691339814, 2.9622626487197246, 2.9849623113198596, 3.007490648364513, 3.0298514815086235, 3.052048492406371, 3.0740852297878796, 3.095965116082544, 3.117691453623979, 3.1392674304684527, 3.160696125855822, 3.181980515339464, 3.203123475609394, 3.224127789030702, 3.244996147917591, 3.2657311585615862, 3.2863353450309973, 3.306811152757291, 3.3271609519228256, 3.3473870406632096, 3.3674916480965473, 3.3874769371908653, 3.407345007480165, 3.4270978976387587, 3.4467375879228177, 3.4662660024874032, 3.4856850115866753, 3.504996433664377, 3.5242020373412197, 3.5433035433053157, 3.5623026261113755, 3.5812009158939966, 3.6, 3.6187014245444464, 3.637306695894642, 3.6558172820861827, 3.6742346141747673, 3.6925600875273523], [0.0, 0.3968626966596886, 0.5612486080160912, 0.687386354243376, 0.7937253933193772, 0.8874119674649426, 0.9721111047611791, 1.05, 1.1224972160321824, 1.1905880899790657, 1.2549900398011133, 1.3162446581088185, 1.374772708486752, 1.4309088021254186, 1.4849242404917498, 1.5370426148939396, 1.5874507866387544, 1.6363068171953572, 1.6837458240482737, 1.7298843892006197, 1.774823934929885, 1.8186533479473213, 1.8614510468986287, 1.9032866310674283, 1.9442222095223582, 1.984313483298443, 2.0236106344848066, 2.062159062730128, 2.1, 2.137171027316251, 2.173706511928416, 2.2096379793984355, 2.244994432064365, 2.2798026230356, 2.314087293081227, 2.3478713763747794, 2.3811761799581315, 2.4140215409146624, 2.4464259645450137, 2.478406746278746, 2.5099800796022267, 2.5411611519146127, 2.571964229922337, 2.6024027359346205, 2.632489316217637, 2.662235902394827, 2.691653766738954, 2.720753572082558, 2.749545416973504, 2.7780388766178206, 2.806243040080456, 2.834166544153678, 2.861817604250837, 2.8892040426387338, 2.9163333142835373, 2.9432125305522874, 2.9698484809834995, 2.9962476533157267, 3.022416251941483, 3.048360214935236, 3.074085229787879, 3.099596747965774, 3.1248999983999486, 3.15, 3.1749015732775088, 3.1996093511552313, 3.2241277890307014, 3.2484611741561573, 3.2726136343907144, 3.2965891463753865, 3.3203915431767985, 3.344024521441193, 3.3674916480965473, 3.3907963666371947, 3.4139420030223127, 3.43693177121688, 3.4597687784012394, 3.48245602987317, 3.5049964336643775, 3.5273928048914542, 3.54964786985977, 3.571764269937198, 3.593744565213282, 3.6155912379581845, 3.6373066958946425, 3.658893275295141, 3.6803532439155897, 3.70168880377592, 3.7229020937972575, 3.7439951923046055, 3.76497011940334, 3.785828839237189, 3.8065732621348567, 3.8272052466519226, 3.847726601514198, 3.868139087468288, 3.8884444190447165, 3.9086442662386154, 3.928740256112638, 3.9487339743264553, 3.968626966596886, 3.9884207400925002], [0.0, 0.4242640687119285, 0.6, 0.7348469228349535, 0.848528137423857, 0.9486832980505139, 1.0392304845413265, 1.1224972160321824, 1.2, 1.2727922061357855, 1.3416407864998738, 1.407124727947029, 1.469693845669907, 1.5297058540778354, 1.5874507866387542, 1.6431676725154982, 1.697056274847714, 1.7492855684535902, 1.7999999999999998, 1.8493242008906932, 1.8973665961010278, 1.944222209522358, 1.98997487421324, 2.034698994937581, 2.078460969082653, 2.1213203435596424, 2.1633307652783937, 2.2045407685048604, 2.244994432064365, 2.2847319317591723, 2.32379000772445, 2.362202362203543, 2.4, 2.4372115213907883, 2.4738633753705965, 2.5099800796022267, 2.545584412271571, 2.5806975801127883, 2.615339366124404, 2.649528259898354, 2.6832815729997477, 2.716615541441225, 2.749545416973504, 2.782085548648711, 2.814249455894058, 2.846049894151541, 2.877498913987632, 2.908607914449797, 2.939387691339814, 2.9698484809834995, 3.0, 3.0298514815086235, 3.059411708155671, 3.0886890422961004, 3.117691453623979, 3.1464265445104544, 3.1749015732775083, 3.2031234756093934, 3.2310988842807027, 3.2588341473600644, 3.2863353450309964, 3.3136083051561784, 3.340658617698013, 3.3674916480965473, 3.394112549695428, 3.4205262752974135, 3.446737587922817, 3.4727510708370675, 3.4985711369071804, 3.524202037341219, 3.5496478698597698, 3.5749125863438955, 3.5999999999999996, 3.6249137920783716, 3.6496575181789317, 3.674234614174767, 3.6986484017813863, 3.722902093797257, 3.7469987990390394, 3.7709415269929605, 3.7947331922020555, 3.818376618407357, 3.8418745424597094, 3.8652296180175374, 3.888444419044716, 3.9115214431215897, 3.934463114581201, 3.9572717874818757, 3.97994974842648, 4.0024992192379, 4.024922359499621, 4.047221268969612, 4.069397989875162, 4.091454509095757, 4.113392760240626, 4.135214625627066, 4.156921938165306, 4.178516483155236, 4.199999999999999, 4.221374183841087, 4.242640687119285, 4.263801121065569], [0.0, 0.44999999999999996, 0.6363961030678927, 0.7794228634059948, 0.8999999999999999, 1.0062305898749055, 1.1022703842524302, 1.1905880899790657, 1.2727922061357855, 1.3499999999999999, 1.4230249470757705, 1.49248115565993, 1.5588457268119895, 1.622498073958795, 1.6837458240482734, 1.7428425057933374, 1.7999999999999998, 1.8553975315279472, 1.909188309203678, 1.9615045245933032, 2.012461179749811, 2.062159062730128, 2.1106870919205436, 2.158124185490724, 2.2045407685048604, 2.25, 2.2945587811167534, 2.3382685902179845, 2.3811761799581315, 2.423324163210527, 2.4647515087732477, 2.50549396327351, 2.545584412271571, 2.585053190942113, 2.6239283526803856, 2.662235902394827, 2.6999999999999997, 2.737243138634199, 2.773986301336039, 2.8102490992792792, 2.846049894151541, 2.881405906844782, 2.9163333142835373, 2.9508473359358995, 2.98496231131986, 3.018691769624716, 3.052048492406371, 3.0850445701804694, 3.117691453623979, 3.15, 3.181980515339464, 3.213642792844283, 3.24499614791759, 3.2760494501762336, 3.3068111527572905, 3.337289319193048, 3.367491648096547, 3.397425495871837, 3.427097897638759, 3.456515586540873, 3.485685011586675, 3.5146123541579946, 3.543303543305315, 3.5717642699371974, 3.5999999999999996, 3.628015986734347, 3.655817282086182, 3.683408747342602, 3.7107950630558943, 3.7379807383131336, 3.76497011940334, 3.791767397929361, 3.818376618407356, 3.844801685392889, 3.8710463701691817, 3.8971143170299736, 3.9230090491866063, 3.9487339743264553, 3.9742923898475317, 3.999687487792015, 4.024922359499622, 4.05, 4.074923312161838, 4.099695110614934, 4.124318125460256, 4.1487950057818, 4.173128322973067, 4.197320573889966, 4.221374183841087, 4.2452915094254715, 4.269074841227312, 4.292726406376255, 4.316248370981448, 4.33964284244683, 4.362911871674696, 4.386057455164034, 4.409081537009721, 4.431986010808248, 4.454772721475249, 4.47744346697979, 4.5, 4.522444029504402], [0.0, 0.4743416490252569, 0.6708203932499369, 0.8215838362577492, 0.9486832980505138, 1.0606601717798214, 1.161895003862225, 1.2549900398011133, 1.3416407864998738, 1.4230249470757705, 1.5, 1.5732132722552274, 1.6431676725154984, 1.710263137648707, 1.7748239349298847, 1.8371173070873834, 1.8973665961010275, 1.9557607215607946, 2.0124611797498106, 2.0676073128135335, 2.121320343559643, 2.173706511928416, 2.224859546128699, 2.2748626332154656, 2.32379000772445, 2.3717082451262845, 2.418677324489565, 2.4647515087732477, 2.5099800796022267, 2.55440795488896, 2.598076211353316, 2.6410225292488514, 2.6832815729997477, 2.724885318687743, 2.7658633371878665, 2.806243040080456, 2.846049894151541, 2.885307609250702, 2.924038303442689, 2.962262648719725, 3.0, 3.0372685096974883, 3.0740852297878796, 3.1104662029991577, 3.146426544510455, 3.181980515339464, 3.2171415884290826, 3.2519225083018197, 3.286335345030997, 3.3203915431767985, 3.3541019662496847, 3.387476937190865, 3.420526275297414, 3.453259329966402, 3.4856850115866753, 3.517811819867572, 3.5496478698597693, 3.5812009158939966, 3.612478373637689, 3.6434873404473356, 3.674234614174767, 3.704726710568541, 3.7349698793966195, 3.76497011940334, 3.794733192202055, 3.8242646351945884, 3.8535697735995385, 3.882653731663435, 3.9115214431215892, 3.940177660969109, 3.968626966596886, 3.9968737783422683, 4.024922359499621, 4.052776825831889, 4.080441152620633, 4.107919181288746, 4.135214625627067, 4.162331077653483, 4.189272013130683, 4.216040796766559, 4.242640687119286, 4.2690748412273125, 4.295346318982906, 4.32145808726638, 4.347413023856832, 4.373213921133976, 4.398863489584555, 4.424364361125788, 4.449719092257398, 4.474930167052889, 4.5, 4.524930938699507, 4.549725266430931, 4.574385204593073, 4.598912915026768, 4.623310502226732, 4.6475800154489, 4.671723450719232, 4.695742752749558, 4.719639816765683, 4.743416490252569, 4.767074574621212], [0.0, 0.49749371855331, 0.7035623639735145, 0.8616843969807044, 0.99498743710662, 1.1124297730643498, 1.2186057606953942, 1.3162446581088185, 1.407124727947029, 1.4924811556599298, 1.5732132722552274, 1.6500000000000004, 1.7233687939614089, 1.79373911146521, 1.8614510468986285, 1.9267848867997694, 1.98997487421324, 2.0512191496766015, 2.1106870919205436, 2.1685248442201446, 2.2248595461286995, 2.2798026230355997, 2.333452377915607, 2.3858960580880306, 2.4372115213907883, 2.4874685927665503, 2.536730178793165, 2.585053190942113, 2.632489316217637, 2.679085664923763, 2.724885318687743, 2.7699277968929086, 2.814249455894058, 2.857883832488648, 2.900861940872058, 2.943212530552288, 2.9849623113198596, 3.0261361502748025, 3.066757245039131, 3.106847276581197, 3.146426544510455, 3.1855140872392957, 3.224127789030702, 3.262284475639732, 3.3000000000000007, 3.3372893191930486, 3.374166563760598, 3.4106451002706217, 3.4467375879228177, 3.48245602987317, 3.5178118198675725, 3.552815784698104, 3.58747822293042, 3.6218089402948914, 3.6558172820861827, 3.689512162874653, 3.722902093797257, 3.7559952076646748, 3.7887992820945273, 3.8213217608570993, 3.853569773599539, 3.885550154096586, 3.9172694571601787, 3.9487339743264553, 3.97994974842648, 4.010922587136282, 4.0416580755922435, 4.072161588149468, 4.102438299353203, 4.1324931941867735, 4.162331077653483, 4.191956583744636, 4.221374183841087, 4.250588194591426, 4.279602785306132, 4.3084219849035215, 4.337049688440289, 4.365489663256575, 4.393745554763044, 4.421820891895103, 4.449719092257399, 4.477443466979791, 4.504997225304362, 4.532383478921438, 4.559605246071199, 4.586665455426198, 4.61356694976891, 4.640312489477406, 4.666904755831214, 4.693346354148605, 4.719639816765683, 4.745787605866913, 4.771792116176061, 4.797655677515844, 4.823380557244058, 4.848968962573385, 4.874423042781577, 4.899744891318323, 4.9249365478146006, 4.950000000000001, 4.974937185533101, 4.999749993749689], [0.0, 0.5196152422706632, 0.7348469228349536, 0.9000000000000001, 1.0392304845413265, 1.1618950038622253, 1.2727922061357857, 1.3747727084867523, 1.4696938456699071, 1.5588457268119895, 1.6431676725154984, 1.7233687939614089, 1.8000000000000003, 1.8734993995195197, 1.9442222095223582, 2.0124611797498106, 2.078460969082653, 2.1424285285628555, 2.2045407685048604, 2.2649503305812253, 2.3237900077244507, 2.381176179958132, 2.437211521390789, 2.491987158875423, 2.5455844122715714, 2.5980762113533165, 2.6495282598983545, 2.7000000000000006, 2.7495454169735045, 2.798213715926645, 2.846049894151542, 2.893095228297887, 2.9393876913398143, 2.9849623113198605, 3.029851481508624, 3.07408522978788, 3.117691453623979, 3.1606961258558224, 3.203123475609394, 3.244996147917591, 3.286335345030997, 3.327160951922826, 3.3674916480965478, 3.407345007480164, 3.4467375879228177, 3.4856850115866758, 3.5242020373412197, 3.5623026261113755, 3.6000000000000005, 3.637306695894643, 3.6742346141747677, 3.7107950630558952, 3.7469987990390394, 3.782856063875548, 3.818376618407357, 3.853569773599539, 3.8884444190447165, 3.9230090491866068, 3.9572717874818766, 3.9912404086950217, 4.024922359499621, 4.058324777540606, 4.091454509095757, 4.124318125460257, 4.156921938165306, 4.189272013130682, 4.221374183841087, 4.253234063627348, 4.284857057125711, 4.316248370981448, 4.3474130238568325, 4.378355855797928, 4.409081537009721, 4.439594576084623, 4.469899327725402, 4.5, 4.529900661162451, 4.5596052460712, 4.589117562233508, 4.618441295502197, 4.647580015448901, 4.67653718043597, 4.705316142407438, 4.73392015141785, 4.762352359916264, 4.790615826801395, 4.818713521262705, 4.846648326421054, 4.874423042781578, 4.902040391510458, 4.929503017546495, 4.956813492557493, 4.983974317750846, 5.010987926547021, 5.037856687124, 5.06458290484024, 5.091168824543143, 5.117616632769596, 5.143928459844674, 5.170106381884227, 5.196152422706633, 5.2220685556587645], [0.0, 0.5408326913195984, 0.7648529270389178, 0.9367496997597599, 1.0816653826391969, 1.2093386622447826, 1.3247641299491772, 1.4309088021254186, 1.5297058540778357, 1.622498073958795, 1.710263137648707, 1.79373911146521, 1.8734993995195197, 1.9500000000000002, 2.023610634484806, 2.094636006565341, 2.1633307652783937, 2.229910312097776, 2.2945587811167534, 2.357435046825257, 2.418677324489565, 2.478406746278746, 2.5367301787931646, 2.593742469868588, 2.6495282598983545, 2.704163456597992, 2.7577164466275357, 2.8102490992792797, 2.861817604250837, 2.9124731758421403, 2.962262648719725, 3.01122898498271, 3.0594117081556713, 3.1068472765811976, 3.153569406244296, 3.1996093511552317, 3.24499614791759, 3.2897568299191966, 3.3339166156339304, 3.377499074759311, 3.420526275297414, 3.463018914184559, 3.504996433664377, 3.5464771252610663, 3.58747822293042, 3.6280159867343476, 3.6681057781912454, 3.7077621282924826, 3.7469987990390394, 3.785828839237189, 3.8242646351945893, 3.8623179568751205, 3.9000000000000004, 3.9373214245220067, 3.9742923898475313, 4.010922587136282, 4.047221268969612, 4.08319727664486, 4.118859065323795, 4.154214727237869, 4.189272013130682, 4.224038352098617, 4.258520869973517, 4.292726406376255, 4.3266615305567875, 4.36033255612459, 4.393745554763043, 4.426906369012112, 4.459820624195552, 4.492493739561581, 4.524930938699507, 4.557137259288994, 4.589117562233507, 4.620876540224809, 4.6524187257812475, 4.683748498798799, 4.714870093650514, 4.745787605866913, 4.776504998427199, 4.80702610768862, 4.83735464897913, 4.867494221876386, 4.897448315194353, 4.927220311697052, 4.956813492557492, 4.9862310415783995, 5.015476049190148, 5.044551516240071, 5.073460357586329, 5.102205405508485, 5.130789412946121, 5.1592150565759525, 5.187484939737176, 5.215601595214114, 5.243567487884561, 5.271385017241674, 5.299056519796709, 5.326584271369412, 5.353970489272424, 5.38121733439563, 5.408326913195984, 5.435301279598033], [0.0, 0.5612486080160912, 0.7937253933193772, 0.9721111047611791, 1.1224972160321824, 1.2549900398011133, 1.374772708486752, 1.4849242404917498, 1.5874507866387544, 1.6837458240482734, 1.7748239349298847, 1.8614510468986285, 1.9442222095223582, 2.023610634484806, 2.0999999999999996, 2.1737065119284154, 2.244994432064365, 2.3140872930812266, 2.3811761799581315, 2.4464259645450137, 2.5099800796022267, 2.571964229922337, 2.6324893162176366, 2.6916537667389546, 2.749545416973504, 2.806243040080456, 2.861817604250837, 2.9163333142835373, 2.9698484809834995, 3.0224162519414826, 3.0740852297878796, 3.1248999983999486, 3.1749015732775088, 3.224127789030702, 3.2726136343907144, 3.3203915431767985, 3.367491648096547, 3.4139420030223127, 3.4597687784012385, 3.504996433664377, 3.5496478698597693, 3.593744565213282, 3.6373066958946425, 3.6803532439155884, 3.722902093797257, 3.7649701194033396, 3.8065732621348563, 3.8477266015141978, 3.8884444190447165, 3.9287402561126386, 3.968626966596886, 4.008116764766217, 4.047221268969612, 4.0859515415628715, 4.124318125460256, 4.162331077653482, 4.199999999999999, 4.2373340675476605, 4.274342054632503, 4.311032358959974, 4.347413023856831, 4.383491758860737, 4.41927595879687, 4.4547727214752495, 4.48998886412873, 4.524930938699506, 4.559605246071198, 4.594017849334066, 4.628174586162453, 4.662081080376016, 4.695742752749559, 4.729164831130333, 4.762352359916263, 4.795310208943734, 4.828043081829324, 4.860555523805895, 4.892851929090027, 4.924936547814601, 4.956813492557493, 4.988486744494767, 5.019960159204453, 5.051237472144821, 5.082322303829225, 5.113218164717793, 5.143928459844674, 5.174456493198103, 5.204805471869243, 5.234978509984544, 5.264978632435273, 5.294808778416837, 5.324471804789654, 5.353970489272424, 5.383307533477909, 5.4124855658006155, 5.441507144165116, 5.470374758643141, 5.499090833947008, 5.527657731806484, 5.556077753235639, 5.584353140695886, 5.612486080160912, 5.6404787030889505], [0.0, 0.5809475019311124, 0.8215838362577491, 1.0062305898749053, 1.1618950038622249, 1.299038105676658, 1.4230249470757705, 1.5370426148939396, 1.6431676725154982, 1.7428425057933372, 1.8371173070873834, 1.9267848867997694, 2.0124611797498106, 2.094636006565341, 2.1737065119284154, 2.2499999999999996, 2.3237900077244498, 2.3953079134006967, 2.4647515087732472, 2.53229145242012, 2.598076211353316, 2.662235902394827, 2.7248853186877424, 2.7861263431510066, 2.846049894151541, 2.9047375096555625, 2.962262648719725, 3.018691769624716, 3.074085229787879, 3.128498042192131, 3.181980515339464, 3.2345787979271736, 3.2863353450309964, 3.3372893191930486, 3.3874769371908644, 3.4369317712168796, 3.4856850115866744, 3.533765696816924, 3.581200915893996, 3.628015986734347, 3.674234614174767, 3.7198790302911733, 3.7649701194033396, 3.8095275297600875, 3.853569773599539, 3.8971143170299736, 3.940177660969109, 3.9827754142055256, 4.024922359499621, 4.066632513517788, 4.107919181288746, 4.1487950057818, 4.189272013130682, 4.229361653961505, 4.269074841227312, 4.308421984903521, 4.347413023856831, 4.386057455164034, 4.424364361125788, 4.462342434193054, 4.499999999999999, 4.537345038676252, 4.574385204593071, 4.611127844681819, 4.6475800154488995, 4.683748498798798, 4.719639816765682, 4.755260245244207, 4.790615826801393, 4.825712382643623, 4.860555523805895, 4.895150661624216, 4.9295030175464944, 4.963617632332289, 4.997499374687304, 5.031152949374526, 5.06458290484024, 5.097793640389929, 5.130789412946122, 5.163574343417552, 5.196152422706632, 5.228527517380013, 5.260703375025054, 5.2926836293132045, 5.324471804789654, 5.356071321407137, 5.387485498820391, 5.418717560456533, 5.449770637375485, 5.4806477719335325, 5.5113519212621505, 5.5418859605733495, 5.572252686302013, 5.60245481909493, 5.632495006655576, 5.6623758264530615, 5.692099788303082, 5.721669336828196, 5.751086853804243, 5.780354660399309, 5.809475019311125, 5.83845013680857], [0.0, 0.6, 0.848528137423857, 1.0392304845413265, 1.2, 1.341640786499874, 1.469693845669907, 1.5874507866387544, 1.697056274847714, 1.7999999999999998, 1.8973665961010275, 1.9899748742132402, 2.078460969082653, 2.1633307652783937, 2.244994432064365, 2.3237900077244498, 2.4, 2.4738633753705965, 2.545584412271571, 2.6153393661244047, 2.683281572999748, 2.749545416973504, 2.814249455894058, 2.8774989139876324, 2.939387691339814, 3.0, 3.0594117081556713, 3.1176914536239795, 3.1749015732775088, 3.2310988842807027, 3.286335345030997, 3.340658617698013, 3.394112549695428, 3.4467375879228177, 3.498571136907181, 3.5496478698597698, 3.5999999999999996, 3.649657518178932, 3.698648401781386, 3.746998799039039, 3.794733192202055, 3.84187454245971, 3.8884444190447165, 3.9344631145811997, 3.9799497484264803, 4.024922359499621, 4.069397989875161, 4.113392760240626, 4.156921938165306, 4.2, 4.242640687119286, 4.284857057125711, 4.3266615305567875, 4.368065933568311, 4.409081537009721, 4.449719092257398, 4.48998886412873, 4.52990066116245, 4.5694638635183455, 4.608687448721165, 4.6475800154488995, 4.686149805543993, 4.724404724407086, 4.762352359916263, 4.8, 4.8373546489791295, 4.874423042781576, 4.91121166312347, 4.947726750741193, 4.983974317750845, 5.019960159204453, 5.055689863905815, 5.091168824543142, 5.126402247190518, 5.1613951602255765, 5.196152422706632, 5.230678732248809, 5.264978632435274, 5.299056519796709, 5.332916650389354, 5.366563145999496, 5.4, 5.43323108288245, 5.466260147486579, 5.499090833947008, 5.531726674375733, 5.564171097297423, 5.596427431853289, 5.628498911788116, 5.660388679233963, 5.692099788303083, 5.723635208501674, 5.754997827975265, 5.786190456595774, 5.817215828899595, 5.848076606885378, 5.878775382679628, 5.909314681077664, 5.939696961966999, 5.969924622639721, 6.0, 6.029925372672536], [0.0, 0.618465843842649, 0.8746427842267951, 1.0712142642814275, 1.236931687685298, 1.3829316685939332, 1.5149257407543117, 1.6363068171953572, 1.7492855684535902, 1.855397531527947, 1.9557607215607946, 2.0512191496766015, 2.142428528562855, 2.229910312097776, 2.3140872930812266, 2.3953079134006967, 2.473863375370596, 2.55, 2.623928352680385, 2.6958301133417146, 2.7658633371878665, 2.834166544153678, 2.9008619408720575, 2.9660579899927786, 3.0298514815086235, 3.0923292192132457, 3.153569406244296, 3.213642792844283, 3.2726136343907144, 3.3305404966761776, 3.3874769371908644, 3.443472084974699, 3.4985711369071804, 3.5528157846981037, 3.606244584051393, 3.6588932752951404, 3.710795063055894, 3.7619808611953363, 3.8124795081416503, 3.86231795687512, 3.9115214431215892, 3.960113634733226, 4.008116764766216, 4.055551750378732, 4.102438299353203, 4.148795005781799, 4.194639436232869, 4.239988207530771, 4.28485705712571, 4.3292609068985435, 4.373213921133976, 4.416729559300638, 4.459820624195552, 4.5024993059410905, 4.544777222262935, 4.586665455426196, 4.628174586162453, 4.669314724882014, 4.710095540432275, 4.750526286633934, 4.790615826801393, 4.830372656431385, 4.869804924224378, 4.908920451586072, 4.947726750741192, 4.986231041578398, 5.024440267333268, 5.062361109205861, 5.1, 5.1373631368631125, 5.174456493198102, 5.211285829812063, 5.24785670536077, 5.284174486142561, 5.32024435529046, 5.356071321407137, 5.391660226683429, 5.427015754537663, 5.4621424368099385, 5.497044660542609, 5.531726674375733, 5.566192594583843, 5.600446410778341, 5.634491991297884, 5.668333088307356, 5.7019733426244645, 5.735416288291549, 5.768665356908823, 5.801723881744115, 5.834595101633018, 5.867282164682384, 5.8997881317891405, 5.932115979985557, 5.964268605621314, 5.996248827392005, 6.028059389223036, 6.059702963017247, 6.0911821512740865, 6.122499489587565, 6.153657449029805, 6.184658438426491, 6.2155048065302], [0.0, 0.6363961030678927, 0.9, 1.1022703842524302, 1.2727922061357855, 1.423024947075771, 1.5588457268119897, 1.6837458240482737, 1.8, 1.909188309203678, 2.0124611797498106, 2.1106870919205436, 2.2045407685048604, 2.2945587811167534, 2.3811761799581315, 2.4647515087732472, 2.545584412271571, 2.623928352680385, 2.6999999999999997, 2.77398630133604, 2.846049894151542, 2.9163333142835373, 2.98496231131986, 3.0520484924063713, 3.1176914536239795, 3.181980515339464, 3.2449961479175906, 3.3068111527572905, 3.3674916480965473, 3.4270978976387587, 3.4856850115866753, 3.543303543305315, 3.6, 3.6558172820861827, 3.710795063055895, 3.76497011940334, 3.818376618407356, 3.8710463701691826, 3.9230090491866063, 3.9742923898475313, 4.024922359499621, 4.074923312161838, 4.124318125460256, 4.173128322973066, 4.221374183841087, 4.2690748412273125, 4.316248370981448, 4.3629118716746955, 4.409081537009721, 4.4547727214752495, 4.5, 4.544777222262936, 4.589117562233507, 4.633033563444151, 4.676537180435969, 4.719639816765682, 4.762352359916263, 4.80468521341409, 4.846648326421055, 4.888251221040097, 4.9295030175464944, 4.970412457734268, 5.01098792654702, 5.051237472144821, 5.091168824543142, 5.130789412946121, 5.170106381884225, 5.209126606255601, 5.24785670536077, 5.286303056011829, 5.324471804789654, 5.362368879515843, 5.3999999999999995, 5.437370688117557, 5.474486277268398, 5.5113519212621505, 5.54797260267208, 5.584353140695886, 5.620498198558559, 5.656412290489441, 5.692099788303084, 5.727564927611035, 5.762811813689564, 5.797844427026306, 5.8326666285670745, 5.8672821646823845, 5.901694671871802, 5.9359076812228135, 5.96992462263972, 6.003748828856851, 6.037383539249432, 6.070831903454419, 6.104096984812743, 6.137181763643636, 6.17008914036094, 6.2028219384406, 6.235382907247959, 6.267774724732854, 6.3, 6.332061275761631, 6.363961030678928, 6.3957016815983545], [0.0, 0.653834841531101, 0.9246621004453466, 1.1324751652906127, 1.307669683062202, 1.462019151721345, 1.601561737804697, 1.7298843892006197, 1.8493242008906932, 1.9615045245933032, 2.0676073128135335, 2.1685248442201446, 2.2649503305812253, 2.3574350468252567, 2.4464259645450137, 2.53229145242012, 2.615339366124404, 2.6958301133417146, 2.7739863013360395, 2.8500000000000005, 2.92403830344269, 2.996247653315727, 3.0667572450391316, 3.1356817440550317, 3.203123475609394, 3.2691742076555057, 3.3339166156339313, 3.397425495871838, 3.4597687784012394, 3.521008378291651, 3.581200915893997, 3.6403983298534794, 3.6986484017813863, 3.755995207664675, 3.812479508141651, 3.8681390874682884, 3.9230090491866063, 3.9771220750688565, 4.030508652763321, 4.08319727664486, 4.135214625627067, 4.1865857210858595, 4.2373340675476605, 4.287481778386935, 4.337049688440289, 4.386057455164035, 4.434523649728345, 4.48246583924518, 4.529900661162451, 4.576843890717708, 4.623310502226733, 4.669314724882015, 4.7148700936505135, 4.75998949578673, 4.804685213414091, 4.848968962573385, 4.892851929090027, 4.936344801571301, 4.9794578018093505, 5.022200712834962, 5.06458290484024, 5.106613359164761, 5.148300690519155, 5.1896531676018585, 5.230678732248808, 5.271385017241674, 5.311779362887732, 5.351868832473382, 5.391660226683429, 5.431160097069502, 5.470374758643142, 5.509310301662088, 5.547972602672079, 5.586367334860823, 5.624499977775803, 5.662375826453062, 5.700000000000001, 5.737377449671584, 5.774512966476049, 5.811411188343156, 5.84807660688538, 5.884513573779911, 5.9207263067971665, 5.956718895499434, 5.992495306631454, 6.028059389223038, 6.063414879422322, 6.098565405076837, 6.133514490078263, 6.168265558485627, 6.2028219384406, 6.237186865887538, 6.2713634881100635, 6.3053548670951125, 6.339163982734632, 6.372793735874401, 6.406246951218788, 6.439526380099706, 6.472634703117425, 6.505574532660433, 6.538348415311011, 6.570958834142855], [0.0, 0.6708203932499369, 0.9486832980505139, 1.1618950038622253, 1.3416407864998738, 1.5000000000000002, 1.6431676725154984, 1.7748239349298849, 1.8973665961010278, 2.0124611797498106, 2.121320343559643, 2.224859546128699, 2.3237900077244507, 2.418677324489565, 2.5099800796022267, 2.598076211353316, 2.6832815729997477, 2.7658633371878665, 2.8460498941515415, 2.9240383034426896, 3.0000000000000004, 3.0740852297878796, 3.1464265445104553, 3.217141588429083, 3.286335345030997, 3.3541019662496847, 3.4205262752974144, 3.4856850115866758, 3.5496478698597698, 3.612478373637689, 3.6742346141747677, 3.73496987939662, 3.7947331922020555, 3.8535697735995393, 3.91152144312159, 3.968626966596886, 4.024922359499621, 4.080441152620634, 4.135214625627067, 4.189272013130683, 4.242640687119286, 4.295346318982906, 4.347413023856832, 4.398863489584554, 4.449719092257398, 4.5, 4.549725266430931, 4.598912915026768, 4.647580015448901, 4.695742752749559, 4.74341649025257, 4.790615826801394, 4.83735464897913, 4.883646178829912, 4.929503017546495, 4.9749371855331, 5.019960159204453, 5.06458290484024, 5.108815909777921, 5.152669211195301, 5.196152422706632, 5.239274758971895, 5.282045058497703, 5.324471804789655, 5.366563145999495, 5.408326913195984, 5.449770637375485, 5.490901565316938, 5.531726674375733, 5.572252686302013, 5.612486080160913, 5.6524331044250316, 5.692099788303083, 5.73149195236284, 5.770615218501404, 5.809475019311125, 5.848076606885379, 5.886425061104576, 5.924525297439451, 5.962382074305538, 6.000000000000001, 6.037383539249433, 6.074537019394977, 6.111464636239009, 6.148170459575759, 6.184658438426492, 6.220932405998317, 6.256996084384263, 6.292853089020911, 6.328506932918696, 6.3639610306789285, 6.399218702310463, 6.434283176858166, 6.469157595854349, 6.50384501660364, 6.5383484153110105, 6.572670690061994, 6.606814663663574, 6.640783086353596, 6.674578638386098, 6.708203932499369, 6.741661516273272], [0.0, 0.687386354243376, 0.9721111047611791, 1.190588089979066, 1.374772708486752, 1.53704261489394, 1.6837458240482739, 1.8186533479473213, 1.9442222095223582, 2.062159062730128, 2.173706511928416, 2.2798026230355997, 2.381176179958132, 2.478406746278746, 2.571964229922337, 2.662235902394827, 2.749545416973504, 2.834166544153678, 2.9163333142835373, 2.996247653315727, 3.07408522978788, 3.1500000000000004, 3.224127789030702, 3.2965891463753874, 3.3674916480965478, 3.43693177121688, 3.5049964336643775, 3.571764269937198, 3.6373066958946425, 3.70168880377592, 3.7649701194033405, 3.827205246651922, 3.8884444190447165, 3.948733974326456, 4.008116764766217, 4.066632513517788, 4.124318125460256, 4.181207959429907, 4.2373340675476605, 4.292726406376256, 4.347413023856832, 4.401420225336364, 4.4547727214752495, 4.507493760395016, 4.559605246071199, 4.611127844681819, 4.662081080376017, 4.712483421721503, 4.762352359916264, 4.811704479703633, 4.860555523805895, 4.908920451586073, 4.956813492557492, 5.004248195283684, 5.051237472144821, 5.097793640389929, 5.143928459844674, 5.1896531676018585, 5.234978509984545, 5.279914772039413, 5.324471804789654, 5.368659050451985, 5.412485565800615, 5.455960043841964, 5.499090833947008, 5.5418859605733495, 5.584353140695885, 5.626499800053315, 5.668333088307356, 5.709859893202284, 5.751086853804245, 5.792020372892347, 5.8326666285670745, 5.8730315851355686, 5.913121003328108, 5.952940449895329, 5.992495306631454, 6.031790778864931, 6.07083190345442, 6.109623556324891, 6.14817045957576, 6.186477188190385, 6.224548176373929, 6.262387723544431, 6.300000000000001, 6.337389052283283, 6.3745588082627345, 6.411513081948754, 6.448255578061404, 6.484789896365187, 6.521119535785248, 6.557247898318319, 6.593178292750775, 6.628913938195307, 6.664457967456919, 6.699813430238189, 6.7349832961930955, 6.769970457838056, 6.804777733328253, 6.8394078691068, 6.87386354243376, 6.908147363801675], [0.0, 0.7035623639735145, 0.99498743710662, 1.2186057606953942, 1.407124727947029, 1.5732132722552277, 1.7233687939614086, 1.8614510468986285, 1.98997487421324, 2.110687091920543, 2.224859546128699, 2.333452377915607, 2.4372115213907883, 2.5367301787931646, 2.6324893162176366, 2.7248853186877424, 2.814249455894058, 2.9008619408720575, 2.98496231131986, 3.066757245039131, 3.1464265445104553, 3.224127789030702, 3.3000000000000003, 3.3741665637605984, 3.4467375879228173, 3.5178118198675725, 3.58747822293042, 3.6558172820861827, 3.722902093797257, 3.788799282094527, 3.853569773599539, 3.9172694571601787, 3.97994974842648, 4.041658075592244, 4.102438299353204, 4.162331077653483, 4.221374183841086, 4.279602785306132, 4.337049688440288, 4.3937455547630435, 4.449719092257398, 4.504997225304362, 4.559605246071199, 4.613566949768909, 4.666904755831214, 4.719639816765682, 4.77179211617606, 4.823380557244058, 4.874423042781577, 4.924936547814601, 4.974937185533101, 5.024440267333269, 5.073460357586329, 5.122011323689162, 5.170106381884226, 5.217758139277826, 5.264978632435273, 5.311779362887732, 5.358171329847527, 5.404165060395546, 5.449770637375485, 5.494997725204261, 5.539855593785816, 5.584353140695886, 5.628498911788116, 5.672301120356711, 5.715767664977295, 5.75890614613574, 5.801723881744115, 5.844227921633447, 5.886425061104576, 5.928321853610852, 5.96992462263972, 6.011239472854164, 6.052272300549604, 6.093028803476971, 6.133514490078262, 6.173734688177004, 6.213694553162395, 6.25339907570275, 6.292853089020911, 6.332061275761631, 6.371028174478591, 6.4097581857664485, 6.448255578061404, 6.486524493131897, 6.5245689512794645, 6.5623928562682075, 6.6000000000000005, 6.637394066951276, 6.674578638386097, 6.711557196359128, 6.748333127521197, 6.784909726739186, 6.821290200541244, 6.8574776703974765, 6.8934751758456345, 6.929285677470659, 6.964912059746339, 7.000357133746822, 7.035623639735145, 7.070714249635607], [0.0, 0.719374728496908, 1.0173494974687902, 1.2459935794377115, 1.438749456993816, 1.6085707942145415, 1.7621010186706099, 1.9032866310674281, 2.0346989949375804, 2.1581241854907236, 2.2748626332154656, 2.38589605808803, 2.491987158875423, 2.5937424698685874, 2.691653766738954, 2.7861263431510066, 2.877498913987632, 2.9660579899927786, 3.052048492406371, 3.1356817440550313, 3.217141588429083, 3.296589146375387, 3.3741665637605984, 3.450000000000001, 3.5242020373412197, 3.59687364248454, 3.668105778191246, 3.737980738313134, 3.8065732621348563, 3.8739514710434877, 3.9401776609691095, 4.0053089768456065, 4.069397989875161, 4.132493194186774, 4.19463943623287, 4.255878287733332, 4.316248370981447, 4.375785643744448, 4.434523649728345, 4.492493739561581, 4.549725266430931, 4.606245759835227, 4.662081080376017, 4.717255558054916, 4.77179211617606, 4.825712382643624, 4.879036790187178, 4.931784666832079, 4.983974317750846, 5.035623099478356, 5.086747487343952, 5.137363136863113, 5.187484939737175, 5.237127075028829, 5.286303056011829, 5.335025773133622, 5.383307533477908, 5.431160097069502, 5.478594710324903, 5.525622136918159, 5.572252686302013, 5.6184962400984135, 5.664362276549762, 5.709859893202284, 5.754997827975264, 5.799784478754361, 5.844227921633447, 5.888335927917156, 5.932115979985557, 5.975575286112627, 6.0187207943216645, 6.061559205353026, 6.104096984812742, 6.146340374564364, 6.188295403420881, 6.229967897188557, 6.271363488110063, 6.312487623750245, 6.353345575364213, 6.393942445784135, 6.434283176858166, 6.474372556472172, 6.51421522518254, 6.553815682486043, 6.593178292750774, 6.632307290830244, 6.671206787381127, 6.709880773903513, 6.748333127521197, 6.786567615518172, 6.824587899646396, 6.862397540218725, 6.900000000000002, 6.937398647908308, 6.974596762537603, 7.011597535512147, 7.0484040746824395, 7.085019407171728, 7.121446482281532, 7.157688174264091, 7.19374728496908, 7.229626546371536], [0.0, 0.7348469228349535, 1.0392304845413265, 1.2727922061357857, 1.469693845669907, 1.6431676725154987, 1.8, 1.9442222095223582, 2.078460969082653, 2.20454076850486, 2.32379000772445, 2.4372115213907883, 2.5455844122715714, 2.649528259898354, 2.749545416973504, 2.846049894151541, 2.939387691339814, 3.0298514815086235, 3.117691453623979, 3.203123475609394, 3.2863353450309973, 3.3674916480965473, 3.4467375879228177, 3.5242020373412197, 3.6, 3.6742346141747673, 3.7469987990390394, 3.818376618407357, 3.8884444190447165, 3.957271787481876, 4.024922359499621, 4.091454509095757, 4.156921938165306, 4.221374183841087, 4.284857057125711, 4.347413023856832, 4.40908153700972, 4.469899327725402, 4.52990066116245, 4.589117562233507, 4.6475800154489, 4.705316142407437, 4.762352359916263, 4.818713521262703, 4.874423042781577, 4.929503017546495, 4.983974317750845, 5.037856687123999, 5.091168824543143, 5.143928459844674, 5.196152422706632, 5.247856705360771, 5.299056519796708, 5.349766350038103, 5.4, 5.449770637375485, 5.499090833947008, 5.547972602672079, 5.59642743185329, 5.644466316668034, 5.692099788303082, 5.739337940912698, 5.786190456595773, 5.8326666285670745, 5.878775382679628, 5.924525297439449, 5.969924622639719, 6.014981296729026, 6.059702963017247, 6.104096984812742, 6.148170459575759, 6.191930232165088, 6.235382907247958, 6.278534860936905, 6.321392251711644, 6.363961030678928, 6.406246951218788, 6.448255578061404, 6.489992295835182, 6.5314623171231725, 6.572670690061995, 6.613622305514582, 6.654321903845651, 6.694774081326419, 6.734983296193095, 6.774953874381731, 6.81469001496033, 6.854195795277517, 6.893475175845635, 6.9325320049748065, 6.971370023173351, 7.009992867328754, 7.0484040746824395, 7.086607086610631, 7.124605252222751, 7.162401831787993, 7.2, 7.237402849088893, 7.274613391789284, 7.3116345641723655, 7.3484692283495345, 7.385120175054705], [0.0, 0.75, 1.0606601717798214, 1.2990381056766582, 1.5, 1.6770509831248426, 1.8371173070873839, 1.984313483298443, 2.121320343559643, 2.25, 2.3717082451262845, 2.4874685927665503, 2.5980762113533165, 2.704163456597992, 2.806243040080456, 2.9047375096555625, 3.0, 3.0923292192132457, 3.181980515339464, 3.2691742076555057, 3.354101966249685, 3.43693177121688, 3.5178118198675725, 3.5968736424845407, 3.6742346141747677, 3.7500000000000004, 3.8242646351945893, 3.8971143170299745, 3.968626966596886, 4.0388736053508785, 4.107919181288747, 4.175823272122517, 4.242640687119286, 4.308421984903522, 4.373213921133976, 4.437059837324712, 4.5, 4.562071897723666, 4.623310502226732, 4.683748498798799, 4.743416490252569, 4.802343178074637, 4.860555523805895, 4.9180788932265, 4.974937185533101, 5.031152949374527, 5.086747487343952, 5.141740950300783, 5.196152422706633, 5.250000000000001, 5.303300858899107, 5.356071321407138, 5.408326913195984, 5.46008241696039, 5.511351921262151, 5.562148865321747, 5.612486080160912, 5.662375826453062, 5.711829829397932, 5.7608593109014565, 5.809475019311125, 5.857687256929991, 5.905505905508858, 5.952940449895329, 6.0, 6.046693311223912, 6.093028803476971, 6.139014578904337, 6.184658438426491, 6.229967897188557, 6.274950199005567, 6.319612329882269, 6.363961030678928, 6.408002808988149, 6.451743950281971, 6.49519052838329, 6.538348415311011, 6.581223290544092, 6.623820649745887, 6.666145812986692, 6.70820393249937, 6.750000000000001, 6.791538853603063, 6.832825184358224, 6.87386354243376, 6.914658342969667, 6.955213871621779, 6.995534289816612, 7.035623639735145, 7.075485849042454, 7.115124735378854, 7.1545440106270926, 7.193747284969081, 7.232738070744718, 7.271519786124494, 7.310095758606723, 7.348469228349535, 7.38664335134708, 7.424621202458749, 7.462405778299651, 7.500000000000001, 7.537406715840669], [0.0, 0.7648529270389177, 1.0816653826391969, 1.3247641299491772, 1.5297058540778354, 1.7102631376487074, 1.8734993995195197, 2.0236106344848066, 2.1633307652783937, 2.294558781116753, 2.418677324489565, 2.5367301787931646, 2.6495282598983545, 2.7577164466275357, 2.8618176042508368, 2.962262648719725, 3.059411708155671, 3.153569406244296, 3.2449961479175906, 3.333916615633931, 3.420526275297415, 3.504996433664377, 3.58747822293042, 3.668105778191246, 3.7469987990390394, 3.824264635194589, 3.900000000000001, 3.9742923898475317, 4.047221268969613, 4.118859065323795, 4.189272013130683, 4.258520869973517, 4.3266615305567875, 4.3937455547630435, 4.459820624195553, 4.524930938699507, 4.589117562233506, 4.6524187257812475, 4.7148700936505135, 4.776504998427198, 4.83735464897913, 4.897448315194353, 4.956813492557492, 5.015476049190146, 5.073460357586329, 5.130789412946121, 5.187484939737176, 5.243567487884561, 5.299056519796709, 5.353970489272425, 5.408326913195984, 5.4621424368099385, 5.515432893255071, 5.568213357981176, 5.620498198558559, 5.672301120356711, 5.7236352085016735, 5.774512966476048, 5.8249463516842805, 5.874946808269842, 5.92452529743945, 5.973692325521964, 6.022457969965419, 6.070831903454419, 6.118823416311342, 6.16644143732834, 6.2136945531623935, 6.2605910264127616, 6.307138812488592, 6.353345575364211, 6.399218702310463, 6.444765317682251, 6.489992295835181, 6.53490627323759, 6.579513659838393, 6.623820649745885, 6.667833231267862, 6.711557196359129, 6.754998149518623, 6.798161516174797, 6.84105255059483, 6.883676343350261, 6.926037828369118, 6.968141789602161, 7.009992867328754, 7.051595564125897, 7.092954250522135, 7.134073170356469, 7.17495644586084, 7.215608082483417, 7.256031973468695, 7.296231904209186, 7.336211556382492, 7.375974511886549, 7.415524256584966, 7.454864183873506, 7.493997598078079, 7.532927717693833, 7.571657678474377, 7.610190536379495, 7.648529270389178, 7.686676785191376], [0.0, 0.7794228634059948, 1.1022703842524302, 1.35, 1.5588457268119895, 1.7428425057933379, 1.9091883092036785, 2.062159062730128, 2.2045407685048604, 2.338268590217984, 2.4647515087732477, 2.585053190942113, 2.7, 2.8102490992792792, 2.9163333142835373, 3.018691769624716, 3.117691453623979, 3.213642792844283, 3.3068111527572905, 3.397425495871838, 3.4856850115866758, 3.5717642699371974, 3.6558172820861827, 3.7379807383131345, 3.818376618407357, 3.897114317029974, 3.9742923898475317, 4.050000000000001, 4.124318125460256, 4.197320573889967, 4.2690748412273125, 4.33964284244683, 4.409081537009721, 4.477443466979791, 4.544777222262936, 4.611127844681819, 4.676537180435968, 4.741044188783733, 4.80468521341409, 4.867494221876386, 4.929503017546495, 4.990741427884238, 5.051237472144821, 5.111017511220246, 5.170106381884226, 5.228527517380013, 5.286303056011829, 5.343453939167063, 5.4, 5.455960043841964, 5.511351921262151, 5.566192594583843, 5.6204981985585585, 5.674284095813322, 5.727564927611035, 5.780354660399309, 5.8326666285670745, 5.88451357377991, 5.935907681222814, 5.9868606130425315, 6.037383539249432, 6.087487166310908, 6.137181763643635, 6.186477188190384, 6.235382907247958, 6.283908019696024, 6.33206127576163, 6.379851095441022, 6.427285585688566, 6.474372556472171, 6.521119535785248, 6.5675337836968914, 6.613622305514581, 6.659391864126935, 6.704848991588103, 6.75, 6.794850991743676, 6.839407869106799, 6.8836763433502615, 6.927661943253295, 6.9713700231733515, 7.014805770653954, 7.057974213611156, 7.100880227126775, 7.143528539874395, 7.185923740202092, 7.228070281894056, 7.269972489631581, 7.3116345641723655, 7.353060587265687, 7.3942545263197434, 7.435220238836238, 7.475961476626269, 7.516481889820532, 7.556785030686, 7.59687435726036, 7.636753236814714, 7.676424949154393, 7.715892689767011, 7.75515957282634, 7.794228634059948, 7.833102833488146], [0.0, 0.7937253933193772, 1.1224972160321824, 1.374772708486752, 1.5874507866387544, 1.774823934929885, 1.9442222095223582, 2.1, 2.244994432064365, 2.3811761799581315, 2.5099800796022267, 2.632489316217637, 2.749545416973504, 2.861817604250837, 2.9698484809834995, 3.074085229787879, 3.1749015732775088, 3.2726136343907144, 3.3674916480965473, 3.4597687784012394, 3.54964786985977, 3.6373066958946425, 3.7229020937972575, 3.8065732621348567, 3.8884444190447165, 3.968626966596886, 4.047221268969613, 4.124318125460256, 4.2, 4.274342054632502, 4.347413023856832, 4.419275958796871, 4.48998886412873, 4.5596052460712, 4.628174586162454, 4.695742752749559, 4.762352359916263, 4.828043081829325, 4.892851929090027, 4.956813492557492, 5.019960159204453, 5.082322303829225, 5.143928459844674, 5.204805471869241, 5.264978632435274, 5.324471804789654, 5.383307533477908, 5.441507144165116, 5.499090833947008, 5.556077753235641, 5.612486080160912, 5.668333088307356, 5.723635208501674, 5.7784080852774675, 5.8326666285670745, 5.886425061104575, 5.939696961966999, 5.9924953066314535, 6.044832503882966, 6.096720429870472, 6.148170459575758, 6.199193495931548, 6.249799996799897, 6.3, 6.3498031465550175, 6.3992187023104625, 6.448255578061403, 6.496922348312315, 6.545227268781429, 6.593178292750773, 6.640783086353597, 6.688049042882386, 6.734983296193095, 6.7815927332743895, 6.827884006044625, 6.87386354243376, 6.919537556802479, 6.96491205974634, 7.009992867328755, 7.0547856097829085, 7.09929573971954, 7.143528539874396, 7.187489130426564, 7.231182475916369, 7.274613391789285, 7.317786550590282, 7.360706487831179, 7.40337760755184, 7.445804187594515, 7.487990384609211, 7.52994023880668, 7.571657678474378, 7.613146524269713, 7.654410493303845, 7.695453203028396, 7.736278174936576, 7.776888838089433, 7.817288532477231, 7.857480512225276, 7.897467948652911, 7.937253933193772, 7.9768414801850005], [0.0, 0.8077747210701757, 1.1423659658795864, 1.3991068579633223, 1.6155494421403513, 1.8062391868188445, 1.978635893740938, 2.1371710273162514, 2.2847319317591728, 2.423324163210527, 2.55440795488896, 2.6790856649237633, 2.7982137159266447, 2.91247317584214, 3.0224162519414826, 3.1284980421921316, 3.2310988842807027, 3.330540496676178, 3.4270978976387587, 3.5210083782916515, 3.612478373637689, 3.70168880377592, 3.7887992820945273, 3.873951471043488, 3.957271787481876, 4.0388736053508785, 4.118859065323795, 4.197320573889967, 4.274342054632503, 4.3500000000000005, 4.424364361125789, 4.497499305169486, 4.5694638635183455, 4.640312489477407, 4.710095540432275, 4.778859696622198, 4.846648326421054, 4.913501806247761, 4.97945780180935, 5.044551516240071, 5.10881590977792, 5.172281894870001, 5.234978509984545, 5.2969330749028725, 5.358171329847527, 5.418717560456534, 5.478594710324903, 5.53782448259242, 5.596427431853289, 5.65442304749123, 5.7118298293979315, 5.768665356908824, 5.82494635168428, 5.880688735173798, 5.935907681222814, 5.990617664314757, 6.044832503882965, 6.098565405076837, 6.151828996322965, 6.204635363983931, 6.256996084384263, 6.308922253443928, 6.360424514134257, 6.411513081948754, 6.462197768561405, 6.512488003827723, 6.5623928562682075, 6.611921052160257, 6.661080993352356, 6.709880773903513, 6.758328195641287, 6.806430782723057, 6.854195795277517, 6.901630242196405, 6.9487408931402825, 6.995534289816612, 7.042016756583303, 7.0881944104263965, 7.134073170356471, 7.179658766264592, 7.224956747275378, 7.269972489631582, 7.314711204141966, 7.359177943221647, 7.40337760755184, 7.447314952383847, 7.4909945935102655, 7.534421012924617, 7.577598564189055, 7.620531477528323, 7.663223864666881, 7.705679723424794, 7.747902942086976, 7.789897303559273, 7.831666489323968, 7.873214083206426, 7.914543574963752, 7.955658363705673, 7.996561761157103, 8.03725699477129, 8.077747210701757, 8.118035476640888], [0.0, 0.8215838362577491, 1.161895003862225, 1.4230249470757708, 1.6431676725154982, 1.8371173070873836, 2.0124611797498106, 2.173706511928416, 2.32379000772445, 2.4647515087732472, 2.598076211353316, 2.7248853186877424, 2.8460498941515415, 2.9622626487197246, 3.074085229787879, 3.1819805153394634, 3.2863353450309964, 3.3874769371908644, 3.485685011586675, 3.5812009158939966, 3.6742346141747673, 3.7649701194033396, 3.853569773599539, 3.9401776609691095, 4.024922359499621, 4.107919181288746, 4.189272013130682, 4.2690748412273125, 4.347413023856832, 4.424364361125788, 4.5, 4.574385204593072, 4.6475800154489, 4.719639816765683, 4.790615826801393, 4.860555523805895, 4.9295030175464944, 4.997499374687305, 5.064582904840239, 5.130789412946121, 5.196152422706632, 5.260703375025055, 5.324471804789654, 5.38748549882039, 5.449770637375485, 5.5113519212621505, 5.572252686302013, 5.632495006655575, 5.692099788303083, 5.751086853804244, 5.809475019311125, 5.8672821646823845, 5.924525297439449, 5.981220611213066, 6.037383539249432, 6.09302880347697, 6.148170459575758, 6.202821938440599, 6.256996084384263, 6.310705190388788, 6.363961030678927, 6.416774890862231, 6.469157595854346, 6.521119535785247, 6.572670690061993, 6.623820649745884, 6.674578638386095, 6.724953531437968, 6.774953874381729, 6.824587899646395, 6.87386354243376, 6.922788455528595, 6.97137002317335, 7.019615374078554, 7.067531393633847, 7.115124735378853, 7.162401831787993, 7.20936890441875, 7.256031973468695, 7.302396866782851, 7.3484692283495345, 7.394254526319743, 7.439758060582347, 7.484984969924788, 7.529940238806679, 7.574628703771559, 7.619055059520177, 7.66322386466688, 7.707139547199078, 7.750806409658288, 7.794228634059947, 7.837410286567878, 7.880355321938219, 7.923067587746555, 7.965550828411052, 8.007808689023483, 8.049844718999243, 8.091662375556707, 8.133265027035574, 8.174655956063228, 8.215838362577491, 8.256815366713733], [0.0, 0.8351646544245033, 1.1811011811017718, 1.4465476141489433, 1.6703293088490065, 1.8674849396983102, 2.0457272545478786, 2.2096379793984355, 2.3622023622035435, 2.50549396327351, 2.6410225292488514, 2.7699277968929086, 2.8930952282978866, 3.0112289849827096, 3.1248999983999486, 3.2345787979271736, 3.340658617698013, 3.443472084974699, 3.543303543305315, 3.6403983298534794, 3.7349698793966204, 3.827205246651922, 3.9172694571601787, 4.005308976845607, 4.091454509095757, 4.175823272122517, 4.258520869973517, 4.33964284244683, 4.419275958796871, 4.497499305169485, 4.574385204593072, 4.65, 4.724404724407087, 4.797655677515843, 4.869804924224378, 4.940900727600181, 5.01098792654702, 5.0801082665628305, 5.148300690519154, 5.215601595214113, 5.282045058497703, 5.347663040992766, 5.412485565800615, 5.4765408790586045, 5.539855593785817, 5.6024548190949295, 5.664362276549762, 5.725600405197694, 5.786190456595773, 5.846152580971523, 5.905505905508859, 5.964268605621314, 6.022457969965419, 6.080090459853373, 6.137181763643635, 6.193746846618773, 6.249799996799897, 6.305354867095111, 6.360424514134258, 6.415021434102929, 6.469157595854347, 6.52284447154767, 6.576093065034891, 6.628913938195306, 6.681317235396026, 6.733312706239031, 6.784909726739184, 6.836117319063504, 6.886944169949398, 6.9373986479083065, 6.98748881931127, 7.03722246344394, 7.08660708661063, 7.135649935359778, 7.184358008896829, 7.232738070744716, 7.280796659706959, 7.328540100183665, 7.375974511886549, 7.4231058189951735, 7.469939758793241, 7.516481889820531, 7.562737599573319, 7.608712111783438, 7.654410493303844, 7.69983766062636, 7.744998386055353, 7.789897303559271, 7.834538914320357, 7.878927592001338, 7.923067587746554, 7.966963034933701, 8.010617953691215, 8.05403625519528, 8.097221745759468, 8.140178130729081, 8.182909018191515, 8.225417922513119, 8.2677082677124, 8.309783390678726, 8.351646544245034, 8.39330090012267], [0.0, 0.848528137423857, 1.2, 1.469693845669907, 1.697056274847714, 1.8973665961010278, 2.078460969082653, 2.244994432064365, 2.4, 2.545584412271571, 2.6832815729997477, 2.814249455894058, 2.939387691339814, 3.059411708155671, 3.1749015732775083, 3.2863353450309964, 3.394112549695428, 3.4985711369071804, 3.5999999999999996, 3.6986484017813863, 3.7947331922020555, 3.888444419044716, 3.97994974842648, 4.069397989875162, 4.156921938165306, 4.242640687119285, 4.3266615305567875, 4.409081537009721, 4.48998886412873, 4.569463863518345, 4.6475800154489, 4.724404724407086, 4.8, 4.874423042781577, 4.947726750741193, 5.019960159204453, 5.091168824543142, 5.1613951602255765, 5.230678732248808, 5.299056519796708, 5.366563145999495, 5.43323108288245, 5.499090833947008, 5.564171097297422, 5.628498911788116, 5.692099788303082, 5.754997827975264, 5.817215828899594, 5.878775382679628, 5.939696961966999, 6.0, 6.059702963017247, 6.118823416311342, 6.177378084592201, 6.235382907247958, 6.292853089020909, 6.349803146555017, 6.406246951218787, 6.462197768561405, 6.517668294720129, 6.572670690061993, 6.627216610312357, 6.681317235396026, 6.734983296193095, 6.788225099390856, 6.841052550594827, 6.893475175845634, 6.945502141674135, 6.997142273814361, 7.048404074682438, 7.0992957397195395, 7.149825172687791, 7.199999999999999, 7.249827584156743, 7.299315036357863, 7.348469228349534, 7.397296803562773, 7.445804187594514, 7.493997598078079, 7.541883053985921, 7.589466384404111, 7.636753236814714, 7.683749084919419, 7.730459236035075, 7.776888838089432, 7.823042886243179, 7.868926229162402, 7.914543574963751, 7.95989949685296, 8.0049984384758, 8.049844718999243, 8.094442537939225, 8.138795979750324, 8.182909018191515, 8.226785520481252, 8.270429251254132, 8.313843876330612, 8.357032966310472, 8.399999999999999, 8.442748367682174, 8.48528137423857, 8.527602242131138], [0.0, 0.8616843969807043, 1.2186057606953942, 1.4924811556599302, 1.7233687939614086, 1.9267848867997697, 2.1106870919205436, 2.2798026230355997, 2.4372115213907883, 2.585053190942113, 2.724885318687743, 2.857883832488648, 2.9849623113198605, 3.106847276581197, 3.2241277890307014, 3.337289319193048, 3.4467375879228173, 3.5528157846981037, 3.6558172820861823, 3.755995207664675, 3.8535697735995393, 3.9487339743264553, 4.041658075592244, 4.132493194186774, 4.221374183841087, 4.308421984903522, 4.3937455547630435, 4.477443466979791, 4.559605246071199, 4.640312489477407, 4.719639816765683, 4.797655677515843, 4.874423042781577, 4.950000000000001, 5.024440267333269, 5.097793640389929, 5.170106381884226, 5.2414215628968455, 5.311779362887733, 5.38121733439563, 5.449770637375486, 5.517472247324857, 5.584353140695886, 5.650442460551209, 5.715767664977296, 5.780354660399309, 5.844227921633448, 5.907410600254565, 5.969924622639721, 6.031790778864931, 6.0930288034769715, 6.153657449029805, 6.213694553162394, 6.273157099897946, 6.332061275761631, 6.390422521242238, 6.448255578061403, 6.505574532660432, 6.562392856268208, 6.618723441873063, 6.674578638386096, 6.729970282252368, 6.784909726739185, 6.839407869106799, 6.8934751758456345, 6.947121706145647, 7.000357133746821, 7.0531907673052485, 7.105631569396207, 7.1576881742640905, 7.20936890441875, 7.260681786168569, 7.311634564172365, 7.362234715084816, 7.412489460363503, 7.46240577829965, 7.51199041532935, 7.561249896677137, 7.610190536379496, 7.658818446731846, 7.707139547199079, 7.75515957282634, 7.802884082183973, 7.850318464877715, 7.897467948652911, 7.944337606119218, 7.990932361120324, 8.037256994771289, 8.083316151184489, 8.129114342903538, 8.174655956063228, 8.219945255292155, 8.264986388373549, 8.309783390678726, 8.354340189386592, 8.398660607501652, 8.442748367682174, 8.486607095889383, 8.530240324867759, 8.573651497465944, 8.616843969807045, 8.659821014316638], [0.0, 0.8746427842267951, 1.2369316876852983, 1.5149257407543117, 1.7492855684535902, 1.9557607215607948, 2.142428528562855, 2.314087293081227, 2.4738633753705965, 2.623928352680385, 2.7658633371878665, 2.9008619408720575, 3.0298514815086235, 3.1535694062442956, 3.272613634390714, 3.3874769371908644, 3.4985711369071804, 3.6062445840513924, 3.7107950630558943, 3.8124795081416507, 3.9115214431215897, 4.008116764766216, 4.102438299353204, 4.19463943623287, 4.28485705712571, 4.373213921133975, 4.459820624195553, 4.544777222262936, 4.628174586162454, 4.710095540432275, 4.790615826801393, 4.869804924224378, 4.947726750741193, 5.024440267333269, 5.1000000000000005, 5.174456493198102, 5.24785670536077, 5.32024435529046, 5.391660226683428, 5.462142436809938, 5.531726674375733, 5.600446410778342, 5.668333088307356, 5.735416288291548, 5.801723881744115, 5.867282164682384, 5.932115979985557, 5.996248827392005, 6.059702963017247, 6.122499489587566, 6.184658438426491, 6.246198844097105, 6.307138812488591, 6.367495583037338, 6.427285585688566, 6.486524493131896, 6.545227268781428, 6.603408210916542, 6.661080993352356, 6.718258702967607, 6.774953874381729, 6.83117852204142, 6.886944169949397, 6.942261879243681, 6.997142273814361, 7.051595564125895, 7.105631569396206, 7.159259738269034, 7.212489168102785, 7.265328622987401, 7.317786550590282, 7.369871097922948, 7.421590126111789, 7.472951224248691, 7.523961722390672, 7.574628703771558, 7.624959016283301, 7.67495928327962, 7.724635913750241, 7.773995111909963, 7.823042886243179, 7.871785058041157, 7.920227269466452, 7.968374991176055, 8.016233529532432, 8.06380803342937, 8.111103500757466, 8.158124784532289, 8.204876598706408, 8.25136352368504, 8.2975900115636, 8.343560391104027, 8.38927887246574, 8.43474955170573, 8.479976415061543, 8.524963343029693, 8.56971411425142, 8.61423240921674, 8.658521813797087, 8.702585822616173, 8.74642784226795, 8.790051194390168], [0.0, 0.8874119674649423, 1.2549900398011133, 1.5370426148939398, 1.7748239349298847, 1.9843134832984433, 2.173706511928416, 2.3478713763747794, 2.5099800796022267, 2.6622359023948268, 2.806243040080456, 2.943212530552288, 3.0740852297878796, 3.1996093511552313, 3.320391543176798, 3.4369317712168796, 3.5496478698597693, 3.6588932752951404, 3.7649701194033396, 3.8681390874682884, 3.9686269665968865, 4.066632513517788, 4.162331077653483, 4.255878287733333, 4.347413023856832, 4.437059837324712, 4.524930938699507, 4.611127844681819, 4.695742752749559, 4.778859696622197, 4.860555523805895, 4.940900727600181, 5.019960159204453, 5.097793640389929, 5.174456493198102, 5.25, 5.3244718047896535, 5.397916264633975, 5.470374758643141, 5.54188596057335, 5.612486080160912, 5.682209077462744, 5.751086853804244, 5.819149422381246, 5.886425061104576, 5.952940449895329, 6.018720794321664, 6.083789937201973, 6.148170459575759, 6.211883772254597, 6.274950199005567, 6.3373890522832825, 6.3992187023104625, 6.4604566402074095, 6.521119535785248, 6.5812232905440915, 6.640783086353596, 6.699813430238188, 6.758328195641287, 6.816340660501058, 6.873863542433759, 6.930909031288754, 6.987488819311269, 7.043614129124338, 7.099295739719539, 7.154544010627092, 7.209368904418749, 7.26378000768195, 7.317786550590281, 7.3713974251833685, 7.4246212024587495, 7.477466148368711, 7.529940238806679, 7.582051173660067, 7.633806389999683, 7.685213074469698, 7.736278174936577, 7.787008411450446, 7.83741028656788, 7.887490095080945, 7.937253933193773, 7.9867077071844825, 8.035857141587325, 8.084707786927119, 8.133265027035575, 8.181534085976788, 8.229520034607123, 8.277227796792836, 8.324662155306966, 8.371827757425496, 8.418729120241368, 8.465370635713477, 8.511756575466666, 8.557891095357549, 8.603778239819992, 8.649421946003097, 8.694826047713663, 8.739994279174331, 8.784930278607792, 8.829637591656864, 8.874119674649425, 8.918379897716852], [0.0, 0.8999999999999999, 1.2727922061357855, 1.5588457268119895, 1.7999999999999998, 2.012461179749811, 2.2045407685048604, 2.3811761799581315, 2.545584412271571, 2.6999999999999997, 2.846049894151541, 2.98496231131986, 3.117691453623979, 3.24499614791759, 3.367491648096547, 3.485685011586675, 3.5999999999999996, 3.7107950630558943, 3.818376618407356, 3.9230090491866063, 4.024922359499622, 4.124318125460256, 4.221374183841087, 4.316248370981448, 4.409081537009721, 4.5, 4.589117562233507, 4.676537180435969, 4.762352359916263, 4.846648326421054, 4.929503017546495, 5.01098792654702, 5.091168824543142, 5.170106381884226, 5.247856705360771, 5.324471804789654, 5.3999999999999995, 5.474486277268398, 5.547972602672078, 5.6204981985585585, 5.692099788303082, 5.762811813689564, 5.8326666285670745, 5.901694671871799, 5.96992462263972, 6.037383539249432, 6.104096984812742, 6.170089140360939, 6.235382907247958, 6.3, 6.363961030678928, 6.427285585688566, 6.48999229583518, 6.552098900352467, 6.613622305514581, 6.674578638386096, 6.734983296193094, 6.794850991743674, 6.854195795277518, 6.913031173081746, 6.97137002317335, 7.029224708315989, 7.08660708661063, 7.143528539874395, 7.199999999999999, 7.256031973468694, 7.311634564172364, 7.366817494685204, 7.421590126111789, 7.475961476626267, 7.52994023880668, 7.583534795858722, 7.636753236814712, 7.689603370785778, 7.7420927403383635, 7.794228634059947, 7.846018098373213, 7.897467948652911, 7.9485847796950635, 7.99937497558403, 8.049844718999244, 8.1, 8.149846624323676, 8.199390221229867, 8.248636250920512, 8.2975900115636, 8.346256645946134, 8.394641147779932, 8.442748367682174, 8.490583018850943, 8.538149682454623, 8.58545281275251, 8.632496741962896, 8.67928568489366, 8.725823743349393, 8.772114910328067, 8.818163074019441, 8.863972021616496, 8.909545442950497, 8.95488693395958, 9.0, 9.044888059008803], [0.0, 0.9124143795447329, 1.2903487900563941, 1.580348062927911, 1.8248287590894658, 2.040220576310317, 2.234949663862701, 2.4140215409146624, 2.5806975801127883, 2.7372431386341987, 2.885307609250702, 3.0261361502748025, 3.160696125855822, 3.2897568299191966, 3.4139420030223127, 3.533765696816924, 3.6496575181789317, 3.761980861195336, 3.871046370169182, 3.977122075068856, 4.080441152620634, 4.181207959429907, 4.279602785306132, 4.375785643744448, 4.469899327725402, 4.562071897723665, 4.6524187257812475, 4.741044188783733, 4.828043081829325, 4.91350180624776, 4.997499374687305, 5.0801082665628305, 5.1613951602255765, 5.2414215628968455, 5.320244355290461, 5.397916264633975, 5.474486277268397, 5.550000000000001, 5.624499977775803, 5.698025973966774, 5.770615218501404, 5.842302628245135, 5.913121003328108, 5.983101202553739, 6.052272300549605, 6.1206617289309495, 6.188295403420881, 6.255197838597913, 6.321392251711644, 6.386900656813132, 6.451743950281971, 6.515941988692043, 6.579513659838393, 6.64247694764536, 6.704848991588103, 6.766646141183976, 6.827884006044625, 6.888577501923021, 6.9487408931402825, 7.0083878317342, 7.067531393633848, 7.126184112131822, 7.184358008896829, 7.242064622743987, 7.299315036357863, 7.356119901143537, 7.412489460363502, 7.468433570702762, 7.523961722390672, 7.579083057995868, 7.633806389999684, 7.6881402172437, 7.742092740338364, 7.79567187611177, 7.848885271170678, 7.901740314639554, 7.954244150137712, 8.006403687049511, 8.058225611137978, 8.109716394547963, 8.160882305241268, 8.211729415902598, 8.262263612352248, 8.312490601498446, 8.362415918859814, 8.412044935685973, 8.461382865702275, 8.51043477150257, 8.559205570612264, 8.607700041242143, 8.655922827752105, 8.703878445842406, 8.751571287488895, 8.79900562563748, 8.84618561867204, 8.893115314668982, 8.939798655450804, 8.986239480450097, 9.032441530394758, 9.078408450824409, 9.12414379544733, 9.169651029346758], [0.0, 0.9246621004453465, 1.307669683062202, 1.601561737804697, 1.849324200890693, 2.0676073128135335, 2.2649503305812253, 2.4464259645450137, 2.615339366124404, 2.773986301336039, 2.924038303442689, 3.066757245039131, 3.203123475609394, 3.3339166156339304, 3.4597687784012385, 3.5812009158939966, 3.698648401781386, 3.8124795081416507, 3.9230090491866063, 4.030508652763322, 4.135214625627067, 4.2373340675476605, 4.337049688440288, 4.434523649728346, 4.529900661162451, 4.623310502226732, 4.714870093650514, 4.804685213414091, 4.892851929090027, 4.97945780180935, 5.06458290484024, 5.148300690519155, 5.230678732248808, 5.311779362887733, 5.391660226683429, 5.470374758643141, 5.547972602672078, 5.624499977775803, 5.7, 5.774512966476048, 5.848076606885378, 5.9207263067971665, 5.992495306631454, 6.063414879422321, 6.133514490078262, 6.2028219384406, 6.271363488110063, 6.3391639827346316, 6.406246951218788, 6.472634703117426, 6.538348415311011, 6.603408210916543, 6.667833231267861, 6.731641701695064, 6.794850991743675, 6.8574776703974765, 6.919537556802477, 6.981045766932058, 7.042016756583303, 7.1024643610510285, 7.162401831787993, 7.221841870326434, 7.280796659706958, 7.339277893635042, 7.397296803562772, 7.454864183873506, 7.511990415329349, 7.568685486925719, 7.624959016283301, 7.680820268695265, 7.736278174936577, 7.791341347932332, 7.846018098373213, 7.900316449358216, 7.954244150137711, 8.007808689023484, 8.061017305526644, 8.113877001779114, 8.166394553289722, 8.218576519081635, 8.270429251254134, 8.32195890400812, 8.373171442171719, 8.424072649259383, 8.474668135095321, 8.524963343029695, 8.574963556773874, 8.62467390687903, 8.674099376880577, 8.723244809129227, 8.772114910328067, 8.820714256793494, 8.869047299456692, 8.91711836862111, 8.96493167849036, 9.01249133147988, 9.059801322324901, 9.106865541996326, 9.153687781435414, 9.200271735117395, 9.246621004453464, 9.292739101040127], [0.0, 0.9367496997597597, 1.3247641299491772, 1.6224980739587955, 1.8734993995195195, 2.0946360065653415, 2.2945587811167534, 2.478406746278746, 2.6495282598983545, 2.8102490992792792, 2.962262648719725, 3.106847276581197, 3.244996147917591, 3.377499074759311, 3.5049964336643766, 3.6280159867343476, 3.746998799039039, 3.86231795687512, 3.9742923898475313, 4.083197276644861, 4.189272013130683, 4.292726406376256, 4.3937455547630435, 4.492493739561582, 4.589117562233507, 4.683748498798799, 4.776504998427198, 4.867494221876386, 4.956813492557492, 5.044551516240071, 5.130789412946122, 5.215601595214113, 5.299056519796709, 5.381217334395631, 5.4621424368099385, 5.54188596057335, 5.6204981985585585, 5.698025973966774, 5.774512966476047, 5.8500000000000005, 5.92452529743945, 5.998124706939662, 6.070831903454419, 6.142678568832981, 6.213694553162394, 6.283908019696024, 6.353345575364212, 6.422032388582294, 6.489992295835182, 6.55724789831832, 6.623820649745886, 6.689730936293329, 6.754998149518622, 6.819640753001584, 6.883676343350261, 6.947121706145647, 7.009992867328753, 7.072305140475771, 7.13407317035647, 7.195310973126874, 7.256031973468695, 7.31624903895432, 7.3759745118865485, 7.435220238836239, 7.493997598078078, 7.552317525104463, 7.610190536379493, 7.667626751479235, 7.72463591375024, 7.781227409605763, 7.83741028656788, 7.893193270153722, 7.948584779695063, 8.00359294317246, 8.058225611137976, 8.112490369793976, 8.166394553289722, 8.219945255292156, 8.273149339882607, 8.326013451826752, 8.378544026261366, 8.43074729783784, 8.482629309359217, 8.534195919944656, 8.585452812752512, 8.636405502290872, 8.687059341342158, 8.73741952752642, 8.787491109526087, 8.837278992993262, 8.886787946159176, 8.936022605163888, 8.984987479123165, 9.03368695494813, 9.082125301932363, 9.130306676119922, 9.178235124467014, 9.22591458880907, 9.27334890964424, 9.320541829743593, 9.367496997597598, 9.414217970707925], [0.0, 0.9486832980505138, 1.3416407864998738, 1.6431676725154984, 1.8973665961010275, 2.121320343559643, 2.32379000772445, 2.5099800796022267, 2.6832815729997477, 2.846049894151541, 3.0, 3.146426544510455, 3.286335345030997, 3.420526275297414, 3.5496478698597693, 3.674234614174767, 3.794733192202055, 3.9115214431215892, 4.024922359499621, 4.135214625627067, 4.242640687119286, 4.347413023856832, 4.449719092257398, 4.549725266430931, 4.6475800154489, 4.743416490252569, 4.83735464897913, 4.929503017546495, 5.019960159204453, 5.10881590977792, 5.196152422706632, 5.282045058497703, 5.366563145999495, 5.449770637375486, 5.531726674375733, 5.612486080160912, 5.692099788303082, 5.770615218501404, 5.848076606885378, 5.92452529743945, 6.0, 6.074537019394977, 6.148170459575759, 6.220932405998315, 6.29285308902091, 6.363961030678928, 6.434283176858165, 6.5038450166036395, 6.572670690061994, 6.640783086353597, 6.708203932499369, 6.77495387438173, 6.841052550594828, 6.906518659932804, 6.971370023173351, 7.035623639735144, 7.099295739719539, 7.162401831787993, 7.224956747275378, 7.286974680894671, 7.348469228349534, 7.409453421137082, 7.469939758793239, 7.52994023880668, 7.58946638440411, 7.648529270389177, 7.707139547199077, 7.76530746332687, 7.8230428862431785, 7.880355321938218, 7.937253933193772, 7.993747556684537, 8.049844718999243, 8.105553651663778, 8.160882305241266, 8.215838362577491, 8.270429251254134, 8.324662155306966, 8.378544026261366, 8.432081593533118, 8.485281374238571, 8.538149682454625, 8.590692637965812, 8.64291617453276, 8.694826047713663, 8.746427842267952, 8.79772697916911, 8.848728722251575, 8.899438184514796, 8.949860334105779, 9.0, 9.049861877399014, 9.099450532861862, 9.148770409186145, 9.197825830053535, 9.246621004453464, 9.2951600308978, 9.343446901438464, 9.391485505499116, 9.439279633531365, 9.486832980505138, 9.534149149242424], [0.0, 0.9604686356149273, 1.3583077707206126, 1.6635804759614128, 1.9209372712298547, 2.1476731594914535, 2.3526580712037184, 2.5411611519146127, 2.716615541441225, 2.881405906844782, 3.0372685096974883, 3.1855140872392957, 3.3271609519228256, 3.463018914184559, 3.593744565213282, 3.7198790302911733, 3.8418745424597094, 3.960113634733226, 4.074923312161838, 4.1865857210858595, 4.295346318982907, 4.401420225336364, 4.504997225304363, 4.606245759835227, 4.705316142407437, 4.802343178074637, 4.897448315194353, 4.990741427884238, 5.082322303829225, 5.172281894870001, 5.260703375025055, 5.347663040992766, 5.43323108288245, 5.517472247324857, 5.600446410778342, 5.682209077462744, 5.762811813689564, 5.842302628245135, 5.920726306797166, 5.998124706939662, 6.074537019394977, 6.150000000000001, 6.224548176373929, 6.298214032565104, 6.3710281744785915, 6.443019478474359, 6.51421522518254, 6.58464122029439, 6.654321903845651, 6.723280449304492, 6.791538853603063, 6.859118019104207, 6.926037828369118, 6.992317212484, 7.057974213611156, 7.12302604235026, 7.187489130426564, 7.251379179163092, 7.314711204141966, 7.377499576414762, 7.439758060582347, 7.501499850029994, 7.562737599573318, 7.6234834557438385, 7.683749084919419, 7.7435456994841845, 7.802884082183971, 7.861774608827195, 7.920227269466452, 7.97825168818332, 8.035857141587325, 8.093052576129727, 8.149846624323676, 8.206247619953958, 8.262263612352248, 8.317902379807062, 8.373171442171719, 8.42807807272809, 8.482629309359218, 8.536831965079319, 8.590692637965814, 8.644217720534348, 8.697413408594535, 8.750285709621144, 8.802840450672727, 8.855083285887266, 8.907019703582115, 8.958655032983467, 9.009994450608726, 9.061042986323374, 9.111805529092464, 9.162286832445272, 9.212491519670454, 9.262424088757761, 9.312088917101255, 9.361490265977956, 9.410632284814874, 9.45951901525654, 9.508154395044288, 9.556542261717887, 9.604686356149275, 9.652590325917703], [0.0, 0.9721111047611791, 1.374772708486752, 1.6837458240482739, 1.9442222095223582, 2.1737065119284162, 2.381176179958132, 2.571964229922337, 2.749545416973504, 2.9163333142835373, 3.0740852297878796, 3.2241277890307023, 3.3674916480965478, 3.504996433664377, 3.6373066958946425, 3.76497011940334, 3.8884444190447165, 4.008116764766217, 4.124318125460256, 4.237334067547661, 4.3474130238568325, 4.4547727214752495, 4.5596052460712, 4.6620810803760175, 4.762352359916264, 4.860555523805895, 4.956813492557493, 5.051237472144821, 5.143928459844674, 5.234978509984545, 5.324471804789655, 5.4124855658006155, 5.499090833947008, 5.584353140695887, 5.668333088307357, 5.751086853804245, 5.8326666285670745, 5.913121003328108, 5.992495306631454, 6.07083190345442, 6.148170459575759, 6.22454817637393, 6.300000000000001, 6.374558808262733, 6.448255578061405, 6.521119535785248, 6.593178292750774, 6.664457967456919, 6.7349832961930955, 6.804777733328255, 6.873863542433761, 6.942261879243682, 7.009992867328754, 7.077075667251271, 7.143528539874396, 7.20936890441875, 7.274613391789285, 7.339277893635042, 7.403377607551842, 7.466927078792185, 7.52994023880668, 7.592430440906259, 7.654410493303844, 7.715892689767012, 7.776888838089433, 7.837410286567879, 7.89746794865291, 7.957072325924907, 8.016233529532434, 8.074961300216863, 8.133265027035577, 8.191153764885629, 8.248636250920512, 8.305720919944278, 8.362415918859814, 8.418729120241368, 8.474668135095323, 8.53024032486776, 8.585452812752512, 8.640312494348802, 8.694826047713665, 8.748999942850613, 8.802840450672727, 8.856353651475306, 8.909545442950499, 8.962421547773795, 9.014987520790033, 9.06724875582445, 9.1192104921424, 9.170877820579664, 9.222255689363639, 9.27334890964424, 9.324162160752035, 9.37469999519985, 9.424966843443006, 9.474967018412254, 9.524704719832528, 9.574184038339771, 9.623408959407264, 9.672383367092106, 9.72111104761179, 9.769595692760271], [0.0, 0.9836157786453, 1.3910427743243554, 1.703672503740082, 1.9672315572906, 2.1994317447922773, 2.4093567606313515, 2.602402735934621, 2.782085548648711, 2.9508473359358995, 3.1104662029991577, 3.262284475639732, 3.407345007480164, 3.5464771252610663, 3.6803532439155884, 3.8095275297600875, 3.9344631145812, 4.055551750378732, 4.173128322973066, 4.287481778386936, 4.398863489584555, 4.507493760395016, 4.613566949768909, 4.717255558054917, 4.818713521262703, 4.9180788932265, 5.015476049190147, 5.111017511220246, 5.204805471869242, 5.2969330749028725, 5.387485498820391, 5.4765408790586045, 5.564171097297422, 5.65044246055121, 5.735416288291549, 5.819149422381247, 5.901694671871799, 5.98310120255374, 6.063414879422321, 6.142678568832981, 6.220932405998315, 6.298214032565105, 6.374558808262733, 6.449999999999998, 6.524568951279464, 6.59829523437683, 6.671206787381125, 6.743330037896706, 6.814690014960328, 6.8853104505171006, 6.955213871621778, 7.024421684380857, 7.092954250522133, 7.160830957368007, 7.2280702818940545, 7.294689849472697, 7.360706487831177, 7.426136276691937, 7.490994593510264, 7.555296155677816, 7.619055059520175, 7.682284816381126, 7.74499838605535, 7.807208207803862, 7.8689262291624, 7.930163932731781, 7.99093236112032, 8.051242140191784, 8.111103500757464, 8.170526298837792, 8.229520034607122, 8.288093870124783, 8.346256645946132, 8.404016896698863, 8.461382865702271, 8.518362518700409, 8.574963556773872, 8.631193428489482, 8.687059341342156, 8.742568272538682, 8.79772697916911, 8.8525420078077, 8.907019703582113, 8.961166218746307, 9.014987520790031, 9.068489400115105, 9.121677477306463, 9.174557210023815, 9.227133899537819, 9.279412696932926, 9.331398608997473, 9.383096503820047, 9.434511116109833, 9.485647052257427, 9.536508795151398, 9.587100708764876, 9.637427042525406, 9.687491935480516, 9.737299420270487, 9.786853426919196, 9.836157786453, 9.885216234357245], [0.0, 0.99498743710662, 1.407124727947029, 1.7233687939614089, 1.98997487421324, 2.2248595461286995, 2.4372115213907883, 2.632489316217637, 2.814249455894058, 2.9849623113198596, 3.146426544510455, 3.3000000000000007, 3.4467375879228177, 3.58747822293042, 3.722902093797257, 3.853569773599539, 3.97994974842648, 4.102438299353203, 4.221374183841087, 4.337049688440289, 4.449719092257399, 4.559605246071199, 4.666904755831214, 4.771792116176061, 4.874423042781577, 4.974937185533101, 5.07346035758633, 5.170106381884226, 5.264978632435274, 5.358171329847526, 5.449770637375486, 5.539855593785817, 5.628498911788116, 5.715767664977296, 5.801723881744116, 5.886425061104576, 5.969924622639719, 6.052272300549605, 6.133514490078262, 6.213694553162394, 6.29285308902091, 6.3710281744785915, 6.448255578061404, 6.524568951279464, 6.600000000000001, 6.674578638386097, 6.748333127521196, 6.8212902005412435, 6.893475175845635, 6.96491205974634, 7.035623639735145, 7.105631569396208, 7.17495644586084, 7.243617880589783, 7.3116345641723655, 7.379024325749306, 7.445804187594514, 7.5119904153293495, 7.577598564189055, 7.642643521714199, 7.707139547199078, 7.771100308193172, 7.834538914320357, 7.897467948652911, 7.95989949685296, 8.021845174272563, 8.083316151184487, 8.144323176298936, 8.204876598706406, 8.264986388373547, 8.324662155306966, 8.383913167489272, 8.442748367682174, 8.501176389182852, 8.559205570612264, 8.616843969807043, 8.674099376880578, 8.73097932651315, 8.787491109526089, 8.843641783790206, 8.899438184514798, 8.954886933959582, 9.009994450608724, 9.064766957842876, 9.119210492142399, 9.173330910852396, 9.22713389953782, 9.280624978954812, 9.333809511662428, 9.38669270829721, 9.439279633531365, 9.491575211733826, 9.543584232352122, 9.595311355031688, 9.646761114488116, 9.69793792514677, 9.748846085563153, 9.799489782636646, 9.849873095629201, 9.900000000000002, 9.949874371066201, 9.999499987499378], [0.0, 1.0062305898749053, 1.4230249470757705, 1.7428425057933377, 2.0124611797498106, 2.25, 2.4647515087732472, 2.662235902394827, 2.846049894151541, 3.0186917696247155, 3.181980515339464, 3.337289319193048, 3.4856850115866753, 3.628015986734347, 3.764970119403339, 3.897114317029973, 4.024922359499621, 4.148795005781799, 4.269074841227312, 4.386057455164034, 4.5, 4.6111278446818185, 4.719639816765682, 4.825712382643625, 4.9295030175464944, 5.031152949374526, 5.130789412946121, 5.228527517380012, 5.324471804789654, 5.418717560456533, 5.5113519212621505, 5.6024548190949295, 5.692099788303082, 5.780354660399309, 5.867282164682384, 5.952940449895329, 6.037383539249431, 6.1206617289309495, 6.202821938440599, 6.283908019696023, 6.363961030678928, 6.443019478474359, 6.521119535785247, 6.598295234376829, 6.674578638386096, 6.749999999999999, 6.824587899646395, 6.8983693725401505, 6.971370023173351, 7.043614129124338, 7.115124735378854, 7.185923740202091, 7.256031973468694, 7.325469268244868, 7.394254526319743, 7.462405778299649, 7.529940238806678, 7.596874357260359, 7.663223864666881, 7.729003816792949, 7.794228634059946, 7.858912138457841, 7.923067587746553, 7.986707707184481, 8.049844718999243, 8.112490369793974, 8.174655956063226, 8.236352347975405, 8.297590011563598, 8.358379029453019, 8.418729120241368, 8.478649656637547, 8.538149682454623, 8.59723792854426, 8.655922827752104, 8.714212528966687, 8.772114910328067, 8.829637591656862, 8.886787946159176, 8.943573111458305, 9.0, 9.056075308874147, 9.111805529092464, 9.167196954358511, 9.222255689363637, 9.276987657639737, 9.331398608997475, 9.385494126576393, 9.439279633531363, 9.492760399378044, 9.54594154601839, 9.598828053465693, 9.65142476528725, 9.703736393781522, 9.755767524905458, 9.807522622966514, 9.859006035092989, 9.910221995495359, 9.961174629530394, 10.011867957579145, 10.062305898749052, 10.112492274409906], [0.0, 1.0173494974687902, 1.438749456993816, 1.7621010186706099, 2.0346989949375804, 2.2748626332154656, 2.4919871588754225, 2.691653766738954, 2.877498913987632, 3.0520484924063704, 3.2171415884290826, 3.374166563760598, 3.5242020373412197, 3.6681057781912454, 3.806573262134856, 3.940177660969109, 4.069397989875161, 4.194639436232869, 4.316248370981447, 4.434523649728345, 4.549725266430931, 4.662081080376016, 4.77179211617606, 4.879036790187179, 4.983974317750845, 5.086747487343952, 5.187484939737176, 5.286303056011829, 5.383307533477908, 5.478594710324902, 5.572252686302013, 5.664362276549762, 5.754997827975264, 5.844227921633448, 5.932115979985557, 6.0187207943216645, 6.104096984812741, 6.188295403420882, 6.271363488110062, 6.353345575364211, 6.434283176858165, 6.51421522518254, 6.593178292750774, 6.6712067873811245, 6.748333127521196, 6.824587899646396, 6.9, 6.974596762537602, 7.0484040746824395, 7.121446482281533, 7.19374728496908, 7.2653286229874015, 7.336211556382491, 7.406416137377106, 7.475961476626268, 7.544865803975575, 7.613146524269712, 7.680820268695265, 7.747902942086976, 7.814409766578663, 7.880355321938218, 7.9457535828894175, 8.010617953691213, 8.074961300216863, 8.138795979750322, 8.20213386869539, 8.264986388373547, 8.327364529069206, 8.389278872465738, 8.450739612601964, 8.511756575466665, 8.57233923733773, 8.632496741962894, 8.692237916670251, 8.751571287488893, 8.810505093353047, 8.86904729945669, 8.927205609819907, 8.984987479123165, 9.042400123860922, 9.099450532861862, 9.156145477219113, 9.212491519670452, 9.268495023465244, 9.324162160752032, 9.37949892051809, 9.434511116109833, 9.489204392360827, 9.54358423235212, 9.597655963827835, 9.651424765287247, 9.704895671773087, 9.758073580374358, 9.8109632554607, 9.863569333664158, 9.915896328623045, 9.96794863550169, 10.019730535298843, 10.071246198956711, 10.122499691281796, 10.173494974687904, 10.224235912771187], [0.0, 1.0283481900601565, 1.4543039572248988, 1.7811513130556877, 2.056696380120313, 2.2994564575133842, 2.518928343562, 2.7207535720825584, 2.9086079144497976, 3.0850445701804694, 3.2519225083018197, 3.410645100270622, 3.5623026261113755, 3.7077621282924826, 3.8477266015141978, 3.9827754142055256, 4.113392760240626, 4.239988207530771, 4.362911871674696, 4.482465839245181, 4.5989129150267685, 4.712483421721503, 4.823380557244058, 4.93178466683208, 5.037856687124, 5.141740950300783, 5.243567487884561, 5.3434539391670635, 5.441507144165117, 5.53782448259242, 5.632495006655576, 5.725600405197694, 5.817215828899595, 5.907410600254566, 5.996248827392006, 6.083789937201974, 6.170089140360939, 6.255197838597914, 6.3391639827346316, 6.422032388582294, 6.5038450166036395, 6.584641220294391, 6.664457967456919, 6.743330037896706, 6.821290200541244, 6.898369372540151, 6.974596762537602, 7.05, 7.124605252222751, 7.198437330421097, 7.271519786124494, 7.343874998936189, 7.415524256584965, 7.486487828080669, 7.556785030686, 7.626434291331696, 7.6954532030283955, 7.7638585767645205, 7.831666489323968, 7.898892327408951, 7.965550828411051, 8.031656118136533, 8.097221745759468, 8.162260716247674, 8.226785520481252, 8.290808163261287, 8.354340189386592, 8.41739270795892, 8.479976415061541, 8.54210161494231, 8.603778239819993, 8.665015868421708, 8.725823743349393, 8.786210787364483, 8.846185618672038, 8.905756565278438, 8.964931678490363, 9.023718745617021, 9.082125301932363, 9.140158641949274, 9.197825830053537, 9.255133710541411, 9.312088917101255, 9.368697881776313, 9.424966843443006, 9.480901855836292, 9.5365087951514, 9.5917933672489, 9.646761114488116, 9.701417422212076, 9.75576752490546, 9.809816512045472, 9.86356933366416, 9.917030805639358, 9.97020561473032, 10.023098323372867, 10.075713374248, 10.12805509463688, 10.18012770057429, 10.231935300811866, 10.283481900601567, 10.334771405309363], [0.0, 1.0392304845413265, 1.4696938456699071, 1.8000000000000003, 2.078460969082653, 2.3237900077244507, 2.5455844122715714, 2.7495454169735045, 2.9393876913398143, 3.117691453623979, 3.286335345030997, 3.4467375879228177, 3.6000000000000005, 3.7469987990390394, 3.8884444190447165, 4.024922359499621, 4.156921938165306, 4.284857057125711, 4.409081537009721, 4.529900661162451, 4.647580015448901, 4.762352359916264, 4.874423042781578, 4.983974317750846, 5.091168824543143, 5.196152422706633, 5.299056519796709, 5.400000000000001, 5.499090833947009, 5.59642743185329, 5.692099788303084, 5.786190456595774, 5.8787753826796285, 5.969924622639721, 6.059702963017248, 6.14817045957576, 6.235382907247958, 6.321392251711645, 6.406246951218788, 6.489992295835182, 6.572670690061994, 6.654321903845652, 6.7349832961930955, 6.814690014960328, 6.893475175845635, 6.9713700231733515, 7.0484040746824395, 7.124605252222751, 7.200000000000001, 7.274613391789286, 7.348469228349535, 7.4215901261117905, 7.493997598078079, 7.565712127751096, 7.636753236814714, 7.707139547199078, 7.776888838089433, 7.8460180983732135, 7.914543574963753, 7.9824808173900434, 8.049844718999243, 8.116649555081212, 8.182909018191515, 8.248636250920514, 8.313843876330612, 8.378544026261364, 8.442748367682174, 8.506468127254696, 8.569714114251422, 8.632496741962896, 8.694826047713665, 8.756711711595855, 8.818163074019441, 8.879189152169246, 8.939798655450804, 9.0, 9.059801322324901, 9.1192104921424, 9.178235124467015, 9.236882591004393, 9.295160030897803, 9.35307436087194, 9.410632284814875, 9.4678403028357, 9.524704719832528, 9.58123165360279, 9.63742704252541, 9.693296652842108, 9.748846085563155, 9.804080783020916, 9.85900603509299, 9.913626985114986, 9.967948635501692, 10.021975853094043, 10.075713374248, 10.12916580968048, 10.182337649086286, 10.235233265539192, 10.287856919689348, 10.340212763768454, 10.392304845413266, 10.444137111317529], [0.0, 1.05, 1.4849242404917498, 1.8186533479473213, 2.1, 2.3478713763747794, 2.571964229922337, 2.77803887661782, 2.9698484809834995, 3.1499999999999995, 3.3203915431767985, 3.48245602987317, 3.6373066958946425, 3.7858288392371886, 3.928740256112638, 4.066632513517788, 4.2, 4.3292609068985435, 4.4547727214752495, 4.576843890717708, 4.695742752749559, 4.811704479703632, 4.924936547814601, 5.035623099478356, 5.143928459844674, 5.25, 5.353970489272425, 5.455960043841964, 5.55607775323564, 5.654423047491229, 5.751086853804244, 5.846152580971523, 5.939696961966999, 6.031790778864931, 6.122499489587566, 6.211883772254597, 6.299999999999999, 6.386900656813131, 6.472634703117425, 6.557247898318319, 6.640783086353597, 6.723280449304491, 6.804777733328254, 6.8853104505171, 6.96491205974634, 7.043614129124338, 7.121446482281532, 7.198437330421096, 7.274613391789285, 7.3500000000000005, 7.4246212024587495, 7.498499849969994, 7.571657678474377, 7.644115383744545, 7.715892689767012, 7.787008411450446, 7.857480512225276, 7.927326157034287, 7.996561761157104, 8.065203035262039, 8.133265027035575, 8.200762159701988, 8.2677082677124, 8.33411662985346, 8.4, 8.465370635713477, 8.530240324867759, 8.594620410466073, 8.658521813797087, 8.721955056063978, 8.784930278607794, 8.847457261835176, 8.909545442950499, 8.971203932583407, 9.032441530394758, 9.093266739736606, 9.153687781435416, 9.21371260676173, 9.273348909644241, 9.332604138181368, 9.391485505499118, 9.450000000000001, 9.508154395044288, 9.565955258101512, 9.623408959407264, 9.680521680157533, 9.73729942027049, 9.793748005743256, 9.849873095629203, 9.905680188659433, 9.961174629530396, 10.01636161487793, 10.071246198956713, 10.125833299042604, 10.18012770057429, 10.234134062049412, 10.287856919689348, 10.34130069188591, 10.394469683442248, 10.447368089619511, 10.5, 10.552369402176938], [0.0, 1.0606601717798212, 1.5, 1.8371173070873839, 2.1213203435596424, 2.371708245126285, 2.598076211353316, 2.806243040080456, 3.0, 3.181980515339464, 3.3541019662496847, 3.5178118198675725, 3.6742346141747677, 3.824264635194589, 3.9686269665968856, 4.107919181288746, 4.242640687119285, 4.373213921133976, 4.5, 4.623310502226733, 4.74341649025257, 4.860555523805895, 4.974937185533101, 5.086747487343953, 5.196152422706632, 5.303300858899107, 5.408326913195985, 5.511351921262151, 5.612486080160912, 5.7118298293979315, 5.809475019311126, 5.905505905508859, 6.0, 6.0930288034769715, 6.184658438426491, 6.274950199005567, 6.363961030678928, 6.451743950281971, 6.5383484153110105, 6.623820649745886, 6.708203932499369, 6.791538853603063, 6.87386354243376, 6.955213871621777, 7.035623639735145, 7.115124735378854, 7.19374728496908, 7.271519786124493, 7.348469228349535, 7.4246212024587495, 7.500000000000001, 7.57462870377156, 7.648529270389178, 7.7217226057402515, 7.794228634059948, 7.866066361276137, 7.937253933193771, 8.007808689023484, 8.077747210701757, 8.147085368400163, 8.215838362577491, 8.284020762890446, 8.351646544245034, 8.418729120241368, 8.48528137423857, 8.551315688243534, 8.616843969807043, 8.681877677092668, 8.746427842267952, 8.810505093353049, 8.874119674649425, 8.937281465859739, 9.0, 9.06228448019593, 9.12414379544733, 9.185586535436919, 9.246621004453466, 9.307255234493145, 9.3674969975976, 9.427353817482402, 9.48683298050514, 9.545941546018392, 9.604686356149275, 9.663074045043844, 9.72111104761179, 9.778803607803974, 9.836157786453002, 9.89317946870469, 9.949874371066201, 10.00624804809475, 10.062305898749054, 10.118053172424032, 10.173494974687905, 10.228636272739394, 10.283481900601567, 10.338036564067666, 10.392304845413264, 10.446291207888091, 10.5, 10.553435459602719, 10.606601717798213, 10.659502802663924], [0.0, 1.0712142642814275, 1.514925740754312, 1.8553975315279476, 2.142428528562855, 2.395307913400697, 2.6239283526803856, 2.834166544153678, 3.029851481508624, 3.2136427928442823, 3.387476937190865, 3.552815784698104, 3.7107950630558952, 3.86231795687512, 4.008116764766216, 4.1487950057818, 4.28485705712571, 4.416729559300638, 4.544777222262935, 4.669314724882015, 4.790615826801394, 4.908920451586072, 5.024440267333269, 5.137363136863114, 5.247856705360771, 5.356071321407138, 5.4621424368099385, 5.566192594583843, 5.668333088307356, 5.768665356908824, 5.8672821646823845, 5.964268605621314, 6.059702963017248, 6.153657449029806, 6.246198844097106, 6.337389052283283, 6.427285585688565, 6.515941988692043, 6.603408210916542, 6.689730936293328, 6.77495387438173, 6.859118019104207, 6.942261879243682, 7.024421684380857, 7.105631569396208, 7.1859237402020915, 7.2653286229874015, 7.3438749989361884, 7.4215901261117905, 7.498499849969994, 7.57462870377156, 7.650000000000001, 7.72463591375024, 7.7985575589335765, 7.871785058041157, 7.944337606119217, 8.016233529532432, 8.087490340025143, 8.15812478453229, 8.228152891141487, 8.2975900115636, 8.366450860430605, 8.43474955170573, 8.502499632461033, 8.56971411425142, 8.63640550229087, 8.702585822616173, 8.76826664740529, 8.833459118601276, 8.898173969978336, 8.962421547773795, 9.026211829998232, 9.08955444452587, 9.15245868605808, 9.214933532044602, 9.276987657639737, 9.33862944976403, 9.39986702033598, 9.46070821873289, 9.52116064353501, 9.581231653602789, 9.64092837853285, 9.700257728534847, 9.759226403767872, 9.817840903172144, 9.876107532828916, 9.934032413879072, 9.991621490028534, 10.048880534666537, 10.105815157620885, 10.162430811572595, 10.218732798150661, 10.274726273726229, 10.3304162549241, 10.385807623868258, 10.440905133176914, 10.495713410721542, 10.550236964163414, 10.604480185280181, 10.658447354094312, 10.712142642814277, 10.765570119598872], [0.0, 1.0816653826391969, 1.5297058540778357, 1.8734993995195197, 2.1633307652783937, 2.418677324489565, 2.6495282598983545, 2.861817604250837, 3.0594117081556713, 3.24499614791759, 3.420526275297414, 3.58747822293042, 3.7469987990390394, 3.9000000000000004, 4.047221268969612, 4.189272013130682, 4.3266615305567875, 4.459820624195552, 4.589117562233507, 4.714870093650514, 4.83735464897913, 4.956813492557492, 5.073460357586329, 5.187484939737176, 5.299056519796709, 5.408326913195984, 5.515432893255071, 5.620498198558559, 5.723635208501674, 5.8249463516842805, 5.92452529743945, 6.02245796996542, 6.118823416311343, 6.213694553162395, 6.307138812488592, 6.399218702310463, 6.48999229583518, 6.579513659838393, 6.667833231267861, 6.754998149518622, 6.841052550594828, 6.926037828369118, 7.009992867328754, 7.092954250522133, 7.17495644586084, 7.256031973468695, 7.336211556382491, 7.415524256584965, 7.493997598078079, 7.571657678474378, 7.6485292703891785, 7.724635913750241, 7.800000000000001, 7.8746428490440135, 7.948584779695063, 8.021845174272563, 8.094442537939225, 8.16639455328972, 8.23771813064759, 8.308429454475737, 8.378544026261364, 8.448076704197234, 8.517041739947034, 8.58545281275251, 8.653323061113575, 8.72066511224918, 8.787491109526085, 8.853812738024224, 8.919641248391104, 8.984987479123163, 9.049861877399014, 9.114274518577988, 9.178235124467014, 9.241753080449618, 9.304837451562495, 9.367496997597598, 9.429740187301029, 9.491575211733826, 9.553009996854398, 9.61405221537724, 9.67470929795826, 9.734988443752773, 9.794896630388706, 9.854440623394105, 9.913626985114984, 9.972462083156799, 10.030952098380295, 10.089103032480143, 10.146920715172659, 10.20441081101697, 10.261578825892242, 10.318430113151905, 10.374969879474351, 10.431203190428228, 10.487134975769122, 10.542770034483349, 10.598113039593418, 10.653168542738824, 10.707940978544848, 10.76243466879126, 10.816653826391969, 10.870602559196065], [0.0, 1.0920164833920778, 1.5443445211480502, 1.891428031937774, 2.1840329667841556, 2.4418230894149566, 2.6748831750190516, 2.8892040426387338, 3.0886890422961004, 3.276049450176233, 3.453259329966402, 3.6218089402948914, 3.782856063875548, 3.9373214245220067, 4.085951541562871, 4.229361653961505, 4.368065933568311, 4.5024993059410905, 4.63303356344415, 4.75998949578673, 4.883646178829913, 5.004248195283684, 5.122011323689163, 5.237127075028829, 5.349766350038103, 5.46008241696039, 5.568213357981177, 5.674284095813322, 5.7784080852774675, 5.880688735173798, 5.981220611213066, 6.080090459853373, 6.177378084592201, 6.273157099897947, 6.367495583037338, 6.4604566402074095, 6.552098900352466, 6.64247694764536, 6.731641701695064, 6.819640753001584, 6.906518659932804, 6.992317212484, 7.07707566725127, 7.160830957368006, 7.243617880589783, 7.325469268244868, 7.406416137377106, 7.486487828080668, 7.565712127751096, 7.644115383744546, 7.7217226057402515, 7.7985575589335765, 7.8746428490440135, 7.950000000000002, 8.024649525057155, 8.098610992015853, 8.171903083125741, 8.244543650196778, 8.316549765377468, 8.38793776800949, 8.45872330792301, 8.528921385497702, 8.598546388779909, 8.6676121279162, 8.736131867136622, 8.804118354497513, 8.871583849572747, 8.93854014926375, 9.004998611882181, 9.070970179644513, 9.136465399704639, 9.201494443839001, 9.2660671268883, 9.330192924050392, 9.393880987110707, 9.45714015968887, 9.51997899157346, 9.582405752210665, 9.644428443407108, 9.706054811302069, 9.767292357659827, 9.828148350528702, 9.888629834309707, 9.948743639274259, 10.008496390567368, 10.067894516729904, 10.126944257770951, 10.185651672818977, 10.244022647378326, 10.302062900215667, 10.359777989899206, 10.4171733210118, 10.474254150057657, 10.531025591080864, 10.587492621012778, 10.643660084764075, 10.699532700076206, 10.755115062146015, 10.81041164803635, 10.865426820884675, 10.92016483392078, 10.974629834304212], [0.0, 1.1022703842524302, 1.5588457268119897, 1.9091883092036785, 2.2045407685048604, 2.464751508773248, 2.7, 2.9163333142835373, 3.1176914536239795, 3.30681115275729, 3.4856850115866753, 3.6558172820861827, 3.818376618407357, 3.9742923898475313, 4.124318125460256, 4.269074841227312, 4.409081537009721, 4.544777222262935, 4.676537180435969, 4.804685213414091, 4.929503017546496, 5.051237472144821, 5.170106381884226, 5.28630305601183, 5.4, 5.511351921262151, 5.620498198558559, 5.727564927611035, 5.8326666285670745, 5.9359076812228135, 6.037383539249433, 6.137181763643635, 6.235382907247959, 6.332061275761631, 6.427285585688566, 6.521119535785248, 6.61362230551458, 6.704848991588103, 6.794850991743675, 6.88367634335026, 6.971370023173351, 7.057974213611156, 7.143528539874395, 7.228070281894054, 7.3116345641723655, 7.394254526319743, 7.475961476626268, 7.556785030685999, 7.636753236814714, 7.715892689767012, 7.794228634059948, 7.871785058041157, 7.948584779695063, 8.024649525057155, 8.100000000000001, 8.174655956063228, 8.248636250920512, 8.321958904008119, 8.394641147779934, 8.46669947500205, 8.538149682454623, 8.609006911369047, 8.67928568489366, 8.748999942850611, 8.818163074019441, 8.886787946159174, 8.95488693395958, 9.022471945093539, 9.08955444452587, 9.156145477219113, 9.222255689363639, 9.287895348247632, 9.353074360871938, 9.417802291405359, 9.482088377567464, 9.545941546018392, 9.609370426828182, 9.672383367092106, 9.734988443752773, 9.79719347568476, 9.859006035092992, 9.920433458271873, 9.981482855768476, 10.04216112198963, 10.102474944289643, 10.162430811572595, 10.222035022440494, 10.281293692916277, 10.340212763768452, 10.39879800746221, 10.457055034760026, 10.51498930099313, 10.57260611202366, 10.629910629915948, 10.686907878334127, 10.74360274768199, 10.8, 10.856104273633338, 10.911920087683926, 10.967451846258548, 11.022703842524303, 11.077680262582057], [0.0, 1.1124297730643495, 1.5732132722552274, 1.9267848867997694, 2.224859546128699, 2.4874685927665503, 2.724885318687743, 2.943212530552288, 3.146426544510455, 3.337289319193048, 3.517811819867572, 3.6895121628746534, 3.853569773599539, 4.010922587136282, 4.162331077653482, 4.3084219849035215, 4.449719092257398, 4.586665455426197, 4.719639816765682, 4.848968962573385, 4.974937185533101, 5.097793640389929, 5.2177581392778265, 5.335025773133623, 5.449770637375486, 5.562148865321747, 5.672301120356712, 5.780354660399309, 5.886425061104576, 5.990617664314758, 6.093028803476971, 6.193746846618774, 6.29285308902091, 6.390422521242239, 6.486524493131897, 6.581223290544092, 6.674578638386096, 6.766646141183977, 6.8574776703974765, 6.947121706145647, 7.035623639735144, 7.1230260423502605, 7.20936890441875, 7.294689849472697, 7.379024325749307, 7.46240577829965, 7.544865803975576, 7.626434291331696, 7.707139547199078, 7.787008411450447, 7.866066361276137, 7.944337606119217, 8.021845174272563, 8.098610992015855, 8.174655956063228, 8.25, 8.324662155306964, 8.398660607501652, 8.472012747865765, 8.544735221175669, 8.616843969807043, 8.688354274544748, 8.75928079239386, 8.829637591656864, 8.899438184514796, 8.968695557326049, 9.037422198835241, 9.105630126465712, 9.173330910852394, 9.240535698756863, 9.307255234493143, 9.373499879980796, 9.439279633531363, 9.504604147464534, 9.569482744641949, 9.633924433998846, 9.69793792514677, 9.761531642114369, 9.824713736287691, 9.887492098606199, 9.949874371066201, 10.011867957579147, 10.07348003422849, 10.13471755896532, 10.195587280779858, 10.256095748383009, 10.31624931842964, 10.376054163312757, 10.435516278555653, 10.494641489827083, 10.553435459602717, 10.611903693494396, 10.670051546267246, 10.727884227563235, 10.78540680734853, 10.84262422110072, 10.899541274750971, 10.95616264939509, 11.01249290578659, 11.06853648862396, 11.124297730643494, 11.179780856528453], [0.0, 1.1224972160321824, 1.5874507866387544, 1.9442222095223582, 2.244994432064365, 2.5099800796022267, 2.749545416973504, 2.9698484809834995, 3.1749015732775088, 3.367491648096547, 3.5496478698597693, 3.722902093797257, 3.8884444190447165, 4.047221268969612, 4.199999999999999, 4.347413023856831, 4.48998886412873, 4.628174586162453, 4.762352359916263, 4.892851929090027, 5.019960159204453, 5.143928459844674, 5.264978632435273, 5.383307533477909, 5.499090833947008, 5.612486080160912, 5.723635208501674, 5.8326666285670745, 5.939696961966999, 6.044832503882965, 6.148170459575759, 6.249799996799897, 6.3498031465550175, 6.448255578061404, 6.545227268781429, 6.640783086353597, 6.734983296193094, 6.827884006044625, 6.919537556802477, 7.009992867328754, 7.099295739719539, 7.187489130426564, 7.274613391789285, 7.360706487831177, 7.445804187594514, 7.529940238806679, 7.6131465242697125, 7.6954532030283955, 7.776888838089433, 7.857480512225277, 7.937253933193772, 8.016233529532434, 8.094442537939225, 8.171903083125743, 8.248636250920512, 8.324662155306964, 8.399999999999999, 8.474668135095321, 8.548684109265006, 8.622064717919947, 8.694826047713661, 8.766983517721474, 8.83855191759374, 8.909545442950499, 8.97997772825746, 9.049861877399012, 9.119210492142397, 9.188035698668132, 9.256349172324907, 9.324162160752032, 9.391485505499118, 9.458329662260667, 9.524704719832526, 9.590620417887468, 9.656086163658648, 9.72111104761179, 9.785703858180055, 9.849873095629203, 9.913626985114986, 9.976973488989534, 10.039920318408907, 10.102474944289643, 10.16464460765845, 10.226436329435586, 10.287856919689348, 10.348912986396206, 10.409610943738485, 10.469957019969089, 10.529957264870546, 10.589617556833675, 10.648943609579309, 10.707940978544848, 10.766615066955818, 10.824971131601231, 10.883014288330232, 10.940749517286282, 10.998181667894016, 11.055315463612969, 11.112155506471279, 11.168706281391772, 11.224972160321824, 11.280957406177901], [0.0, 1.1324751652906124, 1.6015617378046967, 1.9615045245933032, 2.264950330581225, 2.5322914524201203, 2.7739863013360395, 2.9962476533157267, 3.2031234756093934, 3.397425495871837, 3.5812009158939966, 3.7559952076646748, 3.9230090491866063, 4.08319727664486, 4.23733406754766, 4.386057455164034, 4.52990066116245, 4.669314724882014, 4.80468521341409, 4.936344801571301, 5.064582904840241, 5.1896531676018585, 5.311779362887733, 5.431160097069503, 5.547972602672079, 5.662375826453062, 5.774512966476048, 5.88451357377991, 5.9924953066314535, 6.098565405076837, 6.2028219384406, 6.305354867095111, 6.406246951218787, 6.505574532660433, 6.603408210916542, 6.699813430238189, 6.794850991743674, 6.888577501923021, 6.981045766932057, 7.072305140475771, 7.162401831787993, 7.251379179163092, 7.339277893635041, 7.4261362766919365, 7.5119904153293495, 7.59687435726036, 7.680820268695265, 7.76385857676452, 7.846018098373213, 7.927326157034288, 8.007808689023484, 8.087490340025143, 8.16639455328972, 8.244543650196778, 8.321958904008119, 8.39866060750165, 8.47466813509532, 8.55, 8.624673906879032, 8.698706800438787, 8.772114910328067, 8.844913792683341, 8.917118368621109, 8.988742959947182, 9.0598013223249, 9.13030667611992, 9.200271735117392, 9.269708733288224, 9.338629449764028, 9.407045232165093, 9.474967018412254, 9.542405357141353, 9.60937042682818, 9.675872053722083, 9.741919728677711, 9.807522622966514, 9.872689603142602, 9.937429245031133, 10.001749846901793, 10.06565944188457, 10.129165809680481, 10.192276487615514, 10.254998781082326, 10.317339773410586, 10.379306335203717, 10.440905133176914, 10.502142638528579, 10.563025134874952, 10.623558725775466, 10.683749341874321, 10.74360274768199, 10.803124548018504, 10.862320194139006, 10.921194989560439, 10.97975409560706, 11.038002536691138, 11.095945205344158, 11.153586867012784, 11.210932164632876, 11.267985622994024, 11.324751652906125, 11.38123455517898], [0.0, 1.1423659658795862, 1.6155494421403513, 1.978635893740938, 2.2847319317591723, 2.5544079548889607, 2.7982137159266447, 3.022416251941483, 3.2310988842807027, 3.4270978976387587, 3.612478373637689, 3.7887992820945273, 3.957271787481876, 4.118859065323795, 4.274342054632502, 4.424364361125788, 4.569463863518345, 4.710095540432275, 4.846648326421054, 4.9794578018093505, 5.108815909777921, 5.234978509984544, 5.358171329847527, 5.478594710324904, 5.596427431853289, 5.7118298293979315, 5.8249463516842805, 5.935907681222814, 6.044832503882966, 6.151828996322964, 6.256996084384264, 6.360424514134258, 6.462197768561405, 6.562392856268208, 6.661080993352356, 6.758328195641287, 6.854195795277517, 6.9487408931402825, 7.042016756583302, 7.13407317035647, 7.224956747275378, 7.314711204141966, 7.40337760755184, 7.490994593510263, 7.577598564189055, 7.663223864666881, 7.747902942086975, 7.831666489323967, 7.914543574963752, 7.996561761157105, 8.077747210701757, 8.15812478453229, 8.23771813064759, 8.316549765377468, 8.394641147779934, 8.472012747865763, 8.548684109265004, 8.624673906879032, 8.700000000000001, 8.7746794813258, 8.848728722251575, 8.922163414777831, 8.99499861033897, 9.06724875582445, 9.13892772703669, 9.210048859805251, 9.280624978954812, 9.35066842530522, 9.42019108086455, 9.489204392360827, 9.557719393244396, 9.625746724280669, 9.693296652842108, 9.760379090998464, 9.82700361249552, 9.89317946870469, 9.958915603618701, 10.024220667962174, 10.089103032480145, 10.15357080046227, 10.217631819555843, 10.281293692916277, 10.344563789740002, 10.407449255220993, 10.469957019969089, 10.532093808925177, 10.593866149805747, 10.655280381106826, 10.716342659695053, 10.777058968011636, 10.837435120913067, 10.897476772170704, 10.957189420649808, 11.016578416187127, 11.07564896518484, 11.13440613593738, 11.192854863706579, 11.250999955559507, 11.308846094982458, 11.366397846283581, 11.423659658795863, 11.480635870891476], [0.0, 1.1521718621802912, 1.6294170736800322, 1.9956202043475106, 2.3043437243605824, 2.5763346055976504, 2.822233158334017, 3.048360214935236, 3.2588341473600644, 3.456515586540873, 3.6434873404473356, 3.8213217608570993, 3.9912404086950213, 4.154214727237869, 4.311032358959974, 4.462342434193054, 4.608687448721165, 4.750526286633934, 4.888251221040097, 5.022200712834962, 5.152669211195301, 5.279914772039412, 5.404165060395546, 5.52562213691816, 5.644466316668034, 5.760859310901456, 5.874946808269842, 5.9868606130425315, 6.096720429870472, 6.20463536398393, 6.310705190388789, 6.415021434102929, 6.517668294720129, 6.618723441873063, 6.718258702967608, 6.816340660501058, 6.913031173081746, 7.0083878317342005, 7.1024643610510285, 7.195310973126873, 7.286974680894671, 7.377499576414762, 7.466927078792185, 7.555296155677816, 7.642643521714199, 7.72900381679295, 7.814409766578663, 7.898892327408951, 7.982480817390043, 8.065203035262039, 8.147085368400163, 8.228152891141487, 8.308429454475737, 8.38793776800949, 8.46669947500205, 8.544735221175667, 8.622064717919947, 8.698706800438787, 8.7746794813258, 8.85, 8.924684868386109, 8.998749913182387, 9.072210315022463, 9.14508064480571, 9.21737489744233, 9.28910652323462, 9.360288457093615, 9.430933145770888, 9.501052573267868, 9.570658284569562, 9.639761407835778, 9.708372675170644, 9.776502442080194, 9.844160705717883, 9.911357122009074, 9.978101021737553, 10.044401425669925, 10.11026705878732, 10.17570636368798, 10.240727513218971, 10.305338422390601, 10.369546759622622, 10.433359957367522, 10.49678522215254, 10.559829544078823, 10.62249970581313, 10.684802291104877, 10.74674369285878, 10.808330120791092, 10.86956760869539, 10.930462021342006, 10.991019061033422, 11.05124427383632, 11.111143055509636, 11.170720657146521, 11.229982190546874, 11.288932633336067, 11.34757683384431, 11.405919515760225, 11.463965282571298, 11.521718621802911, 11.579183909067169], [0.0, 1.1618950038622249, 1.6431676725154982, 2.0124611797498106, 2.3237900077244498, 2.598076211353316, 2.846049894151541, 3.074085229787879, 3.2863353450309964, 3.4856850115866744, 3.674234614174767, 3.853569773599539, 4.024922359499621, 4.189272013130682, 4.347413023856831, 4.499999999999999, 4.6475800154488995, 4.790615826801393, 4.9295030175464944, 5.06458290484024, 5.196152422706632, 5.324471804789654, 5.449770637375485, 5.572252686302013, 5.692099788303082, 5.809475019311125, 5.92452529743945, 6.037383539249432, 6.148170459575758, 6.256996084384262, 6.363961030678928, 6.469157595854347, 6.572670690061993, 6.674578638386097, 6.774953874381729, 6.873863542433759, 6.971370023173349, 7.067531393633848, 7.162401831787992, 7.256031973468694, 7.348469228349534, 7.439758060582347, 7.529940238806679, 7.619055059520175, 7.707139547199078, 7.794228634059947, 7.880355321938218, 7.965550828411051, 8.049844718999243, 8.133265027035575, 8.215838362577491, 8.2975900115636, 8.378544026261364, 8.45872330792301, 8.538149682454623, 8.616843969807041, 8.694826047713661, 8.772114910328067, 8.848728722251575, 8.924684868386109, 8.999999999999998, 9.074690077352503, 9.148770409186142, 9.222255689363639, 9.295160030897799, 9.367496997597597, 9.439279633531363, 9.510520490488414, 9.581231653602787, 9.651424765287246, 9.72111104761179, 9.790301323248432, 9.859006035092989, 9.927235264664578, 9.994998749374608, 10.062305898749052, 10.12916580968048, 10.195587280779858, 10.261578825892244, 10.327148686835104, 10.392304845413264, 10.457055034760026, 10.521406750050108, 10.585367258626409, 10.648943609579309, 10.712142642814275, 10.774970997640782, 10.837435120913065, 10.89954127475097, 10.961295543867065, 11.022703842524301, 11.083771921146699, 11.144505372604026, 11.20490963818986, 11.264990013311152, 11.324751652906123, 11.384199576606164, 11.443338673656392, 11.502173707608486, 11.560709320798617, 11.61895003862225, 11.67690027361714], [0.0, 1.1715374513859982, 1.6568041525780892, 2.0291623887703025, 2.3430749027719964, 2.6196373794859475, 2.8696689704563485, 3.099596747965774, 3.3136083051561784, 3.514612354157994, 3.704726710568541, 3.885550154096586, 4.058324777540605, 4.224038352098617, 4.383491758860737, 4.537345038676252, 4.686149805543993, 4.830372656431385, 4.970412457734267, 5.106613359164761, 5.239274758971895, 5.368659050451984, 5.494997725204261, 5.6184962400984135, 5.739337940912697, 5.8576872569299905, 5.973692325521964, 6.087487166310908, 6.199193495931548, 6.308922253443927, 6.416774890862231, 6.522844471547669, 6.627216610312357, 6.729970282252367, 6.83117852204142, 6.930909031288753, 7.029224708315988, 7.126184112131822, 7.2218418703264335, 7.31624903895432, 7.409453421137082, 7.501499850029993, 7.592430440906258, 7.6822848163811255, 7.771100308193172, 7.858912138457841, 7.945753582889417, 8.031656118136532, 8.11664955508121, 8.200762159701988, 8.284020762890446, 8.366450860430605, 8.448076704197234, 8.5289213854977, 8.609006911369047, 8.688354274544748, 8.766983517721474, 8.844913792683341, 8.922163414777831, 8.998749913182385, 9.074690077352503, 9.15, 9.224695116913079, 9.29879024389732, 9.372299611087985, 9.445236894858699, 9.517615247529182, 9.589447325054765, 9.66074531286277, 9.731520949985155, 9.801785551622725, 9.871550030263737, 9.940824915468534, 10.009620372421724, 10.077946219344495, 10.14581194385151, 10.213226718329523, 10.280199414408264, 10.346738616588322, 10.412852635085162, 10.47854951794379, 10.543837062473985, 10.608722826052155, 10.673214136332128, 10.737318100903968, 10.801041616436816, 10.864391377339093, 10.927373883966816, 10.989995450408522, 11.052262211873188, 11.114180131705622, 11.175755008052029, 11.236992480196827, 11.29789803459033, 11.35847701058553, 11.418734605900953, 11.478675881825394, 11.538305768179315, 11.597629068046622, 11.656650462289758, 11.715374513859981, 11.773805671914245], [0.0, 1.1811011811017715, 1.6703293088490065, 2.045727254547878, 2.362202362203543, 2.6410225292488514, 2.8930952282978866, 3.1248999983999486, 3.340658617698013, 3.5433035433053144, 3.7349698793966195, 3.9172694571601787, 4.091454509095756, 4.258520869973517, 4.41927595879687, 4.574385204593071, 4.724404724407086, 4.869804924224378, 5.01098792654702, 5.148300690519155, 5.282045058497703, 5.412485565800615, 5.539855593785816, 5.664362276549762, 5.786190456595773, 5.905505905508858, 6.02245796996542, 6.137181763643635, 6.249799996799897, 6.360424514134257, 6.469157595854347, 6.576093065034891, 6.681317235396026, 6.784909726739185, 6.886944169949398, 6.987488819311269, 7.086607086610629, 7.184358008896829, 7.280796659706958, 7.375974511886548, 7.469939758793239, 7.562737599573318, 7.654410493303844, 7.74499838605535, 7.834538914320357, 7.923067587746553, 8.010617953691213, 8.097221745759466, 8.182909018191513, 8.267708267712402, 8.351646544245034, 8.43474955170573, 8.517041739947034, 8.598546388779909, 8.67928568489366, 8.75928079239386, 8.83855191759374, 8.917118368621109, 8.994998610338971, 9.072210315022463, 9.148770409186142, 9.224695116913079, 9.299999999999999, 9.374699995199846, 9.448809448814172, 9.522342148862325, 9.595311355031685, 9.66772982659321, 9.739609848448756, 9.810963255460699, 9.881801455200362, 9.952135449239021, 10.02197585309404, 10.091332914932496, 10.16021653312566, 10.22863627273939, 10.29660138103831, 10.36412080207482, 10.431203190428228, 10.497856924153615, 10.564090116995406, 10.629910629915946, 10.695326081985533, 10.76034386067657, 10.82497113160123, 10.889214847728923, 10.95308175811721, 11.016578416187123, 11.079711187571633, 11.142486257563883, 11.204909638189859, 11.266987174928353, 11.328724553099525, 11.39012730394178, 11.451200810395388, 11.511950312609935, 11.572380913191546, 11.63249758220478, 11.692305161943045, 11.751808371480536, 11.811011811017716, 11.869919966031786], [0.0, 1.1905880899790657, 1.6837458240482737, 2.062159062730128, 2.3811761799581315, 2.6622359023948277, 2.9163333142835373, 3.15, 3.3674916480965473, 3.571764269937197, 3.76497011940334, 3.9487339743264553, 4.124318125460256, 4.292726406376255, 4.4547727214752495, 4.611127844681819, 4.762352359916263, 4.908920451586072, 5.0512374721448206, 5.1896531676018585, 5.324471804789655, 5.455960043841964, 5.584353140695886, 5.709859893202285, 5.8326666285670745, 5.952940449895329, 6.07083190345442, 6.186477188190384, 6.3, 6.411513081948754, 6.521119535785248, 6.628913938195306, 6.734983296193095, 6.839407869106799, 6.942261879243682, 7.043614129124338, 7.143528539874394, 7.242064622743987, 7.339277893635041, 7.435220238836238, 7.52994023880668, 7.6234834557438385, 7.715892689767012, 7.807208207803861, 7.897467948652911, 7.986707707184482, 8.074961300216863, 8.162260716247674, 8.248636250920512, 8.334116629853462, 8.418729120241368, 8.502499632461033, 8.58545281275251, 8.6676121279162, 8.748999942850611, 8.829637591656862, 8.909545442950499, 8.988742959947182, 9.06724875582445, 9.14508064480571, 9.222255689363639, 9.298790243897322, 9.374699995199846, 9.450000000000001, 9.524704719832526, 9.598828053465693, 9.672383367092104, 9.74538352246847, 9.817840903172144, 9.88976743912616, 9.961174629530396, 10.032073564323579, 10.102474944289641, 10.172389099911584, 10.241826009066939, 10.31079531365064, 10.379306335203717, 10.447368089619511, 10.514989300993133, 10.582178414674363, 10.64894360957931, 10.715292809811594, 10.781233695639846, 10.846773713874555, 10.911920087683928, 10.976679825885423, 11.041059731746769, 11.10506641132776, 11.168706281391772, 11.231985576913816, 11.29491035821002, 11.357486517711566, 11.41971978640457, 11.48161573995577, 11.543179804542595, 11.604417262404864, 11.665333257134149, 11.725932798715846, 11.786220768337914, 11.846201922979366, 11.905880899790658, 11.9652622202775], [0.0, 1.2, 1.697056274847714, 2.078460969082653, 2.4, 2.683281572999748, 2.939387691339814, 3.1749015732775088, 3.394112549695428, 3.5999999999999996, 3.794733192202055, 3.9799497484264803, 4.156921938165306, 4.3266615305567875, 4.48998886412873, 4.6475800154488995, 4.8, 4.947726750741193, 5.091168824543142, 5.230678732248809, 5.366563145999496, 5.499090833947008, 5.628498911788116, 5.754997827975265, 5.878775382679628, 6.0, 6.118823416311343, 6.235382907247959, 6.3498031465550175, 6.462197768561405, 6.572670690061994, 6.681317235396026, 6.788225099390856, 6.893475175845635, 6.997142273814362, 7.0992957397195395, 7.199999999999999, 7.299315036357864, 7.397296803562772, 7.493997598078078, 7.58946638440411, 7.68374908491942, 7.776888838089433, 7.868926229162399, 7.959899496852961, 8.049844718999243, 8.138795979750322, 8.226785520481252, 8.313843876330612, 8.4, 8.485281374238571, 8.569714114251422, 8.653323061113575, 8.736131867136622, 8.818163074019441, 8.899438184514796, 8.97997772825746, 9.0598013223249, 9.138927727036691, 9.21737489744233, 9.295160030897799, 9.372299611087985, 9.448809448814172, 9.524704719832526, 9.6, 9.674709297958259, 9.748846085563152, 9.82242332624694, 9.895453501482386, 9.96794863550169, 10.039920318408907, 10.11137972781163, 10.182337649086284, 10.252804494381037, 10.322790320451153, 10.392304845413264, 10.461357464497619, 10.529957264870548, 10.598113039593418, 10.665833300778708, 10.733126291998992, 10.8, 10.8664621657649, 10.932520294973157, 10.998181667894016, 11.063453348751466, 11.128342194594847, 11.192854863706579, 11.256997823576231, 11.320777358467925, 11.384199576606166, 11.447270417003349, 11.50999565595053, 11.572380913191548, 11.63443165779919, 11.696153213770756, 11.757550765359255, 11.818629362155328, 11.879393923933998, 11.939849245279442, 12.0, 12.059850745345072], [0.0, 1.2093386622447824, 1.710263137648707, 2.094636006565341, 2.4186773244895647, 2.704163456597992, 2.9622626487197246, 3.1996093511552313, 3.420526275297414, 3.6280159867343467, 3.8242646351945884, 4.010922587136282, 4.189272013130682, 4.36033255612459, 4.524930938699506, 4.683748498798798, 4.8373546489791295, 4.986231041578398, 5.13078941294612, 5.271385017241674, 5.408326913195984, 5.5418859605733495, 5.672301120356711, 5.799784478754362, 5.924525297439449, 6.046693311223912, 6.16644143732834, 6.283908019696024, 6.3992187023104625, 6.512488003827722, 6.623820649745885, 6.733312706239031, 6.841052550594828, 6.947121706145647, 7.051595564125895, 7.154544010627092, 7.256031973468693, 7.356119901143537, 7.4548641838735055, 7.5523175251044625, 7.648529270389177, 7.7435456994841845, 7.837410286567878, 7.93016393273178, 8.021845174272563, 8.112490369793976, 8.20213386869539, 8.290808163261286, 8.378544026261364, 8.465370635713477, 8.551315688243534, 8.63640550229087, 8.72066511224918, 8.804118354497513, 8.886787946159174, 8.968695557326047, 9.049861877399012, 9.13030667611992, 9.210048859805251, 9.28910652323462, 9.367496997597597, 9.445236894858699, 9.522342148862325, 9.598828053465693, 9.674709297958259, 9.749999999999998, 9.824713736287688, 9.898863571137849, 9.972462083156795, 10.045521390151931, 10.11805317242403, 10.190068694567273, 10.26157882589224, 10.332594059576714, 10.40312453063982, 10.473180032826704, 10.542770034483349, 10.611903693494396, 10.68058987135074, 10.748837146407977, 10.816653826391969, 10.884047960203043, 10.951027349066388, 11.01759955707231, 11.083771921146699, 11.14955156048888, 11.214945385511248, 11.279960106312432, 11.344602240713423, 11.40887812188385, 11.472793905583766, 11.536355577044251, 11.599568957508724, 11.6624397104551, 11.72497334751768, 11.787175234126282, 11.849050594878898, 11.910604518663192, 11.971841963540946, 12.032767761408845, 12.093386622447824, 12.15370313937279], [0.0, 1.218605760695394, 1.7233687939614086, 2.1106870919205436, 2.437211521390788, 2.724885318687743, 2.98496231131986, 3.2241277890307014, 3.4467375879228173, 3.655817282086182, 3.8535697735995385, 4.041658075592244, 4.221374183841087, 4.393745554763043, 4.559605246071198, 4.719639816765682, 4.874423042781576, 5.024440267333268, 5.170106381884225, 5.311779362887733, 5.449770637375486, 5.584353140695885, 5.715767664977296, 5.844227921633448, 5.96992462263972, 6.093028803476971, 6.213694553162394, 6.33206127576163, 6.448255578061403, 6.5623928562682075, 6.674578638386097, 6.784909726739185, 6.8934751758456345, 7.000357133746822, 7.105631569396207, 7.209368904418749, 7.311634564172364, 7.412489460363503, 7.511990415329349, 7.610190536379494, 7.707139547199077, 7.802884082183972, 7.89746794865291, 7.99093236112032, 8.083316151184489, 8.174655956063228, 8.264986388373547, 8.354340189386592, 8.442748367682174, 8.530240324867759, 8.616843969807043, 8.702585822616173, 8.787491109526085, 8.871583849572747, 8.95488693395958, 9.037422198835241, 9.119210492142397, 9.200271735117393, 9.280624978954814, 9.360288457093617, 9.439279633531363, 9.517615247529184, 9.595311355031685, 9.672383367092104, 9.748846085563152, 9.824713736287688, 9.899999999999999, 9.974718041127778, 10.048880534666536, 10.122499691281792, 10.195587280779858, 10.268154654074898, 10.34021276376845, 10.411772183446965, 10.48284312579369, 10.553435459602715, 10.623558725775466, 10.69322215237297, 10.76243466879126, 10.831204919121419, 10.899541274750971, 10.967451846258548, 11.034944494649713, 11.102026841977999, 11.16870628139177, 11.234989986644404, 11.30088492110242, 11.36639784628358, 11.431535329954592, 11.496303753815832, 11.560709320798615, 11.624758061998538, 11.688455843266896, 11.751808371480537, 11.81482120050913, 11.877499736897493, 11.93984924527944, 12.00187485353851, 12.063581557729858, 12.124974226776732, 12.186057606953941, 12.24683632617012], [0.0, 1.2278029157808674, 1.7363755354185337, 2.126617031813674, 2.455605831561735, 2.745450782658469, 3.0074906483645134, 3.2484611741561573, 3.4727510708370675, 3.683408747342602, 3.882653731663435, 4.072161588149468, 4.253234063627348, 4.426906369012111, 4.594017849334066, 4.755260245244207, 4.91121166312347, 5.062361109205861, 5.209126606255601, 5.351868832473382, 5.490901565316938, 5.626499800053315, 5.7589061461357405, 5.888335927917157, 6.014981296729027, 6.139014578904337, 6.260591026412762, 6.379851095441022, 6.496922348312315, 6.611921052160257, 6.7249535314379685, 6.836117319063504, 6.945502141674135, 7.053190767305249, 7.159259738269035, 7.263780007681951, 7.366817494685204, 7.468433570702762, 7.568685486925718, 7.667626751479235, 7.76530746332687, 7.861774608827196, 7.957072325924907, 8.051242140191784, 8.144323176298936, 8.236352347975407, 8.327364529069206, 8.41739270795892, 8.506468127254696, 8.594620410466073, 8.68187767709267, 8.76826664740529, 8.853812738024223, 8.93854014926375, 9.022471945093539, 9.105630126465712, 9.188035698668132, 9.269708733288226, 9.350668425305221, 9.430933145770888, 9.510520490488414, 9.589447325054765, 9.667729826593211, 9.745383522468472, 9.82242332624694, 9.89886357113785, 9.974718041127778, 10.049999999999999, 10.124722218411723, 10.198896999185745, 10.27253620095836, 10.345651260312229, 10.418253212511202, 10.490352710943517, 10.561960045370366, 10.633085159068369, 10.703737664946765, 10.773926860713322, 10.843661743156693, 10.91295102160731, 10.981803130633876, 11.050226242027808, 11.118228276123855, 11.185816912501293, 11.25299960010663, 11.319783566835545, 11.386175828609009, 11.452183197975833, 11.517812292271481, 11.583069541360787, 11.647961194990305, 11.71249332977398, 11.776671855834314, 11.840502523119534, 11.903990927415897, 11.967142516072915, 12.029962593458054, 12.092456326156404, 12.154628747929735, 12.216484764448406, 12.278029157808675, 12.339266590847288], [0.0, 1.236931687685298, 1.7492855684535902, 2.142428528562855, 2.473863375370596, 2.7658633371878665, 3.0298514815086235, 3.2726136343907144, 3.4985711369071804, 3.710795063055894, 3.9115214431215892, 4.102438299353203, 4.28485705712571, 4.459820624195552, 4.628174586162453, 4.790615826801393, 4.947726750741192, 5.1, 5.24785670536077, 5.391660226683429, 5.531726674375733, 5.668333088307356, 5.801723881744115, 5.932115979985557, 6.059702963017247, 6.184658438426491, 6.307138812488592, 6.427285585688566, 6.545227268781429, 6.661080993352355, 6.774953874381729, 6.886944169949398, 6.997142273814361, 7.105631569396207, 7.212489168102786, 7.317786550590281, 7.421590126111788, 7.5239617223906725, 7.6249590162833005, 7.72463591375024, 7.8230428862431785, 7.920227269466452, 8.016233529532432, 8.111103500757464, 8.204876598706406, 8.297590011563598, 8.389278872465738, 8.479976415061541, 8.56971411425142, 8.658521813797087, 8.746427842267952, 8.833459118601276, 8.919641248391104, 9.004998611882181, 9.08955444452587, 9.173330910852393, 9.256349172324907, 9.338629449764028, 9.42019108086455, 9.501052573267868, 9.581231653602787, 9.66074531286277, 9.739609848448756, 9.817840903172144, 9.895453501482384, 9.972462083156795, 10.048880534666536, 10.124722218411723, 10.2, 10.274726273726225, 10.348912986396204, 10.422571659624126, 10.49571341072154, 10.568348972285122, 10.64048871058092, 10.712142642814275, 10.783320453366859, 10.854031509075327, 10.924284873619877, 10.994089321085218, 11.063453348751466, 11.132385189167685, 11.200892821556682, 11.268983982595769, 11.336666176614711, 11.403946685248929, 11.470832576583097, 11.537330713817646, 11.60344776348823, 11.669190203266036, 11.734564329364767, 11.799576263578281, 11.864231959971114, 11.928537211242627, 11.99249765478401, 12.056118778446072, 12.119405926034494, 12.182364302548173, 12.24499897917513, 12.30731489805961, 12.369316876852983, 12.4310096130604], [0.0, 1.2459935794377113, 1.7621010186706096, 2.158124185490724, 2.4919871588754225, 2.786126343151007, 3.052048492406371, 3.296589146375387, 3.5242020373412193, 3.7379807383131336, 3.940177660969109, 4.1324931941867735, 4.316248370981448, 4.492493739561581, 4.662081080376016, 4.825712382643624, 4.983974317750845, 5.1373631368631125, 5.286303056011829, 5.431160097069503, 5.572252686302014, 5.709859893202284, 5.844227921633448, 5.975575286112628, 6.104096984812742, 6.229967897188557, 6.353345575364212, 6.474372556472172, 6.593178292750774, 6.709880773903513, 6.824587899646396, 6.9373986479083065, 7.048404074682439, 7.157688174264091, 7.2653286229874015, 7.371397425183369, 7.475961476626267, 7.579083057995869, 7.680820268695265, 7.781227409605763, 7.880355321938218, 7.978251688183321, 8.074961300216863, 8.170526298837792, 8.264986388373547, 8.358379029453019, 8.450739612601964, 8.54210161494231, 8.632496741962896, 8.72195505606398, 8.810505093353049, 8.898173969978336, 8.984987479123163, 9.070970179644513, 9.156145477219113, 9.240535698756863, 9.324162160752032, 9.407045232165093, 9.489204392360827, 9.570658284569562, 9.651424765287247, 9.731520949985157, 9.810963255460699, 9.88976743912616, 9.96794863550169, 10.045521390151931, 10.122499691281792, 10.198896999185745, 10.274726273726225, 10.35, 10.424730212336433, 10.49892851675827, 10.572606112023658, 10.645773809357403, 10.718442050969909, 10.790620927453618, 10.862320194139006, 10.933549286485155, 11.004317334573738, 11.074633176769334, 11.144505372604028, 11.213942214939403, 11.282951741454895, 11.351541745507523, 11.419719786404569, 11.487493199127478, 11.554869103542456, 11.621854413130462, 11.688455843266896, 11.75467991907904, 11.820532982907327, 11.88602120139452, 11.951150572225256, 12.015926930536823, 12.080355955020531, 12.144443173731762, 12.208193969625484, 12.27161358583296, 12.334707130694266, 12.397479582560322, 12.459935794377113, 12.522080498064213], [0.0, 1.2549900398011133, 1.7748239349298849, 2.1737065119284162, 2.5099800796022267, 2.8062430400804566, 3.0740852297878796, 3.3203915431767985, 3.5496478698597698, 3.7649701194033396, 3.968626966596886, 4.162331077653483, 4.3474130238568325, 4.524930938699507, 4.695742752749558, 4.860555523805895, 5.019960159204453, 5.174456493198102, 5.324471804789654, 5.470374758643142, 5.612486080160913, 5.751086853804244, 5.886425061104576, 6.018720794321665, 6.148170459575759, 6.274950199005567, 6.399218702310463, 6.521119535785248, 6.640783086353597, 6.758328195641287, 6.87386354243376, 6.98748881931127, 7.0992957397195395, 7.209368904418751, 7.317786550590282, 7.4246212024587495, 7.529940238806679, 7.633806389999685, 7.736278174936576, 7.83741028656788, 7.937253933193772, 8.035857141587325, 8.133265027035575, 8.229520034607122, 8.324662155306966, 8.418729120241368, 8.511756575466665, 8.603778239819992, 8.694826047713665, 8.784930278607794, 8.874119674649425, 8.962421547773795, 9.049861877399014, 9.136465399704639, 9.222255689363639, 9.307255234493143, 9.391485505499116, 9.474967018412254, 9.557719393244396, 9.639761407835778, 9.72111104761179, 9.801785551622725, 9.881801455200362, 9.961174629530396, 10.039920318408907, 10.11805317242403, 10.195587280779858, 10.27253620095836, 10.348912986396204, 10.424730212336433, 10.500000000000002, 10.57473403920874, 10.648943609579309, 10.72263960039691, 10.79583252926795, 10.868532559642079, 10.940749517286283, 11.012492905786592, 11.083771921146703, 11.154595465546924, 11.224972160321826, 11.294910358210021, 11.364418154925488, 11.433503400095702, 11.502173707608488, 11.570436465406136, 11.638298844762495, 11.705767809076002, 11.772850122209151, 11.83955235640267, 11.905880899790658, 11.97184196354095, 12.03744158864333, 12.102685652366588, 12.167579874403948, 12.232129822725069, 12.296340919151518, 12.3602184446716, 12.423767544509193, 12.48699323296045, 12.549900398011134, 12.612493805746748], [0.0, 1.2639224659764536, 1.7874562931719478, 2.189177927898964, 2.5278449319529073, 2.826216552212516, 3.095965116082544, 3.344024521441193, 3.5749125863438955, 3.791767397929361, 3.9968737783422683, 4.191956583744636, 4.378355855797928, 4.557137259288994, 4.729164831130333, 4.895150661624216, 5.0556898639058145, 5.211285829812063, 5.362368879515843, 5.509310301662088, 5.652433104425032, 5.792020372892347, 5.928321853610852, 6.061559205353026, 6.191930232165088, 6.319612329882269, 6.4447653176822515, 6.5675337836968914, 6.688049042882386, 6.806430782723057, 6.922788455528596, 7.03722246344394, 7.149825172687791, 7.26068178616857, 7.369871097922949, 7.477466148368711, 7.583534795858722, 7.6881402172437, 7.791341347932331, 7.893193270153722, 7.993747556684537, 8.093052576129727, 8.191153764885629, 8.288093870124781, 8.383913167489272, 8.478649656637547, 8.57233923733773, 8.665015868421706, 8.756711711595855, 8.847457261835178, 8.937281465859739, 9.026211829998232, 9.114274518577988, 9.201494443839001, 9.287895348247632, 9.373499879980796, 9.458329662260667, 9.542405357141353, 9.625746724280669, 9.708372675170644, 9.790301323248432, 9.871550030263737, 9.952135449239021, 10.032073564323579, 10.111379727811629, 10.190068694567273, 10.268154654074898, 10.345651260312227, 10.422571659624126, 10.49892851675827, 10.57473403920874, 10.65, 10.724737759031687, 10.798958283093791, 10.872672164652073, 10.945889639494817, 11.018620603324177, 11.090874627368214, 11.162660973083437, 11.23398860601167, 11.304866208850065, 11.375302193788086, 11.445304714161175, 11.514881675466752, 11.584040745784694, 11.652789365641175, 11.721134757351782, 11.789083933877135, 11.856643707221703, 11.92382069640432, 11.990621335026805, 12.05705187846515, 12.123118410706052, 12.188826850849923, 12.254182959300062, 12.3191923436563, 12.383860464330176, 12.44819263989757, 12.512194052203633, 12.57586975123391, 12.639224659764539, 12.702263577803762], [0.0, 1.2727922061357855, 1.8, 2.2045407685048604, 2.545584412271571, 2.846049894151542, 3.1176914536239795, 3.3674916480965473, 3.6, 3.818376618407356, 4.024922359499621, 4.221374183841087, 4.409081537009721, 4.589117562233507, 4.762352359916263, 4.9295030175464944, 5.091168824543142, 5.24785670536077, 5.3999999999999995, 5.54797260267208, 5.692099788303084, 5.8326666285670745, 5.96992462263972, 6.104096984812743, 6.235382907247959, 6.363961030678928, 6.489992295835181, 6.613622305514581, 6.734983296193095, 6.854195795277517, 6.971370023173351, 7.08660708661063, 7.2, 7.3116345641723655, 7.42159012611179, 7.52994023880668, 7.636753236814712, 7.742092740338365, 7.846018098373213, 7.948584779695063, 8.049844718999243, 8.149846624323676, 8.248636250920512, 8.346256645946132, 8.442748367682174, 8.538149682454625, 8.632496741962896, 8.725823743349391, 8.818163074019441, 8.909545442950499, 9.0, 9.089554444525872, 9.178235124467014, 9.266067126888302, 9.353074360871938, 9.439279633531363, 9.524704719832526, 9.60937042682818, 9.69329665284211, 9.776502442080194, 9.859006035092989, 9.940824915468536, 10.02197585309404, 10.102474944289643, 10.182337649086284, 10.261578825892242, 10.34021276376845, 10.418253212511202, 10.49571341072154, 10.572606112023658, 10.648943609579309, 10.724737759031687, 10.799999999999999, 10.874741376235114, 10.948972554536796, 11.022703842524301, 11.09594520534416, 11.168706281391772, 11.240996397117119, 11.312824580978882, 11.384199576606168, 11.45512985522207, 11.525623627379128, 11.595688854052613, 11.665333257134149, 11.734564329364769, 11.803389343743603, 11.871815362445627, 11.93984924527944, 12.007497657713701, 12.074767078498864, 12.141663806908838, 12.208193969625485, 12.274363527287273, 12.34017828072188, 12.4056438768812, 12.470765814495918, 12.535549449465709, 12.6, 12.664122551523262, 12.727922061357855, 12.791403363196709], [0.0, 1.2816005617976296, 1.8124568960391858, 2.2197972880423116, 2.563201123595259, 2.8657459761814206, 3.1392674304684527, 3.3907963666371947, 3.6249137920783716, 3.8448016853928886, 4.052776825831889, 4.250588194591426, 4.439594576084623, 4.620876540224809, 4.795310208943734, 4.963617632332289, 5.126402247190518, 5.284174486142561, 5.437370688117557, 5.586367334860823, 5.731491952362841, 5.873031585135568, 6.011239472854164, 6.146340374564365, 6.278534860936905, 6.408002808988148, 6.53490627323759, 6.659391864126935, 6.7815927332743895, 6.901630242196404, 7.019615374078555, 7.135649935359778, 7.249827584156743, 7.362234715084817, 7.472951224248691, 7.5820511736600675, 7.689603370785777, 7.79567187611177, 7.900316449358216, 8.00359294317246, 8.105553651663778, 8.206247619953958, 8.305720919944276, 8.404016896698863, 8.501176389182852, 8.59723792854426, 8.692237916670251, 8.786210787364482, 8.879189152169246, 8.971203932583409, 9.06228448019593, 9.15245868605808, 9.241753080449618, 9.330192924050392, 9.417802291405359, 9.504604147464534, 9.590620417887468, 9.675872053722083, 9.760379090998464, 9.844160705717883, 9.927235264664578, 10.009620372421724, 10.091332914932496, 10.172389099911584, 10.252804494381037, 10.332594059576714, 10.411772183446965, 10.490352710943517, 10.568348972285122, 10.6457738093574, 10.72263960039691, 10.798958283093791, 10.874741376235114, 10.95, 11.024744895007775, 11.098986440211556, 11.172734669721645, 11.245999288635938, 11.31878968794809, 11.391114958598214, 11.462983904725682, 11.534405056178668, 11.60538668033082, 11.675936793251322, 11.746063170271135, 11.815773355984788, 11.885074673724185, 11.953974234538068, 12.022478945708327, 12.090595518831982, 12.158330477495667, 12.225690164567398, 12.29268074912873, 12.359308233068711, 12.425578457359642, 12.491497108033128, 12.55706972187381, 12.622301691846857, 12.6871982722743, 12.75176458377428, 12.816005617976296, 12.879926242024839], [0.0, 1.290348790056394, 1.8248287590894658, 2.234949663862701, 2.580697580112788, 2.885307609250702, 3.1606961258558215, 3.4139420030223127, 3.6496575181789317, 3.8710463701691813, 4.080441152620633, 4.279602785306132, 4.469899327725402, 4.652418725781247, 4.828043081829324, 4.997499374687304, 5.161395160225576, 5.32024435529046, 5.474486277268397, 5.624499977775803, 5.770615218501404, 5.913121003328107, 6.052272300549604, 6.188295403420882, 6.321392251711643, 6.45174395028197, 6.579513659838393, 6.704848991588103, 6.827884006044625, 6.948740893140282, 7.067531393633848, 7.184358008896828, 7.299315036357863, 7.412489460363503, 7.523961722390672, 7.633806389999683, 7.742092740338363, 7.848885271170678, 7.95424415013771, 8.058225611137976, 8.160882305241266, 8.262263612352248, 8.362415918859812, 8.461382865702271, 8.559205570612264, 8.655922827752104, 8.751571287488893, 8.846185618672038, 8.939798655450804, 9.032441530394758, 9.12414379544733, 9.214933532044602, 9.304837451562493, 9.393880987110705, 9.482088377567464, 9.569482744641947, 9.656086163658648, 9.74191972867771, 9.82700361249552, 9.911357122009074, 9.994998749374608, 10.077946219344495, 10.16021653312566, 10.241826009066937, 10.322790320451151, 10.40312453063982, 10.482843125793687, 10.561960045370366, 10.64048871058092, 10.718442050969907, 10.79583252926795, 10.872672164652073, 10.948972554536795, 11.024744895007775, 11.1, 11.174748319313503, 11.248999955551605, 11.322764680059372, 11.396051947933548, 11.468870912169166, 11.541230437002808, 11.613139110507547, 11.684605256490268, 11.755636945737988, 11.826242006656214, 11.896428035339012, 11.96620240510748, 12.035572275550505, 12.104544601099208, 12.173126139164088, 12.241323457861899, 12.309142943357186, 12.376590806841763, 12.443673091173684, 12.510395677195826, 12.576764289752749, 12.642784503423286, 12.708461747985082, 12.77380131362626, 12.838808355918395, 12.90348790056394, 12.967844847930595], [0.0, 1.299038105676658, 1.8371173070873836, 2.25, 2.598076211353316, 2.904737509655563, 3.181980515339464, 3.43693177121688, 3.6742346141747673, 3.8971143170299736, 4.107919181288746, 4.3084219849035215, 4.5, 4.683748498798798, 4.860555523805894, 5.031152949374526, 5.196152422706632, 5.356071321407137, 5.5113519212621505, 5.662375826453063, 5.809475019311126, 5.952940449895329, 6.093028803476971, 6.2299678971885575, 6.363961030678928, 6.49519052838329, 6.623820649745886, 6.750000000000001, 6.87386354243376, 6.995534289816612, 7.115124735378854, 7.232738070744716, 7.3484692283495345, 7.462405778299651, 7.574628703771559, 7.685213074469699, 7.794228634059947, 7.901740314639555, 8.007808689023483, 8.112490369793976, 8.215838362577491, 8.317902379807064, 8.418729120241368, 8.518362518700409, 8.616843969807043, 8.714212528966687, 8.810505093353049, 8.905756565278438, 9.0, 9.093266739736606, 9.185586535436919, 9.276987657639737, 9.367496997597597, 9.45714015968887, 9.545941546018392, 9.633924433998846, 9.721111047611789, 9.807522622966516, 9.893179468704691, 9.978101021737553, 10.062305898749052, 10.145811943851513, 10.228636272739392, 10.31079531365064, 10.392304845413264, 10.473180032826706, 10.553435459602715, 10.633085159068369, 10.712142642814275, 10.790620927453618, 10.86853255964208, 10.945889639494817, 11.022703842524301, 11.098986440211556, 11.174748319313505, 11.25, 11.324751652906127, 11.399013115177999, 11.472793905583767, 11.54610323875549, 11.618950038622252, 11.691342951089924, 11.763290356018592, 11.834800378544625, 11.905880899790658, 11.976539567003487, 12.04678380315676, 12.116620816052635, 12.186057606953941, 12.255100978776143, 12.323757543866238, 12.39203373139373, 12.459935794377115, 12.527469816367551, 12.59464171781, 12.6614572621006, 12.727922061357855, 12.794041581923988, 12.859821149611683, 12.925265954710566, 12.99038105676658, 13.05517138914691], [0.0, 1.307669683062202, 1.8493242008906932, 2.2649503305812253, 2.615339366124404, 2.92403830344269, 3.203123475609394, 3.4597687784012394, 3.6986484017813863, 3.9230090491866063, 4.135214625627067, 4.337049688440289, 4.529900661162451, 4.7148700936505135, 4.892851929090027, 5.06458290484024, 5.230678732248808, 5.391660226683429, 5.547972602672079, 5.700000000000001, 5.84807660688538, 5.992495306631454, 6.133514490078263, 6.2713634881100635, 6.406246951218788, 6.538348415311011, 6.6678332312678625, 6.794850991743676, 6.919537556802479, 7.042016756583302, 7.162401831787994, 7.280796659706959, 7.397296803562773, 7.51199041532935, 7.624959016283302, 7.736278174936577, 7.846018098373213, 7.954244150137713, 8.061017305526642, 8.16639455328972, 8.270429251254134, 8.373171442171719, 8.474668135095321, 8.57496355677387, 8.674099376880578, 8.77211491032807, 8.86904729945669, 8.96493167849036, 9.059801322324901, 9.153687781435416, 9.246621004453466, 9.33862944976403, 9.429740187301027, 9.51997899157346, 9.609370426828182, 9.69793792514677, 9.785703858180055, 9.872689603142602, 9.958915603618701, 10.044401425669925, 10.12916580968048, 10.213226718329523, 10.29660138103831, 10.379306335203717, 10.461357464497617, 10.542770034483349, 10.623558725775464, 10.703737664946765, 10.783320453366859, 10.862320194139004, 10.940749517286283, 11.018620603324177, 11.095945205344158, 11.172734669721645, 11.248999955551605, 11.324751652906125, 11.400000000000002, 11.474754899343168, 11.549025932952098, 11.622822376686312, 11.69615321377076, 11.769027147559822, 11.841452613594333, 11.913437790998868, 11.984990613262909, 12.056118778446075, 12.126829758844645, 12.197130810153674, 12.267028980156526, 12.336531116971255, 12.4056438768812, 12.474373731775076, 12.542726976220127, 12.610709734190225, 12.678327965469265, 12.745587471748802, 12.812493902437575, 12.879052760199412, 12.94526940623485, 13.011149065320867, 13.076696830622023, 13.14191766828571], [0.0, 1.3162446581088183, 1.8614510468986285, 2.2798026230355997, 2.6324893162176366, 2.943212530552288, 3.224127789030702, 3.48245602987317, 3.722902093797257, 3.9487339743264545, 4.162331077653483, 4.365489663256575, 4.559605246071199, 4.745787605866912, 4.9249365478146006, 5.097793640389928, 5.264978632435273, 5.427015754537663, 5.584353140695885, 5.737377449671584, 5.886425061104576, 6.031790778864931, 6.173734688177004, 6.312487623750245, 6.448255578061404, 6.5812232905440915, 6.711557196359129, 6.839407869106799, 6.96491205974634, 7.0881944104263965, 7.20936890441875, 7.328540100183665, 7.445804187594514, 7.561249896677137, 7.67495928327962, 7.787008411450446, 7.897467948652909, 8.006403687049511, 8.113877001779112, 8.219945255292155, 8.324662155306966, 8.42807807272809, 8.530240324867759, 8.63119342848948, 8.73097932651315, 8.829637591656862, 8.927205609819907, 9.02371874561702, 9.119210492142399, 9.21371260676173, 9.307255234493143, 9.39986702033598, 9.491575211733824, 9.582405752210665, 9.672383367092106, 9.761531642114367, 9.849873095629201, 9.937429245031131, 10.024220667962174, 10.11026705878732, 10.195587280779856, 10.280199414408264, 10.364120802074819, 10.447368089619511, 10.529957264870546, 10.611903693494396, 10.69322215237297, 10.77392686071332, 10.854031509075327, 10.933549286485153, 11.012492905786592, 11.090874627368214, 11.16870628139177, 11.245999288635938, 11.322764680059372, 11.399013115177997, 11.474754899343168, 11.55, 11.62475806199854, 11.699038422024266, 11.772850122209151, 11.846201922979366, 11.91910231519136, 11.991559531603885, 12.063581557729862, 12.135176142108529, 12.206350806035358, 12.27711285278424, 12.347469376354008, 12.417427269768888, 12.486993232960447, 12.556173780256469, 12.62497524750049, 12.69340379882402, 12.761465433091923, 12.829165990040039, 12.896511156122807, 12.963506470087484, 13.030157328290398, 13.096468989769726, 13.162446581088183, 13.228095100958418], [0.0, 1.3247641299491772, 1.8734993995195197, 2.294558781116754, 2.6495282598983545, 2.9622626487197254, 3.244996147917591, 3.504996433664377, 3.7469987990390394, 3.9742923898475313, 4.189272013130683, 4.3937455547630435, 4.589117562233508, 4.776504998427198, 4.956813492557492, 5.130789412946121, 5.299056519796709, 5.462142436809938, 5.6204981985585585, 5.774512966476049, 5.924525297439451, 6.07083190345442, 6.213694553162395, 6.353345575364213, 6.489992295835182, 6.623820649745886, 6.754998149518623, 6.883676343350261, 7.009992867328754, 7.13407317035647, 7.256031973468696, 7.375974511886549, 7.493997598078079, 7.610190536379495, 7.724635913750242, 7.83741028656788, 7.948584779695063, 8.058225611137978, 8.16639455328972, 8.273149339882607, 8.378544026261366, 8.482629309359217, 8.585452812752512, 8.687059341342154, 8.787491109526087, 8.886787946159176, 8.984987479123165, 9.082125301932363, 9.178235124467015, 9.273348909644241, 9.367496997597598, 9.46070821873289, 9.553009996854396, 9.644428443407108, 9.734988443752773, 9.82471373628769, 9.913626985114984, 10.001749846901792, 10.089103032480145, 10.175706363687977, 10.261578825892242, 10.346738616588322, 10.431203190428226, 10.514989300993133, 10.598113039593418, 10.68058987135074, 10.76243466879126, 10.84366174315669, 10.924284873619875, 11.004317334573736, 11.0837719211467, 11.162660973083435, 11.240996397117117, 11.31878968794809, 11.396051947933548, 11.472793905583767, 11.549025932952098, 11.62475806199854, 11.700000000000003, 11.77476114407422, 11.849050594878902, 11.922877169542597, 11.996249413879324, 12.069175613934865, 12.14166380690884, 12.213721791493374, 12.285357137665965, 12.356577195971385, 12.42738910632479, 12.49779980636592, 12.56781603939205, 12.63744436189533, 12.706691150728426, 12.775562609920554, 12.84406477716459, 12.912203529994407, 12.979984591670364, 13.047413536789584, 13.114495796636637, 13.181236664289132, 13.247641299491772, 13.313714733311665], [0.0, 1.3332291625973383, 1.8854707634964802, 2.309220647751098, 2.6664583251946765, 2.9811910371527692, 3.2657311585615862, 3.5273928048914542, 3.7709415269929605, 3.9996874877920146, 4.216040796766559, 4.421820891895103, 4.618441295502196, 4.807026107688619, 4.988486744494767, 5.163574343417552, 5.332916650389353, 5.497044660542609, 5.656412290489441, 5.811411188343156, 5.9623820743055385, 6.10962355632489, 6.25339907570275, 6.393942445784136, 6.5314623171231725, 6.666145812986692, 6.798161516174797, 6.927661943253295, 7.0547856097829085, 7.179658766264592, 7.302396866782852, 7.4231058189951735, 7.541883053985921, 7.658818446731847, 7.773995111909964, 7.887490095080945, 7.999374975584029, 8.109716394547963, 8.218576519081635, 8.326013451826752, 8.432081593533118, 8.536831965079319, 8.640312494348802, 8.742568272538682, 8.843641783790206, 8.943573111458306, 9.042400123860922, 9.140158641949274, 9.236882591004392, 9.332604138181368, 9.427353817482402, 9.52116064353501, 9.614052215377239, 9.706054811302069, 9.79719347568476, 9.887492098606199, 9.976973488989534, 10.06565944188457, 10.153570800462271, 10.240727513218971, 10.327148686835104, 10.412852635085162, 10.497856924153615, 10.582178414674363, 10.665833300778706, 10.748837146407977, 10.831204919121417, 10.912951021607308, 10.994089321085218, 11.074633176769332, 11.154595465546924, 11.23398860601167, 11.312824580978882, 11.391114958598214, 11.468870912169166, 11.546103238755489, 11.622822376686312, 11.699038422024266, 11.77476114407422, 11.850000000000001, 11.924764148611077, 11.999062463376047, 12.072903544715333, 12.146295731621224, 12.21924711264978, 12.291765536325531, 12.363858620996927, 12.435533764177556, 12.5067981514055, 12.577658764650916, 12.648122390299676, 12.718195626738881, 12.787884891568272, 12.857196428459824, 12.926136313686314, 12.994710462338128, 13.062924634246345, 13.130784439628885, 13.19829534447536, 13.26546267568531, 13.332291625973385, 13.398787258554414], [0.0, 1.3416407864998738, 1.8973665961010278, 2.3237900077244507, 2.6832815729997477, 3.0000000000000004, 3.286335345030997, 3.5496478698597698, 3.7947331922020555, 4.024922359499621, 4.242640687119286, 4.449719092257398, 4.647580015448901, 4.83735464897913, 5.019960159204453, 5.196152422706632, 5.366563145999495, 5.531726674375733, 5.692099788303083, 5.848076606885379, 6.000000000000001, 6.148170459575759, 6.292853089020911, 6.434283176858166, 6.572670690061994, 6.708203932499369, 6.841052550594829, 6.9713700231733515, 7.0992957397195395, 7.224956747275378, 7.348469228349535, 7.46993975879324, 7.589466384404111, 7.707139547199079, 7.82304288624318, 7.937253933193772, 8.049844718999243, 8.160882305241268, 8.270429251254134, 8.378544026261366, 8.485281374238571, 8.590692637965812, 8.694826047713663, 8.797726979169108, 8.899438184514796, 9.0, 9.099450532861862, 9.197825830053535, 9.295160030897803, 9.391485505499118, 9.48683298050514, 9.581231653602789, 9.67470929795826, 9.767292357659825, 9.85900603509299, 9.9498743710662, 10.039920318408907, 10.12916580968048, 10.217631819555843, 10.305338422390601, 10.392304845413264, 10.47854951794379, 10.564090116995406, 10.64894360957931, 10.73312629199899, 10.816653826391969, 10.89954127475097, 10.981803130633876, 11.063453348751466, 11.144505372604026, 11.224972160321826, 11.304866208850063, 11.384199576606166, 11.46298390472568, 11.541230437002808, 11.61895003862225, 11.696153213770758, 11.772850122209151, 11.849050594878902, 11.924764148611075, 12.000000000000002, 12.074767078498866, 12.149074038789953, 12.222929272478018, 12.296340919151518, 12.369316876852984, 12.441864811996634, 12.513992168768526, 12.585706178041821, 12.657013865837392, 12.727922061357857, 12.798437404620927, 12.868566353716332, 12.938315191708698, 13.00769003320728, 13.076696830622021, 13.145341380123988, 13.213629327327148, 13.281566172707192, 13.349157276772196, 13.416407864998739, 13.483323032546544], [0.0, 1.35, 1.9091883092036783, 2.3382685902179845, 2.7, 3.0186917696247164, 3.3068111527572905, 3.5717642699371974, 3.8183766184073566, 4.05, 4.2690748412273125, 4.47744346697979, 4.676537180435969, 4.8674942218763855, 5.0512374721448206, 5.228527517380012, 5.4, 5.566192594583842, 5.727564927611035, 5.88451357377991, 6.037383539249433, 6.186477188190384, 6.332061275761631, 6.474372556472173, 6.613622305514581, 6.75, 6.883676343350261, 7.014805770653954, 7.143528539874395, 7.269972489631581, 7.3942545263197434, 7.51648188982053, 7.636753236814713, 7.75515957282634, 7.871785058041157, 7.9867077071844825, 8.1, 8.211729415902598, 8.321958904008119, 8.430747297837838, 8.538149682454625, 8.644217720534346, 8.748999942850611, 8.852542007807699, 8.95488693395958, 9.05607530887415, 9.156145477219113, 9.25513371054141, 9.353074360871938, 9.450000000000001, 9.545941546018392, 9.640928378532848, 9.734988443752771, 9.828148350528702, 9.920433458271873, 10.011867957579145, 10.102474944289641, 10.192276487615512, 10.281293692916277, 10.36954675962262, 10.457055034760025, 10.543837062473985, 10.629910629915944, 10.715292809811592, 10.8, 10.884047960203041, 10.967451846258546, 11.050226242027808, 11.132385189167683, 11.2139422149394, 11.294910358210021, 11.375302193788084, 11.45512985522207, 11.534405056178668, 11.613139110507547, 11.691342951089922, 11.76902714755982, 11.846201922979366, 11.922877169542597, 11.999062463376045, 12.074767078498866, 12.150000000000002, 12.224769936485513, 12.299085331844804, 12.372954376380768, 12.446385017345401, 12.519384968919203, 12.5919617216699, 12.664122551523262, 12.735874528276415, 12.807224523681937, 12.878179219128768, 12.948745112944346, 13.018928527340492, 13.088735615024088, 13.158172365492101, 13.227244611029162, 13.295958032424744, 13.364318164425747, 13.432330400939371, 13.5, 13.567332088513206], [0.0, 1.3583077707206126, 1.920937271229855, 2.352658071203719, 2.716615541441225, 3.0372685096974887, 3.3271609519228256, 3.5937445652132824, 3.84187454245971, 4.074923312161838, 4.295346318982906, 4.504997225304363, 4.705316142407438, 4.897448315194353, 5.082322303829225, 5.260703375025055, 5.43323108288245, 5.600446410778342, 5.762811813689564, 5.9207263067971665, 6.0745370193949775, 6.224548176373929, 6.3710281744785915, 6.514215225182541, 6.654321903845651, 6.791538853603063, 6.926037828369119, 7.057974213611156, 7.187489130426565, 7.314711204141966, 7.4397580605823475, 7.562737599573319, 7.68374908491942, 7.802884082183973, 7.920227269466453, 8.035857141587325, 8.149846624323676, 8.262263612352248, 8.373171442171719, 8.482629309359217, 8.590692637965812, 8.697413408594537, 8.802840450672727, 8.907019703582113, 9.009994450608726, 9.111805529092464, 9.212491519670454, 9.312088917101255, 9.410632284814875, 9.50815439504429, 9.604686356149275, 9.700257728534847, 9.794896630388706, 9.888629834309707, 9.981482855768476, 10.07348003422849, 10.16464460765845, 10.254998781082328, 10.344563789740002, 10.433359957367522, 10.52140675005011, 10.608722826052155, 10.695326081985533, 10.781233695639846, 10.8664621657649, 10.951027349066388, 11.034944494649713, 11.118228276123855, 11.200892821556684, 11.282951741454895, 11.364418154925488, 11.445304714161175, 11.525623627379128, 11.60538668033082, 11.684605256490268, 11.763290356018592, 11.841452613594333, 11.919102315191362, 11.996249413879326, 12.072903544715333, 12.149074038789955, 12.224769936485515, 12.300000000000002, 12.374772725185704, 12.449096352747858, 12.522978878845084, 12.596428065130214, 12.669451448267207, 12.742056348957183, 12.814249880504127, 12.886038956948719, 12.95743030079653, 13.028430450365082, 13.099045766772482, 13.169282440588782, 13.239146498169738, 13.308643807691302, 13.377780084901982, 13.446560898608983, 13.51499167591309, 13.583077707206126, 13.650824150944151], [0.0, 1.3665650368716447, 1.9326148090087687, 2.366960075708925, 2.7331300737432893, 3.055732318119505, 3.3473870406632096, 3.615591237958185, 3.8652296180175374, 4.099695110614934, 4.32145808726638, 4.532383478921439, 4.73392015141785, 4.927220311697052, 5.113218164717793, 5.2926836293132045, 5.466260147486579, 5.634491991297884, 5.797844427026306, 5.956718895499435, 6.11146463623901, 6.262387723544431, 6.409758185766449, 6.553815682486044, 6.694774081326419, 6.832825184358224, 6.968141789602161, 7.100880227126775, 7.23118247591637, 7.359177943221647, 7.484984969924789, 7.608712111783439, 7.730459236035075, 7.850318464877716, 7.968374991176056, 8.084707786927119, 8.199390221229867, 8.312490601498446, 8.424072649259383, 8.534195919944656, 8.64291617453276, 8.750285709621144, 8.856353651475306, 8.961166218746307, 9.064766957842878, 9.167196954358513, 9.268495023465244, 9.368697881776313, 9.4678403028357, 9.565955258101514, 9.663074045043844, 9.759226403767872, 9.854440623394105, 9.948743639274259, 10.04216112198963, 10.13471755896532, 10.226436329435586, 10.317339773410586, 10.407449255220994, 10.49678522215254, 10.585367258626409, 10.67321413633213, 10.76034386067657, 10.846773713874555, 10.932520294973157, 11.01759955707231, 11.102026841977999, 11.185816912501293, 11.268983982595769, 11.351541745507523, 11.433503400095702, 11.514881675466752, 11.595688854052613, 11.675936793251322, 11.755636945737988, 11.834800378544625, 11.91343779099887, 11.991559531603887, 12.069175613934865, 12.146295731621226, 12.22292927247802, 12.299085331844804, 12.374772725185704, 12.45, 12.524775447088862, 12.599107111220224, 12.673002801230655, 12.746470099600124, 12.819516371532899, 12.892148773575334, 12.96437426179914, 13.036199599576557, 13.107631364972088, 13.178675957773605, 13.24933960618415, 13.3196283731942, 13.389548162652838, 13.459104725055083, 13.52830366306138, 13.597150436764316, 13.665650368716449, 13.733808648732516], [0.0, 1.374772708486752, 1.9442222095223582, 2.381176179958132, 2.749545416973504, 3.07408522978788, 3.3674916480965478, 3.6373066958946425, 3.8884444190447165, 4.124318125460256, 4.347413023856832, 4.559605246071199, 4.762352359916264, 4.956813492557492, 5.143928459844674, 5.324471804789654, 5.499090833947008, 5.668333088307356, 5.8326666285670745, 5.992495306631454, 6.14817045957576, 6.300000000000001, 6.448255578061404, 6.593178292750775, 6.7349832961930955, 6.87386354243376, 7.009992867328755, 7.143528539874396, 7.274613391789285, 7.40337760755184, 7.529940238806681, 7.654410493303844, 7.776888838089433, 7.897467948652912, 8.016233529532434, 8.133265027035575, 8.248636250920512, 8.362415918859814, 8.474668135095321, 8.585452812752512, 8.694826047713663, 8.802840450672727, 8.909545442950499, 9.014987520790031, 9.119210492142399, 9.222255689363639, 9.324162160752033, 9.424966843443006, 9.524704719832528, 9.623408959407266, 9.72111104761179, 9.817840903172145, 9.913626985114984, 10.008496390567368, 10.102474944289643, 10.195587280779858, 10.287856919689348, 10.379306335203717, 10.46995701996909, 10.559829544078825, 10.648943609579309, 10.73731810090397, 10.82497113160123, 10.911920087683928, 10.998181667894016, 11.083771921146699, 11.16870628139177, 11.25299960010663, 11.336666176614711, 11.419719786404569, 11.50217370760849, 11.584040745784694, 11.665333257134149, 11.746063170271137, 11.826242006656216, 11.905880899790658, 11.984990613262909, 12.063581557729862, 12.14166380690884, 12.219247112649782, 12.29634091915152, 12.37295437638077, 12.449096352747858, 12.524775447088862, 12.600000000000001, 12.674778104566567, 12.749117616525469, 12.823026163897508, 12.896511156122807, 12.969579792730373, 13.042239071570496, 13.114495796636637, 13.18635658550155, 13.257827876390614, 13.328915934913837, 13.399626860476378, 13.469966592386191, 13.539940915676112, 13.609555466656506, 13.6788157382136, 13.74772708486752, 13.81629472760335], [0.0, 1.382931668593933, 1.9557607215607948, 2.395307913400697, 2.765863337187866, 3.092329219213246, 3.387476937190865, 3.6588932752951404, 3.9115214431215897, 4.148795005781799, 4.373213921133976, 4.586665455426197, 4.790615826801394, 4.986231041578399, 5.174456493198102, 5.356071321407137, 5.531726674375732, 5.701973342624464, 5.867282164682384, 6.028059389223037, 6.184658438426492, 6.3373890522832825, 6.486524493131896, 6.632307290830244, 6.77495387438173, 6.914658342969666, 7.051595564125896, 7.1859237402020915, 7.317786550590281, 7.447314952383846, 7.574628703771559, 7.699837660626359, 7.823042886243179, 7.944337606119218, 8.06380803342937, 8.181534085976786, 8.297590011563598, 8.412044935685973, 8.524963343029693, 8.63640550229087, 8.746427842267952, 8.855083285887266, 8.962421547773793, 9.068489400115103, 9.173330910852394, 9.276987657639737, 9.37949892051809, 9.48090185583629, 9.581231653602789, 9.680521680157533, 9.778803607803974, 9.876107532828915, 9.972462083156797, 10.067894516729902, 10.162430811572595, 10.256095748383007, 10.348912986396204, 10.440905133176914, 10.532093808925177, 10.622499705813128, 10.712142642814275, 10.801041616436816, 10.88921484772892, 10.976679825885421, 11.063453348751464, 11.149551560488879, 11.234989986644402, 11.319783566835543, 11.403946685248927, 11.487493199127476, 11.570436465406136, 11.652789365641173, 11.734564329364767, 11.815773355984788, 11.896428035339012, 11.976539567003485, 12.056118778446073, 12.135176142108529, 12.213721791493372, 12.29176553632553, 12.369316876852984, 12.4463850173454, 12.522978878845082, 12.599107111220222, 12.674778104566565, 12.750000000000002, 12.824780699879435, 12.899127877496214, 12.973048986263793, 13.046551268438721, 13.119641763401926, 13.192327315527008, 13.264614581660489, 13.336510038237142, 13.408019988051928, 13.479150566708572, 13.54990774876346, 13.620297353582266, 13.690325050925562, 13.759996366278592, 13.829316685939332, 13.898291261878207], [0.0, 1.3910427743243556, 1.9672315572906003, 2.409356760631352, 2.7820855486487113, 3.1104662029991585, 3.4073450074801643, 3.6803532439155893, 3.9344631145812006, 4.173128322973066, 4.398863489584555, 4.61356694976891, 4.818713521262704, 5.015476049190147, 5.204805471869242, 5.387485498820391, 5.5641710972974225, 5.735416288291549, 5.901694671871801, 6.0634148794223215, 6.220932405998317, 6.374558808262734, 6.5245689512794645, 6.671206787381127, 6.814690014960329, 6.955213871621778, 7.092954250522134, 7.228070281894055, 7.3607064878311785, 7.490994593510264, 7.619055059520177, 7.744998386055352, 7.868926229162401, 7.990932361120323, 8.111103500757466, 8.229520034607122, 8.346256645946132, 8.461382865702273, 8.574963556773872, 8.687059341342156, 8.79772697916911, 8.907019703582115, 9.014987520790031, 9.121677477306463, 9.22713389953782, 9.331398608997475, 9.434511116109833, 9.5365087951514, 9.637427042525408, 9.73729942027049, 9.836157786453002, 9.93403241387907, 10.030952098380293, 10.126944257770951, 10.222035022440494, 10.316249318429639, 10.409610943738484, 10.502142638528579, 10.593866149805747, 10.684802291104875, 10.774970997640782, 10.864391377339093, 10.95308175811721, 11.041059731746769, 11.128342194594845, 11.214945385511246, 11.300884921102417, 11.386175828609007, 11.470832576583097, 11.554869103542455, 11.638298844762495, 11.721134757351782, 11.803389343743602, 11.885074673724183, 11.96620240510748, 12.046783803156758, 12.126829758844643, 12.206350806035358, 12.285357137665965, 12.363858620996927, 12.441864811996634, 12.519384968919201, 12.59642806513021, 12.673002801230654, 12.749117616525467, 12.824780699879435, 12.900000000000002, 12.974783235183546, 13.049137902558929, 13.123071286859643, 13.196590468753662, 13.269702332757884, 13.342413574762254, 13.414730709186825, 13.486660075793415, 13.558207846172001, 13.629380029920657, 13.70018248053653, 13.770620901034201, 13.840700849306732, 13.910427743243556, 13.979806865618713], [0.0, 1.3991068579633223, 1.978635893740938, 2.423324163210527, 2.7982137159266447, 3.128498042192132, 3.427097897638759, 3.70168880377592, 3.957271787481876, 4.197320573889966, 4.424364361125788, 4.640312489477407, 4.846648326421054, 5.044551516240071, 5.234978509984544, 5.418717560456533, 5.596427431853289, 5.768665356908824, 5.9359076812228135, 6.098565405076838, 6.256996084384264, 6.411513081948754, 6.562392856268208, 6.709880773903514, 6.854195795277518, 6.995534289816612, 7.13407317035647, 7.269972489631581, 7.40337760755184, 7.534421012924617, 7.663223864666881, 7.789897303559271, 7.914543574963752, 8.03725699477129, 8.158124784532289, 8.277227796792838, 8.394641147779932, 8.51043477150257, 8.62467390687903, 8.73741952752642, 8.848728722251575, 8.958655032983469, 9.067248755824448, 9.174557210023815, 9.280624978954814, 9.385494126576395, 9.489204392360827, 9.5917933672489, 9.693296652842108, 9.793748005743257, 9.893179468704691, 9.991621490028534, 10.089103032480143, 10.185651672818977, 10.281293692916277, 10.376054163312757, 10.469957019969089, 10.563025134874952, 10.655280381106827, 10.74674369285878, 10.837435120913065, 10.927373883966816, 11.016578416187123, 11.10506641132776, 11.192854863706579, 11.279960106312434, 11.36639784628358, 11.452183197975833, 11.537330713817648, 11.621854413130462, 11.705767809076004, 11.789083933877135, 11.871815362445627, 11.95397423453807, 12.035572275550507, 12.116620816052635, 12.197130810153675, 12.277112852784242, 12.356577195971385, 12.435533764177556, 12.513992168768528, 12.591961721669902, 12.669451448267207, 12.746470099600124, 12.823026163897508, 12.899127877496216, 12.974783235183548, 13.05, 13.124785712536417, 13.199147699756981, 13.273093083377363, 13.346628787825036, 13.419761547807028, 13.492497915508457, 13.564844267443693, 13.636806810980348, 13.708391590555037, 13.779604493598503, 13.850451256186565, 13.92093746843222, 13.991068579633223, 14.060849903188643], [0.0, 1.407124727947029, 1.98997487421324, 2.4372115213907883, 2.814249455894058, 3.1464265445104553, 3.4467375879228173, 3.722902093797257, 3.97994974842648, 4.221374183841086, 4.449719092257398, 4.666904755831214, 4.874423042781577, 5.073460357586329, 5.264978632435273, 5.449770637375485, 5.628498911788116, 5.801723881744115, 5.96992462263972, 6.133514490078262, 6.292853089020911, 6.448255578061404, 6.6000000000000005, 6.748333127521197, 6.8934751758456345, 7.035623639735145, 7.17495644586084, 7.3116345641723655, 7.445804187594514, 7.577598564189054, 7.707139547199078, 7.834538914320357, 7.95989949685296, 8.083316151184489, 8.204876598706408, 8.324662155306966, 8.442748367682173, 8.559205570612264, 8.674099376880577, 8.787491109526087, 8.899438184514796, 9.009994450608724, 9.119210492142399, 9.227133899537819, 9.333809511662428, 9.439279633531363, 9.54358423235212, 9.646761114488116, 9.748846085563153, 9.849873095629203, 9.949874371066201, 10.048880534666537, 10.146920715172659, 10.244022647378324, 10.340212763768452, 10.435516278555651, 10.529957264870546, 10.623558725775464, 10.716342659695053, 10.808330120791092, 10.89954127475097, 10.989995450408522, 11.079711187571633, 11.168706281391772, 11.256997823576231, 11.344602240713423, 11.43153532995459, 11.51781229227148, 11.60344776348823, 11.688455843266894, 11.772850122209151, 11.856643707221703, 11.93984924527944, 12.022478945708327, 12.104544601099208, 12.186057606953941, 12.267028980156525, 12.347469376354008, 12.42738910632479, 12.5067981514055, 12.585706178041821, 12.664122551523262, 12.742056348957181, 12.819516371532897, 12.896511156122807, 12.973048986263795, 13.049137902558929, 13.124785712536415, 13.200000000000001, 13.274788133902552, 13.349157276772194, 13.423114392718256, 13.496666255042394, 13.569819453478372, 13.642580401082489, 13.714955340794953, 13.786950351691269, 13.858571354941319, 13.929824119492679, 14.000714267493644, 14.07124727947029, 14.141428499271214], [0.0, 1.4150971698084904, 2.00124960961895, 2.4510201957552287, 2.830194339616981, 3.164253466459348, 3.466266002487403, 3.7439951923046055, 4.0024992192379, 4.2452915094254715, 4.474930167052889, 4.693346354148605, 4.902040391510457, 5.102205405508484, 5.2948087784168365, 5.4806477719335325, 5.660388679233962, 5.834595101633017, 6.00374882885685, 6.168265558485627, 6.328506932918696, 6.484789896365186, 6.637394066951276, 6.786567615518172, 6.932532004974806, 7.075485849042453, 7.215608082483417, 7.353060587265687, 7.487990384609211, 7.620531477528322, 7.750806409658288, 7.878927592001338, 8.0049984384758, 8.129114342903538, 8.25136352368504, 8.371827757425494, 8.490583018850943, 8.607700041242143, 8.723244809129227, 8.837278992993262, 8.949860334105779, 9.061042986323374, 9.170877820579664, 9.279412696932924, 9.38669270829721, 9.492760399378044, 9.597655963827835, 9.701417422212074, 9.804080783020915, 9.905680188659435, 10.00624804809475, 10.105815157620883, 10.204410811016968, 10.302062900215665, 10.398798007462208, 10.494641489827082, 10.589617556833673, 10.683749341874321, 10.777058968011636, 10.869567608695387, 10.961295543867065, 11.052262211873188, 11.142486257563883, 11.231985576913816, 11.320777358467923, 11.40887812188385, 11.49630375381583, 11.583069541360786, 11.669190203266034, 11.754679919079038, 11.839552356402669, 11.92382069640432, 12.0074976577137, 12.09059551883198, 12.173126139164088, 12.255100978776143, 12.336531116971255, 12.417427269768888, 12.49779980636592, 12.577658764650916, 12.657013865837392, 12.735874528276415, 12.814249880504127, 12.892148773575332, 12.969579792730372, 13.046551268438723, 13.123071286859645, 13.19914769975698, 13.274788133902552, 13.35, 13.424790501158668, 13.499166640944914, 13.573135231036344, 13.646702898502628, 13.719876092734948, 13.792661092044565, 13.865064009949611, 13.93709080116794, 14.008747267332648, 14.080039062445815, 14.150971698084906, 14.22155054837552], [0.0, 1.4230249470757705, 2.0124611797498106, 2.4647515087732477, 2.846049894151541, 3.1819805153394642, 3.4856850115866753, 3.76497011940334, 4.024922359499621, 4.269074841227312, 4.5, 4.719639816765683, 4.929503017546495, 5.130789412946121, 5.324471804789654, 5.5113519212621505, 5.692099788303082, 5.867282164682384, 6.037383539249432, 6.2028219384406, 6.3639610306789285, 6.521119535785248, 6.674578638386097, 6.824587899646397, 6.971370023173351, 7.115124735378854, 7.256031973468696, 7.3942545263197434, 7.52994023880668, 7.663223864666881, 7.794228634059948, 7.923067587746554, 8.049844718999243, 8.174655956063228, 8.2975900115636, 8.418729120241368, 8.538149682454623, 8.655922827752105, 8.772114910328067, 8.886787946159174, 9.0, 9.111805529092464, 9.222255689363639, 9.331398608997473, 9.439279633531365, 9.54594154601839, 9.651424765287247, 9.755767524905458, 9.85900603509299, 9.961174629530396, 10.062305898749054, 10.162430811572595, 10.261578825892242, 10.359777989899206, 10.457055034760026, 10.553435459602717, 10.648943609579309, 10.74360274768199, 10.837435120913067, 10.930462021342006, 11.022703842524301, 11.114180131705623, 11.204909638189859, 11.29491035821002, 11.384199576606164, 11.472793905583766, 11.560709320798615, 11.647961194990305, 11.734564329364767, 11.820532982907327, 11.905880899790658, 11.990621335026805, 12.074767078498864, 12.158330477495667, 12.241323457861899, 12.323757543866236, 12.4056438768812, 12.486993232960447, 12.56781603939205, 12.648122390299676, 12.727922061357857, 12.807224523681938, 12.886038956948719, 12.96437426179914, 13.042239071570496, 13.119641763401928, 13.196590468753664, 13.273093083377363, 13.349157276772194, 13.424790501158668, 13.5, 13.57479281609852, 13.649175799292793, 13.723155613779218, 13.796738745080303, 13.869931506680196, 13.942740046346701, 14.015170352157696, 14.087228258248674, 14.158919450297049, 14.230249470757707, 14.301223723863636], [0.0, 1.4309088021254184, 2.023610634484806, 2.478406746278746, 2.8618176042508368, 3.1996093511552317, 3.504996433664377, 3.785828839237189, 4.047221268969612, 4.292726406376255, 4.524930938699507, 4.745787605866913, 4.956813492557492, 5.159215056575952, 5.353970489272424, 5.5418859605733495, 5.7236352085016735, 5.8997881317891405, 6.070831903454419, 6.237186865887538, 6.399218702310463, 6.557247898318319, 6.711557196359129, 6.862397540218725, 7.009992867328754, 7.1545440106270926, 7.296231904209186, 7.435220238836238, 7.571657678474378, 7.705679723424794, 7.837410286567879, 7.966963034933701, 8.094442537939225, 8.219945255292156, 8.34356039110403, 8.465370635713478, 8.58545281275251, 8.703878445842406, 8.820714256793494, 8.936022605163888, 9.049861877399014, 9.162286832445272, 9.27334890964424, 9.383096503820047, 9.491575211733826, 9.598828053465693, 9.704895671773087, 9.809816512045472, 9.913626985114984, 10.01636161487793, 10.118053172424032, 10.218732798150661, 10.318430113151903, 10.4171733210118, 10.51498930099313, 10.611903693494396, 10.707940978544848, 10.803124548018504, 10.897476772170704, 10.991019061033422, 11.083771921146699, 11.175755008052029, 11.266987174928353, 11.357486517711566, 11.447270417003347, 11.536355577044251, 11.624758061998538, 11.71249332977398, 11.799576263578281, 11.886021201394518, 11.97184196354095, 12.05705187846515, 12.141663806908838, 12.225690164567398, 12.309142943357186, 12.39203373139373, 12.474373731775076, 12.556173780256469, 12.63744436189533, 12.718195626738881, 12.798437404620927, 12.878179219128768, 12.95743030079653, 13.036199599576557, 13.114495796636637, 13.19232731552701, 13.269702332757886, 13.346628787825036, 13.423114392718258, 13.499166640944914, 13.57479281609852, 13.65, 13.72479508043745, 13.799184758528312, 13.873175555726238, 13.946773820493398, 14.019985734657508, 14.09281731947165, 14.165274441393642, 14.23736281760074, 14.309088021254185, 14.380455486527541], [0.0, 1.438749456993816, 2.0346989949375804, 2.491987158875423, 2.877498913987632, 3.217141588429083, 3.5242020373412197, 3.8065732621348563, 4.069397989875161, 4.316248370981447, 4.549725266430931, 4.77179211617606, 4.983974317750846, 5.187484939737175, 5.383307533477908, 5.572252686302013, 5.754997827975264, 5.932115979985557, 6.104096984812742, 6.271363488110063, 6.434283176858166, 6.593178292750774, 6.748333127521197, 6.900000000000002, 7.0484040746824395, 7.19374728496908, 7.336211556382492, 7.475961476626268, 7.6131465242697125, 7.747902942086975, 7.880355321938219, 8.010617953691213, 8.138795979750322, 8.264986388373549, 8.38927887246574, 8.511756575466665, 8.632496741962894, 8.751571287488895, 8.86904729945669, 8.984987479123163, 9.099450532861862, 9.212491519670454, 9.324162160752033, 9.434511116109832, 9.54358423235212, 9.651424765287247, 9.758073580374356, 9.863569333664158, 9.967948635501692, 10.071246198956713, 10.173494974687904, 10.274726273726227, 10.37496987947435, 10.474254150057657, 10.572606112023658, 10.670051546267244, 10.766615066955817, 10.862320194139004, 10.957189420649806, 11.051244273836318, 11.144505372604026, 11.236992480196827, 11.328724553099525, 11.419719786404569, 11.509995655950528, 11.599568957508723, 11.688455843266894, 11.776671855834312, 11.864231959971114, 11.951150572225254, 12.037441588643329, 12.123118410706052, 12.208193969625484, 12.292680749128728, 12.376590806841762, 12.459935794377113, 12.542726976220125, 12.62497524750049, 12.706691150728426, 12.78788489156827, 12.868566353716332, 12.948745112944344, 13.02843045036508, 13.107631364972086, 13.186356585501548, 13.264614581660489, 13.342413574762254, 13.419761547807026, 13.496666255042394, 13.573135231036344, 13.649175799292792, 13.72479508043745, 13.800000000000004, 13.874797295816617, 13.949193525075206, 14.023195071024293, 14.096808149364879, 14.170038814343457, 14.242892964563064, 14.315376348528183, 14.38749456993816, 14.459253092743072], [0.0, 1.4465476141489433, 2.0457272545478786, 2.5054939632735103, 2.8930952282978866, 3.2345787979271745, 3.5433035433053153, 3.8272052466519226, 4.091454509095757, 4.339642842446829, 4.574385204593073, 4.797655677515843, 5.0109879265470205, 5.215601595214113, 5.412485565800615, 5.6024548190949295, 5.786190456595773, 5.964268605621314, 6.137181763643635, 6.305354867095112, 6.469157595854349, 6.628913938195306, 6.784909726739186, 6.937398647908308, 7.0866070866106305, 7.232738070744717, 7.375974511886549, 7.516481889820531, 7.654410493303845, 7.789897303559272, 7.923067587746555, 8.05403625519528, 8.182909018191515, 8.309783390678726, 8.43474955170573, 8.557891095357547, 8.679285684893658, 8.79900562563748, 8.91711836862111, 9.03368695494813, 9.148770409186145, 9.26242408875776, 9.374699995199848, 9.485647052257425, 9.595311355031686, 9.703736393781522, 9.8109632554607, 9.917030805639357, 10.021975853094041, 10.125833299042604, 10.228636272739394, 10.3304162549241, 10.431203190428226, 10.531025591080862, 10.629910629915946, 10.727884227563234, 10.82497113160123, 10.921194989560439, 11.016578416187127, 11.111143055509636, 11.204909638189859, 11.297898034590329, 11.390127303941778, 11.481615739955767, 11.572380913191546, 11.662439710455098, 11.751808371480536, 11.840502523119532, 11.928537211242627, 12.01592693053682, 12.102685652366587, 12.188826850849921, 12.27436352728727, 12.359308233068711, 12.443673091173684, 12.52746981636755, 12.610709734190223, 12.69340379882402, 12.775562609920554, 12.857196428459824, 12.938315191708698, 13.018928527340492, 13.09904576677248, 13.178675957773603, 13.257827876390612, 13.336510038237142, 13.414730709186825, 13.492497915508455, 13.569819453478372, 13.646702898502628, 13.723155613779216, 13.79918475852831, 13.874797295816617, 13.950000000000003, 14.02479946380696, 14.09920210508382, 14.173214173221261, 14.246841755280364, 14.320090781835148, 14.392967032547531, 14.465476141489434, 14.537623602226057], [0.0, 1.4543039572248988, 2.0566963801203135, 2.518928343562, 2.9086079144497976, 3.2519225083018206, 3.5623026261113755, 3.847726601514198, 4.113392760240627, 4.3629118716746955, 4.598912915026768, 4.823380557244059, 5.037856687124, 5.243567487884561, 5.441507144165116, 5.632495006655576, 5.817215828899595, 5.996248827392006, 6.17008914036094, 6.339163982734633, 6.503845016603641, 6.664457967456919, 6.821290200541244, 6.974596762537604, 7.124605252222751, 7.271519786124494, 7.415524256584966, 7.556785030686, 7.695453203028396, 7.831666489323968, 7.965550828411053, 8.097221745759468, 8.226785520481254, 8.354340189386594, 8.479976415061543, 8.603778239819993, 8.725823743349391, 8.84618561867204, 8.96493167849036, 9.082125301932363, 9.197825830053535, 9.312088917101255, 9.424966843443006, 9.536508795151398, 9.646761114488118, 9.75576752490546, 9.86356933366416, 9.97020561473032, 10.075713374248, 10.180127700574293, 10.283481900601567, 10.385807623868258, 10.487134975769122, 10.587492621012778, 10.686907878334127, 10.78540680734853, 10.883014288330232, 10.97975409560706, 11.075648965184842, 11.170720657146521, 11.264990013311152, 11.358477010585531, 11.451200810395388, 11.543179804542595, 11.63443165779919, 11.724973347517682, 11.81482120050913, 11.903990927415897, 11.992497654784012, 12.080355955020531, 12.16757987440395, 12.254182959300062, 12.34017828072188, 12.425578457359642, 12.510395677195826, 12.59464171781, 12.678327965469267, 12.761465433091924, 12.84406477716459, 12.926136313686316, 13.007690033207282, 13.08873561502409, 13.169282440588782, 13.24933960618415, 13.328915934913837, 13.40801998805193, 13.486660075793417, 13.564844267443693, 13.642580401082489, 13.71987609273495, 13.796738745080303, 13.873175555726238, 13.949193525075207, 14.024799463806964, 14.100000000000001, 14.17480158591294, 14.249210504445502, 14.323232875297395, 14.396874660842192, 14.470141671732177, 14.543039572248988, 14.615573885414152], [0.0, 1.4620191517213443, 2.067607312813533, 2.53229145242012, 2.9240383034426887, 3.2691742076555053, 3.5812009158939966, 3.868139087468288, 4.135214625627066, 4.386057455164033, 4.623310502226732, 4.848968962573384, 5.06458290484024, 5.271385017241673, 5.47037475864314, 5.6623758264530615, 5.848076606885377, 6.028059389223036, 6.202821938440599, 6.372793735874401, 6.5383484153110105, 6.699813430238188, 6.8574776703974765, 7.011597535512147, 7.162401831787993, 7.310095758606723, 7.454864183873506, 7.59687435726036, 7.736278174936576, 7.873214083206426, 8.007808689023483, 8.140178130729081, 8.270429251254132, 8.398660607501652, 8.524963343029693, 8.649421946003097, 8.772114910328066, 8.893115314668982, 9.01249133147988, 9.13030667611992, 9.246621004453464, 9.361490265977954, 9.474967018412254, 9.587100708764874, 9.697937925146768, 9.807522622966514, 9.915896328623045, 10.023098323372867, 10.12916580968048, 10.234134062049412, 10.338036564067666, 10.440905133176912, 10.542770034483347, 10.643660084764075, 10.74360274768199, 10.842624221100719, 10.94074951728628, 11.038002536691137, 11.13440613593738, 11.229982190546874, 11.324751652906123, 11.418734605900953, 11.511950312609935, 11.604417262404864, 11.696153213770755, 11.787175234126282, 11.87749973689749, 11.967142516072915, 12.056118778446072, 12.14444317373176, 12.232129822725067, 12.3191923436563, 12.405643876881198, 12.491497108033126, 12.576764289752749, 12.661457262100598, 12.745587471748802, 12.829165990040039, 12.912203529994407, 12.994710462338128, 13.076696830622021, 13.158172365492101, 13.239146498169736, 13.319628373194199, 13.399626860476376, 13.479150566708572, 13.558207846172001, 13.636806810980346, 13.714955340794953, 13.792661092044565, 13.869931506680196, 13.946773820493396, 14.023195071024293, 14.09920210508382, 14.17480158591294, 14.249999999999998, 14.324803663575986, 14.399218728806089, 14.47325118969473, 14.546906887720153, 14.620191517213446, 14.693110630496188], [0.0, 1.469693845669907, 2.078460969082653, 2.5455844122715714, 2.939387691339814, 3.2863353450309973, 3.6, 3.8884444190447165, 4.156921938165306, 4.40908153700972, 4.6475800154489, 4.874423042781577, 5.091168824543143, 5.299056519796708, 5.499090833947008, 5.692099788303082, 5.878775382679628, 6.059702963017247, 6.235382907247958, 6.406246951218788, 6.572670690061995, 6.734983296193095, 6.893475175845635, 7.0484040746824395, 7.2, 7.3484692283495345, 7.493997598078079, 7.636753236814714, 7.776888838089433, 7.914543574963752, 8.049844718999243, 8.182909018191515, 8.313843876330612, 8.442748367682174, 8.569714114251422, 8.694826047713663, 8.81816307401944, 8.939798655450804, 9.0598013223249, 9.178235124467014, 9.2951600308978, 9.410632284814874, 9.524704719832526, 9.637427042525406, 9.748846085563153, 9.85900603509299, 9.96794863550169, 10.075713374247998, 10.182337649086286, 10.287856919689348, 10.392304845413264, 10.495713410721542, 10.598113039593416, 10.699532700076206, 10.8, 10.89954127475097, 10.998181667894016, 11.095945205344158, 11.19285486370658, 11.288932633336067, 11.384199576606164, 11.478675881825396, 11.572380913191546, 11.665333257134149, 11.757550765359255, 11.849050594878898, 11.939849245279438, 12.029962593458052, 12.119405926034494, 12.208193969625484, 12.296340919151518, 12.383860464330176, 12.470765814495916, 12.55706972187381, 12.642784503423288, 12.727922061357855, 12.812493902437575, 12.896511156122807, 12.979984591670364, 13.062924634246345, 13.14534138012399, 13.227244611029164, 13.308643807691302, 13.389548162652838, 13.46996659238619, 13.549907748763461, 13.62938002992066, 13.708391590555035, 13.78695035169127, 13.865064009949613, 13.942740046346701, 14.019985734657508, 14.096808149364879, 14.173214173221263, 14.249210504445502, 14.324803663575986, 14.4, 14.474805698177786, 14.549226783578568, 14.623269128344731, 14.696938456699069, 14.77024035010941], [0.0, 1.4773286702694157, 2.089258241577618, 2.5588083163847974, 2.9546573405388314, 3.303407331831787, 3.618701424544446, 3.9086442662386154, 4.178516483155236, 4.431986010808247, 4.671723450719232, 4.899744891318323, 5.117616632769595, 5.326584271369412, 5.5276577318064835, 5.721669336828195, 5.909314681077663, 6.0911821512740865, 6.267774724732854, 6.439526380099705, 6.606814663663574, 6.769970457838055, 6.929285677470659, 7.085019407171728, 7.237402849088892, 7.38664335134708, 7.532927717693833, 7.676424949154392, 7.817288532477231, 7.955658363705672, 8.091662375556707, 8.225417922513119, 8.357032966310472, 8.486607095889383, 8.61423240921674, 8.739994279174331, 8.863972021616494, 8.986239480450097, 9.106865541996324, 9.22591458880907, 9.343446901438464, 9.45951901525654, 9.57418403833977, 9.687491935480514, 9.799489782636646, 9.910221995495359, 10.019730535298843, 10.128055094636878, 10.23523326553919, 10.341300691885912, 10.446291207888091, 10.550236964163414, 10.653168542738824, 10.755115062146013, 10.856104273633338, 10.95616264939509, 11.055315463612967, 11.153586867012782, 11.250999955559509, 11.347576833844307, 11.44333867365639, 11.538305768179315, 11.632497582204778, 11.725932798715846, 11.818629362155326, 11.91060451866319, 12.001874853538508, 12.092456326156404, 12.182364302548173, 12.271613585832958, 12.3602184446716, 12.44819263989757, 12.535549449465709, 12.622301691846857, 12.708461747985082, 12.794041581923986, 12.87905276019941, 12.963506470087484, 13.047413536789584, 13.130784439628885, 13.213629327327148, 13.295958032424744, 13.377780084901982, 13.45910472505508, 13.53994091567611, 13.620297353582266, 13.700182480536531, 13.779604493598502, 13.858571354941319, 13.93709080116794, 14.015170352157694, 14.092817319471648, 14.170038814343457, 14.246841755280364, 14.323232875297395, 14.399218728806089, 14.474805698177784, 14.550000000000004, 14.624807691043324, 14.69923467395497, 14.77328670269416, 14.846969387723547], [0.0, 1.4849242404917498, 2.1, 2.571964229922337, 2.9698484809834995, 3.3203915431767985, 3.6373066958946425, 3.9287402561126386, 4.2, 4.454772721475249, 4.695742752749558, 4.924936547814601, 5.143928459844674, 5.353970489272424, 5.556077753235639, 5.751086853804243, 5.939696961966999, 6.1224994895875655, 6.3, 6.472634703117426, 6.640783086353597, 6.804777733328253, 6.96491205974634, 7.121446482281533, 7.274613391789285, 7.4246212024587495, 7.571657678474378, 7.715892689767012, 7.857480512225277, 7.996561761157103, 8.133265027035575, 8.267708267712402, 8.4, 8.53024032486776, 8.658521813797089, 8.784930278607794, 8.909545442950497, 9.03244153039476, 9.153687781435414, 9.27334890964424, 9.391485505499116, 9.508154395044288, 9.623408959407264, 9.737299420270487, 9.849873095629203, 9.961174629530394, 10.071246198956711, 10.18012770057429, 10.287856919689348, 10.39446968344225, 10.5, 10.604480185280183, 10.707940978544848, 10.810411648036352, 10.911920087683928, 11.01249290578659, 11.112155506471279, 11.210932164632876, 11.30884609498246, 11.405919515760226, 11.502173707608486, 11.597629068046624, 11.692305161943045, 11.786220768337916, 11.879393923933998, 11.971841963540948, 12.06358155772986, 12.154628747929737, 12.244998979175131, 12.334707130694266, 12.423767544509195, 12.512194052203634, 12.6, 12.687198272274301, 12.773801313626262, 12.859821149611685, 12.945269406234852, 13.0301573282904, 13.11449579663664, 13.198295344475362, 13.281566172707194, 13.36431816442575, 13.446560898608983, 13.528303663061381, 13.609555466656506, 13.690325050925564, 13.770620901034203, 13.850451256186565, 13.92982411949268, 14.00874726733265, 14.087228258248675, 14.165274441393644, 14.242892964563065, 14.320090781835152, 14.396874660842192, 14.473251189694732, 14.54922678357857, 14.624807691043328, 14.699999999999998, 14.774809643443804, 14.849242404917499, 14.923303923729494], [0.0, 1.49248115565993, 2.1106870919205436, 2.585053190942113, 2.98496231131986, 3.337289319193049, 3.6558172820861827, 3.9487339743264553, 4.221374183841087, 4.47744346697979, 4.719639816765683, 4.950000000000001, 5.170106381884226, 5.38121733439563, 5.584353140695885, 5.780354660399308, 5.96992462263972, 6.153657449029805, 6.33206127576163, 6.505574532660433, 6.674578638386098, 6.839407869106799, 7.000357133746822, 7.157688174264091, 7.3116345641723655, 7.46240577829965, 7.610190536379495, 7.75515957282634, 7.897467948652911, 8.037256994771289, 8.174655956063228, 8.309783390678724, 8.442748367682174, 8.573651497465944, 8.702585822616173, 8.829637591656864, 8.95488693395958, 9.078408450824409, 9.200271735117393, 9.320541829743592, 9.439279633531365, 9.556542261717887, 9.672383367092106, 9.786853426919194, 9.900000000000002, 10.011867957579145, 10.122499691281794, 10.231935300811866, 10.340212763768452, 10.447368089619511, 10.553435459602717, 10.658447354094312, 10.76243466879126, 10.865426820884675, 10.967451846258548, 11.068536488623959, 11.16870628139177, 11.267985622994024, 11.366397846283583, 11.463965282571298, 11.560709320798615, 11.656650462289758, 11.751808371480536, 11.846201922979366, 11.93984924527944, 12.032767761408843, 12.124974226776732, 12.216484764448404, 12.30731489805961, 12.39747958256032, 12.48699323296045, 12.57586975123391, 12.66412255152326, 12.75176458377428, 12.838808355918395, 12.925265954710564, 13.011149065320867, 13.096468989769726, 13.181236664289132, 13.26546267568531, 13.349157276772196, 13.432330400939371, 13.514991675913087, 13.597150436764315, 13.678815738213599, 13.759996366278592, 13.840700849306732, 13.920937468432218, 14.000714267493644, 14.080039062445815, 14.158919450297047, 14.237362817600738, 14.315376348528183, 14.392967032547531, 14.470141671732176, 14.546906887720153, 14.623269128344731, 14.69923467395497, 14.774809643443803, 14.850000000000003, 14.9248115565993, 14.999249981249067], [0.0, 1.5, 2.121320343559643, 2.5980762113533165, 3.0, 3.354101966249685, 3.6742346141747677, 3.968626966596886, 4.242640687119286, 4.5, 4.743416490252569, 4.974937185533101, 5.196152422706633, 5.408326913195984, 5.612486080160912, 5.809475019311125, 6.0, 6.184658438426491, 6.363961030678928, 6.538348415311011, 6.70820393249937, 6.87386354243376, 7.035623639735145, 7.193747284969081, 7.348469228349535, 7.500000000000001, 7.6485292703891785, 7.794228634059949, 7.937253933193772, 8.077747210701757, 8.215838362577493, 8.351646544245034, 8.485281374238571, 8.616843969807045, 8.746427842267952, 8.874119674649425, 9.0, 9.124143795447331, 9.246621004453464, 9.367496997597598, 9.486832980505138, 9.604686356149275, 9.72111104761179, 9.836157786453, 9.949874371066201, 10.062305898749054, 10.173494974687904, 10.283481900601567, 10.392304845413266, 10.500000000000002, 10.606601717798213, 10.712142642814277, 10.816653826391969, 10.92016483392078, 11.022703842524303, 11.124297730643494, 11.224972160321824, 11.324751652906125, 11.423659658795865, 11.521718621802913, 11.61895003862225, 11.715374513859983, 11.811011811017716, 11.905880899790658, 12.0, 12.093386622447824, 12.186057606953941, 12.278029157808675, 12.369316876852983, 12.459935794377113, 12.549900398011134, 12.639224659764539, 12.727922061357855, 12.816005617976298, 12.903487900563942, 12.99038105676658, 13.076696830622023, 13.162446581088185, 13.247641299491773, 13.332291625973385, 13.41640786499874, 13.500000000000002, 13.583077707206126, 13.665650368716449, 13.74772708486752, 13.829316685939334, 13.910427743243558, 13.991068579633223, 14.07124727947029, 14.150971698084907, 14.230249470757707, 14.309088021254185, 14.387494569938163, 14.465476141489436, 14.543039572248988, 14.620191517213446, 14.69693845669907, 14.77328670269416, 14.849242404917497, 14.924811556599302, 15.000000000000002, 15.074813431681338], [0.0, 1.5074813431681338, 2.1319005605327845, 2.611034277829382, 3.0149626863362675, 3.3708307581366355, 3.692560087527352, 3.9884207400925, 4.263801121065569, 4.522444029504401, 4.767074574621212, 4.999749993749688, 5.222068555658764, 5.435301279598032, 5.64047870308895, 5.838450136808569, 6.029925372672535, 6.215504806530199, 6.395701681598354, 6.570958834142854, 6.741661516273271, 6.908147363801674, 7.070714249635607, 7.229626546371536, 7.385120175054704, 7.537406715840668, 7.686676785191376, 7.833102833488146, 7.976841480185, 8.118035476640886, 8.256815366713733, 8.39330090012267, 8.527602242131138, 8.659821014316638, 8.790051194390168, 8.91837989771685, 9.044888059008802, 9.169651029346756, 9.292739101040125, 9.414217970707924, 9.534149149242424, 9.652590325917703, 9.76959569276027, 9.885216234357243, 9.999499987499377, 10.112492274409906, 10.224235912771185, 10.334771405309361, 10.444137111317527, 10.552369402176936, 10.659502802663923, 10.765570119598872, 10.870602559196064, 10.97462983430421, 11.077680262582055, 11.17978085652845, 11.2809574061779, 11.381234555178978, 11.480635870891476, 11.579183909067167, 11.676900273617138, 11.773805671914245, 11.869919966031786, 11.9652622202775, 12.05985074534507, 12.15370313937279, 12.246836326170119, 12.339266590847286, 12.431009613060398, 12.522080498064211, 12.612493805746746, 12.702263577803762, 12.791403363196707, 12.879926242024837, 12.967844847930593, 13.055171389146908, 13.141917668285709, 13.228095100958416, 13.313714733311665, 13.398787258554412, 13.483323032546542, 13.567332088513204, 13.65082415094415, 13.733808648732515, 13.816294727603347, 13.898291261878207, 13.979806865618713, 14.060849903188641, 14.141428499271214, 14.22155054837552, 14.301223723863634, 14.380455486527541, 14.459253092743072, 14.537623602226057, 14.615573885414149, 14.693110630496186, 14.770240350109408, 14.846969387723547, 14.92330392372949, 14.999249981249067, 15.074813431681337, 15.150000000000004]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"A = 2.0\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.2, 0.282842712474619, 0.3464101615137755, 0.4, 0.447213595499958, 0.48989794855663565, 0.5291502622129182, 0.565685424949238, 0.6, 0.6324555320336759, 0.66332495807108, 0.692820323027551, 0.7211102550927979, 0.7483314773547883, 0.7745966692414833, 0.8, 0.8246211251235321, 0.848528137423857, 0.8717797887081349, 0.894427190999916, 0.9165151389911681, 0.938083151964686, 0.959166304662544, 0.9797958971132713, 1.0, 1.019803902718557, 1.0392304845413265, 1.0583005244258363, 1.077032961426901, 1.0954451150103321, 1.1135528725660044, 1.131370849898476, 1.148912529307606, 1.1661903789690602, 1.1832159566199232, 1.2, 1.216552506059644, 1.2328828005937953, 1.2489995996796799, 1.2649110640673518, 1.2806248474865698, 1.2961481396815722, 1.3114877048604001, 1.32664991614216, 1.3416407864998738, 1.3564659966250536, 1.3711309200802089, 1.385640646055102, 1.4000000000000001, 1.4142135623730951, 1.4282856857085702, 1.4422205101855958, 1.4560219778561039, 1.469693845669907, 1.4832396974191326, 1.4966629547095767, 1.50996688705415, 1.5231546211727818, 1.5362291495737217, 1.5491933384829666, 1.5620499351813308, 1.574801574802362, 1.5874507866387544, 1.6, 1.6124515496597098, 1.624807680927192, 1.6370705543744901, 1.6492422502470643, 1.661324772583615, 1.6733200530681511, 1.6852299546352718, 1.697056274847714, 1.7088007490635062, 1.7204650534085253, 1.7320508075688774, 1.7435595774162698, 1.7549928774784245, 1.7663521732655696, 1.7776388834631178, 1.788854381999832, 1.8, 1.8110770276274835, 1.8220867158288598, 1.8330302779823362, 1.8439088914585775, 1.854723699099141, 1.8654758106177631, 1.876166303929372, 1.8867962264113207, 1.8973665961010275, 1.9078784028338913, 1.918332609325088, 1.9287301521985911, 1.9390719429665317, 1.9493588689617927, 1.9595917942265426, 1.9697715603592212, 1.9798989873223332, 1.9899748742132402, 2.0, 2.0099751242241783], [0.0, 0.282842712474619, 0.39999999999999997, 0.48989794855663565, 0.565685424949238, 0.6324555320336759, 0.6928203230275509, 0.7483314773547882, 0.7999999999999999, 0.848528137423857, 0.8944271909999159, 0.938083151964686, 0.9797958971132713, 1.019803902718557, 1.058300524425836, 1.0954451150103321, 1.131370849898476, 1.16619037896906, 1.2, 1.2328828005937953, 1.2649110640673518, 1.2961481396815722, 1.3266499161421599, 1.3564659966250536, 1.3856406460551018, 1.4142135623730951, 1.4422205101855958, 1.469693845669907, 1.4966629547095764, 1.5231546211727818, 1.5491933384829666, 1.5748015748023623, 1.5999999999999999, 1.624807680927192, 1.6492422502470643, 1.6733200530681511, 1.697056274847714, 1.7204650534085253, 1.7435595774162695, 1.7663521732655694, 1.7888543819998317, 1.8110770276274835, 1.8330302779823362, 1.8547236990991405, 1.876166303929372, 1.8973665961010273, 1.9183326093250879, 1.9390719429665315, 1.9595917942265426, 1.979898987322333, 2.0, 2.0199009876724157, 2.039607805437114, 2.0591260281974004, 2.078460969082653, 2.0976176963403033, 2.116601048851672, 2.1354156504062622, 2.1540659228538015, 2.172556098240043, 2.1908902300206643, 2.209072203437452, 2.2271057451320084, 2.244994432064365, 2.262741699796952, 2.2803508501982757, 2.2978250586152114, 2.315167380558045, 2.33238075793812, 2.349468024894146, 2.3664319132398464, 2.3832750575625967, 2.4, 2.4166091947189146, 2.4331050121192876, 2.449489742783178, 2.4657656011875906, 2.4819347291981715, 2.4979991993593593, 2.513961017995307, 2.5298221281347035, 2.545584412271571, 2.5612496949731396, 2.576819745345025, 2.5922962793631443, 2.6076809620810595, 2.6229754097208002, 2.6381811916545836, 2.6532998322843198, 2.6683328128252666, 2.6832815729997477, 2.698147512646408, 2.7129319932501073, 2.727636339397171, 2.7422618401604177, 2.756809750418044, 2.7712812921102037, 2.785677655436824, 2.8, 2.814249455894058, 2.8284271247461903, 2.8425340807103794], [0.0, 0.3464101615137755, 0.48989794855663565, 0.6000000000000002, 0.692820323027551, 0.7745966692414835, 0.8485281374238571, 0.9165151389911681, 0.9797958971132713, 1.0392304845413265, 1.0954451150103324, 1.148912529307606, 1.2000000000000004, 1.2489995996796799, 1.2961481396815722, 1.3416407864998738, 1.385640646055102, 1.4282856857085702, 1.4696938456699071, 1.5099668870541503, 1.549193338482967, 1.5874507866387546, 1.6248076809271923, 1.6613247725836153, 1.6970562748477143, 1.7320508075688776, 1.7663521732655698, 1.8000000000000003, 1.8330302779823362, 1.8654758106177634, 1.8973665961010278, 1.9287301521985913, 1.9595917942265426, 1.9899748742132404, 2.019900987672416, 2.04939015319192, 2.078460969082653, 2.107130750570548, 2.1354156504062627, 2.163330765278394, 2.1908902300206647, 2.2181073012818837, 2.2449944320643653, 2.2715633383201097, 2.297825058615212, 2.32379000772445, 2.3494680248941466, 2.374868417407584, 2.400000000000001, 2.4248711305964283, 2.4494897427831783, 2.473863375370597, 2.4979991993593598, 2.521904042583699, 2.5455844122715714, 2.5690465157330262, 2.5922962793631443, 2.6153393661244047, 2.6381811916545845, 2.6608269391300143, 2.6832815729997477, 2.705549851693737, 2.727636339397171, 2.7495454169735045, 2.771281292110204, 2.7928480087537886, 2.8142494558940583, 2.8354893757515653, 2.8565713714171403, 2.8774989139876324, 2.8982753492378883, 2.918903903865285, 2.9393876913398143, 2.9597297173897488, 2.979932885150268, 3.0000000000000004, 3.0199337741083006, 3.039736830714133, 3.0594117081556718, 3.078960863668131, 3.098386676965934, 3.1176914536239795, 3.136877428271625, 3.1559467676119004, 3.174901573277509, 3.193743884534263, 3.2124756808418025, 3.231098884280703, 3.2496153618543846, 3.2680269276736387, 3.286335345030997, 3.3045423283716615, 3.3226495451672307, 3.340658617698014, 3.3585711247493335, 3.3763886032268267, 3.3941125496954285, 3.411744421846397, 3.4292856398964497, 3.4467375879228177, 3.4641016151377553, 3.481379037105843], [0.0, 0.4, 0.565685424949238, 0.692820323027551, 0.8, 0.894427190999916, 0.9797958971132713, 1.0583005244258363, 1.131370849898476, 1.2, 1.2649110640673518, 1.32664991614216, 1.385640646055102, 1.4422205101855958, 1.4966629547095767, 1.5491933384829666, 1.6, 1.6492422502470643, 1.697056274847714, 1.7435595774162698, 1.788854381999832, 1.8330302779823362, 1.876166303929372, 1.918332609325088, 1.9595917942265426, 2.0, 2.039607805437114, 2.078460969082653, 2.1166010488516727, 2.154065922853802, 2.1908902300206643, 2.227105745132009, 2.262741699796952, 2.297825058615212, 2.3323807579381204, 2.3664319132398464, 2.4, 2.433105012119288, 2.4657656011875906, 2.4979991993593598, 2.5298221281347035, 2.5612496949731396, 2.5922962793631443, 2.6229754097208002, 2.65329983228432, 2.6832815729997477, 2.7129319932501073, 2.7422618401604177, 2.771281292110204, 2.8000000000000003, 2.8284271247461903, 2.8565713714171403, 2.8844410203711917, 2.9120439557122078, 2.939387691339814, 2.9664793948382653, 2.9933259094191533, 3.0199337741083, 3.0463092423455636, 3.0724582991474434, 3.098386676965933, 3.1240998703626617, 3.149603149604724, 3.1749015732775088, 3.2, 3.2249030993194197, 3.249615361854384, 3.2741411087489802, 3.2984845004941286, 3.32264954516723, 3.3466401061363023, 3.3704599092705436, 3.394112549695428, 3.4176014981270124, 3.4409301068170506, 3.464101615137755, 3.4871191548325395, 3.509985754956849, 3.532704346531139, 3.5552777669262356, 3.577708763999664, 3.6, 3.622154055254967, 3.6441734316577197, 3.6660605559646724, 3.687817782917155, 3.709447398198282, 3.7309516212355263, 3.752332607858744, 3.7735924528226414, 3.794733192202055, 3.8157568056677826, 3.836665218650176, 3.8574603043971822, 3.8781438859330635, 3.8987177379235853, 3.9191835884530852, 3.9395431207184424, 3.9597979746446663, 3.9799497484264803, 4.0, 4.019950248448357], [0.0, 0.447213595499958, 0.6324555320336759, 0.7745966692414835, 0.894427190999916, 1.0000000000000002, 1.0954451150103324, 1.1832159566199234, 1.2649110640673518, 1.3416407864998738, 1.4142135623730951, 1.4832396974191329, 1.549193338482967, 1.61245154965971, 1.6733200530681511, 1.7320508075688772, 1.788854381999832, 1.8439088914585775, 1.8973665961010278, 1.9493588689617931, 2.0000000000000004, 2.04939015319192, 2.0976176963403033, 2.144761058952722, 2.1908902300206647, 2.23606797749979, 2.280350850198276, 2.3237900077244507, 2.366431913239847, 2.4083189157584592, 2.4494897427831783, 2.489979919597747, 2.5298221281347035, 2.5690465157330262, 2.60768096208106, 2.6457513110645907, 2.6832815729997477, 2.720294101747089, 2.7568097504180447, 2.7928480087537886, 2.8284271247461903, 2.863564212655271, 2.8982753492378883, 2.932575659723036, 2.9664793948382657, 3.0, 3.0331501776206204, 3.0659419433511785, 3.098386676965934, 3.130495168499706, 3.1622776601683795, 3.193743884534263, 3.22490309931942, 3.255764119219942, 3.286335345030997, 3.3166247903554003, 3.3466401061363023, 3.3763886032268267, 3.405877273185281, 3.4351128074635335, 3.4641016151377544, 3.492849839314596, 3.521363372331802, 3.5496478698597698, 3.577708763999664, 3.605551275463989, 3.6331804249169903, 3.6606010435446255, 3.687817782917155, 3.7148351242013424, 3.7416573867739418, 3.768288736283355, 3.7947331922020555, 3.82099463490856, 3.847076812334269, 3.872983346207417, 3.8987177379235862, 3.924283374069717, 3.9496835316263006, 3.9749213828703587, 4.000000000000001, 4.024922359499622, 4.049691346263318, 4.0743097574926725, 4.09878030638384, 4.123105625617661, 4.147288270665545, 4.171330722922843, 4.1952353926806065, 4.219004621945797, 4.242640687119286, 4.266145801540309, 4.289522117905444, 4.312771730569565, 4.335896677735761, 4.358898943540674, 4.3817804600413295, 4.404543109109049, 4.427188724235731, 4.449719092257398, 4.47213595499958, 4.494441010848847], [0.0, 0.48989794855663565, 0.6928203230275509, 0.8485281374238571, 0.9797958971132713, 1.0954451150103324, 1.2000000000000002, 1.2961481396815722, 1.3856406460551018, 1.469693845669907, 1.5491933384829668, 1.6248076809271923, 1.6970562748477143, 1.7663521732655696, 1.833030277982336, 1.8973665961010275, 1.9595917942265426, 2.0199009876724157, 2.078460969082653, 2.1354156504062627, 2.1908902300206647, 2.244994432064365, 2.297825058615212, 2.349468024894146, 2.4000000000000004, 2.4494897427831783, 2.4979991993593598, 2.5455844122715714, 2.5922962793631443, 2.638181191654584, 2.6832815729997477, 2.727636339397171, 2.7712812921102037, 2.8142494558940583, 2.8565713714171403, 2.898275349237888, 2.939387691339814, 2.979932885150268, 3.0199337741083, 3.0594117081556713, 3.0983866769659336, 3.136877428271625, 3.174901573277509, 3.212475680841802, 3.2496153618543846, 3.2863353450309964, 3.32264954516723, 3.358571124749333, 3.3941125496954285, 3.4292856398964493, 3.464101615137755, 3.498571136907181, 3.532704346531139, 3.5665109000254023, 3.6, 3.6331804249169903, 3.666060555964672, 3.698648401781386, 3.7309516212355263, 3.7629775444453557, 3.794733192202055, 3.8262252939417984, 3.857460304397182, 3.8884444190447165, 3.9191835884530852, 3.9496835316262997, 3.97994974842648, 4.009987531152684, 4.039801975344831, 4.069397989875161, 4.09878030638384, 4.127953488110059, 4.156921938165306, 4.18568990729127, 4.214261501141095, 4.242640687119286, 4.270831300812525, 4.298837052040936, 4.3266615305567875, 4.354308211415448, 4.3817804600413295, 4.409081537009721, 4.436214602563767, 4.463182720884279, 4.48998886412873, 4.5166359162544865, 4.543126676640219, 4.5694638635183455, 4.595650117230424, 4.621688003316537, 4.6475800154489, 4.673328578219169, 4.698936049788292, 4.724404724407087, 4.749736834815168, 4.774934554525329, 4.800000000000001, 4.824935232725928, 4.849742261192857, 4.874423042781577, 4.898979485566357, 4.9234134500364695], [0.0, 0.5291502622129182, 0.7483314773547882, 0.9165151389911681, 1.0583005244258363, 1.1832159566199234, 1.2961481396815722, 1.4000000000000001, 1.4966629547095764, 1.5874507866387544, 1.6733200530681511, 1.7549928774784245, 1.8330302779823362, 1.9078784028338915, 1.9798989873223332, 2.0493901531919194, 2.1166010488516727, 2.181742422927143, 2.244994432064365, 2.3065125189341593, 2.366431913239847, 2.4248711305964283, 2.4819347291981715, 2.5377155080899043, 2.5922962793631443, 2.6457513110645907, 2.6981475126464085, 2.749545416973504, 2.8000000000000003, 2.8495613697550017, 2.8982753492378874, 2.946183972531247, 2.993325909419153, 3.039736830714133, 3.0854497241083028, 3.1304951684997055, 3.1749015732775088, 3.2186953878862163, 3.2619012860600183, 3.3045423283716615, 3.3466401061363023, 3.3882148692194836, 3.4292856398964497, 3.4698703145794942, 3.509985754956849, 3.5496478698597693, 3.5888716889852725, 3.627671429443411, 3.6660605559646724, 3.704051835490427, 3.7416573867739418, 3.7788887255382373, 3.815756805667783, 3.852272056851645, 3.8884444190447165, 3.924283374069717, 3.9597979746446663, 3.994996871087636, 4.029888335921977, 4.064480286580315, 4.098780306383839, 4.132795663954365, 4.166533331199932, 4.2, 4.233202097703345, 4.266145801540308, 4.298837052040936, 4.331281565541543, 4.363484845854286, 4.3954521951671826, 4.427188724235731, 4.458699361921591, 4.48998886412873, 4.521061822182926, 4.551922670696417, 4.58257569495584, 4.613025037868319, 4.64327470649756, 4.67332857821917, 4.703190406521939, 4.732863826479694, 4.762352359916263, 4.791659420284376, 4.82078831727758, 4.849742261192857, 4.878524367060187, 4.907137658554119, 4.935585071701227, 4.963869458396343, 4.991993589739474, 5.019960159204453, 5.047771785649585, 5.075431016179809, 5.10294032886923, 5.130302135352265, 5.15751878329105, 5.184592558726289, 5.2115256883181535, 5.238320341483518, 5.264978632435274, 5.291502622129181, 5.317894320123333], [0.0, 0.565685424949238, 0.7999999999999999, 0.9797958971132713, 1.131370849898476, 1.2649110640673518, 1.3856406460551018, 1.4966629547095764, 1.5999999999999999, 1.697056274847714, 1.7888543819998317, 1.876166303929372, 1.9595917942265426, 2.039607805437114, 2.116601048851672, 2.1908902300206643, 2.262741699796952, 2.33238075793812, 2.4, 2.4657656011875906, 2.5298221281347035, 2.5922962793631443, 2.6532998322843198, 2.7129319932501073, 2.7712812921102037, 2.8284271247461903, 2.8844410203711917, 2.939387691339814, 2.993325909419153, 3.0463092423455636, 3.098386676965933, 3.1496031496047245, 3.1999999999999997, 3.249615361854384, 3.2984845004941286, 3.3466401061363023, 3.394112549695428, 3.4409301068170506, 3.487119154832539, 3.5327043465311387, 3.5777087639996634, 3.622154055254967, 3.6660605559646724, 3.709447398198281, 3.752332607858744, 3.7947331922020546, 3.8366652186501757, 3.878143885933063, 3.9191835884530852, 3.959797974644666, 4.0, 4.039801975344831, 4.079215610874228, 4.118252056394801, 4.156921938165306, 4.1952353926806065, 4.233202097703344, 4.2708313008125245, 4.308131845707603, 4.345112196480086, 4.381780460041329, 4.418144406874904, 4.454211490264017, 4.48998886412873, 4.525483399593904, 4.560701700396551, 4.595650117230423, 4.63033476111609, 4.66476151587624, 4.698936049788292, 4.732863826479693, 4.766550115125193, 4.8, 4.833218389437829, 4.866210024238575, 4.898979485566356, 4.931531202375181, 4.963869458396343, 4.995998398718719, 5.027922035990614, 5.059644256269407, 5.091168824543142, 5.122499389946279, 5.15363949069005, 5.184592558726289, 5.215361924162119, 5.2459508194416005, 5.276362383309167, 5.3065996645686395, 5.336665625650533, 5.366563145999495, 5.396295025292816, 5.4258639865002145, 5.455272678794342, 5.4845236803208355, 5.513619500836088, 5.542562584220407, 5.571355310873648, 5.6, 5.628498911788116, 5.656854249492381, 5.685068161420759], [0.0, 0.6, 0.848528137423857, 1.0392304845413265, 1.2, 1.3416407864998738, 1.469693845669907, 1.5874507866387544, 1.697056274847714, 1.7999999999999998, 1.8973665961010275, 1.98997487421324, 2.078460969082653, 2.1633307652783937, 2.244994432064365, 2.3237900077244498, 2.4, 2.473863375370596, 2.545584412271571, 2.615339366124404, 2.6832815729997477, 2.749545416973504, 2.814249455894058, 2.877498913987632, 2.939387691339814, 3.0, 3.059411708155671, 3.117691453623979, 3.1749015732775088, 3.2310988842807027, 3.2863353450309964, 3.340658617698013, 3.394112549695428, 3.4467375879228173, 3.4985711369071804, 3.5496478698597693, 3.5999999999999996, 3.6496575181789317, 3.698648401781386, 3.746998799039039, 3.794733192202055, 3.8418745424597094, 3.8884444190447165, 3.9344631145812, 3.97994974842648, 4.024922359499621, 4.069397989875161, 4.113392760240626, 4.156921938165306, 4.2, 4.242640687119285, 4.28485705712571, 4.3266615305567875, 4.368065933568311, 4.409081537009721, 4.449719092257398, 4.48998886412873, 4.52990066116245, 4.569463863518345, 4.608687448721165, 4.6475800154488995, 4.686149805543993, 4.724404724407086, 4.762352359916263, 4.8, 4.8373546489791295, 4.874423042781576, 4.91121166312347, 4.947726750741192, 4.983974317750845, 5.019960159204453, 5.0556898639058145, 5.091168824543142, 5.126402247190518, 5.161395160225576, 5.196152422706632, 5.230678732248808, 5.264978632435273, 5.299056519796709, 5.332916650389353, 5.366563145999495, 5.4, 5.43323108288245, 5.466260147486579, 5.499090833947008, 5.531726674375732, 5.5641710972974225, 5.596427431853289, 5.628498911788116, 5.660388679233962, 5.692099788303082, 5.7236352085016735, 5.754997827975264, 5.786190456595773, 5.817215828899595, 5.848076606885377, 5.878775382679628, 5.909314681077663, 5.939696961966999, 5.96992462263972, 6.0, 6.029925372672535], [0.0, 0.6324555320336759, 0.8944271909999159, 1.0954451150103324, 1.2649110640673518, 1.4142135623730951, 1.5491933384829668, 1.6733200530681511, 1.7888543819998317, 1.8973665961010275, 2.0, 2.0976176963403033, 2.1908902300206647, 2.280350850198276, 2.3664319132398464, 2.449489742783178, 2.5298221281347035, 2.6076809620810595, 2.6832815729997477, 2.7568097504180447, 2.8284271247461903, 2.898275349237888, 2.9664793948382653, 3.0331501776206204, 3.0983866769659336, 3.1622776601683795, 3.22490309931942, 3.286335345030997, 3.3466401061363023, 3.4058772731852804, 3.4641016151377544, 3.521363372331802, 3.5777087639996634, 3.6331804249169903, 3.687817782917155, 3.7416573867739413, 3.794733192202055, 3.847076812334269, 3.898717737923586, 3.9496835316263, 4.0, 4.049691346263318, 4.09878030638384, 4.147288270665544, 4.1952353926806065, 4.242640687119285, 4.2895221179054435, 4.33589667773576, 4.3817804600413295, 4.427188724235731, 4.47213595499958, 4.5166359162544865, 4.560701700396552, 4.604345773288536, 4.6475800154489, 4.69041575982343, 4.732863826479693, 4.774934554525329, 4.8166378315169185, 4.857983120596447, 4.898979485566356, 4.9396356140913875, 4.979959839195493, 5.019960159204453, 5.059644256269407, 5.0990195135927845, 5.138093031466052, 5.176871642217914, 5.215361924162119, 5.253570214625479, 5.291502622129181, 5.329165037789691, 5.366563145999495, 5.403702434442518, 5.440588203494177, 5.477225575051661, 5.513619500836089, 5.549774770204643, 5.585696017507577, 5.621387729022079, 5.656854249492381, 5.692099788303083, 5.727128425310542, 5.761944116355173, 5.796550698475776, 5.830951894845301, 5.865151319446072, 5.8991524815010505, 5.932958789676531, 5.966573556070519, 6.0, 6.0332412515993425, 6.066300355241241, 6.099180272790763, 6.131883886702357, 6.164414002968976, 6.196773353931867, 6.228964600958975, 6.260990336999411, 6.29285308902091, 6.324555320336759, 6.356099432828282], [0.0, 0.66332495807108, 0.938083151964686, 1.148912529307606, 1.32664991614216, 1.4832396974191329, 1.6248076809271923, 1.7549928774784245, 1.876166303929372, 1.98997487421324, 2.0976176963403033, 2.2, 2.297825058615212, 2.3916521486202797, 2.4819347291981715, 2.569046515733026, 2.65329983228432, 2.734958866235469, 2.814249455894058, 2.8913664589601926, 2.9664793948382657, 3.039736830714133, 3.1112698372208096, 3.1811947441173736, 3.2496153618543846, 3.3166247903554003, 3.382306905057553, 3.4467375879228177, 3.509985754956849, 3.5721142198983507, 3.63318042491699, 3.693237062523878, 3.752332607858744, 3.8105117766515306, 3.8678159211627436, 3.924283374069717, 3.97994974842648, 4.034848200366404, 4.0890096600521755, 4.1424630354415966, 4.1952353926806065, 4.247352116319061, 4.298837052040936, 4.349712634186309, 4.4, 4.449719092257398, 4.498888751680798, 4.54752680036083, 4.595650117230424, 4.64327470649756, 4.69041575982343, 4.737087712930806, 4.7833042972405595, 4.829078587059855, 4.874423042781577, 4.919349550499538, 4.963869458396343, 5.007993610219566, 5.051732376126036, 5.095095681142799, 5.138093031466052, 5.180733538795447, 5.223025942880239, 5.264978632435274, 5.30659966456864, 5.347896782848375, 5.388877434122993, 5.429548784199292, 5.469917732470938, 5.509990925582365, 5.549774770204644, 5.589275444992849, 5.628498911788116, 5.667450926121902, 5.706137047074843, 5.7445626465380295, 5.782732917920385, 5.8206528843421, 5.858327406350725, 5.895761189193471, 5.9329587896765315, 5.969924622639721, 6.006662967072484, 6.043177971895251, 6.079473661428266, 6.115553940568263, 6.15142259969188, 6.187083319303208, 6.222539674441619, 6.2577951388648065, 6.29285308902091, 6.327716807822551, 6.362389488234747, 6.3968742366877915, 6.431174076325411, 6.465291950097845, 6.499230723708769, 6.532993188424431, 6.566582063752802, 6.600000000000001, 6.6332495807108005, 6.666333324999584], [0.0, 0.692820323027551, 0.9797958971132713, 1.2000000000000004, 1.385640646055102, 1.549193338482967, 1.6970562748477143, 1.8330302779823362, 1.9595917942265426, 2.078460969082653, 2.1908902300206647, 2.297825058615212, 2.400000000000001, 2.4979991993593598, 2.5922962793631443, 2.6832815729997477, 2.771281292110204, 2.8565713714171403, 2.9393876913398143, 3.0199337741083006, 3.098386676965934, 3.174901573277509, 3.2496153618543846, 3.3226495451672307, 3.3941125496954285, 3.4641016151377553, 3.5327043465311396, 3.6000000000000005, 3.6660605559646724, 3.7309516212355267, 3.7947331922020555, 3.8574603043971827, 3.9191835884530852, 3.9799497484264807, 4.039801975344832, 4.09878030638384, 4.156921938165306, 4.214261501141096, 4.270831300812525, 4.326661530556788, 4.3817804600413295, 4.436214602563767, 4.489988864128731, 4.543126676640219, 4.595650117230424, 4.6475800154489, 4.698936049788293, 4.749736834815168, 4.800000000000002, 4.849742261192857, 4.898979485566357, 4.947726750741194, 4.9959983987187195, 5.043808085167398, 5.091168824543143, 5.1380930314660525, 5.184592558726289, 5.230678732248809, 5.276362383309169, 5.321653878260029, 5.366563145999495, 5.411099703387474, 5.455272678794342, 5.499090833947009, 5.542562584220408, 5.585696017507577, 5.628498911788117, 5.670978751503131, 5.713142742834281, 5.754997827975265, 5.796550698475777, 5.83780780773057, 5.8787753826796285, 5.9194594347794975, 5.959865770300536, 6.000000000000001, 6.039867548216601, 6.079473661428266, 6.1188234163113435, 6.157921727336262, 6.196773353931868, 6.235382907247959, 6.27375485654325, 6.311893535223801, 6.349803146555018, 6.387487769068526, 6.424951361683605, 6.462197768561406, 6.499230723708769, 6.536053855347277, 6.572670690061994, 6.609084656743323, 6.645299090334461, 6.681317235396028, 6.717142249498667, 6.752777206453653, 6.788225099390857, 6.823488843692794, 6.8585712797928995, 6.893475175845635, 6.9282032302755105, 6.962758074211686], [0.0, 0.7211102550927979, 1.019803902718557, 1.2489995996796799, 1.4422205101855958, 1.61245154965971, 1.7663521732655696, 1.9078784028338915, 2.039607805437114, 2.1633307652783937, 2.280350850198276, 2.3916521486202797, 2.4979991993593598, 2.6000000000000005, 2.6981475126464085, 2.792848008753788, 2.8844410203711917, 2.973213749463701, 3.0594117081556713, 3.1432467291003428, 3.22490309931942, 3.3045423283716615, 3.3823069050575527, 3.458323293158117, 3.532704346531139, 3.6055512754639896, 3.6769552621700474, 3.7469987990390394, 3.815756805667783, 3.88329756778952, 3.9496835316262997, 4.014971979976947, 4.079215610874228, 4.1424630354415966, 4.204759208325728, 4.266145801540309, 4.3266615305567875, 4.386342439892262, 4.445222154178574, 4.503332099679081, 4.560701700396552, 4.617358552246079, 4.67332857821917, 4.728636167014756, 4.7833042972405595, 4.8373546489791295, 4.890807704254994, 4.94368283772331, 4.9959983987187195, 5.047771785649585, 5.099019513592785, 5.149757275833494, 5.200000000000001, 5.249761899362676, 5.299056519796709, 5.347896782848376, 5.396295025292817, 5.44426303552648, 5.491812087098393, 5.5389529696504916, 5.585696017507576, 5.63205113613149, 5.678027826631356, 5.723635208501674, 5.768882040742383, 5.813776741499453, 5.858327406350725, 5.902541825349482, 5.946427498927402, 5.989991652748776, 6.033241251599343, 6.076183012385325, 6.118823416311343, 6.161168720299745, 6.203224967708329, 6.244997998398398, 6.2864934582006855, 6.327716807822551, 6.3686733312362644, 6.409368143584826, 6.44980619863884, 6.489992295835181, 6.529931086925804, 6.569627082262737, 6.609084656743323, 6.648308055437865, 6.687301398920196, 6.726068688320096, 6.764613810115105, 6.802940540677979, 6.841052550594828, 6.878953408767936, 6.916646586316234, 6.954135460285485, 6.9914233171794145, 7.0285133563222315, 7.065408693062278, 7.102112361825883, 7.138627319029899, 7.17495644586084, 7.211102550927979, 7.247068372797377], [0.0, 0.7483314773547883, 1.058300524425836, 1.2961481396815722, 1.4966629547095767, 1.6733200530681511, 1.833030277982336, 1.9798989873223332, 2.116601048851672, 2.244994432064365, 2.3664319132398464, 2.4819347291981715, 2.5922962793631443, 2.6981475126464085, 2.8, 2.8982753492378874, 2.9933259094191533, 3.0854497241083023, 3.1749015732775088, 3.2619012860600183, 3.3466401061363023, 3.4292856398964493, 3.509985754956849, 3.5888716889852725, 3.666060555964672, 3.7416573867739413, 3.8157568056677826, 3.8884444190447165, 3.9597979746446663, 4.029888335921977, 4.098780306383839, 4.166533331199932, 4.233202097703344, 4.298837052040936, 4.363484845854286, 4.427188724235731, 4.48998886412873, 4.551922670696417, 4.613025037868319, 4.673328578219169, 4.732863826479693, 4.791659420284376, 4.849742261192857, 4.907137658554118, 4.963869458396343, 5.0199601592044525, 5.075431016179809, 5.130302135352264, 5.184592558726289, 5.238320341483518, 5.291502622129181, 5.344155686354956, 5.396295025292817, 5.447935388750495, 5.499090833947008, 5.549774770204643, 5.6, 5.649778756730214, 5.6991227395100035, 5.748043145279965, 5.796550698475775, 5.844655678480983, 5.892367945062493, 5.939696961966999, 5.986651818838307, 6.033241251599342, 6.079473661428265, 6.125357132445422, 6.170899448216605, 6.216108107168021, 6.260990336999411, 6.305553108173778, 6.3498031465550175, 6.393746945258312, 6.437390775772432, 6.48074069840786, 6.523802572120037, 6.566582063752802, 6.609084656743323, 6.6513156593263565, 6.6932802122726045, 6.734983296193095, 6.776429738438967, 6.817624219623724, 6.858571279792899, 6.899275324264136, 6.939740629158989, 6.979971346646059, 7.019971509913698, 7.059745037889116, 7.099295739719539, 7.138627319029899, 7.177743377970545, 7.216647421067487, 7.255342858886822, 7.293833011524187, 7.332121111929344, 7.370210309075312, 7.408103670980854, 7.445804187594514, 7.483314773547883, 7.520638270785267], [0.0, 0.7745966692414833, 1.0954451150103321, 1.3416407864998738, 1.5491933384829666, 1.7320508075688772, 1.8973665961010275, 2.0493901531919194, 2.1908902300206643, 2.3237900077244498, 2.449489742783178, 2.569046515733026, 2.6832815729997477, 2.792848008753788, 2.8982753492378874, 2.9999999999999996, 3.098386676965933, 3.1937438845342623, 3.2863353450309964, 3.3763886032268267, 3.4641016151377544, 3.5496478698597693, 3.63318042491699, 3.714835124201342, 3.794733192202055, 3.8729833462074166, 3.9496835316262997, 4.024922359499621, 4.098780306383839, 4.171330722922842, 4.242640687119285, 4.3127717305695645, 4.381780460041329, 4.449719092257398, 4.516635916254486, 4.58257569495584, 4.6475800154488995, 4.711687595755898, 4.774934554525329, 4.8373546489791295, 4.898979485566356, 4.959838707054898, 5.019960159204453, 5.079370039680117, 5.138093031466052, 5.196152422706631, 5.253570214625478, 5.310367218940701, 5.366563145999495, 5.422176684690383, 5.477225575051661, 5.531726674375732, 5.585696017507576, 5.639148871948674, 5.692099788303082, 5.744562646538029, 5.796550698475775, 5.848076606885378, 5.8991524815010505, 5.949789912257406, 5.999999999999999, 6.049793384901669, 6.099180272790762, 6.148170459575758, 6.196773353931866, 6.244997998398397, 6.292853089020909, 6.340346993658943, 6.387487769068525, 6.434283176858164, 6.48074069840786, 6.526867548832287, 6.572670690061993, 6.618156843109718, 6.663332499583071, 6.7082039324993685, 6.752777206453653, 6.797058187186571, 6.841052550594828, 6.884765791223402, 6.928203230275509, 6.97137002317335, 7.014271166700073, 7.056911505750939, 7.099295739719539, 7.1414284285428495, 7.183313998427188, 7.224956747275377, 7.26636084983398, 7.307530362578043, 7.348469228349534, 7.389181280764466, 7.429670248402684, 7.469939758793239, 7.5099933422074345, 7.549834435270749, 7.58946638440411, 7.628892449104261, 7.668115805072325, 7.707139547199078, 7.745966692414833, 7.784600182411426], [0.0, 0.8, 1.131370849898476, 1.385640646055102, 1.6, 1.788854381999832, 1.9595917942265426, 2.1166010488516727, 2.262741699796952, 2.4, 2.5298221281347035, 2.65329983228432, 2.771281292110204, 2.8844410203711917, 2.9933259094191533, 3.098386676965933, 3.2, 3.2984845004941286, 3.394112549695428, 3.4871191548325395, 3.577708763999664, 3.6660605559646724, 3.752332607858744, 3.836665218650176, 3.9191835884530852, 4.0, 4.079215610874228, 4.156921938165306, 4.233202097703345, 4.308131845707604, 4.381780460041329, 4.454211490264018, 4.525483399593904, 4.595650117230424, 4.664761515876241, 4.732863826479693, 4.8, 4.866210024238576, 4.931531202375181, 4.9959983987187195, 5.059644256269407, 5.122499389946279, 5.184592558726289, 5.2459508194416005, 5.30659966456864, 5.366563145999495, 5.4258639865002145, 5.4845236803208355, 5.542562584220408, 5.6000000000000005, 5.656854249492381, 5.713142742834281, 5.768882040742383, 5.8240879114244155, 5.878775382679628, 5.932958789676531, 5.986651818838307, 6.0398675482166, 6.092618484691127, 6.144916598294887, 6.196773353931866, 6.248199740725323, 6.299206299209448, 6.3498031465550175, 6.4, 6.449806198638839, 6.499230723708768, 6.5482822174979605, 6.596969000988257, 6.64529909033446, 6.6932802122726045, 6.740919818541087, 6.788225099390856, 6.835202996254025, 6.881860213634101, 6.92820323027551, 6.974238309665079, 7.019971509913698, 7.065408693062278, 7.110555533852471, 7.155417527999328, 7.2, 7.244308110509934, 7.288346863315439, 7.332121111929345, 7.37563556583431, 7.418894796396564, 7.4619032424710525, 7.504665215717488, 7.547184905645283, 7.58946638440411, 7.631513611335565, 7.673330437300352, 7.7149206087943645, 7.756287771866127, 7.797435475847171, 7.8383671769061705, 7.879086241436885, 7.919595949289333, 7.959899496852961, 8.0, 8.039900496896713], [0.0, 0.8246211251235321, 1.16619037896906, 1.4282856857085702, 1.6492422502470643, 1.8439088914585775, 2.0199009876724157, 2.181742422927143, 2.33238075793812, 2.473863375370596, 2.6076809620810595, 2.734958866235469, 2.8565713714171403, 2.973213749463701, 3.0854497241083023, 3.1937438845342623, 3.2984845004941286, 3.4, 3.4985711369071804, 3.594440151122286, 3.687817782917155, 3.778888725538237, 3.867815921162743, 3.954743986657038, 4.039801975344831, 4.123105625617661, 4.204759208325728, 4.28485705712571, 4.363484845854286, 4.440720662234904, 4.516635916254486, 4.591296113299599, 4.66476151587624, 4.737087712930805, 4.8083261120685235, 4.878524367060187, 4.947726750741192, 5.015974481593781, 5.083306010855534, 5.149757275833494, 5.215361924162119, 5.280151512977635, 5.344155686354956, 5.407402333838309, 5.469917732470938, 5.531726674375732, 5.592852581643825, 5.653317610041028, 5.713142742834281, 5.772347875864725, 5.830951894845301, 5.888972745734184, 5.946427498927402, 6.003332407921454, 6.059702963017247, 6.115553940568263, 6.170899448216605, 6.2257529665093525, 6.280127387243033, 6.334035048845246, 6.387487769068525, 6.440496875241847, 6.49307323229917, 6.545227268781429, 6.596969000988257, 6.648308055437864, 6.699253689777691, 6.749814812274482, 6.8, 6.849817515817484, 6.899275324264137, 6.948381106416083, 6.997142273814361, 7.045565981523414, 7.093659140387279, 7.14142842854285, 7.188880302244572, 7.236021006050217, 7.282856582413251, 7.329392880723478, 7.37563556583431, 7.42159012611179, 7.467261881037788, 7.512655988397179, 7.557777451076474, 7.602631123499285, 7.647221717722065, 7.691553809211764, 7.735631842325486, 7.779460135510689, 7.8230428862431785, 7.866384175718855, 7.909487973314076, 7.952358140828418, 7.994998436522675, 8.037412518964047, 8.079603950689663, 8.121576201698781, 8.16333265278342, 8.204876598706406, 8.246211251235321, 8.287339742040265], [0.0, 0.848528137423857, 1.2, 1.4696938456699071, 1.697056274847714, 1.8973665961010278, 2.078460969082653, 2.244994432064365, 2.4, 2.545584412271571, 2.6832815729997477, 2.814249455894058, 2.9393876913398143, 3.0594117081556713, 3.1749015732775088, 3.2863353450309964, 3.394112549695428, 3.4985711369071804, 3.6, 3.6986484017813863, 3.7947331922020555, 3.8884444190447165, 3.97994974842648, 4.069397989875161, 4.156921938165306, 4.242640687119286, 4.3266615305567875, 4.409081537009721, 4.48998886412873, 4.5694638635183455, 4.6475800154489, 4.724404724407087, 4.8, 4.874423042781577, 4.947726750741193, 5.019960159204453, 5.091168824543142, 5.1613951602255765, 5.230678732248808, 5.299056519796709, 5.366563145999495, 5.43323108288245, 5.499090833947008, 5.564171097297422, 5.628498911788116, 5.692099788303082, 5.754997827975264, 5.817215828899595, 5.8787753826796285, 5.939696961966999, 6.0, 6.059702963017248, 6.118823416311343, 6.177378084592201, 6.235382907247959, 6.29285308902091, 6.3498031465550175, 6.406246951218787, 6.462197768561405, 6.517668294720129, 6.572670690061993, 6.627216610312357, 6.681317235396026, 6.734983296193095, 6.788225099390856, 6.841052550594828, 6.8934751758456345, 6.945502141674135, 6.997142273814361, 7.048404074682439, 7.0992957397195395, 7.149825172687791, 7.2, 7.249827584156743, 7.299315036357863, 7.3484692283495345, 7.397296803562773, 7.445804187594514, 7.493997598078079, 7.541883053985921, 7.589466384404111, 7.636753236814713, 7.68374908491942, 7.730459236035075, 7.776888838089433, 7.823042886243179, 7.868926229162401, 7.914543574963752, 7.95989949685296, 8.0049984384758, 8.049844718999243, 8.094442537939225, 8.138795979750322, 8.182909018191515, 8.226785520481254, 8.270429251254132, 8.313843876330612, 8.357032966310472, 8.4, 8.442748367682174, 8.485281374238571, 8.527602242131138], [0.0, 0.8717797887081349, 1.2328828005937953, 1.5099668870541503, 1.7435595774162698, 1.9493588689617931, 2.1354156504062627, 2.3065125189341593, 2.4657656011875906, 2.615339366124404, 2.7568097504180447, 2.8913664589601926, 3.0199337741083006, 3.1432467291003428, 3.2619012860600183, 3.3763886032268267, 3.4871191548325395, 3.594440151122286, 3.6986484017813863, 3.8000000000000007, 3.8987177379235862, 3.9949968710876362, 4.0890096600521755, 4.180908992073375, 4.270831300812525, 4.358898943540674, 4.445222154178575, 4.529900661162451, 4.613025037868319, 4.694677837722201, 4.774934554525329, 4.8538644398046396, 4.931531202375181, 5.007993610219566, 5.083306010855535, 5.157518783291051, 5.230678732248808, 5.302829433425142, 5.374011537017762, 5.444263035526481, 5.513619500836089, 5.582114294781146, 5.649778756730215, 5.716642371182581, 5.782732917920385, 5.848076606885378, 5.912698199637794, 5.976621118993575, 6.039867548216601, 6.102458520956944, 6.164414002968978, 6.225752966509353, 6.2864934582006855, 6.3466526610489735, 6.406246951218788, 6.465291950097846, 6.523802572120037, 6.581793068761734, 6.639277069079134, 6.696267617113283, 6.752777206453653, 6.808817812219681, 6.864400920692206, 6.919537556802479, 6.974238309665079, 7.0285133563222315, 7.08237248385031, 7.13582510996451, 7.188880302244572, 7.2415467960926705, 7.293833011524189, 7.345747068882784, 7.397296803562773, 7.448489779814429, 7.49933330370107, 7.549834435270751, 7.600000000000001, 7.649836599562112, 7.6993506219680645, 7.748548251124208, 7.7974354758471724, 7.8460180983732135, 7.894301742396222, 7.942291860665913, 7.9899937421752725, 8.037412518964048, 8.084553172563096, 8.13142054010245, 8.178019320104351, 8.224354077980836, 8.270429251254134, 8.316249154516717, 8.36181798414675, 8.407139822793482, 8.452218643646177, 8.497058314499201, 8.54166260162505, 8.586035173466273, 8.630179604156568, 8.674099376880578, 8.717797887081348, 8.761278445523805], [0.0, 0.894427190999916, 1.2649110640673518, 1.549193338482967, 1.788854381999832, 2.0000000000000004, 2.1908902300206647, 2.366431913239847, 2.5298221281347035, 2.6832815729997477, 2.8284271247461903, 2.9664793948382657, 3.098386676965934, 3.22490309931942, 3.3466401061363023, 3.4641016151377544, 3.577708763999664, 3.687817782917155, 3.7947331922020555, 3.8987177379235862, 4.000000000000001, 4.09878030638384, 4.1952353926806065, 4.289522117905444, 4.3817804600413295, 4.47213595499958, 4.560701700396552, 4.647580015448901, 4.732863826479694, 4.8166378315169185, 4.898979485566357, 4.979959839195494, 5.059644256269407, 5.1380930314660525, 5.21536192416212, 5.291502622129181, 5.366563145999495, 5.440588203494178, 5.513619500836089, 5.585696017507577, 5.656854249492381, 5.727128425310542, 5.796550698475777, 5.865151319446072, 5.9329587896765315, 6.0, 6.066300355241241, 6.131883886702357, 6.196773353931868, 6.260990336999412, 6.324555320336759, 6.387487769068526, 6.44980619863884, 6.511528238439884, 6.572670690061994, 6.6332495807108005, 6.6932802122726045, 6.752777206453653, 6.811754546370562, 6.870225614927067, 6.928203230275509, 6.985699678629192, 7.042726744663604, 7.0992957397195395, 7.155417527999328, 7.211102550927978, 7.266360849833981, 7.321202087089251, 7.37563556583431, 7.429670248402685, 7.4833147735478835, 7.53657747256671, 7.589466384404111, 7.64198926981712, 7.694153624668538, 7.745966692414834, 7.7974354758471724, 7.848566748139434, 7.899367063252601, 7.949842765740717, 8.000000000000002, 8.049844718999244, 8.099382692526635, 8.148619514985345, 8.19756061276768, 8.246211251235321, 8.29457654133109, 8.342661445845685, 8.390470785361213, 8.438009243891594, 8.485281374238571, 8.532291603080617, 8.579044235810889, 8.62554346113913, 8.671793355471522, 8.717797887081348, 8.763560920082659, 8.809086218218098, 8.854377448471462, 8.899438184514796, 8.94427190999916, 8.988882021697695], [0.0, 0.9165151389911681, 1.2961481396815722, 1.5874507866387546, 1.8330302779823362, 2.04939015319192, 2.244994432064365, 2.4248711305964283, 2.5922962793631443, 2.749545416973504, 2.898275349237888, 3.039736830714133, 3.174901573277509, 3.3045423283716615, 3.4292856398964493, 3.5496478698597693, 3.6660605559646724, 3.778888725538237, 3.8884444190447165, 3.9949968710876362, 4.09878030638384, 4.2, 4.298837052040936, 4.3954521951671826, 4.48998886412873, 4.582575694955841, 4.67332857821917, 4.762352359916264, 4.849742261192857, 4.935585071701227, 5.019960159204453, 5.10294032886923, 5.184592558726289, 5.264978632435274, 5.344155686354956, 5.422176684690384, 5.499090833947008, 5.574943945906542, 5.649778756730214, 5.723635208501674, 5.796550698475776, 5.868560300448484, 5.939696961967, 6.009991680526688, 6.079473661428266, 6.148170459575759, 6.216108107168022, 6.2833112289620034, 6.349803146555018, 6.4156059729381765, 6.480740698407861, 6.54522726878143, 6.609084656743323, 6.672330927044912, 6.7349832961930955, 6.797058187186572, 6.858571279792899, 6.919537556802478, 6.97997134664606, 7.0398863627192165, 7.099295739719539, 7.158212067269313, 7.216647421067486, 7.274613391789285, 7.332121111929345, 7.389181280764467, 7.445804187594514, 7.501999733404421, 7.557777451076474, 7.6131465242697125, 7.668115805072326, 7.72269383052313, 7.776888838089433, 7.830708780180758, 7.884161337770809, 7.937253933193772, 7.9899937421752725, 8.04238770515324, 8.094442537939226, 8.14616474176652, 8.19756061276768, 8.248636250920512, 8.299397568498573, 8.349850298059241, 8.4, 8.449852069711044, 8.499411744350311, 8.548684109265006, 8.597674104081872, 8.646386528486914, 8.694826047713663, 8.742997197757758, 8.790904390334365, 8.838551917593742, 8.885943956609225, 8.933084573650918, 8.97997772825746, 9.026627277117408, 9.073036977771006, 9.119210492142399, 9.165151389911681, 9.210863151735564], [0.0, 0.938083151964686, 1.3266499161421599, 1.6248076809271923, 1.876166303929372, 2.0976176963403033, 2.297825058615212, 2.4819347291981715, 2.6532998322843198, 2.814249455894058, 2.9664793948382653, 3.1112698372208096, 3.2496153618543846, 3.3823069050575527, 3.509985754956849, 3.63318042491699, 3.752332607858744, 3.867815921162743, 3.97994974842648, 4.0890096600521755, 4.1952353926806065, 4.298837052040936, 4.4, 4.498888751680798, 4.595650117230424, 4.69041575982343, 4.7833042972405595, 4.874423042781577, 4.963869458396343, 5.0517323761260355, 5.138093031466052, 5.223025942880239, 5.3065996645686395, 5.388877434122993, 5.469917732470938, 5.549774770204643, 5.628498911788116, 5.706137047074843, 5.782732917920384, 5.858327406350725, 5.932958789676531, 6.006662967072483, 6.079473661428266, 6.151422599691879, 6.222539674441619, 6.292853089020909, 6.362389488234747, 6.431174076325411, 6.499230723708769, 6.566582063752802, 6.6332495807108005, 6.6992536897776915, 6.764613810115105, 6.82934843158555, 6.8934751758456345, 6.957010852370435, 7.019971509913698, 7.0823724838503095, 7.144228439796701, 7.205553413860728, 7.26636084983398, 7.326663633605681, 7.386474125047755, 7.445804187594514, 7.504665215717488, 7.5630681604756145, 7.62102355330306, 7.678541528180987, 7.735631842325486, 7.792303895511263, 7.848566748139434, 7.904429138147802, 7.95989949685296, 8.014985963805552, 8.069696400732806, 8.12403840463596, 8.178019320104351, 8.231646250902672, 8.284926070883193, 8.337865434270332, 8.390470785361213, 8.442748367682174, 8.494704232638123, 8.546344247688598, 8.597674104081872, 8.648699324175862, 8.699425268372618, 8.749857141690944, 8.8, 8.849858755935035, 8.899438184514796, 8.948742928478838, 8.997777503361595, 9.046546302318914, 9.09505360072166, 9.143303560529969, 9.191300234460847, 9.23904756996088, 9.28654941299512, 9.333809511662428, 9.38083151964686, 9.427618999514142], [0.0, 0.959166304662544, 1.3564659966250536, 1.6613247725836153, 1.918332609325088, 2.144761058952722, 2.349468024894146, 2.5377155080899043, 2.7129319932501073, 2.877498913987632, 3.0331501776206204, 3.1811947441173736, 3.3226495451672307, 3.458323293158117, 3.5888716889852725, 3.714835124201342, 3.836665218650176, 3.954743986657038, 4.069397989875161, 4.180908992073375, 4.289522117905444, 4.3954521951671826, 4.498888751680798, 4.6000000000000005, 4.698936049788292, 4.79583152331272, 4.8908077042549944, 4.983974317750846, 5.075431016179809, 5.165268628057984, 5.253570214625479, 5.340411969127476, 5.4258639865002145, 5.509990925582366, 5.592852581643825, 5.674504383644443, 5.754997827975264, 5.83438085832593, 5.912698199637794, 5.989991652748776, 6.066300355241241, 6.1416610131136355, 6.216108107168022, 6.289674077406555, 6.362389488234747, 6.434283176858165, 6.505382386916238, 6.575712889109439, 6.645299090334461, 6.714164132637808, 6.782329983125269, 6.8498175158174845, 6.916646586316234, 6.982836100038438, 7.0484040746824395, 7.113367697511497, 7.177743377970545, 7.24154679609267, 7.3047929470998705, 7.367496182557545, 7.429670248402684, 7.491328320131218, 7.552483035399683, 7.6131465242697125, 7.673330437300352, 7.733045971672482, 7.792303895511263, 7.851114570556209, 7.909487973314076, 7.967433714816837, 8.024961059095553, 8.082078940470701, 8.138795979750322, 8.195120499419152, 8.251060537894508, 8.306623862918075, 8.36181798414675, 8.416650165000327, 8.47112743381895, 8.525256594378847, 8.579044235810889, 8.632496741962896, 8.685620300243388, 8.738420909981391, 8.790904390334365, 8.843076387773658, 8.894942383174834, 8.946507698538017, 8.997777503361595, 9.048756820690896, 9.099450532861862, 9.1498633869583, 9.200000000000001, 9.249864863877743, 9.299462350050137, 9.348796714016196, 9.397872099576585, 9.446692542895637, 9.495261976375376, 9.54358423235212, 9.59166304662544, 9.639502061828715], [0.0, 0.9797958971132713, 1.3856406460551018, 1.6970562748477143, 1.9595917942265426, 2.1908902300206647, 2.4000000000000004, 2.5922962793631443, 2.7712812921102037, 2.939387691339814, 3.0983866769659336, 3.2496153618543846, 3.3941125496954285, 3.532704346531139, 3.666060555964672, 3.794733192202055, 3.9191835884530852, 4.039801975344831, 4.156921938165306, 4.270831300812525, 4.3817804600413295, 4.48998886412873, 4.595650117230424, 4.698936049788292, 4.800000000000001, 4.898979485566357, 4.9959983987187195, 5.091168824543143, 5.184592558726289, 5.276362383309168, 5.366563145999495, 5.455272678794342, 5.542562584220407, 5.628498911788117, 5.713142742834281, 5.796550698475776, 5.878775382679628, 5.959865770300536, 6.0398675482166, 6.118823416311343, 6.196773353931867, 6.27375485654325, 6.349803146555018, 6.424951361683604, 6.499230723708769, 6.572670690061993, 6.64529909033446, 6.717142249498666, 6.788225099390857, 6.858571279792899, 6.92820323027551, 6.997142273814362, 7.065408693062278, 7.1330218000508046, 7.2, 7.266360849833981, 7.332121111929344, 7.397296803562772, 7.4619032424710525, 7.525955088890711, 7.58946638440411, 7.652450587883597, 7.714920608794364, 7.776888838089433, 7.8383671769061705, 7.899367063252599, 7.95989949685296, 8.019975062305368, 8.079603950689663, 8.138795979750322, 8.19756061276768, 8.255906976220118, 8.313843876330612, 8.37137981458254, 8.42852300228219, 8.485281374238571, 8.54166260162505, 8.597674104081872, 8.653323061113575, 8.708616422830897, 8.763560920082659, 8.818163074019441, 8.872429205127535, 8.926365441768558, 8.97997772825746, 9.033271832508973, 9.086253353280439, 9.138927727036691, 9.191300234460847, 9.243376006633074, 9.2951600308978, 9.346657156438338, 9.397872099576585, 9.448809448814174, 9.499473669630335, 9.549869109050658, 9.600000000000001, 9.649870465451857, 9.699484522385713, 9.748846085563153, 9.797958971132713, 9.846826900072939], [0.0, 1.0, 1.4142135623730951, 1.7320508075688776, 2.0, 2.23606797749979, 2.4494897427831783, 2.6457513110645907, 2.8284271247461903, 3.0, 3.1622776601683795, 3.3166247903554003, 3.4641016151377553, 3.6055512754639896, 3.7416573867739413, 3.8729833462074166, 4.0, 4.123105625617661, 4.242640687119286, 4.358898943540674, 4.47213595499958, 4.582575694955841, 4.69041575982343, 4.79583152331272, 4.898979485566357, 5.000000000000001, 5.099019513592785, 5.196152422706633, 5.291502622129181, 5.385164807134505, 5.477225575051661, 5.567764362830022, 5.656854249492381, 5.7445626465380295, 5.830951894845301, 5.916079783099616, 6.0, 6.08276253029822, 6.164414002968977, 6.244997998398399, 6.324555320336759, 6.403124237432849, 6.480740698407861, 6.557438524302, 6.6332495807108005, 6.7082039324993685, 6.782329983125269, 6.855654600401045, 6.9282032302755105, 7.0, 7.071067811865476, 7.141428428542851, 7.211102550927979, 7.28010988928052, 7.348469228349535, 7.416198487095664, 7.483314773547883, 7.54983443527075, 7.6157731058639095, 7.681145747868608, 7.745966692414833, 7.810249675906655, 7.874007874011811, 7.937253933193772, 8.0, 8.06225774829855, 8.12403840463596, 8.18535277187245, 8.246211251235321, 8.306623862918075, 8.366600265340756, 8.426149773176359, 8.485281374238571, 8.544003745317532, 8.602325267042627, 8.660254037844387, 8.717797887081348, 8.774964387392123, 8.831760866327848, 8.88819441731559, 8.94427190999916, 9.000000000000002, 9.055385138137417, 9.1104335791443, 9.165151389911681, 9.219544457292889, 9.273618495495704, 9.327379053088816, 9.38083151964686, 9.433981132056603, 9.486832980505138, 9.539392014169458, 9.59166304662544, 9.643650760992957, 9.695359714832659, 9.746794344808963, 9.797958971132713, 9.848857801796106, 9.899494936611665, 9.949874371066201, 10.000000000000002, 10.049875621120892], [0.0, 1.019803902718557, 1.4422205101855958, 1.7663521732655698, 2.039607805437114, 2.280350850198276, 2.4979991993593598, 2.6981475126464085, 2.8844410203711917, 3.059411708155671, 3.22490309931942, 3.382306905057553, 3.5327043465311396, 3.6769552621700474, 3.8157568056677826, 3.9496835316262997, 4.079215610874228, 4.204759208325728, 4.3266615305567875, 4.445222154178575, 4.560701700396552, 4.67332857821917, 4.7833042972405595, 4.8908077042549944, 4.9959983987187195, 5.099019513592785, 5.200000000000001, 5.299056519796709, 5.396295025292817, 5.491812087098393, 5.585696017507576, 5.678027826631356, 5.768882040742383, 5.858327406350725, 5.946427498927402, 6.0332412515993425, 6.118823416311342, 6.20322496770833, 6.2864934582006855, 6.3686733312362644, 6.44980619863884, 6.529931086925804, 6.609084656743324, 6.687301398920195, 6.764613810115106, 6.841052550594828, 6.916646586316234, 6.9914233171794145, 7.065408693062279, 7.138627319029899, 7.211102550927979, 7.282856582413251, 7.353910524340095, 7.424284477308236, 7.493997598078079, 7.563068160475615, 7.631513611335565, 7.699350621968064, 7.766595135579041, 7.833262411026456, 7.899367063252599, 7.964923100695951, 8.029943959953892, 8.094442537939226, 8.158431221748456, 8.221921916437786, 8.284926070883191, 8.347454701883683, 8.409518416651457, 8.47112743381895, 8.532291603080617, 8.593020423576334, 8.653323061113575, 8.713208364316786, 8.772684879784524, 8.831760866327848, 8.89044430835715, 8.948742928478838, 9.006664199358164, 9.064215354899728, 9.121403400793104, 9.178235124467014, 9.234717104492159, 9.290855719469548, 9.34665715643834, 9.402127418834528, 9.457272334029513, 9.512097560475294, 9.566608594481119, 9.620810776644555, 9.67470929795826, 9.728309205612248, 9.781615408509989, 9.834632682515398, 9.887365675446622, 9.939818911831342, 9.991996797437439, 10.043903623591778, 10.09554357129917, 10.146920715172659, 10.19803902718557, 10.248902380255167], [0.0, 1.0392304845413265, 1.469693845669907, 1.8000000000000003, 2.078460969082653, 2.3237900077244507, 2.5455844122715714, 2.749545416973504, 2.939387691339814, 3.117691453623979, 3.286335345030997, 3.4467375879228177, 3.6000000000000005, 3.7469987990390394, 3.8884444190447165, 4.024922359499621, 4.156921938165306, 4.28485705712571, 4.409081537009721, 4.529900661162451, 4.647580015448901, 4.762352359916264, 4.874423042781577, 4.983974317750846, 5.091168824543143, 5.196152422706633, 5.299056519796709, 5.4, 5.499090833947008, 5.596427431853289, 5.692099788303083, 5.786190456595773, 5.878775382679628, 5.969924622639721, 6.059702963017247, 6.148170459575759, 6.235382907247958, 6.321392251711644, 6.406246951218788, 6.489992295835182, 6.572670690061994, 6.654321903845651, 6.7349832961930955, 6.814690014960328, 6.893475175845635, 6.971370023173351, 7.0484040746824395, 7.124605252222751, 7.200000000000001, 7.274613391789285, 7.348469228349535, 7.4215901261117905, 7.493997598078079, 7.565712127751096, 7.636753236814714, 7.707139547199078, 7.776888838089433, 7.846018098373213, 7.914543574963752, 7.982480817390043, 8.049844718999243, 8.11664955508121, 8.182909018191513, 8.248636250920512, 8.313843876330612, 8.378544026261364, 8.442748367682174, 8.506468127254696, 8.56971411425142, 8.632496741962896, 8.694826047713665, 8.756711711595855, 8.818163074019441, 8.879189152169246, 8.939798655450804, 9.0, 9.059801322324901, 9.119210492142399, 9.178235124467015, 9.236882591004392, 9.295160030897803, 9.353074360871938, 9.410632284814875, 9.4678403028357, 9.524704719832528, 9.581231653602789, 9.637427042525408, 9.693296652842108, 9.748846085563153, 9.804080783020915, 9.85900603509299, 9.913626985114984, 9.967948635501692, 10.021975853094041, 10.075713374248, 10.12916580968048, 10.182337649086286, 10.23523326553919, 10.287856919689348, 10.340212763768452, 10.392304845413266, 10.444137111317527], [0.0, 1.0583005244258363, 1.4966629547095764, 1.8330302779823362, 2.1166010488516727, 2.366431913239847, 2.5922962793631443, 2.8000000000000003, 2.993325909419153, 3.1749015732775088, 3.3466401061363023, 3.509985754956849, 3.6660605559646724, 3.815756805667783, 3.9597979746446663, 4.098780306383839, 4.233202097703345, 4.363484845854286, 4.48998886412873, 4.613025037868319, 4.732863826479694, 4.849742261192857, 4.963869458396343, 5.075431016179809, 5.184592558726289, 5.291502622129181, 5.396295025292817, 5.499090833947008, 5.6000000000000005, 5.6991227395100035, 5.796550698475775, 5.892367945062494, 5.986651818838306, 6.079473661428266, 6.1708994482166055, 6.260990336999411, 6.3498031465550175, 6.437390775772433, 6.523802572120037, 6.609084656743323, 6.6932802122726045, 6.776429738438967, 6.8585712797928995, 6.9397406291589885, 7.019971509913698, 7.099295739719539, 7.177743377970545, 7.255342858886822, 7.332121111929345, 7.408103670980854, 7.4833147735478835, 7.557777451076475, 7.631513611335566, 7.70454411370329, 7.776888838089433, 7.848566748139434, 7.919595949289333, 7.989993742175272, 8.059776671843954, 8.12896057316063, 8.197560612767678, 8.26559132790873, 8.333066662399863, 8.4, 8.46640419540669, 8.532291603080616, 8.597674104081872, 8.662563131083086, 8.726969691708572, 8.790904390334365, 8.854377448471462, 8.917398723843181, 8.97997772825746, 9.042123644365851, 9.103845341392834, 9.16515138991168, 9.226050075736637, 9.28654941299512, 9.34665715643834, 9.406380813043878, 9.465727652959387, 9.524704719832526, 9.583318840568753, 9.64157663455516, 9.699484522385713, 9.757048734120374, 9.814275317108239, 9.871170143402454, 9.927738916792686, 9.983987179478948, 10.039920318408907, 10.09554357129917, 10.150862032359617, 10.20588065773846, 10.26060427070453, 10.3150375665821, 10.369185117452577, 10.423051376636307, 10.476640682967036, 10.529957264870548, 10.583005244258363, 10.635788640246666], [0.0, 1.077032961426901, 1.5231546211727818, 1.8654758106177634, 2.154065922853802, 2.4083189157584592, 2.638181191654584, 2.8495613697550017, 3.0463092423455636, 3.2310988842807027, 3.4058772731852804, 3.5721142198983507, 3.7309516212355267, 3.88329756778952, 4.029888335921977, 4.171330722922842, 4.308131845707604, 4.440720662234904, 4.5694638635183455, 4.694677837722201, 4.8166378315169185, 4.935585071701227, 5.0517323761260355, 5.165268628057984, 5.276362383309168, 5.385164807134505, 5.491812087098393, 5.596427431853289, 5.6991227395100035, 5.800000000000001, 5.8991524815010505, 5.99666574022598, 6.092618484691127, 6.187083319303209, 6.280127387243033, 6.371812928829597, 6.462197768561405, 6.551335741663681, 6.639277069079133, 6.726068688320096, 6.811754546370561, 6.896375859826668, 6.97997134664606, 7.06257743320383, 7.144228439796701, 7.224956747275377, 7.3047929470998705, 7.383765976789894, 7.461903242471053, 7.539230729988306, 7.6157731058639095, 7.691553809211766, 7.76659513557904, 7.840918313565065, 7.914543574963752, 7.987490219086344, 8.059776671843954, 8.131420540102448, 8.202438661763953, 8.272847151978574, 8.342661445845684, 8.411896337925237, 8.480566018845677, 8.548684109265006, 8.616263691415208, 8.683317338436964, 8.749857141690944, 8.815894736213677, 8.881441324469808, 8.946507698538017, 9.01110426085505, 9.075241043630742, 9.138927727036691, 9.202173656261873, 9.264987857520376, 9.327379053088816, 9.389355675444403, 9.450925880568528, 9.512097560475294, 9.572878355019457, 9.633275663033837, 9.693296652842108, 9.752948272189288, 9.812237257628864, 9.871170143402454, 9.92975326984513, 9.987992791347018, 10.045894683899489, 10.103464752252071, 10.160708636704431, 10.21763181955584, 10.274239631233058, 10.330537256115967, 10.386529738079028, 10.442221985765292, 10.497618777608567, 10.552724766618336, 10.607544484940897, 10.662082348209472, 10.716342659695053, 10.77032961426901, 10.824047302187848], [0.0, 1.0954451150103321, 1.5491933384829666, 1.8973665961010278, 2.1908902300206643, 2.4494897427831783, 2.6832815729997477, 2.8982753492378874, 3.098386676965933, 3.2863353450309964, 3.4641016151377544, 3.63318042491699, 3.7947331922020555, 3.9496835316262997, 4.098780306383839, 4.242640687119285, 4.381780460041329, 4.516635916254486, 4.6475800154489, 4.774934554525329, 4.898979485566357, 5.019960159204453, 5.138093031466052, 5.253570214625479, 5.366563145999495, 5.477225575051661, 5.585696017507576, 5.692099788303083, 5.796550698475775, 5.8991524815010505, 5.999999999999999, 6.099180272790762, 6.196773353931866, 6.29285308902091, 6.387487769068525, 6.4807406984078595, 6.572670690061993, 6.663332499583072, 6.752777206453652, 6.841052550594828, 6.928203230275509, 7.014271166700073, 7.0992957397195395, 7.183313998427187, 7.26636084983398, 7.348469228349534, 7.429670248402684, 7.5099933422074345, 7.589466384404111, 7.6681158050723255, 7.745966692414834, 7.8230428862431785, 7.899367063252599, 7.974960814950755, 8.049844718999243, 8.12403840463596, 8.197560612767678, 8.270429251254132, 8.342661445845684, 8.41427358718505, 8.48528137423857, 8.555699854482974, 8.625543461139129, 8.694826047713663, 8.763560920082657, 8.831760866327846, 8.899438184514795, 8.966604708583956, 9.033271832508971, 9.09945053286186, 9.16515138991168, 9.23038460737146, 9.2951600308978, 9.359487165438072, 9.423375191511797, 9.486832980505138, 9.549869109050658, 9.612491872558332, 9.67470929795826, 9.736529155710468, 9.797958971132713, 9.85900603509299, 9.919677414109795, 9.979979959899719, 10.039920318408907, 10.099504938362077, 10.158740079360236, 10.21763181955584, 10.276186062932103, 10.33440854621105, 10.392304845413264, 10.449880382090505, 10.507140429250958, 10.564090116995406, 10.620734437881403, 10.67707825203131, 10.73312629199899, 10.788883167408942, 10.844353369380766, 10.89954127475097, 10.954451150103322, 11.009087155618309], [0.0, 1.1135528725660044, 1.5748015748023623, 1.9287301521985913, 2.227105745132009, 2.489979919597747, 2.727636339397171, 2.946183972531247, 3.1496031496047245, 3.340658617698013, 3.521363372331802, 3.693237062523878, 3.8574603043971827, 4.014971979976947, 4.166533331199932, 4.3127717305695645, 4.454211490264018, 4.591296113299599, 4.724404724407087, 4.8538644398046396, 4.979959839195494, 5.10294032886923, 5.223025942880239, 5.340411969127476, 5.455272678794342, 5.567764362830022, 5.678027826631356, 5.786190456595773, 5.892367945062494, 5.99666574022598, 6.099180272790762, 6.2, 6.299206299209449, 6.396874236687791, 6.493073232299171, 6.587867636800241, 6.681317235396026, 6.77347768875044, 6.864400920692206, 6.954135460285484, 7.042726744663604, 7.130217387990355, 7.216647421067487, 7.302054505411473, 7.386474125047756, 7.469939758793239, 7.552483035399683, 7.634133873596926, 7.714920608794365, 7.794870107962031, 7.874007874011811, 7.9523581408284185, 8.029943959953894, 8.106787279804498, 8.182909018191515, 8.258329128825032, 8.333066662399863, 8.40713982279348, 8.480566018845677, 8.553361912137238, 8.625543461139129, 8.69712596206356, 8.76812408671319, 8.838551917593742, 8.908422980528035, 8.977750274985375, 9.046546302318912, 9.114823092084674, 9.182592226599198, 9.249864863877743, 9.316651759081694, 9.38296328459192, 9.448809448814174, 9.514199913813037, 9.579144011862438, 9.643650760992955, 9.707728879609279, 9.771386800244887, 9.834632682515398, 9.897474425326898, 9.959919678390987, 10.02197585309404, 10.083650132764426, 10.144949482377918, 10.20588065773846, 10.26645021416848, 10.32666451474047, 10.386529738079028, 10.446051885760477, 10.505236789335116, 10.564090116995406, 10.6226173799116, 10.680823938254951, 10.73871500692704, 10.796295661012625, 10.853570840972107, 10.910545357588685, 10.967223896684157, 11.023611023616535, 11.079711187571634, 11.135528725660045, 11.191067866830226], [0.0, 1.131370849898476, 1.5999999999999999, 1.9595917942265426, 2.262741699796952, 2.5298221281347035, 2.7712812921102037, 2.993325909419153, 3.1999999999999997, 3.394112549695428, 3.5777087639996634, 3.752332607858744, 3.9191835884530852, 4.079215610874228, 4.233202097703344, 4.381780460041329, 4.525483399593904, 4.66476151587624, 4.8, 4.931531202375181, 5.059644256269407, 5.184592558726289, 5.3065996645686395, 5.4258639865002145, 5.542562584220407, 5.656854249492381, 5.768882040742383, 5.878775382679628, 5.986651818838306, 6.092618484691127, 6.196773353931866, 6.299206299209449, 6.3999999999999995, 6.499230723708768, 6.596969000988257, 6.6932802122726045, 6.788225099390856, 6.881860213634101, 6.974238309665078, 7.0654086930622775, 7.155417527999327, 7.244308110509934, 7.332121111929345, 7.418894796396562, 7.504665215717488, 7.589466384404109, 7.6733304373003515, 7.756287771866126, 7.8383671769061705, 7.919595949289332, 8.0, 8.079603950689663, 8.158431221748456, 8.236504112789602, 8.313843876330612, 8.390470785361213, 8.466404195406689, 8.541662601625049, 8.616263691415206, 8.690224392960172, 8.763560920082657, 8.836288813749809, 8.908422980528034, 8.97997772825746, 9.050966799187808, 9.121403400793103, 9.191300234460845, 9.26066952223218, 9.32952303175248, 9.397872099576585, 9.465727652959385, 9.533100230250387, 9.6, 9.666436778875658, 9.73242004847715, 9.797958971132712, 9.863062404750362, 9.927738916792686, 9.991996797437437, 10.055844071981229, 10.119288512538814, 10.182337649086284, 10.244998779892558, 10.3072789813801, 10.369185117452577, 10.430723848324238, 10.491901638883201, 10.552724766618335, 10.613199329137279, 10.673331251301066, 10.73312629199899, 10.792590050585632, 10.851727973000429, 10.910545357588685, 10.969047360641671, 11.027239001672177, 11.085125168440815, 11.142710621747296, 11.2, 11.256997823576231, 11.313708498984761, 11.370136322841518], [0.0, 1.148912529307606, 1.624807680927192, 1.9899748742132404, 2.297825058615212, 2.5690465157330262, 2.8142494558940583, 3.039736830714133, 3.249615361854384, 3.4467375879228173, 3.6331804249169903, 3.8105117766515306, 3.9799497484264807, 4.1424630354415966, 4.298837052040936, 4.449719092257398, 4.595650117230424, 4.737087712930805, 4.874423042781577, 5.007993610219566, 5.1380930314660525, 5.264978632435274, 5.388877434122993, 5.509990925582366, 5.628498911788117, 5.7445626465380295, 5.858327406350725, 5.969924622639721, 6.079473661428266, 6.187083319303209, 6.29285308902091, 6.396874236687791, 6.499230723708768, 6.600000000000001, 6.6992536897776915, 6.797058187186572, 6.8934751758456345, 6.98856208386246, 7.08237248385031, 7.17495644586084, 7.266360849833981, 7.35662966309981, 7.445804187594515, 7.533923280734945, 7.621023553303061, 7.707139547199078, 7.792303895511264, 7.8765474670060875, 7.9598994968529615, 8.04238770515324, 8.12403840463596, 8.204876598706408, 8.284926070883193, 8.364209466530596, 8.442748367682174, 8.520563361656318, 8.597674104081872, 8.674099376880577, 8.749857141690944, 8.824964589164084, 8.899438184514796, 8.973293709669823, 9.046546302318914, 9.119210492142399, 9.191300234460847, 9.262828941527529, 9.333809511662428, 9.404254356406998, 9.47417542586161, 9.54358423235212, 9.612491872558333, 9.680909048224759, 9.748846085563153, 9.816312953446422, 9.88331928048467, 9.949874371066201, 10.015987220439133, 10.081666528902849, 10.14692071517266, 10.211757928975796, 10.276186062932105, 10.340212763768452, 10.403845442911964, 10.46709128650362, 10.529957264870548, 10.59245014149229, 10.654576481493764, 10.716342659695052, 10.777754868245985, 10.838819123871383, 10.899541274750971, 10.959927007056207, 11.019981851164731, 11.079711187571634, 11.139120252515458, 11.198214143335536, 11.256997823576233, 11.315476127852511, 11.373653766490346, 11.431535329954592, 11.489125293076059, 11.54642801908885], [0.0, 1.1661903789690602, 1.6492422502470643, 2.019900987672416, 2.3323807579381204, 2.60768096208106, 2.8565713714171403, 3.0854497241083028, 3.2984845004941286, 3.4985711369071804, 3.687817782917155, 3.8678159211627436, 4.039801975344832, 4.204759208325728, 4.363484845854286, 4.516635916254486, 4.664761515876241, 4.8083261120685235, 4.947726750741193, 5.083306010855535, 5.21536192416212, 5.344155686354956, 5.469917732470938, 5.592852581643825, 5.713142742834281, 5.830951894845301, 5.946427498927402, 6.059702963017247, 6.1708994482166055, 6.280127387243033, 6.387487769068525, 6.493073232299171, 6.596969000988257, 6.6992536897776915, 6.800000000000001, 6.899275324264136, 6.997142273814361, 7.09365914038728, 7.188880302244572, 7.282856582413251, 7.37563556583431, 7.467261881037788, 7.557777451076475, 7.647221717722064, 7.735631842325487, 7.823042886243178, 7.909487973314076, 7.994998436522674, 8.079603950689664, 8.16333265278342, 8.246211251235321, 8.328265125462806, 8.409518416651457, 8.48999411071645, 8.56971411425142, 8.648699324175862, 8.726969691708572, 8.804544281222055, 8.881441324469808, 8.957678270623477, 9.033271832508971, 9.108238029388561, 9.182592226599196, 9.256349172324908, 9.329523031752482, 9.402127418834526, 9.47417542586161, 9.54567965102538, 9.616652224137047, 9.687104830649869, 9.757048734120374, 9.826494797230598, 9.895453501482386, 9.96393496566492, 10.031948963187562, 10.099504938362077, 10.16661202171107, 10.233279044372825, 10.299514551666988, 10.365326815879952, 10.43072384832424, 10.495713410721542, 10.56030302595527, 10.62449998823474, 10.688311372709911, 10.75174404457249, 10.81480466767662, 10.877499712709719, 10.939835464941876, 11.001818031580052, 11.063453348751466, 11.124747188138704, 11.18570516328765, 11.24633273560764, 11.306635220082057, 11.366617790706258, 11.426285485668561, 11.485643212288984, 11.54469575172945, 11.60344776348823, 11.661903789690601, 11.72006825918689], [0.0, 1.1832159566199232, 1.6733200530681511, 2.04939015319192, 2.3664319132398464, 2.6457513110645907, 2.898275349237888, 3.1304951684997055, 3.3466401061363023, 3.5496478698597693, 3.7416573867739413, 3.924283374069717, 4.09878030638384, 4.266145801540309, 4.427188724235731, 4.58257569495584, 4.732863826479693, 4.878524367060187, 5.019960159204453, 5.157518783291051, 5.291502622129181, 5.422176684690384, 5.549774770204643, 5.674504383644443, 5.796550698475776, 5.916079783099616, 6.0332412515993425, 6.148170459575759, 6.260990336999411, 6.371812928829597, 6.4807406984078595, 6.587867636800241, 6.6932802122726045, 6.797058187186572, 6.899275324264136, 7.0, 7.099295739719539, 7.197221686178633, 7.293833011524188, 7.389181280764467, 7.483314773547883, 7.576278769950325, 7.668115805072326, 7.758865896508328, 7.848566748139434, 7.937253933193771, 8.024961059095553, 8.1117199162693, 8.19756061276768, 8.282511696339462, 8.366600265340756, 8.449852069711044, 8.532291603080617, 8.613942186943213, 8.694826047713663, 8.774964387392123, 8.854377448471462, 8.933084573650918, 9.01110426085505, 9.08845421400141, 9.16515138991168, 9.241212041718336, 9.316651759081692, 9.391485505499118, 9.465727652959385, 9.539392014169456, 9.612491872558332, 9.6850400102426, 9.757048734120374, 9.828529900244492, 9.899494936611665, 9.969954864491614, 10.039920318408907, 10.10940156488009, 10.178408519999577, 10.246950765959598, 10.315037566582102, 10.382677881933928, 10.449880382090507, 10.516653460107925, 10.583005244258363, 10.648943609579309, 10.7144761887831, 10.779610382569492, 10.844353369380768, 10.908712114635716, 10.972693379476162, 11.036303729057115, 11.099549540409287, 11.16243700990066, 11.224972160321824, 11.287160847617969, 11.349008767288886, 11.41052146047673, 11.47170431975999, 11.532562594670795, 11.593101396951552, 11.653325705565774, 11.713240371477058, 11.772850122209151, 11.832159566199232, 11.8911731969558], [0.0, 1.2, 1.697056274847714, 2.078460969082653, 2.4, 2.6832815729997477, 2.939387691339814, 3.1749015732775088, 3.394112549695428, 3.5999999999999996, 3.794733192202055, 3.97994974842648, 4.156921938165306, 4.3266615305567875, 4.48998886412873, 4.6475800154488995, 4.8, 4.947726750741192, 5.091168824543142, 5.230678732248808, 5.366563145999495, 5.499090833947008, 5.628498911788116, 5.754997827975264, 5.878775382679628, 6.0, 6.118823416311342, 6.235382907247958, 6.3498031465550175, 6.462197768561405, 6.572670690061993, 6.681317235396026, 6.788225099390856, 6.8934751758456345, 6.997142273814361, 7.099295739719539, 7.199999999999999, 7.299315036357863, 7.397296803562772, 7.493997598078078, 7.58946638440411, 7.683749084919419, 7.776888838089433, 7.8689262291624, 7.95989949685296, 8.049844718999243, 8.138795979750322, 8.226785520481252, 8.313843876330612, 8.4, 8.48528137423857, 8.56971411425142, 8.653323061113575, 8.736131867136622, 8.818163074019441, 8.899438184514796, 8.97997772825746, 9.0598013223249, 9.13892772703669, 9.21737489744233, 9.295160030897799, 9.372299611087985, 9.448809448814172, 9.524704719832526, 9.6, 9.674709297958259, 9.748846085563152, 9.82242332624694, 9.895453501482384, 9.96794863550169, 10.039920318408907, 10.111379727811629, 10.182337649086284, 10.252804494381037, 10.322790320451151, 10.392304845413264, 10.461357464497617, 10.529957264870546, 10.598113039593418, 10.665833300778706, 10.73312629199899, 10.8, 10.8664621657649, 10.932520294973157, 10.998181667894016, 11.063453348751464, 11.128342194594845, 11.192854863706579, 11.256997823576231, 11.320777358467923, 11.384199576606164, 11.447270417003347, 11.509995655950528, 11.572380913191546, 11.63443165779919, 11.696153213770755, 11.757550765359255, 11.818629362155326, 11.879393923933998, 11.93984924527944, 12.0, 12.05985074534507], [0.0, 1.216552506059644, 1.7204650534085253, 2.107130750570548, 2.433105012119288, 2.720294101747089, 2.979932885150268, 3.2186953878862163, 3.4409301068170506, 3.6496575181789317, 3.847076812334269, 4.034848200366404, 4.214261501141096, 4.386342439892262, 4.551922670696417, 4.711687595755898, 4.866210024238576, 5.015974481593781, 5.1613951602255765, 5.302829433425142, 5.440588203494178, 5.574943945906542, 5.706137047074843, 5.83438085832593, 5.959865770300536, 6.08276253029822, 6.20322496770833, 6.321392251711644, 6.437390775772433, 6.551335741663681, 6.663332499583072, 6.77347768875044, 6.881860213634101, 6.98856208386246, 7.09365914038728, 7.197221686178633, 7.299315036357863, 7.4, 7.4993333037010705, 7.597367965289033, 7.694153624668538, 7.78973683766018, 7.88416133777081, 7.977468270071652, 8.069696400732807, 8.160882305241266, 8.251060537894508, 8.340263784797218, 8.428523002282192, 8.515867542417508, 8.602325267042628, 8.68792265158939, 8.772684879784524, 8.856635930193812, 8.939798655450804, 9.02219485491197, 9.103845341392834, 9.184770002564028, 9.264987857520376, 9.344517108978932, 9.423375191511797, 9.501578816175762, 9.579144011862438, 9.65608616365865, 9.732420048477152, 9.808159868191382, 9.88331928048467, 9.957911427603682, 10.031948963187562, 10.105444077327824, 10.178408519999579, 10.250853622991599, 10.322790320451153, 10.394229168149026, 10.465180361560904, 10.53565375285274, 10.605658866850284, 10.675204916066015, 10.744300814850636, 10.812955192730618, 10.881176406988356, 10.948972554536796, 11.016351483136331, 11.083320801997928, 11.149887891813083, 11.216059914247962, 11.281843820936365, 11.347246362003428, 11.412274094149685, 11.476933388322859, 11.541230437002808, 11.605171261123207, 11.66876171665186, 11.732007500849972, 11.794914158229385, 11.85748708622531, 11.919731540601072, 11.98165264060013, 12.043255373859678, 12.10454460109921, 12.16552506059644, 12.226201372462342], [0.0, 1.2328828005937953, 1.7435595774162695, 2.1354156504062627, 2.4657656011875906, 2.7568097504180447, 3.0199337741083, 3.2619012860600183, 3.487119154832539, 3.698648401781386, 3.898717737923586, 4.0890096600521755, 4.270831300812525, 4.445222154178574, 4.613025037868319, 4.774934554525329, 4.931531202375181, 5.083306010855534, 5.230678732248808, 5.374011537017762, 5.513619500836089, 5.649778756730214, 5.782732917920384, 5.912698199637794, 6.0398675482166, 6.164414002968977, 6.2864934582006855, 6.406246951218788, 6.523802572120037, 6.639277069079133, 6.752777206453652, 6.864400920692206, 6.974238309665078, 7.08237248385031, 7.188880302244572, 7.293833011524188, 7.397296803562772, 7.4993333037010705, 7.6000000000000005, 7.6993506219680645, 7.797435475847172, 7.894301742396221, 7.9899937421752725, 8.084553172563094, 8.178019320104351, 8.270429251254132, 8.36181798414675, 8.452218643646177, 8.54166260162505, 8.630179604156568, 8.717797887081348, 8.804544281222057, 8.890444308357148, 8.975522268926753, 9.059801322324901, 9.143303560529969, 9.226050075736637, 9.308061022576076, 9.389355675444403, 9.469952481401371, 9.549869109050658, 9.629122493768579, 9.707728879609277, 9.785703858180055, 9.863062404750362, 9.939818911831342, 10.015987220439133, 10.091580649234292, 10.166612021711067, 10.241093691593687, 10.315037566582102, 10.388455130576443, 10.461357464497617, 10.533755265810955, 10.605658866850282, 10.677078252031311, 10.748023074035524, 10.818502669038818, 10.888526071052961, 10.95810202544218, 11.027239001672179, 11.095945205344158, 11.164228589562292, 11.232096865679178, 11.299557513460428, 11.36661779070626, 11.433284742365162, 11.499565209172042, 11.565465835840769, 11.63099307883897, 11.696153213770756, 11.760952342391326, 11.825396399275588, 11.889491158161482, 11.95324223798715, 12.016655108639842, 12.0797350964332, 12.142487389328434, 12.204917041913886, 12.267028980156525, 12.328828005937954, 12.390318801386833], [0.0, 1.2489995996796799, 1.7663521732655694, 2.163330765278394, 2.4979991993593598, 2.7928480087537886, 3.0594117081556713, 3.3045423283716615, 3.5327043465311387, 3.746998799039039, 3.9496835316263, 4.1424630354415966, 4.326661530556788, 4.503332099679081, 4.673328578219169, 4.8373546489791295, 4.9959983987187195, 5.149757275833494, 5.299056519796709, 5.444263035526481, 5.585696017507577, 5.723635208501674, 5.858327406350725, 5.989991652748776, 6.118823416311343, 6.244997998398399, 6.3686733312362644, 6.489992295835182, 6.609084656743323, 6.726068688320096, 6.841052550594828, 6.954135460285484, 7.0654086930622775, 7.17495644586084, 7.282856582413251, 7.389181280764467, 7.493997598078078, 7.597367965289033, 7.6993506219680645, 7.800000000000002, 7.8993670632526, 7.997499609252883, 8.094442537939226, 8.190238091777308, 8.284926070883193, 8.378544026261364, 8.47112743381895, 8.562709851443058, 8.653323061113577, 8.742997197757758, 8.831760866327848, 8.919641248391105, 9.006664199358163, 9.092854337335446, 9.178235124467014, 9.26282894152753, 9.346657156438338, 9.429740187301027, 9.512097560475294, 9.593747964169166, 9.674709297958259, 9.75499871860576, 9.834632682515398, 9.913626985114984, 9.991996797437439, 10.069756700139283, 10.146920715172659, 10.223502335305646, 10.299514551666988, 10.374969879474351, 10.449880382090507, 10.524257693538296, 10.598113039593418, 10.671457257563281, 10.744300814850634, 10.816653826391969, 10.888526071052961, 10.959927007056207, 11.030865786510144, 11.101351269102336, 11.171392035015154, 11.240996397117119, 11.310172412478956, 11.37892789325954, 11.447270417003349, 11.515207336387826, 11.582745788456208, 11.649892703368561, 11.71665481270145, 11.783038657324349, 11.8490505948789, 11.914696806885186, 11.979983305497552, 12.04491593993084, 12.109500402576485, 12.17374223482656, 12.237646832622685, 12.301219451745427, 12.364465212858986, 12.427389106324789, 12.489995996796798, 12.552290627610565], [0.0, 1.2649110640673518, 1.7888543819998317, 2.1908902300206647, 2.5298221281347035, 2.8284271247461903, 3.0983866769659336, 3.3466401061363023, 3.5777087639996634, 3.794733192202055, 4.0, 4.1952353926806065, 4.3817804600413295, 4.560701700396552, 4.732863826479693, 4.898979485566356, 5.059644256269407, 5.215361924162119, 5.366563145999495, 5.513619500836089, 5.656854249492381, 5.796550698475776, 5.932958789676531, 6.066300355241241, 6.196773353931867, 6.324555320336759, 6.44980619863884, 6.572670690061994, 6.6932802122726045, 6.811754546370561, 6.928203230275509, 7.042726744663604, 7.155417527999327, 7.266360849833981, 7.37563556583431, 7.483314773547883, 7.58946638440411, 7.694153624668538, 7.797435475847172, 7.8993670632526, 8.0, 8.099382692526635, 8.19756061276768, 8.294576541331088, 8.390470785361213, 8.48528137423857, 8.579044235810887, 8.67179335547152, 8.763560920082659, 8.854377448471462, 8.94427190999916, 9.033271832508973, 9.121403400793104, 9.208691546577072, 9.2951600308978, 9.38083151964686, 9.465727652959385, 9.549869109050658, 9.633275663033837, 9.715966241192895, 9.797958971132712, 9.879271228182775, 9.959919678390985, 10.039920318408907, 10.119288512538814, 10.198039027185569, 10.276186062932103, 10.353743284435827, 10.430723848324238, 10.507140429250958, 10.583005244258363, 10.658330075579382, 10.73312629199899, 10.807404868885037, 10.881176406988354, 10.954451150103322, 11.027239001672179, 11.099549540409287, 11.171392035015154, 11.242775458044157, 11.313708498984761, 11.384199576606166, 11.454256850621084, 11.523888232710346, 11.593101396951552, 11.661903789690601, 11.730302638892145, 11.798304963002101, 11.865917579353061, 11.933147112141038, 12.0, 12.066482503198685, 12.132600710482482, 12.198360545581526, 12.263767773404714, 12.328828005937952, 12.393546707863734, 12.45792920191795, 12.521980673998822, 12.58570617804182, 12.649110640673518, 12.712198865656564], [0.0, 1.2806248474865698, 1.8110770276274835, 2.2181073012818837, 2.5612496949731396, 2.863564212655271, 3.136877428271625, 3.3882148692194836, 3.622154055254967, 3.8418745424597094, 4.049691346263318, 4.247352116319061, 4.436214602563767, 4.617358552246079, 4.791659420284376, 4.959838707054898, 5.122499389946279, 5.280151512977635, 5.43323108288245, 5.582114294781146, 5.727128425310542, 5.868560300448484, 6.006662967072483, 6.1416610131136355, 6.27375485654325, 6.403124237432849, 6.529931086925804, 6.654321903845651, 6.776429738438967, 6.896375859826668, 7.014271166700073, 7.130217387990355, 7.244308110509934, 7.35662966309981, 7.467261881037788, 7.576278769950325, 7.683749084919419, 7.78973683766018, 7.894301742396221, 7.997499609252883, 8.099382692526635, 8.200000000000001, 8.299397568498573, 8.397618710086807, 8.494704232638123, 8.590692637965812, 8.685620300243386, 8.779521627059188, 8.872429205127535, 8.964373932405989, 9.055385138137417, 9.145490692138942, 9.234717104492159, 9.323089616645333, 9.410632284814874, 9.497368056467014, 9.583318840568753, 9.668505572217457, 9.752948272189288, 9.836666101886351, 9.919677414109795, 10.001999800039991, 10.083650132764426, 10.16464460765845, 10.244998779892558, 10.324727599312245, 10.403845442911964, 10.482366145102928, 10.56030302595527, 10.637668917577761, 10.7144761887831, 10.79073676817297, 10.8664621657649, 10.941663493271944, 11.01635148313633, 11.090536506409418, 11.164228589562292, 11.23743743030412, 11.310172412478956, 11.382442620105758, 11.454256850621084, 11.52562362737913, 11.596551211459381, 11.667047612828192, 11.737120600896969, 11.806777714516354, 11.87602627144282, 11.944873377311291, 12.013325934144966, 12.081390648431166, 12.149074038789953, 12.216382443260363, 12.283322026227271, 12.349898785010348, 12.416118556135007, 12.48198702130394, 12.5475097130865, 12.61269202034205, 12.677539193392384, 12.742056348957183, 12.806248474865699, 12.870120434556938], [0.0, 1.2961481396815722, 1.8330302779823362, 2.2449944320643653, 2.5922962793631443, 2.8982753492378883, 3.174901573277509, 3.4292856398964497, 3.6660605559646724, 3.8884444190447165, 4.09878030638384, 4.298837052040936, 4.489988864128731, 4.67332857821917, 4.849742261192857, 5.019960159204453, 5.184592558726289, 5.344155686354956, 5.499090833947008, 5.649778756730215, 5.796550698475777, 5.939696961967, 6.079473661428266, 6.216108107168022, 6.349803146555018, 6.480740698407861, 6.609084656743324, 6.7349832961930955, 6.8585712797928995, 6.97997134664606, 7.0992957397195395, 7.216647421067487, 7.332121111929345, 7.445804187594515, 7.557777451076475, 7.668115805072326, 7.776888838089433, 7.88416133777081, 7.9899937421752725, 8.094442537939226, 8.19756061276768, 8.299397568498573, 8.400000000000002, 8.499411744350311, 8.597674104081872, 8.694826047713663, 8.790904390334365, 8.885943956609225, 8.979977728257461, 9.073036977771006, 9.165151389911681, 9.25634917232491, 9.34665715643834, 9.436100889668362, 9.524704719832528, 9.612491872558333, 9.699484522385713, 9.785703858180055, 9.871170143402454, 9.955902771722915, 10.039920318408907, 10.123240587875012, 10.20588065773846, 10.287856919689348, 10.369185117452577, 10.449880382090505, 10.529957264870548, 10.609429767899876, 10.688311372709911, 10.766615066955818, 10.84435336938077, 10.92153835318084, 10.998181667894016, 11.074294559925702, 11.149887891813083, 11.224972160321824, 11.29955751346043, 11.373653766490346, 11.44727041700335, 11.520416659131737, 11.593101396951553, 11.66533325713415, 11.73712060089697, 11.80847153530041, 11.879393923934, 11.949895397031726, 12.019983361053377, 12.089665007765932, 12.158947322856532, 12.227837094106219, 12.296340919151518, 12.364465212858986, 12.432216214336044, 12.499599993599798, 12.566622457924009, 12.633289357883006, 12.699606293110037, 12.76557871778636, 12.831211945876353, 12.89651115612281, 12.961481396815723, 13.026127590347027], [0.0, 1.3114877048604001, 1.8547236990991405, 2.2715633383201097, 2.6229754097208002, 2.932575659723036, 3.212475680841802, 3.4698703145794942, 3.709447398198281, 3.9344631145812, 4.147288270665544, 4.349712634186309, 4.543126676640219, 4.728636167014756, 4.907137658554118, 5.079370039680117, 5.2459508194416005, 5.407402333838309, 5.564171097297422, 5.716642371182581, 5.865151319446072, 6.009991680526688, 6.151422599691879, 6.289674077406555, 6.424951361683604, 6.557438524302, 6.687301398920195, 6.814690014960328, 6.9397406291589885, 7.06257743320383, 7.183313998427187, 7.302054505411473, 7.418894796396562, 7.533923280734945, 7.647221717722064, 7.758865896508328, 7.8689262291624, 7.977468270071652, 8.084553172563094, 8.190238091777308, 8.294576541331088, 8.397618710086807, 8.499411744350311, 8.599999999999998, 8.699425268372618, 8.797726979169106, 8.894942383174834, 8.991106717195608, 9.086253353280439, 9.1804139340228, 9.273618495495704, 9.365895579174477, 9.457272334029511, 9.547774609824009, 9.637427042525406, 9.726253132630262, 9.814275317108237, 9.90151503558925, 9.987992791347018, 10.07372820757042, 10.158740079360234, 10.243046421841502, 10.326664514740468, 10.409610943738484, 10.491901638883201, 10.57355191030904, 10.654576481493761, 10.734989520255713, 10.814804667676619, 10.894035065117057, 10.972693379476162, 11.050791826833043, 11.128342194594843, 11.20535586226515, 11.281843820936361, 11.357816691600547, 11.433284742365162, 11.508257904652641, 11.582745788456208, 11.656757696718243, 11.730302638892145, 11.8033893437436, 11.876026271442818, 11.948221624995076, 12.019983361053376, 12.091319200153471, 12.162236636408617, 12.232742946698421, 12.302845199383759, 12.372550262577233, 12.44186481199663, 12.51079533842673, 12.57934815481311, 12.647529403009901, 12.715345060201866, 12.782800945019833, 12.849902723367208, 12.916655913974019, 12.983065893693984, 13.049137902558927, 13.114877048604, 13.180288312476325], [0.0, 1.32664991614216, 1.876166303929372, 2.297825058615212, 2.65329983228432, 2.9664793948382657, 3.2496153618543846, 3.509985754956849, 3.752332607858744, 3.97994974842648, 4.1952353926806065, 4.4, 4.595650117230424, 4.7833042972405595, 4.963869458396343, 5.138093031466052, 5.30659966456864, 5.469917732470938, 5.628498911788116, 5.782732917920385, 5.9329587896765315, 6.079473661428266, 6.222539674441619, 6.362389488234747, 6.499230723708769, 6.6332495807108005, 6.764613810115106, 6.893475175845635, 7.019971509913698, 7.144228439796701, 7.26636084983398, 7.386474125047756, 7.504665215717488, 7.621023553303061, 7.735631842325487, 7.848566748139434, 7.95989949685296, 8.069696400732807, 8.178019320104351, 8.284926070883193, 8.390470785361213, 8.494704232638123, 8.597674104081872, 8.699425268372618, 8.8, 8.899438184514796, 8.997777503361595, 9.09505360072166, 9.191300234460847, 9.28654941299512, 9.38083151964686, 9.474175425861612, 9.566608594481119, 9.65815717411971, 9.748846085563153, 9.838699100999076, 9.927738916792686, 10.015987220439133, 10.103464752252073, 10.190191362285598, 10.276186062932103, 10.361467077590895, 10.446051885760477, 10.529957264870548, 10.61319932913728, 10.69579356569675, 10.777754868245985, 10.859097568398584, 10.939835464941876, 11.01998185116473, 11.099549540409289, 11.178550889985697, 11.256997823576231, 11.334901852243805, 11.412274094149685, 11.489125293076059, 11.56546583584077, 11.6413057686842, 11.71665481270145, 11.791522378386942, 11.865917579353063, 11.939849245279442, 12.013325934144968, 12.086355943790503, 12.158947322856532, 12.231107881136525, 12.30284519938376, 12.374166638606416, 12.445079348883239, 12.515590277729613, 12.58570617804182, 12.655433615645101, 12.724778976469494, 12.793748473375583, 12.862348152650823, 12.93058390019569, 12.998461447417538, 13.065986376848862, 13.133164127505603, 13.200000000000003, 13.266499161421601, 13.332666649999169], [0.0, 1.3416407864998738, 1.8973665961010273, 2.32379000772445, 2.6832815729997477, 3.0, 3.2863353450309964, 3.5496478698597693, 3.7947331922020546, 4.024922359499621, 4.242640687119285, 4.449719092257398, 4.6475800154489, 4.8373546489791295, 5.0199601592044525, 5.196152422706631, 5.366563145999495, 5.531726674375732, 5.692099788303082, 5.848076606885378, 6.0, 6.148170459575759, 6.292853089020909, 6.434283176858165, 6.572670690061993, 6.7082039324993685, 6.841052550594828, 6.971370023173351, 7.099295739719539, 7.224956747275377, 7.348469228349534, 7.469939758793239, 7.589466384404109, 7.707139547199078, 7.823042886243178, 7.937253933193771, 8.049844718999243, 8.160882305241266, 8.270429251254132, 8.378544026261364, 8.48528137423857, 8.590692637965812, 8.694826047713663, 8.797726979169106, 8.899438184514796, 8.999999999999998, 9.09945053286186, 9.197825830053535, 9.2951600308978, 9.391485505499116, 9.486832980505138, 9.581231653602787, 9.674709297958259, 9.767292357659825, 9.859006035092989, 9.9498743710662, 10.039920318408905, 10.129165809680478, 10.21763181955584, 10.3053384223906, 10.392304845413262, 10.478549517943787, 10.564090116995404, 10.648943609579309, 10.73312629199899, 10.816653826391967, 10.89954127475097, 10.981803130633875, 11.063453348751464, 11.144505372604025, 11.224972160321824, 11.304866208850061, 11.384199576606164, 11.462983904725679, 11.541230437002806, 11.61895003862225, 11.696153213770756, 11.77285012220915, 11.8490505948789, 11.924764148611073, 12.0, 12.074767078498864, 12.149074038789953, 12.222929272478016, 12.296340919151518, 12.36931687685298, 12.441864811996632, 12.513992168768526, 12.585706178041818, 12.65701386583739, 12.727922061357855, 12.798437404620923, 12.86856635371633, 12.938315191708694, 13.007690033207279, 13.07669683062202, 13.145341380123986, 13.213629327327144, 13.281566172707192, 13.349157276772193, 13.416407864998737, 13.48332303254654], [0.0, 1.3564659966250536, 1.9183326093250879, 2.3494680248941466, 2.7129319932501073, 3.0331501776206204, 3.32264954516723, 3.5888716889852725, 3.8366652186501757, 4.069397989875161, 4.2895221179054435, 4.498888751680798, 4.698936049788293, 4.890807704254994, 5.075431016179809, 5.253570214625478, 5.4258639865002145, 5.592852581643825, 5.754997827975264, 5.912698199637794, 6.066300355241241, 6.216108107168022, 6.362389488234747, 6.505382386916238, 6.64529909033446, 6.782329983125269, 6.916646586316234, 7.0484040746824395, 7.177743377970545, 7.3047929470998705, 7.429670248402684, 7.552483035399683, 7.6733304373003515, 7.792303895511264, 7.909487973314076, 8.024961059095553, 8.138795979750322, 8.251060537894508, 8.36181798414675, 8.47112743381895, 8.579044235810887, 8.685620300243386, 8.790904390334365, 8.894942383174834, 8.997777503361595, 9.09945053286186, 9.200000000000001, 9.299462350050137, 9.397872099576587, 9.495261976375376, 9.59166304662544, 9.687104830649869, 9.781615408509987, 9.875221516502808, 9.96794863550169, 10.059821071967434, 10.150862032359617, 10.241093691593687, 10.330537256115967, 10.419213022104884, 10.507140429250956, 10.594338110519223, 10.680823938254951, 10.766615066955817, 10.851727973000429, 10.936178491593852, 11.01998185116473, 11.103152705425607, 11.18570516328765, 11.26765281680262, 11.349008767288886, 11.42978564978364, 11.509995655950528, 11.589650555560336, 11.668761716651858, 11.747340124470732, 11.825396399275588, 11.90294081309321, 11.979983305497552, 12.05653349848123, 12.132600710482482, 12.208193969625484, 12.283322026227271, 12.357993364620325, 12.432216214336044, 12.505998560690786, 12.579348154813111, 12.652272523147769, 12.724778976469494, 12.796874618437112, 12.86856635371633, 12.93986089569745, 13.010764773832475, 13.081284340614268, 13.15142577821888, 13.221195104830727, 13.29059818066892, 13.35964071373179, 13.428328265275615, 13.496666255042392, 13.564659966250538, 13.63231455036158], [0.0, 1.3711309200802089, 1.9390719429665315, 2.374868417407584, 2.7422618401604177, 3.0659419433511785, 3.358571124749333, 3.627671429443411, 3.878143885933063, 4.113392760240626, 4.33589667773576, 4.54752680036083, 4.749736834815168, 4.94368283772331, 5.130302135352264, 5.310367218940701, 5.4845236803208355, 5.653317610041028, 5.817215828899595, 5.976621118993575, 6.131883886702357, 6.2833112289620034, 6.431174076325411, 6.575712889109439, 6.717142249498666, 6.855654600401045, 6.9914233171794145, 7.124605252222751, 7.255342858886822, 7.383765976789894, 7.5099933422074345, 7.634133873596926, 7.756287771866126, 7.8765474670060875, 7.994998436522674, 8.1117199162693, 8.226785520481252, 8.340263784797218, 8.452218643646177, 8.562709851443058, 8.67179335547152, 8.779521627059188, 8.885943956609225, 8.991106717195608, 9.09505360072166, 9.197825830053535, 9.299462350050137, 9.4, 9.499473669630335, 9.597916440561463, 9.695359714832659, 9.79183333191492, 9.88736567544662, 9.981983770774226, 10.075713374248, 10.16857905510893, 10.260604270704528, 10.351811435686027, 10.442221985765292, 10.531856436545269, 10.620734437881403, 10.708874824182043, 10.796295661012623, 10.883014288330234, 10.969047360641671, 11.054410884348382, 11.139120252515456, 11.22319027727856, 11.306635220082056, 11.38946881992308, 11.47170431975999, 11.553354491228944, 11.63443165779919, 11.714947716485977, 11.794914158229384, 11.874342087037917, 11.95324223798715, 12.031624994156028, 12.109500402576485, 12.1868781892657, 12.263767773404714, 12.34017828072188, 12.416118556135006, 12.491597175701752, 12.566622457924007, 12.641202474448386, 12.715345060201868, 12.789057822998535, 12.862348152650823, 12.935223229616101, 13.007690033207279, 13.079755349393963, 13.151425778218877, 13.222707740852478, 13.293607486307094, 13.36413109783049, 13.434284498997332, 13.504073459515837, 13.573503600765722, 13.642580401082489, 13.71130920080209, 13.779695207079149], [0.0, 1.385640646055102, 1.9595917942265426, 2.400000000000001, 2.771281292110204, 3.098386676965934, 3.3941125496954285, 3.6660605559646724, 3.9191835884530852, 4.156921938165306, 4.3817804600413295, 4.595650117230424, 4.800000000000002, 4.9959983987187195, 5.184592558726289, 5.366563145999495, 5.542562584220408, 5.713142742834281, 5.8787753826796285, 6.039867548216601, 6.196773353931868, 6.349803146555018, 6.499230723708769, 6.645299090334461, 6.788225099390857, 6.9282032302755105, 7.065408693062279, 7.200000000000001, 7.332121111929345, 7.461903242471053, 7.589466384404111, 7.714920608794365, 7.8383671769061705, 7.9598994968529615, 8.079603950689664, 8.19756061276768, 8.313843876330612, 8.428523002282192, 8.54166260162505, 8.653323061113577, 8.763560920082659, 8.872429205127535, 8.979977728257461, 9.086253353280439, 9.191300234460847, 9.2951600308978, 9.397872099576587, 9.499473669630335, 9.600000000000003, 9.699484522385713, 9.797958971132713, 9.895453501482388, 9.991996797437439, 10.087616170334796, 10.182337649086286, 10.276186062932105, 10.369185117452577, 10.461357464497619, 10.552724766618338, 10.643307756520057, 10.73312629199899, 10.822199406774947, 10.910545357588685, 10.998181667894018, 11.085125168440817, 11.171392035015154, 11.256997823576233, 11.341957503006261, 11.426285485668561, 11.50999565595053, 11.593101396951553, 11.67561561546114, 11.757550765359257, 11.838918869558995, 11.919731540601072, 12.000000000000002, 12.079735096433202, 12.158947322856532, 12.237646832622687, 12.315843454672525, 12.393546707863736, 12.470765814495918, 12.5475097130865, 12.623787070447602, 12.699606293110037, 12.774975538137053, 12.84990272336721, 12.924395537122813, 12.998461447417538, 13.072107710694555, 13.145341380123988, 13.218169313486646, 13.290598180668923, 13.362634470792056, 13.434284498997334, 13.505554412907307, 13.576450198781714, 13.646977687385588, 13.717142559585799, 13.78695035169127, 13.856406460551021, 13.925516148423371], [0.0, 1.4000000000000001, 1.979898987322333, 2.4248711305964283, 2.8000000000000003, 3.130495168499706, 3.4292856398964493, 3.704051835490427, 3.959797974644666, 4.2, 4.427188724235731, 4.64327470649756, 4.849742261192857, 5.047771785649585, 5.238320341483518, 5.422176684690383, 5.6000000000000005, 5.772347875864725, 5.939696961966999, 6.102458520956944, 6.260990336999412, 6.4156059729381765, 6.566582063752802, 6.714164132637808, 6.858571279792899, 7.0, 7.138627319029899, 7.274613391789285, 7.408103670980854, 7.539230729988306, 7.6681158050723255, 7.794870107962031, 7.919595949289332, 8.04238770515324, 8.16333265278342, 8.282511696339462, 8.4, 8.515867542417508, 8.630179604156568, 8.742997197757758, 8.854377448471462, 8.964373932405989, 9.073036977771006, 9.1804139340228, 9.28654941299512, 9.391485505499116, 9.495261976375376, 9.597916440561463, 9.699484522385713, 9.8, 9.899494936611665, 9.997999799959992, 10.09554357129917, 10.192153844992726, 10.287856919689348, 10.382677881933928, 10.476640682967036, 10.569768209379049, 10.662082348209472, 10.75360404701605, 10.844353369380766, 10.934349546269315, 11.023611023616535, 11.11215550647128, 11.200000000000001, 11.287160847617969, 11.373653766490344, 11.45949388062143, 11.54469575172945, 11.629273408085306, 11.713240371477058, 11.796609682446903, 11.879393923933998, 11.961605243444543, 12.043255373859678, 12.12435565298214, 12.204917041913887, 12.284950142348972, 12.364465212858986, 12.443472184241825, 12.521980673998824, 12.600000000000001, 12.677539193392384, 12.754607010802019, 12.831211945876353, 12.907362240210043, 12.983065893693986, 13.058330674324342, 13.133164127505603, 13.207573584879245, 13.281566172707194, 13.35514881983724, 13.428328265275615, 13.501111065390138, 13.573503600765722, 13.645512082732548, 13.717142559585797, 13.788400922514548, 13.85929291125633, 13.92982411949268, 14.0, 14.069825869569248], [0.0, 1.4142135623730951, 2.0, 2.4494897427831783, 2.8284271247461903, 3.1622776601683795, 3.464101615137755, 3.7416573867739418, 4.0, 4.242640687119285, 4.47213595499958, 4.69041575982343, 4.898979485566357, 5.099019513592785, 5.291502622129181, 5.477225575051661, 5.656854249492381, 5.830951894845301, 6.0, 6.164414002968978, 6.324555320336759, 6.480740698407861, 6.6332495807108005, 6.782329983125269, 6.92820323027551, 7.071067811865476, 7.211102550927979, 7.348469228349535, 7.4833147735478835, 7.6157731058639095, 7.745966692414834, 7.874007874011811, 8.0, 8.12403840463596, 8.246211251235321, 8.366600265340756, 8.48528137423857, 8.602325267042628, 8.717797887081348, 8.831760866327848, 8.94427190999916, 9.055385138137417, 9.165151389911681, 9.273618495495704, 9.38083151964686, 9.486832980505138, 9.59166304662544, 9.695359714832659, 9.797958971132713, 9.899494936611665, 10.000000000000002, 10.09950493836208, 10.19803902718557, 10.295630140987003, 10.392304845413264, 10.488088481701517, 10.583005244258363, 10.677078252031311, 10.77032961426901, 10.862780491200215, 10.954451150103322, 11.045361017187261, 11.135528725660043, 11.224972160321824, 11.313708498984761, 11.40175425099138, 11.489125293076057, 11.575836902790225, 11.661903789690601, 11.747340124470732, 11.832159566199234, 11.916375287812986, 12.0, 12.083045973594572, 12.165525060596439, 12.247448713915892, 12.328828005937956, 12.409673645990857, 12.489995996796798, 12.569805089976535, 12.649110640673518, 12.727922061357857, 12.806248474865699, 12.884098726725126, 12.961481396815723, 13.038404810405298, 13.114877048604002, 13.19090595827292, 13.266499161421601, 13.341664064126334, 13.416407864998739, 13.490737563232042, 13.564659966250538, 13.638181696985857, 13.71130920080209, 13.784048752090222, 13.85640646055102, 13.928388277184121, 14.0, 14.07124727947029, 14.142135623730953, 14.212670403551897], [0.0, 1.4282856857085702, 2.0199009876724157, 2.473863375370597, 2.8565713714171403, 3.193743884534263, 3.498571136907181, 3.7788887255382373, 4.039801975344831, 4.28485705712571, 4.5166359162544865, 4.737087712930806, 4.947726750741194, 5.149757275833494, 5.344155686354956, 5.531726674375732, 5.713142742834281, 5.888972745734184, 6.059702963017248, 6.225752966509353, 6.387487769068526, 6.54522726878143, 6.6992536897776915, 6.8498175158174845, 6.997142273814362, 7.141428428542851, 7.282856582413251, 7.4215901261117905, 7.557777451076475, 7.691553809211766, 7.8230428862431785, 7.9523581408284185, 8.079603950689663, 8.204876598706408, 8.328265125462806, 8.449852069711044, 8.56971411425142, 8.68792265158939, 8.804544281222057, 8.919641248391105, 9.033271832508973, 9.145490692138942, 9.25634917232491, 9.365895579174477, 9.474175425861612, 9.581231653602787, 9.687104830649869, 9.79183333191492, 9.895453501482388, 9.997999799959992, 10.09950493836208, 10.200000000000003, 10.299514551666988, 10.398076745244769, 10.495713410721542, 10.59245014149229, 10.688311372709911, 10.783320453366859, 10.87749971270972, 10.970870521521983, 11.063453348751464, 11.155267813907473, 11.24633273560764, 11.336666176614711, 11.426285485668561, 11.515207336387826, 11.60344776348823, 11.691022196540388, 11.777945491468367, 11.864231959971114, 11.949895397031726, 12.034949106664309, 12.119405926034496, 12.203278248077442, 12.286578042726136, 12.369316876852983, 12.451505933018707, 12.533156027114641, 12.614277624977186, 12.694880858046682, 12.774975538137053, 12.854571171377131, 12.933676971379796, 13.012301871690498, 13.09045453756286, 13.168143377105219, 13.24537655183876, 13.322161986704712, 13.398507379555383, 13.47442021016118, 13.54990774876346, 13.62497706420088, 13.699635031634969, 13.773888339898798, 13.847743498491011, 13.921206844235885, 13.994284547628723, 14.066982618884552, 14.13930691370691, 14.211263138792416, 14.282856857085703, 14.354093492798494], [0.0, 1.4422205101855958, 2.039607805437114, 2.4979991993593598, 2.8844410203711917, 3.22490309931942, 3.532704346531139, 3.815756805667783, 4.079215610874228, 4.3266615305567875, 4.560701700396552, 4.7833042972405595, 4.9959983987187195, 5.200000000000001, 5.396295025292817, 5.585696017507576, 5.768882040742383, 5.946427498927402, 6.118823416311343, 6.2864934582006855, 6.44980619863884, 6.609084656743323, 6.764613810115105, 6.916646586316234, 7.065408693062278, 7.211102550927979, 7.353910524340095, 7.493997598078079, 7.631513611335566, 7.76659513557904, 7.899367063252599, 8.029943959953894, 8.158431221748456, 8.284926070883193, 8.409518416651457, 8.532291603080617, 8.653323061113575, 8.772684879784524, 8.890444308357148, 9.006664199358163, 9.121403400793104, 9.234717104492159, 9.34665715643834, 9.457272334029511, 9.566608594481119, 9.674709297958259, 9.781615408509987, 9.88736567544662, 9.991996797437439, 10.09554357129917, 10.19803902718557, 10.299514551666988, 10.400000000000002, 10.499523798725352, 10.598113039593418, 10.695793565696752, 10.792590050585634, 10.88852607105296, 10.983624174196786, 11.077905939300983, 11.171392035015153, 11.26410227226298, 11.356055653262713, 11.447270417003349, 11.537764081484767, 11.627553482998906, 11.71665481270145, 11.805083650698965, 11.892854997854805, 11.979983305497552, 12.066482503198687, 12.15236602477065, 12.237646832622685, 12.32233744059949, 12.406449935416658, 12.489995996796797, 12.572986916401371, 12.655433615645101, 12.737346662472529, 12.818736287169653, 12.89961239727768, 12.979984591670362, 13.059862173851608, 13.139254164525473, 13.218169313486646, 13.29661611087573, 13.374602797840392, 13.452137376640191, 13.52922762023021, 13.605881081355959, 13.682105101189656, 13.757906817535872, 13.833293172632468, 13.90827092057097, 13.982846634358829, 14.057026712644463, 14.130817386124557, 14.204224723651766, 14.277254638059798, 14.34991289172168, 14.422205101855958, 14.494136745594753], [0.0, 1.4560219778561039, 2.0591260281974004, 2.521904042583699, 2.9120439557122078, 3.255764119219942, 3.5665109000254023, 3.852272056851645, 4.118252056394801, 4.368065933568311, 4.604345773288536, 4.829078587059855, 5.043808085167398, 5.249761899362676, 5.447935388750495, 5.639148871948674, 5.8240879114244155, 6.003332407921454, 6.177378084592201, 6.3466526610489735, 6.511528238439884, 6.672330927044912, 6.82934843158555, 6.982836100038438, 7.1330218000508046, 7.28010988928052, 7.424284477308236, 7.565712127751096, 7.70454411370329, 7.840918313565065, 7.974960814950755, 8.106787279804498, 8.236504112789602, 8.364209466530596, 8.48999411071645, 8.613942186943213, 8.736131867136622, 8.856635930193812, 8.975522268926753, 9.092854337335446, 9.208691546577072, 9.323089616645333, 9.436100889668362, 9.547774609824009, 9.65815717411971, 9.767292357659825, 9.875221516502808, 9.981983770774226, 10.087616170334796, 10.192153844992726, 10.295630140987003, 10.398076745244769, 10.499523798725352, 10.600000000000001, 10.699532700076206, 10.798147989354472, 10.89587077750099, 10.992724866929038, 11.088733020503291, 11.183917024012652, 11.278297743897348, 11.3718951806636, 11.464728518373212, 11.556816170554935, 11.648175822848831, 11.738824472663351, 11.828778466096997, 11.918053532351665, 12.006664815842909, 12.094626906192685, 12.18195386627285, 12.268659258452002, 12.354756169184402, 12.440257232067191, 12.525174649480942, 12.609520212918493, 12.693305322097947, 12.776541002947551, 12.85923792454281, 12.941406415069425, 13.023056476879768, 13.104197800704934, 13.18483977907961, 13.264991519032344, 13.344661854089823, 13.42385935563987, 13.502592343694602, 13.58086889709197, 13.6586968631711, 13.736083866954221, 13.813037319865607, 13.889564428015735, 13.965672200076876, 14.041367454774484, 14.116656828017039, 14.191546779685433, 14.266043600101609, 14.340153416194685, 14.413882197381803, 14.487235761179566, 14.56021977856104, 14.63283977907228], [0.0, 1.469693845669907, 2.078460969082653, 2.5455844122715714, 2.939387691339814, 3.286335345030997, 3.6, 3.8884444190447165, 4.156921938165306, 4.409081537009721, 4.6475800154489, 4.874423042781577, 5.091168824543143, 5.299056519796709, 5.499090833947008, 5.692099788303082, 5.878775382679628, 6.059702963017247, 6.235382907247959, 6.406246951218788, 6.572670690061994, 6.7349832961930955, 6.8934751758456345, 7.0484040746824395, 7.2, 7.348469228349535, 7.493997598078079, 7.636753236814714, 7.776888838089433, 7.914543574963752, 8.049844718999243, 8.182909018191515, 8.313843876330612, 8.442748367682174, 8.56971411425142, 8.694826047713663, 8.818163074019441, 8.939798655450804, 9.059801322324901, 9.178235124467014, 9.2951600308978, 9.410632284814874, 9.524704719832528, 9.637427042525406, 9.748846085563153, 9.859006035092989, 9.96794863550169, 10.075713374248, 10.182337649086286, 10.287856919689348, 10.392304845413264, 10.495713410721542, 10.598113039593418, 10.699532700076206, 10.8, 10.899541274750971, 10.998181667894016, 11.095945205344158, 11.192854863706579, 11.288932633336067, 11.384199576606164, 11.478675881825394, 11.572380913191546, 11.665333257134149, 11.757550765359255, 11.849050594878898, 11.93984924527944, 12.029962593458054, 12.119405926034494, 12.208193969625484, 12.296340919151518, 12.383860464330176, 12.470765814495918, 12.55706972187381, 12.642784503423286, 12.727922061357855, 12.812493902437575, 12.896511156122807, 12.979984591670364, 13.062924634246345, 13.145341380123988, 13.227244611029162, 13.308643807691302, 13.389548162652838, 13.469966592386191, 13.54990774876346, 13.629380029920657, 13.708391590555037, 13.786950351691269, 13.865064009949611, 13.942740046346701, 14.019985734657508, 14.096808149364879, 14.173214173221261, 14.249210504445502, 14.324803663575986, 14.4, 14.474805698177784, 14.54922678357857, 14.623269128344731, 14.69693845669907, 14.770240350109408], [0.0, 1.4832396974191326, 2.0976176963403033, 2.5690465157330262, 2.9664793948382653, 3.3166247903554003, 3.6331804249169903, 3.924283374069717, 4.1952353926806065, 4.449719092257398, 4.69041575982343, 4.919349550499538, 5.1380930314660525, 5.347896782848376, 5.549774770204643, 5.744562646538029, 5.932958789676531, 6.115553940568263, 6.29285308902091, 6.465291950097846, 6.6332495807108005, 6.797058187186572, 6.957010852370435, 7.113367697511497, 7.266360849833981, 7.416198487095664, 7.563068160475615, 7.707139547199078, 7.848566748139434, 7.987490219086344, 8.12403840463596, 8.258329128825032, 8.390470785361213, 8.520563361656318, 8.648699324175862, 8.774964387392123, 8.899438184514796, 9.02219485491197, 9.143303560529969, 9.26282894152753, 9.38083151964686, 9.497368056467014, 9.612491872558333, 9.726253132630262, 9.838699100999076, 9.9498743710662, 10.059821071967434, 10.16857905510893, 10.276186062932105, 10.382677881933928, 10.488088481701517, 10.59245014149229, 10.695793565696752, 10.798147989354472, 10.899541274750971, 11.0, 11.099549540409287, 11.198214143335536, 11.296016997154352, 11.392980294900891, 11.489125293076057, 11.584472366059664, 11.679041056525145, 11.772850122209151, 11.865917579353061, 11.958260743101398, 12.049896265113654, 12.14084016862095, 12.231107881136525, 12.320714265009153, 12.409673645990857, 12.497999839974396, 12.58570617804182, 12.672805529952711, 12.759310326189265, 12.84523257866513, 12.930583900195693, 13.015375522819156, 13.099618315050254, 13.183322798141598, 13.266499161421601, 13.349157276772194, 13.431306712304654, 13.512956745287095, 13.594116374373144, 13.674794331177344, 13.75499909123952, 13.83473888441701, 13.91402170474087, 13.992855319769443, 14.071247279470288, 14.149204924659195, 14.226735395022994, 14.30384563675098, 14.380542409798041, 14.456832294800959, 14.532721699667961, 14.60821686586012, 14.683323874382122, 14.758048651498614, 14.832396974191328, 14.906374475371269], [0.0, 1.4966629547095767, 2.116601048851672, 2.5922962793631443, 2.9933259094191533, 3.3466401061363023, 3.666060555964672, 3.9597979746446663, 4.233202097703344, 4.48998886412873, 4.732863826479693, 4.963869458396343, 5.184592558726289, 5.396295025292817, 5.6, 5.796550698475775, 5.986651818838307, 6.170899448216605, 6.3498031465550175, 6.523802572120037, 6.6932802122726045, 6.858571279792899, 7.019971509913698, 7.177743377970545, 7.332121111929344, 7.483314773547883, 7.631513611335565, 7.776888838089433, 7.919595949289333, 8.059776671843954, 8.197560612767678, 8.333066662399863, 8.466404195406689, 8.597674104081872, 8.726969691708572, 8.854377448471462, 8.97997772825746, 9.103845341392834, 9.226050075736637, 9.346657156438338, 9.465727652959385, 9.583318840568753, 9.699484522385713, 9.814275317108237, 9.927738916792686, 10.039920318408905, 10.150862032359617, 10.260604270704528, 10.369185117452577, 10.476640682967036, 10.583005244258363, 10.688311372709911, 10.792590050585634, 10.89587077750099, 10.998181667894016, 11.099549540409287, 11.2, 11.299557513460428, 11.398245479020007, 11.49608629055993, 11.59310139695155, 11.689311356961966, 11.784735890124987, 11.879393923933998, 11.973303637676613, 12.066482503198683, 12.15894732285653, 12.250714264890844, 12.34179889643321, 12.432216214336043, 12.521980673998822, 12.611106216347556, 12.699606293110035, 12.787493890516624, 12.874781551544864, 12.96148139681572, 13.047605144240073, 13.133164127505603, 13.218169313486646, 13.302631318652713, 13.386560424545209, 13.46996659238619, 13.552859476877934, 13.635248439247448, 13.717142559585797, 13.798550648528272, 13.879481258317979, 13.959942693292119, 14.039943019827396, 14.119490075778232, 14.198591479439077, 14.277254638059798, 14.35548675594109, 14.433294842134973, 14.510685717773644, 14.587666023048374, 14.664242223858688, 14.740420618150624, 14.816207341961707, 14.891608375189028, 14.966629547095765, 15.041276541570534], [0.0, 1.50996688705415, 2.1354156504062622, 2.6153393661244047, 3.0199337741083, 3.3763886032268267, 3.698648401781386, 3.994996871087636, 4.2708313008125245, 4.52990066116245, 4.774934554525329, 5.007993610219566, 5.230678732248809, 5.44426303552648, 5.649778756730214, 5.848076606885378, 6.0398675482166, 6.2257529665093525, 6.406246951218787, 6.581793068761734, 6.752777206453653, 6.919537556802478, 7.0823724838503095, 7.24154679609267, 7.397296803562772, 7.54983443527075, 7.699350621968064, 7.846018098373213, 7.989993742175272, 8.131420540102448, 8.270429251254132, 8.40713982279348, 8.541662601625049, 8.674099376880577, 8.804544281222055, 8.933084573650918, 9.0598013223249, 9.184770002564028, 9.308061022576076, 9.429740187301027, 9.549869109050658, 9.668505572217457, 9.785703858180055, 9.90151503558925, 10.015987220439133, 10.129165809680478, 10.241093691593687, 10.351811435686027, 10.461357464497619, 10.569768209379049, 10.677078252031311, 10.783320453366859, 10.88852607105296, 10.992724866929038, 11.095945205344158, 11.198214143335536, 11.299557513460428, 11.4, 11.499565209172042, 11.598275733918381, 11.696153213770756, 11.793218390244455, 11.889491158161478, 11.984990613262907, 12.0797350964332, 12.17374223482656, 12.267028980156523, 12.3596116443843, 12.451505933018705, 12.542726976220123, 12.633289357883006, 12.723207142855138, 12.812493902437573, 12.90116273829611, 12.989226304903614, 13.076696830622021, 13.163586137523469, 13.24990566004151, 13.335666462535723, 13.420879255846094, 13.505554412907307, 13.58970198348735, 13.67333170810977, 13.756453031214114, 13.839075113604956, 13.921206844235885, 14.002856851371437, 14.084033513166604, 14.164744967700619, 14.244999122499095, 14.324803663575986, 14.404166064024672, 14.48309359218534, 14.561593319413918, 14.63967212747608, 14.717336715588184, 14.794593607125543, 14.871449156017043, 14.947909552843836, 15.023980830658699, 15.0996688705415, 15.174979406905305], [0.0, 1.5231546211727818, 2.1540659228538015, 2.6381811916545845, 3.0463092423455636, 3.405877273185281, 3.7309516212355263, 4.029888335921977, 4.308131845707603, 4.569463863518345, 4.8166378315169185, 5.051732376126036, 5.276362383309169, 5.491812087098393, 5.6991227395100035, 5.8991524815010505, 6.092618484691127, 6.280127387243033, 6.462197768561405, 6.639277069079134, 6.811754546370562, 6.97997134664606, 7.144228439796701, 7.3047929470998705, 7.4619032424710525, 7.6157731058639095, 7.766595135579041, 7.914543574963752, 8.059776671843954, 8.202438661763953, 8.342661445845684, 8.480566018845677, 8.616263691415206, 8.749857141690944, 8.881441324469808, 9.01110426085505, 9.13892772703669, 9.264987857520376, 9.389355675444403, 9.512097560475294, 9.633275663033837, 9.752948272189288, 9.871170143402454, 9.987992791347018, 10.103464752252073, 10.21763181955584, 10.330537256115967, 10.442221985765292, 10.552724766618338, 10.662082348209472, 10.77032961426901, 10.87749971270972, 10.983624174196786, 11.088733020503291, 11.192854863706579, 11.296016997154352, 11.398245479020007, 11.499565209172042, 11.600000000000001, 11.699572641767732, 11.798304963002101, 11.896217886370442, 11.99333148045196, 12.089665007765932, 12.185236969382254, 12.280065146407, 12.374166638606416, 12.46755790040696, 12.560254774486067, 12.65227252314777, 12.743625857659195, 12.834328965707558, 12.92439553712281, 13.013838787997953, 13.10267148332736, 13.19090595827292, 13.278554138158269, 13.365627557282899, 13.452137376640191, 13.53809440061636, 13.623509092741124, 13.708391590555037, 13.792751719653337, 13.876599006961325, 13.95994269329212, 14.042791745233568, 14.125154866407662, 14.207040508142434, 14.288456879593403, 14.369411957348847, 14.449913494550756, 14.529969029560938, 14.609585894199741, 14.688771221582833, 14.767531953579788, 14.845874847916507, 14.923806484942105, 15.001333274079343, 15.078461459976612, 15.15519712837811, 15.231546211727819, 15.307514494521966], [0.0, 1.5362291495737217, 2.172556098240043, 2.6608269391300143, 3.0724582991474434, 3.4351128074635335, 3.7629775444453557, 4.064480286580315, 4.345112196480086, 4.608687448721165, 4.857983120596447, 5.095095681142799, 5.321653878260029, 5.5389529696504916, 5.748043145279965, 5.949789912257406, 6.144916598294887, 6.334035048845246, 6.517668294720129, 6.696267617113283, 6.870225614927067, 7.0398863627192165, 7.205553413860728, 7.367496182557545, 7.525955088890711, 7.681145747868608, 7.833262411026456, 7.982480817390043, 8.12896057316063, 8.272847151978574, 8.41427358718505, 8.553361912137238, 8.690224392960172, 8.824964589164084, 8.957678270623477, 9.08845421400141, 9.21737489744233, 9.344517108978932, 9.469952481401371, 9.593747964169166, 9.715966241192895, 9.836666101886351, 9.955902771722915, 10.07372820757042, 10.190191362285598, 10.3053384223906, 10.419213022104884, 10.531856436545269, 10.643307756520057, 10.75360404701605, 10.862780491200215, 10.970870521521983, 11.077905939300983, 11.183917024012652, 11.288932633336067, 11.392980294900891, 11.49608629055993, 11.598275733918381, 11.699572641767732, 11.799999999999999, 11.899579824514811, 11.998333217576514, 12.09628042002995, 12.193440859740944, 12.289833196589774, 12.385475364312827, 12.480384609458154, 12.574577527694519, 12.668070097690492, 12.760877712759417, 12.853015210447703, 12.944496900227524, 13.035336589440258, 13.125547607623842, 13.215142829345432, 13.30413469565007, 13.392535234226566, 13.480356078383092, 13.567608484917304, 13.654303350958628, 13.740451229854134, 13.826062346163495, 13.911146609823362, 13.995713629536722, 14.079772725438433, 14.163332941084171, 14.246403054806501, 14.328991590478376, 14.411106827721456, 14.492756811593852, 14.573949361789342, 14.654692081377895, 14.73499236511509, 14.814857407346182, 14.894294209528695, 14.973309587395832, 15.051910177781423, 15.130102445125743, 15.207892687680301, 15.285287043428397, 15.362291495737216, 15.438911878756224], [0.0, 1.5491933384829666, 2.1908902300206643, 2.6832815729997477, 3.098386676965933, 3.4641016151377544, 3.794733192202055, 4.098780306383839, 4.381780460041329, 4.6475800154488995, 4.898979485566356, 5.138093031466052, 5.366563145999495, 5.585696017507576, 5.796550698475775, 5.999999999999999, 6.196773353931866, 6.387487769068525, 6.572670690061993, 6.752777206453653, 6.928203230275509, 7.099295739719539, 7.26636084983398, 7.429670248402684, 7.58946638440411, 7.745966692414833, 7.899367063252599, 8.049844718999243, 8.197560612767678, 8.342661445845684, 8.48528137423857, 8.625543461139129, 8.763560920082657, 8.899438184514796, 9.033271832508971, 9.16515138991168, 9.295160030897799, 9.423375191511797, 9.549869109050658, 9.674709297958259, 9.797958971132712, 9.919677414109795, 10.039920318408907, 10.158740079360234, 10.276186062932103, 10.392304845413262, 10.507140429250956, 10.620734437881403, 10.73312629199899, 10.844353369380766, 10.954451150103322, 11.063453348751464, 11.171392035015153, 11.278297743897348, 11.384199576606164, 11.489125293076057, 11.59310139695155, 11.696153213770756, 11.798304963002101, 11.899579824514811, 11.999999999999998, 12.099586769803338, 12.198360545581524, 12.296340919151517, 12.393546707863733, 12.489995996796795, 12.585706178041818, 12.680693987317886, 12.77497553813705, 12.868566353716329, 12.96148139681572, 13.053735097664575, 13.145341380123986, 13.236313686219436, 13.326664999166143, 13.416407864998737, 13.505554412907307, 13.594116374373142, 13.682105101189656, 13.769531582446804, 13.856406460551018, 13.9427400463467, 14.028542333400146, 14.113823011501879, 14.198591479439077, 14.282856857085699, 14.366627996854376, 14.449913494550755, 14.53272169966796, 14.615060725156086, 14.696938456699067, 14.778362561528931, 14.859340496805368, 14.939879517586478, 15.019986684414869, 15.099668870541498, 15.17893276880822, 15.257784898208522, 15.33623161014465, 15.414279094398156, 15.491933384829666, 15.569200364822851], [0.0, 1.5620499351813308, 2.209072203437452, 2.705549851693737, 3.1240998703626617, 3.492849839314596, 3.8262252939417984, 4.132795663954365, 4.418144406874904, 4.686149805543993, 4.9396356140913875, 5.180733538795447, 5.411099703387474, 5.63205113613149, 5.844655678480983, 6.049793384901669, 6.248199740725323, 6.440496875241847, 6.627216610312357, 6.808817812219681, 6.985699678629192, 7.158212067269313, 7.326663633605681, 7.491328320131218, 7.652450587883597, 7.810249675906655, 7.964923100695951, 8.11664955508121, 8.26559132790873, 8.411896337925237, 8.555699854482974, 8.69712596206356, 8.836288813749809, 8.973293709669823, 9.108238029388561, 9.241212041718336, 9.372299611087985, 9.501578816175762, 9.629122493768579, 9.75499871860576, 9.879271228182775, 10.001999800039991, 10.123240587875012, 10.243046421841502, 10.361467077590895, 10.478549517943787, 10.594338110519223, 10.708874824182043, 10.822199406774947, 10.934349546269315, 11.045361017187261, 11.155267813907473, 11.26410227226298, 11.3718951806636, 11.478675881825394, 11.584472366059664, 11.689311356961966, 11.793218390244455, 11.896217886370442, 11.998333217576514, 12.099586769803338, 12.2, 12.299593489217438, 12.398386991863095, 12.496399481450647, 12.59364919314493, 12.690153663372245, 12.785929766739686, 12.880993750483695, 12.975361266646875, 13.069047402163633, 13.162066707018317, 13.254433220624714, 13.346160496562298, 13.43726162579266, 13.527749258468683, 13.617635624439362, 13.706932552544352, 13.79565148878443, 13.883803513446884, 13.971399357258385, 14.058449416631978, 14.14496376806954, 14.230952181776171, 14.316424134538625, 14.401388821915754, 14.485855169785456, 14.569831845289087, 14.653327267211361, 14.736349615830916, 14.818906842274163, 14.901006677402705, 14.982656640262435, 15.063864046120438, 15.144636014114042, 15.224979474534603, 15.304901175767194, 15.384407690905752, 15.463505424062165, 15.542200616386344, 15.62049935181331, 15.698407562552326], [0.0, 1.574801574802362, 2.2271057451320084, 2.727636339397171, 3.149603149604724, 3.521363372331802, 3.857460304397182, 4.166533331199932, 4.454211490264017, 4.724404724407086, 4.979959839195493, 5.223025942880239, 5.455272678794342, 5.678027826631356, 5.892367945062493, 6.099180272790762, 6.299206299209448, 6.49307323229917, 6.681317235396026, 6.864400920692206, 7.042726744663604, 7.216647421067486, 7.386474125047755, 7.552483035399683, 7.714920608794364, 7.874007874011811, 8.029943959953892, 8.182909018191513, 8.333066662399863, 8.480566018845677, 8.625543461139129, 8.76812408671319, 8.908422980528034, 9.046546302318914, 9.182592226599196, 9.316651759081692, 9.448809448814172, 9.579144011862438, 9.707728879609277, 9.834632682515398, 9.959919678390985, 10.083650132764426, 10.20588065773846, 10.326664514740468, 10.446051885760477, 10.564090116995404, 10.680823938254951, 10.796295661012623, 10.910545357588685, 11.023611023616535, 11.135528725660043, 11.24633273560764, 11.356055653262713, 11.464728518373212, 11.572380913191546, 11.679041056525145, 11.784735890124987, 11.889491158161478, 11.99333148045196, 12.09628042002995, 12.198360545581524, 12.299593489217438, 12.399999999999999, 12.499599993599794, 12.598412598418896, 12.696456198483101, 12.79374847337558, 12.890306435457614, 12.98614646459834, 13.081284340614266, 13.175735273600482, 13.269513932318695, 13.362634470792052, 13.455110553243328, 13.546955377500877, 13.638181696985855, 13.728801841384412, 13.81882773609976, 13.908270920570969, 13.997142565538153, 14.085453489327207, 14.17321417322126, 14.26043477598071, 14.347125147568763, 14.433294842134972, 14.51895313030523, 14.604109010822947, 14.688771221582831, 14.77294825009551, 14.85664834341851, 14.939879517586478, 15.022649566571138, 15.104966070799366, 15.186836405255704, 15.268267747193851, 15.349267083479912, 15.429841217588727, 15.509996776273038, 15.58974021592406, 15.669077828640715, 15.748015748023622, 15.826559954709047], [0.0, 1.5874507866387544, 2.244994432064365, 2.7495454169735045, 3.1749015732775088, 3.5496478698597698, 3.8884444190447165, 4.2, 4.48998886412873, 4.762352359916263, 5.019960159204453, 5.264978632435274, 5.499090833947009, 5.723635208501674, 5.939696961966999, 6.148170459575758, 6.3498031465550175, 6.545227268781429, 6.734983296193095, 6.919537556802479, 7.0992957397195395, 7.274613391789285, 7.445804187594514, 7.6131465242697125, 7.776888838089433, 7.937253933193772, 8.094442537939226, 8.248636250920512, 8.4, 8.548684109265006, 8.694826047713663, 8.838551917593742, 8.97997772825746, 9.119210492142399, 9.256349172324908, 9.391485505499118, 9.524704719832526, 9.65608616365865, 9.785703858180055, 9.913626985114984, 10.039920318408907, 10.16464460765845, 10.287856919689348, 10.409610943738484, 10.529957264870548, 10.648943609579309, 10.766615066955817, 10.883014288330234, 10.998181667894018, 11.11215550647128, 11.224972160321824, 11.336666176614711, 11.447270417003349, 11.556816170554935, 11.665333257134149, 11.772850122209151, 11.879393923933998, 11.984990613262907, 12.089665007765932, 12.193440859740944, 12.296340919151517, 12.398386991863095, 12.499599993599794, 12.6, 12.699606293110035, 12.798437404620925, 12.896511156122806, 12.99384469662463, 13.090454537562858, 13.186356585501548, 13.281566172707194, 13.376098085764772, 13.46996659238619, 13.563185466548779, 13.65576801208925, 13.74772708486752, 13.839075113604958, 13.92982411949268, 14.019985734657508, 14.109571219565817, 14.198591479439079, 14.28705707974879, 14.37497826085313, 14.46236495183274, 14.54922678357857, 14.635573101180562, 14.721412975662357, 14.80675521510368, 14.891608375189028, 14.975980769218422, 15.05988047761336, 15.143315356948756, 15.226293048539425, 15.30882098660769, 15.390906406056793, 15.472556349873152, 15.553777676178866, 15.634577064954462, 15.714961024450554, 15.794935897305821, 15.874507866387544, 15.95368296037], [0.0, 1.6, 2.262741699796952, 2.771281292110204, 3.2, 3.577708763999664, 3.9191835884530852, 4.233202097703345, 4.525483399593904, 4.8, 5.059644256269407, 5.30659966456864, 5.542562584220408, 5.768882040742383, 5.986651818838307, 6.196773353931866, 6.4, 6.596969000988257, 6.788225099390856, 6.974238309665079, 7.155417527999328, 7.332121111929345, 7.504665215717488, 7.673330437300352, 7.8383671769061705, 8.0, 8.158431221748456, 8.313843876330612, 8.46640419540669, 8.616263691415208, 8.763560920082657, 8.908422980528035, 9.050966799187808, 9.191300234460847, 9.329523031752482, 9.465727652959385, 9.6, 9.732420048477152, 9.863062404750362, 9.991996797437439, 10.119288512538814, 10.244998779892558, 10.369185117452577, 10.491901638883201, 10.61319932913728, 10.73312629199899, 10.851727973000429, 10.969047360641671, 11.085125168440817, 11.200000000000001, 11.313708498984761, 11.426285485668561, 11.537764081484767, 11.648175822848831, 11.757550765359255, 11.865917579353061, 11.973303637676613, 12.0797350964332, 12.185236969382254, 12.289833196589774, 12.393546707863733, 12.496399481450647, 12.598412598418896, 12.699606293110035, 12.8, 12.899612397277679, 12.998461447417537, 13.096564434995921, 13.193938001976514, 13.29059818066892, 13.386560424545209, 13.481839637082174, 13.576450198781712, 13.67040599250805, 13.763720427268202, 13.85640646055102, 13.948476619330158, 14.039943019827396, 14.130817386124557, 14.221111067704943, 14.310835055998655, 14.4, 14.488616221019868, 14.576693726630879, 14.66424222385869, 14.75127113166862, 14.837789592793127, 14.923806484942105, 15.009330431434975, 15.094369811290566, 15.17893276880822, 15.26302722267113, 15.346660874600705, 15.429841217588729, 15.512575543732254, 15.594870951694341, 15.676734353812341, 15.75817248287377, 15.839191898578665, 15.919798993705921, 16.0, 16.079800993793427], [0.0, 1.6124515496597098, 2.2803508501982757, 2.7928480087537886, 3.2249030993194197, 3.605551275463989, 3.9496835316262997, 4.266145801540308, 4.560701700396551, 4.8373546489791295, 5.0990195135927845, 5.347896782848375, 5.585696017507577, 5.813776741499453, 6.033241251599342, 6.244997998398397, 6.449806198638839, 6.648308055437864, 6.841052550594828, 7.0285133563222315, 7.211102550927978, 7.389181280764467, 7.5630681604756145, 7.733045971672482, 7.899367063252599, 8.06225774829855, 8.221921916437786, 8.378544026261364, 8.532291603080616, 8.683317338436964, 8.831760866327846, 8.977750274985375, 9.121403400793103, 9.262828941527529, 9.402127418834526, 9.539392014169456, 9.674709297958259, 9.808159868191382, 9.939818911831342, 10.069756700139283, 10.198039027185569, 10.324727599312245, 10.449880382090505, 10.57355191030904, 10.69579356569675, 10.816653826391967, 10.936178491593852, 11.054410884348382, 11.171392035015154, 11.287160847617969, 11.40175425099138, 11.515207336387826, 11.627553482998906, 11.738824472663351, 11.849050594878898, 11.958260743101398, 12.066482503198683, 12.17374223482656, 12.280065146407, 12.385475364312827, 12.489995996796795, 12.59364919314493, 12.696456198483101, 12.798437404620925, 12.899612397277679, 12.999999999999998, 13.09961831505025, 13.198484761517133, 13.296616110875728, 13.394028520202575, 13.490737563232042, 13.586758259423032, 13.682105101189656, 13.776792079435618, 13.87083270751976, 13.96424004376894, 14.057026712644463, 14.149204924659195, 14.24078649513432, 14.331782861877304, 14.422205101855956, 14.512063946937388, 14.601369798755185, 14.690132742763081, 14.778362561528933, 14.866068747318506, 14.953260514014994, 15.039946808416577, 15.126136320951229, 15.211837495845133, 15.297058540778353, 15.381807436059, 15.466091943344964, 15.549919613940132, 15.633297796690243, 15.716233645501708, 15.798734126505199, 15.880806024884254, 15.96245595138793, 16.043690348545127, 16.1245154965971, 16.20493751916372], [0.0, 1.624807680927192, 2.2978250586152114, 2.8142494558940583, 3.249615361854384, 3.6331804249169903, 3.97994974842648, 4.298837052040936, 4.595650117230423, 4.874423042781576, 5.138093031466052, 5.388877434122993, 5.628498911788117, 5.858327406350725, 6.079473661428265, 6.292853089020909, 6.499230723708768, 6.699253689777691, 6.8934751758456345, 7.08237248385031, 7.266360849833981, 7.445804187594514, 7.62102355330306, 7.792303895511263, 7.95989949685296, 8.12403840463596, 8.284926070883191, 8.442748367682174, 8.597674104081872, 8.749857141690944, 8.899438184514795, 9.046546302318912, 9.191300234460845, 9.333809511662428, 9.47417542586161, 9.612491872558332, 9.748846085563152, 9.88331928048467, 10.015987220439133, 10.146920715172659, 10.276186062932103, 10.403845442911964, 10.529957264870548, 10.654576481493761, 10.777754868245985, 10.89954127475097, 11.01998185116473, 11.139120252515456, 11.256997823576233, 11.373653766490344, 11.489125293076057, 11.60344776348823, 11.71665481270145, 11.828778466096997, 11.93984924527944, 12.049896265113654, 12.15894732285653, 12.267028980156523, 12.374166638606416, 12.480384609458154, 12.585706178041818, 12.690153663372245, 12.79374847337558, 12.896511156122806, 12.998461447417537, 13.09961831505025, 13.2, 13.299624054837038, 13.398507379555381, 13.496666255042392, 13.594116374373144, 13.690872872099865, 13.786950351691269, 13.882362911262621, 13.977124167724918, 14.071247279470288, 14.16474496770062, 14.257629536497292, 14.34991289172168, 14.441606558828557, 14.532721699667961, 14.62326912834473, 14.713259326199617, 14.802702455970666, 14.891608375189028, 14.979986648859205, 15.06784656146989, 15.155197128378108, 15.24204710660612, 15.328405005087776, 15.414279094398154, 15.49967741599805, 15.584607791022526, 15.669077828640715, 15.753094934012175, 15.836666315863322, 15.91979899370592, 16.002499804718013, 16.08477541030648, 16.166632302368978, 16.24807680927192, 16.32911510156016], [0.0, 1.6370705543744901, 2.315167380558045, 2.8354893757515653, 3.2741411087489802, 3.6606010435446255, 4.009987531152684, 4.331281565541543, 4.63033476111609, 4.91121166312347, 5.176871642217914, 5.429548784199292, 5.670978751503131, 5.902541825349482, 6.125357132445422, 6.340346993658943, 6.5482822174979605, 6.749814812274482, 6.945502141674135, 7.13582510996451, 7.321202087089251, 7.501999733404421, 7.678541528180987, 7.851114570556209, 8.019975062305368, 8.18535277187245, 8.347454701883683, 8.506468127254696, 8.662563131083086, 8.815894736213677, 8.966604708583956, 9.114823092084674, 9.26066952223218, 9.404254356406998, 9.54567965102538, 9.6850400102426, 9.82242332624694, 9.957911427603682, 10.091580649234292, 10.223502335305646, 10.353743284435827, 10.482366145102928, 10.609429767899876, 10.734989520255713, 10.859097568398584, 10.981803130633875, 11.103152705425607, 11.22319027727856, 11.341957503006261, 11.45949388062143, 11.575836902790225, 11.691022196540388, 11.805083650698965, 11.918053532351665, 12.029962593458054, 12.14084016862095, 12.250714264890844, 12.3596116443843, 12.46755790040696, 12.574577527694519, 12.680693987317886, 12.785929766739686, 12.890306435457614, 12.99384469662463, 13.096564434995921, 13.198484761517133, 13.299624054837038, 13.4, 13.499629624548964, 13.59852933224766, 13.696714934611146, 13.794201680416304, 13.89100428334827, 13.98713694792469, 14.082613393827154, 14.177446878757825, 14.27165021992902, 14.365235814284429, 14.458215657542256, 14.550601362143079, 14.642404174178502, 14.73363498937041, 14.824304368165139, 14.914422550001726, 15.003999466808843, 15.093044755780724, 15.181567771478676, 15.269577597301112, 15.357083056361974, 15.444092721814382, 15.53061492665374, 15.616657773031974, 15.702229141112419, 15.78733669749271, 15.871987903221198, 15.956190021430553, 16.039950124610737, 16.12327510154187, 16.206171663906314, 16.288646352597873, 16.3707055437449, 16.45235545446305], [0.0, 1.6492422502470643, 2.33238075793812, 2.8565713714171403, 3.2984845004941286, 3.687817782917155, 4.039801975344831, 4.363484845854286, 4.66476151587624, 4.947726750741192, 5.215361924162119, 5.469917732470938, 5.713142742834281, 5.946427498927402, 6.170899448216605, 6.387487769068525, 6.596969000988257, 6.8, 6.997142273814361, 7.188880302244572, 7.37563556583431, 7.557777451076474, 7.735631842325486, 7.909487973314076, 8.079603950689663, 8.246211251235321, 8.409518416651457, 8.56971411425142, 8.726969691708572, 8.881441324469808, 9.033271832508971, 9.182592226599198, 9.32952303175248, 9.47417542586161, 9.616652224137047, 9.757048734120374, 9.895453501482384, 10.031948963187562, 10.166612021711067, 10.299514551666988, 10.430723848324238, 10.56030302595527, 10.688311372709911, 10.814804667676619, 10.939835464941876, 11.063453348751464, 11.18570516328765, 11.306635220082056, 11.426285485668561, 11.54469575172945, 11.661903789690601, 11.777945491468367, 11.892854997854805, 12.006664815842909, 12.119405926034494, 12.231107881136525, 12.34179889643321, 12.451505933018705, 12.560254774486067, 12.668070097690492, 12.77497553813705, 12.880993750483695, 12.98614646459834, 13.090454537562858, 13.193938001976514, 13.296616110875728, 13.398507379555381, 13.499629624548964, 13.6, 13.699635031634967, 13.798550648528273, 13.896762212832167, 13.994284547628721, 14.091131963046829, 14.187318280774559, 14.2828568570857, 14.377760604489144, 14.472042012100435, 14.565713164826501, 14.658785761446955, 14.75127113166862, 14.84318025222358, 14.934523762075576, 15.025311976794358, 15.115554902152947, 15.20526224699857, 15.29444343544413, 15.383107618423528, 15.471263684650973, 15.558920271021378, 15.646085772486357, 15.73276835143771, 15.818975946628152, 15.904716281656835, 15.98999687304535, 16.074825037928093, 16.159207901379325, 16.243152403397563, 16.32666530556684, 16.40975319741281, 16.492422502470642, 16.57467948408053], [0.0, 1.661324772583615, 2.349468024894146, 2.8774989139876324, 3.32264954516723, 3.7148351242013424, 4.069397989875161, 4.3954521951671826, 4.698936049788292, 4.983974317750845, 5.253570214625479, 5.509990925582365, 5.754997827975265, 5.989991652748776, 6.216108107168021, 6.434283176858164, 6.64529909033446, 6.849817515817484, 7.048404074682439, 7.2415467960926705, 7.429670248402685, 7.6131465242697125, 7.792303895511263, 7.967433714816837, 8.138795979750322, 8.306623862918075, 8.47112743381895, 8.632496741962896, 8.790904390334365, 8.946507698538017, 9.09945053286186, 9.249864863877743, 9.397872099576585, 9.54358423235212, 9.687104830649869, 9.828529900244492, 9.96794863550169, 10.105444077327824, 10.241093691593687, 10.374969879474351, 10.507140429250958, 10.637668917577761, 10.766615066955818, 10.894035065117057, 11.01998185116473, 11.144505372604025, 11.26765281680262, 11.38946881992308, 11.50999565595053, 11.629273408085306, 11.747340124470732, 11.864231959971114, 11.979983305497552, 12.094626906192685, 12.208193969625484, 12.320714265009153, 12.432216214336043, 12.542726976220123, 12.65227252314777, 12.760877712759417, 12.868566353716329, 12.975361266646875, 13.081284340614266, 13.186356585501548, 13.29059818066892, 13.394028520202575, 13.496666255042392, 13.59852933224766, 13.699635031634967, 13.8, 13.899640283115245, 13.998571355677694, 14.096808149364877, 14.194365079143202, 14.291256067959877, 14.38749456993816, 14.483093592185341, 14.578065715313539, 14.672423112764983, 14.766177569025778, 14.85934049680537, 14.951922953252536, 15.043935655273193, 15.135388994010032, 15.226293048539425, 15.316657598836635, 15.406492138056606, 15.49580588417395, 15.584607791022526, 15.672906558772052, 15.760710643876436, 15.848028268526026, 15.934867429633673, 16.02123590738243, 16.10714127336071, 16.192590898309017, 16.277591959500644, 16.36215144777728, 16.446276174259022, 16.529972776747094, 16.61324772583615, 16.69610733075228], [0.0, 1.6733200530681511, 2.3664319132398464, 2.8982753492378883, 3.3466401061363023, 3.7416573867739418, 4.09878030638384, 4.427188724235731, 4.732863826479693, 5.019960159204453, 5.291502622129181, 5.549774770204644, 5.796550698475777, 6.033241251599343, 6.260990336999411, 6.48074069840786, 6.6932802122726045, 6.899275324264137, 7.0992957397195395, 7.293833011524189, 7.4833147735478835, 7.668115805072326, 7.848566748139434, 8.024961059095553, 8.19756061276768, 8.366600265340756, 8.532291603080617, 8.694826047713665, 8.854377448471462, 9.01110426085505, 9.16515138991168, 9.316651759081694, 9.465727652959385, 9.612491872558333, 9.757048734120374, 9.899494936611665, 10.039920318408907, 10.178408519999579, 10.315037566582102, 10.449880382090507, 10.583005244258363, 10.7144761887831, 10.84435336938077, 10.972693379476162, 11.099549540409289, 11.224972160321824, 11.349008767288886, 11.47170431975999, 11.593101396951553, 11.713240371477058, 11.832159566199234, 11.949895397031726, 12.066482503198687, 12.18195386627285, 12.296340919151518, 12.409673645990857, 12.521980673998822, 12.633289357883006, 12.743625857659195, 12.853015210447703, 12.96148139681572, 13.069047402163633, 13.175735273600482, 13.281566172707194, 13.386560424545209, 13.490737563232042, 13.594116374373144, 13.696714934611146, 13.798550648528273, 13.899640283115245, 14.000000000000002, 14.099645385611653, 14.198591479439079, 14.296852800529214, 14.394443372357266, 14.49137674618944, 14.587666023048378, 14.683323874382124, 14.778362561528935, 14.872793954062567, 14.966629547095767, 15.059880477613362, 15.15255753990065, 15.244671200127604, 15.336231610144653, 15.427248620541514, 15.51773179301666, 15.607690412101338, 15.697133496278868, 15.786069808536892, 15.874507866387544, 15.962455951387932, 16.049922118191105, 16.13691420315545, 16.2234398325386, 16.30950643030009, 16.39512122553536, 16.480291259562133, 16.565023392678924, 16.64932431061393, 16.73320053068151, 16.816658407662327], [0.0, 1.6852299546352718, 2.3832750575625967, 2.918903903865285, 3.3704599092705436, 3.768288736283355, 4.127953488110059, 4.458699361921591, 4.766550115125193, 5.0556898639058145, 5.329165037789691, 5.589275444992849, 5.83780780773057, 6.076183012385325, 6.305553108173778, 6.526867548832287, 6.740919818541087, 6.948381106416083, 7.149825172687791, 7.345747068882784, 7.53657747256671, 7.72269383052313, 7.904429138147802, 8.082078940470701, 8.255906976220118, 8.426149773176359, 8.593020423576334, 8.756711711595855, 8.917398723843181, 9.075241043630742, 9.23038460737146, 9.38296328459192, 9.533100230250387, 9.680909048224759, 9.826494797230598, 9.969954864491614, 10.111379727811629, 10.250853622991599, 10.388455130576443, 10.524257693538296, 10.658330075579382, 10.79073676817297, 10.92153835318084, 11.050791826833043, 11.178550889985697, 11.304866208850061, 11.42978564978364, 11.553354491228944, 11.67561561546114, 11.796609682446903, 11.916375287812986, 12.034949106664309, 12.15236602477065, 12.268659258452002, 12.383860464330176, 12.497999839974396, 12.611106216347556, 12.723207142855138, 12.834328965707558, 12.944496900227524, 13.053735097664575, 13.162066707018317, 13.269513932318695, 13.376098085764772, 13.481839637082174, 13.586758259423032, 13.690872872099865, 13.794201680416304, 13.896762212832167, 13.998571355677694, 14.099645385611653, 14.2, 14.299650345375582, 14.398611044125055, 14.496896219536097, 14.594519519326424, 14.691494137765568, 14.787832836490951, 14.883547964111248, 14.978651474682225, 15.07315494513342, 15.167069591717446, 15.260406285548234, 15.353175567289002, 15.44538766104626, 15.537052487521564, 15.628179676469042, 15.718778578502848, 15.808858276295604, 15.898427595205758, 15.987495113369073, 16.076069171286868, 16.164157880941403, 16.251769134466564, 16.33891061240008, 16.425589791541732, 16.511813952440235, 16.597590186530095, 16.682925402938178, 16.767826334978544, 16.852299546352718, 16.936351437071682], [0.0, 1.697056274847714, 2.4, 2.9393876913398143, 3.394112549695428, 3.7947331922020555, 4.156921938165306, 4.48998886412873, 4.8, 5.091168824543142, 5.366563145999495, 5.628498911788116, 5.8787753826796285, 6.118823416311343, 6.3498031465550175, 6.572670690061993, 6.788225099390856, 6.997142273814361, 7.2, 7.397296803562773, 7.589466384404111, 7.776888838089433, 7.95989949685296, 8.138795979750322, 8.313843876330612, 8.485281374238571, 8.653323061113575, 8.818163074019441, 8.97997772825746, 9.138927727036691, 9.2951600308978, 9.448809448814174, 9.6, 9.748846085563153, 9.895453501482386, 10.039920318408907, 10.182337649086284, 10.322790320451153, 10.461357464497617, 10.598113039593418, 10.73312629199899, 10.8664621657649, 10.998181667894016, 11.128342194594843, 11.256997823576231, 11.384199576606164, 11.509995655950528, 11.63443165779919, 11.757550765359257, 11.879393923933998, 12.0, 12.119405926034496, 12.237646832622685, 12.354756169184402, 12.470765814495918, 12.58570617804182, 12.699606293110035, 12.812493902437573, 12.92439553712281, 13.035336589440258, 13.145341380123986, 13.254433220624714, 13.362634470792052, 13.46996659238619, 13.576450198781712, 13.682105101189656, 13.786950351691269, 13.89100428334827, 13.994284547628721, 14.096808149364877, 14.198591479439079, 14.299650345375582, 14.4, 14.499655168313486, 14.598630072715727, 14.696938456699069, 14.794593607125545, 14.891608375189028, 14.987995196156158, 15.083766107971842, 15.178932768808222, 15.273506473629427, 15.36749816983884, 15.46091847207015, 15.553777676178866, 15.646085772486359, 15.737852458324802, 15.829087149927505, 15.91979899370592, 16.0099968769516, 16.099689437998485, 16.18888507587845, 16.277591959500644, 16.36581803638303, 16.453571040962508, 16.540858502508264, 16.627687752661224, 16.714065932620944, 16.8, 16.88549673536435, 16.970562748477143, 17.055204484262276], [0.0, 1.7088007490635062, 2.4166091947189146, 2.9597297173897488, 3.4176014981270124, 3.82099463490856, 4.18568990729127, 4.521061822182926, 4.833218389437829, 5.126402247190518, 5.403702434442518, 5.667450926121902, 5.9194594347794975, 6.161168720299745, 6.393746945258312, 6.618156843109718, 6.835202996254025, 7.045565981523414, 7.249827584156743, 7.448489779814429, 7.64198926981712, 7.830708780180758, 8.014985963805552, 8.195120499419152, 8.37137981458254, 8.544003745317532, 8.713208364316786, 8.879189152169246, 9.042123644365851, 9.202173656261873, 9.359487165438072, 9.514199913813037, 9.666436778875658, 9.816312953446422, 9.96393496566492, 10.10940156488009, 10.252804494381037, 10.394229168149026, 10.533755265810955, 10.671457257563281, 10.807404868885037, 10.941663493271944, 11.074294559925702, 11.20535586226515, 11.334901852243805, 11.462983904725679, 11.589650555560336, 11.714947716485977, 11.838918869558995, 11.961605243444543, 12.083045973594572, 12.203278248077442, 12.32233744059949, 12.440257232067191, 12.55706972187381, 12.672805529952711, 12.787493890516624, 12.90116273829611, 13.013838787997953, 13.125547607623842, 13.236313686219436, 13.346160496562298, 13.455110553243328, 13.563185466548779, 13.67040599250805, 13.776792079435618, 13.882362911262621, 13.98713694792469, 14.091131963046829, 14.194365079143202, 14.296852800529214, 14.398611044125055, 14.499655168313486, 14.6, 14.699659860010366, 14.798648586948742, 14.896979559628859, 14.994665718181249, 15.091719583930788, 15.188153278130953, 15.28397853963424, 15.379206741571556, 15.473848907107762, 15.567915724335098, 15.661417560361516, 15.754364474646383, 15.846766231632245, 15.938632312717425, 16.029971927611104, 16.12079402510931, 16.211107303327555, 16.300920219423197, 16.390240998838305, 16.479077644091614, 16.56743794314619, 16.655329477377503, 16.74275962916508, 16.829735589129143, 16.9162643630324, 17.002352778365704, 17.088007490635064, 17.17323498936645], [0.0, 1.7204650534085253, 2.4331050121192876, 2.979932885150268, 3.4409301068170506, 3.847076812334269, 4.214261501141095, 4.551922670696417, 4.866210024238575, 5.161395160225576, 5.440588203494177, 5.706137047074843, 5.959865770300536, 6.203224967708329, 6.437390775772432, 6.663332499583071, 6.881860213634101, 7.093659140387279, 7.299315036357863, 7.49933330370107, 7.694153624668538, 7.884161337770809, 8.069696400732806, 8.251060537894508, 8.42852300228219, 8.602325267042627, 8.772684879784524, 8.939798655450804, 9.103845341392834, 9.264987857520376, 9.423375191511797, 9.579144011862438, 9.73242004847715, 9.88331928048467, 10.031948963187562, 10.178408519999577, 10.322790320451151, 10.465180361560904, 10.605658866850282, 10.744300814850634, 10.881176406988354, 11.01635148313633, 11.149887891813083, 11.281843820936361, 11.412274094149685, 11.541230437002806, 11.668761716651858, 11.794914158229384, 11.919731540601072, 12.043255373859678, 12.165525060596439, 12.286578042726136, 12.406449935416658, 12.525174649480942, 12.642784503423286, 12.759310326189265, 12.874781551544864, 12.989226304903614, 13.10267148332736, 13.215142829345432, 13.326664999166143, 13.43726162579266, 13.546955377500877, 13.65576801208925, 13.763720427268202, 13.87083270751976, 13.977124167724918, 14.082613393827154, 14.187318280774559, 14.291256067959877, 14.394443372357266, 14.496896219536097, 14.598630072715727, 14.699659860010366, 14.799999999999999, 14.89966442575134, 14.99866660740214, 15.097019573412496, 15.194735930578064, 15.291827882892221, 15.388307249337076, 15.484185480676729, 15.579473675320358, 15.674182594317317, 15.768322675541619, 15.861904047118681, 15.954936540143304, 16.047429700734007, 16.13939280146561, 16.230834852218784, 16.321764610482532, 16.412190591142913, 16.502121075789017, 16.59156412156491, 16.680527569594435, 16.769019053003664, 16.85704600456438, 16.94461566398011, 17.031735084835013, 17.118411141224527, 17.204650534085253, 17.29045979724079], [0.0, 1.7320508075688774, 2.449489742783178, 3.0000000000000004, 3.464101615137755, 3.872983346207417, 4.242640687119286, 4.58257569495584, 4.898979485566356, 5.196152422706632, 5.477225575051661, 5.7445626465380295, 6.000000000000001, 6.244997998398398, 6.48074069840786, 6.7082039324993685, 6.92820323027551, 7.14142842854285, 7.3484692283495345, 7.549834435270751, 7.745966692414834, 7.937253933193772, 8.12403840463596, 8.306623862918075, 8.485281374238571, 8.660254037844387, 8.831760866327848, 9.0, 9.16515138991168, 9.327379053088816, 9.486832980505138, 9.643650760992955, 9.797958971132712, 9.949874371066201, 10.099504938362077, 10.246950765959598, 10.392304845413264, 10.53565375285274, 10.677078252031311, 10.816653826391969, 10.954451150103322, 11.090536506409418, 11.224972160321824, 11.357816691600547, 11.489125293076059, 11.61895003862225, 11.747340124470732, 11.874342087037917, 12.000000000000002, 12.12435565298214, 12.247448713915892, 12.369316876852983, 12.489995996796797, 12.609520212918493, 12.727922061357855, 12.84523257866513, 12.96148139681572, 13.076696830622021, 13.19090595827292, 13.30413469565007, 13.416407864998737, 13.527749258468683, 13.638181696985855, 13.74772708486752, 13.85640646055102, 13.96424004376894, 14.071247279470288, 14.177446878757825, 14.2828568570857, 14.38749456993816, 14.49137674618944, 14.594519519326424, 14.696938456699069, 14.798648586948742, 14.89966442575134, 15.0, 15.099668870541501, 15.198684153570664, 15.297058540778357, 15.394804318340654, 15.491933384829668, 15.588457268119896, 15.684387141358124, 15.7797338380595, 15.874507866387544, 15.968719422671313, 16.06237840420901, 16.155494421403514, 16.24807680927192, 16.34013463836819, 16.431676725154983, 16.522711641858308, 16.61324772583615, 16.703293088490067, 16.792855623746668, 16.88194301613413, 16.970562748477143, 17.058722109231983, 17.146428199482248, 17.233687939614086, 17.320508075688775, 17.406895185529212], [0.0, 1.7435595774162698, 2.4657656011875906, 3.0199337741083006, 3.4871191548325395, 3.8987177379235862, 4.270831300812525, 4.613025037868319, 4.931531202375181, 5.230678732248808, 5.513619500836089, 5.782732917920385, 6.039867548216601, 6.2864934582006855, 6.523802572120037, 6.752777206453653, 6.974238309665079, 7.188880302244572, 7.397296803562773, 7.600000000000001, 7.7974354758471724, 7.9899937421752725, 8.178019320104351, 8.36181798414675, 8.54166260162505, 8.717797887081348, 8.89044430835715, 9.059801322324901, 9.226050075736637, 9.389355675444403, 9.549869109050658, 9.707728879609279, 9.863062404750362, 10.015987220439133, 10.16661202171107, 10.315037566582102, 10.461357464497617, 10.605658866850284, 10.748023074035524, 10.888526071052961, 11.027239001672179, 11.164228589562292, 11.29955751346043, 11.433284742365162, 11.56546583584077, 11.696153213770756, 11.825396399275588, 11.95324223798715, 12.079735096433202, 12.204917041913887, 12.328828005937956, 12.451505933018707, 12.572986916401371, 12.693305322097947, 12.812493902437575, 12.930583900195693, 13.047605144240073, 13.163586137523469, 13.278554138158269, 13.392535234226566, 13.505554412907307, 13.617635624439362, 13.728801841384412, 13.839075113604958, 13.948476619330158, 14.057026712644463, 14.16474496770062, 14.27165021992902, 14.377760604489144, 14.483093592185341, 14.587666023048378, 14.691494137765568, 14.794593607125545, 14.896979559628859, 14.99866660740214, 15.099668870541501, 15.200000000000003, 15.299673199124223, 15.398701243936129, 15.497096502248416, 15.594870951694345, 15.692036196746427, 15.788603484792445, 15.884583721331826, 15.979987484350545, 16.074825037928097, 16.169106345126192, 16.2628410802049, 16.356038640208702, 16.448708155961672, 16.540858502508268, 16.632498309033434, 16.7236359682935, 16.814279645586964, 16.904437287292353, 16.994116628998402, 17.0833252032501, 17.172070346932546, 17.260359208313137, 17.348198753761157, 17.435595774162696, 17.52255689104761], [0.0, 1.7549928774784245, 2.4819347291981715, 3.039736830714133, 3.509985754956849, 3.924283374069717, 4.298837052040936, 4.64327470649756, 4.963869458396343, 5.264978632435273, 5.549774770204643, 5.8206528843421, 6.079473661428266, 6.327716807822551, 6.566582063752802, 6.797058187186571, 7.019971509913698, 7.236021006050217, 7.445804187594514, 7.649836599562112, 7.848566748139434, 8.04238770515324, 8.231646250902672, 8.416650165000327, 8.597674104081872, 8.774964387392123, 8.948742928478838, 9.119210492142399, 9.28654941299512, 9.450925880568528, 9.612491872558332, 9.771386800244887, 9.927738916792686, 10.081666528902849, 10.233279044372825, 10.382677881933928, 10.529957264870546, 10.675204916066015, 10.818502669038818, 10.959927007056207, 11.099549540409287, 11.23743743030412, 11.373653766490346, 11.508257904652641, 11.6413057686842, 11.77285012220915, 11.90294081309321, 12.031624994156028, 12.158947322856532, 12.284950142348972, 12.409673645990857, 12.533156027114641, 12.655433615645101, 12.776541002947551, 12.896511156122807, 13.015375522819156, 13.133164127505603, 13.24990566004151, 13.365627557282899, 13.480356078383092, 13.594116374373142, 13.706932552544352, 13.81882773609976, 13.92982411949268, 14.039943019827396, 14.149204924659195, 14.257629536497292, 14.365235814284429, 14.472042012100435, 14.578065715313539, 14.683323874382124, 14.787832836490951, 14.891608375189028, 14.994665718181249, 15.097019573412496, 15.198684153570664, 15.299673199124223, 15.4, 15.499677415998052, 15.598717896032355, 15.697133496278868, 15.794935897305821, 15.892136420255147, 15.988746042138514, 16.08477541030648, 16.180234856144704, 16.275134408047144, 16.369483803712324, 16.463292501805345, 16.556569693025182, 16.64932431061393, 16.741565040341957, 16.833300330000654, 16.924538398432023, 17.015287244122565, 17.10555465338672, 17.195348208163743, 17.28467529344998, 17.3735431043872, 17.4619586530263, 17.549928774784245, 17.63746013461122], [0.0, 1.7663521732655696, 2.4979991993593593, 3.0594117081556718, 3.532704346531139, 3.9496835316263006, 4.3266615305567875, 4.67332857821917, 4.995998398718719, 5.299056519796709, 5.585696017507577, 5.858327406350725, 6.1188234163113435, 6.3686733312362644, 6.609084656743323, 6.841052550594828, 7.065408693062278, 7.282856582413251, 7.493997598078079, 7.6993506219680645, 7.899367063252601, 8.094442537939226, 8.284926070883193, 8.47112743381895, 8.653323061113575, 8.831760866327848, 9.006664199358164, 9.178235124467015, 9.34665715643834, 9.512097560475294, 9.67470929795826, 9.834632682515398, 9.991996797437437, 10.14692071517266, 10.299514551666988, 10.449880382090507, 10.598113039593418, 10.744300814850636, 10.888526071052961, 11.030865786510144, 11.171392035015154, 11.310172412478956, 11.44727041700335, 11.582745788456208, 11.71665481270145, 11.8490505948789, 11.979983305497552, 12.109500402576485, 12.237646832622687, 12.364465212858986, 12.489995996796798, 12.614277624977186, 12.737346662472529, 12.85923792454281, 12.979984591670364, 13.099618315050254, 13.218169313486646, 13.335666462535723, 13.452137376640191, 13.567608484917304, 13.682105101189656, 13.79565148878443, 13.908270920570969, 14.019985734657508, 14.130817386124557, 14.24078649513432, 14.34991289172168, 14.458215657542256, 14.565713164826501, 14.672423112764983, 14.778362561528935, 14.883547964111248, 14.987995196156158, 15.091719583930788, 15.194735930578064, 15.297058540778357, 15.398701243936129, 15.499677415998052, 15.600000000000003, 15.699681525432293, 15.798734126505202, 15.897169559390127, 15.994999218505768, 16.092234151913154, 16.188885075878453, 16.284962388657828, 16.38047618355462, 16.47543626129518, 16.569852141766386, 16.66373307515456, 16.757088052522732, 16.849925815860438, 16.9422548676379, 17.034083479894072, 17.12541970288612, 17.216271373325874, 17.30664612222715, 17.39655138238611, 17.485994395515515, 17.574982219052174, 17.663521732655695, 17.751619644415552], [0.0, 1.7776388834631178, 2.513961017995307, 3.078960863668131, 3.5552777669262356, 3.9749213828703587, 4.354308211415448, 4.703190406521939, 5.027922035990614, 5.332916650389353, 5.621387729022079, 5.895761189193471, 6.157921727336262, 6.409368143584826, 6.6513156593263565, 6.884765791223402, 7.110555533852471, 7.329392880723478, 7.541883053985921, 7.748548251124208, 7.949842765740717, 8.14616474176652, 8.337865434270332, 8.525256594378847, 8.708616422830897, 8.88819441731559, 9.064215354899728, 9.236882591004392, 9.406380813043878, 9.572878355019457, 9.736529155710468, 9.897474425326898, 10.055844071981229, 10.211757928975796, 10.365326815879952, 10.516653460107925, 10.665833300778706, 10.812955192730618, 10.95810202544218, 11.101351269102336, 11.242775458044157, 11.382442620105758, 11.520416659131737, 11.656757696718243, 11.791522378386942, 11.924764148611073, 12.05653349848123, 12.1868781892657, 12.315843454672525, 12.443472184241825, 12.569805089976535, 12.694880858046682, 12.818736287169653, 12.941406415069425, 13.062924634246345, 13.183322798141598, 13.302631318652713, 13.420879255846094, 13.53809440061636, 13.654303350958628, 13.769531582446804, 13.883803513446884, 13.997142565538153, 14.109571219565817, 14.221111067704943, 14.331782861877304, 14.441606558828557, 14.550601362143079, 14.658785761446955, 14.766177569025778, 14.872793954062567, 14.978651474682225, 15.083766107971842, 15.188153278130953, 15.291827882892221, 15.394804318340654, 15.497096502248416, 15.598717896032355, 15.699681525432293, 15.8, 15.899685531481435, 15.998749951168062, 16.09720472628711, 16.195060975494968, 16.29232948353304, 16.389020715100706, 16.485144827995903, 16.580711685570076, 16.675730868540665, 16.770211686201222, 16.864163187066236, 16.957594168985175, 17.050513188757694, 17.142928571279764, 17.23484841824842, 17.326280616450838, 17.417232845661793, 17.507712586171845, 17.59772712596715, 17.687283567580412, 17.77638883463118, 17.86504967807255], [0.0, 1.788854381999832, 2.5298221281347035, 3.098386676965934, 3.577708763999664, 4.000000000000001, 4.3817804600413295, 4.732863826479694, 5.059644256269407, 5.366563145999495, 5.656854249492381, 5.9329587896765315, 6.196773353931868, 6.44980619863884, 6.6932802122726045, 6.928203230275509, 7.155417527999328, 7.37563556583431, 7.589466384404111, 7.7974354758471724, 8.000000000000002, 8.19756061276768, 8.390470785361213, 8.579044235810889, 8.763560920082659, 8.94427190999916, 9.121403400793104, 9.295160030897803, 9.465727652959387, 9.633275663033837, 9.797958971132713, 9.959919678390987, 10.119288512538814, 10.276186062932105, 10.43072384832424, 10.583005244258363, 10.73312629199899, 10.881176406988356, 11.027239001672179, 11.171392035015154, 11.313708498984761, 11.454256850621084, 11.593101396951553, 11.730302638892145, 11.865917579353063, 12.0, 12.132600710482482, 12.263767773404714, 12.393546707863736, 12.521980673998824, 12.649110640673518, 12.774975538137053, 12.89961239727768, 13.023056476879768, 13.145341380123988, 13.266499161421601, 13.386560424545209, 13.505554412907307, 13.623509092741124, 13.740451229854134, 13.856406460551018, 13.971399357258385, 14.085453489327207, 14.198591479439079, 14.310835055998655, 14.422205101855956, 14.532721699667961, 14.642404174178502, 14.75127113166862, 14.85934049680537, 14.966629547095767, 15.07315494513342, 15.178932768808222, 15.28397853963424, 15.388307249337076, 15.491933384829668, 15.594870951694345, 15.697133496278868, 15.798734126505202, 15.899685531481435, 16.000000000000004, 16.09968943799849, 16.19876538505327, 16.29723902997069, 16.39512122553536, 16.492422502470642, 16.58915308266218, 16.68532289169137, 16.780941570722426, 16.87601848778319, 16.970562748477143, 17.064583206161235, 17.158088471621777, 17.25108692227826, 17.343586710943043, 17.435595774162696, 17.527121840165318, 17.618172436436197, 17.708754896942924, 17.798876369029593, 17.88854381999832, 17.97776404339539], [0.0, 1.8, 2.545584412271571, 3.1176914536239795, 3.6, 4.024922359499622, 4.409081537009721, 4.762352359916263, 5.091168824543142, 5.4, 5.692099788303083, 5.969924622639721, 6.235382907247959, 6.489992295835181, 6.734983296193095, 6.97137002317335, 7.2, 7.42159012611179, 7.636753236814713, 7.8460180983732135, 8.049844718999244, 8.248636250920512, 8.442748367682174, 8.632496741962896, 8.818163074019441, 9.000000000000002, 9.178235124467014, 9.353074360871938, 9.524704719832526, 9.693296652842108, 9.85900603509299, 10.02197585309404, 10.182337649086284, 10.340212763768452, 10.495713410721542, 10.648943609579309, 10.8, 10.948972554536796, 11.095945205344158, 11.240996397117119, 11.384199576606166, 11.52562362737913, 11.66533325713415, 11.8033893437436, 11.939849245279442, 12.074767078498864, 12.208193969625484, 12.34017828072188, 12.470765814495918, 12.600000000000001, 12.727922061357857, 12.854571171377131, 12.979984591670362, 13.104197800704934, 13.227244611029162, 13.349157276772194, 13.46996659238619, 13.58970198348735, 13.708391590555037, 13.826062346163495, 13.9427400463467, 14.058449416631978, 14.17321417322126, 14.28705707974879, 14.4, 14.512063946937388, 14.62326912834473, 14.73363498937041, 14.84318025222358, 14.951922953252536, 15.059880477613362, 15.167069591717446, 15.273506473629427, 15.379206741571556, 15.484185480676729, 15.588457268119896, 15.692036196746427, 15.794935897305821, 15.897169559390127, 15.998749951168062, 16.09968943799849, 16.200000000000003, 16.29969324864735, 16.39878044245974, 16.497272501841024, 16.5951800231272, 16.69251329189227, 16.789282295559868, 16.88549673536435, 16.981166037701886, 17.07629936490925, 17.17090562550502, 17.264993483925792, 17.35857136978732, 17.451647486698786, 17.544229820656135, 17.636326148038883, 17.72794404323299, 17.819090885900998, 17.90977386791916, 18.000000000000004, 18.089776118017607], [0.0, 1.8110770276274835, 2.5612496949731396, 3.136877428271625, 3.622154055254967, 4.049691346263318, 4.436214602563767, 4.791659420284376, 5.122499389946279, 5.43323108288245, 5.727128425310542, 6.006662967072484, 6.27375485654325, 6.529931086925804, 6.776429738438967, 7.014271166700073, 7.244308110509934, 7.467261881037788, 7.68374908491942, 7.894301742396222, 8.099382692526635, 8.299397568498573, 8.494704232638123, 8.685620300243388, 8.872429205127535, 9.055385138137417, 9.234717104492159, 9.410632284814875, 9.583318840568753, 9.752948272189288, 9.919677414109795, 10.083650132764426, 10.244998779892558, 10.403845442911964, 10.56030302595527, 10.7144761887831, 10.8664621657649, 11.016351483136331, 11.164228589562292, 11.310172412478956, 11.454256850621084, 11.596551211459381, 11.73712060089697, 11.876026271442818, 12.013325934144968, 12.149074038789953, 12.283322026227271, 12.416118556135006, 12.5475097130865, 12.677539193392384, 12.806248474865699, 12.933676971379796, 13.059862173851608, 13.18483977907961, 13.308643807691302, 13.431306712304654, 13.552859476877934, 13.67333170810977, 13.792751719653337, 13.911146609823362, 14.028542333400146, 14.14496376806954, 14.26043477598071, 14.37497826085313, 14.488616221019868, 14.601369798755185, 14.713259326199617, 14.824304368165139, 14.934523762075576, 15.043935655273193, 15.15255753990065, 15.260406285548234, 15.36749816983884, 15.473848907107762, 15.579473675320358, 15.684387141358124, 15.788603484792445, 15.892136420255147, 15.994999218505768, 16.09720472628711, 16.19876538505327, 16.29969324864735, 16.400000000000002, 16.49969696691427, 16.598795136997147, 16.697305171793445, 16.795237420173617, 16.892601931022945, 16.989408465276245, 17.085666507338836, 17.181385275931625, 17.276573734395374, 17.371240600486775, 17.465394355696642, 17.55904325411838, 17.652195330892983, 17.74485841025507, 17.837040113202644, 17.928747864811978, 18.019988901217452, 18.110770276274835, 18.201098867925534], [0.0, 1.8220867158288598, 2.576819745345025, 3.1559467676119004, 3.6441734316577197, 4.0743097574926725, 4.463182720884279, 4.82078831727758, 5.15363949069005, 5.466260147486579, 5.761944116355173, 6.043177971895251, 6.311893535223801, 6.569627082262737, 6.817624219623724, 7.056911505750939, 7.288346863315439, 7.512655988397179, 7.730459236035075, 7.942291860665913, 8.148619514985345, 8.349850298059241, 8.546344247688598, 8.738420909981391, 8.926365441768558, 9.1104335791443, 9.290855719469548, 9.4678403028357, 9.64157663455516, 9.812237257628864, 9.979979959899719, 10.144949482377918, 10.3072789813801, 10.46709128650362, 10.62449998823474, 10.779610382569492, 10.932520294973157, 11.083320801997928, 11.232096865679178, 11.37892789325954, 11.523888232710346, 11.667047612828192, 11.80847153530041, 11.948221624995076, 12.086355943790503, 12.222929272478016, 12.357993364620325, 12.491597175701752, 12.623787070447602, 12.754607010802019, 12.884098726725126, 13.012301871690498, 13.139254164525473, 13.264991519032344, 13.389548162652838, 13.512956745287095, 13.635248439247448, 13.756453031214114, 13.876599006961325, 13.995713629536722, 14.113823011501879, 14.230952181776171, 14.347125147568763, 14.46236495183274, 14.576693726630879, 14.690132742763081, 14.802702455970666, 14.914422550001726, 15.025311976794358, 15.135388994010032, 15.244671200127604, 15.353175567289002, 15.46091847207015, 15.567915724335098, 15.674182594317317, 15.7797338380595, 15.884583721331826, 15.988746042138514, 16.092234151913154, 16.195060975494968, 16.29723902997069, 16.39878044245974, 16.49969696691427, 16.599999999999998, 16.699700596118483, 16.798809481626964, 16.89733706830754, 16.9952934661335, 17.092688495377196, 17.189531698100446, 17.28583234906552, 17.381599466102077, 17.476841819962782, 17.57156794369814, 17.66578614157887, 17.759504497592268, 17.852730883537117, 17.94547296674011, 18.037738217415175, 18.129533915685755, 18.2208671582886, 18.311744864976685], [0.0, 1.8330302779823362, 2.5922962793631443, 3.174901573277509, 3.6660605559646724, 4.09878030638384, 4.48998886412873, 4.849742261192857, 5.184592558726289, 5.499090833947008, 5.796550698475776, 6.079473661428266, 6.349803146555018, 6.609084656743323, 6.858571279792899, 7.099295739719539, 7.332121111929345, 7.557777451076474, 7.776888838089433, 7.9899937421752725, 8.19756061276768, 8.4, 8.597674104081872, 8.790904390334365, 8.97997772825746, 9.165151389911681, 9.34665715643834, 9.524704719832528, 9.699484522385713, 9.871170143402454, 10.039920318408907, 10.20588065773846, 10.369185117452577, 10.529957264870548, 10.688311372709911, 10.844353369380768, 10.998181667894016, 11.149887891813083, 11.299557513460428, 11.447270417003349, 11.593101396951552, 11.737120600896969, 11.879393923934, 12.019983361053376, 12.158947322856532, 12.296340919151518, 12.432216214336044, 12.566622457924007, 12.699606293110037, 12.831211945876353, 12.961481396815723, 13.09045453756286, 13.218169313486646, 13.344661854089823, 13.469966592386191, 13.594116374373144, 13.717142559585797, 13.839075113604956, 13.95994269329212, 14.079772725438433, 14.198591479439077, 14.316424134538625, 14.433294842134972, 14.54922678357857, 14.66424222385869, 14.778362561528933, 14.891608375189028, 15.003999466808843, 15.115554902152947, 15.226293048539425, 15.336231610144653, 15.44538766104626, 15.553777676178866, 15.661417560361516, 15.768322675541619, 15.874507866387544, 15.979987484350545, 16.08477541030648, 16.188885075878453, 16.29232948353304, 16.39512122553536, 16.497272501841024, 16.598795136997147, 16.699700596118483, 16.8, 16.899704139422088, 16.998823488700623, 17.09736821853001, 17.195348208163743, 17.29277305697383, 17.389652095427326, 17.485994395515515, 17.58180878066873, 17.677103835187484, 17.77188791321845, 17.866169147301836, 17.95995545651492, 18.053254554234815, 18.14607395554201, 18.238420984284797, 18.330302779823363, 18.42172630347113], [0.0, 1.8439088914585775, 2.6076809620810595, 3.193743884534263, 3.687817782917155, 4.123105625617661, 4.5166359162544865, 4.878524367060187, 5.215361924162119, 5.531726674375732, 5.830951894845301, 6.115553940568263, 6.387487769068526, 6.648308055437865, 6.899275324264136, 7.1414284285428495, 7.37563556583431, 7.602631123499285, 7.823042886243179, 8.037412518964048, 8.246211251235321, 8.449852069711044, 8.648699324175862, 8.843076387773658, 9.033271832508973, 9.219544457292889, 9.402127418834528, 9.581231653602789, 9.757048734120374, 9.92975326984513, 10.099504938362077, 10.26645021416848, 10.430723848324238, 10.59245014149229, 10.75174404457249, 10.908712114635716, 11.063453348751464, 11.216059914247962, 11.36661779070626, 11.515207336387826, 11.661903789690601, 11.806777714516354, 11.949895397031726, 12.091319200153471, 12.231107881136525, 12.36931687685298, 12.505998560690786, 12.641202474448386, 12.774975538137053, 12.907362240210043, 13.038404810405298, 13.168143377105219, 13.29661611087573, 13.42385935563987, 13.54990774876346, 13.674794331177344, 13.798550648528272, 13.921206844235885, 14.042791745233568, 14.163332941084171, 14.282856857085699, 14.401388821915754, 14.51895313030523, 14.635573101180562, 14.75127113166862, 14.866068747318506, 14.979986648859205, 15.093044755780724, 15.20526224699857, 15.316657598836635, 15.427248620541514, 15.537052487521564, 15.646085772486359, 15.754364474646383, 15.861904047118681, 15.968719422671313, 16.074825037928097, 16.180234856144704, 16.284962388657828, 16.389020715100706, 16.492422502470642, 16.5951800231272, 16.697305171793445, 16.798809481626964, 16.899704139422088, 17.0, 17.099707599839245, 17.198837169994956, 17.297398648351724, 17.395401691251628, 17.492855684535904, 17.58976975403601, 17.686152775547317, 17.782013384316187, 17.877359984069237, 17.97220075561143, 18.066543665017946, 18.160396471443022, 18.253766734567417, 18.34666182170479, 18.439088914585778, 18.531055015837605], [0.0, 1.854723699099141, 2.6229754097208002, 3.2124756808418025, 3.709447398198282, 4.147288270665545, 4.543126676640219, 4.907137658554119, 5.2459508194416005, 5.5641710972974225, 5.865151319446072, 6.15142259969188, 6.424951361683605, 6.687301398920196, 6.939740629158989, 7.183313998427188, 7.418894796396564, 7.647221717722065, 7.868926229162401, 8.084553172563096, 8.29457654133109, 8.499411744350311, 8.699425268372618, 8.894942383174834, 9.086253353280439, 9.273618495495704, 9.457272334029513, 9.637427042525408, 9.814275317108239, 9.987992791347018, 10.158740079360236, 10.32666451474047, 10.491901638883201, 10.654576481493764, 10.81480466767662, 10.972693379476162, 11.128342194594845, 11.281843820936365, 11.433284742365162, 11.582745788456208, 11.730302638892145, 11.87602627144282, 12.019983361053377, 12.162236636408617, 12.30284519938376, 12.441864811996632, 12.579348154813111, 12.715345060201868, 12.84990272336721, 12.983065893693986, 13.114877048604002, 13.24537655183876, 13.374602797840392, 13.502592343694602, 13.629380029920657, 13.75499909123952, 13.879481258317979, 14.002856851371437, 14.125154866407662, 14.246403054806501, 14.366627996854376, 14.485855169785456, 14.604109010822947, 14.721412975662357, 14.837789592793127, 14.953260514014994, 15.06784656146989, 15.181567771478676, 15.29444343544413, 15.406492138056606, 15.51773179301666, 15.628179676469042, 15.737852458324802, 15.846766231632245, 15.954936540143304, 16.06237840420901, 16.169106345126192, 16.275134408047144, 16.38047618355462, 16.485144827995903, 16.58915308266218, 16.69251329189227, 16.795237420173617, 16.89733706830754, 16.998823488700623, 17.099707599839245, 17.200000000000003, 17.29971098024473, 17.398850536745236, 17.497428382479523, 17.59545395833822, 17.69293644367718, 17.78988476634967, 17.886307612249098, 17.98221343439122, 18.077610461562667, 18.172506706560878, 18.266909974048705, 18.360827868045604, 18.45426779907564, 18.547236990991408, 18.639742487491613], [0.0, 1.8654758106177631, 2.6381811916545836, 3.231098884280703, 3.7309516212355263, 4.171330722922843, 4.5694638635183455, 4.935585071701227, 5.276362383309167, 5.596427431853289, 5.8991524815010505, 6.187083319303208, 6.462197768561406, 6.726068688320096, 6.979971346646059, 7.224956747275377, 7.4619032424710525, 7.691553809211764, 7.914543574963752, 8.13142054010245, 8.342661445845685, 8.548684109265006, 8.749857141690944, 8.946507698538017, 9.138927727036691, 9.327379053088816, 9.512097560475294, 9.693296652842108, 9.871170143402454, 10.045894683899489, 10.21763181955584, 10.386529738079028, 10.552724766618335, 10.716342659695052, 10.877499712709719, 11.036303729057115, 11.192854863706579, 11.347246362003428, 11.499565209172042, 11.649892703368561, 11.798304963002101, 11.944873377311291, 12.089665007765932, 12.232742946698421, 12.374166638606416, 12.513992168768526, 12.652272523147769, 12.789057822998535, 12.924395537122813, 13.058330674324342, 13.19090595827292, 13.322161986704712, 13.452137376640191, 13.58086889709197, 13.708391590555037, 13.83473888441701, 13.959942693292119, 14.084033513166604, 14.207040508142434, 14.328991590478376, 14.449913494550755, 14.569831845289087, 14.688771221582831, 14.80675521510368, 14.923806484942105, 15.039946808416577, 15.155197128378108, 15.269577597301112, 15.383107618423528, 15.49580588417395, 15.607690412101338, 15.718778578502848, 15.829087149927505, 15.938632312717425, 16.047429700734007, 16.155494421403514, 16.2628410802049, 16.369483803712324, 16.47543626129518, 16.580711685570076, 16.68532289169137, 16.789282295559868, 16.892601931022945, 16.9952934661335, 17.09736821853001, 17.198837169994956, 17.29971098024473, 17.400000000000002, 17.499714283381888, 17.598863599675976, 17.69745744450315, 17.795505050433384, 17.893015397076034, 17.989997220677942, 18.086459023258257, 18.182409081307128, 18.277855454073382, 18.37280599146467, 18.467268341582088, 18.561249957909627, 18.65475810617763, 18.74779987091819], [0.0, 1.876166303929372, 2.6532998322843198, 3.2496153618543846, 3.752332607858744, 4.1952353926806065, 4.595650117230424, 4.963869458396343, 5.3065996645686395, 5.628498911788116, 5.932958789676531, 6.222539674441619, 6.499230723708769, 6.764613810115105, 7.019971509913698, 7.26636084983398, 7.504665215717488, 7.735631842325486, 7.95989949685296, 8.178019320104351, 8.390470785361213, 8.597674104081872, 8.8, 8.997777503361595, 9.191300234460847, 9.38083151964686, 9.566608594481119, 9.748846085563153, 9.927738916792686, 10.103464752252071, 10.276186062932103, 10.446051885760477, 10.613199329137279, 10.777754868245985, 10.939835464941876, 11.099549540409287, 11.256997823576231, 11.412274094149685, 11.565465835840769, 11.71665481270145, 11.865917579353061, 12.013325934144966, 12.158947322856532, 12.302845199383759, 12.445079348883239, 12.585706178041818, 12.724778976469494, 12.862348152650823, 12.998461447417538, 13.133164127505603, 13.266499161421601, 13.398507379555383, 13.52922762023021, 13.6586968631711, 13.786950351691269, 13.91402170474087, 14.039943019827396, 14.164744967700619, 14.288456879593403, 14.411106827721456, 14.53272169966796, 14.653327267211361, 14.77294825009551, 14.891608375189028, 15.009330431434975, 15.126136320951229, 15.24204710660612, 15.357083056361974, 15.471263684650973, 15.584607791022526, 15.697133496278868, 15.808858276295604, 15.91979899370592, 16.029971927611104, 16.13939280146561, 16.24807680927192, 16.356038640208702, 16.463292501805345, 16.569852141766386, 16.675730868540665, 16.780941570722426, 16.88549673536435, 16.989408465276245, 17.092688495377196, 17.195348208163743, 17.297398648351724, 17.398850536745236, 17.499714283381888, 17.6, 17.69971751187007, 17.798876369029593, 17.897485856957676, 17.99555500672319, 18.093092604637828, 18.19010720144332, 18.286607121059937, 18.382600468921694, 18.47809513992176, 18.57309882599024, 18.667619023324857, 18.76166303929372, 18.855237999028283], [0.0, 1.8867962264113207, 2.6683328128252666, 3.2680269276736387, 3.7735924528226414, 4.219004621945797, 4.621688003316537, 4.991993589739474, 5.336665625650533, 5.660388679233962, 5.966573556070519, 6.2577951388648065, 6.536053855347277, 6.802940540677979, 7.059745037889116, 7.307530362578043, 7.547184905645283, 7.779460135510689, 8.0049984384758, 8.224354077980836, 8.438009243891594, 8.646386528486914, 8.849858755935035, 9.048756820690896, 9.243376006633074, 9.433981132056603, 9.620810776644555, 9.804080783020915, 9.983987179478948, 10.160708636704431, 10.33440854621105, 10.505236789335116, 10.673331251301066, 10.838819123871383, 11.001818031580052, 11.16243700990066, 11.320777358467923, 11.476933388322859, 11.63099307883897, 11.783038657324349, 11.933147112141038, 12.081390648431166, 12.227837094106219, 12.372550262577233, 12.515590277729613, 12.65701386583739, 12.796874618437112, 12.935223229616101, 13.072107710694555, 13.207573584879245, 13.341664064126334, 13.47442021016118, 13.605881081355959, 13.736083866954221, 13.865064009949611, 13.992855319769443, 14.119490075778232, 14.244999122499095, 14.369411957348847, 14.492756811593852, 14.615060725156086, 14.736349615830916, 14.85664834341851, 14.975980769218422, 15.094369811290566, 15.211837495845133, 15.328405005087776, 15.444092721814382, 15.558920271021378, 15.672906558772052, 15.786069808536892, 15.898427595205758, 16.0099968769516, 16.12079402510931, 16.230834852218784, 16.34013463836819, 16.448708155961672, 16.556569693025182, 16.66373307515456, 16.770211686201222, 16.87601848778319, 16.981166037701886, 17.085666507338836, 17.189531698100446, 17.29277305697383, 17.395401691251628, 17.497428382479523, 17.598863599675976, 17.69971751187007, 17.799999999999997, 17.899720668211557, 17.99888885459322, 18.09751364138179, 18.19560386467017, 18.2931681236466, 18.390214789392754, 18.48675201326615, 18.582787734890587, 18.678329689776866, 18.77338541659442, 18.867962264113206, 18.962067397834026], [0.0, 1.8973665961010275, 2.6832815729997477, 3.286335345030997, 3.794733192202055, 4.242640687119286, 4.6475800154489, 5.019960159204453, 5.366563145999495, 5.692099788303082, 6.0, 6.29285308902091, 6.572670690061994, 6.841052550594828, 7.099295739719539, 7.348469228349534, 7.58946638440411, 7.8230428862431785, 8.049844718999243, 8.270429251254134, 8.485281374238571, 8.694826047713663, 8.899438184514796, 9.099450532861862, 9.2951600308978, 9.486832980505138, 9.67470929795826, 9.85900603509299, 10.039920318408907, 10.21763181955584, 10.392304845413264, 10.564090116995406, 10.73312629199899, 10.899541274750971, 11.063453348751466, 11.224972160321824, 11.384199576606164, 11.541230437002808, 11.696153213770756, 11.8490505948789, 12.0, 12.149074038789953, 12.296340919151518, 12.44186481199663, 12.58570617804182, 12.727922061357855, 12.86856635371633, 13.007690033207279, 13.145341380123988, 13.281566172707194, 13.416407864998739, 13.54990774876346, 13.682105101189656, 13.813037319865607, 13.942740046346701, 14.071247279470288, 14.198591479439077, 14.324803663575986, 14.449913494550756, 14.573949361789342, 14.696938456699067, 14.818906842274163, 14.939879517586478, 15.05988047761336, 15.17893276880822, 15.297058540778353, 15.414279094398154, 15.53061492665374, 15.646085772486357, 15.760710643876436, 15.874507866387544, 15.987495113369073, 16.099689437998485, 16.211107303327555, 16.321764610482532, 16.431676725154983, 16.540858502508268, 16.64932431061393, 16.757088052522732, 16.864163187066236, 16.970562748477143, 17.07629936490925, 17.181385275931625, 17.28583234906552, 17.389652095427326, 17.492855684535904, 17.59545395833822, 17.69745744450315, 17.798876369029593, 17.899720668211557, 18.0, 18.099723754798028, 18.198901065723724, 18.29754081837229, 18.39565166010707, 18.49324200890693, 18.5903200617956, 18.686893802876927, 18.78297101099823, 18.87855926706273, 18.973665961010276, 19.068298298484848], [0.0, 1.9078784028338913, 2.698147512646408, 3.3045423283716615, 3.8157568056677826, 4.266145801540309, 4.673328578219169, 5.047771785649585, 5.396295025292816, 5.7236352085016735, 6.0332412515993425, 6.327716807822551, 6.609084656743323, 6.878953408767936, 7.138627319029899, 7.389181280764466, 7.631513611335565, 7.866384175718855, 8.094442537939225, 8.316249154516717, 8.532291603080617, 8.742997197757758, 8.948742928478838, 9.1498633869583, 9.346657156438338, 9.539392014169458, 9.728309205612248, 9.913626985114984, 10.09554357129917, 10.274239631233058, 10.449880382090505, 10.6226173799116, 10.792590050585632, 10.959927007056207, 11.124747188138704, 11.287160847617969, 11.447270417003347, 11.605171261123207, 11.760952342391326, 11.914696806885186, 12.066482503198685, 12.216382443260363, 12.364465212858986, 12.51079533842673, 12.655433615645101, 12.798437404620923, 12.93986089569745, 13.079755349393963, 13.218169313486646, 13.35514881983724, 13.490737563232042, 13.62497706420088, 13.757906817535872, 13.889564428015735, 14.019985734657508, 14.149204924659195, 14.277254638059798, 14.404166064024672, 14.529969029560938, 14.654692081377895, 14.778362561528931, 14.901006677402705, 15.022649566571138, 15.143315356948756, 15.26302722267113, 15.381807436059, 15.49967741599805, 15.616657773031974, 15.73276835143771, 15.848028268526026, 15.962455951387932, 16.076069171286868, 16.18888507587845, 16.300920219423197, 16.412190591142913, 16.522711641858308, 16.632498309033434, 16.741565040341957, 16.849925815860438, 16.957594168985175, 17.064583206161235, 17.17090562550502, 17.276573734395374, 17.381599466102077, 17.485994395515515, 17.58976975403601, 17.69293644367718, 17.795505050433384, 17.897485856957676, 17.99888885459322, 18.099723754798028, 18.2, 18.2997267739166, 18.398913011371082, 18.497567407634985, 18.59569842732453, 18.693314312876677, 18.790423092628863, 18.887032588524857, 18.983150423467652, 19.078784028338916, 19.173940648703386], [0.0, 1.918332609325088, 2.7129319932501073, 3.3226495451672307, 3.836665218650176, 4.289522117905444, 4.698936049788292, 5.075431016179809, 5.4258639865002145, 5.754997827975264, 6.066300355241241, 6.362389488234747, 6.645299090334461, 6.916646586316234, 7.177743377970545, 7.429670248402684, 7.673330437300352, 7.909487973314076, 8.138795979750322, 8.36181798414675, 8.579044235810889, 8.790904390334365, 8.997777503361595, 9.200000000000001, 9.397872099576585, 9.59166304662544, 9.781615408509989, 9.967948635501692, 10.150862032359617, 10.330537256115967, 10.507140429250958, 10.680823938254951, 10.851727973000429, 11.019981851164731, 11.18570516328765, 11.349008767288886, 11.509995655950528, 11.66876171665186, 11.825396399275588, 11.979983305497552, 12.132600710482482, 12.283322026227271, 12.432216214336044, 12.57934815481311, 12.724778976469494, 12.86856635371633, 13.010764773832475, 13.151425778218877, 13.290598180668923, 13.428328265275615, 13.564659966250538, 13.699635031634969, 13.833293172632468, 13.965672200076876, 14.096808149364879, 14.226735395022994, 14.35548675594109, 14.48309359218534, 14.609585894199741, 14.73499236511509, 14.859340496805368, 14.982656640262435, 15.104966070799366, 15.226293048539425, 15.346660874600705, 15.466091943344964, 15.584607791022526, 15.702229141112419, 15.818975946628152, 15.934867429633673, 16.049922118191105, 16.164157880941403, 16.277591959500644, 16.390240998838305, 16.502121075789017, 16.61324772583615, 16.7236359682935, 16.833300330000654, 16.9422548676379, 17.050513188757694, 17.158088471621777, 17.264993483925792, 17.371240600486775, 17.476841819962782, 17.58180878066873, 17.686152775547317, 17.78988476634967, 17.893015397076034, 17.99555500672319, 18.09751364138179, 18.198901065723724, 18.2997267739166, 18.400000000000002, 18.499729727755486, 18.598924700100273, 18.69759342803239, 18.79574419915317, 18.893385085791273, 18.990523952750753, 19.08716846470424, 19.18332609325088, 19.27900412365743], [0.0, 1.9287301521985911, 2.727636339397171, 3.340658617698014, 3.8574603043971822, 4.312771730569565, 4.724404724407087, 5.10294032886923, 5.455272678794342, 5.786190456595773, 6.099180272790763, 6.3968742366877915, 6.681317235396028, 6.954135460285485, 7.216647421067487, 7.469939758793239, 7.7149206087943645, 7.952358140828418, 8.182909018191515, 8.407139822793482, 8.62554346113913, 8.838551917593742, 9.046546302318914, 9.249864863877743, 9.448809448814174, 9.643650760992957, 9.834632682515398, 10.021975853094041, 10.20588065773846, 10.386529738079028, 10.564090116995406, 10.73871500692704, 10.910545357588685, 11.079711187571634, 11.24633273560764, 11.41052146047673, 11.572380913191546, 11.732007500849972, 11.889491158161482, 12.04491593993084, 12.198360545581526, 12.349898785010348, 12.499599993599798, 12.647529403009901, 12.793748473375583, 12.938315191708694, 13.081284340614268, 13.222707740852478, 13.362634470792056, 13.501111065390138, 13.638181696985857, 13.773888339898798, 13.90827092057097, 14.041367454774484, 14.173214173221261, 14.30384563675098, 14.433294842134973, 14.561593319413918, 14.688771221582833, 14.814857407346182, 14.939879517586478, 15.063864046120438, 15.186836405255704, 15.30882098660769, 15.429841217588729, 15.549919613940132, 15.669077828640715, 15.78733669749271, 15.904716281656835, 16.02123590738243, 16.13691420315545, 16.251769134466564, 16.36581803638303, 16.479077644091614, 16.59156412156491, 16.703293088490067, 16.814279645586964, 16.924538398432023, 17.034083479894072, 17.142928571279764, 17.25108692227826, 17.35857136978732, 17.465394355696642, 17.57156794369814, 17.677103835187484, 17.782013384316187, 17.886307612249098, 17.989997220677942, 18.093092604637828, 18.19560386467017, 18.29754081837229, 18.398913011371082, 18.499729727755486, 18.6, 18.699732618409282, 18.79893614011176, 18.897618897628348, 18.995789007040486, 19.0934543757802, 19.190622710063373, 19.287301521985913, 19.38349813630141], [0.0, 1.9390719429665317, 2.7422618401604177, 3.3585711247493335, 3.8781438859330635, 4.335896677735761, 4.749736834815168, 5.130302135352265, 5.4845236803208355, 5.817215828899595, 6.131883886702357, 6.431174076325411, 6.717142249498667, 6.9914233171794145, 7.255342858886822, 7.5099933422074345, 7.756287771866127, 7.994998436522675, 8.226785520481254, 8.452218643646177, 8.671793355471522, 8.885943956609225, 9.09505360072166, 9.299462350050137, 9.499473669630335, 9.695359714832659, 9.887365675446622, 10.075713374248, 10.26060427070453, 10.442221985765292, 10.620734437881403, 10.796295661012625, 10.969047360641671, 11.139120252515458, 11.306635220082057, 11.47170431975999, 11.63443165779919, 11.794914158229385, 11.95324223798715, 12.109500402576485, 12.263767773404714, 12.416118556135007, 12.566622457924009, 12.715345060201866, 12.862348152650823, 13.007690033207279, 13.15142577821888, 13.293607486307094, 13.434284498997334, 13.573503600765722, 13.71130920080209, 13.847743498491011, 13.982846634358829, 14.116656828017039, 14.249210504445502, 14.380542409798041, 14.510685717773644, 14.63967212747608, 14.767531953579788, 14.894294209528695, 15.019986684414869, 15.144636014114042, 15.268267747193851, 15.390906406056793, 15.512575543732254, 15.633297796690243, 15.753094934012175, 15.871987903221198, 15.98999687304535, 16.10714127336071, 16.2234398325386, 16.33891061240008, 16.453571040962508, 16.56743794314619, 16.680527569594435, 16.792855623746668, 16.904437287292353, 17.015287244122565, 17.12541970288612, 17.23484841824842, 17.343586710943043, 17.451647486698786, 17.55904325411838, 17.66578614157887, 17.77188791321845, 17.877359984069237, 17.98221343439122, 18.086459023258257, 18.19010720144332, 18.2931681236466, 18.39565166010707, 18.497567407634985, 18.598924700100273, 18.699732618409282, 18.8, 18.89973544788392, 18.99894733926067, 19.097643833729858, 19.195832881122925, 19.293522228976236, 19.390719429665317, 19.48743184721887], [0.0, 1.9493588689617927, 2.756809750418044, 3.3763886032268267, 3.8987177379235853, 4.358898943540674, 4.774934554525329, 5.15751878329105, 5.513619500836088, 5.848076606885377, 6.164414002968976, 6.465291950097845, 6.752777206453653, 7.0285133563222315, 7.293833011524187, 7.549834435270749, 7.797435475847171, 8.037412518964047, 8.270429251254132, 8.497058314499201, 8.717797887081348, 8.933084573650918, 9.143303560529969, 9.348796714016196, 9.549869109050658, 9.746794344808963, 9.939818911831342, 10.12916580968048, 10.3150375665821, 10.497618777608567, 10.67707825203131, 10.853570840972107, 11.027239001672177, 11.198214143335536, 11.366617790706258, 11.532562594670795, 11.696153213770755, 11.85748708622531, 12.016655108639842, 12.17374223482656, 12.328828005937952, 12.48198702130394, 12.633289357883006, 12.782800945019833, 12.93058390019569, 13.07669683062202, 13.221195104830727, 13.36413109783049, 13.505554412907307, 13.645512082732548, 13.784048752090222, 13.921206844235885, 14.057026712644463, 14.191546779685433, 14.324803663575986, 14.456832294800959, 14.587666023048374, 14.717336715588184, 14.845874847916507, 14.973309587395832, 15.099668870541498, 15.224979474534603, 15.349267083479912, 15.472556349873152, 15.594870951694341, 15.716233645501708, 15.836666315863322, 15.956190021430553, 16.074825037928093, 16.192590898309017, 16.30950643030009, 16.425589791541732, 16.540858502508264, 16.655329477377503, 16.769019053003664, 16.88194301613413, 16.994116628998402, 17.10555465338672, 17.216271373325874, 17.326280616450838, 17.435595774162696, 17.544229820656135, 17.652195330892983, 17.759504497592268, 17.866169147301836, 17.97220075561143, 18.077610461562667, 18.182409081307128, 18.286607121059937, 18.390214789392754, 18.49324200890693, 18.59569842732453, 18.69759342803239, 18.79893614011176, 18.89973544788392, 18.999999999999996, 19.099738218101315, 19.198958305074783, 19.297668252926307, 19.395875850293535, 19.493588689617926, 19.590814173994914], [0.0, 1.9595917942265426, 2.7712812921102037, 3.3941125496954285, 3.9191835884530852, 4.3817804600413295, 4.800000000000001, 5.184592558726289, 5.542562584220407, 5.878775382679628, 6.196773353931867, 6.499230723708769, 6.788225099390857, 7.065408693062278, 7.332121111929344, 7.58946638440411, 7.8383671769061705, 8.079603950689663, 8.313843876330612, 8.54166260162505, 8.763560920082659, 8.97997772825746, 9.191300234460847, 9.397872099576585, 9.600000000000001, 9.797958971132713, 9.991996797437439, 10.182337649086286, 10.369185117452577, 10.552724766618336, 10.73312629199899, 10.910545357588685, 11.085125168440815, 11.256997823576233, 11.426285485668561, 11.593101396951552, 11.757550765359255, 11.919731540601072, 12.0797350964332, 12.237646832622685, 12.393546707863734, 12.5475097130865, 12.699606293110037, 12.849902723367208, 12.998461447417538, 13.145341380123986, 13.29059818066892, 13.434284498997332, 13.576450198781714, 13.717142559585797, 13.85640646055102, 13.994284547628723, 14.130817386124557, 14.266043600101609, 14.4, 14.532721699667961, 14.664242223858688, 14.794593607125543, 14.923806484942105, 15.051910177781423, 15.17893276880822, 15.304901175767194, 15.429841217588727, 15.553777676178866, 15.676734353812341, 15.798734126505199, 15.91979899370592, 16.039950124610737, 16.159207901379325, 16.277591959500644, 16.39512122553536, 16.511813952440235, 16.627687752661224, 16.74275962916508, 16.85704600456438, 16.970562748477143, 17.0833252032501, 17.195348208163743, 17.30664612222715, 17.417232845661793, 17.527121840165318, 17.636326148038883, 17.74485841025507, 17.852730883537117, 17.95995545651492, 18.066543665017946, 18.172506706560878, 18.277855454073382, 18.382600468921694, 18.48675201326615, 18.5903200617956, 18.693314312876677, 18.79574419915317, 18.897618897628348, 18.99894733926067, 19.099738218101315, 19.200000000000003, 19.299740930903713, 19.398969044771427, 19.497692171126307, 19.595917942265427, 19.693653800145878], [0.0, 1.9697715603592212, 2.785677655436824, 3.411744421846397, 3.9395431207184424, 4.404543109109049, 4.824935232725928, 5.2115256883181535, 5.571355310873648, 5.909314681077663, 6.228964600958975, 6.532993188424431, 6.823488843692794, 7.102112361825883, 7.370210309075312, 7.628892449104261, 7.879086241436885, 8.121576201698781, 8.357032966310472, 8.586035173466273, 8.809086218218098, 9.026627277117408, 9.23904756996088, 9.446692542895637, 9.649870465451857, 9.848857801796106, 10.043903623591778, 10.23523326553919, 10.423051376636307, 10.607544484940897, 10.788883167408942, 10.967223896684157, 11.142710621747296, 11.315476127852511, 11.485643212288984, 11.653325705565774, 11.818629362155326, 11.98165264060013, 12.142487389328434, 12.301219451745427, 12.45792920191795, 12.61269202034205, 12.76557871778636, 12.916655913974019, 13.065986376848862, 13.213629327327144, 13.35964071373179, 13.504073459515837, 13.646977687385588, 13.788400922514548, 13.928388277184121, 14.066982618884552, 14.204224723651766, 14.340153416194685, 14.474805698177784, 14.60821686586012, 14.740420618150624, 14.871449156017043, 15.001333274079343, 15.130102445125743, 15.257784898208522, 15.384407690905752, 15.509996776273038, 15.634577064954462, 15.75817248287377, 15.880806024884254, 16.002499804718013, 16.12327510154187, 16.243152403397563, 16.36215144777728, 16.480291259562133, 16.597590186530095, 16.714065932620944, 16.829735589129143, 16.94461566398011, 17.058722109231983, 17.172070346932546, 17.28467529344998, 17.39655138238611, 17.507712586171845, 17.618172436436197, 17.72794404323299, 17.837040113202644, 17.94547296674011, 18.053254554234815, 18.160396471443022, 18.266909974048705, 18.37280599146467, 18.47809513992176, 18.582787734890587, 18.686893802876927, 18.790423092628863, 18.893385085791273, 18.995789007040486, 19.097643833729858, 19.198958305074783, 19.299740930903713, 19.400000000000006, 19.49974358805777, 19.598979565273293, 19.69771560359221, 19.795959183631396], [0.0, 1.9798989873223332, 2.8, 3.4292856398964497, 3.9597979746446663, 4.427188724235731, 4.849742261192857, 5.238320341483518, 5.6, 5.939696961966999, 6.260990336999411, 6.566582063752802, 6.8585712797928995, 7.138627319029899, 7.408103670980854, 7.668115805072325, 7.919595949289333, 8.16333265278342, 8.4, 8.630179604156568, 8.854377448471462, 9.073036977771006, 9.28654941299512, 9.495261976375376, 9.699484522385713, 9.899494936611665, 10.09554357129917, 10.287856919689348, 10.476640682967036, 10.662082348209472, 10.844353369380766, 11.023611023616535, 11.2, 11.373653766490346, 11.54469575172945, 11.713240371477058, 11.879393923933998, 12.043255373859678, 12.204917041913886, 12.364465212858986, 12.521980673998822, 12.677539193392384, 12.831211945876353, 12.983065893693984, 13.133164127505603, 13.281566172707192, 13.428328265275615, 13.573503600765722, 13.717142559585799, 13.85929291125633, 14.0, 14.13930691370691, 14.277254638059798, 14.413882197381803, 14.54922678357857, 14.683323874382122, 14.816207341961707, 14.947909552843836, 15.078461459976612, 15.207892687680301, 15.33623161014465, 15.463505424062165, 15.58974021592406, 15.714961024450554, 15.839191898578665, 15.96245595138793, 16.08477541030648, 16.206171663906314, 16.32666530556684, 16.446276174259022, 16.565023392678924, 16.682925402938178, 16.8, 16.9162643630324, 17.031735084835013, 17.146428199482248, 17.260359208313137, 17.3735431043872, 17.485994395515515, 17.59772712596715, 17.708754896942924, 17.819090885900998, 17.928747864811978, 18.037738217415175, 18.14607395554201, 18.253766734567417, 18.360827868045604, 18.467268341582088, 18.57309882599024, 18.678329689776866, 18.78297101099823, 18.887032588524857, 18.990523952750753, 19.0934543757802, 19.195832881122925, 19.297668252926307, 19.398969044771427, 19.49974358805777, 19.6, 19.699746191258406, 19.79898987322333, 19.897738564972656], [0.0, 1.9899748742132402, 2.814249455894058, 3.4467375879228177, 3.9799497484264803, 4.449719092257398, 4.874423042781577, 5.264978632435274, 5.628498911788116, 5.96992462263972, 6.29285308902091, 6.600000000000001, 6.893475175845635, 7.17495644586084, 7.445804187594514, 7.707139547199078, 7.959899496852961, 8.204876598706406, 8.442748367682174, 8.674099376880578, 8.899438184514796, 9.119210492142399, 9.333809511662428, 9.54358423235212, 9.748846085563153, 9.949874371066201, 10.146920715172659, 10.340212763768452, 10.529957264870548, 10.716342659695053, 10.89954127475097, 11.079711187571634, 11.256997823576231, 11.431535329954592, 11.60344776348823, 11.772850122209151, 11.93984924527944, 12.10454460109921, 12.267028980156525, 12.427389106324789, 12.58570617804182, 12.742056348957183, 12.89651115612281, 13.049137902558927, 13.200000000000003, 13.349157276772193, 13.496666255042392, 13.642580401082489, 13.78695035169127, 13.92982411949268, 14.07124727947029, 14.211263138792416, 14.34991289172168, 14.487235761179566, 14.623269128344731, 14.758048651498614, 14.891608375189028, 15.023980830658699, 15.15519712837811, 15.285287043428397, 15.414279094398156, 15.542200616386344, 15.669077828640715, 15.794935897305821, 15.919798993705921, 16.043690348545127, 16.166632302368978, 16.288646352597873, 16.40975319741281, 16.529972776747094, 16.64932431061393, 16.767826334978544, 16.88549673536435, 17.002352778365704, 17.118411141224527, 17.233687939614086, 17.348198753761157, 17.4619586530263, 17.574982219052174, 17.687283567580412, 17.798876369029593, 17.90977386791916, 18.019988901217452, 18.129533915685755, 18.238420984284797, 18.34666182170479, 18.45426779907564, 18.561249957909627, 18.667619023324857, 18.77338541659442, 18.87855926706273, 18.983150423467652, 19.08716846470424, 19.190622710063373, 19.293522228976236, 19.395875850293535, 19.497692171126307, 19.598979565273293, 19.699746191258406, 19.800000000000004, 19.899748742132402, 19.998999974998753], [0.0, 2.0, 2.8284271247461903, 3.4641016151377553, 4.0, 4.47213595499958, 4.898979485566357, 5.291502622129181, 5.656854249492381, 6.0, 6.324555320336759, 6.6332495807108005, 6.9282032302755105, 7.211102550927979, 7.483314773547883, 7.745966692414833, 8.0, 8.246211251235321, 8.485281374238571, 8.717797887081348, 8.94427190999916, 9.165151389911681, 9.38083151964686, 9.59166304662544, 9.797958971132713, 10.000000000000002, 10.19803902718557, 10.392304845413266, 10.583005244258363, 10.77032961426901, 10.954451150103322, 11.135528725660045, 11.313708498984761, 11.489125293076059, 11.661903789690601, 11.832159566199232, 12.0, 12.16552506059644, 12.328828005937954, 12.489995996796798, 12.649110640673518, 12.806248474865699, 12.961481396815723, 13.114877048604, 13.266499161421601, 13.416407864998737, 13.564659966250538, 13.71130920080209, 13.856406460551021, 14.0, 14.142135623730953, 14.282856857085703, 14.422205101855958, 14.56021977856104, 14.69693845669907, 14.832396974191328, 14.966629547095765, 15.0996688705415, 15.231546211727819, 15.362291495737216, 15.491933384829666, 15.62049935181331, 15.748015748023622, 15.874507866387544, 16.0, 16.1245154965971, 16.24807680927192, 16.3707055437449, 16.492422502470642, 16.61324772583615, 16.73320053068151, 16.852299546352718, 16.970562748477143, 17.088007490635064, 17.204650534085253, 17.320508075688775, 17.435595774162696, 17.549928774784245, 17.663521732655695, 17.77638883463118, 17.88854381999832, 18.000000000000004, 18.110770276274835, 18.2208671582886, 18.330302779823363, 18.439088914585778, 18.547236990991408, 18.65475810617763, 18.76166303929372, 18.867962264113206, 18.973665961010276, 19.078784028338916, 19.18332609325088, 19.287301521985913, 19.390719429665317, 19.493588689617926, 19.595917942265427, 19.69771560359221, 19.79898987322333, 19.899748742132402, 20.000000000000004, 20.099751242241783], [0.0, 2.0099751242241783, 2.8425340807103794, 3.481379037105843, 4.019950248448357, 4.494441010848847, 4.9234134500364695, 5.317894320123333, 5.685068161420759, 6.029925372672535, 6.356099432828282, 6.666333324999584, 6.962758074211686, 7.247068372797377, 7.520638270785267, 7.784600182411426, 8.039900496896713, 8.287339742040265, 8.527602242131138, 8.761278445523805, 8.988882021697695, 9.210863151735564, 9.427618999514142, 9.639502061828715, 9.846826900072939, 10.049875621120892, 10.248902380255167, 10.444137111317527, 10.635788640246666, 10.824047302187848, 11.009087155618309, 11.191067866830226, 11.370136322841518, 11.54642801908885, 11.72006825918689, 11.8911731969558, 12.05985074534507, 12.226201372462342, 12.390318801386833, 12.552290627610565, 12.712198865656564, 12.870120434556938, 13.026127590347027, 13.180288312476325, 13.332666649999169, 13.48332303254654, 13.63231455036158, 13.779695207079149, 13.925516148423371, 14.069825869569248, 14.212670403551897, 14.354093492798494, 14.494136745594753, 14.63283977907228, 14.770240350109408, 14.906374475371269, 15.041276541570534, 15.174979406905305, 15.307514494521966, 15.438911878756224, 15.569200364822851, 15.698407562552326, 15.826559954709047, 15.95368296037, 16.079800993793427, 16.20493751916372, 16.32911510156016, 16.45235545446305, 16.57467948408053, 16.69610733075228, 16.816658407662327, 16.936351437071682, 17.055204484262276, 17.17323498936645, 17.29045979724079, 17.406895185529212, 17.52255689104761, 17.63746013461122, 17.751619644415552, 17.86504967807255, 17.97776404339539, 18.089776118017607, 18.201098867925534, 18.311744864976685, 18.42172630347113, 18.531055015837605, 18.639742487491613, 18.74779987091819, 18.855237999028283, 18.962067397834026, 19.068298298484848, 19.173940648703386, 19.27900412365743, 19.38349813630141, 19.48743184721887, 19.590814173994914, 19.693653800145878, 19.795959183631396, 19.897738564972656, 19.998999974998753, 20.099751242241783, 20.200000000000003]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"A = 2.5\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.25, 0.3535533905932738, 0.4330127018922194, 0.5, 0.5590169943749475, 0.6123724356957946, 0.6614378277661477, 0.7071067811865476, 0.75, 0.7905694150420949, 0.8291561975888502, 0.8660254037844388, 0.9013878188659974, 0.9354143466934853, 0.9682458365518543, 1.0, 1.0307764064044151, 1.0606601717798214, 1.0897247358851685, 1.118033988749895, 1.1456439237389602, 1.1726039399558574, 1.19895788082818, 1.2247448713915892, 1.2500000000000002, 1.2747548783981963, 1.2990381056766582, 1.3228756555322954, 1.3462912017836262, 1.369306393762915, 1.3919410907075056, 1.4142135623730951, 1.4361406616345074, 1.4577379737113252, 1.479019945774904, 1.5, 1.520690632574555, 1.5411035007422442, 1.5612494995995998, 1.5811388300841898, 1.6007810593582121, 1.6201851746019653, 1.6393596310755, 1.6583123951777003, 1.6770509831248421, 1.695582495781317, 1.7139136501002612, 1.7320508075688776, 1.75, 1.7677669529663689, 1.7853571071357128, 1.8027756377319948, 1.8200274723201297, 1.8371173070873839, 1.854049621773916, 1.8708286933869707, 1.8874586088176877, 1.9039432764659772, 1.920286436967152, 1.9364916731037085, 1.9525624189766635, 1.9685019685029528, 1.9843134832984428, 2.0, 2.0155644370746373, 2.03100960115899, 2.0463381929681126, 2.0615528128088303, 2.0766559657295187, 2.091650066335189, 2.1065374432940898, 2.121320343559643, 2.136000936329383, 2.1505813167606567, 2.165063509461097, 2.179449471770337, 2.1937410968480306, 2.207940216581962, 2.222048604328897, 2.23606797749979, 2.25, 2.2638462845343543, 2.277608394786075, 2.2912878474779204, 2.3048861143232218, 2.318404623873926, 2.331844763272204, 2.345207879911715, 2.358495283014151, 2.3717082451262845, 2.384848003542364, 2.39791576165636, 2.4109126902482387, 2.4238399287081647, 2.436698586202241, 2.4494897427831783, 2.4622144504490264, 2.4748737341529163, 2.48746859276655, 2.5000000000000004, 2.512468905280223], [0.0, 0.3535533905932738, 0.5, 0.6123724356957946, 0.7071067811865476, 0.7905694150420949, 0.8660254037844387, 0.9354143466934853, 1.0, 1.0606601717798212, 1.118033988749895, 1.1726039399558577, 1.2247448713915892, 1.2747548783981963, 1.3228756555322954, 1.3693063937629153, 1.4142135623730951, 1.457737973711325, 1.5, 1.5411035007422442, 1.5811388300841898, 1.620185174601965, 1.6583123951777, 1.695582495781317, 1.7320508075688774, 1.7677669529663689, 1.8027756377319948, 1.8371173070873839, 1.8708286933869707, 1.9039432764659772, 1.9364916731037083, 1.9685019685029528, 2.0, 2.03100960115899, 2.0615528128088303, 2.091650066335189, 2.1213203435596424, 2.1505813167606567, 2.179449471770337, 2.207940216581962, 2.23606797749979, 2.263846284534354, 2.2912878474779204, 2.318404623873926, 2.3452078799117153, 2.371708245126284, 2.3979157616563596, 2.4238399287081647, 2.4494897427831783, 2.4748737341529163, 2.5, 2.52487623459052, 2.5495097567963927, 2.57390753524675, 2.598076211353316, 2.622022120425379, 2.6457513110645907, 2.669269563007828, 2.692582403567252, 2.715695122800054, 2.7386127875258306, 2.761340254296815, 2.7838821814150108, 2.8062430400804557, 2.8284271247461903, 2.850438562747845, 2.8722813232690143, 2.8939592256975564, 2.91547594742265, 2.936835031117683, 2.958039891549808, 2.979093821953246, 3.0, 3.020761493398643, 3.0413812651491097, 3.0618621784789726, 3.0822070014844885, 3.1024184114977142, 3.122498999199199, 3.142451272494134, 3.1622776601683795, 3.181980515339464, 3.2015621187164247, 3.221024681681281, 3.24037034920393, 3.259601202601324, 3.278719262151, 3.29772648956823, 3.3166247903554, 3.335416016031583, 3.3541019662496843, 3.3726843908080104, 3.391164991562634, 3.409545424246464, 3.4278273002005224, 3.446012188022555, 3.464101615137755, 3.48209706929603, 3.5, 3.517811819867572, 3.5355339059327378, 3.553167600887974], [0.0, 0.4330127018922194, 0.6123724356957946, 0.7500000000000002, 0.8660254037844388, 0.9682458365518544, 1.0606601717798214, 1.1456439237389602, 1.2247448713915892, 1.2990381056766582, 1.3693063937629155, 1.4361406616345076, 1.5000000000000004, 1.5612494995996, 1.6201851746019653, 1.6770509831248426, 1.7320508075688776, 1.7853571071357126, 1.8371173070873839, 1.887458608817688, 1.9364916731037087, 1.9843134832984435, 2.03100960115899, 2.076655965729519, 2.121320343559643, 2.1650635094610973, 2.2079402165819624, 2.250000000000001, 2.2912878474779204, 2.3318447632722044, 2.3717082451262845, 2.410912690248239, 2.4494897427831783, 2.4874685927665507, 2.52487623459052, 2.5617376914899, 2.5980762113533165, 2.6339134382131855, 2.6692695630078282, 2.7041634565979926, 2.738612787525831, 2.772634126602355, 2.806243040080457, 2.8394541729001372, 2.872281323269015, 2.9047375096555625, 2.936835031117683, 2.9685855217594797, 3.000000000000001, 3.0310889132455356, 3.061862178478973, 3.092329219213246, 3.1224989991992, 3.152380053229624, 3.1819805153394647, 3.211308144666283, 3.2403703492039306, 3.2691742076555057, 3.2977264895682303, 3.326033673912518, 3.354101966249685, 3.381937314617171, 3.4095454242464647, 3.43693177121688, 3.4641016151377553, 3.4910600109422356, 3.5178118198675725, 3.544361719689457, 3.570714214271425, 3.5968736424845402, 3.62284418654736, 3.648629879831607, 3.6742346141747677, 3.699662146737186, 3.724916106437835, 3.7500000000000004, 3.774917217635376, 3.7996710383926664, 3.8242646351945893, 3.848701079585164, 3.8729833462074175, 3.8971143170299745, 3.9210967853395315, 3.9449334595148757, 3.968626966596887, 3.9921798556678283, 4.015594601052253, 4.0388736053508785, 4.06201920231798, 4.085033659592048, 4.107919181288747, 4.130677910464577, 4.153311931459038, 4.175823272122517, 4.198213905936667, 4.220485754033533, 4.242640687119286, 4.264680527307996, 4.286607049870563, 4.308421984903522, 4.3301270189221945, 4.351723796382303], [0.0, 0.5, 0.7071067811865476, 0.8660254037844388, 1.0, 1.118033988749895, 1.2247448713915892, 1.3228756555322954, 1.4142135623730951, 1.5, 1.5811388300841898, 1.6583123951777003, 1.7320508075688776, 1.8027756377319948, 1.8708286933869707, 1.9364916731037085, 2.0, 2.0615528128088303, 2.121320343559643, 2.179449471770337, 2.23606797749979, 2.2912878474779204, 2.345207879911715, 2.39791576165636, 2.4494897427831783, 2.5000000000000004, 2.5495097567963927, 2.5980762113533165, 2.6457513110645907, 2.6925824035672523, 2.73861278752583, 2.783882181415011, 2.8284271247461903, 2.8722813232690148, 2.9154759474226504, 2.958039891549808, 3.0, 3.04138126514911, 3.0822070014844885, 3.1224989991991996, 3.1622776601683795, 3.2015621187164243, 3.2403703492039306, 3.278719262151, 3.3166247903554007, 3.3541019662496843, 3.391164991562634, 3.4278273002005224, 3.4641016151377553, 3.5, 3.5355339059327378, 3.5707142142714257, 3.6055512754639896, 3.6400549446402595, 3.6742346141747677, 3.708099243547832, 3.7416573867739413, 3.7749172176353754, 3.8078865529319543, 3.840572873934304, 3.872983346207417, 3.905124837953327, 3.9370039370059056, 3.9686269665968856, 4.0, 4.031128874149275, 4.06201920231798, 4.092676385936225, 4.123105625617661, 4.153311931459037, 4.183300132670378, 4.2130748865881795, 4.242640687119286, 4.272001872658766, 4.301162633521313, 4.330127018922194, 4.358898943540674, 4.387482193696061, 4.415880433163924, 4.444097208657794, 4.47213595499958, 4.5, 4.527692569068709, 4.55521678957215, 4.582575694955841, 4.6097722286464435, 4.636809247747852, 4.663689526544408, 4.69041575982343, 4.716990566028302, 4.743416490252569, 4.769696007084728, 4.79583152331272, 4.8218253804964775, 4.847679857416329, 4.873397172404482, 4.898979485566357, 4.924428900898053, 4.949747468305833, 4.9749371855331, 5.000000000000001, 5.024937810560446], [0.0, 0.5590169943749475, 0.7905694150420949, 0.9682458365518545, 1.118033988749895, 1.2500000000000002, 1.3693063937629155, 1.479019945774904, 1.5811388300841898, 1.6770509831248424, 1.7677669529663689, 1.8540496217739162, 1.936491673103709, 2.0155644370746377, 2.091650066335189, 2.165063509461097, 2.23606797749979, 2.3048861143232218, 2.371708245126285, 2.4366985862022412, 2.5000000000000004, 2.5617376914899, 2.622022120425379, 2.6809513236909024, 2.738612787525831, 2.7950849718747377, 2.8504385627478457, 2.9047375096555634, 2.958039891549808, 3.0103986446980744, 3.0618621784789726, 3.112474899497183, 3.1622776601683795, 3.2113081446662832, 3.2596012026013246, 3.3071891388307386, 3.3541019662496847, 3.4003676271838614, 3.446012188022556, 3.491060010942236, 3.5355339059327378, 3.5794552658190883, 3.6228441865473604, 3.665719574653795, 3.7080992435478324, 3.7499999999999996, 3.7914377220257753, 3.8324274291889733, 3.872983346207418, 3.913118960624632, 3.9528470752104745, 3.9921798556678287, 4.0311288741492755, 4.069705149024927, 4.107919181288747, 4.14578098794425, 4.183300132670378, 4.220485754033533, 4.257346591481601, 4.293891009329417, 4.330127018922194, 4.366062299143246, 4.401704215414752, 4.437059837324712, 4.47213595499958, 4.5069390943299865, 4.541475531146238, 4.575751304430782, 4.6097722286464435, 4.643543905251678, 4.677071733467427, 4.710360920354193, 4.74341649025257, 4.776243293635701, 4.808846015417836, 4.841229182759272, 4.8733971724044824, 4.9053542175871465, 4.937104414532875, 4.968651728587949, 5.000000000000001, 5.031152949374527, 5.062114182829148, 5.092887196865841, 5.1234753829798, 5.153882032022076, 5.18411033833193, 5.214163403653553, 5.244044240850758, 5.273755777432247, 5.303300858899107, 5.332682251925386, 5.361902647381805, 5.390964663211957, 5.419870847169701, 5.448623679425841, 5.477225575051662, 5.505678886386311, 5.5339859052946645, 5.562148865321748, 5.590169943749475, 5.618051263561059], [0.0, 0.6123724356957946, 0.8660254037844387, 1.0606601717798214, 1.2247448713915892, 1.3693063937629153, 1.5, 1.620185174601965, 1.7320508075688774, 1.8371173070873836, 1.9364916731037085, 2.0310096011589907, 2.121320343559643, 2.207940216581962, 2.29128784747792, 2.3717082451262845, 2.4494897427831783, 2.5248762345905194, 2.598076211353316, 2.6692695630078282, 2.7386127875258306, 2.8062430400804566, 2.8722813232690143, 2.936835031117683, 3.0, 3.061862178478973, 3.1224989991991996, 3.1819805153394647, 3.24037034920393, 3.2977264895682303, 3.3541019662496843, 3.4095454242464642, 3.464101615137755, 3.517811819867573, 3.570714214271425, 3.62284418654736, 3.6742346141747673, 3.7249161064378353, 3.7749172176353754, 3.8242646351945893, 3.872983346207417, 3.9210967853395307, 3.9686269665968865, 4.0155946010522525, 4.062019202317981, 4.107919181288746, 4.153311931459037, 4.198213905936667, 4.242640687119286, 4.286607049870562, 4.330127018922194, 4.373213921133976, 4.415880433163924, 4.4581386250317525, 4.500000000000001, 4.541475531146238, 4.58257569495584, 4.623310502226733, 4.663689526544408, 4.703721930556695, 4.743416490252569, 4.782781617427248, 4.8218253804964775, 4.860555523805895, 4.898979485566357, 4.937104414532875, 4.9749371855331, 5.0124844139408555, 5.049752469181039, 5.086747487343952, 5.123475382979799, 5.1599418601375735, 5.196152422706632, 5.232112384114088, 5.267826876426369, 5.303300858899107, 5.3385391260156565, 5.373546315051169, 5.408326913195984, 5.442885264269311, 5.477225575051661, 5.511351921262151, 5.54526825320471, 5.578978401105349, 5.612486080160913, 5.645794895318107, 5.678908345800274, 5.7118298293979315, 5.744562646538029, 5.777110004145671, 5.809475019311126, 5.841660722773962, 5.873670062235366, 5.905505905508859, 5.937171043518959, 5.9686681931566605, 6.0, 6.03116904090741, 6.062177826491071, 6.093028803476971, 6.123724356957946, 6.154266812545586], [0.0, 0.6614378277661477, 0.9354143466934854, 1.1456439237389602, 1.3228756555322954, 1.479019945774904, 1.620185174601965, 1.75, 1.8708286933869709, 1.984313483298443, 2.091650066335189, 2.193741096848031, 2.2912878474779204, 2.3848480035423645, 2.4748737341529163, 2.5617376914898995, 2.6457513110645907, 2.7271780286589284, 2.806243040080456, 2.883140648667699, 2.958039891549808, 3.0310889132455356, 3.1024184114977142, 3.17214438511238, 3.24037034920393, 3.3071891388307386, 3.372684390808011, 3.4369317712168805, 3.5, 3.561951712193752, 3.6228441865473595, 3.682729965664059, 3.7416573867739418, 3.7996710383926664, 3.856812155135378, 3.913118960624632, 3.968626966596886, 4.023369234857771, 4.077376607575023, 4.130677910464577, 4.183300132670378, 4.235268586524354, 4.286607049870562, 4.337337893224368, 4.387482193696062, 4.437059837324711, 4.4860896112315904, 4.534589286804264, 4.582575694955841, 4.630064794363033, 4.677071733467427, 4.723610906922796, 4.769696007084729, 4.815340071064556, 4.860555523805896, 4.9053542175871465, 4.949747468305833, 4.993746088859545, 5.0373604199024715, 5.080600358225394, 5.123475382979799, 5.165994579942956, 5.208166663999915, 5.25, 5.291502622129181, 5.332682251925386, 5.373546315051169, 5.414101956926929, 5.454356057317857, 5.494315243958978, 5.533985905294664, 5.573374202401989, 5.612486080160912, 5.651327277728658, 5.68990333837052, 5.7282196186948005, 5.766281297335398, 5.80409338312195, 5.841660722773962, 5.878988008152424, 5.916079783099616, 5.952940449895329, 5.989574275355471, 6.025985396596975, 6.062177826491071, 6.098155458825234, 6.1339220731926485, 6.169481339626533, 6.2048368229954285, 6.239991987174342, 6.274950199005566, 6.309714732061981, 6.34428877022476, 6.378675411086537, 6.412877669190331, 6.446898479113813, 6.48074069840786, 6.514407110397692, 6.547900426854397, 6.581223290544092, 6.614378277661477, 6.647367900154166], [0.0, 0.7071067811865476, 1.0, 1.2247448713915892, 1.4142135623730951, 1.5811388300841898, 1.7320508075688774, 1.8708286933869707, 2.0, 2.1213203435596424, 2.23606797749979, 2.3452078799117153, 2.4494897427831783, 2.5495097567963927, 2.6457513110645907, 2.7386127875258306, 2.8284271247461903, 2.91547594742265, 3.0, 3.0822070014844885, 3.1622776601683795, 3.24037034920393, 3.3166247903554, 3.391164991562634, 3.464101615137755, 3.5355339059327378, 3.6055512754639896, 3.6742346141747677, 3.7416573867739413, 3.8078865529319543, 3.8729833462074166, 3.9370039370059056, 4.0, 4.06201920231798, 4.123105625617661, 4.183300132670378, 4.242640687119285, 4.301162633521313, 4.358898943540674, 4.415880433163924, 4.47213595499958, 4.527692569068708, 4.582575694955841, 4.636809247747852, 4.690415759823431, 4.743416490252568, 4.795831523312719, 4.847679857416329, 4.898979485566357, 4.949747468305833, 5.0, 5.04975246918104, 5.099019513592785, 5.1478150704935, 5.196152422706632, 5.244044240850758, 5.291502622129181, 5.338539126015656, 5.385164807134504, 5.431390245600108, 5.477225575051661, 5.52268050859363, 5.5677643628300215, 5.612486080160911, 5.656854249492381, 5.70087712549569, 5.744562646538029, 5.787918451395113, 5.8309518948453, 5.873670062235366, 5.916079783099616, 5.958187643906492, 6.0, 6.041522986797286, 6.082762530298219, 6.123724356957945, 6.164414002968977, 6.2048368229954285, 6.244997998398398, 6.284902544988268, 6.324555320336759, 6.363961030678928, 6.403124237432849, 6.442049363362562, 6.48074069840786, 6.519202405202648, 6.557438524302, 6.59545297913646, 6.6332495807108, 6.670832032063166, 6.7082039324993685, 6.745368781616021, 6.782329983125268, 6.819090848492928, 6.855654600401045, 6.89202437604511, 6.92820323027551, 6.96419413859206, 7.0, 7.035623639735144, 7.0710678118654755, 7.106335201775948], [0.0, 0.75, 1.0606601717798212, 1.2990381056766582, 1.5, 1.6770509831248424, 1.8371173070873836, 1.9843134832984428, 2.1213203435596424, 2.25, 2.3717082451262845, 2.4874685927665503, 2.5980762113533165, 2.704163456597992, 2.806243040080456, 2.9047375096555625, 3.0, 3.092329219213245, 3.181980515339464, 3.2691742076555053, 3.3541019662496847, 3.43693177121688, 3.517811819867572, 3.59687364248454, 3.6742346141747673, 3.75, 3.8242646351945893, 3.8971143170299745, 3.9686269665968856, 4.0388736053508785, 4.107919181288746, 4.175823272122516, 4.242640687119285, 4.308421984903522, 4.373213921133975, 4.437059837324712, 4.5, 4.562071897723665, 4.623310502226732, 4.683748498798799, 4.743416490252569, 4.802343178074636, 4.860555523805895, 4.9180788932265, 4.974937185533101, 5.031152949374526, 5.086747487343951, 5.141740950300783, 5.196152422706633, 5.25, 5.303300858899107, 5.356071321407138, 5.408326913195984, 5.460082416960389, 5.511351921262151, 5.562148865321747, 5.612486080160912, 5.662375826453062, 5.7118298293979315, 5.760859310901456, 5.809475019311125, 5.8576872569299905, 5.905505905508858, 5.952940449895328, 6.0, 6.046693311223912, 6.093028803476971, 6.139014578904337, 6.18465843842649, 6.229967897188557, 6.274950199005566, 6.319612329882269, 6.363961030678928, 6.408002808988148, 6.451743950281969, 6.49519052838329, 6.5383484153110105, 6.5812232905440915, 6.623820649745886, 6.6661458129866915, 6.708203932499369, 6.75, 6.791538853603063, 6.8328251843582235, 6.87386354243376, 6.914658342969665, 6.955213871621777, 6.995534289816612, 7.035623639735144, 7.075485849042452, 7.115124735378854, 7.1545440106270926, 7.19374728496908, 7.232738070744716, 7.271519786124494, 7.310095758606722, 7.3484692283495345, 7.386643351347079, 7.4246212024587495, 7.46240577829965, 7.5, 7.5374067158406675], [0.0, 0.7905694150420949, 1.118033988749895, 1.3693063937629155, 1.5811388300841898, 1.7677669529663689, 1.9364916731037085, 2.091650066335189, 2.23606797749979, 2.3717082451262845, 2.5, 2.6220221204253793, 2.738612787525831, 2.8504385627478452, 2.958039891549808, 3.0618621784789726, 3.1622776601683795, 3.259601202601324, 3.3541019662496847, 3.446012188022556, 3.5355339059327378, 3.62284418654736, 3.7080992435478315, 3.7914377220257753, 3.872983346207417, 3.9528470752104745, 4.0311288741492755, 4.107919181288747, 4.183300132670378, 4.257346591481601, 4.330127018922193, 4.401704215414752, 4.47213595499958, 4.541475531146238, 4.6097722286464435, 4.677071733467427, 4.743416490252569, 4.808846015417837, 4.8733971724044824, 4.937104414532875, 5.0, 5.062114182829147, 5.1234753829798, 5.18411033833193, 5.244044240850759, 5.303300858899106, 5.361902647381804, 5.4198708471697, 5.477225575051662, 5.533985905294664, 5.5901699437494745, 5.645794895318108, 5.7008771254956905, 5.75543221661067, 5.809475019311126, 5.863019699779287, 5.916079783099616, 5.968668193156661, 6.020797289396148, 6.072478900745559, 6.123724356957945, 6.174544517614234, 6.224949798994366, 6.274950199005566, 6.324555320336759, 6.373774391990981, 6.422616289332565, 6.471089552772392, 6.519202405202648, 6.566962768281849, 6.614378277661476, 6.661456297237114, 6.708203932499369, 6.754628043053148, 6.800735254367721, 6.846531968814577, 6.892024376045112, 6.937218462755804, 6.982120021884471, 7.026734661277598, 7.0710678118654755, 7.115124735378854, 7.158910531638178, 7.202430145443967, 7.24568837309472, 7.2886898685566255, 7.33143914930759, 7.373940601876313, 7.416198487095663, 7.458216945088148, 7.5, 7.541551564499178, 7.582875444051551, 7.623975340988453, 7.664854858377947, 7.70551750371122, 7.745966692414834, 7.786205751198719, 7.826237921249264, 7.866066361276137, 7.905694150420949, 7.945124291035352], [0.0, 0.8291561975888501, 1.1726039399558574, 1.4361406616345076, 1.6583123951777001, 1.854049621773916, 2.03100960115899, 2.1937410968480306, 2.345207879911715, 2.4874685927665503, 2.6220221204253793, 2.750000000000001, 2.872281323269015, 2.98956518577535, 3.1024184114977142, 3.2113081446662823, 3.3166247903554003, 3.418698582794336, 3.5178118198675725, 3.6142080737002407, 3.708099243547832, 3.7996710383926664, 3.8890872965260117, 3.976493430146717, 4.06201920231798, 4.14578098794425, 4.227883631321942, 4.308421984903522, 4.387482193696061, 4.465142774872938, 4.541475531146237, 4.616546328154848, 4.69041575982343, 4.763139720814414, 4.834769901453429, 4.9053542175871465, 4.974937185533101, 5.043560250458005, 5.111262075065219, 5.178078794301996, 5.244044240850759, 5.3091901453988255, 5.37354631505117, 5.437140792732887, 5.500000000000002, 5.562148865321747, 5.623610939600996, 5.684408500451037, 5.74456264653803, 5.80409338312195, 5.863019699779287, 5.921359641163507, 5.9791303715507, 6.036348233824819, 6.0930288034769715, 6.149186938124423, 6.2048368229954285, 6.259992012774458, 6.314665470157545, 6.368869601428498, 6.422616289332565, 6.475916923494309, 6.528782428600298, 6.5812232905440915, 6.6332495807108005, 6.684870978560469, 6.736096792653741, 6.7869359802491145, 6.837397165588672, 6.887488656977957, 6.937218462755804, 6.986594306241061, 7.035623639735145, 7.084313657652378, 7.132671308843553, 7.180703308172537, 7.228416147400481, 7.275816105427625, 7.322909257938406, 7.369701486491838, 7.416198487095664, 7.46240577829965, 7.5083287088406045, 7.553972464869064, 7.599342076785333, 7.644442425710328, 7.6892782496148495, 7.7338541491290105, 7.778174593052023, 7.8222439235810075, 7.866066361276137, 7.909646009778188, 7.952986860293434, 7.996092795859739, 8.038967595406765, 8.081614937622307, 8.12403840463596, 8.16624148553054, 8.208227579691004, 8.250000000000002, 8.2915619758885, 8.33291665624948], [0.0, 0.8660254037844388, 1.2247448713915892, 1.5000000000000004, 1.7320508075688776, 1.9364916731037087, 2.121320343559643, 2.2912878474779204, 2.4494897427831783, 2.5980762113533165, 2.738612787525831, 2.872281323269015, 3.000000000000001, 3.1224989991992, 3.2403703492039306, 3.354101966249685, 3.4641016151377553, 3.570714214271425, 3.6742346141747677, 3.774917217635376, 3.8729833462074175, 3.968626966596887, 4.06201920231798, 4.153311931459038, 4.242640687119286, 4.3301270189221945, 4.415880433163925, 4.500000000000002, 4.582575694955841, 4.663689526544409, 4.743416490252569, 4.821825380496478, 4.898979485566357, 4.9749371855331015, 5.04975246918104, 5.1234753829798, 5.196152422706633, 5.267826876426371, 5.3385391260156565, 5.408326913195985, 5.477225575051662, 5.54526825320471, 5.612486080160914, 5.6789083458002745, 5.74456264653803, 5.809475019311125, 5.873670062235366, 5.937171043518959, 6.000000000000002, 6.062177826491071, 6.123724356957946, 6.184658438426492, 6.2449979983984, 6.304760106459248, 6.363961030678929, 6.422616289332566, 6.480740698407861, 6.538348415311011, 6.595452979136461, 6.652067347825036, 6.70820393249937, 6.763874629234342, 6.819090848492929, 6.87386354243376, 6.9282032302755105, 6.982120021884471, 7.035623639735145, 7.088723439378914, 7.14142842854285, 7.1937472849690804, 7.24568837309472, 7.297259759663214, 7.348469228349535, 7.399324293474372, 7.44983221287567, 7.500000000000001, 7.549834435270752, 7.599342076785333, 7.6485292703891785, 7.697402159170328, 7.745966692414835, 7.794228634059949, 7.842193570679063, 7.8898669190297515, 7.937253933193774, 7.984359711335657, 8.031189202104507, 8.077747210701757, 8.12403840463596, 8.170067319184096, 8.215838362577493, 8.261355820929154, 8.306623862918077, 8.351646544245034, 8.396427811873334, 8.440971508067067, 8.485281374238571, 8.529361054615991, 8.573214099741126, 8.616843969807045, 8.660254037844389, 8.703447592764606], [0.0, 0.9013878188659974, 1.2747548783981963, 1.5612494995996, 1.8027756377319948, 2.0155644370746377, 2.207940216581962, 2.3848480035423645, 2.5495097567963927, 2.704163456597992, 2.8504385627478452, 2.98956518577535, 3.1224989991992, 3.2500000000000004, 3.3726843908080104, 3.4910600109422356, 3.6055512754639896, 3.7165171868296265, 3.8242646351945893, 3.9290584113754283, 4.0311288741492755, 4.130677910464577, 4.227883631321941, 4.322904116447646, 4.415880433163924, 4.506939094329987, 4.59619407771256, 4.6837484987988, 4.769696007084729, 4.854121959736901, 4.937104414532874, 5.018714974971183, 5.099019513592785, 5.178078794301996, 5.25594901040716, 5.3326822519253865, 5.408326913195984, 5.482928049865328, 5.556527692723218, 5.6291651245988525, 5.7008771254956905, 5.771698190307598, 5.8416607227739625, 5.9107952087684446, 5.9791303715507, 6.046693311223912, 6.113509630318742, 6.179603547154138, 6.2449979983984, 6.309714732061981, 6.373774391990982, 6.4371965947918675, 6.500000000000001, 6.562202374203345, 6.623820649745887, 6.68487097856047, 6.745368781616021, 6.8053287944081005, 6.864765108872991, 6.923691212063114, 6.982120021884471, 7.0400639201643616, 7.097534783289196, 7.1545440106270926, 7.211102550927979, 7.267220926874317, 7.322909257938406, 7.378177281686853, 7.433034373659253, 7.487489565935969, 7.541551564499178, 7.595228765481657, 7.6485292703891785, 7.701460900374682, 7.754031209635411, 7.806247497997998, 7.858116822750857, 7.9096460097781875, 7.96084166404533, 8.011710179481033, 8.062257748298551, 8.112490369793976, 8.162413858657256, 8.212033852828421, 8.261355820929154, 8.31038506929733, 8.359126748650244, 8.40758586040012, 8.455767262643882, 8.503675675847475, 8.551315688243536, 8.59869176095992, 8.645808232895291, 8.692669325356855, 8.739279146474269, 8.78564169540279, 8.831760866327848, 8.877640452282353, 8.923284148787374, 8.968695557326049, 9.013878188659975, 9.05883546599672], [0.0, 0.9354143466934853, 1.3228756555322954, 1.6201851746019653, 1.8708286933869707, 2.091650066335189, 2.29128784747792, 2.4748737341529163, 2.6457513110645907, 2.806243040080456, 2.958039891549808, 3.1024184114977147, 3.2403703492039306, 3.3726843908080104, 3.5, 3.6228441865473595, 3.7416573867739413, 3.8568121551353776, 3.968626966596886, 4.077376607575023, 4.183300132670378, 4.286607049870562, 4.387482193696061, 4.4860896112315904, 4.58257569495584, 4.677071733467427, 4.769696007084729, 4.860555523805896, 4.949747468305833, 5.0373604199024715, 5.123475382979798, 5.208166663999915, 5.291502622129181, 5.37354631505117, 5.454356057317857, 5.533985905294664, 5.612486080160912, 5.689903338370522, 5.766281297335398, 5.841660722773962, 5.916079783099616, 5.989574275355469, 6.062177826491071, 6.1339220731926485, 6.204836822995429, 6.274950199005565, 6.34428877022476, 6.412877669190331, 6.480740698407861, 6.547900426854397, 6.614378277661476, 6.680194607943695, 6.745368781616021, 6.809919235938119, 6.87386354243376, 6.937218462755804, 7.0, 7.0622234459127675, 7.123903424387503, 7.185053931599956, 7.245688373094719, 7.305819598101229, 7.365459931328117, 7.424621202458749, 7.483314773547883, 7.541551564499178, 7.599342076785332, 7.656696415556777, 7.713624310270755, 7.770135133960027, 7.826237921249263, 7.881941385217224, 7.937253933193772, 7.99218368157289, 8.046738469715539, 8.100925873009825, 8.154753215150047, 8.208227579691002, 8.261355820929154, 8.314144574157945, 8.366600265340756, 8.418729120241368, 8.47053717304871, 8.522030274529655, 8.573214099741124, 8.62409415533017, 8.674675786448736, 8.724964183307574, 8.774964387392123, 8.824681297361394, 8.874119674649425, 8.923284148787374, 8.972179222463181, 9.020809276334358, 9.069178573608529, 9.117291264405234, 9.16515138991168, 9.212762886344139, 9.260129588726068, 9.307255234493143, 9.354143466934854, 9.400797838481584], [0.0, 0.9682458365518541, 1.3693063937629153, 1.6770509831248424, 1.9364916731037083, 2.1650635094610964, 2.3717082451262845, 2.5617376914898995, 2.7386127875258306, 2.9047375096555625, 3.0618621784789726, 3.2113081446662823, 3.3541019662496847, 3.491060010942235, 3.6228441865473595, 3.7499999999999996, 3.8729833462074166, 3.9921798556678274, 4.107919181288746, 4.220485754033533, 4.330127018922193, 4.437059837324712, 4.541475531146237, 4.643543905251677, 4.743416490252569, 4.841229182759271, 4.937104414532875, 5.031152949374527, 5.123475382979799, 5.2141634036535525, 5.303300858899106, 5.390964663211956, 5.477225575051661, 5.562148865321747, 5.645794895318107, 5.7282196186948, 5.809475019311125, 5.889609494694874, 5.968668193156661, 6.046693311223913, 6.123724356957945, 6.199798383818622, 6.274950199005567, 6.349212549600146, 6.422616289332565, 6.495190528383288, 6.566962768281848, 6.637959023675877, 6.708203932499369, 6.777720855862979, 6.846531968814576, 6.914658342969665, 6.98212002188447, 7.048936089935842, 7.115124735378854, 7.180703308172536, 7.245688373094719, 7.310095758606723, 7.3739406018763125, 7.437237390321758, 7.499999999999999, 7.562241731127086, 7.623975340988452, 7.685213074469698, 7.745966692414833, 7.806247497997997, 7.866066361276136, 7.925433742073679, 7.984359711335655, 8.042853971072706, 8.100925873009825, 8.15858443604036, 8.215838362577491, 8.272696053887147, 8.32916562447884, 8.38525491562421, 8.440971508067067, 8.496322733983213, 8.551315688243536, 8.605957239029252, 8.660254037844386, 8.714212528966687, 8.76783895837509, 8.821139382188674, 8.874119674649425, 8.926785535678562, 8.979142498033985, 9.031195934094221, 9.082951062292475, 9.134412953222554, 9.185586535436917, 9.236476600955582, 9.287087810503355, 9.33742469849155, 9.387491677759293, 9.437293044088435, 9.486832980505138, 9.536115561380326, 9.585144756340407, 9.633924433998846, 9.682458365518542, 9.730750228014282], [0.0, 1.0, 1.4142135623730951, 1.7320508075688776, 2.0, 2.23606797749979, 2.4494897427831783, 2.6457513110645907, 2.8284271247461903, 3.0, 3.1622776601683795, 3.3166247903554007, 3.4641016151377553, 3.6055512754639896, 3.7416573867739413, 3.872983346207417, 4.0, 4.123105625617661, 4.242640687119286, 4.358898943540674, 4.47213595499958, 4.582575694955841, 4.69041575982343, 4.79583152331272, 4.898979485566357, 5.000000000000001, 5.099019513592785, 5.196152422706633, 5.291502622129181, 5.385164807134505, 5.47722557505166, 5.567764362830022, 5.656854249492381, 5.7445626465380295, 5.830951894845301, 5.916079783099616, 6.0, 6.08276253029822, 6.164414002968977, 6.244997998398399, 6.324555320336759, 6.4031242374328485, 6.480740698407861, 6.557438524302, 6.633249580710801, 6.7082039324993685, 6.782329983125268, 6.855654600401045, 6.9282032302755105, 7.0, 7.0710678118654755, 7.141428428542851, 7.211102550927979, 7.280109889280519, 7.348469228349535, 7.416198487095664, 7.483314773547883, 7.549834435270751, 7.615773105863909, 7.681145747868608, 7.745966692414834, 7.810249675906654, 7.874007874011811, 7.937253933193771, 8.0, 8.06225774829855, 8.12403840463596, 8.18535277187245, 8.246211251235321, 8.306623862918075, 8.366600265340756, 8.426149773176359, 8.485281374238571, 8.544003745317532, 8.602325267042627, 8.660254037844387, 8.717797887081348, 8.774964387392123, 8.831760866327848, 8.888194417315589, 8.94427190999916, 9.0, 9.055385138137417, 9.1104335791443, 9.165151389911681, 9.219544457292887, 9.273618495495704, 9.327379053088816, 9.38083151964686, 9.433981132056603, 9.486832980505138, 9.539392014169456, 9.59166304662544, 9.643650760992955, 9.695359714832659, 9.746794344808963, 9.797958971132713, 9.848857801796106, 9.899494936611665, 9.9498743710662, 10.000000000000002, 10.049875621120892], [0.0, 1.0307764064044151, 1.4577379737113252, 1.7853571071357128, 2.0615528128088303, 2.3048861143232218, 2.52487623459052, 2.7271780286589284, 2.9154759474226504, 3.0923292192132457, 3.259601202601324, 3.4186985827943364, 3.5707142142714257, 3.716517186829627, 3.856812155135378, 3.992179855667828, 4.123105625617661, 4.25, 4.373213921133976, 4.493050188902858, 4.6097722286464435, 4.723610906922796, 4.834769901453429, 4.943429983321297, 5.04975246918104, 5.153882032022076, 5.255949010407161, 5.356071321407138, 5.454356057317857, 5.55090082779363, 5.645794895318107, 5.739120141624499, 5.830951894845301, 5.921359641163507, 6.010407640085654, 6.098155458825234, 6.184658438426491, 6.269968101992227, 6.354132513569418, 6.4371965947918675, 6.519202405202648, 6.600189391222043, 6.680194607943695, 6.7592529172978875, 6.837397165588673, 6.914658342969664, 6.991065727054781, 7.066647012551285, 7.141428428542851, 7.215434844830906, 7.288689868556626, 7.361215932167729, 7.433034373659254, 7.504165509901818, 7.574628703771559, 7.644442425710328, 7.713624310270756, 7.782191208136691, 7.850159234053791, 7.917543811056557, 7.984359711335656, 8.050621094052309, 8.116341540373963, 8.181534085976786, 8.246211251235321, 8.31038506929733, 8.374067112222113, 8.437268515343103, 8.5, 8.562271894771856, 8.62409415533017, 8.685476383020106, 8.746427842267952, 8.806957476904268, 8.8670739254841, 8.926785535678563, 8.986100377805716, 9.045026257562771, 9.103570728016564, 9.161741100904347, 9.219544457292887, 9.276987657639737, 9.334077351297235, 9.390819985496474, 9.447221813845593, 9.503288904374106, 9.55902714715258, 9.614442261514705, 9.669539802906858, 9.724325169388361, 9.778803607803972, 9.832980219648569, 9.886859966642595, 9.940447676035522, 9.993748045653343, 10.046765648705058, 10.09950493836208, 10.151970252123476, 10.204165815979277, 10.256095748383007, 10.307764064044152, 10.359174677550332], [0.0, 1.0606601717798214, 1.5, 1.8371173070873839, 2.121320343559643, 2.3717082451262845, 2.598076211353316, 2.806243040080456, 3.0, 3.181980515339464, 3.3541019662496847, 3.517811819867573, 3.6742346141747677, 3.8242646351945893, 3.968626966596886, 4.107919181288746, 4.242640687119286, 4.373213921133975, 4.5, 4.623310502226733, 4.743416490252569, 4.860555523805895, 4.9749371855331, 5.086747487343951, 5.196152422706632, 5.303300858899107, 5.408326913195985, 5.511351921262151, 5.612486080160912, 5.7118298293979315, 5.809475019311125, 5.905505905508859, 6.0, 6.0930288034769715, 6.18465843842649, 6.274950199005567, 6.363961030678928, 6.451743950281971, 6.538348415311011, 6.623820649745886, 6.708203932499369, 6.791538853603063, 6.873863542433761, 6.955213871621778, 7.035623639735146, 7.115124735378853, 7.193747284969079, 7.271519786124494, 7.348469228349535, 7.424621202458749, 7.500000000000001, 7.57462870377156, 7.6485292703891785, 7.7217226057402515, 7.794228634059949, 7.866066361276137, 7.937253933193772, 8.007808689023484, 8.077747210701757, 8.14708536840016, 8.215838362577491, 8.284020762890446, 8.351646544245034, 8.418729120241368, 8.485281374238571, 8.551315688243536, 8.616843969807043, 8.68187767709267, 8.74642784226795, 8.810505093353049, 8.874119674649425, 8.937281465859739, 9.0, 9.06228448019593, 9.12414379544733, 9.185586535436919, 9.246621004453466, 9.307255234493143, 9.367496997597598, 9.427353817482402, 9.486832980505138, 9.545941546018392, 9.604686356149275, 9.663074045043844, 9.72111104761179, 9.778803607803972, 9.836157786453, 9.893179468704691, 9.9498743710662, 10.006248048094749, 10.062305898749054, 10.118053172424032, 10.173494974687902, 10.228636272739392, 10.283481900601567, 10.338036564067666, 10.392304845413264, 10.446291207888091, 10.5, 10.553435459602717, 10.606601717798213, 10.659502802663923], [0.0, 1.0897247358851685, 1.5411035007422444, 1.887458608817688, 2.179449471770337, 2.4366985862022412, 2.6692695630078282, 2.883140648667699, 3.082207001484489, 3.2691742076555057, 3.446012188022556, 3.614208073700241, 3.774917217635376, 3.9290584113754288, 4.077376607575023, 4.220485754033533, 4.358898943540674, 4.493050188902857, 4.623310502226733, 4.750000000000001, 4.8733971724044824, 4.993746088859545, 5.111262075065219, 5.226136240091718, 5.3385391260156565, 5.448623679425843, 5.556527692723218, 5.662375826453064, 5.766281297335398, 5.868347297152752, 5.968668193156661, 6.067330549755799, 6.164414002968978, 6.259992012774459, 6.354132513569418, 6.446898479113814, 6.538348415311011, 6.6285367917814275, 6.717514421272203, 6.805328794408101, 6.892024376045112, 6.9776428684764324, 7.062223445912769, 7.145802963978227, 7.228416147400482, 7.310095758606723, 7.390872749547242, 7.470776398741969, 7.549834435270752, 7.62807315119618, 7.705517503711222, 7.782191208136692, 7.8581168227508575, 7.933315826311217, 8.007808689023484, 8.081614937622309, 8.154753215150047, 8.227241335952169, 8.299096336348917, 8.370334521391603, 8.440971508067067, 8.511022265274601, 8.580501150865258, 8.649421946003097, 8.717797887081348, 8.78564169540279, 8.852965604812887, 8.919781387455638, 8.986100377805714, 9.051933495115838, 9.117291264405235, 9.18218383610348, 9.246621004453466, 9.310612224768038, 9.374166629626338, 9.437293044088438, 9.500000000000002, 9.56229574945264, 9.62418827746008, 9.68568531390526, 9.746794344808965, 9.807522622966516, 9.867877177995277, 9.927864825832392, 9.98749217771909, 10.04676564870506, 10.105691465703869, 10.164275675128064, 10.222524150130438, 10.280442597476044, 10.338036564067668, 10.395311443145896, 10.452272480183437, 10.508924778491853, 10.565273304557723, 10.621322893124, 10.677078252031313, 10.732543966832843, 10.78772450519571, 10.842624221100722, 10.897247358851686, 10.951598056904757], [0.0, 1.118033988749895, 1.5811388300841898, 1.936491673103709, 2.23606797749979, 2.5000000000000004, 2.738612787525831, 2.958039891549808, 3.1622776601683795, 3.3541019662496847, 3.5355339059327378, 3.7080992435478324, 3.872983346207418, 4.0311288741492755, 4.183300132670378, 4.330127018922194, 4.47213595499958, 4.6097722286464435, 4.74341649025257, 4.8733971724044824, 5.000000000000001, 5.1234753829798, 5.244044240850758, 5.361902647381805, 5.477225575051662, 5.590169943749475, 5.700877125495691, 5.809475019311127, 5.916079783099616, 6.020797289396149, 6.123724356957945, 6.224949798994366, 6.324555320336759, 6.4226162893325665, 6.519202405202649, 6.614378277661477, 6.708203932499369, 6.800735254367723, 6.892024376045112, 6.982120021884472, 7.0710678118654755, 7.158910531638177, 7.245688373094721, 7.33143914930759, 7.416198487095665, 7.499999999999999, 7.582875444051551, 7.664854858377947, 7.745966692414836, 7.826237921249264, 7.905694150420949, 7.9843597113356575, 8.062257748298551, 8.139410298049855, 8.215838362577493, 8.2915619758885, 8.366600265340756, 8.440971508067067, 8.514693182963201, 8.587782018658833, 8.660254037844387, 8.732124598286491, 8.803408430829505, 8.874119674649425, 8.94427190999916, 9.013878188659973, 9.082951062292477, 9.151502608861565, 9.219544457292887, 9.287087810503357, 9.354143466934854, 9.420721840708387, 9.48683298050514, 9.552486587271401, 9.617692030835672, 9.682458365518544, 9.746794344808965, 9.810708435174293, 9.87420882906575, 9.937303457175897, 10.000000000000002, 10.062305898749054, 10.124228365658295, 10.185774393731682, 10.2469507659596, 10.307764064044152, 10.36822067666386, 10.428326807307107, 10.488088481701515, 10.547511554864494, 10.606601717798213, 10.665364503850771, 10.72380529476361, 10.781929326423914, 10.839741694339402, 10.897247358851683, 10.954451150103324, 11.011357772772621, 11.067971810589329, 11.124297730643496, 11.18033988749895, 11.236102527122117], [0.0, 1.1456439237389602, 1.6201851746019653, 1.9843134832984435, 2.2912878474779204, 2.5617376914899, 2.806243040080456, 3.0310889132455356, 3.2403703492039306, 3.43693177121688, 3.62284418654736, 3.799671038392667, 3.968626966596887, 4.130677910464577, 4.286607049870562, 4.437059837324712, 4.582575694955841, 4.723610906922796, 4.860555523805895, 4.993746088859545, 5.1234753829798, 5.250000000000001, 5.373546315051169, 5.494315243958978, 5.612486080160912, 5.7282196186948005, 5.8416607227739625, 5.95294044989533, 6.062177826491071, 6.169481339626534, 6.274950199005566, 6.378675411086538, 6.480740698407861, 6.581223290544093, 6.680194607943694, 6.77772085586298, 6.87386354243376, 6.9686799323831785, 7.062223445912768, 7.154544010627093, 7.24568837309472, 7.335700375560605, 7.42462120245875, 7.51248960065836, 7.599342076785334, 7.685213074469698, 7.770135133960027, 7.854139036202505, 7.937253933193774, 8.01950746617272, 8.100925873009826, 8.181534085976788, 8.261355820929154, 8.34041365880614, 8.41872912024137, 8.496322733983215, 8.573214099741124, 8.649421946003098, 8.724964183307575, 8.799857953399021, 8.874119674649425, 8.94776508408664, 9.020809276334358, 9.093266739736606, 9.165151389911681, 9.236476600955584, 9.307255234493143, 9.377499666755527, 9.447221813845593, 9.516433155337142, 9.585144756340407, 9.653367288153913, 9.72111104761179, 9.788385975225946, 9.85520167221351, 9.921567416492216, 9.98749217771909, 10.05298463144155, 10.118053172424032, 10.18270592720815, 10.2469507659596, 10.31079531365064, 10.374246960623216, 10.437312872574052, 10.500000000000002, 10.562315087138805, 10.62426468043789, 10.685855136581257, 10.747092630102339, 10.807983160608643, 10.86853255964208, 10.928746497197197, 10.988630487917955, 11.048189896992177, 11.107429945761533, 11.166355717063647, 11.224972160321824, 11.283284096396759, 11.341296222213757, 11.399013115177999, 11.456439237389601, 11.513578939669456], [0.0, 1.1726039399558574, 1.6583123951777001, 2.0310096011589907, 2.345207879911715, 2.622022120425379, 2.8722813232690148, 3.1024184114977142, 3.3166247903554003, 3.5178118198675725, 3.7080992435478315, 3.889087296526012, 4.062019202317981, 4.227883631321942, 4.387482193696061, 4.541475531146237, 4.69041575982343, 4.834769901453429, 4.974937185533101, 5.111262075065219, 5.244044240850758, 5.37354631505117, 5.5, 5.623610939600996, 5.7445626465380295, 5.863019699779287, 5.9791303715507, 6.0930288034769715, 6.2048368229954285, 6.314665470157545, 6.422616289332564, 6.528782428600298, 6.6332495807108005, 6.736096792653741, 6.837397165588672, 6.937218462755805, 7.035623639735145, 7.132671308843554, 7.228416147400481, 7.322909257938406, 7.416198487095663, 7.508328708840604, 7.599342076785333, 7.6892782496148495, 7.778174593052024, 7.866066361276136, 7.952986860293433, 8.038967595406763, 8.124038404635963, 8.208227579691002, 8.2915619758885, 8.374067112222114, 8.455767262643883, 8.536685539481937, 8.616843969807045, 8.696263565463044, 8.774964387392123, 8.852965604812887, 8.930285549745877, 9.00694176732591, 9.082951062292475, 9.1583295420071, 9.233092656309694, 9.307255234493143, 9.38083151964686, 9.453835200594519, 9.526279441628827, 9.598176910226234, 9.669539802906858, 9.740379869389079, 9.810708435174291, 9.880536422684752, 9.949874371066201, 10.01873245475694, 10.087120500916006, 10.155048005794951, 10.222524150130438, 10.28955781362834, 10.35615758860399, 10.422331792837916, 10.488088481701515, 10.553435459602717, 10.618380290797653, 10.682930309610748, 10.74709263010234, 10.810874155219826, 10.874281585465774, 10.93732142711368, 11.0, 11.062323444918793, 11.124297730643494, 11.185928660598547, 11.247221879201993, 11.308182877898641, 11.368817000902075, 11.42912945066246, 11.489125293076059, 11.548809462451098, 11.6081867662439, 11.667261889578036, 11.726039399558575, 11.784523749392676], [0.0, 1.19895788082818, 1.6955824957813173, 2.076655965729519, 2.39791576165636, 2.6809513236909024, 2.936835031117683, 3.1721443851123805, 3.3911649915626345, 3.59687364248454, 3.7914377220257753, 3.9764934301467174, 4.153311931459038, 4.3229041164476465, 4.4860896112315904, 4.643543905251677, 4.79583152331272, 4.943429983321297, 5.086747487343952, 5.226136240091719, 5.361902647381805, 5.494315243958979, 5.623610939600996, 5.750000000000001, 5.873670062235366, 5.9947894041409, 6.1135096303187435, 6.2299678971885575, 6.344288770224761, 6.45658578507248, 6.566962768281848, 6.675514961409345, 6.782329983125269, 6.887488656977957, 6.991065727054782, 7.093130479555555, 7.19374728496908, 7.292976072907412, 7.390872749547243, 7.48748956593597, 7.582875444051551, 7.677076266392044, 7.770135133960028, 7.8620925967581945, 7.952986860293435, 8.042853971072706, 8.131727983645296, 8.2196411113868, 8.306623862918077, 8.39270516579726, 8.477912478906585, 8.562271894771856, 8.645808232895293, 8.728545125048047, 8.810505093353049, 8.89170962188937, 8.972179222463181, 9.051933495115838, 9.130991183874839, 9.209370228196931, 9.287087810503355, 9.364160400164021, 9.440603794249604, 9.51643315533714, 9.59166304662544, 9.666307464590604, 9.740379869389079, 9.813893213195263, 9.886859966642595, 9.959292143521045, 10.03120132386944, 10.102598675588377, 10.173494974687904, 10.24390062427394, 10.313825672368134, 10.383279828647595, 10.452272480183439, 10.520812706250407, 10.588909292273687, 10.656570742973559, 10.72380529476361, 10.79062092745362, 10.857025375304234, 10.92302613747674, 10.988630487917957, 11.053845484717073, 11.118677978968543, 11.183134623172522, 11.247221879201993, 11.31094602586362, 11.374313166077327, 11.437329233697875, 11.500000000000002, 11.562331079847178, 11.624327937562672, 11.685995892520243, 11.747340124470732, 11.808365678619545, 11.86907747046922, 11.929480290440152, 11.9895788082818, 12.049377577285892], [0.0, 1.2247448713915892, 1.7320508075688774, 2.121320343559643, 2.4494897427831783, 2.7386127875258306, 3.0, 3.24037034920393, 3.464101615137755, 3.6742346141747673, 3.872983346207417, 4.062019202317981, 4.242640687119286, 4.415880433163924, 4.58257569495584, 4.743416490252569, 4.898979485566357, 5.049752469181039, 5.196152422706632, 5.3385391260156565, 5.477225575051661, 5.612486080160913, 5.744562646538029, 5.873670062235366, 6.0, 6.123724356957946, 6.244997998398399, 6.363961030678929, 6.48074069840786, 6.595452979136461, 6.7082039324993685, 6.8190908484929285, 6.92820323027551, 7.035623639735146, 7.14142842854285, 7.24568837309472, 7.3484692283495345, 7.449832212875671, 7.549834435270751, 7.6485292703891785, 7.745966692414834, 7.842193570679061, 7.937253933193773, 8.031189202104505, 8.124038404635963, 8.215838362577491, 8.306623862918075, 8.396427811873334, 8.485281374238571, 8.573214099741124, 8.660254037844387, 8.746427842267952, 8.831760866327848, 8.916277250063505, 9.000000000000002, 9.082951062292477, 9.16515138991168, 9.246621004453466, 9.327379053088816, 9.40744386111339, 9.486832980505138, 9.565563234854496, 9.643650760992955, 9.72111104761179, 9.797958971132713, 9.87420882906575, 9.9498743710662, 10.024968827881711, 10.099504938362077, 10.173494974687904, 10.246950765959598, 10.319883720275147, 10.392304845413264, 10.464224768228176, 10.535653752852738, 10.606601717798213, 10.677078252031313, 10.747092630102339, 10.816653826391969, 10.885770528538622, 10.954451150103322, 11.022703842524303, 11.09053650640942, 11.157956802210698, 11.224972160321826, 11.291589790636214, 11.357816691600547, 11.423659658795863, 11.489125293076057, 11.554220008291342, 11.618950038622252, 11.683321445547923, 11.747340124470732, 11.811011811017718, 11.874342087037919, 11.937336386313321, 12.0, 12.06233808181482, 12.124355652982143, 12.186057606953941, 12.247448713915892, 12.308533625091172], [0.0, 1.2500000000000002, 1.767766952966369, 2.1650635094610973, 2.5000000000000004, 2.7950849718747373, 3.061862178478973, 3.3071891388307386, 3.535533905932738, 3.7500000000000004, 3.9528470752104745, 4.145780987944251, 4.3301270189221945, 4.506939094329987, 4.677071733467427, 4.841229182759271, 5.000000000000001, 5.153882032022076, 5.303300858899107, 5.448623679425843, 5.5901699437494745, 5.7282196186948005, 5.863019699779287, 5.9947894041409, 6.123724356957946, 6.250000000000001, 6.373774391990983, 6.495190528383291, 6.614378277661477, 6.731456008918131, 6.846531968814576, 6.959705453537528, 7.071067811865476, 7.1807033081725375, 7.2886898685566255, 7.395099728874521, 7.500000000000001, 7.603453162872776, 7.705517503711222, 7.806247497997999, 7.905694150420949, 8.00390529679106, 8.100925873009826, 8.1967981553775, 8.291561975888502, 8.38525491562421, 8.477912478906585, 8.569568250501305, 8.660254037844389, 8.75, 8.838834764831844, 8.926785535678563, 9.013878188659975, 9.10013736160065, 9.185586535436919, 9.27024810886958, 9.354143466934854, 9.437293044088438, 9.519716382329886, 9.60143218483576, 9.682458365518542, 9.762812094883317, 9.842509842514765, 9.921567416492215, 10.000000000000002, 10.077822185373188, 10.155048005794951, 10.231690964840563, 10.307764064044152, 10.383279828647595, 10.458250331675945, 10.53268721647045, 10.606601717798213, 10.680004681646915, 10.752906583803282, 10.825317547305485, 10.897247358851686, 10.968705484240154, 11.03970108290981, 11.110243021644488, 11.180339887498949, 11.25, 11.319231422671773, 11.388041973930374, 11.456439237389601, 11.52443057161611, 11.59202311936963, 11.65922381636102, 11.726039399558575, 11.792476415070755, 11.858541225631424, 11.924240017711822, 11.9895788082818, 12.054563451241195, 12.119199643540824, 12.183492931011205, 12.247448713915892, 12.311072252245133, 12.374368670764584, 12.437342963832752, 12.500000000000002, 12.562344526401114], [0.0, 1.2747548783981963, 1.8027756377319948, 2.2079402165819624, 2.5495097567963927, 2.8504385627478452, 3.1224989991991996, 3.372684390808011, 3.6055512754639896, 3.824264635194589, 4.0311288741492755, 4.227883631321942, 4.415880433163925, 4.59619407771256, 4.769696007084729, 4.937104414532875, 5.099019513592785, 5.25594901040716, 5.408326913195984, 5.556527692723218, 5.7008771254956905, 5.8416607227739625, 5.979130371550699, 6.113509630318743, 6.244997998398399, 6.373774391990982, 6.500000000000002, 6.623820649745887, 6.745368781616022, 6.864765108872992, 6.98212002188447, 7.097534783289196, 7.211102550927979, 7.322909257938407, 7.433034373659253, 7.541551564499179, 7.648529270389178, 7.7540312096354125, 7.858116822750857, 7.96084166404533, 8.062257748298551, 8.162413858657255, 8.261355820929154, 8.359126748650244, 8.455767262643883, 8.551315688243534, 8.645808232895291, 8.739279146474269, 8.83176086632785, 8.923284148787374, 9.013878188659975, 9.103570728016564, 9.19238815542512, 9.280355596635294, 9.367496997597598, 9.45383520059452, 9.539392014169458, 9.62418827746008, 9.7082439194738, 9.79157801378307, 9.87420882906575, 9.956153875869939, 10.037429949942366, 10.118053172424032, 10.19803902718557, 10.277402395547234, 10.35615758860399, 10.434318377354604, 10.51189802081432, 10.588909292273687, 10.665364503850771, 10.74127552947042, 10.816653826391969, 10.891510455395983, 10.965856099730654, 11.03970108290981, 11.113055385446437, 11.185928660598547, 11.258330249197705, 11.33026919362466, 11.401754250991381, 11.472793905583767, 11.543396380615198, 11.613569649336934, 11.683321445547925, 11.75265927354316, 11.821590417536889, 11.890121950594116, 11.958260743101398, 12.026013470805694, 12.093386622447825, 12.16038650701531, 12.227019260637485, 12.293290853144248, 12.359207094308278, 12.424773639789176, 12.489995996796798, 12.554879529489721, 12.619429464123964, 12.683650893965824, 12.747548783981964, 12.811127975318959], [0.0, 1.2990381056766582, 1.8371173070873839, 2.2500000000000004, 2.5980762113533165, 2.904737509655563, 3.1819805153394642, 3.43693177121688, 3.6742346141747677, 3.897114317029974, 4.107919181288747, 4.308421984903522, 4.500000000000001, 4.683748498798799, 4.860555523805895, 5.031152949374527, 5.196152422706633, 5.356071321407137, 5.511351921262151, 5.662375826453063, 5.809475019311126, 5.95294044989533, 6.093028803476971, 6.229967897188557, 6.3639610306789285, 6.495190528383291, 6.623820649745887, 6.750000000000002, 6.87386354243376, 6.995534289816613, 7.115124735378854, 7.232738070744717, 7.348469228349535, 7.462405778299652, 7.574628703771559, 7.6852130744697, 7.794228634059948, 7.9017403146395555, 8.007808689023484, 8.112490369793978, 8.215838362577493, 8.317902379807064, 8.41872912024137, 8.51836251870041, 8.616843969807045, 8.714212528966687, 8.810505093353049, 8.90575656527844, 9.000000000000002, 9.093266739736606, 9.185586535436919, 9.276987657639738, 9.367496997597598, 9.457140159688871, 9.545941546018394, 9.633924433998848, 9.72111104761179, 9.807522622966516, 9.893179468704691, 9.978101021737553, 10.062305898749054, 10.145811943851513, 10.228636272739394, 10.31079531365064, 10.392304845413266, 10.473180032826706, 10.553435459602717, 10.63308515906837, 10.712142642814275, 10.79062092745362, 10.868532559642079, 10.945889639494819, 11.022703842524303, 11.098986440211558, 11.174748319313505, 11.250000000000002, 11.324751652906127, 11.399013115177999, 11.472793905583767, 11.54610323875549, 11.618950038622252, 11.691342951089922, 11.763290356018594, 11.834800378544626, 11.90588089979066, 11.976539567003485, 12.046783803156758, 12.116620816052636, 12.186057606953941, 12.255100978776143, 12.323757543866238, 12.392033731393731, 12.459935794377113, 12.52746981636755, 12.594641717810001, 12.6614572621006, 12.727922061357857, 12.794041581923988, 12.859821149611687, 12.925265954710566, 12.990381056766582, 13.05517138914691], [0.0, 1.3228756555322954, 1.8708286933869709, 2.2912878474779204, 2.6457513110645907, 2.958039891549808, 3.24037034920393, 3.5, 3.7416573867739418, 3.968626966596886, 4.183300132670378, 4.387482193696062, 4.582575694955841, 4.769696007084729, 4.949747468305833, 5.123475382979799, 5.291502622129181, 5.454356057317857, 5.612486080160912, 5.766281297335398, 5.916079783099616, 6.062177826491071, 6.2048368229954285, 6.34428877022476, 6.48074069840786, 6.614378277661477, 6.745368781616022, 6.873863542433761, 7.0, 7.123903424387504, 7.245688373094719, 7.365459931328118, 7.4833147735478835, 7.599342076785333, 7.713624310270756, 7.826237921249264, 7.937253933193772, 8.046738469715542, 8.154753215150047, 8.261355820929154, 8.366600265340756, 8.470537173048708, 8.573214099741124, 8.674675786448736, 8.774964387392124, 8.874119674649423, 8.972179222463181, 9.069178573608529, 9.165151389911681, 9.260129588726066, 9.354143466934854, 9.447221813845593, 9.539392014169458, 9.630680142129112, 9.721111047611792, 9.810708435174293, 9.899494936611665, 9.98749217771909, 10.074720839804943, 10.161200716450788, 10.246950765959598, 10.331989159885913, 10.41633332799983, 10.5, 10.583005244258363, 10.665364503850771, 10.747092630102339, 10.828203913853859, 10.908712114635714, 10.988630487917955, 11.067971810589327, 11.146748404803978, 11.224972160321824, 11.302654555457316, 11.37980667674104, 11.456439237389601, 11.532562594670797, 11.6081867662439, 11.683321445547923, 11.757976016304848, 11.832159566199232, 11.905880899790658, 11.979148550710942, 12.05197079319395, 12.124355652982143, 12.196310917650468, 12.267844146385297, 12.338962679253067, 12.409673645990857, 12.479983974348684, 12.549900398011133, 12.619429464123963, 12.68857754044952, 12.757350822173073, 12.825755338380661, 12.893796958227625, 12.96148139681572, 13.028814220795384, 13.095800853708795, 13.162446581088185, 13.228756555322954, 13.294735800308333], [0.0, 1.3462912017836262, 1.9039432764659774, 2.3318447632722044, 2.6925824035672523, 3.010398644698074, 3.29772648956823, 3.561951712193752, 3.8078865529319548, 4.0388736053508785, 4.257346591481601, 4.465142774872939, 4.663689526544409, 4.854121959736901, 5.0373604199024715, 5.2141634036535525, 5.385164807134505, 5.55090082779363, 5.7118298293979315, 5.868347297152752, 6.020797289396148, 6.169481339626534, 6.314665470157545, 6.4565857850724795, 6.59545297913646, 6.731456008918131, 6.864765108872992, 6.995534289816613, 7.123903424387504, 7.250000000000001, 7.3739406018763125, 7.495832175282476, 7.6157731058639095, 7.733854149129011, 7.850159234053791, 7.964766161036996, 8.077747210701757, 8.189169677079601, 8.299096336348917, 8.40758586040012, 8.514693182963201, 8.620469824783335, 8.724964183307575, 8.828221791504788, 8.930285549745879, 9.031195934094221, 9.130991183874837, 9.229707470987368, 9.327379053088817, 9.424038412485382, 9.519716382329886, 9.614442261514707, 9.708243919473801, 9.801147891956331, 9.893179468704691, 9.98436277385793, 10.074720839804943, 10.164275675128062, 10.25304832720494, 10.341058939973218, 10.428326807307105, 10.514870422406545, 10.600707523557096, 10.685855136581255, 10.77032961426901, 10.854146673046206, 10.93732142711368, 11.019868420267096, 11.10180165558726, 11.183134623172522, 11.26388032606881, 11.344051304538429, 11.423659658795863, 11.502717070327341, 11.58123482190047, 11.65922381636102, 11.736694594305504, 11.81365735071066, 11.890121950594116, 11.96609794377432, 12.041594578792296, 12.116620816052635, 12.191185340236611, 12.26529657203608, 12.338962679253068, 12.41219158730641, 12.484990989183773, 12.557368354874361, 12.62933094031509, 12.700885795880538, 12.772039774444801, 12.842799539041323, 12.913171570144959, 12.983162172598785, 13.052777482206615, 13.122023472010708, 13.19090595827292, 13.259430606176121, 13.32760293526184, 13.395428324618816, 13.462912017836262, 13.530059127734809], [0.0, 1.3693063937629153, 1.9364916731037085, 2.371708245126285, 2.7386127875258306, 3.0618621784789726, 3.3541019662496843, 3.6228441865473595, 3.872983346207417, 4.107919181288746, 4.330127018922193, 4.541475531146238, 4.74341649025257, 4.937104414532875, 5.123475382979799, 5.303300858899106, 5.477225575051661, 5.645794895318107, 5.809475019311125, 5.968668193156661, 6.123724356957945, 6.274950199005567, 6.422616289332564, 6.566962768281848, 6.7082039324993685, 6.846531968814577, 6.982120021884471, 7.1151247353788545, 7.245688373094719, 7.373940601876313, 7.499999999999999, 7.623975340988452, 7.745966692414834, 7.866066361276138, 7.984359711335656, 8.100925873009825, 8.215838362577491, 8.329165624478842, 8.440971508067067, 8.551315688243536, 8.660254037844386, 8.76783895837509, 8.874119674649425, 8.979142498033985, 9.082951062292477, 9.185586535436917, 9.287087810503355, 9.387491677759293, 9.48683298050514, 9.585144756340407, 9.682458365518542, 9.778803607803974, 9.87420882906575, 9.968701018688444, 10.062305898749054, 10.155048005794951, 10.246950765959598, 10.338036564067666, 10.428326807307105, 10.517841983981313, 10.606601717798211, 10.694624818103717, 10.781929326423912, 10.868532559642079, 10.954451150103322, 11.039701082909808, 11.124297730643494, 11.208255885729947, 11.291589790636214, 11.374313166077325, 11.4564392373896, 11.537980759214326, 11.61895003862225, 11.699358956797589, 11.779218989389745, 11.858541225631422, 11.937336386313323, 12.015614840697916, 12.093386622447825, 12.170661444638085, 12.24744871391589, 12.323757543866236, 12.399596767637245, 12.474974949874648, 12.549900398011134, 12.624381172952596, 12.698425099200293, 12.772039774444801, 12.845232578665128, 12.918010682763812, 12.990381056766578, 13.062350477613132, 13.133925536563696, 13.205112646244256, 13.275918047351754, 13.346347815039136, 13.416407864998737, 13.486103959261177, 13.555441711725958, 13.624426593438713, 13.693063937629153, 13.761358944522884], [0.0, 1.3919410907075056, 1.9685019685029528, 2.410912690248239, 2.783882181415011, 3.112474899497183, 3.4095454242464642, 3.682729965664059, 3.9370039370059056, 4.175823272122517, 4.401704215414752, 4.616546328154848, 4.821825380496478, 5.018714974971183, 5.208166663999915, 5.390964663211956, 5.567764362830022, 5.739120141624498, 5.905505905508859, 6.067330549755799, 6.224949798994366, 6.378675411086538, 6.528782428600298, 6.675514961409345, 6.8190908484929285, 6.959705453537528, 7.097534783289196, 7.232738070744718, 7.365459931328118, 7.495832175282476, 7.623975340988452, 7.75, 7.874007874011811, 7.996092795859739, 8.116341540373963, 8.234834546000302, 8.351646544245034, 8.466847110938051, 8.580501150865258, 8.692669325356857, 8.803408430829505, 8.912771734987944, 9.02080927633436, 9.127568131764342, 9.233092656309696, 9.337424698491548, 9.440603794249602, 9.542667341996157, 9.643650760992957, 9.743587634952538, 9.842509842514763, 9.940447676035523, 10.037429949942366, 10.133484099755623, 10.228636272739394, 10.32291141103129, 10.41633332799983, 10.508924778491853, 10.600707523557096, 10.691702390171548, 10.781929326423912, 10.871407452579449, 10.960155108391486, 11.048189896992175, 11.135528725660045, 11.22218784373172, 11.308182877898641, 11.393528865105841, 11.478240283248995, 11.562331079847178, 11.645814698852115, 11.7287041057399, 11.811011811017718, 11.892749892266297, 11.973930014828046, 12.054563451241194, 12.134661099511598, 12.214233500306108, 12.293290853144248, 12.371843031658623, 12.449899597988733, 12.52746981636755, 12.604562665955532, 12.681186852972399, 12.757350822173075, 12.833062767710597, 12.908330643425586, 12.983162172598785, 13.057564857200596, 13.131545986668895, 13.205112646244256, 13.278271724889501, 13.35102992281869, 13.423393758658799, 13.49536957626578, 13.566963551215133, 13.638181696985857, 13.709029870855195, 13.77951377952067, 13.849638984464542, 13.919410907075056, 13.988834833537782], [0.0, 1.4142135623730951, 2.0, 2.4494897427831783, 2.8284271247461903, 3.1622776601683795, 3.464101615137755, 3.7416573867739413, 4.0, 4.242640687119285, 4.47213595499958, 4.690415759823431, 4.898979485566357, 5.099019513592785, 5.291502622129181, 5.477225575051661, 5.656854249492381, 5.8309518948453, 6.0, 6.164414002968977, 6.324555320336759, 6.48074069840786, 6.6332495807108, 6.782329983125268, 6.92820323027551, 7.0710678118654755, 7.211102550927979, 7.348469228349535, 7.483314773547883, 7.615773105863909, 7.745966692414833, 7.874007874011811, 8.0, 8.12403840463596, 8.246211251235321, 8.366600265340756, 8.48528137423857, 8.602325267042627, 8.717797887081348, 8.831760866327848, 8.94427190999916, 9.055385138137416, 9.165151389911681, 9.273618495495704, 9.380831519646861, 9.486832980505136, 9.591663046625438, 9.695359714832659, 9.797958971132713, 9.899494936611665, 10.0, 10.09950493836208, 10.19803902718557, 10.295630140987, 10.392304845413264, 10.488088481701515, 10.583005244258363, 10.677078252031311, 10.770329614269007, 10.862780491200215, 10.954451150103322, 11.04536101718726, 11.135528725660043, 11.224972160321823, 11.313708498984761, 11.40175425099138, 11.489125293076057, 11.575836902790225, 11.6619037896906, 11.747340124470732, 11.832159566199232, 11.916375287812984, 12.0, 12.083045973594572, 12.165525060596439, 12.24744871391589, 12.328828005937954, 12.409673645990857, 12.489995996796797, 12.569805089976535, 12.649110640673518, 12.727922061357855, 12.806248474865699, 12.884098726725124, 12.96148139681572, 13.038404810405297, 13.114877048604, 13.19090595827292, 13.2664991614216, 13.341664064126332, 13.416407864998737, 13.490737563232042, 13.564659966250536, 13.638181696985855, 13.71130920080209, 13.78404875209022, 13.85640646055102, 13.92838827718412, 14.0, 14.071247279470288, 14.142135623730951, 14.212670403551895], [0.0, 1.4361406616345074, 2.03100960115899, 2.4874685927665507, 2.8722813232690148, 3.211308144666283, 3.5178118198675725, 3.7996710383926664, 4.06201920231798, 4.308421984903522, 4.541475531146238, 4.763139720814414, 4.9749371855331015, 5.178078794301996, 5.37354631505117, 5.562148865321747, 5.7445626465380295, 5.921359641163506, 6.0930288034769715, 6.259992012774458, 6.422616289332566, 6.581223290544092, 6.736096792653741, 6.887488656977956, 7.035623639735145, 7.1807033081725375, 7.322909257938407, 7.462405778299652, 7.599342076785333, 7.733854149129011, 7.866066361276136, 7.996092795859739, 8.12403840463596, 8.250000000000002, 8.374067112222114, 8.496322733983215, 8.616843969807045, 8.735702604828075, 8.852965604812889, 8.96869555732605, 9.082951062292477, 9.195787078874762, 9.307255234493145, 9.417404100918683, 9.526279441628828, 9.633924433998846, 9.740379869389079, 9.84568433375761, 9.949874371066203, 10.05298463144155, 10.155048005794951, 10.256095748383009, 10.356157588603992, 10.455261833163243, 10.553435459602719, 10.650704202070399, 10.74709263010234, 10.842624221100722, 10.93732142711368, 11.031205736455105, 11.124297730643494, 11.216617137087278, 11.308182877898643, 11.399013115177999, 11.489125293076059, 11.578536176909411, 11.667261889578036, 11.755317945508748, 11.842719282327012, 11.929480290440152, 12.015614840697916, 12.10113631028095, 12.186057606953943, 12.270391191808027, 12.354149100605836, 12.437342963832752, 12.519984025548917, 12.602083161128562, 12.683650893965824, 12.764697411219744, 12.845232578665131, 12.925265954710566, 13.004806803639955, 13.083864108129525, 13.162446581088185, 13.24056267686536, 13.318220601867203, 13.395428324618816, 13.472193585307481, 13.548523904839229, 13.624426593438713, 13.699908758820259, 13.774977313955912, 13.849638984464542, 13.923900315644323, 13.997767679169417, 14.07124727947029, 14.144345159815638, 14.217067208112933, 14.28941916244324, 14.361406616345075, 14.433035023861061], [0.0, 1.4577379737113252, 2.0615528128088303, 2.52487623459052, 2.9154759474226504, 3.2596012026013246, 3.570714214271425, 3.8568121551353785, 4.123105625617661, 4.373213921133975, 4.6097722286464435, 4.83476990145343, 5.04975246918104, 5.255949010407161, 5.454356057317858, 5.645794895318107, 5.830951894845301, 6.010407640085654, 6.184658438426491, 6.354132513569418, 6.519202405202649, 6.680194607943695, 6.837397165588672, 6.991065727054782, 7.14142842854285, 7.288689868556626, 7.433034373659254, 7.57462870377156, 7.713624310270757, 7.850159234053792, 7.984359711335656, 8.116341540373963, 8.246211251235321, 8.374067112222114, 8.5, 8.624094155330171, 8.74642784226795, 8.867073925484101, 8.986100377805716, 9.103570728016564, 9.219544457292887, 9.334077351297235, 9.447221813845594, 9.55902714715258, 9.66953980290686, 9.778803607803972, 9.886859966642595, 9.993748045653343, 10.09950493836208, 10.204165815979275, 10.307764064044152, 10.410331406828508, 10.511898020814321, 10.612492638395564, 10.712142642814277, 10.810874155219828, 10.908712114635716, 11.00568035152757, 11.10180165558726, 11.197097838279346, 11.291589790636214, 11.385297536735699, 11.478240283248997, 11.570436465406134, 11.661903789690601, 11.75265927354316, 11.842719282327012, 11.932099563781724, 12.020815280171307, 12.108881038312335, 12.196310917650468, 12.283118496538247, 12.369316876852983, 12.45491870708115, 12.539936203984452, 12.624381172952598, 12.708265027138836, 12.791598805466032, 12.874393189583735, 12.95665851984994, 13.038404810405298, 13.119641763401926, 13.200378782444087, 13.280624985293425, 13.36038921588739, 13.439680055715613, 13.518505834595775, 13.59687464088715, 13.674794331177344, 13.752272539475067, 13.82931668593933, 13.90593398517338, 13.982131454109563, 14.057915919509549, 14.133294025102572, 14.20827223838282, 14.2828568570857, 14.35705401536123, 14.430869689661813, 14.504309704360288, 14.577379737113253, 14.650085323983612], [0.0, 1.479019945774904, 2.091650066335189, 2.5617376914899, 2.958039891549808, 3.307189138830738, 3.6228441865473595, 3.913118960624632, 4.183300132670378, 4.437059837324712, 4.677071733467427, 4.9053542175871465, 5.1234753829798, 5.332682251925386, 5.533985905294664, 5.7282196186948, 5.916079783099616, 6.098155458825233, 6.274950199005567, 6.446898479113814, 6.614378277661476, 6.77772085586298, 6.937218462755804, 7.093130479555554, 7.245688373094719, 7.395099728874521, 7.541551564499179, 7.6852130744697, 7.826237921249264, 7.964766161036996, 8.100925873009825, 8.234834546000302, 8.366600265340756, 8.496322733983215, 8.62409415533017, 8.75, 8.874119674649425, 8.996527107723292, 9.117291264405235, 9.236476600955584, 9.354143466934854, 9.470348462437904, 9.585144756340409, 9.69858237063541, 9.810708435174293, 9.921567416492213, 10.031201323869439, 10.139649895336625, 10.2469507659596, 10.353139620424328, 10.458250331675945, 10.562315087138805, 10.665364503850771, 10.767427733679016, 10.86853255964208, 10.968705484240154, 11.067971810589327, 11.166355717063649, 11.26388032606881, 11.360567767501763, 11.4564392373896, 11.55151505214792, 11.645814698852115, 11.739356881873896, 11.832159566199232, 11.92424001771182, 12.015614840697916, 12.106300012803251, 12.196310917650466, 12.285662375305616, 12.374368670764582, 12.462443580614519, 12.549900398011134, 12.636751956100111, 12.723010649999472, 12.808688457449499, 12.893796958227629, 12.97834735241741, 13.062350477613132, 13.145816825134908, 13.228756555322953, 13.311179511974137, 13.393095235978874, 13.474512978211866, 13.55544171172596, 13.635890143294642, 13.715866724345203, 13.795379661321395, 13.874436925511608, 13.953046262375825, 14.03121520040228, 14.108951059522463, 14.186260959111108, 14.263151825595912, 14.339630399699988, 14.415703243338493, 14.491376746189438, 14.566657131957216, 14.641550464346322, 14.716062652761439, 14.790199457749042, 14.863966496194749], [0.0, 1.5, 2.1213203435596424, 2.5980762113533165, 3.0, 3.3541019662496847, 3.6742346141747673, 3.9686269665968856, 4.242640687119285, 4.5, 4.743416490252569, 4.974937185533101, 5.196152422706633, 5.408326913195984, 5.612486080160912, 5.809475019311125, 6.0, 6.18465843842649, 6.363961030678928, 6.5383484153110105, 6.708203932499369, 6.87386354243376, 7.035623639735144, 7.19374728496908, 7.3484692283495345, 7.5, 7.6485292703891785, 7.794228634059949, 7.937253933193771, 8.077747210701757, 8.215838362577491, 8.351646544245032, 8.48528137423857, 8.616843969807045, 8.74642784226795, 8.874119674649425, 9.0, 9.12414379544733, 9.246621004453464, 9.367496997597598, 9.486832980505138, 9.604686356149273, 9.72111104761179, 9.836157786453, 9.949874371066201, 10.062305898749052, 10.173494974687902, 10.283481900601567, 10.392304845413266, 10.5, 10.606601717798213, 10.712142642814277, 10.816653826391969, 10.920164833920778, 11.022703842524303, 11.124297730643494, 11.224972160321824, 11.324751652906125, 11.423659658795863, 11.521718621802911, 11.61895003862225, 11.715374513859981, 11.811011811017716, 11.905880899790656, 12.0, 12.093386622447824, 12.186057606953941, 12.278029157808675, 12.36931687685298, 12.459935794377113, 12.549900398011133, 12.639224659764539, 12.727922061357855, 12.816005617976296, 12.903487900563938, 12.99038105676658, 13.076696830622021, 13.162446581088183, 13.247641299491772, 13.332291625973383, 13.416407864998739, 13.5, 13.583077707206126, 13.665650368716447, 13.74772708486752, 13.82931668593933, 13.910427743243554, 13.991068579633223, 14.071247279470288, 14.150971698084904, 14.230249470757707, 14.309088021254185, 14.38749456993816, 14.465476141489432, 14.543039572248988, 14.620191517213444, 14.696938456699069, 14.773286702694158, 14.849242404917499, 14.9248115565993, 15.0, 15.074813431681335], [0.0, 1.520690632574555, 2.150581316760657, 2.6339134382131855, 3.04138126514911, 3.400367627183861, 3.7249161064378353, 4.02336923485777, 4.301162633521314, 4.562071897723665, 4.808846015417837, 5.043560250458005, 5.267826876426371, 5.482928049865328, 5.689903338370521, 5.889609494694874, 6.08276253029822, 6.269968101992226, 6.451743950281971, 6.628536791781427, 6.800735254367722, 6.968679932383178, 7.132671308843553, 7.292976072907411, 7.449832212875671, 7.603453162872776, 7.7540312096354125, 7.9017403146395555, 8.04673846971554, 8.189169677079601, 8.32916562447884, 8.46684711093805, 8.602325267042628, 8.735702604828075, 8.8670739254841, 8.996527107723292, 9.12414379544733, 9.250000000000002, 9.37416662962634, 9.49670995661129, 9.617692030835673, 9.737171047075224, 9.855201672213514, 9.971835337589566, 10.08712050091601, 10.201102881551583, 10.313825672368134, 10.425329730996522, 10.535653752852742, 10.644834428021884, 10.752906583803284, 10.859903314486738, 10.965856099730656, 11.070794912742265, 11.174748319313506, 11.277743568639963, 11.379806676741042, 11.480962503205035, 11.58123482190047, 11.680646386223666, 11.779218989389747, 11.876973520219703, 11.973930014828047, 12.07010770457331, 12.16552506059644, 12.260199835239229, 12.354149100605838, 12.447389284504604, 12.539936203984452, 12.631805096659782, 12.723010649999473, 12.8135670287395, 12.903487900563942, 12.992786460186284, 13.081475451951128, 13.169567191065925, 13.257073583562853, 13.344006145082519, 13.430376018563294, 13.516193990913271, 13.601470508735444, 13.686215693170995, 13.770439353920414, 13.85415100249741, 13.937359864766355, 14.020074892809953, 14.102304776170454, 14.184057952504284, 14.265342617687105, 14.346166735403573, 14.426538046253508, 14.50646407640401, 14.585952145814822, 14.665009376062466, 14.743642697786733, 14.821858857781637, 14.899664425751341, 14.977065800750161, 15.054069217324598, 15.130680751374012, 15.206906325745551, 15.282751715577927], [0.0, 1.5411035007422442, 2.179449471770337, 2.6692695630078282, 3.0822070014844885, 3.446012188022556, 3.7749172176353754, 4.077376607575023, 4.358898943540674, 4.623310502226732, 4.8733971724044824, 5.111262075065219, 5.3385391260156565, 5.556527692723218, 5.766281297335398, 5.968668193156661, 6.164414002968977, 6.354132513569417, 6.538348415311011, 6.717514421272202, 6.892024376045112, 7.062223445912768, 7.22841614740048, 7.390872749547242, 7.549834435270751, 7.705517503711222, 7.8581168227508575, 8.007808689023486, 8.154753215150047, 8.299096336348917, 8.440971508067065, 8.580501150865258, 8.717797887081348, 8.852965604812889, 8.986100377805714, 9.117291264405235, 9.246621004453464, 9.37416662962634, 9.500000000000002, 9.62418827746008, 9.746794344808965, 9.867877177995275, 9.98749217771909, 10.105691465703869, 10.222524150130438, 10.338036564067666, 10.452272480183437, 10.56527330455772, 10.677078252031313, 10.787724505195708, 10.897247358851684, 11.005680351527571, 11.113055385446437, 11.219402836158439, 11.324751652906127, 11.429129450662462, 11.532562594670797, 11.635076278220097, 11.736694594305503, 11.837440601751714, 11.937336386313323, 12.036403117210723, 12.134661099511598, 12.232129822725067, 12.328828005937954, 12.424773639789178, 12.519984025548915, 12.614475811542865, 12.708265027138834, 12.801367114492109, 12.893796958227627, 12.985568913220554, 13.076696830622023, 13.167194082263693, 13.257073583562851, 13.34634781503914, 13.435028842544405, 13.523128336298521, 13.610657588816201, 13.697627531802725, 13.784048752090223, 13.869931506680198, 13.955285736952865, 14.040121082098972, 14.124446891825537, 14.208272238382822, 14.291605927956452, 14.374456511465052, 14.45683229480096, 14.538741348548712, 14.620191517213447, 14.701190427989157, 14.781745499094484, 14.86186394770185, 14.941552797483936, 15.020818885799802, 15.099668870541501, 15.178109236660543, 15.25614630239236, 15.333786225195656, 15.411035007422443, 15.487898501733541], [0.0, 1.5612494995995998, 2.207940216581962, 2.7041634565979926, 3.1224989991991996, 3.4910600109422356, 3.8242646351945893, 4.130677910464577, 4.415880433163924, 4.683748498798799, 4.937104414532875, 5.178078794301996, 5.408326913195985, 5.6291651245988525, 5.841660722773962, 6.046693311223913, 6.244997998398399, 6.437196594791867, 6.623820649745886, 6.805328794408101, 6.982120021884471, 7.154544010627093, 7.322909257938406, 7.487489565935969, 7.6485292703891785, 7.806247497997999, 7.960841664045331, 8.112490369793978, 8.261355820929154, 8.40758586040012, 8.551315688243534, 8.692669325356857, 8.831760866327848, 8.96869555732605, 9.103570728016562, 9.236476600955584, 9.367496997597598, 9.49670995661129, 9.62418827746008, 9.750000000000002, 9.87420882906575, 9.996874511566103, 10.118053172424034, 10.237797614721636, 10.356157588603992, 10.473180032826706, 10.588909292273685, 10.703387314303825, 10.81665382639197, 10.928746497197197, 11.03970108290981, 11.14955156048888, 11.258330249197705, 11.366067921669307, 11.472793905583767, 11.578536176909413, 11.683321445547923, 11.787175234126286, 11.890121950594116, 11.992184955211457, 12.093386622447825, 12.193748398257199, 12.293290853144248, 12.39203373139373, 12.489995996796798, 12.587195875174107, 12.683650893965824, 12.77937791913206, 12.874393189583733, 12.968712349342939, 13.062350477613132, 13.155322116922871, 13.247641299491772, 13.339321571954102, 13.430376018563292, 13.520817282989961, 13.610657588816203, 13.699908758820259, 13.78858223313768, 13.876689086377919, 13.964240043768942, 14.051245496396398, 14.137715515598696, 14.223659866574426, 14.309088021254187, 14.394009170484782, 14.47843223557026, 14.562365879210702, 14.645818515876812, 14.728798321655436, 14.811313243598626, 14.893371008606481, 14.974979131871939, 15.05614492491355, 15.136875503220606, 15.217177793533201, 15.297058540778357, 15.376524314681783, 15.455581516073734, 15.534236382905986, 15.612494995995998, 15.690363284513207], [0.0, 1.5811388300841898, 2.23606797749979, 2.738612787525831, 3.1622776601683795, 3.5355339059327378, 3.872983346207417, 4.183300132670378, 4.47213595499958, 4.743416490252569, 5.0, 5.244044240850759, 5.477225575051662, 5.7008771254956905, 5.916079783099616, 6.123724356957945, 6.324555320336759, 6.519202405202648, 6.708203932499369, 6.892024376045112, 7.0710678118654755, 7.24568837309472, 7.416198487095663, 7.582875444051551, 7.745966692414834, 7.905694150420949, 8.062257748298551, 8.215838362577493, 8.366600265340756, 8.514693182963201, 8.660254037844386, 8.803408430829505, 8.94427190999916, 9.082951062292477, 9.219544457292887, 9.354143466934854, 9.486832980505138, 9.617692030835673, 9.746794344808965, 9.87420882906575, 10.0, 10.124228365658293, 10.2469507659596, 10.36822067666386, 10.488088481701517, 10.606601717798211, 10.723805294763608, 10.8397416943394, 10.954451150103324, 11.067971810589327, 11.180339887498949, 11.291589790636216, 11.401754250991381, 11.51086443322134, 11.618950038622252, 11.726039399558575, 11.832159566199232, 11.937336386313323, 12.041594578792296, 12.144957801491119, 12.24744871391589, 12.349089035228468, 12.449899597988733, 12.549900398011133, 12.649110640673518, 12.747548783981962, 12.84523257866513, 12.942179105544785, 13.038404810405297, 13.133925536563698, 13.228756555322953, 13.322912594474229, 13.416407864998739, 13.509256086106296, 13.601470508735442, 13.693063937629153, 13.784048752090223, 13.874436925511608, 13.964240043768942, 14.053469322555197, 14.142135623730951, 14.230249470757707, 14.317821063276355, 14.404860290887934, 14.49137674618944, 14.577379737113251, 14.66287829861518, 14.747881203752627, 14.832396974191326, 14.916433890176297, 15.0, 15.083103128998356, 15.165750888103101, 15.247950681976906, 15.329709716755893, 15.41103500742244, 15.491933384829668, 15.572411502397438, 15.652475842498529, 15.732132722552274, 15.811388300841898, 15.890248582070704], [0.0, 1.6007810593582124, 2.2638462845343543, 2.772634126602355, 3.2015621187164247, 3.579455265819089, 3.921096785339531, 4.235268586524355, 4.527692569068709, 4.802343178074637, 5.062114182829147, 5.309190145398826, 5.54526825320471, 5.771698190307599, 5.98957427535547, 6.199798383818623, 6.403124237432849, 6.600189391222043, 6.791538853603063, 6.9776428684764324, 7.158910531638178, 7.335700375560606, 7.508328708840604, 7.677076266392044, 7.842193570679062, 8.003905296791062, 8.162413858657256, 8.317902379807064, 8.47053717304871, 8.620469824783335, 8.76783895837509, 8.912771734987945, 9.055385138137417, 9.195787078874762, 9.334077351297235, 9.470348462437906, 9.604686356149275, 9.737171047075226, 9.867877177995277, 9.996874511566105, 10.124228365658293, 10.25, 10.374246960623216, 10.49702338760851, 10.618380290797653, 10.738365797457265, 10.857025375304232, 10.974402033823985, 11.09053650640942, 11.205467415507485, 11.319231422671772, 11.431863365173678, 11.543396380615198, 11.653862020806667, 11.763290356018594, 11.871710070583768, 11.97914855071094, 12.085631965271823, 12.19118534023661, 12.295832627357937, 12.399596767637245, 12.502499750049989, 12.604562665955532, 12.705805759573062, 12.806248474865699, 12.905909499140307, 13.004806803639953, 13.10295768137866, 13.200378782444085, 13.297086146972202, 13.393095235978874, 13.488420960216212, 13.583077707206126, 13.67707936658993, 13.77043935392041, 13.863170633011773, 13.955285736952865, 14.046796787880147, 14.137715515598694, 14.228053275132197, 14.317821063276355, 14.407029534223911, 14.495689014324228, 14.58380951603524, 14.671400751121212, 14.758472143145443, 14.845032839303522, 14.931091721639113, 15.016657417681207, 15.101738310538956, 15.186342548487442, 15.270478054075454, 15.354152532784088, 15.437373481262933, 15.520148195168758, 15.602483776629924, 15.684387141358124, 15.765865025427564, 15.846923991740482, 15.927570436196477, 16.007810593582125, 16.087650543196172], [0.0, 1.6201851746019653, 2.2912878474779204, 2.806243040080457, 3.2403703492039306, 3.62284418654736, 3.9686269665968865, 4.286607049870562, 4.582575694955841, 4.860555523805895, 5.1234753829798, 5.37354631505117, 5.612486080160914, 5.8416607227739625, 6.062177826491071, 6.274950199005567, 6.480740698407861, 6.680194607943694, 6.873863542433761, 7.062223445912768, 7.24568837309472, 7.42462120245875, 7.599342076785333, 7.770135133960028, 7.937253933193773, 8.100925873009826, 8.261355820929156, 8.41872912024137, 8.573214099741124, 8.724964183307575, 8.874119674649425, 9.020809276334358, 9.165151389911681, 9.307255234493145, 9.447221813845593, 9.585144756340409, 9.72111104761179, 9.855201672213514, 9.98749217771909, 10.118053172424034, 10.2469507659596, 10.374246960623216, 10.500000000000002, 10.62426468043789, 10.74709263010234, 10.868532559642079, 10.988630487917955, 11.107429945761533, 11.224972160321828, 11.341296222213757, 11.456439237389601, 11.570436465406136, 11.683321445547925, 11.795126112085452, 11.90588089979066, 12.015614840697918, 12.124355652982143, 12.232129822725069, 12.338962679253067, 12.444878464653643, 12.549900398011134, 12.654050734843764, 12.757350822173075, 12.859821149611685, 12.961481396815723, 13.062350477613133, 13.162446581088185, 13.261787209874845, 13.360389215887388, 13.458268833694772, 13.55544171172596, 13.651922941476048, 13.747727084867522, 13.842868199907128, 13.937359864766353, 14.031215200402283, 14.124446891825537, 14.217067208112931, 14.309088021254187, 14.40052082391467, 14.49137674618944, 14.581666571417687, 14.671400751121213, 14.760589419125512, 14.8492424049175, 14.937369246289657, 15.02497920131672, 15.112081259707416, 15.198684153570666, 15.284796367632772, 15.3704261489394, 15.455581516073734, 15.540270267920056, 15.624499991999745, 15.708278072405012, 15.791611697353757, 15.874507866387546, 15.95697339723295, 16.03901493234544, 16.12063894515351, 16.201851746019653, 16.282659487933785], [0.0, 1.6393596310755, 2.318404623873926, 2.8394541729001372, 3.278719262151, 3.665719574653795, 4.0155946010522525, 4.337337893224368, 4.636809247747852, 4.9180788932265, 5.18411033833193, 5.437140792732887, 5.6789083458002745, 5.9107952087684446, 6.1339220731926485, 6.349212549600146, 6.557438524302, 6.759252917297887, 6.955213871621778, 7.145802963978226, 7.33143914930759, 7.51248960065836, 7.689278249614849, 7.862092596758194, 8.031189202104505, 8.1967981553775, 8.359126748650244, 8.51836251870041, 8.674675786448736, 8.828221791504788, 8.979142498033983, 9.127568131764342, 9.273618495495704, 9.417404100918683, 9.559027147152579, 9.698582370635412, 9.836157786453, 9.971835337589566, 10.105691465703869, 10.237797614721636, 10.36822067666386, 10.497023387608508, 10.62426468043789, 10.749999999999998, 10.874281585465774, 10.997158723961382, 11.118677978968542, 11.238883396494511, 11.357816691600549, 11.4755174175285, 11.59202311936963, 11.707369473968095, 11.821590417536889, 11.934718262280011, 12.046783803156758, 12.157816415787828, 12.267844146385297, 12.376893794486563, 12.484990989183773, 12.592160259463027, 12.698425099200293, 12.803808027301876, 12.908330643425584, 13.012013679673103, 13.114877048604, 13.216939887886301, 13.318220601867202, 13.418736900319642, 13.518505834595773, 13.61754383139632, 13.7158667243452, 13.813489783541304, 13.910427743243556, 14.006694827831438, 14.102304776170453, 14.197270864500684, 14.291605927956452, 14.3853223808158, 14.478432235570258, 14.570947120897804, 14.66287829861518, 14.7542366796795, 14.845032839303522, 14.935277031243846, 15.02497920131672, 15.114149000191839, 15.20279579551077, 15.290928683373028, 15.378556499229697, 15.465687828221542, 15.55233101499579, 15.638494173033411, 15.724185193516387, 15.809411753762376, 15.894181325252333, 15.978501181274792, 16.06237840420901, 16.145819892467525, 16.22883236711748, 16.31142237819866, 16.393596310755, 16.475360390595405], [0.0, 1.6583123951777001, 2.345207879911715, 2.872281323269015, 3.3166247903554003, 3.708099243547832, 4.06201920231798, 4.387482193696061, 4.69041575982343, 4.974937185533101, 5.244044240850759, 5.500000000000002, 5.74456264653803, 5.9791303715507, 6.2048368229954285, 6.422616289332565, 6.6332495807108005, 6.837397165588672, 7.035623639735145, 7.228416147400481, 7.416198487095664, 7.599342076785333, 7.778174593052023, 7.952986860293434, 8.12403840463596, 8.2915619758885, 8.455767262643883, 8.616843969807045, 8.774964387392123, 8.930285549745877, 9.082951062292475, 9.233092656309696, 9.38083151964686, 9.526279441628828, 9.669539802906858, 9.810708435174293, 9.949874371066201, 10.08712050091601, 10.222524150130438, 10.356157588603992, 10.488088481701517, 10.618380290797651, 10.74709263010234, 10.874281585465774, 11.000000000000004, 11.124297730643494, 11.247221879201993, 11.368817000902075, 11.48912529307606, 11.6081867662439, 11.726039399558575, 11.842719282327014, 11.9582607431014, 12.072696467649639, 12.186057606953943, 12.298373876248846, 12.409673645990857, 12.519984025548917, 12.62933094031509, 12.737739202856996, 12.84523257866513, 12.951833846988619, 13.057564857200596, 13.162446581088183, 13.266499161421601, 13.369741957120938, 13.472193585307481, 13.573871960498229, 13.674794331177344, 13.774977313955914, 13.874436925511608, 13.973188612482122, 14.07124727947029, 14.168627315304755, 14.265342617687105, 14.361406616345073, 14.456832294800963, 14.55163221085525, 14.645818515876812, 14.739402972983676, 14.832396974191328, 14.9248115565993, 15.016657417681209, 15.107944929738128, 15.198684153570666, 15.288884851420656, 15.378556499229699, 15.467708298258021, 15.556349186104047, 15.644487847162015, 15.732132722552274, 15.819292019556377, 15.905973720586868, 15.992185591719478, 16.07793519081353, 16.163229875244614, 16.24807680927192, 16.33248297106108, 16.416455159382007, 16.500000000000004, 16.583123951777, 16.66583331249896], [0.0, 1.6770509831248421, 2.3717082451262845, 2.904737509655563, 3.3541019662496843, 3.75, 4.107919181288746, 4.437059837324711, 4.743416490252569, 5.031152949374526, 5.303300858899106, 5.562148865321747, 5.809475019311126, 6.046693311223913, 6.274950199005566, 6.495190528383289, 6.7082039324993685, 6.914658342969664, 7.115124735378854, 7.310095758606723, 7.5, 7.685213074469699, 7.866066361276136, 8.042853971072706, 8.215838362577491, 8.38525491562421, 8.551315688243536, 8.714212528966689, 8.874119674649423, 9.031195934094221, 9.185586535436917, 9.337424698491548, 9.486832980505138, 9.633924433998848, 9.778803607803972, 9.921567416492215, 10.062305898749052, 10.201102881551583, 10.338036564067666, 10.473180032826706, 10.606601717798211, 10.738365797457265, 10.868532559642079, 10.997158723961384, 11.124297730643494, 11.249999999999998, 11.374313166077325, 11.497282287566918, 11.618950038622252, 11.739356881873894, 11.858541225631422, 11.976539567003485, 12.093386622447825, 12.20911544707478, 12.323757543866238, 12.43734296383275, 12.549900398011133, 12.6614572621006, 12.7720397744448, 12.88167302798825, 12.990381056766578, 13.098186897429734, 13.205112646244256, 13.311179511974133, 13.416407864998737, 13.52081728298996, 13.624426593438711, 13.727253913292344, 13.829316685939329, 13.930631715755032, 14.03121520040228, 14.13108276106258, 14.230249470757707, 14.3287298809071, 14.426538046253507, 14.523687548277813, 14.620191517213446, 14.716062652761437, 14.811313243598624, 14.905955185763842, 15.0, 15.093458848123579, 15.18634254848744, 15.27866159059752, 15.370426148939398, 15.461646096066225, 15.552331014995788, 15.642490210960657, 15.732132722552272, 15.821267332296737, 15.909902576697318, 15.998046755776155, 16.08570794214541, 16.172893989635867, 16.2596125415091, 16.345871038277522, 16.431676725154983, 16.51703665915893, 16.60195771588399, 16.68644659596524, 16.77050983124842, 16.854153790683174], [0.0, 1.6955824957813173, 2.39791576165636, 2.9368350311176834, 3.3911649915626345, 3.7914377220257753, 4.153311931459037, 4.4860896112315904, 4.79583152331272, 5.086747487343952, 5.361902647381804, 5.623610939600997, 5.873670062235367, 6.113509630318743, 6.34428877022476, 6.566962768281849, 6.782329983125269, 6.991065727054782, 7.19374728496908, 7.390872749547243, 7.582875444051551, 7.770135133960028, 7.952986860293433, 8.131727983645296, 8.306623862918075, 8.477912478906585, 8.645808232895293, 8.810505093353049, 8.972179222463181, 9.130991183874839, 9.287087810503355, 9.440603794249604, 9.59166304662544, 9.74037986938908, 9.886859966642595, 10.03120132386944, 10.173494974687904, 10.313825672368136, 10.452272480183437, 10.588909292273687, 10.723805294763608, 10.857025375304232, 10.988630487917957, 11.118677978968543, 11.247221879201994, 11.374313166077325, 11.5, 11.62432793756267, 11.747340124470734, 11.86907747046922, 11.9895788082818, 12.108881038312337, 12.227019260637485, 12.344026895628511, 12.459935794377115, 12.574776339959293, 12.68857754044952, 12.801367114492109, 12.913171570144959, 13.024016277631105, 13.133925536563698, 13.242922638149027, 13.35102992281869, 13.45826883369477, 13.564659966250538, 13.670223114492316, 13.774977313955912, 13.878940881782011, 13.982131454109563, 14.084566021003276, 14.186260959111108, 14.28723206222955, 14.38749456993816, 14.48706319445042, 14.58595214581482, 14.684175155588415, 14.781745499094486, 14.87867601636651, 14.974979131871939, 15.070666873101537, 15.165750888103101, 15.260242462031854, 15.35415253278409, 15.447491705775407, 15.540270267920056, 15.632498200863482, 15.724185193516387, 15.815340653934712, 15.905973720586866, 15.996093273046391, 16.08570794214541, 16.174826119621812, 16.263455967290593, 16.351605425767833, 16.4392822227736, 16.52649388103841, 16.61324772583615, 16.699550892164737, 16.78541033159452, 16.87083281880299, 16.95582495781317, 17.040393187951974], [0.0, 1.7139136501002612, 2.4238399287081647, 2.9685855217594797, 3.4278273002005224, 3.8324274291889733, 4.198213905936666, 4.534589286804263, 4.847679857416329, 5.141740950300783, 5.4198708471697, 5.684408500451037, 5.937171043518959, 6.179603547154138, 6.41287766919033, 6.637959023675877, 6.855654600401045, 7.066647012551284, 7.271519786124494, 7.470776398741968, 7.664854858377947, 7.854139036202505, 8.038967595406763, 8.219641111386798, 8.396427811873332, 8.569568250501305, 8.739279146474269, 8.90575656527844, 9.069178573608527, 9.229707470987368, 9.387491677759293, 9.542667341996157, 9.695359714832659, 9.84568433375761, 9.993748045653343, 10.139649895336625, 10.283481900601567, 10.425329730996523, 10.56527330455772, 10.703387314303823, 10.8397416943394, 10.974402033823985, 11.107429945761533, 11.238883396494511, 11.368817000902075, 11.497282287566918, 11.62432793756267, 11.75, 11.874342087037919, 11.997395550701826, 12.119199643540822, 12.239791664893648, 12.359207094308276, 12.477479713467782, 12.594641717810001, 12.710723818886162, 12.82575533838066, 12.939764294607535, 13.052777482206613, 13.164820545681586, 13.275918047351754, 13.386093530227555, 13.49536957626578, 13.60376786041279, 13.71130920080209, 13.818013605435478, 13.923900315644321, 14.0289878465982, 14.133294025102568, 14.23683602490385, 14.339630399699987, 14.44169311403618, 14.543039572248988, 14.643684645607472, 14.74364269778673, 14.842927608797398, 14.941552797483936, 15.039531242695032, 15.136875503220605, 15.233597736582125, 15.329709716755893, 15.42522285090235, 15.520148195168758, 15.614496469627191, 15.70827807240501, 15.801503093060482, 15.894181325252333, 15.986322278748169, 16.077935190813527, 16.169029037020124, 16.2596125415091, 16.349694186742454, 16.439282222773596, 16.528384676065595, 16.61700935788387, 16.70516387228811, 16.792855623746664, 16.880091824394796, 16.966879500957152, 17.05322550135311, 17.13913650100261, 17.224619008848933], [0.0, 1.7320508075688776, 2.4494897427831783, 3.000000000000001, 3.4641016151377553, 3.8729833462074175, 4.242640687119286, 4.582575694955841, 4.898979485566357, 5.196152422706633, 5.477225575051662, 5.74456264653803, 6.000000000000002, 6.2449979983984, 6.480740698407861, 6.70820393249937, 6.9282032302755105, 7.14142842854285, 7.348469228349535, 7.549834435270752, 7.745966692414835, 7.937253933193774, 8.12403840463596, 8.306623862918077, 8.485281374238571, 8.660254037844389, 8.83176086632785, 9.000000000000004, 9.165151389911681, 9.327379053088817, 9.486832980505138, 9.643650760992957, 9.797958971132713, 9.949874371066203, 10.09950493836208, 10.2469507659596, 10.392304845413266, 10.535653752852742, 10.677078252031313, 10.81665382639197, 10.954451150103324, 11.09053650640942, 11.224972160321828, 11.357816691600549, 11.48912529307606, 11.61895003862225, 11.747340124470732, 11.874342087037919, 12.000000000000004, 12.124355652982143, 12.247448713915892, 12.369316876852984, 12.4899959967968, 12.609520212918495, 12.727922061357859, 12.845232578665131, 12.961481396815723, 13.076696830622023, 13.190905958272921, 13.304134695650072, 13.41640786499874, 13.527749258468685, 13.638181696985859, 13.74772708486752, 13.856406460551021, 13.964240043768942, 14.07124727947029, 14.177446878757827, 14.2828568570857, 14.387494569938161, 14.49137674618944, 14.594519519326427, 14.69693845669907, 14.798648586948744, 14.89966442575134, 15.000000000000002, 15.099668870541503, 15.198684153570666, 15.297058540778357, 15.394804318340656, 15.49193338482967, 15.588457268119898, 15.684387141358126, 15.779733838059503, 15.874507866387548, 15.968719422671313, 16.062378404209014, 16.155494421403514, 16.24807680927192, 16.34013463836819, 16.431676725154986, 16.522711641858308, 16.613247725836153, 16.703293088490067, 16.792855623746668, 16.881943016134134, 16.970562748477143, 17.058722109231983, 17.14642819948225, 17.23368793961409, 17.320508075688778, 17.406895185529212], [0.0, 1.75, 2.4748737341529163, 3.0310889132455356, 3.5, 3.913118960624632, 4.286607049870562, 4.630064794363034, 4.949747468305833, 5.25, 5.533985905294664, 5.804093383121951, 6.062177826491071, 6.309714732061982, 6.547900426854397, 6.777720855862979, 7.0, 7.215434844830906, 7.4246212024587495, 7.62807315119618, 7.826237921249264, 8.01950746617272, 8.208227579691002, 8.39270516579726, 8.573214099741124, 8.75, 8.923284148787374, 9.093266739736608, 9.260129588726068, 9.424038412485382, 9.585144756340405, 9.743587634952538, 9.899494936611665, 10.052984631441552, 10.204165815979275, 10.35313962042433, 10.5, 10.644834428021886, 10.78772450519571, 10.928746497197197, 11.067971810589327, 11.205467415507485, 11.341296222213757, 11.4755174175285, 11.608186766243902, 11.739356881873894, 11.869077470469218, 11.997395550701828, 12.124355652982143, 12.25, 12.374368670764582, 12.49749974994999, 12.619429464123964, 12.740192306240909, 12.859821149611687, 12.978347352417412, 13.095800853708795, 13.212210261723813, 13.32760293526184, 13.442005058770064, 13.555441711725958, 13.667936932836644, 13.77951377952067, 13.8901943830891, 14.0, 14.108951059522463, 14.217067208112931, 14.324367350776788, 14.430869689661812, 14.536591760106631, 14.641550464346322, 14.74576210305863, 14.849242404917499, 14.95200655430568, 15.054069217324596, 15.155444566227677, 15.25614630239236, 15.356187677936214, 15.455581516073734, 15.55434023030228, 15.652475842498529, 15.75, 15.846923991740482, 15.943258763502524, 16.03901493234544, 16.134202800262553, 16.22883236711748, 16.322913342905427, 16.416455159382004, 16.509466981099056, 16.60195771588399, 16.69393602479655, 16.78541033159452, 16.87638883173767, 16.966879500957152, 17.056890103415686, 17.146428199482248, 17.235501153143183, 17.324116139070416, 17.41228014936585, 17.5, 17.587282336961557], [0.0, 1.767766952966369, 2.5000000000000004, 3.0618621784789735, 3.535533905932738, 3.9528470752104745, 4.330127018922194, 4.677071733467427, 5.000000000000001, 5.303300858899107, 5.5901699437494745, 5.863019699779288, 6.123724356957947, 6.373774391990982, 6.614378277661477, 6.846531968814577, 7.071067811865476, 7.2886898685566255, 7.500000000000001, 7.705517503711222, 7.905694150420949, 8.100925873009826, 8.2915619758885, 8.477912478906585, 8.660254037844387, 8.838834764831844, 9.013878188659975, 9.18558653543692, 9.354143466934854, 9.519716382329886, 9.682458365518542, 9.842509842514763, 10.000000000000002, 10.155048005794953, 10.307764064044152, 10.458250331675945, 10.606601717798213, 10.752906583803286, 10.897247358851686, 11.03970108290981, 11.180339887498949, 11.319231422671772, 11.456439237389603, 11.59202311936963, 11.726039399558577, 11.858541225631422, 11.989578808281799, 12.119199643540824, 12.247448713915894, 12.374368670764582, 12.500000000000002, 12.6243811729526, 12.747548783981964, 12.869537676233753, 12.990381056766582, 13.110110602126896, 13.228756555322954, 13.34634781503914, 13.462912017836262, 13.57847561400027, 13.693063937629153, 13.806701271484076, 13.919410907075056, 14.031215200402281, 14.142135623730953, 14.252192813739226, 14.361406616345073, 14.469796128487783, 14.577379737113251, 14.684175155588415, 14.79019945774904, 14.895469109766232, 15.000000000000002, 15.103807466993215, 15.206906325745548, 15.309310892394864, 15.411035007422443, 15.512092057488571, 15.612494995995998, 15.71225636247067, 15.811388300841898, 15.90990257669732, 16.007810593582125, 16.105123408406406, 16.201851746019653, 16.29800601300662, 16.393596310755, 16.48863244784115, 16.583123951777, 16.677080080157918, 16.770509831248425, 16.863421954040053, 16.95582495781317, 17.04772712123232, 17.139136501002614, 17.230060940112775, 17.320508075688775, 17.41048534648015, 17.5, 17.589059099337863, 17.67766952966369, 17.76583800443987], [0.0, 1.7853571071357128, 2.52487623459052, 3.092329219213246, 3.5707142142714257, 3.9921798556678287, 4.373213921133976, 4.723610906922796, 5.04975246918104, 5.356071321407138, 5.645794895318108, 5.921359641163507, 6.184658438426492, 6.4371965947918675, 6.680194607943695, 6.914658342969666, 7.141428428542851, 7.361215932167728, 7.57462870377156, 7.782191208136692, 7.9843597113356575, 8.181534085976788, 8.374067112222114, 8.562271894771856, 8.746427842267952, 8.926785535678563, 9.103570728016564, 9.276987657639738, 9.447221813845593, 9.614442261514707, 9.778803607803972, 9.940447676035523, 10.09950493836208, 10.25609574838301, 10.410331406828508, 10.562315087138806, 10.712142642814277, 10.859903314486738, 11.005680351527571, 11.14955156048888, 11.291589790636216, 11.431863365173678, 11.570436465406138, 11.707369473968097, 11.842719282327014, 11.976539567003483, 12.108881038312335, 12.23979166489365, 12.369316876852984, 12.497499749949988, 12.6243811729526, 12.750000000000004, 12.874393189583735, 12.997595931555962, 13.11964176340193, 13.240562676865363, 13.36038921588739, 13.479150566708574, 13.59687464088715, 13.713588151902478, 13.829316685939332, 13.944084767384341, 14.05791591950955, 14.17083272076839, 14.282856857085703, 14.394009170484784, 14.504309704360288, 14.613777745675485, 14.722431864335457, 14.830289949963895, 14.937369246289657, 15.043686383330387, 15.14925740754312, 15.254097810096802, 15.35822255340767, 15.461646096066229, 15.564382416273384, 15.6664450338933, 15.767847031221482, 15.868601072558352, 15.968719422671315, 16.068213964221414, 16.167096214224745, 16.265377339613124, 16.363068171953575, 16.460179221381523, 16.55672068979845, 16.652702483380892, 16.74813422444423, 16.843025262701474, 16.937384685954324, 17.0312213302511, 17.12454378954371, 17.217360424873497, 17.309679373113763, 17.401508555294853, 17.492855684535904, 17.58372827360569, 17.67413364213364, 17.76407892349052, 17.853571071357127, 17.94261686599812], [0.0, 1.8027756377319948, 2.5495097567963927, 3.1224989991992, 3.6055512754639896, 4.0311288741492755, 4.415880433163924, 4.769696007084729, 5.099019513592785, 5.408326913195984, 5.7008771254956905, 5.9791303715507, 6.2449979983984, 6.500000000000001, 6.745368781616021, 6.982120021884471, 7.211102550927979, 7.433034373659253, 7.6485292703891785, 7.858116822750857, 8.062257748298551, 8.261355820929154, 8.455767262643882, 8.645808232895291, 8.831760866327848, 9.013878188659975, 9.19238815542512, 9.3674969975976, 9.539392014169458, 9.708243919473801, 9.874208829065749, 10.037429949942366, 10.19803902718557, 10.356157588603992, 10.51189802081432, 10.665364503850773, 10.816653826391969, 10.965856099730656, 11.113055385446437, 11.258330249197705, 11.401754250991381, 11.543396380615196, 11.683321445547925, 11.821590417536889, 11.9582607431014, 12.093386622447824, 12.227019260637483, 12.359207094308276, 12.4899959967968, 12.619429464123963, 12.747548783981964, 12.874393189583735, 13.000000000000002, 13.12440474840669, 13.247641299491773, 13.36974195712094, 13.490737563232042, 13.610657588816201, 13.729530217745982, 13.847382424126229, 13.964240043768942, 14.080127840328723, 14.195069566578391, 14.309088021254185, 14.422205101855958, 14.534441853748634, 14.645818515876812, 14.756354563373707, 14.866068747318506, 14.974979131871939, 15.083103128998356, 15.190457530963315, 15.297058540778357, 15.402921800749365, 15.508062419270821, 15.612494995995997, 15.716233645501713, 15.819292019556375, 15.92168332809066, 16.023420358962067, 16.124515496597102, 16.224980739587952, 16.324827717314513, 16.424067705656842, 16.522711641858308, 16.62077013859466, 16.718253497300488, 16.81517172080024, 16.911534525287763, 17.00735135169495, 17.10263137648707, 17.19738352191984, 17.291616465790582, 17.38533865071371, 17.478558292948538, 17.57128339080558, 17.663521732655695, 17.755280904564707, 17.84656829757475, 17.937391114652097, 18.02775637731995, 18.11767093199344], [0.0, 1.82002747232013, 2.5739075352467506, 3.152380053229624, 3.64005494464026, 4.069705149024927, 4.4581386250317525, 4.815340071064556, 5.147815070493501, 5.46008241696039, 5.75543221661067, 6.036348233824819, 6.304760106459248, 6.562202374203345, 6.809919235938119, 7.048936089935843, 7.28010988928052, 7.504165509901817, 7.7217226057402515, 7.933315826311217, 8.139410298049855, 8.34041365880614, 8.536685539481937, 8.728545125048047, 8.916277250063505, 9.10013736160065, 9.280355596635296, 9.457140159688871, 9.630680142129112, 9.801147891956331, 9.968701018688442, 10.133484099755623, 10.295630140987003, 10.455261833163245, 10.612492638395564, 10.767427733679016, 10.92016483392078, 11.070794912742267, 11.21940283615844, 11.366067921669307, 11.51086443322134, 11.653862020806667, 11.795126112085452, 11.934718262280011, 12.072696467649639, 12.20911544707478, 12.34402689562851, 12.477479713467782, 12.609520212918495, 12.740192306240909, 12.869537676233753, 12.997595931555962, 13.12440474840669, 13.250000000000004, 13.37441587509526, 13.497684986693091, 13.619838471876237, 13.740906083661297, 13.860916275629114, 13.979896280015815, 14.097872179871686, 14.2148689758295, 14.330910647966515, 14.446020213193668, 14.56021977856104, 14.67353059082919, 14.785973082621247, 14.897566915439583, 15.008331019803634, 15.118283632740857, 15.227442332841061, 15.335824073065004, 15.443445211480503, 15.550321540083988, 15.656468311851176, 15.761900266148118, 15.866631652622434, 15.97067625368444, 16.074047405678513, 16.17675801883678, 16.27882059609971, 16.38024725088117, 16.481049723849512, 16.58123939879043, 16.68082731761228, 16.779824194549835, 16.87824042961825, 16.97608612136496, 17.073371078963874, 17.170104833692776, 17.266296649832007, 17.361955535019668, 17.457090250096094, 17.551709318468102, 17.6458210350213, 17.73943347460679, 17.83255450012701, 17.925191770243355, 18.017352746727255, 18.109044701474456, 18.2002747232013, 18.29104972384035], [0.0, 1.8371173070873839, 2.598076211353316, 3.1819805153394647, 3.6742346141747677, 4.107919181288747, 4.5, 4.860555523805895, 5.196152422706632, 5.511351921262151, 5.809475019311126, 6.0930288034769715, 6.363961030678929, 6.623820649745886, 6.87386354243376, 7.115124735378854, 7.348469228349535, 7.574628703771558, 7.794228634059948, 8.007808689023484, 8.215838362577493, 8.41872912024137, 8.616843969807043, 8.810505093353049, 9.0, 9.185586535436919, 9.367496997597598, 9.545941546018394, 9.72111104761179, 9.893179468704691, 10.062305898749052, 10.228636272739392, 10.392304845413264, 10.553435459602719, 10.712142642814275, 10.86853255964208, 11.022703842524303, 11.174748319313506, 11.324751652906127, 11.472793905583767, 11.618950038622252, 11.763290356018592, 11.90588089979066, 12.046783803156758, 12.186057606953943, 12.323757543866236, 12.459935794377111, 12.59464171781, 12.727922061357859, 12.859821149611685, 12.99038105676658, 13.119641763401928, 13.247641299491772, 13.374415875095258, 13.500000000000002, 13.624426593438715, 13.74772708486752, 13.8699315066802, 13.991068579633223, 14.111165791670084, 14.230249470757707, 14.348344852281743, 14.465476141489432, 14.581666571417685, 14.69693845669907, 14.811313243598624, 14.9248115565993, 15.037453241822567, 15.149257407543116, 15.260242462031854, 15.370426148939398, 15.47982558041272, 15.588457268119896, 15.696337152342263, 15.803480629279107, 15.90990257669732, 16.01561737804697, 16.12063894515351, 16.224980739587952, 16.328655792807933, 16.431676725154986, 16.53405576378645, 16.63580475961413, 16.736935203316047, 16.83745824048274, 16.937384685954324, 17.03672503740082, 17.135489488193794, 17.233687939614086, 17.331330012437014, 17.428425057933378, 17.524982168321884, 17.621010186706098, 17.716517716526575, 17.81151313055688, 17.906004579469982, 18.0, 18.09350712272223, 18.186533479473212, 18.279086410430914, 18.371173070873837, 18.46280043763676], [0.0, 1.854049621773916, 2.6220221204253793, 3.211308144666283, 3.708099243547832, 4.14578098794425, 4.541475531146238, 4.9053542175871465, 5.244044240850759, 5.562148865321747, 5.863019699779287, 6.149186938124423, 6.422616289332566, 6.68487097856047, 6.937218462755804, 7.180703308172536, 7.416198487095664, 7.644442425710327, 7.866066361276137, 8.081614937622309, 8.2915619758885, 8.496322733983215, 8.696263565463044, 8.89170962188937, 9.082951062292477, 9.27024810886958, 9.45383520059452, 9.633924433998848, 9.810708435174293, 9.98436277385793, 10.15504800579495, 10.32291141103129, 10.488088481701517, 10.650704202070399, 10.810874155219826, 10.968705484240154, 11.124297730643494, 11.277743568639963, 11.429129450662462, 11.578536176909413, 11.726039399558575, 11.871710070583767, 12.015614840697918, 12.157816415787828, 12.298373876248846, 12.437342963832748, 12.574776339959291, 12.710723818886162, 12.845232578665131, 12.97834735241741, 13.110110602126895, 13.240562676865363, 13.36974195712094, 13.497684986693091, 13.624426593438715, 13.750000000000002, 13.874436925511608, 13.997767679169419, 14.12002124644294, 14.241225368626115, 14.361406616345072, 14.48059045757458, 14.598801320656433, 14.716062652761437, 14.832396974191328, 14.947825928876748, 15.062370331392069, 15.17605021077619, 15.288884851420654, 15.40089283126144, 15.512092057488571, 15.622499799967995, 15.732132722552274, 15.84100691244089, 15.94913790773658, 16.056540723331413, 16.163229875244618, 16.269219403523945, 16.374522893812816, 16.479153497676997, 16.583123951777, 16.686446595965243, 16.78913339038082, 16.89119593160887, 16.99264546796643, 17.09349291397168, 17.1937488640494, 17.293423605521262, 17.392527130926087, 17.4910691497118, 17.589059099337863, 17.686506155823995, 17.78341924377874, 17.879807045938723, 17.975678012247553, 18.071040368501198, 18.165902124584953, 18.26027108232515, 18.354154842977653, 18.447560814373265, 18.54049621773916, 18.632968094214085], [0.0, 1.8708286933869707, 2.6457513110645907, 3.2403703492039306, 3.7416573867739413, 4.183300132670378, 4.58257569495584, 4.949747468305833, 5.291502622129181, 5.612486080160912, 5.916079783099616, 6.204836822995429, 6.480740698407861, 6.745368781616021, 7.0, 7.245688373094719, 7.483314773547883, 7.713624310270755, 7.937253933193772, 8.154753215150047, 8.366600265340756, 8.573214099741124, 8.774964387392123, 8.972179222463181, 9.16515138991168, 9.354143466934854, 9.539392014169458, 9.721111047611792, 9.899494936611665, 10.074720839804943, 10.246950765959596, 10.41633332799983, 10.583005244258363, 10.74709263010234, 10.908712114635714, 11.067971810589327, 11.224972160321824, 11.379806676741044, 11.532562594670797, 11.683321445547923, 11.832159566199232, 11.979148550710939, 12.124355652982143, 12.267844146385297, 12.409673645990859, 12.54990039801113, 12.68857754044952, 12.825755338380661, 12.961481396815723, 13.095800853708795, 13.228756555322953, 13.36038921588739, 13.490737563232042, 13.619838471876237, 13.74772708486752, 13.874436925511608, 14.0, 14.124446891825535, 14.247806848775006, 14.370107863199912, 14.491376746189438, 14.611639196202457, 14.730919862656235, 14.849242404917497, 14.966629547095765, 15.083103128998356, 15.198684153570664, 15.313392831113553, 15.42724862054151, 15.540270267920054, 15.652475842498527, 15.763882770434448, 15.874507866387544, 15.98436736314578, 16.093476939431078, 16.20185174601965, 16.309506430300093, 16.416455159382004, 16.522711641858308, 16.62828914831589, 16.73320053068151, 16.837458240482736, 16.94107434609742, 17.04406054905931, 17.146428199482248, 17.24818831066034, 17.349351572897472, 17.449928366615147, 17.549928774784245, 17.64936259472279, 17.74823934929885, 17.84656829757475, 17.944358444926362, 18.041618552668716, 18.138357147217057, 18.234582528810467, 18.33030277982336, 18.425525772688278, 18.520259177452136, 18.614510468986285, 18.708286933869708, 18.801595676963167], [0.0, 1.8874586088176875, 2.669269563007828, 3.2691742076555057, 3.774917217635375, 4.220485754033533, 4.623310502226732, 4.993746088859544, 5.338539126015656, 5.662375826453062, 5.968668193156661, 6.259992012774458, 6.538348415311011, 6.8053287944081005, 7.0622234459127675, 7.310095758606723, 7.54983443527075, 7.78219120813669, 8.007808689023484, 8.227241335952169, 8.440971508067067, 8.649421946003098, 8.852965604812887, 9.051933495115836, 9.246621004453464, 9.437293044088438, 9.62418827746008, 9.807522622966518, 9.987492177719089, 10.164275675128062, 10.338036564067664, 10.508924778491851, 10.677078252031311, 10.842624221100722, 11.00568035152757, 11.166355717063649, 11.324751652906125, 11.480962503205035, 11.635076278220097, 11.787175234126284, 11.937336386313323, 12.085631965271821, 12.232129822725069, 12.376893794486563, 12.519984025548917, 12.661457262100598, 12.801367114492107, 12.939764294607535, 13.076696830622023, 13.212210261723811, 13.34634781503914, 13.479150566708572, 13.610657588816201, 13.740906083661297, 13.8699315066802, 13.997767679169419, 14.124446891825535, 14.250000000000002, 14.374456511465052, 14.497844667397978, 14.620191517213446, 14.741522987805567, 14.861863947701849, 14.981238266578634, 15.0996688705415, 15.217177793533201, 15.333786225195654, 15.449514555480377, 15.56438241627338, 15.678408720275156, 15.791611697353757, 15.904008928568924, 16.01561737804697, 16.12645342287014, 16.236532881129516, 16.345871038277526, 16.454482671904337, 16.562382075051886, 16.66958307816965, 16.776099069807618, 16.881943016134134, 16.987127479359188, 17.091664635137214, 17.195566289017645, 17.298843892006197, 17.401508555294853, 17.503571064214295, 17.605041891458253, 17.705931209625774, 17.80624890312387, 17.906004579469982, 18.00520758003084, 18.103866990231673, 18.201991649267395, 18.2995901593451, 18.39667089448523, 18.49324200890693, 18.589311445021306, 18.684886941054796, 18.779976038323372, 18.874586088176876, 18.968724258631628], [0.0, 1.9039432764659774, 2.6925824035672523, 3.297726489568231, 3.8078865529319548, 4.257346591481601, 4.663689526544408, 5.0373604199024715, 5.385164807134505, 5.7118298293979315, 6.020797289396148, 6.3146654701575455, 6.595452979136462, 6.864765108872992, 7.123903424387504, 7.373940601876313, 7.6157731058639095, 7.850159234053791, 8.077747210701757, 8.299096336348917, 8.514693182963201, 8.724964183307575, 8.930285549745877, 9.130991183874837, 9.327379053088816, 9.519716382329888, 9.708243919473801, 9.893179468704691, 10.074720839804943, 10.25304832720494, 10.428326807307105, 10.600707523557096, 10.77032961426901, 10.937321427113682, 11.10180165558726, 11.263880326068811, 11.423659658795863, 11.581234821900471, 11.736694594305504, 11.890121950594118, 12.041594578792296, 12.19118534023661, 12.338962679253068, 12.484990989183773, 12.629330940315091, 12.7720397744448, 12.913171570144959, 13.052777482206615, 13.190905958272923, 13.32760293526184, 13.462912017836262, 13.59687464088715, 13.729530217745983, 13.860916275629114, 13.991068579633225, 14.12002124644294, 14.247806848775008, 14.374456511465052, 14.500000000000002, 14.624465802209667, 14.747881203752627, 14.870272357963051, 14.991664350564951, 15.112081259707413, 15.231546211727819, 15.350081433008752, 15.467708298258021, 15.5844473755087, 15.700318468107582, 15.815340653934713, 15.929532322073992, 16.04291120713445, 16.155494421403514, 16.26729848499744, 16.3783393541592, 16.48863244784115, 16.598192672697834, 16.707034446603622, 16.81517172080024, 16.92261800077045, 17.029386365926403, 17.135489488193794, 17.24093964956667, 17.345748758701657, 17.44992836661515, 17.553489681541958, 17.656443583009576, 17.758800635178044, 17.860571099491754, 17.961764946686056, 18.062391868188445, 18.162461286951174, 18.261982367749674, 18.36096402697854, 18.459414941974735, 18.557343559895635, 18.65475810617763, 18.75166659259918, 18.848076824970764, 18.943996410472636, 19.039432764659775, 19.134393118152456], [0.0, 1.920286436967152, 2.715695122800054, 3.326033673912518, 3.840572873934304, 4.293891009329417, 4.703721930556695, 5.080600358225394, 5.431390245600108, 5.760859310901456, 6.072478900745559, 6.368869601428499, 6.652067347825036, 6.923691212063114, 7.185053931599957, 7.437237390321758, 7.681145747868608, 7.917543811056556, 8.147085368400163, 8.370334521391603, 8.587782018658833, 8.799857953399021, 9.00694176732591, 9.209370228196931, 9.40744386111339, 9.60143218483576, 9.79157801378307, 9.978101021737555, 10.161200716450788, 10.341058939973218, 10.517841983981313, 10.691702390171548, 10.862780491200215, 11.031205736455105, 11.197097838279346, 11.360567767501763, 11.521718621802911, 11.680646386223668, 11.837440601751716, 11.992184955211457, 12.144957801491119, 12.295832627357937, 12.444878464653643, 12.592160259463027, 12.737739202856998, 12.88167302798825, 13.024016277631103, 13.164820545681586, 13.304134695650072, 13.442005058770063, 13.57847561400027, 13.713588151902478, 13.847382424126229, 13.979896280015815, 14.111165791670086, 14.241225368626115, 14.370107863199914, 14.49784466739798, 14.624465802209665, 14.749999999999998, 14.874474780643515, 14.997916521970641, 15.12035052503744, 15.24180107467618, 15.362291495737216, 15.481844205391035, 15.600480761822695, 15.718221909618148, 15.835087622113113, 15.95109714094927, 16.066269013059628, 16.180621125284407, 16.294170736800325, 16.406934509529805, 16.518928536681788, 16.63016836956259, 16.740669042783207, 16.850445097978866, 16.95951060614663, 17.067879188698285, 17.175564037317667, 17.282577932704367, 17.388933262279203, 17.494642036920904, 17.599715906798043, 17.704166176355212, 17.808003818508126, 17.91123948809797, 18.01388353465182, 18.115946014492312, 18.21743670223668, 18.318365101722367, 18.418740456393863, 18.518571759182723, 18.61786776191087, 18.71663698424479, 18.81488772222678, 18.91262805640718, 19.009865859600378, 19.106608804285496, 19.20286436967152, 19.29863984844528], [0.0, 1.9364916731037083, 2.7386127875258306, 3.3541019662496847, 3.8729833462074166, 4.330127018922193, 4.743416490252569, 5.123475382979799, 5.477225575051661, 5.809475019311125, 6.123724356957945, 6.422616289332565, 6.708203932499369, 6.98212002188447, 7.245688373094719, 7.499999999999999, 7.745966692414833, 7.984359711335655, 8.215838362577491, 8.440971508067067, 8.660254037844386, 8.874119674649425, 9.082951062292475, 9.287087810503355, 9.486832980505138, 9.682458365518542, 9.87420882906575, 10.062305898749054, 10.246950765959598, 10.428326807307105, 10.606601717798211, 10.781929326423912, 10.954451150103322, 11.124297730643494, 11.291589790636214, 11.4564392373896, 11.61895003862225, 11.779218989389747, 11.937336386313323, 12.093386622447825, 12.24744871391589, 12.399596767637243, 12.549900398011134, 12.698425099200293, 12.84523257866513, 12.990381056766577, 13.133925536563696, 13.275918047351754, 13.416407864998739, 13.555441711725958, 13.693063937629152, 13.82931668593933, 13.96424004376894, 14.097872179871684, 14.230249470757707, 14.361406616345072, 14.491376746189438, 14.620191517213446, 14.747881203752625, 14.874474780643515, 14.999999999999998, 15.124483462254172, 15.247950681976905, 15.370426148939396, 15.491933384829666, 15.612494995995995, 15.732132722552272, 15.850867484147358, 15.96871942267131, 16.08570794214541, 16.20185174601965, 16.31716887208072, 16.431676725154983, 16.545392107774294, 16.65833124895768, 16.77050983124842, 16.881943016134134, 16.992645467966426, 17.10263137648707, 17.211914478058503, 17.32050807568877, 17.428425057933374, 17.53567791675018, 17.642278764377348, 17.74823934929885, 17.853571071357123, 17.95828499606797, 18.062391868188442, 18.16590212458495, 18.26882590644511, 18.371173070873834, 18.472953201911164, 18.57417562100671, 18.6748493969831, 18.774983355518586, 18.87458608817687, 18.973665961010276, 19.072231122760652, 19.170289512680814, 19.267848867997692, 19.364916731037084, 19.461500456028563], [0.0, 1.9525624189766637, 2.7613402542968153, 3.381937314617171, 3.9051248379533274, 4.366062299143246, 4.782781617427248, 5.165994579942956, 5.522680508593631, 5.8576872569299905, 6.174544517614234, 6.47591692349431, 6.763874629234342, 7.040063920164362, 7.305819598101229, 7.562241731127086, 7.810249675906655, 8.050621094052309, 8.284020762890446, 8.511022265274601, 8.732124598286491, 8.94776508408664, 9.1583295420071, 9.364160400164021, 9.565563234854496, 9.76281209488332, 9.95615387586994, 10.145811943851514, 10.331989159885913, 10.514870422406545, 10.694624818103717, 10.871407452579449, 11.045361017187261, 11.21661713708728, 11.385297536735699, 11.551515052147922, 11.715374513859981, 11.876973520219703, 12.036403117210723, 12.193748398257199, 12.349089035228468, 12.502499750049987, 12.654050734843766, 12.803808027301876, 12.95183384698862, 13.098186897429734, 13.242922638149027, 13.386093530227555, 13.527749258468685, 13.667936932836644, 13.806701271484076, 13.944084767384341, 14.080127840328725, 14.2148689758295, 14.348344852281745, 14.480590457574582, 14.611639196202457, 14.741522987805569, 14.870272357963051, 14.997916521970643, 15.124483462254172, 15.249999999999998, 15.374491861521799, 15.497983739828868, 15.62049935181331, 15.742061491431166, 15.862692079215305, 15.98241220842461, 16.101242188104617, 16.219201583308596, 16.33630925270454, 16.452583383772897, 16.56804152578089, 16.68270062070287, 16.796577032240823, 16.909686573085853, 17.022044530549202, 17.133665690680438, 17.244564360980537, 17.354754391808605, 17.464249196572982, 17.573061770789973, 17.681204710086927, 17.788690227220215, 17.89553016817328, 18.001736027394692, 18.10731896223182, 18.21228980661136, 18.3166590840142, 18.420437019788643, 18.523633552842703, 18.62625834675338, 18.728320800328042, 18.829830057650547, 18.930795017642552, 19.031224343168255, 19.131126469708992, 19.23050961363219, 19.329381780077707, 19.427750770482927, 19.52562418976664, 19.623009453190406], [0.0, 1.9685019685029528, 2.7838821814150108, 3.4095454242464642, 3.9370039370059056, 4.401704215414752, 4.8218253804964775, 5.208166663999915, 5.5677643628300215, 5.905505905508858, 6.224949798994366, 6.528782428600298, 6.8190908484929285, 7.097534783289196, 7.365459931328117, 7.623975340988452, 7.874007874011811, 8.116341540373963, 8.351646544245034, 8.580501150865258, 8.803408430829505, 9.020809276334358, 9.233092656309694, 9.440603794249602, 9.643650760992955, 9.842509842514763, 10.037429949942366, 10.228636272739394, 10.41633332799983, 10.600707523557096, 10.78192932642391, 10.960155108391486, 11.135528725660043, 11.308182877898643, 11.478240283248995, 11.645814698852115, 11.811011811017716, 11.973930014828047, 12.134661099511598, 12.293290853144248, 12.449899597988733, 12.60456266595553, 12.757350822173075, 12.908330643425584, 13.057564857200596, 13.205112646244254, 13.351029922818688, 13.49536957626578, 13.638181696985857, 13.779513779520668, 13.919410907075054, 14.057915919509549, 14.195069566578391, 14.330910647966514, 14.465476141489434, 14.598801320656433, 14.730919862656235, 14.861863947701849, 14.99166435056495, 15.12035052503744, 15.247950681976905, 15.374491861521797, 15.5, 15.624499991999743, 15.748015748023622, 15.870570248103878, 15.992185591719476, 16.112883044322018, 16.232683080747925, 16.351605425767833, 16.469669092000604, 16.58689241539837, 16.703293088490067, 16.81888819155416, 16.9336942218761, 17.04772712123232, 17.161002301730516, 17.273534670124697, 17.38533865071371, 17.49642820692269, 17.60681686165901, 17.716517716526575, 17.825543469975887, 17.93390643446095, 18.041618552668716, 18.148691412881536, 18.255136263528684, 18.36096402697854, 18.466185312619388, 18.570810429273138, 18.6748493969831, 18.778311958213923, 18.881207588499205, 18.98354550656963, 19.085334683992315, 19.18658385434989, 19.28730152198591, 19.3874959703413, 19.487175269905077, 19.586347285800894, 19.685019685029527, 19.783199943386307], [0.0, 1.984313483298443, 2.806243040080456, 3.4369317712168805, 3.968626966596886, 4.437059837324712, 4.860555523805895, 5.25, 5.612486080160912, 5.952940449895329, 6.274950199005566, 6.581223290544092, 6.873863542433761, 7.154544010627093, 7.4246212024587495, 7.685213074469699, 7.937253933193772, 8.181534085976786, 8.418729120241368, 8.649421946003098, 8.874119674649425, 9.093266739736606, 9.307255234493143, 9.51643315533714, 9.72111104761179, 9.921567416492216, 10.118053172424032, 10.310795313650642, 10.5, 10.685855136581257, 10.868532559642079, 11.048189896992177, 11.224972160321824, 11.399013115178, 11.570436465406134, 11.739356881873897, 11.905880899790658, 12.070107704573312, 12.232129822725069, 12.392033731393731, 12.549900398011133, 12.705805759573062, 12.859821149611687, 13.012013679673103, 13.162446581088185, 13.311179511974135, 13.45826883369477, 13.603767860412791, 13.747727084867522, 13.890194383089101, 14.031215200402281, 14.17083272076839, 14.309088021254187, 14.446020213193668, 14.581666571417687, 14.716062652761439, 14.849242404917499, 14.981238266578636, 15.112081259707415, 15.24180107467618, 15.370426148939398, 15.497983739828868, 15.624499991999745, 15.75, 15.874507866387544, 15.998046755776157, 16.12063894515351, 16.242305870780786, 16.36306817195357, 16.482945731876935, 16.60195771588399, 16.720122607205965, 16.837458240482736, 16.953981833185974, 17.06971001511156, 17.1846588560844, 17.298843892006197, 17.41228014936585, 17.524982168321888, 17.63696402445727, 17.74823934929885, 17.858821349685986, 17.96872282606641, 18.077956189790925, 18.186533479473212, 18.2944663764757, 18.401766219577947, 18.5084440188796, 18.614510468986285, 18.719975961523026, 18.8248505970167, 18.929144196185945, 19.03286631067428, 19.13602623325961, 19.238633007570993, 19.340695437341438, 19.44222209522358, 19.543221331193077, 19.643701280563192, 19.743669871632274, 19.843134832984433, 19.942103700462496], [0.0, 2.0, 2.8284271247461903, 3.4641016151377553, 4.0, 4.47213595499958, 4.898979485566357, 5.291502622129181, 5.656854249492381, 6.0, 6.324555320336759, 6.633249580710801, 6.9282032302755105, 7.211102550927979, 7.483314773547883, 7.745966692414834, 8.0, 8.246211251235321, 8.485281374238571, 8.717797887081348, 8.94427190999916, 9.165151389911681, 9.38083151964686, 9.59166304662544, 9.797958971132713, 10.000000000000002, 10.19803902718557, 10.392304845413266, 10.583005244258363, 10.77032961426901, 10.95445115010332, 11.135528725660045, 11.313708498984761, 11.489125293076059, 11.661903789690601, 11.832159566199232, 12.0, 12.16552506059644, 12.328828005937954, 12.489995996796798, 12.649110640673518, 12.806248474865697, 12.961481396815723, 13.114877048604, 13.266499161421603, 13.416407864998737, 13.564659966250536, 13.71130920080209, 13.856406460551021, 14.0, 14.142135623730951, 14.282856857085703, 14.422205101855958, 14.560219778561038, 14.69693845669907, 14.832396974191328, 14.966629547095765, 15.099668870541501, 15.231546211727817, 15.362291495737216, 15.491933384829668, 15.620499351813308, 15.748015748023622, 15.874507866387543, 16.0, 16.1245154965971, 16.24807680927192, 16.3707055437449, 16.492422502470642, 16.61324772583615, 16.73320053068151, 16.852299546352718, 16.970562748477143, 17.088007490635064, 17.204650534085253, 17.320508075688775, 17.435595774162696, 17.549928774784245, 17.663521732655695, 17.776388834631177, 17.88854381999832, 18.0, 18.110770276274835, 18.2208671582886, 18.330302779823363, 18.439088914585774, 18.547236990991408, 18.65475810617763, 18.76166303929372, 18.867962264113206, 18.973665961010276, 19.078784028338912, 19.18332609325088, 19.28730152198591, 19.390719429665317, 19.493588689617926, 19.595917942265427, 19.69771560359221, 19.79898987322333, 19.8997487421324, 20.000000000000004, 20.099751242241783], [0.0, 2.0155644370746373, 2.850438562747845, 3.4910600109422356, 4.031128874149275, 4.5069390943299865, 4.937104414532874, 5.332682251925386, 5.70087712549569, 6.046693311223912, 6.373774391990981, 6.684870978560469, 6.982120021884471, 7.267220926874317, 7.541551564499177, 7.806247497997997, 8.06225774829855, 8.310385069297329, 8.551315688243534, 8.78564169540279, 9.013878188659973, 9.236476600955584, 9.453835200594519, 9.666307464590602, 9.874208829065749, 10.077822185373186, 10.277402395547234, 10.473180032826708, 10.665364503850771, 10.854146673046206, 11.039701082909806, 11.222187843731719, 11.40175425099138, 11.578536176909413, 11.752659273543157, 11.92424001771182, 12.093386622447824, 12.260199835239229, 12.424773639789178, 12.587195875174105, 12.747548783981962, 12.905909499140305, 13.062350477613132, 13.216939887886301, 13.369741957120938, 13.520817282989958, 13.670223114492314, 13.818013605435478, 13.964240043768942, 14.108951059522461, 14.252192813739224, 14.394009170484782, 14.534441853748634, 14.67353059082919, 14.811313243598624, 14.947825928876748, 15.083103128998355, 15.217177793533201, 15.35008143300875, 15.481844205391035, 15.612494995995995, 15.742061491431164, 15.870570248103878, 15.998046755776155, 16.1245154965971, 16.25, 16.374522893812813, 16.498105951896417, 16.620770138594658, 16.74253565025322, 16.86342195404005, 16.98344782427879, 17.102631376487068, 17.22099009929452, 17.3385408843997, 17.455300054711177, 17.57128339080558, 17.68650615582399, 17.800983118917898, 17.91472857734663, 18.027756377319946, 18.140079933671736, 18.25171224844398, 18.36266592845385, 18.472953201911167, 18.58258593414813, 18.691575642518742, 18.799933510520724, 18.907670401189037, 19.014796869806418, 19.121323175972943, 19.22725929507375, 19.332614929181204, 19.437399517425163, 19.541622245862804, 19.645292056877135, 19.748417658131498, 19.851007531105317, 19.953069939234915, 20.054612935681405, 20.155644370746373, 20.256171898954648], [0.0, 2.03100960115899, 2.8722813232690143, 3.5178118198675725, 4.06201920231798, 4.541475531146237, 4.9749371855331, 5.373546315051169, 5.744562646538029, 6.093028803476971, 6.422616289332565, 6.736096792653741, 7.035623639735145, 7.322909257938406, 7.599342076785332, 7.866066361276136, 8.12403840463596, 8.374067112222113, 8.616843969807043, 8.852965604812887, 9.082951062292475, 9.307255234493143, 9.526279441628825, 9.740379869389079, 9.9498743710662, 10.155048005794951, 10.356157588603992, 10.553435459602719, 10.747092630102339, 10.93732142711368, 11.124297730643493, 11.308182877898641, 11.489125293076057, 11.667261889578036, 11.84271928232701, 12.015614840697916, 12.186057606953941, 12.354149100605838, 12.519984025548915, 12.683650893965824, 12.84523257866513, 13.004806803639953, 13.162446581088185, 13.318220601867202, 13.472193585307481, 13.624426593438711, 13.77497731395591, 13.923900315644321, 14.07124727947029, 14.21706720811293, 14.361406616345072, 14.504309704360288, 14.645818515876812, 14.785973082621247, 14.9248115565993, 15.062370331392069, 15.198684153570664, 15.333786225195656, 15.46770829825802, 15.600480761822693, 15.732132722552272, 15.862692079215305, 15.992185591719476, 16.120638945153505, 16.24807680927192, 16.374522893812816, 16.5, 16.6245300685463, 16.748134224444225, 16.870832818802988, 16.99264546796643, 17.11359109012483, 17.233687939614086, 17.352953639078276, 17.471405209656147, 17.589059099337863, 17.705931209625774, 17.822036920621617, 17.937391114652097, 18.052008198535695, 18.16590212458495, 18.27908641043091, 18.391574157749524, 18.503378069963333, 18.614510468986285, 18.724983311074006, 18.83480820183736, 18.943996410472636, 19.05255888325765, 19.16050625635972, 19.267848867997692, 19.374596769997563, 19.480759738778158, 19.586347285800894, 19.691368667515217, 19.79583289482915, 19.8997487421324, 20.003124755897517, 20.1059692628831, 20.20829037796122, 20.310096011589902, 20.411393876950196], [0.0, 2.0463381929681126, 2.8939592256975564, 3.544361719689457, 4.092676385936225, 4.575751304430781, 5.0124844139408555, 5.414101956926928, 5.787918451395113, 6.139014578904337, 6.471089552772392, 6.7869359802491145, 7.088723439378914, 7.378177281686853, 7.656696415556778, 7.925433742073679, 8.18535277187245, 8.437268515343101, 8.68187767709267, 8.919781387455638, 9.151502608861563, 9.377499666755526, 9.598176910226233, 9.81389321319526, 10.024968827881711, 10.231690964840563, 10.434318377354606, 10.63308515906837, 10.828203913853857, 11.019868420267096, 11.208255885729946, 11.393528865105841, 11.575836902790225, 11.755317945508748, 11.932099563781723, 12.106300012803251, 12.278029157808675, 12.447389284504604, 12.614475811542865, 12.77937791913206, 12.942179105544785, 13.102957681378658, 13.261787209874846, 13.418736900319642, 13.573871960498229, 13.727253913292342, 13.87894088178201, 14.0289878465982, 14.177446878757827, 14.324367350776786, 14.469796128487783, 14.613777745675485, 14.756354563373707, 14.897566915439583, 15.037453241822567, 15.17605021077619, 15.313392831113555, 15.449514555480377, 15.5844473755087, 15.718221909618148, 15.850867484147358, 15.982412208424607, 16.112883044322018, 16.242305870780786, 16.3707055437449, 16.498105951896417, 16.6245300685463, 16.75, 16.874537030686202, 16.998161665309578, 17.120893668263932, 17.24275210052038, 17.36375535418534, 17.48392118490586, 17.603266742283942, 17.721808598447282, 17.839562774911276, 17.956544767855537, 18.072769571927818, 18.188251702678848, 18.303005217723125, 18.417043736713012, 18.530380460206427, 18.643028187502157, 18.75499933351105, 18.866305944725905, 18.976959714348343, 19.086971996626392, 19.196353820452465, 19.30511590226798, 19.413268658317175, 19.520822216289968, 19.62778642639052, 19.734170871865885, 19.8399848790265, 19.94523752678819, 20.049937655763422, 20.154093876927337, 20.257714579882894, 20.360807940747343, 20.463381929681127, 20.56544431807881], [0.0, 2.0615528128088303, 2.9154759474226504, 3.5707142142714257, 4.123105625617661, 4.6097722286464435, 5.04975246918104, 5.454356057317857, 5.830951894845301, 6.184658438426491, 6.519202405202648, 6.837397165588673, 7.141428428542851, 7.433034373659254, 7.713624310270756, 7.984359711335656, 8.246211251235321, 8.5, 8.746427842267952, 8.986100377805716, 9.219544457292887, 9.447221813845593, 9.669539802906858, 9.886859966642595, 10.09950493836208, 10.307764064044152, 10.511898020814321, 10.712142642814277, 10.908712114635714, 11.10180165558726, 11.291589790636214, 11.478240283248997, 11.661903789690601, 11.842719282327014, 12.020815280171307, 12.196310917650468, 12.369316876852983, 12.539936203984453, 12.708265027138836, 12.874393189583735, 13.038404810405297, 13.200378782444085, 13.36038921588739, 13.518505834595775, 13.674794331177345, 13.829316685939329, 13.982131454109561, 14.13329402510257, 14.282856857085703, 14.430869689661812, 14.577379737113253, 14.722431864335459, 14.866068747318508, 15.008331019803636, 15.149257407543118, 15.288884851420656, 15.427248620541512, 15.564382416273382, 15.700318468107582, 15.835087622113114, 15.968719422671311, 16.101242188104617, 16.232683080747925, 16.36306817195357, 16.492422502470642, 16.62077013859466, 16.748134224444225, 16.874537030686206, 17.0, 17.12454378954371, 17.24818831066034, 17.37095276604021, 17.492855684535904, 17.613914953808536, 17.7341478509682, 17.853571071357127, 17.972200755611432, 18.090052515125542, 18.207141456033128, 18.323482201808694, 18.439088914585774, 18.553975315279473, 18.66815470259447, 18.78163997099295, 18.894443627691185, 19.00657780874821, 19.11805429430516, 19.22888452302941, 19.339079605813716, 19.448650338776723, 19.557607215607945, 19.665960439297137, 19.77371993328519, 19.880895352071043, 19.987496091306685, 20.093531297410117, 20.19900987672416, 20.303940504246953, 20.408331631958553, 20.512191496766015, 20.615528128088304, 20.718349355100663], [0.0, 2.0766559657295187, 2.936835031117683, 3.5968736424845402, 4.153311931459037, 4.643543905251677, 5.086747487343952, 5.494315243958978, 5.873670062235366, 6.229967897188557, 6.566962768281849, 6.887488656977957, 7.1937472849690804, 7.487489565935969, 7.770135133960027, 8.042853971072706, 8.306623862918075, 8.562271894771854, 8.810505093353049, 9.051933495115838, 9.287087810503355, 9.516433155337142, 9.740379869389079, 9.959292143521045, 10.173494974687904, 10.383279828647595, 10.588909292273687, 10.790620927453622, 10.988630487917955, 11.183134623172522, 11.374313166077325, 11.562331079847178, 11.747340124470732, 11.929480290440152, 12.108881038312335, 12.285662375305616, 12.459935794377113, 12.631805096659782, 12.801367114492109, 12.968712349342939, 13.133925536563698, 13.297086146972202, 13.458268833694772, 13.617543831396322, 13.774977313955914, 13.93063171575503, 14.084566021003274, 14.23683602490385, 14.387494569938161, 14.536591760106631, 14.684175155588415, 14.830289949963893, 14.974979131871939, 15.118283632740857, 15.260242462031856, 15.40089283126144, 15.540270267920054, 15.678408720275156, 15.815340653934712, 15.95109714094927, 16.08570794214541, 16.219201583308593, 16.351605425767833, 16.48294573187693, 16.61324772583615, 16.74253565025322, 16.870832818802988, 16.998161665309578, 17.124543789543708, 17.25, 17.374550353894055, 17.498214194597118, 17.621010186706098, 17.742956348929003, 17.864070084949844, 17.984368212422698, 18.103866990231676, 18.22258214414192, 18.34052889095623, 18.45772196128222, 18.57417562100671, 18.689903691565668, 18.804919569091492, 18.91923624251254, 19.032866310674283, 19.14582199854579, 19.258115172570758, 19.369757355217438, 19.480759738778158, 19.591133198465062, 19.700888304845545, 19.81003533565753, 19.91858428704209, 20.026544884228034, 20.133926591700888, 20.24073862288627, 20.346989949375807, 20.452689309721595, 20.55784521782378, 20.66246597093387, 20.76655965729519, 20.87013416344035], [0.0, 2.091650066335189, 2.9580398915498085, 3.6228441865473604, 4.183300132670378, 4.677071733467427, 5.1234753829798, 5.5339859052946645, 5.916079783099617, 6.274950199005567, 6.614378277661476, 6.937218462755806, 7.245688373094721, 7.541551564499179, 7.826237921249264, 8.100925873009826, 8.366600265340756, 8.62409415533017, 8.874119674649425, 9.117291264405235, 9.354143466934854, 9.585144756340409, 9.810708435174293, 10.03120132386944, 10.2469507659596, 10.458250331675945, 10.665364503850773, 10.868532559642082, 11.067971810589329, 11.263880326068811, 11.4564392373896, 11.645814698852117, 11.832159566199234, 12.015614840697918, 12.196310917650468, 12.374368670764582, 12.549900398011134, 12.723010649999475, 12.893796958227629, 13.062350477613133, 13.228756555322953, 13.393095235978874, 13.555441711725962, 13.715866724345203, 13.874436925511612, 14.03121520040228, 14.186260959111108, 14.339630399699988, 14.491376746189442, 14.641550464346322, 14.790199457749042, 14.937369246289657, 15.083103128998358, 15.227442332841063, 15.3704261489394, 15.512092057488573, 15.652475842498529, 15.791611697353758, 15.929532322073992, 16.066269013059628, 16.201851746019653, 16.33630925270454, 16.469669092000604, 16.60195771588399, 16.73320053068151, 16.863421954040053, 16.99264546796643, 17.120893668263932, 17.24818831066034, 17.374550353894055, 17.5, 17.624556732014568, 17.74823934929885, 17.871066000661518, 17.99305421544658, 18.1142209327368, 18.23458252881047, 18.354154842977653, 18.472953201911167, 18.59099244257821, 18.708286933869708, 18.824850597016702, 18.940696924875816, 19.055839000159505, 19.170289512680817, 19.284060775676892, 19.397164741270824, 19.509613015126675, 19.621416870348586, 19.732587260671114, 19.84313483298443, 19.953069939234915, 20.06240264773888, 20.17114275394431, 20.27929979067325, 20.386883037875112, 20.4939015319192, 20.600364074452667, 20.70627924084866, 20.811655388267415, 20.91650066335189, 21.02082300957791], [0.0, 2.1065374432940898, 2.9790938219532466, 3.648629879831607, 4.2130748865881795, 4.710360920354193, 5.1599418601375735, 5.573374202401989, 5.958187643906493, 6.319612329882269, 6.661456297237114, 6.986594306241061, 7.297259759663214, 7.595228765481656, 7.881941385217223, 8.15858443604036, 8.426149773176359, 8.685476383020104, 8.937281465859739, 9.18218383610348, 9.420721840708387, 9.653367288153913, 9.880536422684752, 10.102598675588375, 10.319883720275147, 10.53268721647045, 10.74127552947042, 10.945889639494819, 11.146748404803978, 11.344051304538429, 11.537980759214324, 11.7287041057399, 11.916375287812986, 12.10113631028095, 12.283118496538247, 12.462443580614519, 12.639224659764539, 12.8135670287395, 12.985568913220554, 13.155322116922871, 13.322912594474229, 13.48842096021621, 13.651922941476048, 13.813489783541304, 13.973188612482122, 14.131082761062578, 14.287232062229547, 14.44169311403618, 14.594519519326427, 14.745762103058627, 14.895469109766232, 15.043686383330385, 15.190457530963313, 15.335824073065004, 15.479825580412722, 15.622499799967995, 15.763882770434446, 15.904008928568924, 16.042911207134445, 16.180621125284404, 16.31716887208072, 16.452583383772897, 16.58689241539837, 16.720122607205965, 16.852299546352718, 16.98344782427879, 17.11359109012483, 17.24275210052038, 17.370952766040208, 17.498214194597118, 17.624556732014568, 17.75, 17.874562931719478, 17.99826380515632, 18.12112027442012, 18.243149399158032, 18.36436767220696, 18.48479104561369, 18.60443495513906, 18.723314343352783, 18.841443681416774, 18.95883698964681, 19.075507856935292, 19.191469459111254, 19.306734576307825, 19.421315609401955, 19.5352245955863, 19.648473223128562, 19.761072845369505, 19.873034494007197, 19.98436889171134, 20.095086464108583, 20.20519735117675, 20.314711418083203, 20.423638265500102, 20.531987239427163, 20.639767440550294, 20.746987733162616, 20.853656753672723, 20.95978291872318, 21.0653744329409, 21.1704392963396], [0.0, 2.121320343559643, 3.0, 3.6742346141747677, 4.242640687119286, 4.743416490252569, 5.196152422706632, 5.612486080160912, 6.0, 6.363961030678928, 6.708203932499369, 7.035623639735146, 7.348469228349535, 7.6485292703891785, 7.937253933193772, 8.215838362577491, 8.485281374238571, 8.74642784226795, 9.0, 9.246621004453466, 9.486832980505138, 9.72111104761179, 9.9498743710662, 10.173494974687902, 10.392304845413264, 10.606601717798213, 10.81665382639197, 11.022703842524303, 11.224972160321824, 11.423659658795863, 11.61895003862225, 11.811011811017718, 12.0, 12.186057606953943, 12.36931687685298, 12.549900398011134, 12.727922061357855, 12.903487900563942, 13.076696830622023, 13.247641299491772, 13.416407864998739, 13.583077707206126, 13.747727084867522, 13.910427743243556, 14.071247279470292, 14.230249470757705, 14.387494569938157, 14.543039572248988, 14.69693845669907, 14.849242404917497, 15.000000000000002, 15.14925740754312, 15.297058540778357, 15.443445211480503, 15.588457268119898, 15.732132722552274, 15.874507866387544, 16.01561737804697, 16.155494421403514, 16.29417073680032, 16.431676725154983, 16.56804152578089, 16.703293088490067, 16.837458240482736, 16.970562748477143, 17.10263137648707, 17.233687939614086, 17.36375535418534, 17.4928556845359, 17.621010186706098, 17.74823934929885, 17.874562931719478, 18.0, 18.12456896039186, 18.24828759089466, 18.371173070873837, 18.493242008906932, 18.614510468986285, 18.734993995195197, 18.854707634964804, 18.973665961010276, 19.091883092036785, 19.20937271229855, 19.32614809008769, 19.44222209522358, 19.557607215607945, 19.672315572906, 19.786358937409382, 19.8997487421324, 20.012496096189498, 20.12461179749811, 20.236106344848064, 20.346989949375804, 20.457272545478784, 20.566963801203133, 20.676073128135332, 20.784609690826528, 20.892582415776182, 21.0, 21.106870919205434, 21.213203435596427, 21.319005605327845], [0.0, 2.136000936329383, 3.020761493398643, 3.699662146737186, 4.272001872658766, 4.776243293635701, 5.232112384114088, 5.651327277728658, 6.041522986797286, 6.408002808988148, 6.754628043053148, 7.084313657652378, 7.399324293474372, 7.701460900374682, 7.99218368157289, 8.272696053887149, 8.544003745317532, 8.806957476904268, 9.06228448019593, 9.310612224768038, 9.552486587271401, 9.788385975225948, 10.01873245475694, 10.24390062427394, 10.464224768228176, 10.680004681646915, 10.891510455395984, 11.098986440211558, 11.302654555457316, 11.502717070327341, 11.699358956797589, 11.892749892266297, 12.083045973594572, 12.270391191808029, 12.45491870708115, 12.636751956100113, 12.816005617976296, 12.992786460186284, 13.167194082263693, 13.339321571954102, 13.509256086106296, 13.677079366589929, 13.84286819990713, 14.006694827831438, 14.168627315304755, 14.328729880907098, 14.48706319445042, 14.643684645607472, 14.798648586948744, 14.95200655430568, 15.103807466993215, 15.254097810096802, 15.402921800749365, 15.550321540083988, 15.696337152342265, 15.84100691244089, 15.98436736314578, 16.12645342287014, 16.26729848499744, 16.406934509529805, 16.545392107774298, 16.68270062070287, 16.818888191554162, 16.95398183318597, 17.088007490635064, 17.220990099294525, 17.352953639078276, 17.483921184905864, 17.613914953808536, 17.742956348929003, 17.871066000661514, 17.99826380515632, 18.12456896039186, 18.25, 18.374574825012957, 18.49831073368593, 18.621224449536076, 18.743332147726562, 18.864649479913485, 18.985191597663693, 19.104973174542803, 19.224008426964446, 19.342311133884703, 19.45989465541887, 19.576771950451896, 19.69295559330798, 19.808457789540306, 19.92329039089678, 20.03746490951388, 20.150992531386635, 20.263884129159443, 20.376150274278995, 20.48780124854788, 20.59884705511452, 20.709297428932736, 20.81916184672188, 20.928449536456352, 21.03716948641143, 21.145330453790503, 21.25294097295713, 21.36000936329383, 21.46654373670806], [0.0, 2.1505813167606567, 3.0413812651491097, 3.7249161064378353, 4.301162633521313, 4.808846015417836, 5.267826876426369, 5.689903338370521, 6.082762530298219, 6.45174395028197, 6.800735254367721, 7.132671308843554, 7.449832212875671, 7.754031209635412, 8.04673846971554, 8.32916562447884, 8.602325267042627, 8.867073925484098, 9.12414379544733, 9.374166629626338, 9.617692030835672, 9.855201672213513, 10.087120500916006, 10.313825672368134, 10.535653752852738, 10.752906583803284, 10.965856099730656, 11.174748319313506, 11.379806676741042, 11.58123482190047, 11.779218989389744, 11.973930014828047, 12.165525060596439, 12.354149100605838, 12.539936203984452, 12.723010649999473, 12.90348790056394, 13.08147545195113, 13.257073583562853, 13.430376018563294, 13.601470508735442, 13.77043935392041, 13.937359864766355, 14.102304776170453, 14.265342617687107, 14.426538046253507, 14.58595214581482, 14.743642697786731, 14.899664425751341, 15.054069217324596, 15.20690632574555, 15.358222553407671, 15.508062419270823, 15.656468311851176, 15.80348062927911, 15.949137907736581, 16.09347693943108, 16.236532881129516, 16.3783393541592, 16.518928536681788, 16.65833124895768, 16.796577032240823, 16.9336942218761, 17.06971001511156, 17.204650534085253, 17.338540884399702, 17.471405209656147, 17.603266742283942, 17.734147850968196, 17.864070084949848, 17.99305421544658, 18.12112027442012, 18.24828759089466, 18.374574825012957, 18.499999999999996, 18.624580532189174, 18.748333259252675, 18.87127446676562, 18.99341991322258, 19.114784853615276, 19.235384061671343, 19.35523185084591, 19.474342094150447, 19.592728242896648, 19.710403344427025, 19.82738005889835, 19.943670675179128, 20.05928712591751, 20.174241001832012, 20.28854356527348, 20.402205763103165, 20.515238238928642, 20.627651344736268, 20.739455151956136, 20.850659461993043, 20.96127381625458, 21.071307505705477, 21.180769579975134, 21.289668856043768, 21.39801392653066, 21.50581316760657, 21.613074746550986], [0.0, 2.165063509461097, 3.061862178478973, 3.750000000000001, 4.330127018922194, 4.841229182759271, 5.303300858899107, 5.7282196186948005, 6.123724356957946, 6.49519052838329, 6.846531968814577, 7.180703308172537, 7.500000000000002, 7.806247497997998, 8.100925873009826, 8.38525491562421, 8.660254037844387, 8.926785535678562, 9.185586535436919, 9.437293044088438, 9.682458365518542, 9.921567416492216, 10.155048005794951, 10.383279828647593, 10.606601717798213, 10.825317547305485, 11.03970108290981, 11.250000000000002, 11.456439237389601, 11.65922381636102, 11.858541225631422, 12.054563451241194, 12.247448713915892, 12.437342963832752, 12.624381172952598, 12.808688457449499, 12.99038105676658, 13.169567191065925, 13.34634781503914, 13.520817282989961, 13.693063937629153, 13.863170633011771, 14.031215200402283, 14.197270864500684, 14.361406616345073, 14.523687548277811, 14.684175155588413, 14.842927608797398, 15.000000000000004, 15.155444566227676, 15.309310892394864, 15.461646096066229, 15.612494995995997, 15.761900266148116, 15.909902576697322, 16.056540723331413, 16.201851746019653, 16.345871038277526, 16.488632447841148, 16.630168369562586, 16.77050983124842, 16.909686573085853, 17.04772712123232, 17.1846588560844, 17.320508075688775, 17.455300054711177, 17.589059099337863, 17.721808598447282, 17.853571071357123, 17.984368212422698, 18.1142209327368, 18.243149399158032, 18.371173070873837, 18.498310733685926, 18.624580532189174, 18.75, 18.874586088176876, 18.99835519196333, 19.121323175972947, 19.243505397925816, 19.364916731037084, 19.48557158514987, 19.605483926697655, 19.724667297574374, 19.843134832984433, 19.96089927833914, 20.077973005261263, 20.194368026754393, 20.310096011589902, 20.425168297960237, 20.53959590644373, 20.65338955232288, 20.766559657295186, 20.87911636061258, 20.991069529683333, 21.102428770167663, 21.213203435596427, 21.323402636539978, 21.43303524935281, 21.542109924517607, 21.65063509461097, 21.758618981911514], [0.0, 2.179449471770337, 3.082207001484489, 3.774917217635376, 4.358898943540674, 4.8733971724044824, 5.3385391260156565, 5.766281297335398, 6.164414002968978, 6.538348415311011, 6.892024376045112, 7.228416147400482, 7.549834435270752, 7.8581168227508575, 8.154753215150047, 8.440971508067067, 8.717797887081348, 8.986100377805714, 9.246621004453466, 9.500000000000002, 9.746794344808965, 9.98749217771909, 10.222524150130438, 10.452272480183437, 10.677078252031313, 10.897247358851686, 11.113055385446437, 11.324751652906128, 11.532562594670797, 11.736694594305504, 11.937336386313323, 12.134661099511598, 12.328828005937956, 12.519984025548919, 12.708265027138836, 12.893796958227629, 13.076696830622023, 13.257073583562855, 13.435028842544407, 13.610657588816203, 13.784048752090223, 13.955285736952865, 14.124446891825539, 14.291605927956454, 14.456832294800964, 14.620191517213446, 14.781745499094484, 14.941552797483938, 15.099668870541503, 15.25614630239236, 15.411035007422443, 15.564382416273384, 15.716233645501715, 15.866631652622434, 16.01561737804697, 16.163229875244618, 16.309506430300093, 16.454482671904337, 16.598192672697834, 16.740669042783207, 16.881943016134134, 17.022044530549202, 17.161002301730516, 17.298843892006193, 17.435595774162696, 17.57128339080558, 17.705931209625774, 17.839562774911276, 17.97220075561143, 18.103866990231676, 18.23458252881047, 18.36436767220696, 18.493242008906932, 18.621224449536076, 18.748333259252675, 18.874586088176876, 19.000000000000004, 19.12459149890528, 19.24837655492016, 19.37137062781052, 19.49358868961793, 19.615045245933032, 19.735754355990554, 19.855729651664785, 19.97498435543818, 20.09353129741012, 20.211382931407737, 20.328551350256127, 20.445048300260876, 20.56088519495209, 20.676073128135336, 20.790622886291793, 20.904544960366874, 21.017849556983705, 21.130546609115445, 21.242645786248, 21.354156504062626, 21.465087933665686, 21.57544901039142, 21.685248442201445, 21.794494717703373, 21.903196113809514], [0.0, 2.1937410968480306, 3.1024184114977142, 3.799671038392667, 4.387482193696061, 4.9053542175871465, 5.373546315051169, 5.80409338312195, 6.2048368229954285, 6.5812232905440915, 6.937218462755804, 7.275816105427626, 7.599342076785334, 7.909646009778188, 8.208227579691002, 8.496322733983215, 8.774964387392123, 9.045026257562771, 9.307255234493143, 9.56229574945264, 9.810708435174293, 10.052984631441552, 10.28955781362834, 10.520812706250407, 10.747092630102339, 10.968705484240154, 11.185928660598549, 11.399013115178, 11.6081867662439, 11.813657350710661, 12.015614840697914, 12.214233500306108, 12.409673645990857, 12.602083161128563, 12.791598805466032, 12.978347352417412, 13.162446581088183, 13.34400614508252, 13.523128336298523, 13.699908758820259, 13.874436925511608, 14.046796787880147, 14.217067208112933, 14.3853223808158, 14.551632210855251, 14.716062652761437, 14.87867601636651, 15.039531242695034, 15.198684153570667, 15.356187677936214, 15.512092057488571, 15.6664450338933, 15.819292019556377, 15.97067625368444, 16.12063894515351, 16.269219403523945, 16.416455159382004, 16.562382075051886, 16.707034446603622, 16.850445097978866, 16.99264546796643, 17.133665690680438, 17.2735346701247, 17.41228014936585, 17.549928774784245, 17.686506155823995, 17.822036920621617, 17.956544767855537, 18.090052515125542, 18.222582144141924, 18.354154842977653, 18.48479104561369, 18.614510468986285, 18.743332147726562, 18.87127446676562, 18.99835519196333, 19.12459149890528, 19.25, 19.374596769997567, 19.498397370040443, 19.621416870348586, 19.743669871632274, 19.865170525318934, 19.985932552673145, 20.105969262883104, 20.22529357018088, 20.34391801005893, 20.461854754640402, 20.57911562725668, 20.695712116281477, 20.81165538826741, 20.92695630042745, 21.041625412500814, 21.155672998040032, 21.269109055153205, 21.381943316733395, 21.494185260204677, 21.60584411681247, 21.716928880484, 21.827448316282876, 21.937410968480307, 22.046825168264025], [0.0, 2.207940216581962, 3.1224989991991996, 3.8242646351945897, 4.415880433163924, 4.937104414532875, 5.408326913195985, 5.8416607227739625, 6.244997998398399, 6.623820649745886, 6.982120021884471, 7.322909257938407, 7.648529270389179, 7.960841664045331, 8.261355820929154, 8.551315688243536, 8.831760866327848, 9.103570728016562, 9.367496997597598, 9.624188277460082, 9.87420882906575, 10.118053172424034, 10.35615758860399, 10.588909292273687, 10.81665382639197, 11.039701082909811, 11.258330249197705, 11.472793905583769, 11.683321445547925, 11.890121950594118, 12.093386622447825, 12.293290853144248, 12.489995996796798, 12.683650893965826, 12.874393189583735, 13.062350477613133, 13.247641299491772, 13.430376018563296, 13.610657588816203, 13.78858223313768, 13.964240043768942, 14.137715515598694, 14.309088021254189, 14.47843223557026, 14.645818515876813, 14.811313243598624, 14.974979131871939, 15.136875503220606, 15.297058540778359, 15.455581516073734, 15.612494995995998, 15.767847031221482, 15.921683328090662, 16.074047405678513, 16.224980739587956, 16.374522893812816, 16.522711641858308, 16.669583078169655, 16.81517172080024, 16.95951060614663, 17.10263137648707, 17.244564360980537, 17.385338650713713, 17.524982168321884, 17.663521732655695, 17.8009831189179, 17.9373911146521, 18.07276957192782, 18.207141456033124, 18.34052889095623, 18.472953201911167, 18.60443495513906, 18.734993995195197, 18.864649479913485, 18.99341991322258, 19.121323175972947, 19.248376554920164, 19.374596769997567, 19.500000000000004, 19.624601906790367, 19.7484176581315, 19.87146194923766, 19.99374902313221, 20.115292689891444, 20.236106344848068, 20.356202985822286, 20.47559522944327, 20.594295326618976, 20.71231517720798, 20.8296663439432, 20.946360065653415, 21.06240726982555, 21.177818584547374, 21.292604349867588, 21.40677462860765, 21.520339216657344, 21.63330765278394, 21.745689227982638, 21.8574929943944, 21.968727773815218, 22.079402165819623, 22.18952455551944], [0.0, 2.2220486043288976, 3.142451272494134, 3.848701079585164, 4.444097208657795, 4.968651728587948, 5.442885264269311, 5.878988008152424, 6.284902544988268, 6.666145812986692, 7.026734661277598, 7.369701486491839, 7.697402159170328, 8.011710179481033, 8.314144574157945, 8.605957239029253, 8.88819441731559, 9.161741100904347, 9.427353817482402, 9.68568531390526, 9.937303457175895, 10.182705927208152, 10.422331792837916, 10.656570742973559, 10.885770528538622, 11.110243021644488, 11.330269193624662, 11.546103238755492, 11.757976016304848, 11.96609794377432, 12.170661444638084, 12.371843031658623, 12.569805089976535, 12.764697411219744, 12.956658519849938, 13.145816825134908, 13.332291625973385, 13.516193990913273, 13.697627531802727, 13.876689086377919, 14.053469322555197, 14.228053275132195, 14.40052082391467, 14.570947120897804, 14.739402972983678, 14.905955185763842, 15.070666873101535, 15.233597736582125, 15.394804318340656, 15.55434023030228, 15.71225636247067, 15.868601072558352, 16.023420358962067, 16.17675801883678, 16.328655792807933, 16.479153497677, 16.62828914831589, 16.776099069807618, 16.92261800077045, 17.067879188698285, 17.211914478058507, 17.3547543918086, 17.496428206922694, 17.63696402445727, 17.77638883463118, 17.91472857734663, 18.0520081985357, 18.188251702678848, 18.323482201808694, 18.45772196128222, 18.59099244257821, 18.723314343352783, 18.854707634964804, 18.985191597663693, 19.114784853615276, 19.243505397925816, 19.37137062781052, 19.498397370040443, 19.624601906790367, 19.75, 19.87460691435179, 19.998437438960075, 20.12150590785889, 20.24382621936871, 20.365411854416305, 20.48627589387588, 20.606431034994877, 20.725889606962596, 20.844663585675832, 20.962764607751527, 21.080203983832796, 21.19699271123147, 21.313141485947117, 21.428660714099703, 21.543560522810527, 21.657850770563545, 21.771541057077243, 21.884640732714807, 21.99715890745894, 22.109104459475514, 22.220486043288975, 22.331312097590686], [0.0, 2.23606797749979, 3.1622776601683795, 3.872983346207418, 4.47213595499958, 5.000000000000001, 5.477225575051662, 5.916079783099616, 6.324555320336759, 6.708203932499369, 7.0710678118654755, 7.416198487095665, 7.745966692414836, 8.062257748298551, 8.366600265340756, 8.660254037844387, 8.94427190999916, 9.219544457292887, 9.48683298050514, 9.746794344808965, 10.000000000000002, 10.2469507659596, 10.488088481701515, 10.72380529476361, 10.954451150103324, 11.18033988749895, 11.401754250991383, 11.618950038622254, 11.832159566199232, 12.041594578792298, 12.24744871391589, 12.449899597988733, 12.649110640673518, 12.845232578665133, 13.038404810405298, 13.228756555322954, 13.416407864998739, 13.601470508735446, 13.784048752090223, 13.964240043768944, 14.142135623730951, 14.317821063276353, 14.491376746189442, 14.66287829861518, 14.83239697419133, 14.999999999999998, 15.165750888103101, 15.329709716755893, 15.491933384829672, 15.652475842498529, 15.811388300841898, 15.968719422671315, 16.124515496597102, 16.27882059609971, 16.431676725154986, 16.583123951777, 16.73320053068151, 16.881943016134134, 17.029386365926403, 17.175564037317667, 17.320508075688775, 17.464249196572982, 17.60681686165901, 17.74823934929885, 17.88854381999832, 18.027756377319946, 18.165902124584953, 18.30300521772313, 18.439088914585774, 18.574175621006713, 18.708286933869708, 18.841443681416774, 18.97366596101028, 19.104973174542803, 19.235384061671343, 19.364916731037088, 19.49358868961793, 19.621416870348586, 19.7484176581315, 19.874606914351794, 20.000000000000004, 20.12461179749811, 20.24845673131659, 20.371548787463365, 20.4939015319192, 20.615528128088304, 20.73644135332772, 20.856653614614213, 20.97617696340303, 21.095023109728988, 21.213203435596427, 21.330729007701542, 21.44761058952722, 21.563858652847827, 21.679483388678804, 21.794494717703365, 21.90890230020665, 22.022715545545243, 22.135943621178658, 22.248595461286993, 22.3606797749979, 22.472205054244235], [0.0, 2.2500000000000004, 3.1819805153394642, 3.897114317029975, 4.500000000000001, 5.031152949374527, 5.511351921262151, 5.952940449895329, 6.3639610306789285, 6.75, 7.115124735378854, 7.462405778299651, 7.79422863405995, 8.112490369793978, 8.418729120241368, 8.714212528966689, 9.000000000000002, 9.276987657639737, 9.545941546018392, 9.807522622966516, 10.062305898749054, 10.310795313650642, 10.553435459602717, 10.79062092745362, 11.022703842524303, 11.250000000000002, 11.472793905583767, 11.691342951089924, 11.905880899790658, 12.116620816052636, 12.323757543866236, 12.52746981636755, 12.727922061357857, 12.925265954710568, 13.119641763401926, 13.311179511974137, 13.5, 13.686215693170997, 13.8699315066802, 14.051245496396398, 14.230249470757707, 14.407029534223911, 14.581666571417689, 14.7542366796795, 14.924811556599302, 15.093458848123579, 15.260242462031853, 15.425222850902351, 15.5884572681199, 15.75, 15.909902576697322, 16.068213964221414, 16.224980739587956, 16.38024725088117, 16.534055763786455, 16.686446595965243, 16.837458240482736, 16.987127479359188, 17.135489488193794, 17.282577932704367, 17.428425057933378, 17.573061770789973, 17.716517716526575, 17.858821349685986, 18.000000000000004, 18.14007993367174, 18.279086410430914, 18.417043736713012, 18.553975315279473, 18.68990369156567, 18.8248505970167, 18.95883698964681, 19.091883092036785, 19.224008426964446, 19.35523185084591, 19.48557158514987, 19.615045245933032, 19.743669871632274, 19.87146194923766, 19.998437438960078, 20.12461179749811, 20.25, 20.37461656080919, 20.498475553074673, 20.621590627301284, 20.743975028909, 20.865641614865332, 20.986602869449836, 21.106870919205434, 21.226457547127357, 21.34537420613656, 21.46363203188128, 21.58124185490724, 21.69821421223415, 21.814559358373483, 21.930287275820167, 22.045407685048605, 22.159930054041237, 22.27386360737625, 22.387217334898953, 22.500000000000004, 22.612220147522006], [0.0, 2.2638462845343543, 3.2015621187164247, 3.9210967853395315, 4.527692569068709, 5.062114182829148, 5.54526825320471, 5.98957427535547, 6.403124237432849, 6.791538853603063, 7.158910531638178, 7.508328708840605, 7.842193570679063, 8.162413858657256, 8.47053717304871, 8.767838958375092, 9.055385138137417, 9.334077351297235, 9.604686356149275, 9.867877177995277, 10.124228365658295, 10.374246960623216, 10.618380290797651, 10.857025375304234, 11.09053650640942, 11.319231422671773, 11.5433963806152, 11.763290356018596, 11.97914855071094, 12.191185340236611, 12.399596767637245, 12.604562665955532, 12.806248474865699, 13.004806803639957, 13.200378782444087, 13.393095235978876, 13.583077707206126, 13.770439353920414, 13.955285736952865, 14.137715515598696, 14.317821063276355, 14.495689014324226, 14.671400751121213, 14.845032839303524, 15.01665741768121, 15.18634254848744, 15.354152532784088, 15.520148195168758, 15.684387141358126, 15.84692399174048, 16.007810593582125, 16.167096214224745, 16.324827717314513, 16.481049723849512, 16.63580475961413, 16.78913339038082, 16.94107434609742, 17.091664635137214, 17.24093964956667, 17.388933262279203, 17.535677916750185, 17.681204710086924, 17.82554346997589, 17.96872282606641, 18.110770276274835, 18.251712248443983, 18.391574157749524, 18.530380460206427, 18.66815470259447, 18.804919569091492, 18.940696924875812, 19.075507856935292, 19.20937271229855, 19.342311133884703, 19.474342094150447, 19.605483926697655, 19.735754355990554, 19.865170525318934, 19.99374902313221, 20.12150590785889, 20.24845673131659, 20.37461656080919, 20.500000000000004, 20.624621208642843, 20.748493921246432, 20.871631464741803, 20.99404677521702, 21.11575241377868, 21.236760581595302, 21.357083134173543, 21.476731594914533, 21.595717167994216, 21.714050750608468, 21.8317429446208, 21.948804067647973, 22.065244163616228, 22.18107301281884, 22.296300141503302, 22.410934831014973, 22.524986126521814, 22.638462845343547, 22.751373584906915], [0.0, 2.277608394786075, 3.2210246816812815, 3.9449334595148757, 4.55521678957215, 5.092887196865841, 5.578978401105349, 6.025985396596975, 6.442049363362563, 6.832825184358224, 7.202430145443967, 7.553972464869065, 7.8898669190297515, 8.212033852828421, 8.522030274529655, 8.821139382188674, 9.1104335791443, 9.390819985496472, 9.663074045043844, 9.92786482583239, 10.185774393731682, 10.437312872574052, 10.682930309610748, 10.923026137476738, 11.157956802210698, 11.388041973930374, 11.613569649336936, 11.834800378544626, 12.05197079319395, 12.26529657203608, 12.474974949874648, 12.681186852972399, 12.884098726725126, 13.083864108129527, 13.280624985293425, 13.474512978211866, 13.665650368716449, 13.854151002497412, 14.040121082098972, 14.223659866574426, 14.404860290887934, 14.583809516035238, 14.760589419125512, 14.935277031243846, 15.10794492973813, 15.278661590597519, 15.447491705775406, 15.614496469627191, 15.779733838059503, 15.943258763502522, 16.105123408406406, 16.26537733961312, 16.424067705656842, 16.58123939879043, 16.73693520331605, 16.89119593160887, 17.04406054905931, 17.195566289017645, 17.345748758701653, 17.494642036920904, 17.642278764377348, 17.788690227220215, 17.933906434460955, 18.077956189790925, 18.2208671582886, 18.362665928453854, 18.503378069963333, 18.643028187502157, 18.781639970992945, 18.91923624251254, 19.055839000159505, 19.191469459111254, 19.32614809008769, 19.45989465541887, 19.592728242896648, 19.724667297574374, 19.85572965166478, 19.98593255267314, 20.11529268989144, 20.24382621936871, 20.371548787463365, 20.498475553074673, 20.624621208642843, 20.75, 20.874625745148105, 20.998511852033705, 21.121671335384423, 21.244116832666876, 21.365860619221497, 21.486914622625555, 21.6072904363319, 21.726999332627596, 21.846052274953475, 21.96445992962267, 22.082232676973586, 22.199380621990333, 22.315913604421397, 22.431841208425137, 22.54717277176897, 22.66191739460719, 22.776083947860748, 22.889681081220857], [0.0, 2.2912878474779204, 3.2403703492039306, 3.968626966596887, 4.582575694955841, 5.1234753829798, 5.612486080160912, 6.062177826491071, 6.480740698407861, 6.87386354243376, 7.24568837309472, 7.599342076785334, 7.937253933193774, 8.261355820929154, 8.573214099741124, 8.874119674649425, 9.165151389911681, 9.447221813845593, 9.72111104761179, 9.98749217771909, 10.2469507659596, 10.500000000000002, 10.747092630102339, 10.988630487917955, 11.224972160321824, 11.456439237389601, 11.683321445547925, 11.90588089979066, 12.124355652982143, 12.338962679253068, 12.549900398011133, 12.757350822173075, 12.961481396815723, 13.162446581088187, 13.360389215887388, 13.55544171172596, 13.74772708486752, 13.937359864766357, 14.124446891825537, 14.309088021254187, 14.49137674618944, 14.67140075112121, 14.8492424049175, 15.02497920131672, 15.198684153570667, 15.370426148939396, 15.540270267920054, 15.70827807240501, 15.874507866387548, 16.03901493234544, 16.201851746019653, 16.363068171953575, 16.522711641858308, 16.68082731761228, 16.83745824048274, 16.99264546796643, 17.146428199482248, 17.298843892006197, 17.44992836661515, 17.599715906798043, 17.74823934929885, 17.89553016817328, 18.041618552668716, 18.186533479473212, 18.330302779823363, 18.472953201911167, 18.614510468986285, 18.754999333511055, 18.894443627691185, 19.032866310674283, 19.170289512680814, 19.306734576307825, 19.44222209522358, 19.576771950451892, 19.71040334442702, 19.843134832984433, 19.97498435543818, 20.1059692628831, 20.236106344848064, 20.3654118544163, 20.4939015319192, 20.62159062730128, 20.748493921246432, 20.874625745148105, 21.000000000000004, 21.12463017427761, 21.24852936087578, 21.371710273162513, 21.494185260204677, 21.615966321217286, 21.73706511928416, 21.857492994394395, 21.97726097583591, 22.096379793984354, 22.214859891523066, 22.332711434127294, 22.44994432064365, 22.566568192793518, 22.682592444427513, 22.798026230355998, 22.912878474779202, 23.027157879338912], [0.0, 2.304886114323222, 3.2596012026013246, 3.9921798556678287, 4.609772228646444, 5.153882032022076, 5.645794895318108, 6.098155458825234, 6.519202405202649, 6.914658342969666, 7.2886898685566255, 7.644442425710329, 7.9843597113356575, 8.310385069297332, 8.624094155330171, 8.926785535678563, 9.219544457292889, 9.503288904374106, 9.778803607803974, 10.046765648705062, 10.307764064044152, 10.562315087138805, 10.810874155219826, 11.053845484717073, 11.291589790636216, 11.524430571616112, 11.752659273543161, 11.976539567003487, 12.196310917650468, 12.412191587306411, 12.624381172952596, 12.833062767710599, 13.038404810405298, 13.240562676865363, 13.439680055715613, 13.635890143294644, 13.829316685939332, 14.020074892809955, 14.208272238382824, 14.394009170484784, 14.577379737113251, 14.758472143145442, 14.93736924628966, 15.11414900019184, 15.288884851420658, 15.461646096066225, 15.632498200863482, 15.801503093060484, 15.968719422671315, 16.134202800262553, 16.298006013006624, 16.460179221381523, 16.620770138594665, 16.779824194549835, 16.937384685954324, 17.09349291397168, 17.248188310660343, 17.401508555294857, 17.553489681541958, 17.704166176355216, 17.853571071357127, 18.001736027394692, 18.148691412881536, 18.2944663764757, 18.439088914585778, 18.58258593414813, 18.724983311074006, 18.866305944725905, 19.00657780874821, 19.145821998545795, 19.284060775676892, 19.421315609401955, 19.55760721560795, 19.69295559330798, 19.82738005889835, 19.96089927833914, 20.093531297410124, 20.22529357018088, 20.356202985822286, 20.48627589387588, 20.615528128088304, 20.743975028909, 20.871631464741807, 20.998511852033708, 21.12463017427761, 21.25, 21.374634499799054, 21.498546462493692, 21.621748310439653, 21.744252114064533, 21.86606960566988, 21.987212192545012, 22.107690969434145, 22.227516730395234, 22.346699980086548, 22.465250944514285, 22.583179581272432, 22.700495589303774, 22.817208418209272, 22.933327277130985, 23.048861143232223, 23.163818769797007], [0.0, 2.318404623873926, 3.2787192621510006, 4.015594601052253, 4.636809247747852, 5.184110338331931, 5.678908345800274, 6.1339220731926485, 6.557438524302001, 6.955213871621778, 7.33143914930759, 7.68927824961485, 8.031189202104507, 8.359126748650246, 8.674675786448736, 8.979142498033985, 9.273618495495704, 9.55902714715258, 9.836157786453002, 10.10569146570387, 10.368220676663862, 10.624264680437891, 10.874281585465774, 11.118677978968543, 11.357816691600547, 11.592023119369632, 11.82159041753689, 12.04678380315676, 12.267844146385297, 12.484990989183775, 12.698425099200293, 12.908330643425586, 13.114877048604002, 13.318220601867205, 13.518505834595775, 13.715866724345204, 13.910427743243556, 14.102304776170456, 14.291605927956454, 14.478432235570262, 14.66287829861518, 14.845032839303522, 15.024979201316722, 15.202795795510772, 15.3785564992297, 15.552331014995788, 15.724185193516387, 15.894181325252335, 16.062378404209014, 16.22883236711748, 16.393596310755004, 16.55672068979845, 16.71825349730049, 16.878240429618252, 17.036725037400824, 17.1937488640494, 17.349351572897472, 17.5035710642143, 17.656443583009576, 17.808003818508126, 17.95828499606797, 18.10731896223182, 18.255136263528684, 18.401766219577944, 18.547236990991408, 18.691575642518746, 18.834808201837365, 18.976959714348347, 19.11805429430516, 19.258115172570758, 19.397164741270824, 19.535224595586303, 19.672315572906005, 19.808457789540306, 19.94367067517913, 20.077973005261263, 20.21138293140774, 20.34391801005893, 20.47559522944327, 20.606431034994877, 20.736441353327724, 20.865641614865336, 20.99404677521702, 21.121671335384423, 21.248529360875782, 21.374634499799054, 21.5, 21.62463872530591, 21.748563170931547, 21.871785478099405, 21.99431744792277, 22.116170554596472, 22.237355957937087, 22.357884515311373, 22.477766792989026, 22.59701307695333, 22.715633383201094, 22.83363746756088, 22.951034835057005, 23.06783474884455, 23.184046238739263, 23.299678109364518], [0.0, 2.331844763272204, 3.29772648956823, 4.0388736053508785, 4.663689526544408, 5.214163403653553, 5.7118298293979315, 6.169481339626533, 6.59545297913646, 6.995534289816612, 7.373940601876313, 7.733854149129011, 8.077747210701757, 8.40758586040012, 8.724964183307574, 9.031195934094221, 9.327379053088816, 9.614442261514705, 9.893179468704691, 10.164275675128062, 10.428326807307107, 10.685855136581257, 10.937321427113678, 11.18313462317252, 11.423659658795863, 11.65922381636102, 11.890121950594118, 12.116620816052636, 12.338962679253067, 12.557368354874361, 12.7720397744448, 12.983162172598785, 13.19090595827292, 13.395428324618816, 13.596874640887147, 13.795379661321396, 13.991068579633223, 14.184057952504286, 14.374456511465052, 14.5623658792107, 14.747881203752627, 14.931091721639111, 15.112081259707416, 15.290928683373028, 15.467708298258023, 15.642490210960656, 15.81534065393471, 15.986322278748169, 16.155494421403514, 16.322913342905427, 16.48863244784115, 16.652702483380892, 16.81517172080024, 16.97608612136496, 17.135489488193794, 17.293423605521262, 17.449928366615147, 17.605041891458256, 17.75880063517804, 17.91123948809797, 18.062391868188442, 18.21228980661136, 18.36096402697854, 18.508444018879597, 18.65475810617763, 18.799933510520724, 18.943996410472636, 19.086971996626392, 19.22888452302941, 19.369757355217438, 19.50961301512667, 19.648473223128562, 19.786358937409382, 19.92329039089678, 20.05928712591751, 20.194368026754393, 20.328551350256124, 20.461854754640402, 20.594295326618973, 20.725889606962593, 20.856653614614213, 20.986602869449836, 21.11575241377868, 21.244116832666876, 21.371710273162513, 21.498546462493692, 21.62463872530591, 21.750000000000004, 21.874642854227357, 21.998579499594968, 22.12182180562894, 22.24438131304173, 22.36626924634504, 22.487496525847426, 22.608073779072825, 22.72801135163391, 22.847319317591726, 22.96600748933084, 23.08408542697761, 23.20156244738703, 23.31844763272204, 23.434749838647736], [0.0, 2.345207879911715, 3.3166247903554003, 4.062019202317981, 4.69041575982343, 5.244044240850758, 5.7445626465380295, 6.2048368229954285, 6.6332495807108005, 7.035623639735145, 7.416198487095663, 7.778174593052024, 8.124038404635963, 8.455767262643883, 8.774964387392123, 9.082951062292475, 9.38083151964686, 9.669539802906858, 9.949874371066201, 10.222524150130438, 10.488088481701515, 10.74709263010234, 11.0, 11.247221879201993, 11.489125293076059, 11.726039399558575, 11.9582607431014, 12.186057606953943, 12.409673645990857, 12.62933094031509, 12.845232578665128, 13.057564857200596, 13.266499161421601, 13.472193585307481, 13.674794331177344, 13.87443692551161, 14.07124727947029, 14.265342617687107, 14.456832294800963, 14.645818515876812, 14.832396974191326, 15.016657417681207, 15.198684153570666, 15.378556499229699, 15.556349186104049, 15.732132722552272, 15.905973720586866, 16.077935190813527, 16.248076809271925, 16.416455159382004, 16.583123951777, 16.74813422444423, 16.911534525287767, 17.073371078963874, 17.23368793961409, 17.392527130926087, 17.549928774784245, 17.705931209625774, 17.860571099491754, 18.01388353465182, 18.16590212458495, 18.3166590840142, 18.466185312619388, 18.614510468986285, 18.76166303929372, 18.907670401189037, 19.052558883257653, 19.19635382045247, 19.339079605813716, 19.480759738778158, 19.621416870348583, 19.761072845369505, 19.899748742132402, 20.03746490951388, 20.174241001832012, 20.310096011589902, 20.445048300260876, 20.57911562725668, 20.71231517720798, 20.844663585675832, 20.97617696340303, 21.106870919205434, 21.236760581595306, 21.365860619221497, 21.49418526020468, 21.621748310439653, 21.748563170931547, 21.87464285422736, 22.0, 22.124646889837585, 22.24859546128699, 22.371857321197094, 22.494443758403985, 22.616365755797283, 22.73763400180415, 22.85825890132492, 22.978250586152118, 23.097618924902196, 23.2163735324878, 23.334523779156072, 23.45207879911715, 23.569047498785352], [0.0, 2.358495283014151, 3.3354160160315836, 4.085033659592049, 4.716990566028302, 5.273755777432247, 5.777110004145672, 6.239991987174342, 6.670832032063167, 7.075485849042453, 7.458216945088148, 7.822243923581008, 8.170067319184097, 8.503675675847475, 8.824681297361396, 9.134412953222554, 9.433981132056603, 9.724325169388361, 10.00624804809475, 10.280442597476044, 10.547511554864494, 10.807983160608645, 11.062323444918793, 11.310946025863618, 11.554220008291344, 11.792476415070755, 12.026013470805696, 12.255100978776145, 12.479983974348684, 12.700885795880538, 12.91801068276381, 13.131545986668897, 13.341664064126334, 13.548523904839229, 13.752272539475065, 13.953046262375826, 14.150971698084906, 14.346166735403573, 14.538741348548712, 14.728798321655438, 14.916433890176297, 15.101738310538956, 15.284796367632774, 15.465687828221542, 15.644487847162017, 15.821267332296737, 15.99609327304639, 16.169029037020128, 16.340134638368195, 16.509466981099056, 16.677080080157918, 16.843025262701474, 17.00735135169495, 17.170104833692776, 17.331330012437014, 17.491069149711805, 17.649362594722792, 17.80624890312387, 17.961764946686056, 18.115946014492312, 18.26882590644511, 18.420437019788643, 18.570810429273138, 18.719975961523026, 18.867962264113206, 19.014796869806418, 19.16050625635972, 19.30511590226798, 19.448650338776723, 19.591133198465066, 19.732587260671114, 19.8730344940072, 20.0124960961895, 20.150992531386635, 20.28854356527348, 20.42516829796024, 20.56088519495209, 20.695712116281477, 20.8296663439432, 20.962764607751527, 21.095023109728988, 21.226457547127357, 21.357083134173546, 21.486914622625555, 21.61596632121729, 21.744252114064533, 21.871785478099405, 21.998579499594968, 22.124646889837585, 22.249999999999996, 22.374650835264447, 22.498611068241523, 22.621892051727237, 22.744504830837712, 22.86646015455825, 22.98776848674094, 23.108440016582687, 23.228484668613234, 23.347912112221085, 23.466731770743024, 23.58495283014151, 23.70258424729253], [0.0, 2.3717082451262845, 3.3541019662496847, 4.107919181288747, 4.743416490252569, 5.303300858899107, 5.809475019311126, 6.274950199005566, 6.708203932499369, 7.115124735378854, 7.5, 7.866066361276138, 8.215838362577493, 8.551315688243536, 8.874119674649425, 9.185586535436919, 9.486832980505138, 9.778803607803972, 10.062305898749054, 10.338036564067668, 10.606601717798213, 10.86853255964208, 11.124297730643494, 11.374313166077325, 11.618950038622252, 11.858541225631424, 12.093386622447827, 12.32375754386624, 12.549900398011133, 12.772039774444803, 12.990381056766578, 13.205112646244256, 13.416407864998739, 13.624426593438715, 13.82931668593933, 14.031215200402281, 14.230249470757707, 14.42653804625351, 14.620191517213447, 14.811313243598626, 15.0, 15.18634254848744, 15.3704261489394, 15.55233101499579, 15.732132722552276, 15.909902576697316, 16.08570794214541, 16.2596125415091, 16.431676725154986, 16.60195771588399, 16.770509831248425, 16.937384685954324, 17.10263137648707, 17.266296649832007, 17.428425057933378, 17.589059099337863, 17.74823934929885, 17.906004579469986, 18.062391868188442, 18.21743670223668, 18.371173070873837, 18.523633552842703, 18.6748493969831, 18.8248505970167, 18.973665961010276, 19.121323175972943, 19.267848867997692, 19.41326865831718, 19.557607215607945, 19.70088830484555, 19.84313483298443, 19.98436889171134, 20.12461179749811, 20.263884129159443, 20.40220576310316, 20.53959590644373, 20.676073128135336, 20.81165538826741, 20.946360065653415, 21.080203983832796, 21.213203435596427, 21.34537420613656, 21.476731594914533, 21.6072904363319, 21.73706511928416, 21.86606960566988, 21.994317447922768, 22.12182180562894, 22.24859546128699, 22.374650835264447, 22.5, 22.624654693497533, 22.74862633215465, 22.87192602296536, 22.99456457513384, 23.11655251113366, 23.237900077244504, 23.358617253596158, 23.47871376374779, 23.598199083828412, 23.717082451262847, 23.835372873106056], [0.0, 2.3848480035423645, 3.3726843908080104, 4.130677910464577, 4.769696007084729, 5.332682251925386, 5.841660722773962, 6.309714732061981, 6.745368781616021, 7.1545440106270926, 7.541551564499178, 7.909646009778188, 8.261355820929154, 8.59869176095992, 8.923284148787374, 9.236476600955584, 9.539392014169458, 9.832980219648567, 10.118053172424032, 10.395311443145896, 10.665364503850771, 10.928746497197197, 11.185928660598547, 11.437329233697875, 11.683321445547923, 11.924240017711822, 12.160386507015312, 12.392033731393733, 12.619429464123963, 12.842799539041323, 13.06235047761313, 13.278271724889501, 13.490737563232042, 13.69990875882026, 13.90593398517338, 14.108951059522463, 14.309088021254185, 14.50646407640401, 14.701190427989157, 14.893371008606483, 15.083103128998356, 15.270478054075452, 15.455581516073734, 15.638494173033413, 15.819292019556377, 15.998046755776155, 16.174826119621812, 16.349694186742454, 16.522711641858308, 16.69393602479655, 16.863421954040053, 17.0312213302511, 17.19738352191984, 17.361955535019668, 17.524982168321888, 17.686506155823995, 17.84656829757475, 18.00520758003084, 18.16246128695117, 18.318365101722367, 18.472953201911167, 18.62625834675338, 18.778311958213923, 18.929144196185945, 19.078784028338916, 19.227259295073754, 19.374596769997563, 19.520822216289968, 19.665960439297134, 19.810035335657535, 19.953069939234915, 20.095086464108586, 20.236106344848064, 20.376150274278995, 20.515238238928642, 20.653389552322885, 20.790622886291793, 20.926956300427445, 21.06240726982555, 21.19699271123147, 21.330729007701542, 21.46363203188128, 21.595717167994216, 21.726999332627596, 21.857492994394395, 21.987212192545012, 22.116170554596472, 22.24438131304173, 22.371857321197094, 22.498611068241523, 22.624654693497533, 22.75, 22.87465846739575, 22.99864126421385, 23.121959259543733, 23.244623034155662, 23.366642891095847, 23.48802886578608, 23.608790735656076, 23.728938029334564, 23.848480035423645, 23.967425810879234], [0.0, 2.39791576165636, 3.3911649915626345, 4.153311931459038, 4.79583152331272, 5.361902647381805, 5.873670062235366, 6.344288770224761, 6.782329983125269, 7.19374728496908, 7.582875444051551, 7.952986860293435, 8.306623862918077, 8.645808232895293, 8.972179222463181, 9.287087810503355, 9.59166304662544, 9.886859966642595, 10.173494974687904, 10.452272480183439, 10.72380529476361, 10.988630487917957, 11.247221879201993, 11.500000000000002, 11.747340124470732, 11.9895788082818, 12.227019260637487, 12.459935794377115, 12.688577540449522, 12.91317157014496, 13.133925536563696, 13.35102992281869, 13.564659966250538, 13.774977313955914, 13.982131454109563, 14.18626095911111, 14.38749456993816, 14.585952145814824, 14.781745499094486, 14.97497913187194, 15.165750888103101, 15.354152532784088, 15.540270267920056, 15.724185193516389, 15.90597372058687, 16.08570794214541, 16.263455967290593, 16.4392822227736, 16.613247725836153, 16.78541033159452, 16.95582495781317, 17.12454378954371, 17.291616465790586, 17.457090250096094, 17.621010186706098, 17.78341924377874, 17.944358444926362, 18.103866990231676, 18.261982367749678, 18.418740456393863, 18.57417562100671, 18.728320800328042, 18.88120758849921, 19.03286631067428, 19.18332609325088, 19.332614929181208, 19.480759738778158, 19.627786426390525, 19.77371993328519, 19.91858428704209, 20.06240264773888, 20.205197351176754, 20.346989949375807, 20.48780124854788, 20.627651344736268, 20.76655965729519, 20.904544960366877, 21.041625412500814, 21.177818584547374, 21.313141485947117, 21.44761058952722, 21.58124185490724, 21.714050750608468, 21.84605227495348, 21.977260975835915, 22.107690969434145, 22.237355957937087, 22.366269246345045, 22.494443758403985, 22.62189205172724, 22.748626332154654, 22.87465846739575, 23.000000000000004, 23.124662159694356, 23.248655875125344, 23.371991785040485, 23.494680248941464, 23.61673135723909, 23.73815494093844, 23.858960580880304, 23.9791576165636, 24.098755154571784], [0.0, 2.410912690248239, 3.4095454242464642, 4.175823272122518, 4.821825380496478, 5.390964663211957, 5.905505905508859, 6.378675411086538, 6.8190908484929285, 7.232738070744717, 7.623975340988453, 7.99609279585974, 8.351646544245035, 8.692669325356857, 9.020809276334358, 9.33742469849155, 9.643650760992957, 9.940447676035522, 10.228636272739394, 10.508924778491853, 10.781929326423914, 11.048189896992179, 11.308182877898643, 11.562331079847178, 11.811011811017718, 12.054563451241195, 12.29329085314425, 12.527469816367553, 12.757350822173075, 12.983162172598787, 13.205112646244256, 13.4233937586588, 13.638181696985857, 13.849638984464544, 14.057915919509549, 14.263151825595914, 14.465476141489434, 14.665009376062468, 14.861863947701853, 15.056144924913552, 15.247950681976906, 15.437373481262933, 15.624499991999746, 15.809411753762378, 15.99218559171948, 16.172893989635867, 16.351605425767833, 16.5283846760656, 16.70329308849007, 16.87638883173767, 17.04772712123232, 17.217360424873497, 17.385338650713713, 17.551709318468106, 17.716517716526578, 17.879807045938726, 18.041618552668716, 18.2019916492674, 18.360964026978543, 18.518571759182727, 18.6748493969831, 18.829830057650547, 18.98354550656963, 19.13602623325961, 19.287301521985913, 19.437399517425167, 19.586347285800894, 19.73417087186589, 19.880895352071043, 20.026544884228034, 20.17114275394431, 20.314711418083203, 20.457272545478787, 20.59884705511452, 20.739455151956136, 20.879116360612585, 21.017849556983705, 21.155672998040032, 21.292604349867588, 21.428660714099706, 21.563858652847827, 21.698214212234152, 21.831742944620803, 21.964459929622674, 22.096379793984358, 22.227516730395234, 22.357884515311373, 22.487496525847426, 22.616365755797286, 22.744504830837712, 22.87192602296536, 22.998641264213852, 23.124662159694356, 23.250000000000004, 23.374665773011603, 23.498670175139697, 23.622023622035435, 23.744736258800604, 23.86681796972525, 23.988278387579218, 24.10912690248239, 24.22937267037676], [0.0, 2.4238399287081647, 3.4278273002005224, 4.198213905936667, 4.847679857416329, 5.4198708471697, 5.937171043518959, 6.412877669190331, 6.855654600401045, 7.271519786124494, 7.664854858377947, 8.038967595406765, 8.396427811873334, 8.739279146474269, 9.069178573608529, 9.387491677759295, 9.695359714832659, 9.993748045653343, 10.283481900601567, 10.565273304557723, 10.8397416943394, 11.107429945761533, 11.368817000902073, 11.62432793756267, 11.874342087037919, 12.119199643540824, 12.359207094308278, 12.594641717810003, 12.825755338380661, 13.052777482206615, 13.275918047351754, 13.49536957626578, 13.71130920080209, 13.923900315644323, 14.13329402510257, 14.339630399699988, 14.543039572248988, 14.743642697786735, 14.941552797483938, 15.136875503220606, 15.329709716755893, 15.520148195168757, 15.708278072405012, 15.894181325252333, 16.07793519081353, 16.2596125415091, 16.439282222773596, 16.61700935788387, 16.792855623746668, 16.966879500957152, 17.13913650100261, 17.309679373113763, 17.478558292948538, 17.6458210350213, 17.81151313055688, 17.975678012247553, 18.138357147217057, 18.2995901593451, 18.459414941974735, 18.61786776191087, 18.77498335551859, 18.93079501764255, 19.085334683992315, 19.23863300757099, 19.390719429665317, 19.541622245862804, 19.691368667515217, 19.8399848790265, 19.987496091306685, 20.133926591700888, 20.27929979067325, 20.423638265500106, 20.566963801203133, 20.709297428932736, 20.850659461993043, 20.991069529683333, 21.130546609115445, 21.269109055153205, 21.40677462860765, 21.543560522810523, 21.6794833886788, 21.814559358373483, 21.948804067647973, 22.082232676973586, 22.214859891523066, 22.346699980086548, 22.477766792989023, 22.608073779072825, 22.737634001804146, 22.866460154558247, 22.99456457513384, 23.121959259543733, 23.24865587512534, 23.374665773011603, 23.500000000000004, 23.624669309854898, 23.748684174075837, 23.872054792162324, 23.994791101403656, 24.116902786220294, 24.23839928708165, 24.359289809023583], [0.0, 2.436698586202241, 3.4460121880225554, 4.220485754033533, 4.873397172404482, 5.448623679425841, 5.9686681931566605, 6.446898479113813, 6.892024376045111, 7.310095758606723, 7.70551750371122, 8.081614937622307, 8.440971508067067, 8.78564169540279, 9.117291264405234, 9.437293044088436, 9.746794344808963, 10.046765648705058, 10.338036564067666, 10.621322893124, 10.897247358851683, 11.166355717063647, 11.42912945066246, 11.685995892520243, 11.937336386313321, 12.183492931011205, 12.424773639789178, 12.661457262100601, 12.893796958227625, 13.12202347201071, 13.346347815039136, 13.566963551215135, 13.784048752090222, 13.997767679169419, 14.20827223838282, 14.415703243338495, 14.620191517213446, 14.821858857781638, 15.020818885799802, 15.217177793533203, 15.41103500742244, 15.602483776629924, 15.791611697353758, 15.978501181274792, 16.163229875244614, 16.345871038277522, 16.52649388103841, 16.705163872288114, 16.881943016134134, 17.056890103415686, 17.230060940112775, 17.401508555294853, 17.57128339080558, 17.73943347460679, 17.906004579469982, 18.0710403685012, 18.234582528810467, 18.39667089448523, 18.557343559895635, 18.71663698424479, 18.874586088176873, 19.031224343168255, 19.18658385434989, 19.340695437341438, 19.493588689617926, 19.64529205687714, 19.795832894829154, 19.94523752678819, 20.093531297410117, 20.24073862288627, 20.386883037875112, 20.531987239427167, 20.676073128135332, 20.81916184672188, 20.96127381625458, 21.102428770167666, 21.242645786248, 21.381943316733395, 21.520339216657344, 21.657850770563545, 21.794494717703365, 21.930287275820167, 22.065244163616228, 22.199380621990333, 22.332711434127294, 22.465250944514285, 22.59701307695333, 22.728011351633914, 22.85825890132492, 22.98776848674094, 23.11655251113366, 23.244623034155662, 23.371991785040485, 23.498670175139697, 23.6246693098549, 23.749999999999996, 23.874672772626642, 23.998697881343478, 24.122085316157886, 24.24484481286692, 24.36698586202241, 24.488517717493643], [0.0, 2.4494897427831783, 3.464101615137755, 4.242640687119286, 4.898979485566357, 5.477225575051661, 6.0, 6.48074069840786, 6.92820323027551, 7.3484692283495345, 7.745966692414834, 8.124038404635963, 8.485281374238571, 8.831760866327848, 9.16515138991168, 9.486832980505138, 9.797958971132713, 10.099504938362077, 10.392304845413264, 10.677078252031313, 10.954451150103322, 11.224972160321826, 11.489125293076057, 11.747340124470732, 12.0, 12.247448713915892, 12.489995996796798, 12.727922061357859, 12.96148139681572, 13.190905958272921, 13.416407864998737, 13.638181696985857, 13.85640646055102, 14.071247279470292, 14.2828568570857, 14.49137674618944, 14.696938456699069, 14.899664425751341, 15.099668870541501, 15.297058540778357, 15.491933384829668, 15.684387141358123, 15.874507866387546, 16.06237840420901, 16.248076809271925, 16.431676725154983, 16.61324772583615, 16.792855623746668, 16.970562748477143, 17.146428199482248, 17.320508075688775, 17.492855684535904, 17.663521732655695, 17.83255450012701, 18.000000000000004, 18.165902124584953, 18.33030277982336, 18.493242008906932, 18.65475810617763, 18.81488772222678, 18.973665961010276, 19.131126469708992, 19.28730152198591, 19.44222209522358, 19.595917942265427, 19.7484176581315, 19.8997487421324, 20.049937655763422, 20.199009876724155, 20.346989949375807, 20.493901531919196, 20.639767440550294, 20.784609690826528, 20.928449536456352, 21.071307505705477, 21.213203435596427, 21.354156504062626, 21.494185260204677, 21.633307652783937, 21.771541057077243, 21.908902300206645, 22.045407685048605, 22.18107301281884, 22.315913604421397, 22.449944320643652, 22.58317958127243, 22.715633383201094, 22.847319317591726, 22.978250586152114, 23.108440016582684, 23.237900077244504, 23.366642891095847, 23.494680248941464, 23.622023622035435, 23.748684174075837, 23.874672772626642, 24.0, 24.12467616362964, 24.248711305964285, 24.372115213907882, 24.494897427831784, 24.617067250182345], [0.0, 2.4622144504490264, 3.4820970692960302, 4.264680527307997, 4.924428900898053, 5.505678886386311, 6.03116904090741, 6.514407110397692, 6.9641941385920605, 7.38664335134708, 7.786205751198719, 8.16624148553054, 8.529361054615993, 8.877640452282353, 9.21276288634414, 9.536115561380326, 9.848857801796106, 10.151970252123476, 10.446291207888091, 10.732543966832843, 11.011357772772621, 11.283284096396759, 11.548809462451098, 11.808365678619545, 12.06233808181482, 12.311072252245133, 12.554879529489723, 12.79404158192399, 13.028814220795384, 13.259430606176121, 13.486103959261177, 13.709029870855197, 13.928388277184121, 14.14434515981564, 14.35705401536123, 14.566657131957218, 14.77328670269416, 14.977065800750163, 15.178109236660543, 15.376524314681784, 15.572411502397438, 15.765865025427562, 15.956973397232952, 16.145819892467525, 16.33248297106108, 16.51703665915893, 16.699550892164737, 16.880091824394796, 17.058722109231987, 17.235501153143183, 17.41048534648015, 17.58372827360569, 17.755280904564707, 17.925191770243355, 18.093507122722233, 18.26027108232515, 18.42552577268828, 18.589311445021306, 18.75166659259918, 18.91262805640718, 19.072231122760652, 19.23050961363219, 19.3874959703413, 19.543221331193074, 19.69771560359221, 19.851007531105317, 20.003124755897517, 20.15409387692734, 20.303940504246953, 20.4526893097216, 20.600364074452667, 20.74698773316262, 20.892582415776182, 21.03716948641143, 21.180769579975134, 21.323402636539978, 21.465087933665686, 21.60584411681247, 21.745689227982638, 21.884640732714807, 22.022715545545243, 22.159930054041237, 22.296300141503302, 22.431841208425137, 22.566568192793518, 22.700495589303774, 22.83363746756088, 22.96600748933084, 23.097618924902196, 23.228484668613234, 23.358617253596158, 23.48802886578608, 23.61673135723909, 23.744736258800604, 23.872054792162324, 23.998697881343478, 24.12467616362964, 24.250000000000004, 24.374679485072214, 24.498724456591617, 24.622144504490265, 24.74494897953924], [0.0, 2.4748737341529163, 3.5, 4.286607049870562, 4.949747468305833, 5.533985905294664, 6.06217782649107, 6.547900426854397, 7.0, 7.4246212024587495, 7.826237921249264, 8.208227579691004, 8.573214099741124, 8.923284148787374, 9.260129588726068, 9.585144756340407, 9.899494936611665, 10.204165815979275, 10.5, 10.78772450519571, 11.067971810589327, 11.341296222213757, 11.6081867662439, 11.86907747046922, 12.12435565298214, 12.374368670764582, 12.619429464123964, 12.859821149611687, 13.095800853708795, 13.32760293526184, 13.555441711725958, 13.77951377952067, 14.0, 14.217067208112933, 14.430869689661812, 14.641550464346324, 14.849242404917499, 15.054069217324598, 15.25614630239236, 15.455581516073734, 15.652475842498529, 15.846923991740478, 16.03901493234544, 16.22883236711748, 16.416455159382007, 16.60195771588399, 16.785410331594516, 16.966879500957152, 17.146428199482248, 17.324116139070412, 17.5, 17.67413364213364, 17.84656829757475, 18.01735274672725, 18.186533479473212, 18.354154842977653, 18.520259177452136, 18.684886941054796, 18.848076824970764, 19.009865859600378, 19.170289512680814, 19.329381780077703, 19.487175269905077, 19.643701280563192, 19.79898987322333, 19.953069939234915, 20.1059692628831, 20.257714579882894, 20.40833163195855, 20.55784521782378, 20.706279240848655, 20.853656753672723, 21.0, 21.1453304537905, 21.289668856043768, 21.43303524935281, 21.57544901039142, 21.716928880483998, 21.857492994394395, 21.997158907458935, 22.135943621178654, 22.273863607376246, 22.410934831014973, 22.54717277176897, 22.682592444427513, 22.81720841820927, 22.951034835057, 23.08408542697761, 23.2163735324878, 23.34791211222108, 23.47871376374779, 23.608790735656072, 23.73815494093844, 23.866817969725247, 23.994791101403656, 24.122085316157886, 24.24871130596428, 24.37467948507221, 24.5, 24.624682739073005, 24.748737341529164, 24.87217320621582], [0.0, 2.4874685927665503, 3.5178118198675725, 4.308421984903522, 4.974937185533101, 5.562148865321748, 6.093028803476971, 6.581223290544092, 7.035623639735145, 7.46240577829965, 7.866066361276137, 8.250000000000002, 8.616843969807045, 8.96869555732605, 9.307255234493143, 9.633924433998848, 9.949874371066201, 10.256095748383007, 10.553435459602717, 10.842624221100722, 11.124297730643496, 11.399013115177999, 11.667261889578036, 11.929480290440152, 12.186057606953941, 12.437342963832752, 12.683650893965826, 12.925265954710568, 13.162446581088185, 13.395428324618816, 13.624426593438711, 13.849638984464542, 14.07124727947029, 14.289419162443242, 14.504309704360288, 14.71606265276144, 14.9248115565993, 15.130680751374014, 15.333786225195658, 15.534236382905988, 15.732132722552274, 15.927570436196477, 16.120638945153512, 16.31142237819866, 16.500000000000004, 16.68644659596524, 16.870832818802988, 17.05322550135311, 17.23368793961409, 17.41228014936585, 17.589059099337863, 17.76407892349052, 17.9373911146521, 18.109044701474456, 18.279086410430914, 18.44756081437327, 18.614510468986285, 18.779976038323376, 18.943996410472636, 19.106608804285496, 19.267848867997696, 19.427750770482927, 19.586347285800894, 19.743669871632274, 19.899748742132402, 20.05461293568141, 20.208290377961223, 20.360807940747343, 20.512191496766015, 20.66246597093387, 20.811655388267415, 20.95978291872318, 21.106870919205434, 21.252940972957134, 21.39801392653066, 21.54210992451761, 21.685248442201445, 21.827448316282876, 21.968727773815218, 22.109104459475514, 22.248595461286993, 22.387217334898953, 22.524986126521814, 22.661917394607194, 22.798026230355998, 22.933327277130985, 23.06783474884455, 23.201562447387033, 23.334523779156072, 23.466731770743024, 23.598199083828412, 23.728938029334564, 23.858960580880304, 23.988278387579214, 24.116902786220294, 24.24484481286692, 24.372115213907882, 24.498724456591617, 24.62468273907301, 24.750000000000004, 24.874685927665503, 24.99874996874844], [0.0, 2.5000000000000004, 3.535533905932738, 4.3301270189221945, 5.000000000000001, 5.5901699437494745, 6.123724356957946, 6.614378277661477, 7.071067811865476, 7.500000000000001, 7.905694150420949, 8.291561975888502, 8.660254037844389, 9.013878188659975, 9.354143466934854, 9.682458365518542, 10.000000000000002, 10.307764064044152, 10.606601717798213, 10.897247358851686, 11.180339887498949, 11.456439237389601, 11.726039399558575, 11.9895788082818, 12.247448713915892, 12.500000000000002, 12.747548783981966, 12.990381056766582, 13.228756555322954, 13.462912017836262, 13.693063937629152, 13.919410907075056, 14.142135623730953, 14.361406616345075, 14.577379737113251, 14.790199457749042, 15.000000000000002, 15.206906325745551, 15.411035007422443, 15.612494995995998, 15.811388300841898, 16.00781059358212, 16.201851746019653, 16.393596310755, 16.583123951777004, 16.77050983124842, 16.95582495781317, 17.13913650100261, 17.320508075688778, 17.5, 17.67766952966369, 17.853571071357127, 18.02775637731995, 18.2002747232013, 18.371173070873837, 18.54049621773916, 18.708286933869708, 18.874586088176876, 19.03943276465977, 19.20286436967152, 19.364916731037084, 19.525624189766635, 19.68501968502953, 19.84313483298443, 20.000000000000004, 20.155644370746376, 20.310096011589902, 20.463381929681127, 20.615528128088304, 20.76655965729519, 20.91650066335189, 21.0653744329409, 21.213203435596427, 21.36000936329383, 21.505813167606565, 21.65063509461097, 21.794494717703373, 21.937410968480307, 22.07940216581962, 22.220486043288975, 22.360679774997898, 22.5, 22.638462845343547, 22.776083947860748, 22.912878474779202, 23.04886114323222, 23.18404623873926, 23.31844763272204, 23.45207879911715, 23.58495283014151, 23.717082451262847, 23.848480035423645, 23.9791576165636, 24.10912690248239, 24.23839928708165, 24.36698586202241, 24.494897427831784, 24.622144504490265, 24.748737341529168, 24.874685927665503, 25.000000000000004, 25.12468905280223], [0.0, 2.512468905280223, 3.5531676008879742, 4.351723796382304, 5.024937810560446, 5.618051263561059, 6.154266812545586, 6.647367900154166, 7.1063352017759485, 7.537406715840668, 7.945124291035352, 8.33291665624948, 8.703447592764608, 9.05883546599672, 9.400797838481584, 9.730750228014283, 10.049875621120892, 10.359174677550332, 10.659502802663923, 10.951598056904757, 11.236102527122117, 11.513578939669456, 11.784523749392676, 12.049377577285892, 12.308533625091172, 12.562344526401116, 12.81112797531896, 13.055171389146912, 13.294735800308333, 13.53005912773481, 13.761358944522884, 13.988834833537783, 14.212670403551897, 14.433035023861063, 14.650085323983612, 14.86396649619475, 15.074813431681337, 15.282751715577929, 15.487898501733541, 15.690363284513207, 15.890248582070704, 16.087650543196172, 16.282659487933785, 16.475360390595405, 16.66583331249896, 16.854153790683174, 17.040393187951974, 17.224619008848936, 17.406895185529216, 17.587282336961557, 17.76583800443987, 17.94261686599812, 18.11767093199344, 18.29104972384035, 18.462800437636762, 18.632968094214085, 18.801595676963167, 18.96872425863163, 19.134393118152456, 19.29863984844528, 19.461500456028567, 19.623009453190406, 19.78319994338631, 19.942103700462496, 20.099751242241783, 20.25617189895465, 20.4113938769502, 20.56544431807881, 20.718349355100663, 20.87013416344035, 21.02082300957791, 21.170439296339605, 21.319005605327845, 21.46654373670806, 21.613074746550986, 21.758618981911518, 21.903196113809514, 22.046825168264025, 22.18952455551944, 22.331312097590686, 22.472205054244235, 22.612220147522006, 22.75137358490692, 22.88968108122086, 23.027157879338912, 23.163818769797007, 23.299678109364518, 23.43474983864774, 23.569047498785352, 23.70258424729253, 23.835372873106056, 23.967425810879234, 24.098755154571784, 24.22937267037676, 24.359289809023583, 24.488517717493643, 24.617067250182345, 24.74494897953924, 24.87217320621582, 24.99874996874844, 25.124689052802232, 25.250000000000004]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"A = 3.0\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.3, 0.4242640687119285, 0.5196152422706632, 0.6, 0.670820393249937, 0.7348469228349535, 0.7937253933193772, 0.848528137423857, 0.8999999999999999, 0.9486832980505138, 0.9949874371066201, 1.0392304845413265, 1.0816653826391969, 1.1224972160321824, 1.1618950038622249, 1.2, 1.2369316876852983, 1.2727922061357855, 1.3076696830622023, 1.341640786499874, 1.374772708486752, 1.407124727947029, 1.4387494569938162, 1.469693845669907, 1.5, 1.5297058540778357, 1.5588457268119897, 1.5874507866387544, 1.6155494421403513, 1.6431676725154984, 1.6703293088490065, 1.697056274847714, 1.7233687939614089, 1.7492855684535904, 1.7748239349298849, 1.7999999999999998, 1.824828759089466, 1.849324200890693, 1.8734993995195195, 1.8973665961010275, 1.920937271229855, 1.9442222095223582, 1.9672315572905998, 1.9899748742132402, 2.0124611797498106, 2.0346989949375804, 2.056696380120313, 2.078460969082653, 2.1, 2.121320343559643, 2.1424285285628555, 2.1633307652783937, 2.1840329667841556, 2.2045407685048604, 2.224859546128699, 2.244994432064365, 2.264950330581225, 2.2847319317591728, 2.3043437243605824, 2.3237900077244498, 2.3430749027719964, 2.362202362203543, 2.3811761799581315, 2.4, 2.4186773244895647, 2.437211521390788, 2.455605831561735, 2.4738633753705965, 2.4919871588754225, 2.5099800796022267, 2.5278449319529077, 2.545584412271571, 2.563201123595259, 2.5806975801127883, 2.598076211353316, 2.6153393661244047, 2.632489316217637, 2.6495282598983545, 2.666458325194677, 2.683281572999748, 2.7, 2.716615541441225, 2.7331300737432893, 2.749545416973504, 2.7658633371878665, 2.7820855486487117, 2.7982137159266447, 2.814249455894058, 2.8301943396169813, 2.8460498941515415, 2.861817604250837, 2.8774989139876324, 2.893095228297887, 2.9086079144497976, 2.924038303442689, 2.939387691339814, 2.954657340538832, 2.9698484809834995, 2.9849623113198605, 3.0, 3.014962686336268], [0.0, 0.4242640687119285, 0.6, 0.7348469228349535, 0.848528137423857, 0.9486832980505139, 1.0392304845413265, 1.1224972160321824, 1.2, 1.2727922061357855, 1.3416407864998738, 1.407124727947029, 1.469693845669907, 1.5297058540778354, 1.5874507866387542, 1.6431676725154982, 1.697056274847714, 1.7492855684535902, 1.7999999999999998, 1.8493242008906932, 1.8973665961010278, 1.944222209522358, 1.98997487421324, 2.034698994937581, 2.078460969082653, 2.1213203435596424, 2.1633307652783937, 2.2045407685048604, 2.244994432064365, 2.2847319317591723, 2.32379000772445, 2.362202362203543, 2.4, 2.4372115213907883, 2.4738633753705965, 2.5099800796022267, 2.545584412271571, 2.5806975801127883, 2.615339366124404, 2.649528259898354, 2.6832815729997477, 2.716615541441225, 2.749545416973504, 2.782085548648711, 2.814249455894058, 2.846049894151541, 2.877498913987632, 2.908607914449797, 2.939387691339814, 2.9698484809834995, 3.0, 3.0298514815086235, 3.059411708155671, 3.0886890422961004, 3.117691453623979, 3.1464265445104544, 3.1749015732775083, 3.2031234756093934, 3.2310988842807027, 3.2588341473600644, 3.2863353450309964, 3.3136083051561784, 3.340658617698013, 3.3674916480965473, 3.394112549695428, 3.4205262752974135, 3.446737587922817, 3.4727510708370675, 3.4985711369071804, 3.524202037341219, 3.5496478698597698, 3.5749125863438955, 3.5999999999999996, 3.6249137920783716, 3.6496575181789317, 3.674234614174767, 3.6986484017813863, 3.722902093797257, 3.7469987990390394, 3.7709415269929605, 3.7947331922020555, 3.818376618407357, 3.8418745424597094, 3.8652296180175374, 3.888444419044716, 3.9115214431215897, 3.934463114581201, 3.9572717874818757, 3.97994974842648, 4.0024992192379, 4.024922359499621, 4.047221268969612, 4.069397989875162, 4.091454509095757, 4.113392760240626, 4.135214625627066, 4.156921938165306, 4.178516483155236, 4.199999999999999, 4.221374183841087, 4.242640687119285, 4.263801121065569], [0.0, 0.5196152422706632, 0.7348469228349536, 0.9000000000000001, 1.0392304845413265, 1.1618950038622253, 1.2727922061357857, 1.3747727084867523, 1.4696938456699071, 1.5588457268119895, 1.6431676725154984, 1.7233687939614089, 1.8000000000000003, 1.8734993995195197, 1.9442222095223582, 2.0124611797498106, 2.078460969082653, 2.1424285285628555, 2.2045407685048604, 2.2649503305812253, 2.3237900077244507, 2.381176179958132, 2.437211521390789, 2.491987158875423, 2.5455844122715714, 2.5980762113533165, 2.6495282598983545, 2.7000000000000006, 2.7495454169735045, 2.798213715926645, 2.846049894151542, 2.893095228297887, 2.9393876913398143, 2.9849623113198605, 3.029851481508624, 3.07408522978788, 3.117691453623979, 3.1606961258558224, 3.203123475609394, 3.244996147917591, 3.286335345030997, 3.327160951922826, 3.3674916480965478, 3.407345007480164, 3.4467375879228177, 3.4856850115866758, 3.5242020373412197, 3.5623026261113755, 3.6000000000000005, 3.637306695894643, 3.6742346141747677, 3.7107950630558952, 3.7469987990390394, 3.782856063875548, 3.818376618407357, 3.853569773599539, 3.8884444190447165, 3.9230090491866068, 3.9572717874818766, 3.9912404086950217, 4.024922359499621, 4.058324777540606, 4.091454509095757, 4.124318125460257, 4.156921938165306, 4.189272013130682, 4.221374183841087, 4.253234063627348, 4.284857057125711, 4.316248370981448, 4.3474130238568325, 4.378355855797928, 4.409081537009721, 4.439594576084623, 4.469899327725402, 4.5, 4.529900661162451, 4.5596052460712, 4.589117562233508, 4.618441295502197, 4.647580015448901, 4.67653718043597, 4.705316142407438, 4.73392015141785, 4.762352359916264, 4.790615826801395, 4.818713521262705, 4.846648326421054, 4.874423042781578, 4.902040391510458, 4.929503017546495, 4.956813492557493, 4.983974317750846, 5.010987926547021, 5.037856687124, 5.06458290484024, 5.091168824543143, 5.117616632769596, 5.143928459844674, 5.170106381884227, 5.196152422706633, 5.2220685556587645], [0.0, 0.6, 0.848528137423857, 1.0392304845413265, 1.2, 1.341640786499874, 1.469693845669907, 1.5874507866387544, 1.697056274847714, 1.7999999999999998, 1.8973665961010275, 1.9899748742132402, 2.078460969082653, 2.1633307652783937, 2.244994432064365, 2.3237900077244498, 2.4, 2.4738633753705965, 2.545584412271571, 2.6153393661244047, 2.683281572999748, 2.749545416973504, 2.814249455894058, 2.8774989139876324, 2.939387691339814, 3.0, 3.0594117081556713, 3.1176914536239795, 3.1749015732775088, 3.2310988842807027, 3.286335345030997, 3.340658617698013, 3.394112549695428, 3.4467375879228177, 3.498571136907181, 3.5496478698597698, 3.5999999999999996, 3.649657518178932, 3.698648401781386, 3.746998799039039, 3.794733192202055, 3.84187454245971, 3.8884444190447165, 3.9344631145811997, 3.9799497484264803, 4.024922359499621, 4.069397989875161, 4.113392760240626, 4.156921938165306, 4.2, 4.242640687119286, 4.284857057125711, 4.3266615305567875, 4.368065933568311, 4.409081537009721, 4.449719092257398, 4.48998886412873, 4.52990066116245, 4.5694638635183455, 4.608687448721165, 4.6475800154488995, 4.686149805543993, 4.724404724407086, 4.762352359916263, 4.8, 4.8373546489791295, 4.874423042781576, 4.91121166312347, 4.947726750741193, 4.983974317750845, 5.019960159204453, 5.055689863905815, 5.091168824543142, 5.126402247190518, 5.1613951602255765, 5.196152422706632, 5.230678732248809, 5.264978632435274, 5.299056519796709, 5.332916650389354, 5.366563145999496, 5.4, 5.43323108288245, 5.466260147486579, 5.499090833947008, 5.531726674375733, 5.564171097297423, 5.596427431853289, 5.628498911788116, 5.660388679233963, 5.692099788303083, 5.723635208501674, 5.754997827975265, 5.786190456595774, 5.817215828899595, 5.848076606885378, 5.878775382679628, 5.909314681077664, 5.939696961966999, 5.969924622639721, 6.0, 6.029925372672536], [0.0, 0.6708203932499369, 0.9486832980505139, 1.1618950038622253, 1.3416407864998738, 1.5000000000000002, 1.6431676725154984, 1.7748239349298849, 1.8973665961010278, 2.0124611797498106, 2.121320343559643, 2.224859546128699, 2.3237900077244507, 2.418677324489565, 2.5099800796022267, 2.598076211353316, 2.6832815729997477, 2.7658633371878665, 2.8460498941515415, 2.9240383034426896, 3.0000000000000004, 3.0740852297878796, 3.1464265445104553, 3.217141588429083, 3.286335345030997, 3.3541019662496847, 3.4205262752974144, 3.4856850115866758, 3.5496478698597698, 3.612478373637689, 3.6742346141747677, 3.73496987939662, 3.7947331922020555, 3.8535697735995393, 3.91152144312159, 3.968626966596886, 4.024922359499621, 4.080441152620634, 4.135214625627067, 4.189272013130683, 4.242640687119286, 4.295346318982906, 4.347413023856832, 4.398863489584554, 4.449719092257398, 4.5, 4.549725266430931, 4.598912915026768, 4.647580015448901, 4.695742752749559, 4.74341649025257, 4.790615826801394, 4.83735464897913, 4.883646178829912, 4.929503017546495, 4.9749371855331, 5.019960159204453, 5.06458290484024, 5.108815909777921, 5.152669211195301, 5.196152422706632, 5.239274758971895, 5.282045058497703, 5.324471804789655, 5.366563145999495, 5.408326913195984, 5.449770637375485, 5.490901565316938, 5.531726674375733, 5.572252686302013, 5.612486080160913, 5.6524331044250316, 5.692099788303083, 5.73149195236284, 5.770615218501404, 5.809475019311125, 5.848076606885379, 5.886425061104576, 5.924525297439451, 5.962382074305538, 6.000000000000001, 6.037383539249433, 6.074537019394977, 6.111464636239009, 6.148170459575759, 6.184658438426492, 6.220932405998317, 6.256996084384263, 6.292853089020911, 6.328506932918696, 6.3639610306789285, 6.399218702310463, 6.434283176858166, 6.469157595854349, 6.50384501660364, 6.5383484153110105, 6.572670690061994, 6.606814663663574, 6.640783086353596, 6.674578638386098, 6.708203932499369, 6.741661516273272], [0.0, 0.7348469228349535, 1.0392304845413265, 1.2727922061357857, 1.469693845669907, 1.6431676725154987, 1.8, 1.9442222095223582, 2.078460969082653, 2.20454076850486, 2.32379000772445, 2.4372115213907883, 2.5455844122715714, 2.649528259898354, 2.749545416973504, 2.846049894151541, 2.939387691339814, 3.0298514815086235, 3.117691453623979, 3.203123475609394, 3.2863353450309973, 3.3674916480965473, 3.4467375879228177, 3.5242020373412197, 3.6, 3.6742346141747673, 3.7469987990390394, 3.818376618407357, 3.8884444190447165, 3.957271787481876, 4.024922359499621, 4.091454509095757, 4.156921938165306, 4.221374183841087, 4.284857057125711, 4.347413023856832, 4.40908153700972, 4.469899327725402, 4.52990066116245, 4.589117562233507, 4.6475800154489, 4.705316142407437, 4.762352359916263, 4.818713521262703, 4.874423042781577, 4.929503017546495, 4.983974317750845, 5.037856687123999, 5.091168824543143, 5.143928459844674, 5.196152422706632, 5.247856705360771, 5.299056519796708, 5.349766350038103, 5.4, 5.449770637375485, 5.499090833947008, 5.547972602672079, 5.59642743185329, 5.644466316668034, 5.692099788303082, 5.739337940912698, 5.786190456595773, 5.8326666285670745, 5.878775382679628, 5.924525297439449, 5.969924622639719, 6.014981296729026, 6.059702963017247, 6.104096984812742, 6.148170459575759, 6.191930232165088, 6.235382907247958, 6.278534860936905, 6.321392251711644, 6.363961030678928, 6.406246951218788, 6.448255578061404, 6.489992295835182, 6.5314623171231725, 6.572670690061995, 6.613622305514582, 6.654321903845651, 6.694774081326419, 6.734983296193095, 6.774953874381731, 6.81469001496033, 6.854195795277517, 6.893475175845635, 6.9325320049748065, 6.971370023173351, 7.009992867328754, 7.0484040746824395, 7.086607086610631, 7.124605252222751, 7.162401831787993, 7.2, 7.237402849088893, 7.274613391789284, 7.3116345641723655, 7.3484692283495345, 7.385120175054705], [0.0, 0.7937253933193772, 1.1224972160321824, 1.374772708486752, 1.5874507866387544, 1.774823934929885, 1.9442222095223582, 2.1, 2.244994432064365, 2.3811761799581315, 2.5099800796022267, 2.632489316217637, 2.749545416973504, 2.861817604250837, 2.9698484809834995, 3.074085229787879, 3.1749015732775088, 3.2726136343907144, 3.3674916480965473, 3.4597687784012394, 3.54964786985977, 3.6373066958946425, 3.7229020937972575, 3.8065732621348567, 3.8884444190447165, 3.968626966596886, 4.047221268969613, 4.124318125460256, 4.2, 4.274342054632502, 4.347413023856832, 4.419275958796871, 4.48998886412873, 4.5596052460712, 4.628174586162454, 4.695742752749559, 4.762352359916263, 4.828043081829325, 4.892851929090027, 4.956813492557492, 5.019960159204453, 5.082322303829225, 5.143928459844674, 5.204805471869241, 5.264978632435274, 5.324471804789654, 5.383307533477908, 5.441507144165116, 5.499090833947008, 5.556077753235641, 5.612486080160912, 5.668333088307356, 5.723635208501674, 5.7784080852774675, 5.8326666285670745, 5.886425061104575, 5.939696961966999, 5.9924953066314535, 6.044832503882966, 6.096720429870472, 6.148170459575758, 6.199193495931548, 6.249799996799897, 6.3, 6.3498031465550175, 6.3992187023104625, 6.448255578061403, 6.496922348312315, 6.545227268781429, 6.593178292750773, 6.640783086353597, 6.688049042882386, 6.734983296193095, 6.7815927332743895, 6.827884006044625, 6.87386354243376, 6.919537556802479, 6.96491205974634, 7.009992867328755, 7.0547856097829085, 7.09929573971954, 7.143528539874396, 7.187489130426564, 7.231182475916369, 7.274613391789285, 7.317786550590282, 7.360706487831179, 7.40337760755184, 7.445804187594515, 7.487990384609211, 7.52994023880668, 7.571657678474378, 7.613146524269713, 7.654410493303845, 7.695453203028396, 7.736278174936576, 7.776888838089433, 7.817288532477231, 7.857480512225276, 7.897467948652911, 7.937253933193772, 7.9768414801850005], [0.0, 0.848528137423857, 1.2, 1.469693845669907, 1.697056274847714, 1.8973665961010278, 2.078460969082653, 2.244994432064365, 2.4, 2.545584412271571, 2.6832815729997477, 2.814249455894058, 2.939387691339814, 3.059411708155671, 3.1749015732775083, 3.2863353450309964, 3.394112549695428, 3.4985711369071804, 3.5999999999999996, 3.6986484017813863, 3.7947331922020555, 3.888444419044716, 3.97994974842648, 4.069397989875162, 4.156921938165306, 4.242640687119285, 4.3266615305567875, 4.409081537009721, 4.48998886412873, 4.569463863518345, 4.6475800154489, 4.724404724407086, 4.8, 4.874423042781577, 4.947726750741193, 5.019960159204453, 5.091168824543142, 5.1613951602255765, 5.230678732248808, 5.299056519796708, 5.366563145999495, 5.43323108288245, 5.499090833947008, 5.564171097297422, 5.628498911788116, 5.692099788303082, 5.754997827975264, 5.817215828899594, 5.878775382679628, 5.939696961966999, 6.0, 6.059702963017247, 6.118823416311342, 6.177378084592201, 6.235382907247958, 6.292853089020909, 6.349803146555017, 6.406246951218787, 6.462197768561405, 6.517668294720129, 6.572670690061993, 6.627216610312357, 6.681317235396026, 6.734983296193095, 6.788225099390856, 6.841052550594827, 6.893475175845634, 6.945502141674135, 6.997142273814361, 7.048404074682438, 7.0992957397195395, 7.149825172687791, 7.199999999999999, 7.249827584156743, 7.299315036357863, 7.348469228349534, 7.397296803562773, 7.445804187594514, 7.493997598078079, 7.541883053985921, 7.589466384404111, 7.636753236814714, 7.683749084919419, 7.730459236035075, 7.776888838089432, 7.823042886243179, 7.868926229162402, 7.914543574963751, 7.95989949685296, 8.0049984384758, 8.049844718999243, 8.094442537939225, 8.138795979750324, 8.182909018191515, 8.226785520481252, 8.270429251254132, 8.313843876330612, 8.357032966310472, 8.399999999999999, 8.442748367682174, 8.48528137423857, 8.527602242131138], [0.0, 0.8999999999999999, 1.2727922061357855, 1.5588457268119895, 1.7999999999999998, 2.012461179749811, 2.2045407685048604, 2.3811761799581315, 2.545584412271571, 2.6999999999999997, 2.846049894151541, 2.98496231131986, 3.117691453623979, 3.24499614791759, 3.367491648096547, 3.485685011586675, 3.5999999999999996, 3.7107950630558943, 3.818376618407356, 3.9230090491866063, 4.024922359499622, 4.124318125460256, 4.221374183841087, 4.316248370981448, 4.409081537009721, 4.5, 4.589117562233507, 4.676537180435969, 4.762352359916263, 4.846648326421054, 4.929503017546495, 5.01098792654702, 5.091168824543142, 5.170106381884226, 5.247856705360771, 5.324471804789654, 5.3999999999999995, 5.474486277268398, 5.547972602672078, 5.6204981985585585, 5.692099788303082, 5.762811813689564, 5.8326666285670745, 5.901694671871799, 5.96992462263972, 6.037383539249432, 6.104096984812742, 6.170089140360939, 6.235382907247958, 6.3, 6.363961030678928, 6.427285585688566, 6.48999229583518, 6.552098900352467, 6.613622305514581, 6.674578638386096, 6.734983296193094, 6.794850991743674, 6.854195795277518, 6.913031173081746, 6.97137002317335, 7.029224708315989, 7.08660708661063, 7.143528539874395, 7.199999999999999, 7.256031973468694, 7.311634564172364, 7.366817494685204, 7.421590126111789, 7.475961476626267, 7.52994023880668, 7.583534795858722, 7.636753236814712, 7.689603370785778, 7.7420927403383635, 7.794228634059947, 7.846018098373213, 7.897467948652911, 7.9485847796950635, 7.99937497558403, 8.049844718999244, 8.1, 8.149846624323676, 8.199390221229867, 8.248636250920512, 8.2975900115636, 8.346256645946134, 8.394641147779932, 8.442748367682174, 8.490583018850943, 8.538149682454623, 8.58545281275251, 8.632496741962896, 8.67928568489366, 8.725823743349393, 8.772114910328067, 8.818163074019441, 8.863972021616496, 8.909545442950497, 8.95488693395958, 9.0, 9.044888059008803], [0.0, 0.9486832980505138, 1.3416407864998738, 1.6431676725154984, 1.8973665961010275, 2.121320343559643, 2.32379000772445, 2.5099800796022267, 2.6832815729997477, 2.846049894151541, 3.0, 3.146426544510455, 3.286335345030997, 3.420526275297414, 3.5496478698597693, 3.674234614174767, 3.794733192202055, 3.9115214431215892, 4.024922359499621, 4.135214625627067, 4.242640687119286, 4.347413023856832, 4.449719092257398, 4.549725266430931, 4.6475800154489, 4.743416490252569, 4.83735464897913, 4.929503017546495, 5.019960159204453, 5.10881590977792, 5.196152422706632, 5.282045058497703, 5.366563145999495, 5.449770637375486, 5.531726674375733, 5.612486080160912, 5.692099788303082, 5.770615218501404, 5.848076606885378, 5.92452529743945, 6.0, 6.074537019394977, 6.148170459575759, 6.220932405998315, 6.29285308902091, 6.363961030678928, 6.434283176858165, 6.5038450166036395, 6.572670690061994, 6.640783086353597, 6.708203932499369, 6.77495387438173, 6.841052550594828, 6.906518659932804, 6.971370023173351, 7.035623639735144, 7.099295739719539, 7.162401831787993, 7.224956747275378, 7.286974680894671, 7.348469228349534, 7.409453421137082, 7.469939758793239, 7.52994023880668, 7.58946638440411, 7.648529270389177, 7.707139547199077, 7.76530746332687, 7.8230428862431785, 7.880355321938218, 7.937253933193772, 7.993747556684537, 8.049844718999243, 8.105553651663778, 8.160882305241266, 8.215838362577491, 8.270429251254134, 8.324662155306966, 8.378544026261366, 8.432081593533118, 8.485281374238571, 8.538149682454625, 8.590692637965812, 8.64291617453276, 8.694826047713663, 8.746427842267952, 8.79772697916911, 8.848728722251575, 8.899438184514796, 8.949860334105779, 9.0, 9.049861877399014, 9.099450532861862, 9.148770409186145, 9.197825830053535, 9.246621004453464, 9.2951600308978, 9.343446901438464, 9.391485505499116, 9.439279633531365, 9.486832980505138, 9.534149149242424], [0.0, 0.99498743710662, 1.407124727947029, 1.7233687939614089, 1.98997487421324, 2.2248595461286995, 2.4372115213907883, 2.632489316217637, 2.814249455894058, 2.9849623113198596, 3.146426544510455, 3.3000000000000007, 3.4467375879228177, 3.58747822293042, 3.722902093797257, 3.853569773599539, 3.97994974842648, 4.102438299353203, 4.221374183841087, 4.337049688440289, 4.449719092257399, 4.559605246071199, 4.666904755831214, 4.771792116176061, 4.874423042781577, 4.974937185533101, 5.07346035758633, 5.170106381884226, 5.264978632435274, 5.358171329847526, 5.449770637375486, 5.539855593785817, 5.628498911788116, 5.715767664977296, 5.801723881744116, 5.886425061104576, 5.969924622639719, 6.052272300549605, 6.133514490078262, 6.213694553162394, 6.29285308902091, 6.3710281744785915, 6.448255578061404, 6.524568951279464, 6.600000000000001, 6.674578638386097, 6.748333127521196, 6.8212902005412435, 6.893475175845635, 6.96491205974634, 7.035623639735145, 7.105631569396208, 7.17495644586084, 7.243617880589783, 7.3116345641723655, 7.379024325749306, 7.445804187594514, 7.5119904153293495, 7.577598564189055, 7.642643521714199, 7.707139547199078, 7.771100308193172, 7.834538914320357, 7.897467948652911, 7.95989949685296, 8.021845174272563, 8.083316151184487, 8.144323176298936, 8.204876598706406, 8.264986388373547, 8.324662155306966, 8.383913167489272, 8.442748367682174, 8.501176389182852, 8.559205570612264, 8.616843969807043, 8.674099376880578, 8.73097932651315, 8.787491109526089, 8.843641783790206, 8.899438184514798, 8.954886933959582, 9.009994450608724, 9.064766957842876, 9.119210492142399, 9.173330910852396, 9.22713389953782, 9.280624978954812, 9.333809511662428, 9.38669270829721, 9.439279633531365, 9.491575211733826, 9.543584232352122, 9.595311355031688, 9.646761114488116, 9.69793792514677, 9.748846085563153, 9.799489782636646, 9.849873095629201, 9.900000000000002, 9.949874371066201, 9.999499987499378], [0.0, 1.0392304845413265, 1.4696938456699071, 1.8000000000000003, 2.078460969082653, 2.3237900077244507, 2.5455844122715714, 2.7495454169735045, 2.9393876913398143, 3.117691453623979, 3.286335345030997, 3.4467375879228177, 3.6000000000000005, 3.7469987990390394, 3.8884444190447165, 4.024922359499621, 4.156921938165306, 4.284857057125711, 4.409081537009721, 4.529900661162451, 4.647580015448901, 4.762352359916264, 4.874423042781578, 4.983974317750846, 5.091168824543143, 5.196152422706633, 5.299056519796709, 5.400000000000001, 5.499090833947009, 5.59642743185329, 5.692099788303084, 5.786190456595774, 5.8787753826796285, 5.969924622639721, 6.059702963017248, 6.14817045957576, 6.235382907247958, 6.321392251711645, 6.406246951218788, 6.489992295835182, 6.572670690061994, 6.654321903845652, 6.7349832961930955, 6.814690014960328, 6.893475175845635, 6.9713700231733515, 7.0484040746824395, 7.124605252222751, 7.200000000000001, 7.274613391789286, 7.348469228349535, 7.4215901261117905, 7.493997598078079, 7.565712127751096, 7.636753236814714, 7.707139547199078, 7.776888838089433, 7.8460180983732135, 7.914543574963753, 7.9824808173900434, 8.049844718999243, 8.116649555081212, 8.182909018191515, 8.248636250920514, 8.313843876330612, 8.378544026261364, 8.442748367682174, 8.506468127254696, 8.569714114251422, 8.632496741962896, 8.694826047713665, 8.756711711595855, 8.818163074019441, 8.879189152169246, 8.939798655450804, 9.0, 9.059801322324901, 9.1192104921424, 9.178235124467015, 9.236882591004393, 9.295160030897803, 9.35307436087194, 9.410632284814875, 9.4678403028357, 9.524704719832528, 9.58123165360279, 9.63742704252541, 9.693296652842108, 9.748846085563155, 9.804080783020916, 9.85900603509299, 9.913626985114986, 9.967948635501692, 10.021975853094043, 10.075713374248, 10.12916580968048, 10.182337649086286, 10.235233265539192, 10.287856919689348, 10.340212763768454, 10.392304845413266, 10.444137111317529], [0.0, 1.0816653826391969, 1.5297058540778357, 1.8734993995195197, 2.1633307652783937, 2.418677324489565, 2.6495282598983545, 2.861817604250837, 3.0594117081556713, 3.24499614791759, 3.420526275297414, 3.58747822293042, 3.7469987990390394, 3.9000000000000004, 4.047221268969612, 4.189272013130682, 4.3266615305567875, 4.459820624195552, 4.589117562233507, 4.714870093650514, 4.83735464897913, 4.956813492557492, 5.073460357586329, 5.187484939737176, 5.299056519796709, 5.408326913195984, 5.515432893255071, 5.620498198558559, 5.723635208501674, 5.8249463516842805, 5.92452529743945, 6.02245796996542, 6.118823416311343, 6.213694553162395, 6.307138812488592, 6.399218702310463, 6.48999229583518, 6.579513659838393, 6.667833231267861, 6.754998149518622, 6.841052550594828, 6.926037828369118, 7.009992867328754, 7.092954250522133, 7.17495644586084, 7.256031973468695, 7.336211556382491, 7.415524256584965, 7.493997598078079, 7.571657678474378, 7.6485292703891785, 7.724635913750241, 7.800000000000001, 7.8746428490440135, 7.948584779695063, 8.021845174272563, 8.094442537939225, 8.16639455328972, 8.23771813064759, 8.308429454475737, 8.378544026261364, 8.448076704197234, 8.517041739947034, 8.58545281275251, 8.653323061113575, 8.72066511224918, 8.787491109526085, 8.853812738024224, 8.919641248391104, 8.984987479123163, 9.049861877399014, 9.114274518577988, 9.178235124467014, 9.241753080449618, 9.304837451562495, 9.367496997597598, 9.429740187301029, 9.491575211733826, 9.553009996854398, 9.61405221537724, 9.67470929795826, 9.734988443752773, 9.794896630388706, 9.854440623394105, 9.913626985114984, 9.972462083156799, 10.030952098380295, 10.089103032480143, 10.146920715172659, 10.20441081101697, 10.261578825892242, 10.318430113151905, 10.374969879474351, 10.431203190428228, 10.487134975769122, 10.542770034483349, 10.598113039593418, 10.653168542738824, 10.707940978544848, 10.76243466879126, 10.816653826391969, 10.870602559196065], [0.0, 1.1224972160321824, 1.5874507866387544, 1.9442222095223582, 2.244994432064365, 2.5099800796022267, 2.749545416973504, 2.9698484809834995, 3.1749015732775088, 3.367491648096547, 3.5496478698597693, 3.722902093797257, 3.8884444190447165, 4.047221268969612, 4.199999999999999, 4.347413023856831, 4.48998886412873, 4.628174586162453, 4.762352359916263, 4.892851929090027, 5.019960159204453, 5.143928459844674, 5.264978632435273, 5.383307533477909, 5.499090833947008, 5.612486080160912, 5.723635208501674, 5.8326666285670745, 5.939696961966999, 6.044832503882965, 6.148170459575759, 6.249799996799897, 6.3498031465550175, 6.448255578061404, 6.545227268781429, 6.640783086353597, 6.734983296193094, 6.827884006044625, 6.919537556802477, 7.009992867328754, 7.099295739719539, 7.187489130426564, 7.274613391789285, 7.360706487831177, 7.445804187594514, 7.529940238806679, 7.6131465242697125, 7.6954532030283955, 7.776888838089433, 7.857480512225277, 7.937253933193772, 8.016233529532434, 8.094442537939225, 8.171903083125743, 8.248636250920512, 8.324662155306964, 8.399999999999999, 8.474668135095321, 8.548684109265006, 8.622064717919947, 8.694826047713661, 8.766983517721474, 8.83855191759374, 8.909545442950499, 8.97997772825746, 9.049861877399012, 9.119210492142397, 9.188035698668132, 9.256349172324907, 9.324162160752032, 9.391485505499118, 9.458329662260667, 9.524704719832526, 9.590620417887468, 9.656086163658648, 9.72111104761179, 9.785703858180055, 9.849873095629203, 9.913626985114986, 9.976973488989534, 10.039920318408907, 10.102474944289643, 10.16464460765845, 10.226436329435586, 10.287856919689348, 10.348912986396206, 10.409610943738485, 10.469957019969089, 10.529957264870546, 10.589617556833675, 10.648943609579309, 10.707940978544848, 10.766615066955818, 10.824971131601231, 10.883014288330232, 10.940749517286282, 10.998181667894016, 11.055315463612969, 11.112155506471279, 11.168706281391772, 11.224972160321824, 11.280957406177901], [0.0, 1.1618950038622249, 1.6431676725154982, 2.0124611797498106, 2.3237900077244498, 2.598076211353316, 2.846049894151541, 3.074085229787879, 3.2863353450309964, 3.4856850115866744, 3.674234614174767, 3.853569773599539, 4.024922359499621, 4.189272013130682, 4.347413023856831, 4.499999999999999, 4.6475800154488995, 4.790615826801393, 4.9295030175464944, 5.06458290484024, 5.196152422706632, 5.324471804789654, 5.449770637375485, 5.572252686302013, 5.692099788303082, 5.809475019311125, 5.92452529743945, 6.037383539249432, 6.148170459575758, 6.256996084384262, 6.363961030678928, 6.469157595854347, 6.572670690061993, 6.674578638386097, 6.774953874381729, 6.873863542433759, 6.971370023173349, 7.067531393633848, 7.162401831787992, 7.256031973468694, 7.348469228349534, 7.439758060582347, 7.529940238806679, 7.619055059520175, 7.707139547199078, 7.794228634059947, 7.880355321938218, 7.965550828411051, 8.049844718999243, 8.133265027035575, 8.215838362577491, 8.2975900115636, 8.378544026261364, 8.45872330792301, 8.538149682454623, 8.616843969807041, 8.694826047713661, 8.772114910328067, 8.848728722251575, 8.924684868386109, 8.999999999999998, 9.074690077352503, 9.148770409186142, 9.222255689363639, 9.295160030897799, 9.367496997597597, 9.439279633531363, 9.510520490488414, 9.581231653602787, 9.651424765287246, 9.72111104761179, 9.790301323248432, 9.859006035092989, 9.927235264664578, 9.994998749374608, 10.062305898749052, 10.12916580968048, 10.195587280779858, 10.261578825892244, 10.327148686835104, 10.392304845413264, 10.457055034760026, 10.521406750050108, 10.585367258626409, 10.648943609579309, 10.712142642814275, 10.774970997640782, 10.837435120913065, 10.89954127475097, 10.961295543867065, 11.022703842524301, 11.083771921146699, 11.144505372604026, 11.20490963818986, 11.264990013311152, 11.324751652906123, 11.384199576606164, 11.443338673656392, 11.502173707608486, 11.560709320798617, 11.61895003862225, 11.67690027361714], [0.0, 1.2, 1.697056274847714, 2.078460969082653, 2.4, 2.683281572999748, 2.939387691339814, 3.1749015732775088, 3.394112549695428, 3.5999999999999996, 3.794733192202055, 3.9799497484264803, 4.156921938165306, 4.3266615305567875, 4.48998886412873, 4.6475800154488995, 4.8, 4.947726750741193, 5.091168824543142, 5.230678732248809, 5.366563145999496, 5.499090833947008, 5.628498911788116, 5.754997827975265, 5.878775382679628, 6.0, 6.118823416311343, 6.235382907247959, 6.3498031465550175, 6.462197768561405, 6.572670690061994, 6.681317235396026, 6.788225099390856, 6.893475175845635, 6.997142273814362, 7.0992957397195395, 7.199999999999999, 7.299315036357864, 7.397296803562772, 7.493997598078078, 7.58946638440411, 7.68374908491942, 7.776888838089433, 7.868926229162399, 7.959899496852961, 8.049844718999243, 8.138795979750322, 8.226785520481252, 8.313843876330612, 8.4, 8.485281374238571, 8.569714114251422, 8.653323061113575, 8.736131867136622, 8.818163074019441, 8.899438184514796, 8.97997772825746, 9.0598013223249, 9.138927727036691, 9.21737489744233, 9.295160030897799, 9.372299611087985, 9.448809448814172, 9.524704719832526, 9.6, 9.674709297958259, 9.748846085563152, 9.82242332624694, 9.895453501482386, 9.96794863550169, 10.039920318408907, 10.11137972781163, 10.182337649086284, 10.252804494381037, 10.322790320451153, 10.392304845413264, 10.461357464497619, 10.529957264870548, 10.598113039593418, 10.665833300778708, 10.733126291998992, 10.8, 10.8664621657649, 10.932520294973157, 10.998181667894016, 11.063453348751466, 11.128342194594847, 11.192854863706579, 11.256997823576231, 11.320777358467925, 11.384199576606166, 11.447270417003349, 11.50999565595053, 11.572380913191548, 11.63443165779919, 11.696153213770756, 11.757550765359255, 11.818629362155328, 11.879393923933998, 11.939849245279442, 12.0, 12.059850745345072], [0.0, 1.236931687685298, 1.7492855684535902, 2.142428528562855, 2.473863375370596, 2.7658633371878665, 3.0298514815086235, 3.2726136343907144, 3.4985711369071804, 3.710795063055894, 3.9115214431215892, 4.102438299353203, 4.28485705712571, 4.459820624195552, 4.628174586162453, 4.790615826801393, 4.947726750741192, 5.1, 5.24785670536077, 5.391660226683429, 5.531726674375733, 5.668333088307356, 5.801723881744115, 5.932115979985557, 6.059702963017247, 6.184658438426491, 6.307138812488592, 6.427285585688566, 6.545227268781429, 6.661080993352355, 6.774953874381729, 6.886944169949398, 6.997142273814361, 7.105631569396207, 7.212489168102786, 7.317786550590281, 7.421590126111788, 7.5239617223906725, 7.6249590162833005, 7.72463591375024, 7.8230428862431785, 7.920227269466452, 8.016233529532432, 8.111103500757464, 8.204876598706406, 8.297590011563598, 8.389278872465738, 8.479976415061541, 8.56971411425142, 8.658521813797087, 8.746427842267952, 8.833459118601276, 8.919641248391104, 9.004998611882181, 9.08955444452587, 9.173330910852393, 9.256349172324907, 9.338629449764028, 9.42019108086455, 9.501052573267868, 9.581231653602787, 9.66074531286277, 9.739609848448756, 9.817840903172144, 9.895453501482384, 9.972462083156795, 10.048880534666536, 10.124722218411723, 10.2, 10.274726273726225, 10.348912986396204, 10.422571659624126, 10.49571341072154, 10.568348972285122, 10.64048871058092, 10.712142642814275, 10.783320453366859, 10.854031509075327, 10.924284873619877, 10.994089321085218, 11.063453348751466, 11.132385189167685, 11.200892821556682, 11.268983982595769, 11.336666176614711, 11.403946685248929, 11.470832576583097, 11.537330713817646, 11.60344776348823, 11.669190203266036, 11.734564329364767, 11.799576263578281, 11.864231959971114, 11.928537211242627, 11.99249765478401, 12.056118778446072, 12.119405926034494, 12.182364302548173, 12.24499897917513, 12.30731489805961, 12.369316876852983, 12.4310096130604], [0.0, 1.2727922061357855, 1.8, 2.2045407685048604, 2.545584412271571, 2.846049894151542, 3.1176914536239795, 3.3674916480965473, 3.6, 3.818376618407356, 4.024922359499621, 4.221374183841087, 4.409081537009721, 4.589117562233507, 4.762352359916263, 4.9295030175464944, 5.091168824543142, 5.24785670536077, 5.3999999999999995, 5.54797260267208, 5.692099788303084, 5.8326666285670745, 5.96992462263972, 6.104096984812743, 6.235382907247959, 6.363961030678928, 6.489992295835181, 6.613622305514581, 6.734983296193095, 6.854195795277517, 6.971370023173351, 7.08660708661063, 7.2, 7.3116345641723655, 7.42159012611179, 7.52994023880668, 7.636753236814712, 7.742092740338365, 7.846018098373213, 7.948584779695063, 8.049844718999243, 8.149846624323676, 8.248636250920512, 8.346256645946132, 8.442748367682174, 8.538149682454625, 8.632496741962896, 8.725823743349391, 8.818163074019441, 8.909545442950499, 9.0, 9.089554444525872, 9.178235124467014, 9.266067126888302, 9.353074360871938, 9.439279633531363, 9.524704719832526, 9.60937042682818, 9.69329665284211, 9.776502442080194, 9.859006035092989, 9.940824915468536, 10.02197585309404, 10.102474944289643, 10.182337649086284, 10.261578825892242, 10.34021276376845, 10.418253212511202, 10.49571341072154, 10.572606112023658, 10.648943609579309, 10.724737759031687, 10.799999999999999, 10.874741376235114, 10.948972554536796, 11.022703842524301, 11.09594520534416, 11.168706281391772, 11.240996397117119, 11.312824580978882, 11.384199576606168, 11.45512985522207, 11.525623627379128, 11.595688854052613, 11.665333257134149, 11.734564329364769, 11.803389343743603, 11.871815362445627, 11.93984924527944, 12.007497657713701, 12.074767078498864, 12.141663806908838, 12.208193969625485, 12.274363527287273, 12.34017828072188, 12.4056438768812, 12.470765814495918, 12.535549449465709, 12.6, 12.664122551523262, 12.727922061357855, 12.791403363196709], [0.0, 1.307669683062202, 1.8493242008906932, 2.2649503305812253, 2.615339366124404, 2.92403830344269, 3.203123475609394, 3.4597687784012394, 3.6986484017813863, 3.9230090491866063, 4.135214625627067, 4.337049688440289, 4.529900661162451, 4.7148700936505135, 4.892851929090027, 5.06458290484024, 5.230678732248808, 5.391660226683429, 5.547972602672079, 5.700000000000001, 5.84807660688538, 5.992495306631454, 6.133514490078263, 6.2713634881100635, 6.406246951218788, 6.538348415311011, 6.6678332312678625, 6.794850991743676, 6.919537556802479, 7.042016756583302, 7.162401831787994, 7.280796659706959, 7.397296803562773, 7.51199041532935, 7.624959016283302, 7.736278174936577, 7.846018098373213, 7.954244150137713, 8.061017305526642, 8.16639455328972, 8.270429251254134, 8.373171442171719, 8.474668135095321, 8.57496355677387, 8.674099376880578, 8.77211491032807, 8.86904729945669, 8.96493167849036, 9.059801322324901, 9.153687781435416, 9.246621004453466, 9.33862944976403, 9.429740187301027, 9.51997899157346, 9.609370426828182, 9.69793792514677, 9.785703858180055, 9.872689603142602, 9.958915603618701, 10.044401425669925, 10.12916580968048, 10.213226718329523, 10.29660138103831, 10.379306335203717, 10.461357464497617, 10.542770034483349, 10.623558725775464, 10.703737664946765, 10.783320453366859, 10.862320194139004, 10.940749517286283, 11.018620603324177, 11.095945205344158, 11.172734669721645, 11.248999955551605, 11.324751652906125, 11.400000000000002, 11.474754899343168, 11.549025932952098, 11.622822376686312, 11.69615321377076, 11.769027147559822, 11.841452613594333, 11.913437790998868, 11.984990613262909, 12.056118778446075, 12.126829758844645, 12.197130810153674, 12.267028980156526, 12.336531116971255, 12.4056438768812, 12.474373731775076, 12.542726976220127, 12.610709734190225, 12.678327965469265, 12.745587471748802, 12.812493902437575, 12.879052760199412, 12.94526940623485, 13.011149065320867, 13.076696830622023, 13.14191766828571], [0.0, 1.3416407864998738, 1.8973665961010278, 2.3237900077244507, 2.6832815729997477, 3.0000000000000004, 3.286335345030997, 3.5496478698597698, 3.7947331922020555, 4.024922359499621, 4.242640687119286, 4.449719092257398, 4.647580015448901, 4.83735464897913, 5.019960159204453, 5.196152422706632, 5.366563145999495, 5.531726674375733, 5.692099788303083, 5.848076606885379, 6.000000000000001, 6.148170459575759, 6.292853089020911, 6.434283176858166, 6.572670690061994, 6.708203932499369, 6.841052550594829, 6.9713700231733515, 7.0992957397195395, 7.224956747275378, 7.348469228349535, 7.46993975879324, 7.589466384404111, 7.707139547199079, 7.82304288624318, 7.937253933193772, 8.049844718999243, 8.160882305241268, 8.270429251254134, 8.378544026261366, 8.485281374238571, 8.590692637965812, 8.694826047713663, 8.797726979169108, 8.899438184514796, 9.0, 9.099450532861862, 9.197825830053535, 9.295160030897803, 9.391485505499118, 9.48683298050514, 9.581231653602789, 9.67470929795826, 9.767292357659825, 9.85900603509299, 9.9498743710662, 10.039920318408907, 10.12916580968048, 10.217631819555843, 10.305338422390601, 10.392304845413264, 10.47854951794379, 10.564090116995406, 10.64894360957931, 10.73312629199899, 10.816653826391969, 10.89954127475097, 10.981803130633876, 11.063453348751466, 11.144505372604026, 11.224972160321826, 11.304866208850063, 11.384199576606166, 11.46298390472568, 11.541230437002808, 11.61895003862225, 11.696153213770758, 11.772850122209151, 11.849050594878902, 11.924764148611075, 12.000000000000002, 12.074767078498866, 12.149074038789953, 12.222929272478018, 12.296340919151518, 12.369316876852984, 12.441864811996634, 12.513992168768526, 12.585706178041821, 12.657013865837392, 12.727922061357857, 12.798437404620927, 12.868566353716332, 12.938315191708698, 13.00769003320728, 13.076696830622021, 13.145341380123988, 13.213629327327148, 13.281566172707192, 13.349157276772196, 13.416407864998739, 13.483323032546544], [0.0, 1.374772708486752, 1.9442222095223582, 2.381176179958132, 2.749545416973504, 3.07408522978788, 3.3674916480965478, 3.6373066958946425, 3.8884444190447165, 4.124318125460256, 4.347413023856832, 4.559605246071199, 4.762352359916264, 4.956813492557492, 5.143928459844674, 5.324471804789654, 5.499090833947008, 5.668333088307356, 5.8326666285670745, 5.992495306631454, 6.14817045957576, 6.300000000000001, 6.448255578061404, 6.593178292750775, 6.7349832961930955, 6.87386354243376, 7.009992867328755, 7.143528539874396, 7.274613391789285, 7.40337760755184, 7.529940238806681, 7.654410493303844, 7.776888838089433, 7.897467948652912, 8.016233529532434, 8.133265027035575, 8.248636250920512, 8.362415918859814, 8.474668135095321, 8.585452812752512, 8.694826047713663, 8.802840450672727, 8.909545442950499, 9.014987520790031, 9.119210492142399, 9.222255689363639, 9.324162160752033, 9.424966843443006, 9.524704719832528, 9.623408959407266, 9.72111104761179, 9.817840903172145, 9.913626985114984, 10.008496390567368, 10.102474944289643, 10.195587280779858, 10.287856919689348, 10.379306335203717, 10.46995701996909, 10.559829544078825, 10.648943609579309, 10.73731810090397, 10.82497113160123, 10.911920087683928, 10.998181667894016, 11.083771921146699, 11.16870628139177, 11.25299960010663, 11.336666176614711, 11.419719786404569, 11.50217370760849, 11.584040745784694, 11.665333257134149, 11.746063170271137, 11.826242006656216, 11.905880899790658, 11.984990613262909, 12.063581557729862, 12.14166380690884, 12.219247112649782, 12.29634091915152, 12.37295437638077, 12.449096352747858, 12.524775447088862, 12.600000000000001, 12.674778104566567, 12.749117616525469, 12.823026163897508, 12.896511156122807, 12.969579792730373, 13.042239071570496, 13.114495796636637, 13.18635658550155, 13.257827876390614, 13.328915934913837, 13.399626860476378, 13.469966592386191, 13.539940915676112, 13.609555466656506, 13.6788157382136, 13.74772708486752, 13.81629472760335], [0.0, 1.407124727947029, 1.98997487421324, 2.4372115213907883, 2.814249455894058, 3.1464265445104553, 3.4467375879228173, 3.722902093797257, 3.97994974842648, 4.221374183841086, 4.449719092257398, 4.666904755831214, 4.874423042781577, 5.073460357586329, 5.264978632435273, 5.449770637375485, 5.628498911788116, 5.801723881744115, 5.96992462263972, 6.133514490078262, 6.292853089020911, 6.448255578061404, 6.6000000000000005, 6.748333127521197, 6.8934751758456345, 7.035623639735145, 7.17495644586084, 7.3116345641723655, 7.445804187594514, 7.577598564189054, 7.707139547199078, 7.834538914320357, 7.95989949685296, 8.083316151184489, 8.204876598706408, 8.324662155306966, 8.442748367682173, 8.559205570612264, 8.674099376880577, 8.787491109526087, 8.899438184514796, 9.009994450608724, 9.119210492142399, 9.227133899537819, 9.333809511662428, 9.439279633531363, 9.54358423235212, 9.646761114488116, 9.748846085563153, 9.849873095629203, 9.949874371066201, 10.048880534666537, 10.146920715172659, 10.244022647378324, 10.340212763768452, 10.435516278555651, 10.529957264870546, 10.623558725775464, 10.716342659695053, 10.808330120791092, 10.89954127475097, 10.989995450408522, 11.079711187571633, 11.168706281391772, 11.256997823576231, 11.344602240713423, 11.43153532995459, 11.51781229227148, 11.60344776348823, 11.688455843266894, 11.772850122209151, 11.856643707221703, 11.93984924527944, 12.022478945708327, 12.104544601099208, 12.186057606953941, 12.267028980156525, 12.347469376354008, 12.42738910632479, 12.5067981514055, 12.585706178041821, 12.664122551523262, 12.742056348957181, 12.819516371532897, 12.896511156122807, 12.973048986263795, 13.049137902558929, 13.124785712536415, 13.200000000000001, 13.274788133902552, 13.349157276772194, 13.423114392718256, 13.496666255042394, 13.569819453478372, 13.642580401082489, 13.714955340794953, 13.786950351691269, 13.858571354941319, 13.929824119492679, 14.000714267493644, 14.07124727947029, 14.141428499271214], [0.0, 1.438749456993816, 2.0346989949375804, 2.491987158875423, 2.877498913987632, 3.217141588429083, 3.5242020373412197, 3.8065732621348563, 4.069397989875161, 4.316248370981447, 4.549725266430931, 4.77179211617606, 4.983974317750846, 5.187484939737175, 5.383307533477908, 5.572252686302013, 5.754997827975264, 5.932115979985557, 6.104096984812742, 6.271363488110063, 6.434283176858166, 6.593178292750774, 6.748333127521197, 6.900000000000002, 7.0484040746824395, 7.19374728496908, 7.336211556382492, 7.475961476626268, 7.6131465242697125, 7.747902942086975, 7.880355321938219, 8.010617953691213, 8.138795979750322, 8.264986388373549, 8.38927887246574, 8.511756575466665, 8.632496741962894, 8.751571287488895, 8.86904729945669, 8.984987479123163, 9.099450532861862, 9.212491519670454, 9.324162160752033, 9.434511116109832, 9.54358423235212, 9.651424765287247, 9.758073580374356, 9.863569333664158, 9.967948635501692, 10.071246198956713, 10.173494974687904, 10.274726273726227, 10.37496987947435, 10.474254150057657, 10.572606112023658, 10.670051546267244, 10.766615066955817, 10.862320194139004, 10.957189420649806, 11.051244273836318, 11.144505372604026, 11.236992480196827, 11.328724553099525, 11.419719786404569, 11.509995655950528, 11.599568957508723, 11.688455843266894, 11.776671855834312, 11.864231959971114, 11.951150572225254, 12.037441588643329, 12.123118410706052, 12.208193969625484, 12.292680749128728, 12.376590806841762, 12.459935794377113, 12.542726976220125, 12.62497524750049, 12.706691150728426, 12.78788489156827, 12.868566353716332, 12.948745112944344, 13.02843045036508, 13.107631364972086, 13.186356585501548, 13.264614581660489, 13.342413574762254, 13.419761547807026, 13.496666255042394, 13.573135231036344, 13.649175799292792, 13.72479508043745, 13.800000000000004, 13.874797295816617, 13.949193525075206, 14.023195071024293, 14.096808149364879, 14.170038814343457, 14.242892964563064, 14.315376348528183, 14.38749456993816, 14.459253092743072], [0.0, 1.469693845669907, 2.078460969082653, 2.5455844122715714, 2.939387691339814, 3.2863353450309973, 3.6, 3.8884444190447165, 4.156921938165306, 4.40908153700972, 4.6475800154489, 4.874423042781577, 5.091168824543143, 5.299056519796708, 5.499090833947008, 5.692099788303082, 5.878775382679628, 6.059702963017247, 6.235382907247958, 6.406246951218788, 6.572670690061995, 6.734983296193095, 6.893475175845635, 7.0484040746824395, 7.2, 7.3484692283495345, 7.493997598078079, 7.636753236814714, 7.776888838089433, 7.914543574963752, 8.049844718999243, 8.182909018191515, 8.313843876330612, 8.442748367682174, 8.569714114251422, 8.694826047713663, 8.81816307401944, 8.939798655450804, 9.0598013223249, 9.178235124467014, 9.2951600308978, 9.410632284814874, 9.524704719832526, 9.637427042525406, 9.748846085563153, 9.85900603509299, 9.96794863550169, 10.075713374247998, 10.182337649086286, 10.287856919689348, 10.392304845413264, 10.495713410721542, 10.598113039593416, 10.699532700076206, 10.8, 10.89954127475097, 10.998181667894016, 11.095945205344158, 11.19285486370658, 11.288932633336067, 11.384199576606164, 11.478675881825396, 11.572380913191546, 11.665333257134149, 11.757550765359255, 11.849050594878898, 11.939849245279438, 12.029962593458052, 12.119405926034494, 12.208193969625484, 12.296340919151518, 12.383860464330176, 12.470765814495916, 12.55706972187381, 12.642784503423288, 12.727922061357855, 12.812493902437575, 12.896511156122807, 12.979984591670364, 13.062924634246345, 13.14534138012399, 13.227244611029164, 13.308643807691302, 13.389548162652838, 13.46996659238619, 13.549907748763461, 13.62938002992066, 13.708391590555035, 13.78695035169127, 13.865064009949613, 13.942740046346701, 14.019985734657508, 14.096808149364879, 14.173214173221263, 14.249210504445502, 14.324803663575986, 14.4, 14.474805698177786, 14.549226783578568, 14.623269128344731, 14.696938456699069, 14.77024035010941], [0.0, 1.5, 2.121320343559643, 2.5980762113533165, 3.0, 3.354101966249685, 3.6742346141747677, 3.968626966596886, 4.242640687119286, 4.5, 4.743416490252569, 4.974937185533101, 5.196152422706633, 5.408326913195984, 5.612486080160912, 5.809475019311125, 6.0, 6.184658438426491, 6.363961030678928, 6.538348415311011, 6.70820393249937, 6.87386354243376, 7.035623639735145, 7.193747284969081, 7.348469228349535, 7.500000000000001, 7.6485292703891785, 7.794228634059949, 7.937253933193772, 8.077747210701757, 8.215838362577493, 8.351646544245034, 8.485281374238571, 8.616843969807045, 8.746427842267952, 8.874119674649425, 9.0, 9.124143795447331, 9.246621004453464, 9.367496997597598, 9.486832980505138, 9.604686356149275, 9.72111104761179, 9.836157786453, 9.949874371066201, 10.062305898749054, 10.173494974687904, 10.283481900601567, 10.392304845413266, 10.500000000000002, 10.606601717798213, 10.712142642814277, 10.816653826391969, 10.92016483392078, 11.022703842524303, 11.124297730643494, 11.224972160321824, 11.324751652906125, 11.423659658795865, 11.521718621802913, 11.61895003862225, 11.715374513859983, 11.811011811017716, 11.905880899790658, 12.0, 12.093386622447824, 12.186057606953941, 12.278029157808675, 12.369316876852983, 12.459935794377113, 12.549900398011134, 12.639224659764539, 12.727922061357855, 12.816005617976298, 12.903487900563942, 12.99038105676658, 13.076696830622023, 13.162446581088185, 13.247641299491773, 13.332291625973385, 13.41640786499874, 13.500000000000002, 13.583077707206126, 13.665650368716449, 13.74772708486752, 13.829316685939334, 13.910427743243558, 13.991068579633223, 14.07124727947029, 14.150971698084907, 14.230249470757707, 14.309088021254185, 14.387494569938163, 14.465476141489436, 14.543039572248988, 14.620191517213446, 14.69693845669907, 14.77328670269416, 14.849242404917497, 14.924811556599302, 15.000000000000002, 15.074813431681338], [0.0, 1.5297058540778354, 2.1633307652783937, 2.6495282598983545, 3.059411708155671, 3.420526275297415, 3.7469987990390394, 4.047221268969613, 4.3266615305567875, 4.589117562233506, 4.83735464897913, 5.073460357586329, 5.299056519796709, 5.515432893255071, 5.7236352085016735, 5.92452529743945, 6.118823416311342, 6.307138812488592, 6.489992295835181, 6.667833231267862, 6.84105255059483, 7.009992867328754, 7.17495644586084, 7.336211556382492, 7.493997598078079, 7.648529270389178, 7.800000000000002, 7.9485847796950635, 8.094442537939226, 8.23771813064759, 8.378544026261366, 8.517041739947034, 8.653323061113575, 8.787491109526087, 8.919641248391105, 9.049861877399014, 9.178235124467012, 9.304837451562495, 9.429740187301027, 9.553009996854396, 9.67470929795826, 9.794896630388706, 9.913626985114984, 10.030952098380292, 10.146920715172659, 10.261578825892242, 10.374969879474351, 10.487134975769122, 10.598113039593418, 10.70794097854485, 10.816653826391969, 10.924284873619877, 11.030865786510143, 11.136426715962353, 11.240996397117119, 11.344602240713423, 11.447270417003347, 11.549025932952096, 11.649892703368561, 11.749893616539683, 11.8490505948789, 11.947384651043928, 12.044915939930839, 12.141663806908838, 12.237646832622683, 12.33288287465668, 12.427389106324787, 12.521182052825523, 12.614277624977184, 12.706691150728423, 12.798437404620927, 12.889530635364501, 12.979984591670362, 13.06981254647518, 13.159027319676786, 13.24764129949177, 13.335666462535723, 13.423114392718258, 13.509996299037246, 13.596323032349593, 13.68210510118966, 13.767352686700521, 13.852075656738236, 13.936283579204321, 14.019985734657508, 14.103191128251794, 14.18590850104427, 14.268146340712939, 14.34991289172168, 14.431216164966834, 14.51206394693739, 14.592463808418373, 14.672423112764983, 14.751949023773099, 14.831048513169932, 14.909728367747013, 14.987995196156158, 15.065855435387666, 15.143315356948754, 15.22038107275899, 15.297058540778355, 15.373353570382752], [0.0, 1.5588457268119895, 2.2045407685048604, 2.7, 3.117691453623979, 3.4856850115866758, 3.818376618407357, 4.124318125460256, 4.409081537009721, 4.676537180435968, 4.929503017546495, 5.170106381884226, 5.4, 5.6204981985585585, 5.8326666285670745, 6.037383539249432, 6.235382907247958, 6.427285585688566, 6.613622305514581, 6.794850991743676, 6.9713700231733515, 7.143528539874395, 7.3116345641723655, 7.475961476626269, 7.636753236814714, 7.794228634059948, 7.9485847796950635, 8.100000000000001, 8.248636250920512, 8.394641147779934, 8.538149682454625, 8.67928568489366, 8.818163074019441, 8.954886933959582, 9.089554444525872, 9.222255689363639, 9.353074360871936, 9.482088377567466, 9.60937042682818, 9.734988443752773, 9.85900603509299, 9.981482855768476, 10.102474944289643, 10.222035022440492, 10.340212763768452, 10.457055034760026, 10.572606112023658, 10.686907878334125, 10.8, 10.911920087683928, 11.022703842524303, 11.132385189167685, 11.240996397117117, 11.348568191626644, 11.45512985522207, 11.560709320798617, 11.665333257134149, 11.76902714755982, 11.871815362445629, 11.973721226085063, 12.074767078498864, 12.174974332621815, 12.27436352728727, 12.372954376380768, 12.470765814495916, 12.567816039392048, 12.66412255152326, 12.759702190882043, 12.854571171377131, 12.948745112944342, 13.042239071570496, 13.135067567393783, 13.227244611029162, 13.31878372825387, 13.409697983176207, 13.5, 13.589701983487352, 13.678815738213599, 13.767352686700523, 13.85532388650659, 13.942740046346703, 14.029611541307908, 14.115948427222312, 14.20176045425355, 14.28705707974879, 14.371847480404185, 14.456140563788113, 14.539944979263161, 14.623269128344731, 14.706121174531374, 14.788509052639487, 14.870440477672476, 14.951922953252538, 15.032963779641063, 15.113570061372, 15.19374871452072, 15.273506473629428, 15.352849898308786, 15.431785379534022, 15.51031914565268, 15.588457268119896, 15.666205666976293], [0.0, 1.5874507866387544, 2.244994432064365, 2.749545416973504, 3.1749015732775088, 3.54964786985977, 3.8884444190447165, 4.2, 4.48998886412873, 4.762352359916263, 5.019960159204453, 5.264978632435274, 5.499090833947008, 5.723635208501674, 5.939696961966999, 6.148170459575758, 6.3498031465550175, 6.545227268781429, 6.734983296193095, 6.919537556802479, 7.09929573971954, 7.274613391789285, 7.445804187594515, 7.613146524269713, 7.776888838089433, 7.937253933193772, 8.094442537939226, 8.248636250920512, 8.4, 8.548684109265004, 8.694826047713663, 8.838551917593742, 8.97997772825746, 9.1192104921424, 9.256349172324908, 9.391485505499118, 9.524704719832526, 9.65608616365865, 9.785703858180055, 9.913626985114984, 10.039920318408907, 10.16464460765845, 10.287856919689348, 10.409610943738482, 10.529957264870548, 10.648943609579309, 10.766615066955817, 10.883014288330232, 10.998181667894016, 11.112155506471282, 11.224972160321824, 11.336666176614711, 11.447270417003349, 11.556816170554935, 11.665333257134149, 11.77285012220915, 11.879393923933998, 11.984990613262907, 12.089665007765932, 12.193440859740944, 12.296340919151517, 12.398386991863095, 12.499599993599794, 12.6, 12.699606293110035, 12.798437404620925, 12.896511156122806, 12.99384469662463, 13.090454537562858, 13.186356585501546, 13.281566172707194, 13.376098085764772, 13.46996659238619, 13.563185466548779, 13.65576801208925, 13.74772708486752, 13.839075113604958, 13.92982411949268, 14.01998573465751, 14.109571219565817, 14.19859147943908, 14.287057079748791, 14.374978260853128, 14.462364951832738, 14.54922678357857, 14.635573101180563, 14.721412975662359, 14.80675521510368, 14.89160837518903, 14.975980769218422, 15.05988047761336, 15.143315356948756, 15.226293048539427, 15.30882098660769, 15.390906406056793, 15.472556349873152, 15.553777676178866, 15.634577064954462, 15.714961024450552, 15.794935897305821, 15.874507866387544, 15.953682960370001], [0.0, 1.6155494421403513, 2.2847319317591728, 2.7982137159266447, 3.2310988842807027, 3.612478373637689, 3.957271787481876, 4.274342054632503, 4.5694638635183455, 4.846648326421054, 5.10881590977792, 5.358171329847527, 5.596427431853289, 5.82494635168428, 6.044832503882965, 6.256996084384263, 6.462197768561405, 6.661080993352356, 6.854195795277517, 7.042016756583303, 7.224956747275378, 7.40337760755184, 7.577598564189055, 7.747902942086976, 7.914543574963752, 8.077747210701757, 8.23771813064759, 8.394641147779934, 8.548684109265006, 8.700000000000001, 8.848728722251577, 8.994998610338971, 9.138927727036691, 9.280624978954814, 9.42019108086455, 9.557719393244396, 9.693296652842108, 9.827003612495522, 9.9589156036187, 10.089103032480143, 10.21763181955584, 10.344563789740002, 10.46995701996909, 10.593866149805745, 10.716342659695053, 10.837435120913067, 10.957189420649806, 11.07564896518484, 11.192854863706579, 11.30884609498246, 11.423659658795863, 11.537330713817648, 11.64989270336856, 11.761377470347597, 11.871815362445629, 11.981235328629515, 12.08966500776593, 12.197130810153674, 12.30365799264593, 12.409270727967861, 12.513992168768526, 12.617844506887856, 12.720849028268514, 12.823026163897508, 12.92439553712281, 13.024976007655447, 13.124785712536415, 13.223842104320514, 13.322161986704712, 13.419761547807026, 13.516656391282574, 13.612861565446114, 13.708391590555035, 13.80326048439281, 13.897481786280565, 13.991068579633223, 14.084033513166606, 14.176388820852793, 14.268146340712942, 14.359317532529184, 14.449913494550756, 14.539944979263163, 14.629422408283933, 14.718355886443295, 14.80675521510368, 14.894629904767694, 14.981989187020531, 15.068842025849234, 15.15519712837811, 15.241062955056647, 15.326447729333761, 15.411359446849588, 15.495805884173953, 15.579794607118545, 15.663332978647936, 15.746428166412851, 15.829087149927505, 15.911316727411347, 15.993123522314207, 16.07451398954258, 16.155494421403514, 16.236070953281775], [0.0, 1.6431676725154982, 2.32379000772445, 2.8460498941515415, 3.2863353450309964, 3.6742346141747673, 4.024922359499621, 4.347413023856832, 4.6475800154489, 4.9295030175464944, 5.196152422706632, 5.449770637375485, 5.692099788303083, 5.924525297439449, 6.148170459575758, 6.363961030678927, 6.572670690061993, 6.774953874381729, 6.97137002317335, 7.162401831787993, 7.3484692283495345, 7.529940238806679, 7.707139547199078, 7.880355321938219, 8.049844718999243, 8.215838362577491, 8.378544026261364, 8.538149682454625, 8.694826047713663, 8.848728722251575, 9.0, 9.148770409186143, 9.2951600308978, 9.439279633531365, 9.581231653602787, 9.72111104761179, 9.859006035092989, 9.99499874937461, 10.129165809680478, 10.261578825892242, 10.392304845413264, 10.52140675005011, 10.648943609579309, 10.77497099764078, 10.89954127475097, 11.022703842524301, 11.144505372604026, 11.26499001331115, 11.384199576606166, 11.502173707608488, 11.61895003862225, 11.734564329364769, 11.849050594878898, 11.962441222426133, 12.074767078498864, 12.18605760695394, 12.296340919151517, 12.405643876881198, 12.513992168768526, 12.621410380777576, 12.727922061357853, 12.833549781724463, 12.938315191708693, 13.042239071570494, 13.145341380123986, 13.247641299491768, 13.34915727677219, 13.449907062875935, 13.549907748763458, 13.64917579929279, 13.74772708486752, 13.84557691105719, 13.9427400463467, 14.039230748157108, 14.135062787267694, 14.230249470757705, 14.324803663575986, 14.4187378088375, 14.51206394693739, 14.604793733565701, 14.696938456699069, 14.788509052639485, 14.879516121164693, 14.969969939849577, 15.059880477613358, 15.149257407543118, 15.238110119040353, 15.32644772933376, 15.414279094398156, 15.501612819316575, 15.588457268119894, 15.674820573135756, 15.760710643876438, 15.84613517549311, 15.931101656822104, 16.015617378046965, 16.099689437998485, 16.183324751113414, 16.266530054071147, 16.349311912126456, 16.431676725154983, 16.513630733427465], [0.0, 1.6703293088490065, 2.3622023622035435, 2.8930952282978866, 3.340658617698013, 3.7349698793966204, 4.091454509095757, 4.419275958796871, 4.724404724407087, 5.01098792654702, 5.282045058497703, 5.539855593785817, 5.786190456595773, 6.022457969965419, 6.249799996799897, 6.469157595854347, 6.681317235396026, 6.886944169949398, 7.08660708661063, 7.280796659706959, 7.469939758793241, 7.654410493303844, 7.834538914320357, 8.010617953691215, 8.182909018191515, 8.351646544245034, 8.517041739947034, 8.67928568489366, 8.838551917593742, 8.99499861033897, 9.148770409186143, 9.3, 9.448809448814174, 9.595311355031686, 9.739609848448756, 9.881801455200362, 10.02197585309404, 10.160216533125661, 10.296601381038307, 10.431203190428226, 10.564090116995406, 10.695326081985533, 10.82497113160123, 10.953081758117209, 11.079711187571634, 11.204909638189859, 11.328724553099525, 11.451200810395388, 11.572380913191546, 11.692305161943047, 11.811011811017718, 11.928537211242627, 12.044915939930839, 12.160180919706747, 12.27436352728727, 12.387493693237547, 12.499599993599794, 12.610709734190221, 12.720849028268516, 12.830042868205858, 12.938315191708694, 13.04568894309534, 13.152186130069783, 13.257827876390612, 13.362634470792052, 13.466625412478063, 13.569819453478368, 13.672234638127009, 13.773888339898797, 13.874797295816613, 13.97497763862254, 14.07444492688788, 14.17321417322126, 14.271299870719556, 14.368716017793657, 14.465476141489432, 14.561593319413918, 14.65708020036733, 14.751949023773099, 14.846211637990347, 14.939879517586482, 15.032963779641062, 15.125475199146639, 15.217424223566876, 15.308820986607689, 15.39967532125272, 15.489996772110706, 15.579794607118542, 15.669077828640715, 15.757855184002675, 15.846135175493108, 15.933926069867402, 16.02123590738243, 16.10807251039056, 16.194443491518935, 16.280356261458163, 16.36581803638303, 16.450835845026237, 16.5354165354248, 16.619566781357452, 16.703293088490067, 16.78660180024534], [0.0, 1.697056274847714, 2.4, 2.939387691339814, 3.394112549695428, 3.7947331922020555, 4.156921938165306, 4.48998886412873, 4.8, 5.091168824543142, 5.366563145999495, 5.628498911788116, 5.878775382679628, 6.118823416311342, 6.349803146555017, 6.572670690061993, 6.788225099390856, 6.997142273814361, 7.199999999999999, 7.397296803562773, 7.589466384404111, 7.776888838089432, 7.95989949685296, 8.138795979750324, 8.313843876330612, 8.48528137423857, 8.653323061113575, 8.818163074019441, 8.97997772825746, 9.13892772703669, 9.2951600308978, 9.448809448814172, 9.6, 9.748846085563153, 9.895453501482386, 10.039920318408907, 10.182337649086284, 10.322790320451153, 10.461357464497617, 10.598113039593416, 10.73312629199899, 10.8664621657649, 10.998181667894016, 11.128342194594843, 11.256997823576231, 11.384199576606164, 11.509995655950528, 11.634431657799189, 11.757550765359255, 11.879393923933998, 12.0, 12.119405926034494, 12.237646832622683, 12.354756169184402, 12.470765814495916, 12.585706178041818, 12.699606293110033, 12.812493902437573, 12.92439553712281, 13.035336589440258, 13.145341380123986, 13.254433220624714, 13.362634470792052, 13.46996659238619, 13.576450198781712, 13.682105101189654, 13.786950351691267, 13.89100428334827, 13.994284547628721, 14.096808149364875, 14.198591479439079, 14.299650345375582, 14.399999999999999, 14.499655168313486, 14.598630072715727, 14.696938456699067, 14.794593607125545, 14.891608375189028, 14.987995196156158, 15.083766107971842, 15.178932768808222, 15.273506473629428, 15.367498169838838, 15.46091847207015, 15.553777676178864, 15.646085772486359, 15.737852458324804, 15.829087149927503, 15.91979899370592, 16.0099968769516, 16.099689437998485, 16.18888507587845, 16.277591959500647, 16.36581803638303, 16.453571040962505, 16.540858502508264, 16.627687752661224, 16.714065932620944, 16.799999999999997, 16.88549673536435, 16.97056274847714, 17.055204484262276], [0.0, 1.7233687939614086, 2.4372115213907883, 2.9849623113198605, 3.4467375879228173, 3.8535697735995393, 4.221374183841087, 4.559605246071199, 4.874423042781577, 5.170106381884226, 5.449770637375486, 5.715767664977296, 5.969924622639721, 6.213694553162394, 6.448255578061403, 6.674578638386096, 6.8934751758456345, 7.105631569396207, 7.311634564172365, 7.51199041532935, 7.707139547199079, 7.897467948652911, 8.083316151184489, 8.264986388373549, 8.442748367682174, 8.616843969807045, 8.787491109526087, 8.954886933959582, 9.119210492142399, 9.280624978954814, 9.439279633531365, 9.595311355031686, 9.748846085563153, 9.900000000000002, 10.048880534666537, 10.195587280779858, 10.340212763768452, 10.482843125793691, 10.623558725775466, 10.76243466879126, 10.899541274750971, 11.034944494649714, 11.168706281391772, 11.300884921102417, 11.431535329954592, 11.560709320798617, 11.688455843266896, 11.81482120050913, 11.939849245279442, 12.063581557729862, 12.186057606953943, 12.30731489805961, 12.427389106324789, 12.546314199795892, 12.664122551523262, 12.780845042484476, 12.896511156122806, 13.011149065320865, 13.124785712536417, 13.237446883746125, 13.349157276772193, 13.459940564504736, 13.56981945347837, 13.678815738213599, 13.786950351691269, 13.894243412291294, 14.000714267493642, 14.106381534610497, 14.211263138792415, 14.315376348528181, 14.4187378088375, 14.521363572337139, 14.62326912834473, 14.724469430169632, 14.824978920727006, 14.9248115565993, 15.0239808306587, 15.122499793354274, 15.220381072758991, 15.317636893463693, 15.414279094398157, 15.51031914565268, 15.605768164367946, 15.70063692975543, 15.794935897305821, 15.888675212238436, 15.981864722240648, 16.074513989542577, 16.166632302368978, 16.258228685807076, 16.349311912126456, 16.43989051058431, 16.529972776747098, 16.619566781357452, 16.708680378773185, 16.797321215003304, 16.88549673536435, 16.973214191778766, 17.060480649735517, 17.147302994931888, 17.23368793961409, 17.319642028633275], [0.0, 1.7492855684535902, 2.4738633753705965, 3.0298514815086235, 3.4985711369071804, 3.9115214431215897, 4.28485705712571, 4.628174586162454, 4.947726750741193, 5.24785670536077, 5.531726674375733, 5.801723881744115, 6.059702963017247, 6.307138812488591, 6.545227268781428, 6.774953874381729, 6.997142273814361, 7.212489168102785, 7.421590126111789, 7.624959016283301, 7.823042886243179, 8.016233529532432, 8.204876598706408, 8.38927887246574, 8.56971411425142, 8.74642784226795, 8.919641248391105, 9.089554444525872, 9.256349172324908, 9.42019108086455, 9.581231653602787, 9.739609848448756, 9.895453501482386, 10.048880534666537, 10.200000000000001, 10.348912986396204, 10.49571341072154, 10.64048871058092, 10.783320453366857, 10.924284873619875, 11.063453348751466, 11.200892821556684, 11.336666176614711, 11.470832576583096, 11.60344776348823, 11.734564329364767, 11.864231959971114, 11.99249765478401, 12.119405926034494, 12.244998979175133, 12.369316876852983, 12.49239768819421, 12.614277624977182, 12.734991166074677, 12.854571171377131, 12.973048986263793, 13.090454537562856, 13.206816421833084, 13.322161986704712, 13.436517405935215, 13.549907748763458, 13.66235704408284, 13.773888339898795, 13.884523758487362, 13.994284547628721, 14.10319112825179, 14.211263138792413, 14.318519476538068, 14.42497833620557, 14.530657245974801, 14.635573101180563, 14.739742195845896, 14.843180252223577, 14.945902448497382, 15.047923444781343, 15.149257407543116, 15.249918032566603, 15.34991856655924, 15.449271827500482, 15.547990223819927, 15.646085772486359, 15.743570116082314, 15.840454538932905, 15.93674998235211, 16.032467059064864, 16.12761606685874, 16.22220700151493, 16.316249569064578, 16.409753197412815, 16.50272704737008, 16.5951800231272, 16.687120782208055, 16.77855774493148, 16.86949910341146, 16.959952830123086, 17.049926686059386, 17.13942822850284, 17.22846481843348, 17.317043627594174, 17.405171645232347, 17.4928556845359, 17.580102388780336], [0.0, 1.7748239349298847, 2.5099800796022267, 3.0740852297878796, 3.5496478698597693, 3.9686269665968865, 4.347413023856832, 4.695742752749559, 5.019960159204453, 5.3244718047896535, 5.612486080160912, 5.886425061104576, 6.148170459575759, 6.3992187023104625, 6.640783086353596, 6.873863542433759, 7.099295739719539, 7.317786550590281, 7.529940238806679, 7.736278174936577, 7.937253933193773, 8.133265027035575, 8.324662155306966, 8.511756575466666, 8.694826047713663, 8.874119674649425, 9.049861877399014, 9.222255689363639, 9.391485505499118, 9.557719393244394, 9.72111104761179, 9.881801455200362, 10.039920318408907, 10.195587280779858, 10.348912986396204, 10.5, 10.648943609579307, 10.79583252926795, 10.940749517286282, 11.0837719211467, 11.224972160321824, 11.364418154925488, 11.502173707608488, 11.638298844762492, 11.772850122209151, 11.905880899790658, 12.037441588643327, 12.167579874403947, 12.296340919151518, 12.423767544509195, 12.549900398011134, 12.674778104566565, 12.798437404620925, 12.920913280414819, 13.042239071570496, 13.162446581088183, 13.281566172707192, 13.399626860476376, 13.516656391282574, 13.632681321002115, 13.747727084867519, 13.861818062577507, 13.974977638622539, 14.087228258248675, 14.198591479439077, 14.309088021254183, 14.418737808837498, 14.5275600153639, 14.635573101180562, 14.742794850366737, 14.849242404917499, 14.954932296737422, 15.059880477613358, 15.164102347320133, 15.267612779999366, 15.370426148939396, 15.472556349873154, 15.574016822900893, 15.67482057313576, 15.77498019016189, 15.874507866387546, 15.973415414368965, 16.07171428317465, 16.169415573854238, 16.26653005407115, 16.363068171953575, 16.459040069214247, 16.554455593585672, 16.64932431061393, 16.743655514850992, 16.837458240482736, 16.930741271426953, 17.023513150933333, 17.115782190715098, 17.207556479639983, 17.298843892006193, 17.389652095427326, 17.479988558348662, 17.569860557215584, 17.659275183313728, 17.74823934929885, 17.836759795433704], [0.0, 1.7999999999999998, 2.545584412271571, 3.117691453623979, 3.5999999999999996, 4.024922359499622, 4.409081537009721, 4.762352359916263, 5.091168824543142, 5.3999999999999995, 5.692099788303082, 5.96992462263972, 6.235382907247958, 6.48999229583518, 6.734983296193094, 6.97137002317335, 7.199999999999999, 7.421590126111789, 7.636753236814712, 7.846018098373213, 8.049844718999244, 8.248636250920512, 8.442748367682174, 8.632496741962896, 8.818163074019441, 9.0, 9.178235124467014, 9.353074360871938, 9.524704719832526, 9.693296652842108, 9.85900603509299, 10.02197585309404, 10.182337649086284, 10.340212763768452, 10.495713410721542, 10.648943609579309, 10.799999999999999, 10.948972554536796, 11.095945205344156, 11.240996397117117, 11.384199576606164, 11.525623627379128, 11.665333257134149, 11.803389343743598, 11.93984924527944, 12.074767078498864, 12.208193969625484, 12.340178280721878, 12.470765814495916, 12.6, 12.727922061357855, 12.854571171377131, 12.97998459167036, 13.104197800704934, 13.227244611029162, 13.349157276772193, 13.469966592386188, 13.589701983487348, 13.708391590555037, 13.826062346163493, 13.9427400463467, 14.058449416631978, 14.17321417322126, 14.28705707974879, 14.399999999999999, 14.512063946937388, 14.623269128344727, 14.733634989370408, 14.843180252223577, 14.951922953252534, 15.05988047761336, 15.167069591717445, 15.273506473629425, 15.379206741571556, 15.484185480676727, 15.588457268119894, 15.692036196746425, 15.794935897305821, 15.897169559390127, 15.99874995116806, 16.09968943799849, 16.2, 16.29969324864735, 16.398780442459735, 16.497272501841024, 16.5951800231272, 16.69251329189227, 16.789282295559865, 16.88549673536435, 16.981166037701886, 17.076299364909246, 17.17090562550502, 17.264993483925792, 17.35857136978732, 17.451647486698786, 17.544229820656135, 17.636326148038883, 17.72794404323299, 17.819090885900994, 17.90977386791916, 18.0, 18.089776118017607], [0.0, 1.8248287590894658, 2.5806975801127883, 3.160696125855822, 3.6496575181789317, 4.080441152620634, 4.469899327725402, 4.828043081829325, 5.1613951602255765, 5.474486277268397, 5.770615218501404, 6.052272300549605, 6.321392251711644, 6.579513659838393, 6.827884006044625, 7.067531393633848, 7.299315036357863, 7.523961722390672, 7.742092740338364, 7.954244150137712, 8.160882305241268, 8.362415918859814, 8.559205570612264, 8.751571287488895, 8.939798655450804, 9.12414379544733, 9.304837451562495, 9.482088377567466, 9.65608616365865, 9.82700361249552, 9.99499874937461, 10.160216533125661, 10.322790320451153, 10.482843125793691, 10.640488710580922, 10.79583252926795, 10.948972554536795, 11.100000000000001, 11.248999955551605, 11.396051947933548, 11.541230437002808, 11.68460525649027, 11.826242006656216, 11.966202405107477, 12.10454460109921, 12.241323457861899, 12.376590806841762, 12.510395677195826, 12.642784503423288, 12.773801313626263, 12.903487900563942, 13.031883977384085, 13.159027319676786, 13.28495389529072, 13.409697983176207, 13.533292282367952, 13.65576801208925, 13.777155003846042, 13.897481786280565, 14.0167756634684, 14.135062787267696, 14.252368224263645, 14.368716017793657, 14.484129245487974, 14.598630072715727, 14.712239802287074, 14.824978920727004, 14.936867141405523, 15.047923444781343, 15.158166115991737, 15.267612779999368, 15.3762804344874, 15.484185480676729, 15.59134375222354, 15.697770542341356, 15.803480629279107, 15.908488300275424, 16.012807374099022, 16.116451222275956, 16.219432789095926, 16.321764610482536, 16.423458831805196, 16.524527224704496, 16.624981202996892, 16.724831837719627, 16.824089871371946, 16.92276573140455, 17.02086954300514, 17.118411141224527, 17.215400082484287, 17.31184565550421, 17.407756891684812, 17.50314257497779, 17.59801125127496, 17.69237123734408, 17.786230629337965, 17.87959731090161, 17.972478960900194, 18.064883060789516, 18.156816901648817, 18.24828759089466, 18.339302058693516], [0.0, 1.849324200890693, 2.615339366124404, 3.203123475609394, 3.698648401781386, 4.135214625627067, 4.529900661162451, 4.892851929090027, 5.230678732248808, 5.547972602672078, 5.848076606885378, 6.133514490078262, 6.406246951218788, 6.667833231267861, 6.919537556802477, 7.162401831787993, 7.397296803562772, 7.624959016283301, 7.846018098373213, 8.061017305526644, 8.270429251254134, 8.474668135095321, 8.674099376880577, 8.869047299456692, 9.059801322324901, 9.246621004453464, 9.429740187301029, 9.609370426828182, 9.785703858180055, 9.9589156036187, 10.12916580968048, 10.29660138103831, 10.461357464497617, 10.623558725775466, 10.783320453366859, 10.940749517286282, 11.095945205344156, 11.248999955551605, 11.4, 11.549025932952096, 11.696153213770756, 11.841452613594333, 11.984990613262909, 12.126829758844641, 12.267028980156525, 12.4056438768812, 12.542726976220125, 12.678327965469263, 12.812493902437575, 12.945269406234852, 13.076696830622023, 13.206816421833086, 13.335666462535722, 13.463283403390127, 13.58970198348735, 13.714955340794953, 13.839075113604954, 13.962091533864116, 14.084033513166606, 14.204928722102057, 14.324803663575986, 14.443683740652869, 14.561593319413916, 14.678555787270083, 14.794593607125543, 14.909728367747013, 15.023980830658697, 15.137370973851437, 15.249918032566603, 15.36164053739053, 15.472556349873154, 15.582682695864664, 15.692036196746425, 15.800632898716431, 15.908488300275422, 16.01561737804697, 16.122034611053287, 16.22775400355823, 16.332789106579444, 16.43715303816327, 16.540858502508268, 16.64391780801624, 16.746342884343438, 16.848145298518766, 16.949336270190642, 17.04992668605939, 17.149927113547747, 17.24934781375806, 17.348198753761153, 17.446489618258454, 17.544229820656135, 17.641428513586987, 17.738094598913385, 17.83423673724222, 17.92986335698072, 18.02498266295976, 18.119602644649802, 18.213731083992652, 18.307375562870828, 18.40054347023479, 18.49324200890693, 18.585478202080253], [0.0, 1.8734993995195195, 2.6495282598983545, 3.244996147917591, 3.746998799039039, 4.189272013130683, 4.589117562233507, 4.956813492557492, 5.299056519796709, 5.6204981985585585, 5.92452529743945, 6.213694553162394, 6.489992295835182, 6.754998149518622, 7.009992867328753, 7.256031973468695, 7.493997598078078, 7.72463591375024, 7.948584779695063, 8.166394553289722, 8.378544026261366, 8.585452812752512, 8.787491109526087, 8.984987479123165, 9.178235124467014, 9.367496997597598, 9.553009996854396, 9.734988443752773, 9.913626985114984, 10.089103032480143, 10.261578825892244, 10.431203190428226, 10.598113039593418, 10.762434668791261, 10.924284873619877, 11.0837719211467, 11.240996397117117, 11.396051947933548, 11.549025932952095, 11.700000000000001, 11.8490505948789, 11.996249413879324, 12.141663806908838, 12.285357137665962, 12.427389106324789, 12.567816039392048, 12.706691150728425, 12.844064777164588, 12.979984591670364, 13.11449579663664, 13.247641299491772, 13.379461872586658, 13.509996299037244, 13.639281506003169, 13.767352686700521, 13.894243412291294, 14.019985734657507, 14.144610280951541, 14.26814634071294, 14.390621946253749, 14.51206394693739, 14.63249807790864, 14.751949023773097, 14.870440477672478, 14.987995196156156, 15.104635050208927, 15.220381072758986, 15.33525350295847, 15.44927182750048, 15.562454819211526, 15.67482057313576, 15.786386540307443, 15.897169559390125, 16.00718588634492, 16.116451222275952, 16.224980739587952, 16.332789106579444, 16.439890510584313, 16.546298679765215, 16.652026903653503, 16.757088052522732, 16.86149459567568, 16.965258618718433, 17.068391839889312, 17.170905625505025, 17.272811004581744, 17.374118682684315, 17.47483905505284, 17.574982219052174, 17.674557985986524, 17.773575892318352, 17.872045210327776, 17.96997495824633, 18.06737390989626, 18.164250603864726, 18.260613352239844, 18.356470248934027, 18.45182917761814, 18.54669781928848, 18.641083659487187, 18.734993995195197, 18.82843594141585], [0.0, 1.8973665961010275, 2.6832815729997477, 3.286335345030997, 3.794733192202055, 4.242640687119286, 4.6475800154489, 5.019960159204453, 5.366563145999495, 5.692099788303082, 6.0, 6.29285308902091, 6.572670690061994, 6.841052550594828, 7.099295739719539, 7.348469228349534, 7.58946638440411, 7.8230428862431785, 8.049844718999243, 8.270429251254134, 8.485281374238571, 8.694826047713663, 8.899438184514796, 9.099450532861862, 9.2951600308978, 9.486832980505138, 9.67470929795826, 9.85900603509299, 10.039920318408907, 10.21763181955584, 10.392304845413264, 10.564090116995406, 10.73312629199899, 10.899541274750971, 11.063453348751466, 11.224972160321824, 11.384199576606164, 11.541230437002808, 11.696153213770756, 11.8490505948789, 12.0, 12.149074038789953, 12.296340919151518, 12.44186481199663, 12.58570617804182, 12.727922061357855, 12.86856635371633, 13.007690033207279, 13.145341380123988, 13.281566172707194, 13.416407864998739, 13.54990774876346, 13.682105101189656, 13.813037319865607, 13.942740046346701, 14.071247279470288, 14.198591479439077, 14.324803663575986, 14.449913494550756, 14.573949361789342, 14.696938456699067, 14.818906842274163, 14.939879517586478, 15.05988047761336, 15.17893276880822, 15.297058540778353, 15.414279094398154, 15.53061492665374, 15.646085772486357, 15.760710643876436, 15.874507866387544, 15.987495113369073, 16.099689437998485, 16.211107303327555, 16.321764610482532, 16.431676725154983, 16.540858502508268, 16.64932431061393, 16.757088052522732, 16.864163187066236, 16.970562748477143, 17.07629936490925, 17.181385275931625, 17.28583234906552, 17.389652095427326, 17.492855684535904, 17.59545395833822, 17.69745744450315, 17.798876369029593, 17.899720668211557, 18.0, 18.099723754798028, 18.198901065723724, 18.29754081837229, 18.39565166010707, 18.49324200890693, 18.5903200617956, 18.686893802876927, 18.78297101099823, 18.87855926706273, 18.973665961010276, 19.068298298484848], [0.0, 1.9209372712298547, 2.716615541441225, 3.3271609519228256, 3.8418745424597094, 4.295346318982907, 4.705316142407437, 5.082322303829225, 5.43323108288245, 5.762811813689564, 6.074537019394977, 6.3710281744785915, 6.654321903845651, 6.926037828369118, 7.187489130426564, 7.439758060582347, 7.683749084919419, 7.920227269466452, 8.149846624323676, 8.373171442171719, 8.590692637965814, 8.802840450672727, 9.009994450608726, 9.212491519670454, 9.410632284814874, 9.604686356149275, 9.794896630388706, 9.981482855768476, 10.16464460765845, 10.344563789740002, 10.52140675005011, 10.695326081985533, 10.8664621657649, 11.034944494649714, 11.200892821556684, 11.364418154925488, 11.525623627379128, 11.68460525649027, 11.841452613594331, 11.996249413879324, 12.149074038789953, 12.300000000000002, 12.449096352747858, 12.596428065130208, 12.742056348957183, 12.886038956948719, 13.02843045036508, 13.16928244058878, 13.308643807691302, 13.446560898608984, 13.583077707206126, 13.718236038208413, 13.852075656738236, 13.984634424968, 14.115948427222312, 14.24605208470052, 14.374978260853128, 14.502758358326185, 14.629422408283933, 14.754999152829525, 14.879516121164693, 15.002999700059988, 15.125475199146637, 15.246966911487677, 15.367498169838838, 15.487091398968369, 15.605768164367943, 15.72354921765439, 15.840454538932905, 15.95650337636664, 16.07171428317465, 16.186105152259454, 16.29969324864735, 16.412495239907916, 16.524527224704496, 16.635804759614125, 16.746342884343438, 16.85615614545618, 16.965258618718437, 17.073663930158638, 17.18138527593163, 17.288435441068696, 17.39482681718907, 17.500571419242288, 17.605680901345455, 17.710166571774533, 17.81403940716423, 17.917310065966934, 18.019988901217452, 18.122085972646747, 18.22361105818493, 18.324573664890544, 18.42498303934091, 18.524848177515523, 18.62417783420251, 18.722980531955912, 18.821264569629747, 18.91903803051308, 19.016308790088576, 19.113084523435774, 19.20937271229855, 19.305180651835407], [0.0, 1.9442222095223582, 2.749545416973504, 3.3674916480965478, 3.8884444190447165, 4.3474130238568325, 4.762352359916264, 5.143928459844674, 5.499090833947008, 5.8326666285670745, 6.148170459575759, 6.448255578061405, 6.7349832961930955, 7.009992867328754, 7.274613391789285, 7.52994023880668, 7.776888838089433, 8.016233529532434, 8.248636250920512, 8.474668135095323, 8.694826047713665, 8.909545442950499, 9.1192104921424, 9.324162160752035, 9.524704719832528, 9.72111104761179, 9.913626985114986, 10.102474944289643, 10.287856919689348, 10.46995701996909, 10.64894360957931, 10.824971131601231, 10.998181667894016, 11.168706281391774, 11.336666176614713, 11.50217370760849, 11.665333257134149, 11.826242006656216, 11.984990613262909, 12.14166380690884, 12.296340919151518, 12.44909635274786, 12.600000000000001, 12.749117616525465, 12.89651115612281, 13.042239071570496, 13.186356585501548, 13.328915934913837, 13.469966592386191, 13.60955546665651, 13.747727084867522, 13.884523758487363, 14.019985734657508, 14.154151334502542, 14.287057079748791, 14.4187378088375, 14.54922678357857, 14.678555787270083, 14.806755215103683, 14.93385415758437, 15.05988047761336, 15.184860881812519, 15.308820986607689, 15.431785379534023, 15.553777676178866, 15.674820573135758, 15.79493589730582, 15.914144651849814, 16.032467059064867, 16.149922600433726, 16.266530054071154, 16.382307529771257, 16.497272501841024, 16.611441839888556, 16.724831837719627, 16.837458240482736, 16.949336270190646, 17.06048064973552, 17.170905625505025, 17.280624988697603, 17.38965209542733, 17.497999885701226, 17.605680901345455, 17.712707302950612, 17.819090885900998, 17.92484309554759, 18.029975041580066, 18.1344975116489, 18.2384209842848, 18.341755641159327, 18.444511378727277, 18.54669781928848, 18.64832432150407, 18.7493999903997, 18.84993368688601, 18.94993403682451, 19.049409439665055, 19.148368076679542, 19.24681791881453, 19.344766734184212, 19.44222209522358, 19.539191385520542], [0.0, 1.9672315572906, 2.782085548648711, 3.407345007480164, 3.9344631145812, 4.398863489584555, 4.818713521262703, 5.204805471869242, 5.564171097297422, 5.901694671871799, 6.220932405998315, 6.524568951279464, 6.814690014960328, 7.092954250522133, 7.360706487831177, 7.619055059520175, 7.8689262291624, 8.111103500757464, 8.346256645946132, 8.574963556773872, 8.79772697916911, 9.014987520790031, 9.227133899537819, 9.434511116109833, 9.637427042525406, 9.836157786453, 10.030952098380293, 10.222035022440492, 10.409610943738484, 10.593866149805745, 10.774970997640782, 10.953081758117209, 11.128342194594843, 11.30088492110242, 11.470832576583097, 11.638298844762494, 11.803389343743598, 11.96620240510748, 12.126829758844641, 12.285357137665962, 12.44186481199663, 12.59642806513021, 12.749117616525465, 12.899999999999997, 13.049137902558927, 13.19659046875366, 13.34241357476225, 13.486660075793411, 13.629380029920656, 13.770620901034201, 13.910427743243556, 14.048843368761714, 14.185908501044265, 14.321661914736014, 14.456140563788109, 14.589379698945393, 14.721412975662354, 14.852272553383875, 14.981989187020528, 15.110592311355632, 15.23811011904035, 15.364569632762253, 15.4899967721107, 15.614416415607725, 15.7378524583248, 15.860327865463562, 15.98186472224064, 16.102484280383567, 16.222207001514928, 16.341052597675585, 16.459040069214243, 16.576187740249566, 16.692513291892265, 16.808033793397726, 16.922765731404542, 17.036725037400817, 17.149927113547744, 17.262386856978964, 17.374118682684312, 17.485136545077363, 17.59545395833822, 17.7050840156154, 17.814039407164227, 17.922332437492614, 18.029975041580062, 18.13697880023021, 18.243354954612926, 18.34911442004763, 18.454267799075637, 18.558825393865853, 18.662797217994946, 18.766193007640094, 18.869022232219667, 18.971294104514854, 19.073017590302797, 19.17420141752975, 19.274854085050812, 19.37498387096103, 19.474598840540974, 19.57370685383839, 19.672315572906, 19.77043246871449], [0.0, 1.98997487421324, 2.814249455894058, 3.4467375879228177, 3.97994974842648, 4.449719092257399, 4.874423042781577, 5.264978632435274, 5.628498911788116, 5.969924622639719, 6.29285308902091, 6.600000000000001, 6.893475175845635, 7.17495644586084, 7.445804187594514, 7.707139547199078, 7.95989949685296, 8.204876598706406, 8.442748367682174, 8.674099376880578, 8.899438184514798, 9.119210492142399, 9.333809511662428, 9.543584232352122, 9.748846085563153, 9.949874371066201, 10.14692071517266, 10.340212763768452, 10.529957264870548, 10.716342659695052, 10.899541274750971, 11.079711187571634, 11.256997823576231, 11.431535329954592, 11.603447763488232, 11.772850122209151, 11.939849245279438, 12.10454460109921, 12.267028980156525, 12.427389106324789, 12.58570617804182, 12.742056348957183, 12.896511156122807, 13.049137902558927, 13.200000000000003, 13.349157276772194, 13.496666255042392, 13.642580401082487, 13.78695035169127, 13.92982411949268, 14.07124727947029, 14.211263138792416, 14.34991289172168, 14.487235761179566, 14.623269128344731, 14.758048651498612, 14.891608375189028, 15.023980830658699, 15.15519712837811, 15.285287043428397, 15.414279094398156, 15.542200616386344, 15.669077828640715, 15.794935897305821, 15.91979899370592, 16.043690348545127, 16.166632302368974, 16.288646352597873, 16.40975319741281, 16.529972776747094, 16.64932431061393, 16.767826334978544, 16.88549673536435, 17.002352778365704, 17.118411141224527, 17.233687939614086, 17.348198753761157, 17.4619586530263, 17.574982219052178, 17.687283567580412, 17.798876369029596, 17.909773867919164, 18.01998890121745, 18.12953391568575, 18.238420984284797, 18.346661821704792, 18.45426779907564, 18.561249957909624, 18.667619023324857, 18.77338541659442, 18.87855926706273, 18.983150423467652, 19.087168464704245, 19.190622710063376, 19.293522228976233, 19.39587585029354, 19.497692171126307, 19.598979565273293, 19.699746191258402, 19.800000000000004, 19.899748742132402, 19.998999974998757], [0.0, 2.0124611797498106, 2.846049894151541, 3.4856850115866753, 4.024922359499621, 4.5, 4.9295030175464944, 5.324471804789654, 5.692099788303082, 6.037383539249431, 6.363961030678928, 6.674578638386096, 6.971370023173351, 7.256031973468694, 7.529940238806678, 7.794228634059946, 8.049844718999243, 8.297590011563598, 8.538149682454623, 8.772114910328067, 9.0, 9.222255689363637, 9.439279633531363, 9.65142476528725, 9.859006035092989, 10.062305898749052, 10.261578825892242, 10.457055034760025, 10.648943609579309, 10.837435120913065, 11.022703842524301, 11.204909638189859, 11.384199576606164, 11.560709320798617, 11.734564329364767, 11.905880899790658, 12.074767078498862, 12.241323457861899, 12.405643876881198, 12.567816039392046, 12.727922061357855, 12.886038956948719, 13.042239071570494, 13.196590468753659, 13.349157276772193, 13.499999999999998, 13.64917579929279, 13.796738745080301, 13.942740046346701, 14.087228258248675, 14.230249470757707, 14.371847480404181, 14.512063946937388, 14.650938536489736, 14.788509052639485, 14.924811556599298, 15.059880477613357, 15.193748714520718, 15.326447729333761, 15.458007633585899, 15.588457268119893, 15.717824276915682, 15.846135175493107, 15.973415414368962, 16.099689437998485, 16.22498073958795, 16.349311912126453, 16.47270469595081, 16.595180023127195, 16.716758058906038, 16.837458240482736, 16.957299313275094, 17.076299364909246, 17.19447585708852, 17.311845655504207, 17.428425057933374, 17.544229820656135, 17.659275183313724, 17.773575892318352, 17.88714622291661, 18.0, 18.112150617748295, 18.22361105818493, 18.334393908717022, 18.444511378727274, 18.553975315279473, 18.66279721799495, 18.770988253152787, 18.878559267062727, 18.985520798756088, 19.09188309203678, 19.197656106931387, 19.3028495305745, 19.407472787563044, 19.511535049810917, 19.61504524593303, 19.718012070185978, 19.820443990990718, 19.922349259060788, 20.02373591515829, 20.124611797498105, 20.224984548819812], [0.0, 2.0346989949375804, 2.877498913987632, 3.5242020373412197, 4.069397989875161, 4.549725266430931, 4.983974317750845, 5.383307533477908, 5.754997827975264, 6.104096984812741, 6.434283176858165, 6.748333127521196, 7.0484040746824395, 7.336211556382491, 7.613146524269712, 7.880355321938218, 8.138795979750322, 8.389278872465738, 8.632496741962894, 8.86904729945669, 9.099450532861862, 9.324162160752032, 9.54358423235212, 9.758073580374358, 9.96794863550169, 10.173494974687904, 10.374969879474351, 10.572606112023658, 10.766615066955817, 10.957189420649804, 11.144505372604026, 11.328724553099525, 11.509995655950528, 11.688455843266896, 11.864231959971114, 12.037441588643329, 12.208193969625482, 12.376590806841763, 12.542726976220123, 12.706691150728423, 12.86856635371633, 13.02843045036508, 13.186356585501548, 13.342413574762249, 13.496666255042392, 13.649175799292792, 13.8, 13.949193525075204, 14.096808149364879, 14.242892964563065, 14.38749456993816, 14.530657245974803, 14.672423112764982, 14.812832274754212, 14.951922953252536, 15.08973160795115, 15.226293048539423, 15.36164053739053, 15.495805884173953, 15.628819533157326, 15.760710643876436, 15.891507165778835, 16.021235907382426, 16.149922600433726, 16.277591959500644, 16.40426773739078, 16.529972776747094, 16.65472905813841, 16.778557744931476, 16.90147922520393, 17.02351315093333, 17.14467847467546, 17.26499348392579, 17.384475833340503, 17.503142574977787, 17.621010186706094, 17.73809459891338, 17.854411219639815, 17.96997495824633, 18.084800247721844, 18.198901065723724, 18.312290954438225, 18.424983039340905, 18.536990046930487, 18.648324321504063, 18.75899784103618, 18.869022232219667, 18.978408784721655, 19.08716846470424, 19.19531192765567, 19.302849530574495, 19.409791343546175, 19.516147160748716, 19.6219265109214, 19.727138667328315, 19.83179265724609, 19.93589727100338, 20.039461070597685, 20.142492397913422, 20.24499938256359, 20.346989949375807, 20.448471825542374], [0.0, 2.056696380120313, 2.9086079144497976, 3.5623026261113755, 4.113392760240626, 4.5989129150267685, 5.037856687124, 5.441507144165117, 5.817215828899595, 6.170089140360939, 6.5038450166036395, 6.821290200541244, 7.124605252222751, 7.415524256584965, 7.6954532030283955, 7.965550828411051, 8.226785520481252, 8.479976415061541, 8.725823743349393, 8.964931678490363, 9.197825830053537, 9.424966843443006, 9.646761114488116, 9.86356933366416, 10.075713374248, 10.283481900601567, 10.487134975769122, 10.686907878334127, 10.883014288330234, 11.07564896518484, 11.264990013311152, 11.451200810395388, 11.63443165779919, 11.814821200509131, 11.992497654784012, 12.167579874403948, 12.340178280721878, 12.510395677195827, 12.678327965469263, 12.844064777164588, 13.007690033207279, 13.169282440588782, 13.328915934913837, 13.486660075793411, 13.642580401082489, 13.796738745080303, 13.949193525075204, 14.1, 14.249210504445502, 14.396874660842194, 14.543039572248988, 14.687749997872379, 14.83104851316993, 14.972975656161339, 15.113570061372, 15.252868582663393, 15.390906406056791, 15.527717153529041, 15.663332978647936, 15.797784654817901, 15.931101656822102, 16.063312236273067, 16.194443491518935, 16.32452143249535, 16.453571040962505, 16.581616326522575, 16.708680378773185, 16.83478541591784, 16.959952830123083, 17.08420322988462, 17.207556479639987, 17.330031736843416, 17.451647486698786, 17.572421574728967, 17.692371237344076, 17.811513130556875, 17.929863356980725, 18.047437491234042, 18.164250603864726, 18.280317283898547, 18.395651660107074, 18.510267421082823, 18.62417783420251, 18.737395763552627, 18.84993368688601, 18.961803711672584, 19.0730175903028, 19.1835867344978, 19.293522228976233, 19.402834844424152, 19.51153504981092, 19.619633024090945, 19.72713866732832, 19.834061611278717, 19.94041122946064, 20.046196646745734, 20.151426748496, 20.25611018927376, 20.36025540114858, 20.463870601623732, 20.566963801203133, 20.669542810618726], [0.0, 2.078460969082653, 2.9393876913398143, 3.6000000000000005, 4.156921938165306, 4.647580015448901, 5.091168824543143, 5.499090833947009, 5.8787753826796285, 6.235382907247958, 6.572670690061994, 6.893475175845635, 7.200000000000001, 7.493997598078079, 7.776888838089433, 8.049844718999243, 8.313843876330612, 8.569714114251422, 8.818163074019441, 9.059801322324901, 9.295160030897803, 9.524704719832528, 9.748846085563155, 9.967948635501692, 10.182337649086286, 10.392304845413266, 10.598113039593418, 10.800000000000002, 10.998181667894018, 11.19285486370658, 11.384199576606168, 11.572380913191548, 11.757550765359257, 11.939849245279442, 12.119405926034496, 12.29634091915152, 12.470765814495916, 12.64278450342329, 12.812493902437575, 12.979984591670364, 13.145341380123988, 13.308643807691304, 13.469966592386191, 13.629380029920656, 13.78695035169127, 13.942740046346703, 14.096808149364879, 14.249210504445502, 14.400000000000002, 14.549226783578572, 14.69693845669907, 14.843180252223581, 14.987995196156158, 15.131424255502193, 15.273506473629428, 15.414279094398156, 15.553777676178866, 15.692036196746427, 15.829087149927506, 15.964961634780087, 16.099689437998485, 16.233299110162424, 16.36581803638303, 16.497272501841028, 16.627687752661224, 16.75708805252273, 16.88549673536435, 17.01293625450939, 17.139428228502844, 17.264993483925792, 17.38965209542733, 17.51342342319171, 17.636326148038883, 17.758378304338493, 17.87959731090161, 18.0, 18.119602644649802, 18.2384209842848, 18.35647024893403, 18.473765182008787, 18.590320061795605, 18.70614872174388, 18.82126456962975, 18.9356806056714, 19.049409439665055, 19.16246330720558, 19.27485408505082, 19.386593305684215, 19.49769217112631, 19.608161566041833, 19.71801207018598, 19.82725397022997, 19.935897271003384, 20.043951706188086, 20.151426748496, 20.25833161936096, 20.36467529817257, 20.470466531078383, 20.575713839378697, 20.680425527536908, 20.78460969082653, 20.888274222635058], [0.0, 2.1, 2.9698484809834995, 3.6373066958946425, 4.2, 4.695742752749559, 5.143928459844674, 5.55607775323564, 5.939696961966999, 6.299999999999999, 6.640783086353597, 6.96491205974634, 7.274613391789285, 7.571657678474377, 7.857480512225276, 8.133265027035575, 8.4, 8.658521813797087, 8.909545442950499, 9.153687781435416, 9.391485505499118, 9.623408959407264, 9.849873095629203, 10.071246198956713, 10.287856919689348, 10.5, 10.70794097854485, 10.911920087683928, 11.11215550647128, 11.308846094982458, 11.502173707608488, 11.692305161943047, 11.879393923933998, 12.063581557729862, 12.244998979175133, 12.423767544509195, 12.599999999999998, 12.773801313626262, 12.94526940623485, 13.114495796636637, 13.281566172707194, 13.446560898608983, 13.609555466656508, 13.7706209010342, 13.92982411949268, 14.087228258248675, 14.242892964563064, 14.396874660842192, 14.54922678357857, 14.700000000000001, 14.849242404917499, 14.996999699939987, 15.143315356948754, 15.28823076748909, 15.431785379534023, 15.574016822900893, 15.714961024450552, 15.854652314068574, 15.993123522314209, 16.130406070524078, 16.26653005407115, 16.401524319403975, 16.5354165354248, 16.66823325970692, 16.8, 16.930741271426953, 17.060480649735517, 17.189240820932145, 17.317043627594174, 17.443910112127956, 17.569860557215588, 17.694914523670352, 17.819090885900998, 17.942407865166814, 18.064883060789516, 18.186533479473212, 18.30737556287083, 18.42742521352346, 18.546697819288482, 18.665208276362737, 18.782971010998235, 18.900000000000002, 19.016308790088576, 19.131910516203025, 19.24681791881453, 19.361043360315065, 19.47459884054098, 19.58749601148651, 19.699746191258406, 19.811360377318866, 19.92234925906079, 20.03272322975586, 20.142492397913426, 20.251666598085208, 20.36025540114858, 20.468268124098824, 20.575713839378697, 20.68260138377182, 20.788939366884495, 20.894736179239022, 21.0, 21.104738804353875], [0.0, 2.1213203435596424, 3.0, 3.6742346141747677, 4.242640687119285, 4.74341649025257, 5.196152422706632, 5.612486080160912, 6.0, 6.363961030678928, 6.708203932499369, 7.035623639735145, 7.348469228349535, 7.648529270389178, 7.937253933193771, 8.215838362577491, 8.48528137423857, 8.746427842267952, 9.0, 9.246621004453466, 9.48683298050514, 9.72111104761179, 9.949874371066201, 10.173494974687905, 10.392304845413264, 10.606601717798213, 10.81665382639197, 11.022703842524303, 11.224972160321824, 11.423659658795863, 11.618950038622252, 11.811011811017718, 12.0, 12.186057606953943, 12.369316876852983, 12.549900398011134, 12.727922061357855, 12.903487900563942, 13.076696830622021, 13.247641299491772, 13.416407864998739, 13.583077707206126, 13.74772708486752, 13.910427743243554, 14.07124727947029, 14.230249470757707, 14.38749456993816, 14.543039572248986, 14.69693845669907, 14.849242404917499, 15.000000000000002, 15.14925740754312, 15.297058540778355, 15.443445211480503, 15.588457268119896, 15.732132722552274, 15.874507866387543, 16.01561737804697, 16.155494421403514, 16.294170736800325, 16.431676725154983, 16.56804152578089, 16.703293088490067, 16.837458240482736, 16.97056274847714, 17.102631376487068, 17.233687939614086, 17.363755354185336, 17.492855684535904, 17.621010186706098, 17.74823934929885, 17.874562931719478, 18.0, 18.12456896039186, 18.24828759089466, 18.371173070873837, 18.493242008906932, 18.61451046898629, 18.7349939951952, 18.854707634964804, 18.97366596101028, 19.091883092036785, 19.20937271229855, 19.32614809008769, 19.44222209522358, 19.55760721560795, 19.672315572906005, 19.78635893740938, 19.899748742132402, 20.0124960961895, 20.12461179749811, 20.236106344848064, 20.34698994937581, 20.457272545478787, 20.566963801203133, 20.676073128135332, 20.784609690826528, 20.892582415776182, 21.0, 21.106870919205438, 21.213203435596427, 21.31900560532785], [0.0, 2.142428528562855, 3.029851481508624, 3.7107950630558952, 4.28485705712571, 4.790615826801394, 5.247856705360771, 5.668333088307356, 6.059702963017248, 6.427285585688565, 6.77495387438173, 7.105631569396208, 7.4215901261117905, 7.72463591375024, 8.016233529532432, 8.2975900115636, 8.56971411425142, 8.833459118601276, 9.08955444452587, 9.33862944976403, 9.581231653602789, 9.817840903172144, 10.048880534666537, 10.274726273726229, 10.495713410721542, 10.712142642814277, 10.924284873619877, 11.132385189167685, 11.336666176614711, 11.537330713817648, 11.734564329364769, 11.928537211242627, 12.119405926034496, 12.307314898059612, 12.492397688194211, 12.674778104566567, 12.85457117137713, 13.031883977384085, 13.206816421833084, 13.379461872586656, 13.54990774876346, 13.718236038208413, 13.884523758487363, 14.048843368761714, 14.211263138792416, 14.371847480404183, 14.530657245974803, 14.687749997872377, 14.843180252223581, 14.996999699939987, 15.14925740754312, 15.300000000000002, 15.44927182750048, 15.597115117867153, 15.743570116082314, 15.888675212238434, 16.032467059064864, 16.174980680050286, 16.31624956906458, 16.456305782282975, 16.5951800231272, 16.73290172086121, 16.86949910341146, 17.004999264922066, 17.13942822850284, 17.27281100458174, 17.405171645232347, 17.53653329481058, 17.66691823720255, 17.79634793995667, 17.92484309554759, 18.052423659996464, 18.17910888905174, 18.30491737211616, 18.429867064089205, 18.553975315279473, 18.67725889952806, 18.79973404067196, 18.92141643746578, 19.04232128707002, 19.162463307205577, 19.2818567570657, 19.400515457069694, 19.518452807535745, 19.635681806344287, 19.752215065657833, 19.868064827758143, 19.983242980057067, 20.097761069333075, 20.21163031524177, 20.32486162314519, 20.437465596301323, 20.549452547452457, 20.6608325098482, 20.771615247736516, 20.881810266353828, 20.991426821443085, 21.100473928326828, 21.208960370560362, 21.316894708188624, 21.424285285628553, 21.531140239197743], [0.0, 2.1633307652783937, 3.0594117081556713, 3.7469987990390394, 4.3266615305567875, 4.83735464897913, 5.299056519796709, 5.723635208501674, 6.118823416311343, 6.48999229583518, 6.841052550594828, 7.17495644586084, 7.493997598078079, 7.800000000000001, 8.094442537939225, 8.378544026261364, 8.653323061113575, 8.919641248391104, 9.178235124467014, 9.429740187301029, 9.67470929795826, 9.913626985114984, 10.146920715172659, 10.374969879474351, 10.598113039593418, 10.816653826391969, 11.030865786510143, 11.240996397117119, 11.447270417003349, 11.649892703368561, 11.8490505948789, 12.04491593993084, 12.237646832622685, 12.42738910632479, 12.614277624977184, 12.798437404620927, 12.97998459167036, 13.159027319676786, 13.335666462535722, 13.509996299037244, 13.682105101189656, 13.852075656738236, 14.019985734657508, 14.185908501044265, 14.34991289172168, 14.51206394693739, 14.672423112764982, 14.83104851316993, 14.987995196156158, 15.143315356948756, 15.297058540778357, 15.449271827500482, 15.600000000000001, 15.749285698088027, 15.897169559390125, 16.043690348545127, 16.18888507587845, 16.33278910657944, 16.47543626129518, 16.616858908951475, 16.75708805252273, 16.89615340839447, 17.03408347989407, 17.17090562550502, 17.30664612222715, 17.44133022449836, 17.57498221905217, 17.70762547604845, 17.839282496782207, 17.969974958246326, 18.099723754798028, 18.228549037155975, 18.356470248934027, 18.483506160899235, 18.60967490312499, 18.734993995195197, 18.859480374602057, 18.983150423467652, 19.106019993708795, 19.22810443075448, 19.34941859591652, 19.469976887505545, 19.589793260777412, 19.70888124678821, 19.827253970229968, 19.944924166313598, 20.06190419676059, 20.178206064960285, 20.293841430345317, 20.40882162203394, 20.523157651784484, 20.63686022630381, 20.749939758948702, 20.862406380856456, 20.974269951538243, 21.085540068966697, 21.196226079186836, 21.306337085477647, 21.415881957089695, 21.52486933758252, 21.633307652783937, 21.74120511839213], [0.0, 2.1840329667841556, 3.0886890422961004, 3.782856063875548, 4.368065933568311, 4.883646178829913, 5.349766350038103, 5.7784080852774675, 6.177378084592201, 6.552098900352466, 6.906518659932804, 7.243617880589783, 7.565712127751096, 7.8746428490440135, 8.171903083125741, 8.45872330792301, 8.736131867136622, 9.004998611882181, 9.2660671268883, 9.51997899157346, 9.767292357659827, 10.008496390567368, 10.244022647378326, 10.474254150057657, 10.699532700076206, 10.92016483392078, 11.136426715962354, 11.348568191626644, 11.556816170554935, 11.761377470347597, 11.962441222426133, 12.160180919706747, 12.354756169184402, 12.546314199795894, 12.734991166074677, 12.920913280414819, 13.104197800704933, 13.28495389529072, 13.463283403390127, 13.639281506003169, 13.813037319865607, 13.984634424968, 14.15415133450254, 14.321661914736012, 14.487235761179566, 14.650938536489736, 14.812832274754212, 14.972975656161337, 15.131424255502193, 15.288230767489091, 15.443445211480503, 15.597115117867153, 15.749285698088027, 15.900000000000004, 16.04929905011431, 16.197221984031707, 16.343806166251483, 16.489087300393557, 16.633099530754937, 16.77587553601898, 16.91744661584602, 17.057842770995403, 17.197092777559817, 17.3352242558324, 17.472263734273245, 17.608236708995026, 17.743167699145495, 17.8770802985275, 18.009997223764362, 18.141940359289027, 18.272930799409277, 18.402988887678003, 18.5321342537766, 18.660385848100784, 18.787761974221414, 18.91428031937774, 19.03995798314692, 19.16481150442133, 19.288856886814216, 19.412109622604138, 19.534584715319653, 19.656296701057403, 19.777259668619415, 19.897487278548518, 20.016992781134736, 20.135789033459808, 20.253888515541902, 20.371303345637955, 20.488045294756652, 20.604125800431333, 20.71955597979841, 20.8343466420236, 20.948508300115314, 21.062051182161728, 21.174985242025556, 21.28732016952815, 21.399065400152413, 21.51023012429203, 21.6208232960727, 21.73085364176935, 21.84032966784156, 21.949259668608423], [0.0, 2.2045407685048604, 3.1176914536239795, 3.818376618407357, 4.409081537009721, 4.929503017546496, 5.4, 5.8326666285670745, 6.235382907247959, 6.61362230551458, 6.971370023173351, 7.3116345641723655, 7.636753236814714, 7.948584779695063, 8.248636250920512, 8.538149682454623, 8.818163074019441, 9.08955444452587, 9.353074360871938, 9.609370426828182, 9.859006035092992, 10.102474944289643, 10.340212763768452, 10.57260611202366, 10.8, 11.022703842524303, 11.240996397117119, 11.45512985522207, 11.665333257134149, 11.871815362445627, 12.074767078498866, 12.27436352728727, 12.470765814495918, 12.664122551523262, 12.854571171377131, 13.042239071570496, 13.22724461102916, 13.409697983176207, 13.58970198348735, 13.76735268670052, 13.942740046346701, 14.115948427222312, 14.28705707974879, 14.456140563788107, 14.623269128344731, 14.788509052639485, 14.951922953252536, 15.113570061371998, 15.273506473629428, 15.431785379534023, 15.588457268119896, 15.743570116082314, 15.897169559390125, 16.04929905011431, 16.200000000000003, 16.349311912126456, 16.497272501841024, 16.643917808016237, 16.789282295559868, 16.9333989500041, 17.076299364909246, 17.218013822738094, 17.35857136978732, 17.497999885701223, 17.636326148038883, 17.77357589231835, 17.90977386791916, 18.044943890187078, 18.17910888905174, 18.312290954438225, 18.444511378727277, 18.575790696495265, 18.706148721743876, 18.835604582810717, 18.96417675513493, 19.091883092036785, 19.218740853656364, 19.344766734184212, 19.469976887505545, 19.59438695136952, 19.718012070185985, 19.840866916543746, 19.962965711536953, 20.08432224397926, 20.204949888579286, 20.32486162314519, 20.444070044880988, 20.562587385832554, 20.680425527536904, 20.79759601492442, 20.914110069520053, 21.02997860198626, 21.14521222404732, 21.259821259831895, 21.373815756668254, 21.48720549536398, 21.6, 21.712208547266677, 21.823840175367852, 21.934903692517096, 22.045407685048605, 22.155360525164113], [0.0, 2.224859546128699, 3.146426544510455, 3.853569773599539, 4.449719092257398, 4.974937185533101, 5.449770637375486, 5.886425061104576, 6.29285308902091, 6.674578638386096, 7.035623639735144, 7.379024325749307, 7.707139547199078, 8.021845174272563, 8.324662155306964, 8.616843969807043, 8.899438184514796, 9.173330910852394, 9.439279633531363, 9.69793792514677, 9.949874371066201, 10.195587280779858, 10.435516278555653, 10.670051546267246, 10.899541274750971, 11.124297730643494, 11.344602240713424, 11.560709320798617, 11.772850122209151, 11.981235328629516, 12.186057606953941, 12.387493693237548, 12.58570617804182, 12.780845042484478, 12.973048986263795, 13.162446581088185, 13.349157276772193, 13.533292282367954, 13.714955340794953, 13.894243412291294, 14.071247279470288, 14.246052084700521, 14.4187378088375, 14.589379698945393, 14.758048651498614, 14.9248115565993, 15.089731607951151, 15.252868582663393, 15.414279094398156, 15.574016822900894, 15.732132722552274, 15.888675212238434, 16.043690348545127, 16.19722198403171, 16.349311912126456, 16.5, 16.649324310613927, 16.797321215003304, 16.94402549573153, 17.089470442351338, 17.233687939614086, 17.376708549089496, 17.51856158478772, 17.659275183313728, 17.798876369029593, 17.937391114652097, 18.074844397670482, 18.211260252931424, 18.34666182170479, 18.481071397513727, 18.614510468986285, 18.746999759961593, 18.878559267062727, 19.009208294929067, 19.138965489283898, 19.267848867997692, 19.39587585029354, 19.523063284228737, 19.649427472575383, 19.774984197212397, 19.899748742132402, 20.023735915158294, 20.14696006845698, 20.26943511793064, 20.391174561559716, 20.512191496766018, 20.63249863685928, 20.752108326625514, 20.871032557111306, 20.989282979654167, 21.106870919205434, 21.223807386988792, 21.34010309253449, 21.45576845512647, 21.57081361469706, 21.68524844220144, 21.799082549501943, 21.91232529879018, 22.02498581157318, 22.13707297724792, 22.24859546128699, 22.359561713056905], [0.0, 2.244994432064365, 3.1749015732775088, 3.8884444190447165, 4.48998886412873, 5.019960159204453, 5.499090833947008, 5.939696961966999, 6.3498031465550175, 6.734983296193094, 7.099295739719539, 7.445804187594514, 7.776888838089433, 8.094442537939225, 8.399999999999999, 8.694826047713661, 8.97997772825746, 9.256349172324907, 9.524704719832526, 9.785703858180055, 10.039920318408907, 10.287856919689348, 10.529957264870546, 10.766615066955818, 10.998181667894016, 11.224972160321824, 11.447270417003349, 11.665333257134149, 11.879393923933998, 12.08966500776593, 12.296340919151518, 12.499599993599794, 12.699606293110035, 12.896511156122807, 13.090454537562858, 13.281566172707194, 13.469966592386188, 13.65576801208925, 13.839075113604954, 14.019985734657508, 14.198591479439077, 14.374978260853128, 14.54922678357857, 14.721412975662354, 14.891608375189028, 15.059880477613358, 15.226293048539425, 15.390906406056791, 15.553777676178866, 15.714961024450554, 15.874507866387544, 16.032467059064867, 16.18888507587845, 16.343806166251486, 16.497272501841024, 16.649324310613927, 16.799999999999997, 16.949336270190642, 17.09736821853001, 17.244129435839895, 17.389652095427323, 17.53396703544295, 17.67710383518748, 17.819090885900998, 17.95995545651492, 18.099723754798024, 18.238420984284794, 18.376071397336265, 18.512698344649813, 18.648324321504063, 18.782971010998235, 18.916659324521333, 19.04940943966505, 19.181240835774936, 19.312172327317295, 19.44222209522358, 19.57140771636011, 19.699746191258406, 19.82725397022997, 19.95394697797907, 20.079840636817814, 20.204949888579286, 20.3292892153169, 20.452872658871172, 20.575713839378697, 20.697825972792412, 20.81922188747697, 20.939914039938177, 21.059914529741093, 21.17923511366735, 21.297887219158618, 21.415881957089695, 21.533230133911637, 21.649942263202462, 21.766028576660464, 21.881499034572563, 21.996363335788033, 22.110630927225937, 22.224311012942557, 22.337412562783545, 22.44994432064365, 22.561914812355802], [0.0, 2.264950330581225, 3.2031234756093934, 3.9230090491866063, 4.52990066116245, 5.064582904840241, 5.547972602672079, 5.9924953066314535, 6.406246951218787, 6.794850991743674, 7.162401831787993, 7.5119904153293495, 7.846018098373213, 8.16639455328972, 8.47466813509532, 8.772114910328067, 9.0598013223249, 9.338629449764028, 9.60937042682818, 9.872689603142602, 10.129165809680481, 10.379306335203717, 10.623558725775466, 10.862320194139006, 11.095945205344158, 11.324751652906125, 11.549025932952096, 11.76902714755982, 11.984990613262907, 12.197130810153674, 12.4056438768812, 12.610709734190221, 12.812493902437573, 13.011149065320867, 13.206816421833084, 13.399626860476378, 13.589701983487348, 13.777155003846042, 13.962091533864115, 14.144610280951541, 14.324803663575986, 14.502758358326185, 14.678555787270081, 14.852272553383873, 15.023980830658699, 15.19374871452072, 15.36164053739053, 15.52771715352904, 15.692036196746425, 15.854652314068575, 16.01561737804697, 16.174980680050286, 16.33278910657944, 16.489087300393557, 16.643917808016237, 16.7973212150033, 16.94933627019064, 17.1, 17.249347813758064, 17.397413600877574, 17.544229820656135, 17.689827585366682, 17.834236737242218, 17.977485919894363, 18.1196026446498, 18.26061335223984, 18.400543470234783, 18.53941746657645, 18.677258899528056, 18.814090464330185, 18.94993403682451, 19.084810714282707, 19.21874085365636, 19.351744107444166, 19.483839457355423, 19.61504524593303, 19.745379206285204, 19.874858490062266, 20.003499693803587, 20.13131888376914, 20.258331619360963, 20.384552975231028, 20.509997562164653, 20.63467954682117, 20.758612670407434, 20.881810266353828, 21.004285277057157, 21.126050269749904, 21.24711745155093, 21.367498683748643, 21.48720549536398, 21.606249096037008, 21.72464038827801, 21.842389979120878, 21.95950819121412, 22.076005073382277, 22.191890410688316, 22.307173734025568, 22.421864329265752, 22.535971245988048, 22.64950330581225, 22.76246911035796], [0.0, 2.2847319317591723, 3.2310988842807027, 3.957271787481876, 4.569463863518345, 5.108815909777921, 5.596427431853289, 6.044832503882966, 6.462197768561405, 6.854195795277517, 7.224956747275378, 7.577598564189055, 7.914543574963752, 8.23771813064759, 8.548684109265004, 8.848728722251575, 9.13892772703669, 9.42019108086455, 9.693296652842108, 9.958915603618701, 10.217631819555843, 10.469957019969089, 10.716342659695053, 10.957189420649808, 11.192854863706579, 11.423659658795863, 11.649892703368561, 11.871815362445629, 12.089665007765932, 12.303657992645928, 12.513992168768528, 12.720849028268516, 12.92439553712281, 13.124785712536417, 13.322161986704712, 13.516656391282574, 13.708391590555035, 13.897481786280565, 14.084033513166604, 14.26814634071294, 14.449913494550756, 14.629422408283933, 14.80675521510368, 14.981989187020526, 15.15519712837811, 15.326447729333761, 15.49580588417395, 15.663332978647935, 15.829087149927505, 15.99312352231421, 16.155494421403514, 16.31624956906458, 16.47543626129518, 16.633099530754937, 16.789282295559868, 16.944025495731527, 17.097368218530008, 17.249347813758064, 17.400000000000002, 17.5493589626516, 17.69745744450315, 17.844326829555662, 17.98999722067794, 18.1344975116489, 18.27785545407338, 18.420097719610503, 18.561249957909624, 18.70133685061044, 18.8403821617291, 18.978408784721655, 19.11543878648879, 19.251493448561337, 19.386593305684215, 19.52075818199693, 19.65400722499104, 19.78635893740938, 19.917831207237402, 20.04844133592435, 20.17820606496029, 20.30714160092454, 20.435263639111685, 20.562587385832554, 20.689127579480004, 20.814898510441985, 20.939914039938177, 21.064187617850354, 21.187732299611493, 21.31056076221365, 21.432685319390107, 21.55411793602327, 21.674870241826135, 21.794953544341407, 21.914378841299616, 22.033156832374253, 22.15129793036968, 22.26881227187476, 22.385709727413158, 22.501999911119015, 22.617692189964917, 22.732795692567162, 22.847319317591726, 22.96127174178295], [0.0, 2.3043437243605824, 3.2588341473600644, 3.9912404086950213, 4.608687448721165, 5.152669211195301, 5.644466316668034, 6.096720429870472, 6.517668294720129, 6.913031173081746, 7.286974680894671, 7.642643521714199, 7.982480817390043, 8.308429454475737, 8.622064717919947, 8.924684868386109, 9.21737489744233, 9.501052573267868, 9.776502442080194, 10.044401425669925, 10.305338422390601, 10.559829544078823, 10.808330120791092, 11.05124427383632, 11.288932633336067, 11.521718621802911, 11.749893616539683, 11.973721226085063, 12.193440859740944, 12.40927072796786, 12.621410380777577, 12.830042868205858, 13.035336589440258, 13.237446883746125, 13.436517405935216, 13.632681321002115, 13.826062346163493, 14.016775663468401, 14.204928722102057, 14.390621946253747, 14.573949361789342, 14.754999152829525, 14.93385415758437, 15.110592311355632, 15.285287043428397, 15.4580076335859, 15.628819533157326, 15.797784654817901, 15.964961634780085, 16.130406070524078, 16.294170736800325, 16.456305782282975, 16.616858908951475, 16.77587553601898, 16.9333989500041, 17.089470442351335, 17.244129435839895, 17.397413600877574, 17.5493589626516, 17.7, 17.849369736772218, 17.997499826364773, 18.144420630044927, 18.29016128961142, 18.43474979488466, 18.57821304646924, 18.72057691418723, 18.861866291541777, 19.002105146535737, 19.141316569139125, 19.279522815671555, 19.416745350341287, 19.553004884160387, 19.688321411435766, 19.822714244018147, 19.956202043475106, 20.08880285133985, 20.22053411757464, 20.35141272737596, 20.481455026437942, 20.610676844781203, 20.739093519245245, 20.866719914735043, 20.99357044430508, 21.119659088157647, 21.24499941162626, 21.369604582209753, 21.49348738571756, 21.616660241582185, 21.73913521739078, 21.86092404268401, 21.982038122066843, 22.10248854767264, 22.222286111019272, 22.341441314293043, 22.459964381093748, 22.577865266672134, 22.69515366768862, 22.81183903152045, 22.927930565142596, 23.043437243605823, 23.158367818134337], [0.0, 2.3237900077244498, 3.2863353450309964, 4.024922359499621, 4.6475800154488995, 5.196152422706632, 5.692099788303082, 6.148170459575758, 6.572670690061993, 6.971370023173349, 7.348469228349534, 7.707139547199078, 8.049844718999243, 8.378544026261364, 8.694826047713661, 8.999999999999998, 9.295160030897799, 9.581231653602787, 9.859006035092989, 10.12916580968048, 10.392304845413264, 10.648943609579309, 10.89954127475097, 11.144505372604026, 11.384199576606164, 11.61895003862225, 11.8490505948789, 12.074767078498864, 12.296340919151517, 12.513992168768524, 12.727922061357855, 12.938315191708694, 13.145341380123986, 13.349157276772194, 13.549907748763458, 13.747727084867519, 13.942740046346698, 14.135062787267696, 14.324803663575985, 14.512063946937388, 14.696938456699067, 14.879516121164693, 15.059880477613358, 15.23811011904035, 15.414279094398156, 15.588457268119894, 15.760710643876436, 15.931101656822102, 16.099689437998485, 16.26653005407115, 16.431676725154983, 16.5951800231272, 16.75708805252273, 16.91744661584602, 17.076299364909246, 17.233687939614082, 17.389652095427323, 17.544229820656135, 17.69745744450315, 17.849369736772218, 17.999999999999996, 18.149380154705007, 18.297540818372283, 18.444511378727277, 18.590320061795598, 18.734993995195193, 18.878559267062727, 19.021040980976828, 19.162463307205574, 19.30284953057449, 19.44222209522358, 19.580602646496864, 19.718012070185978, 19.854470529329156, 19.989997498749215, 20.124611797498105, 20.25833161936096, 20.391174561559716, 20.523157651784487, 20.654297373670207, 20.784609690826528, 20.914110069520053, 21.042813500100216, 21.170734517252818, 21.297887219158618, 21.42428528562855, 21.549941995281564, 21.67487024182613, 21.79908254950194, 21.92259108773413, 22.045407685048602, 22.167543842293398, 22.289010745208053, 22.40981927637972, 22.529980026622304, 22.649503305812246, 22.76839915321233, 22.886677347312784, 23.004347415216973, 23.121418641597234, 23.2379000772445, 23.35380054723428], [0.0, 2.3430749027719964, 3.3136083051561784, 4.058324777540605, 4.686149805543993, 5.239274758971895, 5.739337940912697, 6.199193495931548, 6.627216610312357, 7.029224708315988, 7.409453421137082, 7.771100308193172, 8.11664955508121, 8.448076704197234, 8.766983517721474, 9.074690077352503, 9.372299611087985, 9.66074531286277, 9.940824915468534, 10.213226718329523, 10.47854951794379, 10.737318100903968, 10.989995450408522, 11.236992480196827, 11.478675881825394, 11.715374513859981, 11.947384651043928, 12.174974332621815, 12.398386991863095, 12.617844506887854, 12.833549781724463, 13.045688943095339, 13.254433220624714, 13.459940564504734, 13.66235704408284, 13.861818062577505, 14.058449416631976, 14.252368224263645, 14.443683740652867, 14.63249807790864, 14.818906842274163, 15.002999700059986, 15.184860881812517, 15.364569632762251, 15.542200616386344, 15.717824276915682, 15.891507165778833, 16.063312236273063, 16.23329911016242, 16.401524319403975, 16.56804152578089, 16.73290172086121, 16.89615340839447, 17.0578427709954, 17.218013822738094, 17.376708549089496, 17.53396703544295, 17.689827585366682, 17.844326829555662, 17.99749982636477, 18.149380154705007, 18.3, 18.449390233826158, 18.59758048779464, 18.74459922217597, 18.890473789717397, 19.035230495058364, 19.17889465010953, 19.32149062572554, 19.46304189997031, 19.60357110324545, 19.743100060527475, 19.881649830937068, 20.019240744843447, 20.15589243868899, 20.29162388770302, 20.426453436659045, 20.560398828816528, 20.693477233176644, 20.825705270170324, 20.95709903588758, 21.08767412494797, 21.21744565210431, 21.346428272664255, 21.474636201807936, 21.602083232873632, 21.728782754678186, 21.85474776793363, 21.979990900817043, 22.104524423746376, 22.228360263411243, 22.351510016104058, 22.473984960393654, 22.59579606918066, 22.71695402117106, 22.837469211801906, 22.957351763650788, 23.07661153635863, 23.195258136093244, 23.313300924579515, 23.430749027719962, 23.54761134382849], [0.0, 2.362202362203543, 3.340658617698013, 4.091454509095756, 4.724404724407086, 5.282045058497703, 5.786190456595773, 6.249799996799897, 6.681317235396026, 7.086607086610629, 7.469939758793239, 7.834538914320357, 8.182909018191513, 8.517041739947034, 8.83855191759374, 9.148770409186142, 9.448809448814172, 9.739609848448756, 10.02197585309404, 10.29660138103831, 10.564090116995406, 10.82497113160123, 11.079711187571633, 11.328724553099525, 11.572380913191546, 11.811011811017716, 12.04491593993084, 12.27436352728727, 12.499599993599794, 12.720849028268514, 12.938315191708694, 13.152186130069783, 13.362634470792052, 13.56981945347837, 13.773888339898797, 13.974977638622539, 14.173214173221258, 14.368716017793657, 14.561593319413916, 14.751949023773095, 14.939879517586478, 15.125475199146637, 15.308820986607689, 15.4899967721107, 15.669077828640715, 15.846135175493107, 16.021235907382426, 16.194443491518932, 16.365818036383025, 16.535416535424805, 16.703293088490067, 16.86949910341146, 17.03408347989407, 17.197092777559817, 17.35857136978732, 17.51856158478772, 17.67710383518748, 17.834236737242218, 17.989997220677942, 18.144420630044927, 18.297540818372283, 18.449390233826158, 18.599999999999998, 18.74939999039969, 18.897618897628345, 19.04468429772465, 19.19062271006337, 19.33545965318642, 19.479219696897513, 19.621926510921398, 19.763602910400724, 19.904270898478043, 20.04395170618808, 20.18266582986499, 20.32043306625132, 20.45727254547878, 20.59320276207662, 20.72824160414964, 20.862406380856456, 20.99571384830723, 21.12818023399081, 21.25982125983189, 21.390652163971065, 21.52068772135314, 21.64994226320246, 21.778429695457845, 21.90616351623442, 22.033156832374246, 22.159422375143265, 22.284972515127766, 22.409819276379718, 22.533974349856706, 22.65744910619905, 22.78025460788356, 22.902401620790776, 23.02390062521987, 23.144761826383093, 23.26499516440956, 23.38461032388609, 23.50361674296107, 23.62202362203543, 23.73983993206357], [0.0, 2.3811761799581315, 3.3674916480965473, 4.124318125460256, 4.762352359916263, 5.324471804789655, 5.8326666285670745, 6.3, 6.734983296193095, 7.143528539874394, 7.52994023880668, 7.897467948652911, 8.248636250920512, 8.58545281275251, 8.909545442950499, 9.222255689363639, 9.524704719832526, 9.817840903172144, 10.102474944289641, 10.379306335203717, 10.64894360957931, 10.911920087683928, 11.168706281391772, 11.41971978640457, 11.665333257134149, 11.905880899790658, 12.14166380690884, 12.372954376380768, 12.6, 12.823026163897508, 13.042239071570496, 13.257827876390612, 13.46996659238619, 13.678815738213599, 13.884523758487363, 14.087228258248675, 14.287057079748788, 14.484129245487974, 14.678555787270081, 14.870440477672476, 15.05988047761336, 15.246966911487677, 15.431785379534023, 15.614416415607723, 15.794935897305821, 15.973415414368963, 16.149922600433726, 16.32452143249535, 16.497272501841024, 16.668233259706923, 16.837458240482736, 17.004999264922066, 17.17090562550502, 17.3352242558324, 17.497999885701223, 17.659275183313724, 17.819090885900998, 17.977485919894363, 18.1344975116489, 18.29016128961142, 18.444511378727277, 18.597580487794644, 18.74939999039969, 18.900000000000002, 19.04940943966505, 19.197656106931387, 19.34476673418421, 19.49076704493694, 19.635681806344287, 19.77953487825232, 19.92234925906079, 20.064147128647157, 20.204949888579282, 20.344778199823168, 20.483652018133878, 20.62159062730128, 20.758612670407434, 20.894736179239022, 21.029978601986265, 21.164356829348726, 21.29788721915862, 21.430585619623187, 21.562467391279693, 21.69354742774911, 21.823840175367856, 21.953359651770846, 22.082119463493537, 22.21013282265552, 22.337412562783545, 22.463971153827632, 22.58982071642004, 22.71497303542313, 22.83943957280914, 22.96323147991154, 23.08635960908519, 23.208834524809728, 23.330666514268298, 23.45186559743169, 23.57244153667583, 23.692403845958733, 23.811761799581316, 23.930524440555], [0.0, 2.4, 3.394112549695428, 4.156921938165306, 4.8, 5.366563145999496, 5.878775382679628, 6.3498031465550175, 6.788225099390856, 7.199999999999999, 7.58946638440411, 7.959899496852961, 8.313843876330612, 8.653323061113575, 8.97997772825746, 9.295160030897799, 9.6, 9.895453501482386, 10.182337649086284, 10.461357464497619, 10.733126291998992, 10.998181667894016, 11.256997823576231, 11.50999565595053, 11.757550765359255, 12.0, 12.237646832622685, 12.470765814495918, 12.699606293110035, 12.92439553712281, 13.145341380123988, 13.362634470792052, 13.576450198781712, 13.78695035169127, 13.994284547628723, 14.198591479439079, 14.399999999999999, 14.598630072715729, 14.794593607125543, 14.987995196156156, 15.17893276880822, 15.36749816983884, 15.553777676178866, 15.737852458324799, 15.919798993705921, 16.099689437998485, 16.277591959500644, 16.453571040962505, 16.627687752661224, 16.8, 16.970562748477143, 17.139428228502844, 17.30664612222715, 17.472263734273245, 17.636326148038883, 17.798876369029593, 17.95995545651492, 18.1196026446498, 18.277855454073382, 18.43474979488466, 18.590320061795598, 18.74459922217597, 18.897618897628345, 19.04940943966505, 19.2, 19.349418595916518, 19.497692171126303, 19.64484665249388, 19.790907002964772, 19.93589727100338, 20.079840636817814, 20.22275945562326, 20.364675298172568, 20.505608988762074, 20.645580640902306, 20.784609690826528, 20.922714928995237, 21.059914529741096, 21.196226079186836, 21.331666601557416, 21.466252583997985, 21.6, 21.7329243315298, 21.865040589946314, 21.996363335788033, 22.126906697502932, 22.256684389189694, 22.385709727413158, 22.513995647152463, 22.64155471693585, 22.768399153212332, 22.894540834006698, 23.01999131190106, 23.144761826383096, 23.26886331559838, 23.392306427541513, 23.51510153071851, 23.637258724310655, 23.758787847867996, 23.879698490558884, 24.0, 24.119701490690144], [0.0, 2.4186773244895647, 3.420526275297414, 4.189272013130682, 4.8373546489791295, 5.408326913195984, 5.924525297439449, 6.3992187023104625, 6.841052550594828, 7.256031973468693, 7.648529270389177, 8.021845174272563, 8.378544026261364, 8.72066511224918, 9.049861877399012, 9.367496997597597, 9.674709297958259, 9.972462083156795, 10.26157882589224, 10.542770034483349, 10.816653826391969, 11.083771921146699, 11.344602240713423, 11.599568957508724, 11.849050594878898, 12.093386622447824, 12.33288287465668, 12.567816039392048, 12.798437404620925, 13.024976007655445, 13.24764129949177, 13.466625412478063, 13.682105101189656, 13.894243412291294, 14.10319112825179, 14.309088021254183, 14.512063946937387, 14.712239802287074, 14.909728367747011, 15.104635050208925, 15.297058540778353, 15.487091398968369, 15.674820573135756, 15.86032786546356, 16.043690348545127, 16.224980739587952, 16.40426773739078, 16.58161632652257, 16.75708805252273, 16.930741271426953, 17.102631376487068, 17.27281100458174, 17.44133022449836, 17.608236708995026, 17.77357589231835, 17.937391114652094, 18.099723754798024, 18.26061335223984, 18.420097719610503, 18.57821304646924, 18.734993995195193, 18.890473789717397, 19.04468429772465, 19.197656106931387, 19.349418595916518, 19.499999999999996, 19.649427472575375, 19.797727142275697, 19.94492416631359, 20.091042780303862, 20.23610634484806, 20.380137389134546, 20.52315765178448, 20.665188119153427, 20.80624906127964, 20.94636006565341, 21.085540068966697, 21.223807386988792, 21.36117974270148, 21.497674292815955, 21.633307652783937, 21.768095920406086, 21.902054698132776, 22.03519911414462, 22.167543842293398, 22.29910312097776, 22.429890771022496, 22.559920212624863, 22.689204481426845, 22.8177562437677, 22.94558781116753, 23.072711154088502, 23.19913791501745, 23.3248794209102, 23.44994669503536, 23.574350468252565, 23.698101189757796, 23.821209037326383, 23.943683927081892, 24.06553552281769, 24.186773244895647, 24.30740627874558], [0.0, 2.437211521390788, 3.4467375879228173, 4.221374183841087, 4.874423042781576, 5.449770637375486, 5.96992462263972, 6.448255578061403, 6.8934751758456345, 7.311634564172364, 7.707139547199077, 8.083316151184489, 8.442748367682174, 8.787491109526085, 9.119210492142397, 9.439279633531363, 9.748846085563152, 10.048880534666536, 10.34021276376845, 10.623558725775466, 10.899541274750971, 11.16870628139177, 11.431535329954592, 11.688455843266896, 11.93984924527944, 12.186057606953941, 12.427389106324789, 12.66412255152326, 12.896511156122806, 13.124785712536415, 13.349157276772194, 13.56981945347837, 13.786950351691269, 14.000714267493644, 14.211263138792415, 14.418737808837498, 14.623269128344727, 14.824978920727006, 15.023980830658697, 15.220381072758988, 15.414279094398154, 15.605768164367944, 15.79493589730582, 15.98186472224064, 16.166632302368978, 16.349311912126456, 16.529972776747094, 16.708680378773185, 16.88549673536435, 17.060480649735517, 17.233687939614086, 17.405171645232347, 17.57498221905217, 17.743167699145495, 17.90977386791916, 18.074844397670482, 18.238420984284794, 18.400543470234787, 18.561249957909627, 18.720576914187234, 18.878559267062727, 19.035230495058368, 19.19062271006337, 19.34476673418421, 19.497692171126303, 19.649427472575375, 19.799999999999997, 19.949436082255556, 20.09776106933307, 20.244999382563584, 20.391174561559716, 20.536309308149796, 20.6804255275369, 20.82354436689393, 20.96568625158738, 21.10687091920543, 21.24711745155093, 21.38644430474594, 21.52486933758252, 21.662409838242837, 21.799082549501943, 21.934903692517096, 22.069888989299425, 22.204053683955998, 22.33741256278354, 22.469979973288808, 22.60176984220484, 22.73279569256716, 22.863070659909184, 22.992607507631664, 23.12141864159723, 23.249516123997076, 23.37691168653379, 23.503616742961075, 23.62964240101826, 23.754999473794985, 23.87969849055888, 24.00374970707702, 24.127163115459716, 24.249948453553465, 24.372115213907882, 24.49367265234024], [0.0, 2.455605831561735, 3.4727510708370675, 4.253234063627348, 4.91121166312347, 5.490901565316938, 6.014981296729027, 6.496922348312315, 6.945502141674135, 7.366817494685204, 7.76530746332687, 8.144323176298936, 8.506468127254696, 8.853812738024223, 9.188035698668132, 9.510520490488414, 9.82242332624694, 10.124722218411723, 10.418253212511202, 10.703737664946765, 10.981803130633876, 11.25299960010663, 11.517812292271481, 11.776671855834314, 12.029962593458054, 12.278029157808675, 12.521182052825525, 12.759702190882043, 12.99384469662463, 13.223842104320514, 13.449907062875937, 13.672234638127009, 13.89100428334827, 14.106381534610499, 14.31851947653807, 14.527560015363902, 14.733634989370408, 14.936867141405523, 15.137370973851436, 15.33525350295847, 15.53061492665374, 15.723549217654393, 15.914144651849814, 16.102484280383567, 16.288646352597873, 16.472704695950814, 16.65472905813841, 16.83478541591784, 17.01293625450939, 17.189240820932145, 17.36375535418534, 17.53653329481058, 17.707625476048445, 17.8770802985275, 18.044943890187078, 18.211260252931424, 18.376071397336265, 18.539417466576452, 18.701336850610442, 18.861866291541777, 19.021040980976828, 19.17889465010953, 19.335459653186422, 19.490767044936945, 19.64484665249388, 19.7977271422757, 19.949436082255556, 20.099999999999998, 20.249444436823445, 20.39779399837149, 20.54507240191672, 20.691302520624458, 20.836506425022403, 20.980705421887034, 21.123920090740732, 21.266170318136737, 21.40747532989353, 21.547853721426645, 21.687323486313385, 21.82590204321462, 21.963606261267753, 22.100452484055616, 22.23645655224771, 22.371633825002586, 22.50599920021326, 22.63956713367109, 22.772351657218017, 22.904366395951666, 23.035624584542962, 23.166139082721575, 23.29592238998061, 23.42498665954796, 23.553343711668628, 23.68100504623907, 23.807981854831795, 23.93428503214583, 24.059925186916107, 24.184912652312807, 24.30925749585947, 24.432969528896813, 24.55605831561735, 24.678533181694576], [0.0, 2.473863375370596, 3.4985711369071804, 4.28485705712571, 4.947726750741192, 5.531726674375733, 6.059702963017247, 6.545227268781429, 6.997142273814361, 7.421590126111788, 7.8230428862431785, 8.204876598706406, 8.56971411425142, 8.919641248391104, 9.256349172324907, 9.581231653602787, 9.895453501482384, 10.2, 10.49571341072154, 10.783320453366859, 11.063453348751466, 11.336666176614711, 11.60344776348823, 11.864231959971114, 12.119405926034494, 12.369316876852983, 12.614277624977184, 12.854571171377131, 13.090454537562858, 13.32216198670471, 13.549907748763458, 13.773888339898797, 13.994284547628721, 14.211263138792415, 14.424978336205571, 14.635573101180562, 14.843180252223576, 15.047923444781345, 15.249918032566601, 15.44927182750048, 15.646085772486357, 15.840454538932905, 16.032467059064864, 16.222207001514928, 16.40975319741281, 16.595180023127195, 16.778557744931476, 16.959952830123083, 17.13942822850284, 17.317043627594174, 17.492855684535904, 17.66691823720255, 17.839282496782207, 18.009997223764362, 18.17910888905174, 18.346661821704785, 18.512698344649813, 18.677258899528056, 18.8403821617291, 19.002105146535737, 19.162463307205574, 19.32149062572554, 19.479219696897513, 19.635681806344287, 19.79090700296477, 19.94492416631359, 20.09776106933307, 20.249444436823445, 20.4, 20.54945254745245, 20.69782597279241, 20.84514331924825, 20.99142682144308, 21.136697944570244, 21.28097742116184, 21.42428528562855, 21.566640906733717, 21.708063018150654, 21.848569747239754, 21.988178642170435, 22.126906697502932, 22.26477037833537, 22.401785643113364, 22.537967965191537, 22.673332353229423, 22.807893370497858, 22.941665153166195, 23.07466142763529, 23.20689552697646, 23.33838040653207, 23.469128658729534, 23.599152527156562, 23.72846391994223, 23.857074422485255, 23.98499530956802, 24.112237556892143, 24.238811852068988, 24.364728605096346, 24.48999795835026, 24.61462979611922, 24.738633753705965, 24.8620192261208], [0.0, 2.4919871588754225, 3.5242020373412193, 4.316248370981448, 4.983974317750845, 5.572252686302014, 6.104096984812742, 6.593178292750774, 7.048404074682439, 7.475961476626267, 7.880355321938218, 8.264986388373547, 8.632496741962896, 8.984987479123163, 9.324162160752032, 9.651424765287247, 9.96794863550169, 10.274726273726225, 10.572606112023658, 10.862320194139006, 11.144505372604028, 11.419719786404569, 11.688455843266896, 11.951150572225256, 12.208193969625484, 12.459935794377113, 12.706691150728425, 12.948745112944344, 13.186356585501548, 13.419761547807026, 13.649175799292792, 13.874797295816613, 14.096808149364877, 14.315376348528183, 14.530657245974803, 14.742794850366739, 14.951922953252534, 15.158166115991738, 15.36164053739053, 15.562454819211526, 15.760710643876436, 15.956503376366642, 16.149922600433726, 16.341052597675585, 16.529972776747094, 16.716758058906038, 16.90147922520393, 17.08420322988462, 17.264993483925792, 17.44391011212796, 17.621010186706098, 17.79634793995667, 17.969974958246326, 18.141940359289027, 18.312290954438225, 18.481071397513727, 18.648324321504063, 18.814090464330185, 18.978408784721655, 19.141316569139125, 19.302849530574495, 19.463041899970314, 19.621926510921398, 19.77953487825232, 19.93589727100338, 20.091042780303862, 20.244999382563584, 20.39779399837149, 20.54945254745245, 20.7, 20.849460424672866, 20.99785703351654, 21.145212224047317, 21.291547618714805, 21.436884101939818, 21.581241854907237, 21.72464038827801, 21.86709857297031, 22.008634669147476, 22.149266353538668, 22.289010745208056, 22.427884429878805, 22.56590348290979, 22.703083491015047, 22.839439572809138, 22.974986398254956, 23.109738207084913, 23.243708826260924, 23.37691168653379, 23.50935983815808, 23.641065965814654, 23.77204240278904, 23.90230114445051, 24.031853861073646, 24.160711910041062, 24.288886347463524, 24.416387939250967, 24.54322717166592, 24.669414261388532, 24.794959165120645, 24.919871588754226, 25.044160996128426], [0.0, 2.5099800796022267, 3.5496478698597698, 4.3474130238568325, 5.019960159204453, 5.612486080160913, 6.148170459575759, 6.640783086353597, 7.0992957397195395, 7.529940238806679, 7.937253933193772, 8.324662155306966, 8.694826047713665, 9.049861877399014, 9.391485505499116, 9.72111104761179, 10.039920318408907, 10.348912986396204, 10.648943609579309, 10.940749517286283, 11.224972160321826, 11.502173707608488, 11.772850122209151, 12.03744158864333, 12.296340919151518, 12.549900398011134, 12.798437404620927, 13.042239071570496, 13.281566172707194, 13.516656391282574, 13.74772708486752, 13.97497763862254, 14.198591479439079, 14.418737808837502, 14.635573101180563, 14.849242404917499, 15.059880477613358, 15.26761277999937, 15.472556349873152, 15.67482057313576, 15.874507866387544, 16.07171428317465, 16.26653005407115, 16.459040069214243, 16.64932431061393, 16.837458240482736, 17.02351315093333, 17.207556479639983, 17.38965209542733, 17.569860557215588, 17.74823934929885, 17.92484309554759, 18.099723754798028, 18.272930799409277, 18.444511378727277, 18.614510468986285, 18.78297101099823, 18.94993403682451, 19.11543878648879, 19.279522815671555, 19.44222209522358, 19.60357110324545, 19.763602910400724, 19.92234925906079, 20.079840636817814, 20.23610634484806, 20.391174561559716, 20.54507240191672, 20.69782597279241, 20.849460424672866, 21.000000000000004, 21.14946807841748, 21.297887219158618, 21.44527920079382, 21.5916650585359, 21.737065119284157, 21.881499034572567, 22.024985811573185, 22.167543842293405, 22.30919093109385, 22.449944320643652, 22.589820716420043, 22.728836309850976, 22.867006800191405, 23.004347415216976, 23.14087293081227, 23.27659768952499, 23.411535618152005, 23.545700244418303, 23.67910471280534, 23.811761799581316, 23.9436839270819, 24.07488317728666, 24.205371304733177, 24.335159748807897, 24.464259645450138, 24.592681838303037, 24.7204368893432, 24.847535089018386, 24.9739864659209, 25.09980079602227, 25.224987611493496], [0.0, 2.5278449319529073, 3.5749125863438955, 4.378355855797928, 5.0556898639058145, 5.652433104425032, 6.191930232165088, 6.688049042882386, 7.149825172687791, 7.583534795858722, 7.993747556684537, 8.383913167489272, 8.756711711595855, 9.114274518577988, 9.458329662260667, 9.790301323248432, 10.111379727811629, 10.422571659624126, 10.724737759031687, 11.018620603324177, 11.304866208850065, 11.584040745784694, 11.856643707221703, 12.123118410706052, 12.383860464330176, 12.639224659764539, 12.889530635364503, 13.135067567393783, 13.376098085764772, 13.612861565446114, 13.845576911057192, 14.07444492688788, 14.299650345375582, 14.52136357233714, 14.739742195845897, 14.954932296737422, 15.167069591717445, 15.3762804344874, 15.582682695864662, 15.786386540307443, 15.987495113369073, 16.186105152259454, 16.382307529771257, 16.576187740249562, 16.767826334978544, 16.957299313275094, 17.14467847467546, 17.330031736843413, 17.51342342319171, 17.694914523670356, 17.874562931719478, 18.052423659996464, 18.228549037155975, 18.402988887678003, 18.575790696495265, 18.746999759961593, 18.916659324521333, 19.084810714282707, 19.251493448561337, 19.416745350341287, 19.580602646496864, 19.743100060527475, 19.904270898478043, 20.064147128647157, 20.222759455623258, 20.380137389134546, 20.536309308149796, 20.691302520624454, 20.84514331924825, 20.99785703351654, 21.14946807841748, 21.3, 21.449475518063373, 21.597916566187582, 21.745344329304146, 21.891779278989635, 22.037241206648353, 22.181749254736427, 22.325321946166873, 22.46797721202334, 22.60973241770013, 22.75060438757617, 22.89060942832235, 23.029763350933504, 23.16808149156939, 23.30557873128235, 23.442269514703565, 23.57816786775427, 23.713287414443407, 23.84764139280864, 23.98124267005361, 24.1141037569303, 24.246236821412104, 24.377653701699845, 24.508365918600123, 24.6383846873126, 24.767720928660353, 24.89638527979514, 25.024388104407265, 25.15173950246782, 25.278449319529077, 25.404527155607525], [0.0, 2.545584412271571, 3.6, 4.409081537009721, 5.091168824543142, 5.692099788303084, 6.235382907247959, 6.734983296193095, 7.2, 7.636753236814712, 8.049844718999243, 8.442748367682174, 8.818163074019441, 9.178235124467014, 9.524704719832526, 9.859006035092989, 10.182337649086284, 10.49571341072154, 10.799999999999999, 11.09594520534416, 11.384199576606168, 11.665333257134149, 11.93984924527944, 12.208193969625485, 12.470765814495918, 12.727922061357855, 12.979984591670362, 13.227244611029162, 13.46996659238619, 13.708391590555035, 13.942740046346701, 14.17321417322126, 14.4, 14.623269128344731, 14.84318025222358, 15.05988047761336, 15.273506473629425, 15.48418548067673, 15.692036196746425, 15.897169559390125, 16.099689437998485, 16.29969324864735, 16.497272501841024, 16.692513291892265, 16.88549673536435, 17.07629936490925, 17.264993483925792, 17.451647486698782, 17.636326148038883, 17.819090885900998, 18.0, 18.179108889051744, 18.356470248934027, 18.532134253776604, 18.706148721743876, 18.878559267062727, 19.04940943966505, 19.21874085365636, 19.38659330568422, 19.553004884160387, 19.718012070185978, 19.88164983093707, 20.04395170618808, 20.204949888579286, 20.364675298172568, 20.523157651784484, 20.6804255275369, 20.836506425022403, 20.99142682144308, 21.145212224047317, 21.297887219158618, 21.449475518063373, 21.599999999999998, 21.74948275247023, 21.897945109073593, 22.045407685048602, 22.19189041068832, 22.337412562783545, 22.481992794234237, 22.625649161957764, 22.768399153212336, 22.91025971044414, 23.051247254758255, 23.191377708105225, 23.330666514268298, 23.469128658729538, 23.606778687487207, 23.743630724891254, 23.87969849055888, 24.014995315427402, 24.149534156997728, 24.283327613817676, 24.41638793925097, 24.548727054574545, 24.68035656144376, 24.8112877537624, 24.941531628991836, 25.071098898931417, 25.2, 25.328245103046523, 25.45584412271571, 25.582806726393418], [0.0, 2.563201123595259, 3.6249137920783716, 4.439594576084623, 5.126402247190518, 5.731491952362841, 6.278534860936905, 6.7815927332743895, 7.249827584156743, 7.689603370785777, 8.105553651663778, 8.501176389182852, 8.879189152169246, 9.241753080449618, 9.590620417887468, 9.927235264664578, 10.252804494381037, 10.568348972285122, 10.874741376235114, 11.172734669721645, 11.462983904725682, 11.746063170271135, 12.022478945708327, 12.29268074912873, 12.55706972187381, 12.816005617976296, 13.06981254647518, 13.31878372825387, 13.563185466548779, 13.803260484392808, 14.03923074815711, 14.271299870719556, 14.499655168313486, 14.724469430169634, 14.945902448497382, 15.164102347320135, 15.379206741571554, 15.59134375222354, 15.800632898716431, 16.00718588634492, 16.211107303327555, 16.412495239907916, 16.611441839888553, 16.808033793397726, 17.002352778365704, 17.19447585708852, 17.384475833340503, 17.572421574728963, 17.758378304338493, 17.942407865166818, 18.12456896039186, 18.30491737211616, 18.483506160899235, 18.660385848100784, 18.835604582810717, 19.009208294929067, 19.181240835774936, 19.351744107444166, 19.52075818199693, 19.688321411435766, 19.854470529329156, 20.019240744843447, 20.18266582986499, 20.344778199823168, 20.505608988762074, 20.665188119153427, 20.82354436689393, 20.980705421887034, 21.136697944570244, 21.2915476187148, 21.44527920079382, 21.597916566187582, 21.74948275247023, 21.9, 22.04948979001555, 22.197972880423112, 22.34546933944329, 22.491998577271875, 22.63757937589618, 22.782229917196428, 22.925967809451365, 23.068810112357337, 23.21077336066164, 23.351873586502645, 23.49212634054227, 23.631546711969577, 23.77014934744837, 23.907948469076135, 24.044957891416654, 24.181191037663964, 24.316660954991335, 24.451380329134796, 24.58536149825746, 24.718616466137423, 24.851156914719283, 24.982994216066256, 25.11413944374762, 25.244603383693715, 25.3743965445486, 25.50352916754856, 25.632011235952593, 25.759852484049677], [0.0, 2.580697580112788, 3.6496575181789317, 4.469899327725402, 5.161395160225576, 5.770615218501404, 6.321392251711643, 6.827884006044625, 7.299315036357863, 7.742092740338363, 8.160882305241266, 8.559205570612264, 8.939798655450804, 9.304837451562493, 9.656086163658648, 9.994998749374608, 10.322790320451151, 10.64048871058092, 10.948972554536795, 11.248999955551605, 11.541230437002808, 11.826242006656214, 12.104544601099208, 12.376590806841763, 12.642784503423286, 12.90348790056394, 13.159027319676786, 13.409697983176207, 13.65576801208925, 13.897481786280563, 14.135062787267696, 14.368716017793655, 14.598630072715727, 14.824978920727006, 15.047923444781343, 15.267612779999366, 15.484185480676725, 15.697770542341356, 15.90848830027542, 16.116451222275952, 16.321764610482532, 16.524527224704496, 16.724831837719623, 16.922765731404542, 17.118411141224527, 17.311845655504207, 17.503142574977787, 17.692371237344076, 17.87959731090161, 18.064883060789516, 18.24828759089466, 18.429867064089205, 18.609674903124986, 18.78776197422141, 18.96417675513493, 19.138965489283894, 19.312172327317295, 19.48383945735542, 19.65400722499104, 19.822714244018147, 19.989997498749215, 20.15589243868899, 20.32043306625132, 20.483652018133874, 20.645580640902303, 20.80624906127964, 20.965686251587375, 21.123920090740732, 21.28097742116184, 21.436884101939814, 21.5916650585359, 21.745344329304146, 21.89794510907359, 22.04948979001555, 22.2, 22.349496638627006, 22.49799991110321, 22.645529360118744, 22.792103895867097, 22.93774182433833, 23.082460874005616, 23.226278221015093, 23.369210512980537, 23.511273891475977, 23.652484013312428, 23.792856070678024, 23.93240481021496, 24.07114455110101, 24.209089202198417, 24.346252278328176, 24.482646915723798, 24.61828588671437, 24.753181613683527, 24.88734618234737, 25.02079135439165, 25.153528579505497, 25.285569006846572, 25.416923495970163, 25.54760262725252, 25.67761671183679, 25.80697580112788, 25.93568969586119], [0.0, 2.598076211353316, 3.6742346141747673, 4.5, 5.196152422706632, 5.809475019311126, 6.363961030678928, 6.87386354243376, 7.3484692283495345, 7.794228634059947, 8.215838362577491, 8.616843969807043, 9.0, 9.367496997597597, 9.721111047611789, 10.062305898749052, 10.392304845413264, 10.712142642814275, 11.022703842524301, 11.324751652906127, 11.618950038622252, 11.905880899790658, 12.186057606953941, 12.459935794377115, 12.727922061357855, 12.99038105676658, 13.247641299491772, 13.500000000000002, 13.74772708486752, 13.991068579633223, 14.230249470757707, 14.465476141489432, 14.696938456699069, 14.924811556599302, 15.149257407543118, 15.370426148939398, 15.588457268119894, 15.80348062927911, 16.015617378046965, 16.224980739587952, 16.431676725154983, 16.63580475961413, 16.837458240482736, 17.036725037400817, 17.233687939614086, 17.428425057933374, 17.621010186706098, 17.811513130556875, 18.0, 18.186533479473212, 18.371173070873837, 18.553975315279473, 18.734993995195193, 18.91428031937774, 19.091883092036785, 19.267848867997692, 19.442222095223578, 19.615045245933032, 19.786358937409382, 19.956202043475106, 20.124611797498105, 20.291623887703025, 20.457272545478784, 20.62159062730128, 20.784609690826528, 20.946360065653412, 21.10687091920543, 21.266170318136737, 21.42428528562855, 21.581241854907237, 21.73706511928416, 21.891779278989635, 22.045407685048602, 22.197972880423112, 22.34949663862701, 22.5, 22.649503305812253, 22.798026230355998, 22.945587811167535, 23.09220647751098, 23.237900077244504, 23.382685902179848, 23.526580712037184, 23.66960075708925, 23.811761799581316, 23.953079134006973, 24.09356760631352, 24.23324163210527, 24.372115213907882, 24.510201957552287, 24.647515087732476, 24.78406746278746, 24.91987158875423, 25.054939632735103, 25.18928343562, 25.3229145242012, 25.45584412271571, 25.588083163847976, 25.719642299223366, 25.850531909421132, 25.98076211353316, 26.11034277829382], [0.0, 2.615339366124404, 3.6986484017813863, 4.529900661162451, 5.230678732248808, 5.84807660688538, 6.406246951218788, 6.919537556802479, 7.397296803562773, 7.846018098373213, 8.270429251254134, 8.674099376880578, 9.059801322324901, 9.429740187301027, 9.785703858180055, 10.12916580968048, 10.461357464497617, 10.783320453366859, 11.095945205344158, 11.400000000000002, 11.69615321377076, 11.984990613262909, 12.267028980156526, 12.542726976220127, 12.812493902437575, 13.076696830622023, 13.335666462535725, 13.589701983487352, 13.839075113604958, 14.084033513166604, 14.324803663575988, 14.561593319413918, 14.794593607125545, 15.0239808306587, 15.249918032566605, 15.472556349873154, 15.692036196746425, 15.908488300275426, 16.122034611053284, 16.33278910657944, 16.540858502508268, 16.746342884343438, 16.949336270190642, 17.14992711354774, 17.348198753761157, 17.54422982065614, 17.73809459891338, 17.92986335698072, 18.119602644649802, 18.30737556287083, 18.493242008906932, 18.67725889952806, 18.859480374602054, 19.03995798314692, 19.218740853656364, 19.39587585029354, 19.57140771636011, 19.745379206285204, 19.917831207237402, 20.08880285133985, 20.25833161936096, 20.426453436659045, 20.59320276207662, 20.758612670407434, 20.922714928995234, 21.085540068966697, 21.247117451550928, 21.40747532989353, 21.566640906733717, 21.724640388278008, 21.881499034572567, 22.037241206648353, 22.191890410688316, 22.34546933944329, 22.49799991110321, 22.64950330581225, 22.800000000000004, 22.949509798686336, 23.098051865904196, 23.245644753372623, 23.39230642754152, 23.538054295119643, 23.682905227188666, 23.826875581997736, 23.969981226525817, 24.11223755689215, 24.25365951768929, 24.394261620307347, 24.534057960313053, 24.67306223394251, 24.8112877537624, 24.948747463550152, 25.085453952440254, 25.22141946838045, 25.35665593093853, 25.491174943497604, 25.62498780487515, 25.758105520398825, 25.8905388124697, 26.022298130641733, 26.153393661244046, 26.28383533657142], [0.0, 2.6324893162176366, 3.722902093797257, 4.559605246071199, 5.264978632435273, 5.886425061104576, 6.448255578061404, 6.96491205974634, 7.445804187594514, 7.897467948652909, 8.324662155306966, 8.73097932651315, 9.119210492142399, 9.491575211733824, 9.849873095629201, 10.195587280779856, 10.529957264870546, 10.854031509075327, 11.16870628139177, 11.474754899343168, 11.772850122209151, 12.063581557729862, 12.347469376354008, 12.62497524750049, 12.896511156122807, 13.162446581088183, 13.423114392718258, 13.678815738213599, 13.92982411949268, 14.176388820852793, 14.4187378088375, 14.65708020036733, 14.891608375189028, 15.122499793354274, 15.34991856655924, 15.574016822900893, 15.794935897305818, 16.012807374099022, 16.227754003558225, 16.43989051058431, 16.64932431061393, 16.85615614545618, 17.060480649735517, 17.26238685697896, 17.4619586530263, 17.659275183313724, 17.854411219639815, 18.04743749123404, 18.238420984284797, 18.42742521352346, 18.614510468986285, 18.79973404067196, 18.98315042346765, 19.16481150442133, 19.344766734184212, 19.523063284228733, 19.699746191258402, 19.874858490062262, 20.04844133592435, 20.22053411757464, 20.391174561559712, 20.560398828816528, 20.728241604149638, 20.894736179239022, 21.059914529741093, 21.223807386988792, 21.38644430474594, 21.54785372142664, 21.708063018150654, 21.867098572970306, 22.024985811573185, 22.181749254736427, 22.33741256278354, 22.491998577271875, 22.645529360118744, 22.798026230355994, 22.949509798686336, 23.1, 23.24951612399708, 23.398076844048532, 23.545700244418303, 23.692403845958733, 23.83820463038272, 23.98311906320777, 24.127163115459723, 24.270352284217058, 24.412701612070716, 24.55422570556848, 24.694938752708016, 24.834854539537776, 24.973986465920895, 25.112347560512937, 25.24995049500098, 25.38680759764804, 25.522930866183845, 25.658331980080078, 25.793022312245615, 25.92701294017497, 26.060314656580797, 26.19293797953945, 26.324893162176366, 26.456190201916836], [0.0, 2.6495282598983545, 3.7469987990390394, 4.589117562233508, 5.299056519796709, 5.924525297439451, 6.489992295835182, 7.009992867328754, 7.493997598078079, 7.948584779695063, 8.378544026261366, 8.787491109526087, 9.178235124467015, 9.553009996854396, 9.913626985114984, 10.261578825892242, 10.598113039593418, 10.924284873619875, 11.240996397117117, 11.549025932952098, 11.849050594878902, 12.14166380690884, 12.42738910632479, 12.706691150728426, 12.979984591670364, 13.247641299491772, 13.509996299037246, 13.767352686700521, 14.019985734657508, 14.26814634071294, 14.512063946937392, 14.751949023773099, 14.987995196156158, 15.22038107275899, 15.449271827500484, 15.67482057313576, 15.897169559390125, 16.116451222275956, 16.33278910657944, 16.546298679765215, 16.757088052522732, 16.965258618718433, 17.170905625505025, 17.37411868268431, 17.574982219052174, 17.773575892318352, 17.96997495824633, 18.164250603864726, 18.35647024893403, 18.546697819288482, 18.734993995195197, 18.92141643746578, 19.10601999370879, 19.288856886814216, 19.469976887505545, 19.64942747257538, 19.827253970229968, 20.003499693803583, 20.17820606496029, 20.351412727375955, 20.523157651784484, 20.693477233176644, 20.862406380856452, 21.029978601986265, 21.196226079186836, 21.36117974270148, 21.52486933758252, 21.68732348631338, 21.84856974723975, 22.008634669147472, 22.1675438422934, 22.32532194616687, 22.481992794234234, 22.63757937589618, 22.792103895867097, 22.945587811167535, 23.098051865904196, 23.24951612399708, 23.400000000000006, 23.54952228814844, 23.698101189757804, 23.845754339085193, 23.99249882775865, 24.13835122786973, 24.28332761381768, 24.427443582986747, 24.57071427533193, 24.71315439194277, 24.85477821264958, 24.99559961273184, 25.1356320787841, 25.27488872379066, 25.413382301456853, 25.551125219841108, 25.68812955432918, 25.824407059988815, 25.95996918334073, 26.094827073579168, 26.228991593273275, 26.362473328578265, 26.495282598983543, 26.62742946662333], [0.0, 2.6664583251946765, 3.7709415269929605, 4.618441295502196, 5.332916650389353, 5.9623820743055385, 6.5314623171231725, 7.0547856097829085, 7.541883053985921, 7.999374975584029, 8.432081593533118, 8.843641783790206, 9.236882591004392, 9.614052215377239, 9.976973488989534, 10.327148686835104, 10.665833300778706, 10.994089321085218, 11.312824580978882, 11.622822376686312, 11.924764148611077, 12.21924711264978, 12.5067981514055, 12.787884891568272, 13.062924634246345, 13.332291625973385, 13.596323032349593, 13.85532388650659, 14.109571219565817, 14.359317532529184, 14.604793733565703, 14.846211637990347, 15.083766107971842, 15.317636893463694, 15.547990223819928, 15.77498019016189, 15.998749951168058, 16.219432789095926, 16.43715303816327, 16.652026903653503, 16.864163187066236, 17.073663930158638, 17.280624988697603, 17.485136545077363, 17.687283567580412, 17.887146222916613, 18.084800247721844, 18.280317283898547, 18.473765182008783, 18.665208276362737, 18.854707634964804, 19.04232128707002, 19.228104430754478, 19.412109622604138, 19.59438695136952, 19.774984197212397, 19.95394697797907, 20.13131888376914, 20.307141600924542, 20.481455026437942, 20.654297373670207, 20.825705270170324, 20.99571384830723, 21.164356829348726, 21.331666601557412, 21.497674292815955, 21.662409838242834, 21.825902043214615, 21.988178642170435, 22.149266353538664, 22.30919093109385, 22.46797721202334, 22.625649161957764, 22.782229917196428, 22.93774182433833, 23.092206477510977, 23.245644753372623, 23.398076844048532, 23.54952228814844, 23.700000000000003, 23.849528297222154, 23.998124926752094, 24.145807089430665, 24.29259146324245, 24.43849422529956, 24.583531072651063, 24.727717241993854, 24.871067528355113, 25.013596302811, 25.155317529301833, 25.296244780599352, 25.436391253477762, 25.575769783136543, 25.71439285691965, 25.852272627372628, 25.989420924676256, 26.12584926849269, 26.26156887925777, 26.39659068895072, 26.53092535137062, 26.66458325194677, 26.797574517108828], [0.0, 2.6832815729997477, 3.7947331922020555, 4.647580015448901, 5.366563145999495, 6.000000000000001, 6.572670690061994, 7.0992957397195395, 7.589466384404111, 8.049844718999243, 8.485281374238571, 8.899438184514796, 9.295160030897803, 9.67470929795826, 10.039920318408907, 10.392304845413264, 10.73312629199899, 11.063453348751466, 11.384199576606166, 11.696153213770758, 12.000000000000002, 12.296340919151518, 12.585706178041821, 12.868566353716332, 13.145341380123988, 13.416407864998739, 13.682105101189658, 13.942740046346703, 14.198591479439079, 14.449913494550756, 14.69693845669907, 14.93987951758648, 15.178932768808222, 15.414279094398157, 15.64608577248636, 15.874507866387544, 16.099689437998485, 16.321764610482536, 16.540858502508268, 16.757088052522732, 16.970562748477143, 17.181385275931625, 17.389652095427326, 17.595453958338215, 17.798876369029593, 18.0, 18.198901065723724, 18.39565166010707, 18.590320061795605, 18.782971010998235, 18.97366596101028, 19.162463307205577, 19.34941859591652, 19.53458471531965, 19.71801207018598, 19.8997487421324, 20.079840636817814, 20.25833161936096, 20.435263639111685, 20.610676844781203, 20.784609690826528, 20.95709903588758, 21.12818023399081, 21.29788721915862, 21.46625258399798, 21.633307652783937, 21.79908254950194, 21.963606261267753, 22.126906697502932, 22.289010745208053, 22.449944320643652, 22.609732417700126, 22.768399153212332, 22.92596780945136, 23.082460874005616, 23.2379000772445, 23.392306427541516, 23.545700244418303, 23.698101189757804, 23.84952829722215, 24.000000000000004, 24.14953415699773, 24.298148077579906, 24.445858544956035, 24.592681838303037, 24.73863375370597, 24.88372962399327, 25.027984337537053, 25.171412356083643, 25.314027731674784, 25.455844122715714, 25.596874809241854, 25.737132707432664, 25.876630383417396, 26.01538006641456, 26.153393661244042, 26.290682760247975, 26.427258654654295, 26.563132345414385, 26.698314553544392, 26.832815729997478, 26.966646065093087], [0.0, 2.7, 3.8183766184073566, 4.676537180435969, 5.4, 6.037383539249433, 6.613622305514581, 7.143528539874395, 7.636753236814713, 8.1, 8.538149682454625, 8.95488693395958, 9.353074360871938, 9.734988443752771, 10.102474944289641, 10.457055034760025, 10.8, 11.132385189167683, 11.45512985522207, 11.76902714755982, 12.074767078498866, 12.372954376380768, 12.664122551523262, 12.948745112944346, 13.227244611029162, 13.5, 13.767352686700521, 14.029611541307908, 14.28705707974879, 14.539944979263161, 14.788509052639487, 15.03296377964106, 15.273506473629427, 15.51031914565268, 15.743570116082314, 15.973415414368965, 16.2, 16.423458831805196, 16.643917808016237, 16.861494595675676, 17.07629936490925, 17.288435441068692, 17.497999885701223, 17.705084015615398, 17.90977386791916, 18.1121506177483, 18.312290954438225, 18.51026742108282, 18.706148721743876, 18.900000000000002, 19.091883092036785, 19.281856757065697, 19.469976887505542, 19.656296701057403, 19.840866916543746, 20.02373591515829, 20.204949888579282, 20.384552975231024, 20.562587385832554, 20.73909351924524, 20.91411006952005, 21.08767412494797, 21.259821259831888, 21.430585619623184, 21.6, 21.768095920406083, 21.934903692517093, 22.100452484055616, 22.264770378335367, 22.4278844298788, 22.589820716420043, 22.750604387576168, 22.91025971044414, 23.068810112357337, 23.226278221015093, 23.382685902179844, 23.53805429511964, 23.692403845958733, 23.845754339085193, 23.99812492675209, 24.14953415699773, 24.300000000000004, 24.449539872971027, 24.598170663689608, 24.745908752761537, 24.892770034690802, 25.038769937838406, 25.1839234433398, 25.328245103046523, 25.47174905655283, 25.614449047363873, 25.756358438257536, 25.897490225888692, 26.037857054680984, 26.177471230048177, 26.316344730984202, 26.454489222058324, 26.59191606484949, 26.728636328851493, 26.864660801878742, 27.0, 27.134664177026412], [0.0, 2.716615541441225, 3.84187454245971, 4.705316142407438, 5.43323108288245, 6.0745370193949775, 6.654321903845651, 7.187489130426565, 7.68374908491942, 8.149846624323676, 8.590692637965812, 9.009994450608726, 9.410632284814875, 9.794896630388706, 10.16464460765845, 10.52140675005011, 10.8664621657649, 11.200892821556684, 11.525623627379128, 11.841452613594333, 12.149074038789955, 12.449096352747858, 12.742056348957183, 13.028430450365082, 13.308643807691302, 13.583077707206126, 13.852075656738238, 14.115948427222312, 14.37497826085313, 14.629422408283933, 14.879516121164695, 15.125475199146639, 15.36749816983884, 15.605768164367946, 15.840454538932907, 16.07171428317465, 16.29969324864735, 16.524527224704496, 16.746342884343438, 16.965258618718433, 17.181385275931625, 17.394826817189074, 17.605680901345455, 17.814039407164227, 18.019988901217452, 18.22361105818493, 18.42498303934091, 18.62417783420251, 18.82126456962975, 19.01630879008858, 19.20937271229855, 19.400515457069694, 19.589793260777412, 19.777259668619415, 19.962965711536953, 20.14696006845698, 20.3292892153169, 20.509997562164656, 20.689127579480004, 20.866719914735043, 21.04281350010022, 21.21744565210431, 21.390652163971065, 21.562467391279693, 21.7329243315298, 21.902054698132776, 22.069888989299425, 22.23645655224771, 22.401785643113367, 22.56590348290979, 22.728836309850976, 22.89060942832235, 23.051247254758255, 23.21077336066164, 23.369210512980537, 23.526580712037184, 23.682905227188666, 23.838204630382723, 23.992498827758652, 24.145807089430665, 24.29814807757991, 24.44953987297103, 24.600000000000005, 24.749545450371407, 24.898192705495717, 25.045957757690168, 25.192856130260427, 25.338902896534414, 25.484112697914366, 25.628499761008253, 25.772077913897437, 25.91486060159306, 26.056860900730165, 26.198091533544964, 26.338564881177565, 26.478292996339476, 26.617287615382605, 26.755560169803964, 26.893121797217965, 27.02998335182618, 27.166155414412252, 27.301648301888303], [0.0, 2.7331300737432893, 3.8652296180175374, 4.73392015141785, 5.466260147486579, 6.11146463623901, 6.694774081326419, 7.23118247591637, 7.730459236035075, 8.199390221229867, 8.64291617453276, 9.064766957842878, 9.4678403028357, 9.854440623394105, 10.226436329435586, 10.585367258626409, 10.932520294973157, 11.268983982595769, 11.595688854052613, 11.91343779099887, 12.22292927247802, 12.524775447088862, 12.819516371532899, 13.107631364972088, 13.389548162652838, 13.665650368716449, 13.936283579204321, 14.20176045425355, 14.46236495183274, 14.718355886443295, 14.969969939849578, 15.217424223566878, 15.46091847207015, 15.700636929755431, 15.936749982352111, 16.169415573854238, 16.398780442459735, 16.624981202996892, 16.848145298518766, 17.068391839889312, 17.28583234906552, 17.500571419242288, 17.712707302950612, 17.922332437492614, 18.129533915685755, 18.334393908717026, 18.536990046930487, 18.737395763552627, 18.9356806056714, 19.13191051620303, 19.32614809008769, 19.518452807535745, 19.70888124678821, 19.897487278548518, 20.08432224397926, 20.26943511793064, 20.452872658871172, 20.63467954682117, 20.81489851044199, 20.99357044430508, 21.170734517252818, 21.34642827266426, 21.52068772135314, 21.69354742774911, 21.865040589946314, 22.03519911414462, 22.204053683955998, 22.371633825002586, 22.537967965191537, 22.703083491015047, 22.867006800191405, 23.029763350933504, 23.191377708105225, 23.351873586502645, 23.511273891475977, 23.66960075708925, 23.82687558199774, 23.983119063207774, 24.13835122786973, 24.292591463242452, 24.44585854495604, 24.598170663689608, 24.749545450371407, 24.9, 25.049550894177724, 25.19821422244045, 25.34600560246131, 25.49294019920025, 25.639032743065798, 25.78429754715067, 25.92874852359828, 26.072399199153114, 26.215262729944175, 26.35735191554721, 26.4986792123683, 26.6392567463884, 26.779096325305677, 26.918209450110165, 27.05660732612276, 27.194300873528633, 27.331300737432898, 27.467617297465033], [0.0, 2.749545416973504, 3.8884444190447165, 4.762352359916264, 5.499090833947008, 6.14817045957576, 6.7349832961930955, 7.274613391789285, 7.776888838089433, 8.248636250920512, 8.694826047713663, 9.119210492142399, 9.524704719832528, 9.913626985114984, 10.287856919689348, 10.648943609579309, 10.998181667894016, 11.336666176614711, 11.665333257134149, 11.984990613262909, 12.29634091915152, 12.600000000000001, 12.896511156122807, 13.18635658550155, 13.469966592386191, 13.74772708486752, 14.01998573465751, 14.287057079748791, 14.54922678357857, 14.80675521510368, 15.059880477613362, 15.308820986607689, 15.553777676178866, 15.794935897305823, 16.032467059064867, 16.26653005407115, 16.497272501841024, 16.724831837719627, 16.949336270190642, 17.170905625505025, 17.389652095427326, 17.605680901345455, 17.819090885900998, 18.029975041580062, 18.238420984284797, 18.444511378727277, 18.648324321504067, 18.84993368688601, 19.049409439665055, 19.246817918814532, 19.44222209522358, 19.63568180634429, 19.827253970229968, 20.016992781134736, 20.204949888579286, 20.391174561559716, 20.575713839378697, 20.758612670407434, 20.93991403993818, 21.11965908815765, 21.297887219158618, 21.47463620180794, 21.64994226320246, 21.823840175367856, 21.996363335788033, 22.167543842293398, 22.33741256278354, 22.50599920021326, 22.673332353229423, 22.839439572809138, 23.00434741521698, 23.16808149156939, 23.330666514268298, 23.492126340542274, 23.65248401331243, 23.811761799581316, 23.969981226525817, 24.127163115459723, 24.28332761381768, 24.438494225299564, 24.59268183830304, 24.74590875276154, 24.898192705495717, 25.049550894177724, 25.200000000000003, 25.349556209133134, 25.498235233050938, 25.646052327795015, 25.793022312245615, 25.939159585460747, 26.08447814314099, 26.228991593273275, 26.3727131710031, 26.515655752781228, 26.657831869827675, 26.799253720952755, 26.939933184772382, 27.079881831352225, 27.21911093331301, 27.3576314764272, 27.49545416973504, 27.6325894552067], [0.0, 2.765863337187866, 3.9115214431215897, 4.790615826801394, 5.531726674375732, 6.184658438426492, 6.77495387438173, 7.317786550590281, 7.823042886243179, 8.297590011563598, 8.746427842267952, 9.173330910852394, 9.581231653602789, 9.972462083156797, 10.348912986396204, 10.712142642814275, 11.063453348751464, 11.403946685248927, 11.734564329364767, 12.056118778446073, 12.369316876852984, 12.674778104566565, 12.973048986263793, 13.264614581660489, 13.54990774876346, 13.829316685939332, 14.103191128251792, 14.371847480404183, 14.635573101180562, 14.894629904767692, 15.149257407543118, 15.399675321252719, 15.646085772486359, 15.888675212238436, 16.12761606685874, 16.36306817195357, 16.595180023127195, 16.824089871371946, 17.049926686059386, 17.27281100458174, 17.492855684535904, 17.710166571774533, 17.924843095547587, 18.136978800230207, 18.34666182170479, 18.553975315279473, 18.75899784103618, 18.96180371167258, 19.162463307205577, 19.361043360315065, 19.55760721560795, 19.75221506565783, 19.944924166313594, 20.135789033459805, 20.32486162314519, 20.512191496766015, 20.69782597279241, 20.881810266353828, 21.064187617850354, 21.244999411626257, 21.42428528562855, 21.602083232873632, 21.77842969545784, 21.953359651770842, 22.12690669750293, 22.299103120977758, 22.469979973288805, 22.639567133671086, 22.807893370497855, 22.974986398254952, 23.14087293081227, 23.305578731282345, 23.469128658729534, 23.631546711969577, 23.792856070678024, 23.95307913400697, 24.112237556892147, 24.270352284217058, 24.427443582986744, 24.58353107265106, 24.73863375370597, 24.8927700346908, 25.045957757690164, 25.198214222440445, 25.34955620913313, 25.500000000000004, 25.64956139975887, 25.79825575499243, 25.946097972527586, 26.093102536877442, 26.239283526803852, 26.384654631054016, 26.529229163320977, 26.673020076474284, 26.816039976103855, 26.958301133417145, 27.09981549752692, 27.240594707164533, 27.380650101851124, 27.519992732557185, 27.658633371878665, 27.796582523756413], [0.0, 2.7820855486487113, 3.9344631145812006, 4.818713521262704, 5.5641710972974225, 6.220932405998317, 6.814690014960329, 7.3607064878311785, 7.868926229162401, 8.346256645946132, 8.79772697916911, 9.22713389953782, 9.637427042525408, 10.030952098380293, 10.409610943738484, 10.774970997640782, 11.128342194594845, 11.470832576583097, 11.803389343743602, 12.126829758844643, 12.441864811996634, 12.749117616525467, 13.049137902558929, 13.342413574762254, 13.629380029920657, 13.910427743243556, 14.185908501044269, 14.45614056378811, 14.721412975662357, 14.981989187020528, 15.238110119040353, 15.489996772110704, 15.737852458324802, 15.981864722240646, 16.22220700151493, 16.459040069214243, 16.692513291892265, 16.922765731404546, 17.149927113547744, 17.374118682684312, 17.59545395833822, 17.81403940716423, 18.029975041580062, 18.243354954612926, 18.45426779907564, 18.66279721799495, 18.869022232219667, 19.0730175903028, 19.274854085050816, 19.47459884054098, 19.672315572906005, 19.86806482775814, 20.061904196760587, 20.253888515541902, 20.444070044880988, 20.632498636859278, 20.819221887476967, 21.004285277057157, 21.187732299611493, 21.36960458220975, 21.549941995281564, 21.728782754678186, 21.90616351623442, 22.082119463493537, 22.25668438918969, 22.429890771022492, 22.601769842204835, 22.772351657218014, 22.941665153166195, 23.10973820708491, 23.27659768952499, 23.442269514703565, 23.606778687487203, 23.770149347448367, 23.93240481021496, 24.093567606313517, 24.253659517689286, 24.412701612070716, 24.57071427533193, 24.727717241993854, 24.88372962399327, 25.038769937838403, 25.19285613026042, 25.346005602461307, 25.498235233050934, 25.64956139975887, 25.800000000000004, 25.949566470367092, 26.098275805117858, 26.246142573719286, 26.393180937507324, 26.539404665515768, 26.68482714952451, 26.82946141837365, 26.97332015158683, 27.116415692344003, 27.258760059841315, 27.40036496107306, 27.541241802068402, 27.681401698613463, 27.820855486487112, 27.959613731237425], [0.0, 2.7982137159266447, 3.957271787481876, 4.846648326421054, 5.596427431853289, 6.256996084384264, 6.854195795277518, 7.40337760755184, 7.914543574963752, 8.394641147779932, 8.848728722251575, 9.280624978954814, 9.693296652842108, 10.089103032480143, 10.469957019969089, 10.837435120913065, 11.192854863706579, 11.537330713817648, 11.871815362445627, 12.197130810153675, 12.513992168768528, 12.823026163897508, 13.124785712536417, 13.419761547807028, 13.708391590555037, 13.991068579633223, 14.26814634071294, 14.539944979263161, 14.80675521510368, 15.068842025849234, 15.326447729333761, 15.579794607118542, 15.829087149927505, 16.07451398954258, 16.316249569064578, 16.554455593585676, 16.789282295559865, 17.02086954300514, 17.24934781375806, 17.47483905505284, 17.69745744450315, 17.917310065966937, 18.134497511648895, 18.34911442004763, 18.561249957909627, 18.77098825315279, 18.978408784721655, 19.1835867344978, 19.386593305684215, 19.587496011486515, 19.786358937409382, 19.983242980057067, 20.178206064960285, 20.371303345637955, 20.562587385832554, 20.752108326625514, 20.939914039938177, 21.126050269749904, 21.310560762213655, 21.49348738571756, 21.67487024182613, 21.85474776793363, 22.033156832374246, 22.21013282265552, 22.385709727413158, 22.559920212624867, 22.73279569256716, 22.904366395951666, 23.074661427635295, 23.243708826260924, 23.41153561815201, 23.57816786775427, 23.743630724891254, 23.90794846907614, 24.071144551101014, 24.23324163210527, 24.39426162030735, 24.554225705568484, 24.71315439194277, 24.871067528355113, 25.027984337537056, 25.183923443339804, 25.338902896534414, 25.49294019920025, 25.646052327795015, 25.798255754992432, 25.949566470367095, 26.1, 26.249571425072833, 26.398295399513962, 26.546186166754726, 26.693257575650073, 26.839523095614055, 26.984995831016914, 27.129688534887386, 27.273613621960695, 27.416783181110073, 27.559208987197007, 27.70090251237313, 27.84187493686444, 27.982137159266447, 28.121699806377286], [0.0, 2.814249455894058, 3.97994974842648, 4.874423042781577, 5.628498911788116, 6.292853089020911, 6.8934751758456345, 7.445804187594514, 7.95989949685296, 8.442748367682173, 8.899438184514796, 9.333809511662428, 9.748846085563153, 10.146920715172659, 10.529957264870546, 10.89954127475097, 11.256997823576231, 11.60344776348823, 11.93984924527944, 12.267028980156525, 12.585706178041821, 12.896511156122807, 13.200000000000001, 13.496666255042394, 13.786950351691269, 14.07124727947029, 14.34991289172168, 14.623269128344731, 14.891608375189028, 15.155197128378108, 15.414279094398156, 15.669077828640715, 15.91979899370592, 16.166632302368978, 16.409753197412815, 16.64932431061393, 16.885496735364345, 17.118411141224527, 17.348198753761153, 17.574982219052174, 17.798876369029593, 18.01998890121745, 18.238420984284797, 18.454267799075637, 18.667619023324857, 18.878559267062727, 19.08716846470424, 19.293522228976233, 19.497692171126307, 19.699746191258406, 19.899748742132402, 20.097761069333075, 20.293841430345317, 20.48804529475665, 20.680425527536904, 20.871032557111302, 21.059914529741093, 21.247117451550928, 21.432685319390107, 21.616660241582185, 21.79908254950194, 21.979990900817043, 22.159422375143265, 22.337412562783545, 22.513995647152463, 22.689204481426845, 22.86307065990918, 23.03562458454296, 23.20689552697646, 23.376911686533788, 23.545700244418303, 23.713287414443407, 23.87969849055888, 24.044957891416654, 24.209089202198417, 24.372115213907882, 24.53405796031305, 24.694938752708016, 24.85477821264958, 25.013596302811, 25.171412356083643, 25.328245103046523, 25.484112697914362, 25.639032743065794, 25.793022312245615, 25.94609797252759, 26.098275805117858, 26.24957142507283, 26.400000000000002, 26.549576267805104, 26.69831455354439, 26.846228785436512, 26.993332510084787, 27.139638906956744, 27.285160802164977, 27.429910681589906, 27.573900703382538, 27.717142709882637, 27.859648238985358, 28.001428534987287, 28.14249455894058, 28.282856998542428], [0.0, 2.830194339616981, 4.0024992192379, 4.902040391510457, 5.660388679233962, 6.328506932918696, 6.932532004974806, 7.487990384609211, 8.0049984384758, 8.490583018850943, 8.949860334105779, 9.38669270829721, 9.804080783020915, 10.204410811016968, 10.589617556833673, 10.961295543867065, 11.320777358467923, 11.669190203266034, 12.0074976577137, 12.336531116971255, 12.657013865837392, 12.969579792730372, 13.274788133902552, 13.573135231036344, 13.865064009949611, 14.150971698084906, 14.431216164966834, 14.706121174531374, 14.975980769218422, 15.241062955056645, 15.501612819316575, 15.757855184002675, 16.0099968769516, 16.258228685807076, 16.50272704737008, 16.74365551485099, 16.981166037701886, 17.215400082484287, 17.446489618258454, 17.674557985986524, 17.899720668211557, 18.122085972646747, 18.341755641159327, 18.55882539386585, 18.77338541659442, 18.985520798756088, 19.19531192765567, 19.40283484442415, 19.60816156604183, 19.81136037731887, 20.0124960961895, 20.211630315241766, 20.408821622033937, 20.60412580043133, 20.797596014924416, 20.989282979654163, 21.179235113667346, 21.367498683748643, 21.55411793602327, 21.739135217390775, 21.92259108773413, 22.104524423746376, 22.284972515127766, 22.463971153827632, 22.641554716935847, 22.8177562437677, 22.99260750763166, 23.16613908272157, 23.338380406532067, 23.509359838158076, 23.679104712805337, 23.84764139280864, 24.0149953154274, 24.18119103766396, 24.346252278328176, 24.510201957552287, 24.67306223394251, 24.834854539537776, 24.99559961273184, 25.155317529301833, 25.314027731674784, 25.47174905655283, 25.628499761008253, 25.784297547150665, 25.939159585460743, 26.093102536877446, 26.24614257371929, 26.39829539951396, 26.549576267805104, 26.7, 26.849581002317336, 26.998333281889828, 27.14627046207269, 27.293405797005256, 27.439752185469896, 27.58532218408913, 27.730128019899222, 27.87418160233588, 28.017494534665296, 28.16007812489163, 28.30194339616981, 28.44310109675104], [0.0, 2.846049894151541, 4.024922359499621, 4.929503017546495, 5.692099788303082, 6.3639610306789285, 6.971370023173351, 7.52994023880668, 8.049844718999243, 8.538149682454623, 9.0, 9.439279633531365, 9.85900603509299, 10.261578825892242, 10.648943609579309, 11.022703842524301, 11.384199576606164, 11.734564329364767, 12.074767078498864, 12.4056438768812, 12.727922061357857, 13.042239071570496, 13.349157276772194, 13.649175799292793, 13.942740046346701, 14.230249470757707, 14.512063946937392, 14.788509052639487, 15.05988047761336, 15.326447729333761, 15.588457268119896, 15.846135175493108, 16.099689437998485, 16.349311912126456, 16.5951800231272, 16.837458240482736, 17.076299364909246, 17.31184565550421, 17.544229820656135, 17.77357589231835, 18.0, 18.22361105818493, 18.444511378727277, 18.662797217994946, 18.87855926706273, 19.09188309203678, 19.302849530574495, 19.511535049810917, 19.71801207018598, 19.92234925906079, 20.12461179749811, 20.32486162314519, 20.523157651784484, 20.71955597979841, 20.914110069520053, 21.106870919205434, 21.297887219158618, 21.48720549536398, 21.674870241826135, 21.86092404268401, 22.045407685048602, 22.228360263411247, 22.409819276379718, 22.58982071642004, 22.76839915321233, 22.94558781116753, 23.12141864159723, 23.29592238998061, 23.469128658729534, 23.641065965814654, 23.811761799581316, 23.98124267005361, 24.149534156997728, 24.316660954991335, 24.482646915723798, 24.647515087732472, 24.8112877537624, 24.973986465920895, 25.1356320787841, 25.296244780599352, 25.455844122715714, 25.614449047363877, 25.772077913897437, 25.92874852359828, 26.08447814314099, 26.239283526803856, 26.393180937507328, 26.546186166754726, 26.69831455354439, 26.849581002317336, 27.0, 27.14958563219704, 27.298351598585587, 27.446311227558436, 27.593477490160605, 27.73986301336039, 27.885480092693403, 28.030340704315392, 28.174456516497347, 28.317838900594097, 28.460498941515414, 28.602447447727272], [0.0, 2.8618176042508368, 4.047221268969612, 4.956813492557492, 5.7236352085016735, 6.399218702310463, 7.009992867328754, 7.571657678474378, 8.094442537939225, 8.58545281275251, 9.049861877399014, 9.491575211733826, 9.913626985114984, 10.318430113151903, 10.707940978544848, 11.083771921146699, 11.447270417003347, 11.799576263578281, 12.141663806908838, 12.474373731775076, 12.798437404620927, 13.114495796636637, 13.423114392718258, 13.72479508043745, 14.019985734657508, 14.309088021254185, 14.592463808418373, 14.870440477672476, 15.143315356948756, 15.411359446849588, 15.674820573135758, 15.933926069867402, 16.18888507587845, 16.439890510584313, 16.68712078220806, 16.930741271426957, 17.17090562550502, 17.407756891684812, 17.641428513586987, 17.872045210327776, 18.099723754798028, 18.324573664890544, 18.54669781928848, 18.766193007640094, 18.983150423467652, 19.197656106931387, 19.409791343546175, 19.619633024090945, 19.827253970229968, 20.03272322975586, 20.236106344848064, 20.437465596301323, 20.636860226303806, 20.8343466420236, 21.02997860198626, 21.223807386988792, 21.415881957089695, 21.606249096037008, 21.794953544341407, 21.982038122066843, 22.167543842293398, 22.351510016104058, 22.533974349856706, 22.71497303542313, 22.894540834006694, 23.072711154088502, 23.249516123997076, 23.42498665954796, 23.599152527156562, 23.772042402789037, 23.9436839270819, 24.1141037569303, 24.283327613817676, 24.451380329134796, 24.61828588671437, 24.78406746278746, 24.948747463550152, 25.112347560512937, 25.27488872379066, 25.436391253477762, 25.596874809241854, 25.756358438257536, 25.91486060159306, 26.072399199153114, 26.228991593273275, 26.38465463105402, 26.53940466551577, 26.693257575650073, 26.846228785436516, 26.998333281889828, 27.14958563219704, 27.3, 27.4495901608749, 27.598369517056625, 27.746351111452476, 27.893547640986796, 28.039971469315017, 28.1856346389433, 28.330548882787284, 28.47472563520148, 28.61817604250837, 28.760910973055083], [0.0, 2.877498913987632, 4.069397989875161, 4.983974317750846, 5.754997827975264, 6.434283176858166, 7.0484040746824395, 7.6131465242697125, 8.138795979750322, 8.632496741962894, 9.099450532861862, 9.54358423235212, 9.967948635501692, 10.37496987947435, 10.766615066955817, 11.144505372604026, 11.509995655950528, 11.864231959971114, 12.208193969625484, 12.542726976220125, 12.868566353716332, 13.186356585501548, 13.496666255042394, 13.800000000000004, 14.096808149364879, 14.38749456993816, 14.672423112764983, 14.951922953252536, 15.226293048539425, 15.49580588417395, 15.760710643876438, 16.021235907382426, 16.277591959500644, 16.529972776747098, 16.77855774493148, 17.02351315093333, 17.26499348392579, 17.50314257497779, 17.73809459891338, 17.969974958246326, 18.198901065723724, 18.42498303934091, 18.648324321504067, 18.869022232219663, 19.08716846470424, 19.302849530574495, 19.516147160748712, 19.727138667328315, 19.935897271003384, 20.142492397913426, 20.346989949375807, 20.549452547452454, 20.7499397589487, 20.948508300115314, 21.145212224047317, 21.340103092534488, 21.533230133911633, 21.724640388278008, 21.914378841299612, 22.102488547672635, 22.289010745208053, 22.473984960393654, 22.65744910619905, 22.839439572809138, 23.019991311901055, 23.199137915017445, 23.376911686533788, 23.553343711668624, 23.72846391994223, 23.902301144450508, 24.074883177286658, 24.246236821412104, 24.416387939250967, 24.585361498257456, 24.753181613683523, 24.919871588754226, 25.08545395244025, 25.24995049500098, 25.413382301456853, 25.57576978313654, 25.737132707432664, 25.89749022588869, 26.05686090073016, 26.215262729944172, 26.372713171003095, 26.529229163320977, 26.68482714952451, 26.83952309561405, 26.993332510084787, 27.14627046207269, 27.298351598585583, 27.4495901608749, 27.60000000000001, 27.749594591633233, 27.89838705015041, 28.046390142048587, 28.193616298729758, 28.340077628686913, 28.485785929126127, 28.630752697056366, 28.77498913987632, 28.918506185486144], [0.0, 2.8930952282978866, 4.091454509095757, 5.0109879265470205, 5.786190456595773, 6.469157595854349, 7.0866070866106305, 7.654410493303845, 8.182909018191515, 8.679285684893658, 9.148770409186145, 9.595311355031686, 10.021975853094041, 10.431203190428226, 10.82497113160123, 11.204909638189859, 11.572380913191546, 11.928537211242627, 12.27436352728727, 12.610709734190223, 12.938315191708698, 13.257827876390612, 13.569819453478372, 13.874797295816617, 14.173214173221261, 14.465476141489434, 14.751949023773099, 15.032963779641062, 15.30882098660769, 15.579794607118544, 15.84613517549311, 16.10807251039056, 16.36581803638303, 16.619566781357452, 16.86949910341146, 17.115782190715095, 17.358571369787317, 17.59801125127496, 17.83423673724222, 18.06737390989626, 18.29754081837229, 18.52484817751552, 18.749399990399695, 18.97129410451485, 19.190622710063373, 19.407472787563044, 19.6219265109214, 19.834061611278713, 20.043951706188082, 20.251666598085208, 20.457272545478787, 20.6608325098482, 20.862406380856452, 21.062051182161724, 21.25982125983189, 21.455768455126467, 21.64994226320246, 21.842389979120878, 22.033156832374253, 22.222286111019272, 22.409819276379718, 22.595796069180658, 22.780254607883556, 22.963231479911535, 23.144761826383093, 23.324879420910197, 23.50361674296107, 23.681005046239065, 23.857074422485255, 24.03185386107364, 24.205371304733173, 24.377653701699842, 24.54872705457454, 24.718616466137423, 24.88734618234737, 25.0549396327351, 25.221419468380446, 25.38680759764804, 25.551125219841108, 25.71439285691965, 25.876630383417396, 26.037857054680984, 26.19809153354496, 26.357351915547206, 26.515655752781225, 26.673020076474284, 26.82946141837365, 26.98499583101691, 27.139638906956744, 27.293405797005256, 27.446311227558432, 27.59836951705662, 27.749594591633233, 27.900000000000006, 28.04959892761392, 28.19840421016764, 28.346428346442522, 28.49368351056073, 28.640181563670296, 28.785934065095063, 28.93095228297887, 29.075247204452115], [0.0, 2.9086079144497976, 4.113392760240627, 5.037856687124, 5.817215828899595, 6.503845016603641, 7.124605252222751, 7.695453203028396, 8.226785520481254, 8.725823743349391, 9.197825830053535, 9.646761114488118, 10.075713374248, 10.487134975769122, 10.883014288330232, 11.264990013311152, 11.63443165779919, 11.992497654784012, 12.34017828072188, 12.678327965469267, 13.007690033207282, 13.328915934913837, 13.642580401082489, 13.949193525075207, 14.249210504445502, 14.543039572248988, 14.831048513169932, 15.113570061372, 15.390906406056793, 15.663332978647936, 15.931101656822106, 16.194443491518935, 16.453571040962508, 16.708680378773188, 16.959952830123086, 17.207556479639987, 17.451647486698782, 17.69237123734408, 17.92986335698072, 18.164250603864726, 18.39565166010707, 18.62417783420251, 18.84993368688601, 19.073017590302797, 19.293522228976236, 19.51153504981092, 19.72713866732832, 19.94041122946064, 20.151426748496, 20.360255401148585, 20.566963801203133, 20.771615247736516, 20.974269951538243, 21.174985242025556, 21.373815756668254, 21.57081361469706, 21.766028576660464, 21.95950819121412, 22.151297930369683, 22.341441314293043, 22.529980026622304, 22.716954021171063, 22.902401620790776, 23.08635960908519, 23.26886331559838, 23.449946695035365, 23.62964240101826, 23.807981854831795, 23.984995309568024, 24.160711910041062, 24.3351597488079, 24.508365918600123, 24.68035656144376, 24.851156914719283, 25.02079135439165, 25.18928343562, 25.356655930938533, 25.52293086618385, 25.68812955432918, 25.85227262737263, 26.015380066414565, 26.17747123004818, 26.338564881177565, 26.4986792123683, 26.657831869827675, 26.81603997610386, 26.973320151586833, 27.129688534887386, 27.285160802164977, 27.4397521854699, 27.593477490160605, 27.746351111452476, 27.898387050150415, 28.04959892761393, 28.200000000000003, 28.34960317182588, 28.498421008891004, 28.64646575059479, 28.793749321684384, 28.940283343464355, 29.086079144497976, 29.231147770828304], [0.0, 2.9240383034426887, 4.135214625627066, 5.06458290484024, 5.848076606885377, 6.5383484153110105, 7.162401831787993, 7.736278174936576, 8.270429251254132, 8.772114910328066, 9.246621004453464, 9.697937925146768, 10.12916580968048, 10.542770034483347, 10.94074951728628, 11.324751652906123, 11.696153213770755, 12.056118778446072, 12.405643876881198, 12.745587471748802, 13.076696830622021, 13.399626860476376, 13.714955340794953, 14.023195071024293, 14.324803663575986, 14.620191517213446, 14.909728367747013, 15.19374871452072, 15.472556349873152, 15.746428166412851, 16.015617378046965, 16.280356261458163, 16.540858502508264, 16.797321215003304, 17.049926686059386, 17.298843892006193, 17.54422982065613, 17.786230629337965, 18.02498266295976, 18.26061335223984, 18.49324200890693, 18.72298053195591, 18.94993403682451, 19.174201417529748, 19.395875850293535, 19.61504524593303, 19.83179265724609, 20.046196646745734, 20.25833161936096, 20.468268124098824, 20.676073128135332, 20.881810266353824, 21.085540068966694, 21.28732016952815, 21.48720549536398, 21.685248442201438, 21.88149903457256, 22.076005073382273, 22.26881227187476, 22.459964381093748, 22.649503305812246, 22.837469211801906, 23.02390062521987, 23.208834524809728, 23.39230642754151, 23.574350468252565, 23.75499947379498, 23.93428503214583, 24.112237556892143, 24.28888634746352, 24.464259645450134, 24.6383846873126, 24.811287753762397, 24.982994216066253, 25.153528579505497, 25.322914524201195, 25.491174943497604, 25.658331980080078, 25.824407059988815, 25.989420924676256, 26.153393661244042, 26.316344730984202, 26.478292996339473, 26.639256746388398, 26.799253720952752, 26.958301133417145, 27.116415692344003, 27.273613621960692, 27.429910681589906, 27.58532218408913, 27.73986301336039, 27.893547640986792, 28.046390142048587, 28.19840421016764, 28.34960317182588, 28.499999999999996, 28.649607327151973, 28.798437457612177, 28.94650237938946, 29.093813775440307, 29.24038303442689, 29.386221260992375], [0.0, 2.939387691339814, 4.156921938165306, 5.091168824543143, 5.878775382679628, 6.572670690061995, 7.2, 7.776888838089433, 8.313843876330612, 8.81816307401944, 9.2951600308978, 9.748846085563153, 10.182337649086286, 10.598113039593416, 10.998181667894016, 11.384199576606164, 11.757550765359255, 12.119405926034494, 12.470765814495916, 12.812493902437575, 13.14534138012399, 13.46996659238619, 13.78695035169127, 14.096808149364879, 14.4, 14.696938456699069, 14.987995196156158, 15.273506473629428, 15.553777676178866, 15.829087149927505, 16.099689437998485, 16.36581803638303, 16.627687752661224, 16.88549673536435, 17.139428228502844, 17.389652095427326, 17.63632614803888, 17.87959731090161, 18.1196026446498, 18.356470248934027, 18.5903200617956, 18.821264569629747, 19.04940943966505, 19.274854085050812, 19.497692171126307, 19.71801207018598, 19.93589727100338, 20.151426748495997, 20.36467529817257, 20.575713839378697, 20.784609690826528, 20.991426821443085, 21.196226079186832, 21.399065400152413, 21.6, 21.79908254950194, 21.996363335788033, 22.191890410688316, 22.38570972741316, 22.577865266672134, 22.76839915321233, 22.95735176365079, 23.144761826383093, 23.330666514268298, 23.51510153071851, 23.698101189757796, 23.879698490558877, 24.059925186916104, 24.238811852068988, 24.416387939250967, 24.592681838303037, 24.767720928660353, 24.941531628991832, 25.11413944374762, 25.285569006846575, 25.45584412271571, 25.62498780487515, 25.793022312245615, 25.95996918334073, 26.12584926849269, 26.29068276024798, 26.454489222058328, 26.617287615382605, 26.779096325305677, 26.93993318477238, 27.099815497526922, 27.25876005984132, 27.41678318111007, 27.57390070338254, 27.730128019899226, 27.885480092693403, 28.039971469315017, 28.193616298729758, 28.346428346442526, 28.498421008891004, 28.649607327151973, 28.8, 28.94961139635557, 29.098453567157136, 29.246538256689462, 29.393876913398138, 29.54048070021882], [0.0, 2.9546573405388314, 4.178516483155236, 5.117616632769595, 5.909314681077663, 6.606814663663574, 7.237402849088892, 7.817288532477231, 8.357032966310472, 8.863972021616494, 9.343446901438464, 9.799489782636646, 10.23523326553919, 10.653168542738824, 11.055315463612967, 11.44333867365639, 11.818629362155326, 12.182364302548173, 12.535549449465709, 12.87905276019941, 13.213629327327148, 13.53994091567611, 13.858571354941319, 14.170038814343457, 14.474805698177784, 14.77328670269416, 15.065855435387666, 15.352849898308785, 15.634577064954462, 15.911316727411345, 16.183324751113414, 16.450835845026237, 16.714065932620944, 16.973214191778766, 17.22846481843348, 17.479988558348662, 17.727944043232988, 17.972478960900194, 18.21373108399265, 18.45182917761814, 18.686893802876927, 18.91903803051308, 19.14836807667954, 19.374983870961028, 19.598979565273293, 19.820443990990718, 20.039461070597685, 20.256110189273755, 20.47046653107838, 20.682601383771825, 20.892582415776182, 21.100473928326828, 21.306337085477647, 21.510230124292026, 21.712208547266677, 21.91232529879018, 22.110630927225934, 22.307173734025564, 22.501999911119018, 22.695153667688615, 22.88667734731278, 23.07661153635863, 23.264995164409555, 23.45186559743169, 23.63725872431065, 23.82120903732638, 24.003749707077016, 24.184912652312807, 24.364728605096346, 24.543227171665915, 24.7204368893432, 24.89638527979514, 25.071098898931417, 25.244603383693715, 25.416923495970163, 25.588083163847973, 25.75810552039882, 25.92701294017497, 26.094827073579168, 26.26156887925777, 26.427258654654295, 26.59191606484949, 26.755560169803964, 26.91820945011016, 27.07988183135222, 27.240594707164533, 27.400364961073063, 27.559208987197003, 27.717142709882637, 27.87418160233588, 28.03034070431539, 28.185634638943295, 28.340077628686913, 28.49368351056073, 28.64646575059479, 28.798437457612177, 28.949611396355568, 29.10000000000001, 29.24961538208665, 29.39846934790994, 29.54657340538832, 29.693938775447094], [0.0, 2.9698484809834995, 4.2, 5.143928459844674, 5.939696961966999, 6.640783086353597, 7.274613391789285, 7.857480512225277, 8.4, 8.909545442950497, 9.391485505499116, 9.849873095629203, 10.287856919689348, 10.707940978544848, 11.112155506471279, 11.502173707608486, 11.879393923933998, 12.244998979175131, 12.6, 12.945269406234852, 13.281566172707194, 13.609555466656506, 13.92982411949268, 14.242892964563065, 14.54922678357857, 14.849242404917499, 15.143315356948756, 15.431785379534023, 15.714961024450554, 15.993123522314207, 16.26653005407115, 16.535416535424805, 16.8, 17.06048064973552, 17.317043627594177, 17.569860557215588, 17.819090885900994, 18.06488306078952, 18.307375562870828, 18.54669781928848, 18.78297101099823, 19.016308790088576, 19.24681791881453, 19.474598840540974, 19.699746191258406, 19.922349259060788, 20.142492397913422, 20.36025540114858, 20.575713839378697, 20.7889393668845, 21.0, 21.208960370560366, 21.415881957089695, 21.620823296072704, 21.823840175367856, 22.02498581157318, 22.224311012942557, 22.421864329265752, 22.61769218996492, 22.811839031520453, 23.004347415216973, 23.195258136093248, 23.38461032388609, 23.572441536675832, 23.758787847867996, 23.943683927081896, 24.12716311545972, 24.309257495859473, 24.489997958350262, 24.669414261388532, 24.84753508901839, 25.02438810440727, 25.2, 25.374396544548603, 25.547602627252523, 25.71964229922337, 25.890538812469703, 26.0603146565808, 26.22899159327328, 26.396590688950724, 26.563132345414388, 26.7286363288515, 26.893121797217965, 27.056607326122762, 27.21911093331301, 27.380650101851128, 27.541241802068406, 27.70090251237313, 27.85964823898536, 28.0174945346653, 28.17445651649735, 28.330548882787287, 28.48578592912613, 28.640181563670303, 28.793749321684384, 28.946502379389464, 29.09845356715714, 29.249615382086656, 29.399999999999995, 29.54961928688761, 29.698484809834998, 29.846607847458987], [0.0, 2.98496231131986, 4.221374183841087, 5.170106381884226, 5.96992462263972, 6.674578638386098, 7.3116345641723655, 7.897467948652911, 8.442748367682174, 8.95488693395958, 9.439279633531365, 9.900000000000002, 10.340212763768452, 10.76243466879126, 11.16870628139177, 11.560709320798615, 11.93984924527944, 12.30731489805961, 12.66412255152326, 13.011149065320867, 13.349157276772196, 13.678815738213599, 14.000714267493644, 14.315376348528183, 14.623269128344731, 14.9248115565993, 15.22038107275899, 15.51031914565268, 15.794935897305821, 16.074513989542577, 16.349311912126456, 16.61956678135745, 16.88549673536435, 17.147302994931888, 17.405171645232347, 17.659275183313728, 17.90977386791916, 18.156816901648817, 18.400543470234787, 18.641083659487183, 18.87855926706273, 19.113084523435774, 19.344766734184212, 19.573706853838388, 19.800000000000004, 20.02373591515829, 20.244999382563588, 20.463870601623732, 20.680425527536904, 20.894736179239022, 21.106870919205434, 21.316894708188624, 21.52486933758252, 21.73085364176935, 21.934903692517096, 22.137072977247918, 22.33741256278354, 22.535971245988048, 22.732795692567166, 22.927930565142596, 23.12141864159723, 23.313300924579515, 23.50361674296107, 23.692403845958733, 23.87969849055888, 24.065535522817687, 24.249948453553465, 24.43296952889681, 24.61462979611922, 24.79495916512064, 24.9739864659209, 25.15173950246782, 25.32824510304652, 25.50352916754856, 25.67761671183679, 25.85053190942113, 26.022298130641733, 26.19293797953945, 26.362473328578265, 26.53092535137062, 26.698314553544392, 26.864660801878742, 27.029983351826175, 27.19430087352863, 27.357631476427198, 27.519992732557185, 27.681401698613463, 27.841874936864436, 28.001428534987287, 28.16007812489163, 28.317838900594094, 28.474725635201477, 28.630752697056366, 28.785934065095063, 28.94028334346435, 29.093813775440307, 29.246538256689462, 29.39846934790994, 29.549619286887605, 29.700000000000006, 29.8496231131986, 29.998499962498133], [0.0, 3.0, 4.242640687119286, 5.196152422706633, 6.0, 6.70820393249937, 7.348469228349535, 7.937253933193772, 8.485281374238571, 9.0, 9.486832980505138, 9.949874371066201, 10.392304845413266, 10.816653826391969, 11.224972160321824, 11.61895003862225, 12.0, 12.369316876852983, 12.727922061357855, 13.076696830622023, 13.41640786499874, 13.74772708486752, 14.07124727947029, 14.387494569938163, 14.69693845669907, 15.000000000000002, 15.297058540778357, 15.588457268119898, 15.874507866387544, 16.155494421403514, 16.431676725154986, 16.703293088490067, 16.970562748477143, 17.23368793961409, 17.492855684535904, 17.74823934929885, 18.0, 18.248287590894662, 18.49324200890693, 18.734993995195197, 18.973665961010276, 19.20937271229855, 19.44222209522358, 19.672315572906, 19.899748742132402, 20.12461179749811, 20.346989949375807, 20.566963801203133, 20.78460969082653, 21.000000000000004, 21.213203435596427, 21.424285285628553, 21.633307652783937, 21.84032966784156, 22.045407685048605, 22.24859546128699, 22.44994432064365, 22.64950330581225, 22.84731931759173, 23.043437243605826, 23.2379000772445, 23.430749027719965, 23.62202362203543, 23.811761799581316, 24.0, 24.186773244895647, 24.372115213907882, 24.55605831561735, 24.738633753705965, 24.919871588754226, 25.09980079602227, 25.278449319529077, 25.45584412271571, 25.632011235952596, 25.806975801127884, 25.98076211353316, 26.153393661244046, 26.32489316217637, 26.495282598983547, 26.66458325194677, 26.83281572999748, 27.000000000000004, 27.166155414412252, 27.331300737432898, 27.49545416973504, 27.65863337187867, 27.820855486487115, 27.982137159266447, 28.14249455894058, 28.301943396169815, 28.460498941515414, 28.61817604250837, 28.774989139876325, 28.930952282978872, 29.086079144497976, 29.24038303442689, 29.39387691339814, 29.54657340538832, 29.698484809834994, 29.849623113198604, 30.000000000000004, 30.149626863362677], [0.0, 3.0149626863362675, 4.263801121065569, 5.222068555658764, 6.029925372672535, 6.741661516273271, 7.385120175054704, 7.976841480185, 8.527602242131138, 9.044888059008802, 9.534149149242424, 9.999499987499377, 10.444137111317527, 10.870602559196064, 11.2809574061779, 11.676900273617138, 12.05985074534507, 12.431009613060398, 12.791403363196707, 13.141917668285709, 13.483323032546542, 13.816294727603347, 14.141428499271214, 14.459253092743072, 14.770240350109408, 15.074813431681337, 15.373353570382752, 15.666205666976293, 15.95368296037, 16.23607095328177, 16.513630733427465, 16.78660180024534, 17.055204484262276, 17.319642028633275, 17.580102388780336, 17.8367597954337, 18.089776118017603, 18.339302058693512, 18.58547820208025, 18.828435941415847, 19.068298298484848, 19.305180651835407, 19.53919138552054, 19.770432468714485, 19.998999974998753, 20.224984548819812, 20.44847182554237, 20.669542810618722, 20.888274222635054, 21.10473880435387, 21.319005605327845, 21.531140239197743, 21.741205118392127, 21.94925966860842, 22.15536052516411, 22.3595617130569, 22.5619148123558, 22.762469110357955, 22.96127174178295, 23.158367818134334, 23.353800547234275, 23.54761134382849, 23.73983993206357, 23.930524440555, 24.11970149069014, 24.30740627874558, 24.493672652340237, 24.678533181694572, 24.862019226120797, 25.044160996128422, 25.224987611493493, 25.404527155607525, 25.582806726393414, 25.759852484049674, 25.935689695861186, 26.110342778293816, 26.283835336571418, 26.456190201916833, 26.62742946662333, 26.797574517108824, 26.966646065093084, 27.13466417702641, 27.3016483018883, 27.46761729746503, 27.632589455206695, 27.796582523756413, 27.959613731237425, 28.121699806377283, 28.282856998542428, 28.44310109675104, 28.60244744772727, 28.760910973055083, 28.918506185486144, 29.075247204452115, 29.231147770828297, 29.38622126099237, 29.540480700218815, 29.693938775447094, 29.84660784745898, 29.998499962498133, 30.149626863362673, 30.300000000000008]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"A = 3.5\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.35000000000000003, 0.4949747468305833, 0.6062177826491071, 0.7000000000000001, 0.7826237921249264, 0.8573214099741124, 0.9260129588726067, 0.9899494936611666, 1.05, 1.1067971810589328, 1.16081867662439, 1.2124355652982142, 1.2619429464123963, 1.3095800853708794, 1.3555441711725957, 1.4000000000000001, 1.4430869689661814, 1.48492424049175, 1.5256146302392362, 1.5652475842498528, 1.6039014932345441, 1.6416455159382004, 1.6785410331594521, 1.7146428199482249, 1.7500000000000002, 1.784656829757475, 1.8186533479473213, 1.8520259177452134, 1.8848076824970768, 1.9170289512680814, 1.9487175269905077, 1.9798989873223332, 2.01059692628831, 2.040833163195855, 2.0706279240848655, 2.1, 2.128966885604377, 2.1575449010391416, 2.18574929943944, 2.2135943621178655, 2.2410934831014973, 2.2682592444427514, 2.2951034835057, 2.32163735324878, 2.347871376374779, 2.373815494093844, 2.3994791101403656, 2.4248711305964283, 2.45, 2.4748737341529163, 2.499499949989998, 2.5238858928247927, 2.548038461248182, 2.571964229922337, 2.595669470483482, 2.619160170741759, 2.6424420523447623, 2.665520587052368, 2.688401011754013, 2.7110883423451915, 2.7335873865673292, 2.755902755904134, 2.7780388766178206, 2.8000000000000003, 2.821790211904492, 2.8434134416225865, 2.8648734701553575, 2.8861739379323628, 2.9073183520213264, 2.928310092869265, 2.9491524206117252, 2.9698484809835, 2.990401310861136, 3.010813843464919, 3.031088913245535, 3.0512292604784723, 3.071237535587243, 3.0911163032147466, 3.1108680460604567, 3.1304951684997055, 3.1500000000000004, 3.1693847983480965, 3.1886517527005047, 3.2078029864690882, 3.2268405600525107, 3.2457664734234966, 3.2645826685810855, 3.283291031876401, 3.301893396219811, 3.3203915431767985, 3.33878720495931, 3.3570820663189043, 3.375277766347535, 3.393375900191431, 3.4113780206831374, 3.4292856398964497, 3.4471002306286374, 3.4648232278140827, 3.48245602987317, 3.5000000000000004, 3.517456467392312], [0.0, 0.49497474683058323, 0.7, 0.8573214099741124, 0.9899494936611665, 1.1067971810589328, 1.2124355652982142, 1.3095800853708794, 1.4, 1.4849242404917498, 1.5652475842498528, 1.6416455159382004, 1.7146428199482249, 1.7846568297574747, 1.8520259177452132, 1.9170289512680811, 1.979898987322333, 2.040833163195855, 2.1, 2.157544901039142, 2.2135943621178655, 2.268259244442751, 2.32163735324878, 2.373815494093844, 2.4248711305964283, 2.474873734152917, 2.5238858928247927, 2.571964229922337, 2.619160170741759, 2.665520587052368, 2.7110883423451915, 2.755902755904134, 2.8, 2.8434134416225865, 2.8861739379323623, 2.9283100928692645, 2.9698484809834995, 3.0108138434649194, 3.0512292604784714, 3.0911163032147466, 3.1304951684997055, 3.169384798348096, 3.2078029864690882, 3.2457664734234957, 3.283291031876401, 3.320391543176798, 3.357082066318904, 3.39337590019143, 3.4292856398964497, 3.4648232278140827, 3.5, 3.5348267284267276, 3.5693136595149495, 3.60347054934545, 3.637306695894642, 3.6708309685955305, 3.7040518354904264, 3.7369773882109585, 3.7696153649941526, 3.801973171920076, 3.8340579025361623, 3.865876356015541, 3.897435053981015, 3.9287402561126386, 3.959797974644666, 3.990613987846982, 4.02119385257662, 4.0515429159765795, 4.08166632639171, 4.111569043564756, 4.141255848169732, 4.1707313507345445, 4.2, 4.2290660907581, 4.257933771208753, 4.286607049870561, 4.315089802078284, 4.3433857760968, 4.371498598878879, 4.399431781491788, 4.427188724235731, 4.4547727214752495, 4.4821869662029945, 4.509434554353794, 4.536518488885502, 4.563441683641854, 4.590206967011401, 4.616817085395522, 4.64327470649756, 4.669582422444217, 4.695742752749558, 4.721758147131214, 4.747630988187688, 4.77336359394505, 4.798958220280731, 4.824417063231577, 4.849742261192857, 4.874935897014442, 4.8999999999999995, 4.924936547814601, 4.949747468305834, 4.974434641243164], [0.0, 0.6062177826491071, 0.8573214099741124, 1.0500000000000003, 1.2124355652982142, 1.3555441711725962, 1.48492424049175, 1.6039014932345443, 1.7146428199482249, 1.8186533479473213, 1.9170289512680816, 2.0105969262883105, 2.1000000000000005, 2.18574929943944, 2.2682592444427514, 2.347871376374779, 2.4248711305964283, 2.499499949989998, 2.5719642299223375, 2.642442052344763, 2.7110883423451924, 2.7780388766178206, 2.8434134416225865, 2.907318352021327, 2.9698484809835, 3.031088913245536, 3.091116303214747, 3.1500000000000004, 3.2078029864690887, 3.264582668581086, 3.3203915431767985, 3.375277766347535, 3.4292856398964497, 3.4824560298731706, 3.534826728426728, 3.58643276808586, 3.6373066958946425, 3.6874788134984593, 3.7369773882109594, 3.78582883923719, 3.834057902536163, 3.881687777243297, 3.928740256112639, 3.9752358420601914, 4.021193852576621, 4.066632513517788, 4.1115690435647565, 4.156019730463272, 4.200000000000001, 4.24352447854375, 4.286607049870563, 4.329260906898544, 4.37149859887888, 4.413332074521473, 4.4547727214752495, 4.4958314025327955, 4.536518488885503, 4.576843890717708, 4.616817085395522, 4.656447143477526, 4.695742752749558, 4.73471224046404, 4.773363593945049, 4.811704479703633, 4.849742261192857, 4.88748401531913, 4.924936547814602, 4.96210640756524, 4.998999899979996, 5.035623099478356, 5.071981861166305, 5.108081831764249, 5.143928459844675, 5.17952700543206, 5.214882549012969, 5.250000000000001, 5.284884104689526, 5.319539453749734, 5.353970489272425, 5.38818151141923, 5.422176684690385, 5.455960043841965, 5.489535499475345, 5.5229068433208255, 5.556077753235641, 5.58905179793496, 5.621832441473155, 5.654423047491231, 5.686826883245173, 5.719047123428867, 5.751086853804245, 5.782949074650408, 5.814636704042654, 5.846152580971524, 5.877499468311334, 5.908680055646947, 5.939696961967, 5.970552738231195, 6.001249869818787, 6.031790778864932, 6.062177826491072, 6.092413314935225], [0.0, 0.7000000000000001, 0.9899494936611666, 1.2124355652982142, 1.4000000000000001, 1.5652475842498528, 1.7146428199482249, 1.8520259177452134, 1.9798989873223332, 2.1, 2.2135943621178655, 2.32163735324878, 2.4248711305964283, 2.5238858928247927, 2.619160170741759, 2.7110883423451915, 2.8000000000000003, 2.8861739379323628, 2.9698484809835, 3.0512292604784723, 3.1304951684997055, 3.2078029864690882, 3.283291031876401, 3.3570820663189043, 3.4292856398964497, 3.5000000000000004, 3.56931365951495, 3.6373066958946425, 3.704051835490427, 3.7696153649941535, 3.8340579025361627, 3.8974350539810154, 3.9597979746446663, 4.02119385257662, 4.08166632639171, 4.141255848169731, 4.2, 4.257933771208754, 4.315089802078283, 4.37149859887888, 4.427188724235731, 4.4821869662029945, 4.536518488885503, 4.5902069670114, 4.64327470649756, 4.695742752749558, 4.747630988187688, 4.798958220280731, 4.849742261192857, 4.9, 4.949747468305833, 4.998999899979996, 5.047771785649585, 5.096076922496364, 5.143928459844674, 5.191338940966964, 5.238320341483518, 5.2848841046895245, 5.331041174104736, 5.376802023508026, 5.422176684690383, 5.4671747731346585, 5.511805511808268, 5.556077753235641, 5.6000000000000005, 5.643580423808984, 5.686826883245173, 5.729746940310715, 5.7723478758647255, 5.814636704042653, 5.85662018573853, 5.8983048412234504, 5.939696961967, 5.980802621722272, 6.021627686929838, 6.06217782649107, 6.102458520956945, 6.142475071174486, 6.182232606429493, 6.2217360921209135, 6.260990336999411, 6.300000000000001, 6.338769596696193, 6.377303505401009, 6.4156059729381765, 6.4536811201050215, 6.491532946846993, 6.529165337162171, 6.566582063752802, 6.603786792439622, 6.640783086353597, 6.67757440991862, 6.7141641326378085, 6.75055553269507, 6.786751800382862, 6.822756041366275, 6.8585712797928995, 6.894200461257275, 6.929646455628165, 6.96491205974634, 7.000000000000001, 7.034912934784624], [0.0, 0.7826237921249265, 1.1067971810589328, 1.3555441711725962, 1.565247584249853, 1.7500000000000002, 1.9170289512680816, 2.070627924084866, 2.2135943621178655, 2.3478713763747794, 2.4748737341529163, 2.5956694704834824, 2.7110883423451924, 2.8217902119044926, 2.9283100928692645, 3.031088913245535, 3.130495168499706, 3.2268405600525107, 3.320391543176799, 3.4113780206831383, 3.5000000000000004, 3.5864327680858596, 3.6708309685955305, 3.7533318531672637, 3.834057902536163, 3.9131189606246326, 3.9906139878469835, 4.066632513517788, 4.141255848169732, 4.214558102577304, 4.286607049870562, 4.357464859296057, 4.427188724235731, 4.495831402532796, 4.563441683641854, 4.630064794363034, 4.695742752749559, 4.7605146780574055, 4.824417063231578, 4.887484015319131, 4.949747468305833, 5.0112373721467245, 5.071981861166305, 5.132007404515313, 5.191338940966965, 5.25, 5.308012810836086, 5.365398400864563, 5.422176684690385, 5.478366544874485, 5.5339859052946645, 5.58905179793496, 5.643580423808985, 5.697587208634898, 5.751086853804244, 5.80409338312195, 5.856620185738529, 5.908680055646946, 5.960285228074241, 6.011447413061185, 6.06217782649107, 6.112487218800544, 6.162385901580653, 6.211883772254597, 6.260990336999412, 6.309714732061981, 6.358065743604733, 6.406051826203095, 6.4536811201050215, 6.50096146735235, 6.547900426854398, 6.594505288495871, 6.640783086353598, 6.68674061108998, 6.73238442158497, 6.77772085586298, 6.822756041366277, 6.867495904622005, 6.911946180346026, 6.956112420023128, 7.000000000000001, 7.043614129124339, 7.086959855960807, 7.130042075612177, 7.172865536171719, 7.215434844830907, 7.257754473664703, 7.299828765114975, 7.341661937191061, 7.383258088405145, 7.4246212024587495, 7.46575515269554, 7.506663706334527, 7.54735052849674, 7.587819186037581, 7.628073151196179, 7.668115805072326, 7.707950440940835, 7.74758026741253, 7.787008411450447, 7.826237921249265, 7.865271768985483], [0.0, 0.8573214099741123, 1.2124355652982142, 1.48492424049175, 1.7146428199482247, 1.9170289512680814, 2.1, 2.2682592444427514, 2.4248711305964283, 2.571964229922337, 2.711088342345192, 2.8434134416225865, 2.9698484809835, 3.0911163032147466, 3.207802986469088, 3.320391543176798, 3.4292856398964493, 3.5348267284267276, 3.637306695894643, 3.73697738821096, 3.8340579025361627, 3.9287402561126386, 4.02119385257662, 4.1115690435647565, 4.2, 4.286607049870562, 4.37149859887888, 4.4547727214752495, 4.536518488885503, 4.616817085395523, 4.695742752749559, 4.773363593945049, 4.849742261192857, 4.924936547814601, 4.998999899979996, 5.071981861166304, 5.143928459844674, 5.2148825490129695, 5.284884104689525, 5.353970489272425, 5.422176684690384, 5.489535499475344, 5.556077753235641, 5.6218324414731535, 5.686826883245173, 5.751086853804244, 5.814636704042653, 5.877499468311333, 5.939696961967, 6.001249869818786, 6.062177826491071, 6.122499489587566, 6.182232606429493, 6.241394075044454, 6.3, 6.358065743604733, 6.415605972938176, 6.472634703117425, 6.529165337162171, 6.585210702779373, 6.640783086353596, 6.695894264398147, 6.750555532695068, 6.804777733328254, 6.858571279792899, 6.911946180346024, 6.96491205974634, 7.017478179517198, 7.069653456853455, 7.121446482281533, 7.17286553617172, 7.223918604192603, 7.274613391789286, 7.324957337759722, 7.374957626996917, 7.4246212024587495, 7.47395477642192, 7.522964841071638, 7.571657678474378, 7.620039369977036, 7.6681158050723255, 7.715892689767012, 7.763375554486593, 7.810569761547489, 7.857480512225277, 7.904112853445351, 7.950471684120384, 7.996561761157105, 8.04238770515324, 8.08795400580394, 8.133265027035575, 8.178325011883546, 8.223138087129513, 8.267708267712402, 8.312039460926544, 8.356135470419325, 8.4, 8.443636657270375, 8.487048957087499, 8.53024032486776, 8.573214099741124, 8.615973537563821], [0.0, 0.9260129588726067, 1.3095800853708794, 1.6039014932345441, 1.8520259177452134, 2.0706279240848655, 2.2682592444427514, 2.45, 2.619160170741759, 2.77803887661782, 2.9283100928692645, 3.071237535587243, 3.2078029864690882, 3.33878720495931, 3.4648232278140827, 3.586432768085859, 3.704051835490427, 3.8180492401225004, 3.928740256112639, 4.03639690813478, 4.141255848169731, 4.243524478543749, 4.3433857760968, 4.441002139157333, 4.536518488885503, 4.630064794363034, 4.721758147131215, 4.811704479703632, 4.9, 4.986732397071253, 5.071981861166304, 5.155821951929682, 5.238320341483518, 5.319539453749733, 5.399537017189529, 5.4783665448744845, 5.55607775323564, 5.632716928800879, 5.7083272506050315, 5.782949074650408, 5.856620185738529, 5.929376021134097, 6.001249869818786, 6.072273050514115, 6.142475071174486, 6.2118837722545965, 6.280525455724227, 6.348425001525969, 6.4156059729381765, 6.482090712108247, 6.547900426854397, 6.613055269691915, 6.67757440991862, 6.741476099490379, 6.804777733328253, 6.867495904622005, 6.929646455628165, 6.9912445244033625, 7.05230458786346, 7.112840501515552, 7.172865536171718, 7.232392411920139, 7.291433329599879, 7.3500000000000005, 7.408103670980854, 7.465755152695539, 7.522964841071637, 7.579742739697701, 7.636098480245001, 7.69204134154257, 7.7475802674125305, 7.802723883362783, 7.857480512225278, 7.91185818882012, 7.965864673718729, 8.01950746617272, 8.07279381626956, 8.12573073637073, 8.178325011883546, 8.230583211413395, 8.282511696339462, 8.334116629853462, 8.385403985497659, 8.436379555235764, 8.487048957087499, 8.537417642355328, 8.587490902469709, 8.637273875477147, 8.6867715521936, 8.735988782044078, 8.784930278607794, 8.833600624886774, 8.882004278314666, 8.930145575521152, 8.978028736866463, 9.02565787075934, 9.073036977771006, 9.120169954556768, 9.167060597596157, 9.21371260676173, 9.260129588726068, 9.306315060215834], [0.0, 0.9899494936611665, 1.4, 1.7146428199482249, 1.979898987322333, 2.2135943621178655, 2.4248711305964283, 2.619160170741759, 2.8, 2.9698484809834995, 3.1304951684997055, 3.283291031876401, 3.4292856398964497, 3.5693136595149495, 3.7040518354904264, 3.8340579025361623, 3.959797974644666, 4.08166632639171, 4.2, 4.315089802078284, 4.427188724235731, 4.536518488885502, 4.64327470649756, 4.747630988187688, 4.849742261192857, 4.949747468305834, 5.047771785649585, 5.143928459844674, 5.238320341483518, 5.331041174104736, 5.422176684690383, 5.511805511808268, 5.6, 5.686826883245173, 5.772347875864725, 5.856620185738529, 5.939696961966999, 6.021627686929839, 6.102458520956943, 6.182232606429493, 6.260990336999411, 6.338769596696192, 6.4156059729381765, 6.491532946846991, 6.566582063752802, 6.640783086353596, 6.714164132637808, 6.78675180038286, 6.8585712797928995, 6.929646455628165, 7.0, 7.069653456853455, 7.138627319029899, 7.2069410986909, 7.274613391789284, 7.341661937191061, 7.408103670980853, 7.473954776421917, 7.539230729988305, 7.603946343840152, 7.668115805072325, 7.731752712031082, 7.79487010796203, 7.857480512225277, 7.919595949289332, 7.981227975693964, 8.04238770515324, 8.103085831953159, 8.16333265278342, 8.223138087129511, 8.282511696339464, 8.341462701469089, 8.4, 8.4581321815162, 8.515867542417507, 8.573214099741122, 8.630179604156568, 8.6867715521936, 8.742997197757758, 8.798863562983575, 8.854377448471462, 8.909545442950499, 8.964373932405989, 9.018869108707587, 9.073036977771004, 9.126883367283709, 9.180413934022802, 9.233634170791044, 9.28654941299512, 9.339164844888433, 9.391485505499116, 9.443516294262428, 9.495261976375376, 9.5467271878901, 9.597916440561463, 9.648834126463154, 9.699484522385713, 9.749871794028884, 9.799999999999999, 9.849873095629203, 9.899494936611667, 9.948869282486328], [0.0, 1.05, 1.4849242404917498, 1.8186533479473213, 2.1, 2.347871376374779, 2.571964229922337, 2.77803887661782, 2.9698484809834995, 3.1499999999999995, 3.320391543176798, 3.4824560298731697, 3.6373066958946425, 3.7858288392371886, 3.928740256112638, 4.066632513517787, 4.2, 4.3292609068985435, 4.4547727214752495, 4.576843890717708, 4.695742752749558, 4.811704479703632, 4.9249365478146006, 5.0356230994783555, 5.143928459844674, 5.250000000000001, 5.353970489272425, 5.455960043841963, 5.55607775323564, 5.65442304749123, 5.751086853804244, 5.8461525809715225, 5.939696961966999, 6.031790778864931, 6.1224994895875655, 6.2118837722545965, 6.299999999999999, 6.386900656813131, 6.472634703117425, 6.557247898318319, 6.640783086353596, 6.723280449304492, 6.804777733328254, 6.8853104505171, 6.964912059746339, 7.043614129124337, 7.121446482281532, 7.198437330421096, 7.274613391789285, 7.35, 7.4246212024587495, 7.498499849969993, 7.571657678474377, 7.644115383744545, 7.715892689767011, 7.787008411450446, 7.857480512225276, 7.927326157034287, 7.996561761157103, 8.065203035262039, 8.133265027035574, 8.200762159701988, 8.2677082677124, 8.33411662985346, 8.4, 8.465370635713477, 8.530240324867759, 8.594620410466073, 8.658521813797087, 8.72195505606398, 8.784930278607794, 8.847457261835176, 8.909545442950499, 8.971203932583407, 9.032441530394756, 9.093266739736606, 9.153687781435416, 9.213712606761728, 9.27334890964424, 9.332604138181368, 9.391485505499116, 9.450000000000001, 9.508154395044288, 9.565955258101512, 9.623408959407264, 9.680521680157533, 9.737299420270489, 9.793748005743257, 9.849873095629201, 9.905680188659433, 9.961174629530394, 10.01636161487793, 10.071246198956711, 10.125833299042604, 10.180127700574293, 10.234134062049412, 10.287856919689348, 10.34130069188591, 10.394469683442248, 10.447368089619511, 10.500000000000002, 10.552369402176936], [0.0, 1.1067971810589328, 1.5652475842498528, 1.9170289512680816, 2.2135943621178655, 2.4748737341529163, 2.711088342345192, 2.9283100928692645, 3.1304951684997055, 3.320391543176798, 3.5, 3.6708309685955305, 3.834057902536163, 3.990613987846983, 4.141255848169731, 4.286607049870561, 4.427188724235731, 4.563441683641854, 4.695742752749559, 4.824417063231579, 4.949747468305833, 5.071981861166304, 5.191338940966964, 5.308012810836086, 5.422176684690384, 5.5339859052946645, 5.643580423808985, 5.751086853804244, 5.856620185738529, 5.960285228074241, 6.06217782649107, 6.162385901580653, 6.260990336999411, 6.358065743604733, 6.4536811201050215, 6.547900426854397, 6.640783086353596, 6.732384421584971, 6.822756041366275, 6.911946180346026, 7.0, 7.0869598559608065, 7.172865536171719, 7.2577544736647015, 7.341661937191061, 7.424621202458749, 7.5066637063345265, 7.58781918603758, 7.668115805072326, 7.74758026741253, 7.826237921249264, 7.904112853445351, 7.981227975693966, 8.057605103254938, 8.133265027035575, 8.208227579691002, 8.282511696339462, 8.356135470419325, 8.429116205154607, 8.501470461043784, 8.573214099741122, 8.644362324659928, 8.714929718592112, 8.784930278607794, 8.854377448471462, 8.923284148787372, 8.991662805065591, 9.05952537388135, 9.126883367283709, 9.193747875594589, 9.260129588726068, 9.326038816131959, 9.391485505499118, 9.456479260274406, 9.52102935611481, 9.585144756340407, 9.648834126463157, 9.712105847858126, 9.77496803063826, 9.837428525788638, 9.899494936611665, 9.961174629530396, 10.022474744293449, 10.083402203621553, 10.143963722332607, 10.204165815979277, 10.264014809030627, 10.323516842626839, 10.382677881933928, 10.441503723123407, 10.5, 10.55817219029885, 10.616025621672172, 10.673565477383836, 10.730796801729126, 10.787724505195708, 10.844353369380768, 10.900688051678207, 10.956733089748969, 11.012492905786592, 11.067971810589329, 11.123174007449494], [0.0, 1.16081867662439, 1.6416455159382004, 2.0105969262883105, 2.32163735324878, 2.5956694704834824, 2.8434134416225865, 3.071237535587243, 3.283291031876401, 3.4824560298731697, 3.6708309685955305, 3.8500000000000005, 4.021193852576621, 4.18539126008549, 4.3433857760968, 4.495831402532795, 4.64327470649756, 4.78617801591207, 4.924936547814601, 5.059891303180337, 5.191338940966965, 5.319539453749733, 5.444722215136416, 5.567090802205405, 5.686826883245173, 5.804093383121951, 5.919037083850718, 6.031790778864931, 6.142475071174486, 6.251199884822114, 6.358065743604733, 6.4631648594167865, 6.566582063752802, 6.668395609140179, 6.768677862034801, 6.867495904622005, 6.964912059746339, 7.060984350641206, 7.155766905091306, 7.249310312022795, 7.341661937191061, 7.4328662035583575, 7.522964841071638, 7.61199710982604, 7.700000000000001, 7.787008411450446, 7.8730553154413965, 7.958171900631451, 8.042387705153242, 8.12573073637073, 8.208227579691004, 8.28990349762891, 8.37078252017098, 8.450887527354746, 8.530240324867759, 8.608861713374191, 8.6867715521936, 8.76398881788424, 8.840531658220563, 8.916417441999899, 8.99166280506559, 9.066283692892034, 9.140295400040417, 9.21371260676173, 9.28654941299512, 9.358819369984657, 9.430535509715238, 9.50171037234876, 9.57235603182414, 9.64248411976914, 9.712105847858128, 9.781232028737485, 9.849873095629203, 9.918039120713328, 9.985739832380974, 10.05298463144155, 10.119782606360674, 10.186142547598676, 10.252072961113768, 10.317582081088574, 10.38267788193393, 10.447368089619511, 10.511660192376848, 10.57556145081669, 10.639078907499465, 10.70221939599446, 10.764989549460791, 10.827395808780615, 10.889444430272832, 10.951141493013411, 11.012492905786592, 11.073504413689463, 11.13418160441081, 11.194529914203635, 11.254554633569471, 11.31426091267123, 11.373653766490346, 11.432738079742755, 11.491518611567402, 11.550000000000002, 11.608186766243902, 11.666083318749273], [0.0, 1.2124355652982142, 1.7146428199482249, 2.1000000000000005, 2.4248711305964283, 2.7110883423451924, 2.9698484809835, 3.2078029864690887, 3.4292856398964497, 3.6373066958946425, 3.834057902536163, 4.021193852576621, 4.200000000000001, 4.37149859887888, 4.536518488885503, 4.695742752749558, 4.849742261192857, 4.998999899979996, 5.143928459844675, 5.284884104689526, 5.422176684690385, 5.556077753235641, 5.686826883245173, 5.814636704042654, 5.939696961967, 6.062177826491072, 6.182232606429494, 6.300000000000001, 6.415605972938177, 6.529165337162172, 6.640783086353597, 6.75055553269507, 6.8585712797928995, 6.964912059746341, 7.069653456853456, 7.17286553617172, 7.274613391789285, 7.374957626996919, 7.473954776421919, 7.57165767847438, 7.668115805072326, 7.763375554486594, 7.857480512225278, 7.950471684120383, 8.042387705153242, 8.133265027035575, 8.223138087129513, 8.312039460926544, 8.400000000000002, 8.4870489570875, 8.573214099741126, 8.658521813797089, 8.74299719775776, 8.826664149042946, 8.909545442950499, 8.991662805065591, 9.073036977771006, 9.153687781435416, 9.233634170791044, 9.312894286955052, 9.391485505499116, 9.46942448092808, 9.546727187890099, 9.623408959407266, 9.699484522385713, 9.77496803063826, 9.849873095629205, 9.92421281513048, 9.997999799959992, 10.071246198956713, 10.14396372233261, 10.216163663528498, 10.28785691968935, 10.35905401086412, 10.429765098025937, 10.500000000000002, 10.569768209379053, 10.639078907499467, 10.70794097854485, 10.77636302283846, 10.84435336938077, 10.91192008768393, 10.97907099895069, 11.045813686641651, 11.112155506471282, 11.17810359586992, 11.24366488294631, 11.308846094982462, 11.373653766490346, 11.438094246857734, 11.50217370760849, 11.565898149300816, 11.629273408085307, 11.692305161943048, 11.754998936622668, 11.817360111293894, 11.879393923934, 11.94110547646239, 12.002499739637575, 12.063581557729863, 12.124355652982144, 12.18482662987045], [0.0, 1.2619429464123963, 1.7846568297574747, 2.18574929943944, 2.5238858928247927, 2.8217902119044926, 3.0911163032147466, 3.33878720495931, 3.5693136595149495, 3.7858288392371886, 3.990613987846983, 4.185391260085489, 4.37149859887888, 4.550000000000001, 4.721758147131214, 4.887484015319129, 5.047771785649585, 5.2031240615614776, 5.353970489272425, 5.5006817759256, 5.643580423808985, 5.782949074650408, 5.919037083850717, 6.052065763026705, 6.182232606429493, 6.309714732061982, 6.434671708797583, 6.557247898318319, 6.67757440991862, 6.795770743631661, 6.911946180346025, 7.026200964959656, 7.138627319029899, 7.249310312022794, 7.358328614570024, 7.46575515269554, 7.571657678474377, 7.676099269811459, 7.779138769812505, 7.880831174438393, 7.981227975693966, 8.080377466430638, 8.178325011883548, 8.275113292275822, 8.370782520170978, 8.465370635713477, 8.55891348244624, 8.651444966015793, 8.74299719775776, 8.833600624886774, 8.923284148787374, 9.012075232708614, 9.100000000000001, 9.187083323884682, 9.27334890964424, 9.358819369984657, 9.443516294262428, 9.527460312171339, 9.610671152422187, 9.693167696888361, 9.774968030638258, 9.856089488230108, 9.936548696604872, 10.01636161487793, 10.09554357129917, 10.174109297624042, 10.252072961113768, 10.329448194361596, 10.406248123122955, 10.482485392310357, 10.558172190298851, 10.633320271674318, 10.70794097854485, 10.782045260524553, 10.855643693489576, 10.928746497197197, 11.0013635518512, 11.073504413689463, 11.145178329663462, 11.216394251273448, 11.28716084761797, 11.357486517711568, 11.427379402120158, 11.49684739395979, 11.565898149300816, 11.634539097016265, 11.702777448110343, 11.770620204560167, 11.838074167701434, 11.905145946186463, 11.97184196354095, 12.038168465343889, 12.10413152605341, 12.1697370554996, 12.234990805063976, 12.299898373563906, 12.364465212858986, 12.428696633195296, 12.492597808302323, 12.55617378025647, 12.619429464123964, 12.68236965239541], [0.0, 1.3095800853708794, 1.8520259177452134, 2.2682592444427514, 2.619160170741759, 2.9283100928692645, 3.2078029864690882, 3.4648232278140827, 3.704051835490427, 3.928740256112638, 4.141255848169731, 4.3433857760968, 4.536518488885503, 4.721758147131214, 4.8999999999999995, 5.071981861166303, 5.238320341483518, 5.399537017189529, 5.55607775323564, 5.708327250605032, 5.856620185738529, 6.001249869818786, 6.142475071174485, 6.280525455724227, 6.4156059729381765, 6.547900426854398, 6.67757440991862, 6.804777733328253, 6.929646455628165, 7.0523045878634605, 7.172865536171718, 7.29143332959988, 7.408103670980854, 7.522964841071637, 7.636098480245001, 7.74758026741253, 7.857480512225276, 7.9658646737187295, 8.072793816269558, 8.178325011883548, 8.282511696339462, 8.385403985497659, 8.487048957087499, 8.587490902469707, 8.6867715521936, 8.784930278607792, 8.882004278314666, 8.978028736866461, 9.073036977771006, 9.167060597596157, 9.260129588726068, 9.352272451121172, 9.443516294262428, 9.533886930313367, 9.623408959407264, 9.712105847858126, 9.799999999999999, 9.887112824277873, 9.973464794142505, 10.05907550423994, 10.143963722332606, 10.22814743734172, 10.311643903859363, 10.39446968344225, 10.476640682967036, 10.558172190298848, 10.639078907499465, 10.719374981779488, 10.799074034379059, 10.878189187544038, 10.95673308974897, 11.034717939304112, 11.11215550647128, 11.189057154202045, 11.265433857601755, 11.341296222213755, 11.416654501210065, 11.491518611567402, 11.565898149300814, 11.639802403821124, 11.713240371477058, 11.786220768337916, 11.858752042268193, 11.930842384341517, 12.002499739637573, 12.073731817462239, 12.144546101028231, 12.214949856630604, 12.28495014234897, 12.354553816305952, 12.423767544509193, 12.492597808302323, 12.561050911448454, 12.629132986868102, 12.696850003051939, 12.764207770167328, 12.831211945876353, 12.897868040881797, 12.964181424216493, 13.0301573282904, 13.095800853708797, 13.161116973874218], [0.0, 1.3555441711725957, 1.9170289512680811, 2.3478713763747794, 2.7110883423451915, 3.031088913245535, 3.320391543176798, 3.586432768085859, 3.8340579025361623, 4.066632513517787, 4.286607049870561, 4.495831402532795, 4.695742752749559, 4.887484015319129, 5.071981861166303, 5.249999999999999, 5.422176684690383, 5.5890517979349585, 5.751086853804244, 5.908680055646947, 6.06217782649107, 6.2118837722545965, 6.358065743604731, 6.500961467352349, 6.640783086353596, 6.77772085586298, 6.911946180346025, 7.043614129124337, 7.172865536171718, 7.299828765114974, 7.424621202458749, 7.547350528496738, 7.668115805072325, 7.787008411450446, 7.90411285344535, 8.019507466172719, 8.133265027035574, 8.245453292572822, 8.356135470419325, 8.465370635713478, 8.573214099741122, 8.679717737346072, 8.784930278607794, 8.888897569440203, 8.99166280506559, 9.093266739736604, 9.193747875594587, 9.293142633146227, 9.391485505499118, 9.488809198208171, 9.585144756340407, 9.680521680157533, 9.774968030638258, 9.86851052591018, 9.961174629530394, 10.05298463144155, 10.143963722332606, 10.23413406204941, 10.323516842626837, 10.412132346450461, 10.499999999999998, 10.58713842357792, 10.673565477383832, 10.759298304257578, 10.844353369380766, 10.928746497197194, 11.01249290578659, 11.09560723890315, 11.178103595869917, 11.259995559501789, 11.341296222213755, 11.422018210456502, 11.502173707608488, 11.581774475442005, 11.660831874270375, 11.739356881873896, 11.817360111293894, 11.894851827576499, 11.971841963540948, 12.048340134640954, 12.12435565298214, 12.199897540553362, 12.274974541725129, 12.349595135064144, 12.423767544509193, 12.497499749949988, 12.57079949724758, 12.64367430773191, 12.716131487209463, 12.788178134511575, 12.859821149611683, 12.931067241337816, 13.001922934704698, 13.072394577888168, 13.142488348863012, 13.21221026172381, 13.281566172707192, 13.350561785932456, 13.419202658876568, 13.487494207598386, 13.55544171172596, 13.623050319219995], [0.0, 1.4000000000000001, 1.9798989873223332, 2.4248711305964283, 2.8000000000000003, 3.1304951684997055, 3.4292856398964497, 3.704051835490427, 3.9597979746446663, 4.2, 4.427188724235731, 4.64327470649756, 4.849742261192857, 5.047771785649585, 5.238320341483518, 5.422176684690383, 5.6000000000000005, 5.7723478758647255, 5.939696961967, 6.102458520956945, 6.260990336999411, 6.4156059729381765, 6.566582063752802, 6.7141641326378085, 6.8585712797928995, 7.000000000000001, 7.1386273190299, 7.274613391789285, 7.408103670980854, 7.539230729988307, 7.6681158050723255, 7.794870107962031, 7.919595949289333, 8.04238770515324, 8.16333265278342, 8.282511696339462, 8.4, 8.515867542417508, 8.630179604156567, 8.74299719775776, 8.854377448471462, 8.964373932405989, 9.073036977771006, 9.1804139340228, 9.28654941299512, 9.391485505499116, 9.495261976375376, 9.597916440561463, 9.699484522385713, 9.8, 9.899494936611665, 9.997999799959992, 10.09554357129917, 10.192153844992728, 10.287856919689348, 10.382677881933928, 10.476640682967036, 10.569768209379049, 10.662082348209472, 10.753604047016053, 10.844353369380766, 10.934349546269317, 11.023611023616535, 11.112155506471282, 11.200000000000001, 11.287160847617969, 11.373653766490346, 11.45949388062143, 11.544695751729451, 11.629273408085306, 11.71324037147706, 11.796609682446901, 11.879393923934, 11.961605243444543, 12.043255373859676, 12.12435565298214, 12.20491704191389, 12.284950142348972, 12.364465212858986, 12.443472184241827, 12.521980673998822, 12.600000000000001, 12.677539193392386, 12.754607010802019, 12.831211945876353, 12.907362240210043, 12.983065893693986, 13.058330674324342, 13.133164127505603, 13.207573584879244, 13.281566172707194, 13.35514881983724, 13.428328265275617, 13.50111106539014, 13.573503600765724, 13.64551208273255, 13.717142559585799, 13.78840092251455, 13.85929291125633, 13.92982411949268, 14.000000000000002, 14.069825869569248], [0.0, 1.4430869689661812, 2.040833163195855, 2.499499949989998, 2.8861739379323623, 3.2268405600525107, 3.5348267284267276, 3.8180492401225, 4.08166632639171, 4.3292609068985435, 4.563441683641854, 4.78617801591207, 4.998999899979996, 5.2031240615614776, 5.399537017189529, 5.5890517979349585, 5.772347875864725, 5.95, 6.122499489587566, 6.290270264464001, 6.4536811201050215, 6.613055269691915, 6.7686778620348, 6.920801976649817, 7.069653456853455, 7.215434844830907, 7.358328614570024, 7.498499849969992, 7.636098480245, 7.7712611589110825, 7.90411285344535, 8.034768198274298, 8.16333265278342, 8.28990349762891, 8.414570696119917, 8.537417642355328, 8.658521813797087, 8.777955342789117, 8.895785518997185, 9.012075232708614, 9.126883367283709, 9.240265147710861, 9.352272451121172, 9.46295408421704, 9.57235603182414, 9.680521680157531, 9.787492017876694, 9.893305817571798, 9.997999799959992, 10.101608782763268, 10.204165815979277, 10.30570230503482, 10.406248123122955, 10.505831713862545, 10.604480185280181, 10.70221939599446, 10.799074034379059, 10.895067691391366, 10.990222927675307, 11.084561335479181, 11.178103595869917, 11.270869531673233, 11.362878156523548, 11.454147720367502, 11.54469575172945, 11.634539097016262, 11.723693957110958, 11.812175921480344, 11.9, 11.987180652680598, 12.073731817462239, 12.159666936228145, 12.244998979175133, 12.329740467665975, 12.413903495677738, 12.497499749949988, 12.580540528928003, 12.66303676058788, 12.744999019223188, 12.826437541266088, 12.907362240210043, 12.987782720695632, 13.06770829181613, 13.147147979695063, 13.22611053938383, 13.30460446612375, 13.382638006013613, 13.460219166120588, 13.5373557240696, 13.614055237143706, 13.690325050925562, 13.766172307507995, 13.841603953299634, 13.916626746449731, 13.991247263914682, 14.065471908187083, 14.13930691370691, 14.212758352972868, 14.285832142370985, 14.358534047736212, 14.430869689661813, 14.502844548570465], [0.0, 1.4849242404917498, 2.1, 2.571964229922337, 2.9698484809834995, 3.3203915431767985, 3.6373066958946425, 3.9287402561126386, 4.2, 4.4547727214752495, 4.695742752749559, 4.924936547814601, 5.143928459844674, 5.353970489272425, 5.55607775323564, 5.751086853804243, 5.939696961966999, 6.1224994895875655, 6.300000000000001, 6.472634703117427, 6.640783086353597, 6.804777733328254, 6.964912059746339, 7.121446482281533, 7.274613391789285, 7.42462120245875, 7.571657678474378, 7.715892689767011, 7.857480512225277, 7.996561761157105, 8.133265027035575, 8.267708267712402, 8.4, 8.53024032486776, 8.658521813797087, 8.784930278607794, 8.909545442950499, 9.03244153039476, 9.153687781435416, 9.273348909644241, 9.391485505499118, 9.508154395044288, 9.623408959407264, 9.737299420270489, 9.849873095629203, 9.961174629530394, 10.071246198956713, 10.18012770057429, 10.287856919689348, 10.39446968344225, 10.5, 10.604480185280183, 10.70794097854485, 10.810411648036352, 10.911920087683926, 11.012492905786592, 11.11215550647128, 11.210932164632876, 11.308846094982458, 11.405919515760226, 11.502173707608486, 11.597629068046624, 11.692305161943045, 11.786220768337916, 11.879393923933998, 11.971841963540948, 12.063581557729862, 12.154628747929738, 12.244998979175131, 12.334707130694268, 12.423767544509195, 12.512194052203634, 12.600000000000001, 12.6871982722743, 12.77380131362626, 12.859821149611685, 12.945269406234853, 13.0301573282904, 13.114495796636637, 13.198295344475364, 13.281566172707194, 13.364318164425748, 13.446560898608984, 13.528303663061381, 13.609555466656508, 13.690325050925564, 13.770620901034203, 13.850451256186567, 13.929824119492679, 14.00874726733265, 14.087228258248675, 14.165274441393644, 14.242892964563065, 14.32009078183515, 14.396874660842196, 14.473251189694732, 14.54922678357857, 14.624807691043328, 14.7, 14.774809643443804, 14.8492424049175, 14.923303923729494], [0.0, 1.525614630239236, 2.157544901039142, 2.642442052344763, 3.051229260478472, 3.411378020683138, 3.7369773882109594, 4.036396908134779, 4.315089802078284, 4.576843890717708, 4.824417063231579, 5.059891303180337, 5.284884104689526, 5.5006817759255995, 5.708327250605032, 5.908680055646946, 6.102458520956944, 6.290270264464001, 6.472634703117427, 6.650000000000002, 6.822756041366276, 6.991244524403363, 7.155766905091306, 7.316590736128407, 7.473954776421919, 7.628073151196181, 7.779138769812506, 7.927326157034288, 8.072793816269558, 8.215686216013854, 8.356135470419327, 8.49426276965812, 8.630179604156568, 8.763988817884242, 8.895785518997185, 9.02565787075934, 9.153687781435416, 9.279951508493998, 9.404520189781083, 9.527460312171343, 9.648834126463157, 9.768700015867006, 9.887112824277876, 10.004124149569517, 10.119782606360674, 10.234134062049412, 10.34722184936614, 10.459086958238755, 10.569768209379053, 10.679302411674652, 10.78772450519571, 10.895067691391368, 11.001363551851199, 11.106642156835704, 11.210932164632878, 11.31426091267123, 11.416654501210065, 11.518137870333035, 11.618734870888483, 11.718468329948246, 11.817360111293892, 11.915431171384443, 12.01270161121136, 12.109190724404337, 12.204917041913887, 12.299898373563906, 12.394151846738044, 12.487693942437893, 12.580540528928003, 12.672706893162173, 12.764207770167332, 12.855057370544872, 12.945269406234853, 13.034857114675251, 13.123833281476871, 13.212210261723813, 13.300000000000004, 13.387214049233696, 13.473863588444113, 13.559959439467365, 13.645512082732552, 13.730531672153123, 13.815028049193389, 13.899010756165348, 13.982489048806727, 14.065471908187087, 14.14796805198542, 14.229985945179289, 14.311533810182612, 14.392619636466462, 14.473251189694734, 14.553436020404256, 14.633181472256814, 14.712494689888596, 14.79138262638081, 14.869852050373602, 14.947909552843837, 15.02556155356598, 15.102814307273993, 15.17967390954101, 15.256146302392361, 15.33223727966666], [0.0, 1.565247584249853, 2.2135943621178655, 2.7110883423451924, 3.130495168499706, 3.5000000000000004, 3.834057902536163, 4.141255848169732, 4.427188724235731, 4.695742752749559, 4.949747468305833, 5.191338940966965, 5.422176684690385, 5.643580423808985, 5.856620185738529, 6.06217782649107, 6.260990336999412, 6.4536811201050215, 6.640783086353598, 6.822756041366277, 7.000000000000001, 7.172865536171719, 7.341661937191061, 7.506663706334527, 7.668115805072326, 7.826237921249265, 7.981227975693967, 8.133265027035575, 8.282511696339464, 8.429116205154608, 8.573214099741124, 8.714929718592114, 8.854377448471462, 8.991662805065593, 9.126883367283709, 9.260129588726068, 9.391485505499118, 9.521029356114811, 9.648834126463155, 9.774968030638261, 9.899494936611665, 10.022474744293449, 10.14396372233261, 10.264014809030625, 10.38267788193393, 10.5, 10.616025621672172, 10.730796801729126, 10.84435336938077, 10.95673308974897, 11.067971810589329, 11.17810359586992, 11.28716084761797, 11.395174417269796, 11.502173707608488, 11.6081867662439, 11.713240371477058, 11.817360111293892, 11.920570456148482, 12.02289482612237, 12.12435565298214, 12.224974437601087, 12.324771803161306, 12.423767544509195, 12.521980673998824, 12.619429464123963, 12.716131487209466, 12.81210365240619, 12.907362240210043, 13.0019229347047, 13.095800853708797, 13.189010576991741, 13.281566172707196, 13.37348122217996, 13.46476884316994, 13.55544171172596, 13.645512082732553, 13.73499180924401, 13.823892360692051, 13.912224840046257, 14.000000000000002, 14.087228258248677, 14.173919711921615, 14.260084151224355, 14.345731072343439, 14.430869689661813, 14.515508947329407, 14.59965753022995, 14.683323874382122, 14.76651617681029, 14.849242404917499, 14.93151030539108, 15.013327412669055, 15.09470105699348, 15.175638372075163, 15.256146302392358, 15.336231610144653, 15.41590088188167, 15.49516053482506, 15.574016822900894, 15.65247584249853, 15.730543537970966], [0.0, 1.6039014932345441, 2.2682592444427514, 2.7780388766178206, 3.2078029864690882, 3.5864327680858596, 3.928740256112639, 4.243524478543749, 4.536518488885503, 4.811704479703632, 5.071981861166304, 5.319539453749733, 5.556077753235641, 5.782949074650408, 6.001249869818786, 6.2118837722545965, 6.4156059729381765, 6.613055269691915, 6.804777733328255, 6.991244524403364, 7.172865536171719, 7.3500000000000005, 7.522964841071637, 7.69204134154257, 7.857480512225278, 8.01950746617272, 8.178325011883548, 8.33411662985346, 8.487048957087499, 8.637273875477147, 8.784930278607794, 8.930145575521152, 9.073036977771006, 9.21371260676173, 9.352272451121172, 9.488809198208171, 9.623408959407264, 9.756151905336448, 9.887112824277875, 10.016361614877932, 10.143963722332607, 10.269980525784849, 10.39446968344225, 10.517485440921703, 10.639078907499465, 10.759298304257578, 10.878189187544038, 10.995794650683505, 11.112155506471282, 11.22731045264181, 11.341296222213757, 11.454147720367502, 11.565898149300816, 11.676579122328596, 11.786220768337916, 11.8948518275765, 12.002499739637573, 12.109190724404336, 12.214949856630604, 12.319801134758631, 12.423767544509193, 12.526871117721297, 12.6291329868681, 12.73057343563125, 12.831211945876353, 12.931067241337816, 13.0301573282904, 13.128499533457738, 13.22611053938383, 13.323006417471998, 13.419202658876571, 13.514714203415476, 13.60955546665651, 13.703740365316325, 13.797282341098915, 13.890194383089101, 13.982489048806729, 14.074178484018171, 14.165274441393645, 14.255788298091414, 14.345731072343439, 14.435113439110898, 14.523945744872503, 14.612238021603673, 14.700000000000001, 14.787241121994327, 14.873970552613047, 14.96019719121376, 15.045929682143274, 15.1311764248521, 15.215945583498911, 15.300245096076077, 15.38408268308514, 15.46746585578905, 15.550401924066145, 15.632898003889107, 15.714961024450556, 15.796597734955464, 15.877814711099258, 15.958618361249199, 16.03901493234544, 16.11901051553724], [0.0, 1.6416455159382004, 2.32163735324878, 2.8434134416225865, 3.283291031876401, 3.6708309685955305, 4.02119385257662, 4.3433857760968, 4.64327470649756, 4.9249365478146006, 5.191338940966964, 5.444722215136416, 5.686826883245173, 5.919037083850718, 6.142475071174485, 6.358065743604731, 6.566582063752802, 6.768677862034801, 6.96491205974634, 7.1557669050913075, 7.341661937191061, 7.522964841071637, 7.7, 7.873055315441396, 8.04238770515324, 8.208227579691004, 8.37078252017098, 8.530240324867759, 8.6867715521936, 8.840531658220563, 8.991662805065591, 9.140295400040417, 9.28654941299512, 9.430535509715238, 9.57235603182414, 9.712105847858126, 9.849873095629201, 9.985739832380975, 10.119782606360673, 10.252072961113768, 10.382677881933928, 10.511660192376846, 10.639078907499465, 10.764989549460788, 10.889444430272832, 11.01249290578659, 11.134181604410808, 11.25455463356947, 11.373653766490346, 11.491518611567404, 11.6081867662439, 11.72369395711096, 11.838074167701436, 11.951359755274712, 12.06358155772986, 12.17476899164826, 12.28495014234897, 12.39415184673804, 12.502399769644226, 12.609718474256276, 12.716131487209463, 12.821661358809942, 12.926329718833571, 13.0301573282904, 13.133164127505603, 13.235369280832325, 13.336791218280357, 13.437447674316727, 13.537355724069602, 13.636531817144713, 13.73499180924401, 13.832750991758653, 13.92982411949268, 14.026225436659713, 14.121968701282409, 14.217067208112931, 14.311533810182615, 14.405380939079675, 14.498620624045587, 14.591264509973085, 14.683323874382122, 14.774809643443804, 14.865732407116713, 14.956102433455047, 15.045929682143274, 15.13522381730776, 15.223994219652084, 15.312249997959153, 15.4, 15.48725282288631, 15.574016822900893, 15.660300124837967, 15.746110630882791, 15.831456029058101, 15.916343801262904, 16.000781230927444, 16.08477541030648, 16.168333247431537, 16.251461472741457, 16.33416664540925, 16.416455159382007, 16.49833324914975], [0.0, 1.678541033159452, 2.373815494093844, 2.907318352021327, 3.357082066318904, 3.7533318531672633, 4.1115690435647565, 4.441002139157333, 4.747630988187688, 5.0356230994783555, 5.308012810836086, 5.567090802205404, 5.814636704042654, 6.052065763026705, 6.280525455724226, 6.500961467352348, 6.714164132637808, 6.920801976649817, 7.121446482281533, 7.316590736128408, 7.5066637063345265, 7.69204134154257, 7.873055315441395, 8.05, 8.223138087129513, 8.392705165797262, 8.55891348244624, 8.72195505606398, 8.882004278314666, 9.039220099101472, 9.193747875594589, 9.345720945973083, 9.495261976375376, 9.64248411976914, 9.787492017876696, 9.930382671377776, 10.071246198956711, 10.210166502070377, 10.34722184936614, 10.482485392310359, 10.616025621672172, 10.747906772948863, 10.878189187544038, 11.006929635461471, 11.134181604410808, 11.259995559501789, 11.384419177103418, 11.507497555941518, 11.629273408085307, 11.749787232116164, 11.86907747046922, 11.987180652680598, 12.10413152605341, 12.219963175067265, 12.334707130694268, 12.448393470645119, 12.561050911448453, 12.672706893162172, 12.783387657424774, 12.893118319475706, 13.001922934704696, 13.109824560229631, 13.216845311949443, 13.323006417471998, 13.428328265275615, 13.532830450426843, 13.636531817144713, 13.739450498473367, 13.841603953299634, 13.943009000929464, 14.043681853417217, 14.143638145823726, 14.242892964563065, 14.341460873983515, 14.439355941315387, 14.536591760106631, 14.633181472256815, 14.72913778875057, 14.824473009183162, 14.919199040162983, 15.013327412669053, 15.106869298435068, 15.199835525425929, 15.292236592467434, 15.38408268308514, 15.475383678603903, 15.566149170555962, 15.656388472441533, 15.74611063088279, 15.835324436209067, 15.924038432508258, 16.012260927177024, 16.1, 16.187263511786053, 16.274059112587743, 16.36039424952834, 16.446276174259026, 16.531711950067365, 16.61670845865691, 16.701272406616212, 16.785410331594523, 16.86912860820025], [0.0, 1.7146428199482247, 2.4248711305964283, 2.9698484809835, 3.4292856398964493, 3.8340579025361627, 4.2, 4.536518488885503, 4.849742261192857, 5.143928459844674, 5.422176684690384, 5.686826883245173, 5.939696961967, 6.182232606429493, 6.415605972938176, 6.640783086353596, 6.858571279792899, 7.069653456853455, 7.274613391789286, 7.47395477642192, 7.6681158050723255, 7.857480512225277, 8.04238770515324, 8.223138087129513, 8.4, 8.573214099741124, 8.74299719775776, 8.909545442950499, 9.073036977771006, 9.233634170791046, 9.391485505499118, 9.546727187890099, 9.699484522385713, 9.849873095629203, 9.997999799959992, 10.143963722332607, 10.287856919689348, 10.429765098025939, 10.56976820937905, 10.70794097854485, 10.844353369380768, 10.979070998950688, 11.112155506471282, 11.243664882946307, 11.373653766490346, 11.502173707608488, 11.629273408085306, 11.754998936622666, 11.879393923934, 12.002499739637573, 12.124355652982143, 12.244998979175133, 12.364465212858986, 12.482788150088908, 12.6, 12.716131487209466, 12.831211945876351, 12.94526940623485, 13.058330674324342, 13.170421405558747, 13.281566172707192, 13.391788528796294, 13.501111065390136, 13.609555466656508, 13.717142559585797, 13.823892360692048, 13.92982411949268, 14.034956359034396, 14.13930691370691, 14.242892964563065, 14.34573107234344, 14.447837208385206, 14.549226783578572, 14.649914675519444, 14.749915253993834, 14.849242404917499, 14.94790955284384, 15.045929682143276, 15.143315356948756, 15.240078739954072, 15.336231610144651, 15.431785379534023, 15.526751108973187, 15.621139523094978, 15.714961024450554, 15.808225706890703, 15.900943368240767, 15.99312352231421, 16.08477541030648, 16.17590801160788, 16.26653005407115, 16.35665002376709, 16.446276174259026, 16.535416535424805, 16.624078921853087, 16.71227094083865, 16.8, 16.88727331454075, 16.974097914174997, 17.06048064973552, 17.146428199482248, 17.231947075127643], [0.0, 1.75, 2.4748737341529163, 3.0310889132455356, 3.5, 3.913118960624632, 4.286607049870562, 4.630064794363034, 4.949747468305833, 5.25, 5.5339859052946645, 5.80409338312195, 6.062177826491071, 6.309714732061982, 6.547900426854397, 6.777720855862979, 7.0, 7.215434844830907, 7.42462120245875, 7.628073151196181, 7.826237921249264, 8.01950746617272, 8.208227579691002, 8.392705165797262, 8.573214099741124, 8.750000000000002, 8.923284148787374, 9.093266739736606, 9.260129588726068, 9.424038412485384, 9.585144756340407, 9.743587634952538, 9.899494936611665, 10.052984631441552, 10.204165815979277, 10.35313962042433, 10.5, 10.644834428021886, 10.78772450519571, 10.9287464971972, 11.067971810589329, 11.205467415507487, 11.341296222213757, 11.4755174175285, 11.6081867662439, 11.739356881873896, 11.869077470469222, 11.997395550701828, 12.124355652982143, 12.250000000000002, 12.374368670764584, 12.49749974994999, 12.619429464123964, 12.740192306240909, 12.859821149611685, 12.97834735241741, 13.095800853708795, 13.212210261723811, 13.32760293526184, 13.442005058770066, 13.555441711725958, 13.667936932836646, 13.779513779520668, 13.890194383089103, 14.0, 14.108951059522461, 14.217067208112933, 14.32436735077679, 14.430869689661813, 14.536591760106633, 14.641550464346324, 14.745762103058627, 14.8492424049175, 14.95200655430568, 15.054069217324596, 15.155444566227677, 15.256146302392361, 15.356187677936216, 15.455581516073734, 15.554340230302284, 15.652475842498529, 15.750000000000002, 15.846923991740482, 15.943258763502524, 16.03901493234544, 16.134202800262557, 16.228832367117484, 16.32291334290543, 16.416455159382004, 16.509466981099056, 16.60195771588399, 16.69393602479655, 16.785410331594523, 16.876388831737675, 16.966879500957155, 17.056890103415686, 17.146428199482248, 17.235501153143186, 17.324116139070416, 17.412280149365852, 17.500000000000004, 17.58728233696156], [0.0, 1.7846568297574747, 2.5238858928247927, 3.091116303214747, 3.5693136595149495, 3.990613987846983, 4.371498598878879, 4.721758147131215, 5.047771785649585, 5.353970489272424, 5.643580423808985, 5.919037083850718, 6.182232606429494, 6.434671708797583, 6.67757440991862, 6.911946180346024, 7.138627319029899, 7.358328614570024, 7.571657678474379, 7.779138769812506, 7.981227975693966, 8.178325011883548, 8.370782520170978, 8.55891348244624, 8.742997197757758, 8.923284148787376, 9.100000000000001, 9.27334890964424, 9.44351629426243, 9.610671152422189, 9.77496803063826, 9.936548696604873, 10.09554357129917, 10.252072961113768, 10.406248123122955, 10.55817219029885, 10.707940978544848, 10.855643693489577, 11.001363551851199, 11.145178329663462, 11.28716084761797, 11.427379402120158, 11.565898149300816, 11.702777448110341, 11.838074167701436, 11.97184196354095, 12.10413152605341, 12.234990805063974, 12.364465212858988, 12.492597808302325, 12.619429464123964, 12.74499901922319, 12.869343417595166, 12.992497835289413, 13.114495796636637, 13.235369280832327, 13.35514881983724, 13.473863588444111, 13.59154148726332, 13.708209219296299, 13.823892360692048, 13.938615426217915, 14.052401929919311, 14.165274441393645, 14.277254638059798, 14.388363353766126, 14.498620624045587, 14.608045728296446, 14.716657229140049, 14.824473009183162, 14.931510305391082, 15.037785741258585, 15.143315356948758, 15.248114637554375, 15.352198539622915, 15.455581516073734, 15.558277539625012, 15.660300124837967, 15.761662348876785, 15.862376871074527, 15.962455951387932, 16.061911467817275, 16.160754932861277, 16.25899750907171, 16.356650023767095, 16.453722982960425, 16.55022658455165, 16.646170730831763, 16.741565040341957, 16.83641885912797, 16.930741271426957, 17.024541109821435, 17.11782696489248, 17.21060719440195, 17.30288993203159, 17.39468309570485, 17.485994395515515, 17.57683134128561, 17.667201249773548, 17.757111251552153, 17.846568297574752, 17.935579165446544], [0.0, 1.8186533479473213, 2.571964229922337, 3.1500000000000004, 3.6373066958946425, 4.066632513517788, 4.4547727214752495, 4.811704479703632, 5.143928459844674, 5.455960043841963, 5.751086853804244, 6.031790778864931, 6.300000000000001, 6.557247898318319, 6.804777733328254, 7.043614129124337, 7.274613391789285, 7.498499849969994, 7.715892689767013, 7.9273261570342894, 8.133265027035575, 8.334116629853462, 8.530240324867759, 8.72195505606398, 8.909545442950499, 9.093266739736608, 9.273348909644241, 9.450000000000001, 9.623408959407264, 9.793748005743257, 9.961174629530396, 10.125833299042604, 10.287856919689348, 10.447368089619511, 10.604480185280183, 10.759298304257578, 10.911920087683926, 11.062436440495377, 11.210932164632878, 11.35748651771157, 11.502173707608488, 11.64506333172989, 11.786220768337916, 11.925707526180574, 12.063581557729862, 12.199897540553364, 12.33470713069427, 12.468059191389814, 12.600000000000001, 12.73057343563125, 12.859821149611687, 12.987782720695632, 13.114495796636637, 13.239996223564418, 13.364318164425748, 13.487494207598386, 13.609555466656508, 13.730531672153122, 13.850451256186565, 13.969341430432577, 14.087228258248674, 14.204136721392118, 14.320090781835148, 14.435113439110898, 14.54922678357857, 14.662452045957387, 14.774809643443804, 14.886319222695718, 14.996999699939987, 15.106869298435068, 15.215945583498913, 15.324245495292745, 15.431785379534025, 15.53858101629618, 15.644647647038905, 15.75, 15.854652314068579, 15.958618361249199, 16.061911467817275, 16.16454453425769, 16.26653005407115, 16.367880131525894, 16.46860649842603, 16.568720529962476, 16.668233259706923, 16.76715539380488, 16.865497324419465, 16.963269142473692, 17.060480649735517, 17.157141370286602, 17.253260561412734, 17.34884722395122, 17.44391011212796, 17.538457742914574, 17.632498404934, 17.726040166940837, 17.819090885900998, 17.911658214693585, 18.00374960945636, 18.095372336594792, 18.186533479473216, 18.277239944805675], [0.0, 1.8520259177452134, 2.619160170741759, 3.2078029864690882, 3.704051835490427, 4.141255848169731, 4.536518488885503, 4.9, 5.238320341483518, 5.55607775323564, 5.856620185738529, 6.142475071174486, 6.4156059729381765, 6.67757440991862, 6.929646455628165, 7.172865536171718, 7.408103670980854, 7.636098480245001, 7.857480512225278, 8.07279381626956, 8.282511696339462, 8.487048957087499, 8.6867715521936, 8.882004278314666, 9.073036977771006, 9.260129588726068, 9.44351629426243, 9.623408959407264, 9.8, 9.973464794142506, 10.143963722332607, 10.311643903859364, 10.476640682967036, 10.639078907499465, 10.799074034379059, 10.956733089748969, 11.11215550647128, 11.265433857601758, 11.416654501210063, 11.565898149300816, 11.713240371477058, 11.858752042268193, 12.002499739637573, 12.14454610102823, 12.284950142348972, 12.423767544509193, 12.561050911448454, 12.696850003051939, 12.831211945876353, 12.964181424216495, 13.095800853708795, 13.22611053938383, 13.35514881983724, 13.482952198980758, 13.609555466656506, 13.73499180924401, 13.85929291125633, 13.982489048806725, 14.10460917572692, 14.225681003031104, 14.345731072343437, 14.464784823840278, 14.582866659199759, 14.700000000000001, 14.816207341961707, 14.931510305391077, 15.045929682143274, 15.159485479395402, 15.272196960490001, 15.38408268308514, 15.495160534825061, 15.605447766725566, 15.714961024450556, 15.82371637764024, 15.931729347437457, 16.03901493234544, 16.14558763253912, 16.25146147274146, 16.35665002376709, 16.46116642282679, 16.565023392678924, 16.668233259706923, 16.770807970995318, 16.872759110471527, 16.974097914174997, 17.074835284710655, 17.174981804939417, 17.274547750954294, 17.3735431043872, 17.471977564088156, 17.569860557215588, 17.667201249773548, 17.76400855662933, 17.860291151042304, 17.956057473732926, 18.05131574151868, 18.14607395554201, 18.240339909113537, 18.334121195192314, 18.42742521352346, 18.520259177452136, 18.612630120431668], [0.0, 1.8848076824970765, 2.665520587052368, 3.264582668581086, 3.769615364994153, 4.214558102577303, 4.616817085395522, 4.986732397071253, 5.331041174104736, 5.654423047491229, 5.960285228074241, 6.251199884822114, 6.529165337162172, 6.79577074363166, 7.05230458786346, 7.299828765114973, 7.539230729988306, 7.771261158911082, 7.996561761157105, 8.215686216013854, 8.429116205154607, 8.637273875477147, 8.840531658220563, 9.039220099101472, 9.233634170791044, 9.424038412485384, 9.610671152422189, 9.793748005743256, 9.973464794142506, 10.150000000000002, 10.323516842626839, 10.494165045395466, 10.662082348209472, 10.827395808780615, 10.990222927675308, 11.150672625451794, 11.308846094982458, 11.464837547911442, 11.618734870888483, 11.770620204560169, 11.920570456148482, 12.06865775469667, 12.214949856630605, 12.359510508106702, 12.502399769644228, 12.64367430773191, 12.783387657424774, 12.921590459382314, 13.058330674324344, 13.193653777479536, 13.32760293526184, 13.46021916612059, 13.59154148726332, 13.721607048738864, 13.850451256186565, 13.978107883401101, 14.10460917572692, 14.229985945179285, 14.354267658086915, 14.477482515962507, 14.599657530229946, 14.720818591369165, 14.840990532979932, 14.960197191213759, 15.078461459976612, 15.195805342264686, 15.312249997959153, 15.427815788373934, 15.542522317822163, 15.656388472441531, 15.769432456496336, 15.881671826353799, 15.99312352231421, 16.103803898458278, 16.213728750660657, 16.322913342905427, 16.431372432027707, 16.539120290994926, 16.646170730831763, 16.75253712128405, 16.858232410309213, 16.96326914247369, 17.067659476331258, 17.17141520085051, 17.274547750954294, 17.377068222228974, 17.478987384857284, 17.58031569682411, 17.681063316441126, 17.78124011423275, 17.880855684222723, 17.979919354657852, 18.078440198202944, 18.176427041638302, 18.27388847508926, 18.370832860814993, 18.467268341582088, 18.56320284864657, 18.658644109366577, 18.753599654466342, 18.848076824970768, 18.942082778828734], [0.0, 1.9170289512680814, 2.7110883423451915, 3.3203915431767985, 3.8340579025361627, 4.286607049870561, 4.695742752749558, 5.071981861166304, 5.422176684690383, 5.751086853804243, 6.06217782649107, 6.358065743604732, 6.640783086353597, 6.911946180346025, 7.172865536171718, 7.424621202458748, 7.6681158050723255, 7.90411285344535, 8.133265027035575, 8.356135470419327, 8.573214099741122, 8.784930278607794, 8.99166280506559, 9.193747875594589, 9.391485505499116, 9.585144756340407, 9.77496803063826, 9.961174629530394, 10.143963722332607, 10.323516842626839, 10.5, 10.673565477383834, 10.844353369380766, 11.012492905786592, 11.178103595869919, 11.341296222213755, 11.502173707608486, 11.660831874270377, 11.817360111293892, 11.97184196354095, 12.12435565298214, 12.274974541725129, 12.423767544509193, 12.570799497247577, 12.716131487209465, 12.859821149611683, 13.001922934704698, 13.14248834886301, 13.281566172707194, 13.41920265887657, 13.555441711725958, 13.690325050925564, 13.82389236069205, 13.956181426163822, 14.087228258248674, 14.21706720811293, 14.345731072343437, 14.47325118969473, 14.599657530229946, 14.72497877757384, 14.849242404917495, 14.972474745345206, 15.094701056993475, 15.215945583498911, 15.336231610144651, 15.45558151607373, 15.574016822900893, 15.691558240021926, 15.8082257068907, 15.924038432508256, 16.03901493234544, 16.153173062900056, 16.26653005407115, 16.379102539516623, 16.49090658514564, 16.60195771588399, 16.712270940838653, 16.821860776977083, 16.930741271426953, 17.03892602249332, 17.146428199482244, 17.253260561412734, 17.359435474692145, 17.464964929824507, 17.569860557215588, 17.674133642133636, 17.77779513888041, 17.880855684222723, 17.98332561013118, 18.085214955869336, 18.186533479473212, 18.287290668658382, 18.387495751189178, 18.48715770474196, 18.586285266292457, 18.684886941054792, 18.78297101099823, 18.88054554296565, 18.97761839641634, 19.0741972308142, 19.170289512680814, 19.26590252233204], [0.0, 1.9487175269905077, 2.755902755904134, 3.3752777663475344, 3.8974350539810154, 4.357464859296057, 4.773363593945049, 5.155821951929682, 5.511805511808268, 5.8461525809715225, 6.162385901580653, 6.463164859416786, 6.750555532695069, 7.026200964959656, 7.29143332959988, 7.547350528496738, 7.794870107962031, 8.034768198274298, 8.267708267712402, 8.49426276965812, 8.714929718592114, 8.930145575521152, 9.140295400040417, 9.345720945973083, 9.546727187890099, 9.74358763495254, 9.936548696604873, 10.125833299042602, 10.311643903859364, 10.494165045395466, 10.673565477383834, 10.85, 11.023611023616535, 11.194529914203635, 11.36287815652355, 11.528768364400422, 11.692305161943045, 11.853585955313271, 12.01270161121136, 12.1697370554996, 12.324771803161306, 12.477880428983124, 12.629132986868102, 12.778595384470078, 12.926329718833571, 13.072394577888168, 13.216845311949445, 13.359734278794619, 13.501111065390138, 13.641022688933555, 13.77951377952067, 13.916626746449731, 14.052401929919313, 14.186877739657872, 14.320090781835148, 14.452075975443805, 14.58286665919976, 14.71249468988859, 14.840990532979934, 14.968383346240168, 15.094701056993475, 15.21997043361123, 15.34421715174808, 15.467465855789047, 15.589740215924062, 15.711062981224407, 15.8314560290581, 15.95094041114818, 16.069536396548596, 16.18726351178605, 16.304140578392964, 16.42018574803586, 16.535416535424805, 16.649849849172814, 16.763502020759265, 16.87638883173767, 16.98852553931624, 17.099926900428553, 17.210607194401945, 17.320580244322073, 17.429859437184227, 17.53845774291457, 17.646387732337747, 17.753661594161358, 17.860291151042304, 17.96628787479484, 18.071662900795822, 18.176427041638302, 18.280590800080834, 18.384164381336454, 18.48715770474196, 18.5895804148453, 18.691441891946166, 18.79275126212232, 18.893517406772094, 18.993748971701187, 19.093454375780198, 19.192641819197274, 19.291319291328936, 19.38949457825036, 19.48717526990508, 19.584368766952895], [0.0, 1.979898987322333, 2.8, 3.4292856398964497, 3.959797974644666, 4.427188724235731, 4.849742261192857, 5.238320341483518, 5.6, 5.939696961966999, 6.260990336999411, 6.566582063752802, 6.8585712797928995, 7.138627319029899, 7.408103670980853, 7.668115805072325, 7.919595949289332, 8.16333265278342, 8.4, 8.630179604156568, 8.854377448471462, 9.073036977771004, 9.28654941299512, 9.495261976375376, 9.699484522385713, 9.899494936611667, 10.09554357129917, 10.287856919689348, 10.476640682967036, 10.662082348209472, 10.844353369380766, 11.023611023616535, 11.2, 11.373653766490346, 11.54469575172945, 11.713240371477058, 11.879393923933998, 12.043255373859678, 12.204917041913886, 12.364465212858986, 12.521980673998822, 12.677539193392384, 12.831211945876353, 12.983065893693983, 13.133164127505603, 13.281566172707192, 13.428328265275615, 13.57350360076572, 13.717142559585799, 13.85929291125633, 14.0, 14.13930691370691, 14.277254638059798, 14.4138821973818, 14.549226783578568, 14.683323874382122, 14.816207341961706, 14.947909552843834, 15.07846145997661, 15.207892687680303, 15.33623161014465, 15.463505424062165, 15.58974021592406, 15.714961024450554, 15.839191898578663, 15.962455951387929, 16.08477541030648, 16.206171663906318, 16.32666530556684, 16.446276174259022, 16.565023392678928, 16.682925402938178, 16.8, 16.9162643630324, 17.031735084835013, 17.146428199482244, 17.260359208313137, 17.3735431043872, 17.485994395515515, 17.59772712596715, 17.708754896942924, 17.819090885900998, 17.928747864811978, 18.037738217415175, 18.146073955542008, 18.253766734567417, 18.360827868045604, 18.467268341582088, 18.57309882599024, 18.678329689776866, 18.78297101099823, 18.887032588524857, 18.990523952750753, 19.0934543757802, 19.195832881122925, 19.297668252926307, 19.398969044771427, 19.49974358805777, 19.599999999999998, 19.699746191258406, 19.798989873223334, 19.897738564972656], [0.0, 2.01059692628831, 2.8434134416225865, 3.4824560298731706, 4.02119385257662, 4.4958314025327955, 4.924936547814601, 5.319539453749733, 5.686826883245173, 6.03179077886493, 6.358065743604733, 6.668395609140179, 6.964912059746341, 7.249310312022794, 7.522964841071637, 7.787008411450445, 8.04238770515324, 8.28990349762891, 8.53024032486776, 8.763988817884243, 8.991662805065591, 9.21371260676173, 9.430535509715236, 9.64248411976914, 9.849873095629203, 10.052984631441552, 10.252072961113768, 10.447368089619511, 10.639078907499465, 10.827395808780617, 11.012492905786592, 11.194529914203635, 11.373653766490346, 11.550000000000002, 11.72369395711096, 11.8948518275765, 12.06358155772986, 12.229983646759306, 12.394151846738042, 12.55617378025647, 12.716131487209466, 12.874101910424669, 13.030157328290402, 13.184365741286154, 13.336791218280357, 13.487494207598386, 13.636531817144713, 13.783958067260652, 13.929824119492682, 14.074178484018171, 14.217067208112933, 14.358534047736214, 14.498620624045587, 14.637366566428542, 14.774809643443804, 14.910985882898556, 15.045929682143274, 15.179673909541009, 15.312249997959151, 15.443688031037148, 15.57401682290089, 15.70326399192219, 15.831456029058097, 15.958618361249199, 16.08477541030648, 16.209950647673175, 16.33416664540925, 16.457445123712247, 16.57980699525782, 16.701272406616212, 16.821860776977086, 16.941590834393327, 17.06048064973552, 17.178547668531237, 17.29580874084817, 17.412280149365852, 17.527977635768487, 17.642916425579987, 17.757111251552153, 17.870576375707643, 17.983325610131182, 18.095372336594792, 18.206729525095938, 18.317409751381334, 18.42742521352346, 18.53678774761151, 18.64550884261409, 18.753599654466342, 18.861071019430472, 18.96793346677492, 19.0741972308142, 19.17987226234836, 19.28496823953828, 19.38949457825036, 19.49346044190205, 19.596874750837188, 19.699746191258406, 19.802083223741896, 19.903894091358104, 20.005186827420538, 20.105969262883104, 20.206249033405488], [0.0, 2.040833163195855, 2.8861739379323623, 3.5348267284267276, 4.08166632639171, 4.563441683641854, 4.998999899979995, 5.399537017189529, 5.772347875864725, 6.1224994895875655, 6.4536811201050215, 6.768677862034801, 7.069653456853455, 7.3583286145700235, 7.636098480245, 7.9041128534453495, 8.16333265278342, 8.414570696119917, 8.658521813797089, 8.895785518997187, 9.126883367283709, 9.352272451121172, 9.57235603182414, 9.787492017876696, 9.99799979995999, 10.204165815979277, 10.406248123122955, 10.604480185280181, 10.799074034379059, 10.990222927675308, 11.178103595869919, 11.362878156523548, 11.54469575172945, 11.72369395711096, 11.9, 12.073731817462239, 12.244998979175131, 12.41390349567774, 12.580540528928001, 12.744999019223188, 12.907362240210043, 13.06770829181613, 13.22611053938383, 13.382638006013611, 13.537355724069602, 13.690325050925562, 13.841603953299634, 13.99124726391468, 14.13930691370691, 14.285832142370987, 14.430869689661813, 14.574463969559911, 14.716657229140047, 14.85748969375379, 14.996999699939986, 15.135223817307757, 15.27219696049, 15.407952492138596, 15.542522317822163, 15.675936973591085, 15.808225706890699, 15.93941655142998, 16.069536396548592, 16.19861105156859, 16.32666530556684, 16.45372298296042, 16.57980699525782, 16.704939389294413, 16.829141392239833, 16.95243345363727, 17.07483528471066, 17.196365895153544, 17.317043627594177, 17.436886189913608, 17.555910685578233, 17.674133642133636, 17.791571037994373, 17.908238327652445, 18.02415046541723, 18.139321927789915, 18.253766734567417, 18.367498468762697, 18.480530295421723, 18.592874979410794, 18.704544902242343, 18.815552078001858, 18.925908168434088, 19.035624497242008, 19.14471206364828, 19.25318155526509, 19.361043360315065, 19.468307579242733, 19.574984035753392, 19.68108228731337, 19.7866116351436, 19.89158113373595, 19.99599959991998, 20.099875621505724, 20.203217565526536, 20.306033586104405, 20.408331631958553, 20.510119453577058], [0.0, 2.0706279240848655, 2.9283100928692645, 3.5864327680858596, 4.141255848169731, 4.630064794363033, 5.071981861166304, 5.4783665448744845, 5.856620185738529, 6.2118837722545965, 6.547900426854397, 6.867495904622004, 7.172865536171719, 7.4657551526955395, 7.747580267412529, 8.019507466172719, 8.282511696339462, 8.537417642355328, 8.784930278607794, 9.025657870759341, 9.260129588726066, 9.488809198208171, 9.712105847858124, 9.930382671377776, 10.143963722332607, 10.35313962042433, 10.55817219029885, 10.759298304257578, 10.956733089748969, 11.150672625451795, 11.341296222213755, 11.528768364400422, 11.713240371477058, 11.8948518275765, 12.073731817462239, 12.25, 12.423767544509193, 12.595137950812608, 12.764207770167328, 12.931067241337818, 13.095800853708795, 13.25848784741307, 13.41920265887657, 13.578015318889575, 13.734991809244008, 13.8901943830891, 14.043681853417217, 14.195509853471272, 14.345731072343439, 14.49439546859406, 14.641550464346322, 14.787241121994327, 14.931510305391079, 15.074398827150622, 15.21594558349891, 15.356187677936214, 15.495160534825057, 15.632898003889105, 15.769432456496334, 15.90479487450247, 16.039014932345438, 16.17212107300709, 16.30414057839296, 16.435099634623455, 16.565023392678924, 16.693936024796546, 16.821860776977083, 16.948820017924554, 17.074835284710655, 17.19992732542786, 17.324116139070416, 17.447421012860325, 17.569860557215588, 17.691452738540153, 17.81221490999926, 17.932163840429297, 18.051315741518682, 18.169686293384377, 18.287290668658386, 18.40414355518887, 18.520259177452132, 18.63565131676379, 18.750333330370427, 18.86431816949661, 18.977618396416343, 19.0902462006125, 19.202213414083285, 19.313531525849953, 19.42421169571625, 19.534264767326153, 19.643701280563192, 19.752531483331445, 19.860765342755553, 19.968412555834277, 20.075482559579985, 20.18198454067389, 20.287927444665215, 20.393319984740103, 20.498170650084848, 20.602487713866015, 20.70627924084866, 20.80955309467265], [0.0, 2.1, 2.9698484809834995, 3.6373066958946425, 4.2, 4.695742752749558, 5.143928459844674, 5.55607775323564, 5.939696961966999, 6.299999999999999, 6.640783086353596, 6.964912059746339, 7.274613391789285, 7.571657678474377, 7.857480512225276, 8.133265027035574, 8.4, 8.658521813797087, 8.909545442950499, 9.153687781435416, 9.391485505499116, 9.623408959407264, 9.849873095629201, 10.071246198956711, 10.287856919689348, 10.500000000000002, 10.70794097854485, 10.911920087683926, 11.11215550647128, 11.30884609498246, 11.502173707608488, 11.692305161943045, 11.879393923933998, 12.063581557729862, 12.244998979175131, 12.423767544509193, 12.599999999999998, 12.773801313626262, 12.94526940623485, 13.114495796636637, 13.281566172707192, 13.446560898608984, 13.609555466656508, 13.7706209010342, 13.929824119492679, 14.087228258248674, 14.242892964563064, 14.396874660842192, 14.54922678357857, 14.7, 14.849242404917499, 14.996999699939986, 15.143315356948754, 15.28823076748909, 15.431785379534022, 15.574016822900893, 15.714961024450552, 15.854652314068574, 15.993123522314207, 16.130406070524078, 16.266530054071147, 16.401524319403975, 16.5354165354248, 16.66823325970692, 16.8, 16.930741271426953, 17.060480649735517, 17.189240820932145, 17.317043627594174, 17.44391011212796, 17.569860557215588, 17.694914523670352, 17.819090885900998, 17.942407865166814, 18.064883060789512, 18.186533479473212, 18.30737556287083, 18.427425213523456, 18.54669781928848, 18.665208276362737, 18.78297101099823, 18.900000000000002, 19.016308790088576, 19.131910516203025, 19.24681791881453, 19.361043360315065, 19.474598840540978, 19.587496011486515, 19.699746191258402, 19.811360377318866, 19.922349259060788, 20.03272322975586, 20.142492397913422, 20.251666598085208, 20.360255401148585, 20.468268124098824, 20.575713839378697, 20.68260138377182, 20.788939366884495, 20.894736179239022, 21.000000000000004, 21.10473880435387], [0.0, 2.128966885604377, 3.0108138434649194, 3.6874788134984593, 4.257933771208754, 4.7605146780574055, 5.2148825490129695, 5.632716928800879, 6.021627686929839, 6.386900656813131, 6.732384421584971, 7.060984350641205, 7.374957626996919, 7.676099269811458, 7.9658646737187295, 8.245453292572822, 8.515867542417508, 8.777955342789118, 9.03244153039476, 9.279951508494, 9.521029356114811, 9.756151905336448, 9.985739832380974, 10.210166502070377, 10.429765098025939, 10.644834428021886, 10.855643693489577, 11.062436440495377, 11.265433857601758, 11.464837547911442, 11.660831874270377, 11.853585955313271, 12.043255373859678, 12.229983646759306, 12.41390349567774, 12.595137950812608, 12.773801313626262, 12.950000000000001, 13.123833281476873, 13.295393939255808, 13.464768843169942, 13.632039465905315, 13.797282341098917, 13.96056947262539, 14.12196870128241, 14.281544034172216, 14.439355941315391, 14.59546162339513, 14.749915253993837, 14.90276819923064, 15.054069217324598, 15.203864640281433, 15.352198539622917, 15.499112877839172, 15.644647647038907, 15.788840996095946, 15.931729347437459, 16.073347504487046, 16.213728750660657, 16.352904940713135, 16.490906585145645, 16.627762928307586, 16.763502020759265, 16.89815078640264, 17.031735084835017, 17.164279769334918, 17.295808740848173, 17.426344998306444, 17.555910685578237, 17.684527135323695, 17.812214909999263, 17.938993840235298, 18.06488306078952, 18.189901044260797, 18.31406563273158, 18.437394067492292, 18.559903016988, 18.681608603115528, 18.80252642598861, 18.922671587278582, 19.042058712229622, 19.160701970439394, 19.27861509548858, 19.395811403496374, 19.512303810672897, 19.628104849933937, 19.74322668663864, 19.857681133506, 19.971479664761947, 20.084633429565, 20.197153264754913, 20.309049706965613, 20.420333004140755, 20.531013126487455, 20.641099776901427, 20.750602400894294, 20.859530196051878, 20.967892121050227, 21.075696904254436, 21.18295305192362, 21.28966885604377, 21.395852401809098], [0.0, 2.157544901039142, 3.0512292604784714, 3.7369773882109594, 4.315089802078284, 4.824417063231578, 5.284884104689525, 5.708327250605032, 6.102458520956943, 6.472634703117425, 6.822756041366275, 7.155766905091306, 7.473954776421919, 7.779138769812505, 8.072793816269558, 8.356135470419325, 8.630179604156568, 8.895785518997185, 9.153687781435416, 9.404520189781085, 9.648834126463155, 9.887112824277875, 10.119782606360673, 10.34722184936614, 10.56976820937905, 10.78772450519571, 11.001363551851199, 11.210932164632878, 11.416654501210065, 11.618734870888485, 11.817360111293892, 12.01270161121136, 12.204917041913886, 12.394151846738044, 12.580540528928001, 12.76420777016733, 12.94526940623485, 13.123833281476873, 13.3, 13.473863588444113, 13.64551208273255, 13.815028049193389, 13.982489048806727, 14.147968051985416, 14.311533810182612, 14.473251189694732, 14.633181472256814, 14.791382626380809, 14.947909552843837, 15.102814307273993, 15.25614630239236, 15.4079524921386, 15.55827753962501, 15.707163970621815, 15.854652314068575, 16.000781230927448, 16.145587632539115, 16.289106789508136, 16.431372432027704, 16.5724168424524, 16.71227094083865, 16.850964364095013, 16.988525539316235, 17.124981751815096, 17.260359208313137, 17.394683095704845, 17.527977635768483, 17.66026613616001, 17.79157103799437, 17.921913960288954, 18.051315741518682, 18.179796478508774, 18.30737556287083, 18.434071715169168, 18.55990301698799, 18.684886941054796, 18.80904037956217, 18.93237967081793, 19.05492062434268, 19.176678544523817, 19.29766825292631, 19.41790410935228, 19.537400031734013, 19.65616951493856, 19.77422564855575, 19.891581133735954, 20.008248299139037, 20.124239116051076, 20.239565212721345, 20.354237887968196, 20.468268124098824, 20.58166659918482, 20.69444369873228, 20.806609526782594, 20.918173916477514, 21.02914644011972, 21.1395364187581, 21.24935293132476, 21.3586048233493, 21.467300715273918, 21.57544901039142, 21.68305790242696], [0.0, 2.1857492994394394, 3.0911163032147466, 3.7858288392371895, 4.371498598878879, 4.88748401531913, 5.353970489272425, 5.782949074650408, 6.182232606429493, 6.557247898318319, 6.911946180346026, 7.249310312022794, 7.571657678474379, 7.880831174438392, 8.178325011883546, 8.465370635713477, 8.742997197757758, 9.012075232708614, 9.273348909644241, 9.527460312171343, 9.77496803063826, 10.01636161487793, 10.252072961113768, 10.482485392310359, 10.70794097854485, 10.9287464971972, 11.145178329663462, 11.357486517711568, 11.565898149300816, 11.770620204560169, 11.97184196354095, 12.169737055499597, 12.364465212858986, 12.55617378025647, 12.744999019223188, 12.931067241337818, 13.114495796636637, 13.295393939255808, 13.473863588444113, 13.650000000000004, 13.823892360692051, 13.995624316192547, 14.165274441393645, 14.33291666061029, 14.498620624045587, 14.662452045957389, 14.824473009183162, 14.984742240025353, 15.143315356948758, 15.300245096076077, 15.455581516073734, 15.609372184684434, 15.761662348876785, 15.91249509033703, 16.061911467817275, 16.20995064767318, 16.35665002376709, 16.5020453277768, 16.646170730831763, 16.78905893729604, 16.930741271426953, 17.07124775756008, 17.210607194401945, 17.348847223951225, 17.485994395515515, 17.622074225243747, 17.757111251552153, 17.891129086784883, 18.02415046541723, 18.156197289080115, 18.287290668658386, 18.41745096369202, 18.546697819288482, 18.67505020073574, 18.80252642598861, 18.929144196185945, 19.054920624342685, 19.17987226234836, 19.30401512639275, 19.427364720929088, 19.54993606127652, 19.67174369495496, 19.792801721838174, 19.913123813204198, 20.03272322975586, 20.151612838678698, 20.269805129798364, 20.38731223089498, 20.504145922227536, 20.62031765031761, 20.735838541038074, 20.850719412049074, 20.964970784620718, 21.078602894878973, 21.191625704508848, 21.304048910946484, 21.4158819570897, 21.527134040554497, 21.637814122503226, 21.747930936068382, 21.8574929943944, 21.96650859831849], [0.0, 2.2135943621178655, 3.1304951684997055, 3.834057902536163, 4.427188724235731, 4.949747468305833, 5.422176684690384, 5.856620185738529, 6.260990336999411, 6.640783086353596, 7.0, 7.341661937191061, 7.668115805072326, 7.981227975693966, 8.282511696339462, 8.573214099741122, 8.854377448471462, 9.126883367283709, 9.391485505499118, 9.648834126463157, 9.899494936611665, 10.143963722332607, 10.382677881933928, 10.616025621672172, 10.844353369380768, 11.067971810589329, 11.28716084761797, 11.502173707608488, 11.713240371477058, 11.920570456148482, 12.12435565298214, 12.324771803161306, 12.521980673998822, 12.716131487209466, 12.907362240210043, 13.095800853708795, 13.281566172707192, 13.464768843169942, 13.64551208273255, 13.823892360692051, 14.0, 14.173919711921613, 14.345731072343439, 14.515508947329403, 14.683323874382122, 14.849242404917497, 15.013327412669053, 15.17563837207516, 15.336231610144653, 15.49516053482506, 15.652475842498529, 15.808225706890703, 15.962455951387932, 16.115210206509875, 16.26653005407115, 16.416455159382004, 16.565023392678924, 16.71227094083865, 16.858232410309213, 17.002940922087568, 17.146428199482244, 17.288724649319857, 17.429859437184223, 17.569860557215588, 17.708754896942924, 17.846568297574745, 17.983325610131182, 18.1190507477627, 18.253766734567417, 18.387495751189178, 18.520259177452136, 18.652077632263918, 18.782971010998235, 18.912958520548813, 19.04205871222962, 19.170289512680814, 19.297668252926314, 19.424211695716252, 19.54993606127652, 19.674857051577277, 19.79898987322333, 19.92234925906079, 20.044949488586898, 20.166804407243106, 20.287927444665215, 20.408331631958553, 20.528029618061254, 20.647033685253678, 20.765355763867856, 20.883007446246815, 21.0, 21.1163443805977, 21.232051243344344, 21.34713095476767, 21.46159360345825, 21.575449010391416, 21.688706738761535, 21.801376103356414, 21.913466179497938, 22.024985811573185, 22.135943621178658, 22.246348014898988], [0.0, 2.2410934831014973, 3.169384798348096, 3.8816877772432967, 4.4821869662029945, 5.011237372146724, 5.489535499475343, 5.929376021134097, 6.338769596696192, 6.723280449304491, 7.0869598559608065, 7.432866203558357, 7.763375554486593, 8.080377466430638, 8.385403985497659, 8.67971773734607, 8.964373932405989, 9.240265147710861, 9.50815439504429, 9.768700015867006, 10.022474744293447, 10.269980525784849, 10.511660192376844, 10.747906772948863, 10.979070998950686, 11.205467415507487, 11.427379402120158, 11.645063331729888, 11.858752042268193, 12.06865775469667, 12.274974541725127, 12.477880428983122, 12.677539193392384, 12.874101910424667, 13.06770829181613, 13.258487847413068, 13.446560898608983, 13.632039465905315, 13.815028049193387, 13.995624316192547, 14.173919711921613, 14.350000000000003, 14.523945744872503, 14.69583274265191, 14.865732407116713, 15.03371211644017, 15.199835525425927, 15.36416284735358, 15.526751108973187, 15.68765438171048, 15.846923991740482, 16.00460871124315, 16.160754932861277, 16.315406829129333, 16.46860649842603, 16.620394098817275, 16.770807970995318, 16.91988475138055, 17.067659476331254, 17.214165678301114, 17.35943547469214, 17.503499650069983, 17.646387732337743, 17.78812806340229, 17.928747864811978, 18.068273298796427, 18.206729525095938, 18.344140753930127, 18.480530295421723, 18.615920605761083, 18.750333330370427, 18.883789344302695, 19.01630879008858, 19.147911113225902, 19.278615095488576, 19.40843888621648, 19.537400031734013, 19.665515503032207, 19.79280172183817, 19.91927458518508, 20.044949488586894, 20.169841347913476, 20.29396462005392, 20.417333322449334, 20.539961051569698, 20.661861000403622, 20.783045975024933, 20.90352841029476, 21.02332038475369, 21.14243363475454, 21.26087956788242, 21.378669275705636, 21.495813545897725, 21.612322873768107, 21.728207473236264, 21.843477287281896, 21.95814199790137, 22.072211035598592, 22.18569358843667, 22.29859861067507, 22.410934831014973, 22.52271076047464], [0.0, 2.2682592444427514, 3.2078029864690882, 3.928740256112639, 4.536518488885503, 5.071981861166304, 5.556077753235641, 6.001249869818787, 6.4156059729381765, 6.804777733328254, 7.172865536171719, 7.522964841071638, 7.857480512225278, 8.178325011883548, 8.487048957087499, 8.784930278607792, 9.073036977771006, 9.352272451121172, 9.623408959407266, 9.887112824277876, 10.143963722332607, 10.39446968344225, 10.639078907499465, 10.87818918754404, 11.112155506471282, 11.341296222213758, 11.565898149300816, 11.786220768337916, 12.002499739637575, 12.214949856630605, 12.423767544509195, 12.629132986868102, 12.831211945876353, 13.030157328290402, 13.22611053938383, 13.419202658876571, 13.609555466656508, 13.797282341098919, 13.982489048806727, 14.165274441393647, 14.345731072343439, 14.523945744872503, 14.700000000000003, 14.873970552613045, 15.045929682143276, 15.215945583498911, 15.38408268308514, 15.550401924066144, 15.714961024450556, 15.87781471109926, 16.03901493234544, 16.19861105156859, 16.356650023767095, 16.513176556919632, 16.668233259706923, 16.821860776977083, 16.974097914174997, 17.124981751815096, 17.274547750954294, 17.4228298505151, 17.569860557215584, 17.715671028781273, 17.860291151042304, 18.003749609456364, 18.14607395554201, 18.287290668658382, 18.42742521352346, 18.566502093824784, 18.704544902242343, 18.84157636717268, 18.977618396416347, 19.112692118066466, 19.246817918814532, 19.38001547986998, 19.512303810672893, 19.643701280563192, 19.774225648555753, 19.903894091358104, 20.032723229755863, 20.16072915348054, 20.287927444665215, 20.414333199984764, 20.539961051569698, 20.664825186775715, 20.7889393668845, 20.91231694480552, 21.03497088184341, 21.15691376359038, 21.27815781499893, 21.398714914685883, 21.518596608515157, 21.637814122503226, 21.75637837508808, 21.874299988799645, 21.991589301367018, 22.10825637629526, 22.224311012942565, 22.33976275612613, 22.454620905283615, 22.568894523214915, 22.682592444427517, 22.7957232831073], [0.0, 2.2951034835057, 3.245766473423496, 3.9752358420601914, 4.5902069670114, 5.132007404515313, 5.6218324414731535, 6.072273050514115, 6.491532946846992, 6.8853104505171, 7.2577544736647015, 7.61199710982604, 7.950471684120383, 8.275113292275822, 8.587490902469707, 8.888897569440203, 9.1804139340228, 9.462954084217042, 9.737299420270489, 10.004124149569517, 10.264014809030625, 10.517485440921703, 10.764989549460788, 11.006929635461471, 11.243664882946307, 11.475517417528502, 11.702777448110341, 11.925707526180574, 12.14454610102823, 12.359510508106704, 12.57079949724758, 12.778595384470078, 12.983065893693984, 13.184365741286154, 13.382638006013613, 13.578015318889575, 13.7706209010342, 13.96056947262539, 14.147968051985416, 14.33291666061029, 14.515508947329403, 14.695832742651913, 14.873970552613045, 15.049999999999997, 15.22399421965208, 15.396022213545937, 15.56614917055596, 15.734436755092315, 15.900943368240766, 16.0657243845399, 16.22883236711748, 16.390317263555335, 16.550226584551645, 16.708605567192016, 16.865497324419458, 17.02094298210296, 17.174981804939414, 17.327651312281187, 17.47898738485728, 17.629024363248238, 17.777795138880407, 17.92533123822263, 18.07166290079582, 18.216819151542346, 18.3608278680456, 18.50371584304082, 18.645508842614085, 18.7862316604475, 18.925908168434084, 19.06456136395485, 19.202213414083285, 19.338885696957824, 19.474598840540978, 19.60937275896401, 19.743226686638632, 19.876179210300954, 20.008248299139034, 20.139451333142123, 20.26980512979836, 20.399325969256925, 20.52802961806125, 20.655931351551303, 20.783045975024933, 20.90938784374138, 21.034970881843407, 21.159808600268576, 21.28391411371508, 21.40730015672224, 21.529979098921576, 21.651962959510158, 21.773263420994105, 21.893891842246777, 22.013859270922943, 22.13317645526733, 22.251853855353268, 22.36990165378471, 22.487329765892614, 22.604147849454534, 22.72036531396447, 22.835991329478123, 22.951034835057005, 23.06550454683357], [0.0, 2.32163735324878, 3.283291031876401, 4.021193852576621, 4.64327470649756, 5.191338940966965, 5.686826883245173, 6.142475071174486, 6.566582063752802, 6.964912059746339, 7.341661937191061, 7.700000000000001, 8.042387705153242, 8.37078252017098, 8.6867715521936, 8.99166280506559, 9.28654941299512, 9.57235603182414, 9.849873095629203, 10.119782606360674, 10.38267788193393, 10.639078907499465, 10.889444430272832, 11.13418160441081, 11.373653766490346, 11.608186766243902, 11.838074167701436, 12.063581557729862, 12.284950142348972, 12.502399769644228, 12.716131487209466, 12.926329718833573, 13.133164127505603, 13.336791218280357, 13.537355724069602, 13.73499180924401, 13.929824119492679, 14.121968701282412, 14.311533810182612, 14.49862062404559, 14.683323874382122, 14.865732407116715, 15.045929682143276, 15.22399421965208, 15.400000000000002, 15.574016822900893, 15.746110630882793, 15.916343801262903, 16.084775410306484, 16.25146147274146, 16.416455159382007, 16.57980699525782, 16.74156504034196, 16.901775054709493, 17.060480649735517, 17.217723426748382, 17.3735431043872, 17.52797763576848, 17.681063316441126, 17.832834883999798, 17.98332561013118, 18.132567385784068, 18.280590800080834, 18.42742521352346, 18.57309882599024, 18.717638739969313, 18.861071019430476, 19.00342074469752, 19.14471206364828, 19.28496823953828, 19.424211695716256, 19.56246405747497, 19.699746191258406, 19.836078241426655, 19.971479664761947, 20.1059692628831, 20.23956521272135, 20.372285095197352, 20.504145922227536, 20.635164162177148, 20.76535576386786, 20.894736179239022, 21.023320384753696, 21.15112290163338, 21.27815781499893, 21.40443879198892, 21.529979098921583, 21.65479161756123, 21.778888860545663, 21.902282986026822, 22.024985811573185, 22.147008827378926, 22.26836320882162, 22.38905982840727, 22.509109267138943, 22.62852182534246, 22.74730753298069, 22.86547615948551, 22.983037223134804, 23.100000000000005, 23.216373532487804, 23.332166637498545], [0.0, 2.347871376374779, 3.320391543176798, 4.066632513517788, 4.695742752749558, 5.249999999999999, 5.751086853804244, 6.2118837722545965, 6.640783086353596, 7.043614129124337, 7.424621202458749, 7.787008411450445, 8.133265027035575, 8.465370635713477, 8.784930278607792, 9.093266739736604, 9.391485505499116, 9.680521680157531, 9.961174629530396, 10.234134062049414, 10.499999999999998, 10.759298304257578, 11.01249290578659, 11.259995559501789, 11.502173707608488, 11.739356881873896, 11.97184196354095, 12.199897540553362, 12.423767544509193, 12.64367430773191, 12.859821149611683, 13.072394577888168, 13.281566172707192, 13.487494207598386, 13.690325050925562, 13.8901943830891, 14.087228258248674, 14.281544034172216, 14.473251189694732, 14.662452045957389, 14.849242404917497, 15.03371211644017, 15.21594558349891, 15.396022213545937, 15.57401682290089, 15.749999999999998, 15.924038432508256, 16.096195202593684, 16.26653005407115, 16.43509963462345, 16.60195771588399, 16.767155393804877, 16.930741271426953, 17.092761625904693, 17.25326056141273, 17.41228014936585, 17.569860557215584, 17.726040166940837, 17.88085568422272, 18.03434223918355, 18.18653347947321, 18.33746165640163, 18.487157704741957, 18.63565131676379, 18.78297101099823, 18.92914419618594, 19.074197230814196, 19.218155478609283, 19.361043360315062, 19.502884402057045, 19.643701280563192, 19.783515865487608, 19.92234925906079, 20.060221833269935, 20.197153264754906, 20.333162567588936, 20.468268124098827, 20.60248771386601, 20.735838541038074, 20.86833726006938, 20.999999999999996, 21.13084238737301, 21.26087956788242, 21.39012622683653, 21.518596608515157, 21.646304534492717, 21.773263420994105, 21.89948629534492, 22.02498581157318, 22.14977426521543, 22.273863607376246, 22.39726545808662, 22.519991119003578, 22.642051585490215, 22.76345755811274, 22.884219453588532, 23.004347415216976, 23.123851322822503, 23.242740802237584, 23.361025234351338, 23.47871376374779, 23.595815306956446], [0.0, 2.373815494093844, 3.357082066318904, 4.1115690435647565, 4.747630988187688, 5.308012810836086, 5.814636704042653, 6.280525455724226, 6.714164132637808, 7.121446482281531, 7.5066637063345265, 7.873055315441396, 8.223138087129513, 8.55891348244624, 8.882004278314664, 9.193747875594587, 9.495261976375376, 9.787492017876694, 10.071246198956713, 10.347221849366141, 10.616025621672172, 10.878189187544038, 11.134181604410806, 11.384419177103418, 11.629273408085306, 11.869077470469222, 12.10413152605341, 12.334707130694268, 12.561050911448453, 12.783387657424774, 13.001922934704696, 13.216845311949445, 13.428328265275615, 13.636531817144713, 13.841603953299634, 14.043681853417215, 14.242892964563062, 14.43935594131539, 14.633181472256812, 14.824473009183162, 15.013327412669053, 15.199835525425927, 15.384082683085138, 15.566149170555958, 15.746110630882791, 15.924038432508256, 16.1, 16.27405911258774, 16.446276174259026, 16.61670845865691, 16.78541033159452, 16.95243345363727, 17.11782696489248, 17.281637653879915, 17.44391011212796, 17.60468687594301, 17.764008556629328, 17.92191396028895, 18.07844019820294, 18.23362278868355, 18.387495751189174, 18.54009169340864, 18.691441891946162, 18.84157636717268, 18.990523952750753, 19.13831236028924, 19.284968239538276, 19.430517234494815, 19.57498403575339, 19.718392429404588, 19.860765342755553, 20.00212488712137, 20.142492397913426, 20.281888472230587, 20.420333004140748, 20.55784521782378, 20.694443698732282, 20.830146422913117, 20.964970784620714, 21.09893362234215, 21.232051243344344, 21.364339446844596, 21.495813545897725, 21.62648838808557, 21.756378375088076, 21.885497481208876, 22.013859270922946, 22.141476915508598, 22.26836320882161, 22.394530582264945, 22.519991119003578, 22.644756567470537, 22.768838354206835, 22.892247596074967, 23.01499511188304, 23.137091433453772, 23.25854681617061, 23.379371249030633, 23.499574464232325, 23.619165946324188, 23.738154940938443, 23.856550463132766], [0.0, 2.3994791101403656, 3.3933759001914305, 4.156019730463272, 4.798958220280731, 5.365398400864562, 5.877499468311333, 6.348425001525969, 6.786751800382861, 7.198437330421096, 7.58781918603758, 7.958171900631451, 8.312039460926544, 8.651444966015793, 8.978028736866461, 9.293142633146227, 9.597916440561463, 9.8933058175718, 10.180127700574293, 10.459086958238757, 10.730796801729124, 10.995794650683505, 11.254554633569468, 11.50749755594152, 11.754998936622666, 11.997395550701828, 12.234990805063976, 12.468059191389813, 12.696850003051939, 12.921590459382314, 13.142488348863012, 13.35973427879462, 13.573503600765722, 13.783958067260654, 13.99124726391468, 14.195509853471274, 14.396874660842192, 14.595461623395131, 14.791382626380809, 14.984742240025355, 15.17563837207516, 15.36416284735358, 15.550401924066144, 15.734436755092315, 15.916343801262903, 16.096195202593684, 16.27405911258774, 16.45, 16.624078921853087, 16.79635377098256, 16.966879500957152, 17.13570833085111, 17.302889932031587, 17.468471598854894, 17.632498404933997, 17.795013346440626, 17.956057473732923, 18.115670012450547, 18.273888475089258, 18.43074876395422, 18.586285266292453, 18.74053094231858, 18.89351740677209, 19.04527500457791, 19.195832881122925, 19.345219047609667, 19.493460441902048, 19.640582985237483, 19.7866116351436, 19.93157043486539, 20.075482559579985, 20.21837035965065, 20.360255401148585, 20.50115850385046, 20.64109977690142, 20.780098652316354, 20.918173916477514, 21.055343739773047, 21.191625704508848, 21.327036831214976, 21.461593603458248, 21.59531199126329, 21.728207473236264, 21.860295057478066, 21.99158930136701, 22.122104330284678, 22.251853855353268, 22.380851190247437, 22.509109267138935, 22.636640651828174, 22.76345755811274, 22.889571861439435, 23.01499511188304, 23.139738546491838, 23.263813101037417, 23.387229421203358, 23.509997873245332, 23.632128554152715, 23.75363130134001, 23.874515701894357, 23.994791101403656, 24.11446661238851], [0.0, 2.4248711305964283, 3.4292856398964497, 4.200000000000001, 4.849742261192857, 5.422176684690385, 5.939696961967, 6.415605972938177, 6.8585712797928995, 7.274613391789285, 7.668115805072326, 8.042387705153242, 8.400000000000002, 8.74299719775776, 9.073036977771006, 9.391485505499116, 9.699484522385713, 9.997999799959992, 10.28785691968935, 10.569768209379053, 10.84435336938077, 11.112155506471282, 11.373653766490346, 11.629273408085307, 11.879393923934, 12.124355652982144, 12.364465212858988, 12.600000000000001, 12.831211945876355, 13.058330674324344, 13.281566172707194, 13.50111106539014, 13.717142559585799, 13.929824119492682, 14.139306913706912, 14.34573107234344, 14.54922678357857, 14.749915253993837, 14.947909552843837, 15.14331535694876, 15.336231610144653, 15.526751108973189, 15.714961024450556, 15.900943368240766, 16.084775410306484, 16.26653005407115, 16.446276174259026, 16.624078921853087, 16.800000000000004, 16.974097914175, 17.14642819948225, 17.317043627594177, 17.48599439551552, 17.653328298085892, 17.819090885900998, 17.983325610131182, 18.14607395554201, 18.30737556287083, 18.467268341582088, 18.625788573910103, 18.78297101099823, 18.93884896185616, 19.093454375780198, 19.246817918814532, 19.398969044771427, 19.54993606127652, 19.69974619125841, 19.84842563026096, 19.995999599919983, 20.142492397913426, 20.28792744466522, 20.432327327056996, 20.5757138393787, 20.71810802172824, 20.859530196051875, 21.000000000000004, 21.139536418758105, 21.278157814998934, 21.4158819570897, 21.55272604567692, 21.68870673876154, 21.82384017536786, 21.95814199790138, 22.091627373283302, 22.224311012942565, 22.35620719173984, 22.48732976589262, 22.617692189964924, 22.74730753298069, 22.876188493715468, 23.00434741521698, 23.131796298601632, 23.258546816170615, 23.384610323886097, 23.509997873245336, 23.634720222587788, 23.758787847868, 23.88221095292478, 24.00499947927515, 24.127163115459727, 24.24871130596429, 24.3696532597409], [0.0, 2.45, 3.4648232278140827, 4.243524478543749, 4.9, 5.4783665448744845, 6.001249869818786, 6.482090712108247, 6.929646455628165, 7.35, 7.74758026741253, 8.12573073637073, 8.487048957087499, 8.833600624886774, 9.167060597596157, 9.48880919820817, 9.8, 10.101608782763268, 10.39446968344225, 10.679302411674652, 10.956733089748969, 11.227310452641808, 11.491518611567402, 11.749787232116164, 12.002499739637573, 12.250000000000002, 12.492597808302325, 12.730573435631248, 12.964181424216495, 13.193653777479536, 13.41920265887657, 13.641022688933553, 13.85929291125633, 14.074178484018171, 14.285832142370987, 14.494395468594059, 14.7, 14.90276819923064, 15.102814307273993, 15.300245096076077, 15.49516053482506, 15.687654381710482, 15.877814711099258, 16.0657243845399, 16.25146147274146, 16.43509963462345, 16.61670845865691, 16.79635377098256, 16.974097914174997, 17.150000000000002, 17.324116139070416, 17.496499649929984, 17.667201249773548, 17.836269228737272, 18.00374960945636, 18.169686293384373, 18.334121195192314, 18.497094366413336, 18.658644109366573, 18.81880708227809, 18.97761839641634, 19.135111705971305, 19.291319291328936, 19.446272136324744, 19.6, 19.752531483331445, 19.903894091358104, 20.054114291087505, 20.203217565526536, 20.351228464149287, 20.49817065008485, 20.644066944282077, 20.7889393668845, 20.93280917602795, 21.075696904254432, 21.217622392718745, 21.358604823349303, 21.4986627491107, 21.637814122503226, 21.776076322423197, 21.913466179497938, 22.05, 22.185693588436674, 22.32056226890353, 22.454620905283615, 22.587883920367577, 22.720365313964475, 22.8520786800676, 22.983037223134804, 23.113253773538677, 23.242740802237588, 23.37151043471517, 23.499574464232328, 23.62694436443274, 23.753631301340015, 23.87964614478196, 24.004999479275146, 24.12970161440046, 24.25376259469858, 24.37719220911219, 24.500000000000004, 24.622195271746186], [0.0, 2.4748737341529163, 3.5, 4.286607049870562, 4.949747468305833, 5.5339859052946645, 6.062177826491071, 6.547900426854397, 7.0, 7.424621202458749, 7.826237921249264, 8.208227579691002, 8.573214099741124, 8.923284148787374, 9.260129588726066, 9.585144756340407, 9.899494936611665, 10.204165815979277, 10.500000000000002, 10.787724505195712, 11.067971810589329, 11.341296222213757, 11.6081867662439, 11.869077470469222, 12.124355652982143, 12.374368670764584, 12.619429464123964, 12.859821149611685, 13.095800853708795, 13.327602935261842, 13.55544171172596, 13.77951377952067, 14.0, 14.217067208112933, 14.430869689661813, 14.641550464346324, 14.849242404917497, 15.0540692173246, 15.25614630239236, 15.455581516073735, 15.652475842498529, 15.846923991740482, 16.03901493234544, 16.22883236711748, 16.416455159382004, 16.60195771588399, 16.78541033159452, 16.966879500957152, 17.146428199482248, 17.324116139070416, 17.5, 17.67413364213364, 17.84656829757475, 18.017352746727255, 18.186533479473212, 18.354154842977653, 18.520259177452132, 18.684886941054796, 18.848076824970764, 19.009865859600378, 19.170289512680814, 19.329381780077707, 19.487175269905077, 19.643701280563196, 19.79898987322333, 19.953069939234915, 20.105969262883104, 20.257714579882897, 20.408331631958553, 20.557845217823782, 20.70627924084866, 20.853656753672723, 21.000000000000004, 21.1453304537905, 21.289668856043768, 21.43303524935281, 21.575449010391424, 21.716928880484, 21.857492994394395, 21.99715890745894, 22.135943621178658, 22.27386360737625, 22.410934831014977, 22.54717277176897, 22.682592444427513, 22.817208418209272, 22.951034835057005, 23.084085426977612, 23.2163735324878, 23.34791211222108, 23.47871376374779, 23.608790735656076, 23.738154940938443, 23.86681796972525, 23.99479110140366, 24.12208531615789, 24.248711305964285, 24.374679485072214, 24.5, 24.62468273907301, 24.748737341529168, 24.872173206215823], [0.0, 2.499499949989998, 3.5348267284267276, 4.329260906898544, 4.998999899979996, 5.589051797934959, 6.122499489587566, 6.613055269691915, 7.069653456853455, 7.498499849969993, 7.904112853445351, 8.28990349762891, 8.658521813797089, 9.012075232708614, 9.352272451121172, 9.680521680157531, 9.997999799959992, 10.30570230503482, 10.604480185280185, 10.89506769139137, 11.178103595869919, 11.454147720367502, 11.723693957110958, 11.987180652680598, 12.244998979175133, 12.49749974994999, 12.74499901922319, 12.987782720695632, 13.22611053938383, 13.46021916612059, 13.690325050925564, 13.916626746449731, 14.13930691370691, 14.358534047736214, 14.574463969559913, 14.787241121994327, 14.996999699939986, 15.203864640281433, 15.407952492138598, 15.609372184684435, 15.808225706890703, 16.00460871124315, 16.19861105156859, 16.390317263555335, 16.57980699525782, 16.767155393804877, 16.952433453637273, 17.13570833085111, 17.317043627594177, 17.496499649929984, 17.67413364213364, 17.850000000000005, 18.02415046541723, 18.196634304178346, 18.367498468762697, 18.536787747611505, 18.704544902242343, 18.870810793392, 19.035624497242008, 19.199023412663472, 19.361043360315062, 19.52171867433808, 19.68108228731337, 19.839165809075748, 19.995999599919983, 20.151612838678695, 20.306033586104405, 20.45928884394568, 20.61140461006964, 20.762405929949452, 20.91231694480552, 21.06116093666254, 21.20896037056037, 21.35573693413552, 21.50151157477074, 21.64630453449272, 21.79013538278274, 21.93302304745062, 22.074985843710074, 22.216041501581696, 22.356207191739838, 22.495499549909983, 22.633934699914647, 22.77152827545837, 22.908295440735003, 23.044250909934135, 23.179408965717833, 23.31378347673325, 23.447387914221917, 23.580235367782063, 23.712338560336054, 23.84370986235154, 23.974361305361196, 24.1043045948229, 24.23355112235927, 24.3621119774128, 24.489997958350266, 24.617219583047966, 24.74378709898709, 24.86971049288673, 24.99499949989998, 25.119663612397368], [0.0, 2.5238858928247927, 3.5693136595149495, 4.37149859887888, 5.047771785649585, 5.643580423808985, 6.182232606429493, 6.67757440991862, 7.138627319029899, 7.571657678474377, 7.981227975693966, 8.370782520170978, 8.74299719775776, 9.100000000000001, 9.443516294262428, 9.774968030638258, 10.09554357129917, 10.406248123122955, 10.70794097854485, 11.0013635518512, 11.28716084761797, 11.565898149300816, 11.838074167701434, 12.10413152605341, 12.364465212858986, 12.619429464123964, 12.869343417595166, 13.114495796636637, 13.35514881983724, 13.591541487263322, 13.82389236069205, 14.052401929919313, 14.277254638059798, 14.498620624045587, 14.716657229140049, 14.93151030539108, 15.143315356948754, 15.352198539622918, 15.55827753962501, 15.761662348876786, 15.962455951387932, 16.160754932861277, 16.356650023767095, 16.550226584551645, 16.741565040341957, 16.930741271426953, 17.11782696489248, 17.302889932031587, 17.48599439551552, 17.667201249773548, 17.84656829757475, 18.02415046541723, 18.200000000000003, 18.374166647769364, 18.54669781928848, 18.717638739969313, 18.887032588524857, 19.054920624342678, 19.221342304844374, 19.386335393776722, 19.549936061276515, 19.712178976460216, 19.873097393209743, 20.03272322975586, 20.19108714259834, 20.348218595248085, 20.504145922227536, 20.658896388723193, 20.81249624624591, 20.964970784620714, 21.116344380597702, 21.266640543348636, 21.4158819570897, 21.564090521049106, 21.71128738697915, 21.857492994394395, 22.0027271037024, 22.147008827378926, 22.290356659326925, 22.432788502546895, 22.57432169523594, 22.714973035423135, 22.854758804240316, 22.99369478791958, 23.131796298601632, 23.26907819403253, 23.405554896220686, 23.541240409120334, 23.676148335402868, 23.810291892372927, 23.9436839270819, 24.076336930687777, 24.20826305210682, 24.3394741109992, 24.469981610127952, 24.59979674712781, 24.728930425717973, 24.85739326639059, 24.985195616604646, 25.11234756051294, 25.23885892824793, 25.36473930479082], [0.0, 2.5480384612481815, 3.6034705493454506, 4.413332074521473, 5.096076922496363, 5.697587208634898, 6.241394075044454, 6.741476099490379, 7.206941098690901, 7.644115383744545, 8.057605103254938, 8.450887527354746, 8.826664149042946, 9.187083323884682, 9.533886930313365, 9.868510525910178, 10.192153844992726, 10.505831713862547, 10.810411648036352, 11.106642156835704, 11.395174417269796, 11.676579122328596, 11.951359755274712, 12.219963175067267, 12.482788150088908, 12.74019230624091, 12.992497835289413, 13.239996223564418, 13.482952198980758, 13.721607048738864, 13.956181426163822, 14.186877739657872, 14.413882197381803, 14.637366566428542, 14.85748969375379, 15.074398827150622, 15.28823076748909, 15.499112877839172, 15.707163970621815, 15.912495090337032, 16.115210206509875, 16.315406829129333, 16.513176556919632, 16.708605567192016, 16.901775054709493, 17.092761625904693, 17.281637653879915, 17.468471598854894, 17.653328298085892, 17.836269228737272, 18.017352746727255, 18.196634304178346, 18.374166647769364, 18.550000000000004, 18.72418222513336, 18.896758981370326, 19.06777386062673, 19.237268517125816, 19.405282785880758, 19.571854792022144, 19.737021051820356, 19.9008165661613, 20.06327490715312, 20.22442829847114, 20.38430768998545, 20.542942827160864, 20.700362315669746, 20.85659368161542, 21.011663427725093, 21.1655970858372, 21.31841926597749, 21.470153702291004, 21.620823296072704, 21.77045015611758, 21.919055636591647, 22.066660372607362, 22.21328431367141, 22.358946755158218, 22.503666367949915, 22.647461226371494, 22.790348834539593, 22.932346151233638, 23.07346961338932, 23.2137351583066, 23.35315824465719, 23.491753872369774, 23.629536601465553, 23.76652056991095, 23.902719510549424, 24.038146767169884, 24.172815309764815, 24.306737749027533, 24.439926350134535, 24.57239304585535, 24.704149449029817, 24.83520686444951, 24.965576300177815, 25.0952684783407, 25.224293845418153, 25.35266258206424, 25.48038461248182, 25.60746961337649], [0.0, 2.571964229922337, 3.6373066958946425, 4.45477272147525, 5.143928459844674, 5.751086853804244, 6.300000000000001, 6.804777733328254, 7.274613391789285, 7.715892689767011, 8.133265027035575, 8.530240324867759, 8.9095454429505, 9.27334890964424, 9.623408959407264, 9.961174629530394, 10.287856919689348, 10.604480185280183, 10.911920087683928, 11.21093216463288, 11.502173707608488, 11.786220768337916, 12.06358155772986, 12.33470713069427, 12.600000000000001, 12.859821149611687, 13.114495796636637, 13.364318164425748, 13.609555466656508, 13.850451256186567, 14.087228258248675, 14.32009078183515, 14.54922678357857, 14.774809643443806, 14.996999699939986, 15.215945583498911, 15.431785379534022, 15.644647647038909, 15.854652314068575, 16.061911467817275, 16.26653005407115, 16.46860649842603, 16.668233259706923, 16.86549732441946, 17.060480649735517, 17.25326056141273, 17.44391011212796, 17.632498404933997, 17.819090885901, 18.00374960945636, 18.186533479473212, 18.367498468762697, 18.54669781928848, 18.72418222513336, 18.9, 19.0741972308142, 19.24681791881453, 19.417904109352275, 19.58749601148651, 19.75563210833812, 19.922349259060788, 20.087682793194443, 20.251666598085205, 20.41433319998476, 20.575713839378697, 20.73583854103807, 20.894736179239022, 21.052434538551594, 21.208960370560366, 21.364339446844596, 21.51859660851516, 21.671755812577807, 21.823840175367856, 21.974872013279168, 22.12487288099075, 22.27386360737625, 22.42186432926576, 22.56889452321491, 22.714973035423135, 22.860118109931108, 23.004347415216976, 23.147678069301037, 23.29012666345978, 23.431709284642466, 23.572441536675832, 23.712338560336054, 23.85141505236115, 23.989685283471314, 24.12716311545972, 24.263862017411817, 24.399795081106728, 24.53497503565064, 24.66941426138854, 24.80312480313721, 24.93611838277963, 25.068406411257975, 25.200000000000003, 25.330909971811124, 25.461146871262496, 25.59072097460328, 25.719642299223374, 25.847920612691464], [0.0, 2.595669470483482, 3.6708309685955305, 4.4958314025327955, 5.191338940966964, 5.80409338312195, 6.358065743604733, 6.867495904622005, 7.341661937191061, 7.787008411450446, 8.208227579691002, 8.608861713374191, 8.991662805065591, 9.358819369984657, 9.712105847858126, 10.052984631441548, 10.382677881933928, 10.70221939599446, 11.012492905786592, 11.314260912671232, 11.6081867662439, 11.8948518275765, 12.17476899164826, 12.44839347064512, 12.716131487209466, 12.978347352417412, 13.235369280832328, 13.487494207598386, 13.73499180924401, 13.978107883401103, 14.217067208112931, 14.452075975443805, 14.683323874382122, 14.910985882898558, 15.13522381730776, 15.356187677936214, 15.574016822900893, 15.788840996095947, 16.000781230927444, 16.20995064767318, 16.416455159382004, 16.620394098817275, 16.821860776977083, 17.02094298210296, 17.217723426748382, 17.41228014936585, 17.60468687594301, 17.795013346440626, 17.983325610131182, 18.169686293384377, 18.354154842977653, 18.53678774761151, 18.717638739969313, 18.896758981370326, 19.0741972308142, 19.25, 19.424211695716252, 19.596874750837184, 19.768029745020115, 19.937715516076562, 20.105969262883097, 20.272826640604414, 20.438321848919003, 20.602487713866015, 20.765355763867856, 20.926956300427445, 21.087318463948897, 21.246470295086667, 21.40443879198892, 21.56124996376602, 21.716928880484, 21.871499719955192, 22.024985811573185, 22.17740967741724, 22.32879307083121, 22.479157012663975, 22.628521825342464, 22.776907164933522, 22.92433205133794, 23.070814896747798, 23.2163735324878, 23.36102523435134, 23.504786746533146, 23.647674304252416, 23.789703655153, 23.930890079560353, 24.07124840966916, 24.21079304772977, 24.34953798329652, 24.487496809596525, 24.624682739073005, 24.761108618153592, 24.89678694129024, 25.031729864314215, 25.165949217146572, 25.29945651590168, 25.432262974418933, 25.56437951525521, 25.695816780168713, 25.826585140122575, 25.956694704834824, 26.08615533189972], [0.0, 2.619160170741759, 3.704051835490427, 4.536518488885503, 5.238320341483518, 5.856620185738529, 6.4156059729381765, 6.929646455628165, 7.408103670980854, 7.857480512225276, 8.282511696339462, 8.6867715521936, 9.073036977771006, 9.443516294262428, 9.799999999999999, 10.143963722332606, 10.476640682967036, 10.799074034379059, 11.11215550647128, 11.416654501210065, 11.713240371477058, 12.002499739637573, 12.28495014234897, 12.561050911448454, 12.831211945876353, 13.095800853708797, 13.35514881983724, 13.609555466656506, 13.85929291125633, 14.104609175726921, 14.345731072343437, 14.58286665919976, 14.816207341961707, 15.045929682143274, 15.272196960490001, 15.49516053482506, 15.714961024450552, 15.931729347437459, 16.145587632539115, 16.356650023767095, 16.565023392678924, 16.770807970995318, 16.974097914174997, 17.174981804939414, 17.3735431043872, 17.569860557215584, 17.76400855662933, 17.956057473732923, 18.14607395554201, 18.334121195192314, 18.520259177452136, 18.704544902242343, 18.887032588524857, 19.067773860626733, 19.24681791881453, 19.424211695716252, 19.599999999999998, 19.774225648555745, 19.94692958828501, 20.11815100847988, 20.28792744466521, 20.45629487468344, 20.623287807718725, 20.7889393668845, 20.95328136593407, 21.116344380597695, 21.27815781499893, 21.438749963558976, 21.598148068758118, 21.756378375088076, 21.91346617949794, 22.069435878608225, 22.22431101294256, 22.37811430840409, 22.53086771520351, 22.68259244442751, 22.83330900242013, 22.983037223134804, 23.13179629860163, 23.279604807642247, 23.426480742954116, 23.572441536675832, 23.717504084536387, 23.861684768683034, 24.004999479275146, 24.147463634924478, 24.289092202056462, 24.429899713261207, 24.56990028469794, 24.709107632611904, 24.847535089018386, 24.985195616604646, 25.12210182289691, 25.258265973736204, 25.393700006103877, 25.528415540334656, 25.662423891752706, 25.795736081763593, 25.928362848432986, 26.0603146565808, 26.191601707417593, 26.322233947748437], [0.0, 2.6424420523447623, 3.736977388210959, 4.576843890717708, 5.2848841046895245, 5.908680055646946, 6.472634703117426, 6.9912445244033625, 7.473954776421918, 7.927326157034287, 8.356135470419325, 8.76398881788424, 9.153687781435416, 9.52746031217134, 9.887112824277873, 10.23413406204941, 10.569768209379049, 10.895067691391366, 11.210932164632878, 11.518137870333037, 11.817360111293892, 12.109190724404336, 12.39415184673804, 12.672706893162172, 12.945269406234852, 13.212210261723813, 13.473863588444111, 13.730531672153122, 13.982489048806725, 14.229985945179287, 14.473251189694732, 14.712494689888592, 14.947909552843836, 15.17967390954101, 15.407952492138598, 15.632898003889107, 15.854652314068574, 16.07334750448705, 16.289106789508136, 16.5020453277768, 16.71227094083865, 16.91988475138055, 17.124981751815096, 17.327651312281187, 17.52797763576848, 17.726040166940837, 17.921913960288954, 18.115670012450547, 18.30737556287083, 18.497094366413336, 18.684886941054796, 18.870810793392003, 19.05492062434268, 19.237268517125816, 19.417904109352275, 19.596874750837184, 19.774225648555745, 19.95, 20.124239116051072, 20.29698253435717, 20.46826812409882, 20.638132182927794, 20.806609526782587, 20.97373357321009, 21.139536418758098, 21.30404891094648, 21.467300715273918, 21.629320377672528, 21.790135382782733, 21.94977220838522, 22.108256376295262, 22.26561249999649, 22.421864329265755, 22.577034792018193, 22.73114603358132, 22.884219453588535, 23.036275740666074, 23.187334905072642, 23.337416309437515, 23.486538697730666, 23.634720222587784, 23.781978471102864, 23.9283304891921, 24.0737928046247, 24.21838144880867, 24.3621119774128, 24.504999489900015, 24.647058648041558, 24.78830369347608, 24.928748464373413, 25.068406411257975, 25.207290612043177, 25.345413786324343, 25.482788308974357, 25.619426223083142, 25.75533925227932, 25.890538812469703, 26.025036023029827, 26.15884171747671, 26.291966453652723, 26.424420523447626, 26.556213962084282], [0.0, 2.665520587052368, 3.769615364994153, 4.616817085395523, 5.331041174104736, 5.960285228074241, 6.529165337162171, 7.0523045878634605, 7.539230729988306, 7.996561761157103, 8.429116205154607, 8.840531658220563, 9.233634170791046, 9.610671152422187, 9.973464794142505, 10.323516842626837, 10.662082348209472, 10.990222927675308, 11.30884609498246, 11.618734870888485, 11.920570456148482, 12.214949856630605, 12.502399769644226, 12.783387657424774, 13.058330674324342, 13.327602935261842, 13.59154148726332, 13.850451256186565, 14.104609175726921, 14.354267658086917, 14.599657530229948, 14.840990532979934, 15.078461459976612, 15.312249997959153, 15.542522317822165, 15.769432456496334, 15.993123522314207, 16.21372875066066, 16.431372432027704, 16.646170730831763, 16.858232410309213, 17.067659476331254, 17.274547750954294, 17.47898738485728, 17.681063316441126, 17.88085568422272, 18.078440198202944, 18.273888475089258, 18.46726834158209, 18.658644109366577, 18.848076824970764, 19.03562449724201, 19.221342304844374, 19.40528278588076, 19.58749601148651, 19.768029745020115, 19.94692958828501, 20.124239116051072, 20.3, 20.474252123093535, 20.647033685253675, 20.81838130114827, 20.988330090790928, 21.15691376359038, 21.324164696418944, 21.490114006212252, 21.65479161756123, 21.818226325712182, 21.980445855350617, 22.141476915508598, 22.30134525090359, 22.460075689988223, 22.61769218996492, 22.774217878996414, 22.92967509582288, 23.08408542697761, 23.23746974177697, 23.389848225245075, 23.541240409120334, 23.69166520107863, 23.841140912296964, 23.989685283471314, 24.13731550939334, 24.284048262182317, 24.42989971326121, 24.574885554158744, 24.719021016213407, 24.86232088924926, 25.004799539288452, 25.14647092536048, 25.287348615463824, 25.427445801731643, 25.566775314849547, 25.70534963776996, 25.84318091876463, 25.980280983853888, 26.116661348648684, 26.25233322963885, 26.38730755495907, 26.52159497466169, 26.655205870523684, 26.78815036541344], [0.0, 2.6884010117540127, 3.8019731719200753, 4.656447143477525, 5.376802023508025, 6.011447413061184, 6.5852107027793725, 7.112840501515551, 7.603946343840151, 8.065203035262037, 8.501470461043784, 8.916417441999897, 9.31289428695505, 9.69316769688836, 10.059075504239939, 10.41213234645046, 10.75360404701605, 11.084561335479181, 11.405919515760226, 11.718468329948246, 12.022894826122368, 12.31980113475863, 12.609718474256274, 12.893118319475704, 13.170421405558745, 13.442005058770064, 13.708209219296299, 13.969341430432573, 14.225681003031102, 14.477482515962505, 14.72497877757384, 14.968383346240167, 15.207892687680301, 15.443688031037146, 15.675936973591083, 15.904794874502468, 16.130406070524074, 16.352904940713135, 16.5724168424524, 16.78905893729604, 17.002940922087568, 17.214165678301114, 17.4228298505151, 17.629024363248238, 17.832834883999794, 18.034342239183548, 18.233622788683547, 18.43074876395422, 18.6257885739101, 18.818807082278088, 19.009865859600378, 19.19902341266347, 19.38633539377672, 19.57185479202214, 19.755632108338116, 19.93771551607656, 20.118151008479877, 20.296982534357166, 20.47425212309353, 20.65, 20.82426469290092, 20.9970831307589, 21.168490735052412, 21.338521504546655, 21.5072080940321, 21.674581887547447, 21.840673066551773, 22.00551067346541, 22.169122670958362, 22.33153599732898, 22.49277661828348, 22.652869575398167, 22.811839031520453, 22.969708313341723, 23.126499951354504, 23.28223571738762, 23.436936659896492, 23.590623137170414, 23.74331484860528, 23.8950308641776, 24.045789652244736, 24.195609105786115, 24.344506567190887, 24.492498851689263, 24.63960226951726, 24.7858326468973, 24.931205345911376, 25.075735283337156, 25.21943694851255, 25.362324420289237, 25.504411383131348, 25.645711142411315, 25.786236638951408, 25.926000462855818, 26.065014866675217, 26.203291777942706, 26.34084281111749, 26.477679278970054, 26.613812203440524, 26.749252325999695, 26.88401011754013, 27.01809578782339], [0.0, 2.7110883423451915, 3.8340579025361623, 4.695742752749559, 5.422176684690383, 6.06217782649107, 6.640783086353596, 7.172865536171718, 7.668115805072325, 8.133265027035574, 8.573214099741122, 8.99166280506559, 9.391485505499118, 9.774968030638258, 10.143963722332606, 10.499999999999998, 10.844353369380766, 11.178103595869917, 11.502173707608488, 11.817360111293894, 12.12435565298214, 12.423767544509193, 12.716131487209463, 13.001922934704698, 13.281566172707192, 13.55544171172596, 13.82389236069205, 14.087228258248674, 14.345731072343437, 14.599657530229948, 14.849242404917497, 15.094701056993475, 15.33623161014465, 15.574016822900893, 15.8082257068907, 16.039014932345438, 16.266530054071147, 16.490906585145645, 16.71227094083865, 16.930741271426957, 17.146428199482244, 17.359435474692145, 17.569860557215588, 17.777795138880407, 17.98332561013118, 18.18653347947321, 18.387495751189174, 18.586285266292453, 18.782971010998235, 18.977618396416343, 19.170289512680814, 19.361043360315065, 19.549936061276515, 19.73702105182036, 19.922349259060788, 20.1059692628831, 20.28792744466521, 20.46826812409882, 20.647033685253675, 20.824264692900922, 20.999999999999996, 21.17427684715584, 21.347130954767664, 21.518596608515157, 21.68870673876153, 21.857492994394388, 22.02498581157318, 22.1912144778063, 22.356207191739834, 22.519991119003578, 22.68259244442751, 22.844036420913003, 23.004347415216976, 23.16354895088401, 23.32166374854075, 23.47871376374779, 23.634720222587788, 23.789703655152998, 23.943683927081896, 24.096680269281908, 24.24871130596428, 24.399795081106724, 24.549949083450258, 24.699190270128287, 24.847535089018386, 24.994999499899976, 25.14159899449516, 25.28734861546382, 25.432262974418926, 25.57635626902315, 25.719642299223366, 25.862134482675632, 26.003845869409396, 26.144789155776337, 26.284976697726023, 26.42442052344762, 26.563132345414385, 26.701123571864912, 26.838405317753136, 26.974988415196773, 27.11088342345192, 27.24610063843999], [0.0, 2.733587386567329, 3.865876356015541, 4.73471224046404, 5.467174773134658, 6.112487218800543, 6.695894264398147, 7.232392411920139, 7.731752712031082, 8.200762159701986, 8.644362324659928, 9.066283692892034, 9.46942448092808, 9.856089488230106, 10.22814743734172, 10.58713842357792, 10.934349546269315, 11.270869531673233, 11.597629068046624, 11.915431171384444, 12.224974437601086, 12.526871117721296, 12.82166135880994, 13.109824560229631, 13.391788528796294, 13.667936932836646, 13.938615426217915, 14.204136721392116, 14.464784823840278, 14.720818591369165, 14.972474745345206, 15.219970433611229, 15.463505424062165, 15.70326399192219, 15.93941655142998, 16.17212107300709, 16.401524319403972, 16.627762928307586, 16.850964364095013, 17.07124775756008, 17.288724649319857, 17.503499650069983, 17.71567102878127, 17.925331238222626, 18.132567385784068, 18.33746165640163, 18.54009169340864, 18.740530942318575, 18.93884896185616, 19.135111705971305, 19.329381780077707, 19.52171867433808, 19.712178976460212, 19.9008165661613, 20.08768279319444, 20.272826640604414, 20.45629487468344, 20.638132182927794, 20.81838130114827, 20.997083130758902, 21.17427684715584, 21.35, 21.524288606130515, 21.697177235760417, 21.86869909253863, 22.03888608800363, 22.20776891090143, 22.375377091794455, 22.541739063346466, 22.70688221663203, 22.87083295378636, 23.033616737282053, 23.195258136093248, 23.35578086898402, 23.51520784513715, 23.673561202320194, 23.83086234276889, 23.987131966952614, 24.14239010537275, 24.296656148532048, 24.44994887520217, 24.602286479105963, 24.753686594121696, 24.9041663181083, 25.05374223544259, 25.202430438352568, 25.35024654712455, 25.497205729255903, 25.64332271761988, 25.788611827704102, 25.933086973979783, 26.076761685454734, 26.219649120459263, 26.36176208071077, 26.503113024699573, 26.643714080435554, 26.783577057592588, 26.922713459085067, 27.06113449210879, 27.1988510786761, 27.335873865673292, 27.472213234466572], [0.0, 2.755902755904134, 3.897435053981015, 4.773363593945049, 5.511805511808268, 6.162385901580653, 6.750555532695069, 7.29143332959988, 7.79487010796203, 8.2677082677124, 8.714929718592112, 9.140295400040417, 9.546727187890099, 9.936548696604873, 10.311643903859364, 10.673565477383832, 11.023611023616535, 11.362878156523548, 11.692305161943047, 12.012701611211362, 12.324771803161306, 12.6291329868681, 12.926329718833571, 13.216845311949445, 13.501111065390138, 13.77951377952067, 14.052401929919313, 14.320090781835148, 14.58286665919976, 14.840990532979934, 15.094701056993475, 15.344217151748081, 15.58974021592406, 15.8314560290581, 16.069536396548596, 16.30414057839296, 16.5354165354248, 16.763502020759265, 16.988525539316235, 17.21060719440195, 17.429859437184223, 17.646387732337743, 17.860291151042304, 18.07166290079582, 18.280590800080834, 18.487157704741957, 18.691441891946166, 18.89351740677209, 19.093454375780198, 19.291319291328936, 19.487175269905077, 19.68108228731337, 19.873097393209747, 20.06327490715312, 20.251666598085205, 20.438321848919006, 20.62328780771873, 20.806609526782587, 20.988330090790928, 21.168490735052416, 21.347130954767664, 21.524288606130515, 21.699999999999996, 21.874299988799642, 22.04722204723307, 22.218798347345427, 22.389059828407266, 22.558036262050827, 22.725756313047096, 22.892247596074967, 23.057536728800848, 23.221649381557718, 23.384610323886093, 23.546443468175823, 23.707171910626535, 23.866817969725247, 24.025403222422725, 24.18294853817458, 24.339474110999195, 24.49499948969177, 24.649543606322613, 24.803124803137205, 24.955760857966247, 25.10746900824533, 25.2582659737362, 25.40816797803415, 25.55719076894016, 25.705349637769956, 25.852659437667143, 25.99913460098239, 26.144789155776337, 26.28963674149949, 26.43369062389889, 26.576963709197482, 26.71946855758924, 26.86121739608985, 27.002222130780275, 27.142494358477816, 27.282045377867103, 27.420886200121252, 27.55902755904134, 27.696479920740835], [0.0, 2.77803887661782, 3.9287402561126386, 4.811704479703633, 5.55607775323564, 6.2118837722545965, 6.804777733328254, 7.3500000000000005, 7.857480512225277, 8.33411662985346, 8.784930278607794, 9.213712606761728, 9.623408959407266, 10.01636161487793, 10.394469683442248, 10.759298304257577, 11.11215550647128, 11.454147720367502, 11.786220768337916, 12.109190724404339, 12.423767544509193, 12.730573435631248, 13.030157328290398, 13.323006417471998, 13.609555466656508, 13.890194383089103, 14.165274441393645, 14.435113439110896, 14.700000000000001, 14.96019719121376, 15.215945583498911, 15.467465855789047, 15.714961024450554, 15.958618361249199, 16.19861105156859, 16.435099634623455, 16.66823325970692, 16.89815078640264, 17.124981751815096, 17.348847223951225, 17.569860557215588, 17.78812806340229, 18.00374960945636, 18.216819151542346, 18.427425213523456, 18.63565131676379, 18.84157636717268, 19.045275004577906, 19.246817918814532, 19.44627213632474, 19.643701280563192, 19.839165809075745, 20.03272322975586, 20.224428298471135, 20.41433319998476, 20.60248771386601, 20.788939366884495, 20.973733573210087, 21.156913763590378, 21.338521504546655, 21.518596608515153, 21.697177235760417, 21.87429998879964, 22.05, 22.22431101294256, 22.39726545808662, 22.56889452321491, 22.739228219093103, 22.908295440735003, 23.07612402462771, 23.24274080223759, 23.40817165008835, 23.572441536675832, 23.73557456646036, 23.897594021156184, 24.05852239851816, 24.218381448808678, 24.37719220911219, 24.53497503565064, 24.691749634240182, 24.847535089018386, 25.00234988956038, 25.156211956492978, 25.309138665707295, 25.461146871262496, 25.612252927065985, 25.762472707409128, 25.91182162643144, 26.060314656580797, 26.207966346132235, 26.35479083582338, 26.500801874660322, 26.646012834943996, 26.79043672656346, 26.93408621059939, 27.076973612278014, 27.219110933313015, 27.36050986367031, 27.50118179278847, 27.641137820285188, 27.780388766178206, 27.9189451806475], [0.0, 2.8000000000000003, 3.9597979746446663, 4.849742261192857, 5.6000000000000005, 6.260990336999411, 6.8585712797928995, 7.408103670980854, 7.919595949289333, 8.4, 8.854377448471462, 9.28654941299512, 9.699484522385713, 10.09554357129917, 10.476640682967036, 10.844353369380766, 11.200000000000001, 11.544695751729451, 11.879393923934, 12.20491704191389, 12.521980673998822, 12.831211945876353, 13.133164127505603, 13.428328265275617, 13.717142559585799, 14.000000000000002, 14.2772546380598, 14.54922678357857, 14.816207341961707, 15.078461459976614, 15.336231610144651, 15.589740215924062, 15.839191898578665, 16.08477541030648, 16.32666530556684, 16.565023392678924, 16.8, 17.031735084835017, 17.260359208313133, 17.48599439551552, 17.708754896942924, 17.928747864811978, 18.14607395554201, 18.3608278680456, 18.57309882599024, 18.78297101099823, 18.990523952750753, 19.195832881122925, 19.398969044771427, 19.6, 19.79898987322333, 19.995999599919983, 20.19108714259834, 20.384307689985455, 20.575713839378697, 20.765355763867856, 20.95328136593407, 21.139536418758098, 21.324164696418944, 21.507208094032105, 21.68870673876153, 21.868699092538634, 22.04722204723307, 22.224311012942565, 22.400000000000002, 22.574321695235938, 22.74730753298069, 22.91898776124286, 23.089391503458902, 23.25854681617061, 23.42648074295412, 23.593219364893802, 23.758787847868, 23.923210486889086, 24.086510747719352, 24.24871130596428, 24.40983408382778, 24.569900284697944, 24.728930425717973, 24.886944368483654, 25.043961347997644, 25.200000000000003, 25.355078386784772, 25.509214021604038, 25.662423891752706, 25.814724480420086, 25.966131787387972, 26.116661348648684, 26.266328255011206, 26.415147169758487, 26.563132345414388, 26.71029763967448, 26.856656530551234, 27.00222213078028, 27.147007201531448, 27.2910241654651, 27.434285119171598, 27.5768018450291, 27.71858582251266, 27.85964823898536, 28.000000000000004, 28.139651739138497], [0.0, 2.821790211904492, 3.9906139878469826, 4.88748401531913, 5.643580423808984, 6.30971473206198, 6.911946180346025, 7.4657551526955395, 7.981227975693965, 8.465370635713477, 8.923284148787372, 9.358819369984657, 9.77496803063826, 10.174109297624042, 10.558172190298848, 10.928746497197194, 11.287160847617969, 11.634539097016264, 11.97184196354095, 12.299898373563908, 12.61942946412396, 12.931067241337816, 13.235369280832325, 13.532830450426845, 13.82389236069205, 14.108951059522463, 14.388363353766126, 14.662452045957387, 14.931510305391079, 15.195805342264688, 15.45558151607373, 15.711062981224408, 15.96245595138793, 16.209950647673175, 16.45372298296042, 16.693936024796546, 16.930741271426953, 17.164279769334918, 17.39468309570485, 17.622074225243747, 17.846568297574745, 18.06827329879643, 18.287290668658382, 18.503715843040823, 18.717638739969313, 18.92914419618594, 19.138312360289245, 19.345219047609667, 19.54993606127652, 19.752531483331445, 19.953069939234915, 20.151612838678695, 20.348218595248085, 20.542942827160864, 20.73583854103807, 20.926956300427445, 21.116344380597695, 21.30404891094648, 21.49011400621225, 21.67458188754745, 21.857492994394388, 22.03888608800363, 22.218798347345427, 22.39726545808662, 22.574321695235938, 22.749999999999996, 22.92433205133794, 23.097348332654985, 23.269078194032527, 23.439549910354508, 23.608790735656072, 23.776826953990305, 23.9436839270819, 24.10938613901233, 24.27395723815958, 24.437420076595647, 24.599796747127815, 24.76110861815359, 24.92137636648506, 25.080620008285283, 25.23885892824792, 25.39611190714043, 25.552397147821576, 25.707732299835392, 25.862134482675632, 26.015620307807385, 26.168205899526242, 26.31990691472901, 26.47073856166465, 26.620715617728983, 26.76985244636212, 26.918163013103253, 27.06566090085369, 27.21235932439523, 27.358271144207926, 27.50340887962799, 27.6477847213841, 27.791410543547446, 27.934297914928877, 28.07645810995397, 28.217902119044926, 28.358640658536512], [0.0, 2.843413441622586, 4.02119385257662, 4.924936547814601, 5.686826883245172, 6.358065743604732, 6.96491205974634, 7.522964841071637, 8.04238770515324, 8.530240324867759, 8.991662805065591, 9.430535509715236, 9.849873095629203, 10.252072961113766, 10.639078907499464, 11.012492905786589, 11.373653766490344, 11.723693957110958, 12.063581557729862, 12.394151846738044, 12.716131487209465, 13.0301573282904, 13.336791218280355, 13.63653181714471, 13.92982411949268, 14.217067208112931, 14.498620624045587, 14.774809643443803, 15.045929682143274, 15.312249997959151, 15.57401682290089, 15.831456029058097, 16.08477541030648, 16.33416664540925, 16.579806995257815, 16.821860776977083, 17.060480649735517, 17.295808740848173, 17.52797763576848, 17.757111251552153, 17.983325610131182, 18.206729525095938, 18.427425213523456, 18.64550884261408, 18.861071019430472, 19.074197230814196, 19.284968239538276, 19.493460441902048, 19.699746191258406, 19.903894091358104, 20.1059692628831, 20.306033586104405, 20.504145922227533, 20.700362315669746, 20.89473617923902, 21.087318463948897, 21.278157814998927, 21.467300715273915, 21.654791617561227, 21.840673066551773, 22.024985811573178, 22.20776891090143, 22.389059828407262, 22.56889452321491, 22.747307532980688, 22.924332051337938, 23.1, 23.27434209596482, 23.447387914221917, 23.619165946324188, 23.789703655153, 23.95902752617476, 24.127163115459723, 24.294135094709585, 24.459967293518606, 24.624682739073005, 24.788303693476088, 24.950851688870262, 25.112347560512937, 25.27281147794998, 25.43226297441893, 25.590720974603276, 25.748203820849334, 25.904729297948666, 26.0603146565808, 26.214976635503607, 26.36873148257231, 26.52159497466169, 26.67358243656071, 26.824708758903608, 26.97498841519677, 27.124435477996588, 27.27306363428942, 27.420886200121252, 27.567916134521308, 27.714166052760813, 27.85964823898536, 28.004374658256523, 28.14835696803634, 28.29160652914571, 28.434134416225863, 28.57595142773028], [0.0, 2.8648734701553575, 4.051542915976579, 4.96210640756524, 5.729746940310715, 6.406051826203094, 7.017478179517197, 7.5797427396977, 8.103085831953157, 8.594620410466073, 9.05952537388135, 9.501710372348759, 9.92421281513048, 10.329448194361595, 10.719374981779488, 11.095607238903149, 11.45949388062143, 11.812175921480344, 12.154628747929738, 12.487693942437893, 12.812103652406188, 13.128499533457736, 13.437447674316726, 13.739450498473367, 14.034956359034394, 14.32436735077679, 14.608045728296446, 14.886319222695716, 15.1594854793954, 15.427815788373934, 15.691558240021925, 15.950940411148178, 16.206171663906314, 16.457445123712247, 16.704939389294413, 16.94882001792455, 17.189240820932145, 17.426344998306444, 17.66026613616001, 17.891129086784883, 18.1190507477627, 18.344140753930123, 18.56650209382478, 18.7862316604475, 19.003420744697518, 19.218155478609283, 19.430517234494815, 19.64058298523748, 19.84842563026096, 20.0541142910875, 20.257714579882894, 20.45928884394568, 20.65889638872319, 20.856593681615415, 21.05243453855159, 21.246470295086663, 21.438749963558976, 21.629320377672524, 21.81822632571218, 22.00551067346541, 22.191214477806298, 22.37537709179445, 22.558036262050823, 22.739228219093103, 22.91898776124286, 23.09734833265498, 23.27434209596482, 23.45, 23.62435184296069, 23.797426331433407, 23.969251135569507, 24.13985294072853, 24.309257495859477, 24.477489658868205, 24.64457343919752, 24.810532037826192, 24.975387884875786, 25.13916267499775, 25.301877400698945, 25.46355238375039, 25.624207304812376, 25.78386123139822, 25.942532644288995, 26.10023946250302, 26.256999066915473, 26.412828322616267, 26.567743600087685, 26.72176079527695, 26.87489534863345, 27.027162263175168, 27.178576121644046, 27.329151102805955, 27.478900996946734, 27.627839220612245, 27.775978830637097, 27.92333253750347, 28.06991271806879, 28.215731427698277, 28.36080041183605, 28.50513111704628, 28.64873470155358, 28.791622045310337], [0.0, 2.8861739379323623, 4.08166632639171, 4.998999899979996, 5.772347875864725, 6.4536811201050215, 7.069653456853455, 7.636098480245, 8.16333265278342, 8.658521813797087, 9.126883367283709, 9.57235603182414, 9.997999799959992, 10.406248123122955, 10.799074034379059, 11.178103595869917, 11.54469575172945, 11.9, 12.244998979175133, 12.580540528928003, 12.907362240210043, 13.22611053938383, 13.5373557240696, 13.841603953299634, 14.13930691370691, 14.430869689661813, 14.716657229140049, 14.996999699939984, 15.27219696049, 15.542522317822165, 15.8082257068907, 16.069536396548596, 16.32666530556684, 16.57980699525782, 16.829141392239833, 17.074835284710655, 17.317043627594174, 17.555910685578233, 17.79157103799437, 18.02415046541723, 18.253766734567417, 18.480530295421723, 18.704544902242343, 18.92590816843408, 19.14471206364828, 19.361043360315062, 19.57498403575339, 19.786611635143597, 19.995999599919983, 20.203217565526536, 20.408331631958553, 20.61140461006964, 20.81249624624591, 21.01166342772509, 21.208960370560362, 21.40443879198892, 21.598148068758118, 21.790135382782733, 21.980445855350613, 22.169122670958362, 22.356207191739834, 22.541739063346466, 22.725756313047096, 22.908295440735003, 23.0893915034589, 23.269078194032524, 23.447387914221917, 23.62435184296069, 23.8, 23.974361305361196, 24.147463634924478, 24.31933387245629, 24.489997958350266, 24.65948093533195, 24.827806991355477, 24.994999499899976, 25.161081057856006, 25.32607352117576, 25.489998038446377, 25.652875082532177, 25.814724480420086, 25.975565441391264, 26.13541658363226, 26.294295959390126, 26.45222107876766, 26.6092089322475, 26.765276012027226, 26.920438332241176, 27.0747114481392, 27.228110474287412, 27.380650101851124, 27.53234461501599, 27.683207906599268, 27.833253492899463, 27.982494527829363, 28.130943816374167, 28.27861382741382, 28.425516705945736, 28.57166428474197, 28.717068095472424, 28.861739379323627, 29.00568909714093], [0.0, 2.9073183520213264, 4.111569043564756, 5.035623099478356, 5.814636704042653, 6.500961467352349, 7.121446482281532, 7.692041341542569, 8.223138087129511, 8.721955056063978, 9.193747875594589, 9.642484119769138, 10.071246198956713, 10.482485392310357, 10.878189187544036, 11.259995559501787, 11.629273408085306, 11.987180652680596, 12.334707130694268, 12.672706893162173, 13.001922934704698, 13.323006417471998, 13.636531817144709, 13.943009000929464, 14.242892964563064, 14.536591760106633, 14.824473009183162, 15.106869298435067, 15.384082683085138, 15.656388472441531, 15.924038432508256, 16.18726351178605, 16.446276174259022, 16.701272406616212, 16.95243345363727, 17.19992732542786, 17.443910112127956, 17.684527135323695, 17.92191396028895, 18.156197289080115, 18.387495751189178, 18.615920605761083, 18.84157636717268, 19.064561363954848, 19.284968239538276, 19.502884402057045, 19.718392429404584, 19.93157043486539, 20.142492397913426, 20.351228464149283, 20.55784521782378, 20.762405929949452, 20.964970784620714, 21.1655970858372, 21.364339446844596, 21.561249963766016, 21.756378375088072, 21.949772208385216, 22.141476915508594, 22.33153599732898, 22.519991119003574, 22.70688221663203, 22.892247596074963, 23.07612402462771, 23.25854681617061, 23.439549910354504, 23.619165946324188, 23.797426331433407, 23.974361305361192, 24.150000000000002, 24.324370495451678, 24.497499872435963, 24.669414261388535, 24.8401388885006, 25.009698118929784, 25.17811549739178, 25.345413786324347, 25.511615001798692, 25.67674044733872, 25.840810745795114, 26.003845869409396, 26.16586516819194, 26.32688739672809, 26.486930739517554, 26.646012834943996, 26.804150797964112, 26.961361241599064, 27.117660297304415, 27.273063634289418, 27.42758647785109, 27.581243626783763, 27.734049469920546, 27.88601800185893, 28.03716283791925, 28.187497228381243, 28.33703407204078, 28.485785929126127, 28.63376503361024, 28.78098330495329, 28.927452359307416, 29.073183520213266, 29.218187828816493], [0.0, 2.9283100928692645, 4.141255848169731, 5.071981861166305, 5.856620185738529, 6.547900426854397, 7.172865536171719, 7.74758026741253, 8.282511696339462, 8.784930278607794, 9.260129588726068, 9.712105847858126, 10.14396372233261, 10.55817219029885, 10.956733089748969, 11.341296222213755, 11.713240371477058, 12.073731817462239, 12.423767544509195, 12.764207770167332, 13.095800853708795, 13.419202658876571, 13.73499180924401, 14.043681853417217, 14.345731072343439, 14.641550464346324, 14.93151030539108, 15.215945583498911, 15.49516053482506, 15.769432456496336, 16.03901493234544, 16.304140578392964, 16.565023392678924, 16.821860776977086, 17.074835284710655, 17.324116139070416, 17.569860557215588, 17.812214909999263, 18.05131574151868, 18.287290668658386, 18.520259177452136, 18.750333330370427, 18.977618396416347, 19.202213414083282, 19.424211695716252, 19.643701280563192, 19.860765342755553, 20.07548255957998, 20.28792744466522, 20.49817065008485, 20.70627924084866, 20.91231694480552, 21.1163443805977, 21.31841926597749, 21.518596608515157, 21.716928880484, 21.913466179497938, 22.10825637629526, 22.301345250903587, 22.492776618283482, 22.68259244442751, 22.87083295378636, 23.057536728800844, 23.24274080223759, 23.426480742954116, 23.608790735656072, 23.789703655153, 23.969251135569507, 24.147463634924478, 24.324370495451678, 24.500000000000004, 24.674379424820394, 24.84753508901839, 25.019492400926122, 25.190275901625213, 25.35990930583152, 25.528415540334663, 25.695816780168716, 25.862134482675636, 26.027389419609495, 26.19160170741759, 26.354790835823383, 26.51697569482614, 26.678174600223308, 26.838405317753143, 26.99768508594765, 27.156030637779157, 27.313458221177342, 27.46998361848802, 27.62562216493956, 27.780388766178202, 27.934297914928884, 28.087363706834434, 28.239599855522037, 28.39101970694255, 28.541636253025157, 28.691462144686877, 28.840509704233735, 28.988790937188117, 29.136317543574382, 29.283100928692647, 29.429152213409076], [0.0, 2.9491524206117257, 4.1707313507345445, 5.108081831764249, 5.898304841223451, 6.59450528849587, 7.223918604192603, 7.802723883362784, 8.341462701469089, 8.847457261835176, 9.326038816131959, 9.781232028737485, 10.216163663528498, 10.633320271674318, 11.034717939304112, 11.422018210456502, 11.796609682446903, 12.159666936228147, 12.512194052203634, 12.855057370544873, 13.18901057699174, 13.514714203415476, 13.832750991758653, 14.143638145823727, 14.447837208385206, 14.74576210305863, 15.037785741258586, 15.324245495292745, 15.605447766725568, 15.8816718263538, 16.153173062900056, 16.42018574803586, 16.682925402938178, 16.941590834393327, 17.196365895153548, 17.447421012860325, 17.694914523670352, 17.9389938402353, 18.179796478508774, 18.41745096369202, 18.652077632263918, 18.8837893443027, 19.112692118066466, 19.338885696957824, 19.56246405747497, 19.783515865487608, 20.00212488712137, 20.21837035965065, 20.432327327056996, 20.64406694428208, 20.853656753672723, 21.06116093666254, 21.266640543348636, 21.470153702291004, 21.671755812577807, 21.871499719955192, 22.069435878608225, 22.26561249999649, 22.460075689988223, 22.65286957539817, 22.844036420913003, 23.033616737282056, 23.221649381557718, 23.408171650088352, 23.593219364893805, 23.776826953990305, 23.959027526174765, 24.139852940728534, 24.319333872456294, 24.497499872435966, 24.674379424820398, 24.849999999999998, 25.02438810440727, 25.197569327218844, 25.369568384188167, 25.54040915882124, 25.710114741089747, 25.878707463859165, 26.04620893719468, 26.212640080693898, 26.37802115398348, 26.54237178550553, 26.70571099970941, 26.868057242755754, 27.029428406830952, 27.189841853162736, 27.349314433820826, 27.507862512379987, 27.665501983517306, 27.822248291610077, 27.978116448395877, 28.133121049752017, 28.287276291647455, 28.440595985316484, 28.593093571700145, 28.744782135198033, 28.89567441677041, 29.045782826427665, 29.19511945514181, 29.343696086212454, 29.49152420611726, 29.638615014875445], [0.0, 2.9698484809834995, 4.2, 5.143928459844674, 5.939696961966999, 6.640783086353597, 7.274613391789285, 7.857480512225277, 8.4, 8.909545442950499, 9.391485505499118, 9.849873095629203, 10.287856919689348, 10.70794097854485, 11.11215550647128, 11.502173707608486, 11.879393923933998, 12.244998979175131, 12.600000000000001, 12.945269406234853, 13.281566172707194, 13.609555466656508, 13.929824119492679, 14.242892964563065, 14.54922678357857, 14.8492424049175, 15.143315356948756, 15.431785379534022, 15.714961024450554, 15.99312352231421, 16.26653005407115, 16.535416535424805, 16.8, 17.06048064973552, 17.317043627594174, 17.569860557215588, 17.819090885900998, 18.06488306078952, 18.30737556287083, 18.546697819288482, 18.782971010998235, 19.016308790088576, 19.24681791881453, 19.474598840540978, 19.699746191258406, 19.922349259060788, 20.142492397913426, 20.36025540114858, 20.575713839378697, 20.7889393668845, 21.0, 21.208960370560366, 21.4158819570897, 21.620823296072704, 21.823840175367852, 22.024985811573185, 22.22431101294256, 22.421864329265752, 22.617692189964917, 22.811839031520453, 23.004347415216973, 23.195258136093248, 23.38461032388609, 23.572441536675832, 23.758787847867996, 23.943683927081896, 24.127163115459723, 24.309257495859477, 24.489997958350262, 24.669414261388535, 24.84753508901839, 25.02438810440727, 25.200000000000003, 25.3743965445486, 25.54760262725252, 25.71964229922337, 25.890538812469707, 26.0603146565808, 26.228991593273275, 26.396590688950727, 26.563132345414388, 26.728636328851497, 26.89312179721797, 27.056607326122762, 27.219110933313015, 27.380650101851128, 27.541241802068406, 27.700902512373133, 27.859648238985358, 28.0174945346653, 28.17445651649735, 28.330548882787287, 28.48578592912613, 28.6401815636703, 28.79374932168439, 28.946502379389464, 29.09845356715714, 29.249615382086656, 29.4, 29.54961928688761, 29.698484809835, 29.846607847458987], [0.0, 2.990401310861136, 4.2290660907581, 5.17952700543206, 5.980802621722272, 6.68674061108998, 7.324957337759723, 7.911858188820121, 8.4581321815162, 8.971203932583407, 9.456479260274406, 9.918039120713328, 10.35905401086412, 10.782045260524555, 11.189057154202047, 11.581774475442007, 11.961605243444543, 12.329740467665976, 12.687198272274301, 13.034857114675253, 13.37348122217996, 13.703740365316325, 14.026225436659715, 14.341460873983516, 14.649914675519446, 14.952006554305681, 15.248114637554377, 15.53858101629618, 15.823716377640242, 16.103803898458278, 16.379102539516627, 16.649849849172814, 16.9162643630324, 17.178547668531237, 17.43688618991361, 17.691452738540157, 17.942407865166814, 18.189901044260797, 18.43407171516917, 18.675050200735743, 18.912958520548813, 19.147911113225906, 19.38001547986998, 19.609372758964014, 19.836078241426655, 20.06022183326994, 20.28188847223059, 20.50115850385046, 20.71810802172824, 20.932809176027952, 21.145330453790503, 21.35573693413552, 21.56409052104911, 21.770450156117583, 21.974872013279168, 22.177409677417245, 22.378114308404093, 22.577034792018193, 22.774217878996414, 22.969708313341727, 23.163548950884014, 23.35578086898402, 23.546443468175823, 23.735574566460365, 23.923210486889086, 24.10938613901233, 24.29413509470959, 24.47748965886821, 24.659480935331953, 24.840138888500608, 25.019492400926126, 25.197569327218844, 25.374396544548603, 25.549999999999997, 25.72440475501814, 25.897635027160298, 26.069714229350506, 26.24066500681719, 26.410509271878876, 26.57926823672917, 26.74696244435992, 26.913611797750224, 27.079235587438582, 27.24385251758642, 27.40748073063265, 27.57013783063117, 27.731840905356428, 27.892606547255497, 28.05245087331943, 28.211389543941287, 28.369437780823223, 28.526610383990594, 28.682921747967033, 28.838385877160327, 28.993016400505834, 29.14682658541063, 29.29982935103889, 29.452037280976, 29.603462635306702, 29.754117362139986, 29.904013108611363, 30.053161231391286], [0.0, 3.0108138434649194, 4.257933771208753, 5.2148825490129695, 6.021627686929839, 6.73238442158497, 7.374957626996917, 7.9658646737187295, 8.515867542417507, 9.032441530394758, 9.52102935611481, 9.985739832380974, 10.429765098025939, 10.855643693489576, 11.265433857601757, 11.660831874270375, 12.043255373859678, 12.41390349567774, 12.773801313626262, 13.123833281476873, 13.46476884316994, 13.797282341098917, 14.121968701282409, 14.43935594131539, 14.749915253993834, 15.054069217324598, 15.352198539622917, 15.644647647038905, 15.931729347437459, 16.213728750660657, 16.490906585145645, 16.763502020759265, 17.031735084835013, 17.295808740848173, 17.555910685578233, 17.81221490999926, 18.064883060789516, 18.31406563273158, 18.55990301698799, 18.80252642598861, 19.04205871222962, 19.27861509548858, 19.512303810672897, 19.743226686638632, 19.971479664761947, 20.19715326475491, 20.42033300414075, 20.641099776901424, 20.859530196051878, 21.075696904254436, 21.289668856043768, 21.50151157477074, 21.71128738697915, 21.919055636591647, 22.12487288099075, 22.328793070831214, 22.530867715203513, 22.73114603358132, 22.92967509582288, 23.126499951354507, 23.32166374854075, 23.515207845137155, 23.707171910626535, 23.897594021156188, 24.086510747719355, 24.27395723815958, 24.45996729351861, 24.644573439197522, 24.82780699135548, 25.009698118929787, 25.190275901625217, 25.369568384188167, 25.547602627252523, 25.72440475501814, 25.899999999999995, 26.074412745064844, 26.247666562953746, 26.419784253471867, 26.59078787851161, 26.76069879506139, 26.92953768633988, 27.097324591184275, 27.26407893181063, 27.429819540055306, 27.594564682197834, 27.75833208245769, 27.921138945250785, 28.083001976284518, 28.243937402564818, 28.40396099138287, 28.56308806834443, 28.7213335345001, 28.87871188263078, 29.035237212738593, 29.190923246790263, 29.345783342756413, 29.499830507987667, 29.65307741196519, 29.805536398461275, 29.957219497142923, 30.108138434649195, 30.258304645171386], [0.0, 3.031088913245535, 4.286607049870562, 5.250000000000001, 6.06217782649107, 6.77772085586298, 7.4246212024587495, 8.01950746617272, 8.573214099741124, 9.093266739736606, 9.585144756340407, 10.05298463144155, 10.500000000000002, 10.928746497197197, 11.341296222213755, 11.739356881873894, 12.12435565298214, 12.497499749949988, 12.859821149611687, 13.212210261723815, 13.55544171172596, 13.890194383089101, 14.21706720811293, 14.536591760106633, 14.849242404917499, 15.155444566227679, 15.455581516073734, 15.75, 16.03901493234544, 16.32291334290543, 16.60195771588399, 16.87638883173767, 17.146428199482248, 17.412280149365852, 17.674133642133636, 17.932163840429297, 18.186533479473212, 18.437394067492296, 18.684886941054796, 18.929144196185945, 19.170289512680814, 19.408438886216484, 19.643701280563192, 19.876179210300954, 20.1059692628831, 20.33316256758894, 20.55784521782378, 20.780098652316354, 21.000000000000004, 21.21762239271875, 21.43303524935281, 21.64630453449272, 21.857492994394395, 22.066660372607362, 22.273863607376246, 22.479157012663975, 22.68259244442751, 22.884219453588535, 23.08408542697761, 23.282235717387625, 23.478713763747788, 23.673561202320194, 23.866817969725247, 24.05852239851816, 24.24871130596428, 24.437420076595643, 24.624682739073005, 24.810532037826196, 24.994999499899976, 25.17811549739178, 25.359909305831522, 25.54040915882124, 25.719642299223374, 25.897635027160295, 26.07441274506484, 26.25, 26.42442052344763, 26.597697268748664, 26.769852446362123, 26.940907557096146, 27.11088342345192, 27.279800219209818, 27.44767749737672, 27.614534216604124, 27.780388766178202, 27.945258989674798, 28.10916220736577, 28.27211523745615, 28.43413441622586, 28.595235617144333, 28.755434269021222, 28.914745373252035, 29.073183520213266, 29.23076290485762, 29.387497341556667, 29.54340027823473, 29.698484809834998, 29.85276369115597, 30.00624934909393, 30.158953894324654, 30.310889132455358, 30.462066574676122], [0.0, 3.051229260478472, 4.315089802078284, 5.284884104689526, 6.102458520956944, 6.822756041366276, 7.473954776421919, 8.072793816269558, 8.630179604156568, 9.153687781435416, 9.648834126463157, 10.119782606360674, 10.569768209379053, 11.001363551851199, 11.416654501210065, 11.817360111293892, 12.204917041913887, 12.580540528928003, 12.945269406234853, 13.300000000000004, 13.645512082732552, 13.982489048806727, 14.311533810182612, 14.633181472256814, 14.947909552843837, 15.256146302392361, 15.558277539625012, 15.854652314068575, 16.145587632539115, 16.431372432027707, 16.712270940838653, 16.98852553931624, 17.260359208313137, 17.527977635768483, 17.79157103799437, 18.05131574151868, 18.30737556287083, 18.559903016987995, 18.809040379562166, 19.054920624342685, 19.297668252926314, 19.537400031734013, 19.774225648555753, 20.008248299139034, 20.23956521272135, 20.468268124098824, 20.69444369873228, 20.91817391647751, 21.139536418758105, 21.358604823349303, 21.57544901039142, 21.790135382782736, 22.002727103702398, 22.21328431367141, 22.421864329265755, 22.62852182534246, 22.83330900242013, 23.03627574066607, 23.237469741776966, 23.436936659896492, 23.634720222587784, 23.830862342768885, 24.02540322242272, 24.218381448808675, 24.409834083827775, 24.59979674712781, 24.788303693476088, 24.975387884875786, 25.161081057856006, 25.345413786324347, 25.528415540334663, 25.710114741089743, 25.890538812469707, 26.069714229350502, 26.247666562953743, 26.424420523447626, 26.60000000000001, 26.774428098467393, 26.947727176888225, 27.11991887893473, 27.291024165465103, 27.461063344306247, 27.630056098386778, 27.798021512330696, 27.964978097613454, 28.130943816374174, 28.29593610397084, 28.459971890358577, 28.623067620365223, 28.785239272932923, 28.946502379389468, 29.10687204080851, 29.266362944513627, 29.42498937977719, 29.58276525276162, 29.739704100747204, 29.895819105687675, 30.05112310713196, 30.205628614547987, 30.35934781908202, 30.512292604784722, 30.66447455933332], [0.0, 3.071237535587243, 4.3433857760968, 5.319539453749733, 6.142475071174486, 6.867495904622005, 7.522964841071637, 8.12573073637073, 8.6867715521936, 9.213712606761728, 9.712105847858126, 10.186142547598674, 10.639078907499465, 11.073504413689463, 11.491518611567402, 11.894851827576499, 12.284950142348972, 12.66303676058788, 13.0301573282904, 13.387214049233696, 13.73499180924401, 14.074178484018171, 14.405380939079674, 14.72913778875057, 15.045929682143274, 15.356187677936216, 15.660300124837967, 15.958618361249197, 16.25146147274146, 16.539120290994926, 16.821860776977083, 17.099926900428553, 17.3735431043872, 17.642916425579987, 17.908238327652445, 18.169686293384373, 18.427425213523456, 18.681608603115528, 18.93237967081793, 19.179872262348365, 19.424211695716252, 19.665515503032207, 19.903894091358104, 20.13945133314212, 20.37228509519735, 20.60248771386601, 20.830146422913117, 21.055343739773047, 21.27815781499893, 21.4986627491107, 21.716928880484, 21.93302304745062, 22.147008827378926, 22.358946755158218, 22.56889452321491, 22.776907164933522, 22.983037223134804, 23.18733490507264, 23.38984822524507, 23.590623137170414, 23.789703655152998, 23.987131966952614, 24.18294853817458, 24.37719220911219, 24.569900284697944, 24.76110861815359, 24.950851688870266, 25.139162674997753, 25.32607352117576, 25.511615001798695, 25.695816780168716, 25.878707463859165, 26.0603146565808, 26.240665006817185, 26.419784253471864, 26.59769726874866, 26.774428098467393, 26.950000000000003, 27.12443547799659, 27.29775631805662, 27.46998361848802, 27.641137820285188, 27.81123873544651, 27.9803055737424, 28.148356968036342, 28.315410998253235, 28.4814852140825, 28.646596656496566, 28.810761878159347, 28.973996962794068, 29.13631754357438, 29.297738820598425, 29.45827557750114, 29.617942197256045, 29.77675267721449, 29.934720643426758, 30.09185936428655, 30.248181763537463, 30.4037004326776, 30.558427642796026, 30.71237535587243, 30.865555235569637], [0.0, 3.0911163032147466, 4.371498598878879, 5.353970489272426, 6.182232606429493, 6.911946180346026, 7.571657678474379, 8.178325011883548, 8.742997197757758, 9.27334890964424, 9.77496803063826, 10.252072961113768, 10.707940978544851, 11.145178329663462, 11.565898149300816, 11.971841963540948, 12.364465212858986, 12.74499901922319, 13.11449579663664, 13.473863588444114, 13.823892360692051, 14.165274441393645, 14.498620624045587, 14.824473009183164, 15.143315356948758, 15.455581516073735, 15.761662348876786, 16.061911467817275, 16.356650023767095, 16.646170730831766, 16.930741271426957, 17.21060719440195, 17.485994395515515, 17.757111251552157, 18.02415046541723, 18.287290668658386, 18.54669781928848, 18.802526425988614, 19.05492062434268, 19.304015126392752, 19.54993606127652, 19.792801721838174, 20.032723229755863, 20.269805129798364, 20.504145922227536, 20.735838541038074, 20.964970784620718, 21.191625704508848, 21.415881957089702, 21.63781412250323, 21.8574929943944, 22.074985843710074, 22.290356659326925, 22.50366636794992, 22.714973035423135, 22.924332051337945, 23.131796298601632, 23.337416309437515, 23.541240409120334, 23.743314848605284, 23.943683927081896, 24.14239010537275, 24.339474110999195, 24.534975035650643, 24.728930425717973, 24.92137636648506, 25.11234756051294, 25.30187740069895, 25.48999803844638, 25.676740447338723, 25.86213448267564, 26.04620893719468, 26.22899159327328, 26.410509271878876, 26.59078787851161, 26.769852446362123, 26.94772717688823, 27.12443547799659, 27.300000000000004, 27.474442669506516, 27.647784721384102, 27.820046728932724, 27.991248632385094, 28.161409765848017, 28.33054888278729, 28.4986841801512, 28.665833321220585, 28.832013457266566, 28.997241248091175, 29.16153288152048, 29.32490409191478, 29.487370177755768, 29.648946018366328, 29.809646089814628, 29.96948448005071, 30.12847490332028, 30.286630713897516, 30.443964919175695, 30.600490192152154, 30.756218883341308, 30.91116303214747, 31.06533437772722], [0.0, 3.1108680460604563, 4.399431781491788, 5.388181511419229, 6.221736092120913, 6.956112420023127, 7.620039369977035, 8.230583211413393, 8.798863562983575, 9.332604138181368, 9.837428525788638, 10.317582081088574, 10.776363022838458, 11.216394251273446, 11.639802403821124, 12.048340134640952, 12.443472184241825, 12.826437541266086, 13.198295344475364, 13.559959439467365, 13.912224840046253, 14.255788298091412, 14.591264509973081, 14.919199040162983, 15.24007873995407, 15.554340230302284, 15.862376871074526, 16.164544534257686, 16.461166422826786, 16.75253712128405, 17.03892602249332, 17.32058024432207, 17.59772712596715, 17.870576375707643, 18.139321927789915, 18.40414355518887, 18.665208276362737, 18.92267158727858, 19.176678544523817, 19.427364720929088, 19.674857051577277, 19.91927458518508, 20.16072915348054, 20.399325969256925, 20.635164162177148, 20.868337260069378, 21.09893362234215, 21.327036831214972, 21.552726045676916, 21.776076322423194, 21.99715890745894, 22.216041501581692, 22.43278850254689, 22.647461226371494, 22.860118109931104, 23.070814896747798, 23.279604807642247, 23.486538697730662, 23.691665201078628, 23.8950308641776, 24.096680269281904, 24.296656148532044, 24.494999489691768, 24.691749634240182, 24.88694436848365, 25.08062000828528, 25.27281147794998, 25.46355238375039, 25.652875082532173, 25.840810745795114, 26.02738941960949, 26.212640080693895, 26.396590688950727, 26.579268236729167, 26.760698795061383, 26.940907557096143, 27.11991887893473, 27.29775631805662, 27.474442669506512, 27.650000000000006, 27.824449680092506, 27.997812414544107, 28.170108271002444, 28.34135670711619, 28.511576596182824, 28.680786251426237, 28.84900344899283, 29.016245449747633, 29.182529019946163, 29.347870450852135, 29.512285577365912, 29.675789795724057, 29.838398080325966, 30.00012499973959, 30.160984731934736, 30.320991078788964, 30.48015747990814, 30.63849702580073, 30.79602247044251, 30.95274624326572, 31.108680460604567, 31.263836936626962], [0.0, 3.130495168499706, 4.427188724235731, 5.422176684690385, 6.260990336999412, 7.000000000000001, 7.668115805072326, 8.282511696339464, 8.854377448471462, 9.391485505499118, 9.899494936611665, 10.38267788193393, 10.84435336938077, 11.28716084761797, 11.713240371477058, 12.12435565298214, 12.521980673998824, 12.907362240210043, 13.281566172707196, 13.645512082732553, 14.000000000000002, 14.345731072343439, 14.683323874382122, 15.013327412669055, 15.336231610144653, 15.65247584249853, 15.962455951387934, 16.26653005407115, 16.565023392678928, 16.858232410309217, 17.146428199482248, 17.429859437184227, 17.708754896942924, 17.983325610131185, 18.253766734567417, 18.520259177452136, 18.782971010998235, 19.042058712229622, 19.29766825292631, 19.549936061276522, 19.79898987322333, 20.044949488586898, 20.28792744466522, 20.52802961806125, 20.76535576386786, 21.0, 21.232051243344344, 21.46159360345825, 21.68870673876154, 21.91346617949794, 22.135943621178658, 22.35620719173984, 22.57432169523594, 22.790348834539593, 23.004347415216976, 23.2163735324878, 23.426480742954116, 23.634720222587784, 23.841140912296964, 24.04578965224474, 24.24871130596428, 24.449948875202175, 24.649543606322613, 24.84753508901839, 25.043961347997648, 25.238858928247925, 25.432262974418933, 25.62420730481238, 25.814724480420086, 26.0038458694094, 26.191601707417593, 26.378021153983482, 26.56313234541439, 26.74696244435992, 26.92953768633988, 27.11088342345192, 27.291024165465107, 27.46998361848802, 27.647784721384102, 27.824449680092513, 28.000000000000004, 28.174456516497354, 28.34783942384323, 28.52016830244871, 28.691462144686877, 28.861739379323627, 29.031017894658813, 29.1993150604599, 29.366647748764244, 29.53303235362058, 29.698484809834998, 29.86302061078216, 30.02665482533811, 30.18940211398696, 30.351276744150326, 30.512292604784715, 30.672463220289305, 30.83180176376334, 30.99032106965012, 31.14803364580179, 31.30495168499706, 31.461087075941933], [0.0, 3.1500000000000004, 4.4547727214752495, 5.455960043841964, 6.300000000000001, 7.043614129124338, 7.715892689767012, 8.334116629853462, 8.909545442950499, 9.45, 9.961174629530396, 10.447368089619511, 10.911920087683928, 11.357486517711568, 11.786220768337916, 12.199897540553362, 12.600000000000001, 12.987782720695632, 13.36431816442575, 13.730531672153125, 14.087228258248675, 14.435113439110896, 14.774809643443803, 15.106869298435068, 15.431785379534023, 15.750000000000002, 16.061911467817275, 16.36788013152589, 16.668233259706923, 16.963269142473692, 17.253260561412734, 17.53845774291457, 17.819090885900998, 18.095372336594792, 18.367498468762697, 18.63565131676379, 18.9, 19.160701970439394, 19.41790410935228, 19.67174369495496, 19.92234925906079, 20.169841347913476, 20.41433319998476, 20.6559313515513, 20.894736179239022, 21.13084238737301, 21.364339446844596, 21.59531199126329, 21.823840175367856, 22.05, 22.27386360737625, 22.49549954990998, 22.714973035423135, 22.932346151233634, 23.147678069301033, 23.361025234351338, 23.572441536675832, 23.78197847110286, 23.98968528347131, 24.19560910578612, 24.399795081106724, 24.602286479105963, 24.8031248031372, 25.002349889560385, 25.200000000000003, 25.39611190714043, 25.59072097460328, 25.78386123139822, 25.975565441391264, 26.16586516819194, 26.354790835823383, 26.54237178550553, 26.7286363288515, 26.91361179775022, 27.09732459118427, 27.279800219209818, 27.46106334430625, 27.641137820285188, 27.82004672893272, 27.99781241454411, 28.17445651649735, 28.35, 28.52446318513287, 28.697865774304542, 28.870226878221793, 29.041565040472598, 29.21189826081147, 29.381244017229772, 29.549619286887605, 29.7170405659783, 29.883523888591185, 30.04908484463379, 30.213738596870137, 30.377499897127812, 30.540383101722878, 30.702402186148237, 30.863570759068047, 31.023902075657734, 31.183409050326745, 31.342104268858535, 31.500000000000004, 31.65710820653081], [0.0, 3.169384798348096, 4.4821869662029945, 5.489535499475344, 6.338769596696192, 7.0869598559608065, 7.763375554486593, 8.385403985497659, 8.964373932405989, 9.508154395044288, 10.022474744293449, 10.511660192376846, 10.979070998950688, 11.427379402120158, 11.858752042268192, 12.274974541725127, 12.677539193392384, 13.06770829181613, 13.446560898608984, 13.81502804919339, 14.173919711921613, 14.523945744872503, 14.865732407116711, 15.199835525425929, 15.526751108973187, 15.846923991740482, 16.160754932861277, 16.46860649842603, 16.770807970995318, 17.067659476331258, 17.359435474692145, 17.646387732337747, 17.928747864811978, 18.206729525095938, 18.480530295421723, 18.750333330370424, 19.016308790088576, 19.27861509548858, 19.53740003173401, 19.792801721838174, 20.044949488586898, 20.29396462005392, 20.539961051569698, 20.78304597502493, 21.023320384753692, 21.260879567882416, 21.495813545897725, 21.72820747323626, 21.958141997901375, 22.185693588436674, 22.410934831014973, 22.633934699914644, 22.854758804240316, 23.073469613389317, 23.290126663459777, 23.504786746533142, 23.717504084536383, 23.928330489192096, 24.137315509393336, 24.344506567190887, 24.549949083450255, 24.753686594121696, 24.955760857966244, 25.156211956492978, 25.35507838678477, 25.552397147821573, 25.748203820849334, 25.942532644288995, 26.13541658363226, 26.32688739672809, 26.51697569482614, 26.705710999709407, 26.89312179721797, 27.07923558743858, 27.264078931810626, 27.447677497376716, 27.63005609838678, 27.81123873544651, 27.99124863238509, 28.170108271002444, 28.347839423843226, 28.524463185132866, 28.70000000000001, 28.874469692099975, 29.047891489745005, 29.22028405063853, 29.39166548530383, 29.562053379290152, 29.731464814233423, 29.89991638784296, 30.067424232880345, 30.2340040351919, 30.399671050851858, 30.564440122469126, 30.728325694707163, 30.89134182906272, 31.053502217946374, 31.214820198104626, 31.37530876342096, 31.53498057713054, 31.693847983480964, 31.851923018869684], [0.0, 3.1886517527005047, 4.509434554353794, 5.5229068433208255, 6.377303505401009, 7.1300420756121765, 7.810569761547489, 8.436379555235765, 9.018869108707587, 9.565955258101512, 10.083402203621553, 10.57556145081669, 11.045813686641651, 11.49684739395979, 11.930842384341517, 12.349595135064144, 12.754607010802019, 13.147147979695065, 13.528303663061383, 13.89901075616535, 14.260084151224353, 14.612238021603673, 14.956102433455047, 15.292236592467436, 15.621139523094978, 15.943258763502525, 16.25899750907171, 16.568720529962473, 16.87275911047153, 17.17141520085051, 17.464964929824507, 17.753661594161358, 18.037738217415175, 18.317409751381337, 18.592874979410798, 18.86431816949661, 19.131910516203025, 19.395811403496374, 19.65616951493856, 19.913123813204198, 20.166804407243106, 20.417333322449338, 20.664825186775715, 20.90938784374138, 21.15112290163338, 21.39012622683653, 21.626488388085573, 21.860295057478066, 22.091627373283302, 22.320562268903533, 22.54717277176897, 22.771528275458373, 22.99369478791958, 23.2137351583066, 23.431709284642466, 23.647674304252416, 23.861684768683034, 24.0737928046247, 24.284048262182317, 24.492498851689266, 24.699190270128287, 24.904166318108302, 25.10746900824533, 25.309138665707295, 25.509214021604038, 25.707732299835392, 25.904729297948666, 26.100239462503023, 26.29429595939013, 26.486930739517557, 26.678174600223308, 26.868057242755754, 27.056607326122766, 27.24385251758642, 27.429819540055306, 27.614534216604124, 27.7980215123307, 27.9803055737424, 28.161409765848017, 28.341356707116194, 28.520168302448706, 28.697865774304542, 28.87446969209998, 29.049999999999997, 29.224476043207346, 29.39791659284719, 29.570339869538195, 29.741763565733624, 29.912204866910095, 30.081680471675778, 30.25020661086466, 30.417799065678633, 30.584473184934872, 30.750243901471745, 30.91512574776302, 31.079132870786466, 31.242279046189957, 31.40457769179519, 31.566041880476554, 31.72668435245007, 31.88651752700505, 32.0455535137092], [0.0, 3.2078029864690882, 4.536518488885503, 5.556077753235641, 6.4156059729381765, 7.172865536171719, 7.857480512225278, 8.487048957087499, 9.073036977771006, 9.623408959407264, 10.143963722332607, 10.639078907499465, 11.112155506471282, 11.565898149300816, 12.002499739637573, 12.423767544509193, 12.831211945876353, 13.22611053938383, 13.60955546665651, 13.982489048806729, 14.345731072343439, 14.700000000000001, 15.045929682143274, 15.38408268308514, 15.714961024450556, 16.03901493234544, 16.356650023767095, 16.66823325970692, 16.974097914174997, 17.274547750954294, 17.569860557215588, 17.860291151042304, 18.14607395554201, 18.42742521352346, 18.704544902242343, 18.977618396416343, 19.24681791881453, 19.512303810672897, 19.77422564855575, 20.032723229755863, 20.287927444665215, 20.539961051569698, 20.7889393668845, 21.034970881843407, 21.27815781499893, 21.518596608515157, 21.756378375088076, 21.99158930136701, 22.224311012942565, 22.45462090528362, 22.682592444427513, 22.908295440735003, 23.131796298601632, 23.35315824465719, 23.572441536675832, 23.789703655153, 24.004999479275146, 24.21838144880867, 24.429899713261207, 24.639602269517262, 24.847535089018386, 25.053742235442595, 25.2582659737362, 25.4611468712625, 25.662423891752706, 25.862134482675632, 26.0603146565808, 26.256999066915476, 26.45222107876766, 26.646012834943996, 26.838405317753143, 27.029428406830952, 27.21911093331302, 27.40748073063265, 27.59456468219783, 27.780388766178202, 27.964978097613457, 28.148356968036342, 28.33054888278729, 28.511576596182827, 28.691462144686877, 28.870226878221796, 29.047891489745005, 29.224476043207346, 29.400000000000002, 29.574482243988655, 29.747941105226094, 29.92039438242752, 30.09185936428655, 30.2623528497042, 30.431891166997822, 30.600490192152154, 30.76816536617028, 30.9349317115781, 31.10080384813229, 31.265796007778214, 31.429922048901112, 31.593195469910928, 31.755629422198517, 31.917236722498398, 32.07802986469088, 32.23802103107448], [0.0, 3.2268405600525107, 4.563441683641854, 5.58905179793496, 6.4536811201050215, 7.215434844830907, 7.904112853445351, 8.537417642355328, 9.126883367283709, 9.680521680157531, 10.204165815979277, 10.70221939599446, 11.17810359586992, 11.634539097016264, 12.073731817462239, 12.497499749949986, 12.907362240210043, 13.30460446612375, 13.690325050925564, 14.065471908187087, 14.430869689661813, 14.787241121994327, 15.135223817307757, 15.475383678603903, 15.808225706890703, 16.134202800262557, 16.453722982960425, 16.767155393804877, 17.074835284710655, 17.377068222228974, 17.674133642133636, 17.966287874794837, 18.253766734567417, 18.53678774761151, 18.815552078001858, 19.0902462006125, 19.361043360315062, 19.628104849933937, 19.89158113373595, 20.151612838678698, 20.408331631958553, 20.661861000403622, 20.91231694480552, 21.159808600268576, 21.40443879198892, 21.646304534492717, 21.885497481208876, 22.122104330284678, 22.35620719173984, 22.587883920367574, 22.817208418209272, 23.044250909934135, 23.269078194032527, 23.49175387236977, 23.71233856033605, 23.930890079560353, 24.147463634924478, 24.362111977412795, 24.574885554158744, 24.7858326468973, 24.994999499899972, 25.202430438352568, 25.40816797803415, 25.612252927065985, 25.814724480420086, 26.01562030780738, 26.21497663550361, 26.412828322616267, 26.6092089322475, 26.804150797964112, 26.99768508594765, 27.189841853162736, 27.380650101851128, 27.570137830631168, 27.75833208245769, 27.945258989674798, 28.130943816374174, 28.315410998253235, 28.498684180151198, 28.680786251426237, 28.861739379323627, 29.041565040472598, 29.22028405063853, 29.39791659284719, 29.574482243988655, 29.750000000000004, 29.924488299718682, 30.097965047491172, 30.270447634615515, 30.441952959690347, 30.61249744793783, 30.78209706956302, 30.950767357207805, 31.11852342255333, 31.28537997212117, 31.45135132232, 31.616451413781405, 31.780693825025285, 31.94409178549298, 32.106658187983385, 32.268405600525114, 32.429346277715815], [0.0, 3.2457664734234966, 4.590206967011401, 5.621832441473154, 6.491532946846993, 7.257754473664702, 7.950471684120384, 8.587490902469709, 9.180413934022802, 9.737299420270489, 10.264014809030627, 10.76498954946079, 11.243664882946309, 11.702777448110343, 12.144546101028231, 12.570799497247577, 12.983065893693986, 13.382638006013615, 13.770620901034203, 14.14796805198542, 14.515508947329405, 14.873970552613045, 15.223994219652083, 15.566149170555962, 15.900943368240767, 16.228832367117484, 16.55022658455165, 16.86549732441946, 17.174981804939417, 17.478987384857284, 17.77779513888041, 18.071662900795822, 18.360827868045604, 18.64550884261409, 18.925908168434088, 19.202213414083285, 19.474598840540978, 19.74322668663864, 20.008248299139034, 20.269805129798364, 20.528029618061254, 20.783045975024937, 21.03497088184341, 21.283914113715078, 21.52997909892158, 21.773263420994105, 22.013859270922946, 22.251853855353268, 22.487329765892618, 22.720365313964475, 22.951034835057005, 23.17940896571783, 23.405554896220686, 23.629536601465553, 23.85141505236115, 24.07124840966916, 24.289092202056462, 24.504999489900015, 24.719021016213407, 24.93120534591138, 25.141598994495155, 25.35024654712455, 25.557190768940156, 25.762472707409128, 25.966131787387972, 26.16820589952624, 26.36873148257231, 26.567743600087685, 26.76527601202723, 26.961361241599064, 27.156030637779157, 27.349314433820823, 27.541241802068406, 27.731840905356425, 27.92113894525078, 28.10916220736577, 28.29593610397084, 28.4814852140825, 28.665833321220582, 28.849003448992832, 29.03101789465881, 29.21189826081147, 29.39166548530383, 29.57033986953819, 29.74794110522609, 29.924488299718682, 30.100000000000005, 30.274494215428277, 30.447988439304165, 30.620499669339164, 30.79204442709188, 30.96263877643506, 31.132298341111923, 31.301038321435925, 31.468873510184636, 31.635818307734667, 31.801886736481535, 31.967092454585234, 32.1314487690798, 32.29496864838237, 32.45766473423497, 32.61954935311033], [0.0, 3.2645826685810855, 4.616817085395522, 5.65442304749123, 6.529165337162171, 7.299828765114974, 7.996561761157104, 8.637273875477147, 9.233634170791044, 9.793748005743256, 10.323516842626839, 10.827395808780615, 11.30884609498246, 11.770620204560167, 12.214949856630604, 12.643674307731908, 13.058330674324342, 13.460219166120588, 13.850451256186567, 14.229985945179289, 14.599657530229948, 14.960197191213759, 15.312249997959151, 15.656388472441531, 15.993123522314209, 16.32291334290543, 16.646170730831763, 16.96326914247369, 17.274547750954294, 17.58031569682411, 17.88085568422272, 18.1764270416383, 18.467268341582088, 18.753599654466342, 19.035624497242008, 19.313531525849953, 19.58749601148651, 19.857681133506, 20.124239116051072, 20.38731223089498, 20.647033685253678, 20.903528410294758, 21.15691376359038, 21.407300156722236, 21.65479161756123, 21.89948629534492, 22.141476915508598, 22.380851190247434, 22.61769218996492, 22.8520786800676, 23.08408542697761, 23.313783476733246, 23.541240409120334, 23.76652056991095, 23.98968528347131, 24.21079304772977, 24.429899713261207, 24.647058648041554, 24.862320889249258, 25.07573528333716, 25.287348615463817, 25.497205729255903, 25.705349637769952, 25.91182162643144, 26.116661348648684, 26.31990691472901, 26.52159497466169, 26.72176079527695, 26.920438332241176, 27.117660297304415, 27.313458221177342, 27.507862512379983, 27.700902512373133, 27.892606547255493, 28.083001976284514, 28.27211523745615, 28.459971890358577, 28.646596656496566, 28.832013457266562, 29.016245449747633, 29.199315060459895, 29.381244017229772, 29.562053379290152, 29.741763565733624, 29.920394382427517, 30.097965047491172, 30.274494215428277, 30.450000000000003, 30.624499995918303, 30.798011299432954, 30.970550527880516, 31.14213383825842, 31.312776944883062, 31.4824951361864, 31.651303290701954, 31.819215892287477, 31.986247044628417, 32.15241048506317, 32.31771959776865, 32.482187426341845, 32.64582668581086, 32.80864977410683], [0.0, 3.283291031876401, 4.64327470649756, 5.686826883245173, 6.566582063752802, 7.341661937191061, 8.04238770515324, 8.6867715521936, 9.28654941299512, 9.849873095629201, 10.382677881933928, 10.889444430272832, 11.373653766490346, 11.838074167701436, 12.28495014234897, 12.716131487209463, 13.133164127505603, 13.537355724069602, 13.92982411949268, 14.311533810182615, 14.683323874382122, 15.045929682143274, 15.4, 15.746110630882791, 16.08477541030648, 16.416455159382007, 16.74156504034196, 17.060480649735517, 17.3735431043872, 17.681063316441126, 17.983325610131182, 18.280590800080834, 18.57309882599024, 18.861071019430476, 19.14471206364828, 19.424211695716252, 19.699746191258402, 19.97147966476195, 20.239565212721345, 20.504145922227536, 20.765355763867856, 21.023320384753692, 21.27815781499893, 21.529979098921576, 21.778888860545663, 22.02498581157318, 22.268363208821615, 22.50910926713894, 22.74730753298069, 22.983037223134808, 23.2163735324878, 23.44738791422192, 23.67614833540287, 23.902719510549424, 24.12716311545972, 24.34953798329652, 24.56990028469794, 24.78830369347608, 25.004799539288452, 25.219436948512552, 25.432262974418926, 25.643322717619885, 25.852659437667143, 26.0603146565808, 26.266328255011206, 26.47073856166465, 26.673582436560714, 26.874895348633455, 27.074711448139205, 27.273063634289425, 27.46998361848802, 27.665501983517306, 27.85964823898536, 28.052450873319426, 28.243937402564818, 28.434134416225863, 28.62306762036523, 28.81076187815935, 28.997241248091175, 29.18252901994617, 29.366647748764244, 29.54961928688761, 29.731464814233426, 29.912204866910095, 30.09185936428655, 30.27044763461552, 30.44798843930417, 30.624499995918306, 30.8, 30.97450564577262, 31.148033645801785, 31.320600249675934, 31.492221261765582, 31.662912058116202, 31.83268760252581, 32.00156246185489, 32.16955082061296, 32.336666494863074, 32.502922945482915, 32.6683332908185, 32.832910318764014, 32.9966664982995], [0.0, 3.3018933962198114, 4.669582422444217, 5.719047123428868, 6.603786792439623, 7.383258088405145, 8.08795400580394, 8.73598878204408, 9.339164844888433, 9.905680188659433, 10.441503723123407, 10.951141493013411, 11.438094246857736, 11.905145946186463, 12.354553816305952, 12.788178134511575, 13.207573584879245, 13.614055237143708, 14.008747267332652, 14.392619636466465, 14.76651617681029, 15.1311764248521, 15.48725282288631, 15.835324436209069, 16.17590801160788, 16.50946698109906, 16.83641885912797, 17.1571413702866, 17.47197756408816, 17.781240114232755, 18.085214955869336, 18.384164381336454, 18.678329689776866, 18.96793346677492, 19.253181555265094, 19.534264767326157, 19.811360377318866, 20.084633429565002, 20.354237887968196, 20.620317650317613, 20.883007446246815, 21.14243363475454, 21.398714914685883, 21.651962959510158, 21.902282986026822, 22.149774265215434, 22.39453058226495, 22.636640651828177, 22.87618849371547, 23.11325377353868, 23.347912112221085, 23.580235367782063, 23.810291892372927, 24.038146767169888, 24.263862017411817, 24.487496809596525, 24.709107632611904, 24.928748464373413, 25.14647092536048, 25.36232442028924, 25.57635626902315, 25.788611827704102, 25.99913460098239, 26.20796634613224, 26.41514716975849, 26.620715617728983, 26.82470875890361, 27.02716226317517, 27.228110474287416, 27.427586477851094, 27.625622164939564, 27.822248291610077, 28.017494534665303, 28.211389543941287, 28.40396099138287, 28.595235617144333, 28.78523927293293, 28.97399696279407, 29.16153288152048, 29.347870450852138, 29.53303235362058, 29.7170405659783, 29.899916387842964, 30.081680471675778, 30.2623528497042, 30.44195295969035, 30.620499669339168, 30.798011299432957, 30.97450564577262, 31.149999999999995, 31.324511169370226, 31.498055495538132, 31.670648872418138, 31.842306763172797, 32.01304421638155, 32.18287588143732, 32.35181602321576, 32.51987853605853, 32.68707695710952, 32.853424479040235, 33.01893396219812, 33.183617946209544], [0.0, 3.3203915431767985, 4.695742752749558, 5.751086853804245, 6.640783086353597, 7.424621202458749, 8.133265027035575, 8.784930278607794, 9.391485505499116, 9.961174629530394, 10.5, 11.01249290578659, 11.50217370760849, 11.97184196354095, 12.423767544509193, 12.859821149611683, 13.281566172707194, 13.690325050925562, 14.087228258248675, 14.473251189694736, 14.849242404917497, 15.215945583498911, 15.57401682290089, 15.924038432508258, 16.26653005407115, 16.601957715883994, 16.930741271426957, 17.25326056141273, 17.569860557215588, 17.880855684222723, 18.186533479473212, 18.48715770474196, 18.78297101099823, 19.0741972308142, 19.361043360315065, 19.643701280563192, 19.922349259060788, 20.197153264754913, 20.468268124098824, 20.735838541038078, 21.0, 21.26087956788242, 21.518596608515157, 21.773263420994105, 22.02498581157318, 22.273863607376246, 22.519991119003578, 22.76345755811274, 23.00434741521698, 23.242740802237588, 23.47871376374779, 23.712338560336054, 23.9436839270819, 24.172815309764815, 24.399795081106724, 24.624682739073005, 24.847535089018386, 25.068406411257975, 25.28734861546382, 25.50441138313135, 25.719642299223366, 25.933086973979783, 26.144789155776337, 26.35479083582338, 26.563132345414388, 26.769852446362115, 26.974988415196773, 27.17857612164405, 27.380650101851124, 27.581243626783767, 27.780388766178206, 27.978116448395877, 28.17445651649735, 28.36943778082322, 28.563088068344427, 28.755434269021222, 28.94650237938947, 29.13631754357438, 29.324904091914778, 29.512285577365915, 29.698484809834994, 29.883523888591185, 30.06742423288035, 30.25020661086466, 30.431891166997822, 30.61249744793783, 30.79204442709188, 30.97055052788052, 31.14803364580178, 31.324511169370222, 31.5, 31.67451657089655, 31.848076865016516, 32.02069643215151, 32.192390405187375, 32.36317351558712, 32.5330601081423, 32.70206415503462, 32.87019926924691, 33.037478717359775, 33.20391543176799, 33.369522022348484], [0.0, 3.33878720495931, 4.721758147131214, 5.782949074650408, 6.67757440991862, 7.4657551526955395, 8.178325011883546, 8.833600624886774, 9.443516294262428, 10.016361614877928, 10.55817219029885, 11.073504413689463, 11.565898149300816, 12.038168465343889, 12.492597808302323, 12.931067241337814, 13.35514881983724, 13.766172307507997, 14.165274441393645, 14.553436020404257, 14.931510305391079, 15.300245096076077, 15.660300124837965, 16.012260927177024, 16.35665002376709, 16.69393602479655, 17.024541109821435, 17.34884722395122, 17.667201249773548, 17.979919354657852, 18.287290668658382, 18.5895804148453, 18.887032588524857, 19.17987226234836, 19.468307579242733, 19.752531483331445, 20.032723229755856, 20.309049706965613, 20.58166659918482, 20.850719412049074, 21.1163443805977, 21.378669275705636, 21.637814122503226, 21.893891842246777, 22.147008827378926, 22.39726545808662, 22.64475656747054, 22.889571861439435, 23.131796298601632, 23.37151043471517, 23.608790735656076, 23.84370986235154, 24.076336930687777, 24.306737749027533, 24.53497503565064, 24.761108618153592, 24.985195616604646, 25.207290612043174, 25.42744580173164, 25.64571114241132, 25.86213448267563, 26.076761685454734, 26.28963674149949, 26.500801874660322, 26.71029763967448, 26.91816301310325, 27.12443547799659, 27.32915110280596, 27.532344615015994, 27.734049469920546, 27.934297914928884, 28.133121049752017, 28.33054888278729, 28.526610383990594, 28.721333534500097, 28.914745373252035, 29.106872040808515, 29.29773882059843, 29.487370177755768, 29.67578979572406, 29.863020610782158, 30.04908484463379, 30.234004035191905, 30.417799065678633, 30.600490192152154, 30.78209706956302, 30.962638776435064, 31.14213383825842, 31.32060024967593, 31.498055495538132, 31.67451657089655, 31.85, 32.02452185435405, 32.19809776989939, 32.370742963361224, 32.542472247817926, 32.71330004753418, 32.88324041210051, 33.0523070299185, 33.22051324106839, 33.3878720495931, 33.55439613523093], [0.0, 3.357082066318904, 4.747630988187688, 5.814636704042654, 6.714164132637808, 7.5066637063345265, 8.223138087129513, 8.882004278314666, 9.495261976375376, 10.071246198956711, 10.616025621672172, 11.134181604410808, 11.629273408085307, 12.10413152605341, 12.561050911448453, 13.001922934704696, 13.428328265275615, 13.841603953299634, 14.242892964563065, 14.633181472256815, 15.013327412669053, 15.38408268308514, 15.74611063088279, 16.1, 16.446276174259026, 16.785410331594523, 17.11782696489248, 17.44391011212796, 17.76400855662933, 18.078440198202944, 18.387495751189178, 18.691441891946166, 18.990523952750753, 19.28496823953828, 19.574984035753392, 19.860765342755553, 20.142492397913422, 20.420333004140755, 20.69444369873228, 20.964970784620718, 21.232051243344344, 21.495813545897725, 21.756378375088076, 22.013859270922943, 22.268363208821615, 22.519991119003578, 22.768838354206835, 23.014995111883035, 23.258546816170615, 23.499574464232328, 23.73815494093844, 23.974361305361196, 24.20826305210682, 24.43992635013453, 24.669414261388535, 24.896786941290237, 25.122101822896905, 25.345413786324343, 25.566775314849547, 25.78623663895141, 26.003845869409393, 26.219649120459263, 26.433690623898887, 26.646012834943996, 26.85665653055123, 27.065660900853686, 27.273063634289425, 27.478900996946734, 27.683207906599268, 27.88601800185893, 28.087363706834434, 28.28727629164745, 28.48578592912613, 28.68292174796703, 28.878711882630775, 29.073183520213263, 29.26636294451363, 29.45827557750114, 29.648946018366324, 29.838398080325966, 30.026654825338106, 30.213738596870137, 30.399671050851858, 30.58447318493487, 30.76816536617028, 30.950767357207805, 31.132298341111923, 31.312776944883066, 31.49222126176558, 31.670648872418134, 31.848076865016516, 32.02452185435405, 32.2, 32.37452702357211, 32.548118225175486, 32.72078849905668, 32.89255234851805, 33.06342390013473, 33.23341691731382, 33.402544813232424, 33.570820663189046, 33.7382572164005], [0.0, 3.3752777663475344, 4.77336359394505, 5.846152580971524, 6.750555532695069, 7.5473505284967395, 8.267708267712402, 8.930145575521152, 9.5467271878901, 10.125833299042602, 10.673565477383836, 11.194529914203635, 11.692305161943048, 12.169737055499597, 12.6291329868681, 13.072394577888168, 13.501111065390138, 13.916626746449731, 14.320090781835152, 14.712494689888596, 15.094701056993479, 15.46746585578905, 15.8314560290581, 16.187263511786053, 16.535416535424805, 16.876388831737675, 17.21060719440195, 17.53845774291457, 17.860291151042304, 18.176427041638302, 18.48715770474196, 18.79275126212232, 19.0934543757802, 19.38949457825036, 19.68108228731337, 19.968412555834277, 20.251666598085205, 20.531013126487455, 20.80660952678259, 21.078602894878973, 21.34713095476767, 21.612322873768107, 21.874299988799645, 22.13317645526733, 22.38905982840727, 22.642051585490215, 22.89224759607497, 23.139738546491834, 23.384610323886097, 23.62694436443274, 23.86681796972525, 24.104304594822896, 24.339474110999195, 24.572393045855346, 24.803124803137205, 25.031729864314215, 25.2582659737362, 25.482788308974353, 25.705349637769956, 25.926000462855818, 26.144789155776337, 26.36176208071077, 26.576963709197482, 26.79043672656346, 27.002222130780275, 27.21235932439523, 27.420886200121252, 27.627839220612245, 27.833253492899463, 28.03716283791925, 28.239599855522037, 28.44059598531648, 28.640181563670303, 28.838385877160324, 29.035237212738593, 29.230762904857617, 29.42498937977719, 29.617942197256045, 29.809646089814624, 30.00012499973959, 30.189402113986958, 30.377499897127812, 30.564440122469126, 30.75024390147174, 30.9349317115781, 31.11852342255333, 31.301038321435925, 31.4824951361864, 31.6629120581162, 31.842306763172797, 32.0206964321515, 32.19809776989939, 32.37452702357211, 32.550000000000004, 32.72453208221625, 32.89813824519558, 33.07083307084961, 33.24263076232085, 33.413545157615346, 33.583589742610904, 33.75277766347535, 33.92112173852746], [0.0, 3.3933759001914305, 4.798958220280731, 5.877499468311334, 6.786751800382861, 7.5878191860375805, 8.312039460926544, 8.978028736866463, 9.597916440561463, 10.18012770057429, 10.730796801729126, 11.25455463356947, 11.754998936622668, 12.234990805063976, 12.696850003051939, 13.14248834886301, 13.573503600765722, 13.991247263914682, 14.396874660842196, 14.79138262638081, 15.175638372075161, 15.550401924066145, 15.916343801262903, 16.27405911258774, 16.624078921853087, 16.966879500957155, 17.302889932031587, 17.632498404934, 17.956057473732926, 18.27388847508926, 18.586285266292457, 18.89351740677209, 19.195832881122925, 19.49346044190205, 19.7866116351436, 20.07548255957998, 20.36025540114858, 20.641099776901427, 20.91817391647751, 21.191625704508848, 21.46159360345825, 21.728207473236264, 21.991589301367014, 22.251853855353264, 22.50910926713894, 22.76345755811274, 23.01499511188304, 23.263813101037414, 23.509997873245336, 23.753631301340015, 23.994791101403656, 24.23355112235927, 24.469981610127952, 24.704149449029817, 24.93611838277963, 25.165949217146572, 25.393700006103877, 25.61942622308314, 25.843180918764627, 26.06501486667522, 26.28497669772602, 26.503113024699573, 26.719468557589238, 26.93408621059939, 27.147007201531444, 27.358271144207922, 27.567916134521308, 27.775978830637097, 27.982494527829363, 28.187497228381243, 28.39101970694255, 28.59309357170014, 28.79374932168439, 28.99301640050583, 29.19092324679026, 29.387497341556667, 29.58276525276162, 29.77675267721449, 29.969484480050706, 30.160984731934736, 30.351276744150322, 30.540383101722878, 30.728325694707163, 30.91512574776302, 31.10080384813229, 31.285379972121167, 31.468873510184636, 31.651303290701954, 31.832687602525805, 32.013044216381545, 32.192390405187375, 32.370742963361224, 32.54811822517548, 32.72453208221625, 32.900000000000006, 33.07453703379686, 33.248157843706174, 33.420876709027254, 33.59270754196512, 33.76366390070841, 33.93375900191431, 34.103005732633015], [0.0, 3.411378020683137, 4.824417063231577, 5.908680055646946, 6.822756041366274, 7.628073151196178, 8.356135470419325, 9.02565787075934, 9.648834126463154, 10.23413406204941, 10.787724505195708, 11.314260912671228, 11.817360111293892, 12.299898373563904, 12.764207770167326, 13.21221026172381, 13.645512082732548, 14.065471908187083, 14.473251189694732, 14.869852050373604, 15.256146302392356, 15.632898003889105, 16.000781230927444, 16.36039424952834, 16.71227094083865, 17.05689010341569, 17.39468309570485, 17.726040166940837, 18.05131574151868, 18.370832860814993, 18.684886941054792, 18.993748971701187, 19.297668252926307, 19.596874750837188, 19.89158113373595, 20.18198454067389, 20.46826812409882, 20.750602400894294, 21.02914644011972, 21.304048910946484, 21.575449010391416, 21.843477287281896, 22.10825637629526, 22.36990165378471, 22.628521825342457, 22.884219453588532, 23.137091433453776, 23.387229421203358, 23.634720222587784, 23.87964614478196, 24.122085316157886, 24.3621119774128, 24.599796747127808, 24.83520686444951, 25.068406411257975, 25.299456515901678, 25.528415540334652, 25.75533925227932, 25.980280983853888, 26.20329177794271, 26.42442052344762, 26.643714080435554, 26.861217396089845, 27.076973612278017, 27.291024165465096, 27.50340887962799, 27.714166052760817, 27.92333253750347, 28.130943816374167, 28.33703407204078, 28.54163625302516, 28.74478213519803, 28.946502379389464, 29.146826585410626, 29.345783342756413, 29.543400278234728, 29.739704100747208, 29.934720643426758, 30.12847490332028, 30.320991078788968, 30.51229260478471, 30.702402186148237, 30.89134182906272, 31.079132870786466, 31.26579600777821, 31.45135132232, 31.635818307734667, 31.819215892287477, 32.00156246185489, 32.18287588143731, 32.36317351558712, 32.542472247817926, 32.72078849905668, 32.89813824519558, 33.074537033796865, 33.24999999999999, 33.4245418816773, 33.59817703388087, 33.770919442621036, 33.94278273801369, 34.11378020683138, 34.2839248044911], [0.0, 3.4292856398964493, 4.849742261192857, 5.939696961967, 6.858571279792899, 7.6681158050723255, 8.4, 9.073036977771006, 9.699484522385713, 10.287856919689348, 10.844353369380768, 11.373653766490346, 11.879393923934, 12.364465212858986, 12.831211945876351, 13.281566172707192, 13.717142559585797, 14.13930691370691, 14.549226783578572, 14.94790955284384, 15.336231610144651, 15.714961024450554, 16.08477541030648, 16.446276174259026, 16.8, 17.146428199482248, 17.48599439551552, 17.819090885900998, 18.14607395554201, 18.46726834158209, 18.782971010998235, 19.093454375780198, 19.398969044771427, 19.699746191258406, 19.995999599919983, 20.287927444665215, 20.575713839378697, 20.859530196051878, 21.1395364187581, 21.4158819570897, 21.688706738761535, 21.958141997901375, 22.224311012942565, 22.487329765892614, 22.74730753298069, 23.004347415216976, 23.25854681617061, 23.509997873245332, 23.758787847868, 24.004999479275146, 24.248711305964285, 24.489997958350266, 24.728930425717973, 24.965576300177815, 25.2, 25.432262974418933, 25.662423891752702, 25.8905388124697, 26.116661348648684, 26.340842811117493, 26.563132345414385, 26.783577057592588, 27.00222213078027, 27.219110933313015, 27.434285119171594, 27.647784721384095, 27.85964823898536, 28.069912718068792, 28.27861382741382, 28.48578592912613, 28.69146214468688, 28.89567441677041, 29.098453567157144, 29.299829351038888, 29.499830507987667, 29.698484809834998, 29.89581910568768, 30.091859364286552, 30.286630713897512, 30.480157479908144, 30.672463220289302, 30.863570759068047, 31.053502217946374, 31.242279046189957, 31.42992204890111, 31.616451413781405, 31.801886736481535, 31.98624704462842, 32.16955082061296, 32.35181602321576, 32.5330601081423, 32.71330004753418, 32.89255234851805, 33.07083307084961, 33.248157843706174, 33.4245418816773, 33.6, 33.7745466290815, 33.948195828349995, 34.12096129947104, 34.292856398964496, 34.463894150255285], [0.0, 3.447100230628637, 4.874935897014442, 5.970552738231195, 6.894200461257274, 7.707950440940835, 8.443636657270375, 9.120169954556768, 9.749871794028884, 10.34130069188591, 10.900688051678207, 11.432738079742753, 11.94110547646239, 12.428696633195294, 12.897868040881797, 13.350561785932456, 13.788400922514548, 14.21275835297287, 14.624807691043328, 15.02556155356598, 15.41590088188167, 15.796597734955464, 16.168333247431537, 16.531711950067365, 16.88727331454075, 17.235501153143186, 17.57683134128561, 17.91165821469358, 18.240339909113537, 18.563202848646572, 18.88054554296565, 19.192641819197274, 19.49974358805777, 19.802083223741896, 20.099875621505724, 20.393319984740103, 20.68260138377182, 20.967892121050227, 21.249352931324758, 21.527134040554497, 21.801376103356414, 22.072211035598592, 22.33976275612613, 22.604147849454534, 22.865476159485507, 23.123851322822503, 23.379371249030633, 23.632128554152715, 23.88221095292478, 24.12970161440046, 24.374679485072214, 24.617219583047966, 24.857393266390588, 25.0952684783407, 25.33090997181112, 25.564379515255208, 25.795736081763593, 26.025036023029827, 26.25233322963885, 26.477679278970054, 26.701123571864912, 26.922713459085067, 27.142494358477816, 27.36050986367031, 27.576801845029095, 27.791410543547443, 28.004374658256523, 28.215731427698277, 28.42551670594574, 28.63376503361024, 28.840509704233735, 29.04578282642766, 29.249615382086656, 29.452037280975997, 29.653077411965185, 29.852763691155968, 30.05112310713196, 30.248181763537463, 30.443964919175695, 30.638497025800735, 30.83180176376334, 31.023902075657734, 31.214820198104626, 31.40457769179519, 31.593195469910928, 31.78069382502529, 31.967092454585238, 32.15241048506318, 32.336666494863074, 32.51987853605853, 32.70206415503462, 32.88324041210051, 33.06342390013473, 33.24263076232085, 33.420876709027254, 33.59817703388087, 33.7745466290815, 33.95000000000001, 34.12455127910109, 34.298214239228265, 34.47100230628637, 34.64292857135494], [0.0, 3.4648232278140827, 4.9, 6.001249869818787, 6.929646455628165, 7.74758026741253, 8.487048957087499, 9.167060597596157, 9.8, 10.394469683442248, 10.956733089748969, 11.491518611567402, 12.002499739637575, 12.492597808302323, 12.964181424216493, 13.419202658876568, 13.85929291125633, 14.285832142370987, 14.700000000000001, 15.102814307273995, 15.49516053482506, 15.877814711099258, 16.251461472741457, 16.61670845865691, 16.974097914174997, 17.324116139070416, 17.667201249773548, 18.00374960945636, 18.334121195192314, 18.658644109366577, 18.977618396416343, 19.291319291328936, 19.6, 19.903894091358104, 20.203217565526536, 20.49817065008485, 20.788939366884495, 21.075696904254436, 21.3586048233493, 21.637814122503226, 21.913466179497938, 22.185693588436674, 22.454620905283615, 22.72036531396447, 22.983037223134804, 23.242740802237588, 23.499574464232328, 23.75363130134001, 24.00499947927515, 24.253762594698582, 24.5, 24.743787098987095, 24.985195616604646, 25.224293845418153, 25.461146871262496, 25.695816780168713, 25.928362848432986, 26.15884171747671, 26.38730755495907, 26.61381220344053, 26.838405317753136, 27.06113449210879, 27.282045377867103, 27.501181792788472, 27.71858582251266, 27.934297914928877, 28.148356968036342, 28.360800411836053, 28.571664284741974, 28.780983304953292, 28.98879093718812, 29.19511945514181, 29.400000000000002, 29.6034626353067, 29.80553639846127, 30.00624934909393, 30.20562861454799, 30.4037004326776, 30.600490192152154, 30.796022470442512, 30.99032106965012, 31.18340905032675, 31.375308763420964, 31.566041880476554, 31.755629422198517, 31.944091785492983, 32.1314487690798, 32.31771959776866, 32.502922945482915, 32.68707695710951, 32.87019926924691, 33.0523070299185, 33.23341691731382, 33.41354515761535, 33.59270754196512, 33.77091944262104, 33.948195828349995, 34.1245512791011, 34.3, 34.47455583470221, 34.64823227814083, 34.82104248870215], [0.0, 3.48245602987317, 4.924936547814601, 6.031790778864931, 6.96491205974634, 7.787008411450446, 8.530240324867759, 9.21371260676173, 9.849873095629203, 10.44736808961951, 11.012492905786592, 11.55, 12.063581557729862, 12.556173780256469, 13.0301573282904, 13.487494207598385, 13.92982411949268, 14.358534047736212, 14.774809643443806, 15.179673909541012, 15.574016822900893, 15.958618361249199, 16.334166645409248, 16.701272406616212, 17.060480649735517, 17.412280149365852, 17.757111251552153, 18.095372336594792, 18.42742521352346, 18.753599654466342, 19.0741972308142, 19.38949457825036, 19.699746191258406, 20.005186827420538, 20.306033586104405, 20.602487713866015, 20.89473617923902, 21.18295305192362, 21.467300715273918, 21.747930936068382, 22.024985811573185, 22.29859861067507, 22.568894523214915, 22.835991329478123, 23.1, 23.361025234351338, 23.619165946324188, 23.874515701894353, 24.127163115459723, 24.37719220911219, 24.62468273907301, 24.86971049288673, 25.112347560512937, 25.35266258206424, 25.590720974603276, 25.826585140122575, 26.0603146565808, 26.29196645365272, 26.52159497466169, 26.749252325999695, 26.97498841519677, 27.1988510786761, 27.42088620012125, 27.641137820285188, 27.85964823898536, 28.07645810995397, 28.29160652914571, 28.505131117046282, 28.717068095472424, 28.927452359307416, 29.136317543574382, 29.343696086212454, 29.549619286887612, 29.754117362139983, 29.95721949714292, 30.158953894324654, 30.359347819082025, 30.558427642796026, 30.756218883341305, 30.952746243265725, 31.148033645801785, 31.342104268858535, 31.534980577130543, 31.726684352450068, 31.917236722498398, 32.106658187983385, 32.29496864838237, 32.482187426341845, 32.668333290818495, 32.853424479040235, 33.037478717359775, 33.22051324106839, 33.402544813232424, 33.583589742610904, 33.763663900708416, 33.94278273801369, 34.120961299471034, 34.298214239228265, 34.47455583470221, 34.650000000000006, 34.824560298731704, 34.99824995624782], [0.0, 3.5, 4.949747468305833, 6.062177826491071, 7.0, 7.826237921249264, 8.573214099741124, 9.260129588726068, 9.899494936611665, 10.5, 11.067971810589329, 11.6081867662439, 12.124355652982143, 12.619429464123964, 13.095800853708795, 13.555441711725958, 14.0, 14.430869689661813, 14.8492424049175, 15.256146302392361, 15.652475842498529, 16.03901493234544, 16.416455159382004, 16.785410331594523, 17.146428199482248, 17.500000000000004, 17.84656829757475, 18.186533479473212, 18.520259177452136, 18.848076824970768, 19.170289512680814, 19.487175269905077, 19.79898987322333, 20.105969262883104, 20.408331631958553, 20.70627924084866, 21.0, 21.28966885604377, 21.57544901039142, 21.8574929943944, 22.135943621178658, 22.410934831014973, 22.682592444427513, 22.951034835057, 23.2163735324878, 23.47871376374779, 23.738154940938443, 23.994791101403656, 24.248711305964285, 24.500000000000004, 24.748737341529168, 24.99499949989998, 25.23885892824793, 25.480384612481817, 25.71964229922337, 25.95669470483482, 26.19160170741759, 26.424420523447623, 26.65520587052368, 26.884010117540132, 27.110883423451916, 27.335873865673292, 27.559027559041336, 27.780388766178206, 28.0, 28.217902119044922, 28.434134416225866, 28.64873470155358, 28.861739379323627, 29.073183520213266, 29.283100928692647, 29.491524206117255, 29.698484809835, 29.90401310861136, 30.10813843464919, 30.310889132455355, 30.512292604784722, 30.71237535587243, 30.911163032147467, 31.108680460604567, 31.304951684997057, 31.500000000000004, 31.693847983480964, 31.886517527005047, 32.07802986469088, 32.268405600525114, 32.45766473423497, 32.64582668581086, 32.83291031876401, 33.01893396219811, 33.20391543176798, 33.3878720495931, 33.570820663189046, 33.75277766347535, 33.93375900191431, 34.11378020683137, 34.292856398964496, 34.47100230628637, 34.64823227814083, 34.824560298731704, 35.00000000000001, 35.17456467392312], [0.0, 3.517456467392312, 4.974434641243164, 6.092413314935225, 7.034912934784624, 7.865271768985482, 8.615973537563821, 9.306315060215834, 9.948869282486328, 10.552369402176936, 11.123174007449494, 11.666083318749273, 12.18482662987045, 12.682369652395408, 13.161116973874217, 13.623050319219994, 14.069825869569248, 14.502844548570465, 14.923303923729494, 15.33223727966666, 15.730543537970965, 16.119010515537237, 16.49833324914975, 16.86912860820025, 17.231947075127643, 17.58728233696156, 17.935579165446544, 18.27723994480567, 18.612630120431668, 18.942082778828734, 19.26590252233204, 19.584368766952895, 19.897738564972656, 20.206249033405488, 20.510119453577058, 20.80955309467265, 21.10473880435387, 21.395852401809098, 21.683057902426956, 21.96650859831849, 22.246348014898988, 22.52271076047464, 22.795723283107296, 23.06550454683357, 23.332166637498545, 23.595815306956446, 23.856550463132766, 24.114466612388508, 24.3696532597409, 24.622195271746186, 24.87217320621582, 25.119663612397364, 25.364739304790817, 25.60746961337649, 25.84792061269146, 26.086155331899718, 26.322233947748433, 26.556213962084282, 26.78815036541344, 27.018095787823395, 27.246100638439987, 27.47221323446657, 27.69647992074083, 27.9189451806475, 28.139651739138497, 28.35864065853651, 28.57595142773028, 28.791622045310337, 29.00568909714093, 29.218187828816493, 29.429152213409076, 29.638615014875445, 29.846607847458987, 30.053161231391282, 30.258304645171382, 30.462066574676122, 30.66447455933332, 30.865555235569637, 31.065334377727215, 31.263836936626962, 31.46108707594193, 31.65710820653081, 31.851923018869687, 32.0455535137092, 32.238021031074474, 32.429346277715815, 32.61954935311033, 32.80864977410683, 32.9966664982995, 33.183617946209544, 33.369522022348484, 33.55439613523093, 33.7382572164005, 33.92112173852746, 34.10300573263302, 34.2839248044911, 34.463894150255285, 34.64292857135494, 34.82104248870215, 34.99824995624782, 35.17456467392312, 35.35000000000001]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"A = 4.0\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.4, 0.565685424949238, 0.692820323027551, 0.8, 0.894427190999916, 0.9797958971132713, 1.0583005244258363, 1.131370849898476, 1.2, 1.2649110640673518, 1.32664991614216, 1.385640646055102, 1.4422205101855958, 1.4966629547095767, 1.5491933384829666, 1.6, 1.6492422502470643, 1.697056274847714, 1.7435595774162698, 1.788854381999832, 1.8330302779823362, 1.876166303929372, 1.918332609325088, 1.9595917942265426, 2.0, 2.039607805437114, 2.078460969082653, 2.1166010488516727, 2.154065922853802, 2.1908902300206643, 2.227105745132009, 2.262741699796952, 2.297825058615212, 2.3323807579381204, 2.3664319132398464, 2.4, 2.433105012119288, 2.4657656011875906, 2.4979991993593598, 2.5298221281347035, 2.5612496949731396, 2.5922962793631443, 2.6229754097208002, 2.65329983228432, 2.6832815729997477, 2.7129319932501073, 2.7422618401604177, 2.771281292110204, 2.8000000000000003, 2.8284271247461903, 2.8565713714171403, 2.8844410203711917, 2.9120439557122078, 2.939387691339814, 2.9664793948382653, 2.9933259094191533, 3.0199337741083, 3.0463092423455636, 3.0724582991474434, 3.098386676965933, 3.1240998703626617, 3.149603149604724, 3.1749015732775088, 3.2, 3.2249030993194197, 3.249615361854384, 3.2741411087489802, 3.2984845004941286, 3.32264954516723, 3.3466401061363023, 3.3704599092705436, 3.394112549695428, 3.4176014981270124, 3.4409301068170506, 3.464101615137755, 3.4871191548325395, 3.509985754956849, 3.532704346531139, 3.5552777669262356, 3.577708763999664, 3.6, 3.622154055254967, 3.6441734316577197, 3.6660605559646724, 3.687817782917155, 3.709447398198282, 3.7309516212355263, 3.752332607858744, 3.7735924528226414, 3.794733192202055, 3.8157568056677826, 3.836665218650176, 3.8574603043971822, 3.8781438859330635, 3.8987177379235853, 3.9191835884530852, 3.9395431207184424, 3.9597979746446663, 3.9799497484264803, 4.0, 4.019950248448357], [0.0, 0.565685424949238, 0.7999999999999999, 0.9797958971132713, 1.131370849898476, 1.2649110640673518, 1.3856406460551018, 1.4966629547095764, 1.5999999999999999, 1.697056274847714, 1.7888543819998317, 1.876166303929372, 1.9595917942265426, 2.039607805437114, 2.116601048851672, 2.1908902300206643, 2.262741699796952, 2.33238075793812, 2.4, 2.4657656011875906, 2.5298221281347035, 2.5922962793631443, 2.6532998322843198, 2.7129319932501073, 2.7712812921102037, 2.8284271247461903, 2.8844410203711917, 2.939387691339814, 2.993325909419153, 3.0463092423455636, 3.098386676965933, 3.1496031496047245, 3.1999999999999997, 3.249615361854384, 3.2984845004941286, 3.3466401061363023, 3.394112549695428, 3.4409301068170506, 3.487119154832539, 3.5327043465311387, 3.5777087639996634, 3.622154055254967, 3.6660605559646724, 3.709447398198281, 3.752332607858744, 3.7947331922020546, 3.8366652186501757, 3.878143885933063, 3.9191835884530852, 3.959797974644666, 4.0, 4.039801975344831, 4.079215610874228, 4.118252056394801, 4.156921938165306, 4.1952353926806065, 4.233202097703344, 4.2708313008125245, 4.308131845707603, 4.345112196480086, 4.381780460041329, 4.418144406874904, 4.454211490264017, 4.48998886412873, 4.525483399593904, 4.560701700396551, 4.595650117230423, 4.63033476111609, 4.66476151587624, 4.698936049788292, 4.732863826479693, 4.766550115125193, 4.8, 4.833218389437829, 4.866210024238575, 4.898979485566356, 4.931531202375181, 4.963869458396343, 4.995998398718719, 5.027922035990614, 5.059644256269407, 5.091168824543142, 5.122499389946279, 5.15363949069005, 5.184592558726289, 5.215361924162119, 5.2459508194416005, 5.276362383309167, 5.3065996645686395, 5.336665625650533, 5.366563145999495, 5.396295025292816, 5.4258639865002145, 5.455272678794342, 5.4845236803208355, 5.513619500836088, 5.542562584220407, 5.571355310873648, 5.6, 5.628498911788116, 5.656854249492381, 5.685068161420759], [0.0, 0.692820323027551, 0.9797958971132713, 1.2000000000000004, 1.385640646055102, 1.549193338482967, 1.6970562748477143, 1.8330302779823362, 1.9595917942265426, 2.078460969082653, 2.1908902300206647, 2.297825058615212, 2.400000000000001, 2.4979991993593598, 2.5922962793631443, 2.6832815729997477, 2.771281292110204, 2.8565713714171403, 2.9393876913398143, 3.0199337741083006, 3.098386676965934, 3.174901573277509, 3.2496153618543846, 3.3226495451672307, 3.3941125496954285, 3.4641016151377553, 3.5327043465311396, 3.6000000000000005, 3.6660605559646724, 3.7309516212355267, 3.7947331922020555, 3.8574603043971827, 3.9191835884530852, 3.9799497484264807, 4.039801975344832, 4.09878030638384, 4.156921938165306, 4.214261501141096, 4.270831300812525, 4.326661530556788, 4.3817804600413295, 4.436214602563767, 4.489988864128731, 4.543126676640219, 4.595650117230424, 4.6475800154489, 4.698936049788293, 4.749736834815168, 4.800000000000002, 4.849742261192857, 4.898979485566357, 4.947726750741194, 4.9959983987187195, 5.043808085167398, 5.091168824543143, 5.1380930314660525, 5.184592558726289, 5.230678732248809, 5.276362383309169, 5.321653878260029, 5.366563145999495, 5.411099703387474, 5.455272678794342, 5.499090833947009, 5.542562584220408, 5.585696017507577, 5.628498911788117, 5.670978751503131, 5.713142742834281, 5.754997827975265, 5.796550698475777, 5.83780780773057, 5.8787753826796285, 5.9194594347794975, 5.959865770300536, 6.000000000000001, 6.039867548216601, 6.079473661428266, 6.1188234163113435, 6.157921727336262, 6.196773353931868, 6.235382907247959, 6.27375485654325, 6.311893535223801, 6.349803146555018, 6.387487769068526, 6.424951361683605, 6.462197768561406, 6.499230723708769, 6.536053855347277, 6.572670690061994, 6.609084656743323, 6.645299090334461, 6.681317235396028, 6.717142249498667, 6.752777206453653, 6.788225099390857, 6.823488843692794, 6.8585712797928995, 6.893475175845635, 6.9282032302755105, 6.962758074211686], [0.0, 0.8, 1.131370849898476, 1.385640646055102, 1.6, 1.788854381999832, 1.9595917942265426, 2.1166010488516727, 2.262741699796952, 2.4, 2.5298221281347035, 2.65329983228432, 2.771281292110204, 2.8844410203711917, 2.9933259094191533, 3.098386676965933, 3.2, 3.2984845004941286, 3.394112549695428, 3.4871191548325395, 3.577708763999664, 3.6660605559646724, 3.752332607858744, 3.836665218650176, 3.9191835884530852, 4.0, 4.079215610874228, 4.156921938165306, 4.233202097703345, 4.308131845707604, 4.381780460041329, 4.454211490264018, 4.525483399593904, 4.595650117230424, 4.664761515876241, 4.732863826479693, 4.8, 4.866210024238576, 4.931531202375181, 4.9959983987187195, 5.059644256269407, 5.122499389946279, 5.184592558726289, 5.2459508194416005, 5.30659966456864, 5.366563145999495, 5.4258639865002145, 5.4845236803208355, 5.542562584220408, 5.6000000000000005, 5.656854249492381, 5.713142742834281, 5.768882040742383, 5.8240879114244155, 5.878775382679628, 5.932958789676531, 5.986651818838307, 6.0398675482166, 6.092618484691127, 6.144916598294887, 6.196773353931866, 6.248199740725323, 6.299206299209448, 6.3498031465550175, 6.4, 6.449806198638839, 6.499230723708768, 6.5482822174979605, 6.596969000988257, 6.64529909033446, 6.6932802122726045, 6.740919818541087, 6.788225099390856, 6.835202996254025, 6.881860213634101, 6.92820323027551, 6.974238309665079, 7.019971509913698, 7.065408693062278, 7.110555533852471, 7.155417527999328, 7.2, 7.244308110509934, 7.288346863315439, 7.332121111929345, 7.37563556583431, 7.418894796396564, 7.4619032424710525, 7.504665215717488, 7.547184905645283, 7.58946638440411, 7.631513611335565, 7.673330437300352, 7.7149206087943645, 7.756287771866127, 7.797435475847171, 7.8383671769061705, 7.879086241436885, 7.919595949289333, 7.959899496852961, 8.0, 8.039900496896713], [0.0, 0.894427190999916, 1.2649110640673518, 1.549193338482967, 1.788854381999832, 2.0000000000000004, 2.1908902300206647, 2.366431913239847, 2.5298221281347035, 2.6832815729997477, 2.8284271247461903, 2.9664793948382657, 3.098386676965934, 3.22490309931942, 3.3466401061363023, 3.4641016151377544, 3.577708763999664, 3.687817782917155, 3.7947331922020555, 3.8987177379235862, 4.000000000000001, 4.09878030638384, 4.1952353926806065, 4.289522117905444, 4.3817804600413295, 4.47213595499958, 4.560701700396552, 4.647580015448901, 4.732863826479694, 4.8166378315169185, 4.898979485566357, 4.979959839195494, 5.059644256269407, 5.1380930314660525, 5.21536192416212, 5.291502622129181, 5.366563145999495, 5.440588203494178, 5.513619500836089, 5.585696017507577, 5.656854249492381, 5.727128425310542, 5.796550698475777, 5.865151319446072, 5.9329587896765315, 6.0, 6.066300355241241, 6.131883886702357, 6.196773353931868, 6.260990336999412, 6.324555320336759, 6.387487769068526, 6.44980619863884, 6.511528238439884, 6.572670690061994, 6.6332495807108005, 6.6932802122726045, 6.752777206453653, 6.811754546370562, 6.870225614927067, 6.928203230275509, 6.985699678629192, 7.042726744663604, 7.0992957397195395, 7.155417527999328, 7.211102550927978, 7.266360849833981, 7.321202087089251, 7.37563556583431, 7.429670248402685, 7.4833147735478835, 7.53657747256671, 7.589466384404111, 7.64198926981712, 7.694153624668538, 7.745966692414834, 7.7974354758471724, 7.848566748139434, 7.899367063252601, 7.949842765740717, 8.000000000000002, 8.049844718999244, 8.099382692526635, 8.148619514985345, 8.19756061276768, 8.246211251235321, 8.29457654133109, 8.342661445845685, 8.390470785361213, 8.438009243891594, 8.485281374238571, 8.532291603080617, 8.579044235810889, 8.62554346113913, 8.671793355471522, 8.717797887081348, 8.763560920082659, 8.809086218218098, 8.854377448471462, 8.899438184514796, 8.94427190999916, 8.988882021697695], [0.0, 0.9797958971132713, 1.3856406460551018, 1.6970562748477143, 1.9595917942265426, 2.1908902300206647, 2.4000000000000004, 2.5922962793631443, 2.7712812921102037, 2.939387691339814, 3.0983866769659336, 3.2496153618543846, 3.3941125496954285, 3.532704346531139, 3.666060555964672, 3.794733192202055, 3.9191835884530852, 4.039801975344831, 4.156921938165306, 4.270831300812525, 4.3817804600413295, 4.48998886412873, 4.595650117230424, 4.698936049788292, 4.800000000000001, 4.898979485566357, 4.9959983987187195, 5.091168824543143, 5.184592558726289, 5.276362383309168, 5.366563145999495, 5.455272678794342, 5.542562584220407, 5.628498911788117, 5.713142742834281, 5.796550698475776, 5.878775382679628, 5.959865770300536, 6.0398675482166, 6.118823416311343, 6.196773353931867, 6.27375485654325, 6.349803146555018, 6.424951361683604, 6.499230723708769, 6.572670690061993, 6.64529909033446, 6.717142249498666, 6.788225099390857, 6.858571279792899, 6.92820323027551, 6.997142273814362, 7.065408693062278, 7.1330218000508046, 7.2, 7.266360849833981, 7.332121111929344, 7.397296803562772, 7.4619032424710525, 7.525955088890711, 7.58946638440411, 7.652450587883597, 7.714920608794364, 7.776888838089433, 7.8383671769061705, 7.899367063252599, 7.95989949685296, 8.019975062305368, 8.079603950689663, 8.138795979750322, 8.19756061276768, 8.255906976220118, 8.313843876330612, 8.37137981458254, 8.42852300228219, 8.485281374238571, 8.54166260162505, 8.597674104081872, 8.653323061113575, 8.708616422830897, 8.763560920082659, 8.818163074019441, 8.872429205127535, 8.926365441768558, 8.97997772825746, 9.033271832508973, 9.086253353280439, 9.138927727036691, 9.191300234460847, 9.243376006633074, 9.2951600308978, 9.346657156438338, 9.397872099576585, 9.448809448814174, 9.499473669630335, 9.549869109050658, 9.600000000000001, 9.649870465451857, 9.699484522385713, 9.748846085563153, 9.797958971132713, 9.846826900072939], [0.0, 1.0583005244258363, 1.4966629547095764, 1.8330302779823362, 2.1166010488516727, 2.366431913239847, 2.5922962793631443, 2.8000000000000003, 2.993325909419153, 3.1749015732775088, 3.3466401061363023, 3.509985754956849, 3.6660605559646724, 3.815756805667783, 3.9597979746446663, 4.098780306383839, 4.233202097703345, 4.363484845854286, 4.48998886412873, 4.613025037868319, 4.732863826479694, 4.849742261192857, 4.963869458396343, 5.075431016179809, 5.184592558726289, 5.291502622129181, 5.396295025292817, 5.499090833947008, 5.6000000000000005, 5.6991227395100035, 5.796550698475775, 5.892367945062494, 5.986651818838306, 6.079473661428266, 6.1708994482166055, 6.260990336999411, 6.3498031465550175, 6.437390775772433, 6.523802572120037, 6.609084656743323, 6.6932802122726045, 6.776429738438967, 6.8585712797928995, 6.9397406291589885, 7.019971509913698, 7.099295739719539, 7.177743377970545, 7.255342858886822, 7.332121111929345, 7.408103670980854, 7.4833147735478835, 7.557777451076475, 7.631513611335566, 7.70454411370329, 7.776888838089433, 7.848566748139434, 7.919595949289333, 7.989993742175272, 8.059776671843954, 8.12896057316063, 8.197560612767678, 8.26559132790873, 8.333066662399863, 8.4, 8.46640419540669, 8.532291603080616, 8.597674104081872, 8.662563131083086, 8.726969691708572, 8.790904390334365, 8.854377448471462, 8.917398723843181, 8.97997772825746, 9.042123644365851, 9.103845341392834, 9.16515138991168, 9.226050075736637, 9.28654941299512, 9.34665715643834, 9.406380813043878, 9.465727652959387, 9.524704719832526, 9.583318840568753, 9.64157663455516, 9.699484522385713, 9.757048734120374, 9.814275317108239, 9.871170143402454, 9.927738916792686, 9.983987179478948, 10.039920318408907, 10.09554357129917, 10.150862032359617, 10.20588065773846, 10.26060427070453, 10.3150375665821, 10.369185117452577, 10.423051376636307, 10.476640682967036, 10.529957264870548, 10.583005244258363, 10.635788640246666], [0.0, 1.131370849898476, 1.5999999999999999, 1.9595917942265426, 2.262741699796952, 2.5298221281347035, 2.7712812921102037, 2.993325909419153, 3.1999999999999997, 3.394112549695428, 3.5777087639996634, 3.752332607858744, 3.9191835884530852, 4.079215610874228, 4.233202097703344, 4.381780460041329, 4.525483399593904, 4.66476151587624, 4.8, 4.931531202375181, 5.059644256269407, 5.184592558726289, 5.3065996645686395, 5.4258639865002145, 5.542562584220407, 5.656854249492381, 5.768882040742383, 5.878775382679628, 5.986651818838306, 6.092618484691127, 6.196773353931866, 6.299206299209449, 6.3999999999999995, 6.499230723708768, 6.596969000988257, 6.6932802122726045, 6.788225099390856, 6.881860213634101, 6.974238309665078, 7.0654086930622775, 7.155417527999327, 7.244308110509934, 7.332121111929345, 7.418894796396562, 7.504665215717488, 7.589466384404109, 7.6733304373003515, 7.756287771866126, 7.8383671769061705, 7.919595949289332, 8.0, 8.079603950689663, 8.158431221748456, 8.236504112789602, 8.313843876330612, 8.390470785361213, 8.466404195406689, 8.541662601625049, 8.616263691415206, 8.690224392960172, 8.763560920082657, 8.836288813749809, 8.908422980528034, 8.97997772825746, 9.050966799187808, 9.121403400793103, 9.191300234460845, 9.26066952223218, 9.32952303175248, 9.397872099576585, 9.465727652959385, 9.533100230250387, 9.6, 9.666436778875658, 9.73242004847715, 9.797958971132712, 9.863062404750362, 9.927738916792686, 9.991996797437437, 10.055844071981229, 10.119288512538814, 10.182337649086284, 10.244998779892558, 10.3072789813801, 10.369185117452577, 10.430723848324238, 10.491901638883201, 10.552724766618335, 10.613199329137279, 10.673331251301066, 10.73312629199899, 10.792590050585632, 10.851727973000429, 10.910545357588685, 10.969047360641671, 11.027239001672177, 11.085125168440815, 11.142710621747296, 11.2, 11.256997823576231, 11.313708498984761, 11.370136322841518], [0.0, 1.2, 1.697056274847714, 2.078460969082653, 2.4, 2.6832815729997477, 2.939387691339814, 3.1749015732775088, 3.394112549695428, 3.5999999999999996, 3.794733192202055, 3.97994974842648, 4.156921938165306, 4.3266615305567875, 4.48998886412873, 4.6475800154488995, 4.8, 4.947726750741192, 5.091168824543142, 5.230678732248808, 5.366563145999495, 5.499090833947008, 5.628498911788116, 5.754997827975264, 5.878775382679628, 6.0, 6.118823416311342, 6.235382907247958, 6.3498031465550175, 6.462197768561405, 6.572670690061993, 6.681317235396026, 6.788225099390856, 6.8934751758456345, 6.997142273814361, 7.099295739719539, 7.199999999999999, 7.299315036357863, 7.397296803562772, 7.493997598078078, 7.58946638440411, 7.683749084919419, 7.776888838089433, 7.8689262291624, 7.95989949685296, 8.049844718999243, 8.138795979750322, 8.226785520481252, 8.313843876330612, 8.4, 8.48528137423857, 8.56971411425142, 8.653323061113575, 8.736131867136622, 8.818163074019441, 8.899438184514796, 8.97997772825746, 9.0598013223249, 9.13892772703669, 9.21737489744233, 9.295160030897799, 9.372299611087985, 9.448809448814172, 9.524704719832526, 9.6, 9.674709297958259, 9.748846085563152, 9.82242332624694, 9.895453501482384, 9.96794863550169, 10.039920318408907, 10.111379727811629, 10.182337649086284, 10.252804494381037, 10.322790320451151, 10.392304845413264, 10.461357464497617, 10.529957264870546, 10.598113039593418, 10.665833300778706, 10.73312629199899, 10.8, 10.8664621657649, 10.932520294973157, 10.998181667894016, 11.063453348751464, 11.128342194594845, 11.192854863706579, 11.256997823576231, 11.320777358467923, 11.384199576606164, 11.447270417003347, 11.509995655950528, 11.572380913191546, 11.63443165779919, 11.696153213770755, 11.757550765359255, 11.818629362155326, 11.879393923933998, 11.93984924527944, 12.0, 12.05985074534507], [0.0, 1.2649110640673518, 1.7888543819998317, 2.1908902300206647, 2.5298221281347035, 2.8284271247461903, 3.0983866769659336, 3.3466401061363023, 3.5777087639996634, 3.794733192202055, 4.0, 4.1952353926806065, 4.3817804600413295, 4.560701700396552, 4.732863826479693, 4.898979485566356, 5.059644256269407, 5.215361924162119, 5.366563145999495, 5.513619500836089, 5.656854249492381, 5.796550698475776, 5.932958789676531, 6.066300355241241, 6.196773353931867, 6.324555320336759, 6.44980619863884, 6.572670690061994, 6.6932802122726045, 6.811754546370561, 6.928203230275509, 7.042726744663604, 7.155417527999327, 7.266360849833981, 7.37563556583431, 7.483314773547883, 7.58946638440411, 7.694153624668538, 7.797435475847172, 7.8993670632526, 8.0, 8.099382692526635, 8.19756061276768, 8.294576541331088, 8.390470785361213, 8.48528137423857, 8.579044235810887, 8.67179335547152, 8.763560920082659, 8.854377448471462, 8.94427190999916, 9.033271832508973, 9.121403400793104, 9.208691546577072, 9.2951600308978, 9.38083151964686, 9.465727652959385, 9.549869109050658, 9.633275663033837, 9.715966241192895, 9.797958971132712, 9.879271228182775, 9.959919678390985, 10.039920318408907, 10.119288512538814, 10.198039027185569, 10.276186062932103, 10.353743284435827, 10.430723848324238, 10.507140429250958, 10.583005244258363, 10.658330075579382, 10.73312629199899, 10.807404868885037, 10.881176406988354, 10.954451150103322, 11.027239001672179, 11.099549540409287, 11.171392035015154, 11.242775458044157, 11.313708498984761, 11.384199576606166, 11.454256850621084, 11.523888232710346, 11.593101396951552, 11.661903789690601, 11.730302638892145, 11.798304963002101, 11.865917579353061, 11.933147112141038, 12.0, 12.066482503198685, 12.132600710482482, 12.198360545581526, 12.263767773404714, 12.328828005937952, 12.393546707863734, 12.45792920191795, 12.521980673998822, 12.58570617804182, 12.649110640673518, 12.712198865656564], [0.0, 1.32664991614216, 1.876166303929372, 2.297825058615212, 2.65329983228432, 2.9664793948382657, 3.2496153618543846, 3.509985754956849, 3.752332607858744, 3.97994974842648, 4.1952353926806065, 4.4, 4.595650117230424, 4.7833042972405595, 4.963869458396343, 5.138093031466052, 5.30659966456864, 5.469917732470938, 5.628498911788116, 5.782732917920385, 5.9329587896765315, 6.079473661428266, 6.222539674441619, 6.362389488234747, 6.499230723708769, 6.6332495807108005, 6.764613810115106, 6.893475175845635, 7.019971509913698, 7.144228439796701, 7.26636084983398, 7.386474125047756, 7.504665215717488, 7.621023553303061, 7.735631842325487, 7.848566748139434, 7.95989949685296, 8.069696400732807, 8.178019320104351, 8.284926070883193, 8.390470785361213, 8.494704232638123, 8.597674104081872, 8.699425268372618, 8.8, 8.899438184514796, 8.997777503361595, 9.09505360072166, 9.191300234460847, 9.28654941299512, 9.38083151964686, 9.474175425861612, 9.566608594481119, 9.65815717411971, 9.748846085563153, 9.838699100999076, 9.927738916792686, 10.015987220439133, 10.103464752252073, 10.190191362285598, 10.276186062932103, 10.361467077590895, 10.446051885760477, 10.529957264870548, 10.61319932913728, 10.69579356569675, 10.777754868245985, 10.859097568398584, 10.939835464941876, 11.01998185116473, 11.099549540409289, 11.178550889985697, 11.256997823576231, 11.334901852243805, 11.412274094149685, 11.489125293076059, 11.56546583584077, 11.6413057686842, 11.71665481270145, 11.791522378386942, 11.865917579353063, 11.939849245279442, 12.013325934144968, 12.086355943790503, 12.158947322856532, 12.231107881136525, 12.30284519938376, 12.374166638606416, 12.445079348883239, 12.515590277729613, 12.58570617804182, 12.655433615645101, 12.724778976469494, 12.793748473375583, 12.862348152650823, 12.93058390019569, 12.998461447417538, 13.065986376848862, 13.133164127505603, 13.200000000000003, 13.266499161421601, 13.332666649999169], [0.0, 1.385640646055102, 1.9595917942265426, 2.400000000000001, 2.771281292110204, 3.098386676965934, 3.3941125496954285, 3.6660605559646724, 3.9191835884530852, 4.156921938165306, 4.3817804600413295, 4.595650117230424, 4.800000000000002, 4.9959983987187195, 5.184592558726289, 5.366563145999495, 5.542562584220408, 5.713142742834281, 5.8787753826796285, 6.039867548216601, 6.196773353931868, 6.349803146555018, 6.499230723708769, 6.645299090334461, 6.788225099390857, 6.9282032302755105, 7.065408693062279, 7.200000000000001, 7.332121111929345, 7.461903242471053, 7.589466384404111, 7.714920608794365, 7.8383671769061705, 7.9598994968529615, 8.079603950689664, 8.19756061276768, 8.313843876330612, 8.428523002282192, 8.54166260162505, 8.653323061113577, 8.763560920082659, 8.872429205127535, 8.979977728257461, 9.086253353280439, 9.191300234460847, 9.2951600308978, 9.397872099576587, 9.499473669630335, 9.600000000000003, 9.699484522385713, 9.797958971132713, 9.895453501482388, 9.991996797437439, 10.087616170334796, 10.182337649086286, 10.276186062932105, 10.369185117452577, 10.461357464497619, 10.552724766618338, 10.643307756520057, 10.73312629199899, 10.822199406774947, 10.910545357588685, 10.998181667894018, 11.085125168440817, 11.171392035015154, 11.256997823576233, 11.341957503006261, 11.426285485668561, 11.50999565595053, 11.593101396951553, 11.67561561546114, 11.757550765359257, 11.838918869558995, 11.919731540601072, 12.000000000000002, 12.079735096433202, 12.158947322856532, 12.237646832622687, 12.315843454672525, 12.393546707863736, 12.470765814495918, 12.5475097130865, 12.623787070447602, 12.699606293110037, 12.774975538137053, 12.84990272336721, 12.924395537122813, 12.998461447417538, 13.072107710694555, 13.145341380123988, 13.218169313486646, 13.290598180668923, 13.362634470792056, 13.434284498997334, 13.505554412907307, 13.576450198781714, 13.646977687385588, 13.717142559585799, 13.78695035169127, 13.856406460551021, 13.925516148423371], [0.0, 1.4422205101855958, 2.039607805437114, 2.4979991993593598, 2.8844410203711917, 3.22490309931942, 3.532704346531139, 3.815756805667783, 4.079215610874228, 4.3266615305567875, 4.560701700396552, 4.7833042972405595, 4.9959983987187195, 5.200000000000001, 5.396295025292817, 5.585696017507576, 5.768882040742383, 5.946427498927402, 6.118823416311343, 6.2864934582006855, 6.44980619863884, 6.609084656743323, 6.764613810115105, 6.916646586316234, 7.065408693062278, 7.211102550927979, 7.353910524340095, 7.493997598078079, 7.631513611335566, 7.76659513557904, 7.899367063252599, 8.029943959953894, 8.158431221748456, 8.284926070883193, 8.409518416651457, 8.532291603080617, 8.653323061113575, 8.772684879784524, 8.890444308357148, 9.006664199358163, 9.121403400793104, 9.234717104492159, 9.34665715643834, 9.457272334029511, 9.566608594481119, 9.674709297958259, 9.781615408509987, 9.88736567544662, 9.991996797437439, 10.09554357129917, 10.19803902718557, 10.299514551666988, 10.400000000000002, 10.499523798725352, 10.598113039593418, 10.695793565696752, 10.792590050585634, 10.88852607105296, 10.983624174196786, 11.077905939300983, 11.171392035015153, 11.26410227226298, 11.356055653262713, 11.447270417003349, 11.537764081484767, 11.627553482998906, 11.71665481270145, 11.805083650698965, 11.892854997854805, 11.979983305497552, 12.066482503198687, 12.15236602477065, 12.237646832622685, 12.32233744059949, 12.406449935416658, 12.489995996796797, 12.572986916401371, 12.655433615645101, 12.737346662472529, 12.818736287169653, 12.89961239727768, 12.979984591670362, 13.059862173851608, 13.139254164525473, 13.218169313486646, 13.29661611087573, 13.374602797840392, 13.452137376640191, 13.52922762023021, 13.605881081355959, 13.682105101189656, 13.757906817535872, 13.833293172632468, 13.90827092057097, 13.982846634358829, 14.057026712644463, 14.130817386124557, 14.204224723651766, 14.277254638059798, 14.34991289172168, 14.422205101855958, 14.494136745594753], [0.0, 1.4966629547095767, 2.116601048851672, 2.5922962793631443, 2.9933259094191533, 3.3466401061363023, 3.666060555964672, 3.9597979746446663, 4.233202097703344, 4.48998886412873, 4.732863826479693, 4.963869458396343, 5.184592558726289, 5.396295025292817, 5.6, 5.796550698475775, 5.986651818838307, 6.170899448216605, 6.3498031465550175, 6.523802572120037, 6.6932802122726045, 6.858571279792899, 7.019971509913698, 7.177743377970545, 7.332121111929344, 7.483314773547883, 7.631513611335565, 7.776888838089433, 7.919595949289333, 8.059776671843954, 8.197560612767678, 8.333066662399863, 8.466404195406689, 8.597674104081872, 8.726969691708572, 8.854377448471462, 8.97997772825746, 9.103845341392834, 9.226050075736637, 9.346657156438338, 9.465727652959385, 9.583318840568753, 9.699484522385713, 9.814275317108237, 9.927738916792686, 10.039920318408905, 10.150862032359617, 10.260604270704528, 10.369185117452577, 10.476640682967036, 10.583005244258363, 10.688311372709911, 10.792590050585634, 10.89587077750099, 10.998181667894016, 11.099549540409287, 11.2, 11.299557513460428, 11.398245479020007, 11.49608629055993, 11.59310139695155, 11.689311356961966, 11.784735890124987, 11.879393923933998, 11.973303637676613, 12.066482503198683, 12.15894732285653, 12.250714264890844, 12.34179889643321, 12.432216214336043, 12.521980673998822, 12.611106216347556, 12.699606293110035, 12.787493890516624, 12.874781551544864, 12.96148139681572, 13.047605144240073, 13.133164127505603, 13.218169313486646, 13.302631318652713, 13.386560424545209, 13.46996659238619, 13.552859476877934, 13.635248439247448, 13.717142559585797, 13.798550648528272, 13.879481258317979, 13.959942693292119, 14.039943019827396, 14.119490075778232, 14.198591479439077, 14.277254638059798, 14.35548675594109, 14.433294842134973, 14.510685717773644, 14.587666023048374, 14.664242223858688, 14.740420618150624, 14.816207341961707, 14.891608375189028, 14.966629547095765, 15.041276541570534], [0.0, 1.5491933384829666, 2.1908902300206643, 2.6832815729997477, 3.098386676965933, 3.4641016151377544, 3.794733192202055, 4.098780306383839, 4.381780460041329, 4.6475800154488995, 4.898979485566356, 5.138093031466052, 5.366563145999495, 5.585696017507576, 5.796550698475775, 5.999999999999999, 6.196773353931866, 6.387487769068525, 6.572670690061993, 6.752777206453653, 6.928203230275509, 7.099295739719539, 7.26636084983398, 7.429670248402684, 7.58946638440411, 7.745966692414833, 7.899367063252599, 8.049844718999243, 8.197560612767678, 8.342661445845684, 8.48528137423857, 8.625543461139129, 8.763560920082657, 8.899438184514796, 9.033271832508971, 9.16515138991168, 9.295160030897799, 9.423375191511797, 9.549869109050658, 9.674709297958259, 9.797958971132712, 9.919677414109795, 10.039920318408907, 10.158740079360234, 10.276186062932103, 10.392304845413262, 10.507140429250956, 10.620734437881403, 10.73312629199899, 10.844353369380766, 10.954451150103322, 11.063453348751464, 11.171392035015153, 11.278297743897348, 11.384199576606164, 11.489125293076057, 11.59310139695155, 11.696153213770756, 11.798304963002101, 11.899579824514811, 11.999999999999998, 12.099586769803338, 12.198360545581524, 12.296340919151517, 12.393546707863733, 12.489995996796795, 12.585706178041818, 12.680693987317886, 12.77497553813705, 12.868566353716329, 12.96148139681572, 13.053735097664575, 13.145341380123986, 13.236313686219436, 13.326664999166143, 13.416407864998737, 13.505554412907307, 13.594116374373142, 13.682105101189656, 13.769531582446804, 13.856406460551018, 13.9427400463467, 14.028542333400146, 14.113823011501879, 14.198591479439077, 14.282856857085699, 14.366627996854376, 14.449913494550755, 14.53272169966796, 14.615060725156086, 14.696938456699067, 14.778362561528931, 14.859340496805368, 14.939879517586478, 15.019986684414869, 15.099668870541498, 15.17893276880822, 15.257784898208522, 15.33623161014465, 15.414279094398156, 15.491933384829666, 15.569200364822851], [0.0, 1.6, 2.262741699796952, 2.771281292110204, 3.2, 3.577708763999664, 3.9191835884530852, 4.233202097703345, 4.525483399593904, 4.8, 5.059644256269407, 5.30659966456864, 5.542562584220408, 5.768882040742383, 5.986651818838307, 6.196773353931866, 6.4, 6.596969000988257, 6.788225099390856, 6.974238309665079, 7.155417527999328, 7.332121111929345, 7.504665215717488, 7.673330437300352, 7.8383671769061705, 8.0, 8.158431221748456, 8.313843876330612, 8.46640419540669, 8.616263691415208, 8.763560920082657, 8.908422980528035, 9.050966799187808, 9.191300234460847, 9.329523031752482, 9.465727652959385, 9.6, 9.732420048477152, 9.863062404750362, 9.991996797437439, 10.119288512538814, 10.244998779892558, 10.369185117452577, 10.491901638883201, 10.61319932913728, 10.73312629199899, 10.851727973000429, 10.969047360641671, 11.085125168440817, 11.200000000000001, 11.313708498984761, 11.426285485668561, 11.537764081484767, 11.648175822848831, 11.757550765359255, 11.865917579353061, 11.973303637676613, 12.0797350964332, 12.185236969382254, 12.289833196589774, 12.393546707863733, 12.496399481450647, 12.598412598418896, 12.699606293110035, 12.8, 12.899612397277679, 12.998461447417537, 13.096564434995921, 13.193938001976514, 13.29059818066892, 13.386560424545209, 13.481839637082174, 13.576450198781712, 13.67040599250805, 13.763720427268202, 13.85640646055102, 13.948476619330158, 14.039943019827396, 14.130817386124557, 14.221111067704943, 14.310835055998655, 14.4, 14.488616221019868, 14.576693726630879, 14.66424222385869, 14.75127113166862, 14.837789592793127, 14.923806484942105, 15.009330431434975, 15.094369811290566, 15.17893276880822, 15.26302722267113, 15.346660874600705, 15.429841217588729, 15.512575543732254, 15.594870951694341, 15.676734353812341, 15.75817248287377, 15.839191898578665, 15.919798993705921, 16.0, 16.079800993793427], [0.0, 1.6492422502470643, 2.33238075793812, 2.8565713714171403, 3.2984845004941286, 3.687817782917155, 4.039801975344831, 4.363484845854286, 4.66476151587624, 4.947726750741192, 5.215361924162119, 5.469917732470938, 5.713142742834281, 5.946427498927402, 6.170899448216605, 6.387487769068525, 6.596969000988257, 6.8, 6.997142273814361, 7.188880302244572, 7.37563556583431, 7.557777451076474, 7.735631842325486, 7.909487973314076, 8.079603950689663, 8.246211251235321, 8.409518416651457, 8.56971411425142, 8.726969691708572, 8.881441324469808, 9.033271832508971, 9.182592226599198, 9.32952303175248, 9.47417542586161, 9.616652224137047, 9.757048734120374, 9.895453501482384, 10.031948963187562, 10.166612021711067, 10.299514551666988, 10.430723848324238, 10.56030302595527, 10.688311372709911, 10.814804667676619, 10.939835464941876, 11.063453348751464, 11.18570516328765, 11.306635220082056, 11.426285485668561, 11.54469575172945, 11.661903789690601, 11.777945491468367, 11.892854997854805, 12.006664815842909, 12.119405926034494, 12.231107881136525, 12.34179889643321, 12.451505933018705, 12.560254774486067, 12.668070097690492, 12.77497553813705, 12.880993750483695, 12.98614646459834, 13.090454537562858, 13.193938001976514, 13.296616110875728, 13.398507379555381, 13.499629624548964, 13.6, 13.699635031634967, 13.798550648528273, 13.896762212832167, 13.994284547628721, 14.091131963046829, 14.187318280774559, 14.2828568570857, 14.377760604489144, 14.472042012100435, 14.565713164826501, 14.658785761446955, 14.75127113166862, 14.84318025222358, 14.934523762075576, 15.025311976794358, 15.115554902152947, 15.20526224699857, 15.29444343544413, 15.383107618423528, 15.471263684650973, 15.558920271021378, 15.646085772486357, 15.73276835143771, 15.818975946628152, 15.904716281656835, 15.98999687304535, 16.074825037928093, 16.159207901379325, 16.243152403397563, 16.32666530556684, 16.40975319741281, 16.492422502470642, 16.57467948408053], [0.0, 1.697056274847714, 2.4, 2.9393876913398143, 3.394112549695428, 3.7947331922020555, 4.156921938165306, 4.48998886412873, 4.8, 5.091168824543142, 5.366563145999495, 5.628498911788116, 5.8787753826796285, 6.118823416311343, 6.3498031465550175, 6.572670690061993, 6.788225099390856, 6.997142273814361, 7.2, 7.397296803562773, 7.589466384404111, 7.776888838089433, 7.95989949685296, 8.138795979750322, 8.313843876330612, 8.485281374238571, 8.653323061113575, 8.818163074019441, 8.97997772825746, 9.138927727036691, 9.2951600308978, 9.448809448814174, 9.6, 9.748846085563153, 9.895453501482386, 10.039920318408907, 10.182337649086284, 10.322790320451153, 10.461357464497617, 10.598113039593418, 10.73312629199899, 10.8664621657649, 10.998181667894016, 11.128342194594843, 11.256997823576231, 11.384199576606164, 11.509995655950528, 11.63443165779919, 11.757550765359257, 11.879393923933998, 12.0, 12.119405926034496, 12.237646832622685, 12.354756169184402, 12.470765814495918, 12.58570617804182, 12.699606293110035, 12.812493902437573, 12.92439553712281, 13.035336589440258, 13.145341380123986, 13.254433220624714, 13.362634470792052, 13.46996659238619, 13.576450198781712, 13.682105101189656, 13.786950351691269, 13.89100428334827, 13.994284547628721, 14.096808149364877, 14.198591479439079, 14.299650345375582, 14.4, 14.499655168313486, 14.598630072715727, 14.696938456699069, 14.794593607125545, 14.891608375189028, 14.987995196156158, 15.083766107971842, 15.178932768808222, 15.273506473629427, 15.36749816983884, 15.46091847207015, 15.553777676178866, 15.646085772486359, 15.737852458324802, 15.829087149927505, 15.91979899370592, 16.0099968769516, 16.099689437998485, 16.18888507587845, 16.277591959500644, 16.36581803638303, 16.453571040962508, 16.540858502508264, 16.627687752661224, 16.714065932620944, 16.8, 16.88549673536435, 16.970562748477143, 17.055204484262276], [0.0, 1.7435595774162698, 2.4657656011875906, 3.0199337741083006, 3.4871191548325395, 3.8987177379235862, 4.270831300812525, 4.613025037868319, 4.931531202375181, 5.230678732248808, 5.513619500836089, 5.782732917920385, 6.039867548216601, 6.2864934582006855, 6.523802572120037, 6.752777206453653, 6.974238309665079, 7.188880302244572, 7.397296803562773, 7.600000000000001, 7.7974354758471724, 7.9899937421752725, 8.178019320104351, 8.36181798414675, 8.54166260162505, 8.717797887081348, 8.89044430835715, 9.059801322324901, 9.226050075736637, 9.389355675444403, 9.549869109050658, 9.707728879609279, 9.863062404750362, 10.015987220439133, 10.16661202171107, 10.315037566582102, 10.461357464497617, 10.605658866850284, 10.748023074035524, 10.888526071052961, 11.027239001672179, 11.164228589562292, 11.29955751346043, 11.433284742365162, 11.56546583584077, 11.696153213770756, 11.825396399275588, 11.95324223798715, 12.079735096433202, 12.204917041913887, 12.328828005937956, 12.451505933018707, 12.572986916401371, 12.693305322097947, 12.812493902437575, 12.930583900195693, 13.047605144240073, 13.163586137523469, 13.278554138158269, 13.392535234226566, 13.505554412907307, 13.617635624439362, 13.728801841384412, 13.839075113604958, 13.948476619330158, 14.057026712644463, 14.16474496770062, 14.27165021992902, 14.377760604489144, 14.483093592185341, 14.587666023048378, 14.691494137765568, 14.794593607125545, 14.896979559628859, 14.99866660740214, 15.099668870541501, 15.200000000000003, 15.299673199124223, 15.398701243936129, 15.497096502248416, 15.594870951694345, 15.692036196746427, 15.788603484792445, 15.884583721331826, 15.979987484350545, 16.074825037928097, 16.169106345126192, 16.2628410802049, 16.356038640208702, 16.448708155961672, 16.540858502508268, 16.632498309033434, 16.7236359682935, 16.814279645586964, 16.904437287292353, 16.994116628998402, 17.0833252032501, 17.172070346932546, 17.260359208313137, 17.348198753761157, 17.435595774162696, 17.52255689104761], [0.0, 1.788854381999832, 2.5298221281347035, 3.098386676965934, 3.577708763999664, 4.000000000000001, 4.3817804600413295, 4.732863826479694, 5.059644256269407, 5.366563145999495, 5.656854249492381, 5.9329587896765315, 6.196773353931868, 6.44980619863884, 6.6932802122726045, 6.928203230275509, 7.155417527999328, 7.37563556583431, 7.589466384404111, 7.7974354758471724, 8.000000000000002, 8.19756061276768, 8.390470785361213, 8.579044235810889, 8.763560920082659, 8.94427190999916, 9.121403400793104, 9.295160030897803, 9.465727652959387, 9.633275663033837, 9.797958971132713, 9.959919678390987, 10.119288512538814, 10.276186062932105, 10.43072384832424, 10.583005244258363, 10.73312629199899, 10.881176406988356, 11.027239001672179, 11.171392035015154, 11.313708498984761, 11.454256850621084, 11.593101396951553, 11.730302638892145, 11.865917579353063, 12.0, 12.132600710482482, 12.263767773404714, 12.393546707863736, 12.521980673998824, 12.649110640673518, 12.774975538137053, 12.89961239727768, 13.023056476879768, 13.145341380123988, 13.266499161421601, 13.386560424545209, 13.505554412907307, 13.623509092741124, 13.740451229854134, 13.856406460551018, 13.971399357258385, 14.085453489327207, 14.198591479439079, 14.310835055998655, 14.422205101855956, 14.532721699667961, 14.642404174178502, 14.75127113166862, 14.85934049680537, 14.966629547095767, 15.07315494513342, 15.178932768808222, 15.28397853963424, 15.388307249337076, 15.491933384829668, 15.594870951694345, 15.697133496278868, 15.798734126505202, 15.899685531481435, 16.000000000000004, 16.09968943799849, 16.19876538505327, 16.29723902997069, 16.39512122553536, 16.492422502470642, 16.58915308266218, 16.68532289169137, 16.780941570722426, 16.87601848778319, 16.970562748477143, 17.064583206161235, 17.158088471621777, 17.25108692227826, 17.343586710943043, 17.435595774162696, 17.527121840165318, 17.618172436436197, 17.708754896942924, 17.798876369029593, 17.88854381999832, 17.97776404339539], [0.0, 1.8330302779823362, 2.5922962793631443, 3.174901573277509, 3.6660605559646724, 4.09878030638384, 4.48998886412873, 4.849742261192857, 5.184592558726289, 5.499090833947008, 5.796550698475776, 6.079473661428266, 6.349803146555018, 6.609084656743323, 6.858571279792899, 7.099295739719539, 7.332121111929345, 7.557777451076474, 7.776888838089433, 7.9899937421752725, 8.19756061276768, 8.4, 8.597674104081872, 8.790904390334365, 8.97997772825746, 9.165151389911681, 9.34665715643834, 9.524704719832528, 9.699484522385713, 9.871170143402454, 10.039920318408907, 10.20588065773846, 10.369185117452577, 10.529957264870548, 10.688311372709911, 10.844353369380768, 10.998181667894016, 11.149887891813083, 11.299557513460428, 11.447270417003349, 11.593101396951552, 11.737120600896969, 11.879393923934, 12.019983361053376, 12.158947322856532, 12.296340919151518, 12.432216214336044, 12.566622457924007, 12.699606293110037, 12.831211945876353, 12.961481396815723, 13.09045453756286, 13.218169313486646, 13.344661854089823, 13.469966592386191, 13.594116374373144, 13.717142559585797, 13.839075113604956, 13.95994269329212, 14.079772725438433, 14.198591479439077, 14.316424134538625, 14.433294842134972, 14.54922678357857, 14.66424222385869, 14.778362561528933, 14.891608375189028, 15.003999466808843, 15.115554902152947, 15.226293048539425, 15.336231610144653, 15.44538766104626, 15.553777676178866, 15.661417560361516, 15.768322675541619, 15.874507866387544, 15.979987484350545, 16.08477541030648, 16.188885075878453, 16.29232948353304, 16.39512122553536, 16.497272501841024, 16.598795136997147, 16.699700596118483, 16.8, 16.899704139422088, 16.998823488700623, 17.09736821853001, 17.195348208163743, 17.29277305697383, 17.389652095427326, 17.485994395515515, 17.58180878066873, 17.677103835187484, 17.77188791321845, 17.866169147301836, 17.95995545651492, 18.053254554234815, 18.14607395554201, 18.238420984284797, 18.330302779823363, 18.42172630347113], [0.0, 1.876166303929372, 2.6532998322843198, 3.2496153618543846, 3.752332607858744, 4.1952353926806065, 4.595650117230424, 4.963869458396343, 5.3065996645686395, 5.628498911788116, 5.932958789676531, 6.222539674441619, 6.499230723708769, 6.764613810115105, 7.019971509913698, 7.26636084983398, 7.504665215717488, 7.735631842325486, 7.95989949685296, 8.178019320104351, 8.390470785361213, 8.597674104081872, 8.8, 8.997777503361595, 9.191300234460847, 9.38083151964686, 9.566608594481119, 9.748846085563153, 9.927738916792686, 10.103464752252071, 10.276186062932103, 10.446051885760477, 10.613199329137279, 10.777754868245985, 10.939835464941876, 11.099549540409287, 11.256997823576231, 11.412274094149685, 11.565465835840769, 11.71665481270145, 11.865917579353061, 12.013325934144966, 12.158947322856532, 12.302845199383759, 12.445079348883239, 12.585706178041818, 12.724778976469494, 12.862348152650823, 12.998461447417538, 13.133164127505603, 13.266499161421601, 13.398507379555383, 13.52922762023021, 13.6586968631711, 13.786950351691269, 13.91402170474087, 14.039943019827396, 14.164744967700619, 14.288456879593403, 14.411106827721456, 14.53272169966796, 14.653327267211361, 14.77294825009551, 14.891608375189028, 15.009330431434975, 15.126136320951229, 15.24204710660612, 15.357083056361974, 15.471263684650973, 15.584607791022526, 15.697133496278868, 15.808858276295604, 15.91979899370592, 16.029971927611104, 16.13939280146561, 16.24807680927192, 16.356038640208702, 16.463292501805345, 16.569852141766386, 16.675730868540665, 16.780941570722426, 16.88549673536435, 16.989408465276245, 17.092688495377196, 17.195348208163743, 17.297398648351724, 17.398850536745236, 17.499714283381888, 17.6, 17.69971751187007, 17.798876369029593, 17.897485856957676, 17.99555500672319, 18.093092604637828, 18.19010720144332, 18.286607121059937, 18.382600468921694, 18.47809513992176, 18.57309882599024, 18.667619023324857, 18.76166303929372, 18.855237999028283], [0.0, 1.918332609325088, 2.7129319932501073, 3.3226495451672307, 3.836665218650176, 4.289522117905444, 4.698936049788292, 5.075431016179809, 5.4258639865002145, 5.754997827975264, 6.066300355241241, 6.362389488234747, 6.645299090334461, 6.916646586316234, 7.177743377970545, 7.429670248402684, 7.673330437300352, 7.909487973314076, 8.138795979750322, 8.36181798414675, 8.579044235810889, 8.790904390334365, 8.997777503361595, 9.200000000000001, 9.397872099576585, 9.59166304662544, 9.781615408509989, 9.967948635501692, 10.150862032359617, 10.330537256115967, 10.507140429250958, 10.680823938254951, 10.851727973000429, 11.019981851164731, 11.18570516328765, 11.349008767288886, 11.509995655950528, 11.66876171665186, 11.825396399275588, 11.979983305497552, 12.132600710482482, 12.283322026227271, 12.432216214336044, 12.57934815481311, 12.724778976469494, 12.86856635371633, 13.010764773832475, 13.151425778218877, 13.290598180668923, 13.428328265275615, 13.564659966250538, 13.699635031634969, 13.833293172632468, 13.965672200076876, 14.096808149364879, 14.226735395022994, 14.35548675594109, 14.48309359218534, 14.609585894199741, 14.73499236511509, 14.859340496805368, 14.982656640262435, 15.104966070799366, 15.226293048539425, 15.346660874600705, 15.466091943344964, 15.584607791022526, 15.702229141112419, 15.818975946628152, 15.934867429633673, 16.049922118191105, 16.164157880941403, 16.277591959500644, 16.390240998838305, 16.502121075789017, 16.61324772583615, 16.7236359682935, 16.833300330000654, 16.9422548676379, 17.050513188757694, 17.158088471621777, 17.264993483925792, 17.371240600486775, 17.476841819962782, 17.58180878066873, 17.686152775547317, 17.78988476634967, 17.893015397076034, 17.99555500672319, 18.09751364138179, 18.198901065723724, 18.2997267739166, 18.400000000000002, 18.499729727755486, 18.598924700100273, 18.69759342803239, 18.79574419915317, 18.893385085791273, 18.990523952750753, 19.08716846470424, 19.18332609325088, 19.27900412365743], [0.0, 1.9595917942265426, 2.7712812921102037, 3.3941125496954285, 3.9191835884530852, 4.3817804600413295, 4.800000000000001, 5.184592558726289, 5.542562584220407, 5.878775382679628, 6.196773353931867, 6.499230723708769, 6.788225099390857, 7.065408693062278, 7.332121111929344, 7.58946638440411, 7.8383671769061705, 8.079603950689663, 8.313843876330612, 8.54166260162505, 8.763560920082659, 8.97997772825746, 9.191300234460847, 9.397872099576585, 9.600000000000001, 9.797958971132713, 9.991996797437439, 10.182337649086286, 10.369185117452577, 10.552724766618336, 10.73312629199899, 10.910545357588685, 11.085125168440815, 11.256997823576233, 11.426285485668561, 11.593101396951552, 11.757550765359255, 11.919731540601072, 12.0797350964332, 12.237646832622685, 12.393546707863734, 12.5475097130865, 12.699606293110037, 12.849902723367208, 12.998461447417538, 13.145341380123986, 13.29059818066892, 13.434284498997332, 13.576450198781714, 13.717142559585797, 13.85640646055102, 13.994284547628723, 14.130817386124557, 14.266043600101609, 14.4, 14.532721699667961, 14.664242223858688, 14.794593607125543, 14.923806484942105, 15.051910177781423, 15.17893276880822, 15.304901175767194, 15.429841217588727, 15.553777676178866, 15.676734353812341, 15.798734126505199, 15.91979899370592, 16.039950124610737, 16.159207901379325, 16.277591959500644, 16.39512122553536, 16.511813952440235, 16.627687752661224, 16.74275962916508, 16.85704600456438, 16.970562748477143, 17.0833252032501, 17.195348208163743, 17.30664612222715, 17.417232845661793, 17.527121840165318, 17.636326148038883, 17.74485841025507, 17.852730883537117, 17.95995545651492, 18.066543665017946, 18.172506706560878, 18.277855454073382, 18.382600468921694, 18.48675201326615, 18.5903200617956, 18.693314312876677, 18.79574419915317, 18.897618897628348, 18.99894733926067, 19.099738218101315, 19.200000000000003, 19.299740930903713, 19.398969044771427, 19.497692171126307, 19.595917942265427, 19.693653800145878], [0.0, 2.0, 2.8284271247461903, 3.4641016151377553, 4.0, 4.47213595499958, 4.898979485566357, 5.291502622129181, 5.656854249492381, 6.0, 6.324555320336759, 6.6332495807108005, 6.9282032302755105, 7.211102550927979, 7.483314773547883, 7.745966692414833, 8.0, 8.246211251235321, 8.485281374238571, 8.717797887081348, 8.94427190999916, 9.165151389911681, 9.38083151964686, 9.59166304662544, 9.797958971132713, 10.000000000000002, 10.19803902718557, 10.392304845413266, 10.583005244258363, 10.77032961426901, 10.954451150103322, 11.135528725660045, 11.313708498984761, 11.489125293076059, 11.661903789690601, 11.832159566199232, 12.0, 12.16552506059644, 12.328828005937954, 12.489995996796798, 12.649110640673518, 12.806248474865699, 12.961481396815723, 13.114877048604, 13.266499161421601, 13.416407864998737, 13.564659966250538, 13.71130920080209, 13.856406460551021, 14.0, 14.142135623730953, 14.282856857085703, 14.422205101855958, 14.56021977856104, 14.69693845669907, 14.832396974191328, 14.966629547095765, 15.0996688705415, 15.231546211727819, 15.362291495737216, 15.491933384829666, 15.62049935181331, 15.748015748023622, 15.874507866387544, 16.0, 16.1245154965971, 16.24807680927192, 16.3707055437449, 16.492422502470642, 16.61324772583615, 16.73320053068151, 16.852299546352718, 16.970562748477143, 17.088007490635064, 17.204650534085253, 17.320508075688775, 17.435595774162696, 17.549928774784245, 17.663521732655695, 17.77638883463118, 17.88854381999832, 18.000000000000004, 18.110770276274835, 18.2208671582886, 18.330302779823363, 18.439088914585778, 18.547236990991408, 18.65475810617763, 18.76166303929372, 18.867962264113206, 18.973665961010276, 19.078784028338916, 19.18332609325088, 19.287301521985913, 19.390719429665317, 19.493588689617926, 19.595917942265427, 19.69771560359221, 19.79898987322333, 19.899748742132402, 20.000000000000004, 20.099751242241783], [0.0, 2.039607805437114, 2.8844410203711917, 3.5327043465311396, 4.079215610874228, 4.560701700396552, 4.9959983987187195, 5.396295025292817, 5.768882040742383, 6.118823416311342, 6.44980619863884, 6.764613810115106, 7.065408693062279, 7.353910524340095, 7.631513611335565, 7.899367063252599, 8.158431221748456, 8.409518416651457, 8.653323061113575, 8.89044430835715, 9.121403400793104, 9.34665715643834, 9.566608594481119, 9.781615408509989, 9.991996797437439, 10.19803902718557, 10.400000000000002, 10.598113039593418, 10.792590050585634, 10.983624174196786, 11.171392035015153, 11.356055653262713, 11.537764081484767, 11.71665481270145, 11.892854997854805, 12.066482503198685, 12.237646832622683, 12.40644993541666, 12.572986916401371, 12.737346662472529, 12.89961239727768, 13.059862173851608, 13.218169313486648, 13.37460279784039, 13.529227620230213, 13.682105101189656, 13.833293172632468, 13.982846634358829, 14.130817386124559, 14.277254638059798, 14.422205101855958, 14.565713164826501, 14.70782104868019, 14.848568954616471, 14.987995196156158, 15.12613632095123, 15.26302722267113, 15.398701243936127, 15.533190271158082, 15.666524822052912, 15.798734126505199, 15.929846201391902, 16.059887919907784, 16.188885075878453, 16.316862443496913, 16.443843832875572, 16.569852141766383, 16.694909403767365, 16.819036833302913, 16.9422548676379, 17.064583206161235, 17.186040847152668, 17.30664612222715, 17.426416728633573, 17.54536975956905, 17.663521732655695, 17.7808886167143, 17.897485856957676, 18.01332839871633, 18.128430709799456, 18.24280680158621, 18.356470248934027, 18.469434208984318, 18.581711438939095, 18.69331431287668, 18.804254837669056, 18.914544668059026, 19.024195120950587, 19.133217188962238, 19.24162155328911, 19.34941859591652, 19.456618411224497, 19.563230817019978, 19.669265365030796, 19.774731350893244, 19.879637823662684, 19.983993594874878, 20.087807247183555, 20.19108714259834, 20.293841430345317, 20.39607805437114, 20.497804760510334], [0.0, 2.078460969082653, 2.939387691339814, 3.6000000000000005, 4.156921938165306, 4.647580015448901, 5.091168824543143, 5.499090833947008, 5.878775382679628, 6.235382907247958, 6.572670690061994, 6.893475175845635, 7.200000000000001, 7.493997598078079, 7.776888838089433, 8.049844718999243, 8.313843876330612, 8.56971411425142, 8.818163074019441, 9.059801322324901, 9.295160030897803, 9.524704719832528, 9.748846085563153, 9.967948635501692, 10.182337649086286, 10.392304845413266, 10.598113039593418, 10.8, 10.998181667894016, 11.192854863706579, 11.384199576606166, 11.572380913191546, 11.757550765359255, 11.939849245279442, 12.119405926034494, 12.296340919151518, 12.470765814495916, 12.642784503423288, 12.812493902437575, 12.979984591670364, 13.145341380123988, 13.308643807691302, 13.469966592386191, 13.629380029920656, 13.78695035169127, 13.942740046346701, 14.096808149364879, 14.249210504445502, 14.400000000000002, 14.54922678357857, 14.69693845669907, 14.843180252223581, 14.987995196156158, 15.131424255502193, 15.273506473629428, 15.414279094398156, 15.553777676178866, 15.692036196746425, 15.829087149927505, 15.964961634780085, 16.099689437998485, 16.23329911016242, 16.365818036383025, 16.497272501841024, 16.627687752661224, 16.75708805252273, 16.88549673536435, 17.01293625450939, 17.13942822850284, 17.264993483925792, 17.38965209542733, 17.51342342319171, 17.636326148038883, 17.758378304338493, 17.87959731090161, 18.0, 18.119602644649802, 18.238420984284797, 18.35647024893403, 18.473765182008783, 18.590320061795605, 18.706148721743876, 18.82126456962975, 18.9356806056714, 19.049409439665055, 19.162463307205577, 19.274854085050816, 19.386593305684215, 19.497692171126307, 19.60816156604183, 19.71801207018598, 19.827253970229968, 19.935897271003384, 20.043951706188082, 20.151426748496, 20.25833161936096, 20.36467529817257, 20.47046653107838, 20.575713839378697, 20.680425527536904, 20.78460969082653, 20.888274222635054], [0.0, 2.1166010488516727, 2.993325909419153, 3.6660605559646724, 4.233202097703345, 4.732863826479694, 5.184592558726289, 5.6000000000000005, 5.986651818838306, 6.3498031465550175, 6.6932802122726045, 7.019971509913698, 7.332121111929345, 7.631513611335566, 7.919595949289333, 8.197560612767678, 8.46640419540669, 8.726969691708572, 8.97997772825746, 9.226050075736637, 9.465727652959387, 9.699484522385713, 9.927738916792686, 10.150862032359617, 10.369185117452577, 10.583005244258363, 10.792590050585634, 10.998181667894016, 11.200000000000001, 11.398245479020007, 11.59310139695155, 11.784735890124988, 11.973303637676612, 12.158947322856532, 12.341798896433211, 12.521980673998822, 12.699606293110035, 12.874781551544865, 13.047605144240073, 13.218169313486646, 13.386560424545209, 13.552859476877934, 13.717142559585799, 13.879481258317977, 14.039943019827396, 14.198591479439077, 14.35548675594109, 14.510685717773644, 14.66424222385869, 14.816207341961707, 14.966629547095767, 15.11555490215295, 15.263027222671132, 15.40908822740658, 15.553777676178866, 15.697133496278868, 15.839191898578665, 15.979987484350543, 16.119553343687908, 16.25792114632126, 16.395121225535355, 16.53118265581746, 16.666133324799727, 16.8, 16.93280839081338, 17.06458320616123, 17.195348208163743, 17.325126262166172, 17.453939383417143, 17.58180878066873, 17.708754896942924, 17.834797447686363, 17.95995545651492, 18.084247288731703, 18.207690682785667, 18.33030277982336, 18.452100151473275, 18.57309882599024, 18.69331431287668, 18.812761626087756, 18.931455305918774, 19.04940943966505, 19.166637681137505, 19.28315326911032, 19.398969044771427, 19.51409746824075, 19.628550634216477, 19.742340286804907, 19.855477833585372, 19.967974358957896, 20.079840636817814, 20.19108714259834, 20.301724064719235, 20.41176131547692, 20.52120854140906, 20.6300751331642, 20.738370234905155, 20.846102753272614, 20.95328136593407, 21.059914529741096, 21.166010488516726, 21.271577280493332], [0.0, 2.154065922853802, 3.0463092423455636, 3.7309516212355267, 4.308131845707604, 4.8166378315169185, 5.276362383309168, 5.6991227395100035, 6.092618484691127, 6.462197768561405, 6.811754546370561, 7.144228439796701, 7.461903242471053, 7.76659513557904, 8.059776671843954, 8.342661445845684, 8.616263691415208, 8.881441324469808, 9.138927727036691, 9.389355675444403, 9.633275663033837, 9.871170143402454, 10.103464752252071, 10.330537256115967, 10.552724766618336, 10.77032961426901, 10.983624174196786, 11.192854863706579, 11.398245479020007, 11.600000000000001, 11.798304963002101, 11.99333148045196, 12.185236969382254, 12.374166638606418, 12.560254774486067, 12.743625857659193, 12.92439553712281, 13.102671483327361, 13.278554138158267, 13.452137376640191, 13.623509092741122, 13.792751719653335, 13.95994269329212, 14.12515486640766, 14.288456879593403, 14.449913494550755, 14.609585894199741, 14.767531953579788, 14.923806484942107, 15.078461459976612, 15.231546211727819, 15.383107618423532, 15.53319027115808, 15.68183662713013, 15.829087149927505, 15.974980438172688, 16.119553343687908, 16.262841080204897, 16.404877323527906, 16.54569430395715, 16.685322891691367, 16.823792675850473, 16.961132037691353, 17.09736821853001, 17.232527382830416, 17.36663467687393, 17.499714283381888, 17.631789472427354, 17.762882648939616, 17.893015397076034, 18.0222085217101, 18.150482087261484, 18.277855454073382, 18.404347312523747, 18.529975715040752, 18.65475810617763, 18.778711350888805, 18.901851761137056, 19.024195120950587, 19.145756710038913, 19.266551326067674, 19.386593305684215, 19.505896544378576, 19.624474515257727, 19.742340286804907, 19.85950653969026, 19.975985582694037, 20.091789367798977, 20.206929504504142, 20.321417273408862, 20.43526363911168, 20.548479262466117, 20.661074512231934, 20.773059476158057, 20.884443971530583, 20.995237555217134, 21.105449533236673, 21.215088969881794, 21.324164696418944, 21.432685319390107, 21.54065922853802, 21.648094604375697], [0.0, 2.1908902300206643, 3.098386676965933, 3.7947331922020555, 4.381780460041329, 4.898979485566357, 5.366563145999495, 5.796550698475775, 6.196773353931866, 6.572670690061993, 6.928203230275509, 7.26636084983398, 7.589466384404111, 7.899367063252599, 8.197560612767678, 8.48528137423857, 8.763560920082657, 9.033271832508971, 9.2951600308978, 9.549869109050658, 9.797958971132713, 10.039920318408907, 10.276186062932103, 10.507140429250958, 10.73312629199899, 10.954451150103322, 11.171392035015153, 11.384199576606166, 11.59310139695155, 11.798304963002101, 11.999999999999998, 12.198360545581524, 12.393546707863733, 12.58570617804182, 12.77497553813705, 12.961481396815719, 13.145341380123986, 13.326664999166145, 13.505554412907305, 13.682105101189656, 13.856406460551018, 14.028542333400146, 14.198591479439079, 14.366627996854374, 14.53272169966796, 14.696938456699067, 14.859340496805368, 15.019986684414869, 15.178932768808222, 15.336231610144651, 15.491933384829668, 15.646085772486357, 15.798734126505199, 15.94992162990151, 16.099689437998485, 16.24807680927192, 16.395121225535355, 16.540858502508264, 16.685322891691367, 16.8285471743701, 16.97056274847714, 17.111399708965948, 17.251086922278258, 17.389652095427326, 17.527121840165314, 17.663521732655692, 17.79887636902959, 17.933209417167912, 18.066543665017942, 18.19890106572372, 18.33030277982336, 18.46076921474292, 18.5903200617956, 18.718974330876144, 18.846750383023593, 18.973665961010276, 19.099738218101315, 19.224983745116663, 19.34941859591652, 19.473058311420935, 19.595917942265427, 19.71801207018598, 19.83935482821959, 19.959959919799438, 20.079840636817814, 20.199009876724155, 20.31748015872047, 20.43526363911168, 20.552372125864206, 20.6688170924221, 20.784609690826528, 20.89976076418101, 21.014280858501916, 21.12818023399081, 21.241468875762806, 21.35415650406262, 21.46625258399798, 21.577766334817884, 21.68870673876153, 21.79908254950194, 21.908902300206645, 22.018174311236617], [0.0, 2.227105745132009, 3.1496031496047245, 3.8574603043971827, 4.454211490264018, 4.979959839195494, 5.455272678794342, 5.892367945062494, 6.299206299209449, 6.681317235396026, 7.042726744663604, 7.386474125047756, 7.714920608794365, 8.029943959953894, 8.333066662399863, 8.625543461139129, 8.908422980528035, 9.182592226599198, 9.448809448814174, 9.707728879609279, 9.959919678390987, 10.20588065773846, 10.446051885760477, 10.680823938254951, 10.910545357588685, 11.135528725660045, 11.356055653262713, 11.572380913191546, 11.784735890124988, 11.99333148045196, 12.198360545581524, 12.4, 12.598412598418898, 12.793748473375581, 12.986146464598342, 13.175735273600482, 13.362634470792052, 13.54695537750088, 13.728801841384412, 13.908270920570969, 14.085453489327207, 14.26043477598071, 14.433294842134973, 14.604109010822945, 14.772948250095512, 14.939879517586478, 15.104966070799366, 15.268267747193851, 15.42984121758873, 15.589740215924062, 15.748015748023622, 15.904716281656837, 16.059887919907787, 16.213574559608997, 16.36581803638303, 16.516658257650064, 16.666133324799727, 16.81427964558696, 16.961132037691353, 17.106723824274475, 17.251086922278258, 17.39425192412712, 17.53624817342638, 17.677103835187484, 17.81684596105607, 17.95550054997075, 18.093092604637825, 18.229646184169347, 18.365184453198395, 18.499729727755486, 18.633303518163387, 18.76592656918384, 18.897618897628348, 19.028399827626075, 19.158288023724875, 19.28730152198591, 19.415457759218558, 19.542773600489774, 19.669265365030796, 19.794948850653796, 19.919839356781974, 20.04395170618808, 20.16730026552885, 20.289898964755835, 20.41176131547692, 20.53290042833696, 20.65332902948094, 20.773059476158057, 20.892103771520954, 21.010473578670233, 21.12818023399081, 21.2452347598232, 21.361647876509902, 21.47743001385408, 21.59259132202525, 21.707141681944215, 21.82109071517737, 21.934447793368314, 22.04722204723307, 22.15942237514327, 22.27105745132009, 22.38213573366045], [0.0, 2.262741699796952, 3.1999999999999997, 3.9191835884530852, 4.525483399593904, 5.059644256269407, 5.542562584220407, 5.986651818838306, 6.3999999999999995, 6.788225099390856, 7.155417527999327, 7.504665215717488, 7.8383671769061705, 8.158431221748456, 8.466404195406689, 8.763560920082657, 9.050966799187808, 9.32952303175248, 9.6, 9.863062404750362, 10.119288512538814, 10.369185117452577, 10.613199329137279, 10.851727973000429, 11.085125168440815, 11.313708498984761, 11.537764081484767, 11.757550765359255, 11.973303637676612, 12.185236969382254, 12.393546707863733, 12.598412598418898, 12.799999999999999, 12.998461447417537, 13.193938001976514, 13.386560424545209, 13.576450198781712, 13.763720427268202, 13.948476619330156, 14.130817386124555, 14.310835055998654, 14.488616221019868, 14.66424222385869, 14.837789592793124, 15.009330431434975, 15.178932768808219, 15.346660874600703, 15.512575543732252, 15.676734353812341, 15.839191898578663, 16.0, 16.159207901379325, 16.316862443496913, 16.473008225579203, 16.627687752661224, 16.780941570722426, 16.932808390813378, 17.083325203250098, 17.232527382830412, 17.380448785920343, 17.527121840165314, 17.672577627499617, 17.816845961056067, 17.95995545651492, 18.101933598375616, 18.242806801586205, 18.38260046892169, 18.52133904446436, 18.65904606350496, 18.79574419915317, 18.93145530591877, 19.066200460500774, 19.2, 19.332873557751316, 19.4648400969543, 19.595917942265423, 19.726124809500725, 19.855477833585372, 19.983993594874875, 20.111688143962457, 20.23857702507763, 20.364675298172568, 20.489997559785117, 20.6145579627602, 20.738370234905155, 20.861447696648476, 20.983803277766402, 21.10544953323667, 21.226398658274558, 21.346662502602133, 21.46625258399798, 21.585180101171265, 21.703455946000858, 21.82109071517737, 21.938094721283342, 22.054478003344354, 22.17025033688163, 22.285421243494593, 22.4, 22.513995647152463, 22.627416997969522, 22.740272645683035], [0.0, 2.297825058615212, 3.249615361854384, 3.9799497484264807, 4.595650117230424, 5.1380930314660525, 5.628498911788117, 6.079473661428266, 6.499230723708768, 6.8934751758456345, 7.266360849833981, 7.621023553303061, 7.9598994968529615, 8.284926070883193, 8.597674104081872, 8.899438184514796, 9.191300234460847, 9.47417542586161, 9.748846085563153, 10.015987220439133, 10.276186062932105, 10.529957264870548, 10.777754868245985, 11.019981851164731, 11.256997823576233, 11.489125293076059, 11.71665481270145, 11.939849245279442, 12.158947322856532, 12.374166638606418, 12.58570617804182, 12.793748473375581, 12.998461447417537, 13.200000000000003, 13.398507379555383, 13.594116374373144, 13.786950351691269, 13.97712416772492, 14.16474496770062, 14.34991289172168, 14.532721699667961, 14.71325932619962, 14.89160837518903, 15.06784656146989, 15.242047106606122, 15.414279094398156, 15.584607791022528, 15.753094934012175, 15.919798993705923, 16.08477541030648, 16.24807680927192, 16.409753197412815, 16.569852141766386, 16.728418933061192, 16.88549673536435, 17.041126723312637, 17.195348208163743, 17.348198753761153, 17.499714283381888, 17.64992917832817, 17.798876369029593, 17.946587419339647, 18.093092604637828, 18.238420984284797, 18.382600468921694, 18.525657883055057, 18.667619023324857, 18.808508712813996, 18.94835085172322, 19.08716846470424, 19.224983745116667, 19.361818096449518, 19.497692171126307, 19.632625906892844, 19.76663856096934, 19.899748742132402, 20.031974440878265, 20.163333057805698, 20.29384143034532, 20.423515857951593, 20.55237212586421, 20.680425527536904, 20.807690885823927, 20.93418257300724, 21.059914529741096, 21.18490028298458, 21.30915296298753, 21.432685319390103, 21.55550973649197, 21.677638247742767, 21.799082549501943, 21.919854014112413, 22.039963702329462, 22.15942237514327, 22.278240505030915, 22.39642828667107, 22.513995647152466, 22.630952255705022, 22.74730753298069, 22.863070659909184, 22.978250586152118, 23.0928560381777], [0.0, 2.3323807579381204, 3.2984845004941286, 4.039801975344832, 4.664761515876241, 5.21536192416212, 5.713142742834281, 6.1708994482166055, 6.596969000988257, 6.997142273814361, 7.37563556583431, 7.735631842325487, 8.079603950689664, 8.409518416651457, 8.726969691708572, 9.033271832508971, 9.329523031752482, 9.616652224137047, 9.895453501482386, 10.16661202171107, 10.43072384832424, 10.688311372709911, 10.939835464941876, 11.18570516328765, 11.426285485668561, 11.661903789690601, 11.892854997854805, 12.119405926034494, 12.341798896433211, 12.560254774486067, 12.77497553813705, 12.986146464598342, 13.193938001976514, 13.398507379555383, 13.600000000000001, 13.798550648528272, 13.994284547628721, 14.18731828077456, 14.377760604489144, 14.565713164826501, 14.75127113166862, 14.934523762075576, 15.11555490215295, 15.294443435444128, 15.471263684650975, 15.646085772486355, 15.818975946628152, 15.989996873045348, 16.15920790137933, 16.32666530556684, 16.492422502470642, 16.656530250925613, 16.819036833302913, 16.9799882214329, 17.13942822850284, 17.297398648351724, 17.453939383417143, 17.60908856244411, 17.762882648939616, 17.915356541246954, 18.066543665017942, 18.216476058777122, 18.365184453198392, 18.512698344649817, 18.659046063504963, 18.804254837669053, 18.94835085172322, 19.09135930205076, 19.233304448274094, 19.374209661299737, 19.51409746824075, 19.652989594461197, 19.790907002964772, 19.92786993132984, 20.063897926375123, 20.199009876724155, 20.33322404342214, 20.46655808874565, 20.599029103333976, 20.730653631759903, 20.86144769664848, 20.991426821443085, 21.12060605191054, 21.24899997646948, 21.376622745419823, 21.50348808914498, 21.62960933535324, 21.754999425419438, 21.87967092988375, 22.003636063160105, 22.126906697502932, 22.249494376277408, 22.3714103265753, 22.49266547121528, 22.613270440164115, 22.733235581412515, 22.852570971337123, 22.97128642457797, 23.0893915034589, 23.20689552697646, 23.323807579381203, 23.44013651837378], [0.0, 2.3664319132398464, 3.3466401061363023, 4.09878030638384, 4.732863826479693, 5.291502622129181, 5.796550698475776, 6.260990336999411, 6.6932802122726045, 7.099295739719539, 7.483314773547883, 7.848566748139434, 8.19756061276768, 8.532291603080617, 8.854377448471462, 9.16515138991168, 9.465727652959385, 9.757048734120374, 10.039920318408907, 10.315037566582102, 10.583005244258363, 10.844353369380768, 11.099549540409287, 11.349008767288886, 11.593101396951552, 11.832159566199232, 12.066482503198685, 12.296340919151518, 12.521980673998822, 12.743625857659193, 12.961481396815719, 13.175735273600482, 13.386560424545209, 13.594116374373144, 13.798550648528272, 14.0, 14.198591479439077, 14.394443372357266, 14.587666023048376, 14.778362561528933, 14.966629547095765, 15.15255753990065, 15.336231610144653, 15.517731793016656, 15.697133496278868, 15.874507866387543, 16.049922118191105, 16.2234398325386, 16.39512122553536, 16.565023392678924, 16.73320053068151, 16.899704139422088, 17.064583206161235, 17.227884373886425, 17.389652095427326, 17.549928774784245, 17.708754896942924, 17.866169147301836, 18.0222085217101, 18.17690842800282, 18.33030277982336, 18.482424083436673, 18.633303518163384, 18.782971010998235, 18.93145530591877, 19.078784028338912, 19.224983745116663, 19.3700800204852, 19.51409746824075, 19.657059800488984, 19.79898987322333, 19.939909728983228, 20.079840636817814, 20.21880312976018, 20.356817039999154, 20.493901531919196, 20.630075133164205, 20.765355763867856, 20.899760764181014, 21.03330692021585, 21.166010488516726, 21.297887219158618, 21.4289523775662, 21.559220765138985, 21.688706738761535, 21.81742422927143, 21.945386758952324, 22.07260745811423, 22.199099080818574, 22.32487401980132, 22.44994432064365, 22.574321695235938, 22.698017534577772, 22.82104292095346, 22.94340863951998, 23.06512518934159, 23.186202793903103, 23.306651411131547, 23.426480742954116, 23.545700244418303, 23.664319132398465, 23.7823463939116], [0.0, 2.4, 3.394112549695428, 4.156921938165306, 4.8, 5.366563145999495, 5.878775382679628, 6.3498031465550175, 6.788225099390856, 7.199999999999999, 7.58946638440411, 7.95989949685296, 8.313843876330612, 8.653323061113575, 8.97997772825746, 9.295160030897799, 9.6, 9.895453501482384, 10.182337649086284, 10.461357464497617, 10.73312629199899, 10.998181667894016, 11.256997823576231, 11.509995655950528, 11.757550765359255, 12.0, 12.237646832622683, 12.470765814495916, 12.699606293110035, 12.92439553712281, 13.145341380123986, 13.362634470792052, 13.576450198781712, 13.786950351691269, 13.994284547628721, 14.198591479439077, 14.399999999999999, 14.598630072715727, 14.794593607125543, 14.987995196156156, 15.17893276880822, 15.367498169838838, 15.553777676178866, 15.7378524583248, 15.91979899370592, 16.099689437998485, 16.277591959500644, 16.453571040962505, 16.627687752661224, 16.8, 16.97056274847714, 17.13942822850284, 17.30664612222715, 17.472263734273245, 17.636326148038883, 17.798876369029593, 17.95995545651492, 18.1196026446498, 18.27785545407338, 18.43474979488466, 18.590320061795598, 18.74459922217597, 18.897618897628345, 19.04940943966505, 19.2, 19.349418595916518, 19.497692171126303, 19.64484665249388, 19.79090700296477, 19.93589727100338, 20.079840636817814, 20.222759455623258, 20.364675298172568, 20.505608988762074, 20.645580640902303, 20.784609690826528, 20.922714928995234, 21.059914529741093, 21.196226079186836, 21.331666601557412, 21.46625258399798, 21.6, 21.7329243315298, 21.865040589946314, 21.996363335788033, 22.12690669750293, 22.25668438918969, 22.385709727413158, 22.513995647152463, 22.641554716935847, 22.76839915321233, 22.894540834006694, 23.019991311901055, 23.144761826383093, 23.26886331559838, 23.39230642754151, 23.51510153071851, 23.63725872431065, 23.758787847867996, 23.87969849055888, 24.0, 24.11970149069014], [0.0, 2.433105012119288, 3.4409301068170506, 4.214261501141096, 4.866210024238576, 5.440588203494178, 5.959865770300536, 6.437390775772433, 6.881860213634101, 7.299315036357863, 7.694153624668538, 8.069696400732807, 8.428523002282192, 8.772684879784524, 9.103845341392834, 9.423375191511797, 9.732420048477152, 10.031948963187562, 10.322790320451153, 10.605658866850284, 10.881176406988356, 11.149887891813083, 11.412274094149685, 11.66876171665186, 11.919731540601072, 12.16552506059644, 12.40644993541666, 12.642784503423288, 12.874781551544865, 13.102671483327361, 13.326664999166145, 13.54695537750088, 13.763720427268202, 13.97712416772492, 14.18731828077456, 14.394443372357266, 14.598630072715727, 14.8, 14.998666607402141, 15.194735930578066, 15.388307249337076, 15.57947367532036, 15.76832267554162, 15.954936540143304, 16.139392801465615, 16.321764610482532, 16.502121075789017, 16.680527569594435, 16.857046004564385, 17.031735084835017, 17.204650534085257, 17.37584530317878, 17.54536975956905, 17.713271860387625, 17.87959731090161, 18.04438970982394, 18.207690682785667, 18.369540005128055, 18.529975715040752, 18.689034217957865, 18.846750383023593, 19.003157632351524, 19.158288023724875, 19.3121723273173, 19.464840096954305, 19.616319736382763, 19.76663856096934, 19.915822855207363, 20.063897926375123, 20.21088815465565, 20.356817039999157, 20.501707245983198, 20.645580640902306, 20.788458336298053, 20.930360723121808, 21.07130750570548, 21.211317733700568, 21.35040983213203, 21.48860162970127, 21.625910385461236, 21.76235281397671, 21.897945109073593, 22.032702966272662, 22.166641603995856, 22.299775783626167, 22.432119828495924, 22.56368764187273, 22.694492724006857, 22.82454818829937, 22.953866776645718, 23.082460874005616, 23.210342522246414, 23.33752343330372, 23.464015001699945, 23.58982831645877, 23.71497417245062, 23.839463081202144, 23.96330528120026, 24.086510747719355, 24.20908920219842, 24.33105012119288, 24.452402744924683], [0.0, 2.4657656011875906, 3.487119154832539, 4.270831300812525, 4.931531202375181, 5.513619500836089, 6.0398675482166, 6.523802572120037, 6.974238309665078, 7.397296803562772, 7.797435475847172, 8.178019320104351, 8.54166260162505, 8.890444308357148, 9.226050075736637, 9.549869109050658, 9.863062404750362, 10.166612021711067, 10.461357464497617, 10.748023074035524, 11.027239001672179, 11.299557513460428, 11.565465835840769, 11.825396399275588, 12.0797350964332, 12.328828005937954, 12.572986916401371, 12.812493902437575, 13.047605144240073, 13.278554138158267, 13.505554412907305, 13.728801841384412, 13.948476619330156, 14.16474496770062, 14.377760604489144, 14.587666023048376, 14.794593607125543, 14.998666607402141, 15.200000000000001, 15.398701243936129, 15.594870951694343, 15.788603484792443, 15.979987484350545, 16.16910634512619, 16.356038640208702, 16.540858502508264, 16.7236359682935, 16.904437287292353, 17.0833252032501, 17.260359208313137, 17.435595774162696, 17.609088562444114, 17.780888616714297, 17.951044537853505, 18.119602644649802, 18.286607121059937, 18.452100151473275, 18.616122045152153, 18.778711350888805, 18.939904962802743, 19.099738218101315, 19.258244987537157, 19.415457759218555, 19.57140771636011, 19.726124809500725, 19.879637823662684, 20.031974440878265, 20.183161298468583, 20.333224043422135, 20.482187383187373, 20.630075133164205, 20.776910261152885, 20.922714928995234, 21.06751053162191, 21.211317733700565, 21.354156504062622, 21.49604614807105, 21.637005338077635, 21.777052142105923, 21.91620405088436, 22.054478003344357, 22.191890410688316, 22.328457179124584, 22.464193731358357, 22.599115026920856, 22.73323558141252, 22.866569484730324, 22.999130418344084, 23.130931671681537, 23.26198615767794, 23.392306427541513, 23.52190468478265, 23.650792798551176, 23.778982316322963, 23.9064844759743, 24.033310217279684, 24.1594701928664, 24.284974778656867, 24.40983408382777, 24.53405796031305, 24.657656011875908, 24.780637602773666], [0.0, 2.4979991993593598, 3.5327043465311387, 4.326661530556788, 4.9959983987187195, 5.585696017507577, 6.118823416311343, 6.609084656743323, 7.0654086930622775, 7.493997598078078, 7.8993670632526, 8.284926070883193, 8.653323061113577, 9.006664199358163, 9.346657156438338, 9.674709297958259, 9.991996797437439, 10.299514551666988, 10.598113039593418, 10.888526071052961, 11.171392035015154, 11.447270417003349, 11.71665481270145, 11.979983305497552, 12.237646832622685, 12.489995996796798, 12.737346662472529, 12.979984591670364, 13.218169313486646, 13.452137376640191, 13.682105101189656, 13.908270920570969, 14.130817386124555, 14.34991289172168, 14.565713164826501, 14.778362561528933, 14.987995196156156, 15.194735930578066, 15.398701243936129, 15.600000000000003, 15.7987341265052, 15.994999218505766, 16.188885075878453, 16.380476183554617, 16.569852141766386, 16.75708805252273, 16.9422548676379, 17.125419702886116, 17.306646122227153, 17.485994395515515, 17.663521732655695, 17.83928249678221, 18.013328398716325, 18.18570867467089, 18.356470248934027, 18.52565788305506, 18.693314312876677, 18.859480374602054, 19.024195120950587, 19.187495928338333, 19.349418595916518, 19.50999743721152, 19.669265365030796, 19.827253970229968, 19.983993594874878, 20.139513400278567, 20.293841430345317, 20.447004670611292, 20.599029103333976, 20.749939758948702, 20.899760764181014, 21.04851538707659, 21.196226079186836, 21.342914515126562, 21.488601629701268, 21.633307652783937, 21.777052142105923, 21.919854014112413, 22.06173157302029, 22.202702538204672, 22.34278407003031, 22.481992794234237, 22.62034482495791, 22.75785578651908, 22.894540834006698, 23.030414672775652, 23.165491576912416, 23.299785406737122, 23.4333096254029, 23.566077314648698, 23.6981011897578, 23.82939361377037, 23.959966610995103, 24.08983187986168, 24.21900080515297, 24.34748446965312, 24.47529366524537, 24.602438903490853, 24.728930425717973, 24.854778212649578, 24.979991993593597, 25.10458125522113], [0.0, 2.5298221281347035, 3.5777087639996634, 4.3817804600413295, 5.059644256269407, 5.656854249492381, 6.196773353931867, 6.6932802122726045, 7.155417527999327, 7.58946638440411, 8.0, 8.390470785361213, 8.763560920082659, 9.121403400793104, 9.465727652959385, 9.797958971132712, 10.119288512538814, 10.430723848324238, 10.73312629199899, 11.027239001672179, 11.313708498984761, 11.593101396951552, 11.865917579353061, 12.132600710482482, 12.393546707863734, 12.649110640673518, 12.89961239727768, 13.145341380123988, 13.386560424545209, 13.623509092741122, 13.856406460551018, 14.085453489327207, 14.310835055998654, 14.532721699667961, 14.75127113166862, 14.966629547095765, 15.17893276880822, 15.388307249337076, 15.594870951694343, 15.7987341265052, 16.0, 16.19876538505327, 16.39512122553536, 16.589153082662175, 16.780941570722426, 16.97056274847714, 17.158088471621774, 17.34358671094304, 17.527121840165318, 17.708754896942924, 17.88854381999832, 18.066543665017946, 18.24280680158621, 18.417383093154143, 18.5903200617956, 18.76166303929372, 18.93145530591877, 19.099738218101315, 19.266551326067674, 19.43193248238579, 19.595917942265423, 19.75854245636555, 19.91983935678197, 20.079840636817814, 20.23857702507763, 20.396078054371138, 20.552372125864206, 20.707486568871655, 20.861447696648476, 21.014280858501916, 21.166010488516726, 21.316660151158764, 21.46625258399798, 21.614809737770074, 21.762352813976708, 21.908902300206645, 22.054478003344357, 22.199099080818574, 22.34278407003031, 22.485550916088314, 22.627416997969522, 22.768399153212332, 22.908513701242168, 23.047776465420693, 23.186202793903103, 23.323807579381203, 23.46060527778429, 23.596609926004202, 23.731835158706122, 23.866294224282075, 24.0, 24.13296500639737, 24.265201420964964, 24.39672109116305, 24.52753554680943, 24.657656011875904, 24.78709341572747, 24.9158584038359, 25.043961347997644, 25.17141235608364, 25.298221281347036, 25.424397731313128], [0.0, 2.5612496949731396, 3.622154055254967, 4.436214602563767, 5.122499389946279, 5.727128425310542, 6.27375485654325, 6.776429738438967, 7.244308110509934, 7.683749084919419, 8.099382692526635, 8.494704232638123, 8.872429205127535, 9.234717104492159, 9.583318840568753, 9.919677414109795, 10.244998779892558, 10.56030302595527, 10.8664621657649, 11.164228589562292, 11.454256850621084, 11.737120600896969, 12.013325934144966, 12.283322026227271, 12.5475097130865, 12.806248474865699, 13.059862173851608, 13.308643807691302, 13.552859476877934, 13.792751719653335, 14.028542333400146, 14.26043477598071, 14.488616221019868, 14.71325932619962, 14.934523762075576, 15.15255753990065, 15.367498169838838, 15.57947367532036, 15.788603484792443, 15.994999218505766, 16.19876538505327, 16.400000000000002, 16.598795136997147, 16.795237420173613, 16.989408465276245, 17.181385275931625, 17.37124060048677, 17.559043254118375, 17.74485841025507, 17.928747864811978, 18.110770276274835, 18.290981384277885, 18.469434208984318, 18.646179233290667, 18.821264569629747, 18.994736112934028, 19.166637681137505, 19.337011144434914, 19.505896544378576, 19.673332203772702, 19.83935482821959, 20.003999600079982, 20.16730026552885, 20.3292892153169, 20.489997559785117, 20.64945519862449, 20.807690885823927, 20.964732290205855, 21.12060605191054, 21.275337835155522, 21.4289523775662, 21.58147353634594, 21.7329243315298, 21.88332698654389, 22.03270296627266, 22.181073012818835, 22.328457179124584, 22.47487486060824, 22.62034482495791, 22.764885240211516, 22.908513701242168, 23.05124725475826, 23.193102422918763, 23.334095225656384, 23.474241201793937, 23.613555429032708, 23.75205254288564, 23.889746754622582, 24.02665186828993, 24.16278129686233, 24.298148077579906, 24.432764886520726, 24.566644052454542, 24.699797570020696, 24.832237112270015, 24.96397404260788, 25.095019426173, 25.2253840406841, 25.35507838678477, 25.484112697914366, 25.612496949731398, 25.740240869113876], [0.0, 2.5922962793631443, 3.6660605559646724, 4.489988864128731, 5.184592558726289, 5.796550698475777, 6.349803146555018, 6.8585712797928995, 7.332121111929345, 7.776888838089433, 8.19756061276768, 8.597674104081872, 8.979977728257461, 9.34665715643834, 9.699484522385713, 10.039920318408907, 10.369185117452577, 10.688311372709911, 10.998181667894016, 11.29955751346043, 11.593101396951553, 11.879393923934, 12.158947322856532, 12.432216214336044, 12.699606293110037, 12.961481396815723, 13.218169313486648, 13.469966592386191, 13.717142559585799, 13.95994269329212, 14.198591479439079, 14.433294842134973, 14.66424222385869, 14.89160837518903, 15.11555490215295, 15.336231610144653, 15.553777676178866, 15.76832267554162, 15.979987484350545, 16.188885075878453, 16.39512122553536, 16.598795136997147, 16.800000000000004, 16.998823488700623, 17.195348208163743, 17.389652095427326, 17.58180878066873, 17.77188791321845, 17.959955456514923, 18.14607395554201, 18.330302779823363, 18.51269834464982, 18.69331431287668, 18.872201779336724, 19.049409439665055, 19.224983745116667, 19.398969044771427, 19.57140771636011, 19.742340286804907, 19.91180554344583, 20.079840636817814, 20.246481175750024, 20.41176131547692, 20.575713839378697, 20.738370234905155, 20.89976076418101, 21.059914529741096, 21.21885953579975, 21.376622745419823, 21.533230133911637, 21.68870673876154, 21.84307670636168, 21.996363335788033, 22.148589119851405, 22.299775783626167, 22.44994432064365, 22.59911502692086, 22.74730753298069, 22.8945408340067, 23.040833318263473, 23.186202793903107, 23.3306665142683, 23.47424120179394, 23.61694307060082, 23.758787847868, 23.899790794063453, 24.039966722106755, 24.179330015531864, 24.317894645713064, 24.455674188212438, 24.592681838303037, 24.728930425717973, 24.86443242867209, 24.999199987199596, 25.133244915848017, 25.266578715766013, 25.399212586220074, 25.53115743557272, 25.662423891752706, 25.79302231224562, 25.922962793631445, 26.052255180694054], [0.0, 2.6229754097208002, 3.709447398198281, 4.543126676640219, 5.2459508194416005, 5.865151319446072, 6.424951361683604, 6.9397406291589885, 7.418894796396562, 7.8689262291624, 8.294576541331088, 8.699425268372618, 9.086253353280439, 9.457272334029511, 9.814275317108237, 10.158740079360234, 10.491901638883201, 10.814804667676619, 11.128342194594843, 11.433284742365162, 11.730302638892145, 12.019983361053376, 12.302845199383759, 12.57934815481311, 12.849902723367208, 13.114877048604, 13.37460279784039, 13.629380029920656, 13.879481258317977, 14.12515486640766, 14.366627996854374, 14.604109010822945, 14.837789592793124, 15.06784656146989, 15.294443435444128, 15.517731793016656, 15.7378524583248, 15.954936540143304, 16.16910634512619, 16.380476183554617, 16.589153082662175, 16.795237420173613, 16.998823488700623, 17.199999999999996, 17.398850536745236, 17.59545395833821, 17.78988476634967, 17.982213434391216, 18.172506706560878, 18.3608278680456, 18.547236990991408, 18.731791158348955, 18.914544668059023, 19.095549219648017, 19.274854085050812, 19.452506265260524, 19.628550634216474, 19.8030300711785, 19.975985582694037, 20.14745641514084, 20.317480158720468, 20.486092843683004, 20.653329029480936, 20.819221887476967, 20.983803277766402, 21.14710382061808, 21.309152962987522, 21.469979040511426, 21.629609335353237, 21.788070130234114, 21.945386758952324, 22.101583653666086, 22.256684389189687, 22.4107117245303, 22.563687641872722, 22.715633383201094, 22.866569484730324, 23.016515809305282, 23.165491576912416, 23.313515393436486, 23.46060527778429, 23.6067786874872, 23.752052542885636, 23.896443249990153, 24.03996672210675, 24.182638400306942, 24.324473272817233, 24.465485893396842, 24.605690398767518, 24.745100525154466, 24.88372962399326, 25.02159067685346, 25.15869630962622, 25.295058806019803, 25.43069012040373, 25.565601890039666, 25.699805446734416, 25.833311827948037, 25.96613178738797, 26.098275805117854, 26.229754097208, 26.36057662495265], [0.0, 2.65329983228432, 3.752332607858744, 4.595650117230424, 5.30659966456864, 5.9329587896765315, 6.499230723708769, 7.019971509913698, 7.504665215717488, 7.95989949685296, 8.390470785361213, 8.8, 9.191300234460847, 9.566608594481119, 9.927738916792686, 10.276186062932103, 10.61319932913728, 10.939835464941876, 11.256997823576231, 11.56546583584077, 11.865917579353063, 12.158947322856532, 12.445079348883239, 12.724778976469494, 12.998461447417538, 13.266499161421601, 13.529227620230213, 13.78695035169127, 14.039943019827396, 14.288456879593403, 14.53272169966796, 14.772948250095512, 15.009330431434975, 15.242047106606122, 15.471263684650975, 15.697133496278868, 15.91979899370592, 16.139392801465615, 16.356038640208702, 16.569852141766386, 16.780941570722426, 16.989408465276245, 17.195348208163743, 17.398850536745236, 17.6, 17.798876369029593, 17.99555500672319, 18.19010720144332, 18.382600468921694, 18.57309882599024, 18.76166303929372, 18.948350851723223, 19.133217188962238, 19.31631434823942, 19.497692171126307, 19.67739820199815, 19.855477833585372, 20.031974440878265, 20.206929504504146, 20.380382724571195, 20.552372125864206, 20.72293415518179, 20.892103771520954, 21.059914529741096, 21.22639865827456, 21.3915871313935, 21.55550973649197, 21.718195136797167, 21.87967092988375, 22.03996370232946, 22.199099080818577, 22.357101779971394, 22.513995647152463, 22.66980370448761, 22.82454818829937, 22.978250586152118, 23.13093167168154, 23.2826115373684, 23.4333096254029, 23.583044756773884, 23.731835158706126, 23.879698490558884, 24.026651868289935, 24.172711887581006, 24.317894645713064, 24.46221576227305, 24.60569039876752, 24.748333277212833, 24.890158697766477, 25.031180555459226, 25.17141235608364, 25.310867231290203, 25.44955795293899, 25.587496946751166, 25.724696305301645, 25.86116780039138, 25.996922894835077, 26.131972753697724, 26.266328255011206, 26.400000000000006, 26.532998322843202, 26.665333299998338], [0.0, 2.6832815729997477, 3.7947331922020546, 4.6475800154489, 5.366563145999495, 6.0, 6.572670690061993, 7.099295739719539, 7.589466384404109, 8.049844718999243, 8.48528137423857, 8.899438184514796, 9.2951600308978, 9.674709297958259, 10.039920318408905, 10.392304845413262, 10.73312629199899, 11.063453348751464, 11.384199576606164, 11.696153213770756, 12.0, 12.296340919151518, 12.585706178041818, 12.86856635371633, 13.145341380123986, 13.416407864998737, 13.682105101189656, 13.942740046346701, 14.198591479439077, 14.449913494550755, 14.696938456699067, 14.939879517586478, 15.178932768808219, 15.414279094398156, 15.646085772486355, 15.874507866387543, 16.099689437998485, 16.321764610482532, 16.540858502508264, 16.75708805252273, 16.97056274847714, 17.181385275931625, 17.389652095427326, 17.59545395833821, 17.798876369029593, 17.999999999999996, 18.19890106572372, 18.39565166010707, 18.5903200617956, 18.78297101099823, 18.973665961010276, 19.162463307205574, 19.349418595916518, 19.53458471531965, 19.718012070185978, 19.8997487421324, 20.07984063681781, 20.258331619360956, 20.43526363911168, 20.6106768447812, 20.784609690826525, 20.957099035887573, 21.128180233990808, 21.297887219158618, 21.46625258399798, 21.633307652783934, 21.79908254950194, 21.96360626126775, 22.12690669750293, 22.28901074520805, 22.44994432064365, 22.609732417700123, 22.76839915321233, 22.925967809451357, 23.082460874005612, 23.2379000772445, 23.392306427541513, 23.5457002444183, 23.6981011897578, 23.849528297222147, 24.0, 24.149534156997728, 24.298148077579906, 24.44585854495603, 24.592681838303037, 24.73863375370596, 24.883729623993265, 25.027984337537053, 25.171412356083636, 25.31402773167478, 25.45584412271571, 25.596874809241847, 25.73713270743266, 25.87663038341739, 26.015380066414558, 26.15339366124404, 26.29068276024797, 26.42725865465429, 26.563132345414385, 26.698314553544385, 26.832815729997474, 26.96664606509308], [0.0, 2.7129319932501073, 3.8366652186501757, 4.698936049788293, 5.4258639865002145, 6.066300355241241, 6.64529909033446, 7.177743377970545, 7.6733304373003515, 8.138795979750322, 8.579044235810887, 8.997777503361595, 9.397872099576587, 9.781615408509987, 10.150862032359617, 10.507140429250956, 10.851727973000429, 11.18570516328765, 11.509995655950528, 11.825396399275588, 12.132600710482482, 12.432216214336044, 12.724778976469494, 13.010764773832475, 13.29059818066892, 13.564659966250538, 13.833293172632468, 14.096808149364879, 14.35548675594109, 14.609585894199741, 14.859340496805368, 15.104966070799366, 15.346660874600703, 15.584607791022528, 15.818975946628152, 16.049922118191105, 16.277591959500644, 16.502121075789017, 16.7236359682935, 16.9422548676379, 17.158088471621774, 17.37124060048677, 17.58180878066873, 17.78988476634967, 17.99555500672319, 18.19890106572372, 18.400000000000002, 18.598924700100273, 18.795744199153173, 18.990523952750753, 19.18332609325088, 19.374209661299737, 19.563230817019974, 19.750443033005617, 19.93589727100338, 20.11964214393487, 20.301724064719235, 20.482187383187373, 20.661074512231934, 20.83842604420977, 21.014280858501913, 21.188676221038445, 21.361647876509902, 21.533230133911633, 21.703455946000858, 21.872356983187704, 22.03996370232946, 22.206305410851215, 22.3714103265753, 22.53530563360524, 22.698017534577772, 22.85957129956728, 23.019991311901055, 23.179301111120672, 23.337523433303716, 23.494680248941464, 23.650792798551176, 23.80588162618642, 23.959966610995103, 24.11306699696246, 24.265201420964964, 24.416387939250967, 24.566644052454542, 24.71598672924065, 24.86443242867209, 25.011997121381572, 25.158696309626222, 25.304545046295537, 25.44955795293899, 25.593749236874224, 25.73713270743266, 25.8797217913949, 26.02152954766495, 26.162568681228535, 26.30285155643776, 26.442390209661454, 26.58119636133784, 26.71928142746358, 26.85665653055123, 26.993332510084784, 27.129319932501076, 27.26462910072316], [0.0, 2.7422618401604177, 3.878143885933063, 4.749736834815168, 5.4845236803208355, 6.131883886702357, 6.717142249498666, 7.255342858886822, 7.756287771866126, 8.226785520481252, 8.67179335547152, 9.09505360072166, 9.499473669630335, 9.88736567544662, 10.260604270704528, 10.620734437881403, 10.969047360641671, 11.306635220082056, 11.63443165779919, 11.95324223798715, 12.263767773404714, 12.566622457924007, 12.862348152650823, 13.151425778218877, 13.434284498997332, 13.71130920080209, 13.982846634358829, 14.249210504445502, 14.510685717773644, 14.767531953579788, 15.019986684414869, 15.268267747193851, 15.512575543732252, 15.753094934012175, 15.989996873045348, 16.2234398325386, 16.453571040962505, 16.680527569594435, 16.904437287292353, 17.125419702886116, 17.34358671094304, 17.559043254118375, 17.77188791321845, 17.982213434391216, 18.19010720144332, 18.39565166010707, 18.598924700100273, 18.8, 18.99894733926067, 19.195832881122925, 19.390719429665317, 19.58366666382984, 19.77473135089324, 19.963967541548453, 20.151426748496, 20.33715811021786, 20.521208541409056, 20.703622871372055, 20.884443971530583, 21.063712873090537, 21.241468875762806, 21.417749648364087, 21.592591322025246, 21.766028576660467, 21.938094721283342, 22.108821768696764, 22.27824050503091, 22.44638055455712, 22.61327044016411, 22.77893763984616, 22.94340863951998, 23.10670898245789, 23.26886331559838, 23.429895432971954, 23.589828316458767, 23.748684174075834, 23.9064844759743, 24.063249988312055, 24.21900080515297, 24.3737563785314, 24.52753554680943, 24.68035656144376, 24.83223711227001, 24.983194351403505, 25.133244915848014, 25.282404948896772, 25.430690120403735, 25.57811564599707, 25.724696305301645, 25.870446459232202, 26.015380066414558, 26.159510698787926, 26.302851556437755, 26.445415481704956, 26.587214972614188, 26.72826219566098, 26.868568997994664, 27.008146919031674, 27.147007201531444, 27.285160802164977, 27.42261840160418, 27.559390414158297], [0.0, 2.771281292110204, 3.9191835884530852, 4.800000000000002, 5.542562584220408, 6.196773353931868, 6.788225099390857, 7.332121111929345, 7.8383671769061705, 8.313843876330612, 8.763560920082659, 9.191300234460847, 9.600000000000003, 9.991996797437439, 10.369185117452577, 10.73312629199899, 11.085125168440817, 11.426285485668561, 11.757550765359257, 12.079735096433202, 12.393546707863736, 12.699606293110037, 12.998461447417538, 13.290598180668923, 13.576450198781714, 13.856406460551021, 14.130817386124559, 14.400000000000002, 14.66424222385869, 14.923806484942107, 15.178932768808222, 15.42984121758873, 15.676734353812341, 15.919798993705923, 16.15920790137933, 16.39512122553536, 16.627687752661224, 16.857046004564385, 17.0833252032501, 17.306646122227153, 17.527121840165318, 17.74485841025507, 17.959955456514923, 18.172506706560878, 18.382600468921694, 18.5903200617956, 18.795744199153173, 18.99894733926067, 19.200000000000006, 19.398969044771427, 19.595917942265427, 19.790907002964776, 19.983993594874878, 20.17523234066959, 20.36467529817257, 20.55237212586421, 20.738370234905155, 20.922714928995237, 21.105449533236676, 21.286615513040115, 21.46625258399798, 21.644398813549895, 21.82109071517737, 21.996363335788036, 22.170250336881633, 22.34278407003031, 22.513995647152466, 22.683915006012523, 22.852570971337123, 23.01999131190106, 23.186202793903107, 23.35123123092228, 23.515101530718514, 23.67783773911799, 23.839463081202144, 24.000000000000004, 24.159470192866404, 24.317894645713064, 24.475293665245374, 24.63168690934505, 24.787093415727472, 24.941531628991836, 25.095019426173, 25.247574140895203, 25.399212586220074, 25.549951076274105, 25.69980544673442, 25.848791074245625, 25.996922894835077, 26.14421542138911, 26.290682760247975, 26.436338626973292, 26.581196361337845, 26.725268941584112, 26.868568997994668, 27.011108825814613, 27.152900397563428, 27.293955374771176, 27.434285119171598, 27.57390070338254, 27.712812921102042, 27.851032296846743], [0.0, 2.8000000000000003, 3.959797974644666, 4.849742261192857, 5.6000000000000005, 6.260990336999412, 6.858571279792899, 7.408103670980854, 7.919595949289332, 8.4, 8.854377448471462, 9.28654941299512, 9.699484522385713, 10.09554357129917, 10.476640682967036, 10.844353369380766, 11.200000000000001, 11.54469575172945, 11.879393923933998, 12.204917041913887, 12.521980673998824, 12.831211945876353, 13.133164127505603, 13.428328265275615, 13.717142559585797, 14.0, 14.277254638059798, 14.54922678357857, 14.816207341961707, 15.078461459976612, 15.336231610144651, 15.589740215924062, 15.839191898578663, 16.08477541030648, 16.32666530556684, 16.565023392678924, 16.8, 17.031735084835017, 17.260359208313137, 17.485994395515515, 17.708754896942924, 17.928747864811978, 18.14607395554201, 18.3608278680456, 18.57309882599024, 18.78297101099823, 18.990523952750753, 19.195832881122925, 19.398969044771427, 19.6, 19.79898987322333, 19.995999599919983, 20.19108714259834, 20.38430768998545, 20.575713839378697, 20.765355763867856, 20.95328136593407, 21.139536418758098, 21.324164696418944, 21.5072080940321, 21.68870673876153, 21.86869909253863, 22.04722204723307, 22.22431101294256, 22.400000000000002, 22.574321695235938, 22.747307532980688, 22.91898776124286, 23.0893915034589, 23.25854681617061, 23.426480742954116, 23.593219364893805, 23.758787847867996, 23.923210486889086, 24.086510747719355, 24.24871130596428, 24.409834083827775, 24.569900284697944, 24.728930425717973, 24.88694436848365, 25.043961347997648, 25.200000000000003, 25.35507838678477, 25.509214021604038, 25.662423891752706, 25.814724480420086, 25.966131787387972, 26.116661348648684, 26.266328255011206, 26.41514716975849, 26.563132345414388, 26.71029763967448, 26.85665653055123, 27.002222130780275, 27.147007201531444, 27.291024165465096, 27.434285119171594, 27.576801845029095, 27.71858582251266, 27.85964823898536, 28.0, 28.139651739138497], [0.0, 2.8284271247461903, 4.0, 4.898979485566357, 5.656854249492381, 6.324555320336759, 6.92820323027551, 7.4833147735478835, 8.0, 8.48528137423857, 8.94427190999916, 9.38083151964686, 9.797958971132713, 10.19803902718557, 10.583005244258363, 10.954451150103322, 11.313708498984761, 11.661903789690601, 12.0, 12.328828005937956, 12.649110640673518, 12.961481396815723, 13.266499161421601, 13.564659966250538, 13.85640646055102, 14.142135623730953, 14.422205101855958, 14.69693845669907, 14.966629547095767, 15.231546211727819, 15.491933384829668, 15.748015748023622, 16.0, 16.24807680927192, 16.492422502470642, 16.73320053068151, 16.97056274847714, 17.204650534085257, 17.435595774162696, 17.663521732655695, 17.88854381999832, 18.110770276274835, 18.330302779823363, 18.547236990991408, 18.76166303929372, 18.973665961010276, 19.18332609325088, 19.390719429665317, 19.595917942265427, 19.79898987322333, 20.000000000000004, 20.19900987672416, 20.39607805437114, 20.591260281974005, 20.784609690826528, 20.976176963403034, 21.166010488516726, 21.354156504062622, 21.54065922853802, 21.72556098240043, 21.908902300206645, 22.090722034374522, 22.271057451320086, 22.44994432064365, 22.627416997969522, 22.80350850198276, 22.978250586152114, 23.15167380558045, 23.323807579381203, 23.494680248941464, 23.664319132398468, 23.832750575625973, 24.0, 24.166091947189145, 24.331050121192877, 24.494897427831784, 24.65765601187591, 24.819347291981714, 24.979991993593597, 25.13961017995307, 25.298221281347036, 25.455844122715714, 25.612496949731398, 25.768197453450252, 25.922962793631445, 26.076809620810597, 26.229754097208005, 26.38181191654584, 26.532998322843202, 26.68332812825267, 26.832815729997478, 26.981475126464083, 27.129319932501076, 27.276363393971714, 27.42261840160418, 27.568097504180443, 27.71281292110204, 27.856776554368242, 28.0, 28.14249455894058, 28.284271247461906, 28.425340807103794], [0.0, 2.8565713714171403, 4.039801975344831, 4.947726750741194, 5.713142742834281, 6.387487769068526, 6.997142273814362, 7.557777451076475, 8.079603950689663, 8.56971411425142, 9.033271832508973, 9.474175425861612, 9.895453501482388, 10.299514551666988, 10.688311372709911, 11.063453348751464, 11.426285485668561, 11.777945491468367, 12.119405926034496, 12.451505933018707, 12.774975538137053, 13.09045453756286, 13.398507379555383, 13.699635031634969, 13.994284547628723, 14.282856857085703, 14.565713164826501, 14.843180252223581, 15.11555490215295, 15.383107618423532, 15.646085772486357, 15.904716281656837, 16.159207901379325, 16.409753197412815, 16.656530250925613, 16.899704139422088, 17.13942822850284, 17.37584530317878, 17.609088562444114, 17.83928249678221, 18.066543665017946, 18.290981384277885, 18.51269834464982, 18.731791158348955, 18.948350851723223, 19.162463307205574, 19.374209661299737, 19.58366666382984, 19.790907002964776, 19.995999599919983, 20.19900987672416, 20.400000000000006, 20.599029103333976, 20.796153490489537, 20.991426821443085, 21.18490028298458, 21.376622745419823, 21.566640906733717, 21.75499942541944, 21.941741043043965, 22.12690669750293, 22.310535627814946, 22.49266547121528, 22.673332353229423, 22.852570971337123, 23.030414672775652, 23.20689552697646, 23.382044393080776, 23.555890982936734, 23.72846391994223, 23.899790794063453, 24.069898213328617, 24.23881185206899, 24.406556496154884, 24.573156085452272, 24.738633753705965, 24.903011866037414, 25.066312054229282, 25.228555249954372, 25.389761716093364, 25.549951076274105, 25.709142342754262, 25.867353942759593, 26.024603743380997, 26.18090907512572, 26.336286754210438, 26.49075310367752, 26.644323973409424, 26.797014759110766, 26.94884042032236, 27.09981549752692, 27.24995412840176, 27.399270063269938, 27.547776679797597, 27.695486996982023, 27.84241368847177, 27.988569095257446, 28.133965237769104, 28.27861382741382, 28.422526277584833, 28.565713714171405, 28.70818698559699], [0.0, 2.8844410203711917, 4.079215610874228, 4.9959983987187195, 5.768882040742383, 6.44980619863884, 7.065408693062278, 7.631513611335566, 8.158431221748456, 8.653323061113575, 9.121403400793104, 9.566608594481119, 9.991996797437439, 10.400000000000002, 10.792590050585634, 11.171392035015153, 11.537764081484767, 11.892854997854805, 12.237646832622685, 12.572986916401371, 12.89961239727768, 13.218169313486646, 13.52922762023021, 13.833293172632468, 14.130817386124557, 14.422205101855958, 14.70782104868019, 14.987995196156158, 15.263027222671132, 15.53319027115808, 15.798734126505199, 16.059887919907787, 16.316862443496913, 16.569852141766386, 16.819036833302913, 17.064583206161235, 17.30664612222715, 17.54536975956905, 17.780888616714297, 18.013328398716325, 18.24280680158621, 18.469434208984318, 18.69331431287668, 18.914544668059023, 19.133217188962238, 19.349418595916518, 19.563230817019974, 19.77473135089324, 19.983993594874878, 20.19108714259834, 20.39607805437114, 20.599029103333976, 20.800000000000004, 20.999047597450705, 21.196226079186836, 21.391587131393504, 21.585180101171268, 21.77705214210592, 21.96724834839357, 22.155811878601966, 22.342784070030305, 22.52820454452596, 22.712111306525426, 22.894540834006698, 23.075528162969533, 23.25510696599781, 23.4333096254029, 23.61016730139793, 23.78570999570961, 23.959966610995103, 24.132965006397374, 24.3047320495413, 24.47529366524537, 24.64467488119898, 24.812899870833316, 24.979991993593593, 25.145973832802742, 25.310867231290203, 25.474693324945058, 25.637472574339306, 25.79922479455536, 25.959969183340725, 26.119724347703215, 26.278508329050947, 26.436338626973292, 26.59323222175146, 26.749205595680785, 26.904274753280383, 27.05845524046042, 27.211762162711917, 27.36421020237931, 27.515813635071744, 27.666586345264935, 27.81654184114194, 27.965693268717658, 28.114053425288926, 28.261634772249113, 28.408449447303532, 28.554509276119596, 28.69982578344336, 28.844410203711917, 28.988273491189506], [0.0, 2.9120439557122078, 4.118252056394801, 5.043808085167398, 5.8240879114244155, 6.511528238439884, 7.1330218000508046, 7.70454411370329, 8.236504112789602, 8.736131867136622, 9.208691546577072, 9.65815717411971, 10.087616170334796, 10.499523798725352, 10.89587077750099, 11.278297743897348, 11.648175822848831, 12.006664815842909, 12.354756169184402, 12.693305322097947, 13.023056476879768, 13.344661854089823, 13.6586968631711, 13.965672200076876, 14.266043600101609, 14.56021977856104, 14.848568954616471, 15.131424255502193, 15.40908822740658, 15.68183662713013, 15.94992162990151, 16.213574559608997, 16.473008225579203, 16.728418933061192, 16.9799882214329, 17.227884373886425, 17.472263734273245, 17.713271860387625, 17.951044537853505, 18.18570867467089, 18.417383093154143, 18.646179233290667, 18.872201779336724, 19.095549219648017, 19.31631434823942, 19.53458471531965, 19.750443033005617, 19.963967541548453, 20.17523234066959, 20.38430768998545, 20.591260281974005, 20.796153490489537, 20.999047597450705, 21.200000000000003, 21.399065400152413, 21.596295978708945, 21.79174155500198, 21.985449733858076, 22.177466041006582, 22.367834048025305, 22.556595487794695, 22.7437903613272, 22.929457036746424, 23.11363234110987, 23.296351645697662, 23.477648945326703, 23.657556932193994, 23.83610706470333, 24.013329631685817, 24.18925381238537, 24.3639077325457, 24.537318516904005, 24.709512338368803, 24.880514464134382, 25.050349298961883, 25.219040425836987, 25.386610644195894, 25.553082005895103, 25.71847584908562, 25.88281283013885, 26.046112953759536, 26.20839560140987, 26.36967955815922, 26.52998303806469, 26.689323708179646, 26.84771871127974, 27.005184687389203, 27.16173779418394, 27.3173937263422, 27.472167733908442, 27.626074639731215, 27.77912885603147, 27.93134440015375, 28.082734909548968, 28.233313656034078, 28.383093559370867, 28.532087200203218, 28.68030683238937, 28.827764394763605, 28.97447152235913, 29.12043955712208, 29.26567955814456], [0.0, 2.939387691339814, 4.156921938165306, 5.091168824543143, 5.878775382679628, 6.572670690061994, 7.2, 7.776888838089433, 8.313843876330612, 8.818163074019441, 9.2951600308978, 9.748846085563153, 10.182337649086286, 10.598113039593418, 10.998181667894016, 11.384199576606164, 11.757550765359255, 12.119405926034494, 12.470765814495918, 12.812493902437575, 13.145341380123988, 13.469966592386191, 13.786950351691269, 14.096808149364879, 14.4, 14.69693845669907, 14.987995196156158, 15.273506473629428, 15.553777676178866, 15.829087149927505, 16.099689437998485, 16.36581803638303, 16.627687752661224, 16.88549673536435, 17.13942822850284, 17.389652095427326, 17.636326148038883, 17.87959731090161, 18.119602644649802, 18.356470248934027, 18.5903200617956, 18.821264569629747, 19.049409439665055, 19.274854085050812, 19.497692171126307, 19.718012070185978, 19.93589727100338, 20.151426748496, 20.36467529817257, 20.575713839378697, 20.784609690826528, 20.991426821443085, 21.196226079186836, 21.399065400152413, 21.6, 21.799082549501943, 21.996363335788033, 22.191890410688316, 22.385709727413158, 22.577865266672134, 22.76839915321233, 22.957351763650788, 23.144761826383093, 23.330666514268298, 23.51510153071851, 23.698101189757796, 23.87969849055888, 24.059925186916107, 24.238811852068988, 24.416387939250967, 24.592681838303037, 24.767720928660353, 24.941531628991836, 25.11413944374762, 25.285569006846572, 25.45584412271571, 25.62498780487515, 25.793022312245615, 25.95996918334073, 26.12584926849269, 26.290682760247975, 26.454489222058324, 26.617287615382605, 26.779096325305677, 26.939933184772382, 27.09981549752692, 27.258760059841315, 27.416783181110073, 27.573900703382538, 27.730128019899222, 27.885480092693403, 28.039971469315017, 28.193616298729758, 28.346428346442522, 28.498421008891004, 28.649607327151973, 28.8, 28.949611396355568, 29.09845356715714, 29.246538256689462, 29.39387691339814, 29.540480700218815], [0.0, 2.9664793948382653, 4.1952353926806065, 5.1380930314660525, 5.932958789676531, 6.6332495807108005, 7.266360849833981, 7.848566748139434, 8.390470785361213, 8.899438184514796, 9.38083151964686, 9.838699100999076, 10.276186062932105, 10.695793565696752, 11.099549540409287, 11.489125293076057, 11.865917579353061, 12.231107881136525, 12.58570617804182, 12.930583900195693, 13.266499161421601, 13.594116374373144, 13.91402170474087, 14.226735395022994, 14.532721699667961, 14.832396974191328, 15.12613632095123, 15.414279094398156, 15.697133496278868, 15.974980438172688, 16.24807680927192, 16.516658257650064, 16.780941570722426, 17.041126723312637, 17.297398648351724, 17.549928774784245, 17.798876369029593, 18.04438970982394, 18.286607121059937, 18.52565788305506, 18.76166303929372, 18.994736112934028, 19.224983745116667, 19.452506265260524, 19.67739820199815, 19.8997487421324, 20.11964214393487, 20.33715811021786, 20.55237212586421, 20.765355763867856, 20.976176963403034, 21.18490028298458, 21.391587131393504, 21.596295978708945, 21.799082549501943, 22.0, 22.199099080818574, 22.39642828667107, 22.592033994308704, 22.785960589801782, 22.978250586152114, 23.16894473211933, 23.35808211305029, 23.545700244418303, 23.731835158706122, 23.916521486202797, 24.099792530227308, 24.2816803372419, 24.46221576227305, 24.641428530018306, 24.819347291981714, 24.995999679948792, 25.17141235608364, 25.345611059905423, 25.51862065237853, 25.69046515733026, 25.861167800391385, 26.03075104563831, 26.199236630100508, 26.366645596283195, 26.532998322843202, 26.69831455354439, 26.862613424609307, 27.02591349057419, 27.188232748746287, 27.349588662354687, 27.50999818247904, 27.66947776883402, 27.82804340948174, 27.985710639538887, 28.142494558940577, 28.29840984931839, 28.453470790045987, 28.60769127350196, 28.761084819596082, 28.913664589601918, 29.065443399335923, 29.21643373172024, 29.366647748764244, 29.516097302997228, 29.664793948382655, 29.812748950742538], [0.0, 2.9933259094191533, 4.233202097703344, 5.184592558726289, 5.986651818838307, 6.6932802122726045, 7.332121111929344, 7.919595949289333, 8.466404195406689, 8.97997772825746, 9.465727652959385, 9.927738916792686, 10.369185117452577, 10.792590050585634, 11.2, 11.59310139695155, 11.973303637676613, 12.34179889643321, 12.699606293110035, 13.047605144240073, 13.386560424545209, 13.717142559585797, 14.039943019827396, 14.35548675594109, 14.664242223858688, 14.966629547095765, 15.26302722267113, 15.553777676178866, 15.839191898578665, 16.119553343687908, 16.395121225535355, 16.666133324799727, 16.932808390813378, 17.195348208163743, 17.453939383417143, 17.708754896942924, 17.95995545651492, 18.207690682785667, 18.452100151473275, 18.693314312876677, 18.93145530591877, 19.166637681137505, 19.398969044771427, 19.628550634216474, 19.855477833585372, 20.07984063681781, 20.301724064719235, 20.521208541409056, 20.738370234905155, 20.95328136593407, 21.166010488516726, 21.376622745419823, 21.585180101171268, 21.79174155500198, 21.996363335788033, 22.199099080818574, 22.4, 22.599115026920856, 22.796490958040014, 22.99217258111986, 23.1862027939031, 23.37862271392393, 23.569471780249973, 23.758787847867996, 23.946607275353227, 24.132965006397367, 24.31789464571306, 24.501428529781688, 24.68359779286642, 24.864432428672085, 25.043961347997644, 25.222212432695112, 25.39921258622007, 25.574987781033247, 25.749563103089727, 25.92296279363144, 26.095210288480146, 26.266328255011206, 26.436338626973292, 26.605262637305426, 26.773120849090418, 26.93993318477238, 27.10571895375587, 27.270496878494896, 27.434285119171594, 27.597101297056543, 27.758962516635957, 27.919885386584237, 28.07988603965479, 28.238980151556465, 28.397182958878155, 28.554509276119596, 28.71097351188218, 28.866589684269947, 29.021371435547287, 29.17533204609675, 29.328484447717376, 29.48084123630125, 29.632414683923415, 29.783216750378056, 29.93325909419153, 30.082553083141068], [0.0, 3.0199337741083, 4.2708313008125245, 5.230678732248809, 6.0398675482166, 6.752777206453653, 7.397296803562772, 7.989993742175272, 8.541662601625049, 9.0598013223249, 9.549869109050658, 10.015987220439133, 10.461357464497619, 10.88852607105296, 11.299557513460428, 11.696153213770756, 12.0797350964332, 12.451505933018705, 12.812493902437573, 13.163586137523469, 13.505554412907307, 13.839075113604956, 14.164744967700619, 14.48309359218534, 14.794593607125543, 15.0996688705415, 15.398701243936127, 15.692036196746425, 15.979987484350543, 16.262841080204897, 16.540858502508264, 16.81427964558696, 17.083325203250098, 17.348198753761153, 17.60908856244411, 17.866169147301836, 18.1196026446498, 18.369540005128055, 18.616122045152153, 18.859480374602054, 19.099738218101315, 19.337011144434914, 19.57140771636011, 19.8030300711785, 20.031974440878265, 20.258331619360956, 20.482187383187373, 20.703622871372055, 20.922714928995237, 21.139536418758098, 21.354156504062622, 21.566640906733717, 21.77705214210592, 21.985449733858076, 22.191890410688316, 22.39642828667107, 22.599115026920856, 22.8, 22.999130418344084, 23.196551467836763, 23.392306427541513, 23.58643678048891, 23.778982316322956, 23.969981226525814, 24.1594701928664, 24.34748446965312, 24.534057960313046, 24.7192232887686, 24.90301186603741, 25.085453952440247, 25.266578715766013, 25.446414285710276, 25.624987804875147, 25.80232547659222, 25.978452609807228, 26.153393661244042, 26.327172275046937, 26.49981132008302, 26.671332925071447, 26.841758511692188, 27.011108825814613, 27.1794039669747, 27.34666341621954, 27.51290606242823, 27.678150227209912, 27.84241368847177, 28.005713702742874, 28.16806702633321, 28.329489935401238, 28.48999824499819, 28.649607327151973, 28.808332128049344, 28.96618718437068, 29.123186638827836, 29.27934425495216, 29.434673431176368, 29.589187214251087, 29.742898312034086, 29.89581910568767, 30.047961661317398, 30.199337741083, 30.34995881381061], [0.0, 3.0463092423455636, 4.308131845707603, 5.276362383309169, 6.092618484691127, 6.811754546370562, 7.4619032424710525, 8.059776671843954, 8.616263691415206, 9.13892772703669, 9.633275663033837, 10.103464752252073, 10.552724766618338, 10.983624174196786, 11.398245479020007, 11.798304963002101, 12.185236969382254, 12.560254774486067, 12.92439553712281, 13.278554138158269, 13.623509092741124, 13.95994269329212, 14.288456879593403, 14.609585894199741, 14.923806484942105, 15.231546211727819, 15.533190271158082, 15.829087149927505, 16.119553343687908, 16.404877323527906, 16.685322891691367, 16.961132037691353, 17.232527382830412, 17.499714283381888, 17.762882648939616, 18.0222085217101, 18.27785545407338, 18.529975715040752, 18.778711350888805, 19.024195120950587, 19.266551326067674, 19.505896544378576, 19.742340286804907, 19.975985582694037, 20.206929504504146, 20.43526363911168, 20.661074512231934, 20.884443971530583, 21.105449533236676, 21.324164696418944, 21.54065922853802, 21.75499942541944, 21.96724834839357, 22.177466041006582, 22.385709727413158, 22.592033994308704, 22.796490958040014, 22.999130418344084, 23.200000000000003, 23.399145283535464, 23.596609926004202, 23.792435772740884, 23.98666296090392, 24.179330015531864, 24.37047393876451, 24.560130292814, 24.748333277212833, 24.93511580081392, 25.120509548972134, 25.30454504629554, 25.48725171531839, 25.668657931415115, 25.84879107424562, 26.027677575995906, 26.20534296665472, 26.38181191654584, 26.557108276316537, 26.731255114565798, 26.904274753280383, 27.07618880123272, 27.247018185482247, 27.416783181110073, 27.585503439306674, 27.75319801392265, 27.91988538658424, 28.085583490467137, 28.250309732815325, 28.414081016284868, 28.576913759186805, 28.738823914697694, 28.899826989101513, 29.059938059121876, 29.219171788399482, 29.377542443165666, 29.535063907159575, 29.691749695833014, 29.84761296988421, 30.002666548158686, 30.156922919953224, 30.31039425675622, 30.463092423455638, 30.61502898904393], [0.0, 3.0724582991474434, 4.345112196480086, 5.321653878260029, 6.144916598294887, 6.870225614927067, 7.525955088890711, 8.12896057316063, 8.690224392960172, 9.21737489744233, 9.715966241192895, 10.190191362285598, 10.643307756520057, 11.077905939300983, 11.49608629055993, 11.899579824514811, 12.289833196589774, 12.668070097690492, 13.035336589440258, 13.392535234226566, 13.740451229854134, 14.079772725438433, 14.411106827721456, 14.73499236511509, 15.051910177781423, 15.362291495737216, 15.666524822052912, 15.964961634780085, 16.25792114632126, 16.54569430395715, 16.8285471743701, 17.106723824274475, 17.380448785920343, 17.64992917832817, 17.915356541246954, 18.17690842800282, 18.43474979488466, 18.689034217957865, 18.939904962802743, 19.187495928338333, 19.43193248238579, 19.673332203772702, 19.91180554344583, 20.14745641514084, 20.380382724571195, 20.6106768447812, 20.83842604420977, 21.063712873090537, 21.286615513040115, 21.5072080940321, 21.72556098240043, 21.941741043043965, 22.155811878601966, 22.367834048025305, 22.577865266672134, 22.785960589801782, 22.99217258111986, 23.196551467836763, 23.399145283535464, 23.599999999999998, 23.799159649029622, 23.996666435153028, 24.1925608400599, 24.386881719481888, 24.579666393179547, 24.770950728625653, 24.960769218916308, 25.149155055389038, 25.336140195380985, 25.521755425518833, 25.706030420895406, 25.888993800455047, 26.070673178880515, 26.251095215247684, 26.430285658690863, 26.60826939130014, 26.78507046845313, 26.960712156766185, 27.13521696983461, 27.308606701917256, 27.48090245970827, 27.65212469232699, 27.822293219646724, 27.991427259073443, 28.159545450876866, 28.326665882168342, 28.492806109613003, 28.65798318095675, 28.822213655442912, 28.985513623187703, 29.147898723578685, 29.30938416275579, 29.46998473023018, 29.629714814692363, 29.78858841905739, 29.946619174791664, 30.103820355562846, 30.260204890251487, 30.415785375360603, 30.570574086856794, 30.72458299147443, 30.87782375751245], [0.0, 3.098386676965933, 4.381780460041329, 5.366563145999495, 6.196773353931866, 6.928203230275509, 7.58946638440411, 8.197560612767678, 8.763560920082657, 9.295160030897799, 9.797958971132712, 10.276186062932103, 10.73312629199899, 11.171392035015153, 11.59310139695155, 11.999999999999998, 12.393546707863733, 12.77497553813705, 13.145341380123986, 13.505554412907307, 13.856406460551018, 14.198591479439077, 14.53272169966796, 14.859340496805368, 15.17893276880822, 15.491933384829666, 15.798734126505199, 16.099689437998485, 16.395121225535355, 16.685322891691367, 16.97056274847714, 17.251086922278258, 17.527121840165314, 17.798876369029593, 18.066543665017942, 18.33030277982336, 18.590320061795598, 18.846750383023593, 19.099738218101315, 19.349418595916518, 19.595917942265423, 19.83935482821959, 20.079840636817814, 20.317480158720468, 20.552372125864206, 20.784609690826525, 21.014280858501913, 21.241468875762806, 21.46625258399798, 21.68870673876153, 21.908902300206645, 22.12690669750293, 22.342784070030305, 22.556595487794695, 22.76839915321233, 22.978250586152114, 23.1862027939031, 23.392306427541513, 23.596609926004202, 23.799159649029622, 23.999999999999996, 24.199173539606676, 24.396721091163048, 24.592681838303033, 24.787093415727465, 24.97999199359359, 25.171412356083636, 25.36138797463577, 25.5499510762741, 25.737132707432657, 25.92296279363144, 26.10747019532915, 26.29068276024797, 26.472627372438872, 26.653329998332286, 26.832815729997474, 27.011108825814613, 27.188232748746284, 27.36421020237931, 27.53906316489361, 27.712812921102035, 27.8854800926934, 28.057084666800293, 28.227646023003757, 28.397182958878155, 28.565713714171398, 28.733255993708752, 28.89982698910151, 29.06544339933592, 29.230121450312172, 29.393876913398135, 29.556725123057863, 29.718680993610736, 29.879759035172956, 30.039973368829738, 30.199337741082996, 30.35786553761644, 30.515569796417044, 30.6724632202893, 30.82855818879631, 30.983866769659333, 31.138400729645703], [0.0, 3.1240998703626617, 4.418144406874904, 5.411099703387474, 6.248199740725323, 6.985699678629192, 7.652450587883597, 8.26559132790873, 8.836288813749809, 9.372299611087985, 9.879271228182775, 10.361467077590895, 10.822199406774947, 11.26410227226298, 11.689311356961966, 12.099586769803338, 12.496399481450647, 12.880993750483695, 13.254433220624714, 13.617635624439362, 13.971399357258385, 14.316424134538625, 14.653327267211361, 14.982656640262435, 15.304901175767194, 15.62049935181331, 15.929846201391902, 16.23329911016242, 16.53118265581746, 16.823792675850473, 17.111399708965948, 17.39425192412712, 17.672577627499617, 17.946587419339647, 18.216476058777122, 18.482424083436673, 18.74459922217597, 19.003157632351524, 19.258244987537157, 19.50999743721152, 19.75854245636555, 20.003999600079982, 20.246481175750024, 20.486092843683004, 20.72293415518179, 20.957099035887573, 21.188676221038445, 21.417749648364087, 21.644398813549895, 21.86869909253863, 22.090722034374522, 22.310535627814946, 22.52820454452596, 22.7437903613272, 22.957351763650788, 23.16894473211933, 23.37862271392393, 23.58643678048891, 23.792435772740884, 23.996666435153028, 24.199173539606676, 24.4, 24.599186978434876, 24.79677398372619, 24.992798962901293, 25.18729838628986, 25.38030732674449, 25.571859533479373, 25.76198750096739, 25.95072253329375, 26.138094804327267, 26.324133414036634, 26.508866441249427, 26.692320993124596, 26.87452325158532, 27.055498516937366, 27.235271248878725, 27.413865105088703, 27.59130297756886, 27.767607026893767, 27.94279871451677, 28.116898833263956, 28.28992753613908, 28.461904363552343, 28.63284826907725, 28.802777643831508, 28.97171033957091, 29.139663690578175, 29.306654534422723, 29.47269923166183, 29.637813684548327, 29.80201335480541, 29.96531328052487, 30.127728092240876, 30.289272028228083, 30.449958949069206, 30.609802351534388, 30.768815381811503, 30.92701084812433, 31.084401232772688, 31.24099870362662, 31.396815125104652], [0.0, 3.149603149604724, 4.454211490264017, 5.455272678794342, 6.299206299209448, 7.042726744663604, 7.714920608794364, 8.333066662399863, 8.908422980528034, 9.448809448814172, 9.959919678390985, 10.446051885760477, 10.910545357588685, 11.356055653262713, 11.784735890124987, 12.198360545581524, 12.598412598418896, 12.98614646459834, 13.362634470792052, 13.728801841384412, 14.085453489327207, 14.433294842134972, 14.77294825009551, 15.104966070799366, 15.429841217588727, 15.748015748023622, 16.059887919907784, 16.365818036383025, 16.666133324799727, 16.961132037691353, 17.251086922278258, 17.53624817342638, 17.816845961056067, 18.093092604637828, 18.365184453198392, 18.633303518163384, 18.897618897628345, 19.158288023724875, 19.415457759218555, 19.669265365030796, 19.91983935678197, 20.16730026552885, 20.41176131547692, 20.653329029480936, 20.892103771520954, 21.128180233990808, 21.361647876509902, 21.592591322025246, 21.82109071517737, 22.04722204723307, 22.271057451320086, 22.49266547121528, 22.712111306525426, 22.929457036746424, 23.144761826383093, 23.35808211305029, 23.569471780249973, 23.778982316322956, 23.98666296090392, 24.1925608400599, 24.396721091163048, 24.599186978434876, 24.799999999999997, 24.99919998719959, 25.196825196837793, 25.392912396966203, 25.58749694675116, 25.780612870915228, 25.97229292919668, 26.16256868122853, 26.351470547200964, 26.53902786463739, 26.725268941584105, 26.910221106486656, 27.093910755001755, 27.27636339397171, 27.457603682768823, 27.63765547219952, 27.816541841141937, 27.994285131076307, 28.170906978654415, 28.34642834644252, 28.52086955196142, 28.694250295137525, 28.866589684269943, 29.03790626061046, 29.208218021645894, 29.377542443165662, 29.54589650019102, 29.71329668683702, 29.879759035172956, 30.045299133142276, 30.20993214159873, 30.373672810511408, 30.536535494387703, 30.698534166959824, 30.859682435177454, 31.019993552546076, 31.17948043184812, 31.33815565728143, 31.496031496047245, 31.653119909418095], [0.0, 3.1749015732775088, 4.48998886412873, 5.499090833947009, 6.3498031465550175, 7.0992957397195395, 7.776888838089433, 8.4, 8.97997772825746, 9.524704719832526, 10.039920318408907, 10.529957264870548, 10.998181667894018, 11.447270417003349, 11.879393923933998, 12.296340919151517, 12.699606293110035, 13.090454537562858, 13.46996659238619, 13.839075113604958, 14.198591479439079, 14.54922678357857, 14.891608375189028, 15.226293048539425, 15.553777676178866, 15.874507866387544, 16.188885075878453, 16.497272501841024, 16.8, 17.09736821853001, 17.389652095427326, 17.677103835187484, 17.95995545651492, 18.238420984284797, 18.512698344649817, 18.782971010998235, 19.04940943966505, 19.3121723273173, 19.57140771636011, 19.827253970229968, 20.079840636817814, 20.3292892153169, 20.575713839378697, 20.819221887476967, 21.059914529741096, 21.297887219158618, 21.533230133911633, 21.766028576660467, 21.996363335788036, 22.22431101294256, 22.44994432064365, 22.673332353229423, 22.894540834006698, 23.11363234110987, 23.330666514268298, 23.545700244418303, 23.758787847867996, 23.969981226525814, 24.179330015531864, 24.386881719481888, 24.592681838303033, 24.79677398372619, 24.99919998719959, 25.2, 25.39921258622007, 25.59687480924185, 25.79302231224561, 25.98768939324926, 26.180909075125715, 26.372713171003095, 26.563132345414388, 26.752196171529544, 26.93993318477238, 27.126370933097558, 27.3115360241785, 27.49545416973504, 27.678150227209915, 27.85964823898536, 28.039971469315017, 28.219142439131634, 28.397182958878158, 28.57411415949758, 28.74995652170626, 28.92472990366548, 29.09845356715714, 29.271146202361123, 29.442825951324714, 29.61351043020736, 29.783216750378056, 29.951961538436844, 30.11976095522672, 30.286630713897512, 30.45258609707885, 30.61764197321538, 30.781812812113586, 30.945112699746304, 31.107555352357732, 31.269154129908923, 31.42992204890111, 31.589871794611643, 31.74901573277509, 31.90736592074], [0.0, 3.2, 4.525483399593904, 5.542562584220408, 6.4, 7.155417527999328, 7.8383671769061705, 8.46640419540669, 9.050966799187808, 9.6, 10.119288512538814, 10.61319932913728, 11.085125168440817, 11.537764081484767, 11.973303637676613, 12.393546707863733, 12.8, 13.193938001976514, 13.576450198781712, 13.948476619330158, 14.310835055998655, 14.66424222385869, 15.009330431434975, 15.346660874600705, 15.676734353812341, 16.0, 16.316862443496913, 16.627687752661224, 16.93280839081338, 17.232527382830416, 17.527121840165314, 17.81684596105607, 18.101933598375616, 18.382600468921694, 18.659046063504963, 18.93145530591877, 19.2, 19.464840096954305, 19.726124809500725, 19.983993594874878, 20.23857702507763, 20.489997559785117, 20.738370234905155, 20.983803277766402, 21.22639865827456, 21.46625258399798, 21.703455946000858, 21.938094721283342, 22.170250336881633, 22.400000000000002, 22.627416997969522, 22.852570971337123, 23.075528162969533, 23.296351645697662, 23.51510153071851, 23.731835158706122, 23.946607275353227, 24.1594701928664, 24.37047393876451, 24.579666393179547, 24.787093415727465, 24.992798962901293, 25.196825196837793, 25.39921258622007, 25.6, 25.799224794555357, 25.996922894835073, 26.193128869991842, 26.38787600395303, 26.58119636133784, 26.773120849090418, 26.96367927416435, 27.152900397563425, 27.3408119850161, 27.527440854536405, 27.71281292110204, 27.896953238660316, 28.07988603965479, 28.261634772249113, 28.442222135409885, 28.62167011199731, 28.8, 28.977232442039735, 29.153387453261757, 29.32848444771738, 29.50254226333724, 29.675579185586255, 29.84761296988421, 30.01866086286995, 30.18873962258113, 30.35786553761644, 30.52605444534226, 30.69332174920141, 30.859682435177458, 31.025151087464508, 31.189741903388683, 31.353468707624682, 31.51634496574754, 31.67838379715733, 31.839597987411842, 32.0, 32.15960198758685], [0.0, 3.2249030993194197, 4.560701700396551, 5.585696017507577, 6.449806198638839, 7.211102550927978, 7.899367063252599, 8.532291603080616, 9.121403400793103, 9.674709297958259, 10.198039027185569, 10.69579356569675, 11.171392035015154, 11.627553482998906, 12.066482503198683, 12.489995996796795, 12.899612397277679, 13.296616110875728, 13.682105101189656, 14.057026712644463, 14.422205101855956, 14.778362561528933, 15.126136320951229, 15.466091943344964, 15.798734126505199, 16.1245154965971, 16.443843832875572, 16.75708805252273, 17.06458320616123, 17.36663467687393, 17.663521732655692, 17.95550054997075, 18.242806801586205, 18.525657883055057, 18.804254837669053, 19.078784028338912, 19.349418595916518, 19.616319736382763, 19.879637823662684, 20.139513400278567, 20.396078054371138, 20.64945519862449, 20.89976076418101, 21.14710382061808, 21.3915871313935, 21.633307652783934, 21.872356983187704, 22.108821768696764, 22.34278407003031, 22.574321695235938, 22.80350850198276, 23.030414672775652, 23.25510696599781, 23.477648945326703, 23.698101189757796, 23.916521486202797, 24.132965006397367, 24.34748446965312, 24.560130292814, 24.770950728625653, 24.97999199359359, 25.18729838628986, 25.392912396966203, 25.59687480924185, 25.799224794555357, 25.999999999999996, 26.1992366301005, 26.396969523034265, 26.593232221751457, 26.78805704040515, 26.981475126464083, 27.173516518846064, 27.36421020237931, 27.553584158871235, 27.74166541503952, 27.92848008753788, 28.114053425288926, 28.29840984931839, 28.48157299026864, 28.66356572375461, 28.844410203711913, 29.024127893874777, 29.20273959751037, 29.380265485526163, 29.556725123057866, 29.732137494637012, 29.90652102802999, 30.079893616833154, 30.252272641902458, 30.423674991690266, 30.594117081556707, 30.763614872118, 30.932183886689927, 31.099839227880263, 31.266595593380487, 31.432467291003416, 31.597468253010398, 31.76161204976851, 31.92491190277586, 32.08738069709025, 32.2490309931942, 32.40987503832744], [0.0, 3.249615361854384, 4.595650117230423, 5.628498911788117, 6.499230723708768, 7.266360849833981, 7.95989949685296, 8.597674104081872, 9.191300234460845, 9.748846085563152, 10.276186062932103, 10.777754868245985, 11.256997823576233, 11.71665481270145, 12.15894732285653, 12.585706178041818, 12.998461447417537, 13.398507379555381, 13.786950351691269, 14.16474496770062, 14.532721699667961, 14.891608375189028, 15.24204710660612, 15.584607791022526, 15.91979899370592, 16.24807680927192, 16.569852141766383, 16.88549673536435, 17.195348208163743, 17.499714283381888, 17.79887636902959, 18.093092604637825, 18.38260046892169, 18.667619023324857, 18.94835085172322, 19.224983745116663, 19.497692171126303, 19.76663856096934, 20.031974440878265, 20.293841430345317, 20.552372125864206, 20.807690885823927, 21.059914529741096, 21.309152962987522, 21.55550973649197, 21.79908254950194, 22.03996370232946, 22.27824050503091, 22.513995647152466, 22.747307532980688, 22.978250586152114, 23.20689552697646, 23.4333096254029, 23.657556932193994, 23.87969849055888, 24.099792530227308, 24.31789464571306, 24.534057960313046, 24.748333277212833, 24.960769218916308, 25.171412356083636, 25.38030732674449, 25.58749694675116, 25.79302231224561, 25.996922894835073, 26.1992366301005, 26.4, 26.599248109674075, 26.797014759110763, 26.993332510084784, 27.188232748746287, 27.38174574419973, 27.573900703382538, 27.764725822525243, 27.954248335449837, 28.142494558940577, 28.32948993540124, 28.515259072994585, 28.69982578344336, 28.883213117657114, 29.065443399335923, 29.24653825668946, 29.426518652399235, 29.60540491194133, 29.783216750378056, 29.95997329771841, 30.13569312293978, 30.310394256756215, 30.48409421321224, 30.65681001017555, 30.828558188796308, 30.9993548319961, 31.16921558204505, 31.33815565728143, 31.50618986802435, 31.673332631726645, 31.83959798741184, 32.00499960943603, 32.16955082061296, 32.333264604737955, 32.49615361854384, 32.65823020312032], [0.0, 3.2741411087489802, 4.63033476111609, 5.670978751503131, 6.5482822174979605, 7.321202087089251, 8.019975062305368, 8.662563131083086, 9.26066952223218, 9.82242332624694, 10.353743284435827, 10.859097568398584, 11.341957503006261, 11.805083650698965, 12.250714264890844, 12.680693987317886, 13.096564434995921, 13.499629624548964, 13.89100428334827, 14.27165021992902, 14.642404174178502, 15.003999466808843, 15.357083056361974, 15.702229141112419, 16.039950124610737, 16.3707055437449, 16.694909403767365, 17.01293625450939, 17.325126262166172, 17.631789472427354, 17.933209417167912, 18.229646184169347, 18.52133904446436, 18.808508712813996, 19.09135930205076, 19.3700800204852, 19.64484665249388, 19.915822855207363, 20.183161298468583, 20.447004670611292, 20.707486568871655, 20.964732290205855, 21.21885953579975, 21.469979040511426, 21.718195136797167, 21.96360626126775, 22.206305410851215, 22.44638055455712, 22.683915006012523, 22.91898776124286, 23.15167380558045, 23.382044393080776, 23.61016730139793, 23.83610706470333, 24.059925186916107, 24.2816803372419, 24.501428529781688, 24.7192232887686, 24.93511580081392, 25.149155055389038, 25.36138797463577, 25.571859533479373, 25.780612870915228, 25.98768939324926, 26.193128869991842, 26.396969523034265, 26.599248109674075, 26.8, 26.99925924909793, 27.19705866449532, 27.39342986922229, 27.588403360832608, 27.78200856669654, 27.97427389584938, 28.16522678765431, 28.35489375751565, 28.54330043985804, 28.730471628568857, 28.916431315084512, 29.101202724286157, 29.284808348357004, 29.46726997874082, 29.648608736330278, 29.828845100003452, 30.007998933617685, 30.18608951156145, 30.36313554295735, 30.539155194602223, 30.714166112723948, 30.888185443628764, 31.06122985330748, 31.23331554606395, 31.404458282224837, 31.57467339498542, 31.743975806442396, 31.912380042861106, 32.079900249221474, 32.24655020308374, 32.41234332781263, 32.577292705195745, 32.7414110874898, 32.9047109089261], [0.0, 3.2984845004941286, 4.66476151587624, 5.713142742834281, 6.596969000988257, 7.37563556583431, 8.079603950689663, 8.726969691708572, 9.32952303175248, 9.895453501482384, 10.430723848324238, 10.939835464941876, 11.426285485668561, 11.892854997854805, 12.34179889643321, 12.77497553813705, 13.193938001976514, 13.6, 13.994284547628721, 14.377760604489144, 14.75127113166862, 15.115554902152947, 15.471263684650973, 15.818975946628152, 16.159207901379325, 16.492422502470642, 16.819036833302913, 17.13942822850284, 17.453939383417143, 17.762882648939616, 18.066543665017942, 18.365184453198395, 18.65904606350496, 18.94835085172322, 19.233304448274094, 19.51409746824075, 19.79090700296477, 20.063897926375123, 20.333224043422135, 20.599029103333976, 20.861447696648476, 21.12060605191054, 21.376622745419823, 21.629609335353237, 21.87967092988375, 22.12690669750293, 22.3714103265753, 22.61327044016411, 22.852570971337123, 23.0893915034589, 23.323807579381203, 23.555890982936734, 23.78570999570961, 24.013329631685817, 24.238811852068988, 24.46221576227305, 24.68359779286642, 24.90301186603741, 25.120509548972134, 25.336140195380985, 25.5499510762741, 25.76198750096739, 25.97229292919668, 26.180909075125715, 26.38787600395303, 26.593232221751457, 26.797014759110763, 26.99925924909793, 27.2, 27.399270063269935, 27.597101297056547, 27.793524425664334, 27.988569095257443, 28.182263926093658, 28.374636561549117, 28.5657137141714, 28.755521208978287, 28.94408402420087, 29.131426329653003, 29.31757152289391, 29.50254226333724, 29.68636050444716, 29.869047524151153, 30.050623953588715, 30.231109804305895, 30.41052449399714, 30.58888687088826, 30.766215236847057, 30.942527369301946, 31.117840542042757, 31.292171544972714, 31.46553670287542, 31.637951893256304, 31.80943256331367, 31.9799937460907, 32.14965007585619, 32.31841580275865, 32.486304806795125, 32.65333061113368, 32.81950639482562, 32.984845004941285, 33.14935896816106], [0.0, 3.32264954516723, 4.698936049788292, 5.754997827975265, 6.64529909033446, 7.429670248402685, 8.138795979750322, 8.790904390334365, 9.397872099576585, 9.96794863550169, 10.507140429250958, 11.01998185116473, 11.50999565595053, 11.979983305497552, 12.432216214336043, 12.868566353716329, 13.29059818066892, 13.699635031634967, 14.096808149364877, 14.483093592185341, 14.85934049680537, 15.226293048539425, 15.584607791022526, 15.934867429633673, 16.277591959500644, 16.61324772583615, 16.9422548676379, 17.264993483925792, 17.58180878066873, 17.893015397076034, 18.19890106572372, 18.499729727755486, 18.79574419915317, 19.08716846470424, 19.374209661299737, 19.657059800488984, 19.93589727100338, 20.21088815465565, 20.482187383187373, 20.749939758948702, 21.014280858501916, 21.275337835155522, 21.533230133911637, 21.788070130234114, 22.03996370232946, 22.28901074520805, 22.53530563360524, 22.77893763984616, 23.01999131190106, 23.25854681617061, 23.494680248941464, 23.72846391994223, 23.959966610995103, 24.18925381238537, 24.416387939250967, 24.641428530018306, 24.864432428672085, 25.085453952440247, 25.30454504629554, 25.521755425518833, 25.737132707432657, 25.95072253329375, 26.16256868122853, 26.372713171003095, 26.58119636133784, 26.78805704040515, 26.993332510084784, 27.19705866449532, 27.399270063269935, 27.6, 27.79928056623049, 27.997142711355387, 28.193616298729754, 28.388730158286403, 28.582512135919753, 28.77498913987632, 28.966187184370682, 29.156131430627077, 29.344846225529967, 29.532355138051557, 29.71868099361074, 29.903845906505072, 30.087871310546387, 30.270777988020065, 30.45258609707885, 30.63331519767327, 30.812984276113212, 30.9916117683479, 31.16921558204505, 31.345813117544104, 31.521421287752872, 31.69605653705205, 31.869734859267346, 32.04247181476486, 32.21428254672142, 32.385181796618035, 32.55518391900129, 32.72430289555456, 32.892552348518045, 33.05994555349419, 33.2264954516723, 33.39221466150456], [0.0, 3.3466401061363023, 4.732863826479693, 5.796550698475777, 6.6932802122726045, 7.4833147735478835, 8.19756061276768, 8.854377448471462, 9.465727652959385, 10.039920318408907, 10.583005244258363, 11.099549540409289, 11.593101396951553, 12.066482503198687, 12.521980673998822, 12.96148139681572, 13.386560424545209, 13.798550648528273, 14.198591479439079, 14.587666023048378, 14.966629547095767, 15.336231610144653, 15.697133496278868, 16.049922118191105, 16.39512122553536, 16.73320053068151, 17.064583206161235, 17.38965209542733, 17.708754896942924, 18.0222085217101, 18.33030277982336, 18.633303518163387, 18.93145530591877, 19.224983745116667, 19.51409746824075, 19.79898987322333, 20.079840636817814, 20.356817039999157, 20.630075133164205, 20.899760764181014, 21.166010488516726, 21.4289523775662, 21.68870673876154, 21.945386758952324, 22.199099080818577, 22.44994432064365, 22.698017534577772, 22.94340863951998, 23.186202793903107, 23.426480742954116, 23.664319132398468, 23.899790794063453, 24.132965006397374, 24.3639077325457, 24.592681838303037, 24.819347291981714, 25.043961347997644, 25.266578715766013, 25.48725171531839, 25.706030420895406, 25.92296279363144, 26.138094804327267, 26.351470547200964, 26.563132345414388, 26.773120849090418, 26.981475126464083, 27.188232748746287, 27.39342986922229, 27.597101297056547, 27.79928056623049, 28.000000000000004, 28.199290771223307, 28.397182958878158, 28.593705601058428, 28.78888674471453, 28.98275349237888, 29.175332046096756, 29.366647748764247, 29.55672512305787, 29.745587908125135, 29.933259094191534, 30.119760955226724, 30.3051150798013, 30.489342400255207, 30.672463220289305, 30.854497241083028, 31.03546358603332, 31.215380824202676, 31.394266992557736, 31.572139617073784, 31.74901573277509, 31.924911902775865, 32.09984423638221, 32.2738284063109, 32.4468796650772, 32.61901286060018, 32.79024245107072, 32.960582519124266, 33.13004678535785, 33.29864862122786, 33.46640106136302, 33.633316815324655], [0.0, 3.3704599092705436, 4.766550115125193, 5.83780780773057, 6.740919818541087, 7.53657747256671, 8.255906976220118, 8.917398723843181, 9.533100230250387, 10.111379727811629, 10.658330075579382, 11.178550889985697, 11.67561561546114, 12.15236602477065, 12.611106216347556, 13.053735097664575, 13.481839637082174, 13.896762212832167, 14.299650345375582, 14.691494137765568, 15.07315494513342, 15.44538766104626, 15.808858276295604, 16.164157880941403, 16.511813952440235, 16.852299546352718, 17.186040847152668, 17.51342342319171, 17.834797447686363, 18.150482087261484, 18.46076921474292, 18.76592656918384, 19.066200460500774, 19.361818096449518, 19.652989594461197, 19.939909728983228, 20.222759455623258, 20.501707245983198, 20.776910261152885, 21.04851538707659, 21.316660151158764, 21.58147353634594, 21.84307670636168, 22.101583653666086, 22.357101779971394, 22.609732417700123, 22.85957129956728, 23.10670898245789, 23.35123123092228, 23.593219364893805, 23.832750575625973, 24.069898213328617, 24.3047320495413, 24.537318516904005, 24.767720928660353, 24.995999679948792, 25.222212432695112, 25.446414285710276, 25.668657931415115, 25.888993800455047, 26.10747019532915, 26.324133414036634, 26.53902786463739, 26.752196171529544, 26.96367927416435, 27.173516518846064, 27.38174574419973, 27.588403360832608, 27.793524425664334, 27.997142711355387, 28.199290771223307, 28.4, 28.599300690751164, 28.79722208825011, 28.993792439072195, 29.189039038652847, 29.382988275531137, 29.575665672981902, 29.767095928222496, 29.95730294936445, 30.14630989026684, 30.334139183434893, 30.520812571096467, 30.706351134578004, 30.89077532209252, 31.074104975043127, 31.256359352938084, 31.437557157005696, 31.617716552591208, 31.796855190411517, 31.974990226738147, 32.152138342573735, 32.328315761882806, 32.50353826893313, 32.67782122480016, 32.851179583083464, 33.02362790488047, 33.19518037306019, 33.365850805876356, 33.53565266995709, 33.704599092705436, 33.872702874143364], [0.0, 3.394112549695428, 4.8, 5.8787753826796285, 6.788225099390856, 7.589466384404111, 8.313843876330612, 8.97997772825746, 9.6, 10.182337649086284, 10.73312629199899, 11.256997823576231, 11.757550765359257, 12.237646832622685, 12.699606293110035, 13.145341380123986, 13.576450198781712, 13.994284547628721, 14.4, 14.794593607125545, 15.178932768808222, 15.553777676178866, 15.91979899370592, 16.277591959500644, 16.627687752661224, 16.970562748477143, 17.30664612222715, 17.636326148038883, 17.95995545651492, 18.277855454073382, 18.5903200617956, 18.897618897628348, 19.2, 19.497692171126307, 19.790907002964772, 20.079840636817814, 20.364675298172568, 20.645580640902306, 20.922714928995234, 21.196226079186836, 21.46625258399798, 21.7329243315298, 21.996363335788033, 22.256684389189687, 22.513995647152463, 22.76839915321233, 23.019991311901055, 23.26886331559838, 23.515101530718514, 23.758787847867996, 24.0, 24.23881185206899, 24.47529366524537, 24.709512338368803, 24.941531628991836, 25.17141235608364, 25.39921258622007, 25.624987804875147, 25.84879107424562, 26.070673178880515, 26.29068276024797, 26.508866441249427, 26.725268941584105, 26.93993318477238, 27.152900397563425, 27.36421020237931, 27.573900703382538, 27.78200856669654, 27.988569095257443, 28.193616298729754, 28.397182958878158, 28.599300690751164, 28.8, 28.999310336626973, 29.197260145431454, 29.393876913398138, 29.58918721425109, 29.783216750378056, 29.975990392312315, 30.167532215943684, 30.357865537616444, 30.547012947258853, 30.73499633967768, 30.9218369441403, 31.107555352357732, 31.292171544972717, 31.475704916649605, 31.65817429985501, 31.83959798741184, 32.0199937539032, 32.19937887599697, 32.3777701517569, 32.55518391900129, 32.73163607276606, 32.907142081925016, 33.08171700501653, 33.25537550532245, 33.42813186524189, 33.6, 33.7709934707287, 33.941125496954285, 34.11040896852455], [0.0, 3.4176014981270124, 4.833218389437829, 5.9194594347794975, 6.835202996254025, 7.64198926981712, 8.37137981458254, 9.042123644365851, 9.666436778875658, 10.252804494381037, 10.807404868885037, 11.334901852243805, 11.838918869558995, 12.32233744059949, 12.787493890516624, 13.236313686219436, 13.67040599250805, 14.091131963046829, 14.499655168313486, 14.896979559628859, 15.28397853963424, 15.661417560361516, 16.029971927611104, 16.390240998838305, 16.74275962916508, 17.088007490635064, 17.426416728633573, 17.758378304338493, 18.084247288731703, 18.404347312523747, 18.718974330876144, 19.028399827626075, 19.332873557751316, 19.632625906892844, 19.92786993132984, 20.21880312976018, 20.505608988762074, 20.788458336298053, 21.06751053162191, 21.342914515126562, 21.614809737770074, 21.88332698654389, 22.148589119851405, 22.4107117245303, 22.66980370448761, 22.925967809451357, 23.179301111120672, 23.429895432971954, 23.67783773911799, 23.923210486889086, 24.166091947189145, 24.406556496154884, 24.64467488119898, 24.880514464134382, 25.11413944374762, 25.345611059905423, 25.574987781033247, 25.80232547659222, 26.027677575995906, 26.251095215247684, 26.472627372438872, 26.692320993124596, 26.910221106486656, 27.126370933097558, 27.3408119850161, 27.553584158871235, 27.764725822525243, 27.97427389584938, 28.182263926093658, 28.388730158286403, 28.593705601058428, 28.79722208825011, 28.999310336626973, 29.2, 29.39931972002073, 29.597297173897484, 29.793959119257718, 29.989331436362498, 30.183439167861575, 30.376306556261905, 30.56795707926848, 30.758413483143112, 30.947697814215523, 31.135831448670196, 31.32283512072303, 31.508728949292767, 31.69353246326449, 31.87726462543485, 32.05994385522221, 32.24158805021862, 32.42221460665511, 32.601840438846395, 32.78048199767661, 32.95815528818323, 33.13487588629238, 33.310658954755006, 33.48551925833016, 33.659471178258286, 33.8325287260648, 34.00470555673141, 34.17601498127013, 34.3464699787329], [0.0, 3.4409301068170506, 4.866210024238575, 5.959865770300536, 6.881860213634101, 7.694153624668538, 8.42852300228219, 9.103845341392834, 9.73242004847715, 10.322790320451151, 10.881176406988354, 11.412274094149685, 11.919731540601072, 12.406449935416658, 12.874781551544864, 13.326664999166143, 13.763720427268202, 14.187318280774559, 14.598630072715727, 14.99866660740214, 15.388307249337076, 15.768322675541619, 16.13939280146561, 16.502121075789017, 16.85704600456438, 17.204650534085253, 17.54536975956905, 17.87959731090161, 18.207690682785667, 18.529975715040752, 18.846750383023593, 19.158288023724875, 19.4648400969543, 19.76663856096934, 20.063897926375123, 20.356817039999154, 20.645580640902303, 20.930360723121808, 21.211317733700565, 21.488601629701268, 21.762352813976708, 22.03270296627266, 22.299775783626167, 22.563687641872722, 22.82454818829937, 23.082460874005612, 23.337523433303716, 23.589828316458767, 23.839463081202144, 24.086510747719355, 24.331050121192877, 24.573156085452272, 24.812899870833316, 25.050349298961883, 25.285569006846572, 25.51862065237853, 25.749563103089727, 25.978452609807228, 26.20534296665472, 26.430285658690863, 26.653329998332286, 26.87452325158532, 27.093910755001755, 27.3115360241785, 27.527440854536405, 27.74166541503952, 27.954248335449837, 28.16522678765431, 28.374636561549117, 28.582512135919753, 28.78888674471453, 28.993792439072195, 29.197260145431454, 29.39931972002073, 29.599999999999998, 29.79932885150268, 29.99733321480428, 30.19403914682499, 30.389471861156128, 30.583655765784442, 30.776614498674153, 30.968370961353457, 31.158947350640716, 31.348365188634634, 31.536645351083237, 31.723808094237363, 31.90987308028661, 32.094859401468014, 32.27878560293122, 32.46166970443757, 32.643529220965064, 32.824381182285826, 33.00424215157803, 33.18312824312982, 33.36105513918887, 33.53803810600733, 33.71409200912876, 33.88923132796022, 34.063470169670026, 34.236822282449054, 34.40930106817051, 34.58091959448158], [0.0, 3.464101615137755, 4.898979485566356, 6.000000000000001, 6.92820323027551, 7.745966692414834, 8.485281374238571, 9.16515138991168, 9.797958971132712, 10.392304845413264, 10.954451150103322, 11.489125293076059, 12.000000000000002, 12.489995996796797, 12.96148139681572, 13.416407864998737, 13.85640646055102, 14.2828568570857, 14.696938456699069, 15.099668870541501, 15.491933384829668, 15.874507866387544, 16.24807680927192, 16.61324772583615, 16.970562748477143, 17.320508075688775, 17.663521732655695, 18.0, 18.33030277982336, 18.65475810617763, 18.973665961010276, 19.28730152198591, 19.595917942265423, 19.899748742132402, 20.199009876724155, 20.493901531919196, 20.784609690826528, 21.07130750570548, 21.354156504062622, 21.633307652783937, 21.908902300206645, 22.181073012818835, 22.44994432064365, 22.715633383201094, 22.978250586152118, 23.2379000772445, 23.494680248941464, 23.748684174075834, 24.000000000000004, 24.24871130596428, 24.494897427831784, 24.738633753705965, 24.979991993593593, 25.219040425836987, 25.45584412271571, 25.69046515733026, 25.92296279363144, 26.153393661244042, 26.38181191654584, 26.60826939130014, 26.832815729997474, 27.055498516937366, 27.27636339397171, 27.49545416973504, 27.71281292110204, 27.92848008753788, 28.142494558940577, 28.35489375751565, 28.5657137141714, 28.77498913987632, 28.98275349237888, 29.189039038652847, 29.393876913398138, 29.597297173897484, 29.79932885150268, 30.0, 30.199337741083003, 30.397368307141328, 30.594117081556714, 30.789608636681308, 30.983866769659336, 31.176914536239792, 31.36877428271625, 31.559467676119, 31.74901573277509, 31.937438845342626, 32.12475680841802, 32.31098884280703, 32.49615361854384, 32.68026927673638, 32.863353450309965, 33.045423283716616, 33.2264954516723, 33.406586176980134, 33.585711247493336, 33.76388603226826, 33.941125496954285, 34.117444218463966, 34.292856398964496, 34.46737587922817, 34.64101615137755, 34.813790371058424], [0.0, 3.4871191548325395, 4.931531202375181, 6.039867548216601, 6.974238309665079, 7.7974354758471724, 8.54166260162505, 9.226050075736637, 9.863062404750362, 10.461357464497617, 11.027239001672179, 11.56546583584077, 12.079735096433202, 12.572986916401371, 13.047605144240073, 13.505554412907307, 13.948476619330158, 14.377760604489144, 14.794593607125545, 15.200000000000003, 15.594870951694345, 15.979987484350545, 16.356038640208702, 16.7236359682935, 17.0833252032501, 17.435595774162696, 17.7808886167143, 18.119602644649802, 18.452100151473275, 18.778711350888805, 19.099738218101315, 19.415457759218558, 19.726124809500725, 20.031974440878265, 20.33322404342214, 20.630075133164205, 20.922714928995234, 21.211317733700568, 21.49604614807105, 21.777052142105923, 22.054478003344357, 22.328457179124584, 22.59911502692086, 22.866569484730324, 23.13093167168154, 23.392306427541513, 23.650792798551176, 23.9064844759743, 24.159470192866404, 24.409834083827775, 24.65765601187591, 24.903011866037414, 25.145973832802742, 25.386610644195894, 25.62498780487515, 25.861167800391385, 26.095210288480146, 26.327172275046937, 26.557108276316537, 26.78507046845313, 27.011108825814613, 27.235271248878725, 27.457603682768823, 27.678150227209915, 27.896953238660316, 28.114053425288926, 28.32948993540124, 28.54330043985804, 28.755521208978287, 28.966187184370682, 29.175332046096756, 29.382988275531137, 29.58918721425109, 29.793959119257718, 29.99733321480428, 30.199337741083003, 30.400000000000006, 30.599346398248446, 30.797402487872258, 30.994193004496832, 31.18974190338869, 31.384072393492854, 31.57720696958489, 31.76916744266365, 31.95997496870109, 32.149650075856194, 32.338212690252384, 32.5256821604098, 32.712077280417404, 32.897416311923344, 33.081717005016536, 33.26499661806687, 33.447271936587, 33.62855929117393, 33.808874574584706, 33.988233257996804, 34.1666504065002, 34.34414069386509, 34.52071841662627, 34.69639750752231, 34.87119154832539, 35.04511378209522], [0.0, 3.509985754956849, 4.963869458396343, 6.079473661428266, 7.019971509913698, 7.848566748139434, 8.597674104081872, 9.28654941299512, 9.927738916792686, 10.529957264870546, 11.099549540409287, 11.6413057686842, 12.158947322856532, 12.655433615645101, 13.133164127505603, 13.594116374373142, 14.039943019827396, 14.472042012100435, 14.891608375189028, 15.299673199124223, 15.697133496278868, 16.08477541030648, 16.463292501805345, 16.833300330000654, 17.195348208163743, 17.549928774784245, 17.897485856957676, 18.238420984284797, 18.57309882599024, 18.901851761137056, 19.224983745116663, 19.542773600489774, 19.855477833585372, 20.163333057805698, 20.46655808874565, 20.765355763867856, 21.059914529741093, 21.35040983213203, 21.637005338077635, 21.919854014112413, 22.199099080818574, 22.47487486060824, 22.74730753298069, 23.016515809305282, 23.2826115373684, 23.5457002444183, 23.80588162618642, 24.063249988312055, 24.317894645713064, 24.569900284697944, 24.819347291981714, 25.066312054229282, 25.310867231290203, 25.553082005895103, 25.793022312245615, 26.03075104563831, 26.266328255011206, 26.49981132008302, 26.731255114565798, 26.960712156766185, 27.188232748746284, 27.413865105088703, 27.63765547219952, 27.85964823898536, 28.07988603965479, 28.29840984931839, 28.515259072994585, 28.730471628568857, 28.94408402420087, 29.156131430627077, 29.366647748764247, 29.575665672981902, 29.783216750378056, 29.989331436362498, 30.19403914682499, 30.397368307141328, 30.599346398248446, 30.8, 30.999354831996104, 31.19743579206471, 31.394266992557736, 31.589871794611643, 31.784272840510294, 31.977492084277028, 32.16955082061296, 32.36046971228941, 32.55026881609429, 32.73896760742465, 32.92658500361069, 33.113139386050364, 33.29864862122786, 33.483130080683914, 33.66660066000131, 33.84907679686405, 34.03057448824513, 34.21110930677344, 34.390696416327486, 34.56935058689996, 34.7470862087744, 34.9239173060526, 35.09985754956849, 35.27492026922244], [0.0, 3.532704346531139, 4.995998398718719, 6.1188234163113435, 7.065408693062278, 7.899367063252601, 8.653323061113575, 9.34665715643834, 9.991996797437437, 10.598113039593418, 11.171392035015154, 11.71665481270145, 12.237646832622687, 12.737346662472529, 13.218169313486646, 13.682105101189656, 14.130817386124557, 14.565713164826501, 14.987995196156158, 15.398701243936129, 15.798734126505202, 16.188885075878453, 16.569852141766386, 16.9422548676379, 17.30664612222715, 17.663521732655695, 18.01332839871633, 18.35647024893403, 18.69331431287668, 19.024195120950587, 19.34941859591652, 19.669265365030796, 19.983993594874875, 20.29384143034532, 20.599029103333976, 20.899760764181014, 21.196226079186836, 21.48860162970127, 21.777052142105923, 22.06173157302029, 22.34278407003031, 22.62034482495791, 22.8945408340067, 23.165491576912416, 23.4333096254029, 23.6981011897578, 23.959966610995103, 24.21900080515297, 24.475293665245374, 24.728930425717973, 24.979991993593597, 25.228555249954372, 25.474693324945058, 25.71847584908562, 25.95996918334073, 26.199236630100508, 26.436338626973292, 26.671332925071447, 26.904274753280383, 27.13521696983461, 27.36421020237931, 27.59130297756886, 27.816541841141937, 28.039971469315017, 28.261634772249113, 28.48157299026864, 28.69982578344336, 28.916431315084512, 29.131426329653003, 29.344846225529967, 29.55672512305787, 29.767095928222496, 29.975990392312315, 30.183439167861575, 30.389471861156128, 30.594117081556714, 30.797402487872258, 30.999354831996104, 31.200000000000006, 31.399363050864586, 31.597468253010405, 31.794339118780254, 31.989998437011536, 32.18446830382631, 32.377770151756906, 32.569924777315656, 32.76095236710924, 32.95087252259036, 33.13970428353277, 33.32746615030912, 33.514176105045465, 33.699851631720875, 33.8845097352758, 34.068166959788144, 34.25083940577224, 34.43254274665175, 34.6132922444543, 34.79310276477222, 34.97198879103103, 35.14996443810435, 35.32704346531139, 35.503239288831104], [0.0, 3.5552777669262356, 5.027922035990614, 6.157921727336262, 7.110555533852471, 7.949842765740717, 8.708616422830897, 9.406380813043878, 10.055844071981229, 10.665833300778706, 11.242775458044157, 11.791522378386942, 12.315843454672525, 12.818736287169653, 13.302631318652713, 13.769531582446804, 14.221111067704943, 14.658785761446955, 15.083766107971842, 15.497096502248416, 15.899685531481435, 16.29232948353304, 16.675730868540665, 17.050513188757694, 17.417232845661793, 17.77638883463118, 18.128430709799456, 18.473765182008783, 18.812761626087756, 19.145756710038913, 19.473058311420935, 19.794948850653796, 20.111688143962457, 20.423515857951593, 20.730653631759903, 21.03330692021585, 21.331666601557412, 21.625910385461236, 21.91620405088436, 22.202702538204672, 22.485550916088314, 22.764885240211516, 23.040833318263473, 23.313515393436486, 23.583044756773884, 23.849528297222147, 24.11306699696246, 24.3737563785314, 24.63168690934505, 24.88694436848365, 25.13961017995307, 25.389761716093364, 25.637472574339306, 25.88281283013885, 26.12584926849269, 26.366645596283195, 26.605262637305426, 26.841758511692188, 27.07618880123272, 27.308606701917256, 27.53906316489361, 27.767607026893767, 27.994285131076307, 28.219142439131634, 28.442222135409885, 28.66356572375461, 28.883213117657114, 29.101202724286157, 29.31757152289391, 29.532355138051557, 29.745587908125135, 29.95730294936445, 30.167532215943684, 30.376306556261905, 30.583655765784442, 30.789608636681308, 30.994193004496832, 31.19743579206471, 31.399363050864586, 31.6, 31.79937106296287, 31.997499902336124, 32.19440945257422, 32.390121950989936, 32.58465896706608, 32.77804143020141, 32.970289655991806, 33.16142337114015, 33.35146173708133, 33.540423372402444, 33.72832637413247, 33.91518833797035, 34.10102637751539, 34.28585714255953, 34.46969683649684, 34.652561232901675, 34.83446569132359, 35.01542517234369, 35.1954542519343, 35.374567135160824, 35.55277766926236, 35.7300993561451], [0.0, 3.577708763999664, 5.059644256269407, 6.196773353931868, 7.155417527999328, 8.000000000000002, 8.763560920082659, 9.465727652959387, 10.119288512538814, 10.73312629199899, 11.313708498984761, 11.865917579353063, 12.393546707863736, 12.89961239727768, 13.386560424545209, 13.856406460551018, 14.310835055998655, 14.75127113166862, 15.178932768808222, 15.594870951694345, 16.000000000000004, 16.39512122553536, 16.780941570722426, 17.158088471621777, 17.527121840165318, 17.88854381999832, 18.24280680158621, 18.590320061795605, 18.931455305918774, 19.266551326067674, 19.595917942265427, 19.919839356781974, 20.23857702507763, 20.55237212586421, 20.86144769664848, 21.166010488516726, 21.46625258399798, 21.76235281397671, 22.054478003344357, 22.34278407003031, 22.627416997969522, 22.908513701242168, 23.186202793903107, 23.46060527778429, 23.731835158706126, 24.0, 24.265201420964964, 24.52753554680943, 24.787093415727472, 25.043961347997648, 25.298221281347036, 25.549951076274105, 25.79922479455536, 26.046112953759536, 26.290682760247975, 26.532998322843202, 26.773120849090418, 27.011108825814613, 27.247018185482247, 27.48090245970827, 27.712812921102035, 27.94279871451677, 28.170906978654415, 28.397182958878158, 28.62167011199731, 28.844410203711913, 29.065443399335923, 29.284808348357004, 29.50254226333724, 29.71868099361074, 29.933259094191534, 30.14630989026684, 30.357865537616444, 30.56795707926848, 30.776614498674153, 30.983866769659336, 31.18974190338869, 31.394266992557736, 31.597468253010405, 31.79937106296287, 32.00000000000001, 32.19937887599698, 32.39753077010654, 32.59447805994138, 32.79024245107072, 32.984845004941285, 33.17830616532436, 33.37064578338274, 33.56188314144485, 33.75203697556638, 33.941125496954285, 34.12916641232247, 34.316176943243555, 34.50217384455652, 34.68717342188609, 34.87119154832539, 35.054243680330636, 35.236344872872394, 35.41750979388585, 35.597752738059185, 35.77708763999664, 35.95552808679078], [0.0, 3.6, 5.091168824543142, 6.235382907247959, 7.2, 8.049844718999244, 8.818163074019441, 9.524704719832526, 10.182337649086284, 10.8, 11.384199576606166, 11.939849245279442, 12.470765814495918, 12.979984591670362, 13.46996659238619, 13.9427400463467, 14.4, 14.84318025222358, 15.273506473629427, 15.692036196746427, 16.09968943799849, 16.497272501841024, 16.88549673536435, 17.264993483925792, 17.636326148038883, 18.000000000000004, 18.356470248934027, 18.706148721743876, 19.04940943966505, 19.386593305684215, 19.71801207018598, 20.04395170618808, 20.364675298172568, 20.680425527536904, 20.991426821443085, 21.297887219158618, 21.6, 21.897945109073593, 22.191890410688316, 22.481992794234237, 22.768399153212332, 23.05124725475826, 23.3306665142683, 23.6067786874872, 23.879698490558884, 24.149534156997728, 24.416387939250967, 24.68035656144376, 24.941531628991836, 25.200000000000003, 25.455844122715714, 25.709142342754262, 25.959969183340725, 26.20839560140987, 26.454489222058324, 26.69831455354439, 26.93993318477238, 27.1794039669747, 27.416783181110073, 27.65212469232699, 27.8854800926934, 28.116898833263956, 28.34642834644252, 28.57411415949758, 28.8, 29.024127893874777, 29.24653825668946, 29.46726997874082, 29.68636050444716, 29.903845906505072, 30.119760955226724, 30.334139183434893, 30.547012947258853, 30.758413483143112, 30.968370961353457, 31.176914536239792, 31.384072393492854, 31.589871794611643, 31.794339118780254, 31.997499902336124, 32.19937887599698, 32.400000000000006, 32.5993864972947, 32.79756088491948, 32.99454500368205, 33.1903600462544, 33.38502658378454, 33.578564591119736, 33.7709934707287, 33.96233207540377, 34.1525987298185, 34.34181125101004, 34.529986967851585, 34.71714273957464, 34.90329497339757, 35.08845964131227, 35.272652296077766, 35.45588808646598, 35.638181771801996, 35.81954773583832, 36.00000000000001, 36.179552236035214], [0.0, 3.622154055254967, 5.122499389946279, 6.27375485654325, 7.244308110509934, 8.099382692526635, 8.872429205127535, 9.583318840568753, 10.244998779892558, 10.8664621657649, 11.454256850621084, 12.013325934144968, 12.5475097130865, 13.059862173851608, 13.552859476877934, 14.028542333400146, 14.488616221019868, 14.934523762075576, 15.36749816983884, 15.788603484792445, 16.19876538505327, 16.598795136997147, 16.989408465276245, 17.371240600486775, 17.74485841025507, 18.110770276274835, 18.469434208984318, 18.82126456962975, 19.166637681137505, 19.505896544378576, 19.83935482821959, 20.16730026552885, 20.489997559785117, 20.807690885823927, 21.12060605191054, 21.4289523775662, 21.7329243315298, 22.032702966272662, 22.328457179124584, 22.62034482495791, 22.908513701242168, 23.193102422918763, 23.47424120179394, 23.752052542885636, 24.026651868289935, 24.298148077579906, 24.566644052454542, 24.83223711227001, 25.095019426173, 25.35507838678477, 25.612496949731398, 25.867353942759593, 26.119724347703215, 26.36967955815922, 26.617287615382605, 26.862613424609307, 27.10571895375587, 27.34666341621954, 27.585503439306674, 27.822293219646724, 28.057084666800293, 28.28992753613908, 28.52086955196142, 28.74995652170626, 28.977232442039735, 29.20273959751037, 29.426518652399235, 29.648608736330278, 29.869047524151153, 30.087871310546387, 30.3051150798013, 30.520812571096467, 30.73499633967768, 30.947697814215523, 31.158947350640716, 31.36877428271625, 31.57720696958489, 31.784272840510294, 31.989998437011536, 32.19440945257422, 32.39753077010654, 32.5993864972947, 32.800000000000004, 32.99939393382854, 33.197590273994294, 33.39461034358689, 33.590474840347234, 33.78520386204589, 33.97881693055249, 34.17133301467767, 34.36277055186325, 34.55314746879075, 34.74248120097355, 34.930788711393284, 35.11808650823676, 35.304390661785966, 35.48971682051014, 35.67408022640529, 35.857495729623956, 36.039977802434905, 36.22154055254967, 36.40219773585107], [0.0, 3.6441734316577197, 5.15363949069005, 6.311893535223801, 7.288346863315439, 8.148619514985345, 8.926365441768558, 9.64157663455516, 10.3072789813801, 10.932520294973157, 11.523888232710346, 12.086355943790503, 12.623787070447602, 13.139254164525473, 13.635248439247448, 14.113823011501879, 14.576693726630879, 15.025311976794358, 15.46091847207015, 15.884583721331826, 16.29723902997069, 16.699700596118483, 17.092688495377196, 17.476841819962782, 17.852730883537117, 18.2208671582886, 18.581711438939095, 18.9356806056714, 19.28315326911032, 19.624474515257727, 19.959959919799438, 20.289898964755835, 20.6145579627602, 20.93418257300724, 21.24899997646948, 21.559220765138985, 21.865040589946314, 22.166641603995856, 22.464193731358357, 22.75785578651908, 23.047776465420693, 23.334095225656384, 23.61694307060082, 23.896443249990153, 24.172711887581006, 24.44585854495603, 24.71598672924065, 24.983194351403505, 25.247574140895203, 25.509214021604038, 25.768197453450252, 26.024603743380997, 26.278508329050947, 26.52998303806469, 26.779096325305677, 27.02591349057419, 27.270496878494896, 27.51290606242823, 27.75319801392265, 27.991427259073443, 28.227646023003757, 28.461904363552343, 28.694250295137525, 28.92472990366548, 29.153387453261757, 29.380265485526163, 29.60540491194133, 29.828845100003452, 30.050623953588715, 30.270777988020065, 30.489342400255207, 30.706351134578004, 30.9218369441403, 31.135831448670196, 31.348365188634634, 31.559467676119, 31.76916744266365, 31.977492084277028, 32.18446830382631, 32.390121950989936, 32.59447805994138, 32.79756088491948, 32.99939393382854, 33.199999999999996, 33.399401192236965, 33.59761896325393, 33.79467413661508, 33.990586932267, 34.18537699075439, 34.37906339620089, 34.57166469813104, 34.763198932204155, 34.953683639925565, 35.14313588739628, 35.33157228315774, 35.519008995184535, 35.70546176707423, 35.89094593348022, 36.07547643483035, 36.25906783137151, 36.4417343165772, 36.62348972995337], [0.0, 3.6660605559646724, 5.184592558726289, 6.349803146555018, 7.332121111929345, 8.19756061276768, 8.97997772825746, 9.699484522385713, 10.369185117452577, 10.998181667894016, 11.593101396951552, 12.158947322856532, 12.699606293110037, 13.218169313486646, 13.717142559585797, 14.198591479439077, 14.66424222385869, 15.115554902152947, 15.553777676178866, 15.979987484350545, 16.39512122553536, 16.8, 17.195348208163743, 17.58180878066873, 17.95995545651492, 18.330302779823363, 18.69331431287668, 19.049409439665055, 19.398969044771427, 19.742340286804907, 20.079840636817814, 20.41176131547692, 20.738370234905155, 21.059914529741096, 21.376622745419823, 21.688706738761535, 21.996363335788033, 22.299775783626167, 22.599115026920856, 22.894540834006698, 23.186202793903103, 23.474241201793937, 23.758787847868, 24.03996672210675, 24.317894645713064, 24.592681838303037, 24.86443242867209, 25.133244915848014, 25.399212586220074, 25.662423891752706, 25.922962793631445, 26.18090907512572, 26.436338626973292, 26.689323708179646, 26.939933184772382, 27.188232748746287, 27.434285119171594, 27.678150227209912, 27.91988538658424, 28.159545450876866, 28.397182958878155, 28.63284826907725, 28.866589684269943, 29.09845356715714, 29.32848444771738, 29.556725123057866, 29.783216750378056, 30.007998933617685, 30.231109804305895, 30.45258609707885, 30.672463220289305, 30.89077532209252, 31.107555352357732, 31.32283512072303, 31.536645351083237, 31.74901573277509, 31.95997496870109, 32.16955082061296, 32.377770151756906, 32.58465896706608, 32.79024245107072, 32.99454500368205, 33.197590273994294, 33.399401192236965, 33.6, 33.799408278844176, 33.997646977401246, 34.19473643706002, 34.390696416327486, 34.58554611394766, 34.77930419085465, 34.97198879103103, 35.16361756133746, 35.35420767037497, 35.5437758264369, 35.73233829460367, 35.91991091302984, 36.10650910846963, 36.29214791108402, 36.476841968569595, 36.660605559646726, 36.84345260694226], [0.0, 3.687817782917155, 5.215361924162119, 6.387487769068526, 7.37563556583431, 8.246211251235321, 9.033271832508973, 9.757048734120374, 10.430723848324238, 11.063453348751464, 11.661903789690601, 12.231107881136525, 12.774975538137053, 13.29661611087573, 13.798550648528272, 14.282856857085699, 14.75127113166862, 15.20526224699857, 15.646085772486359, 16.074825037928097, 16.492422502470642, 16.899704139422088, 17.297398648351724, 17.686152775547317, 18.066543665017946, 18.439088914585778, 18.804254837669056, 19.162463307205577, 19.51409746824075, 19.85950653969026, 20.199009876724155, 20.53290042833696, 20.861447696648476, 21.18490028298458, 21.50348808914498, 21.81742422927143, 22.12690669750293, 22.432119828495924, 22.73323558141252, 23.030414672775652, 23.323807579381203, 23.613555429032708, 23.899790794063453, 24.182638400306942, 24.46221576227305, 24.73863375370596, 25.011997121381572, 25.282404948896772, 25.549951076274105, 25.814724480420086, 26.076809620810597, 26.336286754210438, 26.59323222175146, 26.84771871127974, 27.09981549752692, 27.349588662354687, 27.597101297056543, 27.84241368847177, 28.085583490467137, 28.326665882168342, 28.565713714171398, 28.802777643831508, 29.03790626061046, 29.271146202361123, 29.50254226333724, 29.732137494637012, 29.95997329771841, 30.18608951156145, 30.41052449399714, 30.63331519767327, 30.854497241083028, 31.074104975043127, 31.292171544972717, 31.508728949292767, 31.723808094237363, 31.937438845342626, 32.149650075856194, 32.36046971228941, 32.569924777315656, 32.77804143020141, 32.984845004941285, 33.1903600462544, 33.39461034358689, 33.59761896325393, 33.799408278844176, 34.0, 34.19941519967849, 34.39767433998991, 34.59479729670345, 34.790803382503256, 34.98571136907181, 35.17953950807202, 35.372305551094634, 35.564026768632374, 35.754719968138474, 35.94440151122286, 36.13308733003589, 36.320792942886044, 36.507533469134835, 36.69332364340958, 36.878177829171555, 37.06211003167521], [0.0, 3.709447398198282, 5.2459508194416005, 6.424951361683605, 7.418894796396564, 8.29457654133109, 9.086253353280439, 9.814275317108239, 10.491901638883201, 11.128342194594845, 11.730302638892145, 12.30284519938376, 12.84990272336721, 13.374602797840392, 13.879481258317979, 14.366627996854376, 14.837789592793127, 15.29444343544413, 15.737852458324802, 16.169106345126192, 16.58915308266218, 16.998823488700623, 17.398850536745236, 17.78988476634967, 18.172506706560878, 18.547236990991408, 18.914544668059026, 19.274854085050816, 19.628550634216477, 19.975985582694037, 20.31748015872047, 20.65332902948094, 20.983803277766402, 21.30915296298753, 21.62960933535324, 21.945386758952324, 22.25668438918969, 22.56368764187273, 22.866569484730324, 23.165491576912416, 23.46060527778429, 23.75205254288564, 24.039966722106755, 24.324473272817233, 24.60569039876752, 24.883729623993265, 25.158696309626222, 25.430690120403735, 25.69980544673442, 25.966131787387972, 26.229754097208005, 26.49075310367752, 26.749205595680785, 27.005184687389203, 27.258760059841315, 27.50999818247904, 27.758962516635957, 28.005713702742874, 28.250309732815325, 28.492806109613003, 28.733255993708752, 28.97171033957091, 29.208218021645894, 29.442825951324714, 29.675579185586255, 29.90652102802999, 30.13569312293978, 30.36313554295735, 30.58888687088826, 30.812984276113212, 31.03546358603332, 31.256359352938084, 31.475704916649605, 31.69353246326449, 31.90987308028661, 32.12475680841802, 32.338212690252384, 32.55026881609429, 32.76095236710924, 32.970289655991806, 33.17830616532436, 33.38502658378454, 33.590474840347234, 33.79467413661508, 33.997646977401246, 34.19941519967849, 34.400000000000006, 34.59942196048946, 34.79770107349047, 34.994856764959046, 35.19090791667644, 35.38587288735436, 35.57976953269934, 35.772615224498196, 35.96442686878244, 36.155220923125334, 36.345013413121755, 36.53381994809741, 36.72165573609121, 36.90853559815128, 37.094473981982816, 37.27948497498323], [0.0, 3.7309516212355263, 5.276362383309167, 6.462197768561406, 7.4619032424710525, 8.342661445845685, 9.138927727036691, 9.871170143402454, 10.552724766618335, 11.192854863706579, 11.798304963002101, 12.374166638606416, 12.924395537122813, 13.452137376640191, 13.959942693292119, 14.449913494550755, 14.923806484942105, 15.383107618423528, 15.829087149927505, 16.2628410802049, 16.68532289169137, 17.09736821853001, 17.499714283381888, 17.893015397076034, 18.277855454073382, 18.65475810617763, 19.024195120950587, 19.386593305684215, 19.742340286804907, 20.091789367798977, 20.43526363911168, 20.773059476158057, 21.10544953323667, 21.432685319390103, 21.754999425419438, 22.07260745811423, 22.385709727413158, 22.694492724006857, 22.999130418344084, 23.299785406737122, 23.596609926004202, 23.889746754622582, 24.179330015531864, 24.465485893396842, 24.748333277212833, 25.027984337537053, 25.304545046295537, 25.57811564599707, 25.848791074245625, 26.116661348648684, 26.38181191654584, 26.644323973409424, 26.904274753280383, 27.16173779418394, 27.416783181110073, 27.66947776883402, 27.919885386584237, 28.16806702633321, 28.414081016284868, 28.65798318095675, 28.89982698910151, 29.139663690578175, 29.377542443165662, 29.61351043020736, 29.84761296988421, 30.079893616833154, 30.310394256756215, 30.539155194602223, 30.766215236847057, 30.9916117683479, 31.215380824202676, 31.437557157005696, 31.65817429985501, 31.87726462543485, 32.094859401468014, 32.31098884280703, 32.5256821604098, 32.73896760742465, 32.95087252259036, 33.16142337114015, 33.37064578338274, 33.578564591119736, 33.78520386204589, 33.990586932267, 34.19473643706002, 34.39767433998991, 34.59942196048946, 34.800000000000004, 34.999428566763775, 35.19772719935195, 35.3949148890063, 35.59101010086677, 35.78603079415207, 35.979994441355885, 36.172918046516514, 36.364818162614256, 36.555710908146764, 36.74561198292934, 36.934536683164175, 37.122499915819255, 37.30951621235526, 37.49559974183638], [0.0, 3.752332607858744, 5.3065996645686395, 6.499230723708769, 7.504665215717488, 8.390470785361213, 9.191300234460847, 9.927738916792686, 10.613199329137279, 11.256997823576231, 11.865917579353061, 12.445079348883239, 12.998461447417538, 13.52922762023021, 14.039943019827396, 14.53272169966796, 15.009330431434975, 15.471263684650973, 15.91979899370592, 16.356038640208702, 16.780941570722426, 17.195348208163743, 17.6, 17.99555500672319, 18.382600468921694, 18.76166303929372, 19.133217188962238, 19.497692171126307, 19.855477833585372, 20.206929504504142, 20.552372125864206, 20.892103771520954, 21.226398658274558, 21.55550973649197, 21.87967092988375, 22.199099080818574, 22.513995647152463, 22.82454818829937, 23.130931671681537, 23.4333096254029, 23.731835158706122, 24.02665186828993, 24.317894645713064, 24.605690398767518, 24.890158697766477, 25.171412356083636, 25.44955795293899, 25.724696305301645, 25.996922894835077, 26.266328255011206, 26.532998322843202, 26.797014759110766, 27.05845524046042, 27.3173937263422, 27.573900703382538, 27.82804340948174, 28.07988603965479, 28.329489935401238, 28.576913759186805, 28.822213655442912, 29.06544339933592, 29.306654534422723, 29.54589650019102, 29.783216750378056, 30.01866086286995, 30.252272641902458, 30.48409421321224, 30.714166112723948, 30.942527369301946, 31.16921558204505, 31.394266992557736, 31.617716552591208, 31.83959798741184, 32.05994385522221, 32.27878560293122, 32.49615361854384, 32.712077280417404, 32.92658500361069, 33.13970428353277, 33.35146173708133, 33.56188314144485, 33.7709934707287, 33.97881693055249, 34.18537699075439, 34.390696416327486, 34.59479729670345, 34.79770107349047, 34.999428566763775, 35.2, 35.39943502374014, 35.597752738059185, 35.79497171391535, 35.99111001344638, 36.186185209275656, 36.38021440288664, 36.573214242119874, 36.76520093784339, 36.95619027984352, 37.14619765198048, 37.335238046649714, 37.52332607858744, 37.710475998056566], [0.0, 3.7735924528226414, 5.336665625650533, 6.536053855347277, 7.547184905645283, 8.438009243891594, 9.243376006633074, 9.983987179478948, 10.673331251301066, 11.320777358467923, 11.933147112141038, 12.515590277729613, 13.072107710694555, 13.605881081355959, 14.119490075778232, 14.615060725156086, 15.094369811290566, 15.558920271021378, 16.0099968769516, 16.448708155961672, 16.87601848778319, 17.29277305697383, 17.69971751187007, 18.09751364138179, 18.48675201326615, 18.867962264113206, 19.24162155328911, 19.60816156604183, 19.967974358957896, 20.321417273408862, 20.6688170924221, 21.010473578670233, 21.346662502602133, 21.677638247742767, 22.003636063160105, 22.32487401980132, 22.641554716935847, 22.953866776645718, 23.26198615767794, 23.566077314648698, 23.866294224282075, 24.16278129686233, 24.455674188212438, 24.745100525154466, 25.031180555459226, 25.31402773167478, 25.593749236874224, 25.870446459232202, 26.14421542138911, 26.41514716975849, 26.68332812825267, 26.94884042032236, 27.211762162711917, 27.472167733908442, 27.730128019899222, 27.985710639538887, 28.238980151556465, 28.48999824499819, 28.738823914697694, 28.985513623187703, 29.230121450312172, 29.47269923166183, 29.71329668683702, 29.951961538436844, 30.18873962258113, 30.423674991690266, 30.65681001017555, 30.888185443628764, 31.117840542042757, 31.345813117544104, 31.572139617073784, 31.796855190411517, 32.0199937539032, 32.24158805021862, 32.46166970443757, 32.68026927673638, 32.897416311923344, 33.113139386050364, 33.32746615030912, 33.540423372402444, 33.75203697556638, 33.96233207540377, 34.17133301467767, 34.37906339620089, 34.58554611394766, 34.790803382503256, 34.994856764959046, 35.19772719935195, 35.39943502374014, 35.599999999999994, 35.799441336423115, 35.99777770918644, 36.19502728276358, 36.39120772934034, 36.5863362472932, 36.78042957878551, 36.9735040265323, 37.165575469781174, 37.35665937955373, 37.54677083318884, 37.73592452822641, 37.92413479566805], [0.0, 3.794733192202055, 5.366563145999495, 6.572670690061994, 7.58946638440411, 8.485281374238571, 9.2951600308978, 10.039920318408907, 10.73312629199899, 11.384199576606164, 12.0, 12.58570617804182, 13.145341380123988, 13.682105101189656, 14.198591479439077, 14.696938456699067, 15.17893276880822, 15.646085772486357, 16.099689437998485, 16.540858502508268, 16.970562748477143, 17.389652095427326, 17.798876369029593, 18.198901065723724, 18.5903200617956, 18.973665961010276, 19.34941859591652, 19.71801207018598, 20.079840636817814, 20.43526363911168, 20.784609690826528, 21.12818023399081, 21.46625258399798, 21.799082549501943, 22.126906697502932, 22.44994432064365, 22.76839915321233, 23.082460874005616, 23.392306427541513, 23.6981011897578, 24.0, 24.298148077579906, 24.592681838303037, 24.88372962399326, 25.17141235608364, 25.45584412271571, 25.73713270743266, 26.015380066414558, 26.290682760247975, 26.563132345414388, 26.832815729997478, 27.09981549752692, 27.36421020237931, 27.626074639731215, 27.885480092693403, 28.142494558940577, 28.397182958878155, 28.649607327151973, 28.899826989101513, 29.147898723578685, 29.393876913398135, 29.637813684548327, 29.879759035172956, 30.11976095522672, 30.35786553761644, 30.594117081556707, 30.828558188796308, 31.06122985330748, 31.292171544972714, 31.521421287752872, 31.74901573277509, 31.974990226738147, 32.19937887599697, 32.42221460665511, 32.643529220965064, 32.863353450309965, 33.081717005016536, 33.29864862122786, 33.514176105045465, 33.72832637413247, 33.941125496954285, 34.1525987298185, 34.36277055186325, 34.57166469813104, 34.77930419085465, 34.98571136907181, 35.19090791667644, 35.3949148890063, 35.597752738059185, 35.799441336423115, 36.0, 36.199447509596055, 36.39780213144745, 36.59508163674458, 36.79130332021414, 36.98648401781386, 37.1806401235912, 37.373787605753854, 37.56594202199646, 37.75711853412546, 37.94733192202055, 38.136596596969696], [0.0, 3.8157568056677826, 5.396295025292816, 6.609084656743323, 7.631513611335565, 8.532291603080617, 9.346657156438338, 10.09554357129917, 10.792590050585632, 11.447270417003347, 12.066482503198685, 12.655433615645101, 13.218169313486646, 13.757906817535872, 14.277254638059798, 14.778362561528931, 15.26302722267113, 15.73276835143771, 16.18888507587845, 16.632498309033434, 17.064583206161235, 17.485994395515515, 17.897485856957676, 18.2997267739166, 18.693314312876677, 19.078784028338916, 19.456618411224497, 19.827253970229968, 20.19108714259834, 20.548479262466117, 20.89976076418101, 21.2452347598232, 21.585180101171265, 21.919854014112413, 22.249494376277408, 22.574321695235938, 22.894540834006694, 23.210342522246414, 23.52190468478265, 23.82939361377037, 24.13296500639737, 24.432764886520726, 24.728930425717973, 25.02159067685346, 25.310867231290203, 25.596874809241847, 25.8797217913949, 26.159510698787926, 26.436338626973292, 26.71029763967448, 26.981475126464083, 27.24995412840176, 27.515813635071744, 27.77912885603147, 28.039971469315017, 28.29840984931839, 28.554509276119596, 28.808332128049344, 29.059938059121876, 29.30938416275579, 29.556725123057863, 29.80201335480541, 30.045299133142276, 30.286630713897512, 30.52605444534226, 30.763614872118, 30.9993548319961, 31.23331554606395, 31.46553670287542, 31.69605653705205, 31.924911902775865, 32.152138342573735, 32.3777701517569, 32.601840438846395, 32.824381182285826, 33.045423283716616, 33.26499661806687, 33.483130080683914, 33.699851631720875, 33.91518833797035, 34.12916641232247, 34.34181125101004, 34.55314746879075, 34.763198932204155, 34.97198879103103, 35.17953950807202, 35.38587288735436, 35.59101010086677, 35.79497171391535, 35.99777770918644, 36.199447509596055, 36.4, 36.5994535478332, 36.797826022742164, 36.99513481526997, 37.19139685464906, 37.38662862575335, 37.58084618525773, 37.774065177049714, 37.966300846935304, 38.15756805667783, 38.34788129740677], [0.0, 3.836665218650176, 5.4258639865002145, 6.645299090334461, 7.673330437300352, 8.579044235810889, 9.397872099576585, 10.150862032359617, 10.851727973000429, 11.509995655950528, 12.132600710482482, 12.724778976469494, 13.290598180668923, 13.833293172632468, 14.35548675594109, 14.859340496805368, 15.346660874600705, 15.818975946628152, 16.277591959500644, 16.7236359682935, 17.158088471621777, 17.58180878066873, 17.99555500672319, 18.400000000000002, 18.79574419915317, 19.18332609325088, 19.563230817019978, 19.935897271003384, 20.301724064719235, 20.661074512231934, 21.014280858501916, 21.361647876509902, 21.703455946000858, 22.039963702329462, 22.3714103265753, 22.698017534577772, 23.019991311901055, 23.33752343330372, 23.650792798551176, 23.959966610995103, 24.265201420964964, 24.566644052454542, 24.86443242867209, 25.15869630962622, 25.44955795293899, 25.73713270743266, 26.02152954766495, 26.302851556437755, 26.581196361337845, 26.85665653055123, 27.129319932501076, 27.399270063269938, 27.666586345264935, 27.93134440015375, 28.193616298729758, 28.453470790045987, 28.71097351188218, 28.96618718437068, 29.219171788399482, 29.46998473023018, 29.718680993610736, 29.96531328052487, 30.20993214159873, 30.45258609707885, 30.69332174920141, 30.932183886689927, 31.16921558204505, 31.404458282224837, 31.637951893256304, 31.869734859267346, 32.09984423638221, 32.328315761882806, 32.55518391900129, 32.78048199767661, 33.00424215157803, 33.2264954516723, 33.447271936587, 33.66660066000131, 33.8845097352758, 34.10102637751539, 34.316176943243555, 34.529986967851585, 34.74248120097355, 34.953683639925565, 35.16361756133746, 35.372305551094634, 35.57976953269934, 35.78603079415207, 35.99111001344638, 36.19502728276358, 36.39780213144745, 36.5994535478332, 36.800000000000004, 36.99945945551097, 37.197849400200546, 37.39518685606478, 37.59148839830634, 37.786770171582546, 37.981047905501505, 38.17433692940848, 38.36665218650176, 38.55800824731486], [0.0, 3.8574603043971822, 5.455272678794342, 6.681317235396028, 7.7149206087943645, 8.62554346113913, 9.448809448814174, 10.20588065773846, 10.910545357588685, 11.572380913191546, 12.198360545581526, 12.793748473375583, 13.362634470792056, 13.90827092057097, 14.433294842134973, 14.939879517586478, 15.429841217588729, 15.904716281656835, 16.36581803638303, 16.814279645586964, 17.25108692227826, 17.677103835187484, 18.093092604637828, 18.499729727755486, 18.897618897628348, 19.287301521985913, 19.669265365030796, 20.043951706188082, 20.41176131547692, 20.773059476158057, 21.12818023399081, 21.47743001385408, 21.82109071517737, 22.15942237514327, 22.49266547121528, 22.82104292095346, 23.144761826383093, 23.464015001699945, 23.778982316322963, 24.08983187986168, 24.39672109116305, 24.699797570020696, 24.999199987199596, 25.295058806019803, 25.587496946751166, 25.87663038341739, 26.162568681228535, 26.445415481704956, 26.725268941584112, 27.002222130780275, 27.276363393971714, 27.547776679797597, 27.81654184114194, 28.082734909548968, 28.346428346442522, 28.60769127350196, 28.866589684269947, 29.123186638827836, 29.377542443165666, 29.629714814692363, 29.879759035172956, 30.127728092240876, 30.373672810511408, 30.61764197321538, 30.859682435177458, 31.099839227880263, 31.33815565728143, 31.57467339498542, 31.80943256331367, 32.04247181476486, 32.2738284063109, 32.50353826893313, 32.73163607276606, 32.95815528818323, 33.18312824312982, 33.406586176980134, 33.62855929117393, 33.84907679686405, 34.068166959788144, 34.28585714255953, 34.50217384455652, 34.71714273957464, 34.930788711393284, 35.14313588739628, 35.35420767037497, 35.564026768632374, 35.772615224498196, 35.979994441355885, 36.186185209275656, 36.39120772934034, 36.59508163674458, 36.797826022742164, 36.99945945551097, 37.2, 37.399465236818564, 37.59787228022352, 37.795237795256696, 37.99157801408097, 38.1869087515604, 38.381245420126746, 38.57460304397183, 38.76699627260282], [0.0, 3.8781438859330635, 5.4845236803208355, 6.717142249498667, 7.756287771866127, 8.671793355471522, 9.499473669630335, 10.26060427070453, 10.969047360641671, 11.63443165779919, 12.263767773404714, 12.862348152650823, 13.434284498997334, 13.982846634358829, 14.510685717773644, 15.019986684414869, 15.512575543732254, 15.98999687304535, 16.453571040962508, 16.904437287292353, 17.343586710943043, 17.77188791321845, 18.19010720144332, 18.598924700100273, 18.99894733926067, 19.390719429665317, 19.774731350893244, 20.151426748496, 20.52120854140906, 20.884443971530583, 21.241468875762806, 21.59259132202525, 21.938094721283342, 22.278240505030915, 22.613270440164115, 22.94340863951998, 23.26886331559838, 23.58982831645877, 23.9064844759743, 24.21900080515297, 24.52753554680943, 24.832237112270015, 25.133244915848017, 25.43069012040373, 25.724696305301645, 26.015380066414558, 26.30285155643776, 26.587214972614188, 26.868568997994668, 27.147007201531444, 27.42261840160418, 27.695486996982023, 27.965693268717658, 28.233313656034078, 28.498421008891004, 28.761084819596082, 29.021371435547287, 29.27934425495216, 29.535063907159575, 29.78858841905739, 30.039973368829738, 30.289272028228083, 30.536535494387703, 30.781812812113586, 31.025151087464508, 31.266595593380487, 31.50618986802435, 31.743975806442396, 31.9799937460907, 32.21428254672142, 32.4468796650772, 32.67782122480016, 32.907142081925016, 33.13487588629238, 33.36105513918887, 33.585711247493336, 33.808874574584706, 34.03057448824513, 34.25083940577224, 34.46969683649684, 34.68717342188609, 34.90329497339757, 35.11808650823676, 35.33157228315774, 35.5437758264369, 35.754719968138474, 35.96442686878244, 36.172918046516514, 36.38021440288664, 36.5863362472932, 36.79130332021414, 36.99513481526997, 37.197849400200546, 37.399465236818564, 37.6, 37.79947089576784, 37.99789467852134, 38.195287667459716, 38.39166576224585, 38.58704445795247, 38.781438859330635, 38.97486369443774], [0.0, 3.8987177379235853, 5.513619500836088, 6.752777206453653, 7.797435475847171, 8.717797887081348, 9.549869109050658, 10.3150375665821, 11.027239001672177, 11.696153213770755, 12.328828005937952, 12.93058390019569, 13.505554412907307, 14.057026712644463, 14.587666023048374, 15.099668870541498, 15.594870951694341, 16.074825037928093, 16.540858502508264, 16.994116628998402, 17.435595774162696, 17.866169147301836, 18.286607121059937, 18.69759342803239, 19.099738218101315, 19.493588689617926, 19.879637823662684, 20.25833161936096, 20.6300751331642, 20.995237555217134, 21.35415650406262, 21.707141681944215, 22.054478003344354, 22.39642828667107, 22.733235581412515, 23.06512518934159, 23.39230642754151, 23.71497417245062, 24.033310217279684, 24.34748446965312, 24.657656011875904, 24.96397404260788, 25.266578715766013, 25.565601890039666, 25.86116780039138, 26.15339366124404, 26.442390209661454, 26.72826219566098, 27.011108825814613, 27.291024165465096, 27.568097504180443, 27.84241368847177, 28.114053425288926, 28.383093559370867, 28.649607327151973, 28.913664589601918, 29.17533204609675, 29.434673431176368, 29.691749695833014, 29.946619174791664, 30.199337741082996, 30.449958949069206, 30.698534166959824, 30.945112699746304, 31.189741903388683, 31.432467291003416, 31.673332631726645, 31.912380042861106, 32.14965007585619, 32.385181796618035, 32.61901286060018, 32.851179583083464, 33.08171700501653, 33.310658954755006, 33.53803810600733, 33.76388603226826, 33.988233257996804, 34.21110930677344, 34.43254274665175, 34.652561232901675, 34.87119154832539, 35.08845964131227, 35.304390661785966, 35.519008995184535, 35.73233829460367, 35.94440151122286, 36.155220923125334, 36.364818162614256, 36.573214242119874, 36.78042957878551, 36.98648401781386, 37.19139685464906, 37.39518685606478, 37.59787228022352, 37.79947089576784, 37.99999999999999, 38.19947643620263, 38.397916610149565, 38.595336505852615, 38.79175170058707, 38.98717737923585, 39.18162834798983], [0.0, 3.9191835884530852, 5.542562584220407, 6.788225099390857, 7.8383671769061705, 8.763560920082659, 9.600000000000001, 10.369185117452577, 11.085125168440815, 11.757550765359255, 12.393546707863734, 12.998461447417538, 13.576450198781714, 14.130817386124557, 14.664242223858688, 15.17893276880822, 15.676734353812341, 16.159207901379325, 16.627687752661224, 17.0833252032501, 17.527121840165318, 17.95995545651492, 18.382600468921694, 18.79574419915317, 19.200000000000003, 19.595917942265427, 19.983993594874878, 20.36467529817257, 20.738370234905155, 21.105449533236673, 21.46625258399798, 21.82109071517737, 22.17025033688163, 22.513995647152466, 22.852570971337123, 23.186202793903103, 23.51510153071851, 23.839463081202144, 24.1594701928664, 24.47529366524537, 24.78709341572747, 25.095019426173, 25.399212586220074, 25.699805446734416, 25.996922894835077, 26.29068276024797, 26.58119636133784, 26.868568997994664, 27.152900397563428, 27.434285119171594, 27.71281292110204, 27.988569095257446, 28.261634772249113, 28.532087200203218, 28.8, 29.065443399335923, 29.328484447717376, 29.589187214251087, 29.84761296988421, 30.103820355562846, 30.35786553761644, 30.609802351534388, 30.859682435177454, 31.107555352357732, 31.353468707624682, 31.597468253010398, 31.83959798741184, 32.079900249221474, 32.31841580275865, 32.55518391900129, 32.79024245107072, 33.02362790488047, 33.25537550532245, 33.48551925833016, 33.71409200912876, 33.941125496954285, 34.1666504065002, 34.390696416327486, 34.6132922444543, 34.83446569132359, 35.054243680330636, 35.272652296077766, 35.48971682051014, 35.70546176707423, 35.91991091302984, 36.13308733003589, 36.345013413121755, 36.555710908146764, 36.76520093784339, 36.9735040265323, 37.1806401235912, 37.38662862575335, 37.59148839830634, 37.795237795256696, 37.99789467852134, 38.19947643620263, 38.400000000000006, 38.599481861807426, 38.79793808954285, 38.99538434225261, 39.19183588453085, 39.387307600291756], [0.0, 3.9395431207184424, 5.571355310873648, 6.823488843692794, 7.879086241436885, 8.809086218218098, 9.649870465451857, 10.423051376636307, 11.142710621747296, 11.818629362155326, 12.45792920191795, 13.065986376848862, 13.646977687385588, 14.204224723651766, 14.740420618150624, 15.257784898208522, 15.75817248287377, 16.243152403397563, 16.714065932620944, 17.172070346932546, 17.618172436436197, 18.053254554234815, 18.47809513992176, 18.893385085791273, 19.299740930903713, 19.69771560359221, 20.087807247183555, 20.47046653107838, 20.846102753272614, 21.215088969881794, 21.577766334817884, 21.934447793368314, 22.285421243494593, 22.630952255705022, 22.97128642457797, 23.306651411131547, 23.63725872431065, 23.96330528120026, 24.284974778656867, 24.602438903490853, 24.9158584038359, 25.2253840406841, 25.53115743557272, 25.833311827948037, 26.131972753697724, 26.42725865465429, 26.71928142746358, 27.008146919031674, 27.293955374771176, 27.576801845029095, 27.856776554368242, 28.133965237769104, 28.408449447303532, 28.68030683238937, 28.949611396355568, 29.21643373172024, 29.48084123630125, 29.742898312034086, 30.002666548158686, 30.260204890251487, 30.515569796417044, 30.768815381811503, 31.019993552546076, 31.269154129908923, 31.51634496574754, 31.76161204976851, 32.00499960943603, 32.24655020308374, 32.486304806795125, 32.72430289555456, 32.960582519124266, 33.19518037306019, 33.42813186524189, 33.659471178258286, 33.88923132796022, 34.117444218463966, 34.34414069386509, 34.56935058689996, 34.79310276477222, 35.01542517234369, 35.236344872872394, 35.45588808646598, 35.67408022640529, 35.89094593348022, 36.10650910846963, 36.320792942886044, 36.53381994809741, 36.74561198292934, 36.95619027984352, 37.165575469781174, 37.373787605753854, 37.58084618525773, 37.786770171582546, 37.99157801408097, 38.195287667459716, 38.397916610149565, 38.599481861807426, 38.80000000000001, 38.99948717611554, 39.197959130546586, 39.39543120718442, 39.59191836726279], [0.0, 3.9597979746446663, 5.6, 6.8585712797928995, 7.919595949289333, 8.854377448471462, 9.699484522385713, 10.476640682967036, 11.2, 11.879393923933998, 12.521980673998822, 13.133164127505603, 13.717142559585799, 14.277254638059798, 14.816207341961707, 15.33623161014465, 15.839191898578665, 16.32666530556684, 16.8, 17.260359208313137, 17.708754896942924, 18.14607395554201, 18.57309882599024, 18.990523952750753, 19.398969044771427, 19.79898987322333, 20.19108714259834, 20.575713839378697, 20.95328136593407, 21.324164696418944, 21.68870673876153, 22.04722204723307, 22.4, 22.74730753298069, 23.0893915034589, 23.426480742954116, 23.758787847867996, 24.086510747719355, 24.40983408382777, 24.728930425717973, 25.043961347997644, 25.35507838678477, 25.662423891752706, 25.96613178738797, 26.266328255011206, 26.563132345414385, 26.85665653055123, 27.147007201531444, 27.434285119171598, 27.71858582251266, 28.0, 28.27861382741382, 28.554509276119596, 28.827764394763605, 29.09845356715714, 29.366647748764244, 29.632414683923415, 29.89581910568767, 30.156922919953224, 30.415785375360603, 30.6724632202893, 30.92701084812433, 31.17948043184812, 31.42992204890111, 31.67838379715733, 31.92491190277586, 32.16955082061296, 32.41234332781263, 32.65333061113368, 32.892552348518045, 33.13004678535785, 33.365850805876356, 33.6, 33.8325287260648, 34.063470169670026, 34.292856398964496, 34.52071841662627, 34.7470862087744, 34.97198879103103, 35.1954542519343, 35.41750979388585, 35.638181771801996, 35.857495729623956, 36.07547643483035, 36.29214791108402, 36.507533469134835, 36.72165573609121, 36.934536683164175, 37.14619765198048, 37.35665937955373, 37.56594202199646, 37.774065177049714, 37.981047905501505, 38.1869087515604, 38.39166576224585, 38.595336505852615, 38.79793808954285, 38.99948717611554, 39.2, 39.39949238251681, 39.59797974644666, 39.79547712994531], [0.0, 3.9799497484264803, 5.628498911788116, 6.893475175845635, 7.959899496852961, 8.899438184514796, 9.748846085563153, 10.529957264870548, 11.256997823576231, 11.93984924527944, 12.58570617804182, 13.200000000000003, 13.78695035169127, 14.34991289172168, 14.891608375189028, 15.414279094398156, 15.919798993705921, 16.40975319741281, 16.88549673536435, 17.348198753761157, 17.798876369029593, 18.238420984284797, 18.667619023324857, 19.08716846470424, 19.497692171126307, 19.899748742132402, 20.293841430345317, 20.680425527536904, 21.059914529741096, 21.432685319390107, 21.79908254950194, 22.15942237514327, 22.513995647152463, 22.863070659909184, 23.20689552697646, 23.545700244418303, 23.87969849055888, 24.20908920219842, 24.53405796031305, 24.854778212649578, 25.17141235608364, 25.484112697914366, 25.79302231224562, 26.098275805117854, 26.400000000000006, 26.698314553544385, 26.993332510084784, 27.285160802164977, 27.57390070338254, 27.85964823898536, 28.14249455894058, 28.422526277584833, 28.69982578344336, 28.97447152235913, 29.246538256689462, 29.516097302997228, 29.783216750378056, 30.047961661317398, 30.31039425675622, 30.570574086856794, 30.82855818879631, 31.084401232772688, 31.33815565728143, 31.589871794611643, 31.839597987411842, 32.08738069709025, 32.333264604737955, 32.577292705195745, 32.81950639482562, 33.05994555349419, 33.29864862122786, 33.53565266995709, 33.7709934707287, 34.00470555673141, 34.236822282449054, 34.46737587922817, 34.69639750752231, 34.9239173060526, 35.14996443810435, 35.374567135160824, 35.597752738059185, 35.81954773583832, 36.039977802434905, 36.25906783137151, 36.476841968569595, 36.69332364340958, 36.90853559815128, 37.122499915819255, 37.335238046649714, 37.54677083318884, 37.75711853412546, 37.966300846935304, 38.17433692940848, 38.381245420126746, 38.58704445795247, 38.79175170058707, 38.99538434225261, 39.197959130546586, 39.39949238251681, 39.60000000000001, 39.799497484264805, 39.99799994999751], [0.0, 4.0, 5.656854249492381, 6.9282032302755105, 8.0, 8.94427190999916, 9.797958971132713, 10.583005244258363, 11.313708498984761, 12.0, 12.649110640673518, 13.266499161421601, 13.856406460551021, 14.422205101855958, 14.966629547095765, 15.491933384829666, 16.0, 16.492422502470642, 16.970562748477143, 17.435595774162696, 17.88854381999832, 18.330302779823363, 18.76166303929372, 19.18332609325088, 19.595917942265427, 20.000000000000004, 20.39607805437114, 20.78460969082653, 21.166010488516726, 21.54065922853802, 21.908902300206645, 22.27105745132009, 22.627416997969522, 22.978250586152118, 23.323807579381203, 23.664319132398465, 24.0, 24.33105012119288, 24.657656011875908, 24.979991993593597, 25.298221281347036, 25.612496949731398, 25.922962793631445, 26.229754097208, 26.532998322843202, 26.832815729997474, 27.129319932501076, 27.42261840160418, 27.712812921102042, 28.0, 28.284271247461906, 28.565713714171405, 28.844410203711917, 29.12043955712208, 29.39387691339814, 29.664793948382655, 29.93325909419153, 30.199337741083, 30.463092423455638, 30.72458299147443, 30.983866769659333, 31.24099870362662, 31.496031496047245, 31.74901573277509, 32.0, 32.2490309931942, 32.49615361854384, 32.7414110874898, 32.984845004941285, 33.2264954516723, 33.46640106136302, 33.704599092705436, 33.941125496954285, 34.17601498127013, 34.40930106817051, 34.64101615137755, 34.87119154832539, 35.09985754956849, 35.32704346531139, 35.55277766926236, 35.77708763999664, 36.00000000000001, 36.22154055254967, 36.4417343165772, 36.660605559646726, 36.878177829171555, 37.094473981982816, 37.30951621235526, 37.52332607858744, 37.73592452822641, 37.94733192202055, 38.15756805667783, 38.36665218650176, 38.57460304397183, 38.781438859330635, 38.98717737923585, 39.19183588453085, 39.39543120718442, 39.59797974644666, 39.799497484264805, 40.00000000000001, 40.19950248448357], [0.0, 4.019950248448357, 5.685068161420759, 6.962758074211686, 8.039900496896713, 8.988882021697695, 9.846826900072939, 10.635788640246666, 11.370136322841518, 12.05985074534507, 12.712198865656564, 13.332666649999169, 13.925516148423371, 14.494136745594753, 15.041276541570534, 15.569200364822851, 16.079800993793427, 16.57467948408053, 17.055204484262276, 17.52255689104761, 17.97776404339539, 18.42172630347113, 18.855237999028283, 19.27900412365743, 19.693653800145878, 20.099751242241783, 20.497804760510334, 20.888274222635054, 21.271577280493332, 21.648094604375697, 22.018174311236617, 22.38213573366045, 22.740272645683035, 23.0928560381777, 23.44013651837378, 23.7823463939116, 24.11970149069014, 24.452402744924683, 24.780637602773666, 25.10458125522113, 25.424397731313128, 25.740240869113876, 26.052255180694054, 26.36057662495265, 26.665333299998338, 26.96664606509308, 27.26462910072316, 27.559390414158297, 27.851032296846743, 28.139651739138497, 28.425340807103794, 28.70818698559699, 28.988273491189506, 29.26567955814456, 29.540480700218815, 29.812748950742538, 30.082553083141068, 30.34995881381061, 30.61502898904393, 30.87782375751245, 31.138400729645703, 31.396815125104652, 31.653119909418095, 31.90736592074, 32.15960198758685, 32.40987503832744, 32.65823020312032, 32.9047109089261, 33.14935896816106, 33.39221466150456, 33.633316815324655, 33.872702874143364, 34.11040896852455, 34.3464699787329, 34.58091959448158, 34.813790371058424, 35.04511378209522, 35.27492026922244, 35.503239288831104, 35.7300993561451, 35.95552808679078, 36.179552236035214, 36.40219773585107, 36.62348972995337, 36.84345260694226, 37.06211003167521, 37.27948497498323, 37.49559974183638, 37.710475998056566, 37.92413479566805, 38.136596596969696, 38.34788129740677, 38.55800824731486, 38.76699627260282, 38.97486369443774, 39.18162834798983, 39.387307600291756, 39.59191836726279, 39.79547712994531, 39.99799994999751, 40.19950248448357, 40.400000000000006]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"A = 4.5\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.45, 0.6363961030678927, 0.7794228634059949, 0.9, 1.0062305898749055, 1.1022703842524302, 1.1905880899790657, 1.2727922061357855, 1.3499999999999999, 1.4230249470757708, 1.4924811556599302, 1.5588457268119897, 1.6224980739587953, 1.6837458240482737, 1.7428425057933377, 1.8, 1.8553975315279472, 1.9091883092036783, 1.9615045245933032, 2.012461179749811, 2.062159062730128, 2.1106870919205436, 2.158124185490724, 2.2045407685048604, 2.25, 2.2945587811167534, 2.3382685902179845, 2.3811761799581315, 2.423324163210527, 2.4647515087732472, 2.50549396327351, 2.545584412271571, 2.585053190942113, 2.6239283526803856, 2.662235902394827, 2.6999999999999997, 2.737243138634199, 2.7739863013360395, 2.8102490992792797, 2.8460498941515415, 2.881405906844782, 2.9163333142835373, 2.9508473359359, 2.9849623113198605, 3.018691769624716, 3.052048492406371, 3.08504457018047, 3.1176914536239795, 3.1500000000000004, 3.1819805153394642, 3.213642792844283, 3.2449961479175906, 3.2760494501762336, 3.306811152757291, 3.3372893191930486, 3.3674916480965473, 3.3974254958718375, 3.427097897638759, 3.456515586540873, 3.4856850115866753, 3.5146123541579946, 3.543303543305315, 3.5717642699371974, 3.6, 3.6280159867343476, 3.655817282086182, 3.6834087473426025, 3.7107950630558943, 3.7379807383131336, 3.76497011940334, 3.7917673979293616, 3.8183766184073566, 3.8448016853928895, 3.871046370169182, 3.897114317029974, 3.9230090491866063, 3.948733974326455, 3.9742923898475317, 3.999687487792015, 4.024922359499622, 4.05, 4.074923312161838, 4.099695110614935, 4.124318125460256, 4.1487950057818, 4.173128322973067, 4.197320573889967, 4.221374183841087, 4.2452915094254715, 4.2690748412273125, 4.292726406376255, 4.316248370981448, 4.33964284244683, 4.362911871674696, 4.386057455164034, 4.409081537009721, 4.431986010808248, 4.4547727214752495, 4.47744346697979, 4.5, 4.522444029504401], [0.0, 0.6363961030678927, 0.8999999999999999, 1.1022703842524302, 1.2727922061357855, 1.4230249470757708, 1.5588457268119895, 1.6837458240482737, 1.7999999999999998, 1.909188309203678, 2.0124611797498106, 2.1106870919205436, 2.2045407685048604, 2.294558781116753, 2.3811761799581315, 2.4647515087732472, 2.545584412271571, 2.623928352680385, 2.6999999999999997, 2.7739863013360395, 2.8460498941515415, 2.9163333142835373, 2.98496231131986, 3.052048492406371, 3.117691453623979, 3.181980515339464, 3.2449961479175906, 3.3068111527572905, 3.3674916480965473, 3.4270978976387587, 3.485685011586675, 3.543303543305315, 3.5999999999999996, 3.6558172820861823, 3.710795063055895, 3.7649701194033396, 3.818376618407356, 3.871046370169182, 3.923009049186606, 3.9742923898475317, 4.024922359499621, 4.074923312161838, 4.124318125460256, 4.173128322973066, 4.221374183841087, 4.269074841227312, 4.316248370981447, 4.362911871674696, 4.409081537009721, 4.4547727214752495, 4.5, 4.544777222262935, 4.589117562233506, 4.63303356344415, 4.676537180435969, 4.719639816765682, 4.762352359916263, 4.80468521341409, 4.846648326421054, 4.888251221040096, 4.9295030175464944, 4.970412457734267, 5.01098792654702, 5.0512374721448206, 5.091168824543142, 5.130789412946121, 5.170106381884225, 5.209126606255601, 5.24785670536077, 5.286303056011828, 5.324471804789654, 5.362368879515843, 5.3999999999999995, 5.437370688117558, 5.474486277268397, 5.5113519212621505, 5.547972602672079, 5.584353140695885, 5.620498198558559, 5.65641229048944, 5.692099788303083, 5.727564927611035, 5.762811813689564, 5.797844427026306, 5.8326666285670745, 5.867282164682384, 5.901694671871801, 5.9359076812228135, 5.96992462263972, 6.00374882885685, 6.037383539249432, 6.070831903454419, 6.104096984812742, 6.137181763643635, 6.17008914036094, 6.202821938440599, 6.235382907247958, 6.267774724732854, 6.3, 6.33206127576163, 6.363961030678928, 6.395701681598354], [0.0, 0.7794228634059949, 1.1022703842524302, 1.3500000000000003, 1.5588457268119897, 1.742842505793338, 1.9091883092036785, 2.0621590627301285, 2.2045407685048604, 2.3382685902179845, 2.4647515087732477, 2.5850531909421135, 2.7000000000000006, 2.8102490992792797, 2.9163333142835377, 3.0186917696247164, 3.1176914536239795, 3.213642792844283, 3.3068111527572905, 3.397425495871838, 3.485685011586676, 3.571764269937198, 3.655817282086183, 3.7379807383131345, 3.818376618407357, 3.8971143170299745, 3.9742923898475317, 4.050000000000001, 4.124318125460257, 4.197320573889967, 4.2690748412273125, 4.33964284244683, 4.409081537009721, 4.477443466979791, 4.544777222262936, 4.611127844681819, 4.676537180435969, 4.741044188783733, 4.804685213414091, 4.867494221876387, 4.929503017546495, 4.990741427884238, 5.051237472144821, 5.111017511220246, 5.170106381884227, 5.228527517380013, 5.286303056011829, 5.3434539391670635, 5.400000000000001, 5.455960043841965, 5.511351921262151, 5.566192594583843, 5.620498198558559, 5.674284095813323, 5.727564927611036, 5.7803546603993095, 5.832666628567075, 5.88451357377991, 5.935907681222815, 5.9868606130425315, 6.037383539249433, 6.087487166310908, 6.137181763643635, 6.186477188190385, 6.235382907247959, 6.283908019696024, 6.33206127576163, 6.379851095441022, 6.427285585688566, 6.474372556472172, 6.521119535785249, 6.567533783696892, 6.613622305514581, 6.659391864126936, 6.704848991588103, 6.750000000000001, 6.794850991743676, 6.839407869106799, 6.8836763433502615, 6.927661943253295, 6.971370023173352, 7.014805770653954, 7.057974213611156, 7.100880227126776, 7.143528539874396, 7.1859237402020915, 7.228070281894055, 7.269972489631582, 7.311634564172366, 7.353060587265688, 7.3942545263197434, 7.435220238836239, 7.475961476626269, 7.516481889820531, 7.556785030686, 7.59687435726036, 7.636753236814714, 7.676424949154393, 7.715892689767013, 7.75515957282634, 7.794228634059949, 7.833102833488146], [0.0, 0.9, 1.2727922061357855, 1.5588457268119897, 1.8, 2.012461179749811, 2.2045407685048604, 2.3811761799581315, 2.545584412271571, 2.6999999999999997, 2.8460498941515415, 2.9849623113198605, 3.1176914536239795, 3.2449961479175906, 3.3674916480965473, 3.4856850115866753, 3.6, 3.7107950630558943, 3.8183766184073566, 3.9230090491866063, 4.024922359499622, 4.124318125460256, 4.221374183841087, 4.316248370981448, 4.409081537009721, 4.5, 4.589117562233507, 4.676537180435969, 4.762352359916263, 4.846648326421054, 4.9295030175464944, 5.01098792654702, 5.091168824543142, 5.170106381884226, 5.247856705360771, 5.324471804789654, 5.3999999999999995, 5.474486277268398, 5.547972602672079, 5.620498198558559, 5.692099788303083, 5.762811813689564, 5.8326666285670745, 5.9016946718718, 5.969924622639721, 6.037383539249432, 6.104096984812742, 6.17008914036094, 6.235382907247959, 6.300000000000001, 6.3639610306789285, 6.427285585688566, 6.489992295835181, 6.552098900352467, 6.613622305514582, 6.674578638386097, 6.734983296193095, 6.794850991743675, 6.854195795277518, 6.913031173081746, 6.971370023173351, 7.029224708315989, 7.08660708661063, 7.143528539874395, 7.2, 7.256031973468695, 7.311634564172364, 7.366817494685205, 7.421590126111789, 7.475961476626267, 7.52994023880668, 7.583534795858723, 7.636753236814713, 7.689603370785779, 7.742092740338364, 7.794228634059948, 7.846018098373213, 7.89746794865291, 7.9485847796950635, 7.99937497558403, 8.049844718999244, 8.1, 8.149846624323676, 8.19939022122987, 8.248636250920512, 8.2975900115636, 8.346256645946134, 8.394641147779934, 8.442748367682174, 8.490583018850943, 8.538149682454625, 8.58545281275251, 8.632496741962896, 8.67928568489366, 8.725823743349393, 8.772114910328067, 8.818163074019441, 8.863972021616496, 8.909545442950499, 8.95488693395958, 9.0, 9.044888059008802], [0.0, 1.0062305898749055, 1.4230249470757708, 1.7428425057933379, 2.012461179749811, 2.2500000000000004, 2.4647515087732477, 2.6622359023948277, 2.8460498941515415, 3.018691769624716, 3.1819805153394642, 3.337289319193049, 3.4856850115866758, 3.6280159867343476, 3.76497011940334, 3.897114317029974, 4.024922359499622, 4.1487950057818, 4.2690748412273125, 4.386057455164035, 4.500000000000001, 4.61112784468182, 4.719639816765683, 4.825712382643625, 4.929503017546495, 5.031152949374527, 5.130789412946122, 5.228527517380014, 5.324471804789655, 5.418717560456534, 5.5113519212621505, 5.60245481909493, 5.692099788303083, 5.780354660399309, 5.8672821646823845, 5.952940449895329, 6.037383539249432, 6.12066172893095, 6.2028219384406, 6.283908019696025, 6.3639610306789285, 6.443019478474359, 6.521119535785248, 6.59829523437683, 6.674578638386098, 6.75, 6.824587899646396, 6.898369372540152, 6.9713700231733515, 7.043614129124339, 7.1151247353788545, 7.1859237402020915, 7.256031973468695, 7.325469268244869, 7.3942545263197434, 7.462405778299651, 7.52994023880668, 7.5968743572603605, 7.663223864666882, 7.72900381679295, 7.794228634059948, 7.858912138457842, 7.923067587746554, 7.986707707184482, 8.049844718999244, 8.112490369793976, 8.174655956063228, 8.236352347975407, 8.2975900115636, 8.35837902945302, 8.41872912024137, 8.478649656637549, 8.538149682454625, 8.597237928544262, 8.655922827752105, 8.714212528966689, 8.77211491032807, 8.829637591656864, 8.886787946159176, 8.943573111458306, 9.000000000000002, 9.05607530887415, 9.111805529092464, 9.167196954358515, 9.22225568936364, 9.276987657639737, 9.331398608997475, 9.385494126576395, 9.439279633531365, 9.492760399378044, 9.545941546018392, 9.598828053465695, 9.65142476528725, 9.703736393781522, 9.75576752490546, 9.807522622966514, 9.85900603509299, 9.910221995495359, 9.961174629530396, 10.011867957579147, 10.062305898749054, 10.112492274409906], [0.0, 1.1022703842524302, 1.5588457268119895, 1.9091883092036785, 2.2045407685048604, 2.464751508773248, 2.7, 2.9163333142835373, 3.117691453623979, 3.30681115275729, 3.4856850115866753, 3.6558172820861827, 3.818376618407357, 3.9742923898475313, 4.124318125460256, 4.269074841227312, 4.409081537009721, 4.544777222262935, 4.676537180435969, 4.80468521341409, 4.929503017546496, 5.051237472144821, 5.170106381884226, 5.286303056011829, 5.4, 5.511351921262151, 5.6204981985585585, 5.727564927611036, 5.8326666285670745, 5.9359076812228135, 6.037383539249432, 6.137181763643635, 6.235382907247958, 6.332061275761631, 6.427285585688566, 6.521119535785248, 6.61362230551458, 6.704848991588103, 6.794850991743675, 6.883676343350261, 6.971370023173351, 7.057974213611155, 7.143528539874395, 7.228070281894054, 7.3116345641723655, 7.394254526319742, 7.475961476626267, 7.556785030686, 7.636753236814714, 7.715892689767012, 7.794228634059948, 7.871785058041157, 7.948584779695063, 8.024649525057155, 8.100000000000001, 8.174655956063228, 8.248636250920512, 8.321958904008119, 8.394641147779934, 8.46669947500205, 8.538149682454623, 8.609006911369045, 8.67928568489366, 8.748999942850611, 8.818163074019441, 8.886787946159174, 8.95488693395958, 9.022471945093539, 9.08955444452587, 9.156145477219113, 9.222255689363639, 9.287895348247632, 9.353074360871938, 9.417802291405359, 9.482088377567464, 9.545941546018392, 9.60937042682818, 9.672383367092106, 9.734988443752773, 9.79719347568476, 9.859006035092992, 9.920433458271871, 9.981482855768476, 10.04216112198963, 10.102474944289643, 10.162430811572595, 10.222035022440492, 10.281293692916277, 10.340212763768452, 10.39879800746221, 10.457055034760026, 10.51498930099313, 10.572606112023658, 10.629910629915946, 10.686907878334127, 10.743602747681988, 10.8, 10.856104273633338, 10.911920087683928, 10.967451846258548, 11.022703842524303, 11.077680262582055], [0.0, 1.1905880899790657, 1.6837458240482737, 2.062159062730128, 2.3811761799581315, 2.6622359023948277, 2.9163333142835373, 3.15, 3.3674916480965473, 3.571764269937197, 3.76497011940334, 3.9487339743264553, 4.124318125460256, 4.292726406376255, 4.4547727214752495, 4.611127844681819, 4.762352359916263, 4.908920451586072, 5.0512374721448206, 5.1896531676018585, 5.324471804789655, 5.455960043841964, 5.584353140695886, 5.709859893202284, 5.8326666285670745, 5.952940449895329, 6.070831903454419, 6.186477188190385, 6.3, 6.411513081948754, 6.521119535785247, 6.628913938195306, 6.734983296193095, 6.839407869106799, 6.942261879243682, 7.043614129124338, 7.143528539874394, 7.242064622743987, 7.339277893635041, 7.435220238836239, 7.52994023880668, 7.623483455743838, 7.715892689767012, 7.807208207803861, 7.897467948652911, 7.986707707184481, 8.074961300216863, 8.162260716247674, 8.248636250920512, 8.334116629853462, 8.418729120241368, 8.502499632461033, 8.58545281275251, 8.6676121279162, 8.748999942850611, 8.829637591656864, 8.909545442950499, 8.988742959947182, 9.06724875582445, 9.145080644805708, 9.222255689363639, 9.29879024389732, 9.374699995199846, 9.45, 9.524704719832526, 9.598828053465693, 9.672383367092104, 9.74538352246847, 9.817840903172144, 9.88976743912616, 9.961174629530396, 10.03207356432358, 10.102474944289641, 10.172389099911584, 10.241826009066939, 10.31079531365064, 10.379306335203717, 10.44736808961951, 10.514989300993133, 10.582178414674361, 10.64894360957931, 10.715292809811592, 10.781233695639846, 10.846773713874555, 10.911920087683928, 10.976679825885421, 11.041059731746767, 11.10506641132776, 11.168706281391772, 11.231985576913816, 11.29491035821002, 11.357486517711566, 11.419719786404569, 11.481615739955767, 11.543179804542595, 11.604417262404864, 11.665333257134149, 11.725932798715846, 11.786220768337916, 11.846201922979366, 11.905880899790658, 11.965262220277499], [0.0, 1.2727922061357855, 1.7999999999999998, 2.2045407685048604, 2.545584412271571, 2.8460498941515415, 3.117691453623979, 3.3674916480965473, 3.5999999999999996, 3.818376618407356, 4.024922359499621, 4.221374183841087, 4.409081537009721, 4.589117562233506, 4.762352359916263, 4.9295030175464944, 5.091168824543142, 5.24785670536077, 5.3999999999999995, 5.547972602672079, 5.692099788303083, 5.8326666285670745, 5.96992462263972, 6.104096984812742, 6.235382907247958, 6.363961030678928, 6.489992295835181, 6.613622305514581, 6.734983296193095, 6.854195795277517, 6.97137002317335, 7.08660708661063, 7.199999999999999, 7.311634564172365, 7.42159012611179, 7.529940238806679, 7.636753236814712, 7.742092740338364, 7.846018098373212, 7.9485847796950635, 8.049844718999243, 8.149846624323676, 8.248636250920512, 8.346256645946132, 8.442748367682174, 8.538149682454623, 8.632496741962894, 8.725823743349393, 8.818163074019441, 8.909545442950499, 9.0, 9.08955444452587, 9.178235124467012, 9.2660671268883, 9.353074360871938, 9.439279633531363, 9.524704719832526, 9.60937042682818, 9.693296652842108, 9.776502442080192, 9.859006035092989, 9.940824915468534, 10.02197585309404, 10.102474944289641, 10.182337649086284, 10.261578825892242, 10.34021276376845, 10.418253212511202, 10.49571341072154, 10.572606112023657, 10.648943609579309, 10.724737759031687, 10.799999999999999, 10.874741376235116, 10.948972554536795, 11.022703842524301, 11.095945205344158, 11.16870628139177, 11.240996397117119, 11.31282458097888, 11.384199576606166, 11.45512985522207, 11.525623627379128, 11.595688854052613, 11.665333257134149, 11.734564329364767, 11.803389343743602, 11.871815362445627, 11.93984924527944, 12.0074976577137, 12.074767078498864, 12.141663806908838, 12.208193969625484, 12.27436352728727, 12.34017828072188, 12.405643876881198, 12.470765814495916, 12.535549449465709, 12.6, 12.66412255152326, 12.727922061357855, 12.791403363196707], [0.0, 1.35, 1.909188309203678, 2.3382685902179845, 2.7, 3.0186917696247164, 3.3068111527572905, 3.5717642699371974, 3.818376618407356, 4.05, 4.269074841227312, 4.47744346697979, 4.676537180435969, 4.8674942218763855, 5.0512374721448206, 5.228527517380012, 5.4, 5.566192594583842, 5.727564927611034, 5.884513573779909, 6.037383539249433, 6.186477188190384, 6.33206127576163, 6.474372556472171, 6.613622305514581, 6.75, 6.88367634335026, 7.014805770653954, 7.143528539874395, 7.269972489631581, 7.394254526319742, 7.516481889820529, 7.636753236814712, 7.755159572826339, 7.871785058041156, 7.986707707184481, 8.1, 8.211729415902596, 8.321958904008119, 8.430747297837838, 8.538149682454623, 8.644217720534346, 8.748999942850611, 8.852542007807699, 8.95488693395958, 9.056075308874147, 9.15614547721911, 9.25513371054141, 9.353074360871938, 9.450000000000001, 9.545941546018392, 9.640928378532848, 9.734988443752771, 9.8281483505287, 9.920433458271871, 10.011867957579145, 10.102474944289641, 10.192276487615512, 10.281293692916277, 10.369546759622619, 10.457055034760025, 10.543837062473983, 10.629910629915944, 10.715292809811592, 10.8, 10.884047960203041, 10.967451846258545, 11.050226242027806, 11.132385189167683, 11.2139422149394, 11.29491035821002, 11.375302193788084, 11.455129855222069, 11.534405056178668, 11.613139110507547, 11.691342951089922, 11.769027147559818, 11.846201922979365, 11.922877169542595, 11.999062463376044, 12.074767078498866, 12.15, 12.224769936485513, 12.299085331844802, 12.372954376380768, 12.446385017345397, 12.5193849689192, 12.5919617216699, 12.66412255152326, 12.735874528276415, 12.807224523681937, 12.878179219128766, 12.948745112944342, 13.018928527340488, 13.088735615024088, 13.1581723654921, 13.227244611029162, 13.295958032424743, 13.364318164425748, 13.43233040093937, 13.5, 13.567332088513202], [0.0, 1.4230249470757708, 2.0124611797498106, 2.4647515087732477, 2.8460498941515415, 3.1819805153394642, 3.4856850115866753, 3.76497011940334, 4.024922359499621, 4.269074841227312, 4.5, 4.719639816765683, 4.929503017546495, 5.130789412946121, 5.324471804789654, 5.5113519212621505, 5.692099788303083, 5.867282164682384, 6.037383539249432, 6.2028219384406, 6.3639610306789285, 6.521119535785248, 6.674578638386097, 6.824587899646396, 6.971370023173351, 7.115124735378854, 7.256031973468695, 7.3942545263197434, 7.52994023880668, 7.663223864666881, 7.794228634059947, 7.923067587746554, 8.049844718999243, 8.174655956063228, 8.2975900115636, 8.418729120241368, 8.538149682454623, 8.655922827752105, 8.772114910328067, 8.886787946159176, 9.0, 9.111805529092464, 9.222255689363639, 9.331398608997473, 9.439279633531365, 9.54594154601839, 9.651424765287247, 9.75576752490546, 9.85900603509299, 9.961174629530396, 10.062305898749054, 10.162430811572595, 10.261578825892242, 10.359777989899206, 10.457055034760026, 10.553435459602717, 10.648943609579309, 10.74360274768199, 10.837435120913067, 10.930462021342006, 11.022703842524301, 11.114180131705622, 11.204909638189859, 11.29491035821002, 11.384199576606166, 11.472793905583766, 11.560709320798615, 11.647961194990305, 11.734564329364767, 11.820532982907327, 11.905880899790658, 11.990621335026805, 12.074767078498864, 12.158330477495667, 12.241323457861899, 12.323757543866238, 12.4056438768812, 12.486993232960447, 12.56781603939205, 12.648122390299676, 12.727922061357857, 12.807224523681937, 12.886038956948719, 12.96437426179914, 13.042239071570496, 13.119641763401926, 13.196590468753662, 13.273093083377363, 13.349157276772194, 13.424790501158668, 13.5, 13.57479281609852, 13.649175799292792, 13.723155613779216, 13.796738745080303, 13.869931506680196, 13.942740046346701, 14.015170352157694, 14.087228258248675, 14.158919450297047, 14.230249470757707, 14.301223723863634], [0.0, 1.4924811556599302, 2.1106870919205436, 2.585053190942113, 2.9849623113198605, 3.337289319193049, 3.6558172820861827, 3.9487339743264553, 4.221374183841087, 4.47744346697979, 4.719639816765683, 4.950000000000001, 5.170106381884226, 5.38121733439563, 5.584353140695886, 5.780354660399309, 5.969924622639721, 6.153657449029804, 6.33206127576163, 6.505574532660433, 6.674578638386098, 6.839407869106799, 7.000357133746822, 7.1576881742640905, 7.3116345641723655, 7.46240577829965, 7.610190536379494, 7.75515957282634, 7.897467948652911, 8.037256994771289, 8.174655956063228, 8.309783390678724, 8.442748367682174, 8.573651497465944, 8.702585822616173, 8.829637591656864, 8.95488693395958, 9.078408450824407, 9.200271735117393, 9.320541829743593, 9.439279633531365, 9.556542261717887, 9.672383367092106, 9.786853426919194, 9.900000000000002, 10.011867957579145, 10.122499691281794, 10.231935300811866, 10.340212763768452, 10.447368089619511, 10.553435459602717, 10.658447354094312, 10.76243466879126, 10.865426820884675, 10.967451846258548, 11.06853648862396, 11.168706281391772, 11.267985622994024, 11.366397846283583, 11.463965282571296, 11.560709320798617, 11.656650462289758, 11.751808371480536, 11.846201922979365, 11.939849245279442, 12.032767761408845, 12.124974226776732, 12.216484764448404, 12.307314898059609, 12.39747958256032, 12.48699323296045, 12.57586975123391, 12.66412255152326, 12.75176458377428, 12.838808355918395, 12.925265954710566, 13.011149065320867, 13.096468989769726, 13.181236664289132, 13.265462675685308, 13.349157276772196, 13.432330400939371, 13.514991675913087, 13.597150436764316, 13.678815738213599, 13.75999636627859, 13.84070084930673, 13.920937468432218, 14.000714267493644, 14.080039062445815, 14.158919450297047, 14.237362817600738, 14.315376348528181, 14.39296703254753, 14.470141671732176, 14.546906887720152, 14.623269128344731, 14.69923467395497, 14.774809643443804, 14.850000000000001, 14.9248115565993, 14.999249981249065], [0.0, 1.5588457268119897, 2.2045407685048604, 2.7000000000000006, 3.1176914536239795, 3.485685011586676, 3.818376618407357, 4.124318125460257, 4.409081537009721, 4.676537180435969, 4.929503017546495, 5.170106381884227, 5.400000000000001, 5.620498198558559, 5.832666628567075, 6.037383539249433, 6.235382907247959, 6.427285585688566, 6.613622305514581, 6.794850991743676, 6.971370023173352, 7.143528539874396, 7.311634564172366, 7.475961476626269, 7.636753236814714, 7.794228634059949, 7.9485847796950635, 8.100000000000001, 8.248636250920514, 8.394641147779934, 8.538149682454625, 8.67928568489366, 8.818163074019441, 8.954886933959582, 9.089554444525872, 9.222255689363639, 9.353074360871938, 9.482088377567466, 9.609370426828182, 9.734988443752775, 9.85900603509299, 9.981482855768476, 10.102474944289643, 10.222035022440492, 10.340212763768454, 10.457055034760026, 10.572606112023658, 10.686907878334127, 10.800000000000002, 10.91192008768393, 11.022703842524303, 11.132385189167685, 11.240996397117119, 11.348568191626645, 11.455129855222072, 11.560709320798619, 11.66533325713415, 11.76902714755982, 11.87181536244563, 11.973721226085063, 12.074767078498866, 12.174974332621815, 12.27436352728727, 12.37295437638077, 12.470765814495918, 12.567816039392048, 12.66412255152326, 12.759702190882043, 12.854571171377131, 12.948745112944344, 13.042239071570497, 13.135067567393785, 13.227244611029162, 13.318783728253871, 13.409697983176207, 13.500000000000002, 13.589701983487352, 13.678815738213599, 13.767352686700523, 13.85532388650659, 13.942740046346705, 14.029611541307908, 14.115948427222312, 14.201760454253552, 14.287057079748791, 14.371847480404183, 14.45614056378811, 14.539944979263163, 14.623269128344733, 14.706121174531376, 14.788509052639487, 14.870440477672478, 14.951922953252538, 15.032963779641062, 15.113570061372, 15.19374871452072, 15.273506473629428, 15.352849898308786, 15.431785379534025, 15.51031914565268, 15.588457268119898, 15.666205666976293], [0.0, 1.6224980739587953, 2.2945587811167534, 2.8102490992792797, 3.2449961479175906, 3.628015986734348, 3.9742923898475313, 4.292726406376255, 4.589117562233507, 4.8674942218763855, 5.130789412946121, 5.38121733439563, 5.620498198558559, 5.8500000000000005, 6.070831903454419, 6.283908019696024, 6.489992295835181, 6.689730936293327, 6.88367634335026, 7.072305140475771, 7.256031973468696, 7.435220238836239, 7.610190536379495, 7.781227409605763, 7.948584779695063, 8.112490369793976, 8.273149339882607, 8.43074729783784, 8.58545281275251, 8.73741952752642, 8.886787946159174, 9.033686954948129, 9.178235124467014, 9.320541829743592, 9.460708218732888, 9.598828053465693, 9.734988443752771, 9.86927048975759, 10.001749846901792, 10.132497224277934, 10.261578825892242, 10.389056742553677, 10.51498930099313, 10.639431375783198, 10.76243466879126, 10.884047960203041, 11.004317334573736, 11.12328638487745, 11.240996397117119, 11.357486517711568, 11.472793905583767, 11.586953870625361, 11.700000000000001, 11.811964273566021, 11.922877169542595, 12.032767761408845, 12.141663806908838, 12.24959182993458, 12.356577195971385, 12.462644181713605, 12.567816039392048, 12.672115056295851, 12.775562609920552, 12.878179219128766, 12.979984591670362, 13.08099766837377, 13.181236664289129, 13.280719107036335, 13.379461872586655, 13.477481218684744, 13.57479281609852, 13.671411777866982, 13.76735268670052, 13.86262962067443, 13.95725617734374, 14.051245496396398, 14.144610280951541, 14.237362817600738, 14.329514995281595, 14.42107832306586, 14.512063946937392, 14.602482665629157, 14.69234494558306, 14.781660935091159, 14.870440477672478, 14.958693124735197, 15.04642814757044, 15.133654548720214, 15.22038107275899, 15.306616216525455, 15.392368238838364, 15.477645169727856, 15.562454819211526, 15.64680478564234, 15.730702463653683, 15.81415505172502, 15.897169559390125, 15.979752814108236, 16.061911467817275, 16.14365200318689, 16.224980739587952, 16.305903838794098], [0.0, 1.6837458240482737, 2.3811761799581315, 2.9163333142835373, 3.3674916480965473, 3.7649701194033405, 4.124318125460256, 4.4547727214752495, 4.762352359916263, 5.0512374721448206, 5.324471804789654, 5.584353140695886, 5.8326666285670745, 6.070831903454419, 6.3, 6.521119535785247, 6.734983296193095, 6.94226187924368, 7.143528539874394, 7.339277893635041, 7.529940238806681, 7.715892689767012, 7.897467948652911, 8.074961300216863, 8.248636250920512, 8.418729120241368, 8.58545281275251, 8.748999942850611, 8.909545442950499, 9.067248755824448, 9.222255689363637, 9.374699995199846, 9.524704719832526, 9.672383367092106, 9.817840903172144, 9.961174629530394, 10.102474944289641, 10.241826009066937, 10.379306335203715, 10.514989300993133, 10.648943609579309, 10.781233695639846, 10.911920087683926, 11.041059731746765, 11.168706281391772, 11.294910358210018, 11.419719786404569, 11.543179804542595, 11.665333257134149, 11.786220768337916, 11.905880899790658, 12.02435029429865, 12.141663806908838, 12.257854624688614, 12.372954376380768, 12.486993232960447, 12.6, 12.712002202642982, 12.823026163897508, 12.933097076879921, 13.042239071570494, 13.150475276582211, 13.25782787639061, 13.364318164425748, 13.46996659238619, 13.574792816098519, 13.678815738213595, 13.782053548002198, 13.88452375848736, 13.986243241128047, 14.087228258248675, 14.187494493391002, 14.287057079748788, 14.385930626831204, 14.484129245487972, 14.581666571417685, 14.678555787270081, 14.774809643443803, 14.870440477672478, 14.9654602334843, 15.059880477613362, 15.153712416434463, 15.246966911487675, 15.339654494153379, 15.431785379534023, 15.523369479594306, 15.614416415607725, 15.704935529953632, 15.794935897305821, 15.884426335250511, 15.973415414368963, 16.06191146781727, 16.149922600433726, 16.237456697401843, 16.32452143249535, 16.41112427592942, 16.497272501841024, 16.582973195419452, 16.66823325970692, 16.753059422087656, 16.837458240482736, 16.92143610926685], [0.0, 1.7428425057933374, 2.4647515087732472, 3.018691769624716, 3.485685011586675, 3.897114317029974, 4.269074841227312, 4.611127844681819, 4.9295030175464944, 5.228527517380011, 5.5113519212621505, 5.780354660399309, 6.037383539249432, 6.283908019696023, 6.521119535785247, 6.749999999999999, 6.97137002317335, 7.18592374020209, 7.394254526319742, 7.596874357260359, 7.794228634059948, 7.986707707184482, 8.174655956063228, 8.358379029453019, 8.538149682454623, 8.714212528966687, 8.886787946159174, 9.05607530887415, 9.222255689363639, 9.385494126576393, 9.54594154601839, 9.70373639378152, 9.859006035092989, 10.011867957579145, 10.162430811572593, 10.310795313650639, 10.457055034760023, 10.601297090450771, 10.743602747681988, 10.884047960203043, 11.022703842524301, 11.159637090873519, 11.29491035821002, 11.428582589280262, 11.560709320798617, 11.691342951089919, 11.820532982907327, 11.948326242616577, 12.074767078498864, 12.199897540553362, 12.323757543866238, 12.446385017345397, 12.567816039392046, 12.688084961884517, 12.807224523681937, 12.925265954710564, 13.042239071570494, 13.158172365492101, 13.273093083377363, 13.387027302579162, 13.499999999999998, 13.612035116028755, 13.723155613779214, 13.833383534045456, 13.9427400463467, 14.051245496396394, 14.158919450297043, 14.26578073573262, 14.37184748040418, 14.47713714793087, 14.581666571417685, 14.685451984872648, 14.788509052639483, 14.890852896996867, 14.992498124061912, 15.09345884812358, 15.193748714520718, 15.293380921169785, 15.392368238838364, 15.490723030252653, 15.588457268119896, 15.685582552140037, 15.782110125075164, 15.878050887939613, 15.973415414368963, 16.06821396422141, 16.16245649646117, 16.256152681369596, 16.349311912126456, 16.441943315800597, 16.53405576378645, 16.62565788172005, 16.716758058906038, 16.807364457284788, 16.897485019966727, 16.987127479359184, 17.076299364909246, 17.165008010484584, 17.25326056141273, 17.341063981197923, 17.428425057933374, 17.515350410425707], [0.0, 1.8, 2.545584412271571, 3.1176914536239795, 3.6, 4.024922359499622, 4.409081537009721, 4.762352359916263, 5.091168824543142, 5.3999999999999995, 5.692099788303083, 5.969924622639721, 6.235382907247959, 6.489992295835181, 6.734983296193095, 6.971370023173351, 7.2, 7.421590126111789, 7.636753236814713, 7.846018098373213, 8.049844718999244, 8.248636250920512, 8.442748367682174, 8.632496741962896, 8.818163074019441, 9.0, 9.178235124467014, 9.353074360871938, 9.524704719832526, 9.693296652842108, 9.859006035092989, 10.02197585309404, 10.182337649086284, 10.340212763768452, 10.495713410721542, 10.648943609579309, 10.799999999999999, 10.948972554536796, 11.095945205344158, 11.240996397117119, 11.384199576606166, 11.525623627379128, 11.665333257134149, 11.8033893437436, 11.939849245279442, 12.074767078498864, 12.208193969625484, 12.34017828072188, 12.470765814495918, 12.600000000000001, 12.727922061357857, 12.854571171377131, 12.979984591670362, 13.104197800704934, 13.227244611029164, 13.349157276772194, 13.46996659238619, 13.58970198348735, 13.708391590555037, 13.826062346163493, 13.942740046346701, 14.058449416631978, 14.17321417322126, 14.28705707974879, 14.4, 14.51206394693739, 14.623269128344727, 14.73363498937041, 14.843180252223577, 14.951922953252534, 15.05988047761336, 15.167069591717446, 15.273506473629427, 15.379206741571558, 15.484185480676729, 15.588457268119896, 15.692036196746425, 15.79493589730582, 15.897169559390127, 15.99874995116806, 16.09968943799849, 16.2, 16.29969324864735, 16.39878044245974, 16.497272501841024, 16.5951800231272, 16.69251329189227, 16.789282295559868, 16.88549673536435, 16.981166037701886, 17.07629936490925, 17.17090562550502, 17.264993483925792, 17.35857136978732, 17.451647486698786, 17.544229820656135, 17.636326148038883, 17.72794404323299, 17.819090885900998, 17.90977386791916, 18.0, 18.089776118017603], [0.0, 1.8553975315279474, 2.623928352680385, 3.213642792844283, 3.710795063055895, 4.1487950057818, 4.544777222262935, 4.908920451586072, 5.24785670536077, 5.566192594583841, 5.867282164682384, 6.153657449029805, 6.427285585688566, 6.689730936293327, 6.942261879243681, 7.18592374020209, 7.42159012611179, 7.6499999999999995, 7.871785058041155, 8.087490340025143, 8.2975900115636, 8.502499632461033, 8.702585822616173, 8.898173969978336, 9.08955444452587, 9.276987657639737, 9.460708218732888, 9.640928378532848, 9.817840903172144, 9.991621490028534, 10.162430811572593, 10.330416254924097, 10.49571341072154, 10.65844735409431, 10.818733752154179, 10.976679825885421, 11.132385189167682, 11.285942583586008, 11.43743852442495, 11.586953870625361, 11.734564329364767, 11.880340904199677, 12.02435029429865, 12.166655251136195, 12.30731489805961, 12.446385017345396, 12.583918308698607, 12.719964622592313, 12.854571171377131, 12.987782720695632, 13.119641763401926, 13.250188677901912, 13.379461872586655, 13.507497917823272, 13.634331666788807, 13.75999636627859, 13.884523758487362, 14.007944174646044, 14.130286621296825, 14.251578859901802, 14.37184748040418, 14.491117969294155, 14.609414772673134, 14.726761354758214, 14.84318025222358, 14.958693124735195, 15.073320801999802, 15.187083327617584, 15.299999999999999, 15.412089410589337, 15.523369479594306, 15.633857489436188, 15.74357011608231, 15.852523458427685, 15.960733065871379, 16.068213964221414, 16.174980680050286, 16.28104726361299, 16.386427310429816, 16.491133981627826, 16.5951800231272, 16.698577783751524, 16.801339232335025, 16.903475973893652, 17.004999264922066, 17.105920027873392, 17.206248864874645, 17.30599607072647, 17.405171645232347, 17.50378530489905, 17.60184649404715, 17.69936439536742, 17.79634793995667, 17.89280581686394, 17.988746482176015, 18.084178167669105, 18.17910888905174, 18.27354645382226, 18.367498468762697, 18.460972347089413, 18.553975315279473, 18.6465144195906], [0.0, 1.9091883092036783, 2.6999999999999997, 3.3068111527572905, 3.8183766184073566, 4.2690748412273125, 4.676537180435969, 5.051237472144821, 5.3999999999999995, 5.727564927611034, 6.037383539249432, 6.332061275761631, 6.613622305514581, 6.88367634335026, 7.143528539874395, 7.394254526319743, 7.636753236814713, 7.871785058041155, 8.1, 8.321958904008119, 8.538149682454625, 8.748999942850611, 8.95488693395958, 9.156145477219113, 9.353074360871938, 9.545941546018392, 9.734988443752771, 9.920433458271873, 10.102474944289643, 10.281293692916277, 10.457055034760025, 10.629910629915946, 10.799999999999999, 10.967451846258548, 11.132385189167685, 11.29491035821002, 11.455129855222069, 11.613139110507547, 11.769027147559818, 11.922877169542595, 12.074767078498864, 12.224769936485513, 12.372954376380768, 12.519384968919198, 12.664122551523262, 12.807224523681935, 12.948745112944342, 13.088735615024088, 13.227244611029162, 13.364318164425748, 13.5, 13.634331666788807, 13.76735268670052, 13.899100690332451, 14.029611541307908, 14.158919450297047, 14.28705707974879, 14.414055640242271, 14.539944979263163, 14.66475366312029, 14.788509052639485, 14.911237373202802, 15.03296377964106, 15.153712416434463, 15.273506473629427, 15.392368238838362, 15.510319145652677, 15.627379818766803, 15.74357011608231, 15.858909168035487, 15.973415414368963, 16.08710663854753, 16.2, 16.312112064352675, 16.423458831805192, 16.53405576378645, 16.643917808016237, 16.753059422087656, 16.86149459567568, 16.969236871468322, 17.07629936490925, 17.182694782833106, 17.288435441068692, 17.39353328107892, 17.497999885701223, 17.60184649404715, 17.7050840156154, 17.807723043668442, 17.90977386791916, 18.011246486570553, 18.1121506177483, 18.212495710363257, 18.312290954438225, 18.411545290930906, 18.51026742108282, 18.608465815321797, 18.706148721743876, 18.80332417419856, 18.900000000000002, 18.99618382728489, 19.091883092036785, 19.18710504479506], [0.0, 1.9615045245933034, 2.7739863013360395, 3.397425495871838, 3.9230090491866068, 4.386057455164035, 4.804685213414091, 5.1896531676018585, 5.547972602672079, 5.884513573779909, 6.2028219384406, 6.505574532660433, 6.794850991743676, 7.072305140475771, 7.339277893635042, 7.59687435726036, 7.8460180983732135, 8.087490340025143, 8.321958904008119, 8.55, 8.77211491032807, 8.988742959947182, 9.200271735117395, 9.407045232165094, 9.609370426828182, 9.807522622966516, 10.001749846901793, 10.192276487615514, 10.379306335203717, 10.563025134874954, 10.74360274768199, 10.921194989560439, 11.095945205344158, 11.267985622994026, 11.437438524424953, 11.604417262404866, 11.769027147559818, 11.931366225206569, 12.091525958289964, 12.249591829934582, 12.4056438768812, 12.559757163257578, 12.712002202642983, 12.862445335160807, 13.011149065320867, 13.158172365492101, 13.303570949185035, 13.447397517735544, 13.589701983487352, 13.730531672153123, 13.8699315066802, 14.007944174646045, 14.144610280951541, 14.27996848736019, 14.414055640242273, 14.546906887720155, 14.678555787270083, 14.809034404713904, 14.938373405428052, 15.066602138504885, 15.19374871452072, 15.319840077494282, 15.444902071557465, 15.568959502805576, 15.692036196746427, 15.814155051725022, 15.935338088663197, 16.055606497420147, 16.174980680050286, 16.293480291208507, 16.411124275929424, 16.527930904986263, 16.643917808016237, 16.75910200458247, 16.87349993332741, 16.987127479359188, 17.1, 17.21213234901475, 17.323538899428147, 17.434233565029466, 17.54422982065614, 17.65354072133973, 17.7621789203915, 17.870156686498305, 17.977485919894363, 18.08417816766911, 18.190244638266964, 18.29569621523051, 18.40054347023479, 18.504796675456884, 18.6084658153218, 18.711560597662615, 18.81409046433019, 18.916064601285335, 19.017491948203897, 19.1183812076232, 19.218740853656364, 19.318579140299118, 19.41790410935228, 19.5167235979813, 19.615045245933032, 19.71287650242856], [0.0, 2.012461179749811, 2.8460498941515415, 3.4856850115866758, 4.024922359499622, 4.500000000000001, 4.929503017546495, 5.324471804789655, 5.692099788303083, 6.037383539249432, 6.3639610306789285, 6.674578638386098, 6.9713700231733515, 7.256031973468695, 7.52994023880668, 7.794228634059948, 8.049844718999244, 8.2975900115636, 8.538149682454625, 8.77211491032807, 9.000000000000002, 9.22225568936364, 9.439279633531365, 9.65142476528725, 9.85900603509299, 10.062305898749054, 10.261578825892244, 10.457055034760028, 10.64894360957931, 10.837435120913067, 11.022703842524301, 11.20490963818986, 11.384199576606166, 11.560709320798617, 11.734564329364769, 11.905880899790658, 12.074767078498864, 12.2413234578619, 12.4056438768812, 12.56781603939205, 12.727922061357857, 12.886038956948719, 13.042239071570496, 13.19659046875366, 13.349157276772196, 13.5, 13.649175799292792, 13.796738745080305, 13.942740046346703, 14.087228258248677, 14.230249470757709, 14.371847480404183, 14.51206394693739, 14.650938536489738, 14.788509052639487, 14.924811556599302, 15.05988047761336, 15.193748714520721, 15.326447729333765, 15.4580076335859, 15.588457268119896, 15.717824276915684, 15.846135175493108, 15.973415414368963, 16.09968943799849, 16.224980739587952, 16.349311912126456, 16.472704695950814, 16.5951800231272, 16.71675805890604, 16.83745824048274, 16.957299313275097, 17.07629936490925, 17.194475857088523, 17.31184565550421, 17.428425057933378, 17.54422982065614, 17.659275183313728, 17.773575892318352, 17.887146222916613, 18.000000000000004, 18.1121506177483, 18.22361105818493, 18.33439390871703, 18.44451137872728, 18.553975315279473, 18.66279721799495, 18.77098825315279, 18.87855926706273, 18.985520798756088, 19.091883092036785, 19.19765610693139, 19.3028495305745, 19.407472787563044, 19.51153504981092, 19.61504524593303, 19.71801207018598, 19.820443990990718, 19.92234925906079, 20.023735915158294, 20.12461179749811, 20.224984548819812], [0.0, 2.062159062730128, 2.9163333142835373, 3.571764269937198, 4.124318125460256, 4.61112784468182, 5.051237472144821, 5.455960043841964, 5.8326666285670745, 6.186477188190383, 6.521119535785248, 6.8394078691068, 7.143528539874396, 7.435220238836238, 7.715892689767012, 7.986707707184482, 8.248636250920512, 8.502499632461033, 8.748999942850611, 8.988742959947182, 9.22225568936364, 9.450000000000001, 9.672383367092106, 9.88976743912616, 10.102474944289643, 10.31079531365064, 10.51498930099313, 10.715292809811594, 10.911920087683928, 11.10506641132776, 11.29491035821002, 11.481615739955767, 11.665333257134149, 11.846201922979366, 12.024350294298651, 12.199897540553364, 12.372954376380767, 12.54362387828972, 12.712002202642982, 12.87817921912877, 13.042239071570496, 13.20426067600909, 13.364318164425748, 13.522481281185046, 13.6788157382136, 13.833383534045456, 13.986243241128049, 14.137450265164508, 14.287057079748791, 14.435113439110898, 14.581666571417687, 14.726761354758217, 14.870440477672476, 15.012744585851053, 15.153712416434464, 15.293380921169787, 15.431785379534023, 15.568959502805576, 15.704935529953636, 15.839744316118235, 15.973415414368963, 16.10597715135595, 16.237456697401846, 16.36788013152589, 16.497272501841024, 16.62565788172005, 16.753059422087656, 16.879499400159947, 17.004999264922066, 17.129579679606852, 17.253260561412734, 17.376061118677043, 17.497999885701223, 17.619094755406707, 17.739363009984324, 17.85882134968599, 17.977485919894363, 18.095372336594792, 18.21249571036326, 18.32887066897467, 18.44451137872728, 18.559431564571153, 18.673644529121788, 18.787163170633292, 18.900000000000002, 19.01216715684985, 19.1236764247882, 19.23453924584626, 19.344766734184212, 19.45436968909556, 19.56335860735574, 19.671743694954955, 19.77953487825232, 19.88674181458592, 19.993373902370756, 20.099440290714565, 20.204949888579286, 20.30991137351417, 20.41433319998476, 20.518223607320397, 20.62159062730128, 20.72444209140502], [0.0, 2.1106870919205436, 2.98496231131986, 3.6558172820861827, 4.221374183841087, 4.719639816765683, 5.170106381884226, 5.584353140695886, 5.96992462263972, 6.332061275761629, 6.674578638386097, 7.000357133746822, 7.3116345641723655, 7.610190536379494, 7.89746794865291, 8.174655956063228, 8.442748367682174, 8.702585822616172, 8.95488693395958, 9.200271735117393, 9.439279633531365, 9.672383367092106, 9.9, 10.122499691281794, 10.340212763768452, 10.553435459602717, 10.76243466879126, 10.967451846258548, 11.168706281391772, 11.366397846283581, 11.560709320798615, 11.751808371480536, 11.93984924527944, 12.124974226776732, 12.30731489805961, 12.486993232960447, 12.664122551523258, 12.838808355918395, 13.011149065320865, 13.18123666428913, 13.349157276772194, 13.514991675913087, 13.678815738213599, 13.840700849306726, 14.000714267493644, 14.158919450297045, 14.31537634852818, 14.470141671732176, 14.623269128344731, 14.774809643443804, 14.9248115565993, 15.073320801999806, 15.220381072758988, 15.366033971067488, 15.510319145652678, 15.65327441783348, 15.79493589730582, 15.935338088663197, 16.07451398954258, 16.212495181186636, 16.349311912126456, 16.484993175612782, 16.61956678135745, 16.753059422087656, 16.88549673536435, 17.016903361070135, 17.147302994931884, 17.27671843840722, 17.405171645232343, 17.53268376490034, 17.659275183313724, 17.784965560832553, 17.90977386791916, 18.033718418562493, 18.156816901648813, 18.279086410430914, 18.400543470234787, 18.521204064531013, 18.641083659487187, 18.760197227108247, 18.87855926706273, 18.99618382728489, 19.113084523435774, 19.229274557299348, 19.344766734184212, 19.45957347939569, 19.57370685383839, 19.687178568804622, 19.8, 19.912182200853827, 20.02373591515829, 20.134671589077385, 20.244999382563588, 20.354729180217557, 20.463870601623732, 20.572433011192427, 20.680425527536904, 20.787857032411978, 20.894736179239022, 21.001071401240463, 21.106870919205434, 21.212142748906818], [0.0, 2.158124185490724, 3.052048492406371, 3.737980738313134, 4.316248370981448, 4.825712382643625, 5.286303056011829, 5.709859893202284, 6.104096984812742, 6.474372556472171, 6.824587899646396, 7.157688174264091, 7.475961476626268, 7.781227409605763, 8.074961300216863, 8.358379029453019, 8.632496741962896, 8.898173969978336, 9.156145477219113, 9.407045232165094, 9.65142476528725, 9.889767439126162, 10.122499691281796, 10.350000000000001, 10.572606112023658, 10.79062092745362, 11.004317334573736, 11.213942214939403, 11.419719786404569, 11.621854413130464, 11.820532982907327, 12.015926930536821, 12.208193969625484, 12.397479582560322, 12.583918308698609, 12.767634863199998, 12.948745112944342, 13.12735693123334, 13.303570949185035, 13.477481218684746, 13.649175799292792, 13.81873727950568, 13.986243241128049, 14.151766674164747, 14.315376348528183, 14.47713714793087, 14.637110370561535, 14.79535400049624, 14.951922953252536, 15.106869298435068, 15.260242462031854, 15.41208941058934, 15.562454819211526, 15.711381225086484, 15.858909168035488, 16.00507731940087, 16.149922600433726, 16.293480291208507, 16.43578413097471, 16.576866410754477, 16.716758058906038, 16.855488720295238, 16.993086829649286, 17.129579679606852, 17.264993483925792, 17.399353436263084, 17.53268376490034, 17.66500778375147, 17.79634793995667, 17.926725858337882, 18.05616238296499, 18.184677616059076, 18.312290954438225, 18.43902112369309, 18.564886210262642, 18.68990369156567, 18.81409046433019, 18.937462871250734, 19.060036726092637, 19.181827337352406, 19.3028495305745, 19.423117669416516, 19.54264567554762, 19.661447047458132, 19.779534878252324, 19.896921872490733, 20.013620362143378, 20.129642321710538, 20.24499938256359, 20.359702846554516, 20.473763698939187, 20.587192620656175, 20.700000000000003, 20.812195943724923, 20.923790287612807, 21.03479260653644, 21.145212224047317, 21.25505822151518, 21.364339446844596, 21.473064522792274, 21.58124185490724, 21.688879639114607], [0.0, 2.2045407685048604, 3.117691453623979, 3.818376618407357, 4.409081537009721, 4.929503017546496, 5.4, 5.8326666285670745, 6.235382907247958, 6.61362230551458, 6.971370023173351, 7.3116345641723655, 7.636753236814714, 7.948584779695063, 8.248636250920512, 8.538149682454623, 8.818163074019441, 9.08955444452587, 9.353074360871938, 9.60937042682818, 9.859006035092992, 10.102474944289643, 10.340212763768452, 10.572606112023658, 10.8, 11.022703842524303, 11.240996397117117, 11.455129855222072, 11.665333257134149, 11.871815362445627, 12.074767078498864, 12.27436352728727, 12.470765814495916, 12.664122551523262, 12.854571171377131, 13.042239071570496, 13.22724461102916, 13.409697983176207, 13.58970198348735, 13.767352686700521, 13.942740046346701, 14.11594842722231, 14.28705707974879, 14.456140563788107, 14.623269128344731, 14.788509052639483, 14.951922953252534, 15.113570061372, 15.273506473629428, 15.431785379534023, 15.588457268119896, 15.743570116082314, 15.897169559390125, 16.04929905011431, 16.200000000000003, 16.349311912126456, 16.497272501841024, 16.643917808016237, 16.789282295559868, 16.9333989500041, 17.076299364909246, 17.21801382273809, 17.35857136978732, 17.497999885701223, 17.636326148038883, 17.77357589231835, 17.90977386791916, 18.044943890187078, 18.17910888905174, 18.312290954438225, 18.444511378727277, 18.575790696495265, 18.706148721743876, 18.835604582810717, 18.96417675513493, 19.091883092036785, 19.21874085365636, 19.344766734184212, 19.469976887505545, 19.59438695136952, 19.718012070185985, 19.840866916543742, 19.962965711536953, 20.08432224397926, 20.204949888579286, 20.32486162314519, 20.444070044880984, 20.562587385832554, 20.680425527536904, 20.79759601492442, 20.914110069520053, 21.02997860198626, 21.145212224047317, 21.25982125983189, 21.373815756668254, 21.487205495363977, 21.6, 21.712208547266677, 21.823840175367856, 21.934903692517096, 22.045407685048605, 22.15536052516411], [0.0, 2.2500000000000004, 3.181980515339464, 3.8971143170299745, 4.500000000000001, 5.031152949374528, 5.511351921262151, 5.952940449895329, 6.363961030678928, 6.75, 7.115124735378854, 7.462405778299651, 7.794228634059949, 8.112490369793976, 8.418729120241368, 8.714212528966689, 9.000000000000002, 9.276987657639737, 9.545941546018392, 9.807522622966516, 10.062305898749056, 10.310795313650642, 10.553435459602719, 10.79062092745362, 11.022703842524303, 11.25, 11.472793905583767, 11.691342951089924, 11.905880899790658, 12.116620816052635, 12.323757543866238, 12.52746981636755, 12.727922061357855, 12.925265954710566, 13.119641763401928, 13.311179511974137, 13.5, 13.686215693170995, 13.869931506680198, 14.0512454963964, 14.230249470757707, 14.407029534223911, 14.581666571417687, 14.7542366796795, 14.924811556599302, 15.09345884812358, 15.260242462031854, 15.425222850902351, 15.588457268119898, 15.750000000000002, 15.909902576697322, 16.068213964221414, 16.224980739587952, 16.38024725088117, 16.534055763786455, 16.686446595965243, 16.837458240482736, 16.987127479359188, 17.135489488193798, 17.282577932704367, 17.428425057933378, 17.573061770789973, 17.716517716526575, 17.858821349685986, 18.000000000000004, 18.140079933671736, 18.27908641043091, 18.417043736713012, 18.553975315279473, 18.689903691565668, 18.824850597016702, 18.95883698964681, 19.091883092036785, 19.22400842696445, 19.35523185084591, 19.48557158514987, 19.615045245933032, 19.743669871632274, 19.87146194923766, 19.998437438960075, 20.124611797498112, 20.250000000000004, 20.37461656080919, 20.498475553074673, 20.621590627301284, 20.743975028909, 20.865641614865336, 20.986602869449836, 21.106870919205438, 21.22645754712736, 21.34537420613656, 21.46363203188128, 21.58124185490724, 21.698214212234152, 21.814559358373483, 21.930287275820167, 22.045407685048605, 22.15993005404124, 22.27386360737625, 22.387217334898953, 22.5, 22.612220147522006], [0.0, 2.2945587811167534, 3.2449961479175906, 3.9742923898475317, 4.589117562233507, 5.130789412946122, 5.620498198558559, 6.070831903454419, 6.489992295835181, 6.88367634335026, 7.256031973468695, 7.610190536379495, 7.9485847796950635, 8.273149339882607, 8.58545281275251, 8.886787946159174, 9.178235124467014, 9.460708218732888, 9.734988443752771, 10.001749846901792, 10.261578825892244, 10.514989300993133, 10.76243466879126, 11.004317334573736, 11.240996397117119, 11.472793905583767, 11.700000000000001, 11.922877169542595, 12.141663806908838, 12.356577195971385, 12.567816039392048, 12.775562609920552, 12.979984591670362, 13.18123666428913, 13.379461872586658, 13.57479281609852, 13.76735268670052, 13.957256177343742, 14.144610280951541, 14.329514995281595, 14.51206394693739, 14.69234494558306, 14.870440477672476, 15.046428147570438, 15.22038107275899, 15.392368238838362, 15.562454819211526, 15.730702463653683, 15.897169559390127, 16.061911467817275, 16.224980739587952, 16.386427310429816, 16.546298679765215, 16.70464007394353, 16.861494595675676, 17.016903361070135, 17.17090562550502, 17.323538899428144, 17.474839055052843, 17.624840424809523, 17.77357589231835, 17.92107697656589, 18.067373909896258, 18.212495710363257, 18.356470248934027, 18.49932431198502, 18.64108365948718, 18.781773079238285, 18.921416437465776, 19.060036726092633, 19.19765610693139, 19.334295953046755, 19.469976887505542, 19.604718819712772, 19.73854097951518, 19.87146194923766, 20.003499693803583, 20.134671589077385, 20.264994448555868, 20.39448454852439, 20.523157651784487, 20.65102903005078, 20.778113485107355, 20.904425368806482, 21.029978601986265, 21.154786692377687, 21.2788627515664, 21.402219511069408, 21.52486933758252, 21.64682424745025, 21.768095920406086, 21.88869571262756, 22.008634669147472, 22.127923535659647, 22.2465727697549, 22.364592551620518, 22.481992794234237, 22.5987831530815, 22.714973035423135, 22.830571609138484, 22.945587811167535, 23.060030355574128], [0.0, 2.3382685902179845, 3.3068111527572905, 4.050000000000001, 4.676537180435969, 5.228527517380014, 5.727564927611035, 6.186477188190384, 6.613622305514581, 7.014805770653953, 7.3942545263197434, 7.75515957282634, 8.100000000000001, 8.430747297837838, 8.748999942850611, 9.05607530887415, 9.353074360871938, 9.640928378532848, 9.920433458271871, 10.192276487615514, 10.457055034760028, 10.715292809811594, 10.967451846258548, 11.213942214939403, 11.45512985522207, 11.691342951089922, 11.922877169542595, 12.150000000000002, 12.372954376380768, 12.591961721669902, 12.807224523681937, 13.01892852734049, 13.227244611029162, 13.432330400939371, 13.634331666788807, 13.833383534045458, 14.029611541307906, 14.223132566351198, 14.414055640242271, 14.602482665629159, 14.788509052639487, 14.972224283652714, 15.153712416434464, 15.333052533660737, 15.51031914565268, 15.685582552140037, 15.858909168035487, 16.03036181750119, 16.200000000000003, 16.367880131525894, 16.534055763786455, 16.698577783751528, 16.861494595675676, 17.022852287439967, 17.182694782833106, 17.341063981197927, 17.497999885701223, 17.65354072133973, 17.807723043668446, 17.960581839127595, 18.1121506177483, 18.262461498932723, 18.411545290930906, 18.559431564571153, 18.706148721743876, 18.85172405908807, 18.996183827284888, 19.139553286323064, 19.281856757065697, 19.423117669416516, 19.563358607355745, 19.702601351090674, 19.840866916543742, 19.978175592380804, 20.11454697476431, 20.250000000000004, 20.384552975231028, 20.518223607320397, 20.651029030050783, 20.78298582975988, 20.914110069520056, 21.044417311961862, 21.173922640833467, 21.302640681380325, 21.430585619623187, 21.557771220606273, 21.684210845682166, 21.809917468894742, 21.934903692517096, 22.05918176179706, 22.18276357895923, 22.305660716508715, 22.427884429878805, 22.54944566946159, 22.670355092058, 22.790623071781077, 22.91025971044414, 23.029274847463178, 23.147678069301033, 23.26547871847902, 23.382685902179844, 23.499308500464437], [0.0, 2.3811761799581315, 3.3674916480965473, 4.124318125460256, 4.762352359916263, 5.324471804789655, 5.8326666285670745, 6.3, 6.734983296193095, 7.143528539874394, 7.52994023880668, 7.897467948652911, 8.248636250920512, 8.58545281275251, 8.909545442950499, 9.222255689363639, 9.524704719832526, 9.817840903172144, 10.102474944289641, 10.379306335203717, 10.64894360957931, 10.911920087683928, 11.168706281391772, 11.419719786404569, 11.665333257134149, 11.905880899790658, 12.141663806908838, 12.37295437638077, 12.6, 12.823026163897508, 13.042239071570494, 13.257827876390612, 13.46996659238619, 13.678815738213599, 13.884523758487363, 14.087228258248675, 14.287057079748788, 14.484129245487974, 14.678555787270081, 14.870440477672478, 15.05988047761336, 15.246966911487675, 15.431785379534023, 15.614416415607723, 15.794935897305821, 15.973415414368962, 16.149922600433726, 16.32452143249535, 16.497272501841024, 16.668233259706923, 16.837458240482736, 17.004999264922066, 17.17090562550502, 17.3352242558324, 17.497999885701223, 17.659275183313728, 17.819090885900998, 17.977485919894363, 18.1344975116489, 18.290161289611415, 18.444511378727277, 18.59758048779464, 18.74939999039969, 18.9, 19.04940943966505, 19.197656106931387, 19.34476673418421, 19.49076704493694, 19.635681806344287, 19.77953487825232, 19.92234925906079, 20.06414712864716, 20.204949888579282, 20.344778199823168, 20.483652018133878, 20.62159062730128, 20.758612670407434, 20.89473617923902, 21.029978601986265, 21.164356829348723, 21.29788721915862, 21.430585619623184, 21.562467391279693, 21.69354742774911, 21.823840175367856, 21.953359651770842, 22.082119463493534, 22.21013282265552, 22.337412562783545, 22.463971153827632, 22.58982071642004, 22.71497303542313, 22.839439572809138, 22.963231479911535, 23.08635960908519, 23.208834524809728, 23.330666514268298, 23.45186559743169, 23.572441536675832, 23.692403845958733, 23.811761799581316, 23.930524440554997], [0.0, 2.423324163210527, 3.4270978976387587, 4.197320573889967, 4.846648326421054, 5.418717560456534, 5.935907681222814, 6.411513081948754, 6.854195795277517, 7.26997248963158, 7.663223864666881, 8.03725699477129, 8.394641147779934, 8.73741952752642, 9.067248755824448, 9.385494126576395, 9.693296652842108, 9.991621490028534, 10.281293692916277, 10.563025134874954, 10.837435120913067, 11.10506641132776, 11.366397846283581, 11.621854413130464, 11.871815362445629, 12.116620816052635, 12.356577195971385, 12.591961721669902, 12.823026163897508, 13.05, 13.273093083377363, 13.492497915508455, 13.708391590555035, 13.92093746843222, 14.130286621296825, 14.336579089866593, 14.53994497926316, 14.74050541874328, 14.938373405428049, 15.133654548720216, 15.326447729333761, 15.516845684610002, 15.704935529953634, 15.890799224708616, 16.07451398954258, 16.2561526813696, 16.435784130974707, 16.61347344777726, 16.789282295559868, 16.96326914247369, 17.135489488193794, 17.305996070726472, 17.47483905505284, 17.642066205521395, 17.807723043668442, 17.971852992944275, 18.134497511648895, 18.29569621523051, 18.455486988968893, 18.61390609195179, 18.77098825315279, 18.92676676033178, 19.081273542402773, 19.23453924584626, 19.386593305684215, 19.53746401148317, 19.687178568804622, 19.83576315648077, 19.983242980057067, 20.129642321710538, 20.27498458692386, 20.419292348169172, 20.562587385832554, 20.704890726589216, 20.846222679420848, 20.986602869449836, 21.126050269749907, 21.26458323127919, 21.40221951106941, 21.538976298793777, 21.674870241826135, 21.809917468894742, 21.944133612425897, 22.077533829664944, 22.21013282265552, 22.34194485715154, 22.472983780530793, 22.60326303877385, 22.732795692567162, 22.86159443258497, 22.989671594000644, 23.11703917027438, 23.243708826260928, 23.369691910677815, 23.494999467971905, 23.619642249619275, 23.743630724891258, 23.866975091117016, 23.989685283471314, 24.111770984313868, 24.23324163210527, 24.35410642992266], [0.0, 2.4647515087732477, 3.485685011586675, 4.2690748412273125, 4.929503017546495, 5.511351921262151, 6.037383539249432, 6.521119535785247, 6.97137002317335, 7.394254526319742, 7.794228634059947, 8.174655956063228, 8.538149682454625, 8.886787946159174, 9.222255689363639, 9.54594154601839, 9.85900603509299, 10.162430811572593, 10.457055034760025, 10.74360274768199, 11.022703842524303, 11.29491035821002, 11.560709320798617, 11.820532982907327, 12.074767078498864, 12.323757543866236, 12.567816039392048, 12.807224523681937, 13.042239071570494, 13.273093083377363, 13.499999999999998, 13.723155613779214, 13.9427400463467, 14.158919450297047, 14.371847480404181, 14.581666571417685, 14.788509052639483, 14.992498124061914, 15.193748714520718, 15.392368238838364, 15.588457268119894, 15.782110125075164, 15.973415414368963, 16.16245649646117, 16.349311912126456, 16.534055763786448, 16.716758058906038, 16.897485019966727, 17.07629936490925, 17.253260561412734, 17.428425057933374, 17.60184649404715, 17.77357589231835, 17.943661833639197, 18.1121506177483, 18.27908641043091, 18.444511378727277, 18.6084658153218, 18.77098825315279, 18.932115571166364, 19.09188309203678, 19.250324672586693, 19.40747278756304, 19.56335860735574, 19.71801207018598, 19.871461949237652, 20.023735915158287, 20.174860594313902, 20.324861623145186, 20.473763698939184, 20.62159062730128, 20.768365366585787, 20.91411006952005, 21.058846122235664, 21.202594180901542, 21.345374206136558, 21.48720549536398, 21.628106713256248, 21.768095920406086, 21.90719060034855, 22.045407685048605, 22.18276357895923, 22.31927418174704, 22.454954909774365, 22.58982071642004, 22.723886111314673, 22.85716517856053, 22.98967159400064, 23.121418641597234, 23.252419228974862, 23.38268590217984, 23.512230859703635, 23.641065965814654, 23.76920276323966, 23.896652485233155, 24.023426067070446, 24.149534156997728, 24.27498712667012, 24.399795081106724, 24.523967868189683, 24.647515087732472, 24.770446100141193], [0.0, 2.50549396327351, 3.543303543305315, 4.33964284244683, 5.01098792654702, 5.60245481909493, 6.137181763643635, 6.628913938195306, 7.08660708661063, 7.516481889820529, 7.923067587746554, 8.309783390678726, 8.67928568489366, 9.033686954948129, 9.374699995199846, 9.70373639378152, 10.02197585309404, 10.330416254924096, 10.629910629915944, 10.921194989560437, 11.20490963818986, 11.481615739955767, 11.751808371480537, 12.015926930536821, 12.27436352728727, 12.52746981636755, 12.775562609920552, 13.01892852734049, 13.257827876390612, 13.492497915508455, 13.723155613779214, 13.950000000000001, 14.17321417322126, 14.39296703254753, 14.609414772673135, 14.822702182800544, 15.032963779641058, 15.24032479968849, 15.444902071557463, 15.646804785642342, 15.846135175493108, 16.042989122978298, 16.237456697401843, 16.429622637175815, 16.619566781357452, 16.807364457284788, 16.993086829649286, 17.176801215593084, 17.35857136978732, 17.53845774291457, 17.716517716526575, 17.89280581686394, 18.067373909896258, 18.24027137956012, 18.411545290930906, 18.58124053985632, 18.74939999039969, 18.91606460128533, 19.081273542402773, 19.245064302308784, 19.40747278756304, 19.56853341464301, 19.728279195104676, 19.886741814585918, 20.04395170618808, 20.199938118717096, 20.354729180217554, 20.508351957190513, 20.66083250984819, 20.81219594372492, 20.962466457933807, 21.11166739033182, 21.259821259831888, 21.406949806079336, 21.553074026690485, 21.69821421223415, 21.842389979120874, 21.985620300550995, 22.127923535659647, 22.26931745698552, 22.40981927637972, 22.54944566946159, 22.688212798719956, 22.826136335350316, 22.963231479911535, 23.099512981879077, 23.234995158166054, 23.369691910677812, 23.503616742961075, 23.636782776004015, 23.76920276323966, 23.900889104801102, 24.031853861073643, 24.162108765585838, 24.291665237278405, 24.420534392187243, 24.54872705457454, 24.676253767539354, 24.803124803137205, 24.929350172036177, 25.0549396327351, 25.179902700368007], [0.0, 2.545584412271571, 3.5999999999999996, 4.409081537009721, 5.091168824543142, 5.692099788303083, 6.235382907247958, 6.734983296193095, 7.199999999999999, 7.636753236814712, 8.049844718999243, 8.442748367682174, 8.818163074019441, 9.178235124467012, 9.524704719832526, 9.859006035092989, 10.182337649086284, 10.49571341072154, 10.799999999999999, 11.095945205344158, 11.384199576606166, 11.665333257134149, 11.93984924527944, 12.208193969625484, 12.470765814495916, 12.727922061357855, 12.979984591670362, 13.227244611029162, 13.46996659238619, 13.708391590555035, 13.9427400463467, 14.17321417322126, 14.399999999999999, 14.62326912834473, 14.84318025222358, 15.059880477613358, 15.273506473629425, 15.484185480676729, 15.692036196746423, 15.897169559390127, 16.099689437998485, 16.29969324864735, 16.497272501841024, 16.692513291892265, 16.88549673536435, 17.076299364909246, 17.26499348392579, 17.451647486698786, 17.636326148038883, 17.819090885900998, 18.0, 18.17910888905174, 18.356470248934023, 18.5321342537766, 18.706148721743876, 18.878559267062727, 19.04940943966505, 19.21874085365636, 19.386593305684215, 19.553004884160384, 19.718012070185978, 19.881649830937068, 20.04395170618808, 20.204949888579282, 20.364675298172568, 20.523157651784484, 20.6804255275369, 20.836506425022403, 20.99142682144308, 21.145212224047313, 21.297887219158618, 21.449475518063373, 21.599999999999998, 21.749482752470232, 21.89794510907359, 22.045407685048602, 22.191890410688316, 22.33741256278354, 22.481992794234237, 22.62564916195776, 22.768399153212332, 22.91025971044414, 23.051247254758255, 23.191377708105225, 23.330666514268298, 23.469128658729534, 23.606778687487203, 23.743630724891254, 23.87969849055888, 24.0149953154274, 24.149534156997728, 24.283327613817676, 24.416387939250967, 24.54872705457454, 24.68035656144376, 24.811287753762397, 24.941531628991832, 25.071098898931417, 25.2, 25.32824510304652, 25.45584412271571, 25.582806726393414], [0.0, 2.585053190942113, 3.6558172820861823, 4.477443466979791, 5.170106381884226, 5.7803546603993095, 6.332061275761631, 6.839407869106799, 7.311634564172365, 7.755159572826338, 8.174655956063228, 8.573651497465944, 8.954886933959582, 9.320541829743592, 9.672383367092106, 10.011867957579145, 10.340212763768452, 10.65844735409431, 10.967451846258546, 11.267985622994024, 11.560709320798619, 11.846201922979366, 12.124974226776734, 12.39747958256032, 12.664122551523262, 12.925265954710566, 13.18123666428913, 13.432330400939373, 13.678815738213599, 13.92093746843222, 14.158919450297047, 14.39296703254753, 14.62326912834473, 14.850000000000003, 15.073320801999806, 15.293380921169787, 15.510319145652677, 15.724264688690536, 15.935338088663197, 16.14365200318689, 16.349311912126456, 16.55241674197457, 16.75305942208766, 16.951327381653627, 17.147302994931888, 17.341063981197923, 17.53268376490034, 17.722231800763698, 17.909773867919164, 18.095372336594792, 18.279086410430914, 18.460972347089417, 18.641083659487183, 18.81947129969384, 18.99618382728489, 19.171267563726715, 19.344766734184212, 19.5167235979813, 19.687178568804626, 19.856170325619185, 20.02373591515829, 20.1899108467571, 20.354729180217557, 20.518223607320397, 20.680425527536904, 20.84136511843694, 21.001071401240463, 21.159572301915745, 21.31689470818862, 21.47306452279227, 21.62810671325625, 21.78204535850571, 21.934903692517093, 22.08670414525445, 22.23746838109051, 22.387217334898953, 22.535971245988048, 22.683749690031412, 22.830571609138484, 22.97645534019554, 23.121418641597238, 23.26547871847902, 23.408652246551917, 23.550955394633146, 23.692403845958733, 23.833012818357652, 23.972797083360966, 24.111770984313868, 24.24994845355347, 24.387343028710614, 24.523967868189686, 24.659835765876466, 24.79495916512064, 24.929350172036177, 25.06302056815978, 25.195981822504955, 25.328245103046523, 25.45982128766815, 25.59072097460328, 25.720954492397833, 25.850531909421132, 25.97946304294991], [0.0, 2.6239283526803856, 3.7107950630558943, 4.544777222262936, 5.247856705360771, 5.8672821646823845, 6.427285585688566, 6.942261879243681, 7.421590126111789, 7.871785058041155, 8.2975900115636, 8.702585822616173, 9.089554444525872, 9.460708218732888, 9.817840903172144, 10.162430811572593, 10.495713410721542, 10.818733752154177, 11.132385189167683, 11.437438524424952, 11.734564329364769, 12.02435029429865, 12.30731489805961, 12.583918308698607, 12.854571171377131, 13.119641763401926, 13.379461872586656, 13.634331666788807, 13.884523758487362, 14.130286621296824, 14.37184748040418, 14.609414772673134, 14.843180252223577, 15.073320801999804, 15.300000000000002, 15.523369479594306, 15.74357011608231, 15.96073306587138, 16.174980680050286, 16.386427310429816, 16.5951800231272, 16.801339232335025, 17.004999264922066, 17.20624886487464, 17.405171645232347, 17.601846494047148, 17.79634793995667, 17.98874648217602, 18.179108889051744, 18.367498468762697, 18.553975315279473, 18.738596532291314, 18.921416437465776, 19.102486749112014, 19.281856757065697, 19.45957347939569, 19.635681806344287, 19.810224632749627, 19.983242980057067, 20.15477610890282, 20.324861623145186, 20.493535566124258, 20.660832509848195, 20.826785637731042, 20.991426821443085, 21.154786692377684, 21.31689470818862, 21.4777792148071, 21.637467504308354, 21.7959858689622, 21.953359651770842, 22.109613293768845, 22.264770378335367, 22.418853672746074, 22.571885167172017, 22.723886111314677, 22.874877048849903, 23.02487784983886, 23.173907741250723, 23.321985335729888, 23.469128658729538, 23.61535517412347, 23.760681808399355, 23.905124973528167, 24.0487005885973, 24.191424100288103, 24.333310502272393, 24.474374353596865, 24.61462979611922, 24.75409057105512, 24.892770034690795, 25.030681173312086, 25.167836617397214, 25.30424865511719, 25.439929245184626, 25.574890029089076, 25.709142342754262, 25.842697227650216, 25.97556544139126, 26.10775746784852, 26.239283526803852, 26.370153583170502], [0.0, 2.662235902394827, 3.7649701194033396, 4.611127844681819, 5.324471804789654, 5.95294044989533, 6.521119535785248, 7.043614129124338, 7.529940238806679, 7.986707707184481, 8.418729120241368, 8.829637591656864, 9.222255689363639, 9.598828053465693, 9.961174629530396, 10.310795313650639, 10.648943609579309, 10.976679825885421, 11.29491035821002, 11.604417262404864, 11.90588089979066, 12.199897540553364, 12.486993232960447, 12.767634863199998, 13.042239071570496, 13.311179511974137, 13.57479281609852, 13.83338353404546, 14.087228258248675, 14.336579089866593, 14.581666571417683, 14.822702182800544, 15.059880477613358, 15.293380921169787, 15.523369479594308, 15.75, 15.973415414368962, 16.193748793901925, 16.41112427592942, 16.625657881720052, 16.837458240482736, 17.04662723238823, 17.253260561412734, 17.45744826714374, 17.659275183313728, 17.858821349685986, 18.05616238296499, 18.251369811605922, 18.444511378727277, 18.63565131676379, 18.8248505970167, 19.01216715684985, 19.197656106931387, 19.381369920622227, 19.56335860735574, 19.743669871632274, 19.92234925906079, 20.099440290714565, 20.27498458692386, 20.449021981503172, 20.621590627301277, 20.792727093866258, 20.962466457933807, 21.13084238737301, 21.297887219158618, 21.463632031881275, 21.628106713256248, 21.79134002304585, 21.953359651770842, 22.114192275550106, 22.273863607376246, 22.43239844510613, 22.58982071642004, 22.7461535209802, 22.901419169999052, 23.055639223409095, 23.208834524809728, 23.361025234351338, 23.51223085970364, 23.662470285242833, 23.81176179958132, 23.960123121553444, 24.107571424761975, 24.254123360781357, 24.399795081106728, 24.544602257930357, 24.688560103821363, 24.831683390378508, 24.973986465920895, 25.115483272276485, 25.256187360724105, 25.39611190714043, 25.535269726399996, 25.673673286072642, 25.811334719459975, 25.948265838009288, 26.08447814314099, 26.219982837522988, 26.35479083582338, 26.48891277497059, 26.622359023948274, 26.75513969315055], [0.0, 2.7, 3.818376618407356, 4.676537180435969, 5.4, 6.037383539249433, 6.613622305514581, 7.143528539874395, 7.636753236814712, 8.1, 8.538149682454623, 8.95488693395958, 9.353074360871938, 9.734988443752771, 10.102474944289641, 10.457055034760025, 10.8, 11.132385189167683, 11.455129855222069, 11.769027147559818, 12.074767078498866, 12.372954376380768, 12.66412255152326, 12.948745112944342, 13.227244611029162, 13.5, 13.76735268670052, 14.029611541307908, 14.28705707974879, 14.539944979263161, 14.788509052639483, 15.032963779641058, 15.273506473629425, 15.510319145652678, 15.743570116082312, 15.973415414368962, 16.2, 16.423458831805192, 16.643917808016237, 16.861494595675676, 17.076299364909246, 17.288435441068692, 17.497999885701223, 17.705084015615398, 17.90977386791916, 18.112150617748295, 18.31229095443822, 18.51026742108282, 18.706148721743876, 18.900000000000002, 19.091883092036785, 19.281856757065697, 19.469976887505542, 19.6562967010574, 19.840866916543742, 20.02373591515829, 20.204949888579282, 20.384552975231024, 20.562587385832554, 20.739093519245237, 20.91411006952005, 21.087674124947966, 21.259821259831888, 21.430585619623184, 21.6, 21.768095920406083, 21.93490369251709, 22.100452484055612, 22.264770378335367, 22.4278844298788, 22.58982071642004, 22.750604387576168, 22.910259710444137, 23.068810112357337, 23.226278221015093, 23.382685902179844, 23.538054295119636, 23.69240384595873, 23.84575433908519, 23.998124926752087, 24.14953415699773, 24.3, 24.449539872971027, 24.598170663689604, 24.745908752761537, 24.892770034690795, 25.0387699378384, 25.1839234433398, 25.32824510304652, 25.47174905655283, 25.614449047363873, 25.756358438257532, 25.897490225888685, 26.037857054680977, 26.177471230048177, 26.3163447309842, 26.454489222058324, 26.591916064849485, 26.728636328851497, 26.86466080187874, 27.0, 27.134664177026405], [0.0, 2.737243138634199, 3.871046370169182, 4.741044188783733, 5.474486277268398, 6.12066172893095, 6.704848991588103, 7.242064622743987, 7.742092740338364, 8.211729415902596, 8.655922827752105, 9.078408450824409, 9.482088377567466, 9.86927048975759, 10.241826009066939, 10.601297090450771, 10.948972554536796, 11.285942583586007, 11.613139110507547, 11.931366225206569, 12.2413234578619, 12.54362387828972, 12.838808355918397, 13.12735693123334, 13.409697983176207, 13.686215693170995, 13.957256177343742, 14.2231325663512, 14.484129245487974, 14.74050541874328, 14.992498124061912, 15.24032479968849, 15.484185480676729, 15.724264688690536, 15.960733065871382, 16.193748793901925, 16.423458831805192, 16.650000000000002, 16.87349993332741, 17.094077921900325, 17.31184565550421, 17.526907884735405, 17.739363009984324, 17.949303607661214, 18.156816901648817, 18.361985186792847, 18.564886210262642, 18.76559351579374, 18.964176755134933, 19.160701970439394, 19.35523185084591, 19.54782596607613, 19.73854097951518, 19.92743084293608, 20.114546974764313, 20.299938423551932, 20.483652018133878, 20.665732505769064, 20.846222679420848, 21.025163495202598, 21.202594180901542, 21.378552336395465, 21.553074026690485, 21.72619386823196, 21.897945109073593, 22.068359703430612, 22.237468381090505, 22.405300712108282, 22.571885167172013, 22.737249173987603, 22.901419169999052, 23.0644206517311, 23.226278221015093, 23.387015628335313, 23.546655813512032, 23.705220943918665, 23.862732450413137, 24.019211061148535, 24.174676833413933, 24.32914918364389, 24.4826469157238, 24.63518824770779, 24.786790837056742, 24.93747180449534, 25.08724775657944, 25.236134807057915, 25.38414859710682, 25.53130431450771, 25.677616711836794, 25.823100123726434, 25.967768483256318, 26.11163533752722, 26.25471386246668, 26.39701687691244, 26.53855685601612, 26.679345944006947, 26.819395966352413, 26.95871844135029, 27.097324591184275, 27.235225352473222, 27.37243138634199, 27.50895308804027], [0.0, 2.7739863013360395, 3.9230090491866063, 4.804685213414091, 5.547972602672079, 6.202821938440601, 6.794850991743675, 7.339277893635042, 7.846018098373213, 8.321958904008119, 8.772114910328067, 9.200271735117395, 9.609370426828182, 10.001749846901792, 10.379306335203717, 10.74360274768199, 11.095945205344158, 11.437438524424952, 11.769027147559818, 12.091525958289964, 12.405643876881202, 12.712002202642983, 13.011149065320867, 13.303570949185035, 13.58970198348735, 13.869931506680198, 14.144610280951541, 14.414055640242273, 14.678555787270083, 14.93837340542805, 15.19374871452072, 15.444902071557463, 15.692036196746425, 15.935338088663197, 16.17498068005029, 16.411124275929424, 16.643917808016237, 16.87349993332741, 17.1, 17.323538899428147, 17.544229820656135, 17.7621789203915, 17.977485919894363, 18.19024463826696, 18.40054347023479, 18.6084658153218, 18.814090464330185, 19.017491948203897, 19.218740853656364, 19.41790410935228, 19.615045245933032, 19.810224632749627, 20.003499693803583, 20.19492510508519, 20.384552975231028, 20.57243301119243, 20.758612670407434, 20.943137300796174, 21.126050269749907, 21.307393083153084, 21.48720549536398, 21.6655256109793, 21.842389979120874, 22.017833680905124, 22.191890410688316, 22.364592551620518, 22.535971245988044, 22.706056460777155, 22.874877048849903, 23.042460806085796, 23.20883452480973, 23.374024043796997, 23.538054295119636, 23.700949348074648, 23.862732450413134, 24.023426067070453, 24.183051916579927, 24.34163100533734, 24.499183659869164, 24.655729557244904, 24.811287753762404, 24.965876712024357, 25.119514326515155, 25.27221794777815, 25.424004405285967, 25.57489002908908, 25.724890670321614, 25.874021720637092, 26.022298130641733, 26.16973442738768, 26.316344730984206, 26.462142770380485, 26.60714189837007, 26.751355105863333, 26.894795035471084, 27.037473994439644, 27.1794039669747, 27.320596625988976, 27.461063344306247, 27.60081520535218, 27.739863013360395, 27.878217303120373], [0.0, 2.8102490992792797, 3.9742923898475313, 4.867494221876386, 5.620498198558559, 6.283908019696025, 6.883676343350261, 7.435220238836239, 7.948584779695063, 8.430747297837838, 8.886787946159176, 9.320541829743593, 9.734988443752773, 10.132497224277934, 10.51498930099313, 10.884047960203043, 11.240996397117119, 11.58695387062536, 11.922877169542593, 12.24959182993458, 12.56781603939205, 12.878179219128768, 13.18123666428913, 13.477481218684746, 13.767352686700521, 14.051245496396398, 14.329514995281594, 14.602482665629159, 14.870440477672478, 15.133654548720214, 15.392368238838364, 15.64680478564234, 15.897169559390125, 16.14365200318689, 16.386427310429816, 16.625657881720052, 16.861494595675676, 17.094077921900322, 17.323538899428144, 17.550000000000004, 17.773575892318352, 17.994374120818986, 18.212495710363257, 18.428035706498942, 18.641083659487187, 18.85172405908807, 19.060036726092633, 19.266097165746885, 19.469976887505545, 19.67174369495496, 19.87146194923766, 20.069192808879986, 20.264994448555868, 20.458922259004755, 20.651029030050783, 20.841365118436944, 21.02997860198626, 21.216915421427313, 21.40221951106941, 21.58593291938062, 21.768095920406086, 21.948747116862958, 22.127923535659647, 22.305660716508715, 22.481992794234237, 22.65695257531339, 22.83057160913848, 23.002880254437706, 23.17390774125072, 23.343682228817286, 23.51223085970364, 23.679579810461167, 23.845754339085186, 24.010778829517385, 24.17467683341393, 24.33747110938193, 24.49918365986916, 24.659835765876466, 24.819448019647826, 24.978040355480253, 25.1356320787841, 25.292241893513516, 25.447887928077648, 25.602587759833966, 25.756358438257536, 25.90921650687261, 26.061178024026468, 26.21225858257926, 26.36247332857826, 26.511836978979787, 26.660363838477526, 26.80806781549167, 26.954962437369492, 27.101060864844392, 27.246375905797088, 27.390920028359762, 27.534705373401042, 27.67774376642721, 27.82004672893272, 27.961625489230777, 28.102490992792795, 28.242653912123775], [0.0, 2.8460498941515415, 4.024922359499621, 4.929503017546495, 5.692099788303083, 6.3639610306789285, 6.971370023173351, 7.52994023880668, 8.049844718999243, 8.538149682454623, 9.0, 9.439279633531365, 9.85900603509299, 10.261578825892242, 10.648943609579309, 11.022703842524301, 11.384199576606166, 11.734564329364767, 12.074767078498864, 12.4056438768812, 12.727922061357857, 13.042239071570496, 13.349157276772194, 13.649175799292792, 13.942740046346701, 14.230249470757707, 14.51206394693739, 14.788509052639487, 15.05988047761336, 15.326447729333761, 15.588457268119894, 15.846135175493108, 16.099689437998485, 16.349311912126456, 16.5951800231272, 16.837458240482736, 17.076299364909246, 17.31184565550421, 17.544229820656135, 17.773575892318352, 18.0, 18.22361105818493, 18.444511378727277, 18.662797217994946, 18.87855926706273, 19.09188309203678, 19.302849530574495, 19.51153504981092, 19.71801207018598, 19.92234925906079, 20.12461179749811, 20.32486162314519, 20.523157651784484, 20.71955597979841, 20.914110069520053, 21.106870919205434, 21.297887219158618, 21.48720549536398, 21.674870241826135, 21.86092404268401, 22.045407685048602, 22.228360263411243, 22.409819276379718, 22.58982071642004, 22.768399153212332, 22.94558781116753, 23.12141864159723, 23.29592238998061, 23.469128658729534, 23.641065965814654, 23.811761799581316, 23.98124267005361, 24.149534156997728, 24.316660954991335, 24.482646915723798, 24.647515087732476, 24.8112877537624, 24.973986465920895, 25.1356320787841, 25.296244780599352, 25.455844122715714, 25.614449047363873, 25.772077913897437, 25.92874852359828, 26.08447814314099, 26.239283526803852, 26.393180937507324, 26.546186166754726, 26.69831455354439, 26.849581002317336, 27.0, 27.14958563219704, 27.298351598585583, 27.446311227558432, 27.593477490160605, 27.73986301336039, 27.885480092693403, 28.03034070431539, 28.17445651649735, 28.317838900594094, 28.460498941515414, 28.60244744772727], [0.0, 2.8814059068447824, 4.074923312161838, 4.990741427884238, 5.762811813689565, 6.44301947847436, 7.057974213611156, 7.6234834557438385, 8.149846624323676, 8.644217720534346, 9.111805529092464, 9.556542261717887, 9.981482855768476, 10.389056742553677, 10.781233695639846, 11.15963709087352, 11.52562362737913, 11.880340904199677, 12.224769936485513, 12.559757163257578, 12.88603895694872, 13.20426067600909, 13.514991675913087, 13.81873727950568, 14.115948427222312, 14.407029534223911, 14.69234494558306, 14.972224283652716, 15.246966911487677, 15.516845684610002, 15.782110125075164, 16.0429891229783, 16.29969324864735, 16.55241674197457, 16.801339232335025, 17.046627232388232, 17.288435441068692, 17.526907884735405, 17.7621789203915, 17.99437412081899, 18.22361105818493, 18.450000000000003, 18.673644529121788, 18.894642097695314, 19.113084523435774, 19.329058435423075, 19.542645675547618, 19.753923660883174, 19.962965711536953, 20.169841347913476, 20.37461656080919, 20.577354057312622, 20.778113485107355, 20.976951637452, 21.173922640833467, 21.36907812705078, 21.562467391279693, 21.754137537489278, 21.9441336124259, 22.132498729244286, 22.31927418174704, 22.504499550089978, 22.688212798719956, 22.870450367231513, 23.05124725475826, 23.230637098452554, 23.408652246551917, 23.585323826481588, 23.760681808399355, 23.93475506454996, 24.107571424761975, 24.279157728389183, 24.449539872971027, 24.61874285986188, 24.786790837056742, 24.95370713942119, 25.119514326515155, 25.284234218184267, 25.44788792807765, 25.610495895237953, 25.77207791389744, 25.93265316160304, 26.09224022578361, 26.250857128863434, 26.40852135201818, 26.565249857661797, 26.721059110746342, 26.875965098950402, 27.029983351826175, 27.183128958970123, 27.335416587277393, 27.486860497335815, 27.63747455901136, 27.78727226627328, 27.936266751303766, 28.084470797933864, 28.231896854444624, 28.378557045769615, 28.524463185132866, 28.66962678515366, 28.814059068447822, 28.95777097775311], [0.0, 2.9163333142835377, 4.124318125460256, 5.051237472144821, 5.832666628567075, 6.521119535785249, 7.143528539874396, 7.715892689767012, 8.248636250920512, 8.748999942850611, 9.222255689363639, 9.672383367092106, 10.102474944289643, 10.51498930099313, 10.911920087683928, 11.29491035821002, 11.66533325713415, 12.02435029429865, 12.372954376380768, 12.712002202642983, 13.042239071570497, 13.36431816442575, 13.678815738213599, 13.986243241128049, 14.287057079748791, 14.581666571417687, 14.870440477672478, 15.153712416434466, 15.431785379534023, 15.704935529953636, 15.973415414368963, 16.237456697401846, 16.497272501841024, 16.75305942208766, 17.00499926492207, 17.253260561412734, 17.497999885701223, 17.739363009984324, 17.977485919894363, 18.21249571036326, 18.444511378727277, 18.673644529121788, 18.900000000000002, 19.1236764247882, 19.344766734184212, 19.56335860735574, 19.77953487825232, 19.993373902370756, 20.204949888579286, 20.414333199984764, 20.621590627301284, 20.826785637731046, 21.02997860198626, 21.231227001753812, 21.430585619623187, 21.62810671325625, 21.823840175367856, 22.017833680905124, 22.210132822655524, 22.400781236376556, 22.58982071642004, 22.777291322718774, 22.963231479911535, 23.147678069301033, 23.3306665142683, 23.51223085970364, 23.69240384595873, 23.87121697777472, 24.0487005885973, 24.22488390065059, 24.399795081106728, 24.573461294656887, 24.745908752761537, 24.917162759832834, 25.08724775657944, 25.25618736072411, 25.424004405285967, 25.59072097460328, 25.75635843825754, 25.920937483046405, 26.084478143140995, 26.246999828551836, 26.40852135201818, 26.56906095442592, 26.7286363288515, 26.887264643321384, 27.0449625623701, 27.201746267473347, 27.357631476427198, 27.512633461738993, 27.66676706809092, 27.82004672893272, 27.972486482256098, 28.124099985599543, 28.274900530329017, 28.424901055236763, 28.574114159497583, 28.72255211501931, 28.870226878221796, 29.017150101276318, 29.163333142835373, 29.30878707828081], [0.0, 2.9508473359359, 4.173128322973066, 5.111017511220246, 5.9016946718718, 6.598295234376831, 7.2280702818940545, 7.807208207803862, 8.346256645946132, 8.852542007807699, 9.331398608997473, 9.786853426919196, 10.222035022440492, 10.6394313757832, 11.041059731746767, 11.428582589280262, 11.8033893437436, 12.166655251136195, 12.519384968919198, 12.862445335160807, 13.196590468753662, 13.522481281185048, 13.840700849306728, 14.15176667416475, 14.456140563788109, 14.7542366796795, 15.046428147570438, 15.333052533660739, 15.614416415607725, 15.890799224708617, 16.16245649646117, 16.429622637175815, 16.692513291892265, 16.951327381653627, 17.206248864874645, 17.45744826714374, 17.705084015615398, 17.949303607661218, 18.19024463826696, 18.428035706498946, 18.662797217994946, 18.894642097695314, 19.1236764247882, 19.349999999999994, 19.57370685383839, 19.79488570313049, 20.013620362143374, 20.229990113690118, 20.444070044880984, 20.655931351551303, 20.865641614865332, 21.073265053142574, 21.2788627515664, 21.48249287210402, 21.684210845682163, 21.88406954841809, 22.082119463493534, 22.27840883007581, 22.472983780530793, 22.665888467033447, 22.857165178560525, 23.046854449143378, 23.234995158166054, 23.421624623411585, 23.6067786874872, 23.790491798195344, 23.972797083360962, 24.153726420575353, 24.33331050227239, 24.511578896513374, 24.688560103821363, 24.86428161037435, 25.038769937838396, 25.21205069009659, 25.384148597106815, 25.55508755610123, 25.724890670321614, 25.893580285468442, 26.061178024026468, 26.227704817616043, 26.393180937507324, 26.5576260234231, 26.72105911074634, 26.88349865623892, 27.044962562370095, 27.20546820034531, 27.36503243191939, 27.523671630071448, 27.681401698613456, 27.838238090798775, 27.99419582699242, 28.14928951146014, 28.3035333483295, 28.456941156772277, 28.609526385454195, 28.761302126294623, 28.912281127576218, 29.062475806441544, 29.211898260811466, 29.360560280757586, 29.508473359359, 29.65564870307173], [0.0, 2.9849623113198605, 4.221374183841087, 5.170106381884226, 5.969924622639721, 6.674578638386098, 7.3116345641723655, 7.897467948652911, 8.442748367682174, 8.95488693395958, 9.439279633531365, 9.900000000000002, 10.340212763768452, 10.76243466879126, 11.168706281391772, 11.560709320798617, 11.939849245279442, 12.307314898059609, 12.66412255152326, 13.011149065320867, 13.349157276772196, 13.678815738213599, 14.000714267493644, 14.315376348528181, 14.623269128344731, 14.9248115565993, 15.220381072758988, 15.51031914565268, 15.794935897305821, 16.074513989542577, 16.349311912126456, 16.61956678135745, 16.88549673536435, 17.147302994931888, 17.405171645232347, 17.659275183313728, 17.90977386791916, 18.156816901648813, 18.400543470234787, 18.641083659487187, 18.87855926706273, 19.113084523435774, 19.344766734184212, 19.573706853838388, 19.800000000000004, 20.02373591515829, 20.244999382563588, 20.463870601623732, 20.680425527536904, 20.894736179239022, 21.106870919205434, 21.316894708188624, 21.52486933758252, 21.73085364176935, 21.934903692517096, 22.13707297724792, 22.337412562783545, 22.535971245988048, 22.732795692567166, 22.927930565142592, 23.121418641597234, 23.313300924579515, 23.50361674296107, 23.69240384595873, 23.879698490558884, 24.06553552281769, 24.249948453553465, 24.43296952889681, 24.614629796119218, 24.79495916512064, 24.9739864659209, 25.15173950246782, 25.32824510304652, 25.50352916754856, 25.67761671183679, 25.850531909421132, 26.022298130641733, 26.19293797953945, 26.362473328578265, 26.530925351370616, 26.698314553544392, 26.864660801878742, 27.029983351826175, 27.194300873528633, 27.357631476427198, 27.51999273255718, 27.68140169861346, 27.841874936864436, 28.001428534987287, 28.16007812489163, 28.317838900594094, 28.474725635201477, 28.630752697056362, 28.78593406509506, 28.94028334346435, 29.093813775440303, 29.246538256689462, 29.39846934790994, 29.54961928688761, 29.700000000000003, 29.8496231131986, 29.99849996249813], [0.0, 3.018691769624716, 4.269074841227312, 5.228527517380012, 6.037383539249432, 6.75, 7.394254526319743, 7.986707707184481, 8.538149682454623, 9.056075308874146, 9.54594154601839, 10.011867957579145, 10.457055034760025, 10.884047960203041, 11.29491035821002, 11.69134295108992, 12.074767078498864, 12.446385017345396, 12.807224523681935, 13.158172365492101, 13.5, 13.833383534045458, 14.158919450297045, 14.47713714793087, 14.788509052639485, 15.093458848123579, 15.392368238838362, 15.685582552140039, 15.973415414368962, 16.2561526813696, 16.534055763786448, 16.807364457284788, 17.076299364909246, 17.341063981197923, 17.60184649404715, 17.858821349685986, 18.11215061774829, 18.361985186792847, 18.608465815321797, 18.85172405908807, 19.09188309203678, 19.329058435423075, 19.56335860735574, 19.79488570313049, 20.02373591515829, 20.249999999999996, 20.473763698939184, 20.695108117620453, 20.91411006952005, 21.13084238737301, 21.345374206136558, 21.55777122060627, 21.768095920406083, 21.976407804734603, 22.18276357895923, 22.38721733489895, 22.58982071642004, 22.790623071781077, 22.989671594000644, 23.187011450378847, 23.38268590217984, 23.57673641537352, 23.76920276323966, 23.960123121553444, 24.149534156997728, 24.337471109381926, 24.52396786818968, 24.70905704392622, 24.89277003469079, 25.075137088359057, 25.256187360724102, 25.43594896991264, 25.61444904736387, 25.79171378563278, 25.967768483256314, 26.14263758690006, 26.316344730984202, 26.488912774970586, 26.660363838477526, 26.830719334374916, 27.0, 27.168225926622444, 27.33541658727739, 27.50159086307554, 27.666767068090916, 27.830962972919206, 27.99419582699242, 28.15648237972918, 28.31783890059409, 28.47828119813413, 28.63782463805517, 28.79648416039708, 28.95427429586174, 29.111209181344563, 29.26730257471638, 29.42256786889954, 29.57701810527897, 29.730665986486073, 29.88352388859118, 30.035603872737433, 30.186917696247157, 30.337476823229714], [0.0, 3.052048492406371, 4.316248370981447, 5.286303056011829, 6.104096984812742, 6.824587899646397, 7.475961476626268, 8.074961300216863, 8.632496741962894, 9.15614547721911, 9.651424765287247, 10.122499691281796, 10.572606112023658, 11.004317334573736, 11.419719786404569, 11.820532982907327, 12.208193969625484, 12.583918308698607, 12.948745112944342, 13.303570949185035, 13.649175799292793, 13.986243241128049, 14.315376348528181, 14.637110370561535, 14.951922953252536, 15.260242462031854, 15.562454819211526, 15.858909168035488, 16.149922600433726, 16.435784130974707, 16.716758058906038, 16.993086829649286, 17.26499348392579, 17.532683764900344, 17.79634793995667, 18.05616238296499, 18.31229095443822, 18.564886210262642, 18.814090464330185, 19.060036726092637, 19.302849530574495, 19.542645675547618, 19.77953487825232, 20.013620362143374, 20.24499938256359, 20.473763698939184, 20.7, 20.923790287612807, 21.145212224047317, 21.364339446844596, 21.58124185490724, 21.795985868962205, 22.008634669147472, 22.219248412131318, 22.427884429878805, 22.634597411926727, 22.839439572809138, 23.042460806085796, 23.243708826260928, 23.44322929973599, 23.641065965814654, 23.83726074866825, 24.03185386107364, 24.22488390065059, 24.416387939250967, 24.60640160608617, 24.794959165120638, 24.98209358720762, 25.167836617397214, 25.352218837805893, 25.535269726399996, 25.717017712013188, 25.897490225888685, 26.076713750010757, 26.25471386246668, 26.431515280059145, 26.60714189837007, 26.78161682945972, 26.954962437369492, 27.127200371582763, 27.298351598585587, 27.468436431657338, 27.63747455901136, 27.805485070395733, 27.972486482256098, 28.13849676155427, 28.3035333483295, 28.46761317708248, 28.630752697056362, 28.792967891483507, 28.954274295861744, 29.114687015319262, 29.27422074112307, 29.4328897663821, 29.590708000992475, 29.747688985869136, 29.903845906505072, 30.059191605896526, 30.213738596870133, 30.367499073845384, 30.52048492406371, 30.672707738313555], [0.0, 3.08504457018047, 4.362911871674696, 5.3434539391670635, 6.17008914036094, 6.898369372540152, 7.556785030686, 8.162260716247674, 8.725823743349393, 9.255133710541408, 9.75576752490546, 10.231935300811866, 10.686907878334127, 11.123286384877447, 11.543179804542595, 11.948326242616577, 12.34017828072188, 12.719964622592313, 13.088735615024088, 13.447397517735542, 13.796738745080305, 14.137450265164508, 14.470141671732176, 14.795354000496237, 15.113570061372, 15.42522285090235, 15.730702463653682, 16.03036181750119, 16.32452143249535, 16.61347344777726, 16.897485019966727, 17.176801215593084, 17.451647486698786, 17.722231800763698, 17.98874648217602, 18.251369811605922, 18.510267421082816, 18.76559351579374, 19.017491948203894, 19.266097165746885, 19.51153504981092, 19.75392366088317, 19.993373902370756, 20.229990113690118, 20.463870601623732, 20.695108117620453, 20.923790287612807, 21.150000000000002, 21.373815756668254, 21.59531199126329, 21.814559358373483, 22.031624996808567, 22.246572769754895, 22.459463484242008, 22.670355092058, 22.87930287399509, 23.08635960908519, 23.291575730293562, 23.494999467971905, 23.69667698222685, 23.896652485233155, 24.0949683544096, 24.2916652372784, 24.486782148743025, 24.68035656144376, 24.87242448978386, 25.063020568159775, 25.252178123876757, 25.439929245184626, 25.626304844826926, 25.81133471945998, 25.995047605265125, 26.177471230048177, 26.35863236209345, 26.538556856016115, 26.717269695835316, 26.894795035471084, 27.07115623685106, 27.24637590579709, 27.42047592584782, 27.59347749016061, 27.76540113162423, 27.936266751303762, 28.106093645328944, 28.274900530329017, 28.44270556750887, 28.6095263854542, 28.775380101746702, 28.94028334346435, 29.104252266636227, 29.26730257471638, 29.429449536136417, 29.590708000992475, 29.751092416918073, 29.91061684419096, 30.0692949701186, 30.227140122744, 30.384165283910633, 30.540383101722874, 30.6958059024356, 30.8504457018047, 31.004314215928083], [0.0, 3.1176914536239795, 4.409081537009721, 5.400000000000001, 6.235382907247959, 6.971370023173352, 7.636753236814714, 8.248636250920514, 8.818163074019441, 9.353074360871938, 9.85900603509299, 10.340212763768454, 10.800000000000002, 11.240996397117119, 11.66533325713415, 12.074767078498866, 12.470765814495918, 12.854571171377131, 13.227244611029162, 13.589701983487352, 13.942740046346705, 14.287057079748791, 14.623269128344733, 14.951922953252538, 15.273506473629428, 15.588457268119898, 15.897169559390127, 16.200000000000003, 16.497272501841028, 16.789282295559868, 17.07629936490925, 17.35857136978732, 17.636326148038883, 17.909773867919164, 18.179108889051744, 18.444511378727277, 18.706148721743876, 18.964176755134933, 19.218740853656364, 19.46997688750555, 19.71801207018598, 19.962965711536953, 20.204949888579286, 20.444070044880984, 20.680425527536908, 20.914110069520053, 21.145212224047317, 21.373815756668254, 21.600000000000005, 21.82384017536786, 22.045407685048605, 22.26477037833537, 22.481992794234237, 22.69713638325329, 22.910259710444144, 23.121418641597238, 23.3306665142683, 23.53805429511964, 23.74363072489126, 23.947442452170126, 24.14953415699773, 24.34994866524363, 24.54872705457454, 24.74590875276154, 24.941531628991836, 25.135632078784095, 25.32824510304652, 25.519404381764087, 25.709142342754262, 25.89749022588869, 26.084478143140995, 26.27013513478757, 26.454489222058324, 26.637567456507742, 26.819395966352413, 27.000000000000004, 27.179403966974704, 27.357631476427198, 27.534705373401046, 27.71064777301318, 27.88548009269341, 28.059223082615816, 28.231896854444624, 28.403520908507105, 28.574114159497583, 28.743694960808366, 28.91228112757622, 29.079889958526326, 29.246538256689465, 29.41224234906275, 29.577018105278974, 29.740880955344956, 29.903845906505076, 30.065927559282123, 30.227140122744, 30.38749742904144, 30.547012947258857, 30.705699796617573, 30.86357075906805, 31.02063829130536, 31.176914536239796, 31.332411333952585], [0.0, 3.1500000000000004, 4.4547727214752495, 5.455960043841964, 6.300000000000001, 7.043614129124339, 7.715892689767012, 8.33411662985346, 8.909545442950499, 9.45, 9.961174629530396, 10.447368089619511, 10.911920087683928, 11.357486517711566, 11.786220768337916, 12.199897540553362, 12.600000000000001, 12.98778272069563, 13.364318164425748, 13.730531672153122, 14.087228258248677, 14.435113439110896, 14.774809643443804, 15.106869298435067, 15.431785379534023, 15.75, 16.06191146781727, 16.367880131525894, 16.66823325970692, 16.96326914247369, 17.25326056141273, 17.53845774291457, 17.819090885900998, 18.095372336594792, 18.367498468762697, 18.63565131676379, 18.9, 19.160701970439394, 19.417904109352275, 19.67174369495496, 19.92234925906079, 20.169841347913476, 20.41433319998476, 20.6559313515513, 20.894736179239022, 21.13084238737301, 21.364339446844593, 21.59531199126329, 21.823840175367856, 22.05, 22.27386360737625, 22.49549954990998, 22.71497303542313, 22.932346151233634, 23.147678069301033, 23.361025234351338, 23.572441536675832, 23.781978471102864, 23.989685283471314, 24.19560910578611, 24.399795081106724, 24.60228647910596, 24.803124803137205, 25.00234988956038, 25.200000000000003, 25.39611190714043, 25.590720974603272, 25.783861231398216, 25.97556544139126, 26.165865168191935, 26.35479083582338, 26.54237178550553, 26.728636328851497, 26.913611797750224, 27.097324591184275, 27.279800219209818, 27.461063344306243, 27.641137820285184, 27.820046728932724, 27.997812414544104, 28.174456516497354, 28.35, 28.524463185132863, 28.697865774304542, 28.870226878221793, 29.041565040472594, 29.211898260811466, 29.38124401722977, 29.54961928688761, 29.7170405659783, 29.883523888591185, 30.04908484463379, 30.213738596870133, 30.37749989712781, 30.540383101722874, 30.702402186148234, 30.863570759068047, 31.023902075657734, 31.18340905032675, 31.34210426885853, 31.5, 31.657108206530808], [0.0, 3.1819805153394642, 4.5, 5.511351921262151, 6.3639610306789285, 7.1151247353788545, 7.794228634059948, 8.418729120241368, 9.0, 9.54594154601839, 10.062305898749054, 10.553435459602719, 11.022703842524303, 11.472793905583766, 11.905880899790658, 12.323757543866238, 12.727922061357857, 13.119641763401926, 13.5, 13.869931506680198, 14.230249470757709, 14.581666571417687, 14.924811556599302, 15.260242462031854, 15.588457268119896, 15.90990257669732, 16.224980739587952, 16.534055763786455, 16.837458240482736, 17.135489488193794, 17.428425057933374, 17.716517716526575, 18.0, 18.279086410430914, 18.553975315279477, 18.8248505970167, 19.09188309203678, 19.35523185084591, 19.615045245933032, 19.87146194923766, 20.12461179749811, 20.37461656080919, 20.62159062730128, 20.865641614865332, 21.106870919205438, 21.345374206136558, 21.58124185490724, 21.814559358373483, 22.045407685048605, 22.27386360737625, 22.500000000000004, 22.72388611131468, 22.94558781116753, 23.165167817220755, 23.382685902179848, 23.598199083828412, 23.811761799581316, 24.023426067070453, 24.233241632105273, 24.441256105200484, 24.647515087732476, 24.852062288671338, 25.0549396327351, 25.256187360724105, 25.455844122715714, 25.653947064730605, 25.85053190942113, 26.045633031278008, 26.239283526803852, 26.431515280059145, 26.622359023948274, 26.81184439757922, 27.0, 27.18685344058779, 27.37243138634199, 27.556759606310756, 27.739863013360395, 27.92176570347943, 28.1024909927928, 28.282061452447202, 28.460498941515418, 28.63782463805518, 28.814059068447822, 28.989222135131534, 29.163333142835373, 29.33641082341192, 29.508473359359005, 29.67953840611407, 29.849623113198604, 30.018744144284252, 30.186917696247164, 30.354159517272095, 30.52048492406371, 30.685908818218177, 30.850445701804702, 31.014109692202997, 31.176914536239792, 31.338873623664274, 31.500000000000004, 31.66030637880815, 31.81980515339464, 31.978508407991768], [0.0, 3.213642792844283, 4.544777222262935, 5.566192594583843, 6.427285585688566, 7.185923740202092, 7.871785058041157, 8.502499632461033, 9.08955444452587, 9.640928378532848, 10.162430811572595, 10.658447354094312, 11.132385189167685, 11.586953870625361, 12.02435029429865, 12.4463850173454, 12.854571171377131, 13.250188677901912, 13.634331666788807, 14.007944174646045, 14.371847480404185, 14.726761354758217, 15.073320801999806, 15.41208941058934, 15.743570116082314, 16.068213964221414, 16.386427310429816, 16.698577783751528, 17.004999264922066, 17.305996070726472, 17.60184649404715, 17.89280581686394, 18.17910888905174, 18.460972347089417, 18.738596532291318, 19.01216715684985, 19.281856757065697, 19.54782596607613, 19.810224632749627, 20.069192808879986, 20.32486162314519, 20.57735405731262, 20.826785637731046, 21.07326505314257, 21.316894708188624, 21.55777122060627, 21.795985868962205, 22.031624996808567, 22.26477037833537, 22.495499549909983, 22.72388611131468, 22.950000000000006, 23.173907741250723, 23.39567267680073, 23.615355174123472, 23.833012818357652, 24.0487005885973, 24.26247102007543, 24.474374353596872, 24.68445867342446, 24.8927700346908, 25.099352581291814, 25.30424865511719, 25.5074988973831, 25.709142342754262, 25.90921650687261, 26.10775746784852, 26.30479994221587, 26.500377355803824, 26.694521909935006, 26.887264643321384, 27.078635489994696, 27.268663333577614, 27.457376058174244, 27.64480059613381, 27.830962972919213, 28.01588834929209, 28.19960106100794, 28.38212465619867, 28.563481930605032, 28.74369496080837, 28.922785135598545, 29.10077318560454, 29.27767921130362, 29.453522709516434, 29.628322598486744, 29.80209724163721, 29.974864470085603, 30.146641603999612, 30.317445472862655, 30.487292434717784, 30.65619839445198, 30.82417882117868, 30.991248764772294, 31.157422871604773, 31.32271539953074, 31.487140232164627, 31.650710892490242, 31.81344055584055, 31.975342062282937, 32.13642792844283, 32.29671035879661], [0.0, 3.2449961479175906, 4.589117562233507, 5.620498198558559, 6.489992295835181, 7.256031973468696, 7.948584779695063, 8.58545281275251, 9.178235124467014, 9.734988443752771, 10.261578825892242, 10.76243466879126, 11.240996397117119, 11.700000000000001, 12.141663806908838, 12.567816039392048, 12.979984591670362, 13.379461872586655, 13.76735268670052, 14.144610280951541, 14.512063946937392, 14.870440477672478, 15.22038107275899, 15.562454819211526, 15.897169559390125, 16.224980739587952, 16.546298679765215, 16.86149459567568, 17.17090562550502, 17.47483905505284, 17.77357589231835, 18.067373909896258, 18.356470248934027, 18.641083659487183, 18.921416437465776, 19.197656106931387, 19.469976887505542, 19.73854097951518, 20.003499693803583, 20.264994448555868, 20.523157651784484, 20.778113485107355, 21.02997860198626, 21.278862751566397, 21.52486933758252, 21.768095920406083, 22.008634669147472, 22.2465727697549, 22.481992794234237, 22.714973035423135, 22.945587811167535, 23.173907741250723, 23.400000000000002, 23.623928547132042, 23.84575433908519, 24.06553552281769, 24.283327613817676, 24.49918365986916, 24.71315439194277, 24.92528836342721, 25.135632078784095, 25.344230112591703, 25.551125219841104, 25.756358438257532, 25.959969183340725, 26.16199533674754, 26.362473328578258, 26.56143821407267, 26.75892374517331, 26.95496243736949, 27.14958563219704, 27.342823555733965, 27.53470537340104, 27.72525924134886, 27.91451235468748, 28.102490992792795, 28.289220561903083, 28.474725635201477, 28.65902999056319, 28.84215664613172, 29.024127893874784, 29.204965331258315, 29.38468989116612, 29.563321870182317, 29.740880955344956, 29.917386249470393, 30.09285629514088, 30.267309097440428, 30.44076214551798, 30.61323243305091, 30.784736477676727, 30.95529033945571, 31.124909638423052, 31.29360957128468, 31.461404927307367, 31.62831010345004, 31.79433911878025, 31.959505628216473, 32.12382293563455, 32.28730400637378, 32.449961479175904, 32.611807677588196], [0.0, 3.2760494501762336, 4.63303356344415, 5.674284095813322, 6.552098900352467, 7.32546926824487, 8.024649525057155, 8.6676121279162, 9.2660671268883, 9.8281483505287, 10.359777989899206, 10.865426820884675, 11.348568191626644, 11.81196427356602, 12.257854624688614, 12.688084961884517, 13.104197800704934, 13.507497917823272, 13.899100690332451, 14.27996848736019, 14.65093853648974, 15.012744585851053, 15.36603397106749, 15.711381225086484, 16.04929905011431, 16.38024725088117, 16.70464007394353, 17.022852287439967, 17.3352242558324, 17.642066205521395, 17.943661833639197, 18.24027137956012, 18.5321342537766, 18.819471299693838, 19.102486749112018, 19.381369920622227, 19.6562967010574, 19.92743084293608, 20.19492510508519, 20.458922259004755, 20.71955597979841, 20.976951637452, 21.231227001753812, 21.482492872104018, 21.73085364176935, 21.976407804734603, 22.219248412131318, 22.459463484242008, 22.697136383253287, 22.932346151233638, 23.165167817220755, 23.39567267680073, 23.62392854713204, 23.850000000000005, 24.073948575171464, 24.295832976047564, 24.515709249377228, 24.733630950590335, 24.949649296132407, 25.163813304028466, 25.376169923769034, 25.5867641564931, 25.795639166339726, 26.0028363837486, 26.20839560140987, 26.41235506349254, 26.614751548718242, 26.815620447791247, 27.014995835646545, 27.21291053893354, 27.409396199113914, 27.604483331517006, 27.798201380664903, 27.99057877215118, 28.18164296133212, 28.37142047906661, 28.55993697472038, 28.74721725663199, 28.933285330221324, 29.118164433906202, 29.30187707297948, 29.484445051586103, 29.665889502929122, 29.846230917822776, 30.025489171702105, 30.203683550189705, 30.38083277331285, 30.55695501845693, 30.73206794213498, 30.906188700647, 31.079333969697615, 31.251519963035403, 31.422762450172968, 31.593076773242586, 31.762477863038335, 31.930980254292226, 32.09859810022862, 32.26534518643804, 32.43123494410906, 32.59628046265402, 32.76049450176234, 32.92388950291263], [0.0, 3.3068111527572905, 4.676537180435969, 5.727564927611035, 6.613622305514581, 7.3942545263197434, 8.100000000000001, 8.748999942850611, 9.353074360871938, 9.920433458271871, 10.457055034760026, 10.967451846258548, 11.45512985522207, 11.922877169542593, 12.372954376380768, 12.807224523681937, 13.227244611029162, 13.634331666788805, 14.029611541307906, 14.414055640242271, 14.788509052639487, 15.153712416434464, 15.51031914565268, 15.858909168035488, 16.200000000000003, 16.53405576378645, 16.861494595675676, 17.182694782833106, 17.497999885701223, 17.807723043668442, 18.112150617748295, 18.411545290930906, 18.706148721743876, 18.99618382728489, 19.281856757065697, 19.56335860735574, 19.840866916543742, 20.11454697476431, 20.384552975231024, 20.651029030050783, 20.914110069520053, 21.173922640833467, 21.430585619623184, 21.684210845682163, 21.934903692517096, 22.182763578959225, 22.4278844298788, 22.670355092058, 22.91025971044414, 23.147678069301037, 23.382685902179844, 23.61535517412347, 23.845754339085186, 24.073948575171464, 24.300000000000004, 24.523967868189686, 24.745908752761537, 24.965876712024357, 25.183923443339804, 25.40009842500615, 25.614449047363873, 25.827020734107137, 26.03785705468098, 26.246999828551836, 26.454489222058324, 26.660363838477522, 26.86466080187874, 27.067415835280617, 27.26866333357761, 27.468436431657338, 27.666767068090916, 27.8636860447429, 28.059223082615812, 28.253406874216076, 28.446265132702397, 28.637824638055175, 28.828111280484542, 29.017150101276314, 29.204965331258318, 29.391580427054276, 29.577018105278974, 29.761300374815615, 29.94444856730543, 30.126483365968888, 30.30742483286893, 30.48729243471778, 30.666105067321478, 30.84388107874883, 31.02063829130536, 31.196394022386627, 31.371165104280077, 31.544967902979394, 31.717818336070977, 31.889731889747836, 32.060723635002375, 32.23080824304597, 32.400000000000006, 32.56831282090001, 32.73576026305178, 32.902355538775645, 33.0681115275729, 33.23304078774616], [0.0, 3.3372893191930486, 4.719639816765682, 5.780354660399309, 6.674578638386097, 7.462405778299651, 8.174655956063228, 8.829637591656864, 9.439279633531363, 10.011867957579144, 10.553435459602717, 11.06853648862396, 11.560709320798617, 12.032767761408845, 12.486993232960447, 12.925265954710564, 13.349157276772194, 13.75999636627859, 14.158919450297045, 14.546906887720153, 14.924811556599302, 15.293380921169787, 15.65327441783348, 16.00507731940087, 16.349311912126456, 16.686446595965243, 17.016903361070135, 17.341063981197927, 17.659275183313728, 17.971852992944275, 18.27908641043091, 18.58124053985632, 18.878559267062727, 19.171267563726715, 19.45957347939569, 19.743669871632274, 20.023735915158287, 20.299938423551932, 20.57243301119243, 20.841365118436944, 21.106870919205434, 21.36907812705078, 21.62810671325625, 21.88406954841809, 22.13707297724792, 22.387217334898946, 22.634597411926727, 22.87930287399509, 23.121418641597234, 23.36102523435134, 23.598199083828412, 23.833012818357652, 24.06553552281769, 24.295832976047564, 24.523967868189686, 24.750000000000004, 24.973986465920895, 25.195981822504955, 25.416038243597292, 25.634205663527002, 25.85053190942113, 26.065062823634246, 26.277842377181578, 26.488912774970586, 26.69831455354439, 26.906086671978144, 27.112266596505723, 27.31689037939714, 27.51999273255718, 27.721607096270592, 27.92176570347943, 28.12049963994239, 28.31783890059409, 28.5138124423936, 28.708448233925846, 28.901773301996542, 29.093813775440307, 29.2845949263431, 29.474141208863074, 29.662476295818596, 29.849623113198604, 30.035603872737436, 30.22044010268547, 30.404152676895965, 30.586761842339573, 30.768287245149022, 30.94874795528892, 31.128162489938273, 31.30654883566696, 31.48392446948125, 31.66030637880815, 31.83571108048319, 32.01015463880174, 32.183652682689704, 32.35622042204559, 32.52787266330216, 32.69862382425291, 32.86848794818527, 33.037478717359775, 33.20560946587188, 33.37289319193049, 33.53934256958535], [0.0, 3.3674916480965473, 4.762352359916263, 5.8326666285670745, 6.734983296193095, 7.529940238806681, 8.248636250920512, 8.909545442950499, 9.524704719832526, 10.102474944289641, 10.648943609579309, 11.168706281391772, 11.665333257134149, 12.141663806908838, 12.6, 13.042239071570494, 13.46996659238619, 13.88452375848736, 14.287057079748788, 14.678555787270081, 15.059880477613362, 15.431785379534023, 15.794935897305821, 16.149922600433726, 16.497272501841024, 16.837458240482736, 17.17090562550502, 17.497999885701223, 17.819090885900998, 18.134497511648895, 18.444511378727274, 18.74939999039969, 19.04940943966505, 19.344766734184212, 19.635681806344287, 19.922349259060788, 20.204949888579282, 20.483652018133874, 20.75861267040743, 21.029978601986265, 21.297887219158618, 21.562467391279693, 21.823840175367852, 22.08211946349353, 22.337412562783545, 22.589820716420036, 22.839439572809138, 23.08635960908519, 23.330666514268298, 23.572441536675832, 23.811761799581316, 24.0487005885973, 24.283327613817676, 24.515709249377228, 24.745908752761537, 24.973986465920895, 25.2, 25.424004405285963, 25.646052327795015, 25.866194153759842, 26.084478143140988, 26.300950553164423, 26.51565575278122, 26.728636328851497, 26.93993318477238, 27.149585632197038, 27.35763147642719, 27.564107096004395, 27.76904751697472, 27.972486482256095, 28.17445651649735, 28.374988986782004, 28.574114159497576, 28.771861253662408, 28.968258490975945, 29.16333314283537, 29.357111574540163, 29.549619286887605, 29.740880955344956, 29.9309204669686, 30.119760955226724, 30.307424832868925, 30.49393382297535, 30.679308988306758, 30.863570759068047, 31.046738959188612, 31.22883283121545, 31.409871059907264, 31.589871794611643, 31.768852670501023, 31.946830828737927, 32.12382293563454, 32.29984520086745, 32.474913394803686, 32.6490428649907, 32.82224855185884, 32.99454500368205, 33.165946390838904, 33.33646651941384, 33.50611884417531, 33.67491648096547, 33.8428722185337], [0.0, 3.3974254958718375, 4.80468521341409, 5.88451357377991, 6.794850991743675, 7.5968743572603605, 8.321958904008119, 8.988742959947182, 9.60937042682818, 10.19227648761551, 10.74360274768199, 11.267985622994024, 11.76902714755982, 12.24959182993458, 12.712002202642982, 13.158172365492101, 13.58970198348735, 14.007944174646042, 14.41405564024227, 14.809034404713902, 15.193748714520721, 15.568959502805576, 15.935338088663197, 16.293480291208507, 16.643917808016237, 16.987127479359188, 17.323538899428144, 17.65354072133973, 17.977485919894363, 18.29569621523051, 18.608465815321797, 18.91606460128533, 19.21874085365636, 19.516723597981297, 19.810224632749627, 20.099440290714565, 20.38455297523102, 20.66573250576906, 20.943137300796174, 21.216915421427313, 21.48720549536398, 21.754137537489278, 22.017833680905124, 22.27840883007581, 22.535971245988048, 22.790623071781077, 23.042460806085796, 23.291575730293562, 23.53805429511964, 23.781978471102864, 24.023426067070453, 24.26247102007543, 24.49918365986916, 24.733630950590335, 24.965876712024357, 25.195981822504955, 25.424004405285963, 25.650000000000002, 25.874021720637096, 26.09612040131636, 26.316344730984202, 26.534741378050022, 26.75135510586333, 26.96622887984154, 27.1794039669747, 27.390920028359762, 27.600815205352177, 27.809126199864675, 28.015888349292084, 28.221135696495278, 28.424901055236763, 28.627216071424062, 28.82811128048454, 29.02761616116625, 29.22575918603313, 29.42256786889955, 29.618068809427804, 29.812287735093395, 30.00524954070538, 30.19697832565371, 30.387497429041442, 30.576829462846536, 30.76499634324698, 30.952019320231756, 31.137919005611153, 31.322715399530736, 31.506427915585732, 31.689075404624855, 31.870676177326395, 32.05124802562297, 32.23080824304597, 32.40937364405551, 32.586960582417014, 32.763584968681315, 32.939262286821176, 33.114007610073415, 33.287835616032474, 33.460760601038345, 33.63279649389863, 33.80395686898207, 33.974254958718376, 34.14370366553693], [0.0, 3.427097897638759, 4.846648326421054, 5.935907681222814, 6.854195795277518, 7.6632238646668815, 8.394641147779934, 9.06724875582445, 9.693296652842108, 10.281293692916275, 10.837435120913067, 11.366397846283581, 11.871815362445629, 12.356577195971383, 12.823026163897508, 13.273093083377363, 13.708391590555037, 14.130286621296824, 14.539944979263161, 14.93837340542805, 15.326447729333763, 15.704935529953636, 16.074513989542577, 16.43578413097471, 16.789282295559868, 17.135489488193794, 17.47483905505284, 17.807723043668446, 18.1344975116489, 18.455486988968893, 18.77098825315279, 19.081273542402773, 19.386593305684215, 19.687178568804626, 19.98324298005707, 20.274984586923857, 20.56258738583255, 20.846222679420848, 21.126050269749904, 21.40221951106941, 21.674870241826135, 21.944133612425897, 22.21013282265552, 22.47298378053079, 22.732795692567162, 22.98967159400064, 23.243708826260924, 23.494999467971905, 23.743630724891258, 23.989685283471314, 24.23324163210527, 24.47437435359687, 24.713154391942766, 24.949649296132407, 25.183923443339804, 25.416038243597292, 25.646052327795015, 25.874021720637096, 26.100000000000005, 26.324038443977397, 26.546186166754726, 26.766490244333493, 26.98499583101691, 27.201746267473347, 27.416783181110073, 27.630146579415754, 27.841874936864436, 28.052005275915658, 28.260573242593647, 28.46761317708248, 28.673158179733186, 28.877240172842004, 29.079889958526323, 29.281137272995394, 29.48101083748656, 29.67953840611407, 29.8767468108561, 30.07266200388652, 30.267309097440435, 30.460712401386807, 30.652895458667526, 30.843881078748833, 31.033691369220005, 31.22234776566298, 31.40987105990727, 31.596281426775526, 31.78159844941724, 31.965841143320475, 32.149027979085155, 32.331176904034905, 32.5123053627392, 32.69243031651211, 32.87156826194942, 33.049735248561376, 33.22694689555452, 33.40321840781214, 33.578564591119736, 33.75299986667852, 33.92653828494738, 34.09919353885074, 34.27097897638759, 34.44190761267442], [0.0, 3.4565155865408737, 4.888251221040097, 5.9868606130425315, 6.913031173081747, 7.729003816792951, 8.46669947500205, 9.14508064480571, 9.776502442080194, 10.369546759622619, 10.930462021342006, 11.463965282571298, 11.973721226085063, 12.462644181713605, 12.933097076879921, 13.387027302579163, 13.826062346163495, 14.251578859901803, 14.66475366312029, 15.066602138504885, 15.458007633585902, 15.839744316118237, 16.21249518118664, 16.576866410754477, 16.9333989500041, 17.282577932704367, 17.624840424809523, 17.960581839127595, 18.29016128961142, 18.61390609195179, 18.932115571166364, 19.245064302308787, 19.553004884160387, 19.85617032561919, 20.154776108902823, 20.449021981503172, 20.739093519245237, 21.025163495202598, 21.307393083153084, 21.585932919380625, 21.86092404268401, 22.132498729244286, 22.400781236376556, 22.665888467033447, 22.927930565142596, 23.187011450378847, 23.44322929973599, 23.696676982226855, 23.947442452170126, 24.195609105786115, 24.441256105200484, 24.68445867342446, 24.92528836342721, 25.163813304028466, 25.400098425006153, 25.634205663527005, 25.866194153759842, 26.096120401316362, 26.3240384439774, 26.549999999999994, 26.774054605158327, 26.996249739547157, 27.21663094506739, 27.435241934417125, 27.65212469232699, 27.867319569703863, 28.080865371280847, 28.292799437312663, 28.503157719803607, 28.711974853708686, 28.91928422350733, 29.12511802551193, 29.32950732624058, 29.53248211715365, 29.734071366027223, 29.93430306521266, 30.13320427700977, 30.33080117636196, 30.527119091063938, 30.72218253965691, 30.916015267171804, 31.108640278867863, 31.300079872102565, 31.490355666457624, 31.679488632236474, 31.867499117439383, 32.054406873314626, 32.24023107857634, 32.42499036237328, 32.608702826086166, 32.79138606402602, 32.973057183100266, 33.15373282150895, 33.33342916652891, 33.51216197143956, 33.68994657164062, 33.8667979000082, 34.04273050153292, 34.21775854728068, 34.39189584771389, 34.565155865408734, 34.7375517272015], [0.0, 3.485685011586675, 4.9295030175464944, 6.037383539249432, 6.97137002317335, 7.794228634059948, 8.538149682454623, 9.222255689363639, 9.859006035092989, 10.457055034760023, 11.022703842524301, 11.560709320798617, 12.074767078498864, 12.567816039392046, 13.042239071570494, 13.499999999999998, 13.9427400463467, 14.37184748040418, 14.788509052639483, 15.193748714520718, 15.588457268119896, 15.973415414368963, 16.349311912126456, 16.716758058906038, 17.076299364909246, 17.428425057933374, 17.77357589231835, 18.1121506177483, 18.444511378727277, 18.770988253152787, 19.09188309203678, 19.40747278756304, 19.718012070185978, 20.02373591515829, 20.324861623145186, 20.621590627301277, 20.914110069520046, 21.202594180901542, 21.487205495363977, 21.768095920406086, 22.045407685048602, 22.319274181747037, 22.58982071642004, 22.857165178560525, 23.121418641597234, 23.382685902179837, 23.641065965814654, 23.896652485233155, 24.149534156997728, 24.399795081106724, 24.647515087732476, 24.892770034690795, 25.13563207878409, 25.376169923769034, 25.614449047363873, 25.85053190942113, 26.084478143140988, 26.316344730984202, 26.546186166754726, 26.774054605158323, 26.999999999999996, 27.22407023205751, 27.44631122755843, 27.666767068090913, 27.8854800926934, 28.102490992792788, 28.317838900594086, 28.53156147146524, 28.74369496080836, 28.95427429586174, 29.16333314283537, 29.370903969745296, 29.577018105278967, 29.781705793993734, 29.984996248123824, 30.18691769624716, 30.387497429041435, 30.58676184233957, 30.784736477676727, 30.981446060505306, 31.176914536239792, 31.371165104280074, 31.564220250150328, 31.756101775879227, 31.946830828737927, 32.13642792844282, 32.32491299292234, 32.51230536273919, 32.69862382425291, 32.88388663160119, 33.0681115275729, 33.2513157634401, 33.433516117812076, 33.614728914569575, 33.79497003993345, 33.97425495871837, 34.15259872981849, 34.33001602096917, 34.50652112282546, 34.682127962395846, 34.85685011586675, 35.030700820851415], [0.0, 3.5146123541579946, 4.970412457734267, 6.087487166310908, 7.029224708315989, 7.858912138457842, 8.609006911369047, 9.29879024389732, 9.940824915468534, 10.543837062473981, 11.114180131705622, 11.656650462289758, 12.174974332621815, 12.672115056295851, 13.150475276582211, 13.612035116028755, 14.058449416631978, 14.491117969294155, 14.911237373202802, 15.319840077494282, 15.717824276915684, 16.105977151355955, 16.484993175612782, 16.855488720295238, 17.218013822738094, 17.573061770789973, 17.92107697656589, 18.262461498932723, 18.59758048779464, 18.92676676033178, 19.250324672586693, 19.56853341464301, 19.881649830937068, 20.1899108467571, 20.49353556612426, 20.792727093866258, 21.087674124947963, 21.378552336395465, 21.6655256109793, 21.94874711686296, 22.228360263411243, 22.504499550089978, 22.777291322718774, 23.046854449143375, 23.313300924579515, 23.57673641537352, 23.83726074866825, 24.0949683544096, 24.34994866524363, 24.602286479105963, 24.852062288671338, 25.099352581291814, 25.344230112591703, 25.5867641564931, 25.82702073410714, 26.065062823634246, 26.300950553164423, 26.534741378050022, 26.766490244333493, 26.996249739547153, 27.22407023205751, 27.45, 27.674085350739237, 27.896370731691963, 28.116898833263956, 28.335710684576096, 28.552845742587547, 28.768341975164294, 28.98223593858831, 29.194562849955467, 29.405356654868175, 29.614650090791212, 29.822474746405604, 30.028861117265173, 30.233838658033484, 30.437435831554538, 30.639680154988564, 30.84059824322479, 31.040215849764966, 31.238557905255483, 31.435648553831367, 31.63151118742195, 31.826168478156465, 32.01964240899639, 32.21195430271191, 32.403124849310444, 32.593174132017275, 32.78212165190045, 32.969986351225565, 33.15678663561956, 33.34254039511686, 33.52726502415609, 33.710977440590476, 33.89369410377098, 34.07543103175659, 34.256203817702854, 34.43602764547619, 34.61491730453794, 34.79288720413987, 34.96995138686927, 35.14612354157995, 35.32141701574273], [0.0, 3.543303543305315, 5.01098792654702, 6.137181763643635, 7.08660708661063, 7.923067587746555, 8.67928568489366, 9.374699995199846, 10.02197585309404, 10.629910629915942, 11.204909638189859, 11.751808371480536, 12.27436352728727, 12.77556260992055, 13.25782787639061, 13.723155613779214, 14.17321417322126, 14.609414772673132, 15.032963779641058, 15.444902071557463, 15.84613517549311, 16.237456697401843, 16.61956678135745, 16.993086829649286, 17.35857136978732, 17.716517716526575, 18.067373909896258, 18.411545290930906, 18.74939999039969, 19.08127354240277, 19.40747278756304, 19.728279195104676, 20.04395170618808, 20.354729180217554, 20.660832509848195, 20.962466457933807, 21.259821259831885, 21.553074026690485, 21.842389979120874, 22.127923535659647, 22.409819276379718, 22.688212798719956, 22.96323147991153, 23.23499515816605, 23.50361674296107, 23.769202763239658, 24.03185386107364, 24.2916652372784, 24.54872705457454, 24.803124803137205, 25.0549396327351, 25.30424865511719, 25.5511252198411, 25.795639166339726, 26.03785705468098, 26.277842377181578, 26.51565575278122, 26.75135510586333, 26.98499583101691, 27.216630945067386, 27.44631122755843, 27.674085350739233, 27.9, 28.124099985599536, 28.34642834644252, 28.56702644658698, 28.785934065095052, 29.00318947977963, 29.218829545346264, 29.432889766382097, 29.645404365601085, 29.856406347717066, 30.065927559282116, 30.273998744797492, 30.480649599376978, 30.685908818218174, 30.889804143114926, 31.092362406224456, 31.29360957128468, 31.493570772460842, 31.69227035098622, 31.889731889747832, 32.085978245956596, 32.28103158202971, 32.474913394803686, 32.66764454318676, 32.85924527435163, 33.04973524856137, 33.2391335627149, 33.42745877269165, 33.614728914569575, 33.80096152478506, 33.98617365929857, 34.17038191182533, 34.35360243118616, 34.5358509378298, 34.71714273957464, 34.89749274661433, 35.07691548582914, 35.25542511444161, 35.43303543305315, 35.609759898095355], [0.0, 3.5717642699371974, 5.0512374721448206, 6.186477188190384, 7.143528539874395, 7.9867077071844825, 8.748999942850611, 9.450000000000001, 10.102474944289641, 10.71529280981159, 11.29491035821002, 11.846201922979366, 12.372954376380768, 12.878179219128766, 13.364318164425748, 13.833383534045458, 14.28705707974879, 14.726761354758214, 15.153712416434463, 15.568959502805575, 15.973415414368965, 16.36788013152589, 16.75305942208766, 17.129579679606852, 17.497999885701223, 17.858821349685986, 18.212495710363257, 18.559431564571156, 18.900000000000002, 19.23453924584626, 19.56335860735574, 19.886741814585918, 20.204949888579282, 20.518223607320397, 20.826785637731046, 21.13084238737301, 21.43058561962318, 21.72619386823196, 22.017833680905124, 22.30566071650872, 22.58982071642004, 22.870450367231513, 23.147678069301033, 23.421624623411585, 23.692403845958733, 23.960123121553444, 24.224883900650585, 24.486782148743025, 24.745908752761537, 25.00234988956038, 25.256187360724105, 25.5074988973831, 25.756358438257532, 26.002836383748605, 26.246999828551836, 26.48891277497059, 26.728636328851497, 26.966228879841545, 27.201746267473347, 27.435241934417125, 27.666767068090916, 27.896370731691963, 28.12409998559954, 28.35, 28.57411415949758, 28.796484160397082, 29.01715010127631, 29.236150567405414, 29.453522709516427, 29.669302317378477, 29.883523888591185, 30.09622069297074, 30.307424832868925, 30.517167299734755, 30.725478027200815, 30.93238594095192, 31.13791900561115, 31.34210426885853, 31.544967902979398, 31.746535244023086, 31.94683082873793, 32.145878429434774, 32.34370108691954, 32.540321141623664, 32.73576026305178, 32.930039477656265, 33.123179195240304, 33.31519923398328, 33.50611884417532, 33.69595673074145, 33.88473107463006, 34.0724595531347, 34.259159359213704, 34.4448472198673, 34.62953941362778, 34.81325178721459, 34.995999771402445, 35.17779839614754, 35.358662305013745, 35.5386057689381, 35.71764269937197, 35.8957866608325], [0.0, 3.6, 5.091168824543142, 6.235382907247959, 7.2, 8.049844718999244, 8.818163074019441, 9.524704719832526, 10.182337649086284, 10.799999999999999, 11.384199576606166, 11.939849245279442, 12.470765814495918, 12.979984591670362, 13.46996659238619, 13.942740046346701, 14.4, 14.843180252223577, 15.273506473629427, 15.692036196746425, 16.09968943799849, 16.497272501841024, 16.88549673536435, 17.264993483925792, 17.636326148038883, 18.0, 18.356470248934027, 18.706148721743876, 19.04940943966505, 19.386593305684215, 19.718012070185978, 20.04395170618808, 20.364675298172568, 20.680425527536904, 20.991426821443085, 21.297887219158618, 21.599999999999998, 21.897945109073593, 22.191890410688316, 22.481992794234237, 22.768399153212332, 23.051247254758255, 23.330666514268298, 23.6067786874872, 23.879698490558884, 24.149534156997728, 24.416387939250967, 24.68035656144376, 24.941531628991836, 25.200000000000003, 25.455844122715714, 25.709142342754262, 25.959969183340725, 26.20839560140987, 26.454489222058328, 26.69831455354439, 26.93993318477238, 27.1794039669747, 27.416783181110073, 27.652124692326986, 27.885480092693403, 28.116898833263956, 28.34642834644252, 28.57411415949758, 28.8, 29.02412789387478, 29.246538256689455, 29.46726997874082, 29.686360504447155, 29.90384590650507, 30.11976095522672, 30.334139183434893, 30.547012947258853, 30.758413483143116, 30.968370961353457, 31.176914536239792, 31.38407239349285, 31.58987179461164, 31.794339118780254, 31.99749990233612, 32.19937887599698, 32.4, 32.5993864972947, 32.79756088491948, 32.99454500368205, 33.1903600462544, 33.38502658378454, 33.578564591119736, 33.7709934707287, 33.96233207540377, 34.1525987298185, 34.34181125101004, 34.529986967851585, 34.71714273957464, 34.90329497339757, 35.08845964131227, 35.272652296077766, 35.45588808646598, 35.638181771801996, 35.81954773583832, 36.0, 36.17955223603521], [0.0, 3.628015986734347, 5.13078941294612, 6.283908019696024, 7.256031973468694, 8.112490369793976, 8.886787946159174, 9.598828053465693, 10.26157882589224, 10.88404796020304, 11.472793905583766, 12.032767761408845, 12.567816039392048, 13.080997668373769, 13.574792816098519, 14.051245496396394, 14.512063946937388, 14.958693124735193, 15.392368238838362, 15.81415505172502, 16.224980739587952, 16.62565788172005, 17.016903361070135, 17.399353436263084, 17.77357589231835, 18.140079933671736, 18.49932431198502, 18.85172405908807, 19.197656106931387, 19.537464011483166, 19.871461949237652, 20.199938118717096, 20.52315765178448, 20.84136511843694, 21.154786692377687, 21.463632031881275, 21.76809592040608, 22.06835970343061, 22.364592551620518, 22.65695257531339, 22.94558781116753, 23.23063709845255, 23.512230859703635, 23.79049179819534, 24.06553552281769, 24.337471109381923, 24.606401606086166, 24.87242448978386, 25.135632078784095, 25.39611190714043, 25.653947064730605, 25.909216506872607, 26.161995336747538, 26.41235506349254, 26.660363838477522, 26.906086671978144, 27.149585632197038, 27.390920028359762, 27.630146579415754, 27.86731956970386, 28.102490992792788, 28.335710684576096, 28.56702644658698, 28.79648416039708, 29.024127893874777, 29.249999999999996, 29.474141208863063, 29.69659071341355, 29.917386249470386, 30.13656417045579, 30.35415951727209, 30.570206083701823, 30.784736477676724, 30.99778217873014, 31.209373591919462, 31.419540098480116, 31.62831010345004, 31.835711080483186, 32.04176961405222, 32.24651143922393, 32.449961479175904, 32.652143880609124, 32.853082047199166, 33.052798671216934, 33.2513157634401, 33.448654681466635, 33.644836156533735, 33.8398803189373, 34.03380672214027, 34.226634365651556, 34.4183817167513, 34.60906673113275, 34.79870687252617, 34.9873191313653, 35.17492004255305, 35.36152570237884, 35.5471517846367, 35.73181355598957, 35.915525890622845, 36.09830328422653, 36.28015986734347, 36.46110941811837], [0.0, 3.6558172820861823, 5.170106381884225, 6.33206127576163, 7.311634564172365, 8.174655956063228, 8.95488693395958, 9.672383367092104, 10.34021276376845, 10.967451846258545, 11.560709320798615, 12.124974226776732, 12.66412255152326, 13.181236664289129, 13.678815738213597, 14.158919450297045, 14.62326912834473, 15.073320801999802, 15.510319145652677, 15.935338088663196, 16.349311912126456, 16.753059422087656, 17.147302994931888, 17.53268376490034, 17.90977386791916, 18.27908641043091, 18.641083659487183, 18.99618382728489, 19.34476673418421, 19.687178568804622, 20.023735915158287, 20.354729180217554, 20.6804255275369, 21.001071401240463, 21.316894708188624, 21.628106713256248, 21.93490369251709, 22.237468381090505, 22.535971245988044, 22.830571609138484, 23.12141864159723, 23.408652246551917, 23.69240384595873, 23.972797083360962, 24.249948453553465, 24.52396786818968, 24.794959165120638, 25.06302056815978, 25.32824510304652, 25.590720974603276, 25.85053190942113, 26.10775746784852, 26.362473328578258, 26.614751548718242, 26.864660801878742, 27.112266596505723, 27.357631476427194, 27.60081520535218, 27.84187493686444, 28.080865371280847, 28.31783890059409, 28.55284574258755, 28.785934065095056, 29.017150101276314, 29.24653825668946, 29.474141208863067, 29.7, 29.924154123383335, 30.146641603999605, 30.36749907384538, 30.58676184233957, 30.804463962224695, 31.020638291305353, 31.2353165503409, 31.448529377381067, 31.66030637880815, 31.87067617732639, 32.07966645711891, 32.28730400637378, 32.493614757364256, 32.69862382425291, 32.90235553877564, 33.104833483949136, 33.306080525934, 33.50611884417531, 33.70496995993321, 33.902654763307254, 34.09919353885074, 34.294605989863776, 34.4889112614475, 34.682127962395846, 34.87427418599562, 35.06536752980068, 35.25542511444161, 35.44446360152739, 35.63249921069247, 35.81954773583832, 36.00562456061553, 36.190744673189585, 36.374922680330194, 36.55817282086182, 36.740508978510356], [0.0, 3.6834087473426025, 5.209126606255601, 6.379851095441022, 7.366817494685205, 8.236352347975409, 9.022471945093539, 9.745383522468472, 10.418253212511202, 11.050226242027806, 11.647961194990305, 12.216484764448406, 12.759702190882043, 13.280719107036335, 13.7820535480022, 14.265780735732621, 14.73363498937041, 15.187083327617584, 15.627379818766803, 16.055606497420147, 16.472704695950817, 16.879499400159947, 17.276718438407222, 17.66500778375147, 18.044943890187078, 18.417043736713012, 18.781773079238288, 19.139553286323068, 19.490767044936945, 19.83576315648077, 20.174860594313902, 20.508351957190513, 20.836506425022403, 21.15957230191575, 21.477779214807104, 21.79134002304585, 22.100452484055612, 22.405300712108286, 22.706056460777155, 23.002880254437706, 23.29592238998061, 23.585323826481588, 23.87121697777472, 24.153726420575353, 24.432969528896813, 24.70905704392622, 24.98209358720762, 25.25217812387676, 25.519404381764087, 25.78386123139822, 26.045633031278008, 26.304799942215872, 26.56143821407267, 26.81562044779125, 27.06741583528062, 27.31689037939714, 27.5641070960044, 27.80912619986468, 28.05200527591566, 28.292799437312663, 28.531561471465242, 28.768341975164294, 29.003189479779632, 29.236150567405414, 29.46726997874082, 29.69659071341355, 29.924154123383335, 30.15, 30.374166655235168, 30.596690997557236, 30.817608602875076, 31.036953780936685, 31.254759637533606, 31.471058132830553, 31.6858801361111, 31.899255477205106, 32.111212994840294, 32.321780582139965, 32.530985229470076, 32.738853064821924, 32.945409391901634, 33.15067872608342, 33.35468482837156, 33.557450737503885, 33.758998800319894, 33.959350700506626, 34.15852748582702, 34.356549593927504, 34.553436876814445, 34.749208624082364, 34.94388358497092, 35.137479989321946, 35.33001556750294, 35.5215075693586, 35.71197278224769, 35.90142754821874, 36.089887780374156, 36.27736897846921, 36.46388624378921, 36.649454293345215, 36.834087473426024, 37.017799772541856], [0.0, 3.710795063055895, 5.24785670536077, 6.427285585688566, 7.42159012611179, 8.2975900115636, 9.08955444452587, 9.817840903172144, 10.49571341072154, 11.132385189167682, 11.734564329364767, 12.30731489805961, 12.854571171377131, 13.379461872586655, 13.884523758487362, 14.37184748040418, 14.84318025222358, 15.299999999999999, 15.74357011608231, 16.174980680050286, 16.5951800231272, 17.004999264922066, 17.405171645232347, 17.79634793995667, 18.17910888905174, 18.553975315279473, 18.921416437465776, 19.281856757065697, 19.635681806344287, 19.983242980057067, 20.324861623145186, 20.660832509848195, 20.99142682144308, 21.31689470818862, 21.637467504308358, 21.953359651770842, 22.264770378335363, 22.571885167172017, 22.8748770488499, 23.173907741250723, 23.469128658729534, 23.760681808399355, 24.0487005885973, 24.33331050227239, 24.61462979611922, 24.89277003469079, 25.167836617397214, 25.439929245184626, 25.709142342754262, 25.975565441391264, 26.239283526803852, 26.500377355803824, 26.75892374517331, 27.014995835646545, 27.268663333577614, 27.51999273255718, 27.769047516974723, 28.015888349292087, 28.26057324259365, 28.503157719803603, 28.74369496080836, 28.98223593858831, 29.218829545346267, 29.453522709516427, 29.68636050444716, 29.91738624947039, 30.146641603999605, 30.374166655235168, 30.599999999999998, 30.824178821178673, 31.046738959188612, 31.267714978872377, 31.48714023216462, 31.70504691685537, 31.921466131742758, 32.13642792844283, 32.34996136010057, 32.56209452722598, 32.77285462085963, 32.98226796325565, 33.1903600462544, 33.39715556750305, 33.60267846467005, 33.806951947787304, 34.00999852984413, 34.211840055746784, 34.41249772974929, 34.61199214145294, 34.810343290464694, 35.0075706097981, 35.2036929880943, 35.39872879073484, 35.59269587991334, 35.78561163372788, 35.97749296435203, 36.16835633533821, 36.35821777810348, 36.54709290764452, 36.734996937525395, 36.921944694178826, 37.107950630558946, 37.2930288391812], [0.0, 3.737980738313134, 5.286303056011829, 6.474372556472172, 7.475961476626268, 8.35837902945302, 9.156145477219113, 9.88976743912616, 10.572606112023658, 11.2139422149394, 11.820532982907327, 12.397479582560322, 12.948745112944344, 13.477481218684744, 13.986243241128049, 14.47713714793087, 14.951922953252536, 15.412089410589338, 15.858909168035487, 16.293480291208507, 16.71675805890604, 17.129579679606856, 17.532683764900344, 17.926725858337882, 18.312290954438225, 18.689903691565668, 19.060036726092637, 19.423117669416516, 19.77953487825232, 20.129642321710538, 20.473763698939184, 20.81219594372492, 21.145212224047317, 21.47306452279227, 21.795985868962205, 22.114192275550106, 22.4278844298788, 22.737249173987607, 23.042460806085796, 23.34368222881729, 23.641065965814654, 23.93475506454996, 24.22488390065059, 24.511578896513374, 24.794959165120645, 25.075137088359057, 25.352218837805893, 25.62630484482693, 25.89749022588869, 26.16586516819194, 26.431515280059145, 26.69452190993501, 26.95496243736949, 27.212910538933542, 27.468436431657338, 27.721607096270592, 27.972486482256098, 28.22113569649528, 28.467613177082484, 28.711974853708686, 28.95427429586174, 29.194562849955467, 29.432889766382097, 29.66930231737848, 29.903845906505072, 30.136564170455795, 30.36749907384538, 30.596690997557236, 30.824178821178677, 31.05, 31.274190637009298, 31.49678555027481, 31.717818336070973, 31.93732142807221, 32.15532615290972, 32.37186278236086, 32.586960582417014, 32.80064785945546, 33.01295200372121, 33.223899530307996, 33.43351611781208, 33.6418266448182, 33.848855224364684, 34.054625236522575, 34.25915935921371, 34.462479597382426, 34.66460731062736, 34.865563239391385, 35.06536752980069, 35.26403975723712, 35.461598948721985, 35.65806360418356, 35.853451716675764, 36.047780791610464, 36.241067865061595, 36.43332952119528, 36.62458190887645, 36.81484075749888, 37.0041213920828, 37.19243874768096, 37.379807383131336, 37.56624149419263], [0.0, 3.7649701194033405, 5.324471804789654, 6.521119535785248, 7.529940238806681, 8.41872912024137, 9.222255689363639, 9.961174629530396, 10.648943609579309, 11.29491035821002, 11.905880899790658, 12.48699323296045, 13.042239071570496, 13.57479281609852, 14.087228258248675, 14.581666571417685, 15.059880477613362, 15.523369479594306, 15.973415414368963, 16.411124275929424, 16.83745824048274, 17.253260561412734, 17.659275183313728, 18.05616238296499, 18.444511378727277, 18.824850597016702, 19.19765610693139, 19.563358607355745, 19.92234925906079, 20.27498458692386, 20.62159062730128, 20.96246645793381, 21.297887219158618, 21.62810671325625, 21.953359651770846, 22.273863607376246, 22.58982071642004, 22.901419169999052, 23.208834524809728, 23.512230859703642, 23.811761799581316, 24.107571424761975, 24.399795081106728, 24.688560103821363, 24.9739864659209, 25.256187360724102, 25.535269726399996, 25.81133471945998, 26.08447814314099, 26.354790835823383, 26.622359023948274, 26.887264643321384, 27.14958563219704, 27.409396199113914, 27.66676706809092, 27.92176570347943, 28.17445651649735, 28.424901055236766, 28.67315817973319, 28.91928422350733, 29.16333314283537, 29.405356654868175, 29.645404365601088, 29.883523888591185, 30.119760955226724, 30.354159517272095, 30.58676184233957, 30.817608602875076, 31.046738959188612, 31.274190637009298, 31.500000000000004, 31.724202117626223, 31.946830828737927, 32.16791880119073, 32.38749758780385, 32.60559767892624, 32.82224855185885, 33.037478717359775, 33.251315763440104, 33.46378639664077, 33.67491648096548, 33.88473107463006, 34.093254464776464, 34.30051020028711, 34.50652112282547, 34.711309396218404, 34.914896534287486, 35.11730342722801, 35.318550366627456, 35.51865706920801, 35.71764269937197, 35.915525890622845, 36.11232476592998, 36.30805695709976, 36.502739623211845, 36.696389468175205, 36.889022757454555, 37.0806553340148, 37.27130263352758, 37.460979698881346, 37.649701194033405, 37.83748141724024], [0.0, 3.7917673979293616, 5.362368879515843, 6.5675337836968914, 7.583534795858723, 8.478649656637549, 9.287895348247632, 10.032073564323579, 10.724737759031687, 11.375302193788082, 11.990621335026805, 12.57586975123391, 13.135067567393783, 13.67141177786698, 14.187494493391002, 14.685451984872648, 15.167069591717446, 15.633857489436188, 16.087106638547528, 16.527930904986263, 16.957299313275097, 17.376061118677043, 17.784965560832557, 18.184677616059076, 18.575790696495265, 18.95883698964681, 19.33429595304675, 19.702601351090674, 20.064147128647157, 20.41929234816917, 20.768365366585787, 21.11166739033182, 21.449475518063373, 21.78204535850571, 22.109613293768845, 22.43239844510613, 22.750604387576164, 23.064420651731098, 23.374024043796993, 23.679579810461167, 23.98124267005361, 24.27915772838918, 24.573461294656884, 24.864281610374345, 25.15173950246782, 25.43594896991264, 25.717017712013188, 25.995047605265125, 26.270135134787566, 26.54237178550553, 26.81184439757922, 27.078635489994692, 27.34282355573396, 27.604483331517006, 27.8636860447429, 28.12049963994239, 28.374988986782004, 28.627216071424062, 28.877240172842004, 29.125118025511927, 29.370903969745296, 29.614650090791212, 29.856406347717066, 30.096220692970736, 30.334139183434893, 30.570206083701823, 30.804463962224695, 31.03695378093668, 31.267714978872377, 31.496785550274808, 31.72420211762622, 31.95, 32.174213277095056, 32.396874849281375, 32.61801649395622, 32.837668918484454, 33.05586180997253, 33.27262388210464, 33.48798291925031, 33.701965818035006, 33.914598626550195, 34.125906581364255, 34.335914142483524, 34.544645026400254, 34.75212223735409, 34.958368096923515, 35.163404272055345, 35.367251801631404, 35.569931121665114, 35.77146208921296, 35.97186400508041, 36.17115563539545, 36.36935523211815, 36.56648055254976, 36.76254887790018, 36.9575770309689, 37.15158139299053, 37.34457791969271, 37.536582156610905, 37.72760925370173, 37.91767397929362, 38.10679073341129], [0.0, 3.8183766184073566, 5.3999999999999995, 6.613622305514581, 7.636753236814713, 8.538149682454625, 9.353074360871938, 10.102474944289643, 10.799999999999999, 11.455129855222069, 12.074767078498864, 12.664122551523262, 13.227244611029162, 13.76735268670052, 14.28705707974879, 14.788509052639485, 15.273506473629427, 15.74357011608231, 16.2, 16.643917808016237, 17.07629936490925, 17.497999885701223, 17.90977386791916, 18.312290954438225, 18.706148721743876, 19.091883092036785, 19.469976887505542, 19.840866916543746, 20.204949888579286, 20.562587385832554, 20.91411006952005, 21.25982125983189, 21.599999999999998, 21.934903692517096, 22.26477037833537, 22.58982071642004, 22.910259710444137, 23.226278221015093, 23.538054295119636, 23.84575433908519, 24.149534156997728, 24.449539872971027, 24.745908752761537, 25.038769937838396, 25.328245103046523, 25.61444904736387, 25.897490225888685, 26.177471230048177, 26.454489222058324, 26.728636328851497, 27.0, 27.268663333577614, 27.53470537340104, 27.798201380664903, 28.059223082615816, 28.317838900594094, 28.57411415949758, 28.828111280484542, 29.079889958526326, 29.32950732624058, 29.57701810527897, 29.822474746405604, 30.06592755928212, 30.307424832868925, 30.547012947258853, 30.784736477676724, 31.020638291305353, 31.254759637533606, 31.48714023216462, 31.717818336070973, 31.946830828737927, 32.17421327709506, 32.4, 32.62422412870535, 32.846917663610384, 33.0681115275729, 33.287835616032474, 33.50611884417531, 33.72298919135136, 33.938473742936644, 34.1525987298185, 34.36538956566621, 34.576870882137385, 34.78706656215784, 34.995999771402445, 35.2036929880943, 35.4101680312308, 35.615446087336885, 35.81954773583832, 36.022492973141105, 36.2243012354966, 36.42499142072651, 36.62458190887645, 36.82309058186181, 37.02053484216564, 37.21693163064359, 37.41229744348775, 37.60664834839712, 37.800000000000004, 37.99236765456978, 38.18376618407357, 38.37421008959012], [0.0, 3.844801685392889, 5.437370688117557, 6.659391864126935, 7.689603370785778, 8.597237928544262, 9.417802291405359, 10.172389099911584, 10.874741376235114, 11.534405056178667, 12.158330477495667, 12.75176458377428, 13.31878372825387, 13.862629620674427, 14.385930626831202, 14.890852896996867, 15.379206741571556, 15.852523458427683, 16.31211206435267, 16.759102004582466, 17.194475857088523, 17.619094755406703, 18.03371841856249, 18.43902112369309, 18.835604582810717, 19.224008426964446, 19.60471881971277, 19.978175592380804, 20.344778199823168, 20.704890726589213, 21.05884612223566, 21.406949806079332, 21.74948275247023, 22.086704145254448, 22.418853672746074, 22.7461535209802, 23.068810112357333, 23.38701562833531, 23.700949348074644, 24.010778829517385, 24.316660954991335, 24.618742859861875, 24.91716275983283, 25.212050690096586, 25.50352916754856, 25.791713785632776, 26.076713750010754, 26.35863236209345, 26.63756745650774, 26.913611797750224, 27.18685344058779, 27.457376058174244, 27.725259241348855, 27.990578772151178, 28.253406874216076, 28.5138124423936, 28.771861253662404, 29.02761616116625, 29.281137272995394, 29.532482117153645, 29.781705793993734, 30.02886111726517, 30.27399874479749, 30.51716729973475, 30.758413483143112, 30.99778217873014, 31.235316550340897, 31.47105813283055, 31.705046916855366, 31.937321428072202, 32.16791880119073, 32.396874849281375, 32.62422412870534, 32.85, 33.07423468502333, 33.29695932063467, 33.51820400916493, 33.737997865907815, 33.95636906384427, 34.17334487579464, 34.38895171417705, 34.603215168536, 34.81616004099246, 35.02781037975397, 35.238189510813406, 35.447320067954365, 35.65522402117255, 35.861922703614205, 36.06743683712498, 36.27178655649595, 36.474991432487, 36.677070493702196, 36.87804224738618, 37.07792469920613, 37.276735372078925, 37.47449132409938, 37.671209165621434, 37.86690507554057, 38.061594816822904, 38.25529375132284, 38.44801685392889, 38.63977872607451], [0.0, 3.871046370169182, 5.474486277268397, 6.704848991588103, 7.742092740338364, 8.655922827752105, 9.482088377567464, 10.241826009066937, 10.948972554536795, 11.613139110507545, 12.241323457861899, 12.838808355918395, 13.409697983176207, 13.957256177343739, 14.484129245487972, 14.992498124061912, 15.484185480676729, 15.960733065871377, 16.423458831805192, 16.873499933327405, 17.31184565550421, 17.73936300998432, 18.156816901648813, 18.564886210262642, 18.96417675513493, 19.35523185084591, 19.73854097951518, 20.11454697476431, 20.483652018133874, 20.846222679420844, 21.202594180901542, 21.553074026690485, 21.89794510907359, 22.237468381090505, 22.571885167172017, 22.90141916999905, 23.22627822101509, 23.546655813512032, 23.86273245041313, 24.17467683341393, 24.482646915723798, 24.78679083705674, 25.087247756579437, 25.38414859710681, 25.67761671183679, 25.96776848325631, 26.254713862466676, 26.538556856016115, 26.819395966352413, 27.097324591184275, 27.37243138634199, 27.644800596133805, 27.914512354687478, 28.181642961332116, 28.446265132702397, 28.708448233925846, 28.968258490975945, 29.22575918603313, 29.48101083748656, 29.734071366027216, 29.984996248123824, 30.23383865803348, 30.480649599376978, 30.72547802720081, 30.968370961353457, 31.209373591919462, 31.448529377381064, 31.685880136111095, 31.921466131742754, 32.15532615290972, 32.38749758780384, 32.61801649395622, 32.846917663610384, 33.07423468502333, 33.3, 33.52424495794051, 33.74699986665481, 33.968294040178115, 34.188155843800644, 34.4066127365075, 34.62369131100842, 34.83941733152264, 35.0538157694708, 35.26691083721396, 35.47872601996864, 35.689284106017034, 35.898607215322436, 36.106716826651514, 36.31363380329763, 36.51937841749226, 36.72397037358569, 36.927428830071555, 37.129772420525285, 37.33101927352105, 37.53118703158748, 37.73029286925824, 37.92835351026986, 38.12538524395524, 38.32140394087878, 38.516425067755186, 38.71046370169182, 38.90353454379178], [0.0, 3.897114317029974, 5.5113519212621505, 6.750000000000001, 7.794228634059948, 8.714212528966689, 9.545941546018392, 10.31079531365064, 11.022703842524301, 11.69134295108992, 12.323757543866238, 12.925265954710566, 13.500000000000002, 14.051245496396396, 14.581666571417685, 15.09345884812358, 15.588457268119896, 16.06821396422141, 16.53405576378645, 16.987127479359188, 17.428425057933378, 17.85882134968599, 18.279086410430914, 18.689903691565668, 19.091883092036785, 19.48557158514987, 19.871461949237656, 20.250000000000004, 20.62159062730128, 20.986602869449836, 21.345374206136558, 21.69821421223415, 22.045407685048602, 22.387217334898953, 22.723886111314677, 23.055639223409095, 23.38268590217984, 23.705220943918665, 24.02342606707045, 24.33747110938193, 24.647515087732476, 24.95370713942119, 25.256187360724105, 25.555087556101228, 25.850531909421132, 26.14263758690006, 26.431515280059145, 26.717269695835316, 27.000000000000004, 27.279800219209818, 27.556759606310756, 27.830962972919213, 28.10249099279279, 28.37142047906661, 28.63782463805518, 28.901773301996542, 29.16333314283537, 29.42256786889955, 29.679538406114073, 29.934303065212656, 30.18691769624716, 30.437435831554534, 30.685908818218177, 30.93238594095192, 31.176914536239792, 31.419540098480116, 31.660306378808148, 31.899255477205106, 32.13642792844282, 32.37186278236086, 32.60559767892624, 32.837668918484454, 33.0681115275729, 33.29695932063467, 33.52424495794052, 33.75, 33.974254958718376, 34.197039345533994, 34.418381716751306, 34.63830971626647, 34.856850115866756, 35.074028853269766, 35.289871068055774, 35.50440113563388, 35.71764269937198, 35.929618701010455, 36.14035140947028, 36.3498624481579, 36.55817282086183, 36.76530293632843, 36.971272631598715, 37.17610119418119, 37.379807383131336, 37.58240944910265, 37.78392515343, 37.98437178630179, 38.18376618407357, 38.38212474577196, 38.57946344883506, 38.7757978641317, 38.97114317029974, 39.165514167440726], [0.0, 3.9230090491866068, 5.547972602672079, 6.794850991743676, 7.8460180983732135, 8.77211491032807, 9.609370426828182, 10.379306335203717, 11.095945205344158, 11.769027147559818, 12.4056438768812, 13.011149065320867, 13.589701983487352, 14.144610280951541, 14.678555787270083, 15.19374871452072, 15.692036196746427, 16.174980680050286, 16.643917808016237, 17.1, 17.54422982065614, 17.977485919894363, 18.40054347023479, 18.81409046433019, 19.218740853656364, 19.615045245933032, 20.003499693803587, 20.384552975231028, 20.758612670407434, 21.126050269749907, 21.48720549536398, 21.842389979120878, 22.191890410688316, 22.53597124598805, 22.874877048849907, 23.20883452480973, 23.538054295119636, 23.862732450413137, 24.183051916579927, 24.499183659869164, 24.8112877537624, 25.119514326515155, 25.424004405285967, 25.724890670321614, 26.022298130641733, 26.316344730984202, 26.60714189837007, 26.894795035471088, 27.179403966974704, 27.461063344306247, 27.7398630133604, 28.01588834929209, 28.289220561903083, 28.55993697472038, 28.828111280484546, 29.09381377544031, 29.357111574540166, 29.618068809427808, 29.876746810856105, 30.13320427700977, 30.38749742904144, 30.639680154988564, 30.88980414311493, 31.137919005611153, 31.384072393492854, 31.628310103450044, 31.870676177326395, 32.111212994840294, 32.34996136010057, 32.586960582417014, 32.82224855185885, 33.05586180997253, 33.287835616032474, 33.51820400916494, 33.74699986665482, 33.974254958718376, 34.2, 34.4242646980295, 34.647077798856294, 34.86846713005893, 35.08845964131228, 35.30708144267946, 35.524357840783, 35.74031337299661, 35.954971839788726, 36.16835633533822, 36.38048927653393, 36.59139243046102, 36.80108694046958, 37.00959335091377, 37.2169316306436, 37.42312119532523, 37.62818092866038, 37.83212920257067, 38.034983896407795, 38.2367624152464, 38.43748170731273, 38.637158280598236, 38.83580821870456, 39.0334471959626, 39.230090491866065, 39.42575300485712], [0.0, 3.9487339743264553, 5.584353140695885, 6.839407869106799, 7.897467948652911, 8.829637591656864, 9.672383367092106, 10.447368089619511, 11.16870628139177, 11.846201922979365, 12.486993232960447, 13.096468989769726, 13.678815738213599, 14.237362817600738, 14.774809643443804, 15.293380921169785, 15.794935897305821, 16.28104726361299, 16.753059422087656, 17.21213234901475, 17.659275183313728, 18.095372336594792, 18.521204064531013, 18.937462871250734, 19.344766734184212, 19.743669871632274, 20.134671589077385, 20.5182236073204, 20.894736179239022, 21.26458323127919, 21.628106713256248, 21.985620300550995, 22.33741256278354, 22.683749690031412, 23.02487784983886, 23.361025234351338, 23.69240384595873, 24.019211061148535, 24.341631005337337, 24.65983576587647, 24.973986465920895, 25.284234218184267, 25.590720974603276, 25.89358028546844, 26.19293797953945, 26.488912774970586, 26.78161682945972, 27.07115623685106, 27.357631476427198, 27.641137820285188, 27.92176570347943, 28.199601061007943, 28.474725635201477, 28.74721725663199, 29.017150101276318, 29.284594926343104, 29.54961928688761, 29.812287735093395, 30.072662003886524, 30.330801176361955, 30.58676184233957, 30.84059824322479, 31.09236240622446, 31.342104268858527, 31.589871794611643, 31.835711080483186, 32.079666457118904, 32.321780582139965, 32.56209452722598, 32.80064785945546, 33.037478717359775, 33.27262388210464, 33.50611884417531, 33.737997865907815, 33.968294040178115, 34.197039345533994, 34.4242646980295, 34.65, 34.874274185995624, 35.0971152660728, 35.318550366627456, 35.5386057689381, 35.75730694557408, 35.97467859481166, 36.190744673189585, 36.40552842632558, 36.61905241810607, 36.831338558352726, 37.042408129062025, 37.252281809306666, 37.460979698881346, 37.66852134076941, 37.87492574250147, 38.08021139647206, 38.28439629927577, 38.48749797012012, 38.689533468368424, 38.89051941026245, 39.0904719848712, 39.28940696930918, 39.48733974326455, 39.684285302875246], [0.0, 3.9742923898475317, 5.6204981985585585, 6.883676343350261, 7.9485847796950635, 8.886787946159176, 9.734988443752773, 10.514989300993133, 11.240996397117117, 11.922877169542593, 12.56781603939205, 13.181236664289132, 13.767352686700521, 14.329514995281594, 14.870440477672478, 15.392368238838364, 15.897169559390127, 16.386427310429813, 16.861494595675676, 17.323538899428144, 17.773575892318352, 18.21249571036326, 18.641083659487187, 19.060036726092637, 19.469976887505545, 19.87146194923766, 20.264994448555868, 20.651029030050783, 21.029978601986265, 21.40221951106941, 21.768095920406086, 22.127923535659647, 22.481992794234234, 22.830571609138484, 23.173907741250723, 23.51223085970364, 23.845754339085186, 24.17467683341393, 24.49918365986916, 24.819448019647826, 25.1356320787841, 25.44788792807765, 25.756358438257536, 26.061178024026464, 26.362473328578265, 26.660363838477522, 26.954962437369492, 27.24637590579709, 27.534705373401042, 27.820046728932724, 28.102490992792795, 28.38212465619867, 28.659029990563187, 28.933285330221324, 29.204965331258318, 29.474141208863074, 29.740880955344956, 30.00524954070538, 30.267309097440435, 30.52711909106393, 30.784736477676727, 31.040215849764966, 31.29360957128468, 31.544967902979394, 31.794339118780254, 32.04176961405222, 32.28730400637377, 32.530985229470076, 32.772854620859626, 33.01295200372121, 33.251315763440104, 33.48798291925031, 33.72298919135135, 33.95636906384427, 34.188155843800644, 34.418381716751306, 34.64707779885629, 34.87427418599562, 35.10000000000001, 35.32428343222266, 35.547151784636704, 35.768631508627784, 35.98874824163798, 36.207526841804594, 36.42499142072652, 36.64116537448011, 36.85607141299789, 37.069731587914156, 37.28216731897437, 37.49339941909776, 37.70344811817615, 37.91233308568599, 38.120073452185274, 38.32668782976166, 38.53219433149377, 38.73661058998322, 38.93995377501109, 39.14224061036875, 39.34348738990992, 39.54370999286739, 39.74292389847532, 39.94114419993499], [0.0, 3.9996874877920154, 5.656412290489441, 6.927661943253295, 7.999374975584031, 8.943573111458306, 9.79719347568476, 10.582178414674363, 11.312824580978882, 11.999062463376044, 12.648122390299676, 13.26546267568531, 13.85532388650659, 14.42107832306586, 14.965460233484302, 15.490723030252655, 15.998749951168062, 16.491133981627826, 16.969236871468322, 17.434233565029466, 17.887146222916613, 18.328870668974673, 18.76019722710825, 19.181827337352406, 19.59438695136952, 19.998437438960075, 20.39448454852439, 20.782985829759884, 21.164356829348726, 21.538976298793777, 21.907190600348553, 22.26931745698552, 22.625649161957764, 22.97645534019554, 23.32198533572989, 23.662470285242833, 23.998124926752087, 24.32914918364389, 24.655729557244904, 24.978040355480257, 25.296244780599352, 25.610495895237953, 25.920937483046405, 26.227704817616043, 26.53092535137062, 26.830719334374916, 27.127200371582763, 27.420475925847825, 27.71064777301318, 27.997812414544107, 28.282061452447206, 28.563481930605032, 28.84215664613172, 29.118164433906205, 29.39158042705428, 29.662476295818596, 29.930920466968605, 30.196978325653713, 30.46071240138681, 30.72218253965691, 30.98144606050531, 31.238557905255487, 31.493570772460846, 31.746535244023086, 31.997499902336124, 32.24651143922394, 32.493614757364256, 32.738853064821924, 32.98226796325565, 33.223899530307996, 33.46378639664077, 33.701965818035006, 33.938473742936644, 34.17334487579465, 34.4066127365075, 34.63830971626647, 34.86846713005893, 35.0971152660728, 35.324283432222664, 35.55, 35.774292445833225, 35.99718739012814, 36.218710634146, 36.438887194863675, 36.657741337949346, 36.87529660897658, 37.09157586299078, 37.30660129253267, 37.5203944542165, 37.732976293952746, 37.94436717089903, 38.15458688021665, 38.36365467470481, 38.57158928537947, 38.77840894105894, 38.98413138701438, 39.18877390273904, 39.392353318886656, 39.594886033426086, 39.796388027055926, 39.99687487792015, 40.196361775663235], [0.0, 4.024922359499622, 5.692099788303083, 6.9713700231733515, 8.049844718999244, 9.000000000000002, 9.85900603509299, 10.64894360957931, 11.384199576606166, 12.074767078498864, 12.727922061357857, 13.349157276772196, 13.942740046346703, 14.51206394693739, 15.05988047761336, 15.588457268119896, 16.09968943799849, 16.5951800231272, 17.07629936490925, 17.54422982065614, 18.000000000000004, 18.44451137872728, 18.87855926706273, 19.3028495305745, 19.71801207018598, 20.12461179749811, 20.523157651784487, 20.914110069520056, 21.29788721915862, 21.674870241826135, 22.045407685048602, 22.40981927637972, 22.768399153212332, 23.121418641597234, 23.469128658729538, 23.811761799581316, 24.149534156997728, 24.4826469157238, 24.8112877537624, 25.1356320787841, 25.455844122715714, 25.772077913897437, 26.08447814314099, 26.39318093750732, 26.698314553544392, 27.0, 27.298351598585583, 27.59347749016061, 27.885480092693406, 28.174456516497354, 28.460498941515418, 28.743694960808366, 29.02412789387478, 29.301877072979476, 29.577018105278974, 29.849623113198604, 30.11976095522672, 30.387497429041442, 30.65289545866753, 30.9160152671718, 31.176914536239792, 31.435648553831367, 31.692270350986217, 31.946830828737927, 32.19937887599698, 32.449961479175904, 32.69862382425291, 32.94540939190163, 33.1903600462544, 33.43351611781208, 33.67491648096548, 33.914598626550195, 34.1525987298185, 34.38895171417705, 34.62369131100842, 34.856850115866756, 35.08845964131228, 35.318550366627456, 35.547151784636704, 35.774292445833225, 36.00000000000001, 36.2243012354966, 36.44722211636986, 36.66878781743406, 36.88902275745456, 37.107950630558946, 37.3255944359899, 37.54197650630558, 37.75711853412546, 37.971041597512176, 38.18376618407357, 38.39531221386278, 38.605699061149, 38.81494557512609, 39.02307009962184, 39.23009049186606, 39.43602414037196, 39.640887981981436, 39.84469851812158, 40.04747183031659, 40.24922359499622, 40.449969097639624], [0.0, 4.050000000000001, 5.727564927611035, 7.014805770653954, 8.100000000000001, 9.05607530887415, 9.920433458271873, 10.715292809811592, 11.45512985522207, 12.149999999999999, 12.807224523681937, 13.432330400939371, 14.029611541307908, 14.602482665629157, 15.153712416434463, 15.685582552140039, 16.200000000000003, 16.698577783751524, 17.182694782833106, 17.65354072133973, 18.1121506177483, 18.559431564571153, 18.99618382728489, 19.423117669416516, 19.840866916543746, 20.25, 20.65102903005078, 21.044417311961862, 21.430585619623184, 21.809917468894742, 22.182763578959225, 22.54944566946159, 22.91025971044414, 23.26547871847902, 23.61535517412347, 23.960123121553444, 24.299999999999997, 24.63518824770779, 24.965876712024354, 25.292241893513516, 25.614449047363873, 25.93265316160304, 26.246999828551836, 26.5576260234231, 26.864660801878742, 27.168225926622444, 27.468436431657338, 27.76540113162423, 28.059223082615816, 28.35, 28.63782463805518, 28.92278513559855, 29.204965331258315, 29.484445051586103, 29.76130037481562, 30.03560387273744, 30.307424832868925, 30.57682946284654, 30.843881078748833, 31.10864027886786, 31.371165104280077, 31.63151118742195, 31.889731889747836, 32.145878429434774, 32.400000000000006, 32.652143880609124, 32.90235553877564, 33.15067872608342, 33.39715556750305, 33.6418266448182, 33.88473107463006, 34.125906581364255, 34.36538956566621, 34.603215168536, 34.83941733152264, 35.074028853269766, 35.30708144267946, 35.5386057689381, 35.768631508627784, 35.99718739012813, 36.2243012354966, 36.45, 36.67430980945654, 36.89725599553441, 37.118863129142305, 37.3391550520362, 37.5581549067576, 37.775885165009704, 37.99236765456978, 38.20762358482925, 38.42167357104581, 38.6345376573863, 38.84623533883303, 39.05678558202147, 39.26620684507227, 39.474517096476305, 39.68173383308749, 39.88787409727423, 40.09295449327725, 40.29699120281811, 40.5, 40.70199626553961], [0.0, 4.074923312161838, 5.762811813689564, 7.057974213611156, 8.149846624323676, 9.111805529092466, 9.981482855768476, 10.781233695639846, 11.525623627379128, 12.224769936485512, 12.886038956948719, 13.51499167591309, 14.115948427222312, 14.69234494558306, 15.246966911487677, 15.782110125075164, 16.29969324864735, 16.801339232335025, 17.288435441068692, 17.7621789203915, 18.223611058184932, 18.673644529121788, 19.113084523435774, 19.54264567554762, 19.962965711536953, 20.37461656080919, 20.778113485107355, 21.17392264083347, 21.562467391279693, 21.944133612425897, 22.31927418174704, 22.68821279871996, 23.051247254758255, 23.40865224655192, 23.760681808399358, 24.107571424761975, 24.449539872971023, 24.786790837056746, 25.119514326515155, 25.44788792807765, 25.772077913897437, 26.09224022578361, 26.40852135201818, 26.72105911074634, 27.02998335182618, 27.335416587277393, 27.63747455901136, 27.936266751303766, 28.231896854444624, 28.524463185132866, 28.814059068447822, 29.10077318560454, 29.38468989116612, 29.665889502929122, 29.944448567305432, 30.220440102685473, 30.493933822975354, 30.764996343246985, 31.03369136922001, 31.30007987210256, 31.564220250150328, 31.826168478156465, 32.0859782459566, 32.34370108691954, 32.5993864972947, 32.853082047199166, 33.104833483949136, 33.35468482837156, 33.60267846467005, 33.848855224364684, 34.093254464776464, 34.335914142483524, 34.576870882137385, 34.816160040992465, 35.05381576947081, 35.28987106805578, 35.524357840783, 35.75730694557408, 35.98874824163798, 36.21871063414599, 36.447222116369865, 36.674309809456545, 36.900000000000006, 37.124318175557114, 37.347289058243575, 37.56893663653525, 37.789284195390636, 38.008354344801624, 38.22616904687155, 38.44274964151238, 38.65811687084616, 38.87229090238959, 39.08529135109524, 39.297137300317445, 39.50784732176635, 39.71743949450921, 39.925931423073905, 40.13334025470594, 40.33968269582695, 40.54497502773926, 40.74923312161838, 40.95247245283245], [0.0, 4.099695110614935, 5.797844427026306, 7.100880227126775, 8.19939022122987, 9.167196954358515, 10.04216112198963, 10.846773713874555, 11.595688854052613, 12.299085331844802, 12.96437426179914, 13.597150436764316, 14.20176045425355, 14.781660935091157, 15.33965449415338, 15.878050887939613, 16.39878044245974, 16.903475973893652, 17.39353328107892, 17.8701566864983, 18.33439390871703, 18.787163170633292, 19.229274557299348, 19.66144704745813, 20.08432224397926, 20.498475553074673, 20.904425368806482, 21.30264068138033, 21.69354742774911, 22.077533829664944, 22.454954909774365, 22.826136335350316, 23.191377708105225, 23.550955394633146, 23.905124973528167, 24.254123360781357, 24.598170663689604, 24.93747180449534, 25.27221794777815, 25.60258775983397, 25.92874852359828, 26.25085712886343, 26.56906095442592, 26.883498656238917, 27.194300873528633, 27.501590863075535, 27.805485070395733, 28.106093645328944, 28.4035209085071, 28.697865774304542, 28.989222135131534, 29.27767921130362, 29.563321870182314, 29.846230917822776, 30.126483365968888, 30.404152676895965, 30.67930898830676, 30.95201932023176, 31.22234776566298, 31.49035566645762, 31.756101775879227, 32.01964240899638, 32.28103158202971, 32.540321141623664, 32.79756088491948, 33.052798671216934, 33.30608052593399, 33.55745073750388, 33.806951947787304, 34.05462523652257, 34.30051020028711, 34.544645026400254, 34.78706656215784, 35.02781037975397, 35.26691083721396, 35.50440113563388, 35.7403133729966, 35.97467859481166, 36.207526841804594, 36.438887194863675, 36.66878781743406, 36.89725599553441, 37.124318175557114, 37.35, 37.574326341266584, 37.79732133366067, 38.01900840369196, 38.23941029880037, 38.458549114598696, 38.676446320726, 38.893122785397416, 39.10859879872967, 39.32289409491626, 39.53602787332081, 39.74801881855245, 39.9588851195826, 40.16864448795852, 40.377314175165246, 40.584910989184145, 40.79145131029295, 40.996951106149346, 41.201425946197546], [0.0, 4.124318125460256, 5.8326666285670745, 7.143528539874396, 8.248636250920512, 9.22225568936364, 10.102474944289643, 10.911920087683928, 11.665333257134149, 12.372954376380767, 13.042239071570496, 13.6788157382136, 14.287057079748791, 14.870440477672476, 15.431785379534023, 15.973415414368963, 16.497272501841024, 17.004999264922066, 17.497999885701223, 17.977485919894363, 18.44451137872728, 18.900000000000002, 19.344766734184212, 19.77953487825232, 20.204949888579286, 20.62159062730128, 21.02997860198626, 21.430585619623187, 21.823840175367856, 22.21013282265552, 22.58982071642004, 22.963231479911535, 23.330666514268298, 23.692403845958733, 24.048700588597303, 24.399795081106728, 24.745908752761533, 25.08724775657944, 25.424004405285963, 25.75635843825754, 26.08447814314099, 26.40852135201818, 26.728636328851497, 27.04496256237009, 27.3576314764272, 27.666767068090913, 27.972486482256098, 28.274900530329017, 28.574114159497583, 28.870226878221796, 29.163333142835373, 29.453522709516434, 29.740880955344952, 30.025489171702105, 30.30742483286893, 30.586761842339573, 30.863570759068047, 31.137919005611153, 31.40987105990727, 31.67948863223647, 31.946830828737927, 32.2119543027119, 32.47491339480369, 32.73576026305178, 32.99454500368205, 33.2513157634401, 33.50611884417531, 33.758998800319894, 34.00999852984413, 34.259159359213704, 34.50652112282547, 34.75212223735409, 34.995999771402445, 35.23818951081341, 35.47872601996865, 35.71764269937198, 35.954971839788726, 36.190744673189585, 36.42499142072652, 36.65774133794934, 36.88902275745456, 37.118863129142305, 37.347289058243575, 37.574326341266584, 37.800000000000004, 38.0243343136997, 38.2473528495764, 38.46907849169252, 38.689533468368424, 38.90873937819112, 39.12671721471148, 39.34348738990991, 39.55906975650464, 39.77348362917184, 39.98674780474151, 40.19888058142913, 40.40989977715857, 40.61982274702834, 40.82866639996952, 41.036447214640795, 41.24318125460256, 41.44888418281004], [0.0, 4.1487950057818, 5.867282164682384, 7.1859237402020915, 8.2975900115636, 9.276987657639738, 10.162430811572595, 10.976679825885421, 11.734564329364767, 12.446385017345397, 13.119641763401926, 13.759996366278592, 14.371847480404183, 14.958693124735197, 15.523369479594306, 16.068213964221414, 16.5951800231272, 17.105920027873392, 17.60184649404715, 18.08417816766911, 18.553975315279477, 19.01216715684985, 19.45957347939569, 19.896921872490733, 20.32486162314519, 20.743975028909, 21.154786692377687, 21.557771220606273, 21.953359651770842, 22.34194485715154, 22.723886111314673, 23.099512981879077, 23.469128658729534, 23.833012818357652, 24.191424100288106, 24.544602257930357, 24.892770034690795, 25.236134807057915, 25.57489002908908, 25.909216506872614, 26.239283526803852, 26.565249857661797, 26.887264643321384, 27.205468200345308, 27.519992732557185, 27.830962972919206, 28.13849676155427, 28.44270556750887, 28.743694960808366, 29.041565040472598, 29.33641082341192, 29.628322598486744, 29.917386249470393, 30.203683550189705, 30.487292434717784, 30.768287245149025, 31.046738959188612, 31.32271539953074, 31.59628142677553, 31.867499117439383, 32.13642792844283, 32.403124849310444, 32.66764454318677, 32.930039477656265, 33.1903600462544, 33.448654681466635, 33.70496995993321, 33.959350700506626, 34.211840055746784, 34.462479597382426, 34.711309396218404, 34.95836809692352, 35.2036929880943, 35.447320067954365, 35.689284106017034, 35.929618701010455, 36.16835633533822, 36.40552842632558, 36.64116537448012, 36.87529660897658, 37.10795063055895, 37.3391550520362, 37.56893663653525, 37.79732133366067, 38.0243343136997, 38.25, 38.4743420996383, 38.697383632488645, 38.91914695879138, 39.139653805316165, 39.35892529020578, 39.57698194658102, 39.793843744981466, 40.009530114711424, 40.224059964155785, 40.43745170012571, 40.64972324629038, 40.86089206074679, 41.07097515277669, 41.27998909883578, 41.487950057818, 41.69487378563461], [0.0, 4.173128322973067, 5.901694671871801, 7.228070281894055, 8.346256645946134, 9.331398608997477, 10.222035022440494, 11.041059731746769, 11.803389343743602, 12.5193849689192, 13.196590468753662, 13.840700849306732, 14.45614056378811, 15.04642814757044, 15.614416415607726, 16.162456496461175, 16.69251329189227, 17.206248864874645, 17.7050840156154, 18.190244638266964, 18.662797217994953, 19.1236764247882, 19.57370685383839, 20.013620362143378, 20.444070044880988, 20.865641614865336, 21.278862751566404, 21.684210845682166, 22.082119463493537, 22.472983780530793, 22.85716517856053, 23.234995158166054, 23.606778687487203, 23.97279708336097, 24.333310502272397, 24.688560103821366, 25.0387699378384, 25.38414859710682, 25.724890670321614, 26.06117802402647, 26.393180937507324, 26.721059110746342, 27.044962562370095, 27.365032431919385, 27.681401698613463, 27.99419582699242, 28.3035333483295, 28.609526385454203, 28.91228112757622, 29.21189826081147, 29.508473359359005, 29.80209724163721, 30.09285629514088, 30.38083277331285, 30.66610506732148, 30.948747955288923, 31.228832831215453, 31.506427915585736, 31.78159844941724, 32.054406873314626, 32.32491299292235, 32.593174132017275, 32.85924527435163, 33.123179195240304, 33.38502658378454, 33.64483615653374, 33.902654763307254, 34.158527485827015, 34.41249772974929, 34.66460731062736, 34.914896534287486, 35.163404272055345, 35.4101680312308, 35.65522402117255, 35.898607215322436, 36.14035140947028, 36.38048927653393, 36.61905241810607, 36.85607141299789, 37.09157586299078, 37.325594435989906, 37.5581549067576, 37.789284195390636, 38.01900840369196, 38.2473528495764, 38.4743420996383, 38.7, 38.92434970555064, 39.14741370767678, 39.36921386057893, 39.58977140626099, 39.80910699827365, 40.027240724286756, 40.244192127560474, 40.45998022738024, 40.674623538516, 40.888140089761976, 41.100547441609585, 41.311862703102605, 41.52210254792019, 41.73128322973067, 41.93942059685613], [0.0, 4.197320573889967, 5.9359076812228135, 7.269972489631581, 8.394641147779934, 9.385494126576397, 10.281293692916277, 11.10506641132776, 11.871815362445627, 12.591961721669898, 13.273093083377363, 13.92093746843222, 14.539944979263161, 15.133654548720214, 15.704935529953634, 16.2561526813696, 16.789282295559868, 17.30599607072647, 17.807723043668442, 18.29569621523051, 18.770988253152794, 19.23453924584626, 19.687178568804626, 20.129642321710538, 20.562587385832554, 20.986602869449836, 21.402219511069408, 21.809917468894746, 22.21013282265552, 22.60326303877385, 22.98967159400064, 23.369691910677815, 23.743630724891254, 24.111770984313868, 24.47437435359687, 24.83168339037851, 25.183923443339797, 25.53130431450771, 25.874021720637092, 26.212258582579263, 26.546186166754726, 26.875965098950402, 27.201746267473347, 27.523671630071448, 27.84187493686444, 28.15648237972918, 28.46761317708248, 28.775380101746702, 29.079889958526323, 29.381244017229772, 29.67953840611407, 29.974864470085603, 30.267309097440428, 30.556955018456932, 30.843881078748833, 31.128162489938273, 31.409871059907267, 31.68907540462486, 31.96584114332048, 32.24023107857634, 32.5123053627392, 32.78212165190045, 33.04973524856137, 33.31519923398328, 33.578564591119736, 33.8398803189373, 34.09919353885074, 34.356549593927504, 34.61199214145294, 34.865563239391385, 35.11730342722801, 35.36725180163141, 35.615446087336885, 35.86192270361421, 36.10671682665152, 36.34986244815791, 36.59139243046102, 36.831338558352726, 37.069731587914156, 37.30660129253267, 37.54197650630559, 37.775885165009704, 38.008354344801624, 38.23941029880037, 38.46907849169252, 38.697383632488645, 38.92434970555064, 39.15, 39.37435713760925, 39.59744309927095, 39.81927925013209, 40.03988636347511, 40.259284643421076, 40.47749374652537, 40.69453280233108, 40.91042043294104, 41.12517477166511, 41.33881348079551, 41.5513537685597, 41.76281240529666, 41.97320573889967, 42.182549709565926], [0.0, 4.221374183841087, 5.96992462263972, 7.3116345641723655, 8.442748367682174, 9.439279633531365, 10.340212763768452, 11.168706281391772, 11.93984924527944, 12.664122551523258, 13.349157276772194, 14.000714267493644, 14.623269128344731, 15.220381072758988, 15.79493589730582, 16.349311912126456, 16.88549673536435, 17.405171645232343, 17.90977386791916, 18.400543470234787, 18.87855926706273, 19.344766734184212, 19.8, 20.244999382563588, 20.680425527536904, 21.106870919205434, 21.52486933758252, 21.934903692517096, 22.337412562783545, 22.732795692567162, 23.12141864159723, 23.50361674296107, 23.87969849055888, 24.249948453553465, 24.61462979611922, 24.973986465920895, 25.328245103046516, 25.67761671183679, 26.02229813064173, 26.36247332857826, 26.69831455354439, 27.029983351826175, 27.357631476427198, 27.681401698613453, 28.001428534987287, 28.31783890059409, 28.63075269705636, 28.94028334346435, 29.246538256689462, 29.54961928688761, 29.8496231131986, 30.146641603999612, 30.440762145517976, 30.732067942134975, 31.020638291305357, 31.30654883566696, 31.58987179461164, 31.870676177326395, 32.14902797908516, 32.42499036237327, 32.69862382425291, 32.969986351225565, 33.2391335627149, 33.50611884417531, 33.7709934707287, 34.03380672214027, 34.29460598986377, 34.55343687681444, 34.81034329046469, 35.06536752980068, 35.31855036662745, 35.56993112166511, 35.81954773583832, 36.06743683712499, 36.31363380329763, 36.55817282086183, 36.801086940469574, 37.042408129062025, 37.28216731897437, 37.52039445421649, 37.75711853412546, 37.99236765456978, 38.22616904687155, 38.458549114598696, 38.689533468368424, 38.91914695879138, 39.14741370767678, 39.374357137609245, 39.6, 39.824364401707655, 40.04747183031658, 40.26934317815477, 40.489998765127176, 40.709458360435114, 40.927741203247464, 41.14486602238485, 41.36085105507381, 41.575714064823956, 41.789472358478044, 42.002142802480925, 42.21374183841087, 42.424285497813635], [0.0, 4.2452915094254715, 6.00374882885685, 7.353060587265687, 8.490583018850943, 9.492760399378044, 10.398798007462208, 11.231985576913816, 12.0074976577137, 12.735874528276414, 13.424790501158668, 14.080039062445815, 14.706121174531374, 15.306616216525454, 15.884426335250511, 16.441943315800597, 16.981166037701886, 17.50378530489905, 18.01124648657055, 18.50479667545688, 18.985520798756088, 19.454369689095557, 19.912182200853827, 20.359702846554516, 20.797596014924416, 21.226457547127357, 21.646824247450247, 22.05918176179706, 22.463971153827632, 22.86159443258497, 23.252419228974862, 23.63678277600401, 24.0149953154274, 24.38734302871061, 24.754090571055123, 25.115483272276485, 25.471749056552827, 25.82310012372643, 26.169734427387677, 26.511836978979787, 26.849581002317336, 27.18312895897012, 27.51263346173899, 27.83823809079877, 28.16007812489163, 28.478281198134127, 28.792967891483503, 29.104252266636227, 29.412242349062748, 29.7170405659783, 30.018744144284252, 30.31744547286265, 30.613232433050907, 30.906188700646997, 31.196394022386627, 31.48392446948125, 31.768852670501023, 32.05124802562297, 32.331176904034905, 32.60870282608616, 32.88388663160119, 33.15678663561956, 33.42745877269165, 33.69595673074145, 33.96233207540377, 34.22663436565155, 34.48891126144749, 34.74920862408236, 35.0075706097981, 35.264039757237114, 35.518657069208004, 35.77146208921296, 36.0224929731411, 36.27178655649595, 36.51937841749226, 36.76530293632843, 37.00959335091376, 37.25228180930666, 37.49339941909776, 37.732976293952746, 37.971041597512176, 38.20762358482924, 38.44274964151238, 38.676446320726, 38.908739378191115, 39.139653805316165, 39.369213860578924, 39.59744309927094, 39.824364401707655, 40.05, 40.274371503476004, 40.49749992283474, 40.71940569310903, 40.94010869550788, 41.15962827820484, 41.37798327613369, 41.59519202984883, 41.81127240350382, 42.02624180199795, 42.24011718733745, 42.45291509425471, 42.664651645126554], [0.0, 4.2690748412273125, 6.037383539249432, 7.3942545263197434, 8.538149682454625, 9.545941546018392, 10.457055034760026, 11.29491035821002, 12.074767078498864, 12.807224523681935, 13.5, 14.158919450297049, 14.788509052639487, 15.392368238838362, 15.973415414368963, 16.53405576378645, 17.07629936490925, 17.60184649404715, 18.112150617748295, 18.6084658153218, 19.091883092036785, 19.563358607355745, 20.02373591515829, 20.473763698939187, 20.914110069520053, 21.34537420613656, 21.768095920406086, 22.182763578959232, 22.58982071642004, 22.98967159400064, 23.38268590217984, 23.76920276323966, 24.149534156997728, 24.523967868189686, 24.8927700346908, 25.256187360724105, 25.61444904736387, 25.967768483256314, 26.316344730984202, 26.66036383847753, 27.0, 27.335416587277393, 27.666767068090916, 27.994195826992417, 28.317838900594097, 28.63782463805517, 28.954274295861744, 29.267302574716382, 29.577018105278974, 29.883523888591185, 30.186917696247164, 30.487292434717784, 30.784736477676724, 31.079333969697615, 31.37116510428008, 31.66030637880815, 31.946830828737927, 32.23080824304597, 32.5123053627392, 32.791386064026014, 33.0681115275729, 33.34254039511686, 33.614728914569575, 33.88473107463006, 34.1525987298185, 34.4183817167513, 34.682127962395846, 34.94388358497092, 35.2036929880943, 35.461598948721985, 35.71764269937197, 35.97186400508042, 36.22430123549659, 36.474991432487, 36.7239703735857, 36.971272631598715, 37.2169316306436, 37.460979698881346, 37.70344811817615, 37.94436717089903, 38.18376618407357, 38.42167357104581, 38.65811687084616, 38.89312278539742, 39.12671721471149, 39.358925290205775, 39.58977140626099, 39.81927925013209, 40.04747183031658, 40.274371503476004, 40.5, 40.72437844829556, 40.947527397878375, 41.16946684133765, 41.390216235240906, 41.60979452004059, 41.828220139040106, 42.04551105647308, 42.26168477474603, 42.47675835089114, 42.69074841227312, 42.9036711715909], [0.0, 4.292726406376255, 6.070831903454419, 7.435220238836238, 8.58545281275251, 9.598828053465695, 10.51498930099313, 11.357486517711566, 12.141663806908838, 12.878179219128764, 13.57479281609852, 14.23736281760074, 14.870440477672476, 15.477645169727856, 16.06191146781727, 16.62565788172005, 17.17090562550502, 17.69936439536742, 18.212495710363257, 18.71156059766261, 19.19765610693139, 19.671743694954955, 20.134671589077385, 20.587192620656175, 21.02997860198626, 21.46363203188128, 21.88869571262756, 22.305660716508715, 22.71497303542313, 23.11703917027438, 23.512230859703635, 23.900889104801102, 24.283327613817676, 24.659835765876466, 25.030681173312086, 25.39611190714043, 25.75635843825753, 26.111635337527215, 26.46214277038048, 26.80806781549167, 27.14958563219704, 27.486860497335815, 27.82004672893272, 28.14928951146014, 28.47472563520148, 28.79648416039708, 29.114687015319262, 29.42944953613642, 29.740880955344952, 30.04908484463379, 30.354159517272095, 30.65619839445198, 30.95529033945571, 31.251519963035403, 31.544967902979394, 31.83571108048319, 32.12382293563454, 32.40937364405551, 32.692430316512116, 32.97305718310026, 33.2513157634401, 33.52726502415609, 33.80096152478506, 34.0724595531347, 34.34181125101004, 34.609066731132756, 34.87427418599561, 35.13747998932194, 35.39872879073484, 35.65806360418355, 35.915525890622845, 36.17115563539545, 36.42499142072651, 36.677070493702196, 36.927428830071555, 37.17610119418119, 37.42312119532522, 37.6685213407694, 37.91233308568599, 38.15458688021664, 38.39531221386278, 38.6345376573863, 38.87229090238959, 39.10859879872967, 39.34348738990991, 39.57698194658102, 39.80910699827365, 40.03988636347511, 40.26934317815477, 40.49749992283474, 40.72437844829556, 40.95, 41.17438524131235, 41.39755427558493, 41.61952666717871, 41.84032146148019, 42.05995720397252, 42.27845195841494, 42.49582332418093, 42.71208845280221, 42.92726406376256, 43.14136645958262], [0.0, 4.316248370981448, 6.104096984812742, 7.475961476626268, 8.632496741962896, 9.65142476528725, 10.572606112023658, 11.419719786404569, 12.208193969625484, 12.948745112944342, 13.649175799292792, 14.315376348528183, 14.951922953252536, 15.562454819211526, 16.149922600433726, 16.716758058906038, 17.264993483925792, 17.79634793995667, 18.312290954438225, 18.81409046433019, 19.3028495305745, 19.779534878252324, 20.24499938256359, 20.700000000000003, 21.145212224047317, 21.58124185490724, 22.008634669147472, 22.427884429878805, 22.839439572809138, 23.243708826260928, 23.641065965814654, 24.031853861073643, 24.416387939250967, 24.794959165120645, 25.167836617397217, 25.535269726399996, 25.897490225888685, 26.25471386246668, 26.60714189837007, 26.954962437369492, 27.298351598585583, 27.63747455901136, 27.972486482256098, 28.303533348329495, 28.630752697056366, 28.95427429586174, 29.27422074112307, 29.59070800099248, 29.903845906505072, 30.213738596870137, 30.52048492406371, 30.82417882117868, 31.124909638423052, 31.422762450172968, 31.717818336070977, 32.01015463880174, 32.29984520086745, 32.586960582417014, 32.87156826194942, 33.15373282150895, 33.433516117812076, 33.710977440590476, 33.98617365929857, 34.259159359213704, 34.529986967851585, 34.79870687252617, 35.06536752980068, 35.33001556750294, 35.59269587991334, 35.853451716675764, 36.11232476592998, 36.36935523211815, 36.62458190887645, 36.87804224738618, 37.129772420525285, 37.37980738313134, 37.62818092866038, 37.87492574250147, 38.120073452185274, 38.36365467470481, 38.605699061149, 38.84623533883303, 39.08529135109524, 39.322894094916265, 39.55906975650465, 39.793843744981466, 40.027240724286756, 40.259284643421076, 40.48999876512718, 40.71940569310903, 40.947527397878375, 41.17438524131235, 41.400000000000006, 41.624391887449846, 41.847580575225614, 42.06958521307288, 42.29042444809463, 42.51011644303036, 42.72867889368919, 42.94612904558455, 43.16248370981448, 43.37775927822921], [0.0, 4.33964284244683, 6.137181763643635, 7.516481889820531, 8.67928568489366, 9.703736393781522, 10.629910629915946, 11.481615739955767, 12.27436352728727, 13.018928527340488, 13.723155613779216, 14.392967032547531, 15.032963779641062, 15.64680478564234, 16.237456697401846, 16.807364457284788, 17.35857136978732, 17.892805816863937, 18.411545290930906, 18.916064601285335, 19.407472787563044, 19.88674181458592, 20.354729180217557, 20.812195943724923, 21.25982125983189, 21.698214212234152, 22.127923535659647, 22.549445669461594, 22.963231479911535, 23.369691910677815, 23.76920276323966, 24.16210876558584, 24.54872705457454, 24.929350172036177, 25.304248655117192, 25.673673286072642, 26.037857054680977, 26.39701687691244, 26.75135510586333, 27.101060864844392, 27.446311227558432, 27.78727226627328, 28.124099985599543, 28.456941156772277, 28.785934065095063, 29.111209181344563, 29.4328897663821, 29.751092416918073, 30.065927559282123, 30.377499897127812, 30.68590881821818, 30.991248764772294, 31.29360957128468, 31.59307677324259, 31.88973188974784, 32.183652682689704, 32.47491339480369, 32.763584968681315, 33.049735248561376, 33.3334291665289, 33.614728914569575, 33.89369410377098, 34.17038191182534, 34.4448472198673, 34.71714273957464, 34.9873191313653, 35.25542511444161, 35.5215075693586, 35.785611633727875, 36.047780791610464, 36.30805695709976, 36.56648055254977, 36.82309058186181, 37.077924699206136, 37.33101927352105, 37.58240944910265, 37.83212920257067, 38.08021139647206, 38.32668782976166, 38.57158928537947, 38.81494557512609, 39.05678558202147, 39.297137300317445, 39.53602787332081, 39.77348362917184, 40.009530114711424, 40.244192127560474, 40.47749374652537, 40.709458360435114, 40.94010869550788, 41.16946684133765, 41.39755427558493, 41.624391887449846, 41.85, 42.074398391420885, 42.29760631525146, 42.51964251966378, 42.74052526584109, 42.96027234550545, 43.17890109764259, 43.396428424468304, 43.61287080667817], [0.0, 4.362911871674696, 6.17008914036094, 7.556785030686, 8.725823743349393, 9.755767524905462, 10.686907878334127, 11.543179804542595, 12.34017828072188, 13.088735615024088, 13.796738745080303, 14.470141671732177, 15.113570061372, 15.730702463653682, 16.32452143249535, 16.89748501996673, 17.451647486698786, 17.988746482176015, 18.51026742108282, 19.017491948203897, 19.511535049810924, 19.99337390237076, 20.463870601623736, 20.923790287612807, 21.373815756668254, 21.814559358373483, 22.2465727697549, 22.670355092058003, 23.08635960908519, 23.494999467971905, 23.896652485233155, 24.291665237278405, 24.68035656144376, 25.06302056815978, 25.43992924518463, 25.81133471945998, 26.177471230048177, 26.53855685601612, 26.894795035471084, 27.24637590579709, 27.593477490160605, 27.936266751303766, 28.274900530329017, 28.609526385454195, 28.940283343464355, 29.26730257471638, 29.590708000992475, 29.91061684419096, 30.227140122744, 30.540383101722878, 30.850445701804702, 31.157422871604776, 31.461404927307363, 31.762477863038335, 32.06072363500238, 32.356220422045595, 32.6490428649907, 32.93926228682118, 33.226946895554526, 33.51216197143956, 33.79497003993346, 34.075431031756594, 34.35360243118617, 34.62953941362778, 34.90329497339757, 35.17492004255305, 35.44446360152739, 35.71197278224769, 35.97749296435203, 36.241067865061595, 36.502739623211845, 36.76254887790019, 37.02053484216564, 37.27673537207893, 37.53118703158748, 37.78392515343, 38.034983896407795, 38.28439629927577, 38.53219433149377, 38.77840894105894, 39.02307009962185, 39.26620684507227, 39.50784732176635, 39.74801881855245, 39.98674780474152, 40.224059964155785, 40.45998022738024, 40.69453280233108, 40.92774120324747, 41.15962827820485, 41.39021623524091, 41.61952666717872, 41.847580575225614, 42.074398391420885, 42.300000000000004, 42.52440475773882, 42.74763151333651, 42.969698625892185, 43.19062398252658, 43.41042501519653, 43.629118716746966, 43.84672165624245], [0.0, 4.386057455164034, 6.202821938440599, 7.59687435726036, 8.772114910328067, 9.807522622966516, 10.74360274768199, 11.604417262404864, 12.405643876881198, 13.1581723654921, 13.869931506680196, 14.546906887720153, 15.19374871452072, 15.81415505172502, 16.41112427592942, 16.987127479359184, 17.544229820656135, 18.084178167669105, 18.608465815321797, 19.1183812076232, 19.615045245933032, 20.099440290714565, 20.57243301119243, 21.03479260653644, 21.48720549536398, 21.930287275820167, 22.364592551620518, 22.79062307178108, 23.208834524809728, 23.619642249619275, 24.023426067070446, 24.420534392187243, 24.811287753762397, 25.195981822504955, 25.57489002908908, 25.948265838009288, 26.3163447309842, 26.679345944006947, 27.03747399443964, 27.390920028359766, 27.73986301336039, 28.084470797933864, 28.42490105523676, 28.761302126294623, 29.093813775440307, 29.42256786889954, 29.747688985869136, 30.0692949701186, 30.38749742904144, 30.702402186148237, 31.014109692202997, 31.32271539953074, 31.62831010345004, 31.930980254292226, 32.23080824304597, 32.52787266330216, 32.82224855185884, 33.114007610073415, 33.40321840781215, 33.68994657164062, 33.97425495871837, 34.256203817702854, 34.53585093782981, 34.81325178721459, 35.08845964131227, 35.36152570237885, 35.63249921069247, 35.90142754821874, 36.16835633533821, 36.43332952119528, 36.6963894681752, 36.9575770309689, 37.21693163064359, 37.47449132409938, 37.73029286925825, 37.98437178630179, 38.2367624152464, 38.48749797012011, 38.73661058998322, 38.98413138701438, 39.230090491866065, 39.474517096476305, 39.71743949450921, 39.9588851195826, 40.19888058142913, 40.43745170012571, 40.674623538516, 40.91042043294104, 41.14486602238486, 41.3779832761337, 41.60979452004059, 41.840321461480194, 42.06958521307288, 42.29760631525146, 42.524404757738814, 42.74999999999999, 42.97441099072796, 43.197656186418264, 43.41975356908419, 43.64072066316046, 43.86057455164033, 44.07933189148856], [0.0, 4.409081537009721, 6.235382907247958, 7.636753236814714, 8.818163074019441, 9.859006035092992, 10.8, 11.665333257134149, 12.470765814495916, 13.22724461102916, 13.942740046346701, 14.623269128344731, 15.273506473629428, 15.897169559390125, 16.497272501841024, 17.076299364909246, 17.636326148038883, 18.17910888905174, 18.706148721743876, 19.21874085365636, 19.718012070185985, 20.204949888579286, 20.680425527536904, 21.145212224047317, 21.6, 22.045407685048605, 22.481992794234234, 22.910259710444144, 23.330666514268298, 23.743630724891254, 24.149534156997728, 24.54872705457454, 24.941531628991832, 25.328245103046523, 25.709142342754262, 26.08447814314099, 26.45448922205832, 26.819395966352413, 27.1794039669747, 27.534705373401042, 27.885480092693403, 28.23189685444462, 28.57411415949758, 28.912281127576215, 29.246538256689462, 29.577018105278967, 29.90384590650507, 30.227140122744, 30.547012947258857, 30.863570759068047, 31.176914536239792, 31.487140232164627, 31.79433911878025, 32.09859810022862, 32.400000000000006, 32.69862382425291, 32.99454500368205, 33.287835616032474, 33.578564591119736, 33.8667979000082, 34.15259872981849, 34.43602764547618, 34.71714273957464, 34.995999771402445, 35.272652296077766, 35.5471517846367, 35.81954773583832, 36.089887780374156, 36.35821777810348, 36.62458190887645, 36.889022757454555, 37.15158139299053, 37.41229744348775, 37.671209165621434, 37.92835351026986, 38.18376618407357, 38.43748170731272, 38.689533468368424, 38.93995377501109, 39.18877390273904, 39.43602414037197, 39.681733833087485, 39.925931423073905, 40.16864448795852, 40.40989977715857, 40.64972324629038, 40.88814008976197, 41.12517477166511, 41.36085105507381, 41.59519202984884, 41.828220139040106, 42.05995720397252, 42.29042444809463, 42.51964251966378, 42.74763151333651, 42.974410990727954, 43.2, 43.424417094533354, 43.64768035073571, 43.86980738503419, 44.09081537009721, 44.31072105032822], [0.0, 4.431986010808248, 6.267774724732854, 7.676424949154392, 8.863972021616496, 9.91022199549536, 10.856104273633338, 11.725932798715846, 12.535549449465709, 13.29595803242474, 14.015170352157694, 14.69923467395497, 15.352849898308785, 15.979752814108235, 16.582973195419452, 17.165008010484588, 17.72794404323299, 18.27354645382226, 18.80332417419856, 19.318579140299114, 19.82044399099072, 20.30991137351417, 20.787857032411978, 21.25505822151518, 21.712208547266677, 22.159930054041237, 22.5987831530815, 23.029274847463178, 23.45186559743169, 23.866975091117016, 24.27498712667012, 24.676253767539354, 25.071098898931417, 25.45982128766815, 25.84269722765022, 26.219982837522988, 26.59191606484948, 26.95871844135029, 27.320596625988973, 27.677743766427213, 28.03034070431539, 28.378557045769615, 28.722552115019308, 29.06247580644154, 29.39846934790994, 29.730665986486073, 30.059191605896526, 30.384165283910637, 30.70569979661757, 31.023902075657734, 31.338873623664274, 31.650710892490242, 31.95950562821647, 32.26534518643804, 32.56831282090002, 32.86848794818527, 33.165946390838904, 33.46076060103835, 33.75299986667852, 34.04273050153292, 34.330016020969175, 34.61491730453794, 34.89749274661433, 35.17779839614754, 35.45588808646598, 35.731813555989575, 36.00562456061553, 36.277368978469205, 36.54709290764452, 36.81484075749887, 37.0806553340148, 37.34457791969271, 37.60664834839712, 37.86690507554057, 38.12538524395524, 38.38212474577196, 38.63715828059823, 38.89051941026245, 39.14224061036875, 39.39235331888665, 39.64088798198144, 39.88787409727423, 40.13334025470594, 40.377314175165246, 40.61982274702834, 40.86089206074679, 41.100547441609585, 41.33881348079551, 41.575714064823956, 41.81127240350382, 42.04551105647308, 42.27845195841494, 42.51011644303036, 42.740525265841086, 42.96969862589218, 43.197656186418264, 43.424417094533354, 43.650000000000006, 43.87442307312998, 44.09770402186491, 44.31986010808247, 44.540908163170634], [0.0, 4.4547727214752495, 6.3, 7.715892689767012, 8.909545442950499, 9.961174629530396, 10.911920087683928, 11.786220768337916, 12.6, 13.364318164425747, 14.087228258248675, 14.774809643443804, 15.431785379534023, 16.06191146781727, 16.66823325970692, 17.25326056141273, 17.819090885900998, 18.367498468762694, 18.9, 19.417904109352275, 19.92234925906079, 20.41433319998476, 20.894736179239022, 21.364339446844596, 21.823840175367856, 22.273863607376246, 22.714973035423135, 23.147678069301037, 23.572441536675832, 23.98968528347131, 24.399795081106724, 24.803124803137205, 25.2, 25.590720974603276, 25.975565441391264, 26.35479083582338, 26.728636328851493, 27.097324591184275, 27.461063344306243, 27.82004672893272, 28.17445651649735, 28.524463185132863, 28.870226878221793, 29.211898260811463, 29.54961928688761, 29.88352388859118, 30.213738596870133, 30.540383101722874, 30.863570759068047, 31.18340905032675, 31.5, 31.81344055584055, 32.12382293563454, 32.43123494410906, 32.73576026305178, 33.037478717359775, 33.33646651941384, 33.63279649389863, 33.92653828494738, 34.217758547280674, 34.50652112282546, 34.792887204139866, 35.07691548582914, 35.358662305013745, 35.638181771801996, 35.915525890622845, 36.19074467318958, 36.463886243789204, 36.73499693752539, 37.0041213920828, 37.27130263352758, 37.536582156610905, 37.8, 38.061594816822904, 38.32140394087878, 38.57946344883506, 38.83580821870455, 39.0904719848712, 39.34348738990992, 39.594886033426086, 39.84469851812158, 40.09295449327725, 40.33968269582695, 40.584910989184145, 40.82866639996952, 41.07097515277669, 41.311862703102605, 41.55135376855969, 41.789472358478044, 42.02624180199795, 42.26168477474602, 42.49582332418093, 42.72867889368919, 42.960272345505444, 43.19062398252658, 43.41975356908419, 43.64768035073571, 43.87442307312998, 44.1, 44.324428930331415, 44.54772721475249, 44.769911771188475], [0.0, 4.47744346697979, 6.33206127576163, 7.75515957282634, 8.95488693395958, 10.011867957579147, 10.967451846258548, 11.846201922979366, 12.66412255152326, 13.43233040093937, 14.158919450297047, 14.850000000000003, 15.51031914565268, 16.14365200318689, 16.75305942208766, 17.341063981197923, 17.90977386791916, 18.460972347089413, 18.99618382728489, 19.516723597981297, 20.023735915158294, 20.518223607320397, 21.001071401240466, 21.47306452279227, 21.934903692517096, 22.387217334898953, 22.830571609138484, 23.26547871847902, 23.692403845958733, 24.111770984313868, 24.523967868189683, 24.929350172036177, 25.32824510304652, 25.720954492397833, 26.107757467848522, 26.48891277497059, 26.86466080187874, 27.235225352473222, 27.60081520535218, 27.961625489230777, 28.317838900594094, 28.66962678515366, 29.017150101276318, 29.360560280757586, 29.700000000000006, 30.035603872737433, 30.367499073845384, 30.6958059024356, 31.02063829130536, 31.342104268858535, 31.660306378808155, 31.975342062282937, 32.28730400637378, 32.59628046265402, 32.902355538775645, 33.20560946587188, 33.50611884417532, 33.80395686898207, 34.09919353885075, 34.39189584771389, 34.682127962395846, 34.96995138686927, 35.25542511444161, 35.5386057689381, 35.81954773583832, 36.09830328422653, 36.374922680330194, 36.649454293345215, 36.921944694178826, 37.19243874768096, 37.460979698881346, 37.72760925370173, 37.99236765456978, 38.25529375132284, 38.516425067755186, 38.7757978641317, 39.033447195962594, 39.28940696930918, 39.5437099928674, 39.796388027055926, 40.04747183031659, 40.29699120281811, 40.54497502773926, 40.79145131029295, 41.036447214640795, 41.27998909883577, 41.52210254792019, 41.76281240529666, 42.00214280248093, 42.24011718733745, 42.47675835089114, 42.71208845280221, 42.94612904558454, 43.17890109764259, 43.41042501519652, 43.64072066316046, 43.86980738503419, 44.09770402186491, 44.324428930331415, 44.550000000000004, 44.774434669797905, 44.997749943747195], [0.0, 4.500000000000001, 6.363961030678928, 7.794228634059949, 9.000000000000002, 10.062305898749056, 11.022703842524303, 11.905880899790658, 12.727922061357855, 13.5, 14.230249470757707, 14.924811556599302, 15.588457268119898, 16.224980739587952, 16.837458240482736, 17.428425057933378, 18.000000000000004, 18.553975315279473, 19.091883092036785, 19.615045245933032, 20.124611797498112, 20.621590627301284, 21.106870919205438, 21.58124185490724, 22.045407685048605, 22.5, 22.945587811167535, 23.382685902179848, 23.811761799581316, 24.23324163210527, 24.647515087732476, 25.0549396327351, 25.45584412271571, 25.850531909421132, 26.239283526803856, 26.622359023948274, 27.0, 27.37243138634199, 27.739863013360395, 28.1024909927928, 28.460498941515414, 28.814059068447822, 29.163333142835373, 29.508473359359, 29.849623113198604, 30.18691769624716, 30.52048492406371, 30.850445701804702, 31.176914536239796, 31.500000000000004, 31.819805153394643, 32.13642792844283, 32.449961479175904, 32.76049450176234, 33.06811152757291, 33.37289319193049, 33.67491648096547, 33.974254958718376, 34.270978976387596, 34.565155865408734, 34.856850115866756, 35.14612354157995, 35.43303543305315, 35.71764269937197, 36.00000000000001, 36.28015986734347, 36.55817282086182, 36.834087473426024, 37.107950630558946, 37.379807383131336, 37.649701194033405, 37.91767397929362, 38.18376618407357, 38.4480168539289, 38.71046370169182, 38.97114317029974, 39.230090491866065, 39.48733974326455, 39.74292389847532, 39.99687487792015, 40.249223594996224, 40.50000000000001, 40.74923312161838, 40.996951106149346, 41.24318125460257, 41.487950057818, 41.73128322973067, 41.97320573889967, 42.213741838410876, 42.45291509425472, 42.69074841227312, 42.92726406376256, 43.16248370981448, 43.396428424468304, 43.629118716746966, 43.86057455164033, 44.09081537009721, 44.31986010808248, 44.5477272147525, 44.774434669797905, 45.0, 45.22444029504401], [0.0, 4.522444029504402, 6.395701681598354, 7.833102833488146, 9.044888059008803, 10.112492274409906, 11.077680262582055, 11.9652622202775, 12.791403363196707, 13.567332088513202, 14.301223723863634, 14.999249981249067, 15.666205666976293, 16.305903838794098, 16.92143610926685, 17.515350410425707, 18.089776118017607, 18.646514419590595, 19.18710504479506, 19.71287650242856, 20.224984548819812, 20.72444209140502, 21.21214274890682, 21.688879639114607, 22.15536052516411, 22.612220147522006, 23.060030355574128, 23.49930850046444, 23.930524440555, 24.35410642992266, 24.770446100141193, 25.179902700368007, 25.582806726393414, 25.97946304294991, 26.370153583170506, 26.75513969315055, 27.134664177026405, 27.50895308804027, 27.878217303120373, 28.242653912123775, 28.60244744772727, 28.95777097775311, 29.30878707828081, 29.65564870307173, 29.998499962498133, 30.337476823229714, 30.672707738313555, 31.004314215928083, 31.332411333952585, 31.65710820653081, 31.97850840799177, 32.296710358796616, 32.611807677588196, 32.92388950291263, 33.23304078774617, 33.53934256958536, 33.8428722185337, 34.14370366553693, 34.44190761267443, 34.7375517272015, 35.030700820851415, 35.32141701574273, 35.609759898095355, 35.8957866608325, 36.179552236035214, 36.46110941811837, 36.740508978510356, 37.017799772541856, 37.29302883918119, 37.56624149419263, 37.83748141724024, 38.10679073341129, 38.37421008959012, 38.63977872607451, 38.90353454379178, 39.165514167440726, 39.42575300485712, 39.684285302875246, 39.941144199934996, 40.196361775663235, 40.449969097639624, 40.70199626553961, 40.952472452832446, 41.201425946197546, 41.44888418281004, 41.69487378563461, 41.93942059685613, 42.182549709565926, 42.42428549781364, 42.66465164512656, 42.9036711715909, 43.14136645958262, 43.37775927822921, 43.61287080667817, 43.84672165624245, 44.07933189148856, 44.31072105032822, 44.54090816317064, 44.769911771188475, 44.997749943747195, 45.22444029504401, 45.45000000000001]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"A = 5.0\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.5, 0.7071067811865476, 0.8660254037844388, 1.0, 1.118033988749895, 1.2247448713915892, 1.3228756555322954, 1.4142135623730951, 1.5, 1.5811388300841898, 1.6583123951777003, 1.7320508075688776, 1.8027756377319948, 1.8708286933869707, 1.9364916731037085, 2.0, 2.0615528128088303, 2.121320343559643, 2.179449471770337, 2.23606797749979, 2.2912878474779204, 2.345207879911715, 2.39791576165636, 2.4494897427831783, 2.5000000000000004, 2.5495097567963927, 2.5980762113533165, 2.6457513110645907, 2.6925824035672523, 2.73861278752583, 2.783882181415011, 2.8284271247461903, 2.8722813232690148, 2.9154759474226504, 2.958039891549808, 3.0, 3.04138126514911, 3.0822070014844885, 3.1224989991991996, 3.1622776601683795, 3.2015621187164243, 3.2403703492039306, 3.278719262151, 3.3166247903554007, 3.3541019662496843, 3.391164991562634, 3.4278273002005224, 3.4641016151377553, 3.5, 3.5355339059327378, 3.5707142142714257, 3.6055512754639896, 3.6400549446402595, 3.6742346141747677, 3.708099243547832, 3.7416573867739413, 3.7749172176353754, 3.8078865529319543, 3.840572873934304, 3.872983346207417, 3.905124837953327, 3.9370039370059056, 3.9686269665968856, 4.0, 4.031128874149275, 4.06201920231798, 4.092676385936225, 4.123105625617661, 4.153311931459037, 4.183300132670378, 4.2130748865881795, 4.242640687119286, 4.272001872658766, 4.301162633521313, 4.330127018922194, 4.358898943540674, 4.387482193696061, 4.415880433163924, 4.444097208657794, 4.47213595499958, 4.5, 4.527692569068709, 4.55521678957215, 4.582575694955841, 4.6097722286464435, 4.636809247747852, 4.663689526544408, 4.69041575982343, 4.716990566028302, 4.743416490252569, 4.769696007084728, 4.79583152331272, 4.8218253804964775, 4.847679857416329, 4.873397172404482, 4.898979485566357, 4.924428900898053, 4.949747468305833, 4.9749371855331, 5.000000000000001, 5.024937810560446], [0.0, 0.7071067811865476, 1.0, 1.2247448713915892, 1.4142135623730951, 1.5811388300841898, 1.7320508075688774, 1.8708286933869707, 2.0, 2.1213203435596424, 2.23606797749979, 2.3452078799117153, 2.4494897427831783, 2.5495097567963927, 2.6457513110645907, 2.7386127875258306, 2.8284271247461903, 2.91547594742265, 3.0, 3.0822070014844885, 3.1622776601683795, 3.24037034920393, 3.3166247903554, 3.391164991562634, 3.464101615137755, 3.5355339059327378, 3.6055512754639896, 3.6742346141747677, 3.7416573867739413, 3.8078865529319543, 3.8729833462074166, 3.9370039370059056, 4.0, 4.06201920231798, 4.123105625617661, 4.183300132670378, 4.242640687119285, 4.301162633521313, 4.358898943540674, 4.415880433163924, 4.47213595499958, 4.527692569068708, 4.582575694955841, 4.636809247747852, 4.690415759823431, 4.743416490252568, 4.795831523312719, 4.847679857416329, 4.898979485566357, 4.949747468305833, 5.0, 5.04975246918104, 5.099019513592785, 5.1478150704935, 5.196152422706632, 5.244044240850758, 5.291502622129181, 5.338539126015656, 5.385164807134504, 5.431390245600108, 5.477225575051661, 5.52268050859363, 5.5677643628300215, 5.612486080160911, 5.656854249492381, 5.70087712549569, 5.744562646538029, 5.787918451395113, 5.8309518948453, 5.873670062235366, 5.916079783099616, 5.958187643906492, 6.0, 6.041522986797286, 6.082762530298219, 6.123724356957945, 6.164414002968977, 6.2048368229954285, 6.244997998398398, 6.284902544988268, 6.324555320336759, 6.363961030678928, 6.403124237432849, 6.442049363362562, 6.48074069840786, 6.519202405202648, 6.557438524302, 6.59545297913646, 6.6332495807108, 6.670832032063166, 6.7082039324993685, 6.745368781616021, 6.782329983125268, 6.819090848492928, 6.855654600401045, 6.89202437604511, 6.92820323027551, 6.96419413859206, 7.0, 7.035623639735144, 7.0710678118654755, 7.106335201775948], [0.0, 0.8660254037844388, 1.2247448713915892, 1.5000000000000004, 1.7320508075688776, 1.9364916731037087, 2.121320343559643, 2.2912878474779204, 2.4494897427831783, 2.5980762113533165, 2.738612787525831, 2.872281323269015, 3.000000000000001, 3.1224989991992, 3.2403703492039306, 3.354101966249685, 3.4641016151377553, 3.570714214271425, 3.6742346141747677, 3.774917217635376, 3.8729833462074175, 3.968626966596887, 4.06201920231798, 4.153311931459038, 4.242640687119286, 4.3301270189221945, 4.415880433163925, 4.500000000000002, 4.582575694955841, 4.663689526544409, 4.743416490252569, 4.821825380496478, 4.898979485566357, 4.9749371855331015, 5.04975246918104, 5.1234753829798, 5.196152422706633, 5.267826876426371, 5.3385391260156565, 5.408326913195985, 5.477225575051662, 5.54526825320471, 5.612486080160914, 5.6789083458002745, 5.74456264653803, 5.809475019311125, 5.873670062235366, 5.937171043518959, 6.000000000000002, 6.062177826491071, 6.123724356957946, 6.184658438426492, 6.2449979983984, 6.304760106459248, 6.363961030678929, 6.422616289332566, 6.480740698407861, 6.538348415311011, 6.595452979136461, 6.652067347825036, 6.70820393249937, 6.763874629234342, 6.819090848492929, 6.87386354243376, 6.9282032302755105, 6.982120021884471, 7.035623639735145, 7.088723439378914, 7.14142842854285, 7.1937472849690804, 7.24568837309472, 7.297259759663214, 7.348469228349535, 7.399324293474372, 7.44983221287567, 7.500000000000001, 7.549834435270752, 7.599342076785333, 7.6485292703891785, 7.697402159170328, 7.745966692414835, 7.794228634059949, 7.842193570679063, 7.8898669190297515, 7.937253933193774, 7.984359711335657, 8.031189202104507, 8.077747210701757, 8.12403840463596, 8.170067319184096, 8.215838362577493, 8.261355820929154, 8.306623862918077, 8.351646544245034, 8.396427811873334, 8.440971508067067, 8.485281374238571, 8.529361054615991, 8.573214099741126, 8.616843969807045, 8.660254037844389, 8.703447592764606], [0.0, 1.0, 1.4142135623730951, 1.7320508075688776, 2.0, 2.23606797749979, 2.4494897427831783, 2.6457513110645907, 2.8284271247461903, 3.0, 3.1622776601683795, 3.3166247903554007, 3.4641016151377553, 3.6055512754639896, 3.7416573867739413, 3.872983346207417, 4.0, 4.123105625617661, 4.242640687119286, 4.358898943540674, 4.47213595499958, 4.582575694955841, 4.69041575982343, 4.79583152331272, 4.898979485566357, 5.000000000000001, 5.099019513592785, 5.196152422706633, 5.291502622129181, 5.385164807134505, 5.47722557505166, 5.567764362830022, 5.656854249492381, 5.7445626465380295, 5.830951894845301, 5.916079783099616, 6.0, 6.08276253029822, 6.164414002968977, 6.244997998398399, 6.324555320336759, 6.4031242374328485, 6.480740698407861, 6.557438524302, 6.633249580710801, 6.7082039324993685, 6.782329983125268, 6.855654600401045, 6.9282032302755105, 7.0, 7.0710678118654755, 7.141428428542851, 7.211102550927979, 7.280109889280519, 7.348469228349535, 7.416198487095664, 7.483314773547883, 7.549834435270751, 7.615773105863909, 7.681145747868608, 7.745966692414834, 7.810249675906654, 7.874007874011811, 7.937253933193771, 8.0, 8.06225774829855, 8.12403840463596, 8.18535277187245, 8.246211251235321, 8.306623862918075, 8.366600265340756, 8.426149773176359, 8.485281374238571, 8.544003745317532, 8.602325267042627, 8.660254037844387, 8.717797887081348, 8.774964387392123, 8.831760866327848, 8.888194417315589, 8.94427190999916, 9.0, 9.055385138137417, 9.1104335791443, 9.165151389911681, 9.219544457292887, 9.273618495495704, 9.327379053088816, 9.38083151964686, 9.433981132056603, 9.486832980505138, 9.539392014169456, 9.59166304662544, 9.643650760992955, 9.695359714832659, 9.746794344808963, 9.797958971132713, 9.848857801796106, 9.899494936611665, 9.9498743710662, 10.000000000000002, 10.049875621120892], [0.0, 1.118033988749895, 1.5811388300841898, 1.936491673103709, 2.23606797749979, 2.5000000000000004, 2.738612787525831, 2.958039891549808, 3.1622776601683795, 3.3541019662496847, 3.5355339059327378, 3.7080992435478324, 3.872983346207418, 4.0311288741492755, 4.183300132670378, 4.330127018922194, 4.47213595499958, 4.6097722286464435, 4.74341649025257, 4.8733971724044824, 5.000000000000001, 5.1234753829798, 5.244044240850758, 5.361902647381805, 5.477225575051662, 5.590169943749475, 5.700877125495691, 5.809475019311127, 5.916079783099616, 6.020797289396149, 6.123724356957945, 6.224949798994366, 6.324555320336759, 6.4226162893325665, 6.519202405202649, 6.614378277661477, 6.708203932499369, 6.800735254367723, 6.892024376045112, 6.982120021884472, 7.0710678118654755, 7.158910531638177, 7.245688373094721, 7.33143914930759, 7.416198487095665, 7.499999999999999, 7.582875444051551, 7.664854858377947, 7.745966692414836, 7.826237921249264, 7.905694150420949, 7.9843597113356575, 8.062257748298551, 8.139410298049855, 8.215838362577493, 8.2915619758885, 8.366600265340756, 8.440971508067067, 8.514693182963201, 8.587782018658833, 8.660254037844387, 8.732124598286491, 8.803408430829505, 8.874119674649425, 8.94427190999916, 9.013878188659973, 9.082951062292477, 9.151502608861565, 9.219544457292887, 9.287087810503357, 9.354143466934854, 9.420721840708387, 9.48683298050514, 9.552486587271401, 9.617692030835672, 9.682458365518544, 9.746794344808965, 9.810708435174293, 9.87420882906575, 9.937303457175897, 10.000000000000002, 10.062305898749054, 10.124228365658295, 10.185774393731682, 10.2469507659596, 10.307764064044152, 10.36822067666386, 10.428326807307107, 10.488088481701515, 10.547511554864494, 10.606601717798213, 10.665364503850771, 10.72380529476361, 10.781929326423914, 10.839741694339402, 10.897247358851683, 10.954451150103324, 11.011357772772621, 11.067971810589329, 11.124297730643496, 11.18033988749895, 11.236102527122117], [0.0, 1.2247448713915892, 1.7320508075688774, 2.121320343559643, 2.4494897427831783, 2.7386127875258306, 3.0, 3.24037034920393, 3.464101615137755, 3.6742346141747673, 3.872983346207417, 4.062019202317981, 4.242640687119286, 4.415880433163924, 4.58257569495584, 4.743416490252569, 4.898979485566357, 5.049752469181039, 5.196152422706632, 5.3385391260156565, 5.477225575051661, 5.612486080160913, 5.744562646538029, 5.873670062235366, 6.0, 6.123724356957946, 6.244997998398399, 6.363961030678929, 6.48074069840786, 6.595452979136461, 6.7082039324993685, 6.8190908484929285, 6.92820323027551, 7.035623639735146, 7.14142842854285, 7.24568837309472, 7.3484692283495345, 7.449832212875671, 7.549834435270751, 7.6485292703891785, 7.745966692414834, 7.842193570679061, 7.937253933193773, 8.031189202104505, 8.124038404635963, 8.215838362577491, 8.306623862918075, 8.396427811873334, 8.485281374238571, 8.573214099741124, 8.660254037844387, 8.746427842267952, 8.831760866327848, 8.916277250063505, 9.000000000000002, 9.082951062292477, 9.16515138991168, 9.246621004453466, 9.327379053088816, 9.40744386111339, 9.486832980505138, 9.565563234854496, 9.643650760992955, 9.72111104761179, 9.797958971132713, 9.87420882906575, 9.9498743710662, 10.024968827881711, 10.099504938362077, 10.173494974687904, 10.246950765959598, 10.319883720275147, 10.392304845413264, 10.464224768228176, 10.535653752852738, 10.606601717798213, 10.677078252031313, 10.747092630102339, 10.816653826391969, 10.885770528538622, 10.954451150103322, 11.022703842524303, 11.09053650640942, 11.157956802210698, 11.224972160321826, 11.291589790636214, 11.357816691600547, 11.423659658795863, 11.489125293076057, 11.554220008291342, 11.618950038622252, 11.683321445547923, 11.747340124470732, 11.811011811017718, 11.874342087037919, 11.937336386313321, 12.0, 12.06233808181482, 12.124355652982143, 12.186057606953941, 12.247448713915892, 12.308533625091172], [0.0, 1.3228756555322954, 1.8708286933869709, 2.2912878474779204, 2.6457513110645907, 2.958039891549808, 3.24037034920393, 3.5, 3.7416573867739418, 3.968626966596886, 4.183300132670378, 4.387482193696062, 4.582575694955841, 4.769696007084729, 4.949747468305833, 5.123475382979799, 5.291502622129181, 5.454356057317857, 5.612486080160912, 5.766281297335398, 5.916079783099616, 6.062177826491071, 6.2048368229954285, 6.34428877022476, 6.48074069840786, 6.614378277661477, 6.745368781616022, 6.873863542433761, 7.0, 7.123903424387504, 7.245688373094719, 7.365459931328118, 7.4833147735478835, 7.599342076785333, 7.713624310270756, 7.826237921249264, 7.937253933193772, 8.046738469715542, 8.154753215150047, 8.261355820929154, 8.366600265340756, 8.470537173048708, 8.573214099741124, 8.674675786448736, 8.774964387392124, 8.874119674649423, 8.972179222463181, 9.069178573608529, 9.165151389911681, 9.260129588726066, 9.354143466934854, 9.447221813845593, 9.539392014169458, 9.630680142129112, 9.721111047611792, 9.810708435174293, 9.899494936611665, 9.98749217771909, 10.074720839804943, 10.161200716450788, 10.246950765959598, 10.331989159885913, 10.41633332799983, 10.5, 10.583005244258363, 10.665364503850771, 10.747092630102339, 10.828203913853859, 10.908712114635714, 10.988630487917955, 11.067971810589327, 11.146748404803978, 11.224972160321824, 11.302654555457316, 11.37980667674104, 11.456439237389601, 11.532562594670797, 11.6081867662439, 11.683321445547923, 11.757976016304848, 11.832159566199232, 11.905880899790658, 11.979148550710942, 12.05197079319395, 12.124355652982143, 12.196310917650468, 12.267844146385297, 12.338962679253067, 12.409673645990857, 12.479983974348684, 12.549900398011133, 12.619429464123963, 12.68857754044952, 12.757350822173073, 12.825755338380661, 12.893796958227625, 12.96148139681572, 13.028814220795384, 13.095800853708795, 13.162446581088185, 13.228756555322954, 13.294735800308333], [0.0, 1.4142135623730951, 2.0, 2.4494897427831783, 2.8284271247461903, 3.1622776601683795, 3.464101615137755, 3.7416573867739413, 4.0, 4.242640687119285, 4.47213595499958, 4.690415759823431, 4.898979485566357, 5.099019513592785, 5.291502622129181, 5.477225575051661, 5.656854249492381, 5.8309518948453, 6.0, 6.164414002968977, 6.324555320336759, 6.48074069840786, 6.6332495807108, 6.782329983125268, 6.92820323027551, 7.0710678118654755, 7.211102550927979, 7.348469228349535, 7.483314773547883, 7.615773105863909, 7.745966692414833, 7.874007874011811, 8.0, 8.12403840463596, 8.246211251235321, 8.366600265340756, 8.48528137423857, 8.602325267042627, 8.717797887081348, 8.831760866327848, 8.94427190999916, 9.055385138137416, 9.165151389911681, 9.273618495495704, 9.380831519646861, 9.486832980505136, 9.591663046625438, 9.695359714832659, 9.797958971132713, 9.899494936611665, 10.0, 10.09950493836208, 10.19803902718557, 10.295630140987, 10.392304845413264, 10.488088481701515, 10.583005244258363, 10.677078252031311, 10.770329614269007, 10.862780491200215, 10.954451150103322, 11.04536101718726, 11.135528725660043, 11.224972160321823, 11.313708498984761, 11.40175425099138, 11.489125293076057, 11.575836902790225, 11.6619037896906, 11.747340124470732, 11.832159566199232, 11.916375287812984, 12.0, 12.083045973594572, 12.165525060596439, 12.24744871391589, 12.328828005937954, 12.409673645990857, 12.489995996796797, 12.569805089976535, 12.649110640673518, 12.727922061357855, 12.806248474865699, 12.884098726725124, 12.96148139681572, 13.038404810405297, 13.114877048604, 13.19090595827292, 13.2664991614216, 13.341664064126332, 13.416407864998737, 13.490737563232042, 13.564659966250536, 13.638181696985855, 13.71130920080209, 13.78404875209022, 13.85640646055102, 13.92838827718412, 14.0, 14.071247279470288, 14.142135623730951, 14.212670403551895], [0.0, 1.5, 2.1213203435596424, 2.5980762113533165, 3.0, 3.3541019662496847, 3.6742346141747673, 3.9686269665968856, 4.242640687119285, 4.5, 4.743416490252569, 4.974937185533101, 5.196152422706633, 5.408326913195984, 5.612486080160912, 5.809475019311125, 6.0, 6.18465843842649, 6.363961030678928, 6.5383484153110105, 6.708203932499369, 6.87386354243376, 7.035623639735144, 7.19374728496908, 7.3484692283495345, 7.5, 7.6485292703891785, 7.794228634059949, 7.937253933193771, 8.077747210701757, 8.215838362577491, 8.351646544245032, 8.48528137423857, 8.616843969807045, 8.74642784226795, 8.874119674649425, 9.0, 9.12414379544733, 9.246621004453464, 9.367496997597598, 9.486832980505138, 9.604686356149273, 9.72111104761179, 9.836157786453, 9.949874371066201, 10.062305898749052, 10.173494974687902, 10.283481900601567, 10.392304845413266, 10.5, 10.606601717798213, 10.712142642814277, 10.816653826391969, 10.920164833920778, 11.022703842524303, 11.124297730643494, 11.224972160321824, 11.324751652906125, 11.423659658795863, 11.521718621802911, 11.61895003862225, 11.715374513859981, 11.811011811017716, 11.905880899790656, 12.0, 12.093386622447824, 12.186057606953941, 12.278029157808675, 12.36931687685298, 12.459935794377113, 12.549900398011133, 12.639224659764539, 12.727922061357855, 12.816005617976296, 12.903487900563938, 12.99038105676658, 13.076696830622021, 13.162446581088183, 13.247641299491772, 13.332291625973383, 13.416407864998739, 13.5, 13.583077707206126, 13.665650368716447, 13.74772708486752, 13.82931668593933, 13.910427743243554, 13.991068579633223, 14.071247279470288, 14.150971698084904, 14.230249470757707, 14.309088021254185, 14.38749456993816, 14.465476141489432, 14.543039572248988, 14.620191517213444, 14.696938456699069, 14.773286702694158, 14.849242404917499, 14.9248115565993, 15.0, 15.074813431681335], [0.0, 1.5811388300841898, 2.23606797749979, 2.738612787525831, 3.1622776601683795, 3.5355339059327378, 3.872983346207417, 4.183300132670378, 4.47213595499958, 4.743416490252569, 5.0, 5.244044240850759, 5.477225575051662, 5.7008771254956905, 5.916079783099616, 6.123724356957945, 6.324555320336759, 6.519202405202648, 6.708203932499369, 6.892024376045112, 7.0710678118654755, 7.24568837309472, 7.416198487095663, 7.582875444051551, 7.745966692414834, 7.905694150420949, 8.062257748298551, 8.215838362577493, 8.366600265340756, 8.514693182963201, 8.660254037844386, 8.803408430829505, 8.94427190999916, 9.082951062292477, 9.219544457292887, 9.354143466934854, 9.486832980505138, 9.617692030835673, 9.746794344808965, 9.87420882906575, 10.0, 10.124228365658293, 10.2469507659596, 10.36822067666386, 10.488088481701517, 10.606601717798211, 10.723805294763608, 10.8397416943394, 10.954451150103324, 11.067971810589327, 11.180339887498949, 11.291589790636216, 11.401754250991381, 11.51086443322134, 11.618950038622252, 11.726039399558575, 11.832159566199232, 11.937336386313323, 12.041594578792296, 12.144957801491119, 12.24744871391589, 12.349089035228468, 12.449899597988733, 12.549900398011133, 12.649110640673518, 12.747548783981962, 12.84523257866513, 12.942179105544785, 13.038404810405297, 13.133925536563698, 13.228756555322953, 13.322912594474229, 13.416407864998739, 13.509256086106296, 13.601470508735442, 13.693063937629153, 13.784048752090223, 13.874436925511608, 13.964240043768942, 14.053469322555197, 14.142135623730951, 14.230249470757707, 14.317821063276355, 14.404860290887934, 14.49137674618944, 14.577379737113251, 14.66287829861518, 14.747881203752627, 14.832396974191326, 14.916433890176297, 15.0, 15.083103128998356, 15.165750888103101, 15.247950681976906, 15.329709716755893, 15.41103500742244, 15.491933384829668, 15.572411502397438, 15.652475842498529, 15.732132722552274, 15.811388300841898, 15.890248582070704], [0.0, 1.6583123951777001, 2.345207879911715, 2.872281323269015, 3.3166247903554003, 3.708099243547832, 4.06201920231798, 4.387482193696061, 4.69041575982343, 4.974937185533101, 5.244044240850759, 5.500000000000002, 5.74456264653803, 5.9791303715507, 6.2048368229954285, 6.422616289332565, 6.6332495807108005, 6.837397165588672, 7.035623639735145, 7.228416147400481, 7.416198487095664, 7.599342076785333, 7.778174593052023, 7.952986860293434, 8.12403840463596, 8.2915619758885, 8.455767262643883, 8.616843969807045, 8.774964387392123, 8.930285549745877, 9.082951062292475, 9.233092656309696, 9.38083151964686, 9.526279441628828, 9.669539802906858, 9.810708435174293, 9.949874371066201, 10.08712050091601, 10.222524150130438, 10.356157588603992, 10.488088481701517, 10.618380290797651, 10.74709263010234, 10.874281585465774, 11.000000000000004, 11.124297730643494, 11.247221879201993, 11.368817000902075, 11.48912529307606, 11.6081867662439, 11.726039399558575, 11.842719282327014, 11.9582607431014, 12.072696467649639, 12.186057606953943, 12.298373876248846, 12.409673645990857, 12.519984025548917, 12.62933094031509, 12.737739202856996, 12.84523257866513, 12.951833846988619, 13.057564857200596, 13.162446581088183, 13.266499161421601, 13.369741957120938, 13.472193585307481, 13.573871960498229, 13.674794331177344, 13.774977313955914, 13.874436925511608, 13.973188612482122, 14.07124727947029, 14.168627315304755, 14.265342617687105, 14.361406616345073, 14.456832294800963, 14.55163221085525, 14.645818515876812, 14.739402972983676, 14.832396974191328, 14.9248115565993, 15.016657417681209, 15.107944929738128, 15.198684153570666, 15.288884851420656, 15.378556499229699, 15.467708298258021, 15.556349186104047, 15.644487847162015, 15.732132722552274, 15.819292019556377, 15.905973720586868, 15.992185591719478, 16.07793519081353, 16.163229875244614, 16.24807680927192, 16.33248297106108, 16.416455159382007, 16.500000000000004, 16.583123951777, 16.66583331249896], [0.0, 1.7320508075688776, 2.4494897427831783, 3.000000000000001, 3.4641016151377553, 3.8729833462074175, 4.242640687119286, 4.582575694955841, 4.898979485566357, 5.196152422706633, 5.477225575051662, 5.74456264653803, 6.000000000000002, 6.2449979983984, 6.480740698407861, 6.70820393249937, 6.9282032302755105, 7.14142842854285, 7.348469228349535, 7.549834435270752, 7.745966692414835, 7.937253933193774, 8.12403840463596, 8.306623862918077, 8.485281374238571, 8.660254037844389, 8.83176086632785, 9.000000000000004, 9.165151389911681, 9.327379053088817, 9.486832980505138, 9.643650760992957, 9.797958971132713, 9.949874371066203, 10.09950493836208, 10.2469507659596, 10.392304845413266, 10.535653752852742, 10.677078252031313, 10.81665382639197, 10.954451150103324, 11.09053650640942, 11.224972160321828, 11.357816691600549, 11.48912529307606, 11.61895003862225, 11.747340124470732, 11.874342087037919, 12.000000000000004, 12.124355652982143, 12.247448713915892, 12.369316876852984, 12.4899959967968, 12.609520212918495, 12.727922061357859, 12.845232578665131, 12.961481396815723, 13.076696830622023, 13.190905958272921, 13.304134695650072, 13.41640786499874, 13.527749258468685, 13.638181696985859, 13.74772708486752, 13.856406460551021, 13.964240043768942, 14.07124727947029, 14.177446878757827, 14.2828568570857, 14.387494569938161, 14.49137674618944, 14.594519519326427, 14.69693845669907, 14.798648586948744, 14.89966442575134, 15.000000000000002, 15.099668870541503, 15.198684153570666, 15.297058540778357, 15.394804318340656, 15.49193338482967, 15.588457268119898, 15.684387141358126, 15.779733838059503, 15.874507866387548, 15.968719422671313, 16.062378404209014, 16.155494421403514, 16.24807680927192, 16.34013463836819, 16.431676725154986, 16.522711641858308, 16.613247725836153, 16.703293088490067, 16.792855623746668, 16.881943016134134, 16.970562748477143, 17.058722109231983, 17.14642819948225, 17.23368793961409, 17.320508075688778, 17.406895185529212], [0.0, 1.8027756377319948, 2.5495097567963927, 3.1224989991992, 3.6055512754639896, 4.0311288741492755, 4.415880433163924, 4.769696007084729, 5.099019513592785, 5.408326913195984, 5.7008771254956905, 5.9791303715507, 6.2449979983984, 6.500000000000001, 6.745368781616021, 6.982120021884471, 7.211102550927979, 7.433034373659253, 7.6485292703891785, 7.858116822750857, 8.062257748298551, 8.261355820929154, 8.455767262643882, 8.645808232895291, 8.831760866327848, 9.013878188659975, 9.19238815542512, 9.3674969975976, 9.539392014169458, 9.708243919473801, 9.874208829065749, 10.037429949942366, 10.19803902718557, 10.356157588603992, 10.51189802081432, 10.665364503850773, 10.816653826391969, 10.965856099730656, 11.113055385446437, 11.258330249197705, 11.401754250991381, 11.543396380615196, 11.683321445547925, 11.821590417536889, 11.9582607431014, 12.093386622447824, 12.227019260637483, 12.359207094308276, 12.4899959967968, 12.619429464123963, 12.747548783981964, 12.874393189583735, 13.000000000000002, 13.12440474840669, 13.247641299491773, 13.36974195712094, 13.490737563232042, 13.610657588816201, 13.729530217745982, 13.847382424126229, 13.964240043768942, 14.080127840328723, 14.195069566578391, 14.309088021254185, 14.422205101855958, 14.534441853748634, 14.645818515876812, 14.756354563373707, 14.866068747318506, 14.974979131871939, 15.083103128998356, 15.190457530963315, 15.297058540778357, 15.402921800749365, 15.508062419270821, 15.612494995995997, 15.716233645501713, 15.819292019556375, 15.92168332809066, 16.023420358962067, 16.124515496597102, 16.224980739587952, 16.324827717314513, 16.424067705656842, 16.522711641858308, 16.62077013859466, 16.718253497300488, 16.81517172080024, 16.911534525287763, 17.00735135169495, 17.10263137648707, 17.19738352191984, 17.291616465790582, 17.38533865071371, 17.478558292948538, 17.57128339080558, 17.663521732655695, 17.755280904564707, 17.84656829757475, 17.937391114652097, 18.02775637731995, 18.11767093199344], [0.0, 1.8708286933869707, 2.6457513110645907, 3.2403703492039306, 3.7416573867739413, 4.183300132670378, 4.58257569495584, 4.949747468305833, 5.291502622129181, 5.612486080160912, 5.916079783099616, 6.204836822995429, 6.480740698407861, 6.745368781616021, 7.0, 7.245688373094719, 7.483314773547883, 7.713624310270755, 7.937253933193772, 8.154753215150047, 8.366600265340756, 8.573214099741124, 8.774964387392123, 8.972179222463181, 9.16515138991168, 9.354143466934854, 9.539392014169458, 9.721111047611792, 9.899494936611665, 10.074720839804943, 10.246950765959596, 10.41633332799983, 10.583005244258363, 10.74709263010234, 10.908712114635714, 11.067971810589327, 11.224972160321824, 11.379806676741044, 11.532562594670797, 11.683321445547923, 11.832159566199232, 11.979148550710939, 12.124355652982143, 12.267844146385297, 12.409673645990859, 12.54990039801113, 12.68857754044952, 12.825755338380661, 12.961481396815723, 13.095800853708795, 13.228756555322953, 13.36038921588739, 13.490737563232042, 13.619838471876237, 13.74772708486752, 13.874436925511608, 14.0, 14.124446891825535, 14.247806848775006, 14.370107863199912, 14.491376746189438, 14.611639196202457, 14.730919862656235, 14.849242404917497, 14.966629547095765, 15.083103128998356, 15.198684153570664, 15.313392831113553, 15.42724862054151, 15.540270267920054, 15.652475842498527, 15.763882770434448, 15.874507866387544, 15.98436736314578, 16.093476939431078, 16.20185174601965, 16.309506430300093, 16.416455159382004, 16.522711641858308, 16.62828914831589, 16.73320053068151, 16.837458240482736, 16.94107434609742, 17.04406054905931, 17.146428199482248, 17.24818831066034, 17.349351572897472, 17.449928366615147, 17.549928774784245, 17.64936259472279, 17.74823934929885, 17.84656829757475, 17.944358444926362, 18.041618552668716, 18.138357147217057, 18.234582528810467, 18.33030277982336, 18.425525772688278, 18.520259177452136, 18.614510468986285, 18.708286933869708, 18.801595676963167], [0.0, 1.9364916731037083, 2.7386127875258306, 3.3541019662496847, 3.8729833462074166, 4.330127018922193, 4.743416490252569, 5.123475382979799, 5.477225575051661, 5.809475019311125, 6.123724356957945, 6.422616289332565, 6.708203932499369, 6.98212002188447, 7.245688373094719, 7.499999999999999, 7.745966692414833, 7.984359711335655, 8.215838362577491, 8.440971508067067, 8.660254037844386, 8.874119674649425, 9.082951062292475, 9.287087810503355, 9.486832980505138, 9.682458365518542, 9.87420882906575, 10.062305898749054, 10.246950765959598, 10.428326807307105, 10.606601717798211, 10.781929326423912, 10.954451150103322, 11.124297730643494, 11.291589790636214, 11.4564392373896, 11.61895003862225, 11.779218989389747, 11.937336386313323, 12.093386622447825, 12.24744871391589, 12.399596767637243, 12.549900398011134, 12.698425099200293, 12.84523257866513, 12.990381056766577, 13.133925536563696, 13.275918047351754, 13.416407864998739, 13.555441711725958, 13.693063937629152, 13.82931668593933, 13.96424004376894, 14.097872179871684, 14.230249470757707, 14.361406616345072, 14.491376746189438, 14.620191517213446, 14.747881203752625, 14.874474780643515, 14.999999999999998, 15.124483462254172, 15.247950681976905, 15.370426148939396, 15.491933384829666, 15.612494995995995, 15.732132722552272, 15.850867484147358, 15.96871942267131, 16.08570794214541, 16.20185174601965, 16.31716887208072, 16.431676725154983, 16.545392107774294, 16.65833124895768, 16.77050983124842, 16.881943016134134, 16.992645467966426, 17.10263137648707, 17.211914478058503, 17.32050807568877, 17.428425057933374, 17.53567791675018, 17.642278764377348, 17.74823934929885, 17.853571071357123, 17.95828499606797, 18.062391868188442, 18.16590212458495, 18.26882590644511, 18.371173070873834, 18.472953201911164, 18.57417562100671, 18.6748493969831, 18.774983355518586, 18.87458608817687, 18.973665961010276, 19.072231122760652, 19.170289512680814, 19.267848867997692, 19.364916731037084, 19.461500456028563], [0.0, 2.0, 2.8284271247461903, 3.4641016151377553, 4.0, 4.47213595499958, 4.898979485566357, 5.291502622129181, 5.656854249492381, 6.0, 6.324555320336759, 6.633249580710801, 6.9282032302755105, 7.211102550927979, 7.483314773547883, 7.745966692414834, 8.0, 8.246211251235321, 8.485281374238571, 8.717797887081348, 8.94427190999916, 9.165151389911681, 9.38083151964686, 9.59166304662544, 9.797958971132713, 10.000000000000002, 10.19803902718557, 10.392304845413266, 10.583005244258363, 10.77032961426901, 10.95445115010332, 11.135528725660045, 11.313708498984761, 11.489125293076059, 11.661903789690601, 11.832159566199232, 12.0, 12.16552506059644, 12.328828005937954, 12.489995996796798, 12.649110640673518, 12.806248474865697, 12.961481396815723, 13.114877048604, 13.266499161421603, 13.416407864998737, 13.564659966250536, 13.71130920080209, 13.856406460551021, 14.0, 14.142135623730951, 14.282856857085703, 14.422205101855958, 14.560219778561038, 14.69693845669907, 14.832396974191328, 14.966629547095765, 15.099668870541501, 15.231546211727817, 15.362291495737216, 15.491933384829668, 15.620499351813308, 15.748015748023622, 15.874507866387543, 16.0, 16.1245154965971, 16.24807680927192, 16.3707055437449, 16.492422502470642, 16.61324772583615, 16.73320053068151, 16.852299546352718, 16.970562748477143, 17.088007490635064, 17.204650534085253, 17.320508075688775, 17.435595774162696, 17.549928774784245, 17.663521732655695, 17.776388834631177, 17.88854381999832, 18.0, 18.110770276274835, 18.2208671582886, 18.330302779823363, 18.439088914585774, 18.547236990991408, 18.65475810617763, 18.76166303929372, 18.867962264113206, 18.973665961010276, 19.078784028338912, 19.18332609325088, 19.28730152198591, 19.390719429665317, 19.493588689617926, 19.595917942265427, 19.69771560359221, 19.79898987322333, 19.8997487421324, 20.000000000000004, 20.099751242241783], [0.0, 2.0615528128088303, 2.9154759474226504, 3.5707142142714257, 4.123105625617661, 4.6097722286464435, 5.04975246918104, 5.454356057317857, 5.830951894845301, 6.184658438426491, 6.519202405202648, 6.837397165588673, 7.141428428542851, 7.433034373659254, 7.713624310270756, 7.984359711335656, 8.246211251235321, 8.5, 8.746427842267952, 8.986100377805716, 9.219544457292887, 9.447221813845593, 9.669539802906858, 9.886859966642595, 10.09950493836208, 10.307764064044152, 10.511898020814321, 10.712142642814277, 10.908712114635714, 11.10180165558726, 11.291589790636214, 11.478240283248997, 11.661903789690601, 11.842719282327014, 12.020815280171307, 12.196310917650468, 12.369316876852983, 12.539936203984453, 12.708265027138836, 12.874393189583735, 13.038404810405297, 13.200378782444085, 13.36038921588739, 13.518505834595775, 13.674794331177345, 13.829316685939329, 13.982131454109561, 14.13329402510257, 14.282856857085703, 14.430869689661812, 14.577379737113253, 14.722431864335459, 14.866068747318508, 15.008331019803636, 15.149257407543118, 15.288884851420656, 15.427248620541512, 15.564382416273382, 15.700318468107582, 15.835087622113114, 15.968719422671311, 16.101242188104617, 16.232683080747925, 16.36306817195357, 16.492422502470642, 16.62077013859466, 16.748134224444225, 16.874537030686206, 17.0, 17.12454378954371, 17.24818831066034, 17.37095276604021, 17.492855684535904, 17.613914953808536, 17.7341478509682, 17.853571071357127, 17.972200755611432, 18.090052515125542, 18.207141456033128, 18.323482201808694, 18.439088914585774, 18.553975315279473, 18.66815470259447, 18.78163997099295, 18.894443627691185, 19.00657780874821, 19.11805429430516, 19.22888452302941, 19.339079605813716, 19.448650338776723, 19.557607215607945, 19.665960439297137, 19.77371993328519, 19.880895352071043, 19.987496091306685, 20.093531297410117, 20.19900987672416, 20.303940504246953, 20.408331631958553, 20.512191496766015, 20.615528128088304, 20.718349355100663], [0.0, 2.121320343559643, 3.0, 3.6742346141747677, 4.242640687119286, 4.743416490252569, 5.196152422706632, 5.612486080160912, 6.0, 6.363961030678928, 6.708203932499369, 7.035623639735146, 7.348469228349535, 7.6485292703891785, 7.937253933193772, 8.215838362577491, 8.485281374238571, 8.74642784226795, 9.0, 9.246621004453466, 9.486832980505138, 9.72111104761179, 9.9498743710662, 10.173494974687902, 10.392304845413264, 10.606601717798213, 10.81665382639197, 11.022703842524303, 11.224972160321824, 11.423659658795863, 11.61895003862225, 11.811011811017718, 12.0, 12.186057606953943, 12.36931687685298, 12.549900398011134, 12.727922061357855, 12.903487900563942, 13.076696830622023, 13.247641299491772, 13.416407864998739, 13.583077707206126, 13.747727084867522, 13.910427743243556, 14.071247279470292, 14.230249470757705, 14.387494569938157, 14.543039572248988, 14.69693845669907, 14.849242404917497, 15.000000000000002, 15.14925740754312, 15.297058540778357, 15.443445211480503, 15.588457268119898, 15.732132722552274, 15.874507866387544, 16.01561737804697, 16.155494421403514, 16.29417073680032, 16.431676725154983, 16.56804152578089, 16.703293088490067, 16.837458240482736, 16.970562748477143, 17.10263137648707, 17.233687939614086, 17.36375535418534, 17.4928556845359, 17.621010186706098, 17.74823934929885, 17.874562931719478, 18.0, 18.12456896039186, 18.24828759089466, 18.371173070873837, 18.493242008906932, 18.614510468986285, 18.734993995195197, 18.854707634964804, 18.973665961010276, 19.091883092036785, 19.20937271229855, 19.32614809008769, 19.44222209522358, 19.557607215607945, 19.672315572906, 19.786358937409382, 19.8997487421324, 20.012496096189498, 20.12461179749811, 20.236106344848064, 20.346989949375804, 20.457272545478784, 20.566963801203133, 20.676073128135332, 20.784609690826528, 20.892582415776182, 21.0, 21.106870919205434, 21.213203435596427, 21.319005605327845], [0.0, 2.179449471770337, 3.082207001484489, 3.774917217635376, 4.358898943540674, 4.8733971724044824, 5.3385391260156565, 5.766281297335398, 6.164414002968978, 6.538348415311011, 6.892024376045112, 7.228416147400482, 7.549834435270752, 7.8581168227508575, 8.154753215150047, 8.440971508067067, 8.717797887081348, 8.986100377805714, 9.246621004453466, 9.500000000000002, 9.746794344808965, 9.98749217771909, 10.222524150130438, 10.452272480183437, 10.677078252031313, 10.897247358851686, 11.113055385446437, 11.324751652906128, 11.532562594670797, 11.736694594305504, 11.937336386313323, 12.134661099511598, 12.328828005937956, 12.519984025548919, 12.708265027138836, 12.893796958227629, 13.076696830622023, 13.257073583562855, 13.435028842544407, 13.610657588816203, 13.784048752090223, 13.955285736952865, 14.124446891825539, 14.291605927956454, 14.456832294800964, 14.620191517213446, 14.781745499094484, 14.941552797483938, 15.099668870541503, 15.25614630239236, 15.411035007422443, 15.564382416273384, 15.716233645501715, 15.866631652622434, 16.01561737804697, 16.163229875244618, 16.309506430300093, 16.454482671904337, 16.598192672697834, 16.740669042783207, 16.881943016134134, 17.022044530549202, 17.161002301730516, 17.298843892006193, 17.435595774162696, 17.57128339080558, 17.705931209625774, 17.839562774911276, 17.97220075561143, 18.103866990231676, 18.23458252881047, 18.36436767220696, 18.493242008906932, 18.621224449536076, 18.748333259252675, 18.874586088176876, 19.000000000000004, 19.12459149890528, 19.24837655492016, 19.37137062781052, 19.49358868961793, 19.615045245933032, 19.735754355990554, 19.855729651664785, 19.97498435543818, 20.09353129741012, 20.211382931407737, 20.328551350256127, 20.445048300260876, 20.56088519495209, 20.676073128135336, 20.790622886291793, 20.904544960366874, 21.017849556983705, 21.130546609115445, 21.242645786248, 21.354156504062626, 21.465087933665686, 21.57544901039142, 21.685248442201445, 21.794494717703373, 21.903196113809514], [0.0, 2.23606797749979, 3.1622776601683795, 3.872983346207418, 4.47213595499958, 5.000000000000001, 5.477225575051662, 5.916079783099616, 6.324555320336759, 6.708203932499369, 7.0710678118654755, 7.416198487095665, 7.745966692414836, 8.062257748298551, 8.366600265340756, 8.660254037844387, 8.94427190999916, 9.219544457292887, 9.48683298050514, 9.746794344808965, 10.000000000000002, 10.2469507659596, 10.488088481701515, 10.72380529476361, 10.954451150103324, 11.18033988749895, 11.401754250991383, 11.618950038622254, 11.832159566199232, 12.041594578792298, 12.24744871391589, 12.449899597988733, 12.649110640673518, 12.845232578665133, 13.038404810405298, 13.228756555322954, 13.416407864998739, 13.601470508735446, 13.784048752090223, 13.964240043768944, 14.142135623730951, 14.317821063276353, 14.491376746189442, 14.66287829861518, 14.83239697419133, 14.999999999999998, 15.165750888103101, 15.329709716755893, 15.491933384829672, 15.652475842498529, 15.811388300841898, 15.968719422671315, 16.124515496597102, 16.27882059609971, 16.431676725154986, 16.583123951777, 16.73320053068151, 16.881943016134134, 17.029386365926403, 17.175564037317667, 17.320508075688775, 17.464249196572982, 17.60681686165901, 17.74823934929885, 17.88854381999832, 18.027756377319946, 18.165902124584953, 18.30300521772313, 18.439088914585774, 18.574175621006713, 18.708286933869708, 18.841443681416774, 18.97366596101028, 19.104973174542803, 19.235384061671343, 19.364916731037088, 19.49358868961793, 19.621416870348586, 19.7484176581315, 19.874606914351794, 20.000000000000004, 20.12461179749811, 20.24845673131659, 20.371548787463365, 20.4939015319192, 20.615528128088304, 20.73644135332772, 20.856653614614213, 20.97617696340303, 21.095023109728988, 21.213203435596427, 21.330729007701542, 21.44761058952722, 21.563858652847827, 21.679483388678804, 21.794494717703365, 21.90890230020665, 22.022715545545243, 22.135943621178658, 22.248595461286993, 22.3606797749979, 22.472205054244235], [0.0, 2.2912878474779204, 3.2403703492039306, 3.968626966596887, 4.582575694955841, 5.1234753829798, 5.612486080160912, 6.062177826491071, 6.480740698407861, 6.87386354243376, 7.24568837309472, 7.599342076785334, 7.937253933193774, 8.261355820929154, 8.573214099741124, 8.874119674649425, 9.165151389911681, 9.447221813845593, 9.72111104761179, 9.98749217771909, 10.2469507659596, 10.500000000000002, 10.747092630102339, 10.988630487917955, 11.224972160321824, 11.456439237389601, 11.683321445547925, 11.90588089979066, 12.124355652982143, 12.338962679253068, 12.549900398011133, 12.757350822173075, 12.961481396815723, 13.162446581088187, 13.360389215887388, 13.55544171172596, 13.74772708486752, 13.937359864766357, 14.124446891825537, 14.309088021254187, 14.49137674618944, 14.67140075112121, 14.8492424049175, 15.02497920131672, 15.198684153570667, 15.370426148939396, 15.540270267920054, 15.70827807240501, 15.874507866387548, 16.03901493234544, 16.201851746019653, 16.363068171953575, 16.522711641858308, 16.68082731761228, 16.83745824048274, 16.99264546796643, 17.146428199482248, 17.298843892006197, 17.44992836661515, 17.599715906798043, 17.74823934929885, 17.89553016817328, 18.041618552668716, 18.186533479473212, 18.330302779823363, 18.472953201911167, 18.614510468986285, 18.754999333511055, 18.894443627691185, 19.032866310674283, 19.170289512680814, 19.306734576307825, 19.44222209522358, 19.576771950451892, 19.71040334442702, 19.843134832984433, 19.97498435543818, 20.1059692628831, 20.236106344848064, 20.3654118544163, 20.4939015319192, 20.62159062730128, 20.748493921246432, 20.874625745148105, 21.000000000000004, 21.12463017427761, 21.24852936087578, 21.371710273162513, 21.494185260204677, 21.615966321217286, 21.73706511928416, 21.857492994394395, 21.97726097583591, 22.096379793984354, 22.214859891523066, 22.332711434127294, 22.44994432064365, 22.566568192793518, 22.682592444427513, 22.798026230355998, 22.912878474779202, 23.027157879338912], [0.0, 2.345207879911715, 3.3166247903554003, 4.062019202317981, 4.69041575982343, 5.244044240850758, 5.7445626465380295, 6.2048368229954285, 6.6332495807108005, 7.035623639735145, 7.416198487095663, 7.778174593052024, 8.124038404635963, 8.455767262643883, 8.774964387392123, 9.082951062292475, 9.38083151964686, 9.669539802906858, 9.949874371066201, 10.222524150130438, 10.488088481701515, 10.74709263010234, 11.0, 11.247221879201993, 11.489125293076059, 11.726039399558575, 11.9582607431014, 12.186057606953943, 12.409673645990857, 12.62933094031509, 12.845232578665128, 13.057564857200596, 13.266499161421601, 13.472193585307481, 13.674794331177344, 13.87443692551161, 14.07124727947029, 14.265342617687107, 14.456832294800963, 14.645818515876812, 14.832396974191326, 15.016657417681207, 15.198684153570666, 15.378556499229699, 15.556349186104049, 15.732132722552272, 15.905973720586866, 16.077935190813527, 16.248076809271925, 16.416455159382004, 16.583123951777, 16.74813422444423, 16.911534525287767, 17.073371078963874, 17.23368793961409, 17.392527130926087, 17.549928774784245, 17.705931209625774, 17.860571099491754, 18.01388353465182, 18.16590212458495, 18.3166590840142, 18.466185312619388, 18.614510468986285, 18.76166303929372, 18.907670401189037, 19.052558883257653, 19.19635382045247, 19.339079605813716, 19.480759738778158, 19.621416870348583, 19.761072845369505, 19.899748742132402, 20.03746490951388, 20.174241001832012, 20.310096011589902, 20.445048300260876, 20.57911562725668, 20.71231517720798, 20.844663585675832, 20.97617696340303, 21.106870919205434, 21.236760581595306, 21.365860619221497, 21.49418526020468, 21.621748310439653, 21.748563170931547, 21.87464285422736, 22.0, 22.124646889837585, 22.24859546128699, 22.371857321197094, 22.494443758403985, 22.616365755797283, 22.73763400180415, 22.85825890132492, 22.978250586152118, 23.097618924902196, 23.2163735324878, 23.334523779156072, 23.45207879911715, 23.569047498785352], [0.0, 2.39791576165636, 3.3911649915626345, 4.153311931459038, 4.79583152331272, 5.361902647381805, 5.873670062235366, 6.344288770224761, 6.782329983125269, 7.19374728496908, 7.582875444051551, 7.952986860293435, 8.306623862918077, 8.645808232895293, 8.972179222463181, 9.287087810503355, 9.59166304662544, 9.886859966642595, 10.173494974687904, 10.452272480183439, 10.72380529476361, 10.988630487917957, 11.247221879201993, 11.500000000000002, 11.747340124470732, 11.9895788082818, 12.227019260637487, 12.459935794377115, 12.688577540449522, 12.91317157014496, 13.133925536563696, 13.35102992281869, 13.564659966250538, 13.774977313955914, 13.982131454109563, 14.18626095911111, 14.38749456993816, 14.585952145814824, 14.781745499094486, 14.97497913187194, 15.165750888103101, 15.354152532784088, 15.540270267920056, 15.724185193516389, 15.90597372058687, 16.08570794214541, 16.263455967290593, 16.4392822227736, 16.613247725836153, 16.78541033159452, 16.95582495781317, 17.12454378954371, 17.291616465790586, 17.457090250096094, 17.621010186706098, 17.78341924377874, 17.944358444926362, 18.103866990231676, 18.261982367749678, 18.418740456393863, 18.57417562100671, 18.728320800328042, 18.88120758849921, 19.03286631067428, 19.18332609325088, 19.332614929181208, 19.480759738778158, 19.627786426390525, 19.77371993328519, 19.91858428704209, 20.06240264773888, 20.205197351176754, 20.346989949375807, 20.48780124854788, 20.627651344736268, 20.76655965729519, 20.904544960366877, 21.041625412500814, 21.177818584547374, 21.313141485947117, 21.44761058952722, 21.58124185490724, 21.714050750608468, 21.84605227495348, 21.977260975835915, 22.107690969434145, 22.237355957937087, 22.366269246345045, 22.494443758403985, 22.62189205172724, 22.748626332154654, 22.87465846739575, 23.000000000000004, 23.124662159694356, 23.248655875125344, 23.371991785040485, 23.494680248941464, 23.61673135723909, 23.73815494093844, 23.858960580880304, 23.9791576165636, 24.098755154571784], [0.0, 2.4494897427831783, 3.464101615137755, 4.242640687119286, 4.898979485566357, 5.477225575051661, 6.0, 6.48074069840786, 6.92820323027551, 7.3484692283495345, 7.745966692414834, 8.124038404635963, 8.485281374238571, 8.831760866327848, 9.16515138991168, 9.486832980505138, 9.797958971132713, 10.099504938362077, 10.392304845413264, 10.677078252031313, 10.954451150103322, 11.224972160321826, 11.489125293076057, 11.747340124470732, 12.0, 12.247448713915892, 12.489995996796798, 12.727922061357859, 12.96148139681572, 13.190905958272921, 13.416407864998737, 13.638181696985857, 13.85640646055102, 14.071247279470292, 14.2828568570857, 14.49137674618944, 14.696938456699069, 14.899664425751341, 15.099668870541501, 15.297058540778357, 15.491933384829668, 15.684387141358123, 15.874507866387546, 16.06237840420901, 16.248076809271925, 16.431676725154983, 16.61324772583615, 16.792855623746668, 16.970562748477143, 17.146428199482248, 17.320508075688775, 17.492855684535904, 17.663521732655695, 17.83255450012701, 18.000000000000004, 18.165902124584953, 18.33030277982336, 18.493242008906932, 18.65475810617763, 18.81488772222678, 18.973665961010276, 19.131126469708992, 19.28730152198591, 19.44222209522358, 19.595917942265427, 19.7484176581315, 19.8997487421324, 20.049937655763422, 20.199009876724155, 20.346989949375807, 20.493901531919196, 20.639767440550294, 20.784609690826528, 20.928449536456352, 21.071307505705477, 21.213203435596427, 21.354156504062626, 21.494185260204677, 21.633307652783937, 21.771541057077243, 21.908902300206645, 22.045407685048605, 22.18107301281884, 22.315913604421397, 22.449944320643652, 22.58317958127243, 22.715633383201094, 22.847319317591726, 22.978250586152114, 23.108440016582684, 23.237900077244504, 23.366642891095847, 23.494680248941464, 23.622023622035435, 23.748684174075837, 23.874672772626642, 24.0, 24.12467616362964, 24.248711305964285, 24.372115213907882, 24.494897427831784, 24.617067250182345], [0.0, 2.5000000000000004, 3.535533905932738, 4.3301270189221945, 5.000000000000001, 5.5901699437494745, 6.123724356957946, 6.614378277661477, 7.071067811865476, 7.500000000000001, 7.905694150420949, 8.291561975888502, 8.660254037844389, 9.013878188659975, 9.354143466934854, 9.682458365518542, 10.000000000000002, 10.307764064044152, 10.606601717798213, 10.897247358851686, 11.180339887498949, 11.456439237389601, 11.726039399558575, 11.9895788082818, 12.247448713915892, 12.500000000000002, 12.747548783981966, 12.990381056766582, 13.228756555322954, 13.462912017836262, 13.693063937629152, 13.919410907075056, 14.142135623730953, 14.361406616345075, 14.577379737113251, 14.790199457749042, 15.000000000000002, 15.206906325745551, 15.411035007422443, 15.612494995995998, 15.811388300841898, 16.00781059358212, 16.201851746019653, 16.393596310755, 16.583123951777004, 16.77050983124842, 16.95582495781317, 17.13913650100261, 17.320508075688778, 17.5, 17.67766952966369, 17.853571071357127, 18.02775637731995, 18.2002747232013, 18.371173070873837, 18.54049621773916, 18.708286933869708, 18.874586088176876, 19.03943276465977, 19.20286436967152, 19.364916731037084, 19.525624189766635, 19.68501968502953, 19.84313483298443, 20.000000000000004, 20.155644370746376, 20.310096011589902, 20.463381929681127, 20.615528128088304, 20.76655965729519, 20.91650066335189, 21.0653744329409, 21.213203435596427, 21.36000936329383, 21.505813167606565, 21.65063509461097, 21.794494717703373, 21.937410968480307, 22.07940216581962, 22.220486043288975, 22.360679774997898, 22.5, 22.638462845343547, 22.776083947860748, 22.912878474779202, 23.04886114323222, 23.18404623873926, 23.31844763272204, 23.45207879911715, 23.58495283014151, 23.717082451262847, 23.848480035423645, 23.9791576165636, 24.10912690248239, 24.23839928708165, 24.36698586202241, 24.494897427831784, 24.622144504490265, 24.748737341529168, 24.874685927665503, 25.000000000000004, 25.12468905280223], [0.0, 2.5495097567963927, 3.6055512754639896, 4.415880433163925, 5.099019513592785, 5.7008771254956905, 6.244997998398399, 6.745368781616022, 7.211102550927979, 7.648529270389178, 8.062257748298551, 8.455767262643883, 8.83176086632785, 9.19238815542512, 9.539392014169458, 9.87420882906575, 10.19803902718557, 10.51189802081432, 10.816653826391969, 11.113055385446437, 11.401754250991381, 11.683321445547925, 11.958260743101398, 12.227019260637485, 12.489995996796798, 12.747548783981964, 13.000000000000004, 13.247641299491773, 13.490737563232043, 13.729530217745983, 13.96424004376894, 14.195069566578391, 14.422205101855958, 14.645818515876813, 14.866068747318506, 15.083103128998358, 15.297058540778355, 15.508062419270825, 15.716233645501713, 15.92168332809066, 16.124515496597102, 16.32482771731451, 16.522711641858308, 16.718253497300488, 16.911534525287767, 17.102631376487068, 17.291616465790582, 17.478558292948538, 17.6635217326557, 17.84656829757475, 18.02775637731995, 18.207141456033128, 18.38477631085024, 18.56071119327059, 18.734993995195197, 18.90767040118904, 19.078784028338916, 19.24837655492016, 19.4164878389476, 19.58315602756614, 19.7484176581315, 19.912307751739878, 20.074859899884732, 20.236106344848064, 20.39607805437114, 20.55480479109447, 20.71231517720798, 20.868636754709208, 21.02379604162864, 21.177818584547374, 21.330729007701542, 21.48255105894084, 21.633307652783937, 21.783020910791965, 21.93171219946131, 22.07940216581962, 22.226110770892873, 22.371857321197094, 22.51666049839541, 22.66053838724932, 22.803508501982762, 22.945587811167535, 23.086792761230395, 23.22713929867387, 23.36664289109585, 23.50531854708632, 23.643180835073778, 23.780243901188232, 23.916521486202797, 24.052026941611388, 24.18677324489565, 24.32077301403062, 24.45403852127497, 24.586581706288495, 24.718414188616556, 24.849547279578353, 24.979991993593597, 25.109759058979442, 25.23885892824793, 25.36730178793165, 25.495097567963928, 25.622255950637918], [0.0, 2.5980762113533165, 3.6742346141747677, 4.500000000000001, 5.196152422706633, 5.809475019311126, 6.3639610306789285, 6.87386354243376, 7.348469228349535, 7.794228634059948, 8.215838362577493, 8.616843969807045, 9.000000000000002, 9.367496997597598, 9.72111104761179, 10.062305898749054, 10.392304845413266, 10.712142642814275, 11.022703842524303, 11.324751652906127, 11.618950038622252, 11.90588089979066, 12.186057606953941, 12.459935794377113, 12.727922061357857, 12.990381056766582, 13.247641299491773, 13.500000000000004, 13.74772708486752, 13.991068579633225, 14.230249470757707, 14.465476141489434, 14.69693845669907, 14.924811556599304, 15.149257407543118, 15.3704261489394, 15.588457268119896, 15.803480629279111, 16.01561737804697, 16.224980739587956, 16.431676725154986, 16.63580475961413, 16.83745824048274, 17.03672503740082, 17.23368793961409, 17.428425057933374, 17.621010186706098, 17.81151313055688, 18.000000000000004, 18.186533479473212, 18.371173070873837, 18.553975315279477, 18.734993995195197, 18.914280319377742, 19.091883092036788, 19.267848867997696, 19.44222209522358, 19.615045245933032, 19.786358937409382, 19.956202043475106, 20.12461179749811, 20.291623887703025, 20.457272545478787, 20.62159062730128, 20.78460969082653, 20.946360065653412, 21.106870919205434, 21.26617031813674, 21.42428528562855, 21.58124185490724, 21.737065119284157, 21.891779278989638, 22.045407685048605, 22.197972880423116, 22.34949663862701, 22.500000000000004, 22.649503305812253, 22.798026230355998, 22.945587811167535, 23.09220647751098, 23.237900077244504, 23.382685902179844, 23.526580712037187, 23.669600757089253, 23.81176179958132, 23.95307913400697, 24.093567606313517, 24.233241632105273, 24.372115213907882, 24.510201957552287, 24.647515087732476, 24.784067462787462, 24.919871588754226, 25.0549396327351, 25.189283435620002, 25.3229145242012, 25.455844122715714, 25.588083163847976, 25.719642299223374, 25.850531909421132, 25.980762113533164, 26.11034277829382], [0.0, 2.6457513110645907, 3.7416573867739418, 4.582575694955841, 5.291502622129181, 5.916079783099616, 6.48074069840786, 7.0, 7.4833147735478835, 7.937253933193772, 8.366600265340756, 8.774964387392124, 9.165151389911681, 9.539392014169458, 9.899494936611665, 10.246950765959598, 10.583005244258363, 10.908712114635714, 11.224972160321824, 11.532562594670797, 11.832159566199232, 12.124355652982143, 12.409673645990857, 12.68857754044952, 12.96148139681572, 13.228756555322954, 13.490737563232043, 13.747727084867522, 14.0, 14.247806848775008, 14.491376746189438, 14.730919862656236, 14.966629547095767, 15.198684153570666, 15.427248620541512, 15.652475842498529, 15.874507866387544, 16.093476939431085, 16.309506430300093, 16.522711641858308, 16.73320053068151, 16.941074346097416, 17.146428199482248, 17.349351572897472, 17.54992877478425, 17.748239349298846, 17.944358444926362, 18.138357147217057, 18.330302779823363, 18.520259177452132, 18.708286933869708, 18.894443627691185, 19.078784028338916, 19.261360284258224, 19.442222095223585, 19.621416870348586, 19.79898987322333, 19.97498435543818, 20.149441679609886, 20.322401432901575, 20.493901531919196, 20.663978319771825, 20.83266665599966, 21.0, 21.166010488516726, 21.330729007701542, 21.494185260204677, 21.656407827707717, 21.817424229271428, 21.97726097583591, 22.135943621178654, 22.293496809607955, 22.44994432064365, 22.605309110914632, 22.75961335348208, 22.912878474779202, 23.065125189341593, 23.2163735324878, 23.366642891095847, 23.515952032609697, 23.664319132398465, 23.811761799581316, 23.958297101421884, 24.1039415863879, 24.248711305964285, 24.392621835300936, 24.535688292770594, 24.677925358506133, 24.819347291981714, 24.95996794869737, 25.099800796022265, 25.238858928247925, 25.37715508089904, 25.514701644346147, 25.651510676761323, 25.78759391645525, 25.92296279363144, 26.05762844159077, 26.19160170741759, 26.32489316217637, 26.45751311064591, 26.589471600616665], [0.0, 2.6925824035672523, 3.8078865529319548, 4.663689526544409, 5.385164807134505, 6.020797289396148, 6.59545297913646, 7.123903424387504, 7.6157731058639095, 8.077747210701757, 8.514693182963201, 8.930285549745879, 9.327379053088817, 9.708243919473801, 10.074720839804943, 10.428326807307105, 10.77032961426901, 11.10180165558726, 11.423659658795863, 11.736694594305504, 12.041594578792296, 12.338962679253068, 12.62933094031509, 12.913171570144959, 13.19090595827292, 13.462912017836262, 13.729530217745983, 13.991068579633225, 14.247806848775008, 14.500000000000002, 14.747881203752625, 14.991664350564951, 15.231546211727819, 15.467708298258023, 15.700318468107582, 15.929532322073992, 16.155494421403514, 16.378339354159202, 16.598192672697834, 16.81517172080024, 17.029386365926403, 17.24093964956667, 17.44992836661515, 17.656443583009576, 17.860571099491757, 18.062391868188442, 18.261982367749674, 18.459414941974735, 18.654758106177635, 18.848076824970764, 19.03943276465977, 19.228884523029414, 19.416487838947603, 19.602295783912663, 19.786358937409382, 19.96872554771586, 20.149441679609886, 20.328551350256124, 20.50609665440988, 20.682117879946436, 20.85665361461421, 21.02974084481309, 21.201415047114192, 21.37171027316251, 21.54065922853802, 21.70829334609241, 21.87464285422736, 22.039736840534193, 22.20360331117452, 22.366269246345045, 22.52776065213762, 22.688102609076857, 22.847319317591726, 23.005434140654682, 23.16246964380094, 23.31844763272204, 23.47338918861101, 23.62731470142132, 23.780243901188232, 23.93219588754864, 24.08318915758459, 24.23324163210527, 24.382370680473223, 24.53059314407216, 24.677925358506137, 24.82438317461282, 24.969981978367546, 25.114736709748723, 25.25866188063018, 25.401771591761076, 25.544079548889602, 25.685599078082646, 25.826343140289918, 25.96632434519757, 26.10555496441323, 26.244046944021417, 26.38181191654584, 26.518861212352242, 26.65520587052368, 26.790856649237632, 26.925824035672523, 27.060118255469618], [0.0, 2.7386127875258306, 3.872983346207417, 4.74341649025257, 5.477225575051661, 6.123724356957945, 6.7082039324993685, 7.245688373094719, 7.745966692414834, 8.215838362577491, 8.660254037844386, 9.082951062292477, 9.48683298050514, 9.87420882906575, 10.246950765959598, 10.606601717798211, 10.954451150103322, 11.291589790636214, 11.61895003862225, 11.937336386313323, 12.24744871391589, 12.549900398011134, 12.845232578665128, 13.133925536563696, 13.416407864998737, 13.693063937629153, 13.964240043768942, 14.230249470757709, 14.491376746189438, 14.747881203752627, 14.999999999999998, 15.247950681976905, 15.491933384829668, 15.732132722552276, 15.968719422671311, 16.20185174601965, 16.431676725154983, 16.658331248957683, 16.881943016134134, 17.10263137648707, 17.32050807568877, 17.53567791675018, 17.74823934929885, 17.95828499606797, 18.165902124584953, 18.371173070873834, 18.57417562100671, 18.774983355518586, 18.97366596101028, 19.170289512680814, 19.364916731037084, 19.55760721560795, 19.7484176581315, 19.937402037376888, 20.12461179749811, 20.310096011589902, 20.493901531919196, 20.676073128135332, 20.85665361461421, 21.035683967962626, 21.213203435596423, 21.389249636207435, 21.563858652847824, 21.737065119284157, 21.908902300206645, 22.079402165819616, 22.24859546128699, 22.416511771459895, 22.58317958127243, 22.74862633215465, 22.9128784747792, 23.075961518428652, 23.2379000772445, 23.398717913595178, 23.55843797877949, 23.717082451262844, 23.874672772626646, 24.031229681395832, 24.18677324489565, 24.34132288927617, 24.49489742783178, 24.647515087732472, 24.79919353527449, 24.949949899749296, 25.09980079602227, 25.24876234590519, 25.396850198400585, 25.544079548889602, 25.690465157330255, 25.836021365527625, 25.980762113533157, 26.124700955226263, 26.267851073127392, 26.410225292488512, 26.551836094703507, 26.692695630078273, 26.832815729997474, 26.972207918522354, 27.110883423451916, 27.248853186877426, 27.386127875258307, 27.52271788904577], [0.0, 2.783882181415011, 3.9370039370059056, 4.821825380496478, 5.567764362830022, 6.224949798994366, 6.8190908484929285, 7.365459931328118, 7.874007874011811, 8.351646544245034, 8.803408430829505, 9.233092656309696, 9.643650760992957, 10.037429949942366, 10.41633332799983, 10.781929326423912, 11.135528725660045, 11.478240283248995, 11.811011811017718, 12.134661099511598, 12.449899597988733, 12.757350822173075, 13.057564857200596, 13.35102992281869, 13.638181696985857, 13.919410907075056, 14.195069566578391, 14.465476141489436, 14.730919862656236, 14.991664350564951, 15.247950681976905, 15.5, 15.748015748023622, 15.992185591719478, 16.232683080747925, 16.469669092000604, 16.703293088490067, 16.933694221876102, 17.161002301730516, 17.385338650713713, 17.60681686165901, 17.825543469975887, 18.04161855266872, 18.255136263528684, 18.46618531261939, 18.674849396983095, 18.881207588499205, 19.085334683992315, 19.287301521985913, 19.487175269905077, 19.685019685029527, 19.880895352071047, 20.074859899884732, 20.266968199511247, 20.457272545478787, 20.64582282206258, 20.83266665599966, 21.017849556983705, 21.201415047114192, 21.383404780343096, 21.563858652847824, 21.742814905158898, 21.920310216782973, 22.09637979398435, 22.27105745132009, 22.44437568746344, 22.616365755797283, 22.787057730211682, 22.95648056649799, 23.124662159694356, 23.29162939770423, 23.4574082114798, 23.622023622035435, 23.785499784532593, 23.94786002965609, 24.109126902482387, 24.269322199023197, 24.428467000612216, 24.586581706288495, 24.743686063317245, 24.899799195977465, 25.0549396327351, 25.209125331911064, 25.362373705944798, 25.51470164434615, 25.666125535421195, 25.816661286851172, 25.96632434519757, 26.115129714401192, 26.26309197333779, 26.410225292488512, 26.556543449779003, 26.70205984563738, 26.846787517317598, 26.99073915253156, 27.133927102430267, 27.276363393971714, 27.41805974171039, 27.55902755904134, 27.699277968929085, 27.838821814150112, 27.977669667075563], [0.0, 2.8284271247461903, 4.0, 4.898979485566357, 5.656854249492381, 6.324555320336759, 6.92820323027551, 7.483314773547883, 8.0, 8.48528137423857, 8.94427190999916, 9.380831519646861, 9.797958971132713, 10.19803902718557, 10.583005244258363, 10.954451150103322, 11.313708498984761, 11.6619037896906, 12.0, 12.328828005937954, 12.649110640673518, 12.96148139681572, 13.2664991614216, 13.564659966250536, 13.85640646055102, 14.142135623730951, 14.422205101855958, 14.69693845669907, 14.966629547095765, 15.231546211727817, 15.491933384829666, 15.748015748023622, 16.0, 16.24807680927192, 16.492422502470642, 16.73320053068151, 16.97056274847714, 17.204650534085253, 17.435595774162696, 17.663521732655695, 17.88854381999832, 18.11077027627483, 18.330302779823363, 18.547236990991408, 18.761663039293722, 18.973665961010273, 19.183326093250876, 19.390719429665317, 19.595917942265427, 19.79898987322333, 20.0, 20.19900987672416, 20.39607805437114, 20.591260281974, 20.784609690826528, 20.97617696340303, 21.166010488516726, 21.354156504062622, 21.540659228538015, 21.72556098240043, 21.908902300206645, 22.09072203437452, 22.271057451320086, 22.449944320643645, 22.627416997969522, 22.80350850198276, 22.978250586152114, 23.15167380558045, 23.3238075793812, 23.494680248941464, 23.664319132398465, 23.83275057562597, 24.0, 24.166091947189145, 24.331050121192877, 24.49489742783178, 24.657656011875908, 24.819347291981714, 24.979991993593593, 25.13961017995307, 25.298221281347036, 25.45584412271571, 25.612496949731398, 25.76819745345025, 25.92296279363144, 26.076809620810593, 26.229754097208, 26.38181191654584, 26.5329983228432, 26.683328128252665, 26.832815729997474, 26.981475126464083, 27.129319932501073, 27.27636339397171, 27.42261840160418, 27.56809750418044, 27.71281292110204, 27.85677655436824, 28.0, 28.142494558940577, 28.284271247461902, 28.42534080710379], [0.0, 2.8722813232690148, 4.06201920231798, 4.9749371855331015, 5.7445626465380295, 6.422616289332566, 7.035623639735145, 7.599342076785333, 8.12403840463596, 8.616843969807045, 9.082951062292477, 9.526279441628828, 9.949874371066203, 10.356157588603992, 10.74709263010234, 11.124297730643494, 11.489125293076059, 11.842719282327012, 12.186057606953943, 12.519984025548917, 12.845232578665131, 13.162446581088185, 13.472193585307481, 13.774977313955912, 14.07124727947029, 14.361406616345075, 14.645818515876813, 14.924811556599304, 15.198684153570666, 15.467708298258023, 15.732132722552272, 15.992185591719478, 16.24807680927192, 16.500000000000004, 16.74813422444423, 16.99264546796643, 17.23368793961409, 17.47140520965615, 17.705931209625778, 17.9373911146521, 18.165902124584953, 18.391574157749524, 18.61451046898629, 18.834808201837365, 19.052558883257657, 19.267848867997692, 19.480759738778158, 19.69136866751522, 19.899748742132406, 20.1059692628831, 20.310096011589902, 20.512191496766018, 20.712315177207984, 20.910523666326487, 21.106870919205438, 21.301408404140798, 21.49418526020468, 21.685248442201445, 21.87464285422736, 22.06241147291021, 22.24859546128699, 22.433234274174556, 22.616365755797286, 22.798026230355998, 22.978250586152118, 23.157072353818823, 23.334523779156072, 23.510635891017497, 23.685438564654024, 23.858960580880304, 24.031229681395832, 24.2022726205619, 24.372115213907886, 24.540782383616055, 24.708298201211672, 24.874685927665503, 25.039968051097834, 25.204166322257123, 25.36730178793165, 25.52939482243949, 25.690465157330262, 25.850531909421132, 26.00961360727991, 26.16772821625905, 26.32489316217637, 26.48112535373072, 26.636441203734407, 26.790856649237632, 26.944387170614963, 27.097047809678457, 27.248853186877426, 27.399817517640518, 27.549954627911823, 27.699277968929085, 27.847800631288646, 27.995535358338834, 28.14249455894058, 28.288690319631275, 28.434134416225866, 28.57883832488648, 28.72281323269015, 28.866070047722122], [0.0, 2.9154759474226504, 4.123105625617661, 5.04975246918104, 5.830951894845301, 6.519202405202649, 7.14142842854285, 7.713624310270757, 8.246211251235321, 8.74642784226795, 9.219544457292887, 9.66953980290686, 10.09950493836208, 10.511898020814321, 10.908712114635716, 11.291589790636214, 11.661903789690601, 12.020815280171307, 12.369316876852983, 12.708265027138836, 13.038404810405298, 13.36038921588739, 13.674794331177344, 13.982131454109563, 14.2828568570857, 14.577379737113253, 14.866068747318508, 15.14925740754312, 15.427248620541514, 15.700318468107584, 15.968719422671311, 16.232683080747925, 16.492422502470642, 16.74813422444423, 17.0, 17.248188310660343, 17.4928556845359, 17.734147850968203, 17.972200755611432, 18.207141456033128, 18.439088914585774, 18.66815470259447, 18.89444362769119, 19.11805429430516, 19.33907960581372, 19.557607215607945, 19.77371993328519, 19.987496091306685, 20.19900987672416, 20.40833163195855, 20.615528128088304, 20.820662813657016, 21.023796041628643, 21.224985276791127, 21.424285285628553, 21.621748310439656, 21.81742422927143, 22.01136070305514, 22.20360331117452, 22.39419567655869, 22.58317958127243, 22.770595073471398, 22.956480566497994, 23.140872930812268, 23.323807579381203, 23.50531854708632, 23.685438564654024, 23.86419912756345, 24.041630560342615, 24.21776207662467, 24.392621835300936, 24.566236993076494, 24.738633753705965, 24.9098374141623, 25.079872407968903, 25.248762345905195, 25.416530054277672, 25.583197610932064, 25.74878637916747, 25.91331703969988, 26.076809620810597, 26.239283526803852, 26.400757564888174, 26.56124997058685, 26.72077843177478, 26.879360111431225, 27.03701166919155, 27.1937492817743, 27.349588662354687, 27.504545078950134, 27.65863337187866, 27.81186797034676, 27.964262908219126, 28.115831839019098, 28.266588050205144, 28.41654447676564, 28.5657137141714, 28.71410803072246, 28.861739379323627, 29.008619408720577, 29.154759474226505, 29.300170647967224], [0.0, 2.958039891549808, 4.183300132670378, 5.1234753829798, 5.916079783099616, 6.614378277661476, 7.245688373094719, 7.826237921249264, 8.366600265340756, 8.874119674649425, 9.354143466934854, 9.810708435174293, 10.2469507659596, 10.665364503850771, 11.067971810589327, 11.4564392373896, 11.832159566199232, 12.196310917650466, 12.549900398011134, 12.893796958227629, 13.228756555322953, 13.55544171172596, 13.874436925511608, 14.186260959111108, 14.491376746189438, 14.790199457749042, 15.083103128998358, 15.3704261489394, 15.652475842498529, 15.929532322073992, 16.20185174601965, 16.469669092000604, 16.73320053068151, 16.99264546796643, 17.24818831066034, 17.5, 17.74823934929885, 17.993054215446584, 18.23458252881047, 18.472953201911167, 18.708286933869708, 18.94069692487581, 19.170289512680817, 19.39716474127082, 19.621416870348586, 19.843134832984425, 20.062402647738878, 20.27929979067325, 20.4939015319192, 20.706279240848655, 20.91650066335189, 21.12463017427761, 21.330729007701542, 21.53485546735803, 21.73706511928416, 21.937410968480307, 22.135943621178654, 22.332711434127297, 22.52776065213762, 22.721135535003526, 22.9128784747792, 23.10303010429584, 23.29162939770423, 23.47871376374779, 23.664319132398465, 23.84848003542364, 24.031229681395832, 24.212600025606502, 24.392621835300933, 24.571324750611232, 24.748737341529164, 24.924887161229037, 25.09980079602227, 25.273503912200223, 25.446021299998943, 25.617376914898998, 25.787593916455258, 25.95669470483482, 26.124700955226263, 26.291633650269816, 26.457513110645905, 26.622359023948274, 26.78619047195775, 26.949025956423732, 27.11088342345192, 27.271780286589284, 27.431733448690405, 27.59075932264279, 27.748873851023216, 27.90609252475165, 28.06243040080456, 28.217902119044926, 28.372521918222215, 28.526303651191824, 28.679260799399977, 28.831406486676986, 28.982753492378876, 29.133314263914432, 29.283100928692644, 29.432125305522877, 29.580398915498083, 29.727932992389498], [0.0, 3.0, 4.242640687119285, 5.196152422706633, 6.0, 6.708203932499369, 7.3484692283495345, 7.937253933193771, 8.48528137423857, 9.0, 9.486832980505138, 9.949874371066201, 10.392304845413266, 10.816653826391969, 11.224972160321824, 11.61895003862225, 12.0, 12.36931687685298, 12.727922061357855, 13.076696830622021, 13.416407864998739, 13.74772708486752, 14.071247279470288, 14.38749456993816, 14.696938456699069, 15.0, 15.297058540778357, 15.588457268119898, 15.874507866387543, 16.155494421403514, 16.431676725154983, 16.703293088490064, 16.97056274847714, 17.23368793961409, 17.4928556845359, 17.74823934929885, 18.0, 18.24828759089466, 18.49324200890693, 18.734993995195197, 18.973665961010276, 19.209372712298546, 19.44222209522358, 19.672315572906, 19.899748742132402, 20.124611797498105, 20.346989949375804, 20.566963801203133, 20.78460969082653, 21.0, 21.213203435596427, 21.424285285628553, 21.633307652783937, 21.840329667841555, 22.045407685048605, 22.24859546128699, 22.44994432064365, 22.64950330581225, 22.847319317591726, 23.043437243605823, 23.2379000772445, 23.430749027719962, 23.62202362203543, 23.811761799581312, 24.0, 24.186773244895647, 24.372115213907882, 24.55605831561735, 24.73863375370596, 24.919871588754226, 25.099800796022265, 25.278449319529077, 25.45584412271571, 25.632011235952593, 25.806975801127876, 25.98076211353316, 26.153393661244042, 26.324893162176366, 26.495282598983543, 26.664583251946766, 26.832815729997478, 27.0, 27.166155414412252, 27.331300737432894, 27.49545416973504, 27.65863337187866, 27.82085548648711, 27.982137159266447, 28.142494558940577, 28.301943396169808, 28.460498941515414, 28.61817604250837, 28.77498913987632, 28.930952282978865, 29.086079144497976, 29.240383034426888, 29.393876913398138, 29.546573405388315, 29.698484809834998, 29.8496231131986, 30.0, 30.14962686336267], [0.0, 3.04138126514911, 4.301162633521314, 5.267826876426371, 6.08276253029822, 6.800735254367722, 7.449832212875671, 8.04673846971554, 8.602325267042628, 9.12414379544733, 9.617692030835673, 10.08712050091601, 10.535653752852742, 10.965856099730656, 11.379806676741042, 11.779218989389747, 12.16552506059644, 12.539936203984452, 12.903487900563942, 13.257073583562853, 13.601470508735444, 13.937359864766355, 14.265342617687105, 14.585952145814822, 14.899664425751341, 15.206906325745551, 15.508062419270825, 15.803480629279111, 16.09347693943108, 16.378339354159202, 16.65833124895768, 16.9336942218761, 17.204650534085257, 17.47140520965615, 17.7341478509682, 17.993054215446584, 18.24828759089466, 18.500000000000004, 18.74833325925268, 18.99341991322258, 19.235384061671347, 19.474342094150447, 19.71040334442703, 19.94367067517913, 20.17424100183202, 20.402205763103165, 20.627651344736268, 20.850659461993043, 21.071307505705484, 21.289668856043768, 21.50581316760657, 21.719806628973476, 21.931712199461312, 22.14158982548453, 22.349496638627013, 22.555487137279925, 22.759613353482084, 22.96192500641007, 23.16246964380094, 23.36129277244733, 23.558437978779494, 23.753947040439407, 23.947860029656095, 24.14021540914662, 24.33105012119288, 24.520399670478458, 24.708298201211676, 24.89477856900921, 25.079872407968903, 25.263610193319565, 25.446021299998947, 25.627134057479, 25.806975801127884, 25.98557292037257, 26.162950903902257, 26.33913438213185, 26.514147167125707, 26.688012290165037, 26.860752037126588, 27.032387981826542, 27.202941017470888, 27.37243138634199, 27.54087870784083, 27.70830200499482, 27.87471972953271, 28.040149785619906, 28.20460955234091, 28.36811590500857, 28.53068523537421, 28.692333470807146, 28.853076092507017, 29.01292815280802, 29.171904291629644, 29.330018752124932, 29.487285395573466, 29.643717715563273, 29.799328851502683, 29.954131601500322, 30.108138434649195, 30.261361502748024, 30.413812651491103, 30.565503431155854], [0.0, 3.0822070014844885, 4.358898943540674, 5.3385391260156565, 6.164414002968977, 6.892024376045112, 7.549834435270751, 8.154753215150047, 8.717797887081348, 9.246621004453464, 9.746794344808965, 10.222524150130438, 10.677078252031313, 11.113055385446437, 11.532562594670797, 11.937336386313323, 12.328828005937954, 12.708265027138834, 13.076696830622023, 13.435028842544405, 13.784048752090223, 14.124446891825537, 14.45683229480096, 14.781745499094484, 15.099668870541501, 15.411035007422443, 15.716233645501715, 16.015617378046972, 16.309506430300093, 16.598192672697834, 16.88194301613413, 17.161002301730516, 17.435595774162696, 17.705931209625778, 17.97220075561143, 18.23458252881047, 18.49324200890693, 18.74833325925268, 19.000000000000004, 19.24837655492016, 19.49358868961793, 19.73575435599055, 19.97498435543818, 20.211382931407737, 20.445048300260876, 20.676073128135332, 20.904544960366874, 21.13054660911544, 21.354156504062626, 21.575449010391416, 21.79449471770337, 22.011360703055143, 22.226110770892873, 22.438805672316878, 22.649503305812253, 22.858258901324923, 23.065125189341593, 23.270152556440195, 23.473389188611005, 23.67488120350343, 23.874672772626646, 24.072806234421446, 24.269322199023197, 24.464259645450134, 24.657656011875908, 24.849547279578356, 25.03996805109783, 25.22895162308573, 25.41653005427767, 25.602734228984218, 25.787593916455254, 25.971137826441108, 26.153393661244046, 26.334388164527386, 26.514147167125703, 26.69269563007828, 26.87005768508881, 27.046256672597043, 27.221315177632402, 27.39525506360545, 27.568097504180447, 27.739863013360395, 27.91057147390573, 28.080242164197944, 28.248893783651074, 28.416544476765644, 28.583211855912904, 28.748913022930104, 28.91366458960192, 29.077482697097423, 29.240383034426895, 29.402380855978315, 29.563490998188968, 29.7237278954037, 29.883105594967873, 30.041637771599603, 30.199337741083003, 30.356218473321086, 30.51229260478472, 30.66757245039131, 30.822070014844886, 30.975797003467083], [0.0, 3.1224989991991996, 4.415880433163924, 5.408326913195985, 6.244997998398399, 6.982120021884471, 7.6485292703891785, 8.261355820929154, 8.831760866327848, 9.367496997597598, 9.87420882906575, 10.356157588603992, 10.81665382639197, 11.258330249197705, 11.683321445547923, 12.093386622447825, 12.489995996796798, 12.874393189583733, 13.247641299491772, 13.610657588816203, 13.964240043768942, 14.309088021254187, 14.645818515876812, 14.974979131871939, 15.297058540778357, 15.612494995995998, 15.921683328090662, 16.224980739587956, 16.522711641858308, 16.81517172080024, 17.102631376487068, 17.385338650713713, 17.663521732655695, 17.9373911146521, 18.207141456033124, 18.472953201911167, 18.734993995195197, 18.99341991322258, 19.24837655492016, 19.500000000000004, 19.7484176581315, 19.993749023132207, 20.236106344848068, 20.47559522944327, 20.712315177207984, 20.946360065653412, 21.17781858454737, 21.40677462860765, 21.63330765278394, 21.857492994394395, 22.07940216581962, 22.29910312097776, 22.51666049839541, 22.732135843338614, 22.945587811167535, 23.157072353818826, 23.366642891095847, 23.57435046825257, 23.780243901188232, 23.984369910422913, 24.18677324489565, 24.387496796514398, 24.586581706288495, 24.78406746278746, 24.979991993593597, 25.174391750348214, 25.36730178793165, 25.55875583826412, 25.748786379167466, 25.937424698685877, 26.124700955226263, 26.310644233845743, 26.495282598983543, 26.678643143908204, 26.860752037126584, 27.041634565979923, 27.221315177632405, 27.399817517640518, 27.57716446627536, 27.753378172755838, 27.928480087537885, 28.102490992792795, 28.275431031197392, 28.447319733148852, 28.618176042508374, 28.788018340969565, 28.95686447114052, 29.124731758421404, 29.291637031753623, 29.457596643310872, 29.622626487197252, 29.786742017212962, 29.949958263743877, 30.1122898498271, 30.273751006441213, 30.434355587066403, 30.594117081556714, 30.753048629363565, 30.911163032147467, 31.068472765811972, 31.224989991991997, 31.380726569026415], [0.0, 3.1622776601683795, 4.47213595499958, 5.477225575051662, 6.324555320336759, 7.0710678118654755, 7.745966692414834, 8.366600265340756, 8.94427190999916, 9.486832980505138, 10.0, 10.488088481701517, 10.954451150103324, 11.401754250991381, 11.832159566199232, 12.24744871391589, 12.649110640673518, 13.038404810405297, 13.416407864998739, 13.784048752090223, 14.142135623730951, 14.49137674618944, 14.832396974191326, 15.165750888103101, 15.491933384829668, 15.811388300841898, 16.124515496597102, 16.431676725154986, 16.73320053068151, 17.029386365926403, 17.32050807568877, 17.60681686165901, 17.88854381999832, 18.165902124584953, 18.439088914585774, 18.708286933869708, 18.973665961010276, 19.235384061671347, 19.49358868961793, 19.7484176581315, 20.0, 20.248456731316587, 20.4939015319192, 20.73644135332772, 20.976176963403034, 21.213203435596423, 21.447610589527216, 21.6794833886788, 21.90890230020665, 22.135943621178654, 22.360679774997898, 22.583179581272432, 22.803508501982762, 23.02172886644268, 23.237900077244504, 23.45207879911715, 23.664319132398465, 23.874672772626646, 24.08318915758459, 24.289915602982237, 24.49489742783178, 24.698178070456937, 24.899799195977465, 25.099800796022265, 25.298221281347036, 25.495097567963924, 25.69046515733026, 25.88435821108957, 26.076809620810593, 26.267851073127396, 26.457513110645905, 26.645825188948457, 26.832815729997478, 27.018512172212592, 27.202941017470884, 27.386127875258307, 27.568097504180447, 27.748873851023216, 27.928480087537885, 28.106938645110393, 28.284271247461902, 28.460498941515414, 28.63564212655271, 28.809720581775867, 28.98275349237888, 29.154759474226502, 29.32575659723036, 29.495762407505254, 29.664793948382652, 29.832867780352593, 30.0, 30.166206257996713, 30.331501776206203, 30.495901363953813, 30.659419433511786, 30.82207001484488, 30.983866769659336, 31.144823004794876, 31.304951684997057, 31.464265445104548, 31.622776601683796, 31.78049716414141], [0.0, 3.2015621187164247, 4.527692569068709, 5.54526825320471, 6.403124237432849, 7.158910531638178, 7.842193570679062, 8.47053717304871, 9.055385138137417, 9.604686356149275, 10.124228365658293, 10.618380290797653, 11.09053650640942, 11.543396380615198, 11.97914855071094, 12.399596767637245, 12.806248474865699, 13.200378782444085, 13.583077707206126, 13.955285736952865, 14.317821063276355, 14.671400751121212, 15.016657417681207, 15.354152532784088, 15.684387141358124, 16.007810593582125, 16.324827717314513, 16.63580475961413, 16.94107434609742, 17.24093964956667, 17.53567791675018, 17.82554346997589, 18.110770276274835, 18.391574157749524, 18.66815470259447, 18.940696924875812, 19.20937271229855, 19.47434209415045, 19.735754355990554, 19.99374902313221, 20.248456731316587, 20.5, 20.748493921246432, 20.99404677521702, 21.236760581595306, 21.47673159491453, 21.714050750608465, 21.94880406764797, 22.18107301281884, 22.41093483101497, 22.638462845343543, 22.863726730347356, 23.086792761230395, 23.307724041613334, 23.526580712037187, 23.743420141167537, 23.95829710142188, 24.171263930543645, 24.38237068047322, 24.591665254715874, 24.79919353527449, 25.004999500099977, 25.209125331911064, 25.411611519146124, 25.612496949731398, 25.811818998280614, 26.009613607279906, 26.20591536275732, 26.40075756488817, 26.594172293944403, 26.78619047195775, 26.976841920432424, 27.166155414412252, 27.35415873317986, 27.54087870784082, 27.726341266023546, 27.91057147390573, 28.093593575760295, 28.27543103119739, 28.456106550264394, 28.63564212655271, 28.814059068447822, 28.991378028648455, 29.16761903207048, 29.342801502242423, 29.516944286290887, 29.690065678607045, 29.862183443278226, 30.033314835362415, 30.20347662107791, 30.372685096974884, 30.540956108150908, 30.708305065568176, 30.874746962525865, 31.040296390337517, 31.20496755325985, 31.36877428271625, 31.531730050855128, 31.693847983480964, 31.855140872392955, 32.01562118716425, 32.175301086392345], [0.0, 3.2403703492039306, 4.582575694955841, 5.612486080160914, 6.480740698407861, 7.24568837309472, 7.937253933193773, 8.573214099741124, 9.165151389911681, 9.72111104761179, 10.2469507659596, 10.74709263010234, 11.224972160321828, 11.683321445547925, 12.124355652982143, 12.549900398011134, 12.961481396815723, 13.360389215887388, 13.747727084867522, 14.124446891825537, 14.49137674618944, 14.8492424049175, 15.198684153570666, 15.540270267920056, 15.874507866387546, 16.201851746019653, 16.52271164185831, 16.83745824048274, 17.146428199482248, 17.44992836661515, 17.74823934929885, 18.041618552668716, 18.330302779823363, 18.61451046898629, 18.894443627691185, 19.170289512680817, 19.44222209522358, 19.71040334442703, 19.97498435543818, 20.236106344848068, 20.4939015319192, 20.748493921246432, 21.000000000000004, 21.24852936087578, 21.49418526020468, 21.737065119284157, 21.97726097583591, 22.214859891523066, 22.449944320643656, 22.682592444427513, 22.912878474779202, 23.14087293081227, 23.36664289109585, 23.590252224170904, 23.81176179958132, 24.031229681395835, 24.248711305964285, 24.464259645450138, 24.677925358506133, 24.889756929307286, 25.09980079602227, 25.30810146968753, 25.51470164434615, 25.71964229922337, 25.922962793631445, 26.124700955226267, 26.32489316217637, 26.52357441974969, 26.720778431774775, 26.916537667389544, 27.11088342345192, 27.303845882952096, 27.495454169735044, 27.685736399814257, 27.874719729532707, 28.062430400804566, 28.248893783651074, 28.434134416225863, 28.618176042508374, 28.80104164782934, 28.98275349237888, 29.163333142835373, 29.342801502242427, 29.521178838251025, 29.698484809835, 29.874738492579315, 30.04995840263344, 30.224162519414833, 30.39736830714133, 30.569592735265545, 30.7408522978788, 30.911163032147467, 31.08054053584011, 31.24899998399949, 31.416556144810023, 31.583223394707513, 31.749015732775092, 31.9139467944659, 32.07802986469088, 32.24127789030702, 32.403703492039305, 32.56531897586757], [0.0, 3.278719262151, 4.636809247747852, 5.6789083458002745, 6.557438524302, 7.33143914930759, 8.031189202104505, 8.674675786448736, 9.273618495495704, 9.836157786453, 10.36822067666386, 10.874281585465774, 11.357816691600549, 11.821590417536889, 12.267844146385297, 12.698425099200293, 13.114877048604, 13.518505834595773, 13.910427743243556, 14.291605927956452, 14.66287829861518, 15.02497920131672, 15.378556499229697, 15.724185193516387, 16.06237840420901, 16.393596310755, 16.718253497300488, 17.03672503740082, 17.349351572897472, 17.656443583009576, 17.958284996067967, 18.255136263528684, 18.547236990991408, 18.834808201837365, 19.118054294305157, 19.397164741270824, 19.672315572906, 19.94367067517913, 20.211382931407737, 20.47559522944327, 20.73644135332772, 20.994046775217015, 21.24852936087578, 21.499999999999996, 21.748563170931547, 21.994317447922764, 22.237355957937083, 22.477766792989023, 22.715633383201098, 22.951034835057, 23.18404623873926, 23.41473894793619, 23.643180835073778, 23.869436524560022, 24.093567606313517, 24.315632831575655, 24.535688292770594, 24.753787588973125, 24.969981978367546, 25.184320518926054, 25.396850198400585, 25.607616054603753, 25.81666128685117, 26.024027359346206, 26.229754097208, 26.433879775772603, 26.636441203734403, 26.837473800639284, 27.037011669191546, 27.23508766279264, 27.4317334486904, 27.626979567082607, 27.820855486487112, 28.013389655662877, 28.204609552340905, 28.394541729001368, 28.583211855912904, 28.7706447616316, 28.956864471140516, 29.141894241795608, 29.32575659723036, 29.508473359359, 29.690065678607045, 29.87055406248769, 30.04995840263344, 30.228298000383678, 30.40559159102154, 30.581857366746057, 30.757112998459395, 30.931375656443084, 31.10466202999158, 31.276988346066823, 31.448370387032774, 31.618823507524752, 31.788362650504666, 31.957002362549584, 32.12475680841802, 32.29163978493505, 32.45766473423496, 32.62284475639732, 32.78719262151, 32.95072078119081], [0.0, 3.3166247903554003, 4.69041575982343, 5.74456264653803, 6.6332495807108005, 7.416198487095664, 8.12403840463596, 8.774964387392123, 9.38083151964686, 9.949874371066201, 10.488088481701517, 11.000000000000004, 11.48912529307606, 11.9582607431014, 12.409673645990857, 12.84523257866513, 13.266499161421601, 13.674794331177344, 14.07124727947029, 14.456832294800963, 14.832396974191328, 15.198684153570666, 15.556349186104047, 15.905973720586868, 16.24807680927192, 16.583123951777, 16.911534525287767, 17.23368793961409, 17.549928774784245, 17.860571099491754, 18.16590212458495, 18.46618531261939, 18.76166303929372, 19.052558883257657, 19.339079605813716, 19.621416870348586, 19.899748742132402, 20.17424100183202, 20.445048300260876, 20.712315177207984, 20.976176963403034, 21.236760581595302, 21.49418526020468, 21.748563170931547, 22.000000000000007, 22.24859546128699, 22.494443758403985, 22.73763400180415, 22.97825058615212, 23.2163735324878, 23.45207879911715, 23.685438564654028, 23.9165214862028, 24.145392935299277, 24.372115213907886, 24.59674775249769, 24.819347291981714, 25.039968051097834, 25.25866188063018, 25.475478405713993, 25.69046515733026, 25.903667693977237, 26.115129714401192, 26.324893162176366, 26.532998322843202, 26.739483914241877, 26.944387170614963, 27.147743920996458, 27.349588662354687, 27.549954627911827, 27.748873851023216, 27.946377224964245, 28.14249455894058, 28.33725463060951, 28.53068523537421, 28.722813232690147, 28.913664589601925, 29.1032644217105, 29.291637031753623, 29.478805945967352, 29.664793948382655, 29.8496231131986, 30.033314835362418, 30.215889859476256, 30.39736830714133, 30.577769702841312, 30.757112998459398, 30.935416596516042, 31.112698372208094, 31.28897569432403, 31.464265445104548, 31.638584039112754, 31.811947441173736, 31.984371183438956, 32.15587038162706, 32.32645975048923, 32.49615361854384, 32.66496594212216, 32.832910318764014, 33.00000000000001, 33.166247903554, 33.33166662499792], [0.0, 3.3541019662496843, 4.743416490252569, 5.809475019311126, 6.7082039324993685, 7.5, 8.215838362577491, 8.874119674649423, 9.486832980505138, 10.062305898749052, 10.606601717798211, 11.124297730643494, 11.618950038622252, 12.093386622447825, 12.549900398011133, 12.990381056766578, 13.416407864998737, 13.829316685939329, 14.230249470757707, 14.620191517213446, 15.0, 15.370426148939398, 15.732132722552272, 16.08570794214541, 16.431676725154983, 16.77050983124842, 17.10263137648707, 17.428425057933378, 17.748239349298846, 18.062391868188442, 18.371173070873834, 18.674849396983095, 18.973665961010276, 19.267848867997696, 19.557607215607945, 19.84313483298443, 20.124611797498105, 20.402205763103165, 20.676073128135332, 20.946360065653412, 21.213203435596423, 21.47673159491453, 21.737065119284157, 21.994317447922768, 22.24859546128699, 22.499999999999996, 22.74862633215465, 22.994564575133836, 23.237900077244504, 23.478713763747788, 23.717082451262844, 23.95307913400697, 24.18677324489565, 24.41823089414956, 24.647515087732476, 24.8746859276655, 25.099800796022265, 25.3229145242012, 25.5440795488896, 25.7633460559765, 25.980762113533157, 26.19637379485947, 26.410225292488512, 26.622359023948267, 26.832815729997474, 27.04163456597992, 27.248853186877422, 27.45450782658469, 27.658633371878658, 27.861263431510064, 28.06243040080456, 28.26216552212516, 28.460498941515414, 28.6574597618142, 28.853076092507013, 29.047375096555626, 29.24038303442689, 29.432125305522874, 29.62262648719725, 29.811910371527684, 30.0, 30.186917696247157, 30.37268509697488, 30.55732318119504, 30.740852297878796, 30.92329219213245, 31.104662029991577, 31.284980421921315, 31.464265445104544, 31.642534664593473, 31.819805153394636, 31.99609351155231, 32.17141588429082, 32.34578797927173, 32.5192250830182, 32.691742076555045, 32.863353450309965, 33.03407331831786, 33.20391543176798, 33.37289319193048, 33.54101966249684, 33.70830758136635], [0.0, 3.3911649915626345, 4.79583152331272, 5.873670062235367, 6.782329983125269, 7.582875444051551, 8.306623862918075, 8.972179222463181, 9.59166304662544, 10.173494974687904, 10.723805294763608, 11.247221879201994, 11.747340124470734, 12.227019260637485, 12.68857754044952, 13.133925536563698, 13.564659966250538, 13.982131454109563, 14.38749456993816, 14.781745499094486, 15.165750888103101, 15.540270267920056, 15.905973720586866, 16.263455967290593, 16.61324772583615, 16.95582495781317, 17.291616465790586, 17.621010186706098, 17.944358444926362, 18.261982367749678, 18.57417562100671, 18.88120758849921, 19.18332609325088, 19.48075973877816, 19.77371993328519, 20.06240264773888, 20.346989949375807, 20.62765134473627, 20.904544960366874, 21.177818584547374, 21.447610589527216, 21.714050750608465, 21.977260975835915, 22.237355957937087, 22.49444375840399, 22.74862633215465, 23.0, 23.24865587512534, 23.494680248941467, 23.73815494093844, 23.9791576165636, 24.217762076624673, 24.45403852127497, 24.688053791257023, 24.91987158875423, 25.149552679918585, 25.37715508089904, 25.602734228984218, 25.826343140289918, 26.04803255526221, 26.267851073127396, 26.485845276298054, 26.70205984563738, 26.91653766738954, 27.129319932501076, 27.340446228984632, 27.549954627911823, 27.757881763564022, 27.964262908219126, 28.169132042006552, 28.372521918222215, 28.5744641244591, 28.77498913987632, 28.97412638890084, 29.17190429162964, 29.36835031117683, 29.56349099818897, 29.75735203273302, 29.949958263743877, 30.141333746203074, 30.331501776206203, 30.52048492406371, 30.70830506556818, 30.894983411550815, 31.08054053584011, 31.264996401726965, 31.448370387032774, 31.630681307869423, 31.811947441173732, 31.992186546092782, 32.17141588429082, 32.349652239243625, 32.526911934581186, 32.703210851535665, 32.8785644455472, 33.05298776207682, 33.2264954516723, 33.399101784329474, 33.57082066318904, 33.74166563760598, 33.91164991562634, 34.08078637590395], [0.0, 3.4278273002005224, 4.847679857416329, 5.937171043518959, 6.855654600401045, 7.664854858377947, 8.396427811873332, 9.069178573608527, 9.695359714832659, 10.283481900601567, 10.8397416943394, 11.368817000902075, 11.874342087037919, 12.359207094308276, 12.82575533838066, 13.275918047351754, 13.71130920080209, 14.133294025102568, 14.543039572248988, 14.941552797483936, 15.329709716755893, 15.70827807240501, 16.077935190813527, 16.439282222773596, 16.792855623746664, 17.13913650100261, 17.478558292948538, 17.81151313055688, 18.138357147217054, 18.459414941974735, 18.774983355518586, 19.085334683992315, 19.390719429665317, 19.69136866751522, 19.987496091306685, 20.27929979067325, 20.566963801203133, 20.850659461993047, 21.13054660911544, 21.406774628607646, 21.6794833886788, 21.94880406764797, 22.214859891523066, 22.477766792989023, 22.73763400180415, 22.994564575133836, 23.24865587512534, 23.5, 23.748684174075837, 23.994791101403653, 24.238399287081645, 24.479583329787296, 24.718414188616553, 24.954959426935563, 25.189283435620002, 25.421447637772324, 25.65151067676132, 25.87952858921507, 26.105554964413226, 26.32964109136317, 26.551836094703507, 26.77218706045511, 26.99073915253156, 27.20753572082558, 27.42261840160418, 27.636027210870957, 27.847800631288642, 28.0579756931964, 28.266588050205137, 28.4736720498077, 28.679260799399973, 28.88338622807236, 29.086079144497976, 29.287369291214944, 29.48728539557346, 29.685855217594796, 29.883105594967873, 30.079062485390065, 30.27375100644121, 30.46719547316425, 30.659419433511786, 30.8504457018047, 31.040296390337517, 31.228992939254383, 31.41655614481002, 31.603006186120965, 31.788362650504666, 31.972644557496338, 32.155870381627054, 32.33805807404025, 32.5192250830182, 32.69938837348491, 32.87856444554719, 33.05676935213119, 33.23401871576774, 33.41032774457622, 33.58571124749333, 33.76018364878959, 33.933759001914304, 34.10645100270622, 34.27827300200522, 34.449238017697866], [0.0, 3.4641016151377553, 4.898979485566357, 6.000000000000002, 6.9282032302755105, 7.745966692414835, 8.485281374238571, 9.165151389911681, 9.797958971132713, 10.392304845413266, 10.954451150103324, 11.48912529307606, 12.000000000000004, 12.4899959967968, 12.961481396815723, 13.41640786499874, 13.856406460551021, 14.2828568570857, 14.69693845669907, 15.099668870541503, 15.49193338482967, 15.874507866387548, 16.24807680927192, 16.613247725836153, 16.970562748477143, 17.320508075688778, 17.6635217326557, 18.000000000000007, 18.330302779823363, 18.654758106177635, 18.973665961010276, 19.287301521985913, 19.595917942265427, 19.899748742132406, 20.19900987672416, 20.4939015319192, 20.78460969082653, 21.071307505705484, 21.354156504062626, 21.63330765278394, 21.90890230020665, 22.18107301281884, 22.449944320643656, 22.715633383201098, 22.97825058615212, 23.2379000772445, 23.494680248941464, 23.748684174075837, 24.000000000000007, 24.248711305964285, 24.494897427831784, 24.73863375370597, 24.9799919935936, 25.21904042583699, 25.455844122715718, 25.690465157330262, 25.922962793631445, 26.153393661244046, 26.381811916545843, 26.608269391300144, 26.83281572999748, 27.05549851693737, 27.276363393971717, 27.49545416973504, 27.712812921102042, 27.928480087537885, 28.14249455894058, 28.354893757515654, 28.5657137141714, 28.774989139876322, 28.98275349237888, 29.189039038652854, 29.39387691339814, 29.597297173897488, 29.79932885150268, 30.000000000000004, 30.199337741083006, 30.39736830714133, 30.594117081556714, 30.78960863668131, 30.98386676965934, 31.176914536239796, 31.368774282716252, 31.559467676119006, 31.749015732775096, 31.937438845342626, 32.12475680841803, 32.31098884280703, 32.49615361854384, 32.68026927673638, 32.86335345030997, 33.045423283716616, 33.22649545167231, 33.406586176980134, 33.585711247493336, 33.76388603226827, 33.941125496954285, 34.117444218463966, 34.2928563989645, 34.46737587922818, 34.641016151377556, 34.813790371058424], [0.0, 3.5, 4.949747468305833, 6.062177826491071, 7.0, 7.826237921249264, 8.573214099741124, 9.260129588726068, 9.899494936611665, 10.5, 11.067971810589327, 11.608186766243902, 12.124355652982143, 12.619429464123964, 13.095800853708795, 13.555441711725958, 14.0, 14.430869689661812, 14.849242404917499, 15.25614630239236, 15.652475842498529, 16.03901493234544, 16.416455159382004, 16.78541033159452, 17.146428199482248, 17.5, 17.84656829757475, 18.186533479473216, 18.520259177452136, 18.848076824970764, 19.17028951268081, 19.487175269905077, 19.79898987322333, 20.105969262883104, 20.40833163195855, 20.70627924084866, 21.0, 21.28966885604377, 21.57544901039142, 21.857492994394395, 22.135943621178654, 22.41093483101497, 22.682592444427513, 22.951034835057, 23.216373532487804, 23.478713763747788, 23.738154940938436, 23.994791101403656, 24.248711305964285, 24.5, 24.748737341529164, 24.99499949989998, 25.23885892824793, 25.480384612481817, 25.719642299223374, 25.956694704834824, 26.19160170741759, 26.424420523447626, 26.65520587052368, 26.88401011754013, 27.110883423451916, 27.33587386567329, 27.55902755904134, 27.7803887661782, 28.0, 28.217902119044926, 28.434134416225863, 28.648734701553575, 28.861739379323623, 29.073183520213263, 29.283100928692644, 29.49152420611726, 29.698484809834998, 29.90401310861136, 30.10813843464919, 30.310889132455355, 30.51229260478472, 30.712375355872428, 30.911163032147467, 31.10868046060456, 31.304951684997057, 31.5, 31.693847983480964, 31.886517527005047, 32.07802986469088, 32.26840560052511, 32.45766473423496, 32.64582668581085, 32.83291031876401, 33.01893396219811, 33.20391543176798, 33.3878720495931, 33.57082066318904, 33.75277766347534, 33.933759001914304, 34.11378020683137, 34.292856398964496, 34.471002306286366, 34.64823227814083, 34.8245602987317, 35.0, 35.174564673923115], [0.0, 3.535533905932738, 5.000000000000001, 6.123724356957947, 7.071067811865476, 7.905694150420949, 8.660254037844387, 9.354143466934854, 10.000000000000002, 10.606601717798213, 11.180339887498949, 11.726039399558577, 12.247448713915894, 12.747548783981964, 13.228756555322954, 13.693063937629153, 14.142135623730953, 14.577379737113251, 15.000000000000002, 15.411035007422443, 15.811388300841898, 16.201851746019653, 16.583123951777, 16.95582495781317, 17.320508075688775, 17.67766952966369, 18.02775637731995, 18.37117307087384, 18.708286933869708, 19.03943276465977, 19.364916731037084, 19.685019685029527, 20.000000000000004, 20.310096011589906, 20.615528128088304, 20.91650066335189, 21.213203435596427, 21.505813167606572, 21.794494717703373, 22.07940216581962, 22.360679774997898, 22.638462845343543, 22.912878474779205, 23.18404623873926, 23.452078799117153, 23.717082451262844, 23.979157616563597, 24.23839928708165, 24.494897427831788, 24.748737341529164, 25.000000000000004, 25.2487623459052, 25.495097567963928, 25.739075352467506, 25.980762113533164, 26.220221204253793, 26.45751311064591, 26.69269563007828, 26.925824035672523, 27.15695122800054, 27.386127875258307, 27.613402542968153, 27.838821814150112, 28.062430400804562, 28.284271247461906, 28.504385627478452, 28.722813232690147, 28.939592256975565, 29.154759474226502, 29.36835031117683, 29.58039891549808, 29.790938219532464, 30.000000000000004, 30.20761493398643, 30.413812651491096, 30.618621784789728, 30.822070014844886, 31.024184114977142, 31.224989991991997, 31.42451272494134, 31.622776601683796, 31.81980515339464, 32.01562118716425, 32.21024681681281, 32.403703492039305, 32.59601202601324, 32.78719262151, 32.9772648956823, 33.166247903554, 33.354160160315836, 33.54101966249685, 33.726843908080106, 33.91164991562634, 34.09545424246464, 34.27827300200523, 34.46012188022555, 34.64101615137755, 34.8209706929603, 35.0, 35.178118198675726, 35.35533905932738, 35.53167600887974], [0.0, 3.5707142142714257, 5.04975246918104, 6.184658438426492, 7.141428428542851, 7.9843597113356575, 8.746427842267952, 9.447221813845593, 10.09950493836208, 10.712142642814277, 11.291589790636216, 11.842719282327014, 12.369316876852984, 12.874393189583735, 13.36038921588739, 13.829316685939332, 14.282856857085703, 14.722431864335457, 15.14925740754312, 15.564382416273384, 15.968719422671315, 16.363068171953575, 16.74813422444423, 17.12454378954371, 17.492855684535904, 17.853571071357127, 18.207141456033128, 18.553975315279477, 18.894443627691185, 19.228884523029414, 19.557607215607945, 19.880895352071047, 20.19900987672416, 20.51219149676602, 20.820662813657016, 21.124630174277613, 21.424285285628553, 21.719806628973476, 22.011360703055143, 22.29910312097776, 22.583179581272432, 22.863726730347356, 23.140872930812275, 23.414738947936193, 23.685438564654028, 23.953079134006966, 24.21776207662467, 24.4795833297873, 24.73863375370597, 24.994999499899976, 25.2487623459052, 25.500000000000007, 25.74878637916747, 25.995191863111923, 26.23928352680386, 26.481125353730725, 26.72077843177478, 26.958301133417148, 27.1937492817743, 27.427176303804956, 27.658633371878665, 27.888169534768682, 28.1158318390191, 28.34166544153678, 28.565713714171405, 28.78801834096957, 29.008619408720577, 29.22755549135097, 29.444863728670914, 29.66057989992779, 29.874738492579315, 30.087372766660774, 30.29851481508624, 30.508195620193604, 30.71644510681534, 30.923292192132458, 31.128764832546768, 31.3328900677866, 31.535694062442964, 31.737202145116704, 31.93743884534263, 32.13642792844283, 32.33419242844949, 32.53075467922625, 32.72613634390715, 32.920358442763046, 33.1134413795969, 33.305404966761785, 33.49626844888846, 33.68605052540295, 33.87476937190865, 34.0624426605022, 34.24908757908742, 34.434720849746995, 34.619358746227526, 34.80301711058971, 34.98571136907181, 35.16745654721138, 35.34826728426728, 35.52815784698104, 35.707142142714254, 35.88523373199624], [0.0, 3.6055512754639896, 5.099019513592785, 6.2449979983984, 7.211102550927979, 8.062257748298551, 8.831760866327848, 9.539392014169458, 10.19803902718557, 10.816653826391969, 11.401754250991381, 11.9582607431014, 12.4899959967968, 13.000000000000002, 13.490737563232042, 13.964240043768942, 14.422205101855958, 14.866068747318506, 15.297058540778357, 15.716233645501713, 16.124515496597102, 16.522711641858308, 16.911534525287763, 17.291616465790582, 17.663521732655695, 18.02775637731995, 18.38477631085024, 18.7349939951952, 19.078784028338916, 19.416487838947603, 19.748417658131498, 20.074859899884732, 20.39607805437114, 20.712315177207984, 21.02379604162864, 21.330729007701546, 21.633307652783937, 21.931712199461312, 22.226110770892873, 22.51666049839541, 22.803508501982762, 23.08679276123039, 23.36664289109585, 23.643180835073778, 23.9165214862028, 24.186773244895647, 24.454038521274967, 24.718414188616553, 24.9799919935936, 25.238858928247925, 25.495097567963928, 25.74878637916747, 26.000000000000004, 26.24880949681338, 26.495282598983547, 26.73948391424188, 26.981475126464083, 27.221315177632402, 27.459060435491963, 27.694764848252458, 27.928480087537885, 28.160255680657446, 28.390139133156783, 28.61817604250837, 28.844410203711917, 29.068883707497267, 29.291637031753623, 29.512709126747414, 29.732137494637012, 29.949958263743877, 30.166206257996713, 30.38091506192663, 30.594117081556714, 30.80584360149873, 31.016124838541643, 31.224989991991993, 31.432467291003427, 31.63858403911275, 31.84336665618132, 32.046840717924134, 32.249030993194204, 32.449961479175904, 32.649655434629025, 32.848135411313685, 33.045423283716616, 33.24154027718932, 33.436506994600975, 33.63034344160048, 33.823069050575526, 34.0147027033899, 34.20526275297414, 34.39476704383968, 34.583232931581165, 34.77067730142742, 34.957116585897076, 35.14256678161116, 35.32704346531139, 35.51056180912941, 35.6931365951495, 35.874782229304195, 36.0555127546399, 36.23534186398688], [0.0, 3.64005494464026, 5.147815070493501, 6.304760106459248, 7.28010988928052, 8.139410298049855, 8.916277250063505, 9.630680142129112, 10.295630140987003, 10.92016483392078, 11.51086443322134, 12.072696467649639, 12.609520212918495, 13.12440474840669, 13.619838471876237, 14.097872179871686, 14.56021977856104, 15.008331019803634, 15.443445211480503, 15.866631652622434, 16.27882059609971, 16.68082731761228, 17.073371078963874, 17.457090250096094, 17.83255450012701, 18.2002747232013, 18.560711193270592, 18.914280319377742, 19.261360284258224, 19.602295783912663, 19.937402037376884, 20.266968199511247, 20.591260281974005, 20.91052366632649, 21.224985276791127, 21.53485546735803, 21.84032966784156, 22.141589825484534, 22.43880567231688, 22.732135843338614, 23.02172886644268, 23.307724041613334, 23.590252224170904, 23.869436524560022, 24.145392935299277, 24.41823089414956, 24.68805379125702, 24.954959426935563, 25.21904042583699, 25.480384612481817, 25.739075352467506, 25.995191863111923, 26.24880949681338, 26.500000000000007, 26.74883175019052, 26.995369973386182, 27.239676943752475, 27.481812167322595, 27.721832551258228, 27.95979256003163, 28.195744359743372, 28.429737951659, 28.66182129593303, 28.892040426387336, 29.12043955712208, 29.34706118165838, 29.571946165242494, 29.795133830879166, 30.01666203960727, 30.236567265481714, 30.454884665682123, 30.671648146130007, 30.886890422961006, 31.100643080167977, 31.312936623702353, 31.523800532296235, 31.73326330524487, 31.94135250736888, 32.148094811357026, 32.35351603767356, 32.55764119219942, 32.76049450176234, 32.962099447699025, 33.16247879758086, 33.36165463522456, 33.55964838909967, 33.7564808592365, 33.95217224272992, 34.14674215792775, 34.34020966738555, 34.532593299664015, 34.723911070039335, 34.91418050019219, 35.103418636936205, 35.2916420700426, 35.47886694921358, 35.66510900025402, 35.85038354048671, 36.03470549345451, 36.21808940294891, 36.4005494464026, 36.5820994476807], [0.0, 3.6742346141747677, 5.196152422706632, 6.363961030678929, 7.348469228349535, 8.215838362577493, 9.0, 9.72111104761179, 10.392304845413264, 11.022703842524303, 11.618950038622252, 12.186057606953943, 12.727922061357859, 13.247641299491772, 13.74772708486752, 14.230249470757707, 14.69693845669907, 15.149257407543116, 15.588457268119896, 16.01561737804697, 16.431676725154986, 16.83745824048274, 17.233687939614086, 17.621010186706098, 18.0, 18.371173070873837, 18.734993995195197, 19.091883092036788, 19.44222209522358, 19.786358937409382, 20.124611797498105, 20.457272545478784, 20.784609690826528, 21.106870919205438, 21.42428528562855, 21.73706511928416, 22.045407685048605, 22.349496638627013, 22.649503305812253, 22.945587811167535, 23.237900077244504, 23.526580712037184, 23.81176179958132, 24.093567606313517, 24.372115213907886, 24.647515087732472, 24.919871588754223, 25.18928343562, 25.455844122715718, 25.71964229922337, 25.98076211353316, 26.239283526803856, 26.495282598983543, 26.748831750190515, 27.000000000000004, 27.24885318687743, 27.49545416973504, 27.7398630133604, 27.982137159266447, 28.222331583340168, 28.460498941515414, 28.696689704563486, 28.930952282978865, 29.16333314283537, 29.39387691339814, 29.62262648719725, 29.8496231131986, 30.074906483645133, 30.298514815086232, 30.52048492406371, 30.740852297878796, 30.95965116082544, 31.176914536239792, 31.392674304684526, 31.606961258558215, 31.81980515339464, 32.03123475609394, 32.24127789030702, 32.449961479175904, 32.657311585615865, 32.86335345030997, 33.0681115275729, 33.27160951922826, 33.473870406632095, 33.67491648096548, 33.87476937190865, 34.07345007480164, 34.27097897638759, 34.46737587922817, 34.66266002487403, 34.856850115866756, 35.04996433664377, 35.242020373412196, 35.43303543305315, 35.62302626111376, 35.812009158939965, 36.0, 36.18701424544446, 36.373066958946424, 36.55817282086183, 36.742346141747674, 36.92560087527352], [0.0, 3.708099243547832, 5.244044240850759, 6.422616289332566, 7.416198487095664, 8.2915619758885, 9.082951062292477, 9.810708435174293, 10.488088481701517, 11.124297730643494, 11.726039399558575, 12.298373876248846, 12.845232578665131, 13.36974195712094, 13.874436925511608, 14.361406616345072, 14.832396974191328, 15.288884851420654, 15.732132722552274, 16.163229875244618, 16.583123951777, 16.99264546796643, 17.392527130926087, 17.78341924377874, 18.165902124584953, 18.54049621773916, 18.90767040118904, 19.267848867997696, 19.621416870348586, 19.96872554771586, 20.3100960115899, 20.64582282206258, 20.976176963403034, 21.301408404140798, 21.621748310439653, 21.937410968480307, 22.24859546128699, 22.555487137279925, 22.858258901324923, 23.157072353818826, 23.45207879911715, 23.743420141167533, 24.031229681395835, 24.315632831575655, 24.59674775249769, 24.874685927665496, 25.149552679918582, 25.421447637772324, 25.690465157330262, 25.95669470483482, 26.22022120425379, 26.481125353730725, 26.73948391424188, 26.995369973386182, 27.24885318687743, 27.500000000000004, 27.748873851023216, 27.995535358338838, 28.24004249288588, 28.48245073725223, 28.722813232690143, 28.96118091514916, 29.197602641312866, 29.432125305522874, 29.664793948382655, 29.895651857753496, 30.124740662784138, 30.35210042155238, 30.57776970284131, 30.80178566252288, 31.024184114977142, 31.24499959993599, 31.464265445104548, 31.68201382488178, 31.89827581547316, 32.113081446662825, 32.326459750489235, 32.53843880704789, 32.74904578762563, 32.95830699535399, 33.166247903554, 33.37289319193049, 33.57826678076164, 33.78239186321774, 33.98529093593286, 34.18698582794336, 34.3874977280988, 34.586847211042524, 34.785054261852174, 34.9821382994236, 35.178118198675726, 35.37301231164799, 35.56683848755748, 35.759614091877445, 35.951356024495105, 36.142080737002395, 36.331804249169906, 36.5205421646503, 36.70830968595531, 36.89512162874653, 37.08099243547832, 37.26593618842817], [0.0, 3.7416573867739413, 5.291502622129181, 6.480740698407861, 7.483314773547883, 8.366600265340756, 9.16515138991168, 9.899494936611665, 10.583005244258363, 11.224972160321824, 11.832159566199232, 12.409673645990859, 12.961481396815723, 13.490737563232042, 14.0, 14.491376746189438, 14.966629547095765, 15.42724862054151, 15.874507866387544, 16.309506430300093, 16.73320053068151, 17.146428199482248, 17.549928774784245, 17.944358444926362, 18.33030277982336, 18.708286933869708, 19.078784028338916, 19.442222095223585, 19.79898987322333, 20.149441679609886, 20.493901531919192, 20.83266665599966, 21.166010488516726, 21.49418526020468, 21.817424229271428, 22.135943621178654, 22.44994432064365, 22.759613353482088, 23.065125189341593, 23.366642891095847, 23.664319132398465, 23.958297101421877, 24.248711305964285, 24.535688292770594, 24.819347291981718, 25.09980079602226, 25.37715508089904, 25.651510676761323, 25.922962793631445, 26.19160170741759, 26.457513110645905, 26.72077843177478, 26.981475126464083, 27.239676943752475, 27.49545416973504, 27.748873851023216, 28.0, 28.24889378365107, 28.495613697550013, 28.740215726399825, 28.982753492378876, 29.223278392404914, 29.46183972531247, 29.698484809834994, 29.93325909419153, 30.166206257996713, 30.397368307141328, 30.626785662227107, 30.85449724108302, 31.080540535840107, 31.304951684997054, 31.527765540868895, 31.74901573277509, 31.96873472629156, 32.186953878862155, 32.4037034920393, 32.619012860600186, 32.83291031876401, 33.045423283716616, 33.25657829663178, 33.46640106136302, 33.67491648096547, 33.88214869219484, 34.08812109811862, 34.292856398964496, 34.49637662132068, 34.698703145794944, 34.899856733230294, 35.09985754956849, 35.29872518944558, 35.4964786985977, 35.6931365951495, 35.888716889852724, 36.08323710533743, 36.276714294434115, 36.469165057620934, 36.66060555964672, 36.851051545376556, 37.04051835490427, 37.22902093797257, 37.416573867739416, 37.603191353926334], [0.0, 3.774917217635375, 5.338539126015656, 6.538348415311011, 7.54983443527075, 8.440971508067067, 9.246621004453464, 9.987492177719089, 10.677078252031311, 11.324751652906125, 11.937336386313323, 12.519984025548917, 13.076696830622023, 13.610657588816201, 14.124446891825535, 14.620191517213446, 15.0996688705415, 15.56438241627338, 16.01561737804697, 16.454482671904337, 16.881943016134134, 17.298843892006197, 17.705931209625774, 18.103866990231673, 18.49324200890693, 18.874586088176876, 19.24837655492016, 19.615045245933036, 19.974984355438178, 20.328551350256124, 20.67607312813533, 21.017849556983702, 21.354156504062622, 21.685248442201445, 22.01136070305514, 22.332711434127297, 22.64950330581225, 22.96192500641007, 23.270152556440195, 23.574350468252568, 23.874672772626646, 24.171263930543642, 24.464259645450138, 24.753787588973125, 25.039968051097834, 25.322914524201195, 25.602734228984215, 25.87952858921507, 26.153393661244046, 26.424420523447623, 26.69269563007828, 26.958301133417145, 27.221315177632402, 27.481812167322595, 27.7398630133604, 27.995535358338838, 28.24889378365107, 28.500000000000004, 28.748913022930104, 28.995689334795955, 29.24038303442689, 29.483045975611134, 29.723727895403698, 29.962476533157268, 30.199337741083, 30.434355587066403, 30.667572450391308, 30.899029110960754, 31.12876483254676, 31.356817440550312, 31.583223394707513, 31.80801785713785, 32.03123475609394, 32.25290684574028, 32.47306576225903, 32.69174207655505, 32.908965343808674, 33.12476415010377, 33.3391661563393, 33.552198139615236, 33.76388603226827, 33.974254958718376, 34.18332927027443, 34.39113257803529, 34.59768778401239, 34.80301711058971, 35.00714212842859, 35.210083782916506, 35.41186241925155, 35.61249780624774, 35.812009158939965, 36.01041516006168, 36.207733980463345, 36.40398329853479, 36.5991803186902, 36.79334178897046, 36.98648401781386, 37.17862289004261, 37.36977388210959, 37.559952076646745, 37.74917217635375, 37.937448517263256], [0.0, 3.8078865529319548, 5.385164807134505, 6.595452979136462, 7.6157731058639095, 8.514693182963201, 9.327379053088816, 10.074720839804943, 10.77032961426901, 11.423659658795863, 12.041594578792296, 12.629330940315091, 13.190905958272923, 13.729530217745983, 14.247806848775008, 14.747881203752627, 15.231546211727819, 15.700318468107582, 16.155494421403514, 16.598192672697834, 17.029386365926403, 17.44992836661515, 17.860571099491754, 18.261982367749674, 18.65475810617763, 19.039432764659775, 19.416487838947603, 19.786358937409382, 20.149441679609886, 20.50609665440988, 20.85665361461421, 21.201415047114192, 21.54065922853802, 21.874642854227364, 22.20360331117452, 22.527760652137623, 22.847319317591726, 23.162469643800943, 23.47338918861101, 23.780243901188236, 24.08318915758459, 24.38237068047322, 24.677925358506137, 24.969981978367546, 25.258661880630182, 25.5440795488896, 25.826343140289918, 26.10555496441323, 26.381811916545846, 26.65520587052368, 26.925824035672523, 27.1937492817743, 27.459060435491967, 27.721832551258228, 27.98213715926645, 28.24004249288588, 28.495613697550016, 28.748913022930104, 29.000000000000004, 29.248931604419333, 29.495762407505254, 29.740544715926102, 29.983328701129903, 30.224162519414826, 30.463092423455638, 30.700162866017504, 30.935416596516042, 31.1688947510174, 31.400636936215164, 31.630681307869427, 31.859064644147985, 32.0858224142689, 32.31098884280703, 32.53459696999488, 32.7566787083184, 32.9772648956823, 33.19638534539567, 33.414068893207244, 33.63034344160048, 33.8452360015409, 34.058772731852805, 34.27097897638759, 34.48187929913334, 34.69149751740331, 34.8998567332303, 35.106979363083916, 35.31288716601915, 35.51760127035609, 35.72114219898351, 35.92352989337211, 36.12478373637689, 36.32492257390235, 36.52396473549935, 36.72192805395708, 36.91882988394947, 37.11468711979127, 37.30951621235526, 37.50333318519836, 37.69615364994153, 37.88799282094527, 38.07886552931955, 38.26878623630491], [0.0, 3.840572873934304, 5.431390245600108, 6.652067347825036, 7.681145747868608, 8.587782018658833, 9.40744386111339, 10.161200716450788, 10.862780491200215, 11.521718621802911, 12.144957801491119, 12.737739202856998, 13.304134695650072, 13.847382424126229, 14.370107863199914, 14.874474780643515, 15.362291495737216, 15.835087622113113, 16.294170736800325, 16.740669042783207, 17.175564037317667, 17.599715906798043, 18.01388353465182, 18.418740456393863, 18.81488772222678, 19.20286436967152, 19.58315602756614, 19.95620204347511, 20.322401432901575, 20.682117879946436, 21.035683967962626, 21.383404780343096, 21.72556098240043, 22.06241147291021, 22.39419567655869, 22.721135535003526, 23.043437243605823, 23.361292772447335, 23.674881203503432, 23.984369910422913, 24.289915602982237, 24.591665254715874, 24.889756929307286, 25.184320518926054, 25.475478405713996, 25.7633460559765, 26.048032555262207, 26.32964109136317, 26.608269391300144, 26.884010117540125, 27.15695122800054, 27.427176303804956, 27.694764848252458, 27.95979256003163, 28.22233158334017, 28.48245073725223, 28.74021572639983, 28.99568933479596, 29.24893160441933, 29.499999999999996, 29.74894956128703, 29.995833043941282, 30.24070105007488, 30.48360214935236, 30.72458299147443, 30.96368841078207, 31.20096152364539, 31.436443819236295, 31.670175244226225, 31.90219428189854, 32.132538026119256, 32.361242250568814, 32.58834147360065, 32.81386901905961, 33.037857073363575, 33.26033673912518, 33.481338085566414, 33.70089019595773, 33.91902121229326, 34.13575837739657, 34.351128074635334, 34.565155865408734, 34.777866524558405, 34.98928407384181, 35.199431813596085, 35.408332352710424, 35.61600763701625, 35.82247897619594, 36.02776706930364, 36.231892028984625, 36.43487340447336, 36.636730203444735, 36.837480912787726, 37.03714351836545, 37.23573552382174, 37.43327396848958, 37.62977544445356, 37.82525611281436, 38.019731719200756, 38.21321760857099, 38.40572873934304, 38.59727969689056], [0.0, 3.8729833462074166, 5.477225575051661, 6.708203932499369, 7.745966692414833, 8.660254037844386, 9.486832980505138, 10.246950765959598, 10.954451150103322, 11.61895003862225, 12.24744871391589, 12.84523257866513, 13.416407864998739, 13.96424004376894, 14.491376746189438, 14.999999999999998, 15.491933384829666, 15.96871942267131, 16.431676725154983, 16.881943016134134, 17.32050807568877, 17.74823934929885, 18.16590212458495, 18.57417562100671, 18.973665961010276, 19.364916731037084, 19.7484176581315, 20.12461179749811, 20.493901531919196, 20.85665361461421, 21.213203435596423, 21.563858652847824, 21.908902300206645, 22.24859546128699, 22.58317958127243, 22.9128784747792, 23.2379000772445, 23.558437978779494, 23.874672772626646, 24.18677324489565, 24.49489742783178, 24.799193535274487, 25.09980079602227, 25.396850198400585, 25.69046515733026, 25.980762113533153, 26.267851073127392, 26.551836094703507, 26.832815729997478, 27.110883423451916, 27.386127875258303, 27.65863337187866, 27.92848008753788, 28.19574435974337, 28.460498941515414, 28.722813232690143, 28.982753492378876, 29.24038303442689, 29.49576240750525, 29.74894956128703, 29.999999999999996, 30.248966924508345, 30.49590136395381, 30.740852297878792, 30.983866769659333, 31.22498999199199, 31.464265445104544, 31.701734968294716, 31.93743884534262, 32.17141588429082, 32.4037034920393, 32.63433774416144, 32.863353450309965, 33.09078421554859, 33.31666249791536, 33.54101966249684, 33.76388603226827, 33.98529093593285, 34.20526275297414, 34.423828956117006, 34.64101615137754, 34.85685011586675, 35.07135583350036, 35.284557528754696, 35.4964786985977, 35.70714214271425, 35.91656999213594, 36.124783736376884, 36.3318042491699, 36.53765181289022, 36.74234614174767, 36.94590640382233, 37.14835124201342, 37.3496987939662, 37.54996671103717, 37.74917217635374, 37.94733192202055, 38.144462245521304, 38.34057902536163, 38.535697735995385, 38.72983346207417, 38.92300091205713], [0.0, 3.9051248379533274, 5.522680508593631, 6.763874629234342, 7.810249675906655, 8.732124598286491, 9.565563234854496, 10.331989159885913, 11.045361017187261, 11.715374513859981, 12.349089035228468, 12.95183384698862, 13.527749258468685, 14.080127840328725, 14.611639196202457, 15.124483462254172, 15.62049935181331, 16.101242188104617, 16.56804152578089, 17.022044530549202, 17.464249196572982, 17.89553016817328, 18.3166590840142, 18.728320800328042, 19.131126469708992, 19.52562418976664, 19.91230775173988, 20.29162388770303, 20.663978319771825, 21.02974084481309, 21.389249636207435, 21.742814905158898, 22.090722034374522, 22.43323427417456, 22.770595073471398, 23.103030104295843, 23.430749027719962, 23.753947040439407, 24.072806234421446, 24.387496796514398, 24.698178070456937, 25.004999500099974, 25.308101469687532, 25.607616054603753, 25.90366769397724, 26.19637379485947, 26.485845276298054, 26.77218706045511, 27.05549851693737, 27.33587386567329, 27.613402542968153, 27.888169534768682, 28.16025568065745, 28.429737951659, 28.69668970456349, 28.961180915149164, 29.223278392404914, 29.483045975611137, 29.740544715926102, 29.995833043941285, 30.248966924508345, 30.499999999999996, 30.748983723043597, 30.995967479657736, 31.24099870362662, 31.48412298286233, 31.72538415843061, 31.96482441684922, 32.202484376209235, 32.43840316661719, 32.67261850540908, 32.90516676754579, 33.13608305156178, 33.36540124140574, 33.593154064481645, 33.819373146171706, 34.044089061098404, 34.267331381360876, 34.48912872196107, 34.70950878361721, 34.928498393145965, 35.14612354157995, 35.362409420173854, 35.57738045444043, 35.79106033634656, 36.003472054789384, 36.21463792446364, 36.42457961322272, 36.6333181680284, 36.84087403957729, 37.04726710568541, 37.25251669350676, 37.456641600656084, 37.659660115301094, 37.861590035285104, 38.06244868633651, 38.262252939417984, 38.46101922726438, 38.658763560155414, 38.855501540965854, 39.05124837953328, 39.24601890638081], [0.0, 3.9370039370059056, 5.5677643628300215, 6.8190908484929285, 7.874007874011811, 8.803408430829505, 9.643650760992955, 10.41633332799983, 11.135528725660043, 11.811011811017716, 12.449899597988733, 13.057564857200596, 13.638181696985857, 14.195069566578391, 14.730919862656235, 15.247950681976905, 15.748015748023622, 16.232683080747925, 16.703293088490067, 17.161002301730516, 17.60681686165901, 18.041618552668716, 18.466185312619388, 18.881207588499205, 19.28730152198591, 19.685019685029527, 20.074859899884732, 20.457272545478787, 20.83266665599966, 21.201415047114192, 21.56385865284782, 21.920310216782973, 22.271057451320086, 22.616365755797286, 22.95648056649799, 23.29162939770423, 23.62202362203543, 23.947860029656095, 24.269322199023197, 24.586581706288495, 24.899799195977465, 25.20912533191106, 25.51470164434615, 25.81666128685117, 26.115129714401192, 26.41022529248851, 26.702059845637375, 26.99073915253156, 27.276363393971714, 27.559027559041336, 27.83882181415011, 28.115831839019098, 28.390139133156783, 28.661821295933027, 28.93095228297887, 29.197602641312866, 29.46183972531247, 29.723727895403698, 29.9833287011299, 30.24070105007488, 30.49590136395381, 30.748983723043594, 31.0, 31.248999983999486, 31.496031496047245, 31.741140496207755, 31.984371183438952, 32.225766088644036, 32.46536616149585, 32.703210851535665, 32.93933818400121, 33.17378483079674, 33.406586176980134, 33.63777638310832, 33.8673884437522, 34.09545424246464, 34.32200460346103, 34.547069340249394, 34.77067730142742, 34.99285641384538, 35.21363372331802, 35.43303543305315, 35.651086939951774, 35.8678128689219, 36.08323710533743, 36.29738282576307, 36.51027252705737, 36.72192805395708, 36.932370625238775, 37.141620858546275, 37.3496987939662, 37.556623916427846, 37.76241517699841, 37.96709101313926, 38.17066936798463, 38.37316770869978, 38.57460304397182, 38.7749919406826, 38.97435053981015, 39.17269457160179, 39.370039370059054, 39.566399886772615], [0.0, 3.968626966596886, 5.612486080160912, 6.873863542433761, 7.937253933193772, 8.874119674649425, 9.72111104761179, 10.5, 11.224972160321824, 11.905880899790658, 12.549900398011133, 13.162446581088185, 13.747727084867522, 14.309088021254187, 14.849242404917499, 15.370426148939398, 15.874507866387544, 16.36306817195357, 16.837458240482736, 17.298843892006197, 17.74823934929885, 18.186533479473212, 18.614510468986285, 19.03286631067428, 19.44222209522358, 19.843134832984433, 20.236106344848064, 20.621590627301284, 21.0, 21.371710273162513, 21.737065119284157, 22.096379793984354, 22.44994432064365, 22.798026230356, 23.140872930812268, 23.478713763747795, 23.811761799581316, 24.140215409146624, 24.464259645450138, 24.784067462787462, 25.099800796022265, 25.411611519146124, 25.719642299223374, 26.024027359346206, 26.32489316217637, 26.62235902394827, 26.91653766738954, 27.207535720825582, 27.495454169735044, 27.780388766178202, 28.062430400804562, 28.34166544153678, 28.618176042508374, 28.892040426387336, 29.163333142835373, 29.432125305522877, 29.698484809834998, 29.96247653315727, 30.22416251941483, 30.48360214935236, 30.740852297878796, 30.995967479657736, 31.24899998399949, 31.5, 31.74901573277509, 31.996093511552314, 32.24127789030702, 32.48461174156157, 32.72613634390714, 32.96589146375387, 33.20391543176798, 33.44024521441193, 33.67491648096547, 33.90796366637195, 34.13942003022312, 34.3693177121688, 34.59768778401239, 34.8245602987317, 35.049964336643775, 35.27392804891454, 35.4964786985977, 35.71764269937197, 35.93744565213282, 36.15591237958185, 36.373066958946424, 36.5889327529514, 36.803532439155894, 37.0168880377592, 37.22902093797257, 37.43995192304605, 37.6497011940334, 37.85828839237189, 38.06573262134856, 38.27205246651922, 38.477266015141986, 38.681390874682876, 38.88444419044716, 39.086442662386155, 39.287402561126385, 39.48733974326455, 39.686269665968865, 39.88420740092499], [0.0, 4.0, 5.656854249492381, 6.9282032302755105, 8.0, 8.94427190999916, 9.797958971132713, 10.583005244258363, 11.313708498984761, 12.0, 12.649110640673518, 13.266499161421603, 13.856406460551021, 14.422205101855958, 14.966629547095765, 15.491933384829668, 16.0, 16.492422502470642, 16.970562748477143, 17.435595774162696, 17.88854381999832, 18.330302779823363, 18.76166303929372, 19.18332609325088, 19.595917942265427, 20.000000000000004, 20.39607805437114, 20.78460969082653, 21.166010488516726, 21.54065922853802, 21.90890230020664, 22.27105745132009, 22.627416997969522, 22.978250586152118, 23.323807579381203, 23.664319132398465, 24.0, 24.33105012119288, 24.657656011875908, 24.979991993593597, 25.298221281347036, 25.612496949731394, 25.922962793631445, 26.229754097208, 26.532998322843206, 26.832815729997474, 27.129319932501073, 27.42261840160418, 27.712812921102042, 28.0, 28.284271247461902, 28.565713714171405, 28.844410203711917, 29.120439557122076, 29.39387691339814, 29.664793948382655, 29.93325909419153, 30.199337741083003, 30.463092423455635, 30.72458299147443, 30.983866769659336, 31.240998703626616, 31.496031496047245, 31.749015732775085, 32.0, 32.2490309931942, 32.49615361854384, 32.7414110874898, 32.984845004941285, 33.2264954516723, 33.46640106136302, 33.704599092705436, 33.941125496954285, 34.17601498127013, 34.40930106817051, 34.64101615137755, 34.87119154832539, 35.09985754956849, 35.32704346531139, 35.552777669262355, 35.77708763999664, 36.0, 36.22154055254967, 36.4417343165772, 36.660605559646726, 36.87817782917155, 37.094473981982816, 37.30951621235526, 37.52332607858744, 37.73592452822641, 37.94733192202055, 38.157568056677825, 38.36665218650176, 38.57460304397182, 38.781438859330635, 38.98717737923585, 39.19183588453085, 39.39543120718442, 39.59797974644666, 39.7994974842648, 40.00000000000001, 40.19950248448357], [0.0, 4.031128874149275, 5.70087712549569, 6.982120021884471, 8.06225774829855, 9.013878188659973, 9.874208829065749, 10.665364503850771, 11.40175425099138, 12.093386622447824, 12.747548783981962, 13.369741957120938, 13.964240043768942, 14.534441853748634, 15.083103128998355, 15.612494995995995, 16.1245154965971, 16.620770138594658, 17.102631376487068, 17.57128339080558, 18.027756377319946, 18.472953201911167, 18.907670401189037, 19.332614929181204, 19.748417658131498, 20.155644370746373, 20.55480479109447, 20.946360065653415, 21.330729007701542, 21.70829334609241, 22.079402165819612, 22.444375687463438, 22.80350850198276, 23.157072353818826, 23.505318547086315, 23.84848003542364, 24.186773244895647, 24.520399670478458, 24.849547279578356, 25.17439175034821, 25.495097567963924, 25.81181899828061, 26.124700955226263, 26.433879775772603, 26.739483914241877, 27.041634565979916, 27.34044622898463, 27.636027210870957, 27.928480087537885, 28.217902119044922, 28.50438562747845, 28.788018340969565, 29.068883707497267, 29.34706118165838, 29.62262648719725, 29.895651857753496, 30.16620625799671, 30.434355587066403, 30.7001628660175, 30.96368841078207, 31.22498999199199, 31.484122982862328, 31.741140496207755, 31.99609351155231, 32.2490309931942, 32.5, 32.749045787625626, 32.99621190379283, 33.241540277189316, 33.48507130050644, 33.7268439080801, 33.96689564855758, 34.205262752974136, 34.44198019858904, 34.6770817687994, 34.910600109422354, 35.14256678161116, 35.37301231164798, 35.601966237835796, 35.82945715469326, 36.05551275463989, 36.28015986734347, 36.50342449688796, 36.7253318569077, 36.945906403822335, 37.16517186829626, 37.383151285037485, 37.59986702104145, 37.815340802378074, 38.029593739612835, 38.242646351945886, 38.4545185901475, 38.66522985836241, 38.87479903485033, 39.08324449172561, 39.29058411375427, 39.496835316262995, 39.702015062210634, 39.90613987846983, 40.10922587136281, 40.311288741492746, 40.512343797909296], [0.0, 4.06201920231798, 5.744562646538029, 7.035623639735145, 8.12403840463596, 9.082951062292475, 9.9498743710662, 10.747092630102339, 11.489125293076057, 12.186057606953941, 12.84523257866513, 13.472193585307481, 14.07124727947029, 14.645818515876812, 15.198684153570664, 15.732132722552272, 16.24807680927192, 16.748134224444225, 17.233687939614086, 17.705931209625774, 18.16590212458495, 18.614510468986285, 19.05255888325765, 19.480759738778158, 19.8997487421324, 20.310096011589902, 20.712315177207984, 21.106870919205438, 21.494185260204677, 21.87464285422736, 22.248595461286985, 22.616365755797283, 22.978250586152114, 23.334523779156072, 23.68543856465402, 24.031229681395832, 24.372115213907882, 24.708298201211676, 25.03996805109783, 25.36730178793165, 25.69046515733026, 26.009613607279906, 26.32489316217637, 26.636441203734403, 26.944387170614963, 27.248853186877422, 27.54995462791182, 27.847800631288642, 28.14249455894058, 28.43413441622586, 28.722813232690143, 29.008619408720577, 29.291637031753623, 29.571946165242494, 29.8496231131986, 30.124740662784138, 30.397368307141328, 30.66757245039131, 30.93541659651604, 31.200961523645386, 31.464265445104544, 31.72538415843061, 31.984371183438952, 32.24127789030701, 32.49615361854384, 32.74904578762563, 33.0, 33.2490601370926, 33.49626844888845, 33.741665637605976, 33.98529093593286, 34.22718218024966, 34.46737587922817, 34.70590727815655, 34.942810419312295, 35.178118198675726, 35.41186241925155, 35.644073841243234, 35.874782229304195, 36.10401639707139, 36.3318042491699, 36.55817282086182, 36.78314831549905, 37.006756139926665, 37.22902093797257, 37.44996662214801, 37.66961640367472, 37.88799282094527, 38.1051177665153, 38.32101251271944, 38.535697735995385, 38.749193539995126, 38.961519477556315, 39.17269457160179, 39.382737335030434, 39.5916657896583, 39.7994974842648, 40.00624951179503, 40.2119385257662, 40.41658075592244, 40.620192023179804, 40.82278775390039], [0.0, 4.092676385936225, 5.787918451395113, 7.088723439378914, 8.18535277187245, 9.151502608861563, 10.024968827881711, 10.828203913853857, 11.575836902790225, 12.278029157808675, 12.942179105544785, 13.573871960498229, 14.177446878757827, 14.756354563373707, 15.313392831113555, 15.850867484147358, 16.3707055437449, 16.874537030686202, 17.36375535418534, 17.839562774911276, 18.303005217723125, 18.75499933351105, 19.196353820452465, 19.62778642639052, 20.049937655763422, 20.463381929681127, 20.86863675470921, 21.26617031813674, 21.656407827707714, 22.039736840534193, 22.41651177145989, 22.787057730211682, 23.15167380558045, 23.510635891017497, 23.864199127563445, 24.212600025606502, 24.55605831561735, 24.89477856900921, 25.22895162308573, 25.55875583826412, 25.88435821108957, 26.205915362757317, 26.523574419749693, 26.837473800639284, 27.147743920996458, 27.454507826584685, 27.75788176356402, 28.0579756931964, 28.354893757515654, 28.648734701553572, 28.939592256975565, 29.22755549135097, 29.512709126747414, 29.795133830879166, 30.074906483645133, 30.35210042155238, 30.62678566222711, 30.899029110960754, 31.1688947510174, 31.436443819236295, 31.701734968294716, 31.964824416849215, 32.225766088644036, 32.48461174156157, 32.7414110874898, 32.99621190379283, 33.2490601370926, 33.5, 33.749074061372404, 33.996323330619155, 34.241787336527864, 34.48550420104076, 34.72751070837068, 34.96784236981172, 35.206533484567885, 35.443617196894564, 35.67912554982255, 35.91308953571107, 36.145539143855636, 36.376503405357695, 36.60601043544625, 36.834087473426024, 37.060760920412854, 37.286056375004314, 37.5099986670221, 37.73261188945181, 37.953919428696686, 38.173943993252784, 38.39270764090493, 38.61023180453596, 38.82653731663435, 39.041644432579936, 39.25557285278104, 39.46834174373177, 39.679969758053, 39.89047505357638, 40.099875311526844, 40.308187753854675, 40.51542915976579, 40.721615881494685, 40.926763859362254, 41.13088863615762], [0.0, 4.123105625617661, 5.830951894845301, 7.141428428542851, 8.246211251235321, 9.219544457292887, 10.09950493836208, 10.908712114635714, 11.661903789690601, 12.369316876852983, 13.038404810405297, 13.674794331177345, 14.282856857085703, 14.866068747318508, 15.427248620541512, 15.968719422671311, 16.492422502470642, 17.0, 17.492855684535904, 17.972200755611432, 18.439088914585774, 18.894443627691185, 19.339079605813716, 19.77371993328519, 20.19900987672416, 20.615528128088304, 21.023796041628643, 21.424285285628553, 21.817424229271428, 22.20360331117452, 22.58317958127243, 22.956480566497994, 23.323807579381203, 23.685438564654028, 24.041630560342615, 24.392621835300936, 24.738633753705965, 25.079872407968907, 25.416530054277672, 25.74878637916747, 26.076809620810593, 26.40075756488817, 26.72077843177478, 27.03701166919155, 27.34958866235469, 27.658633371878658, 27.964262908219123, 28.26658805020514, 28.565713714171405, 28.861739379323623, 29.154759474226505, 29.444863728670917, 29.732137494637016, 30.016662039607272, 30.298514815086236, 30.577769702841312, 30.854497241083024, 31.128764832546764, 31.400636936215164, 31.67017524422623, 31.937438845342623, 32.202484376209235, 32.46536616149585, 32.72613634390714, 32.984845004941285, 33.24154027718932, 33.49626844888845, 33.74907406137241, 34.0, 34.24908757908742, 34.49637662132068, 34.74190553208042, 34.98571136907181, 35.22782990761707, 35.4682957019364, 35.707142142714254, 35.944401511222864, 36.180105030251084, 36.414282912066255, 36.64696440361739, 36.87817782917155, 37.107950630558946, 37.33630940518894, 37.5632799419859, 37.78888725538237, 38.01315561749642, 38.23610858861032, 38.45776904605882, 38.67815921162743, 38.897300677553446, 39.11521443121589, 39.331920878594275, 39.54743986657038, 39.761790704142086, 39.97499218261337, 40.18706259482023, 40.39801975344832, 40.607881008493905, 40.81666326391711, 41.02438299353203, 41.23105625617661, 41.43669871020133], [0.0, 4.153311931459037, 5.873670062235366, 7.1937472849690804, 8.306623862918075, 9.287087810503355, 10.173494974687904, 10.988630487917955, 11.747340124470732, 12.459935794377113, 13.133925536563698, 13.774977313955914, 14.387494569938161, 14.974979131871939, 15.540270267920054, 16.08570794214541, 16.61324772583615, 17.124543789543708, 17.621010186706098, 18.103866990231676, 18.57417562100671, 19.032866310674283, 19.480759738778158, 19.91858428704209, 20.346989949375807, 20.76655965729519, 21.177818584547374, 21.581241854907244, 21.97726097583591, 22.366269246345045, 22.74862633215465, 23.124662159694356, 23.494680248941464, 23.858960580880304, 24.21776207662467, 24.571324750611232, 24.919871588754226, 25.263610193319565, 25.602734228984218, 25.937424698685877, 26.267851073127396, 26.594172293944403, 26.916537667389544, 27.235087662792644, 27.549954627911827, 27.86126343151006, 28.16913204200655, 28.4736720498077, 28.774989139876322, 29.073183520213263, 29.36835031117683, 29.660579899927786, 29.949958263743877, 30.236567265481714, 30.520484924063712, 30.80178566252288, 31.080540535840107, 31.356817440550312, 31.630681307869423, 31.90219428189854, 32.17141588429082, 32.438403166617185, 32.703210851535665, 32.96589146375386, 33.2264954516723, 33.48507130050644, 33.741665637605976, 33.996323330619155, 34.249087579087416, 34.5, 34.74910070778811, 34.996428389194236, 35.242020373412196, 35.485912697858005, 35.72814016989969, 35.968736424845396, 36.20773398046335, 36.44516428828384, 36.68105778191246, 36.91544392256444, 37.14835124201342, 37.379807383131336, 37.609839138182984, 37.83847248502508, 38.065732621348566, 38.29164399709158, 38.516230345141516, 38.739514710434875, 38.961519477556315, 39.182266396930125, 39.40177660969109, 39.62007067131506, 39.83716857408418, 40.05308976845607, 40.267853183401776, 40.48147724577254, 40.693979898751614, 40.90537861944319, 41.11569043564756, 41.32493194186774, 41.53311931459038, 41.7402683268807], [0.0, 4.183300132670378, 5.916079783099617, 7.245688373094721, 8.366600265340756, 9.354143466934854, 10.2469507659596, 11.067971810589329, 11.832159566199234, 12.549900398011134, 13.228756555322953, 13.874436925511612, 14.491376746189442, 15.083103128998358, 15.652475842498529, 16.201851746019653, 16.73320053068151, 17.24818831066034, 17.74823934929885, 18.23458252881047, 18.708286933869708, 19.170289512680817, 19.621416870348586, 20.06240264773888, 20.4939015319192, 20.91650066335189, 21.330729007701546, 21.737065119284164, 22.135943621178658, 22.527760652137623, 22.9128784747792, 23.291629397704234, 23.664319132398468, 24.031229681395835, 24.392621835300936, 24.748737341529164, 25.09980079602227, 25.44602129999895, 25.787593916455258, 26.124700955226267, 26.457513110645905, 26.78619047195775, 27.110883423451924, 27.431733448690405, 27.748873851023223, 28.06243040080456, 28.372521918222215, 28.679260799399977, 28.982753492378883, 29.283100928692644, 29.580398915498083, 29.874738492579315, 30.166206257996716, 30.454884665682126, 30.7408522978788, 31.024184114977146, 31.304951684997057, 31.583223394707517, 31.859064644147985, 32.132538026119256, 32.403703492039305, 32.67261850540908, 32.93933818400121, 33.20391543176798, 33.46640106136302, 33.726843908080106, 33.98529093593286, 34.241787336527864, 34.49637662132068, 34.74910070778811, 35.0, 35.249113464029136, 35.4964786985977, 35.742132001323036, 35.98610843089316, 36.2284418654736, 36.46916505762094, 36.70830968595531, 36.945906403822335, 37.18198488515642, 37.416573867739416, 37.649701194033405, 37.88139384975163, 38.11167800031901, 38.340579025361635, 38.568121551353784, 38.79432948254165, 39.01922603025335, 39.24283374069717, 39.46517452134223, 39.68626966596886, 39.90613987846983, 40.12480529547776, 40.34228550788862, 40.5585995813465, 40.773766075750224, 40.9878030638384, 41.200728148905334, 41.41255848169732, 41.62331077653483, 41.83300132670378, 42.04164601915582], [0.0, 4.2130748865881795, 5.958187643906493, 7.297259759663214, 8.426149773176359, 9.420721840708387, 10.319883720275147, 11.146748404803978, 11.916375287812986, 12.639224659764539, 13.322912594474229, 13.973188612482122, 14.594519519326427, 15.190457530963313, 15.763882770434446, 16.31716887208072, 16.852299546352718, 17.370952766040208, 17.874562931719478, 18.36436767220696, 18.841443681416774, 19.306734576307825, 19.761072845369505, 20.20519735117675, 20.639767440550294, 21.0653744329409, 21.48255105894084, 21.891779278989638, 22.293496809607955, 22.688102609076857, 23.07596151842865, 23.4574082114798, 23.832750575625973, 24.2022726205619, 24.566236993076494, 24.924887161229037, 25.278449319529077, 25.627134057479, 25.971137826441108, 26.310644233845743, 26.645825188948457, 26.97684192043242, 27.303845882952096, 27.626979567082607, 27.946377224964245, 28.262165522125155, 28.574464124459094, 28.88338622807236, 29.189039038652854, 29.491524206117255, 29.790938219532464, 30.08737276666077, 30.380915061926625, 30.671648146130007, 30.959651160825445, 31.24499959993599, 31.52776554086889, 31.80801785713785, 32.08582241426889, 32.36124225056881, 32.63433774416144, 32.90516676754579, 33.17378483079674, 33.44024521441193, 33.704599092705436, 33.96689564855758, 34.22718218024966, 34.48550420104076, 34.741905532080416, 34.996428389194236, 35.249113464029136, 35.5, 35.749125863438955, 35.99652761031264, 36.24224054884024, 36.486298798316064, 36.72873534441392, 36.96958209122738, 37.20886991027812, 37.446628686705566, 37.68288736283355, 37.91767397929362, 38.151015713870585, 38.38293891822251, 38.61346915261565, 38.84263121880391, 39.0704491911726, 39.296946446257124, 39.52214569073901, 39.74606898801439, 39.96873778342268, 40.190172928217166, 40.4103947023535, 40.629422836166405, 40.847276531000205, 41.06397447885433, 41.27953488110059, 41.49397546632523, 41.70731350734545, 41.91956583744636, 42.1307488658818, 42.3408785926792], [0.0, 4.242640687119286, 6.0, 7.348469228349535, 8.485281374238571, 9.486832980505138, 10.392304845413264, 11.224972160321824, 12.0, 12.727922061357855, 13.416407864998739, 14.071247279470292, 14.69693845669907, 15.297058540778357, 15.874507866387544, 16.431676725154983, 16.970562748477143, 17.4928556845359, 18.0, 18.493242008906932, 18.973665961010276, 19.44222209522358, 19.8997487421324, 20.346989949375804, 20.784609690826528, 21.213203435596427, 21.63330765278394, 22.045407685048605, 22.44994432064365, 22.847319317591726, 23.2379000772445, 23.622023622035435, 24.0, 24.372115213907886, 24.73863375370596, 25.09980079602227, 25.45584412271571, 25.806975801127884, 26.153393661244046, 26.495282598983543, 26.832815729997478, 27.166155414412252, 27.495454169735044, 27.820855486487112, 28.142494558940584, 28.46049894151541, 28.774989139876315, 29.086079144497976, 29.39387691339814, 29.698484809834994, 30.000000000000004, 30.29851481508624, 30.594117081556714, 30.886890422961006, 31.176914536239796, 31.464265445104548, 31.74901573277509, 32.03123475609394, 32.31098884280703, 32.58834147360064, 32.863353450309965, 33.13608305156178, 33.406586176980134, 33.67491648096547, 33.941125496954285, 34.20526275297414, 34.46737587922817, 34.72751070837068, 34.9857113690718, 35.242020373412196, 35.4964786985977, 35.749125863438955, 36.0, 36.24913792078372, 36.49657518178932, 36.742346141747674, 36.986484017813865, 37.22902093797257, 37.46998799039039, 37.70941526992961, 37.94733192202055, 38.18376618407357, 38.4187454245971, 38.65229618017538, 38.88444419044716, 39.11521443121589, 39.344631145812, 39.572717874818764, 39.7994974842648, 40.024992192378996, 40.24922359499622, 40.47221268969613, 40.69397989875161, 40.91454509095757, 41.13392760240627, 41.352146256270665, 41.569219381653056, 41.785164831552365, 42.0, 42.21374183841087, 42.42640687119285, 42.63801121065569], [0.0, 4.272001872658766, 6.041522986797286, 7.399324293474372, 8.544003745317532, 9.552486587271401, 10.464224768228176, 11.302654555457316, 12.083045973594572, 12.816005617976296, 13.509256086106296, 14.168627315304755, 14.798648586948744, 15.402921800749365, 15.98436736314578, 16.545392107774298, 17.088007490635064, 17.613914953808536, 18.12456896039186, 18.621224449536076, 19.104973174542803, 19.576771950451896, 20.03746490951388, 20.48780124854788, 20.928449536456352, 21.36000936329383, 21.78302091079197, 22.197972880423116, 22.605309110914632, 23.005434140654682, 23.398717913595178, 23.785499784532593, 24.166091947189145, 24.540782383616058, 24.9098374141623, 25.273503912200226, 25.632011235952593, 25.98557292037257, 26.334388164527386, 26.678643143908204, 27.018512172212592, 27.354158733179858, 27.68573639981426, 28.013389655662877, 28.33725463060951, 28.657459761814195, 28.97412638890084, 29.287369291214944, 29.597297173897488, 29.90401310861136, 30.20761493398643, 30.508195620193604, 30.80584360149873, 31.100643080167977, 31.39267430468453, 31.68201382488178, 31.96873472629156, 32.25290684574028, 32.53459696999488, 32.81386901905961, 33.090784215548595, 33.36540124140574, 33.637776383108324, 33.90796366637194, 34.17601498127013, 34.44198019858905, 34.70590727815655, 34.96784236981173, 35.22782990761707, 35.485912697858005, 35.74213200132303, 35.99652761031264, 36.24913792078372, 36.5, 36.74914965002591, 36.99662146737186, 37.24244889907215, 37.486664295453124, 37.72929895982697, 37.970383195327386, 38.209946349085605, 38.44801685392889, 38.684622267769406, 38.91978931083774, 39.15354390090379, 39.38591118661596, 39.61691557908061, 39.84658078179356, 40.07492981902776, 40.30198506277327, 40.527768258318886, 40.75230054855799, 40.97560249709576, 41.19769411022904, 41.41859485786547, 41.63832369344376, 41.856899072912704, 42.07433897282286, 42.29066090758101, 42.50588194591426, 42.72001872658766, 42.93308747341612], [0.0, 4.301162633521313, 6.082762530298219, 7.449832212875671, 8.602325267042627, 9.617692030835672, 10.535653752852738, 11.379806676741042, 12.165525060596439, 12.90348790056394, 13.601470508735442, 14.265342617687107, 14.899664425751341, 15.508062419270823, 16.09347693943108, 16.65833124895768, 17.204650534085253, 17.734147850968196, 18.24828759089466, 18.748333259252675, 19.235384061671343, 19.710403344427025, 20.174241001832012, 20.627651344736268, 21.071307505705477, 21.50581316760657, 21.931712199461312, 22.349496638627013, 22.759613353482084, 23.16246964380094, 23.558437978779487, 23.947860029656095, 24.331050121192877, 24.708298201211676, 25.079872407968903, 25.446021299998947, 25.80697580112788, 26.16295090390226, 26.514147167125707, 26.860752037126588, 27.202941017470884, 27.54087870784082, 27.87471972953271, 28.204609552340905, 28.530685235374214, 28.853076092507013, 29.17190429162964, 29.487285395573462, 29.799328851502683, 30.10813843464919, 30.4138126514911, 30.716445106815343, 31.016124838541646, 31.312936623702353, 31.60696125855822, 31.898275815473163, 32.18695387886216, 32.47306576225903, 32.7566787083184, 33.037857073363575, 33.31666249791536, 33.593154064481645, 33.8673884437522, 34.13942003022312, 34.40930106817051, 34.677081768799404, 34.942810419312295, 35.206533484567885, 35.46829570193639, 35.728140169899696, 35.98610843089316, 36.24224054884024, 36.49657518178932, 36.74914965002591, 36.99999999999999, 37.24916106437835, 37.49666651850535, 37.74254893353124, 37.98683982644516, 38.22956970723055, 38.47076812334269, 38.71046370169182, 38.948684188300895, 39.185456485793296, 39.42080668885405, 39.6547601177967, 39.887341350358255, 40.11857425183502, 40.348482003664024, 40.57708713054696, 40.80441152620633, 41.030476477857285, 41.255302689472536, 41.47891030391227, 41.701318923986086, 41.92254763250916, 42.14261501141095, 42.36153915995027, 42.579337712087536, 42.79602785306132, 43.01162633521314, 43.22614949310197], [0.0, 4.330127018922194, 6.123724356957946, 7.500000000000002, 8.660254037844387, 9.682458365518542, 10.606601717798213, 11.456439237389601, 12.247448713915892, 12.99038105676658, 13.693063937629153, 14.361406616345073, 15.000000000000004, 15.612494995995997, 16.201851746019653, 16.77050983124842, 17.320508075688775, 17.853571071357123, 18.371173070873837, 18.874586088176876, 19.364916731037084, 19.843134832984433, 20.310096011589902, 20.766559657295186, 21.213203435596427, 21.65063509461097, 22.07940216581962, 22.500000000000004, 22.912878474779202, 23.31844763272204, 23.717082451262844, 24.109126902482387, 24.494897427831784, 24.874685927665503, 25.248762345905195, 25.617376914898998, 25.98076211353316, 26.33913438213185, 26.69269563007828, 27.041634565979923, 27.386127875258307, 27.726341266023542, 28.062430400804566, 28.394541729001368, 28.722813232690147, 29.047375096555623, 29.368350311176826, 29.685855217594796, 30.000000000000007, 30.31088913245535, 30.618621784789728, 30.923292192132458, 31.224989991991993, 31.52380053229623, 31.819805153394643, 32.113081446662825, 32.403703492039305, 32.69174207655505, 32.977264895682296, 33.26033673912517, 33.54101966249684, 33.819373146171706, 34.09545424246464, 34.3693177121688, 34.64101615137755, 34.910600109422354, 35.178118198675726, 35.443617196894564, 35.70714214271425, 35.968736424845396, 36.2284418654736, 36.486298798316064, 36.742346141747674, 36.99662146737185, 37.24916106437835, 37.5, 37.74917217635375, 37.99671038392666, 38.24264635194589, 38.48701079585163, 38.72983346207417, 38.97114317029974, 39.21096785339531, 39.44933459514875, 39.686269665968865, 39.92179855667828, 40.15594601052253, 40.38873605350879, 40.620192023179804, 40.850336595920474, 41.07919181288746, 41.30677910464576, 41.53311931459037, 41.75823272122516, 41.982139059366666, 42.204857540335325, 42.42640687119285, 42.646805273079956, 42.86607049870562, 43.084219849035215, 43.30127018922194, 43.51723796382303], [0.0, 4.358898943540674, 6.164414002968978, 7.549834435270752, 8.717797887081348, 9.746794344808965, 10.677078252031313, 11.532562594670797, 12.328828005937956, 13.076696830622023, 13.784048752090223, 14.456832294800964, 15.099668870541503, 15.716233645501715, 16.309506430300093, 16.881943016134134, 17.435595774162696, 17.97220075561143, 18.493242008906932, 19.000000000000004, 19.49358868961793, 19.97498435543818, 20.445048300260876, 20.904544960366874, 21.354156504062626, 21.794494717703373, 22.226110770892873, 22.649503305812257, 23.065125189341593, 23.47338918861101, 23.874672772626646, 24.269322199023197, 24.65765601187591, 25.039968051097837, 25.416530054277672, 25.787593916455258, 26.153393661244046, 26.51414716712571, 26.870057685088813, 27.221315177632405, 27.568097504180447, 27.91057147390573, 28.248893783651077, 28.583211855912907, 28.91366458960193, 29.24038303442689, 29.563490998188968, 29.883105594967876, 30.199337741083006, 30.51229260478472, 30.822070014844886, 31.128764832546768, 31.43246729100343, 31.73326330524487, 32.03123475609394, 32.326459750489235, 32.619012860600186, 32.908965343808674, 33.19638534539567, 33.481338085566414, 33.76388603226827, 34.044089061098404, 34.32200460346103, 34.597687784012386, 34.87119154832539, 35.14256678161116, 35.41186241925155, 35.67912554982255, 35.94440151122286, 36.20773398046335, 36.46916505762094, 36.72873534441392, 36.986484017813865, 37.24244889907215, 37.49666651850535, 37.74917217635375, 38.00000000000001, 38.24918299781056, 38.49675310984032, 38.74274125562104, 38.98717737923586, 39.230090491866065, 39.47150871198111, 39.71145930332957, 39.94996871087636, 40.18706259482024, 40.422765862815474, 40.657102700512255, 40.89009660052175, 41.12177038990418, 41.35214625627067, 41.581245772583586, 41.80908992073375, 42.03569911396741, 42.26109321823089, 42.485291572496, 42.70831300812525, 42.93017586733137, 43.15089802078284, 43.37049688440289, 43.588989435406745, 43.80639222761903], [0.0, 4.387482193696061, 6.2048368229954285, 7.599342076785334, 8.774964387392123, 9.810708435174293, 10.747092630102339, 11.6081867662439, 12.409673645990857, 13.162446581088183, 13.874436925511608, 14.551632210855251, 15.198684153570667, 15.819292019556377, 16.416455159382004, 16.99264546796643, 17.549928774784245, 18.090052515125542, 18.614510468986285, 19.12459149890528, 19.621416870348586, 20.105969262883104, 20.57911562725668, 21.041625412500814, 21.494185260204677, 21.937410968480307, 22.371857321197098, 22.798026230356, 23.2163735324878, 23.627314701421323, 24.03122968139583, 24.428467000612216, 24.819347291981714, 25.204166322257127, 25.583197610932064, 25.956694704834824, 26.324893162176366, 26.68801229016504, 27.046256672597046, 27.399817517640518, 27.748873851023216, 28.093593575760295, 28.434134416225866, 28.7706447616316, 29.103264421710502, 29.432125305522874, 29.75735203273302, 30.079062485390068, 30.397368307141335, 30.712375355872428, 31.024184114977142, 31.3328900677866, 31.638584039112754, 31.94135250736888, 32.24127789030702, 32.53843880704789, 32.83291031876401, 33.12476415010377, 33.414068893207244, 33.70089019595773, 33.98529093593286, 34.267331381360876, 34.5470693402494, 34.8245602987317, 35.09985754956849, 35.37301231164799, 35.644073841243234, 35.91308953571107, 36.180105030251084, 36.44516428828385, 36.70830968595531, 36.96958209122738, 37.22902093797257, 37.486664295453124, 37.74254893353124, 37.99671038392666, 38.24918299781056, 38.5, 38.74919353999513, 38.99679474008089, 39.24283374069717, 39.48733974326455, 39.73034105063787, 39.97186510534629, 40.21193852576621, 40.45058714036176, 40.68783602011786, 40.923709509280805, 41.15823125451336, 41.391424232562954, 41.62331077653482, 41.8539126008549, 42.08325082500163, 42.311345996080064, 42.53821811030641, 42.76388663346679, 42.988370520409354, 43.21168823362494, 43.433857760968, 43.65489663256575, 43.874821936960615, 44.09365033652805], [0.0, 4.415880433163924, 6.244997998398399, 7.648529270389179, 8.831760866327848, 9.87420882906575, 10.81665382639197, 11.683321445547925, 12.489995996796798, 13.247641299491772, 13.964240043768942, 14.645818515876813, 15.297058540778359, 15.921683328090662, 16.522711641858308, 17.10263137648707, 17.663521732655695, 18.207141456033124, 18.734993995195197, 19.248376554920164, 19.7484176581315, 20.236106344848068, 20.71231517720798, 21.177818584547374, 21.63330765278394, 22.079402165819623, 22.51666049839541, 22.945587811167538, 23.36664289109585, 23.780243901188236, 24.18677324489565, 24.586581706288495, 24.979991993593597, 25.367301787931652, 25.74878637916747, 26.124700955226267, 26.495282598983543, 26.86075203712659, 27.221315177632405, 27.57716446627536, 27.928480087537885, 28.27543103119739, 28.618176042508377, 28.95686447114052, 29.291637031753627, 29.62262648719725, 29.949958263743877, 30.273751006441213, 30.594117081556718, 30.911163032147467, 31.224989991991997, 31.535694062442964, 31.843366656181324, 32.148094811357026, 32.44996147917591, 32.74904578762563, 33.045423283716616, 33.33916615633931, 33.63034344160048, 33.91902121229326, 34.20526275297414, 34.48912872196107, 34.770677301427426, 35.04996433664377, 35.32704346531139, 35.6019662378358, 35.8747822293042, 36.14553914385564, 36.41428291206625, 36.68105778191246, 36.945906403822335, 37.20886991027812, 37.46998799039039, 37.72929895982697, 37.98683982644516, 38.24264635194589, 38.49675310984033, 38.74919353999513, 39.00000000000001, 39.249203813580735, 39.496835316263, 39.74292389847532, 39.98749804626442, 40.23058537978289, 40.472212689696136, 40.71240597164457, 40.95119045888654, 41.18859065323795, 41.42463035441596, 41.6593326878864, 41.89272013130683, 42.1248145396511, 42.35563716909475, 42.585208699735176, 42.8135492572153, 43.04067843331469, 43.26661530556788, 43.491378455965275, 43.7149859887888, 43.937455547630435, 44.158804331639246, 44.37904911103888], [0.0, 4.444097208657795, 6.284902544988268, 7.697402159170328, 8.88819441731559, 9.937303457175895, 10.885770528538622, 11.757976016304848, 12.569805089976535, 13.332291625973385, 14.053469322555197, 14.739402972983678, 15.394804318340656, 16.023420358962067, 16.62828914831589, 17.211914478058507, 17.77638883463118, 18.323482201808694, 18.854707634964804, 19.37137062781052, 19.87460691435179, 20.365411854416305, 20.844663585675832, 21.313141485947117, 21.771541057077243, 22.220486043288975, 22.660538387249325, 23.092206477510985, 23.515952032609697, 23.93219588754864, 24.341322889276167, 24.743686063317245, 25.13961017995307, 25.52939482243949, 25.913317039699876, 26.291633650269816, 26.66458325194677, 27.032387981826545, 27.395255063605454, 27.753378172755838, 28.106938645110393, 28.45610655026439, 28.80104164782934, 29.141894241795608, 29.478805945967355, 29.811910371527684, 30.14133374620307, 30.46719547316425, 30.78960863668131, 31.10868046060456, 31.42451272494134, 31.737202145116704, 32.046840717924134, 32.35351603767356, 32.657311585615865, 32.958306995354, 33.25657829663178, 33.552198139615236, 33.8452360015409, 34.13575837739657, 34.42382895611701, 34.7095087836172, 34.99285641384539, 35.27392804891454, 35.55277766926236, 35.82945715469326, 36.1040163970714, 36.376503405357695, 36.64696440361739, 36.91544392256444, 37.18198488515642, 37.446628686705566, 37.70941526992961, 37.970383195327386, 38.22956970723055, 38.48701079585163, 38.74274125562104, 38.99679474008089, 39.249203813580735, 39.5, 39.74921382870358, 39.99687487792015, 40.24301181571778, 40.48765243873742, 40.73082370883261, 40.97255178775176, 41.212862069989754, 41.45177921392519, 41.689327171351664, 41.925529215503055, 42.16040796766559, 42.39398542246294, 42.626282971894234, 42.857321428199405, 43.08712104562105, 43.31570154112709, 43.54308211415449, 43.769281465429614, 43.99431781491788, 44.21820891895103, 44.44097208657795, 44.66262419518137], [0.0, 4.47213595499958, 6.324555320336759, 7.745966692414836, 8.94427190999916, 10.000000000000002, 10.954451150103324, 11.832159566199232, 12.649110640673518, 13.416407864998739, 14.142135623730951, 14.83239697419133, 15.491933384829672, 16.124515496597102, 16.73320053068151, 17.320508075688775, 17.88854381999832, 18.439088914585774, 18.97366596101028, 19.49358868961793, 20.000000000000004, 20.4939015319192, 20.97617696340303, 21.44761058952722, 21.90890230020665, 22.3606797749979, 22.803508501982765, 23.237900077244507, 23.664319132398465, 24.083189157584595, 24.49489742783178, 24.899799195977465, 25.298221281347036, 25.690465157330266, 26.076809620810597, 26.45751311064591, 26.832815729997478, 27.20294101747089, 27.568097504180447, 27.92848008753789, 28.284271247461902, 28.635642126552707, 28.982753492378883, 29.32575659723036, 29.66479394838266, 29.999999999999996, 30.331501776206203, 30.659419433511786, 30.983866769659343, 31.304951684997057, 31.622776601683796, 31.93743884534263, 32.249030993194204, 32.55764119219942, 32.86335345030997, 33.166247903554, 33.46640106136302, 33.76388603226827, 34.058772731852805, 34.351128074635334, 34.64101615137755, 34.928498393145965, 35.21363372331802, 35.4964786985977, 35.77708763999664, 36.05551275463989, 36.331804249169906, 36.60601043544626, 36.87817782917155, 37.148351242013426, 37.416573867739416, 37.68288736283355, 37.94733192202056, 38.209946349085605, 38.47076812334269, 38.729833462074176, 38.98717737923586, 39.24283374069717, 39.496835316263, 39.74921382870359, 40.00000000000001, 40.24922359499622, 40.49691346263318, 40.74309757492673, 40.9878030638384, 41.23105625617661, 41.47288270665544, 41.71330722922843, 41.95235392680606, 42.190046219457976, 42.42640687119285, 42.661458015403085, 42.89522117905444, 43.127717305695654, 43.35896677735761, 43.58898943540673, 43.8178046004133, 44.045431091090485, 44.271887242357316, 44.497190922573985, 44.7213595499958, 44.94441010848847], [0.0, 4.500000000000001, 6.3639610306789285, 7.79422863405995, 9.000000000000002, 10.062305898749054, 11.022703842524303, 11.905880899790658, 12.727922061357857, 13.5, 14.230249470757707, 14.924811556599302, 15.5884572681199, 16.224980739587956, 16.837458240482736, 17.428425057933378, 18.000000000000004, 18.553975315279473, 19.091883092036785, 19.615045245933032, 20.12461179749811, 20.621590627301284, 21.106870919205434, 21.58124185490724, 22.045407685048605, 22.500000000000004, 22.945587811167535, 23.382685902179848, 23.811761799581316, 24.233241632105273, 24.647515087732472, 25.0549396327351, 25.455844122715714, 25.850531909421136, 26.239283526803852, 26.622359023948274, 27.0, 27.372431386341994, 27.7398630133604, 28.102490992792795, 28.460498941515414, 28.814059068447822, 29.163333142835377, 29.508473359359, 29.849623113198604, 30.186917696247157, 30.520484924063705, 30.850445701804702, 31.1769145362398, 31.5, 31.819805153394643, 32.13642792844283, 32.44996147917591, 32.76049450176234, 33.06811152757291, 33.37289319193049, 33.67491648096547, 33.974254958718376, 34.27097897638759, 34.565155865408734, 34.856850115866756, 35.14612354157995, 35.43303543305315, 35.71764269937197, 36.00000000000001, 36.28015986734348, 36.55817282086183, 36.834087473426024, 37.107950630558946, 37.37980738313134, 37.6497011940334, 37.91767397929362, 38.18376618407357, 38.44801685392889, 38.71046370169182, 38.97114317029974, 39.230090491866065, 39.48733974326455, 39.74292389847532, 39.996874877920156, 40.24922359499622, 40.5, 40.74923312161838, 40.996951106149346, 41.24318125460257, 41.487950057818, 41.731283229730664, 41.97320573889967, 42.21374183841087, 42.45291509425471, 42.69074841227312, 42.92726406376256, 43.16248370981448, 43.3964284244683, 43.629118716746966, 43.86057455164033, 44.09081537009721, 44.31986010808247, 44.5477272147525, 44.774434669797905, 45.00000000000001, 45.22444029504401], [0.0, 4.527692569068709, 6.403124237432849, 7.842193570679063, 9.055385138137417, 10.124228365658295, 11.09053650640942, 11.97914855071094, 12.806248474865699, 13.583077707206126, 14.317821063276355, 15.01665741768121, 15.684387141358126, 16.324827717314513, 16.94107434609742, 17.535677916750185, 18.110770276274835, 18.66815470259447, 19.20937271229855, 19.735754355990554, 20.24845673131659, 20.748493921246432, 21.236760581595302, 21.714050750608468, 22.18107301281884, 22.638462845343547, 23.0867927612304, 23.52658071203719, 23.95829710142188, 24.382370680473223, 24.79919353527449, 25.209125331911064, 25.612496949731398, 26.009613607279913, 26.400757564888174, 26.786190471957752, 27.166155414412252, 27.54087870784083, 27.91057147390573, 28.275431031197392, 28.63564212655271, 28.99137802864845, 29.342801502242427, 29.69006567860705, 30.03331483536242, 30.37268509697488, 30.708305065568176, 31.040296390337517, 31.368774282716252, 31.69384798348096, 32.01562118716425, 32.33419242844949, 32.649655434629025, 32.962099447699025, 33.27160951922826, 33.57826678076164, 33.88214869219484, 34.18332927027443, 34.48187929913334, 34.777866524558405, 35.07135583350037, 35.36240942017385, 35.65108693995178, 35.93744565213282, 36.22154055254967, 36.503424496887966, 36.78314831549905, 37.060760920412854, 37.33630940518894, 37.609839138182984, 37.881393849751625, 38.151015713870585, 38.4187454245971, 38.684622267769406, 38.948684188300895, 39.21096785339531, 39.47150871198111, 39.73034105063787, 39.98749804626442, 40.24301181571778, 40.49691346263318, 40.74923312161838, 41.00000000000001, 41.249242417285686, 41.496987842492864, 41.743262929483606, 41.98809355043404, 42.23150482755736, 42.473521163190604, 42.714166268347086, 42.953463189829066, 43.19143433598843, 43.428101501216936, 43.6634858892416, 43.89760813529595, 44.130488327232456, 44.36214602563768, 44.592600283006604, 44.82186966202995, 45.04997225304363, 45.276925690687094, 45.50274716981383], [0.0, 4.55521678957215, 6.442049363362563, 7.8898669190297515, 9.1104335791443, 10.185774393731682, 11.157956802210698, 12.05197079319395, 12.884098726725126, 13.665650368716449, 14.404860290887934, 15.10794492973813, 15.779733838059503, 16.424067705656842, 17.04406054905931, 17.642278764377348, 18.2208671582886, 18.781639970992945, 19.32614809008769, 19.85572965166478, 20.371548787463365, 20.874625745148105, 21.365860619221497, 21.846052274953475, 22.315913604421397, 22.776083947860748, 23.227139298673873, 23.669600757089253, 24.1039415863879, 24.53059314407216, 24.949949899749296, 25.362373705944798, 25.768197453450252, 26.167728216259054, 26.56124997058685, 26.949025956423732, 27.331300737432898, 27.708302004994824, 28.080242164197944, 28.447319733148852, 28.809720581775867, 29.167619032070476, 29.521178838251025, 29.87055406248769, 30.21588985947626, 30.557323181195038, 30.89498341155081, 31.228992939254383, 31.559467676119006, 31.886517527005044, 32.21024681681281, 32.53075467922624, 32.848135411313685, 33.16247879758086, 33.4738704066321, 33.78239186321774, 34.08812109811862, 34.39113257803529, 34.691497517403306, 34.98928407384181, 35.284557528754696, 35.57738045444043, 35.86781286892191, 36.15591237958185, 36.4417343165772, 36.72533185690771, 37.006756139926665, 37.286056375004314, 37.56327994198589, 37.83847248502508, 38.11167800031901, 38.38293891822251, 38.65229618017538, 38.91978931083774, 39.185456485793296, 39.44933459514875, 39.71145930332956, 39.97186510534628, 40.23058537978288, 40.48765243873742, 40.74309757492673, 40.996951106149346, 41.249242417285686, 41.5, 41.74925149029621, 41.99702370406741, 42.24334267076885, 42.48823366533375, 42.731721238442994, 42.97382924525111, 43.2145808726638, 43.45399866525519, 43.69210454990695, 43.92891985924534, 44.16446535394717, 44.398761243980665, 44.63182720884279, 44.863682416850274, 45.09434554353794, 45.32383478921438, 45.552167895721496, 45.779362162441714], [0.0, 4.582575694955841, 6.480740698407861, 7.937253933193774, 9.165151389911681, 10.2469507659596, 11.224972160321824, 12.124355652982143, 12.961481396815723, 13.74772708486752, 14.49137674618944, 15.198684153570667, 15.874507866387548, 16.522711641858308, 17.146428199482248, 17.74823934929885, 18.330302779823363, 18.894443627691185, 19.44222209522358, 19.97498435543818, 20.4939015319192, 21.000000000000004, 21.494185260204677, 21.97726097583591, 22.44994432064365, 22.912878474779202, 23.36664289109585, 23.81176179958132, 24.248711305964285, 24.677925358506137, 25.099800796022265, 25.51470164434615, 25.922962793631445, 26.324893162176373, 26.720778431774775, 27.11088342345192, 27.49545416973504, 27.874719729532714, 28.248893783651074, 28.618176042508374, 28.98275349237888, 29.34280150224242, 29.698484809835, 30.04995840263344, 30.397368307141335, 30.740852297878792, 31.080540535840107, 31.41655614481002, 31.749015732775096, 32.07802986469088, 32.403703492039305, 32.72613634390715, 33.045423283716616, 33.36165463522456, 33.67491648096548, 33.98529093593286, 34.292856398964496, 34.59768778401239, 34.8998567332303, 35.199431813596085, 35.4964786985977, 35.79106033634656, 36.08323710533743, 36.373066958946424, 36.660605559646726, 36.945906403822335, 37.22902093797257, 37.50999866702211, 37.78888725538237, 38.065732621348566, 38.34057902536163, 38.61346915261565, 38.88444419044716, 39.153543900903784, 39.42080668885404, 39.686269665968865, 39.94996871087636, 40.2119385257662, 40.47221268969613, 40.7308237088326, 40.9878030638384, 41.24318125460256, 41.496987842492864, 41.74925149029621, 42.00000000000001, 42.24926034855522, 42.49705872175156, 42.74342054632503, 42.988370520409354, 43.23193264243457, 43.47413023856832, 43.71498598878879, 43.95452195167182, 44.19275958796871, 44.42971978304613, 44.66542286825459, 44.8998886412873, 45.133136385587036, 45.365184888855026, 45.596052460711995, 45.825756949558404, 46.054315758677824], [0.0, 4.609772228646444, 6.519202405202649, 7.9843597113356575, 9.219544457292889, 10.307764064044152, 11.291589790636216, 12.196310917650468, 13.038404810405298, 13.829316685939332, 14.577379737113251, 15.288884851420658, 15.968719422671315, 16.620770138594665, 17.248188310660343, 17.853571071357127, 18.439088914585778, 19.00657780874821, 19.55760721560795, 20.093531297410124, 20.615528128088304, 21.12463017427761, 21.621748310439653, 22.107690969434145, 22.583179581272432, 23.048861143232223, 23.505318547086322, 23.953079134006973, 24.392621835300936, 24.824383174612823, 25.24876234590519, 25.666125535421198, 26.076809620810597, 26.481125353730725, 26.879360111431225, 27.271780286589287, 27.658633371878665, 28.04014978561991, 28.416544476765647, 28.78801834096957, 29.154759474226502, 29.516944286290883, 29.87473849257932, 30.22829800038368, 30.577769702841316, 30.92329219213245, 31.264996401726965, 31.603006186120968, 31.93743884534263, 32.26840560052511, 32.59601202601325, 32.920358442763046, 33.24154027718933, 33.55964838909967, 33.87476937190865, 34.18698582794336, 34.496376621320685, 34.803017110589714, 35.106979363083916, 35.40833235271043, 35.707142142714254, 36.003472054789384, 36.29738282576307, 36.5889327529514, 36.878177829171555, 37.16517186829626, 37.44996662214801, 37.73261188945181, 38.01315561749642, 38.29164399709159, 38.568121551353784, 38.84263121880391, 39.1152144312159, 39.38591118661596, 39.6547601177967, 39.92179855667828, 40.18706259482025, 40.45058714036176, 40.71240597164457, 40.97255178775176, 41.23105625617661, 41.487950057818, 41.74326292948361, 41.997023704067416, 42.24926034855522, 42.5, 42.74926899959811, 42.997092924987385, 43.243496620879306, 43.48850422812907, 43.73213921133976, 43.974424385090025, 44.21538193886829, 44.45503346079047, 44.693399960173096, 44.93050188902857, 45.166359162544865, 45.40099117860755, 45.634416836418545, 45.86665455426197, 46.097722286464446, 46.327637539594015], [0.0, 4.636809247747852, 6.557438524302001, 8.031189202104507, 9.273618495495704, 10.368220676663862, 11.357816691600547, 12.267844146385297, 13.114877048604002, 13.910427743243556, 14.66287829861518, 15.3785564992297, 16.062378404209014, 16.71825349730049, 17.349351572897472, 17.95828499606797, 18.547236990991408, 19.11805429430516, 19.672315572906005, 20.21138293140774, 20.736441353327724, 21.248529360875782, 21.748563170931547, 22.237355957937087, 22.715633383201094, 23.184046238739263, 23.64318083507378, 24.09356760631352, 24.535688292770594, 24.96998197836755, 25.396850198400585, 25.816661286851172, 26.229754097208005, 26.63644120373441, 27.03701166919155, 27.43173344869041, 27.820855486487112, 28.204609552340912, 28.583211855912907, 28.956864471140523, 29.32575659723036, 29.690065678607045, 30.049958402633443, 30.405591591021544, 30.7571129984594, 31.104662029991577, 31.448370387032774, 31.78836265050467, 32.12475680841803, 32.45766473423496, 32.78719262151001, 33.1134413795969, 33.43650699460098, 33.756480859236504, 34.07345007480165, 34.3874977280988, 34.698703145794944, 35.0071421284286, 35.31288716601915, 35.61600763701625, 35.91656999213594, 36.21463792446364, 36.51027252705737, 36.80353243915589, 37.094473981982816, 37.38315128503749, 37.66961640367473, 37.95391942869669, 38.23610858861032, 38.516230345141516, 38.79432948254165, 39.07044919117261, 39.34463114581201, 39.61691557908061, 39.88734135035826, 40.15594601052253, 40.42276586281548, 40.68783602011786, 40.95119045888654, 41.212862069989754, 41.47288270665545, 41.73128322973067, 41.98809355043404, 42.24334267076885, 42.497058721751564, 42.74926899959811, 43.0, 43.24927745061182, 43.497126341863094, 43.74357095619881, 43.98863489584554, 44.232341109192944, 44.474711915874174, 44.715769030622745, 44.95553358597805, 45.19402615390666, 45.43126676640219, 45.66727493512176, 45.90206967011401, 46.1356694976891, 46.36809247747853, 46.599356218729035], [0.0, 4.663689526544408, 6.59545297913646, 8.077747210701757, 9.327379053088816, 10.428326807307107, 11.423659658795863, 12.338962679253067, 13.19090595827292, 13.991068579633223, 14.747881203752627, 15.467708298258023, 16.155494421403514, 16.81517172080024, 17.449928366615147, 18.062391868188442, 18.65475810617763, 19.22888452302941, 19.786358937409382, 20.328551350256124, 20.856653614614213, 21.371710273162513, 21.874642854227357, 22.36626924634504, 22.847319317591726, 23.31844763272204, 23.780243901188236, 24.233241632105273, 24.677925358506133, 25.114736709748723, 25.5440795488896, 25.96632434519757, 26.38181191654584, 26.790856649237632, 27.193749281774295, 27.590759322642793, 27.982137159266447, 28.368115905008572, 28.748913022930104, 29.1247317584214, 29.495762407505254, 29.862183443278223, 30.224162519414833, 30.581857366746057, 30.935416596516045, 31.28498042192131, 31.63068130786942, 31.972644557496338, 32.31098884280703, 32.64582668581085, 32.9772648956823, 33.305404966761785, 33.63034344160048, 33.95217224272992, 34.27097897638759, 34.586847211042524, 34.899856733230294, 35.21008378291651, 35.51760127035608, 35.82247897619594, 36.124783736376884, 36.42457961322272, 36.72192805395708, 37.016888037759195, 37.30951621235526, 37.59986702104145, 37.88799282094527, 38.173943993252784, 38.45776904605882, 38.739514710434875, 39.01922603025334, 39.296946446257124, 39.572717874818764, 39.84658078179356, 40.11857425183502, 40.38873605350879, 40.65710270051225, 40.923709509280805, 41.188590653237945, 41.451779213925185, 41.71330722922843, 41.97320573889967, 42.23150482755736, 42.48823366533375, 42.74342054632503, 42.997092924987385, 43.24927745061182, 43.50000000000001, 43.749285708454714, 43.997158999189935, 44.24364361125788, 44.48876262608346, 44.73253849269008, 44.97499305169485, 45.21614755814565, 45.45602270326782, 45.69463863518345, 45.93201497866168, 46.16817085395522, 46.40312489477406, 46.63689526544408, 46.86949967729547], [0.0, 4.69041575982343, 6.6332495807108005, 8.124038404635963, 9.38083151964686, 10.488088481701515, 11.489125293076059, 12.409673645990857, 13.266499161421601, 14.07124727947029, 14.832396974191326, 15.556349186104049, 16.248076809271925, 16.911534525287767, 17.549928774784245, 18.16590212458495, 18.76166303929372, 19.339079605813716, 19.899748742132402, 20.445048300260876, 20.97617696340303, 21.49418526020468, 22.0, 22.494443758403985, 22.978250586152118, 23.45207879911715, 23.9165214862028, 24.372115213907886, 24.819347291981714, 25.25866188063018, 25.690465157330255, 26.115129714401192, 26.532998322843202, 26.944387170614963, 27.349588662354687, 27.74887385102322, 28.14249455894058, 28.530685235374214, 28.913664589601925, 29.291637031753623, 29.664793948382652, 30.033314835362415, 30.39736830714133, 30.757112998459398, 31.112698372208097, 31.464265445104544, 31.811947441173732, 32.155870381627054, 32.49615361854385, 32.83291031876401, 33.166247903554, 33.49626844888846, 33.82306905057553, 34.14674215792775, 34.46737587922818, 34.785054261852174, 35.09985754956849, 35.41186241925155, 35.72114219898351, 36.02776706930364, 36.3318042491699, 36.6333181680284, 36.932370625238775, 37.22902093797257, 37.52332607858744, 37.815340802378074, 38.105117766515306, 38.39270764090494, 38.67815921162743, 38.961519477556315, 39.242833740697165, 39.52214569073901, 39.799497484264805, 40.07492981902776, 40.348482003664024, 40.620192023179804, 40.89009660052175, 41.15823125451336, 41.42463035441596, 41.689327171351664, 41.95235392680606, 42.21374183841087, 42.47352116319061, 42.731721238442994, 42.98837052040936, 43.243496620879306, 43.497126341863094, 43.74928570845472, 44.0, 44.24929377967517, 44.49719092257398, 44.74371464239419, 44.98888751680797, 45.232731511594565, 45.4752680036083, 45.71651780264984, 45.956501172304236, 46.19523784980439, 46.4327470649756, 46.669047558312144, 46.9041575982343, 47.138094997570704], [0.0, 4.716990566028302, 6.670832032063167, 8.170067319184097, 9.433981132056603, 10.547511554864494, 11.554220008291344, 12.479983974348684, 13.341664064126334, 14.150971698084906, 14.916433890176297, 15.644487847162017, 16.340134638368195, 17.00735135169495, 17.649362594722792, 18.26882590644511, 18.867962264113206, 19.448650338776723, 20.0124960961895, 20.56088519495209, 21.095023109728988, 21.61596632121729, 22.124646889837585, 22.621892051727237, 23.108440016582687, 23.58495283014151, 24.05202694161139, 24.51020195755229, 24.95996794869737, 25.401771591761076, 25.83602136552762, 26.263091973337794, 26.68332812825267, 27.097047809678457, 27.50454507895013, 27.906092524751653, 28.30194339616981, 28.692333470807146, 29.077482697097423, 29.457596643310875, 29.832867780352593, 30.20347662107791, 30.569592735265548, 30.931375656443084, 31.288975694324034, 31.642534664593473, 31.99218654609278, 32.338058074040255, 32.68026927673639, 33.01893396219811, 33.354160160315836, 33.68605052540295, 34.0147027033899, 34.34020966738555, 34.66266002487403, 34.98213829942361, 35.298725189445584, 35.61249780624774, 35.92352989337211, 36.231892028984625, 36.53765181289022, 36.84087403957729, 37.141620858546275, 37.43995192304605, 37.73592452822641, 38.029593739612835, 38.32101251271944, 38.61023180453596, 38.897300677553446, 39.18226639693013, 39.46517452134223, 39.7460689880144, 40.024992192379, 40.30198506277327, 40.57708713054696, 40.85033659592048, 41.12177038990418, 41.391424232562954, 41.6593326878864, 41.925529215503055, 42.190046219457976, 42.45291509425471, 42.71416626834709, 42.97382924525111, 43.23193264243458, 43.48850422812907, 43.74357095619881, 43.997158999189935, 44.24929377967517, 44.49999999999999, 44.749301670528894, 44.997222136483046, 45.24378410345447, 45.489009661675425, 45.7329203091165, 45.97553697348188, 46.216880033165374, 46.45696933722647, 46.69582422444217, 46.93346354148605, 47.16990566028302, 47.40516849458506], [0.0, 4.743416490252569, 6.708203932499369, 8.215838362577493, 9.486832980505138, 10.606601717798213, 11.618950038622252, 12.549900398011133, 13.416407864998739, 14.230249470757707, 15.0, 15.732132722552276, 16.431676725154986, 17.10263137648707, 17.74823934929885, 18.371173070873837, 18.973665961010276, 19.557607215607945, 20.12461179749811, 20.676073128135336, 21.213203435596427, 21.73706511928416, 22.24859546128699, 22.74862633215465, 23.237900077244504, 23.717082451262847, 24.186773244895654, 24.64751508773248, 25.099800796022265, 25.544079548889606, 25.980762113533157, 26.410225292488512, 26.832815729997478, 27.24885318687743, 27.65863337187866, 28.062430400804562, 28.460498941515414, 28.85307609250702, 29.240383034426895, 29.622626487197252, 30.0, 30.37268509697488, 30.7408522978788, 31.10466202999158, 31.46426544510455, 31.819805153394633, 32.17141588429082, 32.5192250830182, 32.86335345030997, 33.20391543176798, 33.54101966249685, 33.87476937190865, 34.20526275297414, 34.532593299664015, 34.856850115866756, 35.178118198675726, 35.4964786985977, 35.81200915893997, 36.124783736376884, 36.43487340447336, 36.742346141747674, 37.04726710568541, 37.3496987939662, 37.6497011940334, 37.94733192202055, 38.242646351945886, 38.535697735995385, 38.82653731663436, 39.11521443121589, 39.4017766096911, 39.68626966596886, 39.96873778342268, 40.24922359499622, 40.527768258318886, 40.80441152620632, 41.07919181288746, 41.35214625627067, 41.62331077653482, 41.89272013130683, 42.16040796766559, 42.42640687119285, 42.69074841227312, 42.953463189829066, 43.2145808726638, 43.47413023856832, 43.73213921133976, 43.988634895845536, 44.24364361125788, 44.49719092257398, 44.749301670528894, 45.0, 45.249309386995066, 45.4972526643093, 45.74385204593072, 45.98912915026768, 46.23310502226732, 46.47580015448901, 46.717234507192316, 46.95742752749558, 47.196398167656824, 47.434164902525694, 47.67074574621211], [0.0, 4.769696007084729, 6.745368781616021, 8.261355820929154, 9.539392014169458, 10.665364503850771, 11.683321445547923, 12.619429464123963, 13.490737563232042, 14.309088021254185, 15.083103128998356, 15.819292019556377, 16.522711641858308, 17.19738352191984, 17.84656829757475, 18.472953201911167, 19.078784028338916, 19.665960439297134, 20.236106344848064, 20.790622886291793, 21.330729007701542, 21.857492994394395, 22.371857321197094, 22.87465846739575, 23.366642891095847, 23.848480035423645, 24.320773014030625, 24.784067462787466, 25.238858928247925, 25.685599078082646, 26.12470095522626, 26.556543449779003, 26.981475126464083, 27.39981751764052, 27.81186797034676, 28.217902119044926, 28.61817604250837, 29.01292815280802, 29.402380855978315, 29.786742017212966, 30.166206257996713, 30.540956108150905, 30.911163032147467, 31.276988346066826, 31.638584039112754, 31.99609351155231, 32.349652239243625, 32.69938837348491, 33.045423283716616, 33.3878720495931, 33.726843908080106, 34.0624426605022, 34.39476704383968, 34.723911070039335, 35.049964336643775, 35.37301231164799, 35.6931365951495, 36.01041516006168, 36.32492257390234, 36.636730203444735, 36.945906403822335, 37.25251669350676, 37.556623916427846, 37.85828839237189, 38.15756805667783, 38.45451859014751, 38.749193539995126, 39.041644432579936, 39.33192087859427, 39.62007067131507, 39.90613987846983, 40.19017292821717, 40.47221268969613, 40.75230054855799, 41.030476477857285, 41.30677910464577, 41.581245772583586, 41.85391260085489, 42.1248145396511, 42.39398542246294, 42.661458015403085, 42.92726406376256, 43.19143433598843, 43.45399866525519, 43.71498598878879, 43.974424385090025, 44.232341109192944, 44.48876262608346, 44.74371464239419, 44.997222136483046, 45.249309386995066, 45.5, 45.7493169347915, 45.9972825284277, 46.243918519087465, 46.489246068311324, 46.73328578219169, 46.97605773157216, 47.21758147131215, 47.45787605866913, 47.69696007084729, 47.93485162175847], [0.0, 4.79583152331272, 6.782329983125269, 8.306623862918077, 9.59166304662544, 10.72380529476361, 11.747340124470732, 12.688577540449522, 13.564659966250538, 14.38749456993816, 15.165750888103101, 15.90597372058687, 16.613247725836153, 17.291616465790586, 17.944358444926362, 18.57417562100671, 19.18332609325088, 19.77371993328519, 20.346989949375807, 20.904544960366877, 21.44761058952722, 21.977260975835915, 22.494443758403985, 23.000000000000004, 23.494680248941464, 23.9791576165636, 24.454038521274974, 24.91987158875423, 25.377155080899044, 25.82634314028992, 26.267851073127392, 26.70205984563738, 27.129319932501076, 27.549954627911827, 27.964262908219126, 28.37252191822222, 28.77498913987632, 29.171904291629648, 29.56349099818897, 29.94995826374388, 30.331501776206203, 30.708305065568176, 31.08054053584011, 31.448370387032778, 31.81194744117374, 32.17141588429082, 32.526911934581186, 32.8785644455472, 33.22649545167231, 33.57082066318904, 33.91164991562634, 34.24908757908742, 34.58323293158117, 34.91418050019219, 35.242020373412196, 35.56683848755748, 35.888716889852724, 36.20773398046335, 36.523964735499355, 36.837480912787726, 37.14835124201342, 37.456641600656084, 37.76241517699842, 38.06573262134856, 38.36665218650176, 38.665229858362416, 38.961519477556315, 39.25557285278105, 39.54743986657038, 39.83716857408418, 40.12480529547776, 40.41039470235351, 40.693979898751614, 40.97560249709576, 41.255302689472536, 41.53311931459038, 41.809089920733754, 42.08325082500163, 42.35563716909475, 42.626282971894234, 42.89522117905444, 43.16248370981448, 43.428101501216936, 43.69210454990696, 43.95452195167183, 44.21538193886829, 44.474711915874174, 44.73253849269009, 44.98888751680797, 45.24378410345448, 45.49725266430931, 45.7493169347915, 46.00000000000001, 46.24932431938871, 46.49731175025069, 46.74398357008097, 46.98936049788293, 47.23346271447818, 47.47630988187688, 47.71792116176061, 47.9583152331272, 48.19751030914357], [0.0, 4.821825380496478, 6.8190908484929285, 8.351646544245035, 9.643650760992957, 10.781929326423914, 11.811011811017718, 12.757350822173075, 13.638181696985857, 14.465476141489434, 15.247950681976906, 15.99218559171948, 16.70329308849007, 17.385338650713713, 18.041618552668716, 18.6748493969831, 19.287301521985913, 19.880895352071043, 20.457272545478787, 21.017849556983705, 21.563858652847827, 22.096379793984358, 22.616365755797286, 23.124662159694356, 23.622023622035435, 24.10912690248239, 24.5865817062885, 25.054939632735106, 25.51470164434615, 25.966324345197574, 26.410225292488512, 26.8467875173176, 27.276363393971714, 27.69927796892909, 28.115831839019098, 28.526303651191828, 28.93095228297887, 29.330018752124936, 29.723727895403705, 30.112289849827103, 30.495901363953813, 30.874746962525865, 31.248999983999493, 31.618823507524755, 31.98437118343896, 32.34578797927173, 32.703210851535665, 33.0567693521312, 33.40658617698014, 33.75277766347534, 34.09545424246464, 34.434720849746995, 34.770677301427426, 35.10341863693621, 35.433035433053156, 35.75961409187745, 36.08323710533743, 36.4039832985348, 36.721928053957086, 37.037143518365454, 37.3496987939662, 37.659660115301094, 37.96709101313926, 38.27205246651922, 38.57460304397183, 38.874799034850334, 39.17269457160179, 39.46834174373178, 39.761790704142086, 40.05308976845607, 40.34228550788862, 40.629422836166405, 40.914545090957574, 41.19769411022904, 41.47891030391227, 41.75823272122517, 42.03569911396741, 42.311345996080064, 42.585208699735176, 42.85732142819941, 43.127717305695654, 43.396428424468304, 43.663485889241606, 43.92891985924535, 44.192759587968716, 44.45503346079047, 44.715769030622745, 44.97499305169485, 45.23273151159457, 45.489009661675425, 45.74385204593072, 45.997282528427704, 46.24932431938871, 46.50000000000001, 46.74933154602321, 46.997340350279394, 47.24404724407087, 47.48947251760121, 47.7336359394505, 47.976556775158436, 48.21825380496478, 48.45874534075352], [0.0, 4.847679857416329, 6.855654600401045, 8.396427811873334, 9.695359714832659, 10.8397416943394, 11.874342087037919, 12.825755338380661, 13.71130920080209, 14.543039572248988, 15.329709716755893, 16.07793519081353, 16.792855623746668, 17.478558292948538, 18.138357147217057, 18.77498335551859, 19.390719429665317, 19.987496091306685, 20.566963801203133, 21.130546609115445, 21.6794833886788, 22.214859891523066, 22.737634001804146, 23.24865587512534, 23.748684174075837, 24.23839928708165, 24.718414188616556, 25.189283435620005, 25.651510676761323, 26.10555496441323, 26.551836094703507, 26.99073915253156, 27.42261840160418, 27.847800631288646, 28.26658805020514, 28.679260799399977, 29.086079144497976, 29.48728539557347, 29.883105594967876, 30.273751006441213, 30.659419433511786, 31.040296390337513, 31.416556144810023, 31.788362650504666, 32.15587038162706, 32.5192250830182, 32.87856444554719, 33.23401871576774, 33.585711247493336, 33.933759001914304, 34.27827300200522, 34.619358746227526, 34.957116585897076, 35.2916420700426, 35.62302626111376, 35.951356024495105, 36.276714294434115, 36.5991803186902, 36.91882988394947, 37.23573552382174, 37.54996671103718, 37.8615900352851, 38.17066936798463, 38.47726601514198, 38.781438859330635, 39.08324449172561, 39.382737335030434, 39.679969758053, 39.97499218261337, 40.267853183401776, 40.5585995813465, 40.84727653100021, 41.13392760240627, 41.41859485786547, 41.701318923986086, 41.982139059366666, 42.26109321823089, 42.53821811030641, 42.8135492572153, 43.087121045621046, 43.3589667773576, 43.629118716746966, 43.89760813529595, 44.16446535394717, 44.42971978304613, 44.693399960173096, 44.955533585978046, 45.21614755814565, 45.47526800360829, 45.732920309116494, 45.98912915026768, 46.243918519087465, 46.49731175025068, 46.74933154602321, 47.00000000000001, 47.249338619709796, 47.497368348151674, 47.74410958432465, 47.98958220280731, 48.23380557244059, 48.4767985741633, 48.718579618047166], [0.0, 4.873397172404482, 6.892024376045111, 8.440971508067067, 9.746794344808963, 10.897247358851683, 11.937336386313321, 12.893796958227625, 13.784048752090222, 14.620191517213446, 15.41103500742244, 16.163229875244614, 16.881943016134134, 17.57128339080558, 18.234582528810467, 18.874586088176873, 19.493588689617926, 20.093531297410117, 20.676073128135332, 21.242645786248, 21.794494717703365, 22.332711434127294, 22.85825890132492, 23.371991785040485, 23.874672772626642, 24.36698586202241, 24.849547279578356, 25.322914524201202, 25.78759391645525, 26.24404694402142, 26.692695630078273, 27.13392710243027, 27.568097504180443, 27.995535358338838, 28.41654447676564, 28.83140648667699, 29.24038303442689, 29.643717715563277, 30.041637771599603, 30.434355587066406, 30.82207001484488, 31.20496755325985, 31.583223394707517, 31.957002362549584, 32.32645975048923, 32.691742076555045, 33.05298776207682, 33.41032774457623, 33.76388603226827, 34.11378020683137, 34.46012188022555, 34.80301711058971, 35.14256678161116, 35.47886694921358, 35.812009158939965, 36.1420807370024, 36.469165057620934, 36.79334178897046, 37.11468711979127, 37.43327396848958, 37.749172176353746, 38.06244868633651, 38.37316770869978, 38.681390874682876, 38.98717737923585, 39.29058411375428, 39.59166578965831, 39.89047505357638, 40.18706259482023, 40.48147724577254, 40.773766075750224, 41.063974478854334, 41.352146256270665, 41.63832369344376, 41.92254763250916, 42.20485754033533, 42.485291572496, 42.76388663346679, 43.04067843331469, 43.31570154112709, 43.58898943540673, 43.86057455164033, 44.130488327232456, 44.398761243980665, 44.66542286825459, 44.93050188902857, 45.19402615390666, 45.45602270326783, 45.71651780264984, 45.97553697348188, 46.23310502226732, 46.489246068311324, 46.74398357008097, 46.997340350279394, 47.2493386197098, 47.49999999999999, 47.749345545253284, 47.997395762686956, 48.24417063231577, 48.48968962573384, 48.73397172404482, 48.977035434987286], [0.0, 4.898979485566357, 6.92820323027551, 8.485281374238571, 9.797958971132713, 10.954451150103322, 12.0, 12.96148139681572, 13.85640646055102, 14.696938456699069, 15.491933384829668, 16.248076809271925, 16.970562748477143, 17.663521732655695, 18.33030277982336, 18.973665961010276, 19.595917942265427, 20.199009876724155, 20.784609690826528, 21.354156504062626, 21.908902300206645, 22.449944320643652, 22.978250586152114, 23.494680248941464, 24.0, 24.494897427831784, 24.979991993593597, 25.455844122715718, 25.92296279363144, 26.381811916545843, 26.832815729997474, 27.276363393971714, 27.71281292110204, 28.142494558940584, 28.5657137141714, 28.98275349237888, 29.393876913398138, 29.799328851502683, 30.199337741083003, 30.594117081556714, 30.983866769659336, 31.368774282716245, 31.749015732775092, 32.12475680841802, 32.49615361854385, 32.863353450309965, 33.2264954516723, 33.585711247493336, 33.941125496954285, 34.292856398964496, 34.64101615137755, 34.98571136907181, 35.32704346531139, 35.66510900025402, 36.00000000000001, 36.331804249169906, 36.66060555964672, 36.986484017813865, 37.30951621235526, 37.62977544445356, 37.94733192202055, 38.262252939417984, 38.57460304397182, 38.88444419044716, 39.19183588453085, 39.496835316263, 39.7994974842648, 40.099875311526844, 40.39801975344831, 40.693979898751614, 40.98780306383839, 41.27953488110059, 41.569219381653056, 41.856899072912704, 42.14261501141095, 42.42640687119285, 42.70831300812525, 42.988370520409354, 43.266615305567875, 43.54308211415449, 43.81780460041329, 44.09081537009721, 44.36214602563768, 44.63182720884279, 44.899888641287305, 45.16635916254486, 45.43126676640219, 45.69463863518345, 45.95650117230423, 46.21688003316537, 46.47580015448901, 46.73328578219169, 46.98936049788293, 47.24404724407087, 47.497368348151674, 47.749345545253284, 48.0, 48.24935232725928, 48.49742261192857, 48.744230427815765, 48.98979485566357, 49.23413450036469], [0.0, 4.924428900898053, 6.9641941385920605, 8.529361054615993, 9.848857801796106, 11.011357772772621, 12.06233808181482, 13.028814220795384, 13.928388277184121, 14.77328670269416, 15.572411502397438, 16.33248297106108, 17.058722109231987, 17.755280904564707, 18.42552577268828, 19.072231122760652, 19.69771560359221, 20.303940504246953, 20.892582415776182, 21.465087933665686, 22.022715545545243, 22.566568192793518, 23.097618924902196, 23.61673135723909, 24.12467616362964, 24.622144504490265, 25.109759058979446, 25.58808316384798, 26.05762844159077, 26.518861212352242, 26.972207918522354, 27.418059741710394, 27.856776554368242, 28.28869031963128, 28.71410803072246, 29.133314263914436, 29.54657340538832, 29.954131601500325, 30.356218473321086, 30.75304862936357, 31.144823004794876, 31.531730050855124, 31.913946794465904, 32.29163978493505, 32.66496594212216, 33.03407331831786, 33.399101784329474, 33.76018364878959, 34.11744421846397, 34.471002306286366, 34.8209706929603, 35.16745654721138, 35.51056180912941, 35.85038354048671, 36.187014245444466, 36.5205421646503, 36.85105154537656, 37.17862289004261, 37.50333318519836, 37.82525611281436, 38.144462245521304, 38.46101922726438, 38.7749919406826, 39.08644266238615, 39.39543120718442, 39.702015062210634, 40.00624951179503, 40.30818775385468, 40.607881008493905, 40.9053786194432, 41.200728148905334, 41.49397546632524, 41.785164831552365, 42.07433897282286, 42.36153915995027, 42.646805273079956, 42.93017586733137, 43.21168823362494, 43.491378455965275, 43.769281465429614, 44.045431091090485, 44.31986010808247, 44.592600283006604, 44.863682416850274, 45.133136385587036, 45.40099117860755, 45.66727493512176, 45.93201497866168, 46.19523784980439, 46.45696933722647, 46.717234507192316, 46.97605773157216, 47.23346271447818, 47.48947251760121, 47.74410958432465, 47.997395762686956, 48.24935232725928, 48.50000000000001, 48.74935897014443, 48.997448913183234, 49.24428900898053, 49.48989795907848], [0.0, 4.949747468305833, 7.0, 8.573214099741124, 9.899494936611665, 11.067971810589327, 12.12435565298214, 13.095800853708795, 14.0, 14.849242404917499, 15.652475842498529, 16.416455159382007, 17.146428199482248, 17.84656829757475, 18.520259177452136, 19.170289512680814, 19.79898987322333, 20.40833163195855, 21.0, 21.57544901039142, 22.135943621178654, 22.682592444427513, 23.2163735324878, 23.73815494093844, 24.24871130596428, 24.748737341529164, 25.23885892824793, 25.719642299223374, 26.19160170741759, 26.65520587052368, 27.110883423451916, 27.55902755904134, 28.0, 28.434134416225866, 28.861739379323623, 29.283100928692647, 29.698484809834998, 30.108138434649195, 30.51229260478472, 30.911163032147467, 31.304951684997057, 31.693847983480957, 32.07802986469088, 32.45766473423496, 32.832910318764014, 33.20391543176798, 33.57082066318903, 33.933759001914304, 34.292856398964496, 34.648232278140824, 35.0, 35.34826728426728, 35.6931365951495, 36.0347054934545, 36.373066958946424, 36.70830968595531, 37.04051835490427, 37.36977388210959, 37.69615364994153, 38.019731719200756, 38.34057902536163, 38.65876356015541, 38.97435053981015, 39.287402561126385, 39.59797974644666, 39.90613987846983, 40.2119385257662, 40.51542915976579, 40.8166632639171, 41.11569043564756, 41.41255848169731, 41.70731350734545, 42.0, 42.290660907581, 42.579337712087536, 42.86607049870562, 43.15089802078284, 43.433857760967996, 43.71498598878879, 43.99431781491787, 44.27188724235731, 44.54772721475249, 44.82186966202995, 45.09434554353794, 45.365184888855026, 45.63441683641854, 45.902069670114, 46.16817085395522, 46.4327470649756, 46.69582422444216, 46.95742752749558, 47.217581471312144, 47.47630988187688, 47.733635939450494, 47.98958220280731, 48.24417063231577, 48.49742261192856, 48.74935897014442, 49.0, 49.24936547814601, 49.49747468305833, 49.74434641243164], [0.0, 4.974937185533101, 7.035623639735145, 8.616843969807045, 9.949874371066201, 11.124297730643496, 12.186057606953941, 13.162446581088185, 14.07124727947029, 14.9248115565993, 15.732132722552274, 16.500000000000004, 17.23368793961409, 17.9373911146521, 18.614510468986285, 19.267848867997696, 19.899748742132402, 20.512191496766015, 21.106870919205434, 21.685248442201445, 22.248595461286993, 22.798026230355998, 23.334523779156072, 23.858960580880304, 24.372115213907882, 24.874685927665503, 25.367301787931652, 25.850531909421136, 26.32489316217637, 26.790856649237632, 27.248853186877422, 27.699277968929085, 28.14249455894058, 28.578838324886483, 29.008619408720577, 29.43212530552288, 29.8496231131986, 30.261361502748027, 30.667572450391315, 31.068472765811975, 31.464265445104548, 31.855140872392955, 32.241277890307025, 32.62284475639732, 33.00000000000001, 33.37289319193048, 33.741665637605976, 34.10645100270622, 34.46737587922818, 34.8245602987317, 35.178118198675726, 35.52815784698104, 35.8747822293042, 36.21808940294891, 36.55817282086183, 36.89512162874654, 37.22902093797257, 37.55995207664675, 37.88799282094527, 38.21321760857099, 38.53569773599539, 38.855501540965854, 39.17269457160179, 39.48733974326455, 39.799497484264805, 40.10922587136282, 40.416580755922446, 40.721615881494685, 41.02438299353203, 41.32493194186774, 41.62331077653483, 41.91956583744636, 42.21374183841087, 42.50588194591427, 42.79602785306132, 43.08421984903522, 43.37049688440289, 43.65489663256575, 43.937455547630435, 44.21820891895103, 44.497190922573985, 44.774434669797905, 45.04997225304363, 45.32383478921439, 45.596052460711995, 45.86665455426197, 46.1356694976891, 46.403124894774066, 46.669047558312144, 46.93346354148605, 47.196398167656824, 47.45787605866913, 47.71792116176061, 47.97655677515843, 48.23380557244059, 48.48968962573384, 48.744230427815765, 48.997448913183234, 49.24936547814602, 49.50000000000001, 49.749371855331006, 49.99749993749688], [0.0, 5.000000000000001, 7.071067811865476, 8.660254037844389, 10.000000000000002, 11.180339887498949, 12.247448713915892, 13.228756555322954, 14.142135623730953, 15.000000000000002, 15.811388300841898, 16.583123951777004, 17.320508075688778, 18.02775637731995, 18.708286933869708, 19.364916731037084, 20.000000000000004, 20.615528128088304, 21.213203435596427, 21.794494717703373, 22.360679774997898, 22.912878474779202, 23.45207879911715, 23.9791576165636, 24.494897427831784, 25.000000000000004, 25.49509756796393, 25.980762113533164, 26.45751311064591, 26.925824035672523, 27.386127875258303, 27.838821814150112, 28.284271247461906, 28.72281323269015, 29.154759474226502, 29.580398915498083, 30.000000000000004, 30.413812651491103, 30.822070014844886, 31.224989991991997, 31.622776601683796, 32.01562118716424, 32.403703492039305, 32.78719262151, 33.16624790355401, 33.54101966249684, 33.91164991562634, 34.27827300200522, 34.641016151377556, 35.0, 35.35533905932738, 35.707142142714254, 36.0555127546399, 36.4005494464026, 36.742346141747674, 37.08099243547832, 37.416573867739416, 37.74917217635375, 38.07886552931954, 38.40572873934304, 38.72983346207417, 39.05124837953327, 39.37003937005906, 39.68626966596886, 40.00000000000001, 40.31128874149275, 40.620192023179804, 40.926763859362254, 41.23105625617661, 41.53311931459038, 41.83300132670378, 42.1307488658818, 42.42640687119285, 42.72001872658766, 43.01162633521313, 43.30127018922194, 43.588989435406745, 43.874821936960615, 44.15880433163924, 44.44097208657795, 44.721359549995796, 45.0, 45.276925690687094, 45.552167895721496, 45.825756949558404, 46.09772228646444, 46.36809247747852, 46.63689526544408, 46.9041575982343, 47.16990566028302, 47.434164902525694, 47.69696007084729, 47.9583152331272, 48.21825380496478, 48.4767985741633, 48.73397172404482, 48.98979485566357, 49.24428900898053, 49.497474683058336, 49.749371855331006, 50.00000000000001, 50.24937810560446], [0.0, 5.024937810560446, 7.1063352017759485, 8.703447592764608, 10.049875621120892, 11.236102527122117, 12.308533625091172, 13.294735800308333, 14.212670403551897, 15.074813431681337, 15.890248582070704, 16.66583331249896, 17.406895185529216, 18.11767093199344, 18.801595676963167, 19.461500456028567, 20.099751242241783, 20.718349355100663, 21.319005605327845, 21.903196113809514, 22.472205054244235, 23.027157879338912, 23.569047498785352, 24.098755154571784, 24.617067250182345, 25.124689052802232, 25.62225595063792, 26.110342778293823, 26.589471600616665, 27.06011825546962, 27.52271788904577, 27.977669667075567, 28.425340807103794, 28.866070047722125, 29.300170647967224, 29.7279329923895, 30.149626863362673, 30.565503431155857, 30.975797003467083, 31.380726569026415, 31.78049716414141, 32.175301086392345, 32.56531897586757, 32.95072078119081, 33.33166662499792, 33.70830758136635, 34.08078637590395, 34.44923801769787, 34.81379037105843, 35.174564673923115, 35.53167600887974, 35.88523373199624, 36.23534186398688, 36.5820994476807, 36.925600875273524, 37.26593618842817, 37.603191353926334, 37.93744851726326, 38.26878623630491, 38.59727969689056, 38.923000912057134, 39.24601890638081, 39.56639988677262, 39.88420740092499, 40.19950248448357, 40.5123437979093, 40.8227877539004, 41.13088863615762, 41.43669871020133, 41.7402683268807, 42.04164601915582, 42.34087859267921, 42.63801121065569, 42.93308747341612, 43.22614949310197, 43.517237963823035, 43.80639222761903, 44.09365033652805, 44.37904911103888, 44.66262419518137, 44.94441010848847, 45.22444029504401, 45.50274716981384, 45.77936216244172, 46.054315758677824, 46.327637539594015, 46.599356218729035, 46.86949967729548, 47.138094997570704, 47.40516849458506, 47.67074574621211, 47.93485162175847, 48.19751030914357, 48.45874534075352, 48.718579618047166, 48.977035434987286, 49.23413450036469, 49.48989795907848, 49.74434641243164, 49.99749993749688, 50.249378105604464, 50.50000000000001]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"A = 5.5\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.55, 0.7778174593052023, 0.9526279441628827, 1.1, 1.2298373876248845, 1.3472193585307481, 1.4551632210855248, 1.5556349186104046, 1.65, 1.7392527130926088, 1.82414363469547, 1.9052558883257653, 1.9830532015051943, 2.0579115627256677, 2.130140840414079, 2.2, 2.2677080940897136, 2.333452377915607, 2.397394418947371, 2.459674775249769, 2.520416632225712, 2.5797286679028866, 2.637707337821996, 2.6944387170614963, 2.75, 2.804460732476032, 2.8578838324886475, 2.9103264421710495, 2.9618406439239777, 3.0124740662784135, 3.0622703995565117, 3.111269837220809, 3.159509455595916, 3.2070235421649156, 3.253843880704789, 3.3, 3.345519391664021, 3.3904277016329374, 3.4347488991191195, 3.4785054261852175, 3.5217183305880675, 3.5644073841243236, 3.6065911883661, 3.64828726939094, 3.6895121628746526, 3.7302814907188977, 3.7706100302205745, 3.8105117766515306, 3.85, 3.8890872965260117, 3.927785635698568, 3.9661064030103885, 4.004060439104285, 4.0416580755922435, 4.078909167902615, 4.115823125451335, 4.152408939398912, 4.18867520822515, 4.224630161327735, 4.260281680828158, 4.29563732174866, 4.330704330706496, 4.365489663256575, 4.4, 4.434241761564202, 4.468221122549778, 4.501944024529847, 4.535416188179427, 4.568643124604941, 4.601630145937416, 4.6343823752469975, 4.666904755831214, 4.699202059924642, 4.7312788968734445, 4.763139720814413, 4.794788837894742, 4.826230413065667, 4.857468476480316, 4.888506929523574, 4.919349550499538, 4.95, 4.9804618259755795, 5.0107384685293646, 5.040833264451424, 5.070749451511088, 5.100490172522637, 5.130058479198849, 5.159457335805773, 5.188689622631132, 5.217758139277826, 5.246665607793201, 5.275414675643992, 5.304007918546126, 5.332447843157962, 5.3607368896449294, 5.388877434122993, 5.416871790987859, 5.444722215136417, 5.47243090408641, 5.5, 5.527431591616491], [0.0, 0.7778174593052023, 1.0999999999999999, 1.3472193585307481, 1.5556349186104046, 1.7392527130926088, 1.9052558883257653, 2.0579115627256677, 2.1999999999999997, 2.3334523779156067, 2.4596747752497685, 2.579728667902886, 2.6944387170614963, 2.8044607324760316, 2.9103264421710495, 3.012474066278413, 3.111269837220809, 3.207023542164915, 3.3, 3.3904277016329374, 3.4785054261852175, 3.5644073841243236, 3.64828726939094, 3.7302814907188973, 3.8105117766515306, 3.8890872965260113, 3.9661064030103885, 4.0416580755922435, 4.115823125451335, 4.18867520822515, 4.260281680828158, 4.330704330706496, 4.3999999999999995, 4.468221122549778, 4.535416188179426, 4.601630145937415, 4.666904755831213, 4.7312788968734445, 4.794788837894741, 4.857468476480316, 4.919349550499537, 4.9804618259755795, 5.040833264451424, 5.100490172522637, 5.159457335805772, 5.217758139277825, 5.275414675643992, 5.332447843157962, 5.388877434122993, 5.444722215136416, 5.5, 5.554727716099143, 5.608921464952063, 5.662596577542851, 5.715767664977295, 5.768448664935834, 5.820652884342099, 5.872393038617221, 5.923681287847955, 5.974529270160119, 6.024948132556826, 6.074948559452993, 6.124540799113023, 6.173734688177003, 6.222539674441618, 6.270964838045258, 6.319018911191831, 6.366710296534624, 6.41404708432983, 6.461037068458902, 6.507687761409578, 6.554006408297141, 6.6, 6.645675285477014, 6.691038783328041, 6.73609679265374, 6.780855403265875, 6.825320505294971, 6.869497798238239, 6.913392799487094, 6.957010852370435, 7.00035713374682, 7.043436661176134, 7.086254299698819, 7.128814768248647, 7.171122645722913, 7.2131823767322, 7.254998277050105, 7.29657453878188, 7.337915235269483, 7.379024325749306, 7.419905659777622, 7.4605629814377945, 7.500999933342221, 7.541220060441149, 7.581226813649621, 7.621023553303061, 7.660613552451267, 7.7, 7.739186003708659, 7.7781745930520225, 7.816968721953543], [0.0, 0.9526279441628827, 1.3472193585307481, 1.6500000000000004, 1.9052558883257653, 2.1301408404140796, 2.3334523779156076, 2.520416632225712, 2.6944387170614963, 2.857883832488648, 3.012474066278414, 3.1595094555959164, 3.3000000000000007, 3.4347488991191195, 3.5644073841243236, 3.689512162874653, 3.8105117766515306, 3.927785635698568, 4.041658075592244, 4.152408939398914, 4.260281680828159, 4.365489663256575, 4.468221122549779, 4.568643124604942, 4.666904755831215, 4.763139720814413, 4.857468476480317, 4.950000000000001, 5.040833264451424, 5.1300584791988495, 5.2177581392778265, 5.304007918546126, 5.388877434122993, 5.472430904086411, 5.554727716099144, 5.6358229212777795, 5.715767664977296, 5.794609564069007, 5.872393038617222, 5.949159604515583, 6.024948132556828, 6.099795078525181, 6.173734688177005, 6.246799180380301, 6.319018911191833, 6.390422521242238, 6.461037068458903, 6.530888147870856, 6.600000000000001, 6.668395609140179, 6.736096792653741, 6.803124282269142, 6.869497798238239, 6.935236117105172, 7.000357133746822, 7.064877918265823, 7.128814768248647, 7.192183256842112, 7.254998277050107, 7.31727408260754, 7.379024325749306, 7.440262092157776, 7.5009999333422215, 7.561249896677137, 7.621023553303061, 7.680332024072918, 7.739186003708659, 7.797595783316805, 7.855571271397136, 7.913122013465989, 7.970257210404193, 8.026985735629534, 8.083316151184489, 8.13925672282181, 8.194815434163237, 8.250000000000002, 8.304817878797827, 8.359276284463865, 8.413382197428097, 8.467142375087361, 8.520563361656318, 8.573651497465944, 8.62641292774697, 8.678853610932727, 8.73097932651315, 8.782795682469223, 8.834308122314956, 8.885521931771933, 8.936442245099558, 8.987074051102505, 9.037422198835243, 9.087491403022069, 9.137286249209884, 9.186811198669536, 9.236070593060667, 9.285068658873772, 9.33380951166243, 9.382297160077592, 9.430535509715238, 9.47852836678775, 9.526279441628827, 9.573792352041067], [0.0, 1.1, 1.5556349186104046, 1.9052558883257653, 2.2, 2.459674775249769, 2.6944387170614963, 2.9103264421710495, 3.111269837220809, 3.3, 3.4785054261852175, 3.64828726939094, 3.8105117766515306, 3.9661064030103885, 4.115823125451335, 4.260281680828158, 4.4, 4.535416188179427, 4.666904755831214, 4.794788837894742, 4.919349550499538, 5.040833264451424, 5.159457335805773, 5.275414675643992, 5.388877434122993, 5.5, 5.608921464952064, 5.715767664977295, 5.820652884342099, 5.9236812878479554, 6.024948132556827, 6.124540799113023, 6.222539674441618, 6.319018911191832, 6.414047084329831, 6.507687761409578, 6.6, 6.691038783328042, 6.780855403265875, 6.869497798238239, 6.957010852370435, 7.043436661176135, 7.128814768248647, 7.2131823767322, 7.29657453878188, 7.379024325749305, 7.460562981437795, 7.541220060441149, 7.621023553303061, 7.7, 7.778174593052023, 7.855571271397136, 7.932212806020777, 8.00812087820857, 8.083316151184487, 8.15781833580523, 8.23164625090267, 8.304817878797824, 8.3773504164503, 8.44926032265547, 8.520563361656317, 8.59127464349732, 8.661408661412992, 8.73097932651315, 8.8, 8.868483523128404, 8.936442245099556, 9.003888049059695, 9.070832376358855, 9.137286249209883, 9.203260291874832, 9.268764750493995, 9.333809511662428, 9.398404119849284, 9.462557793746889, 9.526279441628827, 9.589577675789483, 9.652460826131334, 9.714936952960633, 9.777013859047148, 9.838699100999076, 9.9, 9.960923651951159, 10.021476937058729, 10.081666528902849, 10.141498903022176, 10.200980345045274, 10.260116958397697, 10.318914671611546, 10.377379245262263, 10.435516278555651, 10.493331215586402, 10.550829351287984, 10.608015837092251, 10.664895686315925, 10.721473779289859, 10.777754868245985, 10.833743581975718, 10.889444430272833, 10.94486180817282, 11.0, 11.054863183232982], [0.0, 1.2298373876248845, 1.7392527130926085, 2.1301408404140796, 2.459674775249769, 2.7500000000000004, 3.0124740662784144, 3.253843880704789, 3.478505426185217, 3.689512162874653, 3.8890872965260117, 4.078909167902615, 4.260281680828159, 4.434241761564203, 4.601630145937416, 4.763139720814412, 4.919349550499538, 5.070749451511088, 5.2177581392778265, 5.360736889644931, 5.500000000000001, 5.63582292127778, 5.768448664935834, 5.898092912119985, 6.024948132556829, 6.149186938124422, 6.27096483804526, 6.390422521242239, 6.507687761409578, 6.622877018335764, 6.73609679265374, 6.847444778893803, 6.957010852370434, 7.064877918265822, 7.171122645722915, 7.275816105427625, 7.379024325749306, 7.480808779804494, 7.581226813649622, 7.680332024072919, 7.778174593052023, 7.874801584801996, 7.970257210404192, 8.064583064238349, 8.15781833580523, 8.25, 8.341162988456707, 8.43134034421574, 8.520563361656318, 8.608861713374191, 8.696263565463044, 8.782795682469223, 8.868483523128406, 8.95335132785484, 9.037422198835241, 9.120718173477352, 9.203260291874832, 9.285068658873772, 9.366162501259522, 9.446560220524718, 9.526279441628825, 9.60533705811514, 9.683749273912454, 9.761531642114367, 9.838699100999076, 9.91526600752597, 9.991246168521723, 10.06665286974772, 10.141498903022176, 10.21579659155369, 10.28955781362834, 10.362794024779225, 10.435516278555653, 10.507735245998541, 10.57946123391924, 10.650704202070397, 10.721473779289862, 10.791779278691722, 10.861629711972327, 10.931033802893486, 11.000000000000002, 11.068536488623959, 11.136651202224124, 11.20435183310485, 11.27164584255556, 11.338540470448567, 11.405042744330247, 11.471159488037816, 11.536897329871667, 11.602262710350942, 11.667261889578034, 11.731900954235847, 11.79618582423997, 11.860122259066305, 11.92371586377334, 11.986972094736851, 12.049896265113658, 12.112493550049885, 12.174768991648262, 12.236727503707847, 12.298373876248844, 12.35971277983433], [0.0, 1.3472193585307481, 1.9052558883257649, 2.333452377915607, 2.6944387170614963, 3.012474066278414, 3.3000000000000007, 3.564407384124323, 3.8105117766515297, 4.0416580755922435, 4.260281680828159, 4.468221122549778, 4.666904755831214, 4.857468476480316, 5.040833264451424, 5.217758139277826, 5.388877434122993, 5.554727716099143, 5.715767664977295, 5.872393038617222, 6.024948132556828, 6.173734688177004, 6.319018911191832, 6.461037068458902, 6.600000000000001, 6.736096792653741, 6.869497798238239, 7.000357133746821, 7.128814768248646, 7.254998277050107, 7.379024325749306, 7.500999933342221, 7.6210235533030595, 7.739186003708659, 7.855571271397135, 7.970257210404191, 8.083316151184487, 8.194815434163237, 8.304817878797826, 8.413382197428096, 8.520563361656318, 8.62641292774697, 8.73097932651315, 8.834308122314955, 8.936442245099556, 9.03742219883524, 9.137286249209883, 9.236070593060667, 9.333809511662428, 9.430535509715236, 9.526279441628827, 9.621070626494747, 9.714936952960633, 9.807904975069857, 9.9, 9.991246168521723, 10.081666528902849, 10.17128310489881, 10.260116958397697, 10.34818824722473, 10.435516278555651, 10.522119558339945, 10.60801583709225, 10.69322215237297, 10.777754868245985, 10.861629711972324, 10.944861808172819, 11.027465710669881, 11.109455432198287, 11.190844472156693, 11.271645842555559, 11.351872092302662, 11.43153532995459, 11.510647245050992, 11.589219128138012, 11.667261889578036, 11.744786077234444, 11.821801893112573, 11.898319209031166, 11.974347581392484, 12.049896265113656, 12.124974226776732, 12.19959015705036, 12.27375248243177, 12.347469376354008, 12.420748769699836, 12.493598360760602, 12.566025624675449, 12.638037822383664, 12.709642009120476, 12.780845042484476, 12.851653590102714, 12.922074136917804, 12.99211299211949, 13.06177629574171, 13.131070024944654, 13.200000000000003, 13.268571889996304, 13.336791218280357, 13.404663367649338, 13.472193585307481, 13.53938698760029], [0.0, 1.455163221085525, 2.0579115627256677, 2.520416632225712, 2.91032644217105, 3.2538438807047894, 3.5644073841243236, 3.8499999999999996, 4.115823125451335, 4.365489663256574, 4.601630145937415, 4.826230413065668, 5.040833264451424, 5.246665607793202, 5.444722215136416, 5.635822921277779, 5.8206528843421, 5.999791663049643, 6.173734688177003, 6.342909427068939, 6.507687761409579, 6.668395609140179, 6.825320505294972, 6.978717647247236, 7.128814768248647, 7.275816105427625, 7.419905659777624, 7.561249896677136, 7.699999999999999, 7.836293766826255, 7.970257210404191, 8.10200592446093, 8.23164625090267, 8.359276284463865, 8.484986741297833, 8.608861713374191, 8.730979326513149, 8.851412316687094, 8.97022853666505, 9.087491403022069, 9.20326029187483, 9.31759089035358, 9.430535509715236, 9.54214336509361, 9.652460826131335, 9.761531642114365, 9.869397144709499, 9.976096430969381, 10.081666528902849, 10.186142547598674, 10.28955781362834, 10.391943995230152, 10.493331215586403, 10.593748156342023, 10.69322215237297, 10.791779278691722, 10.889444430272832, 10.986241395490998, 11.082192923785437, 11.177320788095868, 11.271645842555557, 11.365188075874503, 11.457966660799812, 11.55, 11.6413057686842, 11.731900954235847, 11.821801893112573, 11.911024305239243, 11.999583326099286, 12.08749353670975, 12.174768991648262, 12.261423245284375, 12.347469376354006, 12.432920011003047, 12.517787344415146, 12.602083161128562, 12.685818854137878, 12.76900544286829, 12.851653590102718, 12.933773617935334, 13.015375522819157, 13.096468989769724, 13.177063405782034, 13.257167872513344, 13.336791218280357, 13.415942009415515, 13.494628561023827, 13.572858947178373, 13.650641010589943, 13.727982371783552, 13.804890437812247, 13.881372410536358, 13.957435294494472, 14.033085904390381, 14.108330872218728, 14.183176654050389, 14.257629536497294, 14.331695642874923, 14.405380939079675, 14.478691239197003, 14.55163221085525, 14.624209380339167], [0.0, 1.5556349186104046, 2.1999999999999997, 2.6944387170614963, 3.111269837220809, 3.4785054261852175, 3.8105117766515306, 4.115823125451335, 4.3999999999999995, 4.666904755831213, 4.919349550499537, 5.159457335805772, 5.388877434122993, 5.608921464952063, 5.820652884342099, 6.024948132556826, 6.222539674441618, 6.41404708432983, 6.6, 6.780855403265875, 6.957010852370435, 7.128814768248647, 7.29657453878188, 7.4605629814377945, 7.621023553303061, 7.7781745930520225, 7.932212806020777, 8.083316151184487, 8.23164625090267, 8.3773504164503, 8.520563361656317, 8.661408661412992, 8.799999999999999, 8.936442245099556, 9.070832376358853, 9.20326029187483, 9.333809511662427, 9.462557793746889, 9.589577675789482, 9.714936952960633, 9.838699100999074, 9.960923651951159, 10.081666528902849, 10.200980345045274, 10.318914671611545, 10.43551627855565, 10.550829351287984, 10.664895686315925, 10.777754868245985, 10.889444430272832, 11.0, 11.109455432198287, 11.217842929904126, 11.325193155085701, 11.43153532995459, 11.536897329871667, 11.641305768684198, 11.744786077234442, 11.84736257569591, 11.949058540320237, 12.049896265113652, 12.149897118905987, 12.249081598226047, 12.347469376354006, 12.445079348883237, 12.541929676090517, 12.638037822383662, 12.733420593069248, 12.82809416865966, 12.922074136917804, 13.015375522819156, 13.108012816594282, 13.2, 13.291350570954028, 13.382077566656083, 13.47219358530748, 13.56171080653175, 13.650641010589942, 13.738995596476478, 13.826785598974189, 13.91402170474087, 14.00071426749364, 14.086873322352268, 14.172508599397638, 14.257629536497294, 14.342245291445826, 14.4263647534644, 14.50999655410021, 14.59314907756376, 14.675830470538965, 14.758048651498612, 14.839811319555244, 14.921125962875589, 15.001999866684441, 15.082440120882298, 15.162453627299241, 15.242047106606122, 15.321227104902533, 15.4, 15.478372007417319, 15.556349186104045, 15.633937443907087], [0.0, 1.6500000000000001, 2.3334523779156067, 2.857883832488648, 3.3000000000000003, 3.689512162874653, 4.041658075592244, 4.365489663256574, 4.666904755831213, 4.949999999999999, 5.217758139277826, 5.472430904086409, 5.715767664977296, 5.949159604515582, 6.173734688177003, 6.390422521242237, 6.6000000000000005, 6.80312428226914, 7.00035713374682, 7.192183256842112, 7.379024325749306, 7.561249896677136, 7.739186003708659, 7.913122013465987, 8.083316151184489, 8.25, 8.413382197428096, 8.573651497465942, 8.730979326513149, 8.885521931771933, 9.037422198835241, 9.186811198669535, 9.333809511662427, 9.478528366787748, 9.621070626494745, 9.761531642114365, 9.899999999999999, 10.036558174992063, 10.17128310489881, 10.304246697357357, 10.435516278555651, 10.565154991764201, 10.69322215237297, 10.8197735650983, 10.944861808172819, 11.068536488623957, 11.190844472156693, 11.311830090661724, 11.431535329954592, 11.55, 11.667261889578034, 11.783356907095703, 11.898319209031165, 12.012181317312857, 12.12497422677673, 12.236727503707845, 12.347469376354006, 12.457226818196736, 12.566025624675449, 12.673890483983204, 12.780845042484474, 12.886911965245979, 12.992112992119486, 13.096468989769724, 13.200000000000001, 13.302725284692606, 13.404663367649334, 13.505832073589541, 13.60624856453828, 13.705929373814824, 13.804890437812247, 13.903147125740992, 14.00071426749364, 14.097606179773924, 14.193836690620333, 14.289419162443238, 14.384366513684224, 14.478691239197001, 14.572405429440948, 14.665520788570722, 14.758048651498612, 14.85, 14.941385477926739, 15.032215405588094, 15.122499793354272, 15.212248354533264, 15.30147051756791, 15.390175437596545, 15.478372007417319, 15.566068867893394, 15.653274417833478, 15.7399968233796, 15.826244026931974, 15.912023755638375, 15.997343529473886, 16.08221066893479, 16.166632302368978, 16.250615372963576, 16.334166645409248, 16.417292712259233, 16.5, 16.58229477484947], [0.0, 1.7392527130926088, 2.4596747752497685, 3.012474066278414, 3.4785054261852175, 3.8890872965260117, 4.260281680828159, 4.601630145937415, 4.919349550499537, 5.217758139277826, 5.5, 5.768448664935834, 6.024948132556828, 6.270964838045259, 6.507687761409578, 6.736096792653739, 6.957010852370435, 7.171122645722914, 7.379024325749306, 7.581226813649623, 7.778174593052023, 7.970257210404192, 8.15781833580523, 8.341162988456706, 8.520563361656318, 8.696263565463044, 8.868483523128406, 9.037422198835241, 9.20326029187483, 9.366162501259522, 9.526279441628825, 9.683749273912454, 9.838699100999074, 9.991246168521723, 10.141498903022176, 10.289557813628338, 10.435516278555651, 10.57946123391924, 10.72147377928986, 10.861629711972325, 11.0, 11.136651202224124, 11.271645842555559, 11.405042744330245, 11.536897329871667, 11.667261889578032, 11.79618582423997, 11.92371586377334, 12.049896265113656, 12.17476899164826, 12.298373876248844, 12.420748769699838, 12.541929676090518, 12.661950876543473, 12.780845042484476, 12.898643339514432, 13.015375522819156, 13.131070024944654, 13.245754036671526, 13.359453581640231, 13.472193585307478, 13.583997938751315, 13.694889557787604, 13.804890437812247, 13.91402170474087, 14.022303662380157, 14.129755836531642, 14.236397016099263, 14.342245291445828, 14.447318090220067, 14.55163221085525, 14.65520385392165, 14.758048651498612, 14.860181694716925, 14.961617559608987, 15.062370331392069, 15.162453627299247, 15.261880618062769, 15.360664048145837, 15.458816254810717, 15.556349186104047, 15.653274417833478, 15.74960316960399, 15.845346319976727, 15.940514420808384, 16.035117710824576, 16.129166128476697, 16.22266932412789, 16.31563667161046, 16.408077279193925, 16.5, 16.59141344189819, 16.68232597691341, 16.772745750174597, 16.86268068843148, 16.952138508164683, 17.041126723312637, 17.129652652637184, 17.217723426748382, 17.305345994807503, 17.392527130926087, 17.479273440277776], [0.0, 1.8241436346954703, 2.579728667902886, 3.1595094555959164, 3.6482872693909405, 4.078909167902616, 4.468221122549779, 4.826230413065667, 5.159457335805772, 5.47243090408641, 5.768448664935834, 6.050000000000001, 6.319018911191833, 6.577043408705769, 6.825320505294972, 7.064877918265821, 7.296574538781881, 7.521136882147539, 7.739186003708659, 7.95125776214053, 8.157818335805231, 8.359276284463867, 8.555992052357226, 8.748285546322776, 8.936442245099558, 9.12071817347735, 9.301343988908272, 9.478528366787748, 9.652460826131334, 9.823314104720465, 9.991246168521723, 10.156401921940663, 10.318914671611545, 10.47890738579171, 10.636493783197546, 10.79177927869172, 10.94486180817282, 11.095832551007609, 11.244776565143482, 11.39177334746439, 11.536897329871667, 11.680218319877419, 11.821801893112575, 11.96170974401235, 12.100000000000001, 12.236727503707844, 12.371944067122193, 12.505698700992282, 12.638037822383666, 12.769005442868291, 12.898643339514432, 13.026991210559714, 13.154086817411539, 13.279966114414602, 13.404663367649336, 13.52821126387373, 13.650641010589943, 13.771982428103806, 13.8922640343466, 14.011513123142699, 14.129755836531642, 14.247017231687481, 14.363321342920655, 14.478691239197003, 14.593149077563762, 14.706716152833032, 14.819412943838229, 14.931259156548052, 15.042273764295079, 15.152475045351503, 15.26188061806277, 15.370507473730333, 15.478372007417319, 15.585490046835229, 15.691876879455817, 15.79754727797958, 15.90251552428106, 16.006795431940773, 16.110400367464493, 16.213343270282046, 16.315636671610463, 16.41729271225923, 16.51832315944933, 16.618739422711943, 16.718552568927734, 16.817773336562723, 16.91641214915267, 17.014479128083824, 17.111984104714452, 17.208936631878217, 17.305345994807503, 17.40122122151201, 17.496571092645553, 17.591404150891425, 17.68572870989488, 17.779552862769073, 17.872884490199116, 17.965731268167186, 18.05810067532021, 18.150000000000006, 18.2414363469547, 18.332416643748857], [0.0, 1.9052558883257653, 2.6944387170614963, 3.3000000000000007, 3.8105117766515306, 4.260281680828159, 4.666904755831215, 5.040833264451424, 5.388877434122993, 5.715767664977296, 6.024948132556828, 6.319018911191833, 6.600000000000001, 6.869497798238239, 7.128814768248647, 7.379024325749306, 7.621023553303061, 7.855571271397136, 8.083316151184489, 8.304817878797827, 8.520563361656318, 8.73097932651315, 8.936442245099558, 9.137286249209884, 9.33380951166243, 9.526279441628827, 9.714936952960635, 9.900000000000002, 10.081666528902849, 10.260116958397699, 10.435516278555653, 10.608015837092251, 10.777754868245985, 10.944861808172822, 11.109455432198288, 11.271645842555559, 11.431535329954592, 11.589219128138014, 11.744786077234444, 11.898319209031166, 12.049896265113656, 12.199590157050363, 12.34746937635401, 12.493598360760602, 12.638037822383666, 12.780845042484476, 12.922074136917805, 13.061776295741712, 13.200000000000003, 13.336791218280357, 13.472193585307481, 13.606248564538284, 13.738995596476478, 13.870472234210345, 14.000714267493644, 14.129755836531645, 14.257629536497294, 14.384366513684224, 14.509996554100214, 14.63454816521508, 14.758048651498612, 14.880524184315552, 15.001999866684443, 15.122499793354274, 15.242047106606122, 15.360664048145836, 15.478372007417319, 15.59519156663361, 15.711142542794272, 15.826244026931978, 15.940514420808386, 16.053971471259068, 16.166632302368978, 16.27851344564362, 16.389630868326474, 16.500000000000004, 16.609635757595655, 16.71855256892773, 16.826764394856195, 16.934284750174722, 17.041126723312637, 17.147302994931888, 17.25282585549394, 17.357707221865454, 17.4619586530263, 17.565591364938445, 17.668616244629913, 17.771043863543866, 17.872884490199116, 17.97414810220501, 18.074844397670486, 18.174982806044138, 18.27457249841977, 18.373622397339073, 18.472141186121334, 18.570137317747545, 18.66761902332486, 18.764594320155183, 18.861071019430476, 18.9570567335755, 19.052558883257653, 19.147584704082135], [0.0, 1.9830532015051945, 2.8044607324760316, 3.4347488991191195, 3.966106403010389, 4.434241761564203, 4.857468476480316, 5.246665607793201, 5.608921464952063, 5.949159604515582, 6.270964838045259, 6.577043408705769, 6.869497798238239, 7.15, 7.419905659777624, 7.680332024072917, 7.932212806020778, 8.17633781102518, 8.413382197428096, 8.643928505025944, 8.868483523128406, 9.087491403022069, 9.30134398890827, 9.51038905618482, 9.714936952960633, 9.915266007525972, 10.111626970967631, 10.304246697357359, 10.493331215586402, 10.679068311421181, 10.861629711972325, 11.041172944936601, 11.217842929904126, 11.39177334746439, 11.563087822895753, 11.731900954235849, 11.898319209031165, 12.062441709703721, 12.22436092399108, 12.384163274117475, 12.541929676090518, 12.697736018676718, 12.851653590102716, 13.003749459290578, 13.154086817411539, 13.302725284692606, 13.449721186701234, 13.595127803739105, 13.738995596476478, 13.88137241053636, 14.02230366238016, 14.161832508542108, 14.3, 14.436845223247358, 14.572405429440948, 14.706716152833033, 14.839811319555247, 14.97172334769782, 15.10248323952058, 15.232120666538853, 15.360664048145834, 15.488140624361595, 15.614576523236229, 15.739996823379604, 15.864425612041556, 15.987886039123495, 16.110400367464493, 16.231990019711077, 16.35267562205036, 16.472477045059133, 16.591413441898194, 16.709503284059643, 16.82676439485619, 16.9432139808243, 17.058868661197906, 17.173744495595596, 17.287857010051887, 17.401221221512014, 17.51385166089973, 17.625762394858274, 17.73696704625681, 17.847478813546747, 17.957310489045962, 18.066474476222528, 18.174982806044138, 18.282847152454128, 18.390078847030537, 18.49668889288026, 18.60268797781654, 18.708086486864442, 18.812894514135778, 18.91712187411182, 19.02077811236964, 19.12387251578508, 19.22641412224339, 19.328411729886135, 19.429873905921266, 19.53080899502118, 19.631225127332225, 19.731130226117312, 19.830532015051944, 19.929438025192788], [0.0, 2.0579115627256677, 2.9103264421710495, 3.5644073841243236, 4.115823125451335, 4.601630145937416, 5.040833264451424, 5.444722215136415, 5.820652884342099, 6.173734688177003, 6.507687761409578, 6.825320505294972, 7.128814768248647, 7.419905659777623, 7.7, 7.97025721040419, 8.23164625090267, 8.484986741297831, 8.730979326513149, 8.97022853666505, 9.203260291874832, 9.430535509715236, 9.652460826131335, 9.869397144709499, 10.081666528902849, 10.289557813628338, 10.493331215586403, 10.69322215237297, 10.88944443027283, 11.082192923785438, 11.271645842555557, 11.45796666079981, 11.641305768684198, 11.821801893112573, 11.999583326099286, 12.174768991648259, 12.347469376354006, 12.517787344415146, 12.685818854137876, 12.851653590102716, 13.015375522819156, 13.177063405782034, 13.336791218280355, 13.494628561023825, 13.650641010589943, 13.804890437812244, 13.957435294494474, 14.108330872218726, 14.257629536497294, 14.405380939079674, 14.55163221085525, 14.696428137476127, 14.839811319555245, 14.98182231906386, 15.122499793354272, 15.26188061806277, 15.4, 15.536891581008087, 15.672587533652509, 15.807118649519905, 15.94051442080838, 16.0728031158227, 16.20401184892186, 16.334166645409248, 16.46329250180534, 16.59141344189819, 16.71855256892773, 16.844732114224907, 16.969973482595663, 17.094297294712057, 17.217723426748382, 17.34027104747789, 17.461958653026297, 17.582804099460358, 17.70282463337419, 17.822036920621617, 17.9404570733301, 18.058100675320205, 18.174982806044138, 18.29111806314748, 18.406520583749664, 18.52120406453101, 18.63518178070716, 18.74846660396524, 18.861071019430472, 18.973007141726374, 19.08428673018722, 19.194921203276664, 19.30492165226267, 19.414298854195067, 19.523063284228733, 19.63122512733222, 19.738794289418998, 19.845780407935585, 19.95219286193876, 20.058040781691513, 20.163333057805698, 20.26807834995711, 20.37228509519735, 20.475961515884915, 20.579115627256677, 20.681755244659485], [0.0, 2.130140840414079, 3.012474066278413, 3.689512162874653, 4.260281680828158, 4.763139720814412, 5.2177581392778265, 5.635822921277778, 6.024948132556826, 6.390422521242237, 6.736096792653739, 7.064877918265821, 7.379024325749306, 7.680332024072917, 7.970257210404191, 8.249999999999998, 8.520563361656317, 8.78279568246922, 9.03742219883524, 9.285068658873774, 9.526279441628825, 9.761531642114367, 9.991246168521721, 10.215796591553689, 10.435516278555653, 10.650704202070395, 10.861629711972325, 11.068536488623959, 11.271645842555555, 11.471159488037816, 11.667261889578032, 11.860122259066301, 12.049896265113652, 12.236727503707844, 12.420748769699836, 12.602083161128558, 12.780845042484474, 12.95714088832872, 13.131070024944654, 13.302725284692606, 13.472193585307478, 13.63955644440097, 13.804890437812245, 13.968267609120321, 14.129755836531642, 14.289419162443235, 14.447318090220067, 14.603509852086928, 14.758048651498612, 14.910985882898554, 15.062370331392067, 15.212248354533264, 15.360664048145834, 15.507659397858854, 15.653274417833476, 15.797547277979579, 15.940514420808382, 16.08221066893479, 16.22266932412789, 16.361922258707867, 16.499999999999996, 16.636931808479588, 16.772745750174593, 16.907468763833336, 17.041126723312633, 17.173744495595592, 17.3053459948075, 17.435954232562093, 17.56559136493844, 17.69427873635995, 17.822036920621617, 17.94888575928879, 18.07484439767048, 18.199931318551723, 18.32416437385345, 18.447560814373265, 18.570137317747548, 18.69191001476307, 18.812894514135778, 18.933105925864357, 19.05255888325765, 19.171267563726712, 19.2892457084252, 19.406506640815085, 19.523063284228733, 19.638928178492836, 19.754113495674765, 19.868631055007285, 19.982492337043443, 20.095708497089618, 20.208290377961216, 20.32024852210228, 20.431593183107378, 20.542334336681407, 20.652481691070445, 20.762044696994558, 20.871032557111306, 20.979454235036716, 21.087318463948893, 21.194633754797465, 21.30140840414079, 21.407650501631423], [0.0, 2.2, 3.111269837220809, 3.8105117766515306, 4.4, 4.919349550499538, 5.388877434122993, 5.820652884342099, 6.222539674441618, 6.6, 6.957010852370435, 7.29657453878188, 7.621023553303061, 7.932212806020777, 8.23164625090267, 8.520563361656317, 8.8, 9.070832376358855, 9.333809511662428, 9.589577675789483, 9.838699100999076, 10.081666528902849, 10.318914671611546, 10.550829351287984, 10.777754868245985, 11.0, 11.217842929904128, 11.43153532995459, 11.641305768684198, 11.847362575695911, 12.049896265113654, 12.249081598226047, 12.445079348883237, 12.638037822383664, 12.828094168659662, 13.015375522819156, 13.2, 13.382077566656084, 13.56171080653175, 13.738995596476478, 13.91402170474087, 14.08687332235227, 14.257629536497294, 14.4263647534644, 14.59314907756376, 14.75804865149861, 14.92112596287559, 15.082440120882298, 15.242047106606122, 15.4, 15.556349186104047, 15.711142542794272, 15.864425612041554, 16.01624175641714, 16.166632302368974, 16.31563667161046, 16.46329250180534, 16.609635757595647, 16.7547008329006, 16.89852064531094, 17.041126723312633, 17.18254928699464, 17.322817322825983, 17.4619586530263, 17.6, 17.736967046256808, 17.872884490199112, 18.00777609811939, 18.14166475271771, 18.274572498419765, 18.406520583749664, 18.53752950098799, 18.667619023324857, 18.796808239698567, 18.925115587493778, 19.052558883257653, 19.179155351578967, 19.304921652262667, 19.429873905921266, 19.554027718094297, 19.67739820199815, 19.8, 19.921847303902318, 20.042953874117458, 20.163333057805698, 20.282997806044353, 20.401960690090547, 20.520233916795394, 20.637829343223093, 20.754758490524527, 20.871032557111302, 20.986662431172803, 21.101658702575968, 21.216031674184503, 21.32979137263185, 21.442947558579718, 21.55550973649197, 21.667487163951435, 21.778888860545667, 21.88972361634564, 22.0, 22.109726366465964], [0.0, 2.2677080940897136, 3.207023542164915, 3.927785635698568, 4.535416188179427, 5.070749451511088, 5.554727716099143, 5.999791663049643, 6.41404708432983, 6.803124282269139, 7.171122645722914, 7.521136882147539, 7.855571271397136, 8.176337811025178, 8.484986741297831, 8.78279568246922, 9.070832376358855, 9.35, 9.621070626494745, 9.884710415586287, 10.141498903022176, 10.391943995230152, 10.636493783197544, 10.875545963306854, 11.109455432198287, 11.338540470448567, 11.563087822895753, 11.783356907095703, 11.999583326099286, 12.211981821145987, 12.420748769699836, 12.626064311573895, 12.82809416865966, 13.026991210559713, 13.22289680818844, 13.415942009415515, 13.606248564538278, 13.793929824382898, 13.979091529852719, 14.161832508542107, 14.342245291445828, 14.520416660688497, 14.696428137476127, 14.870356418055351, 15.042273764295079, 15.212248354533262, 15.38034459952052, 15.546623427612827, 15.711142542794272, 15.873956658627993, 16.035117710824576, 16.194675050769003, 16.352675622050356, 16.509164121784, 16.66418314829743, 16.817773336562723, 16.969973482595663, 17.12082065790072, 17.270350314918343, 17.418596384324427, 17.56559136493844, 17.71136640691508, 17.855951388822717, 17.99937498914893, 18.14166475271771, 18.282847152454124, 18.422947646888648, 18.561990733754826, 18.7, 18.83699816849808, 18.973007141726377, 19.108048042644228, 19.24214125298949, 19.375306449189388, 19.507562636065018, 19.63892817849284, 19.769420831172575, 19.899057766638098, 20.02785560163644, 20.155830421989567, 20.282997806044353, 20.40937284680742, 20.534970172853917, 20.659803968092245, 20.783887990460304, 20.90723558962303, 21.029859723735676, 21.151772975332353, 21.272987566395088, 21.393515372654395, 21.51336793716874, 21.632556483226846, 21.751091926613707, 21.868984887278145, 21.986245700437355, 22.102884427151128, 22.218910864396573, 22.334334554671653, 22.44916479515441, 22.56341064644262, 22.677080940897135, 22.790184290610732], [0.0, 2.333452377915607, 3.3, 4.041658075592244, 4.666904755831214, 5.2177581392778265, 5.715767664977296, 6.173734688177003, 6.6, 7.00035713374682, 7.379024325749306, 7.739186003708659, 8.083316151184489, 8.413382197428096, 8.730979326513149, 9.03742219883524, 9.333809511662428, 9.621070626494745, 9.9, 10.171283104898812, 10.435516278555653, 10.69322215237297, 10.94486180817282, 11.190844472156693, 11.431535329954592, 11.667261889578034, 11.898319209031166, 12.124974226776732, 12.347469376354006, 12.56602562467545, 12.780845042484476, 12.992112992119488, 13.2, 13.404663367649336, 13.60624856453828, 13.804890437812245, 14.00071426749364, 14.193836690620335, 14.384366513684224, 14.572405429440948, 14.758048651498612, 14.94138547792674, 15.122499793354274, 15.30147051756791, 15.478372007417319, 15.653274417833476, 15.826244026931976, 15.997343529473888, 16.166632302368978, 16.334166645409248, 16.5, 16.66418314829743, 16.82676439485619, 16.987789732628553, 17.147302994931884, 17.305345994807503, 17.461958653026297, 17.617179115851663, 17.771043863543866, 17.923587810480356, 18.07484439767048, 18.224845678358978, 18.37362239733907, 18.521204064531013, 18.667619023324857, 18.812894514135774, 18.957056733575495, 19.10013088960387, 19.24214125298949, 19.383111205376707, 19.523063284228733, 19.662019224891424, 19.8, 19.937025856431042, 20.073116349984126, 20.20829037796122, 20.342566209797624, 20.475961515884915, 20.608493394714717, 20.740178398461286, 20.871032557111306, 21.001071401240463, 21.130309983528402, 21.258762899096457, 21.38644430474594, 21.51336793716874, 21.6395471301966, 21.764994831150318, 21.88972361634564, 22.013745705808446, 22.137072977247918, 22.259716979332868, 22.381688944313385, 22.50299980002666, 22.623660181323448, 22.743680440948864, 22.863070659909184, 22.9818406573538, 23.1, 23.21755801112598, 23.33452377915607, 23.45090616586063], [0.0, 2.397394418947371, 3.3904277016329374, 4.152408939398914, 4.794788837894742, 5.360736889644931, 5.872393038617223, 6.342909427068938, 6.780855403265875, 7.192183256842112, 7.581226813649623, 7.951257762140529, 8.304817878797827, 8.643928505025942, 8.97022853666505, 9.285068658873772, 9.589577675789483, 9.884710415586287, 10.171283104898812, 10.450000000000003, 10.721473779289862, 10.986241395491001, 11.244776565143482, 11.497499728201781, 11.744786077234446, 11.986972094736855, 12.224360923991082, 12.45722681819674, 12.685818854137876, 12.910364053736055, 13.131070024944655, 13.348127209462756, 13.56171080653175, 13.771982428103808, 13.97909152985272, 14.18317665405039, 14.384366513684224, 14.58278094191914, 14.778531726798846, 14.971723347697822, 15.162453627299247, 15.350814310648152, 15.53689158100809, 15.720766520752097, 15.902515524281059, 16.08221066893479, 16.259920049003934, 16.43570807723233, 16.609635757595655, 16.781760932631595, 16.952138508164687, 17.120820657900722, 17.287857010051884, 17.45329481788468, 17.617179115851666, 17.77955286276908, 17.9404570733301, 18.09993093909477, 18.25801193996762, 18.41473594706153, 18.570137317747545, 18.724248983604124, 18.877102531903567, 19.028728281206817, 19.179155351578967, 19.328411729886138, 19.47652433058835, 19.6235190524024, 19.769420831172575, 19.914253689254842, 20.05804078169152, 20.200804439427657, 20.342566209797624, 20.48334689448968, 20.623166585177945, 20.762044696994565, 20.900000000000006, 21.03705064879581, 21.17321421041218, 21.308507690591572, 21.442947558579725, 21.576549770526338, 21.70932979158961, 21.84130261683126, 21.972482790982003, 22.10288442715113, 22.232521224548513, 22.361406485281737, 22.489553130286964, 22.616973714447298, 22.743680440948868, 22.86968517492097, 22.994999456403562, 23.119634512682076, 23.243601270026986, 23.3669103648728, 23.489572154468892, 23.611596727032254, 23.732993911430565, 23.85377328642159, 23.97394418947371, 24.093515725190468], [0.0, 2.459674775249769, 3.478505426185217, 4.260281680828159, 4.919349550499538, 5.500000000000001, 6.024948132556829, 6.507687761409578, 6.957010852370434, 7.379024325749306, 7.778174593052023, 8.15781833580523, 8.520563361656318, 8.868483523128406, 9.203260291874832, 9.526279441628825, 9.838699100999076, 10.141498903022176, 10.435516278555653, 10.721473779289862, 11.000000000000002, 11.27164584255556, 11.536897329871667, 11.79618582423997, 12.049896265113658, 12.298373876248844, 12.54192967609052, 12.780845042484478, 13.015375522819156, 13.245754036671528, 13.47219358530748, 13.694889557787606, 13.914021704740868, 14.129755836531643, 14.34224529144583, 14.55163221085525, 14.758048651498612, 14.961617559608989, 15.162453627299245, 15.360664048145837, 15.556349186104047, 15.749603169603992, 15.940514420808384, 16.129166128476697, 16.31563667161046, 16.5, 16.682325976913415, 16.86268068843148, 17.041126723312637, 17.217723426748382, 17.392527130926087, 17.565591364938445, 17.73696704625681, 17.90670265570968, 18.074844397670482, 18.241436346954703, 18.406520583749664, 18.570137317747545, 18.732325002519044, 18.893120441049437, 19.05255888325765, 19.21067411623028, 19.36749854782491, 19.523063284228733, 19.67739820199815, 19.83053201505194, 19.982492337043446, 20.13330573949544, 20.282997806044353, 20.43159318310738, 20.57911562725668, 20.72558804955845, 20.871032557111306, 21.015470491997082, 21.15892246783848, 21.301408404140794, 21.442947558579725, 21.583558557383444, 21.723259423944654, 21.862067605786972, 22.000000000000004, 22.137072977247918, 22.27330240444825, 22.4087036662097, 22.54329168511112, 22.677080940897135, 22.810085488660494, 22.942318976075633, 23.073794659743335, 23.204525420701884, 23.33452377915607, 23.463801908471694, 23.59237164847994, 23.72024451813261, 23.84743172754668, 23.973944189473702, 24.099792530227315, 24.22498710009977, 24.349537983296525, 24.473455007415694, 24.596747752497688, 24.71942555966866], [0.0, 2.520416632225712, 3.564407384124323, 4.365489663256575, 5.040833264451424, 5.6358229212777795, 6.173734688177005, 6.668395609140178, 7.128814768248646, 7.561249896677136, 7.970257210404192, 8.359276284463865, 8.73097932651315, 9.087491403022069, 9.430535509715236, 9.761531642114365, 10.081666528902849, 10.391943995230152, 10.69322215237297, 10.986241395491001, 11.271645842555559, 11.550000000000002, 11.821801893112573, 12.08749353670975, 12.34746937635401, 12.602083161128562, 12.851653590102718, 13.096468989769724, 13.336791218280355, 13.572858947178375, 13.804890437812247, 14.033085904390381, 14.257629536497292, 14.478691239197003, 14.696428137476127, 14.910985882898554, 15.122499793354272, 15.33109585124299, 15.536891581008089, 15.739996823379606, 15.940514420808384, 16.138540826233335, 16.33416664540925, 16.527477121448392, 16.71855256892773, 16.907468763833336, 17.09429729471206, 17.27910587964551, 17.4619586530263, 17.642916425579987, 17.822036920621617, 17.999374989148933, 18.174982806044138, 18.348910049373508, 18.521204064531013, 18.691910014763074, 18.861071019430472, 19.028728281206813, 19.194921203276664, 19.359687497477847, 19.52306328422873, 19.685083184990606, 19.845780407935585, 20.005186827420534, 20.163333057805698, 20.320248522102283, 20.475961515884915, 20.630499266862156, 20.783887990460304, 20.93615294174171, 21.087318463948897, 21.237408033938607, 21.38644430474594, 21.53444914549708, 21.681443678869726, 21.827448316282876, 21.972482790982003, 22.11656618917141, 22.25971697933287, 22.401953039857933, 22.543291685111118, 22.68374969003141, 22.823343313371076, 22.962088319662914, 23.100000000000005, 23.23709319170537, 23.373382296963356, 23.508881300478762, 23.643603786225146, 23.777562953339014, 23.910771631212576, 24.04324229383383, 24.1749870734195, 24.306017773382788, 24.43634588067537, 24.565982577540023, 24.69493875270802, 24.82322501207287, 24.950851688870266, 25.0778288533916, 25.204166322257123, 25.329873667272803], [0.0, 2.5797286679028866, 3.6482872693909396, 4.468221122549779, 5.159457335805773, 5.768448664935834, 6.319018911191833, 6.825320505294971, 7.296574538781879, 7.739186003708658, 8.15781833580523, 8.555992052357226, 8.936442245099558, 9.30134398890827, 9.652460826131335, 9.991246168521721, 10.318914671611546, 10.636493783197544, 10.94486180817282, 11.244776565143482, 11.536897329871667, 11.821801893112575, 12.100000000000001, 12.371944067122191, 12.638037822383666, 12.898643339514432, 13.15408681741154, 13.404663367649336, 13.650641010589942, 13.8922640343466, 14.129755836531642, 14.363321342920655, 14.593149077563758, 14.819412943838229, 15.042273764295079, 15.261880618062769, 15.478372007417317, 15.691876879455817, 15.902515524281057, 16.110400367464493, 16.31563667161046, 16.51832315944933, 16.71855256892773, 16.916412149152666, 17.111984104714452, 17.3053459948075, 17.496571092645556, 17.68572870989488, 17.872884490199116, 18.058100675320205, 18.2414363469547, 18.42294764688865, 18.60268797781654, 18.780708186860263, 18.957056733575495, 19.1317798440187, 19.30492165226267, 19.47652433058835, 19.64662820944093, 19.815271888117003, 19.982492337043443, 20.14832499241562, 20.312803843881326, 20.475961515884915, 20.637829343223093, 20.79843744130794, 20.957814771583415, 21.115989202497712, 21.272987566395088, 21.428835712655975, 21.583558557383444, 21.737180129906456, 21.88972361634564, 22.041211400465265, 22.191665102015214, 22.341105612748894, 22.489553130286964, 22.637027189982344, 22.78354669492878, 22.929129944243417, 23.073794659743335, 23.217558011125977, 23.360436639754834, 23.50244668114365, 23.64360378622515, 23.78392314148362, 23.9234194880247, 24.062107139650095, 24.200000000000003, 24.337111578821343, 24.473455007415687, 24.609043053316803, 24.743888134244383, 24.87800233137701, 25.011397401984564, 25.144084791457413, 25.27607564476733, 25.40738081739242, 25.538010885736583, 25.66797615707168, 25.797286679028865, 25.92595224866389], [0.0, 2.637707337821996, 3.7302814907188977, 4.568643124604942, 5.275414675643992, 5.898092912119986, 6.461037068458904, 6.978717647247236, 7.460562981437795, 7.913122013465987, 8.341162988456706, 8.748285546322778, 9.137286249209884, 9.510389056184822, 9.869397144709499, 10.21579659155369, 10.550829351287984, 10.875545963306855, 11.190844472156693, 11.497499728201783, 11.796185824239972, 12.087493536709752, 12.371944067122193, 12.65, 12.922074136917807, 13.18853668910998, 13.449721186701234, 13.705929373814826, 13.957435294494472, 14.204488727159458, 14.447318090220067, 14.686132915100558, 14.92112596287559, 15.152475045351505, 15.380344599520521, 15.60488705502222, 15.826244026931974, 16.044547360396304, 16.259920049003934, 16.472477045059133, 16.68232597691341, 16.8895677860625, 17.09429729471206, 17.296603712868027, 17.496571092645556, 17.69427873635995, 17.889801564019656, 18.08321044505096, 18.27457249841977, 18.46395136475397, 18.65140745359449, 18.836998168498084, 19.020778112369644, 19.202799275105704, 19.383111205376707, 19.561761168156618, 19.738794289418998, 19.914253689254842, 20.088180604524645, 20.26061450203325, 20.43159318310738, 20.601152880360846, 20.769328347349127, 20.93615294174171, 21.101658702575968, 21.265876422099325, 21.428835712655975, 21.590565069029573, 21.75109192661371, 21.9104427157463, 22.06864291251277, 22.225717086294427, 22.381688944313385, 22.536581373402665, 22.690416479209897, 22.843215623024708, 22.994999456403566, 23.145787953750897, 23.29560044300211, 23.444455634541832, 23.592371648479944, 23.739366040397964, 23.885455825669315, 24.030657502448825, 24.174987073419505, 24.318460066377558, 24.461091553730796, 24.602896170979548, 24.743888134244386, 24.88408125689996, 25.02348896537012, 25.162124314135323, 25.3, 25.437128375663793, 25.573521462637878, 25.709190963544536, 25.844148273835614, 25.978404492963, 26.111970435032287, 26.244856638968336, 26.37707337821996, 26.508630670028964], [0.0, 2.6944387170614963, 3.8105117766515297, 4.666904755831214, 5.388877434122993, 6.024948132556828, 6.600000000000001, 7.128814768248646, 7.6210235533030595, 8.083316151184487, 8.520563361656318, 8.936442245099556, 9.333809511662428, 9.714936952960633, 10.081666528902849, 10.435516278555651, 10.777754868245985, 11.109455432198287, 11.43153532995459, 11.744786077234444, 12.049896265113656, 12.347469376354008, 12.638037822383664, 12.922074136917804, 13.200000000000003, 13.472193585307481, 13.738995596476478, 14.000714267493642, 14.257629536497292, 14.509996554100214, 14.758048651498612, 15.001999866684441, 15.242047106606119, 15.478372007417319, 15.71114254279427, 15.940514420808382, 16.166632302368974, 16.389630868326474, 16.60963575759565, 16.82676439485619, 17.041126723312637, 17.25282585549394, 17.4619586530263, 17.66861624462991, 17.872884490199112, 18.07484439767048, 18.274572498419765, 18.472141186121334, 18.667619023324857, 18.861071019430472, 19.052558883257653, 19.242141252989494, 19.429873905921266, 19.615809950139713, 19.8, 19.982492337043446, 20.163333057805698, 20.34256620979762, 20.520233916795394, 20.69637649444946, 20.871032557111302, 21.04423911667989, 21.2160316741845, 21.38644430474594, 21.55550973649197, 21.723259423944647, 21.889723616345638, 22.054931421339763, 22.218910864396573, 22.381688944313385, 22.543291685111118, 22.703744184605323, 22.86307065990918, 23.021294490101983, 23.178438256276024, 23.334523779156072, 23.48957215446889, 23.643603786225146, 23.796638418062333, 23.94869516278497, 24.09979253022731, 24.249948453553465, 24.39918031410072, 24.54750496486354, 24.694938752708016, 24.841497539399672, 24.987196721521205, 25.132051249350898, 25.276075644767328, 25.41928401824095, 25.56169008496895, 25.703307180205428, 25.844148273835607, 25.98422598423898, 26.12355259148342, 26.262140049889307, 26.400000000000006, 26.537143779992608, 26.673582436560714, 26.809326735298676, 26.944387170614963, 27.07877397520058], [0.0, 2.7500000000000004, 3.8890872965260113, 4.763139720814413, 5.500000000000001, 6.149186938124423, 6.736096792653741, 7.275816105427624, 7.7781745930520225, 8.25, 8.696263565463044, 9.12071817347735, 9.526279441628827, 9.915266007525972, 10.28955781362834, 10.650704202070395, 11.000000000000002, 11.338540470448567, 11.667261889578034, 11.986972094736855, 12.298373876248846, 12.602083161128562, 12.898643339514432, 13.188536689109979, 13.472193585307481, 13.750000000000002, 14.02230366238016, 14.289419162443238, 14.551632210855248, 14.809203219619889, 15.062370331392069, 15.31135199778256, 15.556349186104045, 15.79754727797958, 16.03511771082458, 16.269219403523945, 16.5, 16.727596958320106, 16.952138508164687, 17.173744495595596, 17.392527130926087, 17.608591652940337, 17.822036920621617, 18.0329559418305, 18.2414363469547, 18.447560814373265, 18.65140745359449, 18.853050151102874, 19.052558883257653, 19.25, 19.445436482630058, 19.63892817849284, 19.830532015051944, 20.020302195521428, 20.20829037796122, 20.394545839513075, 20.57911562725668, 20.76204469699456, 20.943376041125752, 21.123150806638673, 21.30140840414079, 21.4781866087433, 21.65352165353248, 21.827448316282876, 22.000000000000004, 22.17120880782101, 22.34110561274889, 22.509720122649238, 22.677080940897135, 22.843215623024708, 23.00815072968708, 23.171911876234986, 23.33452377915607, 23.49601029962321, 23.656394484367222, 23.815698604072065, 23.97394418947371, 24.131152065328337, 24.287342382401583, 24.442534647617872, 24.59674775249769, 24.75, 24.9023091298779, 25.053692342646823, 25.204166322257123, 25.35374725755544, 25.502450862613184, 25.650292395994242, 25.797286679028865, 25.943448113155657, 26.088790696389133, 26.233328038966004, 26.377073378219958, 26.520039592730626, 26.662239215789814, 26.80368444822465, 26.944387170614963, 27.084358954939294, 27.223611075682083, 27.362154520432053, 27.500000000000004, 27.637157958082454], [0.0, 2.804460732476032, 3.966106403010388, 4.857468476480316, 5.608921464952064, 6.27096483804526, 6.86949779823824, 7.419905659777623, 7.932212806020776, 8.413382197428096, 8.868483523128406, 9.30134398890827, 9.714936952960633, 10.111626970967631, 10.493331215586403, 10.861629711972324, 11.217842929904128, 11.563087822895753, 11.898319209031165, 12.22436092399108, 12.54192967609052, 12.851653590102718, 13.154086817411539, 13.449721186701233, 13.73899559647648, 14.02230366238016, 14.300000000000002, 14.572405429440948, 14.839811319555245, 15.102483239520582, 15.360664048145836, 15.614576523236229, 15.864425612041552, 16.110400367464493, 16.35267562205036, 16.591413441898194, 16.82676439485619, 17.058868661197906, 17.287857010051884, 17.513851660899725, 17.73696704625681, 17.957310489045962, 18.174982806044138, 18.390078847030537, 18.60268797781654, 18.812894514135774, 19.020778112369644, 19.22641412224339, 19.429873905921266, 19.631225127332222, 19.830532015051944, 20.02785560163644, 20.223253941935262, 20.416782312597647, 20.608493394714717, 20.798437441307943, 20.986662431172807, 21.173214210412173, 21.358136622842363, 21.541471630322754, 21.723259423944647, 21.903538526913866, 22.082345889873203, 22.25971697933287, 22.435685859808256, 22.61028527020391, 22.783546694928777, 22.955500430180127, 23.126175645791506, 23.295600443002108, 23.463801908471698, 23.63080616483492, 23.79663841806233, 23.96132300187116, 24.12488341940744, 24.287342382401583, 24.44872184798216, 24.609043053316803, 24.76832654823495, 24.926592225974257, 25.08385935218104, 25.240146592284287, 25.395472037353436, 25.549853228541256, 25.703307180205435, 25.85585040179495, 26.007498918581156, 26.158268291307056, 26.308173634823078, 26.457229635772524, 26.605450569385216, 26.75285031543368, 26.899442373402465, 27.045239876917343, 27.19025560747821, 27.334502007536187, 27.47799119295296, 27.62073496487739, 27.762744821072722, 27.904031966724816, 28.04460732476032, 28.18448154570171], [0.0, 2.857883832488648, 4.0416580755922435, 4.950000000000001, 5.715767664977296, 6.390422521242239, 7.000357133746822, 7.561249896677136, 8.083316151184487, 8.573651497465942, 9.037422198835241, 9.478528366787748, 9.900000000000002, 10.304246697357359, 10.69322215237297, 11.068536488623959, 11.431535329954592, 11.783356907095703, 12.124974226776732, 12.45722681819674, 12.780845042484478, 13.096468989769726, 13.404663367649336, 13.705929373814824, 14.000714267493644, 14.28941916244324, 14.57240542944095, 14.850000000000001, 15.122499793354272, 15.390175437596548, 15.653274417833478, 15.912023755638375, 16.166632302368974, 16.417292712259233, 16.66418314829743, 16.907468763833336, 17.147302994931884, 17.38382869220702, 17.617179115851666, 17.84747881354675, 18.074844397670482, 18.299385235575542, 18.521204064531013, 18.7403975411409, 18.957056733575495, 19.171267563726712, 19.383111205376707, 19.592664443612566, 19.800000000000004, 20.005186827420534, 20.208290377961223, 20.409372846807422, 20.608493394714717, 20.805708351315516, 21.001071401240463, 21.194633754797465, 21.38644430474594, 21.576549770526334, 21.764994831150318, 21.95182224782262, 22.137072977247918, 22.320786276473328, 22.50299980002666, 22.683749690031412, 22.863070659909184, 23.040996072218753, 23.217558011125977, 23.392787349950414, 23.566713814191406, 23.739366040397964, 23.910771631212576, 24.080957206888602, 24.249948453553465, 24.417770168465424, 24.58444630248971, 24.750000000000004, 24.91445363639348, 25.077828853391598, 25.24014659228429, 25.40142712526208, 25.561690084968955, 25.72095449239783, 25.879238783240904, 26.036560832798177, 26.19293797953945, 26.348387047407666, 26.502924366944868, 26.656565795315796, 26.809326735298672, 26.961222153307514, 27.112266596505723, 27.262474209066205, 27.411858747629648, 27.56043359600861, 27.708211779182, 27.855205976621317, 28.001428534987287, 28.146891480232775, 28.29160652914571, 28.435585100363248, 28.57883832488648, 28.721377056123202], [0.0, 2.91032644217105, 4.115823125451335, 5.040833264451424, 5.8206528843421, 6.507687761409579, 7.128814768248647, 7.699999999999999, 8.23164625090267, 8.730979326513149, 9.20326029187483, 9.652460826131335, 10.081666528902849, 10.493331215586403, 10.889444430272832, 11.271645842555557, 11.6413057686842, 11.999583326099286, 12.347469376354006, 12.685818854137878, 13.015375522819157, 13.336791218280357, 13.650641010589943, 13.957435294494472, 14.257629536497294, 14.55163221085525, 14.839811319555247, 15.122499793354272, 15.399999999999999, 15.67258753365251, 15.940514420808382, 16.20401184892186, 16.46329250180534, 16.71855256892773, 16.969973482595666, 17.217723426748382, 17.461958653026297, 17.70282463337419, 17.9404570733301, 18.174982806044138, 18.40652058374966, 18.63518178070716, 18.861071019430472, 19.08428673018722, 19.30492165226267, 19.52306328422873, 19.738794289418998, 19.952192861938762, 20.163333057805698, 20.37228509519735, 20.57911562725668, 20.783887990460304, 20.986662431172807, 21.187496312684047, 21.38644430474594, 21.583558557383444, 21.778888860545663, 21.972482790981996, 22.164385847570873, 22.354641576191735, 22.543291685111114, 22.730376151749006, 22.915933321599624, 23.1, 23.2826115373684, 23.463801908471694, 23.643603786225146, 23.822048610478486, 23.99916665219857, 24.1749870734195, 24.349537983296525, 24.52284649056875, 24.694938752708012, 24.865840022006093, 25.03557468883029, 25.204166322257123, 25.371637708275756, 25.53801088573658, 25.703307180205435, 25.867547235870667, 26.030751045638315, 26.192937979539447, 26.35412681156407, 26.51433574502669, 26.673582436560714, 26.83188401883103, 26.989257122047654, 27.145717894356746, 27.301282021179887, 27.455964743567105, 27.609780875624494, 27.762744821072715, 27.914870588988943, 28.066171808780762, 28.216661744437456, 28.366353308100777, 28.51525907299459, 28.663391285749846, 28.81076187815935, 28.957382478394006, 29.1032644217105, 29.248418760678334], [0.0, 2.9618406439239777, 4.18867520822515, 5.1300584791988495, 5.9236812878479554, 6.622877018335763, 7.254998277050107, 7.836293766826254, 8.3773504164503, 8.885521931771931, 9.366162501259522, 9.823314104720465, 10.260116958397699, 10.679068311421181, 11.082192923785437, 11.471159488037815, 11.847362575695911, 12.211981821145987, 12.566025624675449, 12.910364053736055, 13.245754036671526, 13.572858947178375, 13.8922640343466, 14.204488727159454, 14.509996554100214, 14.809203219619887, 15.102483239520582, 15.390175437596547, 15.672587533652507, 15.950000000000003, 16.22266932412789, 16.490830785621444, 16.7547008329006, 17.014479128083824, 17.270350314918343, 17.522485554281392, 17.771043863543863, 18.01617328957512, 18.258011939967616, 18.496688892880265, 18.732325002519044, 18.96503361452334, 19.194921203276664, 19.422087941310533, 19.64662820944093, 19.868631055007285, 20.088180604524645, 20.305356436172207, 20.520233916795398, 20.73288450746784, 20.94337604112575, 21.151772975332356, 21.358136622842363, 21.56252536230393, 21.764994831150318, 21.965598102487448, 22.164385847570873, 22.361406485281734, 22.556706319850868, 22.75032966794108, 22.94231897607563, 23.132714929294398, 23.32155655182561, 23.508881300478766, 23.694725151391822, 23.87912268070165, 24.062107139650095, 24.24371052458761, 24.423963642291973, 24.602896170979548, 24.780536717351385, 24.956912869984542, 25.132051249350898, 25.30597755472015, 25.478716608181035, 25.650292395994246, 25.82072810747211, 25.990046171563453, 26.158268291307056, 26.325415476303508, 26.491508073343052, 26.656565795315796, 26.820607748520544, 26.983652458479376, 27.14571789435675, 27.3068214920741, 27.4669801762043, 27.626210380723595, 27.7845280686932, 27.941948750937183, 28.098487503778564, 28.254158985890907, 28.408977454318908, 28.56295677971733, 28.71611046085455, 28.86845163842356, 29.019993108200428, 29.170747333587467, 29.32072645757605, 29.469942314161397, 29.618406439239774, 29.766130081016584], [0.0, 3.0124740662784135, 4.260281680828158, 5.2177581392778265, 6.024948132556827, 6.73609679265374, 7.379024325749307, 7.97025721040419, 8.520563361656317, 9.03742219883524, 9.526279441628825, 9.991246168521723, 10.435516278555653, 10.861629711972324, 11.271645842555557, 11.667261889578032, 12.049896265113654, 12.420748769699836, 12.780845042484476, 13.131070024944655, 13.47219358530748, 13.804890437812247, 14.129755836531642, 14.447318090220065, 14.758048651498614, 15.062370331392067, 15.360664048145836, 15.653274417833478, 15.94051442080838, 16.22266932412789, 16.5, 16.772745750174593, 17.041126723312633, 17.3053459948075, 17.56559136493844, 17.822036920621613, 18.07484439767048, 18.32416437385345, 18.570137317747545, 18.812894514135778, 19.05255888325765, 19.289245708425202, 19.523063284228733, 19.754113495674765, 19.982492337043446, 20.208290377961216, 20.43159318310738, 20.652481691070445, 20.871032557111306, 21.087318463948893, 21.301408404140794, 21.51336793716874, 21.723259423944647, 21.931142241114575, 22.137072977247918, 22.34110561274889, 22.543291685111114, 22.743680440948864, 22.942318976075633, 23.139252364758892, 23.334523779156065, 23.52817459982818, 23.720244518132603, 23.910771631212572, 24.099792530227308, 24.287342382401576, 24.473455007415687, 24.65816294860588, 24.841497539399672, 25.023488965370117, 25.20416632225712, 25.383557670271514, 25.56169008496895, 25.738589704954695, 25.91428177665744, 26.08879069638913, 26.26214004988931, 26.434352649535413, 26.605450569385216, 26.77545517820379, 26.94438717061496, 27.11226659650572, 27.27911288880194, 27.444944889724226, 27.609780875624494, 27.77363858049571, 27.936535218240643, 28.09848750377856, 28.259511673063283, 28.419623502080384, 28.578838324886473, 28.737171050748884, 28.89463618044013, 29.051247821737363, 29.20701970417386, 29.3619651930861, 29.516097302997228, 29.669428710374593, 29.82197176579711, 29.97373850556517, 30.124740662784134, 30.274989677950348], [0.0, 3.062270399556512, 4.330704330706496, 5.304007918546126, 6.124540799113024, 6.847444778893803, 7.5009999333422215, 8.10200592446093, 8.661408661412992, 9.186811198669536, 9.683749273912454, 10.156401921940663, 10.608015837092251, 11.041172944936603, 11.457966660799812, 11.860122259066301, 12.249081598226049, 12.626064311573897, 12.992112992119488, 13.34812720946276, 13.694889557787606, 14.033085904390383, 14.363321342920656, 14.686132915100558, 15.001999866684443, 15.31135199778256, 15.61457652323623, 15.912023755638376, 16.20401184892186, 16.490830785621448, 16.772745750174597, 17.049999999999997, 17.322817322825983, 17.591404150891425, 17.85595138882272, 18.116636001200664, 18.373622397339073, 18.62706364406371, 18.877102531903567, 19.12387251578508, 19.36749854782491, 19.60809781697348, 19.84578040793559, 20.08064988988155, 20.312803843881326, 20.542334336681407, 20.769328347349127, 20.993868152391546, 21.216031674184503, 21.435892796895583, 21.653521653532483, 21.86898488727815, 22.082345889873206, 22.29366501946237, 22.50299980002666, 22.710405104268837, 22.915933321599624, 23.119634512682072, 23.321556551825612, 23.521745258377408, 23.720244518132603, 23.917096395674786, 24.11234123846127, 24.30601777338279, 24.498163196452097, 24.688813256209784, 24.87800233137701, 25.06576350323285, 25.252128623147794, 25.437128375663793, 25.620792337474658, 25.80314903262778, 25.984225984238975, 26.16404976298585, 26.342646032621705, 26.52003959273063, 26.69625441892552, 26.871313700673436, 27.045239876917346, 27.21805466964897, 27.389779115575212, 27.560433596008608, 27.730037865102172, 27.898611076539275, 28.066171808780766, 28.232738088963316, 28.398327415536286, 28.56295677971733, 28.726642685841313, 28.88940117067157, 29.051247821737366, 29.2121977947569, 29.372265830201115, 29.531466269049357, 29.689813067784716, 29.847319812673295, 30.003999733368886, 30.159865715881434, 30.314930314945475, 30.469205765821993, 30.62270399556512, 30.775436633783123], [0.0, 3.111269837220809, 4.3999999999999995, 5.388877434122993, 6.222539674441618, 6.957010852370435, 7.621023553303061, 8.23164625090267, 8.799999999999999, 9.333809511662427, 9.838699100999074, 10.318914671611545, 10.777754868245985, 11.217842929904126, 11.641305768684198, 12.049896265113652, 12.445079348883237, 12.82809416865966, 13.2, 13.56171080653175, 13.91402170474087, 14.257629536497294, 14.59314907756376, 14.921125962875589, 15.242047106606122, 15.556349186104045, 15.864425612041554, 16.166632302368974, 16.46329250180534, 16.7547008329006, 17.041126723312633, 17.322817322825983, 17.599999999999998, 17.872884490199112, 18.141664752717706, 18.40652058374966, 18.667619023324853, 18.925115587493778, 19.179155351578963, 19.429873905921266, 19.677398201998148, 19.921847303902318, 20.163333057805698, 20.401960690090547, 20.63782934322309, 20.8710325571113, 21.101658702575968, 21.32979137263185, 21.55550973649197, 21.778888860545663, 22.0, 22.218910864396573, 22.435685859808252, 22.650386310171402, 22.86307065990918, 23.073794659743335, 23.282611537368396, 23.489572154468885, 23.69472515139182, 23.898117080640475, 24.099792530227305, 24.299794237811973, 24.498163196452094, 24.694938752708012, 24.890158697766473, 25.083859352181033, 25.276075644767324, 25.466841186138495, 25.65618833731932, 25.844148273835607, 26.03075104563831, 26.216025633188565, 26.4, 26.582701141908057, 26.764155133312165, 26.94438717061496, 27.1234216130635, 27.301282021179883, 27.477991192952956, 27.653571197948377, 27.82804340948174, 28.00142853498728, 28.173746644704536, 28.345017198795276, 28.51525907299459, 28.68449058289165, 28.8527295069288, 29.01999310820042, 29.18629815512752, 29.35166094107793, 29.516097302997224, 29.679622639110487, 29.842251925751178, 30.003999733368882, 30.164880241764596, 30.324907254598482, 30.484094213212245, 30.642454209805067, 30.8, 30.956744014834637, 31.11269837220809, 31.267874887814173], [0.0, 3.1595094555959164, 4.468221122549778, 5.472430904086411, 6.319018911191833, 7.064877918265823, 7.73918600370866, 8.359276284463865, 8.936442245099556, 9.478528366787748, 9.991246168521723, 10.47890738579171, 10.944861808172822, 11.39177334746439, 11.821801893112573, 12.236727503707844, 12.638037822383666, 13.026991210559714, 13.404663367649336, 13.77198242810381, 14.129755836531645, 14.478691239197005, 14.819412943838229, 15.152475045351503, 15.47837200741732, 15.79754727797958, 16.110400367464493, 16.417292712259233, 16.71855256892773, 17.014479128083824, 17.305345994807503, 17.591404150891425, 17.872884490199112, 18.150000000000002, 18.42294764688865, 18.69191001476307, 18.957056733575495, 19.218545730621766, 19.476524330588354, 19.731130226117312, 19.982492337043446, 20.230731573524476, 20.475961515884915, 20.7182890220211, 20.95781477158342, 21.19463375479746, 21.428835712655975, 21.660505534266743, 21.889723616345645, 22.11656618917141, 22.341105612748894, 22.56341064644262, 22.78354669492878, 23.001576032959136, 23.217558011125977, 23.431549244554876, 23.643603786225146, 23.853773286421585, 24.0621071396501, 24.268652620201234, 24.473455007415687, 24.67655770159201, 24.87800233137701, 25.077828853391598, 25.27607564476733, 25.472779589200705, 25.667976157071678, 25.861699480119245, 26.05398242111943, 26.244856638968333, 26.43435264953542, 26.622499882618087, 26.809326735298672, 26.994860621977658, 27.179128021332843, 27.362154520432053, 27.54396485620762, 27.724582954482834, 27.904031966724816, 28.08233430468344, 28.25951167306329, 28.435585100363244, 28.6105749680079, 28.784501037884958, 28.95738247839401, 29.129237889103795, 29.300085324107847, 29.469942314161393, 29.638825887676457, 29.8067525906463, 29.97373850556517, 30.139799269404566, 30.304950090703006, 30.469205765821993, 30.63258069441751, 30.795088894172718, 30.95674401483464, 31.117559351594405, 31.277547857848454, 31.43672215737513, 31.59509455595916, 31.752677052494338], [0.0, 3.2070235421649156, 4.535416188179426, 5.554727716099143, 6.414047084329831, 7.171122645722915, 7.855571271397136, 8.484986741297831, 9.070832376358853, 9.621070626494745, 10.141498903022176, 10.636493783197544, 11.109455432198287, 11.563087822895751, 11.999583326099286, 12.420748769699836, 12.828094168659662, 13.22289680818844, 13.60624856453828, 13.97909152985272, 14.34224529144583, 14.696428137476127, 15.042273764295079, 15.38034459952052, 15.711142542794272, 16.035117710824576, 16.35267562205036, 16.66418314829743, 16.969973482595663, 17.270350314918343, 17.56559136493844, 17.855951388822717, 18.141664752717706, 18.42294764688865, 18.700000000000003, 18.973007141726374, 19.24214125298949, 19.50756263606502, 19.76942083117257, 20.02785560163644, 20.282997806044353, 20.53497017285392, 20.783887990460304, 21.029859723735676, 21.272987566395088, 21.513367937168738, 21.75109192661371, 21.986245700437355, 22.218910864396573, 22.449164795154406, 22.677080940897135, 22.902729095022718, 23.126175645791502, 23.34748380447024, 23.566713814191406, 23.783923141483623, 23.99916665219857, 24.21249677336065, 24.423963642291973, 24.63361524421456, 24.841497539399672, 25.047654580818538, 25.25212862314779, 25.454960223893497, 25.656188337319325, 25.855850401794946, 26.053982421119425, 26.25061904031979, 26.44579361637688, 26.639538284287138, 26.831884018831033, 27.022860692384143, 27.21249712907656, 27.40082115557853, 27.587859648765797, 27.773638580495717, 27.95818305970544, 28.14151737202527, 28.323665017084217, 28.50464874366987, 28.68449058289166, 28.863211879484236, 29.04083332137699, 29.217374967645537, 29.392856274952255, 29.567296122574348, 29.740712836110703, 29.913124209951725, 30.084547528590157, 30.254999586845145, 30.424496709066528, 30.593054767381435, 30.76068919904104, 30.927415022921007, 31.093246855225654, 31.258198924442205, 31.422285085588545, 31.585518833794712, 31.74791331725599, 31.909481349592635, 32.07023542164915, 32.23018771276395], [0.0, 3.253843880704789, 4.601630145937415, 5.6358229212777795, 6.507687761409578, 7.275816105427625, 7.970257210404192, 8.60886171337419, 9.20326029187483, 9.761531642114365, 10.289557813628338, 10.79177927869172, 11.271645842555559, 11.731900954235849, 12.17476899164826, 12.602083161128558, 13.015375522819156, 13.415942009415515, 13.804890437812247, 14.183176654050392, 14.55163221085525, 14.910985882898556, 15.261880618062769, 15.604887055022218, 15.940514420808384, 16.269219403523945, 16.591413441898194, 16.907468763833336, 17.21772342674838, 17.522485554281392, 17.822036920621613, 18.116636001200664, 18.40652058374966, 18.69191001476307, 18.973007141726374, 19.25, 19.52306328422873, 19.79235963699124, 20.058040781691517, 20.320248522102283, 20.579115627256677, 20.834766617363393, 21.087318463948897, 21.336881215397902, 21.58355855738344, 21.82744831628287, 22.068642912512768, 22.307229769740573, 22.543291685111118, 22.776907164933522, 23.008150729687078, 23.23709319170537, 23.463801908471698, 23.688341014093833, 23.910771631212572, 24.131152065328337, 24.34953798329652, 24.565982577540023, 24.780536717351385, 24.99324908850388, 25.204166322257116, 25.413333114725425, 25.620792337474654, 25.82658514012257, 26.03075104563831, 26.233328038966004, 26.434352649535413, 26.633860028167152, 26.83188401883103, 27.02845722567235, 27.223611075682083, 27.417375877351937, 27.609780875624494, 27.800854303420245, 27.990623429998838, 28.179114606388897, 28.366353308100784, 28.552364175318303, 28.73717105074889, 28.9207970152968, 29.1032644217105, 29.2845949263431, 29.464809519153523, 29.643928552066104, 29.821971765797112, 29.998958315248213, 30.174906793559444, 30.34983525490707, 30.523761236125537, 30.696701777226814, 30.868673440885015, 31.039692330949414, 31.209774110044435, 31.378934016311007, 31.54718687933997, 31.714547135344684, 31.881028841616768, 32.04664569030588, 32.21141102156191, 32.37533783607517, 32.53843880704789, 32.70072629162845], [0.0, 3.3000000000000003, 4.666904755831213, 5.715767664977296, 6.6000000000000005, 7.379024325749306, 8.083316151184489, 8.730979326513149, 9.333809511662427, 9.899999999999999, 10.435516278555651, 10.944861808172819, 11.431535329954592, 11.898319209031165, 12.347469376354006, 12.780845042484474, 13.200000000000001, 13.60624856453828, 14.00071426749364, 14.384366513684224, 14.758048651498612, 15.122499793354272, 15.478372007417319, 15.826244026931974, 16.166632302368978, 16.5, 16.82676439485619, 17.147302994931884, 17.461958653026297, 17.771043863543866, 18.074844397670482, 18.37362239733907, 18.667619023324853, 18.957056733575495, 19.24214125298949, 19.52306328422873, 19.799999999999997, 20.073116349984126, 20.34256620979762, 20.608493394714714, 20.871032557111302, 21.130309983528402, 21.38644430474594, 21.6395471301966, 21.889723616345638, 22.137072977247914, 22.381688944313385, 22.623660181323448, 22.863070659909184, 23.1, 23.33452377915607, 23.566713814191406, 23.79663841806233, 24.024362634625714, 24.24994845355346, 24.47345500741569, 24.694938752708012, 24.91445363639347, 25.132051249350898, 25.347780967966408, 25.561690084968948, 25.773823930491957, 25.98422598423897, 26.192937979539447, 26.400000000000002, 26.605450569385212, 26.80932673529867, 27.011664147179083, 27.21249712907656, 27.411858747629648, 27.609780875624494, 27.806294251481983, 28.00142853498728, 28.19521235954785, 28.387673381240667, 28.578838324886476, 28.768733027368448, 28.957382478394003, 29.144810858881897, 29.331041577141445, 29.516097302997224, 29.7, 29.882770955853477, 30.064430811176187, 30.244999586708545, 30.424496709066528, 30.60294103513582, 30.78035087519309, 30.956744014834637, 31.132137735786788, 31.306548835666955, 31.4799936467592, 31.652488053863948, 31.82404751127675, 31.994687058947772, 32.16442133786958, 32.333264604737955, 32.50123074592715, 32.668333290818495, 32.834585424518465, 33.0, 33.16458954969894], [0.0, 3.345519391664021, 4.7312788968734445, 5.794609564069007, 6.691038783328042, 7.480808779804494, 8.194815434163239, 8.851412316687094, 9.462557793746889, 10.036558174992063, 10.57946123391924, 11.095832551007609, 11.589219128138014, 12.062441709703721, 12.517787344415147, 12.95714088832872, 13.382077566656084, 13.793929824382898, 14.193836690620335, 14.58278094191914, 14.961617559608989, 15.331095851242992, 15.691876879455817, 16.044547360396304, 16.389630868326478, 16.727596958320106, 17.05886866119791, 17.38382869220702, 17.70282463337419, 18.016173289575125, 18.32416437385345, 18.62706364406371, 18.925115587493778, 19.218545730621766, 19.50756263606502, 19.79235963699124, 20.073116349984126, 20.35, 20.623166585177945, 20.89276190454484, 21.15892246783848, 21.421776303565494, 21.68144367886973, 21.93803774269704, 22.191665102015218, 22.44242633941348, 22.690416479209897, 22.93572540819235, 23.178438256276028, 23.418635741648146, 23.656394484367226, 23.891787291870823, 24.124883419407443, 24.355748808032985, 24.584446302489713, 24.81103585100792, 25.035574688830295, 25.258117507051075, 25.478716608181035, 25.69742204969207, 25.91428177665744, 26.129341744483344, 26.3426460326217, 26.554236950061288, 26.76415513331217, 26.9724396375263, 27.17912802133284, 27.384256425910127, 27.587859648765797, 27.78997121265152, 27.99062342999884, 28.189847463226897, 28.38767338124067, 28.58413021240982, 28.779245994292484, 28.973047820345034, 29.16556188383828, 29.35681351918154, 29.54682724083925, 29.7356267800092, 29.923235119217978, 30.10967452497619, 30.29496657862491, 30.479132205494306, 30.662191702485984, 30.844164764181897, 31.025070507575, 31.204927495509427, 31.383753758911634, 31.561566817887858, 31.73838370175772, 31.914220968088816, 32.08909472079261, 32.263020627337426, 32.43601393513081, 32.6080894871196, 32.779261736652956, 32.94954476165036, 33.118952278114115, 33.28749765302283, 33.45519391664021, 33.62205377427144], [0.0, 3.3904277016329374, 4.794788837894741, 5.872393038617222, 6.780855403265875, 7.581226813649623, 8.304817878797826, 8.970228536665049, 9.589577675789482, 10.17128310489881, 10.72147377928986, 11.24477656514348, 11.744786077234444, 12.22436092399108, 12.685818854137876, 13.131070024944654, 13.56171080653175, 13.979091529852719, 14.384366513684224, 14.778531726798846, 15.162453627299247, 15.53689158100809, 15.902515524281059, 16.25992004900393, 16.60963575759565, 16.952138508164687, 17.287857010051887, 17.617179115851666, 17.940457073330098, 18.25801193996762, 18.570137317747545, 18.877102531903564, 19.179155351578963, 19.476524330588354, 19.769420831172575, 20.058040781691517, 20.34256620979762, 20.623166585177945, 20.900000000000002, 21.173214210412176, 21.44294755857972, 21.70932979158961, 21.972482790982, 22.23252122454851, 22.48955313028696, 22.743680440948864, 22.994999456403562, 23.243601270026986, 23.48957215446889, 23.73299391143056, 23.973944189473706, 24.212496773360655, 24.44872184798216, 24.682686239548566, 24.914453636393475, 25.144084791457416, 25.371637708275752, 25.597167812084212, 25.82072810747211, 26.042369323853773, 26.262140049889307, 26.48008685786359, 26.696254418925513, 26.910685609995152, 27.1234216130635, 27.334502007536187, 27.543964856207612, 27.751846785394303, 27.958183059705437, 28.16300765188264, 28.366353308100784, 28.568251609085216, 28.768733027368448, 28.967826980980124, 29.165561883838276, 29.36196519308611, 29.557063453597692, 29.750882339856748, 29.943446695395643, 30.134780569965997, 30.324907254598493, 30.513849314696436, 30.7016286212963, 30.88826638061774, 31.07378316201618, 31.25819892444221, 31.441533041504194, 31.623804325223116, 31.805031048562117, 31.985230966807162, 32.164421337869584, 32.34261894157614, 32.51984009800786, 32.69610068494407, 32.87141615446466, 33.04580154875956, 33.2192715151913, 33.391840320653195, 33.56352186526319, 33.734329695430446, 33.904277016329374, 34.07337670381379], [0.0, 3.4347488991191195, 4.8574684764803155, 5.949159604515583, 6.869497798238239, 7.680332024072919, 8.413382197428097, 9.087491403022069, 9.714936952960631, 10.304246697357357, 10.861629711972325, 11.39177334746439, 11.898319209031166, 12.384163274117475, 12.851653590102716, 13.302725284692606, 13.738995596476478, 14.161832508542108, 14.572405429440948, 14.971723347697823, 15.360664048145837, 15.739996823379606, 16.110400367464493, 16.472477045059133, 16.826764394856195, 17.173744495595596, 17.51385166089973, 17.84747881354675, 18.174982806044138, 18.496688892880265, 18.812894514135778, 19.12387251578508, 19.429873905921262, 19.73113022611731, 20.02785560163644, 20.320248522102283, 20.608493394714714, 20.892761904544837, 21.173214210412176, 21.450000000000003, 21.72325942394465, 21.99312392544543, 22.25971697933287, 22.523154752387597, 22.78354669492878, 23.04099607221875, 23.29560044300211, 23.547452091468415, 23.796638418062333, 24.043242293833835, 24.287342382401583, 24.529013433075537, 24.76832654823495, 25.005349427672478, 25.240146592284287, 25.47277958920071, 25.70330718020543, 25.931785515077824, 26.158268291307056, 26.382806901465205, 26.605450569385212, 26.82624647616584, 27.045239876917343, 27.26247420906621, 27.477991192952956, 27.69183092538303, 27.904031966724812, 28.11463142209053, 28.323665017084217, 28.531167168554465, 28.737171050748895, 28.941708657230315, 29.144810858881897, 29.34650745829902, 29.546827240839246, 29.745798022577915, 29.943446695395647, 30.13979926940457, 30.334880912902896, 30.528715990031422, 30.721328096291675, 30.912740092072074, 31.10297413431713, 31.292051706463738, 31.479993646759212, 31.666820175066523, 31.852550918254572, 32.03720493426354, 32.220800734928986, 32.40335630764196, 32.584889135916974, 32.765416218934256, 32.944954090118266, 33.12351883480981, 33.30112610708533, 33.47779114577304, 33.65352878971239, 33.828353492299925, 34.00227933536222, 34.175320042393174, 34.34748899119119, 34.51879922592906], [0.0, 3.4785054261852175, 4.919349550499537, 6.024948132556828, 6.957010852370435, 7.778174593052023, 8.520563361656318, 9.20326029187483, 9.838699100999074, 10.435516278555651, 11.0, 11.536897329871667, 12.049896265113656, 12.541929676090518, 13.015375522819156, 13.472193585307478, 13.91402170474087, 14.342245291445828, 14.758048651498612, 15.162453627299247, 15.556349186104047, 15.940514420808384, 16.31563667161046, 16.68232597691341, 17.041126723312637, 17.392527130926087, 17.73696704625681, 18.074844397670482, 18.40652058374966, 18.732325002519044, 19.05255888325765, 19.36749854782491, 19.677398201998148, 19.982492337043446, 20.282997806044353, 20.579115627256677, 20.871032557111302, 21.15892246783848, 21.44294755857972, 21.72325942394465, 22.0, 22.27330240444825, 22.543291685111118, 22.81008548866049, 23.073794659743335, 23.334523779156065, 23.59237164847994, 23.84743172754668, 24.09979253022731, 24.34953798329652, 24.596747752497688, 24.841497539399676, 25.083859352181037, 25.323901753086947, 25.56169008496895, 25.797286679028865, 26.03075104563831, 26.262140049889307, 26.491508073343052, 26.718907163280463, 26.944387170614956, 27.16799587750263, 27.38977911557521, 27.609780875624494, 27.82804340948174, 28.044607324760314, 28.259511673063283, 28.472794032198525, 28.684490582891655, 28.894636180440134, 29.1032644217105, 29.3104077078433, 29.516097302997224, 29.72036338943385, 29.923235119217974, 30.124740662784138, 30.324907254598493, 30.523761236125537, 30.721328096291675, 30.917632509621434, 31.112698372208094, 31.306548835666955, 31.49920633920798, 31.690692639953454, 31.881028841616768, 32.07023542164915, 32.258332256953395, 32.44533864825578, 32.63127334322092, 32.81615455838785, 33.0, 33.18282688379638, 33.36465195382682, 33.54549150034919, 33.72536137686296, 33.90427701632937, 34.08225344662527, 34.25930530527437, 34.435446853496764, 34.610691989615006, 34.785054261852174, 34.95854688055555], [0.0, 3.5217183305880675, 4.9804618259755795, 6.09979507852518, 7.043436661176135, 7.874801584801996, 8.62641292774697, 9.317590890353578, 9.960923651951159, 10.565154991764201, 11.136651202224124, 11.680218319877417, 12.19959015705036, 12.697736018676716, 13.177063405782034, 13.639556444400968, 14.08687332235227, 14.520416660688495, 14.941385477926739, 15.350814310648152, 15.749603169603992, 16.138540826233335, 16.51832315944933, 16.889567786062496, 17.25282585549394, 17.608591652940337, 17.957310489045962, 18.29938523557554, 18.635181780707157, 18.96503361452334, 19.289245708425202, 19.608097816973476, 19.921847303902318, 20.230731573524476, 20.534970172853917, 20.834766617363393, 21.130309983528402, 21.421776303565494, 21.70932979158961, 21.993123925445428, 22.27330240444825, 22.550000000000004, 22.823343313371076, 23.093451452738716, 23.360436639754834, 23.62440475440598, 23.885455825669315, 24.14368447441277, 24.39918031410072, 24.65202831411647, 24.9023091298779, 25.150099403382093, 25.395472037353432, 25.638496445774667, 25.879238783240904, 26.11776215528429, 26.35412681156407, 26.588390323598006, 26.820607748520544, 27.050831780187465, 27.279112888801937, 27.505499450109973, 27.73003786510217, 27.95277267106074, 28.17374664470454, 28.393000898108674, 28.610574968007896, 28.826506899033053, 29.04083332137699, 29.253589523338842, 29.464809519153526, 29.674526112475665, 29.882770955853477, 30.089574606497848, 30.294966578624905, 30.4989753926259, 30.701628621296305, 30.902952933336323, 31.10297413431713, 31.301717205290835, 31.499206339207984, 31.695464975292605, 31.890515831513298, 32.08438093527753, 32.27708165246667, 32.468638714919976, 32.65907224646775, 32.84840178760605, 33.03664631889866, 33.2238242831857, 33.409953606672374, 33.59505171896599, 33.77913557212499, 33.962221658778454, 34.14432602937127, 34.325464308585836, 34.50565171098788, 34.684903055940644, 34.86323278182906, 35.040654959632256, 35.217183305880674, 35.39283119503158], [0.0, 3.5644073841243236, 5.040833264451424, 6.173734688177005, 7.128814768248647, 7.970257210404193, 8.73097932651315, 9.430535509715236, 10.081666528902849, 10.69322215237297, 11.271645842555559, 11.821801893112575, 12.34746937635401, 12.851653590102716, 13.336791218280357, 13.804890437812245, 14.257629536497294, 14.696428137476127, 15.122499793354274, 15.536891581008092, 15.940514420808386, 16.33416664540925, 16.71855256892773, 17.09429729471206, 17.4619586530263, 17.822036920621617, 18.17498280604414, 18.521204064531013, 18.861071019430472, 19.194921203276667, 19.523063284228733, 19.84578040793559, 20.163333057805698, 20.475961515884915, 20.783887990460304, 21.087318463948897, 21.38644430474594, 21.68144367886973, 21.972482790982, 22.25971697933287, 22.543291685111118, 22.823343313371076, 23.100000000000005, 23.373382296963356, 23.64360378622515, 23.910771631212572, 24.174987073419505, 24.436345880675372, 24.69493875270802, 24.950851688870266, 25.204166322257123, 25.4549602238935, 25.70330718020543, 25.949277446587992, 26.192937979539447, 26.43435264953542, 26.673582436560714, 26.910685609995152, 27.14571789435675, 27.378732622238015, 27.60978087562449, 27.83891161665628, 28.066171808780762, 28.29160652914571, 28.51525907299459, 28.737171050748888, 28.957382478394006, 29.17593186172466, 29.392856274952255, 29.6081914341285, 29.821971765797116, 30.034230471247305, 30.24499958670855, 30.454310039795683, 30.66219170248598, 30.868673440885022, 31.073783162016184, 31.27754785784845, 31.479993646759212, 31.681145812612275, 31.88102884161677, 32.07966645711891, 32.27708165246667, 32.47329672207613, 32.6683332908185, 32.86221234183724, 33.054954242896784, 33.24657877135631, 33.43710513785546, 33.626552008792096, 33.81493752766668, 34.00227933536221, 34.18859458942412, 34.373899982399436, 34.55821175929103, 34.74154573417827, 34.9239173060526, 35.105341473912496, 35.285832851159974, 35.46540567933773, 35.644073841243234, 35.82185087345433], [0.0, 3.6065911883661004, 5.100490172522636, 6.246799180380301, 7.213182376732201, 8.064583064238349, 8.834308122314956, 9.542143365093608, 10.200980345045272, 10.8197735650983, 11.405042744330245, 11.96170974401235, 12.493598360760602, 13.003749459290578, 13.494628561023827, 13.968267609120321, 14.426364753464402, 14.870356418055351, 15.30147051756791, 15.720766520752099, 16.129166128476697, 16.527477121448392, 16.916412149152666, 17.296603712868023, 17.668616244629913, 18.0329559418305, 18.390078847030537, 18.7403975411409, 19.084286730187216, 19.422087941310533, 19.754113495674765, 20.08064988988155, 20.401960690090544, 20.7182890220211, 21.029859723735676, 21.336881215397902, 21.6395471301966, 21.93803774269704, 22.23252122454851, 22.523154752387597, 22.81008548866049, 23.09345145273872, 23.373382296963356, 23.649999999999995, 23.9234194880247, 24.193749192715043, 24.461091553730792, 24.725543472287924, 24.987196721521205, 25.2461383185627, 25.502450862613184, 25.75621284272981, 26.007498918581156, 26.256380177016023, 26.502924366944864, 26.747196114733224, 26.989257122047654, 27.229166347870436, 27.4669801762043, 27.70275257081866, 27.936535218240643, 28.168377660064127, 28.398327415536283, 28.626430095280828, 28.852729506928803, 29.07726775334986, 29.300085324107844, 29.52122118070321, 29.740712836110703, 29.958596429071903, 30.174906793559447, 30.389677523790866, 30.60294103513582, 30.81472862122916, 31.025070507574995, 31.233995901901505, 31.441533041504197, 31.64770923779476, 31.852550918254572, 32.056083665975166, 32.258332256953395, 32.4593206952949, 32.65907224646775, 32.85760946873646, 33.054954242896784, 33.25112780042205, 33.44615075012369, 33.64004310342066, 33.83282429830533, 34.024513222087386, 34.215128232990736, 34.4046871806735, 34.59320742573605, 34.78070585827723, 34.96719891555513, 35.15270259880454, 35.337232489259826, 35.52080376342855, 35.70343120765846, 35.88512923203705, 36.065911883661, 36.245792859309894], [0.0, 3.6482872693909405, 5.159457335805772, 6.319018911191833, 7.296574538781881, 8.157818335805231, 8.936442245099558, 9.652460826131334, 10.318914671611545, 10.94486180817282, 11.536897329871667, 12.100000000000001, 12.638037822383666, 13.154086817411539, 13.650641010589943, 14.129755836531642, 14.593149077563762, 15.042273764295079, 15.478372007417319, 15.90251552428106, 16.315636671610463, 16.718552568927734, 17.111984104714452, 17.496571092645553, 17.872884490199116, 18.2414363469547, 18.602687977816544, 18.957056733575495, 19.304921652262667, 19.64662820944093, 19.982492337043446, 20.312803843881326, 20.63782934322309, 20.95781477158342, 21.27298756639509, 21.58355855738344, 21.88972361634564, 22.191665102015218, 22.489553130286964, 22.78354669492878, 23.073794659743335, 23.360436639754838, 23.64360378622515, 23.9234194880247, 24.200000000000003, 24.473455007415687, 24.743888134244386, 25.011397401984564, 25.27607564476733, 25.538010885736583, 25.797286679028865, 26.05398242111943, 26.308173634823078, 26.559932228829204, 26.809326735298672, 27.05642252774746, 27.301282021179887, 27.543964856207612, 27.7845280686932, 28.023026246285397, 28.259511673063283, 28.494034463374962, 28.72664268584131, 28.957382478394006, 29.186298155127524, 29.413432305666063, 29.638825887676457, 29.862518313096103, 30.084547528590157, 30.304950090703006, 30.52376123612554, 30.741014947460666, 30.956744014834637, 31.170980093670458, 31.383753758911634, 31.59509455595916, 31.80503104856212, 32.01359086388155, 32.220800734928986, 32.42668654056409, 32.631273343220926, 32.83458542451846, 33.03664631889866, 33.23747884542389, 33.43710513785547, 33.63554667312545, 33.83282429830534, 34.02895825616765, 34.223968209428904, 34.417873263756434, 34.610691989615006, 34.80244244302402, 34.993142185291106, 35.18280830178285, 35.37145741978976, 35.559105725538146, 35.74576898039823, 35.93146253633437, 36.11620135064042, 36.30000000000001, 36.4828726939094, 36.664833287497714], [0.0, 3.689512162874653, 5.217758139277825, 6.390422521242238, 7.379024325749306, 8.25, 9.037422198835241, 9.761531642114365, 10.43551627855565, 11.068536488623957, 11.667261889578032, 12.236727503707844, 12.780845042484476, 13.302725284692606, 13.804890437812245, 14.289419162443235, 14.758048651498612, 15.212248354533264, 15.653274417833476, 16.082210668934792, 16.5, 16.907468763833336, 17.3053459948075, 17.69427873635995, 18.074844397670482, 18.447560814373265, 18.812894514135778, 19.171267563726712, 19.52306328422873, 19.868631055007288, 20.208290377961216, 20.542334336681407, 20.8710325571113, 21.19463375479746, 21.51336793716874, 21.82744831628287, 22.137072977247914, 22.44242633941348, 22.743680440948864, 23.040996072218753, 23.334523779156065, 23.624404754405983, 23.910771631212572, 24.193749192715043, 24.473455007415687, 24.749999999999993, 25.023488965370117, 25.29402103264722, 25.56169008496895, 25.826585140122567, 26.08879069638913, 26.348387047407666, 26.605450569385212, 26.860053983564516, 27.11226659650572, 27.36215452043205, 27.60978087562449, 27.855205976621313, 28.09848750377856, 28.33968066157415, 28.57883832488647, 28.816011174345412, 29.05124782173736, 29.284594926343097, 29.516097302997224, 29.745798022577905, 29.973738505565166, 30.199958609243154, 30.424496709066528, 30.647389774661068, 30.868673440885015, 31.08838207433767, 31.306548835666952, 31.523205737995614, 31.738383701757716, 31.952112606211188, 32.164421337869584, 32.37533783607516, 32.584889135916974, 32.79310140868046, 33.0, 33.20560946587187, 33.40995360667237, 33.61305549931455, 33.81493752766667, 34.0156214113457, 34.215128232990736, 34.413478464113446, 34.610691989615, 34.80678813105282, 35.0017856687341, 35.195702862707535, 35.3885574727199, 35.580366777198904, 35.771147591320016, 35.96091628421055, 36.149688795340964, 36.33748065014965, 36.52430697494478, 36.710182511123534, 36.89512162874653, 37.07913833950298], [0.0, 3.7302814907188977, 5.275414675643991, 6.461037068458903, 7.460562981437795, 8.341162988456707, 9.137286249209884, 9.869397144709499, 10.550829351287982, 11.190844472156693, 11.79618582423997, 12.371944067122193, 12.922074136917805, 13.449721186701233, 13.957435294494474, 14.447318090220065, 14.92112596287559, 15.38034459952052, 15.826244026931976, 16.259920049003934, 16.682325976913415, 17.09429729471206, 17.496571092645553, 17.889801564019653, 18.27457249841977, 18.651407453594487, 19.020778112369644, 19.383111205376707, 19.738794289418998, 20.088180604524645, 20.43159318310738, 20.769328347349127, 21.101658702575964, 21.428835712655975, 21.75109192661371, 22.068642912512768, 22.381688944313385, 22.690416479209897, 22.994999456403562, 23.29560044300211, 23.59237164847994, 23.885455825669315, 24.174987073419505, 24.461091553730792, 24.743888134244386, 25.023488965370113, 25.300000000000004, 25.573521462637878, 25.84414827383561, 26.111970435032283, 26.37707337821996, 26.63953828428714, 26.899442373402465, 27.156859170382724, 27.411858747629648, 27.664507947910444, 27.914870588988947, 28.163007651882637, 28.40897745431891, 28.652835810788435, 28.89463618044013, 29.13442980392786, 29.372265830201112, 29.608191434128496, 29.84225192575118, 30.074490851883095, 30.304950090703006, 30.533669939920422, 30.76068919904104, 30.986045246207205, 31.20977411004444, 31.431910536905008, 31.65248805386395, 31.871539027790924, 32.08909472079261, 32.305185342294514, 32.51984009800787, 32.73308723600632, 32.944954090118266, 33.15546712082338, 33.36465195382683, 33.57253341647008, 33.77913557212499, 33.984481752705896, 34.18859458942412, 34.39149604189966, 34.593207425736054, 34.79374943865636, 34.993142185291106, 35.19140520070206, 35.38855747271991, 35.58461746316799, 35.779603128039305, 35.973531936689234, 36.16642089010192, 36.358286538284496, 36.54914499683954, 36.739011962762426, 36.92790272950794, 37.11583220136658, 37.302814907188974, 37.48886501349435], [0.0, 3.7706100302205745, 5.332447843157961, 6.530888147870855, 7.541220060441149, 8.43134034421574, 9.236070593060667, 9.97609643096938, 10.664895686315923, 11.311830090661722, 11.92371586377334, 12.50569870099228, 13.06177629574171, 13.595127803739103, 14.108330872218726, 14.603509852086928, 15.082440120882298, 15.546623427612827, 15.997343529473886, 16.43570807723233, 16.86268068843148, 17.27910587964551, 17.68572870989488, 18.083210445050955, 18.472141186121334, 18.853050151102874, 19.22641412224339, 19.592664443612563, 19.95219286193876, 20.305356436172207, 20.652481691070445, 20.993868152391546, 21.329791372631846, 21.66050553426674, 21.986245700437355, 22.30722976974057, 22.623660181323444, 22.935725408192347, 23.243601270026986, 23.54745209146841, 23.84743172754668, 24.14368447441277, 24.43634588067537, 24.72554347228792, 25.01139740198456, 25.29402103264722, 25.573521462637878, 25.85, 26.12355259148342, 26.394270211544022, 26.66223921578981, 26.92754166276603, 27.190255607478207, 27.45045536962912, 27.708211779181998, 27.96359240154956, 28.216661744437452, 28.467481448136574, 28.71611046085455, 28.96260520049949, 29.207019704173856, 29.449405766500618, 29.689813067784712, 29.92828929290814, 30.164880241764596, 30.39962993195805, 30.632580694417506, 30.863773262516037, 31.093246855225654, 31.321039254788467, 31.547186879339975, 31.771724850879593, 31.994687058947772, 32.216106220336435, 32.43601393513081, 32.65444073935427, 32.87141615446466, 33.08696873392907, 33.30112610708533, 33.513915020480674, 33.72536137686296, 33.93549027198517, 34.144326029371264, 34.35189223317982, 34.55821175929102, 34.76330680473306, 34.96719891555513, 35.16990901324597, 35.37145741978976, 35.57186388144427, 35.771147591320016, 35.9693272108334, 36.16642089010191, 36.36244628734431, 36.55742058734451, 36.751360519033845, 36.94428237224267, 37.13620201366856, 37.32713490210573, 37.51709610297684, 37.70610030220575, 37.894161819467655], [0.0, 3.8105117766515306, 5.388877434122993, 6.600000000000001, 7.621023553303061, 8.520563361656318, 9.33380951166243, 10.081666528902849, 10.777754868245985, 11.431535329954592, 12.049896265113656, 12.638037822383666, 13.200000000000003, 13.738995596476478, 14.257629536497294, 14.758048651498612, 15.242047106606122, 15.711142542794272, 16.166632302368978, 16.609635757595655, 17.041126723312637, 17.4619586530263, 17.872884490199116, 18.27457249841977, 18.66761902332486, 19.052558883257653, 19.42987390592127, 19.800000000000004, 20.163333057805698, 20.520233916795398, 20.871032557111306, 21.216031674184503, 21.55550973649197, 21.889723616345645, 22.218910864396577, 22.543291685111118, 22.863070659909184, 23.178438256276028, 23.48957215446889, 23.796638418062333, 24.09979253022731, 24.399180314100725, 24.69493875270802, 24.987196721521205, 25.27607564476733, 25.56169008496895, 25.84414827383561, 26.123552591483424, 26.400000000000006, 26.673582436560714, 26.944387170614963, 27.212497129076567, 27.477991192952956, 27.74094446842069, 28.001428534987287, 28.25951167306329, 28.51525907299459, 28.768733027368448, 29.019993108200428, 29.26909633043016, 29.516097302997224, 29.761048368631105, 30.003999733368886, 30.24499958670855, 30.484094213212245, 30.72132809629167, 30.956744014834637, 31.19038313326722, 31.422285085588545, 31.652488053863955, 31.88102884161677, 32.107942942518136, 32.333264604737955, 32.55702689128724, 32.77926173665295, 33.00000000000001, 33.21927151519131, 33.43710513785546, 33.65352878971239, 33.868569500349444, 34.08225344662527, 34.294605989863776, 34.50565171098788, 34.71541444373091, 34.9239173060526, 35.13118272987689, 35.337232489259826, 35.54208772708773, 35.74576898039823, 35.94829620441002, 36.14968879534097, 36.349965612088276, 36.54914499683954, 36.747244794678146, 36.94428237224267, 37.14027463549509, 37.33523804664972, 37.529188640310366, 37.72214203886095, 37.914113467151, 38.105117766515306, 38.29516940816427], [0.0, 3.85, 5.444722215136416, 6.668395609140179, 7.7, 8.608861713374191, 9.430535509715236, 10.186142547598672, 10.889444430272832, 11.549999999999999, 12.17476899164826, 12.76900544286829, 13.336791218280357, 13.88137241053636, 14.405380939079675, 14.910985882898553, 15.4, 15.873956658627993, 16.334166645409248, 16.781760932631595, 17.217723426748382, 17.642916425579987, 18.058100675320205, 18.46395136475397, 18.861071019430472, 19.25, 19.631225127332225, 20.005186827420534, 20.372285095197345, 20.732884507467844, 21.087318463948893, 21.435892796895583, 21.778888860545663, 22.11656618917141, 22.44916479515441, 22.776907164933522, 23.099999999999998, 23.418635741648146, 23.73299391143056, 24.043242293833835, 24.34953798329652, 24.65202831411647, 24.950851688870262, 25.2461383185627, 25.53801088573658, 25.826585140122567, 26.111970435032283, 26.394270211544022, 26.673582436560714, 26.95, 27.22361107568208, 27.494499449889975, 27.76274482107272, 28.02842307373, 28.291606529145707, 28.552364175318306, 28.81076187815935, 29.066862575792385, 29.32072645757605, 29.572411129294142, 29.821971765797105, 30.069461252240618, 30.31493031494547, 30.558427642796023, 30.8, 31.039692330949414, 31.277547857848447, 31.51360817170893, 31.747913317255986, 31.980501872234587, 32.21141102156191, 32.44067662672898, 32.668333290818495, 32.89441441947249, 33.118952278114115, 33.34197804570089, 33.56352186526319, 33.78361289145967, 34.00227933536222, 34.21954850666502, 34.435446853496764, 34.65, 34.863232781829055, 35.07516927970555, 35.285832851159974, 35.495246160577615, 35.70343120765846, 35.91040935439194, 36.11620135064041, 36.32082735841792, 36.52430697494478, 36.7266592545524, 36.92790272950794, 37.12805542982288, 37.32713490210573, 37.52515822751451, 37.722142038860945, 37.91810253691501, 38.11305550595491, 38.307016328604874, 38.5, 38.692021141315436], [0.0, 3.8890872965260117, 5.5, 6.736096792653741, 7.778174593052023, 8.696263565463044, 9.526279441628827, 10.289557813628338, 11.0, 11.667261889578034, 12.298373876248844, 12.898643339514432, 13.472193585307481, 14.02230366238016, 14.55163221085525, 15.062370331392067, 15.556349186104047, 16.03511771082458, 16.5, 16.95213850816469, 17.392527130926087, 17.822036920621617, 18.2414363469547, 18.651407453594487, 19.052558883257653, 19.445436482630058, 19.830532015051944, 20.20829037796122, 20.579115627256677, 20.943376041125752, 21.301408404140794, 21.65352165353248, 22.0, 22.341105612748894, 22.677080940897135, 23.008150729687078, 23.33452377915607, 23.656394484367226, 23.973944189473706, 24.287342382401583, 24.596747752497688, 24.9023091298779, 25.204166322257123, 25.502450862613184, 25.797286679028865, 26.088790696389125, 26.37707337821996, 26.662239215789814, 26.944387170614963, 27.223611075682083, 27.500000000000004, 27.773638580495717, 28.04460732476032, 28.312982887714256, 28.578838324886476, 28.84224332467917, 29.1032644217105, 29.361965193086107, 29.618406439239777, 29.872646350800593, 30.124740662784134, 30.374742797264968, 30.622703995565118, 30.86867344088502, 31.112698372208094, 31.354824190226292, 31.595094555959157, 31.83355148267312, 32.07023542164916, 32.305185342294514, 32.53843880704789, 32.770032041485706, 33.0, 33.22837642738507, 33.45519391664021, 33.6804839632687, 33.90427701632938, 34.126602526474855, 34.3474889911912, 34.56696399743547, 34.785054261852174, 35.0017856687341, 35.217183305880674, 35.4312714984941, 35.644073841243234, 35.855613228614565, 36.065911883661, 36.27499138525053, 36.4828726939094, 36.689576176347416, 36.89512162874653, 37.09952829888811, 37.302814907188974, 37.50499966671111, 37.70610030220575, 37.90613406824811, 38.105117766515306, 38.30306776225633, 38.50000000000001, 38.6959300185433, 38.890872965260115, 39.08484360976772], [0.0, 3.927785635698568, 5.554727716099143, 6.803124282269142, 7.855571271397136, 8.782795682469223, 9.621070626494749, 10.391943995230152, 11.109455432198287, 11.783356907095703, 12.420748769699838, 13.026991210559714, 13.606248564538284, 14.161832508542108, 14.696428137476127, 15.212248354533264, 15.711142542794272, 16.194675050769003, 16.66418314829743, 17.120820657900722, 17.565591364938445, 17.999374989148933, 18.42294764688865, 18.83699816849808, 19.242141252989498, 19.63892817849284, 20.027855601636443, 20.409372846807422, 20.783887990460304, 21.151772975332356, 21.51336793716874, 21.86898488727815, 22.218910864396573, 22.56341064644262, 22.902729095022718, 23.23709319170537, 23.566713814191406, 23.891787291870823, 24.212496773360655, 24.529013433075537, 24.841497539399676, 25.150099403382093, 25.4549602238935, 25.75621284272981, 26.05398242111943, 26.348387047407662, 26.63953828428714, 26.92754166276603, 27.212497129076567, 27.494499449889975, 27.773638580495717, 28.050000000000008, 28.323665017084217, 28.594711049423115, 28.86321187948424, 29.1292378891038, 29.392856274952255, 29.65413124675886, 29.91312420995173, 30.169893934185453, 30.424496709066528, 30.67698648824555, 30.927415022921007, 31.175831985690458, 31.422285085588545, 31.66682017506652, 31.909481349592635, 32.150311040486066, 32.38935010153801, 32.626637889920566, 32.86221234183725, 33.096110043326846, 33.32836629659486, 33.55901518221296, 33.78808961749687, 34.015621411345705, 34.241641315801445, 34.46617907456526, 34.68926346868726, 34.91092235962837, 35.13118272987689, 35.35007072128711, 35.56761167129444, 35.78383014714887, 35.998749978297866, 36.21239428703935, 36.424785517556586, 36.635945463437956, 36.8458952937773, 37.05465557794324, 37.26224630909951, 37.468686926552415, 37.67399633699616, 37.87819293472169, 38.08129462085028, 38.28331882164868, 38.484282505978996, 38.68420220193252, 38.88309401269401, 39.08097363167915, 39.27785635698568, 39.47375710519586], [0.0, 3.966106403010389, 5.608921464952063, 6.869497798238239, 7.932212806020778, 8.868483523128406, 9.714936952960633, 10.493331215586402, 11.217842929904126, 11.898319209031165, 12.541929676090518, 13.154086817411539, 13.738995596476478, 14.3, 14.839811319555247, 15.360664048145834, 15.864425612041556, 16.35267562205036, 16.82676439485619, 17.287857010051887, 17.73696704625681, 18.174982806044138, 18.60268797781654, 19.02077811236964, 19.429873905921266, 19.830532015051944, 20.223253941935262, 20.608493394714717, 20.986662431172803, 21.358136622842363, 21.72325942394465, 22.082345889873203, 22.435685859808252, 22.78354669492878, 23.126175645791506, 23.463801908471698, 23.79663841806233, 24.124883419407443, 24.44872184798216, 24.76832654823495, 25.083859352181037, 25.395472037353436, 25.70330718020543, 26.007498918581156, 26.308173634823078, 26.605450569385212, 26.89944237340247, 27.19025560747821, 27.477991192952956, 27.76274482107272, 28.04460732476032, 28.323665017084217, 28.6, 28.873690446494717, 29.144810858881897, 29.413432305666067, 29.679622639110494, 29.94344669539564, 30.20496647904116, 30.464241333077705, 30.721328096291668, 30.97628124872319, 31.229153046472458, 31.47999364675921, 31.72885122408311, 31.97577207824699, 32.220800734928986, 32.463980039422154, 32.70535124410072, 32.944954090118266, 33.18282688379639, 33.419006568119286, 33.65352878971238, 33.8864279616486, 34.11773732239581, 34.34748899119119, 34.575714020103774, 34.80244244302403, 35.02770332179946, 35.25152478971655, 35.47393409251362, 35.694957627093494, 35.914620978091925, 36.132948952445055, 36.349965612088276, 36.565694304908256, 36.780157694061074, 36.99337778576052, 37.20537595563308, 37.416172973728884, 37.625789028271555, 37.83424374822364, 38.04155622473928, 38.24774503157016, 38.45282824448678, 38.65682345977227, 38.85974781184253, 39.06161799004236, 39.26245025466445, 39.462260452234624, 39.66106403010389, 39.858876050385575], [0.0, 4.004060439104285, 5.662596577542851, 6.9352361171051715, 8.00812087820857, 8.95335132785484, 9.807904975069857, 10.593748156342023, 11.325193155085701, 12.012181317312855, 12.661950876543473, 13.279966114414602, 13.870472234210343, 14.436845223247358, 14.98182231906386, 15.507659397858852, 16.01624175641714, 16.509164121784, 16.987789732628553, 17.45329481788468, 17.90670265570968, 18.348910049373508, 18.780708186860263, 19.2027992751057, 19.615809950139713, 20.020302195521428, 20.41678231259765, 20.805708351315513, 21.187496312684047, 21.56252536230393, 21.931142241114575, 22.293665019462367, 22.650386310171402, 23.001576032959136, 23.34748380447024, 23.688341014093833, 24.02436263462571, 24.355748808032985, 24.682686239548566, 25.005349427672478, 25.323901753086947, 25.638496445774667, 25.949277446587992, 26.256380177016023, 26.559932228829204, 26.860053983564516, 27.156859170382724, 27.450455369629122, 27.740944468420686, 28.02842307373, 28.312982887714256, 28.594711049423115, 28.873690446494717, 29.150000000000006, 29.423714925209566, 29.6949069707248, 29.96364463812772, 30.22999338405485, 30.494015806384052, 30.755771816034795, 31.015318795717704, 31.2727117468249, 31.528003425526332, 31.781244469026074, 32.03248351283428, 32.28176729982422, 32.52914078176674, 32.77464721396708, 33.018328243568, 33.260223992029886, 33.50037313225034, 33.738812960743005, 33.975579465257105, 34.21070738818477, 34.44423028607259, 34.676180585525856, 34.90658963576936, 35.13548775810577, 35.36290429249273, 35.58886764144092, 35.81340531141936, 36.03654395193857, 36.25830939246893, 36.47872667733895, 36.697820098747016, 36.91561322800964, 37.13212894516015, 37.34738946700291, 37.561416373720526, 37.7742306341241, 37.98585262963042, 38.196302177043265, 38.4055985502114, 38.61376050062983, 38.820806277046856, 39.02675364413494, 39.231619900279426, 39.43542189453539, 39.638176042799955, 39.83989834324381, 40.040604391042855, 40.24030939244877], [0.0, 4.041658075592244, 5.715767664977295, 7.000357133746822, 8.083316151184489, 9.037422198835243, 9.900000000000002, 10.693222152372968, 11.43153532995459, 12.12497422677673, 12.780845042484476, 13.404663367649336, 14.000714267493644, 14.572405429440948, 15.122499793354272, 15.653274417833476, 16.166632302368978, 16.66418314829743, 17.147302994931884, 17.617179115851666, 18.074844397670486, 18.521204064531013, 18.957056733575495, 19.383111205376707, 19.800000000000004, 20.20829037796122, 20.608493394714717, 21.001071401240463, 21.386444304745936, 21.76499483115032, 22.137072977247918, 22.50299980002666, 22.86307065990918, 23.217558011125977, 23.566713814191406, 23.910771631212572, 24.24994845355346, 24.584446302489713, 24.914453636393475, 25.240146592284287, 25.56169008496895, 25.879238783240904, 26.19293797953945, 26.502924366944864, 26.809326735298672, 27.11226659650572, 27.41185874762965, 27.708211779182, 28.001428534987287, 28.29160652914571, 28.578838324886476, 28.86321187948424, 29.144810858881897, 29.423714925209566, 29.7, 29.973738505565173, 30.244999586708545, 30.513849314696433, 30.780350875193093, 31.044564741674186, 31.306548835666952, 31.566358675019835, 31.82404751127675, 32.07966645711891, 32.333264604737955, 32.584889135916974, 32.83458542451846, 33.082397132009646, 33.32836629659486, 33.57253341647008, 33.81493752766668, 34.05561627690798, 34.29460598986377, 34.53194173515298, 34.767657384414036, 35.00178566873411, 35.23435823170333, 35.46540567933772, 35.6949576270935, 35.92304274417745, 36.14968879534097, 36.374922680330194, 36.598770471151084, 36.82125744729531, 37.042408129062025, 37.26224630909951, 37.48079508228181, 37.69807687402635, 37.91411346715099, 38.12892602736143, 38.34253512745343, 38.55496077030814, 38.766222410753414, 38.97633897635846, 39.18532888722513, 39.39321007483396, 39.60000000000001, 39.805715669988906, 40.01037365484107, 40.21399010294801, 40.41658075592244, 40.61816096280087], [0.0, 4.078909167902615, 5.768448664935834, 7.064877918265822, 8.15781833580523, 9.12071817347735, 9.991246168521725, 10.79177927869172, 11.536897329871667, 12.236727503707844, 12.898643339514432, 13.528211263873729, 14.129755836531643, 14.706716152833033, 15.26188061806277, 15.797547277979577, 16.31563667161046, 16.817773336562723, 17.3053459948075, 17.77955286276908, 18.2414363469547, 18.691910014763074, 19.1317798440187, 19.561761168156615, 19.98249233704345, 20.394545839513075, 20.798437441307943, 21.194633754797465, 21.58355855738344, 21.965598102487448, 22.34110561274889, 22.710405104268833, 23.073794659743335, 23.431549244554873, 23.78392314148362, 24.131152065328337, 24.473455007415687, 24.811035851007915, 25.144084791457416, 25.47277958920071, 25.797286679028865, 26.11776215528429, 26.434352649535416, 26.74719611473322, 27.056422527747458, 27.362154520432046, 27.664507947910444, 27.96359240154956, 28.259511673063287, 28.552364175318303, 28.84224332467917, 29.1292378891038, 29.413432305666067, 29.694906970724798, 29.97373850556517, 30.250000000000004, 30.52376123612554, 30.79508889417272, 31.06404674217447, 31.330695810977453, 31.595094555959154, 31.857299006664075, 32.11736290544415, 32.37533783607517, 32.63127334322092, 32.88521704352884, 33.13721472906255, 33.387310463707614, 33.63554667312545, 33.88196422877517, 34.12660252647486, 34.36949955992959, 34.610691989615, 34.850215207369956, 35.088103397020475, 35.32438959132911, 35.55910572553816, 35.79228268775268, 36.0239503663882, 36.2541376948894, 36.4828726939094, 36.710182511123534, 36.936093458837796, 37.16063104953951, 37.38382002952615, 37.605684410737695, 37.82624750090868, 38.04553193214678, 38.2635596880374, 38.48035212936596, 38.695930018543294, 38.91031354281278, 39.12352233631323, 39.33557550106519, 39.546491626944615, 39.756288810702635, 39.9649846740869, 40.17259638111533, 40.37914065455084, 40.584633791621194, 40.78909167902615, 40.99252980727099], [0.0, 4.115823125451335, 5.820652884342099, 7.128814768248647, 8.23164625090267, 9.203260291874832, 10.081666528902849, 10.88944443027283, 11.641305768684198, 12.347469376354006, 13.015375522819156, 13.650641010589943, 14.257629536497294, 14.839811319555245, 15.4, 15.94051442080838, 16.46329250180534, 16.969973482595663, 17.461958653026297, 17.9404570733301, 18.406520583749664, 18.861071019430472, 19.30492165226267, 19.738794289418998, 20.163333057805698, 20.579115627256677, 20.986662431172807, 21.38644430474594, 21.77888886054566, 22.164385847570877, 22.543291685111114, 22.91593332159962, 23.282611537368396, 23.643603786225146, 23.99916665219857, 24.349537983296518, 24.694938752708012, 25.03557468883029, 25.371637708275752, 25.70330718020543, 26.03075104563831, 26.35412681156407, 26.67358243656071, 26.98925712204765, 27.301282021179887, 27.609780875624487, 27.914870588988947, 28.216661744437452, 28.51525907299459, 28.810761878159347, 29.1032644217105, 29.392856274952255, 29.67962263911049, 29.96364463812772, 30.244999586708545, 30.52376123612554, 30.8, 31.073783162016174, 31.345175067305018, 31.61423729903981, 31.88102884161676, 32.1456062316454, 32.40802369784372, 32.668333290818495, 32.92658500361068, 33.18282688379638, 33.43710513785546, 33.689464228449815, 33.939946965191325, 34.18859458942411, 34.435446853496764, 34.68054209495578, 34.923917306052594, 35.165608198920715, 35.40564926674838, 35.644073841243234, 35.8809141466602, 36.11620135064041, 36.349965612088276, 36.58223612629496, 36.81304116749933, 37.04240812906202, 37.27036356141432, 37.49693320793048, 37.722142038860945, 37.94601428345275, 38.16857346037444, 38.38984240655333, 38.60984330452534, 38.828597708390134, 39.04612656845747, 39.26245025466444, 39.477588578837995, 39.69156081587117, 39.90438572387752, 40.11608156338303, 40.326666115611395, 40.53615669991422, 40.7445701903947, 40.95192303176983, 41.15823125451335, 41.36351048931897], [0.0, 4.152408939398913, 5.872393038617221, 7.192183256842112, 8.304817878797826, 9.285068658873774, 10.171283104898812, 10.986241395490998, 11.744786077234442, 12.457226818196736, 13.131070024944654, 13.771982428103806, 14.384366513684224, 14.97172334769782, 15.536891581008089, 16.08221066893479, 16.60963575759565, 17.12082065790072, 17.617179115851663, 18.099930939094772, 18.570137317747548, 19.028728281206813, 19.47652433058835, 19.91425368925484, 20.342566209797624, 20.76204469699456, 21.173214210412176, 21.576549770526334, 21.972482790981996, 22.361406485281737, 22.743680440948864, 23.11963451268207, 23.489572154468885, 23.853773286421585, 24.21249677336065, 24.565982577540023, 24.91445363639347, 25.258117507051075, 25.597167812084212, 25.931785515077824, 26.262140049889307, 26.58839032359801, 26.910685609995152, 27.229166347870436, 27.543964856207612, 27.855205976621313, 28.16300765188264, 28.467481448136574, 28.768733027368448, 29.06686257579239, 29.361965193086107, 29.654131246758862, 29.94344669539564, 30.229993384054854, 30.513849314696433, 30.79508889417272, 31.073783162016177, 31.349999999999998, 31.623804325223116, 31.895258268275555, 32.16442133786958, 32.431350573172246, 32.696100684944064, 32.958724186473, 33.2192715151913, 33.47779114577304, 33.73432969543044, 33.98893202205683, 34.24164131580144, 34.49249918460534, 34.74154573417827, 34.98881964285163, 35.234358231703325, 35.478197530314304, 35.720372338484935, 35.96091628421056, 36.199861878189544, 36.437240565114145, 36.67308277197324, 36.90741795357676, 37.140274635495096, 37.37168045459021, 37.60166219730187, 37.83024583583882, 38.05745656241363, 38.28331882164868, 38.50785634127145, 38.73109216120816, 38.9530486611767, 39.17374758687251, 39.39321007483396, 39.611456676067846, 39.82850737850968, 40.04438162838827, 40.25909835055922, 40.4726759678675, 40.68513241959525, 40.89648517904687, 41.10675127032055, 41.31594728431142, 41.52408939398912, 41.73119336898959], [0.0, 4.18867520822515, 5.923681287847955, 7.254998277050107, 8.3773504164503, 9.366162501259522, 10.260116958397699, 11.082192923785437, 11.84736257569591, 12.566025624675449, 13.245754036671526, 13.8922640343466, 14.509996554100214, 15.10248323952058, 15.672587533652509, 16.22266932412789, 16.7547008329006, 17.270350314918343, 17.771043863543863, 18.25801193996762, 18.732325002519044, 19.194921203276667, 19.64662820944093, 20.08818060452464, 20.520233916795398, 20.94337604112575, 21.358136622842363, 21.764994831150318, 22.164385847570873, 22.55670631985087, 22.942318976075633, 23.32155655182561, 23.69472515139182, 24.062107139650095, 24.423963642291973, 24.78053671735138, 25.132051249350898, 25.478716608181035, 25.820728107472107, 26.158268291307056, 26.491508073343052, 26.820607748520544, 27.14571789435675, 27.4669801762043, 27.7845280686932, 28.09848750377856, 28.40897745431891, 28.71611046085455, 29.019993108200428, 29.32072645757605, 29.618406439239774, 29.91312420995173, 30.20496647904116, 30.494015806384052, 30.78035087519309, 31.06404674217447, 31.345175067305018, 31.623804325223112, 31.900000000000006, 32.173824764861266, 32.44533864825578, 32.714599187518715, 32.98166157124289, 33.24657877135631, 33.5094016658012, 33.77017915261925, 34.02895825616764, 34.28578422611914, 34.540700629836685, 34.79374943865636, 35.044971108562784, 35.29440465569578, 35.542087727087726, 35.788056666994365, 36.03234657915024, 36.27499138525053, 36.51602387993524, 36.755475782527974, 36.99337778576053, 37.229759601694994, 37.46465000503809, 37.69807687402635, 37.93006722904667, 38.160647269143645, 38.389842406553335, 38.61767729939231, 38.844175882621066, 39.069361397391695, 39.29325641888186, 39.51588288270933, 39.737262110014576, 39.957414831292574, 40.17636120904928, 40.39412085935279, 40.610712872344415, 40.82615583177039, 41.040467833590796, 41.2536665037182, 41.46576901493569, 41.6767921030398, 41.8867520822515, 42.095664859935404], [0.0, 4.224630161327735, 5.974529270160118, 7.31727408260754, 8.44926032265547, 9.446560220524718, 10.34818824722473, 11.177320788095866, 11.949058540320236, 12.673890483983202, 13.359453581640231, 14.011513123142697, 14.63454816521508, 15.232120666538853, 15.807118649519905, 16.361922258707867, 16.89852064531094, 17.418596384324427, 17.923587810480356, 18.41473594706153, 18.893120441049437, 19.359687497477847, 19.815271888117003, 20.26061450203325, 20.69637649444946, 21.123150806638673, 21.541471630322754, 21.951822247822616, 22.35464157619173, 22.75032966794108, 23.13925236475889, 23.521745258377404, 23.89811708064047, 24.26865262020123, 24.63361524421456, 24.993249088503877, 25.347780967966404, 25.697422049692065, 26.042369323853773, 26.382806901465205, 26.718907163280463, 27.050831780187465, 27.378732622238015, 27.702752570818657, 28.023026246285394, 28.339680661574146, 28.65283581078843, 28.96260520049949, 29.26909633043016, 29.57241112929414, 29.872646350800593, 30.169893934185453, 30.464241333077705, 30.755771816034795, 31.044564741674183, 31.330695810977453, 31.61423729903981, 31.89525826827555, 32.173824764861266, 32.449999999999996, 32.723844517415735, 32.99541634833541, 33.264771155082364, 33.5319623642876, 33.79704129062188, 34.06005725186027, 34.32105767600993, 34.580088201159924, 34.837192768648855, 35.092413710088394, 35.34579182873118, 35.59736647562569, 35.84717562096071, 36.09525592096556, 36.341642780699935, 36.58637041303769, 36.82947189412306, 37.0709792155535, 37.31092333352259, 37.54933421513623, 37.78624088209887, 38.02167145194961, 38.255653177014246, 38.488212481225986, 38.71937499495569, 38.94916558798147, 39.17760840071787, 39.404726873815534, 39.630543776234006, 39.855081231883084, 40.078360744920694, 40.30040322378921, 40.5212290040665, 40.74085787020199, 40.95930907620391, 41.176601365338534, 41.39275298889892, 41.6077817240958, 41.82170489112083, 42.034539369428096, 42.246301613277346, 42.457007666579614], [0.0, 4.260281680828158, 6.024948132556826, 7.379024325749306, 8.520563361656317, 9.526279441628825, 10.435516278555653, 11.271645842555555, 12.049896265113652, 12.780845042484474, 13.472193585307478, 14.129755836531642, 14.758048651498612, 15.360664048145834, 15.940514420808382, 16.499999999999996, 17.041126723312633, 17.56559136493844, 18.07484439767048, 18.570137317747548, 19.05255888325765, 19.523063284228733, 19.982492337043443, 20.431593183107378, 20.871032557111306, 21.30140840414079, 21.72325942394465, 22.137072977247918, 22.54329168511111, 22.942318976075633, 23.334523779156065, 23.720244518132603, 24.099792530227305, 24.473455007415687, 24.841497539399672, 25.204166322257116, 25.561690084968948, 25.91428177665744, 26.262140049889307, 26.605450569385212, 26.944387170614956, 27.27911288880194, 27.60978087562449, 27.936535218240643, 28.259511673063283, 28.57883832488647, 28.894636180440134, 29.207019704173856, 29.516097302997224, 29.82197176579711, 30.124740662784134, 30.424496709066528, 30.721328096291668, 31.015318795717707, 31.306548835666952, 31.595094555959157, 31.881028841616764, 32.16442133786958, 32.44533864825578, 32.723844517415735, 32.99999999999999, 33.273863616959176, 33.545491500349186, 33.81493752766667, 34.082253446625266, 34.347488991191184, 34.610691989615, 34.871908465124186, 35.13118272987688, 35.3885574727199, 35.644073841243234, 35.89777151857758, 36.14968879534096, 36.399862637103446, 36.6483287477069, 36.89512162874653, 37.140274635495096, 37.38382002952614, 37.625789028271555, 37.866211851728714, 38.1051177665153, 38.342535127453424, 38.5784914168504, 38.81301328163017, 39.04612656845747, 39.27785635698567, 39.50822699134953, 39.73726211001457, 39.964984674086885, 40.191416994179235, 40.41658075592243, 40.64049704420456, 40.863186366214755, 41.08466867336281, 41.30496338214089, 41.524089393989115, 41.74206511422261, 41.95890847007343, 42.17463692789779, 42.38926750959493, 42.60281680828158, 42.815301003262846], [0.0, 4.29563732174866, 6.074948559452993, 7.440262092157776, 8.59127464349732, 9.60533705811514, 10.522119558339947, 11.365188075874503, 12.149897118905987, 12.886911965245979, 13.583997938751315, 14.247017231687481, 14.880524184315552, 15.488140624361597, 16.072803115822705, 16.636931808479588, 17.18254928699464, 17.71136640691508, 18.22484567835898, 18.724248983604124, 19.21067411623028, 19.68508318499061, 20.148324992415624, 20.601152880360846, 21.044239116679893, 21.4781866087433, 21.903538526913866, 22.320786276473328, 22.730376151749006, 23.1327149292944, 23.52817459982818, 23.917096395674786, 24.299794237811973, 24.676557701592014, 25.04765458081854, 25.413333114725425, 25.773823930491957, 26.129341744483344, 26.48008685786359, 26.82624647616584, 27.16799587750263, 27.505499450109976, 27.838911616656283, 28.168377660064127, 28.494034463374962, 28.816011174345412, 29.134429803927862, 29.44940576650062, 29.761048368631105, 30.069461252240618, 30.374742797264968, 30.676986488245554, 30.976281248723193, 31.2727117468249, 31.566358675019835, 31.85729900666408, 32.14560623164541, 32.431350573172246, 32.714599187518715, 32.99541634833542, 33.273863616959176, 33.55, 33.823882095347955, 34.09556422762351, 34.36509857398928, 34.632535281148556, 34.89792257427367, 35.16130685853414, 35.42273281383016, 35.68224348327891, 35.939880355949995, 36.19568344430037, 36.44969135671796, 36.70194136554632, 36.95246947092981, 37.20131046078888, 37.44849796720825, 37.69406451949696, 37.938041594157184, 38.18045966197893, 38.42134823246056, 38.660735895737936, 38.89865036219123, 39.13511849988448, 39.37016636998122, 39.60381926026832, 39.83610171691, 40.06703757454499, 40.29664998483125, 40.52496144353501, 40.75199381625395, 40.97776836285743, 41.20230576072169, 41.425626126831204, 41.647749038813615, 41.86869355497016, 42.08847823335979, 42.30712114999082, 42.524639916170955, 42.741051695062446, 42.9563732174866, 43.1706207970189], [0.0, 4.330704330706496, 6.124540799113023, 7.5009999333422215, 8.661408661412992, 9.683749273912456, 10.608015837092251, 11.45796666079981, 12.249081598226047, 12.992112992119488, 13.694889557787604, 14.363321342920655, 15.001999866684443, 15.614576523236229, 16.20401184892186, 16.772745750174593, 17.322817322825983, 17.855951388822717, 18.373622397339073, 18.877102531903567, 19.367498547824912, 19.84578040793559, 20.312803843881326, 20.769328347349127, 21.216031674184503, 21.65352165353248, 22.082345889873206, 22.50299980002666, 22.91593332159962, 23.321556551825612, 23.720244518132606, 24.112341238461266, 24.498163196452094, 24.87800233137701, 25.25212862314779, 25.620792337474654, 25.984225984238975, 26.3426460326217, 26.696254418925513, 27.045239876917343, 27.38977911557521, 27.73003786510217, 28.066171808780762, 28.398327415536283, 28.72664268584131, 29.05124782173736, 29.372265830201115, 29.689813067784716, 30.003999733368886, 30.31493031494547, 30.62270399556512, 30.927415022921007, 31.229153046472458, 31.528003425526332, 31.82404751127675, 32.11736290544415, 32.40802369784372, 32.696100684944064, 32.98166157124289, 33.264771155082364, 33.545491500349186, 33.823882095347955, 34.099999999999994, 34.373899982399436, 34.64563464565197, 34.915254545828525, 35.18280830178284, 35.44834269750844, 35.711902777645435, 35.97353193668923, 36.23327200240133, 36.49116331387641, 36.747244794678146, 37.00155402141915, 37.254127288127414, 37.5049996667111, 37.754205063807134, 38.001776274274334, 38.24774503157016, 38.49214205522993, 38.734997095649824, 38.97633897635846, 39.21619563394695, 39.4545941558141, 39.69156081587118, 39.92712110833938, 40.1612997797631, 40.39412085935279, 40.62560768776265, 40.8557829444009, 41.08466867336281, 41.312286308070625, 41.538656694698254, 41.76380011445318, 41.98773630478309, 42.21048447956976, 42.432063348369006, 42.65249113475085, 42.87178559379117, 43.08996402876197, 43.30704330706496, 43.52303987544988], [0.0, 4.365489663256575, 6.173734688177003, 7.561249896677137, 8.73097932651315, 9.761531642114367, 10.693222152372972, 11.549999999999999, 12.347469376354006, 13.096468989769724, 13.804890437812247, 14.478691239197003, 15.122499793354274, 15.739996823379604, 16.334166645409248, 16.907468763833336, 17.4619586530263, 17.99937498914893, 18.52120406453101, 19.028728281206817, 19.523063284228733, 20.005186827420534, 20.475961515884915, 20.93615294174171, 21.386444304745943, 21.827448316282872, 22.25971697933287, 22.68374969003141, 23.099999999999998, 23.508881300478766, 23.910771631212572, 24.306017773382788, 24.694938752708012, 25.077828853391598, 25.454960223893497, 25.82658514012257, 26.192937979539447, 26.554236950061284, 26.910685609995152, 27.26247420906621, 27.609780875624494, 27.952772671060742, 28.29160652914571, 28.626430095280828, 28.957382478394006, 29.284594926343097, 29.608191434128496, 29.928289292908143, 30.24499958670855, 30.558427642796023, 30.86867344088502, 31.175831985690458, 31.47999364675921, 31.78124446902607, 32.07966645711891, 32.37533783607517, 32.668333290818495, 32.95872418647299, 33.24657877135631, 33.5319623642876, 33.81493752766667, 34.095564227623505, 34.373899982399436, 34.650000000000006, 34.9239173060526, 35.19570286270754, 35.465405679337714, 35.73307291571773, 35.99874997829786, 36.26248061012925, 36.524306974944786, 36.78426973585312, 37.04240812906202, 37.29876003300914, 37.553362033245435, 37.806249483385685, 38.057456562413634, 38.30701632860487, 38.55496077030815, 38.801320853806, 39.04612656845747, 39.28940696930917, 39.53119021734611, 39.771503617540034, 40.01037365484107, 40.24782602824654, 40.48388568307148, 40.71857684153512, 40.95192303176983, 41.183947115350655, 41.41467131343674, 41.64411723160907, 41.87230588348342, 42.09925771317114, 42.32499261665618, 42.54952996215116, 42.772888609491886, 42.99508692862477, 43.216142817239025, 43.436073717591015, 43.654896632565745, 43.8726281410175], [0.0, 4.4, 6.222539674441618, 7.621023553303061, 8.8, 9.838699100999076, 10.777754868245985, 11.641305768684198, 12.445079348883237, 13.2, 13.91402170474087, 14.59314907756376, 15.242047106606122, 15.864425612041554, 16.46329250180534, 17.041126723312633, 17.6, 18.14166475271771, 18.667619023324857, 19.179155351578967, 19.67739820199815, 20.163333057805698, 20.637829343223093, 21.101658702575968, 21.55550973649197, 22.0, 22.435685859808256, 22.86307065990918, 23.282611537368396, 23.694725151391822, 24.099792530227308, 24.498163196452094, 24.890158697766473, 25.276075644767328, 25.656188337319325, 26.03075104563831, 26.4, 26.76415513331217, 27.1234216130635, 27.477991192952956, 27.82804340948174, 28.17374664470454, 28.51525907299459, 28.8527295069288, 29.18629815512752, 29.51609730299722, 29.84225192575118, 30.164880241764596, 30.484094213212245, 30.8, 31.112698372208094, 31.422285085588545, 31.728851224083108, 32.03248351283428, 32.33326460473795, 32.63127334322092, 32.92658500361068, 33.219271515191295, 33.5094016658012, 33.79704129062188, 34.082253446625266, 34.36509857398928, 34.64563464565197, 34.9239173060526, 35.2, 35.473934092513616, 35.745768980398225, 36.01555219623878, 36.28332950543542, 36.54914499683953, 36.81304116749933, 37.07505900197598, 37.335238046649714, 37.593616479397134, 37.850231174987556, 38.105117766515306, 38.35831070315793, 38.609843304525334, 38.85974781184253, 39.10805543618859, 39.3547964039963, 39.6, 39.843694607804636, 40.085907748234916, 40.326666115611395, 40.565995612088706, 40.803921380181094, 41.04046783359079, 41.275658686446185, 41.50951698104905, 41.742065114222605, 41.973324862345606, 42.203317405151935, 42.432063348369006, 42.6595827452637, 42.885895117159436, 43.11101947298394, 43.33497432790287, 43.557777721091334, 43.77944723269128, 44.0, 44.21945273293193], [0.0, 4.434241761564202, 6.270964838045258, 7.680332024072918, 8.868483523128404, 9.91526600752597, 10.861629711972325, 11.731900954235845, 12.541929676090517, 13.302725284692606, 14.022303662380157, 14.706716152833032, 15.360664048145836, 15.987886039123495, 16.59141344189819, 17.173744495595592, 17.736967046256808, 18.282847152454128, 18.812894514135774, 19.328411729886138, 19.83053201505194, 20.320248522102283, 20.79843744130794, 21.265876422099325, 21.72325942394465, 22.17120880782101, 22.610285270203914, 23.040996072218753, 23.46380190847169, 23.879122680701652, 24.287342382401576, 24.68881325620978, 25.083859352181033, 25.472779589200705, 25.85585040179495, 26.233328038966004, 26.605450569385212, 26.9724396375263, 27.33450200753619, 27.69183092538303, 28.044607324760314, 28.393000898108678, 28.737171050748888, 29.07726775334986, 29.413432305666063, 29.745798022577905, 30.074490851883095, 30.399629931958053, 30.72132809629167, 31.039692330949414, 31.354824190226292, 31.666820175066523, 31.97577207824699, 32.28176729982422, 32.584889135916974, 32.88521704352885, 33.18282688379638, 33.47779114577304, 33.77017915261926, 34.06005725186028, 34.347488991191184, 34.632535281148556, 34.915254545828525, 35.19570286270754, 35.473934092513616, 35.74999999999999, 36.02395036638819, 36.29583309417212, 36.565694304908256, 36.83357843055708, 37.09952829888812, 37.36358521341334, 37.62578902827155, 37.886178218447945, 38.14478994567934, 38.40166012036459, 38.656823459772276, 38.91031354281278, 39.16216286161938, 39.41240287016259, 39.66106403010388, 39.90817585407782, 40.15376694657676, 40.397865042598475, 40.640497044204565, 40.88168905512589, 41.121466413541235, 41.359853723145584, 41.59687488261588, 41.832553113574114, 42.066910987140474, 42.299970449162245, 42.53175284419865, 42.762278938335356, 42.99156894089817, 43.2196425251297, 43.4465188478893, 43.6722165684317, 43.896753866316814, 44.120148458499095, 44.34241761564202, 44.56357817770023], [0.0, 4.468221122549778, 6.319018911191831, 7.739186003708659, 8.936442245099556, 9.991246168521723, 10.94486180817282, 11.821801893112571, 12.638037822383662, 13.404663367649334, 14.129755836531642, 14.819412943838229, 15.478372007417319, 16.110400367464493, 16.71855256892773, 17.3053459948075, 17.872884490199112, 18.422947646888648, 18.957056733575495, 19.476524330588354, 19.982492337043446, 20.475961515884915, 20.957814771583415, 21.42883571265597, 21.88972361634564, 22.34110561274889, 22.78354669492878, 23.217558011125977, 23.643603786225142, 24.062107139650095, 24.473455007415687, 24.878002331377008, 25.276075644767324, 25.667976157071678, 26.053982421119425, 26.434352649535413, 26.80932673529867, 27.17912802133284, 27.543964856207612, 27.904031966724812, 28.259511673063283, 28.6105749680079, 28.957382478394006, 29.300085324107844, 29.638825887676457, 29.973738505565162, 30.304950090703006, 30.632580694417506, 30.956744014834637, 31.277547857848447, 31.595094555959157, 31.909481349592635, 32.220800734928986, 32.52914078176674, 32.83458542451846, 33.13721472906255, 33.43710513785546, 33.73432969543044, 34.02895825616765, 34.32105767600993, 34.610691989615, 34.89792257427367, 35.18280830178284, 35.46540567933772, 35.745768980398225, 36.02395036638819, 36.3, 36.57396615080186, 36.845895293777296, 37.11583220136657, 37.38382002952615, 37.649900398274625, 37.91411346715099, 38.176498005972206, 38.437091461243526, 38.695930018543294, 38.95304866117671, 39.20848122536756, 39.46226045223462, 39.71441803677853, 39.96498467408689, 40.213990102948, 40.46146314704895, 40.70743175391933, 40.95192303176983, 41.19496328436281, 41.43657804404219, 41.676792103039794, 41.91562954316683, 42.15311376399138, 42.38926750959492, 42.624112893994635, 42.85767142531194, 43.08996402876196, 43.32101106853348, 43.550832368624135, 43.77944723269128, 44.00687446297454, 44.23313237834282, 44.45823883151469, 44.68221122549778, 44.90506652929044], [0.0, 4.501944024529847, 6.366710296534624, 7.797595783316805, 9.003888049059695, 10.06665286974772, 11.027465710669883, 11.911024305239243, 12.733420593069248, 13.505832073589541, 14.236397016099263, 14.931259156548052, 15.59519156663361, 16.231990019711077, 16.84473211422491, 17.435954232562093, 18.00777609811939, 18.561990733754826, 19.10013088960387, 19.623519052402404, 20.13330573949544, 20.63049926686216, 21.115989202497715, 21.590565069029573, 22.054931421339766, 22.509720122649238, 22.95550043018013, 23.39278734995041, 23.822048610478486, 24.243710524587613, 24.65816294860588, 25.065763503232848, 25.466841186138495, 25.861699480119245, 26.250619040319794, 26.633860028167152, 27.011664147179083, 27.384256425910124, 27.751846785394303, 28.11463142209053, 28.472794032198525, 28.826506899033053, 29.17593186172466, 29.52122118070321, 29.862518313096103, 30.199958609243154, 30.533669939920422, 30.86377326251604, 31.19038313326722, 31.51360817170893, 31.833551482673123, 32.150311040486066, 32.463980039422154, 32.77464721396708, 33.082397132009646, 33.387310463707614, 33.68946422844982, 33.98893202205682, 34.28578422611914, 34.580088201159924, 34.871908465124186, 35.16130685853414, 35.44834269750844, 35.733072915717734, 36.01555219623878, 36.29583309417212, 36.57396615080186, 36.85, 37.12398146750965, 37.395955663681065, 37.66596607018065, 37.93405462114484, 38.20026177920774, 38.46462660679289, 38.727186833024675, 38.98797891658402, 39.24703810480481, 39.504398489282174, 39.7600930582412, 40.014153745893466, 40.26661147899088, 40.51749622076863, 40.76683701245413, 41.01466201250475, 41.26099853372432, 41.50587307839699, 41.74931137156636, 41.99133839257806, 42.23197840499543, 42.47125498498955, 42.70919104829779, 42.945808875837926, 43.181130138059146, 43.41517591810495, 43.64796673385829, 43.87952255893402, 44.10986284267953, 44.33900652924015, 44.56697207574237, 44.793777469644155, 45.019440245298476, 45.243977499773386], [0.0, 4.535416188179427, 6.41404708432983, 7.855571271397136, 9.070832376358855, 10.141498903022176, 11.109455432198287, 11.999583326099286, 12.82809416865966, 13.606248564538278, 14.342245291445828, 15.042273764295079, 15.711142542794272, 16.352675622050356, 16.969973482595663, 17.56559136493844, 18.14166475271771, 18.7, 19.24214125298949, 19.769420831172575, 20.282997806044353, 20.783887990460304, 21.272987566395088, 21.751091926613707, 22.218910864396573, 22.677080940897135, 23.126175645791506, 23.566713814191406, 23.99916665219857, 24.423963642291973, 24.841497539399672, 25.25212862314779, 25.65618833731932, 26.053982421119425, 26.44579361637688, 26.83188401883103, 27.212497129076556, 27.587859648765797, 27.958183059705437, 28.323665017084213, 28.684490582891655, 29.040833321376994, 29.392856274952255, 29.740712836110703, 30.084547528590157, 30.424496709066524, 30.76068919904104, 31.093246855225654, 31.422285085588545, 31.747913317255986, 32.07023542164915, 32.38935010153801, 32.70535124410071, 33.018328243568, 33.32836629659486, 33.63554667312545, 33.939946965191325, 34.24164131580144, 34.540700629836685, 34.837192768648855, 35.13118272987688, 35.42273281383016, 35.711902777645435, 35.99874997829786, 36.28332950543542, 36.56569430490825, 36.845895293777296, 37.12398146750965, 37.4, 37.67399633699616, 37.946014283452755, 38.216096085288456, 38.48428250597898, 38.750612898378776, 39.015125272130035, 39.27785635698568, 39.53884166234515, 39.798115533276196, 40.05571120327288, 40.31166084397913, 40.565995612088706, 40.81874569361484, 41.069940345707835, 41.31960793618449, 41.56777598092061, 41.81447117924606, 42.05971944747135, 42.303545950664706, 42.545975132790176, 42.78703074530879, 43.02673587433748, 43.26511296645369, 43.502183853227415, 43.73796977455629, 43.97249140087471, 44.205768854302256, 44.437821728793146, 44.668669109343305, 44.89832959030882, 45.12682129288524, 45.35416188179427, 45.580368581221464], [0.0, 4.568643124604941, 6.461037068458902, 7.913122013465989, 9.137286249209883, 10.215796591553692, 11.190844472156694, 12.08749353670975, 12.922074136917804, 13.705929373814824, 14.447318090220067, 15.152475045351503, 15.826244026931978, 16.472477045059133, 17.09429729471206, 17.69427873635995, 18.274572498419765, 18.83699816849808, 19.383111205376707, 19.914253689254842, 20.431593183107385, 20.93615294174171, 21.428835712655975, 21.9104427157463, 22.38168894431339, 22.843215623024708, 23.29560044300211, 23.739366040397964, 24.1749870734195, 24.60289617097955, 25.023488965370117, 25.43712837566379, 25.844148273835607, 26.244856638968333, 26.639538284287138, 27.02845722567235, 27.411858747629648, 27.78997121265152, 28.16300765188264, 28.531167168554465, 28.894636180440134, 29.253589523338846, 29.6081914341285, 29.958596429071903, 30.304950090703006, 30.647389774661068, 30.986045246207205, 31.32103925478847, 31.652488053863955, 31.98050187223459, 32.305185342294514, 32.626637889920566, 32.944954090118266, 33.260223992029886, 33.57253341647008, 33.88196422877517, 34.18859458942412, 34.492499184605336, 34.79374943865637, 35.092413710088394, 35.3885574727199, 35.6822434832789, 35.97353193668923, 36.26248061012925, 36.54914499683953, 36.83357843055708, 37.11583220136657, 37.395955663681065, 37.67399633699616, 37.95, 38.22401077856692, 38.49607122811366, 38.766222410753414, 39.03450396764381, 39.30095418688966, 39.56561006732994, 39.828507378509684, 40.08968071711223, 40.349163560103705, 40.60698831482089, 40.86318636621477, 41.11778812144447, 41.37082305200128, 41.62231973352759, 41.87230588348342, 42.12080839680074, 42.367853379655664, 42.613466181478366, 42.85767142531195, 43.100493036623135, 43.3419542706602, 43.582077738446564, 43.8208854314926, 44.05839874530167, 44.29463850174195, 44.52962497034979, 44.76337788862678, 44.99591648138752, 45.227259479212314, 45.45742513605451, 45.686431246049416, 45.91429515956877], [0.0, 4.601630145937416, 6.507687761409578, 7.970257210404193, 9.203260291874832, 10.28955781362834, 11.27164584255556, 12.17476899164826, 13.015375522819156, 13.804890437812247, 14.55163221085525, 15.26188061806277, 15.940514420808386, 16.591413441898194, 17.217723426748382, 17.822036920621613, 18.406520583749664, 18.973007141726377, 19.523063284228733, 20.05804078169152, 20.57911562725668, 21.087318463948897, 21.583558557383444, 22.068642912512768, 22.54329168511112, 23.00815072968708, 23.4638019084717, 23.910771631212576, 24.34953798329652, 24.780536717351385, 25.20416632225712, 25.620792337474654, 26.03075104563831, 26.434352649535416, 26.831884018831033, 27.22361107568208, 27.609780875624494, 27.99062342999884, 28.36635330810078, 28.73717105074889, 29.1032644217105, 29.464809519153526, 29.821971765797112, 30.174906793559444, 30.52376123612554, 30.868673440885015, 31.20977411004444, 31.547186879339975, 31.88102884161677, 32.21141102156191, 32.53843880704789, 32.86221234183725, 33.18282688379639, 33.50037313225034, 33.81493752766668, 34.12660252647486, 34.435446853496764, 34.74154573417827, 35.044971108562784, 35.34579182873119, 35.64407384124323, 35.93988035594999, 36.23327200240133, 36.524306974944786, 36.81304116749933, 37.09952829888811, 37.38382002952614, 37.66596607018065, 37.946014283452755, 38.22401077856692, 38.50000000000001, 38.774024810432046, 39.04612656845747, 39.316345201455334, 39.58471927398248, 39.85128605202096, 40.11608156338304, 40.37914065455084, 40.64049704420457, 40.900183373672064, 41.15823125451336, 41.41467131343674, 41.66953323472679, 41.92284580035091, 42.174636927897794, 42.424933706489156, 42.67376243079581, 42.921148633278676, 43.16711711476689, 43.41169197347645, 43.654896632565745, 43.89675386631681, 44.137285825025536, 44.37651405867748, 44.614459539481146, 44.85114268332524, 45.08658337022224, 45.320800963795875, 45.55381432986705, 45.78564185418831, 46.01630145937416, 46.245810621071406], [0.0, 4.6343823752469975, 6.554006408297141, 8.026985735629534, 9.268764750493995, 10.362794024779225, 11.351872092302663, 12.261423245284373, 13.108012816594282, 13.903147125740992, 14.65520385392165, 15.370507473730333, 16.053971471259068, 16.709503284059643, 17.34027104747789, 17.94888575928879, 18.53752950098799, 19.10804804264423, 19.662019224891424, 20.200804439427657, 20.72558804955845, 21.237408033938607, 21.737180129906456, 22.225717086294427, 22.703744184605327, 23.171911876234986, 23.630806164834922, 24.0809572068886, 24.522846490568746, 24.956912869984546, 25.383557670271518, 25.80314903262778, 26.216025633188565, 26.622499882618087, 27.022860692384143, 27.417375877351937, 27.806294251481983, 28.189847463226897, 28.568251609085216, 28.941708657230315, 29.3104077078433, 29.674526112475668, 30.034230471247305, 30.389677523790866, 30.741014947460666, 31.08838207433767, 31.431910536905008, 31.771724850879597, 32.107942942518136, 32.44067662672898, 32.77003204148571, 33.096110043326846, 33.419006568119286, 33.738812960743005, 34.05561627690798, 34.36949955992959, 34.68054209495578, 34.98881964285163, 35.294404655695786, 35.59736647562569, 35.89777151857758, 36.19568344430037, 36.49116331387641, 36.78426973585312, 37.07505900197598, 37.36358521341334, 37.649900398274625, 37.93405462114484, 38.21609608528846, 38.49607122811366, 38.77402481043205, 39.05, 39.32403844978285, 39.5961803713439, 39.86646460372427, 40.134928678147666, 40.40160887885531, 40.666540300350114, 40.92975690130593, 41.191291555376125, 41.4511760991169, 41.70944137722297, 41.966117285257646, 42.22123281004476, 42.474816067877214, 42.7268943406843, 42.97749411028986, 43.22664109088283, 43.47436025981291, 43.72067588681583, 43.96561156176495, 44.20919022103888, 44.451434172588854, 44.69236511978304, 44.93200418410022, 45.17037192673976, 45.407488369210654, 45.64337301295776, 45.878044858079996, 46.111522421191005, 46.34382375246997, 46.57496645194713], [0.0, 4.666904755831214, 6.6, 8.083316151184489, 9.333809511662428, 10.435516278555653, 11.431535329954592, 12.347469376354006, 13.2, 14.00071426749364, 14.758048651498612, 15.478372007417319, 16.166632302368978, 16.82676439485619, 17.461958653026297, 18.07484439767048, 18.667619023324857, 19.24214125298949, 19.8, 20.342566209797624, 20.871032557111306, 21.38644430474594, 21.88972361634564, 22.381688944313385, 22.863070659909184, 23.33452377915607, 23.796638418062333, 24.249948453553465, 24.694938752708012, 25.1320512493509, 25.56169008496895, 25.984225984238975, 26.4, 26.809326735298672, 27.21249712907656, 27.60978087562449, 28.00142853498728, 28.38767338124067, 28.768733027368448, 29.144810858881897, 29.516097302997224, 29.88277095585348, 30.24499958670855, 30.60294103513582, 30.956744014834637, 31.306548835666952, 31.65248805386395, 31.994687058947775, 32.333264604737955, 32.668333290818495, 33.0, 33.32836629659486, 33.65352878971238, 33.975579465257105, 34.29460598986377, 34.610691989615006, 34.923917306052594, 35.234358231703325, 35.54208772708773, 35.84717562096071, 36.14968879534096, 36.449691356717956, 36.74724479467814, 37.042408129062025, 37.335238046649714, 37.62578902827155, 37.91411346715099, 38.20026177920774, 38.48428250597898, 38.766222410753414, 39.04612656845747, 39.32403844978285, 39.6, 39.874051712862084, 40.14623269996825, 40.41658075592244, 40.68513241959525, 40.95192303176983, 41.216986789429434, 41.48035679692257, 41.74206511422261, 42.002142802480925, 42.260619967056805, 42.517525798192914, 42.77288860949188, 43.02673587433748, 43.2790942603932, 43.529989662300636, 43.77944723269128, 44.02749141161689, 44.274145954495836, 44.519433958665736, 44.76337788862677, 45.00599960005332, 45.247320362646896, 45.48736088189773, 45.72614131981837, 45.9636813147076, 46.2, 46.43511602225196, 46.66904755831214, 46.90181233172126], [0.0, 4.699202059924643, 6.645675285477014, 8.13925672282181, 9.398404119849285, 10.507735245998541, 11.510647245050993, 12.432920011003045, 13.291350570954028, 14.097606179773926, 14.860181694716925, 15.58549004683523, 16.27851344564362, 16.9432139808243, 17.582804099460358, 18.199931318551723, 18.79680823969857, 19.37530644918939, 19.937025856431045, 20.48334689448968, 21.015470491997082, 21.534449145497085, 22.041211400465265, 22.536581373402665, 23.021294490101987, 23.49601029962321, 23.961323001871165, 24.417770168465424, 24.86584002200609, 25.305977554720155, 25.7385897049547, 26.16404976298585, 26.582701141908057, 26.99486062197766, 27.400821155578534, 27.800854303420245, 28.195212359547853, 28.58413021240982, 28.967826980980124, 29.346507458299023, 29.72036338943385, 30.089574606497848, 30.454310039795683, 30.814728621229165, 31.17098009367046, 31.523205737995617, 31.871539027790927, 32.216106220336435, 32.55702689128724, 32.8944144194725, 33.22837642738507, 33.55901518221297, 33.8864279616486, 34.21070738818477, 34.53194173515298, 34.850215207369956, 35.165608198920715, 35.478197530314304, 35.78805666699437, 36.09525592096557, 36.399862637103446, 36.70194136554632, 37.00155402141915, 37.298760033009145, 37.59361647939714, 37.886178218447945, 38.176498005972206, 38.4646266067929, 38.75061289837878, 39.03450396764381, 39.31634520145534, 39.5961803713439, 39.87405171286209, 40.15, 40.424064615028506, 40.69628361410904, 40.96669378897936, 41.235330724998434, 41.50222885580967, 41.767421514860125, 42.030940983994164, 42.29281853932178, 42.55308449454634, 42.81176824192152, 43.06889829099417, 43.32450230527755, 43.57860713698867, 43.83123885997292, 44.08242280093053, 44.33218356905059, 44.58054508415078, 44.827530603413784, 45.07316274680533, 45.31746352125194, 45.56045434365202, 45.80215606278813, 46.04258898020397, 46.281772870105144, 46.5197269983391, 46.7564701405057, 46.99202059924642, 47.226396220757735], [0.0, 4.7312788968734445, 6.6910387833280405, 8.194815434163237, 9.462557793746889, 10.57946123391924, 11.589219128138014, 12.517787344415144, 13.382077566656081, 14.193836690620333, 14.961617559608987, 15.691876879455815, 16.389630868326474, 17.058868661197906, 17.70282463337419, 18.324164373853446, 18.925115587493778, 19.507562636065018, 20.073116349984122, 20.623166585177945, 21.15892246783848, 21.681443678869726, 22.191665102015214, 22.690416479209894, 23.178438256276028, 23.656394484367222, 24.124883419407443, 24.58444630248971, 25.035574688830287, 25.478716608181035, 25.91428177665744, 26.3426460326217, 26.764155133312162, 27.17912802133284, 27.587859648765797, 27.990623429998838, 28.387673381240667, 28.779245994292484, 29.165561883838272, 29.546827240839246, 29.923235119217974, 30.29496657862491, 30.66219170248598, 31.025070507574995, 31.38375375891163, 31.738383701757712, 32.08909472079261, 32.43601393513081, 32.77926173665295, 33.118952278114115, 33.455193916640205, 33.78808961749687, 34.11773732239581, 34.44423028607259, 34.767657384414036, 35.08810339702048, 35.40564926674838, 35.720372338484935, 36.03234657915024, 36.341642780699935, 36.64832874770689, 36.95246947092981, 37.254127288127414, 37.55336203324544, 37.850231174987556, 38.144789945679335, 38.437091461243526, 38.727186833024675, 39.015125272130035, 39.30095418688966, 39.58471927398248, 39.86646460372427, 40.146232699968245, 40.424064615028506, 40.699999999999996, 40.97407717081619, 41.24633317035589, 41.516803826884356, 41.785523809089675, 42.05252667795361, 42.31784493567696, 42.581510071861, 42.84355260713098, 43.10400213437263, 43.36288735773945, 43.62023612957637, 43.87607548539408, 44.13043167701852, 44.38333020403043, 44.63479584360165, 44.88485267882696, 45.13352412564301, 45.38083295841979, 45.6268013343035, 45.871450816384694, 46.11480239576008, 46.356876512552056, 46.5976930759453, 46.83727148329629, 47.07563063836745, 47.312788968734445, 47.54876444241217], [0.0, 4.763139720814413, 6.73609679265374, 8.250000000000002, 9.526279441628827, 10.650704202070397, 11.667261889578036, 12.60208316112856, 13.47219358530748, 14.289419162443236, 15.062370331392069, 15.79754727797958, 16.500000000000004, 17.173744495595596, 17.822036920621617, 18.44756081437326, 19.052558883257653, 19.63892817849284, 20.20829037796122, 20.762044696994565, 21.301408404140794, 21.827448316282876, 22.341105612748894, 22.843215623024705, 23.334523779156072, 23.815698604072065, 24.287342382401583, 24.75, 25.20416632225712, 25.650292395994246, 26.08879069638913, 26.520039592730623, 26.94438717061496, 27.36215452043205, 27.773638580495717, 28.179114606388893, 28.578838324886473, 28.973047820345034, 29.361965193086107, 29.745798022577915, 30.124740662784138, 30.4989753926259, 30.86867344088502, 31.2339959019015, 31.59509455595916, 31.952112606211184, 32.305185342294514, 32.65444073935428, 33.00000000000001, 33.34197804570089, 33.6804839632687, 34.015621411345705, 34.34748899119119, 34.676180585525856, 35.0017856687341, 35.32438959132911, 35.644073841243234, 35.960916284210555, 36.27499138525053, 36.5863704130377, 36.89512162874652, 37.201310460788875, 37.5049996667111, 37.806249483385685, 38.105117766515306, 38.40166012036458, 38.695930018543294, 38.98797891658402, 39.27785635698568, 39.565610067329935, 39.85128605202096, 40.134928678147666, 40.41658075592244, 40.69628361410904, 40.97407717081618, 41.25, 41.52408939398913, 41.79638142231933, 42.06691098714048, 42.3357118754368, 42.60281680828159, 42.868257487329714, 43.13206463873484, 43.39426805466363, 43.65489663256575, 43.913978412346104, 44.17154061157478, 44.42760965885966, 44.68221122549779, 44.935370255512524, 45.1871109941762, 45.43745701511034, 45.68643124604941, 45.934055993347684, 46.180352965303335, 46.42534329436886, 46.669047558312144, 46.91148580038796, 47.15267754857618, 47.39264183393875, 47.63139720814413, 47.86896176020534], [0.0, 4.794788837894742, 6.780855403265875, 8.304817878797827, 9.589577675789483, 10.721473779289862, 11.744786077234446, 12.685818854137876, 13.56171080653175, 14.384366513684224, 15.162453627299247, 15.902515524281059, 16.609635757595655, 17.287857010051884, 17.9404570733301, 18.570137317747545, 19.179155351578967, 19.769420831172575, 20.342566209797624, 20.900000000000006, 21.442947558579725, 21.972482790982003, 22.489553130286964, 22.994999456403562, 23.489572154468892, 23.97394418947371, 24.448721847982164, 24.91445363639348, 25.371637708275752, 25.82072810747211, 26.26214004988931, 26.696254418925513, 27.1234216130635, 27.543964856207616, 27.95818305970544, 28.36635330810078, 28.768733027368448, 29.16556188383828, 29.557063453597692, 29.943446695395643, 30.324907254598493, 30.701628621296305, 31.07378316201618, 31.441533041504194, 31.805031048562117, 32.16442133786958, 32.51984009800787, 32.87141615446466, 33.21927151519131, 33.56352186526319, 33.904277016329374, 34.241641315801445, 34.57571402010377, 34.90658963576936, 35.23435823170333, 35.55910572553816, 35.8809141466602, 36.19986187818954, 36.51602387993524, 36.82947189412306, 37.14027463549509, 37.44849796720825, 37.754205063807134, 38.057456562413634, 38.35831070315793, 38.656823459772276, 38.9530486611767, 39.2470381048048, 39.53884166234515, 39.828507378509684, 40.11608156338304, 40.40160887885531, 40.68513241959525, 40.96669378897936, 41.24633317035589, 41.52408939398913, 41.80000000000001, 42.07410129759162, 42.34642842082436, 42.617015381183144, 42.88589511715945, 43.153099541052676, 43.41865958317922, 43.68260523366252, 43.944965581964006, 44.20576885430226, 44.46504244909703, 44.722812970563474, 44.97910626057393, 45.233947428894595, 45.487360881897736, 45.73937034984194, 45.989998912807124, 46.23926902536415, 46.48720254005397, 46.7338207297456, 46.979144308937784, 47.22319345406451, 47.46598782286113, 47.70754657284318, 47.94788837894742, 48.187031450380935], [0.0, 4.826230413065668, 6.825320505294971, 8.359276284463867, 9.652460826131335, 10.791779278691722, 11.821801893112575, 12.76900544286829, 13.650641010589942, 14.478691239197001, 15.261880618062769, 16.006795431940773, 16.718552568927734, 17.401221221512014, 18.058100675320205, 18.69191001476307, 19.30492165226267, 19.899057766638098, 20.475961515884915, 21.03705064879581, 21.583558557383444, 22.11656618917141, 22.637027189982348, 23.145787953750894, 23.64360378622515, 24.131152065328337, 24.609043053316807, 25.077828853391598, 25.53801088573658, 25.990046171563456, 26.434352649535416, 26.871313700673436, 27.301282021179883, 27.724582954482834, 28.14151737202527, 28.552364175318303, 28.957382478394003, 29.35681351918154, 29.750882339856748, 30.13979926940457, 30.523761236125537, 30.902952933336326, 31.27754785784845, 31.64770923779476, 32.01359086388155, 32.37533783607516, 32.73308723600633, 33.086968733929076, 33.43710513785547, 33.78361289145967, 34.12660252647486, 34.46617907456526, 34.80244244302403, 35.13548775810577, 35.46540567933772, 35.79228268775268, 36.11620135064041, 36.437240565114145, 36.755475782527974, 37.07097921555351, 37.38382002952614, 37.69406451949696, 38.001776274274334, 38.307016328604874, 38.60984330452534, 38.91031354281278, 39.20848122536756, 39.50439848928218, 39.798115533276196, 40.08968071711223, 40.37914065455084, 40.666540300350114, 40.95192303176983, 41.235330724998434, 41.51680382688436, 41.79638142231933, 42.07410129759162, 42.35, 42.62411289399465, 42.896474214088975, 43.16711711476689, 43.43607371759101, 43.70337515570165, 43.969051615880915, 44.23313237834282, 44.495645854397935, 44.75661962212964, 45.01608046020888, 45.274054379964696, 45.53056665581925, 45.785641854188306, 46.03930386094038, 46.29157590750179, 46.54248059568807, 46.79203992133705, 47.04027529681347, 47.2872075724503, 47.532857056987446, 47.777243537064805, 48.02038629582233, 48.26230413065667, 48.50301537018086], [0.0, 4.857468476480316, 6.869497798238238, 8.413382197428097, 9.714936952960633, 10.861629711972327, 11.898319209031168, 12.851653590102716, 13.738995596476476, 14.572405429440948, 15.360664048145837, 16.110400367464493, 16.826764394856195, 17.513851660899725, 18.174982806044138, 18.812894514135778, 19.429873905921266, 20.02785560163644, 20.608493394714717, 21.17321421041218, 21.723259423944654, 22.25971697933287, 22.78354669492878, 23.29560044300211, 23.796638418062336, 24.287342382401583, 24.768326548234953, 25.240146592284287, 25.70330718020543, 26.15826829130706, 26.605450569385216, 27.045239876917343, 27.477991192952953, 27.904031966724816, 28.323665017084217, 28.73717105074889, 29.144810858881897, 29.54682724083925, 29.943446695395643, 30.334880912902896, 30.721328096291675, 31.10297413431713, 31.479993646759212, 31.85255091825457, 32.220800734928986, 32.584889135916974, 32.944954090118266, 33.30112610708533, 33.65352878971239, 34.00227933536222, 34.3474889911912, 34.68926346868726, 35.02770332179945, 35.36290429249273, 35.6949576270935, 36.0239503663882, 36.349965612088276, 36.673082771973235, 36.99337778576053, 37.31092333352259, 37.625789028271555, 37.93804159415718, 38.24774503157016, 38.55496077030815, 38.85974781184253, 39.16216286161938, 39.46226045223462, 39.7600930582412, 40.05571120327288, 40.349163560103705, 40.64049704420457, 40.92975690130593, 41.216986789429434, 41.50222885580966, 41.785523809089675, 42.06691098714048, 42.34642842082436, 42.62411289399464, 42.90000000000001, 43.17412419493881, 43.44651884788931, 43.717216288322845, 43.98624785089086, 44.253643917761174, 44.51943395866574, 44.783646568809026, 45.046309504775195, 45.30744971856174, 45.56709338985756, 45.82526595667503, 46.081992144437514, 46.3372959936162, 46.59120088600422, 46.84372956970869, 47.09490418293683, 47.344746276646156, 47.59327683612467, 47.84051630156181, 48.08648458766768, 48.331201102393486, 48.574684764803166, 48.816954022142774], [0.0, 4.888506929523574, 6.913392799487094, 8.46714237508736, 9.777013859047148, 10.931033802893486, 11.974347581392484, 12.933773617935332, 13.826785598974189, 14.66552078857072, 15.458816254810717, 16.213343270282042, 16.93428475017472, 17.625762394858274, 18.29111806314748, 18.933105925864353, 19.554027718094297, 20.155830421989567, 20.740178398461282, 21.308507690591572, 21.862067605786972, 22.401953039857933, 22.929129944243417, 23.44445563454183, 23.94869516278497, 24.442534647617872, 24.926592225974257, 25.401427125262078, 25.867547235870664, 26.325415476303508, 26.77545517820379, 27.218054669648968, 27.653571197948377, 28.082334304683435, 28.50464874366987, 28.920797015296795, 29.33104157714144, 29.735626780009195, 30.134780569965997, 30.528715990031422, 30.917632509621434, 31.301717205290835, 31.681145812612275, 32.056083665975166, 32.426686540564084, 32.79310140868045, 33.15546712082338, 33.513915020480674, 33.86856950034944, 34.21954850666502, 34.56696399743547, 34.91092235962837, 35.25152478971655, 35.58886764144091, 35.92304274417745, 36.2541376948894, 36.58223612629496, 36.90741795357676, 37.22975960169499, 37.54933421513623, 37.86621185172871, 38.18045966197892, 38.49214205522992, 38.801320853806, 39.10805543618859, 39.41240287016258, 39.71441803677853, 40.014153745893466, 40.31166084397913, 40.60698831482089, 40.90018337367206, 41.19129155537612, 41.480356796922564, 41.76742151486012, 42.05252667795361, 42.3357118754368, 42.617015381183144, 42.896474214088975, 43.174124194938805, 43.45, 43.724135211573945, 43.996562365712165, 44.26731299728955, 44.53641768261116, 44.803906079715865, 45.06980696652694, 45.33414827698873, 45.59695713531771, 45.858259888486835, 46.11808213705336, 46.37644876443215, 46.633383964709225, 46.88891126908366, 47.14305357101935, 47.39583315018315, 47.6472716952398, 47.89739032556994, 48.14620961197258, 48.39374959640966, 48.64002981084614, 48.885069295235745, 49.12888661469951], [0.0, 4.919349550499538, 6.957010852370434, 8.520563361656318, 9.838699100999076, 11.000000000000002, 12.049896265113658, 13.015375522819156, 13.914021704740868, 14.758048651498612, 15.556349186104047, 16.31563667161046, 17.041126723312637, 17.73696704625681, 18.406520583749664, 19.05255888325765, 19.67739820199815, 20.282997806044353, 20.871032557111306, 21.442947558579725, 22.000000000000004, 22.54329168511112, 23.073794659743335, 23.59237164847994, 24.099792530227315, 24.596747752497688, 25.08385935218104, 25.561690084968955, 26.03075104563831, 26.491508073343056, 26.94438717061496, 27.389779115575212, 27.828043409481737, 28.259511673063287, 28.68449058289166, 29.1032644217105, 29.516097302997224, 29.923235119217978, 30.32490725459849, 30.721328096291675, 31.112698372208094, 31.499206339207984, 31.881028841616768, 32.258332256953395, 32.63127334322092, 33.0, 33.36465195382683, 33.72536137686296, 34.08225344662527, 34.435446853496764, 34.785054261852174, 35.13118272987689, 35.47393409251362, 35.81340531141936, 36.149688795340964, 36.48287269390941, 36.81304116749933, 37.14027463549509, 37.46465000503809, 37.78624088209887, 38.1051177665153, 38.42134823246056, 38.73499709564982, 39.04612656845747, 39.3547964039963, 39.66106403010388, 39.96498467408689, 40.26661147899088, 40.565995612088706, 40.86318636621476, 41.15823125451336, 41.4511760991169, 41.74206511422261, 42.030940983994164, 42.31784493567696, 42.60281680828159, 42.88589511715945, 43.16711711476689, 43.44651884788931, 43.724135211573945, 44.00000000000001, 44.274145954495836, 44.5466048088965, 44.8174073324194, 45.08658337022224, 45.35416188179427, 45.62017097732099, 45.884637952151266, 46.14758931948667, 46.40905084140377, 46.66904755831214, 46.92760381694339, 47.18474329695988, 47.44048903626522, 47.69486345509336, 47.947888378947404, 48.19958506045463, 48.44997420019954, 48.69907596659305, 48.94691001483139, 49.193495504995376, 49.43885111933732], [0.0, 4.95, 7.00035713374682, 8.573651497465944, 9.9, 11.06853648862396, 12.124974226776734, 13.096468989769724, 14.00071426749364, 14.85, 15.653274417833478, 16.41729271225923, 17.147302994931888, 17.847478813546747, 18.521204064531013, 19.171267563726712, 19.8, 20.409372846807422, 21.001071401240463, 21.576549770526338, 22.13707297724792, 22.683749690031412, 23.217558011125977, 23.73936604039796, 24.24994845355347, 24.750000000000004, 25.24014659228429, 25.72095449239783, 26.192937979539447, 26.6565657953158, 27.112266596505723, 27.560433596008608, 28.00142853498728, 28.435585100363244, 28.86321187948424, 29.2845949263431, 29.7, 30.10967452497619, 30.513849314696436, 30.912740092072074, 31.306548835666955, 31.695464975292605, 32.07966645711891, 32.4593206952949, 32.83458542451846, 33.20560946587187, 33.57253341647008, 33.935490271985174, 34.294605989863776, 34.650000000000006, 35.00178566873411, 35.35007072128711, 35.694957627093494, 36.03654395193857, 36.374922680330194, 36.710182511123534, 37.042408129062025, 37.37168045459021, 37.69807687402635, 38.021671451949615, 38.342535127453424, 38.660735895737936, 38.97633897635846, 39.28940696930918, 39.6, 39.90817585407782, 40.213990102948, 40.51749622076863, 40.818745693614844, 41.11778812144447, 41.41467131343674, 41.70944137722297, 42.002142802480925, 42.29281853932178, 42.581510071861004, 42.868257487329714, 43.153099541052676, 43.43607371759101, 43.71721628832285, 43.99656236571217, 44.27414595449584, 44.550000000000004, 44.82415643378022, 45.096646216764285, 45.367499380062824, 45.63674506359979, 45.904411552703735, 46.17052631278964, 46.435116022251954, 46.698206603680184, 46.95982325350044, 47.21999047013881, 47.47873208079592, 47.736071266915125, 47.99203058842166, 48.24663200680437, 48.49989690710694, 48.751846118890725, 49.00249993622775, 49.2518781367777, 49.50000000000001, 49.74688432454842], [0.0, 4.98046182597558, 7.043436661176134, 8.62641292774697, 9.96092365195116, 11.136651202224124, 12.199590157050363, 13.177063405782034, 14.086873322352268, 14.941385477926739, 15.74960316960399, 16.51832315944933, 17.25282585549394, 17.957310489045962, 18.63518178070716, 19.2892457084252, 19.92184730390232, 20.53497017285392, 21.130309983528402, 21.70932979158961, 22.27330240444825, 22.823343313371076, 23.360436639754834, 23.885455825669315, 24.399180314100725, 24.9023091298779, 25.395472037353436, 25.879238783240904, 26.35412681156407, 26.820607748520548, 27.27911288880194, 27.73003786510217, 28.173746644704536, 28.6105749680079, 29.040833321376994, 29.464809519153523, 29.882770955853477, 30.29496657862491, 30.7016286212963, 31.10297413431713, 31.49920633920798, 31.8905158315133, 32.27708165246667, 32.65907224646775, 33.03664631889866, 33.40995360667237, 33.779135572125, 34.14432602937127, 34.50565171098788, 34.86323278182906, 35.217183305880674, 35.56761167129444, 35.914620978091925, 36.25830939246893, 36.59877047115108, 36.9360934588378, 37.27036356141432, 37.60166219730186, 37.93006722904668, 38.255653177014246, 38.5784914168504, 38.89865036219123, 39.21619563394695, 39.53119021734611, 39.84369460780464, 40.15376694657676, 40.46146314704895, 40.76683701245413, 41.06994034570784, 41.37082305200128, 41.66953323472679, 41.966117285257646, 42.260619967056805, 42.55308449454634, 42.84355260713099, 43.13206463873484, 43.41865958317922, 43.70337515570165, 43.98624785089086, 44.26731299728956, 44.5466048088965, 44.82415643378022, 45.10000000000001, 45.37416665901425, 45.64668662674215, 45.917589222431964, 46.18690290547744, 46.45465531031309, 46.72087327950967, 46.98558289518179, 47.24880950881197, 47.51057776958727, 47.77091165133863, 48.02983447816576, 48.28736894882554, 48.543537159955704, 48.79836062820145, 49.05186031130727, 49.30405662823294, 49.55496947834799, 49.8046182597558, 50.05302188679522], [0.0, 5.0107384685293646, 7.086254299698818, 8.678853610932725, 10.021476937058729, 11.20435183310485, 12.27375248243177, 13.257167872513342, 14.172508599397636, 15.032215405588092, 15.845346319976727, 16.61873942271194, 17.35770722186545, 18.066474476222528, 18.74846660396524, 19.40650664081508, 20.042953874117458, 20.659803968092245, 21.258762899096457, 21.84130261683126, 22.4087036662097, 22.962088319662914, 23.502446681143645, 24.030657502448825, 24.54750496486354, 25.053692342646823, 25.54985322854126, 26.036560832798173, 26.514335745026685, 26.983652458479376, 27.444944889724226, 27.89861107653927, 28.345017198795272, 28.784501037884954, 29.217374967645537, 29.643928552066104, 30.064430811176184, 30.479132205494302, 30.888266380617736, 31.292051706463738, 31.690692639953454, 32.08438093527753, 32.47329672207613, 32.857609468736456, 33.23747884542388, 33.61305549931454, 33.984481752705896, 34.35189223317982, 34.7154144437309, 35.07516927970555, 35.4312714984941, 35.78383014714887, 36.132948952445055, 36.47872667733895, 36.8212574472953, 37.16063104953951, 37.49693320793048, 37.83024583583881, 38.160647269143645, 38.488212481225986, 38.81301328163016, 39.13511849988447, 39.45459415581409, 39.771503617540034, 40.085907748234916, 40.39786504259847, 40.70743175391933, 41.01466201250474, 41.31960793618449, 41.62231973352759, 41.92284580035091, 42.221232810044754, 42.517525798192914, 42.81176824192151, 43.10400213437262, 43.39426805466363, 43.68260523366252, 43.969051615880915, 44.253643917761174, 44.536417682611166, 44.8174073324194, 45.09664621676428, 45.37416665901425, 45.65, 45.92417663932583, 46.19672607447415, 46.46767693784573, 46.737057031867124, 47.00489336228729, 47.27121216977622, 47.53603895993018, 47.7993985317807, 48.06131500489765, 48.321811845169876, 48.58091188934189, 48.838637368378734, 49.09500992972708, 49.3500506585353, 49.603780097891736, 49.85621826813583, 50.107384685293646, 50.35729837868589], [0.0, 5.040833264451424, 7.128814768248646, 8.73097932651315, 10.081666528902849, 11.271645842555559, 12.34746937635401, 13.336791218280355, 14.257629536497292, 15.122499793354272, 15.940514420808384, 16.71855256892773, 17.4619586530263, 18.174982806044138, 18.861071019430472, 19.52306328422873, 20.163333057805698, 20.783887990460304, 21.38644430474594, 21.972482790982003, 22.543291685111118, 23.100000000000005, 23.643603786225146, 24.1749870734195, 24.69493875270802, 25.204166322257123, 25.703307180205435, 26.192937979539447, 26.67358243656071, 27.14571789435675, 27.609780875624494, 28.066171808780762, 28.515259072994585, 28.957382478394006, 29.392856274952255, 29.82197176579711, 30.244999586708545, 30.66219170248598, 31.073783162016177, 31.479993646759212, 31.881028841616768, 32.27708165246667, 32.6683332908185, 33.054954242896784, 33.43710513785546, 33.81493752766667, 34.18859458942412, 34.55821175929102, 34.9239173060526, 35.285832851159974, 35.644073841243234, 35.998749978297866, 36.349965612088276, 36.697820098747016, 37.042408129062025, 37.38382002952615, 37.722142038860945, 38.05745656241363, 38.38984240655333, 38.71937499495569, 39.04612656845746, 39.37016636998121, 39.69156081587117, 40.01037365484107, 40.326666115611395, 40.640497044204565, 40.95192303176983, 41.26099853372431, 41.56777598092061, 41.87230588348342, 42.174636927897794, 42.474816067877214, 42.77288860949188, 43.06889829099416, 43.36288735773945, 43.65489663256575, 43.944965581964006, 44.23313237834282, 44.51943395866574, 44.803906079715865, 45.086583370222236, 45.36749938006282, 45.64668662674215, 45.92417663932583, 46.20000000000001, 46.47418638341074, 46.74676459392671, 47.017762600957525, 47.28720757245029, 47.55512590667803, 47.82154326242515, 48.08648458766766, 48.349974146839, 48.612035546765576, 48.87269176135074, 49.131965155080046, 49.38987750541604, 49.64645002414574, 49.90170337774053, 50.1556577067832, 50.408332644514246, 50.65974733454561], [0.0, 5.070749451511088, 7.171122645722914, 8.782795682469223, 10.141498903022176, 11.338540470448567, 12.42074876969984, 13.415942009415515, 14.342245291445828, 15.212248354533264, 16.035117710824576, 16.817773336562723, 17.565591364938445, 18.282847152454128, 18.973007141726377, 19.638928178492836, 20.282997806044353, 20.907235589623035, 21.51336793716874, 22.102884427151135, 22.677080940897135, 23.237093191705373, 23.78392314148362, 24.318460066377558, 24.84149753939968, 25.353747257555444, 25.855850401794953, 26.348387047407666, 26.83188401883103, 27.306821492074107, 27.773638580495714, 28.232738088963316, 28.684490582891655, 29.129237889103795, 29.567296122574348, 29.998958315248213, 30.424496709066528, 30.844164764181897, 31.258198924442212, 31.666820175066523, 32.07023542164915, 32.468638714919976, 32.86221234183725, 33.25112780042205, 33.63554667312545, 34.0156214113457, 34.391496041899664, 34.76330680473306, 35.13118272987689, 35.495246160577615, 35.85561322861457, 36.21239428703935, 36.565694304908256, 36.91561322800964, 37.26224630909951, 37.6056844107377, 37.946014283452755, 38.28331882164868, 38.61767729939231, 38.949165587981476, 39.27785635698567, 39.60381926026832, 39.92712110833938, 40.24782602824655, 40.565995612088706, 40.88168905512589, 41.194963284362814, 41.50587307839699, 41.81447117924607, 42.12080839680075, 42.42493370648916, 42.7268943406843, 43.02673587433748, 43.324502305277555, 43.62023612957638, 43.91397841234611, 44.20576885430227, 44.495645854397935, 44.78364656880903, 45.06980696652694, 45.35416188179427, 45.6367450635998, 45.91758922243197, 46.19672607447416, 46.474186383410746, 46.75, 47.024195899557924, 47.296802217486125, 47.56784628296724, 47.837354650941975, 48.10535313247373, 48.37186682359902, 48.636920132755115, 48.90053680686952, 49.16273995619041, 49.423552077931426, 49.68299507879936, 49.94109029646831, 50.1978585200604, 50.45332000968817, 50.70749451511089, 50.96040129355342], [0.0, 5.100490172522638, 7.213182376732201, 8.834308122314956, 10.200980345045275, 11.405042744330247, 12.493598360760604, 13.494628561023827, 14.426364753464402, 15.30147051756791, 16.129166128476697, 16.91641214915267, 17.668616244629913, 18.390078847030537, 19.08428673018722, 19.754113495674765, 20.40196069009055, 21.02985972373568, 21.639547130196604, 22.232521224548513, 22.810085488660494, 23.37338229696336, 23.923419488024702, 24.461091553730796, 24.987196721521208, 25.502450862613188, 26.00749891858116, 26.502924366944868, 26.989257122047654, 27.466980176204306, 27.936535218240646, 28.398327415536286, 28.852729506928803, 29.300085324107847, 29.740712836110706, 30.174906793559444, 30.60294103513582, 31.025070507575002, 31.441533041504197, 31.852550918254572, 32.258332256953395, 32.65907224646775, 33.054954242896784, 33.44615075012369, 33.83282429830534, 34.215128232990736, 34.593207425736054, 34.96719891555514, 35.337232489259826, 35.70343120765846, 36.06591188366101, 36.42478551755659, 36.780157694061074, 37.132128945160154, 37.48079508228181, 37.826247500908686, 38.16857346037444, 38.507856341271456, 38.84417588262107, 39.17760840071788, 39.50822699134953, 39.83610171691, 40.161299779763105, 40.483885683071485, 40.8039213801811, 41.121466413541235, 41.4365780440422, 41.74931137156636, 42.05971944747136, 42.36785337965567, 42.67376243079582, 42.97749411028987, 43.27909426039321, 43.57860713698867, 43.87607548539409, 44.171540611574784, 44.46504244909703, 44.75661962212964, 45.0463095047752, 45.334148276988735, 45.62017097732099, 45.904411552703735, 46.18690290547744, 46.46767693784573, 46.74676459392672, 47.024195899557924, 47.3, 47.574205195673, 47.846838976049405, 48.11792805181869, 48.3874983854301, 48.65557522011223, 48.92218310746159, 49.187345933685016, 49.451086944575856, 49.71342876929733, 49.974393443042416, 50.23400242863394, 50.49227663712541, 50.74923644745802, 51.004901725226375, 51.25929184060194], [0.0, 5.130058479198849, 7.254998277050105, 8.885521931771933, 10.260116958397697, 11.471159488037816, 12.56602562467545, 13.572858947178371, 14.50999655410021, 15.390175437596545, 16.22266932412789, 17.014479128083824, 17.771043863543866, 18.49668889288026, 19.194921203276664, 19.868631055007285, 20.520233916795394, 21.151772975332353, 21.764994831150318, 22.361406485281737, 22.942318976075633, 23.508881300478766, 24.062107139650095, 24.602896170979548, 25.1320512493509, 25.650292395994242, 26.158268291307056, 26.656565795315796, 27.145717894356743, 27.6262103807236, 28.09848750377856, 28.562956779717325, 29.01999310820042, 29.469942314161393, 29.91312420995173, 30.349835254907067, 30.78035087519309, 31.204927495509423, 31.623804325223116, 32.03720493426354, 32.44533864825578, 32.84840178760605, 33.24657877135631, 33.64004310342066, 34.02895825616765, 34.413478464113446, 34.79374943865637, 35.16990901324597, 35.54208772708773, 35.91040935439194, 36.27499138525053, 36.635945463437956, 36.99337778576052, 37.34738946700292, 37.69807687402635, 38.04553193214678, 38.38984240655333, 38.73109216120816, 39.069361397391695, 39.404726873815534, 39.73726211001457, 40.06703757454499, 40.39412085935279, 40.71857684153512, 41.04046783359079, 41.359853723145584, 41.676792103039794, 41.99133839257806, 42.303545950664706, 42.613466181478366, 42.92114863327868, 43.22664109088283, 43.529989662300636, 43.83123885997291, 44.13043167701852, 44.42760965885966, 44.722812970563474, 45.01608046020888, 45.30744971856174, 45.59695713531771, 45.884637952151266, 46.17052631278963, 46.45465531031309, 46.737057031867124, 47.01776260095753, 47.29680221748612, 47.574205195673, 47.85, 48.12421427930019, 48.39687489910892, 48.66800797238367, 48.9376388886918, 49.205792341959096, 49.472492356864336, 49.73776231396021, 50.0016249735946, 50.2641024987018, 50.525216476527845, 50.78498793935074, 51.043437384251476, 51.300584791988484, 51.556449645025026], [0.0, 5.159457335805773, 7.296574538781879, 8.936442245099558, 10.318914671611546, 11.536897329871667, 12.638037822383666, 13.650641010589942, 14.593149077563758, 15.478372007417317, 16.31563667161046, 17.111984104714452, 17.872884490199116, 18.60268797781654, 19.30492165226267, 19.982492337043443, 20.637829343223093, 21.272987566395088, 21.88972361634564, 22.489553130286964, 23.073794659743335, 23.64360378622515, 24.200000000000003, 24.743888134244383, 25.27607564476733, 25.797286679028865, 26.30817363482308, 26.809326735298672, 27.301282021179883, 27.7845280686932, 28.259511673063283, 28.72664268584131, 29.186298155127517, 29.638825887676457, 30.084547528590157, 30.523761236125537, 30.956744014834634, 31.383753758911634, 31.805031048562114, 32.220800734928986, 32.63127334322092, 33.03664631889866, 33.43710513785546, 33.83282429830533, 34.223968209428904, 34.610691989615, 34.99314218529111, 35.37145741978976, 35.74576898039823, 36.11620135064041, 36.4828726939094, 36.8458952937773, 37.20537595563308, 37.561416373720526, 37.91411346715099, 38.2635596880374, 38.60984330452534, 38.9530486611767, 39.29325641888186, 39.630543776234006, 39.964984674086885, 40.29664998483124, 40.62560768776265, 40.95192303176983, 41.275658686446185, 41.59687488261588, 41.91562954316683, 42.231978404995424, 42.545975132790176, 42.85767142531195, 43.16711711476689, 43.47436025981291, 43.77944723269128, 44.08242280093053, 44.38333020403043, 44.68221122549779, 44.97910626057393, 45.27405437996469, 45.56709338985756, 45.858259888486835, 46.14758931948667, 46.435116022251954, 46.72087327950967, 47.0048933622873, 47.2872075724503, 47.56784628296724, 47.8468389760494, 48.12421427930019, 48.400000000000006, 48.674223157642686, 48.946910014831374, 49.218086106633606, 49.487776268488766, 49.75600466275402, 50.02279480396913, 50.288169582914826, 50.55215128953466, 50.81476163478484, 51.076021771473165, 51.33595231414336, 51.59457335805773, 51.85190449732778], [0.0, 5.1886896226311325, 7.337915235269483, 8.987074051102507, 10.377379245262265, 11.602262710350944, 12.70964200912048, 13.727982371783552, 14.675830470538965, 15.566068867893394, 16.408077279193925, 17.208936631878217, 17.974148102205014, 18.708086486864445, 19.41429885419507, 20.095708497089618, 20.75475849052453, 21.393515372654395, 22.01374570580845, 22.6169737144473, 23.204525420701888, 23.777562953339018, 24.337111578821347, 24.88408125689996, 25.41928401824096, 25.94344811315566, 26.457229635772528, 26.961222153307517, 27.455964743567105, 27.941948750937186, 28.419623502080388, 28.88940117067157, 29.35166094107793, 29.8067525906463, 30.25499958684515, 30.696701777226814, 31.132137735786788, 31.561566817887858, 31.985230966807165, 32.403356307641964, 32.81615455838785, 33.22382428318571, 33.6265520087921, 34.02451322208739, 34.417873263756434, 34.80678813105282, 35.191405200702064, 35.57186388144428, 35.94829620441003, 36.32082735841792, 36.689576176347416, 37.054655577943244, 37.41617297372889, 37.77423063412411, 38.12892602736143, 38.48035212936597, 38.82859770839014, 39.17374758687251, 39.51588288270933, 39.85508123188309, 40.191416994179235, 40.52496144353501, 40.8557829444009, 41.18394711535066, 41.50951698104906, 41.832553113574114, 42.153113763991385, 42.47125498498955, 42.78703074530879, 43.10049303662314, 43.41169197347646, 43.72067588681583, 44.0274914116169, 44.33218356905059, 44.63479584360166, 44.93537025551253, 45.2339474288946, 45.53056665581925, 45.82526595667504, 46.118082137053364, 46.409050841403776, 46.698206603680184, 46.9855828951818, 47.27121216977623, 47.555125906678036, 47.837354650941975, 48.11792805181869, 48.39687489910893, 48.67422315764269, 48.94999999999999, 49.22423183758178, 49.49694435013134, 49.76816251379992, 50.03791062784296, 50.30621234002815, 50.57309067083007, 50.83856803648192, 51.102666270949115, 51.365406646886385, 51.62680989563466, 51.88689622631132, 52.14568534404357], [0.0, 5.2177581392778265, 7.379024325749306, 9.037422198835241, 10.435516278555653, 11.667261889578036, 12.780845042484478, 13.804890437812245, 14.758048651498612, 15.653274417833476, 16.5, 17.305345994807503, 18.074844397670482, 18.812894514135778, 19.523063284228733, 20.208290377961216, 20.871032557111306, 21.51336793716874, 22.137072977247918, 22.74368044094887, 23.334523779156072, 23.910771631212576, 24.473455007415687, 25.023488965370117, 25.561690084968955, 26.088790696389133, 26.60545056938522, 27.112266596505723, 27.60978087562449, 28.098487503778564, 28.578838324886476, 29.051247821737363, 29.516097302997224, 29.97373850556517, 30.42449670906653, 30.868673440885015, 31.306548835666952, 31.73838370175772, 32.164421337869584, 32.584889135916974, 33.0, 33.409953606672374, 33.81493752766668, 34.215128232990736, 34.610691989615006, 35.0017856687341, 35.38855747271991, 35.77114759132002, 36.149688795340964, 36.52430697494478, 36.89512162874653, 37.26224630909951, 37.625789028271555, 37.98585262963042, 38.34253512745343, 38.695930018543294, 39.04612656845747, 39.39321007483396, 39.737262110014576, 40.078360744920694, 40.41658075592243, 40.75199381625394, 41.08466867336281, 41.41467131343674, 41.74206511422261, 42.066910987140474, 42.38926750959492, 42.70919104829779, 43.02673587433748, 43.3419542706602, 43.65489663256575, 43.96561156176495, 44.274145954495836, 44.58054508415077, 44.88485267882696, 45.18711099417621, 45.48736088189774, 45.785641854188306, 46.081992144437514, 46.376448764432155, 46.669047558312144, 46.95982325350043, 47.24880950881197, 47.53603895993018, 47.82154326242515, 48.105353132473724, 48.38749838543009, 48.66800797238366, 48.946910014831374, 49.224231837581776, 49.5, 49.77424032569457, 50.04697793074023, 50.318237250523794, 50.588042065294445, 50.856415524494054, 51.12338016993791, 51.38895795791155, 51.65317028024515, 51.91603798442251, 52.177581392778265, 52.437820320833325], [0.0, 5.246665607793202, 7.419905659777623, 9.087491403022069, 10.493331215586403, 11.731900954235849, 12.851653590102718, 13.881372410536358, 14.839811319555245, 15.739996823379602, 16.59141344189819, 17.401221221512014, 18.174982806044138, 18.917121874111825, 19.631225127332222, 20.32024852210228, 20.986662431172807, 21.63255648322685, 22.259716979332868, 22.869685174920974, 23.463801908471698, 24.043242293833835, 24.609043053316803, 25.162124314135323, 25.703307180205435, 26.233328038966008, 26.752850315433687, 27.262474209066205, 27.762744821072715, 28.254158985890914, 28.737171050748888, 29.2121977947569, 29.67962263911049, 30.13979926940457, 30.59305476738144, 31.039692330949414, 31.479993646759205, 31.91422096808882, 32.34261894157615, 32.765416218934256, 33.18282688379638, 33.595051718966, 34.00227933536221, 34.404687180673506, 34.80244244302403, 35.19570286270754, 35.58461746316799, 35.969327210833406, 36.349965612088276, 36.72665925455241, 37.09952829888812, 37.46868692655242, 37.83424374822365, 38.19630217704327, 38.55496077030814, 38.91031354281279, 39.262450254664444, 39.611456676067846, 39.95741483129258, 40.30040322378922, 40.64049704420456, 40.97776836285744, 41.312286308070625, 41.64411723160908, 41.97332486234561, 42.29997044916225, 42.624112893994635, 42.94580887583793, 43.2651129664537, 43.58207773844657, 43.896753866316814, 44.20919022103888, 44.519433958665736, 44.82753060341379, 45.133524125643014, 45.43745701511035, 45.73937034984195, 46.039303860940386, 46.33729599361621, 46.63338396470924, 46.927603816943396, 47.21999047013881, 47.51057776958727, 47.79939853178071, 48.08648458766767, 48.37186682359902, 48.65557522011223, 48.9376388886918, 49.218086106633606, 49.49694435013134, 49.77424032569458, 50.05, 50.324248628270645, 50.59701078127047, 50.868310370996205, 51.138170675142455, 51.40661436041087, 51.67366350472938, 51.93933961844336, 52.203663664536045, 52.466656077932015, 52.72833678393432], [0.0, 5.275414675643992, 7.460562981437795, 9.137286249209884, 10.550829351287984, 11.796185824239972, 12.922074136917807, 13.957435294494472, 14.92112596287559, 15.826244026931974, 16.68232597691341, 17.496571092645556, 18.27457249841977, 19.020778112369644, 19.738794289418998, 20.43159318310738, 21.101658702575968, 21.75109192661371, 22.381688944313385, 22.994999456403566, 23.592371648479944, 24.174987073419505, 24.743888134244386, 25.3, 25.844148273835614, 26.37707337821996, 26.89944237340247, 27.41185874762965, 27.914870588988943, 28.408977454318915, 28.894636180440134, 29.372265830201115, 29.84225192575118, 30.30495009070301, 30.760689199041042, 31.20977411004444, 31.652488053863948, 32.08909472079261, 32.51984009800787, 32.944954090118266, 33.36465195382682, 33.779135572125, 34.18859458942412, 34.593207425736054, 34.99314218529111, 35.3885574727199, 35.77960312803931, 36.16642089010192, 36.54914499683954, 36.92790272950794, 37.30281490718898, 37.67399633699617, 38.04155622473929, 38.40559855021141, 38.766222410753414, 39.123522336313236, 39.477588578837995, 39.828507378509684, 40.17636120904929, 40.5212290040665, 40.86318636621476, 41.20230576072169, 41.538656694698254, 41.87230588348342, 42.203317405151935, 42.53175284419865, 42.85767142531195, 43.181130138059146, 43.50218385322742, 43.8208854314926, 44.13728582502554, 44.451434172588854, 44.76337788862677, 45.07316274680533, 45.380832958419795, 45.686431246049416, 45.98999891280713, 46.291575907501795, 46.59120088600422, 46.888911269083664, 47.18474329695989, 47.47873208079593, 47.77091165133863, 48.06131500489765, 48.34997414683901, 48.636920132755115, 48.92218310746159, 49.205792341959096, 49.48777626848877, 49.76816251379992, 50.04697793074024, 50.324248628270645, 50.6, 50.874256751327586, 51.147042925275755, 51.41838192708907, 51.68829654767123, 51.956808985926, 52.223940870064574, 52.48971327793667, 52.75414675643992, 53.01726134005793], [0.0, 5.304007918546126, 7.500999933342221, 9.186811198669538, 10.608015837092251, 11.860122259066305, 12.992112992119491, 14.033085904390381, 15.001999866684441, 15.912023755638376, 16.772745750174597, 17.591404150891425, 18.373622397339076, 19.123872515785084, 19.84578040793559, 20.542334336681407, 21.216031674184503, 21.86898488727815, 22.502999800026664, 23.11963451268208, 23.72024451813261, 24.30601777338279, 24.878002331377015, 25.437128375663793, 25.984225984238982, 26.52003959273063, 27.04523987691735, 27.56043359600861, 28.066171808780762, 28.562956779717332, 29.051247821737366, 29.531466269049357, 30.003999733368882, 30.469205765821993, 30.92741502292101, 31.378934016311007, 31.824047511276753, 32.263020627337426, 32.69610068494407, 33.123518834809815, 33.54549150034919, 33.962221658778454, 34.37389998239944, 34.78070585827723, 35.18280830178285, 35.58036677719891, 35.973531936689234, 36.36244628734431, 36.74724479467815, 37.12805542982288, 37.50499966671111, 37.878192934721696, 38.24774503157017, 38.61376050062983, 38.97633897635847, 39.33557550106519, 39.69156081587118, 40.04438162838827, 40.394120859352796, 40.740857870202, 41.08466867336281, 41.425626126831204, 41.76380011445318, 42.09925771317115, 42.432063348369006, 42.762278938335356, 43.08996402876197, 43.41517591810495, 43.7379697745563, 44.05839874530167, 44.376514058677486, 44.69236511978305, 45.00599960005333, 45.31746352125194, 45.62680133430351, 45.934055993347684, 46.23926902536416, 46.54248059568807, 46.8437295697087, 47.14305357101936, 47.44048903626522, 47.73607126691513, 48.02983447816576, 48.32181184516988, 48.61203554676558, 48.90053680686952, 49.187345933685016, 49.472492356864336, 49.75600466275403, 50.03791062784296, 50.318237250523794, 50.59701078127047, 50.874256751327586, 51.150000000000006, 51.42426470062553, 51.69707438530733, 51.968451968477964, 52.238419769361336, 52.50699953339555, 52.774212452674284, 53.04007918546126, 53.30461987482887], [0.0, 5.332447843157962, 7.541220060441149, 9.236070593060667, 10.664895686315925, 11.923715863773342, 13.061776295741712, 14.108330872218726, 15.082440120882298, 15.997343529473886, 16.86268068843148, 17.68572870989488, 18.472141186121334, 19.22641412224339, 19.952192861938762, 20.652481691070445, 21.32979137263185, 21.986245700437355, 22.623660181323448, 23.24360127002699, 23.847431727546684, 24.436345880675372, 25.011397401984564, 25.573521462637874, 26.123552591483424, 26.662239215789814, 27.19025560747821, 27.708211779182, 28.216661744437452, 28.716110460854555, 29.20701970417386, 29.689813067784716, 30.164880241764596, 30.63258069441751, 31.093246855225658, 31.54718687933997, 31.994687058947772, 32.43601393513081, 32.87141615446466, 33.30112610708533, 33.72536137686296, 34.14432602937127, 34.55821175929102, 34.96719891555513, 35.37145741978976, 35.771147591320016, 36.16642089010192, 36.55742058734451, 36.94428237224267, 37.32713490210573, 37.70610030220575, 38.08129462085028, 38.45282824448678, 38.820806277046856, 39.18532888722513, 39.546491626944615, 39.904385723877525, 40.25909835055922, 40.610712872344415, 40.959309076203915, 41.30496338214089, 41.64774903881361, 41.98773630478309, 42.32499261665618, 42.6595827452637, 42.99156894089817, 43.32101106853348, 43.64796673385829, 43.97249140087471, 44.29463850174195, 44.61445953948115, 44.93200418410022, 45.247320362646896, 45.56045434365202, 45.871450816384694, 46.180352965303335, 46.48720254005398, 46.79203992133705, 47.09490418293683, 47.39583315018316, 47.69486345509337, 47.99203058842166, 48.28736894882554, 48.58091188934189, 48.872691761350744, 49.1627399561904, 49.45108694457585, 49.73776231396021, 50.02279480396913, 50.30621234002814, 50.588042065294445, 50.868310370996205, 51.14704292527575, 51.42426470062552, 51.7, 51.97427248168078, 52.24710518296685, 52.518520542757116, 52.788540423088044, 53.05718612968465, 53.32447843157963, 53.59043757985189], [0.0, 5.36073688964493, 7.581226813649621, 9.285068658873772, 10.72147377928986, 11.986972094736853, 13.131070024944655, 14.183176654050387, 15.162453627299241, 16.08221066893479, 16.952138508164683, 17.779552862769073, 18.570137317747545, 19.328411729886135, 20.058040781691513, 20.762044696994558, 21.44294755857972, 22.10288442715113, 22.743680440948864, 23.366910364872805, 23.973944189473706, 24.565982577540023, 25.144084791457413, 25.709190963544533, 26.26214004988931, 26.80368444822465, 27.33450200753619, 27.855205976621317, 28.366353308100773, 28.868451638423565, 29.361965193086103, 29.847319812673295, 30.324907254598482, 30.79508889417272, 31.25819892444221, 31.714547135344684, 32.16442133786958, 32.6080894871196, 33.04580154875956, 33.47779114577305, 33.90427701632937, 34.325464308585836, 34.74154573417827, 35.152702598804545, 35.559105725538146, 35.96091628421055, 36.3582865382845, 36.75136051903385, 37.14027463549509, 37.52515822751451, 37.90613406824811, 38.28331882164868, 38.65682345977227, 39.02675364413494, 39.39321007483396, 39.75628881070264, 40.11608156338303, 40.4726759678675, 40.8261558317704, 41.17660136533854, 41.524089393989115, 41.86869355497016, 42.21048447956976, 42.54952996215117, 42.88589511715944, 43.2196425251297, 43.550832368624135, 43.87952255893402, 44.20576885430226, 44.52962497034979, 44.85114268332525, 45.17037192673976, 45.48736088189773, 45.80215606278813, 46.11480239576008, 46.425343294368865, 46.73382072974561, 47.04027529681347, 47.344746276646156, 47.6472716952398, 47.94788837894741, 48.24663200680437, 48.543537159955704, 48.838637368378734, 49.131965155080046, 49.423552077931426, 49.71342876929733, 50.00162497359461, 50.288169582914826, 50.57309067083006, 50.856415524494054, 51.13817067514245, 51.418381927089065, 51.69707438530733, 51.97427248168078, 52.24999999999999, 52.52428009977862, 52.79713533895566, 53.06858769554735, 53.338658588307226, 53.6073688964493, 53.874738978486015], [0.0, 5.388877434122993, 7.6210235533030595, 9.333809511662428, 10.777754868245985, 12.049896265113656, 13.200000000000003, 14.257629536497292, 15.242047106606119, 16.166632302368974, 17.041126723312637, 17.872884490199112, 18.667619023324857, 19.429873905921266, 20.163333057805698, 20.871032557111302, 21.55550973649197, 22.218910864396573, 22.86307065990918, 23.48957215446889, 24.09979253022731, 24.694938752708016, 25.276075644767328, 25.844148273835607, 26.400000000000006, 26.944387170614963, 27.477991192952956, 28.001428534987284, 28.515259072994585, 29.019993108200428, 29.516097302997224, 30.003999733368882, 30.484094213212238, 30.956744014834637, 31.42228508558854, 31.881028841616764, 32.33326460473795, 32.77926173665295, 33.2192715151913, 33.65352878971238, 34.08225344662527, 34.50565171098788, 34.9239173060526, 35.33723248925982, 35.745768980398225, 36.14968879534096, 36.54914499683953, 36.94428237224267, 37.335238046649714, 37.722142038860945, 38.105117766515306, 38.48428250597899, 38.85974781184253, 39.231619900279426, 39.6, 39.96498467408689, 40.326666115611395, 40.68513241959524, 41.04046783359079, 41.39275298889892, 41.742065114222605, 42.08847823335978, 42.432063348369, 42.77288860949188, 43.11101947298394, 43.446518847889294, 43.779447232691275, 44.109862842679526, 44.437821728793146, 44.76337788862677, 45.086583370222236, 45.40748836921065, 45.72614131981836, 46.042588980203966, 46.35687651255205, 46.669047558312144, 46.97914430893778, 47.28720757245029, 47.593276836124666, 47.89739032556994, 48.19958506045462, 48.49989690710693, 48.79836062820144, 49.09500992972708, 49.38987750541603, 49.682995078799344, 49.97439344304241, 50.264102498701796, 50.552151289534656, 50.8385680364819, 51.1233801699379, 51.406614360410856, 51.688296547671214, 51.96845196847796, 52.24710518296684, 52.524280099778615, 52.80000000000001, 53.074287559985216, 53.34716487312143, 53.61865347059735, 53.888774341229926, 54.15754795040116], [0.0, 5.416871790987859, 7.660613552451266, 9.382297160077592, 10.833743581975718, 12.112493550049885, 13.268571889996304, 14.331695642874921, 15.321227104902531, 16.250615372963573, 17.129652652637184, 17.965731268167186, 18.764594320155183, 19.530808995021175, 20.268078349957108, 20.979454235036716, 21.667487163951435, 22.33433455467165, 22.9818406573538, 23.611596727032254, 24.22498710009977, 24.82322501207287, 25.40738081739242, 25.978404492962998, 26.537143779992608, 27.08435895493929, 27.62073496487739, 28.14689148023277, 28.663391285749842, 29.170747333587467, 29.669428710374593, 30.15986571588143, 30.642454209805063, 31.117559351594405, 31.58551883379471, 32.04664569030587, 32.501230745927145, 32.94954476165035, 33.391840320653195, 33.828353492299925, 34.25930530527437, 34.684903055940644, 35.10534147391249, 35.52080376342855, 35.93146253633437, 36.337480650149644, 36.739011962762426, 37.13620201366856, 37.529188640310366, 37.91810253691501, 38.30306776225633, 38.684202201932514, 39.06161799004235, 39.43542189453538, 39.805715669988906, 40.17259638111533, 40.536156699914216, 40.89648517904687, 41.25366650371819, 41.6077817240958, 41.95890847007343, 42.30712114999081, 42.65249113475085, 42.99508692862477, 43.33497432790287, 43.67221656843169, 44.00687446297454, 44.339006529240145, 44.6686691093433, 44.99591648138751, 45.32080096379587, 45.64337301295775, 45.9636813147076, 46.281772870105144, 46.597693075945294, 46.91148580038796, 47.22319345406451, 47.53285705698744, 47.840516301561806, 48.14620961197258, 48.44997420019954, 48.751846118890725, 49.051860311307266, 49.3500506585353, 49.64645002414574, 49.9410902964683, 50.234002428633936, 50.525216476527845, 50.81476163478484, 51.10266627094911, 51.38895795791155, 51.67366350472937, 51.956808985925996, 52.23841976936133, 52.518520542757116, 52.797135338955655, 53.074287559985216, 53.350000000000016, 53.624294867158866, 53.89719380450156, 54.16871790987858, 54.43888775498634], [0.0, 5.444722215136416, 7.699999999999999, 9.430535509715236, 10.889444430272832, 12.17476899164826, 13.336791218280357, 14.405380939079674, 15.399999999999999, 16.334166645409248, 17.217723426748382, 18.058100675320205, 18.861071019430472, 19.631225127332222, 20.37228509519735, 21.087318463948893, 21.778888860545663, 22.449164795154406, 23.1, 23.73299391143056, 24.34953798329652, 24.950851688870266, 25.53801088573658, 26.111970435032283, 26.673582436560714, 27.22361107568208, 27.762744821072722, 28.291606529145707, 28.810761878159347, 29.32072645757605, 29.82197176579711, 30.31493031494547, 30.799999999999997, 31.27754785784845, 31.74791331725599, 32.21141102156191, 32.668333290818495, 33.118952278114115, 33.56352186526319, 34.00227933536221, 34.435446853496764, 34.863232781829055, 35.285832851159974, 35.703431207658454, 36.11620135064041, 36.52430697494478, 36.92790272950794, 37.32713490210573, 37.722142038860945, 38.11305550595491, 38.5, 38.883094012694, 39.262450254664444, 39.638176042799955, 40.01037365484107, 40.37914065455084, 40.7445701903947, 41.106751270320544, 41.46576901493568, 41.82170489112083, 42.17463692789779, 42.52463991617095, 42.87178559379117, 43.216142817239025, 43.55777772109133, 43.89675386631681, 44.233132378342816, 44.56697207574236, 44.89832959030881, 45.227259479212314, 45.553814329867045, 45.87804485807999, 46.2, 46.5197269983391, 46.83727148329629, 47.15267754857618, 47.46598782286112, 47.7772435370648, 48.08648458766767, 48.39374959640966, 48.69907596659304, 49.00249993622774, 49.30405662823294, 49.603780097891736, 49.90170337774053, 50.19785852006039, 50.4922766371254, 50.78498793935074, 51.07602177147316, 51.36540664688638, 51.65317028024514, 51.939339618443356, 52.22394087006457, 52.50699953339554, 52.788540423088044, 53.06858769554735, 53.34716487312143, 53.624294867158866, 53.900000000000006, 54.17430202596062, 54.44722215136416, 54.7187810536748], [0.0, 5.47243090408641, 7.739186003708659, 9.47852836678775, 10.94486180817282, 12.236727503707845, 13.404663367649338, 14.478691239197001, 15.478372007417319, 16.41729271225923, 17.305345994807503, 18.150000000000002, 18.9570567335755, 19.73113022611731, 20.475961515884915, 21.19463375479746, 21.88972361634564, 22.56341064644262, 23.217558011125977, 23.85377328642159, 24.47345500741569, 25.0778288533916, 25.667976157071678, 26.244856638968333, 26.809326735298676, 27.362154520432053, 27.904031966724816, 28.435585100363244, 28.957382478394003, 29.469942314161397, 29.97373850556517, 30.46920576582199, 30.956744014834637, 31.436722157375126, 31.909481349592635, 32.37533783607516, 32.83458542451846, 33.287497653022825, 33.734329695430446, 34.175320042393174, 34.610691989615006, 35.040654959632256, 35.46540567933772, 35.88512923203705, 36.300000000000004, 36.71018251112353, 37.11583220136658, 37.51709610297684, 37.914113467151, 38.307016328604874, 38.6959300185433, 39.08097363167914, 39.46226045223462, 39.8398983432438, 40.21399010294801, 40.58463379162119, 40.95192303176983, 41.31594728431142, 41.6767921030398, 42.034539369428096, 42.38926750959492, 42.741051695062446, 43.08996402876196, 43.43607371759101, 43.77944723269128, 44.120148458499095, 44.458238831514684, 44.793777469644155, 45.12682129288524, 45.45742513605451, 45.78564185418831, 46.111522421191, 46.435116022251954, 46.75647014050569, 47.07563063836745, 47.39264183393874, 47.70754657284318, 48.02038629582232, 48.331201102393486, 48.64002981084614, 48.94691001483138, 49.25187813677769, 49.55496947834799, 49.85621826813583, 50.1556577067832, 50.45332000968816, 50.74923644745801, 51.04343738425147, 51.335952314143356, 51.62680989563465, 51.91603798442251, 52.20366366453604, 52.489713277936666, 52.77421245267428, 53.057186129684645, 53.338658588307226, 53.61865347059735, 53.89719380450156, 54.17430202596062, 54.45000000000001, 54.72430904086411, 54.99724993124657], [0.0, 5.500000000000001, 7.7781745930520225, 9.526279441628827, 11.000000000000002, 12.298373876248846, 13.472193585307481, 14.551632210855248, 15.556349186104045, 16.5, 17.392527130926087, 18.2414363469547, 19.052558883257653, 19.830532015051944, 20.57911562725668, 21.30140840414079, 22.000000000000004, 22.677080940897135, 23.33452377915607, 23.97394418947371, 24.59674775249769, 25.204166322257123, 25.797286679028865, 26.377073378219958, 26.944387170614963, 27.500000000000004, 28.04460732476032, 28.578838324886476, 29.103264421710495, 29.618406439239777, 30.124740662784138, 30.62270399556512, 31.11269837220809, 31.59509455595916, 32.07023542164916, 32.53843880704789, 33.0, 33.45519391664021, 33.904277016329374, 34.34748899119119, 34.785054261852174, 35.217183305880674, 35.644073841243234, 36.065911883661, 36.4828726939094, 36.89512162874653, 37.30281490718898, 37.70610030220575, 38.105117766515306, 38.5, 38.890872965260115, 39.27785635698568, 39.66106403010389, 40.040604391042855, 40.41658075592244, 40.78909167902615, 41.15823125451336, 41.52408939398912, 41.886752082251505, 42.246301613277346, 42.60281680828158, 42.9563732174866, 43.30704330706496, 43.65489663256575, 44.00000000000001, 44.34241761564202, 44.68221122549778, 45.019440245298476, 45.35416188179427, 45.686431246049416, 46.01630145937416, 46.34382375246997, 46.66904755831214, 46.99202059924642, 47.312788968734445, 47.63139720814413, 47.94788837894742, 48.26230413065667, 48.574684764803166, 48.885069295235745, 49.19349550499538, 49.5, 49.8046182597558, 50.107384685293646, 50.408332644514246, 50.70749451511088, 51.00490172522637, 51.300584791988484, 51.59457335805773, 51.886896226311315, 52.177581392778265, 52.46665607793201, 52.754146756439916, 53.04007918546125, 53.32447843157963, 53.6073688964493, 53.888774341229926, 54.16871790987859, 54.447222151364166, 54.72430904086411, 55.00000000000001, 55.27431591616491], [0.0, 5.527431591616491, 7.816968721953543, 9.573792352041067, 11.054863183232982, 12.35971277983433, 13.539386987600292, 14.624209380339165, 15.633937443907087, 16.58229477484947, 17.479273440277776, 18.332416643748857, 19.147584704082135, 19.929438025192784, 20.681755244659485, 21.40765050163142, 22.109726366465964, 22.790184290610732, 23.45090616586063, 24.093515725190468, 24.71942555966866, 25.329873667272807, 25.92595224866389, 26.50863067002896, 27.078773975200583, 27.63715795808245, 28.18448154570171, 28.7213770561232, 29.24841876067833, 29.766130081016584, 30.274989677950348, 30.77543663378312, 31.267874887814173, 31.752677052494334, 32.23018771276395, 32.70072629162845, 33.16458954969894, 33.622053774271436, 34.07337670381379, 34.51879922592906, 34.95854688055555, 35.39283119503158, 35.82185087345432, 36.245792859309894, 36.664833287497714, 37.07913833950298, 37.48886501349435, 37.89416181946766, 38.29516940816427, 38.69202114131543, 39.08484360976772, 39.47375710519586, 39.85887605038557, 40.24030939244877, 40.61816096280087, 40.99252980727099, 41.36351048931897, 41.73119336898959, 42.095664859935404, 42.45700766657962, 42.81530100326284, 43.17062079701889, 43.523039875449875, 43.8726281410175, 44.21945273293193, 44.56357817770023, 44.90506652929044, 45.243977499773386, 45.580368581221464, 45.91429515956877, 46.245810621071406, 46.57496645194713, 46.90181233172126, 47.226396220757735, 47.54876444241217, 47.86896176020534, 48.187031450380935, 48.503015370180854, 48.81695402214277, 49.12888661469951, 49.43885111933732, 49.74688432454841, 50.053021886795214, 50.35729837868589, 50.659747334545614, 50.96040129355341, 51.25929184060194, 51.55644964502502, 51.85190449732778, 52.145685344043564, 52.437820320833325, 52.72833678393431, 53.01726134005792, 53.304619874828866, 53.59043757985188, 53.874738978486015, 54.15754795040117, 54.43888775498634, 54.71878105367481, 54.99724993124658, 55.2743159161649, 55.55000000000001]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"A = 6.0\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.6, 0.848528137423857, 1.0392304845413265, 1.2, 1.341640786499874, 1.469693845669907, 1.5874507866387544, 1.697056274847714, 1.7999999999999998, 1.8973665961010275, 1.9899748742132402, 2.078460969082653, 2.1633307652783937, 2.244994432064365, 2.3237900077244498, 2.4, 2.4738633753705965, 2.545584412271571, 2.6153393661244047, 2.683281572999748, 2.749545416973504, 2.814249455894058, 2.8774989139876324, 2.939387691339814, 3.0, 3.0594117081556713, 3.1176914536239795, 3.1749015732775088, 3.2310988842807027, 3.286335345030997, 3.340658617698013, 3.394112549695428, 3.4467375879228177, 3.498571136907181, 3.5496478698597698, 3.5999999999999996, 3.649657518178932, 3.698648401781386, 3.746998799039039, 3.794733192202055, 3.84187454245971, 3.8884444190447165, 3.9344631145811997, 3.9799497484264803, 4.024922359499621, 4.069397989875161, 4.113392760240626, 4.156921938165306, 4.2, 4.242640687119286, 4.284857057125711, 4.3266615305567875, 4.368065933568311, 4.409081537009721, 4.449719092257398, 4.48998886412873, 4.52990066116245, 4.5694638635183455, 4.608687448721165, 4.6475800154488995, 4.686149805543993, 4.724404724407086, 4.762352359916263, 4.8, 4.8373546489791295, 4.874423042781576, 4.91121166312347, 4.947726750741193, 4.983974317750845, 5.019960159204453, 5.055689863905815, 5.091168824543142, 5.126402247190518, 5.1613951602255765, 5.196152422706632, 5.230678732248809, 5.264978632435274, 5.299056519796709, 5.332916650389354, 5.366563145999496, 5.4, 5.43323108288245, 5.466260147486579, 5.499090833947008, 5.531726674375733, 5.564171097297423, 5.596427431853289, 5.628498911788116, 5.660388679233963, 5.692099788303083, 5.723635208501674, 5.754997827975265, 5.786190456595774, 5.817215828899595, 5.848076606885378, 5.878775382679628, 5.909314681077664, 5.939696961966999, 5.969924622639721, 6.0, 6.029925372672536], [0.0, 0.848528137423857, 1.2, 1.469693845669907, 1.697056274847714, 1.8973665961010278, 2.078460969082653, 2.244994432064365, 2.4, 2.545584412271571, 2.6832815729997477, 2.814249455894058, 2.939387691339814, 3.059411708155671, 3.1749015732775083, 3.2863353450309964, 3.394112549695428, 3.4985711369071804, 3.5999999999999996, 3.6986484017813863, 3.7947331922020555, 3.888444419044716, 3.97994974842648, 4.069397989875162, 4.156921938165306, 4.242640687119285, 4.3266615305567875, 4.409081537009721, 4.48998886412873, 4.569463863518345, 4.6475800154489, 4.724404724407086, 4.8, 4.874423042781577, 4.947726750741193, 5.019960159204453, 5.091168824543142, 5.1613951602255765, 5.230678732248808, 5.299056519796708, 5.366563145999495, 5.43323108288245, 5.499090833947008, 5.564171097297422, 5.628498911788116, 5.692099788303082, 5.754997827975264, 5.817215828899594, 5.878775382679628, 5.939696961966999, 6.0, 6.059702963017247, 6.118823416311342, 6.177378084592201, 6.235382907247958, 6.292853089020909, 6.349803146555017, 6.406246951218787, 6.462197768561405, 6.517668294720129, 6.572670690061993, 6.627216610312357, 6.681317235396026, 6.734983296193095, 6.788225099390856, 6.841052550594827, 6.893475175845634, 6.945502141674135, 6.997142273814361, 7.048404074682438, 7.0992957397195395, 7.149825172687791, 7.199999999999999, 7.249827584156743, 7.299315036357863, 7.348469228349534, 7.397296803562773, 7.445804187594514, 7.493997598078079, 7.541883053985921, 7.589466384404111, 7.636753236814714, 7.683749084919419, 7.730459236035075, 7.776888838089432, 7.823042886243179, 7.868926229162402, 7.914543574963751, 7.95989949685296, 8.0049984384758, 8.049844718999243, 8.094442537939225, 8.138795979750324, 8.182909018191515, 8.226785520481252, 8.270429251254132, 8.313843876330612, 8.357032966310472, 8.399999999999999, 8.442748367682174, 8.48528137423857, 8.527602242131138], [0.0, 1.0392304845413265, 1.4696938456699071, 1.8000000000000003, 2.078460969082653, 2.3237900077244507, 2.5455844122715714, 2.7495454169735045, 2.9393876913398143, 3.117691453623979, 3.286335345030997, 3.4467375879228177, 3.6000000000000005, 3.7469987990390394, 3.8884444190447165, 4.024922359499621, 4.156921938165306, 4.284857057125711, 4.409081537009721, 4.529900661162451, 4.647580015448901, 4.762352359916264, 4.874423042781578, 4.983974317750846, 5.091168824543143, 5.196152422706633, 5.299056519796709, 5.400000000000001, 5.499090833947009, 5.59642743185329, 5.692099788303084, 5.786190456595774, 5.8787753826796285, 5.969924622639721, 6.059702963017248, 6.14817045957576, 6.235382907247958, 6.321392251711645, 6.406246951218788, 6.489992295835182, 6.572670690061994, 6.654321903845652, 6.7349832961930955, 6.814690014960328, 6.893475175845635, 6.9713700231733515, 7.0484040746824395, 7.124605252222751, 7.200000000000001, 7.274613391789286, 7.348469228349535, 7.4215901261117905, 7.493997598078079, 7.565712127751096, 7.636753236814714, 7.707139547199078, 7.776888838089433, 7.8460180983732135, 7.914543574963753, 7.9824808173900434, 8.049844718999243, 8.116649555081212, 8.182909018191515, 8.248636250920514, 8.313843876330612, 8.378544026261364, 8.442748367682174, 8.506468127254696, 8.569714114251422, 8.632496741962896, 8.694826047713665, 8.756711711595855, 8.818163074019441, 8.879189152169246, 8.939798655450804, 9.0, 9.059801322324901, 9.1192104921424, 9.178235124467015, 9.236882591004393, 9.295160030897803, 9.35307436087194, 9.410632284814875, 9.4678403028357, 9.524704719832528, 9.58123165360279, 9.63742704252541, 9.693296652842108, 9.748846085563155, 9.804080783020916, 9.85900603509299, 9.913626985114986, 9.967948635501692, 10.021975853094043, 10.075713374248, 10.12916580968048, 10.182337649086286, 10.235233265539192, 10.287856919689348, 10.340212763768454, 10.392304845413266, 10.444137111317529], [0.0, 1.2, 1.697056274847714, 2.078460969082653, 2.4, 2.683281572999748, 2.939387691339814, 3.1749015732775088, 3.394112549695428, 3.5999999999999996, 3.794733192202055, 3.9799497484264803, 4.156921938165306, 4.3266615305567875, 4.48998886412873, 4.6475800154488995, 4.8, 4.947726750741193, 5.091168824543142, 5.230678732248809, 5.366563145999496, 5.499090833947008, 5.628498911788116, 5.754997827975265, 5.878775382679628, 6.0, 6.118823416311343, 6.235382907247959, 6.3498031465550175, 6.462197768561405, 6.572670690061994, 6.681317235396026, 6.788225099390856, 6.893475175845635, 6.997142273814362, 7.0992957397195395, 7.199999999999999, 7.299315036357864, 7.397296803562772, 7.493997598078078, 7.58946638440411, 7.68374908491942, 7.776888838089433, 7.868926229162399, 7.959899496852961, 8.049844718999243, 8.138795979750322, 8.226785520481252, 8.313843876330612, 8.4, 8.485281374238571, 8.569714114251422, 8.653323061113575, 8.736131867136622, 8.818163074019441, 8.899438184514796, 8.97997772825746, 9.0598013223249, 9.138927727036691, 9.21737489744233, 9.295160030897799, 9.372299611087985, 9.448809448814172, 9.524704719832526, 9.6, 9.674709297958259, 9.748846085563152, 9.82242332624694, 9.895453501482386, 9.96794863550169, 10.039920318408907, 10.11137972781163, 10.182337649086284, 10.252804494381037, 10.322790320451153, 10.392304845413264, 10.461357464497619, 10.529957264870548, 10.598113039593418, 10.665833300778708, 10.733126291998992, 10.8, 10.8664621657649, 10.932520294973157, 10.998181667894016, 11.063453348751466, 11.128342194594847, 11.192854863706579, 11.256997823576231, 11.320777358467925, 11.384199576606166, 11.447270417003349, 11.50999565595053, 11.572380913191548, 11.63443165779919, 11.696153213770756, 11.757550765359255, 11.818629362155328, 11.879393923933998, 11.939849245279442, 12.0, 12.059850745345072], [0.0, 1.3416407864998738, 1.8973665961010278, 2.3237900077244507, 2.6832815729997477, 3.0000000000000004, 3.286335345030997, 3.5496478698597698, 3.7947331922020555, 4.024922359499621, 4.242640687119286, 4.449719092257398, 4.647580015448901, 4.83735464897913, 5.019960159204453, 5.196152422706632, 5.366563145999495, 5.531726674375733, 5.692099788303083, 5.848076606885379, 6.000000000000001, 6.148170459575759, 6.292853089020911, 6.434283176858166, 6.572670690061994, 6.708203932499369, 6.841052550594829, 6.9713700231733515, 7.0992957397195395, 7.224956747275378, 7.348469228349535, 7.46993975879324, 7.589466384404111, 7.707139547199079, 7.82304288624318, 7.937253933193772, 8.049844718999243, 8.160882305241268, 8.270429251254134, 8.378544026261366, 8.485281374238571, 8.590692637965812, 8.694826047713663, 8.797726979169108, 8.899438184514796, 9.0, 9.099450532861862, 9.197825830053535, 9.295160030897803, 9.391485505499118, 9.48683298050514, 9.581231653602789, 9.67470929795826, 9.767292357659825, 9.85900603509299, 9.9498743710662, 10.039920318408907, 10.12916580968048, 10.217631819555843, 10.305338422390601, 10.392304845413264, 10.47854951794379, 10.564090116995406, 10.64894360957931, 10.73312629199899, 10.816653826391969, 10.89954127475097, 10.981803130633876, 11.063453348751466, 11.144505372604026, 11.224972160321826, 11.304866208850063, 11.384199576606166, 11.46298390472568, 11.541230437002808, 11.61895003862225, 11.696153213770758, 11.772850122209151, 11.849050594878902, 11.924764148611075, 12.000000000000002, 12.074767078498866, 12.149074038789953, 12.222929272478018, 12.296340919151518, 12.369316876852984, 12.441864811996634, 12.513992168768526, 12.585706178041821, 12.657013865837392, 12.727922061357857, 12.798437404620927, 12.868566353716332, 12.938315191708698, 13.00769003320728, 13.076696830622021, 13.145341380123988, 13.213629327327148, 13.281566172707192, 13.349157276772196, 13.416407864998739, 13.483323032546544], [0.0, 1.469693845669907, 2.078460969082653, 2.5455844122715714, 2.939387691339814, 3.2863353450309973, 3.6, 3.8884444190447165, 4.156921938165306, 4.40908153700972, 4.6475800154489, 4.874423042781577, 5.091168824543143, 5.299056519796708, 5.499090833947008, 5.692099788303082, 5.878775382679628, 6.059702963017247, 6.235382907247958, 6.406246951218788, 6.572670690061995, 6.734983296193095, 6.893475175845635, 7.0484040746824395, 7.2, 7.3484692283495345, 7.493997598078079, 7.636753236814714, 7.776888838089433, 7.914543574963752, 8.049844718999243, 8.182909018191515, 8.313843876330612, 8.442748367682174, 8.569714114251422, 8.694826047713663, 8.81816307401944, 8.939798655450804, 9.0598013223249, 9.178235124467014, 9.2951600308978, 9.410632284814874, 9.524704719832526, 9.637427042525406, 9.748846085563153, 9.85900603509299, 9.96794863550169, 10.075713374247998, 10.182337649086286, 10.287856919689348, 10.392304845413264, 10.495713410721542, 10.598113039593416, 10.699532700076206, 10.8, 10.89954127475097, 10.998181667894016, 11.095945205344158, 11.19285486370658, 11.288932633336067, 11.384199576606164, 11.478675881825396, 11.572380913191546, 11.665333257134149, 11.757550765359255, 11.849050594878898, 11.939849245279438, 12.029962593458052, 12.119405926034494, 12.208193969625484, 12.296340919151518, 12.383860464330176, 12.470765814495916, 12.55706972187381, 12.642784503423288, 12.727922061357855, 12.812493902437575, 12.896511156122807, 12.979984591670364, 13.062924634246345, 13.14534138012399, 13.227244611029164, 13.308643807691302, 13.389548162652838, 13.46996659238619, 13.549907748763461, 13.62938002992066, 13.708391590555035, 13.78695035169127, 13.865064009949613, 13.942740046346701, 14.019985734657508, 14.096808149364879, 14.173214173221263, 14.249210504445502, 14.324803663575986, 14.4, 14.474805698177786, 14.549226783578568, 14.623269128344731, 14.696938456699069, 14.77024035010941], [0.0, 1.5874507866387544, 2.244994432064365, 2.749545416973504, 3.1749015732775088, 3.54964786985977, 3.8884444190447165, 4.2, 4.48998886412873, 4.762352359916263, 5.019960159204453, 5.264978632435274, 5.499090833947008, 5.723635208501674, 5.939696961966999, 6.148170459575758, 6.3498031465550175, 6.545227268781429, 6.734983296193095, 6.919537556802479, 7.09929573971954, 7.274613391789285, 7.445804187594515, 7.613146524269713, 7.776888838089433, 7.937253933193772, 8.094442537939226, 8.248636250920512, 8.4, 8.548684109265004, 8.694826047713663, 8.838551917593742, 8.97997772825746, 9.1192104921424, 9.256349172324908, 9.391485505499118, 9.524704719832526, 9.65608616365865, 9.785703858180055, 9.913626985114984, 10.039920318408907, 10.16464460765845, 10.287856919689348, 10.409610943738482, 10.529957264870548, 10.648943609579309, 10.766615066955817, 10.883014288330232, 10.998181667894016, 11.112155506471282, 11.224972160321824, 11.336666176614711, 11.447270417003349, 11.556816170554935, 11.665333257134149, 11.77285012220915, 11.879393923933998, 11.984990613262907, 12.089665007765932, 12.193440859740944, 12.296340919151517, 12.398386991863095, 12.499599993599794, 12.6, 12.699606293110035, 12.798437404620925, 12.896511156122806, 12.99384469662463, 13.090454537562858, 13.186356585501546, 13.281566172707194, 13.376098085764772, 13.46996659238619, 13.563185466548779, 13.65576801208925, 13.74772708486752, 13.839075113604958, 13.92982411949268, 14.01998573465751, 14.109571219565817, 14.19859147943908, 14.287057079748791, 14.374978260853128, 14.462364951832738, 14.54922678357857, 14.635573101180563, 14.721412975662359, 14.80675521510368, 14.89160837518903, 14.975980769218422, 15.05988047761336, 15.143315356948756, 15.226293048539427, 15.30882098660769, 15.390906406056793, 15.472556349873152, 15.553777676178866, 15.634577064954462, 15.714961024450552, 15.794935897305821, 15.874507866387544, 15.953682960370001], [0.0, 1.697056274847714, 2.4, 2.939387691339814, 3.394112549695428, 3.7947331922020555, 4.156921938165306, 4.48998886412873, 4.8, 5.091168824543142, 5.366563145999495, 5.628498911788116, 5.878775382679628, 6.118823416311342, 6.349803146555017, 6.572670690061993, 6.788225099390856, 6.997142273814361, 7.199999999999999, 7.397296803562773, 7.589466384404111, 7.776888838089432, 7.95989949685296, 8.138795979750324, 8.313843876330612, 8.48528137423857, 8.653323061113575, 8.818163074019441, 8.97997772825746, 9.13892772703669, 9.2951600308978, 9.448809448814172, 9.6, 9.748846085563153, 9.895453501482386, 10.039920318408907, 10.182337649086284, 10.322790320451153, 10.461357464497617, 10.598113039593416, 10.73312629199899, 10.8664621657649, 10.998181667894016, 11.128342194594843, 11.256997823576231, 11.384199576606164, 11.509995655950528, 11.634431657799189, 11.757550765359255, 11.879393923933998, 12.0, 12.119405926034494, 12.237646832622683, 12.354756169184402, 12.470765814495916, 12.585706178041818, 12.699606293110033, 12.812493902437573, 12.92439553712281, 13.035336589440258, 13.145341380123986, 13.254433220624714, 13.362634470792052, 13.46996659238619, 13.576450198781712, 13.682105101189654, 13.786950351691267, 13.89100428334827, 13.994284547628721, 14.096808149364875, 14.198591479439079, 14.299650345375582, 14.399999999999999, 14.499655168313486, 14.598630072715727, 14.696938456699067, 14.794593607125545, 14.891608375189028, 14.987995196156158, 15.083766107971842, 15.178932768808222, 15.273506473629428, 15.367498169838838, 15.46091847207015, 15.553777676178864, 15.646085772486359, 15.737852458324804, 15.829087149927503, 15.91979899370592, 16.0099968769516, 16.099689437998485, 16.18888507587845, 16.277591959500647, 16.36581803638303, 16.453571040962505, 16.540858502508264, 16.627687752661224, 16.714065932620944, 16.799999999999997, 16.88549673536435, 16.97056274847714, 17.055204484262276], [0.0, 1.7999999999999998, 2.545584412271571, 3.117691453623979, 3.5999999999999996, 4.024922359499622, 4.409081537009721, 4.762352359916263, 5.091168824543142, 5.3999999999999995, 5.692099788303082, 5.96992462263972, 6.235382907247958, 6.48999229583518, 6.734983296193094, 6.97137002317335, 7.199999999999999, 7.421590126111789, 7.636753236814712, 7.846018098373213, 8.049844718999244, 8.248636250920512, 8.442748367682174, 8.632496741962896, 8.818163074019441, 9.0, 9.178235124467014, 9.353074360871938, 9.524704719832526, 9.693296652842108, 9.85900603509299, 10.02197585309404, 10.182337649086284, 10.340212763768452, 10.495713410721542, 10.648943609579309, 10.799999999999999, 10.948972554536796, 11.095945205344156, 11.240996397117117, 11.384199576606164, 11.525623627379128, 11.665333257134149, 11.803389343743598, 11.93984924527944, 12.074767078498864, 12.208193969625484, 12.340178280721878, 12.470765814495916, 12.6, 12.727922061357855, 12.854571171377131, 12.97998459167036, 13.104197800704934, 13.227244611029162, 13.349157276772193, 13.469966592386188, 13.589701983487348, 13.708391590555037, 13.826062346163493, 13.9427400463467, 14.058449416631978, 14.17321417322126, 14.28705707974879, 14.399999999999999, 14.512063946937388, 14.623269128344727, 14.733634989370408, 14.843180252223577, 14.951922953252534, 15.05988047761336, 15.167069591717445, 15.273506473629425, 15.379206741571556, 15.484185480676727, 15.588457268119894, 15.692036196746425, 15.794935897305821, 15.897169559390127, 15.99874995116806, 16.09968943799849, 16.2, 16.29969324864735, 16.398780442459735, 16.497272501841024, 16.5951800231272, 16.69251329189227, 16.789282295559865, 16.88549673536435, 16.981166037701886, 17.076299364909246, 17.17090562550502, 17.264993483925792, 17.35857136978732, 17.451647486698786, 17.544229820656135, 17.636326148038883, 17.72794404323299, 17.819090885900994, 17.90977386791916, 18.0, 18.089776118017607], [0.0, 1.8973665961010275, 2.6832815729997477, 3.286335345030997, 3.794733192202055, 4.242640687119286, 4.6475800154489, 5.019960159204453, 5.366563145999495, 5.692099788303082, 6.0, 6.29285308902091, 6.572670690061994, 6.841052550594828, 7.099295739719539, 7.348469228349534, 7.58946638440411, 7.8230428862431785, 8.049844718999243, 8.270429251254134, 8.485281374238571, 8.694826047713663, 8.899438184514796, 9.099450532861862, 9.2951600308978, 9.486832980505138, 9.67470929795826, 9.85900603509299, 10.039920318408907, 10.21763181955584, 10.392304845413264, 10.564090116995406, 10.73312629199899, 10.899541274750971, 11.063453348751466, 11.224972160321824, 11.384199576606164, 11.541230437002808, 11.696153213770756, 11.8490505948789, 12.0, 12.149074038789953, 12.296340919151518, 12.44186481199663, 12.58570617804182, 12.727922061357855, 12.86856635371633, 13.007690033207279, 13.145341380123988, 13.281566172707194, 13.416407864998739, 13.54990774876346, 13.682105101189656, 13.813037319865607, 13.942740046346701, 14.071247279470288, 14.198591479439077, 14.324803663575986, 14.449913494550756, 14.573949361789342, 14.696938456699067, 14.818906842274163, 14.939879517586478, 15.05988047761336, 15.17893276880822, 15.297058540778353, 15.414279094398154, 15.53061492665374, 15.646085772486357, 15.760710643876436, 15.874507866387544, 15.987495113369073, 16.099689437998485, 16.211107303327555, 16.321764610482532, 16.431676725154983, 16.540858502508268, 16.64932431061393, 16.757088052522732, 16.864163187066236, 16.970562748477143, 17.07629936490925, 17.181385275931625, 17.28583234906552, 17.389652095427326, 17.492855684535904, 17.59545395833822, 17.69745744450315, 17.798876369029593, 17.899720668211557, 18.0, 18.099723754798028, 18.198901065723724, 18.29754081837229, 18.39565166010707, 18.49324200890693, 18.5903200617956, 18.686893802876927, 18.78297101099823, 18.87855926706273, 18.973665961010276, 19.068298298484848], [0.0, 1.98997487421324, 2.814249455894058, 3.4467375879228177, 3.97994974842648, 4.449719092257399, 4.874423042781577, 5.264978632435274, 5.628498911788116, 5.969924622639719, 6.29285308902091, 6.600000000000001, 6.893475175845635, 7.17495644586084, 7.445804187594514, 7.707139547199078, 7.95989949685296, 8.204876598706406, 8.442748367682174, 8.674099376880578, 8.899438184514798, 9.119210492142399, 9.333809511662428, 9.543584232352122, 9.748846085563153, 9.949874371066201, 10.14692071517266, 10.340212763768452, 10.529957264870548, 10.716342659695052, 10.899541274750971, 11.079711187571634, 11.256997823576231, 11.431535329954592, 11.603447763488232, 11.772850122209151, 11.939849245279438, 12.10454460109921, 12.267028980156525, 12.427389106324789, 12.58570617804182, 12.742056348957183, 12.896511156122807, 13.049137902558927, 13.200000000000003, 13.349157276772194, 13.496666255042392, 13.642580401082487, 13.78695035169127, 13.92982411949268, 14.07124727947029, 14.211263138792416, 14.34991289172168, 14.487235761179566, 14.623269128344731, 14.758048651498612, 14.891608375189028, 15.023980830658699, 15.15519712837811, 15.285287043428397, 15.414279094398156, 15.542200616386344, 15.669077828640715, 15.794935897305821, 15.91979899370592, 16.043690348545127, 16.166632302368974, 16.288646352597873, 16.40975319741281, 16.529972776747094, 16.64932431061393, 16.767826334978544, 16.88549673536435, 17.002352778365704, 17.118411141224527, 17.233687939614086, 17.348198753761157, 17.4619586530263, 17.574982219052178, 17.687283567580412, 17.798876369029596, 17.909773867919164, 18.01998890121745, 18.12953391568575, 18.238420984284797, 18.346661821704792, 18.45426779907564, 18.561249957909624, 18.667619023324857, 18.77338541659442, 18.87855926706273, 18.983150423467652, 19.087168464704245, 19.190622710063376, 19.293522228976233, 19.39587585029354, 19.497692171126307, 19.598979565273293, 19.699746191258402, 19.800000000000004, 19.899748742132402, 19.998999974998757], [0.0, 2.078460969082653, 2.9393876913398143, 3.6000000000000005, 4.156921938165306, 4.647580015448901, 5.091168824543143, 5.499090833947009, 5.8787753826796285, 6.235382907247958, 6.572670690061994, 6.893475175845635, 7.200000000000001, 7.493997598078079, 7.776888838089433, 8.049844718999243, 8.313843876330612, 8.569714114251422, 8.818163074019441, 9.059801322324901, 9.295160030897803, 9.524704719832528, 9.748846085563155, 9.967948635501692, 10.182337649086286, 10.392304845413266, 10.598113039593418, 10.800000000000002, 10.998181667894018, 11.19285486370658, 11.384199576606168, 11.572380913191548, 11.757550765359257, 11.939849245279442, 12.119405926034496, 12.29634091915152, 12.470765814495916, 12.64278450342329, 12.812493902437575, 12.979984591670364, 13.145341380123988, 13.308643807691304, 13.469966592386191, 13.629380029920656, 13.78695035169127, 13.942740046346703, 14.096808149364879, 14.249210504445502, 14.400000000000002, 14.549226783578572, 14.69693845669907, 14.843180252223581, 14.987995196156158, 15.131424255502193, 15.273506473629428, 15.414279094398156, 15.553777676178866, 15.692036196746427, 15.829087149927506, 15.964961634780087, 16.099689437998485, 16.233299110162424, 16.36581803638303, 16.497272501841028, 16.627687752661224, 16.75708805252273, 16.88549673536435, 17.01293625450939, 17.139428228502844, 17.264993483925792, 17.38965209542733, 17.51342342319171, 17.636326148038883, 17.758378304338493, 17.87959731090161, 18.0, 18.119602644649802, 18.2384209842848, 18.35647024893403, 18.473765182008787, 18.590320061795605, 18.70614872174388, 18.82126456962975, 18.9356806056714, 19.049409439665055, 19.16246330720558, 19.27485408505082, 19.386593305684215, 19.49769217112631, 19.608161566041833, 19.71801207018598, 19.82725397022997, 19.935897271003384, 20.043951706188086, 20.151426748496, 20.25833161936096, 20.36467529817257, 20.470466531078383, 20.575713839378697, 20.680425527536908, 20.78460969082653, 20.888274222635058], [0.0, 2.1633307652783937, 3.0594117081556713, 3.7469987990390394, 4.3266615305567875, 4.83735464897913, 5.299056519796709, 5.723635208501674, 6.118823416311343, 6.48999229583518, 6.841052550594828, 7.17495644586084, 7.493997598078079, 7.800000000000001, 8.094442537939225, 8.378544026261364, 8.653323061113575, 8.919641248391104, 9.178235124467014, 9.429740187301029, 9.67470929795826, 9.913626985114984, 10.146920715172659, 10.374969879474351, 10.598113039593418, 10.816653826391969, 11.030865786510143, 11.240996397117119, 11.447270417003349, 11.649892703368561, 11.8490505948789, 12.04491593993084, 12.237646832622685, 12.42738910632479, 12.614277624977184, 12.798437404620927, 12.97998459167036, 13.159027319676786, 13.335666462535722, 13.509996299037244, 13.682105101189656, 13.852075656738236, 14.019985734657508, 14.185908501044265, 14.34991289172168, 14.51206394693739, 14.672423112764982, 14.83104851316993, 14.987995196156158, 15.143315356948756, 15.297058540778357, 15.449271827500482, 15.600000000000001, 15.749285698088027, 15.897169559390125, 16.043690348545127, 16.18888507587845, 16.33278910657944, 16.47543626129518, 16.616858908951475, 16.75708805252273, 16.89615340839447, 17.03408347989407, 17.17090562550502, 17.30664612222715, 17.44133022449836, 17.57498221905217, 17.70762547604845, 17.839282496782207, 17.969974958246326, 18.099723754798028, 18.228549037155975, 18.356470248934027, 18.483506160899235, 18.60967490312499, 18.734993995195197, 18.859480374602057, 18.983150423467652, 19.106019993708795, 19.22810443075448, 19.34941859591652, 19.469976887505545, 19.589793260777412, 19.70888124678821, 19.827253970229968, 19.944924166313598, 20.06190419676059, 20.178206064960285, 20.293841430345317, 20.40882162203394, 20.523157651784484, 20.63686022630381, 20.749939758948702, 20.862406380856456, 20.974269951538243, 21.085540068966697, 21.196226079186836, 21.306337085477647, 21.415881957089695, 21.52486933758252, 21.633307652783937, 21.74120511839213], [0.0, 2.244994432064365, 3.1749015732775088, 3.8884444190447165, 4.48998886412873, 5.019960159204453, 5.499090833947008, 5.939696961966999, 6.3498031465550175, 6.734983296193094, 7.099295739719539, 7.445804187594514, 7.776888838089433, 8.094442537939225, 8.399999999999999, 8.694826047713661, 8.97997772825746, 9.256349172324907, 9.524704719832526, 9.785703858180055, 10.039920318408907, 10.287856919689348, 10.529957264870546, 10.766615066955818, 10.998181667894016, 11.224972160321824, 11.447270417003349, 11.665333257134149, 11.879393923933998, 12.08966500776593, 12.296340919151518, 12.499599993599794, 12.699606293110035, 12.896511156122807, 13.090454537562858, 13.281566172707194, 13.469966592386188, 13.65576801208925, 13.839075113604954, 14.019985734657508, 14.198591479439077, 14.374978260853128, 14.54922678357857, 14.721412975662354, 14.891608375189028, 15.059880477613358, 15.226293048539425, 15.390906406056791, 15.553777676178866, 15.714961024450554, 15.874507866387544, 16.032467059064867, 16.18888507587845, 16.343806166251486, 16.497272501841024, 16.649324310613927, 16.799999999999997, 16.949336270190642, 17.09736821853001, 17.244129435839895, 17.389652095427323, 17.53396703544295, 17.67710383518748, 17.819090885900998, 17.95995545651492, 18.099723754798024, 18.238420984284794, 18.376071397336265, 18.512698344649813, 18.648324321504063, 18.782971010998235, 18.916659324521333, 19.04940943966505, 19.181240835774936, 19.312172327317295, 19.44222209522358, 19.57140771636011, 19.699746191258406, 19.82725397022997, 19.95394697797907, 20.079840636817814, 20.204949888579286, 20.3292892153169, 20.452872658871172, 20.575713839378697, 20.697825972792412, 20.81922188747697, 20.939914039938177, 21.059914529741093, 21.17923511366735, 21.297887219158618, 21.415881957089695, 21.533230133911637, 21.649942263202462, 21.766028576660464, 21.881499034572563, 21.996363335788033, 22.110630927225937, 22.224311012942557, 22.337412562783545, 22.44994432064365, 22.561914812355802], [0.0, 2.3237900077244498, 3.2863353450309964, 4.024922359499621, 4.6475800154488995, 5.196152422706632, 5.692099788303082, 6.148170459575758, 6.572670690061993, 6.971370023173349, 7.348469228349534, 7.707139547199078, 8.049844718999243, 8.378544026261364, 8.694826047713661, 8.999999999999998, 9.295160030897799, 9.581231653602787, 9.859006035092989, 10.12916580968048, 10.392304845413264, 10.648943609579309, 10.89954127475097, 11.144505372604026, 11.384199576606164, 11.61895003862225, 11.8490505948789, 12.074767078498864, 12.296340919151517, 12.513992168768524, 12.727922061357855, 12.938315191708694, 13.145341380123986, 13.349157276772194, 13.549907748763458, 13.747727084867519, 13.942740046346698, 14.135062787267696, 14.324803663575985, 14.512063946937388, 14.696938456699067, 14.879516121164693, 15.059880477613358, 15.23811011904035, 15.414279094398156, 15.588457268119894, 15.760710643876436, 15.931101656822102, 16.099689437998485, 16.26653005407115, 16.431676725154983, 16.5951800231272, 16.75708805252273, 16.91744661584602, 17.076299364909246, 17.233687939614082, 17.389652095427323, 17.544229820656135, 17.69745744450315, 17.849369736772218, 17.999999999999996, 18.149380154705007, 18.297540818372283, 18.444511378727277, 18.590320061795598, 18.734993995195193, 18.878559267062727, 19.021040980976828, 19.162463307205574, 19.30284953057449, 19.44222209522358, 19.580602646496864, 19.718012070185978, 19.854470529329156, 19.989997498749215, 20.124611797498105, 20.25833161936096, 20.391174561559716, 20.523157651784487, 20.654297373670207, 20.784609690826528, 20.914110069520053, 21.042813500100216, 21.170734517252818, 21.297887219158618, 21.42428528562855, 21.549941995281564, 21.67487024182613, 21.79908254950194, 21.92259108773413, 22.045407685048602, 22.167543842293398, 22.289010745208053, 22.40981927637972, 22.529980026622304, 22.649503305812246, 22.76839915321233, 22.886677347312784, 23.004347415216973, 23.121418641597234, 23.2379000772445, 23.35380054723428], [0.0, 2.4, 3.394112549695428, 4.156921938165306, 4.8, 5.366563145999496, 5.878775382679628, 6.3498031465550175, 6.788225099390856, 7.199999999999999, 7.58946638440411, 7.959899496852961, 8.313843876330612, 8.653323061113575, 8.97997772825746, 9.295160030897799, 9.6, 9.895453501482386, 10.182337649086284, 10.461357464497619, 10.733126291998992, 10.998181667894016, 11.256997823576231, 11.50999565595053, 11.757550765359255, 12.0, 12.237646832622685, 12.470765814495918, 12.699606293110035, 12.92439553712281, 13.145341380123988, 13.362634470792052, 13.576450198781712, 13.78695035169127, 13.994284547628723, 14.198591479439079, 14.399999999999999, 14.598630072715729, 14.794593607125543, 14.987995196156156, 15.17893276880822, 15.36749816983884, 15.553777676178866, 15.737852458324799, 15.919798993705921, 16.099689437998485, 16.277591959500644, 16.453571040962505, 16.627687752661224, 16.8, 16.970562748477143, 17.139428228502844, 17.30664612222715, 17.472263734273245, 17.636326148038883, 17.798876369029593, 17.95995545651492, 18.1196026446498, 18.277855454073382, 18.43474979488466, 18.590320061795598, 18.74459922217597, 18.897618897628345, 19.04940943966505, 19.2, 19.349418595916518, 19.497692171126303, 19.64484665249388, 19.790907002964772, 19.93589727100338, 20.079840636817814, 20.22275945562326, 20.364675298172568, 20.505608988762074, 20.645580640902306, 20.784609690826528, 20.922714928995237, 21.059914529741096, 21.196226079186836, 21.331666601557416, 21.466252583997985, 21.6, 21.7329243315298, 21.865040589946314, 21.996363335788033, 22.126906697502932, 22.256684389189694, 22.385709727413158, 22.513995647152463, 22.64155471693585, 22.768399153212332, 22.894540834006698, 23.01999131190106, 23.144761826383096, 23.26886331559838, 23.392306427541513, 23.51510153071851, 23.637258724310655, 23.758787847867996, 23.879698490558884, 24.0, 24.119701490690144], [0.0, 2.473863375370596, 3.4985711369071804, 4.28485705712571, 4.947726750741192, 5.531726674375733, 6.059702963017247, 6.545227268781429, 6.997142273814361, 7.421590126111788, 7.8230428862431785, 8.204876598706406, 8.56971411425142, 8.919641248391104, 9.256349172324907, 9.581231653602787, 9.895453501482384, 10.2, 10.49571341072154, 10.783320453366859, 11.063453348751466, 11.336666176614711, 11.60344776348823, 11.864231959971114, 12.119405926034494, 12.369316876852983, 12.614277624977184, 12.854571171377131, 13.090454537562858, 13.32216198670471, 13.549907748763458, 13.773888339898797, 13.994284547628721, 14.211263138792415, 14.424978336205571, 14.635573101180562, 14.843180252223576, 15.047923444781345, 15.249918032566601, 15.44927182750048, 15.646085772486357, 15.840454538932905, 16.032467059064864, 16.222207001514928, 16.40975319741281, 16.595180023127195, 16.778557744931476, 16.959952830123083, 17.13942822850284, 17.317043627594174, 17.492855684535904, 17.66691823720255, 17.839282496782207, 18.009997223764362, 18.17910888905174, 18.346661821704785, 18.512698344649813, 18.677258899528056, 18.8403821617291, 19.002105146535737, 19.162463307205574, 19.32149062572554, 19.479219696897513, 19.635681806344287, 19.79090700296477, 19.94492416631359, 20.09776106933307, 20.249444436823445, 20.4, 20.54945254745245, 20.69782597279241, 20.84514331924825, 20.99142682144308, 21.136697944570244, 21.28097742116184, 21.42428528562855, 21.566640906733717, 21.708063018150654, 21.848569747239754, 21.988178642170435, 22.126906697502932, 22.26477037833537, 22.401785643113364, 22.537967965191537, 22.673332353229423, 22.807893370497858, 22.941665153166195, 23.07466142763529, 23.20689552697646, 23.33838040653207, 23.469128658729534, 23.599152527156562, 23.72846391994223, 23.857074422485255, 23.98499530956802, 24.112237556892143, 24.238811852068988, 24.364728605096346, 24.48999795835026, 24.61462979611922, 24.738633753705965, 24.8620192261208], [0.0, 2.545584412271571, 3.6, 4.409081537009721, 5.091168824543142, 5.692099788303084, 6.235382907247959, 6.734983296193095, 7.2, 7.636753236814712, 8.049844718999243, 8.442748367682174, 8.818163074019441, 9.178235124467014, 9.524704719832526, 9.859006035092989, 10.182337649086284, 10.49571341072154, 10.799999999999999, 11.09594520534416, 11.384199576606168, 11.665333257134149, 11.93984924527944, 12.208193969625485, 12.470765814495918, 12.727922061357855, 12.979984591670362, 13.227244611029162, 13.46996659238619, 13.708391590555035, 13.942740046346701, 14.17321417322126, 14.4, 14.623269128344731, 14.84318025222358, 15.05988047761336, 15.273506473629425, 15.48418548067673, 15.692036196746425, 15.897169559390125, 16.099689437998485, 16.29969324864735, 16.497272501841024, 16.692513291892265, 16.88549673536435, 17.07629936490925, 17.264993483925792, 17.451647486698782, 17.636326148038883, 17.819090885900998, 18.0, 18.179108889051744, 18.356470248934027, 18.532134253776604, 18.706148721743876, 18.878559267062727, 19.04940943966505, 19.21874085365636, 19.38659330568422, 19.553004884160387, 19.718012070185978, 19.88164983093707, 20.04395170618808, 20.204949888579286, 20.364675298172568, 20.523157651784484, 20.6804255275369, 20.836506425022403, 20.99142682144308, 21.145212224047317, 21.297887219158618, 21.449475518063373, 21.599999999999998, 21.74948275247023, 21.897945109073593, 22.045407685048602, 22.19189041068832, 22.337412562783545, 22.481992794234237, 22.625649161957764, 22.768399153212336, 22.91025971044414, 23.051247254758255, 23.191377708105225, 23.330666514268298, 23.469128658729538, 23.606778687487207, 23.743630724891254, 23.87969849055888, 24.014995315427402, 24.149534156997728, 24.283327613817676, 24.41638793925097, 24.548727054574545, 24.68035656144376, 24.8112877537624, 24.941531628991836, 25.071098898931417, 25.2, 25.328245103046523, 25.45584412271571, 25.582806726393418], [0.0, 2.615339366124404, 3.6986484017813863, 4.529900661162451, 5.230678732248808, 5.84807660688538, 6.406246951218788, 6.919537556802479, 7.397296803562773, 7.846018098373213, 8.270429251254134, 8.674099376880578, 9.059801322324901, 9.429740187301027, 9.785703858180055, 10.12916580968048, 10.461357464497617, 10.783320453366859, 11.095945205344158, 11.400000000000002, 11.69615321377076, 11.984990613262909, 12.267028980156526, 12.542726976220127, 12.812493902437575, 13.076696830622023, 13.335666462535725, 13.589701983487352, 13.839075113604958, 14.084033513166604, 14.324803663575988, 14.561593319413918, 14.794593607125545, 15.0239808306587, 15.249918032566605, 15.472556349873154, 15.692036196746425, 15.908488300275426, 16.122034611053284, 16.33278910657944, 16.540858502508268, 16.746342884343438, 16.949336270190642, 17.14992711354774, 17.348198753761157, 17.54422982065614, 17.73809459891338, 17.92986335698072, 18.119602644649802, 18.30737556287083, 18.493242008906932, 18.67725889952806, 18.859480374602054, 19.03995798314692, 19.218740853656364, 19.39587585029354, 19.57140771636011, 19.745379206285204, 19.917831207237402, 20.08880285133985, 20.25833161936096, 20.426453436659045, 20.59320276207662, 20.758612670407434, 20.922714928995234, 21.085540068966697, 21.247117451550928, 21.40747532989353, 21.566640906733717, 21.724640388278008, 21.881499034572567, 22.037241206648353, 22.191890410688316, 22.34546933944329, 22.49799991110321, 22.64950330581225, 22.800000000000004, 22.949509798686336, 23.098051865904196, 23.245644753372623, 23.39230642754152, 23.538054295119643, 23.682905227188666, 23.826875581997736, 23.969981226525817, 24.11223755689215, 24.25365951768929, 24.394261620307347, 24.534057960313053, 24.67306223394251, 24.8112877537624, 24.948747463550152, 25.085453952440254, 25.22141946838045, 25.35665593093853, 25.491174943497604, 25.62498780487515, 25.758105520398825, 25.8905388124697, 26.022298130641733, 26.153393661244046, 26.28383533657142], [0.0, 2.6832815729997477, 3.7947331922020555, 4.647580015448901, 5.366563145999495, 6.000000000000001, 6.572670690061994, 7.0992957397195395, 7.589466384404111, 8.049844718999243, 8.485281374238571, 8.899438184514796, 9.295160030897803, 9.67470929795826, 10.039920318408907, 10.392304845413264, 10.73312629199899, 11.063453348751466, 11.384199576606166, 11.696153213770758, 12.000000000000002, 12.296340919151518, 12.585706178041821, 12.868566353716332, 13.145341380123988, 13.416407864998739, 13.682105101189658, 13.942740046346703, 14.198591479439079, 14.449913494550756, 14.69693845669907, 14.93987951758648, 15.178932768808222, 15.414279094398157, 15.64608577248636, 15.874507866387544, 16.099689437998485, 16.321764610482536, 16.540858502508268, 16.757088052522732, 16.970562748477143, 17.181385275931625, 17.389652095427326, 17.595453958338215, 17.798876369029593, 18.0, 18.198901065723724, 18.39565166010707, 18.590320061795605, 18.782971010998235, 18.97366596101028, 19.162463307205577, 19.34941859591652, 19.53458471531965, 19.71801207018598, 19.8997487421324, 20.079840636817814, 20.25833161936096, 20.435263639111685, 20.610676844781203, 20.784609690826528, 20.95709903588758, 21.12818023399081, 21.29788721915862, 21.46625258399798, 21.633307652783937, 21.79908254950194, 21.963606261267753, 22.126906697502932, 22.289010745208053, 22.449944320643652, 22.609732417700126, 22.768399153212332, 22.92596780945136, 23.082460874005616, 23.2379000772445, 23.392306427541516, 23.545700244418303, 23.698101189757804, 23.84952829722215, 24.000000000000004, 24.14953415699773, 24.298148077579906, 24.445858544956035, 24.592681838303037, 24.73863375370597, 24.88372962399327, 25.027984337537053, 25.171412356083643, 25.314027731674784, 25.455844122715714, 25.596874809241854, 25.737132707432664, 25.876630383417396, 26.01538006641456, 26.153393661244042, 26.290682760247975, 26.427258654654295, 26.563132345414385, 26.698314553544392, 26.832815729997478, 26.966646065093087], [0.0, 2.749545416973504, 3.8884444190447165, 4.762352359916264, 5.499090833947008, 6.14817045957576, 6.7349832961930955, 7.274613391789285, 7.776888838089433, 8.248636250920512, 8.694826047713663, 9.119210492142399, 9.524704719832528, 9.913626985114984, 10.287856919689348, 10.648943609579309, 10.998181667894016, 11.336666176614711, 11.665333257134149, 11.984990613262909, 12.29634091915152, 12.600000000000001, 12.896511156122807, 13.18635658550155, 13.469966592386191, 13.74772708486752, 14.01998573465751, 14.287057079748791, 14.54922678357857, 14.80675521510368, 15.059880477613362, 15.308820986607689, 15.553777676178866, 15.794935897305823, 16.032467059064867, 16.26653005407115, 16.497272501841024, 16.724831837719627, 16.949336270190642, 17.170905625505025, 17.389652095427326, 17.605680901345455, 17.819090885900998, 18.029975041580062, 18.238420984284797, 18.444511378727277, 18.648324321504067, 18.84993368688601, 19.049409439665055, 19.246817918814532, 19.44222209522358, 19.63568180634429, 19.827253970229968, 20.016992781134736, 20.204949888579286, 20.391174561559716, 20.575713839378697, 20.758612670407434, 20.93991403993818, 21.11965908815765, 21.297887219158618, 21.47463620180794, 21.64994226320246, 21.823840175367856, 21.996363335788033, 22.167543842293398, 22.33741256278354, 22.50599920021326, 22.673332353229423, 22.839439572809138, 23.00434741521698, 23.16808149156939, 23.330666514268298, 23.492126340542274, 23.65248401331243, 23.811761799581316, 23.969981226525817, 24.127163115459723, 24.28332761381768, 24.438494225299564, 24.59268183830304, 24.74590875276154, 24.898192705495717, 25.049550894177724, 25.200000000000003, 25.349556209133134, 25.498235233050938, 25.646052327795015, 25.793022312245615, 25.939159585460747, 26.08447814314099, 26.228991593273275, 26.3727131710031, 26.515655752781228, 26.657831869827675, 26.799253720952755, 26.939933184772382, 27.079881831352225, 27.21911093331301, 27.3576314764272, 27.49545416973504, 27.6325894552067], [0.0, 2.814249455894058, 3.97994974842648, 4.874423042781577, 5.628498911788116, 6.292853089020911, 6.8934751758456345, 7.445804187594514, 7.95989949685296, 8.442748367682173, 8.899438184514796, 9.333809511662428, 9.748846085563153, 10.146920715172659, 10.529957264870546, 10.89954127475097, 11.256997823576231, 11.60344776348823, 11.93984924527944, 12.267028980156525, 12.585706178041821, 12.896511156122807, 13.200000000000001, 13.496666255042394, 13.786950351691269, 14.07124727947029, 14.34991289172168, 14.623269128344731, 14.891608375189028, 15.155197128378108, 15.414279094398156, 15.669077828640715, 15.91979899370592, 16.166632302368978, 16.409753197412815, 16.64932431061393, 16.885496735364345, 17.118411141224527, 17.348198753761153, 17.574982219052174, 17.798876369029593, 18.01998890121745, 18.238420984284797, 18.454267799075637, 18.667619023324857, 18.878559267062727, 19.08716846470424, 19.293522228976233, 19.497692171126307, 19.699746191258406, 19.899748742132402, 20.097761069333075, 20.293841430345317, 20.48804529475665, 20.680425527536904, 20.871032557111302, 21.059914529741093, 21.247117451550928, 21.432685319390107, 21.616660241582185, 21.79908254950194, 21.979990900817043, 22.159422375143265, 22.337412562783545, 22.513995647152463, 22.689204481426845, 22.86307065990918, 23.03562458454296, 23.20689552697646, 23.376911686533788, 23.545700244418303, 23.713287414443407, 23.87969849055888, 24.044957891416654, 24.209089202198417, 24.372115213907882, 24.53405796031305, 24.694938752708016, 24.85477821264958, 25.013596302811, 25.171412356083643, 25.328245103046523, 25.484112697914362, 25.639032743065794, 25.793022312245615, 25.94609797252759, 26.098275805117858, 26.24957142507283, 26.400000000000002, 26.549576267805104, 26.69831455354439, 26.846228785436512, 26.993332510084787, 27.139638906956744, 27.285160802164977, 27.429910681589906, 27.573900703382538, 27.717142709882637, 27.859648238985358, 28.001428534987287, 28.14249455894058, 28.282856998542428], [0.0, 2.877498913987632, 4.069397989875161, 4.983974317750846, 5.754997827975264, 6.434283176858166, 7.0484040746824395, 7.6131465242697125, 8.138795979750322, 8.632496741962894, 9.099450532861862, 9.54358423235212, 9.967948635501692, 10.37496987947435, 10.766615066955817, 11.144505372604026, 11.509995655950528, 11.864231959971114, 12.208193969625484, 12.542726976220125, 12.868566353716332, 13.186356585501548, 13.496666255042394, 13.800000000000004, 14.096808149364879, 14.38749456993816, 14.672423112764983, 14.951922953252536, 15.226293048539425, 15.49580588417395, 15.760710643876438, 16.021235907382426, 16.277591959500644, 16.529972776747098, 16.77855774493148, 17.02351315093333, 17.26499348392579, 17.50314257497779, 17.73809459891338, 17.969974958246326, 18.198901065723724, 18.42498303934091, 18.648324321504067, 18.869022232219663, 19.08716846470424, 19.302849530574495, 19.516147160748712, 19.727138667328315, 19.935897271003384, 20.142492397913426, 20.346989949375807, 20.549452547452454, 20.7499397589487, 20.948508300115314, 21.145212224047317, 21.340103092534488, 21.533230133911633, 21.724640388278008, 21.914378841299612, 22.102488547672635, 22.289010745208053, 22.473984960393654, 22.65744910619905, 22.839439572809138, 23.019991311901055, 23.199137915017445, 23.376911686533788, 23.553343711668624, 23.72846391994223, 23.902301144450508, 24.074883177286658, 24.246236821412104, 24.416387939250967, 24.585361498257456, 24.753181613683523, 24.919871588754226, 25.08545395244025, 25.24995049500098, 25.413382301456853, 25.57576978313654, 25.737132707432664, 25.89749022588869, 26.05686090073016, 26.215262729944172, 26.372713171003095, 26.529229163320977, 26.68482714952451, 26.83952309561405, 26.993332510084787, 27.14627046207269, 27.298351598585583, 27.4495901608749, 27.60000000000001, 27.749594591633233, 27.89838705015041, 28.046390142048587, 28.193616298729758, 28.340077628686913, 28.485785929126127, 28.630752697056366, 28.77498913987632, 28.918506185486144], [0.0, 2.939387691339814, 4.156921938165306, 5.091168824543143, 5.878775382679628, 6.572670690061995, 7.2, 7.776888838089433, 8.313843876330612, 8.81816307401944, 9.2951600308978, 9.748846085563153, 10.182337649086286, 10.598113039593416, 10.998181667894016, 11.384199576606164, 11.757550765359255, 12.119405926034494, 12.470765814495916, 12.812493902437575, 13.14534138012399, 13.46996659238619, 13.78695035169127, 14.096808149364879, 14.4, 14.696938456699069, 14.987995196156158, 15.273506473629428, 15.553777676178866, 15.829087149927505, 16.099689437998485, 16.36581803638303, 16.627687752661224, 16.88549673536435, 17.139428228502844, 17.389652095427326, 17.63632614803888, 17.87959731090161, 18.1196026446498, 18.356470248934027, 18.5903200617956, 18.821264569629747, 19.04940943966505, 19.274854085050812, 19.497692171126307, 19.71801207018598, 19.93589727100338, 20.151426748495997, 20.36467529817257, 20.575713839378697, 20.784609690826528, 20.991426821443085, 21.196226079186832, 21.399065400152413, 21.6, 21.79908254950194, 21.996363335788033, 22.191890410688316, 22.38570972741316, 22.577865266672134, 22.76839915321233, 22.95735176365079, 23.144761826383093, 23.330666514268298, 23.51510153071851, 23.698101189757796, 23.879698490558877, 24.059925186916104, 24.238811852068988, 24.416387939250967, 24.592681838303037, 24.767720928660353, 24.941531628991832, 25.11413944374762, 25.285569006846575, 25.45584412271571, 25.62498780487515, 25.793022312245615, 25.95996918334073, 26.12584926849269, 26.29068276024798, 26.454489222058328, 26.617287615382605, 26.779096325305677, 26.93993318477238, 27.099815497526922, 27.25876005984132, 27.41678318111007, 27.57390070338254, 27.730128019899226, 27.885480092693403, 28.039971469315017, 28.193616298729758, 28.346428346442526, 28.498421008891004, 28.649607327151973, 28.8, 28.94961139635557, 29.098453567157136, 29.246538256689462, 29.393876913398138, 29.54048070021882], [0.0, 3.0, 4.242640687119286, 5.196152422706633, 6.0, 6.70820393249937, 7.348469228349535, 7.937253933193772, 8.485281374238571, 9.0, 9.486832980505138, 9.949874371066201, 10.392304845413266, 10.816653826391969, 11.224972160321824, 11.61895003862225, 12.0, 12.369316876852983, 12.727922061357855, 13.076696830622023, 13.41640786499874, 13.74772708486752, 14.07124727947029, 14.387494569938163, 14.69693845669907, 15.000000000000002, 15.297058540778357, 15.588457268119898, 15.874507866387544, 16.155494421403514, 16.431676725154986, 16.703293088490067, 16.970562748477143, 17.23368793961409, 17.492855684535904, 17.74823934929885, 18.0, 18.248287590894662, 18.49324200890693, 18.734993995195197, 18.973665961010276, 19.20937271229855, 19.44222209522358, 19.672315572906, 19.899748742132402, 20.12461179749811, 20.346989949375807, 20.566963801203133, 20.78460969082653, 21.000000000000004, 21.213203435596427, 21.424285285628553, 21.633307652783937, 21.84032966784156, 22.045407685048605, 22.24859546128699, 22.44994432064365, 22.64950330581225, 22.84731931759173, 23.043437243605826, 23.2379000772445, 23.430749027719965, 23.62202362203543, 23.811761799581316, 24.0, 24.186773244895647, 24.372115213907882, 24.55605831561735, 24.738633753705965, 24.919871588754226, 25.09980079602227, 25.278449319529077, 25.45584412271571, 25.632011235952596, 25.806975801127884, 25.98076211353316, 26.153393661244046, 26.32489316217637, 26.495282598983547, 26.66458325194677, 26.83281572999748, 27.000000000000004, 27.166155414412252, 27.331300737432898, 27.49545416973504, 27.65863337187867, 27.820855486487115, 27.982137159266447, 28.14249455894058, 28.301943396169815, 28.460498941515414, 28.61817604250837, 28.774989139876325, 28.930952282978872, 29.086079144497976, 29.24038303442689, 29.39387691339814, 29.54657340538832, 29.698484809834994, 29.849623113198604, 30.000000000000004, 30.149626863362677], [0.0, 3.059411708155671, 4.3266615305567875, 5.299056519796709, 6.118823416311342, 6.84105255059483, 7.493997598078079, 8.094442537939226, 8.653323061113575, 9.178235124467012, 9.67470929795826, 10.146920715172659, 10.598113039593418, 11.030865786510143, 11.447270417003347, 11.8490505948789, 12.237646832622683, 12.614277624977184, 12.979984591670362, 13.335666462535723, 13.68210510118966, 14.019985734657508, 14.34991289172168, 14.672423112764983, 14.987995196156158, 15.297058540778355, 15.600000000000003, 15.897169559390127, 16.188885075878453, 16.47543626129518, 16.757088052522732, 17.03408347989407, 17.30664612222715, 17.574982219052174, 17.83928249678221, 18.099723754798028, 18.356470248934023, 18.60967490312499, 18.859480374602054, 19.10601999370879, 19.34941859591652, 19.589793260777412, 19.827253970229968, 20.061904196760583, 20.293841430345317, 20.523157651784484, 20.749939758948702, 20.974269951538243, 21.196226079186836, 21.4158819570897, 21.633307652783937, 21.848569747239754, 22.061731573020285, 22.272853431924705, 22.481992794234237, 22.689204481426845, 22.894540834006694, 23.098051865904193, 23.299785406737122, 23.499787233079367, 23.6981011897578, 23.894769302087855, 24.089831879861677, 24.283327613817676, 24.475293665245367, 24.66576574931336, 24.854778212649574, 25.042364105651046, 25.22855524995437, 25.413382301456846, 25.596874809241854, 25.779061270729002, 25.959969183340725, 26.13962509295036, 26.318054639353573, 26.49528259898354, 26.671332925071447, 26.846228785436516, 27.01999259807449, 27.192646064699186, 27.36421020237932, 27.534705373401042, 27.704151313476473, 27.872567158408643, 28.039971469315017, 28.206382256503588, 28.37181700208854, 28.536292681425877, 28.69982578344336, 28.862432329933668, 29.02412789387478, 29.184927616836745, 29.344846225529967, 29.503898047546198, 29.662097026339865, 29.819456735494025, 29.975990392312315, 30.131710870775333, 30.28663071389751, 30.44076214551798, 30.59411708155671, 30.746707140765505], [0.0, 3.117691453623979, 4.409081537009721, 5.4, 6.235382907247958, 6.9713700231733515, 7.636753236814714, 8.248636250920512, 8.818163074019441, 9.353074360871936, 9.85900603509299, 10.340212763768452, 10.8, 11.240996397117117, 11.665333257134149, 12.074767078498864, 12.470765814495916, 12.854571171377131, 13.227244611029162, 13.589701983487352, 13.942740046346703, 14.28705707974879, 14.623269128344731, 14.951922953252538, 15.273506473629428, 15.588457268119896, 15.897169559390127, 16.200000000000003, 16.497272501841024, 16.789282295559868, 17.07629936490925, 17.35857136978732, 17.636326148038883, 17.909773867919164, 18.179108889051744, 18.444511378727277, 18.706148721743872, 18.964176755134933, 19.21874085365636, 19.469976887505545, 19.71801207018598, 19.962965711536953, 20.204949888579286, 20.444070044880984, 20.680425527536904, 20.914110069520053, 21.145212224047317, 21.37381575666825, 21.6, 21.823840175367856, 22.045407685048605, 22.26477037833537, 22.481992794234234, 22.697136383253287, 22.91025971044414, 23.121418641597234, 23.330666514268298, 23.53805429511964, 23.743630724891258, 23.947442452170126, 24.149534156997728, 24.34994866524363, 24.54872705457454, 24.745908752761537, 24.941531628991832, 25.135632078784095, 25.32824510304652, 25.519404381764087, 25.709142342754262, 25.897490225888685, 26.08447814314099, 26.270135134787566, 26.454489222058324, 26.63756745650774, 26.819395966352413, 27.0, 27.179403966974704, 27.357631476427198, 27.534705373401046, 27.71064777301318, 27.885480092693406, 28.059223082615816, 28.231896854444624, 28.4035209085071, 28.57411415949758, 28.74369496080837, 28.912281127576225, 29.079889958526323, 29.246538256689462, 29.412242349062748, 29.577018105278974, 29.740880955344952, 29.903845906505076, 30.065927559282127, 30.227140122744, 30.38749742904144, 30.547012947258857, 30.705699796617573, 30.863570759068043, 31.02063829130536, 31.176914536239792, 31.332411333952585], [0.0, 3.1749015732775088, 4.48998886412873, 5.499090833947008, 6.3498031465550175, 7.09929573971954, 7.776888838089433, 8.4, 8.97997772825746, 9.524704719832526, 10.039920318408907, 10.529957264870548, 10.998181667894016, 11.447270417003349, 11.879393923933998, 12.296340919151517, 12.699606293110035, 13.090454537562858, 13.46996659238619, 13.839075113604958, 14.19859147943908, 14.54922678357857, 14.89160837518903, 15.226293048539427, 15.553777676178866, 15.874507866387544, 16.188885075878453, 16.497272501841024, 16.8, 17.097368218530008, 17.389652095427326, 17.677103835187484, 17.95995545651492, 18.2384209842848, 18.512698344649817, 18.782971010998235, 19.04940943966505, 19.3121723273173, 19.57140771636011, 19.827253970229968, 20.079840636817814, 20.3292892153169, 20.575713839378697, 20.819221887476964, 21.059914529741096, 21.297887219158618, 21.533230133911633, 21.766028576660464, 21.996363335788033, 22.224311012942565, 22.44994432064365, 22.673332353229423, 22.894540834006698, 23.11363234110987, 23.330666514268298, 23.5457002444183, 23.758787847867996, 23.969981226525814, 24.179330015531864, 24.386881719481888, 24.592681838303033, 24.79677398372619, 24.99919998719959, 25.2, 25.39921258622007, 25.59687480924185, 25.79302231224561, 25.98768939324926, 26.180909075125715, 26.37271317100309, 26.563132345414388, 26.752196171529544, 26.93993318477238, 27.126370933097558, 27.3115360241785, 27.49545416973504, 27.678150227209915, 27.85964823898536, 28.03997146931502, 28.219142439131634, 28.39718295887816, 28.574114159497583, 28.749956521706256, 28.924729903665476, 29.09845356715714, 29.271146202361127, 29.442825951324718, 29.61351043020736, 29.78321675037806, 29.951961538436844, 30.11976095522672, 30.286630713897512, 30.452586097078854, 30.61764197321538, 30.781812812113586, 30.945112699746304, 31.107555352357732, 31.269154129908923, 31.429922048901105, 31.589871794611643, 31.74901573277509, 31.907365920740002], [0.0, 3.2310988842807027, 4.5694638635183455, 5.596427431853289, 6.462197768561405, 7.224956747275378, 7.914543574963752, 8.548684109265006, 9.138927727036691, 9.693296652842108, 10.21763181955584, 10.716342659695053, 11.192854863706579, 11.64989270336856, 12.08966500776593, 12.513992168768526, 12.92439553712281, 13.322161986704712, 13.708391590555035, 14.084033513166606, 14.449913494550756, 14.80675521510368, 15.15519712837811, 15.495805884173953, 15.829087149927505, 16.155494421403514, 16.47543626129518, 16.789282295559868, 17.09736821853001, 17.400000000000002, 17.697457444503154, 17.989997220677942, 18.277855454073382, 18.561249957909627, 18.8403821617291, 19.11543878648879, 19.386593305684215, 19.654007224991044, 19.9178312072374, 20.178206064960285, 20.43526363911168, 20.689127579480004, 20.93991403993818, 21.18773229961149, 21.432685319390107, 21.674870241826135, 21.914378841299612, 22.15129793036968, 22.385709727413158, 22.61769218996492, 22.847319317591726, 23.074661427635295, 23.29978540673712, 23.522754940695194, 23.743630724891258, 23.96247065725903, 24.17933001553186, 24.394261620307347, 24.60731598529186, 24.818541455935723, 25.027984337537053, 25.235689013775712, 25.441698056537028, 25.646052327795015, 25.84879107424562, 26.049952015310893, 26.24957142507283, 26.44768420864103, 26.644323973409424, 26.83952309561405, 27.033312782565147, 27.225723130892227, 27.41678318111007, 27.60652096878562, 27.79496357256113, 27.982137159266447, 28.168067026333212, 28.352777641705586, 28.536292681425884, 28.71863506505837, 28.899826989101513, 29.079889958526326, 29.258844816567866, 29.43671177288659, 29.61351043020736, 29.789259809535388, 29.963978374041062, 30.137684051698468, 30.31039425675622, 30.482125910113293, 30.652895458667523, 30.822718893699175, 30.991611768347905, 31.15958921423709, 31.326665957295873, 31.492856332825703, 31.65817429985501, 31.822633454822693, 31.986247044628414, 32.14902797908516, 32.31098884280703, 32.47214190656355], [0.0, 3.2863353450309964, 4.6475800154489, 5.692099788303083, 6.572670690061993, 7.3484692283495345, 8.049844718999243, 8.694826047713663, 9.2951600308978, 9.859006035092989, 10.392304845413264, 10.89954127475097, 11.384199576606166, 11.849050594878898, 12.296340919151517, 12.727922061357853, 13.145341380123986, 13.549907748763458, 13.9427400463467, 14.324803663575986, 14.696938456699069, 15.059880477613358, 15.414279094398156, 15.760710643876438, 16.099689437998485, 16.431676725154983, 16.75708805252273, 17.07629936490925, 17.389652095427326, 17.69745744450315, 18.0, 18.297540818372287, 18.5903200617956, 18.87855926706273, 19.162463307205574, 19.44222209522358, 19.718012070185978, 19.98999749874922, 20.258331619360956, 20.523157651784484, 20.784609690826528, 21.04281350010022, 21.297887219158618, 21.54994199528156, 21.79908254950194, 22.045407685048602, 22.289010745208053, 22.5299800266223, 22.768399153212332, 23.004347415216976, 23.2379000772445, 23.469128658729538, 23.698101189757796, 23.924882444852265, 24.149534156997728, 24.37211521390788, 24.592681838303033, 24.811287753762397, 25.027984337537053, 25.24282076155515, 25.455844122715707, 25.667099563448925, 25.876630383417385, 26.084478143140988, 26.29068276024797, 26.495282598983536, 26.69831455354438, 26.89981412575187, 27.099815497526915, 27.29835159858558, 27.49545416973504, 27.69115382211438, 27.8854800926934, 28.078461496314215, 28.27012557453539, 28.46049894151541, 28.649607327151973, 28.837475617675, 29.02412789387478, 29.209587467131403, 29.393876913398138, 29.57701810527897, 29.759032242329386, 29.939939879699153, 30.119760955226717, 30.298514815086236, 30.476220238080707, 30.65289545866752, 30.82855818879631, 31.00322563863315, 31.17691453623979, 31.349641146271512, 31.521421287752876, 31.69227035098622, 31.86220331364421, 32.03123475609393, 32.19937887599697, 32.36664950222683, 32.533060108142294, 32.69862382425291, 32.863353450309965, 33.02726146685493], [0.0, 3.340658617698013, 4.724404724407087, 5.786190456595773, 6.681317235396026, 7.469939758793241, 8.182909018191515, 8.838551917593742, 9.448809448814174, 10.02197585309404, 10.564090116995406, 11.079711187571634, 11.572380913191546, 12.044915939930839, 12.499599993599794, 12.938315191708694, 13.362634470792052, 13.773888339898797, 14.17321417322126, 14.561593319413918, 14.939879517586482, 15.308820986607689, 15.669077828640715, 16.02123590738243, 16.36581803638303, 16.703293088490067, 17.03408347989407, 17.35857136978732, 17.677103835187484, 17.98999722067794, 18.297540818372287, 18.6, 18.897618897628348, 19.190622710063373, 19.479219696897513, 19.763602910400724, 20.04395170618808, 20.320433066251322, 20.593202762076615, 20.862406380856452, 21.12818023399081, 21.390652163971065, 21.64994226320246, 21.906163516234418, 22.15942237514327, 22.409819276379718, 22.65744910619905, 22.902401620790776, 23.144761826383093, 23.384610323886093, 23.622023622035435, 23.857074422485255, 24.089831879861677, 24.320361839413493, 24.54872705457454, 24.774987386475093, 24.99919998719959, 25.221419468380443, 25.44169805653703, 25.660085736411716, 25.87663038341739, 26.09137788619068, 26.304372260139566, 26.515655752781225, 26.725268941584105, 26.933250824956126, 27.139638906956737, 27.344469276254017, 27.547776679797593, 27.749594591633226, 27.94995527724508, 28.14888985377576, 28.34642834644252, 28.542599741439112, 28.737432035587315, 28.930952282978865, 29.123186638827836, 29.31416040073466, 29.503898047546198, 29.692423275980694, 29.879759035172963, 30.065927559282123, 30.250950398293277, 30.434848447133753, 30.617641973215378, 30.79935064250544, 30.97999354422141, 31.159589214237084, 31.33815565728143, 31.51571036800535, 31.692270350986217, 31.867852139734804, 32.04247181476486, 32.21614502078112, 32.38888698303787, 32.560712522916326, 32.73163607276606, 32.901671690052474, 33.0708330708496, 33.239133562714905, 33.406586176980134, 33.57320360049068], [0.0, 3.394112549695428, 4.8, 5.878775382679628, 6.788225099390856, 7.589466384404111, 8.313843876330612, 8.97997772825746, 9.6, 10.182337649086284, 10.73312629199899, 11.256997823576231, 11.757550765359255, 12.237646832622683, 12.699606293110033, 13.145341380123986, 13.576450198781712, 13.994284547628721, 14.399999999999999, 14.794593607125545, 15.178932768808222, 15.553777676178864, 15.91979899370592, 16.277591959500647, 16.627687752661224, 16.97056274847714, 17.30664612222715, 17.636326148038883, 17.95995545651492, 18.27785545407338, 18.5903200617956, 18.897618897628345, 19.2, 19.497692171126307, 19.790907002964772, 20.079840636817814, 20.364675298172568, 20.645580640902306, 20.922714928995234, 21.196226079186832, 21.46625258399798, 21.7329243315298, 21.996363335788033, 22.256684389189687, 22.513995647152463, 22.76839915321233, 23.019991311901055, 23.268863315598377, 23.51510153071851, 23.758787847867996, 24.0, 24.238811852068988, 24.475293665245367, 24.709512338368803, 24.941531628991832, 25.171412356083636, 25.399212586220067, 25.624987804875147, 25.84879107424562, 26.070673178880515, 26.29068276024797, 26.508866441249427, 26.725268941584105, 26.93993318477238, 27.152900397563425, 27.364210202379308, 27.573900703382535, 27.78200856669654, 27.988569095257443, 28.19361629872975, 28.397182958878158, 28.599300690751164, 28.799999999999997, 28.999310336626973, 29.197260145431454, 29.393876913398135, 29.58918721425109, 29.783216750378056, 29.975990392312315, 30.167532215943684, 30.357865537616444, 30.547012947258857, 30.734996339677675, 30.9218369441403, 31.10755535235773, 31.292171544972717, 31.475704916649608, 31.658174299855006, 31.83959798741184, 32.0199937539032, 32.19937887599697, 32.3777701517569, 32.555183919001294, 32.73163607276606, 32.90714208192501, 33.08171700501653, 33.25537550532245, 33.42813186524189, 33.599999999999994, 33.7709934707287, 33.94112549695428, 34.11040896852455], [0.0, 3.4467375879228173, 4.874423042781577, 5.969924622639721, 6.8934751758456345, 7.707139547199079, 8.442748367682174, 9.119210492142399, 9.748846085563153, 10.340212763768452, 10.899541274750971, 11.431535329954592, 11.939849245279442, 12.427389106324789, 12.896511156122806, 13.349157276772193, 13.786950351691269, 14.211263138792415, 14.62326912834473, 15.0239808306587, 15.414279094398157, 15.794935897305821, 16.166632302368978, 16.529972776747098, 16.88549673536435, 17.23368793961409, 17.574982219052174, 17.909773867919164, 18.238420984284797, 18.561249957909627, 18.87855926706273, 19.190622710063373, 19.497692171126307, 19.800000000000004, 20.097761069333075, 20.391174561559716, 20.680425527536904, 20.965686251587382, 21.24711745155093, 21.52486933758252, 21.799082549501943, 22.06988898929943, 22.337412562783545, 22.601769842204835, 22.863070659909184, 23.121418641597234, 23.37691168653379, 23.62964240101826, 23.879698490558884, 24.127163115459723, 24.372115213907886, 24.61462979611922, 24.854778212649578, 25.092628399591785, 25.328245103046523, 25.56169008496895, 25.79302231224561, 26.02229813064173, 26.249571425072833, 26.47489376749225, 26.698314553544385, 26.91988112900947, 27.13963890695674, 27.357631476427198, 27.573900703382538, 27.788486824582588, 28.001428534987284, 28.212763069220994, 28.42252627758483, 28.630752697056362, 28.837475617675, 29.042727144674277, 29.24653825668946, 29.448938860339265, 29.64995784145401, 29.8496231131986, 30.0479616613174, 30.24499958670855, 30.440762145517983, 30.635273786927385, 30.828558188796315, 31.02063829130536, 31.211536328735892, 31.40127385951086, 31.589871794611643, 31.77735042447687, 31.963729444481295, 32.149027979085155, 32.333264604737955, 32.51645737161415, 32.69862382425291, 32.87978102116862, 33.059945553494195, 33.239133562714905, 33.41736075754637, 33.59464243000661, 33.7709934707287, 33.94642838355753, 34.120961299471034, 34.294605989863776, 34.46737587922818, 34.63928405726655], [0.0, 3.4985711369071804, 4.947726750741193, 6.059702963017247, 6.997142273814361, 7.823042886243179, 8.56971411425142, 9.256349172324908, 9.895453501482386, 10.49571341072154, 11.063453348751466, 11.60344776348823, 12.119405926034494, 12.614277624977182, 13.090454537562856, 13.549907748763458, 13.994284547628721, 14.42497833620557, 14.843180252223577, 15.249918032566603, 15.646085772486359, 16.032467059064864, 16.409753197412815, 16.77855774493148, 17.13942822850284, 17.4928556845359, 17.83928249678221, 18.179108889051744, 18.512698344649817, 18.8403821617291, 19.162463307205574, 19.479219696897513, 19.790907002964772, 20.097761069333075, 20.400000000000002, 20.69782597279241, 20.99142682144308, 21.28097742116184, 21.566640906733713, 21.84856974723975, 22.126906697502932, 22.401785643113367, 22.673332353229423, 22.94166515316619, 23.20689552697646, 23.469128658729534, 23.72846391994223, 23.98499530956802, 24.238811852068988, 24.489997958350266, 24.738633753705965, 24.98479537638842, 25.228555249954365, 25.469982332149353, 25.709142342754262, 25.946097972527586, 26.18090907512571, 26.413632843666168, 26.644323973409424, 26.87303481187043, 27.099815497526915, 27.32471408816568, 27.54777667979759, 27.769047516974723, 27.988569095257443, 28.20638225650358, 28.422526277584826, 28.637038953076136, 28.84995667241114, 29.061314491949602, 29.271146202361127, 29.47948439169179, 29.686360504447155, 29.891804896994763, 30.095846889562686, 30.298514815086232, 30.499836065133206, 30.69983713311848, 30.898543655000964, 31.095980447639853, 31.292171544972717, 31.487140232164627, 31.68090907786581, 31.87349996470422, 32.06493411812973, 32.25523213371748, 32.44441400302986, 32.632499138129155, 32.81950639482563, 33.00545409474016, 33.1903600462544, 33.37424156441611, 33.55711548986296, 33.73899820682292, 33.91990566024617, 34.09985337211877, 34.27885645700568, 34.45692963686696, 34.63408725518835, 34.810343290464694, 34.9857113690718, 35.16020477756067], [0.0, 3.5496478698597693, 5.019960159204453, 6.148170459575759, 7.099295739719539, 7.937253933193773, 8.694826047713663, 9.391485505499118, 10.039920318408907, 10.648943609579307, 11.224972160321824, 11.772850122209151, 12.296340919151518, 12.798437404620925, 13.281566172707192, 13.747727084867519, 14.198591479439077, 14.635573101180562, 15.059880477613358, 15.472556349873154, 15.874507866387546, 16.26653005407115, 16.64932431061393, 17.023513150933333, 17.389652095427326, 17.74823934929885, 18.099723754798028, 18.444511378727277, 18.782971010998235, 19.115438786488788, 19.44222209522358, 19.763602910400724, 20.079840636817814, 20.391174561559716, 20.69782597279241, 21.0, 21.297887219158614, 21.5916650585359, 21.881499034572563, 22.1675438422934, 22.44994432064365, 22.728836309850976, 23.004347415216976, 23.276597689524984, 23.545700244418303, 23.811761799581316, 24.074883177286655, 24.335159748807893, 24.592681838303037, 24.84753508901839, 25.09980079602227, 25.34955620913313, 25.59687480924185, 25.841826560829638, 26.08447814314099, 26.324893162176366, 26.563132345414385, 26.799253720952752, 27.033312782565147, 27.26536264200423, 27.495454169735037, 27.723636125155014, 27.949955277245078, 28.17445651649735, 28.397182958878155, 28.618176042508367, 28.837475617674997, 29.0551200307278, 29.271146202361123, 29.485589700733474, 29.698484809834998, 29.909864593474843, 30.119760955226717, 30.328204694640267, 30.535225559998732, 30.740852297878792, 30.945112699746307, 31.148033645801785, 31.34964114627152, 31.54996038032378, 31.749015732775092, 31.94683082873793, 32.1434285663493, 32.338831147708476, 32.5330601081423, 32.72613634390715, 32.91808013842849, 33.108911187171344, 33.29864862122786, 33.487311029701985, 33.67491648096547, 33.861482542853906, 34.047026301866666, 34.231564381430196, 34.415112959279966, 34.597687784012386, 34.77930419085465, 34.959977116697324, 35.13972111443117, 35.318550366627456, 35.4964786985977, 35.67351959086741], [0.0, 3.5999999999999996, 5.091168824543142, 6.235382907247958, 7.199999999999999, 8.049844718999244, 8.818163074019441, 9.524704719832526, 10.182337649086284, 10.799999999999999, 11.384199576606164, 11.93984924527944, 12.470765814495916, 12.97998459167036, 13.469966592386188, 13.9427400463467, 14.399999999999999, 14.843180252223577, 15.273506473629425, 15.692036196746425, 16.09968943799849, 16.497272501841024, 16.88549673536435, 17.264993483925792, 17.636326148038883, 18.0, 18.356470248934027, 18.706148721743876, 19.04940943966505, 19.386593305684215, 19.71801207018598, 20.04395170618808, 20.364675298172568, 20.680425527536904, 20.991426821443085, 21.297887219158618, 21.599999999999998, 21.897945109073593, 22.191890410688313, 22.481992794234234, 22.76839915321233, 23.051247254758255, 23.330666514268298, 23.606778687487196, 23.87969849055888, 24.149534156997728, 24.416387939250967, 24.680356561443755, 24.941531628991832, 25.2, 25.45584412271571, 25.709142342754262, 25.95996918334072, 26.20839560140987, 26.454489222058324, 26.698314553544385, 26.939933184772375, 27.179403966974697, 27.416783181110073, 27.652124692326986, 27.8854800926934, 28.116898833263956, 28.34642834644252, 28.57411415949758, 28.799999999999997, 29.024127893874777, 29.246538256689455, 29.467269978740816, 29.686360504447155, 29.90384590650507, 30.11976095522672, 30.33413918343489, 30.54701294725885, 30.758413483143112, 30.968370961353454, 31.17691453623979, 31.38407239349285, 31.589871794611643, 31.794339118780254, 31.99749990233612, 32.19937887599698, 32.4, 32.5993864972947, 32.79756088491947, 32.99454500368205, 33.1903600462544, 33.38502658378454, 33.57856459111973, 33.7709934707287, 33.96233207540377, 34.15259872981849, 34.34181125101004, 34.529986967851585, 34.71714273957464, 34.90329497339757, 35.08845964131227, 35.272652296077766, 35.45588808646598, 35.63818177180199, 35.81954773583832, 36.0, 36.179552236035214], [0.0, 3.6496575181789317, 5.1613951602255765, 6.321392251711644, 7.299315036357863, 8.160882305241268, 8.939798655450804, 9.65608616365865, 10.322790320451153, 10.948972554536795, 11.541230437002808, 12.10454460109921, 12.642784503423288, 13.159027319676786, 13.65576801208925, 14.135062787267696, 14.598630072715727, 15.047923444781343, 15.484185480676729, 15.908488300275424, 16.321764610482536, 16.724831837719627, 17.118411141224527, 17.50314257497779, 17.87959731090161, 18.24828759089466, 18.60967490312499, 18.964176755134933, 19.3121723273173, 19.65400722499104, 19.98999749874922, 20.320433066251322, 20.645580640902306, 20.965686251587382, 21.280977421161843, 21.5916650585359, 21.89794510907359, 22.200000000000003, 22.49799991110321, 22.792103895867097, 23.082460874005616, 23.36921051298054, 23.65248401331243, 23.932404810214955, 24.20908920219842, 24.482646915723798, 24.753181613683523, 25.02079135439165, 25.285569006846575, 25.547602627252527, 25.806975801127884, 26.06376795476817, 26.318054639353573, 26.56990779058144, 26.819395966352413, 27.066584564735905, 27.3115360241785, 27.554310007692084, 27.79496357256113, 28.0335513269368, 28.270125574535392, 28.50473644852729, 28.737432035587315, 28.96825849097595, 29.197260145431454, 29.42447960457415, 29.649957841454007, 29.873734282811046, 30.095846889562686, 30.316332231983473, 30.535225559998736, 30.7525608689748, 30.968370961353457, 31.18268750444708, 31.395541084682712, 31.606961258558215, 31.81697660055085, 32.025614748198045, 32.23290244455191, 32.43886557819185, 32.64352922096507, 32.84691766361039, 33.04905444940899, 33.249962405993784, 33.449663675439254, 33.64817974274389, 33.8455314628091, 34.04173908601028, 34.236822282449054, 34.43080016496857, 34.62369131100842, 34.815513783369624, 35.00628514995558, 35.19602250254992, 35.38474247468816, 35.57246125867593, 35.75919462180322, 35.94495792180039, 36.12976612157903, 36.313633803297634, 36.49657518178932, 36.67860411738703], [0.0, 3.698648401781386, 5.230678732248808, 6.406246951218788, 7.397296803562772, 8.270429251254134, 9.059801322324901, 9.785703858180055, 10.461357464497617, 11.095945205344156, 11.696153213770756, 12.267028980156525, 12.812493902437575, 13.335666462535722, 13.839075113604954, 14.324803663575986, 14.794593607125543, 15.249918032566603, 15.692036196746425, 16.122034611053287, 16.540858502508268, 16.949336270190642, 17.348198753761153, 17.738094598913385, 18.119602644649802, 18.49324200890693, 18.859480374602057, 19.218740853656364, 19.57140771636011, 19.9178312072374, 20.25833161936096, 20.59320276207662, 20.922714928995234, 21.24711745155093, 21.566640906733717, 21.881499034572563, 22.191890410688313, 22.49799991110321, 22.8, 23.098051865904193, 23.392306427541513, 23.682905227188666, 23.969981226525817, 24.253659517689282, 24.53405796031305, 24.8112877537624, 25.08545395244025, 25.356655930938526, 25.62498780487515, 25.890538812469703, 26.153393661244046, 26.41363284366617, 26.671332925071443, 26.926566806780254, 27.1794039669747, 27.429910681589906, 27.67815022720991, 27.924183067728233, 28.168067026333212, 28.409857444204114, 28.649607327151973, 28.887367481305738, 29.123186638827832, 29.357111574540166, 29.589187214251087, 29.819456735494025, 30.047961661317395, 30.274741947702875, 30.499836065133206, 30.72328107478106, 30.945112699746307, 31.165365391729328, 31.38407239349285, 31.601265797432863, 31.816976600550845, 32.03123475609394, 32.244069222106575, 32.45550800711646, 32.66557821315889, 32.87430607632654, 33.081717005016536, 33.28783561603248, 33.492685768686876, 33.69629059703753, 33.898672540381284, 34.09985337211878, 34.299854227095494, 34.49869562751612, 34.696397507522306, 34.89297923651691, 35.08845964131227, 35.282857027173975, 35.47618919782677, 35.66847347448444, 35.85972671396144, 36.04996532591952, 36.239205289299605, 36.427462167985304, 36.614751125741655, 36.80108694046958, 36.98648401781386, 37.170956404160506], [0.0, 3.746998799039039, 5.299056519796709, 6.489992295835182, 7.493997598078078, 8.378544026261366, 9.178235124467014, 9.913626985114984, 10.598113039593418, 11.240996397117117, 11.8490505948789, 12.427389106324789, 12.979984591670364, 13.509996299037244, 14.019985734657507, 14.51206394693739, 14.987995196156156, 15.44927182750048, 15.897169559390125, 16.332789106579444, 16.757088052522732, 17.170905625505025, 17.574982219052174, 17.96997495824633, 18.356470248934027, 18.734993995195197, 19.10601999370879, 19.469976887505545, 19.827253970229968, 20.178206064960285, 20.523157651784487, 20.862406380856452, 21.196226079186836, 21.524869337582523, 21.848569747239754, 22.1675438422934, 22.481992794234234, 22.792103895867097, 23.09805186590419, 23.400000000000002, 23.6981011897578, 23.99249882775865, 24.283327613817676, 24.570714275331923, 24.854778212649578, 25.135632078784095, 25.41338230145685, 25.688129554329176, 25.95996918334073, 26.22899159327328, 26.495282598983543, 26.758923745173316, 27.019992598074488, 27.278563012006337, 27.534705373401042, 27.788486824582588, 28.039971469315013, 28.289220561903083, 28.53629268142588, 28.781243892507497, 29.02412789387478, 29.26499615581728, 29.503898047546194, 29.740880955344956, 29.975990392312312, 30.209270100417854, 30.440762145517972, 30.67050700591694, 30.89854365500096, 31.124909638423052, 31.34964114627152, 31.572773080614887, 31.79433911878025, 32.01437177268984, 32.232902444551904, 32.449961479175904, 32.66557821315889, 32.879781021168625, 33.09259735953043, 33.30405380730701, 33.514176105045465, 33.72298919135136, 33.93051723743687, 34.136783679778624, 34.34181125101005, 34.54562200916349, 34.74823736536863, 34.94967811010568, 35.14996443810435, 35.34911597197305, 35.547151784636704, 35.74409042065555, 35.93994991649266, 36.13474781979252, 36.32850120772945, 36.52122670447969, 36.712940497868054, 36.90365835523628, 37.09339563857696, 37.28216731897437, 37.46998799039039, 37.6568718828317], [0.0, 3.794733192202055, 5.366563145999495, 6.572670690061994, 7.58946638440411, 8.485281374238571, 9.2951600308978, 10.039920318408907, 10.73312629199899, 11.384199576606164, 12.0, 12.58570617804182, 13.145341380123988, 13.682105101189656, 14.198591479439077, 14.696938456699067, 15.17893276880822, 15.646085772486357, 16.099689437998485, 16.540858502508268, 16.970562748477143, 17.389652095427326, 17.798876369029593, 18.198901065723724, 18.5903200617956, 18.973665961010276, 19.34941859591652, 19.71801207018598, 20.079840636817814, 20.43526363911168, 20.784609690826528, 21.12818023399081, 21.46625258399798, 21.799082549501943, 22.126906697502932, 22.44994432064365, 22.76839915321233, 23.082460874005616, 23.392306427541513, 23.6981011897578, 24.0, 24.298148077579906, 24.592681838303037, 24.88372962399326, 25.17141235608364, 25.45584412271571, 25.73713270743266, 26.015380066414558, 26.290682760247975, 26.563132345414388, 26.832815729997478, 27.09981549752692, 27.36421020237931, 27.626074639731215, 27.885480092693403, 28.142494558940577, 28.397182958878155, 28.649607327151973, 28.899826989101513, 29.147898723578685, 29.393876913398135, 29.637813684548327, 29.879759035172956, 30.11976095522672, 30.35786553761644, 30.594117081556707, 30.828558188796308, 31.06122985330748, 31.292171544972714, 31.521421287752872, 31.74901573277509, 31.974990226738147, 32.19937887599697, 32.42221460665511, 32.643529220965064, 32.863353450309965, 33.081717005016536, 33.29864862122786, 33.514176105045465, 33.72832637413247, 33.941125496954285, 34.1525987298185, 34.36277055186325, 34.57166469813104, 34.77930419085465, 34.98571136907181, 35.19090791667644, 35.3949148890063, 35.597752738059185, 35.799441336423115, 36.0, 36.199447509596055, 36.39780213144745, 36.59508163674458, 36.79130332021414, 36.98648401781386, 37.1806401235912, 37.373787605753854, 37.56594202199646, 37.75711853412546, 37.94733192202055, 38.136596596969696], [0.0, 3.8418745424597094, 5.43323108288245, 6.654321903845651, 7.683749084919419, 8.590692637965814, 9.410632284814874, 10.16464460765845, 10.8664621657649, 11.525623627379128, 12.149074038789953, 12.742056348957183, 13.308643807691302, 13.852075656738236, 14.374978260853128, 14.879516121164693, 15.367498169838838, 15.840454538932905, 16.29969324864735, 16.746342884343438, 17.18138527593163, 17.605680901345455, 18.019988901217452, 18.42498303934091, 18.821264569629747, 19.20937271229855, 19.589793260777412, 19.962965711536953, 20.3292892153169, 20.689127579480004, 21.04281350010022, 21.390652163971065, 21.7329243315298, 22.06988898929943, 22.401785643113367, 22.728836309850976, 23.051247254758255, 23.36921051298054, 23.682905227188662, 23.99249882775865, 24.298148077579906, 24.600000000000005, 24.898192705495717, 25.192856130260417, 25.484112697914366, 25.772077913897437, 26.05686090073016, 26.33856488117756, 26.617287615382605, 26.89312179721797, 27.166155414412252, 27.436472076416827, 27.704151313476473, 27.969268849936, 28.231896854444624, 28.49210416940104, 28.749956521706256, 29.00551671665237, 29.258844816567866, 29.50999830565905, 29.759032242329386, 30.005999400119975, 30.250950398293273, 30.493933822975354, 30.734996339677675, 30.974182797936738, 31.211536328735885, 31.44709843530878, 31.68090907786581, 31.91300675273328, 32.1434285663493, 32.37221030451891, 32.5993864972947, 32.82499047981583, 33.04905444940899, 33.27160951922825, 33.492685768686876, 33.71231229091236, 33.930517237436874, 34.147327860317276, 34.36277055186326, 34.57687088213739, 34.78965363437814, 35.001142838484576, 35.21136180269091, 35.420333143549065, 35.62807881432846, 35.83462013193387, 36.039977802434905, 36.244171945293495, 36.44722211636986, 36.64914732978109, 36.84996607868182, 37.049696355031045, 37.24835566840502, 37.445961063911824, 37.642529139259494, 37.83807606102616, 38.03261758017715, 38.22616904687155, 38.4187454245971, 38.610361303670814], [0.0, 3.8884444190447165, 5.499090833947008, 6.7349832961930955, 7.776888838089433, 8.694826047713665, 9.524704719832528, 10.287856919689348, 10.998181667894016, 11.665333257134149, 12.296340919151518, 12.89651115612281, 13.469966592386191, 14.019985734657508, 14.54922678357857, 15.05988047761336, 15.553777676178866, 16.032467059064867, 16.497272501841024, 16.949336270190646, 17.38965209542733, 17.819090885900998, 18.2384209842848, 18.64832432150407, 19.049409439665055, 19.44222209522358, 19.82725397022997, 20.204949888579286, 20.575713839378697, 20.93991403993818, 21.29788721915862, 21.649942263202462, 21.996363335788033, 22.33741256278355, 22.673332353229426, 23.00434741521698, 23.330666514268298, 23.65248401331243, 23.969981226525817, 24.28332761381768, 24.592681838303037, 24.89819270549572, 25.200000000000003, 25.49823523305093, 25.79302231224562, 26.08447814314099, 26.372713171003095, 26.657831869827675, 26.939933184772382, 27.21911093331302, 27.495454169735044, 27.769047516974727, 28.039971469315017, 28.308302669005084, 28.574114159497583, 28.837475617675, 29.09845356715714, 29.357111574540166, 29.613510430207366, 29.86770831516874, 30.11976095522672, 30.369721763625037, 30.617641973215378, 30.863570759068047, 31.107555352357732, 31.349641146271516, 31.58987179461164, 31.828289303699627, 32.064934118129734, 32.29984520086745, 32.53306010814231, 32.764615059542514, 32.99454500368205, 33.22288367977711, 33.449663675439254, 33.67491648096547, 33.89867254038129, 34.12096129947104, 34.34181125101005, 34.56124997739521, 34.77930419085466, 34.99599977140245, 35.21136180269091, 35.425414605901224, 35.638181771801996, 35.84968619109518, 36.05995008316013, 36.2689950232978, 36.4768419685696, 36.683511282318655, 36.889022757454555, 37.09339563857696, 37.29664864300814, 37.4987999807994, 37.69986737377202, 37.89986807364902, 38.09881887933011, 38.296736153359085, 38.49363583762906, 38.689533468368424, 38.88444419044716, 39.078382771041085], [0.0, 3.9344631145812, 5.564171097297422, 6.814690014960328, 7.8689262291624, 8.79772697916911, 9.637427042525406, 10.409610943738484, 11.128342194594843, 11.803389343743598, 12.44186481199663, 13.049137902558927, 13.629380029920656, 14.185908501044265, 14.721412975662354, 15.23811011904035, 15.7378524583248, 16.222207001514928, 16.692513291892265, 17.149927113547744, 17.59545395833822, 18.029975041580062, 18.454267799075637, 18.869022232219667, 19.274854085050812, 19.672315572906, 20.061904196760587, 20.444070044880984, 20.819221887476967, 21.18773229961149, 21.549941995281564, 21.906163516234418, 22.256684389189687, 22.60176984220484, 22.941665153166195, 23.276597689524987, 23.606778687487196, 23.93240481021496, 24.253659517689282, 24.570714275331923, 24.88372962399326, 25.19285613026042, 25.49823523305093, 25.799999999999994, 26.098275805117854, 26.39318093750732, 26.6848271495245, 26.973320151586822, 27.25876005984131, 27.541241802068402, 27.820855486487112, 28.09768673752343, 28.37181700208853, 28.643323829472028, 28.912281127576218, 29.178759397890786, 29.442825951324707, 29.70454510676775, 29.963978374041055, 30.221184622711263, 30.4762202380807, 30.729139265524505, 30.9799935442214, 31.22883283121545, 31.4757049166496, 31.720655730927124, 31.96372944448128, 32.204968560767135, 32.444414003029856, 32.68210519535117, 32.918080138428486, 33.15237548049913, 33.38502658378453, 33.61606758679545, 33.845531462809085, 34.073450074801634, 34.29985422709549, 34.52477371395793, 34.748237365368624, 34.97027309015473, 35.19090791667644, 35.4101680312308, 35.628078814328454, 35.84466487498523, 36.059950083160125, 36.27395760046042, 36.48670990922585, 36.69822884009526, 36.908535598151275, 37.117650787731705, 37.32559443598989, 37.53238601528019, 37.738044464439334, 37.94258820902971, 38.146035180605594, 38.3484028350595, 38.549708170101624, 38.74996774192206, 38.94919768108195, 39.14741370767678, 39.344631145812, 39.54086493742898], [0.0, 3.97994974842648, 5.628498911788116, 6.893475175845635, 7.95989949685296, 8.899438184514798, 9.748846085563153, 10.529957264870548, 11.256997823576231, 11.939849245279438, 12.58570617804182, 13.200000000000003, 13.78695035169127, 14.34991289172168, 14.891608375189028, 15.414279094398156, 15.91979899370592, 16.40975319741281, 16.88549673536435, 17.348198753761157, 17.798876369029596, 18.238420984284797, 18.667619023324857, 19.087168464704245, 19.497692171126307, 19.899748742132402, 20.29384143034532, 20.680425527536904, 21.059914529741096, 21.432685319390103, 21.799082549501943, 22.15942237514327, 22.513995647152463, 22.863070659909184, 23.206895526976464, 23.545700244418303, 23.879698490558877, 24.20908920219842, 24.53405796031305, 24.854778212649578, 25.17141235608364, 25.484112697914366, 25.793022312245615, 26.098275805117854, 26.400000000000006, 26.69831455354439, 26.993332510084784, 27.285160802164974, 27.57390070338254, 27.85964823898536, 28.14249455894058, 28.422526277584833, 28.69982578344336, 28.97447152235913, 29.246538256689462, 29.516097302997224, 29.783216750378056, 30.047961661317398, 30.31039425675622, 30.570574086856794, 30.82855818879631, 31.084401232772688, 31.33815565728143, 31.589871794611643, 31.83959798741184, 32.08738069709025, 32.33326460473795, 32.577292705195745, 32.81950639482562, 33.05994555349419, 33.29864862122786, 33.53565266995709, 33.7709934707287, 34.00470555673141, 34.236822282449054, 34.46737587922817, 34.69639750752231, 34.9239173060526, 35.149964438104355, 35.374567135160824, 35.59775273805919, 35.81954773583833, 36.0399778024349, 36.2590678313715, 36.476841968569595, 36.693323643409585, 36.90853559815128, 37.12249991581925, 37.335238046649714, 37.54677083318884, 37.75711853412546, 37.966300846935304, 38.17433692940849, 38.38124542012675, 38.587044457952466, 38.79175170058708, 38.99538434225261, 39.197959130546586, 39.399492382516804, 39.60000000000001, 39.799497484264805, 39.997999949997514], [0.0, 4.024922359499621, 5.692099788303082, 6.971370023173351, 8.049844718999243, 9.0, 9.859006035092989, 10.648943609579309, 11.384199576606164, 12.074767078498862, 12.727922061357855, 13.349157276772193, 13.942740046346701, 14.512063946937388, 15.059880477613357, 15.588457268119893, 16.099689437998485, 16.595180023127195, 17.076299364909246, 17.544229820656135, 18.0, 18.444511378727274, 18.878559267062727, 19.3028495305745, 19.718012070185978, 20.124611797498105, 20.523157651784484, 20.91411006952005, 21.297887219158618, 21.67487024182613, 22.045407685048602, 22.409819276379718, 22.76839915321233, 23.121418641597234, 23.469128658729534, 23.811761799581316, 24.149534156997724, 24.482646915723798, 24.811287753762397, 25.13563207878409, 25.45584412271571, 25.772077913897437, 26.084478143140988, 26.393180937507317, 26.698314553544385, 26.999999999999996, 27.29835159858558, 27.593477490160602, 27.885480092693403, 28.17445651649735, 28.460498941515414, 28.743694960808362, 29.024127893874777, 29.301877072979472, 29.57701810527897, 29.849623113198597, 30.119760955226713, 30.387497429041435, 30.652895458667523, 30.916015267171797, 31.176914536239785, 31.435648553831363, 31.692270350986213, 31.946830828737923, 32.19937887599697, 32.4499614791759, 32.698623824252905, 32.94540939190162, 33.19036004625439, 33.433516117812076, 33.67491648096547, 33.91459862655019, 34.15259872981849, 34.38895171417704, 34.623691311008415, 34.85685011586675, 35.08845964131227, 35.31855036662745, 35.547151784636704, 35.77429244583322, 36.0, 36.22430123549659, 36.44722211636986, 36.668787817434044, 36.88902275745455, 37.107950630558946, 37.3255944359899, 37.54197650630557, 37.75711853412545, 37.971041597512176, 38.18376618407356, 38.39531221386277, 38.605699061149, 38.81494557512609, 39.02307009962183, 39.23009049186606, 39.436024140371956, 39.640887981981436, 39.844698518121575, 40.04747183031658, 40.24922359499621, 40.449969097639624], [0.0, 4.069397989875161, 5.754997827975264, 7.0484040746824395, 8.138795979750322, 9.099450532861862, 9.96794863550169, 10.766615066955817, 11.509995655950528, 12.208193969625482, 12.86856635371633, 13.496666255042392, 14.096808149364879, 14.672423112764982, 15.226293048539423, 15.760710643876436, 16.277591959500644, 16.778557744931476, 17.26499348392579, 17.73809459891338, 18.198901065723724, 18.648324321504063, 19.08716846470424, 19.516147160748716, 19.93589727100338, 20.346989949375807, 20.749939758948702, 21.145212224047317, 21.533230133911633, 21.91437884129961, 22.289010745208053, 22.65744910619905, 23.019991311901055, 23.37691168653379, 23.72846391994223, 24.074883177286658, 24.416387939250964, 24.753181613683527, 25.085453952440247, 25.413382301456846, 25.73713270743266, 26.05686090073016, 26.372713171003095, 26.684827149524498, 26.993332510084784, 27.298351598585583, 27.6, 27.898387050150408, 28.193616298729758, 28.48578592912613, 28.77498913987632, 29.061314491949606, 29.344846225529963, 29.625664549508425, 29.903845906505072, 30.1794632159023, 30.452586097078846, 30.72328107478106, 30.991611768347905, 31.257639066314653, 31.521421287752872, 31.78301433155767, 32.04247181476485, 32.29984520086745, 32.55518391900129, 32.80853547478156, 33.05994555349419, 33.30945811627682, 33.55711548986295, 33.80295845040786, 34.04702630186666, 34.28935694935092, 34.52998696785158, 34.768951666681005, 35.00628514995557, 35.24202037341219, 35.47618919782676, 35.70882243927963, 35.93994991649266, 36.16960049544369, 36.39780213144745, 36.62458190887645, 36.84996607868181, 37.073980093860975, 37.296648643008126, 37.51799568207236, 37.738044464439334, 37.95681756944331, 38.17433692940848, 38.39062385531134, 38.60569906114899, 38.81958268709235, 39.03229432149743, 39.2438530218428, 39.45427733465663, 39.66358531449218, 39.87179454200676, 40.07892214119537, 40.284984795826844, 40.48999876512718, 40.693979898751614, 40.89694365108475], [0.0, 4.113392760240626, 5.817215828899595, 7.124605252222751, 8.226785520481252, 9.197825830053537, 10.075713374248, 10.883014288330234, 11.63443165779919, 12.340178280721878, 13.007690033207279, 13.642580401082489, 14.249210504445502, 14.83104851316993, 15.390906406056791, 15.931101656822102, 16.453571040962505, 16.959952830123083, 17.451647486698786, 17.929863356980725, 18.395651660107074, 18.84993368688601, 19.293522228976233, 19.72713866732832, 20.151426748496, 20.566963801203133, 20.974269951538243, 21.373815756668254, 21.766028576660467, 22.15129793036968, 22.529980026622304, 22.902401620790776, 23.26886331559838, 23.629642401018263, 23.984995309568024, 24.335159748807897, 24.680356561443755, 25.020791354391655, 25.356655930938526, 25.688129554329176, 26.015380066414558, 26.338564881177565, 26.657831869827675, 26.973320151586822, 27.285160802164977, 27.593477490160605, 27.898387050150408, 28.2, 28.498421008891004, 28.793749321684388, 29.086079144497976, 29.375499995744757, 29.66209702633986, 29.945951312322677, 30.227140122744, 30.505737165326785, 30.781812812113582, 31.055434307058082, 31.326665957295873, 31.595569309635803, 31.862203313644205, 32.12662447254613, 32.38888698303787, 32.6490428649907, 32.90714208192501, 33.16323265304515, 33.41736075754637, 33.66957083183568, 33.919905660246165, 34.16840645976924, 34.41511295927997, 34.66006347368683, 34.90329497339757, 35.144843149457934, 35.38474247468815, 35.62302626111375, 35.85972671396145, 36.094874982468085, 36.32850120772945, 36.560634567797095, 36.79130332021415, 37.020534842165645, 37.24835566840502, 37.47479152710525, 37.69986737377202, 37.92360742334517, 38.1460351806056, 38.3671734689956, 38.587044457952466, 38.805669688848305, 39.02307009962184, 39.23926604818189, 39.45427733465664, 39.66812322255743, 39.88082245892128, 40.09239329349147, 40.302853496992, 40.51222037854752, 40.72051080229716, 40.927741203247464, 41.13392760240627, 41.33908562123745], [0.0, 4.156921938165306, 5.8787753826796285, 7.200000000000001, 8.313843876330612, 9.295160030897803, 10.182337649086286, 10.998181667894018, 11.757550765359257, 12.470765814495916, 13.145341380123988, 13.78695035169127, 14.400000000000002, 14.987995196156158, 15.553777676178866, 16.099689437998485, 16.627687752661224, 17.139428228502844, 17.636326148038883, 18.119602644649802, 18.590320061795605, 19.049409439665055, 19.49769217112631, 19.935897271003384, 20.36467529817257, 20.78460969082653, 21.196226079186836, 21.600000000000005, 21.996363335788036, 22.38570972741316, 22.768399153212336, 23.144761826383096, 23.515101530718514, 23.879698490558884, 24.23881185206899, 24.59268183830304, 24.941531628991832, 25.28556900684658, 25.62498780487515, 25.95996918334073, 26.290682760247975, 26.617287615382608, 26.939933184772382, 27.25876005984131, 27.57390070338254, 27.885480092693406, 28.193616298729758, 28.498421008891004, 28.800000000000004, 29.098453567157144, 29.39387691339814, 29.686360504447162, 29.975990392312315, 30.262848511004385, 30.547012947258857, 30.82855818879631, 31.107555352357732, 31.384072393492854, 31.658174299855013, 31.929923269560174, 32.19937887599697, 32.46659822032485, 32.73163607276606, 32.994545003682056, 33.25537550532245, 33.51417610504546, 33.7709934707287, 34.02587250901878, 34.27885645700569, 34.529986967851585, 34.77930419085466, 35.02684684638342, 35.272652296077766, 35.516756608676985, 35.75919462180322, 36.0, 36.239205289299605, 36.4768419685696, 36.71294049786806, 36.947530364017574, 37.18064012359121, 37.41229744348776, 37.6425291392595, 37.8713612113428, 38.09881887933011, 38.32492661441116, 38.54970817010164, 38.77318661136843, 38.99538434225262, 39.216323132083666, 39.43602414037196, 39.65450794045994, 39.87179454200677, 40.08790341237617, 40.302853496992, 40.51666323872192, 40.72935059634514, 40.940933062156766, 41.15142767875739, 41.360851055073816, 41.56921938165306, 41.776548445270116], [0.0, 4.2, 5.939696961966999, 7.274613391789285, 8.4, 9.391485505499118, 10.287856919689348, 11.11215550647128, 11.879393923933998, 12.599999999999998, 13.281566172707194, 13.92982411949268, 14.54922678357857, 15.143315356948754, 15.714961024450552, 16.26653005407115, 16.8, 17.317043627594174, 17.819090885900998, 18.30737556287083, 18.782971010998235, 19.24681791881453, 19.699746191258406, 20.142492397913426, 20.575713839378697, 21.0, 21.4158819570897, 21.823840175367856, 22.22431101294256, 22.617692189964917, 23.004347415216976, 23.384610323886093, 23.758787847867996, 24.127163115459723, 24.489997958350266, 24.84753508901839, 25.199999999999996, 25.547602627252523, 25.8905388124697, 26.228991593273275, 26.563132345414388, 26.893121797217965, 27.219110933313015, 27.5412418020684, 27.85964823898536, 28.17445651649735, 28.485785929126127, 28.793749321684384, 29.09845356715714, 29.400000000000002, 29.698484809834998, 29.993999399879975, 30.28663071389751, 30.57646153497818, 30.863570759068047, 31.148033645801785, 31.429922048901105, 31.709304628137147, 31.986247044628417, 32.260812141048156, 32.5330601081423, 32.80304863880795, 33.0708330708496, 33.33646651941384, 33.6, 33.861482542853906, 34.120961299471034, 34.37848164186429, 34.63408725518835, 34.88782022425591, 35.139721114431175, 35.389829047340704, 35.638181771801996, 35.88481573033363, 36.12976612157903, 36.373066958946424, 36.61475112574166, 36.85485042704692, 37.093395638576965, 37.330416552725474, 37.56594202199647, 37.800000000000004, 38.03261758017715, 38.26382103240605, 38.49363583762906, 38.72208672063013, 38.94919768108196, 39.17499202297302, 39.39949238251681, 39.62272075463773, 39.84469851812158, 40.06544645951172, 40.28498479582685, 40.503333196170416, 40.72051080229716, 40.93653624819765, 41.15142767875739, 41.36520276754364, 41.57787873376899, 41.789472358478044, 42.0, 42.20947760870775], [0.0, 4.242640687119285, 6.0, 7.348469228349535, 8.48528137423857, 9.48683298050514, 10.392304845413264, 11.224972160321824, 12.0, 12.727922061357855, 13.416407864998739, 14.07124727947029, 14.69693845669907, 15.297058540778355, 15.874507866387543, 16.431676725154983, 16.97056274847714, 17.492855684535904, 18.0, 18.493242008906932, 18.97366596101028, 19.44222209522358, 19.899748742132402, 20.34698994937581, 20.784609690826528, 21.213203435596427, 21.63330765278394, 22.045407685048605, 22.44994432064365, 22.847319317591726, 23.237900077244504, 23.622023622035435, 24.0, 24.372115213907886, 24.738633753705965, 25.09980079602227, 25.45584412271571, 25.806975801127884, 26.153393661244042, 26.495282598983543, 26.832815729997478, 27.166155414412252, 27.49545416973504, 27.82085548648711, 28.14249455894058, 28.460498941515414, 28.77498913987632, 29.086079144497972, 29.39387691339814, 29.698484809834998, 30.000000000000004, 30.29851481508624, 30.59411708155671, 30.886890422961006, 31.176914536239792, 31.464265445104548, 31.749015732775085, 32.03123475609394, 32.31098884280703, 32.58834147360065, 32.863353450309965, 33.13608305156178, 33.406586176980134, 33.67491648096547, 33.94112549695428, 34.205262752974136, 34.46737587922817, 34.72751070837067, 34.98571136907181, 35.242020373412196, 35.4964786985977, 35.749125863438955, 36.0, 36.24913792078372, 36.49657518178932, 36.742346141747674, 36.986484017813865, 37.22902093797258, 37.4699879903904, 37.70941526992961, 37.94733192202056, 38.18376618407357, 38.4187454245971, 38.65229618017538, 38.88444419044716, 39.1152144312159, 39.34463114581201, 39.57271787481876, 39.799497484264805, 40.024992192379, 40.24922359499622, 40.47221268969613, 40.69397989875162, 40.914545090957574, 41.13392760240627, 41.352146256270665, 41.569219381653056, 41.785164831552365, 42.0, 42.213741838410876, 42.42640687119285, 42.6380112106557], [0.0, 4.28485705712571, 6.059702963017248, 7.4215901261117905, 8.56971411425142, 9.581231653602789, 10.495713410721542, 11.336666176614711, 12.119405926034496, 12.85457117137713, 13.54990774876346, 14.211263138792416, 14.843180252223581, 15.44927182750048, 16.032467059064864, 16.5951800231272, 17.13942822850284, 17.66691823720255, 18.17910888905174, 18.67725889952806, 19.162463307205577, 19.635681806344287, 20.097761069333075, 20.549452547452457, 20.991426821443085, 21.424285285628553, 21.848569747239754, 22.26477037833537, 22.673332353229423, 23.074661427635295, 23.469128658729538, 23.857074422485255, 24.23881185206899, 24.614629796119225, 24.984795376388423, 25.349556209133134, 25.70914234275426, 26.06376795476817, 26.413632843666168, 26.758923745173313, 27.09981549752692, 27.436472076416827, 27.769047516974727, 28.09768673752343, 28.422526277584833, 28.743694960808366, 29.061314491949606, 29.375499995744754, 29.686360504447162, 29.993999399879975, 30.29851481508624, 30.600000000000005, 30.89854365500096, 31.194230235734306, 31.487140232164627, 31.777350424476868, 32.06493411812973, 32.34996136010057, 32.63249913812916, 32.91261156456595, 33.1903600462544, 33.46580344172242, 33.73899820682292, 34.00999852984413, 34.27885645700568, 34.54562200916348, 34.810343290464694, 35.07306658962116, 35.3338364744051, 35.59269587991334, 35.84968619109518, 36.10484731999293, 36.35821777810348, 36.60983474423232, 36.85973412817841, 37.107950630558946, 37.35451779905612, 37.59946808134392, 37.84283287493156, 38.08464257414004, 38.324926614411154, 38.5637135141314, 38.80103091413939, 39.03690561507149, 39.271363612688575, 39.504430131315665, 39.73612965551629, 39.966485960114134, 40.19552213866615, 40.42326063048354, 40.64972324629038, 40.874931192602645, 41.098905094904914, 41.3216650196964, 41.54323049547303, 41.763620532707655, 41.98285364288617, 42.200947856653656, 42.417920741120724, 42.63378941637725, 42.848570571257106, 43.062280478395486], [0.0, 4.3266615305567875, 6.118823416311343, 7.493997598078079, 8.653323061113575, 9.67470929795826, 10.598113039593418, 11.447270417003349, 12.237646832622685, 12.97998459167036, 13.682105101189656, 14.34991289172168, 14.987995196156158, 15.600000000000001, 16.18888507587845, 16.75708805252273, 17.30664612222715, 17.839282496782207, 18.356470248934027, 18.859480374602057, 19.34941859591652, 19.827253970229968, 20.293841430345317, 20.749939758948702, 21.196226079186836, 21.633307652783937, 22.061731573020285, 22.481992794234237, 22.894540834006698, 23.299785406737122, 23.6981011897578, 24.08983187986168, 24.47529366524537, 24.85477821264958, 25.22855524995437, 25.596874809241854, 25.95996918334072, 26.318054639353573, 26.671332925071443, 27.019992598074488, 27.36421020237931, 27.704151313476473, 28.039971469315017, 28.37181700208853, 28.69982578344336, 29.02412789387478, 29.344846225529963, 29.66209702633986, 29.975990392312315, 30.286630713897512, 30.594117081556714, 30.898543655000964, 31.200000000000003, 31.498571396176054, 31.79433911878025, 32.08738069709025, 32.3777701517569, 32.66557821315888, 32.95087252259036, 33.23371781790295, 33.51417610504546, 33.79230681678894, 34.06816695978814, 34.34181125101004, 34.6132922444543, 34.88266044899672, 35.14996443810434, 35.4152509520969, 35.678564993564414, 35.93994991649265, 36.199447509596055, 36.45709807431195, 36.712940497868054, 36.96701232179847, 37.21934980624998, 37.46998799039039, 37.718960749204115, 37.966300846935304, 38.21203998741759, 38.45620886150896, 38.69883719183304, 38.93995377501109, 39.179586521554825, 39.41776249357642, 39.654507940459936, 39.889848332627196, 40.12380839352118, 40.35641212992057, 40.587682860690634, 40.81764324406788, 41.04631530356897, 41.27372045260762, 41.499879517897405, 41.72481276171291, 41.94853990307649, 42.171080137933394, 42.39245215837367, 42.612674170955295, 42.83176391417939, 43.04973867516504, 43.266615305567875, 43.48241023678426], [0.0, 4.368065933568311, 6.177378084592201, 7.565712127751096, 8.736131867136622, 9.767292357659827, 10.699532700076206, 11.556816170554935, 12.354756169184402, 13.104197800704933, 13.813037319865607, 14.487235761179566, 15.131424255502193, 15.749285698088027, 16.343806166251483, 16.91744661584602, 17.472263734273245, 18.009997223764362, 18.5321342537766, 19.03995798314692, 19.534584715319653, 20.016992781134736, 20.488045294756652, 20.948508300115314, 21.399065400152413, 21.84032966784156, 22.27285343192471, 22.697136383253287, 23.11363234110987, 23.522754940695194, 23.924882444852265, 24.320361839413493, 24.709512338368803, 25.09262839959179, 25.469982332149353, 25.841826560829638, 26.208395601409865, 26.56990779058144, 26.926566806780254, 27.278563012006337, 27.626074639731215, 27.969268849936, 28.30830266900508, 28.643323829472024, 28.97447152235913, 29.301877072979472, 29.625664549508425, 29.945951312322673, 30.262848511004385, 30.576461534978183, 30.886890422961006, 31.194230235734306, 31.498571396176054, 31.800000000000008, 32.09859810022862, 32.39444396806341, 32.687612332502965, 32.97817460078711, 33.26619906150987, 33.55175107203796, 33.83489323169204, 34.11568554199081, 34.394185555119634, 34.6704485116648, 34.94452746854649, 35.21647341799005, 35.48633539829099, 35.754160597055, 36.019994447528724, 36.283880718578054, 36.545861598818554, 36.805977775356006, 37.0642685075532, 37.32077169620157, 37.57552394844283, 37.82856063875548, 38.07991596629384, 38.32962300884266, 38.57771377362843, 38.824219245208276, 39.069169430639306, 39.31259340211481, 39.55451933723883, 39.794974557097035, 40.03398556226947, 40.271578066919616, 40.507777031083805, 40.74260669127591, 40.976090589513305, 41.20825160086267, 41.43911195959682, 41.6686932840472, 41.89701660023063, 42.124102364323456, 42.34997048405111, 42.5746403390563, 42.798130800304826, 43.02046024858406, 43.2416465921454, 43.4617072835387, 43.68065933568312, 43.89851933721685], [0.0, 4.409081537009721, 6.235382907247959, 7.636753236814714, 8.818163074019441, 9.859006035092992, 10.8, 11.665333257134149, 12.470765814495918, 13.22724461102916, 13.942740046346701, 14.623269128344731, 15.273506473629428, 15.897169559390125, 16.497272501841024, 17.076299364909246, 17.636326148038883, 18.17910888905174, 18.706148721743876, 19.218740853656364, 19.718012070185985, 20.204949888579286, 20.680425527536904, 21.14521222404732, 21.6, 22.045407685048605, 22.481992794234237, 22.91025971044414, 23.330666514268298, 23.743630724891254, 24.14953415699773, 24.54872705457454, 24.941531628991836, 25.328245103046523, 25.709142342754262, 26.08447814314099, 26.45448922205832, 26.819395966352413, 27.1794039669747, 27.53470537340104, 27.885480092693403, 28.231896854444624, 28.57411415949758, 28.912281127576215, 29.246538256689462, 29.57701810527897, 29.903845906505072, 30.227140122743997, 30.547012947258857, 30.863570759068047, 31.176914536239792, 31.487140232164627, 31.79433911878025, 32.09859810022862, 32.400000000000006, 32.69862382425291, 32.99454500368205, 33.287835616032474, 33.578564591119736, 33.8667979000082, 34.15259872981849, 34.43602764547619, 34.71714273957464, 34.995999771402445, 35.272652296077766, 35.5471517846367, 35.81954773583832, 36.089887780374156, 36.35821777810348, 36.62458190887645, 36.889022757454555, 37.15158139299053, 37.41229744348775, 37.671209165621434, 37.92835351026986, 38.18376618407357, 38.43748170731273, 38.689533468368424, 38.93995377501109, 39.18877390273904, 39.43602414037197, 39.68173383308749, 39.925931423073905, 40.16864448795852, 40.40989977715857, 40.64972324629038, 40.888140089761976, 41.12517477166511, 41.36085105507381, 41.59519202984884, 41.828220139040106, 42.05995720397252, 42.29042444809464, 42.51964251966379, 42.74763151333651, 42.97441099072796, 43.2, 43.424417094533354, 43.647680350735705, 43.86980738503419, 44.09081537009721, 44.310721050328226], [0.0, 4.449719092257398, 6.29285308902091, 7.707139547199078, 8.899438184514796, 9.949874371066201, 10.899541274750971, 11.772850122209151, 12.58570617804182, 13.349157276772193, 14.071247279470288, 14.758048651498614, 15.414279094398156, 16.043690348545127, 16.649324310613927, 17.233687939614086, 17.798876369029593, 18.34666182170479, 18.878559267062727, 19.39587585029354, 19.899748742132402, 20.391174561559716, 20.871032557111306, 21.34010309253449, 21.799082549501943, 22.24859546128699, 22.68920448142685, 23.121418641597234, 23.545700244418303, 23.962470657259033, 24.372115213907882, 24.774987386475097, 25.17141235608364, 25.561690084968955, 25.94609797252759, 26.32489316217637, 26.698314553544385, 27.06658456473591, 27.429910681589906, 27.788486824582588, 28.142494558940577, 28.492104169401042, 28.837475617675, 29.178759397890786, 29.516097302997228, 29.8496231131986, 30.179463215902302, 30.505737165326785, 30.82855818879631, 31.14803364580179, 31.464265445104548, 31.777350424476868, 32.08738069709025, 32.39444396806342, 32.69862382425291, 33.0, 33.298648621227855, 33.59464243000661, 33.88805099146306, 34.178940884702676, 34.46737587922817, 34.75341709817899, 35.03712316957544, 35.318550366627456, 35.597752738059185, 35.874782229304195, 36.149688795340964, 36.42252050586285, 36.69332364340958, 36.962142795027454, 37.22902093797257, 37.493999519923186, 37.75711853412545, 38.018416589858134, 38.277930978567795, 38.535697735995385, 38.79175170058708, 39.046126568457474, 39.298854945150765, 39.549968394424795, 39.799497484264805, 40.04747183031659, 40.29392013691396, 40.53887023586128, 40.78234912311943, 41.024382993532036, 41.26499727371856, 41.50421665325103, 41.74206511422261, 41.978565959308334, 42.21374183841087, 42.447614773977584, 42.68020618506898, 42.91153691025294, 43.14162722939412, 43.37049688440288, 43.598165099003886, 43.82465059758036, 44.04997162314636, 44.27414595449584, 44.49719092257398, 44.71912342611381], [0.0, 4.48998886412873, 6.3498031465550175, 7.776888838089433, 8.97997772825746, 10.039920318408907, 10.998181667894016, 11.879393923933998, 12.699606293110035, 13.469966592386188, 14.198591479439077, 14.891608375189028, 15.553777676178866, 16.18888507587845, 16.799999999999997, 17.389652095427323, 17.95995545651492, 18.512698344649813, 19.04940943966505, 19.57140771636011, 20.079840636817814, 20.575713839378697, 21.059914529741093, 21.533230133911637, 21.996363335788033, 22.44994432064365, 22.894540834006698, 23.330666514268298, 23.758787847867996, 24.17933001553186, 24.592681838303037, 24.99919998719959, 25.39921258622007, 25.793022312245615, 26.180909075125715, 26.563132345414388, 26.939933184772375, 27.3115360241785, 27.67815022720991, 28.039971469315017, 28.397182958878155, 28.749956521706256, 29.09845356715714, 29.442825951324707, 29.783216750378056, 30.119760955226717, 30.45258609707885, 30.781812812113582, 31.107555352357732, 31.42992204890111, 31.74901573277509, 32.064934118129734, 32.3777701517569, 32.68761233250297, 32.99454500368205, 33.298648621227855, 33.599999999999994, 33.898672540381284, 34.19473643706002, 34.48825887167979, 34.779304190854646, 35.0679340708859, 35.35420767037496, 35.638181771801996, 35.91991091302984, 36.19944750959605, 36.47684196856959, 36.75214279467253, 37.025396689299626, 37.296648643008126, 37.56594202199647, 37.83331864904267, 38.0988188793301, 38.36248167154987, 38.62434465463459, 38.88444419044716, 39.14281543272022, 39.39949238251681, 39.65450794045994, 39.90789395595814, 40.15968127363563, 40.40989977715857, 40.6585784306338, 40.905745317742344, 41.15142767875739, 41.395651945584824, 41.63844377495394, 41.879828079876354, 42.119829059482186, 42.3584702273347, 42.595774438317235, 42.83176391417939, 43.066460267823274, 43.299884526404924, 43.53205715332093, 43.76299806914513, 43.992726671576065, 44.221261854451875, 44.448622025885115, 44.67482512556709, 44.8998886412873, 45.123829624711604], [0.0, 4.52990066116245, 6.406246951218787, 7.846018098373213, 9.0598013223249, 10.129165809680481, 11.095945205344158, 11.984990613262907, 12.812493902437573, 13.589701983487348, 14.324803663575986, 15.023980830658699, 15.692036196746425, 16.33278910657944, 16.94933627019064, 17.544229820656135, 18.1196026446498, 18.677258899528056, 19.21874085365636, 19.745379206285204, 20.258331619360963, 20.758612670407434, 21.24711745155093, 21.72464038827801, 22.191890410688316, 22.64950330581225, 23.098051865904193, 23.53805429511964, 23.969981226525814, 24.394261620307347, 24.8112877537624, 25.221419468380443, 25.624987804875147, 26.022298130641733, 26.413632843666168, 26.799253720952755, 27.179403966974697, 27.554310007692084, 27.92418306772823, 28.289220561903083, 28.649607327151973, 29.00551671665237, 29.357111574540163, 29.704545106767746, 30.047961661317398, 30.38749742904144, 30.72328107478106, 31.05543430705808, 31.38407239349285, 31.70930462813715, 32.03123475609394, 32.34996136010057, 32.66557821315888, 32.97817460078711, 33.287835616032474, 33.5946424300066, 33.89867254038128, 34.2, 34.49869562751613, 34.79482720175515, 35.08845964131227, 35.379655170733365, 35.668473474484436, 35.954971839788726, 36.2392052892996, 36.52122670447968, 36.80108694046957, 37.0788349331529, 37.35451779905611, 37.62818092866037, 37.89986807364902, 38.169621428565414, 38.43748170731272, 38.70348821488833, 38.967678914710845, 39.23009049186606, 39.49075841257041, 39.74971698012453, 40.00699938760717, 40.26263776753828, 40.516663238721925, 40.769105950462055, 41.019995124329306, 41.26935909364234, 41.51722534081487, 41.763620532707655, 42.008570554114314, 42.25210053949981, 42.49423490310186, 42.734997367497286, 42.97441099072796, 43.212498192074015, 43.44928077655602, 43.684779958241755, 43.91901638242824, 44.15201014676455, 44.38378082137663, 44.614347468051136, 44.843728658531504, 45.071942491976095, 45.2990066116245, 45.52493822071592], [0.0, 4.569463863518345, 6.462197768561405, 7.914543574963752, 9.13892772703669, 10.217631819555843, 11.192854863706579, 12.089665007765932, 12.92439553712281, 13.708391590555035, 14.449913494550756, 15.15519712837811, 15.829087149927505, 16.47543626129518, 17.097368218530008, 17.69745744450315, 18.27785545407338, 18.8403821617291, 19.386593305684215, 19.917831207237402, 20.435263639111685, 20.939914039938177, 21.432685319390107, 21.914378841299616, 22.385709727413158, 22.847319317591726, 23.299785406737122, 23.743630724891258, 24.179330015531864, 24.607315985291855, 25.027984337537056, 25.44169805653703, 25.84879107424562, 26.249571425072833, 26.644323973409424, 27.033312782565147, 27.41678318111007, 27.79496357256113, 28.16806702633321, 28.53629268142588, 28.899826989101513, 29.258844816567866, 29.61351043020736, 29.96397837404105, 30.31039425675622, 30.652895458667523, 30.9916117683479, 31.32666595729587, 31.65817429985501, 31.98624704462842, 32.31098884280703, 32.63249913812916, 32.95087252259036, 33.26619906150987, 33.578564591119736, 33.888050991463054, 34.194736437060016, 34.49869562751613, 34.800000000000004, 35.0987179253032, 35.3949148890063, 35.688653659111324, 35.97999444135588, 36.2689950232978, 36.55571090814676, 36.840195439221006, 37.12249991581925, 37.40267370122088, 37.6807643234582, 37.95681756944331, 38.23087757297758, 38.502986897122675, 38.77318661136843, 39.04151636399386, 39.30801444998208, 39.57271787481876, 39.835662414474804, 40.0968826718487, 40.35641212992058, 40.61428320184908, 40.87052727822337, 41.12517477166511, 41.37825515896001, 41.62979702088397, 41.879828079876354, 42.12837523570071, 42.37546459922299, 42.6211215244273, 42.86537063878021, 43.10823587204654, 43.34974048365227, 43.589907088682814, 43.82875768259923, 44.066313664748506, 44.30259586073936, 44.53762454374952, 44.771419454826315, 45.00399982223803, 45.23538437992983, 45.465591385134324, 45.69463863518345, 45.9225434835659], [0.0, 4.608687448721165, 6.517668294720129, 7.982480817390043, 9.21737489744233, 10.305338422390601, 11.288932633336067, 12.193440859740944, 13.035336589440258, 13.826062346163493, 14.573949361789342, 15.285287043428397, 15.964961634780085, 16.616858908951475, 17.244129435839895, 17.849369736772218, 18.43474979488466, 19.002105146535737, 19.553004884160387, 20.08880285133985, 20.610676844781203, 21.119659088157647, 21.616660241582185, 22.10248854767264, 22.577865266672134, 23.043437243605823, 23.499787233079367, 23.947442452170126, 24.386881719481888, 24.81854145593572, 25.242820761555155, 25.660085736411716, 26.070673178880515, 26.47489376749225, 26.873034811870433, 27.26536264200423, 27.652124692326986, 28.033551326936802, 28.409857444204114, 28.781243892507494, 29.147898723578685, 29.50999830565905, 29.86770831516874, 30.221184622711263, 30.570574086856794, 30.9160152671718, 31.257639066314653, 31.595569309635803, 31.92992326956017, 32.260812141048156, 32.58834147360065, 32.91261156456595, 33.23371781790295, 33.55175107203796, 33.8667979000082, 34.17894088470267, 34.48825887167979, 34.79482720175515, 35.0987179253032, 35.4, 35.698739473544435, 35.99499965272955, 36.28884126008985, 36.58032257922284, 36.86949958976932, 37.15642609293848, 37.44115382837446, 37.72373258308355, 38.00421029307147, 38.28263313827825, 38.55904563134311, 38.833490700682574, 39.106009768320774, 39.37664282287153, 39.645428488036295, 39.91240408695021, 40.1776057026797, 40.44106823514928, 40.70282545475192, 40.962910052875884, 41.221353689562406, 41.47818703849049, 41.733439829470086, 41.98714088861016, 42.239318176315294, 42.48999882325252, 42.739209164419506, 42.98697477143512, 43.23332048316437, 43.47827043478156, 43.72184808536802, 43.964076244133686, 44.20497709534528, 44.444572222038545, 44.682882628586086, 44.919928762187496, 45.15573053334427, 45.39030733537724, 45.6236780630409, 45.85586113028519, 46.086874487211645, 46.316735636268675], [0.0, 4.6475800154488995, 6.572670690061993, 8.049844718999243, 9.295160030897799, 10.392304845413264, 11.384199576606164, 12.296340919151517, 13.145341380123986, 13.942740046346698, 14.696938456699067, 15.414279094398156, 16.099689437998485, 16.75708805252273, 17.389652095427323, 17.999999999999996, 18.590320061795598, 19.162463307205574, 19.718012070185978, 20.25833161936096, 20.784609690826528, 21.297887219158618, 21.79908254950194, 22.289010745208053, 22.76839915321233, 23.2379000772445, 23.6981011897578, 24.149534156997728, 24.592681838303033, 25.02798433753705, 25.45584412271571, 25.87663038341739, 26.29068276024797, 26.69831455354439, 27.099815497526915, 27.495454169735037, 27.885480092693395, 28.270125574535392, 28.64960732715197, 29.024127893874777, 29.393876913398135, 29.759032242329386, 30.119760955226717, 30.4762202380807, 30.82855818879631, 31.17691453623979, 31.521421287752872, 31.862203313644205, 32.19937887599697, 32.5330601081423, 32.863353450309965, 33.1903600462544, 33.51417610504546, 33.83489323169204, 34.15259872981849, 34.467375879228165, 34.779304190854646, 35.08845964131227, 35.3949148890063, 35.698739473544435, 35.99999999999999, 36.298760309410014, 36.59508163674457, 36.889022757454555, 37.180640123591196, 37.469987990390386, 37.75711853412545, 38.042081961953656, 38.32492661441115, 38.60569906114898, 38.88444419044716, 39.16120529299373, 39.436024140371956, 39.70894105865831, 39.97999499749843, 40.24922359499621, 40.51666323872192, 40.78234912311943, 41.046315303568974, 41.308594747340415, 41.569219381653056, 41.828220139040106, 42.08562700020043, 42.341469034505636, 42.595774438317235, 42.8485705712571, 43.09988399056313, 43.34974048365226, 43.59816509900388, 43.84518217546826, 44.090815370097204, 44.335087684586796, 44.578021490416106, 44.81963855275944, 45.05996005324461, 45.29900661162449, 45.53679830642466, 45.77335469462557, 46.008694830433946, 46.24283728319447, 46.475800154489, 46.70760109446856], [0.0, 4.686149805543993, 6.627216610312357, 8.11664955508121, 9.372299611087985, 10.47854951794379, 11.478675881825394, 12.398386991863095, 13.254433220624714, 14.058449416631976, 14.818906842274163, 15.542200616386344, 16.23329911016242, 16.89615340839447, 17.53396703544295, 18.149380154705007, 18.74459922217597, 19.32149062572554, 19.881649830937068, 20.426453436659045, 20.95709903588758, 21.474636201807936, 21.979990900817043, 22.473984960393654, 22.957351763650788, 23.430749027719962, 23.894769302087855, 24.34994866524363, 24.79677398372619, 25.23568901377571, 25.667099563448925, 26.091377886190678, 26.508866441249427, 26.919881129009468, 27.32471408816568, 27.72363612515501, 28.116898833263953, 28.50473644852729, 28.887367481305734, 29.26499615581728, 29.637813684548327, 30.005999400119972, 30.369721763625034, 30.729139265524502, 31.084401232772688, 31.435648553831363, 31.783014331557666, 32.126624472546126, 32.46659822032484, 32.80304863880795, 33.13608305156178, 33.46580344172242, 33.79230681678894, 34.1156855419908, 34.43602764547619, 34.75341709817899, 35.0679340708859, 35.379655170733365, 35.688653659111324, 35.99499965272954, 36.298760309410014, 36.6, 36.898780467652315, 37.19516097558928, 37.48919844435194, 37.780947579434795, 38.07046099011673, 38.35778930021906, 38.64298125145108, 38.92608379994062, 39.2071422064909, 39.48620012105495, 39.763299661874136, 40.038481489686895, 40.31178487737798, 40.58324777540604, 40.85290687331809, 41.120797657633055, 41.38695446635329, 41.65141054034065, 41.91419807177516, 42.17534824989594, 42.43489130420862, 42.69285654532851, 42.94927240361587, 43.204166465747264, 43.45756550935637, 43.70949553586726, 43.959981801634086, 44.20904884749275, 44.45672052682249, 44.703020032208116, 44.94796992078731, 45.19159213836132, 45.43390804234212, 45.67493842360381, 45.914703527301576, 46.15322307271726, 46.39051627218649, 46.62660184915903, 46.861498055439924, 47.09522268765698], [0.0, 4.724404724407086, 6.681317235396026, 8.182909018191513, 9.448809448814172, 10.564090116995406, 11.572380913191546, 12.499599993599794, 13.362634470792052, 14.173214173221258, 14.939879517586478, 15.669077828640715, 16.365818036383025, 17.03408347989407, 17.67710383518748, 18.297540818372283, 18.897618897628345, 19.479219696897513, 20.04395170618808, 20.59320276207662, 21.12818023399081, 21.64994226320246, 22.159422375143265, 22.65744910619905, 23.144761826383093, 23.62202362203543, 24.08983187986168, 24.54872705457454, 24.99919998719959, 25.441698056537028, 25.87663038341739, 26.304372260139566, 26.725268941584105, 27.13963890695674, 27.547776679797593, 27.949955277245078, 28.346428346442515, 28.737432035587315, 29.123186638827832, 29.50389804754619, 29.879759035172956, 30.250950398293273, 30.617641973215378, 30.9799935442214, 31.33815565728143, 31.692270350986213, 32.04247181476485, 32.388886983037864, 32.73163607276605, 33.07083307084961, 33.406586176980134, 33.73899820682292, 34.06816695978814, 34.394185555119634, 34.71714273957464, 35.03712316957544, 35.35420767037496, 35.668473474484436, 35.979994441355885, 36.28884126008985, 36.59508163674457, 36.898780467652315, 37.199999999999996, 37.49879998079938, 37.79523779525669, 38.0893685954493, 38.38124542012674, 38.67091930637284, 38.958439393795025, 39.243853021842796, 39.52720582080145, 39.808541796956085, 40.08790341237616, 40.36533165972998, 40.64086613250264, 40.91454509095756, 41.18640552415324, 41.45648320829928, 41.72481276171291, 41.99142769661446, 42.25636046798162, 42.51964251966378, 42.78130432794213, 43.04137544270628, 43.29988452640492, 43.55685939091569, 43.81232703246884, 44.06631366474849, 44.31884475028653, 44.56994503025553, 44.819638552759436, 45.06794869971341, 45.3148982123981, 45.56050921576712, 45.80480324158155, 46.04780125043974, 46.289523652766185, 46.52999032881912, 46.76922064777218, 47.00723348592214, 47.24404724407086, 47.47967986412714], [0.0, 4.762352359916263, 6.734983296193095, 8.248636250920512, 9.524704719832526, 10.64894360957931, 11.665333257134149, 12.6, 13.46996659238619, 14.287057079748788, 15.05988047761336, 15.794935897305821, 16.497272501841024, 17.17090562550502, 17.819090885900998, 18.444511378727277, 19.04940943966505, 19.635681806344287, 20.204949888579282, 20.758612670407434, 21.29788721915862, 21.823840175367856, 22.337412562783545, 22.83943957280914, 23.330666514268298, 23.811761799581316, 24.28332761381768, 24.745908752761537, 25.2, 25.646052327795015, 26.08447814314099, 26.515655752781225, 26.93993318477238, 27.357631476427198, 27.769047516974727, 28.17445651649735, 28.574114159497576, 28.96825849097595, 29.357111574540163, 29.740880955344952, 30.11976095522672, 30.493933822975354, 30.863570759068047, 31.228832831215446, 31.589871794611643, 31.946830828737927, 32.29984520086745, 32.6490428649907, 32.99454500368205, 33.33646651941385, 33.67491648096547, 34.00999852984413, 34.34181125101004, 34.6704485116648, 34.995999771402445, 35.31855036662745, 35.638181771801996, 35.954971839788726, 36.2689950232978, 36.58032257922284, 36.889022757454555, 37.19516097558929, 37.49879998079938, 37.800000000000004, 38.0988188793301, 38.39531221386277, 38.68953346836842, 38.98153408987388, 39.271363612688575, 39.55906975650464, 39.84469851812158, 40.128294257294314, 40.409899777158564, 40.689556399646335, 40.967304036267755, 41.24318125460256, 41.51722534081487, 41.789472358478044, 42.05995720397253, 42.32871365869745, 42.59577443831724, 42.861171239246374, 43.124934782559386, 43.38709485549822, 43.64768035073571, 43.90671930354169, 44.164238926987075, 44.42026564531104, 44.67482512556709, 44.927942307655265, 45.17964143284008, 45.42994607084626, 45.67887914561828, 45.92646295982308, 46.17271921817038, 46.417669049619455, 46.661333028536596, 46.90373119486338, 47.14488307335166, 47.384807691917466, 47.62352359916263, 47.86104888111], [0.0, 4.8, 6.788225099390856, 8.313843876330612, 9.6, 10.733126291998992, 11.757550765359255, 12.699606293110035, 13.576450198781712, 14.399999999999999, 15.17893276880822, 15.919798993705921, 16.627687752661224, 17.30664612222715, 17.95995545651492, 18.590320061795598, 19.2, 19.790907002964772, 20.364675298172568, 20.922714928995237, 21.466252583997985, 21.996363335788033, 22.513995647152463, 23.01999131190106, 23.51510153071851, 24.0, 24.47529366524537, 24.941531628991836, 25.39921258622007, 25.84879107424562, 26.290682760247975, 26.725268941584105, 27.152900397563425, 27.57390070338254, 27.988569095257446, 28.397182958878158, 28.799999999999997, 29.197260145431457, 29.589187214251087, 29.975990392312312, 30.35786553761644, 30.73499633967768, 31.107555352357732, 31.475704916649597, 31.839597987411842, 32.19937887599697, 32.55518391900129, 32.90714208192501, 33.25537550532245, 33.6, 33.941125496954285, 34.27885645700569, 34.6132922444543, 34.94452746854649, 35.272652296077766, 35.597752738059185, 35.91991091302984, 36.2392052892996, 36.555710908146764, 36.86949958976932, 37.180640123591196, 37.48919844435194, 37.79523779525669, 38.0988188793301, 38.4, 38.698837191833036, 38.995384342252606, 39.28969330498776, 39.581814005929544, 39.87179454200676, 40.15968127363563, 40.44551891124652, 40.729350596345135, 41.01121797752415, 41.29116128180461, 41.569219381653056, 41.845429857990474, 42.11982905948219, 42.39245215837367, 42.66333320311483, 42.93250516799597, 43.2, 43.4658486630596, 43.73008117989263, 43.992726671576065, 44.253813395005864, 44.51336877837939, 44.771419454826315, 45.027991294304925, 45.2831094338717, 45.536798306424664, 45.789081668013395, 46.03998262380212, 46.28952365276619, 46.53772663119676, 46.784612855083026, 47.03020306143702, 47.27451744862131, 47.51757569573599, 47.75939698111777, 48.0, 48.23940298138029], [0.0, 4.8373546489791295, 6.841052550594828, 8.378544026261364, 9.674709297958259, 10.816653826391969, 11.849050594878898, 12.798437404620925, 13.682105101189656, 14.512063946937387, 15.297058540778353, 16.043690348545127, 16.75708805252273, 17.44133022449836, 18.099723754798024, 18.734993995195193, 19.349418595916518, 19.94492416631359, 20.52315765178448, 21.085540068966697, 21.633307652783937, 22.167543842293398, 22.689204481426845, 23.19913791501745, 23.698101189757796, 24.186773244895647, 24.66576574931336, 25.135632078784095, 25.59687480924185, 26.04995201531089, 26.49528259898354, 26.933250824956126, 27.36421020237931, 27.788486824582588, 28.20638225650358, 28.618176042508367, 29.024127893874773, 29.42447960457415, 29.819456735494022, 30.20927010041785, 30.594117081556707, 30.974182797936738, 31.349641146271512, 31.72065573092712, 32.08738069709025, 32.449961479175904, 32.80853547478156, 33.16323265304514, 33.51417610504546, 33.861482542853906, 34.205262752974136, 34.54562200916348, 34.88266044899672, 35.21647341799005, 35.5471517846367, 35.87478222930419, 36.19944750959605, 36.52122670447968, 36.840195439221006, 37.15642609293848, 37.469987990390386, 37.780947579434795, 38.0893685954493, 38.39531221386277, 38.698837191833036, 38.99999999999999, 39.29885494515075, 39.595454284551394, 39.88984833262718, 40.182085560607725, 40.47221268969612, 40.76027477826909, 41.04631530356896, 41.330376238306854, 41.61249812255928, 41.89272013130682, 42.171080137933394, 42.447614773977584, 42.72235948540296, 42.99534858563191, 43.266615305567875, 43.53619184081217, 43.80410939626555, 44.07039822828924, 44.335087684586796, 44.59820624195552, 44.85978154204499, 45.11984042524973, 45.37840896285369, 45.6355124875354, 45.89117562233506, 46.145422308177004, 46.3982758300349, 46.6497588418204, 46.89989339007072, 47.14870093650513, 47.39620237951559, 47.64241807465277, 47.887367854163784, 48.13107104563538, 48.373546489791295, 48.61481255749116], [0.0, 4.874423042781576, 6.8934751758456345, 8.442748367682174, 9.748846085563152, 10.899541274750971, 11.93984924527944, 12.896511156122806, 13.786950351691269, 14.623269128344727, 15.414279094398154, 16.166632302368978, 16.88549673536435, 17.57498221905217, 18.238420984284794, 18.878559267062727, 19.497692171126303, 20.09776106933307, 20.6804255275369, 21.24711745155093, 21.799082549501943, 22.33741256278354, 22.863070659909184, 23.37691168653379, 23.87969849055888, 24.372115213907882, 24.854778212649578, 25.32824510304652, 25.79302231224561, 26.24957142507283, 26.69831455354439, 27.13963890695674, 27.573900703382538, 28.001428534987287, 28.42252627758483, 28.837475617674997, 29.246538256689455, 29.64995784145401, 30.047961661317395, 30.440762145517976, 30.828558188796308, 31.21153632873589, 31.58987179461164, 31.96372944448128, 32.333264604737955, 32.69862382425291, 33.05994555349419, 33.41736075754637, 33.7709934707287, 34.120961299471034, 34.46737587922817, 34.810343290464694, 35.14996443810434, 35.48633539829099, 35.81954773583832, 36.149688795340964, 36.47684196856959, 36.801086940469574, 37.122499915819255, 37.44115382837447, 37.75711853412545, 38.070460990116736, 38.38124542012674, 38.68953346836842, 38.995384342252606, 39.29885494515075, 39.599999999999994, 39.89887216451111, 40.19552213866614, 40.48999876512717, 40.78234912311943, 41.07261861629959, 41.3608510550738, 41.64708873378786, 41.93137250317476, 42.21374183841086, 42.49423490310186, 42.77288860949188, 43.04973867516504, 43.324819676485674, 43.598165099003886, 43.86980738503419, 44.13977797859885, 44.408107367911995, 44.67482512556708, 44.939959946577616, 45.20353968440968, 45.46559138513432, 45.72614131981837, 45.98521501526333, 46.24283728319446, 46.49903224799415, 46.75382337306758, 47.00723348592215, 47.25928480203652, 47.50999894758997, 47.75939698111776, 48.00749941415404, 48.25432623091943, 48.49989690710693, 48.744230427815765, 48.98734530468048], [0.0, 4.91121166312347, 6.945502141674135, 8.506468127254696, 9.82242332624694, 10.981803130633876, 12.029962593458054, 12.99384469662463, 13.89100428334827, 14.733634989370408, 15.53061492665374, 16.288646352597873, 17.01293625450939, 17.707625476048445, 18.376071397336265, 19.021040980976828, 19.64484665249388, 20.249444436823445, 20.836506425022403, 21.40747532989353, 21.963606261267753, 22.50599920021326, 23.035624584542962, 23.553343711668628, 24.059925186916107, 24.55605831561735, 25.04236410565105, 25.519404381764087, 25.98768939324926, 26.44768420864103, 26.899814125751874, 27.344469276254017, 27.78200856669654, 28.212763069220998, 28.63703895307614, 29.055120030727803, 29.467269978740816, 29.873734282811046, 30.27474194770287, 30.67050700591694, 31.06122985330748, 31.447098435308785, 31.828289303699627, 32.204968560767135, 32.577292705195745, 32.94540939190163, 33.30945811627682, 33.66957083183568, 34.02587250901878, 34.37848164186429, 34.72751070837068, 35.07306658962116, 35.41525095209689, 35.754160597055, 36.089887780374156, 36.42252050586285, 36.75214279467253, 37.078834933152905, 37.402673701220884, 37.72373258308355, 38.042081961953656, 38.35778930021906, 38.670919306372845, 38.98153408987389, 39.28969330498776, 39.5954542845514, 39.89887216451111, 40.199999999999996, 40.49888887364689, 40.79558799674298, 41.09014480383344, 41.382605041248915, 41.673012850044806, 41.96141084377407, 42.247840181481465, 42.532340636273474, 42.81495065978706, 43.09570744285329, 43.37464697262677, 43.65180408642924, 43.927212522535505, 44.20090496811123, 44.47291310449542, 44.74326765000517, 45.01199840042652, 45.27913426734218, 45.544703314436035, 45.80873279190333, 46.071249169085924, 46.33227816544315, 46.59184477996122, 46.84997331909592, 47.106687423337256, 47.36201009247814, 47.61596370966359, 47.86857006429166, 48.119850373832215, 48.369825304625614, 48.61851499171894, 48.865939057793625, 49.1121166312347, 49.35706636338915], [0.0, 4.947726750741192, 6.997142273814361, 8.56971411425142, 9.895453501482384, 11.063453348751466, 12.119405926034494, 13.090454537562858, 13.994284547628721, 14.843180252223576, 15.646085772486357, 16.40975319741281, 17.13942822850284, 17.839282496782207, 18.512698344649813, 19.162463307205574, 19.79090700296477, 20.4, 20.99142682144308, 21.566640906733717, 22.126906697502932, 22.673332353229423, 23.20689552697646, 23.72846391994223, 24.238811852068988, 24.738633753705965, 25.22855524995437, 25.709142342754262, 26.180909075125715, 26.64432397340942, 27.099815497526915, 27.547776679797593, 27.988569095257443, 28.42252627758483, 28.849956672411142, 29.271146202361123, 29.68636050444715, 30.09584688956269, 30.499836065133202, 30.89854365500096, 31.292171544972714, 31.68090907786581, 32.06493411812973, 32.444414003029856, 32.81950639482562, 33.19036004625439, 33.55711548986295, 33.919905660246165, 34.27885645700568, 34.63408725518835, 34.98571136907181, 35.3338364744051, 35.678564993564414, 36.019994447528724, 36.35821777810348, 36.69332364340957, 37.025396689299626, 37.35451779905611, 37.6807643234582, 38.00421029307147, 38.32492661441115, 38.64298125145108, 38.958439393795025, 39.271363612688575, 39.58181400592954, 39.88984833262718, 40.19552213866614, 40.49888887364689, 40.8, 41.0989050949049, 41.39565194558482, 41.6902866384965, 41.98285364288616, 42.27339588914049, 42.56195484232368, 42.8485705712571, 43.133281813467434, 43.41612603630131, 43.69713949447951, 43.97635728434087, 44.253813395005864, 44.52954075667074, 44.80357128622673, 45.075935930383075, 45.346664706458846, 45.615786740995716, 45.88333030633239, 46.14932285527058, 46.41379105395292, 46.67676081306414, 46.93825731745907, 47.198305054313124, 47.45692783988446, 47.71414884497051, 47.96999061913604, 48.22447511378429, 48.477623704137976, 48.72945721019269, 48.97999591670052, 49.22925959223844, 49.47726750741193, 49.7240384522416], [0.0, 4.983974317750845, 7.048404074682439, 8.632496741962896, 9.96794863550169, 11.144505372604028, 12.208193969625484, 13.186356585501548, 14.096808149364877, 14.951922953252534, 15.760710643876436, 16.529972776747094, 17.264993483925792, 17.969974958246326, 18.648324321504063, 19.302849530574495, 19.93589727100338, 20.54945254745245, 21.145212224047317, 21.72464038827801, 22.289010745208056, 22.839439572809138, 23.37691168653379, 23.90230114445051, 24.416387939250967, 24.919871588754226, 25.41338230145685, 25.89749022588869, 26.372713171003095, 26.83952309561405, 27.298351598585583, 27.749594591633226, 28.193616298729754, 28.630752697056366, 29.061314491949606, 29.485589700733478, 29.90384590650507, 30.316332231983477, 30.72328107478106, 31.124909638423052, 31.521421287752872, 31.913006752733285, 32.29984520086745, 32.68210519535117, 33.05994555349419, 33.433516117812076, 33.80295845040786, 34.16840645976924, 34.529986967851585, 34.88782022425592, 35.242020373412196, 35.59269587991334, 35.93994991649265, 36.283880718578054, 36.62458190887645, 36.962142795027454, 37.296648643008126, 37.62818092866037, 37.95681756944331, 38.28263313827825, 38.60569906114899, 38.92608379994063, 39.243853021842796, 39.55906975650464, 39.87179454200676, 40.182085560607725, 40.48999876512717, 40.79558799674298, 41.0989050949049, 41.4, 41.69892084934573, 41.99571406703308, 42.29042444809463, 42.58309523742961, 42.873768203879635, 43.162483709814474, 43.44928077655602, 43.73419714594062, 44.01726933829495, 44.298532707077335, 44.57802149041611, 44.85576885975761, 45.13180696581958, 45.40616698203009, 45.678879145618275, 45.94997279650991, 46.219476414169826, 46.48741765252185, 46.75382337306758, 47.01871967631616, 47.28213193162931, 47.54408480557808, 47.80460228890102, 48.06370772214729, 48.321423820082124, 48.57777269492705, 48.832775878501934, 49.08645434333184, 49.338828522777064, 49.58991833024129, 49.83974317750845, 50.08832199225685], [0.0, 5.019960159204453, 7.0992957397195395, 8.694826047713665, 10.039920318408907, 11.224972160321826, 12.296340919151518, 13.281566172707194, 14.198591479439079, 15.059880477613358, 15.874507866387544, 16.64932431061393, 17.38965209542733, 18.099723754798028, 18.78297101099823, 19.44222209522358, 20.079840636817814, 20.69782597279241, 21.297887219158618, 21.881499034572567, 22.449944320643652, 23.004347415216976, 23.545700244418303, 24.07488317728666, 24.592681838303037, 25.09980079602227, 25.596874809241854, 26.08447814314099, 26.563132345414388, 27.033312782565147, 27.49545416973504, 27.94995527724508, 28.397182958878158, 28.837475617675004, 29.271146202361127, 29.698484809834998, 30.119760955226717, 30.53522555999874, 30.945112699746304, 31.34964114627152, 31.74901573277509, 32.1434285663493, 32.5330601081423, 32.918080138428486, 33.29864862122786, 33.67491648096547, 34.04702630186666, 34.415112959279966, 34.77930419085466, 35.139721114431175, 35.4964786985977, 35.84968619109518, 36.199447509596055, 36.545861598818554, 36.889022757454555, 37.22902093797257, 37.56594202199646, 37.89986807364902, 38.23087757297758, 38.55904563134311, 38.88444419044716, 39.2071422064909, 39.52720582080145, 39.84469851812158, 40.15968127363563, 40.47221268969612, 40.78234912311943, 41.09014480383344, 41.39565194558482, 41.69892084934573, 42.00000000000001, 42.29893615683496, 42.595774438317235, 42.89055840158764, 43.1833301170718, 43.474130238568314, 43.762998069145134, 44.04997162314637, 44.33508768458681, 44.6183818621877, 44.899888641287305, 45.179641432840086, 45.45767261970195, 45.73401360038281, 46.00869483043395, 46.28174586162454, 46.55319537904998, 46.82307123630401, 47.091400488836605, 47.35820942561068, 47.62352359916263, 47.8873678541638, 48.14976635457332, 48.410742609466354, 48.67031949761579, 48.928519290900276, 49.18536367660607, 49.4408737786864, 49.69507017803677, 49.9479729318418, 50.19960159204454, 50.44997522298699], [0.0, 5.0556898639058145, 7.149825172687791, 8.756711711595855, 10.111379727811629, 11.304866208850065, 12.383860464330176, 13.376098085764772, 14.299650345375582, 15.167069591717445, 15.987495113369073, 16.767826334978544, 17.51342342319171, 18.228549037155975, 18.916659324521333, 19.580602646496864, 20.222759455623258, 20.84514331924825, 21.449475518063373, 22.037241206648353, 22.60973241770013, 23.16808149156939, 23.713287414443407, 24.246236821412104, 24.767720928660353, 25.278449319529077, 25.779061270729006, 26.270135134787566, 26.752196171529544, 27.225723130892227, 27.691153822114384, 28.14888985377576, 28.599300690751164, 29.04272714467428, 29.479484391691795, 29.909864593474843, 30.33413918343489, 30.7525608689748, 31.165365391729324, 31.572773080614887, 31.974990226738147, 32.37221030451891, 32.764615059542514, 33.152375480499124, 33.53565266995709, 33.91459862655019, 34.28935694935092, 34.660063473686826, 35.02684684638342, 35.38982904734071, 35.749125863438955, 36.10484731999293, 36.45709807431195, 36.805977775356006, 37.15158139299053, 37.493999519923186, 37.83331864904267, 38.169621428565414, 38.502986897122675, 38.833490700682574, 39.16120529299373, 39.48620012105495, 39.808541796956085, 40.128294257294314, 40.445518911246516, 40.76027477826909, 41.07261861629959, 41.38260504124891, 41.6902866384965, 41.99571406703308, 42.29893615683496, 42.6, 42.898951036126746, 43.195833132375164, 43.49068865860829, 43.78355855797927, 44.07448241329671, 44.363498509472855, 44.65064389233375, 44.93595442404668, 45.21946483540026, 45.50120877515234, 45.7812188566447, 46.05952670186701, 46.33616298313878, 46.6111574625647, 46.88453902940713, 47.15633573550854, 47.426574828886814, 47.69528278561728, 47.96248534010722, 48.2282075138606, 48.49247364282421, 48.75530740339969, 49.01673183720025, 49.2767693746252, 49.535441857320706, 49.79277055959028, 50.04877620881453, 50.30347900493564, 50.556898639058154, 50.80905431121505], [0.0, 5.091168824543142, 7.2, 8.818163074019441, 10.182337649086284, 11.384199576606168, 12.470765814495918, 13.46996659238619, 14.4, 15.273506473629425, 16.099689437998485, 16.88549673536435, 17.636326148038883, 18.356470248934027, 19.04940943966505, 19.718012070185978, 20.364675298172568, 20.99142682144308, 21.599999999999998, 22.19189041068832, 22.768399153212336, 23.330666514268298, 23.87969849055888, 24.41638793925097, 24.941531628991836, 25.45584412271571, 25.959969183340725, 26.454489222058324, 26.93993318477238, 27.41678318111007, 27.885480092693403, 28.34642834644252, 28.8, 29.246538256689462, 29.68636050444716, 30.11976095522672, 30.54701294725885, 30.96837096135346, 31.38407239349285, 31.79433911878025, 32.19937887599697, 32.5993864972947, 32.99454500368205, 33.38502658378453, 33.7709934707287, 34.1525987298185, 34.529986967851585, 34.903294973397564, 35.272652296077766, 35.638181771801996, 36.0, 36.35821777810349, 36.712940497868054, 37.06426850755321, 37.41229744348775, 37.75711853412545, 38.0988188793301, 38.43748170731272, 38.77318661136844, 39.106009768320774, 39.436024140371956, 39.76329966187414, 40.08790341237616, 40.40989977715857, 40.729350596345135, 41.04631530356897, 41.3608510550738, 41.673012850044806, 41.98285364288616, 42.29042444809463, 42.595774438317235, 42.898951036126746, 43.199999999999996, 43.49896550494046, 43.795890218147186, 44.090815370097204, 44.38378082137664, 44.67482512556709, 44.963985588468475, 45.25129832391553, 45.53679830642467, 45.82051942088828, 46.10249450951651, 46.38275541621045, 46.661333028536596, 46.938257317459076, 47.213557374974414, 47.48726144978251, 47.75939698111776, 48.029990630854805, 48.299068313995456, 48.56665522763535, 48.83277587850194, 49.09745410914909, 49.36071312288752, 49.6225755075248, 49.88306325798367, 50.142197797862835, 50.4, 50.656490206093046, 50.91168824543142, 51.165613452786836], [0.0, 5.126402247190518, 7.249827584156743, 8.879189152169246, 10.252804494381037, 11.462983904725682, 12.55706972187381, 13.563185466548779, 14.499655168313486, 15.379206741571554, 16.211107303327555, 17.002352778365704, 17.758378304338493, 18.483506160899235, 19.181240835774936, 19.854470529329156, 20.505608988762074, 21.136697944570244, 21.74948275247023, 22.34546933944329, 22.925967809451365, 23.49212634054227, 24.044957891416654, 24.58536149825746, 25.11413944374762, 25.632011235952593, 26.13962509295036, 26.63756745650774, 27.126370933097558, 27.606520968785617, 28.07846149631422, 28.542599741439112, 28.999310336626973, 29.44893886033927, 29.891804896994763, 30.32820469464027, 30.75841348314311, 31.18268750444708, 31.601265797432863, 32.01437177268984, 32.42221460665511, 32.82499047981583, 33.222883679777105, 33.61606758679545, 34.00470555673141, 34.38895171417704, 34.768951666681005, 35.14484314945793, 35.516756608676985, 35.884815730333635, 36.24913792078372, 36.60983474423232, 36.96701232179847, 37.32077169620157, 37.671209165621434, 38.018416589858134, 38.36248167154987, 38.70348821488833, 39.04151636399386, 39.37664282287153, 39.70894105865831, 40.038481489686895, 40.36533165972998, 40.689556399646335, 41.01121797752415, 41.330376238306854, 41.64708873378786, 41.96141084377407, 42.27339588914049, 42.5830952374296, 42.89055840158764, 43.195833132375164, 43.49896550494046, 43.8, 44.0989795800311, 44.395945760846224, 44.69093867888658, 44.98399715454375, 45.27515875179236, 45.564459834392856, 45.85193561890273, 46.137620224714674, 46.42154672132328, 46.70374717300529, 46.98425268108454, 47.263093423939154, 47.54029869489674, 47.81589693815227, 48.08991578283331, 48.36238207532793, 48.63332190998267, 48.90276065826959, 49.17072299651492, 49.437232932274846, 49.702313829438566, 49.96598843213251, 50.22827888749524, 50.48920676738743, 50.7487930890972, 51.00705833509712, 51.264022471905186, 51.519704968099354], [0.0, 5.161395160225576, 7.299315036357863, 8.939798655450804, 10.322790320451151, 11.541230437002808, 12.642784503423286, 13.65576801208925, 14.598630072715727, 15.484185480676725, 16.321764610482532, 17.118411141224527, 17.87959731090161, 18.609674903124986, 19.312172327317295, 19.989997498749215, 20.645580640902303, 21.28097742116184, 21.89794510907359, 22.49799991110321, 23.082460874005616, 23.652484013312428, 24.209089202198417, 24.753181613683527, 25.285569006846572, 25.80697580112788, 26.318054639353573, 26.819395966352413, 27.3115360241785, 27.794963572561127, 28.270125574535392, 28.73743203558731, 29.197260145431454, 29.64995784145401, 30.095846889562686, 30.535225559998732, 30.96837096135345, 31.395541084682712, 31.81697660055084, 32.232902444551904, 32.643529220965064, 33.04905444940899, 33.44966367543925, 33.845531462809085, 34.236822282449054, 34.623691311008415, 35.00628514995557, 35.38474247468815, 35.75919462180322, 36.12976612157903, 36.49657518178932, 36.85973412817841, 37.21934980624997, 37.57552394844282, 37.92835351026986, 38.27793097856779, 38.62434465463459, 38.96767891471084, 39.30801444998208, 39.645428488036295, 39.97999499749843, 40.31178487737798, 40.64086613250264, 40.96730403626775, 41.291161281804605, 41.61249812255928, 41.93137250317475, 42.247840181481465, 42.56195484232368, 42.87376820387963, 43.1833301170718, 43.49068865860829, 43.79589021814718, 44.0989795800311, 44.4, 44.69899327725401, 44.99599982220642, 45.29105872023749, 45.584207791734194, 45.87548364867666, 46.16492174801123, 46.452556442030186, 46.738421025961074, 47.02254778295195, 47.304968026624856, 47.58571214135605, 47.86480962042992, 48.14228910220202, 48.41817840439683, 48.69250455665635, 48.965293831447596, 49.23657177342874, 49.50636322736705, 49.77469236469474, 50.0415827087833, 50.307057159010995, 50.571138013693144, 50.83384699194033, 51.09520525450504, 51.35523342367358, 51.61395160225576, 51.87137939172238], [0.0, 5.196152422706632, 7.3484692283495345, 9.0, 10.392304845413264, 11.618950038622252, 12.727922061357855, 13.74772708486752, 14.696938456699069, 15.588457268119894, 16.431676725154983, 17.233687939614086, 18.0, 18.734993995195193, 19.442222095223578, 20.124611797498105, 20.784609690826528, 21.42428528562855, 22.045407685048602, 22.649503305812253, 23.237900077244504, 23.811761799581316, 24.372115213907882, 24.91987158875423, 25.45584412271571, 25.98076211353316, 26.495282598983543, 27.000000000000004, 27.49545416973504, 27.982137159266447, 28.460498941515414, 28.930952282978865, 29.393876913398138, 29.849623113198604, 30.298514815086236, 30.740852297878796, 31.17691453623979, 31.60696125855822, 32.03123475609393, 32.449961479175904, 32.863353450309965, 33.27160951922826, 33.67491648096547, 34.073450074801634, 34.46737587922817, 34.85685011586675, 35.242020373412196, 35.62302626111375, 36.0, 36.373066958946424, 36.742346141747674, 37.107950630558946, 37.469987990390386, 37.82856063875548, 38.18376618407357, 38.535697735995385, 38.884444190447155, 39.230090491866065, 39.572717874818764, 39.91240408695021, 40.24922359499621, 40.58324777540605, 40.91454509095757, 41.24318125460256, 41.569219381653056, 41.892720131306824, 42.21374183841086, 42.532340636273474, 42.8485705712571, 43.162483709814474, 43.47413023856832, 43.78355855797927, 44.090815370097204, 44.395945760846224, 44.69899327725402, 45.0, 45.299006611624506, 45.596052460711995, 45.89117562233507, 46.18441295502196, 46.47580015448901, 46.765371804359695, 47.05316142407437, 47.3392015141785, 47.62352359916263, 47.90615826801395, 48.18713521262704, 48.46648326421054, 48.744230427815765, 49.02040391510457, 49.29503017546495, 49.56813492557492, 49.83974317750846, 50.109879265470205, 50.37856687124, 50.6458290484024, 50.91168824543142, 51.17616632769595, 51.43928459844673, 51.701063818842265, 51.96152422706632, 52.22068555658764], [0.0, 5.230678732248808, 7.397296803562773, 9.059801322324901, 10.461357464497617, 11.69615321377076, 12.812493902437575, 13.839075113604958, 14.794593607125545, 15.692036196746425, 16.540858502508268, 17.348198753761157, 18.119602644649802, 18.859480374602054, 19.57140771636011, 20.25833161936096, 20.922714928995234, 21.566640906733717, 22.191890410688316, 22.800000000000004, 23.39230642754152, 23.969981226525817, 24.534057960313053, 25.085453952440254, 25.62498780487515, 26.153393661244046, 26.67133292507145, 27.179403966974704, 27.678150227209915, 28.16806702633321, 28.649607327151976, 29.123186638827836, 29.58918721425109, 30.0479616613174, 30.49983606513321, 30.945112699746307, 31.38407239349285, 31.816976600550852, 32.24406922210657, 32.66557821315888, 33.081717005016536, 33.492685768686876, 33.898672540381284, 34.29985422709548, 34.69639750752231, 35.08845964131228, 35.47618919782676, 35.85972671396144, 36.239205289299605, 36.61475112574166, 36.986484017813865, 37.35451779905612, 37.71896074920411, 38.07991596629384, 38.43748170731273, 38.79175170058708, 39.14281543272022, 39.49075841257041, 39.835662414474804, 40.1776057026797, 40.51666323872192, 40.85290687331809, 41.18640552415324, 41.51722534081487, 41.84542985799047, 42.171080137933394, 42.494234903101855, 42.81495065978706, 43.133281813467434, 43.449280776556016, 43.762998069145134, 44.07448241329671, 44.38378082137663, 44.69093867888658, 44.99599982220642, 45.2990066116245, 45.60000000000001, 45.89901959737267, 46.19610373180839, 46.49128950674525, 46.78461285508304, 47.076108590239286, 47.36581045437733, 47.65375116399547, 47.939962453051635, 48.2244751137843, 48.50731903537858, 48.788523240614694, 49.068115920626106, 49.34612446788502, 49.6225755075248, 49.897494927100304, 50.17090790488051, 50.4428389367609, 50.71331186187706, 50.98234988699521, 51.2499756097503, 51.51621104079765, 51.7810776249394, 52.044596261283466, 52.30678732248809, 52.56767067314284], [0.0, 5.264978632435273, 7.445804187594514, 9.119210492142399, 10.529957264870546, 11.772850122209151, 12.896511156122807, 13.92982411949268, 14.891608375189028, 15.794935897305818, 16.64932431061393, 17.4619586530263, 18.238420984284797, 18.98315042346765, 19.699746191258402, 20.391174561559712, 21.059914529741093, 21.708063018150654, 22.33741256278354, 22.949509798686336, 23.545700244418303, 24.127163115459723, 24.694938752708016, 25.24995049500098, 25.793022312245615, 26.324893162176366, 26.846228785436516, 27.357631476427198, 27.85964823898536, 28.352777641705586, 28.837475617675, 29.31416040073466, 29.783216750378056, 30.24499958670855, 30.69983713311848, 31.148033645801785, 31.589871794611636, 32.025614748198045, 32.45550800711645, 32.87978102116862, 33.29864862122786, 33.71231229091236, 34.120961299471034, 34.52477371395792, 34.9239173060526, 35.31855036662745, 35.70882243927963, 36.09487498246808, 36.476841968569595, 36.85485042704692, 37.22902093797257, 37.59946808134392, 37.9663008469353, 38.32962300884266, 38.689533468368424, 39.04612656845747, 39.399492382516804, 39.749716980124525, 40.0968826718487, 40.44106823514928, 40.782349123119424, 41.120797657633055, 41.456483208299275, 41.789472358478044, 42.119829059482186, 42.447614773977584, 42.77288860949188, 43.09570744285328, 43.41612603630131, 43.73419714594061, 44.04997162314637, 44.363498509472855, 44.67482512556708, 44.98399715454375, 45.29105872023749, 45.59605246071199, 45.89901959737267, 46.2, 46.49903224799416, 46.796153688097064, 47.091400488836605, 47.384807691917466, 47.67640926076544, 47.96623812641554, 48.254326230919446, 48.540704568434116, 48.82540322414143, 49.10845141113696, 49.38987750541603, 49.66970907907555, 49.94797293184179, 50.224695121025874, 50.49990099000196, 50.77361519529608, 51.04586173236769, 51.316663960160156, 51.58604462449123, 51.85402588034994, 52.120629313161594, 52.3858759590789, 52.64978632435273, 52.91238040383367], [0.0, 5.299056519796709, 7.493997598078079, 9.178235124467015, 10.598113039593418, 11.849050594878902, 12.979984591670364, 14.019985734657508, 14.987995196156158, 15.897169559390125, 16.757088052522732, 17.574982219052174, 18.35647024893403, 19.10601999370879, 19.827253970229968, 20.523157651784484, 21.196226079186836, 21.84856974723975, 22.481992794234234, 23.098051865904196, 23.698101189757804, 24.28332761381768, 24.85477821264958, 25.413382301456853, 25.95996918334073, 26.495282598983543, 27.01999259807449, 27.534705373401042, 28.039971469315017, 28.53629268142588, 29.024127893874784, 29.503898047546198, 29.975990392312315, 30.44076214551798, 30.898543655000967, 31.34964114627152, 31.79433911878025, 32.23290244455191, 32.66557821315888, 33.09259735953043, 33.514176105045465, 33.93051723743687, 34.34181125101005, 34.74823736536862, 35.14996443810435, 35.547151784636704, 35.93994991649266, 36.32850120772945, 36.71294049786806, 37.093395638576965, 37.46998799039039, 37.84283287493156, 38.21203998741758, 38.57771377362843, 38.93995377501109, 39.29885494515076, 39.654507940459936, 40.006999387607166, 40.35641212992058, 40.70282545475191, 41.04631530356897, 41.38695446635329, 41.724812761712904, 42.05995720397253, 42.39245215837367, 42.72235948540296, 43.04973867516504, 43.37464697262676, 43.6971394944795, 44.017269338294945, 44.3350876845868, 44.65064389233374, 44.96398558846847, 45.27515875179236, 45.584207791734194, 45.89117562233507, 46.19610373180839, 46.49903224799416, 46.80000000000001, 47.09904457629688, 47.39620237951561, 47.691508678170386, 47.9849976555173, 48.27670245573946, 48.56665522763536, 48.854887165973494, 49.14142855066386, 49.42630878388554, 49.70955642529916, 49.99119922546368, 50.2712641575682, 50.54977744758132, 50.826764602913705, 51.102250439682216, 51.37625910865836, 51.64881411997763, 51.91993836668146, 52.189654147158336, 52.45798318654655, 52.72494665715653, 52.990565197967086, 53.25485893324666], [0.0, 5.332916650389353, 7.541883053985921, 9.236882591004392, 10.665833300778706, 11.924764148611077, 13.062924634246345, 14.109571219565817, 15.083766107971842, 15.998749951168058, 16.864163187066236, 17.687283567580412, 18.473765182008783, 19.228104430754478, 19.95394697797907, 20.654297373670207, 21.331666601557412, 21.988178642170435, 22.625649161957764, 23.245644753372623, 23.849528297222154, 24.43849422529956, 25.013596302811, 25.575769783136543, 26.12584926849269, 26.66458325194677, 27.192646064699186, 27.71064777301318, 28.219142439131634, 28.71863506505837, 29.209587467131406, 29.692423275980694, 30.167532215943684, 30.63527378692739, 31.095980447639857, 31.54996038032378, 31.997499902336116, 32.43886557819185, 32.87430607632654, 33.30405380730701, 33.72832637413247, 34.147327860317276, 34.56124997739521, 34.97027309015473, 35.374567135160824, 35.774292445833225, 36.16960049544369, 36.560634567797095, 36.94753036401757, 37.330416552725474, 37.70941526992961, 38.08464257414004, 38.456208861508955, 38.824219245208276, 39.18877390273904, 39.549968394424795, 39.90789395595814, 40.26263776753828, 40.614283201849084, 40.962910052875884, 41.308594747340415, 41.65141054034065, 41.99142769661446, 42.32871365869745, 42.663333203114824, 42.99534858563191, 43.32481967648567, 43.65180408642923, 43.97635728434087, 44.29853270707733, 44.6183818621877, 44.93595442404668, 45.25129832391553, 45.564459834392856, 45.87548364867666, 46.184412955021955, 46.49128950674525, 46.796153688097064, 47.09904457629688, 47.400000000000006, 47.69905659444431, 47.99624985350419, 48.29161417886133, 48.5851829264849, 48.87698845059912, 49.167062145302125, 49.45543448398771, 49.742135056710225, 50.027192605622, 50.310635058603665, 50.592489561198704, 50.872782506955524, 51.15153956627309, 51.4287857138393, 51.704545254745256, 51.97884184935251, 52.25169853698538, 52.52313775851554, 52.79318137790144, 53.06185070274124, 53.32916650389354, 53.595149034217656], [0.0, 5.366563145999495, 7.589466384404111, 9.295160030897803, 10.73312629199899, 12.000000000000002, 13.145341380123988, 14.198591479439079, 15.178932768808222, 16.099689437998485, 16.970562748477143, 17.798876369029593, 18.590320061795605, 19.34941859591652, 20.079840636817814, 20.784609690826528, 21.46625258399798, 22.126906697502932, 22.768399153212332, 23.392306427541516, 24.000000000000004, 24.592681838303037, 25.171412356083643, 25.737132707432664, 26.290682760247975, 26.832815729997478, 27.364210202379315, 27.885480092693406, 28.397182958878158, 28.899826989101513, 29.39387691339814, 29.87975903517296, 30.357865537616444, 30.828558188796315, 31.29217154497272, 31.74901573277509, 32.19937887599697, 32.64352922096507, 33.081717005016536, 33.514176105045465, 33.941125496954285, 34.36277055186325, 34.77930419085465, 35.19090791667643, 35.597752738059185, 36.0, 36.39780213144745, 36.79130332021414, 37.18064012359121, 37.56594202199647, 37.94733192202056, 38.324926614411154, 38.69883719183304, 39.0691694306393, 39.43602414037196, 39.7994974842648, 40.15968127363563, 40.51666323872192, 40.87052727822337, 41.221353689562406, 41.569219381653056, 41.91419807177516, 42.25636046798162, 42.59577443831724, 42.93250516799596, 43.266615305567875, 43.59816509900388, 43.927212522535505, 44.253813395005864, 44.578021490416106, 44.899888641287305, 45.21946483540025, 45.536798306424664, 45.85193561890272, 46.16492174801123, 46.475800154489, 46.78461285508303, 47.091400488836605, 47.39620237951561, 47.6990565944443, 48.00000000000001, 48.29906831399546, 48.59629615515981, 48.89171708991207, 49.18536367660607, 49.47726750741194, 49.76745924798654, 50.055968675074105, 50.342824712167285, 50.62805546334957, 50.91168824543143, 51.19374961848371, 51.47426541486533, 51.75326076683479, 52.03076013282912, 52.306787322488084, 52.58136552049595, 52.85451730930859, 53.12626469082877, 53.396629107088785, 53.665631459994955, 53.933292130186175], [0.0, 5.4, 7.636753236814713, 9.353074360871938, 10.8, 12.074767078498866, 13.227244611029162, 14.28705707974879, 15.273506473629427, 16.2, 17.07629936490925, 17.90977386791916, 18.706148721743876, 19.469976887505542, 20.204949888579282, 20.91411006952005, 21.6, 22.264770378335367, 22.91025971044414, 23.53805429511964, 24.14953415699773, 24.745908752761537, 25.328245103046523, 25.897490225888692, 26.454489222058324, 27.0, 27.534705373401042, 28.059223082615816, 28.57411415949758, 29.079889958526323, 29.577018105278974, 30.06592755928212, 30.547012947258853, 31.02063829130536, 31.487140232164627, 31.94683082873793, 32.4, 32.84691766361039, 33.287835616032474, 33.72298919135135, 34.1525987298185, 34.576870882137385, 34.995999771402445, 35.410168031230796, 35.81954773583832, 36.2243012354966, 36.62458190887645, 37.02053484216564, 37.41229744348775, 37.800000000000004, 38.18376618407357, 38.56371351413139, 38.939953775011084, 39.31259340211481, 39.68173383308749, 40.04747183031658, 40.409899777158564, 40.76910595046205, 41.12517477166511, 41.47818703849048, 41.8282201390401, 42.17534824989594, 42.519642519663776, 42.86117123924637, 43.2, 43.536191840812165, 43.869807385034186, 44.20090496811123, 44.529540756670734, 44.8557688597576, 45.179641432840086, 45.501208775152335, 45.82051942088828, 46.137620224714674, 46.452556442030186, 46.76537180435969, 47.07610859023928, 47.384807691917466, 47.691508678170386, 47.99624985350418, 48.29906831399546, 48.60000000000001, 48.89907974594205, 49.196341327379216, 49.49181750552307, 49.785540069381604, 50.07753987567681, 50.3678468866796, 50.656490206093046, 50.94349811310566, 51.22889809472775, 51.51271687651507, 51.794980451777384, 52.07571410936197, 52.35494246009635, 52.632689461968404, 52.90897844411665, 53.18383212969898, 53.45727265770299, 53.729321603757484, 54.0, 54.269328354052824], [0.0, 5.43323108288245, 7.68374908491942, 9.410632284814875, 10.8664621657649, 12.149074038789955, 13.308643807691302, 14.37497826085313, 15.36749816983884, 16.29969324864735, 17.181385275931625, 18.019988901217452, 18.82126456962975, 19.589793260777412, 20.3292892153169, 21.04281350010022, 21.7329243315298, 22.401785643113367, 23.051247254758255, 23.682905227188666, 24.29814807757991, 24.898192705495717, 25.484112697914366, 26.056860900730165, 26.617287615382605, 27.166155414412252, 27.704151313476476, 28.231896854444624, 28.74995652170626, 29.258844816567866, 29.75903224232939, 30.250950398293277, 30.73499633967768, 31.211536328735892, 31.680909077865813, 32.1434285663493, 32.5993864972947, 33.04905444940899, 33.492685768686876, 33.93051723743687, 34.36277055186325, 34.78965363437815, 35.21136180269091, 35.628078814328454, 36.039977802434905, 36.44722211636986, 36.84996607868182, 37.24835566840502, 37.6425291392595, 38.03261758017716, 38.4187454245971, 38.80103091413939, 39.179586521554825, 39.55451933723883, 39.925931423073905, 40.29392013691396, 40.6585784306338, 41.01999512432931, 41.37825515896001, 41.733439829470086, 42.08562700020044, 42.43489130420862, 42.78130432794213, 43.124934782559386, 43.4658486630596, 43.80410939626555, 44.13977797859885, 44.47291310449542, 44.803571286226735, 45.13180696581958, 45.45767261970195, 45.7812188566447, 46.10249450951651, 46.42154672132328, 46.738421025961074, 47.05316142407437, 47.36581045437733, 47.676409260765446, 47.984997655517304, 48.29161417886133, 48.59629615515982, 48.89907974594206, 49.20000000000001, 49.499090900742814, 49.796385410991434, 50.091915515380336, 50.385712260520854, 50.67780579306883, 50.96822539582873, 51.25699952201651, 51.544155827794874, 51.82972120318612, 52.11372180146033, 52.39618306708993, 52.67712976235513, 52.95658599267895, 53.23457523076521, 53.51112033960793, 53.78624359443593, 54.05996670365236, 54.332310828824504, 54.603296603776606], [0.0, 5.466260147486579, 7.730459236035075, 9.4678403028357, 10.932520294973157, 12.22292927247802, 13.389548162652838, 14.46236495183274, 15.46091847207015, 16.398780442459735, 17.28583234906552, 18.129533915685755, 18.9356806056714, 19.70888124678821, 20.452872658871172, 21.170734517252818, 21.865040589946314, 22.537967965191537, 23.191377708105225, 23.82687558199774, 24.44585854495604, 25.049550894177724, 25.639032743065798, 26.215262729944175, 26.779096325305677, 27.331300737432898, 27.872567158408643, 28.4035209085071, 28.92472990366548, 29.43671177288659, 29.939939879699157, 30.434848447133756, 30.9218369441403, 31.401273859510862, 31.873499964704223, 32.338831147708476, 32.79756088491947, 33.249962405993784, 33.69629059703753, 34.136783679778624, 34.57166469813104, 35.001142838484576, 35.425414605901224, 35.84466487498523, 36.25906783137151, 36.66878781743405, 37.073980093860975, 37.47479152710525, 37.8713612113428, 38.26382103240606, 38.65229618017538, 39.03690561507149, 39.41776249357642, 39.794974557097035, 40.16864448795852, 40.53887023586128, 40.905745317742344, 41.26935909364234, 41.62979702088398, 41.98714088861016, 42.341469034505636, 42.69285654532852, 43.04137544270628, 43.38709485549822, 43.73008117989263, 44.07039822828924, 44.408107367911995, 44.74326765000517, 45.075935930383075, 45.40616698203009, 45.73401360038281, 46.05952670186701, 46.38275541621045, 46.70374717300529, 47.02254778295195, 47.3392015141785, 47.65375116399548, 47.96623812641555, 48.27670245573946, 48.585182926484904, 48.89171708991208, 49.196341327379216, 49.499090900742814, 49.8, 50.09910178835545, 50.3964284448809, 50.69201120492262, 50.9858803984005, 51.278065486131595, 51.56859509430134, 51.85749704719656, 52.14479839830623, 52.43052545988835, 52.71470383109442, 52.9973584247366, 53.2785134927768, 53.55819265061135, 53.83641890022033, 54.11321465224552, 54.388601747057265, 54.662601474865795, 54.935234594930066], [0.0, 5.499090833947008, 7.776888838089433, 9.524704719832528, 10.998181667894016, 12.29634091915152, 13.469966592386191, 14.54922678357857, 15.553777676178866, 16.497272501841024, 17.389652095427326, 18.238420984284797, 19.049409439665055, 19.827253970229968, 20.575713839378697, 21.297887219158618, 21.996363335788033, 22.673332353229423, 23.330666514268298, 23.969981226525817, 24.59268183830304, 25.200000000000003, 25.793022312245615, 26.3727131710031, 26.939933184772382, 27.49545416973504, 28.03997146931502, 28.574114159497583, 29.09845356715714, 29.61351043020736, 30.119760955226724, 30.617641973215378, 31.107555352357732, 31.589871794611646, 32.064934118129734, 32.5330601081423, 32.99454500368205, 33.449663675439254, 33.898672540381284, 34.34181125101005, 34.77930419085465, 35.21136180269091, 35.638181771801996, 36.059950083160125, 36.476841968569595, 36.889022757454555, 37.29664864300813, 37.69986737377202, 38.09881887933011, 38.493635837629064, 38.88444419044716, 39.27136361268858, 39.654507940459936, 40.03398556226947, 40.40989977715857, 40.78234912311943, 41.15142767875739, 41.51722534081487, 41.87982807987636, 42.2393181763153, 42.595774438317235, 42.94927240361588, 43.29988452640492, 43.64768035073571, 43.992726671576065, 44.335087684586796, 44.67482512556708, 45.01199840042652, 45.346664706458846, 45.678879145618275, 46.00869483043396, 46.33616298313878, 46.661333028536596, 46.98425268108455, 47.30496802662486, 47.62352359916263, 47.939962453051635, 48.254326230919446, 48.56665522763536, 48.87698845059913, 49.18536367660608, 49.49181750552308, 49.796385410991434, 50.09910178835545, 50.400000000000006, 50.69911241826627, 50.996470466101876, 51.29210465559003, 51.58604462449123, 51.87831917092149, 52.16895628628198, 52.45798318654655, 52.7454263420062, 53.031311505562456, 53.31566373965535, 53.59850744190551, 53.879866369544764, 54.15976366270445, 54.43822186662602, 54.7152629528544, 54.99090833947008, 55.2651789104134], [0.0, 5.531726674375732, 7.823042886243179, 9.581231653602789, 11.063453348751464, 12.369316876852984, 13.54990774876346, 14.635573101180562, 15.646085772486359, 16.595180023127195, 17.492855684535904, 18.34666182170479, 19.162463307205577, 19.944924166313594, 20.69782597279241, 21.42428528562855, 22.12690669750293, 22.807893370497855, 23.469128658729534, 24.112237556892147, 24.73863375370597, 25.34955620913313, 25.946097972527586, 26.529229163320977, 27.09981549752692, 27.658633371878665, 28.206382256503584, 28.743694960808366, 29.271146202361123, 29.789259809535384, 30.298514815086236, 30.799350642505438, 31.292171544972717, 31.77735042447687, 32.25523213371748, 32.72613634390714, 33.19036004625439, 33.64817974274389, 34.09985337211877, 34.54562200916348, 34.98571136907181, 35.420333143549065, 35.849686191095174, 36.27395760046041, 36.69332364340958, 37.107950630558946, 37.51799568207236, 37.92360742334516, 38.324926614411154, 38.72208672063013, 39.1152144312159, 39.50443013131566, 39.88984833262719, 40.27157806691961, 40.64972324629038, 41.02438299353203, 41.39565194558482, 41.763620532707655, 42.12837523570071, 42.48999882325251, 42.8485705712571, 43.204166465747264, 43.55685939091568, 43.906719303541685, 44.25381339500586, 44.598206241955516, 44.93995994657761, 45.27913426734217, 45.61578674099571, 45.949972796509904, 46.28174586162454, 46.61115746256469, 46.93825731745907, 47.263093423939154, 47.58571214135605, 47.90615826801394, 48.224475113784294, 48.540704568434116, 48.85488716597349, 49.16706214530212, 49.47726750741194, 49.7855400693816, 50.09191551538033, 50.39642844488089, 50.69911241826626, 51.00000000000001, 51.29912279951774, 51.59651150998486, 51.89219594505517, 52.186205073754884, 52.478567053607705, 52.76930926210803, 53.058458326641954, 53.34604015294857, 53.63207995220771, 53.91660226683429, 54.19963099505384, 54.481189414329066, 54.76130020370225, 55.03998546511437, 55.31726674375733, 55.59316504751283], [0.0, 5.5641710972974225, 7.868926229162401, 9.637427042525408, 11.128342194594845, 12.441864811996634, 13.629380029920657, 14.721412975662357, 15.737852458324802, 16.692513291892265, 17.59545395833822, 18.45426779907564, 19.274854085050816, 20.061904196760587, 20.819221887476967, 21.549941995281564, 22.25668438918969, 22.941665153166195, 23.606778687487203, 24.253659517689286, 24.88372962399327, 25.498235233050934, 26.098275805117858, 26.68482714952451, 27.258760059841315, 27.820855486487112, 28.371817002088537, 28.91228112757622, 29.442825951324714, 29.963978374041055, 30.476220238080707, 30.979993544221408, 31.475704916649605, 31.96372944448129, 32.44441400302986, 32.918080138428486, 33.38502658378453, 33.84553146280909, 34.29985422709549, 34.748237365368624, 35.19090791667644, 35.62807881432846, 36.059950083160125, 36.48670990922585, 36.90853559815128, 37.3255944359899, 37.738044464439334, 38.1460351806056, 38.54970817010163, 38.94919768108196, 39.34463114581201, 39.73612965551628, 40.12380839352117, 40.507777031083805, 40.888140089761976, 41.264997273718556, 41.638443774953934, 42.008570554114314, 42.37546459922299, 42.7392091644195, 43.09988399056313, 43.45756550935637, 43.81232703246884, 44.164238926987075, 44.51336877837938, 44.859781542044985, 45.20353968440967, 45.54470331443603, 45.88333030633239, 46.21947641416982, 46.55319537904998, 46.88453902940713, 47.21355737497441, 47.540298694896734, 47.86480962042992, 48.187135212627034, 48.50731903537857, 48.82540322414143, 49.14142855066386, 49.45543448398771, 49.76745924798654, 50.077539875676806, 50.38571226052084, 50.692011204922615, 50.99647046610187, 51.29912279951774, 51.60000000000001, 51.899132940734184, 52.196551610235716, 52.49228514743857, 52.78636187501465, 53.078809331031536, 53.36965429904902, 53.6589228367473, 53.94664030317366, 54.232831384688005, 54.51752011968263, 54.80072992214612, 55.082483604136804, 55.36280339722693, 55.641710972974224, 55.91922746247485], [0.0, 5.596427431853289, 7.914543574963752, 9.693296652842108, 11.192854863706579, 12.513992168768528, 13.708391590555037, 14.80675521510368, 15.829087149927505, 16.789282295559865, 17.69745744450315, 18.561249957909627, 19.386593305684215, 20.178206064960285, 20.939914039938177, 21.67487024182613, 22.385709727413158, 23.074661427635295, 23.743630724891254, 24.39426162030735, 25.027984337537056, 25.646052327795015, 26.249571425072833, 26.839523095614055, 27.416783181110073, 27.982137159266447, 28.53629268142588, 29.079889958526323, 29.61351043020736, 30.137684051698468, 30.652895458667523, 31.159589214237084, 31.65817429985501, 32.14902797908516, 32.632499138129155, 33.10891118717135, 33.57856459111973, 34.04173908601028, 34.49869562751612, 34.94967811010568, 35.3949148890063, 35.834620131933875, 36.26899502329779, 36.69822884009526, 37.122499915819255, 37.54197650630558, 37.95681756944331, 38.3671734689956, 38.77318661136843, 39.17499202297303, 39.572717874818764, 39.966485960114134, 40.35641212992057, 40.74260669127591, 41.12517477166511, 41.50421665325103, 41.879828079876354, 42.25210053949981, 42.62112152442731, 42.98697477143512, 43.34974048365226, 43.70949553586726, 44.06631366474849, 44.42026564531104, 44.771419454826315, 45.119840425249734, 45.46559138513432, 45.80873279190333, 46.14932285527059, 46.48741765252185, 46.82307123630402, 47.15633573550854, 47.48726144978251, 47.81589693815228, 48.14228910220203, 48.46648326421054, 48.7885232406147, 49.10845141113697, 49.42630878388554, 49.742135056710225, 50.05596867507411, 50.36784688667961, 50.67780579306883, 50.9858803984005, 51.29210465559003, 51.596511509984865, 51.89913294073419, 52.2, 52.49914285014567, 52.796590799027925, 53.09237233350945, 53.386515151300145, 53.67904619122811, 53.96999166203383, 54.25937706977477, 54.54722724392139, 54.83356636222015, 55.11841797439401, 55.40180502474626, 55.68374987372888, 55.964274318532894, 56.24339961275457], [0.0, 5.628498911788116, 7.95989949685296, 9.748846085563153, 11.256997823576231, 12.585706178041821, 13.786950351691269, 14.891608375189028, 15.91979899370592, 16.885496735364345, 17.798876369029593, 18.667619023324857, 19.497692171126307, 20.293841430345317, 21.059914529741093, 21.79908254950194, 22.513995647152463, 23.20689552697646, 23.87969849055888, 24.53405796031305, 25.171412356083643, 25.793022312245615, 26.400000000000002, 26.993332510084787, 27.573900703382538, 28.14249455894058, 28.69982578344336, 29.246538256689462, 29.783216750378056, 30.310394256756215, 30.82855818879631, 31.33815565728143, 31.83959798741184, 32.333264604737955, 32.81950639482563, 33.29864862122786, 33.77099347072869, 34.236822282449054, 34.696397507522306, 35.14996443810435, 35.597752738059185, 36.0399778024349, 36.476841968569595, 36.908535598151275, 37.335238046649714, 37.75711853412545, 38.17433692940848, 38.587044457952466, 38.99538434225261, 39.39949238251681, 39.799497484264805, 40.19552213866615, 40.587682860690634, 40.9760905895133, 41.36085105507381, 41.742065114222605, 42.119829059482186, 42.494234903101855, 42.86537063878021, 43.23332048316437, 43.59816509900388, 43.959981801634086, 44.31884475028653, 44.67482512556709, 45.027991294304925, 45.37840896285369, 45.72614131981836, 46.07124916908592, 46.41379105395292, 46.753823373067576, 47.091400488836605, 47.426574828886814, 47.75939698111776, 48.08991578283331, 48.41817840439683, 48.744230427815765, 49.0681159206261, 49.38987750541603, 49.70955642529916, 50.027192605622, 50.342824712167285, 50.656490206093046, 50.968225395828725, 51.27806548613159, 51.58604462449123, 51.89219594505518, 52.196551610235716, 52.49914285014566, 52.800000000000004, 53.09915253561021, 53.39662910708878, 53.692457570873025, 53.986665020169575, 54.27927781391349, 54.570321604329955, 54.85982136317981, 55.147801406765076, 55.434285419765274, 55.719296477970715, 56.002857069974574, 56.28498911788116, 56.565713997084856], [0.0, 5.660388679233962, 8.0049984384758, 9.804080783020915, 11.320777358467923, 12.657013865837392, 13.865064009949611, 14.975980769218422, 16.0099968769516, 16.981166037701886, 17.899720668211557, 18.77338541659442, 19.60816156604183, 20.408821622033937, 21.179235113667346, 21.92259108773413, 22.641554716935847, 23.338380406532067, 24.0149953154274, 24.67306223394251, 25.314027731674784, 25.939159585460743, 26.549576267805104, 27.14627046207269, 27.730128019899222, 28.30194339616981, 28.862432329933668, 29.412242349062748, 29.951961538436844, 30.48212591011329, 31.00322563863315, 31.51571036800535, 32.0199937539032, 32.51645737161415, 33.00545409474016, 33.48731102970198, 33.96233207540377, 34.43080016496857, 34.89297923651691, 35.34911597197305, 35.799441336423115, 36.244171945293495, 36.683511282318655, 37.1176507877317, 37.54677083318884, 37.971041597512176, 38.39062385531134, 38.8056696888483, 39.21632313208366, 39.62272075463774, 40.024992192379, 40.42326063048353, 40.817643244067874, 41.20825160086266, 41.59519202984883, 41.97856595930833, 42.35847022733469, 42.734997367497286, 43.10823587204654, 43.47827043478155, 43.84518217546826, 44.20904884749275, 44.56994503025553, 44.927942307655265, 45.283109433871694, 45.6355124875354, 45.98521501526332, 46.33227816544314, 46.676760813064135, 47.01871967631615, 47.358209425610674, 47.69528278561728, 48.0299906308548, 48.36238207532792, 48.69250455665635, 49.02040391510457, 49.34612446788502, 49.66970907907555, 49.99119922546368, 50.310635058603665, 50.62805546334957, 50.94349811310566, 51.25699952201651, 51.56859509430133, 51.878319170921486, 52.18620507375489, 52.49228514743858, 52.79659079902792, 53.09915253561021, 53.4, 53.69916200463467, 53.996666563779655, 54.29254092414538, 54.58681159401051, 54.87950437093979, 55.17064436817826, 55.460256039798445, 55.74836320467176, 56.03498906933059, 56.32015624978326, 56.60388679233962, 56.88620219350208], [0.0, 5.692099788303082, 8.049844718999243, 9.85900603509299, 11.384199576606164, 12.727922061357857, 13.942740046346701, 15.05988047761336, 16.099689437998485, 17.076299364909246, 18.0, 18.87855926706273, 19.71801207018598, 20.523157651784484, 21.297887219158618, 22.045407685048602, 22.76839915321233, 23.469128658729534, 24.149534156997728, 24.8112877537624, 25.455844122715714, 26.08447814314099, 26.69831455354439, 27.298351598585587, 27.885480092693403, 28.460498941515414, 29.024127893874784, 29.577018105278974, 30.11976095522672, 30.652895458667523, 31.176914536239792, 31.692270350986217, 32.19937887599697, 32.69862382425291, 33.1903600462544, 33.67491648096547, 34.15259872981849, 34.62369131100842, 35.08845964131227, 35.5471517846367, 36.0, 36.44722211636986, 36.889022757454555, 37.32559443598989, 37.75711853412546, 38.18376618407356, 38.60569906114899, 39.02307009962183, 39.43602414037196, 39.84469851812158, 40.24922359499622, 40.64972324629038, 41.04631530356897, 41.43911195959682, 41.828220139040106, 42.21374183841087, 42.595774438317235, 42.97441099072796, 43.34974048365227, 43.72184808536802, 44.090815370097204, 44.456720526822494, 44.819638552759436, 45.17964143284008, 45.53679830642466, 45.89117562233506, 46.24283728319446, 46.59184477996122, 46.93825731745907, 47.28213193162931, 47.62352359916263, 47.96248534010722, 48.299068313995456, 48.63332190998267, 48.965293831447596, 49.295030175464944, 49.6225755075248, 49.94797293184179, 50.2712641575682, 50.592489561198704, 50.91168824543143, 51.228898094727754, 51.544155827794874, 51.85749704719656, 52.16895628628198, 52.47856705360771, 52.786361875014656, 53.09237233350945, 53.39662910708878, 53.69916200463467, 54.0, 54.29917126439408, 54.59670319717117, 54.89262245511687, 55.18695498032121, 55.47972602672078, 55.770960185386805, 56.060681408630785, 56.348913032994695, 56.635677801188194, 56.92099788303083, 57.204894895454544], [0.0, 5.7236352085016735, 8.094442537939225, 9.913626985114984, 11.447270417003347, 12.798437404620927, 14.019985734657508, 15.143315356948756, 16.18888507587845, 17.17090562550502, 18.099723754798028, 18.983150423467652, 19.827253970229968, 20.636860226303806, 21.415881957089695, 22.167543842293398, 22.894540834006694, 23.599152527156562, 24.283327613817676, 24.948747463550152, 25.596874809241854, 26.228991593273275, 26.846228785436516, 27.4495901608749, 28.039971469315017, 28.61817604250837, 29.184927616836745, 29.740880955344952, 30.286630713897512, 30.822718893699175, 31.349641146271516, 31.867852139734804, 32.3777701517569, 32.879781021168625, 33.37424156441612, 33.86148254285391, 34.34181125101004, 34.815513783369624, 35.282857027173975, 35.74409042065555, 36.199447509596055, 36.64914732978109, 37.09339563857696, 37.53238601528019, 37.966300846935304, 38.39531221386277, 38.81958268709235, 39.23926604818189, 39.654507940459936, 40.06544645951172, 40.47221268969613, 40.874931192602645, 41.27372045260761, 41.6686932840472, 42.05995720397252, 42.447614773977584, 42.83176391417939, 43.212498192074015, 43.589907088682814, 43.964076244133686, 44.335087684586796, 44.703020032208116, 45.06794869971341, 45.42994607084626, 45.78908166801339, 46.145422308177004, 46.49903224799415, 46.84997331909592, 47.198305054313124, 47.54408480557807, 47.8873678541638, 48.2282075138606, 48.56665522763535, 48.90276065826959, 49.23657177342874, 49.56813492557492, 49.897494927100304, 50.224695121025874, 50.54977744758132, 50.872782506955524, 51.19374961848371, 51.51271687651507, 51.82972120318612, 52.14479839830623, 52.45798318654655, 52.76930926210804, 53.07880933103154, 53.386515151300145, 53.69245757087303, 53.996666563779655, 54.29917126439408, 54.6, 54.8991803217498, 55.19673903411325, 55.49270222290495, 55.78709528197359, 56.07994293863003, 56.3712692778866, 56.66109776557457, 56.94945127040296, 57.23635208501674, 57.521821946110165], [0.0, 5.754997827975264, 8.138795979750322, 9.967948635501692, 11.509995655950528, 12.868566353716332, 14.096808149364879, 15.226293048539425, 16.277591959500644, 17.26499348392579, 18.198901065723724, 19.08716846470424, 19.935897271003384, 20.7499397589487, 21.533230133911633, 22.289010745208053, 23.019991311901055, 23.72846391994223, 24.416387939250967, 25.08545395244025, 25.737132707432664, 26.372713171003095, 26.993332510084787, 27.60000000000001, 28.193616298729758, 28.77498913987632, 29.344846225529967, 29.903845906505072, 30.45258609707885, 30.9916117683479, 31.521421287752876, 32.04247181476485, 32.55518391900129, 33.059945553494195, 33.55711548986296, 34.04702630186666, 34.52998696785158, 35.00628514995558, 35.47618919782676, 35.93994991649265, 36.39780213144745, 36.84996607868182, 37.29664864300813, 37.73804446443933, 38.17433692940848, 38.60569906114899, 39.032294321497425, 39.45427733465663, 39.87179454200677, 40.28498479582685, 40.693979898751614, 41.09890509490491, 41.4998795178974, 41.89701660023063, 42.29042444809463, 42.680206185068975, 43.06646026782327, 43.449280776556016, 43.828757682599225, 44.20497709534527, 44.578021490416106, 44.94796992078731, 45.3148982123981, 45.678879145618275, 46.03998262380211, 46.39827583003489, 46.753823373067576, 47.10668742333725, 47.45692783988446, 47.804602288901016, 48.149766354573316, 48.49247364282421, 48.832775878501934, 49.17072299651491, 49.506363227367046, 49.83974317750845, 50.1709079048805, 50.49990099000196, 50.826764602913705, 51.15153956627308, 51.47426541486533, 51.79498045177738, 52.11372180146032, 52.430525459888344, 52.74542634200619, 53.058458326641954, 53.36965429904902, 53.6790461912281, 53.986665020169575, 54.29254092414538, 54.596703197171166, 54.8991803217498, 55.20000000000002, 55.499189183266466, 55.79677410030082, 56.092780284097174, 56.387232597459516, 56.680155257373826, 56.971571858252254, 57.26150539411273, 57.54997827975264, 57.83701237097229], [0.0, 5.786190456595773, 8.182909018191515, 10.021975853094041, 11.572380913191546, 12.938315191708698, 14.173214173221261, 15.30882098660769, 16.36581803638303, 17.358571369787317, 18.29754081837229, 19.190622710063373, 20.043951706188082, 20.862406380856452, 21.64994226320246, 22.409819276379718, 23.144761826383093, 23.857074422485255, 24.54872705457454, 25.221419468380446, 25.876630383417396, 26.515655752781225, 27.139638906956744, 27.749594591633233, 28.346428346442522, 28.93095228297887, 29.503898047546198, 30.065927559282123, 30.61764197321538, 31.159589214237087, 31.69227035098622, 32.21614502078112, 32.73163607276606, 33.239133562714905, 33.73899820682292, 34.23156438143019, 34.71714273957463, 35.19602250254992, 35.66847347448444, 36.13474781979252, 36.59508163674458, 37.04969635503104, 37.49879998079939, 37.9425882090297, 38.381245420126746, 38.81494557512609, 39.2438530218428, 39.668123222557426, 40.087903412376164, 40.503333196170416, 40.914545090957574, 41.3216650196964, 41.724812761712904, 42.12410236432345, 42.51964251966378, 42.911536910252934, 43.29988452640492, 43.684779958241755, 44.066313664748506, 44.444572222038545, 44.819638552759436, 45.191592138361315, 45.56050921576711, 45.92646295982307, 46.289523652766185, 46.64975884182039, 47.00723348592214, 47.36201009247813, 47.71414884497051, 48.06370772214728, 48.41074260946635, 48.755307403399684, 49.09745410914908, 49.437232932274846, 49.77469236469474, 50.1098792654702, 50.44283893676089, 50.77361519529608, 51.102250439682216, 51.4287857138393, 51.75326076683479, 52.07571410936197, 52.39618306708992, 52.71470383109441, 53.03131150556245, 53.34604015294857, 53.6589228367473, 53.96999166203382, 54.27927781391349, 54.58681159401051, 54.892622455116864, 55.19673903411324, 55.499189183266466, 55.80000000000001, 56.09919785522784, 56.39680842033528, 56.692856692885044, 56.98736702112146, 57.28036312734059, 57.571868130190126, 57.86190456595774, 58.15049440890423], [0.0, 5.817215828899595, 8.226785520481254, 10.075713374248, 11.63443165779919, 13.007690033207282, 14.249210504445502, 15.390906406056793, 16.453571040962508, 17.451647486698782, 18.39565166010707, 19.293522228976236, 20.151426748496, 20.974269951538243, 21.766028576660464, 22.529980026622304, 23.26886331559838, 23.984995309568024, 24.68035656144376, 25.356655930938533, 26.015380066414565, 26.657831869827675, 27.285160802164977, 27.898387050150415, 28.498421008891004, 29.086079144497976, 29.662097026339865, 30.227140122744, 30.781812812113586, 31.326665957295873, 31.862203313644212, 32.38888698303787, 32.907142081925016, 33.417360757546376, 33.91990566024617, 34.41511295927997, 34.903294973397564, 35.38474247468816, 35.85972671396144, 36.32850120772945, 36.79130332021414, 37.24835566840502, 37.69986737377202, 38.146035180605594, 38.58704445795247, 39.02307009962184, 39.45427733465664, 39.88082245892128, 40.302853496992, 40.72051080229717, 41.13392760240627, 41.54323049547303, 41.94853990307649, 42.34997048405111, 42.74763151333651, 43.14162722939412, 43.53205715332093, 43.91901638242824, 44.302595860739366, 44.682882628586086, 45.05996005324461, 45.433908042342125, 45.80480324158155, 46.17271921817038, 46.53772663119676, 46.89989339007073, 47.25928480203652, 47.61596370966359, 47.96999061913605, 48.321423820082124, 48.6703194976158, 49.01673183720025, 49.36071312288752, 49.702313829438566, 50.0415827087833, 50.37856687124, 50.71331186187707, 51.0458617323677, 51.37625910865836, 51.70454525474526, 52.03076013282913, 52.35494246009636, 52.67712976235513, 52.9973584247366, 53.31566373965535, 53.63207995220772, 53.946640303173666, 54.25937706977477, 54.570321604329955, 54.8795043709398, 55.18695498032121, 55.49270222290495, 55.79677410030083, 56.09919785522786, 56.400000000000006, 56.69920634365176, 56.99684201778201, 57.29293150118958, 57.58749864336877, 57.88056668692871, 58.17215828899595, 58.46229554165661], [0.0, 5.848076606885377, 8.270429251254132, 10.12916580968048, 11.696153213770755, 13.076696830622021, 14.324803663575986, 15.472556349873152, 16.540858502508264, 17.54422982065613, 18.49324200890693, 19.395875850293535, 20.25833161936096, 21.085540068966694, 21.88149903457256, 22.649503305812246, 23.39230642754151, 24.112237556892143, 24.811287753762397, 25.491174943497604, 26.153393661244042, 26.799253720952752, 27.429910681589906, 28.046390142048587, 28.649607327151973, 29.24038303442689, 29.819456735494025, 30.38749742904144, 30.945112699746304, 31.492856332825703, 32.03123475609393, 32.560712522916326, 33.08171700501653, 33.59464243000661, 34.09985337211877, 34.597687784012386, 35.08845964131226, 35.57246125867593, 36.04996532591952, 36.52122670447968, 36.98648401781386, 37.44596106391182, 37.89986807364902, 38.348402835059495, 38.79175170058707, 39.23009049186606, 39.66358531449218, 40.09239329349147, 40.51666323872192, 40.93653624819765, 41.352146256270665, 41.76362053270765, 42.17108013793339, 42.5746403390563, 42.97441099072796, 43.370496884402876, 43.76299806914512, 44.152010146764546, 44.53762454374952, 44.919928762187496, 45.29900661162449, 45.67493842360381, 46.04780125043974, 46.417669049619455, 46.78461285508302, 47.14870093650513, 47.50999894758996, 47.86857006429166, 48.22447511378429, 48.57777269492704, 48.92851929090027, 49.2767693746252, 49.62257550752479, 49.965988432132505, 50.307057159010995, 50.64582904840239, 50.98234988699521, 51.316663960160156, 51.64881411997763, 51.97884184935251, 52.306787322488084, 52.632689461968404, 52.956585992678946, 53.278513492776796, 53.598507441905504, 53.91660226683429, 54.232831384688005, 54.547227243921384, 54.85982136317981, 55.17064436817826, 55.47972602672078, 55.787095281973585, 56.092780284097174, 56.39680842033528, 56.69920634365176, 56.99999999999999, 57.299214654303945, 57.596874915224355, 57.89300475877892, 58.18762755088061, 58.48076606885378, 58.77244252198475], [0.0, 5.878775382679628, 8.313843876330612, 10.182337649086286, 11.757550765359255, 13.14534138012399, 14.4, 15.553777676178866, 16.627687752661224, 17.63632614803888, 18.5903200617956, 19.497692171126307, 20.36467529817257, 21.196226079186832, 21.996363335788033, 22.76839915321233, 23.51510153071851, 24.238811852068988, 24.941531628991832, 25.62498780487515, 26.29068276024798, 26.93993318477238, 27.57390070338254, 28.193616298729758, 28.8, 29.393876913398138, 29.975990392312315, 30.547012947258857, 31.107555352357732, 31.65817429985501, 32.19937887599697, 32.73163607276606, 33.25537550532245, 33.7709934707287, 34.27885645700569, 34.77930419085465, 35.27265229607776, 35.75919462180322, 36.2392052892996, 36.712940497868054, 37.1806401235912, 37.642529139259494, 38.0988188793301, 38.549708170101624, 38.99538434225261, 39.43602414037196, 39.87179454200676, 40.30285349699199, 40.72935059634514, 41.15142767875739, 41.569219381653056, 41.98285364288617, 42.392452158373665, 42.798130800304826, 43.2, 43.59816509900388, 43.992726671576065, 44.38378082137663, 44.77141945482632, 45.15573053334427, 45.53679830642466, 45.91470352730158, 46.289523652766185, 46.661333028536596, 47.03020306143702, 47.39620237951559, 47.75939698111775, 48.11985037383221, 48.477623704137976, 48.832775878501934, 49.18536367660607, 49.535441857320706, 49.883063257983665, 50.22827888749524, 50.57113801369315, 50.91168824543142, 51.2499756097503, 51.58604462449123, 51.91993836668146, 52.25169853698538, 52.58136552049596, 52.908978444116656, 53.23457523076521, 53.55819265061135, 53.87986636954476, 54.199630995053845, 54.51752011968264, 54.83356636222014, 55.14780140676508, 55.46025603979845, 55.770960185386805, 56.07994293863003, 56.387232597459516, 56.69285669288505, 56.99684201778201, 57.299214654303945, 57.6, 57.89922279271114, 58.19690713431427, 58.493076513378924, 58.787753826796276, 59.08096140043764], [0.0, 5.909314681077663, 8.357032966310472, 10.23523326553919, 11.818629362155326, 13.213629327327148, 14.474805698177784, 15.634577064954462, 16.714065932620944, 17.727944043232988, 18.686893802876927, 19.598979565273293, 20.47046653107838, 21.306337085477647, 22.110630927225934, 22.88667734731278, 23.63725872431065, 24.364728605096346, 25.071098898931417, 25.75810552039882, 26.427258654654295, 27.07988183135222, 27.717142709882637, 28.340077628686913, 28.949611396355568, 29.54657340538832, 30.131710870775333, 30.70569979661757, 31.269154129908923, 31.82263345482269, 32.36664950222683, 32.901671690052474, 33.42813186524189, 33.94642838355753, 34.45692963686696, 34.959977116697324, 35.455888086465976, 35.94495792180039, 36.4274621679853, 36.90365835523628, 37.373787605753854, 37.83807606102616, 38.29673615335908, 38.749967741922056, 39.197959130546586, 39.640887981981436, 40.07892214119537, 40.51222037854751, 40.94093306215676, 41.36520276754365, 41.785164831552365, 42.200947856653656, 42.612674170955295, 43.02046024858405, 43.424417094533354, 43.82465059758036, 44.22126185445187, 44.61434746805113, 45.003999822238036, 45.39030733537723, 45.77335469462556, 46.15322307271726, 46.52999032881911, 46.90373119486338, 47.2745174486213, 47.64241807465276, 48.00749941415403, 48.369825304625614, 48.72945721019269, 49.08645434333183, 49.4408737786864, 49.79277055959028, 50.142197797862835, 50.48920676738743, 50.83384699194033, 51.176166327695945, 51.51621104079764, 51.85402588034994, 52.189654147158336, 52.52313775851554, 52.85451730930859, 53.18383212969898, 53.51112033960793, 53.83641890022032, 54.15976366270444, 54.481189414329066, 54.800729922146125, 55.118417974394006, 55.434285419765274, 55.74836320467176, 56.06068140863078, 56.37126927788659, 56.680155257373826, 56.98736702112146, 57.29293150118958, 57.596874915224355, 57.899222792711136, 58.20000000000002, 58.4992307641733, 58.79693869581988, 59.09314681077664, 59.38787755089419], [0.0, 5.939696961966999, 8.4, 10.287856919689348, 11.879393923933998, 13.281566172707194, 14.54922678357857, 15.714961024450554, 16.8, 17.819090885900994, 18.78297101099823, 19.699746191258406, 20.575713839378697, 21.415881957089695, 22.224311012942557, 23.004347415216973, 23.758787847867996, 24.489997958350262, 25.2, 25.890538812469703, 26.563132345414388, 27.21911093331301, 27.85964823898536, 28.48578592912613, 29.09845356715714, 29.698484809834998, 30.286630713897512, 30.863570759068047, 31.42992204890111, 31.986247044628414, 32.5330601081423, 33.07083307084961, 33.6, 34.12096129947104, 34.634087255188355, 35.139721114431175, 35.63818177180199, 36.12976612157904, 36.614751125741655, 37.09339563857696, 37.56594202199646, 38.03261758017715, 38.49363583762906, 38.94919768108195, 39.39949238251681, 39.844698518121575, 40.284984795826844, 40.72051080229716, 41.15142767875739, 41.577878733769, 42.0, 42.41792074112073, 42.83176391417939, 43.24164659214541, 43.64768035073571, 44.04997162314636, 44.448622025885115, 44.843728658531504, 45.23538437992984, 45.623678063040906, 46.008694830433946, 46.390516272186495, 46.76922064777218, 47.144883073351664, 47.51757569573599, 47.88736785416379, 48.25432623091944, 48.618514991718946, 48.979995916700524, 49.338828522777064, 49.69507017803678, 50.04877620881454, 50.4, 50.748793089097205, 51.095205254505046, 51.43928459844674, 51.78107762493941, 52.1206293131616, 52.45798318654656, 52.79318137790145, 53.126264690828776, 53.457272657703, 53.78624359443593, 54.113214652245524, 54.43822186662602, 54.761300203702255, 55.08248360413681, 55.40180502474626, 55.71929647797072, 56.0349890693306, 56.3489130329947, 56.661097765574574, 56.97157185825226, 57.28036312734061, 57.58749864336877, 57.89300475877893, 58.19690713431428, 58.49923076417331, 58.79999999999999, 59.09923857377522, 59.396969619669996, 59.693215694917974], [0.0, 5.96992462263972, 8.442748367682174, 10.340212763768452, 11.93984924527944, 13.349157276772196, 14.623269128344731, 15.794935897305821, 16.88549673536435, 17.90977386791916, 18.87855926706273, 19.800000000000004, 20.680425527536904, 21.52486933758252, 22.33741256278354, 23.12141864159723, 23.87969849055888, 24.61462979611922, 25.32824510304652, 26.022298130641733, 26.698314553544392, 27.357631476427198, 28.001428534987287, 28.630752697056366, 29.246538256689462, 29.8496231131986, 30.44076214551798, 31.02063829130536, 31.589871794611643, 32.149027979085155, 32.69862382425291, 33.2391335627149, 33.7709934707287, 34.294605989863776, 34.810343290464694, 35.318550366627456, 35.81954773583832, 36.313633803297634, 36.801086940469574, 37.282167318974366, 37.75711853412546, 38.22616904687155, 38.689533468368424, 39.147413707676776, 39.60000000000001, 40.04747183031658, 40.489998765127176, 40.927741203247464, 41.36085105507381, 41.789472358478044, 42.21374183841087, 42.63378941637725, 43.04973867516504, 43.4617072835387, 43.86980738503419, 44.274145954495836, 44.67482512556708, 45.071942491976095, 45.46559138513433, 45.85586113028519, 46.24283728319446, 46.62660184915903, 47.00723348592214, 47.384807691917466, 47.75939698111776, 48.13107104563537, 48.49989690710693, 48.86593905779362, 49.22925959223844, 49.58991833024128, 49.9479729318418, 50.30347900493564, 50.65649020609304, 51.00705833509712, 51.35523342367358, 51.70106381884226, 52.044596261283466, 52.3858759590789, 52.72494665715653, 53.06185070274124, 53.396629107088785, 53.729321603757484, 54.05996670365235, 54.38860174705726, 54.715262952854395, 55.03998546511437, 55.36280339722693, 55.68374987372887, 56.002857069974574, 56.32015624978326, 56.63567780118819, 56.94945127040295, 57.26150539411273, 57.571868130190126, 57.8805666869287, 58.18762755088061, 58.493076513378924, 58.79693869581988, 59.09923857377521, 59.40000000000001, 59.6992462263972, 59.99699992499627], [0.0, 6.0, 8.485281374238571, 10.392304845413266, 12.0, 13.41640786499874, 14.69693845669907, 15.874507866387544, 16.970562748477143, 18.0, 18.973665961010276, 19.899748742132402, 20.78460969082653, 21.633307652783937, 22.44994432064365, 23.2379000772445, 24.0, 24.738633753705965, 25.45584412271571, 26.153393661244046, 26.83281572999748, 27.49545416973504, 28.14249455894058, 28.774989139876325, 29.39387691339814, 30.000000000000004, 30.594117081556714, 31.176914536239796, 31.74901573277509, 32.31098884280703, 32.86335345030997, 33.406586176980134, 33.941125496954285, 34.46737587922818, 34.98571136907181, 35.4964786985977, 36.0, 36.496575181789325, 36.98648401781386, 37.46998799039039, 37.94733192202055, 38.4187454245971, 38.88444419044716, 39.344631145812, 39.799497484264805, 40.24922359499622, 40.693979898751614, 41.13392760240627, 41.56921938165306, 42.00000000000001, 42.42640687119285, 42.848570571257106, 43.266615305567875, 43.68065933568312, 44.09081537009721, 44.49719092257398, 44.8998886412873, 45.2990066116245, 45.69463863518346, 46.08687448721165, 46.475800154489, 46.86149805543993, 47.24404724407086, 47.62352359916263, 48.0, 48.373546489791295, 48.744230427815765, 49.1121166312347, 49.47726750741193, 49.83974317750845, 50.19960159204454, 50.556898639058154, 50.91168824543142, 51.26402247190519, 51.61395160225577, 51.96152422706632, 52.30678732248809, 52.64978632435274, 52.99056519796709, 53.32916650389354, 53.66563145999496, 54.00000000000001, 54.332310828824504, 54.662601474865795, 54.99090833947008, 55.31726674375734, 55.64171097297423, 55.964274318532894, 56.28498911788116, 56.60388679233963, 56.92099788303083, 57.23635208501674, 57.54997827975265, 57.861904565957744, 58.17215828899595, 58.48076606885378, 58.78775382679628, 59.09314681077664, 59.39696961966999, 59.69924622639721, 60.00000000000001, 60.299253726725354], [0.0, 6.029925372672535, 8.527602242131138, 10.444137111317527, 12.05985074534507, 13.483323032546542, 14.770240350109408, 15.95368296037, 17.055204484262276, 18.089776118017603, 19.068298298484848, 19.998999974998753, 20.888274222635054, 21.741205118392127, 22.5619148123558, 23.353800547234275, 24.11970149069014, 24.862019226120797, 25.582806726393414, 26.283835336571418, 26.966646065093084, 27.632589455206695, 28.282856998542428, 28.918506185486144, 29.540480700218815, 30.149626863362673, 30.746707140765505, 31.332411333952585, 31.90736592074, 32.47214190656354, 33.02726146685493, 33.57320360049068, 34.11040896852455, 34.63928405726655, 35.16020477756067, 35.6735195908674, 36.17955223603521, 36.678604117387025, 37.1709564041605, 37.656871882831695, 38.136596596969696, 38.610361303670814, 39.07838277104108, 39.54086493742897, 39.99799994999751, 40.449969097639624, 40.89694365108474, 41.339085621237444, 41.77654844527011, 42.20947760870774, 42.63801121065569, 43.062280478395486, 43.482410236784254, 43.89851933721684, 44.31072105032822, 44.7191234261138, 45.1238296247116, 45.52493822071591, 45.9225434835659, 46.31673563626867, 46.70760109446855, 47.09522268765698, 47.47967986412714, 47.86104888111, 48.23940298138028, 48.61481255749116, 48.987345304680474, 49.357066363389144, 49.724038452241594, 50.088321992256844, 50.449975222986986, 50.80905431121505, 51.16561345278683, 51.51970496809935, 51.87137939172237, 52.22068555658763, 52.567670673142835, 52.912380403833666, 53.25485893324666, 53.59514903421765, 53.93329213018617, 54.26932835405282, 54.6032966037766, 54.93523459493006, 55.26517891041339, 55.59316504751283, 55.91922746247485, 56.243399612754565, 56.565713997084856, 56.88620219350208, 57.20489489545454, 57.521821946110165, 57.83701237097229, 58.15049440890423, 58.462295541656594, 58.77244252198474, 59.08096140043763, 59.38787755089419, 59.69321569491796, 59.99699992499627, 60.29925372672535, 60.600000000000016]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"A = 6.5\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.65, 0.9192388155425117, 1.1258330249197703, 1.3, 1.4534441853748636, 1.5921683328090657, 1.719738352191984, 1.8384776310850235, 1.95, 2.0554804791094465, 2.15580611373101, 2.2516660498395407, 2.343608329051593, 2.4320773014030617, 2.517439175034821, 2.6, 2.6800186566514794, 2.7577164466275352, 2.833284313301438, 2.9068883707497273, 2.9786742017212964, 3.0487702438852295, 3.1172904901532683, 3.1843366656181313, 3.25, 3.3143626838353106, 3.377499074759311, 3.439476704383968, 3.500357124637428, 3.5601966237835794, 3.6190468358395145, 3.676955262170047, 3.733965720249719, 3.7901187316494456, 3.84545185901475, 3.9, 3.9537956446938427, 4.006869101929835, 4.059248698958959, 4.110960958218893, 4.162030754331352, 4.212481453965109, 4.2623350407963, 4.31161222746202, 4.36033255612459, 4.4085144890314245, 4.456175490260678, 4.503332099679081, 4.55, 4.59619407771256, 4.641928478552853, 4.687216658103186, 4.732071428032338, 4.776504998427198, 4.820529016612181, 4.864154602806123, 4.907392382925988, 4.950252518811541, 4.992744736114595, 5.034878350069642, 5.076662289339326, 5.118105118107677, 5.159215056575952, 5.2, 5.240467536394057, 5.280624963013374, 5.320479301717093, 5.360037313302959, 5.399305510896749, 5.438290172471492, 5.4769973525646325, 5.5154328932550705, 5.553602434456396, 5.591511423577707, 5.629165124598851, 5.666568626602876, 5.70372685180488, 5.740644563113102, 5.777326371255133, 5.813776741499455, 5.8500000000000005, 5.886000339789321, 5.9217818264437945, 5.957348403442593, 5.992703897240378, 6.027852022072208, 6.062796384507729, 6.097540487770459, 6.132087735836793, 6.16644143732834, 6.200604809210147, 6.234580980306537, 6.268372994645421, 6.301983814641228, 6.335416324125826, 6.368673331236263, 6.401757571167469, 6.434671708797582, 6.467418341193031, 6.5, 6.532419153728579], [0.0, 0.9192388155425117, 1.2999999999999998, 1.592168332809066, 1.8384776310850235, 2.055480479109447, 2.25166604983954, 2.432077301403062, 2.5999999999999996, 2.7577164466275352, 2.9068883707497264, 3.0487702438852295, 3.184336665618132, 3.31436268383531, 3.4394767043839676, 3.5601966237835794, 3.676955262170047, 3.790118731649445, 3.8999999999999995, 4.006869101929835, 4.110960958218894, 4.212481453965109, 4.31161222746202, 4.4085144890314245, 4.50333209967908, 4.596194077712559, 4.687216658103186, 4.776504998427198, 4.864154602806124, 4.95025251881154, 5.034878350069642, 5.118105118107677, 5.199999999999999, 5.280624963013374, 5.360037313302959, 5.438290172471491, 5.5154328932550705, 5.591511423577708, 5.666568626602876, 5.740644563113101, 5.813776741499453, 5.886000339789321, 5.957348403442593, 6.0278520220722065, 6.097540487770459, 6.16644143732834, 6.234580980306535, 6.301983814641227, 6.368673331236264, 6.434671708797582, 6.5, 6.564678209935352, 6.62872536767062, 6.692159591641551, 6.754998149518622, 6.817257513105985, 6.878953408767935, 6.940100863820352, 7.000714249274855, 7.06080731928014, 7.120393247567159, 7.17948466117172, 7.238093671679028, 7.296231904209185, 7.353910524340094, 7.411140263144397, 7.467931440499437, 7.524293986813646, 7.58023746329889, 7.635771080905975, 7.690903718029501, 7.745643937078439, 7.799999999999999, 7.853979882836472, 7.9075912893876845, 7.960841664045328, 8.01373820385967, 8.066287869894056, 8.118497397917919, 8.170373308484747, 8.221921916437788, 8.273149339882606, 8.324061508662703, 8.374664172371332, 8.424962907930219, 8.474963126763445, 8.524670081592602, 8.574088872877397, 8.62322445492404, 8.672081641682116, 8.72066511224918, 8.768979416100828, 8.817028978062849, 8.864818103040808, 8.912350980521357, 8.959631688858643, 9.00666419935816, 9.053452380169679, 9.1, 9.146310731655689, 9.192388155425117, 9.238235762308733], [0.0, 1.1258330249197703, 1.592168332809066, 1.9500000000000006, 2.2516660498395407, 2.5174391750348217, 2.7577164466275357, 2.978674201721297, 3.184336665618132, 3.377499074759311, 3.5601966237835803, 3.7339657202497194, 3.9000000000000012, 4.059248698958959, 4.212481453965109, 4.3603325561245905, 4.503332099679081, 4.641928478552853, 4.776504998427198, 4.9073923829259884, 5.0348783500696435, 5.159215056575953, 5.280624963013375, 5.39930551089675, 5.515432893255071, 5.629165124598852, 5.740644563113102, 5.850000000000001, 5.957348403442594, 6.062796384507731, 6.16644143732834, 6.268372994645422, 6.368673331236264, 6.467418341193031, 6.564678209935352, 6.66051799787374, 6.754998149518622, 6.848174939354281, 6.940100863820354, 7.03082498715478, 7.1203932475671605, 7.208848729166123, 7.296231904209187, 7.382580849540356, 7.467931440499439, 7.552317525104463, 7.635771080905976, 7.718322356574647, 7.8000000000000025, 7.880831174438392, 7.96084166404533, 8.04005596995444, 8.118497397917919, 8.196188138397021, 8.273149339882607, 8.349401176132336, 8.424962907930219, 8.499852939904315, 8.574088872877399, 8.647687552172545, 8.720665112249181, 8.793037018004645, 8.864818103040808, 8.936022605163888, 9.006664199358163, 9.076756028449813, 9.146310731655689, 9.215340471192588, 9.283856957105707, 9.351871470459805, 9.419394885023136, 9.486437687562177, 9.553009996854396, 9.619121581516684, 9.684781876738372, 9.750000000000002, 9.814784765851977, 9.879144699820932, 9.943088051505933, 10.006622806921426, 10.069756700139287, 10.132497224277934, 10.194851641882781, 10.256826994738677, 10.318430113151907, 10.379667624736355, 10.44054596273586, 10.501071373912284, 10.56124992602675, 10.621087514939326, 10.68058987135074, 10.739762567207901, 10.7986110217935, 10.857140507518546, 10.915356155435333, 10.973262960487187, 11.030865786510143, 11.08816937100079, 11.14517832966346, 11.201897160749159, 11.258330249197703, 11.314481870593989], [0.0, 1.3, 1.8384776310850235, 2.2516660498395407, 2.6, 2.9068883707497273, 3.1843366656181313, 3.439476704383968, 3.676955262170047, 3.9, 4.110960958218893, 4.31161222746202, 4.503332099679081, 4.687216658103186, 4.864154602806123, 5.034878350069642, 5.2, 5.360037313302959, 5.5154328932550705, 5.666568626602876, 5.813776741499455, 5.957348403442593, 6.097540487770459, 6.234580980306537, 6.368673331236263, 6.5, 6.628725367670621, 6.754998149518622, 6.878953408767936, 7.000714249274856, 7.120393247567159, 7.238093671679029, 7.353910524340094, 7.467931440499438, 7.580237463298891, 7.6909037180295, 7.8, 7.907591289387685, 8.01373820385967, 8.118497397917919, 8.221921916437786, 8.324061508662703, 8.424962907930219, 8.5246700815926, 8.62322445492404, 8.72066511224918, 8.817028978062849, 8.912350980521357, 9.006664199358163, 9.1, 9.19238815542512, 9.283856957105707, 9.374433316206373, 9.464142856064676, 9.553009996854396, 9.641058033224361, 9.728309205612247, 9.814784765851975, 9.900505037623082, 9.98548947222919, 10.069756700139283, 10.153324578678651, 10.236210236215355, 10.318430113151903, 10.4, 10.480935072788114, 10.561249926026749, 10.640958603434186, 10.720074626605918, 10.798611021793498, 10.876580344942983, 10.953994705129265, 11.030865786510141, 11.107204868912792, 11.183022847155414, 11.258330249197702, 11.333137253205752, 11.40745370360976, 11.481289126226203, 11.554652742510266, 11.62755348299891, 11.700000000000001, 11.772000679578642, 11.843563652887589, 11.914696806885186, 11.985407794480755, 12.055704044144417, 12.125592769015459, 12.195080975540918, 12.264175471673585, 12.33288287465668, 12.401209618420294, 12.469161960613073, 12.536745989290843, 12.603967629282456, 12.670832648251652, 12.737346662472525, 12.803515142334938, 12.869343417595164, 12.934836682386061, 13.0, 13.064838307457158], [0.0, 1.4534441853748634, 2.0554804791094465, 2.5174391750348217, 2.906888370749727, 3.250000000000001, 3.56019662378358, 3.845451859014751, 4.110960958218893, 4.3603325561245905, 4.59619407771256, 4.8205290166121815, 5.0348783500696435, 5.240467536394058, 5.438290172471491, 5.629165124598852, 5.813776741499454, 5.992703897240377, 6.16644143732834, 6.335416324125827, 6.500000000000002, 6.6605179978737405, 6.817257513105987, 6.970473441596347, 7.12039324756716, 7.267220926874317, 7.411140263144398, 7.552317525104464, 7.690903718029502, 7.827036476214993, 7.960841664045328, 8.092434738692678, 8.221921916437786, 8.349401176132336, 8.474963126763443, 8.59869176095992, 8.720665112249181, 8.84095583067804, 8.959631688858645, 9.076756028449813, 9.19238815542512, 9.30658369112963, 9.419394885023136, 9.530870894099866, 9.641058033224363, 9.75, 9.857738077267017, 9.96431131589133, 10.069756700139287, 10.174109297624044, 10.277402395547234, 10.379667624736355, 10.480935072788116, 10.581233387464811, 10.68058987135074, 10.77903056865505, 10.876580344942981, 10.973262960487187, 11.069101137852162, 11.164116624256485, 11.258330249197703, 11.351761977772439, 11.444430960078357, 11.536355577044253, 11.627553482998907, 11.718041645257966, 11.807836380980218, 11.896953391520032, 11.985407794480754, 12.073214153654362, 12.16038650701531, 12.246938392920901, 12.33288287465668, 12.418232563452822, 12.502999640086374, 12.587195875174105, 12.670832648251654, 12.75392096572658, 12.836471477785476, 12.918494494328664, 13.000000000000004, 13.080997668373772, 13.161496875355782, 13.241506711851187, 13.321035995747481, 13.4000932832574, 13.478686879663021, 13.556824849499236, 13.634515026211973, 13.711765021323842, 13.788582233137678, 13.864973855006005, 13.940946883192694, 14.01650812435109, 14.09166420264122, 14.166421566507188, 14.24078649513432, 14.31476510460441, 14.388363353766126, 14.461587049836545, 14.534441853748634, 14.606933285258753], [0.0, 1.592168332809066, 2.25166604983954, 2.7577164466275357, 3.184336665618132, 3.5601966237835803, 3.9, 4.212481453965109, 4.50333209967908, 4.776504998427197, 5.034878350069642, 5.280624963013375, 5.515432893255071, 5.740644563113101, 5.957348403442592, 6.16644143732834, 6.368673331236264, 6.564678209935351, 6.754998149518621, 6.940100863820353, 7.1203932475671605, 7.296231904209187, 7.467931440499439, 7.635771080905976, 7.8, 7.960841664045329, 8.118497397917919, 8.273149339882607, 8.424962907930219, 8.574088872877399, 8.72066511224918, 8.864818103040808, 9.00666419935816, 9.146310731655689, 9.283856957105705, 9.419394885023134, 9.553009996854394, 9.684781876738372, 9.814784765851975, 9.943088051505931, 10.069756700139283, 10.19485164188278, 10.318430113151905, 10.440545962735856, 10.56124992602675, 10.680589871350739, 10.798611021793498, 10.915356155435333, 11.030865786510143, 11.14517832966346, 11.258330249197703, 11.370356194948338, 11.481289126226201, 11.591160425082556, 11.700000000000001, 11.807836380980218, 11.914696806885184, 12.020607305789504, 12.12559276901546, 12.229677019447406, 12.33288287465668, 12.435232205310845, 12.536745989290841, 12.637444361895328, 12.737346662472527, 12.836471477785475, 12.93483668238606, 13.032459476246224, 13.129356419870701, 13.225543467094274, 13.32103599574748, 13.41584883635769, 13.509996299037242, 13.603492198696628, 13.69634987870856, 13.788582233137676, 13.880201727640706, 13.97122041913304, 14.06164997430956, 14.151501687100208, 14.240786495134321, 14.329514995281594, 14.417697458332244, 14.50534384287391, 14.592463808418374, 14.679066727827081, 14.765161699080714, 14.85075755643462, 14.935862880998878, 15.020486010778745, 15.104635050208927, 15.1883178792123, 15.271542161811952, 15.354315354323035, 15.436644713149292, 15.518537302207317, 15.6, 15.681039506359268, 15.761662348876783, 15.841874889040126, 15.921683328090658, 16.001093712618523], [0.0, 1.7197383521919838, 2.4320773014030617, 2.9786742017212964, 3.4394767043839676, 3.845451859014751, 4.212481453965109, 4.550000000000001, 4.864154602806123, 5.159215056575952, 5.438290172471492, 5.7037268518048805, 5.957348403442593, 6.200604809210147, 6.434671708797582, 6.660517997873739, 6.878953408767935, 7.090662874513214, 7.296231904209185, 7.496165686536018, 7.690903718029502, 7.880831174438392, 8.066287869894058, 8.24757540129219, 8.424962907930219, 8.59869176095992, 8.768979416100828, 8.936022605163888, 9.100000000000001, 9.261074451703756, 9.419394885023134, 9.575097910726553, 9.728309205612247, 9.879144699820932, 10.027711603351984, 10.174109297624042, 10.318430113151903, 10.460760010630203, 10.601179179695059, 10.7397625672079, 10.876580344942983, 11.011698324963321, 11.145178329663462, 11.277078522383357, 11.407453703609761, 11.536355577044251, 11.663832989202135, 11.789932145691084, 11.914696806885186, 12.038168465343887, 12.16038650701531, 12.28138835799927, 12.401209618420294, 12.519884184767847, 12.637444361895328, 12.753920965726579, 12.869343417595164, 12.983739831034818, 13.097137091746426, 13.209560931386022, 13.321035995747478, 13.431585907851687, 13.541233326399778, 13.65, 13.75790681753587, 13.864973855006001, 13.97122041913304, 14.076665088010015, 14.181325749026428, 14.285219634293343, 14.388363353766126, 14.49077292624517, 14.59246380841837, 14.693450922094511, 14.793748679763354, 14.89337100860648, 14.992331373072036, 15.09064279611707, 15.1883178792123, 15.2853688211963, 15.381807436059004, 15.477645169727856, 15.572893115924222, 15.667562031152135, 15.761662348876785, 15.85520419294561, 15.948197390300889, 16.040651483028984, 16.132575739788116, 16.22397916665329, 16.314870517414473, 16.405258303361155, 16.49515080258438, 16.584556068824998, 16.67348193989486, 16.76193604569591, 16.849925815860438, 16.937458487034, 17.02454110982143, 17.11118055541464, 17.19738352191984, 17.28315654040083], [0.0, 1.8384776310850235, 2.5999999999999996, 3.184336665618132, 3.676955262170047, 4.110960958218894, 4.50333209967908, 4.864154602806124, 5.199999999999999, 5.5154328932550705, 5.813776741499453, 6.097540487770459, 6.368673331236264, 6.62872536767062, 6.878953408767935, 7.120393247567159, 7.353910524340094, 7.58023746329889, 7.799999999999999, 8.01373820385967, 8.221921916437788, 8.424962907930219, 8.62322445492404, 8.817028978062849, 9.00666419935816, 9.192388155425117, 9.374433316206373, 9.553009996854396, 9.728309205612248, 9.90050503762308, 10.069756700139283, 10.236210236215355, 10.399999999999999, 10.561249926026749, 10.720074626605918, 10.876580344942981, 11.030865786510141, 11.183022847155415, 11.333137253205752, 11.481289126226201, 11.627553482998906, 11.772000679578642, 11.914696806885186, 12.055704044144413, 12.195080975540918, 12.33288287465668, 12.46916196061307, 12.603967629282455, 12.737346662472527, 12.869343417595164, 13.0, 13.129356419870703, 13.25745073534124, 13.384319183283102, 13.509996299037244, 13.63451502621197, 13.75790681753587, 13.880201727640705, 14.00142849854971, 14.12161463856028, 14.240786495134317, 14.35896932234344, 14.476187343358056, 14.59246380841837, 14.707821048680188, 14.822280526288793, 14.935862880998874, 15.048587973627292, 15.16047492659778, 15.27154216181195, 15.381807436059002, 15.491287874156878, 15.599999999999998, 15.707959765672944, 15.815182578775369, 15.921683328090657, 16.02747640771934, 16.132575739788113, 16.236994795835837, 16.340746616969493, 16.443843832875576, 16.54629867976521, 16.648123017325407, 16.749328344742665, 16.849925815860438, 16.94992625352689, 17.049340163185203, 17.148177745754793, 17.24644890984808, 17.34416328336423, 17.44133022449836, 17.537958832201657, 17.634057956125698, 17.729636206081615, 17.824701961042713, 17.919263377717286, 18.01332839871632, 18.106904760339358, 18.2, 18.292621463311377, 18.384776310850235, 18.476471524617466], [0.0, 1.95, 2.7577164466275352, 3.377499074759311, 3.9, 4.3603325561245905, 4.776504998427197, 5.159215056575952, 5.5154328932550705, 5.85, 6.16644143732834, 6.467418341193031, 6.754998149518622, 7.030824987154779, 7.2962319042091845, 7.5523175251044625, 7.8, 8.040055969954437, 8.273149339882606, 8.499852939904313, 8.720665112249181, 8.936022605163888, 9.146310731655689, 9.351871470459804, 9.553009996854394, 9.75, 9.943088051505931, 10.132497224277932, 10.318430113151903, 10.501071373912284, 10.680589871350739, 10.857140507518544, 11.030865786510141, 11.201897160749157, 11.370356194948336, 11.536355577044251, 11.7, 11.861386934081528, 12.020607305789504, 12.177746096876877, 12.33288287465668, 12.486092262994054, 12.637444361895328, 12.7870051223889, 12.934836682386061, 13.080997668373769, 13.225543467094273, 13.368526470782035, 13.509996299037244, 13.649999999999999, 13.788582233137676, 13.92578543565856, 14.061649974309558, 14.196214284097012, 14.329514995281592, 14.461587049836542, 14.592463808418369, 14.722177148777963, 14.85075755643462, 14.978234208343784, 15.104635050208925, 15.229986868017976, 15.354315354323031, 15.477645169727854, 15.6, 15.72140260918217, 15.841874889040122, 15.961437905151277, 16.080111939908875, 16.197916532690247, 16.314870517414473, 16.430992057693896, 16.54629867976521, 16.660807303369186, 16.77453427073312, 16.887495373796554, 16.999705879808626, 17.111180555414638, 17.221933689339302, 17.331979113765396, 17.441330224498362, 17.55, 17.658001019367962, 17.765345479331383, 17.872045210327776, 17.978111691721132, 18.083556066216623, 18.18838915352319, 18.292621463311377, 18.396263207510376, 18.499324311985017, 18.60181442763044, 18.703742940919607, 18.805118983936264, 18.905951443923684, 19.006248972377477, 19.106019993708788, 19.205272713502406, 19.304015126392745, 19.40225502357909, 19.5, 19.597257461185738], [0.0, 2.0554804791094465, 2.9068883707497264, 3.5601966237835803, 4.110960958218893, 4.59619407771256, 5.034878350069642, 5.438290172471492, 5.813776741499453, 6.16644143732834, 6.5, 6.817257513105986, 7.1203932475671605, 7.4111402631443974, 7.6909037180295, 7.960841664045328, 8.221921916437786, 8.474963126763443, 8.72066511224918, 8.959631688858645, 9.19238815542512, 9.419394885023136, 9.641058033224363, 9.857738077267017, 10.069756700139283, 10.277402395547233, 10.480935072788116, 10.68058987135074, 10.876580344942983, 11.069101137852162, 11.258330249197702, 11.444430960078357, 11.627553482998906, 11.807836380980218, 11.985407794480754, 12.160386507015309, 12.33288287465668, 12.502999640086374, 12.670832648251654, 12.836471477785475, 13.0, 13.161496875355782, 13.32103599574748, 13.478686879663018, 13.634515026211972, 13.788582233137676, 13.94094688319269, 14.091664202641219, 14.240786495134321, 14.388363353766126, 14.534441853748634, 14.679066727827081, 14.822280526288795, 14.964123763187741, 15.104635050208927, 15.243851219426146, 15.381807436059, 15.518537302207319, 15.654072952429985, 15.788445141938453, 15.921683328090657, 16.05381574579701, 16.18486947738535, 16.314870517414473, 16.443843832875572, 16.57181341917655, 16.698802352264668, 16.82483283720822, 16.949926253526886, 17.074103197532807, 17.19738352191984, 17.319786372816495, 17.44133022449836, 17.562032911938186, 17.681911661356075, 17.800983118917898, 17.91926337771729, 18.03676800316509, 18.153512056899626, 18.269510119321755, 18.38477631085024, 18.49932431198502, 18.61316738225926, 18.726318378154314, 18.838789770046272, 18.95059365824723, 19.061741788199736, 19.172245564878413, 19.282116066448726, 19.391364057229186, 19.5, 19.608034067697865, 19.715476154534034, 19.82233588656998, 19.92862263178266, 20.03434550964917, 20.139513400278567, 20.24413495311667, 20.348218595248085, 20.451772539317957, 20.554804791094465, 20.657323156691916], [0.0, 2.15580611373101, 3.048770243885229, 3.7339657202497194, 4.31161222746202, 4.820529016612182, 5.280624963013374, 5.7037268518048805, 6.097540487770458, 6.46741834119303, 6.817257513105986, 7.150000000000001, 7.467931440499439, 7.77286948301591, 8.066287869894056, 8.349401176132334, 8.62322445492404, 8.888616315265274, 9.146310731655687, 9.396940991620626, 9.641058033224365, 9.879144699820934, 10.111626970967631, 10.338882918381465, 10.561249926026749, 10.77903056865505, 10.992497441437047, 11.201897160749159, 11.407453703609761, 11.60937121466964, 11.807836380980218, 12.003020453202604, 12.195080975540916, 12.384163274117475, 12.570401743778916, 12.753920965726579, 12.93483668238606, 13.113256651190811, 13.289281395169569, 13.463004865185187, 13.634515026211972, 13.803894378036947, 13.971220419133042, 14.136566061105505, 14.300000000000002, 14.461587049836544, 14.62138844296259, 14.779462101172696, 14.935862880998878, 15.09064279611707, 15.243851219426148, 15.395535067025117, 15.54573896603182, 15.69450540794453, 15.841874889040126, 15.987886039123497, 16.132575739788113, 16.27597923321359, 16.418130222409616, 16.559060963714096, 16.698802352264668, 16.837384001085205, 16.974834314360773, 17.111180555414638, 17.24644890984808, 17.38066454425722, 17.513851660899725, 17.646033548647697, 17.77723263053055, 17.907470508142687, 18.036768003165093, 18.165145196226756, 18.292621463311374, 18.419215509896183, 18.54494540299324, 18.669828601248593, 18.793881983241253, 18.917121874111825, 19.039564070639855, 19.161223864878778, 19.28211606644873, 19.40225502357909, 19.52165464298557, 19.640328408659567, 19.758289399641868, 19.875550306846858, 19.992123448998612, 20.108020787735427, 20.223253941935262, 20.33783420131062, 20.451772539317957, 20.56507962542329, 20.67776583676293, 20.789841269235325, 20.901315748057588, 21.012198837817998, 21.122499852053497, 21.232227862379403, 21.341391707196603, 21.450000000000003, 21.5580611373101, 21.66558330624865], [0.0, 2.2516660498395407, 3.184336665618132, 3.9000000000000012, 4.503332099679081, 5.0348783500696435, 5.515432893255071, 5.957348403442594, 6.368673331236264, 6.754998149518622, 7.1203932475671605, 7.467931440499439, 7.8000000000000025, 8.118497397917919, 8.424962907930219, 8.720665112249181, 9.006664199358163, 9.283856957105707, 9.553009996854396, 9.814784765851977, 10.069756700139287, 10.318430113151907, 10.56124992602675, 10.7986110217935, 11.030865786510143, 11.258330249197703, 11.481289126226203, 11.700000000000003, 11.914696806885187, 12.125592769015462, 12.33288287465668, 12.536745989290845, 12.737346662472527, 12.934836682386061, 13.129356419870703, 13.32103599574748, 13.509996299037244, 13.696349878708562, 13.880201727640708, 14.06164997430956, 14.240786495134321, 14.417697458332245, 14.592463808418374, 14.765161699080712, 14.935862880998878, 15.104635050208927, 15.271542161811952, 15.436644713149294, 15.600000000000005, 15.761662348876785, 15.92168332809066, 16.08011193990888, 16.236994795835837, 16.392376276794042, 16.546298679765215, 16.69880235226467, 16.849925815860438, 16.99970587980863, 17.148177745754797, 17.29537510434509, 17.441330224498362, 17.58607403600929, 17.729636206081615, 17.872045210327776, 18.013328398716325, 18.153512056899626, 18.292621463311377, 18.430680942385177, 18.567713914211414, 18.70374294091961, 18.838789770046272, 18.972875375124353, 19.10601999370879, 19.238243163033367, 19.369563753476744, 19.500000000000004, 19.629569531703954, 19.758289399641864, 19.886176103011866, 20.01324561384285, 20.139513400278574, 20.264994448555868, 20.389703283765563, 20.513653989477355, 20.636860226303813, 20.75933524947271, 20.88109192547172, 21.002142747824568, 21.1224998520535, 21.242175029878652, 21.36117974270148, 21.479525134415802, 21.597222043587, 21.71428101503709, 21.830712310870666, 21.946525920974373, 22.061731573020285, 22.17633874200158, 22.29035665932692, 22.403794321498317, 22.516660498395407, 22.628963741187977], [0.0, 2.343608329051593, 3.31436268383531, 4.059248698958959, 4.687216658103186, 5.240467536394059, 5.740644563113101, 6.200604809210148, 6.62872536767062, 7.030824987154779, 7.4111402631443974, 7.77286948301591, 8.118497397917919, 8.450000000000001, 8.768979416100827, 9.076756028449811, 9.374433316206373, 9.66294468575703, 9.94308805150593, 10.215551869576114, 10.480935072788117, 10.739762567207901, 10.992497441437047, 11.23955070276388, 11.481289126226201, 11.718041645257966, 11.950104602052654, 12.177746096876879, 12.401209618420296, 12.62071709531594, 12.836471477785475, 13.048658934925077, 13.25745073534124, 13.463004865185187, 13.665467427058616, 13.864973855006003, 14.061649974309558, 14.255612929649851, 14.446972001080367, 14.635829323957015, 14.822280526288795, 15.006415294799757, 15.188317879212303, 15.368067542797956, 15.54573896603182, 15.721402609182173, 15.89512503882873, 16.066969222600758, 16.236994795835837, 16.40525830336115, 16.571813419176554, 16.736711146458855, 16.900000000000002, 17.061726172928697, 17.221933689339302, 17.38066454425722, 17.537958832201653, 17.69385486546106, 17.84838928306978, 18.0015971513641, 18.153512056899622, 18.304166192427342, 18.453590436551906, 18.60181442763044, 18.748866632412746, 18.894774409873225, 19.039564070639855, 19.18326093238582, 19.32588937151406, 19.46747287143352, 19.608034067697865, 19.747594790252304, 19.88617610301186, 20.023798340974174, 20.16048114505207, 20.296243494794794, 20.431103739152228, 20.565079625423287, 20.698188326517858, 20.830446466650685, 20.961870145576235, 21.09247496146434, 21.222276032508862, 21.351288017353898, 21.479525134415802, 21.607001180173064, 21.73372954649064, 21.85972323704031, 21.984994882874094, 22.109556757203432, 22.233420789433193, 22.356598578495795, 22.47910140552776, 22.600940245927827, 22.722125780833096, 22.842668408047253, 22.962578252452403, 23.08186517593412, 23.200538786847172, 23.31860844904773, 23.43608329051593, 23.552972211591474], [0.0, 2.4320773014030617, 3.4394767043839676, 4.212481453965109, 4.864154602806123, 5.438290172471492, 5.957348403442592, 6.434671708797583, 6.878953408767935, 7.296231904209185, 7.6909037180295, 8.066287869894058, 8.424962907930219, 8.768979416100828, 9.1, 9.419394885023134, 9.728309205612247, 10.027711603351982, 10.318430113151903, 10.601179179695059, 10.876580344942983, 11.14517832966346, 11.40745370360976, 11.663832989202136, 11.914696806885184, 12.160386507015309, 12.401209618420294, 12.637444361895328, 12.869343417595166, 13.097137091746426, 13.321035995747476, 13.541233326399778, 13.75790681753587, 13.97122041913304, 14.181325749026428, 14.388363353766124, 14.59246380841837, 14.793748679763354, 14.992331373072036, 15.188317879212299, 15.381807436059, 15.572893115924222, 15.761662348876785, 15.948197390300885, 16.132575739788116, 16.314870517414473, 16.495150802584376, 16.673481939894856, 16.849925815860438, 17.02454110982143, 17.19738352191984, 17.368505980653605, 17.537958832201657, 17.70579001343911, 17.872045210327776, 18.03676800316509, 18.2, 18.361780959373196, 18.52214890340751, 18.681140222159886, 18.83878977004627, 18.995130955063196, 19.150195821453107, 19.30401512639275, 19.456618411224493, 19.60803406769786, 19.758289399641864, 19.90741068044762, 20.055423206703964, 20.20235134829607, 20.348218595248085, 20.49304760156478, 20.636860226303806, 20.779677572089515, 20.921520021260402, 21.062407269825545, 21.202358359390118, 21.341391707196603, 21.4795251344158, 21.616775892810658, 21.753160689885966, 21.88869571262756, 22.023396649926642, 22.157278713777107, 22.29035665932692, 22.422644803858443, 22.554157044766715, 22.68490687659969, 22.81490740721952, 22.944171373139625, 23.072711154088502, 23.200538786847172, 23.327665978404273, 23.45410411846933, 23.57986429138217, 23.704957287453606, 23.829393613770367, 23.953183504494767, 24.076336930687773, 24.19886360968217, 24.320773014030618, 24.442074380052116], [0.0, 2.517439175034821, 3.5601966237835794, 4.3603325561245905, 5.034878350069642, 5.629165124598852, 6.166441437328339, 6.660517997873739, 7.120393247567159, 7.5523175251044625, 7.960841664045328, 8.349401176132334, 8.720665112249181, 9.076756028449811, 9.419394885023134, 9.749999999999998, 10.069756700139283, 10.379667624736351, 10.680589871350737, 10.973262960487185, 11.258330249197703, 11.536355577044251, 11.807836380980218, 12.073214153654362, 12.332882874656677, 12.587195875174103, 12.836471477785475, 13.08099766837377, 13.321035995747478, 13.556824849499236, 13.788582233137674, 14.016508124351086, 14.240786495134317, 14.461587049836542, 14.679066727827077, 14.893371008606477, 15.104635050208925, 15.312984686206669, 15.518537302207319, 15.72140260918217, 15.921683328090657, 16.119475797928416, 16.314870517414473, 16.50795262896038, 16.698802352264668, 16.88749537379655, 17.074103197532803, 17.25869346155728, 17.441330224498362, 17.622074225243743, 17.800983118917898, 17.978111691721132, 18.153512056899622, 18.32723383383319, 18.499324311985017, 18.669828601248593, 18.83878977004627, 19.006248972377477, 19.172245564878413, 19.336817214836568, 19.499999999999996, 19.661828500930426, 19.822335886569977, 19.981553993621215, 20.139513400278567, 20.29624349479479, 20.451772539317954, 20.606127729391563, 20.759335249472702, 20.911420324789034, 21.062407269825545, 21.21231953370493, 21.361179742701474, 21.509009740106585, 21.655830623644984, 21.801662780622948, 21.94652592097437, 22.090439108356353, 22.23342078943319, 22.375488821476054, 22.516660498395407, 22.65695257531339, 22.796381291775234, 22.934962393690554, 23.072711154088502, 23.209642392764263, 23.345770494888363, 23.481109428644974, 23.615672761960436, 23.74947367837864, 23.882524992135984, 24.014839162484517, 24.146428307308724, 24.27730421607803, 24.40747836217416, 24.53696191462993, 24.665765749313355, 24.793900459588848, 24.921376366485053, 25.048203528397003, 25.174391750348207, 25.29995059283713], [0.0, 2.6, 3.676955262170047, 4.503332099679081, 5.2, 5.813776741499455, 6.368673331236263, 6.878953408767936, 7.353910524340094, 7.8, 8.221921916437786, 8.62322445492404, 9.006664199358163, 9.374433316206373, 9.728309205612247, 10.069756700139283, 10.4, 10.720074626605918, 11.030865786510141, 11.333137253205752, 11.62755348299891, 11.914696806885186, 12.195080975540918, 12.469161960613073, 12.737346662472525, 13.0, 13.257450735341243, 13.509996299037244, 13.757906817535872, 14.001428498549712, 14.240786495134317, 14.476187343358058, 14.707821048680188, 14.935862880998876, 15.160474926597782, 15.381807436059, 15.6, 15.81518257877537, 16.02747640771934, 16.236994795835837, 16.443843832875572, 16.648123017325407, 16.849925815860438, 17.0493401631852, 17.24644890984808, 17.44133022449836, 17.634057956125698, 17.824701961042713, 18.013328398716325, 18.2, 18.38477631085024, 18.567713914211414, 18.748866632412746, 18.92828571212935, 19.10601999370879, 19.282116066448722, 19.456618411224493, 19.62956953170395, 19.801010075246165, 19.97097894445838, 20.139513400278567, 20.306649157357302, 20.47242047243071, 20.636860226303806, 20.8, 20.961870145576228, 21.122499852053497, 21.28191720686837, 21.440149253211835, 21.597222043586996, 21.753160689885966, 21.90798941025853, 22.061731573020282, 22.214409737825584, 22.366045694310827, 22.516660498395403, 22.666274506411504, 22.81490740721952, 22.962578252452406, 23.10930548502053, 23.25510696599782, 23.400000000000002, 23.544001359157285, 23.687127305775178, 23.82939361377037, 23.97081558896151, 24.111408088288833, 24.251185538030917, 24.390161951081836, 24.52835094334717, 24.66576574931336, 24.80241923684059, 24.938323921226146, 25.073491978581686, 25.207935258564913, 25.341665296503304, 25.47469332494505, 25.607030284669875, 25.73868683519033, 25.869673364772122, 26.0, 26.129676614914317], [0.0, 2.6800186566514794, 3.790118731649445, 4.641928478552853, 5.360037313302959, 5.992703897240378, 6.564678209935351, 7.090662874513215, 7.58023746329889, 8.040055969954437, 8.474963126763443, 8.888616315265274, 9.283856957105707, 9.66294468575703, 10.027711603351982, 10.379667624736353, 10.720074626605918, 11.049999999999999, 11.370356194948336, 11.68193049114743, 11.985407794480755, 12.28138835799927, 12.570401743778916, 12.852917956635375, 13.129356419870701, 13.400093283257396, 13.665467427058616, 13.92578543565856, 14.18132574902643, 14.432342152263438, 14.679066727827077, 14.921712368223696, 15.16047492659778, 15.395535067025115, 15.6270598642227, 15.855204192945607, 16.080111939908875, 16.30191706517979, 16.520744535280485, 16.736711146458852, 16.949926253526886, 17.160492417177313, 17.368505980653605, 17.574057584974504, 17.77723263053055, 17.97811169172113, 18.176770890342432, 18.37328223263334, 18.567713914211414, 18.760130596560355, 18.95059365824723, 19.139161423636097, 19.32588937151406, 19.510830325744728, 19.694034629806055, 19.87555030684685, 20.055423206703964, 20.233697141155396, 20.410414008539856, 20.58561390874705, 20.759335249472706, 20.931614844536004, 21.102488004972304, 21.27198862353964, 21.440149253211835, 21.607001180173057, 21.772574491777494, 21.936898139892065, 22.099999999999998, 22.261906926406823, 22.422644803858443, 22.58223859585227, 22.74071238989667, 22.8980894399511, 23.054392206258658, 23.209642392764263, 23.36386098229486, 23.517068269663206, 23.669283892843065, 23.820526862351304, 23.97081558896151, 24.120167909863316, 24.26860111337281, 24.416131962290834, 24.56277671599854, 24.708551151372678, 24.85347058259671, 24.997549879938234, 25.140803487557832, 25.28324544040974, 25.42488938029033, 25.565748571086278, 25.70583591327075, 25.84516395769236, 25.98374491869869, 26.12159068663315, 26.258712839741403, 26.395122655521043, 26.530831121546115, 26.665848945795823, 26.800186566514792, 26.93385416163086], [0.0, 2.7577164466275352, 3.9, 4.776504998427198, 5.5154328932550705, 6.1664414373283405, 6.754998149518621, 7.296231904209186, 7.8, 8.273149339882606, 8.72066511224918, 9.146310731655689, 9.553009996854396, 9.943088051505931, 10.318430113151903, 10.680589871350739, 11.030865786510141, 11.370356194948336, 11.7, 12.020607305789506, 12.332882874656681, 12.637444361895328, 12.934836682386061, 13.225543467094274, 13.509996299037242, 13.788582233137676, 14.06164997430956, 14.329514995281594, 14.592463808418373, 14.850757556434623, 15.104635050208925, 15.354315354323033, 15.6, 15.841874889040124, 16.080111939908875, 16.314870517414473, 16.54629867976521, 16.774534270733124, 16.99970587980863, 17.221933689339302, 17.44133022449836, 17.658001019367962, 17.872045210327776, 18.083556066216623, 18.292621463311377, 18.499324311985017, 18.703742940919607, 18.905951443923684, 19.10601999370879, 19.30401512639275, 19.5, 19.694034629806055, 19.886176103011863, 20.076478774924652, 20.264994448555864, 20.451772539317954, 20.636860226303806, 20.820302591461058, 21.002142747824568, 21.18242195784042, 21.361179742701477, 21.538453983515158, 21.714281015037084, 21.88869571262756, 22.061731573020282, 22.23342078943319, 22.403794321498314, 22.57288196044094, 22.74071238989667, 22.907313242717926, 23.072711154088502, 23.23693181123532, 23.4, 23.561939648509416, 23.722773868163056, 23.882524992135988, 24.04121461157901, 24.19886360968217, 24.355492193753758, 24.511119925454242, 24.665765749313362, 24.81944801964782, 24.972184525988112, 25.123992517113997, 25.274888723790657, 25.424889380290335, 25.574010244777806, 25.72226661863219, 25.869673364772122, 26.01624492504635, 26.16199533674754, 26.306938248302483, 26.45108693418855, 26.594454309122423, 26.737052941564073, 26.87889506657593, 27.019992598074484, 27.16035714050904, 27.299999999999997, 27.438932194967066, 27.577164466275352, 27.7147072869262], [0.0, 2.833284313301438, 4.006869101929835, 4.9073923829259884, 5.666568626602876, 6.335416324125828, 6.940100863820352, 7.496165686536019, 8.01373820385967, 8.499852939904315, 8.959631688858645, 9.396940991620626, 9.814784765851977, 10.215551869576114, 10.601179179695059, 10.973262960487187, 11.333137253205752, 11.68193049114743, 12.020607305789504, 12.350000000000001, 12.670832648251656, 12.98373983103482, 13.28928139516957, 13.587954224238471, 13.880201727640705, 14.166421566507191, 14.446972001080368, 14.722177148777964, 14.992331373072037, 15.257702972597155, 15.518537302207319, 15.77505942936508, 16.02747640771934, 16.27597923321359, 16.520744535280485, 16.761936045695915, 16.99970587980863, 17.23419565863171, 17.46553749530773, 17.693854865461063, 17.91926337771729, 18.141871458038725, 18.3617809593732, 18.579087706343387, 18.793881983241253, 19.00624897237748, 19.21626914882283, 19.424018636729116, 19.629569531703954, 19.832990193110067, 20.034345509649178, 20.2336971411554, 20.431103739152228, 20.626621148409164, 20.82030259146106, 21.012198837818, 21.202358359390118, 21.39082747347564, 21.577650474507184, 21.76286975561817, 21.946525920974373, 22.128657889713967, 22.30930299224967, 22.488497059608054, 22.666274506411504, 22.842668408047253, 23.017710572513508, 23.191431607384658, 23.36386098229486, 23.535027087301177, 23.704957287453613, 23.873677973869047, 24.041214611579008, 24.207591784396897, 24.372833237028477, 24.536961914629938, 24.700000000000003, 24.861968948576862, 25.02288952139621, 25.182781816153675, 25.34166529650331, 25.499558819712945, 25.656480662787718, 25.81244854716422, 25.96747966206964, 26.121590686633162, 26.274797810830062, 26.42711675533296, 26.57856279033914, 26.729150753437718, 26.878895066575936, 27.027809752179333, 27.175908448476942, 27.32320442407882, 27.469710591850074, 27.6154395221224, 27.76040345528141, 27.904614313765393, 28.048083713508845, 28.190822974861877, 28.332843133014382, 28.474154947952368], [0.0, 2.906888370749727, 4.110960958218893, 5.0348783500696435, 5.813776741499454, 6.500000000000002, 7.12039324756716, 7.690903718029502, 8.221921916437786, 8.720665112249181, 9.19238815542512, 9.641058033224363, 10.069756700139287, 10.480935072788116, 10.876580344942981, 11.258330249197703, 11.627553482998907, 11.985407794480754, 12.33288287465668, 12.670832648251654, 13.000000000000004, 13.321035995747481, 13.634515026211973, 13.940946883192694, 14.24078649513432, 14.534441853748634, 14.822280526288797, 15.104635050208929, 15.381807436059004, 15.654072952429987, 15.921683328090657, 16.184869477385355, 16.443843832875572, 16.69880235226467, 16.949926253526886, 17.19738352191984, 17.441330224498362, 17.68191166135608, 17.91926337771729, 18.153512056899626, 18.38477631085024, 18.61316738225926, 18.838789770046272, 19.061741788199733, 19.282116066448726, 19.5, 19.715476154534034, 19.92862263178266, 20.139513400278574, 20.34821859524809, 20.55480479109447, 20.75933524947271, 20.96187014557623, 21.162466774929623, 21.36117974270148, 21.5580611373101, 21.753160689885963, 21.946525920974373, 22.138202275704323, 22.32823324851297, 22.516660498395407, 22.703523955544878, 22.888861920156714, 23.072711154088505, 23.255106965997815, 23.43608329051593, 23.615672761960436, 23.793906783040065, 23.970815588961507, 24.146428307308724, 24.32077301403062, 24.493876785841803, 24.66576574931336, 24.836465126905644, 25.005999280172748, 25.17439175034821, 25.341665296503308, 25.50784193145316, 25.672942955570953, 25.83698898865733, 26.000000000000007, 26.161995336747545, 26.322993750711564, 26.483013423702374, 26.642071991494962, 26.8001865665148, 26.957373759326043, 27.113649698998472, 27.269030052423947, 27.423530042647684, 27.577164466275356, 27.72994771001201, 27.88189376638539, 28.03301624870218, 28.18332840528244, 28.332843133014375, 28.48157299026864, 28.62953020920882, 28.77672670753225, 28.92317409967309, 29.068883707497267, 29.213866570517506], [0.0, 2.978674201721296, 4.212481453965109, 5.1592150565759525, 5.957348403442592, 6.6605179978737405, 7.296231904209185, 7.880831174438393, 8.424962907930219, 8.936022605163888, 9.419394885023136, 9.879144699820934, 10.318430113151905, 10.739762567207901, 11.14517832966346, 11.536355577044251, 11.914696806885184, 12.28138835799927, 12.637444361895326, 12.983739831034818, 13.321035995747481, 13.650000000000002, 13.971220419133042, 14.285219634293345, 14.59246380841837, 14.893371008606481, 15.188317879212303, 15.477645169727857, 15.761662348876786, 16.040651483028988, 16.314870517414473, 16.584556068824998, 16.849925815860438, 17.11118055541464, 17.368505980653605, 17.622074225243747, 17.872045210327776, 18.118567824196262, 18.361780959373196, 18.60181442763044, 18.838789770046272, 19.072820976457574, 19.304015126392752, 19.532472961711736, 19.758289399641868, 19.981553993621215, 20.20235134829607, 20.420761494126513, 20.63686022630381, 20.850719412049074, 21.06240726982555, 21.271988623539645, 21.479525134415802, 21.685075512895963, 21.88869571262756, 22.090439108356357, 22.29035665932692, 22.488497059608054, 22.684906876599694, 22.87963067883745, 23.072711154088502, 23.264189218625265, 23.45410411846933, 23.642493523315178, 23.829393613770367, 24.014839162484517, 24.19886360968217, 24.38149913356437, 24.56277671599854, 24.74272620387657, 24.92137636648506, 25.09875494920017, 25.274888723790653, 25.449803535587463, 25.62352434775513, 25.79607528287976, 25.967479662069636, 26.13776004174803, 26.306938248302487, 26.475035410741192, 26.642071991494962, 26.80806781549167, 26.97304209762036, 27.137013468692537, 27.300000000000004, 27.462019226560894, 27.623088169138516, 27.783223355111264, 27.942440838266084, 28.10075621758247, 28.258184655069407, 28.414740892712718, 28.57043926858669, 28.725293732179665, 28.87931785897998, 29.03252486436548, 29.18492761683674, 29.336538650631574, 29.487370177755764, 29.637434099462798, 29.786742017212962, 29.935305243140586], [0.0, 3.048770243885229, 4.311612227462019, 5.280624963013375, 6.097540487770458, 6.817257513105987, 7.467931440499437, 8.066287869894058, 8.623224454924038, 9.146310731655689, 9.641058033224363, 10.111626970967631, 10.56124992602675, 10.992497441437047, 11.40745370360976, 11.807836380980218, 12.195080975540916, 12.570401743778916, 12.93483668238606, 13.289281395169569, 13.634515026211973, 13.971220419133042, 14.300000000000002, 14.621388442962592, 14.935862880998874, 15.243851219426146, 15.54573896603182, 15.841874889040126, 16.132575739788116, 16.418130222409616, 16.698802352264668, 16.974834314360777, 17.246448909848077, 17.513851660899725, 17.77723263053055, 18.03676800316509, 18.292621463311377, 18.54494540299324, 18.79388198324125, 19.039564070639855, 19.282116066448726, 19.52165464298557, 19.758289399641864, 19.99212344899861, 20.223253941935262, 20.451772539317954, 20.677765836762926, 20.901315748057584, 21.1224998520535, 21.341391707196603, 21.5580611373101, 21.772574491777497, 21.984994882874094, 22.19538240265304, 22.403794321498314, 22.610285270203914, 22.81490740721952, 23.017710572513508, 23.21874242933928, 23.418048595047367, 23.615672761960436, 23.811656809218466, 24.006040906405204, 24.19886360968217, 24.390161951081833, 24.579971521545747, 24.768326548234946, 24.95525996658821, 25.140803487557832, 25.324987660411605, 25.50784193145316, 25.689394698980355, 25.86967336477212, 26.048704382368044, 26.22651330238162, 26.40312481506687, 26.578562790339138, 26.75285031543368, 26.926009730370378, 27.09806266137858, 27.269030052423947, 27.438932194967066, 27.607788756073894, 27.775618804987946, 27.942440838266084, 28.108272803571552, 28.273132122211013, 28.437035710495564, 28.600000000000005, 28.762040956788862, 28.923174099673087, 29.083414517556225, 29.242776885925185, 29.401275482536473, 29.55892420234539, 29.715736571722395, 29.871725761997748, 30.02690460237286, 30.181285592234136, 30.334880912902893, 30.487702438852292, 30.63976174842096], [0.0, 3.117290490153268, 4.4085144890314245, 5.39930551089675, 6.234580980306536, 6.970473441596347, 7.635771080905975, 8.24757540129219, 8.817028978062849, 9.351871470459804, 9.857738077267017, 10.338882918381465, 10.7986110217935, 11.23955070276388, 11.663832989202135, 12.073214153654362, 12.469161960613071, 12.852917956635373, 13.225543467094273, 13.58795422423847, 13.940946883192694, 14.285219634293345, 14.621388442962592, 14.950000000000003, 15.27154216181195, 15.58645245076634, 15.895125038828732, 16.19791653269025, 16.49515080258438, 16.787123041188448, 17.074103197532807, 17.356338899664298, 17.634057956125698, 17.907470508142687, 18.176770890342432, 18.44213924684444, 18.703742940919607, 18.96173778955927, 19.216269148822832, 19.46747287143352, 19.715476154534034, 19.960398292619317, 20.202351348296073, 20.441440751571303, 20.67776583676293, 20.911420324789038, 21.142492757477772, 21.371066889605675, 21.597222043587, 21.821033431072877, 22.042572445157123, 22.261906926406827, 22.47910140552776, 22.69421732512492, 22.90731324271793, 23.118445016912364, 23.32766597840427, 23.535027087301177, 23.74057707807458, 23.94436259331202, 24.146428307308724, 24.34681704042646, 24.545569865048968, 24.742726203876565, 24.938323921226143, 25.132399407935566, 25.324987660411605, 25.51612235430768, 25.705835913270747, 25.89415957315472, 26.081123442060544, 26.266756556529778, 26.451086934188545, 26.634141623112246, 26.81594674815715, 26.996527554483745, 27.17590844847694, 27.354113036251057, 27.531164159911587, 27.70708393173125, 27.88189376638539, 28.055614411379413, 28.228265975791007, 28.399867957439522, 28.57043926858669, 28.739998260264393, 28.908562745318218, 29.076150020248555, 29.242776885925185, 29.40845966724541, 29.57321423180105, 29.737056007614477, 29.900000000000006, 30.062060807602666, 30.223252637662945, 30.38358932055263, 30.5430843236239, 30.70175076441082, 30.85960142321997, 31.016648755144395, 31.17290490153268, 31.32838170094332], [0.0, 3.184336665618132, 4.50333209967908, 5.515432893255071, 6.368673331236264, 7.1203932475671605, 7.8, 8.424962907930219, 9.00666419935816, 9.553009996854394, 10.069756700139283, 10.56124992602675, 11.030865786510143, 11.481289126226201, 11.914696806885184, 12.33288287465668, 12.737346662472527, 13.129356419870701, 13.509996299037242, 13.880201727640706, 14.240786495134321, 14.592463808418374, 14.935862880998878, 15.271542161811952, 15.6, 15.921683328090658, 16.236994795835837, 16.546298679765215, 16.849925815860438, 17.148177745754797, 17.44133022449836, 17.729636206081615, 18.01332839871632, 18.292621463311377, 18.56771391421141, 18.83878977004627, 19.106019993708788, 19.369563753476744, 19.62956953170395, 19.886176103011863, 20.139513400278567, 20.38970328376556, 20.63686022630381, 20.88109192547171, 21.1224998520535, 21.361179742701477, 21.597222043586996, 21.830712310870666, 22.061731573020285, 22.29035665932692, 22.516660498395407, 22.740712389896675, 22.962578252452403, 23.182320850165112, 23.400000000000002, 23.615672761960436, 23.829393613770367, 24.041214611579008, 24.25118553803092, 24.459354038894812, 24.66576574931336, 24.87046441062169, 25.073491978581682, 25.274888723790657, 25.474693324945054, 25.67294295557095, 25.86967336477212, 26.064918952492448, 26.258712839741403, 26.45108693418855, 26.64207199149496, 26.83169767271538, 27.019992598074484, 27.206984397393256, 27.39269975741712, 27.577164466275352, 27.760403455281413, 27.94244083826608, 28.12329994861912, 28.303003374200415, 28.481572990268642, 28.659029990563187, 28.835394916664487, 29.01068768574782, 29.18492761683675, 29.358133455654162, 29.53032339816143, 29.70151511286924, 29.871725761997755, 30.04097202155749, 30.209270100417854, 30.3766357584246, 30.543084323623905, 30.70863070864607, 30.873289426298584, 31.037074604414634, 31.2, 31.362079012718535, 31.523324697753566, 31.68374977808025, 31.843366656181317, 32.00218742523705], [0.0, 3.25, 4.596194077712559, 5.6291651245988525, 6.5, 7.267220926874318, 7.960841664045329, 8.598691760959921, 9.192388155425117, 9.75, 10.277402395547233, 10.77903056865505, 11.258330249197705, 11.718041645257967, 12.160386507015309, 12.587195875174105, 13.0, 13.400093283257398, 13.788582233137676, 14.166421566507191, 14.534441853748636, 14.893371008606483, 15.24385121942615, 15.586452450766341, 15.921683328090658, 16.25, 16.571813419176554, 16.887495373796558, 17.197383521919843, 17.50178562318714, 17.800983118917898, 18.095234179197575, 18.384776310850235, 18.669828601248597, 18.95059365824723, 19.22725929507375, 19.5, 19.768978223469215, 20.034345509649174, 20.296243494794798, 20.554804791094465, 20.81015377165676, 21.06240726982555, 21.3116752039815, 21.5580611373101, 21.80166278062295, 22.042572445157123, 22.280877451303393, 22.51666049839541, 22.75, 22.980970388562795, 23.209642392764266, 23.436083290515935, 23.66035714016169, 23.882524992135988, 24.102645083060906, 24.320773014030618, 24.536961914629938, 24.751262594057703, 24.963723680572976, 25.17439175034821, 25.383311446696627, 25.590525590538387, 25.79607528287976, 26.0, 26.20233768197029, 26.403124815066874, 26.602396508585464, 26.800186566514796, 26.996527554483745, 27.191450862357456, 27.384986762823164, 27.577164466275352, 27.768012172281978, 27.957557117888538, 28.145825622994256, 28.332843133014382, 28.5186342590244, 28.703222815565507, 28.886631856275667, 29.06888370749727, 29.250000000000004, 29.430001698946608, 29.608909132218972, 29.786742017212966, 29.96351948620189, 30.139260110361043, 30.313981922538648, 30.4877024388523, 30.66043867918396, 30.8322071866417, 31.00302404605074, 31.172904901532682, 31.34186497322711, 31.50991907320614, 31.67708162062913, 31.843366656181317, 32.00878785583735, 32.17335854398791, 32.33709170596516, 32.5, 32.6620957686429], [0.0, 3.31436268383531, 4.687216658103186, 5.740644563113102, 6.62872536767062, 7.411140263144398, 8.118497397917919, 8.768979416100828, 9.374433316206373, 9.943088051505931, 10.480935072788116, 10.992497441437047, 11.481289126226203, 11.950104602052654, 12.401209618420294, 12.836471477785475, 13.25745073534124, 13.665467427058616, 14.061649974309558, 14.446972001080367, 14.822280526288797, 15.188317879212303, 15.54573896603182, 15.895125038828732, 16.236994795835837, 16.57181341917655, 16.900000000000002, 17.221933689339306, 17.537958832201657, 17.84838928306978, 18.153512056899622, 18.45359043655191, 18.748866632412746, 19.039564070639855, 19.32588937151406, 19.60803406769786, 19.886176103011863, 20.16048114505207, 20.431103739152228, 20.698188326517858, 20.96187014557623, 21.222276032508862, 21.479525134415802, 21.733729546490636, 21.984994882874094, 22.23342078943319, 22.47910140552776, 22.722125780833096, 22.962578252452406, 23.200538786847172, 23.436083290515935, 23.669283892843065, 23.90020920410531, 24.128924551251764, 24.355492193753758, 24.57997152154575, 24.80241923684059, 25.02288952139621, 25.24143419063188, 25.45810283583598, 25.67294295557095, 25.886000077261844, 26.09731786985015, 26.306938248302483, 26.51490147068248, 26.721246228422807, 26.926009730370374, 27.12922778112197, 27.33093485411723, 27.531164159911587, 27.729947710012006, 27.927316376623086, 28.123299948619117, 28.317927184029557, 28.511225859299703, 28.703222815565503, 28.893944002160733, 29.083414517556225, 29.27165864791403, 29.45869990342412, 29.644561052577593, 29.829264154517794, 30.012830589599513, 30.195281088276033, 30.376635758424605, 30.55691411121222, 30.73613508559592, 30.9143170715447, 31.09147793206364, 31.267635024094805, 31.442805218364345, 31.61700491823981, 31.790250077657465, 31.96255621817505, 32.133938445201515, 32.304411463451856, 32.473989591671675, 32.64268677667328, 32.8105166067223, 32.97749232431114, 33.1436268383531, 33.308932735829295], [0.0, 3.377499074759311, 4.776504998427197, 5.850000000000001, 6.754998149518622, 7.552317525104464, 8.273149339882606, 8.93602260516389, 9.553009996854394, 10.132497224277932, 10.68058987135074, 11.201897160749159, 11.700000000000003, 12.177746096876879, 12.637444361895328, 13.08099766837377, 13.509996299037244, 13.925785435658558, 14.329514995281592, 14.722177148777964, 15.104635050208929, 15.477645169727857, 15.841874889040126, 16.19791653269025, 16.54629867976521, 16.887495373796554, 17.221933689339306, 17.550000000000004, 17.87204521032778, 18.188389153523193, 18.49932431198502, 18.805118983936264, 19.106019993708788, 19.40225502357909, 19.694034629806055, 19.981553993621215, 20.264994448555864, 20.544524818062843, 20.82030259146106, 21.09247496146434, 21.36117974270148, 21.626546187498366, 21.888695712627563, 22.147742548621068, 22.403794321498317, 22.65695257531339, 22.907313242717926, 23.154967069723938, 23.400000000000006, 23.642493523315178, 23.882524992135988, 24.12016790986332, 24.355492193753758, 24.588564415191062, 24.819448019647822, 25.048203528397003, 25.274888723790657, 25.49955881971294, 25.722266618632194, 25.943062656517636, 26.16199533674754, 26.379111054013933, 26.59445430912242, 26.808067815491665, 27.019992598074488, 27.230268085349437, 27.438932194967066, 27.64602141357776, 27.851570871317115, 28.055614411379413, 28.258184655069407, 28.459313062686526, 28.659029990563184, 28.85736474455005, 29.054345630215114, 29.25, 29.44435429755593, 29.637434099462794, 29.829264154517798, 30.019868420764272, 30.209270100417857, 30.3974916728338, 30.58455492564834, 30.77048098421603, 30.955290339455715, 31.139002874209066, 31.321637888207576, 31.50321412173685, 31.68374977808025, 31.863262544817974, 32.04176961405222, 32.2192877016237, 32.3958330653805, 32.57142152255563, 32.746068466306, 32.91978888146156, 33.09259735953042, 33.26450811300237, 33.43553498899038, 33.60569148224747, 33.77499074759311, 33.94344561178197], [0.0, 3.4394767043839676, 4.864154602806123, 5.957348403442593, 6.878953408767935, 7.690903718029502, 8.424962907930219, 9.100000000000001, 9.728309205612247, 10.318430113151903, 10.876580344942983, 11.407453703609761, 11.914696806885186, 12.401209618420294, 12.869343417595164, 13.321035995747478, 13.75790681753587, 14.181325749026428, 14.59246380841837, 14.992331373072036, 15.381807436059004, 15.761662348876785, 16.132575739788116, 16.49515080258438, 16.849925815860438, 17.19738352191984, 17.537958832201657, 17.872045210327776, 18.200000000000003, 18.522148903407512, 18.83878977004627, 19.150195821453107, 19.456618411224493, 19.758289399641864, 20.055423206703967, 20.348218595248085, 20.636860226303806, 20.921520021260406, 21.202358359390118, 21.4795251344158, 21.753160689885966, 22.023396649926642, 22.290356659326925, 22.554157044766715, 22.814907407219522, 23.072711154088502, 23.32766597840427, 23.57986429138217, 23.82939361377037, 24.076336930687773, 24.32077301403062, 24.56277671599854, 24.80241923684059, 25.039768369535693, 25.274888723790657, 25.507841931453157, 25.73868683519033, 25.967479662069636, 26.19427418349285, 26.419121862772045, 26.642071991494955, 26.863171815703375, 27.082466652799557, 27.3, 27.51581363507174, 27.729947710012002, 27.94244083826608, 28.15333017602003, 28.362651498052855, 28.570439268586686, 28.77672670753225, 28.98154585249034, 29.18492761683674, 29.386901844189023, 29.587497359526708, 29.78674201721296, 29.98466274614407, 30.18128559223414, 30.3766357584246, 30.5707376423926, 30.76361487211801, 30.95529033945571, 31.145786231848444, 31.33512406230427, 31.52332469775357, 31.71040838589122, 31.896394780601778, 32.08130296605797, 32.26515147957623, 32.44795833330658, 32.629741034828946, 32.81051660672231, 32.99030160516876, 33.169112137649996, 33.34696387978972, 33.52387209139182, 33.699851631720875, 33.874916974068, 34.04908221964286, 34.22236111082928, 34.39476704383968, 34.56631308080166], [0.0, 3.5003571246374277, 4.95025251881154, 6.062796384507731, 7.000714249274855, 7.827036476214993, 8.574088872877397, 9.261074451703756, 9.90050503762308, 10.501071373912284, 11.069101137852162, 11.60937121466964, 12.125592769015462, 12.62071709531594, 13.097137091746426, 13.556824849499236, 14.00142849854971, 14.432342152263438, 14.85075755643462, 15.257702972597155, 15.654072952429987, 16.040651483028988, 16.41813022240962, 16.787123041188448, 17.148177745754793, 17.50178562318714, 17.84838928306978, 18.188389153523193, 18.522148903407512, 18.85, 19.172245564878413, 19.489163655734437, 19.80101007524616, 20.108020787735427, 20.410414008539856, 20.708392018696188, 21.002142747824568, 21.29184116040696, 21.577650474507184, 21.85972323704031, 22.138202275704323, 22.41322154443667, 22.684906876599698, 22.953376657912447, 23.21874242933928, 23.481109428644977, 23.74057707807458, 23.99723942456715, 24.251185538030924, 24.502499872461996, 24.751262594057703, 24.997549879938237, 25.24143419063188, 25.48298451908646, 25.722266618632197, 25.959343212030618, 26.19427418349285, 26.42711675533296, 26.657925650732846, 26.886753243930364, 27.113649698998472, 27.33866309825702, 27.561839561248448, 27.783223355111264, 28.00285699709942, 28.220781349920134, 28.437035710495568, 28.65165789269445, 28.864684304526875, 29.07615002024856, 29.28608884777891, 29.494533391799912, 29.70151511286924, 29.90706438285109, 30.111210536941222, 30.313981922538648, 30.51540594519431, 30.715509111847716, 30.914317071544705, 31.111854653813232, 31.308145904859973, 31.503214121736853, 31.697081884615187, 31.88977108729381, 32.081302966057976, 32.27169812699667, 32.460976571877815, 32.64915772267334, 32.83626044481924, 33.0223030692894, 33.20730341355648, 33.39127880150745, 33.574246082376895, 33.75622164875685, 33.937221453737195, 34.11726102722784, 34.29635549150959, 34.474519576057915, 34.651767631680784, 34.82811364400892, 35.00357124637428, 35.17815373211051], [0.0, 3.5601966237835794, 5.034878350069642, 6.1664414373283405, 7.120393247567159, 7.960841664045329, 8.72066511224918, 9.419394885023136, 10.069756700139283, 10.680589871350739, 11.258330249197702, 11.807836380980218, 12.332882874656681, 12.836471477785475, 13.321035995747476, 13.788582233137674, 14.240786495134317, 14.679066727827077, 15.104635050208923, 15.518537302207319, 15.921683328090658, 16.314870517414473, 16.698802352264668, 17.074103197532807, 17.44133022449836, 17.800983118917898, 18.153512056899626, 18.49932431198502, 18.838789770046272, 19.172245564878413, 19.499999999999996, 19.822335886569977, 20.139513400278567, 20.451772539317954, 20.759335249472706, 21.062407269825542, 21.361179742701477, 21.655830623644984, 21.946525920974373, 22.23342078943319, 22.516660498395403, 22.796381291775237, 23.072711154088502, 23.34577049488836, 23.615672761960436, 23.882524992135984, 24.14642830730872, 24.40747836217416, 24.665765749313362, 24.921376366485056, 25.17439175034821, 25.42488938029033, 25.67294295557095, 25.918622648589952, 26.16199533674754, 26.40312481506687, 26.64207199149495, 26.878895066575932, 27.113649698998472, 27.346389158351414, 27.57716446627535, 27.806024527069667, 28.033016248702168, 28.258184655069403, 28.481572990268635, 28.7032228155655, 28.923174099673084, 29.14146530289786, 29.358133455654155, 29.573214231801046, 29.78674201721296, 29.998749973957246, 30.209270100417847, 30.418333287673736, 30.625969372413337, 30.832207186641696, 31.037074604414638, 31.240598585814578, 31.442805218364345, 31.64371975605902, 31.843366656181317, 32.04176961405222, 32.23895159585683, 32.43493486967409, 32.629741034828946, 32.82339104967676, 33.015905257920764, 33.20730341355648, 33.397604704529336, 33.58682777518591, 33.77499074759311, 33.96211124179414, 34.148206395065614, 34.33329288023507, 34.51738692311456, 34.70050431910175, 34.88266044899672, 35.06387029407907, 35.24414845048749, 35.42350914294065, 35.601966237835796, 35.7795332557595], [0.0, 3.619046835839514, 5.118105118107676, 6.268372994645421, 7.238093671679028, 8.092434738692678, 8.864818103040806, 9.575097910726553, 10.236210236215353, 10.857140507518542, 11.444430960078357, 12.003020453202604, 12.536745989290843, 13.048658934925076, 13.541233326399777, 14.016508124351086, 14.476187343358056, 14.921712368223695, 15.354315354323031, 15.775059429365077, 16.184869477385355, 16.584556068824998, 16.974834314360777, 17.356338899664298, 17.72963620608161, 18.095234179197572, 18.45359043655191, 18.805118983936264, 19.150195821453107, 19.489163655734437, 19.822335886569977, 20.150000000000002, 20.472420472430706, 20.78984126923532, 21.102488004972304, 21.410569819600784, 21.714281015037084, 22.01380248843893, 22.30930299224967, 22.600940245927823, 22.888861920156714, 23.173206510968654, 23.45410411846933, 23.731677142587287, 24.006040906405207, 24.277304216078026, 24.545569865048968, 24.810935089190007, 25.073491978581686, 25.3333278508766, 25.590525590538387, 25.84516395769236, 26.09731786985015, 26.34705865936462, 26.594454309122423, 26.839569668681353, 27.082466652799553, 27.323204424078813, 27.561839561248448, 27.798426214446025, 28.03301624870217, 28.26565937670657, 28.496403281817866, 28.725293732179658, 28.952374686716112, 29.17768839370247, 29.40127548253647, 29.623175049275186, 29.84342473644739, 30.062060807602663, 30.2791182170155, 30.49463067492374, 30.708630708646062, 30.921149719892373, 31.13221803855292, 31.341864973227104, 31.550118858730155, 31.75700710079588, 31.962556218175045, 32.16679188231242, 32.36973895477071, 32.57142152255563, 32.77186293148438, 32.97108581772824, 33.169112137649996, 33.36596319604756, 33.56165967290653, 33.75622164875684, 33.949668628721554, 34.142019565339126, 34.33329288023507, 34.523506484712705, 34.712677799328596, 34.90082377251288, 35.08796089829102, 35.27410523315935, 35.45927241216322, 35.64347766422351, 35.82673582675374, 36.00906135960781, 36.190468358395144, 36.370970567198235], [0.0, 3.676955262170047, 5.199999999999999, 6.368673331236264, 7.353910524340094, 8.221921916437788, 9.00666419935816, 9.728309205612248, 10.399999999999999, 11.030865786510141, 11.627553482998906, 12.195080975540918, 12.737346662472527, 13.25745073534124, 13.75790681753587, 14.240786495134317, 14.707821048680188, 15.16047492659778, 15.599999999999998, 16.02747640771934, 16.443843832875576, 16.849925815860438, 17.24644890984808, 17.634057956125698, 18.01332839871632, 18.384776310850235, 18.748866632412746, 19.10601999370879, 19.456618411224497, 19.80101007524616, 20.139513400278567, 20.47242047243071, 20.799999999999997, 21.122499852053497, 21.440149253211835, 21.753160689885963, 22.061731573020282, 22.36604569431083, 22.666274506411504, 22.962578252452403, 23.25510696599781, 23.544001359157285, 23.82939361377037, 24.111408088288826, 24.390161951081836, 24.66576574931336, 24.93832392122614, 25.20793525856491, 25.474693324945054, 25.73868683519033, 26.0, 26.258712839741406, 26.51490147068248, 26.768638366566204, 27.019992598074488, 27.26903005242394, 27.51581363507174, 27.76040345528141, 28.00285699709942, 28.24322927712056, 28.481572990268635, 28.71793864468688, 28.952374686716112, 29.18492761683674, 29.415642097360376, 29.644561052577586, 29.871725761997748, 30.097175947254584, 30.32094985319556, 30.5430843236239, 30.763614872118005, 30.982575748313756, 31.199999999999996, 31.41591953134589, 31.630365157550738, 31.843366656181313, 32.05495281543868, 32.265151479576225, 32.473989591671675, 32.68149323393899, 32.88768766575115, 33.09259735953042, 33.296246034650814, 33.49865668948533, 33.699851631720875, 33.89985250705378, 34.098680326370406, 34.29635549150959, 34.49289781969616, 34.68832656672846, 34.88266044899672, 35.07591766440331, 35.268115912251396, 35.45927241216323, 35.649403922085426, 35.83852675543457, 36.02665679743264, 36.213809520678716, 36.4, 36.585242926622755, 36.76955262170047, 36.95294304923493], [0.0, 3.733965720249719, 5.280624963013374, 6.4674183411930315, 7.467931440499438, 8.349401176132336, 9.146310731655689, 9.879144699820934, 10.561249926026749, 11.201897160749157, 11.807836380980218, 12.384163274117475, 12.934836682386063, 13.463004865185189, 13.97122041913304, 14.461587049836544, 14.935862880998876, 15.395535067025115, 15.841874889040122, 16.27597923321359, 16.69880235226467, 17.11118055541464, 17.51385166089973, 17.907470508142687, 18.292621463311377, 18.669828601248593, 19.039564070639855, 19.402255023579094, 19.758289399641868, 20.10802078773543, 20.451772539317954, 20.78984126923532, 21.122499852053497, 21.450000000000003, 21.772574491777497, 22.090439108356357, 22.403794321498314, 22.712826772552994, 23.017710572513508, 23.31860844904773, 23.615672761960436, 23.90904640507438, 24.198863609682174, 24.485250662388573, 24.76832654823495, 25.048203528397003, 25.324987660411605, 25.598779267769782, 25.869673364772126, 26.13776004174803, 26.403124815066874, 26.665848945795826, 26.926009730370378, 27.183680766224434, 27.438932194967066, 27.691830925383034, 27.94244083826608, 28.190822974861877, 28.437035710495568, 28.68113491478327, 28.923174099673087, 29.163204556426926, 29.40127548253647, 29.637434099462798, 29.87172576199775, 30.10419405996447, 30.334880912902893, 30.563826658322746, 30.79107013405023, 31.016648755144395, 31.240598585814585, 31.462954406730464, 31.683749778080244, 31.90301709870087, 32.12078766157518, 32.33709170596515, 32.55195846642718, 32.765416218934256, 32.97749232431114, 33.188213269171335, 33.39760470452934, 33.60569148224747, 33.81249768946388, 34.01804668113677, 34.22236111082928, 34.425462959849945, 34.627373564854736, 34.828113644008916, 35.02770332179946, 35.22616215258199, 35.42350914294065, 35.619762772932674, 35.814941016285374, 36.00906135960781, 36.20214082067523, 36.39419596584049, 36.585242926622755, 36.77529741552066, 36.96437474109362, 37.15248982235243, 37.339657202497186, 37.52589106203876], [0.0, 3.790118731649445, 5.360037313302959, 6.564678209935352, 7.58023746329889, 8.474963126763445, 9.283856957105705, 10.027711603351984, 10.720074626605918, 11.370356194948336, 11.985407794480754, 12.570401743778918, 13.129356419870703, 13.665467427058616, 14.181325749026428, 14.67906672782708, 15.16047492659778, 15.6270598642227, 16.080111939908875, 16.520744535280485, 16.94992625352689, 17.368505980653605, 17.77723263053055, 18.176770890342436, 18.56771391421141, 18.950593658247225, 19.32588937151406, 19.694034629806055, 20.055423206703967, 20.41041400853986, 20.759335249472706, 21.102488004972308, 21.440149253211835, 21.772574491777494, 22.1, 22.422644803858443, 22.74071238989667, 23.054392206258658, 23.36386098229486, 23.669283892843062, 23.970815588961507, 24.268601113372814, 24.56277671599854, 24.853470582596707, 25.140803487557836, 25.42488938029033, 25.705835913270747, 25.98374491869869, 26.258712839741406, 26.530831121546118, 26.800186566514796, 27.06686165775412, 27.33093485411723, 27.592480859828466, 27.85157087131712, 28.10827280357155, 28.362651498052855, 28.61476891397168, 28.864684304526875, 29.112454379526298, 29.35813345565416, 29.60177359551282, 29.84342473644739, 30.08313481005595, 30.32094985319556, 30.556914111212212, 30.79107013405023, 31.02345886583248, 31.2541197284454, 31.48309069961207, 31.710408385891217, 31.93610809099944, 32.16022387981775, 32.38278863841099, 32.60383413035957, 32.82339104967675, 33.04148907056097, 33.25815689421168, 33.47342229291771, 33.68731215160984, 33.89985250705378, 34.111068584845015, 34.320984834354626, 34.529624961762906, 34.73701196130721, 34.9431681448606, 35.148115169949016, 35.351874066306586, 35.5544652610611, 35.755908602635174, 35.956223383442264, 36.155428361450795, 36.35354178068487, 36.55058139072483, 36.74656446526668, 36.94150781979533, 37.13542782842282, 37.328340439939204, 37.52026119312071, 37.71120523133675, 37.90118731649445, 38.090221842357394], [0.0, 3.84545185901475, 5.438290172471491, 6.66051799787374, 7.6909037180295, 8.598691760959921, 9.419394885023134, 10.174109297624044, 10.876580344942981, 11.536355577044251, 12.160386507015309, 12.75392096572658, 13.32103599574748, 13.864973855006003, 14.388363353766124, 14.89337100860648, 15.381807436059, 15.855204192945608, 16.314870517414473, 16.761936045695915, 17.197383521919843, 17.62207422524375, 18.036768003165093, 18.44213924684444, 18.83878977004627, 19.22725929507375, 19.608034067697865, 19.98155399362122, 20.34821859524809, 20.70839201869619, 21.062407269825545, 21.410569819600788, 21.753160689885963, 22.090439108356357, 22.422644803858443, 22.75, 23.072711154088502, 23.390970480080554, 23.70495728745361, 24.014839162484517, 24.320773014030618, 24.622906002338556, 24.92137636648506, 25.21631416365207, 25.50784193145316, 25.796075282879755, 26.081123442060544, 26.36308972787522, 26.64207199149496, 26.918163013103253, 27.191450862357456, 27.462019226560894, 27.729947710012006, 27.99531210756544, 28.258184655069407, 28.518634259024395, 28.776726707532248, 29.032524864365485, 29.286088847778906, 29.53747619550458, 29.78674201721296, 30.033939135584596, 30.2791182170155, 30.522327892872127, 30.763614872118, 31.003024046050733, 31.24059858581458, 31.476380033288454, 31.710408385891217, 31.9427221757946, 32.17335854398791, 32.40235330959774, 32.629741034828946, 32.85555508586029, 33.07982768999862, 33.30258998936869, 33.52387209139183, 33.74370311628527, 33.96211124179415, 34.17912374535076, 34.394767043839686, 34.609066731132756, 34.822047613545074, 35.03373374335085, 35.2441484504875, 35.453314372566076, 35.66125348329753, 35.867987119435625, 36.07353600633019, 36.27792028217714, 36.481159521045925, 36.683272754758406, 36.88427849368888, 37.08419474654938, 37.283039039219965, 37.480828432680084, 37.67757954009254, 37.87330854308876, 38.068031207300436, 38.26176289717974, 38.4545185901475, 38.64631289010635], [0.0, 3.9, 5.5154328932550705, 6.754998149518622, 7.8, 8.720665112249181, 9.553009996854394, 10.318430113151903, 11.030865786510141, 11.7, 12.33288287465668, 12.934836682386061, 13.509996299037244, 14.061649974309558, 14.592463808418369, 15.104635050208925, 15.6, 16.080111939908875, 16.54629867976521, 16.999705879808626, 17.441330224498362, 17.872045210327776, 18.292621463311377, 18.703742940919607, 19.106019993708788, 19.5, 19.886176103011863, 20.264994448555864, 20.636860226303806, 21.002142747824568, 21.361179742701477, 21.714281015037088, 22.061731573020282, 22.403794321498314, 22.74071238989667, 23.072711154088502, 23.4, 23.722773868163056, 24.041214611579008, 24.355492193753754, 24.66576574931336, 24.97218452598811, 25.274888723790657, 25.5740102447778, 25.869673364772122, 26.161995336747538, 26.451086934188545, 26.73705294156407, 27.019992598074488, 27.299999999999997, 27.577164466275352, 27.85157087131712, 28.123299948619117, 28.392428568194024, 28.659029990563184, 28.923174099673084, 29.184927616836738, 29.444354297555925, 29.70151511286924, 29.956468416687567, 30.20927010041785, 30.459973736035952, 30.708630708646062, 30.955290339455708, 31.2, 31.44280521836434, 31.683749778080244, 31.922875810302553, 32.16022387981775, 32.395833065380494, 32.629741034828946, 32.86198411538779, 33.09259735953042, 33.32161460673837, 33.54906854146624, 33.77499074759311, 33.99941175961725, 34.222361110829276, 34.443867378678604, 34.66395822753079, 34.882660448996724, 35.1, 35.316002038735924, 35.53069095866277, 35.74409042065555, 35.956223383442264, 36.167112132433246, 36.37677830704638, 36.585242926622755, 36.79252641502075, 36.998648623970034, 37.20362885526088, 37.407485881839214, 37.61023796787253, 37.81190288784737, 38.012497944754955, 38.212039987417576, 38.41054542700481, 38.60803025278549, 38.80451004715818, 39.0, 39.194514922371475], [0.0, 3.9537956446938427, 5.591511423577707, 6.848174939354282, 7.907591289387685, 8.84095583067804, 9.68478187673837, 10.460760010630205, 11.183022847155414, 11.861386934081528, 12.502999640086374, 13.113256651190811, 13.696349878708563, 14.255612929649853, 14.793748679763354, 15.31298468620667, 15.81518257877537, 16.30191706517979, 16.77453427073312, 17.23419565863171, 17.68191166135608, 18.118567824196262, 18.54494540299324, 18.961737789559272, 19.36956375347674, 19.768978223469215, 20.16048114505207, 20.544524818062843, 20.92152002126041, 21.291841160406964, 21.655830623644984, 22.013802488438934, 22.366045694310827, 22.712826772552994, 23.05439220625866, 23.390970480080554, 23.722773868163056, 24.05, 24.37283323702848, 24.691445887189353, 25.005999280172748, 25.316644722395583, 25.623524347755136, 25.926771877732868, 26.226513302381623, 26.522867492034116, 26.815946748157153, 27.105857300590955, 27.392699757417127, 27.6765695128569, 27.95755711788854, 28.235748617665518, 28.511225859299707, 28.78406677312989, 29.054345630215117, 29.322133278463898, 29.587497359526708, 29.85050250833309, 30.111210536941222, 30.369680604181532, 30.62596937241334, 30.88013115257123, 31.132218038552924, 31.38228003189061, 31.63036515755074, 31.876519571621994, 32.12078766157518, 32.36321213971197, 32.60383413035958, 32.84269325131543, 33.07982768999863, 33.3152742747227, 33.54906854146624, 33.78124479648434, 34.011836175072936, 34.2408746967714, 34.46839131726342, 34.69441597721455, 34.918977648264566, 35.142104376374505, 35.36382332271216, 35.58416080224459, 35.803142320193075, 36.020792606493266, 36.237135648392524, 36.45219472130588, 36.66599241804319, 36.87855067651114, 37.08989080598648, 37.30003351204929, 37.508998920259124, 37.71680659865043, 37.923475579118545, 38.12902437776241, 38.333471014245504, 38.53683303023225, 38.73912750695348, 38.94037108195042, 39.14057996504395, 39.339769953572436, 39.53795644693843, 39.735154460502606], [0.0, 4.006869101929835, 5.666568626602875, 6.940100863820354, 8.01373820385967, 8.959631688858646, 9.814784765851975, 10.60117917969506, 11.33313725320575, 12.020607305789504, 12.670832648251654, 13.289281395169569, 13.880201727640708, 14.446972001080367, 14.992331373072034, 15.518537302207319, 16.02747640771934, 16.520744535280485, 16.999705879808626, 17.465537495307725, 17.919263377717293, 18.3617809593732, 18.793881983241253, 19.216269148822832, 19.62956953170395, 20.034345509649174, 20.431103739152228, 20.82030259146106, 21.20235835939012, 21.577650474507184, 21.94652592097437, 22.30930299224967, 22.6662745064115, 23.017710572513508, 23.36386098229486, 23.70495728745361, 24.041214611579008, 24.372833237028477, 24.700000000000003, 25.022889521396205, 25.341665296503308, 25.656480662787718, 25.967479662069636, 26.27479781083006, 26.578562790339138, 26.878895066575932, 27.175908448476935, 27.46971059185007, 27.760403455281416, 28.048083713508845, 28.332843133014382, 28.614768913971684, 28.893944002160733, 29.170447374011943, 29.44435429755593, 29.7157365717224, 29.984662746144068, 30.25119832337225, 30.51540594519431, 30.777345564554455, 31.037074604414638, 31.294648104747882, 31.55011885873015, 31.803537539085177, 32.05495281543868, 32.30441146345186, 32.55195846642718, 32.79763711001145, 33.04148907056097, 33.28355449767948, 33.52387209139183, 33.76247917437343, 33.99941175961725, 34.234704613885604, 34.46839131726342, 34.70050431910176, 34.93107499061545, 35.160133674376155, 35.387709730922126, 35.613831582687084, 35.838526755434586, 36.06182191736852, 36.28374291607744, 36.50431481345733, 36.7235619187464, 36.94150781979534, 37.15817541268678, 37.373586929809136, 37.587763966482505, 37.80072750622665, 38.01249794475496, 38.223095112771816, 38.432538297645664, 38.640846264024816, 38.84803727345823, 39.05412910307948, 39.2591390634079, 39.46308401531741, 39.66598038622013, 39.86784418550871, 40.06869101929835, 40.268536104507206], [0.0, 4.059248698958959, 5.740644563113101, 7.030824987154781, 8.118497397917919, 9.076756028449815, 9.943088051505931, 10.739762567207901, 11.481289126226201, 12.177746096876877, 12.836471477785475, 13.463004865185189, 14.061649974309562, 14.635829323957015, 15.188317879212299, 15.721402609182173, 16.236994795835837, 16.736711146458852, 17.221933689339302, 17.693854865461063, 18.15351205689963, 18.601814427630444, 19.039564070639855, 19.46747287143352, 19.886176103011863, 20.296243494794794, 20.698188326517858, 21.09247496146434, 21.479525134415802, 21.85972323704031, 22.23342078943319, 22.600940245927827, 22.962578252452403, 23.31860844904773, 23.669283892843065, 24.014839162484517, 24.355492193753754, 24.691445887189357, 25.02288952139621, 25.35, 25.67294295557095, 25.99187373007187, 26.306938248302487, 26.618273798276253, 26.926009730370378, 27.230268085349437, 27.531164159911583, 27.82880701718994, 28.123299948619124, 28.414740892712715, 28.703222815565507, 28.98883405727109, 29.27165864791403, 29.5517765963402, 29.829264154517794, 30.10419405996447, 30.376635758424598, 30.64665560872834, 30.9143170715447, 31.179680883549786, 31.442805218364345, 31.70374583546872, 31.962556218175042, 32.2192877016237, 32.473989591671675, 32.72670927545268, 32.97749232431114, 33.22638258974335, 33.473422292917704, 33.71865210829164, 33.96211124179415, 34.20383750399946, 34.443867378678604, 34.68223608708067, 34.91897764826456, 35.1541249357739, 35.387709730922126, 35.619762772932674, 35.85031380615796, 36.07939162458259, 36.30702411379926, 36.533238290630635, 36.758060340556604, 36.98151565309351, 37.20362885526089, 37.42442384326044, 37.64392381248268, 37.86215128594782, 38.07912814127971, 38.294875636304134, 38.509414433356426, 38.72276462237686, 38.93494574286704, 39.14597680477524, 39.355876308373574, 39.56466226318632, 39.772352206023726, 39.97896321817264, 40.184511941791705, 40.389014595555565, 40.59248698958959, 40.79494453973434], [0.0, 4.110960958218893, 5.813776741499453, 7.1203932475671605, 8.221921916437786, 9.19238815542512, 10.069756700139283, 10.876580344942983, 11.627553482998906, 12.33288287465668, 13.0, 13.634515026211972, 14.240786495134321, 14.822280526288795, 15.381807436059, 15.921683328090657, 16.443843832875572, 16.949926253526886, 17.44133022449836, 17.91926337771729, 18.38477631085024, 18.838789770046272, 19.282116066448726, 19.715476154534034, 20.139513400278567, 20.554804791094465, 20.96187014557623, 21.36117974270148, 21.753160689885966, 22.138202275704323, 22.516660498395403, 22.888861920156714, 23.25510696599781, 23.615672761960436, 23.970815588961507, 24.320773014030618, 24.66576574931336, 25.005999280172748, 25.341665296503308, 25.67294295557095, 26.0, 26.322993750711564, 26.64207199149496, 26.957373759326035, 27.269030052423943, 27.577164466275352, 27.88189376638538, 28.183328405282438, 28.481572990268642, 28.77672670753225, 29.068883707497267, 29.358133455654162, 29.64456105257759, 29.928247526375483, 30.209270100417854, 30.487702438852292, 30.763614872118, 31.037074604414638, 31.30814590485997, 31.576890283876907, 31.843366656181313, 32.10763149159402, 32.3697389547707, 32.629741034828946, 32.887687665751145, 33.1436268383531, 33.397604704529336, 33.64966567441644, 33.89985250705377, 34.148206395065614, 34.39476704383968, 34.63957274563299, 34.88266044899672, 35.12406582387637, 35.36382332271215, 35.601966237835796, 35.83852675543458, 36.07353600633018, 36.30702411379925, 36.53902023864351, 36.76955262170048, 36.99864862397004, 37.22633476451852, 37.45263675630863, 37.677579540092545, 37.90118731649446, 38.12348357639947, 38.344491129756825, 38.56423213289745, 38.78272811445837, 39.0, 39.21606813539573, 39.43095230906807, 39.64467177313996, 39.85724526356532, 40.06869101929834, 40.27902680055713, 40.48826990623334, 40.69643719049617, 40.903545078635915, 41.10960958218893, 41.31464631338383], [0.0, 4.162030754331352, 5.886000339789321, 7.208848729166123, 8.324061508662703, 9.306583691129632, 10.19485164188278, 11.011698324963323, 11.772000679578642, 12.486092262994056, 13.161496875355782, 13.803894378036949, 14.417697458332245, 15.006415294799757, 15.572893115924222, 16.11947579792842, 16.648123017325407, 17.160492417177313, 17.658001019367962, 18.141871458038725, 18.613167382259263, 19.072820976457578, 19.521654642985574, 19.960398292619317, 20.38970328376556, 20.81015377165676, 21.222276032508866, 21.626546187498366, 22.023396649926646, 22.41322154443667, 22.796381291775237, 23.173206510968658, 23.544001359157285, 23.90904640507438, 24.268601113372814, 24.622906002338556, 24.972184525988112, 25.316644722395583, 25.65648066278772, 25.99187373007187, 26.322993750711564, 26.650000000000002, 26.97304209762036, 27.29226080778212, 27.607788756073898, 27.91975107338889, 28.228265975791004, 28.53344528794236, 28.83539491666449, 29.134215280319463, 29.430001698946608, 29.722844749451564, 30.012830589599513, 30.300041254097334, 30.58455492564834, 30.866446183517795, 31.145786231848444, 31.422643109706737, 31.697081884615187, 31.969164831130637, 32.23895159585684, 32.50649935012997, 32.771862931484385, 33.035094974889965, 33.296246034650814, 33.5553646977648, 33.81249768946388, 34.067689971584514, 34.320984834354626, 34.572423982127724, 34.822047613545074, 35.06989449656215, 35.316002038735924, 35.56040635313382, 35.80314232019307, 36.044243645830605, 36.28374291607745, 36.521671648488386, 36.75806034055661, 36.99293851534371, 37.226334764518526, 37.45827678898217, 37.68879143724299, 37.91790474169163, 38.145641952915156, 38.372027572178155, 38.597085382189164, 38.82083847626169, 39.04330928597115, 39.26451960740129, 39.48449062606735, 39.70324294059618, 39.920796585238634, 40.13717105128363, 40.352385307438766, 40.566457819237804, 40.77940656753112, 40.99124906611167, 41.20200237852524, 41.411683134110845, 41.62030754331352, 41.827891412310045], [0.0, 4.212481453965109, 5.957348403442592, 7.296231904209187, 8.424962907930219, 9.419394885023138, 10.318430113151903, 11.145178329663462, 11.914696806885184, 12.637444361895328, 13.32103599574748, 13.971220419133044, 14.592463808418374, 15.188317879212303, 15.761662348876785, 16.314870517414473, 16.849925815860438, 17.368505980653605, 17.872045210327776, 18.3617809593732, 18.838789770046276, 19.304015126392752, 19.758289399641868, 20.202351348296073, 20.636860226303806, 21.06240726982555, 21.479525134415802, 21.888695712627563, 22.290356659326925, 22.684906876599698, 23.072711154088502, 23.454104118469335, 23.829393613770367, 24.198863609682174, 24.56277671599854, 24.92137636648506, 25.274888723790657, 25.623524347755133, 25.967479662069636, 26.306938248302483, 26.64207199149496, 26.97304209762036, 27.300000000000004, 27.623088169138512, 27.942440838266087, 28.258184655069407, 28.570439268586686, 28.87931785897998, 29.18492761683675, 29.487370177755768, 29.786742017212966, 30.083134810055956, 30.376635758424605, 30.667327891422172, 30.955290339455715, 31.240598585814585, 31.52332469775357, 31.80353753908518, 32.081302966057976, 32.35668400809947, 32.629741034828946, 32.90053191059379, 33.169112137649996, 33.43553498899038, 33.699851631720875, 33.96211124179414, 34.222361110829276, 34.4806467456746, 34.73701196130721, 34.99149896760641, 35.2441484504875, 35.49499964783772, 35.74409042065555, 35.99145731975854, 36.237135648392524, 36.48115952104593, 36.7235619187464, 36.96437474109362, 37.20362885526089, 37.44135414217814, 37.67757954009255, 37.91233308568599, 38.14564195291515, 38.377532489726335, 38.608030252785504, 38.83716004035311, 39.06494592342348, 39.29141127523928, 39.516578799283735, 39.740470555845214, 39.96310798724244, 40.18451194179171, 40.404702696592146, 40.623699979199344, 40.841522988253026, 41.05819041311977, 41.27372045260761, 41.48813083280567, 41.70143882409815, 41.91366125739913, 42.1248145396511, 42.33491466862784], [0.0, 4.2623350407963, 6.0278520220722065, 7.382580849540356, 8.5246700815926, 9.530870894099868, 10.440545962735856, 11.277078522383357, 12.055704044144413, 12.7870051223889, 13.478686879663018, 14.136566061105505, 14.765161699080712, 15.368067542797956, 15.948197390300884, 16.50795262896038, 17.0493401631852, 17.574057584974504, 18.08355606621662, 18.579087706343387, 19.061741788199736, 19.532472961711736, 19.99212344899861, 20.441440751571307, 20.88109192547171, 21.3116752039815, 21.733729546490636, 22.147742548621068, 22.554157044766715, 22.953376657912447, 23.34577049488836, 23.73167714258729, 24.111408088288826, 24.48525066238857, 24.853470582596707, 25.216314163652065, 25.5740102447778, 25.926771877732868, 26.27479781083006, 26.61827379827625, 26.957373759326035, 27.29226080778212, 27.623088169138512, 27.949999999999996, 28.27313212221101, 28.5926126822996, 28.90856274531821, 29.221096830885724, 29.530323398161425, 29.8363452855741, 30.139260110361036, 30.439160632317048, 30.73613508559591, 31.03026748192803, 31.32163788820757, 31.610322681048352, 31.896394780601767, 32.17992386566506, 32.46097657187781, 32.739616674603866, 33.01590525792076, 33.28990087098488, 33.56165967290652, 33.83123556715007, 34.0986803263704, 34.36404370850438, 34.62737356485472, 34.88871594083107, 35.14811516994901, 35.405613961630436, 35.66125348329752, 35.91507343720738, 36.16711213243324, 36.41740655236174, 36.665992418043174, 36.912904247701775, 37.158175412686774, 37.40183819012108, 37.643923812482676, 37.88446251433429, 38.12348357639947, 38.3610153671667, 38.59708538218916, 38.831720281234, 39.06494592342347, 39.296787400498786, 39.52726906832801, 39.75641457676987, 39.98424689799722, 40.21078835337601, 40.436060638989055, 40.66008484988687, 40.88288150314261, 41.104470559782186, 41.32487144565606, 41.54410307131446, 41.76218385094342, 41.979131720415566, 42.19496415450545, 42.409698183316515, 42.623350407963, 42.835937015548055], [0.0, 4.31161222746202, 6.097540487770458, 7.467931440499439, 8.62322445492404, 9.641058033224365, 10.561249926026749, 11.407453703609761, 12.195080975540916, 12.93483668238606, 13.634515026211972, 14.300000000000002, 14.935862880998878, 15.54573896603182, 16.132575739788113, 16.698802352264668, 17.24644890984808, 17.77723263053055, 18.292621463311374, 18.793881983241253, 19.28211606644873, 19.758289399641868, 20.223253941935262, 20.67776583676293, 21.122499852053497, 21.5580611373101, 21.984994882874094, 22.403794321498317, 22.814907407219522, 23.21874242933928, 23.615672761960436, 24.006040906405207, 24.390161951081833, 24.76832654823495, 25.140803487557832, 25.507841931453157, 25.86967336477212, 26.226513302381623, 26.578562790339138, 26.926009730370374, 27.269030052423943, 27.607788756073894, 27.942440838266084, 28.27313212221101, 28.600000000000005, 28.923174099673087, 29.24277688592518, 29.55892420234539, 29.871725761997755, 30.18128559223414, 30.487702438852295, 30.791070134050234, 31.09147793206364, 31.38901081588906, 31.68374977808025, 31.975772078246994, 32.265151479576225, 32.55195846642718, 32.83626044481923, 33.11812192742819, 33.397604704529336, 33.67476800217041, 33.94966862872155, 34.222361110829276, 34.49289781969616, 34.76132908851444, 35.02770332179945, 35.292067097295394, 35.5544652610611, 35.814941016285374, 36.07353600633019, 36.33029039245351, 36.58524292662275, 36.83843101979237, 37.08989080598648, 37.339657202497186, 37.587763966482505, 37.83424374822365, 38.07912814127971, 38.322447729757556, 38.56423213289746, 38.80451004715818, 39.04330928597114, 39.280656817319134, 39.516578799283735, 39.751100613693716, 39.984246897997224, 40.216041575470854, 40.446507883870524, 40.67566840262124, 40.903545078635915, 41.13015925084658, 41.35553167352586, 41.57968253847065, 41.802631496115175, 42.024397675635996, 42.244999704106995, 42.46445572475881, 42.68278341439321, 42.900000000000006, 43.1161222746202, 43.3311666124973], [0.0, 4.36033255612459, 6.166441437328339, 7.552317525104463, 8.72066511224918, 9.75, 10.680589871350739, 11.536355577044251, 12.332882874656677, 13.080997668373769, 13.788582233137676, 14.461587049836544, 15.104635050208927, 15.72140260918217, 16.31487051741447, 16.88749537379655, 17.44133022449836, 17.97811169172113, 18.499324311985017, 19.006248972377477, 19.5, 19.98155399362122, 20.451772539317957, 20.911420324789038, 21.361179742701477, 21.801662780622948, 22.23342078943319, 22.65695257531339, 23.072711154088502, 23.481109428644977, 23.882524992135984, 24.27730421607803, 24.665765749313355, 25.048203528397, 25.424889380290328, 25.796075282879755, 26.161995336747538, 26.522867492034113, 26.878895066575932, 27.230268085349433, 27.577164466275352, 27.919751073388888, 28.258184655069407, 28.592612682299595, 28.923174099673087, 29.249999999999996, 29.573214231801046, 29.892933947673985, 30.209270100417854, 30.522327892872127, 30.832207186641696, 31.13900287420906, 31.44280521836434, 31.74370016239443, 32.041769614052214, 32.33709170596514, 32.62974103482894, 32.91978888146156, 33.20730341355648, 33.492349872769445, 33.7749907475931, 34.05528593331731, 34.333292880235064, 34.60906673113275, 34.88266044899672, 35.15412493577389, 35.42350914294065, 35.69086017456009, 35.95622338344226, 36.21964246096308, 36.481159521045925, 36.7408151787627, 36.998648623970034, 37.25469769035846, 37.50899892025912, 37.76158762552231, 38.012497944754955, 38.261762897179736, 38.509414433356426, 38.75548348298599, 39.0, 39.242993005121306, 39.48449062606734, 39.724520135553554, 39.96310798724244, 40.200279849772194, 40.436060638989055, 40.6704745484977, 40.903545078635915, 41.13529506397152, 41.36574669941302, 41.594921565018005, 41.822840649578076, 42.04952437305326, 42.27499260792366, 42.49926469952156, 42.722359485402954, 42.94429531381322, 43.16509006129837, 43.38476114950963, 43.603325561245896, 43.82079985577625], [0.0, 4.4085144890314245, 6.234580980306535, 7.635771080905976, 8.817028978062849, 9.857738077267017, 10.798611021793498, 11.663832989202136, 12.46916196061307, 13.225543467094273, 13.94094688319269, 14.621388442962592, 15.271542161811952, 15.89512503882873, 16.495150802584376, 17.074103197532807, 17.634057956125698, 18.176770890342432, 18.703742940919607, 19.21626914882283, 19.715476154534034, 20.202351348296073, 20.67776583676293, 21.142492757477775, 21.597222043586996, 22.042572445157123, 22.47910140552776, 22.90731324271793, 23.327665978404273, 23.74057707807458, 24.14642830730872, 24.54556986504897, 24.93832392122614, 25.324987660411605, 25.705835913270747, 26.08112344206054, 26.451086934188545, 26.81594674815715, 27.175908448476935, 27.531164159911583, 27.88189376638538, 28.228265975791004, 28.57043926858669, 28.90856274531821, 29.242776885925185, 29.573214231801046, 29.900000000000002, 30.22325263766294, 30.543084323623905, 30.85960142321997, 31.17290490153268, 31.483090699612074, 31.79025007765746, 32.094469928634126, 32.395833065380494, 32.69441848389416, 32.99030160516875, 33.28355449767948, 33.574246082376895, 33.862442321840874, 34.148206395065614, 34.431598859187474, 34.71267779932859, 34.991498967606404, 35.268115912251396, 35.54258009768002, 35.81494101628537, 36.08524629263323, 36.353541780684864, 36.61987165460852, 36.88427849368888, 37.14680336179683, 37.407485881839214, 37.66636430557109, 37.92347557911854, 38.17885540452988, 38.43253829764566, 38.684557642552925, 38.93494574286704, 39.18373387006399, 39.43095230906807, 39.67663040128282, 39.92079658523863, 40.16347843501606, 40.404702696592146, 40.64449532224506, 40.88288150314261, 41.11988570023025, 41.35553167352586, 41.589842509920615, 41.822840649578076, 42.05454791101672, 42.28498551495555, 42.51417410699637, 42.74213377921135, 42.96888409069986, 43.19444408717399, 43.418832319628315, 43.64206686214575, 43.86416532888778, 44.08514489031425, 44.30502228867513], [0.0, 4.456175490260678, 6.301983814641227, 7.718322356574648, 8.912350980521357, 9.964311315891331, 10.915356155435331, 11.789932145691086, 12.603967629282455, 13.368526470782037, 14.091664202641219, 14.779462101172696, 15.436644713149295, 16.066969222600758, 16.673481939894856, 17.25869346155728, 17.824701961042713, 18.37328223263334, 18.905951443923684, 19.424018636729116, 19.928622631782662, 20.420761494126513, 20.901315748057588, 21.37106688960568, 21.830712310870663, 22.280877451303393, 22.7221257808331, 23.15496706972394, 23.579864291382172, 23.997239424567155, 24.407478362174164, 24.81093508919001, 25.20793525856491, 25.598779267769782, 25.98374491869869, 26.36308972787522, 26.737052941564073, 27.105857300590955, 27.469710591850074, 27.82880701718994, 28.183328405282438, 28.53344528794236, 28.879317858979984, 29.221096830885728, 29.55892420234539, 29.89293394767399, 30.22325263766294, 30.55, 30.87328942629859, 31.19322843182475, 31.50991907320614, 31.823458328723486, 32.133938445201515, 32.441447255016236, 32.746068466306, 33.04788192910402, 33.34696387978971, 33.64338716597959, 33.937221453737195, 34.228533418772116, 34.51738692311456, 34.80384317859164, 35.08796089829102, 35.369796437073255, 35.649403922085426, 35.926835374132246, 36.20214082067523, 36.47536840115532, 36.74656446526668, 37.01577366475001, 37.283039039219965, 37.548402096494065, 37.81190288784737, 38.073580078579425, 38.3334710142455, 38.59161178287323, 38.84803727345823, 39.102781231007086, 39.355876308373574, 39.60735411511352, 39.857245263565325, 40.10557941234611, 40.352385307438766, 40.597690821030696, 40.841522988253026, 41.08390804195726, 41.32487144565607, 41.564437924745235, 41.802631496115175, 42.03947549625233, 42.27499260792366, 42.50920488553039, 42.74213377921136, 42.973800157770555, 43.20422433049805, 43.43342606794909, 43.661424621741325, 43.88823874342647, 44.11388670248859, 44.33838630351809, 44.561754902606786, 44.78400942300723], [0.0, 4.503332099679081, 6.368673331236264, 7.8000000000000025, 9.006664199358163, 10.069756700139287, 11.030865786510143, 11.914696806885187, 12.737346662472527, 13.509996299037244, 14.240786495134321, 14.935862880998878, 15.600000000000005, 16.236994795835837, 16.849925815860438, 17.441330224498362, 18.013328398716325, 18.567713914211414, 19.10601999370879, 19.629569531703954, 20.139513400278574, 20.636860226303813, 21.1224998520535, 21.597222043587, 22.061731573020285, 22.516660498395407, 22.962578252452406, 23.400000000000006, 23.829393613770375, 24.251185538030924, 24.66576574931336, 25.07349197858169, 25.474693324945054, 25.869673364772122, 26.258712839741406, 26.64207199149496, 27.019992598074488, 27.392699757417123, 27.760403455281416, 28.12329994861912, 28.481572990268642, 28.83539491666449, 29.18492761683675, 29.530323398161425, 29.871725761997755, 30.209270100417854, 30.543084323623905, 30.873289426298587, 31.20000000000001, 31.52332469775357, 31.84336665618132, 32.16022387981776, 32.473989591671675, 32.784752553588085, 33.09259735953043, 33.39760470452934, 33.699851631720875, 33.99941175961726, 34.296355491509594, 34.59075020869018, 34.882660448996724, 35.17214807201858, 35.45927241216323, 35.74409042065555, 36.02665679743265, 36.30702411379925, 36.585242926622755, 36.86136188477035, 37.13542782842283, 37.40748588183922, 37.677579540092545, 37.945750750248706, 38.21203998741758, 38.476486326066734, 38.73912750695349, 39.00000000000001, 39.25913906340791, 39.51657879928373, 39.77235220602373, 40.0264912276857, 40.27902680055715, 40.529988897111735, 40.779406567531126, 41.02730797895471, 41.27372045260763, 41.51867049894542, 41.76218385094344, 42.004285495649135, 42.244999704107, 42.484350059757304, 42.72235948540296, 42.959050268831604, 43.194444087174, 43.42856203007418, 43.66142462174133, 43.89305184194875, 44.12346314604057, 44.35267748400316, 44.58071331865384, 44.807588642996635, 45.03332099679081, 45.257927482375955], [0.0, 4.55, 6.434671708797582, 7.880831174438393, 9.1, 10.174109297624044, 11.14517832966346, 12.038168465343889, 12.869343417595164, 13.65, 14.388363353766126, 15.090642796117072, 15.761662348876786, 16.40525830336115, 17.02454110982143, 17.622074225243747, 18.2, 18.760130596560355, 19.304015126392745, 19.832990193110067, 20.34821859524809, 20.850719412049074, 21.341391707196607, 21.821033431072877, 22.29035665932692, 22.75, 23.200538786847172, 23.642493523315178, 24.076336930687777, 24.502499872461996, 24.921376366485056, 25.333327850876604, 25.73868683519033, 26.13776004174803, 26.530831121546118, 26.91816301310325, 27.3, 27.6765695128569, 28.048083713508845, 28.41474089271271, 28.77672670753225, 29.134215280319463, 29.487370177755768, 29.8363452855741, 30.181285592234143, 30.522327892872127, 30.85960142321997, 31.19322843182475, 31.523324697753573, 31.849999999999998, 32.173358543987916, 32.49349934986997, 32.8105166067223, 33.12449999622636, 33.43553498899038, 33.74370311628527, 34.04908221964286, 34.35174668048191, 34.651767631680784, 34.949213152802166, 35.244148450487494, 35.53663602537528, 35.82673582675374, 36.11450539603166, 36.4, 36.6832727547584, 36.96437474109362, 37.24335511201965, 37.52026119312071, 37.79513857627724, 38.068031207300436, 38.33898146795243, 38.60803025278549, 38.875217041194766, 39.14057996504395, 39.40415587219196, 39.665980386220134, 39.926087962634156, 40.184511941791705, 40.44128459878593, 40.69643719049618, 40.95, 41.20200237852524, 41.45247278510656, 41.70143882409815, 41.94892728068264, 42.194964154505456, 42.43957469155411, 42.682783414393214, 42.92461415085754, 43.16509006129838, 43.40423366447103, 43.642066862145754, 43.87861096251795, 44.11388670248859, 44.34791426888078, 44.58071331865384, 44.812302998172285, 45.04270196158308, 45.27192838835121, 45.5, 45.72693407610006], [0.0, 4.596194077712559, 6.5, 7.96084166404533, 9.192388155425117, 10.277402395547234, 11.258330249197702, 12.16038650701531, 13.0, 13.788582233137678, 14.534441853748634, 15.243851219426148, 15.92168332809066, 16.571813419176554, 17.19738352191984, 17.800983118917898, 18.384776310850235, 18.950593658247225, 19.5, 20.034345509649174, 20.55480479109447, 21.06240726982555, 21.5580611373101, 22.042572445157127, 22.516660498395403, 22.980970388562795, 23.436083290515935, 23.88252499213599, 24.32077301403062, 24.751262594057703, 25.17439175034821, 25.590525590538387, 26.0, 26.403124815066874, 26.800186566514796, 27.191450862357456, 27.577164466275356, 27.957557117888538, 28.332843133014382, 28.703222815565503, 29.068883707497267, 29.430001698946608, 29.786742017212966, 30.139260110361036, 30.487702438852295, 30.8322071866417, 31.17290490153268, 31.509919073206138, 31.84336665618132, 32.173358543987916, 32.5, 32.82339104967676, 33.14362683835311, 33.460797958207756, 33.77499074759311, 34.08628756552993, 34.39476704383968, 34.70050431910176, 35.00357124637428, 35.3040365964007, 35.601966237835796, 35.8974233058586, 36.190468358395144, 36.48115952104593, 36.76955262170047, 37.05570131572198, 37.339657202497186, 37.62146993406824, 37.90118731649445, 38.17885540452988, 38.45451859014751, 38.7282196853922, 39.0, 39.26989941418236, 39.53795644693843, 39.80420832022664, 40.06869101929835, 40.33143934947029, 40.592486989589595, 40.85186654242374, 41.10960958218894, 41.36574669941304, 41.62030754331352, 41.87332086185666, 42.1248145396511, 42.37481563381722, 42.62335040796301, 42.87044436438699, 43.1161222746202, 43.36040820841058, 43.6033255612459, 43.84489708050414, 44.085144890314254, 44.32409051520404, 44.561754902606786, 44.798158444293215, 45.033320996790806, 45.267261900848396, 45.5, 45.73155365827844, 45.96194077712559, 46.191178811543665], [0.0, 4.6419284785528525, 6.564678209935351, 8.040055969954441, 9.283856957105705, 10.379667624736355, 11.370356194948336, 12.281388357999273, 13.129356419870701, 13.92578543565856, 14.679066727827081, 15.395535067025119, 16.080111939908882, 16.736711146458855, 17.368505980653605, 17.978111691721132, 18.56771391421141, 19.139161423636097, 19.69403462980605, 20.2336971411554, 20.75933524947271, 21.27198862353965, 21.772574491777497, 22.261906926406827, 22.74071238989667, 23.209642392764266, 23.669283892843065, 24.12016790986332, 24.562776715998545, 24.997549879938237, 25.42488938029033, 25.84516395769236, 26.258712839741403, 26.665848945795823, 27.06686165775412, 27.46201922656089, 27.85157087131712, 28.235748617665518, 28.614768913971684, 28.988834057271088, 29.358133455654162, 29.72284474945156, 30.083134810055956, 30.439160632317048, 30.791070134050237, 31.139002874209062, 31.483090699612074, 31.823458328723486, 32.160223879817764, 32.49349934986997, 32.82339104967676, 33.150000000000006, 33.47342229291771, 33.7937494220455, 34.111068584845015, 34.42546295984994, 34.73701196130721, 35.04579147344229, 35.35187406630659, 35.65532919494644, 35.956223383442264, 36.25462039519929, 36.55058139072483, 36.844165073997814, 37.13542782842282, 37.424423843260435, 37.71120523133675, 37.99582213875626, 38.27832284727219, 38.55875386990613, 38.83716004035311, 39.113584596658995, 39.3880692596121, 39.660654306251686, 39.93137863885994, 40.200279849772194, 40.4673942823108, 40.73275708812258, 40.996402281175854, 41.25836278865171, 41.51867049894542, 41.77735630697568, 42.034450156984335, 42.28998108299412, 42.5439772470793, 42.796465975591964, 43.04747379347597, 43.29702645679031, 43.545148983554995, 43.79186568302383, 44.03720018348125, 44.28117545865287, 44.52381385281365, 44.7651371046711, 45.005166370095786, 45.24392224376662, 45.48142477979334, 45.7176935113748, 45.952747469547454, 46.18660520107535, 46.41928478552853, 46.65080385159511], [0.0, 4.687216658103186, 6.62872536767062, 8.118497397917919, 9.374433316206373, 10.480935072788117, 11.481289126226201, 12.401209618420296, 13.25745073534124, 14.061649974309558, 14.822280526288795, 15.54573896603182, 16.236994795835837, 16.900000000000002, 17.537958832201653, 18.153512056899622, 18.748866632412746, 19.32588937151406, 19.88617610301186, 20.431103739152228, 20.961870145576235, 21.479525134415802, 21.984994882874094, 22.47910140552776, 22.962578252452403, 23.43608329051593, 23.90020920410531, 24.355492193753758, 24.802419236840592, 25.24143419063188, 25.67294295557095, 26.097317869850155, 26.51490147068248, 26.926009730370374, 27.33093485411723, 27.729947710012006, 28.123299948619117, 28.511225859299703, 28.893944002160733, 29.27165864791403, 29.64456105257759, 30.012830589599513, 30.376635758424605, 30.73613508559591, 31.09147793206364, 31.442805218364345, 31.79025007765746, 32.133938445201515, 32.473989591671675, 32.8105166067223, 33.14362683835311, 33.47342229291771, 33.800000000000004, 34.123452345857395, 34.443867378678604, 34.76132908851444, 35.075917664403306, 35.38770973092212, 35.69677856613956, 36.0031943027282, 36.307024113799244, 36.608332384854684, 36.90718087310381, 37.20362885526088, 37.49773326482549, 37.78954881974645, 38.07912814127971, 38.36652186477164, 38.65177874302812, 38.93494574286704, 39.21606813539573, 39.49518958050461, 39.77235220602372, 40.04759668194835, 40.32096229010414, 40.59248698958959, 40.862207478304455, 41.130159250846575, 41.396376653035716, 41.66089293330137, 41.92374029115247, 42.18494992292868, 42.444552065017724, 42.702576034707796, 42.959050268831604, 43.21400236034613, 43.46745909298128, 43.71944647408062, 43.96998976574819, 44.219113514406864, 44.466841578866386, 44.71319715699159, 44.95820281105552, 45.201880491855654, 45.44425156166619, 45.685336816094505, 45.925156504904805, 46.16373035186824, 46.401077573694344, 46.63721689809546, 46.87216658103186, 47.10594442318295], [0.0, 4.732071428032337, 6.69215959164155, 8.196188138397021, 9.464142856064674, 10.581233387464811, 11.591160425082556, 12.519884184767847, 13.3843191832831, 14.196214284097012, 14.964123763187741, 15.694505407944531, 16.392376276794042, 17.061726172928697, 17.705790013439106, 18.32723383383319, 18.928285712129348, 19.510830325744728, 20.076478774924652, 20.626621148409164, 21.162466774929623, 21.685075512895967, 22.19538240265304, 22.694217325124924, 23.182320850165112, 23.660357140161686, 24.128924551251767, 24.588564415191065, 25.039768369535693, 25.48298451908646, 25.918622648589952, 26.34705865936462, 26.7686383665662, 27.183680766224434, 27.592480859828466, 27.99531210756544, 28.392428568194024, 28.78406677312989, 29.170447374011943, 29.551776596340197, 29.928247526375483, 30.300041254097334, 30.667327891422175, 31.03026748192803, 31.389010815889062, 31.74370016239443, 32.094469928634126, 32.44144725501623, 32.784752553588085, 33.12449999622636, 33.460797958207756, 33.7937494220455, 34.123452345857395, 34.45000000000001, 34.77348127524767, 35.09398096540203, 35.41158002687821, 35.72635581751938, 36.0383823166357, 36.347730328041116, 36.65446766766638, 36.9586593371567, 37.26036768471294, 37.55965255430354, 37.856571424258696, 38.151179536155894, 38.44353001481524, 38.73367398014292, 39.021660651489455, 39.30753744512623, 39.59135006538676, 39.87314258996901, 40.152957549849305, 40.43083600421837, 40.70681761081306, 40.980940691985104, 41.25324229681833, 41.523758259579544, 41.792523254764134, 42.059570848975625, 42.324933549859246, 42.58864285229104, 42.85072928200873, 43.11122243685512, 43.370151025791934, 43.62754290582958, 43.883425117007455, 44.1378239155489, 44.39076480530608, 44.64227256760122, 44.89237128956322, 45.14108439105114, 45.38843465024985, 45.634444228017074, 45.87913469105537, 46.12252703397766, 46.364641700330225, 46.60549860263273, 46.84511714149085, 47.08351622383359, 47.32071428032337, 47.55672928198491], [0.0, 4.776504998427197, 6.754998149518621, 8.273149339882607, 9.553009996854394, 10.68058987135074, 11.7, 12.637444361895328, 13.509996299037242, 14.329514995281592, 15.104635050208927, 15.841874889040126, 16.546298679765215, 17.221933689339302, 17.872045210327776, 18.499324311985017, 19.106019993708788, 19.69403462980605, 20.264994448555864, 20.820302591461058, 21.36117974270148, 21.88869571262756, 22.403794321498314, 22.90731324271793, 23.4, 23.882524992135988, 24.355492193753758, 24.819448019647822, 25.274888723790657, 25.722266618632194, 26.161995336747538, 26.594454309122423, 27.019992598074484, 27.438932194967066, 27.851570871317115, 28.258184655069403, 28.659029990563184, 29.054345630215114, 29.444354297555925, 29.829264154517794, 30.209270100417854, 30.58455492564834, 30.955290339455715, 31.32163788820757, 31.68374977808025, 32.04176961405222, 32.395833065380494, 32.746068466306, 33.09259735953043, 33.43553498899038, 33.77499074759311, 34.111068584845015, 34.443867378678604, 34.77348127524767, 35.1, 35.42350914294065, 35.74409042065555, 36.06182191736851, 36.37677830704638, 36.689031058342216, 36.998648623970034, 37.30569661593253, 37.61023796787252, 37.91233308568599, 38.212039987417576, 38.509414433356426, 38.80451004715818, 39.09737842873867, 39.3880692596121, 39.67663040128282, 39.96310798724244, 40.24754650907307, 40.52998889711173, 40.810476596089885, 41.08904963612568, 41.36574669941303, 41.640605182922116, 41.91366125739912, 42.18494992292868, 42.45450506130062, 42.72235948540296, 42.98854498584478, 43.25309237499673, 43.516031528621724, 43.77739142525512, 44.03720018348125, 44.29548509724214, 44.55227266930386, 44.80758864299663, 45.06145803233623, 45.31390515062678, 45.564953637636904, 45.81462648543586, 46.062946062969104, 46.309934139447876, 46.55561190662195, 46.8, 47.0431185190778, 47.28498704663035, 47.525624667120375, 47.765049984271975, 48.00328113785557], [0.0, 4.820529016612181, 6.817257513105985, 8.349401176132336, 9.641058033224361, 10.77903056865505, 11.807836380980218, 12.75392096572658, 13.63451502621197, 14.461587049836544, 15.243851219426146, 15.987886039123499, 16.69880235226467, 17.380664544257222, 18.03676800316509, 18.669828601248593, 19.282116066448722, 19.87555030684685, 20.451772539317954, 21.012198837817998, 21.5580611373101, 22.09043910835636, 22.610285270203917, 23.118445016912364, 23.615672761960436, 24.102645083060906, 24.57997152154575, 25.048203528397003, 25.50784193145316, 25.959343212030618, 26.40312481506687, 26.839569668681357, 27.26903005242394, 27.691830925383034, 28.108272803571552, 28.518634259024395, 28.923174099673087, 29.322133278463898, 29.715736571722402, 30.10419405996447, 30.487702438852292, 30.866446183517795, 31.240598585814585, 31.610322681048352, 31.975772078246997, 32.33709170596515, 32.69441848389416, 33.04788192910402, 33.39760470452934, 33.74370311628527, 34.08628756552993, 34.425462959849945, 34.761329088514444, 35.09398096540203, 35.42350914294066, 35.75, 36.07353600633018, 36.39419596584049, 36.712055240751646, 37.02718595842789, 37.339657202497186, 37.649535189693914, 37.95688343370672, 38.261762897179736, 38.564232132897445, 38.86434741507954, 39.16216286161938, 39.45773054801809, 39.7511006136937, 40.04232136127975, 40.33143934947029, 40.61849947991678, 40.90354507863591, 41.18661797234631, 41.46775856011511, 41.74700588066167, 42.024397675635996, 42.29997044916225, 42.573759523913324, 42.845799093960196, 43.1161222746202, 43.384761149509636, 43.65174681499012, 43.91710942218306, 44.18087821671272, 44.44308157632637, 44.70374704652844, 44.96290137435528, 45.220570540407834, 45.47677978925069, 45.73155365827844, 45.98491600514239, 46.23689003382473, 46.48749831944069, 46.73676283184363, 46.984704958103116, 47.23134552392087, 47.47670481404539, 47.720802591741894, 47.9636581173705, 48.20529016612181, 48.44571704495662], [0.0, 4.864154602806123, 6.878953408767935, 8.424962907930219, 9.728309205612247, 10.876580344942983, 11.914696806885184, 12.869343417595166, 13.75790681753587, 14.59246380841837, 15.381807436059, 16.132575739788116, 16.849925815860438, 17.537958832201657, 18.2, 18.83878977004627, 19.456618411224493, 20.055423206703964, 20.636860226303806, 21.202358359390118, 21.753160689885966, 22.29035665932692, 22.81490740721952, 23.327665978404273, 23.829393613770367, 24.320773014030618, 24.80241923684059, 25.274888723790657, 25.738686835190332, 26.19427418349285, 26.64207199149495, 27.082466652799557, 27.51581363507174, 27.94244083826608, 28.362651498052855, 28.776726707532248, 29.18492761683674, 29.587497359526708, 29.98466274614407, 30.376635758424598, 30.763614872118, 31.145786231848444, 31.52332469775357, 31.89639478060177, 32.26515147957623, 32.629741034828946, 32.99030160516875, 33.34696387978971, 33.699851631720875, 34.04908221964286, 34.39476704383968, 34.73701196130721, 35.07591766440331, 35.41158002687822, 35.74409042065555, 36.07353600633018, 36.4, 36.72356191874639, 37.04429780681502, 37.36228044431977, 37.67757954009254, 37.99026191012639, 38.30039164290621, 38.6080302527855, 38.91323682244899, 39.21606813539572, 39.51657879928373, 39.81482136089524, 40.11084641340793, 40.40470269659214, 40.69643719049617, 40.98609520312956, 41.27372045260761, 41.55935514417903, 41.843040042520805, 42.12481453965109, 42.404716718780236, 42.68278341439321, 42.9590502688316, 43.233551785621316, 43.50632137977193, 43.77739142525512, 44.046793299853285, 44.31455742755421, 44.58071331865384, 44.845289607716886, 45.10831408953343, 45.36981375319938, 45.62981481443904, 45.88834274627925, 46.145422308177004, 46.401077573694344, 46.655331956808546, 46.90820823693866, 47.15972858276434, 47.40991457490721, 47.658787227540735, 47.906367008989534, 48.15267386137555, 48.39772721936434, 48.641546028061235, 48.88414876010423], [0.0, 4.907392382925988, 6.940100863820351, 8.499852939904315, 9.814784765851975, 10.973262960487187, 12.020607305789504, 12.983739831034818, 13.880201727640703, 14.722177148777961, 15.518537302207319, 16.27597923321359, 16.99970587980863, 17.69385486546106, 18.361780959373192, 19.006248972377477, 19.62956953170395, 20.233697141155396, 20.820302591461054, 21.390827473475635, 21.946525920974373, 22.488497059608054, 23.017710572513508, 23.535027087301177, 24.041214611579008, 24.536961914629938, 25.02288952139621, 25.49955881971294, 25.967479662069636, 26.42711675533296, 26.87889506657593, 27.323204424078813, 27.760403455281406, 28.190822974861874, 28.61476891397168, 29.03252486436548, 29.444354297555922, 29.85050250833309, 30.25119832337225, 30.646655608728338, 31.037074604414638, 31.422643109706733, 31.80353753908518, 32.17992386566506, 32.55195846642718, 32.91978888146156, 33.28355449767948, 33.64338716597958, 33.99941175961726, 34.35174668048191, 34.70050431910176, 35.045791473442286, 35.38770973092212, 35.72635581751937, 36.06182191736851, 36.39419596584049, 36.723561918746384, 37.050000000000004, 37.373586929809136, 37.69439613523474, 38.012497944754955, 38.32795976829448, 38.64084626402481, 38.951219493104446, 39.2591390634079, 39.56466226318632, 39.8678441855087, 40.16873784424898, 40.46739428231079, 40.763862672715405, 41.05819041311977, 41.350423214279196, 41.64060518292211, 41.92877889946236, 42.21498549093674, 42.49926469952157, 42.78165494695127, 43.0621933951349, 43.3409160032411, 43.617857581499806, 43.89305184194875, 44.16653144633389, 44.43832805135675, 44.70847235144587, 44.97699411921611, 45.243922243766626, 45.50928476695717, 45.773108917791454, 46.035421145027016, 46.296247148122056, 46.555611906621955, 46.813539708080185, 47.070054174602355, 47.32517828809524, 47.57893441429726, 47.83134432566159, 48.082429223158016, 48.332209757055395, 48.58070604674246, 48.82793769964077, 49.073923829259876, 49.318683072442234], [0.0, 4.95025251881154, 7.000714249274855, 8.574088872877399, 9.90050503762308, 11.069101137852163, 12.12559276901546, 13.097137091746427, 14.00142849854971, 14.850757556434623, 15.654072952429985, 16.41813022240962, 17.148177745754797, 17.84838928306978, 18.52214890340751, 19.172245564878413, 19.80101007524616, 20.410414008539856, 21.002142747824564, 21.577650474507184, 22.138202275704327, 22.684906876599698, 23.218742429339283, 23.74057707807458, 24.25118553803092, 24.751262594057703, 25.24143419063188, 25.722266618632197, 26.194274183492855, 26.657925650732846, 27.113649698998472, 27.56183956124845, 28.00285699709942, 28.437035710495568, 28.864684304526875, 29.286088847778906, 29.701515112869245, 30.111210536941222, 30.51540594519431, 30.9143170715447, 31.30814590485997, 31.697081884615187, 32.081302966057976, 32.46097657187781, 32.83626044481924, 33.20730341355648, 33.574246082376895, 33.937221453737195, 34.296355491509594, 34.651767631680784, 35.00357124637428, 35.35187406630659, 35.69677856613956, 36.0383823166357, 36.376778307046386, 36.712055240751646, 37.04429780681502, 37.373586929809136, 37.7, 38.02361108574513, 38.344491129756825, 38.66270813070393, 38.978327311468874, 39.29141127523928, 39.60202015049232, 39.910211725822755, 40.216041575470854, 40.51956317632262, 40.82082801707971, 41.11988570023025, 41.41678403739238, 41.71156913854956, 42.00428549564913, 42.29497606099335, 42.58368232081392, 42.87044436438699, 43.15530094901437, 43.43828956116942, 43.71944647408063, 43.998806802003166, 44.27640455140865, 44.55227266930387, 44.82644308887334, 45.09894677262431, 45.369813753199395, 45.6390731720091, 45.9067533158249, 46.17288165146291, 46.437484858678566, 46.70058886138375, 46.962218857289955, 47.222399346073054, 47.48115415614916, 47.738506470144216, 47.9944788491343, 48.249093255728646, 48.50237107606184, 48.754333140757865, 49.004999744923985, 49.254390667228854, 49.502525188115406, 49.74942210719639], [0.0, 4.992744736114595, 7.06080731928014, 8.647687552172547, 9.98548947222919, 11.164116624256485, 12.229677019447406, 13.209560931386024, 14.12161463856028, 14.978234208343785, 15.788445141938453, 16.559060963714096, 17.295375104345094, 18.0015971513641, 18.681140222159886, 19.336817214836568, 19.97097894445838, 20.58561390874705, 21.18242195784042, 21.76286975561817, 22.32823324851297, 22.879630678837454, 23.41804859504737, 23.944362593312025, 24.459354038894812, 24.963723680572976, 25.458102835835984, 25.94306265651764, 26.419121862772048, 26.886753243930364, 27.346389158351414, 27.798426214446028, 28.24322927712056, 28.68113491478327, 29.112454379526298, 29.53747619550458, 29.95646841668757, 30.369680604181532, 30.77734556455446, 31.179680883549786, 31.576890283876907, 31.969164831130637, 32.35668400809947, 32.73961667460387, 33.11812192742819, 33.49234987276945, 33.862442321840874, 34.228533418772116, 34.59075020869019, 34.949213152802166, 35.3040365964007, 35.65532919494644, 36.0031943027282, 36.347730328041116, 36.68903105834222, 37.02718595842789, 37.36228044431977, 37.69439613523474, 38.02361108574513, 38.349999999999994, 38.673634429673136, 38.99458295712367, 39.31291136509734, 39.62868279415807, 39.94195788891676, 40.25279493401669, 40.56124998073901, 40.86737696500718, 41.1712278174941, 41.472852566468106, 41.772299433955034, 42.06961492573945, 42.36484391568084, 42.65802972477749, 42.94921419537265, 43.23843776086272, 43.52573951123634, 43.81115725474505, 44.09472757598124, 44.376485890615534, 44.65646649702594, 44.934702625031356, 45.21122648192593, 45.48606929599435, 45.75926135767491, 46.03083205852356, 46.30080992812113, 46.56922266905472, 46.83609719009474, 47.101459637680016, 47.36533542581536, 47.62774926447816, 47.88872518662405, 48.14828657387509, 48.406456180968256, 48.66325615903645, 48.918708077789624, 49.17283294665867, 49.425651234960974, 49.67718289114229, 49.92744736114595, 50.17646360595773], [0.0, 5.034878350069642, 7.120393247567159, 8.720665112249181, 10.069756700139283, 11.258330249197703, 12.332882874656677, 13.321035995747478, 14.240786495134317, 15.104635050208925, 15.921683328090657, 16.698802352264668, 17.441330224498362, 18.153512056899622, 18.83878977004627, 19.499999999999996, 20.139513400278567, 20.759335249472702, 21.361179742701474, 21.94652592097437, 22.516660498395407, 23.072711154088502, 23.615672761960436, 24.146428307308724, 24.665765749313355, 25.174391750348207, 25.67294295557095, 26.16199533674754, 26.642071991494955, 27.113649698998472, 27.57716446627535, 28.03301624870217, 28.481572990268635, 28.923174099673084, 29.358133455654155, 29.786742017212955, 30.20927010041785, 30.625969372413337, 31.037074604414638, 31.44280521836434, 31.843366656181313, 32.23895159585683, 32.629741034828946, 33.01590525792076, 33.397604704529336, 33.7749907475931, 34.14820639506561, 34.51738692311456, 34.882660448996724, 35.24414845048749, 35.601966237835796, 35.956223383442264, 36.307024113799244, 36.65446766766638, 36.998648623970034, 37.339657202497186, 37.67757954009254, 38.012497944754955, 38.344491129756825, 38.673634429673136, 38.99999999999999, 39.32365700186085, 39.644671773139954, 39.96310798724243, 40.27902680055713, 40.59248698958958, 40.90354507863591, 41.212255458783126, 41.518670498945404, 41.82284064957807, 42.12481453965109, 42.42463906740986, 42.72235948540295, 43.01801948021317, 43.31166124728997, 43.603325561245896, 43.89305184194874, 44.180878216712706, 44.46684157886638, 44.75097764295211, 45.03332099679081, 45.31390515062678, 45.59276258355047, 45.86992478738111, 46.145422308177004, 46.419284785528525, 46.691540989776726, 46.96221885728995, 47.23134552392087, 47.49894735675728, 47.76504998427197, 48.029678324969034, 48.29285661461745, 48.55460843215606, 48.81495672434832, 49.07392382925986, 49.33153149862671, 49.587800919177695, 49.842752732970105, 50.09640705679401, 50.34878350069641, 50.59990118567426], [0.0, 5.076662289339326, 7.179484661171719, 8.793037018004645, 10.153324578678651, 11.351761977772439, 12.435232205310843, 13.431585907851687, 14.358969322343437, 15.229986868017976, 16.05381574579701, 16.837384001085205, 17.58607403600929, 18.304166192427342, 18.995130955063193, 19.661828500930426, 20.306649157357302, 20.931614844536004, 21.538453983515158, 22.128657889713963, 22.703523955544878, 23.264189218625265, 23.811656809218466, 24.34681704042646, 24.870464410621686, 25.383311446696627, 25.886000077261844, 26.379111054013933, 26.863171815703375, 27.33866309825702, 27.806024527069667, 28.26565937670657, 28.717938644686875, 29.163204556426923, 29.60177359551282, 30.033939135584593, 30.459973736035952, 30.880131152571227, 31.294648104747882, 31.703745835468716, 32.10763149159402, 32.50649935012997, 32.90053191059379, 33.28990087098488, 33.67476800217041, 34.05528593331731, 34.431598859187474, 34.80384317859164, 35.17214807201858, 35.53663602537527, 35.897423305858595, 36.25462039519929, 36.608332384854684, 36.9586593371567, 37.30569661593253, 37.64953518969391, 37.990261910126385, 38.32795976829448, 38.66270813070393, 38.99458295712367, 39.32365700186085, 39.65, 39.973678839956676, 40.29475772355506, 40.613298314714605, 40.929359877721026, 41.24299940595979, 41.55427174190398, 41.86322968907201, 42.169924116602346, 42.474404057031805, 42.77671679780953, 43.076907967030316, 43.37502161382747, 43.67110028382614, 43.96518509002322, 44.25731577942793, 44.54753079576914, 44.83586733854939, 45.12236141870237, 45.407047911089755, 45.68996060405393, 45.971132246226, 46.25059459077256, 46.52837843725053, 46.8045136712262, 47.079029301802734, 47.35195349718953, 47.62331361843693, 47.89313625145048, 48.16144723739103, 48.42827170155879, 48.69363408085292, 48.957558149891426, 49.22006704587063, 49.48118329223746, 49.74092882124337, 49.99932499544369, 50.25639262820203, 50.512152003255615, 50.766622893393254, 51.01982457829506], [0.0, 5.118105118107676, 7.238093671679027, 8.864818103040808, 10.236210236215353, 11.444430960078357, 12.53674598929084, 13.541233326399778, 14.476187343358054, 15.354315354323031, 16.18486947738535, 16.974834314360773, 17.729636206081615, 18.453590436551906, 19.150195821453103, 19.822335886569977, 20.472420472430706, 21.102488004972304, 21.714281015037084, 22.30930299224967, 22.888861920156714, 23.45410411846933, 24.006040906405207, 24.54556986504897, 25.07349197858168, 25.590525590538384, 26.09731786985015, 26.59445430912242, 27.082466652799557, 27.561839561248448, 28.033016248702168, 28.496403281817866, 28.95237468671611, 29.401275482536466, 29.84342473644739, 30.279118217015498, 30.708630708646062, 31.13221803855292, 31.55011885873015, 31.962556218175042, 32.3697389547707, 32.77186293148438, 33.169112137649996, 33.56165967290652, 33.94966862872155, 34.333292880235064, 34.71267779932859, 35.08796089829102, 35.45927241216323, 35.82673582675374, 36.190468358395144, 36.55058139072483, 36.90718087310381, 37.26036768471294, 37.61023796787252, 37.95688343370672, 38.300391642906206, 38.64084626402481, 38.97832731146887, 39.312911365097335, 39.644671773139954, 39.973678839956676, 40.3, 40.62369997919933, 40.94484094486141, 41.26348264507008, 41.579682538470635, 41.893495915237246, 42.20497600994461, 42.514174106996364, 42.82113963920157, 43.12592028003576, 43.42856203007417, 43.72910929804082, 44.02760497687785, 44.32409051520403, 44.61860598449934, 44.911190142324216, 45.20188049185565, 45.490713337999, 45.77772384031343, 46.0629460629691, 46.34641302193731, 46.62815672959848, 46.90820823693866, 47.186597673491995, 47.46335428517458, 47.7385064701442, 48.012081812810415, 48.28410711611016, 48.55460843215605, 48.8236110913562, 49.09113973009794, 49.35721831708104, 49.621870178380014, 49.885118021309715, 50.14698395716336, 50.407489522887374, 50.66665570175319, 50.924502943082324, 51.18105118107677, 51.4363198528044], [0.0, 5.159215056575952, 7.296231904209185, 8.93602260516389, 10.318430113151903, 11.536355577044253, 12.637444361895326, 13.650000000000002, 14.59246380841837, 15.477645169727856, 16.314870517414473, 17.11118055541464, 17.87204521032778, 18.60181442763044, 19.304015126392745, 19.981553993621215, 20.636860226303806, 21.27198862353964, 21.888695712627555, 22.488497059608054, 23.072711154088505, 23.642493523315178, 24.198863609682174, 24.74272620387657, 25.274888723790653, 25.79607528287976, 26.306938248302483, 26.80806781549167, 27.300000000000004, 27.783223355111268, 28.258184655069403, 28.72529373217966, 29.18492761683674, 29.637434099462794, 30.08313481005595, 30.522327892872127, 30.95529033945571, 31.38228003189061, 31.80353753908518, 32.2192877016237, 32.629741034828946, 33.035094974889965, 33.43553498899038, 33.83123556715007, 34.22236111082928, 34.609066731132756, 34.991498967606404, 35.369796437073255, 35.74409042065556, 36.11450539603166, 36.48115952104593, 36.844165073997814, 37.20362885526088, 37.55965255430354, 37.91233308568599, 38.261762897179736, 38.60803025278549, 38.95121949310445, 39.29141127523928, 39.62868279415807, 39.96310798724243, 40.29475772355506, 40.62369997919934, 40.95, 41.27372045260761, 41.594921565018005, 41.91366125739912, 42.229995264030045, 42.54397724707928, 42.85565890288003, 43.16509006129838, 43.472318778735506, 43.77739142525511, 44.08035276628353, 44.38124603929006, 44.68011302581944, 44.97699411921611, 45.271928388351206, 45.564953637636904, 45.8561064635889, 46.14542230817701, 46.43293550918357, 46.718679347772664, 47.002686093456404, 47.284987046630356, 47.565612578836834, 47.844592170902665, 48.12195444908696, 48.39772721936435, 48.67193749995987, 48.94461155224342, 49.21577491008346, 49.48545240775314, 49.753668206475, 50.020445819684575, 50.28580813708774, 50.549777447581306, 50.812375461102, 51.0736233294643, 51.33354166624392, 51.59215056575952, 51.849469621202495], [0.0, 5.2, 7.353910524340094, 9.006664199358163, 10.4, 11.62755348299891, 12.737346662472525, 13.757906817535872, 14.707821048680188, 15.6, 16.443843832875572, 17.24644890984808, 18.013328398716325, 18.748866632412746, 19.456618411224493, 20.139513400278567, 20.8, 21.440149253211835, 22.061731573020282, 22.666274506411504, 23.25510696599782, 23.82939361377037, 24.390161951081836, 24.938323921226146, 25.47469332494505, 26.0, 26.514901470682485, 27.019992598074488, 27.515813635071744, 28.002856997099425, 28.481572990268635, 28.952374686716116, 29.415642097360376, 29.87172576199775, 30.320949853195565, 30.763614872118, 31.2, 31.63036515755074, 32.05495281543868, 32.473989591671675, 32.887687665751145, 33.296246034650814, 33.699851631720875, 34.0986803263704, 34.49289781969616, 34.88266044899672, 35.268115912251396, 35.649403922085426, 36.02665679743265, 36.4, 36.76955262170048, 37.13542782842283, 37.49773326482549, 37.8565714242587, 38.21203998741758, 38.564232132897445, 38.91323682244899, 39.2591390634079, 39.60202015049233, 39.94195788891676, 40.27902680055713, 40.613298314714605, 40.94484094486142, 41.27372045260761, 41.6, 41.923740291152455, 42.244999704106995, 42.56383441373674, 42.88029850642367, 43.19444408717399, 43.50632137977193, 43.81597882051706, 44.123463146040564, 44.42881947565117, 44.732091388621654, 45.033320996790806, 45.33254901282301, 45.62981481443904, 45.92515650490481, 46.21861097004106, 46.51021393199564, 46.800000000000004, 47.08800271831457, 47.374254611550356, 47.65878722754074, 47.94163117792302, 48.222816176577666, 48.502371076061834, 48.78032390216367, 49.05670188669434, 49.33153149862672, 49.60483847368118, 49.87664784245229, 50.14698395716337, 50.415870517129825, 50.68333059300661, 50.9493866498901, 51.21406056933975, 51.47737367038066, 51.739346729544245, 52.0, 52.25935322982863], [0.0, 5.240467536394057, 7.411140263144396, 9.076756028449813, 10.480935072788114, 11.718041645257966, 12.836471477785473, 13.864973855006003, 14.822280526288791, 15.72140260918217, 16.57181341917655, 17.38066454425722, 18.153512056899626, 18.89477440987322, 19.60803406769786, 20.29624349479479, 20.961870145576228, 21.607001180173057, 22.233420789433186, 22.842668408047253, 23.43608329051593, 24.014839162484517, 24.57997152154575, 25.13239940793557, 25.672942955570946, 26.202337681970285, 26.721246228422807, 27.230268085349437, 27.729947710012006, 28.220781349920134, 28.7032228155655, 29.177688393702475, 29.644561052577583, 30.104194059964467, 30.55691411121221, 31.00302404605073, 31.44280521836434, 31.87651957162199, 32.30441146345186, 32.72670927545267, 33.1436268383531, 33.555364697764794, 33.96211124179414, 34.36404370850438, 34.76132908851444, 35.15412493577389, 35.542580097680016, 35.92683537413224, 36.30702411379925, 36.6832727547584, 37.05570131572198, 37.424423843260435, 37.78954881974644, 38.151179536155894, 38.509414433356426, 38.86434741507954, 39.21606813539572, 39.56466226318632, 39.910211725822755, 40.252794934016684, 40.59248698958958, 40.929359877721026, 41.26348264507008, 41.594921565018005, 41.923740291152455, 42.24999999999999, 42.57375952391332, 42.895075474930685, 43.214002360346115, 43.530592690658374, 43.84489708050413, 44.15696434312485, 44.46684157886637, 44.77457425816576, 45.08020629943922, 45.38378014224905, 45.685336816094505, 45.98491600514238, 46.28255610918654, 46.57829430110123, 46.87216658103186, 47.16420782754652, 47.454451845954345, 47.74293141398002, 48.029678324969034, 48.31472342878514, 48.598096670548735, 48.87982712735387, 49.1599430430915, 49.43847186149669, 49.71544025752965, 49.990874167191755, 50.26479881587114, 50.53723874530543, 50.808217839243284, 51.07775934788055, 51.34588591114189, 51.612619580873826, 51.87798184201077, 52.14199363277166, 52.40467536394057, 52.66604693728209], [0.0, 5.280624963013374, 7.467931440499437, 9.146310731655689, 10.561249926026749, 11.80783638098022, 12.93483668238606, 13.971220419133042, 14.935862880998874, 15.841874889040122, 16.698802352264668, 17.513851660899725, 18.292621463311377, 19.039564070639855, 19.75828939964186, 20.451772539317954, 21.122499852053497, 21.772574491777494, 22.40379432149831, 23.017710572513508, 23.61567276196044, 24.198863609682174, 24.76832654823495, 25.324987660411608, 25.86967336477212, 26.40312481506687, 26.926009730370374, 27.438932194967066, 27.942440838266084, 28.437035710495568, 28.923174099673084, 29.40127548253647, 29.871725761997748, 30.33488091290289, 30.79107013405023, 31.240598585814578, 31.683749778080244, 32.12078766157517, 32.55195846642718, 32.977492324311136, 33.397604704529336, 33.812497689463875, 34.22236111082928, 34.62737356485472, 35.02770332179945, 35.42350914294065, 35.81494101628537, 36.20214082067523, 36.585242926622755, 36.96437474109362, 37.339657202497186, 37.71120523133675, 38.07912814127971, 38.44353001481524, 38.80451004715818, 39.16216286161938, 39.51657879928372, 39.8678441855087, 40.216041575470854, 40.561249980739, 40.90354507863591, 41.24299940595979, 41.579682538470635, 41.91366125739912, 42.244999704106995, 42.57375952391332, 42.9, 43.22377817822038, 43.54514898355499, 43.86416532888777, 44.18087821671271, 44.495336834324554, 44.80758864299662, 45.11767946160352, 45.42565354510598, 45.731553658278436, 46.035421145027016, 46.3372959936162, 46.63721689809546, 46.93522131619281, 47.23134552392088, 47.52562466712037, 47.818092810148755, 48.10878298190467, 48.39772721936435, 48.68495660879242, 48.970501324777146, 49.25439066722884, 49.5366530964699, 49.81731626653527, 50.096407056794, 50.37395160199367, 50.649975320823216, 50.92450294308233, 51.197558535539564, 51.46916552655579, 51.73934672954424, 52.00812436533354, 52.275520083496055, 52.541554982699175, 52.80624963013374, 53.06962408007052], [0.0, 5.320479301717092, 7.524293986813646, 9.215340471192588, 10.640958603434184, 11.896953391520034, 13.032459476246222, 14.076665088010015, 15.048587973627292, 15.961437905151277, 16.82483283720822, 17.646033548647697, 18.430680942385177, 19.18326093238582, 19.90741068044762, 20.606127729391563, 21.281917206868368, 21.936898139892065, 22.572881960440938, 23.191431607384654, 23.793906783040068, 24.38149913356437, 24.95525996658821, 25.516122354307683, 26.064918952492445, 26.60239650858546, 27.12922778112197, 27.646021413577763, 28.15333017602003, 28.65165789269445, 29.14146530289786, 29.62317504927519, 30.097175947254584, 30.563826658322743, 31.02345886583248, 31.47638003328845, 31.922875810302553, 32.36321213971197, 32.79763711001145, 33.22638258974335, 33.64966567441644, 34.067689971584514, 34.4806467456746, 34.88871594083107, 35.292067097295394, 35.69086017456009, 36.08524629263322, 36.475368401155315, 36.86136188477035, 37.24335511201964, 37.62146993406824, 37.99582213875626, 38.36652186477164, 38.73367398014292, 39.09737842873867, 39.45773054801809, 39.81482136089524, 40.16873784424898, 40.51956317632262, 40.86737696500718, 41.212255458783126, 41.55427174190398, 41.893495915237246, 42.229995264030045, 42.563834413736735, 42.895075474930685, 43.22377817822038, 43.55, 43.87379627978413, 44.1952203298049, 44.51432353748622, 44.831155461352985, 45.145763920881876, 45.458195080755246, 45.768493529938254, 46.07670235596293, 46.38286321476931, 46.68701639642439, 46.98920088701233, 47.289454426965, 47.587813566080136, 47.884313715453835, 48.1789891965367, 48.47187328750561, 48.76299826712874, 49.05239545628736, 49.3400952573057, 49.62612719122861, 49.91051993317642, 50.19330134589674, 50.47449851162466, 50.75413776235392, 51.032244708615366, 51.30884426685131, 51.58396068546889, 51.85761756964929, 52.12983790498489, 52.400644080011084, 52.67005790769552, 52.938100645943095, 53.20479301717092, 53.47015522700491], [0.0, 5.360037313302959, 7.58023746329889, 9.283856957105707, 10.720074626605918, 11.985407794480755, 13.129356419870701, 14.18132574902643, 15.16047492659778, 16.080111939908875, 16.949926253526886, 17.77723263053055, 18.567713914211414, 19.32588937151406, 20.055423206703964, 20.759335249472706, 21.440149253211835, 22.099999999999998, 22.74071238989667, 23.36386098229486, 23.97081558896151, 24.56277671599854, 25.140803487557832, 25.70583591327075, 26.258712839741403, 26.800186566514792, 27.33093485411723, 27.85157087131712, 28.36265149805286, 28.864684304526875, 29.358133455654155, 29.843424736447393, 30.32094985319556, 30.79107013405023, 31.2541197284454, 31.710408385891213, 32.16022387981775, 32.60383413035958, 33.04148907056097, 33.473422292917704, 33.89985250705377, 34.320984834354626, 34.73701196130721, 35.14811516994901, 35.5544652610611, 35.95622338344226, 36.353541780684864, 36.74656446526668, 37.13542782842283, 37.52026119312071, 37.90118731649446, 38.27832284727219, 38.65177874302812, 39.021660651489455, 39.38806925961211, 39.7511006136937, 40.11084641340793, 40.46739428231079, 40.82082801707971, 41.1712278174941, 41.51867049894541, 41.86322968907201, 42.20497600994461, 42.54397724707928, 42.88029850642367, 43.214002360346115, 43.54514898355499, 43.87379627978413, 44.199999999999996, 44.523813852813646, 44.845289607716886, 45.16447719170454, 45.48142477979334, 45.7961788799022, 46.108784412517316, 46.419284785528525, 46.72772196458972, 47.03413653932641, 47.33856778568613, 47.64105372470261, 47.94163117792302, 48.24033581972663, 48.53720222674562, 48.83226392458167, 49.12555343199708, 49.417102302745356, 49.70694116519342, 49.99509975987647, 50.281606975115665, 50.56649088081948, 50.84977876058066, 51.131497142172556, 51.4116718265415, 51.69032791538472, 51.96748983739738, 52.2431813732663, 52.517425679482805, 52.790245311042085, 53.06166224309223, 53.331697891591645, 53.600373133029585, 53.86770832326172], [0.0, 5.399305510896749, 7.6357710809059745, 9.351871470459805, 10.798611021793498, 12.073214153654364, 13.225543467094273, 14.285219634293343, 15.271542161811949, 16.197916532690247, 17.074103197532807, 17.907470508142687, 18.70374294091961, 19.46747287143352, 20.20235134829607, 20.911420324789034, 21.597222043586996, 22.261906926406823, 22.907313242717922, 23.535027087301177, 24.146428307308728, 24.74272620387657, 25.324987660411608, 25.89415957315472, 26.451086934188545, 26.996527554483745, 27.531164159911587, 28.055614411379413, 28.570439268586686, 29.07615002024856, 29.573214231801046, 30.062060807602666, 30.543084323623898, 31.01664875514439, 31.48309069961207, 31.942722175794596, 32.395833065380494, 32.84269325131543, 33.28355449767948, 33.718652108291636, 34.148206395065614, 34.572423982127724, 34.99149896760641, 35.405613961630436, 35.814941016285374, 36.21964246096309, 36.61987165460852, 37.01577366475001, 37.40748588183922, 37.79513857627724, 38.17885540452988, 38.55875386990612, 38.93494574286704, 39.30753744512623, 39.67663040128282, 40.04232136127975, 40.40470269659214, 40.763862672715405, 41.11988570023025, 41.4728525664681, 41.82284064957807, 42.169924116602346, 42.514174106996364, 42.85565890288002, 43.19444408717399, 43.530592690658374, 43.86416532888777, 44.1952203298049, 44.523813852813646, 44.85, 45.173830920124544, 45.4953569059525, 45.814626485435845, 46.13168650721541, 46.4465822208696, 46.75935735229901, 47.070054174602355, 47.378713574768994, 47.68537511648619, 47.990077099333774, 48.292856614617456, 48.593749598070744, 48.89279087963787, 49.190014230532604, 49.48545240775314, 49.77913719621907, 50.071099448683974, 50.36136912356533, 50.649975320823216, 50.93694631600917, 51.22230959259842, 51.50609187270959, 51.78831914630944, 52.0690166989929, 52.3482091384223, 52.6259204195043, 52.90217386837709, 53.17699220527616, 53.45039756634182, 53.72241152442806, 53.99305510896749, 54.262348824944915], [0.0, 5.438290172471492, 7.6909037180295, 9.419394885023136, 10.876580344942983, 12.160386507015312, 13.321035995747478, 14.388363353766128, 15.381807436059, 16.314870517414473, 17.19738352191984, 18.036768003165093, 18.838789770046272, 19.608034067697865, 20.348218595248085, 21.062407269825545, 21.753160689885966, 22.422644803858443, 23.072711154088502, 23.704957287453613, 24.320773014030625, 24.921376366485063, 25.507841931453164, 26.081123442060548, 26.642071991494955, 27.191450862357456, 27.72994771001201, 28.25818465506941, 28.776726707532255, 29.28608884777891, 29.78674201721296, 30.279118217015505, 30.763614872118, 31.240598585814585, 31.710408385891217, 32.17335854398791, 32.629741034828946, 33.07982768999863, 33.52387209139184, 33.96211124179414, 34.39476704383968, 34.822047613545074, 35.2441484504875, 35.66125348329753, 36.07353600633019, 36.48115952104593, 36.88427849368888, 37.283039039219965, 37.677579540092545, 38.068031207300436, 38.45451859014751, 38.83716004035311, 39.21606813539573, 39.59135006538676, 39.96310798724244, 40.33143934947029, 40.69643719049617, 41.05819041311977, 41.41678403739238, 41.772299433955034, 42.12481453965109, 42.47440405703181, 42.82113963920157, 43.16509006129838, 43.50632137977193, 43.84489708050413, 44.18087821671271, 44.51432353748623, 44.845289607716886, 45.173830920124544, 45.5, 45.82384750323787, 46.145422308177004, 46.464771601719946, 46.78194096016111, 47.096974425115675, 47.409914574907226, 47.720802591741894, 48.02967832496904, 48.336580350703336, 48.64154602806125, 48.94461155224342, 49.24581200467711, 49.54518140041472, 49.842752732970126, 50.13855801675992, 50.43262832730415, 50.72499383932934, 51.01568386290633, 51.3047268777449, 51.59215056575952, 51.87798184201078, 52.162246884121096, 52.444971160255214, 52.72617945575045, 53.00589589847529, 53.28414398298991, 53.560946593576936, 53.83632602620651, 54.11030400949528, 54.38290172471491, 54.654139824902565], [0.0, 5.476997352564633, 7.74564393707844, 9.486437687562177, 10.953994705129267, 12.246938392920903, 13.41584883635769, 14.490772926245171, 15.49128787415688, 16.4309920576939, 17.319786372816495, 18.165145196226756, 18.972875375124353, 19.747594790252307, 20.49304760156478, 21.212319533704935, 21.907989410258534, 22.58223859585227, 23.23693181123532, 23.873677973869047, 24.493876785841806, 25.09875494920017, 25.689394698980358, 26.26675655652978, 26.83169767271538, 27.384986762823164, 27.92731637662309, 28.45931306268653, 28.981545852490342, 29.494533391799912, 29.998749973957246, 30.494630674923744, 30.98257574831376, 31.462954406730468, 31.93610809099944, 32.40235330959774, 32.8619841153878, 33.3152742747227, 33.76247917437344, 34.20383750399946, 34.63957274563299, 35.06989449656215, 35.49499964783772, 35.91507343720739, 36.33029039245351, 36.7408151787627, 37.14680336179683, 37.548402096494065, 37.945750750248706, 38.33898146795243, 38.728219685392204, 39.113584596659, 39.495189580504615, 39.87314258996901, 40.247546509073075, 40.618499479916785, 40.98609520312956, 41.350423214279196, 41.711569138549564, 42.06961492573945, 42.42463906740987, 42.77671679780953, 43.125920280035764, 43.472318778735506, 43.81597882051707, 44.156964343124855, 44.49533683432456, 44.83115546135299, 45.16447719170454, 45.495356905952505, 45.82384750323788, 46.15, 46.47386362247064, 46.79548589340643, 47.114912713492316, 47.43218843781088, 47.74735594773809, 48.06045671859559, 48.37153088336155, 48.68061729271723, 48.98775357168361, 49.292976173081705, 49.59632042803176, 49.89782059368926, 50.19750989840034, 50.495420584445085, 50.79158394852439, 51.086030380134254, 51.378789397960716, 51.66988968441871, 51.95935911844949, 52.24722480668232, 52.53351311305956, 52.81824968701633, 53.101459490300265, 53.383166822510624, 53.66339534543076, 53.9421681062228, 54.21950755954908, 54.49543558868027, 54.76997352564633, 55.043142170482966], [0.0, 5.5154328932550705, 7.8, 9.553009996854396, 11.030865786510141, 12.332882874656681, 13.509996299037242, 14.592463808418373, 15.6, 16.54629867976521, 17.44133022449836, 18.292621463311377, 19.10601999370879, 19.886176103011863, 20.636860226303806, 21.361179742701477, 22.061731573020282, 22.74071238989667, 23.4, 24.04121461157901, 24.665765749313362, 25.274888723790657, 25.869673364772122, 26.45108693418855, 27.019992598074484, 27.577164466275352, 28.12329994861912, 28.659029990563187, 29.184927616836745, 29.701515112869245, 30.20927010041785, 30.708630708646066, 31.2, 31.683749778080248, 32.16022387981775, 32.629741034828946, 33.09259735953042, 33.54906854146625, 33.99941175961726, 34.443867378678604, 34.88266044899672, 35.316002038735924, 35.74409042065555, 36.167112132433246, 36.585242926622755, 36.998648623970034, 37.407485881839214, 37.81190288784737, 38.21203998741758, 38.6080302527855, 39.0, 39.38806925961211, 39.772352206023726, 40.152957549849305, 40.52998889711173, 40.90354507863591, 41.27372045260761, 41.640605182922116, 42.004285495649135, 42.36484391568084, 42.722359485402954, 43.076907967030316, 43.42856203007417, 43.77739142525512, 44.123463146040564, 44.46684157886638, 44.80758864299663, 45.14576392088188, 45.48142477979334, 45.81462648543585, 46.145422308177004, 46.47386362247064, 46.8, 47.12387929701883, 47.44554773632611, 47.765049984271975, 48.08242922315802, 48.39772721936434, 48.710984387507516, 49.022239850908484, 49.331531498626724, 49.63889603929564, 49.944369051976224, 50.247985034227995, 50.54977744758131, 50.84977876058067, 51.14802048955561, 51.44453323726438, 51.739346729544245, 52.0324898500927, 52.32399067349508, 52.613876496604966, 52.9021738683771, 53.188908618244845, 53.474105883128146, 53.75779013315186, 54.03998519614897, 54.32071428101808, 54.599999999999994, 54.87786438993413, 55.154328932550705, 55.4294145738524], [0.0, 5.553602434456395, 7.853979882836471, 9.619121581516684, 11.10720486891279, 12.418232563452822, 13.603492198696626, 14.693450922094511, 15.707959765672943, 16.660807303369186, 17.562032911938186, 18.419215509896183, 19.238243163033367, 20.023798340974174, 20.779677572089515, 21.509009740106585, 22.21440973782558, 22.898089439951097, 23.561939648509412, 24.207591784396897, 24.836465126905644, 25.449803535587463, 26.048704382368044, 26.634141623112246, 27.206984397393253, 27.768012172281974, 28.317927184029557, 28.85736474455005, 29.386901844189023, 29.90706438285109, 30.418333287673732, 30.921149719892373, 31.415919531345885, 31.90301709870087, 32.38278863841099, 32.85555508586029, 33.32161460673837, 33.78124479648434, 34.234704613885604, 34.68223608708066, 35.12406582387637, 35.56040635313382, 35.99145731975854, 36.41740655236174, 36.83843101979237, 37.25469769035846, 37.66636430557109, 38.073580078579425, 38.476486326066734, 38.875217041194766, 39.26989941418236, 39.660654306251686, 40.04759668194835, 40.43083600421837, 40.810476596089885, 41.18661797234631, 41.55935514417903, 41.92877889946236, 42.29497606099334, 42.658029724777485, 43.01801948021317, 43.37502161382747, 43.72910929804082, 44.08035276628353, 44.42881947565116, 44.77457425816576, 45.11767946160352, 45.45819508075524, 45.79617887990219, 46.131686507215406, 46.464771601719946, 46.79548589340642, 47.123879297018824, 47.45, 47.77389454503369, 48.09560790758341, 48.41518356879379, 48.73266358408906, 49.04808864777506, 49.361498153925595, 49.67293025381129, 49.98242191010756, 50.29000894810022, 50.59572610408907, 50.89960707117493, 51.20168454260075, 51.5019902528048, 51.80055501633163, 52.09740876473609, 52.39258058160525, 52.686098735814554, 52.97799071312539, 53.26828324622449, 53.557002343297754, 53.84417331522511, 54.12982080147688, 54.413968794786506, 54.696640664669715, 54.9778591798553, 55.25764652968855, 55.53602434456395, 55.81301371544096], [0.0, 5.591511423577707, 7.9075912893876845, 9.684781876738372, 11.183022847155414, 12.502999640086376, 13.69634987870856, 14.793748679763356, 15.815182578775369, 16.77453427073312, 17.681911661356075, 18.54494540299324, 19.369563753476744, 20.16048114505207, 20.921520021260402, 21.655830623644984, 22.366045694310827, 23.054392206258658, 23.722773868163053, 24.372833237028477, 25.00599928017275, 25.623524347755133, 26.22651330238162, 26.815946748157153, 27.39269975741712, 27.957557117888534, 28.511225859299703, 29.054345630215114, 29.58749735952671, 30.111210536941222, 30.625969372413337, 31.132218038552924, 31.630365157550738, 32.12078766157517, 32.60383413035957, 33.07982768999862, 33.54906854146624, 34.011836175072936, 34.46839131726342, 34.91897764826456, 35.36382332271215, 35.80314232019307, 36.237135648392524, 36.665992418043174, 37.08989080598648, 37.50899892025912, 37.92347557911854, 38.3334710142455, 38.73912750695349, 39.14057996504395, 39.53795644693843, 39.93137863885995, 40.32096229010414, 40.70681761081306, 41.08904963612568, 41.46775856011511, 41.843040042520805, 42.21498549093675, 42.58368232081392, 42.94921419537265, 43.31166124728997, 43.67110028382614, 44.02760497687785, 44.38124603929006, 44.732091388621654, 45.08020629943922, 45.42565354510598, 45.768493529938254, 46.108784412517316, 46.4465822208696, 46.78194096016111, 47.11491271349231, 47.445547736326105, 47.77389454503369, 48.099999999999994, 48.42390938369185, 48.745666474056954, 49.065313613590604, 49.382891774378706, 49.69844061939972, 50.0119985603455, 50.32360281219937, 50.63328944479116, 50.941093431531286, 51.247048695510266, 51.55118815313572, 51.85354375546574, 52.15414652738552, 52.45302660476324, 52.75021326971105, 53.045734984068226, 53.33961942121447, 53.631893496314305, 53.922583395085965, 54.21171460118191, 54.49931192226191, 54.78539951483424, 55.07000090793535, 55.353139025713794, 55.63483620897971, 55.91511423577707, 56.193994341032564], [0.0, 5.629165124598851, 7.960841664045328, 9.750000000000002, 11.258330249197702, 12.587195875174107, 13.788582233137676, 14.893371008606481, 15.921683328090657, 16.887495373796554, 17.800983118917898, 18.669828601248597, 19.500000000000004, 20.296243494794798, 21.062407269825545, 21.801662780622948, 22.516660498395403, 23.209642392764263, 23.882524992135984, 24.536961914629938, 25.174391750348214, 25.796075282879762, 26.403124815066874, 26.996527554483748, 27.577164466275352, 28.145825622994256, 28.703222815565507, 29.250000000000004, 29.786742017212962, 30.31398192253865, 30.832207186641696, 31.341864973227107, 31.843366656181313, 32.33709170596515, 32.82339104967675, 33.30258998936869, 33.77499074759311, 34.2408746967714, 34.70050431910177, 35.15412493577389, 35.601966237835796, 36.044243645830605, 36.48115952104593, 36.912904247701775, 37.33965720249719, 37.76158762552231, 38.17885540452988, 38.59161178287323, 39.00000000000001, 39.40415587219196, 39.80420832022665, 40.200279849772194, 40.592486989589595, 40.980940691985104, 41.36574669941303, 41.74700588066167, 42.12481453965109, 42.49926469952157, 42.87044436438699, 43.23843776086272, 43.603325561245896, 43.96518509002322, 44.324090515204034, 44.68011302581944, 45.033320996790806, 45.38378014224906, 45.731553658278436, 46.07670235596293, 46.419284785528525, 46.75935735229902, 47.096974425115675, 47.43218843781087, 47.76504998427197, 48.095607907583414, 48.42390938369185, 48.75, 49.073923829259876, 49.395723499104655, 49.71544025752966, 50.033114034607124, 50.34878350069643, 50.66248612138966, 50.9742582094139, 51.28413497369338, 51.592150565759525, 51.89833812368177, 52.20272981367929, 52.50535686956141, 52.80624963013375, 53.10543757469662, 53.402949356753695, 53.6988128360395, 53.993055108967496, 54.28570253759272, 54.57678077717666, 54.86631480243592, 55.154328932550705, 55.44084685500395, 55.7258916483173, 56.00948580374579, 56.29165124598851, 56.57240935296994], [0.0, 5.666568626602876, 8.01373820385967, 9.814784765851977, 11.333137253205752, 12.670832648251656, 13.880201727640705, 14.992331373072037, 16.02747640771934, 16.99970587980863, 17.91926337771729, 18.793881983241253, 19.629569531703954, 20.431103739152228, 21.202358359390118, 21.946525920974373, 22.666274506411504, 23.36386098229486, 24.041214611579008, 24.700000000000003, 25.34166529650331, 25.96747966206964, 26.57856279033914, 27.175908448476942, 27.76040345528141, 28.332843133014382, 28.893944002160737, 29.44435429755593, 29.984662746144075, 30.51540594519431, 31.037074604414638, 31.55011885873016, 32.05495281543868, 32.55195846642718, 33.04148907056097, 33.52387209139183, 33.99941175961726, 34.46839131726342, 34.93107499061546, 35.387709730922126, 35.83852675543458, 36.28374291607745, 36.7235619187464, 37.158175412686774, 37.587763966482505, 38.01249794475496, 38.43253829764566, 38.84803727345823, 39.25913906340791, 39.665980386220134, 40.068691019298356, 40.4673942823108, 40.862207478304455, 41.25324229681833, 41.64060518292212, 42.024397675636, 42.404716718780236, 42.78165494695128, 43.15530094901437, 43.52573951123634, 43.89305184194875, 44.257315779427934, 44.61860598449934, 44.97699411921611, 45.33254901282301, 45.685336816094505, 46.035421145027016, 46.382863214769316, 46.72772196458972, 47.070054174602355, 47.409914574907226, 47.74735594773809, 48.082429223158016, 48.41518356879379, 48.745666474056954, 49.073923829259876, 49.400000000000006, 49.723937897153725, 50.04577904279242, 50.36556363230735, 50.68333059300662, 50.99911763942589, 51.312961325575436, 51.62489709432844, 51.93495932413928, 52.243181373266324, 52.549595621660124, 52.85423351066592, 53.15712558067828, 53.458301506875436, 53.75779013315187, 54.05561950435867, 54.351816896953885, 54.64640884815764, 54.93942118370015, 55.2308790442448, 55.52080691056282, 55.809228627530786, 56.09616742701769, 56.381645949723755, 56.665686266028764, 56.948309895904735], [0.0, 5.70372685180488, 8.066287869894056, 9.879144699820934, 11.40745370360976, 12.753920965726582, 13.97122041913304, 15.090642796117072, 16.132575739788113, 17.111180555414638, 18.03676800316509, 18.917121874111825, 19.758289399641868, 20.56507962542329, 21.341391707196603, 22.090439108356357, 22.81490740721952, 23.517068269663206, 24.19886360968217, 24.861968948576862, 25.507841931453164, 26.137760041748034, 26.752850315433683, 27.35411303625106, 27.94244083826608, 28.5186342590244, 29.083414517556225, 29.637434099462798, 30.181285592234143, 30.71550911184772, 31.24059858581458, 31.757007100795885, 32.265151479576225, 32.765416218934256, 33.25815689421168, 33.74370311628527, 34.222361110829276, 34.69441597721455, 35.160133674376155, 35.619762772932674, 36.07353600633018, 36.521671648488386, 36.96437474109362, 37.40183819012108, 37.83424374822365, 38.261762897179736, 38.684557642552925, 39.102781231007086, 39.516578799283735, 39.926087962634156, 40.33143934947029, 40.73275708812258, 41.13015925084658, 41.523758259579544, 41.91366125739913, 42.29997044916226, 42.68278341439321, 43.062193395134905, 43.43828956116942, 43.81115725474505, 44.18087821671271, 44.54753079576914, 44.911190142324216, 45.271928388351206, 45.62981481443904, 45.98491600514238, 46.3372959936162, 46.68701639642439, 47.03413653932641, 47.378713574769, 47.7208025917419, 48.06045671859559, 48.39772721936434, 48.73266358408907, 49.06531361359061, 49.395723499104655, 49.723937897153725, 50.05, 50.373951601993674, 50.695833162105146, 51.01568386290633, 51.33354166624392, 51.64944336582922, 51.96342463695017, 52.27552008349607, 52.585763282470296, 52.894186826153216, 53.20082236206504, 53.505700630867366, 53.80885150233184, 54.11030400949527, 54.41008638111137, 54.70822607250212, 55.004749794904086, 55.29968354339833, 55.59305262350683, 55.88488167653216, 56.17519470371243, 56.464015089258396, 56.75136562233548, 57.0372685180488, 57.32174543748647], [0.0, 5.740644563113101, 8.118497397917919, 9.943088051505933, 11.481289126226201, 12.836471477785478, 14.061649974309558, 15.188317879212303, 16.236994795835837, 17.221933689339302, 18.153512056899626, 19.03956407063986, 19.886176103011866, 20.698188326517858, 21.4795251344158, 22.233420789433193, 22.962578252452403, 23.669283892843065, 24.355492193753754, 25.02288952139621, 25.672942955570957, 26.306938248302487, 26.926009730370378, 27.53116415991159, 28.123299948619117, 28.703222815565507, 29.271658647914034, 29.829264154517798, 30.376635758424605, 30.914317071544705, 31.442805218364345, 31.96255621817505, 32.473989591671675, 32.97749232431114, 33.47342229291771, 33.96211124179414, 34.443867378678604, 34.918977648264566, 35.387709730922126, 35.85031380615796, 36.30702411379925, 36.758060340556604, 37.20362885526089, 37.643923812482676, 38.07912814127972, 38.509414433356426, 38.93494574286704, 39.355876308373574, 39.77235220602373, 40.184511941791705, 40.592486989589595, 40.996402281175854, 41.396376653035716, 41.792523254764134, 42.18494992292868, 42.573759523913324, 42.9590502688316, 43.3409160032411, 43.71944647408063, 44.09472757598124, 44.466841578866386, 44.8358673385494, 45.20188049185565, 45.564953637636904, 45.925156504904805, 46.282556109186544, 46.63721689809546, 46.98920088701233, 47.33856778568613, 47.68537511648619, 48.02967832496904, 48.37153088336155, 48.71098438750751, 49.04808864777506, 49.382891774378706, 49.71544025752966, 50.04577904279242, 50.37395160199367, 50.70000000000001, 51.023964957654954, 51.34588591114191, 51.66580106801791, 51.98374746014374, 52.299760993717754, 52.61387649660497, 52.92612776313795, 53.23654759655251, 53.54516784920933, 53.852019460740756, 54.157132494252316, 54.46053617069888, 54.76225890154643, 55.06232831982318, 55.36077130965573, 55.65761403437988, 55.952881963309096, 56.246599897238234, 56.53879199275487, 56.82948178542543, 57.11869221191957, 57.406445631131014, 57.692763844350544], [0.0, 5.777326371255133, 8.170373308484747, 10.006622806921426, 11.554652742510266, 12.918494494328666, 14.151501687100206, 15.285368821196304, 16.340746616969493, 17.3319791137654, 18.269510119321755, 19.16122386487878, 20.01324561384285, 20.830446466650688, 21.616775892810658, 22.375488821476058, 23.10930548502053, 23.820526862351304, 24.511119925454242, 25.182781816153675, 25.836988988657332, 26.475035410741196, 27.098062661378584, 27.707083931731255, 28.30300337420041, 28.886631856275663, 29.45869990342412, 30.019868420764276, 30.570737642392608, 31.111854653813236, 31.64371975605902, 32.166791882312424, 32.68149323393899, 33.188213269171335, 33.687312151609845, 34.17912374535076, 34.6639582275308, 35.142104376374505, 35.61383158268709, 36.079391624582584, 36.53902023864351, 36.99293851534371, 37.44135414217814, 37.88446251433429, 38.32244772975756, 38.755483482985994, 39.183733870063996, 39.60735411511352, 40.0264912276857, 40.44128459878593, 40.85186654242374, 41.258362788651716, 41.660892933301376, 42.05957084897563, 42.45450506130062, 42.845799093960196, 43.233551785621316, 43.617857581499806, 43.998806802003166, 44.376485890615534, 44.750977642952115, 45.12236141870237, 45.490713337999, 45.8561064635889, 46.21861097004106, 46.57829430110124, 46.935221316192816, 47.28945442696501, 47.64105372470261, 47.99007709933378, 48.33658035070334, 48.68061729271723, 49.022239850908484, 49.3614981539256, 49.69844061939972, 50.033114034607124, 50.36556363230735, 50.695833162105146, 51.023964957654954, 51.35, 51.673977977314664, 51.9959373412962, 52.3159153604331, 52.63394817035865, 52.95007082148239, 53.2643173240773, 53.57672069098668, 53.88731297810274, 54.19612532275717, 54.50318798015397, 54.80853035796527, 55.11218104920182, 55.41416786346251, 55.714517856659235, 56.01325735930736, 56.31041200346522, 56.60600674840082, 56.900065905058504, 57.19261315939323, 57.48367159463634, 57.773263712551326, 58.061411453735786], [0.0, 5.813776741499454, 8.221921916437786, 10.069756700139287, 11.627553482998907, 13.000000000000004, 14.24078649513432, 15.381807436059004, 16.443843832875572, 17.441330224498362, 18.38477631085024, 19.282116066448726, 20.139513400278574, 20.96187014557623, 21.753160689885963, 22.516660498395407, 23.255106965997815, 23.970815588961507, 24.66576574931336, 25.341665296503308, 26.000000000000007, 26.642071991494962, 27.269030052423947, 27.88189376638539, 28.48157299026864, 29.068883707497267, 29.644561052577593, 30.209270100417857, 30.76361487211801, 31.308145904859973, 31.843366656181313, 32.36973895477071, 32.887687665751145, 33.39760470452934, 33.89985250705377, 34.39476704383968, 34.882660448996724, 35.36382332271216, 35.83852675543458, 36.30702411379925, 36.76955262170048, 37.22633476451852, 37.677579540092545, 38.123483576399465, 38.56423213289745, 39.0, 39.43095230906807, 39.85724526356532, 40.27902680055715, 40.69643719049618, 41.10960958218894, 41.51867049894542, 41.92374029115246, 42.324933549859246, 42.72235948540296, 43.1161222746202, 43.506321379771926, 43.89305184194875, 44.276404551408646, 44.65646649702594, 45.03332099679081, 45.407047911089755, 45.77772384031343, 46.14542230817701, 46.51021393199563, 46.87216658103186, 47.23134552392087, 47.58781356608013, 47.941631177923014, 48.29285661461745, 48.64154602806124, 48.987753571683605, 49.33153149862672, 49.67293025381129, 50.011998560345496, 50.34878350069642, 50.683330593006616, 51.01568386290632, 51.345885911141906, 51.67397797731466, 52.000000000000014, 52.32399067349509, 52.64598750142313, 52.96602684740475, 53.284143982989924, 53.6003731330296, 53.914747518652085, 54.227299397996944, 54.538060104847894, 54.84706008529537, 55.15432893255071, 55.45989542002402, 55.76378753277078, 56.06603249740436, 56.36665681056488, 56.66568626602875, 56.96314598053728, 57.25906041841764, 57.5534534150645, 57.84634819934618, 58.137767414994535, 58.42773314103501], [0.0, 5.8500000000000005, 8.273149339882606, 10.132497224277934, 11.700000000000001, 13.080997668373772, 14.329514995281592, 15.477645169727857, 16.54629867976521, 17.55, 18.49932431198502, 19.40225502357909, 20.264994448555868, 21.09247496146434, 21.888695712627555, 22.656952575313387, 23.400000000000002, 24.120167909863316, 24.81944801964782, 25.49955881971294, 26.161995336747545, 26.80806781549167, 27.438932194967066, 28.055614411379416, 28.659029990563184, 29.25, 29.829264154517794, 30.3974916728338, 30.955290339455715, 31.503214121736853, 32.041769614052214, 32.57142152255563, 33.09259735953042, 33.60569148224747, 34.11106858484501, 34.609066731132756, 35.1, 35.58416080224459, 36.06182191736852, 36.533238290630635, 36.99864862397004, 37.45827678898217, 37.91233308568599, 38.3610153671667, 38.80451004715818, 39.242993005121306, 39.67663040128282, 40.10557941234611, 40.529988897111735, 40.95, 41.36574669941304, 41.777356306975676, 42.18494992292868, 42.58864285229104, 42.98854498584478, 43.38476114950963, 43.77739142525511, 44.16653144633389, 44.55227266930387, 44.934702625031356, 45.31390515062677, 45.68996060405393, 46.0629460629691, 46.432935509183565, 46.800000000000004, 47.16420782754651, 47.52562466712037, 47.884313715453835, 48.24033581972663, 48.593749598070744, 48.94461155224342, 49.2929761730817, 49.63889603929564, 49.98242191010756, 50.32360281219937, 50.66248612138966, 50.99911763942588, 51.33354166624392, 51.66580106801791, 51.9959373412962, 52.32399067349509, 52.650000000000006, 52.97400305810389, 53.296036437994154, 53.61613563098334, 53.934335075163396, 54.250668198649876, 54.56516746056957, 54.87786438993413, 55.18878962253113, 55.49797293595506, 55.80544328289133, 56.11122882275883, 56.415356951808796, 56.71785433177105, 57.01874691713243, 57.31805998112637, 57.61581814050722, 57.91204537917824, 58.206765070737276, 58.5, 58.791772383557216], [0.0, 5.886000339789321, 8.324061508662703, 10.194851641882781, 11.772000679578642, 13.161496875355786, 14.417697458332244, 15.572893115924224, 16.648123017325407, 17.658001019367966, 18.61316738225926, 19.521654642985574, 20.389703283765563, 21.222276032508866, 22.023396649926642, 22.796381291775237, 23.544001359157285, 24.268601113372814, 24.972184525988112, 25.65648066278772, 26.32299375071157, 26.973042097620365, 27.607788756073898, 28.22826597579101, 28.835394916664487, 29.430001698946608, 30.012830589599517, 30.584554925648344, 31.145786231848447, 31.697081884615187, 32.23895159585684, 32.771862931484385, 33.296246034650814, 33.81249768946388, 34.320984834354626, 34.822047613545074, 35.31600203873593, 35.803142320193075, 36.28374291607745, 36.758060340556604, 37.22633476451852, 37.68879143724299, 38.145641952915156, 38.59708538218916, 39.04330928597115, 39.48449062606735, 39.920796585238634, 40.352385307438766, 40.779406567531126, 41.20200237852525, 41.62030754331352, 42.03445015698434, 42.44455206501773, 42.850729282008736, 43.25309237499673, 43.651746814990126, 44.046793299853285, 44.438328051356756, 44.82644308887334, 45.21122648192593, 45.592762583550474, 45.971132246226006, 46.34641302193731, 46.71867934777267, 47.08800271831457, 47.45445184595435, 47.81809281014876, 48.178989196536705, 48.53720222674563, 48.89279087963788, 49.24581200467711, 49.59632042803176, 49.944369051976224, 50.29000894810022, 50.63328944479116, 50.974258209413904, 51.31296132557544, 51.64944336582922, 51.983747460143746, 52.3159153604331, 52.64598750142314, 52.9740030581039, 53.300000000000004, 53.624015142471386, 53.94608419524073, 54.266241808328694, 54.584521615564256, 54.90095627582456, 55.215577512147796, 55.528416148851214, 55.83950214677778, 56.148864636784964, 56.45653195158202, 56.76253165601409, 57.06689057588472, 57.369634825402194, 57.670789833328975, 57.97038036790859, 58.268430560638926, 58.564963928956715, 58.860003397893216, 59.15357132075798], [0.0, 5.921781826443794, 8.37466417237133, 10.256826994738676, 11.843563652887587, 13.241506711851187, 14.505343842873907, 15.667562031152135, 16.74932834474266, 17.765345479331383, 18.726318378154314, 19.640328408659567, 20.51365398947735, 21.351288017353895, 22.157278713777103, 22.934962393690554, 23.687127305775174, 24.41613196229083, 25.123992517113994, 25.812448547164216, 26.483013423702374, 27.137013468692537, 27.77561880498795, 28.399867957439525, 29.010687685747815, 29.60890913221897, 30.19528108827603, 30.77048098421603, 31.33512406230427, 31.88977108729381, 32.43493486967408, 32.97108581772824, 33.49865668948532, 34.01804668113677, 34.529624961762906, 35.03373374335085, 35.53069095866277, 36.020792606493266, 36.50431481345733, 36.9815156530935, 37.45263675630863, 37.91790474169162, 38.377532489726335, 38.831720281234, 39.280656817319134, 39.724520135553554, 40.16347843501606, 40.597690821030696, 41.0273079789547, 41.45247278510656, 41.87332086185666, 42.28998108299412, 42.70257603470779, 43.11122243685512, 43.516031528621724, 43.91710942218306, 44.314557427554206, 44.70847235144587, 45.0989467726243, 45.48606929599435, 45.86992478738111, 46.25059459077256, 46.62815672959848, 47.002686093456404, 47.37425461155035, 47.74293141398002, 48.10878298190467, 48.47187328750561, 48.83226392458166, 49.190014230532604, 49.54518140041471, 49.897820593689254, 50.24798503422799, 50.59572610408907, 50.94109343153128, 51.28413497369337, 51.62489709432843, 51.963424636950165, 52.29976099371775, 52.63394817035864, 52.96602684740475, 53.296036437994154, 53.62401514247138, 53.95, 54.274026937385074, 54.59613081528764, 54.916345471999506, 55.23470376493387, 55.5512376099759, 55.865978018826446, 56.17895513446294, 56.490198264831754, 56.79973591487905, 57.107595817018954, 57.41380496013132, 57.718389617174864, 58.02137537149563, 58.32278714190536, 58.62264920659931, 58.920985225978704, 59.21781826443794, 59.51317081117423], [0.0, 5.957348403442592, 8.424962907930219, 10.318430113151905, 11.914696806885184, 13.321035995747481, 14.59246380841837, 15.761662348876786, 16.849925815860438, 17.872045210327776, 18.838789770046272, 19.758289399641868, 20.63686022630381, 21.479525134415802, 22.29035665932692, 23.072711154088502, 23.829393613770367, 24.56277671599854, 25.274888723790653, 25.967479662069636, 26.642071991494962, 27.300000000000004, 27.942440838266084, 28.57043926858669, 29.18492761683674, 29.786742017212962, 30.376635758424605, 30.955290339455715, 31.523324697753573, 32.081302966057976, 32.629741034828946, 33.169112137649996, 33.699851631720875, 34.22236111082928, 34.73701196130721, 35.244148450487494, 35.74409042065555, 36.237135648392524, 36.72356191874639, 37.20362885526088, 37.677579540092545, 38.14564195291515, 38.608030252785504, 39.06494592342347, 39.516578799283735, 39.96310798724243, 40.40470269659214, 40.841522988253026, 41.27372045260762, 41.70143882409815, 42.1248145396511, 42.54397724707929, 42.959050268831604, 43.37015102579193, 43.77739142525512, 44.18087821671271, 44.58071331865384, 44.97699411921611, 45.36981375319939, 45.7592613576749, 46.145422308177004, 46.52837843725053, 46.90820823693866, 47.284987046630356, 47.658787227540735, 48.029678324969034, 48.39772721936434, 48.76299826712874, 49.12555343199708, 49.48545240775314, 49.84275273297012, 50.19750989840034, 50.549777447581306, 50.89960707117493, 51.24704869551026, 51.59215056575952, 51.93495932413927, 52.27552008349606, 52.61387649660497, 52.950070821482385, 53.284143982989924, 53.61613563098334, 53.94608419524072, 54.274026937385074, 54.60000000000001, 54.92403845312179, 55.24617633827703, 55.56644671022253, 55.88488167653217, 56.20151243516494, 56.51636931013881, 56.829481785425436, 57.14087853717338, 57.45058746435933, 57.75863571795996, 58.06504972873096, 58.36985523367348, 58.67307730126315, 58.97474035551153, 59.274868198925596, 59.573484034425924, 59.87061048628117], [0.0, 5.992703897240377, 8.474963126763443, 10.379667624736355, 11.985407794480754, 13.4000932832574, 14.67906672782708, 15.85520419294561, 16.949926253526886, 17.978111691721132, 18.95059365824723, 19.875550306846854, 20.75933524947271, 21.60700118017306, 22.422644803858443, 23.209642392764263, 23.970815588961507, 24.708551151372678, 25.42488938029033, 26.12159068663316, 26.8001865665148, 27.462019226560894, 28.108272803571555, 28.739998260264393, 29.35813345565416, 29.963519486201886, 30.556914111212215, 31.139002874209062, 31.71040838589122, 32.27169812699667, 32.82339104967675, 33.36596319604756, 33.89985250705377, 34.42546295984994, 34.94316814486059, 35.45331437256607, 35.956223383442264, 36.45219472130588, 36.94150781979534, 37.424423843260435, 37.90118731649446, 38.372027572178155, 38.83716004035311, 39.296787400498786, 39.75110061369371, 40.200279849772194, 40.64449532224506, 41.08390804195726, 41.51867049894542, 41.94892728068264, 42.37481563381722, 42.796465975591964, 43.21400236034612, 43.62754290582958, 44.03720018348125, 44.443081576326364, 44.845289607716886, 45.243922243766626, 45.6390731720091, 46.03083205852355, 46.419284785528525, 46.8045136712262, 47.186597673491995, 47.56561257883683, 47.941631177923014, 48.31472342878514, 48.68495660879241, 49.05239545628736, 49.417102302745356, 49.77913719621907, 50.138558016759916, 50.49542058444508, 50.84977876058066, 51.20168454260075, 51.55118815313571, 51.89833812368177, 52.24318137326632, 52.58576328247029, 52.92612776313794, 53.26431732407729, 53.6003731330296, 53.934335075163396, 54.26624180832869, 54.59613081528764, 54.92403845312179, 55.25000000000001, 55.57404969947755, 55.8962208024836, 56.21654560714311, 56.53505549656779, 56.85178097474168, 57.16675170061704, 57.479996520528786, 57.79154349902762, 58.10141994822502, 58.40965245573714, 58.71626691130832, 59.021288532189814, 59.3247418873441, 59.62665092054056, 59.92703897240377, 60.22592880147222], [0.0, 6.027852022072207, 8.5246700815926, 10.44054596273586, 12.055704044144415, 13.478686879663021, 14.76516169908071, 15.948197390300889, 17.0493401631852, 18.083556066216623, 19.061741788199736, 19.992123448998612, 20.88109192547172, 21.733729546490636, 22.554157044766715, 23.345770494888363, 24.11140808828883, 24.85347058259671, 25.574010244777803, 26.27479781083006, 26.957373759326043, 27.623088169138516, 28.273132122211013, 28.908562745318218, 29.53032339816142, 30.139260110361036, 30.736135085595915, 31.321637888207576, 31.896394780601778, 32.460976571877815, 33.015905257920764, 33.56165967290653, 34.0986803263704, 34.62737356485473, 35.148115169949016, 35.66125348329753, 36.167112132433246, 36.66599241804318, 37.15817541268678, 37.643923812482676, 38.12348357639947, 38.597085382189164, 39.06494592342347, 39.527269068328, 39.984246897997224, 40.436060638989055, 40.88288150314261, 41.324871445656065, 41.76218385094344, 42.194964154505456, 42.62335040796301, 43.04747379347597, 43.46745909298127, 43.883425117007455, 44.295485097242135, 44.70374704652844, 45.10831408953343, 45.50928476695717, 45.9067533158249, 46.300809928121126, 46.691540989776726, 47.079029301802734, 47.46335428517458, 47.84459217090266, 48.22281617657766, 48.598096670548735, 48.970501324777146, 49.3400952573057, 49.70694116519342, 50.071099448683974, 50.432628327304144, 50.791583948524384, 51.148020489555606, 51.501990252804795, 51.853543755465736, 52.202729813679284, 52.54959562166012, 52.89418682615321, 53.23654759655251, 53.576720690986676, 53.914747518652085, 54.250668198649876, 54.58452161556425, 54.916345471999506, 55.24617633827703, 55.57404969947755, 55.900000000000006, 56.224060685795365, 56.54626424442203, 56.86664224305845, 57.185225364599205, 57.50204344195083, 57.817125490636435, 58.13049973980958, 58.44219366177146, 58.752234000078666, 59.06064679632284, 59.36745741565829, 59.6726905711482, 59.976370346995836, 60.27852022072207, 60.57916308434775], [0.0, 6.06279638450773, 8.574088872877397, 10.501071373912286, 12.12559276901546, 13.55682484949924, 14.85075755643462, 16.040651483028988, 17.148177745754793, 18.18838915352319, 19.172245564878413, 20.108020787735427, 21.00214274782457, 21.85972323704031, 22.68490687659969, 23.481109428644977, 24.25118553803092, 24.997549879938234, 25.72226661863219, 26.42711675533296, 27.11364969899848, 27.783223355111268, 28.437035710495568, 29.07615002024856, 29.70151511286924, 30.313981922538648, 30.9143170715447, 31.503214121736853, 32.081302966057976, 32.64915772267334, 33.20730341355648, 33.75622164875684, 34.29635549150959, 34.828113644008916, 35.351874066306586, 35.867987119435625, 36.37677830704638, 36.87855067651114, 37.373586929809136, 37.86215128594782, 38.344491129756825, 38.82083847626169, 39.29141127523928, 39.75641457676987, 40.216041575470854, 40.67047454849771, 41.11988570023025, 41.564437924745235, 42.00428549564914, 42.43957469155411, 42.87044436438699, 43.29702645679031, 43.71944647408062, 44.1378239155489, 44.55227266930387, 44.96290137435528, 45.36981375319938, 45.77310891779146, 46.17288165146291, 46.56922266905472, 46.962218857289955, 47.351953497189534, 47.7385064701442, 48.12195444908696, 48.50237107606184, 48.87982712735388, 49.25439066722885, 49.62612719122861, 49.99509975987647, 50.36136912356534, 50.72499383932935, 51.086030380134254, 51.44453323726438, 51.800555016331636, 52.15414652738553, 52.50535686956142, 52.85423351066592, 53.20082236206505, 53.545167849209335, 53.88731297810274, 54.22729939799696, 54.565167460569576, 54.90095627582456, 55.234703764933876, 55.566446710222536, 55.896220802483604, 56.22406068579537, 56.55, 56.874071420991136, 57.19630669894692, 57.51673669463524, 57.835391413908496, 58.15230004049712, 58.46749096720331, 58.78099182558933, 59.092829514248166, 59.40303022573848, 59.71161947226018, 60.01862211014178, 60.32406236320629, 60.627963845077296, 60.93034958048412], [0.0, 6.097540487770458, 8.623224454924038, 10.56124992602675, 12.195080975540916, 13.634515026211973, 14.935862880998874, 16.132575739788116, 17.246448909848077, 18.292621463311377, 19.282116066448726, 20.223253941935262, 21.1224998520535, 21.984994882874094, 22.81490740721952, 23.615672761960436, 24.390161951081833, 25.140803487557832, 25.86967336477212, 26.578562790339138, 27.269030052423947, 27.942440838266084, 28.600000000000005, 29.242776885925185, 29.871725761997748, 30.487702438852292, 31.09147793206364, 31.68374977808025, 32.26515147957623, 32.83626044481923, 33.397604704529336, 33.949668628721554, 34.492897819696154, 35.02770332179945, 35.5544652610611, 36.07353600633018, 36.585242926622755, 37.08989080598648, 37.5877639664825, 38.07912814127971, 38.56423213289745, 39.04330928597114, 39.51657879928373, 39.98424689799722, 40.446507883870524, 40.90354507863591, 41.35553167352585, 41.80263149611517, 42.244999704107, 42.68278341439321, 43.1161222746202, 43.545148983554995, 43.96998976574819, 44.39076480530608, 44.80758864299663, 45.22057054040783, 45.62981481443904, 46.035421145027016, 46.43748485867856, 46.83609719009473, 47.23134552392087, 47.62331361843693, 48.01208181281041, 48.39772721936434, 48.780323902163666, 49.159943043091495, 49.53665309646989, 49.91051993317642, 50.281606975115665, 50.64997532082321, 51.01568386290632, 51.37878939796071, 51.73934672954424, 52.09740876473609, 52.45302660476324, 52.80624963013374, 53.157125580678276, 53.50570063086736, 53.852019460740756, 54.19612532275716, 54.538060104847894, 54.87786438993413, 55.21557751214779, 55.55123760997589, 55.88488167653217, 56.216545607143104, 56.54626424442203, 56.87407142099113, 57.20000000000001, 57.524081913577724, 57.846348199346174, 58.16682903511245, 58.48555377185037, 58.802550965072946, 59.11784840469078, 59.43147314344479, 59.743451523995496, 60.05380920474572, 60.36257118446827, 60.669761825805786, 60.975404877704584, 61.27952349684192], [0.0, 6.132087735836792, 8.672081641682116, 10.621087514939326, 12.264175471673584, 13.711765021323842, 15.020486010778745, 16.22397916665329, 17.34416328336423, 18.396263207510376, 19.391364057229186, 20.33783420131062, 21.242175029878652, 22.109556757203435, 22.944171373139625, 23.749473678378642, 24.528350943347167, 25.28324544040974, 26.016244925046347, 26.729150753437715, 27.423530042647684, 28.100756217582475, 28.762040956788866, 29.408459667245413, 30.04097202155749, 30.66043867918396, 31.267635024094805, 31.863262544817974, 32.44795833330658, 33.0223030692894, 33.58682777518591, 34.14201956533913, 34.68832656672846, 35.22616215258199, 35.755908602635174, 36.27792028217714, 36.79252641502075, 37.30003351204929, 37.80072750622665, 38.294875636304134, 38.78272811445837, 39.26451960740128, 39.740470555845214, 40.21078835337601, 40.67566840262124, 41.13529506397152, 41.589842509920615, 42.03947549625232, 42.484350059757304, 42.92461415085754, 43.36040820841058, 43.79186568302383, 44.21911351440687, 44.64227256760122, 45.06145803233624, 45.476779789250685, 45.88834274627925, 46.29624714812206, 46.70058886138375, 47.101459637680016, 47.498947356757284, 47.89313625145048, 48.28410711611016, 48.67193749995987, 49.056701886694334, 49.43847186149669, 49.81731626653527, 50.19330134589674, 50.56649088081948, 50.93694631600917, 51.3047268777449, 51.66988968441871, 52.032489850092695, 52.39258058160525, 52.75021326971105, 53.10543757469662, 53.45830150687543, 53.80885150233184, 54.157132494252316, 54.50318798015397, 54.84706008529537, 55.18878962253113, 55.528416148851214, 55.865978018826446, 56.20151243516495, 56.53505549656779, 56.86664224305846, 57.19630669894691, 57.52408191357773, 57.849999999999994, 58.17409217168756, 58.49638877742797, 58.81691933449083, 59.13571256017806, 59.452796401851444, 59.76819806552644, 60.08194404311498, 60.39406013839441, 60.704571491774814, 61.01350260393187, 61.32087735836792, 61.62671904296058], [0.0, 6.16644143732834, 8.72066511224918, 10.68058987135074, 12.33288287465668, 13.788582233137678, 15.104635050208925, 16.314870517414477, 17.44133022449836, 18.49932431198502, 19.5, 20.451772539317957, 21.36117974270148, 22.233420789433193, 23.072711154088502, 23.882524992135984, 24.66576574931336, 25.42488938029033, 26.161995336747538, 26.878895066575936, 27.577164466275356, 28.258184655069407, 28.92317409967309, 29.573214231801053, 30.20927010041785, 30.832207186641696, 31.44280521836435, 32.04176961405222, 32.62974103482895, 33.20730341355649, 33.77499074759311, 34.33329288023507, 34.88266044899672, 35.42350914294065, 35.956223383442264, 36.481159521045925, 36.99864862397004, 37.508998920259124, 38.01249794475496, 38.509414433356426, 39.0, 39.48449062606735, 39.96310798724244, 40.436060638989055, 40.903545078635915, 41.36574669941303, 41.82284064957807, 42.27499260792366, 42.72235948540296, 43.16509006129838, 43.6033255612459, 44.03720018348125, 44.466841578866386, 44.89237128956322, 45.31390515062678, 45.731553658278436, 46.145422308177004, 46.555611906621955, 46.962218857289955, 47.36533542581536, 47.76504998427197, 48.16144723739103, 48.55460843215606, 48.944611552243416, 49.33153149862672, 49.71544025752965, 50.09640705679401, 50.47449851162466, 50.84977876058066, 51.22230959259842, 51.59215056575952, 51.959359118449484, 52.323990673495075, 52.686098735814554, 53.045734984068226, 53.402949356753695, 53.75779013315187, 54.110304009495266, 54.46053617069887, 54.80853035796527, 55.15432893255071, 55.49797293595506, 55.839502146777775, 56.17895513446294, 56.51636931013881, 56.851780974741686, 57.185225364599205, 57.51673669463524, 57.84634819934618, 58.17409217168756, 58.5, 58.824102203093595, 59.146428463602106, 59.46700765970994, 59.78586789534798, 60.10303652894751, 60.4185402008357, 60.73240485935001, 61.044655785744254, 61.35531761795387, 61.66441437328339, 61.97196947007575], [0.0, 6.200604809210147, 8.768979416100827, 10.739762567207901, 12.401209618420294, 13.864973855006005, 15.188317879212299, 16.405258303361155, 17.537958832201653, 18.60181442763044, 19.608034067697865, 20.56507962542329, 21.479525134415802, 22.35659857849579, 23.20053878684717, 24.014839162484513, 24.80241923684059, 25.565748571086278, 26.30693824830248, 27.02780975217933, 27.72994771001201, 28.414740892712715, 29.083414517556225, 29.737056007614477, 30.376635758424598, 31.003024046050733, 31.617004918239807, 32.2192877016237, 32.81051660672231, 33.39127880150744, 33.96211124179414, 34.523506484712705, 35.075917664403306, 35.619762772932674, 36.15542836145079, 36.6832727547584, 37.20362885526088, 37.71680659865042, 38.22309511277181, 38.72276462237685, 39.21606813539573, 39.703242940596176, 40.184511941791705, 40.66008484988687, 41.13015925084658, 41.594921565018005, 42.05454791101671, 42.50920488553038, 42.959050268831604, 43.40423366447103, 43.84489708050414, 44.28117545865286, 44.71319715699158, 45.14108439105114, 45.564953637636904, 45.98491600514238, 46.40107757369434, 46.813539708080185, 47.22239934607305, 47.627749264478155, 48.02967832496903, 48.42827170155879, 48.8236110913562, 49.215774910083454, 49.60483847368118, 49.990874167191755, 50.37395160199367, 50.75413776235392, 51.131497142172556, 51.50609187270958, 51.87798184201078, 52.24722480668231, 52.61387649660496, 52.97799071312539, 53.33961942121447, 53.698812836039494, 54.05561950435866, 54.41008638111136, 54.762258901546424, 55.112181049201816, 55.45989542002402, 55.805443282891325, 56.14886463678496, 56.490198264831754, 56.82948178542543, 57.166751700617034, 57.50204344195083, 57.83539141390849, 58.16682903511245, 58.49638877742796, 58.82410220309359, 59.150000000000006, 59.474112015228954, 59.796467286956016, 60.1170940748137, 60.436019888804715, 60.753271516849196, 61.06887505104381, 61.382855912705786, 61.69523887626987, 62.006048092101466, 62.31530710828601], [0.0, 6.234580980306536, 8.817028978062849, 10.7986110217935, 12.469161960613071, 13.940946883192694, 15.27154216181195, 16.49515080258438, 17.634057956125698, 18.703742940919607, 19.715476154534034, 20.67776583676293, 21.597222043587, 22.47910140552776, 23.32766597840427, 24.146428307308724, 24.938323921226143, 25.705835913270747, 26.451086934188545, 27.17590844847694, 27.88189376638539, 28.57043926858669, 29.242776885925185, 29.900000000000006, 30.5430843236239, 31.17290490153268, 31.790250077657465, 32.3958330653805, 32.99030160516876, 33.574246082376895, 34.148206395065614, 34.712677799328596, 35.268115912251396, 35.814941016285374, 36.353541780684864, 36.88427849368888, 37.407485881839214, 37.92347557911854, 38.432538297645664, 38.93494574286704, 39.43095230906807, 39.920796585238634, 40.404702696592146, 40.882881503142606, 41.35553167352586, 41.822840649578076, 42.284985514955544, 42.74213377921135, 43.194444087174, 43.642066862145754, 44.08514489031425, 44.52381385281365, 44.95820281105552, 45.38843465024984, 45.81462648543586, 46.23689003382473, 46.65533195680854, 47.070054174602355, 47.48115415614916, 47.88872518662404, 48.29285661461745, 48.69363408085292, 49.091139730097936, 49.48545240775313, 49.876647842452286, 50.26479881587113, 50.64997532082321, 51.03224470861536, 51.41167182654149, 51.78831914630944, 52.16224688412109, 52.533513113059556, 52.90217386837709, 53.26828324622449, 53.6318934963143, 53.99305510896749, 54.35181689695388, 54.708226072502114, 55.06232831982317, 55.4141678634625, 55.76378753277078, 56.111228822758825, 56.456531951582015, 56.799735914879044, 57.14087853717338, 57.479996520528786, 57.817125490636435, 58.15230004049711, 58.48555377185037, 58.81691933449082, 59.1464284636021, 59.474112015228954, 59.80000000000001, 60.12412161520533, 60.44650527532589, 60.76717864110526, 61.0861686472478, 61.40350152882164, 61.71920284643994, 62.03329751028879, 62.34580980306536, 62.65676340188664], [0.0, 6.268372994645421, 8.864818103040806, 10.857140507518546, 12.536745989290843, 14.01650812435109, 15.354315354323031, 16.584556068824998, 17.72963620608161, 18.805118983936264, 19.82233588656998, 20.78984126923532, 21.71428101503709, 22.600940245927827, 23.45410411846933, 24.27730421607803, 25.073491978581686, 25.845163957692357, 26.59445430912242, 27.323204424078817, 28.03301624870218, 28.725293732179665, 29.401275482536473, 30.06206080760267, 30.708630708646062, 31.341864973227107, 31.962556218175045, 32.57142152255563, 33.169112137649996, 33.75622164875684, 34.33329288023507, 34.90082377251288, 35.45927241216322, 36.00906135960781, 36.55058139072483, 37.08419474654937, 37.61023796787253, 38.12902437776241, 38.640846264024816, 39.14597680477523, 39.64467177313996, 40.13717105128362, 40.623699979199344, 41.10447055978218, 41.57968253847064, 42.04952437305326, 42.514174106996364, 42.97380015777055, 43.42856203007418, 43.878610962517946, 44.324090515204034, 44.76513710467109, 45.201880491855654, 45.634444228017074, 46.062946062969104, 46.48749831944068, 46.90820823693866, 47.32517828809523, 47.73850647014421, 48.14828657387508, 48.55460843215606, 48.957558149891426, 49.35721831708104, 49.75366820647499, 50.14698395716337, 50.53723874530543, 50.924502943082324, 51.30884426685131, 51.690327915384714, 52.06901669899289, 52.44497116025521, 52.818249687016326, 53.18890861824484, 53.55700234329775, 53.92258339508596, 54.28570253759272, 54.646408848157634, 55.00474979490408, 55.36077130965573, 55.714517856659235, 56.06603249740436, 56.415356951808796, 56.76253165601408, 57.107595817018954, 57.45058746435933, 57.79154349902762, 58.13049973980958, 58.467490967203304, 58.802550965072946, 59.13571256017805, 59.467007659709935, 59.796467286956016, 60.12412161520534, 60.45000000000001, 60.774131009830164, 61.09654245536321, 61.417261417292124, 61.73631427288158, 62.05372672128564, 62.36952380770597, 62.683729946454214, 62.99636894297957], [0.0, 6.301983814641228, 8.912350980521357, 10.915356155435335, 12.603967629282456, 14.091664202641223, 15.436644713149292, 16.67348193989486, 17.824701961042713, 18.905951443923684, 19.92862263178266, 20.901315748057588, 21.83071231087067, 22.7221257808331, 23.579864291382172, 24.407478362174164, 25.207935258564913, 25.98374491869869, 26.737052941564073, 27.469710591850074, 28.183328405282445, 28.879317858979984, 29.558924202345395, 30.22325263766295, 30.873289426298584, 31.50991907320614, 32.13393844520152, 32.746068466306, 33.34696387978972, 33.937221453737195, 34.51738692311456, 35.08796089829103, 35.649403922085426, 36.20214082067524, 36.74656446526669, 37.283039039219965, 37.81190288784737, 38.333471014245504, 38.84803727345824, 39.355876308373574, 39.85724526356532, 40.35238530743877, 40.841522988253026, 41.324871445656065, 41.802631496115175, 42.27499260792366, 42.74213377921135, 43.20422433049806, 43.66142462174134, 44.1138867024886, 44.56175490260679, 45.005166370095786, 45.4442515616662, 45.87913469105538, 46.30993413944788, 46.73676283184363, 47.159728582764345, 47.578934414297265, 47.99447884913431, 48.406456180968256, 48.81495672434833, 49.220067045870636, 49.62187017838002, 50.020445819684575, 50.415870517129825, 50.80821783924329, 51.197558535539564, 51.583960685468895, 51.96748983739738, 52.348209138422305, 52.72617945575045, 53.101459490300265, 53.474105883128146, 53.84417331522512, 54.21171460118191, 54.576780777176666, 54.93942118370015, 55.29968354339833, 55.65761403437989, 56.01325735930736, 56.36665681056489, 56.71785433177106, 57.06689057588472, 57.41380496013133, 57.75863571795997, 58.10141994822503, 58.44219366177147, 58.78099182558933, 59.11784840469079, 59.452796401851444, 59.785867895347984, 60.11709407481371, 60.4465052753259, 60.77413100983017, 61.1, 61.424140205622734, 61.74657885259717, 62.06734245962205, 62.3864568636495, 62.70394724417277, 63.01983814641228, 63.334153503461316], [0.0, 6.335416324125826, 8.959631688858643, 10.973262960487187, 12.670832648251652, 14.166421566507191, 15.518537302207317, 16.761936045695915, 17.919263377717286, 19.006248972377477, 20.03434550964917, 21.012198837817998, 21.946525920974373, 22.842668408047253, 23.704957287453606, 24.536961914629934, 25.341665296503304, 26.12159068663315, 26.87889506657593, 27.6154395221224, 28.332843133014382, 29.032524864365485, 29.7157365717224, 30.383589320552634, 31.037074604414634, 31.67708162062913, 32.30441146345186, 32.91978888146156, 33.52387209139183, 34.11726102722785, 34.70050431910175, 35.274105233159354, 35.83852675543457, 36.39419596584049, 36.94150781979533, 37.480828432680084, 38.012497944754955, 38.53683303023226, 39.05412910307948, 39.56466226318632, 40.06869101929834, 40.566457819237804, 41.05819041311977, 41.54410307131446, 42.024397675635996, 42.49926469952156, 42.96888409069986, 43.43342606794909, 43.89305184194875, 44.347914268880785, 44.79815844429322, 45.24392224376662, 45.685336816094505, 46.12252703397766, 46.555611906621955, 46.984704958103116, 47.40991457490721, 47.8313443256616, 48.24909325572865, 48.66325615903645, 49.07392382925987, 49.48118329223746, 49.885118021309715, 50.28580813708774, 50.68333059300661, 51.07775934788056, 51.4691655265558, 51.8576175696493, 52.2431813732663, 52.625920419504304, 53.005895898475295, 53.383166822510624, 53.75779013315186, 54.12982080147689, 54.49931192226191, 54.86631480243592, 55.2308790442448, 55.59305262350683, 55.952881963309096, 56.31041200346522, 56.665686266028764, 57.01874691713244, 57.36963482540219, 57.71838961717487, 58.06504972873097, 58.409652455737145, 58.75223400007867, 59.092829514248166, 59.4314731434448, 59.76819806552645, 60.10303652894751, 60.43601988880472, 60.76717864110527, 61.09654245536322, 61.424140205622734, 61.749999999999986, 62.07414920882927, 62.39661449149305, 62.7174218220105, 63.03659651345399, 63.35416324125826, 63.67014606548347], [0.0, 6.368673331236264, 9.00666419935816, 11.030865786510143, 12.737346662472527, 14.240786495134321, 15.6, 16.849925815860438, 18.01332839871632, 19.106019993708788, 20.139513400278567, 21.1224998520535, 22.061731573020285, 22.962578252452403, 23.829393613770367, 24.66576574931336, 25.474693324945054, 26.258712839741403, 27.019992598074484, 27.760403455281413, 28.481572990268642, 29.18492761683675, 29.871725761997755, 30.543084323623905, 31.2, 31.843366656181317, 32.473989591671675, 33.09259735953043, 33.699851631720875, 34.296355491509594, 34.88266044899672, 35.45927241216323, 36.02665679743264, 36.585242926622755, 37.13542782842282, 37.67757954009254, 38.212039987417576, 38.73912750695349, 39.2591390634079, 39.772352206023726, 40.27902680055713, 40.77940656753112, 41.27372045260762, 41.76218385094342, 42.244999704107, 42.722359485402954, 43.19444408717399, 43.66142462174133, 44.12346314604057, 44.58071331865384, 45.03332099679081, 45.48142477979335, 45.925156504904805, 46.364641700330225, 46.800000000000004, 47.23134552392087, 47.658787227540735, 48.082429223158016, 48.50237107606184, 48.918708077789624, 49.33153149862672, 49.74092882124338, 50.146983957163364, 50.54977744758131, 50.94938664989011, 51.3458859111419, 51.73934672954424, 52.129837904984896, 52.517425679482805, 52.9021738683771, 53.28414398298992, 53.66339534543076, 54.03998519614897, 54.41396879478651, 54.78539951483424, 55.154328932550705, 55.520806910562825, 55.88488167653216, 56.24659989723824, 56.60600674840083, 56.963145980537284, 57.318059981126375, 57.670789833328975, 58.02137537149564, 58.3698552336735, 58.716266911308324, 59.06064679632286, 59.40303022573848, 59.74345152399551, 60.08194404311498, 60.41854020083571, 60.7532715168492, 61.08616864724781, 61.41726141729214, 61.74657885259717, 62.07414920882927, 62.4, 62.72415802543707, 63.04664939550713, 63.3674995561605, 63.686733312362634, 64.0043748504741], [0.0, 6.401757571167469, 9.053452380169677, 11.08816937100079, 12.803515142334938, 14.31476510460441, 15.681039506359266, 16.937458487034, 18.106904760339354, 19.205272713502406, 20.24413495311667, 21.232227862379403, 22.17633874200158, 23.08186517593412, 23.953183504494763, 24.793900459588848, 25.607030284669875, 26.39512265552104, 27.160357140509035, 27.90461431376539, 28.62953020920882, 29.336538650631578, 30.02690460237286, 30.70175076441082, 31.36207901271853, 32.00878785583734, 32.64268677667328, 33.26450811300237, 33.874916974068, 34.474519576057915, 35.06387029407906, 35.64347766422351, 36.21380952067871, 36.77529741552066, 37.3283404399392, 37.87330854308876, 38.41054542700481, 38.94037108195042, 39.46308401531741, 39.97896321817264, 40.48826990623334, 40.99124906611166, 41.48813083280567, 41.979131720415566, 42.46445572475881, 42.94429531381322, 43.418832319628315, 43.88823874342647, 44.35267748400316, 44.81230299817228, 45.267261900848396, 45.71769351137479, 46.16373035186824, 46.60549860263273, 47.0431185190778, 47.476704814045384, 47.90636700898953, 48.332209757055395, 48.754333140757865, 49.172832946658666, 49.587800919177695, 49.99932499544369, 50.407489522887374, 50.812375461102, 51.21406056933975, 51.612619580873826, 52.00812436533354, 52.400644080011084, 52.79024531104208, 53.17699220527616, 53.560946593576936, 53.9421681062228, 54.32071428101807, 54.696640664669715, 55.07000090793535, 55.44084685500394, 55.80922862753078, 56.17519470371243, 56.53879199275486, 56.9000659050585, 57.25906041841764, 57.61581814050722, 57.97038036790858, 58.32278714190536, 58.673077301263156, 59.02128853218982, 59.3674574156583, 59.711619472260175, 60.05380920474572, 60.39406013839441, 60.73240485935001, 61.06887505104381, 61.40350152882164, 61.73631427288158, 62.06734245962204, 62.39661449149305, 62.72415802543706, 63.05000000000001, 63.37416666118774, 63.6966835871382, 64.01757571167468, 64.33686734680204], [0.0, 6.434671708797582, 9.1, 11.145178329663462, 12.869343417595164, 14.388363353766128, 15.761662348876783, 17.024541109821435, 18.2, 19.30401512639275, 20.348218595248085, 21.341391707196607, 22.290356659326925, 23.200538786847172, 24.076336930687773, 24.921376366485056, 25.73868683519033, 26.530831121546115, 27.299999999999997, 28.048083713508845, 28.776726707532255, 29.487370177755768, 30.181285592234143, 30.859601423219974, 31.523324697753566, 32.17335854398791, 32.8105166067223, 33.43553498899038, 34.04908221964287, 34.651767631680784, 35.244148450487494, 35.82673582675374, 36.4, 36.96437474109362, 37.52026119312071, 38.068031207300436, 38.6080302527855, 39.140579965043955, 39.665980386220134, 40.184511941791705, 40.69643719049617, 41.20200237852525, 41.70143882409815, 42.19496415450545, 42.682783414393214, 43.16509006129838, 43.64206686214575, 44.11388670248859, 44.58071331865385, 45.04270196158308, 45.5, 45.95274746954746, 46.401077573694344, 46.84511714149085, 47.284987046630356, 47.720802591741894, 48.15267386137555, 48.58070604674247, 49.004999744923985, 49.425651234960974, 49.84275273297011, 50.256392628202036, 50.6666557017532, 51.0736233294643, 51.47737367038066, 51.877981842010776, 52.27552008349606, 52.67005790769552, 53.06166224309223, 53.45039756634183, 53.83632602620651, 54.21950755954908, 54.599999999999994, 54.97785917985531, 55.353139025713794, 55.7258916483173, 56.09616742701769, 56.464015089258396, 56.82948178542543, 57.19261315939323, 57.55345341506451, 57.912045379178245, 58.268430560638926, 58.62264920659932, 58.974740355511535, 59.32474188734411, 59.67269057114821, 60.01862211014178, 60.36257118446829, 60.704571491774814, 61.04465578574426, 61.38285591270579, 61.71920284643995, 62.05372672128565, 62.3864568636495, 62.7174218220105, 63.04664939550713, 63.37416666118775, 63.699999999999996, 64.02417512158982, 64.34671708797582, 64.66765033616113], [0.0, 6.46741834119303, 9.146310731655687, 11.201897160749159, 12.93483668238606, 14.461587049836545, 15.841874889040124, 17.11118055541464, 18.292621463311374, 19.40225502357909, 20.451772539317957, 21.450000000000003, 22.403794321498317, 23.31860844904773, 24.19886360968217, 25.048203528397003, 25.86967336477212, 26.66584894579582, 27.438932194967062, 28.190822974861877, 28.92317409967309, 29.6374340994628, 30.334880912902896, 31.016648755144395, 31.683749778080248, 32.33709170596515, 32.97749232431114, 33.60569148224747, 34.22236111082928, 34.82811364400892, 35.42350914294065, 36.00906135960781, 36.58524292662275, 37.15248982235242, 37.71120523133675, 38.261762897179736, 38.80451004715818, 39.33976995357243, 39.86784418550871, 40.389014595555565, 40.903545078635915, 41.411683134110845, 41.91366125739913, 42.409698183316515, 42.900000000000006, 43.38476114950963, 43.86416532888777, 44.338386303518085, 44.807588642996635, 45.27192838835121, 45.73155365827844, 46.18660520107535, 46.63721689809546, 47.08351622383359, 47.525624667120375, 47.96365811737049, 48.39772721936434, 48.82793769964077, 49.254390667228854, 49.67718289114229, 50.09640705679401, 50.512152003255615, 50.924502943082324, 51.33354166624392, 51.73934672954424, 52.14199363277166, 52.541554982699175, 52.938100645943095, 53.33169789159164, 53.72241152442806, 54.11030400949527, 54.495435588680266, 54.877864389934125, 55.25764652968855, 55.63483620897971, 56.00948580374578, 56.381645949723755, 56.75136562233547, 57.118692211919566, 57.483671594636334, 57.84634819934618, 58.206765070737276, 58.564963928956715, 58.920985225978704, 59.2748681989256, 59.62665092054057, 59.976370346995836, 60.32406236320628, 60.66976182580579, 61.01350260393186, 61.35531761795387, 61.695238876269876, 62.03329751028879, 62.36952380770597, 62.70394724417276, 63.036596513453986, 63.367499556160496, 63.6966835871382, 64.02417512158982, 64.35000000000001, 64.6741834119303, 64.99674991874595], [0.0, 6.5, 9.192388155425117, 11.258330249197705, 13.0, 14.534441853748636, 15.921683328090658, 17.197383521919843, 18.384776310850235, 19.5, 20.554804791094465, 21.5580611373101, 22.51666049839541, 23.436083290515935, 24.320773014030618, 25.17439175034821, 26.0, 26.800186566514796, 27.577164466275352, 28.332843133014382, 29.06888370749727, 29.786742017212966, 30.4877024388523, 31.172904901532682, 31.843366656181317, 32.5, 33.14362683835311, 33.774990747593115, 34.394767043839686, 35.00357124637428, 35.601966237835796, 36.19046835839515, 36.76955262170047, 37.33965720249719, 37.90118731649446, 38.4545185901475, 39.0, 39.53795644693843, 40.06869101929835, 40.592486989589595, 41.10960958218893, 41.62030754331352, 42.1248145396511, 42.623350407963, 43.1161222746202, 43.6033255612459, 44.08514489031425, 44.561754902606786, 45.03332099679082, 45.5, 45.96194077712559, 46.41928478552853, 46.87216658103187, 47.32071428032338, 47.765049984271975, 48.20529016612181, 48.641546028061235, 49.073923829259876, 49.502525188115406, 49.92744736114595, 50.34878350069642, 50.766622893393254, 51.181051181076775, 51.59215056575952, 52.0, 52.40467536394058, 52.80624963013375, 53.20479301717093, 53.60037313302959, 53.99305510896749, 54.38290172471491, 54.76997352564633, 55.154328932550705, 55.536024344563955, 55.915114235777075, 56.29165124598851, 56.665686266028764, 57.0372685180488, 57.406445631131014, 57.77326371255133, 58.13776741499454, 58.50000000000001, 58.860003397893216, 59.217818264437945, 59.57348403442593, 59.92703897240378, 60.278520220722086, 60.627963845077296, 60.9754048777046, 61.32087735836792, 61.6644143732834, 62.00604809210148, 62.345809803065364, 62.68372994645422, 63.01983814641228, 63.35416324125826, 63.686733312362634, 64.0175757116747, 64.34671708797582, 64.67418341193031, 65.0, 65.3241915372858], [0.0, 6.532419153728579, 9.238235762308733, 11.314481870593989, 13.064838307457158, 14.606933285258755, 16.001093712618523, 17.283156540400835, 18.476471524617466, 19.597257461185738, 20.657323156691916, 21.66558330624865, 22.628963741187977, 23.552972211591474, 24.442074380052116, 25.299950592837135, 26.129676614914317, 26.93385416163086, 27.714707286926195, 28.474154947952368, 29.21386657051751, 29.93530524314059, 30.639761748420963, 31.328381700943325, 32.00218742523705, 32.6620957686429, 33.308932735829295, 33.94344561178197, 34.56631308080167, 35.17815373211051, 35.7795332557595, 36.370970567198235, 36.95294304923493, 37.52589106203876, 38.090221842357394, 38.64631289010635, 39.194514922371475, 39.735154460502606, 40.268536104507206, 40.79494453973434, 41.31464631338383, 41.827891412310045, 42.33491466862784, 42.835937015548055, 43.3311666124973, 43.82079985577626, 44.30502228867513, 44.78400942300723, 45.257927482375955, 45.72693407610006, 46.191178811543665, 46.65080385159511, 47.10594442318295, 47.55672928198491, 48.00328113785557, 48.44571704495662, 48.88414876010423, 49.31868307244224, 49.74942210719639, 50.17646360595772, 50.59990118567427, 51.01982457829506, 51.4363198528044, 51.849469621202495, 52.25935322982863, 52.66604693728209, 53.06962408007052, 53.47015522700491, 53.86770832326172, 54.262348824944915, 54.654139824902565, 55.043142170482966, 55.42941457385239, 55.81301371544096, 56.19399434103257, 56.572409352969935, 56.948309895904735, 57.32174543748647, 57.692763844350544, 58.06141145373578, 58.42773314103502, 58.791772383557216, 59.153571320757976, 59.513170811174234, 59.87061048628118, 60.22592880147222, 60.579163084347755, 60.93034958048411, 61.279523496841925, 61.62671904296058, 61.97196947007575, 62.315307108286014, 62.65676340188665, 62.99636894297958, 63.33415350346131, 63.670146065483465, 64.0043748504741, 64.33686734680204, 64.66765033616113, 64.99674991874595, 65.3241915372858, 65.65]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"A = 7.0\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.7000000000000001, 0.9899494936611666, 1.2124355652982142, 1.4000000000000001, 1.5652475842498528, 1.7146428199482249, 1.8520259177452134, 1.9798989873223332, 2.1, 2.2135943621178655, 2.32163735324878, 2.4248711305964283, 2.5238858928247927, 2.619160170741759, 2.7110883423451915, 2.8000000000000003, 2.8861739379323628, 2.9698484809835, 3.0512292604784723, 3.1304951684997055, 3.2078029864690882, 3.283291031876401, 3.3570820663189043, 3.4292856398964497, 3.5000000000000004, 3.56931365951495, 3.6373066958946425, 3.704051835490427, 3.7696153649941535, 3.8340579025361627, 3.8974350539810154, 3.9597979746446663, 4.02119385257662, 4.08166632639171, 4.141255848169731, 4.2, 4.257933771208754, 4.315089802078283, 4.37149859887888, 4.427188724235731, 4.4821869662029945, 4.536518488885503, 4.5902069670114, 4.64327470649756, 4.695742752749558, 4.747630988187688, 4.798958220280731, 4.849742261192857, 4.9, 4.949747468305833, 4.998999899979996, 5.047771785649585, 5.096076922496364, 5.143928459844674, 5.191338940966964, 5.238320341483518, 5.2848841046895245, 5.331041174104736, 5.376802023508026, 5.422176684690383, 5.4671747731346585, 5.511805511808268, 5.556077753235641, 5.6000000000000005, 5.643580423808984, 5.686826883245173, 5.729746940310715, 5.7723478758647255, 5.814636704042653, 5.85662018573853, 5.8983048412234504, 5.939696961967, 5.980802621722272, 6.021627686929838, 6.06217782649107, 6.102458520956945, 6.142475071174486, 6.182232606429493, 6.2217360921209135, 6.260990336999411, 6.300000000000001, 6.338769596696193, 6.377303505401009, 6.4156059729381765, 6.4536811201050215, 6.491532946846993, 6.529165337162171, 6.566582063752802, 6.603786792439622, 6.640783086353597, 6.67757440991862, 6.7141641326378085, 6.75055553269507, 6.786751800382862, 6.822756041366275, 6.8585712797928995, 6.894200461257275, 6.929646455628165, 6.96491205974634, 7.000000000000001, 7.034912934784624], [0.0, 0.9899494936611665, 1.4, 1.7146428199482249, 1.979898987322333, 2.2135943621178655, 2.4248711305964283, 2.619160170741759, 2.8, 2.9698484809834995, 3.1304951684997055, 3.283291031876401, 3.4292856398964497, 3.5693136595149495, 3.7040518354904264, 3.8340579025361623, 3.959797974644666, 4.08166632639171, 4.2, 4.315089802078284, 4.427188724235731, 4.536518488885502, 4.64327470649756, 4.747630988187688, 4.849742261192857, 4.949747468305834, 5.047771785649585, 5.143928459844674, 5.238320341483518, 5.331041174104736, 5.422176684690383, 5.511805511808268, 5.6, 5.686826883245173, 5.772347875864725, 5.856620185738529, 5.939696961966999, 6.021627686929839, 6.102458520956943, 6.182232606429493, 6.260990336999411, 6.338769596696192, 6.4156059729381765, 6.491532946846991, 6.566582063752802, 6.640783086353596, 6.714164132637808, 6.78675180038286, 6.8585712797928995, 6.929646455628165, 7.0, 7.069653456853455, 7.138627319029899, 7.2069410986909, 7.274613391789284, 7.341661937191061, 7.408103670980853, 7.473954776421917, 7.539230729988305, 7.603946343840152, 7.668115805072325, 7.731752712031082, 7.79487010796203, 7.857480512225277, 7.919595949289332, 7.981227975693964, 8.04238770515324, 8.103085831953159, 8.16333265278342, 8.223138087129511, 8.282511696339464, 8.341462701469089, 8.4, 8.4581321815162, 8.515867542417507, 8.573214099741122, 8.630179604156568, 8.6867715521936, 8.742997197757758, 8.798863562983575, 8.854377448471462, 8.909545442950499, 8.964373932405989, 9.018869108707587, 9.073036977771004, 9.126883367283709, 9.180413934022802, 9.233634170791044, 9.28654941299512, 9.339164844888433, 9.391485505499116, 9.443516294262428, 9.495261976375376, 9.5467271878901, 9.597916440561463, 9.648834126463154, 9.699484522385713, 9.749871794028884, 9.799999999999999, 9.849873095629203, 9.899494936611667, 9.948869282486328], [0.0, 1.2124355652982142, 1.7146428199482249, 2.1000000000000005, 2.4248711305964283, 2.7110883423451924, 2.9698484809835, 3.2078029864690887, 3.4292856398964497, 3.6373066958946425, 3.834057902536163, 4.021193852576621, 4.200000000000001, 4.37149859887888, 4.536518488885503, 4.695742752749558, 4.849742261192857, 4.998999899979996, 5.143928459844675, 5.284884104689526, 5.422176684690385, 5.556077753235641, 5.686826883245173, 5.814636704042654, 5.939696961967, 6.062177826491072, 6.182232606429494, 6.300000000000001, 6.415605972938177, 6.529165337162172, 6.640783086353597, 6.75055553269507, 6.8585712797928995, 6.964912059746341, 7.069653456853456, 7.17286553617172, 7.274613391789285, 7.374957626996919, 7.473954776421919, 7.57165767847438, 7.668115805072326, 7.763375554486594, 7.857480512225278, 7.950471684120383, 8.042387705153242, 8.133265027035575, 8.223138087129513, 8.312039460926544, 8.400000000000002, 8.4870489570875, 8.573214099741126, 8.658521813797089, 8.74299719775776, 8.826664149042946, 8.909545442950499, 8.991662805065591, 9.073036977771006, 9.153687781435416, 9.233634170791044, 9.312894286955052, 9.391485505499116, 9.46942448092808, 9.546727187890099, 9.623408959407266, 9.699484522385713, 9.77496803063826, 9.849873095629205, 9.92421281513048, 9.997999799959992, 10.071246198956713, 10.14396372233261, 10.216163663528498, 10.28785691968935, 10.35905401086412, 10.429765098025937, 10.500000000000002, 10.569768209379053, 10.639078907499467, 10.70794097854485, 10.77636302283846, 10.84435336938077, 10.91192008768393, 10.97907099895069, 11.045813686641651, 11.112155506471282, 11.17810359586992, 11.24366488294631, 11.308846094982462, 11.373653766490346, 11.438094246857734, 11.50217370760849, 11.565898149300816, 11.629273408085307, 11.692305161943048, 11.754998936622668, 11.817360111293894, 11.879393923934, 11.94110547646239, 12.002499739637575, 12.063581557729863, 12.124355652982144, 12.18482662987045], [0.0, 1.4000000000000001, 1.9798989873223332, 2.4248711305964283, 2.8000000000000003, 3.1304951684997055, 3.4292856398964497, 3.704051835490427, 3.9597979746446663, 4.2, 4.427188724235731, 4.64327470649756, 4.849742261192857, 5.047771785649585, 5.238320341483518, 5.422176684690383, 5.6000000000000005, 5.7723478758647255, 5.939696961967, 6.102458520956945, 6.260990336999411, 6.4156059729381765, 6.566582063752802, 6.7141641326378085, 6.8585712797928995, 7.000000000000001, 7.1386273190299, 7.274613391789285, 7.408103670980854, 7.539230729988307, 7.6681158050723255, 7.794870107962031, 7.919595949289333, 8.04238770515324, 8.16333265278342, 8.282511696339462, 8.4, 8.515867542417508, 8.630179604156567, 8.74299719775776, 8.854377448471462, 8.964373932405989, 9.073036977771006, 9.1804139340228, 9.28654941299512, 9.391485505499116, 9.495261976375376, 9.597916440561463, 9.699484522385713, 9.8, 9.899494936611665, 9.997999799959992, 10.09554357129917, 10.192153844992728, 10.287856919689348, 10.382677881933928, 10.476640682967036, 10.569768209379049, 10.662082348209472, 10.753604047016053, 10.844353369380766, 10.934349546269317, 11.023611023616535, 11.112155506471282, 11.200000000000001, 11.287160847617969, 11.373653766490346, 11.45949388062143, 11.544695751729451, 11.629273408085306, 11.71324037147706, 11.796609682446901, 11.879393923934, 11.961605243444543, 12.043255373859676, 12.12435565298214, 12.20491704191389, 12.284950142348972, 12.364465212858986, 12.443472184241827, 12.521980673998822, 12.600000000000001, 12.677539193392386, 12.754607010802019, 12.831211945876353, 12.907362240210043, 12.983065893693986, 13.058330674324342, 13.133164127505603, 13.207573584879244, 13.281566172707194, 13.35514881983724, 13.428328265275617, 13.50111106539014, 13.573503600765724, 13.64551208273255, 13.717142559585799, 13.78840092251455, 13.85929291125633, 13.92982411949268, 14.000000000000002, 14.069825869569248], [0.0, 1.565247584249853, 2.2135943621178655, 2.7110883423451924, 3.130495168499706, 3.5000000000000004, 3.834057902536163, 4.141255848169732, 4.427188724235731, 4.695742752749559, 4.949747468305833, 5.191338940966965, 5.422176684690385, 5.643580423808985, 5.856620185738529, 6.06217782649107, 6.260990336999412, 6.4536811201050215, 6.640783086353598, 6.822756041366277, 7.000000000000001, 7.172865536171719, 7.341661937191061, 7.506663706334527, 7.668115805072326, 7.826237921249265, 7.981227975693967, 8.133265027035575, 8.282511696339464, 8.429116205154608, 8.573214099741124, 8.714929718592114, 8.854377448471462, 8.991662805065593, 9.126883367283709, 9.260129588726068, 9.391485505499118, 9.521029356114811, 9.648834126463155, 9.774968030638261, 9.899494936611665, 10.022474744293449, 10.14396372233261, 10.264014809030625, 10.38267788193393, 10.5, 10.616025621672172, 10.730796801729126, 10.84435336938077, 10.95673308974897, 11.067971810589329, 11.17810359586992, 11.28716084761797, 11.395174417269796, 11.502173707608488, 11.6081867662439, 11.713240371477058, 11.817360111293892, 11.920570456148482, 12.02289482612237, 12.12435565298214, 12.224974437601087, 12.324771803161306, 12.423767544509195, 12.521980673998824, 12.619429464123963, 12.716131487209466, 12.81210365240619, 12.907362240210043, 13.0019229347047, 13.095800853708797, 13.189010576991741, 13.281566172707196, 13.37348122217996, 13.46476884316994, 13.55544171172596, 13.645512082732553, 13.73499180924401, 13.823892360692051, 13.912224840046257, 14.000000000000002, 14.087228258248677, 14.173919711921615, 14.260084151224355, 14.345731072343439, 14.430869689661813, 14.515508947329407, 14.59965753022995, 14.683323874382122, 14.76651617681029, 14.849242404917499, 14.93151030539108, 15.013327412669055, 15.09470105699348, 15.175638372075163, 15.256146302392358, 15.336231610144653, 15.41590088188167, 15.49516053482506, 15.574016822900894, 15.65247584249853, 15.730543537970966], [0.0, 1.7146428199482247, 2.4248711305964283, 2.9698484809835, 3.4292856398964493, 3.8340579025361627, 4.2, 4.536518488885503, 4.849742261192857, 5.143928459844674, 5.422176684690384, 5.686826883245173, 5.939696961967, 6.182232606429493, 6.415605972938176, 6.640783086353596, 6.858571279792899, 7.069653456853455, 7.274613391789286, 7.47395477642192, 7.6681158050723255, 7.857480512225277, 8.04238770515324, 8.223138087129513, 8.4, 8.573214099741124, 8.74299719775776, 8.909545442950499, 9.073036977771006, 9.233634170791046, 9.391485505499118, 9.546727187890099, 9.699484522385713, 9.849873095629203, 9.997999799959992, 10.143963722332607, 10.287856919689348, 10.429765098025939, 10.56976820937905, 10.70794097854485, 10.844353369380768, 10.979070998950688, 11.112155506471282, 11.243664882946307, 11.373653766490346, 11.502173707608488, 11.629273408085306, 11.754998936622666, 11.879393923934, 12.002499739637573, 12.124355652982143, 12.244998979175133, 12.364465212858986, 12.482788150088908, 12.6, 12.716131487209466, 12.831211945876351, 12.94526940623485, 13.058330674324342, 13.170421405558747, 13.281566172707192, 13.391788528796294, 13.501111065390136, 13.609555466656508, 13.717142559585797, 13.823892360692048, 13.92982411949268, 14.034956359034396, 14.13930691370691, 14.242892964563065, 14.34573107234344, 14.447837208385206, 14.549226783578572, 14.649914675519444, 14.749915253993834, 14.849242404917499, 14.94790955284384, 15.045929682143276, 15.143315356948756, 15.240078739954072, 15.336231610144651, 15.431785379534023, 15.526751108973187, 15.621139523094978, 15.714961024450554, 15.808225706890703, 15.900943368240767, 15.99312352231421, 16.08477541030648, 16.17590801160788, 16.26653005407115, 16.35665002376709, 16.446276174259026, 16.535416535424805, 16.624078921853087, 16.71227094083865, 16.8, 16.88727331454075, 16.974097914174997, 17.06048064973552, 17.146428199482248, 17.231947075127643], [0.0, 1.8520259177452134, 2.619160170741759, 3.2078029864690882, 3.704051835490427, 4.141255848169731, 4.536518488885503, 4.9, 5.238320341483518, 5.55607775323564, 5.856620185738529, 6.142475071174486, 6.4156059729381765, 6.67757440991862, 6.929646455628165, 7.172865536171718, 7.408103670980854, 7.636098480245001, 7.857480512225278, 8.07279381626956, 8.282511696339462, 8.487048957087499, 8.6867715521936, 8.882004278314666, 9.073036977771006, 9.260129588726068, 9.44351629426243, 9.623408959407264, 9.8, 9.973464794142506, 10.143963722332607, 10.311643903859364, 10.476640682967036, 10.639078907499465, 10.799074034379059, 10.956733089748969, 11.11215550647128, 11.265433857601758, 11.416654501210063, 11.565898149300816, 11.713240371477058, 11.858752042268193, 12.002499739637573, 12.14454610102823, 12.284950142348972, 12.423767544509193, 12.561050911448454, 12.696850003051939, 12.831211945876353, 12.964181424216495, 13.095800853708795, 13.22611053938383, 13.35514881983724, 13.482952198980758, 13.609555466656506, 13.73499180924401, 13.85929291125633, 13.982489048806725, 14.10460917572692, 14.225681003031104, 14.345731072343437, 14.464784823840278, 14.582866659199759, 14.700000000000001, 14.816207341961707, 14.931510305391077, 15.045929682143274, 15.159485479395402, 15.272196960490001, 15.38408268308514, 15.495160534825061, 15.605447766725566, 15.714961024450556, 15.82371637764024, 15.931729347437457, 16.03901493234544, 16.14558763253912, 16.25146147274146, 16.35665002376709, 16.46116642282679, 16.565023392678924, 16.668233259706923, 16.770807970995318, 16.872759110471527, 16.974097914174997, 17.074835284710655, 17.174981804939417, 17.274547750954294, 17.3735431043872, 17.471977564088156, 17.569860557215588, 17.667201249773548, 17.76400855662933, 17.860291151042304, 17.956057473732926, 18.05131574151868, 18.14607395554201, 18.240339909113537, 18.334121195192314, 18.42742521352346, 18.520259177452136, 18.612630120431668], [0.0, 1.979898987322333, 2.8, 3.4292856398964497, 3.959797974644666, 4.427188724235731, 4.849742261192857, 5.238320341483518, 5.6, 5.939696961966999, 6.260990336999411, 6.566582063752802, 6.8585712797928995, 7.138627319029899, 7.408103670980853, 7.668115805072325, 7.919595949289332, 8.16333265278342, 8.4, 8.630179604156568, 8.854377448471462, 9.073036977771004, 9.28654941299512, 9.495261976375376, 9.699484522385713, 9.899494936611667, 10.09554357129917, 10.287856919689348, 10.476640682967036, 10.662082348209472, 10.844353369380766, 11.023611023616535, 11.2, 11.373653766490346, 11.54469575172945, 11.713240371477058, 11.879393923933998, 12.043255373859678, 12.204917041913886, 12.364465212858986, 12.521980673998822, 12.677539193392384, 12.831211945876353, 12.983065893693983, 13.133164127505603, 13.281566172707192, 13.428328265275615, 13.57350360076572, 13.717142559585799, 13.85929291125633, 14.0, 14.13930691370691, 14.277254638059798, 14.4138821973818, 14.549226783578568, 14.683323874382122, 14.816207341961706, 14.947909552843834, 15.07846145997661, 15.207892687680303, 15.33623161014465, 15.463505424062165, 15.58974021592406, 15.714961024450554, 15.839191898578663, 15.962455951387929, 16.08477541030648, 16.206171663906318, 16.32666530556684, 16.446276174259022, 16.565023392678928, 16.682925402938178, 16.8, 16.9162643630324, 17.031735084835013, 17.146428199482244, 17.260359208313137, 17.3735431043872, 17.485994395515515, 17.59772712596715, 17.708754896942924, 17.819090885900998, 17.928747864811978, 18.037738217415175, 18.146073955542008, 18.253766734567417, 18.360827868045604, 18.467268341582088, 18.57309882599024, 18.678329689776866, 18.78297101099823, 18.887032588524857, 18.990523952750753, 19.0934543757802, 19.195832881122925, 19.297668252926307, 19.398969044771427, 19.49974358805777, 19.599999999999998, 19.699746191258406, 19.798989873223334, 19.897738564972656], [0.0, 2.1, 2.9698484809834995, 3.6373066958946425, 4.2, 4.695742752749558, 5.143928459844674, 5.55607775323564, 5.939696961966999, 6.299999999999999, 6.640783086353596, 6.964912059746339, 7.274613391789285, 7.571657678474377, 7.857480512225276, 8.133265027035574, 8.4, 8.658521813797087, 8.909545442950499, 9.153687781435416, 9.391485505499116, 9.623408959407264, 9.849873095629201, 10.071246198956711, 10.287856919689348, 10.500000000000002, 10.70794097854485, 10.911920087683926, 11.11215550647128, 11.30884609498246, 11.502173707608488, 11.692305161943045, 11.879393923933998, 12.063581557729862, 12.244998979175131, 12.423767544509193, 12.599999999999998, 12.773801313626262, 12.94526940623485, 13.114495796636637, 13.281566172707192, 13.446560898608984, 13.609555466656508, 13.7706209010342, 13.929824119492679, 14.087228258248674, 14.242892964563064, 14.396874660842192, 14.54922678357857, 14.7, 14.849242404917499, 14.996999699939986, 15.143315356948754, 15.28823076748909, 15.431785379534022, 15.574016822900893, 15.714961024450552, 15.854652314068574, 15.993123522314207, 16.130406070524078, 16.266530054071147, 16.401524319403975, 16.5354165354248, 16.66823325970692, 16.8, 16.930741271426953, 17.060480649735517, 17.189240820932145, 17.317043627594174, 17.44391011212796, 17.569860557215588, 17.694914523670352, 17.819090885900998, 17.942407865166814, 18.064883060789512, 18.186533479473212, 18.30737556287083, 18.427425213523456, 18.54669781928848, 18.665208276362737, 18.78297101099823, 18.900000000000002, 19.016308790088576, 19.131910516203025, 19.24681791881453, 19.361043360315065, 19.474598840540978, 19.587496011486515, 19.699746191258402, 19.811360377318866, 19.922349259060788, 20.03272322975586, 20.142492397913422, 20.251666598085208, 20.360255401148585, 20.468268124098824, 20.575713839378697, 20.68260138377182, 20.788939366884495, 20.894736179239022, 21.000000000000004, 21.10473880435387], [0.0, 2.2135943621178655, 3.1304951684997055, 3.834057902536163, 4.427188724235731, 4.949747468305833, 5.422176684690384, 5.856620185738529, 6.260990336999411, 6.640783086353596, 7.0, 7.341661937191061, 7.668115805072326, 7.981227975693966, 8.282511696339462, 8.573214099741122, 8.854377448471462, 9.126883367283709, 9.391485505499118, 9.648834126463157, 9.899494936611665, 10.143963722332607, 10.382677881933928, 10.616025621672172, 10.844353369380768, 11.067971810589329, 11.28716084761797, 11.502173707608488, 11.713240371477058, 11.920570456148482, 12.12435565298214, 12.324771803161306, 12.521980673998822, 12.716131487209466, 12.907362240210043, 13.095800853708795, 13.281566172707192, 13.464768843169942, 13.64551208273255, 13.823892360692051, 14.0, 14.173919711921613, 14.345731072343439, 14.515508947329403, 14.683323874382122, 14.849242404917497, 15.013327412669053, 15.17563837207516, 15.336231610144653, 15.49516053482506, 15.652475842498529, 15.808225706890703, 15.962455951387932, 16.115210206509875, 16.26653005407115, 16.416455159382004, 16.565023392678924, 16.71227094083865, 16.858232410309213, 17.002940922087568, 17.146428199482244, 17.288724649319857, 17.429859437184223, 17.569860557215588, 17.708754896942924, 17.846568297574745, 17.983325610131182, 18.1190507477627, 18.253766734567417, 18.387495751189178, 18.520259177452136, 18.652077632263918, 18.782971010998235, 18.912958520548813, 19.04205871222962, 19.170289512680814, 19.297668252926314, 19.424211695716252, 19.54993606127652, 19.674857051577277, 19.79898987322333, 19.92234925906079, 20.044949488586898, 20.166804407243106, 20.287927444665215, 20.408331631958553, 20.528029618061254, 20.647033685253678, 20.765355763867856, 20.883007446246815, 21.0, 21.1163443805977, 21.232051243344344, 21.34713095476767, 21.46159360345825, 21.575449010391416, 21.688706738761535, 21.801376103356414, 21.913466179497938, 22.024985811573185, 22.135943621178658, 22.246348014898988], [0.0, 2.32163735324878, 3.283291031876401, 4.021193852576621, 4.64327470649756, 5.191338940966965, 5.686826883245173, 6.142475071174486, 6.566582063752802, 6.964912059746339, 7.341661937191061, 7.700000000000001, 8.042387705153242, 8.37078252017098, 8.6867715521936, 8.99166280506559, 9.28654941299512, 9.57235603182414, 9.849873095629203, 10.119782606360674, 10.38267788193393, 10.639078907499465, 10.889444430272832, 11.13418160441081, 11.373653766490346, 11.608186766243902, 11.838074167701436, 12.063581557729862, 12.284950142348972, 12.502399769644228, 12.716131487209466, 12.926329718833573, 13.133164127505603, 13.336791218280357, 13.537355724069602, 13.73499180924401, 13.929824119492679, 14.121968701282412, 14.311533810182612, 14.49862062404559, 14.683323874382122, 14.865732407116715, 15.045929682143276, 15.22399421965208, 15.400000000000002, 15.574016822900893, 15.746110630882793, 15.916343801262903, 16.084775410306484, 16.25146147274146, 16.416455159382007, 16.57980699525782, 16.74156504034196, 16.901775054709493, 17.060480649735517, 17.217723426748382, 17.3735431043872, 17.52797763576848, 17.681063316441126, 17.832834883999798, 17.98332561013118, 18.132567385784068, 18.280590800080834, 18.42742521352346, 18.57309882599024, 18.717638739969313, 18.861071019430476, 19.00342074469752, 19.14471206364828, 19.28496823953828, 19.424211695716256, 19.56246405747497, 19.699746191258406, 19.836078241426655, 19.971479664761947, 20.1059692628831, 20.23956521272135, 20.372285095197352, 20.504145922227536, 20.635164162177148, 20.76535576386786, 20.894736179239022, 21.023320384753696, 21.15112290163338, 21.27815781499893, 21.40443879198892, 21.529979098921583, 21.65479161756123, 21.778888860545663, 21.902282986026822, 22.024985811573185, 22.147008827378926, 22.26836320882162, 22.38905982840727, 22.509109267138943, 22.62852182534246, 22.74730753298069, 22.86547615948551, 22.983037223134804, 23.100000000000005, 23.216373532487804, 23.332166637498545], [0.0, 2.4248711305964283, 3.4292856398964497, 4.200000000000001, 4.849742261192857, 5.422176684690385, 5.939696961967, 6.415605972938177, 6.8585712797928995, 7.274613391789285, 7.668115805072326, 8.042387705153242, 8.400000000000002, 8.74299719775776, 9.073036977771006, 9.391485505499116, 9.699484522385713, 9.997999799959992, 10.28785691968935, 10.569768209379053, 10.84435336938077, 11.112155506471282, 11.373653766490346, 11.629273408085307, 11.879393923934, 12.124355652982144, 12.364465212858988, 12.600000000000001, 12.831211945876355, 13.058330674324344, 13.281566172707194, 13.50111106539014, 13.717142559585799, 13.929824119492682, 14.139306913706912, 14.34573107234344, 14.54922678357857, 14.749915253993837, 14.947909552843837, 15.14331535694876, 15.336231610144653, 15.526751108973189, 15.714961024450556, 15.900943368240766, 16.084775410306484, 16.26653005407115, 16.446276174259026, 16.624078921853087, 16.800000000000004, 16.974097914175, 17.14642819948225, 17.317043627594177, 17.48599439551552, 17.653328298085892, 17.819090885900998, 17.983325610131182, 18.14607395554201, 18.30737556287083, 18.467268341582088, 18.625788573910103, 18.78297101099823, 18.93884896185616, 19.093454375780198, 19.246817918814532, 19.398969044771427, 19.54993606127652, 19.69974619125841, 19.84842563026096, 19.995999599919983, 20.142492397913426, 20.28792744466522, 20.432327327056996, 20.5757138393787, 20.71810802172824, 20.859530196051875, 21.000000000000004, 21.139536418758105, 21.278157814998934, 21.4158819570897, 21.55272604567692, 21.68870673876154, 21.82384017536786, 21.95814199790138, 22.091627373283302, 22.224311012942565, 22.35620719173984, 22.48732976589262, 22.617692189964924, 22.74730753298069, 22.876188493715468, 23.00434741521698, 23.131796298601632, 23.258546816170615, 23.384610323886097, 23.509997873245336, 23.634720222587788, 23.758787847868, 23.88221095292478, 24.00499947927515, 24.127163115459727, 24.24871130596429, 24.3696532597409], [0.0, 2.5238858928247927, 3.5693136595149495, 4.37149859887888, 5.047771785649585, 5.643580423808985, 6.182232606429493, 6.67757440991862, 7.138627319029899, 7.571657678474377, 7.981227975693966, 8.370782520170978, 8.74299719775776, 9.100000000000001, 9.443516294262428, 9.774968030638258, 10.09554357129917, 10.406248123122955, 10.70794097854485, 11.0013635518512, 11.28716084761797, 11.565898149300816, 11.838074167701434, 12.10413152605341, 12.364465212858986, 12.619429464123964, 12.869343417595166, 13.114495796636637, 13.35514881983724, 13.591541487263322, 13.82389236069205, 14.052401929919313, 14.277254638059798, 14.498620624045587, 14.716657229140049, 14.93151030539108, 15.143315356948754, 15.352198539622918, 15.55827753962501, 15.761662348876786, 15.962455951387932, 16.160754932861277, 16.356650023767095, 16.550226584551645, 16.741565040341957, 16.930741271426953, 17.11782696489248, 17.302889932031587, 17.48599439551552, 17.667201249773548, 17.84656829757475, 18.02415046541723, 18.200000000000003, 18.374166647769364, 18.54669781928848, 18.717638739969313, 18.887032588524857, 19.054920624342678, 19.221342304844374, 19.386335393776722, 19.549936061276515, 19.712178976460216, 19.873097393209743, 20.03272322975586, 20.19108714259834, 20.348218595248085, 20.504145922227536, 20.658896388723193, 20.81249624624591, 20.964970784620714, 21.116344380597702, 21.266640543348636, 21.4158819570897, 21.564090521049106, 21.71128738697915, 21.857492994394395, 22.0027271037024, 22.147008827378926, 22.290356659326925, 22.432788502546895, 22.57432169523594, 22.714973035423135, 22.854758804240316, 22.99369478791958, 23.131796298601632, 23.26907819403253, 23.405554896220686, 23.541240409120334, 23.676148335402868, 23.810291892372927, 23.9436839270819, 24.076336930687777, 24.20826305210682, 24.3394741109992, 24.469981610127952, 24.59979674712781, 24.728930425717973, 24.85739326639059, 24.985195616604646, 25.11234756051294, 25.23885892824793, 25.36473930479082], [0.0, 2.619160170741759, 3.704051835490427, 4.536518488885503, 5.238320341483518, 5.856620185738529, 6.4156059729381765, 6.929646455628165, 7.408103670980854, 7.857480512225276, 8.282511696339462, 8.6867715521936, 9.073036977771006, 9.443516294262428, 9.799999999999999, 10.143963722332606, 10.476640682967036, 10.799074034379059, 11.11215550647128, 11.416654501210065, 11.713240371477058, 12.002499739637573, 12.28495014234897, 12.561050911448454, 12.831211945876353, 13.095800853708797, 13.35514881983724, 13.609555466656506, 13.85929291125633, 14.104609175726921, 14.345731072343437, 14.58286665919976, 14.816207341961707, 15.045929682143274, 15.272196960490001, 15.49516053482506, 15.714961024450552, 15.931729347437459, 16.145587632539115, 16.356650023767095, 16.565023392678924, 16.770807970995318, 16.974097914174997, 17.174981804939414, 17.3735431043872, 17.569860557215584, 17.76400855662933, 17.956057473732923, 18.14607395554201, 18.334121195192314, 18.520259177452136, 18.704544902242343, 18.887032588524857, 19.067773860626733, 19.24681791881453, 19.424211695716252, 19.599999999999998, 19.774225648555745, 19.94692958828501, 20.11815100847988, 20.28792744466521, 20.45629487468344, 20.623287807718725, 20.7889393668845, 20.95328136593407, 21.116344380597695, 21.27815781499893, 21.438749963558976, 21.598148068758118, 21.756378375088076, 21.91346617949794, 22.069435878608225, 22.22431101294256, 22.37811430840409, 22.53086771520351, 22.68259244442751, 22.83330900242013, 22.983037223134804, 23.13179629860163, 23.279604807642247, 23.426480742954116, 23.572441536675832, 23.717504084536387, 23.861684768683034, 24.004999479275146, 24.147463634924478, 24.289092202056462, 24.429899713261207, 24.56990028469794, 24.709107632611904, 24.847535089018386, 24.985195616604646, 25.12210182289691, 25.258265973736204, 25.393700006103877, 25.528415540334656, 25.662423891752706, 25.795736081763593, 25.928362848432986, 26.0603146565808, 26.191601707417593, 26.322233947748437], [0.0, 2.7110883423451915, 3.8340579025361623, 4.695742752749559, 5.422176684690383, 6.06217782649107, 6.640783086353596, 7.172865536171718, 7.668115805072325, 8.133265027035574, 8.573214099741122, 8.99166280506559, 9.391485505499118, 9.774968030638258, 10.143963722332606, 10.499999999999998, 10.844353369380766, 11.178103595869917, 11.502173707608488, 11.817360111293894, 12.12435565298214, 12.423767544509193, 12.716131487209463, 13.001922934704698, 13.281566172707192, 13.55544171172596, 13.82389236069205, 14.087228258248674, 14.345731072343437, 14.599657530229948, 14.849242404917497, 15.094701056993475, 15.33623161014465, 15.574016822900893, 15.8082257068907, 16.039014932345438, 16.266530054071147, 16.490906585145645, 16.71227094083865, 16.930741271426957, 17.146428199482244, 17.359435474692145, 17.569860557215588, 17.777795138880407, 17.98332561013118, 18.18653347947321, 18.387495751189174, 18.586285266292453, 18.782971010998235, 18.977618396416343, 19.170289512680814, 19.361043360315065, 19.549936061276515, 19.73702105182036, 19.922349259060788, 20.1059692628831, 20.28792744466521, 20.46826812409882, 20.647033685253675, 20.824264692900922, 20.999999999999996, 21.17427684715584, 21.347130954767664, 21.518596608515157, 21.68870673876153, 21.857492994394388, 22.02498581157318, 22.1912144778063, 22.356207191739834, 22.519991119003578, 22.68259244442751, 22.844036420913003, 23.004347415216976, 23.16354895088401, 23.32166374854075, 23.47871376374779, 23.634720222587788, 23.789703655152998, 23.943683927081896, 24.096680269281908, 24.24871130596428, 24.399795081106724, 24.549949083450258, 24.699190270128287, 24.847535089018386, 24.994999499899976, 25.14159899449516, 25.28734861546382, 25.432262974418926, 25.57635626902315, 25.719642299223366, 25.862134482675632, 26.003845869409396, 26.144789155776337, 26.284976697726023, 26.42442052344762, 26.563132345414385, 26.701123571864912, 26.838405317753136, 26.974988415196773, 27.11088342345192, 27.24610063843999], [0.0, 2.8000000000000003, 3.9597979746446663, 4.849742261192857, 5.6000000000000005, 6.260990336999411, 6.8585712797928995, 7.408103670980854, 7.919595949289333, 8.4, 8.854377448471462, 9.28654941299512, 9.699484522385713, 10.09554357129917, 10.476640682967036, 10.844353369380766, 11.200000000000001, 11.544695751729451, 11.879393923934, 12.20491704191389, 12.521980673998822, 12.831211945876353, 13.133164127505603, 13.428328265275617, 13.717142559585799, 14.000000000000002, 14.2772546380598, 14.54922678357857, 14.816207341961707, 15.078461459976614, 15.336231610144651, 15.589740215924062, 15.839191898578665, 16.08477541030648, 16.32666530556684, 16.565023392678924, 16.8, 17.031735084835017, 17.260359208313133, 17.48599439551552, 17.708754896942924, 17.928747864811978, 18.14607395554201, 18.3608278680456, 18.57309882599024, 18.78297101099823, 18.990523952750753, 19.195832881122925, 19.398969044771427, 19.6, 19.79898987322333, 19.995999599919983, 20.19108714259834, 20.384307689985455, 20.575713839378697, 20.765355763867856, 20.95328136593407, 21.139536418758098, 21.324164696418944, 21.507208094032105, 21.68870673876153, 21.868699092538634, 22.04722204723307, 22.224311012942565, 22.400000000000002, 22.574321695235938, 22.74730753298069, 22.91898776124286, 23.089391503458902, 23.25854681617061, 23.42648074295412, 23.593219364893802, 23.758787847868, 23.923210486889086, 24.086510747719352, 24.24871130596428, 24.40983408382778, 24.569900284697944, 24.728930425717973, 24.886944368483654, 25.043961347997644, 25.200000000000003, 25.355078386784772, 25.509214021604038, 25.662423891752706, 25.814724480420086, 25.966131787387972, 26.116661348648684, 26.266328255011206, 26.415147169758487, 26.563132345414388, 26.71029763967448, 26.856656530551234, 27.00222213078028, 27.147007201531448, 27.2910241654651, 27.434285119171598, 27.5768018450291, 27.71858582251266, 27.85964823898536, 28.000000000000004, 28.139651739138497], [0.0, 2.8861739379323623, 4.08166632639171, 4.998999899979996, 5.772347875864725, 6.4536811201050215, 7.069653456853455, 7.636098480245, 8.16333265278342, 8.658521813797087, 9.126883367283709, 9.57235603182414, 9.997999799959992, 10.406248123122955, 10.799074034379059, 11.178103595869917, 11.54469575172945, 11.9, 12.244998979175133, 12.580540528928003, 12.907362240210043, 13.22611053938383, 13.5373557240696, 13.841603953299634, 14.13930691370691, 14.430869689661813, 14.716657229140049, 14.996999699939984, 15.27219696049, 15.542522317822165, 15.8082257068907, 16.069536396548596, 16.32666530556684, 16.57980699525782, 16.829141392239833, 17.074835284710655, 17.317043627594174, 17.555910685578233, 17.79157103799437, 18.02415046541723, 18.253766734567417, 18.480530295421723, 18.704544902242343, 18.92590816843408, 19.14471206364828, 19.361043360315062, 19.57498403575339, 19.786611635143597, 19.995999599919983, 20.203217565526536, 20.408331631958553, 20.61140461006964, 20.81249624624591, 21.01166342772509, 21.208960370560362, 21.40443879198892, 21.598148068758118, 21.790135382782733, 21.980445855350613, 22.169122670958362, 22.356207191739834, 22.541739063346466, 22.725756313047096, 22.908295440735003, 23.0893915034589, 23.269078194032524, 23.447387914221917, 23.62435184296069, 23.8, 23.974361305361196, 24.147463634924478, 24.31933387245629, 24.489997958350266, 24.65948093533195, 24.827806991355477, 24.994999499899976, 25.161081057856006, 25.32607352117576, 25.489998038446377, 25.652875082532177, 25.814724480420086, 25.975565441391264, 26.13541658363226, 26.294295959390126, 26.45222107876766, 26.6092089322475, 26.765276012027226, 26.920438332241176, 27.0747114481392, 27.228110474287412, 27.380650101851124, 27.53234461501599, 27.683207906599268, 27.833253492899463, 27.982494527829363, 28.130943816374167, 28.27861382741382, 28.425516705945736, 28.57166428474197, 28.717068095472424, 28.861739379323627, 29.00568909714093], [0.0, 2.9698484809834995, 4.2, 5.143928459844674, 5.939696961966999, 6.640783086353597, 7.274613391789285, 7.857480512225277, 8.4, 8.909545442950499, 9.391485505499118, 9.849873095629203, 10.287856919689348, 10.70794097854485, 11.11215550647128, 11.502173707608486, 11.879393923933998, 12.244998979175131, 12.600000000000001, 12.945269406234853, 13.281566172707194, 13.609555466656508, 13.929824119492679, 14.242892964563065, 14.54922678357857, 14.8492424049175, 15.143315356948756, 15.431785379534022, 15.714961024450554, 15.99312352231421, 16.26653005407115, 16.535416535424805, 16.8, 17.06048064973552, 17.317043627594174, 17.569860557215588, 17.819090885900998, 18.06488306078952, 18.30737556287083, 18.546697819288482, 18.782971010998235, 19.016308790088576, 19.24681791881453, 19.474598840540978, 19.699746191258406, 19.922349259060788, 20.142492397913426, 20.36025540114858, 20.575713839378697, 20.7889393668845, 21.0, 21.208960370560366, 21.4158819570897, 21.620823296072704, 21.823840175367852, 22.024985811573185, 22.22431101294256, 22.421864329265752, 22.617692189964917, 22.811839031520453, 23.004347415216973, 23.195258136093248, 23.38461032388609, 23.572441536675832, 23.758787847867996, 23.943683927081896, 24.127163115459723, 24.309257495859477, 24.489997958350262, 24.669414261388535, 24.84753508901839, 25.02438810440727, 25.200000000000003, 25.3743965445486, 25.54760262725252, 25.71964229922337, 25.890538812469707, 26.0603146565808, 26.228991593273275, 26.396590688950727, 26.563132345414388, 26.728636328851497, 26.89312179721797, 27.056607326122762, 27.219110933313015, 27.380650101851128, 27.541241802068406, 27.700902512373133, 27.859648238985358, 28.0174945346653, 28.17445651649735, 28.330548882787287, 28.48578592912613, 28.6401815636703, 28.79374932168439, 28.946502379389464, 29.09845356715714, 29.249615382086656, 29.4, 29.54961928688761, 29.698484809835, 29.846607847458987], [0.0, 3.051229260478472, 4.315089802078284, 5.284884104689526, 6.102458520956944, 6.822756041366276, 7.473954776421919, 8.072793816269558, 8.630179604156568, 9.153687781435416, 9.648834126463157, 10.119782606360674, 10.569768209379053, 11.001363551851199, 11.416654501210065, 11.817360111293892, 12.204917041913887, 12.580540528928003, 12.945269406234853, 13.300000000000004, 13.645512082732552, 13.982489048806727, 14.311533810182612, 14.633181472256814, 14.947909552843837, 15.256146302392361, 15.558277539625012, 15.854652314068575, 16.145587632539115, 16.431372432027707, 16.712270940838653, 16.98852553931624, 17.260359208313137, 17.527977635768483, 17.79157103799437, 18.05131574151868, 18.30737556287083, 18.559903016987995, 18.809040379562166, 19.054920624342685, 19.297668252926314, 19.537400031734013, 19.774225648555753, 20.008248299139034, 20.23956521272135, 20.468268124098824, 20.69444369873228, 20.91817391647751, 21.139536418758105, 21.358604823349303, 21.57544901039142, 21.790135382782736, 22.002727103702398, 22.21328431367141, 22.421864329265755, 22.62852182534246, 22.83330900242013, 23.03627574066607, 23.237469741776966, 23.436936659896492, 23.634720222587784, 23.830862342768885, 24.02540322242272, 24.218381448808675, 24.409834083827775, 24.59979674712781, 24.788303693476088, 24.975387884875786, 25.161081057856006, 25.345413786324347, 25.528415540334663, 25.710114741089743, 25.890538812469707, 26.069714229350502, 26.247666562953743, 26.424420523447626, 26.60000000000001, 26.774428098467393, 26.947727176888225, 27.11991887893473, 27.291024165465103, 27.461063344306247, 27.630056098386778, 27.798021512330696, 27.964978097613454, 28.130943816374174, 28.29593610397084, 28.459971890358577, 28.623067620365223, 28.785239272932923, 28.946502379389468, 29.10687204080851, 29.266362944513627, 29.42498937977719, 29.58276525276162, 29.739704100747204, 29.895819105687675, 30.05112310713196, 30.205628614547987, 30.35934781908202, 30.512292604784722, 30.66447455933332], [0.0, 3.130495168499706, 4.427188724235731, 5.422176684690385, 6.260990336999412, 7.000000000000001, 7.668115805072326, 8.282511696339464, 8.854377448471462, 9.391485505499118, 9.899494936611665, 10.38267788193393, 10.84435336938077, 11.28716084761797, 11.713240371477058, 12.12435565298214, 12.521980673998824, 12.907362240210043, 13.281566172707196, 13.645512082732553, 14.000000000000002, 14.345731072343439, 14.683323874382122, 15.013327412669055, 15.336231610144653, 15.65247584249853, 15.962455951387934, 16.26653005407115, 16.565023392678928, 16.858232410309217, 17.146428199482248, 17.429859437184227, 17.708754896942924, 17.983325610131185, 18.253766734567417, 18.520259177452136, 18.782971010998235, 19.042058712229622, 19.29766825292631, 19.549936061276522, 19.79898987322333, 20.044949488586898, 20.28792744466522, 20.52802961806125, 20.76535576386786, 21.0, 21.232051243344344, 21.46159360345825, 21.68870673876154, 21.91346617949794, 22.135943621178658, 22.35620719173984, 22.57432169523594, 22.790348834539593, 23.004347415216976, 23.2163735324878, 23.426480742954116, 23.634720222587784, 23.841140912296964, 24.04578965224474, 24.24871130596428, 24.449948875202175, 24.649543606322613, 24.84753508901839, 25.043961347997648, 25.238858928247925, 25.432262974418933, 25.62420730481238, 25.814724480420086, 26.0038458694094, 26.191601707417593, 26.378021153983482, 26.56313234541439, 26.74696244435992, 26.92953768633988, 27.11088342345192, 27.291024165465107, 27.46998361848802, 27.647784721384102, 27.824449680092513, 28.000000000000004, 28.174456516497354, 28.34783942384323, 28.52016830244871, 28.691462144686877, 28.861739379323627, 29.031017894658813, 29.1993150604599, 29.366647748764244, 29.53303235362058, 29.698484809834998, 29.86302061078216, 30.02665482533811, 30.18940211398696, 30.351276744150326, 30.512292604784715, 30.672463220289305, 30.83180176376334, 30.99032106965012, 31.14803364580179, 31.30495168499706, 31.461087075941933], [0.0, 3.2078029864690882, 4.536518488885503, 5.556077753235641, 6.4156059729381765, 7.172865536171719, 7.857480512225278, 8.487048957087499, 9.073036977771006, 9.623408959407264, 10.143963722332607, 10.639078907499465, 11.112155506471282, 11.565898149300816, 12.002499739637573, 12.423767544509193, 12.831211945876353, 13.22611053938383, 13.60955546665651, 13.982489048806729, 14.345731072343439, 14.700000000000001, 15.045929682143274, 15.38408268308514, 15.714961024450556, 16.03901493234544, 16.356650023767095, 16.66823325970692, 16.974097914174997, 17.274547750954294, 17.569860557215588, 17.860291151042304, 18.14607395554201, 18.42742521352346, 18.704544902242343, 18.977618396416343, 19.24681791881453, 19.512303810672897, 19.77422564855575, 20.032723229755863, 20.287927444665215, 20.539961051569698, 20.7889393668845, 21.034970881843407, 21.27815781499893, 21.518596608515157, 21.756378375088076, 21.99158930136701, 22.224311012942565, 22.45462090528362, 22.682592444427513, 22.908295440735003, 23.131796298601632, 23.35315824465719, 23.572441536675832, 23.789703655153, 24.004999479275146, 24.21838144880867, 24.429899713261207, 24.639602269517262, 24.847535089018386, 25.053742235442595, 25.2582659737362, 25.4611468712625, 25.662423891752706, 25.862134482675632, 26.0603146565808, 26.256999066915476, 26.45222107876766, 26.646012834943996, 26.838405317753143, 27.029428406830952, 27.21911093331302, 27.40748073063265, 27.59456468219783, 27.780388766178202, 27.964978097613457, 28.148356968036342, 28.33054888278729, 28.511576596182827, 28.691462144686877, 28.870226878221796, 29.047891489745005, 29.224476043207346, 29.400000000000002, 29.574482243988655, 29.747941105226094, 29.92039438242752, 30.09185936428655, 30.2623528497042, 30.431891166997822, 30.600490192152154, 30.76816536617028, 30.9349317115781, 31.10080384813229, 31.265796007778214, 31.429922048901112, 31.593195469910928, 31.755629422198517, 31.917236722498398, 32.07802986469088, 32.23802103107448], [0.0, 3.283291031876401, 4.64327470649756, 5.686826883245173, 6.566582063752802, 7.341661937191061, 8.04238770515324, 8.6867715521936, 9.28654941299512, 9.849873095629201, 10.382677881933928, 10.889444430272832, 11.373653766490346, 11.838074167701436, 12.28495014234897, 12.716131487209463, 13.133164127505603, 13.537355724069602, 13.92982411949268, 14.311533810182615, 14.683323874382122, 15.045929682143274, 15.4, 15.746110630882791, 16.08477541030648, 16.416455159382007, 16.74156504034196, 17.060480649735517, 17.3735431043872, 17.681063316441126, 17.983325610131182, 18.280590800080834, 18.57309882599024, 18.861071019430476, 19.14471206364828, 19.424211695716252, 19.699746191258402, 19.97147966476195, 20.239565212721345, 20.504145922227536, 20.765355763867856, 21.023320384753692, 21.27815781499893, 21.529979098921576, 21.778888860545663, 22.02498581157318, 22.268363208821615, 22.50910926713894, 22.74730753298069, 22.983037223134808, 23.2163735324878, 23.44738791422192, 23.67614833540287, 23.902719510549424, 24.12716311545972, 24.34953798329652, 24.56990028469794, 24.78830369347608, 25.004799539288452, 25.219436948512552, 25.432262974418926, 25.643322717619885, 25.852659437667143, 26.0603146565808, 26.266328255011206, 26.47073856166465, 26.673582436560714, 26.874895348633455, 27.074711448139205, 27.273063634289425, 27.46998361848802, 27.665501983517306, 27.85964823898536, 28.052450873319426, 28.243937402564818, 28.434134416225863, 28.62306762036523, 28.81076187815935, 28.997241248091175, 29.18252901994617, 29.366647748764244, 29.54961928688761, 29.731464814233426, 29.912204866910095, 30.09185936428655, 30.27044763461552, 30.44798843930417, 30.624499995918306, 30.8, 30.97450564577262, 31.148033645801785, 31.320600249675934, 31.492221261765582, 31.662912058116202, 31.83268760252581, 32.00156246185489, 32.16955082061296, 32.336666494863074, 32.502922945482915, 32.6683332908185, 32.832910318764014, 32.9966664982995], [0.0, 3.357082066318904, 4.747630988187688, 5.814636704042654, 6.714164132637808, 7.5066637063345265, 8.223138087129513, 8.882004278314666, 9.495261976375376, 10.071246198956711, 10.616025621672172, 11.134181604410808, 11.629273408085307, 12.10413152605341, 12.561050911448453, 13.001922934704696, 13.428328265275615, 13.841603953299634, 14.242892964563065, 14.633181472256815, 15.013327412669053, 15.38408268308514, 15.74611063088279, 16.1, 16.446276174259026, 16.785410331594523, 17.11782696489248, 17.44391011212796, 17.76400855662933, 18.078440198202944, 18.387495751189178, 18.691441891946166, 18.990523952750753, 19.28496823953828, 19.574984035753392, 19.860765342755553, 20.142492397913422, 20.420333004140755, 20.69444369873228, 20.964970784620718, 21.232051243344344, 21.495813545897725, 21.756378375088076, 22.013859270922943, 22.268363208821615, 22.519991119003578, 22.768838354206835, 23.014995111883035, 23.258546816170615, 23.499574464232328, 23.73815494093844, 23.974361305361196, 24.20826305210682, 24.43992635013453, 24.669414261388535, 24.896786941290237, 25.122101822896905, 25.345413786324343, 25.566775314849547, 25.78623663895141, 26.003845869409393, 26.219649120459263, 26.433690623898887, 26.646012834943996, 26.85665653055123, 27.065660900853686, 27.273063634289425, 27.478900996946734, 27.683207906599268, 27.88601800185893, 28.087363706834434, 28.28727629164745, 28.48578592912613, 28.68292174796703, 28.878711882630775, 29.073183520213263, 29.26636294451363, 29.45827557750114, 29.648946018366324, 29.838398080325966, 30.026654825338106, 30.213738596870137, 30.399671050851858, 30.58447318493487, 30.76816536617028, 30.950767357207805, 31.132298341111923, 31.312776944883066, 31.49222126176558, 31.670648872418134, 31.848076865016516, 32.02452185435405, 32.2, 32.37452702357211, 32.548118225175486, 32.72078849905668, 32.89255234851805, 33.06342390013473, 33.23341691731382, 33.402544813232424, 33.570820663189046, 33.7382572164005], [0.0, 3.4292856398964493, 4.849742261192857, 5.939696961967, 6.858571279792899, 7.6681158050723255, 8.4, 9.073036977771006, 9.699484522385713, 10.287856919689348, 10.844353369380768, 11.373653766490346, 11.879393923934, 12.364465212858986, 12.831211945876351, 13.281566172707192, 13.717142559585797, 14.13930691370691, 14.549226783578572, 14.94790955284384, 15.336231610144651, 15.714961024450554, 16.08477541030648, 16.446276174259026, 16.8, 17.146428199482248, 17.48599439551552, 17.819090885900998, 18.14607395554201, 18.46726834158209, 18.782971010998235, 19.093454375780198, 19.398969044771427, 19.699746191258406, 19.995999599919983, 20.287927444665215, 20.575713839378697, 20.859530196051878, 21.1395364187581, 21.4158819570897, 21.688706738761535, 21.958141997901375, 22.224311012942565, 22.487329765892614, 22.74730753298069, 23.004347415216976, 23.25854681617061, 23.509997873245332, 23.758787847868, 24.004999479275146, 24.248711305964285, 24.489997958350266, 24.728930425717973, 24.965576300177815, 25.2, 25.432262974418933, 25.662423891752702, 25.8905388124697, 26.116661348648684, 26.340842811117493, 26.563132345414385, 26.783577057592588, 27.00222213078027, 27.219110933313015, 27.434285119171594, 27.647784721384095, 27.85964823898536, 28.069912718068792, 28.27861382741382, 28.48578592912613, 28.69146214468688, 28.89567441677041, 29.098453567157144, 29.299829351038888, 29.499830507987667, 29.698484809834998, 29.89581910568768, 30.091859364286552, 30.286630713897512, 30.480157479908144, 30.672463220289302, 30.863570759068047, 31.053502217946374, 31.242279046189957, 31.42992204890111, 31.616451413781405, 31.801886736481535, 31.98624704462842, 32.16955082061296, 32.35181602321576, 32.5330601081423, 32.71330004753418, 32.89255234851805, 33.07083307084961, 33.248157843706174, 33.4245418816773, 33.6, 33.7745466290815, 33.948195828349995, 34.12096129947104, 34.292856398964496, 34.463894150255285], [0.0, 3.5, 4.949747468305833, 6.062177826491071, 7.0, 7.826237921249264, 8.573214099741124, 9.260129588726068, 9.899494936611665, 10.5, 11.067971810589329, 11.6081867662439, 12.124355652982143, 12.619429464123964, 13.095800853708795, 13.555441711725958, 14.0, 14.430869689661813, 14.8492424049175, 15.256146302392361, 15.652475842498529, 16.03901493234544, 16.416455159382004, 16.785410331594523, 17.146428199482248, 17.500000000000004, 17.84656829757475, 18.186533479473212, 18.520259177452136, 18.848076824970768, 19.170289512680814, 19.487175269905077, 19.79898987322333, 20.105969262883104, 20.408331631958553, 20.70627924084866, 21.0, 21.28966885604377, 21.57544901039142, 21.8574929943944, 22.135943621178658, 22.410934831014973, 22.682592444427513, 22.951034835057, 23.2163735324878, 23.47871376374779, 23.738154940938443, 23.994791101403656, 24.248711305964285, 24.500000000000004, 24.748737341529168, 24.99499949989998, 25.23885892824793, 25.480384612481817, 25.71964229922337, 25.95669470483482, 26.19160170741759, 26.424420523447623, 26.65520587052368, 26.884010117540132, 27.110883423451916, 27.335873865673292, 27.559027559041336, 27.780388766178206, 28.0, 28.217902119044922, 28.434134416225866, 28.64873470155358, 28.861739379323627, 29.073183520213266, 29.283100928692647, 29.491524206117255, 29.698484809835, 29.90401310861136, 30.10813843464919, 30.310889132455355, 30.512292604784722, 30.71237535587243, 30.911163032147467, 31.108680460604567, 31.304951684997057, 31.500000000000004, 31.693847983480964, 31.886517527005047, 32.07802986469088, 32.268405600525114, 32.45766473423497, 32.64582668581086, 32.83291031876401, 33.01893396219811, 33.20391543176798, 33.3878720495931, 33.570820663189046, 33.75277766347535, 33.93375900191431, 34.11378020683137, 34.292856398964496, 34.47100230628637, 34.64823227814083, 34.824560298731704, 35.00000000000001, 35.17456467392312], [0.0, 3.5693136595149495, 5.047771785649585, 6.182232606429494, 7.138627319029899, 7.981227975693966, 8.742997197757758, 9.44351629426243, 10.09554357129917, 10.707940978544848, 11.28716084761797, 11.838074167701436, 12.364465212858988, 12.869343417595166, 13.35514881983724, 13.823892360692048, 14.277254638059798, 14.716657229140049, 15.143315356948758, 15.558277539625012, 15.962455951387932, 16.356650023767095, 16.741565040341957, 17.11782696489248, 17.485994395515515, 17.846568297574752, 18.200000000000003, 18.54669781928848, 18.88703258852486, 19.221342304844377, 19.54993606127652, 19.873097393209747, 20.19108714259834, 20.504145922227536, 20.81249624624591, 21.1163443805977, 21.415881957089695, 21.711287386979155, 22.002727103702398, 22.290356659326925, 22.57432169523594, 22.854758804240316, 23.131796298601632, 23.405554896220682, 23.67614833540287, 23.9436839270819, 24.20826305210682, 24.46998161012795, 24.728930425717977, 24.98519561660465, 25.23885892824793, 25.48999803844638, 25.738686835190332, 25.984995670578826, 26.228991593273275, 26.470738561664653, 26.71029763967448, 26.947727176888222, 27.18308297452664, 27.416418438592597, 27.647784721384095, 27.87723085243583, 28.104803859838622, 28.33054888278729, 28.554509276119596, 28.77672670753225, 28.997241248091175, 29.216091456592892, 29.433314458280098, 29.648946018366324, 29.863020610782165, 30.07557148251717, 30.286630713897516, 30.49622927510875, 30.70439707924583, 30.911163032147467, 31.116555079250023, 31.320600249675934, 31.52332469775357, 31.724753742149055, 31.924911902775865, 32.12382293563455, 32.321509865722554, 32.51799501814342, 32.71330004753419, 32.90744596592085, 33.1004531691033, 33.292341461663526, 33.483130080683914, 33.67283771825594, 33.86148254285391, 34.04908221964287, 34.23565392978496, 34.4212143888039, 34.60577986406318, 34.7893661914097, 34.97198879103103, 35.15366268257122, 35.334402499547096, 35.51422250310431, 35.693136595149504, 35.87115833089309], [0.0, 3.6373066958946425, 5.143928459844674, 6.300000000000001, 7.274613391789285, 8.133265027035575, 8.909545442950499, 9.623408959407264, 10.287856919689348, 10.911920087683926, 11.502173707608488, 12.063581557729862, 12.600000000000001, 13.114495796636637, 13.609555466656508, 14.087228258248674, 14.54922678357857, 14.996999699939987, 15.431785379534025, 15.854652314068579, 16.26653005407115, 16.668233259706923, 17.060480649735517, 17.44391011212796, 17.819090885900998, 18.186533479473216, 18.546697819288482, 18.900000000000002, 19.24681791881453, 19.587496011486515, 19.92234925906079, 20.251666598085208, 20.575713839378697, 20.894736179239022, 21.208960370560366, 21.518596608515157, 21.823840175367852, 22.124872880990754, 22.421864329265755, 22.71497303542314, 23.004347415216976, 23.29012666345978, 23.572441536675832, 23.851415052361148, 24.127163115459723, 24.399795081106728, 24.66941426138854, 24.93611838277963, 25.200000000000003, 25.4611468712625, 25.719642299223374, 25.975565441391264, 26.228991593273275, 26.479992447128836, 26.728636328851497, 26.974988415196773, 27.219110933313015, 27.461063344306243, 27.70090251237313, 27.938682860865153, 28.174456516497347, 28.408273442784235, 28.640181563670296, 28.870226878221796, 29.09845356715714, 29.324904091914775, 29.54961928688761, 29.772638445391436, 29.993999399879975, 30.213738596870137, 30.431891166997826, 30.64849099058549, 30.86357075906805, 31.07716203259236, 31.28929529407781, 31.5, 31.709304628137158, 31.917236722498398, 32.12382293563455, 32.32908906851538, 32.5330601081423, 32.73576026305179, 32.93721299685206, 33.13744105992495, 33.33646651941385, 33.53431078760976, 33.73099464883893, 33.926538284947384, 34.120961299471034, 34.314282740573205, 34.50652112282547, 34.69769444790244, 34.88782022425592, 35.07691548582915, 35.264996809868, 35.452080333881675, 35.638181771801996, 35.82331642938717, 36.00749921891272, 36.190744673189585, 36.37306695894643, 36.55447988961135], [0.0, 3.704051835490427, 5.238320341483518, 6.4156059729381765, 7.408103670980854, 8.282511696339462, 9.073036977771006, 9.8, 10.476640682967036, 11.11215550647128, 11.713240371477058, 12.284950142348972, 12.831211945876353, 13.35514881983724, 13.85929291125633, 14.345731072343437, 14.816207341961707, 15.272196960490001, 15.714961024450556, 16.14558763253912, 16.565023392678924, 16.974097914174997, 17.3735431043872, 17.76400855662933, 18.14607395554201, 18.520259177452136, 18.88703258852486, 19.24681791881453, 19.6, 19.946929588285013, 20.287927444665215, 20.62328780771873, 20.95328136593407, 21.27815781499893, 21.598148068758118, 21.913466179497938, 22.22431101294256, 22.530867715203517, 22.833309002420126, 23.131796298601632, 23.426480742954116, 23.717504084536387, 24.004999479275146, 24.28909220205646, 24.569900284697944, 24.847535089018386, 25.12210182289691, 25.393700006103877, 25.662423891752706, 25.92836284843299, 26.19160170741759, 26.45222107876766, 26.71029763967448, 26.965904397961516, 27.21911093331301, 27.46998361848802, 27.71858582251266, 27.96497809761345, 28.20921835145384, 28.451362006062208, 28.691462144686874, 28.929569647680555, 29.165733318399518, 29.400000000000002, 29.632414683923415, 29.863020610782154, 30.09185936428655, 30.318970958790803, 30.544393920980003, 30.76816536617028, 30.990321069650122, 31.210895533451133, 31.429922048901112, 31.64743275528048, 31.863458694874915, 32.07802986469088, 32.29117526507824, 32.50292294548292, 32.71330004753418, 32.92233284565358, 33.13004678535785, 33.33646651941385, 33.541615941990635, 33.745518220943055, 33.948195828349995, 34.14967056942131, 34.349963609878834, 34.54909550190859, 34.7470862087744, 34.94395512817631, 35.139721114431175, 35.334402499547096, 35.52801711325866, 35.72058230208461, 35.91211494746585, 36.10263148303736, 36.29214791108402, 36.480679818227074, 36.66824239038463, 36.85485042704692, 37.04051835490427, 37.225260240863335], [0.0, 3.769615364994153, 5.331041174104736, 6.529165337162172, 7.539230729988306, 8.429116205154607, 9.233634170791044, 9.973464794142506, 10.662082348209472, 11.308846094982458, 11.920570456148482, 12.502399769644228, 13.058330674324344, 13.59154148726332, 14.10460917572692, 14.599657530229946, 15.078461459976612, 15.542522317822163, 15.99312352231421, 16.431372432027707, 16.858232410309213, 17.274547750954294, 17.681063316441126, 18.078440198202944, 18.467268341582088, 18.848076824970768, 19.221342304844377, 19.58749601148651, 19.946929588285013, 20.300000000000004, 20.647033685253678, 20.98833009079093, 21.324164696418944, 21.65479161756123, 21.980445855350617, 22.301345250903587, 22.617692189964917, 22.929675095822883, 23.237469741776966, 23.541240409120338, 23.841140912296964, 24.13731550939334, 24.42989971326121, 24.719021016213404, 25.004799539288456, 25.28734861546382, 25.566775314849547, 25.843180918764627, 26.116661348648687, 26.387307554959072, 26.65520587052368, 26.92043833224118, 27.18308297452664, 27.44321409747773, 27.70090251237313, 27.956215766802202, 28.20921835145384, 28.45997189035857, 28.70853531617383, 28.954965031925013, 29.19931506045989, 29.44163718273833, 29.681981065959864, 29.920394382427517, 30.156922919953224, 30.391610684529372, 30.624499995918306, 30.855631576747868, 31.085044635644326, 31.312776944883062, 31.538864912992672, 31.763343652707597, 31.98624704462842, 32.207607796916555, 32.427457501321314, 32.64582668581085, 32.862744864055415, 33.07824058198985, 33.292341461663526, 33.5050742425681, 33.71646482061843, 33.92653828494738, 34.135318952662516, 34.34283040170102, 34.54909550190859, 34.75413644445795, 34.95797476971457, 35.16063139364822, 35.36212663288225, 35.5624802284655, 35.76171136844545, 35.959838709315704, 36.15688039640589, 36.352854083276604, 36.54777695017852, 36.741665721629985, 36.934536683164175, 37.12640569729314, 37.317288218733154, 37.507199308932684, 37.696153649941536, 37.88416555765747], [0.0, 3.8340579025361627, 5.422176684690383, 6.640783086353597, 7.6681158050723255, 8.573214099741122, 9.391485505499116, 10.143963722332607, 10.844353369380766, 11.502173707608486, 12.12435565298214, 12.716131487209465, 13.281566172707194, 13.82389236069205, 14.345731072343437, 14.849242404917495, 15.336231610144651, 15.8082257068907, 16.26653005407115, 16.712270940838653, 17.146428199482244, 17.569860557215588, 17.98332561013118, 18.387495751189178, 18.78297101099823, 19.170289512680814, 19.54993606127652, 19.922349259060788, 20.287927444665215, 20.647033685253678, 21.0, 21.347130954767668, 21.68870673876153, 22.024985811573185, 22.356207191739838, 22.68259244442751, 23.004347415216973, 23.321663748540754, 23.634720222587784, 23.9436839270819, 24.24871130596428, 24.549949083450258, 24.847535089018386, 25.141598994495155, 25.43226297441893, 25.719642299223366, 26.003845869409396, 26.28497669772602, 26.563132345414388, 26.83840531775314, 27.110883423451916, 27.380650101851128, 27.6477847213841, 27.912362852327643, 28.174456516497347, 28.43413441622586, 28.691462144686874, 28.94650237938946, 29.19931506045989, 29.44995755514768, 29.69848480983499, 29.944949490690412, 30.18940211398695, 30.431891166997822, 30.672463220289302, 30.91116303214746, 31.148033645801785, 31.383116480043853, 31.6164514137814, 31.848076865016512, 32.07802986469088, 32.30634612580011, 32.5330601081423, 32.758205079033246, 32.98181317029128, 33.20391543176798, 33.42454188167731, 33.643721553954165, 33.861482542853906, 34.07785204498664, 34.29285639896449, 34.50652112282547, 34.71887094938429, 34.929929859649015, 35.139721114431175, 35.34826728426727, 35.55559027776082, 35.76171136844545, 35.96665122026236, 36.17042991173867, 36.373066958946424, 36.574581337316765, 36.774991502378356, 36.97431540948392, 37.17257053258491, 37.369773882109584, 37.56594202199646, 37.7610910859313, 37.95523679283268, 38.1483944616284, 38.34057902536163, 38.53180504466408], [0.0, 3.8974350539810154, 5.511805511808268, 6.750555532695069, 7.794870107962031, 8.714929718592114, 9.546727187890099, 10.311643903859364, 11.023611023616535, 11.692305161943045, 12.324771803161306, 12.926329718833571, 13.501111065390138, 14.052401929919313, 14.58286665919976, 15.094701056993475, 15.589740215924062, 16.069536396548596, 16.535416535424805, 16.98852553931624, 17.429859437184227, 17.860291151042304, 18.280590800080834, 18.691441891946166, 19.093454375780198, 19.48717526990508, 19.873097393209747, 20.251666598085205, 20.62328780771873, 20.98833009079093, 21.347130954767668, 21.7, 22.04722204723307, 22.38905982840727, 22.7257563130471, 23.057536728800844, 23.38461032388609, 23.707171910626542, 24.02540322242272, 24.3394741109992, 24.649543606322613, 24.955760857966247, 25.258265973736204, 25.557190768940156, 25.852659437667143, 26.144789155776337, 26.43369062389889, 26.719468557589238, 27.002222130780275, 27.28204537786711, 27.55902755904134, 27.833253492899463, 28.104803859838626, 28.373755479315744, 28.640181563670296, 28.90415195088761, 29.16573331839952, 29.42498937977718, 29.681981065959867, 29.936766692480337, 30.18940211398695, 30.43994086722246, 30.68843430349616, 30.934931711578095, 31.179480431848123, 31.422125962448813, 31.6629120581162, 31.90188082229636, 32.13907279309719, 32.3745270235721, 32.60828115678593, 32.84037149607172, 33.07083307084961, 33.29969969834563, 33.52700404151853, 33.75277766347534, 33.97705107863248, 34.199853800857106, 34.42121438880389, 34.64116048864415, 34.859718874368454, 35.07691548582914, 35.29277546467549, 35.507323188322715, 35.72058230208461, 35.93257574958968, 36.143325801591644, 36.352854083276604, 36.56118160016167, 36.76832876267291, 36.97431540948392, 37.1791608296906, 37.38288378389233, 37.58550252424464, 37.78703481354419, 37.987497943402374, 38.186908751560395, 38.38528363839455, 38.58263858265787, 38.77898915650072, 38.97435053981016, 39.16873753390579], [0.0, 3.959797974644666, 5.6, 6.8585712797928995, 7.919595949289332, 8.854377448471462, 9.699484522385713, 10.476640682967036, 11.2, 11.879393923933998, 12.521980673998822, 13.133164127505603, 13.717142559585799, 14.277254638059798, 14.816207341961706, 15.33623161014465, 15.839191898578663, 16.32666530556684, 16.8, 17.260359208313137, 17.708754896942924, 18.146073955542008, 18.57309882599024, 18.990523952750753, 19.398969044771427, 19.798989873223334, 20.19108714259834, 20.575713839378697, 20.95328136593407, 21.324164696418944, 21.68870673876153, 22.04722204723307, 22.4, 22.74730753298069, 23.0893915034589, 23.426480742954116, 23.758787847867996, 24.086510747719355, 24.40983408382777, 24.728930425717973, 25.043961347997644, 25.35507838678477, 25.662423891752706, 25.966131787387965, 26.266328255011206, 26.563132345414385, 26.85665653055123, 27.14700720153144, 27.434285119171598, 27.71858582251266, 28.0, 28.27861382741382, 28.554509276119596, 28.8277643947636, 29.098453567157136, 29.366647748764244, 29.63241468392341, 29.895819105687668, 30.15692291995322, 30.415785375360606, 30.6724632202893, 30.92701084812433, 31.17948043184812, 31.42992204890111, 31.678383797157327, 31.924911902775857, 32.16955082061296, 32.412343327812636, 32.65333061113368, 32.892552348518045, 33.130046785357855, 33.365850805876356, 33.6, 33.8325287260648, 34.063470169670026, 34.29285639896449, 34.52071841662627, 34.7470862087744, 34.97198879103103, 35.1954542519343, 35.41750979388585, 35.638181771801996, 35.857495729623956, 36.07547643483035, 36.292147911084015, 36.507533469134835, 36.72165573609121, 36.934536683164175, 37.14619765198048, 37.35665937955373, 37.56594202199646, 37.774065177049714, 37.981047905501505, 38.1869087515604, 38.39166576224585, 38.595336505852615, 38.79793808954285, 38.99948717611554, 39.199999999999996, 39.39949238251681, 39.59797974644667, 39.79547712994531], [0.0, 4.02119385257662, 5.686826883245173, 6.964912059746341, 8.04238770515324, 8.991662805065591, 9.849873095629203, 10.639078907499465, 11.373653766490346, 12.06358155772986, 12.716131487209466, 13.336791218280357, 13.929824119492682, 14.498620624045587, 15.045929682143274, 15.57401682290089, 16.08477541030648, 16.57980699525782, 17.06048064973552, 17.527977635768487, 17.983325610131182, 18.42742521352346, 18.861071019430472, 19.28496823953828, 19.699746191258406, 20.105969262883104, 20.504145922227536, 20.894736179239022, 21.27815781499893, 21.654791617561234, 22.024985811573185, 22.38905982840727, 22.74730753298069, 23.100000000000005, 23.44738791422192, 23.789703655153, 24.12716311545972, 24.459967293518613, 24.788303693476085, 25.11234756051294, 25.432262974418933, 25.748203820849337, 26.060314656580804, 26.368731482572308, 26.673582436560714, 26.974988415196773, 27.273063634289425, 27.567916134521305, 27.859648238985365, 28.148356968036342, 28.434134416225866, 28.717068095472428, 28.997241248091175, 29.274733132857083, 29.54961928688761, 29.821971765797112, 30.09185936428655, 30.359347819082018, 30.624499995918303, 30.887376062074296, 31.14803364580178, 31.40652798384438, 31.662912058116195, 31.917236722498398, 32.16955082061296, 32.41990129534635, 32.6683332908185, 32.914890247424495, 33.15961399051564, 33.402544813232424, 33.64372155395417, 33.883181668786655, 34.12096129947104, 34.357095337062475, 34.59161748169634, 34.824560298731704, 35.05595527153697, 35.285832851159974, 35.51422250310431, 35.741152751415285, 35.966651220262364, 36.190744673189585, 36.413459050191875, 36.63481950276267, 36.85485042704692, 37.07357549522302, 37.29101768522818, 37.507199308932684, 37.722142038860945, 37.93586693354984, 38.1483944616284, 38.35974452469672, 38.56993647907656, 38.77898915650072, 38.9869208838041, 39.193749501674375, 39.39949238251681, 39.60416644748379, 39.80778818271621, 40.010373654841075, 40.21193852576621, 40.412498066810976], [0.0, 4.08166632639171, 5.772347875864725, 7.069653456853455, 8.16333265278342, 9.126883367283709, 9.99799979995999, 10.799074034379059, 11.54469575172945, 12.244998979175131, 12.907362240210043, 13.537355724069602, 14.13930691370691, 14.716657229140047, 15.27219696049, 15.808225706890699, 16.32666530556684, 16.829141392239833, 17.317043627594177, 17.791571037994373, 18.253766734567417, 18.704544902242343, 19.14471206364828, 19.574984035753392, 19.99599959991998, 20.408331631958553, 20.81249624624591, 21.208960370560362, 21.598148068758118, 21.980445855350617, 22.356207191739838, 22.725756313047096, 23.0893915034589, 23.44738791422192, 23.8, 24.147463634924478, 24.489997958350262, 24.82780699135548, 25.161081057856002, 25.489998038446377, 25.814724480420086, 26.13541658363226, 26.45222107876766, 26.765276012027222, 27.074711448139205, 27.380650101851124, 27.683207906599268, 27.98249452782936, 28.27861382741382, 28.571664284741974, 28.861739379323627, 29.148927939119822, 29.433314458280094, 29.71497938750758, 29.99399939987997, 30.270447634615515, 30.54439392098, 30.815904984277193, 31.085044635644326, 31.35187394718217, 31.616451413781398, 31.87883310285996, 32.139072793097185, 32.39722210313718, 32.65333061113368, 32.90744596592084, 33.15961399051564, 33.409878778588826, 33.65828278447967, 33.90486690727454, 34.14967056942132, 34.39273179030709, 34.634087255188355, 34.873772379827216, 35.111821371156466, 35.34826728426727, 35.58314207598875, 35.81647665530489, 36.04830093083446, 36.27864385557983, 36.507533469134835, 36.734996937525395, 36.961060590843445, 37.18574995882159, 37.40908980448469, 37.631104156003715, 37.851816336868175, 38.071248994484016, 38.28942412729656, 38.50636311053018, 38.72208672063013, 38.936615158485466, 39.149968071506784, 39.36216457462674, 39.5732232702872, 39.7831622674719, 39.99199919983996, 40.19975124301145, 40.40643513105307, 40.61206717220881, 40.81666326391711, 41.020238907154116], [0.0, 4.141255848169731, 5.856620185738529, 7.172865536171719, 8.282511696339462, 9.260129588726066, 10.143963722332607, 10.956733089748969, 11.713240371477058, 12.423767544509193, 13.095800853708795, 13.734991809244008, 14.345731072343439, 14.931510305391079, 15.495160534825057, 16.039014932345438, 16.565023392678924, 17.074835284710655, 17.569860557215588, 18.051315741518682, 18.520259177452132, 18.977618396416343, 19.42421169571625, 19.860765342755553, 20.287927444665215, 20.70627924084866, 21.1163443805977, 21.518596608515157, 21.913466179497938, 22.30134525090359, 22.68259244442751, 23.057536728800844, 23.426480742954116, 23.789703655153, 24.147463634924478, 24.5, 24.847535089018386, 25.190275901625217, 25.528415540334656, 25.862134482675636, 26.19160170741759, 26.51697569482614, 26.83840531775314, 27.15603063777915, 27.469983618488016, 27.7803887661782, 28.087363706834434, 28.391019706942544, 28.691462144686877, 28.98879093718812, 29.283100928692644, 29.574482243988655, 29.863020610782158, 30.148797654301244, 30.43189116699782, 30.712375355872428, 30.990321069650115, 31.26579600777821, 31.53886491299267, 31.80958974900494, 32.078029864690876, 32.34424214601418, 32.60828115678592, 32.87019926924691, 33.13004678535785, 33.38787204959309, 33.643721553954165, 33.89764003584911, 34.14967056942131, 34.39985465085572, 34.64823227814083, 34.89484202572065, 35.139721114431175, 35.38290547708031, 35.62442981999852, 35.864327680858594, 36.102631483037364, 36.339372586768754, 36.57458133731677, 36.80828711037774, 37.040518354904265, 37.27130263352758, 37.500666660740855, 37.72863633899322, 37.955236792832686, 38.180492401225, 38.40442682816657, 38.627063051699906, 38.8484233914325, 39.068529534652306, 39.287402561126385, 39.50506296666289, 39.721530685511105, 39.936825111668554, 40.15096511915997, 40.36396908134778, 40.57585488933043, 40.786639969480206, 40.996341300169696, 41.20497542773203, 41.41255848169732, 41.6191061893453], [0.0, 4.2, 5.939696961966999, 7.274613391789285, 8.4, 9.391485505499116, 10.287856919689348, 11.11215550647128, 11.879393923933998, 12.599999999999998, 13.281566172707192, 13.929824119492679, 14.54922678357857, 15.143315356948754, 15.714961024450552, 16.266530054071147, 16.8, 17.317043627594174, 17.819090885900998, 18.30737556287083, 18.78297101099823, 19.24681791881453, 19.699746191258402, 20.142492397913422, 20.575713839378697, 21.000000000000004, 21.4158819570897, 21.823840175367852, 22.22431101294256, 22.61769218996492, 23.004347415216976, 23.38461032388609, 23.758787847867996, 24.127163115459723, 24.489997958350262, 24.847535089018386, 25.199999999999996, 25.547602627252523, 25.8905388124697, 26.228991593273275, 26.563132345414385, 26.89312179721797, 27.219110933313015, 27.5412418020684, 27.859648238985358, 28.174456516497347, 28.485785929126127, 28.793749321684384, 29.09845356715714, 29.4, 29.698484809834998, 29.99399939987997, 30.28663071389751, 30.57646153497818, 30.863570759068043, 31.148033645801785, 31.429922048901105, 31.709304628137147, 31.986247044628414, 32.260812141048156, 32.533060108142294, 32.80304863880795, 33.0708330708496, 33.33646651941384, 33.6, 33.861482542853906, 34.120961299471034, 34.37848164186429, 34.63408725518835, 34.88782022425592, 35.139721114431175, 35.389829047340704, 35.638181771801996, 35.88481573033363, 36.129766121579024, 36.373066958946424, 36.61475112574166, 36.85485042704691, 37.09339563857696, 37.330416552725474, 37.56594202199646, 37.800000000000004, 38.03261758017715, 38.26382103240605, 38.49363583762906, 38.72208672063013, 38.949197681081955, 39.17499202297303, 39.399492382516804, 39.62272075463773, 39.844698518121575, 40.06544645951172, 40.284984795826844, 40.503333196170416, 40.72051080229717, 40.93653624819765, 41.15142767875739, 41.36520276754364, 41.57787873376899, 41.789472358478044, 42.00000000000001, 42.20947760870774], [0.0, 4.257933771208754, 6.021627686929839, 7.374957626996919, 8.515867542417508, 9.521029356114811, 10.429765098025939, 11.265433857601758, 12.043255373859678, 12.773801313626262, 13.464768843169942, 14.12196870128241, 14.749915253993837, 15.352198539622917, 15.931729347437459, 16.490906585145645, 17.031735084835017, 17.555910685578237, 18.06488306078952, 18.559903016988, 19.042058712229622, 19.512303810672897, 19.971479664761947, 20.420333004140755, 20.859530196051878, 21.28966885604377, 21.711287386979155, 22.124872880990754, 22.530867715203517, 22.929675095822883, 23.321663748540754, 23.707171910626542, 24.086510747719355, 24.459967293518613, 24.82780699135548, 25.190275901625217, 25.547602627252523, 25.900000000000002, 26.247666562953746, 26.590787878511616, 26.929537686339884, 27.26407893181063, 27.594564682197834, 27.92113894525078, 28.24393740256482, 28.56308806834443, 28.878711882630782, 29.19092324679026, 29.499830507987674, 29.80553639846128, 30.108138434649195, 30.407729280562865, 30.704397079245833, 30.998225755678344, 31.289295294077814, 31.57768199219189, 31.863458694874918, 32.14669500897409, 32.427457501321314, 32.70580988142627, 32.98181317029129, 33.25552585661517, 33.52700404151853, 33.79630157280528, 34.06347016967003, 34.328559538669836, 34.591617481696346, 34.85268999661289, 35.11182137115647, 35.36905427064739, 35.624429819998525, 35.877987680470596, 36.12976612157904, 36.37980208852159, 36.62813126546316, 36.874788134984584, 37.119806033976, 37.363217206231056, 37.60505285197722, 37.845343174557165, 38.084117424459244, 38.32140394087879, 38.55723019097716, 38.79162280699275, 39.024607621345794, 39.256209699867874, 39.48645337327728, 39.715362267012, 39.942959329523894, 40.16926685913, 40.39430652950983, 40.618099413931226, 40.84066600828151, 41.06202625297491, 41.282199553802855, 41.50120480178859, 41.719060392103756, 41.93578424210045, 42.15139380850887, 42.36590610384724, 42.57933771208754, 42.791704803618195], [0.0, 4.315089802078284, 6.102458520956943, 7.473954776421919, 8.630179604156568, 9.648834126463155, 10.56976820937905, 11.416654501210065, 12.204917041913886, 12.94526940623485, 13.64551208273255, 14.311533810182612, 14.947909552843837, 15.55827753962501, 16.145587632539115, 16.71227094083865, 17.260359208313137, 17.79157103799437, 18.30737556287083, 18.80904037956217, 19.29766825292631, 19.77422564855575, 20.239565212721345, 20.69444369873228, 21.1395364187581, 21.57544901039142, 22.002727103702398, 22.421864329265755, 22.83330900242013, 23.23746974177697, 23.634720222587784, 24.02540322242272, 24.40983408382777, 24.788303693476088, 25.161081057856002, 25.52841554033466, 25.8905388124697, 26.247666562953746, 26.6, 26.947727176888225, 27.2910241654651, 27.630056098386778, 27.964978097613454, 28.29593610397083, 28.623067620365223, 28.946502379389464, 29.266362944513627, 29.582765252761618, 29.895819105687675, 30.205628614547987, 30.51229260478472, 30.8159049842772, 31.11655507925002, 31.41432794124363, 31.70930462813715, 32.001562461854896, 32.29117526507823, 32.57821357901627, 32.86274486405541, 33.1448336849048, 33.4245418816773, 33.701928728190026, 33.97705107863247, 34.24996350363019, 34.52071841662627, 34.78936619140969, 35.055955271536966, 35.32053227232002, 35.58314207598874, 35.84382792057791, 36.102631483037364, 36.35959295701755, 36.61475112574166, 36.868143430338336, 37.11980603397598, 37.36977388210959, 37.61808075912434, 37.86475934163586, 38.10984124868536, 38.353357089047634, 38.59533650585262, 38.83580821870456, 39.074800063468025, 39.31233902987712, 39.5484512971115, 39.78316226747191, 40.016496598278074, 40.24847823210215, 40.47913042544269, 40.70847577593639, 40.93653624819765, 41.16333319836964, 41.38888739746456, 41.61321905356519, 41.83634783295503, 42.05829288023944, 42.2790728375162, 42.49870586264952, 42.7172096466986, 42.934601430547836, 43.15089802078284, 43.36611580485392], [0.0, 4.371498598878879, 6.182232606429493, 7.571657678474379, 8.742997197757758, 9.77496803063826, 10.70794097854485, 11.565898149300816, 12.364465212858986, 13.114495796636637, 13.823892360692051, 14.498620624045587, 15.143315356948758, 15.761662348876785, 16.35665002376709, 16.930741271426953, 17.485994395515515, 18.02415046541723, 18.546697819288482, 19.054920624342685, 19.54993606127652, 20.03272322975586, 20.504145922227536, 20.964970784620718, 21.4158819570897, 21.8574929943944, 22.290356659326925, 22.714973035423135, 23.131796298601632, 23.541240409120338, 23.9436839270819, 24.339474110999195, 24.728930425717973, 25.11234756051294, 25.489998038446377, 25.862134482675636, 26.228991593273275, 26.590787878511616, 26.947727176888225, 27.300000000000008, 27.647784721384102, 27.991248632385094, 28.33054888278729, 28.66583332122058, 28.997241248091175, 29.324904091914778, 29.648946018366324, 29.969484480050706, 30.286630713897516, 30.600490192152154, 30.911163032147467, 31.218744369368867, 31.52332469775357, 31.82499018067406, 32.12382293563455, 32.41990129534636, 32.71330004753418, 33.0040906555536, 33.292341461663526, 33.57811787459208, 33.861482542853906, 34.14249551512016, 34.42121438880389, 34.69769444790245, 34.97198879103103, 35.244148450487494, 35.51422250310431, 35.782258173569765, 36.04830093083446, 36.31239457816023, 36.57458133731677, 36.83490192738404, 37.093395638576965, 37.35010040147148, 37.60505285197722, 37.85828839237189, 38.10984124868537, 38.35974452469672, 38.6080302527855, 38.854729441858176, 39.09987212255304, 39.34348738990992, 39.58560344367635, 39.826247626408396, 40.06544645951172, 40.303225677357396, 40.53961025959673, 40.77462446178996, 41.00829184445507, 41.24063530063522, 41.47167708207615, 41.70143882409815, 41.929941569241436, 42.157205789757946, 42.383251409017696, 42.60809782189297, 42.8317639141794, 43.054268081108994, 43.27562824500645, 43.495861872136764, 43.7149859887888, 43.93301719663698], [0.0, 4.427188724235731, 6.260990336999411, 7.668115805072326, 8.854377448471462, 9.899494936611665, 10.844353369380768, 11.713240371477058, 12.521980673998822, 13.281566172707192, 14.0, 14.683323874382122, 15.336231610144653, 15.962455951387932, 16.565023392678924, 17.146428199482244, 17.708754896942924, 18.253766734567417, 18.782971010998235, 19.297668252926314, 19.79898987322333, 20.287927444665215, 20.765355763867856, 21.232051243344344, 21.688706738761535, 22.135943621178658, 22.57432169523594, 23.004347415216976, 23.426480742954116, 23.841140912296964, 24.24871130596428, 24.649543606322613, 25.043961347997644, 25.432262974418933, 25.814724480420086, 26.19160170741759, 26.563132345414385, 26.929537686339884, 27.2910241654651, 27.647784721384102, 28.0, 28.347839423843226, 28.691462144686877, 29.031017894658806, 29.366647748764244, 29.698484809834994, 30.026654825338106, 30.35127674415032, 30.672463220289305, 30.99032106965012, 31.304951684997057, 31.616451413781405, 31.924911902775865, 32.23042041301975, 32.5330601081423, 32.83291031876401, 33.13004678535785, 33.4245418816773, 33.71646482061843, 34.005881844175136, 34.29285639896449, 34.57744929863971, 34.85971887436845, 35.139721114431175, 35.41750979388585, 35.69313659514949, 35.966651220262364, 36.2381014955254, 36.507533469134835, 36.774991502378356, 37.04051835490427, 37.304155264527836, 37.56594202199647, 37.825917041097625, 38.08411742445924, 38.34057902536163, 38.59533650585263, 38.848423391432505, 39.09987212255304, 39.349714103154554, 39.59797974644666, 39.84469851812158, 40.089898977173796, 40.33360881448621, 40.57585488933043, 40.81666326391711, 41.05605923612251, 41.294067370507356, 41.53071152773571, 41.76601489249363, 42.0, 42.2326887611954, 42.46410248668869, 42.69426190953534, 42.9231872069165, 43.15089802078283, 43.37741347752307, 43.60275220671283, 43.826932358995876, 44.04997162314637, 44.271887242357316, 44.492696029797976], [0.0, 4.4821869662029945, 6.338769596696192, 7.763375554486593, 8.964373932405989, 10.022474744293447, 10.979070998950686, 11.858752042268193, 12.677539193392384, 13.446560898608983, 14.173919711921613, 14.865732407116713, 15.526751108973187, 16.160754932861277, 16.770807970995318, 17.35943547469214, 17.928747864811978, 18.480530295421723, 19.01630879008858, 19.537400031734013, 20.044949488586894, 20.539961051569698, 21.02332038475369, 21.495813545897725, 21.95814199790137, 22.410934831014973, 22.854758804240316, 23.290126663459777, 23.717504084536387, 24.13731550939334, 24.549949083450255, 24.955760857966244, 25.35507838678477, 25.748203820849334, 26.13541658363226, 26.516975694826137, 26.893121797217965, 27.26407893181063, 27.630056098386774, 27.991248632385094, 28.347839423843226, 28.700000000000006, 29.047891489745005, 29.39166548530382, 29.731464814233426, 30.06742423288034, 30.399671050851854, 30.72832569470716, 31.053502217946374, 31.37530876342096, 31.693847983480964, 32.0092174224863, 32.321509865722554, 32.63081365825867, 32.93721299685206, 33.24078819763455, 33.541615941990635, 33.8397695027611, 34.13531895266251, 34.42833135660223, 34.71887094938428, 35.00699930013997, 35.292775464675486, 35.57625612680458, 35.857495729623956, 36.136546597592854, 36.413459050191875, 36.68828150786025, 36.961060590843445, 37.231841211522166, 37.500666660740855, 37.76757868860539, 38.03261758017716, 38.295822226451804, 38.55723019097715, 38.81687777243296, 39.074800063468025, 39.331031006064414, 39.58560344367634, 39.83854917037016, 40.08989897717379, 40.33968269582695, 40.58792924010784, 40.83466664489867, 41.079922103139396, 41.323722000807244, 41.56609195004987, 41.80705682058952, 42.04664076950738, 42.28486726950908, 42.52175913576484, 42.75733855141127, 42.99162709179545, 43.224645747536215, 43.45641494647253, 43.68695457456379, 43.91628399580274, 44.144422071197184, 44.37138717687334, 44.59719722135014, 44.82186966202995, 45.04542152094928], [0.0, 4.536518488885503, 6.4156059729381765, 7.857480512225278, 9.073036977771006, 10.143963722332607, 11.112155506471282, 12.002499739637575, 12.831211945876353, 13.609555466656508, 14.345731072343439, 15.045929682143276, 15.714961024450556, 16.356650023767095, 16.974097914174997, 17.569860557215584, 18.14607395554201, 18.704544902242343, 19.246817918814532, 19.774225648555753, 20.287927444665215, 20.7889393668845, 21.27815781499893, 21.75637837508808, 22.224311012942565, 22.682592444427517, 23.131796298601632, 23.572441536675832, 24.00499947927515, 24.42989971326121, 24.84753508901839, 25.258265973736204, 25.662423891752706, 26.060314656580804, 26.45222107876766, 26.838405317753143, 27.219110933313015, 27.594564682197838, 27.964978097613454, 28.330548882787294, 28.691462144686877, 29.047891489745005, 29.400000000000006, 29.74794110522609, 30.091859364286552, 30.431891166997822, 30.76816536617028, 31.100803848132287, 31.429922048901112, 31.75562942219852, 32.07802986469088, 32.39722210313718, 32.71330004753419, 33.026353113839264, 33.33646651941385, 33.643721553954165, 33.948195828349995, 34.24996350363019, 34.54909550190859, 34.8456597010302, 35.13972111443117, 35.431342057562546, 35.72058230208461, 36.00749921891273, 36.29214791108402, 36.574581337316765, 36.85485042704692, 37.13300418764957, 37.40908980448469, 37.68315273434536, 37.95523679283269, 38.22538423613293, 38.493635837629064, 38.76003095973996, 39.02460762134579, 39.287402561126385, 39.548451297111505, 39.80778818271621, 40.065446459511726, 40.32145830696108, 40.57585488933043, 40.82866639996953, 41.079922103139396, 41.32965037355143, 41.577878733769, 41.82463388961104, 42.06994176368682, 42.31382752718076, 42.55631562999786, 42.797429829371765, 43.037193217030314, 43.27562824500645, 43.51275675017616, 43.74859997759929, 43.983178602734036, 44.21651275259052, 44.44862202588513, 44.67952551225226, 44.90924181056723, 45.13778904642983, 45.36518488885503, 45.5914465662146], [0.0, 4.5902069670114, 6.491532946846992, 7.950471684120383, 9.1804139340228, 10.264014809030625, 11.243664882946307, 12.14454610102823, 12.983065893693984, 13.7706209010342, 14.515508947329403, 15.22399421965208, 15.900943368240766, 16.550226584551645, 17.174981804939414, 17.777795138880407, 18.3608278680456, 18.925908168434084, 19.474598840540978, 20.008248299139034, 20.52802961806125, 21.034970881843407, 21.529979098921576, 22.013859270922943, 22.487329765892614, 22.951034835057005, 23.405554896220682, 23.851415052361148, 24.28909220205646, 24.719021016213407, 25.14159899449516, 25.557190768940156, 25.96613178738797, 26.368731482572308, 26.765276012027226, 27.15603063777915, 27.5412418020684, 27.92113894525078, 28.29593610397083, 28.66583332122058, 29.031017894658806, 29.391665485303825, 29.74794110522609, 30.099999999999994, 30.44798843930416, 30.792044427091874, 31.13229834111192, 31.46887351018463, 31.80188673648153, 32.1314487690798, 32.45766473423496, 32.78063452711067, 33.10045316910329, 33.41721113438403, 33.730994648838916, 34.04188596420592, 34.34996360987883, 34.655302624562374, 34.95797476971456, 35.258048726496476, 35.555590277760814, 35.85066247644526, 36.14332580159164, 36.43363830308469, 36.7216557360912, 37.00743168608164, 37.29101768522817, 37.572463320895, 37.85181633686817, 38.1291227279097, 38.40442682816657, 38.67777139391565, 38.949197681081955, 39.21874551792802, 39.486453373277264, 39.75235842060191, 40.01649659827807, 40.278902666284246, 40.53961025959672, 40.79865193851385, 41.0560592361225, 41.311862703102605, 41.56609195004987, 41.81877568748276, 42.06994176368681, 42.31961720053715, 42.56782822743016, 42.81460031344448, 43.05995819784315, 43.303925919020315, 43.54652684198821, 43.787783684493554, 44.027718541845886, 44.26635291053466, 44.503707710706536, 44.73980330756942, 44.97465953178523, 45.20829569890907, 45.44073062792894, 45.671982658956246, 45.90206967011401, 46.13100909366714], [0.0, 4.64327470649756, 6.566582063752802, 8.042387705153242, 9.28654941299512, 10.38267788193393, 11.373653766490346, 12.284950142348972, 13.133164127505603, 13.929824119492679, 14.683323874382122, 15.400000000000002, 16.084775410306484, 16.74156504034196, 17.3735431043872, 17.98332561013118, 18.57309882599024, 19.14471206364828, 19.699746191258406, 20.23956521272135, 20.76535576386786, 21.27815781499893, 21.778888860545663, 22.26836320882162, 22.74730753298069, 23.216373532487804, 23.67614833540287, 24.127163115459723, 24.569900284697944, 25.004799539288456, 25.432262974418933, 25.852659437667146, 26.266328255011206, 26.673582436560714, 27.074711448139205, 27.46998361848802, 27.859648238985358, 28.243937402564825, 28.623067620365223, 28.99724124809118, 29.366647748764244, 29.73146481423343, 30.091859364286552, 30.44798843930416, 30.800000000000004, 31.148033645801785, 31.492221261765586, 31.832687602525805, 32.16955082061297, 32.50292294548292, 32.832910318764014, 33.15961399051564, 33.48313008068392, 33.803550109418985, 34.120961299471034, 34.435446853496764, 34.7470862087744, 35.05595527153696, 35.36212663288225, 35.665669767999596, 35.96665122026236, 36.265134771568135, 36.56118160016167, 36.85485042704692, 37.14619765198048, 37.43527747993863, 37.72214203886095, 38.00684148939504, 38.28942412729656, 38.56993647907656, 38.84842339143251, 39.12492811494994, 39.39949238251681, 39.67215648285331, 39.942959329523894, 40.2119385257662, 40.4791304254427, 40.744570190394704, 41.00829184445507, 41.270328324354296, 41.53071152773572, 41.789472358478044, 42.04664076950739, 42.30224580326676, 42.55631562999786, 42.80887758397784, 43.059958197843166, 43.30958323512246, 43.55777772109133, 43.804565972053645, 44.04997162314637, 44.29401765475785, 44.53672641764324, 44.77811965681454, 45.018218534277885, 45.25704365068492, 45.49461506596138, 45.73095231897102, 45.96607444626961, 46.20000000000001, 46.43274706497561, 46.66433327499709], [0.0, 4.695742752749558, 6.640783086353596, 8.133265027035575, 9.391485505499116, 10.499999999999998, 11.502173707608488, 12.423767544509193, 13.281566172707192, 14.087228258248674, 14.849242404917497, 15.57401682290089, 16.26653005407115, 16.930741271426953, 17.569860557215584, 18.18653347947321, 18.78297101099823, 19.361043360315062, 19.92234925906079, 20.468268124098827, 20.999999999999996, 21.518596608515157, 22.02498581157318, 22.519991119003578, 23.004347415216976, 23.47871376374779, 23.9436839270819, 24.399795081106724, 24.847535089018386, 25.28734861546382, 25.719642299223366, 26.144789155776337, 26.563132345414385, 26.974988415196773, 27.380650101851124, 27.7803887661782, 28.174456516497347, 28.56308806834443, 28.946502379389464, 29.324904091914778, 29.698484809834994, 30.06742423288034, 30.43189116699782, 30.792044427091874, 31.14803364580178, 31.499999999999996, 31.848076865016512, 32.19239040518737, 32.5330601081423, 32.8701992692469, 33.20391543176798, 33.534310787609755, 33.861482542853906, 34.185523251809386, 34.50652112282546, 34.8245602987317, 35.13972111443117, 35.452080333881675, 35.76171136844544, 36.0686844783671, 36.37306695894642, 36.67492331280326, 36.974315409483914, 37.27130263352758, 37.56594202199646, 37.85828839237188, 38.14839446162839, 38.436310957218566, 38.722086720630124, 39.00576880411409, 39.287402561126385, 39.567031730975216, 39.84469851812158, 40.12044366653987, 40.39430652950981, 40.66632513517787, 40.936536248197655, 41.20497542773202, 41.47167708207615, 41.73667452013876, 41.99999999999999, 42.26168477474602, 42.52175913576484, 42.78025245367306, 43.037193217030314, 43.292609068985435, 43.54652684198821, 43.79897259068984, 44.04997162314636, 44.29954853043086, 44.54772721475249, 44.79453091617324, 45.039982238007156, 45.28410317098043, 45.52691511622548, 45.768438907177064, 46.00869483043395, 46.247702645645006, 46.48548160447517, 46.722050468702676, 46.95742752749558, 47.19163061391289], [0.0, 4.747630988187688, 6.714164132637808, 8.223138087129513, 9.495261976375376, 10.616025621672172, 11.629273408085306, 12.561050911448453, 13.428328265275615, 14.242892964563062, 15.013327412669053, 15.746110630882791, 16.446276174259026, 17.11782696489248, 17.764008556629328, 18.387495751189174, 18.990523952750753, 19.57498403575339, 20.142492397913426, 20.694443698732282, 21.232051243344344, 21.756378375088076, 22.26836320882161, 22.768838354206835, 23.25854681617061, 23.738154940938443, 24.20826305210682, 24.669414261388535, 25.122101822896905, 25.566775314849547, 26.003845869409393, 26.43369062389889, 26.85665653055123, 27.273063634289425, 27.683207906599268, 28.08736370683443, 28.485785929126124, 28.87871188263078, 29.266362944513624, 29.648946018366324, 30.026654825338106, 30.399671050851854, 30.768165366170276, 31.132298341111916, 31.492221261765582, 31.848076865016512, 32.2, 32.54811822517548, 32.89255234851805, 33.23341691731382, 33.57082066318904, 33.90486690727454, 34.23565392978496, 34.56327530775983, 34.88782022425592, 35.20937375188602, 35.528017113258656, 35.8438279205779, 36.15688039640588, 36.4672455773671, 36.77499150237835, 37.08018338681728, 37.382883783892325, 37.68315273434536, 37.981047905501505, 38.27662472057848, 38.56993647907655, 38.86103446898963, 39.14996807150678, 39.436784858809176, 39.721530685511105, 40.00424977424274, 40.28498479582685, 40.563776944461175, 40.840666008281495, 41.11569043564756, 41.388887397464565, 41.660292845826234, 41.92994156924143, 42.1978672446843, 42.46410248668869, 42.72867889368919, 42.99162709179545, 43.25297677617114, 43.51275675017615, 43.77099496241775, 44.02771854184589, 44.282953831017196, 44.53672641764322, 44.78906116452989, 45.039982238007156, 45.289513134941075, 45.53767670841367, 45.78449519214993, 46.02999022376608, 46.274182866907545, 46.51709363234122, 46.75874249806127, 46.99914892846465, 47.238331892648375, 47.47630988187689, 47.71310092626553], [0.0, 4.798958220280731, 6.786751800382861, 8.312039460926544, 9.597916440561463, 10.730796801729124, 11.754998936622666, 12.696850003051939, 13.573503600765722, 14.396874660842192, 15.17563837207516, 15.916343801262903, 16.624078921853087, 17.302889932031587, 17.956057473732923, 18.586285266292453, 19.195832881122925, 19.7866116351436, 20.360255401148585, 20.918173916477514, 21.461593603458248, 21.99158930136701, 22.509109267138935, 23.01499511188304, 23.509997873245332, 23.994791101403656, 24.469981610127952, 24.936118382779625, 25.393700006103877, 25.843180918764627, 26.284976697726023, 26.71946855758924, 27.147007201531444, 27.567916134521308, 27.98249452782936, 28.391019706942547, 28.793749321684384, 29.190923246790263, 29.582765252761618, 29.96948448005071, 30.35127674415032, 30.72832569470716, 31.100803848132287, 31.46887351018463, 31.832687602525805, 32.19239040518737, 32.54811822517548, 32.9, 33.248157843706174, 33.59270754196512, 33.933759001914304, 34.27141666170222, 34.60577986406317, 34.93694319770979, 35.264996809867995, 35.59002669288125, 35.912114947465845, 36.231340024901094, 36.547776950178516, 36.86149752790844, 37.172570532584906, 37.48106188463716, 37.78703481354418, 38.09055000915582, 38.39166576224585, 38.690438095219335, 38.986920883804096, 39.281165970474966, 39.5732232702872, 39.86314086973078, 40.15096511915997, 40.4367407193013, 40.72051080229717, 41.00231700770092, 41.28219955380284, 41.56019730463271, 41.83634783295503, 42.110687479546094, 42.383251409017696, 42.65407366242995, 42.923187206916495, 43.19062398252658, 43.45641494647253, 43.72059011495613, 43.98317860273402, 44.244208660569356, 44.503707710706536, 44.761702380494874, 45.01821853427787, 45.27328130365635, 45.52691511622548, 45.77914372287887, 46.02999022376608, 46.279477092983676, 46.527626202074835, 46.774458842406716, 47.019995746490665, 47.26425710830543, 47.50726260268002, 47.74903140378871, 47.98958220280731, 48.22893322477702], [0.0, 4.849742261192857, 6.8585712797928995, 8.400000000000002, 9.699484522385713, 10.84435336938077, 11.879393923934, 12.831211945876355, 13.717142559585799, 14.54922678357857, 15.336231610144653, 16.084775410306484, 16.800000000000004, 17.48599439551552, 18.14607395554201, 18.78297101099823, 19.398969044771427, 19.995999599919983, 20.5757138393787, 21.139536418758105, 21.68870673876154, 22.224311012942565, 22.74730753298069, 23.258546816170615, 23.758787847868, 24.24871130596429, 24.728930425717977, 25.200000000000003, 25.66242389175271, 26.116661348648687, 26.563132345414388, 27.00222213078028, 27.434285119171598, 27.859648238985365, 28.278613827413825, 28.69146214468688, 29.09845356715714, 29.499830507987674, 29.895819105687675, 30.28663071389752, 30.672463220289305, 31.053502217946377, 31.429922048901112, 31.80188673648153, 32.16955082061297, 32.5330601081423, 32.89255234851805, 33.248157843706174, 33.60000000000001, 33.94819582835, 34.2928563989645, 34.634087255188355, 34.97198879103104, 35.306656596171784, 35.638181771801996, 35.966651220262364, 36.29214791108402, 36.61475112574166, 36.934536683164175, 37.25157714782021, 37.56594202199646, 37.87769792371232, 38.186908751560395, 38.493635837629064, 38.79793808954285, 39.09987212255304, 39.39949238251682, 39.69685126052192, 39.99199919983997, 40.28498479582685, 40.57585488933044, 40.86465465411399, 41.1514276787574, 41.43621604345648, 41.71906039210375, 42.00000000000001, 42.27907283751621, 42.55631562999787, 42.8317639141794, 43.10545209135384, 43.37741347752308, 43.64768035073572, 43.91628399580276, 44.183254746566604, 44.44862202588513, 44.71241438347968, 44.97465953178524, 45.23538437992985, 45.49461506596138, 45.752376987430935, 46.00869483043396, 46.263592597203264, 46.51709363234123, 46.769220647772194, 47.01999574649067, 47.269440445175576, 47.517575695736, 47.76442190584956, 48.0099989585503, 48.25432623091945, 48.49742261192858, 48.7393065194818], [0.0, 4.9, 6.929646455628165, 8.487048957087499, 9.8, 10.956733089748969, 12.002499739637573, 12.964181424216495, 13.85929291125633, 14.7, 15.49516053482506, 16.25146147274146, 16.974097914174997, 17.667201249773548, 18.334121195192314, 18.97761839641634, 19.6, 20.203217565526536, 20.7889393668845, 21.358604823349303, 21.913466179497938, 22.454620905283615, 22.983037223134804, 23.499574464232328, 24.004999479275146, 24.500000000000004, 24.98519561660465, 25.461146871262496, 25.92836284843299, 26.387307554959072, 26.83840531775314, 27.282045377867107, 27.71858582251266, 28.148356968036342, 28.571664284741974, 28.988790937188117, 29.4, 29.80553639846128, 30.205628614547987, 30.600490192152154, 30.99032106965012, 31.375308763420964, 31.755629422198517, 32.1314487690798, 32.50292294548292, 32.8701992692469, 33.23341691731382, 33.59270754196512, 33.948195828349995, 34.300000000000004, 34.64823227814083, 34.99299929985997, 35.334402499547096, 35.672538457474545, 36.00749921891272, 36.33937258676875, 36.66824239038463, 36.99418873282667, 37.31728821873315, 37.63761416455618, 37.95523679283268, 38.27022341194261, 38.58263858265787, 38.89254427264949, 39.2, 39.50506296666289, 39.80778818271621, 40.10822858217501, 40.40643513105307, 40.702456928298574, 40.9963413001697, 41.288133888564154, 41.577878733769, 41.8656183520559, 42.151393808508864, 42.43524478543749, 42.717209646698606, 42.9973254982214, 43.27562824500645, 43.552152644846394, 43.826932358995876, 44.1, 44.37138717687335, 44.64112453780706, 44.90924181056723, 45.175767840735155, 45.44073062792895, 45.7041573601352, 45.96607444626961, 46.226507547077354, 46.485481604475176, 46.74302086943034, 46.999148928464656, 47.25388872886548, 47.50726260268003, 47.75929228956392, 48.00999895855029, 48.25940322880092, 48.50752518939716, 48.75438441822438, 49.00000000000001, 49.24439054349237], [0.0, 4.949747468305833, 7.0, 8.573214099741124, 9.899494936611665, 11.067971810589329, 12.124355652982143, 13.095800853708795, 14.0, 14.849242404917497, 15.652475842498529, 16.416455159382004, 17.146428199482248, 17.84656829757475, 18.520259177452132, 19.170289512680814, 19.79898987322333, 20.408331631958553, 21.000000000000004, 21.575449010391424, 22.135943621178658, 22.682592444427513, 23.2163735324878, 23.738154940938443, 24.248711305964285, 24.748737341529168, 25.23885892824793, 25.71964229922337, 26.19160170741759, 26.655205870523684, 27.11088342345192, 27.55902755904134, 28.0, 28.434134416225866, 28.861739379323627, 29.283100928692647, 29.698484809834994, 30.1081384346492, 30.51229260478472, 30.91116303214747, 31.304951684997057, 31.693847983480964, 32.07802986469088, 32.45766473423496, 32.83291031876401, 33.20391543176798, 33.57082066318904, 33.933759001914304, 34.292856398964496, 34.64823227814083, 35.0, 35.34826728426728, 35.6931365951495, 36.03470549345451, 36.373066958946424, 36.70830968595531, 37.040518354904265, 37.36977388210959, 37.69615364994153, 38.019731719200756, 38.34057902536163, 38.658763560155414, 38.97435053981015, 39.28740256112639, 39.59797974644666, 39.90613987846983, 40.21193852576621, 40.515429159765795, 40.81666326391711, 41.115690435647565, 41.41255848169732, 41.70731350734545, 42.00000000000001, 42.290660907581, 42.579337712087536, 42.86607049870562, 43.15089802078285, 43.433857760968, 43.71498598878879, 43.99431781491788, 44.271887242357316, 44.5477272147525, 44.821869662029954, 45.09434554353794, 45.365184888855026, 45.634416836418545, 45.90206967011401, 46.168170853955225, 46.4327470649756, 46.69582422444216, 46.95742752749558, 47.21758147131215, 47.47630988187689, 47.7336359394505, 47.98958220280732, 48.24417063231578, 48.49742261192857, 48.74935897014443, 49.0, 49.24936547814602, 49.497474683058336, 49.744346412431646], [0.0, 4.998999899979996, 7.069653456853455, 8.658521813797089, 9.997999799959992, 11.178103595869919, 12.244998979175133, 13.22611053938383, 14.13930691370691, 14.996999699939986, 15.808225706890703, 16.57980699525782, 17.317043627594177, 18.02415046541723, 18.704544902242343, 19.361043360315062, 19.995999599919983, 20.61140461006964, 21.20896037056037, 21.79013538278274, 22.356207191739838, 22.908295440735003, 23.447387914221917, 23.974361305361196, 24.489997958350266, 24.99499949989998, 25.48999803844638, 25.975565441391264, 26.45222107876766, 26.92043833224118, 27.380650101851128, 27.833253492899463, 28.27861382741382, 28.717068095472428, 29.148927939119826, 29.574482243988655, 29.99399939987997, 30.407729280562865, 30.815904984277196, 31.21874436936887, 31.616451413781405, 32.0092174224863, 32.39722210313718, 32.78063452711067, 33.15961399051564, 33.534310787609755, 33.904866907274545, 34.27141666170222, 34.634087255188355, 34.99299929985997, 35.34826728426728, 35.70000000000001, 36.04830093083446, 36.39326860835669, 36.734996937525395, 37.07357549522301, 37.40908980448469, 37.741621586784, 38.071248994484016, 38.398046825326944, 38.722086720630124, 39.04343734867616, 39.36216457462674, 39.678331618151496, 39.99199919983997, 40.30322567735739, 40.61206717220881, 40.91857768789136, 41.22280922013928, 41.524811859898904, 41.82463388961104, 42.12232187332508, 42.41792074112074, 42.71147386827104, 43.00302314954148, 43.29260906898544, 43.58027076556548, 43.86604609490124, 44.14997168742015, 44.43208300316339, 44.712414383479675, 44.990999099819966, 45.267869399829294, 45.54305655091674, 45.816590881470006, 46.08850181986827, 46.35881793143567, 46.6275669534665, 46.894775828443834, 47.160470735564125, 47.42467712067211, 47.68741972470308, 47.94872261072239, 48.2086091896458, 48.46710224471854, 48.7242239548256, 48.97999591670053, 49.23443916609593, 49.48757419797418, 49.73942098577346, 49.98999899979996, 50.239327224794735], [0.0, 5.047771785649585, 7.138627319029899, 8.74299719775776, 10.09554357129917, 11.28716084761797, 12.364465212858986, 13.35514881983724, 14.277254638059798, 15.143315356948754, 15.962455951387932, 16.741565040341957, 17.48599439551552, 18.200000000000003, 18.887032588524857, 19.549936061276515, 20.19108714259834, 20.81249624624591, 21.4158819570897, 22.0027271037024, 22.57432169523594, 23.131796298601632, 23.676148335402868, 24.20826305210682, 24.728930425717973, 25.23885892824793, 25.738686835190332, 26.228991593273275, 26.71029763967448, 27.183082974526645, 27.6477847213841, 28.104803859838626, 28.554509276119596, 28.997241248091175, 29.433314458280098, 29.86302061078216, 30.28663071389751, 30.704397079245837, 31.11655507925002, 31.523324697753573, 31.924911902775865, 32.321509865722554, 32.71330004753419, 33.10045316910329, 33.483130080683914, 33.861482542853906, 34.23565392978496, 34.60577986406317, 34.97198879103104, 35.334402499547096, 35.6931365951495, 36.04830093083446, 36.400000000000006, 36.74833329553873, 37.09339563857696, 37.43527747993863, 37.774065177049714, 38.109841248685356, 38.44268460968875, 38.772670787553444, 39.09987212255303, 39.42435795292043, 39.74619478641949, 40.06544645951172, 40.38217428519668, 40.69643719049617, 41.00829184445507, 41.317792777446385, 41.62499249249182, 41.92994156924143, 42.232688761195405, 42.53328108669727, 42.8317639141794, 43.12818104209821, 43.4225747739583, 43.71498598878879, 44.0054542074048, 44.29401765475785, 44.58071331865385, 44.86557700509379, 45.14864339047188, 45.42994607084627, 45.70951760848063, 45.98738957583916, 46.263592597203264, 46.53815638806506, 46.81110979244137, 47.08248081824067, 47.352296670805735, 47.620583784745854, 47.8873678541638, 48.152673861375554, 48.41652610421364, 48.6789482219984, 48.939963220255905, 49.19959349425562, 49.457860851435946, 49.71478653278118, 49.97039123320929, 50.22469512102588, 50.47771785649586, 50.72947860958164], [0.0, 5.096076922496363, 7.206941098690901, 8.826664149042946, 10.192153844992726, 11.395174417269796, 12.482788150088908, 13.482952198980758, 14.413882197381803, 15.28823076748909, 16.115210206509875, 16.901775054709493, 17.653328298085892, 18.374166647769364, 19.06777386062673, 19.737021051820356, 20.38430768998545, 21.011663427725093, 21.620823296072704, 22.21328431367141, 22.790348834539593, 23.35315824465719, 23.902719510549424, 24.439926350134535, 24.965576300177815, 25.48038461248182, 25.984995670578826, 26.479992447128836, 26.965904397961516, 27.44321409747773, 27.912362852327643, 28.373755479315744, 28.827764394763605, 29.274733132857083, 29.71497938750758, 30.148797654301244, 30.57646153497818, 30.998225755678344, 31.41432794124363, 31.824990180674064, 32.23042041301975, 32.63081365825867, 33.026353113839264, 33.41721113438403, 33.803550109418985, 34.185523251809386, 34.56327530775983, 34.93694319770979, 35.306656596171784, 35.672538457474545, 36.03470549345451, 36.39326860835669, 36.74833329553873, 37.10000000000001, 37.44836445026672, 37.79351796274065, 38.13554772125346, 38.47453703425163, 38.810565571761515, 39.14370958404429, 39.47404210364071, 39.8016331323226, 40.12654981430624, 40.44885659694228, 40.7686153799709, 41.08588565432173, 41.40072463133949, 41.71318736323084, 42.023326855450186, 42.3311941716744, 42.63683853195498, 42.94030740458201, 43.24164659214541, 43.54090031223516, 43.838111273183294, 44.133320745214725, 44.42656862734282, 44.717893510316436, 45.00733273589983, 45.29492245274299, 45.580697669079186, 45.864692302467276, 46.14693922677864, 46.4274703166132, 46.70631648931438, 46.98350774473955, 47.259073202931106, 47.5330411398219, 47.80543902109885, 48.07629353433977, 48.34563061952963, 48.61347549805507, 48.87985270026907, 49.1447860917107, 49.408298898059634, 49.67041372889902, 49.93115260035563, 50.1905369566814, 50.448587690836305, 50.70532516412848, 50.96076922496364, 51.21493922675298], [0.0, 5.143928459844674, 7.274613391789285, 8.9095454429505, 10.287856919689348, 11.502173707608488, 12.600000000000001, 13.609555466656508, 14.54922678357857, 15.431785379534022, 16.26653005407115, 17.060480649735517, 17.819090885901, 18.54669781928848, 19.24681791881453, 19.922349259060788, 20.575713839378697, 21.208960370560366, 21.823840175367856, 22.42186432926576, 23.004347415216976, 23.572441536675832, 24.12716311545972, 24.66941426138854, 25.200000000000003, 25.719642299223374, 26.228991593273275, 26.728636328851497, 27.219110933313015, 27.700902512373133, 28.17445651649735, 28.6401815636703, 29.09845356715714, 29.549619286887612, 29.99399939987997, 30.431891166997822, 30.863570759068043, 31.289295294077817, 31.70930462813715, 32.12382293563455, 32.5330601081423, 32.93721299685206, 33.33646651941385, 33.73099464883892, 34.120961299471034, 34.50652112282546, 34.88782022425592, 35.264996809867995, 35.638181771802, 36.00749921891272, 36.373066958946424, 36.734996937525395, 37.09339563857696, 37.44836445026672, 37.8, 38.1483944616284, 38.49363583762906, 38.83580821870455, 39.17499202297302, 39.51126421667624, 39.844698518121575, 40.175365586388885, 40.50333319617041, 40.82866639996952, 41.15142767875739, 41.47167708207614, 41.789472358478044, 42.10486907710319, 42.41792074112073, 42.72867889368919, 43.03719321703032, 43.343511625155614, 43.64768035073571, 43.949744026558335, 44.2497457619815, 44.5477272147525, 44.84372865853152, 45.13778904642982, 45.42994607084627, 45.720236219862215, 46.00869483043395, 46.295356138602074, 46.58025332691956, 46.86341856928493, 47.144883073351664, 47.42467712067211, 47.7028301047223, 47.97937056694263, 48.25432623091944, 48.527724034823635, 48.799590162213455, 49.06995007130128, 49.33882852277708, 49.60624960627442, 49.87223676555926, 50.13681282251595, 50.400000000000006, 50.66181994362225, 50.92229374252499, 51.18144194920656, 51.43928459844675, 51.69584122538293], [0.0, 5.191338940966964, 7.341661937191061, 8.991662805065591, 10.382677881933928, 11.6081867662439, 12.716131487209466, 13.73499180924401, 14.683323874382122, 15.574016822900893, 16.416455159382004, 17.217723426748382, 17.983325610131182, 18.717638739969313, 19.424211695716252, 20.105969262883097, 20.765355763867856, 21.40443879198892, 22.024985811573185, 22.628521825342464, 23.2163735324878, 23.789703655153, 24.34953798329652, 24.89678694129024, 25.432262974418933, 25.956694704834824, 26.470738561664657, 26.974988415196773, 27.46998361848802, 27.956215766802206, 28.434134416225863, 28.90415195088761, 29.366647748764244, 29.821971765797116, 30.27044763461552, 30.712375355872428, 31.148033645801785, 31.577681992191895, 32.00156246185489, 32.41990129534636, 32.83291031876401, 33.24078819763455, 33.643721553954165, 34.04188596420592, 34.435446853496764, 34.8245602987317, 35.20937375188602, 35.59002669288125, 35.966651220262364, 36.339372586768754, 36.70830968595531, 37.07357549522302, 37.43527747993863, 37.79351796274065, 38.1483944616284, 38.5, 38.848423391432505, 39.19374950167437, 39.53605949004023, 39.875431032153124, 40.21193852576619, 40.54565328120883, 40.876643697838006, 41.20497542773203, 41.53071152773571, 41.85391260085489, 42.174636927897794, 42.49294059017333, 42.80887758397784, 43.12249992753204, 43.433857760968, 43.742999439910385, 44.04997162314637, 44.35481935483448, 44.65758614166242, 44.95831402532795, 45.25704365068493, 45.553814329867045, 45.84866410267588, 46.141629793495596, 46.4327470649756, 46.72205046870268, 47.00957349306629, 47.29534860850483, 47.579407310306, 47.861780159120705, 48.14249681933832, 48.42158609545954, 48.69907596659304, 48.97499361919305, 49.24936547814601, 49.522217236307185, 49.79357388258048, 50.06345972862843, 50.331898434293144, 50.59891303180336, 50.864525948837866, 51.12875903051042, 51.391633560337425, 51.65317028024515, 51.91338940966965, 52.17231066379944], [0.0, 5.238320341483518, 7.408103670980854, 9.073036977771006, 10.476640682967036, 11.713240371477058, 12.831211945876353, 13.85929291125633, 14.816207341961707, 15.714961024450552, 16.565023392678924, 17.3735431043872, 18.14607395554201, 18.887032588524857, 19.599999999999998, 20.28792744466521, 20.95328136593407, 21.598148068758118, 22.22431101294256, 22.83330900242013, 23.426480742954116, 24.004999479275146, 24.56990028469794, 25.12210182289691, 25.662423891752706, 26.191601707417593, 26.71029763967448, 27.21911093331301, 27.71858582251266, 28.209218351453842, 28.691462144686874, 29.16573331839952, 29.632414683923415, 30.09185936428655, 30.544393920980003, 30.99032106965012, 31.429922048901105, 31.863458694874918, 32.29117526507823, 32.71330004753419, 33.13004678535785, 33.541615941990635, 33.948195828349995, 34.34996360987883, 34.7470862087744, 35.13972111443117, 35.52801711325866, 35.912114947465845, 36.29214791108402, 36.66824239038463, 37.04051835490427, 37.40908980448469, 37.774065177049714, 38.13554772125347, 38.49363583762906, 38.848423391432505, 39.199999999999996, 39.54845129711149, 39.89385917657002, 40.23630201695976, 40.57585488933042, 40.91258974936688, 41.24657561543745, 41.577878733769, 41.90656273186814, 42.23268876119539, 42.55631562999786, 42.87749992711795, 43.196296137516235, 43.51275675017615, 43.82693235899588, 44.13887175721645, 44.44862202588512, 44.75622861680818, 45.06173543040702, 45.36518488885502, 45.66661800484026, 45.96607444626961, 46.26359259720326, 46.559209615284495, 46.85296148590823, 47.144883073351664, 47.43500816907277, 47.72336953736607, 48.00999895855029, 48.294927269848955, 48.578184404112925, 48.859799426522414, 49.13980056939588, 49.41821526522381, 49.69507017803677, 49.97039123320929, 50.24420364579382, 50.51653194747241, 50.787400012207755, 51.05683108066931, 51.32484778350541, 51.591472163527186, 51.85672569686597, 52.1206293131616, 52.38320341483519, 52.644467895496874], [0.0, 5.2848841046895245, 7.473954776421918, 9.153687781435416, 10.569768209379049, 11.817360111293892, 12.945269406234852, 13.982489048806725, 14.947909552843836, 15.854652314068574, 16.71227094083865, 17.52797763576848, 18.30737556287083, 19.05492062434268, 19.774225648555745, 20.46826812409882, 21.139536418758098, 21.790135382782733, 22.421864329265755, 23.036275740666074, 23.634720222587784, 24.21838144880867, 24.78830369347608, 25.345413786324343, 25.890538812469703, 26.424420523447626, 26.947727176888222, 27.461063344306243, 27.96497809761345, 28.459971890358574, 28.946502379389464, 29.424989379777184, 29.89581910568767, 30.35934781908202, 30.815904984277196, 31.265796007778214, 31.709304628137147, 32.1466950089741, 32.57821357901627, 33.0040906555536, 33.4245418816773, 33.8397695027611, 34.24996350363019, 34.655302624562374, 35.05595527153696, 35.452080333881675, 35.84382792057791, 36.231340024901094, 36.61475112574166, 36.99418873282667, 37.36977388210959, 37.74162158678401, 38.10984124868536, 38.47453703425163, 38.83580821870455, 39.19374950167437, 39.54845129711149, 39.9, 40.248478232102144, 40.59396506871434, 40.93653624819764, 41.27626436585559, 41.613219053565174, 41.94746714642018, 42.279072837516196, 42.60809782189296, 42.934601430547836, 43.258640755345056, 43.580270765565466, 43.89954441677044, 44.216512752590525, 44.53122499999298, 44.84372865853151, 45.154069584036385, 45.46229206716264, 45.76843890717707, 46.07255148133215, 46.374669810145285, 46.67483261887503, 46.97307739546133, 47.26944044517557, 47.56395694220573, 47.8566609783842, 48.1475856092494, 48.43676289761734, 48.7242239548256, 49.00999897980003, 49.294117296083115, 49.57660738695216, 49.857496928746826, 50.13681282251595, 50.414581224086355, 50.690827572648686, 50.96557661794871, 51.238852446166284, 51.51067850455864, 51.78107762493941, 52.050072046059654, 52.31768343495342, 52.583932907305446, 52.84884104689525, 53.112427924168564], [0.0, 5.331041174104736, 7.539230729988306, 9.233634170791046, 10.662082348209472, 11.920570456148482, 13.058330674324342, 14.104609175726921, 15.078461459976612, 15.993123522314207, 16.858232410309213, 17.681063316441126, 18.46726834158209, 19.221342304844374, 19.94692958828501, 20.647033685253675, 21.324164696418944, 21.980445855350617, 22.61769218996492, 23.23746974177697, 23.841140912296964, 24.42989971326121, 25.004799539288452, 25.566775314849547, 26.116661348648684, 26.655205870523684, 27.18308297452664, 27.70090251237313, 28.209218351453842, 28.708535316173833, 29.199315060459895, 29.681981065959867, 30.156922919953224, 30.624499995918306, 31.08504463564433, 31.53886491299267, 31.986247044628414, 32.42745750132132, 32.86274486405541, 33.292341461663526, 33.71646482061843, 34.13531895266251, 34.54909550190859, 34.95797476971456, 35.36212663288225, 35.76171136844544, 36.15688039640589, 36.547776950178516, 36.93453668316418, 37.317288218733154, 37.69615364994153, 38.07124899448402, 38.44268460968875, 38.81056557176152, 39.17499202297302, 39.53605949004023, 39.89385917657002, 40.248478232102144, 40.6, 40.94850424618707, 41.29406737050735, 41.63676260229654, 41.976660181581856, 42.31382752718076, 42.64832939283789, 42.980228012424504, 43.30958323512246, 43.636452651424364, 43.96089171070123, 44.282953831017196, 44.60269050180718, 44.920151379976446, 45.23538437992984, 45.54843575799283, 45.85935019164576, 46.16817085395522, 46.47493948355394, 46.77969645049015, 47.08248081824067, 47.38333040215726, 47.68228182459393, 47.97937056694263, 48.27463101878668, 48.568096524364634, 48.85979942652242, 49.14977110831749, 49.438042032426814, 49.72464177849852, 50.009599078576905, 50.29294185072096, 50.57469723092765, 50.85489160346329, 51.133550629699094, 51.41069927553992, 51.68636183752926, 51.960561967707775, 52.23332269729737, 52.5046664592777, 52.77461510991814, 53.04318994932338, 53.31041174104737, 53.57630073082688], [0.0, 5.376802023508025, 7.603946343840151, 9.31289428695505, 10.75360404701605, 12.022894826122368, 13.170421405558745, 14.225681003031102, 15.207892687680301, 16.130406070524074, 17.002940922087568, 17.832834883999794, 18.6257885739101, 19.38633539377672, 20.118151008479877, 20.82426469290092, 21.5072080940321, 22.169122670958362, 22.811839031520453, 23.436936659896492, 24.045789652244736, 24.63960226951726, 25.21943694851255, 25.786236638951408, 26.34084281111749, 26.88401011754013, 27.416418438592597, 27.938682860865146, 28.451362006062205, 28.95496503192501, 29.44995755514768, 29.936766692480333, 30.415785375360603, 30.887376062074292, 31.351873947182167, 31.809589749004935, 32.26081214104815, 32.70580988142627, 33.1448336849048, 33.57811787459208, 34.005881844175136, 34.42833135660223, 34.8456597010302, 35.258048726496476, 35.66566976799959, 36.068684478367096, 36.467245577367095, 36.86149752790844, 37.2515771478202, 37.637614164556176, 38.019731719200756, 38.39804682532694, 38.77267078755344, 39.14370958404428, 39.51126421667623, 39.87543103215312, 40.236302016959755, 40.59396506871433, 40.94850424618706, 41.3, 41.64852938580184, 41.9941662615178, 42.336981470104824, 42.67704300909331, 43.0144161880642, 43.349163775094894, 43.681346133103546, 44.01102134693082, 44.338245341916725, 44.66307199465796, 44.98555323656696, 45.305739150796335, 45.623678063040906, 45.939416626683446, 46.25299990270901, 46.56447143477524, 46.873873319792985, 47.18124627434083, 47.48662969721056, 47.7900617283552, 48.09157930448947, 48.39121821157223, 48.689013134381774, 48.984997703378525, 49.27920453903452, 49.5716652937946, 49.86241069182275, 50.15147056667431, 50.4388738970251, 50.724648840578475, 51.008822766262696, 51.29142228482263, 51.572473277902816, 51.852000925711636, 52.13002973335043, 52.40658355588541, 52.68168562223498, 52.95535855794011, 53.22762440688105, 53.49850465199939, 53.76802023508026, 54.03619157564678], [0.0, 5.422176684690383, 7.668115805072325, 9.391485505499118, 10.844353369380766, 12.12435565298214, 13.281566172707192, 14.345731072343437, 15.33623161014465, 16.266530054071147, 17.146428199482244, 17.98332561013118, 18.782971010998235, 19.549936061276515, 20.28792744466521, 20.999999999999996, 21.68870673876153, 22.356207191739834, 23.004347415216976, 23.634720222587788, 24.24871130596428, 24.847535089018386, 25.432262974418926, 26.003845869409396, 26.563132345414385, 27.11088342345192, 27.6477847213841, 28.174456516497347, 28.691462144686874, 29.199315060459895, 29.698484809834994, 30.18940211398695, 30.6724632202893, 31.148033645801785, 31.6164514137814, 32.078029864690876, 32.533060108142294, 32.98181317029129, 33.4245418816773, 33.86148254285391, 34.29285639896449, 34.71887094938429, 35.139721114431175, 35.555590277760814, 35.96665122026236, 36.37306695894642, 36.77499150237835, 37.172570532584906, 37.56594202199647, 37.955236792832686, 38.34057902536163, 38.72208672063013, 39.09987212255303, 39.47404210364072, 39.844698518121575, 40.2119385257662, 40.57585488933042, 40.93653624819764, 41.29406737050735, 41.648529385801844, 41.99999999999999, 42.34855369431168, 42.69426190953533, 43.037193217030314, 43.37741347752306, 43.714985988788776, 44.04997162314636, 44.3824289556126, 44.71241438347967, 45.039982238007156, 45.36518488885502, 45.688072841826006, 46.00869483043395, 46.32709790176802, 46.6433274970815, 46.95742752749558, 47.269440445175576, 47.579407310305996, 47.88736785416379, 48.193360538563816, 48.49742261192856, 48.79959016221345, 49.099898166900516, 49.398380540256575, 49.69507017803677, 49.98999899979995, 50.28319798899032, 50.57469723092764, 50.86452594883785, 51.1527125380463, 51.43928459844673, 51.724268965351264, 52.00769173881879, 52.289578311552674, 52.569953395452046, 52.84884104689524, 53.12626469082877, 53.402247143729824, 53.67681063550627, 53.949976830393545, 54.22176684690384, 54.49220127687998], [0.0, 5.467174773134658, 7.731752712031082, 9.46942448092808, 10.934349546269315, 12.224974437601086, 13.391788528796294, 14.464784823840278, 15.463505424062165, 16.401524319403972, 17.288724649319857, 18.132567385784068, 18.93884896185616, 19.712178976460212, 20.45629487468344, 21.17427684715584, 21.86869909253863, 22.541739063346466, 23.195258136093248, 23.83086234276889, 24.44994887520217, 25.05374223544259, 25.64332271761988, 26.219649120459263, 26.783577057592588, 27.335873865673292, 27.87723085243583, 28.408273442784232, 28.929569647680555, 29.44163718273833, 29.944949490690412, 30.439940867222457, 30.92701084812433, 31.40652798384438, 31.87883310285996, 32.34424214601418, 32.803048638807944, 33.25552585661517, 33.701928728190026, 34.14249551512016, 34.57744929863971, 35.00699930013997, 35.43134205756254, 35.85066247644525, 36.265134771568135, 36.67492331280326, 37.08018338681728, 37.48106188463715, 37.87769792371232, 38.27022341194261, 38.658763560155414, 39.04343734867616, 39.424357952920424, 39.8016331323226, 40.17536558638888, 40.54565328120883, 40.91258974936688, 41.27626436585559, 41.63676260229654, 41.994166261517805, 42.34855369431168, 42.7, 43.04857721226103, 43.394354471520835, 43.73739818507726, 44.07777217600726, 44.41553782180286, 44.75075418358891, 45.08347812669293, 45.41376443326406, 45.74166590757272, 46.067233474564105, 46.390516272186495, 46.71156173796804, 47.0304156902743, 47.34712240464039, 47.66172468553778, 47.97426393390523, 48.2847802107455, 48.593312297064095, 48.89989775040434, 49.20457295821193, 49.50737318824339, 49.8083326362166, 50.10748447088518, 50.404860876705136, 50.7004930942491, 50.994411458511806, 51.28664543523976, 51.577223655408204, 51.86617394795957, 52.15352337090947, 52.439298240918525, 52.72352416142154, 53.006226049399146, 53.28742816087111, 53.567154115185176, 53.84542691817013, 54.12226898421758, 54.3977021573522, 54.671747731346585, 54.944426468933145], [0.0, 5.511805511808268, 7.79487010796203, 9.546727187890099, 11.023611023616535, 12.324771803161306, 13.501111065390138, 14.58286665919976, 15.58974021592406, 16.5354165354248, 17.429859437184223, 18.280590800080834, 19.093454375780198, 19.873097393209747, 20.62328780771873, 21.347130954767664, 22.04722204723307, 22.725756313047096, 23.384610323886093, 24.025403222422725, 24.649543606322613, 25.2582659737362, 25.852659437667143, 26.43369062389889, 27.002222130780275, 27.55902755904134, 28.104803859838626, 28.640181563670296, 29.16573331839952, 29.681981065959867, 30.18940211398695, 30.688434303496162, 31.17948043184812, 31.6629120581162, 32.13907279309719, 32.60828115678592, 33.0708330708496, 33.52700404151853, 33.97705107863247, 34.4212143888039, 34.85971887436845, 35.292775464675486, 35.72058230208461, 36.14332580159164, 36.56118160016167, 36.974315409483914, 37.38288378389233, 37.78703481354418, 38.186908751560395, 38.58263858265787, 38.97435053981015, 39.36216457462674, 39.746194786419494, 40.12654981430624, 40.50333319617041, 40.87664369783801, 41.24657561543746, 41.613219053565174, 41.976660181581856, 42.33698147010483, 42.69426190953533, 43.04857721226103, 43.39999999999999, 43.748599977599284, 44.09444409446614, 44.43759669469085, 44.77811965681453, 45.116072524101654, 45.45151262609419, 45.78449519214993, 46.115073457601696, 46.443298763115436, 46.76922064777219, 47.09288693635165, 47.41434382125307, 47.733635939450494, 48.05080644484545, 48.36589707634916, 48.67894822199839, 48.98999897938354, 49.299087212645226, 49.60624960627441, 49.911521715932494, 50.21493801649066, 50.5165319474724, 50.8163359560683, 51.11438153788032, 51.41069927553991, 51.705318875334285, 51.99826920196478, 52.289578311552674, 52.57927348299898, 52.86738124779778, 53.153927418394964, 53.43893711517848, 53.7224347921797, 54.00444426156055, 54.28498871695563, 54.564090755734206, 54.841772400242505, 55.11805511808268, 55.39295984148167], [0.0, 5.55607775323564, 7.857480512225277, 9.623408959407266, 11.11215550647128, 12.423767544509193, 13.609555466656508, 14.700000000000001, 15.714961024450554, 16.66823325970692, 17.569860557215588, 18.427425213523456, 19.246817918814532, 20.03272322975586, 20.788939366884495, 21.518596608515153, 22.22431101294256, 22.908295440735003, 23.572441536675832, 24.218381448808678, 24.847535089018386, 25.461146871262496, 26.060314656580797, 26.646012834943996, 27.219110933313015, 27.780388766178206, 28.33054888278729, 28.870226878221793, 29.400000000000002, 29.92039438242752, 30.431891166997822, 30.934931711578095, 31.42992204890111, 31.917236722498398, 32.39722210313718, 32.87019926924691, 33.33646651941384, 33.79630157280528, 34.24996350363019, 34.69769444790245, 35.139721114431175, 35.57625612680458, 36.00749921891272, 36.43363830308469, 36.85485042704691, 37.27130263352758, 37.68315273434536, 38.09055000915581, 38.493635837629064, 38.89254427264948, 39.287402561126385, 39.67833161815149, 40.06544645951172, 40.44885659694227, 40.82866639996952, 41.20497542773202, 41.57787873376899, 41.94746714642017, 42.313827527180756, 42.67704300909331, 43.03719321703031, 43.394354471520835, 43.74859997759928, 44.1, 44.44862202588512, 44.79453091617324, 45.13778904642982, 45.47845643818621, 45.816590881470006, 46.15224804925542, 46.48548160447518, 46.8163433001767, 47.144883073351664, 47.47114913292072, 47.79518804231237, 48.11704479703632, 48.436762897617356, 48.75438441822438, 49.06995007130128, 49.383499268480364, 49.69507017803677, 50.00469977912076, 50.312423912985956, 50.61827733141459, 50.92229374252499, 51.22450585413197, 51.524945414818255, 51.82364325286288, 52.120629313161594, 52.41593269226447, 52.70958167164676, 53.001603749320644, 53.29202566988799, 53.58087345312692, 53.86817242119878, 54.15394722455603, 54.43822186662603, 54.72101972734062, 55.00236358557694, 55.282275640570376, 55.56077753235641, 55.837890361295], [0.0, 5.6000000000000005, 7.919595949289333, 9.699484522385713, 11.200000000000001, 12.521980673998822, 13.717142559585799, 14.816207341961707, 15.839191898578665, 16.8, 17.708754896942924, 18.57309882599024, 19.398969044771427, 20.19108714259834, 20.95328136593407, 21.68870673876153, 22.400000000000002, 23.089391503458902, 23.758787847868, 24.40983408382778, 25.043961347997644, 25.662423891752706, 26.266328255011206, 26.856656530551234, 27.434285119171598, 28.000000000000004, 28.5545092761196, 29.09845356715714, 29.632414683923415, 30.156922919953228, 30.672463220289302, 31.179480431848123, 31.67838379715733, 32.16955082061296, 32.65333061113368, 33.13004678535785, 33.6, 34.06347016967003, 34.520718416626266, 34.97198879103104, 35.41750979388585, 35.857495729623956, 36.29214791108402, 36.7216557360912, 37.14619765198048, 37.56594202199646, 37.981047905501505, 38.39166576224585, 38.79793808954285, 39.2, 39.59797974644666, 39.99199919983997, 40.38217428519668, 40.76861537997091, 41.15142767875739, 41.53071152773571, 41.90656273186814, 42.279072837516196, 42.64832939283789, 43.01441618806421, 43.37741347752306, 43.73739818507727, 44.09444409446614, 44.44862202588513, 44.800000000000004, 45.148643390471875, 45.49461506596138, 45.83797552248572, 46.178783006917804, 46.51709363234122, 46.85296148590824, 47.186438729787604, 47.517575695736, 47.84642097377817, 48.173021495438704, 48.49742261192856, 48.81966816765556, 49.13980056939589, 49.457860851435946, 49.77388873696731, 50.08792269599529, 50.400000000000006, 50.710156773569544, 51.018428043208075, 51.32484778350541, 51.62944896084017, 51.932263574775945, 52.23332269729737, 52.53265651002241, 52.830294339516975, 53.126264690828776, 53.42059527934896, 53.71331306110247, 54.00444426156056, 54.294014403062896, 54.5820483309302, 54.868570238343196, 55.1536036900582, 55.43717164502532, 55.71929647797072, 56.00000000000001, 56.279303478276994], [0.0, 5.643580423808984, 7.981227975693965, 9.77496803063826, 11.287160847617969, 12.61942946412396, 13.82389236069205, 14.931510305391079, 15.96245595138793, 16.930741271426953, 17.846568297574745, 18.717638739969313, 19.54993606127652, 20.348218595248085, 21.116344380597695, 21.857492994394388, 22.574321695235938, 23.269078194032527, 23.9436839270819, 24.599796747127815, 25.23885892824792, 25.862134482675632, 26.47073856166465, 27.06566090085369, 27.6477847213841, 28.217902119044926, 28.77672670753225, 29.324904091914775, 29.863020610782158, 30.391610684529375, 30.91116303214746, 31.422125962448817, 31.92491190277586, 32.41990129534635, 32.90744596592084, 33.38787204959309, 33.861482542853906, 34.328559538669836, 34.7893661914097, 35.244148450487494, 35.69313659514949, 36.13654659759286, 36.574581337316765, 37.007431686081645, 37.43527747993863, 37.85828839237188, 38.27662472057849, 38.690438095219335, 39.09987212255304, 39.50506296666289, 39.90613987846983, 40.30322567735739, 40.69643719049617, 41.08588565432173, 41.47167708207614, 41.85391260085489, 42.23268876119539, 42.60809782189296, 42.9802280124245, 43.3491637750949, 43.714985988788776, 44.07777217600726, 44.43759669469085, 44.79453091617324, 45.148643390471875, 45.49999999999999, 45.84866410267588, 46.19469666530997, 46.538156388065055, 46.879099820709015, 47.217581471312144, 47.55365390798061, 47.8873678541638, 48.21877227802466, 48.54791447631916, 48.87484015319129, 49.19959349425563, 49.52221723630718, 49.84275273297012, 50.16124001657057, 50.47771785649584, 50.79222381428086, 51.10479429564315, 51.415464599670784, 51.724268965351264, 52.03124061561477, 52.336411799052485, 52.63981382945802, 52.9414771233293, 53.241431235457966, 53.53970489272424, 53.83632602620651, 54.13132180170738, 54.42471864879046, 54.71654228841585, 55.00681775925598, 55.2955694427682, 55.58282108709489, 55.86859582985775, 56.15291621990794, 56.43580423808985, 56.717281317073024], [0.0, 5.686826883245172, 8.04238770515324, 9.849873095629203, 11.373653766490344, 12.716131487209465, 13.92982411949268, 15.045929682143274, 16.08477541030648, 17.060480649735517, 17.983325610131182, 18.861071019430472, 19.699746191258406, 20.504145922227533, 21.278157814998927, 22.024985811573178, 22.747307532980688, 23.447387914221917, 24.127163115459723, 24.788303693476088, 25.43226297441893, 26.0603146565808, 26.67358243656071, 27.27306363428942, 27.85964823898536, 28.434134416225863, 28.997241248091175, 29.549619286887605, 30.09185936428655, 30.624499995918303, 31.14803364580178, 31.662912058116195, 32.16955082061296, 32.6683332908185, 33.15961399051563, 33.643721553954165, 34.120961299471034, 34.591617481696346, 35.05595527153696, 35.51422250310431, 35.966651220262364, 36.413459050191875, 36.85485042704691, 37.29101768522816, 37.722142038860945, 38.14839446162839, 38.56993647907655, 38.986920883804096, 39.39949238251681, 39.80778818271621, 40.2119385257662, 40.61206717220881, 41.008291844455066, 41.40072463133949, 41.78947235847804, 42.174636927897794, 42.556315629997854, 42.93460143054783, 43.30958323512245, 43.681346133103546, 44.049971623146355, 44.41553782180286, 44.778119656814525, 45.13778904642982, 45.494615065961376, 45.848664102675876, 46.2, 46.54868419192964, 46.894775828443834, 47.238331892648375, 47.579407310306, 47.91805505234952, 48.254326230919446, 48.58827018941917, 48.91993458703721, 49.24936547814601, 49.576607386952176, 49.901703377740525, 50.224695121025874, 50.54562295589996, 50.86452594883786, 51.18144194920655, 51.49640764169867, 51.80945859589733, 52.1206293131616, 52.429953271007214, 52.73746296514462, 53.04318994932338, 53.34716487312142, 53.649417517807215, 53.94997683039354, 54.248870955993176, 54.54612726857884, 54.841772400242505, 55.135832269042616, 55.428332105521626, 55.71929647797072, 56.00874931651305, 56.29671393607268, 56.58321305829142, 56.868268832451726, 57.15190285546056], [0.0, 5.729746940310715, 8.103085831953157, 9.92421281513048, 11.45949388062143, 12.812103652406188, 14.034956359034394, 15.1594854793954, 16.206171663906314, 17.189240820932145, 18.1190507477627, 19.003420744697518, 19.84842563026096, 20.65889638872319, 21.438749963558976, 22.191214477806298, 22.91898776124286, 23.62435184296069, 24.309257495859477, 24.975387884875786, 25.624207304812376, 26.256999066915473, 26.87489534863345, 27.478900996946734, 28.06991271806879, 28.64873470155358, 29.216091456592892, 29.772638445391433, 30.3189709587908, 30.855631576747868, 31.38311648004385, 31.901880822296356, 32.41234332781263, 32.914890247424495, 33.409878778588826, 33.8976400358491, 34.37848164186429, 34.85268999661289, 35.32053227232002, 35.782258173569765, 36.2381014955254, 36.688281507860246, 37.13300418764956, 37.572463320895, 38.006841489395036, 38.436310957218566, 38.86103446898963, 39.28116597047496, 39.69685126052192, 40.108228582175, 40.51542915976579, 40.91857768789136, 41.31779277744638, 41.71318736323083, 42.10486907710318, 42.492940590173326, 42.87749992711795, 43.25864075534505, 43.63645265142436, 44.01102134693082, 44.382428955612596, 44.7507541835889, 45.11607252410165, 45.47845643818621, 45.83797552248572, 46.19469666530996, 46.54868419192964, 46.9, 47.24870368592138, 47.59485266286681, 47.938502271139015, 48.27970588145706, 48.61851499171895, 48.95497931773641, 49.28914687839504, 49.621064075652384, 49.95077576975157, 50.2783253499955, 50.60375480139789, 50.92710476750078, 51.24841460962475, 51.56772246279644, 51.88506528857799, 52.20047892500604, 52.513998133830945, 52.825656645232534, 53.13548720017537, 53.4435215905539, 53.7497906972669, 54.054324526350335, 54.35715224328809, 54.65830220561191, 54.95780199389347, 55.25567844122449, 55.551957661274194, 55.84666507500694, 56.13982543613758, 56.43146285539655, 56.7216008236721, 57.01026223409256, 57.29746940310716, 57.583244090620674], [0.0, 5.772347875864725, 8.16333265278342, 9.997999799959992, 11.54469575172945, 12.907362240210043, 14.13930691370691, 15.27219696049, 16.32666530556684, 17.317043627594174, 18.253766734567417, 19.14471206364828, 19.995999599919983, 20.81249624624591, 21.598148068758118, 22.356207191739834, 23.0893915034589, 23.8, 24.489997958350266, 25.161081057856006, 25.814724480420086, 26.45222107876766, 27.0747114481392, 27.683207906599268, 28.27861382741382, 28.861739379323627, 29.433314458280098, 29.993999399879968, 30.54439392098, 31.08504463564433, 31.6164514137814, 32.13907279309719, 32.65333061113368, 33.15961399051564, 33.65828278447967, 34.14967056942131, 34.63408725518835, 35.111821371156466, 35.58314207598874, 36.04830093083446, 36.507533469134835, 36.961060590843445, 37.40908980448469, 37.85181633686816, 38.28942412729656, 38.722086720630124, 39.14996807150678, 39.573223270287194, 39.99199919983997, 40.40643513105307, 40.81666326391711, 41.22280922013928, 41.62499249249182, 42.02332685545018, 42.417920741120724, 42.80887758397784, 43.196296137516235, 43.580270765565466, 43.960891710701226, 44.338245341916725, 44.71241438347967, 45.08347812669293, 45.45151262609419, 45.816590881470006, 46.1787830069178, 46.53815638806505, 46.894775828443834, 47.24870368592138, 47.6, 47.94872261072239, 48.294927269848955, 48.63866774491258, 48.97999591670053, 49.3189618706639, 49.65561398271095, 49.98999899979995, 50.32216211571201, 50.65214704235152, 50.97999607689275, 51.30575016506435, 51.62944896084017, 51.95113088278253, 52.27083316726452, 52.58859191878025, 52.90444215753532, 53.218417864495, 53.53055202405445, 53.84087666448235, 54.1494228962784, 54.456220948574824, 54.76130020370225, 55.06468923003198, 55.366415813198536, 55.666506985798925, 55.96498905565873, 56.26188763274833, 56.55722765482764, 56.85103341189147, 57.14332856948394, 57.43413619094485, 57.72347875864725, 58.01137819428186], [0.0, 5.814636704042653, 8.223138087129511, 10.071246198956713, 11.629273408085306, 13.001922934704698, 14.242892964563064, 15.384082683085138, 16.446276174259022, 17.443910112127956, 18.387495751189178, 19.284968239538276, 20.142492397913426, 20.964970784620714, 21.756378375088072, 22.519991119003574, 23.25854681617061, 23.974361305361192, 24.669414261388535, 25.345413786324347, 26.003845869409396, 26.646012834943996, 27.273063634289418, 27.88601800185893, 28.485785929126127, 29.073183520213266, 29.648946018366324, 30.213738596870133, 30.768165366170276, 31.312776944883062, 31.848076865016512, 32.3745270235721, 32.892552348518045, 33.402544813232424, 33.90486690727454, 34.39985465085572, 34.88782022425591, 35.36905427064739, 35.8438279205779, 36.31239457816023, 36.774991502378356, 37.231841211522166, 37.68315273434536, 38.129122727909696, 38.56993647907655, 39.00576880411409, 39.43678485880917, 39.86314086973078, 40.28498479582685, 40.70245692829857, 41.11569043564756, 41.524811859898904, 41.92994156924143, 42.3311941716744, 42.72867889368919, 43.12249992753203, 43.512756750176145, 43.89954441677043, 44.28295383101719, 44.66307199465796, 45.03998223800715, 45.41376443326406, 45.784495192149926, 46.15224804925542, 46.51709363234122, 46.87909982070901, 47.238331892648375, 47.59485266286681, 47.948722610722385, 48.300000000000004, 48.648740990903356, 48.994999744871926, 49.33882852277707, 49.6802777770012, 50.01939623785957, 50.35623099478356, 50.69082757264869, 51.023230003597384, 51.35348089467744, 51.68162149159023, 52.00769173881879, 52.33173033638388, 52.65377479345618, 52.97386147903511, 53.29202566988799, 53.608301595928225, 53.92272248319813, 54.23532059460883, 54.546127268578836, 54.85517295570218, 55.16248725356753, 55.46809893984109, 55.77203600371786, 56.0743256758385, 56.37499445676249, 56.67406814408156, 56.971571858252254, 57.26753006722048, 57.56196660990658, 57.85490471861483, 58.14636704042653, 58.436375657632986], [0.0, 5.856620185738529, 8.282511696339462, 10.14396372233261, 11.713240371477058, 13.095800853708795, 14.345731072343439, 15.49516053482506, 16.565023392678924, 17.569860557215588, 18.520259177452136, 19.424211695716252, 20.28792744466522, 21.1163443805977, 21.913466179497938, 22.68259244442751, 23.426480742954116, 24.147463634924478, 24.84753508901839, 25.528415540334663, 26.19160170741759, 26.838405317753143, 27.46998361848802, 28.087363706834434, 28.691462144686877, 29.283100928692647, 29.86302061078216, 30.431891166997822, 30.99032106965012, 31.538864912992672, 32.07802986469088, 32.60828115678593, 33.13004678535785, 33.64372155395417, 34.14967056942131, 34.64823227814083, 35.139721114431175, 35.624429819998525, 36.10263148303736, 36.57458133731677, 37.04051835490427, 37.500666660740855, 37.95523679283269, 38.404426828166564, 38.848423391432505, 39.287402561126385, 39.721530685511105, 40.15096511915996, 40.57585488933044, 40.9963413001697, 41.41255848169732, 41.82463388961104, 42.2326887611954, 42.63683853195498, 43.037193217030314, 43.433857760968, 43.826932358995876, 44.21651275259052, 44.602690501807174, 44.985553236566965, 45.36518488885502, 45.74166590757272, 46.11507345760169, 46.48548160447518, 46.85296148590823, 47.217581471312144, 47.579407310306, 47.938502271139015, 48.294927269848955, 48.648740990903356, 49.00000000000001, 49.34875884964079, 49.69507017803678, 50.038984801852244, 50.38055180325043, 50.71981861166304, 51.056831080669326, 51.39163356033743, 51.72426896535127, 52.05477883921899, 52.38320341483518, 52.70958167164677, 53.03395138965228, 53.356349200446616, 53.676810635506286, 53.9953701718953, 54.312061275558314, 54.626916442354684, 54.93996723697604, 55.25124432987912, 55.560777532356404, 55.86859582985777, 56.17472741366887, 56.479199711044075, 56.7820394138851, 57.083272506050314, 57.382924289373754, 57.68101940846747, 57.977581874376234, 58.272635087148764, 58.566201857385295, 58.85830442681815], [0.0, 5.898304841223451, 8.341462701469089, 10.216163663528498, 11.796609682446903, 13.18901057699174, 14.447837208385206, 15.605447766725568, 16.682925402938178, 17.694914523670352, 18.652077632263918, 19.56246405747497, 20.432327327056996, 21.266640543348636, 22.069435878608225, 22.844036420913003, 23.593219364893805, 24.319333872456294, 25.02438810440727, 25.710114741089747, 26.37802115398348, 27.029428406830952, 27.665501983517306, 28.287276291647455, 28.89567441677041, 29.49152420611726, 30.075571482517173, 30.64849099058549, 31.210895533451136, 31.7633436527076, 32.30634612580011, 32.84037149607172, 33.365850805876356, 33.883181668786655, 34.392731790307096, 34.89484202572065, 35.389829047340704, 35.8779876804706, 36.35959295701755, 36.83490192738404, 37.304155264527836, 37.7675786886054, 38.22538423613293, 38.67777139391565, 39.12492811494994, 39.567031730975216, 40.00424977424274, 40.4367407193013, 40.86465465411399, 41.28813388856416, 41.70731350734545, 42.12232187332508, 42.53328108669727, 42.94030740458201, 43.343511625155614, 43.742999439910385, 44.13887175721645, 44.53122499999298, 44.920151379976446, 45.30573915079634, 45.688072841826006, 46.06723347456411, 46.443298763115436, 46.816343300176705, 47.18643872978761, 47.55365390798061, 47.91805505234953, 48.27970588145707, 48.63866774491259, 48.99499974487193, 49.348758849640795, 49.699999999999996, 50.04877620881454, 50.39513865443769, 50.73913676837633, 51.08081831764248, 51.420229482179494, 51.75741492771833, 52.09241787438936, 52.425280161387796, 52.75604230796696, 53.08474357101106, 53.41142199941882, 53.73611448551151, 54.058856813661905, 54.37968370632547, 54.69862886764165, 55.01572502475997, 55.33100396703461, 55.64449658322015, 55.956232896791754, 56.26624209950403, 56.57455258329491, 56.88119197063297, 57.18618714340029, 57.489564270396066, 57.79134883354082, 58.09156565285533, 58.39023891028362, 58.68739217242491, 58.98304841223452, 59.27723002975089], [0.0, 5.939696961966999, 8.4, 10.287856919689348, 11.879393923933998, 13.281566172707194, 14.54922678357857, 15.714961024450554, 16.8, 17.819090885900998, 18.782971010998235, 19.699746191258406, 20.575713839378697, 21.4158819570897, 22.22431101294256, 23.004347415216973, 23.758787847867996, 24.489997958350262, 25.200000000000003, 25.890538812469707, 26.563132345414388, 27.219110933313015, 27.859648238985358, 28.48578592912613, 29.09845356715714, 29.698484809835, 30.286630713897512, 30.863570759068043, 31.42992204890111, 31.98624704462842, 32.5330601081423, 33.07083307084961, 33.6, 34.12096129947104, 34.63408725518835, 35.139721114431175, 35.638181771801996, 36.12976612157904, 36.61475112574166, 37.093395638576965, 37.56594202199647, 38.03261758017715, 38.49363583762906, 38.949197681081955, 39.39949238251681, 39.844698518121575, 40.28498479582685, 40.72051080229716, 41.15142767875739, 41.577878733769, 42.0, 42.41792074112073, 42.8317639141794, 43.24164659214541, 43.647680350735705, 44.04997162314637, 44.44862202588512, 44.843728658531504, 45.23538437992983, 45.623678063040906, 46.008694830433946, 46.390516272186495, 46.76922064777218, 47.144883073351664, 47.51757569573599, 47.88736785416379, 48.254326230919446, 48.61851499171895, 48.979995916700524, 49.33882852277707, 49.69507017803678, 50.04877620881454, 50.400000000000006, 50.7487930890972, 51.09520525450504, 51.43928459844674, 51.781077624939414, 52.1206293131616, 52.45798318654655, 52.793181377901455, 53.126264690828776, 53.457272657702994, 53.78624359443594, 54.113214652245524, 54.43822186662603, 54.761300203702255, 55.08248360413681, 55.40180502474627, 55.719296477970715, 56.0349890693306, 56.3489130329947, 56.661097765574574, 56.97157185825226, 57.2803631273406, 57.58749864336878, 57.89300475877893, 58.19690713431428, 58.49923076417331, 58.8, 59.09923857377522, 59.39696961967, 59.693215694917974], [0.0, 5.980802621722272, 8.4581321815162, 10.35905401086412, 11.961605243444543, 13.37348122217996, 14.649914675519446, 15.823716377640242, 16.9162643630324, 17.942407865166814, 18.912958520548813, 19.836078241426655, 20.71810802172824, 21.56409052104911, 22.378114308404093, 23.163548950884014, 23.923210486889086, 24.659480935331953, 25.374396544548603, 26.069714229350506, 26.74696244435992, 27.40748073063265, 28.05245087331943, 28.682921747967033, 29.29982935103889, 29.904013108611363, 30.496229275108753, 31.07716203259236, 31.647432755280484, 32.207607796916555, 32.75820507903325, 33.29969969834563, 33.8325287260648, 34.357095337062475, 34.87377237982722, 35.382905477080314, 35.88481573033363, 36.37980208852159, 36.86814343033834, 37.35010040147149, 37.825917041097625, 38.29582222645181, 38.76003095973996, 39.21874551792803, 39.67215648285331, 40.12044366653988, 40.56377694446118, 41.00231700770092, 41.43621604345648, 41.865618352055904, 42.29066090758101, 42.71147386827104, 43.12818104209822, 43.540900312235166, 43.949744026558335, 44.35481935483449, 44.75622861680819, 45.154069584036385, 45.54843575799283, 45.93941662668345, 46.32709790176803, 46.71156173796804, 47.09288693635165, 47.47114913292073, 47.84642097377817, 48.21877227802466, 48.58827018941918, 48.95497931773642, 49.318961870663905, 49.680277777001216, 50.03898480185225, 50.39513865443769, 50.748793089097205, 51.099999999999994, 51.44880951003628, 51.795270054320596, 52.13942845870101, 52.48133001363438, 52.82101854375775, 53.15853647345834, 53.49392488871984, 53.82722359550045, 54.158471174877164, 54.48770503517284, 54.8149614612653, 55.14027566126234, 55.463681810712856, 55.78521309451099, 56.10490174663886, 56.422779087882574, 56.738875561646445, 57.05322076798119, 57.365843495934065, 57.676771754320654, 57.98603280101167, 58.29365317082126, 58.59965870207778, 58.904074561952, 59.206925270613404, 59.50823472427997, 59.808026217222725, 60.10632246278257], [0.0, 6.021627686929839, 8.515867542417507, 10.429765098025939, 12.043255373859678, 13.46476884316994, 14.749915253993834, 15.931729347437459, 17.031735084835013, 18.064883060789516, 19.04205871222962, 19.971479664761947, 20.859530196051878, 21.71128738697915, 22.530867715203513, 23.32166374854075, 24.086510747719355, 24.82780699135548, 25.547602627252523, 26.247666562953746, 26.92953768633988, 27.594564682197834, 28.243937402564818, 28.87871188263078, 29.499830507987667, 30.108138434649195, 30.704397079245833, 31.28929529407781, 31.863458694874918, 32.427457501321314, 32.98181317029129, 33.52700404151853, 34.063470169670026, 34.591617481696346, 35.111821371156466, 35.62442981999852, 36.12976612157903, 36.62813126546316, 37.11980603397598, 37.60505285197722, 38.08411742445924, 38.55723019097716, 39.024607621345794, 39.486453373277264, 39.942959329523894, 40.39430652950982, 40.8406660082815, 41.28219955380285, 41.719060392103756, 42.15139380850887, 42.579337712087536, 43.00302314954148, 43.4225747739583, 43.838111273183294, 44.2497457619815, 44.65758614166243, 45.061735430407026, 45.46229206716264, 45.85935019164576, 46.252999902709014, 46.6433274970815, 47.03041569027431, 47.41434382125307, 47.795188042312375, 48.17302149543871, 48.54791447631916, 48.91993458703722, 49.289146878395044, 49.65561398271096, 50.019396237859574, 50.380551803250434, 50.73913676837633, 51.095205254505046, 51.44880951003628, 51.79999999999999, 52.14882549012969, 52.49533312590749, 52.839568506943735, 53.18157575702322, 53.52139759012278, 53.85907537267976, 54.19464918236855, 54.52815786362126, 54.85963908011061, 55.18912936439567, 55.51666416491538, 55.84227789050157, 56.166003952569035, 56.487874805129636, 56.80792198276574, 57.12617613668886, 57.4426670690002, 57.75742376526156, 58.07047442547719, 58.381846493580525, 58.691566685512825, 58.999661015975335, 59.30615482393038, 59.61107279692255, 59.914438994285845, 60.21627686929839, 60.51660929034277], [0.0, 6.06217782649107, 8.573214099741124, 10.500000000000002, 12.12435565298214, 13.55544171172596, 14.849242404917499, 16.03901493234544, 17.146428199482248, 18.186533479473212, 19.170289512680814, 20.1059692628831, 21.000000000000004, 21.857492994394395, 22.68259244442751, 23.478713763747788, 24.24871130596428, 24.994999499899976, 25.719642299223374, 26.42442052344763, 27.11088342345192, 27.780388766178202, 28.43413441622586, 29.073183520213266, 29.698484809834998, 30.310889132455358, 30.911163032147467, 31.5, 32.07802986469088, 32.64582668581086, 33.20391543176798, 33.75277766347534, 34.292856398964496, 34.824560298731704, 35.34826728426727, 35.864327680858594, 36.373066958946424, 36.87478813498459, 37.36977388210959, 37.85828839237189, 38.34057902536163, 38.81687777243297, 39.287402561126385, 39.75235842060191, 40.2119385257662, 40.66632513517788, 41.11569043564756, 41.56019730463271, 42.00000000000001, 42.4352447854375, 42.86607049870562, 43.29260906898544, 43.71498598878879, 44.133320745214725, 44.54772721475249, 44.95831402532795, 45.36518488885502, 45.76843890717707, 46.16817085395522, 46.56447143477525, 46.957427527495575, 47.34712240464039, 47.733635939450494, 48.11704479703632, 48.49742261192856, 48.874840153191286, 49.24936547814601, 49.62106407565239, 49.98999899979995, 50.35623099478356, 50.719818611663044, 51.08081831764248, 51.43928459844675, 51.79527005432059, 52.14882549012968, 52.5, 52.84884104689526, 53.19539453749733, 53.539704892724245, 53.88181511419229, 54.22176684690384, 54.559600438419636, 54.89535499475344, 55.22906843320825, 55.560777532356404, 55.890517979349596, 56.21832441473154, 56.5442304749123, 56.86826883245172, 57.190471234288665, 57.510868538042445, 57.82949074650407, 58.14636704042653, 58.46152580971524, 58.774994683113334, 59.08680055646946, 59.396969619669996, 59.70552738231194, 60.01249869818786, 60.31790778864931, 60.621778264910716, 60.924133149352244], [0.0, 6.102458520956944, 8.630179604156568, 10.569768209379053, 12.204917041913887, 13.645512082732552, 14.947909552843837, 16.145587632539115, 17.260359208313137, 18.30737556287083, 19.297668252926314, 20.23956521272135, 21.139536418758105, 22.002727103702398, 22.83330900242013, 23.634720222587784, 24.409834083827775, 25.161081057856006, 25.890538812469707, 26.60000000000001, 27.291024165465103, 27.964978097613454, 28.623067620365223, 29.266362944513627, 29.895819105687675, 30.512292604784722, 31.116555079250023, 31.70930462813715, 32.29117526507823, 32.862744864055415, 33.42454188167731, 33.97705107863248, 34.52071841662627, 35.055955271536966, 35.58314207598874, 36.10263148303736, 36.61475112574166, 37.11980603397599, 37.61808075912433, 38.10984124868537, 38.59533650585263, 39.074800063468025, 39.548451297111505, 40.01649659827807, 40.4791304254427, 40.93653624819765, 41.38888739746456, 41.83634783295502, 42.27907283751621, 42.717209646698606, 43.15089802078284, 43.58027076556547, 44.005454207404796, 44.42656862734282, 44.84372865853151, 45.25704365068492, 45.66661800484026, 46.07255148133214, 46.47493948355393, 46.873873319792985, 47.26944044517557, 47.66172468553777, 48.05080644484544, 48.43676289761735, 48.81966816765555, 49.19959349425562, 49.576607386952176, 49.95077576975157, 50.32216211571201, 50.69082757264869, 51.056831080669326, 51.42022948217949, 51.781077624939414, 52.139428458701005, 52.495333125907486, 52.84884104689525, 53.20000000000002, 53.548856196934786, 53.89545435377645, 54.23983775786946, 54.582048330930206, 54.922126688612494, 55.260112196773555, 55.59604302466139, 55.92995619522691, 56.26188763274835, 56.59187220794168, 56.919943780717155, 57.246135240730446, 57.570478545865846, 57.893004758778936, 58.21374408161702, 58.532725889027255, 58.84997875955438, 59.16553050552324, 59.47940820149441, 59.79163821137535, 60.10224621426392, 60.41125722909597, 60.71869563816404, 61.024585209569445, 61.32894911866664], [0.0, 6.142475071174486, 8.6867715521936, 10.639078907499465, 12.284950142348972, 13.73499180924401, 15.045929682143274, 16.25146147274146, 17.3735431043872, 18.427425213523456, 19.424211695716252, 20.37228509519735, 21.27815781499893, 22.147008827378926, 22.983037223134804, 23.789703655152998, 24.569900284697944, 25.32607352117576, 26.0603146565808, 26.774428098467393, 27.46998361848802, 28.148356968036342, 28.810761878159347, 29.45827557750114, 30.09185936428655, 30.71237535587243, 31.320600249675934, 31.917236722498394, 32.50292294548292, 33.07824058198985, 33.643721553954165, 34.199853800857106, 34.7470862087744, 35.285832851159974, 35.81647665530489, 36.33937258676875, 36.85485042704691, 37.363217206231056, 37.86475934163586, 38.35974452469673, 38.848423391432505, 39.331031006064414, 39.80778818271621, 40.27890266628424, 40.7445701903947, 41.20497542773202, 41.660292845826234, 42.110687479546094, 42.55631562999786, 42.9973254982214, 43.433857760968, 43.86604609490124, 44.29401765475785, 44.717893510316436, 45.13778904642982, 45.553814329867045, 45.96607444626961, 46.37466981014528, 46.77969645049014, 47.18124627434083, 47.579407310305996, 47.97426393390523, 48.36589707634916, 48.75438441822438, 49.13980056939589, 49.52221723630718, 49.90170337774053, 50.278325349995505, 50.65214704235152, 51.02323000359739, 51.39163356033743, 51.75741492771833, 52.1206293131616, 52.48133001363437, 52.83956850694373, 53.19539453749732, 53.548856196934786, 53.900000000000006, 54.24887095599318, 54.59551263611324, 54.93996723697604, 55.282275640570376, 55.62247747089302, 55.9606111474848, 56.296713936072685, 56.63082199650647, 56.962970428165, 57.29319331299313, 57.621523756318695, 57.947993925588136, 58.27263508714876, 58.59547764119685, 58.91655115500228, 59.23588439451209, 59.55350535442898, 59.869441286853515, 60.1837187285731, 60.49636352707493, 60.8074008653552, 61.11685528559205, 61.42475071174486, 61.731110471139274], [0.0, 6.182232606429493, 8.742997197757758, 10.707940978544851, 12.364465212858986, 13.823892360692051, 15.143315356948758, 16.356650023767095, 17.485994395515515, 18.54669781928848, 19.54993606127652, 20.504145922227536, 21.415881957089702, 22.290356659326925, 23.131796298601632, 23.943683927081896, 24.728930425717973, 25.48999803844638, 26.22899159327328, 26.94772717688823, 27.647784721384102, 28.33054888278729, 28.997241248091175, 29.648946018366328, 30.286630713897516, 30.91116303214747, 31.523324697753573, 32.12382293563455, 32.71330004753419, 33.29234146166353, 33.86148254285391, 34.4212143888039, 34.97198879103103, 35.514222503104314, 36.04830093083446, 36.57458133731677, 37.09339563857696, 37.60505285197723, 38.10984124868536, 38.608030252785504, 39.09987212255304, 39.58560344367635, 40.065446459511726, 40.53961025959673, 41.00829184445507, 41.47167708207615, 41.929941569241436, 42.383251409017696, 42.831763914179405, 43.27562824500646, 43.7149859887888, 44.14997168742015, 44.58071331865385, 45.00733273589984, 45.42994607084627, 45.84866410267589, 46.263592597203264, 46.67483261887503, 47.08248081824067, 47.48662969721057, 47.88736785416379, 48.2847802107455, 48.67894822199839, 49.069950071301285, 49.457860851435946, 49.84275273297012, 50.22469512102588, 50.6037548013979, 50.97999607689276, 51.353480894677446, 51.72426896535128, 52.09241787438936, 52.45798318654656, 52.82101854375775, 53.18157575702322, 53.539704892724245, 53.89545435377646, 54.24887095599318, 54.60000000000001, 54.94888533901303, 55.295569442768205, 55.64009345786545, 55.98249726477019, 56.322819531696034, 56.66109776557458, 56.9973683603024, 57.33166664244117, 57.66402691453313, 57.99448249618235, 58.32306576304096, 58.64980818382956, 58.974740355511535, 59.297892036732655, 59.619292179629255, 59.93896896010142, 60.25694980664056, 60.57326142779503, 60.88792983835139, 61.20098038430431, 61.512437766682616, 61.82232606429494, 62.13066875545444], [0.0, 6.221736092120913, 8.798863562983575, 10.776363022838458, 12.443472184241825, 13.912224840046253, 15.24007873995407, 16.461166422826786, 17.59772712596715, 18.665208276362737, 19.674857051577277, 20.635164162177148, 21.552726045676916, 22.43278850254689, 23.279604807642247, 24.096680269281904, 24.88694436848365, 25.652875082532173, 26.396590688950727, 27.11991887893473, 27.824449680092506, 28.511576596182824, 29.182529019946163, 29.838398080325966, 30.48015747990814, 31.108680460604567, 31.72475374214905, 32.32908906851537, 32.92233284565357, 33.5050742425681, 34.07785204498664, 34.64116048864414, 35.1954542519343, 35.741152751415285, 36.27864385557983, 36.80828711037774, 37.330416552725474, 37.84534317455716, 38.353357089047634, 38.854729441858176, 39.349714103154554, 39.83854917037016, 40.32145830696108, 40.79865193851385, 41.270328324354296, 41.736674520138756, 42.1978672446843, 42.654073662429944, 43.10545209135383, 43.55215264484639, 43.99431781491788, 44.432083003163385, 44.86557700509378, 45.29492245274299, 45.72023621986221, 46.141629793495596, 46.559209615284495, 46.973077395461324, 47.383330402157256, 47.7900617283552, 48.19336053856381, 48.59331229706409, 48.989998979383536, 49.383499268480364, 49.7738887369673, 50.16124001657056, 50.54562295589996, 50.92710476750078, 51.305750165064346, 51.68162149159023, 52.05477883921898, 52.42528016138779, 52.793181377901455, 53.158536473458334, 53.52139759012277, 53.881815114192285, 54.23983775786946, 54.59551263611324, 54.948885339013025, 55.30000000000001, 55.64889936018501, 55.995624829088214, 56.34021654200489, 56.68271341423238, 57.02315319236565, 57.361572502852475, 57.69800689798566, 58.032490899495265, 58.365058039892325, 58.69574090170427, 59.024571154731824, 59.351579591448115, 59.67679616065193, 60.00024999947918, 60.32196946386947, 60.64198215757793, 60.96031495981628, 61.27699405160146, 61.59204494088502, 61.90549248653144, 62.217360921209135, 62.527673873253924], [0.0, 6.260990336999412, 8.854377448471462, 10.84435336938077, 12.521980673998824, 14.000000000000002, 15.336231610144653, 16.565023392678928, 17.708754896942924, 18.782971010998235, 19.79898987322333, 20.76535576386786, 21.68870673876154, 22.57432169523594, 23.426480742954116, 24.24871130596428, 25.043961347997648, 25.814724480420086, 26.56313234541439, 27.291024165465107, 28.000000000000004, 28.691462144686877, 29.366647748764244, 30.02665482533811, 30.672463220289305, 31.30495168499706, 31.924911902775868, 32.5330601081423, 33.130046785357855, 33.716464820618434, 34.292856398964496, 34.859718874368454, 35.41750979388585, 35.96665122026237, 36.507533469134835, 37.04051835490427, 37.56594202199647, 38.084117424459244, 38.59533650585262, 39.099872122553045, 39.59797974644666, 40.089898977173796, 40.57585488933044, 41.0560592361225, 41.53071152773572, 42.0, 42.46410248668869, 42.9231872069165, 43.37741347752308, 43.82693235899588, 44.271887242357316, 44.71241438347968, 45.14864339047188, 45.580697669079186, 46.00869483043395, 46.4327470649756, 46.85296148590823, 47.26944044517557, 47.68228182459393, 48.09157930448948, 48.49742261192856, 48.89989775040435, 49.299087212645226, 49.69507017803678, 50.087922695995296, 50.47771785649585, 50.864525948837866, 51.24841460962476, 51.62944896084017, 52.0076917388188, 52.38320341483519, 52.756042307966965, 53.12626469082878, 53.49392488871984, 53.85907537267976, 54.22176684690384, 54.58204833093021, 54.93996723697604, 55.295569442768205, 55.64889936018503, 56.00000000000001, 56.34891303299471, 56.69567884768646, 57.04033660489742, 57.382924289373754, 57.72347875864725, 58.062035789317626, 58.3986301209198, 58.73329549752849, 59.06606470724116, 59.396969619669996, 59.72604122156432, 60.05330965067622, 60.37880422797392, 60.70255348830065, 61.02458520956943, 61.34492644057861, 61.66360352752668, 61.98064213930024, 62.29606729160358, 62.60990336999412, 62.922174151883866], [0.0, 6.300000000000001, 8.909545442950499, 10.911920087683928, 12.600000000000001, 14.087228258248675, 15.431785379534023, 16.668233259706923, 17.819090885900998, 18.9, 19.92234925906079, 20.894736179239022, 21.823840175367856, 22.714973035423135, 23.572441536675832, 24.399795081106724, 25.200000000000003, 25.975565441391264, 26.7286363288515, 27.46106334430625, 28.17445651649735, 28.870226878221793, 29.549619286887605, 30.213738596870137, 30.863570759068047, 31.500000000000004, 32.12382293563455, 32.73576026305178, 33.33646651941385, 33.926538284947384, 34.50652112282547, 35.07691548582914, 35.638181771801996, 36.190744673189585, 36.734996937525395, 37.27130263352758, 37.8, 38.32140394087879, 38.83580821870456, 39.34348738990992, 39.84469851812158, 40.33968269582695, 40.82866639996952, 41.3118627031026, 41.789472358478044, 42.26168477474602, 42.72867889368919, 43.19062398252658, 43.64768035073571, 44.1, 44.5477272147525, 44.99099909981996, 45.42994607084627, 45.86469230246727, 46.29535613860207, 46.722050468702676, 47.144883073351664, 47.56395694220572, 47.97937056694262, 48.39121821157224, 48.79959016221345, 49.20457295821193, 49.6062496062744, 50.00469977912077, 50.400000000000006, 50.79222381428086, 51.18144194920656, 51.56772246279644, 51.95113088278253, 52.33173033638388, 52.70958167164677, 53.08474357101106, 53.457272657703, 53.82722359550044, 54.19464918236854, 54.559600438419636, 54.9221266886125, 55.282275640570376, 55.64009345786544, 55.99562482908822, 56.3489130329947, 56.7, 57.04892637026574, 57.395731548609085, 57.740453756443586, 58.083130080945196, 58.42379652162294, 58.762488034459544, 59.09923857377521, 59.4340811319566, 59.76704777718237, 60.09816968926758, 60.42747719374027, 60.754999794255625, 61.080766203445755, 61.404804372296475, 61.727141518136094, 62.04780415131547, 62.36681810065349, 62.68420853771707, 63.00000000000001, 63.31421641306162], [0.0, 6.338769596696192, 8.964373932405989, 10.979070998950688, 12.677539193392384, 14.173919711921613, 15.526751108973187, 16.770807970995318, 17.928747864811978, 19.016308790088576, 20.044949488586898, 21.023320384753692, 21.958141997901375, 22.854758804240316, 23.717504084536383, 24.549949083450255, 25.35507838678477, 26.13541658363226, 26.89312179721797, 27.63005609838678, 28.347839423843226, 29.047891489745005, 29.731464814233423, 30.399671050851858, 31.053502217946374, 31.693847983480964, 32.321509865722554, 32.93721299685206, 33.541615941990635, 34.135318952662516, 34.71887094938429, 35.29277546467549, 35.857495729623956, 36.413459050191875, 36.961060590843445, 37.50066666074085, 38.03261758017715, 38.55723019097716, 39.07480006346802, 39.58560344367635, 40.089898977173796, 40.58792924010784, 41.079922103139396, 41.56609195004986, 42.046640769507384, 42.52175913576483, 42.99162709179545, 43.45641494647252, 43.91628399580275, 44.37138717687335, 44.82186966202995, 45.26786939982929, 45.70951760848063, 46.146939226778635, 46.580253326919554, 47.009573493066284, 47.435008169072766, 47.85666097838419, 48.27463101878667, 48.689013134381774, 49.09989816690051, 49.50737318824339, 49.91152171593249, 50.312423912985956, 50.71015677356954, 51.104794295643146, 51.49640764169867, 51.88506528857799, 52.27083316726452, 52.65377479345618, 53.03395138965228, 53.41142199941881, 53.78624359443594, 54.15847117487716, 54.52815786362125, 54.89535499475343, 55.26011219677356, 55.62247747089302, 55.98249726477018, 56.34021654200489, 56.69567884768645, 57.04892637026573, 57.40000000000002, 57.74893938419995, 58.09578297949001, 58.44056810127706, 58.78333097060766, 59.124106758580304, 59.462929628466846, 59.79983277568592, 60.13484846576069, 60.4680080703838, 60.799342101703715, 61.12888024493825, 61.456651389414326, 61.78268365812544, 62.10700443589275, 62.42964039620925, 62.75061752684192, 63.06996115426108, 63.38769596696193, 63.70384603773937], [0.0, 6.377303505401009, 9.018869108707587, 11.045813686641651, 12.754607010802019, 14.260084151224353, 15.621139523094978, 16.87275911047153, 18.037738217415175, 19.131910516203025, 20.166804407243106, 21.15112290163338, 22.091627373283302, 22.99369478791958, 23.861684768683034, 24.699190270128287, 25.509214021604038, 26.29429595939013, 27.056607326122766, 27.7980215123307, 28.520168302448706, 29.224476043207346, 29.912204866910095, 30.584473184934872, 31.242279046189957, 31.88651752700505, 32.51799501814342, 33.137441059924946, 33.74551822094306, 34.34283040170102, 34.929929859649015, 35.507323188322715, 36.07547643483035, 36.634819502762674, 37.185749958821596, 37.72863633899322, 38.26382103240605, 38.79162280699275, 39.31233902987712, 39.826247626408396, 40.33360881448621, 40.834666644898675, 41.32965037355143, 41.81877568748276, 42.30224580326676, 42.78025245367306, 43.252976776171145, 43.72059011495613, 44.183254746566604, 44.641124537807066, 45.09434554353794, 45.543056550916745, 45.98738957583916, 46.4274703166132, 46.86341856928493, 47.29534860850483, 47.72336953736607, 48.1475856092494, 48.568096524364634, 48.98499770337853, 49.398380540256575, 49.808332636216605, 50.21493801649066, 50.61827733141459, 51.018428043208075, 51.415464599670784, 51.80945859589733, 52.200478925006045, 52.58859191878026, 52.973861479035115, 53.356349200446616, 53.73611448551151, 54.11321465224553, 54.48770503517284, 54.85963908011061, 55.22906843320825, 55.5960430246614, 55.9606111474848, 56.322819531696034, 56.68271341423239, 57.04033660489741, 57.395731548609085, 57.74893938419996, 58.099999999999994, 58.44895208641469, 58.79583318569438, 59.14067973907639, 59.48352713146725, 59.82440973382019, 60.163360943351556, 60.50041322172932, 60.835598131357266, 61.168946369869744, 61.50048780294349, 61.83025149552604, 62.15826574157293, 62.48455809237991, 62.80915538359038, 63.13208376095311, 63.45336870490014, 63.7730350540101, 64.0911070274184], [0.0, 6.4156059729381765, 9.073036977771006, 11.112155506471282, 12.831211945876353, 14.345731072343439, 15.714961024450556, 16.974097914174997, 18.14607395554201, 19.24681791881453, 20.287927444665215, 21.27815781499893, 22.224311012942565, 23.131796298601632, 24.004999479275146, 24.847535089018386, 25.662423891752706, 26.45222107876766, 27.21911093331302, 27.964978097613457, 28.691462144686877, 29.400000000000002, 30.09185936428655, 30.76816536617028, 31.429922048901112, 32.07802986469088, 32.71330004753419, 33.33646651941384, 33.948195828349995, 34.54909550190859, 35.139721114431175, 35.72058230208461, 36.29214791108402, 36.85485042704692, 37.40908980448469, 37.955236792832686, 38.49363583762906, 39.024607621345794, 39.5484512971115, 40.065446459511726, 40.57585488933043, 41.079922103139396, 41.577878733769, 42.06994176368681, 42.55631562999786, 43.037193217030314, 43.51275675017615, 43.98317860273402, 44.44862202588513, 44.90924181056724, 45.365184888855026, 45.816590881470006, 46.263592597203264, 46.70631648931438, 47.144883073351664, 47.579407310306, 48.00999895855029, 48.43676289761734, 48.859799426522414, 49.279204539034524, 49.69507017803677, 50.10748447088519, 50.5165319474724, 50.922293742525, 51.32484778350541, 51.724268965351264, 52.1206293131616, 52.51399813383095, 52.90444215753532, 53.29202566988799, 53.676810635506286, 54.058856813661905, 54.43822186662604, 54.8149614612653, 55.18912936439566, 55.560777532356404, 55.929956195226914, 56.296713936072685, 56.66109776557458, 57.023153192365655, 57.382924289373754, 57.74045375644359, 58.09578297949001, 58.44895208641469, 58.800000000000004, 59.14896448797731, 59.49588221045219, 59.84078876485504, 60.1837187285731, 60.5247056994084, 60.863782333995644, 61.20098038430431, 61.53633073234056, 61.8698634231562, 62.20160769626458, 62.53159201555643, 62.859844097802224, 63.186390939821855, 63.511258844397034, 63.834473444996796, 64.15605972938177, 64.47604206214896], [0.0, 6.4536811201050215, 9.126883367283709, 11.17810359586992, 12.907362240210043, 14.430869689661813, 15.808225706890703, 17.074835284710655, 18.253766734567417, 19.361043360315062, 20.408331631958553, 21.40443879198892, 22.35620719173984, 23.269078194032527, 24.147463634924478, 24.994999499899972, 25.814724480420086, 26.6092089322475, 27.380650101851128, 28.130943816374174, 28.861739379323627, 29.574482243988655, 30.270447634615515, 30.950767357207805, 31.616451413781405, 32.268405600525114, 32.90744596592085, 33.534310787609755, 34.14967056942131, 34.75413644445795, 35.34826728426727, 35.932575749589674, 36.507533469134835, 37.07357549522302, 37.631104156003715, 38.180492401225, 38.722086720630124, 39.256209699867874, 39.7831622674719, 40.303225677357396, 40.81666326391711, 41.323722000807244, 41.82463388961104, 42.31961720053715, 42.80887758397784, 43.292609068985435, 43.77099496241775, 44.244208660569356, 44.71241438347968, 45.17576784073515, 45.634416836418545, 46.08850181986827, 46.538156388065055, 46.98350774473954, 47.4246771206721, 47.861780159120705, 48.294927269848955, 48.72422395482559, 49.14977110831749, 49.5716652937946, 49.989998999799944, 50.404860876705136, 50.8163359560683, 51.22450585413197, 51.62944896084017, 52.03124061561476, 52.42995327100722, 52.825656645232534, 53.218417864495, 53.608301595928225, 53.9953701718953, 54.37968370632547, 54.761300203702255, 55.140275661262336, 55.51666416491538, 55.890517979349596, 56.26188763274835, 56.63082199650647, 56.997368360302396, 57.361572502852475, 57.72347875864725, 58.083130080945196, 58.44056810127706, 58.79583318569438, 59.14896448797731, 59.50000000000001, 59.848976599437364, 60.195930094982344, 60.54089526923103, 60.883905919380695, 61.22499489587566, 61.56419413912604, 61.90153471441561, 62.23704684510666, 62.57075994424234, 62.90270264464, 63.23290282756281, 63.56138765005057, 63.88818357098596, 64.21331637596677, 64.53681120105023, 64.85869255543163], [0.0, 6.491532946846993, 9.180413934022802, 11.243664882946309, 12.983065893693986, 14.515508947329405, 15.900943368240767, 17.174981804939417, 18.360827868045604, 19.474598840540978, 20.528029618061254, 21.52997909892158, 22.487329765892618, 23.405554896220686, 24.289092202056462, 25.141598994495155, 25.966131787387972, 26.76527601202723, 27.541241802068406, 28.29593610397084, 29.03101789465881, 29.74794110522609, 30.447988439304165, 31.132298341111923, 31.801886736481535, 32.45766473423497, 33.1004531691033, 33.73099464883892, 34.349963609878834, 34.95797476971457, 35.55559027776082, 36.143325801591644, 36.72165573609121, 37.29101768522818, 37.851816336868175, 38.40442682816657, 38.949197681081955, 39.48645337327728, 40.01649659827807, 40.53961025959673, 41.05605923612251, 41.566091950049874, 42.06994176368682, 42.567828227430155, 43.05995819784316, 43.54652684198821, 44.02771854184589, 44.503707710706536, 44.974659531785235, 45.44073062792895, 45.90206967011401, 46.35881793143566, 46.81110979244137, 47.259073202931106, 47.7028301047223, 48.14249681933832, 48.578184404112925, 49.00999897980003, 49.438042032426814, 49.86241069182276, 50.28319798899031, 50.7004930942491, 51.11438153788031, 51.524945414818255, 51.932263574775945, 52.33641179905248, 52.73746296514462, 53.13548720017537, 53.53055202405446, 53.92272248319813, 54.312061275558314, 54.698628867641645, 55.08248360413681, 55.46368181071285, 55.84227789050156, 56.21832441473154, 56.59187220794168, 56.962970428165, 57.331666642441164, 57.698006897985664, 58.06203578931762, 58.42379652162294, 58.78333097060766, 59.14067973907638, 59.49588221045218, 59.848976599437364, 60.20000000000001, 60.548988430856554, 60.89597687860833, 61.24099933867833, 61.58408885418376, 61.92527755287012, 62.264596682223846, 62.60207664287185, 62.93774702036927, 63.27163661546933, 63.60377347296307, 63.93418490917047, 64.2628975381596, 64.58993729676475, 64.91532946846993, 65.23909870622066], [0.0, 6.529165337162171, 9.233634170791044, 11.30884609498246, 13.058330674324342, 14.599657530229948, 15.993123522314209, 17.274547750954294, 18.467268341582088, 19.58749601148651, 20.647033685253678, 21.65479161756123, 22.61769218996492, 23.541240409120334, 24.429899713261207, 25.287348615463817, 26.116661348648684, 26.920438332241176, 27.700902512373133, 28.459971890358577, 29.199315060459895, 29.920394382427517, 30.624499995918303, 31.312776944883062, 31.986247044628417, 32.64582668581086, 33.292341461663526, 33.92653828494738, 34.54909550190859, 35.16063139364822, 35.76171136844544, 36.3528540832766, 36.934536683164175, 37.507199308932684, 38.071248994484016, 38.627063051699906, 39.17499202297302, 39.715362267012, 40.248478232102144, 40.77462446178996, 41.294067370507356, 41.807056820589516, 42.31382752718076, 42.81460031344447, 43.30958323512246, 43.79897259068984, 44.282953831017196, 44.76170238049487, 45.23538437992984, 45.7041573601352, 46.16817085395522, 46.62756695346649, 47.08248081824067, 47.5330411398219, 47.97937056694262, 48.42158609545954, 48.859799426522414, 49.29411729608311, 49.724641778498516, 50.15147056667432, 50.57469723092763, 50.994411458511806, 51.410699275539905, 51.82364325286288, 52.23332269729737, 52.63981382945802, 53.04318994932338, 53.4435215905539, 53.84087666448235, 54.23532059460883, 54.626916442354684, 55.015725024759966, 55.40180502474627, 55.785213094510986, 56.16600395256903, 56.5442304749123, 56.919943780717155, 57.29319331299313, 57.664026914533125, 58.032490899495265, 58.39863012091979, 58.762488034459544, 59.124106758580304, 59.48352713146725, 59.840788764855034, 60.195930094982344, 60.548988430856554, 60.900000000000006, 61.248999991836605, 61.59602259886591, 61.94110105576103, 62.28426767651684, 62.625553889766124, 62.9649902723728, 63.30260658140391, 63.638431784574955, 63.972494089256834, 64.30482097012634, 64.6354391955373, 64.96437485268369, 65.29165337162172, 65.61729954821367], [0.0, 6.566582063752802, 9.28654941299512, 11.373653766490346, 13.133164127505603, 14.683323874382122, 16.08477541030648, 17.3735431043872, 18.57309882599024, 19.699746191258402, 20.765355763867856, 21.778888860545663, 22.74730753298069, 23.67614833540287, 24.56990028469794, 25.432262974418926, 26.266328255011206, 27.074711448139205, 27.85964823898536, 28.62306762036523, 29.366647748764244, 30.09185936428655, 30.8, 31.492221261765582, 32.16955082061296, 32.832910318764014, 33.48313008068392, 34.120961299471034, 34.7470862087744, 35.36212663288225, 35.966651220262364, 36.56118160016167, 37.14619765198048, 37.72214203886095, 38.28942412729656, 38.848423391432505, 39.399492382516804, 39.9429593295239, 40.47913042544269, 41.00829184445507, 41.53071152773571, 42.046640769507384, 42.55631562999786, 43.05995819784315, 43.55777772109133, 44.04997162314636, 44.53672641764323, 45.01821853427788, 45.49461506596138, 45.966074446269616, 46.4327470649756, 46.89477582844384, 47.35229667080574, 47.80543902109885, 48.25432623091944, 48.69907596659304, 49.13980056939588, 49.57660738695216, 50.009599078576905, 50.438873897025104, 50.86452594883785, 51.28664543523977, 51.705318875334285, 52.1206293131616, 52.53265651002241, 52.9414771233293, 53.34716487312143, 53.74979069726691, 54.14942289627841, 54.54612726857885, 54.93996723697604, 55.33100396703461, 55.71929647797072, 56.10490174663885, 56.487874805129636, 56.868268832451726, 57.24613524073046, 57.6215237563187, 57.99448249618235, 58.36505803989234, 58.73329549752849, 59.09923857377522, 59.46292962846685, 59.82440973382019, 60.1837187285731, 60.54089526923104, 60.89597687860834, 61.24899999183661, 61.6, 61.94901129154524, 62.29606729160357, 62.64120049935187, 62.984442523531165, 63.325824116232404, 63.66537520505162, 64.00312492370978, 64.33910164122592, 64.67333298972615, 65.00584589096583, 65.336666581637, 65.66582063752803, 65.993332996599], [0.0, 6.603786792439623, 9.339164844888433, 11.438094246857736, 13.207573584879245, 14.76651617681029, 16.17590801160788, 17.47197756408816, 18.678329689776866, 19.811360377318866, 20.883007446246815, 21.902282986026822, 22.87618849371547, 23.810291892372927, 24.709107632611904, 25.57635626902315, 26.41514716975849, 27.228110474287416, 28.017494534665303, 28.78523927293293, 29.53303235362058, 30.2623528497042, 30.97450564577262, 31.670648872418138, 32.35181602321576, 33.01893396219812, 33.67283771825594, 34.3142827405732, 34.94395512817632, 35.56248022846551, 36.17042991173867, 36.76832876267291, 37.35665937955373, 37.93586693354984, 38.50636311053019, 39.06852953465231, 39.62272075463773, 40.169266859130005, 40.70847577593639, 41.240635300635226, 41.76601489249363, 42.28486726950908, 42.797429829371765, 43.303925919020315, 43.804565972053645, 44.29954853043087, 44.7890611645299, 45.273281303656354, 45.75237698743094, 46.22650754707736, 46.69582422444217, 47.160470735564125, 47.620583784745854, 48.076293534339776, 48.527724034823635, 48.97499361919305, 49.41821526522381, 49.857496928746826, 50.29294185072096, 50.72464884057848, 51.1527125380463, 51.577223655408204, 51.99826920196478, 52.41593269226448, 52.83029433951698, 53.241431235457966, 53.64941751780722, 54.05432452635034, 54.45622094857483, 54.85517295570219, 55.25124432987913, 55.64449658322015, 56.03498906933061, 56.422779087882574, 56.80792198276574, 57.190471234288665, 57.57047854586586, 57.94799392558814, 58.32306576304096, 58.695740901704276, 59.06606470724116, 59.4340811319566, 59.79983277568593, 60.163360943351556, 60.5247056994084, 60.8839059193807, 61.240999338678336, 61.596022598865915, 61.94901129154524, 62.29999999999999, 62.64902233874045, 62.996110991076264, 63.341297744836275, 63.68461352634559, 64.0260884327631, 64.36575176287464, 64.70363204643152, 65.03975707211706, 65.37415391421904, 65.70684895808047, 66.03786792439624, 66.36723589241909], [0.0, 6.640783086353597, 9.391485505499116, 11.50217370760849, 13.281566172707194, 14.849242404917497, 16.26653005407115, 17.569860557215588, 18.78297101099823, 19.922349259060788, 21.0, 22.02498581157318, 23.00434741521698, 23.9436839270819, 24.847535089018386, 25.719642299223366, 26.563132345414388, 27.380650101851124, 28.17445651649735, 28.94650237938947, 29.698484809834994, 30.431891166997822, 31.14803364580178, 31.848076865016516, 32.5330601081423, 33.20391543176799, 33.86148254285391, 34.50652112282546, 35.139721114431175, 35.76171136844545, 36.373066958946424, 36.97431540948392, 37.56594202199646, 38.1483944616284, 38.72208672063013, 39.287402561126385, 39.844698518121575, 40.39430652950983, 40.93653624819765, 41.471677082076155, 42.0, 42.52175913576484, 43.037193217030314, 43.54652684198821, 44.04997162314636, 44.54772721475249, 45.039982238007156, 45.52691511622548, 46.00869483043396, 46.485481604475176, 46.95742752749558, 47.42467712067211, 47.8873678541638, 48.34563061952963, 48.79959016221345, 49.24936547814601, 49.69507017803677, 50.13681282251595, 50.57469723092764, 51.0088227662627, 51.43928459844673, 51.86617394795957, 52.289578311552674, 52.70958167164676, 53.126264690828776, 53.53970489272423, 53.949976830393545, 54.3571522432881, 54.76130020370225, 55.162487253567534, 55.56077753235641, 55.956232896791754, 56.3489130329947, 56.73887556164644, 57.126176136688855, 57.510868538042445, 57.89300475877894, 58.27263508714876, 58.649808183829556, 59.02457115473183, 59.39696961966999, 59.76704777718237, 60.1348484657607, 60.50041322172932, 60.863782333995644, 61.22499489587566, 61.58408885418376, 61.94110105576104, 62.29606729160356, 62.649022338740444, 63.0, 63.3490331417931, 63.69615373003303, 64.04139286430302, 64.38478081037475, 64.72634703117424, 65.0661202162846, 65.40412831006924, 65.74039853849382, 66.07495743471955, 66.40783086353598, 66.73904404469697], [0.0, 6.67757440991862, 9.443516294262428, 11.565898149300816, 13.35514881983724, 14.931510305391079, 16.35665002376709, 17.667201249773548, 18.887032588524857, 20.032723229755856, 21.1163443805977, 22.147008827378926, 23.131796298601632, 24.076336930687777, 24.985195616604646, 25.86213448267563, 26.71029763967448, 27.532344615015994, 28.33054888278729, 29.106872040808515, 29.863020610782158, 30.600490192152154, 31.32060024967593, 32.02452185435405, 32.71330004753418, 33.3878720495931, 34.04908221964287, 34.69769444790244, 35.334402499547096, 35.959838709315704, 36.574581337316765, 37.1791608296906, 37.774065177049714, 38.35974452469672, 38.936615158485466, 39.50506296666289, 40.06544645951171, 40.618099413931226, 41.16333319836964, 41.70143882409815, 42.2326887611954, 42.75733855141127, 43.27562824500645, 43.787783684493554, 44.29401765475785, 44.79453091617324, 45.28951313494108, 45.77914372287887, 46.263592597203264, 46.74302086943034, 47.21758147131215, 47.68741972470308, 48.152673861375554, 48.61347549805507, 49.06995007130128, 49.522217236307185, 49.97039123320929, 50.41458122408635, 50.85489160346328, 51.29142228482264, 51.72426896535126, 52.15352337090947, 52.57927348299898, 53.001603749320644, 53.42059527934896, 53.8363260262065, 54.24887095599318, 54.65830220561192, 55.06468923003199, 55.46809893984109, 55.86859582985777, 56.26624209950403, 56.66109776557458, 57.05322076798119, 57.442667069000194, 57.82949074650407, 58.21374408161703, 58.59547764119686, 58.974740355511535, 59.35157959144812, 59.726041221564316, 60.09816968926758, 60.46800807038381, 60.835598131357266, 61.20098038430431, 61.56419413912604, 61.92527755287013, 62.28426767651684, 62.64120049935186, 62.996110991076264, 63.3490331417931, 63.7, 64.0490437087081, 64.39619553979878, 64.74148592672245, 65.08494449563585, 65.42660009506837, 65.76648082420103, 66.104614059837, 66.44102648213678, 66.7757440991862, 67.10879227046186], [0.0, 6.714164132637808, 9.495261976375376, 11.629273408085307, 13.428328265275615, 15.013327412669053, 16.446276174259026, 17.76400855662933, 18.990523952750753, 20.142492397913422, 21.232051243344344, 22.268363208821615, 23.258546816170615, 24.20826305210682, 25.122101822896905, 26.003845869409393, 26.85665653055123, 27.683207906599268, 28.48578592912613, 29.26636294451363, 30.026654825338106, 30.76816536617028, 31.49222126176558, 32.2, 32.89255234851805, 33.570820663189046, 34.23565392978496, 34.88782022425592, 35.52801711325866, 36.15688039640589, 36.774991502378356, 37.38288378389233, 37.981047905501505, 38.56993647907656, 39.149968071506784, 39.721530685511105, 40.284984795826844, 40.84066600828151, 41.38888739746456, 41.929941569241436, 42.46410248668869, 42.99162709179545, 43.51275675017615, 44.027718541845886, 44.53672641764323, 45.039982238007156, 45.53767670841367, 46.02999022376607, 46.51709363234123, 46.999148928464656, 47.47630988187688, 47.94872261072239, 48.41652610421364, 48.87985270026906, 49.33882852277707, 49.793573882580475, 50.24420364579381, 50.690827572648686, 51.133550629699094, 51.57247327790282, 52.007691738818785, 52.439298240918525, 52.86738124779777, 53.29202566988799, 53.71331306110246, 54.13132180170737, 54.54612726857885, 54.95780199389347, 55.366415813198536, 55.77203600371786, 56.17472741366887, 56.5745525832949, 56.97157185825226, 57.36584349593406, 57.75742376526155, 58.146367040426526, 58.53272588902726, 58.91655115500228, 59.29789203673265, 59.67679616065193, 60.05330965067621, 60.42747719374027, 60.799342101703715, 61.16894636986974, 61.53633073234056, 61.90153471441561, 62.264596682223846, 62.62555388976613, 62.98444252353116, 63.34129774483627, 63.69615373003303, 64.0490437087081, 64.4, 64.74905404714421, 65.09623645035097, 65.44157699811336, 65.7851046970361, 66.12684780026946, 66.46683383462764, 66.80508962646485, 67.14164132637809, 67.476514432801], [0.0, 6.750555532695069, 9.5467271878901, 11.692305161943048, 13.501111065390138, 15.094701056993479, 16.535416535424805, 17.860291151042304, 19.0934543757802, 20.251666598085205, 21.34713095476767, 22.38905982840727, 23.384610323886097, 24.339474110999195, 25.2582659737362, 26.144789155776337, 27.002222130780275, 27.833253492899463, 28.640181563670303, 29.42498937977719, 30.189402113986958, 30.9349317115781, 31.6629120581162, 32.37452702357211, 33.07083307084961, 33.75277766347535, 34.4212143888039, 35.07691548582914, 35.72058230208461, 36.352854083276604, 36.97431540948392, 37.58550252424464, 38.1869087515604, 38.77898915650072, 39.36216457462674, 39.936825111668554, 40.50333319617041, 41.06202625297491, 41.61321905356518, 42.157205789757946, 42.69426190953534, 43.224645747536215, 43.74859997759929, 44.26635291053466, 44.77811965681454, 45.28410317098043, 45.78449519214994, 46.27947709298367, 46.769220647772194, 47.25388872886548, 47.7336359394505, 48.20860918964579, 48.67894822199839, 49.14478609171069, 49.60624960627441, 50.06345972862843, 50.5165319474724, 50.965576617948706, 51.41069927553991, 51.852000925711636, 52.289578311552674, 52.72352416142154, 53.153927418394964, 53.58087345312692, 54.00444426156055, 54.42471864879046, 54.841772400242505, 55.25567844122449, 55.666506985798925, 56.0743256758385, 56.479199711044075, 56.88119197063296, 57.28036312734061, 57.67677175432065, 58.07047442547719, 58.46152580971523, 58.84997875955438, 59.23588439451209, 59.61929217962925, 60.00024999947918, 60.378804227973916, 60.754999794255625, 61.12888024493825, 61.50048780294348, 61.8698634231562, 62.23704684510666, 62.60207664287185, 62.9649902723728, 63.3258241162324, 63.68461352634559, 64.041392864303, 64.39619553979878, 64.74905404714421, 65.10000000000001, 65.4490641644325, 65.79627649039116, 66.14166614169922, 66.4852615246417, 66.82709031523069, 67.16717948522181, 67.5055553269507, 67.84224347705492], [0.0, 6.786751800382861, 9.597916440561463, 11.754998936622668, 13.573503600765722, 15.175638372075161, 16.624078921853087, 17.956057473732926, 19.195832881122925, 20.36025540114858, 21.46159360345825, 22.50910926713894, 23.509997873245336, 24.469981610127952, 25.393700006103877, 26.28497669772602, 27.147007201531444, 27.982494527829363, 28.79374932168439, 29.58276525276162, 30.351276744150322, 31.10080384813229, 31.832687602525805, 32.54811822517548, 33.248157843706174, 33.93375900191431, 34.60577986406317, 35.264996809868, 35.91211494746585, 36.54777695017852, 37.17257053258491, 37.78703481354418, 38.39166576224585, 38.9869208838041, 39.5732232702872, 40.15096511915996, 40.72051080229716, 41.282199553802855, 41.83634783295502, 42.383251409017696, 42.9231872069165, 43.45641494647253, 43.98317860273403, 44.50370771070653, 45.01821853427788, 45.52691511622548, 46.02999022376608, 46.52762620207483, 47.01999574649067, 47.50726260268003, 47.98958220280731, 48.46710224471854, 48.939963220255905, 49.408298898059634, 49.87223676555926, 50.331898434293144, 50.787400012207755, 51.23885244616628, 51.686361837529255, 52.13002973335044, 52.56995339545204, 53.006226049399146, 53.438937115178476, 53.86817242119878, 54.29401440306289, 54.716542288415845, 55.135832269042616, 55.551957661274194, 55.96498905565873, 56.37499445676249, 56.7820394138851, 57.18618714340028, 57.58749864336878, 57.98603280101166, 58.38184649358052, 58.774994683113334, 59.16553050552324, 59.55350535442898, 59.93896896010141, 60.32196946386947, 60.702553488300644, 61.080766203445755, 61.456651389414326, 61.83025149552604, 62.20160769626458, 62.57075994424233, 62.93774702036927, 63.30260658140391, 63.66537520505161, 64.02608843276309, 64.38478081037475, 64.74148592672245, 65.09623645035096, 65.4490641644325, 65.80000000000001, 66.14907406759372, 66.49631568741235, 66.84175341805451, 67.18541508393024, 67.52732780141682, 67.86751800382862, 68.20601146526603], [0.0, 6.822756041366274, 9.648834126463154, 11.817360111293892, 13.645512082732548, 15.256146302392356, 16.71227094083865, 18.05131574151868, 19.297668252926307, 20.46826812409882, 21.575449010391416, 22.628521825342457, 23.634720222587784, 24.599796747127808, 25.528415540334652, 26.42442052344762, 27.291024165465096, 28.130943816374167, 28.946502379389464, 29.739704100747208, 30.51229260478471, 31.26579600777821, 32.00156246185489, 32.72078849905668, 33.4245418816773, 34.11378020683138, 34.7893661914097, 35.452080333881675, 36.10263148303736, 36.741665721629985, 37.369773882109584, 37.987497943402374, 38.595336505852615, 39.193749501674375, 39.7831622674719, 40.36396908134778, 40.93653624819764, 41.50120480178859, 42.05829288023944, 42.60809782189297, 43.15089802078283, 43.68695457456379, 44.21651275259052, 44.73980330756942, 45.25704365068491, 45.768438907177064, 46.27418286690755, 46.774458842406716, 47.26944044517557, 47.75929228956392, 48.24417063231577, 48.7242239548256, 49.199593494255616, 49.67041372889902, 50.13681282251595, 50.598913031803356, 51.056831080669305, 51.51067850455864, 51.960561967707775, 52.40658355588542, 52.84884104689524, 53.28742816087111, 53.72243479217969, 54.153947224556035, 54.58204833093019, 55.00681775925598, 55.42833210552163, 55.84666507500694, 56.26188763274833, 56.67406814408156, 57.08327250605032, 57.48956427039606, 57.89300475877893, 58.29365317082125, 58.691566685512825, 59.086800556469456, 59.479408201494415, 59.869441286853515, 60.25694980664056, 60.641982157577935, 61.02458520956942, 61.404804372296475, 61.78268365812544, 62.15826574157293, 62.53159201555642, 62.90270264464, 63.27163661546933, 63.638431784574955, 64.00312492370978, 64.36575176287462, 64.72634703117424, 65.08494449563585, 65.44157699811336, 65.79627649039116, 66.14907406759373, 66.49999999999999, 66.8490837633546, 67.19635406776175, 67.54183888524207, 67.88556547602738, 68.22756041366276, 68.5678496089822], [0.0, 6.858571279792899, 9.699484522385713, 11.879393923934, 13.717142559585797, 15.336231610144651, 16.8, 18.14607395554201, 19.398969044771427, 20.575713839378697, 21.688706738761535, 22.74730753298069, 23.758787847868, 24.728930425717973, 25.662423891752702, 26.563132345414385, 27.434285119171594, 28.27861382741382, 29.098453567157144, 29.89581910568768, 30.672463220289302, 31.42992204890111, 32.16955082061296, 32.89255234851805, 33.6, 34.292856398964496, 34.97198879103104, 35.638181771801996, 36.29214791108402, 36.93453668316418, 37.56594202199647, 38.186908751560395, 38.79793808954285, 39.39949238251681, 39.99199919983997, 40.57585488933043, 41.15142767875739, 41.719060392103756, 42.2790728375162, 42.8317639141794, 43.37741347752307, 43.91628399580275, 44.44862202588513, 44.97465953178523, 45.49461506596138, 46.00869483043395, 46.51709363234122, 47.019995746490665, 47.517575695736, 48.00999895855029, 48.49742261192857, 48.97999591670053, 49.457860851435946, 49.93115260035563, 50.4, 50.864525948837866, 51.324847783505405, 51.7810776249394, 52.23332269729737, 52.68168562223499, 53.12626469082877, 53.567154115185176, 54.00444426156054, 54.43822186662603, 54.86857023834319, 55.29556944276819, 55.71929647797072, 56.139825436137585, 56.55722765482764, 56.97157185825226, 57.38292428937376, 57.79134883354082, 58.19690713431429, 58.599658702077775, 58.999661015975335, 59.396969619669996, 59.79163821137536, 60.183718728573105, 60.573261427795025, 60.96031495981629, 61.344926440578604, 61.727141518136094, 62.10700443589275, 62.48455809237991, 62.85984409780222, 63.23290282756281, 63.60377347296307, 63.97249408925684, 64.33910164122592, 64.70363204643152, 65.0661202162846, 65.42660009506837, 65.7851046970361, 66.14166614169922, 66.49631568741235, 66.8490837633546, 67.2, 67.549093258163, 67.89639165669999, 68.24192259894208, 68.58571279792899, 68.92778830051057], [0.0, 6.894200461257274, 9.749871794028884, 11.94110547646239, 13.788400922514548, 15.41590088188167, 16.88727331454075, 18.240339909113537, 19.49974358805777, 20.68260138377182, 21.801376103356414, 22.865476159485507, 23.88221095292478, 24.857393266390588, 25.795736081763593, 26.701123571864912, 27.576801845029095, 28.42551670594574, 29.249615382086656, 30.05112310713196, 30.83180176376334, 31.593195469910928, 32.336666494863074, 33.06342390013473, 33.7745466290815, 34.47100230628637, 35.15366268257122, 35.82331642938716, 36.480679818227074, 37.126405697293144, 37.7610910859313, 38.38528363839455, 38.99948717611554, 39.60416644748379, 40.19975124301145, 40.786639969480206, 41.36520276754364, 41.93578424210045, 42.498705862649516, 43.054268081108994, 43.60275220671283, 44.144422071197184, 44.67952551225226, 45.20829569890907, 45.73095231897101, 46.247702645645006, 46.75874249806127, 47.26425710830543, 47.76442190584956, 48.25940322880092, 48.74935897014443, 49.23443916609593, 49.714786532781176, 50.1905369566814, 50.66181994362224, 51.128759030510416, 51.591472163527186, 52.050072046059654, 52.5046664592777, 52.95535855794011, 53.402247143729824, 53.84542691817013, 54.28498871695563, 54.72101972734062, 55.15360369005819, 55.582821087094885, 56.00874931651305, 56.43146285539655, 56.85103341189148, 57.26753006722048, 57.68101940846747, 58.09156565285532, 58.49923076417331, 58.904074561951994, 59.30615482393037, 59.705527382311935, 60.10224621426392, 60.49636352707493, 60.88792983835139, 61.27699405160147, 61.66360352752668, 62.04780415131547, 62.42964039620925, 62.80915538359038, 63.186390939821855, 63.56138765005058, 63.934184909170476, 64.30482097012636, 64.67333298972615, 65.03975707211706, 65.40412831006924, 65.76648082420103, 66.12684780026946, 66.4852615246417, 66.84175341805451, 67.19635406776175, 67.549093258163, 67.90000000000002, 68.24910255820218, 68.59642847845653, 68.94200461257275, 69.28585714270989], [0.0, 6.929646455628165, 9.8, 12.002499739637575, 13.85929291125633, 15.49516053482506, 16.974097914174997, 18.334121195192314, 19.6, 20.788939366884495, 21.913466179497938, 22.983037223134804, 24.00499947927515, 24.985195616604646, 25.928362848432986, 26.838405317753136, 27.71858582251266, 28.571664284741974, 29.400000000000002, 30.20562861454799, 30.99032106965012, 31.755629422198517, 32.502922945482915, 33.23341691731382, 33.948195828349995, 34.64823227814083, 35.334402499547096, 36.00749921891272, 36.66824239038463, 37.317288218733154, 37.955236792832686, 38.58263858265787, 39.2, 39.80778818271621, 40.40643513105307, 40.9963413001697, 41.57787873376899, 42.15139380850887, 42.7172096466986, 43.27562824500645, 43.826932358995876, 44.37138717687335, 44.90924181056723, 45.44073062792894, 45.96607444626961, 46.485481604475176, 46.999148928464656, 47.50726260268002, 48.0099989585503, 48.507525189397164, 49.0, 49.48757419797419, 49.97039123320929, 50.448587690836305, 50.92229374252499, 51.391633560337425, 51.85672569686597, 52.31768343495342, 52.77461510991814, 53.22762440688106, 53.67681063550627, 54.12226898421758, 54.564090755734206, 55.002363585576944, 55.43717164502532, 55.86859582985775, 56.296713936072685, 56.721600823672105, 57.14332856948395, 57.561966609906584, 57.97758187437624, 58.39023891028362, 58.800000000000004, 59.2069252706134, 59.61107279692254, 60.01249869818786, 60.41125722909598, 60.8074008653552, 61.20098038430431, 61.592044940885025, 61.98064213930024, 62.3668181006535, 62.75061752684193, 63.13208376095311, 63.511258844397034, 63.888183570985966, 64.2628975381596, 64.63543919553732, 65.00584589096583, 65.37415391421902, 65.74039853849382, 66.104614059837, 66.46683383462764, 66.8270903152307, 67.18541508393024, 67.54183888524209, 67.89639165669999, 68.2491025582022, 68.6, 68.94911166940442, 69.29646455628166, 69.6420849774043], [0.0, 6.96491205974634, 9.849873095629203, 12.063581557729862, 13.92982411949268, 15.574016822900893, 17.060480649735517, 18.42742521352346, 19.699746191258406, 20.89473617923902, 22.024985811573185, 23.1, 24.127163115459723, 25.112347560512937, 26.0603146565808, 26.97498841519677, 27.85964823898536, 28.717068095472424, 29.549619286887612, 30.359347819082025, 31.148033645801785, 31.917236722498398, 32.668333290818495, 33.402544813232424, 34.120961299471034, 34.824560298731704, 35.51422250310431, 36.190744673189585, 36.85485042704692, 37.507199308932684, 38.1483944616284, 38.77898915650072, 39.39949238251681, 40.010373654841075, 40.61206717220881, 41.20497542773203, 41.78947235847804, 42.36590610384724, 42.934601430547836, 43.495861872136764, 44.04997162314637, 44.59719722135014, 45.13778904642983, 45.671982658956246, 46.2, 46.722050468702676, 47.238331892648375, 47.749031403788706, 48.254326230919446, 48.75438441822438, 49.24936547814602, 49.73942098577346, 50.224695121025874, 50.70532516412848, 51.18144194920655, 51.65317028024515, 52.1206293131616, 52.58393290730544, 53.04318994932338, 53.49850465199939, 53.94997683039354, 54.3977021573522, 54.8417724002425, 55.282275640570376, 55.71929647797072, 56.15291621990794, 56.58321305829142, 57.010262234092565, 57.43413619094485, 57.85490471861483, 58.272635087148764, 58.68739217242491, 59.099238573775224, 59.508234724279966, 59.91443899428584, 60.31790778864931, 60.71869563816405, 61.11685528559205, 61.51243776668261, 61.90549248653145, 62.29606729160357, 62.68420853771707, 63.06996115426109, 63.453368704900136, 63.834473444996796, 64.21331637596677, 64.58993729676475, 64.96437485268369, 65.33666658163699, 65.70684895808047, 66.07495743471955, 66.44102648213678, 66.80508962646485, 67.16717948522181, 67.52732780141683, 67.88556547602738, 68.24192259894207, 68.59642847845653, 68.94911166940442, 69.30000000000001, 69.64912059746341, 69.99649991249564], [0.0, 7.0, 9.899494936611665, 12.124355652982143, 14.0, 15.652475842498529, 17.146428199482248, 18.520259177452136, 19.79898987322333, 21.0, 22.135943621178658, 23.2163735324878, 24.248711305964285, 25.23885892824793, 26.19160170741759, 27.110883423451916, 28.0, 28.861739379323627, 29.698484809835, 30.512292604784722, 31.304951684997057, 32.07802986469088, 32.83291031876401, 33.570820663189046, 34.292856398964496, 35.00000000000001, 35.6931365951495, 36.373066958946424, 37.04051835490427, 37.696153649941536, 38.34057902536163, 38.97435053981015, 39.59797974644666, 40.21193852576621, 40.81666326391711, 41.41255848169732, 42.0, 42.57933771208754, 43.15089802078284, 43.7149859887888, 44.271887242357316, 44.82186966202995, 45.365184888855026, 45.902069670114, 46.4327470649756, 46.95742752749558, 47.47630988187689, 47.98958220280731, 48.49742261192857, 49.00000000000001, 49.497474683058336, 49.98999899979996, 50.47771785649586, 50.960769224963634, 51.43928459844674, 51.91338940966964, 52.38320341483518, 52.848841046895245, 53.31041174104736, 53.768020235080265, 54.22176684690383, 54.671747731346585, 55.11805511808267, 55.56077753235641, 56.0, 56.435804238089844, 56.86826883245173, 57.29746940310716, 57.72347875864725, 58.14636704042653, 58.566201857385295, 58.98304841223451, 59.39696961967, 59.80802621722272, 60.21627686929838, 60.62177826491071, 61.024585209569445, 61.42475071174486, 61.822326064294934, 62.217360921209135, 62.609903369994115, 63.00000000000001, 63.38769596696193, 63.773035054010094, 64.15605972938177, 64.53681120105023, 64.91532946846993, 65.29165337162172, 65.66582063752801, 66.03786792439622, 66.40783086353596, 66.7757440991862, 67.14164132637809, 67.5055553269507, 67.86751800382862, 68.22756041366274, 68.58571279792899, 68.94200461257275, 69.29646455628166, 69.64912059746341, 70.00000000000001, 70.34912934784624], [0.0, 7.034912934784624, 9.948869282486328, 12.18482662987045, 14.069825869569248, 15.730543537970965, 17.231947075127643, 18.612630120431668, 19.897738564972656, 21.10473880435387, 22.246348014898988, 23.332166637498545, 24.3696532597409, 25.364739304790817, 26.322233947748433, 27.246100638439987, 28.139651739138497, 29.00568909714093, 29.846607847458987, 30.66447455933332, 31.46108707594193, 32.238021031074474, 32.9966664982995, 33.7382572164005, 34.463894150255285, 35.17456467392312, 35.87115833089309, 36.55447988961134, 37.225260240863335, 37.88416555765747, 38.53180504466408, 39.16873753390579, 39.79547712994531, 40.412498066810976, 41.020238907154116, 41.6191061893453, 42.20947760870774, 42.791704803618195, 43.36611580485391, 43.93301719663698, 44.492696029797976, 45.04542152094928, 45.59144656621459, 46.13100909366714, 46.66433327499709, 47.19163061391289, 47.71310092626553, 48.228933224777016, 48.7393065194818, 49.24439054349237, 49.74434641243164, 50.23932722479473, 50.72947860958163, 51.21493922675298, 51.69584122538292, 52.172310663799436, 52.64446789549687, 53.112427924168564, 53.57630073082688, 54.03619157564679, 54.492201276879975, 54.94442646893314, 55.39295984148166, 55.837890361295, 56.279303478276994, 56.71728131707302, 57.15190285546056, 57.583244090620674, 58.01137819428186, 58.436375657632986, 58.85830442681815, 59.27723002975089, 59.693215694917974, 60.106322462782565, 60.516609290342764, 60.924133149352244, 61.32894911866664, 61.731110471139274, 62.13066875545443, 62.527673873253924, 62.92217415188386, 63.31421641306162, 63.703846037739375, 64.0911070274184, 64.47604206214895, 64.85869255543163, 65.23909870622066, 65.61729954821367, 65.993332996599, 66.36723589241909, 66.73904404469697, 67.10879227046186, 67.476514432801, 67.84224347705492, 68.20601146526604, 68.5678496089822, 68.92778830051057, 69.28585714270989, 69.6420849774043, 69.99649991249564, 70.34912934784624, 70.70000000000002]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"A = 7.5\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.75, 1.0606601717798212, 1.2990381056766582, 1.5, 1.6770509831248424, 1.8371173070873839, 1.9843134832984428, 2.1213203435596424, 2.25, 2.3717082451262845, 2.48746859276655, 2.5980762113533165, 2.704163456597992, 2.806243040080456, 2.9047375096555625, 3.0, 3.092329219213245, 3.1819805153394642, 3.2691742076555057, 3.3541019662496847, 3.4369317712168805, 3.517811819867572, 3.5968736424845402, 3.6742346141747677, 3.7500000000000004, 3.824264635194589, 3.897114317029974, 3.9686269665968856, 4.0388736053508785, 4.107919181288746, 4.175823272122516, 4.242640687119285, 4.3084219849035215, 4.373213921133975, 4.437059837324711, 4.5, 4.562071897723665, 4.623310502226733, 4.683748498798799, 4.743416490252569, 4.802343178074637, 4.860555523805896, 4.9180788932265, 4.9749371855331, 5.031152949374526, 5.086747487343951, 5.141740950300783, 5.196152422706633, 5.25, 5.3033008588991075, 5.356071321407138, 5.408326913195984, 5.460082416960389, 5.511351921262151, 5.562148865321748, 5.612486080160912, 5.662375826453062, 5.711829829397932, 5.7608593109014565, 5.809475019311125, 5.8576872569299905, 5.905505905508859, 5.952940449895329, 6.0, 6.046693311223913, 6.09302880347697, 6.139014578904337, 6.18465843842649, 6.229967897188556, 6.274950199005566, 6.319612329882269, 6.3639610306789285, 6.408002808988148, 6.45174395028197, 6.49519052838329, 6.538348415311011, 6.5812232905440915, 6.623820649745887, 6.666145812986692, 6.708203932499369, 6.750000000000001, 6.791538853603064, 6.832825184358224, 6.873863542433761, 6.914658342969666, 6.955213871621778, 6.995534289816612, 7.035623639735144, 7.075485849042453, 7.115124735378854, 7.1545440106270926, 7.1937472849690804, 7.232738070744717, 7.271519786124494, 7.310095758606722, 7.348469228349535, 7.38664335134708, 7.424621202458749, 7.462405778299651, 7.500000000000001, 7.537406715840668], [0.0, 1.0606601717798212, 1.4999999999999998, 1.8371173070873839, 2.1213203435596424, 2.3717082451262845, 2.598076211353316, 2.8062430400804557, 2.9999999999999996, 3.181980515339464, 3.3541019662496843, 3.517811819867572, 3.6742346141747677, 3.824264635194589, 3.968626966596886, 4.107919181288746, 4.242640687119285, 4.373213921133975, 4.5, 4.623310502226733, 4.743416490252569, 4.860555523805895, 4.9749371855331, 5.086747487343952, 5.196152422706632, 5.303300858899107, 5.408326913195984, 5.5113519212621505, 5.612486080160911, 5.7118298293979315, 5.809475019311124, 5.905505905508858, 5.999999999999999, 6.093028803476971, 6.18465843842649, 6.274950199005566, 6.363961030678928, 6.45174395028197, 6.5383484153110105, 6.623820649745886, 6.7082039324993685, 6.791538853603063, 6.873863542433761, 6.955213871621777, 7.035623639735144, 7.115124735378853, 7.193747284969079, 7.271519786124493, 7.348469228349535, 7.424621202458749, 7.500000000000001, 7.574628703771559, 7.648529270389178, 7.72172260574025, 7.794228634059949, 7.866066361276137, 7.937253933193772, 8.007808689023483, 8.077747210701757, 8.14708536840016, 8.215838362577491, 8.284020762890446, 8.351646544245034, 8.418729120241368, 8.48528137423857, 8.551315688243534, 8.616843969807043, 8.681877677092668, 8.74642784226795, 8.810505093353047, 8.874119674649423, 8.937281465859739, 9.0, 9.06228448019593, 9.12414379544733, 9.185586535436917, 9.246621004453466, 9.307255234493143, 9.367496997597598, 9.427353817482402, 9.486832980505138, 9.545941546018392, 9.604686356149275, 9.663074045043844, 9.72111104761179, 9.778803607803974, 9.836157786453, 9.89317946870469, 9.9498743710662, 10.00624804809475, 10.062305898749054, 10.11805317242403, 10.173494974687904, 10.228636272739392, 10.283481900601567, 10.338036564067664, 10.392304845413264, 10.446291207888091, 10.5, 10.553435459602717, 10.606601717798213, 10.659502802663923], [0.0, 1.2990381056766582, 1.8371173070873836, 2.250000000000001, 2.5980762113533165, 2.904737509655563, 3.1819805153394647, 3.43693177121688, 3.6742346141747673, 3.8971143170299745, 4.107919181288747, 4.308421984903522, 4.500000000000002, 4.6837484987988, 4.860555523805896, 5.031152949374527, 5.196152422706633, 5.356071321407138, 5.511351921262151, 5.662375826453064, 5.809475019311126, 5.952940449895331, 6.0930288034769715, 6.2299678971885575, 6.363961030678929, 6.495190528383291, 6.623820649745887, 6.750000000000001, 6.87386354243376, 6.995534289816613, 7.115124735378854, 7.232738070744717, 7.3484692283495345, 7.462405778299651, 7.574628703771559, 7.685213074469699, 7.794228634059949, 7.9017403146395555, 8.007808689023486, 8.112490369793978, 8.215838362577493, 8.317902379807064, 8.41872912024137, 8.51836251870041, 8.616843969807045, 8.714212528966689, 8.810505093353049, 8.90575656527844, 9.000000000000004, 9.093266739736606, 9.18558653543692, 9.276987657639738, 9.3674969975976, 9.45714015968887, 9.545941546018394, 9.63392443399885, 9.721111047611792, 9.807522622966516, 9.893179468704693, 9.978101021737555, 10.062305898749054, 10.145811943851513, 10.228636272739394, 10.31079531365064, 10.392304845413266, 10.473180032826708, 10.553435459602717, 10.63308515906837, 10.712142642814277, 10.79062092745362, 10.86853255964208, 10.945889639494819, 11.022703842524303, 11.098986440211558, 11.174748319313506, 11.250000000000002, 11.324751652906128, 11.399013115177999, 11.472793905583769, 11.546103238755492, 11.618950038622252, 11.691342951089924, 11.763290356018596, 11.834800378544626, 11.905880899790661, 11.976539567003487, 12.04678380315676, 12.116620816052636, 12.186057606953943, 12.255100978776145, 12.32375754386624, 12.392033731393731, 12.459935794377115, 12.527469816367551, 12.594641717810001, 12.6614572621006, 12.727922061357859, 12.794041581923988, 12.859821149611687, 12.925265954710568, 12.990381056766582, 13.05517138914691], [0.0, 1.5, 2.1213203435596424, 2.5980762113533165, 3.0, 3.3541019662496847, 3.6742346141747677, 3.9686269665968856, 4.242640687119285, 4.5, 4.743416490252569, 4.9749371855331, 5.196152422706633, 5.408326913195984, 5.612486080160912, 5.809475019311125, 6.0, 6.18465843842649, 6.3639610306789285, 6.538348415311011, 6.708203932499369, 6.873863542433761, 7.035623639735144, 7.1937472849690804, 7.348469228349535, 7.500000000000001, 7.648529270389178, 7.794228634059948, 7.937253933193771, 8.077747210701757, 8.215838362577491, 8.351646544245032, 8.48528137423857, 8.616843969807043, 8.74642784226795, 8.874119674649423, 9.0, 9.12414379544733, 9.246621004453466, 9.367496997597598, 9.486832980505138, 9.604686356149275, 9.721111047611792, 9.836157786453, 9.9498743710662, 10.062305898749052, 10.173494974687902, 10.283481900601567, 10.392304845413266, 10.5, 10.606601717798215, 10.712142642814277, 10.816653826391969, 10.920164833920778, 11.022703842524303, 11.124297730643496, 11.224972160321824, 11.324751652906125, 11.423659658795865, 11.521718621802913, 11.61895003862225, 11.715374513859981, 11.811011811017718, 11.905880899790658, 12.0, 12.093386622447825, 12.18605760695394, 12.278029157808675, 12.36931687685298, 12.459935794377111, 12.549900398011133, 12.639224659764539, 12.727922061357857, 12.816005617976296, 12.90348790056394, 12.99038105676658, 13.076696830622023, 13.162446581088183, 13.247641299491773, 13.332291625973385, 13.416407864998739, 13.500000000000002, 13.583077707206128, 13.665650368716449, 13.747727084867522, 13.829316685939332, 13.910427743243556, 13.991068579633223, 14.071247279470288, 14.150971698084906, 14.230249470757707, 14.309088021254185, 14.387494569938161, 14.465476141489434, 14.543039572248988, 14.620191517213444, 14.69693845669907, 14.77328670269416, 14.849242404917497, 14.924811556599302, 15.000000000000002, 15.074813431681337], [0.0, 1.6770509831248424, 2.3717082451262845, 2.9047375096555634, 3.3541019662496847, 3.7500000000000004, 4.107919181288747, 4.437059837324712, 4.743416490252569, 5.031152949374527, 5.303300858899107, 5.562148865321748, 5.809475019311127, 6.046693311223914, 6.274950199005567, 6.495190528383289, 6.708203932499369, 6.914658342969665, 7.1151247353788545, 7.310095758606725, 7.500000000000001, 7.685213074469701, 7.866066361276137, 8.042853971072708, 8.215838362577493, 8.385254915624213, 8.551315688243536, 8.714212528966689, 8.874119674649425, 9.031195934094223, 9.185586535436917, 9.33742469849155, 9.486832980505138, 9.633924433998848, 9.778803607803974, 9.921567416492215, 10.062305898749054, 10.201102881551583, 10.338036564067668, 10.473180032826708, 10.606601717798213, 10.738365797457266, 10.86853255964208, 10.997158723961386, 11.124297730643496, 11.25, 11.374313166077327, 11.49728228756692, 11.618950038622254, 11.739356881873896, 11.858541225631425, 11.976539567003487, 12.093386622447827, 12.209115447074781, 12.32375754386624, 12.437342963832752, 12.549900398011134, 12.6614572621006, 12.772039774444803, 12.881673027988253, 12.990381056766578, 13.098186897429736, 13.205112646244258, 13.311179511974137, 13.416407864998739, 13.520817282989961, 13.624426593438713, 13.727253913292344, 13.82931668593933, 13.930631715755034, 14.031215200402281, 14.13108276106258, 14.230249470757709, 14.328729880907101, 14.42653804625351, 14.523687548277815, 14.62019151721345, 14.716062652761439, 14.811313243598628, 14.905955185763846, 15.000000000000002, 15.093458848123582, 15.186342548487444, 15.278661590597524, 15.370426148939401, 15.461646096066229, 15.552331014995792, 15.64249021096066, 15.732132722552274, 15.821267332296742, 15.90990257669732, 15.998046755776157, 16.085707942145415, 16.17289398963587, 16.259612541509103, 16.345871038277526, 16.431676725154986, 16.517036659158933, 16.60195771588399, 16.686446595965243, 16.770509831248425, 16.854153790683174], [0.0, 1.8371173070873836, 2.598076211353316, 3.1819805153394647, 3.6742346141747673, 4.107919181288747, 4.500000000000001, 4.860555523805895, 5.196152422706632, 5.511351921262151, 5.809475019311126, 6.093028803476971, 6.363961030678929, 6.623820649745886, 6.873863542433761, 7.115124735378853, 7.3484692283495345, 7.574628703771558, 7.794228634059948, 8.007808689023484, 8.215838362577493, 8.41872912024137, 8.616843969807043, 8.810505093353049, 9.000000000000002, 9.185586535436919, 9.367496997597598, 9.545941546018392, 9.72111104761179, 9.89317946870469, 10.062305898749052, 10.228636272739392, 10.392304845413264, 10.553435459602717, 10.712142642814275, 10.868532559642079, 11.022703842524303, 11.174748319313505, 11.324751652906127, 11.472793905583767, 11.618950038622252, 11.763290356018594, 11.90588089979066, 12.046783803156758, 12.186057606953941, 12.323757543866238, 12.459935794377111, 12.59464171781, 12.727922061357859, 12.859821149611685, 12.990381056766582, 13.119641763401928, 13.247641299491772, 13.374415875095256, 13.500000000000002, 13.624426593438715, 13.747727084867522, 13.869931506680198, 13.991068579633225, 14.111165791670086, 14.230249470757705, 14.348344852281743, 14.465476141489432, 14.581666571417685, 14.696938456699069, 14.811313243598624, 14.924811556599298, 15.037453241822565, 15.149257407543116, 15.260242462031853, 15.370426148939398, 15.47982558041272, 15.588457268119896, 15.696337152342263, 15.80348062927911, 15.90990257669732, 16.01561737804697, 16.12063894515351, 16.224980739587956, 16.328655792807933, 16.431676725154986, 16.534055763786455, 16.63580475961413, 16.73693520331605, 16.83745824048274, 16.937384685954324, 17.03672503740082, 17.135489488193794, 17.233687939614086, 17.331330012437014, 17.428425057933378, 17.524982168321884, 17.621010186706098, 17.716517716526578, 17.81151313055688, 17.906004579469982, 18.000000000000004, 18.09350712272223, 18.186533479473212, 18.279086410430914, 18.371173070873837, 18.46280043763676], [0.0, 1.984313483298443, 2.8062430400804557, 3.4369317712168805, 3.968626966596886, 4.437059837324712, 4.860555523805896, 5.25, 5.612486080160911, 5.952940449895329, 6.274950199005566, 6.581223290544092, 6.873863542433761, 7.154544010627093, 7.4246212024587495, 7.685213074469698, 7.937253933193772, 8.181534085976786, 8.418729120241368, 8.649421946003098, 8.874119674649425, 9.093266739736608, 9.307255234493143, 9.516433155337142, 9.721111047611792, 9.921567416492216, 10.118053172424032, 10.31079531365064, 10.5, 10.685855136581257, 10.868532559642079, 11.048189896992175, 11.224972160321823, 11.399013115177999, 11.570436465406134, 11.739356881873896, 11.905880899790658, 12.070107704573312, 12.232129822725069, 12.392033731393731, 12.549900398011133, 12.705805759573064, 12.859821149611687, 13.012013679673103, 13.162446581088185, 13.311179511974135, 13.45826883369477, 13.603767860412791, 13.747727084867522, 13.890194383089101, 14.031215200402283, 14.17083272076839, 14.309088021254187, 14.446020213193668, 14.581666571417687, 14.71606265276144, 14.849242404917499, 14.981238266578634, 15.112081259707415, 15.241801074676182, 15.370426148939396, 15.497983739828868, 15.624499991999745, 15.75, 15.874507866387544, 15.998046755776157, 16.120638945153505, 16.242305870780786, 16.36306817195357, 16.48294573187693, 16.60195771588399, 16.720122607205965, 16.837458240482736, 16.95398183318597, 17.069710015111564, 17.1846588560844, 17.298843892006197, 17.41228014936585, 17.524982168321888, 17.63696402445727, 17.74823934929885, 17.85882134968599, 17.96872282606641, 18.077956189790925, 18.186533479473216, 18.294466376475704, 18.401766219577947, 18.5084440188796, 18.614510468986285, 18.719975961523026, 18.8248505970167, 18.92914419618594, 19.032866310674283, 19.136026233259614, 19.238633007570993, 19.340695437341438, 19.442222095223585, 19.543221331193077, 19.643701280563192, 19.743669871632278, 19.843134832984433, 19.942103700462496], [0.0, 2.1213203435596424, 2.9999999999999996, 3.6742346141747677, 4.242640687119285, 4.743416490252569, 5.196152422706632, 5.612486080160911, 5.999999999999999, 6.363961030678928, 6.7082039324993685, 7.035623639735144, 7.348469228349535, 7.648529270389178, 7.937253933193772, 8.215838362577491, 8.48528137423857, 8.74642784226795, 9.0, 9.246621004453466, 9.486832980505138, 9.72111104761179, 9.9498743710662, 10.173494974687904, 10.392304845413264, 10.606601717798213, 10.816653826391969, 11.022703842524301, 11.224972160321823, 11.423659658795863, 11.618950038622248, 11.811011811017716, 11.999999999999998, 12.186057606953941, 12.36931687685298, 12.549900398011133, 12.727922061357855, 12.90348790056394, 13.076696830622021, 13.247641299491772, 13.416407864998737, 13.583077707206126, 13.747727084867522, 13.910427743243554, 14.071247279470288, 14.230249470757705, 14.387494569938157, 14.543039572248986, 14.69693845669907, 14.849242404917497, 15.000000000000002, 15.149257407543118, 15.297058540778355, 15.4434452114805, 15.588457268119898, 15.732132722552274, 15.874507866387544, 16.015617378046965, 16.155494421403514, 16.29417073680032, 16.431676725154983, 16.56804152578089, 16.703293088490067, 16.837458240482736, 16.97056274847714, 17.102631376487068, 17.233687939614086, 17.363755354185336, 17.4928556845359, 17.621010186706094, 17.748239349298846, 17.874562931719478, 18.0, 18.12456896039186, 18.24828759089466, 18.371173070873834, 18.493242008906932, 18.614510468986285, 18.734993995195197, 18.854707634964804, 18.973665961010276, 19.091883092036785, 19.20937271229855, 19.32614809008769, 19.44222209522358, 19.55760721560795, 19.672315572906, 19.78635893740938, 19.8997487421324, 20.0124960961895, 20.12461179749811, 20.23610634484806, 20.346989949375807, 20.457272545478784, 20.566963801203133, 20.67607312813533, 20.784609690826528, 20.892582415776182, 21.0, 21.106870919205434, 21.213203435596427, 21.319005605327845], [0.0, 2.25, 3.1819805153394634, 3.8971143170299745, 4.5, 5.031152949374527, 5.511351921262151, 5.952940449895328, 6.363961030678927, 6.75, 7.115124735378854, 7.46240577829965, 7.794228634059949, 8.112490369793976, 8.418729120241368, 8.714212528966687, 9.0, 9.276987657639735, 9.545941546018392, 9.807522622966516, 10.062305898749054, 10.31079531365064, 10.553435459602715, 10.79062092745362, 11.022703842524303, 11.25, 11.472793905583766, 11.691342951089922, 11.905880899790656, 12.116620816052635, 12.323757543866236, 12.527469816367548, 12.727922061357853, 12.925265954710564, 13.119641763401924, 13.311179511974135, 13.5, 13.686215693170993, 13.869931506680198, 14.051245496396398, 14.230249470757707, 14.407029534223911, 14.581666571417687, 14.7542366796795, 14.9248115565993, 15.093458848123579, 15.260242462031853, 15.42522285090235, 15.588457268119898, 15.749999999999998, 15.909902576697322, 16.068213964221414, 16.224980739587952, 16.380247250881165, 16.534055763786455, 16.686446595965243, 16.837458240482736, 16.987127479359184, 17.135489488193794, 17.282577932704367, 17.428425057933374, 17.573061770789973, 17.716517716526575, 17.858821349685986, 18.0, 18.140079933671736, 18.27908641043091, 18.417043736713012, 18.55397531527947, 18.689903691565668, 18.8248505970167, 18.958836989646805, 19.091883092036785, 19.224008426964442, 19.35523185084591, 19.48557158514987, 19.615045245933032, 19.743669871632274, 19.87146194923766, 19.998437438960075, 20.12461179749811, 20.25, 20.37461656080919, 20.498475553074673, 20.62159062730128, 20.743975028909, 20.865641614865336, 20.986602869449836, 21.10687091920543, 21.226457547127357, 21.345374206136558, 21.463632031881275, 21.58124185490724, 21.69821421223415, 21.814559358373483, 21.930287275820167, 22.045407685048605, 22.159930054041237, 22.273863607376246, 22.38721733489895, 22.5, 22.612220147522002], [0.0, 2.3717082451262845, 3.3541019662496843, 4.107919181288747, 4.743416490252569, 5.303300858899107, 5.809475019311126, 6.274950199005566, 6.7082039324993685, 7.115124735378854, 7.5, 7.866066361276137, 8.215838362577493, 8.551315688243536, 8.874119674649425, 9.185586535436917, 9.486832980505138, 9.778803607803972, 10.062305898749054, 10.338036564067668, 10.606601717798213, 10.86853255964208, 11.124297730643494, 11.374313166077327, 11.618950038622252, 11.858541225631424, 12.093386622447825, 12.323757543866238, 12.549900398011133, 12.772039774444801, 12.990381056766578, 13.205112646244256, 13.416407864998737, 13.624426593438713, 13.82931668593933, 14.03121520040228, 14.230249470757707, 14.426538046253508, 14.620191517213447, 14.811313243598626, 15.0, 15.186342548487442, 15.3704261489394, 15.55233101499579, 15.732132722552274, 15.909902576697318, 16.08570794214541, 16.2596125415091, 16.431676725154986, 16.60195771588399, 16.770509831248425, 16.937384685954324, 17.10263137648707, 17.266296649832007, 17.428425057933378, 17.589059099337863, 17.74823934929885, 17.906004579469982, 18.062391868188445, 18.21743670223668, 18.371173070873834, 18.523633552842703, 18.6748493969831, 18.8248505970167, 18.973665961010276, 19.121323175972943, 19.267848867997692, 19.413268658317175, 19.557607215607945, 19.700888304845545, 19.84313483298443, 19.98436889171134, 20.12461179749811, 20.263884129159443, 20.402205763103165, 20.53959590644373, 20.676073128135336, 20.81165538826741, 20.946360065653415, 21.080203983832796, 21.213203435596427, 21.34537420613656, 21.476731594914533, 21.6072904363319, 21.73706511928416, 21.86606960566988, 21.99431744792277, 22.12182180562894, 22.24859546128699, 22.374650835264447, 22.5, 22.624654693497533, 22.748626332154654, 22.87192602296536, 22.99456457513384, 23.11655251113366, 23.237900077244504, 23.358617253596158, 23.47871376374779, 23.598199083828412, 23.717082451262847, 23.835372873106056], [0.0, 2.4874685927665503, 3.517811819867572, 4.308421984903522, 4.974937185533101, 5.562148865321748, 6.0930288034769715, 6.5812232905440915, 7.035623639735144, 7.46240577829965, 7.866066361276137, 8.250000000000002, 8.616843969807045, 8.96869555732605, 9.307255234493145, 9.633924433998846, 9.949874371066201, 10.256095748383007, 10.553435459602717, 10.842624221100722, 11.124297730643496, 11.399013115178, 11.667261889578036, 11.929480290440152, 12.186057606953943, 12.437342963832752, 12.683650893965824, 12.925265954710566, 13.162446581088183, 13.395428324618814, 13.624426593438711, 13.84963898446454, 14.071247279470288, 14.28941916244324, 14.504309704360288, 14.716062652761437, 14.9248115565993, 15.130680751374012, 15.333786225195658, 15.534236382905988, 15.732132722552274, 15.92757043619648, 16.120638945153512, 16.31142237819866, 16.500000000000004, 16.686446595965243, 16.870832818802988, 17.05322550135311, 17.23368793961409, 17.41228014936585, 17.589059099337867, 17.76407892349052, 17.9373911146521, 18.109044701474456, 18.279086410430914, 18.44756081437327, 18.61451046898629, 18.779976038323372, 18.943996410472636, 19.106608804285496, 19.267848867997692, 19.42775077048293, 19.586347285800894, 19.743669871632274, 19.899748742132402, 20.05461293568141, 20.20829037796122, 20.360807940747343, 20.512191496766015, 20.662465970933866, 20.811655388267415, 20.95978291872318, 21.106870919205434, 21.25294097295713, 21.39801392653066, 21.54210992451761, 21.685248442201445, 21.827448316282872, 21.96872777381522, 22.109104459475518, 22.248595461286993, 22.387217334898953, 22.524986126521814, 22.661917394607194, 22.798026230356, 22.933327277130985, 23.06783474884455, 23.201562447387033, 23.334523779156072, 23.466731770743024, 23.598199083828412, 23.72893802933456, 23.858960580880304, 23.988278387579218, 24.116902786220294, 24.24484481286692, 24.372115213907886, 24.498724456591617, 24.624682739073005, 24.750000000000004, 24.874685927665503, 24.99874996874844], [0.0, 2.5980762113533165, 3.6742346141747673, 4.500000000000002, 5.196152422706633, 5.809475019311126, 6.363961030678929, 6.87386354243376, 7.3484692283495345, 7.794228634059949, 8.215838362577493, 8.616843969807045, 9.000000000000004, 9.3674969975976, 9.721111047611792, 10.062305898749054, 10.392304845413266, 10.712142642814277, 11.022703842524303, 11.324751652906128, 11.618950038622252, 11.905880899790661, 12.186057606953943, 12.459935794377115, 12.727922061357859, 12.990381056766582, 13.247641299491773, 13.500000000000002, 13.74772708486752, 13.991068579633225, 14.230249470757707, 14.465476141489434, 14.696938456699069, 14.924811556599302, 15.149257407543118, 15.370426148939398, 15.588457268119898, 15.803480629279111, 16.015617378046972, 16.224980739587956, 16.431676725154986, 16.63580475961413, 16.83745824048274, 17.03672503740082, 17.23368793961409, 17.428425057933378, 17.621010186706098, 17.81151313055688, 18.000000000000007, 18.186533479473212, 18.37117307087384, 18.553975315279477, 18.7349939951952, 18.91428031937774, 19.091883092036788, 19.2678488679977, 19.442222095223585, 19.615045245933032, 19.786358937409386, 19.95620204347511, 20.12461179749811, 20.291623887703025, 20.457272545478787, 20.62159062730128, 20.78460969082653, 20.946360065653415, 21.106870919205434, 21.26617031813674, 21.424285285628553, 21.58124185490724, 21.73706511928416, 21.891779278989638, 22.045407685048605, 22.197972880423116, 22.349496638627013, 22.500000000000004, 22.649503305812257, 22.798026230355998, 22.945587811167538, 23.092206477510985, 23.237900077244504, 23.382685902179848, 23.52658071203719, 23.669600757089253, 23.811761799581323, 23.953079134006973, 24.09356760631352, 24.233241632105273, 24.372115213907886, 24.51020195755229, 24.64751508773248, 24.784067462787462, 24.91987158875423, 25.054939632735103, 25.189283435620002, 25.3229145242012, 25.455844122715718, 25.588083163847976, 25.719642299223374, 25.850531909421136, 25.980762113533164, 26.11034277829382], [0.0, 2.704163456597992, 3.8242646351945884, 4.6837484987988, 5.408326913195984, 6.046693311223913, 6.623820649745887, 7.1545440106270926, 7.648529270389177, 8.112490369793976, 8.551315688243536, 8.968695557326049, 9.3674969975976, 9.750000000000002, 10.118053172424032, 10.473180032826706, 10.816653826391969, 11.149551560488879, 11.472793905583767, 11.787175234126286, 12.093386622447825, 12.392033731393733, 12.683650893965822, 12.968712349342939, 13.247641299491773, 13.520817282989961, 13.788582233137678, 14.051245496396398, 14.309088021254185, 14.5623658792107, 14.811313243598624, 15.056144924913548, 15.297058540778353, 15.534236382905986, 15.767847031221478, 15.998046755776157, 16.224980739587952, 16.448784149595983, 16.669583078169655, 16.887495373796558, 17.10263137648707, 17.315094570922795, 17.524982168321888, 17.732385626305334, 17.937391114652097, 18.140079933671736, 18.340528890956225, 18.538810641462415, 18.7349939951952, 18.929144196185945, 19.121323175972947, 19.311589784375602, 19.500000000000004, 19.68660712261003, 19.87146194923766, 20.054612935681412, 20.236106344848064, 20.4159863832243, 20.594295326618976, 20.771073636189346, 20.946360065653412, 21.120191760493086, 21.292604349867588, 21.46363203188128, 21.633307652783937, 21.80166278062295, 21.968727773815214, 22.134531845060557, 22.299103120977758, 22.462468697807907, 22.624654693497536, 22.78568629644497, 22.945587811167535, 23.104382701124045, 23.262093628906236, 23.418742493993996, 23.57435046825257, 23.72893802933456, 23.88252499213599, 24.035130538443102, 24.18677324489565, 24.33747110938193, 24.487241575971765, 24.636101558485265, 24.784067462787466, 24.931155207891994, 25.077380245950735, 25.22275758120036, 25.367301787931645, 25.511027027542426, 25.653947064730605, 25.79607528287976, 25.937424698685877, 26.07800797607057, 26.217837439422805, 26.356925086208367, 26.495282598983547, 26.63292135684706, 26.769852446362123, 26.906086671978148, 27.041634565979923, 27.17650639799016], [0.0, 2.806243040080456, 3.9686269665968856, 4.860555523805896, 5.612486080160912, 6.274950199005566, 6.87386354243376, 7.424621202458749, 7.937253933193771, 8.418729120241368, 8.874119674649425, 9.307255234493143, 9.721111047611792, 10.118053172424032, 10.5, 10.868532559642077, 11.224972160321824, 11.570436465406134, 11.905880899790658, 12.232129822725069, 12.549900398011133, 12.859821149611687, 13.162446581088183, 13.458268833694772, 13.74772708486752, 14.031215200402281, 14.309088021254185, 14.581666571417685, 14.849242404917497, 15.112081259707413, 15.370426148939396, 15.624499991999743, 15.874507866387543, 16.12063894515351, 16.36306817195357, 16.60195771588399, 16.837458240482736, 17.069710015111564, 17.298843892006197, 17.524982168321884, 17.74823934929885, 17.96872282606641, 18.186533479473212, 18.401766219577944, 18.614510468986285, 18.8248505970167, 19.03286631067428, 19.23863300757099, 19.442222095223585, 19.643701280563192, 19.843134832984433, 20.04058382383108, 20.236106344848064, 20.429757707814353, 20.62159062730128, 20.811655388267415, 21.0, 21.1866703377383, 21.371710273162513, 21.555161794799872, 21.737065119284154, 21.917458794303684, 22.096379793984354, 22.273863607376246, 22.44994432064365, 22.624654693497533, 22.798026230355994, 22.97008924667033, 23.140872930812268, 23.31040540188008, 23.47871376374779, 23.645824155651667, 23.811761799581316, 23.97655104471867, 24.14021540914662, 24.302777619029474, 24.464259645450138, 24.624682739073005, 24.784067462787462, 24.942433722473837, 25.099800796022265, 25.256187360724105, 25.411611519146128, 25.56609082358897, 25.719642299223374, 25.872282465990512, 26.02402735934621, 26.174892549922724, 26.324893162176366, 26.474043892084186, 26.62235902394827, 26.76985244636212, 26.916537667389544, 27.062427829003074, 27.207535720825582, 27.3518737932157, 27.49545416973504, 27.638288659032423, 27.7803887661782, 27.92176570347943, 28.062430400804562, 28.20239351544475], [0.0, 2.9047375096555625, 4.107919181288745, 5.031152949374527, 5.809475019311125, 6.495190528383289, 7.115124735378854, 7.685213074469698, 8.21583836257749, 8.714212528966687, 9.185586535436917, 9.633924433998846, 10.062305898749054, 10.473180032826706, 10.868532559642079, 11.249999999999998, 11.61895003862225, 11.976539567003481, 12.323757543866238, 12.6614572621006, 12.990381056766578, 13.311179511974137, 13.624426593438711, 13.930631715755032, 14.230249470757707, 14.523687548277813, 14.811313243598624, 15.09345884812358, 15.370426148939396, 15.642490210960657, 15.909902576697316, 16.172893989635867, 16.43167672515498, 16.68644659596524, 16.93738468595432, 17.184658856084397, 17.428425057933374, 17.668828484084617, 17.906004579469982, 18.140079933671736, 18.371173070873834, 18.599395151455866, 18.824850597016702, 19.04763764880044, 19.267848867997692, 19.485571585149867, 19.70088830484554, 19.913877071027628, 20.12461179749811, 20.333162567588936, 20.53959590644373, 20.743975028909, 20.946360065653412, 21.146808269807526, 21.34537420613656, 21.542109924517607, 21.737065119284157, 21.930287275820167, 22.12182180562894, 22.311712170965272, 22.499999999999996, 22.686725193381257, 22.871926022965358, 23.05563922340909, 23.2379000772445, 23.418742493993992, 23.598199083828405, 23.776301226221033, 23.953079134006963, 24.128561913218117, 24.302777619029474, 24.475753308121078, 24.647515087732476, 24.818088161661443, 24.98749687343652, 25.15576474687263, 25.3229145242012, 25.48896820194964, 25.653947064730605, 25.81787171708776, 25.980762113533157, 26.14263758690006, 26.303516875125275, 26.463418146566024, 26.622359023948274, 26.78035660703569, 26.937427494101957, 27.093587802282663, 27.248853186877422, 27.403238859667663, 27.556759606310752, 27.709429802866744, 27.861263431510064, 28.01227409547465, 28.162475033277882, 28.311879132265304, 28.460498941515414, 28.608346684140976, 28.75543426902122, 28.901773301996542, 29.047375096555626, 29.192250684042843], [0.0, 3.0, 4.242640687119285, 5.196152422706633, 6.0, 6.708203932499369, 7.348469228349535, 7.937253933193771, 8.48528137423857, 9.0, 9.486832980505138, 9.9498743710662, 10.392304845413266, 10.816653826391969, 11.224972160321824, 11.61895003862225, 12.0, 12.36931687685298, 12.727922061357857, 13.076696830622023, 13.416407864998739, 13.747727084867522, 14.071247279470288, 14.387494569938161, 14.69693845669907, 15.000000000000002, 15.297058540778355, 15.588457268119896, 15.874507866387543, 16.155494421403514, 16.431676725154983, 16.703293088490064, 16.97056274847714, 17.233687939614086, 17.4928556845359, 17.748239349298846, 18.0, 18.24828759089466, 18.493242008906932, 18.734993995195197, 18.973665961010276, 19.20937271229855, 19.442222095223585, 19.672315572906, 19.8997487421324, 20.124611797498105, 20.346989949375804, 20.566963801203133, 20.78460969082653, 21.0, 21.21320343559643, 21.424285285628553, 21.633307652783937, 21.840329667841555, 22.045407685048605, 22.248595461286993, 22.44994432064365, 22.64950330581225, 22.84731931759173, 23.043437243605826, 23.2379000772445, 23.430749027719962, 23.622023622035435, 23.811761799581316, 24.0, 24.18677324489565, 24.37211521390788, 24.55605831561735, 24.73863375370596, 24.919871588754223, 25.099800796022265, 25.278449319529077, 25.455844122715714, 25.632011235952593, 25.80697580112788, 25.98076211353316, 26.153393661244046, 26.324893162176366, 26.495282598983547, 26.66458325194677, 26.832815729997478, 27.000000000000004, 27.166155414412255, 27.331300737432898, 27.495454169735044, 27.658633371878665, 27.820855486487112, 27.982137159266447, 28.142494558940577, 28.30194339616981, 28.460498941515414, 28.61817604250837, 28.774989139876322, 28.93095228297887, 29.086079144497976, 29.240383034426888, 29.39387691339814, 29.54657340538832, 29.698484809834994, 29.849623113198604, 30.000000000000004, 30.149626863362673], [0.0, 3.0923292192132457, 4.373213921133975, 5.356071321407138, 6.184658438426491, 6.914658342969665, 7.574628703771559, 8.181534085976786, 8.74642784226795, 9.276987657639737, 9.778803607803972, 10.256095748383007, 10.712142642814277, 11.14955156048888, 11.570436465406136, 11.976539567003483, 12.369316876852983, 12.749999999999998, 13.119641763401926, 13.479150566708574, 13.82931668593933, 14.17083272076839, 14.504309704360287, 14.830289949963893, 15.149257407543118, 15.461646096066229, 15.76784703122148, 16.068213964221414, 16.36306817195357, 16.65270248338089, 16.93738468595432, 17.217360424873494, 17.4928556845359, 17.76407892349052, 18.031222920256962, 18.2944663764757, 18.553975315279473, 18.80990430597668, 19.062397540708254, 19.311589784375602, 19.557607215607945, 19.800568173666132, 20.040583823831085, 20.27775875189366, 20.512191496766015, 20.743975028908995, 20.973197181164345, 21.199941037653854, 21.424285285628553, 21.646304534492717, 21.866069605669882, 22.083647796503186, 22.29910312097776, 22.51249652970545, 22.723886111314677, 22.933327277130985, 23.14087293081227, 23.34657362441007, 23.550477702161377, 23.75263143316967, 23.953079134006966, 24.151863282156928, 24.34902462112189, 24.544602257930357, 24.738633753705965, 24.931155207891994, 25.122201336666336, 25.311805546029305, 25.499999999999996, 25.68681568431556, 25.87228246599051, 26.056429149060314, 26.239283526803852, 26.420872430712805, 26.6012217764523, 26.78035660703569, 26.958301133417148, 27.135078772688313, 27.31071218404969, 27.485223302713045, 27.65863337187866, 27.83096297291921, 28.002232053891706, 28.172459956489423, 28.34166544153678, 28.50986671312232, 28.677081441457744, 28.843326784544118, 29.008619408720573, 29.172975508165088, 29.33641082341192, 29.498940658945703, 29.660579899927786, 29.82134302810657, 29.98124413696003, 30.140296946115175, 30.298514815086236, 30.455910756370432, 30.612497447937827, 30.768287245149025, 30.923292192132458, 31.077524032650995], [0.0, 3.181980515339464, 4.5, 5.511351921262151, 6.363961030678928, 7.115124735378854, 7.794228634059949, 8.418729120241368, 9.0, 9.545941546018392, 10.062305898749054, 10.553435459602717, 11.022703842524303, 11.472793905583767, 11.905880899790658, 12.323757543866236, 12.727922061357855, 13.119641763401926, 13.5, 13.8699315066802, 14.230249470757707, 14.581666571417687, 14.9248115565993, 15.260242462031854, 15.588457268119898, 15.909902576697322, 16.224980739587952, 16.53405576378645, 16.837458240482736, 17.135489488193794, 17.428425057933374, 17.716517716526575, 18.0, 18.27908641043091, 18.553975315279473, 18.8248505970167, 19.091883092036785, 19.35523185084591, 19.615045245933032, 19.87146194923766, 20.12461179749811, 20.37461656080919, 20.621590627301284, 20.865641614865332, 21.106870919205434, 21.345374206136558, 21.581241854907237, 21.81455935837348, 22.045407685048605, 22.273863607376246, 22.500000000000004, 22.723886111314677, 22.945587811167535, 23.165167817220752, 23.382685902179848, 23.598199083828412, 23.811761799581316, 24.02342606707045, 24.233241632105273, 24.441256105200484, 24.647515087732472, 24.852062288671338, 25.0549396327351, 25.256187360724102, 25.45584412271571, 25.653947064730605, 25.85053190942113, 26.045633031278005, 26.239283526803852, 26.431515280059145, 26.62235902394827, 26.811844397579215, 27.0, 27.186853440587786, 27.37243138634199, 27.556759606310752, 27.7398630133604, 27.921765703479426, 28.1024909927928, 28.282061452447206, 28.460498941515414, 28.637824638055175, 28.814059068447822, 28.989222135131534, 29.163333142835373, 29.33641082341192, 29.508473359359005, 29.67953840611407, 29.8496231131986, 30.018744144284252, 30.18691769624716, 30.35415951727209, 30.52048492406371, 30.685908818218177, 30.850445701804702, 31.014109692202997, 31.176914536239796, 31.338873623664274, 31.5, 31.66030637880815, 31.819805153394643, 31.978508407991768], [0.0, 3.2691742076555057, 4.623310502226732, 5.662375826453064, 6.538348415311011, 7.310095758606724, 8.007808689023484, 8.649421946003097, 9.246621004453464, 9.807522622966516, 10.338036564067668, 10.842624221100722, 11.324751652906128, 11.787175234126286, 12.23212982272507, 12.6614572621006, 13.076696830622023, 13.479150566708572, 13.8699315066802, 14.250000000000004, 14.620191517213447, 14.981238266578638, 15.333786225195656, 15.678408720275158, 16.01561737804697, 16.34587103827753, 16.669583078169655, 16.987127479359188, 17.298843892006193, 17.605041891458256, 17.906004579469982, 18.201991649267395, 18.49324200890693, 18.779976038323376, 19.062397540708254, 19.34069543734144, 19.615045245933032, 19.88561037534428, 20.152543263816607, 20.415986383224304, 20.676073128135336, 20.9329286054293, 21.186670337738306, 21.43740889193468, 21.685248442201445, 21.93028727582017, 22.172618248641726, 22.412329196225905, 22.649503305812257, 22.88421945358854, 23.11655251113367, 23.346573624410077, 23.57435046825257, 23.79994747893365, 24.023426067070456, 24.244844812866926, 24.46425964545014, 24.681724007856502, 24.897289009046755, 25.111003564174812, 25.3229145242012, 25.533066795823807, 25.741503452595776, 25.94826583800929, 26.153393661244046, 26.35692508620837, 26.55889681443866, 26.75934416236691, 26.958301133417145, 27.155800485347513, 27.351873793215706, 27.54655150831044, 27.7398630133604, 27.93183667430411, 28.122499888879016, 28.311879132265314, 28.500000000000007, 28.68688724835792, 28.872564832380245, 29.05705594171578, 29.240383034426895, 29.422567868899552, 29.603631533985833, 29.783594477497175, 29.962476533157275, 30.140296946115186, 30.31707439711161, 30.492827025384187, 30.66757245039131, 30.84132779242814, 31.014109692203004, 31.18593432943769, 31.356817440550316, 31.526774335475558, 31.695819913673166, 31.863968679372004, 32.03123475609394, 32.19763190049853, 32.36317351558713, 32.52787266330217, 32.69174207655506, 32.85479417071427], [0.0, 3.3541019662496847, 4.743416490252569, 5.809475019311127, 6.708203932499369, 7.500000000000001, 8.215838362577493, 8.874119674649425, 9.486832980505138, 10.062305898749054, 10.606601717798213, 11.124297730643496, 11.618950038622254, 12.093386622447827, 12.549900398011134, 12.990381056766578, 13.416407864998739, 13.82931668593933, 14.230249470757709, 14.62019151721345, 15.000000000000002, 15.370426148939401, 15.732132722552274, 16.085707942145415, 16.431676725154986, 16.770509831248425, 17.10263137648707, 17.428425057933378, 17.74823934929885, 18.062391868188445, 18.371173070873834, 18.6748493969831, 18.973665961010276, 19.267848867997696, 19.55760721560795, 19.84313483298443, 20.12461179749811, 20.402205763103165, 20.676073128135336, 20.946360065653415, 21.213203435596427, 21.476731594914533, 21.73706511928416, 21.99431744792277, 22.248595461286993, 22.5, 22.748626332154654, 22.99456457513384, 23.237900077244507, 23.47871376374779, 23.71708245126285, 23.953079134006973, 24.186773244895654, 24.418230894149563, 24.64751508773248, 24.874685927665503, 25.09980079602227, 25.3229145242012, 25.544079548889606, 25.763346055976506, 25.980762113533157, 26.196373794859472, 26.410225292488516, 26.622359023948274, 26.832815729997478, 27.041634565979923, 27.248853186877426, 27.45450782658469, 27.65863337187866, 27.861263431510068, 28.062430400804562, 28.26216552212516, 28.460498941515418, 28.657459761814202, 28.85307609250702, 29.04737509655563, 29.2403830344269, 29.432125305522877, 29.622626487197255, 29.81191037152769, 30.000000000000004, 30.186917696247164, 30.372685096974887, 30.55732318119505, 30.740852297878803, 30.923292192132458, 31.104662029991584, 31.28498042192132, 31.464265445104548, 31.642534664593484, 31.81980515339464, 31.996093511552314, 32.17141588429083, 32.34578797927174, 32.519225083018206, 32.69174207655505, 32.86335345030997, 33.034073318317866, 33.20391543176798, 33.37289319193049, 33.54101966249685, 33.70830758136635], [0.0, 3.43693177121688, 4.860555523805895, 5.95294044989533, 6.87386354243376, 7.6852130744697, 8.41872912024137, 9.093266739736606, 9.72111104761179, 10.31079531365064, 10.86853255964208, 11.399013115177999, 11.90588089979066, 12.392033731393731, 12.859821149611687, 13.311179511974135, 13.74772708486752, 14.170832720768388, 14.581666571417687, 14.981238266578638, 15.3704261489394, 15.750000000000004, 16.12063894515351, 16.482945731876935, 16.83745824048274, 17.184658856084404, 17.524982168321888, 17.85882134968599, 18.186533479473212, 18.5084440188796, 18.8248505970167, 19.13602623325961, 19.44222209522358, 19.743669871632278, 20.04058382383108, 20.33316256758894, 20.62159062730128, 20.906039797149532, 21.186670337738306, 21.463632031881282, 21.73706511928416, 22.007101126681818, 22.273863607376253, 22.53746880197508, 22.798026230355998, 23.055639223409095, 23.31040540188008, 23.562417108607512, 23.81176179958132, 24.05852239851816, 24.30277761902948, 24.54460225793036, 24.784067462787462, 25.02124097641842, 25.25618736072411, 25.488968201949646, 25.719642299223374, 25.94826583800929, 26.174892549922728, 26.399573860197062, 26.62235902394827, 26.84329525225992, 27.062427829003074, 27.279800219209818, 27.49545416973504, 27.70942980286675, 27.921765703479426, 28.132499000266577, 28.341665441536776, 28.549299466011423, 28.755434269021222, 28.960101864461734, 29.163333142835373, 29.36515792567784, 29.565605016640536, 29.764702249476645, 29.962476533157275, 30.15895389432465, 30.3541595172721, 30.548117781624455, 30.7408522978788, 30.932385940951924, 31.12274088186965, 31.31193861772216, 31.500000000000007, 31.686945261416415, 31.87279404131367, 32.05756540974377, 32.24127789030702, 32.42394948182593, 32.60559767892624, 32.78623949159159, 32.96589146375387, 33.14456969097653, 33.3222898372846, 33.49906715119094, 33.67491648096548, 33.84985228919028, 34.02388866664127, 34.197039345534, 34.36931771216881, 34.540736819008366], [0.0, 3.5178118198675725, 4.9749371855331, 6.0930288034769715, 7.035623639735145, 7.866066361276137, 8.616843969807045, 9.307255234493143, 9.9498743710662, 10.553435459602717, 11.124297730643494, 11.667261889578036, 12.186057606953943, 12.683650893965824, 13.162446581088185, 13.624426593438711, 14.07124727947029, 14.504309704360287, 14.9248115565993, 15.333786225195658, 15.732132722552274, 16.12063894515351, 16.5, 16.87083281880299, 17.23368793961409, 17.589059099337863, 17.937391114652097, 18.279086410430914, 18.614510468986285, 18.943996410472632, 19.267848867997692, 19.586347285800894, 19.8997487421324, 20.20829037796122, 20.512191496766015, 20.81165538826741, 21.106870919205434, 21.39801392653066, 21.685248442201445, 21.968727773815218, 22.24859546128699, 22.524986126521814, 22.798026230355998, 23.067834748844547, 23.334523779156072, 23.59819908382841, 23.8589605808803, 24.11690278622029, 24.372115213907886, 24.624682739073005, 24.874685927665503, 25.122201336666343, 25.36730178793165, 25.61005661844581, 25.850531909421132, 26.088790696389133, 26.32489316217637, 26.55889681443866, 26.790856649237632, 27.020825301977734, 27.248853186877422, 27.474988626021304, 27.699277968929085, 27.921765703479426, 28.14249455894058, 28.361505601783556, 28.578838324886476, 28.794530730678698, 29.008619408720573, 29.221139608167235, 29.432125305522877, 29.641609268054257, 29.8496231131986, 30.056197364270815, 30.261361502748024, 30.46514401738485, 30.667572450391315, 30.868673440885015, 31.068472765811975, 31.26699537851375, 31.464265445104548, 31.66030637880815, 31.85514087239296, 32.04879092883225, 32.24127789030702, 32.432622465659485, 32.62284475639732, 32.81196428134104, 33.0, 33.18697033475638, 33.37289319193049, 33.55778598179564, 33.74166563760598, 33.92454863369593, 34.10645100270622, 34.28738835198738, 34.46737587922818, 34.646428387353296, 34.8245602987317, 35.00178566873411, 35.178118198675726, 35.35357124817803], [0.0, 3.59687364248454, 5.086747487343951, 6.2299678971885575, 7.19374728496908, 8.042853971072708, 8.810505093353049, 9.51643315533714, 10.173494974687902, 10.79062092745362, 11.374313166077327, 11.929480290440152, 12.459935794377115, 12.968712349342939, 13.458268833694772, 13.930631715755032, 14.38749456993816, 14.830289949963891, 15.260242462031854, 15.678408720275158, 16.085707942145415, 16.482945731876935, 16.87083281880299, 17.250000000000004, 17.621010186706098, 17.9843682124227, 18.34052889095623, 18.68990369156567, 19.03286631067428, 19.369757355217438, 19.700888304845545, 20.026544884228034, 20.346989949375804, 20.66246597093387, 20.973197181164345, 21.27939143866666, 21.58124185490724, 21.878928218722233, 22.17261824864173, 22.46246869780791, 22.748626332154654, 23.031228799176134, 23.310405401880086, 23.586277790274583, 23.858960580880304, 24.128561913218117, 24.39518395093589, 24.658923334160395, 24.91987158875423, 25.17811549739178, 25.43373743671976, 25.68681568431557, 25.937424698685877, 26.185635375144138, 26.43151528005915, 26.675128865668114, 26.916537667389544, 27.15580048534751, 27.392973551624518, 27.628110684590798, 27.861263431510064, 28.092481200492067, 28.321811382748812, 28.549299466011423, 28.77498913987632, 28.99892239377181, 29.221139608167235, 29.441679639585782, 29.660579899927782, 29.877876430563134, 30.09360397160832, 30.30779602676513, 30.52048492406371, 30.73170187282182, 30.941477017104404, 31.149839485942785, 31.356817440550316, 31.56243811875122, 31.766727876821065, 31.969712228920677, 32.17141588429083, 32.371862782360864, 32.571076125912704, 32.76907841243022, 32.96589146375387, 33.16153645415122, 33.35603393690563, 33.54940386951757, 33.74166563760598, 33.93283807759086, 34.12293949823198, 34.31198770109362, 34.50000000000001, 34.686993239541536, 34.87298381268802, 35.057987677560725, 35.242020373412196, 35.42509703585864, 35.60723241140766, 35.788440871320454, 35.9687364248454, 36.14813273185768], [0.0, 3.6742346141747673, 5.196152422706632, 6.363961030678929, 7.3484692283495345, 8.215838362577493, 9.000000000000002, 9.72111104761179, 10.392304845413264, 11.022703842524303, 11.618950038622252, 12.186057606953941, 12.727922061357859, 13.247641299491772, 13.747727084867522, 14.230249470757705, 14.696938456699069, 15.149257407543116, 15.588457268119896, 16.01561737804697, 16.431676725154986, 16.83745824048274, 17.233687939614086, 17.621010186706098, 18.000000000000004, 18.371173070873837, 18.734993995195197, 19.091883092036785, 19.44222209522358, 19.78635893740938, 20.124611797498105, 20.457272545478784, 20.784609690826528, 21.106870919205434, 21.42428528562855, 21.737065119284157, 22.045407685048605, 22.34949663862701, 22.649503305812253, 22.945587811167535, 23.237900077244504, 23.526580712037187, 23.81176179958132, 24.093567606313517, 24.372115213907882, 24.647515087732476, 24.919871588754223, 25.18928343562, 25.455844122715718, 25.71964229922337, 25.980762113533164, 26.239283526803856, 26.495282598983543, 26.74883175019051, 27.000000000000004, 27.24885318687743, 27.495454169735044, 27.739863013360395, 27.98213715926645, 28.22233158334017, 28.46049894151541, 28.696689704563486, 28.930952282978865, 29.16333314283537, 29.393876913398138, 29.62262648719725, 29.849623113198597, 30.07490648364513, 30.298514815086232, 30.520484924063705, 30.740852297878796, 30.95965116082544, 31.176914536239792, 31.392674304684526, 31.60696125855822, 31.81980515339464, 32.03123475609394, 32.24127789030702, 32.44996147917591, 32.657311585615865, 32.86335345030997, 33.06811152757291, 33.27160951922826, 33.4738704066321, 33.67491648096548, 33.87476937190865, 34.07345007480164, 34.27097897638759, 34.46737587922817, 34.66266002487403, 34.856850115866756, 35.04996433664377, 35.242020373412196, 35.433035433053156, 35.62302626111376, 35.812009158939965, 36.00000000000001, 36.18701424544446, 36.373066958946424, 36.55817282086183, 36.742346141747674, 36.92560087527352], [0.0, 3.7500000000000004, 5.303300858899107, 6.495190528383291, 7.500000000000001, 8.385254915624213, 9.185586535436919, 9.921567416492215, 10.606601717798213, 11.25, 11.858541225631424, 12.437342963832752, 12.990381056766582, 13.520817282989961, 14.031215200402283, 14.523687548277813, 15.000000000000002, 15.461646096066227, 15.909902576697322, 16.34587103827753, 16.770509831248425, 17.184658856084404, 17.589059099337863, 17.9843682124227, 18.371173070873837, 18.750000000000004, 19.121323175972947, 19.48557158514987, 19.84313483298443, 20.194368026754393, 20.53959590644373, 20.87911636061258, 21.213203435596427, 21.54210992451761, 21.86606960566988, 22.18529918662356, 22.5, 22.810359488618325, 23.116552511133666, 23.418742493993996, 23.717082451262847, 24.011715890373186, 24.30277761902948, 24.5903944661325, 24.874685927665503, 25.155764746872634, 25.433737436719756, 25.708704751503916, 25.980762113533164, 26.25, 26.516504294495537, 26.780356607035692, 27.041634565979923, 27.300412084801945, 27.55675960631076, 27.81074432660874, 28.062430400804566, 28.31187913226531, 28.55914914698966, 28.80429655450728, 29.047375096555626, 29.288436284649954, 29.527529527544292, 29.764702249476645, 30.000000000000004, 30.233466556119563, 30.46514401738485, 30.695072894521687, 30.923292192132454, 31.14983948594278, 31.374750995027835, 31.598061649411346, 31.819805153394643, 32.04001404494074, 32.25871975140985, 32.47595264191645, 32.69174207655506, 32.90611645272046, 33.11910324872943, 33.330729064933465, 33.54101966249685, 33.75000000000001, 33.95769426801532, 34.164125921791126, 34.36931771216881, 34.57329171484833, 34.77606935810889, 34.97767144908306, 35.178118198675726, 35.37742924521227, 35.57562367689427, 35.77272005313546, 35.9687364248454, 36.16369035372359, 36.35759893062247, 36.55047879303361, 36.742346141747674, 36.9332167567354, 37.123106012293746, 37.31202889149825, 37.50000000000001, 37.687033579203344], [0.0, 3.824264635194589, 5.4083269131959835, 6.623820649745887, 7.648529270389178, 8.551315688243536, 9.367496997597598, 10.118053172424032, 10.816653826391967, 11.472793905583767, 12.093386622447825, 12.683650893965824, 13.247641299491773, 13.78858223313768, 14.309088021254187, 14.811313243598624, 15.297058540778355, 15.767847031221478, 16.224980739587952, 16.669583078169655, 17.10263137648707, 17.524982168321888, 17.937391114652097, 18.34052889095623, 18.734993995195197, 19.121323175972947, 19.500000000000004, 19.87146194923766, 20.236106344848064, 20.594295326618973, 20.946360065653412, 21.292604349867585, 21.633307652783934, 21.968727773815218, 22.299103120977758, 22.624654693497533, 22.945587811167535, 23.262093628906236, 23.57435046825257, 23.88252499213599, 24.18677324489565, 24.487241575971765, 24.784067462787466, 25.07738024595073, 25.36730178793165, 25.653947064730605, 25.937424698685874, 26.217837439422805, 26.495282598983547, 26.769852446362123, 27.041634565979926, 27.31071218404969, 27.57716446627536, 27.84106678990588, 28.1024909927928, 28.361505601783563, 28.618176042508374, 28.872564832380238, 29.124731758421404, 29.37473404134921, 29.62262648719725, 29.86846162760982, 30.1122898498271, 30.354159517272095, 30.59411708155671, 30.8322071866417, 31.06847276581197, 31.30295513206381, 31.535694062442957, 31.766727876821058, 31.996093511552314, 32.22382658841126, 32.449961479175904, 32.67453136618795, 32.89756829919197, 33.11910324872943, 33.33916615633931, 33.55778598179564, 33.774990747593115, 33.990807580873984, 34.20526275297414, 34.418381716751306, 34.6301891418456, 34.84070894801081, 35.049964336643775, 35.25797782062948, 35.464771252610674, 35.67036585178235, 35.874782229304195, 36.07804041241708, 36.28015986734348, 36.48115952104593, 36.68105778191246, 36.87987255943275, 37.07762128292483, 37.27432091936753, 37.46998799039039, 37.66463858846917, 37.85828839237189, 38.05095268189747, 38.24264635194589, 38.433383925956875], [0.0, 3.897114317029974, 5.5113519212621505, 6.750000000000002, 7.794228634059948, 8.714212528966689, 9.545941546018394, 10.31079531365064, 11.022703842524301, 11.691342951089922, 12.323757543866238, 12.925265954710566, 13.500000000000004, 14.051245496396398, 14.581666571417687, 15.09345884812358, 15.588457268119896, 16.068213964221414, 16.534055763786455, 16.98712747935919, 17.428425057933378, 17.85882134968599, 18.279086410430914, 18.68990369156567, 19.091883092036788, 19.485571585149874, 19.87146194923766, 20.250000000000004, 20.62159062730128, 20.986602869449836, 21.345374206136558, 21.69821421223415, 22.045407685048602, 22.387217334898953, 22.723886111314677, 23.055639223409095, 23.382685902179844, 23.705220943918665, 24.023426067070453, 24.337471109381934, 24.647515087732476, 24.953707139421194, 25.25618736072411, 25.55508755610123, 25.850531909421132, 26.142637586900065, 26.431515280059145, 26.717269695835316, 27.000000000000007, 27.279800219209818, 27.55675960631076, 27.830962972919213, 28.102490992792795, 28.371420479066607, 28.63782463805518, 28.901773301996545, 29.163333142835373, 29.42256786889955, 29.679538406114073, 29.93430306521266, 30.18691769624716, 30.437435831554538, 30.685908818218177, 30.93238594095192, 31.176914536239792, 31.41954009848012, 31.660306378808148, 31.899255477205106, 32.13642792844283, 32.37186278236086, 32.60559767892624, 32.837668918484454, 33.06811152757291, 33.29695932063467, 33.52424495794052, 33.75, 33.97425495871838, 34.197039345533994, 34.418381716751306, 34.63830971626647, 34.856850115866756, 35.074028853269766, 35.28987106805578, 35.50440113563388, 35.71764269937198, 35.929618701010455, 36.14035140947028, 36.34986244815791, 36.55817282086183, 36.76530293632843, 36.971272631598715, 37.176101194181186, 37.37980738313134, 37.582409449102656, 37.783925153430005, 37.98437178630179, 38.183766184073576, 38.38212474577196, 38.57946344883506, 38.7757978641317, 38.97114317029975, 39.165514167440726], [0.0, 3.968626966596886, 5.612486080160911, 6.873863542433761, 7.937253933193772, 8.874119674649425, 9.721111047611792, 10.5, 11.224972160321823, 11.905880899790658, 12.549900398011133, 13.162446581088185, 13.747727084867522, 14.309088021254187, 14.849242404917499, 15.370426148939396, 15.874507866387544, 16.36306817195357, 16.837458240482736, 17.298843892006197, 17.74823934929885, 18.186533479473216, 18.614510468986285, 19.032866310674283, 19.442222095223585, 19.843134832984433, 20.236106344848064, 20.62159062730128, 21.0, 21.371710273162513, 21.737065119284157, 22.09637979398435, 22.449944320643645, 22.798026230355998, 23.140872930812268, 23.47871376374779, 23.811761799581316, 24.140215409146624, 24.464259645450138, 24.784067462787462, 25.099800796022265, 25.411611519146128, 25.719642299223374, 26.024027359346206, 26.32489316217637, 26.62235902394827, 26.91653766738954, 27.207535720825582, 27.495454169735044, 27.780388766178202, 28.062430400804566, 28.34166544153678, 28.618176042508374, 28.892040426387336, 29.163333142835373, 29.43212530552288, 29.698484809834998, 29.962476533157268, 30.22416251941483, 30.483602149352365, 30.740852297878792, 30.995967479657736, 31.24899998399949, 31.5, 31.74901573277509, 31.996093511552314, 32.24127789030701, 32.48461174156157, 32.72613634390714, 32.96589146375386, 33.20391543176798, 33.44024521441193, 33.67491648096547, 33.90796366637194, 34.13942003022313, 34.3693177121688, 34.59768778401239, 34.8245602987317, 35.049964336643775, 35.27392804891454, 35.4964786985977, 35.71764269937198, 35.93744565213282, 36.15591237958185, 36.37306695894643, 36.58893275295141, 36.803532439155894, 37.0168880377592, 37.22902093797257, 37.43995192304605, 37.6497011940334, 37.85828839237188, 38.065732621348566, 38.27205246651923, 38.477266015141986, 38.681390874682876, 38.88444419044717, 39.086442662386155, 39.287402561126385, 39.487339743264556, 39.686269665968865, 39.88420740092499], [0.0, 4.0388736053508785, 5.7118298293979315, 6.995534289816613, 8.077747210701757, 9.031195934094223, 9.893179468704691, 10.685855136581255, 11.423659658795863, 12.116620816052635, 12.772039774444801, 13.395428324618816, 13.991068579633225, 14.562365879210702, 15.112081259707415, 15.642490210960657, 16.155494421403514, 16.65270248338089, 17.135489488193794, 17.605041891458256, 18.062391868188445, 18.5084440188796, 18.943996410472636, 19.36975735521744, 19.786358937409382, 20.194368026754393, 20.594295326618973, 20.986602869449836, 21.37171027316251, 21.75, 22.121821805628937, 22.487496525847426, 22.847319317591726, 23.201562447387033, 23.550477702161373, 23.894298483110987, 24.23324163210527, 24.567509031238803, 24.89728900904675, 25.22275758120036, 25.544079548889602, 25.861409474350005, 26.174892549922728, 26.484665374514364, 26.790856649237632, 27.093587802282663, 27.39297355162451, 27.6891224129621, 27.98213715926645, 28.27211523745615, 28.55914914698966, 28.84332678454412, 29.124731758421404, 29.40344367586899, 29.679538406114073, 29.953088321573794, 30.22416251941483, 30.492827025384184, 30.759144981614824, 31.023176819919655, 31.284980421921315, 31.544611267219636, 31.802122570671287, 32.057565409743766, 32.31098884280703, 32.56244001913862, 32.811964281341034, 33.059605260801284, 33.30540496676178, 33.54940386951756, 33.79164097820643, 34.03215391361528, 34.27097897638759, 34.50815121098202, 34.74370446570141, 34.97767144908306, 35.21008378291651, 35.44097205213198, 35.67036585178235, 35.89829383132297, 36.12478373637689, 36.34986244815791, 36.57355602070984, 36.79588971610824, 37.0168880377592, 37.23657476191923, 37.45497296755132, 37.67210506462309, 37.88799282094527, 38.102657387641614, 38.316119323334405, 38.52839861712397, 38.73951471043488, 38.94948651779636, 39.158332446619845, 39.36607041603212, 39.572717874818764, 39.778291818528366, 39.98280880578552, 40.186284973856445, 40.38873605350879, 40.59017738320443], [0.0, 4.107919181288746, 5.809475019311124, 7.1151247353788545, 8.215838362577491, 9.185586535436917, 10.062305898749054, 10.868532559642079, 11.618950038622248, 12.323757543866236, 12.990381056766578, 13.624426593438713, 14.230249470757709, 14.811313243598624, 15.370426148939398, 15.909902576697316, 16.431676725154983, 16.93738468595432, 17.428425057933374, 17.906004579469986, 18.371173070873834, 18.824850597016702, 19.267848867997692, 19.700888304845545, 20.12461179749811, 20.53959590644373, 20.946360065653412, 21.345374206136558, 21.737065119284157, 22.121821805628937, 22.499999999999996, 22.871926022965358, 23.237900077244497, 23.59819908382841, 23.953079134006966, 24.302777619029474, 24.647515087732472, 24.98749687343652, 25.3229145242012, 25.653947064730605, 25.980762113533157, 26.303516875125275, 26.622359023948274, 26.937427494101954, 27.248853186877426, 27.55675960631075, 27.86126343151006, 28.16247503327788, 28.460498941515418, 28.75543426902122, 29.04737509655563, 29.33641082341192, 29.62262648719725, 29.906103056065326, 30.186917696247164, 30.465144017384855, 30.740852297878796, 31.014109692202997, 31.28498042192132, 31.553525951943943, 31.819805153394633, 32.08387445431116, 32.34578797927173, 32.60559767892623, 32.863353450309965, 33.119103248729424, 33.37289319193048, 33.624767657189835, 33.87476937190864, 34.12293949823197, 34.369317712168794, 34.61394227764298, 34.85685011586675, 35.09807687039277, 35.337656968169235, 35.57562367689427, 35.81200915893997, 36.04684452209374, 36.28015986734348, 36.511984333914256, 36.74234614174767, 36.971272631598715, 37.19879030291174, 37.42492484962395, 37.649701194033405, 37.873143518857795, 38.095275297600885, 38.316119323334405, 38.535697735995385, 38.754032048291435, 38.97114317029974, 39.18705143283939, 39.40177660969109, 39.61533793873277, 39.82775414205526, 40.03904344511741, 40.24922359499622, 40.45831187778354, 40.66632513517787, 40.87327978031614, 41.07919181288746, 41.284076833568655], [0.0, 4.175823272122517, 5.905505905508858, 7.232738070744718, 8.351646544245034, 9.33742469849155, 10.228636272739394, 11.048189896992175, 11.811011811017716, 12.52746981636755, 13.205112646244256, 13.849638984464542, 14.465476141489436, 15.05614492491355, 15.624499991999745, 16.172893989635867, 16.703293088490067, 17.217360424873494, 17.716517716526575, 18.2019916492674, 18.6748493969831, 19.136026233259614, 19.586347285800894, 20.026544884228034, 20.457272545478787, 20.879116360612585, 21.292604349867588, 21.69821421223415, 22.09637979398435, 22.487496525847426, 22.871926022965358, 23.25, 23.62202362203543, 23.988278387579214, 24.349024621121888, 24.704503638000904, 25.0549396327351, 25.40054133281415, 25.741503452595772, 26.07800797607057, 26.410225292488512, 26.738315204963833, 27.062427829003077, 27.382704395293025, 27.699277968929085, 28.012274095474645, 28.32181138274881, 28.628002025988472, 28.930952282978872, 29.230762904857613, 29.527529527544296, 29.82134302810657, 30.1122898498271, 30.400452299266863, 30.68590881821818, 30.968734233093873, 31.24899998399949, 31.52677433547555, 31.80212257067129, 32.07510717051465, 32.34578797927173, 32.61422235773835, 32.88046532517446, 33.144569690976525, 33.406586176980134, 33.66656353119516, 33.92454863369592, 34.18058659531752, 34.43472084974699, 34.68699323954153, 34.93744409655635, 35.1861123172197, 35.43303543305315, 35.678249676798885, 35.92179004448414, 36.16369035372358, 36.4039832985348, 36.64270050091832, 36.87987255943275, 37.11552909497587, 37.3496987939662, 37.58240944910265, 37.8136879978666, 38.0435605589172, 38.27205246651923, 38.499188303131795, 38.72499193027676, 38.94948651779636, 39.17269457160179, 39.39463796000669, 39.61533793873277, 39.8348151746685, 40.05308976845607, 40.2701812759764, 40.48610872879734, 40.7008906536454, 40.914545090957574, 41.12708961256559, 41.33854133856201, 41.54891695339363, 41.75823272122517, 41.96650450061335], [0.0, 4.242640687119285, 5.999999999999999, 7.348469228349535, 8.48528137423857, 9.486832980505138, 10.392304845413264, 11.224972160321823, 11.999999999999998, 12.727922061357855, 13.416407864998737, 14.071247279470288, 14.69693845669907, 15.297058540778355, 15.874507866387544, 16.431676725154983, 16.97056274847714, 17.4928556845359, 18.0, 18.493242008906932, 18.973665961010276, 19.44222209522358, 19.8997487421324, 20.346989949375807, 20.784609690826528, 21.213203435596427, 21.633307652783937, 22.045407685048602, 22.449944320643645, 22.847319317591726, 23.237900077244497, 23.62202362203543, 23.999999999999996, 24.372115213907882, 24.73863375370596, 25.099800796022265, 25.45584412271571, 25.80697580112788, 26.153393661244042, 26.495282598983543, 26.832815729997474, 27.166155414412252, 27.495454169735044, 27.82085548648711, 28.142494558940577, 28.46049894151541, 28.774989139876315, 29.086079144497972, 29.39387691339814, 29.698484809834994, 30.000000000000004, 30.298514815086236, 30.59411708155671, 30.886890422961, 31.176914536239796, 31.464265445104548, 31.74901573277509, 32.03123475609393, 32.31098884280703, 32.58834147360064, 32.863353450309965, 33.13608305156178, 33.406586176980134, 33.67491648096547, 33.94112549695428, 34.205262752974136, 34.46737587922817, 34.72751070837067, 34.9857113690718, 35.24202037341219, 35.49647869859769, 35.749125863438955, 36.0, 36.24913792078372, 36.49657518178932, 36.74234614174767, 36.986484017813865, 37.22902093797257, 37.46998799039039, 37.70941526992961, 37.94733192202055, 38.18376618407357, 38.4187454245971, 38.65229618017538, 38.88444419044716, 39.1152144312159, 39.344631145812, 39.57271787481876, 39.7994974842648, 40.024992192379, 40.24922359499622, 40.47221268969612, 40.693979898751614, 40.91454509095757, 41.13392760240627, 41.35214625627066, 41.569219381653056, 41.785164831552365, 42.0, 42.21374183841087, 42.42640687119285, 42.63801121065569], [0.0, 4.308421984903522, 6.093028803476971, 7.462405778299652, 8.616843969807045, 9.633924433998848, 10.553435459602719, 11.399013115177999, 12.186057606953941, 12.925265954710566, 13.624426593438713, 14.28941916244324, 14.924811556599304, 15.534236382905988, 16.12063894515351, 16.68644659596524, 17.23368793961409, 17.764078923490516, 18.279086410430914, 18.779976038323376, 19.267848867997696, 19.743669871632278, 20.20829037796122, 20.66246597093387, 21.106870919205438, 21.54210992451761, 21.968727773815218, 22.387217334898953, 22.798026230355998, 23.201562447387033, 23.59819908382841, 23.988278387579214, 24.372115213907882, 24.750000000000004, 25.12220133666634, 25.488968201949643, 25.850531909421132, 26.207107814484225, 26.558896814438665, 26.90608667197815, 27.248853186877426, 27.587361236624286, 27.921765703479434, 28.252212302756046, 28.57883832488648, 28.901773301996542, 29.221139608167235, 29.537053001272827, 29.849623113198607, 30.158953894324654, 30.46514401738486, 30.76828724514903, 31.068472765811975, 31.36578549948973, 31.660306378808155, 31.952112606211195, 32.24127789030702, 32.52787266330216, 32.81196428134104, 33.09361720936531, 33.37289319193048, 33.649851411261835, 33.92454863369593, 34.197039345533994, 34.46737587922818, 34.735608530728236, 35.0017856687341, 35.26595383652624, 35.52815784698103, 35.788440871320454, 36.04684452209375, 36.30340893084285, 36.55817282086183, 36.81117357542408, 37.062447301817514, 37.31202889149825, 37.55995207664675, 37.806249483385685, 38.05095268189748, 38.294092233659235, 38.53569773599539, 38.7757978641317, 39.01442041091987, 39.25159232438858, 39.487339743264556, 39.721688030596084, 39.95466180560162, 40.186284973856445, 40.41658075592244, 40.645571714517686, 40.87327978031614, 41.09972627646077, 41.32493194186774, 41.54891695339363, 41.77170094693297, 41.993303037508255, 42.213741838410876, 42.433035479446914, 42.651201624338796, 42.86825748732972, 43.08421984903522, 43.299105071583185], [0.0, 4.373213921133975, 6.18465843842649, 7.57462870377156, 8.74642784226795, 9.778803607803974, 10.712142642814277, 11.570436465406134, 12.36931687685298, 13.119641763401926, 13.82931668593933, 14.504309704360288, 15.14925740754312, 15.76784703122148, 16.36306817195357, 16.93738468595432, 17.4928556845359, 18.031222920256962, 18.553975315279473, 19.062397540708254, 19.55760721560795, 20.040583823831085, 20.512191496766015, 20.97319718116435, 21.424285285628553, 21.86606960566988, 22.29910312097776, 22.723886111314677, 23.140872930812268, 23.550477702161373, 23.953079134006966, 24.349024621121888, 24.73863375370596, 25.12220133666634, 25.5, 25.87228246599051, 26.239283526803852, 26.6012217764523, 26.958301133417145, 27.31071218404969, 27.65863337187866, 28.002232053891706, 28.34166544153678, 28.67708144145774, 29.008619408720577, 29.336410823411917, 29.660579899927782, 29.98124413696003, 30.29851481508624, 30.612497447937827, 30.92329219213246, 31.230994220485524, 31.53569406244296, 31.83747791518669, 32.13642792844283, 32.432622465659485, 32.72613634390714, 33.017041054582705, 33.305404966761785, 33.591293514838036, 33.87476937190864, 34.155892610207104, 34.43472084974699, 34.711309396218404, 34.9857113690718, 35.25797782062948, 35.52815784698103, 35.79629869134517, 36.062445840513924, 36.326643114937006, 36.5889327529514, 36.84935548961474, 37.107950630558946, 37.36475612124345, 37.61980861195336, 37.873143518857795, 38.12479508141651, 38.37479641639809, 38.623179568751205, 38.86997555954982, 39.1152144312159, 39.35892529020578, 39.601136347332265, 39.84187495588028, 40.08116764766217, 40.31904016714684, 40.55551750378733, 40.790623922661446, 41.02438299353203, 41.2568176184252, 41.487950057818, 41.71780195552014, 41.9463943623287, 42.17374775852865, 42.399882075307715, 42.62481671514846, 42.848570571257106, 43.07116204608369, 43.292609068985435, 43.512929113080865, 43.73213921133976, 43.95025597195084], [0.0, 4.437059837324712, 6.274950199005566, 7.6852130744697, 8.874119674649425, 9.921567416492215, 10.86853255964208, 11.739356881873896, 12.549900398011133, 13.311179511974137, 14.03121520040228, 14.716062652761439, 15.3704261489394, 15.998046755776159, 16.60195771588399, 17.184658856084397, 17.74823934929885, 18.2944663764757, 18.8248505970167, 19.34069543734144, 19.84313483298443, 20.333162567588943, 20.81165538826741, 21.279391438666664, 21.73706511928416, 22.185299186623563, 22.624654693497536, 23.055639223409095, 23.47871376374779, 23.894298483110987, 24.302777619029474, 24.704503638000904, 25.099800796022265, 25.488968201949643, 25.87228246599051, 26.249999999999996, 26.622359023948274, 26.989581323169872, 27.351873793215706, 27.70942980286675, 28.06243040080456, 28.41104538731372, 28.755434269021226, 29.095747111906235, 29.432125305522877, 29.764702249476642, 30.093603971608317, 30.41894968600987, 30.7408522978788, 31.05941886127298, 31.37475099502784, 31.686945261416415, 31.996093511552317, 32.30228320103704, 32.60559767892624, 32.90611645272046, 33.20391543176798, 33.49906715119094, 33.79164097820643, 34.08170330250529, 34.369317712168794, 34.65454515644377, 34.93744409655635, 35.21807064562169, 35.4964786985977, 35.77272005313546, 36.04684452209374, 36.31890003840975, 36.5889327529514, 36.856987125916845, 37.123106012293746, 37.38733074184355, 37.6497011940334, 37.91025586830033, 38.16903194999842, 38.426065372348496, 38.68139087468288, 38.935042057252225, 39.187051432839404, 39.437450475404724, 39.68626966596886, 39.93353853592241, 40.17928570793663, 40.423538934635594, 40.666325135177885, 40.90767042988393, 41.14760017303561, 41.38613898396419, 41.62331077653482, 41.85913878712748, 42.09364560120684, 42.32685317856738, 42.55878287733333, 42.78945547678774, 43.01889119909996, 43.24710973001548, 43.47413023856832, 43.69997139587165, 43.924651393038964, 44.14818795828432, 44.37059837324713, 44.59189948858425], [0.0, 4.5, 6.363961030678927, 7.794228634059949, 9.0, 10.062305898749054, 11.022703842524303, 11.905880899790656, 12.727922061357853, 13.5, 14.230249470757707, 14.9248115565993, 15.588457268119898, 16.224980739587952, 16.837458240482736, 17.428425057933374, 18.0, 18.55397531527947, 19.091883092036785, 19.615045245933032, 20.12461179749811, 20.62159062730128, 21.10687091920543, 21.58124185490724, 22.045407685048605, 22.5, 22.94558781116753, 23.382685902179844, 23.811761799581312, 24.23324163210527, 24.647515087732472, 25.054939632735096, 25.455844122715707, 25.85053190942113, 26.23928352680385, 26.62235902394827, 27.0, 27.372431386341987, 27.739863013360395, 28.102490992792795, 28.460498941515414, 28.814059068447822, 29.163333142835373, 29.508473359359, 29.8496231131986, 30.186917696247157, 30.520484924063705, 30.8504457018047, 31.176914536239796, 31.499999999999996, 31.819805153394643, 32.13642792844283, 32.449961479175904, 32.76049450176233, 33.06811152757291, 33.37289319193049, 33.67491648096547, 33.97425495871837, 34.27097897638759, 34.565155865408734, 34.85685011586675, 35.14612354157995, 35.43303543305315, 35.71764269937197, 36.0, 36.28015986734347, 36.55817282086182, 36.834087473426024, 37.10795063055894, 37.379807383131336, 37.6497011940334, 37.91767397929361, 38.18376618407357, 38.448016853928884, 38.71046370169182, 38.97114317029974, 39.230090491866065, 39.48733974326455, 39.74292389847532, 39.99687487792015, 40.24922359499622, 40.5, 40.74923312161838, 40.996951106149346, 41.24318125460256, 41.487950057818, 41.73128322973067, 41.97320573889967, 42.21374183841086, 42.45291509425471, 42.690748412273116, 42.92726406376255, 43.16248370981448, 43.3964284244683, 43.629118716746966, 43.86057455164033, 44.09081537009721, 44.31986010808247, 44.54772721475249, 44.7744346697979, 45.0, 45.224440295044005], [0.0, 4.562071897723665, 6.45174395028197, 7.9017403146395555, 9.12414379544733, 10.201102881551583, 11.174748319313506, 12.07010770457331, 12.90348790056394, 13.686215693170995, 14.426538046253508, 15.130680751374012, 15.803480629279111, 16.448784149595983, 17.069710015111564, 17.668828484084617, 18.24828759089466, 18.80990430597668, 19.35523185084591, 19.88561037534428, 20.402205763103165, 20.906039797149536, 21.39801392653066, 21.878928218722237, 22.349496638627013, 22.810359488618328, 23.262093628906236, 23.705220943918665, 24.14021540914662, 24.567509031238803, 24.98749687343652, 25.40054133281415, 25.80697580112788, 26.207107814484225, 26.6012217764523, 26.989581323169872, 27.37243138634199, 27.75, 28.122499888879016, 28.490129869833872, 28.853076092507017, 29.211513141225673, 29.56560501664054, 29.915506012768695, 30.261361502748024, 30.603308644654746, 30.941477017104404, 31.275989192989567, 31.606961258558222, 31.934503284065652, 32.258719751409856, 32.579709943460216, 32.89756829919197, 33.212384738226795, 33.52424495794052, 33.83323070591989, 34.13942003022313, 34.442887509615105, 34.74370446570141, 35.041939158671, 35.337656968169235, 35.630920560659106, 35.92179004448414, 36.21032311371993, 36.49657518178932, 36.78059950571769, 37.06244730181751, 37.34216785351381, 37.61980861195336, 37.89541528997934, 38.16903194999842, 38.440701086218496, 38.71046370169182, 38.97835938055885, 39.24442635585339, 39.508701573197776, 39.77122075068856, 40.03201843524755, 40.29112805568989, 40.54858197273982, 40.80441152620633, 41.05864707951299, 41.31131806176124, 41.56245300749224, 41.81207959429907, 42.06022467842986, 42.30691432851137, 42.552173857512855, 42.79602785306132, 43.03850020621072, 43.27961413876053, 43.51939222921202, 43.757856437444474, 43.9950281281874, 44.2309280933602, 44.46557657334491, 44.698993277254026, 44.93119740225048, 45.162207651973794, 45.39204225412204, 45.620718977236656, 45.84825514673378], [0.0, 4.623310502226732, 6.5383484153110105, 8.007808689023486, 9.246621004453464, 10.338036564067668, 11.324751652906127, 12.232129822725067, 13.076696830622021, 13.869931506680198, 14.620191517213447, 15.333786225195656, 16.015617378046972, 16.669583078169655, 17.298843892006197, 17.906004579469982, 18.49324200890693, 19.06239754070825, 19.615045245933032, 20.152543263816607, 20.676073128135336, 21.186670337738306, 21.68524844220144, 22.172618248641726, 22.649503305812253, 23.116552511133666, 23.574350468252568, 24.023426067070453, 24.464259645450134, 24.89728900904675, 25.322914524201195, 25.741503452595772, 26.153393661244042, 26.55889681443866, 26.958301133417145, 27.351873793215702, 27.739863013360395, 28.122499888879013, 28.500000000000004, 28.87256483238024, 29.240383034426895, 29.60363153398583, 29.962476533157275, 30.317074397111607, 30.66757245039131, 31.014109692202997, 31.35681744055031, 31.695819913673162, 32.031234756093944, 32.36317351558713, 32.69174207655506, 33.01704105458271, 33.33916615633931, 33.65820850847532, 33.974254958718376, 34.28738835198739, 34.59768778401239, 34.90522883466029, 35.21008378291651, 35.51232180525515, 35.812009158939965, 36.10920935163217, 36.4039832985348, 36.696389468175205, 36.98648401781386, 37.27432091936753, 37.559952076646745, 37.843427434628595, 38.1247950814165, 38.40410134347633, 38.68139087468288, 38.956706739661655, 39.230090491866065, 39.50158224679108, 39.771220750688556, 40.03904344511742, 40.305086527633215, 40.569385008895566, 40.83197276644861, 41.09288259540818, 41.35214625627067, 41.609794520040595, 41.86585721085859, 42.12036324629692, 42.37334067547661, 42.62481671514847, 42.87481778386936, 43.12336953439516, 43.37049688440288, 43.616224045646135, 43.86057455164034, 44.10357128396747, 44.34523649728345, 44.585591843105554, 44.82465839245181, 45.0624566573994, 45.299006611624506, 45.534327709981625, 45.76843890717707, 46.00135867558697, 46.23310502226733, 46.46369550520062], [0.0, 4.683748498798799, 6.623820649745885, 8.112490369793978, 9.367496997597598, 10.473180032826708, 11.472793905583767, 12.39203373139373, 13.24764129949177, 14.051245496396398, 14.811313243598626, 15.534236382905986, 16.224980739587956, 16.887495373796558, 17.524982168321888, 18.140079933671736, 18.734993995195197, 19.3115897843756, 19.87146194923766, 20.415986383224304, 20.946360065653415, 21.463632031881282, 21.968727773815218, 22.46246869780791, 22.945587811167535, 23.418742493993996, 23.88252499213599, 24.33747110938193, 24.78406746278746, 25.22275758120036, 25.653947064730605, 26.078007976070566, 26.49528259898354, 26.906086671978148, 27.310712184049688, 27.70942980286675, 28.102490992792795, 28.490129869833872, 28.87256483238024, 29.250000000000007, 29.622626487197252, 29.990623534698315, 30.3541595172721, 30.713392844164908, 31.068472765811972, 31.41954009848012, 31.766727876821058, 32.11016194291147, 32.44996147917591, 32.786239491591594, 33.11910324872943, 33.44865468146664, 33.774990747593115, 34.098203765007916, 34.418381716751306, 34.73560853072824, 35.049964336643775, 35.36152570237885, 35.67036585178235, 35.97655486563437, 36.28015986734347, 36.5812451947716, 36.87987255943274, 37.17610119418119, 37.46998799039039, 37.76158762552232, 38.05095268189747, 38.33813375739617, 38.6231795687512, 38.90613704802881, 39.1870514328394, 39.46596635076861, 39.74292389847532, 40.0179647158623, 40.29112805568988, 40.562451848969886, 40.83197276644861, 41.09972627646077, 41.365746699413044, 41.63006725913376, 41.89272013130683, 42.15373648918919, 42.413146546796085, 42.67097959972328, 42.927264063762564, 43.18202751145435, 43.43529670671078, 43.68709763763211, 43.937455547630435, 44.18639496496631, 44.43393973079588, 44.680113025819445, 44.92493739561582, 45.16843477474065, 45.41062650966182, 45.6515333805996, 45.89117562233507, 46.12957294404535, 46.3667445482212, 46.60270914871796, 46.83748498798799, 47.07108985353962], [0.0, 4.743416490252569, 6.7082039324993685, 8.215838362577493, 9.486832980505138, 10.606601717798213, 11.618950038622252, 12.549900398011133, 13.416407864998737, 14.230249470757707, 15.0, 15.732132722552274, 16.431676725154986, 17.10263137648707, 17.74823934929885, 18.371173070873834, 18.973665961010276, 19.557607215607945, 20.12461179749811, 20.676073128135336, 21.213203435596427, 21.73706511928416, 22.24859546128699, 22.748626332154654, 23.237900077244504, 23.717082451262847, 24.18677324489565, 24.647515087732476, 25.099800796022265, 25.544079548889602, 25.980762113533157, 26.410225292488512, 26.832815729997474, 27.248853186877426, 27.65863337187866, 28.06243040080456, 28.460498941515414, 28.853076092507017, 29.240383034426895, 29.622626487197252, 30.0, 30.372685096974884, 30.7408522978788, 31.10466202999158, 31.464265445104548, 31.819805153394636, 32.17141588429082, 32.5192250830182, 32.86335345030997, 33.20391543176798, 33.54101966249685, 33.87476937190865, 34.20526275297414, 34.532593299664015, 34.856850115866756, 35.178118198675726, 35.4964786985977, 35.812009158939965, 36.12478373637689, 36.43487340447336, 36.74234614174767, 37.04726710568541, 37.3496987939662, 37.6497011940334, 37.94733192202055, 38.242646351945886, 38.535697735995385, 38.82653731663435, 39.11521443121589, 39.40177660969109, 39.68626966596886, 39.96873778342268, 40.24922359499622, 40.527768258318886, 40.80441152620633, 41.07919181288746, 41.35214625627067, 41.62331077653482, 41.89272013130683, 42.16040796766559, 42.42640687119285, 42.69074841227312, 42.953463189829066, 43.2145808726638, 43.47413023856832, 43.73213921133976, 43.98863489584554, 44.24364361125788, 44.49719092257398, 44.749301670528894, 45.0, 45.249309386995066, 45.49725266430931, 45.74385204593072, 45.98912915026768, 46.23310502226732, 46.47580015448901, 46.717234507192316, 46.95742752749558, 47.196398167656824, 47.434164902525694, 47.67074574621211], [0.0, 4.802343178074637, 6.791538853603062, 8.317902379807064, 9.604686356149275, 10.738365797457266, 11.763290356018594, 12.705805759573062, 13.583077707206124, 14.407029534223911, 15.186342548487442, 15.927570436196477, 16.63580475961413, 17.315094570922795, 17.96872282606641, 18.599395151455866, 19.20937271229855, 19.80056817366613, 20.37461656080919, 20.9329286054293, 21.476731594914533, 22.00710112668182, 22.52498612652181, 23.031228799176134, 23.526580712037187, 24.011715890373186, 24.487241575971765, 24.95370713942119, 25.411611519146124, 25.861409474350005, 26.303516875125272, 26.738315204963833, 27.16615541441225, 27.587361236624286, 28.002232053891706, 28.411045387313717, 28.814059068447822, 29.211513141225673, 29.603631533985833, 29.99062353469831, 30.372685096974884, 30.750000000000007, 31.12274088186965, 31.491070162825526, 31.855140872392955, 32.215097392371796, 32.5710761259127, 32.923206101471955, 33.27160951922826, 33.616402246522455, 33.957694268015324, 34.295590095521035, 34.63018914184559, 34.96158606242, 35.28987106805578, 35.61513021175131, 35.93744565213282, 36.25689589581546, 36.57355602070984, 36.887497882073816, 37.19879030291173, 37.50749925014996, 37.813687997866595, 38.11741727871919, 38.4187454245971, 38.71772849742092, 39.01442041091986, 39.30887304413598, 39.60113634733226, 39.8912584409166, 40.17928570793662, 40.46526288064863, 40.74923312161838, 41.031238099769794, 41.31131806176124, 41.589511899035315, 41.8658572108586, 42.14039036364044, 42.413146546796085, 42.68415982539659, 42.953463189829066, 43.221088602671735, 43.48706704297268, 43.75142854810572, 44.01420225336364, 44.27541642943633, 44.535098517910576, 44.79327516491734, 45.04997225304362, 45.305214931616874, 45.55902764546232, 45.811434162226355, 46.06245759835227, 46.3121204437888, 46.560444585506275, 46.80745132988977, 47.053161424074375, 47.29759507628269, 47.54077197522144, 47.782711308589434, 48.02343178074637, 48.262951629588514], [0.0, 4.860555523805895, 6.87386354243376, 8.41872912024137, 9.72111104761179, 10.86853255964208, 11.90588089979066, 12.859821149611685, 13.74772708486752, 14.581666571417687, 15.3704261489394, 16.12063894515351, 16.83745824048274, 17.524982168321888, 18.186533479473216, 18.8248505970167, 19.44222209522358, 20.04058382383108, 20.621590627301284, 21.186670337738306, 21.73706511928416, 22.273863607376253, 22.798026230355998, 23.310405401880082, 23.81176179958132, 24.30277761902948, 24.784067462787462, 25.25618736072411, 25.71964229922337, 26.174892549922724, 26.62235902394827, 27.062427829003074, 27.49545416973504, 27.92176570347943, 28.34166544153678, 28.755434269021222, 29.163333142835373, 29.56560501664054, 29.962476533157275, 30.354159517272098, 30.7408522978788, 31.12274088186965, 31.500000000000007, 31.872794041313668, 32.24127789030702, 32.60559767892624, 32.96589146375387, 33.32228983728459, 33.67491648096548, 34.02388866664127, 34.36931771216881, 34.71130939621841, 35.049964336643775, 35.38537833625635, 35.71764269937198, 36.04684452209376, 36.37306695894643, 36.696389468175205, 37.01688803775921, 37.33463539396093, 37.6497011940334, 37.96215220453129, 38.27205246651923, 38.57946344883506, 38.88444419044716, 39.1870514328394, 39.48733974326455, 39.78536162962453, 40.08116764766216, 40.374806501084315, 40.66632513517788, 40.95576882442814, 41.24318125460257, 41.52860459972138, 41.812079594299064, 42.093645601206845, 42.37334067547661, 42.651201624338796, 42.927264063762564, 43.20156247174401, 43.47413023856832, 43.74499971425306, 44.01420225336364, 44.28176825737654, 44.547727214752506, 44.812107738868974, 45.07493760395016, 45.33624377912225, 45.596052460711995, 45.854389102898324, 46.1112784468182, 46.3667445482212, 46.620810803760165, 46.87349997599924, 47.12483421721503, 47.37483509206127, 47.62352359916264, 47.87092019169885, 48.11704479703632, 48.36191683546053, 48.60555523805896, 48.847978463801354], [0.0, 4.9180788932265, 6.955213871621777, 8.51836251870041, 9.836157786453, 10.997158723961384, 12.046783803156758, 13.012013679673103, 13.910427743243554, 14.7542366796795, 15.55233101499579, 16.31142237819866, 17.03672503740082, 17.732385626305334, 18.401766219577944, 19.04763764880044, 19.672315572906, 20.27775875189366, 20.865641614865332, 21.43740889193468, 21.994317447922768, 22.53746880197508, 23.067834748844547, 23.586277790274583, 24.093567606313517, 24.5903944661325, 25.07738024595073, 25.55508755610123, 26.024027359346206, 26.48466537451436, 26.93742749410195, 27.382704395293022, 27.82085548648711, 28.252212302756043, 28.677081441457737, 29.09574711190623, 29.508473359359, 29.91550601276869, 30.317074397111607, 30.713392844164908, 31.10466202999158, 31.491070162825526, 31.872794041313668, 32.24999999999999, 32.62284475639732, 32.99147617188415, 33.356033936905625, 33.71665018948353, 34.07345007480164, 34.4265522525855, 34.77606935810889, 35.12210842190429, 35.46477125261067, 35.80415478684003, 36.14035140947028, 36.47344924736349, 36.80353243915589, 37.13068138345969, 37.45497296755132, 37.77648077838908, 38.09527529760088, 38.41142408190563, 38.72499193027676, 39.03604103901931, 39.344631145812, 39.65081966365891, 39.9546618056016, 40.25621070095892, 40.55551750378732, 40.85263149418896, 41.147600173035606, 41.44046935062391, 41.731283229730664, 42.020084483494315, 42.30691432851136, 42.59181259350205, 42.87481778386936, 43.1559671424474, 43.43529670671078, 43.71284136269341, 43.988634895845536, 44.2627100390385, 44.53509851791057, 44.805831093731534, 45.07493760395016, 45.34244700057552, 45.608387386532314, 45.87278605011908, 46.13566949768909, 46.39706348466463, 46.65699304498737, 46.91548251910023, 47.172555580549165, 47.428235261287135, 47.682543975757, 47.935503543824375, 48.187135212627034, 48.43745967740257, 48.68649710135244, 48.93426713459598, 49.180788932265, 49.426081171786215], [0.0, 4.974937185533101, 7.035623639735144, 8.616843969807045, 9.949874371066201, 11.124297730643496, 12.186057606953943, 13.162446581088183, 14.071247279470288, 14.9248115565993, 15.732132722552274, 16.500000000000004, 17.23368793961409, 17.9373911146521, 18.61451046898629, 19.267848867997692, 19.899748742132402, 20.512191496766015, 21.106870919205434, 21.685248442201445, 22.248595461286993, 22.798026230356, 23.334523779156072, 23.858960580880304, 24.372115213907886, 24.874685927665503, 25.36730178793165, 25.850531909421132, 26.324893162176366, 26.79085664923763, 27.248853186877422, 27.69927796892908, 28.142494558940577, 28.57883832488648, 29.008619408720577, 29.432125305522874, 29.8496231131986, 30.261361502748024, 30.667572450391315, 31.068472765811975, 31.464265445104548, 31.85514087239296, 32.241277890307025, 32.62284475639732, 33.00000000000001, 33.37289319193049, 33.741665637605976, 34.10645100270622, 34.46737587922818, 34.8245602987317, 35.17811819867573, 35.52815784698104, 35.8747822293042, 36.21808940294891, 36.55817282086183, 36.89512162874654, 37.22902093797258, 37.559952076646745, 37.88799282094527, 38.21321760857099, 38.535697735995385, 38.85550154096586, 39.17269457160179, 39.48733974326455, 39.799497484264805, 40.10922587136282, 40.41658075592244, 40.721615881494685, 41.02438299353203, 41.32493194186773, 41.62331077653483, 41.91956583744636, 42.21374183841087, 42.50588194591426, 42.79602785306132, 43.08421984903522, 43.37049688440289, 43.654896632565745, 43.93745554763044, 44.218208918951035, 44.497190922573985, 44.774434669797905, 45.04997225304363, 45.32383478921439, 45.596052460712, 45.86665455426197, 46.1356694976891, 46.403124894774066, 46.669047558312144, 46.93346354148605, 47.196398167656824, 47.45787605866912, 47.71792116176061, 47.976556775158436, 48.23380557244059, 48.48968962573384, 48.74423042781577, 48.997448913183234, 49.24936547814601, 49.50000000000001, 49.749371855331006, 49.99749993749688], [0.0, 5.031152949374526, 7.115124735378853, 8.714212528966689, 10.062305898749052, 11.25, 12.323757543866238, 13.311179511974133, 14.230249470757705, 15.093458848123579, 15.909902576697318, 16.68644659596524, 17.428425057933378, 18.140079933671736, 18.8248505970167, 19.485571585149867, 20.124611797498105, 20.74397502890899, 21.345374206136558, 21.93028727582017, 22.5, 23.0556392234091, 23.59819908382841, 24.128561913218117, 24.647515087732476, 25.155764746872634, 25.653947064730605, 26.14263758690006, 26.622359023948267, 27.093587802282663, 27.55675960631075, 28.012274095474645, 28.46049894151541, 28.90177330199654, 29.336410823411917, 29.76470224947664, 30.186917696247157, 30.603308644654746, 31.014109692203, 31.41954009848012, 31.819805153394636, 32.215097392371796, 32.60559767892624, 32.99147617188415, 33.37289319193048, 33.74999999999999, 34.12293949823197, 34.491846862700754, 34.856850115866756, 35.21807064562168, 35.57562367689427, 35.929618701010455, 36.28015986734347, 36.62734634122434, 36.971272631598715, 37.31202889149825, 37.6497011940334, 37.98437178630179, 38.316119323334405, 38.64501908396475, 38.97114317029973, 39.2945606922892, 39.615337938732765, 39.9335385359224, 40.24922359499621, 40.56245184896988, 40.87327978031613, 41.181761739877025, 41.48795005781798, 41.791895147265095, 42.09364560120684, 42.39324828318773, 42.690748412273116, 42.98618964272129, 43.27961413876052, 43.57106264483344, 43.86057455164034, 44.14818795828431, 44.43393973079588, 44.71786555729153, 45.0, 45.28037654437074, 45.55902764546232, 45.83598477179256, 46.1112784468182, 46.38493828819868, 46.656993044987374, 46.92747063288197, 47.19639816765682, 47.46380199689022, 47.72970773009195, 47.99414026732846, 48.257123826436235, 48.51868196890761, 48.7788376245273, 49.03761311483257, 49.29503017546495, 49.55110997747679, 49.805873147651965, 50.05933978789572, 50.31152949374527, 50.56246137204952], [0.0, 5.086747487343952, 7.193747284969079, 8.810505093353049, 10.173494974687904, 11.374313166077327, 12.459935794377115, 13.45826883369477, 14.387494569938157, 15.260242462031854, 16.08570794214541, 16.87083281880299, 17.621010186706098, 18.34052889095623, 19.032866310674283, 19.700888304845545, 20.346989949375807, 20.973197181164345, 21.58124185490724, 22.17261824864173, 22.748626332154654, 23.310405401880082, 23.8589605808803, 24.39518395093589, 24.91987158875423, 25.43373743671976, 25.937424698685877, 26.431515280059145, 26.91653766738954, 27.392973551624515, 27.861263431510064, 28.32181138274881, 28.774989139876315, 29.22113960816724, 29.660579899927782, 30.093603971608317, 30.52048492406371, 30.941477017104404, 31.356817440550312, 31.76672787682106, 32.17141588429082, 32.571076125912704, 32.96589146375387, 33.356033936905625, 33.74166563760598, 34.12293949823198, 34.5, 34.87298381268801, 35.242020373412196, 35.60723241140766, 35.9687364248454, 36.326643114937006, 36.68105778191246, 37.03208068688553, 37.37980738313134, 37.72432901987788, 38.065732621348566, 38.40410134347633, 38.73951471043488, 39.072048832893316, 39.40177660969109, 39.72876791444708, 40.05308976845607, 40.37480650108431, 40.693979898751614, 41.01066934347695, 41.32493194186773, 41.63682264534603, 41.94639436232869, 42.25369806300982, 42.55878287733332, 42.86169618668865, 43.16248370981448, 43.461189583351256, 43.75785643744447, 44.05252546676524, 44.34523649728346, 44.63602804909953, 44.92493739561582, 45.21200061930461, 45.49725266430931, 45.78072738609556, 46.06245759835227, 46.342475117326224, 46.620810803760165, 46.89749460259045, 47.172555580549165, 47.446021961804135, 47.7179211617606, 47.98827981913917, 48.25712382643624, 48.52447835886544, 48.79036790187178, 49.0548162773035, 49.3178466683208, 49.57948164311522, 49.83974317750846, 50.09865267649421, 50.35623099478356, 50.61249845640897, 50.86747487343952, 51.121179563855925], [0.0, 5.141740950300783, 7.271519786124493, 8.90575656527844, 10.283481900601567, 11.49728228756692, 12.594641717810001, 13.60376786041279, 14.543039572248986, 15.42522285090235, 16.2596125415091, 17.05322550135311, 17.81151313055688, 18.538810641462415, 19.238633007570993, 19.913877071027628, 20.566963801203133, 21.199941037653854, 21.814559358373483, 22.412329196225905, 22.99456457513384, 23.562417108607516, 24.11690278622029, 24.6589233341604, 25.189283435620002, 25.70870475150392, 26.217837439422805, 26.717269695835316, 27.20753572082558, 27.6891224129621, 28.16247503327788, 28.62800202598847, 29.086079144497972, 29.537053001272827, 29.981244136960026, 30.418949686009867, 30.8504457018047, 31.275989192989563, 31.695819913673162, 32.110161942911475, 32.5192250830182, 32.923206101471955, 33.32228983728459, 33.71665018948353, 34.10645100270622, 34.491846862700754, 34.87298381268801, 35.25, 35.62302626111376, 35.99218665210548, 36.35759893062247, 36.71937499468095, 37.07762128292483, 37.43243914040334, 37.783925153430005, 38.13217145665849, 38.477266015141986, 38.8192928838226, 39.158332446619845, 39.49446163704476, 39.827754142055255, 40.158280590682665, 40.48610872879734, 40.81130358123837, 41.13392760240627, 41.45404081630644, 41.77170094693296, 42.086963539794596, 42.39988207530771, 42.71050807471154, 43.01889119909996, 43.32507934210854, 43.629118716746966, 43.93105393682241, 44.23092809336019, 44.52878282639219, 44.82465839245181, 45.118593728085095, 45.41062650966182, 45.70079320974637, 45.98912915026768, 46.27566855270705, 46.560444585506275, 46.843489408881574, 47.12483421721503, 47.404509279181454, 47.682543975757, 47.95896683624451, 48.23380557244058, 48.50708711106038, 48.7788376245273, 49.04908256022736, 49.3178466683208, 49.58515402819679, 49.851028073651605, 50.11549161686433, 50.378566871240004, 50.64027547318439, 50.90063850287145, 51.159676504059334, 51.41740950300784, 51.673857026546806], [0.0, 5.196152422706633, 7.3484692283495345, 9.000000000000004, 10.392304845413266, 11.618950038622252, 12.727922061357859, 13.74772708486752, 14.696938456699069, 15.588457268119898, 16.431676725154986, 17.23368793961409, 18.000000000000007, 18.7349939951952, 19.442222095223585, 20.12461179749811, 20.78460969082653, 21.424285285628553, 22.045407685048605, 22.649503305812257, 23.237900077244504, 23.811761799581323, 24.372115213907886, 24.91987158875423, 25.455844122715718, 25.980762113533164, 26.495282598983547, 27.000000000000004, 27.49545416973504, 27.98213715926645, 28.460498941515414, 28.93095228297887, 29.393876913398138, 29.849623113198604, 30.298514815086236, 30.740852297878796, 31.176914536239796, 31.606961258558222, 32.031234756093944, 32.44996147917591, 32.86335345030997, 33.27160951922826, 33.67491648096548, 34.07345007480164, 34.46737587922818, 34.856850115866756, 35.242020373412196, 35.62302626111376, 36.000000000000014, 36.373066958946424, 36.74234614174768, 37.10795063055895, 37.4699879903904, 37.82856063875548, 38.183766184073576, 38.5356977359954, 38.88444419044717, 39.230090491866065, 39.57271787481877, 39.91240408695022, 40.24922359499622, 40.58324777540605, 40.914545090957574, 41.24318125460256, 41.56921938165306, 41.89272013130683, 42.21374183841087, 42.53234063627348, 42.848570571257106, 43.16248370981448, 43.47413023856832, 43.783558557979276, 44.09081537009721, 44.39594576084623, 44.698993277254026, 45.00000000000001, 45.29900661162451, 45.596052460711995, 45.891175622335076, 46.18441295502197, 46.47580015448901, 46.765371804359695, 47.05316142407438, 47.339201514178505, 47.623523599162645, 47.90615826801395, 48.18713521262704, 48.466483264210545, 48.74423042781577, 49.02040391510458, 49.29503017546496, 49.568134925574924, 49.83974317750846, 50.109879265470205, 50.378566871240004, 50.6458290484024, 50.911688245431435, 51.17616632769595, 51.43928459844675, 51.70106381884227, 51.96152422706633, 52.22068555658764], [0.0, 5.25, 7.424621202458749, 9.093266739736608, 10.5, 11.739356881873896, 12.859821149611687, 13.8901943830891, 14.849242404917497, 15.75, 16.60195771588399, 17.41228014936585, 18.186533479473216, 18.929144196185945, 19.643701280563192, 20.333162567588936, 21.0, 21.646304534492717, 22.27386360737625, 22.88421945358854, 23.47871376374779, 24.058522398518164, 24.624682739073005, 25.17811549739178, 25.719642299223374, 26.250000000000004, 26.769852446362123, 27.279800219209818, 27.7803887661782, 28.27211523745615, 28.75543426902122, 29.230762904857613, 29.698484809834994, 30.15895389432465, 30.612497447937827, 31.05941886127298, 31.5, 31.934503284065652, 32.36317351558713, 32.786239491591594, 33.20391543176798, 33.61640224652246, 34.02388866664127, 34.4265522525855, 34.8245602987317, 35.21807064562169, 35.60723241140766, 35.99218665210548, 36.37306695894643, 36.75, 37.12310601229375, 37.49249924984996, 37.85828839237189, 38.22057691872272, 38.57946344883506, 38.93504205725223, 39.287402561126385, 39.636630785171434, 39.982808805785524, 40.32601517631019, 40.66632513517787, 41.00381079850994, 41.33854133856201, 41.6705831492673, 42.0, 42.32685317856738, 42.65120162433879, 42.97310205233036, 43.292609068985435, 43.609775280319894, 43.924651393038964, 44.23728630917588, 44.5477272147525, 44.856019662917035, 45.16220765197379, 45.46633369868303, 45.76843890717708, 46.06856303380864, 46.366744548221206, 46.66302069090685, 46.95742752749558, 47.25, 47.540771975221446, 47.829776290507574, 48.11704479703633, 48.40260840078766, 48.686497101352444, 48.96874002871628, 49.24936547814601, 49.52840094329717, 49.80587314765197, 50.08180807438964, 50.35623099478356, 50.62916649521302, 50.90063850287146, 51.170670310247054, 51.43928459844675, 51.706503459429555, 51.97234841721124, 52.23684044809755, 52.50000000000001, 52.76184701088468], [0.0, 5.303300858899107, 7.5, 9.18558653543692, 10.606601717798213, 11.858541225631424, 12.990381056766582, 14.031215200402281, 15.0, 15.90990257669732, 16.770509831248425, 17.589059099337863, 18.37117307087384, 19.121323175972947, 19.843134832984433, 20.53959590644373, 21.213203435596427, 21.866069605669875, 22.500000000000004, 23.116552511133666, 23.717082451262847, 24.30277761902948, 24.8746859276655, 25.43373743671976, 25.980762113533164, 26.516504294495537, 27.041634565979923, 27.556759606310756, 28.062430400804562, 28.559149146989657, 29.047375096555626, 29.527529527544292, 30.0, 30.465144017384855, 30.923292192132454, 31.37475099502783, 31.81980515339464, 32.25871975140985, 32.69174207655506, 33.11910324872943, 33.54101966249685, 33.95769426801532, 34.36931771216881, 34.77606935810889, 35.178118198675726, 35.57562367689427, 35.968736424845396, 36.35759893062247, 36.74234614174768, 37.123106012293746, 37.50000000000001, 37.873143518857795, 38.24264635194589, 38.60861302870126, 38.97114317029975, 39.33033180638069, 39.686269665968865, 40.03904344511742, 40.38873605350879, 40.73542684200081, 41.07919181288746, 41.42010381445223, 41.75823272122517, 42.09364560120684, 42.42640687119285, 42.75657844121768, 43.084219849035215, 43.409388385463345, 43.73213921133975, 44.05252546676524, 44.37059837324712, 44.686407329298696, 45.00000000000001, 45.311422400979644, 45.62071897723665, 45.92793267718459, 46.23310502226733, 46.53627617246571, 46.837484987988, 47.13676908741201, 47.434164902525694, 47.72970773009196, 48.02343178074637, 48.315370225219226, 48.60555523805896, 48.89401803901987, 49.18078893226501, 49.46589734352345, 49.749371855331, 50.03124024047376, 50.31152949374527, 50.590265862120155, 50.86747487343952, 51.14318136369697, 51.41740950300784, 51.69018282033833, 51.96152422706633, 52.23145603944045, 52.5, 52.76717729801359, 53.03300858899107, 53.29751401331961], [0.0, 5.356071321407138, 7.574628703771559, 9.276987657639738, 10.712142642814277, 11.976539567003485, 13.11964176340193, 14.17083272076839, 15.149257407543118, 16.068213964221414, 16.937384685954324, 17.76407892349052, 18.553975315279477, 19.311589784375602, 20.040583823831085, 20.743975028908995, 21.424285285628553, 22.083647796503186, 22.72388611131468, 23.346573624410077, 23.95307913400697, 24.544602257930364, 25.122201336666343, 25.68681568431557, 26.23928352680386, 26.780356607035692, 27.31071218404969, 27.830962972919213, 28.34166544153678, 28.843326784544118, 29.33641082341192, 29.821343028106565, 30.298514815086236, 30.768287245149025, 31.230994220485524, 31.68694526141641, 32.13642792844283, 32.57970994346021, 33.01704105458271, 33.44865468146664, 33.87476937190865, 34.295590095521035, 34.71130939621841, 35.12210842190429, 35.52815784698104, 35.929618701010455, 36.326643114937006, 36.71937499468095, 37.10795063055895, 37.49249924984996, 37.8731435188578, 38.25000000000001, 38.623179568751205, 38.992787794667876, 39.35892529020579, 39.72168803059609, 40.08116764766217, 40.43745170012572, 40.79062392266145, 41.14076445570743, 41.48795005781799, 41.832254302153025, 42.17374775852865, 42.512498162305164, 42.848570571257106, 43.18202751145435, 43.512929113080865, 43.84133323702645, 44.16729559300637, 44.49086984989168, 44.812107738868974, 45.13105914999115, 45.44777222262936, 45.762293430290406, 46.074667660223014, 46.38493828819868, 46.69314724882015, 46.9993351016799, 47.30354109366445, 47.60580321767506, 47.90615826801394, 48.20464189266425, 48.50128864267424, 48.79613201883937, 49.08920451586073, 49.380537664144576, 49.67016206939535, 49.95810745014267, 50.24440267333269, 50.52907578810442, 50.81215405786297, 51.0936639907533, 51.37363136863114, 51.65208127462049, 51.92903811934129, 52.20452566588456, 52.47856705360772, 52.751184820817066, 53.02240092640091, 53.29223677047156, 53.560713214071384, 53.82785059799435], [0.0, 5.408326913195984, 7.648529270389177, 9.3674969975976, 10.816653826391969, 12.093386622447825, 13.247641299491773, 14.309088021254185, 15.297058540778353, 16.224980739587952, 17.10263137648707, 17.937391114652097, 18.7349939951952, 19.500000000000004, 20.236106344848064, 20.946360065653412, 21.633307652783937, 22.299103120977758, 22.945587811167535, 23.57435046825257, 24.18677324489565, 24.784067462787466, 25.367301787931645, 25.937424698685877, 26.495282598983547, 27.041634565979923, 27.577164466275356, 28.102490992792795, 28.61817604250837, 29.1247317584214, 29.62262648719725, 30.112289849827096, 30.594117081556707, 31.068472765811972, 31.535694062442957, 31.996093511552314, 32.449961479175904, 32.89756829919197, 33.33916615633931, 33.774990747593115, 34.20526275297414, 34.63018914184559, 35.049964336643775, 35.46477125261067, 35.874782229304195, 36.28015986734347, 36.68105778191245, 37.07762128292483, 37.4699879903904, 37.85828839237189, 38.24264635194589, 38.623179568751205, 39.00000000000001, 39.37321424522006, 39.74292389847532, 40.109225871362824, 40.47221268969613, 40.8319727664486, 41.18859065323795, 41.54214727237869, 41.892720131306824, 42.24038352098617, 42.585208699735176, 42.92726406376256, 43.266615305567875, 43.6033255612459, 43.93745554763043, 44.269063690121115, 44.598206241955516, 44.924937395615814, 45.24930938699507, 45.57137259288994, 45.89117562233507, 46.20876540224809, 46.52418725781247, 46.83748498798799, 47.14870093650514, 47.45787605866912, 47.76504998427198, 48.070261076886204, 48.3735464897913, 48.67494221876386, 48.97448315194353, 49.27220311697053, 49.56813492557493, 49.86231041578399, 50.15476049190147, 50.44551516240072, 50.73460357586329, 51.02205405508485, 51.30789412946121, 51.59215056575952, 51.874849397371754, 52.15601595214114, 52.43567487884561, 52.713850172416734, 52.99056519796709, 53.26584271369412, 53.539704892724245, 53.812173343956296, 54.083269131959845, 54.35301279598032], [0.0, 5.46008241696039, 7.721722605740251, 9.457140159688871, 10.92016483392078, 12.209115447074781, 13.37441587509526, 14.446020213193668, 15.443445211480501, 16.38024725088117, 17.266296649832007, 18.109044701474456, 18.914280319377742, 19.686607122610035, 20.429757707814357, 21.146808269807526, 21.84032966784156, 22.51249652970545, 23.165167817220755, 23.799947478933653, 24.418230894149563, 25.021240976418422, 25.610056618445814, 26.18563537514414, 26.74883175019052, 27.30041208480195, 27.841066789905884, 28.37142047906661, 28.892040426387336, 29.403443675868992, 29.90610305606533, 30.400452299266867, 30.886890422961002, 31.365785499489732, 31.83747791518669, 32.30228320103704, 32.76049450176234, 33.212384738226795, 33.65820850847532, 34.09820376500792, 34.532593299664015, 34.961586062420004, 35.38537833625636, 35.80415478684004, 36.21808940294891, 36.62734634122434, 37.03208068688553, 37.432439140403346, 37.828560638755484, 38.22057691872272, 38.608613028701264, 38.99278779466788, 39.37321424522007, 39.75000000000001, 40.12324762528578, 40.49305496007928, 40.859515415628714, 41.22271825098389, 41.58274882688735, 41.939688840047445, 42.29361653961505, 42.6446069274885, 42.99273194389955, 43.338060639581, 43.68065933568312, 44.02059177248757, 44.357919247863734, 44.69270074631874, 45.0249930594109, 45.354850898222566, 45.68232699852319, 46.00747221919501, 46.33033563444151, 46.65096462025196, 46.969404935553534, 47.285700798444346, 47.599894957867306, 47.91202876105332, 48.22214221703554, 48.53027405651034, 48.836461788299125, 49.14074175264351, 49.44314917154854, 49.7437181963713, 50.042481952836845, 50.33947258364951, 50.634721288854756, 50.92825836409489, 51.22011323689163, 51.510314501078334, 51.79888994949603, 52.085866605058996, 52.37127075028828, 52.65512795540432, 52.9374631050639, 53.218300423820374, 53.49766350038104, 53.77557531073007, 54.05205824018176, 54.32713410442337, 54.6008241696039, 54.87314917152105], [0.0, 5.511351921262151, 7.794228634059947, 9.545941546018394, 11.022703842524303, 12.323757543866238, 13.500000000000002, 14.581666571417685, 15.588457268119894, 16.53405576378645, 17.428425057933378, 18.279086410430914, 19.091883092036788, 19.87146194923766, 20.62159062730128, 21.345374206136558, 22.045407685048605, 22.723886111314673, 23.382685902179844, 24.023426067070456, 24.647515087732476, 25.25618736072411, 25.85053190942113, 26.43151528005915, 27.000000000000004, 27.556759606310756, 28.102490992792795, 28.637824638055175, 29.16333314283537, 29.67953840611407, 30.186917696247157, 30.685908818218174, 31.17691453623979, 31.66030637880815, 32.13642792844283, 32.60559767892624, 33.0681115275729, 33.52424495794052, 33.974254958718376, 34.418381716751306, 34.856850115866756, 35.28987106805578, 35.71764269937198, 36.14035140947028, 36.55817282086183, 36.97127263159871, 37.379807383131336, 37.78392515343, 38.183766184073576, 38.57946344883506, 38.97114317029975, 39.35892529020578, 39.74292389847532, 40.12324762528577, 40.50000000000001, 40.873279780316146, 41.24318125460256, 41.609794520040595, 41.97320573889967, 42.33349737501025, 42.690748412273116, 43.04503455684523, 43.3964284244683, 43.744999714253055, 44.09081537009721, 44.43393973079588, 44.7744346697979, 45.1123597254677, 45.44777222262935, 45.78072738609556, 46.11127844681819, 46.43947674123816, 46.76537180435969, 47.089011457026785, 47.41044188783733, 47.72970773009196, 48.04685213414091, 48.361916835460526, 48.67494221876387, 48.9859673784238, 49.29503017546495, 49.60216729135936, 49.90741427884239, 50.210805609948146, 50.51237472144822, 50.81215405786297, 51.11017511220247, 51.40646846458139, 51.70106381884226, 51.99399003731104, 52.28527517380013, 52.57494650496565, 52.8630305601183, 53.14955314957973, 53.43453939167063, 53.718013738409944, 54.00000000000001, 54.280521368166696, 54.559600438419636, 54.83725923129274, 55.11351921262151, 55.388401312910275], [0.0, 5.562148865321747, 7.866066361276136, 9.633924433998848, 11.124297730643494, 12.43734296383275, 13.624426593438715, 14.716062652761437, 15.732132722552272, 16.686446595965243, 17.589059099337863, 18.447560814373265, 19.267848867997696, 20.05461293568141, 20.811655388267415, 21.542109924517607, 22.24859546128699, 22.93332727713098, 23.598199083828412, 24.244844812866926, 24.8746859276655, 25.488968201949646, 26.08879069638913, 26.675128865668114, 27.24885318687743, 27.810744326608738, 28.36150560178356, 28.901773301996542, 29.432125305522874, 29.953088321573787, 30.465144017384848, 30.968734233093866, 31.464265445104544, 31.95211260621119, 32.43262246565948, 32.906116452720454, 33.37289319193049, 33.83323070591988, 34.28738835198739, 34.735608530728236, 35.178118198675726, 35.6151302117513, 36.04684452209376, 36.47344924736348, 36.89512162874653, 37.312028891498244, 37.72432901987788, 38.13217145665848, 38.53569773599539, 38.93504205725223, 39.33033180638069, 39.721688030596084, 40.10922587136282, 40.49305496007927, 40.873279780316146, 41.25000000000001, 41.62331077653483, 41.993303037508255, 42.36006373932882, 42.72367610587835, 43.084219849035215, 43.44177137272374, 43.7964039619693, 44.14818795828431, 44.49719092257398, 44.843477786630245, 45.1871109941762, 45.52815063232856, 45.86665455426196, 46.20267849378432, 46.53627617246571, 46.867499399903984, 47.196398167656824, 47.52302073732267, 47.84741372320975, 48.169622169994234, 48.48968962573385, 48.80765821057183, 49.12356868143846, 49.437460493031, 49.749371855331, 50.05933978789573, 50.36740017114246, 50.67358779482661, 50.97793640389929, 51.28047874191504, 51.581246592148204, 51.880270816563794, 52.17758139277826, 52.473207449135415, 52.767177298013586, 53.059518467471975, 53.35025773133623, 53.63942113781618, 53.927034036742654, 54.213121105503596, 54.49770637375486, 54.78081324697545, 55.062464528932956, 55.3426824431198, 55.621488653217476, 55.898904282642256], [0.0, 5.612486080160912, 7.937253933193771, 9.721111047611792, 11.224972160321824, 12.549900398011133, 13.74772708486752, 14.849242404917497, 15.874507866387543, 16.837458240482736, 17.74823934929885, 18.614510468986285, 19.442222095223585, 20.236106344848064, 21.0, 21.737065119284154, 22.44994432064365, 23.140872930812268, 23.811761799581316, 24.464259645450138, 25.099800796022265, 25.719642299223374, 26.324893162176366, 26.916537667389544, 27.49545416973504, 28.062430400804562, 28.61817604250837, 29.16333314283537, 29.698484809834994, 30.224162519414826, 30.740852297878792, 31.248999983999486, 31.749015732775085, 32.24127789030702, 32.72613634390714, 33.20391543176798, 33.67491648096547, 34.13942003022313, 34.59768778401239, 35.04996433664377, 35.4964786985977, 35.93744565213282, 36.373066958946424, 36.80353243915589, 37.22902093797257, 37.6497011940334, 38.06573262134856, 38.47726601514198, 38.88444419044717, 39.287402561126385, 39.686269665968865, 40.08116764766216, 40.47221268969613, 40.85951541562871, 41.24318125460256, 41.62331077653483, 42.0, 42.3733406754766, 42.74342054632503, 43.110323589599744, 43.47413023856831, 43.83491758860737, 44.19275958796871, 44.54772721475249, 44.8998886412873, 45.249309386995066, 45.59605246071199, 45.94017849334066, 46.281745861624536, 46.62081080376016, 46.95742752749558, 47.291648311303334, 47.62352359916263, 47.95310208943734, 48.28043081829324, 48.60555523805895, 48.928519290900276, 49.24936547814601, 49.568134925574924, 49.88486744494767, 50.19960159204453, 50.51237472144821, 50.823223038292255, 51.13218164717794, 51.43928459844675, 51.744564931981024, 52.04805471869242, 52.34978509984545, 52.64978632435273, 52.94808778416837, 53.24471804789654, 53.53970489272424, 53.83307533477909, 54.12485565800615, 54.415071441651165, 54.7037475864314, 54.99090833947008, 55.276577318064845, 55.5607775323564, 55.84353140695886, 56.124860801609124, 56.4047870308895], [0.0, 5.662375826453062, 8.007808689023483, 9.807522622966518, 11.324751652906125, 12.6614572621006, 13.8699315066802, 14.981238266578634, 16.015617378046965, 16.987127479359188, 17.906004579469982, 18.779976038323372, 19.615045245933036, 20.4159863832243, 21.186670337738303, 21.930287275820167, 22.64950330581225, 23.34657362441007, 24.023426067070453, 24.681724007856506, 25.3229145242012, 25.948265838009295, 26.55889681443866, 27.155800485347513, 27.7398630133604, 28.311879132265314, 28.872564832380238, 29.42256786889955, 29.962476533157268, 30.492827025384184, 31.014109692202997, 31.52677433547555, 32.03123475609393, 32.52787266330216, 33.017041054582705, 33.49906715119094, 33.974254958718376, 34.442887509615105, 34.90522883466029, 35.361525702378856, 35.812009158939965, 36.25689589581547, 36.696389468175205, 37.13068138345969, 37.559952076646745, 37.98437178630179, 38.40410134347632, 38.8192928838226, 39.23009049186607, 39.636630785171434, 40.03904344511742, 40.43745170012572, 40.8319727664486, 41.22271825098389, 41.609794520040595, 41.99330303750826, 42.373340675476605, 42.75, 43.12336953439516, 43.49353400219393, 43.86057455164033, 44.2245689634167, 44.58559184310555, 44.9437147997359, 45.2990066116245, 45.6515333805996, 46.001358675586964, 46.348543666441124, 46.69314724882014, 47.03522616082546, 47.37483509206127, 47.71202678570677, 48.046852134140906, 48.37936026861041, 48.70959864338855, 49.037613114832574, 49.36344801571301, 49.68714622515566, 50.00874923450896, 50.32829720942286, 50.6458290484024, 50.961382438077564, 51.27499390541164, 51.58669886705293, 51.89653167601859, 52.20452566588457, 52.51071319264289, 52.81512567437476, 53.11779362887732, 53.41874670937161, 53.71801373840995, 54.01562274009252, 54.311600970695025, 54.60597494780219, 54.8987704780353, 55.190012683455684, 55.4797260267208, 55.76793433506391, 56.05466082316438, 56.33992811497012, 56.62375826453063, 56.90617277589489], [0.0, 5.7118298293979315, 8.077747210701755, 9.893179468704691, 11.423659658795863, 12.772039774444803, 13.991068579633225, 15.112081259707413, 16.15549442140351, 17.135489488193794, 18.062391868188445, 18.943996410472636, 19.786358937409382, 20.594295326618976, 21.371710273162513, 22.121821805628937, 22.847319317591726, 23.550477702161373, 24.23324163210527, 24.897289009046755, 25.544079548889606, 26.174892549922728, 26.79085664923763, 27.392973551624515, 27.98213715926645, 28.55914914698966, 29.1247317584214, 29.67953840611407, 30.224162519414826, 30.75914498161482, 31.284980421921315, 31.802122570671287, 32.31098884280702, 32.81196428134104, 33.30540496676178, 33.79164097820643, 34.27097897638759, 34.74370446570141, 35.21008378291651, 35.67036585178235, 36.12478373637689, 36.57355602070983, 37.0168880377592, 37.45497296755132, 37.88799282094527, 38.316119323334405, 38.739514710434875, 39.15833244661984, 39.572717874818764, 39.98280880578552, 40.38873605350879, 40.79062392266145, 41.18859065323795, 41.58274882688734, 41.97320573889967, 42.36006373932882, 42.74342054632503, 43.12336953439515, 43.50000000000001, 43.873397406629, 44.24364361125787, 44.61081707388916, 44.97499305169485, 45.33624377912224, 45.69463863518345, 46.050244299026254, 46.40312489477406, 46.7533421265261, 47.10095540432275, 47.446021961804135, 47.788596966221974, 48.12873362140334, 48.46648326421054, 48.80189545499232, 49.135018062477606, 49.46589734352345, 49.79457801809351, 50.121103339810865, 50.445515162400724, 50.76785400231135, 51.08815909777921, 51.40646846458139, 51.72281894870001, 52.03724627610497, 52.349785099845455, 52.660469044625884, 52.96933074902873, 53.27640190553413, 53.58171329847526, 53.88529484005818, 54.18717560456533, 54.48738386085351, 54.78594710324903, 55.08289208093563, 55.378244825924206, 55.6720306796869, 55.9642743185329, 56.254999777797536, 56.5442304749123, 56.83198923141791, 57.11829829397932, 57.40317935445737], [0.0, 5.760859310901456, 8.14708536840016, 9.978101021737555, 11.521718621802911, 12.881673027988251, 14.111165791670086, 15.24180107467618, 16.29417073680032, 17.282577932704367, 18.21743670223668, 19.106608804285496, 19.95620204347511, 20.771073636189346, 21.555161794799872, 22.311712170965272, 23.043437243605823, 23.75263143316967, 24.441256105200484, 25.111003564174812, 25.763346055976502, 26.399573860197062, 27.02082530197773, 27.628110684590794, 28.22233158334017, 28.80429655450728, 29.37473404134921, 29.93430306521266, 30.48360214935236, 31.02317681991965, 31.55352595194394, 32.07510717051464, 32.58834147360064, 33.09361720936531, 33.591293514838036, 34.08170330250529, 34.565155865408734, 35.041939158671, 35.51232180525515, 35.97655486563437, 36.43487340447336, 36.887497882073816, 37.33463539396093, 37.77648077838908, 38.21321760857099, 38.64501908396475, 39.072048832893316, 39.49446163704476, 39.91240408695022, 40.326015176310186, 40.73542684200081, 41.14076445570743, 41.54214727237869, 41.93968884004744, 42.33349737501025, 42.72367610587835, 43.110323589599744, 43.49353400219393, 43.873397406629, 44.25, 44.623424341930544, 44.993749565911926, 45.36105157511232, 45.72540322402854, 46.086874487211645, 46.445532616173104, 46.80144228546808, 47.15466572885444, 47.50526286633934, 47.85329142284781, 48.19880703917888, 48.54186337585321, 48.88251221040097, 49.22080352858941, 49.55678561004537, 49.89050510868776, 50.222007128349624, 50.551335293936596, 50.878531818439896, 51.203637566094855, 51.526692111953004, 51.847733798113104, 52.16679978683761, 52.48392611076271, 52.799147720394124, 53.11249852906564, 53.42401145552438, 53.73371846429391, 54.04165060395546, 54.34783804347694, 54.65231010671003, 54.955095305167106, 55.25622136918159, 55.55571527754818, 55.8536032857326, 56.149910952734366, 56.44466316668034, 56.737884169221545, 57.02959757880113, 57.319826412856486, 57.60859310901456, 57.895919545335836], [0.0, 5.809475019311125, 8.21583836257749, 10.062305898749054, 11.61895003862225, 12.990381056766578, 14.230249470757707, 15.370426148939396, 16.43167672515498, 17.428425057933374, 18.371173070873834, 19.267848867997692, 20.12461179749811, 20.946360065653412, 21.737065119284157, 22.499999999999996, 23.2379000772445, 23.953079134006963, 24.647515087732476, 25.3229145242012, 25.980762113533157, 26.622359023948274, 27.248853186877422, 27.861263431510064, 28.460498941515414, 29.047375096555626, 29.62262648719725, 30.18691769624716, 30.740852297878792, 31.284980421921315, 31.819805153394633, 32.34578797927173, 32.86335345030996, 33.37289319193048, 33.87476937190864, 34.369317712168794, 34.85685011586675, 35.337656968169235, 35.812009158939965, 36.28015986734347, 36.74234614174767, 37.19879030291173, 37.649701194033405, 38.09527529760088, 38.535697735995385, 38.97114317029973, 39.40177660969108, 39.827754142055255, 40.24922359499622, 40.66632513517787, 41.07919181288746, 41.487950057818, 41.892720131306824, 42.29361653961505, 42.69074841227312, 43.084219849035215, 43.474130238568314, 43.86057455164033, 44.24364361125788, 44.623424341930544, 44.99999999999999, 45.373450386762514, 45.743852045930716, 46.11127844681818, 46.475800154489, 46.837484987987985, 47.19639816765681, 47.552602452442066, 47.906158268013925, 48.257123826436235, 48.60555523805895, 48.951506616242156, 49.29503017546495, 49.636176323322886, 49.97499374687304, 50.31152949374526, 50.6458290484024, 50.97793640389928, 51.30789412946121, 51.63574343417552, 51.96152422706631, 52.28527517380012, 52.60703375025055, 52.92683629313205, 53.24471804789655, 53.56071321407138, 53.874854988203914, 54.187175604565326, 54.497706373754845, 54.80647771933533, 55.113519212621505, 55.41885960573349, 55.72252686302013, 56.0245481909493, 56.324950066555765, 56.62375826453061, 56.92099788303083, 57.21669336828195, 57.51086853804244, 57.803546603993084, 58.09475019311125, 58.38450136808569], [0.0, 5.8576872569299905, 8.284020762890444, 10.145811943851514, 11.715374513859981, 13.098186897429736, 14.348344852281745, 15.497983739828868, 16.568041525780888, 17.573061770789973, 18.523633552842703, 19.427750770482927, 20.29162388770303, 21.120191760493086, 21.917458794303688, 22.686725193381257, 23.430749027719962, 24.151863282156924, 24.852062288671338, 25.533066795823807, 26.196373794859472, 26.843295252259924, 27.474988626021304, 28.092481200492067, 28.69668970456349, 29.288436284649958, 29.86846162760982, 30.437435831554538, 30.995967479657736, 31.544611267219636, 32.08387445431115, 32.61422235773835, 33.136083051561776, 33.649851411261835, 34.1558926102071, 34.65454515644376, 35.14612354157995, 35.630920560659106, 36.109209351632174, 36.5812451947716, 37.04726710568541, 37.50749925014997, 37.96215220453129, 38.41142408190563, 38.855501540965854, 39.2945606922892, 39.72876791444708, 40.158280590682665, 40.58324777540606, 41.00381079850993, 41.42010381445223, 41.832254302153025, 42.24038352098617, 42.644606927488496, 43.04503455684523, 43.44177137272375, 43.834917588607375, 44.2245689634167, 44.61081707388916, 44.993749565911926, 45.373450386762514, 45.75, 46.12347558456539, 46.493951219486604, 46.861498055439924, 47.2261844742935, 47.588076237645915, 47.947236625273824, 48.30372656431385, 48.65760474992578, 49.00892775811362, 49.35775015131868, 49.704124577342675, 50.048101862108616, 50.38973109672247, 50.72905971925756, 51.06613359164761, 51.400997072041314, 51.73369308294161, 52.064263175425815, 52.392747589718944, 52.719185312369916, 53.04361413026078, 53.366070681660645, 53.68659050451985, 54.005208082184076, 54.32195688669546, 54.63686941983408, 54.94997725204261, 55.26131105936594, 55.57090065852811, 55.87877504026014, 56.18496240098413, 56.48949017295165, 56.792385052927656, 57.09367302950476, 57.39337940912698, 57.69152884089657, 57.98814534023312, 58.28325231144879, 58.576872569299915, 58.86902835957122], [0.0, 5.905505905508858, 8.351646544245032, 10.228636272739394, 11.811011811017716, 13.205112646244256, 14.465476141489434, 15.624499991999743, 16.703293088490064, 17.716517716526575, 18.6748493969831, 19.586347285800894, 20.457272545478787, 21.292604349867585, 22.096379793984354, 22.871926022965354, 23.62202362203543, 24.349024621121888, 25.0549396327351, 25.741503452595772, 26.410225292488512, 27.062427829003074, 27.69927796892908, 28.32181138274881, 28.93095228297887, 29.527529527544292, 30.112289849827096, 30.685908818218174, 31.248999983999486, 31.802122570671283, 32.34578797927173, 32.880465325174455, 33.40658617698013, 33.92454863369592, 34.43472084974699, 34.93744409655634, 35.43303543305315, 35.92179004448414, 36.40398329853479, 36.87987255943274, 37.3496987939662, 37.813687997866595, 38.27205246651923, 38.72499193027675, 39.17269457160179, 39.615337938732765, 40.05308976845606, 40.48610872879733, 40.914545090957574, 41.338541338562, 41.75823272122517, 42.17374775852865, 42.58520869973517, 42.992731943899535, 43.3964284244683, 43.796403961969304, 44.19275958796871, 44.58559184310555, 44.97499305169485, 45.36105157511232, 45.74385204593071, 46.12347558456539, 46.5, 46.87349997599922, 47.24404724407086, 47.61171074431163, 47.97655677515842, 48.33864913296605, 48.698049242243776, 49.054816277303495, 49.40900727600181, 49.76067724619511, 50.1098792654702, 50.456664574662476, 50.80108266562829, 51.143181363696954, 51.483006905191544, 51.82060401037409, 52.15601595214114, 52.489284620768075, 52.820450584977024, 53.149553149579724, 53.476630409927665, 53.80171930338286, 54.12485565800615, 54.446074238644606, 54.76540879058605, 55.08289208093562, 55.39855593785816, 55.71243128781941, 56.02454819094929, 56.33493587464176, 56.64362276549762, 56.950636519708894, 57.256004051976944, 57.559751563049666, 57.86190456595774, 58.162487911023895, 58.461525809715226, 58.75904185740268, 59.055059055088584, 59.34959983015892], [0.0, 5.952940449895329, 8.418729120241368, 10.310795313650642, 11.905880899790658, 13.311179511974137, 14.581666571417687, 15.75, 16.837458240482736, 17.858821349685986, 18.8248505970167, 19.743669871632274, 20.621590627301284, 21.46363203188128, 22.27386360737625, 23.055639223409095, 23.811761799581316, 24.544602257930357, 25.256187360724105, 25.948265838009295, 26.622359023948274, 27.27980021920982, 27.921765703479426, 28.549299466011423, 29.163333142835373, 29.76470224947665, 30.354159517272095, 30.93238594095192, 31.5, 32.057565409743766, 32.60559767892623, 33.144569690976525, 33.67491648096547, 34.197039345533994, 34.711309396218404, 35.21807064562169, 35.71764269937197, 36.21032311371993, 36.696389468175205, 37.17610119418119, 37.6497011940334, 38.117417278719195, 38.579463448835064, 39.03604103901931, 39.48733974326455, 39.93353853592241, 40.37480650108431, 40.81130358123837, 41.24318125460257, 41.6705831492673, 42.093645601206845, 42.51249816230517, 42.92726406376256, 43.338060639581, 43.74499971425306, 44.14818795828432, 44.5477272147525, 44.9437147997359, 45.33624377912225, 45.72540322402855, 46.11127844681819, 46.493951219486604, 46.87349997599923, 47.25, 47.62352359916263, 47.99414026732847, 48.36191683546052, 48.726917612342355, 49.089204515860715, 49.4488371956308, 49.80587314765197, 50.160367821617896, 50.51237472144821, 50.86194549955792, 51.20913004533469, 51.5539765682532, 51.89653167601859, 52.236840448097546, 52.57494650496566, 52.91089207337182, 53.24471804789655, 53.57646404905796, 53.906168478199234, 54.233868569372774, 54.55960043841964, 54.88339912942711, 55.20529865873384, 55.5253320566388, 55.84353140695885, 56.159927884569086, 56.474551791050104, 56.78743258855783, 57.098598932022846, 57.40807869977884, 57.715899022712975, 58.022086312024314, 58.32666628567075, 58.62966399357923, 58.93110384168958, 59.23100961489683, 59.5294044989533, 59.826311101387496], [0.0, 6.0, 8.48528137423857, 10.392304845413266, 12.0, 13.416407864998739, 14.69693845669907, 15.874507866387543, 16.97056274847714, 18.0, 18.973665961010276, 19.8997487421324, 20.78460969082653, 21.633307652783937, 22.44994432064365, 23.2379000772445, 24.0, 24.73863375370596, 25.455844122715714, 26.153393661244046, 26.832815729997478, 27.495454169735044, 28.142494558940577, 28.774989139876322, 29.39387691339814, 30.000000000000004, 30.59411708155671, 31.176914536239792, 31.749015732775085, 32.31098884280703, 32.863353450309965, 33.40658617698013, 33.94112549695428, 34.46737587922817, 34.9857113690718, 35.49647869859769, 36.0, 36.49657518178932, 36.986484017813865, 37.46998799039039, 37.94733192202055, 38.4187454245971, 38.88444419044717, 39.344631145812, 39.7994974842648, 40.24922359499621, 40.69397989875161, 41.13392760240627, 41.56921938165306, 42.0, 42.42640687119286, 42.848570571257106, 43.266615305567875, 43.68065933568311, 44.09081537009721, 44.497190922573985, 44.8998886412873, 45.2990066116245, 45.69463863518346, 46.08687448721165, 46.475800154489, 46.861498055439924, 47.24404724407087, 47.62352359916263, 48.0, 48.3735464897913, 48.74423042781576, 49.1121166312347, 49.47726750741192, 49.839743177508446, 50.19960159204453, 50.556898639058154, 50.91168824543143, 51.264022471905186, 51.61395160225576, 51.96152422706632, 52.30678732248809, 52.64978632435273, 52.99056519796709, 53.32916650389354, 53.665631459994955, 54.00000000000001, 54.33231082882451, 54.662601474865795, 54.99090833947009, 55.31726674375733, 55.641710972974224, 55.964274318532894, 56.28498911788115, 56.60388679233962, 56.92099788303083, 57.23635208501674, 57.549978279752644, 57.86190456595774, 58.17215828899595, 58.480766068853775, 58.78775382679628, 59.09314681077664, 59.39696961966999, 59.69924622639721, 60.00000000000001, 60.29925372672535], [0.0, 6.046693311223912, 8.551315688243534, 10.473180032826708, 12.093386622447824, 13.52081728298996, 14.811313243598624, 15.998046755776155, 17.102631376487068, 18.140079933671736, 19.121323175972943, 20.054612935681405, 20.946360065653415, 21.80166278062295, 22.624654693497533, 23.41874249399399, 24.186773244895647, 24.93115520789199, 25.653947064730605, 26.35692508620837, 27.04163456597992, 27.70942980286675, 28.361505601783552, 28.998922393771807, 29.62262648719725, 30.233466556119563, 30.8322071866417, 31.419540098480116, 31.99609351155231, 32.56244001913861, 33.11910324872942, 33.66656353119516, 34.205262752974136, 34.73560853072823, 35.25797782062947, 35.77272005313546, 36.28015986734347, 36.78059950571768, 37.27432091936753, 37.76158762552232, 38.242646351945886, 38.71772849742092, 39.1870514328394, 39.65081966365891, 40.10922587136281, 40.56245184896987, 41.01066934347694, 41.45404081630643, 41.89272013130683, 42.32685317856738, 42.75657844121768, 43.18202751145435, 43.6033255612459, 44.02059177248756, 44.43393973079588, 44.843477786630245, 45.249309386995066, 45.6515333805996, 46.050244299026254, 46.445532616173104, 46.83748498798798, 47.22618447429349, 47.61171074431163, 47.99414026732846, 48.373546489791295, 48.75, 49.123568681438435, 49.494317855689246, 49.86231041578398, 50.22760695075966, 50.59026586212015, 50.950343472836366, 51.30789412946121, 51.66297029788357, 52.0156226531991, 52.36590016413353, 52.71385017241674, 53.059518467471975, 53.4029493567537, 53.74418573203989, 54.08326913195984, 54.42023980101521, 54.755136745331946, 55.08799778536156, 55.4188596057335, 55.7477578024444, 56.074726927556235, 56.399800531562164, 56.723011203567104, 57.04439060941925, 57.363969527918826, 57.68177788522125, 57.99784478754361, 58.3121985522755, 58.62486673758841, 58.9358761706314, 59.2452529743945, 59.55302259331595, 59.85920981770474, 60.16383880704422, 60.466933112239126, 60.76851569686394], [0.0, 6.093028803476971, 8.616843969807043, 10.553435459602719, 12.186057606953941, 13.624426593438713, 14.9248115565993, 16.120638945153505, 17.233687939614086, 18.27908641043091, 19.267848867997692, 20.20829037796122, 21.106870919205438, 21.968727773815218, 22.798026230355998, 23.59819908382841, 24.372115213907882, 25.122201336666336, 25.85053190942113, 26.558896814438665, 27.248853186877426, 27.92176570347943, 28.578838324886476, 29.22113960816724, 29.8496231131986, 30.465144017384855, 31.068472765811972, 31.66030637880815, 32.24127789030701, 32.811964281341034, 33.37289319193048, 33.92454863369592, 34.46737587922817, 35.0017856687341, 35.52815784698103, 36.04684452209374, 36.55817282086182, 37.06244730181751, 37.559952076646745, 38.05095268189747, 38.535697735995385, 39.01442041091986, 39.487339743264556, 39.95466180560161, 40.41658075592244, 40.87327978031613, 41.32493194186773, 41.77170094693296, 42.213741838410876, 42.65120162433879, 43.08421984903522, 43.512929113080865, 43.937455547630435, 44.357919247863734, 44.774434669797905, 45.18711099417621, 45.596052460711995, 46.001358675586964, 46.403124894774066, 46.801442285468084, 47.19639816765682, 47.588076237645915, 47.97655677515843, 48.36191683546052, 48.744230427815765, 49.12356868143844, 49.49999999999999, 49.87359020563889, 50.24440267333267, 50.612498456408964, 50.977936403899285, 51.34077327037449, 51.70106381884226, 52.058860917234824, 52.41421562896844, 52.76717729801358, 53.11779362887733, 53.46611076186485, 53.8121733439563, 54.15602459560709, 54.49770637375485, 54.837259231292734, 55.17472247324857, 55.51013420989, 55.84353140695886, 56.17494993322202, 56.50442460551209, 56.8319892314179, 57.15767664977295, 57.48151876907916, 57.80354660399308, 58.123790309992685, 58.44227921633448, 58.759041857402686, 59.074106002545655, 59.387498684487454, 59.6992462263972, 60.00937426769255, 60.3179077886493, 60.624871133883666, 60.93028803476971, 61.23418163085059], [0.0, 6.139014578904337, 8.681877677092668, 10.63308515906837, 12.278029157808675, 13.727253913292346, 15.037453241822567, 16.242305870780786, 17.363755354185336, 18.417043736713012, 19.413268658317175, 20.360807940747343, 21.26617031813674, 22.13453184506056, 22.970089246670334, 23.776301226221033, 24.55605831561735, 25.311805546029305, 26.045633031278008, 26.75934416236691, 27.454507826584692, 28.13249900026658, 28.794530730678698, 29.441679639585786, 30.074906483645133, 30.69507289452169, 31.30295513206381, 31.899255477205106, 32.48461174156157, 33.059605260801284, 33.624767657189835, 34.18058659531752, 34.72751070837067, 35.26595383652624, 35.79629869134517, 36.31890003840975, 36.834087473426024, 37.34216785351381, 37.843427434628595, 38.33813375739618, 38.82653731663435, 39.30887304413598, 39.78536162962454, 40.256210700958924, 40.721615881494685, 41.18176173987703, 41.63682264534603, 42.086963539794596, 42.53234063627348, 42.97310205233036, 43.40938838546335, 43.841333237026454, 44.26906369012112, 44.69270074631874, 45.112359725467705, 45.52815063232857, 45.94017849334067, 46.348543666441124, 46.75334212652611, 47.15466572885445, 47.552602452442066, 47.947236625273824, 48.338649132966054, 48.726917612342355, 49.1121166312347, 49.49431785568925, 49.87359020563889, 50.24999999999999, 50.62361109205861, 50.99448499592872, 51.362681004791796, 51.72825630156114, 52.091266062556016, 52.45176355471758, 52.809800226851834, 53.16542579534185, 53.51868832473382, 53.869634303566606, 54.218308715783465, 54.56475510803654, 54.909015653169384, 55.251131210139036, 55.59114138061928, 55.929084562506475, 56.26499800053316, 56.59891783417772, 56.93087914304503, 57.26091598987917, 57.589061461357396, 57.915347706803935, 58.23980597495153, 58.5624666488699, 58.88335927917157, 59.20251261559766, 59.51995463707949, 59.83571258036457, 60.149812967290266, 60.462281630782016, 60.77314373964868, 61.08242382224203, 61.39014578904338, 61.69633295423643], [0.0, 6.184658438426491, 8.74642784226795, 10.712142642814277, 12.369316876852983, 13.82931668593933, 15.149257407543118, 16.36306817195357, 17.4928556845359, 18.553975315279473, 19.557607215607945, 20.512191496766015, 21.424285285628553, 22.29910312097776, 23.14087293081227, 23.953079134006966, 24.738633753705965, 25.499999999999996, 26.239283526803852, 26.958301133417148, 27.65863337187866, 28.34166544153678, 29.008619408720573, 29.660579899927786, 30.298514815086236, 30.923292192132458, 31.53569406244296, 32.13642792844283, 32.72613634390714, 33.30540496676178, 33.87476937190864, 34.43472084974699, 34.9857113690718, 35.52815784698104, 36.062445840513924, 36.5889327529514, 37.107950630558946, 37.61980861195336, 38.12479508141651, 38.623179568751205, 39.11521443121589, 39.601136347332265, 40.08116764766217, 40.55551750378732, 41.02438299353203, 41.48795005781799, 41.94639436232869, 42.39988207530771, 42.848570571257106, 43.292609068985435, 43.732139211339764, 44.16729559300637, 44.59820624195552, 45.0249930594109, 45.447772222629354, 45.86665455426197, 46.28174586162454, 46.69314724882014, 47.100955404322754, 47.50526286633934, 47.90615826801393, 48.303726564313855, 48.69804924224378, 49.089204515860715, 49.47726750741193, 49.86231041578399, 50.24440267333267, 50.62361109205861, 50.99999999999999, 51.37363136863112, 51.74456493198102, 52.11285829812063, 52.478567053607705, 52.84174486142561, 53.2024435529046, 53.56071321407138, 53.916602266834296, 54.27015754537663, 54.62142436809938, 54.97044660542609, 55.31726674375732, 55.66192594583842, 56.00446410778341, 56.344919912978845, 56.68333088307356, 57.01973342624464, 57.35416288291549, 57.686653569088236, 58.01723881744115, 58.345951016330176, 58.67282164682384, 58.997881317891405, 59.32115979985557, 59.64268605621314, 59.96248827392006, 60.28059389223035, 60.59702963017247, 60.911821512740865, 61.22499489587565, 61.53657449029805, 61.846584384264915, 62.15504806530199], [0.0, 6.229967897188557, 8.810505093353047, 10.790620927453622, 12.459935794377113, 13.930631715755034, 15.260242462031856, 16.48294573187693, 17.621010186706094, 18.689903691565668, 19.700888304845545, 20.66246597093387, 21.581241854907244, 22.46246869780791, 23.310405401880082, 24.128561913218117, 24.919871588754226, 25.68681568431556, 26.431515280059145, 27.155800485347513, 27.861263431510068, 28.549299466011426, 29.221139608167235, 29.877876430563138, 30.520484924063712, 31.149839485942785, 31.766727876821058, 32.37186278236086, 32.96589146375386, 33.54940386951756, 34.12293949823197, 34.68699323954153, 35.24202037341219, 35.788440871320454, 36.326643114937006, 36.856987125916845, 37.379807383131336, 37.89541528997934, 38.40410134347633, 38.90613704802882, 39.40177660969109, 39.89125844091661, 40.374806501084315, 40.85263149418896, 41.32493194186774, 41.791895147265095, 42.25369806300982, 42.71050807471155, 43.16248370981449, 43.609775280319894, 44.052525466765246, 44.49086984989168, 44.92493739561582, 45.354850898222566, 45.78072738609556, 46.202678493784326, 46.620810803760165, 47.03522616082547, 47.44602196180414, 47.85329142284781, 48.257123826436235, 48.65760474992578, 49.054816277303495, 49.448837195630794, 49.83974317750845, 50.22760695075966, 50.612498456408964, 50.99448499592872, 51.37363136863112, 51.75, 52.12365106168216, 52.49464258379135, 52.86303056011829, 53.228869046787004, 53.59221025484954, 53.9531046372681, 54.311600970695025, 54.667746432425766, 55.021586672868686, 55.37316588384667, 55.722526863020136, 56.06971107469701, 56.41475870727447, 56.757708727537626, 57.09859893202285, 57.43746599563738, 57.77434551771228, 58.10927206565232, 58.44227921633447, 58.7733995953952, 59.10266491453664, 59.43010600697259, 59.755752861126275, 60.079634652684106, 60.40177977510266, 60.72221586865881, 61.040969848127425, 61.35806792916479, 61.67353565347133, 61.987397912801605, 62.29967897188557, 62.61040249032105], [0.0, 6.274950199005567, 8.874119674649423, 10.868532559642082, 12.549900398011134, 14.031215200402281, 15.3704261489394, 16.60195771588399, 17.748239349298846, 18.824850597016702, 19.84313483298443, 20.811655388267415, 21.737065119284164, 22.624654693497536, 23.478713763747795, 24.302777619029474, 25.09980079602227, 25.87228246599051, 26.622359023948274, 27.35187379321571, 28.062430400804562, 28.755434269021226, 29.432125305522877, 30.093603971608324, 30.7408522978788, 31.37475099502784, 31.996093511552317, 32.60559767892624, 33.20391543176798, 33.79164097820643, 34.3693177121688, 34.93744409655635, 35.49647869859769, 36.04684452209375, 36.58893275295141, 37.123106012293746, 37.649701194033405, 38.16903194999842, 38.68139087468288, 39.1870514328394, 39.68626966596886, 40.17928570793663, 40.666325135177885, 41.147600173035606, 41.62331077653483, 42.09364560120684, 42.55878287733332, 43.01889119909996, 43.47413023856833, 43.924651393038964, 44.37059837324713, 44.812107738868974, 45.24930938699507, 45.68232699852319, 46.1112784468182, 46.53627617246572, 46.95742752749559, 47.37483509206127, 47.78859696622198, 48.19880703917889, 48.60555523805895, 49.00892775811362, 49.409007276001816, 49.80587314765197, 50.19960159204454, 50.590265862120155, 50.977936403899285, 51.362681004791796, 51.74456493198102, 52.12365106168216, 52.5, 52.873670196043705, 53.24471804789655, 53.61319800198455, 53.979162646339745, 54.3426627982104, 54.70374758643142, 55.062464528932956, 55.41885960573351, 55.77297732773463, 56.124860801609124, 56.474551791050104, 56.82209077462744, 57.16751700047852, 57.51086853804245, 57.852182327030675, 58.19149422381248, 58.52883904538002, 58.864250611045755, 59.19776178201335, 59.52940449895329, 59.859209817704745, 60.18720794321665, 60.513428261832935, 60.83789937201975, 61.16064911362533, 61.4817045957576, 61.801092223358005, 62.11883772254597, 62.43496616480225, 62.74950199005568, 63.06246902873373], [0.0, 6.319612329882269, 8.937281465859737, 10.945889639494819, 12.639224659764539, 14.13108276106258, 15.479825580412722, 16.720122607205965, 17.874562931719474, 18.95883698964681, 19.98436889171134, 20.95978291872318, 21.891779278989638, 22.785686296444972, 23.64582415565167, 24.475753308121078, 25.278449319529077, 26.05642914906031, 26.81184439757922, 27.54655150831044, 28.26216552212516, 28.960101864461738, 29.641609268054257, 30.30779602676513, 30.959651160825445, 31.59806164941135, 32.22382658841126, 32.837668918484454, 33.44024521441193, 34.03215391361528, 34.61394227764298, 35.1861123172197, 35.74912586343895, 36.30340893084284, 36.84935548961474, 37.38733074184355, 37.91767397929362, 38.440701086218496, 38.95670673966166, 39.46596635076861, 39.96873778342268, 40.46526288064864, 40.95576882442815, 41.440469350623914, 41.91956583744636, 42.39324828318773, 42.86169618668864, 43.32507934210854, 43.783558557979276, 44.23728630917588, 44.6864073292987, 45.13105914999115, 45.571372592889944, 46.007472219195, 46.43947674123817, 46.867499399903984, 47.29164831130334, 47.71202678570677, 48.12873362140334, 48.54186337585322, 48.951506616242156, 49.35775015131869, 49.760677246195115, 50.16036782161789, 50.556898639058154, 50.95034347283637, 51.34077327037449, 51.72825630156114, 52.11285829812062, 52.49464258379135, 52.8736701960437, 53.25, 53.62368879515844, 53.99479141546895, 54.363360823260365, 54.72944819747409, 55.09310301662088, 55.45437313684106, 55.81330486541718, 56.16994303005835, 56.52433104425032, 56.87651096894042, 57.22652357080588, 57.57440837733376, 57.920203728923475, 58.26394682820587, 58.605673786758906, 58.94541966938568, 59.283218536108514, 59.6191034820216, 59.95310667513402, 60.28525939232575, 60.61559205353026, 60.94413425424961, 61.27091479650031, 61.595961718281494, 61.91930232165089, 62.24096319948785, 62.56097026101817, 62.87934875616955, 63.1961232988227, 63.511317889018805], [0.0, 6.363961030678928, 9.0, 11.022703842524303, 12.727922061357855, 14.230249470757707, 15.588457268119898, 16.837458240482736, 18.0, 19.091883092036785, 20.12461179749811, 21.106870919205434, 22.045407685048605, 22.945587811167535, 23.811761799581316, 24.647515087732472, 25.45584412271571, 26.239283526803852, 27.0, 27.7398630133604, 28.460498941515414, 29.163333142835373, 29.8496231131986, 30.52048492406371, 31.176914536239796, 31.819805153394643, 32.449961479175904, 33.0681115275729, 33.67491648096547, 34.27097897638759, 34.85685011586675, 35.43303543305315, 36.0, 36.55817282086182, 37.107950630558946, 37.6497011940334, 38.18376618407357, 38.71046370169182, 39.230090491866065, 39.74292389847532, 40.24922359499622, 40.74923312161838, 41.24318125460257, 41.731283229730664, 42.21374183841087, 42.690748412273116, 43.162483709814474, 43.62911871674696, 44.09081537009721, 44.54772721475249, 45.00000000000001, 45.447772222629354, 45.89117562233507, 46.330335634441504, 46.765371804359695, 47.196398167656824, 47.62352359916263, 48.0468521341409, 48.466483264210545, 48.88251221040097, 49.295030175464944, 49.704124577342675, 50.1098792654702, 50.512374721448204, 50.91168824543142, 51.30789412946121, 51.70106381884226, 52.09126606255601, 52.478567053607705, 52.86303056011829, 53.24471804789654, 53.62368879515843, 54.0, 54.37370688117557, 54.74486277268398, 55.113519212621505, 55.4797260267208, 55.84353140695885, 56.2049819855856, 56.56412290489441, 56.92099788303083, 57.27564927611035, 57.628118136895644, 57.97844427026307, 58.32666628567075, 58.67282164682384, 59.01694671871801, 59.35907681222814, 59.6992462263972, 60.037488288568504, 60.37383539249432, 60.70831903454418, 61.04096984812742, 61.371817636436354, 61.700891403609404, 62.02821938440599, 62.35382907247959, 62.67774724732855, 63.0, 63.3206127576163, 63.63961030678929, 63.957016815983536], [0.0, 6.408002808988148, 9.062284480195927, 11.098986440211558, 12.816005617976296, 14.328729880907101, 15.696337152342265, 16.95398183318597, 18.124568960391855, 19.224008426964446, 20.263884129159443, 21.25294097295713, 22.197972880423116, 23.104382701124045, 23.976551044718672, 24.818088161661443, 25.632011235952593, 26.420872430712805, 27.18685344058779, 27.93183667430411, 28.657459761814202, 29.365157925677842, 30.056197364270815, 30.73170187282182, 31.39267430468453, 32.04001404494075, 32.67453136618795, 33.29695932063467, 33.90796366637194, 34.50815121098202, 35.09807687039277, 35.678249676798885, 36.24913792078371, 36.81117357542408, 37.36475612124345, 37.91025586830033, 38.44801685392889, 38.97835938055885, 39.50158224679108, 40.017964715862306, 40.527768258318886, 41.031238099769794, 41.52860459972139, 42.020084483494315, 42.50588194591426, 42.9861896427213, 43.461189583351256, 43.931053936822416, 44.39594576084623, 44.856019662917035, 45.31142240097965, 45.762293430290406, 46.20876540224809, 46.65096462025196, 47.08901145702679, 47.52302073732267, 47.953102089437344, 48.37936026861041, 48.80189545499233, 49.220803528589414, 49.636176323322886, 50.048101862108616, 50.45666457466248, 50.86194549955792, 51.264022471905186, 51.66297029788357, 52.058860917234824, 52.45176355471758, 52.84174486142561, 53.228869046787004, 53.61319800198455, 53.99479141546895, 54.37370688117558, 54.75, 55.12372447503888, 55.494932201057786, 55.86367334860822, 56.22999644317968, 56.59394843974046, 56.95557479299108, 57.314919523628404, 57.67202528089334, 58.026933401654105, 58.37968396625662, 58.730315851355684, 59.07886677992394, 59.42537336862092, 59.769871172690344, 60.11239472854163, 60.45297759415991, 60.79165238747833, 61.12845082283698, 61.46340374564364, 61.796541165343555, 62.127892286798215, 62.45748554016563, 62.78534860936906, 63.11150845923429, 63.4359913613715, 63.758822918871395, 64.0800280898815, 64.39963121012418], [0.0, 6.45174395028197, 9.124143795447328, 11.174748319313506, 12.90348790056394, 14.426538046253508, 15.80348062927911, 17.06971001511156, 18.248287590894655, 19.35523185084591, 20.402205763103165, 21.39801392653066, 22.349496638627013, 23.262093628906236, 24.140215409146624, 24.98749687343652, 25.80697580112788, 26.601221776452295, 27.37243138634199, 28.122499888879013, 28.853076092507017, 29.56560501664054, 30.26136150274802, 30.941477017104404, 31.60696125855822, 32.25871975140985, 32.89756829919197, 33.52424495794051, 34.13942003022312, 34.743704465701406, 35.337656968169235, 35.92179004448414, 36.49657518178931, 37.06244730181751, 37.61980861195335, 38.16903194999841, 38.71046370169182, 39.244426355853385, 39.771220750688556, 40.29112805568988, 40.80441152620633, 41.311318061761234, 41.812079594299064, 42.30691432851136, 42.79602785306132, 43.27961413876052, 43.75785643744446, 44.23092809336019, 44.698993277254026, 45.16220765197379, 45.62071897723665, 46.074667660223014, 46.52418725781247, 46.96940493555353, 47.41044188783733, 47.84741372320975, 48.28043081829325, 48.70959864338855, 49.135018062477606, 49.55678561004537, 49.97499374687304, 50.38973109672247, 50.8010826656283, 51.20913004533468, 51.61395160225576, 52.0156226531991, 52.414215628968435, 52.80980022685183, 53.20244355290459, 53.59221025484953, 53.97916264633974, 54.363360823260365, 54.74486277268398, 55.12372447503887, 55.5, 55.87374159656752, 56.244999777758025, 56.61382340029685, 56.980259739667744, 57.34435456084583, 57.706152185014034, 58.06569555253773, 58.423026282451346, 58.77818472868994, 59.13121003328108, 59.482140176695054, 59.83101202553739, 60.177861377752535, 60.52272300549604, 60.86563069582044, 61.20661728930949, 61.54571471678592, 61.88295403420881, 62.218365455868415, 62.55197838597913, 62.88382144876374, 63.21392251711644, 63.5423087399254, 63.869006568131304, 64.19404177959198, 64.5174395028197, 64.83922423965296], [0.0, 6.49519052838329, 9.185586535436917, 11.250000000000002, 12.99038105676658, 14.523687548277813, 15.909902576697322, 17.1846588560844, 18.371173070873834, 19.48557158514987, 20.53959590644373, 21.542109924517607, 22.500000000000004, 23.418742493993996, 24.302777619029477, 25.15576474687263, 25.98076211353316, 26.780356607035685, 27.556759606310756, 28.311879132265314, 29.047375096555626, 29.76470224947665, 30.46514401738485, 31.149839485942785, 31.819805153394643, 32.47595264191645, 33.11910324872943, 33.75, 34.3693177121688, 34.977671449083054, 35.57562367689427, 36.16369035372358, 36.74234614174767, 37.31202889149825, 37.873143518857795, 38.42606537234849, 38.97114317029974, 39.50870157319777, 40.03904344511742, 40.562451848969886, 41.07919181288746, 41.58951189903532, 42.093645601206845, 42.59181259350205, 43.084219849035215, 43.57106264483344, 44.05252546676524, 44.52878282639219, 45.00000000000001, 45.46633369868303, 45.9279326771846, 46.38493828819869, 46.83748498798799, 47.285700798444346, 47.72970773009197, 48.16962216999424, 48.605555238058955, 49.037613114832574, 49.46589734352345, 49.89050510868776, 50.31152949374526, 50.72905971925756, 51.14318136369696, 51.5539765682532, 51.96152422706632, 52.36590016413353, 52.76717729801358, 53.16542579534184, 53.56071321407137, 53.95310463726809, 54.34266279821039, 54.72944819747409, 55.11351921262151, 55.49493220105778, 55.87374159656753, 56.25, 56.62375826453063, 56.99506557588999, 57.36396952791884, 57.730516193777454, 58.09475019311125, 58.45671475544961, 58.81645178009297, 59.174001892723126, 59.5294044989533, 59.882697835017424, 60.23391901578379, 60.583104080263176, 60.9302880347697, 61.27550489388072, 61.61878771933119, 61.96016865696865, 62.29967897188557, 62.637349081837755, 62.97320858905, 63.30728631050299, 63.63961030678929, 63.97020790961994, 64.29910574805842, 64.62632977355283, 64.9519052838329, 65.27585694573455], [0.0, 6.538348415311011, 9.246621004453464, 11.324751652906128, 13.076696830622023, 14.620191517213447, 16.01561737804697, 17.298843892006193, 18.49324200890693, 19.615045245933032, 20.676073128135336, 21.685248442201445, 22.649503305812257, 23.57435046825257, 24.46425964545014, 25.3229145242012, 26.153393661244046, 26.958301133417145, 27.7398630133604, 28.500000000000007, 29.240383034426895, 29.962476533157275, 30.66757245039131, 31.356817440550316, 32.03123475609394, 32.69174207655506, 33.33916615633931, 33.974254958718376, 34.597687784012386, 35.21008378291651, 35.812009158939965, 36.40398329853479, 36.98648401781386, 37.55995207664675, 38.12479508141651, 38.68139087468288, 39.230090491866065, 39.77122075068856, 40.305086527633215, 40.83197276644861, 41.35214625627067, 41.8658572108586, 42.37334067547661, 42.87481778386936, 43.37049688440289, 43.86057455164034, 44.34523649728345, 44.82465839245181, 45.29900661162451, 45.76843890717708, 46.23310502226734, 46.69314724882015, 47.14870093650514, 47.5998949578673, 48.04685213414091, 48.48968962573385, 48.92851929090028, 49.363448015713004, 49.79457801809351, 50.222007128349624, 50.6458290484024, 51.06613359164761, 51.48300690519155, 51.89653167601858, 52.30678732248809, 52.71385017241674, 53.11779362887732, 53.51868832473382, 53.91660226683429, 54.311600970695025, 54.70374758643141, 55.09310301662088, 55.4797260267208, 55.86367334860822, 56.24499977775803, 56.62375826453063, 57.000000000000014, 57.37377449671584, 57.74512966476049, 58.11411188343156, 58.48076606885379, 58.845135737799104, 59.20726306797167, 59.56718895499435, 59.92495306631455, 60.28059389223037, 60.63414879422322, 60.985654050768375, 61.33514490078262, 61.68265558485628, 62.02821938440601, 62.37186865887538, 62.71363488110063, 63.053548670951116, 63.39163982734633, 63.72793735874401, 64.06246951218787, 64.39526380099706, 64.72634703117426, 65.05574532660434, 65.38348415311012, 65.70958834142854], [0.0, 6.5812232905440915, 9.307255234493143, 11.399013115178, 13.162446581088183, 14.716062652761439, 16.12063894515351, 17.41228014936585, 18.614510468986285, 19.743669871632274, 20.81165538826741, 21.827448316282876, 22.798026230356, 23.728938029334564, 24.62468273907301, 25.48896820194964, 26.324893162176366, 27.135078772688313, 27.92176570347943, 28.68688724835792, 29.432125305522877, 30.158953894324654, 30.86867344088502, 31.562438118751224, 32.24127789030702, 32.90611645272046, 33.55778598179565, 34.197039345533994, 34.8245602987317, 35.44097205213198, 36.04684452209374, 36.64270050091832, 37.22902093797257, 37.806249483385685, 38.37479641639809, 38.93504205725223, 39.48733974326455, 40.03201843524756, 40.569385008895566, 41.09972627646078, 41.62331077653482, 42.14039036364044, 42.651201624338796, 43.1559671424474, 43.65489663256575, 44.14818795828431, 44.63602804909953, 45.1185937280851, 45.596052460712, 46.068563033808644, 46.53627617246572, 46.999335101679904, 47.45787605866913, 47.912028761053314, 48.36191683546053, 48.80765821057184, 49.24936547814602, 49.68714622515566, 50.12110333981087, 50.5513352939366, 50.97793640389928, 51.40099707204132, 51.8206040103741, 52.236840448097546, 52.64978632435273, 53.05951846747198, 53.46611076186485, 53.869634303566606, 54.27015754537663, 54.667746432425766, 55.062464528932956, 55.45437313684106, 55.84353140695886, 56.22999644317969, 56.61382340029686, 56.99506557588999, 57.37377449671584, 57.75, 58.1237903099927, 58.49519211012133, 58.864250611045755, 59.23100961489683, 59.595511575956806, 59.95779765801943, 60.31790778864931, 60.67588071054264, 61.03175403017679, 61.38556426392121, 61.73734688177004, 62.08713634884444, 62.43496616480224, 62.78086890128234, 63.12487623750245, 63.467018994120096, 63.80732716545962, 64.14582995020018, 64.48255578061404, 64.81753235043742, 65.150786641452, 65.48234494884862, 65.81223290544092, 66.14047550479208], [0.0, 6.623820649745886, 9.367496997597598, 11.472793905583769, 13.247641299491772, 14.811313243598626, 16.224980739587956, 17.524982168321884, 18.734993995195197, 19.87146194923766, 20.946360065653415, 21.968727773815218, 22.945587811167538, 23.88252499213599, 24.784067462787466, 25.653947064730605, 26.495282598983543, 27.310712184049688, 28.102490992792795, 28.872564832380245, 29.622626487197252, 30.3541595172721, 31.068472765811972, 31.76672787682106, 32.44996147917591, 33.11910324872943, 33.774990747593115, 34.418381716751306, 35.04996433664377, 35.67036585178235, 36.28015986734347, 36.87987255943274, 37.46998799039039, 38.05095268189747, 38.623179568751205, 39.1870514328394, 39.74292389847532, 40.29112805568988, 40.83197276644861, 41.36574669941304, 41.89272013130683, 42.413146546796085, 42.927264063762564, 43.43529670671078, 43.937455547630435, 44.43393973079588, 44.924937395615814, 45.41062650966182, 45.891175622335076, 46.3667445482212, 46.837484987988, 47.30354109366445, 47.76504998427198, 48.22214221703553, 48.67494221876387, 49.12356868143846, 49.56813492557493, 50.00874923450896, 50.445515162400724, 50.878531818439896, 51.30789412946121, 51.73369308294161, 52.15601595214114, 52.57494650496565, 52.990565197967086, 53.4029493567537, 53.812173343956296, 54.21830871578346, 54.621424368099376, 55.02158667286868, 55.4188596057335, 55.81330486541717, 56.20498198558559, 56.59394843974045, 56.980259739667744, 57.36396952791883, 57.74512966476049, 58.12379030999269, 58.500000000000014, 58.8738057203711, 59.245252974394504, 59.614385847712974, 59.98124706939663, 60.34587806967433, 60.7083190345442, 61.06860895746686, 61.42678568832982, 61.78288597985693, 62.136945531623944, 62.4889990318296, 62.839080196960246, 63.18722180947664, 63.53345575364212, 63.87781304960277, 64.22032388582295, 64.56101764997203, 64.89992295835182, 65.23706768394791, 65.57247898318319, 65.90618332144565, 66.23820649745886, 66.56857366655832], [0.0, 6.666145812986692, 9.4273538174824, 11.546103238755492, 13.332291625973385, 14.905955185763844, 16.328655792807933, 17.63696402445727, 18.8547076349648, 19.998437438960075, 21.080203983832796, 22.109104459475514, 23.092206477510985, 24.035130538443102, 24.942433722473837, 25.817871717087755, 26.66458325194677, 27.48522330271304, 28.282061452447206, 29.05705594171578, 29.811910371527688, 30.548117781624455, 31.266995378513748, 31.969712228920677, 32.657311585615865, 33.330729064933465, 33.990807580873984, 34.63830971626647, 35.27392804891454, 35.89829383132296, 36.51198433391425, 37.11552909497586, 37.7094152699296, 38.29409223365923, 38.869975559549815, 39.43745047540472, 39.99687487792015, 40.54858197273981, 41.09288259540818, 41.63006725913376, 42.16040796766559, 42.68415982539659, 43.20156247174401, 43.71284136269341, 44.21820891895103, 44.717865557291525, 45.212000619304604, 45.70079320974637, 46.18441295502197, 46.66302069090684, 47.13676908741201, 47.60580321767505, 48.070261076886204, 48.530274056510336, 48.9859673784238, 49.437460493031, 49.88486744494767, 50.32829720942285, 50.76785400231135, 51.203637566094855, 51.63574343417551, 52.06426317542581, 52.489284620768075, 52.91089207337181, 53.32916650389354, 53.74418573203989, 54.156024595607086, 54.56475510803654, 54.97044660542608, 55.37316588384667, 55.77297732773462, 56.16994303005834, 56.56412290489441, 56.95557479299107, 57.34435456084583, 57.73051619377745, 58.11411188343156, 58.49519211012132, 58.8738057203711, 59.25000000000001, 59.623820743055376, 59.99531231688023, 60.36451772357667, 60.731478658106134, 61.09623556324891, 61.458827681627646, 61.81929310498463, 62.17766882088778, 62.533990757027496, 62.88829382325458, 63.24061195149839, 63.590978133694406, 63.939424457841355, 64.28598214229912, 64.63068156843157, 64.97355231169064, 65.31462317123173, 65.65392219814443, 65.9914767223768, 66.32731337842655, 66.66145812986693, 66.99393629277206], [0.0, 6.708203932499369, 9.486832980505138, 11.618950038622254, 13.416407864998739, 15.000000000000002, 16.431676725154986, 17.74823934929885, 18.973665961010276, 20.12461179749811, 21.213203435596427, 22.248595461286993, 23.237900077244507, 24.186773244895654, 25.09980079602227, 25.980762113533157, 26.832815729997478, 27.65863337187866, 28.460498941515418, 29.2403830344269, 30.000000000000004, 30.740852297878803, 31.464265445104548, 32.17141588429083, 32.86335345030997, 33.54101966249685, 34.20526275297414, 34.856850115866756, 35.4964786985977, 36.12478373637689, 36.74234614174767, 37.3496987939662, 37.94733192202055, 38.53569773599539, 39.1152144312159, 39.68626966596886, 40.24922359499622, 40.80441152620633, 41.35214625627067, 41.89272013130683, 42.42640687119285, 42.953463189829066, 43.47413023856832, 43.98863489584554, 44.497190922573985, 45.0, 45.49725266430931, 45.98912915026768, 46.475800154489015, 46.95742752749558, 47.4341649025257, 47.90615826801395, 48.37354648979131, 48.836461788299125, 49.29503017546496, 49.749371855331006, 50.19960159204454, 50.6458290484024, 51.08815909777921, 51.52669211195301, 51.96152422706631, 52.392747589718944, 52.82045058497703, 53.24471804789655, 53.665631459994955, 54.083269131959845, 54.49770637375485, 54.90901565316938, 55.31726674375732, 55.722526863020136, 56.124860801609124, 56.52433104425032, 56.920997883030836, 57.314919523628404, 57.70615218501404, 58.09475019311126, 58.4807660688538, 58.864250611045755, 59.24525297439451, 59.62382074305538, 60.00000000000001, 60.37383539249433, 60.745370193949775, 61.1146463623901, 61.481704595757606, 61.846584384264915, 62.20932405998317, 62.56996084384264, 62.928530890209096, 63.28506932918697, 63.63961030678928, 63.99218702310463, 64.34283176858166, 64.69157595854348, 65.03845016603641, 65.3834841531101, 65.72670690061994, 66.06814663663573, 66.40783086353596, 66.74578638386097, 67.0820393249937, 67.4166151627327], [0.0, 6.75, 9.54594154601839, 11.691342951089924, 13.5, 15.093458848123582, 16.534055763786455, 17.858821349685986, 19.09188309203678, 20.25, 21.34537420613656, 22.387217334898953, 23.382685902179848, 24.33747110938193, 25.256187360724105, 26.14263758690006, 27.0, 27.83096297291921, 28.63782463805518, 29.422567868899552, 30.186917696247164, 30.932385940951924, 31.66030637880815, 32.371862782360864, 33.06811152757291, 33.75000000000001, 34.4183817167513, 35.074028853269766, 35.71764269937197, 36.34986244815791, 36.97127263159871, 37.58240944910265, 38.18376618407356, 38.7757978641317, 39.35892529020578, 39.93353853592241, 40.5, 41.05864707951299, 41.609794520040595, 42.15373648918919, 42.69074841227312, 43.221088602671735, 43.74499971425306, 44.2627100390385, 44.774434669797905, 45.28037654437074, 45.78072738609556, 46.27566855270705, 46.765371804359695, 47.25, 47.72970773009197, 48.20464189266424, 48.67494221876386, 49.1407417526435, 49.602167291359365, 50.05933978789573, 50.51237472144821, 50.961382438077564, 51.40646846458139, 51.847733798113104, 52.28527517380012, 52.719185312369916, 53.14955314957973, 53.57646404905796, 54.0, 54.420239801015214, 54.837259231292734, 55.251131210139036, 55.66192594583842, 56.069711074697004, 56.474551791050104, 56.87651096894042, 57.27564927611036, 57.67202528089334, 58.06569555253773, 58.45671475544961, 58.845135737799104, 59.23100961489683, 59.61438584771298, 59.99531231688023, 60.37383539249433, 60.75000000000001, 61.123849682427576, 61.49542665922402, 61.86477188190385, 62.231925086726996, 62.596924844596, 62.95980860834951, 63.3206127576163, 63.67937264138208, 64.03612261840968, 64.39089609564382, 64.74372556472173, 65.09464263670246, 65.44367807512045, 65.7908618274605, 66.13622305514582, 66.47979016212372, 66.82159082212874, 67.16165200469686, 67.50000000000001, 67.83666044256601], [0.0, 6.791538853603063, 9.604686356149273, 11.763290356018596, 13.583077707206126, 15.186342548487442, 16.63580475961413, 17.96872282606641, 19.209372712298546, 20.37461656080919, 21.476731594914533, 22.524986126521814, 23.52658071203719, 24.487241575971765, 25.411611519146128, 26.303516875125272, 27.166155414412252, 28.002232053891706, 28.814059068447822, 29.603631533985833, 30.372685096974884, 31.12274088186965, 31.855140872392955, 32.571076125912704, 33.27160951922826, 33.95769426801532, 34.63018914184559, 35.28987106805578, 35.93744565213282, 36.57355602070983, 37.19879030291173, 37.813687997866595, 38.41874542459709, 39.01442041091986, 39.60113634733226, 40.17928570793662, 40.74923312161838, 41.31131806176124, 41.8658572108586, 42.413146546796085, 42.953463189829066, 43.48706704297268, 44.01420225336364, 44.53509851791057, 45.04997225304363, 45.55902764546232, 46.06245759835227, 46.560444585506275, 47.05316142407438, 47.54077197522144, 48.02343178074638, 48.50128864267424, 48.97448315194353, 49.443149171548534, 49.90741427884239, 50.36740017114246, 50.823223038292255, 51.274993905411634, 51.72281894870002, 52.16679978683761, 52.607033750250544, 53.04361413026078, 53.47663040992767, 53.90616847819923, 54.332310828824504, 54.755136745331946, 55.174722473248565, 55.59114138061927, 56.00446410778341, 56.414758707274466, 56.82209077462744, 57.226523570805874, 57.628118136895644, 58.0269334016541, 58.423026282451346, 58.81645178009296, 59.20726306797167, 59.5955115759568, 59.98124706939663, 60.36451772357667, 60.74537019394977, 61.123849682427576, 61.500000000000014, 61.87386362592853, 62.2454817637393, 62.614894394225416, 62.98214032565106, 63.34725724133604, 63.71028174478591, 64.07124940252064, 64.43019478474359, 64.78715150398264, 65.14215225182541, 65.49522883386241, 65.84641220294392, 66.19573249084868, 66.54321903845651, 66.88890042450991, 67.23280449304492, 67.57495837956544, 67.91538853603063, 68.25412075472074], [0.0, 6.832825184358224, 9.663074045043842, 11.834800378544626, 13.665650368716449, 15.278661590597522, 16.73693520331605, 18.077956189790925, 19.326148090087685, 20.498475553074673, 21.6072904363319, 22.66191739460719, 23.669600757089253, 24.636101558485265, 25.56609082358897, 26.46341814656602, 27.331300737432898, 28.17245995648942, 28.989222135131534, 29.783594477497175, 30.557323181195045, 31.31193861772216, 32.04879092883225, 32.76907841243022, 33.4738704066321, 34.164125921791126, 34.84070894801081, 35.50440113563388, 36.15591237958185, 36.795889716108235, 37.42492484962394, 38.04356055891719, 38.65229618017537, 39.251592324388575, 39.84187495588027, 40.423538934635594, 40.996951106149346, 41.56245300749223, 42.12036324629692, 42.67097959972328, 43.2145808726638, 43.75142854810572, 44.28176825737654, 44.805831093731534, 45.32383478921438, 45.83598477179256, 46.34247511732622, 46.843489408881574, 47.339201514178505, 47.82977629050757, 48.315370225219226, 48.796132018839366, 49.27220311697053, 49.74371819637129, 50.210805609948146, 50.67358779482661, 51.13218164717794, 51.586698867052924, 52.037246276104966, 52.48392611076271, 52.92683629313204, 53.366070681660645, 53.80171930338286, 54.23386856937277, 54.662601474865795, 55.08799778536156, 55.51013420988999, 55.92908456250647, 56.34491991297884, 56.75770872753762, 57.16751700047851, 57.57440837733376, 57.97844427026307, 58.379683966256614, 58.77818472868994, 59.174001892723126, 59.56718895499435, 59.95779765801942, 60.34587806967433, 60.73147865810613, 61.11464636239009, 61.495426659224016, 61.87386362592852, 62.25, 62.62387723544432, 62.99553555610112, 63.365014006153274, 63.73235049800062, 64.0975818576645, 64.46074386787667, 64.8218713089957, 65.18099799788278, 65.53815682486044, 65.89337978886802, 66.24669803092075, 66.59814186597099, 66.9477408132642, 67.29552362527541, 67.64151831530691, 67.98575218382157, 68.32825184358225, 68.66904324366257], [0.0, 6.87386354243376, 9.72111104761179, 11.90588089979066, 13.74772708486752, 15.3704261489394, 16.83745824048274, 18.186533479473212, 19.44222209522358, 20.62159062730128, 21.73706511928416, 22.798026230355998, 23.81176179958132, 24.784067462787462, 25.719642299223374, 26.62235902394827, 27.49545416973504, 28.341665441536776, 29.163333142835373, 29.962476533157275, 30.7408522978788, 31.500000000000007, 32.24127789030702, 32.96589146375387, 33.67491648096548, 34.36931771216881, 35.049964336643775, 35.71764269937198, 36.373066958946424, 37.0168880377592, 37.6497011940334, 38.27205246651922, 38.88444419044716, 39.487339743264556, 40.08116764766216, 40.66632513517788, 41.24318125460256, 41.812079594299064, 42.37334067547661, 42.927264063762564, 43.47413023856832, 44.014202253363635, 44.547727214752506, 45.07493760395016, 45.596052460711995, 46.11127844681819, 46.62081080376016, 47.124834217215025, 47.62352359916264, 48.11704479703632, 48.60555523805896, 49.08920451586072, 49.568134925574924, 50.04248195283684, 50.51237472144822, 50.97793640389929, 51.43928459844675, 51.89653167601858, 52.349785099845455, 52.799147720394124, 53.24471804789654, 53.68659050451984, 54.12485565800615, 54.559600438419636, 54.99090833947008, 55.4188596057335, 55.84353140695885, 56.264998000533154, 56.68333088307355, 57.098598932022846, 57.510868538042445, 57.92020372892347, 58.32666628567075, 58.73031585135568, 59.13121003328107, 59.52940449895329, 59.92495306631455, 60.3179077886493, 60.7083190345442, 61.09623556324891, 61.4817045957576, 61.86477188190385, 62.2454817637393, 62.62387723544432, 63.000000000000014, 63.37389052283283, 63.74558808262734, 64.11513081948755, 64.48255578061404, 64.84789896365186, 65.21119535785247, 65.57247898318317, 65.93178292750774, 66.28913938195306, 66.6445796745692, 66.99813430238189, 67.34983296193096, 67.69970457838056, 68.04777733328254, 68.394078691068, 68.73863542433762, 69.08147363801673], [0.0, 6.914658342969666, 9.778803607803972, 11.976539567003487, 13.829316685939332, 15.461646096066229, 16.937384685954324, 18.2944663764757, 19.557607215607945, 20.743975028909, 21.86606960566988, 22.933327277130985, 23.953079134006973, 24.931155207891997, 25.872282465990512, 26.780356607035685, 27.658633371878665, 28.509866713122317, 29.33641082341192, 30.140296946115186, 30.923292192132458, 31.68694526141642, 32.432622465659485, 33.16153645415122, 33.87476937190865, 34.57329171484833, 35.25797782062948, 35.929618701010455, 36.5889327529514, 37.23657476191923, 37.87314351885779, 38.499188303131795, 39.11521443121589, 39.721688030596084, 40.31904016714684, 40.90767042988393, 41.487950057818, 42.06022467842986, 42.62481671514847, 43.18202751145435, 43.73213921133976, 44.27541642943633, 44.812107738868974, 45.34244700057552, 45.86665455426197, 46.38493828819868, 46.89749460259045, 47.40450927918145, 47.90615826801395, 48.402608400787656, 48.894018039019876, 49.380537664144576, 49.862310415783995, 50.3394725836495, 50.812154057862976, 51.28047874191505, 51.744564931981024, 52.20452566588456, 52.660469044625884, 53.11249852906565, 53.56071321407137, 54.005208082184076, 54.44607423864461, 54.883399129427104, 55.31726674375733, 55.7477578024444, 56.17494993322202, 56.59891783417771, 57.019733426244635, 57.43746599563738, 57.852182327030675, 58.26394682820586, 58.67282164682384, 59.078866779923935, 59.482140176695054, 59.882697835017424, 60.28059389223037, 60.675880710542636, 61.06860895746686, 61.458827681627646, 61.846584384264915, 62.231925086726996, 62.614894394225416, 62.995535556101125, 63.37389052283284, 63.75000000000001, 64.12390349939717, 64.49563938748108, 64.86524493131897, 65.23275634219361, 65.59820881700963, 65.96163657763503, 66.32307290830244, 66.68255019118571, 67.04009994025965, 67.39575283354284, 67.7495387438173, 68.10148676791133, 68.45162525462781, 68.79998183139296, 69.14658342969666, 69.49145630939103], [0.0, 6.955213871621778, 9.836157786453, 12.04678380315676, 13.910427743243556, 15.552331014995792, 17.036725037400824, 18.401766219577944, 19.672315572906, 20.865641614865336, 21.99431744792277, 23.06783474884455, 24.09356760631352, 25.077380245950735, 26.02402735934621, 26.937427494101954, 27.820855486487112, 28.67708144145774, 29.508473359359005, 30.31707439711161, 31.104662029991584, 31.87279404131367, 32.62284475639732, 33.35603393690563, 34.07345007480165, 34.77606935810889, 35.464771252610674, 36.14035140947028, 36.80353243915589, 37.45497296755132, 38.09527529760088, 38.72499193027676, 39.344631145812, 39.95466180560161, 40.55551750378732, 41.147600173035606, 41.73128322973067, 42.30691432851136, 42.87481778386936, 43.43529670671078, 43.98863489584554, 44.535098517910576, 45.07493760395017, 45.608387386532314, 46.1356694976891, 46.65699304498737, 47.172555580549165, 47.682543975757, 48.18713521262704, 48.686497101352444, 49.18078893226502, 49.67016206939535, 50.15476049190147, 50.63472128885475, 51.11017511220247, 51.581246592148204, 52.04805471869242, 52.51071319264289, 52.969330749028735, 53.42401145552438, 53.87485498820391, 54.32195688669546, 54.76540879058606, 55.20529865873384, 55.641710972974224, 56.074726927556235, 56.504424605512085, 56.93087914304503, 57.35416288291548, 57.77434551771227, 58.19149422381247, 58.605673786758906, 59.01694671871801, 59.42537336862092, 59.8310120255374, 60.23391901578379, 60.63414879422322, 61.031754030176785, 61.42678568832982, 61.81929310498464, 62.20932405998317, 62.596924844596, 62.98214032565106, 63.365014006153274, 63.74558808262734, 64.12390349939717, 64.5, 64.87391617591774, 65.24568951279464, 65.61535643429822, 65.98295234376832, 66.34851166378941, 66.71206787381126, 67.07365354593412, 67.43330037896708, 67.79103923086, 68.1469001496033, 68.50091240268264, 68.853104505171, 69.20350424653365, 69.55213871621778, 69.89903432809355], [0.0, 6.995534289816612, 9.89317946870469, 12.116620816052636, 13.991068579633223, 15.64249021096066, 17.135489488193794, 18.508444018879597, 19.78635893740938, 20.986602869449836, 22.12182180562894, 23.20156244738703, 24.233241632105273, 25.22275758120036, 26.174892549922724, 27.093587802282663, 27.982137159266447, 28.843326784544114, 29.67953840611407, 30.492827025384187, 31.28498042192132, 32.05756540974377, 32.81196428134104, 33.54940386951757, 34.27097897638759, 34.97767144908306, 35.67036585178235, 36.34986244815791, 37.016888037759195, 37.67210506462308, 38.3161193233344, 38.94948651779635, 39.57271787481876, 40.186284973856445, 40.790623922661446, 41.38613898396418, 41.97320573889967, 42.55217385751285, 43.12336953439516, 43.68709763763211, 44.24364361125788, 44.79327516491734, 45.33624377912225, 45.87278605011908, 46.40312489477406, 46.92747063288197, 47.44602196180413, 47.95896683624451, 48.466483264210545, 48.968740028716276, 49.46589734352346, 49.95810745014267, 50.44551516240072, 50.92825836409488, 51.40646846458139, 51.880270816563794, 52.34978509984545, 52.81512567437476, 53.27640190553413, 53.73371846429391, 54.187175604565326, 54.63686941983408, 55.08289208093562, 55.525332056638796, 55.964274318532894, 56.39980053156217, 56.8319892314179, 57.260915989879166, 57.68665356908823, 58.10927206565231, 58.52883904538002, 58.94541966938568, 59.35907681222814, 59.769871172690344, 60.177861377752535, 60.58310408026317, 60.985654050768375, 61.385564263921204, 61.78288597985693, 62.17766882088778, 62.56996084384264, 62.959808608349505, 63.34725724133604, 63.73235049800063, 64.11513081948755, 64.49563938748108, 64.87391617591774, 65.25, 65.62392856268208, 65.9957384987849, 66.36546541688682, 66.73314393912518, 67.09880773903514, 67.46248957754229, 67.82422133721848, 68.18403405490173, 68.54195795277518, 68.89802246799252, 69.25225628093283, 69.6046873421611, 69.95534289816612, 70.30424951594321], [0.0, 7.035623639735145, 9.9498743710662, 12.186057606953943, 14.07124727947029, 15.732132722552274, 17.23368793961409, 18.614510468986285, 19.8997487421324, 21.106870919205434, 22.24859546128699, 23.334523779156072, 24.372115213907886, 25.36730178793165, 26.32489316217637, 27.248853186877422, 28.14249455894058, 29.008619408720573, 29.8496231131986, 30.667572450391315, 31.464265445104548, 32.24127789030702, 33.0, 33.74166563760598, 34.46737587922818, 35.178118198675726, 35.874782229304195, 36.55817282086183, 37.22902093797257, 37.887992820945264, 38.535697735995385, 39.17269457160179, 39.7994974842648, 40.41658075592244, 41.02438299353203, 41.62331077653482, 42.21374183841087, 42.79602785306132, 43.37049688440289, 43.937455547630435, 44.49719092257398, 45.04997225304363, 45.596052460711995, 46.13566949768909, 46.669047558312144, 47.19639816765682, 47.7179211617606, 48.23380557244058, 48.74423042781577, 49.24936547814601, 49.749371855331006, 50.24440267333269, 50.7346035758633, 51.22011323689162, 51.701063818842265, 52.177581392778265, 52.64978632435274, 53.11779362887732, 53.581713298475265, 54.04165060395547, 54.497706373754845, 54.94997725204261, 55.39855593785817, 55.84353140695885, 56.28498911788116, 56.72301120356711, 57.15767664977295, 57.589061461357396, 58.01723881744115, 58.44227921633447, 58.864250611045755, 59.283218536108514, 59.6992462263972, 60.11239472854163, 60.52272300549605, 60.9302880347697, 61.33514490078263, 61.73734688177003, 62.13694553162395, 62.5339907570275, 62.928530890209096, 63.3206127576163, 63.71028174478592, 64.0975818576645, 64.48255578061404, 64.86524493131897, 65.24568951279464, 65.62392856268208, 66.0, 66.37394066951276, 66.74578638386097, 67.11557196359128, 67.48333127521197, 67.84909726739185, 68.21290200541245, 68.57477670397476, 68.93475175845636, 69.29285677470659, 69.6491205974634, 70.00357133746822, 70.35623639735145, 70.70714249635606], [0.0, 7.075485849042453, 10.006248048094749, 12.255100978776145, 14.150971698084906, 15.82126733229674, 17.331330012437014, 18.719975961523026, 20.012496096189498, 21.226457547127357, 22.374650835264447, 23.466731770743024, 24.51020195755229, 25.511027027542426, 26.474043892084186, 27.40323885966766, 28.30194339616981, 29.172975508165084, 30.018744144284252, 30.841327792428135, 31.64253466459348, 32.423949481825936, 33.18697033475638, 33.93283807759086, 34.66266002487403, 35.37742924521227, 36.07804041241708, 36.76530293632843, 37.43995192304605, 38.102657387641614, 38.754032048291435, 39.39463796000668, 40.024992192378996, 40.645571714517686, 41.256817618425195, 41.85913878712747, 42.45291509425471, 43.03850020621071, 43.616224045646135, 44.18639496496631, 44.749301670528894, 45.305214931616874, 45.854389102898324, 46.39706348466463, 46.93346354148605, 47.46380199689021, 47.988279819139166, 48.50708711106038, 49.02040391510458, 49.528400943297164, 50.03124024047376, 50.52907578810442, 51.02205405508485, 51.51031450107833, 51.99399003731104, 52.473207449135415, 52.94808778416837, 53.418746709371604, 53.88529484005818, 54.34783804347694, 54.80647771933532, 55.26131105936594, 55.71243128781941, 56.15992788456908, 56.60388679233962, 57.04439060941925, 57.48151876907916, 57.91534770680393, 58.34595101633017, 58.77339959539519, 59.197761782013345, 59.61910348202159, 60.037488288568504, 60.452977594159904, 60.86563069582044, 61.275504893880715, 61.68265558485627, 62.08713634884443, 62.4889990318296, 62.88829382325458, 63.28506932918696, 63.67937264138207, 64.07124940252064, 64.46074386787667, 64.84789896365187, 65.23275634219361, 65.61535643429822, 65.9957384987849, 66.37394066951276, 66.75, 67.12395250579334, 67.49583320472456, 67.86567615518172, 68.23351449251314, 68.59938046367475, 68.96330546022281, 69.32532004974806, 69.6854540058397, 70.04373633666324, 70.40019531222907, 70.75485849042454, 71.10775274187759], [0.0, 7.115124735378854, 10.062305898749052, 12.32375754386624, 14.230249470757707, 15.90990257669732, 17.428425057933378, 18.8248505970167, 20.124611797498105, 21.34537420613656, 22.5, 23.598199083828412, 24.64751508773248, 25.65394706473061, 26.622359023948274, 27.55675960631075, 28.460498941515414, 29.336410823411917, 30.186917696247164, 31.014109692203004, 31.81980515339464, 32.605597678926244, 33.37289319193049, 34.12293949823198, 34.856850115866756, 35.57562367689427, 36.28015986734348, 36.971272631598715, 37.6497011940334, 38.316119323334405, 38.97114317029973, 39.615337938732765, 40.24922359499621, 40.87327978031614, 41.48795005781799, 42.09364560120684, 42.69074841227312, 43.27961413876052, 43.86057455164034, 44.43393973079588, 45.0, 45.55902764546232, 46.1112784468182, 46.656993044987374, 47.196398167656824, 47.72970773009195, 48.257123826436235, 48.7788376245273, 49.29503017546496, 49.80587314765197, 50.311529493745276, 50.81215405786297, 51.30789412946122, 51.79888994949602, 52.28527517380013, 52.76717729801359, 53.24471804789655, 53.71801373840995, 54.18717560456534, 54.65231010671003, 55.1135192126215, 55.57090065852811, 56.0245481909493, 56.4745517910501, 56.92099788303083, 57.363969527918826, 57.80354660399308, 58.23980597495152, 58.672821646823834, 59.10266491453663, 59.529404498953284, 59.95310667513402, 60.37383539249433, 60.79165238747833, 61.20661728930949, 61.61878771933119, 62.02821938440601, 62.43496616480223, 62.839080196960246, 63.24061195149839, 63.63961030678928, 64.03612261840968, 64.4301947847436, 64.8218713089957, 65.21119535785249, 65.59820881700963, 65.98295234376832, 66.36546541688682, 66.74578638386097, 67.12395250579334, 67.5, 67.8739640804926, 68.24587899646396, 68.61577806889608, 68.98369372540152, 69.34965753340097, 69.71370023173351, 70.07585176078848, 70.43614129124337, 70.79459725148524, 71.15124735378853, 71.50611861931817], [0.0, 7.1545440106270926, 10.11805317242403, 12.392033731393733, 14.309088021254185, 15.998046755776157, 17.524982168321888, 18.929144196185945, 20.23610634484806, 21.46363203188128, 22.624654693497533, 23.728938029334564, 24.784067462787466, 25.796075282879762, 26.769852446362123, 27.709429802866747, 28.61817604250837, 29.498940658945703, 30.354159517272095, 31.185934329437693, 31.996093511552314, 32.786239491591594, 33.55778598179564, 34.31198770109363, 35.049964336643775, 35.772720053135465, 36.48115952104593, 37.17610119418119, 37.85828839237189, 38.52839861712397, 39.18705143283939, 39.8348151746685, 40.47221268969612, 41.09972627646077, 41.71780195552014, 42.32685317856738, 42.92726406376256, 43.51939222921202, 44.103571283967476, 44.680113025819445, 45.249309386995066, 45.81143416222636, 46.366744548221206, 46.91548251910024, 47.45787605866913, 47.99414026732847, 48.52447835886544, 49.04908256022736, 49.56813492557493, 50.08180807438965, 50.59026586212016, 51.0936639907533, 51.592150565759525, 52.085866605058996, 52.57494650496566, 53.05951846747199, 53.539704892724245, 54.01562274009252, 54.48738386085352, 54.95509530516711, 55.418859605733495, 55.878775040260145, 56.33493587464177, 56.78743258855783, 57.23635208501674, 57.68177788522126, 58.123790309992685, 58.5624666488699, 58.997881317891405, 59.43010600697259, 59.859209817704745, 60.28525939232575, 60.70831903454419, 61.12845082283699, 61.54571471678593, 61.96016865696865, 62.371868658875385, 62.78086890128234, 63.18722180947665, 63.59097813369441, 63.99218702310463, 64.39089609564384, 64.78715150398266, 65.1809979978828, 65.57247898318319, 65.96163657763503, 66.34851166378942, 66.73314393912518, 67.11557196359128, 67.49583320472458, 67.8739640804926, 68.25, 68.62397540218726, 68.99592379264155, 69.3658777786312, 69.73386910246698, 70.09992867328755, 70.46408659735825, 70.82637220696822, 71.1868140880037, 71.54544010627093, 71.9022774326377], [0.0, 7.19374728496908, 10.173494974687902, 12.459935794377115, 14.38749456993816, 16.085707942145415, 17.621010186706098, 19.03286631067428, 20.346989949375804, 21.58124185490724, 22.748626332154654, 23.858960580880304, 24.91987158875423, 25.937424698685877, 26.916537667389544, 27.861263431510064, 28.77498913987632, 29.660579899927782, 30.52048492406371, 31.356817440550316, 32.17141588429083, 32.96589146375387, 33.74166563760598, 34.50000000000001, 35.242020373412196, 35.9687364248454, 36.68105778191246, 37.37980738313134, 38.06573262134856, 38.739514710434875, 39.40177660969109, 40.05308976845607, 40.69397989875161, 41.32493194186774, 41.94639436232869, 42.55878287733332, 43.16248370981448, 43.75785643744447, 44.34523649728346, 44.92493739561582, 45.49725266430931, 46.06245759835227, 46.62081080376017, 47.172555580549165, 47.71792116176061, 48.257123826436235, 48.79036790187178, 49.31784666832079, 49.83974317750846, 50.35623099478356, 50.86747487343952, 51.37363136863114, 51.874849397371754, 52.371270750288275, 52.8630305601183, 53.35025773133623, 53.83307533477909, 54.31160097069502, 54.785947103249036, 55.256221369181596, 55.72252686302013, 56.18496240098413, 56.643622765497625, 57.098598932022846, 57.54997827975264, 57.99784478754362, 58.44227921633447, 58.883359279171565, 59.321159799855565, 59.75575286112627, 60.18720794321664, 60.61559205353026, 61.04096984812742, 61.46340374564364, 61.88295403420881, 62.29967897188557, 62.71363488110063, 63.12487623750244, 63.53345575364213, 63.939424457841355, 64.34283176858166, 64.74372556472173, 65.14215225182541, 65.53815682486044, 65.93178292750774, 66.32307290830244, 66.71206787381126, 67.09880773903514, 67.48333127521197, 67.86567615518172, 68.24587899646396, 68.62397540218724, 69.00000000000001, 69.37398647908307, 69.74596762537604, 70.11597535512145, 70.48404074682439, 70.85019407171728, 71.21446482281532, 71.57688174264091, 71.9374728496908, 72.29626546371536], [0.0, 7.232738070744717, 10.228636272739392, 12.527469816367553, 14.465476141489434, 16.17289398963587, 17.716517716526578, 19.13602623325961, 20.457272545478784, 21.698214212234152, 22.87192602296536, 23.988278387579218, 25.054939632735106, 26.07800797607057, 27.062427829003077, 28.01227409547465, 28.93095228297887, 29.821343028106565, 30.68590881821818, 31.52677433547556, 32.34578797927174, 33.14456969097654, 33.92454863369593, 34.686993239541536, 35.433035433053156, 36.16369035372359, 36.87987255943275, 37.58240944910265, 38.27205246651922, 38.94948651779636, 39.61533793873277, 40.2701812759764, 40.91454509095757, 41.54891695339363, 42.17374775852865, 42.78945547678774, 43.396428424468304, 43.9950281281874, 44.585591843105554, 45.16843477474065, 45.74385204593072, 46.3121204437888, 46.873499975999245, 47.428235261287135, 47.976556775158436, 48.51868196890761, 49.054816277303495, 49.58515402819679, 50.10987926547021, 50.62916649521301, 51.14318136369697, 51.65208127462049, 52.15601595214114, 52.65512795540431, 53.14955314957973, 53.63942113781618, 54.124855658006155, 54.60597494780219, 55.08289208093563, 55.55571527754818, 56.0245481909493, 56.48949017295165, 56.950636519708894, 57.408078699778834, 57.86190456595774, 58.3121985522755, 58.75904185740268, 59.20251261559766, 59.64268605621313, 60.0796346526841, 60.51342826183293, 60.944134254249605, 61.37181763643636, 61.796541165343555, 62.218365455868415, 62.63734908183775, 63.05354867095112, 63.46701899412009, 63.87781304960277, 64.28598214229912, 64.69157595854348, 65.09464263670246, 65.49522883386241, 65.89337978886802, 66.28913938195308, 66.68255019118571, 67.07365354593412, 67.46248957754229, 67.84909726739185, 68.23351449251314, 68.61577806889608, 68.99592379264155, 69.37398647908307, 69.75000000000001, 70.12399731903481, 70.4960105254191, 70.86607086610631, 71.23420877640181, 71.60045390917574, 71.96483516273766, 72.32738070744718, 72.68811801113027], [0.0, 7.271519786124494, 10.283481900601567, 12.594641717810003, 14.543039572248988, 16.2596125415091, 17.81151313055688, 19.23863300757099, 20.566963801203133, 21.814559358373483, 22.99456457513384, 24.116902786220294, 25.189283435620005, 26.217837439422805, 27.207535720825586, 28.16247503327788, 29.086079144497976, 29.981244136960026, 30.850445701804702, 31.695819913673166, 32.5192250830182, 33.3222898372846, 34.10645100270622, 34.87298381268801, 35.62302626111376, 36.35759893062247, 37.07762128292483, 37.78392515343, 38.47726601514198, 39.158332446619845, 39.82775414205526, 40.48610872879734, 41.13392760240627, 41.77170094693297, 42.39988207530771, 43.01889119909996, 43.629118716746966, 44.2309280933602, 44.82465839245181, 45.41062650966182, 45.98912915026768, 46.560444585506275, 47.12483421721503, 47.682543975757, 48.23380557244059, 48.7788376245273, 49.31784666832079, 49.851028073651605, 50.37856687124001, 50.90063850287146, 51.41740950300784, 51.92903811934129, 52.43567487884561, 52.93746310506389, 53.43453939167064, 53.92703403674266, 54.41507144165117, 54.8987704780353, 55.378244825924206, 55.85360328573261, 56.32495006655576, 56.792385052927656, 57.256004051976944, 57.71589902271297, 58.17215828899595, 58.62486673758841, 59.07410600254565, 59.519954637079486, 59.96248827392005, 60.40177977510265, 60.83789937201974, 61.27091479650031, 61.700891403609404, 62.12789228679821, 62.55197838597913, 62.973208589049996, 63.39163982734633, 63.80732716545961, 64.22032388582295, 64.63068156843158, 65.0384501660364, 65.44367807512045, 65.84641220294392, 66.24669803092077, 66.6445796745692, 67.04009994025965, 67.43330037896708, 67.82422133721848, 68.21290200541245, 68.59938046367475, 68.98369372540152, 69.36587777863119, 69.74596762537603, 70.12399731903481, 70.50000000000001, 70.8740079295647, 71.24605252222752, 71.61616437648698, 71.98437330421096, 72.35070835866088, 72.71519786124495, 73.07786942707075], [0.0, 7.310095758606723, 10.338036564067664, 12.661457262100601, 14.620191517213446, 16.345871038277526, 17.906004579469982, 19.340695437341438, 20.67607312813533, 21.930287275820167, 23.11655251113366, 24.24484481286692, 25.322914524201202, 26.35692508620837, 27.351873793215702, 28.311879132265307, 29.24038303442689, 30.140296946115175, 31.014109692202997, 31.863968679372007, 32.69174207655505, 33.49906715119094, 34.28738835198738, 35.05798767756073, 35.812009158939965, 36.55047879303361, 37.27432091936753, 37.98437178630179, 38.681390874682876, 39.36607041603213, 40.03904344511741, 40.7008906536454, 41.35214625627066, 41.993303037508255, 42.62481671514846, 43.24710973001548, 43.86057455164033, 44.46557657334491, 45.06245665739941, 45.65153338059961, 46.23310502226732, 46.80745132988977, 47.374835092061275, 47.935503543824375, 48.48968962573384, 49.03761311483257, 49.57948164311522, 50.11549161686434, 50.645829048402405, 51.170670310247054, 51.690182820338336, 52.20452566588457, 52.71385017241674, 53.218300423820374, 53.71801373840995, 54.2131211055036, 54.703747586431405, 55.190012683455684, 55.672030679686905, 56.14991095273437, 56.623758264530615, 57.093673029504764, 57.55975156304967, 58.022086312024314, 58.48076606885378, 58.93587617063141, 59.387498684487454, 59.83571258036457, 60.28059389223035, 60.72221586865881, 61.16064911362533, 61.595961718281494, 62.02821938440599, 62.457485540165635, 62.88382144876375, 63.30728631050299, 63.727937358744015, 64.14582995020018, 64.56101764997204, 64.97355231169064, 65.3834841531101, 65.7908618274605, 66.19573249084868, 66.598141865971, 66.99813430238189, 67.39575283354286, 67.79103923086001, 68.18403405490174, 68.57477670397476, 68.96330546022283, 69.34965753340099, 69.73386910246698, 70.11597535512146, 70.4960105254191, 70.8740079295647, 71.24999999999999, 71.62401831787993, 71.99609364403044, 72.36625594847365, 72.73453443860076, 73.10095758606722, 73.46555315248092], [0.0, 7.3484692283495345, 10.392304845413264, 12.727922061357859, 14.696938456699069, 16.431676725154986, 18.000000000000004, 19.44222209522358, 20.784609690826528, 22.045407685048605, 23.237900077244504, 24.372115213907882, 25.455844122715718, 26.495282598983543, 27.495454169735044, 28.46049894151541, 29.393876913398138, 30.298514815086232, 31.176914536239792, 32.03123475609394, 32.86335345030997, 33.67491648096548, 34.46737587922817, 35.242020373412196, 36.00000000000001, 36.742346141747674, 37.46998799039039, 38.18376618407357, 38.88444419044716, 39.57271787481876, 40.24922359499621, 40.91454509095757, 41.569219381653056, 42.21374183841087, 42.8485705712571, 43.474130238568314, 44.09081537009721, 44.69899327725402, 45.299006611624506, 45.89117562233507, 46.47580015448901, 47.053161424074375, 47.62352359916264, 48.187135212627034, 48.744230427815765, 49.29503017546495, 49.839743177508446, 50.37856687124, 50.911688245431435, 51.43928459844674, 51.96152422706633, 52.47856705360771, 52.990565197967086, 53.49766350038102, 54.00000000000001, 54.49770637375486, 54.99090833947009, 55.47972602672079, 55.9642743185329, 56.44466316668034, 56.92099788303082, 57.39337940912697, 57.86190456595773, 58.32666628567074, 58.787753826796276, 59.2452529743945, 59.69924622639719, 60.14981296729026, 60.597029630172464, 61.04096984812741, 61.48170459575759, 61.91930232165088, 62.353829072479584, 62.78534860936905, 63.21392251711644, 63.63961030678928, 64.06246951218787, 64.48255578061404, 64.89992295835182, 65.31462317123173, 65.72670690061994, 66.13622305514582, 66.54321903845651, 66.9477408132642, 67.34983296193096, 67.7495387438173, 68.14690014960328, 68.54195795277518, 68.93475175845634, 69.32532004974806, 69.71370023173351, 70.09992867328754, 70.48404074682439, 70.86607086610631, 71.24605252222752, 71.62401831787993, 72.00000000000001, 72.37402849088892, 72.74613391789285, 73.11634564172365, 73.48469228349535, 73.85120175054703], [0.0, 7.38664335134708, 10.44629120788809, 12.79404158192399, 14.77328670269416, 16.517036659158933, 18.093507122722233, 19.543221331193074, 20.89258241577618, 22.159930054041237, 23.358617253596158, 24.498724456591617, 25.58808316384798, 26.63292135684706, 27.638288659032423, 28.608346684140976, 29.54657340538832, 30.45591075637043, 31.338873623664274, 32.19763190049853, 33.034073318317866, 33.84985228919028, 34.646428387353296, 35.42509703585864, 36.187014245444466, 36.9332167567354, 37.66463858846917, 38.38212474577196, 39.08644266238615, 39.77829181852836, 40.45831187778353, 41.127089612565584, 41.78516483155236, 42.433035479446914, 43.07116204608369, 43.69997139587165, 44.31986010808247, 44.93119740225048, 45.53432770998163, 46.12957294404535, 46.717234507192316, 47.2975950762827, 47.87092019169886, 48.43745967740257, 48.997448913183234, 49.55110997747679, 50.09865267649421, 50.64027547318439, 51.17616632769596, 51.706503459429555, 52.23145603944046, 52.751184820817066, 53.26584271369412, 53.77557531073006, 54.280521368166696, 54.780813246975455, 55.276577318064845, 55.76793433506391, 56.25499977779754, 56.737884169221545, 57.21669336828195, 57.69152884089657, 58.162487911023895, 58.62966399357923, 59.09314681077664, 59.55302259331596, 60.00937426769254, 60.462281630782016, 60.91182151274086, 61.35806792916479, 61.801092223358, 62.24096319948785, 62.67774724732855, 63.11150845923428, 63.54230873992541, 63.97020790961994, 64.39526380099706, 64.81753235043742, 65.23706768394793, 65.65392219814443, 66.06814663663573, 66.47979016212372, 66.88890042450991, 67.29552362527541, 67.69970457838056, 68.10148676791133, 68.50091240268264, 68.89802246799252, 69.29285677470659, 69.6854540058397, 70.07585176078847, 70.46408659735823, 70.85019407171728, 71.23420877640181, 71.61616437648698, 71.99609364403044, 72.37402849088893, 72.75000000000001, 73.12403845521663, 73.49617336977485, 73.8664335134708, 74.23484693861772], [0.0, 7.4246212024587495, 10.499999999999998, 12.859821149611687, 14.849242404917499, 16.60195771588399, 18.186533479473212, 19.643701280563192, 20.999999999999996, 22.273863607376246, 23.47871376374779, 24.624682739073005, 25.719642299223374, 26.769852446362123, 27.780388766178202, 28.75543426902122, 29.698484809834998, 30.612497447937827, 31.5, 32.36317351558713, 33.20391543176798, 34.02388866664127, 34.8245602987317, 35.60723241140766, 36.373066958946424, 37.123106012293746, 37.85828839237189, 38.57946344883506, 39.287402561126385, 39.98280880578552, 40.66632513517787, 41.338541338562, 41.99999999999999, 42.651201624338796, 43.292609068985435, 43.924651393038964, 44.54772721475249, 45.16220765197379, 45.76843890717708, 46.3667445482212, 46.95742752749558, 47.54077197522144, 48.11704479703633, 48.686497101352444, 49.24936547814601, 49.80587314765197, 50.35623099478355, 50.90063850287145, 51.43928459844675, 51.97234841721124, 52.50000000000001, 53.02240092640091, 53.539704892724245, 54.05205824018175, 54.55960043841964, 55.06246452893296, 55.560777532356404, 56.05466082316438, 56.5442304749123, 57.02959757880113, 57.51086853804244, 57.98814534023312, 58.46152580971523, 58.93110384168957, 59.396969619669996, 59.859209817704745, 60.31790778864929, 60.77314373964868, 61.22499489587565, 61.67353565347133, 62.11883772254597, 62.56097026101817, 63.0, 63.4359913613715, 63.869006568131304, 64.29910574805842, 64.72634703117426, 65.150786641452, 65.57247898318319, 65.99147672237682, 66.40783086353596, 66.82159082212874, 67.23280449304492, 67.64151831530691, 68.04777733328254, 68.45162525462781, 68.853104505171, 69.25225628093283, 69.6491205974634, 70.04373633666326, 70.43614129124337, 70.82637220696822, 71.21446482281532, 71.60045390917576, 71.98437330421098, 72.36625594847365, 72.74613391789285, 73.12403845521663, 73.5, 73.87404821721903, 74.24621202458749, 74.61651961864746], [0.0, 7.46240577829965, 10.553435459602717, 12.925265954710568, 14.9248115565993, 16.686446595965243, 18.279086410430914, 19.743669871632274, 21.106870919205434, 22.387217334898953, 23.598199083828412, 24.750000000000004, 25.850531909421136, 26.90608667197815, 27.92176570347943, 28.90177330199654, 29.8496231131986, 30.768287245149022, 31.660306378808155, 32.52787266330217, 33.37289319193049, 34.197039345534, 35.00178566873411, 35.788440871320454, 36.55817282086183, 37.31202889149826, 38.05095268189747, 38.7757978641317, 39.48733974326455, 40.186284973856445, 40.87327978031614, 41.54891695339362, 42.21374183841087, 42.86825748732972, 43.512929113080865, 44.14818795828431, 44.774434669797905, 45.39204225412204, 46.00135867558697, 46.60270914871796, 47.196398167656824, 47.782711308589434, 48.36191683546053, 48.93426713459598, 49.50000000000001, 50.05933978789572, 50.612498456408964, 51.159676504059334, 51.70106381884227, 52.23684044809755, 52.76717729801359, 53.29223677047156, 53.8121733439563, 54.327134104423365, 54.83725923129274, 55.342682443119806, 55.84353140695886, 56.33992811497012, 56.83198923141791, 57.31982641285649, 57.80354660399308, 58.28325231144879, 58.759041857402686, 59.23100961489683, 59.6992462263972, 60.16383880704422, 60.62487113388366, 61.08242382224203, 61.536574490298044, 61.987397912801605, 62.43496616480224, 62.87934875616954, 63.32061275761631, 63.758822918871395, 64.19404177959198, 64.62632977355283, 65.05574532660434, 65.48234494884862, 65.90618332144567, 66.32731337842655, 66.74578638386097, 67.16165200469686, 67.57495837956544, 67.98575218382159, 68.394078691068, 68.79998183139296, 69.20350424653365, 69.6046873421611, 70.00357133746822, 70.40019531222907, 70.79459725148523, 71.18681408800369, 71.57688174264091, 71.96483516273766, 72.35070835866088, 72.73453443860076, 73.11634564172365, 73.49617336977485, 73.87404821721901, 74.25000000000001, 74.62405778299652, 74.99624990624532], [0.0, 7.500000000000001, 10.606601717798213, 12.990381056766582, 15.000000000000002, 16.770509831248425, 18.371173070873837, 19.84313483298443, 21.213203435596427, 22.5, 23.717082451262847, 24.874685927665503, 25.980762113533164, 27.041634565979923, 28.062430400804566, 29.047375096555626, 30.000000000000004, 30.923292192132454, 31.819805153394643, 32.69174207655506, 33.54101966249685, 34.36931771216881, 35.178118198675726, 35.9687364248454, 36.742346141747674, 37.50000000000001, 38.24264635194589, 38.97114317029974, 39.68626966596886, 40.38873605350879, 41.07919181288746, 41.75823272122516, 42.42640687119285, 43.08421984903522, 43.73213921133976, 44.37059837324712, 45.0, 45.62071897723665, 46.23310502226733, 46.83748498798799, 47.434164902525694, 48.02343178074637, 48.60555523805896, 49.180788932265, 49.749371855331006, 50.31152949374527, 50.86747487343951, 51.41740950300783, 51.96152422706633, 52.5, 53.03300858899107, 53.560713214071384, 54.083269131959845, 54.60082416960389, 55.11351921262152, 55.62148865321748, 56.12486080160913, 56.62375826453062, 57.11829829397932, 57.60859310901456, 58.09475019311125, 58.57687256929991, 59.055059055088584, 59.52940449895329, 60.00000000000001, 60.466933112239126, 60.9302880347697, 61.39014578904337, 61.84658438426491, 62.29967897188556, 62.74950199005567, 63.19612329882269, 63.63961030678929, 64.08002808988148, 64.5174395028197, 64.9519052838329, 65.38348415311012, 65.81223290544092, 66.23820649745886, 66.66145812986693, 67.0820393249937, 67.50000000000001, 67.91538853603063, 68.32825184358225, 68.73863542433762, 69.14658342969666, 69.55213871621778, 69.95534289816612, 70.35623639735145, 70.75485849042454, 71.15124735378853, 71.54544010627092, 71.9374728496908, 72.32738070744718, 72.71519786124495, 73.10095758606722, 73.48469228349535, 73.8664335134708, 74.24621202458749, 74.6240577829965, 75.00000000000001, 75.37406715840669], [0.0, 7.537406715840668, 10.659502802663923, 13.055171389146912, 15.074813431681337, 16.854153790683178, 18.462800437636762, 19.942103700462496, 21.319005605327845, 22.612220147522006, 23.835372873106056, 24.99874996874844, 26.110342778293823, 27.176506397990163, 28.202393515444754, 29.192250684042847, 30.149626863362673, 31.077524032650995, 31.97850840799177, 32.85479417071427, 33.708307581366356, 34.54073681900837, 35.35357124817803, 36.14813273185768, 36.925600875273524, 37.687033579203344, 38.43338392595688, 39.165514167440726, 39.88420740092499, 40.59017738320443, 41.284076833568655, 41.96650450061335, 42.63801121065569, 43.299105071583185, 43.95025597195084, 44.59189948858425, 45.22444029504401, 45.84825514673378, 46.463695505200626, 47.071089853539625, 47.67074574621211, 48.26295162958852, 48.847978463801354, 49.42608117178622, 49.99749993749688, 50.562461372049526, 51.12117956385592, 51.673857026546806, 52.22068555658765, 52.76184701088468, 53.29751401331962, 53.827850597994356, 54.35301279598033, 54.87314917152104, 55.38840131291028, 55.89890428264226, 56.40478703088951, 56.90617277589489, 57.40317935445738, 57.89591954533584, 58.384501368085694, 58.869028359571224, 59.34959983015893, 59.826311101387496, 60.29925372672535, 60.76851569686396, 61.23418163085059, 61.69633295423643, 62.15504806530199, 62.61040249032105, 63.06246902873373, 63.51131788901881, 63.95701681598354, 64.39963121012418, 64.83922423965296, 65.27585694573455, 65.70958834142854, 66.14047550479208, 66.56857366655832, 66.99393629277206, 67.41661516273271, 67.83666044256601, 68.25412075472076, 68.66904324366259, 69.08147363801675, 69.49145630939103, 69.89903432809356, 70.30424951594321, 70.70714249635606, 71.1077527418776, 71.50611861931817, 71.9022774326377, 72.29626546371536, 72.68811801113029, 73.07786942707075, 73.46555315248092, 73.85120175054705, 74.23484693861774, 74.61651961864746, 74.99624990624532, 75.37406715840669, 75.75000000000001]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"A = 8.0\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.8, 1.131370849898476, 1.385640646055102, 1.6, 1.788854381999832, 1.9595917942265426, 2.1166010488516727, 2.262741699796952, 2.4, 2.5298221281347035, 2.65329983228432, 2.771281292110204, 2.8844410203711917, 2.9933259094191533, 3.098386676965933, 3.2, 3.2984845004941286, 3.394112549695428, 3.4871191548325395, 3.577708763999664, 3.6660605559646724, 3.752332607858744, 3.836665218650176, 3.9191835884530852, 4.0, 4.079215610874228, 4.156921938165306, 4.233202097703345, 4.308131845707604, 4.381780460041329, 4.454211490264018, 4.525483399593904, 4.595650117230424, 4.664761515876241, 4.732863826479693, 4.8, 4.866210024238576, 4.931531202375181, 4.9959983987187195, 5.059644256269407, 5.122499389946279, 5.184592558726289, 5.2459508194416005, 5.30659966456864, 5.366563145999495, 5.4258639865002145, 5.4845236803208355, 5.542562584220408, 5.6000000000000005, 5.656854249492381, 5.713142742834281, 5.768882040742383, 5.8240879114244155, 5.878775382679628, 5.932958789676531, 5.986651818838307, 6.0398675482166, 6.092618484691127, 6.144916598294887, 6.196773353931866, 6.248199740725323, 6.299206299209448, 6.3498031465550175, 6.4, 6.449806198638839, 6.499230723708768, 6.5482822174979605, 6.596969000988257, 6.64529909033446, 6.6932802122726045, 6.740919818541087, 6.788225099390856, 6.835202996254025, 6.881860213634101, 6.92820323027551, 6.974238309665079, 7.019971509913698, 7.065408693062278, 7.110555533852471, 7.155417527999328, 7.2, 7.244308110509934, 7.288346863315439, 7.332121111929345, 7.37563556583431, 7.418894796396564, 7.4619032424710525, 7.504665215717488, 7.547184905645283, 7.58946638440411, 7.631513611335565, 7.673330437300352, 7.7149206087943645, 7.756287771866127, 7.797435475847171, 7.8383671769061705, 7.879086241436885, 7.919595949289333, 7.959899496852961, 8.0, 8.039900496896713], [0.0, 1.131370849898476, 1.5999999999999999, 1.9595917942265426, 2.262741699796952, 2.5298221281347035, 2.7712812921102037, 2.993325909419153, 3.1999999999999997, 3.394112549695428, 3.5777087639996634, 3.752332607858744, 3.9191835884530852, 4.079215610874228, 4.233202097703344, 4.381780460041329, 4.525483399593904, 4.66476151587624, 4.8, 4.931531202375181, 5.059644256269407, 5.184592558726289, 5.3065996645686395, 5.4258639865002145, 5.542562584220407, 5.656854249492381, 5.768882040742383, 5.878775382679628, 5.986651818838306, 6.092618484691127, 6.196773353931866, 6.299206299209449, 6.3999999999999995, 6.499230723708768, 6.596969000988257, 6.6932802122726045, 6.788225099390856, 6.881860213634101, 6.974238309665078, 7.0654086930622775, 7.155417527999327, 7.244308110509934, 7.332121111929345, 7.418894796396562, 7.504665215717488, 7.589466384404109, 7.6733304373003515, 7.756287771866126, 7.8383671769061705, 7.919595949289332, 8.0, 8.079603950689663, 8.158431221748456, 8.236504112789602, 8.313843876330612, 8.390470785361213, 8.466404195406689, 8.541662601625049, 8.616263691415206, 8.690224392960172, 8.763560920082657, 8.836288813749809, 8.908422980528034, 8.97997772825746, 9.050966799187808, 9.121403400793103, 9.191300234460845, 9.26066952223218, 9.32952303175248, 9.397872099576585, 9.465727652959385, 9.533100230250387, 9.6, 9.666436778875658, 9.73242004847715, 9.797958971132712, 9.863062404750362, 9.927738916792686, 9.991996797437437, 10.055844071981229, 10.119288512538814, 10.182337649086284, 10.244998779892558, 10.3072789813801, 10.369185117452577, 10.430723848324238, 10.491901638883201, 10.552724766618335, 10.613199329137279, 10.673331251301066, 10.73312629199899, 10.792590050585632, 10.851727973000429, 10.910545357588685, 10.969047360641671, 11.027239001672177, 11.085125168440815, 11.142710621747296, 11.2, 11.256997823576231, 11.313708498984761, 11.370136322841518], [0.0, 1.385640646055102, 1.9595917942265426, 2.400000000000001, 2.771281292110204, 3.098386676965934, 3.3941125496954285, 3.6660605559646724, 3.9191835884530852, 4.156921938165306, 4.3817804600413295, 4.595650117230424, 4.800000000000002, 4.9959983987187195, 5.184592558726289, 5.366563145999495, 5.542562584220408, 5.713142742834281, 5.8787753826796285, 6.039867548216601, 6.196773353931868, 6.349803146555018, 6.499230723708769, 6.645299090334461, 6.788225099390857, 6.9282032302755105, 7.065408693062279, 7.200000000000001, 7.332121111929345, 7.461903242471053, 7.589466384404111, 7.714920608794365, 7.8383671769061705, 7.9598994968529615, 8.079603950689664, 8.19756061276768, 8.313843876330612, 8.428523002282192, 8.54166260162505, 8.653323061113577, 8.763560920082659, 8.872429205127535, 8.979977728257461, 9.086253353280439, 9.191300234460847, 9.2951600308978, 9.397872099576587, 9.499473669630335, 9.600000000000003, 9.699484522385713, 9.797958971132713, 9.895453501482388, 9.991996797437439, 10.087616170334796, 10.182337649086286, 10.276186062932105, 10.369185117452577, 10.461357464497619, 10.552724766618338, 10.643307756520057, 10.73312629199899, 10.822199406774947, 10.910545357588685, 10.998181667894018, 11.085125168440817, 11.171392035015154, 11.256997823576233, 11.341957503006261, 11.426285485668561, 11.50999565595053, 11.593101396951553, 11.67561561546114, 11.757550765359257, 11.838918869558995, 11.919731540601072, 12.000000000000002, 12.079735096433202, 12.158947322856532, 12.237646832622687, 12.315843454672525, 12.393546707863736, 12.470765814495918, 12.5475097130865, 12.623787070447602, 12.699606293110037, 12.774975538137053, 12.84990272336721, 12.924395537122813, 12.998461447417538, 13.072107710694555, 13.145341380123988, 13.218169313486646, 13.290598180668923, 13.362634470792056, 13.434284498997334, 13.505554412907307, 13.576450198781714, 13.646977687385588, 13.717142559585799, 13.78695035169127, 13.856406460551021, 13.925516148423371], [0.0, 1.6, 2.262741699796952, 2.771281292110204, 3.2, 3.577708763999664, 3.9191835884530852, 4.233202097703345, 4.525483399593904, 4.8, 5.059644256269407, 5.30659966456864, 5.542562584220408, 5.768882040742383, 5.986651818838307, 6.196773353931866, 6.4, 6.596969000988257, 6.788225099390856, 6.974238309665079, 7.155417527999328, 7.332121111929345, 7.504665215717488, 7.673330437300352, 7.8383671769061705, 8.0, 8.158431221748456, 8.313843876330612, 8.46640419540669, 8.616263691415208, 8.763560920082657, 8.908422980528035, 9.050966799187808, 9.191300234460847, 9.329523031752482, 9.465727652959385, 9.6, 9.732420048477152, 9.863062404750362, 9.991996797437439, 10.119288512538814, 10.244998779892558, 10.369185117452577, 10.491901638883201, 10.61319932913728, 10.73312629199899, 10.851727973000429, 10.969047360641671, 11.085125168440817, 11.200000000000001, 11.313708498984761, 11.426285485668561, 11.537764081484767, 11.648175822848831, 11.757550765359255, 11.865917579353061, 11.973303637676613, 12.0797350964332, 12.185236969382254, 12.289833196589774, 12.393546707863733, 12.496399481450647, 12.598412598418896, 12.699606293110035, 12.8, 12.899612397277679, 12.998461447417537, 13.096564434995921, 13.193938001976514, 13.29059818066892, 13.386560424545209, 13.481839637082174, 13.576450198781712, 13.67040599250805, 13.763720427268202, 13.85640646055102, 13.948476619330158, 14.039943019827396, 14.130817386124557, 14.221111067704943, 14.310835055998655, 14.4, 14.488616221019868, 14.576693726630879, 14.66424222385869, 14.75127113166862, 14.837789592793127, 14.923806484942105, 15.009330431434975, 15.094369811290566, 15.17893276880822, 15.26302722267113, 15.346660874600705, 15.429841217588729, 15.512575543732254, 15.594870951694341, 15.676734353812341, 15.75817248287377, 15.839191898578665, 15.919798993705921, 16.0, 16.079800993793427], [0.0, 1.788854381999832, 2.5298221281347035, 3.098386676965934, 3.577708763999664, 4.000000000000001, 4.3817804600413295, 4.732863826479694, 5.059644256269407, 5.366563145999495, 5.656854249492381, 5.9329587896765315, 6.196773353931868, 6.44980619863884, 6.6932802122726045, 6.928203230275509, 7.155417527999328, 7.37563556583431, 7.589466384404111, 7.7974354758471724, 8.000000000000002, 8.19756061276768, 8.390470785361213, 8.579044235810889, 8.763560920082659, 8.94427190999916, 9.121403400793104, 9.295160030897803, 9.465727652959387, 9.633275663033837, 9.797958971132713, 9.959919678390987, 10.119288512538814, 10.276186062932105, 10.43072384832424, 10.583005244258363, 10.73312629199899, 10.881176406988356, 11.027239001672179, 11.171392035015154, 11.313708498984761, 11.454256850621084, 11.593101396951553, 11.730302638892145, 11.865917579353063, 12.0, 12.132600710482482, 12.263767773404714, 12.393546707863736, 12.521980673998824, 12.649110640673518, 12.774975538137053, 12.89961239727768, 13.023056476879768, 13.145341380123988, 13.266499161421601, 13.386560424545209, 13.505554412907307, 13.623509092741124, 13.740451229854134, 13.856406460551018, 13.971399357258385, 14.085453489327207, 14.198591479439079, 14.310835055998655, 14.422205101855956, 14.532721699667961, 14.642404174178502, 14.75127113166862, 14.85934049680537, 14.966629547095767, 15.07315494513342, 15.178932768808222, 15.28397853963424, 15.388307249337076, 15.491933384829668, 15.594870951694345, 15.697133496278868, 15.798734126505202, 15.899685531481435, 16.000000000000004, 16.09968943799849, 16.19876538505327, 16.29723902997069, 16.39512122553536, 16.492422502470642, 16.58915308266218, 16.68532289169137, 16.780941570722426, 16.87601848778319, 16.970562748477143, 17.064583206161235, 17.158088471621777, 17.25108692227826, 17.343586710943043, 17.435595774162696, 17.527121840165318, 17.618172436436197, 17.708754896942924, 17.798876369029593, 17.88854381999832, 17.97776404339539], [0.0, 1.9595917942265426, 2.7712812921102037, 3.3941125496954285, 3.9191835884530852, 4.3817804600413295, 4.800000000000001, 5.184592558726289, 5.542562584220407, 5.878775382679628, 6.196773353931867, 6.499230723708769, 6.788225099390857, 7.065408693062278, 7.332121111929344, 7.58946638440411, 7.8383671769061705, 8.079603950689663, 8.313843876330612, 8.54166260162505, 8.763560920082659, 8.97997772825746, 9.191300234460847, 9.397872099576585, 9.600000000000001, 9.797958971132713, 9.991996797437439, 10.182337649086286, 10.369185117452577, 10.552724766618336, 10.73312629199899, 10.910545357588685, 11.085125168440815, 11.256997823576233, 11.426285485668561, 11.593101396951552, 11.757550765359255, 11.919731540601072, 12.0797350964332, 12.237646832622685, 12.393546707863734, 12.5475097130865, 12.699606293110037, 12.849902723367208, 12.998461447417538, 13.145341380123986, 13.29059818066892, 13.434284498997332, 13.576450198781714, 13.717142559585797, 13.85640646055102, 13.994284547628723, 14.130817386124557, 14.266043600101609, 14.4, 14.532721699667961, 14.664242223858688, 14.794593607125543, 14.923806484942105, 15.051910177781423, 15.17893276880822, 15.304901175767194, 15.429841217588727, 15.553777676178866, 15.676734353812341, 15.798734126505199, 15.91979899370592, 16.039950124610737, 16.159207901379325, 16.277591959500644, 16.39512122553536, 16.511813952440235, 16.627687752661224, 16.74275962916508, 16.85704600456438, 16.970562748477143, 17.0833252032501, 17.195348208163743, 17.30664612222715, 17.417232845661793, 17.527121840165318, 17.636326148038883, 17.74485841025507, 17.852730883537117, 17.95995545651492, 18.066543665017946, 18.172506706560878, 18.277855454073382, 18.382600468921694, 18.48675201326615, 18.5903200617956, 18.693314312876677, 18.79574419915317, 18.897618897628348, 18.99894733926067, 19.099738218101315, 19.200000000000003, 19.299740930903713, 19.398969044771427, 19.497692171126307, 19.595917942265427, 19.693653800145878], [0.0, 2.1166010488516727, 2.993325909419153, 3.6660605559646724, 4.233202097703345, 4.732863826479694, 5.184592558726289, 5.6000000000000005, 5.986651818838306, 6.3498031465550175, 6.6932802122726045, 7.019971509913698, 7.332121111929345, 7.631513611335566, 7.919595949289333, 8.197560612767678, 8.46640419540669, 8.726969691708572, 8.97997772825746, 9.226050075736637, 9.465727652959387, 9.699484522385713, 9.927738916792686, 10.150862032359617, 10.369185117452577, 10.583005244258363, 10.792590050585634, 10.998181667894016, 11.200000000000001, 11.398245479020007, 11.59310139695155, 11.784735890124988, 11.973303637676612, 12.158947322856532, 12.341798896433211, 12.521980673998822, 12.699606293110035, 12.874781551544865, 13.047605144240073, 13.218169313486646, 13.386560424545209, 13.552859476877934, 13.717142559585799, 13.879481258317977, 14.039943019827396, 14.198591479439077, 14.35548675594109, 14.510685717773644, 14.66424222385869, 14.816207341961707, 14.966629547095767, 15.11555490215295, 15.263027222671132, 15.40908822740658, 15.553777676178866, 15.697133496278868, 15.839191898578665, 15.979987484350543, 16.119553343687908, 16.25792114632126, 16.395121225535355, 16.53118265581746, 16.666133324799727, 16.8, 16.93280839081338, 17.06458320616123, 17.195348208163743, 17.325126262166172, 17.453939383417143, 17.58180878066873, 17.708754896942924, 17.834797447686363, 17.95995545651492, 18.084247288731703, 18.207690682785667, 18.33030277982336, 18.452100151473275, 18.57309882599024, 18.69331431287668, 18.812761626087756, 18.931455305918774, 19.04940943966505, 19.166637681137505, 19.28315326911032, 19.398969044771427, 19.51409746824075, 19.628550634216477, 19.742340286804907, 19.855477833585372, 19.967974358957896, 20.079840636817814, 20.19108714259834, 20.301724064719235, 20.41176131547692, 20.52120854140906, 20.6300751331642, 20.738370234905155, 20.846102753272614, 20.95328136593407, 21.059914529741096, 21.166010488516726, 21.271577280493332], [0.0, 2.262741699796952, 3.1999999999999997, 3.9191835884530852, 4.525483399593904, 5.059644256269407, 5.542562584220407, 5.986651818838306, 6.3999999999999995, 6.788225099390856, 7.155417527999327, 7.504665215717488, 7.8383671769061705, 8.158431221748456, 8.466404195406689, 8.763560920082657, 9.050966799187808, 9.32952303175248, 9.6, 9.863062404750362, 10.119288512538814, 10.369185117452577, 10.613199329137279, 10.851727973000429, 11.085125168440815, 11.313708498984761, 11.537764081484767, 11.757550765359255, 11.973303637676612, 12.185236969382254, 12.393546707863733, 12.598412598418898, 12.799999999999999, 12.998461447417537, 13.193938001976514, 13.386560424545209, 13.576450198781712, 13.763720427268202, 13.948476619330156, 14.130817386124555, 14.310835055998654, 14.488616221019868, 14.66424222385869, 14.837789592793124, 15.009330431434975, 15.178932768808219, 15.346660874600703, 15.512575543732252, 15.676734353812341, 15.839191898578663, 16.0, 16.159207901379325, 16.316862443496913, 16.473008225579203, 16.627687752661224, 16.780941570722426, 16.932808390813378, 17.083325203250098, 17.232527382830412, 17.380448785920343, 17.527121840165314, 17.672577627499617, 17.816845961056067, 17.95995545651492, 18.101933598375616, 18.242806801586205, 18.38260046892169, 18.52133904446436, 18.65904606350496, 18.79574419915317, 18.93145530591877, 19.066200460500774, 19.2, 19.332873557751316, 19.4648400969543, 19.595917942265423, 19.726124809500725, 19.855477833585372, 19.983993594874875, 20.111688143962457, 20.23857702507763, 20.364675298172568, 20.489997559785117, 20.6145579627602, 20.738370234905155, 20.861447696648476, 20.983803277766402, 21.10544953323667, 21.226398658274558, 21.346662502602133, 21.46625258399798, 21.585180101171265, 21.703455946000858, 21.82109071517737, 21.938094721283342, 22.054478003344354, 22.17025033688163, 22.285421243494593, 22.4, 22.513995647152463, 22.627416997969522, 22.740272645683035], [0.0, 2.4, 3.394112549695428, 4.156921938165306, 4.8, 5.366563145999495, 5.878775382679628, 6.3498031465550175, 6.788225099390856, 7.199999999999999, 7.58946638440411, 7.95989949685296, 8.313843876330612, 8.653323061113575, 8.97997772825746, 9.295160030897799, 9.6, 9.895453501482384, 10.182337649086284, 10.461357464497617, 10.73312629199899, 10.998181667894016, 11.256997823576231, 11.509995655950528, 11.757550765359255, 12.0, 12.237646832622683, 12.470765814495916, 12.699606293110035, 12.92439553712281, 13.145341380123986, 13.362634470792052, 13.576450198781712, 13.786950351691269, 13.994284547628721, 14.198591479439077, 14.399999999999999, 14.598630072715727, 14.794593607125543, 14.987995196156156, 15.17893276880822, 15.367498169838838, 15.553777676178866, 15.7378524583248, 15.91979899370592, 16.099689437998485, 16.277591959500644, 16.453571040962505, 16.627687752661224, 16.8, 16.97056274847714, 17.13942822850284, 17.30664612222715, 17.472263734273245, 17.636326148038883, 17.798876369029593, 17.95995545651492, 18.1196026446498, 18.27785545407338, 18.43474979488466, 18.590320061795598, 18.74459922217597, 18.897618897628345, 19.04940943966505, 19.2, 19.349418595916518, 19.497692171126303, 19.64484665249388, 19.79090700296477, 19.93589727100338, 20.079840636817814, 20.222759455623258, 20.364675298172568, 20.505608988762074, 20.645580640902303, 20.784609690826528, 20.922714928995234, 21.059914529741093, 21.196226079186836, 21.331666601557412, 21.46625258399798, 21.6, 21.7329243315298, 21.865040589946314, 21.996363335788033, 22.12690669750293, 22.25668438918969, 22.385709727413158, 22.513995647152463, 22.641554716935847, 22.76839915321233, 22.894540834006694, 23.019991311901055, 23.144761826383093, 23.26886331559838, 23.39230642754151, 23.51510153071851, 23.63725872431065, 23.758787847867996, 23.87969849055888, 24.0, 24.11970149069014], [0.0, 2.5298221281347035, 3.5777087639996634, 4.3817804600413295, 5.059644256269407, 5.656854249492381, 6.196773353931867, 6.6932802122726045, 7.155417527999327, 7.58946638440411, 8.0, 8.390470785361213, 8.763560920082659, 9.121403400793104, 9.465727652959385, 9.797958971132712, 10.119288512538814, 10.430723848324238, 10.73312629199899, 11.027239001672179, 11.313708498984761, 11.593101396951552, 11.865917579353061, 12.132600710482482, 12.393546707863734, 12.649110640673518, 12.89961239727768, 13.145341380123988, 13.386560424545209, 13.623509092741122, 13.856406460551018, 14.085453489327207, 14.310835055998654, 14.532721699667961, 14.75127113166862, 14.966629547095765, 15.17893276880822, 15.388307249337076, 15.594870951694343, 15.7987341265052, 16.0, 16.19876538505327, 16.39512122553536, 16.589153082662175, 16.780941570722426, 16.97056274847714, 17.158088471621774, 17.34358671094304, 17.527121840165318, 17.708754896942924, 17.88854381999832, 18.066543665017946, 18.24280680158621, 18.417383093154143, 18.5903200617956, 18.76166303929372, 18.93145530591877, 19.099738218101315, 19.266551326067674, 19.43193248238579, 19.595917942265423, 19.75854245636555, 19.91983935678197, 20.079840636817814, 20.23857702507763, 20.396078054371138, 20.552372125864206, 20.707486568871655, 20.861447696648476, 21.014280858501916, 21.166010488516726, 21.316660151158764, 21.46625258399798, 21.614809737770074, 21.762352813976708, 21.908902300206645, 22.054478003344357, 22.199099080818574, 22.34278407003031, 22.485550916088314, 22.627416997969522, 22.768399153212332, 22.908513701242168, 23.047776465420693, 23.186202793903103, 23.323807579381203, 23.46060527778429, 23.596609926004202, 23.731835158706122, 23.866294224282075, 24.0, 24.13296500639737, 24.265201420964964, 24.39672109116305, 24.52753554680943, 24.657656011875904, 24.78709341572747, 24.9158584038359, 25.043961347997644, 25.17141235608364, 25.298221281347036, 25.424397731313128], [0.0, 2.65329983228432, 3.752332607858744, 4.595650117230424, 5.30659966456864, 5.9329587896765315, 6.499230723708769, 7.019971509913698, 7.504665215717488, 7.95989949685296, 8.390470785361213, 8.8, 9.191300234460847, 9.566608594481119, 9.927738916792686, 10.276186062932103, 10.61319932913728, 10.939835464941876, 11.256997823576231, 11.56546583584077, 11.865917579353063, 12.158947322856532, 12.445079348883239, 12.724778976469494, 12.998461447417538, 13.266499161421601, 13.529227620230213, 13.78695035169127, 14.039943019827396, 14.288456879593403, 14.53272169966796, 14.772948250095512, 15.009330431434975, 15.242047106606122, 15.471263684650975, 15.697133496278868, 15.91979899370592, 16.139392801465615, 16.356038640208702, 16.569852141766386, 16.780941570722426, 16.989408465276245, 17.195348208163743, 17.398850536745236, 17.6, 17.798876369029593, 17.99555500672319, 18.19010720144332, 18.382600468921694, 18.57309882599024, 18.76166303929372, 18.948350851723223, 19.133217188962238, 19.31631434823942, 19.497692171126307, 19.67739820199815, 19.855477833585372, 20.031974440878265, 20.206929504504146, 20.380382724571195, 20.552372125864206, 20.72293415518179, 20.892103771520954, 21.059914529741096, 21.22639865827456, 21.3915871313935, 21.55550973649197, 21.718195136797167, 21.87967092988375, 22.03996370232946, 22.199099080818577, 22.357101779971394, 22.513995647152463, 22.66980370448761, 22.82454818829937, 22.978250586152118, 23.13093167168154, 23.2826115373684, 23.4333096254029, 23.583044756773884, 23.731835158706126, 23.879698490558884, 24.026651868289935, 24.172711887581006, 24.317894645713064, 24.46221576227305, 24.60569039876752, 24.748333277212833, 24.890158697766477, 25.031180555459226, 25.17141235608364, 25.310867231290203, 25.44955795293899, 25.587496946751166, 25.724696305301645, 25.86116780039138, 25.996922894835077, 26.131972753697724, 26.266328255011206, 26.400000000000006, 26.532998322843202, 26.665333299998338], [0.0, 2.771281292110204, 3.9191835884530852, 4.800000000000002, 5.542562584220408, 6.196773353931868, 6.788225099390857, 7.332121111929345, 7.8383671769061705, 8.313843876330612, 8.763560920082659, 9.191300234460847, 9.600000000000003, 9.991996797437439, 10.369185117452577, 10.73312629199899, 11.085125168440817, 11.426285485668561, 11.757550765359257, 12.079735096433202, 12.393546707863736, 12.699606293110037, 12.998461447417538, 13.290598180668923, 13.576450198781714, 13.856406460551021, 14.130817386124559, 14.400000000000002, 14.66424222385869, 14.923806484942107, 15.178932768808222, 15.42984121758873, 15.676734353812341, 15.919798993705923, 16.15920790137933, 16.39512122553536, 16.627687752661224, 16.857046004564385, 17.0833252032501, 17.306646122227153, 17.527121840165318, 17.74485841025507, 17.959955456514923, 18.172506706560878, 18.382600468921694, 18.5903200617956, 18.795744199153173, 18.99894733926067, 19.200000000000006, 19.398969044771427, 19.595917942265427, 19.790907002964776, 19.983993594874878, 20.17523234066959, 20.36467529817257, 20.55237212586421, 20.738370234905155, 20.922714928995237, 21.105449533236676, 21.286615513040115, 21.46625258399798, 21.644398813549895, 21.82109071517737, 21.996363335788036, 22.170250336881633, 22.34278407003031, 22.513995647152466, 22.683915006012523, 22.852570971337123, 23.01999131190106, 23.186202793903107, 23.35123123092228, 23.515101530718514, 23.67783773911799, 23.839463081202144, 24.000000000000004, 24.159470192866404, 24.317894645713064, 24.475293665245374, 24.63168690934505, 24.787093415727472, 24.941531628991836, 25.095019426173, 25.247574140895203, 25.399212586220074, 25.549951076274105, 25.69980544673442, 25.848791074245625, 25.996922894835077, 26.14421542138911, 26.290682760247975, 26.436338626973292, 26.581196361337845, 26.725268941584112, 26.868568997994668, 27.011108825814613, 27.152900397563428, 27.293955374771176, 27.434285119171598, 27.57390070338254, 27.712812921102042, 27.851032296846743], [0.0, 2.8844410203711917, 4.079215610874228, 4.9959983987187195, 5.768882040742383, 6.44980619863884, 7.065408693062278, 7.631513611335566, 8.158431221748456, 8.653323061113575, 9.121403400793104, 9.566608594481119, 9.991996797437439, 10.400000000000002, 10.792590050585634, 11.171392035015153, 11.537764081484767, 11.892854997854805, 12.237646832622685, 12.572986916401371, 12.89961239727768, 13.218169313486646, 13.52922762023021, 13.833293172632468, 14.130817386124557, 14.422205101855958, 14.70782104868019, 14.987995196156158, 15.263027222671132, 15.53319027115808, 15.798734126505199, 16.059887919907787, 16.316862443496913, 16.569852141766386, 16.819036833302913, 17.064583206161235, 17.30664612222715, 17.54536975956905, 17.780888616714297, 18.013328398716325, 18.24280680158621, 18.469434208984318, 18.69331431287668, 18.914544668059023, 19.133217188962238, 19.349418595916518, 19.563230817019974, 19.77473135089324, 19.983993594874878, 20.19108714259834, 20.39607805437114, 20.599029103333976, 20.800000000000004, 20.999047597450705, 21.196226079186836, 21.391587131393504, 21.585180101171268, 21.77705214210592, 21.96724834839357, 22.155811878601966, 22.342784070030305, 22.52820454452596, 22.712111306525426, 22.894540834006698, 23.075528162969533, 23.25510696599781, 23.4333096254029, 23.61016730139793, 23.78570999570961, 23.959966610995103, 24.132965006397374, 24.3047320495413, 24.47529366524537, 24.64467488119898, 24.812899870833316, 24.979991993593593, 25.145973832802742, 25.310867231290203, 25.474693324945058, 25.637472574339306, 25.79922479455536, 25.959969183340725, 26.119724347703215, 26.278508329050947, 26.436338626973292, 26.59323222175146, 26.749205595680785, 26.904274753280383, 27.05845524046042, 27.211762162711917, 27.36421020237931, 27.515813635071744, 27.666586345264935, 27.81654184114194, 27.965693268717658, 28.114053425288926, 28.261634772249113, 28.408449447303532, 28.554509276119596, 28.69982578344336, 28.844410203711917, 28.988273491189506], [0.0, 2.9933259094191533, 4.233202097703344, 5.184592558726289, 5.986651818838307, 6.6932802122726045, 7.332121111929344, 7.919595949289333, 8.466404195406689, 8.97997772825746, 9.465727652959385, 9.927738916792686, 10.369185117452577, 10.792590050585634, 11.2, 11.59310139695155, 11.973303637676613, 12.34179889643321, 12.699606293110035, 13.047605144240073, 13.386560424545209, 13.717142559585797, 14.039943019827396, 14.35548675594109, 14.664242223858688, 14.966629547095765, 15.26302722267113, 15.553777676178866, 15.839191898578665, 16.119553343687908, 16.395121225535355, 16.666133324799727, 16.932808390813378, 17.195348208163743, 17.453939383417143, 17.708754896942924, 17.95995545651492, 18.207690682785667, 18.452100151473275, 18.693314312876677, 18.93145530591877, 19.166637681137505, 19.398969044771427, 19.628550634216474, 19.855477833585372, 20.07984063681781, 20.301724064719235, 20.521208541409056, 20.738370234905155, 20.95328136593407, 21.166010488516726, 21.376622745419823, 21.585180101171268, 21.79174155500198, 21.996363335788033, 22.199099080818574, 22.4, 22.599115026920856, 22.796490958040014, 22.99217258111986, 23.1862027939031, 23.37862271392393, 23.569471780249973, 23.758787847867996, 23.946607275353227, 24.132965006397367, 24.31789464571306, 24.501428529781688, 24.68359779286642, 24.864432428672085, 25.043961347997644, 25.222212432695112, 25.39921258622007, 25.574987781033247, 25.749563103089727, 25.92296279363144, 26.095210288480146, 26.266328255011206, 26.436338626973292, 26.605262637305426, 26.773120849090418, 26.93993318477238, 27.10571895375587, 27.270496878494896, 27.434285119171594, 27.597101297056543, 27.758962516635957, 27.919885386584237, 28.07988603965479, 28.238980151556465, 28.397182958878155, 28.554509276119596, 28.71097351188218, 28.866589684269947, 29.021371435547287, 29.17533204609675, 29.328484447717376, 29.48084123630125, 29.632414683923415, 29.783216750378056, 29.93325909419153, 30.082553083141068], [0.0, 3.098386676965933, 4.381780460041329, 5.366563145999495, 6.196773353931866, 6.928203230275509, 7.58946638440411, 8.197560612767678, 8.763560920082657, 9.295160030897799, 9.797958971132712, 10.276186062932103, 10.73312629199899, 11.171392035015153, 11.59310139695155, 11.999999999999998, 12.393546707863733, 12.77497553813705, 13.145341380123986, 13.505554412907307, 13.856406460551018, 14.198591479439077, 14.53272169966796, 14.859340496805368, 15.17893276880822, 15.491933384829666, 15.798734126505199, 16.099689437998485, 16.395121225535355, 16.685322891691367, 16.97056274847714, 17.251086922278258, 17.527121840165314, 17.798876369029593, 18.066543665017942, 18.33030277982336, 18.590320061795598, 18.846750383023593, 19.099738218101315, 19.349418595916518, 19.595917942265423, 19.83935482821959, 20.079840636817814, 20.317480158720468, 20.552372125864206, 20.784609690826525, 21.014280858501913, 21.241468875762806, 21.46625258399798, 21.68870673876153, 21.908902300206645, 22.12690669750293, 22.342784070030305, 22.556595487794695, 22.76839915321233, 22.978250586152114, 23.1862027939031, 23.392306427541513, 23.596609926004202, 23.799159649029622, 23.999999999999996, 24.199173539606676, 24.396721091163048, 24.592681838303033, 24.787093415727465, 24.97999199359359, 25.171412356083636, 25.36138797463577, 25.5499510762741, 25.737132707432657, 25.92296279363144, 26.10747019532915, 26.29068276024797, 26.472627372438872, 26.653329998332286, 26.832815729997474, 27.011108825814613, 27.188232748746284, 27.36421020237931, 27.53906316489361, 27.712812921102035, 27.8854800926934, 28.057084666800293, 28.227646023003757, 28.397182958878155, 28.565713714171398, 28.733255993708752, 28.89982698910151, 29.06544339933592, 29.230121450312172, 29.393876913398135, 29.556725123057863, 29.718680993610736, 29.879759035172956, 30.039973368829738, 30.199337741082996, 30.35786553761644, 30.515569796417044, 30.6724632202893, 30.82855818879631, 30.983866769659333, 31.138400729645703], [0.0, 3.2, 4.525483399593904, 5.542562584220408, 6.4, 7.155417527999328, 7.8383671769061705, 8.46640419540669, 9.050966799187808, 9.6, 10.119288512538814, 10.61319932913728, 11.085125168440817, 11.537764081484767, 11.973303637676613, 12.393546707863733, 12.8, 13.193938001976514, 13.576450198781712, 13.948476619330158, 14.310835055998655, 14.66424222385869, 15.009330431434975, 15.346660874600705, 15.676734353812341, 16.0, 16.316862443496913, 16.627687752661224, 16.93280839081338, 17.232527382830416, 17.527121840165314, 17.81684596105607, 18.101933598375616, 18.382600468921694, 18.659046063504963, 18.93145530591877, 19.2, 19.464840096954305, 19.726124809500725, 19.983993594874878, 20.23857702507763, 20.489997559785117, 20.738370234905155, 20.983803277766402, 21.22639865827456, 21.46625258399798, 21.703455946000858, 21.938094721283342, 22.170250336881633, 22.400000000000002, 22.627416997969522, 22.852570971337123, 23.075528162969533, 23.296351645697662, 23.51510153071851, 23.731835158706122, 23.946607275353227, 24.1594701928664, 24.37047393876451, 24.579666393179547, 24.787093415727465, 24.992798962901293, 25.196825196837793, 25.39921258622007, 25.6, 25.799224794555357, 25.996922894835073, 26.193128869991842, 26.38787600395303, 26.58119636133784, 26.773120849090418, 26.96367927416435, 27.152900397563425, 27.3408119850161, 27.527440854536405, 27.71281292110204, 27.896953238660316, 28.07988603965479, 28.261634772249113, 28.442222135409885, 28.62167011199731, 28.8, 28.977232442039735, 29.153387453261757, 29.32848444771738, 29.50254226333724, 29.675579185586255, 29.84761296988421, 30.01866086286995, 30.18873962258113, 30.35786553761644, 30.52605444534226, 30.69332174920141, 30.859682435177458, 31.025151087464508, 31.189741903388683, 31.353468707624682, 31.51634496574754, 31.67838379715733, 31.839597987411842, 32.0, 32.15960198758685], [0.0, 3.2984845004941286, 4.66476151587624, 5.713142742834281, 6.596969000988257, 7.37563556583431, 8.079603950689663, 8.726969691708572, 9.32952303175248, 9.895453501482384, 10.430723848324238, 10.939835464941876, 11.426285485668561, 11.892854997854805, 12.34179889643321, 12.77497553813705, 13.193938001976514, 13.6, 13.994284547628721, 14.377760604489144, 14.75127113166862, 15.115554902152947, 15.471263684650973, 15.818975946628152, 16.159207901379325, 16.492422502470642, 16.819036833302913, 17.13942822850284, 17.453939383417143, 17.762882648939616, 18.066543665017942, 18.365184453198395, 18.65904606350496, 18.94835085172322, 19.233304448274094, 19.51409746824075, 19.79090700296477, 20.063897926375123, 20.333224043422135, 20.599029103333976, 20.861447696648476, 21.12060605191054, 21.376622745419823, 21.629609335353237, 21.87967092988375, 22.12690669750293, 22.3714103265753, 22.61327044016411, 22.852570971337123, 23.0893915034589, 23.323807579381203, 23.555890982936734, 23.78570999570961, 24.013329631685817, 24.238811852068988, 24.46221576227305, 24.68359779286642, 24.90301186603741, 25.120509548972134, 25.336140195380985, 25.5499510762741, 25.76198750096739, 25.97229292919668, 26.180909075125715, 26.38787600395303, 26.593232221751457, 26.797014759110763, 26.99925924909793, 27.2, 27.399270063269935, 27.597101297056547, 27.793524425664334, 27.988569095257443, 28.182263926093658, 28.374636561549117, 28.5657137141714, 28.755521208978287, 28.94408402420087, 29.131426329653003, 29.31757152289391, 29.50254226333724, 29.68636050444716, 29.869047524151153, 30.050623953588715, 30.231109804305895, 30.41052449399714, 30.58888687088826, 30.766215236847057, 30.942527369301946, 31.117840542042757, 31.292171544972714, 31.46553670287542, 31.637951893256304, 31.80943256331367, 31.9799937460907, 32.14965007585619, 32.31841580275865, 32.486304806795125, 32.65333061113368, 32.81950639482562, 32.984845004941285, 33.14935896816106], [0.0, 3.394112549695428, 4.8, 5.8787753826796285, 6.788225099390856, 7.589466384404111, 8.313843876330612, 8.97997772825746, 9.6, 10.182337649086284, 10.73312629199899, 11.256997823576231, 11.757550765359257, 12.237646832622685, 12.699606293110035, 13.145341380123986, 13.576450198781712, 13.994284547628721, 14.4, 14.794593607125545, 15.178932768808222, 15.553777676178866, 15.91979899370592, 16.277591959500644, 16.627687752661224, 16.970562748477143, 17.30664612222715, 17.636326148038883, 17.95995545651492, 18.277855454073382, 18.5903200617956, 18.897618897628348, 19.2, 19.497692171126307, 19.790907002964772, 20.079840636817814, 20.364675298172568, 20.645580640902306, 20.922714928995234, 21.196226079186836, 21.46625258399798, 21.7329243315298, 21.996363335788033, 22.256684389189687, 22.513995647152463, 22.76839915321233, 23.019991311901055, 23.26886331559838, 23.515101530718514, 23.758787847867996, 24.0, 24.23881185206899, 24.47529366524537, 24.709512338368803, 24.941531628991836, 25.17141235608364, 25.39921258622007, 25.624987804875147, 25.84879107424562, 26.070673178880515, 26.29068276024797, 26.508866441249427, 26.725268941584105, 26.93993318477238, 27.152900397563425, 27.36421020237931, 27.573900703382538, 27.78200856669654, 27.988569095257443, 28.193616298729754, 28.397182958878158, 28.599300690751164, 28.8, 28.999310336626973, 29.197260145431454, 29.393876913398138, 29.58918721425109, 29.783216750378056, 29.975990392312315, 30.167532215943684, 30.357865537616444, 30.547012947258853, 30.73499633967768, 30.9218369441403, 31.107555352357732, 31.292171544972717, 31.475704916649605, 31.65817429985501, 31.83959798741184, 32.0199937539032, 32.19937887599697, 32.3777701517569, 32.55518391900129, 32.73163607276606, 32.907142081925016, 33.08171700501653, 33.25537550532245, 33.42813186524189, 33.6, 33.7709934707287, 33.941125496954285, 34.11040896852455], [0.0, 3.4871191548325395, 4.931531202375181, 6.039867548216601, 6.974238309665079, 7.7974354758471724, 8.54166260162505, 9.226050075736637, 9.863062404750362, 10.461357464497617, 11.027239001672179, 11.56546583584077, 12.079735096433202, 12.572986916401371, 13.047605144240073, 13.505554412907307, 13.948476619330158, 14.377760604489144, 14.794593607125545, 15.200000000000003, 15.594870951694345, 15.979987484350545, 16.356038640208702, 16.7236359682935, 17.0833252032501, 17.435595774162696, 17.7808886167143, 18.119602644649802, 18.452100151473275, 18.778711350888805, 19.099738218101315, 19.415457759218558, 19.726124809500725, 20.031974440878265, 20.33322404342214, 20.630075133164205, 20.922714928995234, 21.211317733700568, 21.49604614807105, 21.777052142105923, 22.054478003344357, 22.328457179124584, 22.59911502692086, 22.866569484730324, 23.13093167168154, 23.392306427541513, 23.650792798551176, 23.9064844759743, 24.159470192866404, 24.409834083827775, 24.65765601187591, 24.903011866037414, 25.145973832802742, 25.386610644195894, 25.62498780487515, 25.861167800391385, 26.095210288480146, 26.327172275046937, 26.557108276316537, 26.78507046845313, 27.011108825814613, 27.235271248878725, 27.457603682768823, 27.678150227209915, 27.896953238660316, 28.114053425288926, 28.32948993540124, 28.54330043985804, 28.755521208978287, 28.966187184370682, 29.175332046096756, 29.382988275531137, 29.58918721425109, 29.793959119257718, 29.99733321480428, 30.199337741083003, 30.400000000000006, 30.599346398248446, 30.797402487872258, 30.994193004496832, 31.18974190338869, 31.384072393492854, 31.57720696958489, 31.76916744266365, 31.95997496870109, 32.149650075856194, 32.338212690252384, 32.5256821604098, 32.712077280417404, 32.897416311923344, 33.081717005016536, 33.26499661806687, 33.447271936587, 33.62855929117393, 33.808874574584706, 33.988233257996804, 34.1666504065002, 34.34414069386509, 34.52071841662627, 34.69639750752231, 34.87119154832539, 35.04511378209522], [0.0, 3.577708763999664, 5.059644256269407, 6.196773353931868, 7.155417527999328, 8.000000000000002, 8.763560920082659, 9.465727652959387, 10.119288512538814, 10.73312629199899, 11.313708498984761, 11.865917579353063, 12.393546707863736, 12.89961239727768, 13.386560424545209, 13.856406460551018, 14.310835055998655, 14.75127113166862, 15.178932768808222, 15.594870951694345, 16.000000000000004, 16.39512122553536, 16.780941570722426, 17.158088471621777, 17.527121840165318, 17.88854381999832, 18.24280680158621, 18.590320061795605, 18.931455305918774, 19.266551326067674, 19.595917942265427, 19.919839356781974, 20.23857702507763, 20.55237212586421, 20.86144769664848, 21.166010488516726, 21.46625258399798, 21.76235281397671, 22.054478003344357, 22.34278407003031, 22.627416997969522, 22.908513701242168, 23.186202793903107, 23.46060527778429, 23.731835158706126, 24.0, 24.265201420964964, 24.52753554680943, 24.787093415727472, 25.043961347997648, 25.298221281347036, 25.549951076274105, 25.79922479455536, 26.046112953759536, 26.290682760247975, 26.532998322843202, 26.773120849090418, 27.011108825814613, 27.247018185482247, 27.48090245970827, 27.712812921102035, 27.94279871451677, 28.170906978654415, 28.397182958878158, 28.62167011199731, 28.844410203711913, 29.065443399335923, 29.284808348357004, 29.50254226333724, 29.71868099361074, 29.933259094191534, 30.14630989026684, 30.357865537616444, 30.56795707926848, 30.776614498674153, 30.983866769659336, 31.18974190338869, 31.394266992557736, 31.597468253010405, 31.79937106296287, 32.00000000000001, 32.19937887599698, 32.39753077010654, 32.59447805994138, 32.79024245107072, 32.984845004941285, 33.17830616532436, 33.37064578338274, 33.56188314144485, 33.75203697556638, 33.941125496954285, 34.12916641232247, 34.316176943243555, 34.50217384455652, 34.68717342188609, 34.87119154832539, 35.054243680330636, 35.236344872872394, 35.41750979388585, 35.597752738059185, 35.77708763999664, 35.95552808679078], [0.0, 3.6660605559646724, 5.184592558726289, 6.349803146555018, 7.332121111929345, 8.19756061276768, 8.97997772825746, 9.699484522385713, 10.369185117452577, 10.998181667894016, 11.593101396951552, 12.158947322856532, 12.699606293110037, 13.218169313486646, 13.717142559585797, 14.198591479439077, 14.66424222385869, 15.115554902152947, 15.553777676178866, 15.979987484350545, 16.39512122553536, 16.8, 17.195348208163743, 17.58180878066873, 17.95995545651492, 18.330302779823363, 18.69331431287668, 19.049409439665055, 19.398969044771427, 19.742340286804907, 20.079840636817814, 20.41176131547692, 20.738370234905155, 21.059914529741096, 21.376622745419823, 21.688706738761535, 21.996363335788033, 22.299775783626167, 22.599115026920856, 22.894540834006698, 23.186202793903103, 23.474241201793937, 23.758787847868, 24.03996672210675, 24.317894645713064, 24.592681838303037, 24.86443242867209, 25.133244915848014, 25.399212586220074, 25.662423891752706, 25.922962793631445, 26.18090907512572, 26.436338626973292, 26.689323708179646, 26.939933184772382, 27.188232748746287, 27.434285119171594, 27.678150227209912, 27.91988538658424, 28.159545450876866, 28.397182958878155, 28.63284826907725, 28.866589684269943, 29.09845356715714, 29.32848444771738, 29.556725123057866, 29.783216750378056, 30.007998933617685, 30.231109804305895, 30.45258609707885, 30.672463220289305, 30.89077532209252, 31.107555352357732, 31.32283512072303, 31.536645351083237, 31.74901573277509, 31.95997496870109, 32.16955082061296, 32.377770151756906, 32.58465896706608, 32.79024245107072, 32.99454500368205, 33.197590273994294, 33.399401192236965, 33.6, 33.799408278844176, 33.997646977401246, 34.19473643706002, 34.390696416327486, 34.58554611394766, 34.77930419085465, 34.97198879103103, 35.16361756133746, 35.35420767037497, 35.5437758264369, 35.73233829460367, 35.91991091302984, 36.10650910846963, 36.29214791108402, 36.476841968569595, 36.660605559646726, 36.84345260694226], [0.0, 3.752332607858744, 5.3065996645686395, 6.499230723708769, 7.504665215717488, 8.390470785361213, 9.191300234460847, 9.927738916792686, 10.613199329137279, 11.256997823576231, 11.865917579353061, 12.445079348883239, 12.998461447417538, 13.52922762023021, 14.039943019827396, 14.53272169966796, 15.009330431434975, 15.471263684650973, 15.91979899370592, 16.356038640208702, 16.780941570722426, 17.195348208163743, 17.6, 17.99555500672319, 18.382600468921694, 18.76166303929372, 19.133217188962238, 19.497692171126307, 19.855477833585372, 20.206929504504142, 20.552372125864206, 20.892103771520954, 21.226398658274558, 21.55550973649197, 21.87967092988375, 22.199099080818574, 22.513995647152463, 22.82454818829937, 23.130931671681537, 23.4333096254029, 23.731835158706122, 24.02665186828993, 24.317894645713064, 24.605690398767518, 24.890158697766477, 25.171412356083636, 25.44955795293899, 25.724696305301645, 25.996922894835077, 26.266328255011206, 26.532998322843202, 26.797014759110766, 27.05845524046042, 27.3173937263422, 27.573900703382538, 27.82804340948174, 28.07988603965479, 28.329489935401238, 28.576913759186805, 28.822213655442912, 29.06544339933592, 29.306654534422723, 29.54589650019102, 29.783216750378056, 30.01866086286995, 30.252272641902458, 30.48409421321224, 30.714166112723948, 30.942527369301946, 31.16921558204505, 31.394266992557736, 31.617716552591208, 31.83959798741184, 32.05994385522221, 32.27878560293122, 32.49615361854384, 32.712077280417404, 32.92658500361069, 33.13970428353277, 33.35146173708133, 33.56188314144485, 33.7709934707287, 33.97881693055249, 34.18537699075439, 34.390696416327486, 34.59479729670345, 34.79770107349047, 34.999428566763775, 35.2, 35.39943502374014, 35.597752738059185, 35.79497171391535, 35.99111001344638, 36.186185209275656, 36.38021440288664, 36.573214242119874, 36.76520093784339, 36.95619027984352, 37.14619765198048, 37.335238046649714, 37.52332607858744, 37.710475998056566], [0.0, 3.836665218650176, 5.4258639865002145, 6.645299090334461, 7.673330437300352, 8.579044235810889, 9.397872099576585, 10.150862032359617, 10.851727973000429, 11.509995655950528, 12.132600710482482, 12.724778976469494, 13.290598180668923, 13.833293172632468, 14.35548675594109, 14.859340496805368, 15.346660874600705, 15.818975946628152, 16.277591959500644, 16.7236359682935, 17.158088471621777, 17.58180878066873, 17.99555500672319, 18.400000000000002, 18.79574419915317, 19.18332609325088, 19.563230817019978, 19.935897271003384, 20.301724064719235, 20.661074512231934, 21.014280858501916, 21.361647876509902, 21.703455946000858, 22.039963702329462, 22.3714103265753, 22.698017534577772, 23.019991311901055, 23.33752343330372, 23.650792798551176, 23.959966610995103, 24.265201420964964, 24.566644052454542, 24.86443242867209, 25.15869630962622, 25.44955795293899, 25.73713270743266, 26.02152954766495, 26.302851556437755, 26.581196361337845, 26.85665653055123, 27.129319932501076, 27.399270063269938, 27.666586345264935, 27.93134440015375, 28.193616298729758, 28.453470790045987, 28.71097351188218, 28.96618718437068, 29.219171788399482, 29.46998473023018, 29.718680993610736, 29.96531328052487, 30.20993214159873, 30.45258609707885, 30.69332174920141, 30.932183886689927, 31.16921558204505, 31.404458282224837, 31.637951893256304, 31.869734859267346, 32.09984423638221, 32.328315761882806, 32.55518391900129, 32.78048199767661, 33.00424215157803, 33.2264954516723, 33.447271936587, 33.66660066000131, 33.8845097352758, 34.10102637751539, 34.316176943243555, 34.529986967851585, 34.74248120097355, 34.953683639925565, 35.16361756133746, 35.372305551094634, 35.57976953269934, 35.78603079415207, 35.99111001344638, 36.19502728276358, 36.39780213144745, 36.5994535478332, 36.800000000000004, 36.99945945551097, 37.197849400200546, 37.39518685606478, 37.59148839830634, 37.786770171582546, 37.981047905501505, 38.17433692940848, 38.36665218650176, 38.55800824731486], [0.0, 3.9191835884530852, 5.542562584220407, 6.788225099390857, 7.8383671769061705, 8.763560920082659, 9.600000000000001, 10.369185117452577, 11.085125168440815, 11.757550765359255, 12.393546707863734, 12.998461447417538, 13.576450198781714, 14.130817386124557, 14.664242223858688, 15.17893276880822, 15.676734353812341, 16.159207901379325, 16.627687752661224, 17.0833252032501, 17.527121840165318, 17.95995545651492, 18.382600468921694, 18.79574419915317, 19.200000000000003, 19.595917942265427, 19.983993594874878, 20.36467529817257, 20.738370234905155, 21.105449533236673, 21.46625258399798, 21.82109071517737, 22.17025033688163, 22.513995647152466, 22.852570971337123, 23.186202793903103, 23.51510153071851, 23.839463081202144, 24.1594701928664, 24.47529366524537, 24.78709341572747, 25.095019426173, 25.399212586220074, 25.699805446734416, 25.996922894835077, 26.29068276024797, 26.58119636133784, 26.868568997994664, 27.152900397563428, 27.434285119171594, 27.71281292110204, 27.988569095257446, 28.261634772249113, 28.532087200203218, 28.8, 29.065443399335923, 29.328484447717376, 29.589187214251087, 29.84761296988421, 30.103820355562846, 30.35786553761644, 30.609802351534388, 30.859682435177454, 31.107555352357732, 31.353468707624682, 31.597468253010398, 31.83959798741184, 32.079900249221474, 32.31841580275865, 32.55518391900129, 32.79024245107072, 33.02362790488047, 33.25537550532245, 33.48551925833016, 33.71409200912876, 33.941125496954285, 34.1666504065002, 34.390696416327486, 34.6132922444543, 34.83446569132359, 35.054243680330636, 35.272652296077766, 35.48971682051014, 35.70546176707423, 35.91991091302984, 36.13308733003589, 36.345013413121755, 36.555710908146764, 36.76520093784339, 36.9735040265323, 37.1806401235912, 37.38662862575335, 37.59148839830634, 37.795237795256696, 37.99789467852134, 38.19947643620263, 38.400000000000006, 38.599481861807426, 38.79793808954285, 38.99538434225261, 39.19183588453085, 39.387307600291756], [0.0, 4.0, 5.656854249492381, 6.9282032302755105, 8.0, 8.94427190999916, 9.797958971132713, 10.583005244258363, 11.313708498984761, 12.0, 12.649110640673518, 13.266499161421601, 13.856406460551021, 14.422205101855958, 14.966629547095765, 15.491933384829666, 16.0, 16.492422502470642, 16.970562748477143, 17.435595774162696, 17.88854381999832, 18.330302779823363, 18.76166303929372, 19.18332609325088, 19.595917942265427, 20.000000000000004, 20.39607805437114, 20.78460969082653, 21.166010488516726, 21.54065922853802, 21.908902300206645, 22.27105745132009, 22.627416997969522, 22.978250586152118, 23.323807579381203, 23.664319132398465, 24.0, 24.33105012119288, 24.657656011875908, 24.979991993593597, 25.298221281347036, 25.612496949731398, 25.922962793631445, 26.229754097208, 26.532998322843202, 26.832815729997474, 27.129319932501076, 27.42261840160418, 27.712812921102042, 28.0, 28.284271247461906, 28.565713714171405, 28.844410203711917, 29.12043955712208, 29.39387691339814, 29.664793948382655, 29.93325909419153, 30.199337741083, 30.463092423455638, 30.72458299147443, 30.983866769659333, 31.24099870362662, 31.496031496047245, 31.74901573277509, 32.0, 32.2490309931942, 32.49615361854384, 32.7414110874898, 32.984845004941285, 33.2264954516723, 33.46640106136302, 33.704599092705436, 33.941125496954285, 34.17601498127013, 34.40930106817051, 34.64101615137755, 34.87119154832539, 35.09985754956849, 35.32704346531139, 35.55277766926236, 35.77708763999664, 36.00000000000001, 36.22154055254967, 36.4417343165772, 36.660605559646726, 36.878177829171555, 37.094473981982816, 37.30951621235526, 37.52332607858744, 37.73592452822641, 37.94733192202055, 38.15756805667783, 38.36665218650176, 38.57460304397183, 38.781438859330635, 38.98717737923585, 39.19183588453085, 39.39543120718442, 39.59797974644666, 39.799497484264805, 40.00000000000001, 40.19950248448357], [0.0, 4.079215610874228, 5.768882040742383, 7.065408693062279, 8.158431221748456, 9.121403400793104, 9.991996797437439, 10.792590050585634, 11.537764081484767, 12.237646832622683, 12.89961239727768, 13.529227620230213, 14.130817386124559, 14.70782104868019, 15.26302722267113, 15.798734126505199, 16.316862443496913, 16.819036833302913, 17.30664612222715, 17.7808886167143, 18.24280680158621, 18.69331431287668, 19.133217188962238, 19.563230817019978, 19.983993594874878, 20.39607805437114, 20.800000000000004, 21.196226079186836, 21.585180101171268, 21.96724834839357, 22.342784070030305, 22.712111306525426, 23.075528162969533, 23.4333096254029, 23.78570999570961, 24.13296500639737, 24.475293665245367, 24.81289987083332, 25.145973832802742, 25.474693324945058, 25.79922479455536, 26.119724347703215, 26.436338626973296, 26.74920559568078, 27.058455240460425, 27.36421020237931, 27.666586345264935, 27.965693268717658, 28.261634772249117, 28.554509276119596, 28.844410203711917, 29.131426329653003, 29.41564209736038, 29.697137909232943, 29.975990392312315, 30.25227264190246, 30.52605444534226, 30.797402487872255, 31.066380542316164, 31.333049644105824, 31.597468253010398, 31.859692402783804, 32.11977583981557, 32.377770151756906, 32.633724886993825, 32.887687665751145, 33.139704283532765, 33.38981880753473, 33.63807366660583, 33.8845097352758, 34.12916641232247, 34.372081694305336, 34.6132922444543, 34.852833457267145, 35.0907395191381, 35.32704346531139, 35.5617772334286, 35.79497171391535, 36.02665679743266, 36.25686141959891, 36.48561360317242, 36.712940497868054, 36.938868417968635, 37.16342287787819, 37.38662862575336, 37.60850967533811, 37.82908933611805, 38.048390241901174, 38.266434377924476, 38.48324310657822, 38.69883719183304, 38.913236822448994, 39.126461634039956, 39.33853073006159, 39.54946270178649, 39.75927564732537, 39.967987189749756, 40.17561449436711, 40.38217428519668, 40.587682860690634, 40.79215610874228, 40.99560952102067], [0.0, 4.156921938165306, 5.878775382679628, 7.200000000000001, 8.313843876330612, 9.295160030897803, 10.182337649086286, 10.998181667894016, 11.757550765359255, 12.470765814495916, 13.145341380123988, 13.78695035169127, 14.400000000000002, 14.987995196156158, 15.553777676178866, 16.099689437998485, 16.627687752661224, 17.13942822850284, 17.636326148038883, 18.119602644649802, 18.590320061795605, 19.049409439665055, 19.497692171126307, 19.935897271003384, 20.36467529817257, 20.78460969082653, 21.196226079186836, 21.6, 21.996363335788033, 22.385709727413158, 22.768399153212332, 23.144761826383093, 23.51510153071851, 23.879698490558884, 24.238811852068988, 24.592681838303037, 24.941531628991832, 25.285569006846575, 25.62498780487515, 25.95996918334073, 26.290682760247975, 26.617287615382605, 26.939933184772382, 27.25876005984131, 27.57390070338254, 27.885480092693403, 28.193616298729758, 28.498421008891004, 28.800000000000004, 29.09845356715714, 29.39387691339814, 29.686360504447162, 29.975990392312315, 30.262848511004385, 30.547012947258857, 30.82855818879631, 31.107555352357732, 31.38407239349285, 31.65817429985501, 31.92992326956017, 32.19937887599697, 32.46659822032484, 32.73163607276605, 32.99454500368205, 33.25537550532245, 33.51417610504546, 33.7709934707287, 34.02587250901878, 34.27885645700568, 34.529986967851585, 34.77930419085466, 35.02684684638342, 35.272652296077766, 35.516756608676985, 35.75919462180322, 36.0, 36.239205289299605, 36.476841968569595, 36.71294049786806, 36.94753036401757, 37.18064012359121, 37.41229744348775, 37.6425291392595, 37.8713612113428, 38.09881887933011, 38.324926614411154, 38.54970817010163, 38.77318661136843, 38.99538434225261, 39.21632313208366, 39.43602414037196, 39.654507940459936, 39.87179454200677, 40.087903412376164, 40.302853496992, 40.51666323872192, 40.72935059634514, 40.94093306215676, 41.15142767875739, 41.36085105507381, 41.56921938165306, 41.77654844527011], [0.0, 4.233202097703345, 5.986651818838306, 7.332121111929345, 8.46640419540669, 9.465727652959387, 10.369185117452577, 11.200000000000001, 11.973303637676612, 12.699606293110035, 13.386560424545209, 14.039943019827396, 14.66424222385869, 15.263027222671132, 15.839191898578665, 16.395121225535355, 16.93280839081338, 17.453939383417143, 17.95995545651492, 18.452100151473275, 18.931455305918774, 19.398969044771427, 19.855477833585372, 20.301724064719235, 20.738370234905155, 21.166010488516726, 21.585180101171268, 21.996363335788033, 22.400000000000002, 22.796490958040014, 23.1862027939031, 23.569471780249977, 23.946607275353223, 24.317894645713064, 24.683597792866422, 25.043961347997644, 25.39921258622007, 25.74956310308973, 26.095210288480146, 26.436338626973292, 26.773120849090418, 27.10571895375587, 27.434285119171598, 27.758962516635954, 28.07988603965479, 28.397182958878155, 28.71097351188218, 29.021371435547287, 29.32848444771738, 29.632414683923415, 29.933259094191534, 30.2311098043059, 30.526054445342265, 30.81817645481316, 31.107555352357732, 31.394266992557736, 31.67838379715733, 31.959974968701086, 32.239106687375816, 32.51584229264252, 32.79024245107071, 33.06236531163492, 33.332266649599454, 33.6, 33.86561678162676, 34.12916641232246, 34.390696416327486, 34.650252524332345, 34.90787876683429, 35.16361756133746, 35.41750979388585, 35.669594895372725, 35.91991091302984, 36.168494577463406, 36.415381365571335, 36.66060555964672, 36.90420030294655, 37.14619765198048, 37.38662862575336, 37.62552325217551, 37.86291061183755, 38.0988188793301, 38.33327536227501, 38.56630653822064, 38.79793808954285, 39.0281949364815, 39.257101268432955, 39.484680573609815, 39.710955667170744, 39.93594871791579, 40.15968127363563, 40.38217428519668, 40.60344812943847, 40.82352263095384, 41.04241708281812, 41.2601502663284, 41.47674046981031, 41.69220550654523, 41.90656273186814, 42.11982905948219, 42.33202097703345, 42.543154560986665], [0.0, 4.308131845707604, 6.092618484691127, 7.461903242471053, 8.616263691415208, 9.633275663033837, 10.552724766618336, 11.398245479020007, 12.185236969382254, 12.92439553712281, 13.623509092741122, 14.288456879593403, 14.923806484942107, 15.53319027115808, 16.119553343687908, 16.685322891691367, 17.232527382830416, 17.762882648939616, 18.277855454073382, 18.778711350888805, 19.266551326067674, 19.742340286804907, 20.206929504504142, 20.661074512231934, 21.105449533236673, 21.54065922853802, 21.96724834839357, 22.385709727413158, 22.796490958040014, 23.200000000000003, 23.596609926004202, 23.98666296090392, 24.37047393876451, 24.748333277212836, 25.120509548972134, 25.487251715318386, 25.84879107424562, 26.205342966654722, 26.557108276316534, 26.904274753280383, 27.247018185482244, 27.58550343930667, 27.91988538658424, 28.25030973281532, 28.576913759186805, 28.89982698910151, 29.219171788399482, 29.535063907159575, 29.847612969884214, 30.156922919953224, 30.463092423455638, 30.766215236847064, 31.06638054231616, 31.36367325426026, 31.65817429985501, 31.949960876345376, 32.239106687375816, 32.525682160409794, 32.80975464705581, 33.0913886079143, 33.370645783382734, 33.64758535170095, 33.92226407538271, 34.19473643706002, 34.46505476566083, 34.73326935374786, 34.999428566763775, 35.26357894485471, 35.52576529787923, 35.78603079415207, 36.0444170434202, 36.30096417452297, 36.555710908146764, 36.808694625047494, 37.059951430081504, 37.30951621235526, 37.55742270177761, 37.80370352227411, 38.048390241901174, 38.29151342007783, 38.53310265213535, 38.77318661136843, 39.01179308875715, 39.248949030515455, 39.484680573609815, 39.71901307938052, 39.95197116538807, 40.183578735597955, 40.413859009008284, 40.642834546817724, 40.87052727822336, 41.096958524932234, 41.32214902446387, 41.546118952316114, 41.768887943061166, 41.99047511043427, 42.210899066473345, 42.43017793976359, 42.64832939283789, 42.86537063878021, 43.08131845707604, 43.29618920875139], [0.0, 4.381780460041329, 6.196773353931866, 7.589466384404111, 8.763560920082657, 9.797958971132713, 10.73312629199899, 11.59310139695155, 12.393546707863733, 13.145341380123986, 13.856406460551018, 14.53272169966796, 15.178932768808222, 15.798734126505199, 16.395121225535355, 16.97056274847714, 17.527121840165314, 18.066543665017942, 18.5903200617956, 19.099738218101315, 19.595917942265427, 20.079840636817814, 20.552372125864206, 21.014280858501916, 21.46625258399798, 21.908902300206645, 22.342784070030305, 22.768399153212332, 23.1862027939031, 23.596609926004202, 23.999999999999996, 24.396721091163048, 24.787093415727465, 25.17141235608364, 25.5499510762741, 25.922962793631438, 26.29068276024797, 26.65332999833229, 27.01110882581461, 27.36421020237931, 27.712812921102035, 28.057084666800293, 28.397182958878158, 28.73325599370875, 29.06544339933592, 29.393876913398135, 29.718680993610736, 30.039973368829738, 30.357865537616444, 30.672463220289302, 30.983866769659336, 31.292171544972714, 31.597468253010398, 31.89984325980302, 32.19937887599697, 32.49615361854384, 32.79024245107071, 33.08171700501653, 33.370645783382734, 33.6570943487402, 33.94112549695428, 34.222799417931896, 34.502173844556516, 34.77930419085465, 35.05424368033063, 35.327043465311384, 35.59775273805918, 35.866418834335825, 36.133087330035885, 36.39780213144744, 36.66060555964672, 36.92153842948584, 37.1806401235912, 37.43794866175229, 37.69350076604719, 37.94733192202055, 38.19947643620263, 38.44996749023333, 38.69883719183304, 38.94611662284187, 39.19183588453085, 39.43602414037196, 39.67870965643918, 39.919919839598876, 40.15968127363563, 40.39801975344831, 40.63496031744094, 40.87052727822336, 41.10474425172841, 41.3376341848442, 41.569219381653056, 41.79952152836202, 42.02856171700383, 42.25636046798162, 42.48293775152561, 42.70831300812524, 42.93250516799596, 43.15553266963577, 43.37741347752306, 43.59816509900388, 43.81780460041329, 44.036348622473234], [0.0, 4.454211490264018, 6.299206299209449, 7.714920608794365, 8.908422980528035, 9.959919678390987, 10.910545357588685, 11.784735890124988, 12.598412598418898, 13.362634470792052, 14.085453489327207, 14.772948250095512, 15.42984121758873, 16.059887919907787, 16.666133324799727, 17.251086922278258, 17.81684596105607, 18.365184453198395, 18.897618897628348, 19.415457759218558, 19.919839356781974, 20.41176131547692, 20.892103771520954, 21.361647876509902, 21.82109071517737, 22.27105745132009, 22.712111306525426, 23.144761826383093, 23.569471780249977, 23.98666296090392, 24.396721091163048, 24.8, 25.196825196837796, 25.587496946751163, 25.972292929196684, 26.351470547200964, 26.725268941584105, 27.09391075500176, 27.457603682768823, 27.816541841141937, 28.170906978654415, 28.52086955196142, 28.866589684269947, 29.20821802164589, 29.545896500191024, 29.879759035172956, 30.20993214159873, 30.536535494387703, 30.85968243517746, 31.179480431848123, 31.496031496047245, 31.809432563313674, 32.119775839815574, 32.427149119217994, 32.73163607276606, 33.03331651530013, 33.332266649599454, 33.62855929117392, 33.92226407538271, 34.21344764854895, 34.502173844556516, 34.78850384825424, 35.07249634685276, 35.35420767037497, 35.63369192211214, 35.9110010999415, 36.18618520927565, 36.459292368338694, 36.73036890639679, 36.99945945551097, 37.266607036326775, 37.53185313836768, 37.795237795256696, 38.05679965525215, 38.31657604744975, 38.57460304397182, 38.830915518437116, 39.08554720097955, 39.33853073006159, 39.58989770130759, 39.83967871356395, 40.08790341237616, 40.3346005310577, 40.57979792951167, 40.82352263095384, 41.06580085667392, 41.30665805896188, 41.546118952316114, 41.78420754304191, 42.020947157340466, 42.25636046798162, 42.4904695196464, 42.723295753019805, 42.95486002770816, 43.1851826440505, 43.41428336388843, 43.64218143035474, 43.86889558673663, 44.09444409446614, 44.31884475028654, 44.54211490264018, 44.7642714673209], [0.0, 4.525483399593904, 6.3999999999999995, 7.8383671769061705, 9.050966799187808, 10.119288512538814, 11.085125168440815, 11.973303637676612, 12.799999999999999, 13.576450198781712, 14.310835055998654, 15.009330431434975, 15.676734353812341, 16.316862443496913, 16.932808390813378, 17.527121840165314, 18.101933598375616, 18.65904606350496, 19.2, 19.726124809500725, 20.23857702507763, 20.738370234905155, 21.226398658274558, 21.703455946000858, 22.17025033688163, 22.627416997969522, 23.075528162969533, 23.51510153071851, 23.946607275353223, 24.37047393876451, 24.787093415727465, 25.196825196837796, 25.599999999999998, 25.996922894835073, 26.38787600395303, 26.773120849090418, 27.152900397563425, 27.527440854536405, 27.896953238660313, 28.26163477224911, 28.621670111997307, 28.977232442039735, 29.32848444771738, 29.675579185586248, 30.01866086286995, 30.357865537616437, 30.693321749201406, 31.025151087464504, 31.353468707624682, 31.678383797157327, 32.0, 32.31841580275865, 32.633724886993825, 32.94601645115841, 33.25537550532245, 33.56188314144485, 33.865616781626755, 34.166650406500196, 34.465054765660824, 34.76089757184069, 35.05424368033063, 35.345155254999234, 35.633691922112135, 35.91991091302984, 36.20386719675123, 36.48561360317241, 36.76520093784338, 37.04267808892872, 37.31809212700992, 37.59148839830634, 37.86291061183754, 38.13240092100155, 38.4, 38.66574711550263, 38.9296801939086, 39.191835884530846, 39.45224961900145, 39.710955667170744, 39.96798718974975, 40.223376287924914, 40.47715405015526, 40.729350596345135, 40.97999511957023, 41.2291159255204, 41.47674046981031, 41.72289539329695, 41.967606555532804, 42.21089906647334, 42.452797316549116, 42.693325005204265, 42.93250516799596, 43.17036020234253, 43.406911892001716, 43.64218143035474, 43.876189442566684, 44.10895600668871, 44.34050067376326, 44.570842486989186, 44.8, 45.027991294304925, 45.254833995939045, 45.48054529136607], [0.0, 4.595650117230424, 6.499230723708768, 7.9598994968529615, 9.191300234460847, 10.276186062932105, 11.256997823576233, 12.158947322856532, 12.998461447417537, 13.786950351691269, 14.532721699667961, 15.242047106606122, 15.919798993705923, 16.569852141766386, 17.195348208163743, 17.798876369029593, 18.382600468921694, 18.94835085172322, 19.497692171126307, 20.031974440878265, 20.55237212586421, 21.059914529741096, 21.55550973649197, 22.039963702329462, 22.513995647152466, 22.978250586152118, 23.4333096254029, 23.879698490558884, 24.317894645713064, 24.748333277212836, 25.17141235608364, 25.587496946751163, 25.996922894835073, 26.400000000000006, 26.797014759110766, 27.188232748746287, 27.573900703382538, 27.95424833544984, 28.32948993540124, 28.69982578344336, 29.065443399335923, 29.42651865239924, 29.78321675037806, 30.13569312293978, 30.484094213212245, 30.82855818879631, 31.169215582045055, 31.50618986802435, 31.839597987411846, 32.16955082061296, 32.49615361854384, 32.81950639482563, 33.13970428353277, 33.456837866122385, 33.7709934707287, 34.08225344662527, 34.390696416327486, 34.696397507522306, 34.999428566763775, 35.29985835665634, 35.597752738059185, 35.89317483867929, 36.186185209275656, 36.476841968569595, 36.76520093784339, 37.051315766110115, 37.335238046649714, 37.61701742562799, 37.89670170344644, 38.17433692940848, 38.449967490233334, 38.723636192899036, 38.99538434225261, 39.26525181378569, 39.53327712193868, 39.799497484264805, 40.06394888175653, 40.326666115611395, 40.58768286069064, 40.847031715903185, 41.10474425172842, 41.36085105507381, 41.615381771647854, 41.86836514601448, 42.11982905948219, 42.36980056596916, 42.61830592597506, 42.865370638780206, 43.11101947298394, 43.35527649548553, 43.598165099003886, 43.83970802822483, 44.079927404658925, 44.31884475028654, 44.55648101006183, 44.79285657334214, 45.02799129430493, 45.261904511410044, 45.49461506596138, 45.72614131981837, 45.956501172304236, 46.1857120763554], [0.0, 4.664761515876241, 6.596969000988257, 8.079603950689664, 9.329523031752482, 10.43072384832424, 11.426285485668561, 12.341798896433211, 13.193938001976514, 13.994284547628721, 14.75127113166862, 15.471263684650975, 16.15920790137933, 16.819036833302913, 17.453939383417143, 18.066543665017942, 18.659046063504963, 19.233304448274094, 19.790907002964772, 20.33322404342214, 20.86144769664848, 21.376622745419823, 21.87967092988375, 22.3714103265753, 22.852570971337123, 23.323807579381203, 23.78570999570961, 24.238811852068988, 24.683597792866422, 25.120509548972134, 25.5499510762741, 25.972292929196684, 26.38787600395303, 26.797014759110766, 27.200000000000003, 27.597101297056543, 27.988569095257443, 28.37463656154912, 28.755521208978287, 29.131426329653003, 29.50254226333724, 29.869047524151153, 30.2311098043059, 30.588886870888256, 30.94252736930195, 31.29217154497271, 31.637951893256304, 31.979993746090695, 32.31841580275866, 32.65333061113368, 32.984845004941285, 33.313060501851226, 33.63807366660583, 33.9599764428658, 34.27885645700568, 34.59479729670345, 34.90787876683429, 35.21817712488822, 35.52576529787923, 35.83071308249391, 36.133087330035885, 36.432952117554244, 36.730368906396784, 37.02539668929963, 37.318092127009926, 37.608509675338105, 37.89670170344644, 38.18271860410152, 38.46660889654819, 38.748419322599474, 39.0281949364815, 39.30597918892239, 39.581814005929544, 39.85573986265968, 40.127795852750246, 40.39801975344831, 40.66644808684428, 40.9331161774913, 41.19805820666795, 41.46130726351981, 41.72289539329696, 41.98285364288617, 42.24121210382108, 42.49799995293896, 42.753245490839646, 43.00697617828996, 43.25921867070648, 43.509998850838876, 43.7593418597675, 44.00727212632021, 44.253813395005864, 44.498988752554816, 44.7428206531506, 44.98533094243056, 45.22654088032823, 45.46647116282503, 45.705141942674246, 45.94257284915594, 46.1787830069178, 46.41379105395292, 46.647615158762406, 46.88027303674756], [0.0, 4.732863826479693, 6.6932802122726045, 8.19756061276768, 9.465727652959385, 10.583005244258363, 11.593101396951552, 12.521980673998822, 13.386560424545209, 14.198591479439077, 14.966629547095765, 15.697133496278868, 16.39512122553536, 17.064583206161235, 17.708754896942924, 18.33030277982336, 18.93145530591877, 19.51409746824075, 20.079840636817814, 20.630075133164205, 21.166010488516726, 21.688706738761535, 22.199099080818574, 22.698017534577772, 23.186202793903103, 23.664319132398465, 24.13296500639737, 24.592681838303037, 25.043961347997644, 25.487251715318386, 25.922962793631438, 26.351470547200964, 26.773120849090418, 27.188232748746287, 27.597101297056543, 28.0, 28.397182958878155, 28.78888674471453, 29.175332046096752, 29.556725123057866, 29.93325909419153, 30.3051150798013, 30.672463220289305, 31.035463586033313, 31.394266992557736, 31.749015732775085, 32.09984423638221, 32.4468796650772, 32.79024245107072, 33.13004678535785, 33.46640106136302, 33.799408278844176, 34.12916641232247, 34.45576874777285, 34.77930419085465, 35.09985754956849, 35.41750979388585, 35.73233829460367, 36.0444170434202, 36.35381685600564, 36.66060555964672, 36.964848166873345, 37.26660703632677, 37.56594202199647, 37.86291061183754, 38.157568056677825, 38.44996749023333, 38.7401600409704, 39.0281949364815, 39.31411960097797, 39.59797974644666, 39.879819457966455, 40.15968127363563, 40.43760625952036, 40.71363407999831, 40.98780306383839, 41.26015026632841, 41.53071152773571, 41.79952152836203, 42.0666138404317, 42.33202097703345, 42.595774438317235, 42.8579047551324, 43.11844153027797, 43.37741347752307, 43.63484845854286, 43.89077351790465, 44.14521491622846, 44.39819816163715, 44.64974803960264, 44.8998886412873, 45.148643390471875, 45.396035069155545, 45.64208584190692, 45.88681727903996, 46.13025037868318, 46.372405587806206, 46.613302822263094, 46.85296148590823, 47.091400488836605, 47.32863826479693, 47.5646927878232], [0.0, 4.8, 6.788225099390856, 8.313843876330612, 9.6, 10.73312629199899, 11.757550765359255, 12.699606293110035, 13.576450198781712, 14.399999999999999, 15.17893276880822, 15.91979899370592, 16.627687752661224, 17.30664612222715, 17.95995545651492, 18.590320061795598, 19.2, 19.79090700296477, 20.364675298172568, 20.922714928995234, 21.46625258399798, 21.996363335788033, 22.513995647152463, 23.019991311901055, 23.51510153071851, 24.0, 24.475293665245367, 24.941531628991832, 25.39921258622007, 25.84879107424562, 26.29068276024797, 26.725268941584105, 27.152900397563425, 27.573900703382538, 27.988569095257443, 28.397182958878155, 28.799999999999997, 29.197260145431454, 29.589187214251087, 29.975990392312312, 30.35786553761644, 30.734996339677675, 31.107555352357732, 31.4757049166496, 31.83959798741184, 32.19937887599697, 32.55518391900129, 32.90714208192501, 33.25537550532245, 33.6, 33.94112549695428, 34.27885645700568, 34.6132922444543, 34.94452746854649, 35.272652296077766, 35.597752738059185, 35.91991091302984, 36.2392052892996, 36.55571090814676, 36.86949958976932, 37.180640123591196, 37.48919844435194, 37.79523779525669, 38.0988188793301, 38.4, 38.698837191833036, 38.995384342252606, 39.28969330498776, 39.58181400592954, 39.87179454200676, 40.15968127363563, 40.445518911246516, 40.729350596345135, 41.01121797752415, 41.291161281804605, 41.569219381653056, 41.84542985799047, 42.119829059482186, 42.39245215837367, 42.663333203114824, 42.93250516799596, 43.2, 43.4658486630596, 43.73008117989263, 43.992726671576065, 44.25381339500586, 44.51336877837938, 44.771419454826315, 45.027991294304925, 45.283109433871694, 45.53679830642466, 45.78908166801339, 46.03998262380211, 46.289523652766185, 46.53772663119676, 46.78461285508302, 47.03020306143702, 47.2745174486213, 47.51757569573599, 47.75939698111776, 48.0, 48.23940298138028], [0.0, 4.866210024238576, 6.881860213634101, 8.428523002282192, 9.732420048477152, 10.881176406988356, 11.919731540601072, 12.874781551544865, 13.763720427268202, 14.598630072715727, 15.388307249337076, 16.139392801465615, 16.857046004564385, 17.54536975956905, 18.207690682785667, 18.846750383023593, 19.464840096954305, 20.063897926375123, 20.645580640902306, 21.211317733700568, 21.76235281397671, 22.299775783626167, 22.82454818829937, 23.33752343330372, 23.839463081202144, 24.33105012119288, 24.81289987083332, 25.285569006846575, 25.74956310308973, 26.205342966654722, 26.65332999833229, 27.09391075500176, 27.527440854536405, 27.95424833544984, 28.37463656154912, 28.78888674471453, 29.197260145431454, 29.6, 29.997333214804282, 30.38947186115613, 30.776614498674153, 31.15894735064072, 31.53664535108324, 31.90987308028661, 32.27878560293123, 32.643529220965064, 33.00424215157803, 33.36105513918887, 33.71409200912877, 34.06347016967003, 34.409301068170514, 34.75169060635756, 35.0907395191381, 35.42654372077525, 35.75919462180322, 36.08877941964788, 36.415381365571335, 36.73908001025611, 37.059951430081504, 37.37806843591573, 37.69350076604719, 38.00631526470305, 38.31657604744975, 38.6243446546346, 38.92968019390861, 39.23263947276553, 39.53327712193868, 39.831645710414726, 40.127795852750246, 40.4217763093113, 40.713634079998315, 41.003414491966396, 41.29116128180461, 41.576916672596106, 41.860721446243616, 42.14261501141096, 42.422635467401136, 42.70081966426406, 42.97720325940254, 43.25182077092247, 43.52470562795342, 43.795890218147186, 44.065405932545325, 44.33328320799171, 44.599551567252334, 44.86423965699185, 45.12737528374546, 45.38898544801371, 45.64909637659874, 45.907733553291436, 46.16492174801123, 46.42068504449283, 46.67504686660744, 46.92803000339989, 47.17965663291754, 47.42994834490124, 47.67892616240429, 47.92661056240052, 48.17302149543871, 48.41817840439684, 48.66210024238576, 48.904805489849366], [0.0, 4.931531202375181, 6.974238309665078, 8.54166260162505, 9.863062404750362, 11.027239001672179, 12.0797350964332, 13.047605144240073, 13.948476619330156, 14.794593607125543, 15.594870951694343, 16.356038640208702, 17.0833252032501, 17.780888616714297, 18.452100151473275, 19.099738218101315, 19.726124809500725, 20.333224043422135, 20.922714928995234, 21.49604614807105, 22.054478003344357, 22.599115026920856, 23.130931671681537, 23.650792798551176, 24.1594701928664, 24.657656011875908, 25.145973832802742, 25.62498780487515, 26.095210288480146, 26.557108276316534, 27.01110882581461, 27.457603682768823, 27.896953238660313, 28.32948993540124, 28.755521208978287, 29.175332046096752, 29.589187214251087, 29.997333214804282, 30.400000000000002, 30.797402487872258, 31.189741903388686, 31.577206969584886, 31.95997496870109, 32.33821269025238, 32.712077280417404, 33.08171700501653, 33.447271936587, 33.808874574584706, 34.1666504065002, 34.52071841662627, 34.87119154832539, 35.21817712488823, 35.56177723342859, 35.90208907570701, 36.239205289299605, 36.573214242119874, 36.90420030294655, 37.232244090304306, 37.55742270177761, 37.879809925605485, 38.19947643620263, 38.516489975074315, 38.83091551843711, 39.14281543272022, 39.45224961900145, 39.75927564732537, 40.06394888175653, 40.36632259693717, 40.66644808684427, 40.964374766374746, 41.26015026632841, 41.55382052230577, 41.84542985799047, 42.13502106324382, 42.42263546740113, 42.708313008125245, 42.9920922961421, 43.27401067615527, 43.554104284211846, 43.83240810176872, 44.108956006688715, 44.38378082137663, 44.65691435824917, 44.928387462716714, 45.19823005384171, 45.46647116282504, 45.73313896946065, 45.99826083668817, 46.261863343363075, 46.52397231535588, 46.784612855083026, 47.0438093695653, 47.30158559710235, 47.55796463264593, 47.8129689519486, 48.06662043455937, 48.3189403857328, 48.569949557313734, 48.81966816765554, 49.0681159206261, 49.315312023751815, 49.56127520554733], [0.0, 4.9959983987187195, 7.0654086930622775, 8.653323061113577, 9.991996797437439, 11.171392035015154, 12.237646832622685, 13.218169313486646, 14.130817386124555, 14.987995196156156, 15.7987341265052, 16.569852141766386, 17.306646122227153, 18.013328398716325, 18.693314312876677, 19.349418595916518, 19.983993594874878, 20.599029103333976, 21.196226079186836, 21.777052142105923, 22.34278407003031, 22.894540834006698, 23.4333096254029, 23.959966610995103, 24.47529366524537, 24.979991993593597, 25.474693324945058, 25.95996918334073, 26.436338626973292, 26.904274753280383, 27.36421020237931, 27.816541841141937, 28.26163477224911, 28.69982578344336, 29.131426329653003, 29.556725123057866, 29.975990392312312, 30.38947186115613, 30.797402487872258, 31.200000000000006, 31.5974682530104, 31.989998437011533, 32.377770151756906, 32.76095236710923, 33.13970428353277, 33.51417610504546, 33.8845097352758, 34.25083940577223, 34.61329224445431, 34.97198879103103, 35.32704346531139, 35.67856499356442, 36.02665679743265, 36.37141734934178, 36.712940497868054, 37.05131576611012, 37.38662862575335, 37.71896074920411, 38.048390241901174, 38.374991856676665, 38.698837191833036, 39.01999487442304, 39.33853073006159, 39.654507940459936, 39.967987189749756, 40.27902680055713, 40.587682860690634, 40.894009341222585, 41.19805820666795, 41.499879517897405, 41.79952152836203, 42.09703077415318, 42.39245215837367, 42.685829030253124, 42.977203259402536, 43.266615305567875, 43.554104284211846, 43.83970802822483, 44.12346314604058, 44.405405076409345, 44.68556814006062, 44.963985588468475, 45.24068964991582, 45.51571157303816, 45.789081668013395, 46.060829345551305, 46.33098315382483, 46.599570813474244, 46.8666192508058, 47.132154629297396, 47.3962023795156, 47.65878722754074, 47.919933221990206, 48.17966375972336, 48.43800161030594, 48.69496893930624, 48.95058733049074, 49.204877806981706, 49.457860851435946, 49.709556425299155, 49.959983987187194, 50.20916251044226], [0.0, 5.059644256269407, 7.155417527999327, 8.763560920082659, 10.119288512538814, 11.313708498984761, 12.393546707863734, 13.386560424545209, 14.310835055998654, 15.17893276880822, 16.0, 16.780941570722426, 17.527121840165318, 18.24280680158621, 18.93145530591877, 19.595917942265423, 20.23857702507763, 20.861447696648476, 21.46625258399798, 22.054478003344357, 22.627416997969522, 23.186202793903103, 23.731835158706122, 24.265201420964964, 24.78709341572747, 25.298221281347036, 25.79922479455536, 26.290682760247975, 26.773120849090418, 27.247018185482244, 27.712812921102035, 28.170906978654415, 28.621670111997307, 29.065443399335923, 29.50254226333724, 29.93325909419153, 30.35786553761644, 30.776614498674153, 31.189741903388686, 31.5974682530104, 32.0, 32.39753077010654, 32.79024245107072, 33.17830616532435, 33.56188314144485, 33.94112549695428, 34.31617694324355, 34.68717342188608, 35.054243680330636, 35.41750979388585, 35.77708763999664, 36.13308733003589, 36.48561360317242, 36.834766186308286, 37.1806401235912, 37.52332607858744, 37.86291061183754, 38.19947643620263, 38.53310265213535, 38.86386496477158, 39.191835884530846, 39.5170849127311, 39.83967871356394, 40.15968127363563, 40.47715405015526, 40.792156108742276, 41.10474425172841, 41.41497313774331, 41.72289539329695, 42.02856171700383, 42.33202097703345, 42.63332030231753, 42.93250516799596, 43.22961947554015, 43.524705627953416, 43.81780460041329, 44.108956006688715, 44.39819816163715, 44.68556814006062, 44.97110183217663, 45.254833995939045, 45.536798306424664, 45.817027402484335, 46.095552930841386, 46.372405587806206, 46.647615158762406, 46.92121055556858, 47.193219852008404, 47.463670317412245, 47.73258844856415, 48.0, 48.26593001279474, 48.53040284192993, 48.7934421823261, 49.05507109361886, 49.31531202375181, 49.57418683145494, 49.8317168076718, 50.08792269599529, 50.34282471216728, 50.59644256269407, 50.848795462626256], [0.0, 5.122499389946279, 7.244308110509934, 8.872429205127535, 10.244998779892558, 11.454256850621084, 12.5475097130865, 13.552859476877934, 14.488616221019868, 15.367498169838838, 16.19876538505327, 16.989408465276245, 17.74485841025507, 18.469434208984318, 19.166637681137505, 19.83935482821959, 20.489997559785117, 21.12060605191054, 21.7329243315298, 22.328457179124584, 22.908513701242168, 23.474241201793937, 24.02665186828993, 24.566644052454542, 25.095019426173, 25.612496949731398, 26.119724347703215, 26.617287615382605, 27.10571895375587, 27.58550343930667, 28.057084666800293, 28.52086955196142, 28.977232442039735, 29.42651865239924, 29.869047524151153, 30.3051150798013, 30.734996339677675, 31.15894735064072, 31.577206969584886, 31.989998437011533, 32.39753077010654, 32.800000000000004, 33.197590273994294, 33.59047484034723, 33.97881693055249, 34.36277055186325, 34.74248120097354, 35.11808650823675, 35.48971682051014, 35.857495729623956, 36.22154055254967, 36.58196276855577, 36.938868417968635, 37.292358466581334, 37.642529139259494, 37.989472225868056, 38.33327536227501, 38.67402228886983, 39.01179308875715, 39.346664407545404, 39.67870965643918, 40.007999200159965, 40.3346005310577, 40.6585784306338, 40.97999511957023, 41.29891039724898, 41.615381771647854, 41.92946458041171, 42.24121210382108, 42.550675670311044, 42.8579047551324, 43.16294707269188, 43.4658486630596, 43.76665397308778, 44.06540593254532, 44.36214602563767, 44.65691435824917, 44.94974972121648, 45.24068964991582, 45.52977048042303, 45.817027402484335, 46.10249450951652, 46.386204845837526, 46.66819045131277, 46.948482403587875, 47.227110858065416, 47.50410508577128, 47.779493509245164, 48.05330373657986, 48.32556259372466, 48.59629615515981, 48.86552977304145, 49.133288104909084, 49.39959514004139, 49.66447422454003, 49.92794808521576, 50.190038852346, 50.4507680813682, 50.71015677356954, 50.96822539582873, 51.224993899462795, 51.48048173822775], [0.0, 5.184592558726289, 7.332121111929345, 8.979977728257461, 10.369185117452577, 11.593101396951553, 12.699606293110037, 13.717142559585799, 14.66424222385869, 15.553777676178866, 16.39512122553536, 17.195348208163743, 17.959955456514923, 18.69331431287668, 19.398969044771427, 20.079840636817814, 20.738370234905155, 21.376622745419823, 21.996363335788033, 22.59911502692086, 23.186202793903107, 23.758787847868, 24.317894645713064, 24.86443242867209, 25.399212586220074, 25.922962793631445, 26.436338626973296, 26.939933184772382, 27.434285119171598, 27.91988538658424, 28.397182958878158, 28.866589684269947, 29.32848444771738, 29.78321675037806, 30.2311098043059, 30.672463220289305, 31.107555352357732, 31.53664535108324, 31.95997496870109, 32.377770151756906, 32.79024245107072, 33.197590273994294, 33.60000000000001, 33.997646977401246, 34.390696416327486, 34.77930419085465, 35.16361756133746, 35.5437758264369, 35.919910913029845, 36.29214791108402, 36.660605559646726, 37.02539668929964, 37.38662862575336, 37.74440355867345, 38.09881887933011, 38.449967490233334, 38.79793808954285, 39.14281543272022, 39.484680573609815, 39.82361108689166, 40.15968127363563, 40.49296235150005, 40.82352263095384, 41.15142767875739, 41.47674046981031, 41.79952152836202, 42.11982905948219, 42.4377190715995, 42.753245490839646, 43.066460267823274, 43.37741347752308, 43.68615341272336, 43.992726671576065, 44.29717823970281, 44.599551567252334, 44.8998886412873, 45.19823005384172, 45.49461506596138, 45.7890816680134, 46.08166663652695, 46.37240558780621, 46.6613330285366, 46.94848240358788, 47.23388614120164, 47.517575695736, 47.799581588126905, 48.07993344421351, 48.35866003106373, 48.63578929142613, 48.911348376424876, 49.18536367660607, 49.457860851435946, 49.72886485734418, 49.99839997439919, 50.266489831696035, 50.533157431532025, 50.79842517244015, 51.06231487114544, 51.32484778350541, 51.58604462449124, 51.84592558726289, 52.10451036138811], [0.0, 5.2459508194416005, 7.418894796396562, 9.086253353280439, 10.491901638883201, 11.730302638892145, 12.849902723367208, 13.879481258317977, 14.837789592793124, 15.7378524583248, 16.589153082662175, 17.398850536745236, 18.172506706560878, 18.914544668059023, 19.628550634216474, 20.317480158720468, 20.983803277766402, 21.629609335353237, 22.256684389189687, 22.866569484730324, 23.46060527778429, 24.03996672210675, 24.605690398767518, 25.15869630962622, 25.699805446734416, 26.229754097208, 26.74920559568078, 27.25876005984131, 27.758962516635954, 28.25030973281532, 28.73325599370875, 29.20821802164589, 29.675579185586248, 30.13569312293978, 30.588886870888256, 31.035463586033313, 31.4757049166496, 31.90987308028661, 32.33821269025238, 32.76095236710923, 33.17830616532435, 33.59047484034723, 33.997646977401246, 34.39999999999999, 34.79770107349047, 35.19090791667642, 35.57976953269934, 35.96442686878243, 36.345013413121755, 36.7216557360912, 37.094473981982816, 37.46358231669791, 37.829089336118045, 38.191098439296034, 38.549708170101624, 38.90501253052105, 39.25710126843295, 39.606060142357, 39.95197116538807, 40.29491283028168, 40.634960317440935, 40.97218568736601, 41.30665805896187, 41.638443774953934, 41.967606555532804, 42.29420764123616, 42.618305925975044, 42.93995808102285, 43.259218670706474, 43.57614026046823, 43.89077351790465, 44.20316730733217, 44.51336877837937, 44.8214234490606, 45.127375283745444, 45.43126676640219, 45.73313896946065, 46.033031618610565, 46.33098315382483, 46.62703078687297, 46.92121055556858, 47.2135573749744, 47.50410508577127, 47.792886499980305, 48.0799334442135, 48.365276800613884, 48.648946545634466, 48.930971786793684, 49.211380797535035, 49.49020105030893, 49.76745924798652, 50.04318135370692, 50.31739261925244, 50.590117612039606, 50.86138024080746, 51.13120378007933, 51.39961089346883, 51.666623655896075, 51.93226357477594, 52.19655161023571, 52.459508194416, 52.7211532499053], [0.0, 5.30659966456864, 7.504665215717488, 9.191300234460847, 10.61319932913728, 11.865917579353063, 12.998461447417538, 14.039943019827396, 15.009330431434975, 15.91979899370592, 16.780941570722426, 17.6, 18.382600468921694, 19.133217188962238, 19.855477833585372, 20.552372125864206, 21.22639865827456, 21.87967092988375, 22.513995647152463, 23.13093167168154, 23.731835158706126, 24.317894645713064, 24.890158697766477, 25.44955795293899, 25.996922894835077, 26.532998322843202, 27.058455240460425, 27.57390070338254, 28.07988603965479, 28.576913759186805, 29.06544339933592, 29.545896500191024, 30.01866086286995, 30.484094213212245, 30.94252736930195, 31.394266992557736, 31.83959798741184, 32.27878560293123, 32.712077280417404, 33.13970428353277, 33.56188314144485, 33.97881693055249, 34.390696416327486, 34.79770107349047, 35.2, 35.597752738059185, 35.99111001344638, 36.38021440288664, 36.76520093784339, 37.14619765198048, 37.52332607858744, 37.896701703446446, 38.266434377924476, 38.63262869647884, 38.99538434225261, 39.3547964039963, 39.710955667170744, 40.06394888175653, 40.41385900900829, 40.76076544914239, 41.10474425172841, 41.44586831036358, 41.78420754304191, 42.11982905948219, 42.45279731654912, 42.783174262787, 43.11101947298394, 43.436390273594334, 43.7593418597675, 44.07992740465892, 44.398198161637154, 44.71420355994279, 45.027991294304925, 45.33960740897522, 45.64909637659874, 45.956501172304236, 46.26186334336308, 46.5652230747368, 46.8666192508058, 47.16608951354777, 47.46367031741225, 47.75939698111777, 48.05330373657987, 48.34542377516201, 48.63578929142613, 48.9244315245461, 49.21138079753504, 49.496666554425666, 49.780317395532954, 50.06236111091845, 50.34282471216728, 50.621734462580406, 50.89911590587798, 51.17499389350233, 51.44939261060329, 51.72233560078276, 51.993845789670154, 52.26394550739545, 52.53265651002241, 52.80000000000001, 53.065996645686404, 53.330666599996675], [0.0, 5.366563145999495, 7.589466384404109, 9.2951600308978, 10.73312629199899, 12.0, 13.145341380123986, 14.198591479439077, 15.178932768808219, 16.099689437998485, 16.97056274847714, 17.798876369029593, 18.5903200617956, 19.349418595916518, 20.07984063681781, 20.784609690826525, 21.46625258399798, 22.12690669750293, 22.76839915321233, 23.392306427541513, 24.0, 24.592681838303037, 25.171412356083636, 25.73713270743266, 26.29068276024797, 26.832815729997474, 27.36421020237931, 27.885480092693403, 28.397182958878155, 28.89982698910151, 29.393876913398135, 29.879759035172956, 30.357865537616437, 30.82855818879631, 31.29217154497271, 31.749015732775085, 32.19937887599697, 32.643529220965064, 33.08171700501653, 33.51417610504546, 33.94112549695428, 34.36277055186325, 34.77930419085465, 35.19090791667642, 35.597752738059185, 35.99999999999999, 36.39780213144744, 36.79130332021414, 37.1806401235912, 37.56594202199646, 37.94733192202055, 38.32492661441115, 38.698837191833036, 39.0691694306393, 39.436024140371956, 39.7994974842648, 40.15968127363562, 40.51666323872191, 40.87052727822336, 41.2213536895624, 41.56921938165305, 41.91419807177515, 42.256360467981615, 42.595774438317235, 42.93250516799596, 43.26661530556787, 43.59816509900388, 43.9272125225355, 44.25381339500586, 44.5780214904161, 44.8998886412873, 45.219464835400245, 45.53679830642466, 45.851935618902715, 46.164921748011224, 46.475800154489, 46.784612855083026, 47.0914004888366, 47.3962023795156, 47.69905659444429, 48.0, 48.299068313995456, 48.59629615515981, 48.89171708991206, 49.18536367660607, 49.47726750741192, 49.76745924798653, 50.055968675074105, 50.34282471216727, 50.62805546334956, 50.91168824543142, 51.19374961848369, 51.47426541486532, 51.75326076683478, 52.030760132829116, 52.30678732248808, 52.58136552049594, 52.85451730930858, 53.12626469082877, 53.39662910708877, 53.66563145999495, 53.93329213018616], [0.0, 5.4258639865002145, 7.6733304373003515, 9.397872099576587, 10.851727973000429, 12.132600710482482, 13.29059818066892, 14.35548675594109, 15.346660874600703, 16.277591959500644, 17.158088471621774, 17.99555500672319, 18.795744199153173, 19.563230817019974, 20.301724064719235, 21.014280858501913, 21.703455946000858, 22.3714103265753, 23.019991311901055, 23.650792798551176, 24.265201420964964, 24.86443242867209, 25.44955795293899, 26.02152954766495, 26.58119636133784, 27.129319932501076, 27.666586345264935, 28.193616298729758, 28.71097351188218, 29.219171788399482, 29.718680993610736, 30.20993214159873, 30.693321749201406, 31.169215582045055, 31.637951893256304, 32.09984423638221, 32.55518391900129, 33.00424215157803, 33.447271936587, 33.8845097352758, 34.31617694324355, 34.74248120097354, 35.16361756133746, 35.57976953269934, 35.99111001344638, 36.39780213144744, 36.800000000000004, 37.197849400200546, 37.591488398306346, 37.981047905501505, 38.36665218650176, 38.748419322599474, 39.12646163403995, 39.50088606601123, 39.87179454200676, 40.23928428786974, 40.60344812943847, 40.964374766374746, 41.32214902446387, 41.67685208841954, 42.028561717003825, 42.37735244207689, 42.723295753019805, 43.06646026782327, 43.406911892001716, 43.74471396637541, 44.07992740465892, 44.41261082170243, 44.7428206531506, 45.07061126721048, 45.396035069155545, 45.71914259913456, 46.03998262380211, 46.358602222241345, 46.67504686660743, 46.98936049788293, 47.30158559710235, 47.61176325237284, 47.919933221990206, 48.22613399392492, 48.53040284192993, 48.832775878501934, 49.133288104909084, 49.4319734584813, 49.72886485734418, 50.023994242763145, 50.317392619252445, 50.609090092591074, 50.89911590587798, 51.18749847374845, 51.47426541486532, 51.7594435827898, 52.0430590953299, 52.32513736245707, 52.60570311287552, 52.88478041932291, 53.16239272267568, 53.43856285492716, 53.71331306110246, 53.98666502016957, 54.25863986500215, 54.52925820144632], [0.0, 5.4845236803208355, 7.756287771866126, 9.499473669630335, 10.969047360641671, 12.263767773404714, 13.434284498997332, 14.510685717773644, 15.512575543732252, 16.453571040962505, 17.34358671094304, 18.19010720144332, 18.99894733926067, 19.77473135089324, 20.521208541409056, 21.241468875762806, 21.938094721283342, 22.61327044016411, 23.26886331559838, 23.9064844759743, 24.52753554680943, 25.133244915848014, 25.724696305301645, 26.302851556437755, 26.868568997994664, 27.42261840160418, 27.965693268717658, 28.498421008891004, 29.021371435547287, 29.535063907159575, 30.039973368829738, 30.536535494387703, 31.025151087464504, 31.50618986802435, 31.979993746090695, 32.4468796650772, 32.90714208192501, 33.36105513918887, 33.808874574584706, 34.25083940577223, 34.68717342188608, 35.11808650823675, 35.5437758264369, 35.96442686878243, 36.38021440288664, 36.79130332021414, 37.197849400200546, 37.6, 37.99789467852134, 38.39166576224585, 38.781438859330635, 39.16733332765968, 39.54946270178648, 39.927935083096905, 40.302853496992, 40.67431622043572, 41.04241708281811, 41.40724574274411, 41.768887943061166, 42.127425746181075, 42.48293775152561, 42.83549929672817, 43.18518264405049, 43.532057153320935, 43.876189442566684, 44.21764353739353, 44.55648101006182, 44.89276110911424, 45.22654088032822, 45.55787527969232, 45.88681727903996, 46.21341796491578, 46.53772663119676, 46.85979086594391, 47.179656632917535, 47.49736834815167, 47.8129689519486, 48.12649997662411, 48.43800161030594, 48.7475127570628, 49.05507109361886, 49.36071312288752, 49.66447422454002, 49.96638870280701, 50.26648983169603, 50.564809897793545, 50.86138024080747, 51.15623129199414, 51.44939261060329, 51.740892918464404, 52.030760132829116, 52.31902139757585, 52.60570311287551, 52.89083096340991, 53.174429945228376, 53.45652439132196, 53.73713799598933, 54.01629383806335, 54.29401440306289, 54.570321604329955, 54.84523680320836, 55.118780828316595], [0.0, 5.542562584220408, 7.8383671769061705, 9.600000000000003, 11.085125168440817, 12.393546707863736, 13.576450198781714, 14.66424222385869, 15.676734353812341, 16.627687752661224, 17.527121840165318, 18.382600468921694, 19.200000000000006, 19.983993594874878, 20.738370234905155, 21.46625258399798, 22.170250336881633, 22.852570971337123, 23.515101530718514, 24.159470192866404, 24.787093415727472, 25.399212586220074, 25.996922894835077, 26.581196361337845, 27.152900397563428, 27.712812921102042, 28.261634772249117, 28.800000000000004, 29.32848444771738, 29.847612969884214, 30.357865537616444, 30.85968243517746, 31.353468707624682, 31.839597987411846, 32.31841580275866, 32.79024245107072, 33.25537550532245, 33.71409200912877, 34.1666504065002, 34.61329224445431, 35.054243680330636, 35.48971682051014, 35.919910913029845, 36.345013413121755, 36.76520093784339, 37.1806401235912, 37.591488398306346, 37.99789467852134, 38.40000000000001, 38.79793808954285, 39.19183588453085, 39.58181400592955, 39.967987189749756, 40.35046468133918, 40.72935059634514, 41.10474425172842, 41.47674046981031, 41.845429857990474, 42.21089906647335, 42.57323102608023, 42.93250516799596, 43.28879762709979, 43.64218143035474, 43.99272667157607, 44.340500673763266, 44.68556814006062, 45.02799129430493, 45.367830012025046, 45.705141942674246, 46.03998262380212, 46.37240558780621, 46.70246246184456, 47.03020306143703, 47.35567547823598, 47.67892616240429, 48.00000000000001, 48.31894038573281, 48.63578929142613, 48.95058733049075, 49.2633738186901, 49.574186831454945, 49.88306325798367, 50.190038852346, 50.49514828179041, 50.79842517244015, 51.09990215254821, 51.39961089346884, 51.69758214849125, 51.993845789670154, 52.28843084277822, 52.58136552049595, 52.872677253946584, 53.16239272267569, 53.450537883168224, 53.737137995989336, 54.02221765162923, 54.305800795126856, 54.58791074954235, 54.868570238343196, 55.14780140676508, 55.425625842204084, 55.702064593693486], [0.0, 5.6000000000000005, 7.919595949289332, 9.699484522385713, 11.200000000000001, 12.521980673998824, 13.717142559585797, 14.816207341961707, 15.839191898578663, 16.8, 17.708754896942924, 18.57309882599024, 19.398969044771427, 20.19108714259834, 20.95328136593407, 21.68870673876153, 22.400000000000002, 23.0893915034589, 23.758787847867996, 24.409834083827775, 25.043961347997648, 25.662423891752706, 26.266328255011206, 26.85665653055123, 27.434285119171594, 28.0, 28.554509276119596, 29.09845356715714, 29.632414683923415, 30.156922919953224, 30.672463220289302, 31.179480431848123, 31.678383797157327, 32.16955082061296, 32.65333061113368, 33.13004678535785, 33.6, 34.06347016967003, 34.52071841662627, 34.97198879103103, 35.41750979388585, 35.857495729623956, 36.29214791108402, 36.7216557360912, 37.14619765198048, 37.56594202199646, 37.981047905501505, 38.39166576224585, 38.79793808954285, 39.2, 39.59797974644666, 39.99199919983997, 40.38217428519668, 40.7686153799709, 41.15142767875739, 41.53071152773571, 41.90656273186814, 42.279072837516196, 42.64832939283789, 43.0144161880642, 43.37741347752306, 43.73739818507726, 44.09444409446614, 44.44862202588512, 44.800000000000004, 45.148643390471875, 45.494615065961376, 45.83797552248572, 46.1787830069178, 46.51709363234122, 46.85296148590823, 47.18643872978761, 47.51757569573599, 47.84642097377817, 48.17302149543871, 48.49742261192856, 48.81966816765555, 49.13980056939589, 49.457860851435946, 49.7738887369673, 50.087922695995296, 50.400000000000006, 50.71015677356954, 51.018428043208075, 51.32484778350541, 51.62944896084017, 51.932263574775945, 52.23332269729737, 52.53265651002241, 52.83029433951698, 53.126264690828776, 53.42059527934896, 53.71331306110246, 54.00444426156055, 54.29401440306289, 54.58204833093019, 54.86857023834319, 55.15360369005819, 55.43717164502532, 55.71929647797072, 56.0, 56.279303478276994], [0.0, 5.656854249492381, 8.0, 9.797958971132713, 11.313708498984761, 12.649110640673518, 13.85640646055102, 14.966629547095767, 16.0, 16.97056274847714, 17.88854381999832, 18.76166303929372, 19.595917942265427, 20.39607805437114, 21.166010488516726, 21.908902300206645, 22.627416997969522, 23.323807579381203, 24.0, 24.65765601187591, 25.298221281347036, 25.922962793631445, 26.532998322843202, 27.129319932501076, 27.71281292110204, 28.284271247461906, 28.844410203711917, 29.39387691339814, 29.933259094191534, 30.463092423455638, 30.983866769659336, 31.496031496047245, 32.0, 32.49615361854384, 32.984845004941285, 33.46640106136302, 33.94112549695428, 34.409301068170514, 34.87119154832539, 35.32704346531139, 35.77708763999664, 36.22154055254967, 36.660605559646726, 37.094473981982816, 37.52332607858744, 37.94733192202055, 38.36665218650176, 38.781438859330635, 39.19183588453085, 39.59797974644666, 40.00000000000001, 40.39801975344832, 40.79215610874228, 41.18252056394801, 41.569219381653056, 41.95235392680607, 42.33202097703345, 42.708313008125245, 43.08131845707604, 43.45112196480086, 43.81780460041329, 44.181444068749045, 44.54211490264017, 44.8998886412873, 45.254833995939045, 45.60701700396552, 45.95650117230423, 46.3033476111609, 46.647615158762406, 46.98936049788293, 47.328638264796936, 47.665501151251945, 48.0, 48.33218389437829, 48.662100242385755, 48.98979485566357, 49.31531202375182, 49.63869458396343, 49.959983987187194, 50.27922035990614, 50.59644256269407, 50.91168824543143, 51.224993899462795, 51.536394906900505, 51.84592558726289, 52.15361924162119, 52.45950819441601, 52.76362383309168, 53.065996645686404, 53.36665625650534, 53.665631459994955, 53.96295025292817, 54.25863986500215, 54.55272678794343, 54.84523680320836, 55.136195008360886, 55.42562584220408, 55.713553108736484, 56.0, 56.28498911788116, 56.56854249492381, 56.85068161420759], [0.0, 5.713142742834281, 8.079603950689663, 9.895453501482388, 11.426285485668561, 12.774975538137053, 13.994284547628723, 15.11555490215295, 16.159207901379325, 17.13942822850284, 18.066543665017946, 18.948350851723223, 19.790907002964776, 20.599029103333976, 21.376622745419823, 22.12690669750293, 22.852570971337123, 23.555890982936734, 24.23881185206899, 24.903011866037414, 25.549951076274105, 26.18090907512572, 26.797014759110766, 27.399270063269938, 27.988569095257446, 28.565713714171405, 29.131426329653003, 29.686360504447162, 30.2311098043059, 30.766215236847064, 31.292171544972714, 31.809432563313674, 32.31841580275865, 32.81950639482563, 33.313060501851226, 33.799408278844176, 34.27885645700568, 34.75169060635756, 35.21817712488823, 35.67856499356442, 36.13308733003589, 36.58196276855577, 37.02539668929964, 37.46358231669791, 37.896701703446446, 38.32492661441115, 38.748419322599474, 39.16733332765968, 39.58181400592955, 39.99199919983997, 40.39801975344832, 40.80000000000001, 41.19805820666795, 41.592306980979075, 41.98285364288617, 42.36980056596916, 42.753245490839646, 43.133281813467434, 43.50999885083888, 43.88348208608793, 44.25381339500586, 44.62107125562989, 44.98533094243056, 45.346664706458846, 45.705141942674246, 46.060829345551305, 46.41379105395292, 46.76408878616155, 47.11178196587347, 47.45692783988446, 47.799581588126905, 48.139796426657234, 48.47762370413798, 48.81311299230977, 49.146312170904544, 49.47726750741193, 49.80602373207483, 50.132624108458565, 50.457110499908744, 50.77952343218673, 51.09990215254821, 51.418284685508524, 51.734707885519185, 52.04920748676199, 52.36181815025144, 52.672573508420875, 52.98150620735504, 53.28864794681885, 53.59402951822153, 53.89768084064472, 54.19963099505384, 54.49990825680352, 54.798540126539876, 55.09555335959519, 55.390973993964046, 55.68482737694354, 55.97713819051489, 56.26793047553821, 56.55722765482764, 56.845052555169666, 57.13142742834281, 57.41637397119398], [0.0, 5.768882040742383, 8.158431221748456, 9.991996797437439, 11.537764081484767, 12.89961239727768, 14.130817386124557, 15.263027222671132, 16.316862443496913, 17.30664612222715, 18.24280680158621, 19.133217188962238, 19.983993594874878, 20.800000000000004, 21.585180101171268, 22.342784070030305, 23.075528162969533, 23.78570999570961, 24.47529366524537, 25.145973832802742, 25.79922479455536, 26.436338626973292, 27.05845524046042, 27.666586345264935, 28.261634772249113, 28.844410203711917, 29.41564209736038, 29.975990392312315, 30.526054445342265, 31.06638054231616, 31.597468253010398, 32.119775839815574, 32.633724886993825, 33.13970428353277, 33.63807366660583, 34.12916641232247, 34.6132922444543, 35.0907395191381, 35.56177723342859, 36.02665679743265, 36.48561360317242, 36.938868417968635, 37.38662862575336, 37.829089336118045, 38.266434377924476, 38.698837191833036, 39.12646163403995, 39.54946270178648, 39.967987189749756, 40.38217428519668, 40.79215610874228, 41.19805820666795, 41.60000000000001, 41.99809519490141, 42.39245215837367, 42.78317426278701, 43.170360202342536, 43.55410428421184, 43.93449669678714, 44.31162375720393, 44.68556814006061, 45.05640908905192, 45.42422261305085, 45.789081668013395, 46.15105632593907, 46.51021393199562, 46.8666192508058, 47.22033460279586, 47.57141999141922, 47.919933221990206, 48.26593001279475, 48.6094640990826, 48.95058733049074, 49.28934976239796, 49.62579974166663, 49.95998398718719, 50.291947665605484, 50.621734462580406, 50.949386649890116, 51.27494514867861, 51.59844958911072, 51.91993836668145, 52.23944869540643, 52.557016658101894, 52.872677253946584, 53.18646444350292, 53.49841119136157, 53.808549506560766, 54.11691048092084, 54.423524325423834, 54.72842040475862, 55.03162727014349, 55.33317269052987, 55.63308368228388, 55.931386537435316, 56.22810685057785, 56.52326954449823, 56.816898894607064, 57.10901855223919, 57.39965156688672, 57.68882040742383, 57.97654698237901], [0.0, 5.8240879114244155, 8.236504112789602, 10.087616170334796, 11.648175822848831, 13.023056476879768, 14.266043600101609, 15.40908822740658, 16.473008225579203, 17.472263734273245, 18.417383093154143, 19.31631434823942, 20.17523234066959, 20.999047597450705, 21.79174155500198, 22.556595487794695, 23.296351645697662, 24.013329631685817, 24.709512338368803, 25.386610644195894, 26.046112953759536, 26.689323708179646, 27.3173937263422, 27.93134440015375, 28.532087200203218, 29.12043955712208, 29.697137909232943, 30.262848511004385, 30.81817645481316, 31.36367325426026, 31.89984325980302, 32.427149119217994, 32.94601645115841, 33.456837866122385, 33.9599764428658, 34.45576874777285, 34.94452746854649, 35.42654372077525, 35.90208907570701, 36.37141734934178, 36.834766186308286, 37.292358466581334, 37.74440355867345, 38.191098439296034, 38.63262869647884, 39.0691694306393, 39.50088606601123, 39.927935083096905, 40.35046468133918, 40.7686153799709, 41.18252056394801, 41.592306980979075, 41.99809519490141, 42.400000000000006, 42.798130800304826, 43.19259195741789, 43.58348311000396, 43.97089946771615, 44.354932082013164, 44.73566809605061, 45.11319097558939, 45.4875807226544, 45.85891407349285, 46.22726468221974, 46.592703291395324, 46.955297890653405, 47.31511386438799, 47.67221412940666, 48.026659263371634, 48.37850762477074, 48.7278154650914, 49.07463703380801, 49.41902467673761, 49.761028928268765, 50.10069859792377, 50.43808085167397, 50.77322128839179, 51.106164011790206, 51.43695169817124, 51.7656256602777, 52.09222590751907, 52.41679120281974, 52.73935911631844, 53.05996607612938, 53.37864741635929, 53.69543742255948, 54.010369374778406, 54.32347558836788, 54.6347874526844, 54.944335467816884, 55.25214927946243, 55.55825771206294, 55.8626888003075, 56.165469819097936, 56.466627312068155, 56.76618711874173, 57.064174400406436, 57.36061366477874, 57.65552878952721, 57.94894304471826, 58.24087911424416, 58.53135911628912], [0.0, 5.878775382679628, 8.313843876330612, 10.182337649086286, 11.757550765359255, 13.145341380123988, 14.4, 15.553777676178866, 16.627687752661224, 17.636326148038883, 18.5903200617956, 19.497692171126307, 20.36467529817257, 21.196226079186836, 21.996363335788033, 22.76839915321233, 23.51510153071851, 24.238811852068988, 24.941531628991836, 25.62498780487515, 26.290682760247975, 26.939933184772382, 27.573900703382538, 28.193616298729758, 28.8, 29.39387691339814, 29.975990392312315, 30.547012947258857, 31.107555352357732, 31.65817429985501, 32.19937887599697, 32.73163607276606, 33.25537550532245, 33.7709934707287, 34.27885645700568, 34.77930419085465, 35.272652296077766, 35.75919462180322, 36.239205289299605, 36.712940497868054, 37.1806401235912, 37.642529139259494, 38.09881887933011, 38.549708170101624, 38.99538434225261, 39.436024140371956, 39.87179454200676, 40.302853496992, 40.72935059634514, 41.15142767875739, 41.569219381653056, 41.98285364288617, 42.39245215837367, 42.798130800304826, 43.2, 43.598165099003886, 43.992726671576065, 44.38378082137663, 44.771419454826315, 45.15573053334427, 45.53679830642466, 45.914703527301576, 46.289523652766185, 46.661333028536596, 47.03020306143702, 47.39620237951559, 47.75939698111776, 48.119850373832215, 48.477623704137976, 48.832775878501934, 49.18536367660607, 49.535441857320706, 49.88306325798367, 50.22827888749524, 50.571138013693144, 50.91168824543142, 51.2499756097503, 51.58604462449123, 51.91993836668146, 52.25169853698538, 52.58136552049595, 52.90897844411665, 53.23457523076521, 53.55819265061135, 53.879866369544764, 54.19963099505384, 54.51752011968263, 54.83356636222015, 55.147801406765076, 55.460256039798445, 55.770960185386805, 56.07994293863003, 56.387232597459516, 56.692856692885044, 56.99684201778201, 57.299214654303945, 57.6, 57.899222792711136, 58.19690713431428, 58.493076513378924, 58.78775382679628, 59.08096140043763], [0.0, 5.932958789676531, 8.390470785361213, 10.276186062932105, 11.865917579353061, 13.266499161421601, 14.532721699667961, 15.697133496278868, 16.780941570722426, 17.798876369029593, 18.76166303929372, 19.67739820199815, 20.55237212586421, 21.391587131393504, 22.199099080818574, 22.978250586152114, 23.731835158706122, 24.46221576227305, 25.17141235608364, 25.861167800391385, 26.532998322843202, 27.188232748746287, 27.82804340948174, 28.453470790045987, 29.065443399335923, 29.664793948382655, 30.25227264190246, 30.82855818879631, 31.394266992557736, 31.949960876345376, 32.49615361854384, 33.03331651530013, 33.56188314144485, 34.08225344662527, 34.59479729670345, 35.09985754956849, 35.597752738059185, 36.08877941964788, 36.573214242119874, 37.05131576611012, 37.52332607858744, 37.989472225868056, 38.449967490233334, 38.90501253052105, 39.3547964039963, 39.7994974842648, 40.23928428786974, 40.67431622043572, 41.10474425172842, 41.53071152773571, 41.95235392680607, 42.36980056596916, 42.78317426278701, 43.19259195741789, 43.598165099003886, 44.0, 44.39819816163715, 44.79285657334214, 45.18406798861741, 45.571921179603564, 45.95650117230423, 46.33788946423866, 46.71616422610058, 47.091400488836605, 47.463670317412245, 47.83304297240559, 48.199585060454616, 48.5633606744838, 48.9244315245461, 49.28285706003661, 49.63869458396343, 49.991999359897584, 50.34282471216728, 50.691222119810845, 51.03724130475706, 51.38093031466052, 51.72233560078277, 52.06150209127662, 52.398473260201015, 52.73329119256639, 53.065996645686404, 53.39662910708878, 53.725226849218615, 54.05182698114838, 54.376465497492575, 54.699177324709375, 55.01999636495808, 55.33895553766804, 55.65608681896348, 55.971421279077774, 56.28498911788115, 56.59681969863678, 56.906941580091974, 57.21538254700392, 57.522169639192164, 57.827329179203836, 58.130886798671845, 58.43286746344048, 58.73329549752849, 59.032194605994455, 59.32958789676531, 59.625497901485076], [0.0, 5.986651818838307, 8.466404195406689, 10.369185117452577, 11.973303637676613, 13.386560424545209, 14.664242223858688, 15.839191898578665, 16.932808390813378, 17.95995545651492, 18.93145530591877, 19.855477833585372, 20.738370234905155, 21.585180101171268, 22.4, 23.1862027939031, 23.946607275353227, 24.68359779286642, 25.39921258622007, 26.095210288480146, 26.773120849090418, 27.434285119171594, 28.07988603965479, 28.71097351188218, 29.328484447717376, 29.93325909419153, 30.52605444534226, 31.107555352357732, 31.67838379715733, 32.239106687375816, 32.79024245107071, 33.332266649599454, 33.865616781626755, 34.390696416327486, 34.90787876683429, 35.41750979388585, 35.91991091302984, 36.415381365571335, 36.90420030294655, 37.38662862575335, 37.86291061183754, 38.33327536227501, 38.79793808954285, 39.25710126843295, 39.710955667170744, 40.15968127363562, 40.60344812943847, 41.04241708281811, 41.47674046981031, 41.90656273186814, 42.33202097703345, 42.753245490839646, 43.170360202342536, 43.58348311000396, 43.992726671576065, 44.39819816163715, 44.8, 45.19823005384171, 45.59298191608003, 45.98434516223972, 46.3724055878062, 46.75724542784786, 47.138943560499946, 47.51757569573599, 47.89321455070645, 48.26593001279473, 48.63578929142612, 49.002857059563375, 49.36719558573284, 49.72886485734417, 50.08792269599529, 50.444424865390225, 50.79842517244014, 51.149975562066494, 51.499126206179454, 51.84592558726288, 52.19042057696029, 52.53265651002241, 52.872677253946584, 53.21052527461085, 53.546241698180836, 53.87986636954476, 54.21143790751174, 54.54099375698979, 54.86857023834319, 55.19420259411309, 55.517925033271915, 55.839770773168475, 56.15977207930958, 56.47796030311293, 56.79436591775631, 57.10901855223919, 57.42194702376436, 57.73317936853989, 58.042742871094575, 58.3506640921935, 58.65696889543475, 58.9616824726025, 59.26482936784683, 59.56643350075611, 59.86651818838306, 60.165106166282136], [0.0, 6.0398675482166, 8.541662601625049, 10.461357464497619, 12.0797350964332, 13.505554412907307, 14.794593607125543, 15.979987484350543, 17.083325203250098, 18.1196026446498, 19.099738218101315, 20.031974440878265, 20.922714928995237, 21.77705214210592, 22.599115026920856, 23.392306427541513, 24.1594701928664, 24.90301186603741, 25.624987804875147, 26.327172275046937, 27.011108825814613, 27.678150227209912, 28.329489935401238, 28.96618718437068, 29.589187214251087, 30.199337741083, 30.797402487872255, 31.38407239349285, 31.959974968701086, 32.525682160409794, 33.08171700501653, 33.62855929117392, 34.166650406500196, 34.696397507522306, 35.21817712488822, 35.73233829460367, 36.2392052892996, 36.73908001025611, 37.232244090304306, 37.71896074920411, 38.19947643620263, 38.67402228886983, 39.14281543272022, 39.606060142357, 40.06394888175653, 40.51666323872191, 40.964374766374746, 41.40724574274411, 41.845429857990474, 42.279072837516196, 42.708313008125245, 43.133281813467434, 43.55410428421184, 43.97089946771615, 44.38378082137663, 44.79285657334214, 45.19823005384171, 45.6, 45.99826083668817, 46.393102935673525, 46.784612855083026, 47.17287356097782, 47.55796463264591, 47.93996245305163, 48.3189403857328, 48.69496893930624, 49.06811592062609, 49.4384465775372, 49.80602373207482, 50.170907904880494, 50.533157431532025, 50.89282857142055, 51.249975609750294, 51.60465095318444, 51.956905219614455, 52.306787322488084, 52.654344550093874, 52.99962264016604, 53.34266585014289, 53.683517023384375, 54.02221765162923, 54.3588079339494, 54.69332683243908, 55.02581212485646, 55.356300454419824, 55.68482737694354, 56.01142740548575, 56.33613405266642, 56.658979870802476, 56.97999648999638, 57.299214654303945, 57.61666425609869, 57.93237436874136, 58.24637327765567, 58.55868850990432, 58.869346862352735, 59.178374428502174, 59.48579662406817, 59.79163821137534, 60.095923322634796, 60.398675482166, 60.69991762762122], [0.0, 6.092618484691127, 8.616263691415206, 10.552724766618338, 12.185236969382254, 13.623509092741124, 14.923806484942105, 16.119553343687908, 17.232527382830412, 18.27785545407338, 19.266551326067674, 20.206929504504146, 21.105449533236676, 21.96724834839357, 22.796490958040014, 23.596609926004202, 24.37047393876451, 25.120509548972134, 25.84879107424562, 26.557108276316537, 27.247018185482247, 27.91988538658424, 28.576913759186805, 29.219171788399482, 29.84761296988421, 30.463092423455638, 31.066380542316164, 31.65817429985501, 32.239106687375816, 32.80975464705581, 33.370645783382734, 33.92226407538271, 34.465054765660824, 34.999428566763775, 35.52576529787923, 36.0444170434202, 36.55571090814676, 37.059951430081504, 37.55742270177761, 38.048390241901174, 38.53310265213535, 39.01179308875715, 39.484680573609815, 39.95197116538807, 40.41385900900829, 40.87052727822336, 41.32214902446387, 41.768887943061166, 42.21089906647335, 42.64832939283789, 43.08131845707604, 43.50999885083888, 43.93449669678714, 44.354932082013164, 44.771419454826315, 45.18406798861741, 45.59298191608003, 45.99826083668817, 46.400000000000006, 46.79829056707093, 47.193219852008404, 47.58487154548177, 47.97332592180784, 48.35866003106373, 48.74094787752902, 49.120260585628, 49.496666554425666, 49.87023160162784, 50.24101909794427, 50.60909009259108, 50.97450343063678, 51.33731586283023, 51.69758214849124, 52.05535515199181, 52.41068593330944, 52.76362383309168, 53.114216552633074, 53.462510229131595, 53.808549506560766, 54.15237760246544, 54.494036370964494, 54.83356636222015, 55.17100687861335, 55.5063960278453, 55.83977077316848, 56.171166980934274, 56.50061946563065, 56.828162032569736, 57.15382751837361, 57.47764782939539, 57.799653978203025, 58.11987611824375, 58.438343576798964, 58.75508488633133, 59.07012781431915, 59.38349939166603, 59.69522593976842, 60.00533309631737, 60.31384583990645, 60.62078851351244, 60.926184846911276, 61.23005797808786], [0.0, 6.144916598294887, 8.690224392960172, 10.643307756520057, 12.289833196589774, 13.740451229854134, 15.051910177781423, 16.25792114632126, 17.380448785920343, 18.43474979488466, 19.43193248238579, 20.380382724571195, 21.286615513040115, 22.155811878601966, 22.99217258111986, 23.799159649029622, 24.579666393179547, 25.336140195380985, 26.070673178880515, 26.78507046845313, 27.48090245970827, 28.159545450876866, 28.822213655442912, 29.46998473023018, 30.103820355562846, 30.72458299147443, 31.333049644105824, 31.92992326956017, 32.51584229264252, 33.0913886079143, 33.6570943487402, 34.21344764854895, 34.76089757184069, 35.29985835665634, 35.83071308249391, 36.35381685600564, 36.86949958976932, 37.37806843591573, 37.879809925605485, 38.374991856676665, 38.86386496477158, 39.346664407545404, 39.82361108689166, 40.29491283028168, 40.76076544914239, 41.2213536895624, 41.67685208841954, 42.127425746181075, 42.57323102608023, 43.0144161880642, 43.45112196480086, 43.88348208608793, 44.31162375720393, 44.73566809605061, 45.15573053334427, 45.571921179603564, 45.98434516223972, 46.393102935673525, 46.79829056707093, 47.199999999999996, 47.598319298059245, 47.993332870306055, 48.3851216801198, 48.773763438963776, 49.159332786359094, 49.541901457251306, 49.921538437832616, 50.298310110778075, 50.67228039076197, 51.04351085103767, 51.41206084179081, 51.777987600910095, 52.14134635776103, 52.50219043049537, 52.860571317381726, 53.21653878260028, 53.57014093690626, 53.92142431353237, 54.27043393966922, 54.61721340383451, 54.96180491941654, 55.30424938465398, 55.64458643929345, 55.98285451814689, 56.31909090175373, 56.653331764336684, 56.985612219226006, 57.3159663619135, 57.644427310885824, 57.97102724637541, 58.29579744715737, 58.61876832551158, 58.93996946046036, 59.25942962938473, 59.57717683811478, 59.89323834958333, 60.20764071112569, 60.52040978050297, 60.831570750721205, 61.14114817371359, 61.44916598294886, 61.7556475150249], [0.0, 6.196773353931866, 8.763560920082657, 10.73312629199899, 12.393546707863733, 13.856406460551018, 15.17893276880822, 16.395121225535355, 17.527121840165314, 18.590320061795598, 19.595917942265423, 20.552372125864206, 21.46625258399798, 22.342784070030305, 23.1862027939031, 23.999999999999996, 24.787093415727465, 25.5499510762741, 26.29068276024797, 27.011108825814613, 27.712812921102035, 28.397182958878155, 29.06544339933592, 29.718680993610736, 30.35786553761644, 30.983866769659333, 31.597468253010398, 32.19937887599697, 32.79024245107071, 33.370645783382734, 33.94112549695428, 34.502173844556516, 35.05424368033063, 35.597752738059185, 36.133087330035885, 36.66060555964672, 37.180640123591196, 37.69350076604719, 38.19947643620263, 38.698837191833036, 39.191835884530846, 39.67870965643918, 40.15968127363563, 40.634960317440935, 41.10474425172841, 41.56921938165305, 42.028561717003825, 42.48293775152561, 42.93250516799596, 43.37741347752306, 43.81780460041329, 44.25381339500586, 44.68556814006061, 45.11319097558939, 45.53679830642466, 45.95650117230423, 46.3724055878062, 46.784612855083026, 47.193219852008404, 47.598319298059245, 47.99999999999999, 48.39834707921335, 48.793442182326096, 49.185363676606066, 49.57418683145493, 49.95998398718718, 50.34282471216727, 50.72277594927154, 51.0999021525482, 51.474265414865314, 51.84592558726288, 52.2149403906583, 52.58136552049594, 52.945254744877744, 53.30665999666457, 53.66563145999495, 54.02221765162923, 54.37646549749257, 54.72842040475862, 55.07812632978722, 55.42562584220407, 55.7709601853868, 56.114169333600586, 56.455292046007514, 56.79436591775631, 57.131427428342796, 57.466511987417505, 57.79965397820302, 58.13088679867184, 58.460242900624344, 58.78775382679627, 59.113450246115725, 59.43736198722147, 59.75951807034591, 60.079946737659476, 60.39867548216599, 60.71573107523288, 61.03113959283409, 61.3449264405786, 61.65711637759262, 61.967733539318665, 62.276801459291406], [0.0, 6.248199740725323, 8.836288813749809, 10.822199406774947, 12.496399481450647, 13.971399357258385, 15.304901175767194, 16.53118265581746, 17.672577627499617, 18.74459922217597, 19.75854245636555, 20.72293415518179, 21.644398813549895, 22.52820454452596, 23.37862271392393, 24.199173539606676, 24.992798962901293, 25.76198750096739, 26.508866441249427, 27.235271248878725, 27.94279871451677, 28.63284826907725, 29.306654534422723, 29.96531328052487, 30.609802351534388, 31.24099870362662, 31.859692402783804, 32.46659822032484, 33.06236531163492, 33.64758535170095, 34.222799417931896, 34.78850384825424, 35.345155254999234, 35.89317483867929, 36.432952117554244, 36.964848166873345, 37.48919844435194, 38.00631526470305, 38.516489975074315, 39.01999487442304, 39.5170849127311, 40.007999200159965, 40.49296235150005, 40.97218568736601, 41.44586831036358, 41.91419807177515, 42.37735244207689, 42.83549929672817, 43.28879762709979, 43.73739818507726, 44.181444068749045, 44.62107125562989, 45.05640908905192, 45.4875807226544, 45.914703527301576, 46.33788946423866, 46.75724542784786, 47.17287356097782, 47.58487154548177, 47.993332870306055, 48.39834707921335, 48.8, 49.19837395686975, 49.59354796745238, 49.98559792580259, 50.37459677257972, 50.76061465348898, 51.143719066958745, 51.52397500193478, 51.9014450665875, 52.27618960865453, 52.64826682807327, 53.017732882498855, 53.38464198624919, 53.74904650317064, 54.11099703387473, 54.47054249775745, 54.82773021017741, 55.18260595513772, 55.535214053787534, 55.88559742903354, 56.23379766652791, 56.57985507227816, 56.923808727104685, 57.2656965381545, 57.605555287663016, 57.94342067914182, 58.27932738115635, 58.613309068845446, 58.94539846332366, 59.275627369096654, 59.60402670961082, 59.93062656104974, 60.25545618448175, 60.57854405645617, 60.89991789813841, 61.219604703068775, 61.53763076362301, 61.85402169624866, 62.168802465545376, 62.48199740725324, 62.793630250209304], [0.0, 6.299206299209448, 8.908422980528034, 10.910545357588685, 12.598412598418896, 14.085453489327207, 15.429841217588727, 16.666133324799727, 17.816845961056067, 18.897618897628345, 19.91983935678197, 20.892103771520954, 21.82109071517737, 22.712111306525426, 23.569471780249973, 24.396721091163048, 25.196825196837793, 25.97229292919668, 26.725268941584105, 27.457603682768823, 28.170906978654415, 28.866589684269943, 29.54589650019102, 30.20993214159873, 30.859682435177454, 31.496031496047245, 32.11977583981557, 32.73163607276605, 33.332266649599454, 33.92226407538271, 34.502173844556516, 35.07249634685276, 35.633691922112135, 36.186185209275656, 36.730368906396784, 37.26660703632677, 37.79523779525669, 38.31657604744975, 38.83091551843711, 39.33853073006159, 39.83967871356394, 40.3346005310577, 40.82352263095384, 41.30665805896187, 41.78420754304191, 42.256360467981615, 42.723295753019805, 43.18518264405049, 43.64218143035474, 44.09444409446614, 44.54211490264017, 44.98533094243056, 45.42422261305085, 45.85891407349285, 46.289523652766185, 46.71616422610058, 47.138943560499946, 47.55796463264591, 47.97332592180784, 48.3851216801198, 48.793442182326096, 49.19837395686975, 49.599999999999994, 49.99839997439918, 50.393650393675586, 50.785824793932406, 51.17499389350232, 51.561225741830455, 51.94458585839336, 52.32513736245706, 52.70294109440193, 53.07805572927478, 53.45053788316821, 53.82044221297331, 54.18782151000351, 54.55272678794342, 54.91520736553765, 55.27531094439904, 55.633083682283875, 55.988570262152614, 56.34181395730883, 56.69285669288504, 57.04173910392284, 57.38850059027505, 57.733179368539886, 58.07581252122092, 58.41643604329179, 58.755084886331325, 59.09179300038204, 59.42659337367404, 59.75951807034591, 60.09059826628455, 60.41986428319746, 60.747345621022816, 61.073070988775406, 61.39706833391965, 61.71936487035491, 62.03998710509215, 62.35896086369624, 62.67631131456286, 62.99206299209449, 63.30623981883619], [0.0, 6.3498031465550175, 8.97997772825746, 10.998181667894018, 12.699606293110035, 14.198591479439079, 15.553777676178866, 16.8, 17.95995545651492, 19.04940943966505, 20.079840636817814, 21.059914529741096, 21.996363335788036, 22.894540834006698, 23.758787847867996, 24.592681838303033, 25.39921258622007, 26.180909075125715, 26.93993318477238, 27.678150227209915, 28.397182958878158, 29.09845356715714, 29.783216750378056, 30.45258609707885, 31.107555352357732, 31.74901573277509, 32.377770151756906, 32.99454500368205, 33.6, 34.19473643706002, 34.77930419085465, 35.35420767037497, 35.91991091302984, 36.476841968569595, 37.02539668929963, 37.56594202199647, 38.0988188793301, 38.6243446546346, 39.14281543272022, 39.654507940459936, 40.15968127363563, 40.6585784306338, 41.15142767875739, 41.638443774953934, 42.11982905948219, 42.595774438317235, 43.06646026782327, 43.532057153320935, 43.99272667157607, 44.44862202588512, 44.8998886412873, 45.346664706458846, 45.789081668013395, 46.22726468221974, 46.661333028536596, 47.091400488836605, 47.51757569573599, 47.93996245305163, 48.35866003106373, 48.773763438963776, 49.185363676606066, 49.59354796745238, 49.99839997439918, 50.4, 50.79842517244014, 51.1937496184837, 51.58604462449122, 51.97537878649852, 52.36181815025143, 52.74542634200619, 53.126264690828776, 53.50439234305909, 53.87986636954476, 54.252741866195116, 54.623072048357, 54.99090833947008, 55.35630045441983, 55.71929647797072, 56.07994293863003, 56.43828487826327, 56.794365917756316, 57.14822831899516, 57.49991304341252, 57.84945980733096, 58.19690713431428, 58.54229240472225, 58.88565190264943, 59.22702086041472, 59.56643350075611, 59.90392307687369, 60.23952191045344, 60.573261427795025, 60.9051721941577, 61.23528394643076, 61.56362562422717, 61.89022539949261, 62.215110704715464, 62.538308259817846, 62.85984409780222, 63.179743589223285, 63.49803146555018, 63.81473184148], [0.0, 6.4, 9.050966799187808, 11.085125168440817, 12.8, 14.310835055998655, 15.676734353812341, 16.93280839081338, 18.101933598375616, 19.2, 20.23857702507763, 21.22639865827456, 22.170250336881633, 23.075528162969533, 23.946607275353227, 24.787093415727465, 25.6, 26.38787600395303, 27.152900397563425, 27.896953238660316, 28.62167011199731, 29.32848444771738, 30.01866086286995, 30.69332174920141, 31.353468707624682, 32.0, 32.633724886993825, 33.25537550532245, 33.86561678162676, 34.46505476566083, 35.05424368033063, 35.63369192211214, 36.20386719675123, 36.76520093784339, 37.318092127009926, 37.86291061183754, 38.4, 38.92968019390861, 39.45224961900145, 39.967987189749756, 40.47715405015526, 40.97999511957023, 41.47674046981031, 41.967606555532804, 42.45279731654912, 42.93250516799596, 43.406911892001716, 43.876189442566684, 44.340500673763266, 44.800000000000004, 45.254833995939045, 45.705141942674246, 46.15105632593907, 46.592703291395324, 47.03020306143702, 47.463670317412245, 47.89321455070645, 48.3189403857328, 48.74094787752902, 49.159332786359094, 49.57418683145493, 49.98559792580259, 50.393650393675586, 50.79842517244014, 51.2, 51.598449589110714, 51.99384578967015, 52.386257739983684, 52.77575200790606, 53.16239272267568, 53.546241698180836, 53.9273585483287, 54.30580079512685, 54.6816239700322, 55.05488170907281, 55.42562584220408, 55.79390647732063, 56.15977207930958, 56.52326954449823, 56.88444427081977, 57.24334022399462, 57.6, 57.95446488407947, 58.306774906523515, 58.65696889543476, 59.00508452667448, 59.35115837117251, 59.69522593976842, 60.0373217257399, 60.37747924516226, 60.71573107523288, 61.05210889068452, 61.38664349840282, 61.719364870354916, 62.050302174929016, 62.379483806777365, 62.706937415249364, 63.03268993149508, 63.35676759431466, 63.679195974823685, 64.0, 64.3192039751737], [0.0, 6.449806198638839, 9.121403400793103, 11.171392035015154, 12.899612397277679, 14.422205101855956, 15.798734126505199, 17.06458320616123, 18.242806801586205, 19.349418595916518, 20.396078054371138, 21.3915871313935, 22.34278407003031, 23.25510696599781, 24.132965006397367, 24.97999199359359, 25.799224794555357, 26.593232221751457, 27.36421020237931, 28.114053425288926, 28.844410203711913, 29.556725123057866, 30.252272641902458, 30.932183886689927, 31.597468253010398, 32.2490309931942, 32.887687665751145, 33.51417610504546, 34.12916641232246, 34.73326935374786, 35.327043465311384, 35.9110010999415, 36.48561360317241, 37.051315766110115, 37.608509675338105, 38.157568056677825, 38.698837191833036, 39.23263947276553, 39.75927564732537, 40.27902680055713, 40.792156108742276, 41.29891039724898, 41.79952152836202, 42.29420764123616, 42.783174262787, 43.26661530556787, 43.74471396637541, 44.21764353739353, 44.68556814006062, 45.148643390471875, 45.60701700396552, 46.060829345551305, 46.51021393199562, 46.955297890653405, 47.39620237951559, 47.83304297240559, 48.26593001279473, 48.69496893930624, 49.120260585628, 49.541901457251306, 49.95998398718718, 50.37459677257972, 50.785824793932406, 51.1937496184837, 51.598449589110714, 51.99999999999999, 52.398473260201, 52.79393904606853, 53.18646444350291, 53.5761140808103, 53.96295025292817, 54.34703303769213, 54.72842040475862, 55.10716831774247, 55.48333083007904, 55.85696017507576, 56.22810685057785, 56.59681969863678, 56.96314598053728, 57.32713144750922, 57.688820407423826, 58.048255787749554, 58.40547919502074, 58.760530971052326, 59.11345024611573, 59.464274989274024, 59.81304205605998, 60.15978723366631, 60.504545283804916, 60.84734998338053, 61.188234163113414, 61.527229744236, 61.864367773379854, 62.19967845576053, 62.53319118676097, 62.86493458200683, 63.194936506020795, 63.52322409953702, 63.84982380555172, 64.1747613941805, 64.4980619863884, 64.81975007665488], [0.0, 6.499230723708768, 9.191300234460845, 11.256997823576233, 12.998461447417537, 14.532721699667961, 15.91979899370592, 17.195348208163743, 18.38260046892169, 19.497692171126303, 20.552372125864206, 21.55550973649197, 22.513995647152466, 23.4333096254029, 24.31789464571306, 25.171412356083636, 25.996922894835073, 26.797014759110763, 27.573900703382538, 28.32948993540124, 29.065443399335923, 29.783216750378056, 30.48409421321224, 31.16921558204505, 31.83959798741184, 32.49615361854384, 33.139704283532765, 33.7709934707287, 34.390696416327486, 34.999428566763775, 35.59775273805918, 36.18618520927565, 36.76520093784338, 37.335238046649714, 37.89670170344644, 38.44996749023333, 38.995384342252606, 39.53327712193868, 40.06394888175653, 40.587682860690634, 41.10474425172841, 41.615381771647854, 42.11982905948219, 42.618305925975044, 43.11101947298394, 43.59816509900388, 44.07992740465892, 44.55648101006182, 45.02799129430493, 45.494615065961376, 45.95650117230423, 46.41379105395292, 46.8666192508058, 47.31511386438799, 47.75939698111776, 48.199585060454616, 48.63578929142612, 49.06811592062609, 49.496666554425666, 49.921538437832616, 50.34282471216727, 50.76061465348898, 51.17499389350232, 51.58604462449122, 51.99384578967015, 52.398473260201, 52.8, 53.19849621934815, 53.594029518221525, 53.98666502016957, 54.376465497492575, 54.76349148839946, 55.147801406765076, 55.529451645050486, 55.90849667089967, 56.28498911788115, 56.65897987080248, 57.03051814598917, 57.39965156688672, 57.76642623531423, 58.130886798671845, 58.49307651337892, 58.85303730479847, 59.21080982388266, 59.56643350075611, 59.91994659543682, 60.27138624587956, 60.62078851351243, 60.96818842642448, 61.3136200203511, 61.657116377592615, 61.9987096639922, 62.3384311640901, 62.67631131456286, 63.0123797360487, 63.34666526345329, 63.67919597482368, 64.00999921887205, 64.33910164122592, 64.66652920947591, 64.99230723708769, 65.31646040624064], [0.0, 6.5482822174979605, 9.26066952223218, 11.341957503006261, 13.096564434995921, 14.642404174178502, 16.039950124610737, 17.325126262166172, 18.52133904446436, 19.64484665249388, 20.707486568871655, 21.718195136797167, 22.683915006012523, 23.61016730139793, 24.501428529781688, 25.36138797463577, 26.193128869991842, 26.99925924909793, 27.78200856669654, 28.54330043985804, 29.284808348357004, 30.007998933617685, 30.714166112723948, 31.404458282224837, 32.079900249221474, 32.7414110874898, 33.38981880753473, 34.02587250901878, 34.650252524332345, 35.26357894485471, 35.866418834335825, 36.459292368338694, 37.04267808892872, 37.61701742562799, 38.18271860410152, 38.7401600409704, 39.28969330498776, 39.831645710414726, 40.36632259693717, 40.894009341222585, 41.41497313774331, 41.92946458041171, 42.4377190715995, 42.93995808102285, 43.436390273594334, 43.9272125225355, 44.41261082170243, 44.89276110911424, 45.367830012025046, 45.83797552248572, 46.3033476111609, 46.76408878616155, 47.22033460279586, 47.67221412940666, 48.119850373832215, 48.5633606744838, 49.002857059563375, 49.4384465775372, 49.87023160162784, 50.298310110778075, 50.72277594927154, 51.143719066958745, 51.561225741830455, 51.97537878649852, 52.386257739983684, 52.79393904606853, 53.19849621934815, 53.6, 53.99851849819586, 54.39411732899064, 54.78685973844458, 55.176806721665216, 55.56401713339308, 55.94854779169876, 56.33045357530862, 56.7097875150313, 57.08660087971608, 57.460943257137714, 57.832862630169025, 58.202405448572314, 58.56961669671401, 58.93453995748164, 59.297217472660556, 59.657690200006904, 60.01599786723537, 60.3721790231229, 60.7262710859147, 61.07831038920445, 61.428332225447896, 61.77637088725753, 62.12245970661496, 62.4666310921279, 62.808916564449675, 63.14934678997084, 63.48795161288479, 63.82476008572221, 64.15980049844295, 64.49310040616749, 64.82468665562526, 65.15458541039149, 65.4828221749796, 65.8094218178522], [0.0, 6.596969000988257, 9.32952303175248, 11.426285485668561, 13.193938001976514, 14.75127113166862, 16.159207901379325, 17.453939383417143, 18.65904606350496, 19.79090700296477, 20.861447696648476, 21.87967092988375, 22.852570971337123, 23.78570999570961, 24.68359779286642, 25.5499510762741, 26.38787600395303, 27.2, 27.988569095257443, 28.755521208978287, 29.50254226333724, 30.231109804305895, 30.942527369301946, 31.637951893256304, 32.31841580275865, 32.984845004941285, 33.63807366660583, 34.27885645700568, 34.90787876683429, 35.52576529787923, 36.133087330035885, 36.73036890639679, 37.31809212700992, 37.89670170344644, 38.46660889654819, 39.0281949364815, 39.58181400592954, 40.127795852750246, 40.66644808684427, 41.19805820666795, 41.72289539329695, 42.24121210382108, 42.753245490839646, 43.259218670706474, 43.7593418597675, 44.25381339500586, 44.7428206531506, 45.22654088032822, 45.705141942674246, 46.1787830069178, 46.647615158762406, 47.11178196587347, 47.57141999141922, 48.026659263371634, 48.477623704137976, 48.9244315245461, 49.36719558573284, 49.80602373207482, 50.24101909794427, 50.67228039076197, 51.0999021525482, 51.52397500193478, 51.94458585839336, 52.36181815025143, 52.77575200790606, 53.18646444350291, 53.594029518221525, 53.99851849819586, 54.4, 54.79854012653987, 55.194202594113094, 55.58704885132867, 55.977138190514886, 56.364527852187315, 56.749273123098234, 57.1314274283428, 57.511042417956574, 57.88816804840174, 58.262852659306006, 58.63514304578782, 59.00508452667448, 59.37272100889432, 59.738095048302306, 60.10124790717743, 60.46221960861179, 60.82104898799428, 61.17777374177652, 61.53243047369411, 61.88505473860389, 62.23568108408551, 62.58434308994543, 62.93107340575084, 63.27590378651261, 63.61886512662734, 63.9599874921814, 64.29930015171237, 64.6368316055173, 64.97260961359025, 65.30666122226737, 65.63901278965125, 65.96969000988257, 66.29871793632212], [0.0, 6.64529909033446, 9.397872099576585, 11.50999565595053, 13.29059818066892, 14.85934049680537, 16.277591959500644, 17.58180878066873, 18.79574419915317, 19.93589727100338, 21.014280858501916, 22.03996370232946, 23.01999131190106, 23.959966610995103, 24.864432428672085, 25.737132707432657, 26.58119636133784, 27.399270063269935, 28.193616298729754, 28.966187184370682, 29.71868099361074, 30.45258609707885, 31.16921558204505, 31.869734859267346, 32.55518391900129, 33.2264954516723, 33.8845097352758, 34.529986967851585, 35.16361756133746, 35.78603079415207, 36.39780213144744, 36.99945945551097, 37.59148839830634, 38.17433692940848, 38.748419322599474, 39.31411960097797, 39.87179454200676, 40.4217763093113, 40.964374766374746, 41.499879517897405, 42.02856171700383, 42.550675670311044, 43.066460267823274, 43.57614026046823, 44.07992740465892, 44.5780214904161, 45.07061126721048, 45.55787527969232, 46.03998262380212, 46.51709363234122, 46.98936049788293, 47.45692783988446, 47.919933221990206, 48.37850762477074, 48.832775878501934, 49.28285706003661, 49.72886485734417, 50.170907904880494, 50.60909009259108, 51.04351085103767, 51.474265414865314, 51.9014450665875, 52.32513736245706, 52.74542634200619, 53.16239272267568, 53.5761140808103, 53.98666502016957, 54.39411732899064, 54.79854012653987, 55.2, 55.59856113246098, 55.994285422710774, 56.38723259745951, 56.77746031657281, 57.165024271839506, 57.54997827975264, 57.932374368741364, 58.312262861254155, 58.68969245105993, 59.06471027610311, 59.43736198722148, 59.807691813010145, 60.17574262109277, 60.54155597604013, 60.9051721941577, 61.26663039534654, 61.625968552226425, 61.9832235366958, 62.3384311640901, 62.69162623508821, 63.042842575505745, 63.3921130741041, 63.73946971853469, 64.08494362952972, 64.42856509344284, 64.77036359323607, 65.11036783800257, 65.44860579110912, 65.78510469703609, 66.11989110698838, 66.4529909033446, 66.78442932300912], [0.0, 6.6932802122726045, 9.465727652959385, 11.593101396951553, 13.386560424545209, 14.966629547095767, 16.39512122553536, 17.708754896942924, 18.93145530591877, 20.079840636817814, 21.166010488516726, 22.199099080818577, 23.186202793903107, 24.132965006397374, 25.043961347997644, 25.92296279363144, 26.773120849090418, 27.597101297056547, 28.397182958878158, 29.175332046096756, 29.933259094191534, 30.672463220289305, 31.394266992557736, 32.09984423638221, 32.79024245107072, 33.46640106136302, 34.12916641232247, 34.77930419085466, 35.41750979388585, 36.0444170434202, 36.66060555964672, 37.266607036326775, 37.86291061183754, 38.449967490233334, 39.0281949364815, 39.59797974644666, 40.15968127363563, 40.713634079998315, 41.26015026632841, 41.79952152836203, 42.33202097703345, 42.8579047551324, 43.37741347752308, 43.89077351790465, 44.398198161637154, 44.8998886412873, 45.396035069155545, 45.88681727903996, 46.37240558780621, 46.85296148590823, 47.328638264796936, 47.799581588126905, 48.26593001279475, 48.7278154650914, 49.18536367660607, 49.63869458396343, 50.08792269599529, 50.533157431532025, 50.97450343063678, 51.41206084179081, 51.84592558726288, 52.27618960865453, 52.70294109440193, 53.126264690828776, 53.546241698180836, 53.96295025292817, 54.376465497492575, 54.78685973844458, 55.194202594113094, 55.59856113246098, 56.00000000000001, 56.398581542446614, 56.794365917756316, 57.187411202116856, 57.57777348942906, 57.96550698475776, 58.35066409219351, 58.733295497528495, 59.11345024611574, 59.49117581625027, 59.86651818838307, 60.23952191045345, 60.6102301596026, 60.978684800510415, 61.34492644057861, 61.708994482166055, 62.07092717206664, 62.43076164840535, 62.78853398511547, 63.14427923414757, 63.49803146555018, 63.84982380555173, 64.19968847276442, 64.5476568126218, 64.8937593301544, 65.23802572120036, 65.58048490214144, 65.92116503824853, 66.2600935707157, 66.59729724245572, 66.93280212272605, 67.26663363064931], [0.0, 6.740919818541087, 9.533100230250387, 11.67561561546114, 13.481839637082174, 15.07315494513342, 16.511813952440235, 17.834797447686363, 19.066200460500774, 20.222759455623258, 21.316660151158764, 22.357101779971394, 23.35123123092228, 24.3047320495413, 25.222212432695112, 26.10747019532915, 26.96367927416435, 27.793524425664334, 28.599300690751164, 29.382988275531137, 30.14630989026684, 30.89077532209252, 31.617716552591208, 32.328315761882806, 33.02362790488047, 33.704599092705436, 34.372081694305336, 35.02684684638342, 35.669594895372725, 36.30096417452297, 36.92153842948584, 37.53185313836768, 38.13240092100155, 38.723636192899036, 39.30597918892239, 39.879819457966455, 40.445518911246516, 41.003414491966396, 41.55382052230577, 42.09703077415318, 42.63332030231753, 43.16294707269188, 43.68615341272336, 44.20316730733217, 44.71420355994279, 45.219464835400245, 45.71914259913456, 46.21341796491578, 46.70246246184456, 47.18643872978761, 47.665501151251945, 48.139796426657234, 48.6094640990826, 49.07463703380801, 49.535441857320706, 49.991999359897584, 50.444424865390225, 50.89282857142055, 51.33731586283023, 51.777987600910095, 52.2149403906583, 52.64826682807327, 53.07805572927478, 53.50439234305909, 53.9273585483287, 54.34703303769213, 54.76349148839946, 55.176806721665216, 55.58704885132867, 55.994285422710774, 56.398581542446614, 56.8, 57.19860138150233, 57.59444417650022, 57.98758487814439, 58.378078077305695, 58.76597655106227, 59.151331345963804, 59.53419185644499, 59.9146058987289, 60.29261978053368, 60.668278366869785, 61.041625142192935, 61.41270226915601, 61.78155064418504, 62.148209950086255, 62.51271870587617, 62.87511431401139, 63.235433105182416, 63.59371038082303, 63.94998045347629, 64.30427668514747, 64.65663152376561, 65.00707653786625, 65.35564244960032, 65.70235916616693, 66.04725580976094, 66.39036074612038, 66.73170161175271, 67.07130533991418, 67.40919818541087, 67.74540574828673], [0.0, 6.788225099390856, 9.6, 11.757550765359257, 13.576450198781712, 15.178932768808222, 16.627687752661224, 17.95995545651492, 19.2, 20.364675298172568, 21.46625258399798, 22.513995647152463, 23.515101530718514, 24.47529366524537, 25.39921258622007, 26.29068276024797, 27.152900397563425, 27.988569095257443, 28.8, 29.58918721425109, 30.357865537616444, 31.107555352357732, 31.83959798741184, 32.55518391900129, 33.25537550532245, 33.941125496954285, 34.6132922444543, 35.272652296077766, 35.91991091302984, 36.555710908146764, 37.1806401235912, 37.795237795256696, 38.4, 38.99538434225261, 39.581814005929544, 40.15968127363563, 40.729350596345135, 41.29116128180461, 41.84542985799047, 42.39245215837367, 42.93250516799596, 43.4658486630596, 43.992726671576065, 44.51336877837937, 45.027991294304925, 45.53679830642466, 46.03998262380211, 46.53772663119676, 47.03020306143703, 47.51757569573599, 48.0, 48.47762370413798, 48.95058733049074, 49.41902467673761, 49.88306325798367, 50.34282471216728, 50.79842517244014, 51.249975609750294, 51.69758214849124, 52.14134635776103, 52.58136552049594, 53.017732882498855, 53.45053788316821, 53.87986636954476, 54.30580079512685, 54.72842040475862, 55.147801406765076, 55.56401713339308, 55.977138190514886, 56.38723259745951, 56.794365917756316, 57.19860138150233, 57.6, 57.998620673253946, 58.39452029086291, 58.787753826796276, 59.17837442850218, 59.56643350075611, 59.95198078462463, 60.33506443188737, 60.71573107523289, 61.094025894517706, 61.46999267935536, 61.8436738882806, 62.215110704715464, 62.584343089945435, 62.95140983329921, 63.31634859971002, 63.67919597482368, 64.0399875078064, 64.39875775199394, 64.7555403035138, 65.11036783800257, 65.46327214553212, 65.81428416385003, 66.16343401003306, 66.5107510106449, 66.85626373048378, 67.2, 67.5419869414574, 67.88225099390857, 68.2208179370491], [0.0, 6.835202996254025, 9.666436778875658, 11.838918869558995, 13.67040599250805, 15.28397853963424, 16.74275962916508, 18.084247288731703, 19.332873557751316, 20.505608988762074, 21.614809737770074, 22.66980370448761, 23.67783773911799, 24.64467488119898, 25.574987781033247, 26.472627372438872, 27.3408119850161, 28.182263926093658, 28.999310336626973, 29.793959119257718, 30.56795707926848, 31.32283512072303, 32.05994385522221, 32.78048199767661, 33.48551925833016, 34.17601498127013, 34.852833457267145, 35.516756608676985, 36.168494577463406, 36.808694625047494, 37.43794866175229, 38.05679965525215, 38.66574711550263, 39.26525181378569, 39.85573986265968, 40.43760625952036, 41.01121797752415, 41.576916672596106, 42.13502106324382, 42.685829030253124, 43.22961947554015, 43.76665397308778, 44.29717823970281, 44.8214234490606, 45.33960740897522, 45.851935618902715, 46.358602222241345, 46.85979086594391, 47.35567547823598, 47.84642097377817, 48.33218389437829, 48.81311299230977, 49.28934976239796, 49.761028928268765, 50.22827888749524, 50.691222119810845, 51.149975562066494, 51.60465095318444, 52.05535515199181, 52.50219043049537, 52.945254744877744, 53.38464198624919, 53.82044221297331, 54.252741866195116, 54.6816239700322, 55.10716831774247, 55.529451645050486, 55.94854779169876, 56.364527852187315, 56.77746031657281, 57.187411202116856, 57.59444417650022, 57.998620673253946, 58.4, 58.79863944004146, 59.19459434779497, 59.587918238515435, 59.978662872724996, 60.36687833572315, 60.75261311252381, 61.13591415853696, 61.516826966286224, 61.89539562843105, 62.27166289734039, 62.64567024144606, 63.01745789858553, 63.38706492652898, 63.7545292508697, 64.11988771044442, 64.48317610043723, 64.84442921331022, 65.20368087769279, 65.56096399535322, 65.91631057636646, 66.26975177258475, 66.62131790951001, 66.97103851666031, 67.31894235651657, 67.6650574521296, 68.00941111346282, 68.35202996254026, 68.6929399574658], [0.0, 6.881860213634101, 9.73242004847715, 11.919731540601072, 13.763720427268202, 15.388307249337076, 16.85704600456438, 18.207690682785667, 19.4648400969543, 20.645580640902303, 21.762352813976708, 22.82454818829937, 23.839463081202144, 24.812899870833316, 25.749563103089727, 26.653329998332286, 27.527440854536405, 28.374636561549117, 29.197260145431454, 29.99733321480428, 30.776614498674153, 31.536645351083237, 32.27878560293122, 33.00424215157803, 33.71409200912876, 34.40930106817051, 35.0907395191381, 35.75919462180322, 36.415381365571335, 37.059951430081504, 37.69350076604719, 38.31657604744975, 38.9296801939086, 39.53327712193868, 40.127795852750246, 40.71363407999831, 41.291161281804605, 41.860721446243616, 42.42263546740113, 42.977203259402536, 43.524705627953416, 44.06540593254532, 44.599551567252334, 45.127375283745444, 45.64909637659874, 46.164921748011224, 46.67504686660743, 47.179656632917535, 47.67892616240429, 48.17302149543871, 48.662100242385755, 49.146312170904544, 49.62579974166663, 50.10069859792377, 50.571138013693144, 51.03724130475706, 51.499126206179454, 51.956905219614455, 52.41068593330944, 52.860571317381726, 53.30665999666457, 53.74904650317064, 54.18782151000351, 54.623072048357, 55.05488170907281, 55.48333083007904, 55.90849667089967, 56.33045357530862, 56.749273123098234, 57.165024271839506, 57.57777348942906, 57.98758487814439, 58.39452029086291, 58.79863944004146, 59.199999999999996, 59.59865770300536, 59.99466642960856, 60.38807829364998, 60.778943722312256, 61.167311531568885, 61.553228997348306, 61.936741922706915, 62.31789470128143, 62.69673037726927, 63.073290702166474, 63.447616188474726, 63.81974616057322, 64.18971880293603, 64.55757120586244, 64.92333940887514, 65.28705844193013, 65.64876236457165, 66.00848430315607, 66.36625648625964, 66.72211027837774, 67.07607621201466, 67.42818401825753, 67.77846265592044, 68.12694033934005, 68.47364456489811, 68.81860213634101, 69.16183918896316], [0.0, 6.92820323027551, 9.797958971132712, 12.000000000000002, 13.85640646055102, 15.491933384829668, 16.970562748477143, 18.33030277982336, 19.595917942265423, 20.784609690826528, 21.908902300206645, 22.978250586152118, 24.000000000000004, 24.979991993593593, 25.92296279363144, 26.832815729997474, 27.71281292110204, 28.5657137141714, 29.393876913398138, 30.199337741083003, 30.983866769659336, 31.74901573277509, 32.49615361854384, 33.2264954516723, 33.941125496954285, 34.64101615137755, 35.32704346531139, 36.0, 36.66060555964672, 37.30951621235526, 37.94733192202055, 38.57460304397182, 39.191835884530846, 39.799497484264805, 40.39801975344831, 40.98780306383839, 41.569219381653056, 42.14261501141096, 42.708313008125245, 43.266615305567875, 43.81780460041329, 44.36214602563767, 44.8998886412873, 45.43126676640219, 45.956501172304236, 46.475800154489, 46.98936049788293, 47.49736834815167, 48.00000000000001, 48.49742261192856, 48.98979485566357, 49.47726750741193, 49.95998398718719, 50.43808085167397, 50.91168824543142, 51.38093031466052, 51.84592558726288, 52.306787322488084, 52.76362383309168, 53.21653878260028, 53.66563145999495, 54.11099703387473, 54.55272678794342, 54.99090833947008, 55.42562584220408, 55.85696017507576, 56.28498911788115, 56.7097875150313, 57.1314274283428, 57.54997827975264, 57.96550698475776, 58.378078077305695, 58.787753826796276, 59.19459434779497, 59.59865770300536, 60.0, 60.398675482166006, 60.794736614282655, 61.18823416311343, 61.579217273362616, 61.96773353931867, 62.353829072479584, 62.7375485654325, 63.118935352238, 63.49803146555018, 63.87487769068525, 64.24951361683604, 64.62197768561406, 64.99230723708769, 65.36053855347276, 65.72670690061993, 66.09084656743323, 66.4529909033446, 66.81317235396027, 67.17142249498667, 67.52777206453652, 67.88225099390857, 68.23488843692793, 68.58571279792899, 68.93475175845634, 69.2820323027551, 69.62758074211685], [0.0, 6.974238309665079, 9.863062404750362, 12.079735096433202, 13.948476619330158, 15.594870951694345, 17.0833252032501, 18.452100151473275, 19.726124809500725, 20.922714928995234, 22.054478003344357, 23.13093167168154, 24.159470192866404, 25.145973832802742, 26.095210288480146, 27.011108825814613, 27.896953238660316, 28.755521208978287, 29.58918721425109, 30.400000000000006, 31.18974190338869, 31.95997496870109, 32.712077280417404, 33.447271936587, 34.1666504065002, 34.87119154832539, 35.5617772334286, 36.239205289299605, 36.90420030294655, 37.55742270177761, 38.19947643620263, 38.830915518437116, 39.45224961900145, 40.06394888175653, 40.66644808684428, 41.26015026632841, 41.84542985799047, 42.422635467401136, 42.9920922961421, 43.554104284211846, 44.108956006688715, 44.65691435824917, 45.19823005384172, 45.73313896946065, 46.26186334336308, 46.784612855083026, 47.30158559710235, 47.8129689519486, 48.31894038573281, 48.81966816765555, 49.31531202375182, 49.80602373207483, 50.291947665605484, 50.77322128839179, 51.2499756097503, 51.72233560078277, 52.19042057696029, 52.654344550093874, 53.114216552633074, 53.57014093690626, 54.02221765162923, 54.47054249775745, 54.91520736553765, 55.35630045441983, 55.79390647732063, 56.22810685057785, 56.65897987080248, 57.08660087971608, 57.511042417956574, 57.932374368741364, 58.35066409219351, 58.76597655106227, 59.17837442850218, 59.587918238515435, 59.99466642960856, 60.398675482166006, 60.80000000000001, 61.19869279649689, 61.594804975744516, 61.988386008993665, 62.37948380677738, 62.76814478698571, 63.15441393916978, 63.5383348853273, 63.91994993740218, 64.29930015171239, 64.67642538050477, 65.0513643208196, 65.42415456083481, 65.79483262384669, 66.16343401003307, 66.52999323613373, 66.894543873174, 67.25711858234786, 67.61774914916941, 67.97646651599361, 68.3333008130004, 68.68828138773019, 69.04143683325255, 69.39279501504463, 69.74238309665078, 70.09022756419044], [0.0, 7.019971509913698, 9.927738916792686, 12.158947322856532, 14.039943019827396, 15.697133496278868, 17.195348208163743, 18.57309882599024, 19.855477833585372, 21.059914529741093, 22.199099080818574, 23.2826115373684, 24.317894645713064, 25.310867231290203, 26.266328255011206, 27.188232748746284, 28.07988603965479, 28.94408402420087, 29.783216750378056, 30.599346398248446, 31.394266992557736, 32.16955082061296, 32.92658500361069, 33.66660066000131, 34.390696416327486, 35.09985754956849, 35.79497171391535, 36.476841968569595, 37.14619765198048, 37.80370352227411, 38.44996749023333, 39.08554720097955, 39.710955667170744, 40.326666115611395, 40.9331161774913, 41.53071152773571, 42.119829059482186, 42.70081966426406, 43.27401067615527, 43.83970802822483, 44.39819816163715, 44.94974972121648, 45.49461506596138, 46.033031618610565, 46.5652230747368, 47.0914004888366, 47.61176325237284, 48.12649997662411, 48.63578929142613, 49.13980056939589, 49.63869458396343, 50.132624108458565, 50.621734462580406, 51.106164011790206, 51.58604462449123, 52.06150209127662, 52.53265651002241, 52.99962264016604, 53.462510229131595, 53.92142431353237, 54.37646549749257, 54.82773021017741, 55.27531094439904, 55.71929647797072, 56.15977207930958, 56.59681969863678, 57.03051814598917, 57.460943257137714, 57.88816804840174, 58.312262861254155, 58.733295497528495, 59.151331345963804, 59.56643350075611, 59.978662872724996, 60.38807829364998, 60.794736614282655, 61.19869279649689, 61.6, 61.99870966399221, 62.39487158412942, 62.78853398511547, 63.179743589223285, 63.56854568102059, 63.954984168554056, 64.33910164122592, 64.72093942457882, 65.10053763218858, 65.4779352148493, 65.85317000722138, 66.22627877210073, 66.59729724245572, 66.96626016136783, 67.33320132000262, 67.6981535937281, 68.06114897649026, 68.42221861354687, 68.78139283265497, 69.13870117379992, 69.4941724175488, 69.8478346121052, 70.19971509913698, 70.54984053844488], [0.0, 7.065408693062278, 9.991996797437437, 12.237646832622687, 14.130817386124557, 15.798734126505202, 17.30664612222715, 18.69331431287668, 19.983993594874875, 21.196226079186836, 22.34278407003031, 23.4333096254029, 24.475293665245374, 25.474693324945058, 26.436338626973292, 27.36421020237931, 28.261634772249113, 29.131426329653003, 29.975990392312315, 30.797402487872258, 31.597468253010405, 32.377770151756906, 33.13970428353277, 33.8845097352758, 34.6132922444543, 35.32704346531139, 36.02665679743266, 36.71294049786806, 37.38662862575336, 38.048390241901174, 38.69883719183304, 39.33853073006159, 39.96798718974975, 40.58768286069064, 41.19805820666795, 41.79952152836203, 42.39245215837367, 42.97720325940254, 43.554104284211846, 44.12346314604058, 44.68556814006062, 45.24068964991582, 45.7890816680134, 46.33098315382483, 46.8666192508058, 47.3962023795156, 47.919933221990206, 48.43800161030594, 48.95058733049075, 49.457860851435946, 49.959983987187194, 50.457110499908744, 50.949386649890116, 51.43695169817124, 51.91993836668146, 52.398473260201015, 52.872677253946584, 53.34266585014289, 53.808549506560766, 54.27043393966922, 54.72842040475862, 55.18260595513772, 55.633083682283875, 56.07994293863003, 56.52326954449823, 56.96314598053728, 57.39965156688672, 57.832862630169025, 58.262852659306006, 58.68969245105993, 59.11345024611574, 59.53419185644499, 59.95198078462463, 60.36687833572315, 60.778943722312256, 61.18823416311343, 61.594804975744516, 61.99870966399221, 62.40000000000001, 62.79872610172917, 63.19493650602081, 63.58867823756051, 63.97999687402307, 64.36893660765261, 64.75554030351381, 65.13984955463131, 65.52190473421848, 65.90174504518072, 66.27940856706554, 66.65493230061824, 67.02835221009093, 67.39970326344175, 67.7690194705516, 68.13633391957629, 68.50167881154448, 68.8650854933035, 69.2265844889086, 69.58620552954444, 69.94397758206206, 70.2999288762087, 70.65408693062278, 71.00647857766221], [0.0, 7.110555533852471, 10.055844071981229, 12.315843454672525, 14.221111067704943, 15.899685531481435, 17.417232845661793, 18.812761626087756, 20.111688143962457, 21.331666601557412, 22.485550916088314, 23.583044756773884, 24.63168690934505, 25.637472574339306, 26.605262637305426, 27.53906316489361, 28.442222135409885, 29.31757152289391, 30.167532215943684, 30.994193004496832, 31.79937106296287, 32.58465896706608, 33.35146173708133, 34.10102637751539, 34.83446569132359, 35.55277766926236, 36.25686141959891, 36.94753036401757, 37.62552325217551, 38.29151342007783, 38.94611662284187, 39.58989770130759, 40.223376287924914, 40.847031715903185, 41.46130726351981, 42.0666138404317, 42.663333203114824, 43.25182077092247, 43.83240810176872, 44.405405076409345, 44.97110183217663, 45.52977048042303, 46.08166663652695, 46.62703078687297, 47.16608951354777, 47.69905659444429, 48.22613399392492, 48.7475127570628, 49.2633738186901, 49.7738887369673, 50.27922035990614, 50.77952343218673, 51.27494514867861, 51.7656256602777, 52.25169853698538, 52.73329119256639, 53.21052527461085, 53.683517023384375, 54.15237760246544, 54.61721340383451, 55.07812632978722, 55.535214053787534, 55.988570262152614, 56.43828487826327, 56.88444427081977, 57.32713144750922, 57.76642623531423, 58.202405448572314, 58.63514304578782, 59.06471027610311, 59.49117581625027, 59.9146058987289, 60.33506443188737, 60.75261311252381, 61.167311531568885, 61.579217273362616, 61.988386008993665, 62.39487158412942, 62.79872610172917, 63.2, 63.59874212592574, 63.99499980467225, 64.38881890514844, 64.78024390197987, 65.16931793413217, 65.55608286040282, 65.94057931198361, 66.3228467422803, 66.70292347416266, 67.08084674480489, 67.45665274826494, 67.8303766759407, 68.20205275503078, 68.57171428511906, 68.93939367299367, 69.30512246580335, 69.66893138264717, 70.03085034468738, 70.3909085038686, 70.74913427032165, 71.10555533852472, 71.4601987122902], [0.0, 7.155417527999328, 10.119288512538814, 12.393546707863736, 14.310835055998655, 16.000000000000004, 17.527121840165318, 18.931455305918774, 20.23857702507763, 21.46625258399798, 22.627416997969522, 23.731835158706126, 24.787093415727472, 25.79922479455536, 26.773120849090418, 27.712812921102035, 28.62167011199731, 29.50254226333724, 30.357865537616444, 31.18974190338869, 32.00000000000001, 32.79024245107072, 33.56188314144485, 34.316176943243555, 35.054243680330636, 35.77708763999664, 36.48561360317242, 37.18064012359121, 37.86291061183755, 38.53310265213535, 39.19183588453085, 39.83967871356395, 40.47715405015526, 41.10474425172842, 41.72289539329696, 42.33202097703345, 42.93250516799596, 43.52470562795342, 44.108956006688715, 44.68556814006062, 45.254833995939045, 45.817027402484335, 46.37240558780621, 46.92121055556858, 47.46367031741225, 48.0, 48.53040284192993, 49.05507109361886, 49.574186831454945, 50.087922695995296, 50.59644256269407, 51.09990215254821, 51.59844958911072, 52.09222590751907, 52.58136552049595, 53.065996645686404, 53.546241698180836, 54.02221765162923, 54.494036370964494, 54.96180491941654, 55.42562584220407, 55.88559742903354, 56.34181395730883, 56.794365917756316, 57.24334022399462, 57.688820407423826, 58.130886798671845, 58.56961669671401, 59.00508452667448, 59.43736198722148, 59.86651818838307, 60.29261978053368, 60.71573107523289, 61.13591415853696, 61.553228997348306, 61.96773353931867, 62.37948380677738, 62.78853398511547, 63.19493650602081, 63.59874212592574, 64.00000000000001, 64.39875775199395, 64.79506154021308, 65.18895611988276, 65.58048490214144, 65.96969000988257, 66.35661233064872, 66.74129156676548, 67.1237662828897, 67.50407395113275, 67.88225099390857, 68.25833282464494, 68.63235388648711, 69.00434768911305, 69.37434684377217, 69.74238309665078, 70.10848736066127, 70.47268974574479, 70.8350195877717, 71.19550547611837, 71.55417527999327, 71.91105617358156], [0.0, 7.2, 10.182337649086284, 12.470765814495918, 14.4, 16.09968943799849, 17.636326148038883, 19.04940943966505, 20.364675298172568, 21.6, 22.768399153212332, 23.879698490558884, 24.941531628991836, 25.959969183340725, 26.93993318477238, 27.8854800926934, 28.8, 29.68636050444716, 30.547012947258853, 31.384072393492854, 32.19937887599698, 32.99454500368205, 33.7709934707287, 34.529986967851585, 35.272652296077766, 36.00000000000001, 36.712940497868054, 37.41229744348775, 38.0988188793301, 38.77318661136843, 39.43602414037196, 40.08790341237616, 40.729350596345135, 41.36085105507381, 41.98285364288617, 42.595774438317235, 43.2, 43.795890218147186, 44.38378082137663, 44.963985588468475, 45.536798306424664, 46.10249450951652, 46.6613330285366, 47.2135573749744, 47.75939698111777, 48.299068313995456, 48.832775878501934, 49.36071312288752, 49.88306325798367, 50.400000000000006, 50.91168824543143, 51.418284685508524, 51.91993836668145, 52.41679120281974, 52.90897844411665, 53.39662910708878, 53.87986636954476, 54.3588079339494, 54.83356636222015, 55.30424938465398, 55.7709601853868, 56.23379766652791, 56.69285669288504, 57.14822831899516, 57.6, 58.048255787749554, 58.49307651337892, 58.93453995748164, 59.37272100889432, 59.807691813010145, 60.23952191045345, 60.668278366869785, 61.094025894517706, 61.516826966286224, 61.936741922706915, 62.353829072479584, 62.76814478698571, 63.179743589223285, 63.58867823756051, 63.99499980467225, 64.39875775199395, 64.80000000000001, 65.1987729945894, 65.59512176983895, 65.9890900073641, 66.3807200925088, 66.77005316756907, 67.15712918223947, 67.5419869414574, 67.92466415080754, 68.305197459637, 68.68362250202009, 69.05997393570317, 69.43428547914928, 69.80658994679514, 70.17691928262454, 70.54530459215553, 70.91177617293197, 71.27636354360399, 71.63909547167664, 72.00000000000001, 72.35910447207043], [0.0, 7.244308110509934, 10.244998779892558, 12.5475097130865, 14.488616221019868, 16.19876538505327, 17.74485841025507, 19.166637681137505, 20.489997559785117, 21.7329243315298, 22.908513701242168, 24.026651868289935, 25.095019426173, 26.119724347703215, 27.10571895375587, 28.057084666800293, 28.977232442039735, 29.869047524151153, 30.73499633967768, 31.57720696958489, 32.39753077010654, 33.197590273994294, 33.97881693055249, 34.74248120097355, 35.48971682051014, 36.22154055254967, 36.938868417968635, 37.6425291392595, 38.33327536227501, 39.01179308875715, 39.67870965643918, 40.3346005310577, 40.97999511957023, 41.615381771647854, 42.24121210382108, 42.8579047551324, 43.4658486630596, 44.065405932545325, 44.65691435824917, 45.24068964991582, 45.817027402484335, 46.386204845837526, 46.94848240358788, 47.50410508577127, 48.05330373657987, 48.59629615515981, 49.133288104909084, 49.66447422454002, 50.190038852346, 50.71015677356954, 51.224993899462795, 51.734707885519185, 52.23944869540643, 52.73935911631844, 53.23457523076521, 53.725226849218615, 54.21143790751174, 54.69332683243908, 55.17100687861335, 55.64458643929345, 56.114169333600586, 56.57985507227816, 57.04173910392284, 57.49991304341252, 57.95446488407947, 58.40547919502074, 58.85303730479847, 59.297217472660556, 59.738095048302306, 60.17574262109277, 60.6102301596026, 61.041625142192935, 61.46999267935536, 61.89539562843105, 62.31789470128143, 62.7375485654325, 63.15441393916978, 63.56854568102059, 63.97999687402307, 64.38881890514844, 64.79506154021308, 65.1987729945894, 65.60000000000001, 65.99878786765709, 66.39518054798859, 66.78922068717378, 67.18094968069447, 67.57040772409178, 67.95763386110498, 68.34266602935534, 68.7255411037265, 69.1062949375815, 69.4849624019471, 69.86157742278657, 70.23617301647351, 70.60878132357193, 70.97943364102028, 71.34816045281057, 71.71499145924791, 72.07995560486981, 72.44308110509934, 72.80439547170214], [0.0, 7.288346863315439, 10.3072789813801, 12.623787070447602, 14.576693726630879, 16.29723902997069, 17.852730883537117, 19.28315326911032, 20.6145579627602, 21.865040589946314, 23.047776465420693, 24.172711887581006, 25.247574140895203, 26.278508329050947, 27.270496878494896, 28.227646023003757, 29.153387453261757, 30.050623953588715, 30.9218369441403, 31.76916744266365, 32.59447805994138, 33.399401192236965, 34.18537699075439, 34.953683639925565, 35.70546176707423, 36.4417343165772, 37.16342287787819, 37.8713612113428, 38.56630653822064, 39.248949030515455, 39.919919839598876, 40.57979792951167, 41.2291159255204, 41.86836514601448, 42.49799995293896, 43.11844153027797, 43.73008117989263, 44.33328320799171, 44.928387462716714, 45.51571157303816, 46.095552930841386, 46.66819045131277, 47.23388614120164, 47.792886499980305, 48.34542377516201, 48.89171708991206, 49.4319734584813, 49.96638870280701, 50.49514828179041, 51.018428043208075, 51.536394906900505, 52.04920748676199, 52.557016658101894, 53.05996607612938, 53.55819265061135, 54.05182698114838, 54.54099375698979, 55.02581212485646, 55.5063960278453, 55.98285451814689, 56.455292046007514, 56.923808727104685, 57.38850059027505, 57.84945980733096, 58.306774906523515, 58.760530971052326, 59.21080982388266, 59.657690200006904, 60.10124790717743, 60.54155597604013, 60.978684800510415, 61.41270226915601, 61.8436738882806, 62.27166289734039, 62.69673037726927, 63.118935352238, 63.5383348853273, 63.954984168554056, 64.36893660765261, 64.78024390197987, 65.18895611988276, 65.59512176983895, 65.99878786765709, 66.39999999999999, 66.79880238447393, 67.19523792650786, 67.58934827323016, 67.981173864534, 68.37075398150878, 68.75812679240178, 69.14332939626208, 69.52639786440831, 69.90736727985113, 70.28627177479255, 70.66314456631548, 71.03801799036907, 71.41092353414847, 71.78189186696044, 72.1509528696607, 72.51813566274302, 72.8834686331544, 73.24697945990674], [0.0, 7.332121111929345, 10.369185117452577, 12.699606293110037, 14.66424222385869, 16.39512122553536, 17.95995545651492, 19.398969044771427, 20.738370234905155, 21.996363335788033, 23.186202793903103, 24.317894645713064, 25.399212586220074, 26.436338626973292, 27.434285119171594, 28.397182958878155, 29.32848444771738, 30.231109804305895, 31.107555352357732, 31.95997496870109, 32.79024245107072, 33.6, 34.390696416327486, 35.16361756133746, 35.91991091302984, 36.660605559646726, 37.38662862575336, 38.09881887933011, 38.79793808954285, 39.484680573609815, 40.15968127363563, 40.82352263095384, 41.47674046981031, 42.11982905948219, 42.753245490839646, 43.37741347752307, 43.992726671576065, 44.599551567252334, 45.19823005384171, 45.789081668013395, 46.372405587806206, 46.948482403587875, 47.517575695736, 48.0799334442135, 48.63578929142613, 49.18536367660607, 49.72886485734418, 50.26648983169603, 50.79842517244015, 51.32484778350541, 51.84592558726289, 52.36181815025144, 52.872677253946584, 53.37864741635929, 53.879866369544764, 54.376465497492575, 54.86857023834319, 55.356300454419824, 55.83977077316848, 56.31909090175373, 56.79436591775631, 57.2656965381545, 57.733179368539886, 58.19690713431428, 58.65696889543476, 59.11345024611573, 59.56643350075611, 60.01599786723537, 60.46221960861179, 60.9051721941577, 61.34492644057861, 61.78155064418504, 62.215110704715464, 62.64567024144606, 63.073290702166474, 63.49803146555018, 63.91994993740218, 64.33910164122592, 64.75554030351381, 65.16931793413217, 65.58048490214144, 65.9890900073641, 66.39518054798859, 66.79880238447393, 67.2, 67.59881655768835, 67.99529395480249, 68.38947287412005, 68.78139283265497, 69.17109222789531, 69.5586083817093, 69.94397758206206, 70.32723512267492, 70.70841534074994, 71.0875516528738, 71.46467658920734, 71.83982182605968, 72.21301821693926, 72.58429582216804, 72.95368393713919, 73.32121111929345, 73.68690521388451], [0.0, 7.37563556583431, 10.430723848324238, 12.774975538137053, 14.75127113166862, 16.492422502470642, 18.066543665017946, 19.51409746824075, 20.861447696648476, 22.12690669750293, 23.323807579381203, 24.46221576227305, 25.549951076274105, 26.59323222175146, 27.597101297056543, 28.565713714171398, 29.50254226333724, 30.41052449399714, 31.292171544972717, 32.149650075856194, 32.984845004941285, 33.799408278844176, 34.59479729670345, 35.372305551094634, 36.13308733003589, 36.878177829171555, 37.60850967533811, 38.324926614411154, 39.0281949364815, 39.71901307938052, 40.39801975344831, 41.06580085667392, 41.72289539329695, 42.36980056596916, 43.00697617828996, 43.63484845854286, 44.25381339500586, 44.86423965699185, 45.46647116282504, 46.060829345551305, 46.647615158762406, 47.227110858065416, 47.799581588126905, 48.365276800613884, 48.9244315245461, 49.47726750741192, 50.023994242763145, 50.564809897793545, 51.09990215254821, 51.62944896084017, 52.15361924162119, 52.672573508420875, 53.18646444350292, 53.69543742255948, 54.19963099505384, 54.699177324709375, 55.19420259411309, 55.68482737694354, 56.171166980934274, 56.653331764336684, 57.131427428342796, 57.605555287663016, 58.07581252122092, 58.54229240472225, 59.00508452667448, 59.464274989274024, 59.91994659543682, 60.3721790231229, 60.82104898799428, 61.26663039534654, 61.708994482166055, 62.148209950086255, 62.584343089945435, 63.01745789858553, 63.447616188474726, 63.87487769068525, 64.29930015171239, 64.72093942457882, 65.13984955463131, 65.55608286040282, 65.96969000988257, 66.3807200925088, 66.78922068717378, 67.19523792650786, 67.59881655768835, 68.0, 68.39883039935698, 68.79534867997982, 69.1895945934069, 69.58160676500651, 69.97142273814362, 70.35907901614404, 70.74461110218927, 71.12805353726475, 71.50943993627695, 71.88880302244571, 72.26617466007178, 72.64158588577209, 73.01506693826967, 73.38664728681916, 73.75635565834311, 74.12422006335042], [0.0, 7.418894796396564, 10.491901638883201, 12.84990272336721, 14.837789592793127, 16.58915308266218, 18.172506706560878, 19.628550634216477, 20.983803277766402, 22.25668438918969, 23.46060527778429, 24.60569039876752, 25.69980544673442, 26.749205595680785, 27.758962516635957, 28.733255993708752, 29.675579185586255, 30.58888687088826, 31.475704916649605, 32.338212690252384, 33.17830616532436, 33.997646977401246, 34.79770107349047, 35.57976953269934, 36.345013413121755, 37.094473981982816, 37.82908933611805, 38.54970817010163, 39.257101268432955, 39.95197116538807, 40.63496031744094, 41.30665805896188, 41.967606555532804, 42.61830592597506, 43.25921867070648, 43.89077351790465, 44.51336877837938, 45.12737528374546, 45.73313896946065, 46.33098315382483, 46.92121055556858, 47.50410508577128, 48.07993344421351, 48.648946545634466, 49.21138079753504, 49.76745924798653, 50.317392619252445, 50.86138024080747, 51.39961089346884, 51.932263574775945, 52.45950819441601, 52.98150620735504, 53.49841119136157, 54.010369374778406, 54.51752011968263, 55.01999636495808, 55.517925033271915, 56.01142740548575, 56.50061946563065, 56.985612219226006, 57.466511987417505, 57.94342067914182, 58.41643604329179, 58.88565190264943, 59.35115837117251, 59.81304205605998, 60.27138624587956, 60.7262710859147, 61.17777374177652, 61.625968552226425, 62.07092717206664, 62.51271870587617, 62.95140983329921, 63.38706492652898, 63.81974616057322, 64.24951361683604, 64.67642538050477, 65.10053763218858, 65.52190473421848, 65.94057931198361, 66.35661233064872, 66.77005316756907, 67.18094968069447, 67.58934827323016, 67.99529395480249, 68.39883039935698, 68.80000000000001, 69.19884392097892, 69.59540214698094, 69.98971352991809, 70.38181583335287, 70.77174577470872, 71.15953906539868, 71.54523044899639, 71.92885373756488, 72.31044184625067, 72.69002682624351, 73.06763989619482, 73.44331147218242, 73.81707119630256, 74.18894796396563, 74.55896994996645], [0.0, 7.4619032424710525, 10.552724766618335, 12.924395537122813, 14.923806484942105, 16.68532289169137, 18.277855454073382, 19.742340286804907, 21.10544953323667, 22.385709727413158, 23.596609926004202, 24.748333277212833, 25.848791074245625, 26.904274753280383, 27.919885386584237, 28.89982698910151, 29.84761296988421, 30.766215236847057, 31.65817429985501, 32.5256821604098, 33.37064578338274, 34.19473643706002, 34.999428566763775, 35.78603079415207, 36.555710908146764, 37.30951621235526, 38.048390241901174, 38.77318661136843, 39.484680573609815, 40.183578735597955, 40.87052727822336, 41.546118952316114, 42.21089906647334, 42.865370638780206, 43.509998850838876, 44.14521491622846, 44.771419454826315, 45.38898544801371, 45.99826083668817, 46.599570813474244, 47.193219852008404, 47.779493509245164, 48.35866003106373, 48.930971786793684, 49.496666554425666, 50.055968675074105, 50.609090092591074, 51.15623129199414, 51.69758214849125, 52.23332269729737, 52.76362383309168, 53.28864794681885, 53.808549506560766, 54.32347558836788, 54.83356636222015, 55.33895553766804, 55.839770773168475, 56.33613405266642, 56.828162032569736, 57.3159663619135, 57.79965397820302, 58.27932738115635, 58.755084886331325, 59.22702086041472, 59.69522593976842, 60.15978723366631, 60.62078851351243, 61.07831038920445, 61.53243047369411, 61.9832235366958, 62.43076164840535, 62.87511431401139, 63.31634859971002, 63.7545292508697, 64.18971880293603, 64.62197768561406, 65.0513643208196, 65.4779352148493, 65.90174504518072, 66.3228467422803, 66.74129156676548, 67.15712918223947, 67.57040772409178, 67.981173864534, 68.38947287412005, 68.79534867997982, 69.19884392097892, 69.60000000000001, 69.99885713352755, 70.3954543987039, 70.7898297780126, 71.18202020173354, 71.57206158830414, 71.95998888271177, 72.34583609303303, 72.72963632522851, 73.11142181629353, 73.49122396585868, 73.86907336632835, 74.24499983163851, 74.61903242471053, 74.99119948367276], [0.0, 7.504665215717488, 10.613199329137279, 12.998461447417538, 15.009330431434975, 16.780941570722426, 18.382600468921694, 19.855477833585372, 21.226398658274558, 22.513995647152463, 23.731835158706122, 24.890158697766477, 25.996922894835077, 27.05845524046042, 28.07988603965479, 29.06544339933592, 30.01866086286995, 30.942527369301946, 31.83959798741184, 32.712077280417404, 33.56188314144485, 34.390696416327486, 35.2, 35.99111001344638, 36.76520093784339, 37.52332607858744, 38.266434377924476, 38.99538434225261, 39.710955667170744, 40.413859009008284, 41.10474425172841, 41.78420754304191, 42.452797316549116, 43.11101947298394, 43.7593418597675, 44.39819816163715, 45.027991294304925, 45.64909637659874, 46.261863343363075, 46.8666192508058, 47.463670317412245, 48.05330373657986, 48.63578929142613, 49.211380797535035, 49.780317395532954, 50.34282471216727, 50.89911590587798, 51.44939261060329, 51.993845789670154, 52.53265651002241, 53.065996645686404, 53.59402951822153, 54.11691048092084, 54.6347874526844, 55.147801406765076, 55.65608681896348, 56.15977207930958, 56.658979870802476, 57.15382751837361, 57.644427310885824, 58.13088679867184, 58.613309068845446, 59.09179300038204, 59.56643350075611, 60.0373217257399, 60.504545283804916, 60.96818842642448, 61.428332225447896, 61.88505473860389, 62.3384311640901, 62.78853398511547, 63.235433105182416, 63.67919597482368, 64.11988771044442, 64.55757120586244, 64.99230723708769, 65.42415456083481, 65.85317000722138, 66.27940856706554, 66.70292347416266, 67.1237662828897, 67.5419869414574, 67.95763386110498, 68.37075398150878, 68.78139283265497, 69.1895945934069, 69.59540214698094, 69.99885713352755, 70.4, 70.79887004748028, 71.19550547611837, 71.5899434278307, 71.98222002689276, 72.37237041855131, 72.76042880577327, 73.14642848423975, 73.53040187568678, 73.91238055968704, 74.29239530396096, 74.67047609329943, 75.04665215717488, 75.42095199611313], [0.0, 7.547184905645283, 10.673331251301066, 13.072107710694555, 15.094369811290566, 16.87601848778319, 18.48675201326615, 19.967974358957896, 21.346662502602133, 22.641554716935847, 23.866294224282075, 25.031180555459226, 26.14421542138911, 27.211762162711917, 28.238980151556465, 29.230121450312172, 30.18873962258113, 31.117840542042757, 32.0199937539032, 32.897416311923344, 33.75203697556638, 34.58554611394766, 35.39943502374014, 36.19502728276358, 36.9735040265323, 37.73592452822641, 38.48324310657822, 39.21632313208366, 39.93594871791579, 40.642834546817724, 41.3376341848442, 42.020947157340466, 42.693325005204265, 43.35527649548553, 44.00727212632021, 44.64974803960264, 45.283109433871694, 45.907733553291436, 46.52397231535588, 47.132154629297396, 47.73258844856415, 48.32556259372466, 48.911348376424876, 49.49020105030893, 50.06236111091845, 50.62805546334956, 51.18749847374845, 51.740892918464404, 52.28843084277822, 52.83029433951698, 53.36665625650534, 53.89768084064472, 54.423524325423834, 54.944335467816884, 55.460256039798445, 55.971421279077774, 56.47796030311293, 56.97999648999638, 57.47764782939539, 57.97102724637541, 58.460242900624344, 58.94539846332366, 59.42659337367404, 59.90392307687369, 60.37747924516226, 60.84734998338053, 61.3136200203511, 61.77637088725753, 62.23568108408551, 62.69162623508821, 63.14427923414757, 63.59371038082303, 64.0399875078064, 64.48317610043723, 64.92333940887514, 65.36053855347276, 65.79483262384669, 66.22627877210073, 66.65493230061824, 67.08084674480489, 67.50407395113275, 67.92466415080754, 68.34266602935534, 68.75812679240178, 69.17109222789531, 69.58160676500651, 69.98971352991809, 70.3954543987039, 70.79887004748028, 71.19999999999999, 71.59888267284623, 71.99555541837287, 72.39005456552717, 72.78241545868067, 73.1726724945864, 73.56085915757102, 73.9470080530646, 74.33115093956235, 74.71331875910747, 75.09354166637767, 75.47184905645283, 75.8482695913361], [0.0, 7.58946638440411, 10.73312629199899, 13.145341380123988, 15.17893276880822, 16.970562748477143, 18.5903200617956, 20.079840636817814, 21.46625258399798, 22.76839915321233, 24.0, 25.17141235608364, 26.290682760247975, 27.36421020237931, 28.397182958878155, 29.393876913398135, 30.35786553761644, 31.292171544972714, 32.19937887599697, 33.081717005016536, 33.941125496954285, 34.77930419085465, 35.597752738059185, 36.39780213144745, 37.1806401235912, 37.94733192202055, 38.69883719183304, 39.43602414037196, 40.15968127363563, 40.87052727822336, 41.569219381653056, 42.25636046798162, 42.93250516799596, 43.598165099003886, 44.253813395005864, 44.8998886412873, 45.53679830642466, 46.16492174801123, 46.784612855083026, 47.3962023795156, 48.0, 48.59629615515981, 49.18536367660607, 49.76745924798652, 50.34282471216728, 50.91168824543142, 51.47426541486532, 52.030760132829116, 52.58136552049595, 53.126264690828776, 53.665631459994955, 54.19963099505384, 54.72842040475862, 55.25214927946243, 55.770960185386805, 56.28498911788115, 56.79436591775631, 57.299214654303945, 57.799653978203025, 58.29579744715737, 58.78775382679627, 59.275627369096654, 59.75951807034591, 60.23952191045344, 60.71573107523288, 61.188234163113414, 61.657116377592615, 62.12245970661496, 62.58434308994543, 63.042842575505745, 63.49803146555018, 63.94998045347629, 64.39875775199394, 64.84442921331022, 65.28705844193013, 65.72670690061993, 66.16343401003307, 66.59729724245572, 67.02835221009093, 67.45665274826494, 67.88225099390857, 68.305197459637, 68.7255411037265, 69.14332939626208, 69.5586083817093, 69.97142273814362, 70.38181583335287, 70.7898297780126, 71.19550547611837, 71.59888267284623, 72.0, 72.39889501919211, 72.7956042628949, 73.19016327348916, 73.58260664042828, 73.97296803562772, 74.3612802471824, 74.74757521150771, 75.13188404399293, 75.51423706825092, 75.8946638440411, 76.27319319393939], [0.0, 7.631513611335565, 10.792590050585632, 13.218169313486646, 15.26302722267113, 17.064583206161235, 18.693314312876677, 20.19108714259834, 21.585180101171265, 22.894540834006694, 24.13296500639737, 25.310867231290203, 26.436338626973292, 27.515813635071744, 28.554509276119596, 29.556725123057863, 30.52605444534226, 31.46553670287542, 32.3777701517569, 33.26499661806687, 34.12916641232247, 34.97198879103103, 35.79497171391535, 36.5994535478332, 37.38662862575335, 38.15756805667783, 38.913236822448994, 39.654507940459936, 40.38217428519668, 41.096958524932234, 41.79952152836202, 42.4904695196464, 43.17036020234253, 43.83970802822483, 44.498988752554816, 45.148643390471875, 45.78908166801339, 46.42068504449283, 47.0438093695653, 47.65878722754074, 48.26593001279474, 48.86552977304145, 49.457860851435946, 50.04318135370692, 50.621734462580406, 51.19374961848369, 51.7594435827898, 52.31902139757585, 52.872677253946584, 53.42059527934896, 53.96295025292817, 54.49990825680352, 55.03162727014349, 55.55825771206294, 56.07994293863003, 56.59681969863678, 57.10901855223919, 57.61666425609869, 58.11987611824375, 58.61876832551158, 59.113450246115725, 59.60402670961082, 60.09059826628455, 60.573261427795025, 61.05210889068452, 61.527229744236, 61.9987096639922, 62.4666310921279, 62.93107340575084, 63.3921130741041, 63.84982380555173, 64.30427668514747, 64.7555403035138, 65.20368087769279, 65.64876236457165, 66.09084656743323, 66.52999323613373, 66.96626016136783, 67.39970326344175, 67.8303766759407, 68.25833282464494, 68.68362250202009, 69.1062949375815, 69.52639786440831, 69.94397758206206, 70.35907901614404, 70.77174577470872, 71.18202020173354, 71.5899434278307, 71.99555541837287, 72.39889501919211, 72.8, 73.1989070956664, 73.59565204548433, 73.99026963053994, 74.38279370929811, 74.7732572515067, 75.16169237051545, 75.54813035409943, 75.93260169387061, 76.31513611335566, 76.69576259481354], [0.0, 7.673330437300352, 10.851727973000429, 13.290598180668923, 15.346660874600705, 17.158088471621777, 18.79574419915317, 20.301724064719235, 21.703455946000858, 23.019991311901055, 24.265201420964964, 25.44955795293899, 26.581196361337845, 27.666586345264935, 28.71097351188218, 29.718680993610736, 30.69332174920141, 31.637951893256304, 32.55518391900129, 33.447271936587, 34.316176943243555, 35.16361756133746, 35.99111001344638, 36.800000000000004, 37.59148839830634, 38.36665218650176, 39.126461634039956, 39.87179454200677, 40.60344812943847, 41.32214902446387, 42.02856171700383, 42.723295753019805, 43.406911892001716, 44.079927404658925, 44.7428206531506, 45.396035069155545, 46.03998262380211, 46.67504686660744, 47.30158559710235, 47.919933221990206, 48.53040284192993, 49.133288104909084, 49.72886485734418, 50.31739261925244, 50.89911590587798, 51.47426541486532, 52.0430590953299, 52.60570311287551, 53.16239272267569, 53.71331306110246, 54.25863986500215, 54.798540126539876, 55.33317269052987, 55.8626888003075, 56.387232597459516, 56.906941580091974, 57.42194702376436, 57.93237436874136, 58.438343576798964, 58.93996946046036, 59.43736198722147, 59.93062656104974, 60.41986428319746, 60.9051721941577, 61.38664349840282, 61.864367773379854, 62.3384311640901, 62.808916564449675, 63.27590378651261, 63.73946971853469, 64.19968847276442, 64.65663152376561, 65.11036783800257, 65.56096399535322, 66.00848430315607, 66.4529909033446, 66.894543873174, 67.33320132000262, 67.7690194705516, 68.20205275503078, 68.63235388648711, 69.05997393570317, 69.4849624019471, 69.90736727985113, 70.32723512267492, 70.74461110218927, 71.15953906539868, 71.57206158830414, 71.98222002689276, 72.39005456552717, 72.7956042628949, 73.1989070956664, 73.60000000000001, 73.99891891102195, 74.39569880040109, 74.79037371212956, 75.18297679661268, 75.57354034316509, 75.96209581100301, 76.34867385881697, 76.73330437300352, 77.11601649462972], [0.0, 7.7149206087943645, 10.910545357588685, 13.362634470792056, 15.429841217588729, 17.25108692227826, 18.897618897628348, 20.41176131547692, 21.82109071517737, 23.144761826383093, 24.39672109116305, 25.587496946751166, 26.725268941584112, 27.81654184114194, 28.866589684269947, 29.879759035172956, 30.859682435177458, 31.80943256331367, 32.73163607276606, 33.62855929117393, 34.50217384455652, 35.35420767037497, 36.186185209275656, 36.99945945551097, 37.795237795256696, 38.57460304397183, 39.33853073006159, 40.087903412376164, 40.82352263095384, 41.546118952316114, 42.25636046798162, 42.95486002770816, 43.64218143035474, 44.31884475028654, 44.98533094243056, 45.64208584190692, 46.289523652766185, 46.92803000339989, 47.55796463264593, 48.17966375972336, 48.7934421823261, 49.39959514004139, 49.99839997439919, 50.590117612039606, 51.17499389350233, 51.75326076683478, 52.32513736245707, 52.89083096340991, 53.450537883168224, 54.00444426156055, 54.55272678794343, 55.09555335959519, 55.63308368228388, 56.165469819097936, 56.692856692885044, 57.21538254700392, 57.73317936853989, 58.24637327765567, 58.75508488633133, 59.25942962938473, 59.75951807034591, 60.25545618448175, 60.747345621022816, 61.23528394643076, 61.719364870354916, 62.19967845576053, 62.67631131456286, 63.14934678997084, 63.61886512662734, 64.08494362952972, 64.5476568126218, 65.00707653786625, 65.46327214553212, 65.91631057636646, 66.36625648625964, 66.81317235396027, 67.25711858234786, 67.6981535937281, 68.13633391957629, 68.57171428511906, 69.00434768911305, 69.43428547914928, 69.86157742278657, 70.28627177479255, 70.70841534074994, 71.12805353726475, 71.54523044899639, 71.95998888271177, 72.37237041855131, 72.78241545868067, 73.19016327348916, 73.59565204548433, 73.99891891102195, 74.4, 74.79893047363713, 75.19574456044704, 75.59047559051339, 75.98315602816194, 76.3738175031208, 76.76249084025349, 77.14920608794365, 77.53399254520563], [0.0, 7.756287771866127, 10.969047360641671, 13.434284498997334, 15.512575543732254, 17.343586710943043, 18.99894733926067, 20.52120854140906, 21.938094721283342, 23.26886331559838, 24.52753554680943, 25.724696305301645, 26.868568997994668, 27.965693268717658, 29.021371435547287, 30.039973368829738, 31.025151087464508, 31.9799937460907, 32.907142081925016, 33.808874574584706, 34.68717342188609, 35.5437758264369, 36.38021440288664, 37.197849400200546, 37.99789467852134, 38.781438859330635, 39.54946270178649, 40.302853496992, 41.04241708281812, 41.768887943061166, 42.48293775152561, 43.1851826440505, 43.876189442566684, 44.55648101006183, 45.22654088032823, 45.88681727903996, 46.53772663119676, 47.17965663291754, 47.8129689519486, 48.43800161030594, 49.05507109361886, 49.66447422454003, 50.266489831696035, 50.86138024080746, 51.44939261060329, 52.030760132829116, 52.60570311287552, 53.174429945228376, 53.737137995989336, 54.29401440306289, 54.84523680320836, 55.390973993964046, 55.931386537435316, 56.466627312068155, 56.99684201778201, 57.522169639192164, 58.042742871094575, 58.55868850990432, 59.07012781431915, 59.57717683811478, 60.079946737659476, 60.57854405645617, 61.073070988775406, 61.56362562422717, 62.050302174929016, 62.53319118676097, 63.0123797360487, 63.48795161288479, 63.9599874921814, 64.42856509344284, 64.8937593301544, 65.35564244960032, 65.81428416385003, 66.26975177258475, 66.72211027837774, 67.17142249498667, 67.61774914916941, 68.06114897649026, 68.50167881154448, 68.93939367299367, 69.37434684377217, 69.80658994679514, 70.23617301647351, 70.66314456631548, 71.0875516528738, 71.50943993627695, 71.92885373756488, 72.34583609303303, 72.76042880577327, 73.1726724945864, 73.58260664042828, 73.99026963053994, 74.39569880040109, 74.79893047363713, 75.2, 75.59894179153568, 75.99578935704268, 76.39057533491943, 76.7833315244917, 77.17408891590495, 77.56287771866127, 77.94972738887547], [0.0, 7.797435475847171, 11.027239001672177, 13.505554412907307, 15.594870951694341, 17.435595774162696, 19.099738218101315, 20.6300751331642, 22.054478003344354, 23.39230642754151, 24.657656011875904, 25.86116780039138, 27.011108825814613, 28.114053425288926, 29.17533204609675, 30.199337741082996, 31.189741903388683, 32.14965007585619, 33.08171700501653, 33.988233257996804, 34.87119154832539, 35.73233829460367, 36.573214242119874, 37.39518685606478, 38.19947643620263, 38.98717737923585, 39.75927564732537, 40.51666323872192, 41.2601502663284, 41.99047511043427, 42.70831300812524, 43.41428336388843, 44.10895600668871, 44.79285657334214, 45.46647116282503, 46.13025037868318, 46.78461285508302, 47.42994834490124, 48.06662043455937, 48.69496893930624, 49.31531202375181, 49.92794808521576, 50.533157431532025, 51.13120378007933, 51.72233560078276, 52.30678732248808, 52.88478041932291, 53.45652439132196, 54.02221765162923, 54.58204833093019, 55.136195008360886, 55.68482737694354, 56.22810685057785, 56.76618711874173, 57.299214654303945, 57.827329179203836, 58.3506640921935, 58.869346862352735, 59.38349939166603, 59.89323834958333, 60.39867548216599, 60.89991789813841, 61.39706833391965, 61.89022539949261, 62.379483806777365, 62.86493458200683, 63.34666526345329, 63.82476008572221, 64.29930015171237, 64.77036359323607, 65.23802572120036, 65.70235916616693, 66.16343401003306, 66.62131790951001, 67.07607621201466, 67.52777206453652, 67.97646651599361, 68.42221861354687, 68.8650854933035, 69.30512246580335, 69.74238309665078, 70.17691928262454, 70.60878132357193, 71.03801799036907, 71.46467658920734, 71.88880302244571, 72.31044184625067, 72.72963632522851, 73.14642848423975, 73.56085915757102, 73.97296803562772, 74.38279370929811, 74.79037371212956, 75.19574456044704, 75.59894179153568, 75.99999999999999, 76.39895287240526, 76.79583322029913, 77.19067301170523, 77.58350340117414, 77.9743547584717, 78.36325669597966], [0.0, 7.8383671769061705, 11.085125168440815, 13.576450198781714, 15.676734353812341, 17.527121840165318, 19.200000000000003, 20.738370234905155, 22.17025033688163, 23.51510153071851, 24.78709341572747, 25.996922894835077, 27.152900397563428, 28.261634772249113, 29.328484447717376, 30.35786553761644, 31.353468707624682, 32.31841580275865, 33.25537550532245, 34.1666504065002, 35.054243680330636, 35.91991091302984, 36.76520093784339, 37.59148839830634, 38.400000000000006, 39.19183588453085, 39.967987189749756, 40.72935059634514, 41.47674046981031, 42.210899066473345, 42.93250516799596, 43.64218143035474, 44.34050067376326, 45.02799129430493, 45.705141942674246, 46.372405587806206, 47.03020306143702, 47.67892616240429, 48.3189403857328, 48.95058733049074, 49.57418683145494, 50.190038852346, 50.79842517244015, 51.39961089346883, 51.993845789670154, 52.58136552049594, 53.16239272267568, 53.73713799598933, 54.305800795126856, 54.86857023834319, 55.42562584220408, 55.97713819051489, 56.52326954449823, 57.064174400406436, 57.6, 58.130886798671845, 58.65696889543475, 59.178374428502174, 59.69522593976842, 60.20764071112569, 60.71573107523288, 61.219604703068775, 61.71936487035491, 62.215110704715464, 62.706937415249364, 63.194936506020795, 63.67919597482368, 64.15980049844295, 64.6368316055173, 65.11036783800257, 65.58048490214144, 66.04725580976094, 66.5107510106449, 66.97103851666031, 67.42818401825753, 67.88225099390857, 68.3333008130004, 68.78139283265497, 69.2265844889086, 69.66893138264717, 70.10848736066127, 70.54530459215553, 70.97943364102028, 71.41092353414847, 71.83982182605968, 72.26617466007178, 72.69002682624351, 73.11142181629353, 73.53040187568678, 73.9470080530646, 74.3612802471824, 74.7732572515067, 75.18297679661268, 75.59047559051339, 75.99578935704268, 76.39895287240526, 76.80000000000001, 77.19896372361485, 77.5958761790857, 77.99076868450523, 78.3836717690617, 78.77461520058351], [0.0, 7.879086241436885, 11.142710621747296, 13.646977687385588, 15.75817248287377, 17.618172436436197, 19.299740930903713, 20.846102753272614, 22.285421243494593, 23.63725872431065, 24.9158584038359, 26.131972753697724, 27.293955374771176, 28.408449447303532, 29.48084123630125, 30.515569796417044, 31.51634496574754, 32.486304806795125, 33.42813186524189, 34.34414069386509, 35.236344872872394, 36.10650910846963, 36.95619027984352, 37.786770171582546, 38.599481861807426, 39.39543120718442, 40.17561449436711, 40.94093306215676, 41.69220550654523, 42.43017793976359, 43.15553266963577, 43.86889558673663, 44.570842486989186, 45.261904511410044, 45.94257284915594, 46.613302822263094, 47.2745174486213, 47.92661056240052, 48.569949557313734, 49.204877806981706, 49.8317168076718, 50.4507680813682, 51.06231487114544, 51.666623655896075, 52.26394550739545, 52.85451730930858, 53.43856285492716, 54.01629383806335, 54.58791074954235, 55.15360369005819, 55.713553108736484, 56.26793047553821, 56.816898894607064, 57.36061366477874, 57.899222792711136, 58.43286746344048, 58.9616824726025, 59.48579662406817, 60.00533309631737, 60.52040978050297, 61.03113959283409, 61.53763076362301, 62.03998710509215, 62.538308259817846, 63.03268993149508, 63.52322409953702, 64.00999921887205, 64.49310040616749, 64.97260961359025, 65.44860579110912, 65.92116503824853, 66.39036074612038, 66.85626373048378, 67.31894235651657, 67.77846265592044, 68.23488843692793, 68.68828138773019, 69.13870117379992, 69.58620552954444, 70.03085034468738, 70.47268974574479, 70.91177617293197, 71.34816045281057, 71.78189186696044, 72.21301821693926, 72.64158588577209, 73.06763989619482, 73.49122396585868, 73.91238055968704, 74.33115093956235, 74.74757521150771, 75.16169237051545, 75.57354034316509, 75.98315602816194, 76.39057533491943, 76.79583322029913, 77.19896372361485, 77.60000000000002, 77.99897435223107, 78.39591826109317, 78.79086241436885, 79.18383673452558], [0.0, 7.919595949289333, 11.2, 13.717142559585799, 15.839191898578665, 17.708754896942924, 19.398969044771427, 20.95328136593407, 22.4, 23.758787847867996, 25.043961347997644, 26.266328255011206, 27.434285119171598, 28.554509276119596, 29.632414683923415, 30.6724632202893, 31.67838379715733, 32.65333061113368, 33.6, 34.52071841662627, 35.41750979388585, 36.29214791108402, 37.14619765198048, 37.981047905501505, 38.79793808954285, 39.59797974644666, 40.38217428519668, 41.15142767875739, 41.90656273186814, 42.64832939283789, 43.37741347752306, 44.09444409446614, 44.8, 45.49461506596138, 46.1787830069178, 46.85296148590823, 47.51757569573599, 48.17302149543871, 48.81966816765554, 49.457860851435946, 50.08792269599529, 50.71015677356954, 51.32484778350541, 51.93226357477594, 52.53265651002241, 53.12626469082877, 53.71331306110246, 54.29401440306289, 54.868570238343196, 55.43717164502532, 56.0, 56.55722765482764, 57.10901855223919, 57.65552878952721, 58.19690713431428, 58.73329549752849, 59.26482936784683, 59.79163821137534, 60.31384583990645, 60.831570750721205, 61.3449264405786, 61.85402169624866, 62.35896086369624, 62.85984409780222, 63.35676759431466, 63.84982380555172, 64.33910164122592, 64.82468665562526, 65.30666122226737, 65.78510469703609, 66.2600935707157, 66.73170161175271, 67.2, 67.6650574521296, 68.12694033934005, 68.58571279792899, 69.04143683325255, 69.4941724175488, 69.94397758206206, 70.3909085038686, 70.8350195877717, 71.27636354360399, 71.71499145924791, 72.1509528696607, 72.58429582216804, 73.01506693826967, 73.44331147218242, 73.86907336632835, 74.29239530396096, 74.71331875910747, 75.13188404399293, 75.54813035409943, 75.96209581100301, 76.3738175031208, 76.7833315244917, 77.19067301170523, 77.5958761790857, 77.99897435223107, 78.4, 78.79898476503362, 79.19595949289332, 79.59095425989062], [0.0, 7.959899496852961, 11.256997823576231, 13.78695035169127, 15.919798993705921, 17.798876369029593, 19.497692171126307, 21.059914529741096, 22.513995647152463, 23.87969849055888, 25.17141235608364, 26.400000000000006, 27.57390070338254, 28.69982578344336, 29.783216750378056, 30.82855818879631, 31.839597987411842, 32.81950639482562, 33.7709934707287, 34.69639750752231, 35.597752738059185, 36.476841968569595, 37.335238046649714, 38.17433692940848, 38.99538434225261, 39.799497484264805, 40.587682860690634, 41.36085105507381, 42.11982905948219, 42.86537063878021, 43.59816509900388, 44.31884475028654, 45.027991294304925, 45.72614131981837, 46.41379105395292, 47.091400488836605, 47.75939698111776, 48.41817840439684, 49.0681159206261, 49.709556425299155, 50.34282471216728, 50.96822539582873, 51.58604462449124, 52.19655161023571, 52.80000000000001, 53.39662910708877, 53.98666502016957, 54.570321604329955, 55.14780140676508, 55.71929647797072, 56.28498911788116, 56.845052555169666, 57.39965156688672, 57.94894304471826, 58.493076513378924, 59.032194605994455, 59.56643350075611, 60.095923322634796, 60.62078851351244, 61.14114817371359, 61.65711637759262, 62.168802465545376, 62.67631131456286, 63.179743589223285, 63.679195974823685, 64.1747613941805, 64.66652920947591, 65.15458541039149, 65.63901278965125, 66.11989110698838, 66.59729724245572, 67.07130533991418, 67.5419869414574, 68.00941111346282, 68.47364456489811, 68.93475175845634, 69.39279501504463, 69.8478346121052, 70.2999288762087, 70.74913427032165, 71.19550547611837, 71.63909547167664, 72.07995560486981, 72.51813566274302, 72.95368393713919, 73.38664728681916, 73.81707119630256, 74.24499983163851, 74.67047609329943, 75.09354166637767, 75.51423706825092, 75.93260169387061, 76.34867385881697, 76.76249084025349, 77.17408891590495, 77.58350340117414, 77.99076868450523, 78.39591826109317, 78.79898476503362, 79.20000000000002, 79.59899496852961, 79.99599989999501], [0.0, 8.0, 11.313708498984761, 13.856406460551021, 16.0, 17.88854381999832, 19.595917942265427, 21.166010488516726, 22.627416997969522, 24.0, 25.298221281347036, 26.532998322843202, 27.712812921102042, 28.844410203711917, 29.93325909419153, 30.983866769659333, 32.0, 32.984845004941285, 33.941125496954285, 34.87119154832539, 35.77708763999664, 36.660605559646726, 37.52332607858744, 38.36665218650176, 39.19183588453085, 40.00000000000001, 40.79215610874228, 41.56921938165306, 42.33202097703345, 43.08131845707604, 43.81780460041329, 44.54211490264018, 45.254833995939045, 45.956501172304236, 46.647615158762406, 47.32863826479693, 48.0, 48.66210024238576, 49.315312023751815, 49.959983987187194, 50.59644256269407, 51.224993899462795, 51.84592558726289, 52.459508194416, 53.065996645686404, 53.66563145999495, 54.25863986500215, 54.84523680320836, 55.425625842204084, 56.0, 56.56854249492381, 57.13142742834281, 57.68882040742383, 58.24087911424416, 58.78775382679628, 59.32958789676531, 59.86651818838306, 60.398675482166, 60.926184846911276, 61.44916598294886, 61.967733539318665, 62.48199740725324, 62.99206299209449, 63.49803146555018, 64.0, 64.4980619863884, 64.99230723708769, 65.4828221749796, 65.96969000988257, 66.4529909033446, 66.93280212272605, 67.40919818541087, 67.88225099390857, 68.35202996254026, 68.81860213634101, 69.2820323027551, 69.74238309665078, 70.19971509913698, 70.65408693062278, 71.10555533852472, 71.55417527999327, 72.00000000000001, 72.44308110509934, 72.8834686331544, 73.32121111929345, 73.75635565834311, 74.18894796396563, 74.61903242471053, 75.04665215717488, 75.47184905645283, 75.8946638440411, 76.31513611335566, 76.73330437300352, 77.14920608794365, 77.56287771866127, 77.9743547584717, 78.3836717690617, 78.79086241436885, 79.19595949289332, 79.59899496852961, 80.00000000000001, 80.39900496896713], [0.0, 8.039900496896713, 11.370136322841518, 13.925516148423371, 16.079800993793427, 17.97776404339539, 19.693653800145878, 21.271577280493332, 22.740272645683035, 24.11970149069014, 25.424397731313128, 26.665333299998338, 27.851032296846743, 28.988273491189506, 30.082553083141068, 31.138400729645703, 32.15960198758685, 33.14935896816106, 34.11040896852455, 35.04511378209522, 35.95552808679078, 36.84345260694226, 37.710475998056566, 38.55800824731486, 39.387307600291756, 40.19950248448357, 40.99560952102067, 41.77654844527011, 42.543154560986665, 43.29618920875139, 44.036348622473234, 44.7642714673209, 45.48054529136607, 46.1857120763554, 46.88027303674756, 47.5646927878232, 48.23940298138028, 48.904805489849366, 49.56127520554733, 50.20916251044226, 50.848795462626256, 51.48048173822775, 52.10451036138811, 52.7211532499053, 53.330666599996675, 53.93329213018616, 54.52925820144632, 55.118780828316595, 55.702064593693486, 56.279303478276994, 56.85068161420759, 57.41637397119398, 57.97654698237901, 58.53135911628912, 59.08096140043763, 59.625497901485076, 60.165106166282136, 60.69991762762122, 61.23005797808786, 61.7556475150249, 62.276801459291406, 62.793630250209304, 63.30623981883619, 63.81473184148, 64.3192039751737, 64.81975007665488, 65.31646040624064, 65.8094218178522, 66.29871793632212, 66.78442932300912, 67.26663363064931, 67.74540574828673, 68.2208179370491, 68.6929399574658, 69.16183918896316, 69.62758074211685, 70.09022756419044, 70.54984053844488, 71.00647857766221, 71.4601987122902, 71.91105617358156, 72.35910447207043, 72.80439547170214, 73.24697945990674, 73.68690521388451, 74.12422006335042, 74.55896994996645, 74.99119948367276, 75.42095199611313, 75.8482695913361, 76.27319319393939, 76.69576259481354, 77.11601649462972, 77.53399254520563, 77.94972738887547, 78.36325669597966, 78.77461520058351, 79.18383673452558, 79.59095425989062, 79.99599989999501, 80.39900496896713, 80.80000000000001]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"A = 8.5\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.8500000000000001, 1.2020815280171309, 1.472243186433546, 1.7000000000000002, 1.9006577808748215, 2.082066281365701, 2.248888614404902, 2.4041630560342617, 2.5500000000000003, 2.6879360111431225, 2.81913107180209, 2.944486372867092, 3.064718584144391, 3.18040877875785, 3.2920358442763042, 3.4000000000000004, 3.504639781775012, 3.6062445840513924, 3.705064102009573, 3.801315561749643, 3.8951893407124643, 3.9868533958499155, 4.076456794815812, 4.164132562731402, 4.25, 4.334166586553867, 4.416729559300638, 4.497777228809804, 4.577390086064329, 4.655641738793912, 4.732599708405519, 4.8083261120685235, 4.882878249557325, 4.9563091106185055, 5.028667815634674, 5.1000000000000005, 5.170348150753488, 5.239751902523631, 5.308248298638639, 5.375872022286245, 5.442655601817922, 5.508629593646682, 5.5738227456567, 5.63826214360418, 5.701973342624464, 5.764980485656479, 5.827306410340888, 5.888972745734184, 5.95, 6.010407640085654, 6.070214164261423, 6.129437168288782, 6.188093405888442, 6.246198844097104, 6.303768714031313, 6.3608175575157, 6.417359269980137, 6.473407139984322, 6.528973885688316, 6.5840716885526085, 6.638712224520656, 6.6929066929100385, 6.746665843214707, 6.800000000000001, 6.852919086053767, 6.905432643940567, 6.957549856091583, 7.009279563550024, 7.060630283480364, 7.111610225539643, 7.162227307199905, 7.212489168102785, 7.262403183519902, 7.311976476986232, 7.361215932167728, 7.410128204019146, 7.458719729283304, 7.506996736378671, 7.554965254718251, 7.602631123499286, 7.65, 7.697077367416805, 7.743868542272653, 7.7903786814249285, 7.836612788698955, 7.8825757211713485, 7.928272195125493, 7.973706791699831, 8.018883962248113, 8.063808033429368, 8.108483212044039, 8.152913589631623, 8.197103146844013, 8.241055757607759, 8.284775193087619, 8.328265125462805, 8.37152913152669, 8.414570696119917, 8.45739321540627, 8.5, 8.542394277952758], [0.0, 1.2020815280171309, 1.7, 2.0820662813657016, 2.4041630560342617, 2.6879360111431225, 2.9444863728670914, 3.1804087787578506, 3.4, 3.6062445840513924, 3.8013155617496426, 3.986853395849915, 4.164132562731403, 4.334166586553867, 4.497777228809803, 4.6556417387939115, 4.8083261120685235, 4.9563091106185055, 5.1, 5.23975190252363, 5.375872022286245, 5.508629593646681, 5.63826214360418, 5.764980485656478, 5.888972745734183, 6.010407640085654, 6.129437168288782, 6.246198844097105, 6.360817557515701, 6.473407139984323, 6.5840716885526085, 6.692906692910039, 6.8, 6.905432643940567, 7.009279563550023, 7.111610225539642, 7.212489168102785, 7.311976476986233, 7.410128204019146, 7.50699673637867, 7.602631123499285, 7.697077367416805, 7.790378681424929, 7.882575721171347, 7.97370679169983, 8.063808033429368, 8.152913589631623, 8.241055757607759, 8.328265125462806, 8.414570696119915, 8.5, 8.584579197607766, 8.668333173107735, 8.751285619838951, 8.833459118601274, 8.914875209446288, 8.995554457619606, 9.075516514226614, 9.154780172128657, 9.233363417520183, 9.311283477587823, 9.388556864609171, 9.465199416811036, 9.541226336273551, 9.616652224137047, 9.691491113342671, 9.76575649911465, 9.839461367371692, 9.912618221237011, 9.985239105800122, 10.057335631269348, 10.128918994641037, 10.2, 10.270589077555387, 10.340696301506972, 10.410331406828506, 10.47950380504726, 10.54822259909223, 10.616496597277278, 10.684334326480053, 10.75174404457249, 10.818733752154177, 10.885311203635844, 10.951483917716356, 11.017259187293362, 11.082644088844503, 11.147645491313401, 11.212270064531982, 11.27652428720836, 11.340414454507382, 11.403946685248927, 11.467126928747236, 11.529960971312956, 11.592454442437978, 11.654612820681775, 11.716441439276688, 11.777945491468365, 11.839130035606502, 11.9, 11.960560187549746, 12.020815280171307, 12.080769843019112], [0.0, 1.472243186433546, 2.0820662813657016, 2.5500000000000007, 2.944486372867092, 3.292035844276305, 3.606244584051393, 3.8951893407124647, 4.164132562731403, 4.416729559300638, 4.655641738793912, 4.882878249557325, 5.100000000000001, 5.308248298638639, 5.508629593646681, 5.7019733426244645, 5.888972745734184, 6.070214164261424, 6.246198844097105, 6.417359269980139, 6.58407168855261, 6.746665843214707, 6.905432643940568, 7.060630283480365, 7.212489168102786, 7.361215932167729, 7.506996736378671, 7.650000000000002, 7.790378681424929, 7.928272195125494, 8.063808033429368, 8.197103146844013, 8.328265125462806, 8.457393215406272, 8.584579197607768, 8.70990815106566, 8.833459118601276, 8.95530568992483, 9.075516514226617, 9.194155752433174, 9.311283477587825, 9.426956030448006, 9.541226336273553, 9.654144187860465, 9.76575649911465, 9.876107532828915, 9.985239105800124, 10.093190773982231, 10.200000000000003, 10.305702305034822, 10.410331406828508, 10.513919345325037, 10.616496597277278, 10.71809218098072, 10.818733752154179, 10.91844769186536, 11.017259187293362, 11.11519230602872, 11.212270064531983, 11.30851449130256, 11.403946685248929, 11.498586869698382, 11.592454442437978, 11.685568022137394, 11.777945491468367, 11.869604037203601, 11.960560187549747, 12.050829846944154, 12.140428328522848, 12.229370384447437, 12.317670234261026, 12.405341591427462, 12.49239768819421, 12.578851298906432, 12.66471476188864, 12.750000000000002, 12.834718539960278, 12.918881530535067, 13.002499759661603, 13.085583670589557, 13.16814337710522, 13.250188677901914, 13.331729070154406, 13.412773762350575, 13.493331686429414, 13.573411509270617, 13.653021643577661, 13.732170258192987, 13.810865287881136, 13.889114442612964, 13.966925216381737, 14.044304895579563, 14.12126056696073, 14.197799125216559, 14.273927280184667, 14.349651563714014, 14.424978336205571, 14.499913792847186, 14.574463969559911, 14.648634748671975, 14.722431864335459, 14.795860907699833], [0.0, 1.7000000000000002, 2.4041630560342617, 2.944486372867092, 3.4000000000000004, 3.801315561749643, 4.164132562731402, 4.497777228809804, 4.8083261120685235, 5.1000000000000005, 5.375872022286245, 5.63826214360418, 5.888972745734184, 6.129437168288782, 6.3608175575157, 6.5840716885526085, 6.800000000000001, 7.009279563550024, 7.212489168102785, 7.410128204019146, 7.602631123499286, 7.7903786814249285, 7.973706791699831, 8.152913589631623, 8.328265125462805, 8.5, 8.668333173107735, 8.833459118601276, 8.995554457619608, 9.154780172128659, 9.311283477587825, 9.465199416811037, 9.616652224137047, 9.76575649911465, 9.912618221237011, 10.057335631269348, 10.200000000000001, 10.340696301506975, 10.479503805047262, 10.616496597277278, 10.75174404457249, 10.885311203635844, 11.017259187293364, 11.1476454913134, 11.27652428720836, 11.403946685248927, 11.529960971312958, 11.654612820681775, 11.777945491468367, 11.9, 12.020815280171307, 12.140428328522846, 12.258874336577565, 12.376186811776885, 12.492397688194208, 12.607537428062626, 12.7216351150314, 12.834718539960274, 12.946814279968644, 13.057947771376632, 13.168143377105217, 13.277424449041312, 13.385813385820077, 13.493331686429414, 13.600000000000001, 13.705838172107534, 13.810865287881134, 13.915099712183165, 14.018559127100048, 14.121260566960729, 14.223220451079285, 14.32445461439981, 14.42497833620557, 14.524806367039805, 14.623952953972465, 14.722431864335457, 14.820256408038292, 14.917439458566609, 15.013993472757342, 15.109930509436502, 15.205262246998572, 15.3, 15.39415473483361, 15.487737084545307, 15.580757362849857, 15.67322557739791, 15.765151442342697, 15.856544390250987, 15.947413583399662, 16.037767924496226, 16.127616066858735, 16.216966424088078, 16.305827179263247, 16.394206293688026, 16.482111515215518, 16.569550386175237, 16.65653025092561, 16.74305826305338, 16.829141392239833, 16.91478643081254, 17.0, 17.084788555905515], [0.0, 1.9006577808748215, 2.6879360111431225, 3.2920358442763047, 3.801315561749643, 4.250000000000001, 4.655641738793912, 5.028667815634674, 5.375872022286245, 5.7019733426244645, 6.0104076400856545, 6.303768714031314, 6.584071688552609, 6.852919086053768, 7.111610225539642, 7.361215932167728, 7.602631123499286, 7.836612788698956, 8.063808033429368, 8.28477519308762, 8.500000000000002, 8.70990815106566, 8.91487520944629, 9.115234500549068, 9.311283477587825, 9.503288904374108, 9.691491113342675, 9.876107532828915, 10.057335631269348, 10.235355391973453, 10.410331406828508, 10.582414658290425, 10.75174404457249, 10.918447691865362, 11.082644088844503, 11.244443072024511, 11.403946685248929, 11.56124993242513, 11.716441439276691, 11.869604037203601, 12.020815280171309, 12.170147903784901, 12.317670234261026, 12.463446553822903, 12.607537428062628, 12.75, 12.890888254887638, 13.030253259242508, 13.168143377105219, 13.30460446612375, 13.439680055715613, 13.573411509270617, 13.705838172107535, 13.836997506684755, 13.966925216381737, 14.09565535901045, 14.223220451079284, 14.349651563714014, 14.474978411037442, 14.599229431720017, 14.722431864335457, 14.844611817087035, 14.965794332410157, 15.086003446904023, 15.205262246998572, 15.323592920721953, 15.44101680589721, 15.55755443506466, 15.673225577397911, 15.788049277855706, 15.902043893789253, 16.01522712920426, 16.127616066858735, 16.23922719836138, 16.35007645242064, 16.460179221381523, 16.56955038617524, 16.6782043397963, 16.786155009411775, 16.893415877199022, 17.000000000000004, 17.105920027873392, 17.2111882216191, 17.315816469343858, 17.41981630213132, 17.52319890887506, 17.625975150328564, 17.72815557242208, 17.82975041889258, 17.930769643269638, 18.031222920256962, 18.131119656546314, 18.230469001098136, 18.329279854920653, 18.42756088037698, 18.525320510047862, 18.62256695517565, 18.719308213713457, 18.815552078001858, 18.91130614209394, 19.006577808748215, 19.1013742961076], [0.0, 2.0820662813657016, 2.9444863728670914, 3.606244584051393, 4.164132562731403, 4.655641738793912, 5.1, 5.508629593646682, 5.888972745734183, 6.246198844097105, 6.5840716885526085, 6.905432643940567, 7.212489168102786, 7.50699673637867, 7.790378681424928, 8.063808033429368, 8.328265125462806, 8.584579197607766, 8.833459118601274, 9.075516514226615, 9.311283477587825, 9.541226336273551, 9.76575649911465, 9.985239105800122, 10.2, 10.410331406828508, 10.616496597277278, 10.818733752154179, 11.017259187293364, 11.212270064531983, 11.403946685248927, 11.592454442437978, 11.777945491468365, 11.960560187549747, 12.140428328522846, 12.317670234261024, 12.49239768819421, 12.664714761888641, 12.834718539960276, 13.002499759661603, 13.168143377105217, 13.331729070154404, 13.493331686429414, 13.653021643577658, 13.810865287881134, 13.966925216381737, 14.121260566960729, 14.273927280184667, 14.424978336205571, 14.574463969559911, 14.722431864335457, 14.868927331855518, 15.01399347275734, 15.15767132510796, 15.3, 15.441016805897208, 15.580757362849855, 15.719255707570891, 15.856544390250987, 15.992654563892762, 16.127616066858735, 16.261457499252643, 16.394206293688022, 16.525888780940047, 16.656530250925613, 16.78615500941177, 16.91478643081254, 17.04244700739891, 17.169158395215533, 17.294941456969436, 17.41981630213132, 17.54380232446775, 17.666918237202548, 17.789182105987898, 17.910611379849655, 18.031222920256962, 18.15103302845323, 18.270057471173978, 18.388311504866348, 18.505809898515654, 18.62256695517565, 18.738596532291314, 18.85391206089601, 18.968526563758186, 19.082452672547102, 19.195702644081567, 19.30828837572093, 19.420221419952966, 19.5315129982293, 19.642174014095282, 19.752215065657825, 19.861646457431473, 19.970478211600245, 20.078720078730118, 20.186381547964462, 20.293471856732648, 20.4, 20.505974739085193, 20.61140461006964, 20.7162979318217, 20.820662813657016, 20.924507162654994], [0.0, 2.248888614404902, 3.18040877875785, 3.8951893407124643, 4.497777228809804, 5.028667815634674, 5.508629593646681, 5.95, 6.3608175575157, 6.746665843214706, 7.111610225539643, 7.458719729283304, 7.7903786814249285, 8.108483212044039, 8.414570696119915, 8.709908151065658, 8.995554457619608, 9.272405297440358, 9.541226336273551, 9.802678205470178, 10.057335631269348, 10.30570230503482, 10.54822259909223, 10.785290909382093, 11.017259187293362, 11.244443072024511, 11.467126928747236, 11.685568022137394, 11.9, 12.110635821458757, 12.317670234261023, 12.521281883257801, 12.7216351150314, 12.918881530535065, 13.113161327460286, 13.304604466123749, 13.493331686429412, 13.67945539851642, 13.863080465755079, 14.044304895579561, 14.223220451079285, 14.399913194182805, 14.574463969559913, 14.74694883696285, 14.917439458566609, 15.086003446904021, 15.252704678187408, 15.417603575134496, 15.580757362849857, 15.742220300834315, 15.90204389378925, 16.06027708353751, 16.216966424088078, 16.372156241619493, 16.525888780940043, 16.678204339796295, 16.82914139223983, 16.978736702122454, 17.127025427668404, 17.27404121796634, 17.419816302131316, 17.564381571806052, 17.70776665759971, 17.85, 17.991108915239217, 18.131119656546307, 18.270057471173978, 18.40794665355156, 18.544810594880715, 18.680671829460525, 18.815552078001858, 18.94947228816676, 19.082452672547102, 19.214512744277435, 19.34567135045977, 19.47594670356232, 19.605356410940356, 19.73391750261463, 19.86164645743147, 19.98855922771824, 20.114671262538696, 20.239997529644118, 20.3645525362086, 20.488350348429712, 20.61140461006964, 20.733728560005797, 20.855335048855007, 20.976236554730214, 21.09644519818446, 21.215972756392762, 21.334830676618928, 21.45303008901074, 21.570581818764186, 21.687496397694225, 21.803784075247123, 21.919454828986964, 22.034518374586725, 22.148984175352155, 22.262861451304953, 22.376159187849915, 22.488886144049022, 22.60105086052417], [0.0, 2.4041630560342617, 3.4, 4.164132562731403, 4.8083261120685235, 5.375872022286245, 5.888972745734183, 6.360817557515701, 6.8, 7.212489168102785, 7.602631123499285, 7.97370679169983, 8.328265125462806, 8.668333173107735, 8.995554457619606, 9.311283477587823, 9.616652224137047, 9.912618221237011, 10.2, 10.47950380504726, 10.75174404457249, 11.017259187293362, 11.27652428720836, 11.529960971312956, 11.777945491468365, 12.020815280171307, 12.258874336577565, 12.49239768819421, 12.721635115031402, 12.946814279968645, 13.168143377105217, 13.385813385820079, 13.6, 13.810865287881134, 14.018559127100046, 14.223220451079284, 14.42497833620557, 14.623952953972466, 14.820256408038292, 15.01399347275734, 15.20526224699857, 15.39415473483361, 15.580757362849859, 15.765151442342693, 15.94741358339966, 16.127616066858735, 16.305827179263247, 16.482111515215518, 16.656530250925613, 16.82914139223983, 17.0, 17.169158395215533, 17.33666634621547, 17.502571239677902, 17.666918237202548, 17.829750418892576, 17.991108915239213, 18.151033028453227, 18.309560344257314, 18.466726835040365, 18.622566955175646, 18.777113729218343, 18.93039883362207, 19.082452672547102, 19.233304448274094, 19.382982226685343, 19.5315129982293, 19.678922734743384, 19.825236442474022, 19.970478211600245, 20.114671262538696, 20.257837989282073, 20.4, 20.541178155110774, 20.681392603013943, 20.820662813657012, 20.95900761009452, 21.09644519818446, 21.232993194554556, 21.368668652960107, 21.50348808914498, 21.637467504308354, 21.770622407271688, 21.90296783543271, 22.034518374586725, 22.165288177689007, 22.295290982626803, 22.424540129063963, 22.55304857441672, 22.680828909014764, 22.807893370497855, 22.934253857494472, 23.059921942625913, 23.184908884875956, 23.30922564136355, 23.432882878553375, 23.55589098293673, 23.678260071213003, 23.8, 23.92112037509949, 24.041630560342615, 24.161539686038225], [0.0, 2.55, 3.6062445840513924, 4.416729559300637, 5.1, 5.701973342624464, 6.246198844097104, 6.746665843214706, 7.212489168102785, 7.65, 8.063808033429368, 8.457393215406269, 8.833459118601274, 9.194155752433172, 9.54122633627355, 9.876107532828913, 10.2, 10.513919345325034, 10.818733752154177, 11.115192306028717, 11.403946685248927, 11.685568022137392, 11.960560187549746, 12.229370384447435, 12.492397688194208, 12.75, 13.002499759661601, 13.250188677901912, 13.493331686429412, 13.732170258192987, 13.966925216381735, 14.197799125216557, 14.42497833620557, 14.648634748671975, 14.868927331855517, 15.086003446904021, 15.3, 15.51104445226046, 15.719255707570891, 15.924744895915916, 16.127616066858735, 16.327966805453766, 16.525888780940047, 16.7214682369701, 16.914786430812537, 17.105920027873392, 17.294941456969436, 17.481919231022662, 17.666918237202548, 17.85, 18.031222920256962, 18.21064249278427, 18.388311504866344, 18.564280217665324, 18.73859653229131, 18.911306142093938, 19.0824526725471, 19.25207780994041, 19.420221419952966, 19.58692165706495, 19.752215065657825, 19.91613667356197, 20.078720078730115, 20.239997529644118, 20.4, 20.558757258161297, 20.7162979318217, 20.87264956827475, 21.027838690650068, 21.181890850441093, 21.334830676618928, 21.486681921599715, 21.637467504308354, 21.787209550559705, 21.935929430958694, 22.083647796503186, 22.230384612057435, 22.37615918784991, 22.52099020913601, 22.66489576415475, 22.807893370497855, 22.95, 23.091232102250412, 23.23160562681796, 23.371136044274785, 23.50983836609686, 23.647727163514045, 23.78481658537648, 23.92112037509949, 24.056651886744337, 24.191424100288103, 24.325449636132117, 24.45874076889487, 24.591309440532036, 24.72316727282328, 24.854325579262856, 24.984795376388416, 25.11458739458007, 25.243712088359747, 25.37217964621881, 25.5, 25.627182833858274], [0.0, 2.6879360111431225, 3.8013155617496426, 4.655641738793912, 5.375872022286245, 6.0104076400856545, 6.5840716885526085, 7.111610225539643, 7.602631123499285, 8.063808033429368, 8.5, 8.914875209446288, 9.311283477587825, 9.691491113342673, 10.057335631269346, 10.410331406828506, 10.75174404457249, 11.082644088844503, 11.403946685248927, 11.71644143927669, 12.020815280171309, 12.317670234261023, 12.607537428062628, 12.890888254887637, 13.168143377105217, 13.439680055715613, 13.705838172107535, 13.966925216381737, 14.223220451079285, 14.474978411037442, 14.722431864335457, 14.965794332410159, 15.20526224699857, 15.44101680589721, 15.67322557739791, 15.902043893789251, 16.127616066858735, 16.350076452420645, 16.56955038617524, 16.786155009411775, 17.0, 17.2111882216191, 17.41981630213132, 17.62597515032856, 17.829750418892576, 18.031222920256962, 18.230469001098136, 18.42756088037698, 18.62256695517565, 18.815552078001858, 19.00657780874821, 19.195702644081567, 19.382982226685346, 19.56846953647628, 19.752215065657825, 19.934266979249575, 20.114671262538693, 20.293471856732648, 20.470710783946902, 20.6464282625349, 20.820662813657012, 20.993451359888397, 21.164829316580843, 21.334830676618928, 21.50348808914498, 21.670832932769333, 21.83689538373072, 22.001704479426134, 22.165288177689007, 22.327673412158287, 22.488886144049022, 22.648951410606188, 22.807893370497855, 22.965735346380704, 23.12249986485025, 23.27820869396956, 23.43288287855338, 23.586542773369736, 23.739208074407202, 23.890897848343833, 24.041630560342618, 24.191424100288103, 24.340295807569802, 24.488262494509485, 24.635340468522045, 24.781545553092528, 24.926893107645807, 25.071398046379464, 25.215074856125256, 25.357937613299704, 25.5, 25.641275319297208, 25.781776509775273, 25.921516159360742, 26.060506518485017, 26.19875951261815, 26.336286754210434, 26.473099554075645, 26.609208932247498, 26.744625628338866, 26.879360111431225, 27.0134225895202], [0.0, 2.81913107180209, 3.9868533958499155, 4.882878249557325, 5.63826214360418, 6.303768714031315, 6.905432643940567, 7.458719729283305, 7.973706791699831, 8.45739321540627, 8.914875209446288, 9.350000000000001, 9.76575649911465, 10.16452163163619, 10.548222599092227, 10.91844769186536, 11.27652428720836, 11.623575181500744, 11.960560187549746, 12.288307450580819, 12.60753742806263, 12.918881530535065, 13.222896808188441, 13.520077662498839, 13.810865287881134, 14.09565535901045, 14.374804346494601, 14.648634748671975, 14.91743945856661, 15.18148543456799, 15.441016805897208, 15.696257515726481, 15.947413583399662, 16.194675050769007, 16.43821766494166, 16.6782043397963, 16.91478643081254, 17.148104851557214, 17.378291055221744, 17.605467900626785, 17.829750418892576, 18.051246494356008, 18.27005747117398, 18.486278695291812, 18.700000000000003, 18.91130614209394, 19.12027719464339, 19.326988901533525, 19.5315129982293, 19.73391750261463, 19.934266979249575, 20.132622779955923, 20.32904326327238, 20.523583995004387, 20.7162979318217, 20.907235589623035, 21.096445198184455, 21.28397284343316, 21.469862598535652, 21.654156644856894, 21.83689538373072, 22.018117539880652, 22.19786025724101, 22.376159187849915, 22.55304857441672, 22.72856132710559, 22.902729095022718, 23.075582332846988, 23.247150363001488, 23.41746143372505, 23.58654277336974, 23.754420641219607, 23.92112037509949, 24.086666436018085, 24.25108245006808, 24.414391247786625, 24.576614901161637, 24.737774758453927, 24.89789147699058, 25.05698505407225, 25.21507485612526, 25.37217964621881, 25.528317610058057, 25.683506380554817, 25.83776306107013, 25.991104247415116, 26.14354604869049, 26.295104107038636, 26.445793616376882, 26.595629340175428, 26.744625628338866, 26.89279643324584, 27.040155324997677, 27.18671550592311, 27.332489824383, 27.477490787915844, 27.621730575762268, 27.76522105080383, 27.907973770949408, 28.050000000000004, 28.1913107180209, 28.331916631248237], [0.0, 2.944486372867092, 4.164132562731403, 5.100000000000001, 5.888972745734184, 6.58407168855261, 7.212489168102786, 7.790378681424929, 8.328265125462806, 8.833459118601276, 9.311283477587825, 9.76575649911465, 10.200000000000003, 10.616496597277278, 11.017259187293362, 11.403946685248929, 11.777945491468367, 12.140428328522848, 12.49239768819421, 12.834718539960278, 13.16814337710522, 13.493331686429414, 13.810865287881136, 14.12126056696073, 14.424978336205571, 14.722431864335459, 15.013993472757342, 15.300000000000004, 15.580757362849859, 15.856544390250988, 16.127616066858735, 16.394206293688026, 16.656530250925613, 16.914786430812544, 17.169158395215536, 17.41981630213132, 17.66691823720255, 17.91061137984966, 18.151033028453234, 18.388311504866348, 18.62256695517565, 18.85391206089601, 19.082452672547106, 19.30828837572093, 19.5315129982293, 19.75221506565783, 19.97047821160025, 20.186381547964462, 20.400000000000006, 20.611404610069645, 20.820662813657016, 21.027838690650075, 21.232993194554556, 21.43618436196144, 21.637467504308358, 21.83689538373072, 22.034518374586725, 22.23038461205744, 22.424540129063967, 22.61702898260512, 22.807893370497858, 22.997173739396764, 23.184908884875956, 23.371136044274788, 23.555890982936734, 23.739208074407202, 23.921120375099495, 24.10165969388831, 24.280856657045696, 24.458740768894874, 24.635340468522053, 24.810683182854923, 24.98479537638842, 25.157702597812865, 25.32942952377728, 25.500000000000004, 25.669437079920556, 25.837763061070135, 26.004999519323206, 26.171167341179114, 26.33628675421044, 26.500377355803828, 26.663458140308812, 26.82554752470115, 26.98666337285883, 27.146823018541234, 27.306043287155322, 27.464340516385974, 27.62173057576227, 27.77822888522593, 27.933850432763474, 28.088609791159126, 28.24252113392146, 28.395598250433117, 28.547854560369334, 28.699303127428028, 28.849956672411142, 28.999827585694373, 29.148927939119822, 29.29726949734395, 29.444863728670917, 29.591721815399666], [0.0, 3.064718584144391, 4.334166586553867, 5.308248298638639, 6.129437168288782, 6.8529190860537685, 7.50699673637867, 8.108483212044039, 8.668333173107735, 9.194155752433174, 9.691491113342673, 10.16452163163619, 10.616496597277278, 11.05, 11.467126928747234, 11.8696040372036, 12.258874336577565, 12.63615843522073, 13.002499759661601, 13.358798598676456, 13.705838172107537, 14.044304895579561, 14.3748043464946, 14.697873995921997, 15.01399347275734, 15.323592920721955, 15.627059864222701, 15.924744895915918, 16.216966424088078, 16.504014663105462, 16.786155009411775, 17.063630914902024, 17.33666634621547, 17.605467900626785, 17.870226635384345, 18.13111965654631, 18.388311504866348, 18.641955369542114, 18.89219415525894, 19.139161423636097, 19.382982226685346, 19.623773847045836, 19.861646457431473, 20.09670370981271, 20.32904326327238, 20.558757258161304, 20.785932743083727, 21.01065206032407, 21.232993194554556, 21.45303008901074, 21.670832932769336, 21.88646842229235, 22.1, 22.311488072291375, 22.52099020913601, 22.728561327105595, 22.93425385749447, 23.13811790098754, 23.34020137016817, 23.54055012101459, 23.7392080744072, 23.93621732855883, 24.131618263183263, 24.325449636132117, 24.51774867315513, 24.708551151372674, 24.89789147699058, 25.0858027577353, 25.27231687044146, 25.457464524182296, 25.64127531929721, 25.823777802637633, 26.004999519323203, 26.18496706127392, 26.363706112760397, 26.541241493193194, 26.717597197352912, 26.89279643324584, 27.06686165775412, 27.239814610235513, 27.411676344215074, 27.58246725729952, 27.75220711943467, 27.920915099616632, 28.088609791159122, 28.255309235610927, 28.42103094541083, 28.585791925360404, 28.7496086929892, 28.912497297881412, 29.07447334002802, 29.23555198726373, 29.395747991843994, 29.55507570621331, 29.71354909801251, 29.871181764369485, 30.02798694551468, 30.18397753776, 30.339166105877073, 30.49356489490857, 30.64718584144391, 30.800040584388853], [0.0, 3.18040877875785, 4.497777228809804, 5.508629593646682, 6.3608175575157, 7.111610225539643, 7.790378681424928, 8.414570696119917, 8.995554457619608, 9.541226336273551, 10.057335631269346, 10.548222599092227, 11.017259187293364, 11.467126928747236, 11.899999999999999, 12.317670234261021, 12.7216351150314, 13.113161327460286, 13.493331686429412, 13.863080465755077, 14.223220451079285, 14.57446396955991, 14.917439458566609, 15.252704678187408, 15.580757362849855, 15.902043893789251, 16.216966424088078, 16.525888780940043, 16.829141392239833, 17.127025427668404, 17.419816302131316, 17.70776665759971, 17.991108915239217, 18.270057471173978, 18.544810594880715, 18.815552078001858, 19.082452672547102, 19.345671350459774, 19.605356410940356, 19.86164645743147, 20.114671262538693, 20.3645525362086, 20.61140461006964, 20.855335048855004, 21.096445198184455, 21.334830676618925, 21.570581818764186, 21.803784075247123, 22.034518374586728, 22.26286145130495, 22.48888614404902, 22.71266166700856, 22.934253857494472, 23.153725402189604, 23.37113604427478, 23.586542773369732, 23.799999999999997, 24.01155971610341, 24.22127164291751, 24.42918336743985, 24.635340468522042, 24.839786633544175, 25.042563766515595, 25.243712088359747, 25.4432702300628, 25.6412753192972, 25.837763061070127, 26.03276781289304, 26.226322654920573, 26.41845945546409, 26.6092089322475, 26.798600709738558, 26.986663372858825, 27.17342451734783, 27.358910797032834, 27.543147968233406, 27.726160931510154, 27.907973770949408, 28.088609791159122, 28.26809155213701, 28.44644090215857, 28.623679008820652, 28.79982638836561, 28.974902933400827, 29.14892793911982, 29.321920128122578, 29.4938976739257, 29.66487822324575, 29.834878917133217, 30.00391641102874, 30.172006893808042, 30.339166105877073, 30.505409356374816, 30.670751539536816, 30.835207150268992, 30.998790298977795, 31.16151472569971, 31.323393813570075, 31.484440601668627, 31.644667797276686, 31.804087787578503, 31.962712650837386], [0.0, 3.2920358442763042, 4.6556417387939115, 5.701973342624464, 6.5840716885526085, 7.361215932167728, 8.063808033429366, 8.709908151065658, 9.311283477587823, 9.876107532828913, 10.410331406828506, 10.918447691865358, 11.403946685248927, 11.8696040372036, 12.317670234261021, 12.749999999999998, 13.168143377105217, 13.573411509270615, 13.966925216381734, 14.349651563714012, 14.722431864335457, 15.08600344690402, 15.441016805897208, 15.788049277855704, 16.12761606685873, 16.46017922138152, 16.786155009411775, 17.105920027873392, 17.419816302131316, 17.72815557242208, 18.03122292025696, 18.32927985492065, 18.622566955175646, 18.91130614209394, 19.195702644081564, 19.475946703562318, 19.752215065657825, 20.02467228196257, 20.293471856732648, 20.5587572581613, 20.820662813657012, 21.079314504983316, 21.334830676618928, 21.587322668640496, 21.836895383730717, 22.083647796503183, 22.327673412158287, 22.56906068049798, 22.807893370497855, 23.044250909934128, 23.278208693969557, 23.50983836609686, 23.7392080744072, 23.966382705781868, 24.1914241002881, 24.414391247786618, 24.635340468522042, 24.854325579262856, 25.07139804637946, 25.286607127093973, 25.499999999999996, 25.71162188583209, 25.921516159360735, 26.129724453196975, 26.336286754210434, 26.541241493193187, 26.744625628338863, 26.946474723050507, 27.14682301854123, 27.3457035016472, 27.543147968233406, 27.73918708253722, 27.933850432763467, 28.127166583216304, 28.319163123228055, 28.509866713122317, 28.699303127428024, 28.88749729554293, 29.074473340028018, 29.260254612699455, 29.444863728670914, 29.628322598486736, 29.81065245847531, 29.99187389944149, 30.17200689380804, 30.35107082130711, 30.529084493315548, 30.706066175920352, 30.882033611794416, 31.05700404095668, 31.230994220485517, 31.40402044324898, 31.576098555711408, 31.747243974871267, 31.917471704381597, 32.08679634990068, 32.25523213371746, 32.422792908693104, 32.58949217155738, 32.75534307559608, 32.92035844276304, 33.08455077524856], [0.0, 3.4000000000000004, 4.8083261120685235, 5.888972745734184, 6.800000000000001, 7.602631123499286, 8.328265125462805, 8.995554457619608, 9.616652224137047, 10.200000000000001, 10.75174404457249, 11.27652428720836, 11.777945491468367, 12.258874336577565, 12.7216351150314, 13.168143377105217, 13.600000000000001, 14.018559127100048, 14.42497833620557, 14.820256408038292, 15.205262246998572, 15.580757362849857, 15.947413583399662, 16.305827179263247, 16.65653025092561, 17.0, 17.33666634621547, 17.66691823720255, 17.991108915239217, 18.309560344257317, 18.62256695517565, 18.930398833622075, 19.233304448274094, 19.5315129982293, 19.825236442474022, 20.114671262538696, 20.400000000000002, 20.68139260301395, 20.959007610094524, 21.232993194554556, 21.50348808914498, 21.770622407271688, 22.034518374586728, 22.2952909826268, 22.55304857441672, 22.807893370497855, 23.059921942625916, 23.30922564136355, 23.555890982936734, 23.8, 24.041630560342615, 24.280856657045693, 24.51774867315513, 24.75237362355377, 24.984795376388416, 25.215074856125252, 25.4432702300628, 25.66943707992055, 25.893628559937287, 26.115895542753265, 26.336286754210434, 26.554848898082625, 26.771626771640154, 26.98666337285883, 27.200000000000003, 27.411676344215067, 27.621730575762268, 27.83019942436633, 28.037118254200095, 28.242521133921457, 28.44644090215857, 28.64890922879962, 28.84995667241114, 29.04961273407961, 29.24790590794493, 29.444863728670914, 29.640512816076583, 29.834878917133217, 30.027986945514684, 30.219861018873004, 30.410524493997144, 30.6, 30.78830946966722, 30.975474169090614, 31.161514725699714, 31.34645115479582, 31.530302884685394, 31.713088780501973, 31.894827166799324, 32.07553584899245, 32.25523213371747, 32.433932848176156, 32.61165435852649, 32.78841258737605, 32.964223030431036, 33.139100772350474, 33.31306050185122, 33.48611652610676, 33.65828278447967, 33.82957286162508, 34.0, 34.16957711181103], [0.0, 3.5046397817750115, 4.9563091106185055, 6.070214164261423, 7.009279563550023, 7.836612788698955, 8.584579197607766, 9.272405297440358, 9.912618221237011, 10.513919345325034, 11.082644088844503, 11.623575181500742, 12.140428328522846, 12.63615843522073, 13.113161327460285, 13.573411509270615, 14.018559127100046, 14.450000000000001, 14.868927331855517, 15.276370642269715, 15.67322557739791, 16.060277083537507, 16.43821766494166, 16.807661943292413, 17.169158395215533, 17.52319890887506, 17.870226635384345, 18.21064249278427, 18.544810594880715, 18.873062814498343, 19.195702644081564, 19.513008481523293, 19.825236442474022, 20.132622779955923, 20.435385976291226, 20.733728560005797, 21.027838690650068, 21.31789154677357, 21.604050546136023, 21.886468422292346, 22.165288177689007, 22.44064393015495, 22.71266166700856, 22.981459918812813, 23.247150363001484, 23.50983836609686, 23.76962347198626, 24.02659984267437, 24.280856657045693, 24.53247847242508, 24.781545553092524, 25.02813416937028, 25.27231687044146, 25.514162733666183, 25.7537375928233, 25.991104247415112, 26.22632265492057, 26.459450107664747, 26.69054139578289, 26.919648957592294, 27.14682301854123, 27.372111719777852, 27.595561237271472, 27.817215892321073, 28.03711825420009, 28.25530923561092, 28.471828181555185, 28.68671295216655, 28.900000000000002, 29.111724442224308, 29.32192012812258, 29.530619702268357, 29.737854663711033, 29.943655421474514, 30.148051346645936, 30.351070821307115, 30.55274128453943, 30.753089275713428, 30.952140475256314, 31.14991974307478, 31.34645115479582, 31.541758035975104, 31.7358629944106, 31.928787950688008, 32.120554167075014, 32.31118227487196, 32.500692300318775, 32.689103689149995, 32.87643532988332, 33.062705575920425, 33.24793226653351, 33.43213274680513, 33.615323886584825, 33.79752209852077, 33.97874335522137, 34.1590032055972, 34.338316790431065, 34.51669885721982, 34.69416377432954, 34.87072554450223, 35.04639781775012, 35.22119390367113], [0.0, 3.6062445840513924, 5.1000000000000005, 6.246198844097105, 7.212489168102785, 8.063808033429368, 8.833459118601274, 9.541226336273551, 10.200000000000001, 10.818733752154177, 11.403946685248927, 11.960560187549746, 12.49239768819421, 13.002499759661601, 13.49333168642941, 13.966925216381735, 14.42497833620557, 14.868927331855517, 15.3, 15.719255707570891, 16.127616066858735, 16.525888780940043, 16.91478643081254, 17.294941456969436, 17.666918237202548, 18.031222920256962, 18.388311504866348, 18.738596532291314, 19.082452672547102, 19.42022141995297, 19.752215065657825, 20.078720078730118, 20.400000000000002, 20.716297931821703, 21.02783869065007, 21.334830676618928, 21.637467504308354, 21.9359294309587, 22.23038461205744, 22.520990209136013, 22.807893370497855, 23.091232102250412, 23.371136044274788, 23.64772716351404, 23.92112037509949, 24.191424100288103, 24.458740768894874, 24.72316727282328, 24.98479537638842, 25.243712088359747, 25.5, 25.753737592823303, 26.004999519323203, 26.253856859516855, 26.50037735580382, 26.744625628338863, 26.98666337285882, 27.226549542679845, 27.46434051638597, 27.700090252560546, 27.93385043276347, 28.165670593827514, 28.39559825043311, 28.623679008820655, 28.84995667241114, 29.074473340028014, 29.297269497343947, 29.518384102115075, 29.737854663711033, 29.955717317400367, 30.172006893808046, 30.386756983923114, 30.6, 30.81176723266616, 31.022088904520917, 31.23099422048552, 31.438511415141782, 31.64466779727669, 31.849489791831832, 32.053002979440166, 32.25523213371747, 32.456201256462535, 32.65593361090753, 32.854451753149064, 33.05177756188009, 33.24793226653351, 33.44293647394021, 33.63681019359594, 33.82957286162508, 34.021243363522146, 34.211840055746784, 34.40138078624171, 34.58988291393887, 34.777363327313935, 34.963838462045324, 35.149324317830065, 35.333836474405096, 35.517390106819505, 35.7, 35.88168056264924, 36.062445840513924, 36.24230952905734], [0.0, 3.705064102009573, 5.239751902523631, 6.417359269980139, 7.410128204019146, 8.28477519308762, 9.075516514226615, 9.802678205470178, 10.479503805047262, 11.11519230602872, 11.71644143927669, 12.288307450580819, 12.834718539960278, 13.358798598676456, 13.863080465755077, 14.349651563714014, 14.820256408038292, 15.276370642269717, 15.719255707570891, 16.150000000000002, 16.56955038617524, 16.978736702122454, 17.378291055221744, 17.768863216311843, 18.15103302845323, 18.525320510047866, 18.89219415525894, 19.252077809940417, 19.605356410940356, 19.952380810319358, 20.293471856732648, 20.628923869169718, 20.959007610094524, 21.28397284343316, 21.604050546136023, 21.919454828986968, 22.23038461205744, 22.537025092056854, 22.83954903232549, 23.13811790098754, 23.43288287855338, 23.72398575281987, 24.011559716103413, 24.295730077525967, 24.576614901161637, 24.85432557926286, 25.128967348460627, 25.400639755722693, 25.669437079920556, 25.93544871406701, 26.198759512618153, 26.459450107664754, 26.717597197352912, 26.97327380945814, 27.226549542679845, 27.477490787915844, 27.726160931510154, 27.972620542237372, 28.21692754358632, 28.45913737273145, 28.699303127428028, 28.937475701933646, 29.173703912941875, 29.408034616410536, 29.640512816076583, 29.871181764369485, 30.100083056363818, 30.32725671734917, 30.552741284539433, 30.776573883393848, 30.998790298977806, 31.219425042751833, 31.438511415141782, 31.656081564211327, 31.872166540729545, 32.08679634990069, 32.300000000000004, 32.51180554813898, 32.722240143364274, 32.931330067277884, 33.13910077235048, 33.34557691808616, 33.550782405183945, 33.75474040783013, 33.95747340424491, 34.15900320559721, 34.359350983393156, 34.558537295435414, 34.75658211044349, 34.95350483141855, 35.14932431783007, 35.34405890669605, 35.537726432623685, 35.7303442468723, 35.92192923549625, 36.11249783662161, 36.30206605690646, 36.490649487231664, 36.67826331766541, 36.86492235174246, 37.05064102009573, 37.23543339347618], [0.0, 3.801315561749643, 5.375872022286245, 6.584071688552609, 7.602631123499286, 8.500000000000002, 9.311283477587825, 10.057335631269348, 10.75174404457249, 11.403946685248929, 12.020815280171309, 12.607537428062628, 13.168143377105219, 13.705838172107535, 14.223220451079284, 14.722431864335457, 15.205262246998572, 15.673225577397911, 16.127616066858735, 16.56955038617524, 17.000000000000004, 17.41981630213132, 17.82975041889258, 18.230469001098136, 18.62256695517565, 19.006577808748215, 19.38298222668535, 19.75221506565783, 20.114671262538696, 20.470710783946906, 20.820662813657016, 21.16482931658085, 21.50348808914498, 21.836895383730724, 22.165288177689007, 22.488886144049022, 22.807893370497858, 23.12249986485026, 23.432882878553382, 23.739208074407202, 24.041630560342618, 24.340295807569802, 24.635340468522053, 24.926893107645807, 25.215074856125256, 25.5, 25.781776509775277, 26.060506518485017, 26.336286754210438, 26.6092089322475, 26.879360111431225, 27.146823018541234, 27.41167634421507, 27.67399501336951, 27.933850432763474, 28.1913107180209, 28.446440902158567, 28.699303127428028, 28.949956822074885, 29.198458863440035, 29.444863728670914, 29.68922363417407, 29.931588664820314, 30.172006893808046, 30.410524493997144, 30.647185841443907, 30.88203361179442, 31.11510887012932, 31.346451154795822, 31.57609855571141, 31.804087787578506, 32.03045425840852, 32.25523213371747, 32.47845439672276, 32.70015290484128, 32.920358442763046, 33.13910077235048, 33.3564086795926, 33.57231001882355, 33.786831754398044, 34.00000000000001, 34.211840055746784, 34.4223764432382, 34.631632938687716, 34.83963260426264, 35.04639781775012, 35.25195030065713, 35.45631114484416, 35.65950083778516, 35.861539286539276, 36.062445840513924, 36.26223931309263, 36.46093800219627, 36.658559709841306, 36.85512176075396, 37.050641020095725, 37.2451339103513, 37.438616427426915, 37.631104156003715, 37.82261228418788, 38.01315561749643, 38.2027485922152], [0.0, 3.8951893407124643, 5.508629593646682, 6.746665843214707, 7.7903786814249285, 8.70990815106566, 9.541226336273551, 10.30570230503482, 11.017259187293364, 11.685568022137392, 12.317670234261023, 12.918881530535065, 13.493331686429414, 14.044304895579561, 14.57446396955991, 15.086003446904021, 15.580757362849857, 16.060277083537507, 16.525888780940043, 16.978736702122454, 17.41981630213132, 17.85, 18.270057471173978, 18.680671829460525, 19.082452672547102, 19.47594670356232, 19.861646457431473, 20.23999752964412, 20.61140461006964, 20.976236554730214, 21.334830676618928, 21.68749639769423, 22.034518374586728, 22.376159187849915, 22.71266166700856, 23.04425090993413, 23.371136044274785, 23.693511770102806, 24.011559716103413, 24.325449636132117, 24.635340468522045, 24.94138127690606, 25.243712088359754, 25.54246464223842, 25.83776306107013, 26.129724453196978, 26.418459455464095, 26.704072723088515, 26.98666337285883, 27.26632538498725, 27.543147968233406, 27.817215892321077, 28.088609791159122, 28.357406439940878, 28.623679008820652, 28.88749729554293, 29.14892793911982, 29.408034616410532, 29.664878223245754, 29.91951704155667, 30.172006893808042, 30.422401285894576, 30.670751539536816, 30.917106915104466, 31.161514725699714, 31.40402044324898, 31.644667797276686, 31.88349886696879, 32.120554167075014, 32.35587272814628, 32.58949217155739, 32.8214487797233, 33.05177756188009, 33.28051231576822, 33.50768568552594, 33.733329216073535, 33.95747340424491, 34.18014774690128, 34.40138078624171, 34.62120015250771, 34.83963260426264, 35.05670406641218, 35.272439666118935, 35.486863766751775, 35.7, 35.91187129627194, 36.122499913488824, 36.33190746437627, 36.540114942347955, 36.747142746069386, 36.95301070278307, 37.157738090470474, 37.36134365892105, 37.563845649773405, 37.765261815589206, 37.9656094380164, 38.164905345094205, 38.36316592774898, 38.56040715552677, 38.756644591605195, 38.95189340712464, 39.146168394876156], [0.0, 3.9868533958499155, 5.63826214360418, 6.905432643940567, 7.973706791699831, 8.91487520944629, 9.765756499114648, 10.54822259909223, 11.27652428720836, 11.960560187549746, 12.607537428062628, 13.22289680818844, 13.810865287881134, 14.3748043464946, 14.917439458566607, 15.441016805897206, 15.947413583399662, 16.43821766494166, 16.91478643081254, 17.378291055221744, 17.82975041889258, 18.270057471173978, 18.700000000000003, 19.12027719464339, 19.531512998229296, 19.93426697924958, 20.32904326327238, 20.716297931821703, 21.09644519818446, 21.469862598535652, 21.83689538373072, 22.197860257241015, 22.55304857441672, 22.902729095022718, 23.247150363001484, 23.586542773369736, 23.92112037509949, 24.251082450068083, 24.576614901161637, 24.89789147699058, 25.215074856125256, 25.528317610058053, 25.837763061070135, 26.143546048690485, 26.44579361637688, 26.744625628338866, 27.040155324997677, 27.332489824382996, 27.621730575762268, 27.907973770949408, 28.191310718020897, 28.47182818155519, 28.7496086929892, 29.02473083423859, 29.297269497343947, 29.567296122574348, 29.834878917133214, 30.100083056363815, 30.362970869135978, 30.623602008908094, 30.882033611794412, 31.138320442824146, 31.392515031452955, 31.64466779727669, 31.894827166799324, 32.14303968202136, 32.38935010153801, 32.633801494769195, 32.87643532988332, 33.11729155592287, 33.3564086795926, 33.593823837128156, 33.82957286162508, 34.063690346173594, 34.29620970311442, 34.527163219702835, 34.75658211044349, 34.984496566336354, 35.21093580125357, 35.43592809564891, 35.65950083778516, 35.88168056264924, 36.102492988712015, 36.321963052676544, 36.540114942347955, 36.75697212774741, 36.97255739058363, 37.18689285218651, 37.400000000000006, 37.6118997127239, 37.82261228418788, 38.032157446035065, 38.24055438928678, 38.447821784855385, 38.65397780306705, 38.85904013225237, 39.06302599645859, 39.26595217233373, 39.46783500522926, 39.66869042456532, 39.86853395849916, 40.067380747935104], [0.0, 4.076456794815812, 5.764980485656478, 7.060630283480365, 8.152913589631623, 9.115234500549068, 9.98523910580012, 10.785290909382095, 11.529960971312956, 12.229370384447437, 12.890888254887637, 13.520077662498837, 14.12126056696073, 14.697873995921997, 15.252704678187406, 15.788049277855704, 16.305827179263247, 16.807661943292413, 17.294941456969436, 17.768863216311843, 18.230469001098136, 18.680671829460525, 19.12027719464339, 19.550000000000004, 19.97047821160024, 20.382283974079062, 20.785932743083727, 21.181890850441093, 21.57058181876419, 21.95239166924643, 22.327673412158287, 22.696750868791774, 23.059921942625913, 23.41746143372505, 23.76962347198626, 24.116643630488884, 24.458740768894874, 24.7961186478852, 25.128967348460627, 25.457464524182296, 25.781776509775273, 26.10205930573295, 26.418459455464095, 26.73111482897786, 27.040155324997674, 27.345703501647204, 27.647875144394014, 27.94677977871512, 28.24252113392146, 28.535197563710685, 28.82490242828239, 29.11172444222431, 29.395747991843994, 29.67705342516336, 29.955717317400364, 30.231812714423857, 30.505409356374813, 30.776573883393848, 31.04537002517445, 31.311858775869567, 31.576098555711408, 31.83814536055767, 32.09805290044865, 32.35587272814628, 32.61165435852649, 32.86544537960805, 33.11729155592287, 33.36723692486389, 33.615323886584825, 33.86159328797156, 34.106084501156104, 34.34883549700048, 34.58988291393887, 34.8292621225314, 35.067007286051656, 35.30315141740182, 35.537726432623685, 35.77076320125139, 36.00229159373053, 36.2323405261101, 36.46093800219627, 36.688111153342305, 36.9138862760344, 37.13828886742091, 37.36134365892105, 37.58307464803805, 37.80350512849305, 38.022657718786576, 38.24055438928678, 38.45721648793631, 38.67266476466291, 38.88691939457278, 39.10000000000001, 39.31192567148041, 39.52271498771308, 39.73238603456883, 39.94095642320048, 40.14844330730646, 40.35486339959535, 40.56023298749651, 40.764567948158124, 40.96788376277204], [0.0, 4.164132562731403, 5.888972745734183, 7.212489168102786, 8.328265125462806, 9.311283477587825, 10.2, 11.017259187293364, 11.777945491468365, 12.49239768819421, 13.168143377105217, 13.810865287881134, 14.424978336205571, 15.01399347275734, 15.580757362849855, 16.127616066858735, 16.656530250925613, 17.169158395215533, 17.666918237202548, 18.15103302845323, 18.62256695517565, 19.082452672547102, 19.5315129982293, 19.970478211600245, 20.4, 20.820662813657016, 21.232993194554556, 21.637467504308358, 22.034518374586728, 22.424540129063967, 22.807893370497855, 23.184908884875956, 23.55589098293673, 23.921120375099495, 24.280856657045693, 24.63534046852205, 24.98479537638842, 25.329429523777282, 25.669437079920552, 26.004999519323206, 26.336286754210434, 26.66345814030881, 26.98666337285883, 27.306043287155315, 27.621730575762268, 27.933850432763474, 28.242521133921457, 28.547854560369334, 28.849956672411142, 29.148927939119822, 29.444863728670914, 29.737854663711037, 30.02798694551468, 30.31534265021592, 30.6, 30.882033611794416, 31.16151472569971, 31.438511415141782, 31.713088780501973, 31.985309127785523, 32.25523213371747, 32.522914998505286, 32.788412587376044, 33.051777561880094, 33.313060501851226, 33.57231001882354, 33.82957286162508, 34.08489401479782, 34.338316790431065, 34.58988291393887, 34.83963260426264, 35.0876046489355, 35.333836474405096, 35.578364211975796, 35.82122275969931, 36.062445840513924, 36.30206605690646, 36.540114942347955, 36.776623009732695, 37.01161979703131, 37.2451339103513, 37.47719306458263, 37.70782412179202, 37.93705312751637, 38.164905345094205, 38.391405288163135, 38.61657675144186, 38.84044283990593, 39.0630259964586, 39.284348028190564, 39.50443013131565, 39.723292914862945, 39.94095642320049, 40.157440157460236, 40.372763095928924, 40.586943713465296, 40.8, 41.011949478170386, 41.22280922013928, 41.4325958636434, 41.64132562731403, 41.84901432530999], [0.0, 4.25, 6.0104076400856545, 7.361215932167729, 8.5, 9.503288904374108, 10.410331406828508, 11.244443072024511, 12.020815280171309, 12.750000000000002, 13.439680055715613, 14.09565535901045, 14.722431864335459, 15.323592920721955, 15.90204389378925, 16.460179221381523, 17.0, 17.52319890887506, 18.031222920256962, 18.525320510047866, 19.006577808748215, 19.47594670356232, 19.93426697924958, 20.382283974079062, 20.820662813657016, 21.250000000000004, 21.67083293276934, 22.08364779650319, 22.488886144049022, 22.886950430321647, 23.27820869396956, 23.662998542027598, 24.041630560342618, 24.414391247786625, 24.78154555309253, 25.14333907817337, 25.500000000000004, 25.851740753767437, 26.198759512618153, 26.541241493193194, 26.879360111431225, 27.21327800908961, 27.543147968233413, 27.8691137282835, 28.1913107180209, 28.50986671312232, 28.824902428282396, 29.13653205170444, 29.444863728670917, 29.750000000000004, 30.05203820042827, 30.35107082130712, 30.64718584144391, 30.94046702944221, 31.23099422048552, 31.51884357015657, 31.8040877875785, 32.08679634990069, 32.367035699921615, 32.64486942844158, 32.920358442763046, 33.193561122603285, 33.46453346455019, 33.733329216073535, 34.0, 34.264595430268834, 34.527163219702835, 34.787749280457916, 35.04639781775012, 35.30315141740182, 35.558051127698214, 35.81113653599952, 36.062445840513924, 36.31201591759951, 36.559882384931164, 36.80607966083865, 37.05064102009573, 37.29359864641653, 37.53498368189335, 37.77482627359125, 38.01315561749643, 38.25000000000001, 38.48538683708403, 38.71934271136327, 38.95189340712464, 39.18306394349477, 39.41287860585675, 39.641360975627464, 39.86853395849916, 40.09441981124056, 40.31904016714684, 40.5424160602202, 40.764567948158124, 40.985515734220066, 41.205278788038804, 41.4238759654381, 41.64132562731403, 41.857645657633455, 42.07285348059958, 42.28696607703135, 42.50000000000001, 42.7119713897638], [0.0, 4.334166586553867, 6.129437168288782, 7.506996736378671, 8.668333173107735, 9.691491113342675, 10.616496597277278, 11.467126928747238, 12.258874336577565, 13.002499759661603, 13.705838172107535, 14.3748043464946, 15.013993472757342, 15.627059864222701, 16.216966424088074, 16.786155009411775, 17.33666634621547, 17.870226635384345, 18.388311504866348, 18.89219415525894, 19.38298222668535, 19.86164645743147, 20.32904326327238, 20.785932743083727, 21.232993194554556, 21.670832932769336, 22.1, 22.520990209136013, 22.934253857494475, 23.34020137016817, 23.739208074407202, 24.131618263183267, 24.51774867315513, 24.897891476990583, 25.27231687044146, 25.641275319297208, 26.004999519323206, 26.363706112760404, 26.717597197352912, 27.06686165775412, 27.41167634421507, 27.752207119434665, 28.088609791159126, 28.421030945410827, 28.7496086929892, 29.07447334002802, 29.395747991843997, 29.71354909801251, 30.027986945514684, 30.339166105877073, 30.64718584144391, 30.952140475256318, 31.254119728445403, 31.553209028560005, 31.849489791831832, 32.14303968202137, 32.43393284817615, 32.722240143364274, 33.008029326210924, 33.29136524686243, 33.57231001882355, 33.850923177957796, 34.12726182980404, 34.40138078624171, 34.67333269243094, 34.94316814486059, 35.21093580125357, 35.47668248300565, 35.74045327076869, 36.00229159373053, 36.26223931309263, 36.52033680019942, 36.776623009732695, 37.03113554834634, 37.28391073908423, 37.53498368189335, 37.78438831051788, 38.032157446035065, 38.27832284727219, 38.52291525832385, 38.7659644533707, 39.00749927898481, 39.24754769409167, 39.486136807745574, 39.72329291486294, 39.95904153004674, 40.19340741962543, 40.42641463201999, 40.65808652654476, 40.888445800739355, 41.11751451632261, 41.345314123852056, 41.571865486167454, 41.79718890069044, 42.02130412064814, 42.2442303752832, 42.46598638910911, 42.686590400265054, 42.90606017802148, 43.1244130394838, 43.34166586553867, 43.55783511608446], [0.0, 4.416729559300638, 6.246198844097105, 7.650000000000001, 8.833459118601276, 9.876107532828915, 10.818733752154177, 11.685568022137394, 12.49239768819421, 13.250188677901912, 13.966925216381737, 14.648634748671974, 15.300000000000002, 15.924744895915916, 16.525888780940043, 17.105920027873392, 17.66691823720255, 18.21064249278427, 18.738596532291314, 19.252077809940413, 19.75221506565783, 20.239997529644118, 20.7162979318217, 21.181890850441093, 21.637467504308354, 22.083647796503186, 22.520990209136013, 22.950000000000003, 23.371136044274788, 23.784816585376483, 24.191424100288103, 24.59130944053204, 24.98479537638842, 25.372179646218814, 25.753737592823303, 26.129724453196978, 26.500377355803824, 26.86591706977449, 27.226549542679848, 27.582467257299523, 27.933850432763474, 28.28086809134402, 28.62367900882066, 28.962432563581395, 29.297269497343947, 29.62832259848674, 29.955717317400367, 30.27957232194669, 30.600000000000005, 30.917106915104462, 31.23099422048552, 31.541758035975107, 31.849489791831832, 32.15427654294216, 32.456201256462535, 32.75534307559608, 33.05177756188009, 33.34557691808615, 33.63681019359595, 33.92554347390768, 34.211840055746784, 34.49576060909514, 34.77736332731393, 35.05670406641218, 35.3338364744051, 35.608812111610796, 35.88168056264924, 36.152489540832455, 36.42128498556854, 36.68811115334231, 36.953010702783075, 37.21602477428238, 37.47719306458263, 37.73655389671929, 37.99414428566592, 38.25, 38.50415561988083, 38.7566445916052, 39.00749927898481, 39.256751011768664, 39.50443013131566, 39.75056603370574, 39.995187210463214, 40.238321287051726, 40.479995059288235, 40.72023452781185, 40.95906493073298, 41.19651077457896, 41.4325958636434, 41.667343327838886, 41.90077564914521, 42.13291468673869, 42.363781700882186, 42.59339737564967, 42.821781840554, 43.048954691142036, 43.27493500861671, 43.49974137854156, 43.72339190867973, 43.94590424601593, 44.16729559300637, 44.3875827230995], [0.0, 4.497777228809804, 6.3608175575157, 7.7903786814249285, 8.995554457619608, 10.057335631269348, 11.017259187293362, 11.9, 12.7216351150314, 13.493331686429412, 14.223220451079285, 14.917439458566609, 15.580757362849857, 16.216966424088078, 16.82914139223983, 17.419816302131316, 17.991108915239217, 18.544810594880715, 19.082452672547102, 19.605356410940356, 20.114671262538696, 20.61140461006964, 21.09644519818446, 21.570581818764186, 22.034518374586725, 22.488886144049022, 22.934253857494472, 23.371136044274788, 23.8, 24.221271642917515, 24.635340468522045, 25.042563766515602, 25.4432702300628, 25.83776306107013, 26.226322654920573, 26.609208932247498, 26.986663372858825, 27.35891079703284, 27.726160931510158, 28.088609791159122, 28.44644090215857, 28.79982638836561, 29.148927939119826, 29.4938976739257, 29.834878917133217, 30.172006893808042, 30.505409356374816, 30.835207150268992, 31.161514725699714, 31.48444060166863, 31.8040877875785, 32.12055416707502, 32.433932848176156, 32.744312483238986, 33.05177756188009, 33.35640867959259, 33.65828278447966, 33.95747340424491, 34.25405085533681, 34.54808243593268, 34.83963260426263, 35.128763143612105, 35.41553331519942, 35.7, 35.98221783047843, 36.262239313092614, 36.540114942347955, 36.81589330710312, 37.08962118976143, 37.36134365892105, 37.631104156003715, 37.89894457633352, 38.164905345094205, 38.42902548855487, 38.69134270091954, 38.95189340712464, 39.21071282188071, 39.46783500522926, 39.72329291486294, 39.97711845543648, 40.22934252507739, 40.479995059288235, 40.7291050724172, 40.976700696859425, 41.22280922013928, 41.467457120011595, 41.710670097710015, 41.95247310946043, 42.19289039636892, 42.431945512785525, 42.669661353237856, 42.90606017802148, 43.14116363752837, 43.37499279538845, 43.607568150494245, 43.83890965797393, 44.06903674917345, 44.29796835070431, 44.52572290260991, 44.75231837569983, 44.977772288098045, 45.20210172104834], [0.0, 4.577390086064329, 6.473407139984323, 7.928272195125494, 9.154780172128659, 10.235355391973453, 11.212270064531982, 12.110635821458757, 12.946814279968645, 13.732170258192987, 14.474978411037442, 15.18148543456799, 15.856544390250988, 16.504014663105462, 17.1270254276684, 17.72815557242208, 18.309560344257317, 18.873062814498343, 19.420221419952966, 19.952380810319358, 20.470710783946906, 20.976236554730214, 21.469862598535652, 21.95239166924643, 22.424540129063963, 22.886950430321644, 23.34020137016817, 23.784816585376483, 24.221271642917515, 24.650000000000006, 25.071398046379464, 25.48582939596042, 25.89362855993729, 26.29510410703864, 26.69054139578289, 27.080204947525786, 27.464340516385974, 27.843176902070645, 28.21692754358632, 28.585791925360407, 28.949956822074885, 29.30959740426334, 29.664878223245758, 30.015954091116274, 30.36297086913598, 30.706066175920355, 31.045370025174453, 31.381005401357047, 31.713088780501977, 32.0417306024503, 32.36703569992161, 32.68910368915, 33.008029326210924, 33.32390283265153, 33.63681019359594, 33.94683343111696, 34.2540508553368, 34.55853729543541, 34.8603643124968, 35.15960039590894, 35.45631114484416, 35.75055943618226, 36.04240558009412, 36.33190746437627, 36.619120688514634, 36.904098688357095, 37.18689285218651, 37.46755262890812, 37.74612562899669, 38.022657718786576, 38.29719310863396, 38.56977443543066, 38.84044283990593, 39.10923803911296, 39.376198394461596, 39.641360975627464, 39.904761620638716, 40.16643499241625, 40.42641463202, 40.68473300883269, 40.94142156789381, 41.19651077457896, 41.45003015680447, 41.70200834492267, 41.95247310946043, 42.2014513968418, 42.44896936322483, 42.69505240657283, 42.939725197071304, 43.18301170599383, 43.42493523311233, 43.665518432740505, 43.90478333849286, 44.142751386835876, 44.37944343950249, 44.61487980483641, 44.84908025812793, 45.08206406099881, 45.31384997989026, 45.544456303703974, 45.77390086064329, 46.00220103429836], [0.0, 4.6556417387939115, 6.5840716885526085, 8.063808033429368, 9.311283477587823, 10.410331406828508, 11.403946685248927, 12.317670234261023, 13.168143377105217, 13.966925216381735, 14.722431864335457, 15.441016805897206, 16.127616066858735, 16.786155009411775, 17.419816302131313, 18.03122292025696, 18.622566955175646, 19.195702644081564, 19.752215065657825, 20.293471856732648, 20.820662813657016, 21.334830676618925, 21.83689538373072, 22.327673412158283, 22.807893370497855, 23.27820869396956, 23.739208074407202, 24.191424100288103, 24.635340468522045, 25.071398046379464, 25.499999999999996, 25.921516159360742, 26.336286754210434, 26.744625628338866, 27.14682301854123, 27.543147968233406, 27.93385043276347, 28.31916312322806, 28.699303127428028, 29.074473340028018, 29.444863728670914, 29.81065245847531, 30.172006893808046, 30.529084493315544, 30.882033611794412, 31.23099422048552, 31.576098555711408, 31.917471704381597, 32.25523213371747, 32.58949217155738, 32.92035844276304, 33.24793226653351, 33.57231001882355, 33.89358346354071, 34.21184005574678, 34.52716321970283, 34.839632604262626, 35.149324317830065, 35.45631114484416, 35.760662745536465, 36.06244584051392, 36.36172438155264, 36.6585597098413, 36.95301070278307, 37.24513391035129, 37.534983681893344, 37.82261228418788, 38.10807001148182, 38.39140528816313, 38.67266476466291, 38.95189340712464, 39.22913458132871, 39.50443013131565, 39.77782045311181, 40.04934456392513, 40.31904016714684, 40.586943713465296, 40.85309045837292, 41.1175145163226, 41.380248911769485, 41.64132562731403, 41.90077564914521, 42.15862900996663, 42.4149148295738, 42.66966135323785, 42.92289598803883, 43.174645337281, 43.42493523311232, 43.67379076746144, 43.92123632139696, 44.167295593006365, 44.411991623884646, 44.65534682431657, 44.89738299723047, 45.13812136099596, 45.37758257113307, 45.61578674099571, 45.85275346148801, 46.088501819868256, 46.323050417691626, 46.55641738793912, 46.78862041137781], [0.0, 4.732599708405519, 6.692906692910039, 8.197103146844013, 9.465199416811037, 10.582414658290423, 11.592454442437978, 12.521281883257801, 13.385813385820079, 14.197799125216557, 14.965794332410159, 15.69625751572648, 16.394206293688026, 17.06363091490202, 17.70776665759971, 18.32927985492065, 18.930398833622075, 19.513008481523293, 20.078720078730118, 20.628923869169718, 21.164829316580846, 21.687496397694225, 22.197860257241015, 22.69675086879177, 23.184908884875956, 23.662998542027594, 24.131618263183263, 24.591309440532036, 25.042563766515602, 25.48582939596042, 25.921516159360742, 26.35, 26.771626771640157, 27.186715505923114, 27.59556123727148, 27.998437456401028, 28.395598250433114, 28.787280177189373, 29.17370391294188, 29.55507570621331, 29.931588664820318, 30.30342389895901, 30.67075153953682, 31.03373164799876, 31.39251503145296, 31.747243974871267, 32.09805290044866, 32.445068962786934, 32.78841258737605, 33.12819795883863, 33.46453346455019, 33.79752209852078, 34.12726182980404, 34.45384593916912, 34.77736332731393, 35.09789879750638, 35.41553331519942, 35.73034424687229, 36.042405580094126, 36.35178812658326, 36.6585597098413, 36.962785338770125, 37.26452736853105, 37.563845649773405, 37.86079766724415, 38.15543866868784, 38.447821784855385, 38.73799814135986, 39.02601696304659, 39.31192567148041, 39.5957699760972, 39.877593959515664, 40.157440157460236, 40.43534963370541, 40.71136205041536, 40.98551573422006, 41.257847738339436, 41.52839390104077, 41.79718890069044, 42.064266307639315, 42.32965863316169, 42.59339737564967, 42.85551306424881, 43.11603530010615, 43.37499279538845, 43.63241341021604, 43.888324187646994, 44.14275138683587, 44.39572051448203, 44.64725635467425, 44.89738299723047, 45.14612386462431, 45.39350173758354, 45.63953877943992, 45.88425655930365, 46.12767607413146, 46.36981776975191, 46.610701560907664, 46.85034685037028, 47.088772547179445, 47.32599708405519, 47.562038434028466], [0.0, 4.8083261120685235, 6.8, 8.328265125462806, 9.616652224137047, 10.75174404457249, 11.777945491468365, 12.721635115031402, 13.6, 14.42497833620557, 15.20526224699857, 15.94741358339966, 16.656530250925613, 17.33666634621547, 17.991108915239213, 18.622566955175646, 19.233304448274094, 19.825236442474022, 20.4, 20.95900761009452, 21.50348808914498, 22.034518374586725, 22.55304857441672, 23.059921942625913, 23.55589098293673, 24.041630560342615, 24.51774867315513, 24.98479537638842, 25.443270230062804, 25.89362855993729, 26.336286754210434, 26.771626771640157, 27.2, 27.621730575762268, 28.03711825420009, 28.446440902158567, 28.84995667241114, 29.247905907944933, 29.640512816076583, 30.02798694551468, 30.41052449399714, 30.78830946966722, 31.161514725699718, 31.530302884685387, 31.89482716679932, 32.25523213371747, 32.61165435852649, 32.964223030431036, 33.313060501851226, 33.65828278447966, 34.0, 34.338316790431065, 34.67333269243094, 35.005142479355804, 35.333836474405096, 35.65950083778515, 35.982217830478426, 36.302066056906455, 36.61912068851463, 36.93345367008073, 37.24513391035129, 37.554227458436685, 37.86079766724414, 38.164905345094205, 38.46660889654819, 38.765964453370685, 39.0630259964586, 39.35784546948677, 39.650472884948044, 39.94095642320049, 40.22934252507739, 40.51567597856415, 40.8, 41.08235631022155, 41.36278520602789, 41.641325627314025, 41.91801522018904, 42.19289039636892, 42.46598638910911, 42.737337305920214, 43.00697617828996, 43.27493500861671, 43.541244814543376, 43.80593567086542, 44.06903674917345, 44.330576355378014, 44.590581965253605, 44.84908025812793, 45.10609714883344, 45.36165781802953, 45.61578674099571, 45.868507714988944, 46.119843885251825, 46.36981776975191, 46.6184512827271, 46.86576575710675, 47.11178196587346, 47.35652014242601, 47.6, 47.84224075019898, 48.08326112068523, 48.32307937207645], [0.0, 4.882878249557325, 6.905432643940567, 8.457393215406272, 9.76575649911465, 10.918447691865362, 11.960560187549746, 12.918881530535065, 13.810865287881134, 14.648634748671975, 15.44101680589721, 16.194675050769003, 16.914786430812544, 17.605467900626785, 18.270057471173974, 18.91130614209394, 19.5315129982293, 20.132622779955923, 20.7162979318217, 21.28397284343316, 21.836895383730724, 22.376159187849915, 22.902729095022718, 23.41746143372505, 23.92112037509949, 24.414391247786625, 24.89789147699058, 25.372179646218814, 25.83776306107013, 26.29510410703864, 26.744625628338866, 27.186715505923114, 27.621730575762268, 28.050000000000008, 28.47182818155519, 28.887497295542932, 29.29726949734395, 29.70138885641546, 30.10008305636382, 30.49356489490857, 30.88203361179442, 31.26567606817419, 31.644667797276693, 32.01917394312352, 32.38935010153801, 32.75534307559608, 33.117291555922876, 33.47532673477587, 33.82957286162509, 34.18014774690128, 34.527163219702835, 34.870725544502235, 35.21093580125357, 35.54789023275504, 35.88168056264924, 36.21239428703935, 36.54011494234795, 36.86492235174245, 37.18689285218651, 37.506099503947354, 37.82261228418788, 38.136498266096744, 38.44782178485538, 38.7566445916052, 39.0630259964586, 39.367023001491994, 39.66869042456532, 39.96808101472975, 40.26524555991185, 40.56023298749652, 40.853090458372925, 41.14386345495523, 41.4325958636434, 41.71933005214729, 42.00410694205984, 42.28696607703135, 42.56794568686632, 42.84708274783711, 43.124413039483805, 43.39997119814713, 43.67379076746145, 43.94590424601593, 44.21634313237585, 44.485137967640384, 44.75231837569983, 45.01791310134223, 45.28195004634849, 45.544456303703974, 45.805458190045435, 46.06498127645337, 46.323050417691626, 46.57968977998888, 46.8349228674501, 47.088772547179445, 47.341261073190694, 47.59241010917603, 47.84224075019898, 48.09077354337317, 48.33802850758397, 48.584025152307014, 48.82878249557325, 49.07231908112761], [0.0, 4.9563091106185055, 7.009279563550023, 8.584579197607768, 9.912618221237011, 11.082644088844503, 12.140428328522844, 13.113161327460286, 14.018559127100046, 14.868927331855517, 15.67322557739791, 16.43821766494166, 17.169158395215536, 17.870226635384345, 18.544810594880712, 19.195702644081564, 19.825236442474022, 20.435385976291226, 21.027838690650068, 21.60405054613602, 22.165288177689007, 22.712661667008557, 23.247150363001484, 23.769623471986257, 24.28085665704569, 24.781545553092528, 25.27231687044146, 25.753737592823303, 26.226322654920573, 26.69054139578289, 27.14682301854123, 27.59556123727148, 28.03711825420009, 28.47182818155519, 28.900000000000002, 29.32192012812258, 29.737854663711033, 30.148051346645943, 30.552741284539433, 30.952140475256314, 31.34645115479582, 31.7358629944106, 32.12055416707502, 32.50069230031877, 32.87643532988332, 33.24793226653351, 33.615323886584825, 33.97874335522137, 34.33831679043107, 34.69416377432954, 35.04639781775011, 35.39512678321693, 35.74045327076869, 36.08247497054492, 36.42128498556853, 36.75697212774741, 37.089621189761424, 37.41931319519374, 37.74612562899668, 38.07013265014977, 38.39140528816313, 38.71001162490138, 39.02601696304659, 39.33948398238086, 39.650472884948044, 39.95904153004673, 40.26524555991184, 40.56913851685786, 40.87077195258245, 41.17019553026194, 41.467457120011595, 41.76260288823004, 42.055677381300136, 42.34672360407591, 42.63578309354713, 42.92289598803883, 43.20810109227204, 43.49143593858451, 43.7729368445847, 44.05263896748979, 44.330576355378014, 44.60678199556655, 44.8812878603099, 45.154124949997644, 45.425323334017115, 45.69491218943308, 45.962919837625634, 46.229373779016306, 46.49430072600297, 46.757726634215224, 47.01967673219372, 47.280175549589494, 47.539246943972515, 47.79691412633247, 48.05319968534874, 48.30812561050159, 48.56171331409138, 48.81398365222819, 49.06495694485016, 49.31465299482498, 49.563091106185055, 49.81029010154429], [0.0, 5.028667815634674, 7.111610225539642, 8.70990815106566, 10.057335631269348, 11.244443072024511, 12.317670234261023, 13.304604466123749, 14.223220451079284, 15.086003446904021, 15.902043893789251, 16.678204339796295, 17.41981630213132, 18.13111965654631, 18.815552078001854, 19.475946703562318, 20.114671262538696, 20.733728560005797, 21.334830676618925, 21.919454828986968, 22.488886144049022, 23.04425090993413, 23.586542773369736, 24.116643630488884, 24.635340468522045, 25.14333907817337, 25.641275319297208, 26.129724453196978, 26.609208932247498, 27.080204947525786, 27.543147968233406, 27.998437456401028, 28.446440902158567, 28.887497295542932, 29.32192012812258, 29.75, 30.172006893808042, 30.58819216625919, 30.998790298977802, 31.404020443248985, 31.804087787578503, 32.19918477228888, 32.58949217155739, 32.9751800601604, 33.35640867959259, 33.73332921607353, 34.1060845011561, 34.47480964414452, 34.83963260426264, 35.200674709442715, 35.55805112769821, 35.91187129627194, 36.26223931309262, 36.60925429450866, 36.95301070278307, 37.29359864641652, 37.63110415600371, 37.9656094380164, 38.297193108633955, 38.62593040950599, 38.951893407124636, 39.27515117730293, 39.59576997609719, 39.913813398371246, 40.22934252507739, 40.542416060220184, 40.85309045837292, 41.16142004353105, 41.467457120011595, 41.77125207603909, 42.07285348059958, 42.37230817408936, 42.66966135323785, 42.96495665074038, 43.2582362099982, 43.549540755328294, 43.838909657973936, 44.1263809982192, 44.411991623884646, 44.69577720545868, 44.977772288098045, 45.25801034071206, 45.536523802328176, 45.81334412592034, 46.08850181986826, 46.36202648720179, 46.63394686277369, 46.90429084849274, 47.17308554673947, 47.440357292077806, 47.70613168136775, 47.970433602376374, 48.23328726097777, 48.4947162070261, 48.75474335897996, 49.013391027350885, 49.27068093704409, 49.52663424865454, 49.78127157877749, 50.03461301938889, 50.28667815634674, 50.537486087062156], [0.0, 5.1, 7.212489168102785, 8.833459118601274, 10.2, 11.403946685248927, 12.492397688194208, 13.493331686429412, 14.42497833620557, 15.3, 16.127616066858735, 16.914786430812537, 17.666918237202548, 18.388311504866344, 19.0824526725471, 19.752215065657825, 20.4, 21.027838690650068, 21.637467504308354, 22.230384612057435, 22.807893370497855, 23.371136044274785, 23.92112037509949, 24.45874076889487, 24.984795376388416, 25.5, 26.004999519323203, 26.500377355803824, 26.986663372858825, 27.464340516385974, 27.93385043276347, 28.395598250433114, 28.84995667241114, 29.29726949734395, 29.737854663711033, 30.172006893808042, 30.6, 31.02208890452092, 31.438511415141782, 31.849489791831832, 32.25523213371747, 32.65593361090753, 33.051777561880094, 33.4429364739402, 33.829572861625074, 34.211840055746784, 34.58988291393887, 34.963838462045324, 35.333836474405096, 35.7, 36.062445840513924, 36.42128498556854, 36.77662300973269, 37.12856043533065, 37.47719306458262, 37.822612284187876, 38.1649053450942, 38.50415561988082, 38.84044283990593, 39.1738433141299, 39.50443013131565, 39.83227334712394, 40.15744015746023, 40.479995059288235, 40.8, 41.11751451632259, 41.4325958636434, 41.7452991365495, 42.055677381300136, 42.363781700882186, 42.669661353237856, 42.97336384319943, 43.27493500861671, 43.57441910111941, 43.87185886191739, 44.16729559300637, 44.46076922411487, 44.75231837569982, 45.04198041827202, 45.3297915283095, 45.61578674099571, 45.9, 46.182464204500825, 46.46321125363592, 46.74227208854957, 47.01967673219372, 47.29545432702809, 47.56963317075296, 47.84224075019898, 48.113303773488674, 48.382848200576205, 48.65089927226423, 48.91748153778974, 49.18261888106407, 49.44633454564656, 49.70865115852571, 49.96959075277683, 50.22917478916014, 50.48742417671949, 50.74435929243762, 51.0, 51.25436566771655], [0.0, 5.170348150753487, 7.311976476986233, 8.95530568992483, 10.340696301506973, 11.56124993242513, 12.66471476188864, 13.67945539851642, 14.623952953972466, 15.511044452260462, 16.350076452420645, 17.148104851557214, 17.91061137984966, 18.641955369542114, 19.34567135045977, 20.02467228196257, 20.681392603013947, 21.31789154677357, 21.935929430958698, 22.53702509205685, 23.12249986485026, 23.693511770102802, 24.251082450068083, 24.796118647885198, 25.32942952377728, 25.851740753767437, 26.3637061127604, 26.865917069774486, 27.35891079703284, 27.843176902070645, 28.31916312322806, 28.787280177189373, 29.247905907944933, 29.70138885641546, 30.148051346645943, 30.58819216625919, 31.022088904520924, 31.450000000000003, 31.872166540729552, 32.28881385247839, 32.70015290484129, 33.106381560055766, 33.50768568552595, 33.90424014780452, 34.29620970311443, 34.68374979727538, 35.06700728605166, 35.44612108538818, 35.82122275969932, 36.19243705527441, 36.559882384931164, 36.92367126925491, 37.28391073908423, 37.64070270332371, 37.99414428566592, 38.34432813337587, 38.69134270091954, 39.035272510897116, 39.376198394461596, 39.714197713160466, 40.04934456392514, 40.38170996874699, 40.71136205041536, 41.038366195549266, 41.362785206027894, 41.68467943981337, 42.00410694205985, 42.32112356731565, 42.63578309354714, 42.948137328643256, 43.258236209998216, 43.5661278977143, 43.871858861917396, 44.17547396463337, 44.47701653663383, 44.776528449624145, 45.0740501841137, 45.36962089328057, 45.6632784631152, 45.955059569105124, 46.24499972970052, 46.533133356781384, 46.81949380332941, 47.104113408491195, 47.387023540205604, 47.66825463555384, 47.94783623897955, 48.225797038514564, 48.502164900136165, 48.776966900372145, 49.050229357261934, 49.32197785977363, 49.592237295770396, 49.86103187861239, 50.12838517247489, 50.39432011645757, 50.65885904755456, 50.92202372255055, 51.183835338903634, 51.44431455467164, 51.703481507534875, 51.961355832964955], [0.0, 5.23975190252363, 7.410128204019146, 9.075516514226615, 10.47950380504726, 11.716441439276691, 12.834718539960274, 13.863080465755079, 14.820256408038292, 15.719255707570891, 16.56955038617524, 17.378291055221744, 18.15103302845323, 18.89219415525894, 19.605356410940352, 20.293471856732648, 20.95900761009452, 21.604050546136023, 22.230384612057435, 22.83954903232549, 23.432882878553382, 24.01155971610341, 24.576614901161637, 25.128967348460623, 25.66943707992055, 26.198759512618153, 26.717597197352912, 27.226549542679848, 27.726160931510158, 28.21692754358632, 28.699303127428028, 29.17370391294188, 29.640512816076583, 30.10008305636382, 30.552741284539433, 30.9987902989778, 31.438511415141782, 31.872166540729552, 32.300000000000004, 32.722240143364274, 33.13910077235048, 33.55078240518394, 33.95747340424491, 34.35935098339315, 34.75658211044349, 35.149324317830065, 35.537726432623685, 35.92192923549625, 36.30206605690646, 36.67826331766541, 37.050641020095725, 37.419313195193745, 37.78438831051788, 38.145969642938695, 38.50415561988083, 38.85904013225237, 39.210712821880705, 39.55925934594833, 39.90476162063871, 40.24729804595583, 40.586943713465296, 40.923770598516455, 41.25784773833943, 41.58924139726523, 41.91801522018904, 42.2442303752832, 42.56794568686632, 42.88921775924574, 43.208101092272045, 43.52464818927317, 43.838909657973936, 44.15093430494988, 44.46076922411487, 44.76845987969656, 45.074050184113695, 45.377582571133075, 45.67909806465098, 45.978636343414976, 46.27623580197508, 46.571933608129264, 46.865765757106765, 47.15776712271268, 47.44797150563974, 47.7364116791365, 48.02311943220682, 48.3081256105016, 48.59146015505194, 48.873152138981176, 49.153229802323274, 49.43172058506562, 49.70865115852572, 49.984047455163136, 50.25793469692125, 50.53033742218629, 50.80127951144539, 51.07078421171933, 51.3388741598411, 51.60557140464584, 51.87089742813402, 52.13487316566523, 52.397519025236306, 52.658854905894046], [0.0, 5.308248298638639, 7.506996736378671, 9.194155752433174, 10.616496597277278, 11.869604037203603, 13.002499759661601, 14.044304895579563, 15.013993472757342, 15.924744895915918, 16.786155009411775, 17.605467900626785, 18.388311504866348, 19.139161423636097, 19.86164645743147, 20.5587572581613, 21.232993194554556, 21.88646842229235, 22.520990209136013, 23.13811790098754, 23.739208074407205, 24.325449636132117, 24.89789147699058, 25.457464524182296, 26.004999519323203, 26.541241493193194, 27.06686165775412, 27.582467257299523, 28.088609791159126, 28.585791925360407, 29.07447334002802, 29.555075706213312, 30.027986945514684, 30.493564894908573, 30.952140475256318, 31.404020443248985, 31.849489791831836, 32.28881385247839, 32.722240143364274, 33.150000000000006, 33.57231001882355, 33.98937333932475, 34.40138078624172, 34.80851189005356, 35.21093580125357, 35.6088121116108, 36.00229159373054, 36.391516868633005, 36.776623009732695, 37.157738090470474, 37.53498368189335, 37.90847530566219, 38.27832284727219, 38.64463093367565, 39.00749927898481, 39.367023001492, 39.72329291486294, 40.07639579602937, 40.42641463201999, 40.773428847718954, 41.1175145163226, 41.45874455407448, 41.797188900690436, 42.13291468673869, 42.46598638910911, 42.79646597559196, 43.1244130394838, 43.449884925049, 43.7729368445847, 44.09362198776599, 44.41199162388465, 44.72809519753776, 45.041980418272026, 45.35369334464394, 45.6632784631152, 45.97077876216587, 46.27623580197508, 46.57968977998888, 46.88117959266811, 47.18074289368492, 47.47841614881441, 47.77423468774775, 48.06823275303556, 48.360443546353046, 48.65089927226423, 48.939631179648266, 49.226669600938884, 49.51204398931638, 49.79578295398116, 50.07791429362848, 50.35846502823533, 50.63746142926204, 50.91492904836459, 51.19089274470607, 51.46537671095006, 51.73840449801289, 52.009999038646406, 52.28018266991806, 52.54897715465069, 52.816403701880354, 53.08248298638639, 53.347235167344905], [0.0, 5.375872022286245, 7.602631123499285, 9.311283477587825, 10.75174404457249, 12.020815280171309, 13.168143377105217, 14.223220451079285, 15.20526224699857, 16.127616066858735, 17.0, 17.829750418892576, 18.62256695517565, 19.382982226685346, 20.114671262538693, 20.820662813657012, 21.50348808914498, 22.165288177689007, 22.807893370497855, 23.43288287855338, 24.041630560342618, 24.635340468522045, 25.215074856125256, 25.781776509775273, 26.336286754210434, 26.879360111431225, 27.41167634421507, 27.933850432763474, 28.44644090215857, 28.949956822074885, 29.444863728670914, 29.931588664820318, 30.41052449399714, 30.88203361179442, 31.34645115479582, 31.804087787578503, 32.25523213371747, 32.70015290484129, 33.13910077235048, 33.57231001882355, 34.0, 34.4223764432382, 34.83963260426264, 35.25195030065712, 35.65950083778515, 36.062445840513924, 36.46093800219627, 36.85512176075396, 37.2451339103513, 37.631104156003715, 38.01315561749642, 38.391405288163135, 38.76596445337069, 39.13693907295256, 39.50443013131565, 39.86853395849915, 40.229342525077385, 40.586943713465296, 40.941421567893805, 41.2928565250698, 41.641325627314025, 41.98690271977679, 42.329658633161685, 42.669661353237856, 43.00697617828996, 43.341665865538666, 43.67379076746144, 44.00340895885227, 44.330576355378014, 44.655346824316574, 44.977772288098045, 45.297902821212375, 45.61578674099571, 45.93147069276141, 46.2449997297005, 46.55641738793912, 46.86576575710676, 47.17308554673947, 47.478416148814404, 47.78179569668767, 48.083261120685236, 48.382848200576205, 48.680591615139605, 48.97652498901897, 49.27068093704409, 49.563091106185055, 49.85378621529161, 50.14279609275893, 50.43014971225051, 50.71587522659941, 51.0, 51.282550638594415, 51.56355301955055, 51.843032318721484, 52.121013036970034, 52.3975190252363, 52.67257350842087, 52.94619910815129, 53.218417864494995, 53.48925125667773, 53.75872022286245, 54.0268451790404], [0.0, 5.442655601817922, 7.697077367416805, 9.426956030448006, 10.885311203635844, 12.170147903784903, 13.331729070154404, 14.399913194182806, 15.39415473483361, 16.327966805453766, 17.2111882216191, 18.051246494356008, 18.85391206089601, 19.623773847045836, 20.364552536208596, 21.079314504983316, 21.770622407271688, 22.44064393015495, 23.091232102250412, 23.72398575281987, 24.340295807569806, 24.941381276906057, 25.528317610058053, 26.10205930573295, 26.66345814030881, 27.21327800908961, 27.75220711943467, 28.28086809134402, 28.799826388365613, 29.30959740426334, 29.81065245847531, 30.303423898959014, 30.78830946966722, 31.265676068174194, 31.735862994410603, 32.19918477228888, 32.65593361090753, 33.106381560055766, 33.550782405183945, 33.98937333932475, 34.4223764432382, 34.85, 35.272439666118935, 35.689879517868924, 36.102492988712015, 36.510443711354704, 36.9138862760344, 37.31296691500155, 37.70782412179202, 38.09858921272546, 38.48538683708402, 38.8683354415905, 39.24754769409167, 39.62313087074267, 39.995187210463214, 40.363814239984805, 40.72910507241719, 41.091148681924196, 41.45003015680447, 41.805830933016985, 42.15862900996663, 42.50849915016996, 42.855513064248804, 43.19973958254842, 43.541244814543376, 43.88009229707704, 44.21634313237585, 44.55005611668744, 44.8812878603099, 45.21009289970549, 45.536523802328176, 45.86063126473512, 46.182464204500825, 46.50206984640577, 46.8194938033294, 47.134780152240026, 47.44797150563974, 47.759109078792505, 48.06823275303556, 48.37538113544947, 48.68059161513961, 48.9839004163613, 49.28534264870237, 49.584952354519814, 49.882762553812114, 50.178805286694505, 50.47311165363198, 50.76571185357298, 51.05663522011611, 51.34591025583245, 51.6335646648573, 51.91962538385655, 52.2041186114659, 52.487069836293976, 52.76850386357378, 53.04844484054175, 53.32691628061762, 53.603941086453716, 53.879541571917635, 54.15373948306803, 54.42655601817922, 54.69801184686699], [0.0, 5.508629593646682, 7.7903786814249285, 9.541226336273553, 11.017259187293364, 12.317670234261024, 13.493331686429412, 14.574463969559913, 15.580757362849857, 16.525888780940047, 17.41981630213132, 18.270057471173978, 19.082452672547106, 19.86164645743147, 20.61140461006964, 21.334830676618928, 22.034518374586728, 22.71266166700856, 23.371136044274785, 24.011559716103413, 24.63534046852205, 25.24371208835975, 25.83776306107013, 26.418459455464095, 26.986663372858825, 27.54314796823341, 28.088609791159126, 28.623679008820655, 29.148927939119826, 29.664878223245758, 30.172006893808046, 30.67075153953682, 31.161514725699714, 31.644667797276693, 32.12055416707502, 32.58949217155739, 33.051777561880094, 33.50768568552595, 33.95747340424491, 34.40138078624171, 34.83963260426264, 35.272439666118935, 35.70000000000001, 36.122499913488824, 36.540114942347955, 36.95301070278307, 37.36134365892106, 37.765261815589206, 38.16490534509421, 38.560407155526775, 38.95189340712464, 39.33948398238086, 39.72329291486294, 40.103428781090535, 40.479995059288235, 40.85309045837292, 41.22280922013928, 41.58924139726523, 41.95247310946043, 42.31258677982238, 42.669661353237856, 43.0237724984688, 43.37499279538845, 43.72339190867974, 44.069036749173456, 44.411991623884646, 44.75231837569983, 45.09007651357447, 45.42532333401712, 45.758114034562226, 46.08850181986827, 46.416538001018566, 46.74227208854957, 47.06575187968424, 47.387023540205604, 47.70613168136776, 48.023119432206826, 48.33802850758397, 48.65089927226423, 48.961770801309875, 49.2706809370441, 49.57766634282014, 49.88276255381212, 50.18600402502674, 50.4874241767195, 50.787055437384836, 51.08492928447685, 51.38107628300521, 51.67552612214026, 51.96830764995143, 52.259448906393956, 52.5489771546507, 52.83691891092819, 53.12329997279914, 53.40814544617704, 53.691479771002776, 53.97332674571765, 54.253709550592035, 54.5326507699745, 54.81017241352193, 55.08629593646682, 55.36104225897487], [0.0, 5.573822745656701, 7.882575721171348, 9.654144187860465, 11.147645491313401, 12.463446553822903, 13.653021643577658, 14.74694883696285, 15.765151442342695, 16.7214682369701, 17.62597515032856, 18.486278695291812, 19.30828837572093, 20.09670370981271, 20.855335048855, 21.587322668640496, 22.295290982626803, 22.981459918812817, 23.64772716351404, 24.295730077525967, 24.926893107645807, 25.54246464223842, 26.14354604869049, 26.73111482897786, 27.306043287155315, 27.8691137282835, 28.42103094541083, 28.962432563581395, 29.4938976739257, 30.015954091116278, 30.529084493315548, 31.033731647998763, 31.53030288468539, 32.01917394312352, 32.500692300318775, 32.9751800601604, 33.4429364739402, 33.90424014780452, 34.359350983393156, 34.80851189005356, 35.25195030065712, 35.689879517868924, 36.122499913488824, 36.54999999999999, 36.972557390583624, 37.39033966146871, 37.80350512849304, 38.212203548081334, 38.61657675144186, 39.0167592195969, 39.41287860585673, 39.805056211491525, 40.19340741962542, 40.57804209175204, 40.95906493073297, 41.336575813678614, 41.71067009771, 42.081438901254316, 42.448969363224826, 42.81334488217429, 43.17464533728099, 43.53294729282638, 43.88832418764699, 44.24084651088855, 44.590581965253605, 44.93759561881342, 45.28195004634849, 45.62370546108678, 45.962919837625634, 46.299649026747495, 46.63394686277369, 46.96586526404043, 47.29545432702808, 47.62276241462689, 47.947836238979534, 48.27072093930232, 48.591460155051934, 48.91009609477373, 49.22666960093888, 49.541220211052526, 49.85378621529161, 50.164404710910304, 50.473111653631975, 50.77994190622907, 51.08492928447684, 51.38810660065225, 51.68950570473662, 51.98915752346829, 52.28709209738098, 52.58333861595324, 52.877925450985686, 53.1708801883136, 53.46222965795572, 53.751999962792084, 54.04021650585793, 54.326904016334296, 54.61208657431063, 54.895787634389585, 55.17803004819943, 55.45883608587544, 55.738227456567, 56.01622532802438], [0.0, 5.63826214360418, 7.973706791699831, 9.76575649911465, 11.27652428720836, 12.60753742806263, 13.810865287881134, 14.91743945856661, 15.947413583399662, 16.91478643081254, 17.829750418892576, 18.700000000000003, 19.5315129982293, 20.32904326327238, 21.096445198184455, 21.83689538373072, 22.55304857441672, 23.247150363001488, 23.92112037509949, 24.576614901161637, 25.21507485612526, 25.83776306107013, 26.445793616376882, 27.040155324997677, 27.621730575762268, 28.1913107180209, 28.749608692989202, 29.29726949734395, 29.83487891713322, 30.36297086913598, 30.882033611794416, 31.392515031452962, 31.894827166799324, 32.389350101538014, 32.87643532988332, 33.3564086795926, 33.82957286162508, 34.29620970311443, 34.75658211044349, 35.21093580125357, 35.65950083778515, 36.102492988712015, 36.54011494234796, 36.972557390583624, 37.400000000000006, 37.82261228418788, 38.24055438928678, 38.65397780306705, 39.0630259964586, 39.46783500522926, 39.86853395849915, 40.26524555991185, 40.65808652654476, 41.047167990008774, 41.4325958636434, 41.81447117924607, 42.19289039636891, 42.56794568686632, 42.939725197071304, 43.30831328971379, 43.67379076746144, 44.036235079761305, 44.39572051448202, 44.75231837569983, 45.10609714883344, 45.45712265421118, 45.805458190045435, 46.151164665693976, 46.494300726002976, 46.8349228674501, 47.17308554673948, 47.508841282439214, 47.84224075019898, 48.17333287203617, 48.50216490013616, 48.82878249557325, 49.153229802323274, 49.475549516907854, 49.79578295398116, 50.1139701081445, 50.43014971225052, 50.74435929243762, 51.056635220116114, 51.367012761109635, 51.67552612214026, 51.98220849483023, 52.28709209738098, 52.59020821407727, 52.891587232753764, 53.191258680350856, 53.48925125667773, 53.78559286649168, 54.080310649995354, 54.37343101184622, 54.664979648766, 54.95498157583169, 55.243461151524535, 55.53044210160766, 55.815947541898815, 56.10000000000001, 56.3826214360418, 56.663833262496475], [0.0, 5.701973342624464, 8.063808033429368, 9.876107532828913, 11.403946685248927, 12.75, 13.966925216381734, 15.086003446904021, 16.127616066858735, 17.105920027873392, 18.031222920256962, 18.911306142093938, 19.752215065657825, 20.5587572581613, 21.33483067661892, 22.083647796503183, 22.807893370497855, 23.50983836609686, 24.1914241002881, 24.85432557926286, 25.5, 26.129724453196975, 26.744625628338863, 27.3457035016472, 27.933850432763467, 28.509866713122317, 29.074473340028018, 29.62832259848674, 30.172006893808042, 30.706066175920355, 31.230994220485517, 31.747243974871267, 32.25523213371747, 32.75534307559608, 33.24793226653351, 33.73332921607353, 34.211840055746784, 34.68374979727538, 35.149324317830065, 35.6088121116108, 36.062445840513924, 36.5104437113547, 36.95301070278307, 37.3903396614687, 37.822612284187876, 38.25, 38.67266476466291, 39.09075977772752, 39.50443013131565, 39.913813398371246, 40.31904016714683, 40.72023452781185, 41.1175145163226, 41.51099252005426, 41.9007756491452, 42.286966077031344, 42.66966135323784, 43.048954691142036, 43.42493523311232, 43.79768829516004, 44.167295593006365, 44.5338354512611, 44.897382997230466, 45.25801034071206, 45.61578674099571, 45.97077876216586, 46.32305041769162, 46.67266330519397, 47.01967673219372, 47.36414783356711, 47.70613168136775, 48.04568138761277, 48.3828482005762, 48.71768159508414, 49.05022935726192, 49.38053766414456, 49.70865115852572, 50.034613019388885, 50.35846502823532, 50.68024763159706, 51.0, 51.31776008362017, 51.633564664857296, 51.94744940803157, 52.25944890639395, 52.56959672662517, 52.877925450985686, 53.18446671726623, 53.489251256677726, 53.792308929808904, 54.09366876077088, 54.39335896963893, 54.6914070032944, 54.98783956476195, 55.28268264113093, 55.57596153014358, 55.867700865526935, 56.15792464114036, 56.446656234005566, 56.73391842628182, 57.019733426244635, 57.304122888322794], [0.0, 5.764980485656478, 8.152913589631623, 9.985239105800122, 11.529960971312956, 12.890888254887638, 14.121260566960727, 15.252704678187408, 16.305827179263247, 17.294941456969436, 18.230469001098136, 19.12027719464339, 19.970478211600245, 20.785932743083723, 21.570581818764182, 22.327673412158283, 23.059921942625913, 23.76962347198626, 24.45874076889487, 25.128967348460623, 25.781776509775277, 26.41845945546409, 27.040155324997674, 27.64787514439401, 28.242521133921453, 28.824902428282392, 29.395747991843994, 29.955717317400367, 30.505409356374816, 31.04537002517445, 31.576098555711408, 32.09805290044865, 32.61165435852649, 33.117291555922876, 33.615323886584825, 34.1060845011561, 34.58988291393887, 35.06700728605166, 35.537726432623685, 36.00229159373053, 36.46093800219627, 36.91388627603439, 37.36134365892106, 37.80350512849304, 38.24055438928678, 38.67266476466291, 39.10000000000001, 39.52271498771308, 39.94095642320049, 40.354863399595345, 40.76456794815812, 41.17019553026194, 41.57186548616745, 41.96969144513694, 42.36378170088218, 42.75423955586159, 43.141163637528365, 43.52464818927317, 43.90478333849286, 44.28165534394576, 44.65534682431657, 45.02593696970669, 45.393501737583534, 45.758114034562226, 46.119843885251825, 46.47875858927387, 46.8349228674501, 47.18839899805884, 47.53924694397252, 47.88752447141114, 48.233287260977775, 48.57658901158047, 48.91748153778974, 49.25601486113143, 49.59223729577039, 49.92619552900061, 50.25793469692125, 50.58749845564614, 50.91492904836459, 51.24026736854522, 51.563553019550554, 51.884824370908305, 52.2041186114659, 52.52147179963638, 52.83691891092818, 53.15049388293584, 53.462229657955724, 53.77215822337802, 54.08031064999535, 54.38671712835772, 54.6914070032944, 54.99440880671417, 55.29575028878802, 55.59545844761063, 55.89355955743023, 56.19007919553059, 56.48504226784291, 56.77847303336011, 57.070395127421364, 57.36083158393017, 57.649804856564785, 57.93733683903672], [0.0, 5.827306410340888, 8.241055757607759, 10.093190773982231, 11.654612820681775, 13.030253259242508, 14.273927280184665, 15.417603575134498, 16.482111515215518, 17.481919231022662, 18.42756088037698, 19.326988901533525, 20.186381547964462, 21.01065206032407, 21.80378407524712, 22.56906068049798, 23.30922564136355, 24.026599842674372, 24.72316727282328, 25.40063975572269, 26.060506518485017, 26.704072723088515, 27.332489824382996, 27.946779778715115, 28.54785456036933, 29.13653205170444, 29.71354909801251, 30.27957232194669, 30.835207150268996, 31.381005401357047, 31.917471704381597, 32.445068962786934, 32.964223030431036, 33.47532673477588, 33.97874335522137, 34.47480964414452, 34.963838462045324, 35.44612108538818, 35.92192923549625, 36.391516868633, 36.85512176075396, 37.312966915001546, 37.76526181558921, 38.212203548081334, 38.65397780306705, 39.09075977772753, 39.52271498771308, 39.95, 40.372763095928924, 40.79114487238621, 41.2052787880388, 41.615291660638405, 42.02130412064814, 42.423431025790464, 42.821781840553996, 43.216460984212944, 43.60756815049424, 43.995198601665614, 44.37944343950248, 44.760389855317385, 45.13812136099596, 45.51271800277369, 45.884256559303644, 46.25281072540349, 46.6184512827271, 46.981246258480624, 47.341261073190694, 47.69855867843388, 48.053199685348744, 48.40524248467309, 48.75474335897996, 49.10175658772301, 49.44633454564656, 49.788527795065406, 50.12838517247488, 50.46595386991115, 50.80127951144538, 51.13440622516312, 51.46537671095005, 51.79423230437922, 52.121013036970034, 52.44575769306799, 52.76850386357378, 53.089287996732445, 53.40814544617703, 53.72511051640564, 54.040216505857934, 54.35349574774377, 54.66497964876599, 54.97469872586843, 55.28268264113094, 55.58896023492435, 55.89355955743023, 56.196507898623025, 56.49783181680515, 56.79755716577959, 57.09570912073866, 57.39231220294231, 57.68739030325432, 57.980966704600576, 58.27306410340888, 58.563704630086384], [0.0, 5.888972745734184, 8.328265125462806, 10.200000000000003, 11.777945491468367, 13.16814337710522, 14.424978336205571, 15.580757362849859, 16.656530250925613, 17.66691823720255, 18.62256695517565, 19.5315129982293, 20.400000000000006, 21.232993194554556, 22.034518374586725, 22.807893370497858, 23.555890982936734, 24.280856657045696, 24.98479537638842, 25.669437079920556, 26.33628675421044, 26.98666337285883, 27.62173057576227, 28.24252113392146, 28.849956672411142, 29.444863728670917, 30.027986945514684, 30.60000000000001, 31.161514725699718, 31.713088780501977, 32.25523213371747, 32.78841258737605, 33.313060501851226, 33.82957286162509, 34.33831679043107, 34.83963260426264, 35.3338364744051, 35.82122275969932, 36.30206605690647, 36.776623009732695, 37.2451339103513, 37.70782412179202, 38.16490534509421, 38.61657675144186, 39.0630259964586, 39.50443013131566, 39.9409564232005, 40.372763095928924, 40.80000000000001, 41.22280922013929, 41.64132562731403, 42.05567738130015, 42.46598638910911, 42.87236872392288, 43.274935008616715, 43.67379076746144, 44.06903674917345, 44.46076922411488, 44.849080258127934, 45.23405796521024, 45.615786740995716, 45.99434747879353, 46.36981776975191, 46.742272088549576, 47.11178196587347, 47.478416148814404, 47.84224075019899, 48.20331938777662, 48.56171331409139, 48.91748153778975, 49.270680937044105, 49.62136636570985, 49.96959075277684, 50.31540519562573, 50.65885904755456, 51.00000000000001, 51.33887415984111, 51.67552612214027, 52.00999903864641, 52.34233468235823, 52.67257350842088, 53.000754711607655, 53.326916280617624, 53.6510950494023, 53.97332674571766, 54.29364603708247, 54.612086574310645, 54.92868103277195, 55.24346115152454, 55.55645777045186, 55.86770086552695, 56.17721958231825, 56.48504226784292, 56.791196500866235, 57.09570912073867, 57.398606254856055, 57.699913344822285, 57.999655171388746, 58.297855878239645, 58.5945389946879, 58.889727457341834, 59.18344363079933], [0.0, 5.95, 8.414570696119915, 10.30570230503482, 11.9, 13.30460446612375, 14.57446396955991, 15.742220300834315, 16.82914139223983, 17.85, 18.815552078001858, 19.73391750261463, 20.61140461006964, 21.45303008901074, 22.26286145130495, 23.044250909934128, 23.8, 24.532478472425083, 25.243712088359747, 25.93544871406701, 26.6092089322475, 27.266325384987248, 27.907973770949408, 28.535197563710682, 29.14892793911982, 29.75, 30.339166105877073, 30.917106915104462, 31.48444060166863, 32.0417306024503, 32.58949217155738, 33.12819795883863, 33.65828278447966, 34.18014774690128, 34.69416377432954, 35.200674709442715, 35.7, 36.19243705527441, 36.67826331766541, 37.157738090470474, 37.631104156003715, 38.09858921272545, 38.560407155526775, 39.0167592195969, 39.46783500522926, 39.913813398371246, 40.35486339959535, 40.79114487238621, 41.22280922013928, 41.65, 42.072853480599576, 42.49149914982996, 42.90606017802148, 43.31665384121909, 43.72339190867973, 44.12638099821919, 44.5257229026099, 44.92151488986096, 45.31384997989026, 45.70281719981821, 46.088501819868256, 46.47098557164459, 46.85034685037027, 47.22666090250294, 47.6, 47.97043360237637, 48.338028507583964, 48.70284899264108, 49.06495694485017, 49.42441198436255, 49.7812715787775, 50.135591150399335, 50.48742417671949, 50.83682228463931, 51.18383533890363, 51.5285115251741, 51.87089742813402, 52.21103810498313, 52.54897715465069, 52.884756783027754, 53.218417864495, 53.550000000000004, 53.879541571917635, 54.20707979590858, 54.532650769974495, 54.85628952089268, 55.17803004819944, 55.49790536587845, 55.815947541898815, 56.132187735736785, 56.44665623400557, 56.75938248430827, 57.070395127421364, 57.37972202790809, 57.68739030325432, 57.99342635161334, 58.29785587823964, 58.600703920686826, 58.90199487283941, 59.20175250784389, 59.5, 59.79675994566931], [0.0, 6.0104076400856545, 8.5, 10.410331406828508, 12.020815280171309, 13.439680055715614, 14.722431864335457, 15.902043893789253, 17.0, 18.031222920256962, 19.00657780874821, 19.93426697924958, 20.820662813657016, 21.670832932769336, 22.48888614404902, 23.27820869396956, 24.041630560342618, 24.78154555309253, 25.5, 26.198759512618153, 26.87936011143123, 27.543147968233406, 28.1913107180209, 28.824902428282392, 29.444863728670914, 30.05203820042827, 30.647185841443914, 31.230994220485524, 31.804087787578506, 32.367035699921615, 32.920358442763046, 33.4645334645502, 34.0, 34.527163219702835, 35.04639781775012, 35.558051127698214, 36.062445840513924, 36.55988238493117, 37.05064102009573, 37.53498368189335, 38.01315561749642, 38.48538683708402, 38.95189340712465, 39.41287860585674, 39.86853395849916, 40.31904016714684, 40.764567948158124, 41.2052787880388, 41.64132562731403, 42.07285348059958, 42.5, 42.92289598803884, 43.34166586553867, 43.756428099194764, 44.16729559300637, 44.57437604723144, 44.97777228809804, 45.377582571133075, 45.77390086064329, 46.16681708760091, 46.55641738793912, 46.942784323045856, 47.32599708405518, 47.70613168136776, 48.083261120685236, 48.457455566713364, 48.82878249557325, 49.19730683685846, 49.56309110618506, 49.92619552900061, 50.286678156346746, 50.64459497320519, 51.0, 51.352945387776934, 51.70348150753487, 52.051657034142536, 52.397519025236306, 52.74111299546115, 53.08248298638639, 53.421671632400276, 53.75872022286246, 54.09366876077089, 54.42655601817922, 54.75741958858178, 55.08629593646681, 55.41322044422252, 55.73822745656701, 56.06135032265991, 56.3826214360418, 56.70207227253692, 57.01973342624464, 57.335634643736185, 57.649804856564785, 57.962272212189895, 58.27306410340888, 58.58220719638344, 58.88972745734183, 59.195650178032515, 59.5, 59.802800937748735, 60.10407640085654, 60.40384921509557], [0.0, 6.070214164261423, 8.584579197607768, 10.513919345325036, 12.140428328522846, 13.573411509270619, 14.868927331855517, 16.06027708353751, 17.169158395215536, 18.21064249278427, 19.195702644081567, 20.13262277995592, 21.02783869065007, 21.88646842229235, 22.712661667008557, 23.509838366096865, 24.280856657045693, 25.028134169370283, 25.753737592823303, 26.45945010766475, 27.146823018541237, 27.817215892321073, 28.47182818155519, 29.11172444222431, 29.737854663711033, 30.35107082130712, 30.952140475256318, 31.54175803597511, 32.12055416707502, 32.68910368915, 33.24793226653351, 33.79752209852078, 34.33831679043107, 34.870725544502235, 35.39512678321693, 35.91187129627194, 36.42128498556854, 36.92367126925491, 37.419313195193745, 37.90847530566219, 38.391405288163135, 38.8683354415905, 39.33948398238087, 39.805056211491525, 40.26524555991184, 40.72023452781185, 41.17019553026195, 41.615291660638405, 42.05567738130014, 42.49149914982996, 42.92289598803883, 43.35000000000001, 43.7729368445847, 44.19182616729027, 44.60678199556655, 45.01791310134223, 45.425323334017115, 45.82911192680915, 46.229373779016306, 46.62619971646842, 47.01967673219373, 47.40988820910676, 47.79691412633247, 48.18083125061253, 48.561713314091385, 48.93963117964826, 49.31465299482498, 49.68684433529665, 50.056268338740566, 50.42298582987724, 50.78705543738484, 51.14853370332331, 51.507475185646605, 51.86393255432913, 52.217956681586074, 52.56959672662518, 52.9189002153295, 53.265913115237225, 53.61067990615304, 53.9532436466984, 54.293646037082475, 54.63192747835281, 54.96812712836414, 55.302282954684614, 55.634431784642146, 55.96460935269718, 56.29285034531473, 56.61918844349503, 56.94365636311038, 57.26628589318501, 57.587107932244706, 57.906152522853745, 58.22344888444862, 58.53902544456989, 58.85290986858679, 59.16512908800251, 59.47570932742207, 59.78467613025934, 60.09205438325437, 60.39786833986777, 60.70214164261424, 61.004897344393605], [0.0, 6.129437168288782, 8.668333173107735, 10.616496597277278, 12.258874336577565, 13.705838172107537, 15.01399347275734, 16.216966424088078, 17.33666634621547, 18.388311504866348, 19.382982226685346, 20.32904326327238, 21.232993194554556, 22.1, 22.93425385749447, 23.7392080744072, 24.51774867315513, 25.27231687044146, 26.004999519323203, 26.717597197352912, 27.411676344215074, 28.088609791159122, 28.7496086929892, 29.395747991843994, 30.02798694551468, 30.64718584144391, 31.254119728445403, 31.849489791831836, 32.433932848176156, 33.008029326210924, 33.57231001882355, 34.12726182980405, 34.67333269243094, 35.21093580125357, 35.74045327076869, 36.26223931309262, 36.776623009732695, 37.28391073908423, 37.78438831051788, 38.27832284727219, 38.76596445337069, 39.24754769409167, 39.723292914862945, 40.19340741962542, 40.65808652654476, 41.11751451632261, 41.571865486167454, 42.02130412064814, 42.46598638910911, 42.90606017802148, 43.34166586553867, 43.7729368445847, 44.2, 44.62297614458275, 45.04198041827202, 45.45712265421119, 45.86850771498894, 46.27623580197508, 46.68040274033634, 47.08110024202918, 47.4784161488144, 47.87243465711766, 48.263236526366526, 48.65089927226423, 49.03549734631026, 49.41710230274535, 49.79578295398116, 50.1716055154706, 50.54463374088292, 50.91492904836459, 51.28255063859442, 51.647555605275265, 52.009999038646406, 52.36993412254784, 52.727412225520794, 53.08248298638639, 53.435194394705825, 53.78559286649168, 54.13372331550824, 54.479629220471026, 54.82335268843015, 55.16493451459904, 55.50441423886934, 55.841830199233264, 56.177219582318244, 56.510618471221854, 56.84206189082166, 57.17158385072081, 57.4992173859784, 57.824994595762824, 58.14894668005604, 58.47110397452746, 58.79149598368799, 59.11015141242662, 59.42709819602502, 59.74236352873897, 60.05597389102936, 60.36795507552, 60.678332211754146, 60.98712978981714, 61.29437168288782, 61.600081168777706], [0.0, 6.188093405888441, 8.751285619838951, 10.71809218098072, 12.376186811776883, 13.836997506684753, 15.157671325107957, 16.372156241619493, 17.502571239677902, 18.564280217665324, 19.56846953647628, 20.523583995004383, 21.43618436196144, 22.31148807229137, 23.1537254021896, 23.966382705781864, 24.752373623553765, 25.514162733666183, 26.253856859516855, 26.973273809458135, 27.673995013369506, 28.357406439940874, 29.02473083423859, 29.677053425163358, 30.315342650215914, 30.940467029442207, 31.55320902856, 32.154276542942156, 32.744312483238986, 33.32390283265153, 33.89358346354071, 34.45384593916912, 35.005142479355804, 35.54789023275503, 36.082474970544915, 36.60925429450865, 37.12856043533065, 37.640702703323704, 38.145969642938695, 38.64463093367564, 39.13693907295256, 39.62313087074266, 40.103428781090535, 40.57804209175204, 41.04716799000877, 41.51099252005426, 41.96969144513694, 42.42343102579046, 42.87236872392288, 43.31665384121909, 43.75642809919476, 44.191826167290266, 44.62297614458274, 45.05000000000001, 45.47301397532387, 45.8921289547565, 46.3074508043792, 46.71908068444841, 47.12711533713898, 47.53164735205377, 47.93276541156373, 48.3305545178203, 48.725096203086146, 49.11646872485848, 49.50474724710753, 49.89000400881924, 50.27230848091224, 50.65172751249458, 51.028325467332365, 51.402164351318916, 51.77330393165962, 52.14180184842101, 52.50771371903371, 52.87109323628556, 53.231992260294, 53.590460904903594, 53.94654761891627, 54.3002992625271, 54.65176117930694, 55.00097726404505, 55.34799002673901, 55.692840652995976, 56.035569061088346, 56.37621395588746, 56.71481287988175, 57.05140226146945, 57.38601746070205, 57.71869281264087, 58.04946166847718, 58.378356434555435, 58.70540860942883, 59.030648819066876, 59.354106850326716, 59.675811682791554, 59.99579151907241, 60.3140738136631, 60.63068530043183, 60.94565201882741, 61.258999338872655, 61.57075198501315, 61.880934058884414, 62.18956906105719], [0.0, 6.246198844097105, 8.833459118601274, 10.818733752154179, 12.49239768819421, 13.966925216381737, 15.3, 16.525888780940047, 17.666918237202548, 18.738596532291314, 19.752215065657825, 20.7162979318217, 21.637467504308358, 22.52099020913601, 23.37113604427478, 24.191424100288103, 24.98479537638842, 25.753737592823303, 26.500377355803824, 27.226549542679848, 27.933850432763474, 28.623679008820652, 29.297269497343947, 29.955717317400367, 30.6, 31.230994220485524, 31.849489791831836, 32.456201256462535, 33.051777561880094, 33.63681019359595, 34.211840055746784, 34.777363327313935, 35.333836474405096, 35.881680562649244, 36.42128498556854, 36.95301070278307, 37.47719306458263, 37.99414428566592, 38.50415561988083, 39.00749927898481, 39.50443013131565, 39.995187210463214, 40.47999505928824, 40.95906493073297, 41.4325958636434, 41.90077564914521, 42.363781700882186, 42.821781840553996, 43.274935008616715, 43.72339190867973, 44.16729559300637, 44.60678199556656, 45.04198041827202, 45.47301397532388, 45.9, 46.323050417691626, 46.74227208854956, 47.15776712271267, 47.56963317075296, 47.97796369167828, 48.382848200576205, 48.78437249775793, 49.182618881064066, 49.57766634282014, 49.96959075277684, 50.358465028235315, 50.74435929243762, 51.12734102219673, 51.507475185646605, 51.884824370908305, 52.259448906393956, 52.63140697340325, 53.00075471160765, 53.36754631796369, 53.731834139548965, 54.09366876077089, 54.453099085359696, 54.81017241352193, 55.16493451459904, 55.517429695546966, 55.86770086552695, 56.21578959687394, 56.56173618268804, 56.90557969127456, 57.247358017641304, 57.5871079322447, 57.924865127162796, 58.2606642598589, 58.594538994687895, 58.926522042285846, 59.25664519697348, 59.584939372294414, 59.911434634800735, 60.23616023619036, 60.55914464389338, 60.88041557019795, 61.2, 61.51792421725558, 61.834213830208924, 62.148893795465106, 62.46198844097105, 62.773521487964985], [0.0, 6.303768714031314, 8.914875209446288, 10.918447691865362, 12.607537428062628, 14.09565535901045, 15.441016805897208, 16.6782043397963, 17.829750418892576, 18.91130614209394, 19.934266979249575, 20.907235589623035, 21.836895383730724, 22.728561327105595, 23.586542773369732, 24.41439124778662, 25.215074856125256, 25.991104247415116, 26.744625628338866, 27.477490787915844, 28.1913107180209, 28.88749729554293, 29.56729612257435, 30.23181271442386, 30.882033611794416, 31.51884357015657, 32.14303968202137, 32.75534307559608, 33.3564086795926, 33.946833431116964, 34.527163219702835, 35.09789879750639, 35.65950083778515, 36.21239428703935, 36.75697212774742, 37.29359864641652, 37.82261228418788, 38.344328133375875, 38.859040132252375, 39.367023001492, 39.86853395849915, 40.363814239984805, 40.85309045837292, 41.336575813678614, 41.81447117924607, 42.28696607703135, 42.754239555861595, 43.21646098421295, 43.67379076746145, 44.1263809982192, 44.57437604723144, 45.01791310134223, 45.45712265421119, 45.89212895475651, 46.323050417691626, 46.75, 47.173085546739465, 47.59241010917602, 48.00807223790599, 48.42016625332879, 48.82878249557324, 49.23400755575357, 49.635924490231865, 50.03461301938889, 50.43014971225051, 50.822608158180934, 51.21205912673304, 51.598570716639045, 51.98220849483023, 52.3630356262889, 52.74111299546115, 53.11649931989118, 53.48925125667773, 53.85942350229902, 54.22706888630437, 54.5922384593268, 54.95498157583169, 55.315345971981415, 55.673377838963575, 56.02912189210179, 56.3826214360418, 56.733918426281825, 57.08305352729478, 57.43006616747015, 57.77499459108586, 58.11787590750371, 58.45874613776796, 58.79764025877229, 59.1345922451487, 59.46963510902013, 59.80280093774873, 60.13412092980158, 60.46362542884772, 60.79134395619166, 61.117305241641674, 61.441537252904084, 61.76406722358883, 62.084921679905506, 62.40412646612402, 62.721706768869105, 63.03768714031314, 63.352091520327896], [0.0, 6.3608175575157, 8.995554457619608, 11.017259187293364, 12.7216351150314, 14.223220451079285, 15.580757362849855, 16.829141392239833, 17.991108915239217, 19.082452672547102, 20.114671262538693, 21.096445198184455, 22.034518374586728, 22.934253857494472, 23.799999999999997, 24.635340468522042, 25.4432702300628, 26.226322654920573, 26.986663372858825, 27.726160931510154, 28.44644090215857, 29.14892793911982, 29.834878917133217, 30.505409356374816, 31.16151472569971, 31.804087787578503, 32.433932848176156, 33.05177756188009, 33.65828278447967, 34.25405085533681, 34.83963260426263, 35.41553331519942, 35.98221783047843, 36.540114942347955, 37.08962118976143, 37.631104156003715, 38.164905345094205, 38.69134270091955, 39.21071282188071, 39.72329291486294, 40.229342525077385, 40.7291050724172, 41.22280922013928, 41.71067009771001, 42.19289039636891, 42.66966135323785, 43.14116363752837, 43.607568150494245, 44.069036749173456, 44.5257229026099, 44.97777228809804, 45.42532333401712, 45.868507714988944, 46.30745080437921, 46.74227208854956, 47.173085546739465, 47.599999999999994, 48.02311943220682, 48.44254328583502, 48.8583667348797, 49.270680937044084, 49.67957326708835, 50.08512753303119, 50.48742417671949, 50.8865404601256, 51.2825506385944, 51.675526122140255, 52.06553562578608, 52.452645309841145, 52.83691891092818, 53.218417864495, 53.597201419477116, 53.97332674571765, 54.34684903469566, 54.71782159406567, 55.08629593646681, 55.45232186302031, 55.815947541898815, 56.177219582318244, 56.53618310427402, 56.89288180431714, 57.247358017641304, 57.59965277673122, 57.949805866801654, 58.29785587823964, 58.643840256245156, 58.9877953478514, 59.3297564464915, 59.669757834266434, 60.00783282205748, 60.344013787616085, 60.678332211754146, 61.01081871274963, 61.34150307907363, 61.670414300537985, 61.99758059795559, 62.32302945139942, 62.64678762714015, 62.968881203337254, 63.28933559455337, 63.608175575157006, 63.92542530167477], [0.0, 6.417359269980137, 9.075516514226615, 11.11519230602872, 12.834718539960274, 14.349651563714014, 15.71925570757089, 16.978736702122454, 18.15103302845323, 19.252077809940413, 20.293471856732648, 21.283972843433155, 22.23038461205744, 23.138117900987538, 24.011559716103406, 24.854325579262856, 25.66943707992055, 26.45945010766475, 27.226549542679845, 27.97262054223737, 28.699303127428028, 29.40803461641053, 30.100083056363818, 30.776573883393844, 31.43851141514178, 32.08679634990069, 32.72224014336427, 33.34557691808615, 33.95747340424491, 34.558537295435414, 35.149324317830065, 35.7303442468723, 36.30206605690646, 36.86492235174246, 37.41931319519374, 37.9656094380164, 38.50415561988083, 39.035272510897116, 39.559259345948334, 40.07639579602937, 40.586943713465296, 41.09114868192419, 41.58924139726524, 42.08143890125431, 42.56794568686631, 43.048954691142036, 43.52464818927317, 43.995198601665614, 44.46076922411488, 44.921514889860966, 45.37758257113307, 45.82911192680915, 46.276235801975076, 46.719080684448414, 47.15776712271267, 47.59241010917602, 48.02311943220681, 48.45, 48.873152138981176, 49.292671869153125, 49.70865115852571, 50.12117815853893, 50.530337422186285, 50.93621010636736, 51.3388741598411, 51.738404498012876, 52.134873165665226, 52.52834948863328, 52.9189002153295, 53.30658964893553, 53.691479771002776, 54.073630357134334, 54.45309908535969, 54.82994163775847, 55.20421179584036, 55.57596153014359, 55.94524108447474, 56.31209905517642, 56.67658246577682, 57.0387368373459, 57.398606254856055, 57.756233429821236, 58.11165975946652, 58.464925382659985, 58.81606923282106, 59.16512908800251, 59.512141618328606, 59.85714243095806, 60.200166112727636, 60.54124627062115, 60.88041557019794, 61.21770577210486, 61.55314776678769, 61.88677160750915, 62.21860654177334, 62.54868104124978, 62.87702283028356, 63.20365891307244, 63.5286155995863, 63.85191853029947, 64.17359269980138, 64.49366247934755], [0.0, 6.473407139984323, 9.154780172128657, 11.212270064531983, 12.946814279968645, 14.474978411037442, 15.856544390250987, 17.127025427668404, 18.309560344257314, 19.420221419952966, 20.470710783946902, 21.469862598535652, 22.424540129063967, 23.34020137016817, 24.22127164291751, 25.071398046379464, 25.89362855993729, 26.69054139578289, 27.46434051638597, 28.21692754358632, 28.949956822074885, 29.664878223245754, 30.36297086913598, 31.04537002517445, 31.713088780501973, 32.367035699921615, 33.008029326210924, 33.63681019359595, 34.25405085533681, 34.8603643124968, 35.45631114484416, 36.042405580094126, 36.61912068851463, 37.18689285218652, 37.74612562899669, 38.297193108633955, 38.84044283990593, 39.3761983944616, 39.904761620638716, 40.42641463202, 40.941421567893805, 41.45003015680447, 41.952473109460435, 42.448969363224826, 42.939725197071304, 43.42493523311233, 43.90478333849286, 44.37944343950249, 44.849080258127934, 45.31384997989026, 45.77390086064329, 46.229373779016306, 46.68040274033634, 47.12711533713899, 47.56963317075296, 48.00807223790599, 48.44254328583502, 48.873152138981176, 49.300000000000004, 49.72318372751286, 50.14279609275893, 50.55892601707438, 50.971658791920824, 51.381076283005214, 51.78725711987458, 52.19027687222975, 52.59020821407727, 52.987121076729586, 53.38108279156578, 53.77215822337802, 54.16040989505158, 54.54589810425712, 54.92868103277194, 55.308814848991304, 55.68635380414128, 56.06135032265991, 56.43385508717264, 56.803917118452325, 57.171583850720815, 57.536901202619525, 57.89991364414977, 58.260664259858906, 58.61919480852668, 58.97554577958562, 59.32975644649151, 59.68186491724266, 60.03190818223256, 60.37992215960534, 60.72594173827196, 61.070000818732595, 61.41213235184071, 61.75236837563399, 62.0907400503489, 62.42727769172704, 62.762010802714094, 63.094968103645165, 63.426177561003946, 63.75566641483721, 64.0834612049006, 64.40958779560697, 64.73407139984323, 65.05693660171836], [0.0, 6.528973885688317, 9.233363417520183, 11.30851449130256, 13.057947771376634, 14.599229431720019, 15.992654563892762, 17.27404121796634, 18.466726835040365, 19.586921657064952, 20.6464282625349, 21.654156644856894, 22.61702898260512, 23.54055012101459, 24.42918336743985, 25.286607127093976, 26.115895542753268, 26.919648957592297, 27.70009025256055, 28.45913737273145, 29.198458863440038, 29.91951704155667, 30.623602008908097, 31.311858775869567, 31.985309127785523, 32.64486942844158, 33.29136524686243, 33.92554347390768, 34.54808243593268, 35.15960039590894, 35.760662745536465, 36.351788126583266, 36.93345367008073, 37.50609950394736, 38.07013265014977, 38.625930409506, 39.173843314129904, 39.714197713160466, 40.24729804595583, 40.773428847718954, 41.2928565250698, 41.805830933016985, 42.31258677982239, 42.81334488217429, 43.30831328971379, 43.79768829516005, 44.281655343945765, 44.76038985531739, 45.23405796521024, 45.70281719981822, 46.16681708760091, 46.62619971646843, 47.08110024202918, 47.531647352053774, 47.97796369167828, 48.42016625332878, 48.8583667348797, 49.292671869153125, 49.72318372751286, 50.14999999999999, 50.57321425418795, 50.992916174700184, 51.40919178512729, 51.82212365389902, 52.231791085506536, 52.638270298329516, 53.04163459019716, 53.441954492701704, 53.839297915184595, 54.23373027922752, 54.62531464440274, 55.01411182596698, 55.4001805051211, 55.783577332401336, 56.16435702471808, 56.5425724565128, 56.9182747454629, 57.29151333312815, 57.66233606089854, 58.03078924157416, 58.396917726880076, 58.76076497119485, 59.12237309174929, 59.481782925531064, 59.83903408311334, 60.19416499960773, 60.547212982927626, 60.89821425953309, 61.247204017816195, 61.594216449273866, 61.939284787604706, 62.28244134585606, 62.623717551739134, 62.963143981221265, 63.30075039049695, 63.63656574643229, 63.97061825557105, 64.30293539178442, 64.63354392264128, 64.96246993457069, 65.28973885688316, 65.61537548471395], [0.0, 6.5840716885526085, 9.311283477587823, 11.403946685248927, 13.168143377105217, 14.722431864335457, 16.12761606685873, 17.419816302131316, 18.622566955175646, 19.752215065657825, 20.820662813657012, 21.836895383730717, 22.807893370497855, 23.7392080744072, 24.635340468522042, 25.499999999999996, 26.336286754210434, 27.14682301854123, 27.933850432763467, 28.699303127428024, 29.444863728670914, 30.17200689380804, 30.882033611794416, 31.576098555711408, 32.25523213371746, 32.92035844276304, 33.57231001882355, 34.211840055746784, 34.83963260426263, 35.45631114484416, 36.06244584051392, 36.6585597098413, 37.24513391035129, 37.82261228418788, 38.39140528816313, 38.951893407124636, 39.50443013131565, 40.04934456392514, 40.586943713465296, 41.1175145163226, 41.641325627314025, 42.15862900996663, 42.669661353237856, 43.17464533728099, 43.67379076746143, 44.167295593006365, 44.655346824316574, 45.13812136099596, 45.61578674099571, 46.088501819868256, 46.55641738793911, 47.01967673219372, 47.4784161488144, 47.932765411563736, 48.3828482005762, 48.828782495573236, 49.270680937044084, 49.70865115852571, 50.14279609275892, 50.573214254187945, 50.99999999999999, 51.42324377166418, 51.84303231872147, 52.25944890639395, 52.67257350842087, 53.082482986386374, 53.489251256677726, 53.892949446101014, 54.29364603708246, 54.6914070032944, 55.08629593646681, 55.47837416507444, 55.867700865526935, 56.25433316643261, 56.63832624645611, 57.019733426244635, 57.39860625485605, 57.77499459108586, 58.148946680056035, 58.52050922539891, 58.88972745734183, 59.25664519697347, 59.62130491695062, 59.98374779888298, 60.34401378761608, 60.70214164261422, 61.058168986631095, 61.412132351840704, 61.76406722358883, 62.11400808191336, 62.461988440971034, 62.80804088649796, 63.152197111422815, 63.494487949742535, 63.834943408763195, 64.17359269980136, 64.51046426743493, 64.84558581738621, 65.17898434311476, 65.51068615119216, 65.84071688552608, 66.16910155049712], [0.0, 6.638712224520656, 9.388556864609171, 11.498586869698382, 13.277424449041312, 14.844611817087035, 16.261457499252643, 17.564381571806052, 18.777113729218343, 19.91613667356197, 20.993451359888397, 22.018117539880652, 22.997173739396764, 23.93621732855883, 24.839786633544175, 25.711621885832095, 26.554848898082625, 27.372111719777852, 28.165670593827514, 28.937475701933646, 29.68922363417407, 30.422401285894576, 31.138320442824146, 31.83814536055767, 32.522914998505286, 33.193561122603285, 33.850923177957796, 34.49576060909514, 35.128763143612105, 35.75055943618226, 36.36172438155264, 36.96278533877013, 37.554227458436685, 38.13649826609675, 38.710011624901384, 39.27515117730293, 39.83227334712394, 40.38170996874699, 40.92377059851646, 41.45874455407448, 41.98690271977679, 42.50849915016996, 43.0237724984688, 43.53294729282638, 44.036235079761305, 44.5338354512611, 45.0259369697067, 45.51271800277369, 45.99434747879353, 46.4709855716446, 46.942784323045856, 47.40988820910676, 47.87243465711766, 48.3305545178203, 48.78437249775792, 49.23400755575357, 49.67957326708835, 50.12117815853893, 50.55892601707437, 50.992916174700184, 51.42324377166419, 51.849999999999994, 52.273272329174105, 52.69314471541816, 53.10969779616525, 53.52300907086595, 53.93315306933204, 54.34020150864367, 54.744223439555704, 55.145285383249224, 55.543451459195445, 55.938783504827846, 56.33134118765503, 56.72118211038977, 57.1083619096188, 57.4929343484919, 57.87495140386729, 58.2544633483135, 58.63151882733382, 59.00616493214925, 59.37844726834814, 59.74841002068591, 60.11609601429554, 60.481546772548725, 60.84480257178915, 61.20590249314195, 61.564884471588186, 61.92178534247862, 62.27664088564829, 62.62948586728139, 62.98035407966519, 63.3292783789615, 63.67629072111534, 64.02142219601186, 64.36470305998468, 64.70616276677207, 65.04582999701057, 65.38373268634945, 65.7198980522642, 66.05435261964196, 66.38712224520657, 66.71823214084739], [0.0, 6.692906692910039, 9.465199416811037, 11.592454442437978, 13.385813385820079, 14.965794332410159, 16.394206293688022, 17.70776665759971, 18.930398833622075, 20.078720078730118, 21.164829316580843, 22.19786025724101, 23.184908884875956, 24.131618263183263, 25.042563766515595, 25.92151615936074, 26.771626771640157, 27.595561237271475, 28.39559825043311, 29.173703912941875, 29.931588664820318, 30.670751539536816, 31.39251503145296, 32.09805290044865, 32.788412587376044, 33.46453346455019, 34.12726182980404, 34.777363327313935, 35.41553331519942, 36.042405580094126, 36.6585597098413, 37.264527368531056, 37.86079766724415, 38.447821784855385, 39.02601696304659, 39.595769976097195, 40.157440157460236, 40.71136205041536, 41.257847738339436, 41.797188900690436, 42.329658633161685, 42.855513064248804, 43.37499279538846, 43.88832418764699, 44.39572051448202, 44.89738299723047, 45.39350173758354, 45.88425655930365, 46.36981776975191, 46.85034685037027, 47.32599708405518, 47.79691412633247, 48.263236526366526, 48.72509620308615, 49.182618881064066, 49.635924490231865, 50.08512753303119, 50.530337422186285, 50.971658791920824, 51.40919178512729, 51.84303231872148, 52.273272329174105, 52.69999999999999, 53.12329997279913, 53.543253543280315, 53.959938843553175, 54.373431011846215, 54.78380235069486, 55.19112247454295, 55.59545844761063, 55.996874912802056, 56.39543421235446, 56.79119650086622, 57.18421985128415, 57.57456035437873, 57.96227221218989, 58.34740782588375, 58.73001787842398, 59.11015141242662, 59.48785590353715, 59.863177329640635, 60.23616023619035, 60.60684779791802, 60.975281877167234, 61.34150307907363, 61.70555080379722, 62.06746329599752, 62.427277691727035, 62.78503006290592, 63.14075545952866, 63.494487949742535, 63.84626065792734, 64.1961058008973, 64.54405472233674, 64.89013792557387, 65.23438510478964, 65.57682517475209, 65.91748629916042, 66.25639591767725, 66.59358077172304, 66.92906692910039, 67.26287980751346], [0.0, 6.746665843214706, 9.541226336273551, 11.685568022137394, 13.493331686429412, 15.086003446904023, 16.525888780940043, 17.85, 19.082452672547102, 20.239997529644118, 21.334830676618928, 22.37615918784991, 23.371136044274788, 24.325449636132117, 25.243712088359743, 26.129724453196975, 26.986663372858825, 27.817215892321073, 28.623679008820652, 29.408034616410532, 30.172006893808046, 30.91710691510446, 31.644667797276686, 32.35587272814628, 33.05177756188009, 33.73332921607353, 34.40138078624171, 35.05670406641218, 35.7, 36.33190746437627, 36.95301070278307, 37.563845649773405, 38.164905345094205, 38.7566445916052, 39.33948398238086, 39.913813398371246, 40.479995059288235, 41.03836619554926, 41.58924139726523, 42.13291468673869, 42.669661353237856, 43.19973958254842, 43.72339190867974, 44.24084651088855, 44.75231837569982, 45.25801034071206, 45.758114034562226, 46.25281072540349, 46.742272088549576, 47.22666090250294, 47.70613168136775, 48.18083125061253, 48.65089927226423, 49.11646872485848, 49.57766634282013, 50.034613019388885, 50.487424176719486, 50.936210106367355, 51.38107628300521, 51.82212365389901, 52.25944890639395, 52.69314471541815, 53.123299972799124, 53.550000000000004, 53.97332674571765, 54.393358969638925, 54.81017241352193, 55.22383996065468, 55.634431784642146, 56.04201548838158, 56.44665623400558, 56.84841686450028, 57.247358017641304, 57.64353823283231, 58.03701405137931, 58.427840110686965, 58.816069232821064, 59.20175250784389, 59.584939372294414, 59.96567768315472, 60.34401378761609, 60.71999258893236, 61.0936576086258, 61.46505104528914, 61.83421383020892, 62.20118568001739, 62.56600514656502, 62.928709664190634, 63.28933559455337, 63.64791826917829, 64.00449202985678, 64.35909026703222, 64.71174545629256, 65.06248919308268, 65.41135222574137, 65.7583644869609, 66.10355512376017, 66.44695252605646, 66.78858435391486, 67.12847756354974, 67.46665843214706, 67.8031525815725], [0.0, 6.800000000000001, 9.616652224137047, 11.777945491468367, 13.600000000000001, 15.205262246998572, 16.65653025092561, 17.991108915239217, 19.233304448274094, 20.400000000000002, 21.50348808914498, 22.55304857441672, 23.555890982936734, 24.51774867315513, 25.4432702300628, 26.336286754210434, 27.200000000000003, 28.037118254200095, 28.84995667241114, 29.640512816076583, 30.410524493997144, 31.161514725699714, 31.894827166799324, 32.61165435852649, 33.31306050185122, 34.0, 34.67333269243094, 35.3338364744051, 35.98221783047843, 36.619120688514634, 37.2451339103513, 37.86079766724415, 38.46660889654819, 39.0630259964586, 39.650472884948044, 40.22934252507739, 40.800000000000004, 41.3627852060279, 41.91801522018905, 42.46598638910911, 43.00697617828996, 43.541244814543376, 44.069036749173456, 44.5905819652536, 45.10609714883344, 45.61578674099571, 46.11984388525183, 46.6184512827271, 47.11178196587347, 47.6, 48.08326112068523, 48.561713314091385, 49.03549734631026, 49.50474724710754, 49.96959075277683, 50.430149712250504, 50.8865404601256, 51.3388741598411, 51.787257119874575, 52.23179108550653, 52.67257350842087, 53.10969779616525, 53.54325354328031, 53.97332674571766, 54.400000000000006, 54.823352688430134, 55.243461151524535, 55.66039884873266, 56.07423650840019, 56.485042267842914, 56.89288180431714, 57.29781845759924, 57.69991334482228, 58.09922546815922, 58.49581181588986, 58.88972745734183, 59.28102563215317, 59.669757834266434, 60.05597389102937, 60.43972203774601, 60.82104898799429, 61.2, 61.57661893933444, 61.95094833818123, 62.32302945139943, 62.69290230959164, 63.06060576937079, 63.426177561003946, 63.78965433359865, 64.1510716979849, 64.51046426743494, 64.86786569635231, 65.22330871705299, 65.5768251747521, 65.92844606086207, 66.27820154470095, 66.62612100370244, 66.97223305221353, 67.31656556895933, 67.65914572325016, 68.0, 68.33915422362206], [0.0, 6.852919086053767, 9.691491113342673, 11.869604037203601, 13.705838172107534, 15.323592920721955, 16.78615500941177, 18.13111965654631, 19.382982226685346, 20.5587572581613, 21.670832932769333, 22.72856132710559, 23.739208074407202, 24.708551151372674, 25.6412753192972, 26.54124149319319, 27.411676344215067, 28.255309235610923, 29.074473340028018, 29.871181764369485, 30.64718584144391, 31.40402044324898, 32.14303968202136, 32.86544537960805, 33.57231001882354, 34.264595430268834, 34.94316814486059, 35.6088121116108, 36.26223931309262, 36.904098688357095, 37.534983681893344, 38.15543866868785, 38.76596445337069, 39.367023001492, 39.95904153004674, 40.54241606022019, 41.1175145163226, 41.68467943981338, 42.2442303752832, 42.79646597559196, 43.341665865538666, 43.88009229707704, 44.41199162388465, 44.937595618813425, 45.45712265421118, 45.97077876216586, 46.47875858927387, 46.981246258480624, 47.478416148814404, 47.97043360237637, 48.45745556671336, 48.93963117964826, 49.41710230274535, 49.89000400881925, 50.358465028235315, 50.822608158180934, 51.2825506385944, 51.73840449801288, 52.19027687222975, 52.638270298329516, 53.08248298638638, 53.52300907086595, 53.959938843553175, 54.39335896963893, 54.823352688430134, 55.249999999999986, 55.67337783896357, 56.09356023644782, 56.51061847122185, 56.92462121086095, 57.33563464373618, 57.743722602547884, 58.148946680056035, 58.55136633760138, 58.95103900695898, 59.348020186018, 59.74236352873897, 60.134120929801576, 60.52334260432086, 60.91007716297854, 61.29437168288782, 61.6762717744839, 62.05582164470953, 62.43306415674309, 62.80804088649796, 63.180792176103644, 63.55135718456373, 63.91977393577045, 64.28607936404272, 64.65030935734181, 65.012498798308, 65.37268160325075, 65.7308907592161, 66.08715835924556, 66.44151563593353, 66.79399299338226, 67.14462003764709, 67.49342560575808, 67.8404377933987, 68.18568398131679, 68.52919086053767, 68.87098445644581], [0.0, 6.905432643940567, 9.76575649911465, 11.960560187549746, 13.810865287881134, 15.44101680589721, 16.914786430812537, 18.270057471173978, 19.5315129982293, 20.7162979318217, 21.83689538373072, 22.902729095022714, 23.92112037509949, 24.897891476990576, 25.837763061070124, 26.744625628338863, 27.621730575762268, 28.471828181555185, 29.297269497343944, 30.100083056363818, 30.88203361179442, 31.644667797276682, 32.38935010153801, 33.11729155592287, 33.829572861625074, 34.527163219702835, 35.21093580125357, 35.88168056264924, 36.540114942347955, 37.18689285218651, 37.82261228418788, 38.447821784855385, 39.0630259964586, 39.66869042456532, 40.26524555991184, 40.85309045837292, 41.4325958636434, 42.00410694205985, 42.56794568686632, 43.1244130394838, 43.67379076746144, 44.21634313237584, 44.75231837569983, 45.281950046348484, 45.80545819004543, 46.32305041769162, 46.8349228674501, 47.34126107319069, 47.84224075019898, 48.338028507583964, 48.82878249557324, 49.31465299482498, 49.79578295398115, 50.272308480912244, 50.744359292437615, 51.21205912673303, 51.67552612214025, 52.134873165665226, 52.590208214077265, 53.041634590197155, 53.489251256677726, 53.933153069332036, 54.37343101184621, 54.81017241352193, 55.243461151524535, 55.67337783896356, 56.1, 56.52340223305742, 56.94365636311037, 57.360831583930164, 57.774994591085864, 58.18620970642443, 58.59453899468789, 59.00004237286614, 59.4027777128309, 59.80280093774873, 60.200166112727636, 60.5949255301135, 60.98712978981713, 61.37682787502137, 61.76406722358884, 62.1488937954651, 62.531352136348374, 62.91148543787533, 63.289335594553364, 63.664943257651615, 64.03834788624704, 64.40958779560695, 64.77870020307601, 65.14572127162305, 65.51068615119216, 65.87362901799172, 66.23458311184574, 66.59358077172304, 66.95065346955174, 67.30583184241912, 67.65914572325015, 68.01062417005156, 68.36029549380254, 68.70818728506815, 69.05432643940567, 69.39873918163067], [0.0, 6.957549856091583, 9.839461367371692, 12.050829846944152, 13.915099712183165, 15.55755443506466, 17.042447007398906, 18.40794665355156, 19.678922734743384, 20.87264956827475, 22.001704479426134, 23.075582332846988, 24.101659693888305, 25.0858027577353, 26.032767812893038, 26.946474723050507, 27.83019942436633, 28.68671295216655, 29.518384102115075, 30.327256717349165, 31.11510887012932, 31.883498866968786, 32.633801494769195, 33.36723692486389, 34.08489401479781, 34.787749280457916, 35.47668248300565, 36.152489540832455, 36.81589330710312, 37.46755262890812, 38.10807001148182, 38.73799814135986, 39.35784546948677, 39.96808101472975, 40.56913851685786, 41.16142004353105, 41.7452991365495, 42.32112356731565, 42.889217759245746, 43.449884925049, 44.00340895885227, 44.55005611668744, 45.09007651357447, 45.62370546108678, 46.151164665693976, 46.67266330519397, 47.18839899805884, 47.69855867843388, 48.20331938777661, 48.70284899264108, 49.19730683685845, 49.68684433529665, 50.1716055154706, 50.65172751249459, 51.127341022196724, 51.59857071663904, 52.065535625786076, 52.52834948863328, 52.98712107672958, 53.4419544927017, 53.892949446101014, 54.340201508643666, 54.783802350694856, 55.22383996065468, 55.66039884873266, 56.093560236447814, 56.52340223305742, 56.95, 57.3734259043331, 57.79374966205256, 58.21103847209737, 58.62535714176929, 59.03676820423015, 59.445332028679935, 59.85110692376541, 60.25414923472076, 60.65451343469833, 61.05225221070882, 61.447416544554585, 61.84005578910808, 62.23021774025864, 62.617948704824244, 63.00329356470184, 63.38629583750733, 63.76699773393757, 64.14544021206808, 64.52166302878437, 64.89570478852973, 65.26760298953839, 65.63739406771113, 66.0051134382784, 66.3707955353859, 66.73447384972778, 67.09618096434401, 67.45594858869009, 67.81380759107985, 68.16978802959562, 68.52391918155296, 68.87622957160184, 69.22674699854096, 69.57549856091583, 69.92251068146797], [0.0, 7.009279563550023, 9.912618221237011, 12.140428328522846, 14.018559127100046, 15.67322557739791, 17.169158395215533, 18.544810594880715, 19.825236442474022, 21.027838690650068, 22.165288177689007, 23.247150363001484, 24.280856657045693, 25.27231687044146, 26.22632265492057, 27.14682301854123, 28.03711825420009, 28.900000000000002, 29.737854663711033, 30.55274128453943, 31.34645115479582, 32.120554167075014, 32.87643532988332, 33.615323886584825, 34.338316790431065, 35.04639781775012, 35.74045327076869, 36.42128498556854, 37.08962118976143, 37.74612562899669, 38.39140528816313, 39.02601696304659, 39.650472884948044, 40.26524555991185, 40.87077195258245, 41.467457120011595, 42.055677381300136, 42.63578309354714, 43.208101092272045, 43.77293684458469, 44.330576355378014, 44.8812878603099, 45.42532333401712, 45.96291983762563, 46.49430072600297, 47.01967673219372, 47.53924694397252, 48.05319968534874, 48.561713314091385, 49.06495694485016, 49.56309110618505, 50.05626833874056, 50.54463374088292, 51.028325467332365, 51.5074751856466, 51.982208494830225, 52.45264530984114, 52.918900215329494, 53.38108279156578, 53.83929791518459, 54.29364603708246, 54.744223439555704, 55.191122474542944, 55.634431784642146, 56.07423650840018, 56.51061847122184, 56.94365636311037, 57.3734259043331, 57.800000000000004, 58.223448884448615, 58.64384025624516, 59.061239404536714, 59.47570932742207, 59.88731084294903, 60.29610269329187, 60.70214164261423, 61.10548256907886, 61.506178551426856, 61.90428095051263, 62.29983948614956, 62.69290230959164, 63.08351607195021, 63.4717259888212, 63.857575901376016, 64.24110833415003, 64.62236454974392, 65.00138460063755, 65.37820737829999, 65.75287065976664, 66.12541115184085, 66.49586453306702, 66.86426549361026, 67.23064777316965, 67.59504419704155, 67.95748671044274, 68.3180064111944, 68.67663358086213, 69.03339771443964, 69.38832754865908, 69.74145108900446, 70.09279563550024, 70.44238780734226], [0.0, 7.060630283480364, 9.985239105800122, 12.229370384447437, 14.121260566960729, 15.788049277855706, 17.294941456969433, 18.680671829460525, 19.970478211600245, 21.181890850441093, 22.327673412158287, 23.417461433725048, 24.458740768894874, 25.457464524182296, 26.418459455464088, 27.3457035016472, 28.242521133921457, 29.111724442224308, 29.955717317400364, 30.776573883393848, 31.57609855571141, 32.35587272814628, 33.11729155592287, 33.86159328797155, 34.589882913938865, 35.30315141740182, 36.00229159373053, 36.68811115334231, 37.36134365892105, 38.022657718786576, 38.67266476466291, 39.31192567148041, 39.94095642320049, 40.56023298749652, 41.17019553026194, 41.77125207603909, 42.363781700882186, 42.948137328643256, 43.52464818927317, 44.09362198776599, 44.655346824316574, 45.21009289970549, 45.758114034562226, 46.29964902674749, 46.834922867450096, 47.36414783356711, 47.88752447141114, 48.40524248467309, 48.91748153778975, 49.42441198436255, 49.9261955290006, 50.422985829877234, 50.91492904836459, 51.402164351318916, 51.8848243709083, 52.36303562628889, 52.836918910928176, 53.30658964893553, 53.77215822337802, 54.233730279227515, 54.6914070032944, 55.14528538324922, 55.595458447610625, 56.04201548838158, 56.485042267842914, 56.92462121086094, 57.360831583930164, 57.79374966205256, 58.223448884448615, 58.650000000000006, 59.07347120323979, 59.493928261630195, 59.91143463480073, 60.32605158635861, 60.73783828882947, 61.146851922237175, 61.553147766787696, 61.956779290082544, 62.35779822925117, 62.75625466835955, 63.15219711142282, 63.54567255132328, 63.93672653491107, 64.32540322454263, 64.71174545629256, 65.0957947950557, 65.47759158674057, 65.85717500773929, 66.23458311184574, 66.60985287478121, 66.98302023647486, 67.35412014123561, 67.7231865759431, 68.09025260637532, 68.45535041178302, 68.81851131781332, 69.17976582787773, 69.53914365305343, 69.89667374060085, 70.25238430117516, 70.60630283480364, 70.9584561556972], [0.0, 7.111610225539643, 10.057335631269348, 12.317670234261024, 14.223220451079285, 15.902043893789253, 17.419816302131316, 18.815552078001858, 20.114671262538696, 21.334830676618928, 22.488886144049022, 23.586542773369736, 24.63534046852205, 25.641275319297208, 26.609208932247498, 27.543147968233406, 28.44644090215857, 29.32192012812258, 30.172006893808042, 30.998790298977802, 31.804087787578506, 32.58949217155738, 33.3564086795926, 34.1060845011561, 34.83963260426263, 35.558051127698214, 36.26223931309263, 36.953010702783075, 37.631104156003715, 38.29719310863396, 38.95189340712464, 39.5957699760972, 40.22934252507739, 40.85309045837292, 41.467457120011595, 42.07285348059958, 42.669661353237856, 43.25823620999821, 43.838909657973936, 44.41199162388465, 44.977772288098045, 45.536523802328176, 46.08850181986827, 46.63394686277368, 47.17308554673947, 47.70613168136776, 48.233287260977775, 48.75474335897996, 49.2706809370441, 49.7812715787775, 50.28667815634674, 50.787055437384836, 51.282550638594415, 51.77330393165962, 52.25944890639395, 52.741112995461144, 53.218417864494995, 53.691479771002776, 54.16040989505157, 54.625314644402735, 55.08629593646681, 55.54345145919544, 55.99687491280205, 56.44665623400558, 56.89288180431714, 57.33563464373617, 57.774994591085864, 58.21103847209737, 58.64384025624516, 59.07347120323979, 59.50000000000001, 59.92349288884953, 60.344013787616085, 60.76162440224916, 61.176384332518374, 61.58835117130512, 61.997580597955604, 62.404126466124026, 62.80804088649797, 63.20937430476591, 63.60817557515701, 64.00449202985679, 64.39836954457776, 64.78985260054232, 65.17898434311476, 65.56580663730143, 65.95036012032081, 66.33268425143069, 66.7128173591852, 67.09079668628179, 67.46665843214706, 67.84043779339872, 68.2121690023122, 68.58188536341066, 68.94961928828904, 69.31540232877539, 69.67926520852527, 70.04123785313907, 70.40134941888543, 70.75962832010921, 71.11610225539643, 71.4707982325649], [0.0, 7.162227307199905, 10.128918994641037, 12.405341591427462, 14.32445461439981, 16.01522712920426, 17.543802324467748, 18.949472288166763, 20.257837989282073, 21.486681921599715, 22.648951410606188, 23.754420641219603, 24.810683182854923, 25.823777802637633, 26.798600709738555, 27.73918708253722, 28.64890922879962, 29.530619702268357, 30.38675698392311, 31.21942504275183, 32.03045425840852, 32.8214487797233, 33.59382383712816, 34.34883549700048, 35.087604648935496, 35.81113653599952, 36.52033680019942, 37.21602477428239, 37.89894457633353, 38.56977443543066, 39.22913458132871, 39.877593959515664, 40.51567597856415, 41.14386345495523, 41.76260288823004, 42.37230817408936, 42.97336384319943, 43.5661278977143, 44.150934304949885, 44.728095197537755, 45.297902821212375, 45.86063126473512, 46.416538001018566, 46.96586526404043, 47.50884128243921, 48.04568138761277, 48.57658901158047, 49.10175658772301, 49.62136636570985, 50.135591150399335, 50.64459497320518, 51.14853370332331, 51.647555605275265, 52.14180184842101, 52.631406973403244, 53.116499319891176, 53.59720141947711, 54.073630357134334, 54.54589810425711, 55.01411182596698, 55.47837416507444, 55.938783504827846, 56.39543421235445, 56.84841686450029, 57.29781845759924, 57.743722602547884, 58.18620970642443, 58.62535714176929, 59.061239404536714, 59.4939282616302, 59.92349288884954, 60.35, 60.77351396784622, 61.194096937531484, 61.611808933028406, 62.026707957137305, 62.43885008550366, 62.848289555086545, 63.255078847472795, 63.65926876739945, 64.06090851681704, 64.46004576479915, 64.85672671357999, 65.25099616097826, 65.6428975594466, 66.03247307196665, 66.41976362499342, 66.8048089586371, 67.18764767425633, 67.56831727962447, 67.94685423181856, 68.32329397796919, 68.69767099400096, 69.07001882148289, 69.44037010270034, 69.80875661405237, 70.17520929787099, 70.5397582927529, 70.90243296248725, 71.26326192365882, 71.62227307199905, 71.97949360755466], [0.0, 7.212489168102785, 10.200000000000001, 12.49239768819421, 14.42497833620557, 16.127616066858735, 17.666918237202548, 19.082452672547102, 20.400000000000002, 21.637467504308354, 22.807893370497855, 23.92112037509949, 24.98479537638842, 26.004999519323203, 26.98666337285882, 27.93385043276347, 28.84995667241114, 29.737854663711033, 30.6, 31.438511415141782, 32.25523213371747, 33.05177756188009, 33.82957286162508, 34.58988291393887, 35.333836474405096, 36.062445840513924, 36.776623009732695, 37.47719306458263, 38.164905345094205, 38.84044283990594, 39.50443013131565, 40.157440157460236, 40.800000000000004, 41.43259586364341, 42.05567738130014, 42.669661353237856, 43.27493500861671, 43.8718588619174, 44.46076922411488, 45.041980418272026, 45.61578674099571, 46.182464204500825, 46.742272088549576, 47.29545432702808, 47.84224075019898, 48.382848200576205, 48.91748153778975, 49.44633454564656, 49.96959075277684, 50.48742417671949, 51.0, 51.507475185646605, 52.009999038646406, 52.50771371903371, 53.00075471160764, 53.489251256677726, 53.97332674571764, 54.45309908535969, 54.92868103277194, 55.40018050512109, 55.86770086552694, 56.33134118765503, 56.79119650086622, 57.24735801764131, 57.69991334482228, 58.14894668005603, 58.594538994687895, 59.03676820423015, 59.47570932742207, 59.911434634800735, 60.34401378761609, 60.77351396784623, 61.2, 61.62353446533232, 62.044177809041834, 62.46198844097104, 62.877022830283565, 63.28933559455338, 63.698979583663665, 64.10600595888033, 64.51046426743494, 64.91240251292507, 65.31186722181506, 65.70890350629813, 66.10355512376017, 66.49586453306702, 66.88587294788042, 67.27362038719188, 67.65914572325016, 68.04248672704429, 68.42368011149357, 68.80276157248342, 69.17976582787774, 69.55472665462787, 69.92767692409065, 70.29864863566013, 70.66767294881019, 71.03478021363901, 71.4, 71.76336112529847, 72.12489168102785, 72.48461905811467], [0.0, 7.262403183519901, 10.270589077555387, 12.578851298906432, 14.524806367039803, 16.23922719836138, 17.789182105987898, 19.21451274427744, 20.541178155110774, 21.787209550559705, 22.965735346380704, 24.08666643601808, 25.157702597812865, 26.18496706127392, 27.173424517347826, 28.127166583216304, 29.049612734079606, 29.943655421474514, 30.81176723266616, 31.656081564211327, 32.47845439672276, 33.28051231576822, 34.063690346173594, 34.8292621225314, 35.578364211975796, 36.31201591759951, 37.03113554834634, 37.73655389671929, 38.42902548855488, 39.10923803911296, 39.77782045311181, 40.43534963370541, 41.08235631022155, 41.7193300521473, 42.34672360407591, 42.96495665074038, 43.57441910111941, 44.17547396463337, 44.76845987969656, 45.35369334464394, 45.93147069276141, 46.50206984640577, 47.06575187968424, 47.62276241462689, 48.17333287203616, 48.71768159508414, 49.25601486113143, 49.7885277950654, 50.31540519562573, 50.83682228463931, 51.35294538777693, 51.863932554329125, 52.36993412254784, 52.87109323628557, 53.36754631796369, 53.859423502299016, 54.34684903469565, 54.82994163775847, 55.3088148489913, 55.78357733240133, 56.25433316643261, 56.72118211038976, 57.18421985128414, 57.64353823283231, 58.09922546815921, 58.55136633760137, 59.00004237286614, 59.445332028679935, 59.88731084294903, 60.326051586358616, 60.76162440224916, 61.194096937531484, 61.62353446533232, 62.050000000000004, 62.473554405044055, 62.89425649453216, 63.312163128422654, 63.72732930227031, 64.13980823170584, 64.54965143205655, 64.95690879344552, 65.36162865167911, 65.76385785520799, 66.16364182842416, 66.56102463153644, 66.95604901724712, 67.34875648443703, 67.73918732904906, 68.12738069234719, 68.51337460671456, 68.8972060391421, 69.2789109325486, 69.6585242450628, 70.03607998738936, 70.41161125837131, 70.78515027885439, 71.15672842395159, 71.52637625379886, 71.8941235428877, 72.25999930805425, 72.62403183519902, 72.98624870480741], [0.0, 7.311976476986232, 10.340696301506973, 12.66471476188864, 14.623952953972465, 16.350076452420645, 17.910611379849655, 19.34567135045977, 20.681392603013947, 21.935929430958698, 23.12249986485025, 24.25108245006808, 25.32942952377728, 26.363706112760397, 27.358910797032834, 28.319163123228055, 29.24790590794493, 30.14805134664594, 31.022088904520917, 31.87216654072955, 32.70015290484129, 33.507685685525935, 34.29620970311443, 35.067007286051656, 35.82122275969931, 36.559882384931164, 37.28391073908423, 37.99414428566592, 38.69134270091954, 39.376198394461596, 40.04934456392513, 40.71136205041536, 41.362785206027894, 42.00410694205985, 42.63578309354714, 43.25823620999821, 43.871858861917396, 44.47701653663384, 45.0740501841137, 45.6632784631152, 46.2449997297005, 46.8194938033294, 47.38702354020561, 47.947836238979534, 48.50216490013616, 49.05022935726193, 49.592237295770396, 50.128385172474886, 50.65885904755456, 51.18383533890363, 51.70348150753486, 52.21795668158608, 52.727412225520794, 53.23199226029401, 53.731834139548965, 54.22706888630437, 54.71782159406567, 55.20421179584036, 55.68635380414128, 56.16435702471808, 56.63832624645611, 57.1083619096188, 57.574560354378725, 58.037014051379316, 58.49581181588986, 58.95103900695898, 59.402777712830904, 59.85110692376541, 60.29610269329188, 60.73783828882948, 61.17638433251838, 61.61180893302841, 62.044177809041834, 62.473554405044055, 62.89999999999999, 63.32357380944319, 63.7443330814591, 64.16233318700311, 64.57762770495677, 64.99026850229194, 65.40030580968258, 65.8077882928761, 66.21276312011152, 66.6152760258486, 67.01537137105187, 67.4130922002544, 67.80848029560904, 68.20157622811954, 68.59241940622886, 68.98104812192983, 69.36749959455075, 69.75181001235738, 70.13401457210331, 70.51414751665087, 70.89224217077634, 71.26833097526558, 71.64244551939862, 72.01461657191545, 72.38487411054881, 72.75324735020423, 73.11976476986233, 73.48445413827336], [0.0, 7.361215932167728, 10.410331406828508, 12.750000000000002, 14.722431864335457, 16.460179221381523, 18.031222920256962, 19.47594670356232, 20.820662813657016, 22.083647796503186, 23.27820869396956, 24.41439124778662, 25.500000000000004, 26.541241493193194, 27.543147968233402, 28.509866713122317, 29.444863728670914, 30.351070821307115, 31.23099422048552, 32.08679634990069, 32.920358442763046, 33.73332921607353, 34.527163219702835, 35.30315141740182, 36.062445840513924, 36.80607966083864, 37.53498368189335, 38.25000000000001, 38.95189340712464, 39.64136097562747, 40.31904016714684, 40.98551573422006, 41.64132562731403, 42.28696607703135, 42.92289598803883, 43.549540755328294, 44.16729559300637, 44.776528449624145, 45.377582571133075, 45.970778762165864, 46.55641738793912, 47.134780152240026, 47.70613168136776, 48.27072093930232, 48.82878249557324, 49.38053766414457, 49.92619552900061, 50.46595386991115, 51.00000000000001, 51.5285115251741, 52.05165703414253, 52.56959672662518, 53.08248298638639, 53.5904609049036, 54.09366876077088, 54.59223845932679, 55.086295936466804, 55.57596153014359, 56.061350322659905, 56.542572456512794, 57.019733426244635, 57.4929343484919, 57.96227221218988, 58.427840110686965, 58.88972745734183, 59.34802018601799, 59.80280093774873, 60.25414923472076, 60.70214164261423, 61.14685192223718, 61.58835117130512, 62.026707957137305, 62.46198844097104, 62.89425649453216, 63.32357380944319, 63.75, 64.17359269980138, 64.59440765267533, 65.01249879830802, 65.42791835294777, 65.84071688552609, 66.25094338950956, 66.65864535077202, 67.06386881175287, 67.46665843214706, 67.86705754635308, 68.2651082178883, 68.66085129096493, 69.05432643940567, 69.4455722130648, 69.83462608190868, 70.2215244778978, 70.60630283480364, 70.98899562608278, 71.36963640092333, 71.74825781857007, 72.12489168102785, 72.49956896423592, 72.87231984779955, 73.24317374335988, 73.61215932167728, 73.97930453849915], [0.0, 7.410128204019146, 10.479503805047262, 12.834718539960278, 14.820256408038292, 16.56955038617524, 18.15103302845323, 19.605356410940356, 20.959007610094524, 22.23038461205744, 23.43288287855338, 24.576614901161637, 25.669437079920556, 26.717597197352912, 27.726160931510154, 28.699303127428028, 29.640512816076583, 30.552741284539433, 31.438511415141782, 32.300000000000004, 33.13910077235048, 33.95747340424491, 34.75658211044349, 35.537726432623685, 36.30206605690646, 37.05064102009573, 37.78438831051788, 38.504155619880834, 39.21071282188071, 39.904761620638716, 40.586943713465296, 41.257847738339436, 41.91801522018905, 42.56794568686632, 43.208101092272045, 43.838909657973936, 44.46076922411488, 45.07405018411371, 45.67909806465098, 46.27623580197508, 46.86576575710676, 47.44797150563974, 48.023119432206826, 48.591460155051934, 49.153229802323274, 49.70865115852572, 50.257934696921254, 50.80127951144539, 51.33887415984111, 51.87089742813402, 52.397519025236306, 52.91890021532951, 53.435194394705825, 53.94654761891628, 54.45309908535969, 54.95498157583169, 55.45232186302031, 55.945241084474745, 56.43385508717264, 56.9182747454629, 57.398606254856055, 57.87495140386729, 58.34740782588375, 58.81606923282107, 59.28102563215317, 59.74236352873897, 60.200166112727636, 60.65451343469834, 61.105482569078866, 61.553147766787696, 61.99758059795561, 62.43885008550367, 62.877022830283565, 63.312163128422654, 63.74433308145909, 64.17359269980138, 64.60000000000001, 65.02361109627796, 65.44448028672855, 65.86266013455577, 66.27820154470096, 66.69115383617232, 67.10156481036789, 67.50948081566025, 67.91494680848982, 68.31800641119442, 68.71870196678631, 69.11707459087083, 69.51316422088698, 69.9070096628371, 70.29864863566014, 70.6881178133921, 71.07545286524737, 71.4606884937446, 71.8438584709925, 72.22499567324321, 72.60413211381292, 72.98129897446333, 73.35652663533082, 73.72984470348491, 74.10128204019146, 74.47086678695236], [0.0, 7.458719729283304, 10.54822259909223, 12.918881530535065, 14.917439458566609, 16.6782043397963, 18.270057471173974, 19.73391750261463, 21.09644519818446, 22.37615918784991, 23.586542773369736, 24.737774758453924, 25.83776306107013, 26.892796433245838, 27.907973770949404, 28.88749729554293, 29.834878917133217, 30.753089275713428, 31.644667797276686, 32.51180554813897, 33.3564086795926, 34.18014774690127, 34.984496566336354, 35.770763201251384, 36.54011494234795, 37.29359864641652, 38.032157446035065, 38.756644591605195, 39.46783500522926, 40.16643499241625, 40.85309045837291, 41.52839390104077, 42.19289039636892, 42.84708274783711, 43.49143593858451, 44.1263809982192, 44.75231837569982, 45.36962089328057, 45.978636343414976, 46.57968977998888, 47.17308554673947, 47.759109078792505, 48.33802850758397, 48.91009609477372, 49.47554951690785, 50.03461301938889, 50.58749845564614, 51.13440622516311, 51.67552612214026, 52.21103810498313, 52.74111299546114, 53.265913115237225, 53.785592866491676, 54.300299262527105, 54.810172413521926, 55.31534597198141, 55.81594754189881, 56.31209905517641, 56.80391711845232, 57.291513333128144, 57.77499459108586, 58.25446334831349, 58.73001787842397, 59.20175250784389, 59.669757834266434, 60.13412092980157, 60.5949255301135, 61.05225221070882, 61.506178551426856, 61.956779290082544, 62.404126466124026, 62.848289555086545, 63.28933559455337, 63.72732930227031, 64.1623331870031, 64.59440765267533, 65.02361109627795, 65.45, 65.87362901799172, 66.2945510581375, 66.7128173591852, 67.12847756354974, 67.54157978608437, 67.95217067908868, 68.36029549380254, 68.76599813861499, 69.16932123420035, 69.57030616577737, 69.96899313267271, 70.36542119535703, 70.7596283201092, 71.15165142145332, 71.54152640250277, 71.9292881933361, 72.31497078752089, 72.69860727689355, 73.0802298846959, 73.4598699971624, 73.8375581936456, 74.21332427536177, 74.58719729283304, 74.9592055720977], [0.0, 7.506996736378671, 10.616496597277278, 13.002499759661605, 15.013993472757342, 16.78615500941178, 18.388311504866348, 19.861646457431473, 21.232993194554556, 22.520990209136013, 23.739208074407202, 24.89789147699058, 26.00499951932321, 27.06686165775412, 28.088609791159122, 29.07447334002802, 30.027986945514684, 30.952140475256318, 31.849489791831836, 32.722240143364274, 33.57231001882356, 34.40138078624171, 35.21093580125357, 36.00229159373054, 36.776623009732695, 37.53498368189336, 38.27832284727219, 39.00749927898481, 39.723292914862945, 40.42641463202, 41.11751451632261, 41.79718890069044, 42.46598638910911, 43.124413039483805, 43.7729368445847, 44.41199162388465, 45.041980418272026, 45.663278463115205, 46.27623580197509, 46.88117959266811, 47.478416148814404, 48.06823275303556, 48.65089927226424, 49.22666960093888, 49.79578295398116, 50.35846502823533, 50.9149290483646, 51.46537671095006, 52.00999903864642, 52.5489771546507, 53.08248298638639, 53.61067990615304, 54.13372331550824, 54.651761179306945, 55.16493451459904, 55.673377838963575, 56.177219582318244, 56.676582465776825, 57.171583850720815, 57.66233606089854, 58.14894668005604, 58.63151882733382, 59.11015141242662, 59.584939372294414, 60.05597389102937, 60.52334260432085, 60.98712978981714, 61.44741654455459, 61.904280950512636, 62.35779822925118, 62.80804088649798, 63.2550788474728, 63.69897958366367, 64.13980823170584, 64.57762770495677, 65.01249879830802, 65.44448028672855, 65.87362901799173, 66.30000000000001, 66.72364648308725, 67.14462003764712, 67.56297062740803, 67.97874667864951, 68.3919951456309, 68.80276157248342, 69.21109015179577, 69.61702378010713, 70.02060411050451, 70.42187160250714, 70.82086556940688, 71.2176242232216, 71.61218471740688, 72.00458318746108, 72.3948547895498, 72.78303373726601, 73.16915333663498, 73.55324601946539, 73.93534337514097, 74.31547618094095, 74.69367443097174, 75.06996736378672, 75.4443834887661], [0.0, 7.554965254718251, 10.684334326480055, 13.085583670589557, 15.109930509436502, 16.893415877199025, 18.505809898515654, 19.98855922771824, 21.36866865296011, 22.664895764154753, 23.890897848343833, 25.05698505407225, 26.171167341179114, 27.239814610235513, 28.26809155213701, 29.26025461269946, 30.219861018873004, 31.149919743074783, 32.053002979440166, 32.931330067277884, 33.78683175439805, 34.62120015250771, 35.43592809564892, 36.2323405261101, 37.01161979703131, 37.77482627359125, 38.52291525832385, 39.25675101176867, 39.97711845543648, 40.684733008832694, 41.38024891176949, 42.06426630763932, 42.73733730592022, 43.399971198147135, 44.0526389674898, 44.69577720545869, 45.32979152830951, 45.955059569105124, 46.57193360812927, 47.18074289368492, 47.78179569668767, 48.37538113544947, 48.96177080130988, 49.541220211052526, 50.1139701081445, 50.68024763159707, 51.240267368545226, 51.79423230437922, 52.34233468235823, 52.884756783027754, 53.42167163240027, 53.9532436466984, 54.479629220471026, 55.000977264045055, 55.517429695546966, 56.02912189210179, 56.53618310427402, 57.0387368373459, 57.536901202619525, 58.03078924157416, 58.52050922539892, 59.006164932149254, 59.487855903537145, 59.96567768315472, 60.43972203774601, 60.91007716297854, 61.37682787502137, 61.840055789108085, 62.299839486149565, 62.75625466835956, 63.20937430476591, 63.65926876739946, 64.10600595888033, 64.54965143205655, 64.99026850229194, 65.42791835294777, 65.86266013455577, 66.29455105813751, 66.72364648308725, 67.15, 67.5736635087961, 67.99468729246426, 68.41312008672021, 68.8290091458536, 69.24240030501542, 69.653338039178, 70.06186551898259, 70.46802466367282, 70.87185619129784, 71.27339966635519, 71.6726935450315, 72.069775218187, 72.4646810522202, 72.857446427939, 73.24810577755578, 73.63669261991606, 74.02323959406262, 74.40777849123035, 74.79034028536039, 75.17095516221676, 75.5496525471825, 75.92646113180834], [0.0, 7.602631123499286, 10.75174404457249, 13.168143377105219, 15.205262246998572, 17.000000000000004, 18.62256695517565, 20.114671262538696, 21.50348808914498, 22.807893370497858, 24.041630560342618, 25.215074856125256, 26.336286754210438, 27.41167634421507, 28.446440902158567, 29.444863728670914, 30.410524493997144, 31.346451154795822, 32.25523213371747, 33.13910077235048, 34.00000000000001, 34.83963260426264, 35.65950083778516, 36.46093800219627, 37.2451339103513, 38.01315561749643, 38.7659644533707, 39.50443013131566, 40.22934252507739, 40.94142156789381, 41.64132562731403, 42.3296586331617, 43.00697617828996, 43.67379076746145, 44.330576355378014, 44.977772288098045, 45.615786740995716, 46.24499972970052, 46.865765757106765, 47.478416148814404, 48.083261120685236, 48.680591615139605, 49.270680937044105, 49.85378621529161, 50.43014971225051, 51.0, 51.563553019550554, 52.121013036970034, 52.672573508420875, 53.218417864495, 53.75872022286245, 54.29364603708247, 54.82335268843014, 55.34799002673902, 55.86770086552695, 56.3826214360418, 56.892881804317135, 57.398606254856055, 57.89991364414977, 58.39691772688007, 58.88972745734183, 59.37844726834814, 59.86317732964063, 60.34401378761609, 60.82104898799429, 61.294371682887814, 61.76406722358884, 62.23021774025864, 62.692902309591645, 63.15219711142282, 63.60817557515701, 64.06090851681704, 64.51046426743494, 64.95690879344552, 65.40030580968256, 65.84071688552609, 66.27820154470096, 66.7128173591852, 67.1446200376471, 67.57366350879609, 68.00000000000001, 68.42368011149357, 68.8447528864764, 69.26326587737543, 69.67926520852528, 70.09279563550024, 70.50390060131426, 70.91262228968831, 71.31900167557032, 71.72307857307855, 72.12489168102785, 72.52447862618526, 72.92187600439254, 73.31711941968261, 73.71024352150792, 74.10128204019145, 74.4902678207026, 74.87723285485383, 75.26220831200743, 75.64522456837577, 76.02631123499286, 76.4054971844304], [0.0, 7.65, 10.818733752154177, 13.250188677901914, 15.3, 17.105920027873392, 18.738596532291314, 20.23999752964412, 21.637467504308354, 22.950000000000003, 24.191424100288103, 25.37217964621881, 26.500377355803828, 27.58246725729952, 28.62367900882065, 29.62832259848674, 30.6, 31.541758035975107, 32.456201256462535, 33.34557691808616, 34.211840055746784, 35.05670406641218, 35.88168056264924, 36.688111153342305, 37.47719306458263, 38.25, 39.00749927898481, 39.75056603370574, 40.47999505928824, 41.19651077457896, 41.90077564914521, 42.59339737564967, 43.27493500861671, 43.94590424601593, 44.60678199556656, 45.25801034071207, 45.900000000000006, 46.533133356781384, 47.15776712271268, 47.77423468774775, 48.382848200576205, 48.983900416361294, 49.57766634282014, 50.164404710910304, 50.74435929243762, 51.31776008362018, 51.88482437090831, 52.44575769306799, 53.000754711607655, 53.550000000000004, 54.09366876077089, 54.631927478352814, 55.16493451459904, 55.692840652995976, 56.21578959687394, 56.733918426281825, 57.2473580176413, 57.756233429821236, 58.2606642598589, 58.76076497119485, 59.25664519697348, 59.74841002068591, 60.23616023619035, 60.719992588932364, 61.2, 61.6762717744839, 62.1488937954651, 62.61794870482425, 63.083516071950214, 63.54567255132328, 64.00449202985679, 64.46004576479915, 64.91240251292507, 65.36162865167911, 65.8077882928761, 66.25094338950956, 66.69115383617232, 67.12847756354974, 67.56297062740803, 67.99468729246426, 68.42368011149357, 68.85000000000001, 69.27369630675125, 69.69481688045389, 70.11340813282436, 70.52951509829059, 70.94318149054214, 71.35444975612944, 71.76336112529847, 72.16995566023301, 72.57427230086431, 72.97634890839635, 73.37622230668461, 73.77392832159612, 74.16950181846984, 74.56297673778857, 74.95438612916526, 75.34376218374021, 75.73113626507924, 76.11653893865643, 76.5, 76.88154850157483], [0.0, 7.697077367416806, 10.885311203635844, 13.331729070154406, 15.394154734833611, 17.211188221619103, 18.85391206089601, 20.364552536208603, 21.770622407271688, 23.091232102250416, 24.340295807569802, 25.528317610058053, 26.663458140308812, 27.75220711943467, 28.79982638836561, 29.81065245847531, 30.788309469667222, 31.735862994410603, 32.65593361090753, 33.550782405183945, 34.42237644323821, 35.272439666118935, 36.102492988712015, 36.9138862760344, 37.70782412179202, 38.48538683708403, 39.24754769409167, 39.99518721046322, 40.729105072417205, 41.45003015680448, 42.15862900996664, 42.85551306424881, 43.541244814543376, 44.21634313237585, 44.8812878603099, 45.536523802328176, 46.18246420450083, 46.81949380332941, 47.44797150563974, 48.06823275303556, 48.680591615139605, 49.28534264870237, 49.88276255381213, 50.473111653631975, 51.05663522011611, 51.6335646648573, 52.20411861146591, 52.76850386357378, 53.326916280617624, 53.879541571917635, 54.42655601817922, 54.96812712836414, 55.50441423886934, 56.03556906108835, 56.56173618268803, 57.08305352729477, 57.59965277673122, 58.11165975946653, 58.61919480852668, 59.12237309174929, 59.62130491695062, 60.11609601429554, 60.606847797918014, 61.093657608625804, 61.576618939334445, 62.05582164470953, 62.53135213634838, 63.00329356470185, 63.471725988821206, 63.936726534911074, 64.39836954457778, 64.85672671358, 65.31186722181506, 65.76385785520799, 66.21276312011152, 66.65864535077203, 67.10156481036789, 67.54157978608438, 67.97874667864951, 68.41312008672021, 68.84475288647641, 69.27369630675125, 69.70000000000002, 70.12371210938565, 70.54487933223787, 70.96354698012213, 71.37975903573786, 71.79355820684751, 72.20498597742403, 72.61408265619005, 73.02088742270941, 73.42543837118033, 73.8277725520688, 74.22792601171072, 74.6259338300031, 75.02183015629518, 75.41564824358404, 75.80742048111124, 76.19717842545091, 76.58495283017416, 76.97077367416806, 77.35467018868353], [0.0, 7.743868542272654, 10.951483917716356, 13.412773762350575, 15.487737084545309, 17.315816469343858, 18.968526563758186, 20.488350348429716, 21.90296783543271, 23.231605626817963, 24.488262494509485, 25.683506380554817, 26.82554752470115, 27.920915099616632, 28.974902933400827, 29.991873899441494, 30.975474169090617, 31.92878795068801, 32.85445175314907, 33.75474040783013, 34.631632938687716, 35.486863766751775, 36.321963052676544, 37.13828886742091, 37.93705312751637, 38.71934271136327, 39.48613680774558, 40.238321287051726, 40.97670069685943, 41.702008344922675, 42.4149148295738, 43.116035300106155, 43.80593567086542, 44.48513796764039, 45.15412494999765, 45.813344125920345, 46.463211253635926, 47.1041134084912, 47.73641167913651, 48.360443546353046, 48.97652498901897, 49.584952354519814, 50.18600402502675, 50.77994190622907, 51.367012761109635, 51.947449408031574, 52.52147179963639, 53.089287996732445, 53.6510950494023, 54.20707979590858, 54.757419588581776, 55.302282954684614, 55.841830199233264, 56.37621395588747, 56.90557969127456, 57.43006616747015, 57.949805866801654, 58.464925382659985, 58.97554577958562, 59.481782925531064, 59.98374779888299, 60.48154677254873, 60.975281877167234, 61.465051045289144, 61.950948338181234, 62.43306415674309, 62.911485437875335, 63.38629583750734, 63.85757590137602, 64.32540322454264, 64.78985260054232, 65.25099616097826, 65.70890350629814, 66.16364182842416, 66.6152760258486, 67.06386881175287, 67.50948081566025, 67.9521706790887, 68.3919951456309, 68.8290091458536, 69.26326587737543, 69.69481688045389, 70.12371210938565, 70.55, 70.97372753350355, 71.3949402969146, 71.81368254030704, 72.22999723106737, 72.64392610535309, 73.05550971692689, 73.46478748352845, 73.87179773093384, 74.27657773484182, 74.67916376071709, 75.0795911017102, 75.47789411476714, 75.87410625503274, 76.26826010864546, 76.6603874240145, 77.05051914166445, 77.43868542272654, 77.82491567615092], [0.0, 7.7903786814249285, 11.017259187293364, 13.493331686429414, 15.580757362849857, 17.41981630213132, 19.082452672547102, 20.61140461006964, 22.034518374586728, 23.371136044274785, 24.635340468522045, 25.83776306107013, 26.98666337285883, 28.088609791159122, 29.14892793911982, 30.172006893808042, 31.161514725699714, 32.120554167075014, 33.05177756188009, 33.95747340424491, 34.83963260426264, 35.7, 36.540114942347955, 37.36134365892105, 38.164905345094205, 38.95189340712464, 39.723292914862945, 40.47999505928824, 41.22280922013928, 41.95247310946043, 42.669661353237856, 43.37499279538846, 44.069036749173456, 44.75231837569983, 45.42532333401712, 46.08850181986826, 46.74227208854957, 47.38702354020561, 48.023119432206826, 48.65089927226423, 49.27068093704409, 49.88276255381212, 50.48742417671951, 51.08492928447684, 51.67552612214026, 52.259448906393956, 52.83691891092819, 53.40814544617703, 53.97332674571766, 54.5326507699745, 55.08629593646681, 55.63443178464215, 56.177219582318244, 56.714812879881755, 57.247358017641304, 57.77499459108586, 58.29785587823964, 58.816069232821064, 59.32975644649151, 59.83903408311334, 60.344013787616085, 60.84480257178915, 61.34150307907363, 61.83421383020893, 62.32302945139943, 62.80804088649796, 63.28933559455337, 63.76699773393758, 64.24110833415003, 64.71174545629256, 65.17898434311478, 65.6428975594466, 66.10355512376017, 66.56102463153644, 67.01537137105188, 67.46665843214707, 67.91494680848982, 68.36029549380255, 68.80276157248342, 69.24240030501542, 69.67926520852528, 70.11340813282436, 70.54487933223787, 70.97372753350355, 71.4, 71.82374259254388, 72.24499982697765, 72.66381492875254, 73.08022988469591, 73.49428549213877, 73.90602140556614, 74.31547618094095, 74.7226873178421, 75.12769129954681, 75.53052363117841, 75.9312188760328, 76.32981069018841, 76.72633185549796, 77.12081431105354, 77.51328918321039, 77.90378681424929, 78.29233678975231], [0.0, 7.836612788698955, 11.082644088844503, 13.573411509270617, 15.67322557739791, 17.52319890887506, 19.195702644081564, 20.733728560005797, 22.165288177689007, 23.509838366096865, 24.781545553092528, 25.991104247415116, 27.146823018541234, 28.255309235610927, 29.321920128122578, 30.35107082130711, 31.34645115479582, 32.31118227487197, 33.24793226653351, 34.15900320559721, 35.04639781775012, 35.91187129627193, 36.75697212774742, 37.58307464803805, 38.39140528816313, 39.18306394349477, 39.95904153004674, 40.720234527811854, 41.467457120011595, 42.2014513968418, 42.92289598803883, 43.63241341021604, 44.330576355378014, 45.01791310134223, 45.69491218943308, 46.36202648720179, 47.01967673219373, 47.66825463555384, 48.308125610501605, 48.939631179648266, 49.563091106185055, 50.178805286694505, 50.787055437384836, 51.38810660065225, 51.98220849483023, 52.56959672662517, 53.15049388293585, 53.72511051640564, 54.29364603708247, 54.85628952089269, 55.41322044422252, 55.96460935269718, 56.510618471221854, 57.05140226146945, 57.5871079322447, 58.11787590750371, 58.643840256245156, 59.16512908800251, 59.68186491724266, 60.19416499960772, 60.70214164261422, 61.20590249314195, 61.705550803797216, 62.201185680017396, 62.69290230959164, 63.180792176103644, 63.66494325765162, 64.14544021206808, 64.62236454974393, 65.0957947950557, 65.56580663730143, 66.03247307196665, 66.49586453306702, 66.95604901724714, 67.4130922002544, 67.86705754635308, 68.31800641119442, 68.765998138615, 69.21109015179577, 69.653338039178, 70.09279563550024, 70.52951509829059, 70.96354698012213, 71.3949402969146, 71.82374259254387, 72.25, 72.67375729931679, 73.09505797247856, 73.51394425549483, 73.93045718781941, 74.34463665927758, 74.75652145465305, 75.1661492960761, 75.5735568833438, 75.97877993229426, 76.38185321134857, 76.78281057632626, 77.18168500363284, 77.57850862191152, 77.97331274224535, 78.36612788698955, 78.75698381730983], [0.0, 7.8825757211713485, 11.147645491313401, 13.653021643577661, 15.765151442342697, 17.625975150328564, 19.30828837572093, 20.855335048855007, 22.295290982626803, 23.647727163514045, 24.926893107645807, 26.14354604869049, 27.306043287155322, 28.42103094541083, 29.4938976739257, 30.52908449331555, 31.530302884685394, 32.500692300318775, 33.44293647394021, 34.359350983393156, 35.25195030065713, 36.122499913488824, 36.97255739058363, 37.80350512849305, 38.61657675144186, 39.41287860585675, 40.19340741962543, 40.959064930732985, 41.710670097710015, 42.44896936322483, 43.174645337281, 43.888324187646994, 44.590581965253605, 45.2819500463485, 45.96291983762564, 46.63394686277369, 47.29545432702809, 47.94783623897955, 48.59146015505195, 49.226669600938884, 49.85378621529161, 50.47311165363198, 51.08492928447686, 51.68950570473662, 52.28709209738098, 52.87792545098569, 53.462229657955724, 54.040216505857934, 54.612086574310645, 55.17803004819944, 55.738227456567, 56.29285034531473, 56.84206189082166, 57.38601746070206, 57.92486512716279, 58.45874613776795, 58.9877953478514, 59.51214161832861, 60.031908182232556, 60.547212982927626, 61.0581689866311, 61.564884471588186, 62.06746329599752, 62.566005146565026, 63.06060576937079, 63.55135718456373, 64.03834788624704, 64.52166302878437, 65.00138460063755, 65.47759158674059, 65.95036012032081, 66.41976362499344, 66.88587294788042, 67.34875648443705, 67.80848029560904, 68.2651082178883, 68.71870196678631, 69.16932123420037, 69.61702378010713, 70.06186551898259, 70.50390060131426, 70.94318149054214, 71.37975903573786, 71.81368254030703, 72.24499982697765, 72.67375729931679, 73.10000000000001, 73.52377166604009, 73.94511478116726, 74.36407062553798, 74.78067932293742, 75.19497988562802, 75.6070102569861, 76.01680735205866, 76.42440709616268, 76.82984446164134, 77.23315350288372, 77.634367389707, 78.03351843919381, 78.43063814607147, 78.8257572117135, 79.21890557183937], [0.0, 7.928272195125493, 11.212270064531982, 13.732170258192987, 15.856544390250987, 17.728155572422082, 19.420221419952966, 20.976236554730214, 22.424540129063963, 23.78481658537648, 25.071398046379464, 26.295104107038636, 27.464340516385974, 28.585791925360404, 29.66487822324575, 30.706066175920352, 31.713088780501973, 32.68910368915, 33.63681019359594, 34.558537295435414, 35.456311144844165, 36.33190746437627, 37.18689285218651, 38.022657718786576, 38.84044283990593, 39.641360975627464, 40.42641463201999, 41.19651077457896, 41.95247310946043, 42.695052406572835, 43.42493523311232, 44.142751386835876, 44.84908025812793, 45.544456303703974, 46.229373779016306, 46.90429084849274, 47.56963317075296, 48.22579703851457, 48.87315213898118, 49.51204398931638, 50.14279609275893, 50.76571185357298, 51.381076283005214, 51.98915752346829, 52.59020821407727, 53.18446671726624, 53.77215822337802, 54.35349574774377, 54.92868103277195, 55.49790536587845, 56.061350322659905, 56.61918844349503, 57.17158385072081, 57.718692812640874, 58.2606642598589, 58.79764025877229, 59.3297564464915, 59.85714243095806, 60.37992215960534, 60.89821425953309, 61.412132351840704, 61.92178534247862, 62.42727769172703, 62.92870966419064, 63.426177561003946, 63.91977393577045, 64.40958779560695, 64.89570478852973, 65.3782073783, 65.85717500773929, 66.33268425143069, 66.80480895863711, 67.27362038719188, 67.73918732904906, 68.20157622811954, 68.66085129096493, 69.11707459087083, 69.57030616577737, 70.02060411050451, 70.46802466367282, 70.91262228968833, 71.35444975612944, 71.79355820684751, 72.22999723106737, 72.66381492875254, 73.09505797247856, 73.52377166604009, 73.95, 74.37378570437302, 74.79517029862289, 75.2141941391384, 75.63089646434189, 76.04531543757315, 76.45748818788125, 76.8674508488476, 77.27523859555531, 77.68088567981187, 78.08442546372486, 78.48589045172388, 78.8853123211159, 79.28272195125493, 79.6781494514023], [0.0, 7.973706791699831, 11.27652428720836, 13.810865287881134, 15.947413583399662, 17.82975041889258, 19.531512998229296, 21.09644519818446, 22.55304857441672, 23.92112037509949, 25.215074856125256, 26.44579361637688, 27.621730575762268, 28.7496086929892, 29.834878917133214, 30.882033611794412, 31.894827166799324, 32.87643532988332, 33.82957286162508, 34.75658211044349, 35.65950083778516, 36.540114942347955, 37.400000000000006, 38.24055438928678, 39.06302599645859, 39.86853395849916, 40.65808652654476, 41.43259586364341, 42.19289039636892, 42.939725197071304, 43.67379076746144, 44.39572051448203, 45.10609714883344, 45.805458190045435, 46.49430072600297, 47.17308554673947, 47.84224075019898, 48.502164900136165, 49.153229802323274, 49.79578295398116, 50.43014971225051, 51.05663522011611, 51.67552612214027, 52.28709209738097, 52.89158723275376, 53.48925125667773, 54.080310649995354, 54.66497964876599, 55.243461151524535, 55.815947541898815, 56.382621436041795, 56.94365636311038, 57.4992173859784, 58.04946166847718, 58.594538994687895, 59.134592245148696, 59.66975783426643, 60.20016611272763, 60.725941738271956, 61.24720401781619, 61.764067223588825, 62.27664088564829, 62.78503006290591, 63.28933559455338, 63.78965433359865, 64.28607936404272, 64.77870020307601, 65.26760298953839, 65.75287065976664, 66.23458311184574, 66.7128173591852, 67.18764767425631, 67.65914572325016, 68.12738069234719, 68.59241940622884, 69.05432643940567, 69.51316422088698, 69.96899313267271, 70.42187160250714, 70.87185619129782, 71.31900167557032, 71.76336112529847, 72.20498597742403, 72.64392610535309, 73.08022988469591, 73.51394425549482, 73.94511478116726, 74.37378570437302, 74.80000000000001, 75.2237994254478, 75.64522456837577, 76.06431489207013, 76.48110877857356, 76.89564356971077, 77.3079556061341, 77.71808026450474, 78.12605199291718, 78.53190434466747, 78.93567001045852, 79.33738084913064, 79.73706791699831, 80.13476149587021], [0.0, 8.018883962248113, 11.340414454507384, 13.889114442612964, 16.037767924496226, 17.930769643269638, 19.642174014095282, 21.215972756392766, 22.680828909014767, 24.05665188674434, 25.357937613299704, 26.595629340175424, 27.77822888522593, 28.912497297881412, 30.00391641102874, 31.057004040956684, 32.07553584899245, 33.06270557592043, 34.021243363522146, 34.95350483141855, 35.861539286539276, 36.747142746069386, 37.6118997127239, 38.45721648793631, 39.284348028190564, 40.09441981124056, 40.88844580073936, 41.66734332783889, 42.43194551278553, 43.18301170599383, 43.92123632139696, 44.64725635467425, 45.361657818029535, 46.06498127645338, 46.75772663421523, 47.440357292077806, 48.11330377348868, 48.77696690037215, 49.43172058506562, 50.07791429362849, 50.71587522659941, 51.34591025583245, 51.968307649951434, 52.58333861595324, 53.19125868035085, 53.79230892980891, 54.38671712835773, 54.97469872586843, 55.55645777045186, 56.13218773573679, 56.70207227253692, 57.26628589318501, 57.824994595762824, 58.37835643455544, 58.926522042285846, 59.469635109020125, 60.00783282205748, 60.54124627062115, 61.070000818732595, 61.594216449273866, 62.11400808191337, 62.62948586728139, 63.14075545952866, 63.6479182691783, 64.1510716979849, 64.65030935734181, 65.14572127162305, 65.63739406771113, 66.12541115184086, 66.60985287478123, 67.09079668628179, 67.56831727962448, 68.04248672704429, 68.51337460671456, 68.98104812192983, 69.4455722130648, 69.9070096628371, 70.36542119535703, 70.82086556940688, 71.27339966635519, 71.72307857307855, 72.16995566023301, 72.61408265619005, 73.05550971692689, 73.49428549213877, 73.93045718781941, 74.36407062553798, 74.79517029862289, 75.2237994254478, 75.64999999999999, 76.07381283989912, 76.49527763202119, 76.91443297587261, 77.33131642484823, 77.74596452549804, 78.1584128549192, 78.56869605638113, 78.976847873285, 79.38290118155169, 79.78688802052628, 80.18883962248113, 80.5887864407946], [0.0, 8.063808033429368, 11.403946685248927, 13.966925216381737, 16.127616066858735, 18.031222920256965, 19.752215065657825, 21.334830676618928, 22.807893370497855, 24.191424100288103, 25.5, 26.744625628338866, 27.933850432763474, 29.07447334002802, 30.17200689380804, 31.23099422048552, 32.25523213371747, 33.24793226653351, 34.211840055746784, 35.149324317830065, 36.06244584051393, 36.95301070278307, 37.82261228418788, 38.67266476466291, 39.50443013131565, 40.31904016714684, 41.11751451632261, 41.90077564914521, 42.669661353237856, 43.42493523311233, 44.16729559300637, 44.89738299723048, 45.61578674099571, 46.32305041769163, 47.01967673219373, 47.70613168136775, 48.382848200576205, 49.050229357261934, 49.708651158525726, 50.35846502823533, 51.0, 51.6335646648573, 52.259448906393956, 52.877925450985686, 53.48925125667773, 54.09366876077088, 54.69140700329441, 55.28268264113094, 55.86770086552695, 56.44665623400557, 57.019733426244635, 57.587107932244706, 58.14894668005604, 58.70540860942884, 59.25664519697348, 59.80280093774873, 60.34401378761608, 60.88041557019794, 61.41213235184071, 61.939284787604706, 62.46198844097104, 62.98035407966519, 63.49448794974253, 64.00449202985678, 64.51046426743494, 65.012498798308, 65.51068615119216, 66.0051134382784, 66.49586453306702, 66.98302023647486, 67.46665843214707, 67.94685423181856, 68.42368011149357, 68.8972060391421, 69.36749959455075, 69.83462608190868, 70.29864863566013, 70.75962832010921, 71.2176242232216, 71.6726935450315, 72.12489168102786, 72.57427230086431, 73.02088742270941, 73.46478748352845, 73.90602140556614, 74.34463665927758, 74.78067932293742, 75.21419413913839, 75.64522456837577, 76.07381283989912, 76.5, 76.92382595789162, 77.34532952932582, 77.76454847808222, 78.18151955545505, 78.59627853785445, 79.0088602626313, 79.41929866222694, 79.82762679674249, 80.2338768850166, 80.63808033429368, 81.0402677685606], [0.0, 8.108483212044039, 11.467126928747236, 14.044304895579561, 16.216966424088078, 18.131119656546314, 19.86164645743147, 21.45303008901074, 22.934253857494472, 24.325449636132117, 25.641275319297208, 26.892796433245838, 28.088609791159122, 29.235551987263726, 30.339166105877066, 31.40402044324898, 32.433932848176156, 33.43213274680513, 34.4013807862417, 35.34405890669605, 36.26223931309263, 37.15773809047047, 38.032157446035065, 38.88691939457277, 39.72329291486294, 40.54241606022019, 41.345314123852056, 42.13291468673869, 42.90606017802148, 43.6655184327405, 44.411991623884646, 45.14612386462431, 45.868507714988944, 46.57968977998888, 47.280175549589494, 47.970433602376374, 48.65089927226423, 49.32197785977363, 49.984047455163136, 50.63746142926204, 51.282550638594415, 51.91962538385654, 52.5489771546507, 53.170880188313596, 53.785592866491676, 54.39335896963893, 54.99440880671417, 55.58896023492434, 56.177219582318244, 56.75938248430827, 57.33563464373618, 57.906152522853745, 58.47110397452745, 59.030648819066876, 59.58493937229441, 60.134120929801576, 60.67833221175413, 61.21770577210486, 61.752368375633985, 62.28244134585605, 62.80804088649796, 63.3292783789615, 63.84626065792733, 64.35909026703222, 64.86786569635231, 65.37268160325075, 65.87362901799172, 66.3707955353859, 66.86426549361026, 67.35412014123561, 67.84043779339872, 68.32329397796919, 68.8027615724834, 69.27891093254858, 69.75181001235738, 70.2215244778978, 70.6881178133921, 71.15165142145332, 71.61218471740686, 72.06977521818699, 72.52447862618526, 72.97634890839635, 73.42543837118033, 73.87179773093382, 74.31547618094093, 74.75652145465304, 75.194979885628, 75.63089646434187, 76.06431489207013, 76.49527763202117, 76.92382595789162, 77.35000000000001, 77.77383878914554, 78.1953802983271, 78.61466148244868, 79.03171831612926, 79.44658582972588, 79.85929814367267, 80.26988850123065, 80.67838929973752, 81.08483212044038, 81.4892477569894], [0.0, 8.152913589631623, 11.529960971312956, 14.12126056696073, 16.305827179263247, 18.230469001098136, 19.97047821160024, 21.57058181876419, 23.059921942625913, 24.458740768894874, 25.781776509775273, 27.040155324997674, 28.24252113392146, 29.395747991843994, 30.505409356374813, 31.576098555711408, 32.61165435852649, 33.615323886584825, 34.58988291393887, 35.537726432623685, 36.46093800219627, 37.36134365892105, 38.24055438928678, 39.10000000000001, 39.94095642320048, 40.764567948158124, 41.571865486167454, 42.363781700882186, 43.14116363752838, 43.90478333849286, 44.655346824316574, 45.39350173758355, 46.119843885251825, 46.8349228674501, 47.53924694397252, 48.23328726097777, 48.91748153778975, 49.5922372957704, 50.257934696921254, 50.91492904836459, 51.56355301955055, 52.2041186114659, 52.83691891092819, 53.46222965795572, 54.08031064999535, 54.69140700329441, 55.29575028878803, 55.89355955743024, 56.48504226784292, 57.07039512742137, 57.64980485656478, 58.22344888444862, 58.79149598368799, 59.35410685032672, 59.91143463480073, 60.46362542884771, 61.010818712749625, 61.553147766787696, 62.0907400503489, 62.623717551739134, 63.152197111422815, 63.67629072111534, 64.1961058008973, 64.71174545629256, 65.22330871705299, 65.7308907592161, 66.23458311184574, 66.73447384972778, 67.23064777316965, 67.72318657594312, 68.21216900231221, 68.69767099400096, 69.17976582787774, 69.6585242450628, 70.13401457210331, 70.60630283480364, 71.07545286524737, 71.54152640250278, 72.00458318746107, 72.4646810522202, 72.92187600439254, 73.37622230668461, 73.8277725520688, 74.27657773484182, 74.7226873178421, 75.1661492960761, 75.6070102569861, 76.04531543757315, 76.48110877857356, 76.91443297587261, 77.34532952932582, 77.77383878914556, 78.20000000000002, 78.62385134296082, 79.04542997542616, 79.46477206913767, 79.88191284640097, 80.29688661461292, 80.7097267991907, 81.12046597499302, 81.52913589631625, 81.93576752554408], [0.0, 8.197103146844013, 11.592454442437978, 14.197799125216559, 16.394206293688026, 18.329279854920653, 20.078720078730118, 21.68749639769423, 23.184908884875956, 24.591309440532036, 25.921516159360742, 27.18671550592311, 28.395598250433117, 29.55507570621331, 30.670751539536816, 31.747243974871267, 32.78841258737605, 33.79752209852078, 34.777363327313935, 35.7303442468723, 36.658559709841306, 37.563845649773405, 38.447821784855385, 39.31192567148041, 40.157440157460236, 40.985515734220066, 41.79718890069044, 42.59339737564967, 43.37499279538846, 44.142751386835876, 44.89738299723047, 45.639538779439924, 46.36981776975191, 47.08877254717945, 47.796914126332474, 48.49471620702611, 49.18261888106407, 49.86103187861239, 50.5303374221863, 51.19089274470607, 51.843032318721484, 52.487069836293976, 53.12329997279914, 53.75199996279208, 54.37343101184622, 54.987839564761956, 55.59545844761064, 56.19650789862303, 56.791196500866235, 57.37972202790809, 57.96227221218989, 58.539025444569894, 59.11015141242662, 59.67581168279156, 60.23616023619036, 60.79134395619166, 61.34150307907363, 61.886771607509154, 62.42727769172704, 62.963143981221265, 63.494487949742535, 64.02142219601186, 64.54405472233674, 65.06248919308268, 65.5768251747521, 66.08715835924555, 66.59358077172304, 67.09618096434401, 67.59504419704156, 68.09025260637532, 68.58188536341066, 69.07001882148289, 69.55472665462787, 70.03607998738937, 70.51414751665087, 70.98899562608278, 71.4606884937446, 71.9292881933361, 72.3948547895498, 72.857446427939, 73.31711941968261, 73.77392832159612, 74.22792601171072, 74.67916376071709, 75.12769129954681, 75.5735568833438, 76.01680735205866, 76.45748818788125, 76.89564356971077, 77.33131642484823, 77.76454847808223, 78.1953802983271, 78.62385134296082, 79.05000000000001, 79.47386362823946, 79.89547859547498, 80.31488031492047, 80.73210327992206, 81.14718109706585, 81.56014651776934, 81.97103146844013, 82.37986707928098], [0.0, 8.24105575760776, 11.654612820681777, 14.273927280184667, 16.48211151521552, 18.427560880376983, 20.18638154796446, 21.803784075247126, 23.309225641363554, 24.72316727282328, 26.060506518485017, 27.332489824382996, 28.547854560369334, 29.71354909801251, 30.835207150268992, 31.917471704381597, 32.96422303043104, 33.97874335522137, 34.963838462045324, 35.92192923549625, 36.85512176075397, 37.765261815589206, 38.65397780306705, 39.52271498771308, 40.37276309592892, 41.205278788038804, 42.02130412064814, 42.821781840554, 43.60756815049425, 44.37944343950249, 45.13812136099597, 45.88425655930366, 46.61845128272711, 47.3412610731907, 48.053199685348744, 48.75474335897996, 49.44633454564656, 50.12838517247489, 50.80127951144539, 51.46537671095006, 52.121013036970034, 52.76850386357378, 53.40814544617704, 54.04021650585793, 54.66497964876599, 55.28268264113094, 55.89355955743024, 56.49783181680515, 57.09570912073867, 57.68739030325432, 58.27306410340888, 58.8529098685868, 59.42709819602502, 59.99579151907242, 60.55914464389338, 61.11730524164167, 61.670414300537985, 62.21860654177334, 62.762010802714094, 63.30075039049695, 63.834943408763195, 64.36470305998468, 64.89013792557387, 65.41135222574138, 65.92844606086209, 66.44151563593353, 66.95065346955174, 67.45594858869009, 67.95748671044274, 68.45535041178302, 68.94961928828906, 69.44037010270036, 69.92767692409065, 70.41161125837131, 70.89224217077634, 71.36963640092333, 71.8438584709925, 72.3149707875209, 72.78303373726601, 73.24810577755578, 73.71024352150793, 74.16950181846984, 74.6259338300031, 75.0795911017102, 75.53052363117841, 75.97877993229426, 76.42440709616268, 76.8674508488476, 77.3079556061341, 77.74596452549804, 78.18151955545505, 78.6146614824487, 79.04542997542616, 79.47386362823946, 79.9, 80.32387565350666, 80.74552619185783, 81.1649862933519, 81.58228974477242, 81.997469473149, 82.41055757607761, 82.82158535068018], [0.0, 8.284775193087619, 11.716441439276688, 14.349651563714012, 16.569550386175237, 18.525320510047862, 20.293471856732644, 21.919454828986964, 23.432882878553375, 24.854325579262856, 26.19875951261815, 27.47749078791584, 28.699303127428024, 29.87118176436948, 30.99879029897779, 32.08679634990068, 33.139100772350474, 34.1590032055972, 35.149324317830065, 36.11249783662161, 37.050641020095725, 37.9656094380164, 38.85904013225237, 39.732386034568826, 40.58694371346529, 41.42387596543809, 42.2442303752832, 43.048954691142036, 43.83890965797393, 44.61487980483641, 45.37758257113307, 46.12767607413146, 46.86576575710675, 47.59241010917602, 48.30812561050159, 49.01339102735088, 49.70865115852571, 50.39432011645757, 51.07078421171933, 51.73840449801288, 52.3975190252363, 53.04844484054174, 53.691479771002776, 54.32690401633429, 54.95498157583168, 55.57596153014359, 56.19007919553059, 56.79755716577959, 57.39860625485605, 57.99342635161333, 58.582207196383436, 59.16512908800251, 59.74236352873896, 60.3140738136631, 60.88041557019793, 61.44153725290408, 61.99758059795558, 62.54868104124978, 63.09496810364516, 63.63656574643228, 64.17359269980136, 64.70616276677207, 65.23438510478962, 65.7583644869609, 66.27820154470095, 66.79399299338226, 67.30583184241912, 67.81380759107985, 68.3180064111944, 68.81851131781332, 69.31540232877539, 69.80875661405236, 70.29864863566013, 70.78515027885439, 71.26833097526557, 71.74825781857005, 72.22499567324321, 72.69860727689355, 73.16915333663496, 73.63669261991605, 74.10128204019145, 74.56297673778857, 75.02183015629518, 75.47789411476712, 75.9312188760328, 76.38185321134857, 76.82984446164133, 77.2752385955553, 77.71808026450474, 78.15841285491919, 78.59627853785445, 79.03171831612926, 79.46477206913765, 79.89547859547497, 80.32387565350666, 80.75, 81.17388742693058, 81.59557279656784, 82.01509007493681, 82.43247236374752, 82.84775193087619, 83.2609602394784], [0.0, 8.328265125462806, 11.777945491468365, 14.424978336205571, 16.656530250925613, 18.62256695517565, 20.4, 22.034518374586728, 23.55589098293673, 24.98479537638842, 26.336286754210434, 27.621730575762268, 28.849956672411142, 30.02798694551468, 31.16151472569971, 32.25523213371747, 33.313060501851226, 34.338316790431065, 35.333836474405096, 36.30206605690646, 37.2451339103513, 38.164905345094205, 39.0630259964586, 39.94095642320049, 40.8, 41.64132562731403, 42.46598638910911, 43.274935008616715, 44.069036749173456, 44.849080258127934, 45.61578674099571, 46.36981776975191, 47.11178196587346, 47.84224075019899, 48.561713314091385, 49.2706809370441, 49.96959075277684, 50.658859047554564, 51.338874159841104, 52.00999903864641, 52.67257350842087, 53.32691628061762, 53.97332674571766, 54.61208657431063, 55.243461151524535, 55.86770086552695, 56.485042267842914, 57.09570912073867, 57.699913344822285, 58.297855878239645, 58.88972745734183, 59.475709327422074, 60.05597389102936, 60.63068530043184, 61.2, 61.76406722358883, 62.32302945139942, 62.877022830283565, 63.426177561003946, 63.97061825557105, 64.51046426743494, 65.04582999701057, 65.57682517475209, 66.10355512376019, 66.62612100370245, 67.14462003764709, 67.65914572325016, 68.16978802959564, 68.67663358086213, 69.17976582787774, 69.67926520852528, 70.175209297871, 70.66767294881019, 71.15672842395159, 71.64244551939862, 72.12489168102785, 72.60413211381292, 73.08022988469591, 73.55324601946539, 74.02323959406262, 74.4902678207026, 74.95438612916526, 75.41564824358404, 75.87410625503274, 76.32981069018841, 76.78281057632627, 77.23315350288372, 77.68088567981187, 78.1260519929172, 78.56869605638113, 79.0088602626313, 79.44658582972589, 79.88191284640098, 80.31488031492047, 80.74552619185785, 81.17388742693059, 81.6, 82.02389895634077, 82.44561844027857, 82.8651917272868, 83.28265125462806, 83.69802865061997], [0.0, 8.37152913152669, 11.839130035606503, 14.499913792847186, 16.74305826305338, 18.719308213713457, 20.505974739085193, 22.148984175352155, 23.678260071213007, 25.11458739458007, 26.473099554075645, 27.76522105080383, 28.999827585694373, 30.18397753776, 31.323393813570075, 32.422792908693104, 33.48611652610676, 34.51669885721982, 35.517390106819505, 36.490649487231664, 37.438616427426915, 38.36316592774898, 39.26595217233373, 40.14844330730646, 41.011949478170386, 41.85764565763345, 42.686590400265054, 43.49974137854156, 44.29796835070431, 45.08206406099881, 45.85275346148801, 46.61070156090767, 47.356520142426014, 48.090773543373174, 48.81398365222819, 49.52663424865454, 50.22917478916014, 50.92202372255055, 51.60557140464585, 52.28018266991806, 52.94619910815129, 53.603941086453716, 54.253709550592035, 54.89578763438958, 55.53044210160766, 56.15792464114037, 56.778473033360115, 57.39231220294231, 57.999655171388746, 58.60070392068683, 59.19565017803251, 59.78467613025934, 60.36795507552, 60.94565201882742, 61.51792421725558, 62.084921679905506, 62.64678762714015, 63.20365891307244, 63.75566641483721, 64.30293539178442, 64.84558581738621, 65.38373268634945, 65.9174862991604, 66.44695252605646, 66.97223305221353, 67.49342560575808, 68.01062417005156, 68.52391918155296, 69.03339771443964, 69.53914365305343, 70.04123785313908, 70.5397582927529, 71.03478021363901, 71.52637625379886, 72.01461657191545, 72.49956896423593, 72.98129897446333, 73.45986999716241, 73.93534337514097, 74.40777849123035, 74.87723285485383, 75.34376218374021, 75.80742048111122, 76.26826010864546, 76.72633185549796, 77.18168500363284, 77.634367389707, 78.08442546372484, 78.53190434466747, 78.976847873285, 79.41929866222694, 79.85929814367267, 80.29688661461292, 80.73210327992206, 81.1649862933519, 81.59557279656784, 82.02389895634077, 82.45000000000002, 82.87391024924553, 83.29566315241149, 83.7152913152669, 84.13282653043343], [0.0, 8.414570696119915, 11.9, 14.574463969559911, 16.82914139223983, 18.815552078001858, 20.611404610069638, 22.262861451304953, 23.8, 25.243712088359747, 26.609208932247498, 27.907973770949404, 29.148927939119822, 30.33916610587707, 31.484440601668624, 32.58949217155738, 33.65828278447966, 34.69416377432954, 35.699999999999996, 36.67826331766541, 37.631104156003715, 38.56040715552677, 39.46783500522926, 40.354863399595345, 41.222809220139276, 42.072853480599576, 42.90606017802148, 43.72339190867973, 44.52572290260991, 45.31384997989026, 46.08850181986826, 46.85034685037028, 47.6, 48.33802850758397, 49.06495694485017, 49.7812715787775, 50.48742417671949, 51.183835338903634, 51.87089742813402, 52.54897715465069, 53.218417864494995, 53.879541571917635, 54.5326507699745, 55.17803004819943, 55.81594754189881, 56.44665623400557, 57.07039512742137, 57.68739030325432, 58.297855878239645, 58.90199487283941, 59.5, 60.09205438325437, 60.67833221175414, 61.25899933887266, 61.83421383020892, 62.40412646612401, 62.96888120333725, 63.5286155995863, 64.0834612049006, 64.63354392264128, 65.17898434311476, 65.7198980522642, 66.25639591767725, 66.78858435391486, 67.31656556895932, 67.8404377933987, 68.36029549380254, 68.87622957160184, 69.38832754865908, 69.89667374060085, 70.40134941888543, 70.90243296248727, 71.39999999999999, 71.89412354288771, 72.38487411054881, 72.87231984779955, 73.35652663533082, 73.8375581936456, 74.31547618094095, 74.79034028536039, 75.26220831200743, 75.73113626507924, 76.1971784254509, 76.66038742401449, 77.12081431105354, 77.57850862191152, 78.03351843919381, 78.48589045172388, 78.93567001045852, 79.38290118155167, 79.82762679674249, 80.26988850123065, 80.70972679919069, 81.14718109706584, 81.58228974477242, 82.01509007493682, 82.44561844027855, 82.87391024924551, 83.3, 83.72392131284822, 84.14570696119915, 84.56538890113379], [0.0, 8.45739321540627, 11.960560187549747, 14.648634748671975, 16.91478643081254, 18.911306142093945, 20.7162979318217, 22.376159187849915, 23.921120375099495, 25.37217964621881, 26.744625628338866, 28.05, 29.29726949734395, 30.49356489490857, 31.644667797276682, 32.75534307559608, 33.82957286162508, 34.87072554450223, 35.88168056264924, 36.86492235174246, 37.82261228418789, 38.756644591605195, 39.66869042456532, 40.56023298749651, 41.4325958636434, 42.28696607703135, 43.1244130394838, 43.94590424601593, 44.75231837569983, 45.544456303703974, 46.323050417691626, 47.088772547179445, 47.84224075019899, 48.58402515230702, 49.31465299482498, 50.03461301938889, 50.74435929243762, 51.44431455467164, 52.13487316566523, 52.816403701880354, 53.48925125667773, 54.15373948306802, 54.81017241352194, 55.45883608587544, 56.1, 56.733918426281825, 57.36083158393017, 57.980966704600576, 58.5945389946879, 59.20175250784389, 59.80280093774873, 60.39786833986777, 60.98712978981714, 61.57075198501316, 62.1488937954651, 62.721706768869105, 63.289335594553364, 63.85191853029947, 64.40958779560695, 64.96246993457068, 65.51068615119216, 66.05435261964196, 66.59358077172303, 67.12847756354975, 67.65914572325016, 68.18568398131679, 68.70818728506815, 69.22674699854097, 69.74145108900446, 70.25238430117516, 70.75962832010921, 71.26326192365882, 71.76336112529847, 72.25999930805425, 72.75324735020423, 73.24317374335988, 73.72984470348491, 74.21332427536178, 74.69367443097174, 75.17095516221674, 75.64522456837578, 76.11653893865643, 76.58495283017416, 77.05051914166445, 77.51328918321039, 77.97331274224535, 78.43063814607147, 78.8853123211159, 79.33738084913064, 79.78688802052628, 80.2338768850166, 80.67838929973752, 81.12046597499302, 81.56014651776934, 81.997469473149, 82.43247236374754, 82.8651917272868, 83.29566315241149, 83.72392131284822, 84.15, 84.5739321540627, 84.9957498937447], [0.0, 8.5, 12.020815280171309, 14.722431864335459, 17.0, 19.006577808748215, 20.820662813657016, 22.488886144049022, 24.041630560342618, 25.500000000000004, 26.879360111431225, 28.1913107180209, 29.444863728670917, 30.64718584144391, 31.8040877875785, 32.920358442763046, 34.0, 35.04639781775012, 36.062445840513924, 37.05064102009573, 38.01315561749643, 38.95189340712464, 39.86853395849916, 40.764567948158124, 41.64132562731403, 42.50000000000001, 43.34166586553868, 44.16729559300638, 44.977772288098045, 45.773900860643295, 46.55641738793912, 47.325997084055196, 48.083261120685236, 48.82878249557325, 49.56309110618506, 50.28667815634674, 51.00000000000001, 51.703481507534875, 52.397519025236306, 53.08248298638639, 53.75872022286245, 54.42655601817922, 55.086295936466826, 55.738227456567, 56.3826214360418, 57.01973342624464, 57.64980485656479, 58.27306410340888, 58.889727457341834, 59.50000000000001, 60.10407640085654, 60.70214164261424, 61.29437168288782, 61.88093405888442, 62.46198844097104, 63.03768714031314, 63.608175575157, 64.17359269980138, 64.73407139984323, 65.28973885688316, 65.84071688552609, 66.38712224520657, 66.92906692910039, 67.46665843214707, 68.0, 68.52919086053767, 69.05432643940567, 69.57549856091583, 70.09279563550024, 70.60630283480364, 71.11610225539643, 71.62227307199905, 72.12489168102785, 72.62403183519902, 73.11976476986233, 73.6121593216773, 74.10128204019146, 74.58719729283305, 75.0699673637867, 75.5496525471825, 76.02631123499286, 76.50000000000001, 76.97077367416806, 77.43868542272654, 77.90378681424929, 78.36612788698955, 78.8257572117135, 79.28272195125493, 79.73706791699831, 80.18883962248113, 80.63808033429368, 81.0848321204404, 81.52913589631625, 81.97103146844013, 82.41055757607761, 82.8477519308762, 83.28265125462806, 83.71529131526691, 84.14570696119917, 84.5739321540627, 85.00000000000001, 85.4239427795276], [0.0, 8.542394277952758, 12.080769843019112, 14.795860907699831, 17.084788555905515, 19.1013742961076, 20.924507162654994, 22.60105086052417, 24.161539686038225, 25.627182833858274, 27.0134225895202, 28.331916631248234, 29.591721815399662, 30.80004058438885, 31.962712650837382, 33.08455077524856, 34.16957711181103, 35.22119390367113, 36.24230952905734, 37.23543339347617, 38.2027485922152, 39.14616839487615, 40.067380747935104, 40.96788376277203, 41.84901432530999, 42.71197138976379, 43.55783511608446, 44.3875827230995, 45.20210172104834, 46.00220103429836, 46.78862041137781, 47.562038434028466, 48.32307937207645, 49.07231908112761, 49.81029010154429, 50.537486087062156, 51.25436566771655, 51.961355832964955, 52.658854905894046, 53.347235167344905, 54.0268451790404, 54.69801184686698, 55.36104225897487, 56.016225328024376, 56.66383326249647, 57.304122888322794, 57.93733683903672, 58.56370463008638, 59.183443630799324, 59.79675994566931, 60.40384921509556, 61.004897344393605, 61.6000811687777, 62.1895690610572, 62.77352148796498, 63.35209152032789, 63.925425301674764, 64.49366247934755, 65.05693660171835, 65.61537548471395, 66.16910155049712, 66.71823214084738, 67.26287980751344, 67.8031525815725, 68.33915422362206, 68.87098445644581, 69.39873918163067, 69.92251068146797, 70.44238780734226, 70.9584561556972, 71.4707982325649, 71.97949360755466, 72.48461905811467, 72.98624870480741, 73.48445413827335, 73.97930453849915, 74.47086678695234, 74.9592055720977, 75.44438348876609, 75.92646113180834, 76.4054971844304, 76.88154850157483, 77.35467018868351, 77.82491567615091, 78.2923367897523, 78.75698381730983, 79.21890557183936, 79.6781494514023, 80.13476149587021, 80.5887864407946, 81.0402677685606, 81.4892477569894, 81.93576752554407, 82.37986707928098, 82.82158535068018, 83.2609602394784, 83.69802865061997, 84.13282653043343, 84.56538890113379, 84.9957498937447, 85.42394277952758, 85.85000000000002]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"A = 9.0\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.9, 1.2727922061357855, 1.5588457268119897, 1.8, 2.012461179749811, 2.2045407685048604, 2.3811761799581315, 2.545584412271571, 2.6999999999999997, 2.8460498941515415, 2.9849623113198605, 3.1176914536239795, 3.2449961479175906, 3.3674916480965473, 3.4856850115866753, 3.6, 3.7107950630558943, 3.8183766184073566, 3.9230090491866063, 4.024922359499622, 4.124318125460256, 4.221374183841087, 4.316248370981448, 4.409081537009721, 4.5, 4.589117562233507, 4.676537180435969, 4.762352359916263, 4.846648326421054, 4.9295030175464944, 5.01098792654702, 5.091168824543142, 5.170106381884226, 5.247856705360771, 5.324471804789654, 5.3999999999999995, 5.474486277268398, 5.547972602672079, 5.620498198558559, 5.692099788303083, 5.762811813689564, 5.8326666285670745, 5.9016946718718, 5.969924622639721, 6.037383539249432, 6.104096984812742, 6.17008914036094, 6.235382907247959, 6.300000000000001, 6.3639610306789285, 6.427285585688566, 6.489992295835181, 6.552098900352467, 6.613622305514582, 6.674578638386097, 6.734983296193095, 6.794850991743675, 6.854195795277518, 6.913031173081746, 6.971370023173351, 7.029224708315989, 7.08660708661063, 7.143528539874395, 7.2, 7.256031973468695, 7.311634564172364, 7.366817494685205, 7.421590126111789, 7.475961476626267, 7.52994023880668, 7.583534795858723, 7.636753236814713, 7.689603370785779, 7.742092740338364, 7.794228634059948, 7.846018098373213, 7.89746794865291, 7.9485847796950635, 7.99937497558403, 8.049844718999244, 8.1, 8.149846624323676, 8.19939022122987, 8.248636250920512, 8.2975900115636, 8.346256645946134, 8.394641147779934, 8.442748367682174, 8.490583018850943, 8.538149682454625, 8.58545281275251, 8.632496741962896, 8.67928568489366, 8.725823743349393, 8.772114910328067, 8.818163074019441, 8.863972021616496, 8.909545442950499, 8.95488693395958, 9.0, 9.044888059008802], [0.0, 1.2727922061357855, 1.7999999999999998, 2.2045407685048604, 2.545584412271571, 2.8460498941515415, 3.117691453623979, 3.3674916480965473, 3.5999999999999996, 3.818376618407356, 4.024922359499621, 4.221374183841087, 4.409081537009721, 4.589117562233506, 4.762352359916263, 4.9295030175464944, 5.091168824543142, 5.24785670536077, 5.3999999999999995, 5.547972602672079, 5.692099788303083, 5.8326666285670745, 5.96992462263972, 6.104096984812742, 6.235382907247958, 6.363961030678928, 6.489992295835181, 6.613622305514581, 6.734983296193095, 6.854195795277517, 6.97137002317335, 7.08660708661063, 7.199999999999999, 7.311634564172365, 7.42159012611179, 7.529940238806679, 7.636753236814712, 7.742092740338364, 7.846018098373212, 7.9485847796950635, 8.049844718999243, 8.149846624323676, 8.248636250920512, 8.346256645946132, 8.442748367682174, 8.538149682454623, 8.632496741962894, 8.725823743349393, 8.818163074019441, 8.909545442950499, 9.0, 9.08955444452587, 9.178235124467012, 9.2660671268883, 9.353074360871938, 9.439279633531363, 9.524704719832526, 9.60937042682818, 9.693296652842108, 9.776502442080192, 9.859006035092989, 9.940824915468534, 10.02197585309404, 10.102474944289641, 10.182337649086284, 10.261578825892242, 10.34021276376845, 10.418253212511202, 10.49571341072154, 10.572606112023657, 10.648943609579309, 10.724737759031687, 10.799999999999999, 10.874741376235116, 10.948972554536795, 11.022703842524301, 11.095945205344158, 11.16870628139177, 11.240996397117119, 11.31282458097888, 11.384199576606166, 11.45512985522207, 11.525623627379128, 11.595688854052613, 11.665333257134149, 11.734564329364767, 11.803389343743602, 11.871815362445627, 11.93984924527944, 12.0074976577137, 12.074767078498864, 12.141663806908838, 12.208193969625484, 12.27436352728727, 12.34017828072188, 12.405643876881198, 12.470765814495916, 12.535549449465709, 12.6, 12.66412255152326, 12.727922061357855, 12.791403363196707], [0.0, 1.5588457268119897, 2.2045407685048604, 2.7000000000000006, 3.1176914536239795, 3.485685011586676, 3.818376618407357, 4.124318125460257, 4.409081537009721, 4.676537180435969, 4.929503017546495, 5.170106381884227, 5.400000000000001, 5.620498198558559, 5.832666628567075, 6.037383539249433, 6.235382907247959, 6.427285585688566, 6.613622305514581, 6.794850991743676, 6.971370023173352, 7.143528539874396, 7.311634564172366, 7.475961476626269, 7.636753236814714, 7.794228634059949, 7.9485847796950635, 8.100000000000001, 8.248636250920514, 8.394641147779934, 8.538149682454625, 8.67928568489366, 8.818163074019441, 8.954886933959582, 9.089554444525872, 9.222255689363639, 9.353074360871938, 9.482088377567466, 9.609370426828182, 9.734988443752775, 9.85900603509299, 9.981482855768476, 10.102474944289643, 10.222035022440492, 10.340212763768454, 10.457055034760026, 10.572606112023658, 10.686907878334127, 10.800000000000002, 10.91192008768393, 11.022703842524303, 11.132385189167685, 11.240996397117119, 11.348568191626645, 11.455129855222072, 11.560709320798619, 11.66533325713415, 11.76902714755982, 11.87181536244563, 11.973721226085063, 12.074767078498866, 12.174974332621815, 12.27436352728727, 12.37295437638077, 12.470765814495918, 12.567816039392048, 12.66412255152326, 12.759702190882043, 12.854571171377131, 12.948745112944344, 13.042239071570497, 13.135067567393785, 13.227244611029162, 13.318783728253871, 13.409697983176207, 13.500000000000002, 13.589701983487352, 13.678815738213599, 13.767352686700523, 13.85532388650659, 13.942740046346705, 14.029611541307908, 14.115948427222312, 14.201760454253552, 14.287057079748791, 14.371847480404183, 14.45614056378811, 14.539944979263163, 14.623269128344733, 14.706121174531376, 14.788509052639487, 14.870440477672478, 14.951922953252538, 15.032963779641062, 15.113570061372, 15.19374871452072, 15.273506473629428, 15.352849898308786, 15.431785379534025, 15.51031914565268, 15.588457268119898, 15.666205666976293], [0.0, 1.8, 2.545584412271571, 3.1176914536239795, 3.6, 4.024922359499622, 4.409081537009721, 4.762352359916263, 5.091168824543142, 5.3999999999999995, 5.692099788303083, 5.969924622639721, 6.235382907247959, 6.489992295835181, 6.734983296193095, 6.971370023173351, 7.2, 7.421590126111789, 7.636753236814713, 7.846018098373213, 8.049844718999244, 8.248636250920512, 8.442748367682174, 8.632496741962896, 8.818163074019441, 9.0, 9.178235124467014, 9.353074360871938, 9.524704719832526, 9.693296652842108, 9.859006035092989, 10.02197585309404, 10.182337649086284, 10.340212763768452, 10.495713410721542, 10.648943609579309, 10.799999999999999, 10.948972554536796, 11.095945205344158, 11.240996397117119, 11.384199576606166, 11.525623627379128, 11.665333257134149, 11.8033893437436, 11.939849245279442, 12.074767078498864, 12.208193969625484, 12.34017828072188, 12.470765814495918, 12.600000000000001, 12.727922061357857, 12.854571171377131, 12.979984591670362, 13.104197800704934, 13.227244611029164, 13.349157276772194, 13.46996659238619, 13.58970198348735, 13.708391590555037, 13.826062346163493, 13.942740046346701, 14.058449416631978, 14.17321417322126, 14.28705707974879, 14.4, 14.51206394693739, 14.623269128344727, 14.73363498937041, 14.843180252223577, 14.951922953252534, 15.05988047761336, 15.167069591717446, 15.273506473629427, 15.379206741571558, 15.484185480676729, 15.588457268119896, 15.692036196746425, 15.79493589730582, 15.897169559390127, 15.99874995116806, 16.09968943799849, 16.2, 16.29969324864735, 16.39878044245974, 16.497272501841024, 16.5951800231272, 16.69251329189227, 16.789282295559868, 16.88549673536435, 16.981166037701886, 17.07629936490925, 17.17090562550502, 17.264993483925792, 17.35857136978732, 17.451647486698786, 17.544229820656135, 17.636326148038883, 17.72794404323299, 17.819090885900998, 17.90977386791916, 18.0, 18.089776118017603], [0.0, 2.012461179749811, 2.8460498941515415, 3.4856850115866758, 4.024922359499622, 4.500000000000001, 4.929503017546495, 5.324471804789655, 5.692099788303083, 6.037383539249432, 6.3639610306789285, 6.674578638386098, 6.9713700231733515, 7.256031973468695, 7.52994023880668, 7.794228634059948, 8.049844718999244, 8.2975900115636, 8.538149682454625, 8.77211491032807, 9.000000000000002, 9.22225568936364, 9.439279633531365, 9.65142476528725, 9.85900603509299, 10.062305898749054, 10.261578825892244, 10.457055034760028, 10.64894360957931, 10.837435120913067, 11.022703842524301, 11.20490963818986, 11.384199576606166, 11.560709320798617, 11.734564329364769, 11.905880899790658, 12.074767078498864, 12.2413234578619, 12.4056438768812, 12.56781603939205, 12.727922061357857, 12.886038956948719, 13.042239071570496, 13.19659046875366, 13.349157276772196, 13.5, 13.649175799292792, 13.796738745080305, 13.942740046346703, 14.087228258248677, 14.230249470757709, 14.371847480404183, 14.51206394693739, 14.650938536489738, 14.788509052639487, 14.924811556599302, 15.05988047761336, 15.193748714520721, 15.326447729333765, 15.4580076335859, 15.588457268119896, 15.717824276915684, 15.846135175493108, 15.973415414368963, 16.09968943799849, 16.224980739587952, 16.349311912126456, 16.472704695950814, 16.5951800231272, 16.71675805890604, 16.83745824048274, 16.957299313275097, 17.07629936490925, 17.194475857088523, 17.31184565550421, 17.428425057933378, 17.54422982065614, 17.659275183313728, 17.773575892318352, 17.887146222916613, 18.000000000000004, 18.1121506177483, 18.22361105818493, 18.33439390871703, 18.44451137872728, 18.553975315279473, 18.66279721799495, 18.77098825315279, 18.87855926706273, 18.985520798756088, 19.091883092036785, 19.19765610693139, 19.3028495305745, 19.407472787563044, 19.51153504981092, 19.61504524593303, 19.71801207018598, 19.820443990990718, 19.92234925906079, 20.023735915158294, 20.12461179749811, 20.224984548819812], [0.0, 2.2045407685048604, 3.117691453623979, 3.818376618407357, 4.409081537009721, 4.929503017546496, 5.4, 5.8326666285670745, 6.235382907247958, 6.61362230551458, 6.971370023173351, 7.3116345641723655, 7.636753236814714, 7.948584779695063, 8.248636250920512, 8.538149682454623, 8.818163074019441, 9.08955444452587, 9.353074360871938, 9.60937042682818, 9.859006035092992, 10.102474944289643, 10.340212763768452, 10.572606112023658, 10.8, 11.022703842524303, 11.240996397117117, 11.455129855222072, 11.665333257134149, 11.871815362445627, 12.074767078498864, 12.27436352728727, 12.470765814495916, 12.664122551523262, 12.854571171377131, 13.042239071570496, 13.22724461102916, 13.409697983176207, 13.58970198348735, 13.767352686700521, 13.942740046346701, 14.11594842722231, 14.28705707974879, 14.456140563788107, 14.623269128344731, 14.788509052639483, 14.951922953252534, 15.113570061372, 15.273506473629428, 15.431785379534023, 15.588457268119896, 15.743570116082314, 15.897169559390125, 16.04929905011431, 16.200000000000003, 16.349311912126456, 16.497272501841024, 16.643917808016237, 16.789282295559868, 16.9333989500041, 17.076299364909246, 17.21801382273809, 17.35857136978732, 17.497999885701223, 17.636326148038883, 17.77357589231835, 17.90977386791916, 18.044943890187078, 18.17910888905174, 18.312290954438225, 18.444511378727277, 18.575790696495265, 18.706148721743876, 18.835604582810717, 18.96417675513493, 19.091883092036785, 19.21874085365636, 19.344766734184212, 19.469976887505545, 19.59438695136952, 19.718012070185985, 19.840866916543742, 19.962965711536953, 20.08432224397926, 20.204949888579286, 20.32486162314519, 20.444070044880984, 20.562587385832554, 20.680425527536904, 20.79759601492442, 20.914110069520053, 21.02997860198626, 21.145212224047317, 21.25982125983189, 21.373815756668254, 21.487205495363977, 21.6, 21.712208547266677, 21.823840175367856, 21.934903692517096, 22.045407685048605, 22.15536052516411], [0.0, 2.3811761799581315, 3.3674916480965473, 4.124318125460256, 4.762352359916263, 5.324471804789655, 5.8326666285670745, 6.3, 6.734983296193095, 7.143528539874394, 7.52994023880668, 7.897467948652911, 8.248636250920512, 8.58545281275251, 8.909545442950499, 9.222255689363639, 9.524704719832526, 9.817840903172144, 10.102474944289641, 10.379306335203717, 10.64894360957931, 10.911920087683928, 11.168706281391772, 11.419719786404569, 11.665333257134149, 11.905880899790658, 12.141663806908838, 12.37295437638077, 12.6, 12.823026163897508, 13.042239071570494, 13.257827876390612, 13.46996659238619, 13.678815738213599, 13.884523758487363, 14.087228258248675, 14.287057079748788, 14.484129245487974, 14.678555787270081, 14.870440477672478, 15.05988047761336, 15.246966911487675, 15.431785379534023, 15.614416415607723, 15.794935897305821, 15.973415414368962, 16.149922600433726, 16.32452143249535, 16.497272501841024, 16.668233259706923, 16.837458240482736, 17.004999264922066, 17.17090562550502, 17.3352242558324, 17.497999885701223, 17.659275183313728, 17.819090885900998, 17.977485919894363, 18.1344975116489, 18.290161289611415, 18.444511378727277, 18.59758048779464, 18.74939999039969, 18.9, 19.04940943966505, 19.197656106931387, 19.34476673418421, 19.49076704493694, 19.635681806344287, 19.77953487825232, 19.92234925906079, 20.06414712864716, 20.204949888579282, 20.344778199823168, 20.483652018133878, 20.62159062730128, 20.758612670407434, 20.89473617923902, 21.029978601986265, 21.164356829348723, 21.29788721915862, 21.430585619623184, 21.562467391279693, 21.69354742774911, 21.823840175367856, 21.953359651770842, 22.082119463493534, 22.21013282265552, 22.337412562783545, 22.463971153827632, 22.58982071642004, 22.71497303542313, 22.839439572809138, 22.963231479911535, 23.08635960908519, 23.208834524809728, 23.330666514268298, 23.45186559743169, 23.572441536675832, 23.692403845958733, 23.811761799581316, 23.930524440554997], [0.0, 2.545584412271571, 3.5999999999999996, 4.409081537009721, 5.091168824543142, 5.692099788303083, 6.235382907247958, 6.734983296193095, 7.199999999999999, 7.636753236814712, 8.049844718999243, 8.442748367682174, 8.818163074019441, 9.178235124467012, 9.524704719832526, 9.859006035092989, 10.182337649086284, 10.49571341072154, 10.799999999999999, 11.095945205344158, 11.384199576606166, 11.665333257134149, 11.93984924527944, 12.208193969625484, 12.470765814495916, 12.727922061357855, 12.979984591670362, 13.227244611029162, 13.46996659238619, 13.708391590555035, 13.9427400463467, 14.17321417322126, 14.399999999999999, 14.62326912834473, 14.84318025222358, 15.059880477613358, 15.273506473629425, 15.484185480676729, 15.692036196746423, 15.897169559390127, 16.099689437998485, 16.29969324864735, 16.497272501841024, 16.692513291892265, 16.88549673536435, 17.076299364909246, 17.26499348392579, 17.451647486698786, 17.636326148038883, 17.819090885900998, 18.0, 18.17910888905174, 18.356470248934023, 18.5321342537766, 18.706148721743876, 18.878559267062727, 19.04940943966505, 19.21874085365636, 19.386593305684215, 19.553004884160384, 19.718012070185978, 19.881649830937068, 20.04395170618808, 20.204949888579282, 20.364675298172568, 20.523157651784484, 20.6804255275369, 20.836506425022403, 20.99142682144308, 21.145212224047313, 21.297887219158618, 21.449475518063373, 21.599999999999998, 21.749482752470232, 21.89794510907359, 22.045407685048602, 22.191890410688316, 22.33741256278354, 22.481992794234237, 22.62564916195776, 22.768399153212332, 22.91025971044414, 23.051247254758255, 23.191377708105225, 23.330666514268298, 23.469128658729534, 23.606778687487203, 23.743630724891254, 23.87969849055888, 24.0149953154274, 24.149534156997728, 24.283327613817676, 24.416387939250967, 24.54872705457454, 24.68035656144376, 24.811287753762397, 24.941531628991832, 25.071098898931417, 25.2, 25.32824510304652, 25.45584412271571, 25.582806726393414], [0.0, 2.7, 3.818376618407356, 4.676537180435969, 5.4, 6.037383539249433, 6.613622305514581, 7.143528539874395, 7.636753236814712, 8.1, 8.538149682454623, 8.95488693395958, 9.353074360871938, 9.734988443752771, 10.102474944289641, 10.457055034760025, 10.8, 11.132385189167683, 11.455129855222069, 11.769027147559818, 12.074767078498866, 12.372954376380768, 12.66412255152326, 12.948745112944342, 13.227244611029162, 13.5, 13.76735268670052, 14.029611541307908, 14.28705707974879, 14.539944979263161, 14.788509052639483, 15.032963779641058, 15.273506473629425, 15.510319145652678, 15.743570116082312, 15.973415414368962, 16.2, 16.423458831805192, 16.643917808016237, 16.861494595675676, 17.076299364909246, 17.288435441068692, 17.497999885701223, 17.705084015615398, 17.90977386791916, 18.112150617748295, 18.31229095443822, 18.51026742108282, 18.706148721743876, 18.900000000000002, 19.091883092036785, 19.281856757065697, 19.469976887505542, 19.6562967010574, 19.840866916543742, 20.02373591515829, 20.204949888579282, 20.384552975231024, 20.562587385832554, 20.739093519245237, 20.91411006952005, 21.087674124947966, 21.259821259831888, 21.430585619623184, 21.6, 21.768095920406083, 21.93490369251709, 22.100452484055612, 22.264770378335367, 22.4278844298788, 22.58982071642004, 22.750604387576168, 22.910259710444137, 23.068810112357337, 23.226278221015093, 23.382685902179844, 23.538054295119636, 23.69240384595873, 23.84575433908519, 23.998124926752087, 24.14953415699773, 24.3, 24.449539872971027, 24.598170663689604, 24.745908752761537, 24.892770034690795, 25.0387699378384, 25.1839234433398, 25.32824510304652, 25.47174905655283, 25.614449047363873, 25.756358438257532, 25.897490225888685, 26.037857054680977, 26.177471230048177, 26.3163447309842, 26.454489222058324, 26.591916064849485, 26.728636328851497, 26.86466080187874, 27.0, 27.134664177026405], [0.0, 2.8460498941515415, 4.024922359499621, 4.929503017546495, 5.692099788303083, 6.3639610306789285, 6.971370023173351, 7.52994023880668, 8.049844718999243, 8.538149682454623, 9.0, 9.439279633531365, 9.85900603509299, 10.261578825892242, 10.648943609579309, 11.022703842524301, 11.384199576606166, 11.734564329364767, 12.074767078498864, 12.4056438768812, 12.727922061357857, 13.042239071570496, 13.349157276772194, 13.649175799292792, 13.942740046346701, 14.230249470757707, 14.51206394693739, 14.788509052639487, 15.05988047761336, 15.326447729333761, 15.588457268119894, 15.846135175493108, 16.099689437998485, 16.349311912126456, 16.5951800231272, 16.837458240482736, 17.076299364909246, 17.31184565550421, 17.544229820656135, 17.773575892318352, 18.0, 18.22361105818493, 18.444511378727277, 18.662797217994946, 18.87855926706273, 19.09188309203678, 19.302849530574495, 19.51153504981092, 19.71801207018598, 19.92234925906079, 20.12461179749811, 20.32486162314519, 20.523157651784484, 20.71955597979841, 20.914110069520053, 21.106870919205434, 21.297887219158618, 21.48720549536398, 21.674870241826135, 21.86092404268401, 22.045407685048602, 22.228360263411243, 22.409819276379718, 22.58982071642004, 22.768399153212332, 22.94558781116753, 23.12141864159723, 23.29592238998061, 23.469128658729534, 23.641065965814654, 23.811761799581316, 23.98124267005361, 24.149534156997728, 24.316660954991335, 24.482646915723798, 24.647515087732476, 24.8112877537624, 24.973986465920895, 25.1356320787841, 25.296244780599352, 25.455844122715714, 25.614449047363873, 25.772077913897437, 25.92874852359828, 26.08447814314099, 26.239283526803852, 26.393180937507324, 26.546186166754726, 26.69831455354439, 26.849581002317336, 27.0, 27.14958563219704, 27.298351598585583, 27.446311227558432, 27.593477490160605, 27.73986301336039, 27.885480092693403, 28.03034070431539, 28.17445651649735, 28.317838900594094, 28.460498941515414, 28.60244744772727], [0.0, 2.9849623113198605, 4.221374183841087, 5.170106381884226, 5.969924622639721, 6.674578638386098, 7.3116345641723655, 7.897467948652911, 8.442748367682174, 8.95488693395958, 9.439279633531365, 9.900000000000002, 10.340212763768452, 10.76243466879126, 11.168706281391772, 11.560709320798617, 11.939849245279442, 12.307314898059609, 12.66412255152326, 13.011149065320867, 13.349157276772196, 13.678815738213599, 14.000714267493644, 14.315376348528181, 14.623269128344731, 14.9248115565993, 15.220381072758988, 15.51031914565268, 15.794935897305821, 16.074513989542577, 16.349311912126456, 16.61956678135745, 16.88549673536435, 17.147302994931888, 17.405171645232347, 17.659275183313728, 17.90977386791916, 18.156816901648813, 18.400543470234787, 18.641083659487187, 18.87855926706273, 19.113084523435774, 19.344766734184212, 19.573706853838388, 19.800000000000004, 20.02373591515829, 20.244999382563588, 20.463870601623732, 20.680425527536904, 20.894736179239022, 21.106870919205434, 21.316894708188624, 21.52486933758252, 21.73085364176935, 21.934903692517096, 22.13707297724792, 22.337412562783545, 22.535971245988048, 22.732795692567166, 22.927930565142592, 23.121418641597234, 23.313300924579515, 23.50361674296107, 23.69240384595873, 23.879698490558884, 24.06553552281769, 24.249948453553465, 24.43296952889681, 24.614629796119218, 24.79495916512064, 24.9739864659209, 25.15173950246782, 25.32824510304652, 25.50352916754856, 25.67761671183679, 25.850531909421132, 26.022298130641733, 26.19293797953945, 26.362473328578265, 26.530925351370616, 26.698314553544392, 26.864660801878742, 27.029983351826175, 27.194300873528633, 27.357631476427198, 27.51999273255718, 27.68140169861346, 27.841874936864436, 28.001428534987287, 28.16007812489163, 28.317838900594094, 28.474725635201477, 28.630752697056362, 28.78593406509506, 28.94028334346435, 29.093813775440303, 29.246538256689462, 29.39846934790994, 29.54961928688761, 29.700000000000003, 29.8496231131986, 29.99849996249813], [0.0, 3.1176914536239795, 4.409081537009721, 5.400000000000001, 6.235382907247959, 6.971370023173352, 7.636753236814714, 8.248636250920514, 8.818163074019441, 9.353074360871938, 9.85900603509299, 10.340212763768454, 10.800000000000002, 11.240996397117119, 11.66533325713415, 12.074767078498866, 12.470765814495918, 12.854571171377131, 13.227244611029162, 13.589701983487352, 13.942740046346705, 14.287057079748791, 14.623269128344733, 14.951922953252538, 15.273506473629428, 15.588457268119898, 15.897169559390127, 16.200000000000003, 16.497272501841028, 16.789282295559868, 17.07629936490925, 17.35857136978732, 17.636326148038883, 17.909773867919164, 18.179108889051744, 18.444511378727277, 18.706148721743876, 18.964176755134933, 19.218740853656364, 19.46997688750555, 19.71801207018598, 19.962965711536953, 20.204949888579286, 20.444070044880984, 20.680425527536908, 20.914110069520053, 21.145212224047317, 21.373815756668254, 21.600000000000005, 21.82384017536786, 22.045407685048605, 22.26477037833537, 22.481992794234237, 22.69713638325329, 22.910259710444144, 23.121418641597238, 23.3306665142683, 23.53805429511964, 23.74363072489126, 23.947442452170126, 24.14953415699773, 24.34994866524363, 24.54872705457454, 24.74590875276154, 24.941531628991836, 25.135632078784095, 25.32824510304652, 25.519404381764087, 25.709142342754262, 25.89749022588869, 26.084478143140995, 26.27013513478757, 26.454489222058324, 26.637567456507742, 26.819395966352413, 27.000000000000004, 27.179403966974704, 27.357631476427198, 27.534705373401046, 27.71064777301318, 27.88548009269341, 28.059223082615816, 28.231896854444624, 28.403520908507105, 28.574114159497583, 28.743694960808366, 28.91228112757622, 29.079889958526326, 29.246538256689465, 29.41224234906275, 29.577018105278974, 29.740880955344956, 29.903845906505076, 30.065927559282123, 30.227140122744, 30.38749742904144, 30.547012947258857, 30.705699796617573, 30.86357075906805, 31.02063829130536, 31.176914536239796, 31.332411333952585], [0.0, 3.2449961479175906, 4.589117562233507, 5.620498198558559, 6.489992295835181, 7.256031973468696, 7.948584779695063, 8.58545281275251, 9.178235124467014, 9.734988443752771, 10.261578825892242, 10.76243466879126, 11.240996397117119, 11.700000000000001, 12.141663806908838, 12.567816039392048, 12.979984591670362, 13.379461872586655, 13.76735268670052, 14.144610280951541, 14.512063946937392, 14.870440477672478, 15.22038107275899, 15.562454819211526, 15.897169559390125, 16.224980739587952, 16.546298679765215, 16.86149459567568, 17.17090562550502, 17.47483905505284, 17.77357589231835, 18.067373909896258, 18.356470248934027, 18.641083659487183, 18.921416437465776, 19.197656106931387, 19.469976887505542, 19.73854097951518, 20.003499693803583, 20.264994448555868, 20.523157651784484, 20.778113485107355, 21.02997860198626, 21.278862751566397, 21.52486933758252, 21.768095920406083, 22.008634669147472, 22.2465727697549, 22.481992794234237, 22.714973035423135, 22.945587811167535, 23.173907741250723, 23.400000000000002, 23.623928547132042, 23.84575433908519, 24.06553552281769, 24.283327613817676, 24.49918365986916, 24.71315439194277, 24.92528836342721, 25.135632078784095, 25.344230112591703, 25.551125219841104, 25.756358438257532, 25.959969183340725, 26.16199533674754, 26.362473328578258, 26.56143821407267, 26.75892374517331, 26.95496243736949, 27.14958563219704, 27.342823555733965, 27.53470537340104, 27.72525924134886, 27.91451235468748, 28.102490992792795, 28.289220561903083, 28.474725635201477, 28.65902999056319, 28.84215664613172, 29.024127893874784, 29.204965331258315, 29.38468989116612, 29.563321870182317, 29.740880955344956, 29.917386249470393, 30.09285629514088, 30.267309097440428, 30.44076214551798, 30.61323243305091, 30.784736477676727, 30.95529033945571, 31.124909638423052, 31.29360957128468, 31.461404927307367, 31.62831010345004, 31.79433911878025, 31.959505628216473, 32.12382293563455, 32.28730400637378, 32.449961479175904, 32.611807677588196], [0.0, 3.3674916480965473, 4.762352359916263, 5.8326666285670745, 6.734983296193095, 7.529940238806681, 8.248636250920512, 8.909545442950499, 9.524704719832526, 10.102474944289641, 10.648943609579309, 11.168706281391772, 11.665333257134149, 12.141663806908838, 12.6, 13.042239071570494, 13.46996659238619, 13.88452375848736, 14.287057079748788, 14.678555787270081, 15.059880477613362, 15.431785379534023, 15.794935897305821, 16.149922600433726, 16.497272501841024, 16.837458240482736, 17.17090562550502, 17.497999885701223, 17.819090885900998, 18.134497511648895, 18.444511378727274, 18.74939999039969, 19.04940943966505, 19.344766734184212, 19.635681806344287, 19.922349259060788, 20.204949888579282, 20.483652018133874, 20.75861267040743, 21.029978601986265, 21.297887219158618, 21.562467391279693, 21.823840175367852, 22.08211946349353, 22.337412562783545, 22.589820716420036, 22.839439572809138, 23.08635960908519, 23.330666514268298, 23.572441536675832, 23.811761799581316, 24.0487005885973, 24.283327613817676, 24.515709249377228, 24.745908752761537, 24.973986465920895, 25.2, 25.424004405285963, 25.646052327795015, 25.866194153759842, 26.084478143140988, 26.300950553164423, 26.51565575278122, 26.728636328851497, 26.93993318477238, 27.149585632197038, 27.35763147642719, 27.564107096004395, 27.76904751697472, 27.972486482256095, 28.17445651649735, 28.374988986782004, 28.574114159497576, 28.771861253662408, 28.968258490975945, 29.16333314283537, 29.357111574540163, 29.549619286887605, 29.740880955344956, 29.9309204669686, 30.119760955226724, 30.307424832868925, 30.49393382297535, 30.679308988306758, 30.863570759068047, 31.046738959188612, 31.22883283121545, 31.409871059907264, 31.589871794611643, 31.768852670501023, 31.946830828737927, 32.12382293563454, 32.29984520086745, 32.474913394803686, 32.6490428649907, 32.82224855185884, 32.99454500368205, 33.165946390838904, 33.33646651941384, 33.50611884417531, 33.67491648096547, 33.8428722185337], [0.0, 3.485685011586675, 4.9295030175464944, 6.037383539249432, 6.97137002317335, 7.794228634059948, 8.538149682454623, 9.222255689363639, 9.859006035092989, 10.457055034760023, 11.022703842524301, 11.560709320798617, 12.074767078498864, 12.567816039392046, 13.042239071570494, 13.499999999999998, 13.9427400463467, 14.37184748040418, 14.788509052639483, 15.193748714520718, 15.588457268119896, 15.973415414368963, 16.349311912126456, 16.716758058906038, 17.076299364909246, 17.428425057933374, 17.77357589231835, 18.1121506177483, 18.444511378727277, 18.770988253152787, 19.09188309203678, 19.40747278756304, 19.718012070185978, 20.02373591515829, 20.324861623145186, 20.621590627301277, 20.914110069520046, 21.202594180901542, 21.487205495363977, 21.768095920406086, 22.045407685048602, 22.319274181747037, 22.58982071642004, 22.857165178560525, 23.121418641597234, 23.382685902179837, 23.641065965814654, 23.896652485233155, 24.149534156997728, 24.399795081106724, 24.647515087732476, 24.892770034690795, 25.13563207878409, 25.376169923769034, 25.614449047363873, 25.85053190942113, 26.084478143140988, 26.316344730984202, 26.546186166754726, 26.774054605158323, 26.999999999999996, 27.22407023205751, 27.44631122755843, 27.666767068090913, 27.8854800926934, 28.102490992792788, 28.317838900594086, 28.53156147146524, 28.74369496080836, 28.95427429586174, 29.16333314283537, 29.370903969745296, 29.577018105278967, 29.781705793993734, 29.984996248123824, 30.18691769624716, 30.387497429041435, 30.58676184233957, 30.784736477676727, 30.981446060505306, 31.176914536239792, 31.371165104280074, 31.564220250150328, 31.756101775879227, 31.946830828737927, 32.13642792844282, 32.32491299292234, 32.51230536273919, 32.69862382425291, 32.88388663160119, 33.0681115275729, 33.2513157634401, 33.433516117812076, 33.614728914569575, 33.79497003993345, 33.97425495871837, 34.15259872981849, 34.33001602096917, 34.50652112282546, 34.682127962395846, 34.85685011586675, 35.030700820851415], [0.0, 3.6, 5.091168824543142, 6.235382907247959, 7.2, 8.049844718999244, 8.818163074019441, 9.524704719832526, 10.182337649086284, 10.799999999999999, 11.384199576606166, 11.939849245279442, 12.470765814495918, 12.979984591670362, 13.46996659238619, 13.942740046346701, 14.4, 14.843180252223577, 15.273506473629427, 15.692036196746425, 16.09968943799849, 16.497272501841024, 16.88549673536435, 17.264993483925792, 17.636326148038883, 18.0, 18.356470248934027, 18.706148721743876, 19.04940943966505, 19.386593305684215, 19.718012070185978, 20.04395170618808, 20.364675298172568, 20.680425527536904, 20.991426821443085, 21.297887219158618, 21.599999999999998, 21.897945109073593, 22.191890410688316, 22.481992794234237, 22.768399153212332, 23.051247254758255, 23.330666514268298, 23.6067786874872, 23.879698490558884, 24.149534156997728, 24.416387939250967, 24.68035656144376, 24.941531628991836, 25.200000000000003, 25.455844122715714, 25.709142342754262, 25.959969183340725, 26.20839560140987, 26.454489222058328, 26.69831455354439, 26.93993318477238, 27.1794039669747, 27.416783181110073, 27.652124692326986, 27.885480092693403, 28.116898833263956, 28.34642834644252, 28.57411415949758, 28.8, 29.02412789387478, 29.246538256689455, 29.46726997874082, 29.686360504447155, 29.90384590650507, 30.11976095522672, 30.334139183434893, 30.547012947258853, 30.758413483143116, 30.968370961353457, 31.176914536239792, 31.38407239349285, 31.58987179461164, 31.794339118780254, 31.99749990233612, 32.19937887599698, 32.4, 32.5993864972947, 32.79756088491948, 32.99454500368205, 33.1903600462544, 33.38502658378454, 33.578564591119736, 33.7709934707287, 33.96233207540377, 34.1525987298185, 34.34181125101004, 34.529986967851585, 34.71714273957464, 34.90329497339757, 35.08845964131227, 35.272652296077766, 35.45588808646598, 35.638181771801996, 35.81954773583832, 36.0, 36.17955223603521], [0.0, 3.710795063055895, 5.24785670536077, 6.427285585688566, 7.42159012611179, 8.2975900115636, 9.08955444452587, 9.817840903172144, 10.49571341072154, 11.132385189167682, 11.734564329364767, 12.30731489805961, 12.854571171377131, 13.379461872586655, 13.884523758487362, 14.37184748040418, 14.84318025222358, 15.299999999999999, 15.74357011608231, 16.174980680050286, 16.5951800231272, 17.004999264922066, 17.405171645232347, 17.79634793995667, 18.17910888905174, 18.553975315279473, 18.921416437465776, 19.281856757065697, 19.635681806344287, 19.983242980057067, 20.324861623145186, 20.660832509848195, 20.99142682144308, 21.31689470818862, 21.637467504308358, 21.953359651770842, 22.264770378335363, 22.571885167172017, 22.8748770488499, 23.173907741250723, 23.469128658729534, 23.760681808399355, 24.0487005885973, 24.33331050227239, 24.61462979611922, 24.89277003469079, 25.167836617397214, 25.439929245184626, 25.709142342754262, 25.975565441391264, 26.239283526803852, 26.500377355803824, 26.75892374517331, 27.014995835646545, 27.268663333577614, 27.51999273255718, 27.769047516974723, 28.015888349292087, 28.26057324259365, 28.503157719803603, 28.74369496080836, 28.98223593858831, 29.218829545346267, 29.453522709516427, 29.68636050444716, 29.91738624947039, 30.146641603999605, 30.374166655235168, 30.599999999999998, 30.824178821178673, 31.046738959188612, 31.267714978872377, 31.48714023216462, 31.70504691685537, 31.921466131742758, 32.13642792844283, 32.34996136010057, 32.56209452722598, 32.77285462085963, 32.98226796325565, 33.1903600462544, 33.39715556750305, 33.60267846467005, 33.806951947787304, 34.00999852984413, 34.211840055746784, 34.41249772974929, 34.61199214145294, 34.810343290464694, 35.0075706097981, 35.2036929880943, 35.39872879073484, 35.59269587991334, 35.78561163372788, 35.97749296435203, 36.16835633533821, 36.35821777810348, 36.54709290764452, 36.734996937525395, 36.921944694178826, 37.107950630558946, 37.2930288391812], [0.0, 3.8183766184073566, 5.3999999999999995, 6.613622305514581, 7.636753236814713, 8.538149682454625, 9.353074360871938, 10.102474944289643, 10.799999999999999, 11.455129855222069, 12.074767078498864, 12.664122551523262, 13.227244611029162, 13.76735268670052, 14.28705707974879, 14.788509052639485, 15.273506473629427, 15.74357011608231, 16.2, 16.643917808016237, 17.07629936490925, 17.497999885701223, 17.90977386791916, 18.312290954438225, 18.706148721743876, 19.091883092036785, 19.469976887505542, 19.840866916543746, 20.204949888579286, 20.562587385832554, 20.91411006952005, 21.25982125983189, 21.599999999999998, 21.934903692517096, 22.26477037833537, 22.58982071642004, 22.910259710444137, 23.226278221015093, 23.538054295119636, 23.84575433908519, 24.149534156997728, 24.449539872971027, 24.745908752761537, 25.038769937838396, 25.328245103046523, 25.61444904736387, 25.897490225888685, 26.177471230048177, 26.454489222058324, 26.728636328851497, 27.0, 27.268663333577614, 27.53470537340104, 27.798201380664903, 28.059223082615816, 28.317838900594094, 28.57411415949758, 28.828111280484542, 29.079889958526326, 29.32950732624058, 29.57701810527897, 29.822474746405604, 30.06592755928212, 30.307424832868925, 30.547012947258853, 30.784736477676724, 31.020638291305353, 31.254759637533606, 31.48714023216462, 31.717818336070973, 31.946830828737927, 32.17421327709506, 32.4, 32.62422412870535, 32.846917663610384, 33.0681115275729, 33.287835616032474, 33.50611884417531, 33.72298919135136, 33.938473742936644, 34.1525987298185, 34.36538956566621, 34.576870882137385, 34.78706656215784, 34.995999771402445, 35.2036929880943, 35.4101680312308, 35.615446087336885, 35.81954773583832, 36.022492973141105, 36.2243012354966, 36.42499142072651, 36.62458190887645, 36.82309058186181, 37.02053484216564, 37.21693163064359, 37.41229744348775, 37.60664834839712, 37.800000000000004, 37.99236765456978, 38.18376618407357, 38.37421008959012], [0.0, 3.9230090491866068, 5.547972602672079, 6.794850991743676, 7.8460180983732135, 8.77211491032807, 9.609370426828182, 10.379306335203717, 11.095945205344158, 11.769027147559818, 12.4056438768812, 13.011149065320867, 13.589701983487352, 14.144610280951541, 14.678555787270083, 15.19374871452072, 15.692036196746427, 16.174980680050286, 16.643917808016237, 17.1, 17.54422982065614, 17.977485919894363, 18.40054347023479, 18.81409046433019, 19.218740853656364, 19.615045245933032, 20.003499693803587, 20.384552975231028, 20.758612670407434, 21.126050269749907, 21.48720549536398, 21.842389979120878, 22.191890410688316, 22.53597124598805, 22.874877048849907, 23.20883452480973, 23.538054295119636, 23.862732450413137, 24.183051916579927, 24.499183659869164, 24.8112877537624, 25.119514326515155, 25.424004405285967, 25.724890670321614, 26.022298130641733, 26.316344730984202, 26.60714189837007, 26.894795035471088, 27.179403966974704, 27.461063344306247, 27.7398630133604, 28.01588834929209, 28.289220561903083, 28.55993697472038, 28.828111280484546, 29.09381377544031, 29.357111574540166, 29.618068809427808, 29.876746810856105, 30.13320427700977, 30.38749742904144, 30.639680154988564, 30.88980414311493, 31.137919005611153, 31.384072393492854, 31.628310103450044, 31.870676177326395, 32.111212994840294, 32.34996136010057, 32.586960582417014, 32.82224855185885, 33.05586180997253, 33.287835616032474, 33.51820400916494, 33.74699986665482, 33.974254958718376, 34.2, 34.4242646980295, 34.647077798856294, 34.86846713005893, 35.08845964131228, 35.30708144267946, 35.524357840783, 35.74031337299661, 35.954971839788726, 36.16835633533822, 36.38048927653393, 36.59139243046102, 36.80108694046958, 37.00959335091377, 37.2169316306436, 37.42312119532523, 37.62818092866038, 37.83212920257067, 38.034983896407795, 38.2367624152464, 38.43748170731273, 38.637158280598236, 38.83580821870456, 39.0334471959626, 39.230090491866065, 39.42575300485712], [0.0, 4.024922359499622, 5.692099788303083, 6.9713700231733515, 8.049844718999244, 9.000000000000002, 9.85900603509299, 10.64894360957931, 11.384199576606166, 12.074767078498864, 12.727922061357857, 13.349157276772196, 13.942740046346703, 14.51206394693739, 15.05988047761336, 15.588457268119896, 16.09968943799849, 16.5951800231272, 17.07629936490925, 17.54422982065614, 18.000000000000004, 18.44451137872728, 18.87855926706273, 19.3028495305745, 19.71801207018598, 20.12461179749811, 20.523157651784487, 20.914110069520056, 21.29788721915862, 21.674870241826135, 22.045407685048602, 22.40981927637972, 22.768399153212332, 23.121418641597234, 23.469128658729538, 23.811761799581316, 24.149534156997728, 24.4826469157238, 24.8112877537624, 25.1356320787841, 25.455844122715714, 25.772077913897437, 26.08447814314099, 26.39318093750732, 26.698314553544392, 27.0, 27.298351598585583, 27.59347749016061, 27.885480092693406, 28.174456516497354, 28.460498941515418, 28.743694960808366, 29.02412789387478, 29.301877072979476, 29.577018105278974, 29.849623113198604, 30.11976095522672, 30.387497429041442, 30.65289545866753, 30.9160152671718, 31.176914536239792, 31.435648553831367, 31.692270350986217, 31.946830828737927, 32.19937887599698, 32.449961479175904, 32.69862382425291, 32.94540939190163, 33.1903600462544, 33.43351611781208, 33.67491648096548, 33.914598626550195, 34.1525987298185, 34.38895171417705, 34.62369131100842, 34.856850115866756, 35.08845964131228, 35.318550366627456, 35.547151784636704, 35.774292445833225, 36.00000000000001, 36.2243012354966, 36.44722211636986, 36.66878781743406, 36.88902275745456, 37.107950630558946, 37.3255944359899, 37.54197650630558, 37.75711853412546, 37.971041597512176, 38.18376618407357, 38.39531221386278, 38.605699061149, 38.81494557512609, 39.02307009962184, 39.23009049186606, 39.43602414037196, 39.640887981981436, 39.84469851812158, 40.04747183031659, 40.24922359499622, 40.449969097639624], [0.0, 4.124318125460256, 5.8326666285670745, 7.143528539874396, 8.248636250920512, 9.22225568936364, 10.102474944289643, 10.911920087683928, 11.665333257134149, 12.372954376380767, 13.042239071570496, 13.6788157382136, 14.287057079748791, 14.870440477672476, 15.431785379534023, 15.973415414368963, 16.497272501841024, 17.004999264922066, 17.497999885701223, 17.977485919894363, 18.44451137872728, 18.900000000000002, 19.344766734184212, 19.77953487825232, 20.204949888579286, 20.62159062730128, 21.02997860198626, 21.430585619623187, 21.823840175367856, 22.21013282265552, 22.58982071642004, 22.963231479911535, 23.330666514268298, 23.692403845958733, 24.048700588597303, 24.399795081106728, 24.745908752761533, 25.08724775657944, 25.424004405285963, 25.75635843825754, 26.08447814314099, 26.40852135201818, 26.728636328851497, 27.04496256237009, 27.3576314764272, 27.666767068090913, 27.972486482256098, 28.274900530329017, 28.574114159497583, 28.870226878221796, 29.163333142835373, 29.453522709516434, 29.740880955344952, 30.025489171702105, 30.30742483286893, 30.586761842339573, 30.863570759068047, 31.137919005611153, 31.40987105990727, 31.67948863223647, 31.946830828737927, 32.2119543027119, 32.47491339480369, 32.73576026305178, 32.99454500368205, 33.2513157634401, 33.50611884417531, 33.758998800319894, 34.00999852984413, 34.259159359213704, 34.50652112282547, 34.75212223735409, 34.995999771402445, 35.23818951081341, 35.47872601996865, 35.71764269937198, 35.954971839788726, 36.190744673189585, 36.42499142072652, 36.65774133794934, 36.88902275745456, 37.118863129142305, 37.347289058243575, 37.574326341266584, 37.800000000000004, 38.0243343136997, 38.2473528495764, 38.46907849169252, 38.689533468368424, 38.90873937819112, 39.12671721471148, 39.34348738990991, 39.55906975650464, 39.77348362917184, 39.98674780474151, 40.19888058142913, 40.40989977715857, 40.61982274702834, 40.82866639996952, 41.036447214640795, 41.24318125460256, 41.44888418281004], [0.0, 4.221374183841087, 5.96992462263972, 7.3116345641723655, 8.442748367682174, 9.439279633531365, 10.340212763768452, 11.168706281391772, 11.93984924527944, 12.664122551523258, 13.349157276772194, 14.000714267493644, 14.623269128344731, 15.220381072758988, 15.79493589730582, 16.349311912126456, 16.88549673536435, 17.405171645232343, 17.90977386791916, 18.400543470234787, 18.87855926706273, 19.344766734184212, 19.8, 20.244999382563588, 20.680425527536904, 21.106870919205434, 21.52486933758252, 21.934903692517096, 22.337412562783545, 22.732795692567162, 23.12141864159723, 23.50361674296107, 23.87969849055888, 24.249948453553465, 24.61462979611922, 24.973986465920895, 25.328245103046516, 25.67761671183679, 26.02229813064173, 26.36247332857826, 26.69831455354439, 27.029983351826175, 27.357631476427198, 27.681401698613453, 28.001428534987287, 28.31783890059409, 28.63075269705636, 28.94028334346435, 29.246538256689462, 29.54961928688761, 29.8496231131986, 30.146641603999612, 30.440762145517976, 30.732067942134975, 31.020638291305357, 31.30654883566696, 31.58987179461164, 31.870676177326395, 32.14902797908516, 32.42499036237327, 32.69862382425291, 32.969986351225565, 33.2391335627149, 33.50611884417531, 33.7709934707287, 34.03380672214027, 34.29460598986377, 34.55343687681444, 34.81034329046469, 35.06536752980068, 35.31855036662745, 35.56993112166511, 35.81954773583832, 36.06743683712499, 36.31363380329763, 36.55817282086183, 36.801086940469574, 37.042408129062025, 37.28216731897437, 37.52039445421649, 37.75711853412546, 37.99236765456978, 38.22616904687155, 38.458549114598696, 38.689533468368424, 38.91914695879138, 39.14741370767678, 39.374357137609245, 39.6, 39.824364401707655, 40.04747183031658, 40.26934317815477, 40.489998765127176, 40.709458360435114, 40.927741203247464, 41.14486602238485, 41.36085105507381, 41.575714064823956, 41.789472358478044, 42.002142802480925, 42.21374183841087, 42.424285497813635], [0.0, 4.316248370981448, 6.104096984812742, 7.475961476626268, 8.632496741962896, 9.65142476528725, 10.572606112023658, 11.419719786404569, 12.208193969625484, 12.948745112944342, 13.649175799292792, 14.315376348528183, 14.951922953252536, 15.562454819211526, 16.149922600433726, 16.716758058906038, 17.264993483925792, 17.79634793995667, 18.312290954438225, 18.81409046433019, 19.3028495305745, 19.779534878252324, 20.24499938256359, 20.700000000000003, 21.145212224047317, 21.58124185490724, 22.008634669147472, 22.427884429878805, 22.839439572809138, 23.243708826260928, 23.641065965814654, 24.031853861073643, 24.416387939250967, 24.794959165120645, 25.167836617397217, 25.535269726399996, 25.897490225888685, 26.25471386246668, 26.60714189837007, 26.954962437369492, 27.298351598585583, 27.63747455901136, 27.972486482256098, 28.303533348329495, 28.630752697056366, 28.95427429586174, 29.27422074112307, 29.59070800099248, 29.903845906505072, 30.213738596870137, 30.52048492406371, 30.82417882117868, 31.124909638423052, 31.422762450172968, 31.717818336070977, 32.01015463880174, 32.29984520086745, 32.586960582417014, 32.87156826194942, 33.15373282150895, 33.433516117812076, 33.710977440590476, 33.98617365929857, 34.259159359213704, 34.529986967851585, 34.79870687252617, 35.06536752980068, 35.33001556750294, 35.59269587991334, 35.853451716675764, 36.11232476592998, 36.36935523211815, 36.62458190887645, 36.87804224738618, 37.129772420525285, 37.37980738313134, 37.62818092866038, 37.87492574250147, 38.120073452185274, 38.36365467470481, 38.605699061149, 38.84623533883303, 39.08529135109524, 39.322894094916265, 39.55906975650465, 39.793843744981466, 40.027240724286756, 40.259284643421076, 40.48999876512718, 40.71940569310903, 40.947527397878375, 41.17438524131235, 41.400000000000006, 41.624391887449846, 41.847580575225614, 42.06958521307288, 42.29042444809463, 42.51011644303036, 42.72867889368919, 42.94612904558455, 43.16248370981448, 43.37775927822921], [0.0, 4.409081537009721, 6.235382907247958, 7.636753236814714, 8.818163074019441, 9.859006035092992, 10.8, 11.665333257134149, 12.470765814495916, 13.22724461102916, 13.942740046346701, 14.623269128344731, 15.273506473629428, 15.897169559390125, 16.497272501841024, 17.076299364909246, 17.636326148038883, 18.17910888905174, 18.706148721743876, 19.21874085365636, 19.718012070185985, 20.204949888579286, 20.680425527536904, 21.145212224047317, 21.6, 22.045407685048605, 22.481992794234234, 22.910259710444144, 23.330666514268298, 23.743630724891254, 24.149534156997728, 24.54872705457454, 24.941531628991832, 25.328245103046523, 25.709142342754262, 26.08447814314099, 26.45448922205832, 26.819395966352413, 27.1794039669747, 27.534705373401042, 27.885480092693403, 28.23189685444462, 28.57411415949758, 28.912281127576215, 29.246538256689462, 29.577018105278967, 29.90384590650507, 30.227140122744, 30.547012947258857, 30.863570759068047, 31.176914536239792, 31.487140232164627, 31.79433911878025, 32.09859810022862, 32.400000000000006, 32.69862382425291, 32.99454500368205, 33.287835616032474, 33.578564591119736, 33.8667979000082, 34.15259872981849, 34.43602764547618, 34.71714273957464, 34.995999771402445, 35.272652296077766, 35.5471517846367, 35.81954773583832, 36.089887780374156, 36.35821777810348, 36.62458190887645, 36.889022757454555, 37.15158139299053, 37.41229744348775, 37.671209165621434, 37.92835351026986, 38.18376618407357, 38.43748170731272, 38.689533468368424, 38.93995377501109, 39.18877390273904, 39.43602414037197, 39.681733833087485, 39.925931423073905, 40.16864448795852, 40.40989977715857, 40.64972324629038, 40.88814008976197, 41.12517477166511, 41.36085105507381, 41.59519202984884, 41.828220139040106, 42.05995720397252, 42.29042444809463, 42.51964251966378, 42.74763151333651, 42.974410990727954, 43.2, 43.424417094533354, 43.64768035073571, 43.86980738503419, 44.09081537009721, 44.31072105032822], [0.0, 4.500000000000001, 6.363961030678928, 7.794228634059949, 9.000000000000002, 10.062305898749056, 11.022703842524303, 11.905880899790658, 12.727922061357855, 13.5, 14.230249470757707, 14.924811556599302, 15.588457268119898, 16.224980739587952, 16.837458240482736, 17.428425057933378, 18.000000000000004, 18.553975315279473, 19.091883092036785, 19.615045245933032, 20.124611797498112, 20.621590627301284, 21.106870919205438, 21.58124185490724, 22.045407685048605, 22.5, 22.945587811167535, 23.382685902179848, 23.811761799581316, 24.23324163210527, 24.647515087732476, 25.0549396327351, 25.45584412271571, 25.850531909421132, 26.239283526803856, 26.622359023948274, 27.0, 27.37243138634199, 27.739863013360395, 28.1024909927928, 28.460498941515414, 28.814059068447822, 29.163333142835373, 29.508473359359, 29.849623113198604, 30.18691769624716, 30.52048492406371, 30.850445701804702, 31.176914536239796, 31.500000000000004, 31.819805153394643, 32.13642792844283, 32.449961479175904, 32.76049450176234, 33.06811152757291, 33.37289319193049, 33.67491648096547, 33.974254958718376, 34.270978976387596, 34.565155865408734, 34.856850115866756, 35.14612354157995, 35.43303543305315, 35.71764269937197, 36.00000000000001, 36.28015986734347, 36.55817282086182, 36.834087473426024, 37.107950630558946, 37.379807383131336, 37.649701194033405, 37.91767397929362, 38.18376618407357, 38.4480168539289, 38.71046370169182, 38.97114317029974, 39.230090491866065, 39.48733974326455, 39.74292389847532, 39.99687487792015, 40.249223594996224, 40.50000000000001, 40.74923312161838, 40.996951106149346, 41.24318125460257, 41.487950057818, 41.73128322973067, 41.97320573889967, 42.213741838410876, 42.45291509425472, 42.69074841227312, 42.92726406376256, 43.16248370981448, 43.396428424468304, 43.629118716746966, 43.86057455164033, 44.09081537009721, 44.31986010808248, 44.5477272147525, 44.774434669797905, 45.0, 45.22444029504401], [0.0, 4.589117562233507, 6.489992295835181, 7.9485847796950635, 9.178235124467014, 10.261578825892244, 11.240996397117119, 12.141663806908838, 12.979984591670362, 13.76735268670052, 14.51206394693739, 15.22038107275899, 15.897169559390127, 16.546298679765215, 17.17090562550502, 17.77357589231835, 18.356470248934027, 18.921416437465776, 19.469976887505542, 20.003499693803583, 20.523157651784487, 21.029978601986265, 21.52486933758252, 22.008634669147472, 22.481992794234237, 22.945587811167535, 23.400000000000002, 23.84575433908519, 24.283327613817676, 24.71315439194277, 25.135632078784095, 25.551125219841104, 25.959969183340725, 26.36247332857826, 26.758923745173316, 27.14958563219704, 27.53470537340104, 27.914512354687485, 28.289220561903083, 28.65902999056319, 29.02412789387478, 29.38468989116612, 29.740880955344952, 30.092856295140876, 30.44076214551798, 30.784736477676724, 31.124909638423052, 31.461404927307367, 31.794339118780254, 32.12382293563455, 32.449961479175904, 32.77285462085963, 33.09259735953043, 33.40928014788706, 33.72298919135135, 34.03380672214027, 34.34181125101004, 34.64707779885629, 34.94967811010569, 35.24968084961905, 35.5471517846367, 35.84215395313178, 36.134747819792516, 36.42499142072651, 36.712940497868054, 36.99864862397004, 37.28216731897436, 37.56354615847657, 37.84283287493155, 38.12007345218527, 38.39531221386278, 38.66859190609351, 38.939953775011084, 39.209437639425545, 39.47708195903036, 39.74292389847532, 40.006999387607166, 40.26934317815477, 40.529988897111735, 40.78896909704878, 41.046315303568974, 41.30205806010156, 41.55622697021471, 41.808850737612964, 42.05995720397253, 42.309573384755375, 42.5577255031328, 42.804439022138816, 43.04973867516504, 43.2936484949005, 43.53619184081217, 43.77739142525512, 44.017269338294945, 44.255847071319295, 44.4931455395098, 44.729185103241036, 44.963985588468475, 45.197566306163, 45.42994607084627, 45.66114321827697, 45.89117562233507, 46.120060711148255], [0.0, 4.676537180435969, 6.613622305514581, 8.100000000000001, 9.353074360871938, 10.457055034760028, 11.45512985522207, 12.372954376380768, 13.227244611029162, 14.029611541307906, 14.788509052639487, 15.51031914565268, 16.200000000000003, 16.861494595675676, 17.497999885701223, 18.1121506177483, 18.706148721743876, 19.281856757065697, 19.840866916543742, 20.384552975231028, 20.914110069520056, 21.430585619623187, 21.934903692517096, 22.427884429878805, 22.91025971044414, 23.382685902179844, 23.84575433908519, 24.300000000000004, 24.745908752761537, 25.183923443339804, 25.614449047363873, 26.03785705468098, 26.454489222058324, 26.864660801878742, 27.268663333577614, 27.666767068090916, 28.059223082615812, 28.446265132702397, 28.828111280484542, 29.204965331258318, 29.577018105278974, 29.94444856730543, 30.30742483286893, 30.666105067321475, 31.02063829130536, 31.371165104280074, 31.717818336070973, 32.06072363500238, 32.400000000000006, 32.73576026305179, 33.06811152757291, 33.397155567503056, 33.72298919135135, 34.045704574879935, 34.36538956566621, 34.68212796239585, 34.995999771402445, 35.30708144267946, 35.61544608733689, 35.92116367825519, 36.2243012354966, 36.524922997865445, 36.82309058186181, 37.118863129142305, 37.41229744348775, 37.70344811817614, 37.992367654569776, 38.27910657264613, 38.56371351413139, 38.84623533883303, 39.12671721471149, 39.40520270218135, 39.681733833087485, 39.95635118476161, 40.22909394952862, 40.50000000000001, 40.769105950462055, 41.036447214640795, 41.302058060101565, 41.56597165951976, 41.82822013904011, 42.088834623923724, 42.347845281666935, 42.60528136276065, 42.861171239246374, 43.11554244121255, 43.36842169136433, 43.619834937789484, 43.86980738503419, 44.11836352359412, 44.36552715791846, 44.61132143301743, 44.85576885975761, 45.09889133892318, 45.340710184116, 45.581246143562154, 45.82051942088828, 46.058549694926356, 46.29535613860207, 46.53095743695804, 46.76537180435969, 46.998617000928874], [0.0, 4.762352359916263, 6.734983296193095, 8.248636250920512, 9.524704719832526, 10.64894360957931, 11.665333257134149, 12.6, 13.46996659238619, 14.287057079748788, 15.05988047761336, 15.794935897305821, 16.497272501841024, 17.17090562550502, 17.819090885900998, 18.444511378727277, 19.04940943966505, 19.635681806344287, 20.204949888579282, 20.758612670407434, 21.29788721915862, 21.823840175367856, 22.337412562783545, 22.839439572809138, 23.330666514268298, 23.811761799581316, 24.283327613817676, 24.74590875276154, 25.2, 25.646052327795015, 26.084478143140988, 26.515655752781225, 26.93993318477238, 27.357631476427198, 27.769047516974727, 28.17445651649735, 28.574114159497576, 28.96825849097595, 29.357111574540163, 29.740880955344956, 30.11976095522672, 30.49393382297535, 30.863570759068047, 31.228832831215446, 31.589871794611643, 31.946830828737923, 32.29984520086745, 32.6490428649907, 32.99454500368205, 33.33646651941385, 33.67491648096547, 34.00999852984413, 34.34181125101004, 34.6704485116648, 34.995999771402445, 35.318550366627456, 35.638181771801996, 35.954971839788726, 36.2689950232978, 36.58032257922283, 36.889022757454555, 37.19516097558928, 37.49879998079938, 37.8, 38.0988188793301, 38.39531221386277, 38.68953346836842, 38.98153408987388, 39.271363612688575, 39.55906975650464, 39.84469851812158, 40.12829425729432, 40.409899777158564, 40.689556399646335, 40.967304036267755, 41.24318125460256, 41.51722534081487, 41.78947235847804, 42.05995720397253, 42.328713658697446, 42.59577443831724, 42.86117123924637, 43.124934782559386, 43.38709485549822, 43.64768035073571, 43.906719303541685, 44.16423892698707, 44.42026564531104, 44.67482512556709, 44.927942307655265, 45.17964143284008, 45.42994607084626, 45.678879145618275, 45.92646295982307, 46.17271921817038, 46.417669049619455, 46.661333028536596, 46.90373119486338, 47.144883073351664, 47.384807691917466, 47.62352359916263, 47.861048881109994], [0.0, 4.846648326421054, 6.854195795277517, 8.394641147779934, 9.693296652842108, 10.837435120913067, 11.871815362445629, 12.823026163897508, 13.708391590555035, 14.53994497926316, 15.326447729333761, 16.07451398954258, 16.789282295559868, 17.47483905505284, 18.134497511648895, 18.77098825315279, 19.386593305684215, 19.983242980057067, 20.562587385832554, 21.126050269749907, 21.674870241826135, 22.21013282265552, 22.732795692567162, 23.243708826260928, 23.743630724891258, 24.23324163210527, 24.71315439194277, 25.183923443339804, 25.646052327795015, 26.1, 26.546186166754726, 26.98499583101691, 27.41678318111007, 27.84187493686444, 28.26057324259365, 28.673158179733186, 29.07988995852632, 29.48101083748656, 29.876746810856098, 30.26730909744043, 30.652895458667523, 31.033691369220005, 31.409871059907267, 31.78159844941723, 32.14902797908516, 32.5123053627392, 32.87156826194941, 33.22694689555452, 33.578564591119736, 33.92653828494738, 34.27097897638759, 34.611992141452944, 34.94967811010568, 35.28413241104279, 35.615446087336885, 35.94370598588855, 36.26899502329779, 36.59139243046102, 36.910973977937786, 37.22781218390358, 37.54197650630558, 37.85353352066356, 38.162547084805546, 38.46907849169252, 38.77318661136843, 39.07492802296634, 39.374357137609245, 39.67152631296154, 39.966485960114134, 40.259284643421076, 40.54996917384772, 40.838584696338344, 41.12517477166511, 41.40978145317843, 41.692445358841695, 41.97320573889967, 42.252100539499814, 42.52916646255838, 42.80443902213882, 43.077952597587554, 43.34974048365227, 43.619834937789484, 43.888267224851795, 44.15506765932989, 44.42026564531104, 44.68388971430308, 44.945967561061586, 45.2065260775477, 45.465591385134324, 45.72318886516994, 45.97934318800129, 46.23407834054876, 46.487417652521856, 46.73938382135563, 46.98999893594381, 47.23928449923855, 47.487261449782515, 47.73395018223403, 47.97937056694263, 48.223541968627735, 48.46648326421054, 48.70821285984532], [0.0, 4.929503017546495, 6.97137002317335, 8.538149682454625, 9.85900603509299, 11.022703842524303, 12.074767078498864, 13.042239071570494, 13.9427400463467, 14.788509052639483, 15.588457268119894, 16.349311912126456, 17.07629936490925, 17.77357589231835, 18.444511378727277, 19.09188309203678, 19.71801207018598, 20.324861623145186, 20.91411006952005, 21.48720549536398, 22.045407685048605, 22.58982071642004, 23.121418641597234, 23.641065965814654, 24.149534156997728, 24.647515087732472, 25.135632078784095, 25.614449047363873, 26.084478143140988, 26.546186166754726, 26.999999999999996, 27.44631122755843, 27.8854800926934, 28.317838900594094, 28.743694960808362, 29.16333314283537, 29.577018105278967, 29.984996248123828, 30.387497429041435, 30.784736477676727, 31.17691453623979, 31.564220250150328, 31.946830828737927, 32.32491299292234, 32.69862382425291, 33.068111527572896, 33.433516117812076, 33.79497003993345, 34.1525987298185, 34.50652112282547, 34.85685011586675, 35.2036929880943, 35.5471517846367, 35.887323667278395, 36.2243012354966, 36.55817282086182, 36.889022757454555, 37.2169316306436, 37.54197650630558, 37.86423114233273, 38.18376618407356, 38.500649345173386, 38.81494557512608, 39.12671721471148, 39.43602414037196, 39.742923898475304, 40.047471830316574, 40.349721188627804, 40.64972324629037, 40.94752739787837, 41.24318125460256, 41.536730733171574, 41.8282201390401, 42.11769224447133, 42.405188361803084, 42.690748412273116, 42.97441099072796, 43.256213426512495, 43.53619184081217, 43.8143812006971, 44.09081537009721, 44.36552715791846, 44.63854836349408, 44.90990981954873, 45.17964143284008, 45.44777222262935, 45.71433035712106, 45.97934318800128, 46.24283728319447, 46.504838457949724, 46.76537180435968, 47.02446171940727, 47.28213193162931, 47.53840552647932, 47.79330497046631, 48.04685213414089, 48.299068313995456, 48.54997425334024, 48.79959016221345, 49.047935736379365, 49.295030175464944, 49.540892200282386], [0.0, 5.01098792654702, 7.08660708661063, 8.67928568489366, 10.02197585309404, 11.20490963818986, 12.27436352728727, 13.257827876390612, 14.17321417322126, 15.032963779641058, 15.846135175493108, 16.619566781357452, 17.35857136978732, 18.067373909896258, 18.74939999039969, 19.40747278756304, 20.04395170618808, 20.66083250984819, 21.259821259831888, 21.842389979120874, 22.40981927637972, 22.963231479911535, 23.503616742961075, 24.031853861073643, 24.54872705457454, 25.0549396327351, 25.551125219841104, 26.03785705468098, 26.515655752781225, 26.98499583101691, 27.44631122755843, 27.900000000000002, 28.34642834644252, 28.78593406509506, 29.21882954534627, 29.645404365601088, 30.065927559282116, 30.48064959937698, 30.889804143114926, 31.293609571284684, 31.692270350986217, 32.085978245956596, 32.474913394803686, 32.85924527435163, 33.239133562714905, 33.614728914569575, 33.98617365929857, 34.35360243118617, 34.71714273957464, 35.07691548582914, 35.43303543305315, 35.78561163372788, 36.134747819792516, 36.48054275912024, 36.82309058186181, 37.16248107971264, 37.49879998079938, 37.83212920257066, 38.162547084805546, 38.49012860461757, 38.81494557512608, 39.13706682928602, 39.45655839020935, 39.773483629171835, 40.08790341237616, 40.39987623743419, 40.70945836043511, 41.016703914381026, 41.32166501969638, 41.62439188744984, 41.924932915867615, 42.22333478066364, 42.519642519663776, 42.81389961215867, 43.10614805338097, 43.3964284244683, 43.68477995824175, 43.97124060110199, 44.255847071319295, 44.53863491397104, 44.81963855275944, 45.09889133892318, 45.37642559743991, 45.65227267070063, 45.92646295982307, 46.19902596375815, 46.46999031633211, 46.739383821355624, 47.00723348592215, 47.27356555200803, 47.53840552647932, 47.801778209602205, 48.063707722147285, 48.324217531171676, 48.58333047455681, 48.841068784374485, 49.09745410914908, 49.35250753507871, 49.60624960627441, 49.85870034407235, 50.1098792654702, 50.359805400736015], [0.0, 5.091168824543142, 7.199999999999999, 8.818163074019441, 10.182337649086284, 11.384199576606166, 12.470765814495916, 13.46996659238619, 14.399999999999999, 15.273506473629425, 16.099689437998485, 16.88549673536435, 17.636326148038883, 18.356470248934023, 19.04940943966505, 19.718012070185978, 20.364675298172568, 20.99142682144308, 21.599999999999998, 22.191890410688316, 22.768399153212332, 23.330666514268298, 23.87969849055888, 24.416387939250967, 24.941531628991832, 25.45584412271571, 25.959969183340725, 26.454489222058324, 26.93993318477238, 27.41678318111007, 27.8854800926934, 28.34642834644252, 28.799999999999997, 29.24653825668946, 29.68636050444716, 30.119760955226717, 30.54701294725885, 30.968370961353457, 31.384072393492847, 31.794339118780254, 32.19937887599697, 32.5993864972947, 32.99454500368205, 33.38502658378453, 33.7709934707287, 34.15259872981849, 34.52998696785158, 34.90329497339757, 35.272652296077766, 35.638181771801996, 36.0, 36.35821777810348, 36.71294049786805, 37.0642685075532, 37.41229744348775, 37.75711853412545, 38.0988188793301, 38.43748170731272, 38.77318661136843, 39.10600976832077, 39.436024140371956, 39.763299661874136, 40.08790341237616, 40.409899777158564, 40.729350596345135, 41.04631530356897, 41.3608510550738, 41.673012850044806, 41.98285364288616, 42.290424448094626, 42.595774438317235, 42.898951036126746, 43.199999999999996, 43.498965504940465, 43.79589021814718, 44.090815370097204, 44.38378082137663, 44.67482512556708, 44.963985588468475, 45.25129832391552, 45.536798306424664, 45.82051942088828, 46.10249450951651, 46.38275541621045, 46.661333028536596, 46.93825731745907, 47.21355737497441, 47.48726144978251, 47.75939698111776, 48.0299906308548, 48.299068313995456, 48.56665522763535, 48.832775878501934, 49.09745410914908, 49.36071312288752, 49.62257550752479, 49.883063257983665, 50.142197797862835, 50.4, 50.65649020609304, 50.91168824543142, 51.16561345278683], [0.0, 5.170106381884226, 7.311634564172365, 8.954886933959582, 10.340212763768452, 11.560709320798619, 12.664122551523262, 13.678815738213599, 14.62326912834473, 15.510319145652677, 16.349311912126456, 17.147302994931888, 17.909773867919164, 18.641083659487183, 19.344766734184212, 20.02373591515829, 20.680425527536904, 21.31689470818862, 21.934903692517093, 22.535971245988048, 23.121418641597238, 23.692403845958733, 24.24994845355347, 24.79495916512064, 25.328245103046523, 25.850531909421132, 26.36247332857826, 26.864660801878745, 27.357631476427198, 27.84187493686444, 28.317838900594094, 28.78593406509506, 29.24653825668946, 29.700000000000006, 30.146641603999612, 30.586761842339573, 31.020638291305353, 31.44852937738107, 31.870676177326395, 32.28730400637378, 32.69862382425291, 33.10483348394914, 33.50611884417532, 33.902654763307254, 34.294605989863776, 34.682127962395846, 35.06536752980068, 35.444463601527396, 35.81954773583833, 36.190744673189585, 36.55817282086183, 36.92194469417883, 37.282167318974366, 37.63894259938768, 37.99236765456978, 38.34253512745343, 38.689533468368424, 39.0334471959626, 39.37435713760925, 39.71234065123837, 40.04747183031658, 40.3798216935142, 40.709458360435114, 41.036447214640795, 41.36085105507381, 41.68273023687388, 42.002142802480925, 42.31914460383149, 42.63378941637724, 42.94612904558454, 43.2562134265125, 43.56409071701142, 43.869807385034186, 44.1734082905089, 44.47493676218102, 44.774434669797905, 45.071942491976095, 45.367499380062824, 45.66114321827697, 45.95291068039108, 46.242837283194476, 46.53095743695804, 46.81730449310383, 47.10191078926629, 47.384807691917466, 47.666025636715304, 47.94559416672193, 48.223541968627735, 48.49989690710694, 48.77468605742123, 49.04793573637937, 49.31967153175293, 49.58991833024128, 49.85870034407235, 50.12604113631956, 50.39196364500991, 50.656490206093046, 50.9196425753363, 51.18144194920656, 51.44190898479567, 51.701063818842265, 51.95892608589982], [0.0, 5.247856705360771, 7.421590126111789, 9.089554444525872, 10.495713410721542, 11.734564329364769, 12.854571171377131, 13.884523758487362, 14.843180252223577, 15.74357011608231, 16.5951800231272, 17.405171645232347, 18.179108889051744, 18.921416437465776, 19.635681806344287, 20.324861623145186, 20.991426821443085, 21.637467504308354, 22.264770378335367, 22.874877048849903, 23.469128658729538, 24.0487005885973, 24.61462979611922, 25.167836617397214, 25.709142342754262, 26.239283526803852, 26.758923745173313, 27.268663333577614, 27.769047516974723, 28.260573242593647, 28.74369496080836, 29.218829545346267, 29.686360504447155, 30.14664160399961, 30.600000000000005, 31.046738959188612, 31.48714023216462, 31.92146613174276, 32.34996136010057, 32.77285462085963, 33.1903600462544, 33.60267846467005, 34.00999852984413, 34.41249772974928, 34.810343290464694, 35.203692988094296, 35.59269587991334, 35.97749296435204, 36.35821777810349, 36.734996937525395, 37.107950630558946, 37.47719306458263, 37.84283287493155, 38.20497349822403, 38.56371351413139, 38.91914695879138, 39.271363612688575, 39.62044926549925, 39.966485960114134, 40.30955221780564, 40.64972324629037, 40.987071132248516, 41.32166501969639, 41.653571275462085, 41.98285364288617, 42.30957338475537, 42.63378941637724, 42.9555584296142, 43.27493500861671, 43.5919717379244, 43.906719303541685, 44.21922658753769, 44.529540756670734, 44.83770734549215, 45.14377033434403, 45.447772222629354, 45.74975409769981, 46.04975569967772, 46.347815482501446, 46.643970671459776, 46.938257317459076, 47.23071034824694, 47.52136361679871, 47.810249947056334, 48.0974011771946, 48.382848200576205, 48.66662100454479, 48.94874870719373, 49.22925959223844, 49.50818114211024, 49.78554006938159, 50.06136234662417, 50.33567323479443, 50.60849731023438, 50.87985849036925, 51.14978005817815, 51.418284685508524, 51.68539445530043, 51.95113088278252, 52.21551493569704, 52.478567053607705, 52.740307166341005], [0.0, 5.324471804789654, 7.529940238806679, 9.222255689363639, 10.648943609579309, 11.90588089979066, 13.042239071570496, 14.087228258248675, 15.059880477613358, 15.973415414368962, 16.837458240482736, 17.659275183313728, 18.444511378727277, 19.197656106931387, 19.92234925906079, 20.621590627301277, 21.297887219158618, 21.953359651770842, 22.58982071642004, 23.208834524809728, 23.81176179958132, 24.399795081106728, 24.973986465920895, 25.535269726399996, 26.08447814314099, 26.622359023948274, 27.14958563219704, 27.66676706809092, 28.17445651649735, 28.673158179733186, 29.163333142835366, 29.645404365601088, 30.119760955226717, 30.586761842339573, 31.046738959188616, 31.5, 31.946830828737923, 32.38749758780385, 32.82224855185884, 33.251315763440104, 33.67491648096547, 34.09325446477646, 34.50652112282547, 34.91489653428748, 35.318550366627456, 35.71764269937197, 36.11232476592998, 36.502739623211845, 36.889022757454555, 37.27130263352758, 37.6497011940334, 38.0243343136997, 38.39531221386277, 38.76273984124445, 39.12671721471148, 39.48733974326455, 39.84469851812158, 40.19888058142913, 40.54996917384772, 40.898043963006344, 41.243181254602554, 41.585454187732516, 41.924932915867615, 42.26168477474602, 42.595774438317235, 42.92726406376255, 43.256213426512495, 43.5826800460917, 43.906719303541685, 44.22838455110021, 44.54772721475249, 44.86479689021226, 45.17964143284008, 45.4923070419604, 45.802838339998104, 46.11127844681819, 46.417669049619455, 46.722050468702676, 47.02446171940728, 47.324940570485666, 47.62352359916264, 47.92024624310689, 48.21514284952395, 48.50824672156271, 48.799590162213455, 49.089204515860715, 49.377120207642726, 49.663366780757016, 49.94797293184179, 50.23096654455297, 50.51237472144821, 50.79222381428086, 51.07053945279999, 51.347346572145284, 51.62266943891995, 51.896531676018576, 52.16895628628198, 52.439965675045976, 52.70958167164676, 52.97782554994118, 53.24471804789655, 53.5102793863011], [0.0, 5.4, 7.636753236814712, 9.353074360871938, 10.8, 12.074767078498866, 13.227244611029162, 14.28705707974879, 15.273506473629425, 16.2, 17.076299364909246, 17.90977386791916, 18.706148721743876, 19.469976887505542, 20.204949888579282, 20.91411006952005, 21.6, 22.264770378335367, 22.910259710444137, 23.538054295119636, 24.14953415699773, 24.745908752761537, 25.32824510304652, 25.897490225888685, 26.454489222058324, 27.0, 27.53470537340104, 28.059223082615816, 28.57411415949758, 29.079889958526323, 29.577018105278967, 30.065927559282116, 30.54701294725885, 31.020638291305357, 31.487140232164624, 31.946830828737923, 32.4, 32.846917663610384, 33.287835616032474, 33.72298919135135, 34.15259872981849, 34.576870882137385, 34.995999771402445, 35.410168031230796, 35.81954773583832, 36.22430123549659, 36.62458190887644, 37.02053484216564, 37.41229744348775, 37.800000000000004, 38.18376618407357, 38.56371351413139, 38.939953775011084, 39.3125934021148, 39.681733833087485, 40.04747183031658, 40.409899777158564, 40.76910595046205, 41.12517477166511, 41.478187038490475, 41.8282201390401, 42.17534824989593, 42.519642519663776, 42.86117123924637, 43.2, 43.536191840812165, 43.86980738503418, 44.200904968111224, 44.529540756670734, 44.8557688597576, 45.17964143284008, 45.501208775152335, 45.820519420888274, 46.137620224714674, 46.452556442030186, 46.76537180435969, 47.07610859023927, 47.38480769191746, 47.69150867817038, 47.996249853504175, 48.29906831399546, 48.6, 48.89907974594205, 49.19634132737921, 49.49181750552307, 49.78554006938159, 50.0775398756768, 50.3678468866796, 50.65649020609304, 50.94349811310566, 51.22889809472775, 51.512716876515064, 51.79498045177737, 52.075714109361954, 52.35494246009635, 52.6326894619684, 52.90897844411665, 53.18383212969897, 53.457272657702994, 53.72932160375748, 54.0, 54.26932835405281], [0.0, 5.474486277268398, 7.742092740338364, 9.482088377567466, 10.948972554536796, 12.2413234578619, 13.409697983176207, 14.484129245487974, 15.484185480676729, 16.423458831805192, 17.31184565550421, 18.156816901648817, 18.964176755134933, 19.73854097951518, 20.483652018133878, 21.202594180901542, 21.897945109073593, 22.571885167172013, 23.226278221015093, 23.862732450413137, 24.4826469157238, 25.08724775657944, 25.677616711836794, 26.25471386246668, 26.819395966352413, 27.37243138634199, 27.914512354687485, 28.4462651327024, 28.96825849097595, 29.48101083748656, 29.984996248123824, 30.48064959937698, 30.968370961353457, 31.44852937738107, 31.921466131742765, 32.38749758780385, 32.846917663610384, 33.300000000000004, 33.74699986665482, 34.18815584380065, 34.62369131100842, 35.05381576947081, 35.47872601996865, 35.89860721532243, 36.313633803297634, 36.72397037358569, 37.129772420525285, 37.53118703158748, 37.928353510269865, 38.32140394087879, 38.71046370169182, 39.09565193215226, 39.47708195903036, 39.85486168587216, 40.229093949528625, 40.599876847103864, 40.967304036267755, 41.33146501153813, 41.692445358841695, 42.050326990405196, 42.405188361803084, 42.75710467279093, 43.10614805338097, 43.45238773646392, 43.795890218147186, 44.136719406861225, 44.47493676218101, 44.810601424216564, 45.143770334344026, 45.47449834797521, 45.802838339998104, 46.1288413034622, 46.452556442030186, 46.774031256670625, 47.093311627024065, 47.41044188783733, 47.725464900826275, 48.03842212229707, 48.34935366682787, 48.65829836728778, 48.9652938314476, 49.27037649541558, 49.573581674113484, 49.87494360899068, 50.17449551315888, 50.47226961411583, 50.76829719421364, 51.06260862901542, 51.35523342367359, 51.64620024745287, 51.935536966512636, 52.22327067505444, 52.50942772493336, 52.79403375382488, 53.07711371203224, 53.358691888013894, 53.63879193270483, 53.91743688270058, 54.19464918236855, 54.470450704946444, 54.74486277268398, 55.01790617608054], [0.0, 5.547972602672079, 7.846018098373213, 9.609370426828182, 11.095945205344158, 12.405643876881202, 13.58970198348735, 14.678555787270083, 15.692036196746425, 16.643917808016237, 17.544229820656135, 18.40054347023479, 19.218740853656364, 20.003499693803583, 20.758612670407434, 21.48720549536398, 22.191890410688316, 22.874877048849903, 23.538054295119636, 24.183051916579927, 24.811287753762404, 25.424004405285967, 26.022298130641733, 26.60714189837007, 27.1794039669747, 27.739863013360395, 28.289220561903083, 28.828111280484546, 29.357111574540166, 29.8767468108561, 30.38749742904144, 30.889804143114926, 31.38407239349285, 31.870676177326395, 32.34996136010058, 32.82224855185885, 33.287835616032474, 33.74699986665482, 34.2, 34.647077798856294, 35.08845964131227, 35.524357840783, 35.954971839788726, 36.38048927653392, 36.80108694046958, 37.2169316306436, 37.62818092866037, 38.034983896407795, 38.43748170731273, 38.83580821870456, 39.230090491866065, 39.62044926549925, 40.006999387607166, 40.38985021017038, 40.769105950462055, 41.14486602238486, 41.51722534081487, 41.88627460159235, 42.252100539499814, 42.61478616630617, 42.97441099072796, 43.3310512219586, 43.68477995824175, 44.03566736181025, 44.38378082137663, 44.729185103241036, 45.07194249197609, 45.41211292155431, 45.74975409769981, 46.08492161217159, 46.41766904961946, 46.74804808759399, 47.07610859023927, 47.401898696149296, 47.72546490082627, 48.046852134140906, 48.366103833159855, 48.68326201067468, 48.99836731973833, 49.31145911448981, 49.62257550752481, 49.931753424048715, 50.23902865303031, 50.5444358955563, 50.84800881057193, 51.14978005817816, 51.44978134064323, 51.748043441274184, 52.044596261283466, 52.33946885477536, 52.63268946196841, 52.92428554076097, 53.21428379674014, 53.502710211726665, 53.78959007094217, 54.07494798887929, 54.3588079339494, 54.64119325197795, 54.922126688612494, 55.20163041070436, 55.47972602672079, 55.756434606240745], [0.0, 5.620498198558559, 7.948584779695063, 9.734988443752773, 11.240996397117119, 12.56781603939205, 13.767352686700521, 14.870440477672478, 15.897169559390125, 16.861494595675676, 17.773575892318352, 18.641083659487187, 19.469976887505545, 20.264994448555868, 21.02997860198626, 21.768095920406086, 22.481992794234237, 23.17390774125072, 23.845754339085186, 24.49918365986916, 25.1356320787841, 25.756358438257536, 26.36247332857826, 26.954962437369492, 27.534705373401042, 28.102490992792795, 28.659029990563187, 29.204965331258318, 29.740880955344956, 30.267309097440428, 30.784736477676727, 31.29360957128468, 31.79433911878025, 32.28730400637378, 32.77285462085963, 33.251315763440104, 33.72298919135135, 34.188155843800644, 34.64707779885629, 35.10000000000001, 35.547151784636704, 35.98874824163797, 36.42499142072651, 36.856071412997885, 37.28216731897437, 37.70344811817614, 38.12007345218527, 38.53219433149377, 38.93995377501109, 39.34348738990992, 39.74292389847532, 40.13838561775997, 40.529988897111735, 40.91784451800951, 41.302058060101565, 41.68273023687389, 42.05995720397252, 42.433830842854626, 42.80443902213882, 43.17186583876124, 43.53619184081217, 43.897494233725915, 44.255847071319295, 44.61132143301743, 44.963985588468475, 45.31390515062678, 45.66114321827696, 46.00576050887541, 46.34781548250144, 46.68736445763457, 47.02446171940728, 47.359159620922334, 47.69150867817037, 48.02155765903477, 48.34935366682786, 48.67494221876386, 48.99836731973832, 49.31967153175293, 49.63889603929565, 49.95608071096051, 50.2712641575682, 50.58448378702703, 50.895775856155296, 51.20517551966793, 51.51271687651507, 51.81843301374522, 52.122356048052936, 52.42451716515852, 52.72494665715652, 53.02367395795957, 53.32072767695505, 53.61613563098334, 53.909924874738984, 54.202121729688784, 54.492751811594175, 54.781840056719524, 55.069410746802085, 55.35548753285442, 55.64009345786544, 55.92325097846155, 56.20498198558559, 56.48530782424755], [0.0, 5.692099788303083, 8.049844718999243, 9.85900603509299, 11.384199576606166, 12.727922061357857, 13.942740046346701, 15.05988047761336, 16.099689437998485, 17.076299364909246, 18.0, 18.87855926706273, 19.71801207018598, 20.523157651784484, 21.297887219158618, 22.045407685048602, 22.768399153212332, 23.469128658729534, 24.149534156997728, 24.8112877537624, 25.455844122715714, 26.08447814314099, 26.69831455354439, 27.298351598585583, 27.885480092693403, 28.460498941515414, 29.02412789387478, 29.577018105278974, 30.11976095522672, 30.652895458667523, 31.17691453623979, 31.692270350986217, 32.19937887599697, 32.69862382425291, 33.1903600462544, 33.67491648096547, 34.15259872981849, 34.62369131100842, 35.08845964131227, 35.547151784636704, 36.0, 36.44722211636986, 36.889022757454555, 37.32559443598989, 37.75711853412546, 38.18376618407356, 38.60569906114899, 39.02307009962184, 39.43602414037196, 39.84469851812158, 40.24922359499622, 40.64972324629038, 41.04631530356897, 41.43911195959682, 41.828220139040106, 42.21374183841087, 42.595774438317235, 42.97441099072796, 43.34974048365227, 43.72184808536802, 44.090815370097204, 44.45672052682249, 44.819638552759436, 45.17964143284008, 45.536798306424664, 45.89117562233506, 46.24283728319446, 46.59184477996122, 46.93825731745907, 47.28213193162931, 47.62352359916263, 47.96248534010722, 48.299068313995456, 48.63332190998267, 48.965293831447596, 49.29503017546495, 49.6225755075248, 49.94797293184179, 50.2712641575682, 50.592489561198704, 50.91168824543143, 51.22889809472775, 51.544155827794874, 51.85749704719656, 52.16895628628198, 52.478567053607705, 52.78636187501465, 53.09237233350945, 53.39662910708878, 53.69916200463467, 54.0, 54.29917126439408, 54.596703197171166, 54.892622455116864, 55.18695498032121, 55.47972602672078, 55.770960185386805, 56.06068140863078, 56.3489130329947, 56.63567780118819, 56.92099788303083, 57.20489489545454], [0.0, 5.762811813689565, 8.149846624323676, 9.981482855768476, 11.52562362737913, 12.88603895694872, 14.115948427222312, 15.246966911487677, 16.29969324864735, 17.288435441068692, 18.22361105818493, 19.113084523435774, 19.962965711536953, 20.778113485107355, 21.562467391279693, 22.31927418174704, 23.05124725475826, 23.760681808399355, 24.449539872971027, 25.119514326515155, 25.77207791389744, 26.40852135201818, 27.029983351826175, 27.63747455901136, 28.231896854444624, 28.814059068447822, 29.38468989116612, 29.944448567305432, 30.493933822975354, 31.033691369220005, 31.564220250150328, 32.0859782459566, 32.5993864972947, 33.10483348394914, 33.60267846467005, 34.093254464776464, 34.576870882137385, 35.05381576947081, 35.524357840783, 35.98874824163798, 36.44722211636986, 36.900000000000006, 37.347289058243575, 37.78928419539063, 38.22616904687155, 38.65811687084615, 39.085291351095236, 39.50784732176635, 39.925931423073905, 40.33968269582695, 40.74923312161838, 41.154708114625244, 41.55622697021471, 41.953903274904, 42.347845281666935, 42.73815625410156, 43.124934782559386, 43.508275074978556, 43.8882672248518, 44.26499745848857, 44.63854836349408, 45.008999100179956, 45.37642559743991, 45.740900734463025, 46.10249450951652, 46.46127419690511, 46.81730449310383, 47.170647652963176, 47.52136361679871, 47.86951012909992, 48.21514284952395, 48.55831545677837, 48.89907974594205, 49.23748571972376, 49.573581674113484, 49.90741427884238, 50.23902865303031, 50.56846843636853, 50.8957758561553, 51.22099179047591, 51.54415582779488, 51.86530632320608, 52.18448045156722, 52.50171425772687, 52.81704270403636, 53.130499715323595, 53.442118221492684, 53.751930197900805, 54.05996670365235, 54.366257917940246, 54.67083317455479, 54.97372099467163, 55.27494911802272, 55.57454453254656, 55.87253350260753, 56.16894159586773, 56.46379370888925, 56.75711409153923, 57.04892637026573, 57.33925357030732, 57.628118136895644, 57.91554195550622], [0.0, 5.832666628567075, 8.248636250920512, 10.102474944289643, 11.66533325713415, 13.042239071570497, 14.287057079748791, 15.431785379534023, 16.497272501841024, 17.497999885701223, 18.444511378727277, 19.344766734184212, 20.204949888579286, 21.02997860198626, 21.823840175367856, 22.58982071642004, 23.3306665142683, 24.0487005885973, 24.745908752761537, 25.424004405285967, 26.084478143140995, 26.7286363288515, 27.357631476427198, 27.972486482256098, 28.574114159497583, 29.163333142835373, 29.740880955344956, 30.307424832868932, 30.863570759068047, 31.40987105990727, 31.946830828737927, 32.47491339480369, 32.99454500368205, 33.50611884417532, 34.00999852984414, 34.50652112282547, 34.995999771402445, 35.47872601996865, 35.954971839788726, 36.42499142072652, 36.889022757454555, 37.347289058243575, 37.800000000000004, 38.2473528495764, 38.689533468368424, 39.12671721471148, 39.55906975650464, 39.98674780474151, 40.40989977715857, 40.82866639996953, 41.24318125460257, 41.65357127546209, 42.05995720397252, 42.462454003507624, 42.861171239246374, 43.2562134265125, 43.64768035073571, 44.03566736181025, 44.42026564531105, 44.80156247275311, 45.17964143284008, 45.55458264543755, 45.92646295982307, 46.29535613860207, 46.6613330285366, 47.02446171940728, 47.38480769191746, 47.74243395554944, 48.0974011771946, 48.44976780130118, 48.799590162213455, 49.146922589313775, 49.49181750552307, 49.83432551966567, 50.17449551315888, 50.51237472144822, 50.84800881057193, 51.18144194920656, 51.51271687651508, 51.84187496609281, 52.16895628628199, 52.49399965710367, 52.81704270403636, 53.13812190885184, 53.457272657703, 53.77452928664277, 54.0899251247402, 54.40349253494669, 54.715262952854395, 55.025266923477986, 55.33353413618184, 55.64009345786544, 55.944972964512196, 56.248199971199085, 56.549801060658034, 56.849802110473526, 57.148228318995166, 57.44510423003862, 57.74045375644359, 58.034300202552636, 58.32666628567075, 58.61757415656162], [0.0, 5.9016946718718, 8.346256645946132, 10.222035022440492, 11.8033893437436, 13.196590468753662, 14.456140563788109, 15.614416415607725, 16.692513291892265, 17.705084015615398, 18.662797217994946, 19.57370685383839, 20.444070044880984, 21.2788627515664, 22.082119463493534, 22.857165178560525, 23.6067786874872, 24.33331050227239, 25.038769937838396, 25.724890670321614, 26.393180937507324, 27.044962562370095, 27.681401698613456, 28.3035333483295, 28.912281127576218, 29.508473359359, 30.092856295140876, 30.666105067321478, 31.22883283121545, 31.781598449417235, 32.32491299292234, 32.85924527435163, 33.38502658378453, 33.902654763307254, 34.41249772974929, 34.91489653428748, 35.410168031230796, 35.898607215322436, 36.38048927653392, 36.85607141299789, 37.32559443598989, 37.78928419539063, 38.2473528495764, 38.69999999999999, 39.14741370767678, 39.58977140626098, 40.02724072428675, 40.459980227380235, 40.88814008976197, 41.311862703102605, 41.731283229730664, 42.14653010628515, 42.5577255031328, 42.96498574420804, 43.368421691364325, 43.76813909683618, 44.16423892698707, 44.55681766015162, 44.945967561061586, 45.331776934066895, 45.71433035712105, 46.093708898286756, 46.46999031633211, 46.84324924682317, 47.2135573749744, 47.58098359639069, 47.945594166721925, 48.307452841150706, 48.66662100454478, 49.02315779302675, 49.377120207642726, 49.7285632207487, 50.07753987567679, 50.42410138019318, 50.76829719421363, 51.11017511220246, 51.44978134064323, 51.787160570936884, 52.122356048052936, 52.45540963523209, 52.78636187501465, 53.1152520468462, 53.44211822149268, 53.76699731247784, 54.08992512474019, 54.41093640069062, 54.73006486383878, 55.047343260142895, 55.36280339722691, 55.67647618159755, 55.98839165398484, 56.29857902292028, 56.607066696659, 56.913882313544555, 57.21905277090839, 57.52260425258925, 57.824562255152436, 58.12495161288309, 58.42379652162293, 58.72112056151517, 59.016946718718, 59.31129740614346], [0.0, 5.969924622639721, 8.442748367682174, 10.340212763768452, 11.939849245279442, 13.349157276772196, 14.623269128344731, 15.794935897305821, 16.88549673536435, 17.90977386791916, 18.87855926706273, 19.800000000000004, 20.680425527536904, 21.52486933758252, 22.337412562783545, 23.121418641597234, 23.879698490558884, 24.614629796119218, 25.32824510304652, 26.022298130641733, 26.698314553544392, 27.357631476427198, 28.001428534987287, 28.630752697056362, 29.246538256689462, 29.8496231131986, 30.440762145517976, 31.02063829130536, 31.589871794611643, 32.149027979085155, 32.69862382425291, 33.2391335627149, 33.7709934707287, 34.294605989863776, 34.810343290464694, 35.318550366627456, 35.81954773583832, 36.31363380329763, 36.801086940469574, 37.28216731897437, 37.75711853412546, 38.22616904687155, 38.689533468368424, 39.147413707676776, 39.60000000000001, 40.04747183031658, 40.489998765127176, 40.927741203247464, 41.36085105507381, 41.789472358478044, 42.21374183841087, 42.63378941637725, 43.04973867516504, 43.4617072835387, 43.86980738503419, 44.27414595449584, 44.67482512556709, 45.071942491976095, 45.46559138513433, 45.855861130285184, 46.24283728319447, 46.62660184915903, 47.00723348592214, 47.38480769191746, 47.75939698111777, 48.13107104563538, 48.49989690710693, 48.86593905779362, 49.229259592238435, 49.58991833024128, 49.9479729318418, 50.30347900493564, 50.65649020609304, 51.00705833509712, 51.35523342367358, 51.701063818842265, 52.044596261283466, 52.3858759590789, 52.72494665715653, 53.06185070274123, 53.396629107088785, 53.729321603757484, 54.05996670365235, 54.388601747057265, 54.715262952854395, 55.03998546511436, 55.36280339722692, 55.68374987372887, 56.002857069974574, 56.32015624978326, 56.63567780118819, 56.94945127040295, 57.261505394112724, 57.57186813019012, 57.8805666869287, 58.187627550880606, 58.493076513378924, 58.79693869581988, 59.09923857377522, 59.400000000000006, 59.6992462263972, 59.99699992499626], [0.0, 6.037383539249432, 8.538149682454623, 10.457055034760025, 12.074767078498864, 13.5, 14.788509052639485, 15.973415414368962, 17.076299364909246, 18.11215061774829, 19.09188309203678, 20.02373591515829, 20.91411006952005, 21.768095920406083, 22.58982071642004, 23.38268590217984, 24.149534156997728, 24.89277003469079, 25.61444904736387, 26.316344730984202, 27.0, 27.666767068090916, 28.31783890059409, 28.95427429586174, 29.57701810527897, 30.186917696247157, 30.784736477676724, 31.371165104280077, 31.946830828737923, 32.5123053627392, 33.068111527572896, 33.614728914569575, 34.15259872981849, 34.682127962395846, 35.2036929880943, 35.71764269937197, 36.22430123549658, 36.72397037358569, 37.21693163064359, 37.70344811817614, 38.18376618407356, 38.65811687084615, 39.12671721471148, 39.58977140626098, 40.04747183031658, 40.49999999999999, 40.94752739787837, 41.390216235240906, 41.8282201390401, 42.26168477474602, 42.690748412273116, 43.11554244121254, 43.536191840812165, 43.952815609469205, 44.36552715791846, 44.7744346697979, 45.17964143284008, 45.581246143562154, 45.97934318800129, 46.374022900757694, 46.76537180435968, 47.15347283074704, 47.53840552647932, 47.92024624310689, 48.299068313995456, 48.67494221876385, 49.04793573637936, 49.41811408785244, 49.78554006938158, 50.15027417671811, 50.512374721448204, 50.87189793982528, 51.22889809472774, 51.58342757126556, 51.93553696651263, 52.28527517380012, 52.632689461968404, 52.97782554994117, 53.32072767695505, 53.66143866874983, 54.0, 54.33645185324489, 54.67083317455478, 55.00318172615108, 55.33353413618183, 55.66192594583841, 55.98839165398484, 56.31296475945836, 56.63567780118818, 56.95656239626826, 57.27564927611034, 57.59296832079416, 57.90854859172348, 58.222418362689126, 58.53460514943276, 58.84513573779908, 59.15403621055794, 59.46133197297215, 59.76704777718236, 60.071207745474865, 60.373835392494314, 60.67495364645943], [0.0, 6.104096984812742, 8.632496741962894, 10.572606112023658, 12.208193969625484, 13.649175799292793, 14.951922953252536, 16.149922600433726, 17.26499348392579, 18.31229095443822, 19.302849530574495, 20.24499938256359, 21.145212224047317, 22.008634669147472, 22.839439572809138, 23.641065965814654, 24.416387939250967, 25.167836617397214, 25.897490225888685, 26.60714189837007, 27.298351598585587, 27.972486482256098, 28.630752697056362, 29.27422074112307, 29.903845906505072, 30.52048492406371, 31.124909638423052, 31.717818336070977, 32.29984520086745, 32.87156826194941, 33.433516117812076, 33.98617365929857, 34.52998696785158, 35.06536752980069, 35.59269587991334, 36.11232476592998, 36.62458190887644, 37.129772420525285, 37.62818092866037, 38.120073452185274, 38.60569906114899, 39.085291351095236, 39.55906975650464, 40.02724072428675, 40.48999876512718, 40.94752739787837, 41.4, 41.847580575225614, 42.29042444809463, 42.72867889368919, 43.16248370981448, 43.59197173792441, 44.017269338294945, 44.438496824262636, 44.85576885975761, 45.269194823853454, 45.678879145618275, 46.08492161217159, 46.487417652521856, 46.88645859947198, 47.28213193162931, 47.6745214973365, 48.06370772214728, 48.44976780130118, 48.832775878501934, 49.21280321217234, 49.589918330241275, 49.96418717441524, 50.33567323479443, 50.704437675611786, 51.07053945279999, 51.434035424026376, 51.79498045177737, 52.153427500021515, 52.50942772493336, 52.86303056011829, 53.21428379674014, 53.56323365891944, 53.909924874738984, 54.254400743165526, 54.59670319717117, 54.936872863314676, 55.27494911802272, 55.610970140791466, 55.944972964512196, 56.27699352310854, 56.607066696659, 56.93522635416496, 57.261505394112724, 57.58593578296701, 57.90854859172349, 58.229374030638525, 58.54844148224614, 58.8657795327642, 59.18141600198495, 59.49537797173827, 59.807691813010145, 60.11838321179305, 60.427477193740266, 60.73499814769077, 61.04096984812742, 61.34541547662711], [0.0, 6.17008914036094, 8.725823743349393, 10.686907878334127, 12.34017828072188, 13.796738745080305, 15.113570061372, 16.32452143249535, 17.451647486698786, 18.510267421082816, 19.51153504981092, 20.463870601623732, 21.373815756668254, 22.246572769754895, 23.08635960908519, 23.896652485233155, 24.68035656144376, 25.439929245184626, 26.177471230048177, 26.894795035471084, 27.59347749016061, 28.274900530329017, 28.94028334346435, 29.590708000992475, 30.227140122744, 30.8504457018047, 31.461404927307363, 32.06072363500238, 32.6490428649907, 33.22694689555452, 33.79497003993345, 34.35360243118617, 34.90329497339757, 35.444463601527396, 35.97749296435204, 36.502739623211845, 37.02053484216563, 37.53118703158748, 38.03498389640779, 38.53219433149377, 39.02307009962184, 39.50784732176634, 39.98674780474151, 40.459980227380235, 40.927741203247464, 41.390216235240906, 41.847580575225614, 42.300000000000004, 42.74763151333651, 43.19062398252658, 43.629118716746966, 44.063249993617134, 44.49314553950979, 44.918926968484016, 45.340710184116, 45.75860574799018, 46.17271921817038, 46.583151460587125, 46.98999893594381, 47.3933539644537, 47.79330497046631, 48.1899367088192, 48.5833304745568, 48.97356429748605, 49.36071312288752, 49.74484897956772, 50.12604113631955, 50.50435624775351, 50.87985849036925, 51.25260968965385, 51.62266943891996, 51.99009521053025, 52.35494246009635, 52.7172647241869, 53.07711371203223, 53.43453939167063, 53.78959007094217, 54.14231247370212, 54.49275181159418, 54.84095185169564, 55.18695498032122, 55.53080226324846, 55.872533502607524, 56.21218729065789, 56.549801060658034, 56.88541113501774, 57.2190527709084, 57.550760203493404, 57.8805666869287, 58.20850453327245, 58.53460514943276, 58.858899072272834, 59.18141600198495, 59.50218483383615, 59.82123368838192, 60.1385899402372, 60.454280245488, 60.768330567821266, 61.08076620344575, 61.3916118048712, 61.7008914036094, 62.00862843185617], [0.0, 6.235382907247959, 8.818163074019441, 10.800000000000002, 12.470765814495918, 13.942740046346705, 15.273506473629428, 16.497272501841028, 17.636326148038883, 18.706148721743876, 19.71801207018598, 20.680425527536908, 21.600000000000005, 22.481992794234237, 23.3306665142683, 24.14953415699773, 24.941531628991836, 25.709142342754262, 26.454489222058324, 27.179403966974704, 27.88548009269341, 28.574114159497583, 29.246538256689465, 29.903845906505076, 30.547012947258857, 31.176914536239796, 31.794339118780254, 32.400000000000006, 32.994545003682056, 33.578564591119736, 34.1525987298185, 34.71714273957464, 35.272652296077766, 35.81954773583833, 36.35821777810349, 36.889022757454555, 37.41229744348775, 37.928353510269865, 38.43748170731273, 38.9399537750111, 39.43602414037196, 39.925931423073905, 40.40989977715857, 40.88814008976197, 41.360851055073816, 41.828220139040106, 42.29042444809463, 42.74763151333651, 43.20000000000001, 43.64768035073572, 44.09081537009721, 44.52954075667074, 44.963985588468475, 45.39427276650658, 45.82051942088829, 46.242837283194476, 46.6613330285366, 47.07610859023928, 47.48726144978252, 47.89488490434025, 48.29906831399546, 48.69989733048726, 49.09745410914908, 49.49181750552308, 49.88306325798367, 50.27126415756819, 50.65649020609304, 51.03880876352817, 51.418284685508524, 51.79498045177738, 52.16895628628199, 52.54027026957514, 52.90897844411665, 53.275134913015485, 53.63879193270483, 54.00000000000001, 54.35880793394941, 54.715262952854395, 55.06941074680209, 55.42129554602636, 55.77096018538682, 56.11844616523163, 56.46379370888925, 56.80704181701421, 57.148228318995166, 57.48738992161673, 57.82456225515244, 58.15977991705265, 58.49307651337893, 58.8244846981255, 59.15403621055795, 59.48176191068991, 59.80769181301015, 60.131855118564246, 60.454280245488, 60.77499485808288, 61.09402589451771, 61.411399593235146, 61.7271415181361, 62.04127658261072, 62.35382907247959, 62.66482266790517], [0.0, 6.300000000000001, 8.909545442950499, 10.911920087683928, 12.600000000000001, 14.087228258248677, 15.431785379534023, 16.66823325970692, 17.819090885900998, 18.9, 19.92234925906079, 20.894736179239022, 21.823840175367856, 22.71497303542313, 23.572441536675832, 24.399795081106724, 25.200000000000003, 25.97556544139126, 26.728636328851497, 27.461063344306243, 28.174456516497354, 28.870226878221793, 29.54961928688761, 30.213738596870133, 30.863570759068047, 31.5, 32.12382293563454, 32.73576026305179, 33.33646651941384, 33.92653828494738, 34.50652112282546, 35.07691548582914, 35.638181771801996, 36.190744673189585, 36.734996937525395, 37.27130263352758, 37.8, 38.32140394087879, 38.83580821870455, 39.34348738990992, 39.84469851812158, 40.33968269582695, 40.82866639996952, 41.3118627031026, 41.789472358478044, 42.26168477474602, 42.728678893689185, 43.19062398252658, 43.64768035073571, 44.1, 44.5477272147525, 44.99099909981996, 45.42994607084626, 45.86469230246727, 46.29535613860207, 46.722050468702676, 47.144883073351664, 47.56395694220573, 47.97937056694263, 48.39121821157222, 48.79959016221345, 49.20457295821192, 49.60624960627441, 50.00469977912076, 50.400000000000006, 50.79222381428086, 51.181441949206544, 51.56772246279643, 51.95113088278252, 52.33173033638387, 52.70958167164676, 53.08474357101106, 53.457272657702994, 53.82722359550045, 54.19464918236855, 54.559600438419636, 54.92212668861249, 55.28227564057037, 55.64009345786545, 55.99562482908821, 56.34891303299471, 56.7, 57.048926370265725, 57.395731548609085, 57.740453756443586, 58.08313008094519, 58.42379652162293, 58.76248803445954, 59.09923857377522, 59.4340811319566, 59.76704777718237, 60.09816968926758, 60.427477193740266, 60.75499979425562, 61.08076620344575, 61.40480437229647, 61.727141518136094, 62.04780415131547, 62.3668181006535, 62.68420853771706, 63.0, 63.314216413061615], [0.0, 6.3639610306789285, 9.0, 11.022703842524303, 12.727922061357857, 14.230249470757709, 15.588457268119896, 16.837458240482736, 18.0, 19.09188309203678, 20.12461179749811, 21.106870919205438, 22.045407685048605, 22.94558781116753, 23.811761799581316, 24.647515087732476, 25.455844122715714, 26.239283526803852, 27.0, 27.739863013360395, 28.460498941515418, 29.163333142835373, 29.849623113198604, 30.52048492406371, 31.176914536239792, 31.81980515339464, 32.449961479175904, 33.06811152757291, 33.67491648096547, 34.27097897638759, 34.85685011586675, 35.43303543305315, 36.0, 36.55817282086183, 37.10795063055895, 37.6497011940334, 38.18376618407356, 38.71046370169182, 39.230090491866065, 39.74292389847532, 40.24922359499622, 40.74923312161838, 41.24318125460256, 41.731283229730664, 42.213741838410876, 42.690748412273116, 43.16248370981448, 43.629118716746966, 44.09081537009721, 44.5477272147525, 45.00000000000001, 45.44777222262936, 45.89117562233506, 46.33033563444151, 46.765371804359695, 47.196398167656824, 47.62352359916263, 48.046852134140906, 48.466483264210545, 48.88251221040097, 49.29503017546495, 49.704124577342675, 50.1098792654702, 50.51237472144821, 50.91168824543143, 51.30789412946121, 51.70106381884226, 52.091266062556016, 52.478567053607705, 52.86303056011829, 53.24471804789655, 53.62368879515844, 54.0, 54.37370688117558, 54.74486277268398, 55.11351921262151, 55.47972602672079, 55.84353140695886, 56.2049819855856, 56.564122904894404, 56.920997883030836, 57.27564927611036, 57.628118136895644, 57.97844427026307, 58.32666628567075, 58.67282164682384, 59.01694671871801, 59.35907681222814, 59.69924622639721, 60.037488288568504, 60.37383539249433, 60.70831903454419, 61.04096984812742, 61.371817636436354, 61.700891403609404, 62.02821938440599, 62.353829072479584, 62.67774724732855, 63.00000000000001, 63.3206127576163, 63.63961030678928, 63.957016815983536], [0.0, 6.427285585688566, 9.08955444452587, 11.132385189167685, 12.854571171377131, 14.371847480404185, 15.743570116082314, 17.004999264922066, 18.17910888905174, 19.281856757065697, 20.32486162314519, 21.316894708188624, 22.26477037833537, 23.173907741250723, 24.0487005885973, 24.8927700346908, 25.709142342754262, 26.500377355803824, 27.268663333577614, 28.01588834929209, 28.74369496080837, 29.453522709516434, 30.146641603999612, 30.82417882117868, 31.487140232164627, 32.13642792844283, 32.77285462085963, 33.397155567503056, 34.00999852984413, 34.611992141452944, 35.2036929880943, 35.78561163372788, 36.35821777810348, 36.92194469417883, 37.477193064582636, 38.0243343136997, 38.56371351413139, 39.09565193215226, 39.62044926549925, 40.13838561775997, 40.64972324629038, 41.15470811462524, 41.65357127546209, 42.14653010628514, 42.63378941637725, 43.11554244121254, 43.59197173792441, 44.063249993617134, 44.52954075667074, 44.990999099819966, 45.44777222262936, 45.90000000000001, 46.347815482501446, 46.79134535360146, 47.230710348246944, 47.666025636715304, 48.0974011771946, 48.52494204015086, 48.948748707193744, 49.36891734684892, 49.7855400693816, 50.19870516258363, 50.60849731023438, 51.0149977947662, 51.418284685508524, 51.81843301374522, 52.21551493569704, 52.60959988443174, 53.00075471160765, 53.38904381987001, 53.77452928664277, 54.15727097998939, 54.53732666715523, 54.91475211634849, 55.28960119226762, 55.661925945838426, 56.03177669858418, 56.39920212201588, 56.76424931239734, 57.126963861210065, 57.48738992161674, 57.84557027119709, 58.20154637120908, 58.55535842260724, 58.90704541903287, 59.25664519697349, 59.60419448327442, 59.949728940171205, 60.293283207999224, 60.63489094572531, 60.97458486943557, 61.31239678890396, 61.64835764235736, 61.98249752954459, 62.314845743209546, 62.64543079906148, 62.974280464329254, 63.301421784980484, 63.6268811116811, 63.950684124565875, 64.27285585688566, 64.59342071759322], [0.0, 6.489992295835181, 9.178235124467014, 11.240996397117119, 12.979984591670362, 14.512063946937392, 15.897169559390125, 17.17090562550502, 18.356470248934027, 19.469976887505542, 20.523157651784484, 21.52486933758252, 22.481992794234237, 23.400000000000002, 24.283327613817676, 25.135632078784095, 25.959969183340725, 26.75892374517331, 27.53470537340104, 28.289220561903083, 29.024127893874784, 29.740880955344956, 30.44076214551798, 31.124909638423052, 31.79433911878025, 32.449961479175904, 33.09259735953043, 33.72298919135136, 34.34181125101004, 34.94967811010568, 35.5471517846367, 36.134747819792516, 36.712940497868054, 37.282167318974366, 37.84283287493155, 38.39531221386277, 38.939953775011084, 39.47708195903036, 40.006999387607166, 40.529988897111735, 41.04631530356897, 41.55622697021471, 42.05995720397252, 42.557725503132794, 43.04973867516504, 43.536191840812165, 44.017269338294945, 44.4931455395098, 44.963985588468475, 45.42994607084627, 45.89117562233507, 46.347815482501446, 46.800000000000004, 47.247857094264084, 47.69150867817038, 48.13107104563538, 48.56665522763535, 48.99836731973832, 49.42630878388554, 49.85057672685442, 50.27126415756819, 50.688460225183405, 51.10225043968221, 51.512716876515064, 51.91993836668145, 52.32399067349508, 52.724946657156515, 53.12287642814534, 53.51784749034662, 53.90992487473898, 54.29917126439408, 54.68564711146793, 55.06941074680208, 55.45051848269772, 55.82902470937496, 56.20498198558559, 56.578441123806165, 56.94945127040295, 57.31805998112638, 57.68431329226344, 58.04825578774957, 58.40993066251663, 58.76937978233224, 59.126643740364635, 59.48176191068991, 59.83477249894079, 60.18571259028176, 60.534618194880856, 60.88152429103596, 61.22646486610182, 61.569472955353454, 61.91058067891142, 62.249819276846104, 62.58721914256936, 62.922809854614734, 63.25662020690008, 63.5886782375605, 63.919011256432945, 64.2476458712691, 64.57460801274756, 64.89992295835181, 65.22361535517639], [0.0, 6.552098900352467, 9.2660671268883, 11.348568191626644, 13.104197800704934, 14.65093853648974, 16.04929905011431, 17.3352242558324, 18.5321342537766, 19.6562967010574, 20.71955597979841, 21.73085364176935, 22.697136383253287, 23.62392854713204, 24.515709249377228, 25.376169923769034, 26.20839560140987, 27.014995835646545, 27.798201380664903, 28.55993697472038, 29.30187707297948, 30.025489171702105, 30.73206794213498, 31.422762450172968, 32.09859810022862, 32.76049450176234, 33.40928014788706, 34.045704574879935, 34.6704485116648, 35.28413241104279, 35.887323667278395, 36.48054275912024, 37.0642685075532, 37.638942599387676, 38.204973498224035, 38.76273984124445, 39.3125934021148, 39.85486168587216, 40.38985021017038, 40.91784451800951, 41.43911195959682, 41.953903274904, 42.462454003507624, 42.964985744208036, 43.4617072835387, 43.952815609469205, 44.438496824262636, 44.918926968484016, 45.394272766506575, 45.864692302467276, 46.33033563444151, 46.79134535360146, 47.24785709426408, 47.70000000000001, 48.14789715034293, 48.59166595209513, 49.031418498754455, 49.46726190118067, 49.89929859226481, 50.32762660805693, 50.75233984753807, 51.1735283129862, 51.59127833267945, 52.0056727674972, 52.41679120281974, 52.82471012698508, 53.229503097436485, 53.63124089558249, 54.02999167129309, 54.42582107786708, 54.81879239822783, 55.20896666303401, 55.596402761329806, 55.98115754430236, 56.36328592266424, 56.74284095813322, 57.11987394944076, 57.49443451326398, 57.86657066044265, 58.236328867812404, 58.60375414595896, 58.96889010317221, 59.331779005858245, 59.69246183564555, 60.05097834340421, 60.40736710037941, 60.7616655466257, 61.11391003691386, 61.46413588426996, 61.812377401294, 62.15866793939523, 62.503039926070805, 62.845524900345936, 63.18615354648517, 63.52495572607667, 63.86196050858445, 64.19719620045724, 64.53069037287608, 64.86246988821811, 65.19256092530804, 65.52098900352468, 65.84777900582526], [0.0, 6.613622305514581, 9.353074360871938, 11.45512985522207, 13.227244611029162, 14.788509052639487, 16.200000000000003, 17.497999885701223, 18.706148721743876, 19.840866916543742, 20.914110069520053, 21.934903692517096, 22.91025971044414, 23.845754339085186, 24.745908752761537, 25.614449047363873, 26.454489222058324, 27.26866333357761, 28.059223082615812, 28.828111280484542, 29.577018105278974, 30.30742483286893, 31.02063829130536, 31.717818336070977, 32.400000000000006, 33.0681115275729, 33.72298919135135, 34.36538956566621, 34.995999771402445, 35.615446087336885, 36.22430123549659, 36.82309058186181, 37.41229744348775, 37.99236765456978, 38.56371351413139, 39.12671721471148, 39.681733833087485, 40.22909394952862, 40.76910595046205, 41.302058060101565, 41.828220139040106, 42.347845281666935, 42.86117123924637, 43.368421691364325, 43.86980738503419, 44.36552715791845, 44.8557688597576, 45.340710184116, 45.82051942088828, 46.295356138602074, 46.76537180435969, 47.23071034824694, 47.69150867817037, 48.14789715034293, 48.60000000000001, 49.04793573637937, 49.49181750552307, 49.931753424048715, 50.36784688667961, 50.8001968500123, 51.22889809472775, 51.654041468214274, 52.07571410936196, 52.49399965710367, 52.90897844411665, 53.320727676955045, 53.72932160375748, 54.13483167056123, 54.53732666715522, 54.936872863314676, 55.33353413618183, 55.7273720894858, 56.118446165231624, 56.50681374843215, 56.892530265404794, 57.27564927611035, 57.656222560969084, 58.03430020255263, 58.409930662516636, 58.78316085410855, 59.15403621055795, 59.52260074963123, 59.88889713461086, 60.252966731937775, 60.61484966573786, 60.97458486943556, 61.332210134642956, 61.68776215749766, 62.04127658261072, 62.392788044773255, 62.742330208560155, 63.08993580595879, 63.43563667214195, 63.77946377949567, 64.12144727000475, 64.46161648609194, 64.80000000000001, 65.13662564180002, 65.47152052610356, 65.80471107755129, 66.1362230551458, 66.46608157549232], [0.0, 6.674578638386097, 9.439279633531363, 11.560709320798617, 13.349157276772194, 14.924811556599302, 16.349311912126456, 17.659275183313728, 18.878559267062727, 20.023735915158287, 21.106870919205434, 22.13707297724792, 23.121418641597234, 24.06553552281769, 24.973986465920895, 25.85053190942113, 26.69831455354439, 27.51999273255718, 28.31783890059409, 29.093813775440307, 29.849623113198604, 30.586761842339573, 31.30654883566696, 32.01015463880174, 32.69862382425291, 33.37289319193049, 34.03380672214027, 34.68212796239585, 35.318550366627456, 35.94370598588855, 36.55817282086182, 37.16248107971264, 37.75711853412545, 38.34253512745343, 38.91914695879138, 39.48733974326455, 40.047471830316574, 40.599876847103864, 41.14486602238486, 41.68273023687389, 42.21374183841087, 42.73815625410156, 43.2562134265125, 43.76813909683618, 44.27414595449584, 44.77443466979789, 45.269194823853454, 45.75860574799018, 46.24283728319447, 46.72205046870268, 47.196398167656824, 47.666025636715304, 48.13107104563538, 48.59166595209513, 49.04793573637937, 49.50000000000001, 49.94797293184179, 50.39196364500991, 50.832076487194584, 51.268411327054004, 51.70106381884226, 52.13012564726849, 52.555684754363156, 52.97782554994117, 53.39662910708878, 53.81217334395629, 54.224533193011446, 54.63378075879428, 55.03998546511436, 55.443214192541184, 55.84353140695886, 56.24099927988478, 56.63567780118818, 57.0276248847872, 57.41689646785169, 57.803546603993084, 58.18762755088061, 58.5691898526862, 58.94828241772615, 59.32495259163719, 59.69924622639721, 60.07120774547487, 60.44088020537094, 60.80830535379193, 61.17352368467915, 61.536574490298044, 61.89749591057784, 62.256324979876545, 62.61309767133392, 62.9678489389625, 63.3206127576163, 63.67142216096638, 64.02030927760347, 64.36730536537941, 64.71244084409118, 65.05574532660432, 65.39724764850583, 65.73697589637054, 66.07495743471955, 66.41121893174376, 66.74578638386097, 67.0786851391707], [0.0, 6.734983296193095, 9.524704719832526, 11.665333257134149, 13.46996659238619, 15.059880477613362, 16.497272501841024, 17.819090885900998, 19.04940943966505, 20.204949888579282, 21.297887219158618, 22.337412562783545, 23.330666514268298, 24.283327613817676, 25.2, 26.084478143140988, 26.93993318477238, 27.76904751697472, 28.574114159497576, 29.357111574540163, 30.119760955226724, 30.863570759068047, 31.589871794611643, 32.29984520086745, 32.99454500368205, 33.67491648096547, 34.34181125101004, 34.995999771402445, 35.638181771801996, 36.26899502329779, 36.88902275745455, 37.49879998079938, 38.0988188793301, 38.689533468368424, 39.271363612688575, 39.844698518121575, 40.409899777158564, 40.96730403626775, 41.51722534081486, 42.05995720397253, 42.595774438317235, 43.124934782559386, 43.647680350735705, 44.16423892698706, 44.67482512556709, 45.17964143284007, 45.678879145618275, 46.17271921817038, 46.661333028536596, 47.144883073351664, 47.62352359916263, 48.0974011771946, 48.56665522763535, 49.031418498754455, 49.49181750552307, 49.94797293184179, 50.4, 50.848008810571926, 51.29210465559003, 51.732388307519685, 52.168956286281976, 52.601901106328846, 53.03131150556244, 53.457272657702994, 53.87986636954476, 54.299171264394076, 54.71526295285438, 55.12821419200879, 55.53809503394944, 55.94497296451219, 56.3489130329947, 56.74997797356401, 57.14822831899515, 57.543722507324816, 57.93651698195189, 58.32666628567074, 58.714223149080325, 59.09923857377521, 59.48176191068991, 59.8618409339372, 60.23952191045345, 60.61484966573785, 60.9878676459507, 61.358617976613516, 61.727141518136094, 62.093477918377225, 62.4576656624309, 62.81974211981453, 63.179743589223285, 63.537705341002045, 63.89366165747585, 64.24764587126909, 64.5996904017349, 64.94982678960737, 65.2980857299814, 65.64449710371768, 65.9890900073641, 66.33189278167781, 66.67293303882768, 67.01223768835062, 67.34983296193094, 67.6857444370674], [0.0, 6.794850991743675, 9.60937042682818, 11.76902714755982, 13.58970198348735, 15.193748714520721, 16.643917808016237, 17.977485919894363, 19.21874085365636, 20.38455297523102, 21.48720549536398, 22.535971245988048, 23.53805429511964, 24.49918365986916, 25.424004405285963, 26.316344730984202, 27.1794039669747, 28.015888349292084, 28.82811128048454, 29.618068809427804, 30.387497429041442, 31.137919005611153, 31.870676177326395, 32.586960582417014, 33.287835616032474, 33.974254958718376, 34.64707779885629, 35.30708144267946, 35.954971839788726, 36.59139243046102, 37.21693163064359, 37.83212920257066, 38.43748170731272, 39.033447195962594, 39.62044926549925, 40.19888058142913, 40.76910595046204, 41.33146501153812, 41.88627460159235, 42.433830842854626, 42.97441099072796, 43.508275074978556, 44.03566736181025, 44.55681766015162, 45.071942491976095, 45.581246143562154, 46.08492161217159, 46.583151460587125, 47.07610859023928, 47.56395694220573, 48.046852134140906, 48.52494204015086, 48.99836731973832, 49.46726190118067, 49.931753424048715, 50.39196364500991, 50.848008810571926, 51.300000000000004, 51.74804344127419, 52.19224080263272, 52.632689461968404, 53.069482756100044, 53.50271021172666, 53.93245775968308, 54.3588079339494, 54.781840056719524, 55.201630410704354, 55.61825239972935, 56.03177669858417, 56.442271392990556, 56.849802110473526, 57.254432142848124, 57.65622256096908, 58.0552323223325, 58.45151837206626, 58.8451357377991, 59.23613761885561, 59.62457547018679, 60.01049908141076, 60.39395665130742, 60.774994858082884, 61.15365892569307, 61.52999268649396, 61.90403864046351, 62.275838011222305, 62.64543079906147, 63.012855831171464, 63.37815080924971, 63.74135235465279, 64.10249605124594, 64.46161648609194, 64.81874728811103, 65.17392116483403, 65.52716993736263, 65.87852457364235, 66.22801522014683, 66.57567123206495, 66.92152120207669, 67.26559298779726, 67.60791373796414, 67.94850991743675, 68.28740733107387], [0.0, 6.854195795277518, 9.693296652842108, 11.871815362445629, 13.708391590555037, 15.326447729333763, 16.789282295559868, 18.1344975116489, 19.386593305684215, 20.56258738583255, 21.674870241826135, 22.732795692567162, 23.743630724891258, 24.713154391942766, 25.646052327795015, 26.546186166754726, 27.416783181110073, 28.260573242593647, 29.079889958526323, 29.8767468108561, 30.652895458667526, 31.40987105990727, 32.149027979085155, 32.87156826194942, 33.578564591119736, 34.27097897638759, 34.94967811010568, 35.61544608733689, 36.2689950232978, 36.910973977937786, 37.54197650630558, 38.162547084805546, 38.77318661136843, 39.37435713760925, 39.96648596011414, 40.549969173847714, 41.1251747716651, 41.692445358841695, 42.25210053949981, 42.80443902213882, 43.34974048365227, 43.888267224851795, 44.42026564531104, 44.94596756106158, 45.465591385134324, 45.97934318800128, 46.48741765252185, 46.98999893594381, 47.487261449782515, 47.97937056694263, 48.46648326421054, 48.94874870719374, 49.42630878388553, 49.89929859226481, 50.36784688667961, 50.832076487194584, 51.29210465559003, 51.74804344127419, 52.20000000000001, 52.648076887954794, 53.09237233350945, 53.532980488666986, 53.96999166203382, 54.40349253494669, 54.83356636222015, 55.26029315883151, 55.68374987372887, 56.104010551831315, 56.521146485187295, 56.93522635416496, 57.34631635946637, 57.75448034568401, 58.159779917052646, 58.56227454599079, 58.96202167497312, 59.35907681222814, 59.7534936217122, 60.14532400777304, 60.53461819488087, 60.921424802773615, 61.30579091733505, 61.687762157497666, 62.06738273844001, 62.44469553132596, 62.81974211981454, 63.19256285355105, 63.56319689883448, 63.93168228664095, 64.29805595817031, 64.66235380806981, 65.0246107254784, 65.38486063302422, 65.74313652389884, 66.09947049712275, 66.45389379110904, 66.80643681562428, 67.15712918223947, 67.50599973335704, 67.85307656989475, 68.19838707770148, 68.54195795277518, 68.88381522534884], [0.0, 6.913031173081747, 9.776502442080194, 11.973721226085063, 13.826062346163495, 15.458007633585902, 16.9333989500041, 18.29016128961142, 19.553004884160387, 20.739093519245237, 21.86092404268401, 22.927930565142596, 23.947442452170126, 24.92528836342721, 25.866194153759842, 26.774054605158327, 27.65212469232699, 28.503157719803607, 29.32950732624058, 30.13320427700977, 30.916015267171804, 31.679488632236474, 32.42499036237328, 33.15373282150895, 33.8667979000082, 34.565155865408734, 35.24968084961905, 35.92116367825519, 36.58032257922284, 37.22781218390358, 37.86423114233273, 38.490128604617574, 39.106009768320774, 39.71234065123838, 40.309552217805646, 40.898043963006344, 41.478187038490475, 42.050326990405196, 42.61478616630617, 43.17186583876125, 43.72184808536802, 44.26499745848857, 44.80156247275311, 45.331776934066895, 45.85586113028519, 46.374022900757694, 46.88645859947198, 47.39335396445371, 47.89488490434025, 48.39121821157223, 48.88251221040097, 49.36891734684892, 49.85057672685442, 50.32762660805693, 50.800196850012306, 51.26841132705401, 51.732388307519685, 52.192240802632725, 52.6480768879548, 53.09999999999999, 53.54810921031665, 53.99249947909431, 54.43326189013478, 54.87048386883425, 55.30424938465398, 55.734639139407726, 56.161730742561694, 56.585598874625326, 57.006315439607214, 57.42394970741737, 57.83856844701466, 58.25023605102386, 58.65901465248116, 59.0649642343073, 59.468142732054446, 59.86860613042532, 60.26640855401954, 60.66160235272392, 61.054238182127875, 61.44436507931382, 61.83203053434361, 62.21728055773573, 62.60015974420513, 62.98071133291525, 63.35897726447295, 63.734998234878766, 64.10881374662925, 64.48046215715269, 64.84998072474656, 65.21740565217233, 65.58277212805204, 65.94611436620053, 66.3074656430179, 66.66685833305782, 67.02432394287912, 67.37989314328124, 67.7335958000164, 68.08546100306584, 68.43551709456136, 68.78379169542778, 69.13031173081747, 69.475103454403], [0.0, 6.97137002317335, 9.859006035092989, 12.074767078498864, 13.9427400463467, 15.588457268119896, 17.076299364909246, 18.444511378727277, 19.718012070185978, 20.914110069520046, 22.045407685048602, 23.121418641597234, 24.149534156997728, 25.13563207878409, 26.084478143140988, 26.999999999999996, 27.8854800926934, 28.74369496080836, 29.577018105278967, 30.387497429041435, 31.176914536239792, 31.946830828737927, 32.69862382425291, 33.433516117812076, 34.15259872981849, 34.85685011586675, 35.5471517846367, 36.2243012354966, 36.889022757454555, 37.54197650630557, 38.18376618407356, 38.81494557512608, 39.436024140371956, 40.04747183031658, 40.64972324629037, 41.243181254602554, 41.82822013904009, 42.405188361803084, 42.974410990727954, 43.53619184081217, 44.090815370097204, 44.638548363494074, 45.17964143284008, 45.71433035712105, 46.24283728319447, 46.765371804359674, 47.28213193162931, 47.79330497046631, 48.299068313995456, 48.79959016221345, 49.29503017546495, 49.78554006938159, 50.27126415756818, 50.75233984753807, 51.22889809472775, 51.70106381884226, 52.168956286281976, 52.632689461968404, 53.09237233350945, 53.548109210316646, 53.99999999999999, 54.44814046411502, 54.89262245511686, 55.333534136181825, 55.7709601853868, 56.204981985585576, 56.63567780118817, 57.06312294293048, 57.48738992161672, 57.90854859172348, 58.32666628567074, 58.74180793949059, 59.15403621055793, 59.56341158798747, 59.96999249624765, 60.37383539249432, 60.77499485808287, 61.17352368467914, 61.569472955353454, 61.96289212101061, 62.353829072479584, 62.74233020856015, 63.128440500300655, 63.512203551758454, 63.89366165747585, 64.27285585688564, 64.64982598584469, 65.02461072547838, 65.39724764850583, 65.76777326320239, 66.1362230551458, 66.5026315268802, 66.86703223562415, 67.22945782913915, 67.5899400798669, 67.94850991743674, 68.30519745963699, 68.66003204193834, 69.01304224565092, 69.36425592479169, 69.7137002317335, 70.06140164170283], [0.0, 7.029224708315989, 9.940824915468534, 12.174974332621815, 14.058449416631978, 15.717824276915684, 17.218013822738094, 18.59758048779464, 19.881649830937068, 21.087674124947963, 22.228360263411243, 23.313300924579515, 24.34994866524363, 25.344230112591703, 26.300950553164423, 27.22407023205751, 28.116898833263956, 28.98223593858831, 29.822474746405604, 30.639680154988564, 31.435648553831367, 32.21195430271191, 32.969986351225565, 33.710977440590476, 34.43602764547619, 35.14612354157995, 35.84215395313178, 36.524922997865445, 37.19516097558928, 37.85353352066356, 38.500649345173386, 39.13706682928602, 39.763299661874136, 40.3798216935142, 40.98707113224852, 41.585454187732516, 42.175348249895926, 42.75710467279093, 43.3310512219586, 43.89749423372592, 44.45672052682249, 45.008999100179956, 45.55458264543755, 46.09370889828675, 46.62660184915903, 47.15347283074704, 47.6745214973365, 48.1899367088192, 48.69989733048726, 49.20457295821193, 49.704124577342675, 50.19870516258363, 50.688460225183405, 51.1735283129862, 51.65404146821428, 52.13012564726849, 52.601901106328846, 53.069482756100044, 53.532980488666986, 53.992499479094306, 54.44814046411502, 54.9, 55.34817070147847, 55.792741463383926, 56.23379766652791, 56.67142136915219, 57.10569148517509, 57.53668395032859, 57.96447187717662, 58.389125699910934, 58.81071330973635, 59.229300181582424, 59.64494949281121, 60.057722234530345, 60.46767731606697, 60.874871663109076, 61.27936030997713, 61.68119648644958, 62.08043169952993, 62.477115810510966, 62.871297107662734, 63.2630223748439, 63.65233695631293, 64.03928481799278, 64.42390860542382, 64.80624969862089, 65.18634826403455, 65.5642433038009, 65.93997270245113, 66.31357327123912, 66.68508079023373, 67.05453004831217, 67.42195488118095, 67.78738820754197, 68.15086206351317, 68.51240763540571, 68.87205529095237, 69.22983460907588, 69.58577440827975, 69.93990277373854, 70.2922470831599, 70.64283403148546], [0.0, 7.08660708661063, 10.02197585309404, 12.27436352728727, 14.17321417322126, 15.84613517549311, 17.35857136978732, 18.74939999039969, 20.04395170618808, 21.259821259831885, 22.409819276379718, 23.50361674296107, 24.54872705457454, 25.5511252198411, 26.51565575278122, 27.44631122755843, 28.34642834644252, 29.218829545346264, 30.065927559282116, 30.889804143114926, 31.69227035098622, 32.474913394803686, 33.2391335627149, 33.98617365929857, 34.71714273957464, 35.43303543305315, 36.134747819792516, 36.82309058186181, 37.49879998079938, 38.16254708480554, 38.81494557512608, 39.45655839020935, 40.08790341237616, 40.70945836043511, 41.32166501969639, 41.924932915867615, 42.51964251966377, 43.10614805338097, 43.68477995824175, 44.255847071319295, 44.819638552759436, 45.37642559743991, 45.92646295982306, 46.4699903163321, 47.00723348592214, 47.538405526479316, 48.06370772214728, 48.5833304745568, 49.09745410914908, 49.60624960627441, 50.1098792654702, 50.60849731023438, 51.1022504396822, 51.59127833267945, 52.07571410936196, 52.555684754363156, 53.03131150556244, 53.50271021172666, 53.96999166203382, 54.43326189013477, 54.89262245511686, 55.348170701478466, 55.8, 56.24819997119907, 56.69285669288504, 57.13405289317396, 57.571868130190104, 58.00637895955926, 58.43765909069253, 58.86577953276419, 59.29080873120217, 59.71281269543413, 60.13185511856423, 60.547997489594984, 60.961299198753956, 61.37181763643635, 61.77960828622985, 62.18472481244891, 62.58721914256936, 62.987141544921684, 63.38454070197244, 63.779463779495664, 64.17195649191319, 64.56206316405942, 64.94982678960737, 65.33528908637352, 65.71849054870326, 66.09947049712274, 66.4782671254298, 66.8549175453833, 67.22945782913915, 67.60192304957012, 67.97234731859714, 68.34076382365066, 68.70720486237232, 69.0717018756596, 69.43428547914928, 69.79498549322867, 70.15383097165828, 70.51085022888321, 70.8660708661063, 71.21951979619071], [0.0, 7.143528539874395, 10.102474944289641, 12.372954376380768, 14.28705707974879, 15.973415414368965, 17.497999885701223, 18.900000000000002, 20.204949888579282, 21.43058561962318, 22.58982071642004, 23.692403845958733, 24.745908752761537, 25.756358438257532, 26.728636328851497, 27.666767068090916, 28.57411415949758, 29.453522709516427, 30.307424832868925, 31.13791900561115, 31.94683082873793, 32.73576026305178, 33.50611884417532, 34.259159359213704, 34.995999771402445, 35.71764269937197, 36.42499142072651, 37.11886312914231, 37.800000000000004, 38.46907849169252, 39.12671721471148, 39.773483629171835, 40.409899777158564, 41.036447214640795, 41.65357127546209, 42.26168477474602, 42.86117123924636, 43.45238773646392, 44.03566736181025, 44.61132143301744, 45.17964143284008, 45.740900734463025, 46.29535613860207, 46.84324924682317, 47.384807691917466, 47.92024624310689, 48.44976780130117, 48.97356429748605, 49.49181750552307, 50.00469977912076, 50.51237472144821, 51.0149977947662, 51.512716876515064, 52.00567276749721, 52.49399965710367, 52.97782554994118, 53.457272657702994, 53.93245775968309, 54.40349253494669, 54.87048386883425, 55.33353413618183, 55.792741463383926, 56.24819997119908, 56.7, 57.14822831899516, 57.592968320794164, 58.03430020255262, 58.47230113481083, 58.907045419032855, 59.338604634756955, 59.76704777718237, 60.19244138594148, 60.61484966573785, 61.03433459946951, 61.45095605440163, 61.86477188190384, 62.2758380112223, 62.68420853771706, 63.089935805958795, 63.49307048804617, 63.89366165747586, 64.29175685886955, 64.68740217383908, 65.08064228324733, 65.47152052610356, 65.86007895531253, 66.24635839048061, 66.63039846796656, 67.01223768835064, 67.3919134614829, 67.76946214926012, 68.1449191062694, 68.51831871842741, 68.8896944397346, 69.25907882725556, 69.62650357442918, 69.99199954280489, 70.35559679229507, 70.71732461002749, 71.0772115378762, 71.43528539874394, 71.791573321665], [0.0, 7.2, 10.182337649086284, 12.470765814495918, 14.4, 16.09968943799849, 17.636326148038883, 19.04940943966505, 20.364675298172568, 21.599999999999998, 22.768399153212332, 23.879698490558884, 24.941531628991836, 25.959969183340725, 26.93993318477238, 27.885480092693403, 28.8, 29.686360504447155, 30.547012947258853, 31.38407239349285, 32.19937887599698, 32.99454500368205, 33.7709934707287, 34.529986967851585, 35.272652296077766, 36.0, 36.712940497868054, 37.41229744348775, 38.0988188793301, 38.77318661136843, 39.436024140371956, 40.08790341237616, 40.729350596345135, 41.36085105507381, 41.98285364288617, 42.595774438317235, 43.199999999999996, 43.795890218147186, 44.38378082137663, 44.963985588468475, 45.536798306424664, 46.10249450951651, 46.661333028536596, 47.2135573749744, 47.75939698111777, 48.299068313995456, 48.832775878501934, 49.36071312288752, 49.88306325798367, 50.400000000000006, 50.91168824543143, 51.418284685508524, 51.91993836668145, 52.41679120281974, 52.908978444116656, 53.39662910708878, 53.87986636954476, 54.3588079339494, 54.83356636222015, 55.30424938465397, 55.770960185386805, 56.23379766652791, 56.69285669288504, 57.14822831899516, 57.6, 58.04825578774956, 58.49307651337891, 58.93453995748164, 59.37272100889431, 59.80769181301014, 60.23952191045344, 60.668278366869785, 61.094025894517706, 61.51682696628623, 61.936741922706915, 62.353829072479584, 62.7681447869857, 63.17974358922328, 63.58867823756051, 63.99499980467224, 64.39875775199395, 64.8, 65.1987729945894, 65.59512176983895, 65.9890900073641, 66.3807200925088, 66.77005316756907, 67.15712918223947, 67.5419869414574, 67.92466415080754, 68.305197459637, 68.68362250202009, 69.05997393570317, 69.43428547914928, 69.80658994679514, 70.17691928262454, 70.54530459215553, 70.91177617293197, 71.27636354360399, 71.63909547167664, 72.0, 72.35910447207041], [0.0, 7.256031973468694, 10.26157882589224, 12.567816039392048, 14.512063946937388, 16.224980739587952, 17.77357589231835, 19.197656106931387, 20.52315765178448, 21.76809592040608, 22.94558781116753, 24.06553552281769, 25.135632078784095, 26.161995336747538, 27.149585632197038, 28.102490992792788, 29.024127893874777, 29.917386249470386, 30.784736477676724, 31.62831010345004, 32.449961479175904, 33.2513157634401, 34.03380672214027, 34.79870687252617, 35.5471517846367, 36.28015986734347, 36.99864862397004, 37.70344811817614, 38.39531221386277, 39.07492802296633, 39.742923898475304, 40.39987623743419, 41.04631530356896, 41.68273023687388, 42.309573384755375, 42.92726406376255, 43.53619184081216, 44.13671940686122, 44.729185103241036, 45.31390515062678, 45.89117562233506, 46.4612741969051, 47.02446171940727, 47.58098359639068, 48.13107104563538, 48.674942218763846, 49.21280321217233, 49.74484897956772, 50.27126415756819, 50.79222381428086, 51.30789412946121, 51.818433013745214, 52.323990673495075, 52.82471012698508, 53.320727676955045, 53.81217334395629, 54.299171264394076, 54.781840056719524, 55.26029315883151, 55.73463913940772, 56.204981985585576, 56.67142136915219, 57.13405289317396, 57.59296832079416, 58.048255787749554, 58.49999999999999, 58.948282417726126, 59.3931814268271, 59.83477249894077, 60.27312834091158, 60.70831903454418, 61.140412167403646, 61.56947295535345, 61.99556435746028, 62.418747183838924, 62.83908019696023, 63.25662020690008, 63.67142216096637, 64.08353922810444, 64.49302287844786, 64.89992295835181, 65.30428776121825, 65.70616409439833, 66.10559734243387, 66.5026315268802, 66.89730936293327, 67.28967231306747, 67.6797606378746, 68.06761344428054, 68.45326873130311, 68.8367634335026, 69.2181334622655, 69.59741374505234, 69.9746382627306, 70.3498400851061, 70.72305140475768, 71.0943035692734, 71.46362711197914, 71.83105178124569, 72.19660656845306, 72.56031973468694, 72.92221883623674], [0.0, 7.311634564172365, 10.34021276376845, 12.66412255152326, 14.62326912834473, 16.349311912126456, 17.90977386791916, 19.34476673418421, 20.6804255275369, 21.93490369251709, 23.12141864159723, 24.249948453553465, 25.32824510304652, 26.362473328578258, 27.357631476427194, 28.31783890059409, 29.24653825668946, 30.146641603999605, 31.020638291305353, 31.87067617732639, 32.69862382425291, 33.50611884417531, 34.294605989863776, 35.06536752980068, 35.81954773583832, 36.55817282086182, 37.282167318974366, 37.99236765456978, 38.68953346836842, 39.374357137609245, 40.047471830316574, 40.70945836043511, 41.3608510550738, 42.002142802480925, 42.63378941637725, 43.256213426512495, 43.86980738503418, 44.47493676218101, 45.07194249197609, 45.66114321827697, 46.24283728319446, 46.81730449310383, 47.38480769191746, 47.945594166721925, 48.49989690710693, 49.04793573637936, 49.589918330241275, 50.12604113631956, 50.65649020609304, 51.18144194920655, 51.70106381884226, 52.21551493569704, 52.724946657156515, 53.229503097436485, 53.729321603757484, 54.224533193011446, 54.71526295285439, 55.20163041070436, 55.68374987372888, 56.161730742561694, 56.63567780118818, 57.1056914851751, 57.57186813019011, 58.03430020255263, 58.49307651337892, 58.94828241772613, 59.4, 59.84830824676667, 60.29328320799921, 60.73499814769076, 61.17352368467914, 61.60892792444939, 62.041276582610706, 62.4706331006818, 62.897058754762135, 63.3206127576163, 63.74135235465278, 64.15933291423782, 64.57460801274756, 64.98722951472851, 65.39724764850583, 65.80471107755127, 66.20966696789827, 66.612161051868, 67.01223768835062, 67.40993991986642, 67.80530952661451, 68.19838707770148, 68.58921197972755, 68.977822522895, 69.36425592479169, 69.74854837199123, 70.13073505960136, 70.51085022888321, 70.88892720305478, 71.26499842138495, 71.63909547167664, 72.01124912123106, 72.38148934637917, 72.74984536066039, 73.11634564172364, 73.48101795702071], [0.0, 7.366817494685205, 10.418253212511202, 12.759702190882043, 14.73363498937041, 16.472704695950817, 18.044943890187078, 19.490767044936945, 20.836506425022403, 22.100452484055612, 23.29592238998061, 24.432969528896813, 25.519404381764087, 26.56143821407267, 27.5641070960044, 28.531561471465242, 29.46726997874082, 30.374166655235168, 31.254759637533606, 32.111212994840294, 32.945409391901634, 33.758998800319894, 34.553436876814445, 35.33001556750294, 36.089887780374156, 36.834087473426024, 37.563546158476576, 38.279106572646135, 38.98153408987389, 39.67152631296154, 40.349721188627804, 41.016703914381026, 41.673012850044806, 42.3191446038315, 42.95555842961421, 43.5826800460917, 44.200904968111224, 44.81060142421657, 45.41211292155431, 46.00576050887541, 46.59184477996122, 47.170647652963176, 47.74243395554944, 48.307452841150706, 48.865939057793625, 49.41811408785244, 49.96418717441524, 50.50435624775352, 51.03880876352817, 51.56772246279644, 52.091266062556016, 52.609599884431745, 53.12287642814534, 53.6312408955825, 54.13483167056124, 54.63378075879428, 55.1282141920088, 55.61825239972936, 56.10401055183132, 56.585598874625326, 57.063122942930484, 57.53668395032859, 58.006378959559264, 58.47230113481083, 58.93453995748164, 59.3931814268271, 59.84830824676667, 60.3, 60.748333310470336, 61.19338199511447, 61.63521720575015, 62.07390756187337, 62.50951927506721, 62.942116265661106, 63.3717602722222, 63.79851095441021, 64.22242598968059, 64.64356116427993, 65.06197045894015, 65.47770612964385, 65.89081878380327, 66.30135745216684, 66.70936965674312, 67.11490147500777, 67.51799760063979, 67.91870140101325, 68.31705497165404, 68.71309918785501, 69.10687375362889, 69.49841724816473, 69.88776716994184, 70.27495997864389, 70.66003113500588, 71.0430151387172, 71.42394556449538, 71.80285509643748, 72.17977556074831, 72.55473795693842, 72.92777248757842, 73.29890858669043, 73.66817494685205, 74.03559954508371], [0.0, 7.42159012611179, 10.49571341072154, 12.854571171377131, 14.84318025222358, 16.5951800231272, 18.17910888905174, 19.635681806344287, 20.99142682144308, 22.264770378335363, 23.469128658729534, 24.61462979611922, 25.709142342754262, 26.75892374517331, 27.769047516974723, 28.74369496080836, 29.68636050444716, 30.599999999999998, 31.48714023216462, 32.34996136010057, 33.1903600462544, 34.00999852984413, 34.810343290464694, 35.59269587991334, 36.35821777810348, 37.107950630558946, 37.84283287493155, 38.56371351413139, 39.271363612688575, 39.966485960114134, 40.64972324629037, 41.32166501969639, 41.98285364288616, 42.63378941637724, 43.274935008616715, 43.906719303541685, 44.52954075667073, 45.14377033434403, 45.7497540976998, 46.347815482501446, 46.93825731745907, 47.52136361679871, 48.0974011771946, 48.66662100454478, 49.22925959223844, 49.78554006938158, 50.33567323479443, 50.87985849036925, 51.418284685508524, 51.95113088278253, 52.478567053607705, 53.00075471160765, 53.51784749034662, 54.02999167129309, 54.53732666715523, 55.03998546511436, 55.538095033949446, 56.031776698584174, 56.5211464851873, 57.00631543960721, 57.48738992161672, 57.96447187717662, 58.437659090692534, 58.907045419032855, 59.37272100889432, 59.83477249894078, 60.29328320799921, 60.748333310470336, 61.199999999999996, 61.64835764235735, 62.093477918377225, 62.53542995774475, 62.97428046432924, 63.41009383371074, 63.842932263485515, 64.27285585688566, 64.69992272020114, 65.12418905445196, 65.54570924171927, 65.9645359265113, 66.3807200925088, 66.7943111350061, 67.2053569293401, 67.61390389557461, 68.01999705968827, 68.42368011149357, 68.82499545949858, 69.22398428290587, 69.62068658092939, 70.0151412195962, 70.4073859761886, 70.79745758146969, 71.18539175982669, 71.57122326745576, 71.95498592870406, 72.33671267067642, 72.71643555620696, 73.09418581528904, 73.46999387505079, 73.84388938835765, 74.21590126111789, 74.5860576783624], [0.0, 7.475961476626268, 10.572606112023658, 12.948745112944344, 14.951922953252536, 16.71675805890604, 18.312290954438225, 19.77953487825232, 21.145212224047317, 22.4278844298788, 23.641065965814654, 24.794959165120645, 25.89749022588869, 26.95496243736949, 27.972486482256098, 28.95427429586174, 29.903845906505072, 30.824178821178677, 31.717818336070973, 32.586960582417014, 33.43351611781208, 34.25915935921371, 35.06536752980069, 35.853451716675764, 36.62458190887645, 37.379807383131336, 38.120073452185274, 38.84623533883303, 39.55906975650464, 40.259284643421076, 40.94752739787837, 41.62439188744984, 42.29042444809463, 42.94612904558454, 43.59197173792441, 44.22838455110021, 44.8557688597576, 45.474498347975214, 46.08492161217159, 46.68736445763458, 47.28213193162931, 47.86951012909992, 48.44976780130118, 49.02315779302675, 49.58991833024129, 50.15027417671811, 50.704437675611786, 51.25260968965386, 51.79498045177738, 52.33173033638388, 52.86303056011829, 53.38904381987002, 53.90992487473898, 54.425821077867084, 54.936872863314676, 55.443214192541184, 55.944972964512196, 56.44227139299056, 56.93522635416497, 57.42394970741737, 57.90854859172348, 58.389125699910934, 58.86577953276419, 59.33860463475696, 59.807691813010145, 60.27312834091159, 60.73499814769076, 61.19338199511447, 61.648357642357354, 62.1, 62.548381274018595, 62.99357110054962, 63.435636672141946, 63.87464285614442, 64.31065230581945, 64.74372556472171, 65.17392116483403, 65.60129571891092, 66.02590400744242, 66.44779906061599, 66.86703223562417, 67.2836532896364, 67.69771044872937, 68.10925047304515, 68.51831871842742, 68.92495919476485, 69.32921462125472, 69.73112647878277, 70.13073505960138, 70.52807951447424, 70.92319789744397, 71.31612720836712, 71.70690343335153, 72.09556158322093, 72.48213573012319, 72.86665904239057, 73.2491638177529, 73.62968151499776, 74.0082427841656, 74.38487749536192, 74.75961476626267, 75.13248298838526], [0.0, 7.529940238806681, 10.648943609579309, 13.042239071570496, 15.059880477613362, 16.83745824048274, 18.444511378727277, 19.92234925906079, 21.297887219158618, 22.58982071642004, 23.811761799581316, 24.9739864659209, 26.08447814314099, 27.14958563219704, 28.17445651649735, 29.16333314283537, 30.119760955226724, 31.046738959188612, 31.946830828737927, 32.82224855185885, 33.67491648096548, 34.50652112282547, 35.318550366627456, 36.11232476592998, 36.889022757454555, 37.649701194033405, 38.39531221386278, 39.12671721471149, 39.84469851812158, 40.54996917384772, 41.24318125460256, 41.92493291586762, 42.595774438317235, 43.2562134265125, 43.90671930354169, 44.54772721475249, 45.17964143284008, 45.802838339998104, 46.417669049619455, 47.024461719407284, 47.62352359916263, 48.21514284952395, 48.799590162213455, 49.377120207642726, 49.9479729318418, 50.512374721448204, 51.07053945279999, 51.62266943891996, 52.16895628628198, 52.70958167164677, 53.24471804789655, 53.77452928664277, 54.29917126439408, 54.81879239822783, 55.33353413618184, 55.84353140695886, 56.3489130329947, 56.84980211047353, 57.34631635946638, 57.83856844701466, 58.32666628567074, 58.81071330973635, 59.290808731202176, 59.76704777718237, 60.23952191045345, 60.70831903454419, 61.17352368467914, 61.63521720575015, 62.093477918377225, 62.548381274018595, 63.00000000000001, 63.44840423525245, 63.89366165747585, 64.33583760238146, 64.7749951756077, 65.21119535785247, 65.6444971037177, 66.07495743471955, 66.50263152688021, 66.92757279328154, 67.34983296193096, 67.76946214926012, 68.18650892955293, 68.60102040057421, 69.01304224565094, 69.42261879243681, 69.82979306857497, 70.23460685445602, 70.63710073325491, 71.03731413841602, 71.43528539874394, 71.83105178124569, 72.22464953185997, 72.61611391419952, 73.00547924642369, 73.39277893635041, 73.77804551490911, 74.1613106680296, 74.54260526705517, 74.92195939776269, 75.29940238806681, 75.67496283448048], [0.0, 7.583534795858723, 10.724737759031687, 13.135067567393783, 15.167069591717446, 16.957299313275097, 18.575790696495265, 20.064147128647157, 21.449475518063373, 22.750604387576164, 23.98124267005361, 25.15173950246782, 26.270135134787566, 27.34282355573396, 28.374988986782004, 29.370903969745296, 30.334139183434893, 31.267714978872377, 32.174213277095056, 33.05586180997253, 33.914598626550195, 34.75212223735409, 35.569931121665114, 36.36935523211815, 37.15158139299053, 37.91767397929362, 38.6685919060935, 39.40520270218135, 40.128294257294314, 40.83858469633834, 41.536730733171574, 42.22333478066364, 42.898951036126746, 43.56409071701142, 44.21922658753769, 44.86479689021226, 45.50120877515233, 46.128841303462195, 46.748048087593986, 47.359159620922334, 47.96248534010722, 48.55831545677836, 49.14692258931377, 49.72856322074869, 50.30347900493564, 50.87189793982528, 51.434035424026376, 51.99009521053025, 52.54027026957513, 53.08474357101106, 53.62368879515844, 54.157270979989384, 54.68564711146792, 55.20896666303401, 55.7273720894858, 56.24099927988478, 56.74997797356401, 57.254432142848124, 57.75448034568401, 58.250236051023855, 58.74180793949059, 59.229300181582424, 59.71281269543413, 60.19244138594147, 60.668278366869785, 61.140412167403646, 61.60892792444939, 62.07390756187336, 62.53542995774475, 62.993571100549616, 63.44840423525244, 63.9, 64.34842655419011, 64.79374969856275, 65.23603298791244, 65.67533783696891, 66.11172361994505, 66.54524776420928, 66.97596583850061, 67.40393163607001, 67.82919725310039, 68.25181316272851, 68.67182828496705, 69.08929005280051, 69.50424447470817, 69.91673619384703, 70.32680854411069, 70.73450360326281, 71.13986224333023, 71.54292417842592, 71.94372801016083, 72.3423112707909, 72.7387104642363, 73.13296110509953, 73.52509775580036, 73.9151540619378, 74.30316278598106, 74.68915583938542, 75.07316431322181, 75.45521850740346, 75.83534795858723, 76.21358146682257], [0.0, 7.636753236814713, 10.799999999999999, 13.227244611029162, 15.273506473629427, 17.07629936490925, 18.706148721743876, 20.204949888579286, 21.599999999999998, 22.910259710444137, 24.149534156997728, 25.328245103046523, 26.454489222058324, 27.53470537340104, 28.57411415949758, 29.57701810527897, 30.547012947258853, 31.48714023216462, 32.4, 33.287835616032474, 34.1525987298185, 34.995999771402445, 35.81954773583832, 36.62458190887645, 37.41229744348775, 38.18376618407357, 38.939953775011084, 39.68173383308749, 40.40989977715857, 41.12517477166511, 41.8282201390401, 42.51964251966378, 43.199999999999996, 43.86980738503419, 44.52954075667074, 45.17964143284008, 45.820519420888274, 46.452556442030186, 47.07610859023927, 47.69150867817038, 48.299068313995456, 48.89907974594205, 49.49181750552307, 50.07753987567679, 50.656490206093046, 51.22889809472774, 51.79498045177737, 52.35494246009635, 52.90897844411665, 53.457272657702994, 54.0, 54.53732666715523, 55.06941074680208, 55.596402761329806, 56.11844616523163, 56.63567780118819, 57.14822831899516, 57.656222560969084, 58.15977991705265, 58.65901465248116, 59.15403621055794, 59.64494949281121, 60.13185511856424, 60.61484966573785, 61.094025894517706, 61.56947295535345, 62.041276582610706, 62.50951927506721, 62.97428046432924, 63.435636672141946, 63.89366165747585, 64.34842655419013, 64.8, 65.2484482574107, 65.69383532722077, 66.1362230551458, 66.57567123206495, 67.01223768835062, 67.44597838270272, 67.87694748587329, 68.305197459637, 68.73077913133243, 69.15374176427477, 69.57413312431568, 69.99199954280489, 70.4073859761886, 70.8203360624616, 71.23089217467377, 71.63909547167664, 72.04498594628221, 72.4486024709932, 72.84998284145303, 73.2491638177529, 73.64618116372363, 74.04106968433128, 74.43386326128719, 74.8245948869755, 75.21329669679425, 75.60000000000001, 75.98473530913957, 76.36753236814714, 76.74842017918024], [0.0, 7.689603370785778, 10.874741376235114, 13.31878372825387, 15.379206741571556, 17.194475857088523, 18.835604582810717, 20.344778199823168, 21.74948275247023, 23.068810112357333, 24.316660954991335, 25.50352916754856, 26.63756745650774, 27.725259241348855, 28.771861253662404, 29.781705793993734, 30.758413483143112, 31.705046916855366, 32.62422412870534, 33.51820400916493, 34.38895171417705, 35.238189510813406, 36.06743683712498, 36.87804224738618, 37.671209165621434, 38.44801685392889, 39.20943763942554, 39.95635118476161, 40.689556399646335, 41.409781453178425, 42.11769224447132, 42.813899612158664, 43.49896550494046, 44.173408290508895, 44.83770734549215, 45.4923070419604, 46.13762022471467, 46.77403125667062, 47.40189869614929, 48.02155765903477, 48.63332190998267, 49.23748571972375, 49.83432551966566, 50.42410138019317, 51.00705833509712, 51.58342757126555, 52.15342750002151, 52.7172647241869, 53.27513491301548, 53.82722359550045, 54.37370688117558, 54.91475211634849, 55.45051848269771, 55.981157544302356, 56.50681374843215, 57.0276248847872, 57.54372250732481, 58.0552323223325, 58.56227454599079, 59.06496423430729, 59.56341158798747, 60.05772223453034, 60.54799748959498, 61.0343345994695, 61.516826966286224, 61.99556435746028, 62.470633100681795, 62.9421162656611, 63.41009383371073, 63.874642856144405, 64.33583760238146, 64.79374969856275, 65.24844825741069, 65.7, 66.14846937004666, 66.59391864126934, 67.03640801832987, 67.47599573181563, 67.91273812768854, 68.34668975158928, 68.7779034283541, 69.206430337072, 69.63232008198491, 70.05562075950795, 70.47637902162681, 70.89464013590873, 71.3104480423451, 71.72384540722841, 72.13487367424996, 72.5435731129919, 72.949982864974, 73.35414098740439, 73.75608449477237, 74.15584939841226, 74.55347074415785, 74.94898264819876, 75.34241833124287, 75.73381015108114, 76.12318963364581, 76.51058750264568, 76.89603370785778, 77.27955745214902], [0.0, 7.742092740338364, 10.948972554536795, 13.409697983176207, 15.484185480676729, 17.31184565550421, 18.96417675513493, 20.483652018133874, 21.89794510907359, 23.22627822101509, 24.482646915723798, 25.67761671183679, 26.819395966352413, 27.914512354687478, 28.968258490975945, 29.984996248123824, 30.968370961353457, 31.921466131742754, 32.846917663610384, 33.74699986665481, 34.62369131100842, 35.47872601996864, 36.31363380329763, 37.129772420525285, 37.92835351026986, 38.71046370169182, 39.47708195903036, 40.22909394952862, 40.96730403626775, 41.69244535884169, 42.405188361803084, 43.10614805338097, 43.79589021814718, 44.47493676218101, 45.14377033434403, 45.8028383399981, 46.45255644203018, 47.093311627024065, 47.72546490082626, 48.34935366682786, 48.965293831447596, 49.57358167411348, 50.174495513158874, 50.76829719421362, 51.35523342367358, 51.93553696651262, 52.50942772493335, 53.07711371203223, 53.63879193270483, 54.19464918236855, 54.74486277268398, 55.28960119226761, 55.829024709374956, 56.36328592266423, 56.892530265404794, 57.41689646785169, 57.93651698195189, 58.45151837206626, 58.96202167497312, 59.46814273205443, 59.96999249624765, 60.46767731606696, 60.961299198753956, 61.45095605440162, 61.936741922706915, 62.418747183838924, 62.89705875476213, 63.37176027222219, 63.84293226348551, 64.31065230581945, 64.77499517560769, 65.23603298791244, 65.69383532722077, 66.14846937004666, 66.6, 67.04848991588102, 67.49399973330962, 67.93658808035623, 68.37631168760129, 68.813225473015, 69.24738262201684, 69.67883466304528, 70.1076315389416, 70.53382167442793, 70.95745203993728, 71.37856821203407, 71.79721443064487, 72.21343365330303, 72.62726760659525, 73.03875683498453, 73.44794074717139, 73.85485766014311, 74.25954484105057, 74.6620385470421, 75.06237406317496, 75.46058573851649, 75.85670702053972, 76.25077048791049, 76.64280788175756, 77.03285013551037, 77.42092740338364, 77.80706908758356], [0.0, 7.794228634059948, 11.022703842524301, 13.500000000000002, 15.588457268119896, 17.428425057933378, 19.091883092036785, 20.62159062730128, 22.045407685048602, 23.38268590217984, 24.647515087732476, 25.850531909421132, 27.000000000000004, 28.10249099279279, 29.16333314283537, 30.18691769624716, 31.176914536239792, 32.13642792844282, 33.0681115275729, 33.974254958718376, 34.856850115866756, 35.71764269937198, 36.55817282086183, 37.379807383131336, 38.18376618407357, 38.97114317029974, 39.74292389847531, 40.50000000000001, 41.24318125460256, 41.97320573889967, 42.690748412273116, 43.3964284244683, 44.090815370097204, 44.774434669797905, 45.447772222629354, 46.11127844681819, 46.76537180435968, 47.41044188783733, 48.0468521341409, 48.67494221876386, 49.29503017546495, 49.90741427884238, 50.51237472144821, 51.110175112202455, 51.701063818842265, 52.28527517380012, 52.86303056011829, 53.43453939167063, 54.00000000000001, 54.559600438419636, 55.11351921262151, 55.661925945838426, 56.20498198558558, 56.74284095813322, 57.27564927611036, 57.803546603993084, 58.32666628567074, 58.8451357377991, 59.359076812228146, 59.86860613042531, 60.37383539249432, 60.87487166310907, 61.371817636436354, 61.86477188190384, 62.353829072479584, 62.83908019696023, 63.320612757616296, 63.79851095441021, 64.27285585688564, 64.74372556472171, 65.21119535785247, 65.67533783696891, 66.1362230551458, 66.59391864126934, 67.04848991588104, 67.5, 67.94850991743675, 68.39407869106799, 68.83676343350261, 69.27661943253294, 69.71370023173351, 70.14805770653953, 70.57974213611155, 71.00880227126775, 71.43528539874396, 71.85923740202091, 72.28070281894055, 72.6997248963158, 73.11634564172365, 73.53060587265686, 73.94254526319743, 74.35220238836239, 74.75961476626267, 75.1648188982053, 75.56785030686, 75.96874357260359, 76.36753236814714, 76.76424949154392, 77.15892689767011, 77.5515957282634, 77.94228634059948, 78.33102833488145], [0.0, 7.8460180983732135, 11.095945205344158, 13.589701983487352, 15.692036196746427, 17.54422982065614, 19.218740853656364, 20.758612670407434, 22.191890410688316, 23.538054295119636, 24.8112877537624, 26.022298130641733, 27.179403966974704, 28.289220561903083, 29.357111574540166, 30.38749742904144, 31.384072393492854, 32.34996136010057, 33.287835616032474, 34.2, 35.08845964131228, 35.954971839788726, 36.80108694046958, 37.62818092866038, 38.43748170731273, 39.230090491866065, 40.00699938760717, 40.769105950462055, 41.51722534081487, 42.252100539499814, 42.97441099072796, 43.684779958241755, 44.38378082137663, 45.0719424919761, 45.749754097699814, 46.41766904961946, 47.07610859023927, 47.725464900826275, 48.366103833159855, 48.99836731973833, 49.6225755075248, 50.23902865303031, 50.84800881057193, 51.44978134064323, 52.044596261283466, 52.632689461968404, 53.21428379674014, 53.789590070942175, 54.35880793394941, 54.922126688612494, 55.4797260267208, 56.03177669858418, 56.578441123806165, 57.11987394944076, 57.65622256096909, 58.18762755088062, 58.71422314908033, 59.236137618855615, 59.75349362171221, 60.26640855401954, 60.77499485808288, 61.27936030997713, 61.77960828622986, 62.275838011222305, 62.76814478698571, 63.25662020690009, 63.74135235465279, 64.22242598968059, 64.69992272020114, 65.17392116483403, 65.6444971037177, 66.11172361994505, 66.57567123206495, 67.03640801832988, 67.49399973330964, 67.94850991743675, 68.4, 68.848529396059, 69.29415559771259, 69.73693426011786, 70.17691928262455, 70.61416288535892, 71.048715681566, 71.48062674599322, 71.90994367957745, 72.33671267067643, 72.76097855306786, 73.18278486092204, 73.60217388093916, 74.01918670182754, 74.4338632612872, 74.84624239065046, 75.25636185732075, 75.66425840514134, 76.06996779281559, 76.4735248304928, 76.87496341462546, 77.27431656119647, 77.67161643740911, 78.0668943919252, 78.46018098373213, 78.85150600971424], [0.0, 7.897467948652911, 11.16870628139177, 13.678815738213599, 15.794935897305821, 17.659275183313728, 19.344766734184212, 20.894736179239022, 22.33741256278354, 23.69240384595873, 24.973986465920895, 26.19293797953945, 27.357631476427198, 28.474725635201477, 29.54961928688761, 30.58676184233957, 31.589871794611643, 32.56209452722598, 33.50611884417531, 34.4242646980295, 35.318550366627456, 36.190744673189585, 37.042408129062025, 37.87492574250147, 38.689533468368424, 39.48733974326455, 40.26934317815477, 41.0364472146408, 41.789472358478044, 42.52916646255838, 43.256213426512495, 43.97124060110199, 44.67482512556708, 45.367499380062824, 46.04975569967772, 46.722050468702676, 47.38480769191746, 48.03842212229707, 48.683262010674675, 49.31967153175294, 49.94797293184179, 50.56846843636853, 51.18144194920655, 51.78716057093688, 52.3858759590789, 52.97782554994117, 53.56323365891944, 54.14231247370212, 54.715262952854395, 55.282275640570376, 55.84353140695886, 56.399202122015886, 56.94945127040295, 57.49443451326398, 58.034300202552636, 58.56918985268621, 59.09923857377522, 59.62457547018679, 60.14532400777305, 60.66160235272391, 61.17352368467914, 61.68119648644958, 62.18472481244892, 62.684208537717055, 63.179743589223285, 63.67142216096637, 64.15933291423781, 64.64356116427993, 65.12418905445196, 65.60129571891092, 66.07495743471955, 66.54524776420928, 67.01223768835062, 67.47599573181563, 67.93658808035623, 68.39407869106799, 68.848529396059, 69.3, 69.74854837199125, 70.1942305321456, 70.63710073325491, 71.0772115378762, 71.51461389114816, 71.94935718962331, 72.38148934637917, 72.81105685265116, 73.23810483621214, 73.66267711670545, 74.08481625812405, 74.50456361861333, 74.92195939776269, 75.33704268153882, 75.74985148500294, 76.16042279294412, 76.56879259855154, 76.97499594024023, 77.37906693673685, 77.7810388205249, 78.1809439697424, 78.57881393861835, 78.9746794865291, 79.36857060575049], [0.0, 7.9485847796950635, 11.240996397117117, 13.767352686700521, 15.897169559390127, 17.773575892318352, 19.469976887505545, 21.029978601986265, 22.481992794234234, 23.845754339085186, 25.1356320787841, 26.362473328578265, 27.534705373401042, 28.659029990563187, 29.740880955344956, 30.784736477676727, 31.794339118780254, 32.772854620859626, 33.72298919135135, 34.64707779885629, 35.547151784636704, 36.42499142072652, 37.28216731897437, 38.120073452185274, 38.93995377501109, 39.74292389847532, 40.529988897111735, 41.302058060101565, 42.05995720397253, 42.80443902213882, 43.53619184081217, 44.255847071319295, 44.96398558846847, 45.66114321827697, 46.347815482501446, 47.02446171940728, 47.69150867817037, 48.34935366682786, 48.99836731973832, 49.63889603929565, 50.2712641575682, 50.8957758561553, 51.51271687651507, 52.12235604805293, 52.72494665715653, 53.320727676955045, 53.909924874738984, 54.49275181159418, 55.069410746802085, 55.64009345786545, 56.20498198558559, 56.76424931239734, 57.318059981126375, 57.86657066044265, 58.409930662516636, 58.94828241772615, 59.48176191068991, 60.01049908141076, 60.53461819488087, 61.05423818212786, 61.569472955353454, 62.08043169952993, 62.58721914256936, 63.08993580595879, 63.58867823756051, 64.08353922810444, 64.57460801274755, 65.06197045894015, 65.54570924171925, 66.02590400744242, 66.50263152688021, 66.97596583850061, 67.4459783827027, 67.91273812768854, 68.37631168760129, 68.83676343350261, 69.29415559771257, 69.74854837199123, 70.20000000000002, 70.64856686444531, 71.09430356927341, 71.53726301725557, 71.97749648327596, 72.41505368360919, 72.84998284145304, 73.28233074896022, 73.71214282599578, 74.13946317582831, 74.56433463794875, 74.98679883819553, 75.4068962363523, 75.82466617137197, 76.24014690437055, 76.65337565952332, 77.06438866298754, 77.47322117996644, 77.87990755002218, 78.2844812207375, 78.68697477981983, 79.08741998573478, 79.48584779695064, 79.88228839986998], [0.0, 7.999374975584031, 11.312824580978882, 13.85532388650659, 15.998749951168062, 17.887146222916613, 19.59438695136952, 21.164356829348726, 22.625649161957764, 23.998124926752087, 25.296244780599352, 26.53092535137062, 27.71064777301318, 28.84215664613172, 29.930920466968605, 30.98144606050531, 31.997499902336124, 32.98226796325565, 33.938473742936644, 34.86846713005893, 35.774292445833225, 36.657741337949346, 37.5203944542165, 38.36365467470481, 39.18877390273904, 39.99687487792015, 40.78896909704878, 41.56597165951977, 42.32871365869745, 43.077952597587554, 43.814381200697106, 44.53863491397104, 45.25129832391553, 45.95291068039108, 46.64397067145978, 47.324940570485666, 47.996249853504175, 48.65829836728778, 49.31145911448981, 49.956080710960514, 50.592489561198704, 51.22099179047591, 51.84187496609281, 52.45540963523209, 53.06185070274124, 53.66143866874983, 54.254400743165526, 54.84095185169565, 55.42129554602636, 55.995624829088214, 56.56412290489441, 57.126963861210065, 57.68431329226344, 58.23632886781241, 58.78316085410856, 59.32495259163719, 59.86184093393721, 60.39395665130743, 60.92142480277362, 61.44436507931382, 61.96289212101062, 62.47711581051097, 62.98714154492169, 63.49307048804617, 63.99499980467225, 64.49302287844787, 64.98722951472851, 65.47770612964385, 65.9645359265113, 66.44779906061599, 66.92757279328154, 67.40393163607001, 67.87694748587329, 68.3466897515893, 68.813225473015, 69.27661943253294, 69.73693426011786, 70.1942305321456, 70.64856686444533, 71.1, 71.54858489166645, 71.99437478025628, 72.437421268292, 72.87777438972735, 73.31548267589869, 73.75059321795317, 74.18315172598156, 74.61320258506534, 75.040788908433, 75.46595258790549, 75.88873434179806, 76.3091737604333, 76.72730934940962, 77.14317857075893, 77.55681788211788, 77.96826277402876, 78.37754780547807, 78.78470663777331, 79.18977206685217, 79.59277605411185, 79.9937497558403, 80.39272355132647], [0.0, 8.049844718999244, 11.384199576606166, 13.942740046346703, 16.09968943799849, 18.000000000000004, 19.71801207018598, 21.29788721915862, 22.768399153212332, 24.149534156997728, 25.455844122715714, 26.698314553544392, 27.885480092693406, 29.02412789387478, 30.11976095522672, 31.176914536239792, 32.19937887599698, 33.1903600462544, 34.1525987298185, 35.08845964131228, 36.00000000000001, 36.88902275745456, 37.75711853412546, 38.605699061149, 39.43602414037196, 40.24922359499622, 41.046315303568974, 41.82822013904011, 42.59577443831724, 43.34974048365227, 44.090815370097204, 44.81963855275944, 45.536798306424664, 46.24283728319447, 46.938257317459076, 47.62352359916263, 48.299068313995456, 48.9652938314476, 49.6225755075248, 50.2712641575682, 50.91168824543143, 51.544155827794874, 52.16895628628198, 52.78636187501464, 53.396629107088785, 54.0, 54.596703197171166, 55.18695498032122, 55.77096018538681, 56.34891303299471, 56.920997883030836, 57.48738992161673, 58.04825578774956, 58.60375414595895, 59.15403621055795, 59.69924622639721, 60.23952191045344, 60.774994858082884, 61.30579091733506, 61.8320305343436, 62.353829072479584, 62.871297107662734, 63.38454070197243, 63.89366165747585, 64.39875775199395, 64.89992295835181, 65.39724764850583, 65.89081878380325, 66.3807200925088, 66.86703223562417, 67.34983296193096, 67.82919725310039, 68.305197459637, 68.7779034283541, 69.24738262201684, 69.71370023173351, 70.17691928262455, 70.63710073325491, 71.09430356927341, 71.54858489166645, 72.00000000000001, 72.4486024709932, 72.89444423273972, 73.33757563486812, 73.77804551490912, 74.21590126111789, 74.6511888719798, 75.08395301261116, 75.51423706825092, 75.94208319502435, 76.36753236814714, 76.79062442772556, 77.211398122298, 77.62989115025218, 78.04614019924368, 78.46018098373212, 78.87204828074393, 79.28177596396287, 79.68939703624316, 80.09494366063318, 80.49844718999243, 80.89993819527925], [0.0, 8.100000000000001, 11.45512985522207, 14.029611541307908, 16.200000000000003, 18.1121506177483, 19.840866916543746, 21.430585619623184, 22.91025971044414, 24.299999999999997, 25.614449047363873, 26.864660801878742, 28.059223082615816, 29.204965331258315, 30.307424832868925, 31.371165104280077, 32.400000000000006, 33.39715556750305, 34.36538956566621, 35.30708144267946, 36.2243012354966, 37.118863129142305, 37.99236765456978, 38.84623533883303, 39.68173383308749, 40.5, 41.30205806010156, 42.088834623923724, 42.86117123924637, 43.619834937789484, 44.36552715791845, 45.09889133892318, 45.82051942088828, 46.53095743695804, 47.23071034824694, 47.92024624310689, 48.599999999999994, 49.27037649541558, 49.93175342404871, 50.58448378702703, 51.22889809472775, 51.86530632320608, 52.49399965710367, 53.1152520468462, 53.729321603757484, 54.33645185324489, 54.936872863314676, 55.53080226324846, 56.11844616523163, 56.7, 57.27564927611036, 57.8455702711971, 58.40993066251663, 58.96889010317221, 59.52260074963124, 60.07120774547488, 60.61484966573785, 61.15365892569308, 61.687762157497666, 62.21728055773572, 62.742330208560155, 63.2630223748439, 63.77946377949567, 64.29175685886955, 64.80000000000001, 65.30428776121825, 65.80471107755127, 66.30135745216684, 66.7943111350061, 67.2836532896364, 67.76946214926012, 68.25181316272851, 68.73077913133243, 69.206430337072, 69.67883466304528, 70.14805770653953, 70.61416288535892, 71.0772115378762, 71.53726301725557, 71.99437478025627, 72.4486024709932, 72.9, 73.34861961891308, 73.79451199106882, 74.23772625828461, 74.6783101040724, 75.1163098135152, 75.55177033001941, 75.98473530913957, 76.4152471696585, 76.84334714209162, 77.2690753147726, 77.69247067766607, 78.11357116404294, 78.53241369014454, 78.94903419295261, 79.36346766617498, 79.77574819454846, 80.1859089865545, 80.59398240563623, 81.0, 81.40399253107923], [0.0, 8.149846624323676, 11.525623627379128, 14.115948427222312, 16.29969324864735, 18.223611058184932, 19.962965711536953, 21.562467391279693, 23.051247254758255, 24.449539872971023, 25.772077913897437, 27.02998335182618, 28.231896854444624, 29.38468989116612, 30.493933822975354, 31.564220250150328, 32.5993864972947, 33.60267846467005, 34.576870882137385, 35.524357840783, 36.447222116369865, 37.347289058243575, 38.22616904687155, 39.08529135109524, 39.925931423073905, 40.74923312161838, 41.55622697021471, 42.34784528166694, 43.124934782559386, 43.888267224851795, 44.63854836349408, 45.37642559743992, 46.10249450951651, 46.81730449310384, 47.521363616798716, 48.21514284952395, 48.899079745942046, 49.57358167411349, 50.23902865303031, 50.8957758561553, 51.544155827794874, 52.18448045156722, 52.81704270403636, 53.44211822149268, 54.05996670365236, 54.67083317455479, 55.27494911802272, 55.87253350260753, 56.46379370888925, 57.04892637026573, 57.628118136895644, 58.20154637120908, 58.76937978233224, 59.331779005858245, 59.888897134610865, 60.440880205370945, 60.98786764595071, 61.52999268649397, 62.06738273844002, 62.60015974420512, 63.128440500300655, 63.65233695631293, 64.1719564919132, 64.68740217383908, 65.1987729945894, 65.70616409439833, 66.20966696789827, 66.70936965674312, 67.2053569293401, 67.69771044872937, 68.18650892955293, 68.67182828496705, 69.15374176427477, 69.63232008198493, 70.10763153894162, 70.57974213611156, 71.048715681566, 71.51461389114816, 71.97749648327596, 72.43742126829198, 72.89444423273973, 73.34861961891309, 73.80000000000001, 74.24863635111423, 74.69457811648715, 75.1378732730705, 75.57856839078127, 76.01670868960325, 76.4523380937431, 76.88549928302476, 77.31623374169232, 77.74458180477917, 78.17058270219049, 78.59427460063489, 79.0156946435327, 79.43487898901842, 79.85186284614781, 80.26668050941188, 80.6793653916539, 81.08995005547852, 81.49846624323676, 81.9049449056649], [0.0, 8.19939022122987, 11.595688854052613, 14.20176045425355, 16.39878044245974, 18.33439390871703, 20.08432224397926, 21.69354742774911, 23.191377708105225, 24.598170663689604, 25.92874852359828, 27.194300873528633, 28.4035209085071, 29.563321870182314, 30.67930898830676, 31.756101775879227, 32.79756088491948, 33.806951947787304, 34.78706656215784, 35.7403133729966, 36.66878781743406, 37.574326341266584, 38.458549114598696, 39.32289409491626, 40.16864448795852, 40.996951106149346, 41.808850737612964, 42.60528136276066, 43.38709485549822, 44.15506765932989, 44.90990981954873, 45.65227267070063, 46.38275541621045, 47.10191078926629, 47.810249947056334, 48.50824672156271, 49.19634132737921, 49.87494360899068, 50.5444358955563, 51.20517551966794, 51.85749704719656, 52.50171425772686, 53.13812190885184, 53.766997312477834, 54.388601747057265, 55.00318172615107, 55.610970140791466, 56.21218729065789, 56.8070418170142, 57.395731548609085, 57.97844427026307, 58.55535842260724, 59.12664374036463, 59.69246183564555, 60.252966731937775, 60.80830535379193, 61.35861797661352, 61.90403864046352, 62.44469553132596, 62.98071133291524, 63.512203551758454, 64.03928481799277, 64.56206316405942, 65.08064228324733, 65.59512176983895, 66.10559734243387, 66.61216105186799, 67.11490147500776, 67.61390389557461, 68.10925047304514, 68.60102040057421, 69.08929005280051, 69.57413312431568, 70.05562075950795, 70.53382167442793, 71.00880227126775, 71.4806267459932, 71.94935718962331, 72.41505368360919, 72.87777438972735, 73.33757563486812, 73.79451199106882, 74.24863635111423, 74.7, 75.14865268253317, 75.59464266732134, 76.03801680738393, 76.47882059760074, 76.91709822919739, 77.352892641452, 77.78624557079483, 78.21719759745935, 78.64578818983252, 79.07205574664162, 79.4960376371049, 79.9177702391652, 80.33728897591703, 80.75462835033049, 81.16982197836829, 81.5829026205859, 81.99390221229869, 82.40285189239509], [0.0, 8.248636250920512, 11.665333257134149, 14.287057079748791, 16.497272501841024, 18.44451137872728, 20.204949888579286, 21.823840175367856, 23.330666514268298, 24.745908752761533, 26.08447814314099, 27.3576314764272, 28.574114159497583, 29.740880955344952, 30.863570759068047, 31.946830828737927, 32.99454500368205, 34.00999852984413, 34.995999771402445, 35.954971839788726, 36.88902275745456, 37.800000000000004, 38.689533468368424, 39.55906975650464, 40.40989977715857, 41.24318125460256, 42.05995720397252, 42.861171239246374, 43.64768035073571, 44.42026564531104, 45.17964143284008, 45.92646295982307, 46.661333028536596, 47.384807691917466, 48.097401177194605, 48.799590162213455, 49.491817505523066, 50.17449551315888, 50.848008810571926, 51.51271687651508, 52.16895628628198, 52.81704270403636, 53.457272657702994, 54.08992512474018, 54.7152629528544, 55.333534136181825, 55.944972964512196, 56.549801060658034, 57.148228318995166, 57.74045375644359, 58.32666628567075, 58.90704541903287, 59.481761910689904, 60.05097834340421, 60.61484966573786, 61.17352368467915, 61.727141518136094, 62.275838011222305, 62.81974211981454, 63.35897726447294, 63.89366165747585, 64.4239086054238, 64.94982678960739, 65.47152052610356, 65.9890900073641, 66.5026315268802, 67.01223768835062, 67.51799760063979, 68.01999705968827, 68.51831871842741, 69.01304224565094, 69.50424447470817, 69.99199954280489, 70.47637902162683, 70.9574520399373, 71.43528539874396, 71.90994367957745, 72.38148934637917, 72.84998284145304, 73.31548267589868, 73.77804551490912, 74.23772625828461, 74.69457811648715, 75.14865268253317, 75.60000000000001, 76.0486686273994, 76.4947056991528, 76.93815698338504, 77.37906693673685, 77.81747875638224, 78.25343442942297, 78.68697477981982, 79.11813951300928, 79.54696725834368, 79.97349560948302, 80.39776116285826, 80.81979955431714, 81.23964549405667, 81.65733279993904, 82.07289442928159, 82.48636250920512, 82.89776836562008], [0.0, 8.2975900115636, 11.734564329364767, 14.371847480404183, 16.5951800231272, 18.553975315279477, 20.32486162314519, 21.953359651770842, 23.469128658729534, 24.892770034690795, 26.239283526803852, 27.519992732557185, 28.743694960808366, 29.917386249470393, 31.046738959188612, 32.13642792844283, 33.1903600462544, 34.211840055746784, 35.2036929880943, 36.16835633533822, 37.10795063055895, 38.0243343136997, 38.91914695879138, 39.793843744981466, 40.64972324629038, 41.487950057818, 42.309573384755375, 43.11554244121255, 43.906719303541685, 44.68388971430308, 45.44777222262935, 46.19902596375815, 46.93825731745907, 47.666025636715304, 48.38284820057621, 49.089204515860715, 49.78554006938159, 50.47226961411583, 51.14978005817816, 51.81843301374523, 52.478567053607705, 53.130499715323595, 53.77452928664277, 54.410936400690616, 55.03998546511437, 55.66192594583841, 56.27699352310854, 56.88541113501774, 57.48738992161673, 58.083130080945196, 58.67282164682384, 59.25664519697349, 59.83477249894079, 60.40736710037941, 60.97458486943557, 61.53657449029805, 62.093477918377225, 62.64543079906148, 63.19256285355106, 63.734998234878766, 64.27285585688566, 64.80624969862089, 65.33528908637354, 65.86007895531253, 66.3807200925088, 66.89730936293327, 67.40993991986642, 67.91870140101325, 68.42368011149357, 68.92495919476485, 69.42261879243681, 69.91673619384704, 70.4073859761886, 70.89464013590873, 71.37856821203407, 71.85923740202091, 72.33671267067643, 72.81105685265116, 73.28233074896023, 73.75059321795317, 74.2159012611179, 74.6783101040724, 75.1378732730705, 75.59464266732134, 76.0486686273994, 76.5, 76.9486841992766, 77.39476726497729, 77.83829391758276, 78.27930761063233, 78.71785058041156, 79.15396389316204, 79.58768748996293, 80.01906022942285, 80.44811992831157, 80.87490340025143, 81.29944649258076, 81.72178412149358, 82.14195030555338, 82.55997819767155, 82.975900115636, 83.38974757126923], [0.0, 8.346256645946134, 11.803389343743602, 14.45614056378811, 16.69251329189227, 18.662797217994953, 20.444070044880988, 22.082119463493537, 23.606778687487203, 25.0387699378384, 26.393180937507324, 27.681401698613463, 28.91228112757622, 30.09285629514088, 31.228832831215453, 32.32491299292235, 33.38502658378454, 34.41249772974929, 35.4101680312308, 36.38048927653393, 37.325594435989906, 38.2473528495764, 39.14741370767678, 40.027240724286756, 40.888140089761976, 41.73128322973067, 42.55772550313281, 43.36842169136433, 44.164238926987075, 44.945967561061586, 45.71433035712106, 46.46999031633211, 47.21355737497441, 47.94559416672194, 48.666621004544794, 49.37712020764273, 50.0775398756768, 50.76829719421364, 51.44978134064323, 52.12235604805294, 52.78636187501465, 53.442118221492684, 54.08992512474019, 54.73006486383877, 55.36280339722693, 55.98839165398484, 56.607066696659, 57.219052770908405, 57.82456225515244, 58.42379652162294, 59.01694671871801, 59.60419448327442, 60.18571259028176, 60.7616655466257, 61.33221013464296, 61.897495910577845, 62.457665662430905, 63.01285583117147, 63.56319689883448, 64.10881374662925, 64.6498259858447, 65.18634826403455, 65.71849054870326, 66.24635839048061, 66.77005316756907, 67.28967231306748, 67.80530952661451, 68.31705497165403, 68.82499545949858, 69.32921462125472, 69.82979306857497, 70.32680854411069, 70.8203360624616, 71.3104480423451, 71.79721443064487, 72.28070281894055, 72.76097855306786, 73.23810483621214, 73.71214282599578, 74.18315172598156, 74.65118887197981, 75.1163098135152, 75.57856839078127, 76.03801680738393, 76.4947056991528, 76.9486841992766, 77.4, 77.84869941110128, 78.29482741535357, 78.73842772115786, 79.17954281252197, 79.6182139965473, 80.05448144857351, 80.48838425512095, 80.91996045476048, 81.349247077032, 81.77628017952395, 82.20109488321917, 82.62372540620521, 83.04420509584038, 83.46256645946134, 83.87884119371226], [0.0, 8.394641147779934, 11.871815362445627, 14.539944979263161, 16.789282295559868, 18.770988253152794, 20.562587385832554, 22.21013282265552, 23.743630724891254, 25.183923443339797, 26.546186166754726, 27.84187493686444, 29.079889958526323, 30.267309097440428, 31.409871059907267, 32.5123053627392, 33.578564591119736, 34.61199214145294, 35.615446087336885, 36.59139243046102, 37.54197650630559, 38.46907849169252, 39.37435713760925, 40.259284643421076, 41.12517477166511, 41.97320573889967, 42.804439022138816, 43.61983493778949, 44.42026564531104, 45.2065260775477, 45.97934318800128, 46.73938382135563, 47.48726144978251, 48.223541968627735, 48.94874870719374, 49.66336678075702, 50.367846886679594, 51.06260862901542, 51.748043441274184, 52.42451716515853, 53.09237233350945, 53.751930197900805, 54.40349253494669, 55.047343260142895, 55.68374987372888, 56.31296475945836, 56.93522635416496, 57.550760203493404, 58.159779917052646, 58.762488034459544, 59.35907681222814, 59.949728940171205, 60.534618194880856, 61.113910036913865, 61.687762157497666, 62.256324979876545, 62.819742119814535, 63.37815080924972, 63.93168228664096, 64.48046215715269, 65.0246107254784, 65.5642433038009, 66.09947049712274, 66.63039846796656, 67.15712918223947, 67.6797606378746, 68.19838707770148, 68.71309918785501, 69.22398428290587, 69.73112647878277, 70.23460685445602, 70.73450360326282, 71.23089217467377, 71.72384540722842, 72.21343365330304, 72.69972489631581, 73.18278486092204, 73.66267711670545, 74.13946317582831, 74.61320258506534, 75.08395301261118, 75.55177033001941, 76.01670868960325, 76.47882059760074, 76.93815698338504, 77.39476726497729, 77.84869941110128, 78.3, 78.7487142752185, 79.1948861985419, 79.63855850026418, 80.07977272695022, 80.51856928684215, 80.95498749305074, 81.38906560466216, 81.82084086588208, 82.25034954333022, 82.67762696159102, 83.1027075371194, 83.52562481059331, 83.94641147779934, 84.36509941913185], [0.0, 8.442748367682174, 11.93984924527944, 14.623269128344731, 16.88549673536435, 18.87855926706273, 20.680425527536904, 22.337412562783545, 23.87969849055888, 25.328245103046516, 26.69831455354439, 28.001428534987287, 29.246538256689462, 30.440762145517976, 31.58987179461164, 32.69862382425291, 33.7709934707287, 34.81034329046469, 35.81954773583832, 36.801086940469574, 37.75711853412546, 38.689533468368424, 39.6, 40.489998765127176, 41.36085105507381, 42.21374183841087, 43.04973867516504, 43.86980738503419, 44.67482512556709, 45.465591385134324, 46.24283728319446, 47.00723348592214, 47.75939698111776, 48.49989690710693, 49.22925959223844, 49.94797293184179, 50.65649020609303, 51.35523342367358, 52.04459626128346, 52.72494665715652, 53.39662910708878, 54.05996670365235, 54.715262952854395, 55.362803397226905, 56.002857069974574, 56.63567780118818, 57.26150539411272, 57.8805666869287, 58.493076513378924, 59.09923857377522, 59.6992462263972, 60.293283207999224, 60.88152429103595, 61.46413588426995, 62.04127658261071, 62.61309767133392, 63.17974358922328, 63.74135235465279, 64.29805595817032, 64.84998072474654, 65.39724764850583, 65.93997270245113, 66.4782671254298, 67.01223768835062, 67.5419869414574, 68.06761344428054, 68.58921197972754, 69.10687375362888, 69.62068658092937, 70.13073505960136, 70.6371007332549, 71.13986224333021, 71.63909547167664, 72.13487367424997, 72.62726760659525, 73.11634564172365, 73.60217388093915, 74.08481625812405, 74.56433463794875, 75.04078890843299, 75.51423706825092, 75.98473530913957, 76.4523380937431, 76.91709822919739, 77.37906693673685, 77.83829391758276, 78.29482741535357, 78.74871427521849, 79.2, 79.64872880341531, 80.09494366063316, 80.53868635630954, 80.97999753025435, 81.41891672087023, 81.85548240649493, 82.2897320447697, 82.72170211014762, 83.15142812964791, 83.57894471695609, 84.00428560496185, 84.42748367682174, 84.84857099562727], [0.0, 8.490583018850943, 12.0074976577137, 14.706121174531374, 16.981166037701886, 18.985520798756088, 20.797596014924416, 22.463971153827632, 24.0149953154274, 25.471749056552827, 26.849581002317336, 28.16007812489163, 29.412242349062748, 30.613232433050907, 31.768852670501023, 32.88388663160119, 33.96233207540377, 35.0075706097981, 36.0224929731411, 37.00959335091376, 37.971041597512176, 38.908739378191115, 39.824364401707655, 40.71940569310903, 41.59519202984883, 42.45291509425471, 43.293648494900495, 44.11836352359412, 44.927942307655265, 45.72318886516994, 46.504838457949724, 47.27356555200802, 48.0299906308548, 48.77468605742122, 49.508181142110246, 50.23096654455297, 50.943498113105655, 51.64620024745286, 52.339468854775355, 53.02367395795957, 53.69916200463467, 54.36625791794024, 55.02526692347798, 55.67647618159754, 56.32015624978326, 56.956562396268254, 57.585935782967006, 58.20850453327245, 58.824484698125495, 59.4340811319566, 60.037488288568504, 60.6348909457253, 61.226464866101814, 61.81237740129399, 62.392788044773255, 62.9678489389625, 63.537705341002045, 64.10249605124594, 64.66235380806981, 65.21740565217232, 65.76777326320239, 66.31357327123912, 66.8549175453833, 67.3919134614829, 67.92466415080754, 68.4532687313031, 68.97782252289498, 69.49841724816471, 70.0151412195962, 70.52807951447423, 71.03731413841601, 71.54292417842592, 72.0449859462822, 72.5435731129919, 73.03875683498453, 73.53060587265686, 74.01918670182752, 74.50456361861332, 74.98679883819553, 75.46595258790549, 75.94208319502435, 76.41524716965849, 76.88549928302476, 77.352892641452, 77.81747875638223, 78.27930761063233, 78.73842772115785, 79.19488619854188, 79.64872880341531, 80.1, 80.54874300695201, 80.99499984566948, 81.43881138621806, 81.88021739101576, 82.31925655640968, 82.75596655226738, 83.19038405969766, 83.62254480700764, 84.0524836039959, 84.4802343746749, 84.90583018850943, 85.32930329025311], [0.0, 8.538149682454625, 12.074767078498864, 14.788509052639487, 17.07629936490925, 19.091883092036785, 20.914110069520053, 22.58982071642004, 24.149534156997728, 25.61444904736387, 27.0, 28.317838900594097, 29.577018105278974, 30.784736477676724, 31.946830828737927, 33.0681115275729, 34.1525987298185, 35.2036929880943, 36.22430123549659, 37.2169316306436, 38.18376618407357, 39.12671721471149, 40.04747183031658, 40.947527397878375, 41.828220139040106, 42.69074841227312, 43.53619184081217, 44.365527157918464, 45.17964143284008, 45.97934318800128, 46.76537180435968, 47.53840552647932, 48.299068313995456, 49.04793573637937, 49.7855400693816, 50.51237472144821, 51.22889809472774, 51.93553696651263, 52.632689461968404, 53.32072767695506, 54.0, 54.67083317455479, 55.33353413618183, 55.988391653984834, 56.635677801188194, 57.27564927611034, 57.90854859172349, 58.534605149432764, 59.15403621055795, 59.76704777718237, 60.37383539249433, 60.97458486943557, 61.56947295535345, 62.15866793939523, 62.74233020856016, 63.3206127576163, 63.89366165747585, 64.46161648609194, 65.0246107254784, 65.58277212805203, 66.1362230551458, 66.68508079023373, 67.22945782913915, 67.76946214926012, 68.305197459637, 68.8367634335026, 69.36425592479169, 69.88776716994184, 70.4073859761886, 70.92319789744397, 71.43528539874394, 71.94372801016084, 72.44860247099318, 72.949982864974, 73.4479407471714, 73.94254526319743, 74.4338632612872, 74.92195939776269, 75.4068962363523, 75.88873434179806, 76.36753236814714, 76.84334714209162, 77.31623374169232, 77.78624557079485, 78.25343442942298, 78.71785058041155, 79.17954281252197, 79.63855850026418, 80.09494366063316, 80.54874300695201, 81.0, 81.44875689659112, 81.89505479575675, 82.3389336826753, 82.78043247048181, 83.21958904008117, 83.65644027808021, 84.09102211294616, 84.52336954949206, 84.95351670178228, 85.38149682454625, 85.8073423431818], [0.0, 8.58545281275251, 12.141663806908838, 14.870440477672476, 17.17090562550502, 19.19765610693139, 21.02997860198626, 22.71497303542313, 24.283327613817676, 25.75635843825753, 27.14958563219704, 28.47472563520148, 29.740880955344952, 30.95529033945571, 32.12382293563454, 33.2513157634401, 34.34181125101004, 35.39872879073484, 36.42499142072651, 37.42312119532522, 38.39531221386278, 39.34348738990991, 40.26934317815477, 41.17438524131235, 42.05995720397252, 42.92726406376256, 43.77739142525512, 44.61132143301743, 45.42994607084626, 46.23407834054876, 47.02446171940727, 47.801778209602205, 48.56665522763535, 49.31967153175293, 50.06136234662417, 50.79222381428086, 51.51271687651506, 52.22327067505443, 52.92428554076096, 53.61613563098334, 54.29917126439408, 54.97372099467163, 55.64009345786544, 56.29857902292028, 56.94945127040296, 57.59296832079416, 58.229374030638525, 58.85889907227284, 59.481761910689904, 60.09816968926758, 60.70831903454419, 61.31239678890396, 61.91058067891142, 62.503039926070805, 63.08993580595879, 63.67142216096638, 64.24764587126909, 64.81874728811103, 65.38486063302423, 65.94611436620052, 66.5026315268802, 67.05453004831217, 67.60192304957012, 68.1449191062694, 68.68362250202009, 69.21813346226551, 69.74854837199122, 70.27495997864388, 70.79745758146969, 71.3161272083671, 71.83105178124569, 72.3423112707909, 72.84998284145303, 73.35414098740439, 73.85485766014311, 74.35220238836239, 74.84624239065045, 75.3370426815388, 75.82466617137197, 76.30917376043328, 76.79062442772556, 77.2690753147726, 77.74458180477917, 78.21719759745935, 78.68697477981982, 79.15396389316204, 79.6182139965473, 80.07977272695022, 80.53868635630954, 80.99499984566948, 81.44875689659112, 81.9, 82.3487704826247, 82.79510855116986, 83.23905333435742, 83.68064292296037, 84.11991440794505, 84.55690391682988, 84.99164664836186, 85.42417690560443, 85.85452812752511, 86.28273291916524], [0.0, 8.632496741962896, 12.208193969625484, 14.951922953252536, 17.264993483925792, 19.3028495305745, 21.145212224047317, 22.839439572809138, 24.416387939250967, 25.897490225888685, 27.298351598585583, 28.630752697056366, 29.903845906505072, 31.124909638423052, 32.29984520086745, 33.433516117812076, 34.529986967851585, 35.59269587991334, 36.62458190887645, 37.62818092866038, 38.605699061149, 39.55906975650465, 40.48999876512718, 41.400000000000006, 42.29042444809463, 43.16248370981448, 44.017269338294945, 44.85576885975761, 45.678879145618275, 46.487417652521856, 47.28213193162931, 48.063707722147285, 48.832775878501934, 49.58991833024129, 50.335673234794434, 51.07053945279999, 51.79498045177737, 52.50942772493336, 53.21428379674014, 53.909924874738984, 54.596703197171166, 55.27494911802272, 55.944972964512196, 56.60706669665899, 57.26150539411273, 57.90854859172348, 58.54844148224614, 59.18141600198496, 59.807691813010145, 60.42747719374027, 61.04096984812742, 61.64835764235736, 62.249819276846104, 62.845524900345936, 63.43563667214195, 64.02030927760347, 64.5996904017349, 65.17392116483403, 65.74313652389884, 66.3074656430179, 66.86703223562415, 67.42195488118095, 67.97234731859714, 68.51831871842741, 69.05997393570317, 69.59741374505234, 70.13073505960136, 70.66003113500588, 71.18539175982669, 71.70690343335153, 72.22464953185997, 72.7387104642363, 73.2491638177529, 73.75608449477237, 74.25954484105057, 74.75961476626269, 75.25636185732075, 75.74985148500294, 76.24014690437055, 76.72730934940962, 77.211398122298, 77.69247067766607, 78.17058270219049, 78.64578818983253, 79.1181395130093, 79.58768748996293, 80.05448144857351, 80.51856928684215, 80.97999753025437, 81.43881138621806, 81.89505479575675, 82.3487704826247, 82.80000000000001, 83.24878377489969, 83.69516115045123, 84.13917042614575, 84.58084889618927, 85.02023288606073, 85.45735778737838, 85.8922580911691, 86.32496741962896, 86.75551855645843], [0.0, 8.67928568489366, 12.27436352728727, 15.032963779641062, 17.35857136978732, 19.407472787563044, 21.25982125983189, 22.963231479911535, 24.54872705457454, 26.037857054680977, 27.446311227558432, 28.785934065095063, 30.065927559282123, 31.29360957128468, 32.47491339480369, 33.614728914569575, 34.71714273957464, 35.785611633727875, 36.82309058186181, 37.83212920257067, 38.81494557512609, 39.77348362917184, 40.709458360435114, 41.624391887449846, 42.51964251966378, 43.396428424468304, 44.255847071319295, 45.09889133892319, 45.92646295982307, 46.73938382135563, 47.53840552647932, 48.32421753117168, 49.09745410914908, 49.85870034407235, 50.608497310234384, 51.347346572145284, 52.075714109361954, 52.79403375382488, 53.50271021172666, 54.202121729688784, 54.892622455116864, 55.57454453254656, 56.248199971199085, 56.913882313544555, 57.571868130190126, 58.222418362689126, 58.8657795327642, 59.50218483383615, 60.131855118564246, 60.754999794255625, 61.37181763643636, 61.98249752954459, 62.58721914256936, 63.18615354648518, 63.77946377949568, 64.36730536537941, 64.94982678960739, 65.52716993736263, 66.09947049712275, 66.6668583330578, 67.22945782913915, 67.78738820754197, 68.34076382365068, 68.8896944397346, 69.43428547914928, 69.9746382627306, 70.51085022888321, 71.0430151387172, 71.57122326745575, 72.09556158322093, 72.61611391419952, 73.13296110509954, 73.64618116372363, 74.15584939841227, 74.6620385470421, 75.1648188982053, 75.66425840514134, 76.16042279294412, 76.65337565952332, 77.14317857075893, 77.62989115025218, 78.11357116404294, 78.59427460063489, 79.07205574664162, 79.54696725834368, 80.01906022942285, 80.48838425512095, 80.95498749305074, 81.41891672087023, 81.88021739101576, 82.3389336826753, 82.79510855116986, 83.24878377489969, 83.7, 84.14879678284177, 84.59521263050291, 85.03928503932757, 85.48105053168219, 85.9205446910109, 86.35780219528517, 86.79285684893661, 87.22574161335633], [0.0, 8.725823743349393, 12.34017828072188, 15.113570061372, 17.451647486698786, 19.511535049810924, 21.373815756668254, 23.08635960908519, 24.68035656144376, 26.177471230048177, 27.593477490160605, 28.940283343464355, 30.227140122744, 31.461404927307363, 32.6490428649907, 33.79497003993346, 34.90329497339757, 35.97749296435203, 37.02053484216564, 38.034983896407795, 39.02307009962185, 39.98674780474152, 40.92774120324747, 41.847580575225614, 42.74763151333651, 43.629118716746966, 44.4931455395098, 45.340710184116006, 46.17271921817038, 46.98999893594381, 47.79330497046631, 48.58333047455681, 49.36071312288752, 50.12604113631956, 50.87985849036926, 51.62266943891996, 52.35494246009635, 53.07711371203224, 53.78959007094217, 54.49275181159418, 55.18695498032121, 55.87253350260753, 56.549801060658034, 57.21905277090839, 57.88056668692871, 58.53460514943276, 59.18141600198495, 59.82123368838192, 60.454280245488, 61.080766203445755, 61.700891403609404, 62.31484574320955, 62.92280985461473, 63.52495572607667, 64.12144727000477, 64.71244084409119, 65.2980857299814, 65.87852457364237, 66.45389379110905, 67.02432394287912, 67.58994007986692, 68.15086206351319, 68.70720486237234, 69.25907882725556, 69.80658994679514, 70.3498400851061, 70.88892720305478, 71.42394556449538, 71.95498592870406, 72.48213573012319, 73.00547924642369, 73.52509775580037, 74.04106968433128, 74.55347074415786, 75.06237406317496, 75.56785030686, 76.06996779281559, 76.56879259855154, 77.06438866298754, 77.55681788211788, 78.0461401992437, 78.53241369014454, 79.0156946435327, 79.4960376371049, 79.97349560948304, 80.44811992831157, 80.91996045476048, 81.38906560466216, 81.85548240649494, 82.3192565564097, 82.78043247048183, 83.23905333435744, 83.69516115045123, 84.14879678284177, 84.60000000000001, 85.04880951547764, 85.49526302667302, 85.93939725178437, 86.38124796505316, 86.82085003039306, 87.25823743349393, 87.6934433124849], [0.0, 8.772114910328067, 12.405643876881198, 15.19374871452072, 17.544229820656135, 19.615045245933032, 21.48720549536398, 23.208834524809728, 24.811287753762397, 26.3163447309842, 27.73986301336039, 29.093813775440307, 30.38749742904144, 31.62831010345004, 32.82224855185884, 33.97425495871837, 35.08845964131227, 36.16835633533821, 37.21693163064359, 38.2367624152464, 39.230090491866065, 40.19888058142913, 41.14486602238486, 42.06958521307288, 42.97441099072796, 43.86057455164033, 44.729185103241036, 45.58124614356216, 46.417669049619455, 47.23928449923855, 48.04685213414089, 48.841068784374485, 49.62257550752479, 50.39196364500991, 51.14978005817816, 51.896531676018576, 52.6326894619684, 53.358691888013894, 54.07494798887928, 54.78184005671953, 55.47972602672078, 56.16894159586773, 56.84980211047352, 57.52260425258925, 58.18762755088061, 58.84513573779908, 59.49537797173827, 60.1385899402372, 60.77499485808288, 61.404804372296475, 62.02821938440599, 62.64543079906148, 63.25662020690008, 63.86196050858445, 64.46161648609194, 65.05574532660432, 65.64449710371768, 66.22801522014683, 66.8064368156243, 67.37989314328124, 67.94850991743674, 68.51240763540571, 69.07170187565961, 69.62650357442918, 70.17691928262454, 70.7230514047577, 71.26499842138495, 71.80285509643748, 72.33671267067642, 72.86665904239057, 73.3927789363504, 73.9151540619378, 74.43386326128719, 74.94898264819876, 75.4605857385165, 75.96874357260359, 76.4735248304928, 76.97499594024022, 77.47322117996644, 77.96826277402876, 78.46018098373213, 78.94903419295261, 79.43487898901842, 79.9177702391652, 80.39776116285826, 80.87490340025143, 81.349247077032, 81.82084086588208, 82.28973204476972, 82.7559665522674, 83.21958904008117, 83.68064292296039, 84.13917042614575, 84.59521263050291, 85.04880951547763, 85.49999999999999, 85.94882198145592, 86.39531237283653, 86.83950713816839, 87.28144132632092, 87.72114910328067, 88.15866378297711], [0.0, 8.818163074019441, 12.470765814495916, 15.273506473629428, 17.636326148038883, 19.718012070185985, 21.6, 23.330666514268298, 24.941531628991832, 26.45448922205832, 27.885480092693403, 29.246538256689462, 30.547012947258857, 31.79433911878025, 32.99454500368205, 34.15259872981849, 35.272652296077766, 36.35821777810348, 37.41229744348775, 38.43748170731272, 39.43602414037197, 40.40989977715857, 41.36085105507381, 42.29042444809463, 43.2, 44.09081537009721, 44.96398558846847, 45.82051942088829, 46.661333028536596, 47.48726144978251, 48.299068313995456, 49.09745410914908, 49.883063257983665, 50.656490206093046, 51.418284685508524, 52.16895628628198, 52.90897844411664, 53.63879193270483, 54.3588079339494, 55.069410746802085, 55.770960185386805, 56.46379370888924, 57.14822831899516, 57.82456225515243, 58.493076513378924, 59.15403621055793, 59.80769181301014, 60.454280245488, 61.09402589451771, 61.727141518136094, 62.353829072479584, 62.974280464329254, 63.5886782375605, 64.19719620045724, 64.80000000000001, 65.39724764850583, 65.9890900073641, 66.57567123206495, 67.15712918223947, 67.7335958000164, 68.30519745963699, 68.87205529095236, 69.43428547914928, 69.99199954280489, 70.54530459215553, 71.0943035692734, 71.63909547167664, 72.17977556074831, 72.71643555620696, 73.2491638177529, 73.77804551490911, 74.30316278598106, 74.8245948869755, 75.34241833124287, 75.85670702053972, 76.36753236814714, 76.87496341462544, 77.37906693673685, 77.87990755002218, 78.37754780547807, 78.87204828074394, 79.36346766617497, 79.85186284614781, 80.33728897591703, 80.81979955431714, 81.29944649258076, 81.77628017952394, 82.25034954333022, 82.72170211014762, 83.19038405969768, 83.65644027808021, 84.11991440794505, 84.58084889618927, 85.03928503932757, 85.49526302667302, 85.94882198145591, 86.4, 86.84883418906671, 87.29536070147142, 87.73961477006839, 88.18163074019442, 88.62144210065644], [0.0, 8.863972021616496, 12.535549449465709, 15.352849898308785, 17.72794404323299, 19.82044399099072, 21.712208547266677, 23.45186559743169, 25.071098898931417, 26.59191606484948, 28.03034070431539, 29.39846934790994, 30.70569979661757, 31.95950562821647, 33.165946390838904, 34.330016020969175, 35.45588808646598, 36.54709290764452, 37.60664834839712, 38.63715828059823, 39.64088798198144, 40.61982274702834, 41.575714064823956, 42.51011644303036, 43.424417094533354, 44.31986010808247, 45.197566306163, 46.058549694926356, 46.90373119486338, 47.73395018223403, 48.54997425334024, 49.35250753507871, 50.142197797862835, 50.9196425753363, 51.68539445530044, 52.439965675045976, 53.18383212969896, 53.91743688270058, 54.641193251977946, 55.355487532854426, 56.06068140863078, 56.75711409153923, 57.445104230038616, 58.12495161288308, 58.79693869581988, 59.46133197297215, 60.11838321179305, 60.76833056782127, 61.41139959323514, 62.04780415131547, 62.67774724732855, 63.301421784980484, 63.91901125643294, 64.53069037287608, 65.13662564180004, 65.73697589637054, 66.33189278167781, 66.9215212020767, 67.50599973335704, 68.08546100306584, 68.66003204193835, 69.22983460907588, 69.79498549322867, 70.35559679229507, 70.91177617293197, 71.46362711197915, 72.01124912123106, 72.55473795693841, 73.09418581528904, 73.62968151499774, 74.1613106680296, 74.68915583938542, 75.21329669679425, 75.73381015108114, 76.25077048791049, 76.76424949154392, 77.27431656119646, 77.7810388205249, 78.2844812207375, 78.7847066377733, 79.28177596396289, 79.77574819454846, 80.26668050941188, 80.75462835033049, 81.23964549405667, 81.72178412149358, 82.20109488321917, 82.67762696159102, 83.15142812964791, 83.62254480700764, 84.09102211294616, 84.55690391682988, 85.02023288606073, 85.48105053168217, 85.93939725178436, 86.39531237283653, 86.84883418906671, 87.30000000000001, 87.74884614625996, 88.19540804372981, 88.63972021616495, 89.08181632634127], [0.0, 8.909545442950499, 12.6, 15.431785379534023, 17.819090885900998, 19.92234925906079, 21.823840175367856, 23.572441536675832, 25.2, 26.728636328851493, 28.17445651649735, 29.54961928688761, 30.863570759068047, 32.12382293563454, 33.33646651941384, 34.50652112282546, 35.638181771801996, 36.73499693752539, 37.8, 38.83580821870455, 39.84469851812158, 40.82866639996952, 41.789472358478044, 42.72867889368919, 43.64768035073571, 44.54772721475249, 45.42994607084627, 46.295356138602074, 47.144883073351664, 47.97937056694262, 48.79959016221345, 49.60624960627441, 50.4, 51.18144194920655, 51.95113088278253, 52.70958167164676, 53.45727265770299, 54.19464918236855, 54.92212668861249, 55.64009345786544, 56.3489130329947, 57.048926370265725, 57.740453756443586, 58.423796521622926, 59.09923857377522, 59.76704777718236, 60.427477193740266, 61.08076620344575, 61.727141518136094, 62.3668181006535, 63.0, 63.6268811116811, 64.24764587126909, 64.86246988821811, 65.47152052610356, 66.07495743471955, 66.67293303882768, 67.26559298779726, 67.85307656989475, 68.43551709456135, 69.01304224565092, 69.58577440827973, 70.15383097165828, 70.71732461002749, 71.27636354360399, 71.83105178124569, 72.38148934637915, 72.92777248757841, 73.46999387505078, 74.0082427841656, 74.54260526705517, 75.07316431322181, 75.6, 76.12318963364581, 76.64280788175756, 77.15892689767011, 77.6716164374091, 78.1809439697424, 78.68697477981983, 79.18977206685217, 79.68939703624316, 80.1859089865545, 80.6793653916539, 81.16982197836829, 81.65733279993904, 82.14195030555338, 82.62372540620521, 83.10270753711939, 83.57894471695609, 84.0524836039959, 84.52336954949205, 84.99164664836186, 85.45735778737838, 85.92054469101089, 86.38124796505316, 86.83950713816839, 87.29536070147142, 87.74884614625996, 88.2, 88.64885786066283, 89.09545442950498, 89.53982354237695], [0.0, 8.95488693395958, 12.66412255152326, 15.51031914565268, 17.90977386791916, 20.023735915158294, 21.934903692517096, 23.692403845958733, 25.32824510304652, 26.86466080187874, 28.317838900594094, 29.700000000000006, 31.02063829130536, 32.28730400637378, 33.50611884417532, 34.682127962395846, 35.81954773583832, 36.921944694178826, 37.99236765456978, 39.033447195962594, 40.04747183031659, 41.036447214640795, 42.00214280248093, 42.94612904558454, 43.86980738503419, 44.774434669797905, 45.66114321827697, 46.53095743695804, 47.384807691917466, 48.223541968627735, 49.047935736379365, 49.85870034407235, 50.65649020609304, 51.44190898479567, 52.215514935697044, 52.97782554994118, 53.72932160375748, 54.470450704946444, 55.20163041070436, 55.92325097846155, 56.63567780118819, 57.33925357030732, 58.034300202552636, 58.72112056151517, 59.40000000000001, 60.071207745474865, 60.73499814769077, 61.3916118048712, 62.04127658261072, 62.68420853771707, 63.32061275761631, 63.950684124565875, 64.57460801274756, 65.19256092530804, 65.80471107755129, 66.41121893174376, 67.01223768835064, 67.60791373796414, 68.1983870777015, 68.78379169542778, 69.36425592479169, 69.93990277373854, 70.51085022888321, 71.0772115378762, 71.63909547167664, 72.19660656845306, 72.74984536066039, 73.29890858669043, 73.84388938835765, 74.38487749536192, 74.92195939776269, 75.45521850740346, 75.98473530913957, 76.51058750264568, 77.03285013551037, 77.5515957282634, 78.06689439192519, 78.57881393861835, 79.0874199857348, 79.59277605411185, 80.09494366063318, 80.59398240563623, 81.08995005547852, 81.5829026205859, 82.07289442928159, 82.55997819767154, 83.04420509584038, 83.52562481059331, 84.00428560496186, 84.4802343746749, 84.95351670178228, 85.42417690560443, 85.89225809116908, 86.35780219528517, 86.82085003039305, 87.28144132632092, 87.73961477006839, 88.19540804372981, 88.64885786066283, 89.10000000000001, 89.54886933959581, 89.99549988749439], [0.0, 9.000000000000002, 12.727922061357855, 15.588457268119898, 18.000000000000004, 20.124611797498112, 22.045407685048605, 23.811761799581316, 25.45584412271571, 27.0, 28.460498941515414, 29.849623113198604, 31.176914536239796, 32.449961479175904, 33.67491648096547, 34.856850115866756, 36.00000000000001, 37.107950630558946, 38.18376618407357, 39.230090491866065, 40.249223594996224, 41.24318125460257, 42.213741838410876, 43.16248370981448, 44.09081537009721, 45.0, 45.89117562233507, 46.765371804359695, 47.62352359916263, 48.46648326421054, 49.29503017546495, 50.1098792654702, 50.91168824543142, 51.701063818842265, 52.47856705360771, 53.24471804789655, 54.0, 54.74486277268398, 55.47972602672079, 56.2049819855856, 56.92099788303083, 57.628118136895644, 58.32666628567075, 59.016946718718, 59.69924622639721, 60.37383539249432, 61.04096984812742, 61.700891403609404, 62.35382907247959, 63.00000000000001, 63.63961030678929, 64.27285585688566, 64.89992295835181, 65.52098900352468, 66.13622305514582, 66.74578638386097, 67.34983296193094, 67.94850991743675, 68.54195795277519, 69.13031173081747, 69.71370023173351, 70.2922470831599, 70.8660708661063, 71.43528539874394, 72.00000000000001, 72.56031973468694, 73.11634564172364, 73.66817494685205, 74.21590126111789, 74.75961476626267, 75.29940238806681, 75.83534795858723, 76.36753236814714, 76.8960337078578, 77.42092740338364, 77.94228634059948, 78.46018098373213, 78.9746794865291, 79.48584779695064, 79.9937497558403, 80.49844718999245, 81.00000000000001, 81.49846624323676, 81.99390221229869, 82.48636250920514, 82.975900115636, 83.46256645946134, 83.94641147779934, 84.42748367682175, 84.90583018850944, 85.38149682454625, 85.85452812752511, 86.32496741962896, 86.79285684893661, 87.25823743349393, 87.72114910328067, 88.18163074019442, 88.63972021616496, 89.095454429505, 89.54886933959581, 90.0, 90.44888059008802], [0.0, 9.044888059008803, 12.791403363196707, 15.666205666976293, 18.089776118017607, 20.224984548819812, 22.15536052516411, 23.930524440555, 25.582806726393414, 27.134664177026405, 28.60244744772727, 29.998499962498133, 31.332411333952585, 32.611807677588196, 33.8428722185337, 35.030700820851415, 36.179552236035214, 37.29302883918119, 38.37421008959012, 39.42575300485712, 40.449969097639624, 41.44888418281004, 42.42428549781364, 43.37775927822921, 44.31072105032822, 45.22444029504401, 46.120060711148255, 46.99861700092888, 47.86104888111, 48.70821285984532, 49.540892200282386, 50.359805400736015, 51.16561345278683, 51.95892608589982, 52.74030716634101, 53.5102793863011, 54.26932835405281, 55.01790617608054, 55.756434606240745, 56.48530782424755, 57.20489489545454, 57.91554195550622, 58.61757415656162, 59.31129740614346, 59.99699992499627, 60.67495364645943, 61.34541547662711, 62.00862843185617, 62.66482266790517, 63.31421641306162, 63.95701681598354, 64.59342071759323, 65.22361535517639, 65.84777900582526, 66.46608157549234, 67.07868513917072, 67.6857444370674, 68.28740733107387, 68.88381522534885, 69.475103454403, 70.06140164170283, 70.64283403148546, 71.21951979619071, 71.791573321665, 72.35910447207043, 72.92221883623674, 73.48101795702071, 74.03559954508371, 74.58605767836238, 75.13248298838526, 75.67496283448048, 76.21358146682257, 76.74842017918024, 77.27955745214902, 77.80706908758356, 78.33102833488145, 78.85150600971424, 79.36857060575049, 79.88228839986999, 80.39272355132647, 80.89993819527925, 81.40399253107923, 81.90494490566489, 82.40285189239509, 82.89776836562008, 83.38974757126923, 83.87884119371226, 84.36509941913185, 84.84857099562728, 85.32930329025312, 85.8073423431818, 86.28273291916524, 86.75551855645843, 87.22574161335633, 87.6934433124849, 88.15866378297711, 88.62144210065644, 89.08181632634128, 89.53982354237695, 89.99549988749439, 90.44888059008802, 90.90000000000002]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"A = 9.5\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.9500000000000001, 1.3435028842544403, 1.6454482671904338, 1.9000000000000001, 2.1242645786248002, 2.3270152556440196, 2.513463745511361, 2.6870057685088806, 2.85, 3.0041637771599605, 3.15079355083763, 3.2908965343808676, 3.4252737116907905, 3.554574517435244, 3.679334178897046, 3.8000000000000003, 3.9169503443367777, 4.030508652763321, 4.14095399636364, 4.2485291572496005, 4.353446910208048, 4.455894971832258, 4.556039947147084, 4.654030511288039, 4.750000000000001, 4.844068537913146, 4.936344801571301, 5.026927491022722, 5.115906566777779, 5.203364296299078, 5.289376144688521, 5.374011537017761, 5.457334514211127, 5.539404300103036, 5.620275793944635, 5.7, 5.778624403783309, 5.856193302820528, 5.932748098478479, 6.008327554319921, 6.082968025561207, 6.156703663487468, 6.229566598086901, 6.30158710167526, 6.3727937358744, 6.443213483969005, 6.512871870380993, 6.581793068761735, 6.6499999999999995, 6.717514421272202, 6.784357007115708, 6.850547423381581, 6.916104394816493, 6.981045766932058, 7.04538856274088, 7.109149034870488, 7.172342713507213, 7.234984450570714, 7.297088460475178, 7.358668357794092, 7.419737192111321, 7.48030748031122, 7.5403912365340835, 7.6000000000000005, 7.659144860883622, 7.717836484404162, 7.776085133278827, 7.833900688673555, 7.891292669772172, 7.948270252073718, 8.004842284517542, 8.061017305526642, 8.116803558051654, 8.172209003690496, 8.227241335952167, 8.28190799272728, 8.336216168022517, 8.390172823011456, 8.44378469644981, 8.497058314499201, 8.55, 8.602615881230548, 8.654911900187084, 8.706893820416097, 8.758567234428243, 8.809937570720919, 8.861010100434376, 8.911789943664516, 8.962282075453773, 9.01249133147988, 9.062422413460984, 9.112079894294167, 9.161468222943308, 9.210591729091027, 9.259454627568516, 9.308061022576078, 9.3564149117063, 9.404520189781083, 9.45238065251289, 9.500000000000002, 9.547381840064848], [0.0, 1.3435028842544403, 1.9, 2.3270152556440196, 2.6870057685088806, 3.0041637771599605, 3.290896534380867, 3.554574517435244, 3.8, 4.030508652763321, 4.2485291572496005, 4.455894971832258, 4.654030511288039, 4.844068537913146, 5.026927491022722, 5.203364296299077, 5.374011537017761, 5.539404300103035, 5.7, 5.856193302820528, 6.008327554319921, 6.156703663487467, 6.30158710167526, 6.4432134839690045, 6.581793068761734, 6.717514421272202, 6.85054742338158, 6.981045766932057, 7.109149034870488, 7.234984450570713, 7.358668357794092, 7.48030748031122, 7.6, 7.717836484404162, 7.833900688673555, 7.9482702520737165, 8.061017305526642, 8.172209003690496, 8.28190799272728, 8.390172823011454, 8.497058314499201, 8.602615881230546, 8.706893820416097, 8.809937570720919, 8.911789943664516, 9.01249133147988, 9.112079894294167, 9.210591729091025, 9.308061022576078, 9.404520189781081, 9.500000000000002, 9.594529691443975, 9.688137075826292, 9.78084863393765, 9.8726896031426, 9.963684057616438, 10.053854982045443, 10.143224339429747, 10.231813133555558, 10.319641466640205, 10.406728592598155, 10.493092966327897, 10.578752289377041, 10.663723552305733, 10.748023074035522, 10.83166653844181, 10.914669028422255, 10.997045057650714, 11.07880860020607, 11.159973118247194, 11.240551587889271, 11.320556523422336, 11.4, 11.478893674914843, 11.557248807566616, 11.635076278220096, 11.712386605641056, 11.789189963691314, 11.865496196956958, 11.941314835477709, 12.016655108639842, 12.091525958289962, 12.165936051122415, 12.239893790388868, 12.313407326974934, 12.386484569885033, 12.4591331961738, 12.531360660359274, 12.60317420335052, 12.674580860920017, 12.7455874717488, 12.816200685070438, 12.886426967938009, 12.956272612136564, 13.025743740761985, 13.09484631448571, 13.163586137523469, 13.231968863324914, 13.3, 13.367684915496774, 13.435028842544405, 13.502036883374302], [0.0, 1.6454482671904338, 2.3270152556440196, 2.850000000000001, 3.2908965343808676, 3.6793341788970464, 4.030508652763322, 4.353446910208048, 4.654030511288039, 4.936344801571301, 5.203364296299079, 5.457334514211128, 5.700000000000002, 5.93274809847848, 6.156703663487468, 6.372793735874401, 6.581793068761735, 6.784357007115709, 6.981045766932059, 7.172342713507214, 7.358668357794093, 7.540391236534084, 7.717836484404163, 7.891292669772173, 8.061017305526644, 8.227241335952169, 8.390172823011456, 8.55, 8.706893820416097, 8.861010100434376, 9.012491331479882, 9.161468222943308, 9.308061022576078, 9.452380652512892, 9.594529691443975, 9.73460322766162, 9.872689603142602, 10.008871065210103, 10.143224339429747, 10.275821135072372, 10.406728592598158, 10.536009681088947, 10.663723552305735, 10.78992585702052, 10.914669028422257, 11.03800253669114, 11.159973118247196, 11.280624982686023, 11.400000000000004, 11.518137870333035, 11.6350762782201, 11.750851033010335, 11.86549619695696, 11.979044202272568, 12.091525958289964, 12.202970949731874, 12.313407326974936, 12.422861989090922, 12.531360660359276, 12.63892796086757, 12.745587471748802, 12.85136179554525, 12.956272612136564, 13.060340730624146, 13.16358613752347, 13.266028041580494, 13.367684915496776, 13.468574534819936, 13.568714014231418, 13.668119841441253, 13.766807908879969, 13.864793543360106, 13.962091533864118, 14.058716157601307, 14.154681204463774, 14.250000000000002, 14.344685427014428, 14.438749945892134, 14.53220561373944, 14.625064102423623, 14.717336715588186, 14.809034404713904, 14.90016778429022, 14.990747146156526, 15.080782473068169, 15.170283451537749, 15.259259483998562, 15.34771970033334, 15.435672968808326, 15.523127906449783, 15.610092888897237, 15.696576059765393, 15.782585339544346, 15.868128434065564, 15.953212842559337, 16.037845865327427, 16.122034611053287, 16.205786003770385, 16.289106789508136, 16.372003542633387, 16.454482671904337, 16.536550426252752], [0.0, 1.9000000000000001, 2.6870057685088806, 3.2908965343808676, 3.8000000000000003, 4.2485291572496005, 4.654030511288039, 5.026927491022722, 5.374011537017761, 5.7, 6.008327554319921, 6.30158710167526, 6.581793068761735, 6.850547423381581, 7.109149034870488, 7.358668357794092, 7.6000000000000005, 7.833900688673555, 8.061017305526642, 8.28190799272728, 8.497058314499201, 8.706893820416097, 8.911789943664516, 9.112079894294167, 9.308061022576078, 9.500000000000002, 9.688137075826292, 9.872689603142602, 10.053854982045443, 10.231813133555558, 10.406728592598157, 10.578752289377041, 10.748023074035522, 10.914669028422255, 11.078808600206072, 11.24055158788927, 11.4, 11.557248807566618, 11.712386605641056, 11.865496196956958, 12.016655108639842, 12.165936051122413, 12.313407326974936, 12.459133196173802, 12.60317420335052, 12.7455874717488, 12.88642696793801, 13.025743740761985, 13.16358613752347, 13.299999999999999, 13.435028842544405, 13.568714014231416, 13.701094846763162, 13.832208789632986, 13.962091533864116, 14.09077712548176, 14.218298069740976, 14.344685427014426, 14.469968901141428, 14.594176920950355, 14.717336715588184, 14.839474384222642, 14.96061496062244, 15.080782473068167, 15.200000000000001, 15.318289721767243, 15.435672968808325, 15.552170266557654, 15.66780137734711, 15.782585339544344, 15.896540504147437, 16.009684569035084, 16.122034611053284, 16.233607116103308, 16.34441800738099, 16.454482671904334, 16.56381598545456, 16.672432336045034, 16.780345646022912, 16.88756939289962, 16.994116628998402, 17.1, 17.205231762461096, 17.30982380037417, 17.413787640832194, 17.517134468856487, 17.619875141441838, 17.72202020086875, 17.823579887329032, 17.924564150907546, 18.02498266295976, 18.12484482692197, 18.224159788588334, 18.322936445886615, 18.421183458182053, 18.518909255137032, 18.616122045152157, 18.7128298234126, 18.809040379562166, 18.90476130502578, 19.000000000000004, 19.094763680129695], [0.0, 2.1242645786248007, 3.0041637771599605, 3.679334178897047, 4.248529157249601, 4.75, 5.203364296299079, 5.620275793944636, 6.008327554319921, 6.372793735874401, 6.7175144212722016, 7.0453885627408805, 7.358668357794094, 7.6591448608836235, 7.948270252073717, 8.227241335952167, 8.497058314499203, 8.758567234428243, 9.012491331479882, 9.259454627568518, 9.5, 9.73460322766162, 9.96368405761644, 10.187615030025428, 10.406728592598158, 10.621322893124002, 10.831666538441812, 11.03800253669114, 11.240551587889271, 11.439514849852682, 11.635076278220096, 11.827404618089297, 12.016655108639842, 12.202970949731874, 12.386484569885035, 12.567318727556804, 12.745587471748802, 12.921396983298672, 13.094846314485713, 13.266028041580496, 13.435028842544403, 13.601930010112536, 13.766807908879969, 13.929734383684423, 14.090777125481761, 14.25, 14.407463343697948, 14.563224230918099, 14.717336715588187, 14.869852050373602, 15.020818885799805, 15.170283451537749, 15.318289721767247, 15.464879566294723, 15.610092888897235, 15.75396775418815, 15.896540504147435, 16.037845865327427, 16.177917047630082, 16.316785835451785, 16.454482671904334, 16.591036736744332, 16.726476018576058, 16.860827381833907, 16.994116628998405, 17.126368558453947, 17.257607018355703, 17.38785495683697, 17.517134468856487, 17.645466839956377, 17.772872587176224, 17.899371497345935, 18.024982662959765, 18.14972451581566, 18.273614858587777, 18.396670894485233, 18.518909255137036, 18.640346026831157, 18.76099677522493, 18.880876568634203, 19.0, 19.118381207623205, 19.23603389475076, 19.352971348090193, 19.46920645532324, 19.58475172168389, 19.699619285661335, 19.813820933883502, 19.92736811523288, 20.040271954242538, 20.152543263816607, 20.264192557316466, 20.375230060050857, 20.485665720205436, 20.595509219244864, 20.7047699818182, 20.813457185196317, 20.921579768267982, 21.029146440119725, 21.136165688222643, 21.242645786248005, 21.348594801532023], [0.0, 2.3270152556440196, 3.290896534380867, 4.030508652763322, 4.654030511288039, 5.203364296299078, 5.700000000000001, 6.156703663487467, 6.581793068761734, 6.981045766932057, 7.358668357794093, 7.717836484404163, 8.061017305526644, 8.390172823011456, 8.706893820416095, 9.01249133147988, 9.308061022576078, 9.594529691443974, 9.872689603142602, 10.143224339429748, 10.406728592598157, 10.663723552305733, 10.914669028422255, 11.159973118247194, 11.400000000000002, 11.635076278220097, 11.865496196956958, 12.091525958289964, 12.313407326974934, 12.531360660359274, 12.7455874717488, 12.956272612136562, 13.163586137523469, 13.367684915496776, 13.568714014231416, 13.766807908879967, 13.962091533864115, 14.154681204463772, 14.344685427014426, 14.532205613739437, 14.717336715588186, 14.900167784290216, 15.080782473068169, 15.25925948399856, 15.435672968808326, 15.610092888897235, 15.782585339544344, 15.953212842559333, 16.122034611053287, 16.289106789508132, 16.454482671904337, 16.618212900309107, 16.780345646022912, 16.94092677512066, 17.1, 17.257607018355703, 17.41378764083219, 17.568579908461583, 17.72202020086875, 17.87414333611544, 18.02498266295976, 18.17457014622354, 18.322936445886615, 18.470110990462402, 18.616122045152157, 18.760996775224925, 18.90476130502578, 19.04744077297525, 19.189059382887947, 19.329640451907014, 19.46920645532324, 19.60777906852278, 19.745379206285204, 19.882027059633533, 20.017742130420203, 20.152543263816607, 20.286448678859497, 20.419475997194446, 20.551642270144743, 20.682964004223383, 20.813457185196313, 20.943137300796174, 21.072019362177898, 21.200117924200327, 21.327447104611466, 21.45402060220881, 21.57985171404104, 21.704953351712142, 21.82933805684451, 21.953018015753553, 22.076005073382277, 22.198310746541054, 22.31994623649439, 22.44092244093366, 22.561249965372046, 22.680939133995313, 22.800000000000004, 22.918442355448157, 23.03627574066607, 23.15350945321249, 23.270152556440195, 23.38621388767323], [0.0, 2.5134637455113613, 3.5545745174352446, 4.353446910208049, 5.026927491022723, 5.620275793944636, 6.156703663487468, 6.6499999999999995, 7.109149034870489, 7.540391236534083, 7.948270252073717, 8.336216168022517, 8.706893820416099, 9.062422413460984, 9.404520189781081, 9.734603227661617, 10.053854982045445, 10.36327650890393, 10.663723552305735, 10.955934464937258, 11.240551587889271, 11.518137870333035, 11.789189963691314, 12.054148663427044, 12.313407326974936, 12.567318727556806, 12.81620068507044, 13.060340730624144, 13.299999999999999, 13.535416506336258, 13.766807908879967, 13.994373869523423, 14.218298069740978, 14.43874994589213, 14.655886189514437, 14.8698520503736, 15.080782473068165, 15.288803092459528, 15.494031108785087, 15.696576059765391, 15.896540504147435, 16.094020628792546, 16.289106789508136, 16.4818839942526, 16.672432336045034, 16.860827381833907, 17.047140522680046, 17.2314392898562, 17.413787640832197, 17.594246218579528, 17.772872587176224, 17.949721446306626, 18.12484482692197, 18.298292270045312, 18.470110990462402, 18.640346026831153, 18.809040379562163, 18.976235137666272, 19.14196959562939, 19.306281361256495, 19.469206455323235, 19.630779403783233, 19.791033323199674, 19.950000000000003, 20.10770996409089, 20.264192557316463, 20.419475997194443, 20.57358743632233, 20.72655301780786, 20.878397927044116, 21.029146440119725, 21.178821969127558, 21.32744710461147, 21.4750436553689, 21.62163268580798, 21.76723455104024, 21.911868929874515, 22.05555485586341, 22.198310746541058, 22.34015443097921, 22.481103175778543, 22.62117370960225, 22.76038224635079, 22.898744507068503, 23.03627574066607, 23.17299074353589, 23.308903878132064, 23.444029090580827, 23.578379927382628, 23.711969551262502, 23.844810756221154, 23.97691598183553, 24.10829732685409, 24.23896656212884, 24.368935142923256, 24.49821422063249, 24.62681465394987, 24.75474701951123, 24.88202162204671, 25.00864850406755, 25.134637455113612, 25.259998020585833], [0.0, 2.6870057685088806, 3.8, 4.654030511288039, 5.374011537017761, 6.008327554319921, 6.581793068761734, 7.109149034870488, 7.6, 8.061017305526642, 8.497058314499201, 8.911789943664516, 9.308061022576078, 9.688137075826292, 10.053854982045443, 10.406728592598155, 10.748023074035522, 11.07880860020607, 11.4, 11.712386605641056, 12.016655108639842, 12.313407326974934, 12.60317420335052, 12.886426967938009, 13.163586137523469, 13.435028842544405, 13.70109484676316, 13.962091533864115, 14.218298069740976, 14.469968901141426, 14.717336715588184, 14.96061496062244, 15.2, 15.435672968808325, 15.66780137734711, 15.896540504147433, 16.122034611053284, 16.34441800738099, 16.56381598545456, 16.78034564602291, 16.994116628998402, 17.205231762461093, 17.413787640832194, 17.619875141441838, 17.823579887329032, 18.02498266295976, 18.224159788588334, 18.42118345818205, 18.616122045152157, 18.809040379562163, 19.000000000000004, 19.18905938288795, 19.376274151652584, 19.5616972678753, 19.7453792062852, 19.927368115232877, 20.107709964090887, 20.286448678859493, 20.463626267111117, 20.63928293328041, 20.81345718519631, 20.986185932655793, 21.157504578754082, 21.327447104611466, 21.496046148071045, 21.66333307688362, 21.82933805684451, 21.99409011530143, 22.15761720041214, 22.31994623649439, 22.481103175778543, 22.641113046844673, 22.8, 22.957787349829687, 23.11449761513323, 23.27015255644019, 23.424773211282112, 23.578379927382628, 23.730992393913915, 23.882629670955417, 24.033310217279684, 24.183051916579924, 24.33187210224483, 24.479787580777735, 24.626814653949868, 24.772969139770066, 24.9182663923476, 25.06272132071855, 25.20634840670104, 25.349161721840034, 25.4911749434976, 25.632401370140876, 25.772853935876018, 25.912545224273128, 26.05148748152397, 26.18969262897142, 26.327172275046937, 26.463937726649828, 26.6, 26.735369830993548, 26.87005768508881, 27.004073766748604], [0.0, 2.85, 4.030508652763321, 4.936344801571301, 5.7, 6.3727937358744, 6.981045766932058, 7.540391236534083, 8.061017305526642, 8.549999999999999, 9.01249133147988, 9.45238065251289, 9.872689603142602, 10.27582113507237, 10.663723552305731, 11.038002536691138, 11.4, 11.750851033010333, 12.091525958289964, 12.42286198909092, 12.7455874717488, 13.060340730624144, 13.367684915496774, 13.66811984144125, 13.962091533864116, 14.250000000000002, 14.532205613739437, 14.8090344047139, 15.080782473068165, 15.347719700333338, 15.610092888897233, 15.86812843406556, 16.122034611053284, 16.372003542633383, 16.618212900309107, 16.860827381833904, 17.099999999999998, 17.335873211349924, 17.568579908461583, 17.798244295435435, 18.02498266295976, 18.24890407668362, 18.470110990462402, 18.6886997942607, 18.90476130502578, 19.1183812076232, 19.329640451907014, 19.538615611142976, 19.745379206285204, 19.95, 20.152543263816607, 20.353071021347123, 20.55164227014474, 20.748313184449476, 20.943137300796174, 21.13616568822264, 21.327447104611462, 21.51702814052164, 21.70495335171214, 21.891265381425534, 22.076005073382277, 22.259211576333964, 22.440922440933658, 22.62117370960225, 22.8, 22.977434582650865, 23.153509453212486, 23.328255399836483, 23.501702066020666, 23.673878009316514, 23.844810756221154, 24.01452685355262, 24.183051916579927, 24.35041067415496, 24.516627011071485, 24.681724007856502, 24.84572397818184, 25.008648504067548, 25.170518469034366, 25.33135408934943, 25.4911749434976, 25.65, 25.80784764369164, 25.96473570056125, 26.12068146124829, 26.275701703284728, 26.429812712162754, 26.583030301303125, 26.735369830993548, 26.886846226361317, 27.037473994439644, 27.187267240382948, 27.3362396828825, 27.48440466882992, 27.631775187273078, 27.778363882705545, 27.924183067728233, 28.0692447351189, 28.213560569343247, 28.35714195753867, 28.500000000000004, 28.64214552019454], [0.0, 3.0041637771599605, 4.2485291572496005, 5.203364296299079, 6.008327554319921, 6.7175144212722016, 7.358668357794093, 7.948270252073717, 8.497058314499201, 9.01249133147988, 9.5, 9.96368405761644, 10.406728592598158, 10.831666538441812, 11.24055158788927, 11.635076278220096, 12.016655108639842, 12.386484569885033, 12.745587471748802, 13.094846314485713, 13.435028842544403, 13.766807908879967, 14.09077712548176, 14.407463343697946, 14.717336715588186, 15.020818885799804, 15.318289721767245, 15.610092888897235, 15.896540504147435, 16.177917047630082, 16.454482671904334, 16.726476018576058, 16.994116628998402, 17.257607018355703, 17.517134468856487, 17.77287258717622, 18.02498266295976, 18.273614858587777, 18.518909255137032, 18.760996775224925, 19.0, 19.236033894750758, 19.46920645532324, 19.699619285661335, 19.92736811523288, 20.152543263816604, 20.375230060050857, 20.59550921924486, 20.813457185196317, 21.02914644011972, 21.242645786248005, 21.45402060220881, 21.663333076883625, 21.870642423120543, 22.076005073382277, 22.27947485916129, 22.48110317577854, 22.680939133995313, 22.879029699705363, 23.075419822833126, 23.27015255644019, 23.46326916693409, 23.65480923617859, 23.844810756221154, 24.033310217279684, 24.220342689565726, 24.405941899463745, 24.59014030053509, 24.772969139770066, 24.954458519471025, 25.134637455113612, 25.313533929501034, 25.491174943497604, 25.66758656360196, 25.84279396659734, 26.01682148149539, 26.189692628971425, 26.361430158472057, 26.53205608316099, 26.701591712854874, 26.870057685088806, 27.037473994439644, 27.203860020225076, 27.36923455268707, 27.533615817759934, 27.697021500515177, 27.859468767368842, 28.02097428712999, 28.18155425096352, 28.341224391334965, 28.5, 28.657895945096875, 28.814926687395893, 28.971106295756123, 29.126448461836198, 29.280966514102637, 29.43467343117637, 29.587581854555133, 29.739704100747204, 29.89105217284932, 30.041637771599607, 30.19147230593434], [0.0, 3.1507935508376304, 4.455894971832258, 5.457334514211129, 6.301587101675261, 7.0453885627408805, 7.717836484404164, 8.336216168022517, 8.911789943664516, 9.45238065251289, 9.96368405761644, 10.450000000000001, 10.914669028422258, 11.36034770594633, 11.789189963691314, 12.202970949731872, 12.603174203350521, 12.991054614618477, 13.367684915496776, 13.733990680060915, 14.090777125481761, 14.438749945892132, 14.778531726798844, 15.110675034557525, 15.435672968808328, 15.753967754188153, 16.065957799023376, 16.372003542633383, 16.672432336045034, 16.967542544517165, 17.257607018355703, 17.542876046988418, 17.823579887329032, 18.09993093909477, 18.372125625523033, 18.640346026831153, 18.90476130502578, 19.165528951740416, 19.422795885247833, 19.67669941834758, 19.92736811523288, 20.17492255251554, 20.419475997194446, 20.66113501238497, 20.900000000000002, 21.13616568822264, 21.36972157048379, 21.60075230171394, 21.829338056844517, 22.05555485586341, 22.279474859161294, 22.501166636421324, 22.72069541189266, 22.93812328853431, 23.15350945321249, 23.366910364872805, 23.578379927382628, 23.78796964854294, 23.995728786598672, 24.201704485428294, 24.405941899463745, 24.608484309278378, 24.80937322868113, 25.00864850406755, 25.206348406701043, 25.40250971852978, 25.597167812084212, 25.790356724946633, 25.982109229236954, 26.172456896516234, 26.361430158472057, 26.549058363716032, 26.73536983099355, 26.920391899079032, 27.104150973605503, 27.28667257105564, 27.46798136012183, 27.648101200624975, 27.827055180165946, 28.004865648668986, 28.181554250963522, 28.357141957538673, 28.5316490935943, 28.705095366502444, 28.877499891784264, 29.048881217699247, 29.21925734853643, 29.388645766690242, 29.55706345359769, 29.72452690960783, 29.89105217284932, 30.05665483715711, 30.22135006911505, 30.385152624267008, 30.548076862545706, 30.710136762964765, 30.871345937616656, 31.031717645016048, 31.19126480282581, 31.350000000000005, 31.507935508376306, 31.665083293748026], [0.0, 3.2908965343808676, 4.654030511288039, 5.700000000000002, 6.581793068761735, 7.358668357794093, 8.061017305526644, 8.706893820416097, 9.308061022576078, 9.872689603142602, 10.406728592598158, 10.914669028422257, 11.400000000000004, 11.86549619695696, 12.313407326974936, 12.745587471748802, 13.16358613752347, 13.568714014231418, 13.962091533864118, 14.344685427014428, 14.717336715588186, 15.080782473068169, 15.435672968808326, 15.782585339544346, 16.122034611053287, 16.454482671904337, 16.780345646022912, 17.1, 17.413787640832194, 17.72202020086875, 18.024982662959765, 18.322936445886615, 18.616122045152157, 18.904761305025783, 19.18905938288795, 19.46920645532324, 19.745379206285204, 20.017742130420206, 20.286448678859493, 20.551642270144743, 20.813457185196317, 21.072019362177894, 21.32744710461147, 21.57985171404104, 21.829338056844513, 22.07600507338228, 22.319946236494392, 22.561249965372046, 22.800000000000008, 23.03627574066607, 23.2701525564402, 23.50170206602067, 23.73099239391392, 23.958088404545137, 24.183051916579927, 24.40594189946375, 24.62681465394987, 24.845723978181844, 25.062721320718552, 25.27785592173514, 25.491174943497604, 25.7027235910905, 25.912545224273128, 26.120681461248292, 26.32717227504694, 26.532056083160988, 26.73536983099355, 26.937149069639872, 27.137428028462836, 27.336239682882507, 27.533615817759937, 27.729587086720212, 27.924183067728237, 28.117432315202613, 28.309362408927548, 28.500000000000004, 28.689370854028855, 28.877499891784268, 29.06441122747888, 29.250128204847247, 29.43467343117637, 29.618068809427808, 29.80033556858044, 29.98149429231305, 30.161564946136338, 30.340566903075498, 30.518518967997124, 30.69543940066668, 30.871345937616653, 31.046255812899567, 31.220185777794473, 31.393152119530786, 31.56517067908869, 31.73625686813113, 31.906425685118673, 32.07569173065485, 32.244069222106575, 32.41157200754077, 32.57821357901627, 32.74400708526677, 32.908965343808674, 33.073100852505505], [0.0, 3.42527371169079, 4.844068537913146, 5.93274809847848, 6.85054742338158, 7.659144860883623, 8.390172823011456, 9.062422413460984, 9.688137075826292, 10.27582113507237, 10.831666538441812, 11.36034770594633, 11.86549619695696, 12.350000000000003, 12.81620068507044, 13.266028041580494, 13.70109484676316, 14.122765309952582, 14.532205613739439, 14.930421963226628, 15.318289721767245, 15.696576059765391, 16.065957799023376, 16.427035642501053, 16.780345646022912, 17.12636855845395, 17.465537495307725, 17.79824429543544, 18.12484482692197, 18.44566344700022, 18.760996775224925, 19.071116904890495, 19.376274151652584, 19.67669941834758, 19.972606239547208, 20.264192557316463, 20.55164227014474, 20.835126589488244, 21.11480523234823, 21.390827473475635, 21.663333076883625, 21.932453123168873, 22.198310746541058, 22.46102179332009, 22.72069541189266, 22.97743458265087, 23.23133659521122, 23.482493479185724, 23.73099239391392, 23.97691598183553, 24.220342689565733, 24.461347060209096, 24.700000000000006, 24.93636902197271, 25.170518469034366, 25.40250971852978, 25.63240137014088, 25.860249418750783, 26.086107413717368, 26.310026605839838, 26.532056083160988, 26.752242896624576, 26.970632176498942, 27.187267240382955, 27.40218969352632, 27.6154395221224, 27.82705518016594, 28.03707367041004, 28.245530619905164, 28.452460350556684, 28.65789594509688, 28.861869308830297, 29.064411227478878, 29.26555142142379, 29.465318596614562, 29.663740492392396, 29.860843926453256, 30.056654837157115, 30.251198323372254, 30.444498682027927, 30.63657944353449, 30.82746340521711, 31.017172662897572, 31.205728640748, 31.393152119530782, 31.57946326332986, 31.76468164487093, 31.948826269520456, 32.13191559804675, 32.313967568220406, 32.49499961532543, 32.6750286916477, 32.85407128500211, 33.03214343635605, 33.20926075660222, 33.3854384425306, 33.560691292045824, 33.735033718672945, 33.90847976539202, 34.08104311783899, 34.2527371169079, 34.42357477078754], [0.0, 3.5545745174352446, 5.026927491022722, 6.156703663487469, 7.109149034870489, 7.948270252073717, 8.706893820416097, 9.404520189781081, 10.053854982045443, 10.663723552305733, 11.24055158788927, 11.789189963691314, 12.313407326974938, 12.816200685070442, 13.299999999999999, 13.766807908879965, 14.218298069740978, 14.655886189514437, 15.080782473068167, 15.494031108785087, 15.896540504147435, 16.289106789508136, 16.67243233604503, 17.047140522680042, 17.413787640832194, 17.772872587176224, 18.12484482692197, 18.470110990462402, 18.809040379562163, 19.14196959562939, 19.469206455323235, 19.791033323199674, 20.107709964090887, 20.419475997194443, 20.72655301780786, 21.02914644011972, 21.327447104611466, 21.621632685807977, 21.91186892987451, 22.198310746541054, 22.48110317577854, 22.760382246350783, 23.03627574066607, 23.308903878132064, 23.578379927382628, 23.84481075622115, 24.10829732685409, 24.368935142923256, 24.626814653949875, 24.882021622046707, 25.134637455113612, 25.384739510186037, 25.632401370140883, 25.877693096564848, 26.12068146124829, 26.361430158472054, 26.599999999999998, 26.836449094468517, 27.070833012672516, 27.303204940079837, 27.53361581775993, 27.762114472784667, 27.988747739046843, 28.213560569343247, 28.436596139481956, 28.65789594509687, 28.87749989178426, 29.095446379115753, 29.311772379028874, 29.5265135090481, 29.739704100747204, 29.95137726382545, 30.161564946136334, 30.370297989976983, 30.577606184919052, 30.783518317437338, 30.988062217570175, 31.19126480282581, 31.393152119530786, 31.593749381800194, 31.79308100829487, 31.9911706569172, 32.1880412575851, 32.38371504321269, 32.57821357901627, 32.77155779025465, 32.9637679885052, 33.154863896568784, 33.34486467209006, 33.5337889299733, 33.72165476366781, 33.908479765392016, 34.094281045360084, 34.27907525007056, 34.46287857971241, 34.64570680473989, 34.82757528166439, 35.00849896810773, 35.188492437159056, 35.36756989107394, 35.54574517435245, 35.72303178623002], [0.0, 3.679334178897046, 5.203364296299077, 6.372793735874401, 7.358668357794092, 8.227241335952167, 9.01249133147988, 9.734603227661617, 10.406728592598155, 11.038002536691137, 11.635076278220096, 12.202970949731872, 12.745587471748802, 13.266028041580494, 13.766807908879965, 14.249999999999998, 14.717336715588184, 15.170283451537745, 15.610092888897235, 16.037845865327427, 16.454482671904334, 16.860827381833904, 17.2576070183557, 17.645466839956374, 18.02498266295976, 18.39667089448523, 18.760996775224925, 19.1183812076232, 19.469206455323235, 19.8138209338835, 20.1525432638166, 20.485665720205432, 20.81345718519631, 21.136165688222636, 21.454020602208807, 21.767234551040236, 22.076005073382273, 22.380516079840515, 22.68093913399531, 22.977434582650865, 23.27015255644019, 23.559233858510762, 23.844810756221154, 24.127007688480557, 24.405941899463745, 24.6817240078565, 24.954458519471025, 25.224244289968333, 25.491174943497604, 25.755339252279317, 26.01682148149539, 26.275701703284728, 26.532056083160988, 26.7859571417562, 27.03747399443964, 27.286672571055632, 27.53361581775993, 27.778363882705545, 28.020974287129988, 28.26150208322268, 28.499999999999996, 28.736518578282926, 28.971106295756115, 29.203809682984854, 29.434673431176368, 29.663740492392385, 29.891052172849317, 30.116648219879977, 30.34056690307549, 30.56284509007628, 30.783518317437334, 31.002620856953367, 31.22018577779447, 31.43624500477116, 31.65082937301959, 31.863968679372, 32.07569173065485, 32.28602638913621, 32.49499961532543, 32.70263750831116, 32.90896534380867, 33.114007610073415, 33.317788041825345, 33.52032965231696, 33.72165476366781, 33.92178503557854, 34.12074149252914, 34.31854454955804, 34.5152140367114, 34.7107692222457, 34.905228834660285, 35.09861108363121, 35.29093367991275, 35.48221385426788, 35.672468375485316, 35.86171356753606, 36.04996532591952, 36.23723913324524, 36.42355007409355, 36.60891284919562, 36.79334178897046, 36.97685086645427], [0.0, 3.8000000000000003, 5.374011537017761, 6.581793068761735, 7.6000000000000005, 8.497058314499201, 9.308061022576078, 10.053854982045443, 10.748023074035522, 11.4, 12.016655108639842, 12.60317420335052, 13.16358613752347, 13.701094846763162, 14.218298069740976, 14.717336715588184, 15.200000000000001, 15.66780137734711, 16.122034611053284, 16.56381598545456, 16.994116628998402, 17.413787640832194, 17.823579887329032, 18.224159788588334, 18.616122045152157, 19.000000000000004, 19.376274151652584, 19.745379206285204, 20.107709964090887, 20.463626267111117, 20.813457185196313, 21.157504578754082, 21.496046148071045, 21.82933805684451, 22.157617200412144, 22.48110317577854, 22.8, 23.114497615133235, 23.424773211282112, 23.730992393913915, 24.033310217279684, 24.331872102244827, 24.62681465394987, 24.918266392347604, 25.20634840670104, 25.4911749434976, 25.77285393587602, 26.05148748152397, 26.32717227504694, 26.599999999999998, 26.87005768508881, 27.137428028462832, 27.402189693526324, 27.664417579265972, 27.924183067728233, 28.18155425096352, 28.436596139481953, 28.68937085402885, 28.939937802282856, 29.18835384190071, 29.434673431176368, 29.678948768445284, 29.92122992124488, 30.161564946136334, 30.400000000000002, 30.636579443534487, 30.87134593761665, 31.10434053311531, 31.33560275469422, 31.565170679088688, 31.793081008294873, 32.01936913807017, 32.24406922210657, 32.467214232206615, 32.68883601476198, 32.90896534380867, 33.12763197090912, 33.34486467209007, 33.560691292045824, 33.77513878579924, 33.988233257996804, 34.2, 34.41046352492219, 34.61964760074834, 34.82757528166439, 35.03426893771297, 35.239750282883676, 35.4440404017375, 35.647159774658064, 35.84912830181509, 36.04996532591952, 36.24968965384394, 36.44831957717667, 36.64587289177323, 36.84236691636411, 37.037818510274064, 37.23224409030431, 37.4256596468252, 37.61808075912433, 37.80952261005156, 38.00000000000001, 38.18952736025939], [0.0, 3.9169503443367777, 5.539404300103035, 6.784357007115709, 7.833900688673555, 8.758567234428243, 9.594529691443975, 10.363276508903928, 11.07880860020607, 11.750851033010331, 12.386484569885033, 12.991054614618477, 13.568714014231418, 14.122765309952582, 14.655886189514435, 15.170283451537745, 15.66780137734711, 16.15, 16.618212900309107, 17.07359071783086, 17.517134468856487, 17.949721446306626, 18.37212562552303, 18.78503393662093, 19.18905938288795, 19.58475172168389, 19.972606239547208, 20.353071021347123, 20.726553017807856, 21.093423145615795, 21.454020602208807, 21.808656538173093, 22.15761720041214, 22.50116663642132, 22.839549032325486, 23.172990743535888, 23.501702066020663, 23.82587878757046, 24.145703551563788, 24.461347060209093, 24.772969139770066, 25.080719686643764, 25.384739510186037, 25.68516108573197, 25.982109229236954, 26.275701703284728, 26.56604976280817, 26.853258647694883, 27.137428028462836, 27.418652410357442, 27.69702150051518, 27.972620542237372, 28.245530619905164, 28.515828937626907, 28.78358907433192, 29.048881217699247, 29.31177237902887, 29.572326590919424, 29.830605089404408, 30.08666648201492, 30.34056690307549, 30.592360157398772, 30.84209785342106, 31.08982952671179, 31.33560275469422, 31.579463263329853, 31.821455026444028, 32.06162035830379, 32.3, 32.536633200133046, 32.77155779025465, 33.0048102554764, 33.236425800618214, 33.46643841223622, 33.69488091683958, 33.92178503557854, 34.14718143566172, 34.37109977873853, 34.593568766462944, 34.81461618343652, 35.03426893771297, 35.252553099031, 35.469493934929496, 35.6851159448866, 35.89944289261325, 36.11249783662161, 36.324303159179806, 36.53488059375589, 36.74425125104606, 36.95243564367578, 37.1594537096551, 37.365324834664555, 37.57006787324186, 37.773701168934984, 37.97624257348271, 38.177709465079225, 38.3781187657759, 38.577486958069215, 38.77583010072125, 38.97316384385543, 39.16950344336778, 39.36486377469126], [0.0, 4.030508652763321, 5.7, 6.981045766932059, 8.061017305526642, 9.01249133147988, 9.872689603142602, 10.663723552305733, 11.4, 12.091525958289962, 12.745587471748802, 13.367684915496776, 13.962091533864118, 14.532205613739439, 15.080782473068165, 15.610092888897235, 16.122034611053284, 16.618212900309107, 17.1, 17.568579908461587, 18.02498266295976, 18.470110990462402, 18.90476130502578, 19.329640451907014, 19.745379206285204, 20.152543263816607, 20.55164227014474, 20.943137300796174, 21.327447104611466, 21.704953351712142, 22.076005073382277, 22.44092244093366, 22.8, 23.15350945321249, 23.501702066020666, 23.84481075622115, 24.183051916579924, 24.516627011071485, 24.84572397818184, 25.170518469034366, 25.491174943497604, 25.807847643691638, 26.120681461248292, 26.429812712162757, 26.73536983099355, 27.037473994439644, 27.336239682882503, 27.631775187273078, 27.924183067728237, 28.213560569343244, 28.500000000000004, 28.783589074331925, 29.064411227478878, 29.34254590181295, 29.618068809427804, 29.89105217284932, 30.16156494613633, 30.42967301828924, 30.695439400666675, 30.958924399920615, 31.22018577779447, 31.479278898983694, 31.73625686813112, 31.991170656917202, 32.24406922210657, 32.49499961532543, 32.744007085266766, 32.99113517295214, 33.236425800618214, 33.47991935474158, 33.721654763667814, 33.961669570267006, 34.2, 34.43668102474453, 34.671746422699854, 34.90522883466029, 35.13715981692317, 35.36756989107394, 35.59648859087088, 35.82394450643313, 36.04996532591952, 36.27457787486989, 36.497808153367245, 36.71968137116661, 36.940221980924804, 37.1594537096551, 37.377399588521406, 37.59408198107782, 37.80952261005156, 38.02374258276005, 38.2367624152464, 38.44860205521132, 38.65928090381403, 38.86881783640969, 39.07723122228596, 39.28453894345713, 39.49075841257041, 39.69590658997475, 39.9, 40.10305474649032, 40.305086527633215, 40.506110650122906], [0.0, 4.14095399636364, 5.856193302820528, 7.172342713507215, 8.28190799272728, 9.259454627568516, 10.143224339429748, 10.955934464937258, 11.712386605641056, 12.42286198909092, 13.094846314485713, 13.733990680060915, 14.34468542701443, 14.93042196322663, 15.494031108785087, 16.037845865327427, 16.56381598545456, 17.07359071783086, 17.568579908461587, 18.050000000000004, 18.518909255137032, 18.976235137666272, 19.42279588524783, 19.85931771234853, 20.286448678859497, 20.704769981818202, 21.11480523234823, 21.51702814052164, 21.911868929874515, 22.29971972918046, 22.680939133995313, 23.055856089072037, 23.424773211282112, 23.78796964854294, 24.145703551563788, 24.49821422063249, 24.84572397818184, 25.18843980876942, 25.52655480083437, 25.860249418750783, 26.189692628971425, 26.515042900210442, 26.83644909446852, 27.15405126311726, 27.46798136012183, 27.77836388270555, 28.08531644827952, 28.388950315219482, 28.68937085402886, 28.98667797454548, 29.280966514102644, 29.57232659091943, 29.86084392645326, 30.14660013998262, 30.42967301828924, 30.71013676296477, 30.988062217570175, 31.26351707661824, 31.536566078125887, 31.807271181288094, 32.07569173065485, 32.341884608043486, 32.60590437328798, 32.86780339481177, 33.12763197090912, 33.3854384425306, 33.641269298288975, 33.89516927233142, 34.14718143566172, 34.39734728144018, 34.645706804739895, 34.89229857719322, 35.13715981692317, 35.38032645411854, 35.621833192580084, 35.861713567536064, 36.10000000000001, 36.336723847920034, 36.57191545434831, 36.805604192839986, 37.037818510274064, 37.26858596727276, 37.49793327638206, 37.725886338163086, 37.952470275332544, 38.17770946507923, 38.4016275696747, 38.62424756548664, 38.84559177049566, 39.06568187040897, 39.284538943457136, 39.502183483954404, 39.71863542469706, 39.93391415826904, 40.148038557319346, 40.36102699387121, 40.57289735771899, 40.7836670739648, 40.9933531197437, 41.201972040182746, 41.409539963636405, 41.61607261623808], [0.0, 4.248529157249601, 6.008327554319921, 7.358668357794094, 8.497058314499203, 9.5, 10.406728592598158, 11.240551587889271, 12.016655108639842, 12.745587471748802, 13.435028842544403, 14.090777125481761, 14.717336715588187, 15.318289721767247, 15.896540504147435, 16.454482671904334, 16.994116628998405, 17.517134468856487, 18.024982662959765, 18.518909255137036, 19.0, 19.46920645532324, 19.92736811523288, 20.375230060050857, 20.813457185196317, 21.242645786248005, 21.663333076883625, 22.07600507338228, 22.481103175778543, 22.879029699705363, 23.27015255644019, 23.654809236178593, 24.033310217279684, 24.40594189946375, 24.77296913977007, 25.13463745511361, 25.491174943497604, 25.842793966597345, 26.189692628971425, 26.53205608316099, 26.870057685088806, 27.203860020225072, 27.533615817759937, 27.859468767368845, 28.181554250963522, 28.5, 28.814926687395896, 29.126448461836198, 29.434673431176375, 29.739704100747204, 30.04163777159961, 30.340566903075498, 30.636579443534494, 30.929759132589446, 31.22018577779447, 31.5079355083763, 31.79308100829487, 32.07569173065485, 32.355834095260164, 32.63357167090357, 32.90896534380867, 33.182073473488664, 33.452952037152116, 33.721654763667814, 33.98823325799681, 34.252737116907895, 34.515214036711406, 34.77570991367394, 35.03426893771297, 35.290933679912754, 35.54574517435245, 35.79874299469187, 36.04996532591953, 36.29944903163132, 36.547229717175554, 36.793341788970466, 37.03781851027407, 37.280692053662314, 37.52199355044986, 37.76175313726841, 38.0, 38.23676241524641, 38.47206778950152, 38.70594269618039, 38.93841291064648, 39.16950344336778, 39.39923857132267, 39.627641867767004, 39.85473623046576, 40.080543908485076, 40.305086527633215, 40.52838511463293, 40.750460120101714, 40.97133144041087, 41.19101843848973, 41.4095399636364, 41.62691437039263, 41.843159536535964, 42.05829288023945, 42.27233137644529, 42.48529157249601, 42.69718960306405], [0.0, 4.353446910208048, 6.156703663487468, 7.540391236534085, 8.706893820416097, 9.73460322766162, 10.663723552305735, 11.518137870333033, 12.313407326974936, 13.060340730624144, 13.766807908879967, 14.438749945892132, 15.08078247306817, 15.696576059765393, 16.289106789508136, 16.860827381833907, 17.413787640832194, 17.949721446306626, 18.470110990462405, 18.976235137666272, 19.46920645532324, 19.950000000000003, 20.419475997194443, 20.878397927044116, 21.32744710461147, 21.767234551040243, 22.198310746541054, 22.621173709602253, 23.036275740666067, 23.444029090580827, 23.844810756221154, 24.23896656212884, 24.62681465394987, 25.00864850406755, 25.384739510186037, 25.75533925227932, 26.12068146124829, 26.480983743056072, 26.836449094468517, 27.187267240382955, 27.533615817759934, 27.8756614271303, 28.21356056934325, 28.54746048250177, 28.877499891784264, 29.203809682984858, 29.526513509048105, 29.84572833756952, 30.16156494613634, 30.474128371456334, 30.78351831743734, 31.089829526711792, 31.393152119530786, 31.69357190346333, 31.991170656917202, 32.28602638913622, 32.57821357901627, 32.86780339481177, 33.154863896568784, 33.43946022291628, 33.721654763667814, 34.00150731952923, 34.27907525007056, 34.554413610999106, 34.82757528166439, 35.09861108363121, 35.36756989107394, 35.634498733671, 35.89944289261325, 36.162445990281135, 36.42355007409355, 36.68279569498487, 36.94022198092481, 37.1958667058586, 37.449766354411345, 37.70195618267042, 37.952470275332544, 38.20134159947789, 38.448602055211325, 38.694282523390974, 38.93841291064648, 39.18102219187244, 39.42213845036822, 39.66178891578139, 39.900000000000006, 40.136797331127454, 40.37220578566398, 40.60624951900878, 40.838951994388886, 41.07033601031284, 41.3004237266399, 41.52923668934935, 41.75679585408823, 41.98312160857027, 42.208233793893825, 42.43215172484186, 42.65489420922294, 42.87647956630769, 43.09692564441227, 43.316249837676395, 43.534469102080486, 43.75159997074393], [0.0, 4.455894971832259, 6.30158710167526, 7.717836484404164, 8.911789943664518, 9.96368405761644, 10.914669028422257, 11.789189963691314, 12.60317420335052, 13.367684915496774, 14.09077712548176, 14.778531726798844, 15.435672968808328, 16.065957799023376, 16.67243233604503, 17.257607018355703, 17.823579887329036, 18.372125625523033, 18.904761305025783, 19.422795885247833, 19.92736811523288, 20.419475997194443, 20.9, 21.369721570483787, 21.829338056844513, 22.279474859161294, 22.72069541189266, 23.15350945321249, 23.578379927382628, 23.995728786598672, 24.405941899463745, 24.80937322868113, 25.20634840670104, 25.597167812084212, 25.982109229236954, 26.361430158472054, 26.735369830993548, 27.1041509736055, 27.467981360121826, 27.827055180165942, 28.18155425096352, 28.531649093594293, 28.877499891784264, 29.219257348536427, 29.55706345359769, 29.89105217284932, 30.221350069115047, 30.548076862545702, 30.871345937616656, 31.191264802825806, 31.507935508376303, 31.821455026444035, 32.13191559804675, 32.43940505003136, 32.744007085266766, 33.04580154875956, 33.34486467209006, 33.641269298288975, 33.93508508903433, 34.226378715838464, 34.515214036711406, 34.801652259626984, 35.085752093976836, 35.36756989107394, 35.64715977465807, 35.92457376225917, 36.19986187818954, 36.47307225885969, 36.744251251046066, 37.0134435036785, 37.280692053662314, 37.54603840620206, 37.809522610051566, 38.071183328076366, 38.331057903480826, 38.58918242202081, 38.845591770495666, 39.10031969178769, 39.35339883669517, 39.60486081278408, 39.85473623046576, 40.10305474649032, 40.34984510503108, 40.59513517652084, 40.838951994388886, 41.08132178983534, 41.322270024769935, 41.56182142303199, 41.8, 42.03682909069141, 42.27233137644528, 42.506528910274476, 42.73944314096757, 42.97109493601484, 43.201504603427885, 43.430691912517354, 43.658676113689026, 43.88547595731418, 44.11110971172682, 44.33559518039653, 44.55894971832259, 44.78119024769217], [0.0, 4.5560399471470845, 6.443213483969005, 7.891292669772174, 9.112079894294169, 10.187615030025428, 11.159973118247196, 12.054148663427044, 12.88642696793801, 13.668119841441252, 14.407463343697946, 15.110675034557525, 15.782585339544347, 16.427035642501057, 17.047140522680042, 17.645466839956374, 18.224159788588338, 18.78503393662093, 19.329640451907018, 19.859317712348535, 20.375230060050857, 20.878397927044116, 21.369721570483787, 21.85, 22.319946236494392, 22.780199735735422, 23.23133659521122, 23.673878009316518, 24.10829732685409, 24.535025983275425, 24.954458519471025, 25.36695685335551, 25.77285393587602, 26.172456896516234, 26.566049762808174, 26.953895822311104, 27.336239682882503, 27.713309077048162, 28.08531644827952, 28.452460350556684, 28.814926687395893, 29.172889812289768, 29.526513509048105, 29.875951867681138, 30.22135006911505, 30.562845090076284, 30.90056633785213, 31.23463622326984, 31.565170679088695, 31.892279630029584, 32.21606741984503, 32.53663320013305, 32.854071285002114, 33.16847147518258, 33.47991935474158, 33.788496563179606, 34.094281045360084, 34.39734728144018, 34.697766498724384, 34.99560686714834, 35.29093367991275, 35.583809520623284, 35.874294418148494, 36.162445990281135, 36.448319577176676, 36.73196836544429, 37.0134435036785, 37.29279421014199, 37.57006787324186, 37.84531014537997, 38.11856503070388, 38.38987496723583, 38.659280903814036, 38.92682237224097, 39.192537554998914, 39.45646334886086, 39.71863542469707, 39.97908828375155, 40.237855310640015, 40.49496882329952, 40.750460120101714, 41.00435952432375, 41.25669642615609, 41.507499322411604, 41.75679585408823, 42.004612841924875, 42.25097632008047, 42.49591156805559, 42.73944314096757, 42.981594898281756, 43.222390031093845, 43.46185108805192, 43.7, 43.936858103419276, 44.172446162738154, 44.40678439157693, 44.639892472988784, 44.871789578754274, 45.10249438778304, 45.33202510367258, 45.560399471470845, 45.787634793686394], [0.0, 4.654030511288039, 6.581793068761734, 8.061017305526644, 9.308061022576078, 10.406728592598157, 11.400000000000002, 12.313407326974934, 13.163586137523469, 13.962091533864115, 14.717336715588186, 15.435672968808326, 16.122034611053287, 16.780345646022912, 17.41378764083219, 18.02498266295976, 18.616122045152157, 19.189059382887947, 19.745379206285204, 20.286448678859497, 20.813457185196313, 21.327447104611466, 21.82933805684451, 22.31994623649439, 22.800000000000004, 23.270152556440195, 23.730992393913915, 24.183051916579927, 24.626814653949868, 25.06272132071855, 25.4911749434976, 25.912545224273124, 26.327172275046937, 26.73536983099355, 27.137428028462832, 27.533615817759934, 27.92418306772823, 28.309362408927544, 28.68937085402885, 29.064411227478875, 29.43467343117637, 29.800335568580433, 30.161564946136338, 30.51851896799712, 30.871345937616653, 31.22018577779447, 31.565170679088688, 31.906425685118666, 32.244069222106575, 32.578213579016264, 32.908965343808674, 33.236425800618214, 33.560691292045824, 33.88185355024132, 34.2, 34.515214036711406, 34.82757528166438, 35.137159816923166, 35.4440404017375, 35.74828667223088, 36.04996532591952, 36.34914029244708, 36.64587289177323, 36.940221980924804, 37.23224409030431, 37.52199355044985, 37.80952261005156, 38.0948815459505, 38.378118765775895, 38.65928090381403, 38.93841291064648, 39.21555813704556, 39.49075841257041, 39.764054119267065, 40.035484260840406, 40.305086527633215, 40.57289735771899, 40.83895199438889, 41.103284540289486, 41.365928008446765, 41.626914370392626, 41.88627460159235, 42.144038724355795, 42.400235848400655, 42.65489420922293, 42.90804120441762, 43.15970342808208, 43.409906703424284, 43.65867611368902, 43.90603603150711, 44.15201014676455, 44.39662149308211, 44.63989247298878, 44.88184488186732, 45.12249993074409, 45.361878267990626, 45.60000000000001, 45.836884710896314, 46.07255148133214, 46.30701890642498, 46.54030511288039, 46.77242777534646], [0.0, 4.750000000000001, 6.7175144212722016, 8.227241335952169, 9.500000000000002, 10.621322893124002, 11.635076278220097, 12.567318727556806, 13.435028842544403, 14.25, 15.020818885799804, 15.753967754188151, 16.454482671904337, 17.12636855845395, 17.77287258717622, 18.39667089448523, 19.000000000000004, 19.58475172168389, 20.152543263816607, 20.704769981818202, 21.242645786248005, 21.767234551040243, 22.27947485916129, 22.78019973573542, 23.270152556440195, 23.750000000000004, 24.22034268956573, 24.681724007856502, 25.134637455113612, 25.579532833888898, 26.01682148149539, 26.446880723442604, 26.870057685088806, 27.28667257105564, 27.69702150051518, 28.101378969723175, 28.5, 28.893122018916543, 29.28096651410264, 29.663740492392396, 30.041637771599607, 30.414840127806034, 30.78351831743734, 31.147832990434505, 31.507935508376303, 31.863968679372004, 32.216067419845025, 32.56435935190496, 32.908965343808674, 33.25, 33.587572106361016, 33.921785035578544, 34.2527371169079, 34.580521974082465, 34.90522883466029, 35.2269428137044, 35.54574517435244, 35.861713567536064, 36.17492225285357, 36.485442302375894, 36.79334178897046, 37.09868596055661, 37.401537401556105, 37.70195618267042, 38.00000000000001, 38.29572430441811, 38.58918242202081, 38.88042566639414, 39.16950344336778, 39.45646334886086, 39.741351260368596, 40.024211422587705, 40.305086527633215, 40.58401779025827, 40.86104501845248, 41.13620667976084, 41.409539963636405, 41.681080840112585, 41.95086411505728, 42.21892348224905, 42.48529157249601, 42.75, 43.01307940615274, 43.27455950093542, 43.534469102080486, 43.792836172141214, 44.049687853604595, 44.30505050217188, 44.55894971832258, 44.81141037726887, 45.06245665739941, 45.312112067304916, 45.56039947147084, 45.80734111471654, 46.052958645455135, 46.29727313784258, 46.54030511288039, 46.782074558531505, 47.02260094890541, 47.26190326256445, 47.50000000000001, 47.736909200324234], [0.0, 4.844068537913146, 6.85054742338158, 8.390172823011456, 9.688137075826292, 10.831666538441812, 11.86549619695696, 12.81620068507044, 13.70109484676316, 14.532205613739437, 15.318289721767245, 16.065957799023376, 16.780345646022912, 17.46553749530773, 18.12484482692197, 18.760996775224925, 19.376274151652584, 19.972606239547208, 20.551642270144743, 21.114805232348232, 21.663333076883625, 22.198310746541054, 22.720695411892656, 23.23133659521122, 23.73099239391392, 24.220342689565733, 24.700000000000003, 25.170518469034366, 25.63240137014088, 26.086107413717368, 26.532056083160988, 26.970632176498942, 27.40218969352632, 27.827055180165942, 28.245530619905164, 28.657895945096875, 29.064411227478875, 29.465318596614566, 29.860843926453253, 30.251198323372254, 30.63657944353449, 31.01717266289757, 31.393152119530786, 31.76468164487093, 32.13191559804675, 32.49499961532543, 32.854071285002114, 33.20926075660222, 33.560691292045824, 33.908479765392016, 34.2527371169079, 34.593568766462944, 34.93107499061546, 35.265351267214115, 35.59648859087087, 35.92457376225917, 36.24968965384394, 36.57191545434831, 36.89132689400044, 37.20799645237567, 37.52199355044985, 37.83338472830577, 38.14223380978099, 38.448602055211325, 38.75254830330517, 39.05412910307948, 39.35339883669516, 39.65040983394749, 39.945212479094415, 40.23785531064001, 40.52838511463293, 40.81684701198759, 41.103284540289486, 41.387739730504734, 41.67025317897649, 41.95086411505728, 42.229610464696464, 42.50652891027448, 42.78165494695128, 43.055022935773714, 43.32666615376725, 43.596616841218314, 43.86490624633775, 44.13156466748035, 44.39662149308211, 44.660105239464, 44.92204358664018, 45.18246341225765, 45.44139082378531, 45.698851189061635, 45.95486916530174, 46.20946872665818, 46.46267319042244, 46.71450524194814, 46.964986958371455, 47.21413983119888, 47.46198478782784, 47.70854221206094, 47.953831963671064, 48.19787339707013, 48.440685379131466, 48.68228630621205], [0.0, 4.936344801571301, 6.981045766932058, 8.550000000000002, 9.872689603142602, 11.038002536691138, 12.091525958289965, 13.060340730624144, 13.962091533864116, 14.809034404713902, 15.610092888897235, 16.372003542633383, 17.100000000000005, 17.79824429543544, 18.470110990462402, 19.1183812076232, 19.745379206285204, 20.353071021347123, 20.943137300796177, 21.517028140521642, 22.076005073382277, 22.62117370960225, 23.15350945321249, 23.673878009316514, 24.18305191657993, 24.681724007856506, 25.170518469034366, 25.650000000000002, 26.12068146124829, 26.583030301303125, 27.037473994439644, 27.48440466882992, 27.924183067728233, 28.357141957538673, 28.783589074331925, 29.203809682984854, 29.618068809427804, 30.026613195630308, 30.42967301828924, 30.827463405217113, 31.22018577779447, 31.608029043266843, 31.991170656917202, 32.36977757106156, 32.744007085266766, 33.114007610073415, 33.47991935474159, 33.84187494805807, 34.20000000000001, 34.5544136109991, 34.90522883466029, 35.252553099031005, 35.59648859087088, 35.937132606817705, 36.27457787486989, 36.60891284919562, 36.940221980924804, 37.26858596727276, 37.59408198107783, 37.9167838826027, 38.2367624152464, 38.55408538663575, 38.86881783640969, 39.18102219187244, 39.49075841257041, 39.79808412474148, 40.10305474649032, 40.4057236044598, 40.706142042694246, 41.00435952432375, 41.300423726639906, 41.594380630080316, 41.886274601592355, 42.176148472803916, 42.46404361339132, 42.75000000000001, 43.034056281043284, 43.316249837676395, 43.59661684121832, 43.875192307270865, 44.15201014676455, 44.42710321414171, 44.700503352870655, 44.972241438469574, 45.2423474192045, 45.51085035461324, 45.77777845199568, 46.043159101000015, 46.30701890642498, 46.56938371934935, 46.830278666691704, 47.08972817929617, 47.34775601863303, 47.60438530219669, 47.859638527678, 48.11353759598228, 48.36610383315986, 48.617358011311154, 48.86732036852441, 49.11601062790015, 49.36344801571301, 49.60965127875826], [0.0, 5.026927491022723, 7.109149034870489, 8.706893820416099, 10.053854982045445, 11.240551587889271, 12.313407326974936, 13.299999999999999, 14.218298069740978, 15.080782473068165, 15.896540504147435, 16.672432336045034, 17.413787640832197, 18.12484482692197, 18.809040379562163, 19.469206455323235, 20.10770996409089, 20.72655301780786, 21.32744710461147, 21.911868929874515, 22.481103175778543, 23.03627574066607, 23.578379927382628, 24.10829732685409, 24.62681465394987, 25.134637455113612, 25.63240137014088, 26.12068146124829, 26.599999999999998, 27.070833012672516, 27.533615817759934, 27.988747739046847, 28.436596139481956, 28.87749989178426, 29.311772379028874, 29.7397041007472, 30.16156494613633, 30.577606184919055, 30.988062217570175, 31.393152119530782, 31.79308100829487, 32.18804125758509, 32.57821357901627, 32.9637679885052, 33.34486467209007, 33.721654763667814, 34.09428104536009, 34.4628785797124, 34.827575281664394, 35.188492437159056, 35.54574517435245, 35.89944289261325, 36.24968965384394, 36.596584540090625, 36.940221980924804, 37.28069205366231, 37.618080759124325, 37.952470275332544, 38.28393919125878, 38.61256272251299, 38.93841291064647, 39.261558807566466, 39.58206664639935, 39.900000000000006, 40.21541992818178, 40.528385114632925, 40.838951994388886, 41.14717487264466, 41.45310603561572, 41.75679585408823, 42.05829288023945, 42.357643938255116, 42.65489420922294, 42.9500873107378, 43.24326537161596, 43.53446910208048, 43.82373785974903, 44.11110971172682, 44.396621493082115, 44.68030886195842, 44.962206351557086, 45.2423474192045, 45.52076449270158, 45.79748901413701, 46.07255148133214, 46.34598148707178, 46.61780775626413, 46.888058181161654, 47.156759854765255, 47.423939102525004, 47.68962151244231, 47.95383196367106, 48.21659465370818, 48.47793312425768, 48.73787028584651, 48.99642844126498, 49.25362930789974, 49.50949403902246, 49.76404324409342, 50.0172970081351, 50.269274910227224, 50.519996041171666], [0.0, 5.115906566777779, 7.234984450570713, 8.861010100434378, 10.231813133555558, 11.439514849852682, 12.531360660359276, 13.535416506336258, 14.469968901141426, 15.347719700333336, 16.177917047630082, 16.967542544517165, 17.722020200868755, 18.44566344700022, 19.14196959562939, 19.813820933883502, 20.463626267111117, 21.093423145615795, 21.704953351712142, 22.29971972918046, 22.879029699705363, 23.444029090580827, 23.99572878659867, 24.53502598327542, 25.062721320718552, 25.579532833888898, 26.086107413717368, 26.583030301303125, 27.070833012672516, 27.550000000000004, 28.020974287129988, 28.484162266073405, 28.939937802282852, 29.38864576669024, 29.830605089404408, 30.26611141194058, 30.69543940066667, 31.11884477290248, 31.536566078125883, 31.948826269520453, 32.355834095260164, 32.757785334176674, 33.154863896568784, 33.54724280771819, 33.93508508903433, 34.31854454955804, 34.697766498724384, 35.072888389751995, 35.44404040173751, 35.81134596744445, 36.17492225285357, 36.53488059375589, 36.89132689400044, 37.244361989434054, 37.59408198107782, 37.940578540660134, 38.28393919125878, 38.624247565486634, 38.96158364337877, 39.29602397189823, 39.627641867767004, 39.95650760514487, 40.28268858951696, 40.60624951900878, 40.927252534222234, 41.24575735757558, 41.56182142303198, 41.87549999701496, 42.18684629123159, 42.49591156805558, 42.80274523906148, 43.10739495724603, 43.409906703424284, 43.7103248672439, 44.00869232322179, 44.30505050217187, 44.59943945836092, 44.891897932700516, 45.18246341225765, 45.47117218634242, 45.758059399410726, 46.043159101000015, 46.32650429289912, 46.6081269737371, 46.888058181161654, 47.16632803176436, 47.44296575889834, 47.71799974852258, 47.99145757319734, 48.26336602434605, 48.533751142890246, 48.80263824835703, 49.07005196655084, 49.336016255875386, 49.60055443238514, 49.863689193640695, 50.125442641437104, 50.38583630346926, 50.644891153995, 50.902627633551496, 51.159065667777796, 51.414224685392284], [0.0, 5.203364296299078, 7.358668357794092, 9.012491331479882, 10.406728592598157, 11.635076278220096, 12.745587471748802, 13.766807908879965, 14.717336715588184, 15.610092888897233, 16.454482671904334, 17.257607018355703, 18.024982662959765, 18.760996775224925, 19.469206455323235, 20.152543263816604, 20.813457185196313, 21.454020602208807, 22.076005073382277, 22.680939133995313, 23.27015255644019, 23.84481075622115, 24.405941899463745, 24.954458519471025, 25.491174943497604, 26.01682148149539, 26.532056083160988, 27.037473994439644, 27.53361581775993, 28.020974287129988, 28.499999999999996, 28.97110629575612, 29.434673431176368, 29.891052172849317, 30.34056690307549, 30.78351831743733, 31.220185777794466, 31.650829373019594, 32.07569173065485, 32.49499961532543, 32.90896534380867, 33.317788041825345, 33.721654763667814, 34.12074149252914, 34.515214036711406, 34.905228834660285, 35.29093367991275, 35.672468375485316, 36.04996532591953, 36.42355007409354, 36.793341788970466, 37.1594537096551, 37.52199355044985, 37.88106387101608, 38.2367624152464, 38.58918242202081, 38.93841291064647, 39.28453894345713, 39.627641867767, 39.967799539129, 40.30508652763321, 40.639574308794124, 40.971331440410864, 41.3004237266399, 41.626914370392626, 41.950864115057264, 42.27233137644527, 42.59137236577379, 42.908041204417614, 43.22239003109384, 43.53446910208048, 43.84432688501444, 44.15201014676455, 44.45756403583084, 44.76103215968103, 45.0624566573994, 45.361878267990626, 45.65933639465208, 45.95486916530174, 46.24851348962473, 46.54030511288038, 46.830278666691704, 47.11846771702153, 47.40490480952366, 47.6896215124423, 47.97264845721987, 48.254015376961114, 48.533751142890246, 48.81188379892749, 49.08844059450249, 49.363448015713, 49.636931814929895, 49.90891703894205, 50.179428055728174, 50.448488579936665, 50.71612169714872, 50.98234988699521, 51.24719504519248, 51.51067850455864, 51.772821055067105, 52.03364296299078, 52.293163989186965], [0.0, 5.2893761446885215, 7.480307480311221, 9.16146822294331, 10.578752289377043, 11.827404618089297, 12.956272612136564, 13.994373869523423, 14.960614960622442, 15.868128434065563, 16.726476018576058, 17.542876046988418, 18.32293644588662, 19.0711169048905, 19.791033323199674, 20.485665720205432, 21.157504578754086, 21.808656538173093, 22.44092244093366, 23.055856089072037, 23.654809236178593, 24.23896656212884, 24.80937322868113, 25.36695685335551, 25.912545224273128, 26.446880723442607, 26.970632176498942, 27.484404668829924, 27.988747739046847, 28.484162266073408, 28.971106295756123, 29.45, 29.921229921244883, 30.385152624267004, 30.842097853421063, 31.292371274801145, 31.736256868131125, 32.17401902156459, 32.60590437328798, 33.03214343635605, 33.452952037152116, 33.86853259295419, 34.27907525007056, 34.6847589007045, 35.085752093976836, 35.48221385426788, 35.874294418148494, 36.262135899585395, 36.64587289177324, 37.02563301281965, 37.401537401556105, 37.773701168934984, 38.142233809781, 38.50723957907136, 38.86881783640969, 39.2270633619189, 39.58206664639935, 39.93391415826903, 40.282688589516965, 40.62846908265188, 40.971331440410864, 41.31134831980191, 41.64858941188765, 41.98312160857027, 42.31500915750817, 42.644313806180534, 42.971094936014836, 43.2954096874022, 43.617313076346186, 43.936858103419276, 44.25409585563804, 44.569075601811626, 44.88184488186732, 45.19244959061192, 45.50093405634658, 45.807341114716536, 46.111712178144074, 46.414087301163214, 46.714505241948146, 47.01300352030277, 47.30961847235719, 47.60438530219669, 47.89733813063103, 48.18851004129511, 48.47793312425768, 48.765638517300275, 49.05165644501722, 49.336016255875386, 49.61874645736226, 49.899874749341805, 50.179428055728174, 50.4574325545801, 50.73391370671102, 51.008896282903436, 51.28240438980997, 51.55446149461751, 51.825090448546256, 52.094313509249744, 52.36215236217855, 52.62862814096526, 52.893761446885215, 53.15757236744358], [0.0, 5.374011537017761, 7.6, 9.308061022576078, 10.748023074035522, 12.016655108639842, 13.163586137523469, 14.218298069740976, 15.2, 16.122034611053284, 16.994116628998402, 17.823579887329032, 18.616122045152157, 19.376274151652584, 20.107709964090887, 20.81345718519631, 21.496046148071045, 22.15761720041214, 22.8, 23.424773211282112, 24.033310217279684, 24.626814653949868, 25.20634840670104, 25.772853935876018, 26.327172275046937, 26.87005768508881, 27.40218969352632, 27.92418306772823, 28.436596139481953, 28.939937802282852, 29.434673431176368, 29.92122992124488, 30.4, 30.87134593761665, 31.33560275469422, 31.793081008294866, 32.24406922210657, 32.68883601476198, 33.12763197090912, 33.56069129204582, 33.988233257996804, 34.410463524922186, 34.82757528166439, 35.239750282883676, 35.647159774658064, 36.04996532591952, 36.44831957717667, 36.8423669163641, 37.23224409030431, 37.618080759124325, 38.00000000000001, 38.3781187657759, 38.75254830330517, 39.1233945357506, 39.4907584125704, 39.854736230465754, 40.215419928181774, 40.572897357718986, 40.927252534222234, 41.27856586656082, 41.62691437039262, 41.97237186531159, 42.315009157508165, 42.65489420922293, 42.99209229614209, 43.32666615376724, 43.65867611368902, 43.98818023060286, 44.31523440082428, 44.63989247298878, 44.962206351557086, 45.282226093689346, 45.6, 45.91557469965937, 46.22899523026646, 46.54030511288038, 46.849546422564224, 47.156759854765255, 47.46198478782783, 47.765259341910834, 48.06662043455937, 48.36610383315985, 48.66374420448966, 48.95957516155547, 49.253629307899736, 49.54593827954013, 49.8365327846952, 50.1254426414371, 50.41269681340208, 50.69832344368007, 50.9823498869952, 51.26480274028175, 51.545707871752036, 51.825090448546256, 52.10297496304794, 52.37938525794284, 52.654344550093874, 52.927875453299656, 53.2, 53.470739661987096, 53.74011537017762, 54.00814753349721], [0.0, 5.457334514211128, 7.717836484404163, 9.452380652512893, 10.914669028422257, 12.202970949731874, 13.367684915496778, 14.43874994589213, 15.435672968808326, 16.372003542633383, 17.257607018355703, 18.09993093909477, 18.904761305025787, 19.676699418347585, 20.419475997194443, 21.13616568822264, 21.829338056844513, 22.501166636421324, 23.15350945321249, 23.787969648542944, 24.40594189946375, 25.00864850406755, 25.597167812084212, 26.172456896516234, 26.735369830993555, 27.286672571055643, 27.827055180165942, 28.357141957538673, 28.87749989178426, 29.388645766690242, 29.89105217284932, 30.385152624267004, 30.871345937616653, 31.350000000000005, 31.821455026444035, 32.28602638913621, 32.744007085266766, 33.19566989834669, 33.641269298288975, 34.08104311783899, 34.515214036711406, 34.94399089972409, 35.36756989107395, 35.786135583490996, 36.19986187818954, 36.60891284919562, 37.0134435036785, 37.413600468278915, 37.80952261005157, 38.20134159947789, 38.58918242202082, 38.97316384385544, 39.35339883669517, 39.72999496602033, 40.10305474649033, 40.47267596786751, 40.838951994388886, 41.201972040182746, 41.56182142303199, 41.9185817985294, 42.27233137644528, 42.62314512093166, 42.971094936014836, 43.316249837676395, 43.658676113689026, 43.99843747225576, 44.33559518039653, 44.670208192933245, 45.00233327284265, 45.33202510367257, 45.65933639465209, 45.98431797906761, 46.30701890642498, 46.627486528870506, 46.945766582302184, 47.26190326256445, 47.57593929708589, 47.887916012288535, 48.19787339707013, 48.50585016263503, 48.8118837989275, 49.11601062790015, 49.418265853831834, 49.71868361089219, 50.0172970081351, 50.31413817208838, 50.60923828709537, 50.9026276335515, 51.194335624168424, 51.48439083838907, 51.77282105506711, 52.05965328351698, 52.34491379303247, 52.62862814096526, 52.91082119944843, 53.19151718084379, 53.47073966198711, 53.74851160729943, 54.024855390829146, 54.29979281728431, 54.573345142111286, 54.845533090672035], [0.0, 5.539404300103036, 7.833900688673555, 9.594529691443975, 11.078808600206072, 12.386484569885033, 13.568714014231416, 14.655886189514437, 15.66780137734711, 16.618212900309107, 17.517134468856487, 18.372125625523033, 19.18905938288795, 19.97260623954721, 20.726553017807856, 21.454020602208807, 22.157617200412144, 22.839549032325486, 23.501702066020666, 24.145703551563788, 24.772969139770066, 25.384739510186037, 25.98210922923695, 26.56604976280817, 27.137428028462832, 27.69702150051518, 28.245530619905164, 28.783589074331925, 29.311772379028874, 29.830605089404408, 30.34056690307549, 30.84209785342106, 31.33560275469422, 31.82145502644403, 32.300000000000004, 32.77155779025465, 33.236425800618214, 33.69488091683958, 34.147181435661714, 34.59356876646294, 35.03426893771297, 35.469493934929496, 35.89944289261325, 36.324303159179806, 36.744251251046066, 37.1594537096551, 37.57006787324186, 37.9762425734827, 38.3781187657759, 38.775830100721244, 39.16950344336778, 39.559259345948334, 39.94521247909442, 40.32747202590314, 40.706142042694246, 41.08132178983534, 41.45310603561571, 41.82158533580477, 42.18684629123159, 42.54897178546152, 42.908041204417614, 43.264130639595656, 43.617313076346186, 43.967658568543314, 44.31523440082429, 44.660105239464, 45.00233327284264, 45.34197834237055, 45.67909806465097, 46.01374794558687, 46.34598148707178, 46.67585028684534, 47.00340413204133, 47.32869108690837, 47.65175757514092, 47.972648457219876, 48.291407103127575, 48.60807546077093, 48.92269412041819, 49.23530237542977, 49.54593827954013, 49.854638700927325, 50.161439373287536, 50.46637494411502, 50.769479020372074, 51.07078421171933, 51.37032217146395, 51.66812363537117, 51.9642184584739, 52.25863565000525, 52.551403406569456, 52.84254914365884, 53.13209952561634, 53.420080494136286, 53.70651729538977, 53.99143450585472, 54.274856056925664, 54.55680525837268, 54.83730482071489, 55.1163768765691, 55.39404300103036, 55.670324231137734], [0.0, 5.620275793944636, 7.948270252073717, 9.734603227661621, 11.240551587889271, 12.567318727556806, 13.766807908879969, 14.8698520503736, 15.896540504147435, 16.860827381833904, 17.77287258717622, 18.640346026831153, 19.469206455323242, 20.264192557316466, 21.02914644011972, 21.76723455104024, 22.481103175778543, 23.172990743535888, 23.844810756221154, 24.498214220632494, 25.134637455113612, 25.755339252279324, 26.361430158472054, 26.953895822311104, 27.533615817759937, 28.10137896972318, 28.65789594509688, 29.203809682984858, 29.7397041007472, 30.266111411940585, 30.783518317437334, 31.292371274801145, 31.79308100829487, 32.28602638913621, 32.77155779025465, 33.25, 33.72165476366781, 34.1868030093485, 34.645706804739895, 35.09861108363122, 35.54574517435244, 35.98732415726404, 36.42355007409355, 36.85461300841456, 37.28069205366231, 37.701956182670415, 38.11856503070387, 38.53066960227917, 38.938412910646484, 39.34193055761244, 39.741351260368596, 40.13679733112746, 40.52838511463293, 40.916225387980255, 41.3004237266399, 41.68108084011258, 42.05829288023944, 42.43215172484186, 42.80274523906148, 43.1701575165067, 43.53446910208048, 43.8957571981621, 44.254095855638035, 44.609556151120806, 44.962206351557086, 45.312112067304916, 45.65933639465208, 46.00394004865235, 46.345981487071775, 46.685517026161335, 47.02260094890541, 47.35728560633517, 47.68962151244231, 48.01965743318042, 48.34744046999799, 48.67301613830809, 48.99642844126499, 49.31771993918616, 49.6369318149299, 49.95410393551265, 50.269274910227224, 50.582482145501714, 50.89376189671973, 51.20314931720508, 51.51067850455865, 51.81638254451964, 52.12029355251177, 52.422442713021304, 52.72286031694411, 53.021575797028135, 53.318617761528664, 53.61401402618535, 53.90779164462221, 54.199976937264466, 54.490595518859955, 54.77967232468628, 55.067231635519875, 55.35329710143742, 55.63789176451603, 55.92103808049347, 56.20275793944636, 56.48307268554005], [0.0, 5.7, 8.061017305526642, 9.872689603142602, 11.4, 12.7455874717488, 13.962091533864116, 15.080782473068165, 16.122034611053284, 17.099999999999998, 18.02498266295976, 18.90476130502578, 19.745379206285204, 20.55164227014474, 21.327447104611462, 22.076005073382277, 22.8, 23.501702066020666, 24.183051916579927, 24.84572397818184, 25.4911749434976, 26.12068146124829, 26.735369830993548, 27.3362396828825, 27.924183067728233, 28.500000000000004, 29.064411227478875, 29.6180688094278, 30.16156494613633, 30.695439400666675, 31.220185777794466, 31.73625686813112, 32.24406922210657, 32.744007085266766, 33.236425800618214, 33.72165476366781, 34.199999999999996, 34.67174642269985, 35.137159816923166, 35.59648859087087, 36.04996532591952, 36.49780815336724, 36.940221980924804, 37.3773995885214, 37.80952261005156, 38.2367624152464, 38.65928090381403, 39.07723122228595, 39.49075841257041, 39.9, 40.305086527633215, 40.706142042694246, 41.10328454028948, 41.49662636889895, 41.88627460159235, 42.27233137644528, 42.654894209222924, 43.03405628104328, 43.40990670342428, 43.78253076285107, 44.15201014676455, 44.51842315266793, 44.881844881867316, 45.2423474192045, 45.6, 45.95486916530173, 46.30701890642497, 46.656510799672965, 47.00340413204133, 47.34775601863303, 47.68962151244231, 48.02905370710524, 48.366103833159855, 48.70082134830992, 49.03325402214297, 49.363448015713004, 49.69144795636368, 50.017297008135095, 50.34103693806873, 50.66270817869886, 50.9823498869952, 51.3, 51.61569528738328, 51.9294714011225, 52.24136292249658, 52.551403406569456, 52.85962542432551, 53.16606060260625, 53.470739661987096, 53.773692452722635, 54.07494798887929, 54.374534480765895, 54.672479365765, 54.96880933765984, 55.263550374546156, 55.55672776541109, 55.848366135456466, 56.1384894702378, 56.427121138686495, 56.71428391507734, 57.00000000000001, 57.28429104038908], [0.0, 5.77862440378331, 8.172209003690496, 10.008871065210105, 11.55724880756662, 12.921396983298672, 14.154681204463774, 15.288803092459528, 16.34441800738099, 17.335873211349927, 18.273614858587777, 19.165528951740416, 20.01774213042021, 20.835126589488247, 21.62163268580798, 22.38051607984052, 23.11449761513324, 23.82587878757046, 24.51662701107149, 25.188439808769424, 25.842793966597345, 26.480983743056075, 27.104150973605503, 27.713309077048162, 28.309362408927548, 28.893122018916547, 29.465318596614566, 30.026613195630308, 30.577606184919055, 31.118844772902484, 31.650829373019594, 32.17401902156459, 32.68883601476198, 33.19566989834669, 33.69488091683958, 34.1868030093485, 34.671746422699854, 35.15, 35.621833192580084, 36.0874978351229, 36.547229717175554, 37.00124997888585, 37.44976635441135, 37.89297428284035, 38.33105790348083, 38.76419094989601, 39.192537554998914, 39.616252977786786, 40.03548426084042, 40.45037082648316, 40.86104501845249, 41.267632595049605, 41.670253178976495, 42.069020668420606, 42.46404361339132, 42.855425560831854, 43.24326537161596, 43.627657512179134, 44.00869232322179, 44.38645626764993, 44.76103215968104, 45.13249937683487, 45.50093405634658, 45.86640927737859, 46.22899523026648, 46.58875937390906, 46.94576658230218, 47.30007928111749, 47.65175757514092, 48.00085936730717, 48.347440469998, 48.6915547092101, 49.03325402214298, 49.372588548707874, 49.70960671741429, 50.044355326050514, 50.37687961753885, 50.70722335131357, 51.03542887054052, 51.36153716547043, 51.68558793319469, 52.00761963404978, 52.327669544897574, 52.64577380949016, 52.96196748611215, 53.27628459267782, 53.58875814944773, 53.89942021951629, 54.208301947211005, 54.515433594533576, 54.82084457576334, 55.124563490335234, 55.426618154096325, 55.72703562903737, 56.02584225158959, 56.323063659570224, 56.618724817855096, 56.912850042850614, 57.205463025833474, 57.496586855221246, 57.78624403783309, 58.074456519196126], [0.0, 5.856193302820528, 8.28190799272728, 10.143224339429748, 11.712386605641056, 13.09484631448571, 14.344685427014426, 15.494031108785085, 16.56381598545456, 17.568579908461583, 18.518909255137032, 19.42279588524783, 20.286448678859497, 21.11480523234823, 21.91186892987451, 22.680939133995313, 23.424773211282112, 24.145703551563788, 24.84572397818184, 25.526554800834372, 26.18969262897142, 26.836449094468517, 27.467981360121826, 28.08531644827952, 28.68937085402885, 29.280966514102644, 29.860843926453253, 30.42967301828924, 30.98806221757017, 31.536566078125883, 32.07569173065485, 32.60590437328798, 33.12763197090912, 33.641269298288975, 34.147181435661714, 34.64570680473989, 35.137159816923166, 35.621833192580084, 36.1, 36.5719154543483, 37.037818510274064, 37.49793327638205, 37.952470275332544, 38.4016275696747, 38.84559177049566, 39.284538943457136, 39.71863542469706, 40.14803855731934, 40.57289735771899, 40.993353119743695, 41.409539963636405, 41.82158533580477, 42.22961046469646, 42.633730777402064, 43.03405628104328, 43.430691912517354, 43.82373785974902, 44.21328985723637, 44.59943945836091, 44.98227428665652, 45.361878267990626, 45.738331845400744, 46.11171217814407, 46.48209332635526, 46.849546422564224, 47.21413983119887, 47.575939297085874, 47.93500808386288, 48.291407103127575, 48.64519503507002, 48.99642844126499, 49.3451618702381, 49.69144795636368, 50.035337512602034, 50.37687961753884, 50.716121697148736, 51.053109601668744, 51.38788767793439, 51.720498837501566, 52.05098462085036, 52.37938525794284, 52.70573972538475, 53.03008580042089, 53.35246011197609, 53.67289818893703, 53.99143450585473, 54.30810252623452, 54.6229347435672, 54.93596272024365, 55.247217124485104, 55.5567277654111, 55.864523626358796, 56.17063289655904, 56.47508300126703, 56.777900630438964, 57.07911176603925, 57.3787417080577, 57.67681509931006, 57.973355949090966, 58.268387655743496, 58.56193302820529, 58.85401430658746], [0.0, 5.932748098478479, 8.390172823011456, 10.275821135072373, 11.865496196956958, 13.266028041580496, 14.532205613739439, 15.696576059765391, 16.780345646022912, 17.798244295435435, 18.760996775224925, 19.67669941834758, 20.551642270144747, 21.39082747347564, 22.198310746541054, 22.97743458265087, 23.730992393913915, 24.461347060209096, 25.170518469034366, 25.860249418750787, 26.53205608316099, 27.187267240382955, 27.827055180165942, 28.452460350556684, 29.064411227478878, 29.663740492392396, 30.251198323372254, 30.827463405217113, 31.393152119530782, 31.948826269520456, 32.49499961532543, 33.03214343635605, 33.560691292045824, 34.08104311783899, 34.59356876646294, 35.09861108363121, 35.59648859087087, 36.0874978351229, 36.57191545434831, 37.050000000000004, 37.52199355044985, 37.98812314395119, 38.448602055211325, 38.90363093594222, 39.35339883669516, 39.798084124741486, 40.23785531064001, 40.672871794354535, 41.10328454028949, 41.52923668934935, 41.95086411505728, 42.36829592985775, 42.78165494695128, 43.19105810234336, 43.596616841218314, 43.998437472255766, 44.39662149308211, 44.791265889679885, 45.18246341225765, 45.57030282980354, 45.95486916530174, 46.33624391337736, 46.71450524194814, 47.08972817929618, 47.46198478782783, 47.8313443256616, 48.197873397070126, 48.561636092701825, 48.92269412041819, 49.28110692750317, 49.63693181492991, 49.990224044306906, 50.34103693806873, 50.68942197342558, 51.035428870540514, 51.379105675361856, 51.72049883750157, 52.05965328351699, 52.396612485923185, 52.73141852823609, 53.06411216632198, 53.39473288630631, 53.72331895927505, 54.04990749298282, 54.37453448076591, 54.697234847842175, 55.01804249516699, 55.336990341000664, 55.654110360331885, 55.96943362229066, 56.282990325674774, 56.59480983270463, 56.90492070111337, 57.21335071467149, 57.520126912238304, 57.82527561542617, 58.128822454957756, 58.430792395790775, 58.73120976108019, 59.03009825504275, 59.32748098478479, 59.62338048115019], [0.0, 6.008327554319921, 8.497058314499201, 10.406728592598158, 12.016655108639842, 13.435028842544403, 14.717336715588186, 15.896540504147435, 16.994116628998402, 18.02498266295976, 19.0, 19.92736811523288, 20.813457185196317, 21.663333076883625, 22.48110317577854, 23.27015255644019, 24.033310217279684, 24.772969139770066, 25.491174943497604, 26.189692628971425, 26.870057685088806, 27.533615817759934, 28.18155425096352, 28.814926687395893, 29.43467343117637, 30.041637771599607, 30.63657944353449, 31.22018577779447, 31.79308100829487, 32.355834095260164, 32.90896534380867, 33.452952037152116, 33.988233257996804, 34.515214036711406, 35.03426893771297, 35.54574517435244, 36.04996532591952, 36.547229717175554, 37.037818510274064, 37.52199355044985, 38.0, 38.472067789501516, 38.93841291064648, 39.39923857132267, 39.85473623046576, 40.30508652763321, 40.750460120101714, 41.19101843848972, 41.62691437039263, 42.05829288023944, 42.48529157249601, 42.90804120441762, 43.32666615376725, 43.741284846241086, 44.15201014676455, 44.55894971832258, 44.96220635155708, 45.361878267990626, 45.758059399410726, 46.15083964566625, 46.54030511288038, 46.92653833386818, 47.30961847235718, 47.68962151244231, 48.06662043455937, 48.44068537913145, 48.81188379892749, 49.18028060107018, 49.54593827954013, 49.90891703894205, 50.269274910227224, 50.62706785900207, 50.98234988699521, 51.33517312720392, 51.68558793319468, 52.03364296299078, 52.37938525794285, 52.722860316944114, 53.06411216632198, 53.40318342570975, 53.74011537017761, 54.07494798887929, 54.40772004045015, 54.73846910537414, 55.06723163551987, 55.394043001030354, 55.718937534737684, 56.04194857425998, 56.36310850192704, 56.68244878266993, 57.0, 57.31579189019375, 57.629853374791786, 57.942212591512245, 58.252896923672395, 58.561933028205274, 58.86934686235274, 59.175163709110265, 59.47940820149441, 59.78210434569864, 60.083275543199214, 60.38294461186868], [0.0, 6.0829680255612075, 8.602615881230546, 10.536009681088949, 12.165936051122415, 13.601930010112536, 14.900167784290218, 16.094020628792546, 17.205231762461093, 18.24890407668362, 19.236033894750758, 20.17492255251554, 21.072019362177898, 21.932453123168877, 22.760382246350787, 23.559233858510765, 24.33187210224483, 25.080719686643764, 25.80784764369164, 26.515042900210446, 27.203860020225072, 27.8756614271303, 28.531649093594293, 29.172889812289768, 29.800335568580437, 30.414840127806038, 31.01717266289757, 31.608029043266843, 32.18804125758509, 32.757785334176674, 33.317788041825345, 33.86853259295419, 34.410463524922186, 34.94399089972409, 35.469493934929496, 35.98732415726404, 36.49780815336724, 37.00124997888585, 37.49793327638205, 37.98812314395119, 38.472067789501516, 38.95, 39.42213845036822, 39.88868887291233, 40.34984510503108, 40.80579003033761, 41.25669642615609, 41.702727728531144, 42.144038724355795, 42.580776178928446, 43.01307940615274, 43.44108078765998, 43.86490624633775, 44.28467567906533, 44.700503352870655, 45.11249826821831, 45.52076449270157, 45.92540146803292, 46.32650429289912, 46.72416398396017, 47.11846771702153, 47.50949905018995, 47.89733813063102, 48.28206188637764, 48.66374420448966, 49.04245609673317, 49.41826585383183, 49.79123918923891, 50.16143937328753, 50.528927358494364, 50.893761896719724, 51.25599964882161, 51.61569528738328, 51.97290159304173, 52.32766954489757, 52.68004840544474, 53.03008580042089, 53.37782779394457, 53.72331895927504, 54.066602445502355, 54.407720040450144, 54.74671223005086, 55.08361825443207, 55.41847616093391, 55.7513228542606, 56.082194143952684, 56.41112478935339, 56.738148542228636, 57.063298187188586, 57.386605580048034, 57.70810168425228, 58.02781660548672, 58.345779624579535, 58.662019228799146, 58.976563141641286, 59.289438351193716, 59.60067113716087, 59.91028709662474, 60.21831116861383, 60.52476765754662, 60.829680255612075, 61.13307206414546], [0.0, 6.156703663487468, 8.706893820416097, 10.663723552305736, 12.313407326974936, 13.766807908879969, 15.080782473068169, 16.289106789508136, 17.413787640832194, 18.470110990462402, 19.46920645532324, 20.419475997194446, 21.327447104611473, 22.198310746541058, 23.036275740666067, 23.844810756221154, 24.62681465394987, 25.384739510186037, 26.120681461248292, 26.83644909446852, 27.533615817759937, 28.21356056934325, 28.877499891784264, 29.526513509048105, 30.161564946136338, 30.78351831743734, 31.393152119530786, 31.991170656917202, 32.57821357901627, 33.154863896568784, 33.721654763667814, 34.27907525007056, 34.82757528166439, 35.36756989107395, 35.89944289261325, 36.42355007409355, 36.940221980924804, 37.449766354411345, 37.952470275332544, 38.448602055211325, 38.93841291064648, 39.422138450368216, 39.900000000000006, 40.37220578566398, 40.83895199438889, 41.3004237266399, 41.75679585408824, 42.208233793893825, 42.654894209222945, 43.09692564441227, 43.53446910208049, 43.96765856854332, 44.396621493082115, 44.82147922592471, 45.242347419204506, 45.65933639465209, 46.072551481332134, 46.48209332635526, 46.88805818116166, 47.29053816568384, 47.68962151244231, 48.0853927924063, 48.47793312425768, 48.86732036852441, 49.25362930789974, 49.6369318149299, 50.0172970081351, 50.39479139752441, 50.769479020372074, 51.14142156804014, 51.510678504558655, 51.877307177608984, 52.241362922496585, 52.60289915964709, 52.961967486112144, 53.31861776152867, 53.67289818893704, 54.024855390829146, 54.37453448076592, 54.72197913087575, 55.067231635519875, 55.41033297138721, 55.751322854260614, 56.09023979267695, 56.4271211386865, 56.7620031359007, 57.09492096500354, 57.42590878688818, 57.75499978356853, 58.08222619700454, 58.407619365969715, 58.73120976108019, 59.05302701809621, 59.37309996959903, 59.691456675139044, 60.008124449944276, 60.323129892272675, 60.63649890948521, 60.94825674291268, 61.25842799158334, 61.56703663487468, 61.874106054148385], [0.0, 6.2295665980869, 8.809937570720917, 10.78992585702052, 12.4591331961738, 13.929734383684421, 15.25925948399856, 16.4818839942526, 17.619875141441835, 18.6886997942607, 19.699619285661335, 20.661135012384968, 21.57985171404104, 22.46102179332009, 23.30890387813206, 24.127007688480557, 24.9182663923476, 25.68516108573197, 26.429812712162757, 27.15405126311726, 27.859468767368842, 28.547460482501766, 29.219257348536424, 29.875951867681135, 30.51851896799712, 31.147832990434505, 31.764681644870926, 32.36977757106156, 32.9637679885052, 33.54724280771819, 34.12074149252914, 34.684758900704495, 35.23975028288367, 35.78613558349099, 36.324303159179806, 36.85461300841456, 37.3773995885214, 37.89297428284034, 38.4016275696747, 38.90363093594221, 39.39923857132267, 39.888688872912326, 40.37220578566398, 40.849999999999994, 41.322270024769935, 41.78920315105326, 42.25097632008046, 42.707756906679144, 43.15970342808208, 43.6069661866083, 44.049687853604595, 44.488004001078764, 44.92204358664018, 45.35192939666404, 45.77777845199568, 46.199702379993745, 46.61780775626412, 47.03219641904894, 47.44296575889834, 47.850208985959505, 48.254015376961114, 48.65447050374713, 49.051656445017215, 49.445651982757795, 49.8365327846952, 50.22437157396794, 50.609238287095366, 50.99120022121463, 51.37032217146394, 51.746666559306014, 52.12029355251177, 52.491261177456956, 52.859625424325515, 53.225440345759466, 53.58875814944772, 53.949629285102596, 54.30810252623452, 54.66422504710005, 55.01804249516699, 55.369599059411655, 55.718937534737684, 56.0660993827821, 56.41112478935339, 56.754052718726605, 57.09492096500353, 57.43376620072899, 57.77062402294093, 58.105528996817505, 58.43851469707285, 58.769613747241856, 59.098857856984, 59.42627785752696, 59.75190373536227, 60.07576466429703, 60.39788903595887, 60.71830448884421, 61.03703793599424, 61.35411559137659, 61.66956299504643, 61.9834050371549, 62.29566598086901, 62.606369484262544], [0.0, 6.301587101675261, 8.911789943664516, 10.914669028422258, 12.603174203350521, 14.090777125481761, 15.435672968808328, 16.672432336045034, 17.823579887329032, 18.90476130502578, 19.92736811523288, 20.900000000000002, 21.829338056844517, 22.72069541189266, 23.578379927382628, 24.405941899463745, 25.206348406701043, 25.982109229236954, 26.73536983099355, 27.46798136012183, 28.181554250963522, 28.877499891784264, 29.55706345359769, 30.22135006911505, 30.871345937616656, 31.507935508376306, 32.13191559804675, 32.744007085266766, 33.34486467209007, 33.93508508903433, 34.515214036711406, 35.085752093976836, 35.647159774658064, 36.19986187818954, 36.744251251046066, 37.28069205366231, 37.80952261005156, 38.33105790348083, 38.845591770495666, 39.35339883669516, 39.85473623046576, 40.34984510503108, 40.83895199438889, 41.32227002476994, 41.800000000000004, 42.27233137644528, 42.73944314096758, 43.20150460342788, 43.65867611368903, 44.11110971172682, 44.55894971832259, 45.00233327284265, 45.44139082378532, 45.87624657706862, 46.30701890642498, 46.73382072974561, 47.156759854765255, 47.57593929708588, 47.991457573197344, 48.40340897085659, 48.81188379892749, 49.216968618556756, 49.61874645736226, 50.0172970081351, 50.412696813402086, 50.80501943705956, 51.194335624168424, 51.58071344989327, 51.96421845847391, 52.34491379303247, 52.722860316944114, 53.098116727432064, 53.4707396619871, 53.840783798158064, 54.208301947211005, 54.57334514211128, 54.93596272024366, 55.29620240124995, 55.65411036033189, 56.00973129733797, 56.363108501927044, 56.714283915077345, 57.0632981871886, 57.41019073300489, 57.75499978356853, 58.097762435398494, 58.43851469707286, 58.777291533380485, 59.11412690719538, 59.44905381921566, 59.78210434569864, 60.11330967431422, 60.4427001382301, 60.770305248534015, 61.09615372509141, 61.42027352592953, 61.74269187523331, 62.063435290032096, 62.38252960565162, 62.70000000000001, 63.01587101675261, 63.33016658749605], [0.0, 6.3727937358744, 9.01249133147988, 11.03800253669114, 12.7455874717488, 14.249999999999998, 15.610092888897235, 16.860827381833904, 18.02498266295976, 19.118381207623198, 20.152543263816604, 21.13616568822264, 22.07600507338228, 22.97743458265087, 23.84481075622115, 24.6817240078565, 25.4911749434976, 26.275701703284728, 27.037473994439644, 27.77836388270555, 28.499999999999996, 29.203809682984854, 29.891052172849317, 30.562845090076284, 31.22018577779447, 31.863968679372004, 32.49499961532543, 33.114007610073415, 33.72165476366781, 34.31854454955804, 34.905228834660285, 35.48221385426788, 36.04996532591952, 36.60891284919561, 37.1594537096551, 37.70195618267041, 38.236762415246396, 38.76419094989601, 39.28453894345713, 39.79808412474148, 40.30508652763321, 40.805790030337604, 41.3004237266399, 41.78920315105326, 42.27233137644528, 42.74999999999999, 43.22239003109384, 43.689672692754286, 44.15201014676456, 44.6095561511208, 45.06245665739941, 45.51085035461324, 45.95486916530174, 46.39463869888416, 46.8302786666917, 47.261903262564445, 47.6896215124423, 48.11353759598227, 48.533751142890246, 48.95035750635535, 49.363448015713, 49.773110210232986, 50.17942805572817, 50.582482145501714, 50.9823498869952, 51.37910567536184, 51.772821055067105, 52.1635648705109, 52.551403406569456, 52.93640051986912, 53.318617761528664, 53.698114492037796, 54.07494798887929, 54.449173547446975, 54.820844575763324, 55.190012683455684, 55.5567277654111, 55.92103808049346, 56.282990325674774, 56.6426297059026, 56.99999999999999, 57.355143622869605, 57.70810168425228, 58.05891404427057, 58.40761936596971, 58.75425516505166, 59.098857856984, 59.4414628016505, 59.782104345698635, 60.1208158627276, 60.45762979144981, 60.79257767194939, 61.12569018015257, 61.4569971606163, 61.78652765773458, 62.11430994545459, 62.44037155558894, 62.76473930480393, 63.08743932035917, 63.40849706466792, 63.72793735874401, 64.04578440459606], [0.0, 6.443213483969005, 9.112079894294167, 11.159973118247196, 12.88642696793801, 14.407463343697946, 15.782585339544344, 17.047140522680042, 18.224159788588334, 19.329640451907014, 20.375230060050857, 21.369721570483787, 22.319946236494392, 23.23133659521122, 24.10829732685409, 24.954458519471025, 25.77285393587602, 26.56604976280817, 27.336239682882503, 28.08531644827952, 28.814926687395893, 29.5265135090481, 30.221350069115047, 30.90056633785213, 31.565170679088688, 32.216067419845025, 32.85407128500211, 33.47991935474158, 34.094281045360084, 34.697766498724384, 35.29093367991275, 35.874294418148494, 36.44831957717667, 37.0134435036785, 37.57006787324186, 38.11856503070387, 38.65928090381403, 39.192537554998914, 39.71863542469706, 40.23785531064001, 40.750460120101714, 41.25669642615608, 41.75679585408823, 42.25097632008046, 42.73944314096757, 43.22239003109384, 43.7, 44.17244616273815, 44.639892472988784, 45.10249438778303, 45.560399471470845, 46.01374794558688, 46.46267319042244, 46.90730220338833, 47.34775601863303, 47.78415009184531, 48.21659465370818, 48.64519503507002, 49.07005196655084, 49.4912618549982, 49.90891703894205, 50.32310602496631, 50.733913706711014, 51.14142156804013, 51.54570787175204, 51.9468478350708, 52.34491379303246, 52.73997535077164, 53.13209952561634, 53.521350879812445, 53.907791644622215, 54.291481836472286, 54.67247936576501, 55.050840138911596, 55.426618154096325, 55.79986559123597, 56.17063289655904, 56.538968862192746, 56.90492070111337, 57.26853411778584, 57.629853374791786, 57.98892135572105, 58.34577962457954, 58.700468481946544, 59.0530270180962, 59.40349316328123, 59.751903735362276, 60.09829448495191, 60.442700138230094, 60.78515443757629, 61.12569018015257, 61.46433925456289, 61.80113267570426, 62.13610061791776, 62.46927244653968, 62.80067674794596, 63.130341358177375, 63.458293390226004, 63.784559260059176, 64.10916471145136, 64.43213483969005, 64.7534941142175], [0.0, 6.512871870380993, 9.210591729091025, 11.280624982686025, 13.025743740761985, 14.563224230918097, 15.953212842559333, 17.2314392898562, 18.42118345818205, 19.538615611142976, 20.59550921924486, 21.60075230171394, 22.56124996537205, 23.482493479185727, 24.368935142923252, 25.224244289968333, 26.05148748152397, 26.853258647694883, 27.631775187273078, 28.388950315219482, 29.126448461836194, 29.845728337569515, 30.548076862545702, 31.234636223269835, 31.906425685118666, 32.56435935190496, 33.20926075660222, 33.84187494805806, 34.4628785797124, 35.072888389751995, 35.672468375485316, 36.262135899585395, 36.8423669163641, 37.413600468278915, 37.9762425734827, 38.53066960227917, 39.07723122228595, 39.61625297778678, 40.14803855731934, 40.67287179435453, 41.19101843848972, 41.702727728531144, 42.20823379389382, 42.707756906679144, 43.20150460342788, 43.68967269275429, 44.17244616273815, 44.650000000000006, 45.1224999307441, 45.59010309266694, 46.052958645455135, 46.51120832659586, 46.964986958371455, 47.41442291117757, 47.859638527677994, 48.30075051176741, 48.737870285846505, 49.17110431950863, 49.60055443238513, 50.026318073590026, 50.448488579936665, 50.867155414864705, 51.282404389809955, 51.69431786956861, 52.10297496304794, 52.50845170065482, 52.910821199448414, 53.31015381707316, 53.706517295389766, 54.09997689463462, 54.490595518859955, 54.87843383333748, 55.263550374546156, 55.64600165330839, 56.02584225158957, 56.40312491343011, 56.777900630438964, 57.15021872224113, 57.520126912238304, 57.88767139901208, 58.25289692367239, 58.61584683342893, 58.976563141641286, 59.33508658458332, 59.69145667513903, 60.04571175362983, 60.39788903595886, 60.74802465924304, 61.096153725091405, 61.44231034067648, 61.78652765773458, 62.128837909621325, 62.46927244653967, 62.80786176904927, 63.1446355599587, 63.47962271469483, 63.81285137023733, 64.14434893270023, 64.47414210363718, 64.80225690514182, 65.12871870380992, 65.45355223362596], [0.0, 6.581793068761735, 9.308061022576078, 11.400000000000004, 13.16358613752347, 14.717336715588186, 16.122034611053287, 17.413787640832194, 18.616122045152157, 19.745379206285204, 20.813457185196317, 21.829338056844513, 22.800000000000008, 23.73099239391392, 24.62681465394987, 25.491174943497604, 26.32717227504694, 27.137428028462836, 27.924183067728237, 28.689370854028855, 29.43467343117637, 30.161564946136338, 30.871345937616653, 31.56517067908869, 32.244069222106575, 32.908965343808674, 33.560691292045824, 34.2, 34.82757528166439, 35.4440404017375, 36.04996532591953, 36.64587289177323, 37.23224409030431, 37.809522610051566, 38.3781187657759, 38.93841291064648, 39.49075841257041, 40.03548426084041, 40.572897357718986, 41.103284540289486, 41.62691437039263, 42.14403872435579, 42.65489420922294, 43.15970342808208, 43.658676113689026, 44.15201014676456, 44.639892472988784, 45.12249993074409, 45.600000000000016, 46.07255148133214, 46.5403051128804, 47.00340413204134, 47.46198478782784, 47.916176809090274, 48.366103833159855, 48.8118837989275, 49.25362930789974, 49.69144795636369, 50.125442641437104, 50.55571184347028, 50.98234988699521, 51.405447182181, 51.825090448546256, 52.241362922496585, 52.65434455009388, 53.064112166321976, 53.4707396619871, 53.874298139279745, 54.27485605692567, 54.672479365765014, 55.067231635519875, 55.459174173440424, 55.84836613545647, 56.23486463040523, 56.618724817855096, 57.00000000000001, 57.37874170805771, 57.754999783568536, 58.12882245495776, 58.500256409694494, 58.86934686235274, 59.236137618855615, 59.60067113716088, 59.9629885846261, 60.323129892272675, 60.681133806150996, 61.03703793599425, 61.39087880133336, 61.742691875233305, 62.09251162579913, 62.440371555588946, 62.78630423906157, 63.13034135817738, 63.47251373626226, 63.81285137023735, 64.1513834613097, 64.48813844421315, 64.82314401508154, 65.15642715803254, 65.48801417053355, 65.81793068761735, 66.14620170501101], [0.0, 6.65, 9.404520189781081, 11.518137870333037, 13.3, 14.869852050373602, 16.289106789508136, 17.594246218579528, 18.809040379562163, 19.95, 21.02914644011972, 22.05555485586341, 23.036275740666074, 23.976915981835532, 24.882021622046707, 25.75533925227932, 26.6, 27.418652410357442, 28.213560569343247, 28.986677974545483, 29.739704100747204, 30.474128371456338, 31.191264802825806, 31.892279630029584, 32.57821357901627, 33.25000000000001, 33.90847976539202, 34.554413610999106, 35.188492437159056, 35.81134596744445, 36.42355007409355, 37.02563301281965, 37.618080759124325, 38.20134159947789, 38.77583010072125, 39.34193055761244, 39.9, 40.45037082648316, 40.993353119743695, 41.52923668934935, 42.05829288023944, 42.580776178928446, 43.09692564441227, 43.606966186608304, 44.11110971172682, 44.609556151120806, 45.10249438778303, 45.59010309266694, 46.07255148133215, 46.55, 47.02260094890541, 47.490499049809955, 47.953831963671064, 48.412730763715444, 48.8673203685244, 49.317719939186155, 49.764043244093415, 50.20639899455049, 50.64489115399499, 51.07961922332624, 51.51067850455864, 51.93816034477925, 52.36215236217854, 52.782738655738584, 53.2, 53.61401402618535, 54.02485539082914, 54.43259593295179, 54.837304820714884, 55.2390486884052, 55.63789176451603, 56.033895991622785, 56.427121138686495, 56.81762490636158, 57.20546302583347, 57.59068935166517, 57.973355949090966, 58.35351317615762, 58.73120976108019, 59.10649287514867, 59.47940820149441, 59.85, 60.21831116861383, 60.584383301309586, 60.948256742912676, 61.3099706409977, 61.66956299504643, 62.02707070304063, 62.38252960565161, 62.73597452817641, 63.08743932035917, 63.43695689422688, 63.78455926005917, 64.13027756060315, 64.47414210363718, 64.81618239297961, 65.15642715803254, 65.4949043819441, 65.83164132846758, 66.16666456759023, 66.50000000000001, 66.83167288045392], [0.0, 6.717514421272202, 9.5, 11.6350762782201, 13.435028842544405, 15.020818885799804, 16.454482671904337, 17.77287258717622, 19.0, 20.152543263816604, 21.242645786248005, 22.279474859161294, 23.2701525564402, 24.220342689565733, 25.13463745511361, 26.01682148149539, 26.87005768508881, 27.69702150051518, 28.500000000000004, 29.280966514102644, 30.041637771599607, 30.783518317437338, 31.5079355083763, 32.216067419845025, 32.908965343808674, 33.587572106361016, 34.2527371169079, 34.90522883466029, 35.54574517435244, 36.17492225285357, 36.79334178897046, 37.401537401556105, 38.0, 38.58918242202081, 39.16950344336778, 39.74135126036859, 40.30508652763321, 40.86104501845248, 41.409539963636405, 41.95086411505728, 42.48529157249601, 43.013079406152734, 43.534469102080486, 44.049687853604595, 44.55894971832259, 45.06245665739941, 45.56039947147084, 46.05295864545513, 46.5403051128804, 47.022600948905406, 47.50000000000001, 47.972648457219876, 48.440685379131466, 48.90424316968826, 49.363448015713004, 49.8184202880822, 50.26927491022722, 50.716121697148736, 51.159065667777796, 51.598207333201024, 52.03364296299078, 52.46546483163949, 52.89376144688521, 53.31861776152867, 53.74011537017762, 54.15833269220905, 54.57334514211127, 54.985225288253574, 55.39404300103036, 55.79986559123597, 56.20275793944636, 56.602782617111686, 57.00000000000001, 57.39446837457422, 57.786244037833086, 58.17538139110049, 58.56193302820529, 58.945949818456576, 59.32748098478479, 59.706574177388546, 60.083275543199214, 60.45762979144982, 60.829680255612075, 61.19946895194435, 61.567036634874675, 61.932422849425166, 62.29566598086901, 62.65680330179637, 63.0158710167526, 63.372904304600084, 63.72793735874401, 64.0810034253522, 64.43213483969005, 64.78136306068282, 65.12871870380992, 65.47423157242855, 65.81793068761735, 66.15984431662457, 66.5, 66.83842457748388, 67.17514421272203, 67.51018441687151], [0.0, 6.784357007115709, 9.594529691443975, 11.750851033010337, 13.568714014231418, 15.170283451537749, 16.61821290030911, 17.949721446306626, 19.18905938288795, 20.353071021347123, 21.45402060220881, 22.501166636421324, 23.501702066020673, 24.4613470602091, 25.384739510186037, 26.27570170328473, 27.137428028462836, 27.972620542237372, 28.78358907433193, 29.57232659091943, 30.340566903075498, 31.08982952671179, 31.82145502644403, 32.53663320013305, 33.23642580061822, 33.921785035578544, 34.593568766462944, 35.252553099031005, 35.89944289261325, 36.53488059375589, 37.1594537096551, 37.773701168934984, 38.3781187657759, 38.97316384385543, 39.559259345948334, 40.136797331127454, 40.706142042694246, 41.2676325950496, 41.82158533580477, 42.368295929857744, 42.90804120441762, 43.44108078765997, 43.96765856854332, 44.48800400107877, 45.00233327284265, 45.51085035461324, 46.01374794558688, 46.51120832659586, 47.00340413204135, 47.490499049809955, 47.97264845721988, 48.45000000000001, 48.9226941204182, 49.39086453991265, 49.854638700927325, 50.31413817208838, 50.769479020372074, 51.22077215349258, 51.66812363537117, 52.11163497722942, 52.55140340656946, 52.9875221160605, 53.420080494136286, 53.849164338919884, 54.27485605692567, 54.697234847842175, 55.1163768765691, 55.53235543356684, 55.945241084474745, 56.355101809862795, 56.7620031359007, 57.166008256655466, 57.56717814866386, 57.965571678367844, 58.36124570294915, 58.754255165051674, 59.14465318183886, 59.53249112879455, 59.917818718641634, 60.30068407572174, 60.681133806150996, 61.05921306404137, 61.434965614054036, 61.80843389052986, 62.17965905342358, 62.548681041249786, 62.915538621234106, 63.28026943684739, 63.64291005288806, 64.0034959982656, 64.36206180662643, 64.71864105495418, 65.0732664002661, 65.42596961451929, 65.77678161783231, 66.12573251012046, 66.47285160123644, 66.81816743970163, 67.16170784010782, 67.50349990926398, 67.84357007115709, 68.18194409079285], [0.0, 6.85054742338158, 9.688137075826292, 11.86549619695696, 13.70109484676316, 15.318289721767245, 16.780345646022912, 18.12484482692197, 19.376274151652584, 20.55164227014474, 21.663333076883625, 22.72069541189266, 23.73099239391392, 24.700000000000006, 25.63240137014088, 26.532056083160988, 27.40218969352632, 28.245530619905164, 29.064411227478878, 29.860843926453256, 30.63657944353449, 31.393152119530782, 32.13191559804675, 32.85407128500211, 33.560691292045824, 34.2527371169079, 34.93107499061545, 35.59648859087088, 36.24968965384394, 36.89132689400044, 37.52199355044985, 38.14223380978099, 38.75254830330517, 39.35339883669516, 39.945212479094415, 40.528385114632925, 41.10328454028948, 41.67025317897649, 42.22961046469646, 42.78165494695127, 43.32666615376725, 43.864906246337746, 44.396621493082115, 44.92204358664018, 45.44139082378532, 45.95486916530174, 46.46267319042244, 46.96498695837145, 47.46198478782784, 47.95383196367106, 48.440685379131466, 48.92269412041819, 49.40000000000001, 49.87273804394542, 50.34103693806873, 50.80501943705956, 51.26480274028176, 51.720498837501566, 52.172214827434736, 52.620053211679675, 53.064112166321976, 53.50448579324915, 53.941264352997884, 54.37453448076591, 54.80437938705264, 55.2308790442448, 55.65411036033188, 56.07414734082008, 56.49106123981033, 56.90492070111337, 57.31579189019376, 57.723738617660594, 58.128822454957756, 58.53110284284758, 58.930637193229124, 59.32748098478479, 59.72168785290651, 60.11330967431423, 60.50239664674451, 60.888997364055854, 61.27315888706898, 61.65492681043422, 62.034345325795144, 62.411457281496, 62.786304239061565, 63.15892652665972, 63.52936328974186, 63.89765253904091, 64.2638311960935, 64.62793513644081, 64.98999923065087, 65.3500573832954, 65.70814257000421, 66.0642868727121, 66.41852151320444, 66.7708768850612, 67.12138258409165, 67.47006743734589, 67.81695953078405, 68.16208623567798, 68.5054742338158, 68.84714954157508], [0.0, 6.916104394816493, 9.780848633937651, 11.97904420227257, 13.832208789632986, 15.464879566294723, 16.940926775120662, 18.298292270045312, 19.561697267875303, 20.74831318444948, 21.870642423120543, 22.938123288534314, 23.95808840454514, 24.936369021972713, 25.877693096564848, 26.785957141756203, 27.664417579265972, 28.51582893762691, 29.342545901812958, 30.146600139982624, 30.929759132589446, 31.69357190346333, 32.43940505003136, 33.16847147518258, 33.881853550241324, 34.58052197408247, 35.265351267214115, 35.937132606817705, 36.596584540090625, 37.244361989434054, 37.88106387101609, 38.50723957907137, 39.123394535750606, 39.72999496602033, 40.32747202590314, 40.916225387980255, 41.49662636889896, 42.069020668420606, 42.63373077740207, 43.19105810234337, 43.741284846241086, 44.28467567906533, 44.82147922592471, 45.35192939666405, 45.87624657706863, 46.394638698884165, 46.90730220338834, 47.414422911177574, 47.91617680909028, 48.41273076371545, 48.904243169688264, 49.390864539912656, 49.872738043945425, 50.35000000000001, 50.822780325361975, 51.29120294943374, 51.755386193129695, 52.21544311791293, 52.67148184739063, 53.123605864060096, 53.571914283512406, 54.0165021081521, 54.457460462272756, 54.89487681013594, 55.328835158531945, 55.759416245150916, 56.18669771396073, 56.61075427867041, 57.03165787525382, 57.44947780441525, 57.86428086479604, 58.27613147764701, 58.685091803625916, 59.09122185231915, 59.49457958503447, 59.89522101136284, 60.29320027996525, 60.688569764000874, 61.08138014157835, 61.471680471579766, 61.85951826517889, 62.24493955334844, 62.62798895062815, 63.00870971540363, 63.38714380692666, 63.76333193928938, 64.13731363254935, 64.50912726118686, 64.87881010006272, 65.24639836803254, 65.61192726936163, 65.97543103307473, 66.33694295036516, 66.6964954101788, 67.05411993308094, 67.40984720350582, 67.76370710048265, 68.11572872692476, 68.46594043756356, 68.81436986560294, 69.16104394816495, 69.50598895059333], [0.0, 6.981045766932058, 9.8726896031426, 12.091525958289965, 13.962091533864116, 15.610092888897235, 17.1, 18.470110990462402, 19.7453792062852, 20.943137300796174, 22.076005073382277, 23.15350945321249, 24.18305191657993, 25.170518469034366, 26.12068146124829, 27.037473994439644, 27.924183067728233, 28.783589074331925, 29.618068809427804, 30.429673018289243, 31.22018577779447, 31.991170656917202, 32.744007085266766, 33.47991935474158, 34.2, 34.90522883466029, 35.59648859087087, 36.27457787486989, 36.940221980924804, 37.59408198107782, 38.2367624152464, 38.86881783640969, 39.4907584125704, 40.10305474649032, 40.706142042694246, 41.3004237266399, 41.88627460159235, 42.46404361339132, 43.03405628104328, 43.596616841218314, 44.15201014676455, 44.70050335287065, 45.242347419204506, 45.77777845199568, 46.30701890642498, 46.830278666691704, 47.34775601863303, 47.859638527678, 48.36610383315986, 48.8673203685244, 49.36344801571301, 49.854638700927325, 50.34103693806873, 50.822780325361975, 51.300000000000004, 51.77282105506711, 52.24136292249658, 52.70573972538475, 53.16606060260625, 53.62243000834632, 54.07494798887929, 54.523710438670626, 54.96880933765984, 55.410332971387206, 55.848366135456466, 56.28299032567477, 56.71428391507734, 57.14232231892575, 57.56717814866385, 57.98892135572105, 58.407619365969715, 58.82333720556834, 59.23613761885561, 59.646081178900594, 60.05322639126061, 60.45762979144982, 60.859346036578486, 61.25842799158334, 61.654926810434226, 62.048892012670144, 62.44037155558894, 62.82941190238852, 63.21605808653369, 63.60035377260098, 63.982341313834404, 64.36206180662643, 64.73955514212312, 65.11486005513642, 65.48801417053353, 65.85905404726066, 66.22801522014683, 66.59493223962316, 66.95983870948317, 67.32276732280098, 67.68374989611614, 68.04281740198593, 68.4, 68.75532706634448, 69.10882722199821, 69.46052835963746, 69.81045766932058, 70.15864166301968], [0.0, 7.0453885627408805, 9.96368405761644, 12.202970949731876, 14.090777125481761, 15.75396775418815, 17.257607018355706, 18.640346026831153, 19.92736811523288, 21.13616568822264, 22.27947485916129, 23.366910364872805, 24.405941899463752, 25.402509718529785, 26.361430158472054, 27.286672571055636, 28.181554250963522, 29.048881217699247, 29.89105217284932, 30.710136762964773, 31.5079355083763, 32.28602638913622, 33.04580154875956, 33.788496563179606, 34.51521403671141, 35.226942813704405, 35.92457376225917, 36.60891284919562, 37.28069205366231, 37.940578540660134, 38.58918242202081, 39.2270633619189, 39.85473623046576, 40.47267596786751, 41.08132178983534, 41.68108084011258, 42.27233137644528, 42.855425560831854, 43.430691912517354, 43.998437472255766, 44.55894971832258, 45.11249826821831, 45.65933639465209, 46.19970237999375, 46.73382072974561, 47.261903262564445, 47.78415009184531, 48.30075051176742, 48.811883798927504, 49.317719939186155, 49.81842028808221, 50.31413817208838, 50.80501943705957, 51.29120294943374, 51.77282105506711, 52.25, 52.72286031694411, 53.191517180843796, 53.656080736483176, 54.116656400779235, 54.57334514211127, 55.02624373878341, 55.47544501849444, 55.92103808049347, 56.363108501927044, 56.80173852973164, 57.23700725928986, 57.668990800949516, 58.097762435398494, 58.52339275879348, 58.945949818456576, 59.36549923987838, 59.78210434569864, 60.19582626727537, 60.606724049399006, 61.01485474865937, 61.420273525929545, 61.82303373339099, 62.22318699648871, 62.62078329117259, 63.0158710167526, 63.40849706466792, 63.79870688344711, 64.1865445401137, 64.57205277827244, 64.95527307309239, 65.33624568338772, 65.7150097009808, 66.09160309751913, 66.46606276890485, 66.83842457748388, 67.20872339213118, 67.57699312635921, 67.94326677456715, 68.3075764465407, 68.66995340030456, 69.03042807342283, 69.38903011283557, 69.74578840331509, 70.10073109461841, 70.45388562740881, 70.80527875801353], [0.0, 7.109149034870489, 10.053854982045443, 12.313407326974938, 14.218298069740978, 15.896540504147435, 17.413787640832194, 18.809040379562163, 20.107709964090887, 21.327447104611466, 22.48110317577854, 23.578379927382628, 24.626814653949875, 25.632401370140883, 26.599999999999998, 27.53361581775993, 28.436596139481956, 29.311772379028874, 30.161564946136334, 30.988062217570175, 31.79308100829487, 32.57821357901627, 33.34486467209006, 34.094281045360084, 34.82757528166439, 35.54574517435245, 36.24968965384394, 36.940221980924804, 37.618080759124325, 38.28393919125878, 38.93841291064647, 39.58206664639935, 40.215419928181774, 40.838951994388886, 41.45310603561572, 42.05829288023944, 42.65489420922293, 43.243265371615955, 43.82373785974902, 44.39662149308211, 44.96220635155708, 45.520764492701566, 46.07255148133214, 46.61780775626413, 47.156759854765255, 47.6896215124423, 48.21659465370818, 48.73787028584651, 49.25362930789975, 49.764043244093415, 50.269274910227224, 50.769479020372074, 51.264802740281766, 51.755386193129695, 52.24136292249658, 52.72286031694411, 53.199999999999996, 53.67289818893703, 54.14166602534503, 54.606409880159674, 55.06723163551986, 55.524228945569334, 55.97749547809369, 56.427121138686495, 56.87319227896391, 57.31579189019374, 57.75499978356852, 58.190892758231506, 58.62354475805775, 59.0530270180962, 59.47940820149441, 59.9027545276509, 60.32312989227267, 60.740595979953966, 61.155212369838104, 61.567036634874675, 61.97612443514035, 62.38252960565162, 62.78630423906157, 63.18749876360039, 63.58616201658974, 63.9823413138344, 64.3760825151702, 64.76743008642538, 65.15642715803254, 65.5431155805093, 65.9275359770104, 66.30972779313757, 66.68972934418012, 67.0675778599466, 67.44330952733561, 67.81695953078403, 68.18856209072017, 68.55815050014112, 68.92575715942482, 69.29141360947978, 69.65515056332877, 70.01699793621546, 70.37698487431811, 70.73513978214788, 71.0914903487049, 71.44606357246003], [0.0, 7.172342713507213, 10.143224339429747, 12.422861989090922, 14.344685427014426, 16.037845865327427, 17.568579908461583, 18.97623513766627, 20.286448678859493, 21.517028140521635, 22.680939133995313, 23.787969648542937, 24.845723978181844, 25.860249418750783, 26.836449094468513, 27.778363882705545, 28.68937085402885, 29.572326590919424, 30.42967301828924, 31.26351707661824, 32.07569173065485, 32.867803394811766, 33.64126929828897, 34.397347281440176, 35.137159816923166, 35.861713567536064, 36.5719154543483, 37.26858596727276, 37.95247027533254, 38.624247565486634, 39.28453894345713, 39.93391415826903, 40.572897357718986, 41.20197204018274, 41.82158533580476, 42.43215172484186, 43.03405628104327, 43.62765751217913, 44.21328985723637, 44.79126588967988, 45.361878267990626, 45.925401468032916, 46.48209332635526, 47.032196419048944, 47.575939297085874, 48.11353759598227, 48.64519503507001, 49.17110431950863, 49.69144795636369, 50.20639899455048, 50.716121697148736, 51.220772153492575, 51.720498837501566, 52.215443117912926, 52.70573972538475, 53.19151718084379, 53.672898188937026, 54.150000000000006, 54.6229347435672, 55.09180973611232, 55.55672776541109, 56.017787353661156, 56.47508300126702, 56.92870541299881, 57.3787417080577, 57.825275615426165, 58.26838765574349, 58.708155310825425, 59.14465318183885, 59.57795313704559, 60.00812444994428, 60.43523392856191, 60.85934603657848, 61.28052300690652, 61.69882494829216, 62.1143099454546, 62.52703415323648, 62.93705188519717, 63.34441569704469, 63.74917646526895, 64.1513834613097, 64.55108442156491, 64.9483256135214, 65.34315189826704, 65.73560678962353, 66.12573251012044, 66.51357004401433, 66.89915918754137, 67.28253859657794, 67.6637458318707, 68.04281740198593, 68.41978880411719, 68.79469456288035, 69.1675682672161, 69.53844260551139, 69.90734939904387, 70.27431963384633, 70.63938349108096, 71.00257037600822, 71.36390894562882, 71.72342713507213, 72.0811521828002], [0.0, 7.234984450570714, 10.231813133555558, 12.531360660359276, 14.469968901141428, 16.177917047630082, 17.72202020086875, 19.14196959562939, 20.463626267111117, 21.70495335171214, 22.879029699705363, 23.995728786598672, 25.062721320718552, 26.086107413717368, 27.070833012672512, 28.02097428712999, 28.939937802282856, 29.830605089404408, 30.69543940066668, 31.536566078125887, 32.355834095260164, 33.154863896568784, 33.93508508903433, 34.697766498724384, 35.4440404017375, 36.17492225285357, 36.89132689400044, 37.59408198107782, 38.28393919125878, 38.96158364337877, 39.627641867767, 40.282688589516965, 40.927252534222234, 41.56182142303199, 42.18684629123159, 42.80274523906148, 43.40990670342428, 44.00869232322179, 44.59943945836091, 45.18246341225764, 45.758059399410726, 46.326504292899116, 46.888058181161654, 47.44296575889834, 47.991457573197344, 48.533751142890246, 49.07005196655085, 49.60055443238513, 50.125442641437104, 50.64489115399499, 51.159065667777796, 51.66812363537117, 52.172214827434736, 52.67148184739063, 53.16606060260625, 53.65608073648317, 54.141666025345025, 54.6229347435672, 55.10000000000001, 55.57297004839673, 56.04194857425998, 56.507034960259595, 56.96832453214681, 57.42590878688818, 57.87987560456571, 58.33030944543325, 58.77729153338048, 59.22090002693306, 59.661210178808815, 60.09829448495191, 60.53222282388118, 60.9630625871109, 61.39087880133336, 61.815734242990274, 62.23768954580496, 62.65680330179637, 63.07313215625177, 63.48673089709377, 63.89765253904091, 64.30594840292771, 64.71166819052033, 65.11486005513642, 65.51557066835335, 65.9138452830663, 66.30972779313757, 66.70326078985944, 67.09448561543638, 67.48344241367657, 67.87017017806866, 68.25470679740702, 68.63708909911608, 69.01735289041446, 69.39553299744877, 69.77166330251846, 70.14577677950399, 70.51790552760342, 70.888080803475, 71.25633305187688, 71.6226919348889, 71.98718635979601, 72.34984450570714, 72.71069384897935], [0.0, 7.297088460475178, 10.319641466640205, 12.63892796086757, 14.594176920950355, 16.316785835451785, 17.87414333611544, 19.306281361256495, 20.63928293328041, 21.89126538142553, 23.075419822833126, 24.201704485428294, 25.27785592173514, 26.310026605839838, 27.303204940079834, 28.26150208322268, 29.18835384190071, 30.08666648201492, 30.958924399920615, 31.807271181288094, 32.63357167090357, 33.439460222916274, 34.22637871583846, 34.99560686714834, 35.74828667223088, 36.485442302375894, 37.20799645237567, 37.9167838826027, 38.61256272251299, 39.29602397189822, 39.96779953912899, 40.62846908265188, 41.27856586656082, 41.918581798529395, 42.54897178546151, 43.1701575165067, 43.78253076285106, 44.386456267649926, 44.98227428665652, 45.57030282980353, 46.15083964566625, 46.72416398396016, 47.29053816568384, 47.850208985959505, 48.40340897085659, 48.95035750635535, 49.4912618549982, 50.026318073590026, 50.55571184347028, 51.07961922332624, 51.59820733320103, 52.111634977229414, 52.620053211679675, 53.123605864060096, 53.62243000834632, 54.11665640077923, 54.60640988015967, 55.09180973611232, 55.57297004839673, 56.05, 56.52300416644536, 56.99208278348844, 57.45733199514227, 57.918844083769486, 58.37670768380142, 58.83100798048593, 59.28182689492623, 59.72924325654896, 60.17333296402984, 60.61416913560723, 61.05182224962659, 61.486360276080745, 61.91784879984123, 62.34635113621325, 62.7719284393908, 63.19463980433783, 63.61454236257619, 64.0316913723197, 64.4461403033572, 64.85794091705348, 65.26714334180714, 65.6737961442766, 66.07794639666098, 66.47963974029943, 66.87892044583255, 67.27583147014981, 67.67041451033087, 68.06271005477228, 68.45275743167691, 68.84059485507079, 69.22625946849938, 69.609787386545, 69.99121373429668, 70.37057268489436, 70.7478974952613, 71.1232205401302, 71.49657334446177, 71.86798661434729, 72.23749026648143, 72.60511345628488, 72.97088460475179, 73.33483142409206], [0.0, 7.358668357794092, 10.406728592598155, 12.745587471748802, 14.717336715588184, 16.454482671904334, 18.02498266295976, 19.469206455323235, 20.81345718519631, 22.076005073382273, 23.27015255644019, 24.405941899463745, 25.491174943497604, 26.532056083160988, 27.53361581775993, 28.499999999999996, 29.434673431176368, 30.34056690307549, 31.22018577779447, 32.07569173065485, 32.90896534380867, 33.72165476366781, 34.5152140367114, 35.29093367991275, 36.04996532591952, 36.79334178897046, 37.52199355044985, 38.2367624152464, 38.93841291064647, 39.627641867767, 40.3050865276332, 40.971331440410864, 41.62691437039262, 42.27233137644527, 42.908041204417614, 43.53446910208047, 44.152010146764546, 44.76103215968103, 45.36187826799062, 45.95486916530173, 46.54030511288038, 47.118467717021524, 47.68962151244231, 48.254015376961114, 48.81188379892749, 49.363448015713, 49.90891703894205, 50.448488579936665, 50.98234988699521, 51.51067850455863, 52.03364296299078, 52.551403406569456, 53.064112166321976, 53.5719142835124, 54.07494798887928, 54.573345142111265, 55.06723163551986, 55.55672776541109, 56.041948574259976, 56.52300416644536, 56.99999999999999, 57.47303715656585, 57.94221259151223, 58.40761936596971, 58.869346862352735, 59.32748098478477, 59.782104345698635, 60.233296439759954, 60.68113380615098, 61.12569018015256, 61.56703663487467, 62.005241713906734, 62.44037155558894, 62.87249000954232, 63.30165874603918, 63.727937358744, 64.1513834613097, 64.57205277827242, 64.98999923065087, 65.40527501662233, 65.81793068761733, 66.22801522014683, 66.63557608365069, 67.04065930463392, 67.44330952733561, 67.84357007115707, 68.24148298505828, 68.63708909911608, 69.0304280734228, 69.4215384444914, 69.81045766932057, 70.19722216726242, 70.5818673598255, 70.96442770853577, 71.34493675097063, 71.72342713507211, 72.09993065183905, 72.47447826649048, 72.8471001481871, 73.21782569839124, 73.58668357794092, 73.95370173290854], [0.0, 7.419737192111322, 10.493092966327898, 12.851361795545252, 14.839474384222644, 16.591036736744332, 18.174570146223544, 19.630779403783233, 20.986185932655797, 22.259211576333964, 23.46326916693409, 24.608484309278378, 25.702723591090503, 26.752242896624576, 27.762114472784667, 28.73651857828293, 29.678948768445288, 30.592360157398776, 31.479278898983694, 32.341884608043486, 33.182073473488664, 34.00150731952923, 34.801652259626984, 35.583809520623284, 36.34914029244709, 37.098685960556615, 37.83338472830577, 38.55408538663575, 39.261558807566466, 39.95650760514487, 40.63957430879413, 41.31134831980191, 41.972371865311594, 42.62314512093165, 43.26413063959566, 43.895757198162094, 44.51842315266793, 45.13249937683487, 45.738331845400744, 46.33624391337736, 46.92653833386818, 47.50949905018995, 48.0853927924063, 48.654470503747135, 49.216968618556756, 49.77311021023299, 50.32310602496631, 50.86715541486471, 51.40544718218101, 51.93816034477925, 52.465464831639494, 52.9875221160605, 53.50448579324915, 54.016502108152096, 54.523710438670626, 55.02624373878341, 55.524228945569334, 56.01778735366116, 56.507034960259595, 56.99208278348844, 57.47303715656586, 57.949999999999996, 58.42306907378283, 58.8923382113497, 59.357897536890576, 59.819833667438424, 60.27822990101816, 60.733166392013516, 61.18472031479755, 61.63296601657266, 62.07797516027726, 62.51981685833701, 62.95855779796739, 63.394262358670915, 63.82699272251513, 64.25680897772625, 64.68376921608697, 65.10792962458567, 65.52934457172604, 65.9480666888727, 66.36414694697733, 66.77763472900189, 67.18857789833032, 67.5970228634368, 68.00301463905846, 68.40659690409983, 68.80781205648091, 69.20670126512317, 69.60330451925397, 69.99766067519685, 70.38980750080228, 70.77978171766284, 71.16761904124657, 71.55335421907208, 71.9370210670417, 72.31865250403936, 72.69828058489418, 73.07593653180231, 73.45165076429528, 73.82545292783513, 74.19737192111323, 74.56743592212355], [0.0, 7.480307480311221, 10.578752289377041, 12.956272612136566, 14.960614960622442, 16.726476018576058, 18.322936445886615, 19.791033323199674, 21.157504578754082, 22.440922440933658, 23.65480923617859, 24.80937322868113, 25.91254522427313, 26.970632176498942, 27.988747739046843, 28.97110629575612, 29.921229921244883, 30.84209785342106, 31.736256868131125, 32.60590437328798, 33.452952037152116, 34.279075250070555, 35.085752093976836, 35.87429441814849, 36.64587289177323, 37.401537401556105, 38.14223380978099, 38.86881783640969, 39.58206664639935, 40.28268858951696, 40.971331440410864, 41.64858941188764, 42.315009157508165, 42.971094936014836, 43.617313076346186, 44.254095855638035, 44.881844881867316, 45.50093405634657, 46.11171217814407, 46.71450524194814, 47.30961847235718, 47.89733813063101, 48.47793312425768, 49.05165644501722, 49.61874645736226, 50.179428055728174, 50.733913706711014, 51.28240438980996, 51.82509044854626, 52.362152362178534, 52.893761446885215, 53.420080494136286, 53.941264352997884, 54.45746046227275, 54.96880933765984, 55.47544501849444, 55.97749547809369, 56.47508300126703, 56.96832453214681, 57.45733199514227, 57.94221259151224, 58.42306907378283, 58.89999999999999, 59.373099969599025, 59.84245984248977, 60.30816694279473, 60.770305248534, 61.228955568423665, 61.68419570684212, 62.13610061791776, 62.584742549602296, 63.03019117851381, 63.47251373626225, 63.911775127905806, 64.34803804312916, 64.78136306068282, 65.21180874657595, 65.63943174647386, 66.0642868727121, 66.48642718630623, 66.90590407430423, 67.32276732280098, 67.73706518590838, 68.14884445095161, 68.55815050014111, 68.96502736894983, 69.36951780140899, 69.77166330251845, 70.17150418795367, 70.56907963123793, 70.96442770853577, 71.3575854412129, 71.74858883629697, 72.1374729249646, 72.5242717991708, 72.90901864652959, 73.29174578354646, 73.67248468729693, 74.0512660256393, 74.42811968604339, 74.80307480311221, 75.17615978486798], [0.0, 7.5403912365340835, 10.663723552305733, 13.060340730624146, 15.080782473068167, 16.860827381833907, 18.470110990462405, 19.95, 21.327447104611466, 22.62117370960225, 23.844810756221154, 25.00864850406755, 26.120681461248292, 27.187267240382955, 28.213560569343244, 29.203809682984854, 30.161564946136334, 31.08982952671179, 31.991170656917202, 32.86780339481177, 33.721654763667814, 34.554413610999106, 35.36756989107394, 36.162445990281135, 36.94022198092481, 37.70195618267042, 38.44860205521132, 39.18102219187244, 39.9, 40.60624951900877, 41.3004237266399, 41.98312160857027, 42.65489420922293, 43.316249837676395, 43.967658568543314, 44.6095561511208, 45.2423474192045, 45.86640927737858, 46.48209332635526, 47.08972817929617, 47.68962151244231, 48.28206188637764, 48.86732036852441, 49.445651982757795, 50.0172970081351, 50.582482145501714, 51.14142156804013, 51.69431786956861, 52.241362922496585, 52.78273865573858, 53.31861776152867, 53.849164338919884, 54.37453448076591, 54.89487681013593, 55.410332971387206, 55.92103808049346, 56.42712113868649, 56.928705412998816, 57.42590878688818, 57.91884408376949, 58.40761936596971, 58.892338211349696, 59.373099969599025, 59.85, 60.32312989227267, 60.79257767194939, 61.25842799158333, 61.72076230896699, 62.17965905342358, 62.63519378113235, 63.087439320359174, 63.53646590738267, 63.982341313834404, 64.42513096610669, 64.86489805742394, 65.30170365312073, 65.73560678962355, 66.16666456759023, 66.59493223962316, 67.02046329293763, 67.44330952733563, 67.86352112880675, 68.28114673905236, 68.69623352120551, 69.10882722199821, 69.51897223060767, 69.9267116343962, 70.33208727174248, 70.73513978214788, 71.13590865378751, 71.53443226866347, 71.93074794550658, 72.32489198056227, 72.71689968638653, 73.10680542876977, 73.49464266189747, 73.88044396184962, 74.26424105853368, 74.64606486614014, 75.02594551220265, 75.40391236534084, 75.77999406175749], [0.0, 7.6000000000000005, 10.748023074035522, 13.16358613752347, 15.200000000000001, 16.994116628998402, 18.616122045152157, 20.107709964090887, 21.496046148071045, 22.8, 24.033310217279684, 25.20634840670104, 26.32717227504694, 27.402189693526324, 28.436596139481953, 29.434673431176368, 30.400000000000002, 31.33560275469422, 32.24406922210657, 33.12763197090912, 33.988233257996804, 34.82757528166439, 35.647159774658064, 36.44831957717667, 37.23224409030431, 38.00000000000001, 38.75254830330517, 39.49075841257041, 40.215419928181774, 40.927252534222234, 41.626914370392626, 42.315009157508165, 42.99209229614209, 43.65867611368902, 44.31523440082429, 44.96220635155708, 45.6, 46.22899523026647, 46.849546422564224, 47.46198478782783, 48.06662043455937, 48.66374420448965, 49.25362930789974, 49.83653278469521, 50.41269681340208, 50.9823498869952, 51.54570787175204, 52.10297496304794, 52.65434455009388, 53.199999999999996, 53.74011537017762, 54.274856056925664, 54.80437938705265, 55.328835158531945, 55.848366135456466, 56.36310850192704, 56.873192278963906, 57.3787417080577, 57.87987560456571, 58.37670768380142, 58.869346862352735, 59.35789753689057, 59.84245984248976, 60.32312989227267, 60.800000000000004, 61.27315888706897, 61.7426918752333, 62.20868106623062, 62.67120550938844, 63.130341358177375, 63.586162016589746, 64.03873827614034, 64.48813844421313, 64.93442846441323, 65.37767202952396, 65.81793068761733, 66.25526394181824, 66.68972934418014, 67.12138258409165, 67.55027757159849, 67.97646651599361, 68.4, 68.82092704984439, 69.23929520149667, 69.65515056332877, 70.06853787542595, 70.47950056576735, 70.888080803475, 71.29431954931613, 71.69825660363018, 72.09993065183905, 72.49937930768787, 72.89663915435334, 73.29174578354646, 73.68473383272821, 74.07563702054813, 74.46448818060863, 74.8513192936504, 75.23616151824866, 75.61904522010312, 76.00000000000001, 76.37905472051878], [0.0, 7.659144860883622, 10.83166653844181, 13.266028041580496, 15.318289721767243, 17.126368558453947, 18.760996775224925, 20.264192557316463, 21.66333307688362, 22.977434582650865, 24.220342689565726, 25.40250971852978, 26.53205608316099, 27.615439522122404, 28.65789594509687, 29.66374049239239, 30.636579443534487, 31.579463263329856, 32.49499961532543, 33.3854384425306, 34.252737116907895, 35.09861108363121, 35.924573762259165, 36.73196836544429, 37.52199355044985, 38.295724304418115, 39.05412910307948, 39.79808412474148, 40.528385114632925, 41.24575735757558, 41.95086411505727, 42.644313806180534, 43.32666615376724, 43.99843747225576, 44.660105239464, 45.31211206730491, 45.95486916530173, 46.58875937390906, 47.21413983119887, 47.8313443256616, 48.44068537913145, 49.04245609673316, 49.6369318149299, 50.22437157396795, 50.80501943705956, 51.37910567536184, 51.9468478350708, 52.50845170065482, 53.06411216632198, 53.614014026185345, 54.15833269220906, 54.697234847842175, 55.23087904424481, 55.759416245150916, 56.28299032567477, 56.80173852973164, 57.31579189019374, 57.825275615426165, 58.33030944543326, 58.831007980485936, 59.32748098478478, 59.819833667438424, 60.30816694279473, 60.792577671949395, 61.27315888706897, 61.74999999999999, 62.22318699648869, 62.69280261720638, 63.15892652665971, 63.62163547096223, 64.0810034253522, 64.5371017322594, 64.98999923065087, 65.43976237731918, 65.88645536071886, 66.33014020790247, 66.7708768850612, 67.20872339213118, 67.64373585188802, 68.0759685939172, 68.50547423381579, 68.9323037479526, 69.35650654408713, 69.77813052812463, 70.19722216726242, 70.61382654976289, 71.02798744157123, 71.43974733997875, 71.84914752451833, 72.25622810526438, 72.66102806869718, 73.06358532128024, 73.46393673088858, 73.86211816621562, 74.25816453427866, 74.65210981613312, 75.0439871008997, 75.43382861820021, 75.82166576909268, 76.20752915558934, 76.59144860883623, 76.97345321602766], [0.0, 7.717836484404162, 10.914669028422255, 13.367684915496778, 15.435672968808325, 17.257607018355703, 18.90476130502578, 20.419475997194443, 21.82933805684451, 23.153509453212486, 24.405941899463745, 25.597167812084212, 26.735369830993555, 27.827055180165942, 28.877499891784257, 29.891052172849317, 30.87134593761665, 31.82145502644403, 32.744007085266766, 33.641269298288975, 34.515214036711406, 35.36756989107394, 36.19986187818954, 37.0134435036785, 37.80952261005156, 38.58918242202081, 39.35339883669516, 40.10305474649032, 40.838951994388886, 41.56182142303198, 42.27233137644528, 42.971094936014836, 43.65867611368902, 44.33559518039653, 45.00233327284264, 45.65933639465207, 46.30701890642497, 46.94576658230218, 47.575939297085874, 48.197873397070126, 48.81188379892749, 49.41826585383182, 50.0172970081351, 50.60923828709537, 51.194335624168424, 51.772821055067105, 52.34491379303246, 52.91082119944842, 53.47073966198711, 54.02485539082913, 54.57334514211128, 55.1163768765691, 55.654110360331885, 56.18669771396073, 56.71428391507734, 57.23700725928986, 57.754999783568515, 58.26838765574349, 58.77729153338048, 59.28182689492624, 59.782104345698635, 60.27822990101816, 60.770305248534, 61.25842799158333, 61.7426918752333, 62.22318699648869, 62.699999999999996, 63.17321426047593, 63.64291005288806, 64.10916471145136, 64.57205277827244, 65.03164614247436, 65.48801417053353, 65.94122382849744, 66.39133979669336, 66.83842457748388, 67.28253859657795, 67.72374029836215, 68.16208623567798, 68.59763115443565, 69.03042807342281, 69.46052835963746, 69.88798179944818, 70.31283666586066, 70.73513978214788, 71.15493658208122, 71.57227116698198, 71.98718635979601, 72.39972375637907, 72.80992377416693, 73.21782569839124, 73.62346772599074, 74.026887007357, 74.42811968604339, 74.82720093655783, 75.22416500035078, 75.61904522010312, 76.01187407241056, 76.40268319895578, 76.79150343625264, 77.17836484404162, 77.56329673241076], [0.0, 7.776085133278828, 10.997045057650714, 13.468574534819936, 15.552170266557656, 17.38785495683697, 19.047440772975254, 20.573587436322327, 21.99409011530143, 23.328255399836483, 24.59014030053509, 25.790356724946633, 26.937149069639872, 28.037073670410045, 29.09544637911575, 30.11664821987998, 31.104340533115312, 32.06162035830379, 32.99113517295214, 33.89516927233142, 34.77570991367394, 35.634498733671, 36.47307225885969, 37.29279421014199, 38.09488154595051, 38.88042566639414, 39.65040983394749, 40.4057236044598, 41.147174872644655, 41.87549999701496, 42.59137236577379, 43.29540968740219, 43.98818023060286, 44.67020819293324, 45.34197834237055, 46.00394004865235, 46.656510799672965, 47.30007928111749, 47.93500808386288, 48.56163609270182, 49.18028060107018, 49.7912391892389, 50.39479139752441, 50.99120022121464, 51.58071344989327, 52.16356487051091, 52.73997535077164, 53.310153817073164, 53.874298139279745, 54.432595932951784, 54.98522528825358, 55.53235543356684, 56.07414734082009, 56.610754278670406, 57.14232231892575, 57.668990800949516, 58.1908927582315, 58.70815531082543, 59.22090002693306, 59.72924325654896, 60.23329643975996, 60.73316639201351, 61.228955568423665, 61.72076230896699, 62.208681066230625, 62.69280261720638, 63.17321426047593, 63.65, 64.12324071660758, 64.59301432817638, 65.05939593940295, 65.52245798197745, 65.98227034590428, 66.43890050264227, 66.89241362067898, 67.34287267409967, 67.79033854466284, 68.23487011785105, 68.67652437332572, 69.11535647017962, 69.55141982734789, 69.98476619950945, 70.41544574878442, 70.84350711250819, 71.268997467342, 71.69196258995844, 72.1124469145237, 72.53049358718029, 72.94614451771938, 73.35944042861831, 73.77042090160528, 74.17912442190188, 74.58558842028398, 74.98984931309037, 75.39194254030069, 75.79190260179513, 76.18976309190101, 76.5855567323239, 76.979315403555, 77.3710701748399, 77.76085133278828, 78.14868840869948], [0.0, 7.833900688673555, 11.07880860020607, 13.568714014231418, 15.66780137734711, 17.517134468856487, 19.18905938288795, 20.726553017807856, 22.15761720041214, 23.501702066020663, 24.772969139770066, 25.982109229236954, 27.137428028462836, 28.245530619905164, 29.31177237902887, 30.34056690307549, 31.33560275469422, 32.3, 33.236425800618214, 34.14718143566172, 35.03426893771297, 35.89944289261325, 36.74425125104606, 37.57006787324186, 38.3781187657759, 39.16950344336778, 39.945212479094415, 40.706142042694246, 41.45310603561571, 42.18684629123159, 42.908041204417614, 43.617313076346186, 44.31523440082428, 45.00233327284264, 45.67909806465097, 46.345981487071775, 47.003404132041325, 47.65175757514092, 48.291407103127575, 48.922694120418186, 49.54593827954013, 50.16143937328753, 50.769479020372074, 51.37032217146394, 51.96421845847391, 52.551403406569456, 53.13209952561634, 53.706517295389766, 54.27485605692567, 54.837304820714884, 55.39404300103036, 55.945241084474745, 56.49106123981033, 57.03165787525381, 57.56717814866384, 58.097762435398494, 58.62354475805774, 59.14465318183885, 59.661210178808815, 60.17333296402984, 60.68113380615098, 61.184720314797545, 61.68419570684212, 62.17965905342358, 62.67120550938844, 63.158926526659705, 63.642910052888055, 64.12324071660758, 64.6, 65.07326640026609, 65.5431155805093, 66.0096205109528, 66.47285160123643, 66.93287682447244, 67.38976183367916, 67.84357007115707, 68.29436287132344, 68.74219955747706, 69.18713753292589, 69.62923236687304, 70.06853787542595, 70.505106198062, 70.93898786985899, 71.3702318897732, 71.7988857852265, 72.22499567324321, 72.64860631835961, 73.06976118751177, 73.48850250209212, 73.90487128735155, 74.3189074193102, 74.73064966932911, 75.14013574648372, 75.54740233786997, 75.95248514696542, 76.35541893015845, 76.7562375315518, 77.15497391613843, 77.5516602014425, 77.94632768771086, 78.33900688673556, 78.72972754938252], [0.0, 7.891292669772172, 11.159973118247194, 13.668119841441253, 15.782585339544344, 17.645466839956374, 19.329640451907018, 20.878397927044116, 22.31994623649439, 23.673878009316514, 24.954458519471025, 26.172456896516234, 27.336239682882507, 28.452460350556684, 29.5265135090481, 30.562845090076284, 31.565170679088688, 32.536633200133046, 33.47991935474158, 34.39734728144018, 35.29093367991275, 36.162445990281135, 37.013443503678495, 37.84531014537997, 38.659280903814036, 39.45646334886086, 40.23785531064001, 41.00435952432375, 41.75679585408823, 42.49591156805558, 43.22239003109384, 43.936858103419276, 44.63989247298878, 45.33202510367257, 46.01374794558687, 46.685517026161335, 47.34775601863303, 48.000859367307164, 48.64519503507002, 49.28110692750317, 49.90891703894205, 50.528927358494364, 51.14142156804014, 51.74666655930602, 52.34491379303247, 52.936400519869125, 53.521350879812445, 54.09997689463463, 54.672479365765014, 55.2390486884052, 55.79986559123598, 56.355101809862795, 56.90492070111337, 57.44947780441525, 57.98892135572105, 58.52339275879347, 59.0530270180962, 59.57795313704559, 60.09829448495191, 60.61416913560723, 61.12569018015257, 61.63296601657266, 62.13610061791776, 62.63519378113235, 63.130341358177375, 63.62163547096223, 64.10916471145136, 64.59301432817638, 65.07326640026609, 65.55, 66.02329134479741, 66.49321393946904, 66.95983870948317, 67.42323412593021, 67.88346632280941, 68.34059920720625, 68.79469456288037, 69.24581214773931, 69.69400978563367, 70.13934345287245, 70.5818673598255, 71.02163402794955, 71.45869436254767, 71.89309772154765, 72.32489198056227, 72.75412359447401, 73.18083765576888, 73.60507794982627, 74.02688700735699, 74.44630615416725, 74.86337555841308, 75.27813427549862, 75.69062029075994, 76.10087056006653, 76.50892104846338, 76.91480676696783, 77.31856180762807, 77.72021937694207, 78.11981182773036, 78.5173706895487, 78.91292669772172, 79.30650982107333], [0.0, 7.948270252073718, 11.240551587889271, 13.76680790887997, 15.896540504147437, 17.772872587176224, 19.46920645532324, 21.02914644011972, 22.481103175778543, 23.844810756221154, 25.134637455113612, 26.361430158472057, 27.53361581775994, 28.657895945096882, 29.7397041007472, 30.783518317437338, 31.793081008294873, 32.77155779025465, 33.721654763667814, 34.645706804739895, 35.54574517435245, 36.42355007409355, 37.28069205366231, 38.11856503070388, 38.93841291064648, 39.741351260368596, 40.52838511463293, 41.300423726639906, 42.05829288023944, 42.80274523906148, 43.53446910208048, 44.25409585563804, 44.962206351557086, 45.65933639465208, 46.34598148707178, 47.022600948905406, 47.68962151244231, 48.347440469998, 48.99642844126499, 49.6369318149299, 50.269274910227224, 50.893761896719724, 51.51067850455865, 52.120293552511775, 52.722860316944114, 53.318617761528664, 53.907791644622215, 54.490595518859955, 55.06723163551988, 55.63789176451602, 56.202757939446364, 56.7620031359007, 57.315791890193765, 57.86428086479604, 58.407619365969715, 58.94594981845657, 59.4794082014944, 60.00812444994428, 60.53222282388117, 61.05182224962659, 61.567036634874675, 62.077975160277255, 62.584742549602296, 63.087439320359174, 63.586162016589746, 64.0810034253522, 64.57205277827244, 65.05939593940295, 65.5431155805093, 66.02329134479741, 66.50000000000001, 66.97331558165536, 67.44330952733563, 67.91005080251377, 68.373606018697, 68.83403954439984, 69.29141360947979, 69.74578840331509, 70.19722216726244, 70.6457712817972, 71.0914903487049, 71.53443226866347, 71.9746483145281, 72.41218820060612, 72.8471001481871, 73.2794309475722, 73.70922601682913, 74.13652945748136, 74.56138410732461, 74.98383159055024, 75.40391236534083, 75.82166576909268, 76.23713006140775, 76.65034246498838, 77.06133920455835, 77.47015554392543, 77.87682582129295, 78.28138348292013, 78.6838611152249, 79.08429047541617, 79.48270252073719, 79.87912743639606], [0.0, 8.00484228451754, 11.320556523422336, 13.864793543360106, 16.00968456903508, 17.899371497345932, 19.60777906852278, 21.178821969127554, 22.641113046844673, 24.01452685355262, 25.313533929501034, 26.54905836371603, 27.729587086720212, 28.861869308830297, 29.951377263825446, 31.002620856953367, 32.01936913807016, 33.0048102554764, 33.96166957026701, 34.89229857719322, 35.798742994691864, 36.68279569498486, 37.54603840620206, 38.389874967235826, 39.21555813704556, 40.024211422587705, 40.81684701198759, 41.59438063008031, 42.35764393825511, 43.10739495724603, 43.84432688501444, 44.56907560181162, 45.282226093689346, 45.984317979067605, 46.67585028684534, 47.35728560633516, 48.02905370710524, 48.691554709210095, 49.3451618702381, 49.990224044306906, 50.62706785900207, 51.2559996488216, 51.877307177608984, 52.491261177456956, 53.09811672743206, 53.698114492037796, 54.291481836472286, 54.87843383333748, 55.459174173440424, 56.03389599162278, 56.602782617111686, 57.166008256655466, 57.723738617660594, 58.276131477647006, 58.823337205568336, 59.365499239878375, 59.90275452765089, 60.43523392856191, 60.9630625871109, 61.486360276080745, 62.005241713906734, 62.519816858337, 63.0301911785138, 63.53646590738267, 64.03873827614032, 64.5371017322594, 65.03164614247436, 65.52245798197744, 66.0096205109528, 66.49321393946904, 66.97331558165536, 67.45, 67.92333914053403, 68.393402459594, 68.86025704279646, 69.32396771680051, 69.78459715438645, 70.24220597333202, 70.69685282952842, 71.14859450474057, 71.59748598938373, 72.04358056065787, 72.48692985635411, 72.92758394462275, 73.36559138996972, 73.80099931572742, 74.23385346322794, 74.66419824788854, 75.09207681240412, 75.51753107722736, 75.9406017885031, 76.36132856361262, 76.77974993447165, 77.19590338871616, 77.60982540890039, 78.02155150982323, 78.43111627409112, 78.83855338601794, 79.24389566395635, 79.64717509114809, 80.04842284517541, 80.44766932609049], [0.0, 8.061017305526642, 11.4, 13.962091533864118, 16.122034611053284, 18.02498266295976, 19.745379206285204, 21.327447104611466, 22.8, 24.183051916579924, 25.491174943497604, 26.73536983099355, 27.924183067728237, 29.064411227478878, 30.16156494613633, 31.22018577779447, 32.24406922210657, 33.236425800618214, 34.2, 35.13715981692317, 36.04996532591952, 36.940221980924804, 37.80952261005156, 38.65928090381403, 39.49075841257041, 40.305086527633215, 41.10328454028948, 41.88627460159235, 42.65489420922293, 43.409906703424284, 44.15201014676455, 44.88184488186732, 45.6, 46.30701890642498, 47.00340413204133, 47.6896215124423, 48.36610383315985, 49.03325402214297, 49.69144795636368, 50.34103693806873, 50.98234988699521, 51.615695287383275, 52.241362922496585, 52.859625424325515, 53.4707396619871, 54.07494798887929, 54.67247936576501, 55.263550374546156, 55.84836613545647, 56.42712113868649, 57.00000000000001, 57.56717814866385, 58.128822454957756, 58.6850918036259, 59.23613761885561, 59.78210434569864, 60.32312989227266, 60.85934603657848, 61.39087880133335, 61.91784879984123, 62.44037155558894, 62.95855779796739, 63.47251373626224, 63.982341313834404, 64.48813844421313, 64.98999923065087, 65.48801417053353, 65.98227034590428, 66.47285160123643, 66.95983870948317, 67.44330952733563, 67.92333914053401, 68.4, 68.87336204948906, 69.34349284539971, 69.81045766932058, 70.27431963384635, 70.73513978214788, 71.19297718174175, 71.64788901286626, 72.09993065183905, 72.54915574973978, 72.99561630673449, 73.43936274233322, 73.88044396184961, 74.3189074193102, 74.75479917704281, 75.18816396215564, 75.61904522010312, 76.0474851655201, 76.4735248304928, 76.89720411042263, 77.31856180762806, 77.73763567281938, 78.15446244457192, 78.56907788691426, 78.98151682514082, 79.3918131799495, 79.8, 80.20610949298064, 80.61017305526643, 81.01222130024581], [0.0, 8.116803558051656, 11.478893674914843, 14.058716157601308, 16.23360711610331, 18.14972451581566, 19.882027059633533, 21.475043655368896, 22.957787349829687, 24.35041067415496, 25.66758656360196, 26.920391899079036, 28.117432315202617, 29.265551421423794, 30.370297989976983, 31.436245004771163, 32.46721423220662, 33.46643841223622, 34.43668102474453, 35.380326454118546, 36.29944903163132, 37.1958667058586, 38.071183328076366, 38.92682237224097, 39.764054119267065, 40.58401779025828, 41.387739730504734, 42.176148472803916, 42.95008731073779, 43.7103248672439, 44.45756403583084, 45.19244959061192, 45.91557469965937, 46.6274865288705, 47.32869108690837, 48.01965743318042, 48.70082134830992, 49.372588548707874, 50.035337512602034, 50.68942197342558, 51.33517312720392, 51.97290159304173, 52.60289915964709, 53.22544034575947, 53.84078379815807, 54.44917354744698, 55.050840138911596, 55.64600165330839, 56.234864630405234, 56.81762490636158, 57.394468374574224, 57.965571678367844, 58.53110284284759, 59.09122185231915, 59.646081178900594, 60.19582626727537, 60.740595979953966, 61.28052300690653, 61.815734242990274, 62.34635113621326, 62.872490009542325, 63.394262358670915, 63.911775127905806, 64.42513096610669, 64.93442846441324, 65.43976237731918, 65.94122382849746, 66.43890050264227, 66.93287682447244, 67.42323412593021, 67.91005080251377, 68.39340245959401, 68.87336204948906, 69.35, 69.82338433504924, 70.29358078800652, 70.76065290823709, 71.22466216136094, 71.68566802367124, 72.14372807112203, 72.59889806326264, 73.05123202246489, 73.50078230876187, 73.94759969059172, 74.3917334117172, 74.83323125457032, 75.27213960025315, 75.70850348540777, 76.14236665615273, 76.57377161926921, 77.00275969080589, 77.42937104226019, 77.85364474448194, 78.27561880943516, 78.6953302299444, 79.11281501754314, 79.52810823853413, 79.94124404836343, 80.3522557244039, 80.7611756972371, 81.16803558051656, 81.57286619949063], [0.0, 8.172209003690496, 11.557248807566618, 14.154681204463776, 16.34441800738099, 18.273614858587777, 20.017742130420206, 21.621632685807977, 23.114497615133235, 24.516627011071485, 25.84279396659734, 27.1041509736055, 28.30936240892755, 29.465318596614566, 30.577606184919052, 31.650829373019594, 32.68883601476198, 33.69488091683958, 34.671746422699854, 35.621833192580084, 36.547229717175554, 37.449766354411345, 38.331057903480826, 39.19253755499891, 40.03548426084041, 40.86104501845248, 41.67025317897649, 42.46404361339132, 43.243265371615955, 44.00869232322179, 44.76103215968103, 45.50093405634657, 46.22899523026647, 46.94576658230218, 47.65175757514092, 48.34744046999799, 49.03325402214297, 49.70960671741429, 50.37687961753884, 51.035428870540514, 51.68558793319468, 52.32766954489756, 52.961967486112144, 53.58875814944772, 54.208301947211, 54.820844575763324, 55.426618154096325, 56.02584225158958, 56.6187248178551, 57.20546302583346, 57.78624403783309, 58.36124570294915, 58.93063719322913, 59.494579585034465, 60.05322639126061, 60.606724049399006, 61.155212369838104, 61.69882494829217, 62.23768954580496, 62.7719284393908, 63.30165874603919, 63.82699272251513, 64.34803804312916, 64.86489805742394, 65.37767202952396, 65.88645536071886, 66.39133979669336, 66.89241362067898, 67.38976183367916, 67.88346632280941, 68.37360601869702, 68.86025704279646, 69.34349284539971, 69.82338433504924, 70.3, 70.77340602231887, 71.24366638516017, 71.71084297370935, 72.1749956702458, 72.63618244373805, 73.09445943435111, 73.54988103321446, 74.0024999577717, 74.45236732300725, 74.89953270882269, 75.34404422381373, 75.7859485656807, 76.22529107848655, 76.66211580696165, 77.09646554803922, 77.52838189979202, 77.95790530792884, 78.38507510999781, 78.80992957743332, 79.23250595557357, 79.65284050176741, 80.07096852168083, 80.4869244039055, 80.90074165296632, 81.3124529208165, 81.72209003690496, 82.12968403689375], [0.0, 8.227241335952167, 11.635076278220096, 14.250000000000004, 16.454482671904334, 18.39667089448523, 20.152543263816607, 21.76723455104024, 23.27015255644019, 24.681724007856502, 26.01682148149539, 27.28667257105564, 28.500000000000007, 29.663740492392396, 30.783518317437334, 31.863968679372004, 32.90896534380867, 33.92178503557854, 34.90522883466029, 35.861713567536064, 36.79334178897046, 37.701956182670415, 38.58918242202081, 39.45646334886086, 40.305086527633215, 41.13620667976084, 41.95086411505728, 42.75, 43.53446910208048, 44.30505050217187, 45.0624566573994, 45.807341114716536, 46.54030511288038, 47.26190326256445, 47.972648457219876, 48.673016138308085, 49.363448015713004, 50.04435532605051, 50.71612169714873, 51.37910567536185, 52.03364296299078, 52.68004840544473, 53.31861776152867, 53.9496292851026, 54.57334514211128, 55.19001268345569, 55.79986559123597, 56.40312491343011, 57.000000000000014, 57.59068935166517, 58.17538139110049, 58.75425516505167, 59.32748098478479, 59.895221011362835, 60.45762979144981, 61.01485474865936, 61.56703663487467, 62.1143099454546, 62.65680330179637, 63.19463980433783, 63.72793735874401, 64.25680897772624, 64.7813630606828, 65.30170365312073, 65.81793068761733, 66.33014020790246, 66.83842457748388, 67.34287267409967, 67.84357007115707, 68.34059920720625, 68.83403954439984, 69.32396771680052, 69.81045766932058, 70.29358078800652, 70.77340602231887, 71.25, 71.72342713507213, 72.19374972946066, 72.66102806869719, 73.12532051211811, 73.58668357794092, 74.0451720235695, 74.50083892145109, 74.95373573078263, 75.40391236534083, 75.85141725768874, 76.2962974199928, 76.73859850166669, 77.17836484404162, 77.6156395322489, 78.05046444448617, 78.48288029882696, 78.91292669772172, 79.34064217032781, 79.76606421279666, 80.18922932663713, 80.61017305526643, 81.02893001885191, 81.44553394754068, 81.86001771316691, 82.27241335952168, 82.68275213126375], [0.0, 8.28190799272728, 11.712386605641056, 14.34468542701443, 16.56381598545456, 18.518909255137032, 20.286448678859497, 21.911868929874515, 23.424773211282112, 24.84572397818184, 26.189692628971425, 27.46798136012183, 28.68937085402886, 29.86084392645326, 30.988062217570175, 32.07569173065485, 33.12763197090912, 34.14718143566172, 35.13715981692317, 36.10000000000001, 37.037818510274064, 37.952470275332544, 38.84559177049566, 39.71863542469706, 40.57289735771899, 41.409539963636405, 42.22961046469646, 43.03405628104328, 43.82373785974903, 44.59943945836092, 45.361878267990626, 46.111712178144074, 46.849546422564224, 47.57593929708588, 48.291407103127575, 48.99642844126498, 49.69144795636368, 50.37687961753884, 51.05310960166874, 51.720498837501566, 52.37938525794285, 53.030085800420885, 53.67289818893704, 54.30810252623452, 54.93596272024366, 55.5567277654111, 56.17063289655904, 56.777900630438964, 57.37874170805772, 57.97335594909096, 58.56193302820529, 59.14465318183886, 59.72168785290652, 60.29320027996524, 60.85934603657848, 61.42027352592954, 61.97612443514035, 62.52703415323648, 63.07313215625177, 63.61454236257619, 64.1513834613097, 64.68376921608697, 65.21180874657595, 65.73560678962355, 66.25526394181824, 66.7708768850612, 67.28253859657795, 67.79033854466284, 68.29436287132344, 68.79469456288037, 69.29141360947979, 69.78459715438645, 70.27431963384635, 70.76065290823708, 71.24366638516017, 71.72342713507213, 72.20000000000002, 72.67344769584007, 73.14383090869661, 73.61120838567997, 74.07563702054813, 74.53717193454553, 74.99586655276411, 75.45177267632617, 75.90494055066509, 76.35541893015846, 76.8032551393494, 77.24849513097328, 77.69118354099132, 78.13136374081795, 78.56907788691427, 79.00436696790881, 79.43727084939412, 79.86782831653808, 80.29607711463869, 80.72205398774241, 81.14579471543799, 81.5673341479296, 81.9867062394874, 82.40394408036549, 82.81907992727281, 83.23214523247616], [0.0, 8.336216168022517, 11.789189963691314, 14.438749945892134, 16.672432336045034, 18.640346026831157, 20.419475997194446, 22.05555485586341, 23.578379927382628, 25.008648504067548, 26.361430158472057, 27.648101200624975, 28.877499891784268, 30.056654837157115, 31.191264802825806, 32.28602638913621, 33.34486467209007, 34.37109977873853, 35.36756989107395, 36.336723847920034, 37.280692053662314, 38.20134159947789, 39.10031969178769, 39.979088283751544, 40.83895199438889, 41.681080840112585, 42.50652891027448, 43.316249837676395, 44.11110971172682, 44.89189793270051, 45.65933639465208, 46.41408730116321, 47.156759854765255, 47.88791601228853, 48.60807546077092, 49.317719939186155, 50.017297008135095, 50.707223351313566, 51.38788767793438, 52.05965328351698, 52.722860316944114, 53.37782779394456, 54.024855390829146, 54.66422504710005, 55.29620240124995, 55.92103808049346, 56.538968862192746, 57.15021872224113, 57.754999783568536, 58.35351317615761, 58.945949818456576, 59.53249112879455, 60.11330967431423, 60.68856976400087, 61.25842799158333, 61.823033733390986, 62.38252960565161, 62.93705188519717, 63.48673089709377, 64.0316913723197, 64.57205277827242, 65.10792962458567, 65.63943174647386, 66.16666456759023, 66.68972934418014, 67.20872339213118, 67.72374029836215, 68.23487011785103, 68.74219955747706, 69.2458121477393, 69.74578840331509, 70.24220597333202, 70.7351397821479, 71.22466216136094, 71.71084297370935, 72.19374972946066, 72.67344769584007, 73.15, 73.62346772599075, 74.09391000615369, 74.56138410732463, 75.02594551220265, 75.48764799621195, 75.94654370015795, 76.40268319895578, 76.85611556668734, 77.30688843822392, 77.75504806763354, 78.20063938357538, 78.64370604186962, 79.08429047541617, 79.5224339416243, 79.95817656750309, 80.39155739255212, 80.82261440958219, 81.25138460358691, 81.67790398877779, 82.1022076438874, 82.5243297458392, 82.94430360187492, 83.36216168022517, 83.77793563940331], [0.0, 8.390172823011456, 11.865496196956958, 14.53220561373944, 16.780345646022912, 18.76099677522493, 20.551642270144743, 22.198310746541054, 23.730992393913915, 25.170518469034366, 26.53205608316099, 27.827055180165942, 29.06441122747888, 30.251198323372257, 31.393152119530782, 32.49499961532543, 33.560691292045824, 34.593568766462944, 35.59648859087088, 36.57191545434831, 37.52199355044986, 38.448602055211325, 39.35339883669516, 40.23785531064001, 41.103284540289486, 41.950864115057286, 42.78165494695128, 43.596616841218314, 44.39662149308211, 45.18246341225765, 45.95486916530174, 46.71450524194814, 47.46198478782783, 48.19787339707013, 48.92269412041819, 49.6369318149299, 50.34103693806873, 51.035428870540514, 51.720498837501566, 52.39661248592318, 53.06411216632198, 53.72331895927504, 54.37453448076592, 55.01804249516699, 55.654110360331885, 56.282990325674774, 56.90492070111337, 57.520126912238304, 58.12882245495776, 58.73120976108019, 59.3274809847848, 59.917818718641634, 60.502396646744515, 61.08138014157834, 61.654926810434226, 62.22318699648871, 62.786304239061565, 63.34441569704469, 63.89765253904091, 64.4461403033572, 64.98999923065087, 65.52934457172604, 66.0642868727121, 66.59493223962318, 67.12138258409165, 67.64373585188802, 68.16208623567798, 68.67652437332572, 69.18713753292589, 69.69400978563367, 70.19722216726244, 70.69685282952842, 71.19297718174175, 71.68566802367124, 72.1749956702458, 72.66102806869719, 73.14383090869661, 73.62346772599075, 74.10000000000002, 74.57348724580339, 75.04398710089971, 75.5115554071031, 75.9762462879024, 76.43811222158747, 76.89720411042265, 77.35357134612468, 77.80726187188444, 78.2583222411521, 78.70679767339033, 79.15273210698416, 79.59616824948297, 80.03714762533708, 80.47571062128002, 80.91189652949683, 81.34574358870907, 81.77728902329791, 82.20656908057897, 82.63361906633403, 83.05847337869871, 83.48116554049783, 83.90172823011457, 84.32019331097388], [0.0, 8.44378469644981, 11.941314835477709, 14.625064102423623, 16.88756939289962, 18.880876568634203, 20.682964004223383, 22.340154430979208, 23.882629670955417, 25.33135408934943, 26.701591712854874, 28.004865648668986, 29.250128204847247, 30.44449868202793, 31.59374938180019, 32.70263750831116, 33.77513878579924, 34.81461618343652, 35.82394450643313, 36.805604192839986, 37.76175313726841, 38.694282523390974, 39.60486081278408, 40.49496882329952, 41.365928008446765, 42.21892348224905, 43.055022935773714, 43.875192307270865, 44.680308861958416, 45.47117218634242, 46.24851348962472, 47.01300352030276, 47.765259341910834, 48.50585016263503, 49.23530237542977, 49.95410393551264, 50.66270817869886, 51.36153716547043, 52.05098462085036, 52.73141852823609, 53.40318342570975, 54.06660244550235, 54.721979130875745, 55.369599059411655, 56.00973129733797, 56.6426297059026, 57.26853411778584, 57.88767139901208, 58.500256409694494, 59.10649287514866, 59.70657417738855, 60.30068407572174, 60.88899736405586, 61.47168047157976, 62.04889201267014, 62.62078329117259, 63.18749876360038, 63.74917646526895, 64.30594840292771, 64.85794091705348, 65.40527501662233, 65.94806668887269, 66.48642718630623, 67.02046329293763, 67.55027757159849, 68.0759685939172, 68.59763115443565, 69.11535647017962, 69.62923236687304, 70.13934345287244, 70.6457712817972, 71.14859450474057, 71.64788901286626, 72.14372807112203, 72.63618244373805, 73.12532051211811, 73.61120838567997, 74.09391000615369, 74.57348724580339, 75.05000000000001, 75.52350627453681, 75.9940622680483, 76.46172244986377, 76.9265396336011, 77.38856504678195, 77.84784839672835, 78.30443793298053, 78.75838050645785, 79.20972162556816, 79.65850550945581, 80.10477513856462, 80.54857230267957, 80.98993764659905, 81.42891071357887, 81.86552998668, 82.29983292814147, 82.73185601689353, 83.16163478431626, 83.58920384834396, 84.01459694600696, 84.4378469644981, 84.85898597084461], [0.0, 8.497058314499203, 12.016655108639842, 14.717336715588187, 16.994116628998405, 19.0, 20.813457185196317, 22.481103175778543, 24.033310217279684, 25.491174943497604, 26.870057685088806, 28.181554250963522, 29.434673431176375, 30.636579443534494, 31.79308100829487, 32.90896534380867, 33.98823325799681, 35.03426893771297, 36.04996532591953, 37.03781851027407, 38.0, 38.93841291064648, 39.85473623046576, 40.750460120101714, 41.62691437039263, 42.48529157249601, 43.32666615376725, 44.15201014676456, 44.962206351557086, 45.758059399410726, 46.54030511288038, 47.30961847235719, 48.06662043455937, 48.8118837989275, 49.54593827954014, 50.26927491022722, 50.98234988699521, 51.68558793319469, 52.37938525794285, 53.06411216632198, 53.74011537017761, 54.407720040450144, 55.067231635519875, 55.71893753473769, 56.363108501927044, 57.0, 57.62985337479179, 58.252896923672395, 58.86934686235275, 59.47940820149441, 60.08327554319922, 60.681133806150996, 61.27315888706899, 61.85951826517889, 62.44037155558894, 63.0158710167526, 63.58616201658974, 64.1513834613097, 64.71166819052033, 65.26714334180714, 65.81793068761733, 66.36414694697733, 66.90590407430423, 67.44330952733563, 67.97646651599362, 68.50547423381579, 69.03042807342281, 69.55141982734789, 70.06853787542595, 70.58186735982551, 71.0914903487049, 71.59748598938374, 72.09993065183906, 72.59889806326264, 73.09445943435111, 73.58668357794093, 74.07563702054814, 74.56138410732463, 75.04398710089971, 75.52350627453681, 76.0, 76.47352483049282, 76.94413557900305, 77.41188539236077, 77.87682582129295, 78.33900688673556, 78.79847714264534, 79.25528373553401, 79.70947246093152, 80.16108781697015, 80.61017305526643, 81.05677022926587, 81.50092024020343, 81.94266288082174, 82.38203687697946, 82.8190799272728, 83.25382874078527, 83.68631907307193, 84.1165857604789, 84.54466275289057, 84.97058314499202, 85.3943792061281], [0.0, 8.55, 12.091525958289964, 14.809034404713904, 17.1, 19.1183812076232, 20.943137300796177, 22.62117370960225, 24.183051916579927, 25.65, 27.037473994439644, 28.357141957538673, 29.618068809427808, 30.827463405217113, 31.9911706569172, 33.114007610073415, 34.2, 35.252553099031, 36.27457787486989, 37.26858596727276, 38.2367624152464, 39.18102219187244, 40.10305474649032, 41.00435952432375, 41.886274601592355, 42.75000000000001, 43.596616841218314, 44.42710321414171, 45.2423474192045, 46.043159101000015, 46.830278666691704, 47.60438530219669, 48.366103833159855, 49.116010627900145, 49.854638700927325, 50.582482145501714, 51.3, 52.00761963404978, 52.70573972538475, 53.39473288630631, 54.07494798887929, 54.74671223005086, 55.41033297138721, 56.066099382782106, 56.714283915077345, 57.355143622869605, 57.98892135572105, 58.61584683342893, 59.236137618855615, 59.85, 60.457629791449826, 61.05921306404138, 61.654926810434226, 62.24493955334844, 62.82941190238852, 63.40849706466792, 63.9823413138344, 64.55108442156492, 65.11486005513642, 65.67379614427661, 66.22801522014683, 66.77763472900189, 67.32276732280098, 67.86352112880675, 68.4, 68.9323037479526, 69.46052835963746, 69.98476619950945, 70.505106198062, 71.02163402794955, 71.53443226866347, 72.04358056065787, 72.54915574973978, 73.05123202246489, 73.54988103321446, 74.0451720235695, 74.53717193454553, 75.02594551220265, 75.5115554071031, 75.9940622680483, 76.4735248304928, 76.95, 77.42354293107493, 77.89420710168375, 78.36204438374487, 78.82710510985419, 79.28943813648827, 79.74909090390938, 80.20610949298064, 80.66053867908397, 81.11242198331894, 81.56180172114885, 82.0087190486475, 82.45321400648977, 82.89532556181923, 83.33509164811665, 83.77254920318471, 84.2077342053567, 84.64068170802975, 85.07142587261602, 85.50000000000001, 85.92643656058362], [0.0, 8.602615881230546, 12.165936051122413, 14.90016778429022, 17.205231762461093, 19.23603389475076, 21.072019362177898, 22.760382246350787, 24.331872102244827, 25.807847643691638, 27.203860020225076, 28.531649093594297, 29.80033556858044, 31.017172662897572, 32.18804125758509, 33.317788041825345, 34.410463524922186, 35.469493934929496, 36.497808153367245, 37.49793327638206, 38.47206778950152, 39.422138450368216, 40.34984510503108, 41.25669642615609, 42.144038724355795, 43.01307940615274, 43.86490624633775, 44.700503352870655, 45.52076449270157, 46.32650429289912, 47.11846771702153, 47.89733813063102, 48.66374420448965, 49.41826585383183, 50.161439373287536, 50.893761896719724, 51.615695287383275, 52.32766954489757, 53.030085800420885, 53.72331895927504, 54.40772004045015, 55.08361825443206, 55.75132285426061, 56.411124789353394, 57.06329818718859, 57.70810168425228, 58.34577962457954, 58.976563141641286, 59.60067113716088, 60.21831116861382, 60.829680255612075, 61.434965614054036, 62.034345325795144, 62.62798895062814, 63.216058086533685, 63.7987068834471, 64.37608251517018, 64.9483256135214, 65.51557066835335, 66.07794639666098, 66.63557608365069, 67.18857789833031, 67.73706518590838, 68.28114673905236, 68.82092704984437, 69.35650654408713, 69.88798179944818, 70.4154457487844, 70.93898786985899, 71.45869436254766, 71.9746483145281, 72.48692985635411, 72.99561630673449, 73.50078230876186, 74.0024999577717, 74.50083892145109, 74.99586655276411, 75.48764799621195, 75.9762462879024, 76.46172244986377, 76.94413557900305, 77.42354293107492, 77.90000000000002, 78.3735605928428, 78.84427690073643, 79.31219956601885, 79.77737774582467, 80.23985917235899, 80.69969021006216, 81.15691590985946, 81.61158006067522, 82.06372523837801, 82.51339285231218, 82.96062318955904, 83.4054554570623, 83.84792782174168, 84.28807744871159, 84.72594053771255, 85.1615523578569, 85.59494728078289, 86.02615881230548, 86.45521962264628], [0.0, 8.654911900187084, 12.23989379038887, 14.990747146156528, 17.30982380037417, 19.352971348090193, 21.200117924200327, 22.898744507068503, 24.47978758077774, 25.96473570056125, 27.36923455268707, 28.705095366502444, 29.981494292313055, 31.205728640748003, 32.38371504321269, 33.52032965231696, 34.61964760074834, 35.685115944886604, 36.71968137116661, 37.725886338163086, 38.70594269618039, 39.66178891578139, 40.59513517652084, 41.507499322411604, 42.400235848400655, 43.274559500935425, 44.13156466748035, 44.972241438469574, 45.79748901413701, 46.6081269737371, 47.404904809523664, 48.18851004129511, 48.95957516155548, 49.71868361089219, 50.46637494411502, 51.20314931720508, 51.9294714011225, 52.64577380949016, 53.35246011197609, 54.04990749298282, 54.73846910537414, 55.418476160933906, 56.09023979267695, 56.75405271872661, 57.41019073300489, 58.05891404427058, 58.70046848194655, 59.33508658458332, 59.96298858462611, 60.58438330130958, 61.199468951944354, 61.80843389052986, 62.411457281496006, 63.00870971540363, 63.60035377260098, 64.1865445401137, 64.76743008642538, 65.34315189826705, 65.9138452830663, 66.47963974029943, 67.04065930463392, 67.59702286343682, 68.14884445095161, 68.69623352120551, 69.23929520149667, 69.77813052812463, 70.31283666586066, 70.84350711250819, 71.37023188977321, 71.89309772154765, 72.41218820060612, 72.92758394462277, 73.43936274233322, 73.94759969059172, 74.45236732300727, 74.95373573078263, 75.45177267632617, 75.94654370015795, 76.43811222158747, 76.9265396336011, 77.41188539236077, 77.89420710168376, 78.3735605928428, 78.85, 79.32357783156279, 79.79434503772808, 80.26235107446081, 80.72764396413413, 81.19027035304168, 81.65027556597711, 82.10770365806121, 82.56259746398486, 83.01499864482321, 83.46494773256616, 83.91248417249963, 84.35764636356326, 84.80047169680131, 85.24099659201552, 85.67925653272208, 86.11528609950733, 86.54911900187085, 86.98078810863926], [0.0, 8.706893820416097, 12.313407326974936, 15.08078247306817, 17.413787640832194, 19.46920645532324, 21.32744710461147, 23.036275740666067, 24.62681465394987, 26.12068146124829, 27.533615817759934, 28.877499891784264, 30.16156494613634, 31.393152119530786, 32.57821357901627, 33.721654763667814, 34.82757528166439, 35.89944289261325, 36.94022198092481, 37.952470275332544, 38.93841291064648, 39.900000000000006, 40.838951994388886, 41.75679585408823, 42.65489420922294, 43.534469102080486, 44.39662149308211, 45.242347419204506, 46.072551481332134, 46.888058181161654, 47.68962151244231, 48.47793312425768, 49.25362930789974, 50.0172970081351, 50.769479020372074, 51.51067850455864, 52.24136292249658, 52.961967486112144, 53.67289818893703, 54.37453448076591, 55.06723163551987, 55.7513228542606, 56.4271211386865, 57.09492096500354, 57.75499978356853, 58.407619365969715, 59.05302701809621, 59.69145667513904, 60.32312989227268, 60.94825674291267, 61.56703663487468, 62.179659053423585, 62.78630423906157, 63.38714380692666, 63.982341313834404, 64.57205277827244, 65.15642715803254, 65.73560678962355, 66.30972779313757, 66.87892044583256, 67.44330952733563, 68.00301463905846, 68.55815050014112, 69.10882722199821, 69.65515056332877, 70.19722216726242, 70.73513978214788, 71.268997467342, 71.7988857852265, 72.32489198056227, 72.8471001481871, 73.36559138996974, 73.88044396184962, 74.3917334117172, 74.89953270882269, 75.40391236534084, 75.90494055066509, 76.40268319895578, 76.89720411042265, 77.38856504678195, 77.87682582129295, 78.36204438374487, 78.84427690073645, 79.32357783156279, 79.80000000000001, 80.27359466225491, 80.74441157132796, 81.21249903801755, 81.67790398877777, 82.14067202062569, 82.6008474532798, 83.0584733786987, 83.51359170817646, 83.96624321714054, 84.41646758778765, 84.86430344968372, 85.30978841844588, 85.75295913261537, 86.19385128882455, 86.63249967535279, 87.06893820416097, 87.50319994148786], [0.0, 8.758567234428243, 12.386484569885033, 15.17028345153775, 17.517134468856487, 19.58475172168389, 21.45402060220881, 23.17299074353589, 24.772969139770066, 26.275701703284728, 27.697021500515177, 29.048881217699247, 30.3405669030755, 31.579463263329863, 32.77155779025465, 33.92178503557854, 35.03426893771297, 36.11249783662161, 37.159453709655104, 38.17770946507923, 39.16950344336778, 40.13679733112746, 41.08132178983534, 42.004612841924875, 42.90804120441762, 43.79283617214122, 44.66010523946401, 45.51085035461324, 46.34598148707178, 47.16632803176436, 47.97264845721987, 48.765638517300275, 49.54593827954013, 50.31413817208837, 51.07078421171933, 51.81638254451964, 52.551403406569456, 53.27628459267782, 53.99143450585473, 54.697234847842175, 55.394043001030354, 56.082194143952684, 56.7620031359007, 57.433766200728996, 58.097762435398494, 58.75425516505167, 59.40349316328124, 60.04571175362984, 60.681133806151, 61.3099706409977, 61.93242284942517, 62.54868104124979, 63.15892652665973, 63.76333193928937, 64.36206180662643, 64.95527307309239, 65.5431155805093, 66.12573251012046, 66.70326078985946, 67.27583147014981, 67.84357007115707, 68.40659690409983, 68.96502736894983, 69.51897223060767, 70.06853787542595, 70.6138265497629, 71.15493658208122, 71.69196258995844, 72.22499567324321, 72.75412359447401, 73.2794309475722, 73.80099931572744, 74.31890741931021, 74.83323125457032, 75.34404422381374, 75.85141725768874, 76.35541893015846, 76.85611556668735, 77.35357134612468, 77.84784839672835, 78.33900688673556, 78.82710510985419, 79.31219956601886, 79.79434503772808, 80.27359466225492, 80.75, 81.22361109923641, 81.69447655747604, 82.16264357967069, 82.62815803344523, 83.09106450154553, 83.55140633167105, 84.00922568384975, 84.4645635755019, 84.91745992432888, 85.36795358915428, 85.81608240883524, 86.26188323935435, 86.70539198919523, 87.14664365309774, 87.58567234428244, 88.02251132522863], [0.0, 8.809937570720919, 12.459133196173802, 15.259259483998564, 17.619875141441838, 19.699619285661335, 21.57985171404104, 23.308903878132064, 24.918266392347604, 26.429812712162754, 27.859468767368842, 29.21925734853643, 30.518518967997128, 31.764681644870933, 32.9637679885052, 34.12074149252914, 35.239750282883676, 36.324303159179806, 37.377399588521406, 38.40162756967471, 39.39923857132267, 40.37220578566398, 41.322270024769935, 42.25097632008047, 43.15970342808208, 44.0496878536046, 44.922043586640186, 45.77777845199569, 46.61780775626413, 47.44296575889834, 48.254015376961114, 49.05165644501722, 49.83653278469521, 50.60923828709537, 51.37032217146395, 52.12029355251177, 52.85962542432551, 53.58875814944773, 54.30810252623452, 55.01804249516699, 55.718937534737684, 56.41112478935339, 57.09492096500354, 57.770624022940936, 58.43851469707286, 59.098857856984004, 59.751903735362276, 60.39788903595887, 61.037037935994256, 61.66956299504643, 62.29566598086902, 62.91553862123411, 63.529363289741866, 64.13731363254935, 64.73955514212312, 65.33624568338772, 65.9275359770104, 66.51357004401433, 67.0944856154364, 67.67041451033089, 68.24148298505828, 68.80781205648091, 69.369517801409, 69.9267116343962, 70.47950056576735, 71.02798744157123, 71.57227116698198, 72.11244691452372, 72.64860631835961, 73.18083765576888, 73.70922601682913, 74.23385346322796, 74.75479917704281, 75.27213960025315, 75.7859485656807, 76.29629741999281, 76.80325513934942, 77.30688843822394, 77.80726187188444, 78.30443793298053, 78.79847714264534, 79.28943813648827, 79.77737774582468, 80.26235107446081, 80.74441157132796, 81.22361109923641, 81.7, 82.17362715616247, 82.64454004953987, 83.11278481677773, 83.57840630210653, 84.04144810746659, 84.50195264016094, 84.95996115818322, 85.4155138133583, 85.86864969242266, 86.31940685616416, 86.76782237673135, 87.21393237321662, 87.65777204560929, 88.0993757072092, 88.53877681558517], [0.0, 8.861010100434376, 12.531360660359274, 15.34771970033334, 17.72202020086875, 19.813820933883502, 21.704953351712142, 23.444029090580827, 25.06272132071855, 26.583030301303122, 28.02097428712999, 29.38864576669024, 30.69543940066668, 31.948826269520456, 33.15486389656878, 34.31854454955804, 35.4440404017375, 36.53488059375588, 37.59408198107782, 38.62424756548664, 39.627641867767004, 40.60624951900877, 41.56182142303198, 42.49591156805558, 43.409906703424284, 44.30505050217188, 45.18246341225764, 46.043159101000015, 46.888058181161654, 47.71799974852257, 48.533751142890246, 49.33601625587538, 50.1254426414371, 50.902627633551496, 51.66812363537117, 52.4224427130213, 53.166060602606244, 53.89942021951628, 54.6229347435672, 55.33699034100066, 56.04194857425998, 56.73814854222863, 57.42590878688818, 58.105528996817505, 58.77729153338048, 59.4414628016505, 60.09829448495191, 60.74802465924304, 61.39087880133336, 62.027070703040614, 62.65680330179638, 63.280269436847384, 63.89765253904091, 64.50912726118685, 65.11486005513642, 65.7150097009808, 66.30972779313755, 66.89915918754137, 67.48344241367657, 68.06271005477228, 68.63708909911608, 69.20670126512316, 69.77166330251845, 70.33208727174248, 70.888080803475, 71.43974733997874, 71.98718635979601, 72.53049358718029, 73.06976118751176, 73.60507794982627, 74.13652945748136, 74.66419824788854, 75.18816396215564, 75.70850348540776, 76.22529107848653, 76.73859850166669, 77.24849513097328, 77.75504806763354, 78.2583222411521, 78.75838050645785, 79.25528373553401, 79.74909090390938, 80.23985917235899, 80.72764396413412, 81.21249903801754, 81.69447655747602, 82.17362715616245, 82.65, 83.12364284606396, 83.59460209846088, 84.06292286138996, 84.52864898955856, 84.99182313611117, 85.45248679822022, 85.91068036047673, 86.36644313620887, 86.81981340684857, 87.27082845945718, 87.71952462251492, 88.16593730007072, 88.61010100434376, 89.0520493868614], [0.0, 8.911789943664518, 12.60317420335052, 15.435672968808328, 17.823579887329036, 19.92736811523288, 21.829338056844513, 23.578379927382628, 25.20634840670104, 26.735369830993548, 28.18155425096352, 29.55706345359769, 30.871345937616656, 32.13191559804675, 33.34486467209006, 34.515214036711406, 35.64715977465807, 36.744251251046066, 37.809522610051566, 38.845591770495666, 39.85473623046576, 40.838951994388886, 41.8, 42.73944314096757, 43.658676113689026, 44.55894971832259, 45.44139082378532, 46.30701890642498, 47.156759854765255, 47.991457573197344, 48.81188379892749, 49.61874645736226, 50.41269681340208, 51.194335624168424, 51.96421845847391, 52.72286031694411, 53.470739661987096, 54.208301947211, 54.93596272024365, 55.654110360331885, 56.36310850192704, 57.063298187188586, 57.75499978356853, 58.438514697072854, 59.11412690719538, 59.78210434569864, 60.442700138230094, 61.096153725091405, 61.74269187523331, 62.38252960565161, 63.015871016752605, 63.64291005288807, 64.2638311960935, 64.87881010006272, 65.48801417053353, 66.09160309751913, 66.68972934418012, 67.28253859657795, 67.87017017806866, 68.45275743167693, 69.03042807342281, 69.60330451925397, 70.17150418795367, 70.73513978214788, 71.29431954931614, 71.84914752451834, 72.39972375637907, 72.94614451771938, 73.48850250209213, 74.026887007357, 74.56138410732463, 75.09207681240412, 75.61904522010313, 76.14236665615273, 76.66211580696165, 77.17836484404162, 77.69118354099133, 78.20063938357538, 78.70679767339034, 79.20972162556816, 79.70947246093152, 80.20610949298064, 80.69969021006216, 81.19027035304168, 81.67790398877777, 82.16264357967069, 82.64454004953987, 83.12364284606397, 83.6, 84.07365818138283, 84.54466275289056, 85.01305782054895, 85.47888628193515, 85.94218987202969, 86.40300920685577, 86.86138382503471, 87.31735222737805, 87.77095191462836, 88.22221942345364, 88.67119036079306, 89.11789943664517, 89.56238049538435], [0.0, 8.962282075453773, 12.674580860920017, 15.523127906449785, 17.924564150907546, 20.040271954242538, 21.953018015753553, 23.7119695512625, 25.349161721840034, 26.886846226361317, 28.341224391334965, 29.72452690960783, 31.04625581289957, 32.313967568220406, 33.5337889299733, 34.71076922224571, 35.84912830181509, 36.95243564367578, 38.02374258276005, 39.06568187040897, 40.080543908485076, 41.07033601031284, 42.03682909069141, 42.98159489828175, 43.90603603150711, 44.81141037726887, 45.698851189061635, 46.56938371934935, 47.423939102525, 48.26336602434604, 49.08844059450249, 49.899874749341805, 50.69832344368007, 51.48439083838907, 52.25863565000525, 53.021575797028135, 53.773692452722635, 54.515433594533576, 55.247217124485104, 55.96943362229066, 56.68244878266993, 57.386605580048034, 58.08222619700454, 58.76961374724186, 59.44905381921566, 60.12081586272761, 60.78515443757629, 61.44231034067648, 62.09251162579914, 62.735974528176406, 63.37290430460009, 64.0034959982656, 64.62793513644081, 65.24639836803254, 65.85905404726066, 66.46606276890485, 67.0675778599466, 67.6637458318707, 68.25470679740702, 68.84059485507079, 69.42153844449142, 69.99766067519684, 70.56907963123793, 71.13590865378751, 71.69825660363018, 72.25622810526438, 72.80992377416693, 73.35944042861831, 73.90487128735155, 74.44630615416725, 74.98383159055024, 75.51753107722736, 76.0474851655201, 76.57377161926921, 77.09646554803922, 77.6156395322489, 78.13136374081795, 78.64370604186962, 79.15273210698416, 79.65850550945581, 80.16108781697015, 80.66053867908396, 81.15691590985948, 81.65027556597711, 82.14067202062569, 82.62815803344523, 83.11278481677773, 83.59460209846088, 84.07365818138283, 84.55, 85.0236731740049, 85.49472205931778, 85.9631897965635, 86.4291183571833, 86.89254858732134, 87.35352024961558, 87.81207206301421, 88.26824174073029, 88.72206602644012, 89.1735807288235, 89.62282075453774, 90.06982013971162], [0.0, 9.012491331479882, 12.745587471748802, 15.610092888897238, 18.024982662959765, 20.152543263816604, 22.076005073382277, 23.84481075622115, 25.491174943497604, 27.037473994439644, 28.5, 29.89105217284932, 31.220185777794477, 32.49499961532544, 33.72165476366781, 34.905228834660285, 36.04996532591953, 37.1594537096551, 38.2367624152464, 39.284538943457136, 40.30508652763321, 41.3004237266399, 42.27233137644528, 43.22239003109384, 44.15201014676455, 45.06245665739941, 45.95486916530174, 46.830278666691704, 47.6896215124423, 48.533751142890246, 49.363448015713004, 50.179428055728174, 50.98234988699521, 51.77282105506711, 52.55140340656946, 53.31861776152866, 54.07494798887929, 54.82084457576333, 55.5567277654111, 56.282990325674774, 57.0, 57.70810168425227, 58.407619365969715, 59.098857856984004, 59.78210434569864, 60.45762979144981, 61.125690180152574, 61.78652765773458, 62.44037155558895, 63.08743932035917, 63.727937358744015, 64.36206180662643, 64.98999923065088, 65.61192726936163, 66.22801522014683, 66.83842457748386, 67.44330952733561, 68.04281740198594, 68.63708909911608, 69.22625946849938, 69.81045766932057, 70.38980750080228, 70.96442770853577, 71.53443226866347, 72.09993065183906, 72.66102806869718, 73.21782569839124, 73.77042090160526, 74.3189074193102, 74.86337555841308, 75.40391236534083, 75.9406017885031, 76.4735248304928, 77.00275969080589, 77.52838189979202, 78.05046444448618, 78.56907788691427, 79.08429047541617, 79.59616824948297, 80.10477513856462, 80.61017305526642, 81.11242198331894, 81.61158006067522, 82.10770365806121, 82.6008474532798, 83.09106450154553, 83.57840630210653, 84.06292286138998, 84.54466275289056, 85.0236731740049, 85.5, 85.97368783529063, 86.44478006218768, 86.91331888726836, 87.3793453855086, 87.84289954230792, 88.3040202935291, 88.76274556366539, 89.21911230224161, 89.67315651854796, 90.12491331479882, 90.57441691780302], [0.0, 9.062422413460984, 12.81620068507044, 15.696576059765395, 18.12484482692197, 20.264192557316466, 22.198310746541054, 23.97691598183553, 25.63240137014088, 27.18726724038295, 28.657895945096875, 30.056654837157115, 31.39315211953079, 32.6750286916477, 33.908479765392016, 35.09861108363121, 36.24968965384394, 37.36532483466456, 38.448602055211325, 39.50218348395441, 40.52838511463293, 41.52923668934935, 42.506528910274476, 43.46185108805192, 44.39662149308211, 45.31211206730492, 46.20946872665818, 47.08972817929617, 47.95383196367106, 48.80263824835703, 49.636931814929895, 50.4574325545801, 51.26480274028176, 52.05965328351698, 52.84254914365885, 53.61401402618535, 54.3745344807659, 55.124563490335234, 55.864523626358796, 56.59480983270463, 57.31579189019375, 58.02781660548672, 58.73120976108019, 59.42627785752697, 60.11330967431423, 60.792577671949395, 61.46433925456289, 62.12883790962133, 62.78630423906158, 63.43695689422688, 64.08100342535221, 64.71864105495418, 65.3500573832954, 65.97543103307473, 66.59493223962316, 67.20872339213118, 67.81695953078403, 68.41978880411719, 69.01735289041446, 69.60978738654501, 70.19722216726242, 70.77978171766284, 71.3575854412129, 71.9307479455066, 72.49937930768787, 73.06358532128026, 73.62346772599074, 74.17912442190188, 74.73064966932913, 75.27813427549862, 75.82166576909268, 76.36132856361262, 76.89720411042265, 77.42937104226019, 77.95790530792884, 78.48288029882696, 79.00436696790882, 79.5224339416243, 80.03714762533708, 80.54857230267959, 81.05677022926587, 81.56180172114885, 82.06372523837803, 82.56259746398486, 83.0584733786987, 83.55140633167105, 84.04144810746659, 84.52864898955858, 85.01305782054895, 85.4947220593178, 85.97368783529063, 86.45, 86.92370217610384, 87.39483680401263, 87.86344518626618, 88.32956752979152, 88.79324298616422, 89.2545096899871, 89.71340479549308, 90.16996451147133, 90.62422413460985, 91.0762180813411], [0.0, 9.112079894294169, 12.88642696793801, 15.782585339544347, 18.224159788588338, 20.375230060050857, 22.319946236494392, 24.10829732685409, 25.77285393587602, 27.336239682882503, 28.814926687395893, 30.22135006911505, 31.565170679088695, 32.854071285002114, 34.094281045360084, 35.29093367991275, 36.448319577176676, 37.57006787324186, 38.659280903814036, 39.71863542469707, 40.750460120101714, 41.75679585408823, 42.73944314096757, 43.7, 44.639892472988784, 45.560399471470845, 46.46267319042244, 47.347756018633035, 48.21659465370818, 49.07005196655085, 49.90891703894205, 50.73391370671102, 51.54570787175204, 52.34491379303247, 53.13209952561635, 53.90779164462221, 54.67247936576501, 55.426618154096325, 56.17063289655904, 56.90492070111337, 57.629853374791786, 58.345779624579535, 59.05302701809621, 59.751903735362276, 60.4427001382301, 61.12569018015257, 61.80113267570426, 62.46927244653968, 63.13034135817739, 63.78455926005917, 64.43213483969006, 65.0732664002661, 65.70814257000423, 66.33694295036516, 66.95983870948317, 67.57699312635921, 68.18856209072017, 68.79469456288037, 69.39553299744877, 69.99121373429668, 70.5818673598255, 71.16761904124657, 71.74858883629699, 72.32489198056227, 72.89663915435335, 73.46393673088858, 74.026887007357, 74.58558842028398, 75.14013574648372, 75.69062029075994, 76.23713006140775, 76.77974993447167, 77.31856180762807, 77.85364474448194, 78.38507510999783, 78.91292669772172, 79.43727084939414, 79.9581765675031, 80.47571062128003, 80.98993764659905, 81.50092024020343, 82.0087190486475, 82.51339285231218, 83.01499864482321, 83.51359170817646, 84.00922568384975, 84.50195264016094, 84.99182313611118, 85.47888628193515, 85.96318979656351, 86.44478006218769, 86.92370217610384, 87.4, 87.87371620683855, 88.34489232547631, 88.81356878315385, 89.27978494597757, 89.74357915750855, 90.20498877556608, 90.66405020734516, 91.12079894294169, 91.57526958737279], [0.0, 9.161468222943308, 12.956272612136564, 15.868128434065566, 18.322936445886615, 20.485665720205436, 22.440922440933665, 24.23896656212884, 25.912545224273128, 27.48440466882992, 28.971106295756123, 30.385152624267008, 31.736256868131132, 33.03214343635606, 34.27907525007056, 35.48221385426789, 36.64587289177323, 37.773701168934984, 38.8688178364097, 39.93391415826904, 40.97133144041087, 41.98312160857027, 42.971094936014836, 43.936858103419276, 44.88184488186733, 45.80734111471654, 46.714505241948146, 47.60438530219669, 48.47793312425768, 49.336016255875386, 50.179428055728174, 51.008896282903436, 51.825090448546256, 52.62862814096526, 53.42008049413629, 54.199976937264466, 54.96880933765984, 55.72703562903737, 56.47508300126703, 57.21335071467149, 57.942212591512245, 58.662019228799146, 59.37309996959904, 60.07576466429704, 60.770305248534015, 61.456997160616304, 62.13610061791777, 62.80786176904927, 63.472513736262265, 64.13027756060315, 64.78136306068284, 65.42596961451929, 66.06428687271212, 66.6964954101788, 67.32276732280098, 67.94326677456715, 68.55815050014112, 69.16756826721611, 69.77166330251846, 70.37057268489436, 70.96442770853578, 71.55335421907208, 72.1374729249646, 72.71689968638653, 73.29174578354646, 73.86211816621562, 74.4281196860434, 74.98984931309037, 75.54740233786997, 76.10087056006654, 76.65034246498838, 77.19590338871618, 77.7376356728194, 78.27561880943517, 78.80992957743332, 79.34064217032783, 79.86782831653808, 80.39155739255213, 80.91189652949684, 81.42891071357889, 81.94266288082174, 82.45321400648977, 82.96062318955906, 83.46494773256616, 83.96624321714054, 84.4645635755019, 84.95996115818322, 85.45248679822022, 85.94218987202967, 86.42911835718331, 86.91331888726837, 87.39483680401263, 87.87371620683855, 88.35000000000001, 88.8237299374441, 89.29494666553086, 89.76368976373466, 90.2299977834423, 90.69390828495595, 91.15545787280102, 91.61468222943309, 92.07161614743168], [0.0, 9.210591729091027, 13.025743740761985, 15.953212842559337, 18.421183458182053, 20.59550921924486, 22.561249965372046, 24.368935142923256, 26.05148748152397, 27.631775187273075, 29.126448461836198, 30.548076862545706, 31.906425685118673, 33.20926075660222, 34.4628785797124, 35.672468375485316, 36.84236691636411, 37.97624257348271, 39.07723122228596, 40.148038557319346, 41.19101843848972, 42.20823379389382, 43.20150460342788, 44.17244616273815, 45.12249993074409, 46.052958645455135, 46.964986958371455, 47.859638527678, 48.73787028584651, 49.60055443238513, 50.448488579936665, 51.28240438980996, 52.10297496304794, 52.91082119944842, 53.70651729538977, 54.49059551885995, 55.26355037454615, 56.02584225158958, 56.77790063043896, 57.5201269122383, 58.252896923672395, 58.97656314164128, 59.69145667513904, 60.39788903595887, 61.09615372509141, 61.78652765773458, 62.46927244653968, 63.1446355599587, 63.81285137023735, 64.47414210363718, 65.12871870380994, 65.7767816178323, 66.41852151320444, 67.05411993308093, 67.68374989611614, 68.3075764465407, 68.9257571594248, 69.53844260551139, 70.14577677950399, 70.7478974952613, 71.34493675097063, 71.9370210670417, 72.52427179917079, 73.10680542876977, 73.68473383272821, 74.25816453427865, 74.82720093655783, 75.39194254030069, 75.95248514696542, 76.50892104846336, 77.06133920455835, 77.60982540890039, 78.15446244457192, 78.6953302299444, 79.23250595557356, 79.76606421279666, 80.29607711463869, 80.82261440958219, 81.34574358870907, 81.86552998668, 82.38203687697944, 82.89532556181923, 83.4054554570623, 83.91248417249962, 84.41646758778764, 84.91745992432888, 85.41551381335829, 85.91068036047673, 86.40300920685576, 86.89254858732134, 87.37934538550859, 87.86344518626618, 88.3448923254763, 88.82372993744409, 89.30000000000001, 89.77374337744862, 90.24499986148818, 90.71380821021683, 91.1802061853339, 91.64423058763711, 92.10591729091027, 92.56530127428962], [0.0, 9.259454627568516, 13.094846314485709, 16.037845865327427, 18.518909255137032, 20.7047699818182, 22.680939133995313, 24.498214220632487, 26.189692628971418, 27.778363882705545, 29.280966514102637, 30.710136762964765, 32.07569173065485, 33.3854384425306, 34.64570680473989, 35.86171356753606, 37.037818510274064, 38.177709465079225, 39.28453894345713, 40.36102699387121, 41.4095399636364, 42.43215172484186, 43.43069191251735, 44.40678439157692, 45.361878267990626, 46.29727313784258, 47.21413983119887, 48.11353759598227, 48.996428441264975, 49.863689193640695, 50.71612169714872, 51.554461494617506, 52.379385257942836, 53.19151718084379, 53.99143450585472, 54.779672324686274, 55.55672776541109, 56.32306365957022, 57.07911176603925, 57.825275615426165, 58.561933028205274, 59.28943835119371, 60.008124449944276, 60.71830448884421, 61.42027352592953, 62.11430994545459, 62.80067674794596, 63.47962271469483, 64.1513834613097, 64.8161823929796, 65.47423157242855, 66.12573251012044, 66.7708768850612, 67.4098472035058, 68.04281740198593, 68.66995340030455, 69.29141360947978, 69.90734939904388, 70.51790552760342, 71.1232205401302, 71.72342713507211, 72.31865250403936, 72.90901864652959, 73.49464266189747, 74.07563702054813, 74.65210981613312, 75.22416500035078, 75.79190260179513, 76.35541893015845, 76.91480676696783, 77.47015554392543, 78.02155150982323, 78.56907788691426, 79.11281501754314, 79.65284050176741, 80.18922932663712, 80.72205398774241, 81.25138460358691, 81.77728902329791, 82.29983292814147, 82.8190799272728, 83.33509164811663, 83.84792782174168, 84.35764636356326, 84.86430344968372, 85.36795358915428, 85.86864969242266, 86.36644313620887, 86.8613838250347, 87.35352024961557, 87.8428995423079, 88.3295675297915, 88.81356878315384, 89.29494666553084, 89.77374337744862, 90.24999999999999, 90.72375653598125, 91.19505194910522, 91.66392420139996, 92.1304102888943, 92.59454627568516, 93.05636732647584], [0.0, 9.308061022576078, 13.163586137523469, 16.122034611053287, 18.616122045152157, 20.813457185196313, 22.800000000000004, 24.626814653949868, 26.327172275046937, 27.92418306772823, 29.43467343117637, 30.871345937616653, 32.244069222106575, 33.560691292045824, 34.82757528166438, 36.04996532591952, 37.23224409030431, 38.378118765775895, 39.49075841257041, 40.57289735771899, 41.626914370392626, 42.65489420922293, 43.65867611368902, 44.63989247298878, 45.60000000000001, 46.54030511288039, 47.46198478782783, 48.366103833159855, 49.253629307899736, 50.1254426414371, 50.9823498869952, 51.82509044854625, 52.654344550093874, 53.4707396619871, 54.274856056925664, 55.06723163551987, 55.84836613545646, 56.61872481785509, 57.3787417080577, 58.12882245495775, 58.86934686235274, 59.600671137160866, 60.323129892272675, 61.03703793599424, 61.742691875233305, 62.44037155558894, 63.130341358177375, 63.81285137023733, 64.48813844421315, 65.15642715803253, 65.81793068761735, 66.47285160123643, 67.12138258409165, 67.76370710048263, 68.4, 69.03042807342281, 69.65515056332876, 70.27431963384633, 70.888080803475, 71.49657334446177, 72.09993065183905, 72.69828058489416, 73.29174578354646, 73.88044396184961, 74.46448818060863, 75.0439871008997, 75.61904522010312, 76.189763091901, 76.75623753155179, 77.31856180762806, 77.87682582129295, 78.43111627409112, 78.98151682514082, 79.52810823853413, 80.07096852168081, 80.61017305526643, 81.14579471543799, 81.67790398877779, 82.20656908057897, 82.73185601689353, 83.25382874078525, 83.7725492031847, 84.28807744871159, 84.80047169680131, 85.30978841844586, 85.81608240883524, 86.31940685616416, 86.81981340684857, 87.31735222737804, 87.81207206301421, 88.3040202935291, 88.79324298616422, 89.27978494597755, 89.76368976373465, 90.24499986148818, 90.72375653598125, 91.20000000000002, 91.67376942179263, 92.14510296266428, 92.61403781284996, 93.08061022576078, 93.54485555069292], [0.0, 9.3564149117063, 13.231968863324914, 16.20578600377039, 18.7128298234126, 20.921579768267982, 22.91844235544816, 24.75474701951123, 26.463937726649828, 28.0692447351189, 29.587581854555133, 31.031717645016048, 32.41157200754078, 33.735033718672945, 35.00849896810773, 36.23723913324524, 37.4256596468252, 38.577486958069215, 39.69590658997475, 40.7836670739648, 41.843159536535964, 42.87647956630769, 43.88547595731417, 44.871789578754274, 45.83688471089632, 46.782074558531505, 47.70854221206094, 48.617358011311154, 49.50949403902246, 50.38583630346926, 51.24719504519248, 52.094313509249744, 52.927875453299656, 53.74851160729942, 54.55680525837268, 55.35329710143742, 56.1384894702378, 56.91285004285061, 57.67681509931006, 58.430792395790775, 59.175163709110265, 59.91028709662474, 60.63649890948521, 61.3541155913766, 62.063435290032096, 62.76473930480394, 63.458293390226004, 64.14434893270023, 64.82314401508155, 65.4949043819441, 66.15984431662459, 66.81816743970163, 67.47006743734589, 68.11572872692474, 68.75532706634448, 69.38903011283557, 70.01699793621546, 70.63938349108096, 71.25633305187688, 71.86798661434729, 72.47447826649048, 73.07593653180231, 73.67248468729693, 74.2642410585337, 74.8513192936504, 75.43382861820021, 76.01187407241056, 76.5855567323239, 77.15497391613843, 77.72021937694207, 78.28138348292013, 78.83855338601795, 79.3918131799495, 79.94124404836343, 80.48692440390552, 81.02893001885192, 81.5673341479296, 82.1022076438874, 82.63361906633403, 83.16163478431628, 83.68631907307193, 84.2077342053567, 84.72594053771256, 85.24099659201552, 85.75295913261537, 86.26188323935435, 86.76782237673135, 87.27082845945719, 87.77095191462834, 88.26824174073029, 88.7627455636654, 89.2545096899871, 89.74357915750855, 90.2299977834423, 90.71380821021684, 91.19505194910522, 91.67376942179264, 92.15000000000002, 92.6237820432744, 93.09515293504815, 93.56414911706301, 94.03080612224913], [0.0, 9.404520189781083, 13.3, 16.28910678950814, 18.809040379562166, 21.02914644011972, 23.03627574066607, 24.882021622046707, 26.6, 28.213560569343244, 29.739704100747204, 31.19126480282581, 32.57821357901628, 33.90847976539202, 35.18849243715905, 36.42355007409355, 37.61808075912433, 38.77583010072125, 39.900000000000006, 40.9933531197437, 42.05829288023944, 43.09692564441227, 44.11110971172682, 45.10249438778303, 46.07255148133214, 47.02260094890541, 47.95383196367106, 48.8673203685244, 49.764043244093415, 50.64489115399499, 51.51067850455864, 52.36215236217854, 53.2, 54.02485539082914, 54.837304820714884, 55.63789176451602, 56.42712113868649, 57.20546302583347, 57.97335594909096, 58.73120976108018, 59.47940820149441, 60.21831116861382, 60.948256742912676, 61.66956299504643, 62.38252960565162, 63.08743932035917, 63.784559260059176, 64.47414210363718, 65.15642715803256, 65.83164132846757, 66.50000000000001, 67.16170784010782, 67.81695953078405, 68.46594043756356, 69.1088272219982, 69.74578840331507, 70.3769848743181, 71.00257037600822, 71.6226919348889, 72.23749026648143, 72.8471001481871, 73.45165076429528, 74.05126602563928, 74.64606486614014, 75.23616151824866, 75.82166576909268, 76.40268319895578, 76.97931540355499, 77.5516602014425, 78.11981182773036, 78.6838611152249, 79.24389566395635, 79.80000000000001, 80.3522557244039, 80.90074165296632, 81.44553394754067, 81.9867062394874, 82.5243297458392, 83.05847337869871, 83.58920384834396, 84.11658576047888, 84.64068170802975, 85.1615523578569, 85.67925653272208, 86.19385128882455, 86.70539198919522, 87.21393237321661, 87.71952462251492, 88.22221942345364, 88.72206602644012, 89.21911230224161, 89.71340479549308, 90.20498877556606, 90.69390828495594, 91.1802061853339, 91.66392420139996, 92.14510296266428, 92.6237820432744, 93.10000000000001, 93.57379440847743, 94.04520189781083, 94.51425818362011], [0.0, 9.452380652512892, 13.367684915496776, 16.372003542633387, 18.904761305025783, 21.13616568822264, 23.15350945321249, 25.008648504067548, 26.73536983099355, 28.35714195753867, 29.89105217284932, 31.350000000000005, 32.74400708526677, 34.081043117838995, 35.36756989107394, 36.60891284919562, 37.809522610051566, 38.97316384385543, 40.10305474649033, 41.201972040182746, 42.27233137644528, 43.316249837676395, 44.33559518039653, 45.33202510367257, 46.30701890642498, 47.26190326256446, 48.19787339707013, 49.11601062790015, 50.017297008135095, 50.902627633551496, 51.77282105506711, 52.628628140965255, 53.4707396619871, 54.299792817284306, 55.1163768765691, 55.92103808049346, 56.71428391507734, 57.496586855221246, 58.268387655743496, 59.030098255042745, 59.78210434569864, 60.52476765754661, 61.25842799158334, 61.98340503715491, 62.70000000000001, 63.40849706466792, 64.10916471145137, 64.80225690514182, 65.48801417053355, 66.16666456759023, 66.83842457748389, 67.50349990926398, 68.16208623567799, 68.81436986560293, 69.46052835963746, 70.10073109461841, 70.73513978214788, 71.36390894562882, 71.98718635979601, 72.60511345628488, 73.21782569839124, 73.82545292783513, 74.42811968604339, 75.02594551220265, 75.61904522010313, 76.20752915558934, 76.79150343625264, 77.3710701748399, 77.94632768771086, 78.5173706895487, 79.08429047541618, 79.6471750911481, 80.20610949298066, 80.7611756972371, 81.3124529208165, 81.86001771316691, 82.40394408036549, 82.94430360187492, 83.48116554049783, 84.01459694600696, 84.54466275289056, 85.07142587261602, 85.5949472807829, 86.11528609950733, 86.63249967535279, 87.14664365309774, 87.65777204560929, 88.16593730007072, 88.67119036079306, 89.1735807288235, 89.67315651854797, 90.16996451147133, 90.66405020734514, 91.15545787280102, 91.64423058763713, 92.1304102888943, 92.61403781284996, 93.09515293504815, 93.57379440847743, 94.05000000000001, 94.52380652512892, 94.99524988124408], [0.0, 9.500000000000002, 13.435028842544403, 16.454482671904337, 19.000000000000004, 21.242645786248005, 23.270152556440195, 25.134637455113612, 26.870057685088806, 28.5, 30.041637771599607, 31.507935508376303, 32.908965343808674, 34.2527371169079, 35.54574517435244, 36.79334178897046, 38.00000000000001, 39.16950344336778, 40.305086527633215, 41.409539963636405, 42.48529157249601, 43.534469102080486, 44.55894971832258, 45.56039947147084, 46.54030511288039, 47.50000000000001, 48.44068537913146, 49.363448015713004, 50.269274910227224, 51.159065667777796, 52.03364296299078, 52.89376144688521, 53.74011537017761, 54.57334514211128, 55.39404300103036, 56.20275793944635, 57.0, 57.786244037833086, 58.56193302820528, 59.32748098478479, 60.083275543199214, 60.82968025561207, 61.56703663487468, 62.29566598086901, 63.015871016752605, 63.72793735874401, 64.43213483969005, 65.12871870380992, 65.81793068761735, 66.5, 67.17514421272203, 67.84357007115709, 68.5054742338158, 69.16104394816493, 69.81045766932058, 70.4538856274088, 71.09149034870488, 71.72342713507213, 72.34984450570714, 72.97088460475179, 73.58668357794092, 74.19737192111322, 74.80307480311221, 75.40391236534084, 76.00000000000001, 76.59144860883622, 77.17836484404162, 77.76085133278828, 78.33900688673556, 78.91292669772172, 79.48270252073719, 80.04842284517541, 80.61017305526643, 81.16803558051654, 81.72209003690496, 82.27241335952168, 82.81907992727281, 83.36216168022517, 83.90172823011456, 84.4378469644981, 84.97058314499202, 85.5, 86.02615881230548, 86.54911900187084, 87.06893820416097, 87.58567234428243, 88.09937570720919, 88.61010100434376, 89.11789943664516, 89.62282075453774, 90.12491331479882, 90.62422413460983, 91.12079894294168, 91.61468222943309, 92.10591729091027, 92.59454627568516, 93.08061022576078, 93.56414911706301, 94.04520189781083, 94.5238065251289, 95.00000000000001, 95.47381840064847], [0.0, 9.547381840064848, 13.502036883374302, 16.536550426252756, 19.094763680129695, 21.348594801532023, 23.38621388767323, 25.25999802058583, 27.004073766748604, 28.64214552019454, 30.19147230593434, 31.665083293748026, 33.07310085250551, 34.42357477078754, 35.72303178623002, 36.97685086645427, 38.18952736025939, 39.36486377469126, 40.506110650122906, 41.61607261623808, 42.69718960306405, 43.75159997074393, 44.78119024769217, 45.787634793686394, 46.77242777534646, 47.73690920032424, 48.68228630621204, 49.60965127875826, 50.51999604117166, 51.41422468539228, 52.293163989186965, 53.15757236744357, 54.00814753349721, 54.845533090672035, 55.670324231137734, 56.483072685540044, 57.28429104038908, 58.07445651919612, 58.85401430658746, 59.623380481150186, 60.38294461186868, 61.13307206414545, 61.874106054148385, 62.60636948426255, 63.33016658749605, 64.04578440459606, 64.7534941142175, 65.45355223362596, 66.14620170501102, 66.83167288045392, 67.51018441687152, 68.18194409079285, 68.84714954157508, 69.50598895059332, 70.15864166301968, 70.80527875801353, 71.44606357246003, 72.0811521828002, 72.71069384897933, 73.33483142409206, 73.95370173290854, 74.56743592212355, 75.17615978486798, 75.77999406175749, 76.37905472051878, 76.97345321602766, 77.56329673241076, 78.14868840869948, 78.72972754938252, 79.30650982107333, 79.87912743639606, 80.44766932609049, 81.01222130024581, 81.57286619949063, 82.12968403689375, 82.68275213126375, 83.23214523247616, 83.77793563940331, 84.32019331097388, 84.85898597084461, 85.3943792061281, 85.92643656058362, 86.4552196226463, 86.98078810863926, 87.50319994148786, 88.02251132522862, 88.53877681558517, 89.05204938686141, 89.56238049538435, 90.06982013971162, 90.57441691780302, 91.07621808134108, 91.57526958737279, 92.07161614743168, 92.56530127428962, 93.05636732647585, 93.54485555069292, 94.03080612224912, 94.51425818362011, 94.99524988124408, 95.47381840064848, 95.95000000000002]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"A = 10.0\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 1.0, 1.4142135623730951, 1.7320508075688776, 2.0, 2.23606797749979, 2.4494897427831783, 2.6457513110645907, 2.8284271247461903, 3.0, 3.1622776601683795, 3.3166247903554007, 3.4641016151377553, 3.6055512754639896, 3.7416573867739413, 3.872983346207417, 4.0, 4.123105625617661, 4.242640687119286, 4.358898943540674, 4.47213595499958, 4.582575694955841, 4.69041575982343, 4.79583152331272, 4.898979485566357, 5.000000000000001, 5.099019513592785, 5.196152422706633, 5.291502622129181, 5.385164807134505, 5.47722557505166, 5.567764362830022, 5.656854249492381, 5.7445626465380295, 5.830951894845301, 5.916079783099616, 6.0, 6.08276253029822, 6.164414002968977, 6.244997998398399, 6.324555320336759, 6.4031242374328485, 6.480740698407861, 6.557438524302, 6.633249580710801, 6.7082039324993685, 6.782329983125268, 6.855654600401045, 6.9282032302755105, 7.0, 7.0710678118654755, 7.141428428542851, 7.211102550927979, 7.280109889280519, 7.348469228349535, 7.416198487095664, 7.483314773547883, 7.549834435270751, 7.615773105863909, 7.681145747868608, 7.745966692414834, 7.810249675906654, 7.874007874011811, 7.937253933193771, 8.0, 8.06225774829855, 8.12403840463596, 8.18535277187245, 8.246211251235321, 8.306623862918075, 8.366600265340756, 8.426149773176359, 8.485281374238571, 8.544003745317532, 8.602325267042627, 8.660254037844387, 8.717797887081348, 8.774964387392123, 8.831760866327848, 8.888194417315589, 8.94427190999916, 9.0, 9.055385138137417, 9.1104335791443, 9.165151389911681, 9.219544457292887, 9.273618495495704, 9.327379053088816, 9.38083151964686, 9.433981132056603, 9.486832980505138, 9.539392014169456, 9.59166304662544, 9.643650760992955, 9.695359714832659, 9.746794344808963, 9.797958971132713, 9.848857801796106, 9.899494936611665, 9.9498743710662, 10.000000000000002, 10.049875621120892], [0.0, 1.4142135623730951, 2.0, 2.4494897427831783, 2.8284271247461903, 3.1622776601683795, 3.464101615137755, 3.7416573867739413, 4.0, 4.242640687119285, 4.47213595499958, 4.690415759823431, 4.898979485566357, 5.099019513592785, 5.291502622129181, 5.477225575051661, 5.656854249492381, 5.8309518948453, 6.0, 6.164414002968977, 6.324555320336759, 6.48074069840786, 6.6332495807108, 6.782329983125268, 6.92820323027551, 7.0710678118654755, 7.211102550927979, 7.348469228349535, 7.483314773547883, 7.615773105863909, 7.745966692414833, 7.874007874011811, 8.0, 8.12403840463596, 8.246211251235321, 8.366600265340756, 8.48528137423857, 8.602325267042627, 8.717797887081348, 8.831760866327848, 8.94427190999916, 9.055385138137416, 9.165151389911681, 9.273618495495704, 9.380831519646861, 9.486832980505136, 9.591663046625438, 9.695359714832659, 9.797958971132713, 9.899494936611665, 10.0, 10.09950493836208, 10.19803902718557, 10.295630140987, 10.392304845413264, 10.488088481701515, 10.583005244258363, 10.677078252031311, 10.770329614269007, 10.862780491200215, 10.954451150103322, 11.04536101718726, 11.135528725660043, 11.224972160321823, 11.313708498984761, 11.40175425099138, 11.489125293076057, 11.575836902790225, 11.6619037896906, 11.747340124470732, 11.832159566199232, 11.916375287812984, 12.0, 12.083045973594572, 12.165525060596439, 12.24744871391589, 12.328828005937954, 12.409673645990857, 12.489995996796797, 12.569805089976535, 12.649110640673518, 12.727922061357855, 12.806248474865699, 12.884098726725124, 12.96148139681572, 13.038404810405297, 13.114877048604, 13.19090595827292, 13.2664991614216, 13.341664064126332, 13.416407864998737, 13.490737563232042, 13.564659966250536, 13.638181696985855, 13.71130920080209, 13.78404875209022, 13.85640646055102, 13.92838827718412, 14.0, 14.071247279470288, 14.142135623730951, 14.212670403551895], [0.0, 1.7320508075688776, 2.4494897427831783, 3.000000000000001, 3.4641016151377553, 3.8729833462074175, 4.242640687119286, 4.582575694955841, 4.898979485566357, 5.196152422706633, 5.477225575051662, 5.74456264653803, 6.000000000000002, 6.2449979983984, 6.480740698407861, 6.70820393249937, 6.9282032302755105, 7.14142842854285, 7.348469228349535, 7.549834435270752, 7.745966692414835, 7.937253933193774, 8.12403840463596, 8.306623862918077, 8.485281374238571, 8.660254037844389, 8.83176086632785, 9.000000000000004, 9.165151389911681, 9.327379053088817, 9.486832980505138, 9.643650760992957, 9.797958971132713, 9.949874371066203, 10.09950493836208, 10.2469507659596, 10.392304845413266, 10.535653752852742, 10.677078252031313, 10.81665382639197, 10.954451150103324, 11.09053650640942, 11.224972160321828, 11.357816691600549, 11.48912529307606, 11.61895003862225, 11.747340124470732, 11.874342087037919, 12.000000000000004, 12.124355652982143, 12.247448713915892, 12.369316876852984, 12.4899959967968, 12.609520212918495, 12.727922061357859, 12.845232578665131, 12.961481396815723, 13.076696830622023, 13.190905958272921, 13.304134695650072, 13.41640786499874, 13.527749258468685, 13.638181696985859, 13.74772708486752, 13.856406460551021, 13.964240043768942, 14.07124727947029, 14.177446878757827, 14.2828568570857, 14.387494569938161, 14.49137674618944, 14.594519519326427, 14.69693845669907, 14.798648586948744, 14.89966442575134, 15.000000000000002, 15.099668870541503, 15.198684153570666, 15.297058540778357, 15.394804318340656, 15.49193338482967, 15.588457268119898, 15.684387141358126, 15.779733838059503, 15.874507866387548, 15.968719422671313, 16.062378404209014, 16.155494421403514, 16.24807680927192, 16.34013463836819, 16.431676725154986, 16.522711641858308, 16.613247725836153, 16.703293088490067, 16.792855623746668, 16.881943016134134, 16.970562748477143, 17.058722109231983, 17.14642819948225, 17.23368793961409, 17.320508075688778, 17.406895185529212], [0.0, 2.0, 2.8284271247461903, 3.4641016151377553, 4.0, 4.47213595499958, 4.898979485566357, 5.291502622129181, 5.656854249492381, 6.0, 6.324555320336759, 6.633249580710801, 6.9282032302755105, 7.211102550927979, 7.483314773547883, 7.745966692414834, 8.0, 8.246211251235321, 8.485281374238571, 8.717797887081348, 8.94427190999916, 9.165151389911681, 9.38083151964686, 9.59166304662544, 9.797958971132713, 10.000000000000002, 10.19803902718557, 10.392304845413266, 10.583005244258363, 10.77032961426901, 10.95445115010332, 11.135528725660045, 11.313708498984761, 11.489125293076059, 11.661903789690601, 11.832159566199232, 12.0, 12.16552506059644, 12.328828005937954, 12.489995996796798, 12.649110640673518, 12.806248474865697, 12.961481396815723, 13.114877048604, 13.266499161421603, 13.416407864998737, 13.564659966250536, 13.71130920080209, 13.856406460551021, 14.0, 14.142135623730951, 14.282856857085703, 14.422205101855958, 14.560219778561038, 14.69693845669907, 14.832396974191328, 14.966629547095765, 15.099668870541501, 15.231546211727817, 15.362291495737216, 15.491933384829668, 15.620499351813308, 15.748015748023622, 15.874507866387543, 16.0, 16.1245154965971, 16.24807680927192, 16.3707055437449, 16.492422502470642, 16.61324772583615, 16.73320053068151, 16.852299546352718, 16.970562748477143, 17.088007490635064, 17.204650534085253, 17.320508075688775, 17.435595774162696, 17.549928774784245, 17.663521732655695, 17.776388834631177, 17.88854381999832, 18.0, 18.110770276274835, 18.2208671582886, 18.330302779823363, 18.439088914585774, 18.547236990991408, 18.65475810617763, 18.76166303929372, 18.867962264113206, 18.973665961010276, 19.078784028338912, 19.18332609325088, 19.28730152198591, 19.390719429665317, 19.493588689617926, 19.595917942265427, 19.69771560359221, 19.79898987322333, 19.8997487421324, 20.000000000000004, 20.099751242241783], [0.0, 2.23606797749979, 3.1622776601683795, 3.872983346207418, 4.47213595499958, 5.000000000000001, 5.477225575051662, 5.916079783099616, 6.324555320336759, 6.708203932499369, 7.0710678118654755, 7.416198487095665, 7.745966692414836, 8.062257748298551, 8.366600265340756, 8.660254037844387, 8.94427190999916, 9.219544457292887, 9.48683298050514, 9.746794344808965, 10.000000000000002, 10.2469507659596, 10.488088481701515, 10.72380529476361, 10.954451150103324, 11.18033988749895, 11.401754250991383, 11.618950038622254, 11.832159566199232, 12.041594578792298, 12.24744871391589, 12.449899597988733, 12.649110640673518, 12.845232578665133, 13.038404810405298, 13.228756555322954, 13.416407864998739, 13.601470508735446, 13.784048752090223, 13.964240043768944, 14.142135623730951, 14.317821063276353, 14.491376746189442, 14.66287829861518, 14.83239697419133, 14.999999999999998, 15.165750888103101, 15.329709716755893, 15.491933384829672, 15.652475842498529, 15.811388300841898, 15.968719422671315, 16.124515496597102, 16.27882059609971, 16.431676725154986, 16.583123951777, 16.73320053068151, 16.881943016134134, 17.029386365926403, 17.175564037317667, 17.320508075688775, 17.464249196572982, 17.60681686165901, 17.74823934929885, 17.88854381999832, 18.027756377319946, 18.165902124584953, 18.30300521772313, 18.439088914585774, 18.574175621006713, 18.708286933869708, 18.841443681416774, 18.97366596101028, 19.104973174542803, 19.235384061671343, 19.364916731037088, 19.49358868961793, 19.621416870348586, 19.7484176581315, 19.874606914351794, 20.000000000000004, 20.12461179749811, 20.24845673131659, 20.371548787463365, 20.4939015319192, 20.615528128088304, 20.73644135332772, 20.856653614614213, 20.97617696340303, 21.095023109728988, 21.213203435596427, 21.330729007701542, 21.44761058952722, 21.563858652847827, 21.679483388678804, 21.794494717703365, 21.90890230020665, 22.022715545545243, 22.135943621178658, 22.248595461286993, 22.3606797749979, 22.472205054244235], [0.0, 2.4494897427831783, 3.464101615137755, 4.242640687119286, 4.898979485566357, 5.477225575051661, 6.0, 6.48074069840786, 6.92820323027551, 7.3484692283495345, 7.745966692414834, 8.124038404635963, 8.485281374238571, 8.831760866327848, 9.16515138991168, 9.486832980505138, 9.797958971132713, 10.099504938362077, 10.392304845413264, 10.677078252031313, 10.954451150103322, 11.224972160321826, 11.489125293076057, 11.747340124470732, 12.0, 12.247448713915892, 12.489995996796798, 12.727922061357859, 12.96148139681572, 13.190905958272921, 13.416407864998737, 13.638181696985857, 13.85640646055102, 14.071247279470292, 14.2828568570857, 14.49137674618944, 14.696938456699069, 14.899664425751341, 15.099668870541501, 15.297058540778357, 15.491933384829668, 15.684387141358123, 15.874507866387546, 16.06237840420901, 16.248076809271925, 16.431676725154983, 16.61324772583615, 16.792855623746668, 16.970562748477143, 17.146428199482248, 17.320508075688775, 17.492855684535904, 17.663521732655695, 17.83255450012701, 18.000000000000004, 18.165902124584953, 18.33030277982336, 18.493242008906932, 18.65475810617763, 18.81488772222678, 18.973665961010276, 19.131126469708992, 19.28730152198591, 19.44222209522358, 19.595917942265427, 19.7484176581315, 19.8997487421324, 20.049937655763422, 20.199009876724155, 20.346989949375807, 20.493901531919196, 20.639767440550294, 20.784609690826528, 20.928449536456352, 21.071307505705477, 21.213203435596427, 21.354156504062626, 21.494185260204677, 21.633307652783937, 21.771541057077243, 21.908902300206645, 22.045407685048605, 22.18107301281884, 22.315913604421397, 22.449944320643652, 22.58317958127243, 22.715633383201094, 22.847319317591726, 22.978250586152114, 23.108440016582684, 23.237900077244504, 23.366642891095847, 23.494680248941464, 23.622023622035435, 23.748684174075837, 23.874672772626642, 24.0, 24.12467616362964, 24.248711305964285, 24.372115213907882, 24.494897427831784, 24.617067250182345], [0.0, 2.6457513110645907, 3.7416573867739418, 4.582575694955841, 5.291502622129181, 5.916079783099616, 6.48074069840786, 7.0, 7.4833147735478835, 7.937253933193772, 8.366600265340756, 8.774964387392124, 9.165151389911681, 9.539392014169458, 9.899494936611665, 10.246950765959598, 10.583005244258363, 10.908712114635714, 11.224972160321824, 11.532562594670797, 11.832159566199232, 12.124355652982143, 12.409673645990857, 12.68857754044952, 12.96148139681572, 13.228756555322954, 13.490737563232043, 13.747727084867522, 14.0, 14.247806848775008, 14.491376746189438, 14.730919862656236, 14.966629547095767, 15.198684153570666, 15.427248620541512, 15.652475842498529, 15.874507866387544, 16.093476939431085, 16.309506430300093, 16.522711641858308, 16.73320053068151, 16.941074346097416, 17.146428199482248, 17.349351572897472, 17.54992877478425, 17.748239349298846, 17.944358444926362, 18.138357147217057, 18.330302779823363, 18.520259177452132, 18.708286933869708, 18.894443627691185, 19.078784028338916, 19.261360284258224, 19.442222095223585, 19.621416870348586, 19.79898987322333, 19.97498435543818, 20.149441679609886, 20.322401432901575, 20.493901531919196, 20.663978319771825, 20.83266665599966, 21.0, 21.166010488516726, 21.330729007701542, 21.494185260204677, 21.656407827707717, 21.817424229271428, 21.97726097583591, 22.135943621178654, 22.293496809607955, 22.44994432064365, 22.605309110914632, 22.75961335348208, 22.912878474779202, 23.065125189341593, 23.2163735324878, 23.366642891095847, 23.515952032609697, 23.664319132398465, 23.811761799581316, 23.958297101421884, 24.1039415863879, 24.248711305964285, 24.392621835300936, 24.535688292770594, 24.677925358506133, 24.819347291981714, 24.95996794869737, 25.099800796022265, 25.238858928247925, 25.37715508089904, 25.514701644346147, 25.651510676761323, 25.78759391645525, 25.92296279363144, 26.05762844159077, 26.19160170741759, 26.32489316217637, 26.45751311064591, 26.589471600616665], [0.0, 2.8284271247461903, 4.0, 4.898979485566357, 5.656854249492381, 6.324555320336759, 6.92820323027551, 7.483314773547883, 8.0, 8.48528137423857, 8.94427190999916, 9.380831519646861, 9.797958971132713, 10.19803902718557, 10.583005244258363, 10.954451150103322, 11.313708498984761, 11.6619037896906, 12.0, 12.328828005937954, 12.649110640673518, 12.96148139681572, 13.2664991614216, 13.564659966250536, 13.85640646055102, 14.142135623730951, 14.422205101855958, 14.69693845669907, 14.966629547095765, 15.231546211727817, 15.491933384829666, 15.748015748023622, 16.0, 16.24807680927192, 16.492422502470642, 16.73320053068151, 16.97056274847714, 17.204650534085253, 17.435595774162696, 17.663521732655695, 17.88854381999832, 18.11077027627483, 18.330302779823363, 18.547236990991408, 18.761663039293722, 18.973665961010273, 19.183326093250876, 19.390719429665317, 19.595917942265427, 19.79898987322333, 20.0, 20.19900987672416, 20.39607805437114, 20.591260281974, 20.784609690826528, 20.97617696340303, 21.166010488516726, 21.354156504062622, 21.540659228538015, 21.72556098240043, 21.908902300206645, 22.09072203437452, 22.271057451320086, 22.449944320643645, 22.627416997969522, 22.80350850198276, 22.978250586152114, 23.15167380558045, 23.3238075793812, 23.494680248941464, 23.664319132398465, 23.83275057562597, 24.0, 24.166091947189145, 24.331050121192877, 24.49489742783178, 24.657656011875908, 24.819347291981714, 24.979991993593593, 25.13961017995307, 25.298221281347036, 25.45584412271571, 25.612496949731398, 25.76819745345025, 25.92296279363144, 26.076809620810593, 26.229754097208, 26.38181191654584, 26.5329983228432, 26.683328128252665, 26.832815729997474, 26.981475126464083, 27.129319932501073, 27.27636339397171, 27.42261840160418, 27.56809750418044, 27.71281292110204, 27.85677655436824, 28.0, 28.142494558940577, 28.284271247461902, 28.42534080710379], [0.0, 3.0, 4.242640687119285, 5.196152422706633, 6.0, 6.708203932499369, 7.3484692283495345, 7.937253933193771, 8.48528137423857, 9.0, 9.486832980505138, 9.949874371066201, 10.392304845413266, 10.816653826391969, 11.224972160321824, 11.61895003862225, 12.0, 12.36931687685298, 12.727922061357855, 13.076696830622021, 13.416407864998739, 13.74772708486752, 14.071247279470288, 14.38749456993816, 14.696938456699069, 15.0, 15.297058540778357, 15.588457268119898, 15.874507866387543, 16.155494421403514, 16.431676725154983, 16.703293088490064, 16.97056274847714, 17.23368793961409, 17.4928556845359, 17.74823934929885, 18.0, 18.24828759089466, 18.49324200890693, 18.734993995195197, 18.973665961010276, 19.209372712298546, 19.44222209522358, 19.672315572906, 19.899748742132402, 20.124611797498105, 20.346989949375804, 20.566963801203133, 20.78460969082653, 21.0, 21.213203435596427, 21.424285285628553, 21.633307652783937, 21.840329667841555, 22.045407685048605, 22.24859546128699, 22.44994432064365, 22.64950330581225, 22.847319317591726, 23.043437243605823, 23.2379000772445, 23.430749027719962, 23.62202362203543, 23.811761799581312, 24.0, 24.186773244895647, 24.372115213907882, 24.55605831561735, 24.73863375370596, 24.919871588754226, 25.099800796022265, 25.278449319529077, 25.45584412271571, 25.632011235952593, 25.806975801127876, 25.98076211353316, 26.153393661244042, 26.324893162176366, 26.495282598983543, 26.664583251946766, 26.832815729997478, 27.0, 27.166155414412252, 27.331300737432894, 27.49545416973504, 27.65863337187866, 27.82085548648711, 27.982137159266447, 28.142494558940577, 28.301943396169808, 28.460498941515414, 28.61817604250837, 28.77498913987632, 28.930952282978865, 29.086079144497976, 29.240383034426888, 29.393876913398138, 29.546573405388315, 29.698484809834998, 29.8496231131986, 30.0, 30.14962686336267], [0.0, 3.1622776601683795, 4.47213595499958, 5.477225575051662, 6.324555320336759, 7.0710678118654755, 7.745966692414834, 8.366600265340756, 8.94427190999916, 9.486832980505138, 10.0, 10.488088481701517, 10.954451150103324, 11.401754250991381, 11.832159566199232, 12.24744871391589, 12.649110640673518, 13.038404810405297, 13.416407864998739, 13.784048752090223, 14.142135623730951, 14.49137674618944, 14.832396974191326, 15.165750888103101, 15.491933384829668, 15.811388300841898, 16.124515496597102, 16.431676725154986, 16.73320053068151, 17.029386365926403, 17.32050807568877, 17.60681686165901, 17.88854381999832, 18.165902124584953, 18.439088914585774, 18.708286933869708, 18.973665961010276, 19.235384061671347, 19.49358868961793, 19.7484176581315, 20.0, 20.248456731316587, 20.4939015319192, 20.73644135332772, 20.976176963403034, 21.213203435596423, 21.447610589527216, 21.6794833886788, 21.90890230020665, 22.135943621178654, 22.360679774997898, 22.583179581272432, 22.803508501982762, 23.02172886644268, 23.237900077244504, 23.45207879911715, 23.664319132398465, 23.874672772626646, 24.08318915758459, 24.289915602982237, 24.49489742783178, 24.698178070456937, 24.899799195977465, 25.099800796022265, 25.298221281347036, 25.495097567963924, 25.69046515733026, 25.88435821108957, 26.076809620810593, 26.267851073127396, 26.457513110645905, 26.645825188948457, 26.832815729997478, 27.018512172212592, 27.202941017470884, 27.386127875258307, 27.568097504180447, 27.748873851023216, 27.928480087537885, 28.106938645110393, 28.284271247461902, 28.460498941515414, 28.63564212655271, 28.809720581775867, 28.98275349237888, 29.154759474226502, 29.32575659723036, 29.495762407505254, 29.664793948382652, 29.832867780352593, 30.0, 30.166206257996713, 30.331501776206203, 30.495901363953813, 30.659419433511786, 30.82207001484488, 30.983866769659336, 31.144823004794876, 31.304951684997057, 31.464265445104548, 31.622776601683796, 31.78049716414141], [0.0, 3.3166247903554003, 4.69041575982343, 5.74456264653803, 6.6332495807108005, 7.416198487095664, 8.12403840463596, 8.774964387392123, 9.38083151964686, 9.949874371066201, 10.488088481701517, 11.000000000000004, 11.48912529307606, 11.9582607431014, 12.409673645990857, 12.84523257866513, 13.266499161421601, 13.674794331177344, 14.07124727947029, 14.456832294800963, 14.832396974191328, 15.198684153570666, 15.556349186104047, 15.905973720586868, 16.24807680927192, 16.583123951777, 16.911534525287767, 17.23368793961409, 17.549928774784245, 17.860571099491754, 18.16590212458495, 18.46618531261939, 18.76166303929372, 19.052558883257657, 19.339079605813716, 19.621416870348586, 19.899748742132402, 20.17424100183202, 20.445048300260876, 20.712315177207984, 20.976176963403034, 21.236760581595302, 21.49418526020468, 21.748563170931547, 22.000000000000007, 22.24859546128699, 22.494443758403985, 22.73763400180415, 22.97825058615212, 23.2163735324878, 23.45207879911715, 23.685438564654028, 23.9165214862028, 24.145392935299277, 24.372115213907886, 24.59674775249769, 24.819347291981714, 25.039968051097834, 25.25866188063018, 25.475478405713993, 25.69046515733026, 25.903667693977237, 26.115129714401192, 26.324893162176366, 26.532998322843202, 26.739483914241877, 26.944387170614963, 27.147743920996458, 27.349588662354687, 27.549954627911827, 27.748873851023216, 27.946377224964245, 28.14249455894058, 28.33725463060951, 28.53068523537421, 28.722813232690147, 28.913664589601925, 29.1032644217105, 29.291637031753623, 29.478805945967352, 29.664793948382655, 29.8496231131986, 30.033314835362418, 30.215889859476256, 30.39736830714133, 30.577769702841312, 30.757112998459398, 30.935416596516042, 31.112698372208094, 31.28897569432403, 31.464265445104548, 31.638584039112754, 31.811947441173736, 31.984371183438956, 32.15587038162706, 32.32645975048923, 32.49615361854384, 32.66496594212216, 32.832910318764014, 33.00000000000001, 33.166247903554, 33.33166662499792], [0.0, 3.4641016151377553, 4.898979485566357, 6.000000000000002, 6.9282032302755105, 7.745966692414835, 8.485281374238571, 9.165151389911681, 9.797958971132713, 10.392304845413266, 10.954451150103324, 11.48912529307606, 12.000000000000004, 12.4899959967968, 12.961481396815723, 13.41640786499874, 13.856406460551021, 14.2828568570857, 14.69693845669907, 15.099668870541503, 15.49193338482967, 15.874507866387548, 16.24807680927192, 16.613247725836153, 16.970562748477143, 17.320508075688778, 17.6635217326557, 18.000000000000007, 18.330302779823363, 18.654758106177635, 18.973665961010276, 19.287301521985913, 19.595917942265427, 19.899748742132406, 20.19900987672416, 20.4939015319192, 20.78460969082653, 21.071307505705484, 21.354156504062626, 21.63330765278394, 21.90890230020665, 22.18107301281884, 22.449944320643656, 22.715633383201098, 22.97825058615212, 23.2379000772445, 23.494680248941464, 23.748684174075837, 24.000000000000007, 24.248711305964285, 24.494897427831784, 24.73863375370597, 24.9799919935936, 25.21904042583699, 25.455844122715718, 25.690465157330262, 25.922962793631445, 26.153393661244046, 26.381811916545843, 26.608269391300144, 26.83281572999748, 27.05549851693737, 27.276363393971717, 27.49545416973504, 27.712812921102042, 27.928480087537885, 28.14249455894058, 28.354893757515654, 28.5657137141714, 28.774989139876322, 28.98275349237888, 29.189039038652854, 29.39387691339814, 29.597297173897488, 29.79932885150268, 30.000000000000004, 30.199337741083006, 30.39736830714133, 30.594117081556714, 30.78960863668131, 30.98386676965934, 31.176914536239796, 31.368774282716252, 31.559467676119006, 31.749015732775096, 31.937438845342626, 32.12475680841803, 32.31098884280703, 32.49615361854384, 32.68026927673638, 32.86335345030997, 33.045423283716616, 33.22649545167231, 33.406586176980134, 33.585711247493336, 33.76388603226827, 33.941125496954285, 34.117444218463966, 34.2928563989645, 34.46737587922818, 34.641016151377556, 34.813790371058424], [0.0, 3.6055512754639896, 5.099019513592785, 6.2449979983984, 7.211102550927979, 8.062257748298551, 8.831760866327848, 9.539392014169458, 10.19803902718557, 10.816653826391969, 11.401754250991381, 11.9582607431014, 12.4899959967968, 13.000000000000002, 13.490737563232042, 13.964240043768942, 14.422205101855958, 14.866068747318506, 15.297058540778357, 15.716233645501713, 16.124515496597102, 16.522711641858308, 16.911534525287763, 17.291616465790582, 17.663521732655695, 18.02775637731995, 18.38477631085024, 18.7349939951952, 19.078784028338916, 19.416487838947603, 19.748417658131498, 20.074859899884732, 20.39607805437114, 20.712315177207984, 21.02379604162864, 21.330729007701546, 21.633307652783937, 21.931712199461312, 22.226110770892873, 22.51666049839541, 22.803508501982762, 23.08679276123039, 23.36664289109585, 23.643180835073778, 23.9165214862028, 24.186773244895647, 24.454038521274967, 24.718414188616553, 24.9799919935936, 25.238858928247925, 25.495097567963928, 25.74878637916747, 26.000000000000004, 26.24880949681338, 26.495282598983547, 26.73948391424188, 26.981475126464083, 27.221315177632402, 27.459060435491963, 27.694764848252458, 27.928480087537885, 28.160255680657446, 28.390139133156783, 28.61817604250837, 28.844410203711917, 29.068883707497267, 29.291637031753623, 29.512709126747414, 29.732137494637012, 29.949958263743877, 30.166206257996713, 30.38091506192663, 30.594117081556714, 30.80584360149873, 31.016124838541643, 31.224989991991993, 31.432467291003427, 31.63858403911275, 31.84336665618132, 32.046840717924134, 32.249030993194204, 32.449961479175904, 32.649655434629025, 32.848135411313685, 33.045423283716616, 33.24154027718932, 33.436506994600975, 33.63034344160048, 33.823069050575526, 34.0147027033899, 34.20526275297414, 34.39476704383968, 34.583232931581165, 34.77067730142742, 34.957116585897076, 35.14256678161116, 35.32704346531139, 35.51056180912941, 35.6931365951495, 35.874782229304195, 36.0555127546399, 36.23534186398688], [0.0, 3.7416573867739413, 5.291502622129181, 6.480740698407861, 7.483314773547883, 8.366600265340756, 9.16515138991168, 9.899494936611665, 10.583005244258363, 11.224972160321824, 11.832159566199232, 12.409673645990859, 12.961481396815723, 13.490737563232042, 14.0, 14.491376746189438, 14.966629547095765, 15.42724862054151, 15.874507866387544, 16.309506430300093, 16.73320053068151, 17.146428199482248, 17.549928774784245, 17.944358444926362, 18.33030277982336, 18.708286933869708, 19.078784028338916, 19.442222095223585, 19.79898987322333, 20.149441679609886, 20.493901531919192, 20.83266665599966, 21.166010488516726, 21.49418526020468, 21.817424229271428, 22.135943621178654, 22.44994432064365, 22.759613353482088, 23.065125189341593, 23.366642891095847, 23.664319132398465, 23.958297101421877, 24.248711305964285, 24.535688292770594, 24.819347291981718, 25.09980079602226, 25.37715508089904, 25.651510676761323, 25.922962793631445, 26.19160170741759, 26.457513110645905, 26.72077843177478, 26.981475126464083, 27.239676943752475, 27.49545416973504, 27.748873851023216, 28.0, 28.24889378365107, 28.495613697550013, 28.740215726399825, 28.982753492378876, 29.223278392404914, 29.46183972531247, 29.698484809834994, 29.93325909419153, 30.166206257996713, 30.397368307141328, 30.626785662227107, 30.85449724108302, 31.080540535840107, 31.304951684997054, 31.527765540868895, 31.74901573277509, 31.96873472629156, 32.186953878862155, 32.4037034920393, 32.619012860600186, 32.83291031876401, 33.045423283716616, 33.25657829663178, 33.46640106136302, 33.67491648096547, 33.88214869219484, 34.08812109811862, 34.292856398964496, 34.49637662132068, 34.698703145794944, 34.899856733230294, 35.09985754956849, 35.29872518944558, 35.4964786985977, 35.6931365951495, 35.888716889852724, 36.08323710533743, 36.276714294434115, 36.469165057620934, 36.66060555964672, 36.851051545376556, 37.04051835490427, 37.22902093797257, 37.416573867739416, 37.603191353926334], [0.0, 3.8729833462074166, 5.477225575051661, 6.708203932499369, 7.745966692414833, 8.660254037844386, 9.486832980505138, 10.246950765959598, 10.954451150103322, 11.61895003862225, 12.24744871391589, 12.84523257866513, 13.416407864998739, 13.96424004376894, 14.491376746189438, 14.999999999999998, 15.491933384829666, 15.96871942267131, 16.431676725154983, 16.881943016134134, 17.32050807568877, 17.74823934929885, 18.16590212458495, 18.57417562100671, 18.973665961010276, 19.364916731037084, 19.7484176581315, 20.12461179749811, 20.493901531919196, 20.85665361461421, 21.213203435596423, 21.563858652847824, 21.908902300206645, 22.24859546128699, 22.58317958127243, 22.9128784747792, 23.2379000772445, 23.558437978779494, 23.874672772626646, 24.18677324489565, 24.49489742783178, 24.799193535274487, 25.09980079602227, 25.396850198400585, 25.69046515733026, 25.980762113533153, 26.267851073127392, 26.551836094703507, 26.832815729997478, 27.110883423451916, 27.386127875258303, 27.65863337187866, 27.92848008753788, 28.19574435974337, 28.460498941515414, 28.722813232690143, 28.982753492378876, 29.24038303442689, 29.49576240750525, 29.74894956128703, 29.999999999999996, 30.248966924508345, 30.49590136395381, 30.740852297878792, 30.983866769659333, 31.22498999199199, 31.464265445104544, 31.701734968294716, 31.93743884534262, 32.17141588429082, 32.4037034920393, 32.63433774416144, 32.863353450309965, 33.09078421554859, 33.31666249791536, 33.54101966249684, 33.76388603226827, 33.98529093593285, 34.20526275297414, 34.423828956117006, 34.64101615137754, 34.85685011586675, 35.07135583350036, 35.284557528754696, 35.4964786985977, 35.70714214271425, 35.91656999213594, 36.124783736376884, 36.3318042491699, 36.53765181289022, 36.74234614174767, 36.94590640382233, 37.14835124201342, 37.3496987939662, 37.54996671103717, 37.74917217635374, 37.94733192202055, 38.144462245521304, 38.34057902536163, 38.535697735995385, 38.72983346207417, 38.92300091205713], [0.0, 4.0, 5.656854249492381, 6.9282032302755105, 8.0, 8.94427190999916, 9.797958971132713, 10.583005244258363, 11.313708498984761, 12.0, 12.649110640673518, 13.266499161421603, 13.856406460551021, 14.422205101855958, 14.966629547095765, 15.491933384829668, 16.0, 16.492422502470642, 16.970562748477143, 17.435595774162696, 17.88854381999832, 18.330302779823363, 18.76166303929372, 19.18332609325088, 19.595917942265427, 20.000000000000004, 20.39607805437114, 20.78460969082653, 21.166010488516726, 21.54065922853802, 21.90890230020664, 22.27105745132009, 22.627416997969522, 22.978250586152118, 23.323807579381203, 23.664319132398465, 24.0, 24.33105012119288, 24.657656011875908, 24.979991993593597, 25.298221281347036, 25.612496949731394, 25.922962793631445, 26.229754097208, 26.532998322843206, 26.832815729997474, 27.129319932501073, 27.42261840160418, 27.712812921102042, 28.0, 28.284271247461902, 28.565713714171405, 28.844410203711917, 29.120439557122076, 29.39387691339814, 29.664793948382655, 29.93325909419153, 30.199337741083003, 30.463092423455635, 30.72458299147443, 30.983866769659336, 31.240998703626616, 31.496031496047245, 31.749015732775085, 32.0, 32.2490309931942, 32.49615361854384, 32.7414110874898, 32.984845004941285, 33.2264954516723, 33.46640106136302, 33.704599092705436, 33.941125496954285, 34.17601498127013, 34.40930106817051, 34.64101615137755, 34.87119154832539, 35.09985754956849, 35.32704346531139, 35.552777669262355, 35.77708763999664, 36.0, 36.22154055254967, 36.4417343165772, 36.660605559646726, 36.87817782917155, 37.094473981982816, 37.30951621235526, 37.52332607858744, 37.73592452822641, 37.94733192202055, 38.157568056677825, 38.36665218650176, 38.57460304397182, 38.781438859330635, 38.98717737923585, 39.19183588453085, 39.39543120718442, 39.59797974644666, 39.7994974842648, 40.00000000000001, 40.19950248448357], [0.0, 4.123105625617661, 5.830951894845301, 7.141428428542851, 8.246211251235321, 9.219544457292887, 10.09950493836208, 10.908712114635714, 11.661903789690601, 12.369316876852983, 13.038404810405297, 13.674794331177345, 14.282856857085703, 14.866068747318508, 15.427248620541512, 15.968719422671311, 16.492422502470642, 17.0, 17.492855684535904, 17.972200755611432, 18.439088914585774, 18.894443627691185, 19.339079605813716, 19.77371993328519, 20.19900987672416, 20.615528128088304, 21.023796041628643, 21.424285285628553, 21.817424229271428, 22.20360331117452, 22.58317958127243, 22.956480566497994, 23.323807579381203, 23.685438564654028, 24.041630560342615, 24.392621835300936, 24.738633753705965, 25.079872407968907, 25.416530054277672, 25.74878637916747, 26.076809620810593, 26.40075756488817, 26.72077843177478, 27.03701166919155, 27.34958866235469, 27.658633371878658, 27.964262908219123, 28.26658805020514, 28.565713714171405, 28.861739379323623, 29.154759474226505, 29.444863728670917, 29.732137494637016, 30.016662039607272, 30.298514815086236, 30.577769702841312, 30.854497241083024, 31.128764832546764, 31.400636936215164, 31.67017524422623, 31.937438845342623, 32.202484376209235, 32.46536616149585, 32.72613634390714, 32.984845004941285, 33.24154027718932, 33.49626844888845, 33.74907406137241, 34.0, 34.24908757908742, 34.49637662132068, 34.74190553208042, 34.98571136907181, 35.22782990761707, 35.4682957019364, 35.707142142714254, 35.944401511222864, 36.180105030251084, 36.414282912066255, 36.64696440361739, 36.87817782917155, 37.107950630558946, 37.33630940518894, 37.5632799419859, 37.78888725538237, 38.01315561749642, 38.23610858861032, 38.45776904605882, 38.67815921162743, 38.897300677553446, 39.11521443121589, 39.331920878594275, 39.54743986657038, 39.761790704142086, 39.97499218261337, 40.18706259482023, 40.39801975344832, 40.607881008493905, 40.81666326391711, 41.02438299353203, 41.23105625617661, 41.43669871020133], [0.0, 4.242640687119286, 6.0, 7.348469228349535, 8.485281374238571, 9.486832980505138, 10.392304845413264, 11.224972160321824, 12.0, 12.727922061357855, 13.416407864998739, 14.071247279470292, 14.69693845669907, 15.297058540778357, 15.874507866387544, 16.431676725154983, 16.970562748477143, 17.4928556845359, 18.0, 18.493242008906932, 18.973665961010276, 19.44222209522358, 19.8997487421324, 20.346989949375804, 20.784609690826528, 21.213203435596427, 21.63330765278394, 22.045407685048605, 22.44994432064365, 22.847319317591726, 23.2379000772445, 23.622023622035435, 24.0, 24.372115213907886, 24.73863375370596, 25.09980079602227, 25.45584412271571, 25.806975801127884, 26.153393661244046, 26.495282598983543, 26.832815729997478, 27.166155414412252, 27.495454169735044, 27.820855486487112, 28.142494558940584, 28.46049894151541, 28.774989139876315, 29.086079144497976, 29.39387691339814, 29.698484809834994, 30.000000000000004, 30.29851481508624, 30.594117081556714, 30.886890422961006, 31.176914536239796, 31.464265445104548, 31.74901573277509, 32.03123475609394, 32.31098884280703, 32.58834147360064, 32.863353450309965, 33.13608305156178, 33.406586176980134, 33.67491648096547, 33.941125496954285, 34.20526275297414, 34.46737587922817, 34.72751070837068, 34.9857113690718, 35.242020373412196, 35.4964786985977, 35.749125863438955, 36.0, 36.24913792078372, 36.49657518178932, 36.742346141747674, 36.986484017813865, 37.22902093797257, 37.46998799039039, 37.70941526992961, 37.94733192202055, 38.18376618407357, 38.4187454245971, 38.65229618017538, 38.88444419044716, 39.11521443121589, 39.344631145812, 39.572717874818764, 39.7994974842648, 40.024992192378996, 40.24922359499622, 40.47221268969613, 40.69397989875161, 40.91454509095757, 41.13392760240627, 41.352146256270665, 41.569219381653056, 41.785164831552365, 42.0, 42.21374183841087, 42.42640687119285, 42.63801121065569], [0.0, 4.358898943540674, 6.164414002968978, 7.549834435270752, 8.717797887081348, 9.746794344808965, 10.677078252031313, 11.532562594670797, 12.328828005937956, 13.076696830622023, 13.784048752090223, 14.456832294800964, 15.099668870541503, 15.716233645501715, 16.309506430300093, 16.881943016134134, 17.435595774162696, 17.97220075561143, 18.493242008906932, 19.000000000000004, 19.49358868961793, 19.97498435543818, 20.445048300260876, 20.904544960366874, 21.354156504062626, 21.794494717703373, 22.226110770892873, 22.649503305812257, 23.065125189341593, 23.47338918861101, 23.874672772626646, 24.269322199023197, 24.65765601187591, 25.039968051097837, 25.416530054277672, 25.787593916455258, 26.153393661244046, 26.51414716712571, 26.870057685088813, 27.221315177632405, 27.568097504180447, 27.91057147390573, 28.248893783651077, 28.583211855912907, 28.91366458960193, 29.24038303442689, 29.563490998188968, 29.883105594967876, 30.199337741083006, 30.51229260478472, 30.822070014844886, 31.128764832546768, 31.43246729100343, 31.73326330524487, 32.03123475609394, 32.326459750489235, 32.619012860600186, 32.908965343808674, 33.19638534539567, 33.481338085566414, 33.76388603226827, 34.044089061098404, 34.32200460346103, 34.597687784012386, 34.87119154832539, 35.14256678161116, 35.41186241925155, 35.67912554982255, 35.94440151122286, 36.20773398046335, 36.46916505762094, 36.72873534441392, 36.986484017813865, 37.24244889907215, 37.49666651850535, 37.74917217635375, 38.00000000000001, 38.24918299781056, 38.49675310984032, 38.74274125562104, 38.98717737923586, 39.230090491866065, 39.47150871198111, 39.71145930332957, 39.94996871087636, 40.18706259482024, 40.422765862815474, 40.657102700512255, 40.89009660052175, 41.12177038990418, 41.35214625627067, 41.581245772583586, 41.80908992073375, 42.03569911396741, 42.26109321823089, 42.485291572496, 42.70831300812525, 42.93017586733137, 43.15089802078284, 43.37049688440289, 43.588989435406745, 43.80639222761903], [0.0, 4.47213595499958, 6.324555320336759, 7.745966692414836, 8.94427190999916, 10.000000000000002, 10.954451150103324, 11.832159566199232, 12.649110640673518, 13.416407864998739, 14.142135623730951, 14.83239697419133, 15.491933384829672, 16.124515496597102, 16.73320053068151, 17.320508075688775, 17.88854381999832, 18.439088914585774, 18.97366596101028, 19.49358868961793, 20.000000000000004, 20.4939015319192, 20.97617696340303, 21.44761058952722, 21.90890230020665, 22.3606797749979, 22.803508501982765, 23.237900077244507, 23.664319132398465, 24.083189157584595, 24.49489742783178, 24.899799195977465, 25.298221281347036, 25.690465157330266, 26.076809620810597, 26.45751311064591, 26.832815729997478, 27.20294101747089, 27.568097504180447, 27.92848008753789, 28.284271247461902, 28.635642126552707, 28.982753492378883, 29.32575659723036, 29.66479394838266, 29.999999999999996, 30.331501776206203, 30.659419433511786, 30.983866769659343, 31.304951684997057, 31.622776601683796, 31.93743884534263, 32.249030993194204, 32.55764119219942, 32.86335345030997, 33.166247903554, 33.46640106136302, 33.76388603226827, 34.058772731852805, 34.351128074635334, 34.64101615137755, 34.928498393145965, 35.21363372331802, 35.4964786985977, 35.77708763999664, 36.05551275463989, 36.331804249169906, 36.60601043544626, 36.87817782917155, 37.148351242013426, 37.416573867739416, 37.68288736283355, 37.94733192202056, 38.209946349085605, 38.47076812334269, 38.729833462074176, 38.98717737923586, 39.24283374069717, 39.496835316263, 39.74921382870359, 40.00000000000001, 40.24922359499622, 40.49691346263318, 40.74309757492673, 40.9878030638384, 41.23105625617661, 41.47288270665544, 41.71330722922843, 41.95235392680606, 42.190046219457976, 42.42640687119285, 42.661458015403085, 42.89522117905444, 43.127717305695654, 43.35896677735761, 43.58898943540673, 43.8178046004133, 44.045431091090485, 44.271887242357316, 44.497190922573985, 44.7213595499958, 44.94441010848847], [0.0, 4.582575694955841, 6.480740698407861, 7.937253933193774, 9.165151389911681, 10.2469507659596, 11.224972160321824, 12.124355652982143, 12.961481396815723, 13.74772708486752, 14.49137674618944, 15.198684153570667, 15.874507866387548, 16.522711641858308, 17.146428199482248, 17.74823934929885, 18.330302779823363, 18.894443627691185, 19.44222209522358, 19.97498435543818, 20.4939015319192, 21.000000000000004, 21.494185260204677, 21.97726097583591, 22.44994432064365, 22.912878474779202, 23.36664289109585, 23.81176179958132, 24.248711305964285, 24.677925358506137, 25.099800796022265, 25.51470164434615, 25.922962793631445, 26.324893162176373, 26.720778431774775, 27.11088342345192, 27.49545416973504, 27.874719729532714, 28.248893783651074, 28.618176042508374, 28.98275349237888, 29.34280150224242, 29.698484809835, 30.04995840263344, 30.397368307141335, 30.740852297878792, 31.080540535840107, 31.41655614481002, 31.749015732775096, 32.07802986469088, 32.403703492039305, 32.72613634390715, 33.045423283716616, 33.36165463522456, 33.67491648096548, 33.98529093593286, 34.292856398964496, 34.59768778401239, 34.8998567332303, 35.199431813596085, 35.4964786985977, 35.79106033634656, 36.08323710533743, 36.373066958946424, 36.660605559646726, 36.945906403822335, 37.22902093797257, 37.50999866702211, 37.78888725538237, 38.065732621348566, 38.34057902536163, 38.61346915261565, 38.88444419044716, 39.153543900903784, 39.42080668885404, 39.686269665968865, 39.94996871087636, 40.2119385257662, 40.47221268969613, 40.7308237088326, 40.9878030638384, 41.24318125460256, 41.496987842492864, 41.74925149029621, 42.00000000000001, 42.24926034855522, 42.49705872175156, 42.74342054632503, 42.988370520409354, 43.23193264243457, 43.47413023856832, 43.71498598878879, 43.95452195167182, 44.19275958796871, 44.42971978304613, 44.66542286825459, 44.8998886412873, 45.133136385587036, 45.365184888855026, 45.596052460711995, 45.825756949558404, 46.054315758677824], [0.0, 4.69041575982343, 6.6332495807108005, 8.124038404635963, 9.38083151964686, 10.488088481701515, 11.489125293076059, 12.409673645990857, 13.266499161421601, 14.07124727947029, 14.832396974191326, 15.556349186104049, 16.248076809271925, 16.911534525287767, 17.549928774784245, 18.16590212458495, 18.76166303929372, 19.339079605813716, 19.899748742132402, 20.445048300260876, 20.97617696340303, 21.49418526020468, 22.0, 22.494443758403985, 22.978250586152118, 23.45207879911715, 23.9165214862028, 24.372115213907886, 24.819347291981714, 25.25866188063018, 25.690465157330255, 26.115129714401192, 26.532998322843202, 26.944387170614963, 27.349588662354687, 27.74887385102322, 28.14249455894058, 28.530685235374214, 28.913664589601925, 29.291637031753623, 29.664793948382652, 30.033314835362415, 30.39736830714133, 30.757112998459398, 31.112698372208097, 31.464265445104544, 31.811947441173732, 32.155870381627054, 32.49615361854385, 32.83291031876401, 33.166247903554, 33.49626844888846, 33.82306905057553, 34.14674215792775, 34.46737587922818, 34.785054261852174, 35.09985754956849, 35.41186241925155, 35.72114219898351, 36.02776706930364, 36.3318042491699, 36.6333181680284, 36.932370625238775, 37.22902093797257, 37.52332607858744, 37.815340802378074, 38.105117766515306, 38.39270764090494, 38.67815921162743, 38.961519477556315, 39.242833740697165, 39.52214569073901, 39.799497484264805, 40.07492981902776, 40.348482003664024, 40.620192023179804, 40.89009660052175, 41.15823125451336, 41.42463035441596, 41.689327171351664, 41.95235392680606, 42.21374183841087, 42.47352116319061, 42.731721238442994, 42.98837052040936, 43.243496620879306, 43.497126341863094, 43.74928570845472, 44.0, 44.24929377967517, 44.49719092257398, 44.74371464239419, 44.98888751680797, 45.232731511594565, 45.4752680036083, 45.71651780264984, 45.956501172304236, 46.19523784980439, 46.4327470649756, 46.669047558312144, 46.9041575982343, 47.138094997570704], [0.0, 4.79583152331272, 6.782329983125269, 8.306623862918077, 9.59166304662544, 10.72380529476361, 11.747340124470732, 12.688577540449522, 13.564659966250538, 14.38749456993816, 15.165750888103101, 15.90597372058687, 16.613247725836153, 17.291616465790586, 17.944358444926362, 18.57417562100671, 19.18332609325088, 19.77371993328519, 20.346989949375807, 20.904544960366877, 21.44761058952722, 21.977260975835915, 22.494443758403985, 23.000000000000004, 23.494680248941464, 23.9791576165636, 24.454038521274974, 24.91987158875423, 25.377155080899044, 25.82634314028992, 26.267851073127392, 26.70205984563738, 27.129319932501076, 27.549954627911827, 27.964262908219126, 28.37252191822222, 28.77498913987632, 29.171904291629648, 29.56349099818897, 29.94995826374388, 30.331501776206203, 30.708305065568176, 31.08054053584011, 31.448370387032778, 31.81194744117374, 32.17141588429082, 32.526911934581186, 32.8785644455472, 33.22649545167231, 33.57082066318904, 33.91164991562634, 34.24908757908742, 34.58323293158117, 34.91418050019219, 35.242020373412196, 35.56683848755748, 35.888716889852724, 36.20773398046335, 36.523964735499355, 36.837480912787726, 37.14835124201342, 37.456641600656084, 37.76241517699842, 38.06573262134856, 38.36665218650176, 38.665229858362416, 38.961519477556315, 39.25557285278105, 39.54743986657038, 39.83716857408418, 40.12480529547776, 40.41039470235351, 40.693979898751614, 40.97560249709576, 41.255302689472536, 41.53311931459038, 41.809089920733754, 42.08325082500163, 42.35563716909475, 42.626282971894234, 42.89522117905444, 43.16248370981448, 43.428101501216936, 43.69210454990696, 43.95452195167183, 44.21538193886829, 44.474711915874174, 44.73253849269009, 44.98888751680797, 45.24378410345448, 45.49725266430931, 45.7493169347915, 46.00000000000001, 46.24932431938871, 46.49731175025069, 46.74398357008097, 46.98936049788293, 47.23346271447818, 47.47630988187688, 47.71792116176061, 47.9583152331272, 48.19751030914357], [0.0, 4.898979485566357, 6.92820323027551, 8.485281374238571, 9.797958971132713, 10.954451150103322, 12.0, 12.96148139681572, 13.85640646055102, 14.696938456699069, 15.491933384829668, 16.248076809271925, 16.970562748477143, 17.663521732655695, 18.33030277982336, 18.973665961010276, 19.595917942265427, 20.199009876724155, 20.784609690826528, 21.354156504062626, 21.908902300206645, 22.449944320643652, 22.978250586152114, 23.494680248941464, 24.0, 24.494897427831784, 24.979991993593597, 25.455844122715718, 25.92296279363144, 26.381811916545843, 26.832815729997474, 27.276363393971714, 27.71281292110204, 28.142494558940584, 28.5657137141714, 28.98275349237888, 29.393876913398138, 29.799328851502683, 30.199337741083003, 30.594117081556714, 30.983866769659336, 31.368774282716245, 31.749015732775092, 32.12475680841802, 32.49615361854385, 32.863353450309965, 33.2264954516723, 33.585711247493336, 33.941125496954285, 34.292856398964496, 34.64101615137755, 34.98571136907181, 35.32704346531139, 35.66510900025402, 36.00000000000001, 36.331804249169906, 36.66060555964672, 36.986484017813865, 37.30951621235526, 37.62977544445356, 37.94733192202055, 38.262252939417984, 38.57460304397182, 38.88444419044716, 39.19183588453085, 39.496835316263, 39.7994974842648, 40.099875311526844, 40.39801975344831, 40.693979898751614, 40.98780306383839, 41.27953488110059, 41.569219381653056, 41.856899072912704, 42.14261501141095, 42.42640687119285, 42.70831300812525, 42.988370520409354, 43.266615305567875, 43.54308211415449, 43.81780460041329, 44.09081537009721, 44.36214602563768, 44.63182720884279, 44.899888641287305, 45.16635916254486, 45.43126676640219, 45.69463863518345, 45.95650117230423, 46.21688003316537, 46.47580015448901, 46.73328578219169, 46.98936049788293, 47.24404724407087, 47.497368348151674, 47.749345545253284, 48.0, 48.24935232725928, 48.49742261192857, 48.744230427815765, 48.98979485566357, 49.23413450036469], [0.0, 5.000000000000001, 7.071067811865476, 8.660254037844389, 10.000000000000002, 11.180339887498949, 12.247448713915892, 13.228756555322954, 14.142135623730953, 15.000000000000002, 15.811388300841898, 16.583123951777004, 17.320508075688778, 18.02775637731995, 18.708286933869708, 19.364916731037084, 20.000000000000004, 20.615528128088304, 21.213203435596427, 21.794494717703373, 22.360679774997898, 22.912878474779202, 23.45207879911715, 23.9791576165636, 24.494897427831784, 25.000000000000004, 25.49509756796393, 25.980762113533164, 26.45751311064591, 26.925824035672523, 27.386127875258303, 27.838821814150112, 28.284271247461906, 28.72281323269015, 29.154759474226502, 29.580398915498083, 30.000000000000004, 30.413812651491103, 30.822070014844886, 31.224989991991997, 31.622776601683796, 32.01562118716424, 32.403703492039305, 32.78719262151, 33.16624790355401, 33.54101966249684, 33.91164991562634, 34.27827300200522, 34.641016151377556, 35.0, 35.35533905932738, 35.707142142714254, 36.0555127546399, 36.4005494464026, 36.742346141747674, 37.08099243547832, 37.416573867739416, 37.74917217635375, 38.07886552931954, 38.40572873934304, 38.72983346207417, 39.05124837953327, 39.37003937005906, 39.68626966596886, 40.00000000000001, 40.31128874149275, 40.620192023179804, 40.926763859362254, 41.23105625617661, 41.53311931459038, 41.83300132670378, 42.1307488658818, 42.42640687119285, 42.72001872658766, 43.01162633521313, 43.30127018922194, 43.588989435406745, 43.874821936960615, 44.15880433163924, 44.44097208657795, 44.721359549995796, 45.0, 45.276925690687094, 45.552167895721496, 45.825756949558404, 46.09772228646444, 46.36809247747852, 46.63689526544408, 46.9041575982343, 47.16990566028302, 47.434164902525694, 47.69696007084729, 47.9583152331272, 48.21825380496478, 48.4767985741633, 48.73397172404482, 48.98979485566357, 49.24428900898053, 49.497474683058336, 49.749371855331006, 50.00000000000001, 50.24937810560446], [0.0, 5.099019513592785, 7.211102550927979, 8.83176086632785, 10.19803902718557, 11.401754250991381, 12.489995996796798, 13.490737563232043, 14.422205101855958, 15.297058540778355, 16.124515496597102, 16.911534525287767, 17.6635217326557, 18.38477631085024, 19.078784028338916, 19.7484176581315, 20.39607805437114, 21.02379604162864, 21.633307652783937, 22.226110770892873, 22.803508501982762, 23.36664289109585, 23.916521486202797, 24.45403852127497, 24.979991993593597, 25.495097567963928, 26.000000000000007, 26.495282598983547, 26.981475126464087, 27.459060435491967, 27.92848008753788, 28.390139133156783, 28.844410203711917, 29.291637031753627, 29.732137494637012, 30.166206257996716, 30.59411708155671, 31.01612483854165, 31.432467291003427, 31.84336665618132, 32.249030993194204, 32.64965543462902, 33.045423283716616, 33.436506994600975, 33.82306905057553, 34.205262752974136, 34.583232931581165, 34.957116585897076, 35.3270434653114, 35.6931365951495, 36.0555127546399, 36.414282912066255, 36.76955262170048, 37.12142238654118, 37.46998799039039, 37.81534080237808, 38.15756805667783, 38.49675310984032, 38.8329756778952, 39.16631205513228, 39.496835316263, 39.824615503479755, 40.149719799769464, 40.47221268969613, 40.79215610874228, 41.10960958218894, 41.42463035441596, 41.737273509418415, 42.04759208325728, 42.35563716909475, 42.661458015403085, 42.96510211788168, 43.266615305567875, 43.56604182158393, 43.86342439892262, 44.15880433163924, 44.45222154178575, 44.74371464239419, 45.03332099679082, 45.32107677449864, 45.607017003965524, 45.89117562233507, 46.17358552246079, 46.45427859734774, 46.7332857821917, 47.01063709417264, 47.286361670147556, 47.560487802376464, 47.83304297240559, 48.104053883222775, 48.3735464897913, 48.64154602806124, 48.90807704254994, 49.17316341257699, 49.43682837723311, 49.699094559156705, 49.959983987187194, 50.219518117958884, 50.47771785649586, 50.7346035758633, 50.990195135927856, 51.244511901275835], [0.0, 5.196152422706633, 7.348469228349535, 9.000000000000002, 10.392304845413266, 11.618950038622252, 12.727922061357857, 13.74772708486752, 14.69693845669907, 15.588457268119896, 16.431676725154986, 17.23368793961409, 18.000000000000004, 18.734993995195197, 19.44222209522358, 20.12461179749811, 20.78460969082653, 21.42428528562855, 22.045407685048605, 22.649503305812253, 23.237900077244504, 23.81176179958132, 24.372115213907882, 24.919871588754226, 25.455844122715714, 25.980762113533164, 26.495282598983547, 27.000000000000007, 27.49545416973504, 27.98213715926645, 28.460498941515414, 28.93095228297887, 29.39387691339814, 29.849623113198607, 30.298514815086236, 30.7408522978788, 31.176914536239792, 31.606961258558222, 32.03123475609394, 32.44996147917591, 32.86335345030997, 33.27160951922826, 33.67491648096548, 34.07345007480164, 34.46737587922818, 34.85685011586675, 35.242020373412196, 35.62302626111376, 36.00000000000001, 36.373066958946424, 36.742346141747674, 37.10795063055895, 37.46998799039039, 37.828560638755484, 38.183766184073576, 38.53569773599539, 38.88444419044716, 39.230090491866065, 39.572717874818764, 39.91240408695021, 40.24922359499622, 40.58324777540605, 40.914545090957574, 41.24318125460256, 41.56921938165306, 41.892720131306824, 42.21374183841087, 42.53234063627348, 42.8485705712571, 43.16248370981448, 43.474130238568314, 43.783558557979276, 44.09081537009721, 44.39594576084623, 44.69899327725402, 45.00000000000001, 45.299006611624506, 45.596052460711995, 45.89117562233507, 46.18441295502196, 46.47580015448901, 46.76537180435969, 47.053161424074375, 47.339201514178505, 47.62352359916264, 47.90615826801394, 48.187135212627034, 48.466483264210545, 48.744230427815765, 49.02040391510457, 49.29503017546495, 49.568134925574924, 49.83974317750845, 50.1098792654702, 50.378566871240004, 50.6458290484024, 50.91168824543143, 51.17616632769595, 51.43928459844675, 51.701063818842265, 51.96152422706633, 52.22068555658764], [0.0, 5.291502622129181, 7.4833147735478835, 9.165151389911681, 10.583005244258363, 11.832159566199232, 12.96148139681572, 14.0, 14.966629547095767, 15.874507866387544, 16.73320053068151, 17.54992877478425, 18.330302779823363, 19.078784028338916, 19.79898987322333, 20.493901531919196, 21.166010488516726, 21.817424229271428, 22.44994432064365, 23.065125189341593, 23.664319132398465, 24.248711305964285, 24.819347291981714, 25.37715508089904, 25.92296279363144, 26.45751311064591, 26.981475126464087, 27.495454169735044, 28.0, 28.495613697550016, 28.982753492378876, 29.461839725312473, 29.933259094191534, 30.39736830714133, 30.854497241083024, 31.304951684997057, 31.74901573277509, 32.18695387886217, 32.619012860600186, 33.045423283716616, 33.46640106136302, 33.88214869219483, 34.292856398964496, 34.698703145794944, 35.0998575495685, 35.49647869859769, 35.888716889852724, 36.276714294434115, 36.660605559646726, 37.040518354904265, 37.416573867739416, 37.78888725538237, 38.15756805667783, 38.52272056851645, 38.88444419044717, 39.24283374069717, 39.59797974644666, 39.94996871087636, 40.29888335921977, 40.64480286580315, 40.98780306383839, 41.32795663954365, 41.66533331199932, 42.0, 42.33202097703345, 42.661458015403085, 42.988370520409354, 43.312815655415434, 43.634848458542855, 43.95452195167182, 44.27188724235731, 44.58699361921591, 44.8998886412873, 45.210618221829264, 45.51922670696416, 45.825756949558404, 46.130250378683186, 46.4327470649756, 46.73328578219169, 47.03190406521939, 47.32863826479693, 47.62352359916263, 47.91659420284377, 48.2078831727758, 48.49742261192857, 48.78524367060187, 49.07137658554119, 49.35585071701227, 49.63869458396343, 49.91993589739474, 50.19960159204453, 50.47771785649585, 50.75431016179808, 51.02940328869229, 51.303021353522645, 51.5751878329105, 51.84592558726288, 52.11525688318154, 52.38320341483518, 52.64978632435274, 52.91502622129182, 53.17894320123333], [0.0, 5.385164807134505, 7.6157731058639095, 9.327379053088817, 10.77032961426901, 12.041594578792296, 13.19090595827292, 14.247806848775008, 15.231546211727819, 16.155494421403514, 17.029386365926403, 17.860571099491757, 18.654758106177635, 19.416487838947603, 20.149441679609886, 20.85665361461421, 21.54065922853802, 22.20360331117452, 22.847319317591726, 23.47338918861101, 24.08318915758459, 24.677925358506137, 25.25866188063018, 25.826343140289918, 26.38181191654584, 26.925824035672523, 27.459060435491967, 27.98213715926645, 28.495613697550016, 29.000000000000004, 29.49576240750525, 29.983328701129903, 30.463092423455638, 30.935416596516045, 31.400636936215164, 31.859064644147985, 32.31098884280703, 32.756678708318404, 33.19638534539567, 33.63034344160048, 34.058772731852805, 34.48187929913334, 34.8998567332303, 35.31288716601915, 35.721142198983515, 36.124783736376884, 36.52396473549935, 36.91882988394947, 37.30951621235527, 37.69615364994153, 38.07886552931954, 38.45776904605883, 38.832975677895206, 39.204591567825325, 39.572717874818764, 39.93745109543172, 40.29888335921977, 40.65710270051225, 41.01219330881976, 41.36423575989287, 41.71330722922842, 42.05948168962618, 42.402830094228385, 42.74342054632502, 43.08131845707604, 43.41658669218482, 43.74928570845472, 44.079473681068386, 44.40720662234904, 44.73253849269009, 45.05552130427524, 45.376205218153714, 45.69463863518345, 46.010868281309364, 46.32493928760188, 46.63689526544408, 46.94677837722202, 47.25462940284264, 47.560487802376464, 47.86439177509728, 48.16637831516918, 48.46648326421054, 48.764741360946445, 49.06118628814432, 49.355850717012274, 49.64876634922564, 49.93996395673509, 50.229473419497445, 50.51732376126036, 50.80354318352215, 51.088159097779204, 51.37119815616529, 51.652686280579836, 51.93264869039514, 52.21110992882646, 52.48809388804283, 52.76362383309168, 53.037722424704484, 53.31041174104736, 53.581713298475265, 53.851648071345046, 54.120236510939236], [0.0, 5.477225575051661, 7.745966692414834, 9.48683298050514, 10.954451150103322, 12.24744871391589, 13.416407864998737, 14.491376746189438, 15.491933384829668, 16.431676725154983, 17.32050807568877, 18.165902124584953, 18.97366596101028, 19.7484176581315, 20.493901531919196, 21.213203435596423, 21.908902300206645, 22.58317958127243, 23.2379000772445, 23.874672772626646, 24.49489742783178, 25.09980079602227, 25.690465157330255, 26.267851073127392, 26.832815729997474, 27.386127875258307, 27.928480087537885, 28.460498941515418, 28.982753492378876, 29.495762407505254, 29.999999999999996, 30.49590136395381, 30.983866769659336, 31.46426544510455, 31.937438845342623, 32.4037034920393, 32.863353450309965, 33.31666249791537, 33.76388603226827, 34.20526275297414, 34.64101615137754, 35.07135583350036, 35.4964786985977, 35.91656999213594, 36.331804249169906, 36.74234614174767, 37.14835124201342, 37.54996671103717, 37.94733192202056, 38.34057902536163, 38.72983346207417, 39.1152144312159, 39.496835316263, 39.874804074753776, 40.24922359499622, 40.620192023179804, 40.98780306383839, 41.352146256270665, 41.71330722922842, 42.07136793592525, 42.426406871192846, 42.77849927241487, 43.12771730569565, 43.474130238568314, 43.81780460041329, 44.15880433163923, 44.49719092257398, 44.83302354291979, 45.16635916254486, 45.4972526643093, 45.8257569495584, 46.151923036857305, 46.475800154489, 46.797435827190355, 47.11687595755898, 47.43416490252569, 47.74934554525329, 48.062459362791664, 48.3735464897913, 48.68264577855234, 48.98979485566356, 49.295030175464944, 49.59838707054898, 49.89989979949859, 50.19960159204454, 50.49752469181038, 50.79370039680117, 51.088159097779204, 51.38093031466051, 51.67204273105525, 51.96152422706631, 52.24940191045253, 52.535702146254785, 52.820450584977024, 53.103672189407014, 53.385391260156545, 53.66563145999495, 53.94441583704471, 54.22176684690383, 54.49770637375485, 54.772255750516614, 55.04543577809154], [0.0, 5.567764362830022, 7.874007874011811, 9.643650760992957, 11.135528725660045, 12.449899597988733, 13.638181696985857, 14.730919862656236, 15.748015748023622, 16.703293088490067, 17.60681686165901, 18.46618531261939, 19.287301521985913, 20.074859899884732, 20.83266665599966, 21.563858652847824, 22.27105745132009, 22.95648056649799, 23.622023622035435, 24.269322199023197, 24.899799195977465, 25.51470164434615, 26.115129714401192, 26.70205984563738, 27.276363393971714, 27.838821814150112, 28.390139133156783, 28.930952282978872, 29.461839725312473, 29.983328701129903, 30.49590136395381, 31.0, 31.496031496047245, 31.984371183438956, 32.46536616149585, 32.93933818400121, 33.406586176980134, 33.867388443752205, 34.32200460346103, 34.770677301427426, 35.21363372331802, 35.651086939951774, 36.08323710533744, 36.51027252705737, 36.93237062523878, 37.34969879396619, 37.76241517699841, 38.17066936798463, 38.57460304397183, 38.97435053981015, 39.370039370059054, 39.76179070414209, 40.149719799769464, 40.533936399022494, 40.914545090957574, 41.29164564412516, 41.66533331199932, 42.03569911396741, 42.402830094228385, 42.76680956068619, 43.12771730569565, 43.485629810317796, 43.840620433565945, 44.1927595879687, 44.54211490264018, 44.88875137492688, 45.232731511594565, 45.574115460423364, 45.91296113299598, 46.24932431938871, 46.58325879540846, 46.9148164229596, 47.24404724407087, 47.57099956906519, 47.89572005931218, 48.218253804964775, 48.538644398046394, 48.85693400122443, 49.17316341257699, 49.48737212663449, 49.79959839195493, 50.1098792654702, 50.41825066382213, 50.724747411889595, 51.0294032886923, 51.33225107084239, 51.633322573702344, 51.93264869039514, 52.230259428802384, 52.52618394667558, 52.820450584977024, 53.113086899558006, 53.40411969127476, 53.693575034635195, 53.98147830506312, 54.267854204860534, 54.55272678794343, 54.83611948342078, 55.11805511808268, 55.39855593785817, 55.677643628300224, 55.95533933415113], [0.0, 5.656854249492381, 8.0, 9.797958971132713, 11.313708498984761, 12.649110640673518, 13.85640646055102, 14.966629547095765, 16.0, 16.97056274847714, 17.88854381999832, 18.761663039293722, 19.595917942265427, 20.39607805437114, 21.166010488516726, 21.908902300206645, 22.627416997969522, 23.3238075793812, 24.0, 24.657656011875908, 25.298221281347036, 25.92296279363144, 26.5329983228432, 27.129319932501073, 27.71281292110204, 28.284271247461902, 28.844410203711917, 29.39387691339814, 29.93325909419153, 30.463092423455635, 30.983866769659333, 31.496031496047245, 32.0, 32.49615361854384, 32.984845004941285, 33.46640106136302, 33.94112549695428, 34.40930106817051, 34.87119154832539, 35.32704346531139, 35.77708763999664, 36.22154055254966, 36.660605559646726, 37.094473981982816, 37.523326078587445, 37.947331922020545, 38.36665218650175, 38.781438859330635, 39.19183588453085, 39.59797974644666, 40.0, 40.39801975344832, 40.79215610874228, 41.182520563948, 41.569219381653056, 41.95235392680606, 42.33202097703345, 42.708313008125245, 43.08131845707603, 43.45112196480086, 43.81780460041329, 44.18144406874904, 44.54211490264017, 44.89988864128729, 45.254833995939045, 45.60701700396552, 45.95650117230423, 46.3033476111609, 46.6476151587624, 46.98936049788293, 47.32863826479693, 47.66550115125194, 48.0, 48.33218389437829, 48.662100242385755, 48.98979485566356, 49.315312023751815, 49.63869458396343, 49.95998398718719, 50.27922035990614, 50.59644256269407, 50.91168824543142, 51.224993899462795, 51.5363949069005, 51.84592558726288, 52.153619241621186, 52.459508194416, 52.76362383309168, 53.0659966456864, 53.36665625650533, 53.66563145999495, 53.96295025292817, 54.258639865002145, 54.55272678794342, 54.84523680320836, 55.13619500836088, 55.42562584220408, 55.71355310873648, 56.0, 56.28498911788115, 56.568542494923804, 56.85068161420758], [0.0, 5.7445626465380295, 8.12403840463596, 9.949874371066203, 11.489125293076059, 12.845232578665131, 14.07124727947029, 15.198684153570666, 16.24807680927192, 17.23368793961409, 18.165902124584953, 19.052558883257657, 19.899748742132406, 20.712315177207984, 21.49418526020468, 22.24859546128699, 22.978250586152118, 23.685438564654024, 24.372115213907886, 25.039968051097834, 25.690465157330262, 26.32489316217637, 26.944387170614963, 27.549954627911823, 28.14249455894058, 28.72281323269015, 29.291637031753627, 29.849623113198607, 30.39736830714133, 30.935416596516045, 31.464265445104544, 31.984371183438956, 32.49615361854384, 33.00000000000001, 33.49626844888846, 33.98529093593286, 34.46737587922818, 34.9428104193123, 35.411862419251555, 35.8747822293042, 36.331804249169906, 36.78314831549905, 37.22902093797258, 37.66961640367473, 38.10511776651531, 38.535697735995385, 38.961519477556315, 39.38273733503044, 39.79949748426481, 40.2119385257662, 40.620192023179804, 41.024382993532036, 41.42463035441597, 41.821047332652974, 42.213741838410876, 42.602816808281595, 42.98837052040936, 43.37049688440289, 43.74928570845472, 44.12482294582042, 44.49719092257398, 44.86646854834911, 45.23273151159457, 45.596052460711995, 45.956501172304236, 46.314144707637645, 46.669047558312144, 47.021271782034994, 47.37087712930805, 47.71792116176061, 48.062459362791664, 48.4045452411238, 48.74423042781577, 49.08156476723211, 49.416596402423345, 49.749371855331006, 50.07993610219567, 50.408332644514246, 50.7346035758633, 51.05878964487898, 51.380930314660525, 51.701063818842265, 52.01922721455982, 52.3354564325181, 52.64978632435274, 52.96225070746144, 53.27288240746881, 53.581713298475265, 53.888774341229926, 54.194095619356915, 54.49770637375485, 54.799635035281035, 55.09990925582365, 55.39855593785817, 55.69560126257729, 55.99107071667767, 56.28498911788116, 56.57738063926255, 56.86826883245173, 57.15767664977296, 57.4456264653803, 57.732140095444244], [0.0, 5.830951894845301, 8.246211251235321, 10.09950493836208, 11.661903789690601, 13.038404810405298, 14.2828568570857, 15.427248620541514, 16.492422502470642, 17.4928556845359, 18.439088914585774, 19.33907960581372, 20.19900987672416, 21.023796041628643, 21.81742422927143, 22.58317958127243, 23.323807579381203, 24.041630560342615, 24.738633753705965, 25.416530054277672, 26.076809620810597, 26.72077843177478, 27.349588662354687, 27.964262908219126, 28.5657137141714, 29.154759474226505, 29.732137494637016, 30.29851481508624, 30.854497241083028, 31.400636936215168, 31.937438845342623, 32.46536616149585, 32.984845004941285, 33.49626844888846, 34.0, 34.496376621320685, 34.9857113690718, 35.468295701936405, 35.944401511222864, 36.414282912066255, 36.87817782917155, 37.33630940518894, 37.78888725538238, 38.23610858861032, 38.67815921162744, 39.11521443121589, 39.54743986657038, 39.97499218261337, 40.39801975344832, 40.8166632639171, 41.23105625617661, 41.64132562731403, 42.047592083257285, 42.449970553582254, 42.848570571257106, 43.24349662087931, 43.63484845854286, 44.02272140611028, 44.40720662234904, 44.78839135311738, 45.16635916254486, 45.541190146942796, 45.91296113299599, 46.281745861624536, 46.647615158762406, 47.01063709417264, 47.37087712930805, 47.7283982551269, 48.08326112068523, 48.43552415324934, 48.78524367060187, 49.13247398615299, 49.47726750741193, 49.8196748283246, 50.159744815937806, 50.49752469181039, 50.833060108555344, 51.16639522186413, 51.49757275833494, 51.82663407939976, 52.15361924162119, 52.478567053607705, 52.80151512977635, 53.1224999411737, 53.44155686354956, 53.75872022286245, 54.0740233383831, 54.3874985635486, 54.699177324709375, 55.00909015790027, 55.31726674375732, 55.62373594069352, 55.92852581643825, 56.231663678038196, 56.53317610041029, 56.83308895353128, 57.1314274283428, 57.42821606144492, 57.72347875864725, 58.017238817441154, 58.30951894845301, 58.60034129593445], [0.0, 5.916079783099616, 8.366600265340756, 10.2469507659596, 11.832159566199232, 13.228756555322953, 14.491376746189438, 15.652475842498529, 16.73320053068151, 17.74823934929885, 18.708286933869708, 19.621416870348586, 20.4939015319192, 21.330729007701542, 22.135943621178654, 22.9128784747792, 23.664319132398465, 24.392621835300933, 25.09980079602227, 25.787593916455258, 26.457513110645905, 27.11088342345192, 27.748873851023216, 28.372521918222215, 28.982753492378876, 29.580398915498083, 30.166206257996716, 30.7408522978788, 31.304951684997057, 31.859064644147985, 32.4037034920393, 32.93933818400121, 33.46640106136302, 33.98529093593286, 34.49637662132068, 35.0, 35.4964786985977, 35.98610843089317, 36.46916505762094, 36.945906403822335, 37.416573867739416, 37.88139384975162, 38.340579025361635, 38.79432948254164, 39.24283374069717, 39.68626966596885, 40.124805295477756, 40.5585995813465, 40.9878030638384, 41.41255848169731, 41.83300132670378, 42.24926034855522, 42.661458015403085, 43.06971093471606, 43.47413023856832, 43.874821936960615, 44.27188724235731, 44.665422868254595, 45.05552130427524, 45.44227107000705, 45.8257569495584, 46.20606020859168, 46.58325879540846, 46.95742752749558, 47.32863826479693, 47.69696007084728, 48.062459362791664, 48.425200051213004, 48.785243670601865, 49.142649501222465, 49.49747468305833, 49.849774322458074, 50.19960159204454, 50.547007824400445, 50.892042599997886, 51.234753829797995, 51.575187832910515, 51.91338940966964, 52.24940191045253, 52.58326730053963, 52.91502622129181, 53.24471804789655, 53.5723809439155, 53.898051912847464, 54.22176684690384, 54.54356057317857, 54.86346689738081, 55.18151864528558, 55.49774770204643, 55.8121850495033, 56.12486080160912, 56.43580423808985, 56.74504383644443, 57.05260730238365, 57.35852159879995, 57.66281297335397, 57.96550698475775, 58.266628527828864, 58.56620185738529, 58.864250611045755, 59.16079783099617, 59.455865984778995], [0.0, 6.0, 8.48528137423857, 10.392304845413266, 12.0, 13.416407864998739, 14.696938456699069, 15.874507866387543, 16.97056274847714, 18.0, 18.973665961010276, 19.899748742132402, 20.78460969082653, 21.633307652783937, 22.44994432064365, 23.2379000772445, 24.0, 24.73863375370596, 25.45584412271571, 26.153393661244042, 26.832815729997478, 27.49545416973504, 28.142494558940577, 28.77498913987632, 29.393876913398138, 30.0, 30.594117081556714, 31.176914536239796, 31.749015732775085, 32.31098884280703, 32.863353450309965, 33.40658617698013, 33.94112549695428, 34.46737587922818, 34.9857113690718, 35.4964786985977, 36.0, 36.49657518178932, 36.98648401781386, 37.46998799039039, 37.94733192202055, 38.41874542459709, 38.88444419044716, 39.344631145812, 39.799497484264805, 40.24922359499621, 40.69397989875161, 41.13392760240627, 41.56921938165306, 42.0, 42.42640687119285, 42.848570571257106, 43.266615305567875, 43.68065933568311, 44.09081537009721, 44.49719092257398, 44.8998886412873, 45.2990066116245, 45.69463863518345, 46.086874487211645, 46.475800154489, 46.861498055439924, 47.24404724407086, 47.623523599162624, 48.0, 48.373546489791295, 48.744230427815765, 49.1121166312347, 49.47726750741192, 49.83974317750845, 50.19960159204453, 50.556898639058154, 50.91168824543142, 51.264022471905186, 51.61395160225575, 51.96152422706632, 52.306787322488084, 52.64978632435273, 52.990565197967086, 53.32916650389353, 53.665631459994955, 54.0, 54.332310828824504, 54.66260147486579, 54.99090833947008, 55.31726674375732, 55.64171097297422, 55.964274318532894, 56.28498911788115, 56.603886792339615, 56.92099788303083, 57.23635208501674, 57.54997827975264, 57.86190456595773, 58.17215828899595, 58.480766068853775, 58.787753826796276, 59.09314681077663, 59.396969619669996, 59.6992462263972, 60.0, 60.29925372672534], [0.0, 6.08276253029822, 8.602325267042628, 10.535653752852742, 12.16552506059644, 13.601470508735444, 14.899664425751341, 16.09347693943108, 17.204650534085257, 18.24828759089466, 19.235384061671347, 20.17424100183202, 21.071307505705484, 21.931712199461312, 22.759613353482084, 23.558437978779494, 24.33105012119288, 25.079872407968903, 25.806975801127884, 26.514147167125707, 27.202941017470888, 27.87471972953271, 28.53068523537421, 29.171904291629644, 29.799328851502683, 30.413812651491103, 31.01612483854165, 31.606961258558222, 32.18695387886216, 32.756678708318404, 33.31666249791536, 33.8673884437522, 34.409301068170514, 34.9428104193123, 35.4682957019364, 35.98610843089317, 36.49657518178932, 37.00000000000001, 37.49666651850536, 37.98683982644516, 38.470768123342694, 38.948684188300895, 39.42080668885406, 39.88734135035826, 40.34848200366404, 40.80441152620633, 41.255302689472536, 41.701318923986086, 42.14261501141097, 42.579337712087536, 43.01162633521314, 43.43961325794695, 43.863424398922625, 44.28317965096906, 44.698993277254026, 45.11097427455985, 45.51922670696417, 45.92385001282014, 46.32493928760188, 46.72258554489466, 47.11687595755899, 47.50789408087881, 47.89572005931219, 48.28043081829324, 48.66210024238576, 49.040799340956916, 49.41659640242335, 49.78955713801842, 50.159744815937806, 50.52722038663913, 50.89204259999789, 51.254268114958, 51.61395160225577, 51.97114584074514, 52.32590180780451, 52.6782687642637, 53.02829433425141, 53.376024580330075, 53.721504074253176, 54.064775963653084, 54.405882034941776, 54.74486277268398, 55.08175741568166, 55.41660400998964, 55.74943945906542, 56.08029957123981, 56.40921910468182, 56.73623181001714, 57.06137047074842, 57.38466694161429, 57.706152185014034, 58.02585630561604, 58.34380858325929, 58.660037504249864, 58.97457079114693, 59.287435431126546, 59.598657703005365, 59.908263203000644, 60.21627686929839, 60.52272300549605, 60.827625302982206, 61.13100686231171], [0.0, 6.164414002968977, 8.717797887081348, 10.677078252031313, 12.328828005937954, 13.784048752090223, 15.099668870541501, 16.309506430300093, 17.435595774162696, 18.49324200890693, 19.49358868961793, 20.445048300260876, 21.354156504062626, 22.226110770892873, 23.065125189341593, 23.874672772626646, 24.657656011875908, 25.41653005427767, 26.153393661244046, 26.87005768508881, 27.568097504180447, 28.248893783651074, 28.91366458960192, 29.563490998188968, 30.199337741083003, 30.822070014844886, 31.43246729100343, 32.031234756093944, 32.619012860600186, 33.19638534539567, 33.76388603226826, 34.32200460346103, 34.87119154832539, 35.411862419251555, 35.94440151122286, 36.46916505762094, 36.98648401781386, 37.49666651850536, 38.00000000000001, 38.49675310984032, 38.98717737923586, 39.4715087119811, 39.94996871087636, 40.422765862815474, 40.89009660052175, 41.352146256270665, 41.80908992073375, 42.26109321823088, 42.70831300812525, 43.15089802078283, 43.58898943540674, 44.022721406110286, 44.45222154178575, 44.877611344633756, 45.299006611624506, 45.71651780264985, 46.130250378683186, 46.54030511288039, 46.94677837722201, 47.34976240700686, 47.74934554525329, 48.14561246884289, 48.538644398046394, 48.92851929090027, 49.315312023751815, 49.69909455915671, 50.07993610219566, 50.45790324617146, 50.83306010855534, 51.205468457968436, 51.57518783291051, 51.942275652882216, 52.30678732248809, 52.66877632905477, 53.028294334251406, 53.38539126015656, 53.74011537017762, 54.092513345194085, 54.442630355264804, 54.7905101272109, 55.13619500836089, 55.47972602672079, 55.82114294781146, 56.16048432839589, 56.49778756730215, 56.83308895353129, 57.16642371182581, 57.49782604586021, 57.82732917920384, 58.154965394194846, 58.48076606885379, 58.80476171195663, 59.126981996377936, 59.4474557908074, 59.766211189935746, 60.08327554319921, 60.398675482166006, 60.71243694664217, 61.02458520956944, 61.33514490078262, 61.64414002968977, 61.951594006934165], [0.0, 6.244997998398399, 8.831760866327848, 10.81665382639197, 12.489995996796798, 13.964240043768942, 15.297058540778357, 16.522711641858308, 17.663521732655695, 18.734993995195197, 19.7484176581315, 20.712315177207984, 21.63330765278394, 22.51666049839541, 23.366642891095847, 24.18677324489565, 24.979991993593597, 25.748786379167466, 26.495282598983543, 27.221315177632405, 27.928480087537885, 28.618176042508374, 29.291637031753623, 29.949958263743877, 30.594117081556714, 31.224989991991997, 31.843366656181324, 32.44996147917591, 33.045423283716616, 33.63034344160048, 34.205262752974136, 34.770677301427426, 35.32704346531139, 35.8747822293042, 36.41428291206625, 36.945906403822335, 37.46998799039039, 37.98683982644516, 38.49675310984032, 39.00000000000001, 39.496835316263, 39.98749804626441, 40.472212689696136, 40.95119045888654, 41.42463035441597, 41.892720131306824, 42.35563716909474, 42.8135492572153, 43.26661530556788, 43.71498598878879, 44.15880433163924, 44.59820624195552, 45.03332099679082, 45.46427168667723, 45.89117562233507, 46.31414470763765, 46.73328578219169, 47.14870093650514, 47.560487802376464, 47.968739820845826, 48.3735464897913, 48.774993593028796, 49.17316341257699, 49.56813492557492, 49.959983987187194, 50.34878350069643, 50.7346035758633, 51.11751167652824, 51.49757275833493, 51.874849397371754, 52.24940191045253, 52.621288467691485, 52.990565197967086, 53.35728628781641, 53.72150407425317, 54.083269131959845, 54.44263035526481, 54.799635035281035, 55.15432893255072, 55.506756345511675, 55.85696017507577, 56.20498198558559, 56.550862062394785, 56.894639466297704, 57.23635208501675, 57.57603668193913, 57.91372894228104, 58.24946351684281, 58.58327406350725, 58.915193286621744, 59.245252974394504, 59.573484034425924, 59.899916527487754, 60.2245796996542, 60.547502012882426, 60.868711174132805, 61.18823416311343, 61.50609725872713, 61.822326064294934, 62.136945531623944, 62.449979983983994, 62.76145313805283], [0.0, 6.324555320336759, 8.94427190999916, 10.954451150103324, 12.649110640673518, 14.142135623730951, 15.491933384829668, 16.73320053068151, 17.88854381999832, 18.973665961010276, 20.0, 20.976176963403034, 21.90890230020665, 22.803508501982762, 23.664319132398465, 24.49489742783178, 25.298221281347036, 26.076809620810593, 26.832815729997478, 27.568097504180447, 28.284271247461902, 28.98275349237888, 29.664793948382652, 30.331501776206203, 30.983866769659336, 31.622776601683796, 32.249030993194204, 32.86335345030997, 33.46640106136302, 34.058772731852805, 34.64101615137754, 35.21363372331802, 35.77708763999664, 36.331804249169906, 36.87817782917155, 37.416573867739416, 37.94733192202055, 38.470768123342694, 38.98717737923586, 39.496835316263, 40.0, 40.496913462633174, 40.9878030638384, 41.47288270665544, 41.95235392680607, 42.426406871192846, 42.89522117905443, 43.3589667773576, 43.8178046004133, 44.27188724235731, 44.721359549995796, 45.166359162544865, 45.607017003965524, 46.04345773288536, 46.47580015448901, 46.9041575982343, 47.32863826479693, 47.74934554525329, 48.16637831516918, 48.579831205964474, 48.98979485566356, 49.39635614091387, 49.79959839195493, 50.19960159204453, 50.59644256269407, 50.99019513592785, 51.38093031466052, 51.76871642217914, 52.153619241621186, 52.53570214625479, 52.91502622129181, 53.291650377896914, 53.665631459994955, 54.037024344425184, 54.40588203494177, 54.772255750516614, 55.13619500836089, 55.49774770204643, 55.85696017507577, 56.213877290220786, 56.568542494923804, 56.92099788303083, 57.27128425310542, 57.619441163551734, 57.96550698475776, 58.309518948453004, 58.65151319446072, 58.99152481501051, 59.329587896765304, 59.66573556070519, 60.0, 60.332412515993425, 60.663003552412405, 60.991802727907626, 61.31883886702357, 61.64414002968976, 61.96773353931867, 62.28964600958975, 62.609903369994115, 62.928530890209096, 63.24555320336759, 63.56099432828282], [0.0, 6.403124237432849, 9.055385138137417, 11.09053650640942, 12.806248474865699, 14.317821063276355, 15.684387141358124, 16.94107434609742, 18.110770276274835, 19.20937271229855, 20.248456731316587, 21.236760581595306, 22.18107301281884, 23.086792761230395, 23.95829710142188, 24.79919353527449, 25.612496949731398, 26.40075756488817, 27.166155414412252, 27.91057147390573, 28.63564212655271, 29.342801502242423, 30.033314835362415, 30.708305065568176, 31.36877428271625, 32.01562118716425, 32.649655434629025, 33.27160951922826, 33.88214869219484, 34.48187929913334, 35.07135583350036, 35.65108693995178, 36.22154055254967, 36.78314831549905, 37.33630940518894, 37.881393849751625, 38.4187454245971, 38.9486841883009, 39.47150871198111, 39.98749804626442, 40.496913462633174, 41.0, 41.496987842492864, 41.98809355043404, 42.47352116319061, 42.95346318982906, 43.42810150121693, 43.89760813529594, 44.36214602563768, 44.82186966202994, 45.27692569068709, 45.72745346069471, 46.17358552246079, 46.61544808322667, 47.053161424074375, 47.48684028233507, 47.91659420284376, 48.34252786108729, 48.76474136094644, 49.18333050943175, 49.59838707054898, 50.009999000199954, 50.41825066382213, 50.82322303829225, 51.224993899462795, 51.62363799656123, 52.01922721455981, 52.41183072551464, 52.80151512977634, 53.18834458788881, 53.5723809439155, 53.95368384086485, 54.332310828824504, 54.70831746635972, 55.08175741568164, 55.45268253204709, 55.82114294781146, 56.18718715152059, 56.55086206239478, 56.91221310052879, 57.27128425310542, 57.628118136895644, 57.98275605729691, 58.33523806414096, 58.68560300448485, 59.03388857258177, 59.38013135721409, 59.72436688655645, 60.06662967072483, 60.40695324215582, 60.74537019394977, 61.081912216301816, 61.41661013113635, 61.74949392505173, 62.08059278067503, 62.4099351065197, 62.7375485654325, 63.063460101710255, 63.38769596696193, 63.71028174478591, 64.0312423743285, 64.35060217278469], [0.0, 6.480740698407861, 9.165151389911681, 11.224972160321828, 12.961481396815723, 14.49137674618944, 15.874507866387546, 17.146428199482248, 18.330302779823363, 19.44222209522358, 20.4939015319192, 21.49418526020468, 22.449944320643656, 23.36664289109585, 24.248711305964285, 25.09980079602227, 25.922962793631445, 26.720778431774775, 27.495454169735044, 28.248893783651074, 28.98275349237888, 29.698484809835, 30.39736830714133, 31.08054053584011, 31.749015732775092, 32.403703492039305, 33.04542328371662, 33.67491648096548, 34.292856398964496, 34.8998567332303, 35.4964786985977, 36.08323710533743, 36.660605559646726, 37.22902093797258, 37.78888725538237, 38.340579025361635, 38.88444419044716, 39.42080668885406, 39.94996871087636, 40.472212689696136, 40.9878030638384, 41.496987842492864, 42.00000000000001, 42.49705872175156, 42.98837052040936, 43.474130238568314, 43.95452195167182, 44.42971978304613, 44.89988864128731, 45.365184888855026, 45.825756949558404, 46.28174586162454, 46.7332857821917, 47.18050444834181, 47.62352359916264, 48.06245936279167, 48.49742261192857, 48.928519290900276, 49.35585071701227, 49.77951385861457, 50.19960159204454, 50.61620293937506, 51.0294032886923, 51.43928459844674, 51.84592558726289, 52.249401910452534, 52.64978632435274, 53.04714883949938, 53.44155686354955, 53.83307533477909, 54.22176684690384, 54.60769176590419, 54.99090833947009, 55.37147279962851, 55.749439459065414, 56.12486080160913, 56.49778756730215, 56.868268832451726, 57.23635208501675, 57.60208329565868, 57.96550698475776, 58.32666628567075, 58.685603004484854, 59.04235767650205, 59.39696961967, 59.74947698515863, 60.09991680526688, 60.448325038829665, 60.79473661428266, 61.13918547053109, 61.4817045957576, 61.822326064294934, 62.16108107168022, 62.49799996799898, 62.83311228962005, 63.166446789415026, 63.498031465550184, 63.8278935889318, 64.15605972938177, 64.48255578061404, 64.80740698407861, 65.13063795173514], [0.0, 6.557438524302, 9.273618495495704, 11.357816691600549, 13.114877048604, 14.66287829861518, 16.06237840420901, 17.349351572897472, 18.547236990991408, 19.672315572906, 20.73644135332772, 21.748563170931547, 22.715633383201098, 23.643180835073778, 24.535688292770594, 25.396850198400585, 26.229754097208, 27.037011669191546, 27.820855486487112, 28.583211855912904, 29.32575659723036, 30.04995840263344, 30.757112998459395, 31.448370387032774, 32.12475680841802, 32.78719262151, 33.436506994600975, 34.07345007480164, 34.698703145794944, 35.31288716601915, 35.91656999213593, 36.51027252705737, 37.094473981982816, 37.66961640367473, 38.236108588610314, 38.79432948254165, 39.344631145812, 39.88734135035826, 40.422765862815474, 40.95119045888654, 41.47288270665544, 41.98809355043403, 42.49705872175156, 42.99999999999999, 43.497126341863094, 43.98863489584553, 44.47471191587417, 44.955533585978046, 45.431266766402196, 45.902069670114, 46.36809247747852, 46.82947789587238, 47.286361670147556, 47.738873049120045, 48.187135212627034, 48.63126566315131, 49.07137658554119, 49.50757517794625, 49.93996395673509, 50.36864103785211, 50.79370039680117, 51.215232109207506, 51.63332257370234, 52.04805471869241, 52.459508194416, 52.867759551545205, 53.272882407468806, 53.67494760127857, 54.07402333838309, 54.47017532558528, 54.8634668973808, 55.253959134165214, 55.641710972974224, 56.026779311325754, 56.40921910468181, 56.789083458002736, 57.16642371182581, 57.5412895232632, 57.91372894228103, 58.283788483591216, 58.65151319446072, 59.016946718718, 59.38013135721409, 59.74110812497538, 60.09991680526688, 60.456596000767355, 60.81118318204308, 61.163714733492114, 61.51422599691879, 61.86275131288617, 62.20932405998316, 62.553976692133645, 62.89674077406555, 63.237647015049504, 63.57672530100933, 63.91400472509917, 64.24951361683604, 64.5832795698701, 64.91532946846992, 65.24568951279464, 65.57438524302, 65.90144156238162], [0.0, 6.6332495807108005, 9.38083151964686, 11.48912529307606, 13.266499161421601, 14.832396974191328, 16.24807680927192, 17.549928774784245, 18.76166303929372, 19.899748742132402, 20.976176963403034, 22.000000000000007, 22.97825058615212, 23.9165214862028, 24.819347291981714, 25.69046515733026, 26.532998322843202, 27.349588662354687, 28.14249455894058, 28.913664589601925, 29.664793948382655, 30.39736830714133, 31.112698372208094, 31.811947441173736, 32.49615361854384, 33.166247903554, 33.82306905057553, 34.46737587922818, 35.09985754956849, 35.72114219898351, 36.3318042491699, 36.93237062523878, 37.52332607858744, 38.10511776651531, 38.67815921162743, 39.24283374069717, 39.799497484264805, 40.34848200366404, 40.89009660052175, 41.42463035441597, 41.95235392680607, 42.473521163190604, 42.98837052040936, 43.497126341863094, 44.000000000000014, 44.49719092257398, 44.98888751680797, 45.4752680036083, 45.95650117230424, 46.4327470649756, 46.9041575982343, 47.370877129308056, 47.8330429724056, 48.290785870598555, 48.74423042781577, 49.19349550499538, 49.63869458396343, 50.07993610219567, 50.51732376126036, 50.950956811427986, 51.38093031466052, 51.807335387954474, 52.230259428802384, 52.64978632435273, 53.065996645686404, 53.47896782848375, 53.888774341229926, 54.295487841992916, 54.699177324709375, 55.099909255823654, 55.49774770204643, 55.89275444992849, 56.28498911788116, 56.67450926121902, 57.06137047074842, 57.44562646538029, 57.82732917920385, 58.206528843421, 58.58327406350725, 58.957611891934704, 59.32958789676531, 59.6992462263972, 60.066629670724836, 60.43177971895251, 60.79473661428266, 61.155539405682624, 61.514225996918796, 61.870833193032084, 62.22539674441619, 62.57795138864806, 62.928530890209096, 63.27716807822551, 63.62389488234747, 63.96874236687791, 64.31174076325412, 64.65291950097846, 64.99230723708769, 65.32993188424432, 65.66582063752803, 66.00000000000001, 66.332495807108, 66.66333324999584], [0.0, 6.7082039324993685, 9.486832980505138, 11.618950038622252, 13.416407864998737, 15.0, 16.431676725154983, 17.748239349298846, 18.973665961010276, 20.124611797498105, 21.213203435596423, 22.24859546128699, 23.237900077244504, 24.18677324489565, 25.099800796022265, 25.980762113533157, 26.832815729997474, 27.658633371878658, 28.460498941515414, 29.24038303442689, 30.0, 30.740852297878796, 31.464265445104544, 32.17141588429082, 32.863353450309965, 33.54101966249684, 34.20526275297414, 34.856850115866756, 35.49647869859769, 36.124783736376884, 36.74234614174767, 37.34969879396619, 37.94733192202055, 38.53569773599539, 39.11521443121589, 39.68626966596886, 40.24922359499621, 40.80441152620633, 41.352146256270665, 41.892720131306824, 42.426406871192846, 42.95346318982906, 43.474130238568314, 43.988634895845536, 44.49719092257398, 44.99999999999999, 45.4972526643093, 45.98912915026767, 46.47580015448901, 46.957427527495575, 47.43416490252569, 47.90615826801394, 48.3735464897913, 48.83646178829912, 49.29503017546495, 49.749371855331, 50.19960159204453, 50.6458290484024, 51.0881590977792, 51.526692111953, 51.96152422706631, 52.39274758971894, 52.820450584977024, 53.244718047896534, 53.66563145999495, 54.08326913195984, 54.497706373754845, 54.90901565316938, 55.317266743757315, 55.72252686302013, 56.12486080160912, 56.52433104425032, 56.92099788303083, 57.3149195236284, 57.70615218501403, 58.09475019311125, 58.48076606885378, 58.86425061104575, 59.2452529743945, 59.62382074305537, 60.0, 60.373835392494314, 60.74537019394976, 61.11464636239008, 61.48170459575759, 61.8465843842649, 62.20932405998315, 62.56996084384263, 62.92853089020909, 63.285069329186946, 63.63961030678927, 63.99218702310462, 64.34283176858165, 64.69157595854347, 65.0384501660364, 65.38348415311009, 65.72670690061993, 66.06814663663572, 66.40783086353596, 66.74578638386096, 67.08203932499369, 67.4166151627327], [0.0, 6.782329983125269, 9.59166304662544, 11.747340124470734, 13.564659966250538, 15.165750888103101, 16.61324772583615, 17.944358444926362, 19.18332609325088, 20.346989949375807, 21.447610589527216, 22.49444375840399, 23.494680248941467, 24.45403852127497, 25.37715508089904, 26.267851073127396, 27.129319932501076, 27.964262908219126, 28.77498913987632, 29.56349099818897, 30.331501776206203, 31.08054053584011, 31.811947441173732, 32.526911934581186, 33.2264954516723, 33.91164991562634, 34.58323293158117, 35.242020373412196, 35.888716889852724, 36.523964735499355, 37.14835124201342, 37.76241517699842, 38.36665218650176, 38.96151947755632, 39.54743986657038, 40.12480529547776, 40.693979898751614, 41.25530268947254, 41.80908992073375, 42.35563716909475, 42.89522117905443, 43.42810150121693, 43.95452195167183, 44.474711915874174, 44.98888751680798, 45.4972526643093, 46.0, 46.49731175025068, 46.989360497882934, 47.47630988187688, 47.9583152331272, 48.43552415324935, 48.90807704254994, 49.376107582514045, 49.83974317750846, 50.29910535983717, 50.75431016179808, 51.205468457968436, 51.652686280579836, 52.09606511052442, 52.53570214625479, 52.97169055259611, 53.40411969127476, 53.83307533477908, 54.25863986500215, 54.680892457969264, 55.09990925582365, 55.515763527128044, 55.92852581643825, 56.338264084013105, 56.74504383644443, 57.1489282489182, 57.54997827975264, 57.94825277780168, 58.34380858325928, 58.73670062235366, 59.12698199637794, 59.51470406546604, 59.899916527487754, 60.28266749240615, 60.663003552412405, 61.04096984812742, 61.41661013113636, 61.78996682310163, 62.16108107168022, 62.52999280345393, 62.89674077406555, 63.26136261573885, 63.623894882347464, 63.984373092185564, 64.34283176858165, 64.69930447848725, 65.05382386916237, 65.40642170307133, 65.7571288910944, 66.10597552415364, 66.4529909033446, 66.79820356865895, 67.14164132637808, 67.48333127521197, 67.82329983125268, 68.1615727518079], [0.0, 6.855654600401045, 9.695359714832659, 11.874342087037919, 13.71130920080209, 15.329709716755893, 16.792855623746664, 18.138357147217054, 19.390719429665317, 20.566963801203133, 21.6794833886788, 22.73763400180415, 23.748684174075837, 24.718414188616553, 25.65151067676132, 26.551836094703507, 27.42261840160418, 28.266588050205137, 29.086079144497976, 29.883105594967873, 30.659419433511786, 31.41655614481002, 32.155870381627054, 32.87856444554719, 33.58571124749333, 34.27827300200522, 34.957116585897076, 35.62302626111376, 36.27671429443411, 36.91882988394947, 37.54996671103717, 38.17066936798463, 38.781438859330635, 39.38273733503044, 39.97499218261337, 40.5585995813465, 41.13392760240627, 41.70131892398609, 42.26109321823088, 42.81354925721529, 43.3589667773576, 43.89760813529594, 44.42971978304613, 44.955533585978046, 45.4752680036083, 45.98912915026767, 46.49731175025068, 47.0, 47.497368348151674, 47.989582202807306, 48.47679857416329, 48.95916665957459, 49.436828377233105, 49.909918853871126, 50.378566871240004, 50.84289527554465, 51.30302135352264, 51.75905717843014, 52.21110992882645, 52.65928218272634, 53.103672189407014, 53.54437412091022, 53.98147830506312, 54.41507144165116, 54.84523680320836, 55.27205442174191, 55.695601262577284, 56.1159513863928, 56.53317610041027, 56.9473440996154, 57.358521598799946, 57.76677245614472, 58.17215828899595, 58.57473858242989, 58.97457079114692, 59.37171043518959, 59.766211189935746, 60.15812497078013, 60.54750201288242, 60.9343909463285, 61.31883886702357, 61.7008914036094, 62.08059278067503, 62.457985878508765, 62.83311228962004, 63.20601237224193, 63.57672530100933, 63.945289114992676, 64.31174076325411, 64.6761161480805, 65.0384501660364, 65.39877674696982, 65.75712889109438, 66.11353870426238, 66.46803743153548, 66.82065548915244, 67.17142249498666, 67.52036729757918, 67.86751800382861, 68.21290200541245, 68.55654600401044, 68.89847603539573], [0.0, 6.9282032302755105, 9.797958971132713, 12.000000000000004, 13.856406460551021, 15.49193338482967, 16.970562748477143, 18.330302779823363, 19.595917942265427, 20.78460969082653, 21.90890230020665, 22.97825058615212, 24.000000000000007, 24.9799919935936, 25.922962793631445, 26.83281572999748, 27.712812921102042, 28.5657137141714, 29.39387691339814, 30.199337741083006, 30.98386676965934, 31.749015732775096, 32.49615361854384, 33.22649545167231, 33.941125496954285, 34.641016151377556, 35.3270434653114, 36.000000000000014, 36.660605559646726, 37.30951621235527, 37.94733192202055, 38.57460304397183, 39.19183588453085, 39.79949748426481, 40.39801975344832, 40.9878030638384, 41.56921938165306, 42.14261501141097, 42.70831300812525, 43.26661530556788, 43.8178046004133, 44.36214602563768, 44.89988864128731, 45.431266766402196, 45.95650117230424, 46.475800154489, 46.98936049788293, 47.497368348151674, 48.000000000000014, 48.49742261192857, 48.98979485566357, 49.47726750741194, 49.9599839871872, 50.43808085167398, 50.911688245431435, 51.380930314660525, 51.84592558726289, 52.30678732248809, 52.763623833091685, 53.21653878260029, 53.66563145999496, 54.11099703387474, 54.552726787943435, 54.99090833947008, 55.425625842204084, 55.85696017507577, 56.28498911788116, 56.70978751503131, 57.1314274283428, 57.549978279752644, 57.96550698475776, 58.37807807730571, 58.78775382679628, 59.194594347794975, 59.59865770300536, 60.00000000000001, 60.39867548216601, 60.79473661428266, 61.18823416311343, 61.57921727336262, 61.96773353931868, 62.35382907247959, 62.737548565432505, 63.11893535223801, 63.49803146555019, 63.87487769068525, 64.24951361683605, 64.62197768561406, 64.99230723708769, 65.36053855347276, 65.72670690061994, 66.09084656743323, 66.45299090334461, 66.81317235396027, 67.17142249498667, 67.52777206453653, 67.88225099390857, 68.23488843692793, 68.585712797929, 68.93475175845636, 69.28203230275511, 69.62758074211685], [0.0, 7.0, 9.899494936611665, 12.124355652982143, 14.0, 15.652475842498529, 17.146428199482248, 18.520259177452136, 19.79898987322333, 21.0, 22.135943621178654, 23.216373532487804, 24.248711305964285, 25.23885892824793, 26.19160170741759, 27.110883423451916, 28.0, 28.861739379323623, 29.698484809834998, 30.51229260478472, 31.304951684997057, 32.07802986469088, 32.83291031876401, 33.57082066318904, 34.292856398964496, 35.0, 35.6931365951495, 36.37306695894643, 37.04051835490427, 37.69615364994153, 38.34057902536162, 38.97435053981015, 39.59797974644666, 40.21193852576621, 40.8166632639171, 41.41255848169732, 42.0, 42.57933771208754, 43.15089802078284, 43.71498598878879, 44.27188724235731, 44.82186966202994, 45.365184888855026, 45.902069670114, 46.43274706497561, 46.957427527495575, 47.47630988187687, 47.98958220280731, 48.49742261192857, 49.0, 49.49747468305833, 49.98999899979996, 50.47771785649586, 50.960769224963634, 51.43928459844675, 51.91338940966965, 52.38320341483518, 52.84884104689525, 53.31041174104736, 53.76802023508026, 54.22176684690383, 54.67174773134658, 55.11805511808268, 55.5607775323564, 56.0, 56.43580423808985, 56.868268832451726, 57.29746940310715, 57.723478758647246, 58.146367040426526, 58.56620185738529, 58.98304841223452, 59.396969619669996, 59.80802621722272, 60.21627686929838, 60.62177826491071, 61.02458520956944, 61.424750711744856, 61.822326064294934, 62.21736092120912, 62.609903369994115, 63.0, 63.38769596696193, 63.773035054010094, 64.15605972938177, 64.53681120105021, 64.91532946846992, 65.2916533716217, 65.66582063752801, 66.03786792439622, 66.40783086353596, 66.7757440991862, 67.14164132637808, 67.50555532695068, 67.86751800382861, 68.22756041366274, 68.58571279792899, 68.94200461257273, 69.29646455628166, 69.6491205974634, 70.0, 70.34912934784623], [0.0, 7.071067811865476, 10.000000000000002, 12.247448713915894, 14.142135623730953, 15.811388300841898, 17.320508075688775, 18.708286933869708, 20.000000000000004, 21.213203435596427, 22.360679774997898, 23.452078799117153, 24.494897427831788, 25.495097567963928, 26.45751311064591, 27.386127875258307, 28.284271247461906, 29.154759474226502, 30.000000000000004, 30.822070014844886, 31.622776601683796, 32.403703492039305, 33.166247903554, 33.91164991562634, 34.64101615137755, 35.35533905932738, 36.0555127546399, 36.74234614174768, 37.416573867739416, 38.07886552931954, 38.72983346207417, 39.370039370059054, 40.00000000000001, 40.62019202317981, 41.23105625617661, 41.83300132670378, 42.42640687119285, 43.011626335213144, 43.588989435406745, 44.15880433163924, 44.721359549995796, 45.27692569068709, 45.82575694955841, 46.36809247747852, 46.904157598234306, 47.43416490252569, 47.958315233127195, 48.4767985741633, 48.989794855663575, 49.49747468305833, 50.00000000000001, 50.4975246918104, 50.990195135927856, 51.47815070493501, 51.96152422706633, 52.440442408507586, 52.91502622129182, 53.38539126015656, 53.851648071345046, 54.31390245600108, 54.772255750516614, 55.226805085936306, 55.677643628300224, 56.124860801609124, 56.56854249492381, 57.008771254956905, 57.44562646538029, 57.87918451395113, 58.309518948453004, 58.73670062235366, 59.16079783099616, 59.58187643906493, 60.00000000000001, 60.41522986797286, 60.82762530298219, 61.237243569579455, 61.64414002968977, 62.048368229954285, 62.449979983983994, 62.84902544988268, 63.24555320336759, 63.63961030678928, 64.0312423743285, 64.42049363362563, 64.80740698407861, 65.19202405202648, 65.57438524302, 65.9545297913646, 66.332495807108, 66.70832032063167, 67.0820393249937, 67.45368781616021, 67.82329983125268, 68.19090848492928, 68.55654600401046, 68.9202437604511, 69.2820323027551, 69.6419413859206, 70.0, 70.35623639735145, 70.71067811865476, 71.06335201775948], [0.0, 7.141428428542851, 10.09950493836208, 12.369316876852984, 14.282856857085703, 15.968719422671315, 17.492855684535904, 18.894443627691185, 20.19900987672416, 21.424285285628553, 22.583179581272432, 23.685438564654028, 24.73863375370597, 25.74878637916747, 26.72077843177478, 27.658633371878665, 28.565713714171405, 29.444863728670914, 30.29851481508624, 31.128764832546768, 31.93743884534263, 32.72613634390715, 33.49626844888846, 34.24908757908742, 34.98571136907181, 35.707142142714254, 36.414282912066255, 37.10795063055895, 37.78888725538237, 38.45776904605883, 39.11521443121589, 39.76179070414209, 40.39801975344832, 41.02438299353204, 41.64132562731403, 42.249260348555225, 42.848570571257106, 43.43961325794695, 44.022721406110286, 44.59820624195552, 45.166359162544865, 45.72745346069471, 46.28174586162455, 46.82947789587239, 47.370877129308056, 47.90615826801393, 48.43552415324934, 48.9591666595746, 49.47726750741194, 49.98999899979995, 50.4975246918104, 51.000000000000014, 51.49757275833494, 51.99038372622385, 52.47856705360772, 52.96225070746145, 53.44155686354956, 53.916602266834296, 54.3874985635486, 54.85435260760991, 55.31726674375733, 55.776339069537364, 56.2316636780382, 56.68333088307356, 57.13142742834281, 57.57603668193914, 58.017238817441154, 58.45511098270194, 58.88972745734183, 59.32115979985558, 59.74947698515863, 60.17474553332155, 60.59702963017248, 61.01639124038721, 61.43289021363068, 61.846584384264915, 62.257529665093536, 62.6657801355732, 63.07138812488593, 63.47440429023341, 63.87487769068526, 64.27285585688566, 64.66838485689898, 65.0615093584525, 65.4522726878143, 65.84071688552609, 66.2268827591938, 66.61080993352357, 66.99253689777692, 67.3721010508059, 67.7495387438173, 68.1248853210044, 68.49817515817485, 68.86944169949399, 69.23871749245505, 69.60603422117941, 69.97142273814362, 70.33491309442276, 70.69653456853456, 71.05631569396208, 71.41428428542851, 71.77046746399247], [0.0, 7.211102550927979, 10.19803902718557, 12.4899959967968, 14.422205101855958, 16.124515496597102, 17.663521732655695, 19.078784028338916, 20.39607805437114, 21.633307652783937, 22.803508501982762, 23.9165214862028, 24.9799919935936, 26.000000000000004, 26.981475126464083, 27.928480087537885, 28.844410203711917, 29.732137494637012, 30.594117081556714, 31.432467291003427, 32.249030993194204, 33.045423283716616, 33.823069050575526, 34.583232931581165, 35.32704346531139, 36.0555127546399, 36.76955262170048, 37.4699879903904, 38.15756805667783, 38.832975677895206, 39.496835316262995, 40.149719799769464, 40.79215610874228, 41.42463035441597, 42.04759208325728, 42.66145801540309, 43.266615305567875, 43.863424398922625, 44.45222154178575, 45.03332099679082, 45.607017003965524, 46.17358552246078, 46.7332857821917, 47.286361670147556, 47.8330429724056, 48.373546489791295, 48.908077042549934, 49.436828377233105, 49.9599839871872, 50.47771785649585, 50.990195135927856, 51.49757275833494, 52.00000000000001, 52.49761899362676, 52.99056519796709, 53.47896782848376, 53.96295025292817, 54.442630355264804, 54.91812087098393, 55.389529696504916, 55.85696017507577, 56.32051136131489, 56.780278266313566, 57.23635208501674, 57.68882040742383, 58.137767414994535, 58.58327406350725, 59.02541825349483, 59.464274989274024, 59.899916527487754, 60.332412515993425, 60.76183012385326, 61.18823416311343, 61.61168720299746, 62.032249677083286, 62.44997998398399, 62.86493458200685, 63.2771680782255, 63.68673331236264, 64.09368143584827, 64.49806198638841, 64.89992295835181, 65.29931086925805, 65.69627082262737, 66.09084656743323, 66.48308055437865, 66.87301398920195, 67.26068688320096, 67.64613810115105, 68.0294054067798, 68.41052550594829, 68.78953408767936, 69.16646586316233, 69.54135460285484, 69.91423317179415, 70.28513356322232, 70.65408693062278, 71.02112361825883, 71.386273190299, 71.74956445860839, 72.1110255092798, 72.47068372797376], [0.0, 7.28010988928052, 10.295630140987003, 12.609520212918495, 14.56021977856104, 16.27882059609971, 17.83255450012701, 19.261360284258224, 20.591260281974005, 21.84032966784156, 23.02172886644268, 24.145392935299277, 25.21904042583699, 26.24880949681338, 27.239676943752475, 28.195744359743372, 29.12043955712208, 30.01666203960727, 30.886890422961006, 31.73326330524487, 32.55764119219942, 33.36165463522456, 34.14674215792775, 34.91418050019219, 35.66510900025402, 36.4005494464026, 37.121422386541184, 37.828560638755484, 38.52272056851645, 39.204591567825325, 39.87480407475377, 40.533936399022494, 41.18252056394801, 41.82104733265298, 42.449970553582254, 43.06971093471606, 43.68065933568312, 44.28317965096907, 44.87761134463376, 45.46427168667723, 46.04345773288536, 46.61544808322667, 47.18050444834181, 47.738873049120045, 48.290785870598555, 48.83646178829912, 49.37610758251404, 49.909918853871126, 50.43808085167398, 50.960769224963634, 51.47815070493501, 51.99038372622385, 52.49761899362676, 53.000000000000014, 53.49766350038104, 53.990739946772365, 54.47935388750495, 54.96362433464519, 55.443665102516455, 55.91958512006326, 56.391488719486745, 56.859475903318, 57.32364259186606, 57.78408085277467, 58.24087911424416, 58.69412236331676, 59.14389233048499, 59.59026766175833, 60.03332407921454, 60.47313453096343, 60.909769331364245, 61.343296292260014, 61.77378084592201, 62.201286160335954, 62.625873247404705, 63.04760106459247, 63.46652661048974, 63.88270501473776, 64.29618962271405, 64.70703207534712, 65.11528238439884, 65.52098900352468, 65.92419889539805, 66.32495759516172, 66.72330927044912, 67.11929677819934, 67.512961718473, 67.90434448545984, 68.2934843158555, 68.6804193347711, 69.06518659932803, 69.44782214007867, 69.82836100038438, 70.20683727387241, 70.5832841400852, 70.95773389842716, 71.33021800050804, 71.70076708097342, 72.06941098690902, 72.43617880589782, 72.8010988928052, 73.1641988953614], [0.0, 7.348469228349535, 10.392304845413264, 12.727922061357859, 14.69693845669907, 16.431676725154986, 18.0, 19.44222209522358, 20.784609690826528, 22.045407685048605, 23.237900077244504, 24.372115213907886, 25.455844122715718, 26.495282598983543, 27.49545416973504, 28.460498941515414, 29.39387691339814, 30.298514815086232, 31.176914536239792, 32.03123475609394, 32.86335345030997, 33.67491648096548, 34.46737587922817, 35.242020373412196, 36.0, 36.742346141747674, 37.46998799039039, 38.183766184073576, 38.88444419044716, 39.572717874818764, 40.24922359499621, 40.91454509095757, 41.569219381653056, 42.213741838410876, 42.8485705712571, 43.47413023856832, 44.09081537009721, 44.698993277254026, 45.299006611624506, 45.89117562233507, 46.47580015448901, 47.05316142407437, 47.62352359916264, 48.187135212627034, 48.74423042781577, 49.295030175464944, 49.839743177508446, 50.37856687124, 50.911688245431435, 51.43928459844674, 51.96152422706632, 52.47856705360771, 52.990565197967086, 53.49766350038103, 54.00000000000001, 54.49770637375486, 54.99090833947008, 55.4797260267208, 55.964274318532894, 56.444663166680336, 56.92099788303083, 57.39337940912697, 57.86190456595773, 58.32666628567074, 58.78775382679628, 59.2452529743945, 59.6992462263972, 60.149812967290266, 60.597029630172464, 61.04096984812742, 61.48170459575759, 61.91930232165088, 62.353829072479584, 62.78534860936905, 63.21392251711643, 63.63961030678928, 64.06246951218787, 64.48255578061404, 64.89992295835181, 65.31462317123173, 65.72670690061994, 66.1362230551458, 66.54321903845651, 66.94774081326419, 67.34983296193096, 67.7495387438173, 68.14690014960328, 68.54195795277518, 68.93475175845634, 69.32532004974806, 69.71370023173351, 70.09992867328754, 70.48404074682439, 70.8660708661063, 71.24605252222752, 71.62401831787993, 72.0, 72.37402849088892, 72.74613391789285, 73.11634564172365, 73.48469228349535, 73.85120175054703], [0.0, 7.416198487095664, 10.488088481701517, 12.845232578665131, 14.832396974191328, 16.583123951777, 18.165902124584953, 19.621416870348586, 20.976176963403034, 22.24859546128699, 23.45207879911715, 24.59674775249769, 25.690465157330262, 26.73948391424188, 27.748873851023216, 28.722813232690143, 29.664793948382655, 30.57776970284131, 31.464265445104548, 32.326459750489235, 33.166247903554, 33.98529093593286, 34.785054261852174, 35.56683848755748, 36.331804249169906, 37.08099243547832, 37.81534080237808, 38.53569773599539, 39.24283374069717, 39.93745109543172, 40.6201920231798, 41.29164564412516, 41.95235392680607, 42.602816808281595, 43.243496620879306, 43.874821936960615, 44.49719092257398, 45.11097427455985, 45.71651780264985, 46.31414470763765, 46.9041575982343, 47.486840282335066, 48.06245936279167, 48.63126566315131, 49.19349550499538, 49.74937185533099, 50.299105359837164, 50.84289527554465, 51.380930314660525, 51.91338940966964, 52.44044240850758, 52.96225070746145, 53.47896782848376, 53.990739946772365, 54.49770637375486, 55.00000000000001, 55.49774770204643, 55.991070716677676, 56.48008498577176, 56.96490147450446, 57.445626465380286, 57.92236183029832, 58.39520528262573, 58.86425061104575, 59.32958789676531, 59.79130371550699, 60.249481325568276, 60.70420084310476, 61.15553940568262, 61.60357132504576, 62.048368229954285, 62.48999919987198, 62.928530890209096, 63.36402764976356, 63.79655163094632, 64.22616289332565, 64.65291950097847, 65.07687761409578, 65.49809157525127, 65.91661399070799, 66.332495807108, 66.74578638386097, 67.15653356152328, 67.56478372643548, 67.97058187186572, 68.37397165588672, 68.7749954561976, 69.17369442208505, 69.57010852370435, 69.9642765988472, 70.35623639735145, 70.74602462329598, 71.13367697511497, 71.51922818375489, 71.90271204899021, 72.28416147400479, 72.66360849833981, 73.0410843293006, 73.41661937191061, 73.79024325749306, 74.16198487095664, 74.53187237685634], [0.0, 7.483314773547883, 10.583005244258363, 12.961481396815723, 14.966629547095765, 16.73320053068151, 18.33030277982336, 19.79898987322333, 21.166010488516726, 22.44994432064365, 23.664319132398465, 24.819347291981718, 25.922962793631445, 26.981475126464083, 28.0, 28.982753492378876, 29.93325909419153, 30.85449724108302, 31.74901573277509, 32.619012860600186, 33.46640106136302, 34.292856398964496, 35.09985754956849, 35.888716889852724, 36.66060555964672, 37.416573867739416, 38.15756805667783, 38.88444419044717, 39.59797974644666, 40.29888335921977, 40.987803063838385, 41.66533331199932, 42.33202097703345, 42.98837052040936, 43.634848458542855, 44.27188724235731, 44.8998886412873, 45.519226706964176, 46.130250378683186, 46.73328578219169, 47.32863826479693, 47.916594202843754, 48.49742261192857, 49.07137658554119, 49.638694583963435, 50.19960159204452, 50.75431016179808, 51.303021353522645, 51.84592558726289, 52.38320341483518, 52.91502622129181, 53.44155686354956, 53.96295025292817, 54.47935388750495, 54.99090833947008, 55.49774770204643, 56.0, 56.49778756730214, 56.991227395100026, 57.48043145279965, 57.96550698475775, 58.44655678480983, 58.92367945062494, 59.39696961966999, 59.86651818838306, 60.332412515993425, 60.794736614282655, 61.253571324454214, 61.70899448216604, 62.161081071680215, 62.60990336999411, 63.05553108173779, 63.49803146555018, 63.93746945258312, 64.37390775772431, 64.8074069840786, 65.23802572120037, 65.66582063752801, 66.09084656743323, 66.51315659326356, 66.93280212272605, 67.34983296193094, 67.76429738438968, 68.17624219623724, 68.58571279792899, 68.99275324264136, 69.39740629158989, 69.79971346646059, 70.19971509913698, 70.59745037889115, 70.9929573971954, 71.386273190299, 71.77743377970545, 72.16647421067486, 72.55342858886823, 72.93833011524187, 73.32121111929344, 73.70210309075311, 74.08103670980854, 74.45804187594514, 74.83314773547883, 75.20638270785267], [0.0, 7.54983443527075, 10.677078252031311, 13.076696830622023, 15.0996688705415, 16.881943016134134, 18.49324200890693, 19.974984355438178, 21.354156504062622, 22.64950330581225, 23.874672772626646, 25.039968051097834, 26.153393661244046, 27.221315177632402, 28.24889378365107, 29.24038303442689, 30.199337741083, 31.12876483254676, 32.03123475609394, 32.908965343808674, 33.76388603226827, 34.59768778401239, 35.41186241925155, 36.207733980463345, 36.98648401781386, 37.74917217635375, 38.49675310984032, 39.23009049186607, 39.949968710876355, 40.65710270051225, 41.35214625627066, 42.035699113967404, 42.708313008125245, 43.37049688440289, 44.02272140611028, 44.665422868254595, 45.2990066116245, 45.92385001282014, 46.54030511288039, 47.148700936505136, 47.74934554525329, 48.342527861087284, 48.928519290900276, 49.50757517794625, 50.07993610219567, 50.64582904840239, 51.20546845796843, 51.75905717843014, 52.30678732248809, 52.848841046895245, 53.38539126015656, 53.91660226683429, 54.442630355264804, 54.96362433464519, 55.4797260267208, 55.991070716677676, 56.49778756730214, 57.00000000000001, 57.49782604586021, 57.99137866959191, 58.48076606885378, 58.96609195122227, 59.447455790807396, 59.924953066314536, 60.398675482166, 60.868711174132805, 61.335144900782616, 61.79805822192151, 62.25752966509352, 62.713634881100624, 63.166446789415026, 63.6160357142757, 64.06246951218787, 64.50581369148055, 64.94613152451807, 65.3834841531101, 65.81793068761735, 66.24952830020754, 66.6783323126786, 67.10439627923047, 67.52777206453653, 67.94850991743675, 68.36665854054885, 68.78226515607058, 69.19537556802479, 69.60603422117941, 70.01428425685718, 70.42016756583301, 70.8237248385031, 71.22499561249548, 71.62401831787993, 72.02083032012337, 72.41546796092669, 72.80796659706958, 73.1983606373804, 73.58668357794092, 73.97296803562772, 74.35724578008522, 74.73954776421918, 75.11990415329349, 75.4983443527075, 75.87489703452651], [0.0, 7.6157731058639095, 10.77032961426901, 13.190905958272923, 15.231546211727819, 17.029386365926403, 18.65475810617763, 20.149441679609886, 21.54065922853802, 22.847319317591726, 24.08318915758459, 25.258661880630182, 26.381811916545846, 27.459060435491967, 28.495613697550016, 29.495762407505254, 30.463092423455638, 31.400636936215164, 32.31098884280703, 33.19638534539567, 34.058772731852805, 34.8998567332303, 35.72114219898351, 36.52396473549935, 37.30951621235526, 38.07886552931955, 38.832975677895206, 39.572717874818764, 40.29888335921977, 41.01219330881976, 41.71330722922842, 42.402830094228385, 43.08131845707604, 43.74928570845473, 44.40720662234904, 45.055521304275246, 45.69463863518345, 46.324939287601886, 46.94677837722202, 47.56048780237647, 48.16637831516918, 48.76474136094644, 49.355850717012274, 49.93996395673509, 50.517323761260364, 51.0881590977792, 51.652686280579836, 52.21110992882646, 52.76362383309169, 53.31041174104736, 53.851648071345046, 54.3874985635486, 54.918120870983934, 55.443665102516455, 55.9642743185329, 56.48008498577176, 56.99122739510003, 57.49782604586021, 58.00000000000001, 58.497863208838666, 58.99152481501051, 59.481089431852205, 59.966657402259806, 60.44832503882965, 60.926184846911276, 61.40032573203501, 61.870833193032084, 62.3377895020348, 62.80127387243033, 63.261362615738854, 63.71812928829597, 64.1716448285378, 64.62197768561406, 65.06919393998976, 65.5133574166368, 65.9545297913646, 66.39277069079134, 66.82813778641449, 67.26068688320096, 67.6904720030818, 68.11754546370561, 68.54195795277518, 68.96375859826668, 69.38299503480663, 69.7997134664606, 70.21395872616783, 70.6257743320383, 71.03520254071218, 71.44228439796701, 71.84705978674423, 72.24956747275378, 72.6498451478047, 73.0479294709987, 73.44385610791416, 73.83765976789894, 74.22937423958254, 74.61903242471053, 75.00666637039672, 75.39230729988306, 75.77598564189054, 76.1577310586391, 76.53757247260982], [0.0, 7.681145747868608, 10.862780491200215, 13.304134695650072, 15.362291495737216, 17.175564037317667, 18.81488772222678, 20.322401432901575, 21.72556098240043, 23.043437243605823, 24.289915602982237, 25.475478405713996, 26.608269391300144, 27.694764848252458, 28.74021572639983, 29.74894956128703, 30.72458299147443, 31.670175244226225, 32.58834147360065, 33.481338085566414, 34.351128074635334, 35.199431813596085, 36.02776706930364, 36.837480912787726, 37.62977544445356, 38.40572873934304, 39.16631205513228, 39.91240408695022, 40.64480286580315, 41.36423575989287, 42.07136793592525, 42.76680956068619, 43.45112196480086, 44.12482294582042, 44.78839135311738, 45.44227107000705, 46.086874487211645, 46.72258554489467, 47.349762407006864, 47.968739820845826, 48.579831205964474, 49.18333050943175, 49.77951385861457, 50.36864103785211, 50.95095681142799, 51.526692111953, 52.096065110524414, 52.65928218272634, 53.21653878260029, 53.76802023508025, 54.31390245600108, 54.85435260760991, 55.389529696504916, 55.91958512006326, 56.44466316668034, 56.96490147450446, 57.48043145279966, 57.99137866959192, 58.49786320883866, 58.99999999999999, 59.49789912257406, 59.991666087882564, 60.48140210014976, 60.96720429870472, 61.44916598294886, 61.92737682156414, 62.40192304729078, 62.87288763847259, 63.34035048845245, 63.80438856379708, 64.26507605223851, 64.72248450113763, 65.1766829472013, 65.62773803811922, 66.07571414672715, 66.52067347825036, 66.96267617113283, 67.40178039191547, 67.83804242458652, 68.27151675479314, 68.70225614927067, 69.13031173081747, 69.55573304911681, 69.97856814768362, 70.39886362719217, 70.81666470542085, 71.2320152740325, 71.64495795239188, 72.05553413860729, 72.46378405796925, 72.86974680894672, 73.27346040688947, 73.67496182557545, 74.0742870367309, 74.47147104764348, 74.86654793697916, 75.25955088890711, 75.65051222562872, 76.03946343840151, 76.42643521714199, 76.81145747868608, 77.19455939378112], [0.0, 7.745966692414833, 10.954451150103322, 13.416407864998739, 15.491933384829666, 17.32050807568877, 18.973665961010276, 20.493901531919196, 21.908902300206645, 23.2379000772445, 24.49489742783178, 25.69046515733026, 26.832815729997478, 27.92848008753788, 28.982753492378876, 29.999999999999996, 30.983866769659333, 31.93743884534262, 32.863353450309965, 33.76388603226827, 34.64101615137754, 35.4964786985977, 36.3318042491699, 37.14835124201342, 37.94733192202055, 38.72983346207417, 39.496835316263, 40.24922359499622, 40.98780306383839, 41.71330722922842, 42.426406871192846, 43.12771730569565, 43.81780460041329, 44.49719092257398, 45.16635916254486, 45.8257569495584, 46.475800154489, 47.11687595755899, 47.74934554525329, 48.3735464897913, 48.98979485566356, 49.598387070548974, 50.19960159204454, 50.79370039680117, 51.38093031466052, 51.961524227066306, 52.535702146254785, 53.103672189407014, 53.665631459994955, 54.22176684690383, 54.77225575051661, 55.31726674375732, 55.85696017507576, 56.39148871948674, 56.92099788303083, 57.445626465380286, 57.96550698475775, 58.48076606885378, 58.9915248150105, 59.49789912257406, 59.99999999999999, 60.49793384901669, 60.99180272790762, 61.481704595757584, 61.967733539318665, 62.44997998398398, 62.92853089020909, 63.40346993658943, 63.87487769068524, 64.34283176858165, 64.8074069840786, 65.26867548832288, 65.72670690061993, 66.18156843109718, 66.63332499583072, 67.08203932499369, 67.52777206453653, 67.9705818718657, 68.41052550594829, 68.84765791223401, 69.28203230275508, 69.7137002317335, 70.14271166700073, 70.56911505750939, 70.9929573971954, 71.4142842854285, 71.83313998427188, 72.24956747275377, 72.6636084983398, 73.07530362578044, 73.48469228349533, 73.89181280764465, 74.29670248402684, 74.6993975879324, 75.09993342207434, 75.49834435270748, 75.8946638440411, 76.28892449104261, 76.68115805072325, 77.07139547199077, 77.45966692414834, 77.84600182411425], [0.0, 7.810249675906655, 11.045361017187261, 13.527749258468685, 15.62049935181331, 17.464249196572982, 19.131126469708992, 20.663978319771825, 22.090722034374522, 23.430749027719962, 24.698178070456937, 25.90366769397724, 27.05549851693737, 28.16025568065745, 29.223278392404914, 30.248966924508345, 31.24099870362662, 32.202484376209235, 33.13608305156178, 34.044089061098404, 34.928498393145965, 35.79106033634656, 36.6333181680284, 37.456641600656084, 38.262252939417984, 39.05124837953328, 39.82461550347976, 40.58324777540606, 41.32795663954365, 42.05948168962618, 42.77849927241487, 43.485629810317796, 44.181444068749045, 44.86646854834912, 45.541190146942796, 46.20606020859169, 46.861498055439924, 47.50789408087881, 48.14561246884289, 48.774993593028796, 49.39635614091387, 50.00999900019995, 50.616202939375064, 51.215232109207506, 51.80733538795448, 52.39274758971894, 52.97169055259611, 53.54437412091022, 54.11099703387474, 54.67174773134658, 55.226805085936306, 55.776339069537364, 56.3205113613149, 56.859475903318, 57.39337940912698, 57.92236183029833, 58.44655678480983, 58.966091951222275, 59.481089431852205, 59.99166608788257, 60.49793384901669, 60.99999999999999, 61.497967446087195, 61.99193495931547, 62.48199740725324, 62.96824596572466, 63.45076831686122, 63.92964883369844, 64.40496875241847, 64.87680633323438, 65.34523701081817, 65.81033353509159, 66.27216610312357, 66.73080248281148, 67.18630812896329, 67.63874629234341, 68.08817812219681, 68.53466276272175, 68.97825744392215, 69.41901756723442, 69.85699678629193, 70.2922470831599, 70.72481884034771, 71.15476090888086, 71.58212067269312, 72.00694410957877, 72.42927584892728, 72.84915922644544, 73.2666363360568, 73.68174807915457, 74.09453421137081, 74.50503338701353, 74.91328320131217, 75.31932023060219, 75.72318007057021, 76.12489737267302, 76.52450587883597, 76.92203845452876, 77.31752712031083, 77.71100308193171, 78.10249675906655, 78.49203781276162], [0.0, 7.874007874011811, 11.135528725660043, 13.638181696985857, 15.748015748023622, 17.60681686165901, 19.28730152198591, 20.83266665599966, 22.271057451320086, 23.62202362203543, 24.899799195977465, 26.115129714401192, 27.276363393971714, 28.390139133156783, 29.46183972531247, 30.49590136395381, 31.496031496047245, 32.46536616149585, 33.406586176980134, 34.32200460346103, 35.21363372331802, 36.08323710533743, 36.932370625238775, 37.76241517699841, 38.57460304397182, 39.370039370059054, 40.149719799769464, 40.914545090957574, 41.66533331199932, 42.402830094228385, 43.12771730569564, 43.840620433565945, 44.54211490264017, 45.23273151159457, 45.91296113299598, 46.58325879540846, 47.24404724407086, 47.89572005931219, 48.538644398046394, 49.17316341257699, 49.79959839195493, 50.41825066382212, 51.0294032886923, 51.63332257370234, 52.230259428802384, 52.82045058497702, 53.40411969127475, 53.98147830506312, 54.55272678794343, 55.11805511808267, 55.67764362830022, 56.231663678038196, 56.780278266313566, 57.323642591866054, 57.86190456595774, 58.39520528262573, 58.92367945062494, 59.447455790807396, 59.9666574022598, 60.48140210014976, 60.99180272790762, 61.49796744608719, 62.0, 62.49799996799897, 62.99206299209449, 63.48228099241551, 63.968742366877905, 64.45153217728807, 64.9307323229917, 65.40642170307133, 65.87867636800242, 66.34756966159348, 66.81317235396027, 67.27555276621663, 67.7347768875044, 68.19090848492928, 68.64400920692206, 69.09413868049879, 69.54135460285484, 69.98571282769076, 70.42726744663604, 70.8660708661063, 71.30217387990355, 71.7356257378438, 72.16647421067486, 72.59476565152615, 73.02054505411473, 73.44385610791416, 73.86474125047755, 74.28324171709255, 74.6993975879324, 75.11324783285569, 75.52483035399682, 75.93418202627852, 76.34133873596926, 76.74633541739956, 77.14920608794364, 77.5499838813652, 77.9487010796203, 78.34538914320358, 78.74007874011811, 79.13279977354523], [0.0, 7.937253933193772, 11.224972160321824, 13.747727084867522, 15.874507866387544, 17.74823934929885, 19.44222209522358, 21.0, 22.44994432064365, 23.811761799581316, 25.099800796022265, 26.32489316217637, 27.495454169735044, 28.618176042508374, 29.698484809834998, 30.740852297878796, 31.74901573277509, 32.72613634390714, 33.67491648096547, 34.59768778401239, 35.4964786985977, 36.373066958946424, 37.22902093797257, 38.06573262134856, 38.88444419044716, 39.686269665968865, 40.47221268969613, 41.24318125460257, 42.0, 42.74342054632503, 43.474130238568314, 44.19275958796871, 44.8998886412873, 45.596052460712, 46.281745861624536, 46.95742752749559, 47.62352359916263, 48.28043081829325, 48.928519290900276, 49.568134925574924, 50.19960159204453, 50.82322303829225, 51.43928459844675, 52.04805471869241, 52.64978632435274, 53.24471804789654, 53.83307533477908, 54.415071441651165, 54.99090833947009, 55.560777532356404, 56.124860801609124, 56.68333088307356, 57.23635208501675, 57.78408085277467, 58.32666628567075, 58.864250611045755, 59.396969619669996, 59.92495306631454, 60.44832503882966, 60.96720429870472, 61.48170459575759, 61.99193495931547, 62.49799996799898, 63.0, 63.49803146555018, 63.99218702310463, 64.48255578061404, 64.96922348312314, 65.45227268781429, 65.93178292750774, 66.40783086353596, 66.88049042882386, 67.34983296193094, 67.8159273327439, 68.27884006044624, 68.7386354243376, 69.19537556802479, 69.6491205974634, 70.09992867328755, 70.54785609782908, 70.9929573971954, 71.43528539874394, 71.87489130426565, 72.3118247591637, 72.74613391789285, 73.1778655059028, 73.60706487831179, 74.0337760755184, 74.45804187594514, 74.8799038460921, 75.2994023880668, 75.71657678474378, 76.13146524269712, 76.54410493303844, 76.95453203028397, 77.36278174936575, 77.76888838089432, 78.17288532477231, 78.57480512225277, 78.9746794865291, 79.37253933193773, 79.76841480184999], [0.0, 8.0, 11.313708498984761, 13.856406460551021, 16.0, 17.88854381999832, 19.595917942265427, 21.166010488516726, 22.627416997969522, 24.0, 25.298221281347036, 26.532998322843206, 27.712812921102042, 28.844410203711917, 29.93325909419153, 30.983866769659336, 32.0, 32.984845004941285, 33.941125496954285, 34.87119154832539, 35.77708763999664, 36.660605559646726, 37.52332607858744, 38.36665218650176, 39.19183588453085, 40.00000000000001, 40.79215610874228, 41.56921938165306, 42.33202097703345, 43.08131845707604, 43.81780460041328, 44.54211490264018, 45.254833995939045, 45.956501172304236, 46.647615158762406, 47.32863826479693, 48.0, 48.66210024238576, 49.315312023751815, 49.959983987187194, 50.59644256269407, 51.22499389946279, 51.84592558726289, 52.459508194416, 53.06599664568641, 53.66563145999495, 54.258639865002145, 54.84523680320836, 55.425625842204084, 56.0, 56.568542494923804, 57.13142742834281, 57.68882040742383, 58.24087911424415, 58.78775382679628, 59.32958789676531, 59.86651818838306, 60.398675482166006, 60.92618484691127, 61.44916598294886, 61.96773353931867, 62.48199740725323, 62.99206299209449, 63.49803146555017, 64.0, 64.4980619863884, 64.99230723708769, 65.4828221749796, 65.96969000988257, 66.4529909033446, 66.93280212272605, 67.40919818541087, 67.88225099390857, 68.35202996254026, 68.81860213634101, 69.2820323027551, 69.74238309665078, 70.19971509913698, 70.65408693062278, 71.10555533852471, 71.55417527999327, 72.0, 72.44308110509934, 72.8834686331544, 73.32121111929345, 73.7563556583431, 74.18894796396563, 74.61903242471053, 75.04665215717488, 75.47184905645283, 75.8946638440411, 76.31513611335565, 76.73330437300352, 77.14920608794364, 77.56287771866127, 77.9743547584717, 78.3836717690617, 78.79086241436885, 79.19595949289332, 79.5989949685296, 80.00000000000001, 80.39900496896713], [0.0, 8.06225774829855, 11.40175425099138, 13.964240043768942, 16.1245154965971, 18.027756377319946, 19.748417658131498, 21.330729007701542, 22.80350850198276, 24.186773244895647, 25.495097567963924, 26.739483914241877, 27.928480087537885, 29.068883707497267, 30.16620625799671, 31.22498999199199, 32.2490309931942, 33.241540277189316, 34.205262752974136, 35.14256678161116, 36.05551275463989, 36.945906403822335, 37.815340802378074, 38.66522985836241, 39.496835316262995, 40.311288741492746, 41.10960958218894, 41.89272013130683, 42.661458015403085, 43.41658669218482, 44.158804331639224, 44.888751374926876, 45.60701700396552, 46.31414470763765, 47.01063709417263, 47.69696007084728, 48.373546489791295, 49.040799340956916, 49.69909455915671, 50.34878350069642, 50.99019513592785, 51.62363799656122, 52.24940191045253, 52.867759551545205, 53.47896782848375, 54.08326913195983, 54.68089245796926, 55.27205442174191, 55.85696017507577, 56.435804238089844, 57.0087712549569, 57.57603668193913, 58.137767414994535, 58.69412236331676, 59.2452529743945, 59.79130371550699, 60.33241251599342, 60.868711174132805, 61.400325732035, 61.92737682156414, 62.44997998398398, 62.968245965724655, 63.48228099241551, 63.99218702310462, 64.4980619863884, 65.0, 65.49809157525125, 65.99242380758567, 66.48308055437863, 66.97014260101288, 67.4536878161602, 67.93379129711516, 68.41052550594827, 68.88396039717809, 69.3541635375988, 69.82120021884471, 70.28513356322232, 70.74602462329597, 71.20393247567159, 71.65891430938652, 72.11102550927978, 72.56031973468694, 73.00684899377592, 73.4506637138154, 73.89181280764467, 74.33034373659252, 74.76630257007497, 75.1997340420829, 75.63068160475615, 76.05918747922567, 76.48529270389177, 76.909037180295, 77.33045971672482, 77.74959806970065, 78.16648898345122, 78.58116822750854, 78.99367063252599, 79.40403012442127, 79.81227975693966, 80.21845174272562, 80.62257748298549, 81.02468759581859], [0.0, 8.12403840463596, 11.489125293076057, 14.07124727947029, 16.24807680927192, 18.16590212458495, 19.8997487421324, 21.494185260204677, 22.978250586152114, 24.372115213907882, 25.69046515733026, 26.944387170614963, 28.14249455894058, 29.291637031753623, 30.397368307141328, 31.464265445104544, 32.49615361854384, 33.49626844888845, 34.46737587922817, 35.41186241925155, 36.3318042491699, 37.22902093797257, 38.1051177665153, 38.961519477556315, 39.7994974842648, 40.620192023179804, 41.42463035441597, 42.213741838410876, 42.988370520409354, 43.74928570845472, 44.49719092257397, 45.232731511594565, 45.95650117230423, 46.669047558312144, 47.37087712930804, 48.062459362791664, 48.744230427815765, 49.41659640242335, 50.07993610219566, 50.7346035758633, 51.38093031466052, 52.01922721455981, 52.64978632435274, 53.272882407468806, 53.888774341229926, 54.497706373754845, 55.09990925582364, 55.695601262577284, 56.28498911788116, 56.86826883245172, 57.445626465380286, 58.017238817441154, 58.58327406350725, 59.14389233048499, 59.6992462263972, 60.249481325568276, 60.794736614282655, 61.33514490078262, 61.87083319303208, 62.40192304729077, 62.92853089020909, 63.45076831686122, 63.968742366877905, 64.48255578061402, 64.99230723708769, 65.49809157525127, 66.0, 66.4981202741852, 66.9925368977769, 67.48333127521195, 67.97058187186572, 68.45436436049933, 68.93475175845634, 69.4118145563131, 69.88562083862459, 70.35623639735145, 70.8237248385031, 71.28814768248647, 71.74956445860839, 72.20803279414278, 72.6636084983398, 73.11634564172364, 73.5662966309981, 74.01351227985333, 74.45804187594514, 74.89993324429602, 75.33923280734945, 75.77598564189054, 76.2102355330306, 76.64202502543888, 77.07139547199077, 77.49838707999025, 77.92303895511263, 78.34538914320358, 78.76547467006087, 79.1833315793166, 79.5989949685296, 80.01249902359007, 80.4238770515324, 80.83316151184488, 81.24038404635961, 81.64557550780079], [0.0, 8.18535277187245, 11.575836902790225, 14.177446878757827, 16.3707055437449, 18.303005217723125, 20.049937655763422, 21.656407827707714, 23.15167380558045, 24.55605831561735, 25.88435821108957, 27.147743920996458, 28.354893757515654, 29.512709126747414, 30.62678566222711, 31.701734968294716, 32.7414110874898, 33.749074061372404, 34.72751070837068, 35.67912554982255, 36.60601043544625, 37.5099986670221, 38.39270764090493, 39.25557285278104, 40.099875311526844, 40.926763859362254, 41.73727350941842, 42.53234063627348, 43.31281565541543, 44.079473681068386, 44.83302354291978, 45.574115460423364, 46.3033476111609, 47.021271782034994, 47.72839825512689, 48.425200051213004, 49.1121166312347, 49.78955713801842, 50.45790324617146, 51.11751167652824, 51.76871642217914, 52.41183072551463, 53.047148839499386, 53.67494760127857, 54.295487841992916, 54.90901565316937, 55.51576352712804, 56.1159513863928, 56.70978751503131, 57.297469403107144, 57.87918451395113, 58.45511098270194, 59.02541825349483, 59.59026766175833, 60.149812967290266, 60.70420084310476, 61.25357132445422, 61.79805822192151, 62.3377895020348, 62.87288763847259, 63.40346993658943, 63.92964883369843, 64.45153217728807, 64.96922348312314, 65.4828221749796, 65.99242380758567, 66.4981202741852, 67.0, 67.49814812274481, 67.99264666123831, 68.48357467305573, 68.97100840208152, 69.45502141674136, 69.93568473962344, 70.41306696913577, 70.88723439378913, 71.3582510996451, 71.82617907142215, 72.29107828771127, 72.75300681071539, 73.2120208708925, 73.66817494685205, 74.12152184082571, 74.57211275000863, 75.0199973340442, 75.46522377890362, 75.90783885739337, 76.34788798650557, 76.78541528180986, 77.22046360907191, 77.6530746332687, 78.08328886515987, 78.51114570556209, 78.93668348746354, 79.359939516106, 79.78095010715276, 80.19975062305369, 80.61637550770935, 81.03085831953157, 81.44323176298937, 81.85352771872451, 82.26177727231524], [0.0, 8.246211251235321, 11.661903789690601, 14.282856857085703, 16.492422502470642, 18.439088914585774, 20.19900987672416, 21.817424229271428, 23.323807579381203, 24.738633753705965, 26.076809620810593, 27.34958866235469, 28.565713714171405, 29.732137494637016, 30.854497241083024, 31.937438845342623, 32.984845004941285, 34.0, 34.98571136907181, 35.944401511222864, 36.87817782917155, 37.78888725538237, 38.67815921162743, 39.54743986657038, 40.39801975344832, 41.23105625617661, 42.047592083257285, 42.848570571257106, 43.634848458542855, 44.40720662234904, 45.16635916254486, 45.91296113299599, 46.647615158762406, 47.370877129308056, 48.08326112068523, 48.78524367060187, 49.47726750741193, 50.15974481593781, 50.833060108555344, 51.49757275833494, 52.153619241621186, 52.80151512977634, 53.44155686354956, 54.0740233383831, 54.69917732470938, 55.317266743757315, 55.928525816438245, 56.53317610041028, 57.13142742834281, 57.723478758647246, 58.30951894845301, 58.889727457341834, 59.46427498927403, 60.033324079214545, 60.59702963017247, 61.155539405682624, 61.70899448216605, 62.25752966509353, 62.80127387243033, 63.34035048845246, 63.874877690685246, 64.40496875241847, 64.9307323229917, 65.45227268781429, 65.96969000988257, 66.48308055437865, 66.9925368977769, 67.49814812274482, 68.0, 68.49817515817485, 68.99275324264136, 69.48381106416085, 69.97142273814362, 70.45565981523414, 70.9365914038728, 71.41428428542851, 71.88880302244573, 72.36021006050217, 72.82856582413251, 73.29392880723478, 73.7563556583431, 74.21590126111789, 74.67261881037788, 75.1265598839718, 75.57777451076474, 76.02631123499285, 76.47221717722064, 76.91553809211764, 77.35631842325486, 77.79460135510689, 78.23042886243178, 78.66384175718855, 79.09487973314076, 79.52358140828417, 79.94998436522674, 80.37412518964047, 80.79603950689663, 81.21576201698781, 81.63332652783421, 82.04876598706406, 82.46211251235322, 82.87339742040265], [0.0, 8.306623862918075, 11.747340124470732, 14.387494569938161, 16.61324772583615, 18.57417562100671, 20.346989949375807, 21.97726097583591, 23.494680248941464, 24.919871588754226, 26.267851073127396, 27.549954627911827, 28.774989139876322, 29.949958263743877, 31.080540535840107, 32.17141588429082, 33.2264954516723, 34.249087579087416, 35.242020373412196, 36.20773398046335, 37.14835124201342, 38.065732621348566, 38.961519477556315, 39.83716857408418, 40.693979898751614, 41.53311931459038, 42.35563716909475, 43.16248370981449, 43.95452195167182, 44.73253849269009, 45.4972526643093, 46.24932431938871, 46.98936049788293, 47.71792116176061, 48.43552415324934, 49.142649501222465, 49.83974317750845, 50.52722038663913, 51.205468457968436, 51.874849397371754, 52.53570214625479, 53.18834458788881, 53.83307533477909, 54.47017532558529, 55.099909255823654, 55.72252686302012, 56.3382640840131, 56.9473440996154, 57.549978279752644, 58.146367040426526, 58.73670062235366, 59.32115979985557, 59.899916527487754, 60.47313453096343, 61.040969848127425, 61.60357132504576, 62.161081071680215, 62.713634881100624, 63.26136261573885, 63.80438856379708, 64.34283176858165, 64.87680633323437, 65.40642170307133, 65.93178292750773, 66.4529909033446, 66.97014260101288, 67.48333127521195, 67.99264666123831, 68.49817515817483, 69.0, 69.49820141557622, 69.99285677838847, 70.48404074682439, 70.97182539571601, 71.45628033979938, 71.93747284969079, 72.4154679609267, 72.89032857656768, 73.36211556382491, 73.83088784512888, 74.29670248402684, 74.75961476626267, 75.21967827636597, 75.67694497005016, 76.13146524269713, 76.58328799418317, 77.03246069028303, 77.47902942086975, 77.92303895511263, 78.36453279386025, 78.80355321938218, 79.24014134263012, 79.67433714816836, 80.10617953691214, 80.53570636680355, 80.96295449154508, 81.38795979750323, 81.81075723888638, 82.23138087129512, 82.64986388373548, 83.06623862918076, 83.4805366537614], [0.0, 8.366600265340756, 11.832159566199234, 14.491376746189442, 16.73320053068151, 18.708286933869708, 20.4939015319192, 22.135943621178658, 23.664319132398468, 25.09980079602227, 26.457513110645905, 27.748873851023223, 28.982753492378883, 30.166206257996716, 31.304951684997057, 32.403703492039305, 33.46640106136302, 34.49637662132068, 35.4964786985977, 36.46916505762094, 37.416573867739416, 38.340579025361635, 39.24283374069717, 40.12480529547776, 40.9878030638384, 41.83300132670378, 42.66145801540309, 43.47413023856833, 44.271887242357316, 45.055521304275246, 45.8257569495584, 46.58325879540847, 47.328638264796936, 48.06245936279167, 48.78524367060187, 49.49747468305833, 50.19960159204454, 50.8920425999979, 51.575187832910515, 52.249401910452534, 52.91502622129181, 53.5723809439155, 54.22176684690385, 54.86346689738081, 55.497747702046446, 56.12486080160912, 56.74504383644443, 57.35852159879995, 57.965506984757766, 58.56620185738529, 59.16079783099617, 59.74947698515863, 60.33241251599343, 60.90976933136425, 61.4817045957576, 62.04836822995429, 62.609903369994115, 63.16644678941503, 63.71812928829597, 64.26507605223851, 64.80740698407861, 65.34523701081817, 65.87867636800242, 66.40783086353596, 66.93280212272605, 67.45368781616021, 67.97058187186572, 68.48357467305573, 68.99275324264136, 69.49820141557622, 70.0, 70.49822692805827, 70.9929573971954, 71.48426400264607, 71.97221686178632, 72.4568837309472, 72.93833011524188, 73.41661937191061, 73.89181280764467, 74.36396977031283, 74.83314773547883, 75.29940238806681, 75.76278769950326, 76.22335600063802, 76.68115805072327, 77.13624310270757, 77.5886589650833, 78.0384520605067, 78.48566748139434, 78.93034904268445, 79.37253933193772, 79.81227975693966, 80.24961059095553, 80.68457101577724, 81.117199162693, 81.54753215150045, 81.9756061276768, 82.40145629781067, 82.82511696339463, 83.24662155306966, 83.66600265340756, 84.08329203831164], [0.0, 8.426149773176359, 11.916375287812986, 14.594519519326427, 16.852299546352718, 18.841443681416774, 20.639767440550294, 22.293496809607955, 23.832750575625973, 25.278449319529077, 26.645825188948457, 27.946377224964245, 29.189039038652854, 30.380915061926625, 31.52776554086889, 32.63433774416144, 33.704599092705436, 34.741905532080416, 35.749125863438955, 36.72873534441392, 37.68288736283355, 38.61346915261565, 39.52214569073901, 40.4103947023535, 41.27953488110059, 42.1307488658818, 42.96510211788168, 43.783558557979276, 44.58699361921591, 45.376205218153714, 46.1519230368573, 46.9148164229596, 47.665501151251945, 48.4045452411238, 49.13247398615299, 49.849774322458074, 50.556898639058154, 51.254268114958, 51.942275652882216, 52.621288467691485, 53.291650377896914, 53.95368384086484, 54.60769176590419, 55.253959134165214, 55.89275444992849, 56.52433104425031, 57.14892824891819, 57.76677245614472, 58.37807807730571, 58.98304841223451, 59.58187643906493, 60.17474553332154, 60.76183012385325, 61.343296292260014, 61.91930232165089, 62.48999919987198, 63.05553108173778, 63.6160357142757, 64.17164482853778, 64.72248450113761, 65.26867548832288, 65.81033353509159, 66.34756966159348, 66.88049042882386, 67.40919818541087, 67.93379129711516, 68.45436436049933, 68.97100840208152, 69.48381106416083, 69.99285677838847, 70.49822692805827, 71.0, 71.49825172687791, 71.99305522062528, 72.48448109768049, 72.97259759663213, 73.45747068882784, 73.93916418245476, 74.41773982055624, 74.89325737341113, 75.3657747256671, 75.83534795858723, 76.30203142774117, 76.76587783644501, 77.2269383052313, 77.68526243760782, 78.1408983823452, 78.59389289251425, 79.04429138147802, 79.49213797602879, 79.93747556684536, 80.38034585643433, 80.820789404707, 81.25884567233281, 81.69455306200041, 82.12794895770865, 82.55906976220118, 82.98795093265046, 83.4146270146909, 83.83913167489273, 84.2614977317636, 84.6817571853584], [0.0, 8.485281374238571, 12.0, 14.69693845669907, 16.970562748477143, 18.973665961010276, 20.784609690826528, 22.44994432064365, 24.0, 25.45584412271571, 26.832815729997478, 28.142494558940584, 29.39387691339814, 30.594117081556714, 31.74901573277509, 32.863353450309965, 33.941125496954285, 34.9857113690718, 36.0, 36.986484017813865, 37.94733192202055, 38.88444419044716, 39.7994974842648, 40.69397989875161, 41.569219381653056, 42.42640687119285, 43.26661530556788, 44.09081537009721, 44.8998886412873, 45.69463863518345, 46.475800154489, 47.24404724407087, 48.0, 48.74423042781577, 49.47726750741192, 50.19960159204454, 50.91168824543142, 51.61395160225577, 52.30678732248809, 52.990565197967086, 53.665631459994955, 54.332310828824504, 54.99090833947009, 55.641710972974224, 56.28498911788117, 56.92099788303082, 57.54997827975263, 58.17215828899595, 58.78775382679628, 59.39696961966999, 60.00000000000001, 60.59702963017248, 61.18823416311343, 61.77378084592201, 62.35382907247959, 62.928530890209096, 63.49803146555018, 64.06246951218787, 64.62197768561406, 65.17668294720129, 65.72670690061993, 66.27216610312357, 66.81317235396027, 67.34983296193094, 67.88225099390857, 68.41052550594829, 68.93475175845634, 69.45502141674136, 69.9714227381436, 70.48404074682439, 70.9929573971954, 71.49825172687791, 72.0, 72.49827584156743, 72.99315036357864, 73.48469228349535, 73.97296803562773, 74.45804187594514, 74.93997598078079, 75.41883053985921, 75.8946638440411, 76.36753236814714, 76.8374908491942, 77.30459236035075, 77.76888838089432, 78.23042886243178, 78.689262291624, 79.14543574963753, 79.5989949685296, 80.04998438475799, 80.49844718999243, 80.94442537939226, 81.38795979750321, 81.82909018191513, 82.26785520481253, 82.70429251254133, 83.13843876330611, 83.57032966310473, 84.0, 84.42748367682174, 84.8528137423857, 85.27602242131138], [0.0, 8.544003745317532, 12.083045973594572, 14.798648586948744, 17.088007490635064, 19.104973174542803, 20.928449536456352, 22.605309110914632, 24.166091947189145, 25.632011235952593, 27.018512172212592, 28.33725463060951, 29.597297173897488, 30.80584360149873, 31.96873472629156, 33.090784215548595, 34.17601498127013, 35.22782990761707, 36.24913792078372, 37.24244889907215, 38.209946349085605, 39.15354390090379, 40.07492981902776, 40.97560249709576, 41.856899072912704, 42.72001872658766, 43.56604182158394, 44.39594576084623, 45.210618221829264, 46.010868281309364, 46.797435827190355, 47.57099956906519, 48.33218389437829, 49.081564767232116, 49.8196748283246, 50.54700782440045, 51.264022471905186, 51.97114584074514, 52.66877632905477, 53.35728628781641, 54.037024344425184, 54.708317466359716, 55.37147279962852, 56.026779311325754, 56.67450926121902, 57.31491952362839, 57.94825277780168, 58.57473858242989, 59.194594347794975, 59.80802621722272, 60.41522986797286, 61.01639124038721, 61.61168720299746, 62.201286160335954, 62.78534860936906, 63.36402764976356, 63.93746945258312, 64.50581369148055, 65.06919393998976, 65.62773803811922, 66.18156843109719, 66.73080248281148, 67.27555276621665, 67.81592733274388, 68.35202996254026, 68.8839603971781, 69.4118145563131, 69.93568473962345, 70.45565981523414, 70.97182539571601, 71.48426400264606, 71.99305522062528, 72.49827584156743, 73.0, 73.49829930005183, 73.99324293474372, 74.4848977981443, 74.97332859090625, 75.45859791965394, 75.94076639065477, 76.41989269817121, 76.89603370785778, 77.36924453553881, 77.83957862167549, 78.30708780180758, 78.77182237323191, 79.23383115816122, 79.69316156358713, 80.14985963805552, 80.60397012554654, 81.05553651663777, 81.50460109711598, 81.95120499419151, 82.39538822045807, 82.83718971573094, 83.27664738688752, 83.71379814582541, 84.14867794564572, 84.58132181516201, 85.01176389182852, 85.44003745317532, 85.86617494683225], [0.0, 8.602325267042627, 12.165525060596439, 14.899664425751341, 17.204650534085253, 19.235384061671343, 21.071307505705477, 22.759613353482084, 24.331050121192877, 25.80697580112788, 27.202941017470884, 28.530685235374214, 29.799328851502683, 31.016124838541646, 32.18695387886216, 33.31666249791536, 34.40930106817051, 35.46829570193639, 36.49657518178932, 37.49666651850535, 38.47076812334269, 39.42080668885405, 40.348482003664024, 41.255302689472536, 42.14261501141095, 43.01162633521314, 43.863424398922625, 44.698993277254026, 45.51922670696417, 46.32493928760188, 47.116875957558975, 47.89572005931219, 48.662100242385755, 49.41659640242335, 50.159744815937806, 50.89204259999789, 51.61395160225576, 52.32590180780452, 53.02829433425141, 53.721504074253176, 54.40588203494177, 55.08175741568164, 55.74943945906542, 56.40921910468181, 57.06137047074843, 57.70615218501403, 58.34380858325928, 58.974570791146924, 59.598657703005365, 60.21627686929838, 60.8276253029822, 61.432890213630685, 62.03224967708329, 62.625873247404705, 63.21392251711644, 63.796551630946325, 64.37390775772433, 64.94613152451807, 65.5133574166368, 66.07571414672715, 66.63332499583072, 67.18630812896329, 67.7347768875044, 68.27884006044624, 68.81860213634101, 69.35416353759881, 69.88562083862459, 70.41306696913577, 70.93659140387278, 71.45628033979939, 71.97221686178632, 72.48448109768049, 72.99315036357864, 73.49829930005183, 73.99999999999999, 74.4983221287567, 74.9933330370107, 75.48509786706248, 75.97367965289033, 76.4591394144611, 76.94153624668537, 77.42092740338364, 77.89736837660179, 78.37091297158659, 78.8416133777081, 79.3095202355934, 79.77468270071651, 80.23714850367004, 80.69696400732805, 81.15417426109391, 81.60882305241266, 82.06095295571457, 82.51060537894507, 82.95782060782454, 83.40263784797217, 83.84509526501832, 84.2852300228219, 84.72307831990054, 85.15867542417507, 85.59205570612264, 86.02325267042627, 86.45229898620394], [0.0, 8.660254037844387, 12.247448713915892, 15.000000000000004, 17.320508075688775, 19.364916731037084, 21.213203435596427, 22.912878474779202, 24.494897427831784, 25.98076211353316, 27.386127875258307, 28.722813232690147, 30.000000000000007, 31.224989991991993, 32.403703492039305, 33.54101966249684, 34.64101615137755, 35.70714214271425, 36.742346141747674, 37.74917217635375, 38.72983346207417, 39.686269665968865, 40.620192023179804, 41.53311931459037, 42.42640687119285, 43.30127018922194, 44.15880433163924, 45.00000000000001, 45.825756949558404, 46.63689526544408, 47.43416490252569, 48.218253804964775, 48.98979485566357, 49.749371855331006, 50.49752469181039, 51.234753829797995, 51.96152422706632, 52.6782687642637, 53.38539126015656, 54.083269131959845, 54.772255750516614, 55.452682532047085, 56.12486080160913, 56.789083458002736, 57.44562646538029, 58.094750193111246, 58.73670062235365, 59.37171043518959, 60.000000000000014, 60.6217782649107, 61.237243569579455, 61.846584384264915, 62.44997998398399, 63.04760106459246, 63.63961030678929, 64.22616289332565, 64.80740698407861, 65.3834841531101, 65.95452979136459, 66.52067347825034, 67.08203932499369, 67.63874629234341, 68.19090848492928, 68.7386354243376, 69.2820323027551, 69.82120021884471, 70.35623639735145, 70.88723439378913, 71.4142842854285, 71.93747284969079, 72.4568837309472, 72.97259759663213, 73.48469228349535, 73.9932429347437, 74.4983221287567, 75.0, 75.4983443527075, 75.99342076785332, 76.48529270389179, 76.97402159170326, 77.45966692414834, 77.94228634059948, 78.42193570679062, 78.8986691902975, 79.37253933193773, 79.84359711335657, 80.31189202104505, 80.77747210701757, 81.24038404635961, 81.70067319184095, 82.15838362577492, 82.61355820929153, 83.06623862918075, 83.51646544245033, 83.96427811873333, 84.40971508067065, 84.8528137423857, 85.29361054615991, 85.73214099741124, 86.16843969807043, 86.60254037844388, 87.03447592764606], [0.0, 8.717797887081348, 12.328828005937956, 15.099668870541503, 17.435595774162696, 19.49358868961793, 21.354156504062626, 23.065125189341593, 24.65765601187591, 26.153393661244046, 27.568097504180447, 28.91366458960193, 30.199337741083006, 31.43246729100343, 32.619012860600186, 33.76388603226827, 34.87119154832539, 35.94440151122286, 36.986484017813865, 38.00000000000001, 38.98717737923586, 39.94996871087636, 40.89009660052175, 41.80908992073375, 42.70831300812525, 43.588989435406745, 44.45222154178575, 45.29900661162451, 46.130250378683186, 46.94677837722202, 47.74934554525329, 48.538644398046394, 49.31531202375182, 50.079936102195674, 50.833060108555344, 51.575187832910515, 52.30678732248809, 53.02829433425142, 53.74011537017763, 54.44263035526481, 55.13619500836089, 55.82114294781146, 56.497787567302154, 57.166423711825814, 57.82732917920386, 58.48076606885378, 59.126981996377936, 59.76621118993575, 60.39867548216601, 61.02458520956944, 61.64414002968977, 62.257529665093536, 62.86493458200686, 63.46652661048974, 64.06246951218787, 64.65291950097847, 65.23802572120037, 65.81793068761735, 66.39277069079134, 66.96267617113283, 67.52777206453653, 68.08817812219681, 68.64400920692206, 69.19537556802477, 69.74238309665078, 70.28513356322232, 70.8237248385031, 71.3582510996451, 71.88880302244571, 72.4154679609267, 72.93833011524188, 73.45747068882784, 73.97296803562773, 74.4848977981443, 74.9933330370107, 75.4983443527075, 76.00000000000001, 76.49836599562111, 76.99350621968064, 77.48548251124208, 77.97435475847172, 78.46018098373213, 78.94301742396222, 79.42291860665914, 79.89993742175272, 80.37412518964048, 80.84553172563095, 81.31420540102451, 81.7801932010435, 82.24354077980836, 82.70429251254134, 83.16249154516717, 83.6181798414675, 84.07139822793482, 84.52218643646178, 84.970583144992, 85.4166260162505, 85.86035173466274, 86.30179604156568, 86.74099376880578, 87.17797887081349, 87.61278445523806], [0.0, 8.774964387392123, 12.409673645990857, 15.198684153570667, 17.549928774784245, 19.621416870348586, 21.494185260204677, 23.2163735324878, 24.819347291981714, 26.324893162176366, 27.748873851023216, 29.103264421710502, 30.397368307141335, 31.638584039112754, 32.83291031876401, 33.98529093593286, 35.09985754956849, 36.180105030251084, 37.22902093797257, 38.24918299781056, 39.24283374069717, 40.21193852576621, 41.15823125451336, 42.08325082500163, 42.988370520409354, 43.874821936960615, 44.743714642394195, 45.596052460712, 46.4327470649756, 47.254629402842646, 48.06245936279166, 48.85693400122443, 49.63869458396343, 50.40833264451425, 51.16639522186413, 51.91338940966965, 52.64978632435273, 53.37602458033008, 54.09251334519409, 54.799635035281035, 55.49774770204643, 56.18718715152059, 56.86826883245173, 57.5412895232632, 58.206528843421005, 58.86425061104575, 59.51470406546604, 60.158124970780136, 60.79473661428267, 61.424750711744856, 62.048368229954285, 62.6657801355732, 63.27716807822551, 63.88270501473776, 64.48255578061404, 65.07687761409578, 65.66582063752801, 66.24952830020754, 66.82813778641449, 67.40178039191547, 67.97058187186572, 68.53466276272175, 69.0941386804988, 69.6491205974634, 70.19971509913698, 70.74602462329598, 71.28814768248647, 71.82617907142215, 72.36021006050217, 72.8903285765677, 73.41661937191061, 73.93916418245476, 74.45804187594514, 74.97332859090625, 75.48509786706248, 75.99342076785332, 76.49836599562111, 77.0, 77.49838707999027, 77.99358948016177, 78.48566748139434, 78.9746794865291, 79.46068210127574, 79.94373021069258, 80.42387705153241, 80.90117428072352, 81.37567204023571, 81.84741901856161, 82.31646250902672, 82.78284846512591, 83.24662155306964, 83.7078252017098, 84.16650165000326, 84.62269199216013, 85.07643622061282, 85.52777326693358, 85.97674104081871, 86.42337646724988, 86.867715521936, 87.3097932651315, 87.74964387392123, 88.1873006730561], [0.0, 8.831760866327848, 12.489995996796798, 15.297058540778359, 17.663521732655695, 19.7484176581315, 21.63330765278394, 23.36664289109585, 24.979991993593597, 26.495282598983543, 27.928480087537885, 29.291637031753627, 30.594117081556718, 31.843366656181324, 33.045423283716616, 34.20526275297414, 35.32704346531139, 36.41428291206625, 37.46998799039039, 38.49675310984033, 39.496835316263, 40.472212689696136, 41.42463035441596, 42.35563716909475, 43.26661530556788, 44.158804331639246, 45.03332099679082, 45.891175622335076, 46.7332857821917, 47.56048780237647, 48.3735464897913, 49.17316341257699, 49.959983987187194, 50.734603575863304, 51.49757275833494, 52.249401910452534, 52.990565197967086, 53.72150407425318, 54.44263035526481, 55.15432893255072, 55.85696017507577, 56.55086206239478, 57.236352085016755, 57.91372894228104, 58.583274063507254, 59.2452529743945, 59.899916527487754, 60.547502012882426, 61.188234163113435, 61.822326064294934, 62.449979983983994, 63.07138812488593, 63.68673331236265, 64.29618962271405, 64.89992295835182, 65.49809157525127, 66.09084656743323, 66.67833231267862, 67.26068688320096, 67.83804242458652, 68.41052550594829, 68.97825744392215, 69.54135460285485, 70.09992867328754, 70.65408693062278, 71.2039324756716, 71.7495644586084, 72.29107828771129, 72.8285658241325, 73.36211556382491, 73.89181280764467, 74.41773982055624, 74.93997598078079, 75.45859791965394, 75.97367965289033, 76.48529270389179, 76.99350621968065, 77.49838707999027, 78.00000000000001, 78.49840762716147, 78.993670632526, 79.48584779695064, 79.97499609252884, 80.46117075956577, 80.94442537939227, 81.42481194328914, 81.90238091777309, 82.3771813064759, 82.84926070883192, 83.3186653757728, 83.78544026261366, 84.2496290793022, 84.7112743381895, 85.17041739947035, 85.6270985144306, 86.08135686662938, 86.53323061113576, 86.98275691193055, 87.4299719775776, 87.87491109526087, 88.31760866327849, 88.75809822207776], [0.0, 8.88819441731559, 12.569805089976535, 15.394804318340656, 17.77638883463118, 19.87460691435179, 21.771541057077243, 23.515952032609697, 25.13961017995307, 26.66458325194677, 28.106938645110393, 29.478805945967355, 30.78960863668131, 32.046840717924134, 33.25657829663178, 34.42382895611701, 35.55277766926236, 36.64696440361739, 37.70941526992961, 38.74274125562104, 39.74921382870358, 40.73082370883261, 41.689327171351664, 42.626282971894234, 43.54308211415449, 44.44097208657795, 45.32107677449865, 46.18441295502197, 47.03190406521939, 47.86439177509728, 48.682645778552335, 49.48737212663449, 50.27922035990614, 51.05878964487898, 51.82663407939975, 52.58326730053963, 53.32916650389354, 54.06477596365309, 54.79051012721091, 55.506756345511675, 56.213877290220786, 56.91221310052878, 57.60208329565868, 58.283788483591216, 58.95761189193471, 59.62382074305537, 60.28266749240614, 60.9343909463285, 61.57921727336262, 62.21736092120912, 62.84902544988268, 63.47440429023341, 64.09368143584827, 64.70703207534712, 65.31462317123173, 65.916613990708, 66.51315659326356, 67.10439627923047, 67.6904720030818, 68.27151675479314, 68.84765791223403, 69.4190175672344, 69.98571282769078, 70.54785609782908, 71.10555533852472, 71.65891430938652, 72.2080327941428, 72.75300681071539, 73.29392880723478, 73.83088784512888, 74.36396977031283, 74.89325737341113, 75.41883053985921, 75.94076639065477, 76.4591394144611, 76.97402159170326, 77.48548251124208, 77.99358948016177, 78.49840762716147, 79.0, 79.49842765740716, 79.9937497558403, 80.48602363143556, 80.97530487747484, 81.46164741766522, 81.94510357550352, 82.42572413997951, 82.90355842785038, 83.37865434270333, 83.85105843100611, 84.32081593533118, 84.78797084492588, 85.25256594378847, 85.71464285639881, 86.1742420912421, 86.63140308225418, 87.08616422830897, 87.53856293085923, 87.98863562983576, 88.43641783790206, 88.8819441731559, 89.32524839036274], [0.0, 8.94427190999916, 12.649110640673518, 15.491933384829672, 17.88854381999832, 20.000000000000004, 21.90890230020665, 23.664319132398465, 25.298221281347036, 26.832815729997478, 28.284271247461902, 29.66479394838266, 30.983866769659343, 32.249030993194204, 33.46640106136302, 34.64101615137755, 35.77708763999664, 36.87817782917155, 37.94733192202056, 38.98717737923586, 40.00000000000001, 40.9878030638384, 41.95235392680606, 42.89522117905444, 43.8178046004133, 44.7213595499958, 45.60701700396553, 46.475800154489015, 47.32863826479693, 48.16637831516919, 48.98979485566356, 49.79959839195493, 50.59644256269407, 51.38093031466053, 52.15361924162119, 52.91502622129182, 53.665631459994955, 54.40588203494178, 55.13619500836089, 55.85696017507578, 56.568542494923804, 57.271284253105414, 57.965506984757766, 58.65151319446072, 59.32958789676532, 59.99999999999999, 60.663003552412405, 61.31883886702357, 61.96773353931869, 62.609903369994115, 63.24555320336759, 63.87487769068526, 64.49806198638841, 65.11528238439884, 65.72670690061994, 66.332495807108, 66.93280212272605, 67.52777206453653, 68.11754546370561, 68.70225614927067, 69.2820323027551, 69.85699678629193, 70.42726744663604, 70.9929573971954, 71.55417527999327, 72.11102550927978, 72.66360849833981, 73.21202087089252, 73.7563556583431, 74.29670248402685, 74.83314773547883, 75.3657747256671, 75.89466384404112, 76.41989269817121, 76.94153624668537, 77.45966692414835, 77.97435475847172, 78.48566748139434, 78.993670632526, 79.49842765740718, 80.00000000000001, 80.49844718999243, 80.99382692526636, 81.48619514985346, 81.9756061276768, 82.46211251235322, 82.94576541331088, 83.42661445845685, 83.90470785361212, 84.38009243891595, 84.8528137423857, 85.32291603080617, 85.79044235810888, 86.25543461139131, 86.71793355471522, 87.17797887081346, 87.6356092008266, 88.09086218218097, 88.54377448471463, 88.99438184514797, 89.4427190999916, 89.88882021697694], [0.0, 9.000000000000002, 12.727922061357857, 15.5884572681199, 18.000000000000004, 20.12461179749811, 22.045407685048605, 23.811761799581316, 25.455844122715714, 27.0, 28.460498941515414, 29.849623113198604, 31.1769145362398, 32.44996147917591, 33.67491648096547, 34.856850115866756, 36.00000000000001, 37.107950630558946, 38.18376618407357, 39.230090491866065, 40.24922359499622, 41.24318125460257, 42.21374183841087, 43.16248370981448, 44.09081537009721, 45.00000000000001, 45.89117562233507, 46.765371804359695, 47.62352359916263, 48.466483264210545, 49.295030175464944, 50.1098792654702, 50.91168824543143, 51.70106381884227, 52.478567053607705, 53.24471804789655, 54.0, 54.74486277268399, 55.4797260267208, 56.20498198558559, 56.92099788303083, 57.628118136895644, 58.326666285670754, 59.016946718718, 59.69924622639721, 60.373835392494314, 61.04096984812741, 61.700891403609404, 62.3538290724796, 63.0, 63.63961030678929, 64.27285585688566, 64.89992295835182, 65.52098900352468, 66.13622305514582, 66.74578638386097, 67.34983296193094, 67.94850991743675, 68.54195795277518, 69.13031173081747, 69.71370023173351, 70.2922470831599, 70.8660708661063, 71.43528539874394, 72.00000000000001, 72.56031973468696, 73.11634564172365, 73.66817494685205, 74.21590126111789, 74.75961476626269, 75.2994023880668, 75.83534795858723, 76.36753236814714, 76.89603370785778, 77.42092740338364, 77.94228634059948, 78.46018098373213, 78.9746794865291, 79.48584779695064, 79.99374975584031, 80.49844718999243, 81.0, 81.49846624323676, 81.99390221229869, 82.48636250920514, 82.975900115636, 83.46256645946133, 83.94641147779934, 84.42748367682174, 84.90583018850943, 85.38149682454625, 85.85452812752511, 86.32496741962896, 86.7928568489366, 87.25823743349393, 87.72114910328067, 88.18163074019442, 88.63972021616495, 89.095454429505, 89.54886933959581, 90.00000000000001, 90.44888059008802], [0.0, 9.055385138137417, 12.806248474865699, 15.684387141358126, 18.110770276274835, 20.24845673131659, 22.18107301281884, 23.95829710142188, 25.612496949731398, 27.166155414412252, 28.63564212655271, 30.03331483536242, 31.368774282716252, 32.649655434629025, 33.88214869219484, 35.07135583350037, 36.22154055254967, 37.33630940518894, 38.4187454245971, 39.47150871198111, 40.49691346263318, 41.496987842492864, 42.473521163190604, 43.428101501216936, 44.36214602563768, 45.276925690687094, 46.1735855224608, 47.05316142407438, 47.91659420284376, 48.764741360946445, 49.59838707054898, 50.41825066382213, 51.224993899462795, 52.01922721455983, 52.80151512977635, 53.572380943915505, 54.332310828824504, 55.08175741568166, 55.82114294781146, 56.550862062394785, 57.27128425310542, 57.9827560572969, 58.685603004484854, 59.3801313572141, 60.06662967072484, 60.74537019394976, 61.41661013113635, 62.08059278067503, 62.737548565432505, 63.38769596696192, 64.0312423743285, 64.66838485689898, 65.29931086925805, 65.92419889539805, 66.54321903845651, 67.15653356152328, 67.76429738438968, 68.36665854054885, 68.96375859826668, 69.55573304911681, 70.14271166700074, 70.7248188403477, 71.30217387990356, 71.87489130426565, 72.44308110509934, 73.00684899377593, 73.5662966309981, 74.12152184082571, 74.67261881037788, 75.21967827636597, 75.76278769950325, 76.30203142774117, 76.8374908491942, 77.36924453553881, 77.89736837660179, 78.42193570679062, 78.94301742396222, 79.46068210127574, 79.97499609252884, 80.48602363143556, 80.99382692526636, 81.49846624323676, 82.00000000000001, 82.49848483457137, 82.99397568498573, 83.48652585896721, 83.97618710086807, 84.46300965511472, 84.94704232638121, 85.42833253669417, 85.90692637965813, 86.38286867197687, 86.85620300243387, 87.3269717784832, 87.7952162705919, 88.26097665446491, 88.72429205127536, 89.18520056601321, 89.6437393240599, 90.09994450608725, 90.55385138137419, 91.00549433962766], [0.0, 9.1104335791443, 12.884098726725126, 15.779733838059503, 18.2208671582886, 20.371548787463365, 22.315913604421397, 24.1039415863879, 25.768197453450252, 27.331300737432898, 28.809720581775867, 30.21588985947626, 31.559467676119006, 32.848135411313685, 34.08812109811862, 35.284557528754696, 36.4417343165772, 37.56327994198589, 38.65229618017538, 39.71145930332956, 40.74309757492673, 41.74925149029621, 42.731721238442994, 43.69210454990695, 44.63182720884279, 45.552167895721496, 46.454278597347745, 47.339201514178505, 48.2078831727758, 49.06118628814432, 49.89989979949859, 50.724747411889595, 51.536394906900505, 52.33545643251811, 53.1224999411737, 53.898051912847464, 54.662601474865795, 55.41660400998965, 56.16048432839589, 56.894639466297704, 57.619441163551734, 58.33523806414095, 59.04235767650205, 59.74110812497538, 60.43177971895252, 61.114646362390076, 61.78996682310162, 62.457985878508765, 63.11893535223801, 63.77303505401009, 64.42049363362563, 65.06150935845248, 65.69627082262737, 66.32495759516172, 66.9477408132642, 67.56478372643548, 68.17624219623724, 68.78226515607058, 69.38299503480661, 69.97856814768362, 70.56911505750939, 71.15476090888086, 71.73562573784382, 72.3118247591637, 72.8834686331544, 73.45066371381542, 74.01351227985333, 74.57211275000863, 75.12655988397178, 75.67694497005016, 76.22335600063802, 76.76587783644501, 77.30459236035075, 77.83957862167549, 78.37091297158659, 78.8986691902975, 79.42291860665912, 79.94373021069256, 80.46117075956576, 80.97530487747484, 81.48619514985346, 81.99390221229869, 82.49848483457137, 83.0, 83.49850298059242, 83.99404740813482, 84.4866853415377, 84.9764673306675, 85.46344247688599, 85.94765849050222, 86.4291617453276, 86.90799733051038, 87.3842090998139, 87.85783971849068, 88.32893070789434, 88.79752248796133, 89.26365441768559, 89.72736483370055, 90.18869108707588, 90.64766957842876, 91.10433579144299, 91.55872432488343], [0.0, 9.165151389911681, 12.961481396815723, 15.874507866387548, 18.330302779823363, 20.4939015319192, 22.44994432064365, 24.248711305964285, 25.922962793631445, 27.49545416973504, 28.98275349237888, 30.397368307141335, 31.749015732775096, 33.045423283716616, 34.292856398964496, 35.4964786985977, 36.660605559646726, 37.78888725538237, 38.88444419044716, 39.94996871087636, 40.9878030638384, 42.00000000000001, 42.988370520409354, 43.95452195167182, 44.8998886412873, 45.825756949558404, 46.7332857821917, 47.62352359916264, 48.49742261192857, 49.355850717012274, 50.19960159204453, 51.0294032886923, 51.84592558726289, 52.649786324352746, 53.44155686354955, 54.22176684690384, 54.99090833947008, 55.74943945906543, 56.49778756730215, 57.23635208501675, 57.96550698475776, 58.68560300448484, 59.39696961967, 60.09991680526688, 60.79473661428267, 61.481704595757584, 62.161081071680215, 62.83311228962004, 63.49803146555019, 64.15605972938177, 64.80740698407861, 65.4522726878143, 66.09084656743323, 66.72330927044912, 67.34983296193096, 67.97058187186572, 68.58571279792899, 69.19537556802479, 69.7997134664606, 70.39886362719217, 70.9929573971954, 71.58212067269312, 72.16647421067486, 72.74613391789285, 73.32121111929345, 73.89181280764467, 74.45804187594514, 75.01999733404422, 75.57777451076474, 76.13146524269713, 76.68115805072325, 77.2269383052313, 77.76888838089432, 78.30708780180757, 78.84161337770809, 79.37253933193773, 79.89993742175272, 80.4238770515324, 80.94442537939226, 81.4616474176652, 81.9756061276768, 82.48636250920512, 82.99397568498573, 83.49850298059242, 84.00000000000001, 84.49852069711044, 84.99411744350311, 85.48684109265005, 85.97674104081871, 86.46386528486914, 86.94826047713664, 87.42997197757758, 87.90904390334364, 88.38551917593742, 88.85943956609226, 89.33084573650918, 89.7997772825746, 90.26627277117407, 90.73036977771005, 91.19210492142399, 91.65151389911681, 92.10863151735565], [0.0, 9.219544457292889, 13.038404810405298, 15.968719422671315, 18.439088914585778, 20.615528128088304, 22.583179581272432, 24.392621835300936, 26.076809620810597, 27.658633371878665, 29.154759474226502, 30.577769702841316, 31.93743884534263, 33.24154027718933, 34.496376621320685, 35.707142142714254, 36.878177829171555, 38.01315561749642, 39.1152144312159, 40.18706259482025, 41.23105625617661, 42.24926034855522, 43.243496620879306, 44.21538193886829, 45.166359162544865, 46.097722286464446, 47.010637094172644, 47.90615826801395, 48.78524367060187, 49.648766349225646, 50.49752469181038, 51.332251070842396, 52.15361924162119, 52.96225070746145, 53.75872022286245, 54.543560573178574, 55.31726674375733, 56.08029957123982, 56.833088953531295, 57.57603668193914, 58.309518948453004, 59.033888572581766, 59.74947698515864, 60.45659600076736, 61.15553940568263, 61.8465843842649, 62.52999280345393, 63.206012372241936, 63.87487769068526, 64.53681120105021, 65.1920240520265, 65.84071688552609, 66.48308055437866, 67.11929677819934, 67.7495387438173, 68.37397165588672, 68.99275324264137, 69.60603422117943, 70.21395872616783, 70.81666470542086, 71.41428428542851, 72.00694410957877, 72.59476565152615, 73.1778655059028, 73.75635565834311, 74.33034373659252, 74.89993324429602, 75.46522377890362, 76.02631123499285, 76.58328799418318, 77.13624310270757, 77.68526243760782, 78.2304288624318, 78.77182237323191, 79.3095202355934, 79.84359711335657, 80.3741251896405, 80.90117428072352, 81.42481194328914, 81.94510357550352, 82.46211251235322, 82.975900115636, 83.48652585896723, 83.99404740813483, 84.49852069711044, 85.0, 85.49853799919622, 85.99418584997477, 86.48699324175861, 86.97700845625813, 87.46427842267951, 87.94884877018005, 88.43076387773658, 88.91006692158093, 89.38679992034619, 89.86100377805714, 90.33271832508973, 90.8019823572151, 91.26883367283709, 91.73330910852394, 92.19544457292889, 92.65527507918803], [0.0, 9.273618495495704, 13.114877048604002, 16.062378404209014, 18.547236990991408, 20.736441353327724, 22.715633383201094, 24.535688292770594, 26.229754097208005, 27.820855486487112, 29.32575659723036, 30.7571129984594, 32.12475680841803, 33.43650699460098, 34.698703145794944, 35.91656999213594, 37.094473981982816, 38.23610858861032, 39.34463114581201, 40.42276586281548, 41.47288270665545, 42.497058721751564, 43.497126341863094, 44.474711915874174, 45.43126676640219, 46.36809247747853, 47.28636167014756, 48.18713521262704, 49.07137658554119, 49.9399639567351, 50.79370039680117, 51.633322573702344, 52.45950819441601, 53.27288240746882, 54.0740233383831, 54.86346689738082, 55.641710972974224, 56.409219104681824, 57.166423711825814, 57.91372894228105, 58.65151319446072, 59.38013135721409, 60.099916805266886, 60.81118318204309, 61.5142259969188, 62.20932405998315, 62.89674077406555, 63.57672530100934, 64.24951361683605, 64.91532946846992, 65.57438524302002, 66.2268827591938, 66.87301398920197, 67.51296171847301, 68.1469001496033, 68.7749954561976, 69.39740629158989, 70.0142842568572, 70.6257743320383, 71.2320152740325, 71.83313998427188, 72.42927584892728, 73.02054505411473, 73.60706487831177, 74.18894796396563, 74.76630257007498, 75.33923280734946, 75.90783885739339, 76.47221717722064, 77.03246069028303, 77.5886589650833, 78.14089838234521, 78.68926229162402, 79.23383115816122, 79.77468270071653, 80.31189202104505, 80.84553172563096, 81.37567204023571, 81.90238091777309, 82.42572413997951, 82.9457654133109, 83.46256645946134, 83.97618710086807, 84.4866853415377, 84.99411744350313, 85.49853799919622, 86.0, 86.49855490122364, 86.99425268372619, 87.48714191239762, 87.97726979169109, 88.46468221838589, 88.94942383174835, 89.43153806124549, 89.9110671719561, 90.38805230781333, 90.86253353280438, 91.33454987024352, 91.80413934022802, 92.2713389953782, 92.73618495495705, 93.19871243745807], [0.0, 9.327379053088816, 13.19090595827292, 16.155494421403514, 18.65475810617763, 20.856653614614213, 22.847319317591726, 24.677925358506133, 26.38181191654584, 27.982137159266447, 29.495762407505254, 30.935416596516045, 32.31098884280703, 33.63034344160048, 34.899856733230294, 36.124783736376884, 37.30951621235526, 38.45776904605882, 39.572717874818764, 40.65710270051225, 41.71330722922843, 42.74342054632503, 43.749285708454714, 44.73253849269008, 45.69463863518345, 46.63689526544408, 47.56048780237647, 48.466483264210545, 49.35585071701227, 50.229473419497445, 51.0881590977792, 51.93264869039514, 52.76362383309168, 53.581713298475265, 54.38749856354859, 55.181518645285585, 55.964274318532894, 56.736231810017145, 57.49782604586021, 58.2494635168428, 58.99152481501051, 59.724366886556446, 60.448325038829665, 61.163714733492114, 61.87083319303209, 62.56996084384262, 63.26136261573884, 63.945289114992676, 64.62197768561406, 65.2916533716217, 65.9545297913646, 66.61080993352357, 67.26068688320096, 67.90434448545984, 68.54195795277518, 69.17369442208505, 69.79971346646059, 70.42016756583303, 71.03520254071216, 71.64495795239188, 72.24956747275377, 72.84915922644544, 73.44385610791416, 74.03377607551839, 74.61903242471053, 75.1997340420829, 75.77598564189054, 76.34788798650557, 76.91553809211764, 77.47902942086975, 78.03845206050669, 78.59389289251425, 79.14543574963753, 79.69316156358713, 80.23714850367004, 80.77747210701757, 81.3142054010245, 81.84741901856161, 82.37718130647589, 82.90355842785037, 83.42661445845685, 83.94641147779934, 84.46300965511472, 84.9764673306675, 85.48684109265005, 85.99418584997477, 86.49855490122364, 87.00000000000001, 87.49857141690943, 87.99431799837987, 88.48728722251576, 88.97752525216691, 89.46507698538016, 89.9499861033897, 90.4322951162913, 90.91204540653564, 91.3892772703669, 91.86402995732335, 92.33634170791044, 92.80624978954812, 93.27379053088816, 93.73899935459094], [0.0, 9.38083151964686, 13.266499161421601, 16.248076809271925, 18.76166303929372, 20.97617696340303, 22.978250586152118, 24.819347291981714, 26.532998322843202, 28.14249455894058, 29.664793948382652, 31.112698372208097, 32.49615361854385, 33.82306905057553, 35.09985754956849, 36.3318042491699, 37.52332607858744, 38.67815921162743, 39.799497484264805, 40.89009660052175, 41.95235392680606, 42.98837052040936, 44.0, 44.98888751680797, 45.956501172304236, 46.9041575982343, 47.8330429724056, 48.74423042781577, 49.63869458396343, 50.51732376126036, 51.38093031466051, 52.230259428802384, 53.065996645686404, 53.888774341229926, 54.699177324709375, 55.49774770204644, 56.28498911788116, 57.06137047074843, 57.82732917920385, 58.58327406350725, 59.329587896765304, 60.06662967072483, 60.79473661428266, 61.514225996918796, 62.225396744416194, 62.92853089020909, 63.623894882347464, 64.31174076325411, 64.9923072370877, 65.66582063752801, 66.332495807108, 66.99253689777692, 67.64613810115107, 68.2934843158555, 68.93475175845636, 69.57010852370435, 70.19971509913698, 70.8237248385031, 71.44228439796701, 72.05553413860729, 72.6636084983398, 73.2666363360568, 73.86474125047755, 74.45804187594514, 75.04665215717488, 75.63068160475615, 76.21023553303061, 76.78541528180988, 77.35631842325486, 77.92303895511263, 78.48566748139433, 79.04429138147802, 79.59899496852961, 80.14985963805552, 80.69696400732805, 81.24038404635961, 81.7801932010435, 82.31646250902672, 82.84926070883192, 83.37865434270333, 83.90470785361212, 84.42748367682174, 84.94704232638122, 85.46344247688599, 85.97674104081872, 86.48699324175861, 86.99425268372619, 87.49857141690944, 88.0, 88.49858755935034, 88.99438184514796, 89.48742928478838, 89.97777503361594, 90.46546302318913, 90.9505360072166, 91.43303560529968, 91.91300234460847, 92.39047569960879, 92.8654941299512, 93.33809511662429, 93.8083151964686, 94.27618999514141], [0.0, 9.433981132056603, 13.341664064126334, 16.340134638368195, 18.867962264113206, 21.095023109728988, 23.108440016582687, 24.95996794869737, 26.68332812825267, 28.30194339616981, 29.832867780352593, 31.288975694324034, 32.68026927673639, 34.0147027033899, 35.298725189445584, 36.53765181289022, 37.73592452822641, 38.897300677553446, 40.024992192379, 41.12177038990418, 42.190046219457976, 43.23193264243458, 44.24929377967517, 45.24378410345447, 46.216880033165374, 47.16990566028302, 48.10405388322278, 49.02040391510458, 49.91993589739474, 50.80354318352215, 51.67204273105524, 52.52618394667559, 53.36665625650534, 54.194095619356915, 55.00909015790026, 55.812185049503306, 56.60388679233962, 57.38466694161429, 58.154965394194846, 58.91519328662175, 59.66573556070519, 60.40695324215582, 61.139185470531096, 61.86275131288617, 62.57795138864807, 63.285069329186946, 63.98437309218556, 64.67611614808051, 65.36053855347278, 66.03786792439622, 66.70832032063167, 67.3721010508059, 68.0294054067798, 68.6804193347711, 69.32532004974806, 69.96427659884722, 70.59745037889117, 71.22499561249548, 71.84705978674423, 72.46378405796925, 73.07530362578044, 73.68174807915457, 74.28324171709255, 74.8799038460921, 75.47184905645283, 76.05918747922567, 76.64202502543888, 77.22046360907191, 77.79460135510689, 78.36453279386026, 78.93034904268445, 79.4921379760288, 80.049984384758, 80.60397012554654, 81.15417426109391, 81.70067319184096, 82.24354077980836, 82.78284846512591, 83.3186653757728, 83.85105843100611, 84.38009243891595, 84.90583018850943, 85.42833253669419, 85.94765849050222, 86.46386528486916, 86.97700845625813, 87.48714191239762, 87.99431799837987, 88.49858755935034, 88.99999999999999, 89.49860334105779, 89.99444427296609, 90.48756820690895, 90.97801932335085, 91.465840618233, 91.95107394696376, 92.43376006633075, 92.91393867445294, 93.39164844888434, 93.8669270829721, 94.33981132056604, 94.81033698917012], [0.0, 9.486832980505138, 13.416407864998739, 16.431676725154986, 18.973665961010276, 21.213203435596427, 23.237900077244504, 25.099800796022265, 26.832815729997478, 28.460498941515414, 30.0, 31.46426544510455, 32.86335345030997, 34.20526275297414, 35.4964786985977, 36.742346141747674, 37.94733192202055, 39.11521443121589, 40.24922359499622, 41.35214625627067, 42.42640687119285, 43.47413023856832, 44.49719092257398, 45.4972526643093, 46.47580015448901, 47.434164902525694, 48.37354648979131, 49.29503017546496, 50.19960159204453, 51.08815909777921, 51.96152422706631, 52.820450584977024, 53.665631459994955, 54.49770637375486, 55.31726674375732, 56.124860801609124, 56.92099788303083, 57.70615218501404, 58.48076606885379, 59.245252974394504, 60.0, 60.74537019394976, 61.4817045957576, 62.20932405998316, 62.9285308902091, 63.639610306789265, 64.34283176858165, 65.0384501660364, 65.72670690061994, 66.40783086353596, 67.0820393249937, 67.7495387438173, 68.41052550594829, 69.06518659932803, 69.71370023173351, 70.35623639735145, 70.9929573971954, 71.62401831787994, 72.24956747275377, 72.86974680894672, 73.48469228349535, 74.09453421137081, 74.6993975879324, 75.2994023880668, 75.8946638440411, 76.48529270389177, 77.07139547199077, 77.65307463326872, 78.23042886243178, 78.8035532193822, 79.37253933193772, 79.93747556684536, 80.49844718999243, 81.05553651663777, 81.60882305241265, 82.15838362577492, 82.70429251254134, 83.24662155306964, 83.78544026261366, 84.32081593533118, 84.8528137423857, 85.38149682454625, 85.90692637965813, 86.4291617453276, 86.94826047713664, 87.46427842267951, 87.97726979169107, 88.48728722251576, 88.99438184514796, 89.49860334105779, 90.0, 90.49861877399013, 90.9945053286186, 91.48770409186145, 91.97825830053536, 92.46621004453463, 92.95160030897802, 93.43446901438463, 93.91485505499116, 94.39279633531365, 94.86832980505139, 95.34149149242423], [0.0, 9.539392014169458, 13.490737563232042, 16.522711641858308, 19.078784028338916, 21.330729007701542, 23.366642891095847, 25.238858928247925, 26.981475126464083, 28.61817604250837, 30.166206257996713, 31.638584039112754, 33.045423283716616, 34.39476704383968, 35.6931365951495, 36.945906403822335, 38.15756805667783, 39.33192087859427, 40.47221268969613, 41.581245772583586, 42.661458015403085, 43.71498598878879, 44.74371464239419, 45.7493169347915, 46.73328578219169, 47.69696007084729, 48.64154602806125, 49.56813492557493, 50.47771785649585, 51.37119815616529, 52.24940191045252, 53.113086899558006, 53.96295025292817, 54.79963503528104, 55.62373594069352, 56.43580423808985, 57.23635208501674, 58.02585630561604, 58.80476171195663, 59.57348403442593, 60.332412515993425, 61.08191221630181, 61.822326064294934, 62.55397669213365, 63.27716807822551, 63.99218702310462, 64.69930447848725, 65.39877674696982, 66.09084656743323, 66.7757440991862, 67.45368781616021, 68.1248853210044, 68.78953408767936, 69.44782214007867, 70.09992867328755, 70.74602462329598, 71.386273190299, 72.02083032012337, 72.64984514780468, 73.27346040688947, 73.89181280764467, 74.50503338701353, 75.11324783285569, 75.71657678474378, 76.31513611335566, 76.90903718029502, 77.49838707999025, 78.08328886515987, 78.66384175718854, 79.24014134263014, 79.81227975693966, 80.38034585643435, 80.94442537939226, 81.50460109711598, 82.06095295571457, 82.61355820929154, 83.16249154516717, 83.70782520170978, 84.2496290793022, 84.78797084492588, 85.32291603080617, 85.85452812752511, 86.38286867197687, 86.90799733051038, 87.42997197757758, 87.94884877018005, 88.46468221838589, 88.97752525216691, 89.48742928478838, 89.99444427296609, 90.49861877399013, 91.0, 91.498633869583, 91.9945650568554, 92.48783703817493, 92.97849213662265, 93.46657156438339, 93.95211546314432, 94.4351629426243, 94.91575211733826, 95.39392014169458, 95.86970324351694], [0.0, 9.59166304662544, 13.564659966250538, 16.613247725836153, 19.18332609325088, 21.44761058952722, 23.494680248941464, 25.377155080899044, 27.129319932501076, 28.77498913987632, 30.331501776206203, 31.81194744117374, 33.22649545167231, 34.58323293158117, 35.888716889852724, 37.14835124201342, 38.36665218650176, 39.54743986657038, 40.693979898751614, 41.809089920733754, 42.89522117905444, 43.95452195167183, 44.98888751680797, 46.00000000000001, 46.98936049788293, 47.9583152331272, 48.90807704254995, 49.83974317750846, 50.75431016179809, 51.65268628057984, 52.535702146254785, 53.40411969127476, 54.25863986500215, 55.099909255823654, 55.92852581643825, 56.74504383644444, 57.54997827975264, 58.343808583259296, 59.12698199637794, 59.89991652748776, 60.663003552412405, 61.41661013113635, 62.16108107168022, 62.896740774065556, 63.62389488234748, 64.34283176858165, 65.05382386916237, 65.7571288910944, 66.45299090334461, 67.14164132637808, 67.82329983125268, 68.49817515817485, 69.16646586316234, 69.82836100038438, 70.48404074682439, 71.13367697511497, 71.77743377970545, 72.4154679609267, 73.04792947099871, 73.67496182557545, 74.29670248402684, 74.91328320131217, 75.52483035399683, 76.13146524269712, 76.73330437300352, 77.33045971672483, 77.92303895511263, 78.5111457055621, 79.09487973314076, 79.67433714816836, 80.24961059095553, 80.82078940470701, 81.38795979750323, 81.95120499419151, 82.51060537894507, 83.06623862918076, 83.61817984146751, 84.16650165000326, 84.7112743381895, 85.25256594378847, 85.79044235810888, 86.32496741962896, 86.85620300243387, 87.38420909981392, 87.90904390334366, 88.43076387773658, 88.94942383174835, 89.46507698538018, 89.97777503361594, 90.48756820690896, 90.99450532861862, 91.498633869583, 92.00000000000001, 92.49864863877742, 92.99462350050138, 93.48796714016194, 93.97872099576585, 94.46692542895636, 94.95261976375376, 95.43584232352121, 95.9166304662544, 96.39502061828713], [0.0, 9.643650760992957, 13.638181696985857, 16.70329308849007, 19.287301521985913, 21.563858652847827, 23.622023622035435, 25.51470164434615, 27.276363393971714, 28.93095228297887, 30.495901363953813, 31.98437118343896, 33.40658617698014, 34.770677301427426, 36.08323710533743, 37.3496987939662, 38.57460304397183, 39.761790704142086, 40.914545090957574, 42.03569911396741, 43.127717305695654, 44.192759587968716, 45.23273151159457, 46.24932431938871, 47.24404724407087, 48.21825380496478, 49.173163412577, 50.10987926547021, 51.0294032886923, 51.93264869039515, 52.820450584977024, 53.6935750346352, 54.55272678794343, 55.39855593785818, 56.231663678038196, 57.052607302383656, 57.86190456595774, 58.66003750424987, 59.44745579080741, 60.22457969965421, 60.991802727907626, 61.74949392505173, 62.497999967998986, 63.23764701504951, 63.96874236687792, 64.69157595854347, 65.40642170307133, 66.1135387042624, 66.81317235396028, 67.50555532695068, 68.19090848492928, 68.86944169949399, 69.54135460285485, 70.20683727387242, 70.86607086610631, 71.5192281837549, 72.16647421067486, 72.8079665970696, 73.44385610791417, 74.07428703673091, 74.6993975879324, 75.31932023060219, 75.93418202627852, 76.54410493303844, 77.14920608794365, 77.74959806970067, 78.34538914320358, 78.93668348746355, 79.52358140828417, 80.10617953691214, 80.68457101577724, 81.25884567233281, 81.82909018191515, 82.39538822045807, 82.95782060782454, 83.51646544245034, 84.07139822793482, 84.62269199216013, 85.17041739947035, 85.71464285639883, 86.25543461139131, 86.79285684893661, 87.32697177848321, 87.8578397184907, 88.38551917593743, 88.91006692158093, 89.43153806124549, 89.9499861033897, 90.46546302318914, 90.97801932335085, 91.48770409186145, 91.99456505685541, 92.49864863877742, 93.00000000000001, 93.49866309204641, 93.99468070055879, 94.48809448814174, 94.97894503520241, 95.467271878901, 95.95311355031687, 96.43650760992956, 96.91749068150703], [0.0, 9.695359714832659, 13.71130920080209, 16.792855623746668, 19.390719429665317, 21.6794833886788, 23.748684174075837, 25.651510676761323, 27.42261840160418, 29.086079144497976, 30.659419433511786, 32.15587038162706, 33.585711247493336, 34.957116585897076, 36.276714294434115, 37.54996671103718, 38.781438859330635, 39.97499218261337, 41.13392760240627, 42.26109321823089, 43.3589667773576, 44.42971978304613, 45.47526800360829, 46.49731175025068, 47.497368348151674, 48.4767985741633, 49.43682837723311, 50.37856687124001, 51.303021353522645, 52.21110992882646, 53.103672189407014, 53.98147830506312, 54.84523680320836, 55.69560126257729, 56.53317610041028, 57.35852159879995, 58.17215828899595, 58.97457079114694, 59.76621118993575, 60.547502012882426, 61.31883886702357, 62.080592780675026, 62.83311228962005, 63.57672530100933, 64.31174076325412, 65.0384501660364, 65.75712889109438, 66.46803743153548, 67.17142249498667, 67.86751800382861, 68.55654600401044, 69.23871749245505, 69.91423317179415, 70.5832841400852, 71.24605252222752, 71.90271204899021, 72.55342858886823, 73.1983606373804, 73.83765976789894, 74.47147104764348, 75.09993342207436, 75.7231800705702, 76.34133873596926, 76.95453203028396, 77.56287771866127, 78.16648898345122, 78.76547467006087, 79.359939516106, 79.94998436522674, 80.53570636680355, 81.117199162693, 81.69455306200042, 82.26785520481253, 82.83718971573094, 83.40263784797217, 83.96427811873333, 84.52218643646178, 85.07643622061282, 85.6270985144306, 86.17424209124209, 86.7179335547152, 87.25823743349393, 87.7952162705919, 88.32893070789434, 88.85943956609226, 89.38679992034619, 89.91106717195609, 90.4322951162913, 90.95053600721658, 91.46584061823299, 91.97825830053536, 92.48783703817493, 92.99462350050136, 93.49866309204641, 94.00000000000001, 94.49867723941959, 94.99473669630335, 95.4882191686493, 95.97916440561463, 96.46761114488118, 96.9535971483266, 97.43715923609433], [0.0, 9.746794344808963, 13.784048752090222, 16.881943016134134, 19.493588689617926, 21.794494717703365, 23.874672772626642, 25.78759391645525, 27.568097504180443, 29.24038303442689, 30.82207001484488, 32.32645975048923, 33.76388603226827, 35.14256678161116, 36.469165057620934, 37.749172176353746, 38.98717737923585, 40.18706259482023, 41.352146256270665, 42.485291572496, 43.58898943540673, 44.66542286825459, 45.71651780264984, 46.74398357008097, 47.749345545253284, 48.73397172404482, 49.69909455915671, 50.645829048402405, 51.5751878329105, 52.48809388804284, 53.385391260156545, 54.26785420486054, 55.136195008360886, 55.991070716677676, 56.83308895353128, 57.66281297335398, 58.48076606885378, 59.28743543112655, 60.08327554319921, 60.86871117413281, 61.64414002968976, 62.4099351065197, 63.16644678941503, 63.91400472509917, 64.65291950097846, 65.38348415311009, 66.10597552415364, 66.82065548915246, 67.52777206453653, 68.22756041366274, 68.9202437604511, 69.60603422117941, 70.28513356322232, 70.95773389842716, 71.62401831787993, 72.2841614740048, 72.93833011524187, 73.58668357794092, 74.22937423958254, 74.86654793697916, 75.49834435270749, 76.12489737267302, 76.74633541739956, 77.36278174936575, 77.9743547584717, 78.58116822750856, 79.18333157931662, 79.78095010715276, 80.37412518964047, 80.96295449154508, 81.54753215150045, 82.12794895770867, 82.70429251254133, 83.27664738688752, 83.84509526501832, 84.40971508067067, 84.970583144992, 85.52777326693358, 86.08135686662938, 86.63140308225418, 87.17797887081346, 87.72114910328067, 88.26097665446491, 88.79752248796133, 89.33084573650918, 89.86100377805714, 90.38805230781333, 90.91204540653565, 91.43303560529968, 91.95107394696376, 92.46621004453463, 92.97849213662265, 93.48796714016194, 93.99468070055879, 94.4986772394196, 94.99999999999999, 95.49869109050657, 95.99479152537391, 96.48834126463154, 96.97937925146768, 97.46794344808964, 97.95407086997457], [0.0, 9.797958971132713, 13.85640646055102, 16.970562748477143, 19.595917942265427, 21.908902300206645, 24.0, 25.92296279363144, 27.71281292110204, 29.393876913398138, 30.983866769659336, 32.49615361854385, 33.941125496954285, 35.32704346531139, 36.66060555964672, 37.94733192202055, 39.19183588453085, 40.39801975344831, 41.569219381653056, 42.70831300812525, 43.81780460041329, 44.899888641287305, 45.95650117230423, 46.98936049788293, 48.0, 48.98979485566357, 49.959983987187194, 50.911688245431435, 51.84592558726288, 52.763623833091685, 53.66563145999495, 54.55272678794343, 55.42562584220408, 56.28498911788117, 57.1314274283428, 57.96550698475776, 58.787753826796276, 59.598657703005365, 60.398675482166006, 61.18823416311343, 61.96773353931867, 62.73754856543249, 63.498031465550184, 64.24951361683604, 64.9923072370877, 65.72670690061993, 66.4529909033446, 67.17142249498667, 67.88225099390857, 68.58571279792899, 69.2820323027551, 69.97142273814362, 70.65408693062278, 71.33021800050804, 72.00000000000001, 72.66360849833981, 73.32121111929344, 73.97296803562773, 74.61903242471053, 75.25955088890711, 75.8946638440411, 76.52450587883597, 77.14920608794364, 77.76888838089432, 78.3836717690617, 78.993670632526, 79.5989949685296, 80.19975062305369, 80.79603950689662, 81.38795979750323, 81.97560612767678, 82.55906976220118, 83.13843876330611, 83.71379814582541, 84.2852300228219, 84.8528137423857, 85.4166260162505, 85.97674104081871, 86.53323061113575, 87.08616422830897, 87.63560920082658, 88.18163074019442, 88.72429205127536, 89.26365441768559, 89.79977728257461, 90.33271832508971, 90.86253353280438, 91.3892772703669, 91.91300234460846, 92.43376006633073, 92.95160030897802, 93.46657156438339, 93.97872099576585, 94.48809448814174, 94.99473669630335, 95.49869109050657, 96.0, 96.49870465451856, 96.99484522385714, 97.48846085563153, 97.97958971132714, 98.46826900072938], [0.0, 9.848857801796106, 13.928388277184121, 17.058722109231987, 19.69771560359221, 22.022715545545243, 24.12467616362964, 26.05762844159077, 27.856776554368242, 29.54657340538832, 31.144823004794876, 32.66496594212216, 34.11744421846397, 35.51056180912941, 36.85105154537656, 38.144462245521304, 39.39543120718442, 40.607881008493905, 41.785164831552365, 42.93017586733137, 44.045431091090485, 45.133136385587036, 46.19523784980439, 47.23346271447818, 48.24935232725928, 49.24428900898053, 50.21951811795889, 51.17616632769596, 52.11525688318154, 53.037722424704484, 53.94441583704471, 54.83611948342079, 55.713553108736484, 56.57738063926256, 57.42821606144492, 58.26662852782887, 59.09314681077664, 59.90826320300065, 60.71243694664217, 61.50609725872714, 62.28964600958975, 63.06346010171025, 63.82789358893181, 64.5832795698701, 65.32993188424432, 66.06814663663572, 66.79820356865895, 67.52036729757918, 68.23488843692795, 68.94200461257273, 69.6419413859206, 70.33491309442276, 71.02112361825883, 71.70076708097342, 72.37402849088893, 73.0410843293006, 73.70210309075313, 74.35724578008522, 75.00666637039672, 75.65051222562872, 76.28892449104261, 76.92203845452876, 77.5499838813652, 78.1728853247723, 78.79086241436885, 79.40403012442127, 80.01249902359007, 80.61637550770936, 81.21576201698781, 81.8107572388864, 82.40145629781067, 82.98795093265048, 83.57032966310473, 84.14867794564572, 84.72307831990054, 85.29361054615991, 85.86035173466274, 86.42337646724988, 86.98275691193055, 87.53856293085923, 88.09086218218097, 88.63972021616495, 89.18520056601321, 89.72736483370055, 90.26627277117407, 90.8019823572151, 91.33454987024352, 91.86402995732335, 92.39047569960879, 92.91393867445294, 93.43446901438463, 93.95211546314432, 94.46692542895636, 94.97894503520241, 95.4882191686493, 95.99479152537391, 96.49870465451856, 97.00000000000001, 97.49871794028886, 97.99489782636647, 98.48857801796106, 98.97979591815697], [0.0, 9.899494936611665, 14.0, 17.146428199482248, 19.79898987322333, 22.135943621178654, 24.24871130596428, 26.19160170741759, 28.0, 29.698484809834998, 31.304951684997057, 32.832910318764014, 34.292856398964496, 35.6931365951495, 37.04051835490427, 38.34057902536163, 39.59797974644666, 40.8166632639171, 42.0, 43.15089802078284, 44.27188724235731, 45.365184888855026, 46.4327470649756, 47.47630988187688, 48.49742261192856, 49.49747468305833, 50.47771785649586, 51.43928459844675, 52.38320341483518, 53.31041174104736, 54.22176684690383, 55.11805511808268, 56.0, 56.86826883245173, 57.723478758647246, 58.566201857385295, 59.396969619669996, 60.21627686929839, 61.02458520956944, 61.822326064294934, 62.609903369994115, 63.387695966961914, 64.15605972938177, 64.91532946846992, 65.66582063752803, 66.40783086353596, 67.14164132637806, 67.86751800382861, 68.58571279792899, 69.29646455628165, 70.0, 70.69653456853456, 71.386273190299, 72.069410986909, 72.74613391789285, 73.41661937191061, 74.08103670980854, 74.73954776421918, 75.39230729988306, 76.03946343840151, 76.68115805072325, 77.31752712031081, 77.9487010796203, 78.57480512225277, 79.19595949289332, 79.81227975693966, 80.4238770515324, 81.03085831953157, 81.6333265278342, 82.23138087129512, 82.82511696339462, 83.4146270146909, 84.0, 84.581321815162, 85.15867542417507, 85.73214099741124, 86.30179604156568, 86.86771552193599, 87.42997197757758, 87.98863562983574, 88.54377448471462, 89.09545442950498, 89.6437393240599, 90.18869108707588, 90.73036977771005, 91.26883367283708, 91.804139340228, 92.33634170791044, 92.8654941299512, 93.39164844888433, 93.91485505499116, 94.43516294262429, 94.95261976375376, 95.46727187890099, 95.97916440561463, 96.48834126463154, 96.99484522385713, 97.49871794028884, 98.0, 98.49873095629202, 98.99494936611666, 99.48869282486328], [0.0, 9.949874371066201, 14.07124727947029, 17.23368793961409, 19.899748742132402, 22.248595461286993, 24.372115213907882, 26.32489316217637, 28.14249455894058, 29.8496231131986, 31.464265445104548, 33.00000000000001, 34.46737587922818, 35.8747822293042, 37.22902093797257, 38.53569773599539, 39.799497484264805, 41.02438299353203, 42.21374183841087, 43.37049688440289, 44.497190922573985, 45.596052460711995, 46.669047558312144, 47.71792116176061, 48.744230427815765, 49.749371855331006, 50.734603575863304, 51.70106381884227, 52.64978632435274, 53.581713298475265, 54.497706373754845, 55.39855593785817, 56.28498911788116, 57.15767664977297, 58.017238817441154, 58.86425061104576, 59.6992462263972, 60.522723005496054, 61.33514490078263, 62.13694553162395, 62.928530890209096, 63.71028174478591, 64.48255578061405, 65.24568951279464, 66.00000000000001, 66.74578638386096, 67.48333127521195, 68.21290200541245, 68.93475175845636, 69.6491205974634, 70.35623639735145, 71.05631569396208, 71.7495644586084, 72.43617880589782, 73.11634564172365, 73.79024325749307, 74.45804187594514, 75.1199041532935, 75.77598564189054, 76.42643521714199, 77.07139547199078, 77.71100308193171, 78.34538914320358, 78.9746794865291, 79.59899496852961, 80.21845174272563, 80.83316151184489, 81.44323176298937, 82.04876598706406, 82.64986388373548, 83.24662155306966, 83.83913167489273, 84.42748367682174, 85.01176389182854, 85.59205570612264, 86.16843969807044, 86.74099376880578, 87.3097932651315, 87.87491109526087, 88.43641783790206, 88.99438184514797, 89.54886933959581, 90.09994450608725, 90.64766957842878, 91.19210492142399, 91.73330910852394, 92.2713389953782, 92.80624978954813, 93.33809511662429, 93.8669270829721, 94.39279633531365, 94.91575211733826, 95.43584232352121, 95.95311355031686, 96.46761114488118, 96.97937925146768, 97.48846085563153, 97.99489782636647, 98.49873095629204, 99.00000000000001, 99.49874371066201, 99.99499987499377], [0.0, 10.000000000000002, 14.142135623730953, 17.320508075688778, 20.000000000000004, 22.360679774997898, 24.494897427831784, 26.45751311064591, 28.284271247461906, 30.000000000000004, 31.622776601683796, 33.16624790355401, 34.641016151377556, 36.0555127546399, 37.416573867739416, 38.72983346207417, 40.00000000000001, 41.23105625617661, 42.42640687119285, 43.588989435406745, 44.721359549995796, 45.825756949558404, 46.9041575982343, 47.9583152331272, 48.98979485566357, 50.00000000000001, 50.99019513592786, 51.96152422706633, 52.91502622129182, 53.851648071345046, 54.77225575051661, 55.677643628300224, 56.56854249492381, 57.4456264653803, 58.309518948453004, 59.16079783099617, 60.00000000000001, 60.827625302982206, 61.64414002968977, 62.449979983983994, 63.24555320336759, 64.03124237432849, 64.80740698407861, 65.57438524302, 66.33249580710802, 67.08203932499369, 67.82329983125268, 68.55654600401044, 69.28203230275511, 70.0, 70.71067811865476, 71.41428428542851, 72.1110255092798, 72.8010988928052, 73.48469228349535, 74.16198487095664, 74.83314773547883, 75.4983443527075, 76.15773105863909, 76.81145747868608, 77.45966692414834, 78.10249675906654, 78.74007874011812, 79.37253933193772, 80.00000000000001, 80.6225774829855, 81.24038404635961, 81.85352771872451, 82.46211251235322, 83.06623862918076, 83.66600265340756, 84.2614977317636, 84.8528137423857, 85.44003745317532, 86.02325267042626, 86.60254037844388, 87.17797887081349, 87.74964387392123, 88.31760866327848, 88.8819441731559, 89.44271909999159, 90.0, 90.55385138137419, 91.10433579144299, 91.65151389911681, 92.19544457292888, 92.73618495495704, 93.27379053088816, 93.8083151964686, 94.33981132056604, 94.86832980505139, 95.39392014169458, 95.9166304662544, 96.43650760992956, 96.9535971483266, 97.46794344808964, 97.97958971132714, 98.48857801796106, 98.99494936611667, 99.49874371066201, 100.00000000000001, 100.49875621120891], [0.0, 10.049875621120892, 14.212670403551897, 17.406895185529216, 20.099751242241783, 22.472205054244235, 24.617067250182345, 26.589471600616665, 28.425340807103794, 30.149626863362673, 31.78049716414141, 33.33166662499792, 34.81379037105843, 36.23534186398688, 37.603191353926334, 38.923000912057134, 40.19950248448357, 41.43669871020133, 42.63801121065569, 43.80639222761903, 44.94441010848847, 46.054315758677824, 47.138094997570704, 48.19751030914357, 49.23413450036469, 50.249378105604464, 51.24451190127584, 52.22068555658765, 53.17894320123333, 54.12023651093924, 55.04543577809154, 55.955339334151134, 56.85068161420759, 57.73214009544425, 58.60034129593445, 59.455865984779, 60.29925372672535, 61.131006862311715, 61.951594006934165, 62.76145313805283, 63.56099432828282, 64.35060217278469, 65.13063795173514, 65.90144156238162, 66.66333324999584, 67.4166151627327, 68.1615727518079, 68.89847603539575, 69.62758074211686, 70.34912934784623, 71.06335201775948, 71.77046746399247, 72.47068372797376, 73.1641988953614, 73.85120175054705, 74.53187237685634, 75.20638270785267, 75.87489703452653, 76.53757247260982, 77.19455939378112, 77.84600182411427, 78.49203781276162, 79.13279977354524, 79.76841480184999, 80.39900496896713, 81.0246875958186, 81.6455755078008, 82.26177727231524, 82.87339742040265, 83.4805366537614, 84.08329203831164, 84.68175718535842, 85.27602242131138, 85.86617494683225, 86.45229898620394, 87.03447592764607, 87.61278445523806, 88.1873006730561, 88.75809822207776, 89.32524839036274, 89.88882021697694, 90.44888059008802, 91.00549433962767, 91.55872432488344, 92.10863151735565, 92.65527507918803, 93.19871243745807, 93.73899935459096, 94.27618999514141, 94.81033698917012, 95.34149149242423, 95.86970324351694, 96.39502061828713, 96.91749068150703, 97.43715923609433, 97.95407086997457, 98.46826900072938, 98.97979591815697, 99.48869282486328, 99.99499987499377, 100.49875621120893, 101.00000000000001]]}, {\"colorscale\": [[0.0, \"#440154\"], [0.1111111111111111, \"#482878\"], [0.2222222222222222, \"#3e4989\"], [0.3333333333333333, \"#31688e\"], [0.4444444444444444, \"#26828e\"], [0.5555555555555556, \"#1f9e89\"], [0.6666666666666666, \"#35b779\"], [0.7777777777777778, \"#6ece58\"], [0.8888888888888888, \"#b5de2b\"], [1.0, \"#fde725\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"A = 1\", \"showscale\": false, \"type\": \"surface\", \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.1, 0.1414213562373095, 0.17320508075688776, 0.2, 0.223606797749979, 0.24494897427831783, 0.2645751311064591, 0.282842712474619, 0.3, 0.31622776601683794, 0.33166247903554, 0.3464101615137755, 0.36055512754639896, 0.37416573867739417, 0.38729833462074165, 0.4, 0.41231056256176607, 0.4242640687119285, 0.43588989435406744, 0.447213595499958, 0.45825756949558405, 0.469041575982343, 0.479583152331272, 0.48989794855663565, 0.5, 0.5099019513592785, 0.5196152422706632, 0.5291502622129182, 0.5385164807134505, 0.5477225575051661, 0.5567764362830022, 0.565685424949238, 0.574456264653803, 0.5830951894845301, 0.5916079783099616, 0.6, 0.608276253029822, 0.6164414002968976, 0.6244997998398399, 0.6324555320336759, 0.6403124237432849, 0.6480740698407861, 0.6557438524302001, 0.66332495807108, 0.6708203932499369, 0.6782329983125268, 0.6855654600401044, 0.692820323027551, 0.7000000000000001, 0.7071067811865476, 0.7141428428542851, 0.7211102550927979, 0.7280109889280519, 0.7348469228349535, 0.7416198487095663, 0.7483314773547883, 0.754983443527075, 0.7615773105863909, 0.7681145747868608, 0.7745966692414833, 0.7810249675906654, 0.787400787401181, 0.7937253933193772, 0.8, 0.8062257748298549, 0.812403840463596, 0.8185352771872451, 0.8246211251235321, 0.8306623862918076, 0.8366600265340756, 0.8426149773176359, 0.848528137423857, 0.8544003745317531, 0.8602325267042626, 0.8660254037844387, 0.8717797887081349, 0.8774964387392122, 0.8831760866327848, 0.8888194417315589, 0.894427190999916, 0.9, 0.9055385138137417, 0.9110433579144299, 0.9165151389911681, 0.9219544457292888, 0.9273618495495705, 0.9327379053088816, 0.938083151964686, 0.9433981132056604, 0.9486832980505138, 0.9539392014169457, 0.959166304662544, 0.9643650760992956, 0.9695359714832659, 0.9746794344808963, 0.9797958971132713, 0.9848857801796106, 0.9899494936611666, 0.9949874371066201, 1.0, 1.0049875621120892], [0.0, 0.1414213562373095, 0.19999999999999998, 0.24494897427831783, 0.282842712474619, 0.31622776601683794, 0.34641016151377546, 0.3741657386773941, 0.39999999999999997, 0.4242640687119285, 0.4472135954999579, 0.469041575982343, 0.48989794855663565, 0.5099019513592785, 0.529150262212918, 0.5477225575051661, 0.565685424949238, 0.58309518948453, 0.6, 0.6164414002968976, 0.6324555320336759, 0.6480740698407861, 0.6633249580710799, 0.6782329983125268, 0.6928203230275509, 0.7071067811865476, 0.7211102550927979, 0.7348469228349535, 0.7483314773547882, 0.7615773105863909, 0.7745966692414833, 0.7874007874011811, 0.7999999999999999, 0.812403840463596, 0.8246211251235321, 0.8366600265340756, 0.848528137423857, 0.8602325267042626, 0.8717797887081348, 0.8831760866327847, 0.8944271909999159, 0.9055385138137417, 0.9165151389911681, 0.9273618495495702, 0.938083151964686, 0.9486832980505137, 0.9591663046625439, 0.9695359714832658, 0.9797958971132713, 0.9899494936611665, 1.0, 1.0099504938362078, 1.019803902718557, 1.0295630140987002, 1.0392304845413265, 1.0488088481701516, 1.058300524425836, 1.0677078252031311, 1.0770329614269007, 1.0862780491200215, 1.0954451150103321, 1.104536101718726, 1.1135528725660042, 1.1224972160321824, 1.131370849898476, 1.1401754250991378, 1.1489125293076057, 1.1575836902790224, 1.16619037896906, 1.174734012447073, 1.1832159566199232, 1.1916375287812984, 1.2, 1.2083045973594573, 1.2165525060596438, 1.224744871391589, 1.2328828005937953, 1.2409673645990857, 1.2489995996796797, 1.2569805089976536, 1.2649110640673518, 1.2727922061357855, 1.2806248474865698, 1.2884098726725124, 1.2961481396815722, 1.3038404810405297, 1.3114877048604001, 1.3190905958272918, 1.3266499161421599, 1.3341664064126333, 1.3416407864998738, 1.349073756323204, 1.3564659966250536, 1.3638181696985856, 1.3711309200802089, 1.378404875209022, 1.3856406460551018, 1.392838827718412, 1.4, 1.407124727947029, 1.4142135623730951, 1.4212670403551897], [0.0, 0.17320508075688776, 0.24494897427831783, 0.3000000000000001, 0.3464101615137755, 0.38729833462074176, 0.42426406871192857, 0.45825756949558405, 0.48989794855663565, 0.5196152422706632, 0.5477225575051662, 0.574456264653803, 0.6000000000000002, 0.6244997998398399, 0.6480740698407861, 0.6708203932499369, 0.692820323027551, 0.7141428428542851, 0.7348469228349536, 0.7549834435270751, 0.7745966692414835, 0.7937253933193773, 0.8124038404635961, 0.8306623862918077, 0.8485281374238571, 0.8660254037844388, 0.8831760866327849, 0.9000000000000001, 0.9165151389911681, 0.9327379053088817, 0.9486832980505139, 0.9643650760992957, 0.9797958971132713, 0.9949874371066202, 1.009950493836208, 1.02469507659596, 1.0392304845413265, 1.053565375285274, 1.0677078252031313, 1.081665382639197, 1.0954451150103324, 1.1090536506409419, 1.1224972160321827, 1.1357816691600549, 1.148912529307606, 1.161895003862225, 1.1747340124470733, 1.187434208703792, 1.2000000000000004, 1.2124355652982142, 1.2247448713915892, 1.2369316876852985, 1.2489995996796799, 1.2609520212918495, 1.2727922061357857, 1.2845232578665131, 1.2961481396815722, 1.3076696830622023, 1.3190905958272923, 1.3304134695650072, 1.3416407864998738, 1.3527749258468684, 1.3638181696985856, 1.3747727084867523, 1.385640646055102, 1.3964240043768943, 1.4071247279470291, 1.4177446878757827, 1.4282856857085702, 1.4387494569938162, 1.4491376746189442, 1.4594519519326425, 1.4696938456699071, 1.4798648586948744, 1.489966442575134, 1.5000000000000002, 1.5099668870541503, 1.5198684153570665, 1.5297058540778359, 1.5394804318340656, 1.549193338482967, 1.5588457268119897, 1.5684387141358125, 1.5779733838059502, 1.5874507866387546, 1.5968719422671316, 1.6062378404209012, 1.6155494421403516, 1.6248076809271923, 1.6340134638368193, 1.6431676725154984, 1.6522711641858308, 1.6613247725836153, 1.670329308849007, 1.6792855623746668, 1.6881943016134133, 1.6970562748477143, 1.7058722109231985, 1.7146428199482249, 1.7233687939614089, 1.7320508075688776, 1.7406895185529214], [0.0, 0.2, 0.282842712474619, 0.3464101615137755, 0.4, 0.447213595499958, 0.48989794855663565, 0.5291502622129182, 0.565685424949238, 0.6, 0.6324555320336759, 0.66332495807108, 0.692820323027551, 0.7211102550927979, 0.7483314773547883, 0.7745966692414833, 0.8, 0.8246211251235321, 0.848528137423857, 0.8717797887081349, 0.894427190999916, 0.9165151389911681, 0.938083151964686, 0.959166304662544, 0.9797958971132713, 1.0, 1.019803902718557, 1.0392304845413265, 1.0583005244258363, 1.077032961426901, 1.0954451150103321, 1.1135528725660044, 1.131370849898476, 1.148912529307606, 1.1661903789690602, 1.1832159566199232, 1.2, 1.216552506059644, 1.2328828005937953, 1.2489995996796799, 1.2649110640673518, 1.2806248474865698, 1.2961481396815722, 1.3114877048604001, 1.32664991614216, 1.3416407864998738, 1.3564659966250536, 1.3711309200802089, 1.385640646055102, 1.4000000000000001, 1.4142135623730951, 1.4282856857085702, 1.4422205101855958, 1.4560219778561039, 1.469693845669907, 1.4832396974191326, 1.4966629547095767, 1.50996688705415, 1.5231546211727818, 1.5362291495737217, 1.5491933384829666, 1.5620499351813308, 1.574801574802362, 1.5874507866387544, 1.6, 1.6124515496597098, 1.624807680927192, 1.6370705543744901, 1.6492422502470643, 1.661324772583615, 1.6733200530681511, 1.6852299546352718, 1.697056274847714, 1.7088007490635062, 1.7204650534085253, 1.7320508075688774, 1.7435595774162698, 1.7549928774784245, 1.7663521732655696, 1.7776388834631178, 1.788854381999832, 1.8, 1.8110770276274835, 1.8220867158288598, 1.8330302779823362, 1.8439088914585775, 1.854723699099141, 1.8654758106177631, 1.876166303929372, 1.8867962264113207, 1.8973665961010275, 1.9078784028338913, 1.918332609325088, 1.9287301521985911, 1.9390719429665317, 1.9493588689617927, 1.9595917942265426, 1.9697715603592212, 1.9798989873223332, 1.9899748742132402, 2.0, 2.0099751242241783], [0.0, 0.223606797749979, 0.31622776601683794, 0.38729833462074176, 0.447213595499958, 0.5000000000000001, 0.5477225575051662, 0.5916079783099617, 0.6324555320336759, 0.6708203932499369, 0.7071067811865476, 0.7416198487095664, 0.7745966692414835, 0.806225774829855, 0.8366600265340756, 0.8660254037844386, 0.894427190999916, 0.9219544457292888, 0.9486832980505139, 0.9746794344808966, 1.0000000000000002, 1.02469507659596, 1.0488088481701516, 1.072380529476361, 1.0954451150103324, 1.118033988749895, 1.140175425099138, 1.1618950038622253, 1.1832159566199234, 1.2041594578792296, 1.2247448713915892, 1.2449899597988734, 1.2649110640673518, 1.2845232578665131, 1.30384048104053, 1.3228756555322954, 1.3416407864998738, 1.3601470508735445, 1.3784048752090223, 1.3964240043768943, 1.4142135623730951, 1.4317821063276355, 1.4491376746189442, 1.466287829861518, 1.4832396974191329, 1.5, 1.5165750888103102, 1.5329709716755893, 1.549193338482967, 1.565247584249853, 1.5811388300841898, 1.5968719422671316, 1.61245154965971, 1.627882059609971, 1.6431676725154984, 1.6583123951777001, 1.6733200530681511, 1.6881943016134133, 1.7029386365926404, 1.7175564037317668, 1.7320508075688772, 1.746424919657298, 1.760681686165901, 1.7748239349298849, 1.788854381999832, 1.8027756377319946, 1.8165902124584952, 1.8303005217723127, 1.8439088914585775, 1.8574175621006712, 1.8708286933869709, 1.8841443681416774, 1.8973665961010278, 1.91049731745428, 1.9235384061671346, 1.9364916731037085, 1.9493588689617931, 1.9621416870348585, 1.9748417658131503, 1.9874606914351793, 2.0000000000000004, 2.012461179749811, 2.024845673131659, 2.0371548787463363, 2.04939015319192, 2.0615528128088303, 2.0736441353327724, 2.0856653614614213, 2.0976176963403033, 2.1095023109728985, 2.121320343559643, 2.1330729007701543, 2.144761058952722, 2.1563858652847827, 2.1679483388678804, 2.179449471770337, 2.1908902300206647, 2.2022715545545246, 2.2135943621178655, 2.224859546128699, 2.23606797749979, 2.2472205054244236], [0.0, 0.24494897427831783, 0.34641016151377546, 0.42426406871192857, 0.48989794855663565, 0.5477225575051662, 0.6000000000000001, 0.6480740698407861, 0.6928203230275509, 0.7348469228349535, 0.7745966692414834, 0.8124038404635961, 0.8485281374238571, 0.8831760866327848, 0.916515138991168, 0.9486832980505138, 0.9797958971132713, 1.0099504938362078, 1.0392304845413265, 1.0677078252031313, 1.0954451150103324, 1.1224972160321824, 1.148912529307606, 1.174734012447073, 1.2000000000000002, 1.2247448713915892, 1.2489995996796799, 1.2727922061357857, 1.2961481396815722, 1.319090595827292, 1.3416407864998738, 1.3638181696985856, 1.3856406460551018, 1.4071247279470291, 1.4282856857085702, 1.449137674618944, 1.469693845669907, 1.489966442575134, 1.50996688705415, 1.5297058540778357, 1.5491933384829668, 1.5684387141358125, 1.5874507866387546, 1.606237840420901, 1.6248076809271923, 1.6431676725154982, 1.661324772583615, 1.6792855623746665, 1.6970562748477143, 1.7146428199482247, 1.7320508075688774, 1.7492855684535904, 1.7663521732655696, 1.7832554500127011, 1.8, 1.8165902124584952, 1.833030277982336, 1.849324200890693, 1.8654758106177631, 1.8814887722226779, 1.8973665961010275, 1.9131126469708992, 1.928730152198591, 1.9442222095223582, 1.9595917942265426, 1.9748417658131499, 1.98997487421324, 2.004993765576342, 2.0199009876724157, 2.0346989949375804, 2.04939015319192, 2.0639767440550294, 2.078460969082653, 2.092844953645635, 2.1071307505705477, 2.121320343559643, 2.1354156504062627, 2.149418526020468, 2.1633307652783937, 2.177154105707724, 2.1908902300206647, 2.2045407685048604, 2.2181073012818837, 2.2315913604421396, 2.244994432064365, 2.2583179581272432, 2.2715633383201097, 2.2847319317591728, 2.297825058615212, 2.3108440016582685, 2.32379000772445, 2.3366642891095846, 2.349468024894146, 2.3622023622035435, 2.374868417407584, 2.3874672772626644, 2.4000000000000004, 2.412467616362964, 2.4248711305964283, 2.4372115213907883, 2.4494897427831783, 2.4617067250182347], [0.0, 0.2645751311064591, 0.3741657386773941, 0.45825756949558405, 0.5291502622129182, 0.5916079783099617, 0.6480740698407861, 0.7000000000000001, 0.7483314773547882, 0.7937253933193772, 0.8366600265340756, 0.8774964387392122, 0.9165151389911681, 0.9539392014169458, 0.9899494936611666, 1.0246950765959597, 1.0583005244258363, 1.0908712114635715, 1.1224972160321824, 1.1532562594670797, 1.1832159566199234, 1.2124355652982142, 1.2409673645990857, 1.2688577540449522, 1.2961481396815722, 1.3228756555322954, 1.3490737563232043, 1.374772708486752, 1.4000000000000001, 1.4247806848775009, 1.4491376746189437, 1.4730919862656235, 1.4966629547095764, 1.5198684153570665, 1.5427248620541514, 1.5652475842498528, 1.5874507866387544, 1.6093476939431082, 1.6309506430300091, 1.6522711641858308, 1.6733200530681511, 1.6941074346097418, 1.7146428199482249, 1.7349351572897471, 1.7549928774784245, 1.7748239349298847, 1.7944358444926363, 1.8138357147217055, 1.8330302779823362, 1.8520259177452134, 1.8708286933869709, 1.8894443627691186, 1.9078784028338915, 1.9261360284258224, 1.9442222095223582, 1.9621416870348585, 1.9798989873223332, 1.997498435543818, 2.0149441679609885, 2.0322401432901573, 2.0493901531919194, 2.0663978319771825, 2.083266665599966, 2.1, 2.1166010488516727, 2.133072900770154, 2.149418526020468, 2.1656407827707715, 2.181742422927143, 2.1977260975835913, 2.2135943621178655, 2.2293496809607953, 2.244994432064365, 2.260530911091463, 2.2759613353482084, 2.29128784747792, 2.3065125189341593, 2.32163735324878, 2.336664289109585, 2.3515952032609695, 2.366431913239847, 2.3811761799581315, 2.395829710142188, 2.41039415863879, 2.4248711305964283, 2.4392621835300936, 2.4535688292770597, 2.4677925358506134, 2.4819347291981715, 2.495996794869737, 2.5099800796022267, 2.5238858928247927, 2.5377155080899043, 2.551470164434615, 2.5651510676761324, 2.578759391645525, 2.5922962793631443, 2.6057628441590768, 2.619160170741759, 2.632489316217637, 2.6457513110645907, 2.6589471600616665], [0.0, 0.282842712474619, 0.39999999999999997, 0.48989794855663565, 0.565685424949238, 0.6324555320336759, 0.6928203230275509, 0.7483314773547882, 0.7999999999999999, 0.848528137423857, 0.8944271909999159, 0.938083151964686, 0.9797958971132713, 1.019803902718557, 1.058300524425836, 1.0954451150103321, 1.131370849898476, 1.16619037896906, 1.2, 1.2328828005937953, 1.2649110640673518, 1.2961481396815722, 1.3266499161421599, 1.3564659966250536, 1.3856406460551018, 1.4142135623730951, 1.4422205101855958, 1.469693845669907, 1.4966629547095764, 1.5231546211727818, 1.5491933384829666, 1.5748015748023623, 1.5999999999999999, 1.624807680927192, 1.6492422502470643, 1.6733200530681511, 1.697056274847714, 1.7204650534085253, 1.7435595774162695, 1.7663521732655694, 1.7888543819998317, 1.8110770276274835, 1.8330302779823362, 1.8547236990991405, 1.876166303929372, 1.8973665961010273, 1.9183326093250879, 1.9390719429665315, 1.9595917942265426, 1.979898987322333, 2.0, 2.0199009876724157, 2.039607805437114, 2.0591260281974004, 2.078460969082653, 2.0976176963403033, 2.116601048851672, 2.1354156504062622, 2.1540659228538015, 2.172556098240043, 2.1908902300206643, 2.209072203437452, 2.2271057451320084, 2.244994432064365, 2.262741699796952, 2.2803508501982757, 2.2978250586152114, 2.315167380558045, 2.33238075793812, 2.349468024894146, 2.3664319132398464, 2.3832750575625967, 2.4, 2.4166091947189146, 2.4331050121192876, 2.449489742783178, 2.4657656011875906, 2.4819347291981715, 2.4979991993593593, 2.513961017995307, 2.5298221281347035, 2.545584412271571, 2.5612496949731396, 2.576819745345025, 2.5922962793631443, 2.6076809620810595, 2.6229754097208002, 2.6381811916545836, 2.6532998322843198, 2.6683328128252666, 2.6832815729997477, 2.698147512646408, 2.7129319932501073, 2.727636339397171, 2.7422618401604177, 2.756809750418044, 2.7712812921102037, 2.785677655436824, 2.8, 2.814249455894058, 2.8284271247461903, 2.8425340807103794], [0.0, 0.3, 0.4242640687119285, 0.5196152422706632, 0.6, 0.6708203932499369, 0.7348469228349535, 0.7937253933193772, 0.848528137423857, 0.8999999999999999, 0.9486832980505138, 0.99498743710662, 1.0392304845413265, 1.0816653826391969, 1.1224972160321824, 1.1618950038622249, 1.2, 1.236931687685298, 1.2727922061357855, 1.307669683062202, 1.3416407864998738, 1.374772708486752, 1.407124727947029, 1.438749456993816, 1.469693845669907, 1.5, 1.5297058540778354, 1.5588457268119895, 1.5874507866387544, 1.6155494421403513, 1.6431676725154982, 1.6703293088490065, 1.697056274847714, 1.7233687939614086, 1.7492855684535902, 1.7748239349298847, 1.7999999999999998, 1.8248287590894658, 1.849324200890693, 1.8734993995195195, 1.8973665961010275, 1.9209372712298547, 1.9442222095223582, 1.9672315572906, 1.98997487421324, 2.0124611797498106, 2.0346989949375804, 2.056696380120313, 2.078460969082653, 2.1, 2.1213203435596424, 2.142428528562855, 2.1633307652783937, 2.1840329667841556, 2.2045407685048604, 2.224859546128699, 2.244994432064365, 2.264950330581225, 2.2847319317591723, 2.3043437243605824, 2.3237900077244498, 2.3430749027719964, 2.362202362203543, 2.3811761799581315, 2.4, 2.4186773244895647, 2.437211521390788, 2.455605831561735, 2.473863375370596, 2.4919871588754225, 2.5099800796022267, 2.5278449319529073, 2.545584412271571, 2.563201123595259, 2.580697580112788, 2.598076211353316, 2.615339366124404, 2.6324893162176366, 2.6495282598983545, 2.6664583251946765, 2.6832815729997477, 2.7, 2.716615541441225, 2.7331300737432893, 2.749545416973504, 2.765863337187866, 2.7820855486487113, 2.7982137159266447, 2.814249455894058, 2.830194339616981, 2.846049894151541, 2.8618176042508368, 2.877498913987632, 2.8930952282978866, 2.9086079144497976, 2.9240383034426887, 2.939387691339814, 2.9546573405388314, 2.9698484809834995, 2.98496231131986, 3.0, 3.0149626863362675], [0.0, 0.31622776601683794, 0.4472135954999579, 0.5477225575051662, 0.6324555320336759, 0.7071067811865476, 0.7745966692414834, 0.8366600265340756, 0.8944271909999159, 0.9486832980505138, 1.0, 1.0488088481701516, 1.0954451150103324, 1.140175425099138, 1.1832159566199232, 1.224744871391589, 1.2649110640673518, 1.3038404810405297, 1.3416407864998738, 1.3784048752090223, 1.4142135623730951, 1.449137674618944, 1.4832396974191326, 1.5165750888103102, 1.5491933384829668, 1.5811388300841898, 1.61245154965971, 1.6431676725154984, 1.6733200530681511, 1.7029386365926402, 1.7320508075688772, 1.760681686165901, 1.7888543819998317, 1.8165902124584952, 1.8439088914585775, 1.8708286933869707, 1.8973665961010275, 1.9235384061671346, 1.949358868961793, 1.97484176581315, 2.0, 2.024845673131659, 2.04939015319192, 2.073644135332772, 2.0976176963403033, 2.1213203435596424, 2.1447610589527217, 2.16794833886788, 2.1908902300206647, 2.2135943621178655, 2.23606797749979, 2.2583179581272432, 2.280350850198276, 2.302172886644268, 2.32379000772445, 2.345207879911715, 2.3664319132398464, 2.3874672772626644, 2.4083189157584592, 2.4289915602982237, 2.449489742783178, 2.4698178070456938, 2.4899799195977463, 2.5099800796022267, 2.5298221281347035, 2.5495097567963922, 2.569046515733026, 2.588435821108957, 2.6076809620810595, 2.6267851073127395, 2.6457513110645907, 2.6645825188948455, 2.6832815729997477, 2.701851217221259, 2.7202941017470885, 2.7386127875258306, 2.7568097504180447, 2.7748873851023217, 2.7928480087537886, 2.8106938645110393, 2.8284271247461903, 2.8460498941515415, 2.863564212655271, 2.8809720581775866, 2.898275349237888, 2.9154759474226504, 2.932575659723036, 2.9495762407505253, 2.9664793948382653, 2.9832867780352594, 3.0, 3.0166206257996713, 3.0331501776206204, 3.0495901363953815, 3.0659419433511785, 3.082207001484488, 3.0983866769659336, 3.1144823004794877, 3.1304951684997055, 3.146426544510455, 3.1622776601683795, 3.178049716414141], [0.0, 0.33166247903554, 0.469041575982343, 0.574456264653803, 0.66332495807108, 0.7416198487095664, 0.8124038404635961, 0.8774964387392122, 0.938083151964686, 0.99498743710662, 1.0488088481701516, 1.1, 1.148912529307606, 1.1958260743101399, 1.2409673645990857, 1.284523257866513, 1.32664991614216, 1.3674794331177345, 1.407124727947029, 1.4456832294800963, 1.4832396974191329, 1.5198684153570665, 1.5556349186104048, 1.5905973720586868, 1.6248076809271923, 1.6583123951777001, 1.6911534525287766, 1.7233687939614089, 1.7549928774784245, 1.7860571099491753, 1.816590212458495, 1.846618531261939, 1.876166303929372, 1.9052558883257653, 1.9339079605813718, 1.9621416870348585, 1.98997487421324, 2.017424100183202, 2.0445048300260877, 2.0712315177207983, 2.0976176963403033, 2.1236760581595306, 2.149418526020468, 2.1748563170931545, 2.2, 2.224859546128699, 2.249444375840399, 2.273763400180415, 2.297825058615212, 2.32163735324878, 2.345207879911715, 2.368543856465403, 2.3916521486202797, 2.4145392935299275, 2.4372115213907883, 2.459674775249769, 2.4819347291981715, 2.503996805109783, 2.525866188063018, 2.5475478405713994, 2.569046515733026, 2.5903667693977237, 2.6115129714401193, 2.632489316217637, 2.65329983228432, 2.6739483914241875, 2.6944387170614963, 2.714774392099646, 2.734958866235469, 2.7549954627911823, 2.774887385102322, 2.7946377224964243, 2.814249455894058, 2.833725463060951, 2.8530685235374214, 2.8722813232690148, 2.8913664589601926, 2.91032644217105, 2.9291637031753623, 2.9478805945967355, 2.9664793948382657, 2.9849623113198605, 3.003331483536242, 3.0215889859476257, 3.039736830714133, 3.0577769702841313, 3.07571129984594, 3.093541659651604, 3.1112698372208096, 3.1288975694324033, 3.146426544510455, 3.1638584039112754, 3.1811947441173736, 3.1984371183438958, 3.2155870381627056, 3.2326459750489227, 3.2496153618543846, 3.2664965942122155, 3.283291031876401, 3.3000000000000007, 3.3166247903554003, 3.333166662499792], [0.0, 0.3464101615137755, 0.48989794855663565, 0.6000000000000002, 0.692820323027551, 0.7745966692414835, 0.8485281374238571, 0.9165151389911681, 0.9797958971132713, 1.0392304845413265, 1.0954451150103324, 1.148912529307606, 1.2000000000000004, 1.2489995996796799, 1.2961481396815722, 1.3416407864998738, 1.385640646055102, 1.4282856857085702, 1.4696938456699071, 1.5099668870541503, 1.549193338482967, 1.5874507866387546, 1.6248076809271923, 1.6613247725836153, 1.6970562748477143, 1.7320508075688776, 1.7663521732655698, 1.8000000000000003, 1.8330302779823362, 1.8654758106177634, 1.8973665961010278, 1.9287301521985913, 1.9595917942265426, 1.9899748742132404, 2.019900987672416, 2.04939015319192, 2.078460969082653, 2.107130750570548, 2.1354156504062627, 2.163330765278394, 2.1908902300206647, 2.2181073012818837, 2.2449944320643653, 2.2715633383201097, 2.297825058615212, 2.32379000772445, 2.3494680248941466, 2.374868417407584, 2.400000000000001, 2.4248711305964283, 2.4494897427831783, 2.473863375370597, 2.4979991993593598, 2.521904042583699, 2.5455844122715714, 2.5690465157330262, 2.5922962793631443, 2.6153393661244047, 2.6381811916545845, 2.6608269391300143, 2.6832815729997477, 2.705549851693737, 2.727636339397171, 2.7495454169735045, 2.771281292110204, 2.7928480087537886, 2.8142494558940583, 2.8354893757515653, 2.8565713714171403, 2.8774989139876324, 2.8982753492378883, 2.918903903865285, 2.9393876913398143, 2.9597297173897488, 2.979932885150268, 3.0000000000000004, 3.0199337741083006, 3.039736830714133, 3.0594117081556718, 3.078960863668131, 3.098386676965934, 3.1176914536239795, 3.136877428271625, 3.1559467676119004, 3.174901573277509, 3.193743884534263, 3.2124756808418025, 3.231098884280703, 3.2496153618543846, 3.2680269276736387, 3.286335345030997, 3.3045423283716615, 3.3226495451672307, 3.340658617698014, 3.3585711247493335, 3.3763886032268267, 3.3941125496954285, 3.411744421846397, 3.4292856398964497, 3.4467375879228177, 3.4641016151377553, 3.481379037105843], [0.0, 0.36055512754639896, 0.5099019513592785, 0.6244997998398399, 0.7211102550927979, 0.806225774829855, 0.8831760866327848, 0.9539392014169458, 1.019803902718557, 1.0816653826391969, 1.140175425099138, 1.1958260743101399, 1.2489995996796799, 1.3000000000000003, 1.3490737563232043, 1.396424004376894, 1.4422205101855958, 1.4866068747318506, 1.5297058540778357, 1.5716233645501714, 1.61245154965971, 1.6522711641858308, 1.6911534525287764, 1.7291616465790585, 1.7663521732655696, 1.8027756377319948, 1.8384776310850237, 1.8734993995195197, 1.9078784028338915, 1.94164878389476, 1.9748417658131499, 2.0074859899884734, 2.039607805437114, 2.0712315177207983, 2.102379604162864, 2.1330729007701543, 2.1633307652783937, 2.193171219946131, 2.222611077089287, 2.2516660498395407, 2.280350850198276, 2.3086792761230397, 2.336664289109585, 2.364318083507378, 2.3916521486202797, 2.4186773244895647, 2.445403852127497, 2.471841418861655, 2.4979991993593598, 2.5238858928247927, 2.5495097567963927, 2.574878637916747, 2.6000000000000005, 2.624880949681338, 2.6495282598983545, 2.673948391424188, 2.6981475126464085, 2.72213151776324, 2.7459060435491964, 2.7694764848252458, 2.792848008753788, 2.816025568065745, 2.839013913315678, 2.861817604250837, 2.8844410203711917, 2.9068883707497264, 2.9291637031753623, 2.951270912674741, 2.973213749463701, 2.994995826374388, 3.0166206257996717, 3.0380915061926625, 3.0594117081556713, 3.0805843601498726, 3.1016124838541645, 3.122498999199199, 3.1432467291003428, 3.1638584039112754, 3.1843366656181322, 3.204684071792413, 3.22490309931942, 3.2449961479175906, 3.264965543462902, 3.2848135411313684, 3.3045423283716615, 3.3241540277189325, 3.343650699460098, 3.363034344160048, 3.3823069050575527, 3.4014702703389896, 3.420526275297414, 3.439476704383968, 3.458323293158117, 3.4770677301427426, 3.4957116585897072, 3.5142566781611158, 3.532704346531139, 3.5510561809129415, 3.5693136595149495, 3.58747822293042, 3.6055512754639896, 3.6235341863986883], [0.0, 0.37416573867739417, 0.529150262212918, 0.6480740698407861, 0.7483314773547883, 0.8366600265340756, 0.916515138991168, 0.9899494936611666, 1.058300524425836, 1.1224972160321824, 1.1832159566199232, 1.2409673645990857, 1.2961481396815722, 1.3490737563232043, 1.4, 1.4491376746189437, 1.4966629547095767, 1.5427248620541512, 1.5874507866387544, 1.6309506430300091, 1.6733200530681511, 1.7146428199482247, 1.7549928774784245, 1.7944358444926363, 1.833030277982336, 1.8708286933869707, 1.9078784028338913, 1.9442222095223582, 1.9798989873223332, 2.0149441679609885, 2.0493901531919194, 2.083266665599966, 2.116601048851672, 2.149418526020468, 2.181742422927143, 2.2135943621178655, 2.244994432064365, 2.2759613353482084, 2.3065125189341593, 2.3366642891095846, 2.3664319132398464, 2.395829710142188, 2.4248711305964283, 2.453568829277059, 2.4819347291981715, 2.5099800796022262, 2.5377155080899043, 2.565151067676132, 2.5922962793631443, 2.619160170741759, 2.6457513110645907, 2.672077843177478, 2.6981475126464085, 2.7239676943752476, 2.749545416973504, 2.7748873851023217, 2.8, 2.824889378365107, 2.8495613697550017, 2.8740215726399825, 2.8982753492378874, 2.9223278392404914, 2.9461839725312466, 2.9698484809834995, 2.9933259094191533, 3.016620625799671, 3.0397368307141326, 3.062678566222711, 3.0854497241083023, 3.1080540535840107, 3.1304951684997055, 3.152776554086889, 3.1749015732775088, 3.196873472629156, 3.218695387886216, 3.24037034920393, 3.2619012860600183, 3.283291031876401, 3.3045423283716615, 3.3256578296631782, 3.3466401061363023, 3.3674916480965473, 3.3882148692194836, 3.408812109811862, 3.4292856398964493, 3.449637662132068, 3.4698703145794947, 3.4899856733230297, 3.509985754956849, 3.529872518944558, 3.5496478698597693, 3.5693136595149495, 3.5888716889852725, 3.6083237105337433, 3.627671429443411, 3.6469165057620936, 3.666060555964672, 3.685105154537656, 3.704051835490427, 3.722902093797257, 3.7416573867739413, 3.7603191353926335], [0.0, 0.38729833462074165, 0.5477225575051661, 0.6708203932499369, 0.7745966692414833, 0.8660254037844386, 0.9486832980505138, 1.0246950765959597, 1.0954451150103321, 1.1618950038622249, 1.224744871391589, 1.284523257866513, 1.3416407864998738, 1.396424004376894, 1.4491376746189437, 1.4999999999999998, 1.5491933384829666, 1.5968719422671311, 1.6431676725154982, 1.6881943016134133, 1.7320508075688772, 1.7748239349298847, 1.816590212458495, 1.857417562100671, 1.8973665961010275, 1.9364916731037083, 1.9748417658131499, 2.0124611797498106, 2.0493901531919194, 2.085665361461421, 2.1213203435596424, 2.1563858652847823, 2.1908902300206643, 2.224859546128699, 2.258317958127243, 2.29128784747792, 2.3237900077244498, 2.355843797877949, 2.3874672772626644, 2.4186773244895647, 2.449489742783178, 2.479919353527449, 2.5099800796022267, 2.5396850198400585, 2.569046515733026, 2.5980762113533156, 2.626785107312739, 2.6551836094703507, 2.6832815729997477, 2.7110883423451915, 2.7386127875258306, 2.765863337187866, 2.792848008753788, 2.819574435974337, 2.846049894151541, 2.8722813232690143, 2.8982753492378874, 2.924038303442689, 2.9495762407505253, 2.974894956128703, 2.9999999999999996, 3.0248966924508345, 3.049590136395381, 3.074085229787879, 3.098386676965933, 3.1224989991991987, 3.1464265445104544, 3.1701734968294715, 3.1937438845342623, 3.217141588429082, 3.24037034920393, 3.2634337744161437, 3.2863353450309964, 3.309078421554859, 3.3316662497915357, 3.3541019662496843, 3.3763886032268267, 3.3985290935932855, 3.420526275297414, 3.442382895611701, 3.4641016151377544, 3.485685011586675, 3.5071355833500366, 3.5284557528754696, 3.5496478698597693, 3.5707142142714248, 3.591656999213594, 3.6124783736376886, 3.63318042491699, 3.6537651812890215, 3.674234614174767, 3.694590640382233, 3.714835124201342, 3.7349698793966195, 3.7549966711037173, 3.7749172176353745, 3.794733192202055, 3.8144462245521304, 3.8340579025361623, 3.853569773599539, 3.8729833462074166, 3.892300091205713], [0.0, 0.4, 0.565685424949238, 0.692820323027551, 0.8, 0.894427190999916, 0.9797958971132713, 1.0583005244258363, 1.131370849898476, 1.2, 1.2649110640673518, 1.32664991614216, 1.385640646055102, 1.4422205101855958, 1.4966629547095767, 1.5491933384829666, 1.6, 1.6492422502470643, 1.697056274847714, 1.7435595774162698, 1.788854381999832, 1.8330302779823362, 1.876166303929372, 1.918332609325088, 1.9595917942265426, 2.0, 2.039607805437114, 2.078460969082653, 2.1166010488516727, 2.154065922853802, 2.1908902300206643, 2.227105745132009, 2.262741699796952, 2.297825058615212, 2.3323807579381204, 2.3664319132398464, 2.4, 2.433105012119288, 2.4657656011875906, 2.4979991993593598, 2.5298221281347035, 2.5612496949731396, 2.5922962793631443, 2.6229754097208002, 2.65329983228432, 2.6832815729997477, 2.7129319932501073, 2.7422618401604177, 2.771281292110204, 2.8000000000000003, 2.8284271247461903, 2.8565713714171403, 2.8844410203711917, 2.9120439557122078, 2.939387691339814, 2.9664793948382653, 2.9933259094191533, 3.0199337741083, 3.0463092423455636, 3.0724582991474434, 3.098386676965933, 3.1240998703626617, 3.149603149604724, 3.1749015732775088, 3.2, 3.2249030993194197, 3.249615361854384, 3.2741411087489802, 3.2984845004941286, 3.32264954516723, 3.3466401061363023, 3.3704599092705436, 3.394112549695428, 3.4176014981270124, 3.4409301068170506, 3.464101615137755, 3.4871191548325395, 3.509985754956849, 3.532704346531139, 3.5552777669262356, 3.577708763999664, 3.6, 3.622154055254967, 3.6441734316577197, 3.6660605559646724, 3.687817782917155, 3.709447398198282, 3.7309516212355263, 3.752332607858744, 3.7735924528226414, 3.794733192202055, 3.8157568056677826, 3.836665218650176, 3.8574603043971822, 3.8781438859330635, 3.8987177379235853, 3.9191835884530852, 3.9395431207184424, 3.9597979746446663, 3.9799497484264803, 4.0, 4.019950248448357], [0.0, 0.41231056256176607, 0.58309518948453, 0.7141428428542851, 0.8246211251235321, 0.9219544457292888, 1.0099504938362078, 1.0908712114635715, 1.16619037896906, 1.236931687685298, 1.3038404810405297, 1.3674794331177345, 1.4282856857085702, 1.4866068747318506, 1.5427248620541512, 1.5968719422671311, 1.6492422502470643, 1.7, 1.7492855684535902, 1.797220075561143, 1.8439088914585775, 1.8894443627691184, 1.9339079605813716, 1.977371993328519, 2.0199009876724157, 2.0615528128088303, 2.102379604162864, 2.142428528562855, 2.181742422927143, 2.220360331117452, 2.258317958127243, 2.2956480566497994, 2.33238075793812, 2.3685438564654024, 2.4041630560342617, 2.4392621835300936, 2.473863375370596, 2.5079872407968904, 2.541653005427767, 2.574878637916747, 2.6076809620810595, 2.6400757564888173, 2.672077843177478, 2.7037011669191546, 2.734958866235469, 2.765863337187866, 2.7964262908219126, 2.826658805020514, 2.8565713714171403, 2.8861739379323623, 2.9154759474226504, 2.944486372867092, 2.973213749463701, 3.001666203960727, 3.0298514815086235, 3.0577769702841313, 3.0854497241083023, 3.1128764832546763, 3.1400636936215167, 3.167017524422623, 3.1937438845342623, 3.2202484376209237, 3.246536616149585, 3.2726136343907144, 3.2984845004941286, 3.324154027718932, 3.3496268448888453, 3.374907406137241, 3.4, 3.424908757908742, 3.4496376621320683, 3.4741905532080417, 3.4985711369071804, 3.522782990761707, 3.5468295701936396, 3.570714214271425, 3.594440151122286, 3.6180105030251086, 3.6414282912066254, 3.664696440361739, 3.687817782917155, 3.710795063055895, 3.733630940518894, 3.7563279941985894, 3.778888725538237, 3.8013155617496426, 3.8236108588610325, 3.845776904605882, 3.867815921162743, 3.8897300677553446, 3.9115214431215892, 3.9331920878594273, 3.954743986657038, 3.976179070414209, 3.9974992182613374, 4.018706259482023, 4.039801975344831, 4.060788100849391, 4.08166632639171, 4.102438299353203, 4.123105625617661, 4.1436698710201325], [0.0, 0.4242640687119285, 0.6, 0.7348469228349536, 0.848528137423857, 0.9486832980505139, 1.0392304845413265, 1.1224972160321824, 1.2, 1.2727922061357855, 1.3416407864998738, 1.407124727947029, 1.4696938456699071, 1.5297058540778357, 1.5874507866387544, 1.6431676725154982, 1.697056274847714, 1.7492855684535902, 1.8, 1.8493242008906932, 1.8973665961010278, 1.9442222095223582, 1.98997487421324, 2.0346989949375804, 2.078460969082653, 2.121320343559643, 2.1633307652783937, 2.2045407685048604, 2.244994432064365, 2.2847319317591728, 2.32379000772445, 2.3622023622035435, 2.4, 2.4372115213907883, 2.4738633753705965, 2.5099800796022267, 2.545584412271571, 2.5806975801127883, 2.615339366124404, 2.6495282598983545, 2.6832815729997477, 2.716615541441225, 2.749545416973504, 2.782085548648711, 2.814249455894058, 2.846049894151541, 2.877498913987632, 2.9086079144497976, 2.9393876913398143, 2.9698484809834995, 3.0, 3.029851481508624, 3.0594117081556713, 3.0886890422961004, 3.1176914536239795, 3.146426544510455, 3.1749015732775088, 3.2031234756093934, 3.2310988842807027, 3.2588341473600644, 3.2863353450309964, 3.3136083051561784, 3.340658617698013, 3.3674916480965473, 3.394112549695428, 3.420526275297414, 3.4467375879228173, 3.4727510708370675, 3.4985711369071804, 3.5242020373412193, 3.5496478698597698, 3.5749125863438955, 3.6, 3.6249137920783716, 3.6496575181789317, 3.6742346141747673, 3.6986484017813863, 3.722902093797257, 3.7469987990390394, 3.7709415269929605, 3.7947331922020555, 3.8183766184073566, 3.84187454245971, 3.8652296180175374, 3.8884444190447165, 3.9115214431215897, 3.9344631145812006, 3.957271787481876, 3.97994974842648, 4.0024992192379, 4.024922359499621, 4.047221268969612, 4.069397989875161, 4.091454509095757, 4.113392760240627, 4.135214625627066, 4.156921938165306, 4.178516483155236, 4.2, 4.221374183841087, 4.242640687119286, 4.263801121065569], [0.0, 0.43588989435406744, 0.6164414002968976, 0.7549834435270751, 0.8717797887081349, 0.9746794344808966, 1.0677078252031313, 1.1532562594670797, 1.2328828005937953, 1.307669683062202, 1.3784048752090223, 1.4456832294800963, 1.5099668870541503, 1.5716233645501714, 1.6309506430300091, 1.6881943016134133, 1.7435595774162698, 1.797220075561143, 1.8493242008906932, 1.9000000000000004, 1.9493588689617931, 1.9974984355438181, 2.0445048300260877, 2.0904544960366875, 2.1354156504062627, 2.179449471770337, 2.2226110770892875, 2.2649503305812253, 2.3065125189341593, 2.3473389188611007, 2.3874672772626644, 2.4269322199023198, 2.4657656011875906, 2.503996805109783, 2.5416530054277673, 2.5787593916455256, 2.615339366124404, 2.651414716712571, 2.687005768508881, 2.7221315177632404, 2.7568097504180447, 2.791057147390573, 2.8248893783651075, 2.8583211855912904, 2.8913664589601926, 2.924038303442689, 2.956349099818897, 2.9883105594967874, 3.0199337741083006, 3.051229260478472, 3.082207001484489, 3.1128764832546767, 3.1432467291003428, 3.1733263305244868, 3.203123475609394, 3.232645975048923, 3.2619012860600183, 3.290896534380867, 3.319638534539567, 3.3481338085566414, 3.3763886032268267, 3.4044089061098406, 3.432200460346103, 3.4597687784012394, 3.4871191548325395, 3.5142566781611158, 3.541186241925155, 3.567912554982255, 3.594440151122286, 3.6207733980463352, 3.6469165057620945, 3.672873534441392, 3.6986484017813863, 3.7242448899072147, 3.749666651850535, 3.7749172176353754, 3.8000000000000007, 3.824918299781056, 3.8496753109840323, 3.874274125562104, 3.8987177379235862, 3.9230090491866068, 3.947150871198111, 3.9711459303329564, 3.9949968710876362, 4.018706259482024, 4.042276586281548, 4.065710270051225, 4.0890096600521755, 4.112177038990418, 4.135214625627067, 4.158124577258358, 4.180908992073375, 4.203569911396741, 4.226109321823088, 4.2485291572496005, 4.270831300812525, 4.293017586733137, 4.315089802078284, 4.337049688440289, 4.358898943540674, 4.380639222761903], [0.0, 0.447213595499958, 0.6324555320336759, 0.7745966692414835, 0.894427190999916, 1.0000000000000002, 1.0954451150103324, 1.1832159566199234, 1.2649110640673518, 1.3416407864998738, 1.4142135623730951, 1.4832396974191329, 1.549193338482967, 1.61245154965971, 1.6733200530681511, 1.7320508075688772, 1.788854381999832, 1.8439088914585775, 1.8973665961010278, 1.9493588689617931, 2.0000000000000004, 2.04939015319192, 2.0976176963403033, 2.144761058952722, 2.1908902300206647, 2.23606797749979, 2.280350850198276, 2.3237900077244507, 2.366431913239847, 2.4083189157584592, 2.4494897427831783, 2.489979919597747, 2.5298221281347035, 2.5690465157330262, 2.60768096208106, 2.6457513110645907, 2.6832815729997477, 2.720294101747089, 2.7568097504180447, 2.7928480087537886, 2.8284271247461903, 2.863564212655271, 2.8982753492378883, 2.932575659723036, 2.9664793948382657, 3.0, 3.0331501776206204, 3.0659419433511785, 3.098386676965934, 3.130495168499706, 3.1622776601683795, 3.193743884534263, 3.22490309931942, 3.255764119219942, 3.286335345030997, 3.3166247903554003, 3.3466401061363023, 3.3763886032268267, 3.405877273185281, 3.4351128074635335, 3.4641016151377544, 3.492849839314596, 3.521363372331802, 3.5496478698597698, 3.577708763999664, 3.605551275463989, 3.6331804249169903, 3.6606010435446255, 3.687817782917155, 3.7148351242013424, 3.7416573867739418, 3.768288736283355, 3.7947331922020555, 3.82099463490856, 3.847076812334269, 3.872983346207417, 3.8987177379235862, 3.924283374069717, 3.9496835316263006, 3.9749213828703587, 4.000000000000001, 4.024922359499622, 4.049691346263318, 4.0743097574926725, 4.09878030638384, 4.123105625617661, 4.147288270665545, 4.171330722922843, 4.1952353926806065, 4.219004621945797, 4.242640687119286, 4.266145801540309, 4.289522117905444, 4.312771730569565, 4.335896677735761, 4.358898943540674, 4.3817804600413295, 4.404543109109049, 4.427188724235731, 4.449719092257398, 4.47213595499958, 4.494441010848847], [0.0, 0.45825756949558405, 0.6480740698407861, 0.7937253933193773, 0.9165151389911681, 1.02469507659596, 1.1224972160321824, 1.2124355652982142, 1.2961481396815722, 1.374772708486752, 1.449137674618944, 1.5198684153570665, 1.5874507866387546, 1.6522711641858308, 1.7146428199482247, 1.7748239349298847, 1.8330302779823362, 1.8894443627691184, 1.9442222095223582, 1.9974984355438181, 2.04939015319192, 2.1, 2.149418526020468, 2.1977260975835913, 2.244994432064365, 2.2912878474779204, 2.336664289109585, 2.381176179958132, 2.4248711305964283, 2.4677925358506134, 2.5099800796022267, 2.551470164434615, 2.5922962793631443, 2.632489316217637, 2.672077843177478, 2.711088342345192, 2.749545416973504, 2.787471972953271, 2.824889378365107, 2.861817604250837, 2.898275349237888, 2.934280150224242, 2.9698484809835, 3.004995840263344, 3.039736830714133, 3.0740852297878796, 3.108054053584011, 3.1416556144810017, 3.174901573277509, 3.2078029864690882, 3.2403703492039306, 3.272613634390715, 3.3045423283716615, 3.336165463522456, 3.3674916480965478, 3.398529093593286, 3.4292856398964493, 3.459768778401239, 3.48998567332303, 3.5199431813596083, 3.5496478698597693, 3.5791060336346563, 3.608323710533743, 3.6373066958946425, 3.6660605559646724, 3.6945906403822333, 3.722902093797257, 3.7509998667022106, 3.778888725538237, 3.8065732621348563, 3.834057902536163, 3.861346915261565, 3.8884444190447165, 3.915354390090379, 3.9420806688854046, 3.968626966596886, 3.9949968710876362, 4.02119385257662, 4.047221268969613, 4.07308237088326, 4.09878030638384, 4.124318125460256, 4.149698784249287, 4.174925149029621, 4.2, 4.224926034855522, 4.249705872175156, 4.274342054632503, 4.298837052040936, 4.323193264243457, 4.347413023856832, 4.371498598878879, 4.3954521951671826, 4.419275958796871, 4.442971978304612, 4.466542286825459, 4.48998886412873, 4.513313638558704, 4.536518488885503, 4.559605246071199, 4.582575694955841, 4.605431575867782], [0.0, 0.469041575982343, 0.6633249580710799, 0.8124038404635961, 0.938083151964686, 1.0488088481701516, 1.148912529307606, 1.2409673645990857, 1.3266499161421599, 1.407124727947029, 1.4832396974191326, 1.5556349186104048, 1.6248076809271923, 1.6911534525287764, 1.7549928774784245, 1.816590212458495, 1.876166303929372, 1.9339079605813716, 1.98997487421324, 2.0445048300260877, 2.0976176963403033, 2.149418526020468, 2.2, 2.249444375840399, 2.297825058615212, 2.345207879911715, 2.3916521486202797, 2.4372115213907883, 2.4819347291981715, 2.5258661880630178, 2.569046515733026, 2.6115129714401193, 2.6532998322843198, 2.6944387170614963, 2.734958866235469, 2.7748873851023217, 2.814249455894058, 2.8530685235374214, 2.891366458960192, 2.9291637031753623, 2.9664793948382653, 3.0033314835362415, 3.039736830714133, 3.0757112998459397, 3.1112698372208096, 3.1464265445104544, 3.1811947441173736, 3.2155870381627056, 3.2496153618543846, 3.283291031876401, 3.3166247903554003, 3.3496268448888458, 3.3823069050575527, 3.414674215792775, 3.4467375879228173, 3.4785054261852175, 3.509985754956849, 3.5411862419251547, 3.5721142198983507, 3.602776706930364, 3.63318042491699, 3.6633318168028404, 3.6932370625238775, 3.722902093797257, 3.752332607858744, 3.7815340802378072, 3.81051177665153, 3.8392707640904935, 3.867815921162743, 3.8961519477556315, 3.924283374069717, 3.952214569073901, 3.97994974842648, 4.007492981902776, 4.034848200366403, 4.06201920231798, 4.0890096600521755, 4.115823125451336, 4.1424630354415966, 4.168932717135166, 4.1952353926806065, 4.221374183841087, 4.247352116319061, 4.273172123844299, 4.298837052040936, 4.324349662087931, 4.349712634186309, 4.374928570845472, 4.4, 4.424929377967517, 4.449719092257398, 4.474371464239419, 4.498888751680798, 4.523273151159457, 4.54752680036083, 4.571651780264984, 4.595650117230424, 4.61952378498044, 4.64327470649756, 4.666904755831214, 4.69041575982343, 4.713809499757071], [0.0, 0.479583152331272, 0.6782329983125268, 0.8306623862918077, 0.959166304662544, 1.072380529476361, 1.174734012447073, 1.2688577540449522, 1.3564659966250536, 1.438749456993816, 1.5165750888103102, 1.5905973720586868, 1.6613247725836153, 1.7291616465790585, 1.7944358444926363, 1.857417562100671, 1.918332609325088, 1.977371993328519, 2.0346989949375804, 2.0904544960366875, 2.144761058952722, 2.1977260975835913, 2.249444375840399, 2.3000000000000003, 2.349468024894146, 2.39791576165636, 2.4454038521274972, 2.491987158875423, 2.5377155080899043, 2.582634314028992, 2.6267851073127395, 2.670205984563738, 2.7129319932501073, 2.754995462791183, 2.7964262908219126, 2.8372521918222215, 2.877498913987632, 2.917190429162965, 2.956349099818897, 2.994995826374388, 3.0331501776206204, 3.0708305065568178, 3.108054053584011, 3.1448370387032774, 3.1811947441173736, 3.2171415884290826, 3.252691193458119, 3.2878564445547194, 3.3226495451672307, 3.357082066318904, 3.3911649915626345, 3.4249087579087423, 3.458323293158117, 3.491418050019219, 3.5242020373412197, 3.5566838487557484, 3.5888716889852725, 3.620773398046335, 3.6523964735499352, 3.6837480912787726, 3.714835124201342, 3.745664160065609, 3.7762415176998414, 3.8065732621348563, 3.836665218650176, 3.866522985836241, 3.8961519477556315, 3.9255572852781047, 3.954743986657038, 3.9837168574084183, 4.012480529547776, 4.041039470235351, 4.069397989875161, 4.097560249709576, 4.125530268947254, 4.153311931459037, 4.180908992073375, 4.2083250825001635, 4.235563716909475, 4.262628297189424, 4.289522117905444, 4.316248370981448, 4.342810150121694, 4.369210454990696, 4.3954521951671826, 4.421538193886829, 4.447471191587417, 4.473253849269009, 4.498888751680798, 4.524378410345448, 4.549725266430931, 4.57493169347915, 4.6000000000000005, 4.624932431938872, 4.649731175025068, 4.674398357008098, 4.698936049788292, 4.723346271447818, 4.747630988187688, 4.77179211617606, 4.79583152331272, 4.819751030914357], [0.0, 0.48989794855663565, 0.6928203230275509, 0.8485281374238571, 0.9797958971132713, 1.0954451150103324, 1.2000000000000002, 1.2961481396815722, 1.3856406460551018, 1.469693845669907, 1.5491933384829668, 1.6248076809271923, 1.6970562748477143, 1.7663521732655696, 1.833030277982336, 1.8973665961010275, 1.9595917942265426, 2.0199009876724157, 2.078460969082653, 2.1354156504062627, 2.1908902300206647, 2.244994432064365, 2.297825058615212, 2.349468024894146, 2.4000000000000004, 2.4494897427831783, 2.4979991993593598, 2.5455844122715714, 2.5922962793631443, 2.638181191654584, 2.6832815729997477, 2.727636339397171, 2.7712812921102037, 2.8142494558940583, 2.8565713714171403, 2.898275349237888, 2.939387691339814, 2.979932885150268, 3.0199337741083, 3.0594117081556713, 3.0983866769659336, 3.136877428271625, 3.174901573277509, 3.212475680841802, 3.2496153618543846, 3.2863353450309964, 3.32264954516723, 3.358571124749333, 3.3941125496954285, 3.4292856398964493, 3.464101615137755, 3.498571136907181, 3.532704346531139, 3.5665109000254023, 3.6, 3.6331804249169903, 3.666060555964672, 3.698648401781386, 3.7309516212355263, 3.7629775444453557, 3.794733192202055, 3.8262252939417984, 3.857460304397182, 3.8884444190447165, 3.9191835884530852, 3.9496835316262997, 3.97994974842648, 4.009987531152684, 4.039801975344831, 4.069397989875161, 4.09878030638384, 4.127953488110059, 4.156921938165306, 4.18568990729127, 4.214261501141095, 4.242640687119286, 4.270831300812525, 4.298837052040936, 4.3266615305567875, 4.354308211415448, 4.3817804600413295, 4.409081537009721, 4.436214602563767, 4.463182720884279, 4.48998886412873, 4.5166359162544865, 4.543126676640219, 4.5694638635183455, 4.595650117230424, 4.621688003316537, 4.6475800154489, 4.673328578219169, 4.698936049788292, 4.724404724407087, 4.749736834815168, 4.774934554525329, 4.800000000000001, 4.824935232725928, 4.849742261192857, 4.874423042781577, 4.898979485566357, 4.9234134500364695], [0.0, 0.5, 0.7071067811865476, 0.8660254037844388, 1.0, 1.118033988749895, 1.2247448713915892, 1.3228756555322954, 1.4142135623730951, 1.5, 1.5811388300841898, 1.6583123951777001, 1.7320508075688776, 1.8027756377319948, 1.8708286933869707, 1.9364916731037083, 2.0, 2.0615528128088303, 2.121320343559643, 2.179449471770337, 2.23606797749979, 2.2912878474779204, 2.345207879911715, 2.39791576165636, 2.4494897427831783, 2.5000000000000004, 2.5495097567963927, 2.5980762113533165, 2.6457513110645907, 2.6925824035672523, 2.7386127875258306, 2.783882181415011, 2.8284271247461903, 2.8722813232690148, 2.9154759474226504, 2.958039891549808, 3.0, 3.04138126514911, 3.0822070014844885, 3.1224989991991996, 3.1622776601683795, 3.2015621187164247, 3.2403703492039306, 3.278719262151, 3.3166247903554003, 3.3541019662496843, 3.3911649915626345, 3.4278273002005224, 3.4641016151377553, 3.5, 3.535533905932738, 3.5707142142714257, 3.6055512754639896, 3.64005494464026, 3.6742346141747677, 3.708099243547832, 3.7416573867739413, 3.774917217635375, 3.8078865529319548, 3.840572873934304, 3.8729833462074166, 3.9051248379533274, 3.9370039370059056, 3.968626966596886, 4.0, 4.031128874149275, 4.06201920231798, 4.092676385936225, 4.123105625617661, 4.153311931459037, 4.183300132670378, 4.2130748865881795, 4.242640687119286, 4.272001872658766, 4.301162633521313, 4.330127018922194, 4.358898943540674, 4.387482193696061, 4.415880433163924, 4.444097208657795, 4.47213595499958, 4.500000000000001, 4.527692569068709, 4.55521678957215, 4.582575694955841, 4.609772228646444, 4.636809247747852, 4.663689526544408, 4.69041575982343, 4.716990566028302, 4.743416490252569, 4.769696007084729, 4.79583152331272, 4.821825380496478, 4.847679857416329, 4.873397172404482, 4.898979485566357, 4.924428900898053, 4.949747468305833, 4.974937185533101, 5.000000000000001, 5.024937810560446], [0.0, 0.5099019513592785, 0.7211102550927979, 0.8831760866327849, 1.019803902718557, 1.140175425099138, 1.2489995996796799, 1.3490737563232043, 1.4422205101855958, 1.5297058540778354, 1.61245154965971, 1.6911534525287766, 1.7663521732655698, 1.8384776310850237, 1.9078784028338913, 1.9748417658131499, 2.039607805437114, 2.102379604162864, 2.1633307652783937, 2.2226110770892875, 2.280350850198276, 2.336664289109585, 2.3916521486202797, 2.4454038521274972, 2.4979991993593598, 2.5495097567963927, 2.6000000000000005, 2.6495282598983545, 2.6981475126464085, 2.7459060435491964, 2.792848008753788, 2.839013913315678, 2.8844410203711917, 2.9291637031753623, 2.973213749463701, 3.0166206257996713, 3.059411708155671, 3.101612483854165, 3.1432467291003428, 3.1843366656181322, 3.22490309931942, 3.264965543462902, 3.304542328371662, 3.3436506994600976, 3.382306905057553, 3.420526275297414, 3.458323293158117, 3.4957116585897072, 3.5327043465311396, 3.5693136595149495, 3.6055512754639896, 3.6414282912066254, 3.6769552621700474, 3.712142238654118, 3.7469987990390394, 3.7815340802378077, 3.8157568056677826, 3.849675310984032, 3.8832975677895205, 3.916631205513228, 3.9496835316262997, 3.9824615503479754, 4.014971979976946, 4.047221268969613, 4.079215610874228, 4.110960958218893, 4.142463035441596, 4.173727350941841, 4.204759208325728, 4.235563716909475, 4.266145801540309, 4.296510211788167, 4.3266615305567875, 4.356604182158393, 4.386342439892262, 4.415880433163924, 4.445222154178575, 4.474371464239419, 4.503332099679082, 4.532107677449864, 4.560701700396552, 4.589117562233507, 4.617358552246079, 4.645427859734774, 4.67332857821917, 4.701063709417264, 4.7286361670147565, 4.756048780237647, 4.7833042972405595, 4.810405388322278, 4.83735464897913, 4.864154602806124, 4.8908077042549944, 4.917316341257699, 4.943682837723311, 4.969909455915671, 4.9959983987187195, 5.021951811795889, 5.047771785649585, 5.073460357586329, 5.099019513592785, 5.1244511901275835], [0.0, 0.5196152422706632, 0.7348469228349535, 0.9000000000000001, 1.0392304845413265, 1.1618950038622253, 1.2727922061357857, 1.374772708486752, 1.469693845669907, 1.5588457268119895, 1.6431676725154984, 1.7233687939614089, 1.8000000000000003, 1.8734993995195197, 1.9442222095223582, 2.0124611797498106, 2.078460969082653, 2.142428528562855, 2.2045407685048604, 2.2649503305812253, 2.3237900077244507, 2.381176179958132, 2.4372115213907883, 2.491987158875423, 2.5455844122715714, 2.5980762113533165, 2.6495282598983545, 2.7, 2.749545416973504, 2.7982137159266447, 2.8460498941515415, 2.8930952282978866, 2.939387691339814, 2.9849623113198605, 3.0298514815086235, 3.0740852297878796, 3.117691453623979, 3.160696125855822, 3.203123475609394, 3.244996147917591, 3.286335345030997, 3.3271609519228256, 3.3674916480965478, 3.407345007480164, 3.4467375879228177, 3.4856850115866753, 3.5242020373412197, 3.5623026261113755, 3.6000000000000005, 3.6373066958946425, 3.6742346141747677, 3.7107950630558952, 3.7469987990390394, 3.782856063875548, 3.818376618407357, 3.853569773599539, 3.8884444190447165, 3.9230090491866063, 3.957271787481876, 3.9912404086950213, 4.024922359499621, 4.058324777540605, 4.091454509095756, 4.124318125460256, 4.156921938165306, 4.189272013130682, 4.221374183841087, 4.253234063627348, 4.28485705712571, 4.316248370981448, 4.3474130238568325, 4.378355855797928, 4.409081537009721, 4.439594576084623, 4.469899327725402, 4.5, 4.529900661162451, 4.559605246071199, 4.589117562233508, 4.618441295502196, 4.647580015448901, 4.676537180435969, 4.705316142407438, 4.73392015141785, 4.762352359916264, 4.790615826801394, 4.818713521262704, 4.846648326421054, 4.874423042781577, 4.902040391510457, 4.929503017546495, 4.956813492557492, 4.983974317750846, 5.0109879265470205, 5.037856687124, 5.06458290484024, 5.091168824543143, 5.117616632769595, 5.143928459844674, 5.170106381884226, 5.196152422706633, 5.222068555658764], [0.0, 0.5291502622129182, 0.7483314773547882, 0.9165151389911681, 1.0583005244258363, 1.1832159566199234, 1.2961481396815722, 1.4000000000000001, 1.4966629547095764, 1.5874507866387544, 1.6733200530681511, 1.7549928774784245, 1.8330302779823362, 1.9078784028338915, 1.9798989873223332, 2.0493901531919194, 2.1166010488516727, 2.181742422927143, 2.244994432064365, 2.3065125189341593, 2.366431913239847, 2.4248711305964283, 2.4819347291981715, 2.5377155080899043, 2.5922962793631443, 2.6457513110645907, 2.6981475126464085, 2.749545416973504, 2.8000000000000003, 2.8495613697550017, 2.8982753492378874, 2.946183972531247, 2.993325909419153, 3.039736830714133, 3.0854497241083028, 3.1304951684997055, 3.1749015732775088, 3.2186953878862163, 3.2619012860600183, 3.3045423283716615, 3.3466401061363023, 3.3882148692194836, 3.4292856398964497, 3.4698703145794942, 3.509985754956849, 3.5496478698597693, 3.5888716889852725, 3.627671429443411, 3.6660605559646724, 3.704051835490427, 3.7416573867739418, 3.7788887255382373, 3.815756805667783, 3.852272056851645, 3.8884444190447165, 3.924283374069717, 3.9597979746446663, 3.994996871087636, 4.029888335921977, 4.064480286580315, 4.098780306383839, 4.132795663954365, 4.166533331199932, 4.2, 4.233202097703345, 4.266145801540308, 4.298837052040936, 4.331281565541543, 4.363484845854286, 4.3954521951671826, 4.427188724235731, 4.458699361921591, 4.48998886412873, 4.521061822182926, 4.551922670696417, 4.58257569495584, 4.613025037868319, 4.64327470649756, 4.67332857821917, 4.703190406521939, 4.732863826479694, 4.762352359916263, 4.791659420284376, 4.82078831727758, 4.849742261192857, 4.878524367060187, 4.907137658554119, 4.935585071701227, 4.963869458396343, 4.991993589739474, 5.019960159204453, 5.047771785649585, 5.075431016179809, 5.10294032886923, 5.130302135352265, 5.15751878329105, 5.184592558726289, 5.2115256883181535, 5.238320341483518, 5.264978632435274, 5.291502622129181, 5.317894320123333], [0.0, 0.5385164807134505, 0.7615773105863909, 0.9327379053088817, 1.077032961426901, 1.2041594578792296, 1.319090595827292, 1.4247806848775009, 1.5231546211727818, 1.6155494421403513, 1.7029386365926402, 1.7860571099491753, 1.8654758106177634, 1.94164878389476, 2.0149441679609885, 2.085665361461421, 2.154065922853802, 2.220360331117452, 2.2847319317591728, 2.3473389188611007, 2.4083189157584592, 2.4677925358506134, 2.5258661880630178, 2.582634314028992, 2.638181191654584, 2.6925824035672523, 2.7459060435491964, 2.7982137159266447, 2.8495613697550017, 2.9000000000000004, 2.9495762407505253, 2.99833287011299, 3.0463092423455636, 3.0935416596516045, 3.1400636936215167, 3.1859064644147983, 3.2310988842807027, 3.2756678708318403, 3.3196385345395667, 3.363034344160048, 3.4058772731852804, 3.448187929913334, 3.48998567332303, 3.531288716601915, 3.5721142198983507, 3.6124783736376886, 3.6523964735499352, 3.691882988394947, 3.7309516212355267, 3.769615364994153, 3.8078865529319548, 3.845776904605883, 3.88329756778952, 3.9204591567825324, 3.957271787481876, 3.993745109543172, 4.029888335921977, 4.065710270051224, 4.101219330881976, 4.136423575989287, 4.171330722922842, 4.205948168962618, 4.240283009422838, 4.274342054632503, 4.308131845707604, 4.341658669218482, 4.374928570845472, 4.407947368106838, 4.440720662234904, 4.473253849269009, 4.505552130427525, 4.537620521815371, 4.5694638635183455, 4.601086828130937, 4.632493928760188, 4.663689526544408, 4.694677837722201, 4.725462940284264, 4.756048780237647, 4.786439177509728, 4.8166378315169185, 4.846648326421054, 4.876474136094644, 4.906118628814432, 4.935585071701227, 4.964876634922565, 4.993996395673509, 5.022947341949744, 5.0517323761260355, 5.0803543183522155, 5.10881590977792, 5.137119815616529, 5.165268628057984, 5.193264869039514, 5.221110992882646, 5.2488093888042835, 5.276362383309168, 5.3037722424704485, 5.331041174104736, 5.358171329847527, 5.385164807134505, 5.412023651093924], [0.0, 0.5477225575051661, 0.7745966692414833, 0.9486832980505139, 1.0954451150103321, 1.2247448713915892, 1.3416407864998738, 1.4491376746189437, 1.5491933384829666, 1.6431676725154982, 1.7320508075688772, 1.816590212458495, 1.8973665961010278, 1.9748417658131499, 2.0493901531919194, 2.1213203435596424, 2.1908902300206643, 2.258317958127243, 2.32379000772445, 2.3874672772626644, 2.4494897427831783, 2.5099800796022267, 2.569046515733026, 2.6267851073127395, 2.6832815729997477, 2.7386127875258306, 2.792848008753788, 2.8460498941515415, 2.8982753492378874, 2.9495762407505253, 2.9999999999999996, 3.049590136395381, 3.098386676965933, 3.146426544510455, 3.1937438845342623, 3.2403703492039297, 3.2863353450309964, 3.331666249791536, 3.376388603226826, 3.420526275297414, 3.4641016151377544, 3.5071355833500366, 3.5496478698597698, 3.5916569992135936, 3.63318042491699, 3.674234614174767, 3.714835124201342, 3.7549966711037173, 3.7947331922020555, 3.8340579025361627, 3.872983346207417, 3.9115214431215892, 3.9496835316262997, 3.9874804074753776, 4.024922359499621, 4.06201920231798, 4.098780306383839, 4.135214625627066, 4.171330722922842, 4.207136793592525, 4.242640687119285, 4.277849927241487, 4.3127717305695645, 4.347413023856832, 4.381780460041329, 4.415880433163923, 4.449719092257397, 4.483302354291978, 4.516635916254486, 4.54972526643093, 4.58257569495584, 4.61519230368573, 4.6475800154489, 4.679743582719036, 4.711687595755898, 4.743416490252569, 4.774934554525329, 4.806245936279166, 4.83735464897913, 4.868264577855234, 4.898979485566357, 4.929503017546495, 4.959838707054898, 4.9899899799498595, 5.019960159204453, 5.049752469181039, 5.079370039680118, 5.10881590977792, 5.138093031466052, 5.167204273105525, 5.196152422706632, 5.224940191045253, 5.253570214625479, 5.282045058497703, 5.310367218940701, 5.338539126015655, 5.366563145999495, 5.394441583704471, 5.422176684690383, 5.449770637375485, 5.477225575051661, 5.504543577809154], [0.0, 0.5567764362830022, 0.7874007874011811, 0.9643650760992957, 1.1135528725660044, 1.2449899597988734, 1.3638181696985856, 1.4730919862656235, 1.5748015748023623, 1.6703293088490065, 1.760681686165901, 1.846618531261939, 1.9287301521985913, 2.0074859899884734, 2.083266665599966, 2.1563858652847823, 2.227105745132009, 2.2956480566497994, 2.3622023622035435, 2.4269322199023198, 2.489979919597747, 2.551470164434615, 2.6115129714401193, 2.670205984563738, 2.727636339397171, 2.783882181415011, 2.839013913315678, 2.8930952282978866, 2.946183972531247, 2.99833287011299, 3.049590136395381, 3.1, 3.1496031496047245, 3.1984371183438953, 3.2465366161495854, 3.2939338184001206, 3.340658617698013, 3.38673884437522, 3.432200460346103, 3.477067730142742, 3.521363372331802, 3.5651086939951777, 3.6083237105337433, 3.6510272527057364, 3.693237062523878, 3.7349698793966195, 3.7762415176998414, 3.817066936798463, 3.8574603043971827, 3.8974350539810154, 3.9370039370059056, 3.9761790704142093, 4.014971979976947, 4.053393639902249, 4.091454509095757, 4.129164564412516, 4.166533331199932, 4.20356991139674, 4.240283009422838, 4.276680956068619, 4.3127717305695645, 4.34856298103178, 4.384062043356595, 4.419275958796871, 4.454211490264018, 4.488875137492688, 4.523273151159456, 4.557411546042337, 4.591296113299599, 4.624932431938872, 4.658325879540847, 4.69148164229596, 4.724404724407087, 4.757099956906519, 4.789572005931219, 4.8218253804964775, 4.8538644398046396, 4.8856934001224435, 4.917316341257699, 4.948737212663449, 4.979959839195494, 5.01098792654702, 5.041825066382213, 5.072474741188959, 5.10294032886923, 5.13322510708424, 5.163332257370235, 5.193264869039514, 5.223025942880239, 5.252618394667558, 5.282045058497703, 5.3113086899558, 5.340411969127476, 5.36935750346352, 5.398147830506312, 5.426785420486054, 5.455272678794342, 5.483611948342078, 5.511805511808268, 5.539855593785817, 5.567764362830022, 5.595533933415113], [0.0, 0.565685424949238, 0.7999999999999999, 0.9797958971132713, 1.131370849898476, 1.2649110640673518, 1.3856406460551018, 1.4966629547095764, 1.5999999999999999, 1.697056274847714, 1.7888543819998317, 1.876166303929372, 1.9595917942265426, 2.039607805437114, 2.116601048851672, 2.1908902300206643, 2.262741699796952, 2.33238075793812, 2.4, 2.4657656011875906, 2.5298221281347035, 2.5922962793631443, 2.6532998322843198, 2.7129319932501073, 2.7712812921102037, 2.8284271247461903, 2.8844410203711917, 2.939387691339814, 2.993325909419153, 3.0463092423455636, 3.098386676965933, 3.1496031496047245, 3.1999999999999997, 3.249615361854384, 3.2984845004941286, 3.3466401061363023, 3.394112549695428, 3.4409301068170506, 3.487119154832539, 3.5327043465311387, 3.5777087639996634, 3.622154055254967, 3.6660605559646724, 3.709447398198281, 3.752332607858744, 3.7947331922020546, 3.8366652186501757, 3.878143885933063, 3.9191835884530852, 3.959797974644666, 4.0, 4.039801975344831, 4.079215610874228, 4.118252056394801, 4.156921938165306, 4.1952353926806065, 4.233202097703344, 4.2708313008125245, 4.308131845707603, 4.345112196480086, 4.381780460041329, 4.418144406874904, 4.454211490264017, 4.48998886412873, 4.525483399593904, 4.560701700396551, 4.595650117230423, 4.63033476111609, 4.66476151587624, 4.698936049788292, 4.732863826479693, 4.766550115125193, 4.8, 4.833218389437829, 4.866210024238575, 4.898979485566356, 4.931531202375181, 4.963869458396343, 4.995998398718719, 5.027922035990614, 5.059644256269407, 5.091168824543142, 5.122499389946279, 5.15363949069005, 5.184592558726289, 5.215361924162119, 5.2459508194416005, 5.276362383309167, 5.3065996645686395, 5.336665625650533, 5.366563145999495, 5.396295025292816, 5.4258639865002145, 5.455272678794342, 5.4845236803208355, 5.513619500836088, 5.542562584220407, 5.571355310873648, 5.6, 5.628498911788116, 5.656854249492381, 5.685068161420759], [0.0, 0.574456264653803, 0.812403840463596, 0.9949874371066202, 1.148912529307606, 1.2845232578665131, 1.4071247279470291, 1.5198684153570665, 1.624807680927192, 1.7233687939614086, 1.8165902124584952, 1.9052558883257653, 1.9899748742132404, 2.0712315177207983, 2.149418526020468, 2.224859546128699, 2.297825058615212, 2.3685438564654024, 2.4372115213907883, 2.503996805109783, 2.5690465157330262, 2.632489316217637, 2.6944387170614963, 2.754995462791183, 2.8142494558940583, 2.8722813232690148, 2.9291637031753623, 2.9849623113198605, 3.039736830714133, 3.0935416596516045, 3.146426544510455, 3.1984371183438953, 3.249615361854384, 3.3000000000000007, 3.3496268448888458, 3.398529093593286, 3.4467375879228173, 3.49428104193123, 3.541186241925155, 3.58747822293042, 3.6331804249169903, 3.678314831549905, 3.7229020937972575, 3.7669616403674726, 3.8105117766515306, 3.853569773599539, 3.896151947755632, 3.9382737335030438, 3.9799497484264807, 4.02119385257662, 4.06201920231798, 4.102438299353204, 4.1424630354415966, 4.182104733265298, 4.221374183841087, 4.260281680828159, 4.298837052040936, 4.337049688440288, 4.374928570845472, 4.412482294582042, 4.449719092257398, 4.486646854834912, 4.523273151159457, 4.559605246071199, 4.595650117230424, 4.631414470763764, 4.666904755831214, 4.702127178203499, 4.737087712930805, 4.77179211617606, 4.806245936279167, 4.8404545241123795, 4.874423042781577, 4.908156476723211, 4.941659640242335, 4.974937185533101, 5.007993610219566, 5.040833264451424, 5.07346035758633, 5.105878964487898, 5.1380930314660525, 5.170106381884226, 5.201922721455982, 5.23354564325181, 5.264978632435274, 5.296225070746145, 5.327288240746882, 5.358171329847526, 5.388877434122993, 5.419409561935692, 5.449770637375486, 5.479963503528103, 5.509990925582366, 5.539855593785817, 5.569560126257729, 5.599107071667768, 5.628498911788117, 5.657738063926256, 5.686826883245173, 5.715767664977296, 5.7445626465380295, 5.773214009544425], [0.0, 0.5830951894845301, 0.8246211251235321, 1.009950493836208, 1.1661903789690602, 1.30384048104053, 1.4282856857085702, 1.5427248620541514, 1.6492422502470643, 1.7492855684535902, 1.8439088914585775, 1.9339079605813718, 2.019900987672416, 2.102379604162864, 2.181742422927143, 2.258317958127243, 2.3323807579381204, 2.4041630560342617, 2.4738633753705965, 2.5416530054277673, 2.60768096208106, 2.672077843177478, 2.734958866235469, 2.7964262908219126, 2.8565713714171403, 2.9154759474226504, 2.973213749463701, 3.0298514815086235, 3.0854497241083028, 3.1400636936215167, 3.1937438845342623, 3.2465366161495854, 3.2984845004941286, 3.3496268448888458, 3.4000000000000004, 3.449637662132068, 3.4985711369071804, 3.54682957019364, 3.594440151122286, 3.6414282912066254, 3.687817782917155, 3.733630940518894, 3.7788887255382373, 3.823610858861032, 3.8678159211627436, 3.911521443121589, 3.954743986657038, 3.997499218261337, 4.039801975344832, 4.08166632639171, 4.123105625617661, 4.164132562731403, 4.204759208325728, 4.244997055358225, 4.28485705712571, 4.324349662087931, 4.363484845854286, 4.402272140611028, 4.440720662234904, 4.4788391353117385, 4.516635916254486, 4.5541190146942805, 4.591296113299598, 4.628174586162454, 4.664761515876241, 4.701063709417263, 4.737087712930805, 4.77283982551269, 4.8083261120685235, 4.843552415324934, 4.878524367060187, 4.913247398615299, 4.947726750741193, 4.98196748283246, 5.015974481593781, 5.049752469181039, 5.083306010855535, 5.1166395221864125, 5.149757275833494, 5.182663407939976, 5.21536192416212, 5.247856705360771, 5.280151512977635, 5.31224999411737, 5.344155686354956, 5.375872022286245, 5.40740233383831, 5.4387498563548595, 5.469917732470938, 5.500909015790026, 5.531726674375733, 5.562373594069352, 5.592852581643825, 5.62316636780382, 5.653317610041029, 5.683308895353129, 5.713142742834281, 5.742821606144492, 5.772347875864725, 5.801723881744115, 5.830951894845301, 5.860034129593445], [0.0, 0.5916079783099616, 0.8366600265340756, 1.02469507659596, 1.1832159566199232, 1.3228756555322954, 1.449137674618944, 1.5652475842498528, 1.6733200530681511, 1.7748239349298847, 1.8708286933869707, 1.9621416870348585, 2.04939015319192, 2.1330729007701543, 2.2135943621178655, 2.29128784747792, 2.3664319132398464, 2.4392621835300936, 2.5099800796022267, 2.5787593916455256, 2.6457513110645907, 2.711088342345192, 2.7748873851023217, 2.8372521918222215, 2.898275349237888, 2.958039891549808, 3.0166206257996713, 3.0740852297878796, 3.1304951684997055, 3.1859064644147983, 3.2403703492039297, 3.2939338184001206, 3.3466401061363023, 3.398529093593286, 3.449637662132068, 3.5, 3.5496478698597693, 3.5986108430893164, 3.646916505762094, 3.6945906403822333, 3.7416573867739413, 3.7881393849751626, 3.834057902536163, 3.879432948254164, 3.924283374069717, 3.9686269665968856, 4.012480529547776, 4.05585995813465, 4.09878030638384, 4.141255848169731, 4.183300132670378, 4.224926034855522, 4.266145801540309, 4.306971093471606, 4.347413023856832, 4.387482193696061, 4.427188724235731, 4.466542286825459, 4.505552130427525, 4.544227107000705, 4.58257569495584, 4.620606020859168, 4.658325879540846, 4.695742752749559, 4.732863826479693, 4.769696007084728, 4.806245936279166, 4.8425200051213, 4.878524367060187, 4.914264950122246, 4.949747468305833, 4.984977432245807, 5.019960159204453, 5.054700782440045, 5.089204259999788, 5.123475382979799, 5.157518783291051, 5.191338940966964, 5.2249401910452535, 5.2583267300539625, 5.291502622129181, 5.324471804789654, 5.35723809439155, 5.389805191284746, 5.422176684690384, 5.454356057317858, 5.486346689738081, 5.518151864528558, 5.549774770204643, 5.58121850495033, 5.612486080160912, 5.643580423808984, 5.674504383644443, 5.705260730238365, 5.735852159879995, 5.766281297335397, 5.796550698475776, 5.826662852782887, 5.856620185738529, 5.886425061104576, 5.916079783099616, 5.9455865984779], [0.0, 0.6, 0.848528137423857, 1.0392304845413265, 1.2, 1.3416407864998738, 1.469693845669907, 1.5874507866387544, 1.697056274847714, 1.7999999999999998, 1.8973665961010275, 1.98997487421324, 2.078460969082653, 2.1633307652783937, 2.244994432064365, 2.3237900077244498, 2.4, 2.473863375370596, 2.545584412271571, 2.615339366124404, 2.6832815729997477, 2.749545416973504, 2.814249455894058, 2.877498913987632, 2.939387691339814, 3.0, 3.059411708155671, 3.117691453623979, 3.1749015732775088, 3.2310988842807027, 3.2863353450309964, 3.340658617698013, 3.394112549695428, 3.4467375879228173, 3.4985711369071804, 3.5496478698597693, 3.5999999999999996, 3.6496575181789317, 3.698648401781386, 3.746998799039039, 3.794733192202055, 3.8418745424597094, 3.8884444190447165, 3.9344631145812, 3.97994974842648, 4.024922359499621, 4.069397989875161, 4.113392760240626, 4.156921938165306, 4.2, 4.242640687119285, 4.28485705712571, 4.3266615305567875, 4.368065933568311, 4.409081537009721, 4.449719092257398, 4.48998886412873, 4.52990066116245, 4.569463863518345, 4.608687448721165, 4.6475800154488995, 4.686149805543993, 4.724404724407086, 4.762352359916263, 4.8, 4.8373546489791295, 4.874423042781576, 4.91121166312347, 4.947726750741192, 4.983974317750845, 5.019960159204453, 5.0556898639058145, 5.091168824543142, 5.126402247190518, 5.161395160225576, 5.196152422706632, 5.230678732248808, 5.264978632435273, 5.299056519796709, 5.332916650389353, 5.366563145999495, 5.4, 5.43323108288245, 5.466260147486579, 5.499090833947008, 5.531726674375732, 5.5641710972974225, 5.596427431853289, 5.628498911788116, 5.660388679233962, 5.692099788303082, 5.7236352085016735, 5.754997827975264, 5.786190456595773, 5.817215828899595, 5.848076606885377, 5.878775382679628, 5.909314681077663, 5.939696961966999, 5.96992462263972, 6.0, 6.029925372672535], [0.0, 0.608276253029822, 0.8602325267042626, 1.053565375285274, 1.216552506059644, 1.3601470508735445, 1.489966442575134, 1.6093476939431082, 1.7204650534085253, 1.8248287590894658, 1.9235384061671346, 2.017424100183202, 2.107130750570548, 2.193171219946131, 2.2759613353482084, 2.355843797877949, 2.433105012119288, 2.5079872407968904, 2.5806975801127883, 2.651414716712571, 2.720294101747089, 2.787471972953271, 2.8530685235374214, 2.917190429162965, 2.979932885150268, 3.04138126514911, 3.101612483854165, 3.160696125855822, 3.2186953878862163, 3.2756678708318403, 3.331666249791536, 3.38673884437522, 3.4409301068170506, 3.49428104193123, 3.54682957019364, 3.5986108430893164, 3.6496575181789317, 3.7, 3.7496666518505353, 3.7986839826445165, 3.847076812334269, 3.89486841883009, 3.942080668885405, 3.988734135035826, 4.034848200366404, 4.080441152620633, 4.125530268947254, 4.170131892398609, 4.214261501141096, 4.257933771208754, 4.301162633521314, 4.343961325794695, 4.386342439892262, 4.428317965096906, 4.469899327725402, 4.511097427455985, 4.551922670696417, 4.592385001282014, 4.632493928760188, 4.672258554489466, 4.711687595755898, 4.750789408087881, 4.789572005931219, 4.828043081829325, 4.866210024238576, 4.904079934095691, 4.941659640242335, 4.978955713801841, 5.015974481593781, 5.052722038663912, 5.089204259999789, 5.1254268114957995, 5.1613951602255765, 5.197114584074513, 5.232590180780452, 5.26782687642637, 5.302829433425142, 5.3376024580330075, 5.372150407425318, 5.406477596365309, 5.440588203494178, 5.474486277268398, 5.508175741568166, 5.541660400998964, 5.574943945906542, 5.608029957123981, 5.640921910468182, 5.673623181001714, 5.706137047074843, 5.7384666941614295, 5.770615218501404, 5.8025856305616035, 5.83438085832593, 5.866003750424986, 5.897457079114693, 5.928743543112655, 5.959865770300536, 5.990826320300065, 6.021627686929839, 6.052272300549605, 6.08276253029822, 6.113100686231171], [0.0, 0.6164414002968976, 0.8717797887081348, 1.0677078252031313, 1.2328828005937953, 1.3784048752090223, 1.50996688705415, 1.6309506430300091, 1.7435595774162695, 1.849324200890693, 1.949358868961793, 2.0445048300260877, 2.1354156504062627, 2.222611077089287, 2.3065125189341593, 2.3874672772626644, 2.4657656011875906, 2.541653005427767, 2.615339366124404, 2.687005768508881, 2.7568097504180447, 2.824889378365107, 2.891366458960192, 2.956349099818897, 3.0199337741083, 3.0822070014844885, 3.1432467291003428, 3.203123475609394, 3.2619012860600183, 3.3196385345395667, 3.376388603226826, 3.432200460346103, 3.487119154832539, 3.541186241925155, 3.594440151122286, 3.646916505762094, 3.698648401781386, 3.7496666518505353, 3.8000000000000003, 3.8496753109840323, 3.898717737923586, 3.9471508711981107, 3.9949968710876362, 4.042276586281547, 4.0890096600521755, 4.135214625627066, 4.180908992073375, 4.226109321823088, 4.270831300812525, 4.315089802078284, 4.358898943540674, 4.402272140611029, 4.445222154178574, 4.487761134463376, 4.529900661162451, 4.571651780264984, 4.613025037868319, 4.654030511288038, 4.694677837722201, 4.734976240700686, 4.774934554525329, 4.814561246884289, 4.853864439804639, 4.892851929090027, 4.931531202375181, 4.969909455915671, 5.007993610219566, 5.045790324617146, 5.083306010855534, 5.120546845796843, 5.157518783291051, 5.194227565288221, 5.230678732248808, 5.266877632905477, 5.302829433425141, 5.338539126015656, 5.374011537017762, 5.409251334519409, 5.444263035526481, 5.47905101272109, 5.513619500836089, 5.547972602672079, 5.582114294781146, 5.616048432839589, 5.649778756730214, 5.68330889535313, 5.716642371182581, 5.749782604586021, 5.782732917920384, 5.815496539419485, 5.848076606885378, 5.880476171195663, 5.912698199637794, 5.944745579080741, 5.976621118993575, 6.008327554319921, 6.0398675482166, 6.071243694664217, 6.102458520956943, 6.133514490078262, 6.164414002968977, 6.1951594006934165], [0.0, 0.6244997998398399, 0.8831760866327847, 1.081665382639197, 1.2489995996796799, 1.3964240043768943, 1.5297058540778357, 1.6522711641858308, 1.7663521732655694, 1.8734993995195195, 1.97484176581315, 2.0712315177207983, 2.163330765278394, 2.2516660498395407, 2.3366642891095846, 2.4186773244895647, 2.4979991993593598, 2.574878637916747, 2.6495282598983545, 2.7221315177632404, 2.7928480087537886, 2.861817604250837, 2.9291637031753623, 2.994995826374388, 3.0594117081556713, 3.1224989991991996, 3.1843366656181322, 3.244996147917591, 3.3045423283716615, 3.363034344160048, 3.420526275297414, 3.477067730142742, 3.5327043465311387, 3.58747822293042, 3.6414282912066254, 3.6945906403822333, 3.746998799039039, 3.7986839826445165, 3.8496753109840323, 3.900000000000001, 3.9496835316263, 3.9987498046264416, 4.047221268969613, 4.095119045888654, 4.1424630354415966, 4.189272013130682, 4.235563716909475, 4.281354925721529, 4.326661530556788, 4.371498598878879, 4.415880433163924, 4.459820624195553, 4.503332099679081, 4.546427168667723, 4.589117562233507, 4.631414470763765, 4.673328578219169, 4.7148700936505135, 4.756048780237647, 4.796873982084583, 4.8373546489791295, 4.87749935930288, 4.917316341257699, 4.956813492557492, 4.9959983987187195, 5.034878350069642, 5.073460357586329, 5.111751167652823, 5.149757275833494, 5.187484939737176, 5.2249401910452535, 5.262128846769148, 5.299056519796709, 5.335728628781641, 5.372150407425317, 5.408326913195984, 5.444263035526481, 5.479963503528103, 5.515432893255072, 5.550675634551168, 5.585696017507577, 5.620498198558559, 5.655086206239478, 5.68946394662977, 5.723635208501674, 5.757603668193913, 5.791372894228104, 5.8249463516842805, 5.858327406350725, 5.8915193286621745, 5.92452529743945, 5.957348403442593, 5.989991652748776, 6.02245796996542, 6.054750201288242, 6.08687111741328, 6.118823416311343, 6.150609725872713, 6.182232606429493, 6.213694553162394, 6.244997998398399, 6.276145313805283], [0.0, 0.6324555320336759, 0.8944271909999159, 1.0954451150103324, 1.2649110640673518, 1.4142135623730951, 1.5491933384829668, 1.6733200530681511, 1.7888543819998317, 1.8973665961010275, 2.0, 2.0976176963403033, 2.1908902300206647, 2.280350850198276, 2.3664319132398464, 2.449489742783178, 2.5298221281347035, 2.6076809620810595, 2.6832815729997477, 2.7568097504180447, 2.8284271247461903, 2.898275349237888, 2.9664793948382653, 3.0331501776206204, 3.0983866769659336, 3.1622776601683795, 3.22490309931942, 3.286335345030997, 3.3466401061363023, 3.4058772731852804, 3.4641016151377544, 3.521363372331802, 3.5777087639996634, 3.6331804249169903, 3.687817782917155, 3.7416573867739413, 3.794733192202055, 3.847076812334269, 3.898717737923586, 3.9496835316263, 4.0, 4.049691346263318, 4.09878030638384, 4.147288270665544, 4.1952353926806065, 4.242640687119285, 4.2895221179054435, 4.33589667773576, 4.3817804600413295, 4.427188724235731, 4.47213595499958, 4.5166359162544865, 4.560701700396552, 4.604345773288536, 4.6475800154489, 4.69041575982343, 4.732863826479693, 4.774934554525329, 4.8166378315169185, 4.857983120596447, 4.898979485566356, 4.9396356140913875, 4.979959839195493, 5.019960159204453, 5.059644256269407, 5.0990195135927845, 5.138093031466052, 5.176871642217914, 5.215361924162119, 5.253570214625479, 5.291502622129181, 5.329165037789691, 5.366563145999495, 5.403702434442518, 5.440588203494177, 5.477225575051661, 5.513619500836089, 5.549774770204643, 5.585696017507577, 5.621387729022079, 5.656854249492381, 5.692099788303083, 5.727128425310542, 5.761944116355173, 5.796550698475776, 5.830951894845301, 5.865151319446072, 5.8991524815010505, 5.932958789676531, 5.966573556070519, 6.0, 6.0332412515993425, 6.066300355241241, 6.099180272790763, 6.131883886702357, 6.164414002968976, 6.196773353931867, 6.228964600958975, 6.260990336999411, 6.29285308902091, 6.324555320336759, 6.356099432828282], [0.0, 0.6403124237432849, 0.9055385138137417, 1.1090536506409419, 1.2806248474865698, 1.4317821063276355, 1.5684387141358125, 1.6941074346097418, 1.8110770276274835, 1.9209372712298547, 2.024845673131659, 2.1236760581595306, 2.2181073012818837, 2.3086792761230397, 2.395829710142188, 2.479919353527449, 2.5612496949731396, 2.6400757564888173, 2.716615541441225, 2.791057147390573, 2.863564212655271, 2.934280150224242, 3.0033314835362415, 3.0708305065568178, 3.136877428271625, 3.2015621187164247, 3.264965543462902, 3.3271609519228256, 3.3882148692194836, 3.448187929913334, 3.5071355833500366, 3.5651086939951777, 3.622154055254967, 3.678314831549905, 3.733630940518894, 3.7881393849751626, 3.8418745424597094, 3.89486841883009, 3.9471508711981107, 3.9987498046264416, 4.049691346263318, 4.1000000000000005, 4.149698784249287, 4.198809355043403, 4.247352116319061, 4.295346318982906, 4.342810150121693, 4.389760813529594, 4.436214602563767, 4.4821869662029945, 4.527692569068709, 4.572745346069471, 4.617358552246079, 4.661544808322667, 4.705316142407437, 4.748684028233507, 4.791659420284376, 4.8342527861087286, 4.876474136094644, 4.9183330509431755, 4.959838707054898, 5.000999900019996, 5.041825066382213, 5.082322303829225, 5.122499389946279, 5.162363799656123, 5.201922721455982, 5.241183072551464, 5.280151512977635, 5.3188344587888805, 5.35723809439155, 5.395368384086485, 5.43323108288245, 5.470831746635972, 5.508175741568165, 5.545268253204709, 5.582114294781146, 5.61871871515206, 5.655086206239478, 5.691221310052879, 5.727128425310542, 5.762811813689565, 5.798275605729691, 5.833523806414096, 5.868560300448484, 5.903388857258177, 5.93801313572141, 5.9724366886556455, 6.006662967072483, 6.040695324215583, 6.074537019394977, 6.1081912216301815, 6.1416610131136355, 6.174949392505174, 6.208059278067504, 6.24099351065197, 6.27375485654325, 6.306346010171025, 6.338769596696192, 6.3710281744785915, 6.403124237432849, 6.435060217278469], [0.0, 0.6480740698407861, 0.9165151389911681, 1.1224972160321827, 1.2961481396815722, 1.4491376746189442, 1.5874507866387546, 1.7146428199482249, 1.8330302779823362, 1.9442222095223582, 2.04939015319192, 2.149418526020468, 2.2449944320643653, 2.336664289109585, 2.4248711305964283, 2.5099800796022267, 2.5922962793631443, 2.672077843177478, 2.749545416973504, 2.8248893783651075, 2.8982753492378883, 2.9698484809835, 3.039736830714133, 3.108054053584011, 3.174901573277509, 3.2403703492039306, 3.304542328371662, 3.3674916480965478, 3.4292856398964497, 3.48998567332303, 3.5496478698597698, 3.6083237105337433, 3.6660605559646724, 3.7229020937972575, 3.7788887255382373, 3.834057902536163, 3.8884444190447165, 3.942080668885405, 3.9949968710876362, 4.047221268969613, 4.09878030638384, 4.149698784249287, 4.200000000000001, 4.249705872175156, 4.298837052040936, 4.347413023856832, 4.3954521951671826, 4.442971978304612, 4.489988864128731, 4.536518488885503, 4.582575694955841, 4.628174586162455, 4.67332857821917, 4.718050444834181, 4.762352359916264, 4.806245936279167, 4.849742261192857, 4.892851929090027, 4.935585071701227, 4.9779513858614575, 5.019960159204453, 5.061620293937506, 5.10294032886923, 5.143928459844674, 5.184592558726289, 5.224940191045253, 5.264978632435274, 5.304714883949938, 5.344155686354956, 5.383307533477909, 5.422176684690385, 5.46076917659042, 5.499090833947008, 5.537147279962851, 5.574943945906542, 5.612486080160912, 5.649778756730215, 5.686826883245173, 5.723635208501675, 5.760208329565868, 5.796550698475777, 5.832666628567075, 5.868560300448485, 5.904235767650205, 5.939696961967, 5.974947698515863, 6.009991680526689, 6.044832503882966, 6.079473661428266, 6.113918547053109, 6.148170459575759, 6.182232606429493, 6.216108107168022, 6.249799996799899, 6.283311228962004, 6.316644678941503, 6.349803146555018, 6.38278935889318, 6.4156059729381765, 6.448255578061405, 6.480740698407861, 6.5130637951735135], [0.0, 0.6557438524302001, 0.9273618495495702, 1.1357816691600549, 1.3114877048604001, 1.466287829861518, 1.606237840420901, 1.7349351572897471, 1.8547236990991405, 1.9672315572906, 2.073644135332772, 2.1748563170931545, 2.2715633383201097, 2.364318083507378, 2.453568829277059, 2.5396850198400585, 2.6229754097208002, 2.7037011669191546, 2.782085548648711, 2.8583211855912904, 2.932575659723036, 3.004995840263344, 3.0757112998459397, 3.1448370387032774, 3.212475680841802, 3.278719262151, 3.3436506994600976, 3.407345007480164, 3.4698703145794942, 3.531288716601915, 3.5916569992135936, 3.6510272527057364, 3.709447398198281, 3.7669616403674726, 3.823610858861032, 3.879432948254164, 3.9344631145812, 3.988734135035826, 4.042276586281547, 4.095119045888654, 4.147288270665544, 4.198809355043403, 4.249705872175156, 4.299999999999999, 4.349712634186309, 4.398863489584553, 4.447471191587417, 4.495553358597804, 4.543126676640219, 4.5902069670114, 4.636809247747852, 4.682947789587239, 4.728636167014756, 4.773887304912004, 4.818713521262703, 4.863126566315131, 4.907137658554118, 4.950757517794625, 4.993996395673509, 5.03686410378521, 5.079370039680117, 5.121523210920751, 5.163332257370234, 5.204805471869242, 5.2459508194416005, 5.28677595515452, 5.3272882407468805, 5.367494760127856, 5.407402333838309, 5.447017532558529, 5.486346689738081, 5.525395913416522, 5.564171097297422, 5.602677931132575, 5.6409219104681805, 5.678908345800274, 5.716642371182581, 5.754128952326321, 5.791372894228104, 5.8283788483591215, 5.865151319446072, 5.9016946718718, 5.938013135721409, 5.974110812497538, 6.009991680526688, 6.0456596000767355, 6.081118318204308, 6.1163714733492105, 6.151422599691879, 6.186275131288617, 6.220932405998315, 6.255397669213365, 6.289674077406555, 6.323764701504951, 6.357672530100933, 6.3914004725099165, 6.424951361683604, 6.458327956987009, 6.491532946846992, 6.524568951279464, 6.557438524302, 6.590144156238162], [0.0, 0.66332495807108, 0.938083151964686, 1.148912529307606, 1.32664991614216, 1.4832396974191329, 1.6248076809271923, 1.7549928774784245, 1.876166303929372, 1.98997487421324, 2.0976176963403033, 2.2, 2.297825058615212, 2.3916521486202797, 2.4819347291981715, 2.569046515733026, 2.65329983228432, 2.734958866235469, 2.814249455894058, 2.8913664589601926, 2.9664793948382657, 3.039736830714133, 3.1112698372208096, 3.1811947441173736, 3.2496153618543846, 3.3166247903554003, 3.382306905057553, 3.4467375879228177, 3.509985754956849, 3.5721142198983507, 3.63318042491699, 3.693237062523878, 3.752332607858744, 3.8105117766515306, 3.8678159211627436, 3.924283374069717, 3.97994974842648, 4.034848200366404, 4.0890096600521755, 4.1424630354415966, 4.1952353926806065, 4.247352116319061, 4.298837052040936, 4.349712634186309, 4.4, 4.449719092257398, 4.498888751680798, 4.54752680036083, 4.595650117230424, 4.64327470649756, 4.69041575982343, 4.737087712930806, 4.7833042972405595, 4.829078587059855, 4.874423042781577, 4.919349550499538, 4.963869458396343, 5.007993610219566, 5.051732376126036, 5.095095681142799, 5.138093031466052, 5.180733538795447, 5.223025942880239, 5.264978632435274, 5.30659966456864, 5.347896782848375, 5.388877434122993, 5.429548784199292, 5.469917732470938, 5.509990925582365, 5.549774770204644, 5.589275444992849, 5.628498911788116, 5.667450926121902, 5.706137047074843, 5.7445626465380295, 5.782732917920385, 5.8206528843421, 5.858327406350725, 5.895761189193471, 5.9329587896765315, 5.969924622639721, 6.006662967072484, 6.043177971895251, 6.079473661428266, 6.115553940568263, 6.15142259969188, 6.187083319303208, 6.222539674441619, 6.2577951388648065, 6.29285308902091, 6.327716807822551, 6.362389488234747, 6.3968742366877915, 6.431174076325411, 6.465291950097845, 6.499230723708769, 6.532993188424431, 6.566582063752802, 6.600000000000001, 6.6332495807108005, 6.666333324999584], [0.0, 0.6708203932499369, 0.9486832980505137, 1.161895003862225, 1.3416407864998738, 1.5, 1.6431676725154982, 1.7748239349298847, 1.8973665961010273, 2.0124611797498106, 2.1213203435596424, 2.224859546128699, 2.32379000772445, 2.4186773244895647, 2.5099800796022262, 2.5980762113533156, 2.6832815729997477, 2.765863337187866, 2.846049894151541, 2.924038303442689, 3.0, 3.0740852297878796, 3.1464265445104544, 3.2171415884290826, 3.2863353450309964, 3.3541019662496843, 3.420526275297414, 3.4856850115866753, 3.5496478698597693, 3.6124783736376886, 3.674234614174767, 3.7349698793966195, 3.7947331922020546, 3.853569773599539, 3.911521443121589, 3.9686269665968856, 4.024922359499621, 4.080441152620633, 4.135214625627066, 4.189272013130682, 4.242640687119285, 4.295346318982906, 4.347413023856832, 4.398863489584553, 4.449719092257398, 4.499999999999999, 4.54972526643093, 4.598912915026768, 4.6475800154489, 4.695742752749558, 4.743416490252569, 4.790615826801393, 4.8373546489791295, 4.883646178829912, 4.9295030175464944, 4.9749371855331, 5.0199601592044525, 5.064582904840239, 5.10881590977792, 5.1526692111953, 5.196152422706631, 5.239274758971893, 5.282045058497702, 5.324471804789654, 5.366563145999495, 5.4083269131959835, 5.449770637375485, 5.490901565316937, 5.531726674375732, 5.572252686302012, 5.612486080160912, 5.652433104425031, 5.692099788303082, 5.731491952362839, 5.770615218501403, 5.809475019311125, 5.848076606885378, 5.886425061104575, 5.92452529743945, 5.962382074305537, 6.0, 6.037383539249432, 6.074537019394977, 6.111464636239008, 6.148170459575759, 6.18465843842649, 6.220932405998316, 6.256996084384263, 6.292853089020909, 6.328506932918695, 6.363961030678928, 6.399218702310462, 6.434283176858165, 6.469157595854347, 6.5038450166036395, 6.53834841531101, 6.572670690061993, 6.606814663663572, 6.640783086353596, 6.674578638386096, 6.7082039324993685, 6.74166151627327], [0.0, 0.6782329983125268, 0.9591663046625439, 1.1747340124470733, 1.3564659966250536, 1.5165750888103102, 1.661324772583615, 1.7944358444926363, 1.9183326093250879, 2.0346989949375804, 2.1447610589527217, 2.249444375840399, 2.3494680248941466, 2.445403852127497, 2.5377155080899043, 2.626785107312739, 2.7129319932501073, 2.7964262908219126, 2.877498913987632, 2.956349099818897, 3.0331501776206204, 3.108054053584011, 3.1811947441173736, 3.252691193458119, 3.32264954516723, 3.3911649915626345, 3.458323293158117, 3.5242020373412197, 3.5888716889852725, 3.6523964735499352, 3.714835124201342, 3.7762415176998414, 3.8366652186501757, 3.896151947755632, 3.954743986657038, 4.012480529547776, 4.069397989875161, 4.125530268947254, 4.180908992073375, 4.235563716909475, 4.2895221179054435, 4.342810150121693, 4.3954521951671826, 4.447471191587417, 4.498888751680798, 4.54972526643093, 4.6000000000000005, 4.649731175025068, 4.698936049788293, 4.747630988187688, 4.79583152331272, 4.843552415324934, 4.890807704254994, 4.937610758251404, 4.983974317750845, 5.029910535983717, 5.075431016179809, 5.120546845796843, 5.165268628057984, 5.209606511052442, 5.253570214625478, 5.297169055259611, 5.340411969127476, 5.383307533477908, 5.4258639865002145, 5.468089245796926, 5.509990925582365, 5.551576352712804, 5.592852581643825, 5.63382640840131, 5.674504383644443, 5.71489282489182, 5.754997827975264, 5.794825277780168, 5.834380858325929, 5.873670062235366, 5.912698199637794, 5.951470406546605, 5.989991652748776, 6.028266749240615, 6.066300355241241, 6.104096984812742, 6.1416610131136355, 6.178996682310163, 6.216108107168022, 6.252999280345393, 6.289674077406556, 6.326136261573884, 6.362389488234747, 6.398437309218556, 6.434283176858165, 6.469930447848725, 6.505382386916238, 6.540642170307134, 6.57571288910944, 6.6105975524153635, 6.64529909033446, 6.679820356865895, 6.714164132637808, 6.748333127521196, 6.782329983125269, 6.81615727518079], [0.0, 0.6855654600401044, 0.9695359714832658, 1.187434208703792, 1.3711309200802089, 1.5329709716755893, 1.6792855623746665, 1.8138357147217055, 1.9390719429665315, 2.056696380120313, 2.16794833886788, 2.273763400180415, 2.374868417407584, 2.471841418861655, 2.565151067676132, 2.6551836094703507, 2.7422618401604177, 2.826658805020514, 2.9086079144497976, 2.9883105594967874, 3.0659419433511785, 3.1416556144810017, 3.2155870381627056, 3.2878564445547194, 3.358571124749333, 3.4278273002005224, 3.4957116585897072, 3.5623026261113755, 3.627671429443411, 3.691882988394947, 3.7549966711037173, 3.817066936798463, 3.878143885933063, 3.9382737335030438, 3.997499218261337, 4.05585995813465, 4.113392760240626, 4.170131892398609, 4.226109321823088, 4.281354925721529, 4.33589667773576, 4.389760813529594, 4.442971978304612, 4.495553358597804, 4.54752680036083, 4.598912915026768, 4.649731175025068, 4.7, 4.749736834815168, 4.798958220280731, 4.847679857416329, 4.89591666595746, 4.94368283772331, 4.990991885387113, 5.037856687124, 5.084289527554465, 5.130302135352264, 5.175905717843014, 5.221110992882646, 5.265928218272634, 5.310367218940701, 5.354437412091022, 5.3981478305063115, 5.441507144165117, 5.4845236803208355, 5.527205442174191, 5.569560126257728, 5.61159513863928, 5.653317610041028, 5.69473440996154, 5.735852159879995, 5.776677245614472, 5.817215828899595, 5.857473858242988, 5.897457079114692, 5.937171043518958, 5.976621118993575, 6.015812497078014, 6.054750201288242, 6.09343909463285, 6.131883886702357, 6.17008914036094, 6.208059278067503, 6.245798587850876, 6.2833112289620034, 6.320601237224193, 6.357672530100934, 6.394528911499267, 6.431174076325411, 6.4676116148080505, 6.5038450166036395, 6.539877674696982, 6.575712889109439, 6.611353870426239, 6.646803743153547, 6.682065548915245, 6.717142249498666, 6.7520367297579185, 6.786751800382861, 6.821290200541244, 6.855654600401045, 6.889847603539574], [0.0, 0.692820323027551, 0.9797958971132713, 1.2000000000000004, 1.385640646055102, 1.549193338482967, 1.6970562748477143, 1.8330302779823362, 1.9595917942265426, 2.078460969082653, 2.1908902300206647, 2.297825058615212, 2.400000000000001, 2.4979991993593598, 2.5922962793631443, 2.6832815729997477, 2.771281292110204, 2.8565713714171403, 2.9393876913398143, 3.0199337741083006, 3.098386676965934, 3.174901573277509, 3.2496153618543846, 3.3226495451672307, 3.3941125496954285, 3.4641016151377553, 3.5327043465311396, 3.6000000000000005, 3.6660605559646724, 3.7309516212355267, 3.7947331922020555, 3.8574603043971827, 3.9191835884530852, 3.9799497484264807, 4.039801975344832, 4.09878030638384, 4.156921938165306, 4.214261501141096, 4.270831300812525, 4.326661530556788, 4.3817804600413295, 4.436214602563767, 4.489988864128731, 4.543126676640219, 4.595650117230424, 4.6475800154489, 4.698936049788293, 4.749736834815168, 4.800000000000002, 4.849742261192857, 4.898979485566357, 4.947726750741194, 4.9959983987187195, 5.043808085167398, 5.091168824543143, 5.1380930314660525, 5.184592558726289, 5.230678732248809, 5.276362383309169, 5.321653878260029, 5.366563145999495, 5.411099703387474, 5.455272678794342, 5.499090833947009, 5.542562584220408, 5.585696017507577, 5.628498911788117, 5.670978751503131, 5.713142742834281, 5.754997827975265, 5.796550698475777, 5.83780780773057, 5.8787753826796285, 5.9194594347794975, 5.959865770300536, 6.000000000000001, 6.039867548216601, 6.079473661428266, 6.1188234163113435, 6.157921727336262, 6.196773353931868, 6.235382907247959, 6.27375485654325, 6.311893535223801, 6.349803146555018, 6.387487769068526, 6.424951361683605, 6.462197768561406, 6.499230723708769, 6.536053855347277, 6.572670690061994, 6.609084656743323, 6.645299090334461, 6.681317235396028, 6.717142249498667, 6.752777206453653, 6.788225099390857, 6.823488843692794, 6.8585712797928995, 6.893475175845635, 6.9282032302755105, 6.962758074211686], [0.0, 0.7000000000000001, 0.9899494936611665, 1.2124355652982142, 1.4000000000000001, 1.565247584249853, 1.7146428199482247, 1.8520259177452134, 1.979898987322333, 2.1, 2.2135943621178655, 2.32163735324878, 2.4248711305964283, 2.5238858928247927, 2.619160170741759, 2.7110883423451915, 2.8000000000000003, 2.8861739379323623, 2.9698484809834995, 3.051229260478472, 3.130495168499706, 3.2078029864690882, 3.283291031876401, 3.357082066318904, 3.4292856398964493, 3.5, 3.5693136595149495, 3.6373066958946425, 3.704051835490427, 3.769615364994153, 3.8340579025361627, 3.8974350539810154, 3.959797974644666, 4.02119385257662, 4.08166632639171, 4.141255848169731, 4.2, 4.257933771208754, 4.315089802078284, 4.371498598878879, 4.427188724235731, 4.4821869662029945, 4.536518488885503, 4.5902069670114, 4.64327470649756, 4.695742752749558, 4.747630988187688, 4.798958220280731, 4.849742261192857, 4.9, 4.949747468305833, 4.998999899979996, 5.047771785649585, 5.096076922496363, 5.143928459844674, 5.191338940966964, 5.238320341483518, 5.2848841046895245, 5.331041174104736, 5.376802023508025, 5.422176684690383, 5.467174773134658, 5.511805511808268, 5.55607775323564, 5.6000000000000005, 5.643580423808984, 5.686826883245172, 5.729746940310715, 5.772347875864725, 5.814636704042653, 5.856620185738529, 5.898304841223451, 5.939696961966999, 5.980802621722272, 6.021627686929839, 6.06217782649107, 6.102458520956944, 6.142475071174486, 6.182232606429493, 6.221736092120913, 6.260990336999412, 6.300000000000001, 6.338769596696192, 6.377303505401009, 6.4156059729381765, 6.4536811201050215, 6.491532946846993, 6.529165337162171, 6.566582063752802, 6.603786792439623, 6.640783086353597, 6.67757440991862, 6.714164132637808, 6.750555532695069, 6.786751800382861, 6.822756041366274, 6.858571279792899, 6.894200461257274, 6.929646455628165, 6.96491205974634, 7.0, 7.034912934784624], [0.0, 0.7071067811865476, 1.0, 1.2247448713915892, 1.4142135623730951, 1.5811388300841898, 1.7320508075688774, 1.8708286933869709, 2.0, 2.1213203435596424, 2.23606797749979, 2.345207879911715, 2.4494897427831783, 2.5495097567963927, 2.6457513110645907, 2.7386127875258306, 2.8284271247461903, 2.9154759474226504, 3.0, 3.082207001484489, 3.1622776601683795, 3.2403703492039306, 3.3166247903554003, 3.3911649915626345, 3.464101615137755, 3.535533905932738, 3.6055512754639896, 3.6742346141747677, 3.7416573867739418, 3.8078865529319548, 3.872983346207417, 3.9370039370059056, 4.0, 4.06201920231798, 4.123105625617661, 4.183300132670378, 4.242640687119285, 4.301162633521314, 4.358898943540674, 4.415880433163924, 4.47213595499958, 4.527692569068709, 4.582575694955841, 4.636809247747852, 4.69041575982343, 4.743416490252569, 4.79583152331272, 4.847679857416329, 4.898979485566357, 4.949747468305833, 5.000000000000001, 5.04975246918104, 5.099019513592785, 5.147815070493501, 5.196152422706632, 5.244044240850759, 5.291502622129181, 5.338539126015656, 5.385164807134505, 5.431390245600108, 5.477225575051661, 5.522680508593631, 5.5677643628300215, 5.612486080160912, 5.656854249492381, 5.70087712549569, 5.744562646538029, 5.787918451395113, 5.830951894845301, 5.873670062235366, 5.916079783099617, 5.958187643906493, 6.0, 6.041522986797286, 6.082762530298219, 6.123724356957946, 6.164414002968978, 6.2048368229954285, 6.244997998398399, 6.284902544988268, 6.324555320336759, 6.3639610306789285, 6.403124237432849, 6.442049363362563, 6.480740698407861, 6.519202405202649, 6.557438524302001, 6.59545297913646, 6.6332495807108005, 6.670832032063167, 6.708203932499369, 6.745368781616021, 6.782329983125269, 6.8190908484929285, 6.855654600401045, 6.892024376045111, 6.92820323027551, 6.9641941385920605, 7.0, 7.035623639735145, 7.071067811865476, 7.1063352017759485], [0.0, 0.7141428428542851, 1.0099504938362078, 1.2369316876852985, 1.4282856857085702, 1.5968719422671316, 1.7492855684535904, 1.8894443627691186, 2.0199009876724157, 2.142428528562855, 2.2583179581272432, 2.368543856465403, 2.473863375370597, 2.574878637916747, 2.672077843177478, 2.765863337187866, 2.8565713714171403, 2.944486372867092, 3.029851481508624, 3.1128764832546767, 3.193743884534263, 3.272613634390715, 3.3496268448888458, 3.4249087579087423, 3.498571136907181, 3.5707142142714257, 3.6414282912066254, 3.7107950630558952, 3.7788887255382373, 3.845776904605883, 3.9115214431215892, 3.9761790704142093, 4.039801975344831, 4.102438299353204, 4.164132562731403, 4.224926034855522, 4.28485705712571, 4.343961325794695, 4.402272140611029, 4.459820624195553, 4.5166359162544865, 4.572745346069471, 4.628174586162455, 4.682947789587239, 4.737087712930806, 4.790615826801393, 4.843552415324934, 4.89591666595746, 4.947726750741194, 4.998999899979996, 5.04975246918104, 5.100000000000001, 5.149757275833494, 5.199038372622384, 5.247856705360771, 5.296225070746145, 5.344155686354956, 5.391660226683429, 5.43874985635486, 5.485435260760991, 5.531726674375732, 5.577633906953737, 5.62316636780382, 5.668333088307356, 5.713142742834281, 5.757603668193913, 5.801723881744115, 5.845511098270194, 5.888972745734184, 5.932115979985557, 5.974947698515863, 6.017474553332154, 6.059702963017248, 6.101639124038721, 6.143289021363068, 6.184658438426491, 6.225752966509353, 6.266578013557321, 6.307138812488593, 6.347440429023341, 6.387487769068526, 6.427285585688566, 6.466838485689898, 6.506150935845249, 6.54522726878143, 6.584071688552609, 6.62268827591938, 6.661080993352356, 6.6992536897776915, 6.73721010508059, 6.77495387438173, 6.81248853210044, 6.8498175158174845, 6.886944169949399, 6.923871749245506, 6.960603422117942, 6.997142273814362, 7.033491309442276, 7.069653456853455, 7.105631569396208, 7.141428428542851, 7.177046746399247], [0.0, 0.7211102550927979, 1.019803902718557, 1.2489995996796799, 1.4422205101855958, 1.61245154965971, 1.7663521732655696, 1.9078784028338915, 2.039607805437114, 2.1633307652783937, 2.280350850198276, 2.3916521486202797, 2.4979991993593598, 2.6000000000000005, 2.6981475126464085, 2.792848008753788, 2.8844410203711917, 2.973213749463701, 3.0594117081556713, 3.1432467291003428, 3.22490309931942, 3.3045423283716615, 3.3823069050575527, 3.458323293158117, 3.532704346531139, 3.6055512754639896, 3.6769552621700474, 3.7469987990390394, 3.815756805667783, 3.88329756778952, 3.9496835316262997, 4.014971979976947, 4.079215610874228, 4.1424630354415966, 4.204759208325728, 4.266145801540309, 4.3266615305567875, 4.386342439892262, 4.445222154178574, 4.503332099679081, 4.560701700396552, 4.617358552246079, 4.67332857821917, 4.728636167014756, 4.7833042972405595, 4.8373546489791295, 4.890807704254994, 4.94368283772331, 4.9959983987187195, 5.047771785649585, 5.099019513592785, 5.149757275833494, 5.200000000000001, 5.249761899362676, 5.299056519796709, 5.347896782848376, 5.396295025292817, 5.44426303552648, 5.491812087098393, 5.5389529696504916, 5.585696017507576, 5.63205113613149, 5.678027826631356, 5.723635208501674, 5.768882040742383, 5.813776741499453, 5.858327406350725, 5.902541825349482, 5.946427498927402, 5.989991652748776, 6.033241251599343, 6.076183012385325, 6.118823416311343, 6.161168720299745, 6.203224967708329, 6.244997998398398, 6.2864934582006855, 6.327716807822551, 6.3686733312362644, 6.409368143584826, 6.44980619863884, 6.489992295835181, 6.529931086925804, 6.569627082262737, 6.609084656743323, 6.648308055437865, 6.687301398920196, 6.726068688320096, 6.764613810115105, 6.802940540677979, 6.841052550594828, 6.878953408767936, 6.916646586316234, 6.954135460285485, 6.9914233171794145, 7.0285133563222315, 7.065408693062278, 7.102112361825883, 7.138627319029899, 7.17495644586084, 7.211102550927979, 7.247068372797377], [0.0, 0.7280109889280519, 1.0295630140987002, 1.2609520212918495, 1.4560219778561039, 1.627882059609971, 1.7832554500127011, 1.9261360284258224, 2.0591260281974004, 2.1840329667841556, 2.302172886644268, 2.4145392935299275, 2.521904042583699, 2.624880949681338, 2.7239676943752476, 2.819574435974337, 2.9120439557122078, 3.001666203960727, 3.0886890422961004, 3.1733263305244868, 3.255764119219942, 3.336165463522456, 3.414674215792775, 3.491418050019219, 3.5665109000254023, 3.64005494464026, 3.712142238654118, 3.782856063875548, 3.852272056851645, 3.9204591567825324, 3.9874804074753776, 4.053393639902249, 4.118252056394801, 4.182104733265298, 4.244997055358225, 4.306971093471606, 4.368065933568311, 4.428317965096906, 4.487761134463376, 4.546427168667723, 4.604345773288536, 4.661544808322667, 4.718050444834181, 4.773887304912004, 4.829078587059855, 4.883646178829912, 4.937610758251404, 4.990991885387113, 5.043808085167398, 5.096076922496363, 5.147815070493501, 5.199038372622384, 5.249761899362676, 5.300000000000001, 5.349766350038103, 5.399073994677236, 5.447935388750495, 5.496362433464519, 5.5443665102516455, 5.591958512006326, 5.639148871948674, 5.6859475903318, 5.732364259186606, 5.7784080852774675, 5.8240879114244155, 5.869412236331676, 5.914389233048499, 5.959026766175833, 6.003332407921454, 6.047313453096343, 6.090976933136425, 6.134329629226001, 6.177378084592201, 6.220128616033596, 6.262587324740471, 6.304760106459247, 6.3466526610489735, 6.388270501473776, 6.429618962271405, 6.470703207534712, 6.511528238439884, 6.552098900352467, 6.592419889539805, 6.632495759516172, 6.672330927044912, 6.711929677819935, 6.751296171847301, 6.790434448545985, 6.82934843158555, 6.868041933477111, 6.906518659932804, 6.944782214007867, 6.982836100038438, 7.020683727387242, 7.058328414008519, 7.095773389842717, 7.1330218000508046, 7.170076708097342, 7.206941098690901, 7.243617880589783, 7.28010988928052, 7.31641988953614], [0.0, 0.7348469228349535, 1.0392304845413265, 1.2727922061357857, 1.469693845669907, 1.6431676725154984, 1.8, 1.9442222095223582, 2.078460969082653, 2.2045407685048604, 2.32379000772445, 2.4372115213907883, 2.5455844122715714, 2.6495282598983545, 2.749545416973504, 2.846049894151541, 2.939387691339814, 3.0298514815086235, 3.1176914536239795, 3.203123475609394, 3.286335345030997, 3.3674916480965478, 3.4467375879228173, 3.5242020373412197, 3.6, 3.6742346141747677, 3.7469987990390394, 3.818376618407357, 3.8884444190447165, 3.957271787481876, 4.024922359499621, 4.091454509095757, 4.156921938165306, 4.221374183841087, 4.28485705712571, 4.347413023856832, 4.409081537009721, 4.469899327725402, 4.529900661162451, 4.589117562233507, 4.6475800154489, 4.705316142407437, 4.762352359916264, 4.818713521262703, 4.874423042781577, 4.9295030175464944, 4.983974317750845, 5.037856687124, 5.091168824543143, 5.143928459844674, 5.196152422706632, 5.247856705360771, 5.299056519796709, 5.349766350038103, 5.4, 5.449770637375486, 5.499090833947008, 5.547972602672079, 5.596427431853289, 5.644466316668034, 5.692099788303082, 5.739337940912697, 5.786190456595773, 5.8326666285670745, 5.878775382679628, 5.924525297439449, 5.96992462263972, 6.014981296729027, 6.059702963017247, 6.104096984812742, 6.148170459575759, 6.191930232165088, 6.235382907247959, 6.278534860936905, 6.321392251711643, 6.363961030678928, 6.406246951218788, 6.448255578061404, 6.489992295835182, 6.5314623171231725, 6.572670690061994, 6.613622305514581, 6.654321903845651, 6.694774081326419, 6.7349832961930955, 6.77495387438173, 6.814690014960329, 6.854195795277518, 6.8934751758456345, 6.932532004974806, 6.971370023173351, 7.009992867328754, 7.0484040746824395, 7.0866070866106305, 7.124605252222751, 7.162401831787993, 7.2, 7.237402849088892, 7.274613391789285, 7.3116345641723655, 7.348469228349535, 7.385120175054704], [0.0, 0.7416198487095663, 1.0488088481701516, 1.2845232578665131, 1.4832396974191326, 1.6583123951777001, 1.8165902124584952, 1.9621416870348585, 2.0976176963403033, 2.224859546128699, 2.345207879911715, 2.459674775249769, 2.5690465157330262, 2.673948391424188, 2.7748873851023217, 2.8722813232690143, 2.9664793948382653, 3.0577769702841313, 3.146426544510455, 3.232645975048923, 3.3166247903554003, 3.398529093593286, 3.4785054261852175, 3.5566838487557484, 3.6331804249169903, 3.708099243547832, 3.7815340802378077, 3.853569773599539, 3.924283374069717, 3.993745109543172, 4.06201920231798, 4.129164564412516, 4.1952353926806065, 4.260281680828159, 4.324349662087931, 4.387482193696061, 4.449719092257398, 4.511097427455985, 4.571651780264984, 4.631414470763765, 4.69041575982343, 4.748684028233507, 4.806245936279167, 4.863126566315131, 4.919349550499538, 4.9749371855331, 5.029910535983717, 5.084289527554465, 5.1380930314660525, 5.191338940966964, 5.244044240850759, 5.296225070746145, 5.347896782848376, 5.399073994677236, 5.449770637375486, 5.5, 5.549774770204643, 5.599107071667768, 5.648008498577176, 5.6964901474504455, 5.744562646538029, 5.792236183029832, 5.839520528262573, 5.886425061104576, 5.932958789676531, 5.979130371550699, 6.024948132556827, 6.070420084310475, 6.115553940568263, 6.1603571325045765, 6.2048368229954285, 6.248999919987198, 6.29285308902091, 6.336402764976356, 6.3796551630946325, 6.422616289332565, 6.465291950097846, 6.507687761409578, 6.549809157525127, 6.591661399070799, 6.6332495807108005, 6.674578638386097, 6.715653356152327, 6.756478372643548, 6.797058187186572, 6.837397165588672, 6.87749954561976, 6.917369442208505, 6.957010852370435, 6.996427659884722, 7.035623639735144, 7.074602462329597, 7.113367697511497, 7.15192281837549, 7.1902712048990205, 7.2284161474004796, 7.266360849833981, 7.30410843293006, 7.341661937191061, 7.379024325749307, 7.416198487095664, 7.4531872376856345], [0.0, 0.7483314773547883, 1.058300524425836, 1.2961481396815722, 1.4966629547095767, 1.6733200530681511, 1.833030277982336, 1.9798989873223332, 2.116601048851672, 2.244994432064365, 2.3664319132398464, 2.4819347291981715, 2.5922962793631443, 2.6981475126464085, 2.8, 2.8982753492378874, 2.9933259094191533, 3.0854497241083023, 3.1749015732775088, 3.2619012860600183, 3.3466401061363023, 3.4292856398964493, 3.509985754956849, 3.5888716889852725, 3.666060555964672, 3.7416573867739413, 3.8157568056677826, 3.8884444190447165, 3.9597979746446663, 4.029888335921977, 4.098780306383839, 4.166533331199932, 4.233202097703344, 4.298837052040936, 4.363484845854286, 4.427188724235731, 4.48998886412873, 4.551922670696417, 4.613025037868319, 4.673328578219169, 4.732863826479693, 4.791659420284376, 4.849742261192857, 4.907137658554118, 4.963869458396343, 5.0199601592044525, 5.075431016179809, 5.130302135352264, 5.184592558726289, 5.238320341483518, 5.291502622129181, 5.344155686354956, 5.396295025292817, 5.447935388750495, 5.499090833947008, 5.549774770204643, 5.6, 5.649778756730214, 5.6991227395100035, 5.748043145279965, 5.796550698475775, 5.844655678480983, 5.892367945062493, 5.939696961966999, 5.986651818838307, 6.033241251599342, 6.079473661428265, 6.125357132445422, 6.170899448216605, 6.216108107168021, 6.260990336999411, 6.305553108173778, 6.3498031465550175, 6.393746945258312, 6.437390775772432, 6.48074069840786, 6.523802572120037, 6.566582063752802, 6.609084656743323, 6.6513156593263565, 6.6932802122726045, 6.734983296193095, 6.776429738438967, 6.817624219623724, 6.858571279792899, 6.899275324264136, 6.939740629158989, 6.979971346646059, 7.019971509913698, 7.059745037889116, 7.099295739719539, 7.138627319029899, 7.177743377970545, 7.216647421067487, 7.255342858886822, 7.293833011524187, 7.332121111929344, 7.370210309075312, 7.408103670980854, 7.445804187594514, 7.483314773547883, 7.520638270785267], [0.0, 0.754983443527075, 1.0677078252031311, 1.3076696830622023, 1.50996688705415, 1.6881943016134133, 1.849324200890693, 1.997498435543818, 2.1354156504062622, 2.264950330581225, 2.3874672772626644, 2.503996805109783, 2.6153393661244047, 2.72213151776324, 2.824889378365107, 2.924038303442689, 3.0199337741083, 3.1128764832546763, 3.2031234756093934, 3.290896534380867, 3.3763886032268267, 3.459768778401239, 3.5411862419251547, 3.620773398046335, 3.698648401781386, 3.774917217635375, 3.849675310984032, 3.9230090491866063, 3.994996871087636, 4.065710270051224, 4.135214625627066, 4.20356991139674, 4.2708313008125245, 4.337049688440288, 4.402272140611028, 4.466542286825459, 4.52990066116245, 4.592385001282014, 4.654030511288038, 4.7148700936505135, 4.774934554525329, 4.8342527861087286, 4.892851929090027, 4.950757517794625, 5.007993610219566, 5.064582904840239, 5.120546845796843, 5.175905717843014, 5.230678732248809, 5.2848841046895245, 5.338539126015656, 5.391660226683429, 5.44426303552648, 5.496362433464519, 5.547972602672079, 5.599107071667768, 5.649778756730214, 5.7, 5.749782604586021, 5.799137866959191, 5.848076606885378, 5.8966091951222275, 5.944745579080739, 5.9924953066314535, 6.0398675482166, 6.08687111741328, 6.133514490078261, 6.17980582219215, 6.2257529665093525, 6.271363488110062, 6.316644678941503, 6.361603571427569, 6.406246951218787, 6.450581369148055, 6.494613152451807, 6.5383484153110105, 6.581793068761734, 6.624952830020755, 6.667833231267862, 6.710439627923047, 6.752777206453653, 6.794850991743675, 6.836665854054885, 6.878226515607057, 6.919537556802478, 6.960603422117942, 7.001428425685718, 7.042016756583302, 7.0823724838503095, 7.122499561249548, 7.162401831787993, 7.202083032012336, 7.24154679609267, 7.280796659706959, 7.31983606373804, 7.358668357794092, 7.397296803562772, 7.4357245780085215, 7.473954776421918, 7.5119904153293495, 7.54983443527075, 7.587489703452652], [0.0, 0.7615773105863909, 1.0770329614269007, 1.3190905958272923, 1.5231546211727818, 1.7029386365926404, 1.8654758106177631, 2.0149441679609885, 2.1540659228538015, 2.2847319317591723, 2.4083189157584592, 2.525866188063018, 2.6381811916545845, 2.7459060435491964, 2.8495613697550017, 2.9495762407505253, 3.0463092423455636, 3.1400636936215167, 3.2310988842807027, 3.319638534539567, 3.405877273185281, 3.48998567332303, 3.5721142198983507, 3.6523964735499352, 3.7309516212355263, 3.8078865529319548, 3.8832975677895205, 3.957271787481876, 4.029888335921977, 4.101219330881976, 4.171330722922842, 4.240283009422838, 4.308131845707603, 4.374928570845472, 4.440720662234904, 4.505552130427525, 4.569463863518345, 4.632493928760188, 4.694677837722201, 4.756048780237647, 4.8166378315169185, 4.876474136094644, 4.935585071701227, 4.993996395673509, 5.051732376126036, 5.10881590977792, 5.165268628057984, 5.221110992882646, 5.276362383309169, 5.331041174104736, 5.385164807134505, 5.43874985635486, 5.491812087098393, 5.5443665102516455, 5.596427431853289, 5.648008498577176, 5.6991227395100035, 5.749782604586021, 5.800000000000001, 5.849786320883866, 5.8991524815010505, 5.948108943185221, 5.99666574022598, 6.044832503882966, 6.092618484691127, 6.1400325732035, 6.187083319303208, 6.23377895020348, 6.280127387243033, 6.326136261573885, 6.3718129288295975, 6.417164482853779, 6.462197768561405, 6.5069193939989765, 6.55133574166368, 6.59545297913646, 6.639277069079134, 6.682813778641449, 6.726068688320096, 6.76904720030818, 6.811754546370562, 6.854195795277518, 6.8963758598266685, 6.938299503480662, 6.97997134664606, 7.021395872616784, 7.062577433203831, 7.103520254071217, 7.144228439796701, 7.184705978674423, 7.224956747275378, 7.264984514780469, 7.3047929470998705, 7.3443856107914165, 7.383765976789894, 7.4229374239582535, 7.4619032424710525, 7.5006666370396715, 7.539230729988306, 7.577598564189055, 7.6157731058639095, 7.653757247260983], [0.0, 0.7681145747868608, 1.0862780491200215, 1.3304134695650072, 1.5362291495737217, 1.7175564037317668, 1.8814887722226779, 2.0322401432901573, 2.172556098240043, 2.3043437243605824, 2.4289915602982237, 2.5475478405713994, 2.6608269391300143, 2.7694764848252458, 2.8740215726399825, 2.974894956128703, 3.0724582991474434, 3.167017524422623, 3.2588341473600644, 3.3481338085566414, 3.4351128074635335, 3.5199431813596083, 3.602776706930364, 3.6837480912787726, 3.7629775444453557, 3.840572873934304, 3.916631205513228, 3.9912404086950213, 4.064480286580315, 4.136423575989287, 4.207136793592525, 4.276680956068619, 4.345112196480086, 4.412482294582042, 4.4788391353117385, 4.544227107000705, 4.608687448721165, 4.672258554489466, 4.734976240700686, 4.796873982084583, 4.857983120596447, 4.9183330509431755, 4.9779513858614575, 5.03686410378521, 5.095095681142799, 5.1526692111953, 5.209606511052442, 5.265928218272634, 5.321653878260029, 5.376802023508025, 5.431390245600108, 5.485435260760991, 5.5389529696504916, 5.591958512006326, 5.644466316668034, 5.6964901474504455, 5.748043145279965, 5.799137866959191, 5.849786320883866, 5.8999999999999995, 5.949789912257406, 5.999166608788257, 6.048140210014975, 6.096720429870472, 6.144916598294887, 6.192737682156413, 6.240192304729077, 6.287288763847259, 6.334035048845246, 6.380438856379708, 6.4265076052238514, 6.472248450113762, 6.517668294720129, 6.562773803811921, 6.607571414672716, 6.652067347825035, 6.696267617113283, 6.740178039191546, 6.783804242458652, 6.827151675479314, 6.870225614927067, 6.913031173081747, 6.955573304911681, 6.997856814768361, 7.0398863627192165, 7.0816664705420855, 7.123201527403251, 7.164495795239188, 7.205553413860728, 7.246378405796926, 7.286974680894671, 7.327346040688948, 7.367496182557545, 7.407428703673091, 7.447147104764348, 7.486654793697916, 7.525955088890711, 7.565051222562872, 7.603946343840151, 7.642643521714199, 7.681145747868608, 7.719455939378112], [0.0, 0.7745966692414833, 1.0954451150103321, 1.3416407864998738, 1.5491933384829666, 1.7320508075688772, 1.8973665961010275, 2.0493901531919194, 2.1908902300206643, 2.3237900077244498, 2.449489742783178, 2.569046515733026, 2.6832815729997477, 2.792848008753788, 2.8982753492378874, 2.9999999999999996, 3.098386676965933, 3.1937438845342623, 3.2863353450309964, 3.3763886032268267, 3.4641016151377544, 3.5496478698597693, 3.63318042491699, 3.714835124201342, 3.794733192202055, 3.8729833462074166, 3.9496835316262997, 4.024922359499621, 4.098780306383839, 4.171330722922842, 4.242640687119285, 4.3127717305695645, 4.381780460041329, 4.449719092257398, 4.516635916254486, 4.58257569495584, 4.6475800154488995, 4.711687595755898, 4.774934554525329, 4.8373546489791295, 4.898979485566356, 4.959838707054898, 5.019960159204453, 5.079370039680117, 5.138093031466052, 5.196152422706631, 5.253570214625478, 5.310367218940701, 5.366563145999495, 5.422176684690383, 5.477225575051661, 5.531726674375732, 5.585696017507576, 5.639148871948674, 5.692099788303082, 5.744562646538029, 5.796550698475775, 5.848076606885378, 5.8991524815010505, 5.949789912257406, 5.999999999999999, 6.049793384901669, 6.099180272790762, 6.148170459575758, 6.196773353931866, 6.244997998398397, 6.292853089020909, 6.340346993658943, 6.387487769068525, 6.434283176858164, 6.48074069840786, 6.526867548832287, 6.572670690061993, 6.618156843109718, 6.663332499583071, 6.7082039324993685, 6.752777206453653, 6.797058187186571, 6.841052550594828, 6.884765791223402, 6.928203230275509, 6.97137002317335, 7.014271166700073, 7.056911505750939, 7.099295739719539, 7.1414284285428495, 7.183313998427188, 7.224956747275377, 7.26636084983398, 7.307530362578043, 7.348469228349534, 7.389181280764466, 7.429670248402684, 7.469939758793239, 7.5099933422074345, 7.549834435270749, 7.58946638440411, 7.628892449104261, 7.668115805072325, 7.707139547199078, 7.745966692414833, 7.784600182411426], [0.0, 0.7810249675906654, 1.104536101718726, 1.3527749258468684, 1.5620499351813308, 1.746424919657298, 1.9131126469708992, 2.0663978319771825, 2.209072203437452, 2.3430749027719964, 2.4698178070456938, 2.5903667693977237, 2.705549851693737, 2.816025568065745, 2.9223278392404914, 3.0248966924508345, 3.1240998703626617, 3.2202484376209237, 3.3136083051561784, 3.4044089061098406, 3.492849839314596, 3.5791060336346563, 3.6633318168028404, 3.745664160065609, 3.8262252939417984, 3.9051248379533274, 3.9824615503479754, 4.058324777540605, 4.132795663954365, 4.205948168962618, 4.277849927241487, 4.34856298103178, 4.418144406874904, 4.486646854834912, 4.5541190146942805, 4.620606020859168, 4.686149805543993, 4.750789408087881, 4.814561246884289, 4.87749935930288, 4.9396356140913875, 5.000999900019996, 5.061620293937506, 5.121523210920751, 5.180733538795447, 5.239274758971893, 5.297169055259611, 5.354437412091022, 5.411099703387474, 5.467174773134658, 5.522680508593631, 5.577633906953737, 5.63205113613149, 5.6859475903318, 5.739337940912697, 5.792236183029832, 5.844655678480983, 5.8966091951222275, 5.948108943185221, 5.999166608788257, 6.049793384901669, 6.1, 6.149796744608719, 6.199193495931548, 6.248199740725323, 6.296824596572465, 6.345076831686122, 6.392964883369843, 6.440496875241847, 6.487680633323437, 6.534523701081817, 6.5810333535091585, 6.627216610312357, 6.673080248281149, 6.71863081289633, 6.7638746292343415, 6.808817812219681, 6.853466276272176, 6.897825744392215, 6.941901756723442, 6.985699678629192, 7.029224708315989, 7.07248188403477, 7.115476090888086, 7.158212067269313, 7.200694410957877, 7.242927584892728, 7.284915922644544, 7.326663633605681, 7.368174807915458, 7.409453421137082, 7.450503338701353, 7.491328320131218, 7.531932023060219, 7.572318007057021, 7.6124897372673015, 7.652450587883597, 7.692203845452876, 7.731752712031082, 7.771100308193172, 7.810249675906655, 7.849203781276163], [0.0, 0.787400787401181, 1.1135528725660042, 1.3638181696985856, 1.574801574802362, 1.760681686165901, 1.928730152198591, 2.083266665599966, 2.2271057451320084, 2.362202362203543, 2.4899799195977463, 2.6115129714401193, 2.727636339397171, 2.839013913315678, 2.9461839725312466, 3.049590136395381, 3.149603149604724, 3.246536616149585, 3.340658617698013, 3.432200460346103, 3.521363372331802, 3.608323710533743, 3.6932370625238775, 3.7762415176998414, 3.857460304397182, 3.9370039370059056, 4.014971979976946, 4.091454509095756, 4.166533331199932, 4.240283009422838, 4.3127717305695645, 4.384062043356595, 4.454211490264017, 4.523273151159457, 4.591296113299598, 4.658325879540846, 4.724404724407086, 4.789572005931219, 4.853864439804639, 4.917316341257699, 4.979959839195493, 5.041825066382213, 5.10294032886923, 5.163332257370234, 5.223025942880239, 5.282045058497702, 5.340411969127476, 5.3981478305063115, 5.455272678794342, 5.511805511808268, 5.5677643628300215, 5.62316636780382, 5.678027826631356, 5.732364259186606, 5.786190456595773, 5.839520528262573, 5.892367945062493, 5.944745579080739, 5.99666574022598, 6.048140210014975, 6.099180272790762, 6.149796744608719, 6.199999999999999, 6.249799996799897, 6.299206299209448, 6.348228099241551, 6.39687423668779, 6.445153217728807, 6.49307323229917, 6.540642170307133, 6.587867636800241, 6.6347569661593475, 6.681317235396026, 6.727555276621664, 6.773477688750439, 6.819090848492928, 6.864400920692206, 6.90941386804988, 6.954135460285484, 6.998571282769077, 7.042726744663604, 7.08660708661063, 7.130217387990355, 7.173562573784381, 7.216647421067486, 7.259476565152615, 7.302054505411474, 7.344385610791416, 7.386474125047755, 7.428324171709255, 7.469939758793239, 7.511324783285569, 7.552483035399683, 7.593418202627852, 7.634133873596926, 7.674633541739956, 7.714920608794364, 7.754998388136519, 7.79487010796203, 7.834538914320357, 7.874007874011811, 7.913279977354524], [0.0, 0.7937253933193772, 1.1224972160321824, 1.3747727084867523, 1.5874507866387544, 1.7748239349298849, 1.9442222095223582, 2.1, 2.244994432064365, 2.3811761799581315, 2.5099800796022267, 2.632489316217637, 2.7495454169735045, 2.861817604250837, 2.9698484809834995, 3.074085229787879, 3.1749015732775088, 3.2726136343907144, 3.3674916480965473, 3.4597687784012394, 3.5496478698597698, 3.6373066958946425, 3.722902093797257, 3.8065732621348563, 3.8884444190447165, 3.968626966596886, 4.047221268969613, 4.124318125460256, 4.2, 4.274342054632503, 4.347413023856832, 4.419275958796871, 4.48998886412873, 4.559605246071199, 4.628174586162454, 4.695742752749559, 4.762352359916263, 4.828043081829325, 4.892851929090027, 4.956813492557492, 5.019960159204453, 5.082322303829225, 5.143928459844674, 5.204805471869242, 5.264978632435274, 5.324471804789654, 5.383307533477908, 5.441507144165117, 5.499090833947009, 5.55607775323564, 5.612486080160912, 5.668333088307356, 5.723635208501674, 5.7784080852774675, 5.8326666285670745, 5.886425061104576, 5.939696961966999, 5.9924953066314535, 6.044832503882966, 6.096720429870472, 6.148170459575758, 6.199193495931548, 6.249799996799897, 6.3, 6.3498031465550175, 6.3992187023104625, 6.448255578061403, 6.496922348312315, 6.545227268781429, 6.593178292750774, 6.640783086353597, 6.688049042882386, 6.734983296193095, 6.7815927332743895, 6.827884006044625, 6.87386354243376, 6.919537556802479, 6.96491205974634, 7.009992867328754, 7.0547856097829085, 7.0992957397195395, 7.143528539874395, 7.187489130426565, 7.23118247591637, 7.274613391789285, 7.317786550590281, 7.3607064878311785, 7.40337760755184, 7.445804187594514, 7.487990384609211, 7.52994023880668, 7.571657678474378, 7.6131465242697125, 7.654410493303845, 7.695453203028396, 7.736278174936576, 7.776888838089433, 7.817288532477231, 7.857480512225277, 7.897467948652911, 7.937253933193772, 7.976841480185], [0.0, 0.8, 1.131370849898476, 1.385640646055102, 1.6, 1.788854381999832, 1.9595917942265426, 2.1166010488516727, 2.262741699796952, 2.4, 2.5298221281347035, 2.65329983228432, 2.771281292110204, 2.8844410203711917, 2.9933259094191533, 3.098386676965933, 3.2, 3.2984845004941286, 3.394112549695428, 3.4871191548325395, 3.577708763999664, 3.6660605559646724, 3.752332607858744, 3.836665218650176, 3.9191835884530852, 4.0, 4.079215610874228, 4.156921938165306, 4.233202097703345, 4.308131845707604, 4.381780460041329, 4.454211490264018, 4.525483399593904, 4.595650117230424, 4.664761515876241, 4.732863826479693, 4.8, 4.866210024238576, 4.931531202375181, 4.9959983987187195, 5.059644256269407, 5.122499389946279, 5.184592558726289, 5.2459508194416005, 5.30659966456864, 5.366563145999495, 5.4258639865002145, 5.4845236803208355, 5.542562584220408, 5.6000000000000005, 5.656854249492381, 5.713142742834281, 5.768882040742383, 5.8240879114244155, 5.878775382679628, 5.932958789676531, 5.986651818838307, 6.0398675482166, 6.092618484691127, 6.144916598294887, 6.196773353931866, 6.248199740725323, 6.299206299209448, 6.3498031465550175, 6.4, 6.449806198638839, 6.499230723708768, 6.5482822174979605, 6.596969000988257, 6.64529909033446, 6.6932802122726045, 6.740919818541087, 6.788225099390856, 6.835202996254025, 6.881860213634101, 6.92820323027551, 6.974238309665079, 7.019971509913698, 7.065408693062278, 7.110555533852471, 7.155417527999328, 7.2, 7.244308110509934, 7.288346863315439, 7.332121111929345, 7.37563556583431, 7.418894796396564, 7.4619032424710525, 7.504665215717488, 7.547184905645283, 7.58946638440411, 7.631513611335565, 7.673330437300352, 7.7149206087943645, 7.756287771866127, 7.797435475847171, 7.8383671769061705, 7.879086241436885, 7.919595949289333, 7.959899496852961, 8.0, 8.039900496896713], [0.0, 0.8062257748298549, 1.1401754250991378, 1.3964240043768943, 1.6124515496597098, 1.8027756377319946, 1.9748417658131499, 2.133072900770154, 2.2803508501982757, 2.4186773244895647, 2.5495097567963922, 2.6739483914241875, 2.7928480087537886, 2.9068883707497264, 3.016620625799671, 3.1224989991991987, 3.2249030993194197, 3.324154027718932, 3.420526275297414, 3.5142566781611158, 3.605551275463989, 3.6945906403822333, 3.7815340802378072, 3.866522985836241, 3.9496835316262997, 4.031128874149275, 4.110960958218893, 4.189272013130682, 4.266145801540308, 4.341658669218482, 4.415880433163923, 4.488875137492688, 4.560701700396551, 4.631414470763764, 4.701063709417263, 4.769696007084728, 4.8373546489791295, 4.904079934095691, 4.969909455915671, 5.034878350069642, 5.0990195135927845, 5.162363799656123, 5.224940191045253, 5.28677595515452, 5.347896782848375, 5.4083269131959835, 5.468089245796926, 5.527205442174191, 5.585696017507577, 5.643580423808984, 5.70087712549569, 5.757603668193913, 5.813776741499453, 5.869412236331676, 5.924525297439449, 5.979130371550699, 6.033241251599342, 6.08687111741328, 6.1400325732035, 6.192737682156413, 6.244997998398397, 6.296824596572465, 6.348228099241551, 6.3992187023104625, 6.449806198638839, 6.499999999999999, 6.549809157525125, 6.599242380758566, 6.648308055437864, 6.697014260101287, 6.745368781616021, 6.793379129711516, 6.841052550594828, 6.888396039717809, 6.93541635375988, 6.98212002188447, 7.0285133563222315, 7.074602462329597, 7.12039324756716, 7.165891430938652, 7.211102550927978, 7.256031973468694, 7.300684899377592, 7.345066371381541, 7.389181280764467, 7.433034373659253, 7.476630257007497, 7.519973404208288, 7.5630681604756145, 7.6059187479225665, 7.648529270389177, 7.6909037180295, 7.733045971672482, 7.774959806970066, 7.816648898345122, 7.858116822750854, 7.899367063252599, 7.940403012442127, 7.981227975693965, 8.021845174272563, 8.06225774829855, 8.10246875958186], [0.0, 0.812403840463596, 1.1489125293076057, 1.4071247279470291, 1.624807680927192, 1.8165902124584952, 1.98997487421324, 2.149418526020468, 2.2978250586152114, 2.437211521390788, 2.569046515733026, 2.6944387170614963, 2.8142494558940583, 2.9291637031753623, 3.0397368307141326, 3.1464265445104544, 3.249615361854384, 3.3496268448888453, 3.4467375879228173, 3.541186241925155, 3.6331804249169903, 3.722902093797257, 3.81051177665153, 3.8961519477556315, 3.97994974842648, 4.06201920231798, 4.142463035441596, 4.221374183841087, 4.298837052040936, 4.374928570845472, 4.449719092257397, 4.523273151159456, 4.595650117230423, 4.666904755831214, 4.737087712930805, 4.806245936279166, 4.874423042781576, 4.941659640242335, 5.007993610219566, 5.073460357586329, 5.138093031466052, 5.201922721455982, 5.264978632435274, 5.3272882407468805, 5.388877434122993, 5.449770637375485, 5.509990925582365, 5.569560126257728, 5.628498911788117, 5.686826883245172, 5.744562646538029, 5.801723881744115, 5.858327406350725, 5.914389233048499, 5.96992462263972, 6.024948132556827, 6.079473661428265, 6.133514490078261, 6.187083319303208, 6.240192304729077, 6.292853089020909, 6.345076831686122, 6.39687423668779, 6.448255578061403, 6.499230723708768, 6.549809157525125, 6.6, 6.649812027418519, 6.699253689777691, 6.748333127521196, 6.797058187186572, 6.8454364360499325, 6.8934751758456345, 6.941181455631311, 6.988562083862459, 7.035623639735144, 7.08237248385031, 7.128814768248646, 7.17495644586084, 7.2208032794142785, 7.266360849833981, 7.311634564172365, 7.356629663099809, 7.401351227985333, 7.445804187594514, 7.489993324429602, 7.533923280734945, 7.577598564189054, 7.62102355330306, 7.664202502543888, 7.707139547199077, 7.749838707999025, 7.792303895511263, 7.834538914320357, 7.8765474670060875, 7.918333157931661, 7.95989949685296, 8.001249902359007, 8.04238770515324, 8.083316151184489, 8.12403840463596, 8.16455755078008], [0.0, 0.8185352771872451, 1.1575836902790224, 1.4177446878757827, 1.6370705543744901, 1.8303005217723127, 2.004993765576342, 2.1656407827707715, 2.315167380558045, 2.455605831561735, 2.588435821108957, 2.714774392099646, 2.8354893757515653, 2.951270912674741, 3.062678566222711, 3.1701734968294715, 3.2741411087489802, 3.374907406137241, 3.4727510708370675, 3.567912554982255, 3.6606010435446255, 3.7509998667022106, 3.8392707640904935, 3.9255572852781047, 4.009987531152684, 4.092676385936225, 4.173727350941841, 4.253234063627348, 4.331281565541543, 4.407947368106838, 4.483302354291978, 4.557411546042337, 4.63033476111609, 4.702127178203499, 4.77283982551269, 4.8425200051213, 4.91121166312347, 4.978955713801841, 5.045790324617146, 5.111751167652823, 5.176871642217914, 5.241183072551464, 5.304714883949938, 5.367494760127856, 5.429548784199292, 5.490901565316937, 5.551576352712804, 5.61159513863928, 5.670978751503131, 5.729746940310715, 5.787918451395113, 5.845511098270194, 5.902541825349482, 5.959026766175833, 6.014981296729027, 6.070420084310475, 6.125357132445422, 6.17980582219215, 6.23377895020348, 6.287288763847259, 6.340346993658943, 6.392964883369843, 6.445153217728807, 6.496922348312315, 6.5482822174979605, 6.599242380758566, 6.649812027418519, 6.7, 6.749814812274482, 6.79926466612383, 6.848357467305573, 6.897100840208152, 6.945502141674135, 6.993568473962345, 7.041306696913577, 7.088723439378913, 7.13582510996451, 7.182617907142214, 7.229107828771128, 7.275300681071539, 7.321202087089251, 7.366817494685205, 7.4121521840825695, 7.457211275000863, 7.501999733404421, 7.546522377890362, 7.590783885739338, 7.634788798650556, 7.678541528180987, 7.722046360907191, 7.76530746332687, 7.808328886515987, 7.851114570556209, 7.893668348746355, 7.935993951610599, 7.978095010715276, 8.019975062305368, 8.061637550770936, 8.103085831953157, 8.144323176298936, 8.18535277187245, 8.226177727231525], [0.0, 0.8246211251235321, 1.16619037896906, 1.4282856857085702, 1.6492422502470643, 1.8439088914585775, 2.0199009876724157, 2.181742422927143, 2.33238075793812, 2.473863375370596, 2.6076809620810595, 2.734958866235469, 2.8565713714171403, 2.973213749463701, 3.0854497241083023, 3.1937438845342623, 3.2984845004941286, 3.4, 3.4985711369071804, 3.594440151122286, 3.687817782917155, 3.778888725538237, 3.867815921162743, 3.954743986657038, 4.039801975344831, 4.123105625617661, 4.204759208325728, 4.28485705712571, 4.363484845854286, 4.440720662234904, 4.516635916254486, 4.591296113299599, 4.66476151587624, 4.737087712930805, 4.8083261120685235, 4.878524367060187, 4.947726750741192, 5.015974481593781, 5.083306010855534, 5.149757275833494, 5.215361924162119, 5.280151512977635, 5.344155686354956, 5.407402333838309, 5.469917732470938, 5.531726674375732, 5.592852581643825, 5.653317610041028, 5.713142742834281, 5.772347875864725, 5.830951894845301, 5.888972745734184, 5.946427498927402, 6.003332407921454, 6.059702963017247, 6.115553940568263, 6.170899448216605, 6.2257529665093525, 6.280127387243033, 6.334035048845246, 6.387487769068525, 6.440496875241847, 6.49307323229917, 6.545227268781429, 6.596969000988257, 6.648308055437864, 6.699253689777691, 6.749814812274482, 6.8, 6.849817515817484, 6.899275324264137, 6.948381106416083, 6.997142273814361, 7.045565981523414, 7.093659140387279, 7.14142842854285, 7.188880302244572, 7.236021006050217, 7.282856582413251, 7.329392880723478, 7.37563556583431, 7.42159012611179, 7.467261881037788, 7.512655988397179, 7.557777451076474, 7.602631123499285, 7.647221717722065, 7.691553809211764, 7.735631842325486, 7.779460135510689, 7.8230428862431785, 7.866384175718855, 7.909487973314076, 7.952358140828418, 7.994998436522675, 8.037412518964047, 8.079603950689663, 8.121576201698781, 8.16333265278342, 8.204876598706406, 8.246211251235321, 8.287339742040265], [0.0, 0.8306623862918076, 1.174734012447073, 1.4387494569938162, 1.661324772583615, 1.8574175621006712, 2.0346989949375804, 2.1977260975835913, 2.349468024894146, 2.4919871588754225, 2.6267851073127395, 2.7549954627911823, 2.8774989139876324, 2.994995826374388, 3.1080540535840107, 3.217141588429082, 3.32264954516723, 3.424908757908742, 3.5242020373412193, 3.6207733980463352, 3.7148351242013424, 3.8065732621348563, 3.8961519477556315, 3.9837168574084183, 4.069397989875161, 4.153311931459037, 4.235563716909475, 4.316248370981448, 4.3954521951671826, 4.473253849269009, 4.54972526643093, 4.624932431938872, 4.698936049788292, 4.77179211617606, 4.843552415324934, 4.914264950122246, 4.983974317750845, 5.052722038663912, 5.120546845796843, 5.187484939737176, 5.253570214625479, 5.3188344587888805, 5.383307533477909, 5.447017532558529, 5.509990925582365, 5.572252686302012, 5.63382640840131, 5.69473440996154, 5.754997827975265, 5.814636704042653, 5.873670062235366, 5.932115979985557, 5.989991652748776, 6.047313453096343, 6.104096984812742, 6.1603571325045765, 6.216108107168021, 6.271363488110062, 6.326136261573885, 6.380438856379708, 6.434283176858164, 6.487680633323437, 6.540642170307133, 6.593178292750774, 6.64529909033446, 6.697014260101287, 6.748333127521196, 6.79926466612383, 6.849817515817484, 6.9, 6.949820141557622, 6.999285677838847, 7.048404074682439, 7.097182539571601, 7.145628033979938, 7.19374728496908, 7.2415467960926705, 7.289032857656769, 7.336211556382492, 7.383088784512889, 7.429670248402685, 7.475961476626268, 7.521967827636597, 7.567694497005016, 7.6131465242697125, 7.658328799418317, 7.703246069028303, 7.747902942086975, 7.792303895511263, 7.836453279386026, 7.880355321938218, 7.924014134263013, 7.967433714816837, 8.010617953691215, 8.053570636680355, 8.096295449154509, 8.138795979750322, 8.18107572388864, 8.223138087129511, 8.264986388373547, 8.306623862918075, 8.34805366537614], [0.0, 0.8366600265340756, 1.1832159566199232, 1.4491376746189442, 1.6733200530681511, 1.8708286933869709, 2.04939015319192, 2.2135943621178655, 2.3664319132398464, 2.5099800796022267, 2.6457513110645907, 2.774887385102322, 2.8982753492378883, 3.0166206257996717, 3.1304951684997055, 3.24037034920393, 3.3466401061363023, 3.4496376621320683, 3.5496478698597698, 3.6469165057620945, 3.7416573867739418, 3.834057902536163, 3.924283374069717, 4.012480529547776, 4.09878030638384, 4.183300132670378, 4.266145801540309, 4.3474130238568325, 4.427188724235731, 4.505552130427525, 4.58257569495584, 4.658325879540847, 4.732863826479693, 4.806245936279167, 4.878524367060187, 4.949747468305833, 5.019960159204453, 5.089204259999789, 5.157518783291051, 5.2249401910452535, 5.291502622129181, 5.35723809439155, 5.422176684690385, 5.486346689738081, 5.549774770204644, 5.612486080160912, 5.674504383644443, 5.735852159879995, 5.796550698475777, 5.856620185738529, 5.916079783099617, 5.974947698515863, 6.033241251599343, 6.090976933136425, 6.148170459575759, 6.2048368229954285, 6.260990336999411, 6.316644678941503, 6.3718129288295975, 6.4265076052238514, 6.48074069840786, 6.534523701081817, 6.587867636800241, 6.640783086353597, 6.6932802122726045, 6.745368781616021, 6.797058187186572, 6.848357467305573, 6.899275324264137, 6.949820141557622, 7.000000000000001, 7.049822692805827, 7.0992957397195395, 7.148426400264607, 7.197221686178633, 7.24568837309472, 7.293833011524189, 7.341661937191062, 7.3891812807644675, 7.436396977031284, 7.4833147735478835, 7.529940238806681, 7.576278769950325, 7.622335600063802, 7.668115805072326, 7.713624310270757, 7.75886589650833, 7.803845206050669, 7.848566748139434, 7.893034904268446, 7.937253933193772, 7.981227975693966, 8.024961059095553, 8.068457101577724, 8.1117199162693, 8.154753215150045, 8.19756061276768, 8.240145629781066, 8.282511696339462, 8.324662155306966, 8.366600265340756, 8.408329203831164], [0.0, 0.8426149773176359, 1.1916375287812984, 1.4594519519326425, 1.6852299546352718, 1.8841443681416774, 2.0639767440550294, 2.2293496809607953, 2.3832750575625967, 2.5278449319529073, 2.6645825188948455, 2.7946377224964243, 2.918903903865285, 3.0380915061926625, 3.152776554086889, 3.2634337744161437, 3.3704599092705436, 3.4741905532080417, 3.5749125863438955, 3.672873534441392, 3.768288736283355, 3.861346915261565, 3.952214569073901, 4.041039470235351, 4.127953488110059, 4.2130748865881795, 4.296510211788167, 4.378355855797928, 4.458699361921591, 4.537620521815371, 4.61519230368573, 4.69148164229596, 4.766550115125193, 4.8404545241123795, 4.913247398615299, 4.984977432245807, 5.0556898639058145, 5.1254268114957995, 5.194227565288221, 5.262128846769148, 5.329165037789691, 5.395368384086485, 5.46076917659042, 5.525395913416522, 5.589275444992849, 5.652433104425031, 5.71489282489182, 5.776677245614472, 5.83780780773057, 5.898304841223451, 5.958187643906493, 6.017474553332154, 6.076183012385325, 6.134329629226001, 6.191930232165088, 6.248999919987198, 6.305553108173778, 6.361603571427569, 6.417164482853779, 6.472248450113762, 6.526867548832287, 6.5810333535091585, 6.6347569661593475, 6.688049042882386, 6.740919818541087, 6.793379129711516, 6.8454364360499325, 6.897100840208152, 6.948381106416083, 6.999285677838847, 7.049822692805827, 7.1, 7.149825172687791, 7.199305522062527, 7.248448109768049, 7.297259759663212, 7.345747068882784, 7.3939164182454755, 7.441773982055624, 7.489325737341113, 7.53657747256671, 7.583534795858723, 7.630203142774117, 7.676587783644501, 7.72269383052313, 7.768526243760782, 7.814089838234521, 7.859389289251424, 7.904429138147802, 7.949213797602879, 7.993747556684537, 8.038034585643434, 8.082078940470701, 8.125884567233282, 8.16945530620004, 8.212794895770866, 8.255906976220118, 8.298795093265047, 8.341462701469089, 8.383913167489272, 8.426149773176359, 8.468175718535841], [0.0, 0.848528137423857, 1.2, 1.4696938456699071, 1.697056274847714, 1.8973665961010278, 2.078460969082653, 2.244994432064365, 2.4, 2.545584412271571, 2.6832815729997477, 2.814249455894058, 2.9393876913398143, 3.0594117081556713, 3.1749015732775088, 3.2863353450309964, 3.394112549695428, 3.4985711369071804, 3.6, 3.6986484017813863, 3.7947331922020555, 3.8884444190447165, 3.97994974842648, 4.069397989875161, 4.156921938165306, 4.242640687119286, 4.3266615305567875, 4.409081537009721, 4.48998886412873, 4.5694638635183455, 4.6475800154489, 4.724404724407087, 4.8, 4.874423042781577, 4.947726750741193, 5.019960159204453, 5.091168824543142, 5.1613951602255765, 5.230678732248808, 5.299056519796709, 5.366563145999495, 5.43323108288245, 5.499090833947008, 5.564171097297422, 5.628498911788116, 5.692099788303082, 5.754997827975264, 5.817215828899595, 5.8787753826796285, 5.939696961966999, 6.0, 6.059702963017248, 6.118823416311343, 6.177378084592201, 6.235382907247959, 6.29285308902091, 6.3498031465550175, 6.406246951218787, 6.462197768561405, 6.517668294720129, 6.572670690061993, 6.627216610312357, 6.681317235396026, 6.734983296193095, 6.788225099390856, 6.841052550594828, 6.8934751758456345, 6.945502141674135, 6.997142273814361, 7.048404074682439, 7.0992957397195395, 7.149825172687791, 7.2, 7.249827584156743, 7.299315036357863, 7.3484692283495345, 7.397296803562773, 7.445804187594514, 7.493997598078079, 7.541883053985921, 7.589466384404111, 7.636753236814713, 7.68374908491942, 7.730459236035075, 7.776888838089433, 7.823042886243179, 7.868926229162401, 7.914543574963752, 7.95989949685296, 8.0049984384758, 8.049844718999243, 8.094442537939225, 8.138795979750322, 8.182909018191515, 8.226785520481254, 8.270429251254132, 8.313843876330612, 8.357032966310472, 8.4, 8.442748367682174, 8.485281374238571, 8.527602242131138], [0.0, 0.8544003745317531, 1.2083045973594573, 1.4798648586948744, 1.7088007490635062, 1.91049731745428, 2.092844953645635, 2.260530911091463, 2.4166091947189146, 2.563201123595259, 2.701851217221259, 2.833725463060951, 2.9597297173897488, 3.0805843601498726, 3.196873472629156, 3.309078421554859, 3.4176014981270124, 3.522782990761707, 3.6249137920783716, 3.7242448899072147, 3.82099463490856, 3.915354390090379, 4.007492981902776, 4.097560249709576, 4.18568990729127, 4.272001872658766, 4.356604182158393, 4.439594576084623, 4.521061822182926, 4.601086828130937, 4.679743582719036, 4.757099956906519, 4.833218389437829, 4.908156476723211, 4.98196748283246, 5.054700782440045, 5.126402247190518, 5.197114584074513, 5.266877632905477, 5.335728628781641, 5.403702434442518, 5.470831746635972, 5.537147279962851, 5.602677931132575, 5.667450926121902, 5.731491952362839, 5.794825277780168, 5.857473858242988, 5.9194594347794975, 5.980802621722272, 6.041522986797286, 6.101639124038721, 6.161168720299745, 6.220128616033596, 6.278534860936905, 6.336402764976356, 6.393746945258312, 6.450581369148055, 6.5069193939989765, 6.562773803811921, 6.618156843109718, 6.673080248281149, 6.727555276621664, 6.7815927332743895, 6.835202996254025, 6.888396039717809, 6.941181455631311, 6.993568473962345, 7.045565981523414, 7.097182539571601, 7.148426400264607, 7.199305522062527, 7.249827584156743, 7.3, 7.349829930005183, 7.399324293474371, 7.448489779814429, 7.4973328590906245, 7.545859791965394, 7.594076639065476, 7.64198926981712, 7.689603370785778, 7.736924453553881, 7.783957862167549, 7.830708780180758, 7.877182237323192, 7.923383115816122, 7.969316156358713, 8.014985963805552, 8.060397012554654, 8.105553651663778, 8.150460109711599, 8.195120499419152, 8.239538822045807, 8.283718971573094, 8.327664738688751, 8.37137981458254, 8.414867794564572, 8.4581321815162, 8.501176389182852, 8.544003745317532, 8.586617494683225], [0.0, 0.8602325267042626, 1.2165525060596438, 1.489966442575134, 1.7204650534085253, 1.9235384061671346, 2.1071307505705477, 2.2759613353482084, 2.4331050121192876, 2.580697580112788, 2.7202941017470885, 2.8530685235374214, 2.979932885150268, 3.1016124838541645, 3.218695387886216, 3.3316662497915357, 3.4409301068170506, 3.5468295701936396, 3.6496575181789317, 3.749666651850535, 3.847076812334269, 3.9420806688854046, 4.034848200366403, 4.125530268947254, 4.214261501141095, 4.301162633521313, 4.386342439892262, 4.469899327725402, 4.551922670696417, 4.632493928760188, 4.711687595755898, 4.789572005931219, 4.866210024238575, 4.941659640242335, 5.015974481593781, 5.089204259999788, 5.161395160225576, 5.232590180780452, 5.302829433425141, 5.372150407425317, 5.440588203494177, 5.508175741568165, 5.574943945906542, 5.6409219104681805, 5.706137047074843, 5.770615218501403, 5.834380858325929, 5.897457079114692, 5.959865770300536, 6.021627686929839, 6.082762530298219, 6.143289021363068, 6.203224967708329, 6.262587324740471, 6.321392251711643, 6.3796551630946325, 6.437390775772432, 6.494613152451807, 6.55133574166368, 6.607571414672716, 6.663332499583071, 6.71863081289633, 6.773477688750439, 6.827884006044625, 6.881860213634101, 6.93541635375988, 6.988562083862459, 7.041306696913577, 7.093659140387279, 7.145628033979938, 7.197221686178633, 7.248448109768049, 7.299315036357863, 7.349829930005183, 7.3999999999999995, 7.44983221287567, 7.49933330370107, 7.548509786706248, 7.597367965289032, 7.645913941446111, 7.694153624668538, 7.742092740338364, 7.789736837660179, 7.837091297158659, 7.884161337770809, 7.930952023559341, 7.977468270071652, 8.023714850367003, 8.069696400732806, 8.115417426109392, 8.160882305241266, 8.206095295571457, 8.251060537894508, 8.295782060782456, 8.340263784797218, 8.384509526501832, 8.42852300228219, 8.472307831990054, 8.515867542417507, 8.559205570612264, 8.602325267042627, 8.645229898620395], [0.0, 0.8660254037844387, 1.224744871391589, 1.5000000000000002, 1.7320508075688774, 1.9364916731037085, 2.121320343559643, 2.29128784747792, 2.449489742783178, 2.598076211353316, 2.7386127875258306, 2.8722813232690148, 3.0000000000000004, 3.122498999199199, 3.24037034920393, 3.3541019662496843, 3.464101615137755, 3.570714214271425, 3.6742346141747673, 3.7749172176353754, 3.872983346207417, 3.968626966596886, 4.06201920231798, 4.153311931459037, 4.242640687119286, 4.330127018922194, 4.415880433163924, 4.5, 4.58257569495584, 4.663689526544408, 4.743416490252569, 4.8218253804964775, 4.898979485566356, 4.974937185533101, 5.049752469181039, 5.123475382979799, 5.196152422706632, 5.26782687642637, 5.338539126015656, 5.408326913195984, 5.477225575051661, 5.545268253204709, 5.612486080160912, 5.678908345800274, 5.7445626465380295, 5.809475019311125, 5.873670062235366, 5.937171043518958, 6.000000000000001, 6.06217782649107, 6.123724356957946, 6.184658438426491, 6.244997998398398, 6.304760106459247, 6.363961030678928, 6.422616289332565, 6.48074069840786, 6.5383484153110105, 6.59545297913646, 6.652067347825035, 6.7082039324993685, 6.7638746292343415, 6.819090848492928, 6.87386354243376, 6.92820323027551, 6.98212002188447, 7.035623639735144, 7.088723439378913, 7.14142842854285, 7.19374728496908, 7.24568837309472, 7.297259759663212, 7.3484692283495345, 7.399324293474371, 7.44983221287567, 7.5, 7.549834435270751, 7.599342076785332, 7.6485292703891785, 7.697402159170327, 7.745966692414834, 7.794228634059948, 7.842193570679062, 7.88986691902975, 7.937253933193772, 7.984359711335657, 8.031189202104505, 8.077747210701757, 8.12403840463596, 8.170067319184096, 8.215838362577491, 8.261355820929154, 8.306623862918075, 8.351646544245034, 8.396427811873334, 8.440971508067065, 8.485281374238571, 8.529361054615991, 8.573214099741124, 8.616843969807043, 8.660254037844387, 8.703447592764606], [0.0, 0.8717797887081349, 1.2328828005937953, 1.5099668870541503, 1.7435595774162698, 1.9493588689617931, 2.1354156504062627, 2.3065125189341593, 2.4657656011875906, 2.615339366124404, 2.7568097504180447, 2.8913664589601926, 3.0199337741083006, 3.1432467291003428, 3.2619012860600183, 3.3763886032268267, 3.4871191548325395, 3.594440151122286, 3.6986484017813863, 3.8000000000000007, 3.8987177379235862, 3.9949968710876362, 4.0890096600521755, 4.180908992073375, 4.270831300812525, 4.358898943540674, 4.445222154178575, 4.529900661162451, 4.613025037868319, 4.694677837722201, 4.774934554525329, 4.8538644398046396, 4.931531202375181, 5.007993610219566, 5.083306010855535, 5.157518783291051, 5.230678732248808, 5.302829433425142, 5.374011537017762, 5.444263035526481, 5.513619500836089, 5.582114294781146, 5.649778756730215, 5.716642371182581, 5.782732917920385, 5.848076606885378, 5.912698199637794, 5.976621118993575, 6.039867548216601, 6.102458520956944, 6.164414002968978, 6.225752966509353, 6.2864934582006855, 6.3466526610489735, 6.406246951218788, 6.465291950097846, 6.523802572120037, 6.581793068761734, 6.639277069079134, 6.696267617113283, 6.752777206453653, 6.808817812219681, 6.864400920692206, 6.919537556802479, 6.974238309665079, 7.0285133563222315, 7.08237248385031, 7.13582510996451, 7.188880302244572, 7.2415467960926705, 7.293833011524189, 7.345747068882784, 7.397296803562773, 7.448489779814429, 7.49933330370107, 7.549834435270751, 7.600000000000001, 7.649836599562112, 7.6993506219680645, 7.748548251124208, 7.7974354758471724, 7.8460180983732135, 7.894301742396222, 7.942291860665913, 7.9899937421752725, 8.037412518964048, 8.084553172563096, 8.13142054010245, 8.178019320104351, 8.224354077980836, 8.270429251254134, 8.316249154516717, 8.36181798414675, 8.407139822793482, 8.452218643646177, 8.497058314499201, 8.54166260162505, 8.586035173466273, 8.630179604156568, 8.674099376880578, 8.717797887081348, 8.761278445523805], [0.0, 0.8774964387392122, 1.2409673645990857, 1.5198684153570665, 1.7549928774784245, 1.9621416870348585, 2.149418526020468, 2.32163735324878, 2.4819347291981715, 2.6324893162176366, 2.7748873851023217, 2.91032644217105, 3.039736830714133, 3.1638584039112754, 3.283291031876401, 3.3985290935932855, 3.509985754956849, 3.6180105030251086, 3.722902093797257, 3.824918299781056, 3.924283374069717, 4.02119385257662, 4.115823125451336, 4.2083250825001635, 4.298837052040936, 4.387482193696061, 4.474371464239419, 4.559605246071199, 4.64327470649756, 4.725462940284264, 4.806245936279166, 4.8856934001224435, 4.963869458396343, 5.040833264451424, 5.1166395221864125, 5.191338940966964, 5.264978632435273, 5.3376024580330075, 5.409251334519409, 5.479963503528103, 5.549774770204643, 5.61871871515206, 5.686826883245173, 5.754128952326321, 5.8206528843421, 5.886425061104575, 5.951470406546605, 6.015812497078014, 6.079473661428266, 6.142475071174486, 6.2048368229954285, 6.266578013557321, 6.327716807822551, 6.388270501473776, 6.448255578061404, 6.507687761409578, 6.566582063752802, 6.624952830020755, 6.682813778641449, 6.740178039191546, 6.797058187186571, 6.853466276272176, 6.90941386804988, 6.96491205974634, 7.019971509913698, 7.074602462329597, 7.128814768248646, 7.182617907142214, 7.236021006050217, 7.289032857656769, 7.341661937191062, 7.3939164182454755, 7.445804187594514, 7.4973328590906245, 7.548509786706248, 7.599342076785332, 7.649836599562112, 7.7, 7.749838707999026, 7.799358948016177, 7.848566748139434, 7.897467948652911, 7.9460682101275735, 7.994373021069257, 8.04238770515324, 8.090117428072352, 8.137567204023572, 8.184741901856162, 8.231646250902672, 8.278284846512591, 8.324662155306966, 8.370782520170978, 8.416650165000327, 8.462269199216012, 8.507643622061282, 8.55277732669336, 8.597674104081872, 8.64233764672499, 8.6867715521936, 8.73097932651315, 8.774964387392123, 8.81873006730561], [0.0, 0.8831760866327848, 1.2489995996796797, 1.5297058540778359, 1.7663521732655696, 1.9748417658131503, 2.1633307652783937, 2.336664289109585, 2.4979991993593593, 2.6495282598983545, 2.7928480087537886, 2.9291637031753623, 3.0594117081556718, 3.1843366656181322, 3.3045423283716615, 3.420526275297414, 3.532704346531139, 3.6414282912066254, 3.7469987990390394, 3.8496753109840323, 3.9496835316263006, 4.047221268969613, 4.1424630354415966, 4.235563716909475, 4.3266615305567875, 4.415880433163924, 4.503332099679082, 4.589117562233508, 4.67332857821917, 4.756048780237647, 4.83735464897913, 4.917316341257699, 4.995998398718719, 5.07346035758633, 5.149757275833494, 5.2249401910452535, 5.299056519796709, 5.372150407425318, 5.444263035526481, 5.515432893255072, 5.585696017507577, 5.655086206239478, 5.723635208501675, 5.791372894228104, 5.858327406350725, 5.92452529743945, 5.989991652748776, 6.054750201288242, 6.1188234163113435, 6.182232606429493, 6.244997998398399, 6.307138812488593, 6.3686733312362644, 6.429618962271405, 6.489992295835182, 6.549809157525127, 6.609084656743323, 6.667833231267862, 6.726068688320096, 6.783804242458652, 6.841052550594828, 6.897825744392215, 6.954135460285484, 7.009992867328754, 7.065408693062278, 7.12039324756716, 7.17495644586084, 7.229107828771128, 7.282856582413251, 7.336211556382492, 7.3891812807644675, 7.441773982055624, 7.493997598078079, 7.545859791965394, 7.597367965289032, 7.6485292703891785, 7.6993506219680645, 7.749838707999026, 7.800000000000002, 7.849840762716147, 7.899367063252601, 7.9485847796950635, 7.997499609252884, 8.046117075956577, 8.094442537939226, 8.142481194328914, 8.19023809177731, 8.23771813064759, 8.284926070883193, 8.33186653757728, 8.378544026261366, 8.424962907930219, 8.47112743381895, 8.517041739947036, 8.56270985144306, 8.608135686662937, 8.653323061113575, 8.698275691193055, 8.742997197757758, 8.787491109526087, 8.831760866327848, 8.875809822207776], [0.0, 0.8888194417315589, 1.2569805089976536, 1.5394804318340656, 1.7776388834631178, 1.9874606914351793, 2.177154105707724, 2.3515952032609695, 2.513961017995307, 2.6664583251946765, 2.8106938645110393, 2.9478805945967355, 3.078960863668131, 3.204684071792413, 3.3256578296631782, 3.442382895611701, 3.5552777669262356, 3.664696440361739, 3.7709415269929605, 3.874274125562104, 3.9749213828703587, 4.07308237088326, 4.168932717135166, 4.262628297189424, 4.354308211415448, 4.444097208657795, 4.532107677449864, 4.618441295502196, 4.703190406521939, 4.786439177509728, 4.868264577855234, 4.948737212663449, 5.027922035990614, 5.105878964487898, 5.182663407939976, 5.2583267300539625, 5.332916650389353, 5.406477596365309, 5.47905101272109, 5.550675634551168, 5.621387729022079, 5.691221310052879, 5.760208329565868, 5.8283788483591215, 5.895761189193471, 5.962382074305537, 6.028266749240615, 6.09343909463285, 6.157921727336262, 6.221736092120913, 6.284902544988268, 6.347440429023341, 6.409368143584826, 6.470703207534712, 6.5314623171231725, 6.591661399070799, 6.6513156593263565, 6.710439627923047, 6.76904720030818, 6.827151675479314, 6.884765791223402, 6.941901756723442, 6.998571282769077, 7.0547856097829085, 7.110555533852471, 7.165891430938652, 7.2208032794142785, 7.275300681071539, 7.329392880723478, 7.383088784512889, 7.436396977031284, 7.489325737341113, 7.541883053985921, 7.594076639065476, 7.645913941446111, 7.697402159170327, 7.748548251124208, 7.799358948016177, 7.849840762716147, 7.9, 7.949842765740717, 7.999374975584031, 8.048602363143555, 8.097530487747484, 8.14616474176652, 8.194510357550353, 8.242572413997951, 8.290355842785038, 8.337865434270332, 8.385105843100611, 8.432081593533118, 8.478797084492587, 8.525256594378847, 8.571464285639882, 8.61742420912421, 8.663140308225419, 8.708616422830897, 8.753856293085923, 8.798863562983575, 8.843641783790206, 8.88819441731559, 8.932524839036274], [0.0, 0.894427190999916, 1.2649110640673518, 1.549193338482967, 1.788854381999832, 2.0000000000000004, 2.1908902300206647, 2.366431913239847, 2.5298221281347035, 2.6832815729997477, 2.8284271247461903, 2.9664793948382657, 3.098386676965934, 3.22490309931942, 3.3466401061363023, 3.4641016151377544, 3.577708763999664, 3.687817782917155, 3.7947331922020555, 3.8987177379235862, 4.000000000000001, 4.09878030638384, 4.1952353926806065, 4.289522117905444, 4.3817804600413295, 4.47213595499958, 4.560701700396552, 4.647580015448901, 4.732863826479694, 4.8166378315169185, 4.898979485566357, 4.979959839195494, 5.059644256269407, 5.1380930314660525, 5.21536192416212, 5.291502622129181, 5.366563145999495, 5.440588203494178, 5.513619500836089, 5.585696017507577, 5.656854249492381, 5.727128425310542, 5.796550698475777, 5.865151319446072, 5.9329587896765315, 6.0, 6.066300355241241, 6.131883886702357, 6.196773353931868, 6.260990336999412, 6.324555320336759, 6.387487769068526, 6.44980619863884, 6.511528238439884, 6.572670690061994, 6.6332495807108005, 6.6932802122726045, 6.752777206453653, 6.811754546370562, 6.870225614927067, 6.928203230275509, 6.985699678629192, 7.042726744663604, 7.0992957397195395, 7.155417527999328, 7.211102550927978, 7.266360849833981, 7.321202087089251, 7.37563556583431, 7.429670248402685, 7.4833147735478835, 7.53657747256671, 7.589466384404111, 7.64198926981712, 7.694153624668538, 7.745966692414834, 7.7974354758471724, 7.848566748139434, 7.899367063252601, 7.949842765740717, 8.000000000000002, 8.049844718999244, 8.099382692526635, 8.148619514985345, 8.19756061276768, 8.246211251235321, 8.29457654133109, 8.342661445845685, 8.390470785361213, 8.438009243891594, 8.485281374238571, 8.532291603080617, 8.579044235810889, 8.62554346113913, 8.671793355471522, 8.717797887081348, 8.763560920082659, 8.809086218218098, 8.854377448471462, 8.899438184514796, 8.94427190999916, 8.988882021697695], [0.0, 0.9, 1.2727922061357855, 1.5588457268119897, 1.8, 2.012461179749811, 2.2045407685048604, 2.3811761799581315, 2.545584412271571, 2.7, 2.8460498941515415, 2.9849623113198605, 3.1176914536239795, 3.2449961479175906, 3.3674916480965473, 3.485685011586675, 3.6, 3.710795063055895, 3.8183766184073566, 3.9230090491866068, 4.024922359499622, 4.124318125460256, 4.221374183841087, 4.316248370981448, 4.409081537009721, 4.500000000000001, 4.589117562233507, 4.676537180435969, 4.762352359916263, 4.846648326421054, 4.929503017546495, 5.01098792654702, 5.091168824543142, 5.170106381884226, 5.247856705360771, 5.324471804789654, 5.4, 5.474486277268398, 5.547972602672079, 5.620498198558559, 5.692099788303083, 5.762811813689565, 5.832666628567075, 5.9016946718718, 5.969924622639721, 6.037383539249432, 6.104096984812742, 6.17008914036094, 6.235382907247959, 6.300000000000001, 6.3639610306789285, 6.427285585688566, 6.489992295835181, 6.552098900352467, 6.613622305514581, 6.674578638386097, 6.734983296193095, 6.794850991743675, 6.854195795277518, 6.913031173081747, 6.97137002317335, 7.029224708315989, 7.08660708661063, 7.143528539874395, 7.2, 7.256031973468694, 7.311634564172365, 7.366817494685205, 7.42159012611179, 7.475961476626268, 7.529940238806681, 7.583534795858723, 7.636753236814713, 7.689603370785778, 7.742092740338364, 7.794228634059948, 7.8460180983732135, 7.897467948652911, 7.9485847796950635, 7.999374975584031, 8.049844718999244, 8.100000000000001, 8.149846624323676, 8.19939022122987, 8.248636250920512, 8.2975900115636, 8.346256645946134, 8.394641147779934, 8.442748367682174, 8.490583018850943, 8.538149682454625, 8.58545281275251, 8.632496741962896, 8.67928568489366, 8.725823743349393, 8.772114910328067, 8.818163074019441, 8.863972021616496, 8.909545442950499, 8.95488693395958, 9.000000000000002, 9.044888059008803], [0.0, 0.9055385138137417, 1.2806248474865698, 1.5684387141358125, 1.8110770276274835, 2.024845673131659, 2.2181073012818837, 2.395829710142188, 2.5612496949731396, 2.716615541441225, 2.863564212655271, 3.003331483536242, 3.136877428271625, 3.264965543462902, 3.3882148692194836, 3.5071355833500366, 3.622154055254967, 3.733630940518894, 3.84187454245971, 3.947150871198111, 4.049691346263318, 4.149698784249287, 4.247352116319061, 4.342810150121694, 4.436214602563767, 4.527692569068709, 4.617358552246079, 4.705316142407438, 4.791659420284376, 4.876474136094644, 4.959838707054898, 5.041825066382213, 5.122499389946279, 5.201922721455982, 5.280151512977635, 5.35723809439155, 5.43323108288245, 5.508175741568166, 5.582114294781146, 5.655086206239478, 5.727128425310542, 5.798275605729691, 5.868560300448485, 5.938013135721409, 6.006662967072484, 6.074537019394977, 6.1416610131136355, 6.208059278067503, 6.27375485654325, 6.338769596696192, 6.403124237432849, 6.466838485689898, 6.529931086925804, 6.592419889539805, 6.654321903845651, 6.715653356152327, 6.776429738438967, 6.836665854054885, 6.8963758598266685, 6.955573304911681, 7.014271166700073, 7.07248188403477, 7.130217387990355, 7.187489130426565, 7.244308110509934, 7.300684899377592, 7.356629663099809, 7.4121521840825695, 7.467261881037788, 7.521967827636597, 7.576278769950325, 7.630203142774117, 7.68374908491942, 7.736924453553881, 7.789736837660179, 7.842193570679062, 7.894301742396222, 7.9460682101275735, 7.997499609252884, 8.048602363143555, 8.099382692526635, 8.149846624323676, 8.200000000000001, 8.249848483457136, 8.299397568498573, 8.348652585896723, 8.397618710086808, 8.446300965511472, 8.494704232638123, 8.542833253669418, 8.590692637965812, 8.638286867197687, 8.685620300243388, 8.732697177848321, 8.77952162705919, 8.826097665446492, 8.872429205127535, 8.918520056601322, 8.964373932405989, 9.009994450608726, 9.055385138137417, 9.100549433962767], [0.0, 0.9110433579144299, 1.2884098726725124, 1.5779733838059502, 1.8220867158288598, 2.0371548787463363, 2.2315913604421396, 2.41039415863879, 2.576819745345025, 2.7331300737432893, 2.8809720581775866, 3.0215889859476257, 3.1559467676119004, 3.2848135411313684, 3.408812109811862, 3.5284557528754696, 3.6441734316577197, 3.7563279941985894, 3.8652296180175374, 3.9711459303329564, 4.0743097574926725, 4.174925149029621, 4.273172123844299, 4.369210454990696, 4.463182720884279, 4.55521678957215, 4.645427859734774, 4.73392015141785, 4.82078831727758, 4.906118628814432, 4.9899899799498595, 5.072474741188959, 5.15363949069005, 5.23354564325181, 5.31224999411737, 5.389805191284746, 5.466260147486579, 5.541660400998964, 5.616048432839589, 5.68946394662977, 5.761944116355173, 5.833523806414096, 5.904235767650205, 5.974110812497538, 6.043177971895251, 6.111464636239008, 6.178996682310163, 6.245798587850876, 6.311893535223801, 6.377303505401009, 6.442049363362563, 6.506150935845249, 6.569627082262737, 6.632495759516172, 6.694774081326419, 6.756478372643548, 6.817624219623724, 6.878226515607057, 6.938299503480662, 6.997856814768361, 7.056911505750939, 7.115476090888086, 7.173562573784381, 7.23118247591637, 7.288346863315439, 7.345066371381541, 7.401351227985333, 7.457211275000863, 7.512655988397179, 7.567694497005016, 7.622335600063802, 7.676587783644501, 7.730459236035075, 7.783957862167549, 7.837091297158659, 7.88986691902975, 7.942291860665913, 7.994373021069257, 8.046117075956577, 8.097530487747484, 8.148619514985345, 8.19939022122987, 8.249848483457136, 8.299999999999999, 8.349850298059241, 8.399404740813482, 8.44866853415377, 8.49764673306675, 8.546344247688598, 8.594765849050223, 8.64291617453276, 8.690799733051039, 8.738420909981391, 8.78578397184907, 8.832893070789435, 8.879752248796134, 8.926365441768558, 8.972736483370054, 9.018869108707587, 9.064766957842878, 9.1104335791443, 9.155872432488342], [0.0, 0.9165151389911681, 1.2961481396815722, 1.5874507866387546, 1.8330302779823362, 2.04939015319192, 2.244994432064365, 2.4248711305964283, 2.5922962793631443, 2.749545416973504, 2.898275349237888, 3.039736830714133, 3.174901573277509, 3.3045423283716615, 3.4292856398964493, 3.5496478698597693, 3.6660605559646724, 3.778888725538237, 3.8884444190447165, 3.9949968710876362, 4.09878030638384, 4.2, 4.298837052040936, 4.3954521951671826, 4.48998886412873, 4.582575694955841, 4.67332857821917, 4.762352359916264, 4.849742261192857, 4.935585071701227, 5.019960159204453, 5.10294032886923, 5.184592558726289, 5.264978632435274, 5.344155686354956, 5.422176684690384, 5.499090833947008, 5.574943945906542, 5.649778756730214, 5.723635208501674, 5.796550698475776, 5.868560300448484, 5.939696961967, 6.009991680526688, 6.079473661428266, 6.148170459575759, 6.216108107168022, 6.2833112289620034, 6.349803146555018, 6.4156059729381765, 6.480740698407861, 6.54522726878143, 6.609084656743323, 6.672330927044912, 6.7349832961930955, 6.797058187186572, 6.858571279792899, 6.919537556802478, 6.97997134664606, 7.0398863627192165, 7.099295739719539, 7.158212067269313, 7.216647421067486, 7.274613391789285, 7.332121111929345, 7.389181280764467, 7.445804187594514, 7.501999733404421, 7.557777451076474, 7.6131465242697125, 7.668115805072326, 7.72269383052313, 7.776888838089433, 7.830708780180758, 7.884161337770809, 7.937253933193772, 7.9899937421752725, 8.04238770515324, 8.094442537939226, 8.14616474176652, 8.19756061276768, 8.248636250920512, 8.299397568498573, 8.349850298059241, 8.4, 8.449852069711044, 8.499411744350311, 8.548684109265006, 8.597674104081872, 8.646386528486914, 8.694826047713663, 8.742997197757758, 8.790904390334365, 8.838551917593742, 8.885943956609225, 8.933084573650918, 8.97997772825746, 9.026627277117408, 9.073036977771006, 9.119210492142399, 9.165151389911681, 9.210863151735564], [0.0, 0.9219544457292888, 1.3038404810405297, 1.5968719422671316, 1.8439088914585775, 2.0615528128088303, 2.2583179581272432, 2.4392621835300936, 2.6076809620810595, 2.765863337187866, 2.9154759474226504, 3.0577769702841313, 3.193743884534263, 3.3241540277189325, 3.449637662132068, 3.5707142142714248, 3.687817782917155, 3.8013155617496426, 3.9115214431215897, 4.018706259482024, 4.123105625617661, 4.224926034855522, 4.324349662087931, 4.421538193886829, 4.5166359162544865, 4.609772228646444, 4.701063709417264, 4.790615826801394, 4.878524367060187, 4.964876634922565, 5.049752469181039, 5.13322510708424, 5.215361924162119, 5.296225070746145, 5.375872022286245, 5.454356057317858, 5.531726674375732, 5.608029957123981, 5.68330889535313, 5.757603668193913, 5.830951894845301, 5.903388857258177, 5.974947698515863, 6.0456596000767355, 6.115553940568263, 6.18465843842649, 6.252999280345393, 6.320601237224193, 6.387487769068526, 6.4536811201050215, 6.519202405202649, 6.584071688552609, 6.648308055437865, 6.711929677819935, 6.77495387438173, 6.837397165588672, 6.899275324264136, 6.960603422117942, 7.021395872616784, 7.0816664705420855, 7.1414284285428495, 7.200694410957877, 7.259476565152615, 7.317786550590281, 7.37563556583431, 7.433034373659253, 7.489993324429602, 7.546522377890362, 7.602631123499285, 7.658328799418317, 7.713624310270757, 7.768526243760782, 7.823042886243179, 7.877182237323192, 7.930952023559341, 7.984359711335657, 8.037412518964048, 8.090117428072352, 8.142481194328914, 8.194510357550353, 8.246211251235321, 8.2975900115636, 8.348652585896723, 8.399404740813482, 8.449852069711044, 8.5, 8.549853799919623, 8.599418584997478, 8.648699324175862, 8.697700845625814, 8.746427842267952, 8.794884877018005, 8.843076387773658, 8.891006692158093, 8.938679992034618, 8.986100377805714, 9.033271832508973, 9.080198235721511, 9.126883367283709, 9.173330910852394, 9.219544457292889, 9.265527507918803], [0.0, 0.9273618495495705, 1.3114877048604001, 1.6062378404209012, 1.854723699099141, 2.0736441353327724, 2.2715633383201097, 2.4535688292770597, 2.6229754097208002, 2.7820855486487113, 2.932575659723036, 3.07571129984594, 3.2124756808418025, 3.343650699460098, 3.4698703145794947, 3.591656999213594, 3.709447398198282, 3.8236108588610325, 3.9344631145812006, 4.042276586281548, 4.147288270665545, 4.249705872175156, 4.349712634186309, 4.447471191587417, 4.543126676640219, 4.636809247747852, 4.7286361670147565, 4.818713521262704, 4.907137658554119, 4.993996395673509, 5.079370039680118, 5.163332257370235, 5.2459508194416005, 5.327288240746882, 5.40740233383831, 5.486346689738081, 5.5641710972974225, 5.640921910468182, 5.716642371182581, 5.791372894228104, 5.865151319446072, 5.93801313572141, 6.009991680526689, 6.081118318204308, 6.15142259969188, 6.220932405998316, 6.289674077406556, 6.357672530100934, 6.424951361683605, 6.491532946846993, 6.557438524302001, 6.62268827591938, 6.687301398920196, 6.751296171847301, 6.814690014960329, 6.87749954561976, 6.939740629158989, 7.001428425685718, 7.062577433203831, 7.123201527403251, 7.183313998427188, 7.242927584892728, 7.302054505411474, 7.3607064878311785, 7.418894796396564, 7.476630257007497, 7.533923280734945, 7.590783885739338, 7.647221717722065, 7.703246069028303, 7.75886589650833, 7.814089838234521, 7.868926229162401, 7.923383115816122, 7.977468270071652, 8.031189202104505, 8.084553172563096, 8.137567204023572, 8.19023809177731, 8.242572413997951, 8.29457654133109, 8.346256645946134, 8.397618710086808, 8.44866853415377, 8.499411744350311, 8.549853799919623, 8.600000000000001, 8.649855490122365, 8.699425268372618, 8.748714191239761, 8.79772697916911, 8.84646822183859, 8.894942383174834, 8.943153806124549, 8.99110671719561, 9.038805230781334, 9.086253353280439, 9.133454987024352, 9.180413934022802, 9.22713389953782, 9.273618495495704, 9.319871243745807], [0.0, 0.9327379053088816, 1.3190905958272918, 1.6155494421403516, 1.8654758106177631, 2.0856653614614213, 2.2847319317591728, 2.4677925358506134, 2.6381811916545836, 2.7982137159266447, 2.9495762407505253, 3.093541659651604, 3.231098884280703, 3.363034344160048, 3.4899856733230297, 3.6124783736376886, 3.7309516212355263, 3.845776904605882, 3.957271787481876, 4.065710270051225, 4.171330722922843, 4.274342054632503, 4.374928570845472, 4.473253849269009, 4.5694638635183455, 4.663689526544408, 4.756048780237647, 4.846648326421054, 4.935585071701227, 5.022947341949744, 5.10881590977792, 5.193264869039514, 5.276362383309167, 5.358171329847526, 5.4387498563548595, 5.518151864528558, 5.596427431853289, 5.673623181001714, 5.749782604586021, 5.8249463516842805, 5.8991524815010505, 5.9724366886556455, 6.044832503882966, 6.1163714733492105, 6.187083319303208, 6.256996084384263, 6.326136261573884, 6.394528911499267, 6.462197768561406, 6.529165337162171, 6.59545297913646, 6.661080993352356, 6.726068688320096, 6.790434448545985, 6.854195795277518, 6.917369442208505, 6.979971346646059, 7.042016756583302, 7.103520254071217, 7.164495795239188, 7.224956747275377, 7.284915922644544, 7.344385610791416, 7.40337760755184, 7.4619032424710525, 7.519973404208288, 7.577598564189054, 7.634788798650556, 7.691553809211764, 7.747902942086975, 7.803845206050669, 7.859389289251424, 7.914543574963752, 7.969316156358713, 8.023714850367003, 8.077747210701757, 8.13142054010245, 8.184741901856162, 8.23771813064759, 8.290355842785038, 8.342661445845685, 8.394641147779934, 8.446300965511472, 8.49764673306675, 8.548684109265006, 8.599418584997478, 8.649855490122365, 8.700000000000001, 8.749857141690944, 8.799431799837988, 8.848728722251575, 8.897752525216692, 8.946507698538017, 8.994998610338971, 9.043229511629129, 9.091204540653564, 9.138927727036691, 9.186402995732335, 9.233634170791044, 9.280624978954814, 9.327379053088816, 9.373899935459095], [0.0, 0.938083151964686, 1.3266499161421599, 1.6248076809271923, 1.876166303929372, 2.0976176963403033, 2.297825058615212, 2.4819347291981715, 2.6532998322843198, 2.814249455894058, 2.9664793948382653, 3.1112698372208096, 3.2496153618543846, 3.3823069050575527, 3.509985754956849, 3.63318042491699, 3.752332607858744, 3.867815921162743, 3.97994974842648, 4.0890096600521755, 4.1952353926806065, 4.298837052040936, 4.4, 4.498888751680798, 4.595650117230424, 4.69041575982343, 4.7833042972405595, 4.874423042781577, 4.963869458396343, 5.0517323761260355, 5.138093031466052, 5.223025942880239, 5.3065996645686395, 5.388877434122993, 5.469917732470938, 5.549774770204643, 5.628498911788116, 5.706137047074843, 5.782732917920384, 5.858327406350725, 5.932958789676531, 6.006662967072483, 6.079473661428266, 6.151422599691879, 6.222539674441619, 6.292853089020909, 6.362389488234747, 6.431174076325411, 6.499230723708769, 6.566582063752802, 6.6332495807108005, 6.6992536897776915, 6.764613810115105, 6.82934843158555, 6.8934751758456345, 6.957010852370435, 7.019971509913698, 7.0823724838503095, 7.144228439796701, 7.205553413860728, 7.26636084983398, 7.326663633605681, 7.386474125047755, 7.445804187594514, 7.504665215717488, 7.5630681604756145, 7.62102355330306, 7.678541528180987, 7.735631842325486, 7.792303895511263, 7.848566748139434, 7.904429138147802, 7.95989949685296, 8.014985963805552, 8.069696400732806, 8.12403840463596, 8.178019320104351, 8.231646250902672, 8.284926070883193, 8.337865434270332, 8.390470785361213, 8.442748367682174, 8.494704232638123, 8.546344247688598, 8.597674104081872, 8.648699324175862, 8.699425268372618, 8.749857141690944, 8.8, 8.849858755935035, 8.899438184514796, 8.948742928478838, 8.997777503361595, 9.046546302318914, 9.09505360072166, 9.143303560529969, 9.191300234460847, 9.23904756996088, 9.28654941299512, 9.333809511662428, 9.38083151964686, 9.427618999514142], [0.0, 0.9433981132056604, 1.3341664064126333, 1.6340134638368193, 1.8867962264113207, 2.1095023109728985, 2.3108440016582685, 2.495996794869737, 2.6683328128252666, 2.830194339616981, 2.9832867780352594, 3.1288975694324033, 3.2680269276736387, 3.4014702703389896, 3.529872518944558, 3.6537651812890215, 3.7735924528226414, 3.8897300677553446, 4.0024992192379, 4.112177038990418, 4.219004621945797, 4.323193264243457, 4.424929377967517, 4.524378410345448, 4.621688003316537, 4.716990566028302, 4.810405388322278, 4.902040391510457, 4.991993589739474, 5.0803543183522155, 5.167204273105525, 5.252618394667558, 5.336665625650533, 5.419409561935692, 5.500909015790026, 5.58121850495033, 5.660388679233962, 5.7384666941614295, 5.815496539419485, 5.8915193286621745, 5.966573556070519, 6.040695324215583, 6.113918547053109, 6.186275131288617, 6.2577951388648065, 6.328506932918695, 6.398437309218556, 6.4676116148080505, 6.536053855347277, 6.603786792439623, 6.670832032063167, 6.73721010508059, 6.802940540677979, 6.868041933477111, 6.932532004974806, 6.996427659884722, 7.059745037889116, 7.122499561249548, 7.184705978674423, 7.246378405796926, 7.307530362578043, 7.368174807915458, 7.428324171709255, 7.487990384609211, 7.547184905645283, 7.6059187479225665, 7.664202502543888, 7.722046360907191, 7.779460135510689, 7.836453279386026, 7.893034904268446, 7.949213797602879, 8.0049984384758, 8.060397012554654, 8.115417426109392, 8.170067319184096, 8.224354077980836, 8.278284846512591, 8.33186653757728, 8.385105843100611, 8.438009243891594, 8.490583018850943, 8.542833253669418, 8.594765849050223, 8.646386528486914, 8.697700845625814, 8.748714191239761, 8.799431799837988, 8.849858755935035, 8.899999999999999, 8.949860334105779, 8.99944442729661, 9.048756820690896, 9.097801932335084, 9.1465840618233, 9.195107394696377, 9.243376006633074, 9.291393867445294, 9.339164844888433, 9.38669270829721, 9.433981132056603, 9.481033698917013], [0.0, 0.9486832980505138, 1.3416407864998738, 1.6431676725154984, 1.8973665961010275, 2.121320343559643, 2.32379000772445, 2.5099800796022267, 2.6832815729997477, 2.846049894151541, 3.0, 3.146426544510455, 3.286335345030997, 3.420526275297414, 3.5496478698597693, 3.674234614174767, 3.794733192202055, 3.9115214431215892, 4.024922359499621, 4.135214625627067, 4.242640687119286, 4.347413023856832, 4.449719092257398, 4.549725266430931, 4.6475800154489, 4.743416490252569, 4.83735464897913, 4.929503017546495, 5.019960159204453, 5.10881590977792, 5.196152422706632, 5.282045058497703, 5.366563145999495, 5.449770637375486, 5.531726674375733, 5.612486080160912, 5.692099788303082, 5.770615218501404, 5.848076606885378, 5.92452529743945, 6.0, 6.074537019394977, 6.148170459575759, 6.220932405998315, 6.29285308902091, 6.363961030678928, 6.434283176858165, 6.5038450166036395, 6.572670690061994, 6.640783086353597, 6.708203932499369, 6.77495387438173, 6.841052550594828, 6.906518659932804, 6.971370023173351, 7.035623639735144, 7.099295739719539, 7.162401831787993, 7.224956747275378, 7.286974680894671, 7.348469228349534, 7.409453421137082, 7.469939758793239, 7.52994023880668, 7.58946638440411, 7.648529270389177, 7.707139547199077, 7.76530746332687, 7.8230428862431785, 7.880355321938218, 7.937253933193772, 7.993747556684537, 8.049844718999243, 8.105553651663778, 8.160882305241266, 8.215838362577491, 8.270429251254134, 8.324662155306966, 8.378544026261366, 8.432081593533118, 8.485281374238571, 8.538149682454625, 8.590692637965812, 8.64291617453276, 8.694826047713663, 8.746427842267952, 8.79772697916911, 8.848728722251575, 8.899438184514796, 8.949860334105779, 9.0, 9.049861877399014, 9.099450532861862, 9.148770409186145, 9.197825830053535, 9.246621004453464, 9.2951600308978, 9.343446901438464, 9.391485505499116, 9.439279633531365, 9.486832980505138, 9.534149149242424], [0.0, 0.9539392014169457, 1.349073756323204, 1.6522711641858308, 1.9078784028338913, 2.1330729007701543, 2.3366642891095846, 2.5238858928247927, 2.698147512646408, 2.8618176042508368, 3.0166206257996713, 3.1638584039112754, 3.3045423283716615, 3.439476704383968, 3.5693136595149495, 3.694590640382233, 3.8157568056677826, 3.9331920878594273, 4.047221268969612, 4.158124577258358, 4.266145801540309, 4.371498598878879, 4.474371464239419, 4.57493169347915, 4.673328578219169, 4.769696007084729, 4.864154602806124, 4.956813492557492, 5.047771785649585, 5.137119815616529, 5.224940191045253, 5.3113086899558, 5.396295025292816, 5.479963503528103, 5.562373594069352, 5.643580423808984, 5.7236352085016735, 5.8025856305616035, 5.880476171195663, 5.957348403442593, 6.0332412515993425, 6.1081912216301815, 6.182232606429493, 6.255397669213365, 6.327716807822551, 6.399218702310462, 6.469930447848725, 6.539877674696982, 6.609084656743323, 6.67757440991862, 6.745368781616021, 6.81248853210044, 6.878953408767936, 6.944782214007867, 7.009992867328754, 7.074602462329597, 7.138627319029899, 7.202083032012336, 7.264984514780469, 7.327346040688948, 7.389181280764466, 7.450503338701353, 7.511324783285569, 7.571657678474378, 7.631513611335565, 7.6909037180295, 7.749838707999025, 7.808328886515987, 7.866384175718855, 7.924014134263013, 7.981227975693966, 8.038034585643434, 8.094442537939225, 8.150460109711599, 8.206095295571457, 8.261355820929154, 8.316249154516717, 8.370782520170978, 8.424962907930219, 8.478797084492587, 8.532291603080617, 8.58545281275251, 8.638286867197687, 8.690799733051039, 8.742997197757758, 8.794884877018005, 8.84646822183859, 8.897752525216692, 8.948742928478838, 8.99944442729661, 9.049861877399014, 9.1, 9.1498633869583, 9.199456505685541, 9.248783703817493, 9.297849213662264, 9.346657156438338, 9.395211546314432, 9.443516294262428, 9.491575211733826, 9.539392014169458, 9.586970324351693], [0.0, 0.959166304662544, 1.3564659966250536, 1.6613247725836153, 1.918332609325088, 2.144761058952722, 2.349468024894146, 2.5377155080899043, 2.7129319932501073, 2.877498913987632, 3.0331501776206204, 3.1811947441173736, 3.3226495451672307, 3.458323293158117, 3.5888716889852725, 3.714835124201342, 3.836665218650176, 3.954743986657038, 4.069397989875161, 4.180908992073375, 4.289522117905444, 4.3954521951671826, 4.498888751680798, 4.6000000000000005, 4.698936049788292, 4.79583152331272, 4.8908077042549944, 4.983974317750846, 5.075431016179809, 5.165268628057984, 5.253570214625479, 5.340411969127476, 5.4258639865002145, 5.509990925582366, 5.592852581643825, 5.674504383644443, 5.754997827975264, 5.83438085832593, 5.912698199637794, 5.989991652748776, 6.066300355241241, 6.1416610131136355, 6.216108107168022, 6.289674077406555, 6.362389488234747, 6.434283176858165, 6.505382386916238, 6.575712889109439, 6.645299090334461, 6.714164132637808, 6.782329983125269, 6.8498175158174845, 6.916646586316234, 6.982836100038438, 7.0484040746824395, 7.113367697511497, 7.177743377970545, 7.24154679609267, 7.3047929470998705, 7.367496182557545, 7.429670248402684, 7.491328320131218, 7.552483035399683, 7.6131465242697125, 7.673330437300352, 7.733045971672482, 7.792303895511263, 7.851114570556209, 7.909487973314076, 7.967433714816837, 8.024961059095553, 8.082078940470701, 8.138795979750322, 8.195120499419152, 8.251060537894508, 8.306623862918075, 8.36181798414675, 8.416650165000327, 8.47112743381895, 8.525256594378847, 8.579044235810889, 8.632496741962896, 8.685620300243388, 8.738420909981391, 8.790904390334365, 8.843076387773658, 8.894942383174834, 8.946507698538017, 8.997777503361595, 9.048756820690896, 9.099450532861862, 9.1498633869583, 9.200000000000001, 9.249864863877743, 9.299462350050137, 9.348796714016196, 9.397872099576585, 9.446692542895637, 9.495261976375376, 9.54358423235212, 9.59166304662544, 9.639502061828715], [0.0, 0.9643650760992956, 1.3638181696985856, 1.670329308849007, 1.9287301521985911, 2.1563858652847827, 2.3622023622035435, 2.551470164434615, 2.727636339397171, 2.8930952282978866, 3.0495901363953815, 3.1984371183438958, 3.340658617698014, 3.4770677301427426, 3.6083237105337433, 3.7349698793966195, 3.8574603043971822, 3.976179070414209, 4.091454509095757, 4.203569911396741, 4.312771730569565, 4.419275958796871, 4.523273151159457, 4.624932431938872, 4.724404724407087, 4.821825380496478, 4.917316341257699, 5.0109879265470205, 5.10294032886923, 5.193264869039514, 5.282045058497703, 5.36935750346352, 5.455272678794342, 5.539855593785817, 5.62316636780382, 5.705260730238365, 5.786190456595773, 5.866003750424986, 5.944745579080741, 6.02245796996542, 6.099180272790763, 6.174949392505174, 6.249799996799899, 6.323764701504951, 6.3968742366877915, 6.469157595854347, 6.540642170307134, 6.611353870426239, 6.681317235396028, 6.750555532695069, 6.8190908484929285, 6.886944169949399, 6.954135460285485, 7.020683727387242, 7.0866070866106305, 7.15192281837549, 7.216647421067487, 7.280796659706959, 7.3443856107914165, 7.407428703673091, 7.469939758793239, 7.531932023060219, 7.593418202627852, 7.654410493303845, 7.7149206087943645, 7.774959806970066, 7.834538914320357, 7.893668348746355, 7.952358140828418, 8.010617953691215, 8.068457101577724, 8.125884567233282, 8.182909018191515, 8.239538822045807, 8.295782060782456, 8.351646544245034, 8.407139822793482, 8.462269199216012, 8.517041739947036, 8.571464285639882, 8.62554346113913, 8.67928568489366, 8.732697177848321, 8.78578397184907, 8.838551917593742, 8.891006692158093, 8.943153806124549, 8.994998610338971, 9.046546302318914, 9.097801932335084, 9.148770409186145, 9.199456505685541, 9.249864863877743, 9.3, 9.349866309204641, 9.39946807005588, 9.448809448814174, 9.497894503520243, 9.5467271878901, 9.595311355031686, 9.643650760992957, 9.691749068150704], [0.0, 0.9695359714832659, 1.3711309200802089, 1.6792855623746668, 1.9390719429665317, 2.1679483388678804, 2.374868417407584, 2.5651510676761324, 2.7422618401604177, 2.9086079144497976, 3.0659419433511785, 3.2155870381627056, 3.3585711247493335, 3.4957116585897072, 3.627671429443411, 3.7549966711037173, 3.8781438859330635, 3.9974992182613374, 4.113392760240627, 4.226109321823088, 4.335896677735761, 4.442971978304612, 4.54752680036083, 4.649731175025068, 4.749736834815168, 4.847679857416329, 4.943682837723311, 5.037856687124, 5.130302135352265, 5.221110992882646, 5.310367218940701, 5.398147830506312, 5.4845236803208355, 5.569560126257729, 5.653317610041029, 5.735852159879995, 5.817215828899595, 5.897457079114693, 5.976621118993575, 6.054750201288242, 6.131883886702357, 6.208059278067504, 6.283311228962004, 6.357672530100933, 6.431174076325411, 6.5038450166036395, 6.57571288910944, 6.646803743153547, 6.717142249498667, 6.786751800382861, 6.855654600401045, 6.923871749245506, 6.9914233171794145, 7.058328414008519, 7.124605252222751, 7.1902712048990205, 7.255342858886822, 7.31983606373804, 7.383765976789894, 7.447147104764348, 7.5099933422074345, 7.572318007057021, 7.634133873596926, 7.695453203028396, 7.756287771866127, 7.816648898345122, 7.8765474670060875, 7.935993951610599, 7.994998436522675, 8.053570636680355, 8.1117199162693, 8.16945530620004, 8.226785520481254, 8.283718971573094, 8.340263784797218, 8.396427811873334, 8.452218643646177, 8.507643622061282, 8.56270985144306, 8.61742420912421, 8.671793355471522, 8.725823743349393, 8.77952162705919, 8.832893070789435, 8.885943956609225, 8.938679992034618, 8.99110671719561, 9.043229511629129, 9.09505360072166, 9.1465840618233, 9.197825830053535, 9.248783703817493, 9.299462350050137, 9.349866309204641, 9.4, 9.44986772394196, 9.499473669630335, 9.548821916864929, 9.597916440561463, 9.646761114488118, 9.695359714832659, 9.743715923609434], [0.0, 0.9746794344808963, 1.378404875209022, 1.6881943016134133, 1.9493588689617927, 2.179449471770337, 2.3874672772626644, 2.578759391645525, 2.756809750418044, 2.9240383034426887, 3.082207001484488, 3.2326459750489227, 3.3763886032268267, 3.5142566781611158, 3.6469165057620936, 3.7749172176353745, 3.8987177379235853, 4.018706259482023, 4.135214625627066, 4.2485291572496005, 4.358898943540674, 4.466542286825459, 4.571651780264984, 4.674398357008098, 4.774934554525329, 4.873397172404482, 4.969909455915671, 5.06458290484024, 5.15751878329105, 5.2488093888042835, 5.338539126015655, 5.426785420486054, 5.513619500836088, 5.599107071667768, 5.683308895353129, 5.766281297335397, 5.848076606885377, 5.928743543112655, 6.008327554319921, 6.08687111741328, 6.164414002968976, 6.24099351065197, 6.316644678941503, 6.3914004725099165, 6.465291950097845, 6.53834841531101, 6.6105975524153635, 6.682065548915245, 6.752777206453653, 6.822756041366274, 6.892024376045111, 6.960603422117942, 7.0285133563222315, 7.095773389842717, 7.162401831787993, 7.2284161474004796, 7.293833011524187, 7.358668357794092, 7.4229374239582535, 7.486654793697916, 7.549834435270749, 7.6124897372673015, 7.674633541739956, 7.736278174936576, 7.797435475847171, 7.858116822750854, 7.918333157931661, 7.978095010715276, 8.037412518964047, 8.096295449154509, 8.154753215150045, 8.212794895770866, 8.270429251254132, 8.327664738688751, 8.384509526501832, 8.440971508067065, 8.497058314499201, 8.55277732669336, 8.608135686662937, 8.663140308225419, 8.717797887081348, 8.772114910328067, 8.826097665446492, 8.879752248796134, 8.933084573650918, 8.986100377805714, 9.038805230781334, 9.091204540653564, 9.143303560529969, 9.195107394696377, 9.246621004453464, 9.297849213662264, 9.348796714016196, 9.39946807005588, 9.44986772394196, 9.499999999999998, 9.549869109050658, 9.599479152537391, 9.648834126463154, 9.697937925146768, 9.746794344808963, 9.795407086997457], [0.0, 0.9797958971132713, 1.3856406460551018, 1.6970562748477143, 1.9595917942265426, 2.1908902300206647, 2.4000000000000004, 2.5922962793631443, 2.7712812921102037, 2.939387691339814, 3.0983866769659336, 3.2496153618543846, 3.3941125496954285, 3.532704346531139, 3.666060555964672, 3.794733192202055, 3.9191835884530852, 4.039801975344831, 4.156921938165306, 4.270831300812525, 4.3817804600413295, 4.48998886412873, 4.595650117230424, 4.698936049788292, 4.800000000000001, 4.898979485566357, 4.9959983987187195, 5.091168824543143, 5.184592558726289, 5.276362383309168, 5.366563145999495, 5.455272678794342, 5.542562584220407, 5.628498911788117, 5.713142742834281, 5.796550698475776, 5.878775382679628, 5.959865770300536, 6.0398675482166, 6.118823416311343, 6.196773353931867, 6.27375485654325, 6.349803146555018, 6.424951361683604, 6.499230723708769, 6.572670690061993, 6.64529909033446, 6.717142249498666, 6.788225099390857, 6.858571279792899, 6.92820323027551, 6.997142273814362, 7.065408693062278, 7.1330218000508046, 7.2, 7.266360849833981, 7.332121111929344, 7.397296803562772, 7.4619032424710525, 7.525955088890711, 7.58946638440411, 7.652450587883597, 7.714920608794364, 7.776888838089433, 7.8383671769061705, 7.899367063252599, 7.95989949685296, 8.019975062305368, 8.079603950689663, 8.138795979750322, 8.19756061276768, 8.255906976220118, 8.313843876330612, 8.37137981458254, 8.42852300228219, 8.485281374238571, 8.54166260162505, 8.597674104081872, 8.653323061113575, 8.708616422830897, 8.763560920082659, 8.818163074019441, 8.872429205127535, 8.926365441768558, 8.97997772825746, 9.033271832508973, 9.086253353280439, 9.138927727036691, 9.191300234460847, 9.243376006633074, 9.2951600308978, 9.346657156438338, 9.397872099576585, 9.448809448814174, 9.499473669630335, 9.549869109050658, 9.600000000000001, 9.649870465451857, 9.699484522385713, 9.748846085563153, 9.797958971132713, 9.846826900072939], [0.0, 0.9848857801796106, 1.392838827718412, 1.7058722109231985, 1.9697715603592212, 2.2022715545545246, 2.412467616362964, 2.6057628441590768, 2.785677655436824, 2.9546573405388314, 3.1144823004794877, 3.2664965942122155, 3.411744421846397, 3.5510561809129415, 3.685105154537656, 3.8144462245521304, 3.9395431207184424, 4.060788100849391, 4.178516483155236, 4.293017586733137, 4.404543109109049, 4.513313638558704, 4.61952378498044, 4.723346271447818, 4.824935232725928, 4.924428900898053, 5.021951811795889, 5.117616632769595, 5.2115256883181535, 5.3037722424704485, 5.394441583704471, 5.483611948342078, 5.571355310873648, 5.657738063926256, 5.742821606144492, 5.826662852782887, 5.909314681077663, 5.990826320300065, 6.071243694664217, 6.150609725872713, 6.228964600958975, 6.306346010171025, 6.38278935889318, 6.458327956987009, 6.532993188424431, 6.606814663663572, 6.679820356865895, 6.7520367297579185, 6.823488843692794, 6.894200461257274, 6.9641941385920605, 7.033491309442276, 7.102112361825883, 7.170076708097342, 7.237402849088892, 7.30410843293006, 7.370210309075312, 7.4357245780085215, 7.5006666370396715, 7.565051222562872, 7.628892449104261, 7.692203845452876, 7.754998388136519, 7.817288532477231, 7.879086241436885, 7.940403012442127, 8.001249902359007, 8.061637550770936, 8.121576201698781, 8.18107572388864, 8.240145629781066, 8.298795093265047, 8.357032966310472, 8.414867794564572, 8.472307831990054, 8.529361054615991, 8.586035173466273, 8.64233764672499, 8.698275691193055, 8.753856293085923, 8.809086218218098, 8.863972021616496, 8.918520056601322, 8.972736483370054, 9.026627277117408, 9.080198235721511, 9.133454987024352, 9.186402995732335, 9.23904756996088, 9.291393867445294, 9.343446901438464, 9.395211546314432, 9.446692542895637, 9.497894503520243, 9.548821916864929, 9.599479152537391, 9.649870465451857, 9.700000000000003, 9.749871794028884, 9.799489782636646, 9.848857801796106, 9.897979591815698], [0.0, 0.9899494936611666, 1.4, 1.7146428199482249, 1.9798989873223332, 2.2135943621178655, 2.4248711305964283, 2.619160170741759, 2.8, 2.9698484809834995, 3.1304951684997055, 3.283291031876401, 3.4292856398964497, 3.5693136595149495, 3.704051835490427, 3.8340579025361623, 3.9597979746446663, 4.08166632639171, 4.2, 4.315089802078284, 4.427188724235731, 4.536518488885503, 4.64327470649756, 4.747630988187688, 4.849742261192857, 4.949747468305833, 5.047771785649585, 5.143928459844674, 5.238320341483518, 5.331041174104736, 5.422176684690383, 5.511805511808268, 5.6, 5.686826883245173, 5.772347875864725, 5.856620185738529, 5.939696961966999, 6.021627686929839, 6.102458520956943, 6.182232606429493, 6.260990336999411, 6.338769596696192, 6.4156059729381765, 6.491532946846992, 6.566582063752802, 6.640783086353596, 6.714164132637808, 6.786751800382861, 6.8585712797928995, 6.929646455628165, 7.0, 7.069653456853455, 7.138627319029899, 7.206941098690901, 7.274613391789285, 7.341661937191061, 7.408103670980854, 7.473954776421918, 7.539230729988306, 7.603946343840151, 7.668115805072325, 7.731752712031082, 7.79487010796203, 7.857480512225277, 7.919595949289333, 7.981227975693965, 8.04238770515324, 8.103085831953157, 8.16333265278342, 8.223138087129511, 8.282511696339462, 8.341462701469089, 8.4, 8.4581321815162, 8.515867542417507, 8.573214099741124, 8.630179604156568, 8.6867715521936, 8.742997197757758, 8.798863562983575, 8.854377448471462, 8.909545442950499, 8.964373932405989, 9.018869108707587, 9.073036977771006, 9.126883367283709, 9.180413934022802, 9.233634170791044, 9.28654941299512, 9.339164844888433, 9.391485505499116, 9.443516294262428, 9.495261976375376, 9.5467271878901, 9.597916440561463, 9.648834126463154, 9.699484522385713, 9.749871794028884, 9.8, 9.849873095629203, 9.899494936611665, 9.948869282486328], [0.0, 0.9949874371066201, 1.407124727947029, 1.7233687939614089, 1.9899748742132402, 2.224859546128699, 2.4372115213907883, 2.632489316217637, 2.814249455894058, 2.98496231131986, 3.146426544510455, 3.3000000000000007, 3.4467375879228177, 3.58747822293042, 3.722902093797257, 3.853569773599539, 3.9799497484264803, 4.102438299353203, 4.221374183841087, 4.337049688440289, 4.449719092257398, 4.559605246071199, 4.666904755831214, 4.77179211617606, 4.874423042781577, 4.974937185533101, 5.073460357586329, 5.170106381884226, 5.264978632435274, 5.358171329847527, 5.449770637375485, 5.539855593785817, 5.628498911788116, 5.715767664977296, 5.801723881744115, 5.886425061104576, 5.96992462263972, 6.052272300549605, 6.133514490078262, 6.213694553162394, 6.29285308902091, 6.3710281744785915, 6.448255578061405, 6.524568951279464, 6.600000000000001, 6.674578638386096, 6.748333127521196, 6.821290200541244, 6.893475175845635, 6.96491205974634, 7.035623639735145, 7.105631569396208, 7.17495644586084, 7.243617880589783, 7.3116345641723655, 7.379024325749307, 7.445804187594514, 7.5119904153293495, 7.577598564189055, 7.642643521714199, 7.707139547199078, 7.771100308193172, 7.834538914320357, 7.897467948652911, 7.959899496852961, 8.021845174272563, 8.083316151184489, 8.144323176298936, 8.204876598706406, 8.264986388373547, 8.324662155306966, 8.383913167489272, 8.442748367682174, 8.501176389182852, 8.559205570612264, 8.616843969807043, 8.674099376880578, 8.73097932651315, 8.787491109526087, 8.843641783790206, 8.899438184514796, 8.95488693395958, 9.009994450608726, 9.064766957842878, 9.119210492142399, 9.173330910852394, 9.22713389953782, 9.280624978954814, 9.333809511662428, 9.38669270829721, 9.439279633531365, 9.491575211733826, 9.54358423235212, 9.595311355031686, 9.646761114488118, 9.697937925146768, 9.748846085563153, 9.799489782636646, 9.849873095629203, 9.900000000000002, 9.949874371066201, 9.999499987499377], [0.0, 1.0, 1.4142135623730951, 1.7320508075688776, 2.0, 2.23606797749979, 2.4494897427831783, 2.6457513110645907, 2.8284271247461903, 3.0, 3.1622776601683795, 3.3166247903554003, 3.4641016151377553, 3.6055512754639896, 3.7416573867739413, 3.8729833462074166, 4.0, 4.123105625617661, 4.242640687119286, 4.358898943540674, 4.47213595499958, 4.582575694955841, 4.69041575982343, 4.79583152331272, 4.898979485566357, 5.000000000000001, 5.099019513592785, 5.196152422706633, 5.291502622129181, 5.385164807134505, 5.477225575051661, 5.567764362830022, 5.656854249492381, 5.7445626465380295, 5.830951894845301, 5.916079783099616, 6.0, 6.08276253029822, 6.164414002968977, 6.244997998398399, 6.324555320336759, 6.403124237432849, 6.480740698407861, 6.557438524302, 6.6332495807108005, 6.7082039324993685, 6.782329983125269, 6.855654600401045, 6.9282032302755105, 7.0, 7.071067811865476, 7.141428428542851, 7.211102550927979, 7.28010988928052, 7.348469228349535, 7.416198487095664, 7.483314773547883, 7.54983443527075, 7.6157731058639095, 7.681145747868608, 7.745966692414833, 7.810249675906655, 7.874007874011811, 7.937253933193772, 8.0, 8.06225774829855, 8.12403840463596, 8.18535277187245, 8.246211251235321, 8.306623862918075, 8.366600265340756, 8.426149773176359, 8.485281374238571, 8.544003745317532, 8.602325267042627, 8.660254037844387, 8.717797887081348, 8.774964387392123, 8.831760866327848, 8.88819441731559, 8.94427190999916, 9.000000000000002, 9.055385138137417, 9.1104335791443, 9.165151389911681, 9.219544457292889, 9.273618495495704, 9.327379053088816, 9.38083151964686, 9.433981132056603, 9.486832980505138, 9.539392014169458, 9.59166304662544, 9.643650760992957, 9.695359714832659, 9.746794344808963, 9.797958971132713, 9.848857801796106, 9.899494936611665, 9.949874371066201, 10.000000000000002, 10.049875621120892], [0.0, 1.0049875621120892, 1.4212670403551897, 1.7406895185529214, 2.0099751242241783, 2.2472205054244236, 2.4617067250182347, 2.6589471600616665, 2.8425340807103794, 3.0149626863362675, 3.178049716414141, 3.333166662499792, 3.481379037105843, 3.6235341863986883, 3.7603191353926335, 3.892300091205713, 4.019950248448357, 4.1436698710201325, 4.263801121065569, 4.380639222761903, 4.494441010848847, 4.605431575867782, 4.713809499757071, 4.819751030914357, 4.9234134500364695, 5.024937810560446, 5.1244511901275835, 5.222068555658764, 5.317894320123333, 5.412023651093924, 5.504543577809154, 5.595533933415113, 5.685068161420759, 5.773214009544425, 5.860034129593445, 5.9455865984779, 6.029925372672535, 6.113100686231171, 6.1951594006934165, 6.276145313805283, 6.356099432828282, 6.435060217278469, 6.5130637951735135, 6.590144156238162, 6.666333324999584, 6.74166151627327, 6.81615727518079, 6.889847603539574, 6.962758074211686, 7.034912934784624, 7.1063352017759485, 7.177046746399247, 7.247068372797377, 7.31641988953614, 7.385120175054704, 7.4531872376856345, 7.520638270785267, 7.587489703452652, 7.653757247260983, 7.719455939378112, 7.784600182411426, 7.849203781276163, 7.913279977354524, 7.976841480185, 8.039900496896713, 8.10246875958186, 8.16455755078008, 8.226177727231525, 8.287339742040265, 8.34805366537614, 8.408329203831164, 8.468175718535841, 8.527602242131138, 8.586617494683225, 8.645229898620395, 8.703447592764606, 8.761278445523805, 8.81873006730561, 8.875809822207776, 8.932524839036274, 8.988882021697695, 9.044888059008803, 9.100549433962767, 9.155872432488342, 9.210863151735564, 9.265527507918803, 9.319871243745807, 9.373899935459095, 9.427618999514142, 9.481033698917013, 9.534149149242424, 9.586970324351693, 9.639502061828715, 9.691749068150704, 9.743715923609434, 9.795407086997457, 9.846826900072939, 9.897979591815698, 9.948869282486328, 9.999499987499377, 10.049875621120892, 10.100000000000001]]}],\n",
       "                        {\"autosize\": false, \"height\": 600, \"margin\": {\"b\": 65, \"l\": 65, \"r\": 50, \"t\": 90}, \"scene\": {\"xaxis\": {\"title\": {\"text\": \"K\"}}, \"yaxis\": {\"title\": {\"text\": \"L\"}}, \"zaxis\": {\"title\": {\"text\": \"Y\"}}}, \"sliders\": [{\"active\": 1, \"currentvalue\": {\"prefix\": \"\"}, \"pad\": {\"t\": 50}, \"steps\": [{\"args\": [{\"visible\": [true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"A = 0.5\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"A = 1.0\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"A = 1.5\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"A = 2.0\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"A = 2.5\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"A = 3.0\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"A = 3.5\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"A = 4.0\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"A = 4.5\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"A = 5.0\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"A = 5.5\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, true]}], \"label\": \"A = 6.0\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, true]}], \"label\": \"A = 6.5\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, true]}], \"label\": \"A = 7.0\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, true]}], \"label\": \"A = 7.5\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, true]}], \"label\": \"A = 8.0\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, true]}], \"label\": \"A = 8.5\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, true]}], \"label\": \"A = 9.0\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, true]}], \"label\": \"A = 9.5\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, true]}], \"label\": \"A = 10.0\", \"method\": \"update\"}]}], \"template\": {\"data\": {\"bar\": [{\"error_x\": {\"color\": \"#2a3f5f\"}, \"error_y\": {\"color\": \"#2a3f5f\"}, \"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"bar\"}], \"barpolar\": [{\"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"barpolar\"}], \"carpet\": [{\"aaxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"baxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"type\": \"carpet\"}], \"choropleth\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"choropleth\"}], \"contour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"contour\"}], \"contourcarpet\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"contourcarpet\"}], \"heatmap\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmap\"}], \"heatmapgl\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmapgl\"}], \"histogram\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"histogram\"}], \"histogram2d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2d\"}], \"histogram2dcontour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2dcontour\"}], \"mesh3d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"mesh3d\"}], \"parcoords\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"parcoords\"}], \"scatter\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter\"}], \"scatter3d\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter3d\"}], \"scattercarpet\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattercarpet\"}], \"scattergeo\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergeo\"}], \"scattergl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergl\"}], \"scattermapbox\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattermapbox\"}], \"scatterpolar\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolar\"}], \"scatterpolargl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolargl\"}], \"scatterternary\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterternary\"}], \"surface\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"surface\"}], \"table\": [{\"cells\": {\"fill\": {\"color\": \"#EBF0F8\"}, \"line\": {\"color\": \"white\"}}, \"header\": {\"fill\": {\"color\": \"#C8D4E3\"}, \"line\": {\"color\": \"white\"}}, \"type\": \"table\"}]}, \"layout\": {\"annotationdefaults\": {\"arrowcolor\": \"#2a3f5f\", \"arrowhead\": 0, \"arrowwidth\": 1}, \"colorscale\": {\"diverging\": [[0, \"#8e0152\"], [0.1, \"#c51b7d\"], [0.2, \"#de77ae\"], [0.3, \"#f1b6da\"], [0.4, \"#fde0ef\"], [0.5, \"#f7f7f7\"], [0.6, \"#e6f5d0\"], [0.7, \"#b8e186\"], [0.8, \"#7fbc41\"], [0.9, \"#4d9221\"], [1, \"#276419\"]], \"sequential\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"sequentialminus\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]]}, \"colorway\": [\"#636efa\", \"#EF553B\", \"#00cc96\", \"#ab63fa\", \"#FFA15A\", \"#19d3f3\", \"#FF6692\", \"#B6E880\", \"#FF97FF\", \"#FECB52\"], \"font\": {\"color\": \"#2a3f5f\"}, \"geo\": {\"bgcolor\": \"white\", \"lakecolor\": \"white\", \"landcolor\": \"#E5ECF6\", \"showlakes\": true, \"showland\": true, \"subunitcolor\": \"white\"}, \"hoverlabel\": {\"align\": \"left\"}, \"hovermode\": \"closest\", \"mapbox\": {\"style\": \"light\"}, \"paper_bgcolor\": \"white\", \"plot_bgcolor\": \"#E5ECF6\", \"polar\": {\"angularaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"radialaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"scene\": {\"xaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"yaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"zaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}}, \"shapedefaults\": {\"line\": {\"color\": \"#2a3f5f\"}}, \"ternary\": {\"aaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"baxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"caxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"title\": {\"x\": 0.05}, \"xaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}, \"yaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}}}, \"title\": {\"text\": \"Cobb-Douglas Production Function\"}, \"width\": 500},\n",
       "                        {\"responsive\": true}\n",
       "                    )\n",
       "                };\n",
       "                \n",
       "            </script>\n",
       "        </div>\n",
       "</body>\n",
       "</html>"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "filename = \"fig6.html\"\n",
    "\n",
    "L_s = np.arange(0, 10.11, 0.1)\n",
    "K_s = np.arange(0, 10.11, 0.1)\n",
    "alpha = 0.5\n",
    "xx, yy = np.meshgrid(K_s, L_s)\n",
    "# plot_cobb_douglas(curr_V, orig_cobb_douglas(), fr\"A = {A}\", r\"A = 1\", filename=filename)\n",
    "\n",
    "layout = go.Layout(\n",
    "    title = \"Cobb-Douglas Production Function\", autosize=False, width=500, height=500, margin = dict(l = 65, r = 50, b = 65, t = 90),\n",
    "    scene = dict(xaxis = dict(title = 'K'), yaxis = dict(title = 'L'), zaxis = dict(title = 'Y'))\n",
    ")\n",
    "\n",
    "fig = go.Figure(layout = layout)\n",
    "\n",
    "active = None\n",
    "As = []\n",
    "for i, A in enumerate(np.arange(0.5, 10.1, 0.5)):\n",
    "    As.append(A)\n",
    "    if A == 1:\n",
    "        active = i\n",
    "    V = cobb_douglas(A, xx, yy, alpha)\n",
    "    fig.add_trace(go.Surface(\n",
    "        z = V, contours = go.surface.Contours(\n",
    "            z = go.surface.contours.Z(\n",
    "                show = False, project = dict(z = True)\n",
    "            )\n",
    "        ), colorscale = \"Electric\", showscale = False, name=f\"A = {A}\", visible=False\n",
    "    ))\n",
    "    \n",
    "fig.data[active].visible = True\n",
    "\n",
    "steps = []\n",
    "for i in range(len(fig.data)):\n",
    "    step = dict(\n",
    "        method=\"update\", args=[\n",
    "            {\"visible\": [False] * len(fig.data) + [True]},\n",
    "        ], label=f\"A = {As[i]}\"\n",
    "    )\n",
    "    step[\"args\"][0][\"visible\"][i] = True\n",
    "    steps.append(step)\n",
    "    \n",
    "sliders = [dict(\n",
    "    active=active,\n",
    "    currentvalue={\"prefix\": \"\"},\n",
    "    pad={\"t\": 50},\n",
    "    steps=steps\n",
    ")]\n",
    "\n",
    "fig.update_layout(sliders=sliders, width=500, height=600)\n",
    "\n",
    "orig_V = orig_cobb_douglas()\n",
    "fig.add_trace(go.Surface(\n",
    "    z = orig_V, contours = go.surface.Contours(\n",
    "        z = go.surface.contours.Z(\n",
    "            show = False, project = dict(z = True)\n",
    "        )\n",
    "    ), colorscale = \"Viridis\", showscale = False, name=\"A = 1\"\n",
    "))\n",
    "\n",
    "plot(fig, filename=filename, auto_open=False, include_mathjax='cdn')\n",
    "\n",
    "display(HTML(filename))"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Favorable shocks rotate the production function upward through an increase in A. Thus, each unit of input from capital and labor now simulataneously produce more output. What does this mean for the rental rate of capital and the real wage? Recall the functions for both of them:\n",
    "\n",
    "$$\\begin{aligned}\n",
    "\\text{MPL} &= A (1 - \\alpha) \\left ( \\frac{K}{L} \\right )^{\\alpha} \\\\\n",
    "\\text{MPK} &= \\alpha A \\left ( \\frac{L}{K} \\right )^{1 - \\alpha} \n",
    "\\end{aligned}$$\n",
    "\n",
    "Both MPK and MPL will increase by a factor of $A$. Thus, it would be more expensive to hire an additional unit of labor or rent an additional unit of capital. As they are both more productive than previously, they are both more valuable to a business and thus will cost more. Negative shocks do the opposite. They rotate the production function downward through a decrease in $A$. Each unit of input is now less productive, meaning that both the rental rate of capital and the real wage are lower."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Shifts in $\\alpha$ and their Effect on Output\n",
    "\n",
    "We will now plot what happens to the Cobb-Douglas function as we vary $\\alpha$, while holding all other variables constant. The plot below shows $\\alpha = 0.8$ (the purple-yellow surface) with $\\alpha=0.5$ for reference (the blue-yellow surface). Try and hypothesize what this will do to our production function."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {
    "tags": [
     "remove_input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<html>\n",
       "<head><meta charset=\"utf-8\" /></head>\n",
       "<body>\n",
       "    <div>\n",
       "            <script src=\"https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.5/MathJax.js?config=TeX-AMS-MML_SVG\"></script><script type=\"text/javascript\">if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}</script>\n",
       "                <script type=\"text/javascript\">window.PlotlyConfig = {MathJaxConfig: 'local'};</script>\n",
       "        <script type=\"text/javascript\">/**\n",
       "* plotly.js v1.49.1\n",
       "* Copyright 2012-2019, Plotly, Inc.\n",
       "* All rights reserved.\n",
       "* Licensed under the MIT license\n",
       "*/\n",
       "!function(t){if(\"object\"==typeof exports&&\"undefined\"!=typeof module)module.exports=t();else if(\"function\"==typeof define&&define.amd)define([],t);else{(\"undefined\"!=typeof window?window:\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:this).Plotly=t()}}(function(){return function(){return function t(e,r,n){function i(o,s){if(!r[o]){if(!e[o]){var l=\"function\"==typeof require&&require;if(!s&&l)return l(o,!0);if(a)return a(o,!0);var c=new Error(\"Cannot find module '\"+o+\"'\");throw c.code=\"MODULE_NOT_FOUND\",c}var u=r[o]={exports:{}};e[o][0].call(u.exports,function(t){return i(e[o][1][t]||t)},u,u.exports,t,e,r,n)}return r[o].exports}for(var a=\"function\"==typeof require&&require,o=0;o<n.length;o++)i(n[o]);return i}}()({1:[function(t,e,r){\"use strict\";var n=t(\"../src/lib\"),i={\"X,X div\":\"direction:ltr;font-family:'Open Sans', verdana, arial, sans-serif;margin:0;padding:0;\",\"X input,X button\":\"font-family:'Open Sans', verdana, arial, sans-serif;\",\"X input:focus,X button:focus\":\"outline:none;\",\"X a\":\"text-decoration:none;\",\"X a:hover\":\"text-decoration:none;\",\"X .crisp\":\"shape-rendering:crispEdges;\",\"X .user-select-none\":\"-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;\",\"X svg\":\"overflow:hidden;\",\"X svg a\":\"fill:#447adb;\",\"X svg a:hover\":\"fill:#3c6dc5;\",\"X .main-svg\":\"position:absolute;top:0;left:0;pointer-events:none;\",\"X .main-svg .draglayer\":\"pointer-events:all;\",\"X .cursor-default\":\"cursor:default;\",\"X .cursor-pointer\":\"cursor:pointer;\",\"X .cursor-crosshair\":\"cursor:crosshair;\",\"X .cursor-move\":\"cursor:move;\",\"X .cursor-col-resize\":\"cursor:col-resize;\",\"X .cursor-row-resize\":\"cursor:row-resize;\",\"X .cursor-ns-resize\":\"cursor:ns-resize;\",\"X .cursor-ew-resize\":\"cursor:ew-resize;\",\"X .cursor-sw-resize\":\"cursor:sw-resize;\",\"X .cursor-s-resize\":\"cursor:s-resize;\",\"X .cursor-se-resize\":\"cursor:se-resize;\",\"X .cursor-w-resize\":\"cursor:w-resize;\",\"X .cursor-e-resize\":\"cursor:e-resize;\",\"X .cursor-nw-resize\":\"cursor:nw-resize;\",\"X .cursor-n-resize\":\"cursor:n-resize;\",\"X .cursor-ne-resize\":\"cursor:ne-resize;\",\"X .cursor-grab\":\"cursor:-webkit-grab;cursor:grab;\",\"X .modebar\":\"position:absolute;top:2px;right:2px;\",\"X .ease-bg\":\"-webkit-transition:background-color 0.3s ease 0s;-moz-transition:background-color 0.3s ease 0s;-ms-transition:background-color 0.3s ease 0s;-o-transition:background-color 0.3s ease 0s;transition:background-color 0.3s ease 0s;\",\"X .modebar--hover>:not(.watermark)\":\"opacity:0;-webkit-transition:opacity 0.3s ease 0s;-moz-transition:opacity 0.3s ease 0s;-ms-transition:opacity 0.3s ease 0s;-o-transition:opacity 0.3s ease 0s;transition:opacity 0.3s ease 0s;\",\"X:hover .modebar--hover .modebar-group\":\"opacity:1;\",\"X .modebar-group\":\"float:left;display:inline-block;box-sizing:border-box;padding-left:8px;position:relative;vertical-align:middle;white-space:nowrap;\",\"X .modebar-btn\":\"position:relative;font-size:16px;padding:3px 4px;height:22px;cursor:pointer;line-height:normal;box-sizing:border-box;\",\"X .modebar-btn svg\":\"position:relative;top:2px;\",\"X .modebar.vertical\":\"display:flex;flex-direction:column;flex-wrap:wrap;align-content:flex-end;max-height:100%;\",\"X .modebar.vertical svg\":\"top:-1px;\",\"X .modebar.vertical .modebar-group\":\"display:block;float:none;padding-left:0px;padding-bottom:8px;\",\"X .modebar.vertical .modebar-group .modebar-btn\":\"display:block;text-align:center;\",\"X [data-title]:before,X [data-title]:after\":\"position:absolute;-webkit-transform:translate3d(0, 0, 0);-moz-transform:translate3d(0, 0, 0);-ms-transform:translate3d(0, 0, 0);-o-transform:translate3d(0, 0, 0);transform:translate3d(0, 0, 0);display:none;opacity:0;z-index:1001;pointer-events:none;top:110%;right:50%;\",\"X [data-title]:hover:before,X [data-title]:hover:after\":\"display:block;opacity:1;\",\"X [data-title]:before\":\"content:'';position:absolute;background:transparent;border:6px solid transparent;z-index:1002;margin-top:-12px;border-bottom-color:#69738a;margin-right:-6px;\",\"X [data-title]:after\":\"content:attr(data-title);background:#69738a;color:white;padding:8px 10px;font-size:12px;line-height:12px;white-space:nowrap;margin-right:-18px;border-radius:2px;\",\"X .vertical [data-title]:before,X .vertical [data-title]:after\":\"top:0%;right:200%;\",\"X .vertical [data-title]:before\":\"border:6px solid transparent;border-left-color:#69738a;margin-top:8px;margin-right:-30px;\",\"X .select-outline\":\"fill:none;stroke-width:1;shape-rendering:crispEdges;\",\"X .select-outline-1\":\"stroke:white;\",\"X .select-outline-2\":\"stroke:black;stroke-dasharray:2px 2px;\",Y:\"font-family:'Open Sans';position:fixed;top:50px;right:20px;z-index:10000;font-size:10pt;max-width:180px;\",\"Y p\":\"margin:0;\",\"Y .notifier-note\":\"min-width:180px;max-width:250px;border:1px solid #fff;z-index:3000;margin:0;background-color:#8c97af;background-color:rgba(140,151,175,0.9);color:#fff;padding:10px;overflow-wrap:break-word;word-wrap:break-word;-ms-hyphens:auto;-webkit-hyphens:auto;hyphens:auto;\",\"Y .notifier-close\":\"color:#fff;opacity:0.8;float:right;padding:0 5px;background:none;border:none;font-size:20px;font-weight:bold;line-height:20px;\",\"Y .notifier-close:hover\":\"color:#444;text-decoration:none;cursor:pointer;\"};for(var a in i){var o=a.replace(/^,/,\" ,\").replace(/X/g,\".js-plotly-plot .plotly\").replace(/Y/g,\".plotly-notifier\");n.addStyleRule(o,i[a])}},{\"../src/lib\":719}],2:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/aggregate\")},{\"../src/transforms/aggregate\":1265}],3:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/bar\")},{\"../src/traces/bar\":864}],4:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/barpolar\")},{\"../src/traces/barpolar\":876}],5:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/box\")},{\"../src/traces/box\":886}],6:[function(t,e,r){\"use strict\";e.exports=t(\"../src/components/calendars\")},{\"../src/components/calendars\":591}],7:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/candlestick\")},{\"../src/traces/candlestick\":895}],8:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/carpet\")},{\"../src/traces/carpet\":914}],9:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choropleth\")},{\"../src/traces/choropleth\":928}],10:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choroplethmapbox\")},{\"../src/traces/choroplethmapbox\":935}],11:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/cone\")},{\"../src/traces/cone\":941}],12:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contour\")},{\"../src/traces/contour\":956}],13:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contourcarpet\")},{\"../src/traces/contourcarpet\":967}],14:[function(t,e,r){\"use strict\";e.exports=t(\"../src/core\")},{\"../src/core\":697}],15:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/densitymapbox\")},{\"../src/traces/densitymapbox\":977}],16:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/filter\")},{\"../src/transforms/filter\":1266}],17:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnel\")},{\"../src/traces/funnel\":987}],18:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnelarea\")},{\"../src/traces/funnelarea\":996}],19:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/groupby\")},{\"../src/transforms/groupby\":1267}],20:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmap\")},{\"../src/traces/heatmap\":1009}],21:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmapgl\")},{\"../src/traces/heatmapgl\":1018}],22:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram\")},{\"../src/traces/histogram\":1030}],23:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2d\")},{\"../src/traces/histogram2d\":1036}],24:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2dcontour\")},{\"../src/traces/histogram2dcontour\":1040}],25:[function(t,e,r){\"use strict\";var n=t(\"./core\");n.register([t(\"./bar\"),t(\"./box\"),t(\"./heatmap\"),t(\"./histogram\"),t(\"./histogram2d\"),t(\"./histogram2dcontour\"),t(\"./contour\"),t(\"./scatterternary\"),t(\"./violin\"),t(\"./funnel\"),t(\"./waterfall\"),t(\"./pie\"),t(\"./sunburst\"),t(\"./funnelarea\"),t(\"./scatter3d\"),t(\"./surface\"),t(\"./isosurface\"),t(\"./volume\"),t(\"./mesh3d\"),t(\"./cone\"),t(\"./streamtube\"),t(\"./scattergeo\"),t(\"./choropleth\"),t(\"./scattergl\"),t(\"./splom\"),t(\"./pointcloud\"),t(\"./heatmapgl\"),t(\"./parcoords\"),t(\"./parcats\"),t(\"./scattermapbox\"),t(\"./choroplethmapbox\"),t(\"./densitymapbox\"),t(\"./sankey\"),t(\"./indicator\"),t(\"./table\"),t(\"./carpet\"),t(\"./scattercarpet\"),t(\"./contourcarpet\"),t(\"./ohlc\"),t(\"./candlestick\"),t(\"./scatterpolar\"),t(\"./scatterpolargl\"),t(\"./barpolar\")]),n.register([t(\"./aggregate\"),t(\"./filter\"),t(\"./groupby\"),t(\"./sort\")]),n.register([t(\"./calendars\")]),e.exports=n},{\"./aggregate\":2,\"./bar\":3,\"./barpolar\":4,\"./box\":5,\"./calendars\":6,\"./candlestick\":7,\"./carpet\":8,\"./choropleth\":9,\"./choroplethmapbox\":10,\"./cone\":11,\"./contour\":12,\"./contourcarpet\":13,\"./core\":14,\"./densitymapbox\":15,\"./filter\":16,\"./funnel\":17,\"./funnelarea\":18,\"./groupby\":19,\"./heatmap\":20,\"./heatmapgl\":21,\"./histogram\":22,\"./histogram2d\":23,\"./histogram2dcontour\":24,\"./indicator\":26,\"./isosurface\":27,\"./mesh3d\":28,\"./ohlc\":29,\"./parcats\":30,\"./parcoords\":31,\"./pie\":32,\"./pointcloud\":33,\"./sankey\":34,\"./scatter3d\":35,\"./scattercarpet\":36,\"./scattergeo\":37,\"./scattergl\":38,\"./scattermapbox\":39,\"./scatterpolar\":40,\"./scatterpolargl\":41,\"./scatterternary\":42,\"./sort\":43,\"./splom\":44,\"./streamtube\":45,\"./sunburst\":46,\"./surface\":47,\"./table\":48,\"./violin\":49,\"./volume\":50,\"./waterfall\":51}],26:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/indicator\")},{\"../src/traces/indicator\":1046}],27:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/isosurface\")},{\"../src/traces/isosurface\":1052}],28:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/mesh3d\")},{\"../src/traces/mesh3d\":1057}],29:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/ohlc\")},{\"../src/traces/ohlc\":1062}],30:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcats\")},{\"../src/traces/parcats\":1071}],31:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcoords\")},{\"../src/traces/parcoords\":1081}],32:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pie\")},{\"../src/traces/pie\":1092}],33:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pointcloud\")},{\"../src/traces/pointcloud\":1101}],34:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sankey\")},{\"../src/traces/sankey\":1107}],35:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatter3d\")},{\"../src/traces/scatter3d\":1143}],36:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattercarpet\")},{\"../src/traces/scattercarpet\":1149}],37:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergeo\")},{\"../src/traces/scattergeo\":1156}],38:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergl\")},{\"../src/traces/scattergl\":1167}],39:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattermapbox\")},{\"../src/traces/scattermapbox\":1176}],40:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolar\")},{\"../src/traces/scatterpolar\":1183}],41:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolargl\")},{\"../src/traces/scatterpolargl\":1189}],42:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterternary\")},{\"../src/traces/scatterternary\":1196}],43:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/sort\")},{\"../src/transforms/sort\":1269}],44:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/splom\")},{\"../src/traces/splom\":1205}],45:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/streamtube\")},{\"../src/traces/streamtube\":1213}],46:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sunburst\")},{\"../src/traces/sunburst\":1219}],47:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/surface\")},{\"../src/traces/surface\":1228}],48:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/table\")},{\"../src/traces/table\":1236}],49:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/violin\")},{\"../src/traces/violin\":1244}],50:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/volume\")},{\"../src/traces/volume\":1252}],51:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/waterfall\")},{\"../src/traces/waterfall\":1260}],52:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).eye||[0,0,1],r=t.center||[0,0,0],s=t.up||[0,1,0],l=t.distanceLimits||[0,1/0],c=t.mode||\"turntable\",u=n(),h=i(),f=a();return u.setDistanceLimits(l[0],l[1]),u.lookAt(0,e,r,s),h.setDistanceLimits(l[0],l[1]),h.lookAt(0,e,r,s),f.setDistanceLimits(l[0],l[1]),f.lookAt(0,e,r,s),new o({turntable:u,orbit:h,matrix:f},c)};var n=t(\"turntable-camera-controller\"),i=t(\"orbit-camera-controller\"),a=t(\"matrix-camera-controller\");function o(t,e){this._controllerNames=Object.keys(t),this._controllerList=this._controllerNames.map(function(e){return t[e]}),this._mode=e,this._active=t[e],this._active||(this._mode=\"turntable\",this._active=t.turntable),this.modes=this._controllerNames,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}var s=o.prototype;[[\"flush\",1],[\"idle\",1],[\"lookAt\",4],[\"rotate\",4],[\"pan\",4],[\"translate\",4],[\"setMatrix\",2],[\"setDistanceLimits\",2],[\"setDistance\",2]].forEach(function(t){for(var e=t[0],r=[],n=0;n<t[1];++n)r.push(\"a\"+n);var i=\"var cc=this._controllerList;for(var i=0;i<cc.length;++i){cc[i].\"+t[0]+\"(\"+r.join()+\")}\";s[e]=Function.apply(null,r.concat(i))}),s.recalcMatrix=function(t){this._active.recalcMatrix(t)},s.getDistance=function(t){return this._active.getDistance(t)},s.getDistanceLimits=function(t){return this._active.getDistanceLimits(t)},s.lastT=function(){return this._active.lastT()},s.setMode=function(t){if(t!==this._mode){var e=this._controllerNames.indexOf(t);if(!(e<0)){var r=this._active,n=this._controllerList[e],i=Math.max(r.lastT(),n.lastT());r.recalcMatrix(i),n.setMatrix(i,r.computedMatrix),this._active=n,this._mode=t,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}}},s.getMode=function(){return this._mode}},{\"matrix-camera-controller\":433,\"orbit-camera-controller\":456,\"turntable-camera-controller\":542}],53:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n,i){\"use strict\";function a(t){return t.target.depth}function o(t,e){return t.sourceLinks.length?t.depth:e-1}function s(t){return function(){return t}}i=i&&i.hasOwnProperty(\"default\")?i.default:i;var l=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&\"function\"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?\"symbol\":typeof t};function c(t,e){return h(t.source,e.source)||t.index-e.index}function u(t,e){return h(t.target,e.target)||t.index-e.index}function h(t,e){return t.partOfCycle===e.partOfCycle?t.y0-e.y0:\"top\"===t.circularLinkType||\"bottom\"===e.circularLinkType?-1:1}function f(t){return t.value}function p(t){return(t.y0+t.y1)/2}function d(t){return p(t.source)}function g(t){return p(t.target)}function v(t){return t.index}function m(t){return t.nodes}function y(t){return t.links}function x(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function b(t,e){return e(t)}var _=25,w=10,k=.3;function T(t,e){var r=0,n=0;t.links.forEach(function(i){i.circular&&(i.source.circularLinkType||i.target.circularLinkType?i.circularLinkType=i.source.circularLinkType?i.source.circularLinkType:i.target.circularLinkType:i.circularLinkType=r<n?\"top\":\"bottom\",\"top\"==i.circularLinkType?r+=1:n+=1,t.nodes.forEach(function(t){b(t,e)!=b(i.source,e)&&b(t,e)!=b(i.target,e)||(t.circularLinkType=i.circularLinkType)}))}),t.links.forEach(function(t){t.circular&&(t.source.circularLinkType==t.target.circularLinkType&&(t.circularLinkType=t.source.circularLinkType),Y(t,e)&&(t.circularLinkType=t.source.circularLinkType))})}function A(t){var e=Math.abs(t.y1-t.y0),r=Math.abs(t.target.x0-t.source.x1);return Math.atan(r/e)}function M(t,e){var r=0;t.sourceLinks.forEach(function(t){r=t.circular&&!Y(t,e)?r+1:r});var n=0;return t.targetLinks.forEach(function(t){n=t.circular&&!Y(t,e)?n+1:n}),r+n}function S(t){var e=t.source.sourceLinks,r=0;e.forEach(function(t){r=t.circular?r+1:r});var n=t.target.targetLinks,i=0;return n.forEach(function(t){i=t.circular?i+1:i}),!(r>1||i>1)}function E(t,e,r){return t.sort(L),t.forEach(function(n,i){var a,o,s=0;if(Y(n,r)&&S(n))n.circularPathData.verticalBuffer=s+n.width/2;else{for(var l=0;l<i;l++)if(a=t[i],o=t[l],!(a.source.column<o.target.column||a.target.column>o.source.column)){var c=t[l].circularPathData.verticalBuffer+t[l].width/2+e;s=c>s?c:s}n.circularPathData.verticalBuffer=s+n.width/2}}),t}function C(t,r,i,a){var o=e.min(t.links,function(t){return t.source.y0});t.links.forEach(function(t){t.circular&&(t.circularPathData={})}),E(t.links.filter(function(t){return\"top\"==t.circularLinkType}),r,a),E(t.links.filter(function(t){return\"bottom\"==t.circularLinkType}),r,a),t.links.forEach(function(e){if(e.circular){if(e.circularPathData.arcRadius=e.width+w,e.circularPathData.leftNodeBuffer=5,e.circularPathData.rightNodeBuffer=5,e.circularPathData.sourceWidth=e.source.x1-e.source.x0,e.circularPathData.sourceX=e.source.x0+e.circularPathData.sourceWidth,e.circularPathData.targetX=e.target.x0,e.circularPathData.sourceY=e.y0,e.circularPathData.targetY=e.y1,Y(e,a)&&S(e))e.circularPathData.leftSmallArcRadius=w+e.width/2,e.circularPathData.leftLargeArcRadius=w+e.width/2,e.circularPathData.rightSmallArcRadius=w+e.width/2,e.circularPathData.rightLargeArcRadius=w+e.width/2,\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=e.source.y1+_+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=e.source.y0-_-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius);else{var s=e.source.column,l=e.circularLinkType,c=t.links.filter(function(t){return t.source.column==s&&t.circularLinkType==l});\"bottom\"==e.circularLinkType?c.sort(O):c.sort(P);var u=0;c.forEach(function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.leftSmallArcRadius=w+e.width/2+u,e.circularPathData.leftLargeArcRadius=w+e.width/2+n*r+u),u+=t.width}),s=e.target.column,c=t.links.filter(function(t){return t.target.column==s&&t.circularLinkType==l}),\"bottom\"==e.circularLinkType?c.sort(I):c.sort(z),u=0,c.forEach(function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.rightSmallArcRadius=w+e.width/2+u,e.circularPathData.rightLargeArcRadius=w+e.width/2+n*r+u),u+=t.width}),\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=Math.max(i,e.source.y1,e.target.y1)+_+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=o-_-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius)}e.circularPathData.leftInnerExtent=e.circularPathData.sourceX+e.circularPathData.leftNodeBuffer,e.circularPathData.rightInnerExtent=e.circularPathData.targetX-e.circularPathData.rightNodeBuffer,e.circularPathData.leftFullExtent=e.circularPathData.sourceX+e.circularPathData.leftLargeArcRadius+e.circularPathData.leftNodeBuffer,e.circularPathData.rightFullExtent=e.circularPathData.targetX-e.circularPathData.rightLargeArcRadius-e.circularPathData.rightNodeBuffer}if(e.circular)e.path=function(t){var e=\"\";e=\"top\"==t.circularLinkType?\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 0 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY-t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 0 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 0 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY-t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 0 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY:\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 1 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY+t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 1 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 1 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY+t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 1 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY;return e}(e);else{var h=n.linkHorizontal().source(function(t){return[t.source.x0+(t.source.x1-t.source.x0),t.y0]}).target(function(t){return[t.target.x0,t.y1]});e.path=h(e)}})}function L(t,e){return D(t)==D(e)?\"bottom\"==t.circularLinkType?O(t,e):P(t,e):D(e)-D(t)}function P(t,e){return t.y0-e.y0}function O(t,e){return e.y0-t.y0}function z(t,e){return t.y1-e.y1}function I(t,e){return e.y1-t.y1}function D(t){return t.target.column-t.source.column}function R(t){return t.target.x0-t.source.x1}function F(t,e){var r=A(t),n=R(e)/Math.tan(r);return\"up\"==G(t)?t.y1+n:t.y1-n}function B(t,e){var r=A(t),n=R(e)/Math.tan(r);return\"up\"==G(t)?t.y1-n:t.y1+n}function N(t,e,r,n){t.links.forEach(function(i){if(!i.circular&&i.target.column-i.source.column>1){var a=i.source.column+1,o=i.target.column-1,s=1,l=o-a+1;for(s=1;a<=o;a++,s++)t.nodes.forEach(function(o){if(o.column==a){var c,u=s/(l+1),h=Math.pow(1-u,3),f=3*u*Math.pow(1-u,2),p=3*Math.pow(u,2)*(1-u),d=Math.pow(u,3),g=h*i.y0+f*i.y0+p*i.y1+d*i.y1,v=g-i.width/2,m=g+i.width/2;v>o.y0&&v<o.y1?(c=o.y1-v+10,c=\"bottom\"==o.circularLinkType?c:-c,o=U(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&j(o,t)&&U(t,c,e,r)})):m>o.y0&&m<o.y1?(c=m-o.y0+10,o=U(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&U(t,c,e,r)})):v<o.y0&&m>o.y1&&(c=m-o.y0+10,o=U(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&U(t,c,e,r)}))}})}})}function j(t,e){return t.y0>e.y0&&t.y0<e.y1||(t.y1>e.y0&&t.y1<e.y1||t.y0<e.y0&&t.y1>e.y1)}function U(t,e,r,n){return t.y0+e>=r&&t.y1+e<=n&&(t.y0=t.y0+e,t.y1=t.y1+e,t.targetLinks.forEach(function(t){t.y1=t.y1+e}),t.sourceLinks.forEach(function(t){t.y0=t.y0+e})),t}function V(t,e,r,n){t.nodes.forEach(function(i){n&&i.y+(i.y1-i.y0)>e&&(i.y=i.y-(i.y+(i.y1-i.y0)-e));var a=t.links.filter(function(t){return b(t.source,r)==b(i,r)}),o=a.length;o>1&&a.sort(function(t,e){if(!t.circular&&!e.circular){if(t.target.column==e.target.column)return t.y1-e.y1;if(!H(t,e))return t.y1-e.y1;if(t.target.column>e.target.column){var r=B(e,t);return t.y1-r}if(e.target.column>t.target.column)return B(t,e)-e.y1}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.target.column===e.target.column?t.target.y1-e.target.y1:e.target.column-t.target.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.target.column===e.target.column?e.target.y1-t.target.y1:t.target.column-e.target.column:\"top\"==t.circularLinkType?-1:1:void 0});var s=i.y0;a.forEach(function(t){t.y0=s+t.width/2,s+=t.width}),a.forEach(function(t,e){if(\"bottom\"==t.circularLinkType){for(var r=e+1,n=0;r<o;r++)n+=a[r].width;t.y0=i.y1-n-t.width/2}})})}function q(t,e,r){t.nodes.forEach(function(e){var n=t.links.filter(function(t){return b(t.target,r)==b(e,r)}),i=n.length;i>1&&n.sort(function(t,e){if(!t.circular&&!e.circular){if(t.source.column==e.source.column)return t.y0-e.y0;if(!H(t,e))return t.y0-e.y0;if(e.source.column<t.source.column){var r=F(e,t);return t.y0-r}if(t.source.column<e.source.column)return F(t,e)-e.y0}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:t.source.column-e.source.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:e.source.column-t.source.column:\"top\"==t.circularLinkType?-1:1:void 0});var a=e.y0;n.forEach(function(t){t.y1=a+t.width/2,a+=t.width}),n.forEach(function(t,r){if(\"bottom\"==t.circularLinkType){for(var a=r+1,o=0;a<i;a++)o+=n[a].width;t.y1=e.y1-o-t.width/2}})})}function H(t,e){return G(t)==G(e)}function G(t){return t.y0-t.y1>0?\"up\":\"down\"}function Y(t,e){return b(t.source,e)==b(t.target,e)}t.sankeyCircular=function(){var t,n,a=0,b=0,A=1,S=1,E=24,L=v,P=o,O=m,z=y,I=32,D=2,R=null;function F(){var o={nodes:O.apply(null,arguments),links:z.apply(null,arguments)};!function(t){t.nodes.forEach(function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]});var e=r.map(t.nodes,L);t.links.forEach(function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!==(\"undefined\"==typeof n?\"undefined\":l(n))&&(n=t.source=x(e,n)),\"object\"!==(\"undefined\"==typeof i?\"undefined\":l(i))&&(i=t.target=x(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)})}(o),function(t,e,r){var n=0;if(null===r){for(var a=[],o=0;o<t.links.length;o++){var s=t.links[o],l=s.source.index,c=s.target.index;a[l]||(a[l]=[]),a[c]||(a[c]=[]),-1===a[l].indexOf(c)&&a[l].push(c)}var u=i(a);u.sort(function(t,e){return t.length-e.length});var h={};for(o=0;o<u.length;o++){var f=u[o],p=f.slice(-2);h[p[0]]||(h[p[0]]={}),h[p[0]][p[1]]=!0}t.links.forEach(function(t){var e=t.target.index,r=t.source.index;e===r||h[r]&&h[r][e]?(t.circular=!0,t.circularLinkID=n,n+=1):t.circular=!1})}else t.links.forEach(function(t){t.source[r]<t.target[r]?t.circular=!1:(t.circular=!0,t.circularLinkID=n,n+=1)})}(o,0,R),function(t){t.nodes.forEach(function(t){t.partOfCycle=!1,t.value=Math.max(e.sum(t.sourceLinks,f),e.sum(t.targetLinks,f)),t.sourceLinks.forEach(function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)}),t.targetLinks.forEach(function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)})})}(o),function(t){var e,r,n;for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach(function(t){t.depth=n,t.sourceLinks.forEach(function(t){r.indexOf(t.target)<0&&!t.circular&&r.push(t.target)})});for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach(function(t){t.height=n,t.targetLinks.forEach(function(t){r.indexOf(t.source)<0&&!t.circular&&r.push(t.source)})});t.nodes.forEach(function(t){t.column=Math.floor(P.call(null,t,n))})}(o),T(o,L),function(i,o,s){var l=r.nest().key(function(t){return t.column}).sortKeys(e.ascending).entries(i.nodes).map(function(t){return t.values});(function(r){if(n){var o=1/0;l.forEach(function(t){var e=S*n/(t.length+1);o=e<o?e:o}),t=o}var s=e.min(l,function(r){return(S-b-(r.length-1)*t)/e.sum(r,f)});s*=k,i.links.forEach(function(t){t.width=t.value*s});var c=function(t){var r=0,n=0,i=0,a=0,o=e.max(t.nodes,function(t){return t.column});return t.links.forEach(function(t){t.circular&&(\"top\"==t.circularLinkType?r+=t.width:n+=t.width,0==t.target.column&&(a+=t.width),t.source.column==o&&(i+=t.width))}),{top:r=r>0?r+_+w:r,bottom:n=n>0?n+_+w:n,left:a=a>0?a+_+w:a,right:i=i>0?i+_+w:i}}(i),u=function(t,r){var n=e.max(t.nodes,function(t){return t.column}),i=A-a,o=S-b,s=i+r.right+r.left,l=o+r.top+r.bottom,c=i/s,u=o/l;return a=a*c+r.left,A=0==r.right?A:A*c,b=b*u+r.top,S*=u,t.nodes.forEach(function(t){t.x0=a+t.column*((A-a-E)/n),t.x1=t.x0+E}),u}(i,c);s*=u,i.links.forEach(function(t){t.width=t.value*s}),l.forEach(function(t){var e=t.length;t.forEach(function(t,n){t.depth==l.length-1&&1==e?(t.y0=S/2-t.value*s,t.y1=t.y0+t.value*s):0==t.depth&&1==e?(t.y0=S/2-t.value*s,t.y1=t.y0+t.value*s):t.partOfCycle?0==M(t,r)?(t.y0=S/2+n,t.y1=t.y0+t.value*s):\"top\"==t.circularLinkType?(t.y0=b+n,t.y1=t.y0+t.value*s):(t.y0=S-t.value*s-n,t.y1=t.y0+t.value*s):0==c.top||0==c.bottom?(t.y0=(S-b)/e*n,t.y1=t.y0+t.value*s):(t.y0=(S-b)/2-e/2+n,t.y1=t.y0+t.value*s)})})})(s),m();for(var c=1,u=o;u>0;--u)v(c*=.99,s),m();function v(t,r){var n=l.length;l.forEach(function(i){var a=i.length,o=i[0].depth;i.forEach(function(i){var s;if(i.sourceLinks.length||i.targetLinks.length)if(i.partOfCycle&&M(i,r)>0);else if(0==o&&1==a)s=i.y1-i.y0,i.y0=S/2-s/2,i.y1=S/2+s/2;else if(o==n-1&&1==a)s=i.y1-i.y0,i.y0=S/2-s/2,i.y1=S/2+s/2;else{var l=e.mean(i.sourceLinks,g),c=e.mean(i.targetLinks,d),u=((l&&c?(l+c)/2:l||c)-p(i))*t;i.y0+=u,i.y1+=u}})})}function m(){l.forEach(function(e){var r,n,i,a=b,o=e.length;for(e.sort(h),i=0;i<o;++i)r=e[i],(n=a-r.y0)>0&&(r.y0+=n,r.y1+=n),a=r.y1+t;if((n=a-t-S)>0)for(a=r.y0-=n,r.y1-=n,i=o-2;i>=0;--i)r=e[i],(n=r.y1+t-a)>0&&(r.y0-=n,r.y1-=n),a=r.y0})}}(o,I,L),B(o);for(var s=0;s<4;s++)V(o,S,L),q(o,0,L),N(o,b,S,L),V(o,S,L),q(o,0,L);return function(t,r,n){var i=t.nodes,a=t.links,o=!1,s=!1;if(a.forEach(function(t){\"top\"==t.circularLinkType?o=!0:\"bottom\"==t.circularLinkType&&(s=!0)}),0==o||0==s){var l=e.min(i,function(t){return t.y0}),c=e.max(i,function(t){return t.y1}),u=c-l,h=n-r,f=h/u;i.forEach(function(t){var e=(t.y1-t.y0)*f;t.y0=(t.y0-l)*f,t.y1=t.y0+e}),a.forEach(function(t){t.y0=(t.y0-l)*f,t.y1=(t.y1-l)*f,t.width=t.width*f})}}(o,b,S),C(o,D,S,L),o}function B(t){t.nodes.forEach(function(t){t.sourceLinks.sort(u),t.targetLinks.sort(c)}),t.nodes.forEach(function(t){var e=t.y0,r=e,n=t.y1,i=n;t.sourceLinks.forEach(function(t){t.circular?(t.y0=n-t.width/2,n-=t.width):(t.y0=e+t.width/2,e+=t.width)}),t.targetLinks.forEach(function(t){t.circular?(t.y1=i-t.width/2,i-=t.width):(t.y1=r+t.width/2,r+=t.width)})})}return F.nodeId=function(t){return arguments.length?(L=\"function\"==typeof t?t:s(t),F):L},F.nodeAlign=function(t){return arguments.length?(P=\"function\"==typeof t?t:s(t),F):P},F.nodeWidth=function(t){return arguments.length?(E=+t,F):E},F.nodePadding=function(e){return arguments.length?(t=+e,F):t},F.nodes=function(t){return arguments.length?(O=\"function\"==typeof t?t:s(t),F):O},F.links=function(t){return arguments.length?(z=\"function\"==typeof t?t:s(t),F):z},F.size=function(t){return arguments.length?(a=b=0,A=+t[0],S=+t[1],F):[A-a,S-b]},F.extent=function(t){return arguments.length?(a=+t[0][0],A=+t[1][0],b=+t[0][1],S=+t[1][1],F):[[a,b],[A,S]]},F.iterations=function(t){return arguments.length?(I=+t,F):I},F.circularLinkGap=function(t){return arguments.length?(D=+t,F):D},F.nodePaddingRatio=function(t){return arguments.length?(n=+t,F):n},F.sortNodes=function(t){return arguments.length?(R=t,F):R},F.update=function(t){return T(t,L),B(t),t.links.forEach(function(t){t.circular&&(t.circularLinkType=t.y0+t.y1<S?\"top\":\"bottom\",t.source.circularLinkType=t.circularLinkType,t.target.circularLinkType=t.circularLinkType)}),V(t,S,L,!1),q(t,0,L),C(t,D,S,L),t},F},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,a)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=o,Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\"),t(\"elementary-circuits-directed-graph\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,null)},{\"d3-array\":152,\"d3-collection\":153,\"d3-shape\":161,\"elementary-circuits-directed-graph\":172}],54:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n){\"use strict\";function i(t){return t.target.depth}function a(t,e){return t.sourceLinks.length?t.depth:e-1}function o(t){return function(){return t}}function s(t,e){return c(t.source,e.source)||t.index-e.index}function l(t,e){return c(t.target,e.target)||t.index-e.index}function c(t,e){return t.y0-e.y0}function u(t){return t.value}function h(t){return(t.y0+t.y1)/2}function f(t){return h(t.source)*t.value}function p(t){return h(t.target)*t.value}function d(t){return t.index}function g(t){return t.nodes}function v(t){return t.links}function m(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function y(t){return[t.source.x1,t.y0]}function x(t){return[t.target.x0,t.y1]}t.sankey=function(){var t=0,n=0,i=1,y=1,x=24,b=8,_=d,w=a,k=g,T=v,A=32,M=2/3;function S(){var a={nodes:k.apply(null,arguments),links:T.apply(null,arguments)};return function(t){t.nodes.forEach(function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]});var e=r.map(t.nodes,_);t.links.forEach(function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!=typeof n&&(n=t.source=m(e,n)),\"object\"!=typeof i&&(i=t.target=m(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)})}(a),function(t){t.nodes.forEach(function(t){t.value=Math.max(e.sum(t.sourceLinks,u),e.sum(t.targetLinks,u))})}(a),function(e){var r,n,a;for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach(function(t){t.depth=a,t.sourceLinks.forEach(function(t){n.indexOf(t.target)<0&&n.push(t.target)})});for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach(function(t){t.height=a,t.targetLinks.forEach(function(t){n.indexOf(t.source)<0&&n.push(t.source)})});var o=(i-t-x)/(a-1);e.nodes.forEach(function(e){e.x1=(e.x0=t+Math.max(0,Math.min(a-1,Math.floor(w.call(null,e,a))))*o)+x})}(a),function(t){var i=r.nest().key(function(t){return t.x0}).sortKeys(e.ascending).entries(t.nodes).map(function(t){return t.values});(function(){var r=e.max(i,function(t){return t.length}),a=M*(y-n)/(r-1);b>a&&(b=a);var o=e.min(i,function(t){return(y-n-(t.length-1)*b)/e.sum(t,u)});i.forEach(function(t){t.forEach(function(t,e){t.y1=(t.y0=e)+t.value*o})}),t.links.forEach(function(t){t.width=t.value*o})})(),d();for(var a=1,o=A;o>0;--o)l(a*=.99),d(),s(a),d();function s(t){i.forEach(function(r){r.forEach(function(r){if(r.targetLinks.length){var n=(e.sum(r.targetLinks,f)/e.sum(r.targetLinks,u)-h(r))*t;r.y0+=n,r.y1+=n}})})}function l(t){i.slice().reverse().forEach(function(r){r.forEach(function(r){if(r.sourceLinks.length){var n=(e.sum(r.sourceLinks,p)/e.sum(r.sourceLinks,u)-h(r))*t;r.y0+=n,r.y1+=n}})})}function d(){i.forEach(function(t){var e,r,i,a=n,o=t.length;for(t.sort(c),i=0;i<o;++i)e=t[i],(r=a-e.y0)>0&&(e.y0+=r,e.y1+=r),a=e.y1+b;if((r=a-b-y)>0)for(a=e.y0-=r,e.y1-=r,i=o-2;i>=0;--i)e=t[i],(r=e.y1+b-a)>0&&(e.y0-=r,e.y1-=r),a=e.y0})}}(a),E(a),a}function E(t){t.nodes.forEach(function(t){t.sourceLinks.sort(l),t.targetLinks.sort(s)}),t.nodes.forEach(function(t){var e=t.y0,r=e;t.sourceLinks.forEach(function(t){t.y0=e+t.width/2,e+=t.width}),t.targetLinks.forEach(function(t){t.y1=r+t.width/2,r+=t.width})})}return S.update=function(t){return E(t),t},S.nodeId=function(t){return arguments.length?(_=\"function\"==typeof t?t:o(t),S):_},S.nodeAlign=function(t){return arguments.length?(w=\"function\"==typeof t?t:o(t),S):w},S.nodeWidth=function(t){return arguments.length?(x=+t,S):x},S.nodePadding=function(t){return arguments.length?(b=+t,S):b},S.nodes=function(t){return arguments.length?(k=\"function\"==typeof t?t:o(t),S):k},S.links=function(t){return arguments.length?(T=\"function\"==typeof t?t:o(t),S):T},S.size=function(e){return arguments.length?(t=n=0,i=+e[0],y=+e[1],S):[i-t,y-n]},S.extent=function(e){return arguments.length?(t=+e[0][0],i=+e[1][0],n=+e[0][1],y=+e[1][1],S):[[t,n],[i,y]]},S.iterations=function(t){return arguments.length?(A=+t,S):A},S},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,i)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=a,t.sankeyLinkHorizontal=function(){return n.linkHorizontal().source(y).target(x)},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3)},{\"d3-array\":152,\"d3-collection\":153,\"d3-shape\":161}],55:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\"),i=6378137;function a(t){var e=0;if(t&&t.length>0){e+=Math.abs(o(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(o(t[r]))}return e}function o(t){var e,r,n,a,o,l,c=0,u=t.length;if(u>2){for(l=0;l<u;l++)l===u-2?(n=u-2,a=u-1,o=0):l===u-1?(n=u-1,a=0,o=1):(n=l,a=l+1,o=l+2),e=t[n],r=t[a],c+=(s(t[o][0])-s(e[0]))*Math.sin(s(r[1]));c=c*i*i/2}return c}function s(t){return t*Math.PI/180}r.default=function(t){return n.geomReduce(t,function(t,e){return t+function(t){var e,r=0;switch(t.type){case\"Polygon\":return a(t.coordinates);case\"MultiPolygon\":for(e=0;e<t.coordinates.length;e++)r+=a(t.coordinates[e]);return r;case\"Point\":case\"MultiPoint\":case\"LineString\":case\"MultiLineString\":return 0}return 0}(e)},0)}},{\"@turf/meta\":58}],56:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\"),i=t(\"@turf/helpers\");r.default=function(t,e){void 0===e&&(e={});var r=0,a=0,o=0;return n.coordEach(t,function(t){r+=t[0],a+=t[1],o++}),i.point([r/o,a/o],e.properties)}},{\"@turf/helpers\":57,\"@turf/meta\":58}],57:[function(t,e,r){\"use strict\";function n(t,e,r){void 0===r&&(r={});var n={type:\"Feature\"};return(0===r.id||r.id)&&(n.id=r.id),r.bbox&&(n.bbox=r.bbox),n.properties=e||{},n.geometry=t,n}function i(t,e,r){return void 0===r&&(r={}),n({type:\"Point\",coordinates:t},e,r)}function a(t,e,r){void 0===r&&(r={});for(var i=0,a=t;i<a.length;i++){var o=a[i];if(o.length<4)throw new Error(\"Each LinearRing of a Polygon must have 4 or more Positions.\");for(var s=0;s<o[o.length-1].length;s++)if(o[o.length-1][s]!==o[0][s])throw new Error(\"First and last Position are not equivalent.\")}return n({type:\"Polygon\",coordinates:t},e,r)}function o(t,e,r){if(void 0===r&&(r={}),t.length<2)throw new Error(\"coordinates must be an array of two or more positions\");return n({type:\"LineString\",coordinates:t},e,r)}function s(t,e){void 0===e&&(e={});var r={type:\"FeatureCollection\"};return e.id&&(r.id=e.id),e.bbox&&(r.bbox=e.bbox),r.features=t,r}function l(t,e,r){return void 0===r&&(r={}),n({type:\"MultiLineString\",coordinates:t},e,r)}function c(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPoint\",coordinates:t},e,r)}function u(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPolygon\",coordinates:t},e,r)}function h(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t*n}function f(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t/n}function p(t){return 180*(t%(2*Math.PI))/Math.PI}function d(t){return!isNaN(t)&&null!==t&&!Array.isArray(t)&&!/^\\s*$/.test(t)}Object.defineProperty(r,\"__esModule\",{value:!0}),r.earthRadius=6371008.8,r.factors={centimeters:100*r.earthRadius,centimetres:100*r.earthRadius,degrees:r.earthRadius/111325,feet:3.28084*r.earthRadius,inches:39.37*r.earthRadius,kilometers:r.earthRadius/1e3,kilometres:r.earthRadius/1e3,meters:r.earthRadius,metres:r.earthRadius,miles:r.earthRadius/1609.344,millimeters:1e3*r.earthRadius,millimetres:1e3*r.earthRadius,nauticalmiles:r.earthRadius/1852,radians:1,yards:r.earthRadius/1.0936},r.unitsFactors={centimeters:100,centimetres:100,degrees:1/111325,feet:3.28084,inches:39.37,kilometers:.001,kilometres:.001,meters:1,metres:1,miles:1/1609.344,millimeters:1e3,millimetres:1e3,nauticalmiles:1/1852,radians:1/r.earthRadius,yards:1/1.0936},r.areaFactors={acres:247105e-9,centimeters:1e4,centimetres:1e4,feet:10.763910417,inches:1550.003100006,kilometers:1e-6,kilometres:1e-6,meters:1,metres:1,miles:3.86e-7,millimeters:1e6,millimetres:1e6,yards:1.195990046},r.feature=n,r.geometry=function(t,e,r){switch(void 0===r&&(r={}),t){case\"Point\":return i(e).geometry;case\"LineString\":return o(e).geometry;case\"Polygon\":return a(e).geometry;case\"MultiPoint\":return c(e).geometry;case\"MultiLineString\":return l(e).geometry;case\"MultiPolygon\":return u(e).geometry;default:throw new Error(t+\" is invalid\")}},r.point=i,r.points=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return i(t,e)}),r)},r.polygon=a,r.polygons=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return a(t,e)}),r)},r.lineString=o,r.lineStrings=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return o(t,e)}),r)},r.featureCollection=s,r.multiLineString=l,r.multiPoint=c,r.multiPolygon=u,r.geometryCollection=function(t,e,r){return void 0===r&&(r={}),n({type:\"GeometryCollection\",geometries:t},e,r)},r.round=function(t,e){if(void 0===e&&(e=0),e&&!(e>=0))throw new Error(\"precision must be a positive number\");var r=Math.pow(10,e||0);return Math.round(t*r)/r},r.radiansToLength=h,r.lengthToRadians=f,r.lengthToDegrees=function(t,e){return p(f(t,e))},r.bearingToAzimuth=function(t){var e=t%360;return e<0&&(e+=360),e},r.radiansToDegrees=p,r.degreesToRadians=function(t){return t%360*Math.PI/180},r.convertLength=function(t,e,r){if(void 0===e&&(e=\"kilometers\"),void 0===r&&(r=\"kilometers\"),!(t>=0))throw new Error(\"length must be a positive number\");return h(f(t,e),r)},r.convertArea=function(t,e,n){if(void 0===e&&(e=\"meters\"),void 0===n&&(n=\"kilometers\"),!(t>=0))throw new Error(\"area must be a positive number\");var i=r.areaFactors[e];if(!i)throw new Error(\"invalid original units\");var a=r.areaFactors[n];if(!a)throw new Error(\"invalid final units\");return t/i*a},r.isNumber=d,r.isObject=function(t){return!!t&&t.constructor===Object},r.validateBBox=function(t){if(!t)throw new Error(\"bbox is required\");if(!Array.isArray(t))throw new Error(\"bbox must be an Array\");if(4!==t.length&&6!==t.length)throw new Error(\"bbox must be an Array of 4 or 6 numbers\");t.forEach(function(t){if(!d(t))throw new Error(\"bbox must only contain numbers\")})},r.validateId=function(t){if(!t)throw new Error(\"id is required\");if(-1===[\"string\",\"number\"].indexOf(typeof t))throw new Error(\"id must be a number or a string\")},r.radians2degrees=function(){throw new Error(\"method has been renamed to `radiansToDegrees`\")},r.degrees2radians=function(){throw new Error(\"method has been renamed to `degreesToRadians`\")},r.distanceToDegrees=function(){throw new Error(\"method has been renamed to `lengthToDegrees`\")},r.distanceToRadians=function(){throw new Error(\"method has been renamed to `lengthToRadians`\")},r.radiansToDistance=function(){throw new Error(\"method has been renamed to `radiansToLength`\")},r.bearingToAngle=function(){throw new Error(\"method has been renamed to `bearingToAzimuth`\")},r.convertDistance=function(){throw new Error(\"method has been renamed to `convertLength`\")}},{}],58:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/helpers\");function i(t,e,r){if(null!==t)for(var n,a,o,s,l,c,u,h,f=0,p=0,d=t.type,g=\"FeatureCollection\"===d,v=\"Feature\"===d,m=g?t.features.length:1,y=0;y<m;y++){l=(h=!!(u=g?t.features[y].geometry:v?t.geometry:t)&&\"GeometryCollection\"===u.type)?u.geometries.length:1;for(var x=0;x<l;x++){var b=0,_=0;if(null!==(s=h?u.geometries[x]:u)){c=s.coordinates;var w=s.type;switch(f=!r||\"Polygon\"!==w&&\"MultiPolygon\"!==w?0:1,w){case null:break;case\"Point\":if(!1===e(c,p,y,b,_))return!1;p++,b++;break;case\"LineString\":case\"MultiPoint\":for(n=0;n<c.length;n++){if(!1===e(c[n],p,y,b,_))return!1;p++,\"MultiPoint\"===w&&b++}\"LineString\"===w&&b++;break;case\"Polygon\":case\"MultiLineString\":for(n=0;n<c.length;n++){for(a=0;a<c[n].length-f;a++){if(!1===e(c[n][a],p,y,b,_))return!1;p++}\"MultiLineString\"===w&&b++,\"Polygon\"===w&&_++}\"Polygon\"===w&&b++;break;case\"MultiPolygon\":for(n=0;n<c.length;n++){for(_=0,a=0;a<c[n].length;a++){for(o=0;o<c[n][a].length-f;o++){if(!1===e(c[n][a][o],p,y,b,_))return!1;p++}_++}b++}break;case\"GeometryCollection\":for(n=0;n<s.geometries.length;n++)if(!1===i(s.geometries[n],e,r))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}}}}}function a(t,e){var r;switch(t.type){case\"FeatureCollection\":for(r=0;r<t.features.length&&!1!==e(t.features[r].properties,r);r++);break;case\"Feature\":e(t.properties,0)}}function o(t,e){if(\"Feature\"===t.type)e(t,0);else if(\"FeatureCollection\"===t.type)for(var r=0;r<t.features.length&&!1!==e(t.features[r],r);r++);}function s(t,e){var r,n,i,a,o,s,l,c,u,h,f=0,p=\"FeatureCollection\"===t.type,d=\"Feature\"===t.type,g=p?t.features.length:1;for(r=0;r<g;r++){for(s=p?t.features[r].geometry:d?t.geometry:t,c=p?t.features[r].properties:d?t.properties:{},u=p?t.features[r].bbox:d?t.bbox:void 0,h=p?t.features[r].id:d?t.id:void 0,o=(l=!!s&&\"GeometryCollection\"===s.type)?s.geometries.length:1,i=0;i<o;i++)if(null!==(a=l?s.geometries[i]:s))switch(a.type){case\"Point\":case\"LineString\":case\"MultiPoint\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":if(!1===e(a,f,c,u,h))return!1;break;case\"GeometryCollection\":for(n=0;n<a.geometries.length;n++)if(!1===e(a.geometries[n],f,c,u,h))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}else if(!1===e(null,f,c,u,h))return!1;f++}}function l(t,e){s(t,function(t,r,i,a,o){var s,l=null===t?null:t.type;switch(l){case null:case\"Point\":case\"LineString\":case\"Polygon\":return!1!==e(n.feature(t,i,{bbox:a,id:o}),r,0)&&void 0}switch(l){case\"MultiPoint\":s=\"Point\";break;case\"MultiLineString\":s=\"LineString\";break;case\"MultiPolygon\":s=\"Polygon\"}for(var c=0;c<t.coordinates.length;c++){var u={type:s,coordinates:t.coordinates[c]};if(!1===e(n.feature(u,i),r,c))return!1}})}function c(t,e){l(t,function(t,r,a){var o=0;if(t.geometry){var s=t.geometry.type;if(\"Point\"!==s&&\"MultiPoint\"!==s){var l,c=0,u=0,h=0;return!1!==i(t,function(i,s,f,p,d){if(void 0===l||r>c||p>u||d>h)return l=i,c=r,u=p,h=d,void(o=0);var g=n.lineString([l,i],t.properties);if(!1===e(g,r,a,d,o))return!1;o++,l=i})&&void 0}}})}function u(t,e){if(!t)throw new Error(\"geojson is required\");l(t,function(t,r,i){if(null!==t.geometry){var a=t.geometry.type,o=t.geometry.coordinates;switch(a){case\"LineString\":if(!1===e(t,r,i,0,0))return!1;break;case\"Polygon\":for(var s=0;s<o.length;s++)if(!1===e(n.lineString(o[s],t.properties),r,i,s))return!1}}})}r.coordEach=i,r.coordReduce=function(t,e,r,n){var a=r;return i(t,function(t,n,i,o,s){a=0===n&&void 0===r?t:e(a,t,n,i,o,s)},n),a},r.propEach=a,r.propReduce=function(t,e,r){var n=r;return a(t,function(t,i){n=0===i&&void 0===r?t:e(n,t,i)}),n},r.featureEach=o,r.featureReduce=function(t,e,r){var n=r;return o(t,function(t,i){n=0===i&&void 0===r?t:e(n,t,i)}),n},r.coordAll=function(t){var e=[];return i(t,function(t){e.push(t)}),e},r.geomEach=s,r.geomReduce=function(t,e,r){var n=r;return s(t,function(t,i,a,o,s){n=0===i&&void 0===r?t:e(n,t,i,a,o,s)}),n},r.flattenEach=l,r.flattenReduce=function(t,e,r){var n=r;return l(t,function(t,i,a){n=0===i&&0===a&&void 0===r?t:e(n,t,i,a)}),n},r.segmentEach=c,r.segmentReduce=function(t,e,r){var n=r,i=!1;return c(t,function(t,a,o,s,l){n=!1===i&&void 0===r?t:e(n,t,a,o,s,l),i=!0}),n},r.lineEach=u,r.lineReduce=function(t,e,r){var n=r;return u(t,function(t,i,a,o){n=0===i&&void 0===r?t:e(n,t,i,a,o)}),n},r.findSegment=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.segmentIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":case\"MultiPoint\":return null;case\"LineString\":return s<0&&(s=c.length+s-1),n.lineString([c[s],c[s+1]],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s-1),n.lineString([c[o][s],c[o][s+1]],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s-1),n.lineString([c[a][s],c[a][s+1]],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s-1),n.lineString([c[a][o][s],c[a][o][s+1]],l,e)}throw new Error(\"geojson is invalid\")},r.findPoint=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.coordIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":return n.point(c,l,e);case\"MultiPoint\":return a<0&&(a=c.length+a),n.point(c[a],l,e);case\"LineString\":return s<0&&(s=c.length+s),n.point(c[s],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s),n.point(c[o][s],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s),n.point(c[a][s],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s),n.point(c[a][o][s],l,e)}throw new Error(\"geojson is invalid\")}},{\"@turf/helpers\":57}],59:[function(t,e,r){\"use strict\";var n=\"undefined\"==typeof WeakMap?t(\"weak-map\"):WeakMap,i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=new n;e.exports=function(t){var e=o.get(t),r=e&&(e._triangleBuffer.handle||e._triangleBuffer.buffer);if(!r||!t.isBuffer(r)){var n=i(t,new Float32Array([-1,-1,-1,4,4,-1]));(e=a(t,[{buffer:n,type:t.FLOAT,size:2}]))._triangleBuffer=n,o.set(t,e)}e.bind(),t.drawArrays(t.TRIANGLES,0,3),e.unbind()}},{\"gl-buffer\":241,\"gl-vao\":327,\"weak-map\":552}],60:[function(t,e,r){e.exports=function(t){var e=0,r=0,n=0,i=0;return t.map(function(t){var a=(t=t.slice())[0],o=a.toUpperCase();if(a!=o)switch(t[0]=o,a){case\"a\":t[6]+=n,t[7]+=i;break;case\"v\":t[1]+=i;break;case\"h\":t[1]+=n;break;default:for(var s=1;s<t.length;)t[s++]+=n,t[s++]+=i}switch(o){case\"Z\":n=e,i=r;break;case\"H\":n=t[1];break;case\"V\":i=t[1];break;case\"M\":n=e=t[1],i=r=t[2];break;default:n=t[t.length-2],i=t[t.length-1]}return t})}},{}],61:[function(t,e,r){var n=t(\"pad-left\");e.exports=function(t,e,r){e=\"number\"==typeof e?e:1,r=r||\": \";var i=t.split(/\\r?\\n/),a=String(i.length+e-1).length;return i.map(function(t,i){var o=i+e,s=String(o).length,l=n(o,a-s);return l+r+t}).join(\"\\n\")}},{\"pad-left\":457}],62:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[0];for(var r=t[0].length,n=[t[0]],a=[0],o=1;o<e;++o)if(n.push(t[o]),i(n,r)){if(a.push(o),a.length===r+1)return a}else n.pop();return a};var n=t(\"robust-orientation\");function i(t,e){for(var r=new Array(e+1),i=0;i<t.length;++i)r[i]=t[i];for(i=0;i<=t.length;++i){for(var a=t.length;a<=e;++a){for(var o=new Array(e),s=0;s<e;++s)o[s]=Math.pow(a+1-i,s);r[a]=o}if(n.apply(void 0,r))return!0}return!1}},{\"robust-orientation\":510}],63:[function(t,e,r){\"use strict\";e.exports=function(t,e){return n(e).filter(function(r){for(var n=new Array(r.length),a=0;a<r.length;++a)n[a]=e[r[a]];return i(n)*t<1})};var n=t(\"delaunay-triangulate\"),i=t(\"circumradius\")},{circumradius:114,\"delaunay-triangulate\":165}],64:[function(t,e,r){e.exports=function(t,e){return i(n(t,e))};var n=t(\"alpha-complex\"),i=t(\"simplicial-complex-boundary\")},{\"alpha-complex\":63,\"simplicial-complex-boundary\":517}],65:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(!t||null==t.length)throw Error(\"Argument should be an array\");e=null==e?1:Math.floor(e);for(var r=Array(2*e),n=0;n<e;n++){for(var i=-1/0,a=1/0,o=n,s=t.length;o<s;o+=e)t[o]>i&&(i=t[o]),t[o]<a&&(a=t[o]);r[n]=a,r[e+n]=i}return r}},{}],66:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\");e.exports=function(t,e,r){if(!t||null==t.length)throw Error(\"Argument should be an array\");null==e&&(e=1);null==r&&(r=n(t,e));for(var i=0;i<e;i++){var a=r[e+i],o=r[i],s=i,l=t.length;if(a===1/0&&o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:t[s]===o?0:.5;else if(a===1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:0;else if(o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===o?0:1;else{var c=a-o;for(s=i;s<l;s+=e)t[s]=0===c?.5:(t[s]-o)/c}}return t}},{\"array-bounds\":65}],67:[function(t,e,r){e.exports=function(t,e){var r=\"number\"==typeof t,n=\"number\"==typeof e;r&&!n?(e=t,t=0):r||n||(t=0,e=0);var i=(e|=0)-(t|=0);if(i<0)throw new Error(\"array length must be positive\");for(var a=new Array(i),o=0,s=t;o<i;o++,s++)a[o]=s;return a}},{}],68:[function(t,e,r){(function(r){\"use strict\";var n=t(\"object-assign\");function i(t,e){if(t===e)return 0;for(var r=t.length,n=e.length,i=0,a=Math.min(r,n);i<a;++i)if(t[i]!==e[i]){r=t[i],n=e[i];break}return r<n?-1:n<r?1:0}function a(t){return r.Buffer&&\"function\"==typeof r.Buffer.isBuffer?r.Buffer.isBuffer(t):!(null==t||!t._isBuffer)}var o=t(\"util/\"),s=Object.prototype.hasOwnProperty,l=Array.prototype.slice,c=\"foo\"===function(){}.name;function u(t){return Object.prototype.toString.call(t)}function h(t){return!a(t)&&(\"function\"==typeof r.ArrayBuffer&&(\"function\"==typeof ArrayBuffer.isView?ArrayBuffer.isView(t):!!t&&(t instanceof DataView||!!(t.buffer&&t.buffer instanceof ArrayBuffer))))}var f=e.exports=y,p=/\\s*function\\s+([^\\(\\s]*)\\s*/;function d(t){if(o.isFunction(t)){if(c)return t.name;var e=t.toString().match(p);return e&&e[1]}}function g(t,e){return\"string\"==typeof t?t.length<e?t:t.slice(0,e):t}function v(t){if(c||!o.isFunction(t))return o.inspect(t);var e=d(t);return\"[Function\"+(e?\": \"+e:\"\")+\"]\"}function m(t,e,r,n,i){throw new f.AssertionError({message:r,actual:t,expected:e,operator:n,stackStartFunction:i})}function y(t,e){t||m(t,!0,e,\"==\",f.ok)}function x(t,e,r,n){if(t===e)return!0;if(a(t)&&a(e))return 0===i(t,e);if(o.isDate(t)&&o.isDate(e))return t.getTime()===e.getTime();if(o.isRegExp(t)&&o.isRegExp(e))return t.source===e.source&&t.global===e.global&&t.multiline===e.multiline&&t.lastIndex===e.lastIndex&&t.ignoreCase===e.ignoreCase;if(null!==t&&\"object\"==typeof t||null!==e&&\"object\"==typeof e){if(h(t)&&h(e)&&u(t)===u(e)&&!(t instanceof Float32Array||t instanceof Float64Array))return 0===i(new Uint8Array(t.buffer),new Uint8Array(e.buffer));if(a(t)!==a(e))return!1;var s=(n=n||{actual:[],expected:[]}).actual.indexOf(t);return-1!==s&&s===n.expected.indexOf(e)||(n.actual.push(t),n.expected.push(e),function(t,e,r,n){if(null==t||null==e)return!1;if(o.isPrimitive(t)||o.isPrimitive(e))return t===e;if(r&&Object.getPrototypeOf(t)!==Object.getPrototypeOf(e))return!1;var i=b(t),a=b(e);if(i&&!a||!i&&a)return!1;if(i)return t=l.call(t),e=l.call(e),x(t,e,r);var s,c,u=k(t),h=k(e);if(u.length!==h.length)return!1;for(u.sort(),h.sort(),c=u.length-1;c>=0;c--)if(u[c]!==h[c])return!1;for(c=u.length-1;c>=0;c--)if(s=u[c],!x(t[s],e[s],r,n))return!1;return!0}(t,e,r,n))}return r?t===e:t==e}function b(t){return\"[object Arguments]\"==Object.prototype.toString.call(t)}function _(t,e){if(!t||!e)return!1;if(\"[object RegExp]\"==Object.prototype.toString.call(e))return e.test(t);try{if(t instanceof e)return!0}catch(t){}return!Error.isPrototypeOf(e)&&!0===e.call({},t)}function w(t,e,r,n){var i;if(\"function\"!=typeof e)throw new TypeError('\"block\" argument must be a function');\"string\"==typeof r&&(n=r,r=null),i=function(t){var e;try{t()}catch(t){e=t}return e}(e),n=(r&&r.name?\" (\"+r.name+\").\":\".\")+(n?\" \"+n:\".\"),t&&!i&&m(i,r,\"Missing expected exception\"+n);var a=\"string\"==typeof n,s=!t&&i&&!r;if((!t&&o.isError(i)&&a&&_(i,r)||s)&&m(i,r,\"Got unwanted exception\"+n),t&&i&&r&&!_(i,r)||!t&&i)throw i}f.AssertionError=function(t){var e;this.name=\"AssertionError\",this.actual=t.actual,this.expected=t.expected,this.operator=t.operator,t.message?(this.message=t.message,this.generatedMessage=!1):(this.message=g(v((e=this).actual),128)+\" \"+e.operator+\" \"+g(v(e.expected),128),this.generatedMessage=!0);var r=t.stackStartFunction||m;if(Error.captureStackTrace)Error.captureStackTrace(this,r);else{var n=new Error;if(n.stack){var i=n.stack,a=d(r),o=i.indexOf(\"\\n\"+a);if(o>=0){var s=i.indexOf(\"\\n\",o+1);i=i.substring(s+1)}this.stack=i}}},o.inherits(f.AssertionError,Error),f.fail=m,f.ok=y,f.equal=function(t,e,r){t!=e&&m(t,e,r,\"==\",f.equal)},f.notEqual=function(t,e,r){t==e&&m(t,e,r,\"!=\",f.notEqual)},f.deepEqual=function(t,e,r){x(t,e,!1)||m(t,e,r,\"deepEqual\",f.deepEqual)},f.deepStrictEqual=function(t,e,r){x(t,e,!0)||m(t,e,r,\"deepStrictEqual\",f.deepStrictEqual)},f.notDeepEqual=function(t,e,r){x(t,e,!1)&&m(t,e,r,\"notDeepEqual\",f.notDeepEqual)},f.notDeepStrictEqual=function t(e,r,n){x(e,r,!0)&&m(e,r,n,\"notDeepStrictEqual\",t)},f.strictEqual=function(t,e,r){t!==e&&m(t,e,r,\"===\",f.strictEqual)},f.notStrictEqual=function(t,e,r){t===e&&m(t,e,r,\"!==\",f.notStrictEqual)},f.throws=function(t,e,r){w(!0,t,e,r)},f.doesNotThrow=function(t,e,r){w(!1,t,e,r)},f.ifError=function(t){if(t)throw t},f.strict=n(function t(e,r){e||m(e,!0,r,\"==\",t)},f,{equal:f.strictEqual,deepEqual:f.deepStrictEqual,notEqual:f.notStrictEqual,notDeepEqual:f.notDeepStrictEqual}),f.strict.strict=f.strict;var k=Object.keys||function(t){var e=[];for(var r in t)s.call(t,r)&&e.push(r);return e}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"object-assign\":454,\"util/\":71}],69:[function(t,e,r){\"function\"==typeof Object.create?e.exports=function(t,e){t.super_=e,t.prototype=Object.create(e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}})}:e.exports=function(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}},{}],70:[function(t,e,r){e.exports=function(t){return t&&\"object\"==typeof t&&\"function\"==typeof t.copy&&\"function\"==typeof t.fill&&\"function\"==typeof t.readUInt8}},{}],71:[function(t,e,r){(function(e,n){var i=/%[sdj%]/g;r.format=function(t){if(!m(t)){for(var e=[],r=0;r<arguments.length;r++)e.push(s(arguments[r]));return e.join(\" \")}r=1;for(var n=arguments,a=n.length,o=String(t).replace(i,function(t){if(\"%%\"===t)return\"%\";if(r>=a)return t;switch(t){case\"%s\":return String(n[r++]);case\"%d\":return Number(n[r++]);case\"%j\":try{return JSON.stringify(n[r++])}catch(t){return\"[Circular]\"}default:return t}}),l=n[r];r<a;l=n[++r])g(l)||!b(l)?o+=\" \"+l:o+=\" \"+s(l);return o},r.deprecate=function(t,i){if(y(n.process))return function(){return r.deprecate(t,i).apply(this,arguments)};if(!0===e.noDeprecation)return t;var a=!1;return function(){if(!a){if(e.throwDeprecation)throw new Error(i);e.traceDeprecation?console.trace(i):console.error(i),a=!0}return t.apply(this,arguments)}};var a,o={};function s(t,e){var n={seen:[],stylize:c};return arguments.length>=3&&(n.depth=arguments[2]),arguments.length>=4&&(n.colors=arguments[3]),d(e)?n.showHidden=e:e&&r._extend(n,e),y(n.showHidden)&&(n.showHidden=!1),y(n.depth)&&(n.depth=2),y(n.colors)&&(n.colors=!1),y(n.customInspect)&&(n.customInspect=!0),n.colors&&(n.stylize=l),u(n,t,n.depth)}function l(t,e){var r=s.styles[e];return r?\"\\x1b[\"+s.colors[r][0]+\"m\"+t+\"\\x1b[\"+s.colors[r][1]+\"m\":t}function c(t,e){return t}function u(t,e,n){if(t.customInspect&&e&&k(e.inspect)&&e.inspect!==r.inspect&&(!e.constructor||e.constructor.prototype!==e)){var i=e.inspect(n,t);return m(i)||(i=u(t,i,n)),i}var a=function(t,e){if(y(e))return t.stylize(\"undefined\",\"undefined\");if(m(e)){var r=\"'\"+JSON.stringify(e).replace(/^\"|\"$/g,\"\").replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"')+\"'\";return t.stylize(r,\"string\")}if(v(e))return t.stylize(\"\"+e,\"number\");if(d(e))return t.stylize(\"\"+e,\"boolean\");if(g(e))return t.stylize(\"null\",\"null\")}(t,e);if(a)return a;var o=Object.keys(e),s=function(t){var e={};return t.forEach(function(t,r){e[t]=!0}),e}(o);if(t.showHidden&&(o=Object.getOwnPropertyNames(e)),w(e)&&(o.indexOf(\"message\")>=0||o.indexOf(\"description\")>=0))return h(e);if(0===o.length){if(k(e)){var l=e.name?\": \"+e.name:\"\";return t.stylize(\"[Function\"+l+\"]\",\"special\")}if(x(e))return t.stylize(RegExp.prototype.toString.call(e),\"regexp\");if(_(e))return t.stylize(Date.prototype.toString.call(e),\"date\");if(w(e))return h(e)}var c,b=\"\",T=!1,A=[\"{\",\"}\"];(p(e)&&(T=!0,A=[\"[\",\"]\"]),k(e))&&(b=\" [Function\"+(e.name?\": \"+e.name:\"\")+\"]\");return x(e)&&(b=\" \"+RegExp.prototype.toString.call(e)),_(e)&&(b=\" \"+Date.prototype.toUTCString.call(e)),w(e)&&(b=\" \"+h(e)),0!==o.length||T&&0!=e.length?n<0?x(e)?t.stylize(RegExp.prototype.toString.call(e),\"regexp\"):t.stylize(\"[Object]\",\"special\"):(t.seen.push(e),c=T?function(t,e,r,n,i){for(var a=[],o=0,s=e.length;o<s;++o)S(e,String(o))?a.push(f(t,e,r,n,String(o),!0)):a.push(\"\");return i.forEach(function(i){i.match(/^\\d+$/)||a.push(f(t,e,r,n,i,!0))}),a}(t,e,n,s,o):o.map(function(r){return f(t,e,n,s,r,T)}),t.seen.pop(),function(t,e,r){if(t.reduce(function(t,e){return 0,e.indexOf(\"\\n\")>=0&&0,t+e.replace(/\\u001b\\[\\d\\d?m/g,\"\").length+1},0)>60)return r[0]+(\"\"===e?\"\":e+\"\\n \")+\" \"+t.join(\",\\n  \")+\" \"+r[1];return r[0]+e+\" \"+t.join(\", \")+\" \"+r[1]}(c,b,A)):A[0]+b+A[1]}function h(t){return\"[\"+Error.prototype.toString.call(t)+\"]\"}function f(t,e,r,n,i,a){var o,s,l;if((l=Object.getOwnPropertyDescriptor(e,i)||{value:e[i]}).get?s=l.set?t.stylize(\"[Getter/Setter]\",\"special\"):t.stylize(\"[Getter]\",\"special\"):l.set&&(s=t.stylize(\"[Setter]\",\"special\")),S(n,i)||(o=\"[\"+i+\"]\"),s||(t.seen.indexOf(l.value)<0?(s=g(r)?u(t,l.value,null):u(t,l.value,r-1)).indexOf(\"\\n\")>-1&&(s=a?s.split(\"\\n\").map(function(t){return\"  \"+t}).join(\"\\n\").substr(2):\"\\n\"+s.split(\"\\n\").map(function(t){return\"   \"+t}).join(\"\\n\")):s=t.stylize(\"[Circular]\",\"special\")),y(o)){if(a&&i.match(/^\\d+$/))return s;(o=JSON.stringify(\"\"+i)).match(/^\"([a-zA-Z_][a-zA-Z_0-9]*)\"$/)?(o=o.substr(1,o.length-2),o=t.stylize(o,\"name\")):(o=o.replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"').replace(/(^\"|\"$)/g,\"'\"),o=t.stylize(o,\"string\"))}return o+\": \"+s}function p(t){return Array.isArray(t)}function d(t){return\"boolean\"==typeof t}function g(t){return null===t}function v(t){return\"number\"==typeof t}function m(t){return\"string\"==typeof t}function y(t){return void 0===t}function x(t){return b(t)&&\"[object RegExp]\"===T(t)}function b(t){return\"object\"==typeof t&&null!==t}function _(t){return b(t)&&\"[object Date]\"===T(t)}function w(t){return b(t)&&(\"[object Error]\"===T(t)||t instanceof Error)}function k(t){return\"function\"==typeof t}function T(t){return Object.prototype.toString.call(t)}function A(t){return t<10?\"0\"+t.toString(10):t.toString(10)}r.debuglog=function(t){if(y(a)&&(a=e.env.NODE_DEBUG||\"\"),t=t.toUpperCase(),!o[t])if(new RegExp(\"\\\\b\"+t+\"\\\\b\",\"i\").test(a)){var n=e.pid;o[t]=function(){var e=r.format.apply(r,arguments);console.error(\"%s %d: %s\",t,n,e)}}else o[t]=function(){};return o[t]},r.inspect=s,s.colors={bold:[1,22],italic:[3,23],underline:[4,24],inverse:[7,27],white:[37,39],grey:[90,39],black:[30,39],blue:[34,39],cyan:[36,39],green:[32,39],magenta:[35,39],red:[31,39],yellow:[33,39]},s.styles={special:\"cyan\",number:\"yellow\",boolean:\"yellow\",undefined:\"grey\",null:\"bold\",string:\"green\",date:\"magenta\",regexp:\"red\"},r.isArray=p,r.isBoolean=d,r.isNull=g,r.isNullOrUndefined=function(t){return null==t},r.isNumber=v,r.isString=m,r.isSymbol=function(t){return\"symbol\"==typeof t},r.isUndefined=y,r.isRegExp=x,r.isObject=b,r.isDate=_,r.isError=w,r.isFunction=k,r.isPrimitive=function(t){return null===t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||\"symbol\"==typeof t||\"undefined\"==typeof t},r.isBuffer=t(\"./support/isBuffer\");var M=[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"];function S(t,e){return Object.prototype.hasOwnProperty.call(t,e)}r.log=function(){var t,e;console.log(\"%s - %s\",(t=new Date,e=[A(t.getHours()),A(t.getMinutes()),A(t.getSeconds())].join(\":\"),[t.getDate(),M[t.getMonth()],e].join(\" \")),r.format.apply(r,arguments))},r.inherits=t(\"inherits\"),r._extend=function(t,e){if(!e||!b(e))return t;for(var r=Object.keys(e),n=r.length;n--;)t[r[n]]=e[r[n]];return t}}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./support/isBuffer\":70,_process:482,inherits:69}],72:[function(t,e,r){e.exports=function(t){return atob(t)}},{}],73:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=e.length,a=new Array(r+1),o=0;o<r;++o){for(var s=new Array(r+1),l=0;l<=r;++l)s[l]=t[l][o];a[o]=s}a[r]=new Array(r+1);for(var o=0;o<=r;++o)a[r][o]=1;for(var c=new Array(r+1),o=0;o<r;++o)c[o]=e[o];c[r]=1;var u=n(a,c),h=i(u[r+1]);0===h&&(h=1);for(var f=new Array(r+1),o=0;o<=r;++o)f[o]=i(u[o])/h;return f};var n=t(\"robust-linear-solve\");function i(t){for(var e=0,r=0;r<t.length;++r)e+=t[r];return e}},{\"robust-linear-solve\":509}],74:[function(t,e,r){\"use strict\";r.byteLength=function(t){var e=c(t),r=e[0],n=e[1];return 3*(r+n)/4-n},r.toByteArray=function(t){for(var e,r=c(t),n=r[0],o=r[1],s=new a(function(t,e,r){return 3*(e+r)/4-r}(0,n,o)),l=0,u=o>0?n-4:n,h=0;h<u;h+=4)e=i[t.charCodeAt(h)]<<18|i[t.charCodeAt(h+1)]<<12|i[t.charCodeAt(h+2)]<<6|i[t.charCodeAt(h+3)],s[l++]=e>>16&255,s[l++]=e>>8&255,s[l++]=255&e;2===o&&(e=i[t.charCodeAt(h)]<<2|i[t.charCodeAt(h+1)]>>4,s[l++]=255&e);1===o&&(e=i[t.charCodeAt(h)]<<10|i[t.charCodeAt(h+1)]<<4|i[t.charCodeAt(h+2)]>>2,s[l++]=e>>8&255,s[l++]=255&e);return s},r.fromByteArray=function(t){for(var e,r=t.length,i=r%3,a=[],o=0,s=r-i;o<s;o+=16383)a.push(u(t,o,o+16383>s?s:o+16383));1===i?(e=t[r-1],a.push(n[e>>2]+n[e<<4&63]+\"==\")):2===i&&(e=(t[r-2]<<8)+t[r-1],a.push(n[e>>10]+n[e>>4&63]+n[e<<2&63]+\"=\"));return a.join(\"\")};for(var n=[],i=[],a=\"undefined\"!=typeof Uint8Array?Uint8Array:Array,o=\"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/\",s=0,l=o.length;s<l;++s)n[s]=o[s],i[o.charCodeAt(s)]=s;function c(t){var e=t.length;if(e%4>0)throw new Error(\"Invalid string. Length must be a multiple of 4\");var r=t.indexOf(\"=\");return-1===r&&(r=e),[r,r===e?0:4-r%4]}function u(t,e,r){for(var i,a,o=[],s=e;s<r;s+=3)i=(t[s]<<16&16711680)+(t[s+1]<<8&65280)+(255&t[s+2]),o.push(n[(a=i)>>18&63]+n[a>>12&63]+n[a>>6&63]+n[63&a]);return o.join(\"\")}i[\"-\".charCodeAt(0)]=62,i[\"_\".charCodeAt(0)]=63},{}],75:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).add(e[0].mul(t[1])),t[1].mul(e[1]))}},{\"./lib/rationalize\":85}],76:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t[0].mul(e[1]).cmp(e[0].mul(t[1]))}},{}],77:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]),t[1].mul(e[0]))}},{\"./lib/rationalize\":85}],78:[function(t,e,r){\"use strict\";var n=t(\"./is-rat\"),i=t(\"./lib/is-bn\"),a=t(\"./lib/num-to-bn\"),o=t(\"./lib/str-to-bn\"),s=t(\"./lib/rationalize\"),l=t(\"./div\");e.exports=function t(e,r){if(n(e))return r?l(e,t(r)):[e[0].clone(),e[1].clone()];var c=0;var u,h;if(i(e))u=e.clone();else if(\"string\"==typeof e)u=o(e);else{if(0===e)return[a(0),a(1)];if(e===Math.floor(e))u=a(e);else{for(;e!==Math.floor(e);)e*=Math.pow(2,256),c-=256;u=a(e)}}if(n(r))u.mul(r[1]),h=r[0].clone();else if(i(r))h=r.clone();else if(\"string\"==typeof r)h=o(r);else if(r)if(r===Math.floor(r))h=a(r);else{for(;r!==Math.floor(r);)r*=Math.pow(2,256),c+=256;h=a(r)}else h=a(1);c>0?u=u.ushln(c):c<0&&(h=h.ushln(-c));return s(u,h)}},{\"./div\":77,\"./is-rat\":79,\"./lib/is-bn\":83,\"./lib/num-to-bn\":84,\"./lib/rationalize\":85,\"./lib/str-to-bn\":86}],79:[function(t,e,r){\"use strict\";var n=t(\"./lib/is-bn\");e.exports=function(t){return Array.isArray(t)&&2===t.length&&n(t[0])&&n(t[1])}},{\"./lib/is-bn\":83}],80:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return t.cmp(new n(0))}},{\"bn.js\":94}],81:[function(t,e,r){\"use strict\";var n=t(\"./bn-sign\");e.exports=function(t){var e=t.length,r=t.words,i=0;if(1===e)i=r[0];else if(2===e)i=r[0]+67108864*r[1];else for(var a=0;a<e;a++){var o=r[a];i+=o*Math.pow(67108864,a)}return n(t)*i}},{\"./bn-sign\":80}],82:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=t(\"bit-twiddle\").countTrailingZeros;e.exports=function(t){var e=i(n.lo(t));if(e<32)return e;var r=i(n.hi(t));if(r>20)return 52;return r+32}},{\"bit-twiddle\":92,\"double-bits\":167}],83:[function(t,e,r){\"use strict\";t(\"bn.js\");e.exports=function(t){return t&&\"object\"==typeof t&&Boolean(t.words)}},{\"bn.js\":94}],84:[function(t,e,r){\"use strict\";var n=t(\"bn.js\"),i=t(\"double-bits\");e.exports=function(t){var e=i.exponent(t);return e<52?new n(t):new n(t*Math.pow(2,52-e)).ushln(e-52)}},{\"bn.js\":94,\"double-bits\":167}],85:[function(t,e,r){\"use strict\";var n=t(\"./num-to-bn\"),i=t(\"./bn-sign\");e.exports=function(t,e){var r=i(t),a=i(e);if(0===r)return[n(0),n(1)];if(0===a)return[n(0),n(0)];a<0&&(t=t.neg(),e=e.neg());var o=t.gcd(e);if(o.cmpn(1))return[t.div(o),e.div(o)];return[t,e]}},{\"./bn-sign\":80,\"./num-to-bn\":84}],86:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return new n(t)}},{\"bn.js\":94}],87:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[0]),t[1].mul(e[1]))}},{\"./lib/rationalize\":85}],88:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-sign\");e.exports=function(t){return n(t[0])*n(t[1])}},{\"./lib/bn-sign\":80}],89:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).sub(t[1].mul(e[0])),t[1].mul(e[1]))}},{\"./lib/rationalize\":85}],90:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-to-num\"),i=t(\"./lib/ctz\");e.exports=function(t){var e=t[0],r=t[1];if(0===e.cmpn(0))return 0;var a=e.abs().divmod(r.abs()),o=a.div,s=n(o),l=a.mod,c=e.negative!==r.negative?-1:1;if(0===l.cmpn(0))return c*s;if(s){var u=i(s)+4,h=n(l.ushln(u).divRound(r));return c*(s+h*Math.pow(2,-u))}var f=r.bitLength()-l.bitLength()+53,h=n(l.ushln(f).divRound(r));return f<1023?c*h*Math.pow(2,-f):(h*=Math.pow(2,-1023),c*h*Math.pow(2,1023-f))}},{\"./lib/bn-to-num\":81,\"./lib/ctz\":82}],91:[function(t,e,r){\"use strict\";function n(t,e,r,n,i,a){var o=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",a?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a\",i?\".get(m)\":\"[m]\"];return a?e.indexOf(\"c\")<0?o.push(\";if(x===y){return m}else if(x<=y){\"):o.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):o.push(\";if(\",e,\"){i=m;\"),r?o.push(\"l=m+1}else{h=m-1}\"):o.push(\"h=m-1}else{l=m+1}\"),o.push(\"}\"),a?o.push(\"return -1};\"):o.push(\"return i};\"),o.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],!1,i),n(\"B\",\"x\"+t+\"y\",e,[\"y\"],!0,i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!1,i),n(\"Q\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!0,i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(a.shape){if(typeof(c)==='function'){return Q(a,(l===undefined)?0:l|0,(h===undefined)?a.shape[0]-1:h|0,y,c)}else{return B(a,(c===undefined)?0:c|0,(l===undefined)?a.shape[0]-1:l|0,y)}}else{if(typeof(c)==='function'){return P(a,(l===undefined)?0:l|0,(h===undefined)?a.length-1:h|0,y,c)}else{return A(a,(c===undefined)?0:c|0,(l===undefined)?a.length-1:l|0,y)}}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],92:[function(t,e,r){\"use strict\";function n(t){var e=32;return(t&=-t)&&e--,65535&t&&(e-=16),16711935&t&&(e-=8),252645135&t&&(e-=4),858993459&t&&(e-=2),1431655765&t&&(e-=1),e}r.INT_BITS=32,r.INT_MAX=2147483647,r.INT_MIN=-1<<31,r.sign=function(t){return(t>0)-(t<0)},r.abs=function(t){var e=t>>31;return(t^e)-e},r.min=function(t,e){return e^(t^e)&-(t<e)},r.max=function(t,e){return t^(t^e)&-(t<e)},r.isPow2=function(t){return!(t&t-1||!t)},r.log2=function(t){var e,r;return e=(t>65535)<<4,e|=r=((t>>>=e)>255)<<3,e|=r=((t>>>=r)>15)<<2,(e|=r=((t>>>=r)>3)<<1)|(t>>>=r)>>1},r.log10=function(t){return t>=1e9?9:t>=1e8?8:t>=1e7?7:t>=1e6?6:t>=1e5?5:t>=1e4?4:t>=1e3?3:t>=100?2:t>=10?1:0},r.popCount=function(t){return 16843009*((t=(858993459&(t-=t>>>1&1431655765))+(t>>>2&858993459))+(t>>>4)&252645135)>>>24},r.countTrailingZeros=n,r.nextPow2=function(t){return t+=0===t,--t,t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)+1},r.prevPow2=function(t){return t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)-(t>>>1)},r.parity=function(t){return t^=t>>>16,t^=t>>>8,t^=t>>>4,27030>>>(t&=15)&1};var i=new Array(256);!function(t){for(var e=0;e<256;++e){var r=e,n=e,i=7;for(r>>>=1;r;r>>>=1)n<<=1,n|=1&r,--i;t[e]=n<<i&255}}(i),r.reverse=function(t){return i[255&t]<<24|i[t>>>8&255]<<16|i[t>>>16&255]<<8|i[t>>>24&255]},r.interleave2=function(t,e){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t&=65535)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e&=65535)|e<<8))|e<<4))|e<<2))|e<<1))<<1},r.deinterleave2=function(t,e){return(t=65535&((t=16711935&((t=252645135&((t=858993459&((t=t>>>e&1431655765)|t>>>1))|t>>>2))|t>>>4))|t>>>16))<<16>>16},r.interleave3=function(t,e,r){return t=1227133513&((t=3272356035&((t=251719695&((t=4278190335&((t&=1023)|t<<16))|t<<8))|t<<4))|t<<2),(t|=(e=1227133513&((e=3272356035&((e=251719695&((e=4278190335&((e&=1023)|e<<16))|e<<8))|e<<4))|e<<2))<<1)|(r=1227133513&((r=3272356035&((r=251719695&((r=4278190335&((r&=1023)|r<<16))|r<<8))|r<<4))|r<<2))<<2},r.deinterleave3=function(t,e){return(t=1023&((t=4278190335&((t=251719695&((t=3272356035&((t=t>>>e&1227133513)|t>>>2))|t>>>4))|t>>>8))|t>>>16))<<22>>22},r.nextCombination=function(t){var e=t|t-1;return e+1|(~e&-~e)-1>>>n(t)+1}},{}],93:[function(t,e,r){\"use strict\";var n=t(\"clamp\");e.exports=function(t,e){e||(e={});var r,o,s,l,c,u,h,f,p,d,g,v=null==e.cutoff?.25:e.cutoff,m=null==e.radius?8:e.radius,y=e.channel||0;if(ArrayBuffer.isView(t)||Array.isArray(t)){if(!e.width||!e.height)throw Error(\"For raw data width and height should be provided by options\");r=e.width,o=e.height,l=t,u=e.stride?e.stride:Math.floor(t.length/r/o)}else window.HTMLCanvasElement&&t instanceof window.HTMLCanvasElement?(h=(f=t).getContext(\"2d\"),r=f.width,o=f.height,p=h.getImageData(0,0,r,o),l=p.data,u=4):window.CanvasRenderingContext2D&&t instanceof window.CanvasRenderingContext2D?(f=t.canvas,h=t,r=f.width,o=f.height,p=h.getImageData(0,0,r,o),l=p.data,u=4):window.ImageData&&t instanceof window.ImageData&&(p=t,r=t.width,o=t.height,l=p.data,u=4);if(s=Math.max(r,o),window.Uint8ClampedArray&&l instanceof window.Uint8ClampedArray||window.Uint8Array&&l instanceof window.Uint8Array)for(c=l,l=Array(r*o),d=0,g=c.length;d<g;d++)l[d]=c[d*u+y]/255;else if(1!==u)throw Error(\"Raw data can have only 1 value per pixel\");var x=Array(r*o),b=Array(r*o),_=Array(s),w=Array(s),k=Array(s+1),T=Array(s);for(d=0,g=r*o;d<g;d++){var A=l[d];x[d]=1===A?0:0===A?i:Math.pow(Math.max(0,.5-A),2),b[d]=1===A?i:0===A?0:Math.pow(Math.max(0,A-.5),2)}a(x,r,o,_,w,T,k),a(b,r,o,_,w,T,k);var M=window.Float32Array?new Float32Array(r*o):new Array(r*o);for(d=0,g=r*o;d<g;d++)M[d]=n(1-((x[d]-b[d])/m+v),0,1);return M};var i=1e20;function a(t,e,r,n,i,a,s){for(var l=0;l<e;l++){for(var c=0;c<r;c++)n[c]=t[c*e+l];for(o(n,i,a,s,r),c=0;c<r;c++)t[c*e+l]=i[c]}for(c=0;c<r;c++){for(l=0;l<e;l++)n[l]=t[c*e+l];for(o(n,i,a,s,e),l=0;l<e;l++)t[c*e+l]=Math.sqrt(i[l])}}function o(t,e,r,n,a){r[0]=0,n[0]=-i,n[1]=+i;for(var o=1,s=0;o<a;o++){for(var l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);l<=n[s];)s--,l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);r[++s]=o,n[s]=l,n[s+1]=+i}for(o=0,s=0;o<a;o++){for(;n[s+1]<o;)s++;e[o]=(o-r[s])*(o-r[s])+t[r[s]]}}},{clamp:115}],94:[function(t,e,r){!function(e,r){\"use strict\";function n(t,e){if(!t)throw new Error(e||\"Assertion failed\")}function i(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}function a(t,e,r){if(a.isBN(t))return t;this.negative=0,this.words=null,this.length=0,this.red=null,null!==t&&(\"le\"!==e&&\"be\"!==e||(r=e,e=10),this._init(t||0,e||10,r||\"be\"))}var o;\"object\"==typeof e?e.exports=a:r.BN=a,a.BN=a,a.wordSize=26;try{o=t(\"buffer\").Buffer}catch(t){}function s(t,e,r){for(var n=0,i=Math.min(t.length,r),a=e;a<i;a++){var o=t.charCodeAt(a)-48;n<<=4,n|=o>=49&&o<=54?o-49+10:o>=17&&o<=22?o-17+10:15&o}return n}function l(t,e,r,n){for(var i=0,a=Math.min(t.length,r),o=e;o<a;o++){var s=t.charCodeAt(o)-48;i*=n,i+=s>=49?s-49+10:s>=17?s-17+10:s}return i}a.isBN=function(t){return t instanceof a||null!==t&&\"object\"==typeof t&&t.constructor.wordSize===a.wordSize&&Array.isArray(t.words)},a.max=function(t,e){return t.cmp(e)>0?t:e},a.min=function(t,e){return t.cmp(e)<0?t:e},a.prototype._init=function(t,e,r){if(\"number\"==typeof t)return this._initNumber(t,e,r);if(\"object\"==typeof t)return this._initArray(t,e,r);\"hex\"===e&&(e=16),n(e===(0|e)&&e>=2&&e<=36);var i=0;\"-\"===(t=t.toString().replace(/\\s+/g,\"\"))[0]&&i++,16===e?this._parseHex(t,i):this._parseBase(t,e,i),\"-\"===t[0]&&(this.negative=1),this.strip(),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initNumber=function(t,e,r){t<0&&(this.negative=1,t=-t),t<67108864?(this.words=[67108863&t],this.length=1):t<4503599627370496?(this.words=[67108863&t,t/67108864&67108863],this.length=2):(n(t<9007199254740992),this.words=[67108863&t,t/67108864&67108863,1],this.length=3),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initArray=function(t,e,r){if(n(\"number\"==typeof t.length),t.length<=0)return this.words=[0],this.length=1,this;this.length=Math.ceil(t.length/3),this.words=new Array(this.length);for(var i=0;i<this.length;i++)this.words[i]=0;var a,o,s=0;if(\"be\"===r)for(i=t.length-1,a=0;i>=0;i-=3)o=t[i]|t[i-1]<<8|t[i-2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);else if(\"le\"===r)for(i=0,a=0;i<t.length;i+=3)o=t[i]|t[i+1]<<8|t[i+2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);return this.strip()},a.prototype._parseHex=function(t,e){this.length=Math.ceil((t.length-e)/6),this.words=new Array(this.length);for(var r=0;r<this.length;r++)this.words[r]=0;var n,i,a=0;for(r=t.length-6,n=0;r>=e;r-=6)i=s(t,r,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303,(a+=24)>=26&&(a-=26,n++);r+6!==e&&(i=s(t,e,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303),this.strip()},a.prototype._parseBase=function(t,e,r){this.words=[0],this.length=1;for(var n=0,i=1;i<=67108863;i*=e)n++;n--,i=i/e|0;for(var a=t.length-r,o=a%n,s=Math.min(a,a-o)+r,c=0,u=r;u<s;u+=n)c=l(t,u,u+n,e),this.imuln(i),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c);if(0!==o){var h=1;for(c=l(t,u,t.length,e),u=0;u<o;u++)h*=e;this.imuln(h),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c)}},a.prototype.copy=function(t){t.words=new Array(this.length);for(var e=0;e<this.length;e++)t.words[e]=this.words[e];t.length=this.length,t.negative=this.negative,t.red=this.red},a.prototype.clone=function(){var t=new a(null);return this.copy(t),t},a.prototype._expand=function(t){for(;this.length<t;)this.words[this.length++]=0;return this},a.prototype.strip=function(){for(;this.length>1&&0===this.words[this.length-1];)this.length--;return this._normSign()},a.prototype._normSign=function(){return 1===this.length&&0===this.words[0]&&(this.negative=0),this},a.prototype.inspect=function(){return(this.red?\"<BN-R: \":\"<BN: \")+this.toString(16)+\">\"};var c=[\"\",\"0\",\"00\",\"000\",\"0000\",\"00000\",\"000000\",\"0000000\",\"00000000\",\"000000000\",\"0000000000\",\"00000000000\",\"000000000000\",\"0000000000000\",\"00000000000000\",\"000000000000000\",\"0000000000000000\",\"00000000000000000\",\"000000000000000000\",\"0000000000000000000\",\"00000000000000000000\",\"000000000000000000000\",\"0000000000000000000000\",\"00000000000000000000000\",\"000000000000000000000000\",\"0000000000000000000000000\"],u=[0,0,25,16,12,11,10,9,8,8,7,7,7,7,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5],h=[0,0,33554432,43046721,16777216,48828125,60466176,40353607,16777216,43046721,1e7,19487171,35831808,62748517,7529536,11390625,16777216,24137569,34012224,47045881,64e6,4084101,5153632,6436343,7962624,9765625,11881376,14348907,17210368,20511149,243e5,28629151,33554432,39135393,45435424,52521875,60466176];function f(t,e,r){r.negative=e.negative^t.negative;var n=t.length+e.length|0;r.length=n,n=n-1|0;var i=0|t.words[0],a=0|e.words[0],o=i*a,s=67108863&o,l=o/67108864|0;r.words[0]=s;for(var c=1;c<n;c++){for(var u=l>>>26,h=67108863&l,f=Math.min(c,e.length-1),p=Math.max(0,c-t.length+1);p<=f;p++){var d=c-p|0;u+=(o=(i=0|t.words[d])*(a=0|e.words[p])+h)/67108864|0,h=67108863&o}r.words[c]=0|h,l=0|u}return 0!==l?r.words[c]=0|l:r.length--,r.strip()}a.prototype.toString=function(t,e){var r;if(e=0|e||1,16===(t=t||10)||\"hex\"===t){r=\"\";for(var i=0,a=0,o=0;o<this.length;o++){var s=this.words[o],l=(16777215&(s<<i|a)).toString(16);r=0!==(a=s>>>24-i&16777215)||o!==this.length-1?c[6-l.length]+l+r:l+r,(i+=2)>=26&&(i-=26,o--)}for(0!==a&&(r=a.toString(16)+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}if(t===(0|t)&&t>=2&&t<=36){var f=u[t],p=h[t];r=\"\";var d=this.clone();for(d.negative=0;!d.isZero();){var g=d.modn(p).toString(t);r=(d=d.idivn(p)).isZero()?g+r:c[f-g.length]+g+r}for(this.isZero()&&(r=\"0\"+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}n(!1,\"Base should be between 2 and 36\")},a.prototype.toNumber=function(){var t=this.words[0];return 2===this.length?t+=67108864*this.words[1]:3===this.length&&1===this.words[2]?t+=4503599627370496+67108864*this.words[1]:this.length>2&&n(!1,\"Number can only safely store up to 53 bits\"),0!==this.negative?-t:t},a.prototype.toJSON=function(){return this.toString(16)},a.prototype.toBuffer=function(t,e){return n(\"undefined\"!=typeof o),this.toArrayLike(o,t,e)},a.prototype.toArray=function(t,e){return this.toArrayLike(Array,t,e)},a.prototype.toArrayLike=function(t,e,r){var i=this.byteLength(),a=r||Math.max(1,i);n(i<=a,\"byte array longer than desired length\"),n(a>0,\"Requested array length <= 0\"),this.strip();var o,s,l=\"le\"===e,c=new t(a),u=this.clone();if(l){for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[s]=o;for(;s<a;s++)c[s]=0}else{for(s=0;s<a-i;s++)c[s]=0;for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[a-s-1]=o}return c},Math.clz32?a.prototype._countBits=function(t){return 32-Math.clz32(t)}:a.prototype._countBits=function(t){var e=t,r=0;return e>=4096&&(r+=13,e>>>=13),e>=64&&(r+=7,e>>>=7),e>=8&&(r+=4,e>>>=4),e>=2&&(r+=2,e>>>=2),r+e},a.prototype._zeroBits=function(t){if(0===t)return 26;var e=t,r=0;return 0==(8191&e)&&(r+=13,e>>>=13),0==(127&e)&&(r+=7,e>>>=7),0==(15&e)&&(r+=4,e>>>=4),0==(3&e)&&(r+=2,e>>>=2),0==(1&e)&&r++,r},a.prototype.bitLength=function(){var t=this.words[this.length-1],e=this._countBits(t);return 26*(this.length-1)+e},a.prototype.zeroBits=function(){if(this.isZero())return 0;for(var t=0,e=0;e<this.length;e++){var r=this._zeroBits(this.words[e]);if(t+=r,26!==r)break}return t},a.prototype.byteLength=function(){return Math.ceil(this.bitLength()/8)},a.prototype.toTwos=function(t){return 0!==this.negative?this.abs().inotn(t).iaddn(1):this.clone()},a.prototype.fromTwos=function(t){return this.testn(t-1)?this.notn(t).iaddn(1).ineg():this.clone()},a.prototype.isNeg=function(){return 0!==this.negative},a.prototype.neg=function(){return this.clone().ineg()},a.prototype.ineg=function(){return this.isZero()||(this.negative^=1),this},a.prototype.iuor=function(t){for(;this.length<t.length;)this.words[this.length++]=0;for(var e=0;e<t.length;e++)this.words[e]=this.words[e]|t.words[e];return this.strip()},a.prototype.ior=function(t){return n(0==(this.negative|t.negative)),this.iuor(t)},a.prototype.or=function(t){return this.length>t.length?this.clone().ior(t):t.clone().ior(this)},a.prototype.uor=function(t){return this.length>t.length?this.clone().iuor(t):t.clone().iuor(this)},a.prototype.iuand=function(t){var e;e=this.length>t.length?t:this;for(var r=0;r<e.length;r++)this.words[r]=this.words[r]&t.words[r];return this.length=e.length,this.strip()},a.prototype.iand=function(t){return n(0==(this.negative|t.negative)),this.iuand(t)},a.prototype.and=function(t){return this.length>t.length?this.clone().iand(t):t.clone().iand(this)},a.prototype.uand=function(t){return this.length>t.length?this.clone().iuand(t):t.clone().iuand(this)},a.prototype.iuxor=function(t){var e,r;this.length>t.length?(e=this,r=t):(e=t,r=this);for(var n=0;n<r.length;n++)this.words[n]=e.words[n]^r.words[n];if(this!==e)for(;n<e.length;n++)this.words[n]=e.words[n];return this.length=e.length,this.strip()},a.prototype.ixor=function(t){return n(0==(this.negative|t.negative)),this.iuxor(t)},a.prototype.xor=function(t){return this.length>t.length?this.clone().ixor(t):t.clone().ixor(this)},a.prototype.uxor=function(t){return this.length>t.length?this.clone().iuxor(t):t.clone().iuxor(this)},a.prototype.inotn=function(t){n(\"number\"==typeof t&&t>=0);var e=0|Math.ceil(t/26),r=t%26;this._expand(e),r>0&&e--;for(var i=0;i<e;i++)this.words[i]=67108863&~this.words[i];return r>0&&(this.words[i]=~this.words[i]&67108863>>26-r),this.strip()},a.prototype.notn=function(t){return this.clone().inotn(t)},a.prototype.setn=function(t,e){n(\"number\"==typeof t&&t>=0);var r=t/26|0,i=t%26;return this._expand(r+1),this.words[r]=e?this.words[r]|1<<i:this.words[r]&~(1<<i),this.strip()},a.prototype.iadd=function(t){var e,r,n;if(0!==this.negative&&0===t.negative)return this.negative=0,e=this.isub(t),this.negative^=1,this._normSign();if(0===this.negative&&0!==t.negative)return t.negative=0,e=this.isub(t),t.negative=1,e._normSign();this.length>t.length?(r=this,n=t):(r=t,n=this);for(var i=0,a=0;a<n.length;a++)e=(0|r.words[a])+(0|n.words[a])+i,this.words[a]=67108863&e,i=e>>>26;for(;0!==i&&a<r.length;a++)e=(0|r.words[a])+i,this.words[a]=67108863&e,i=e>>>26;if(this.length=r.length,0!==i)this.words[this.length]=i,this.length++;else if(r!==this)for(;a<r.length;a++)this.words[a]=r.words[a];return this},a.prototype.add=function(t){var e;return 0!==t.negative&&0===this.negative?(t.negative=0,e=this.sub(t),t.negative^=1,e):0===t.negative&&0!==this.negative?(this.negative=0,e=t.sub(this),this.negative=1,e):this.length>t.length?this.clone().iadd(t):t.clone().iadd(this)},a.prototype.isub=function(t){if(0!==t.negative){t.negative=0;var e=this.iadd(t);return t.negative=1,e._normSign()}if(0!==this.negative)return this.negative=0,this.iadd(t),this.negative=1,this._normSign();var r,n,i=this.cmp(t);if(0===i)return this.negative=0,this.length=1,this.words[0]=0,this;i>0?(r=this,n=t):(r=t,n=this);for(var a=0,o=0;o<n.length;o++)a=(e=(0|r.words[o])-(0|n.words[o])+a)>>26,this.words[o]=67108863&e;for(;0!==a&&o<r.length;o++)a=(e=(0|r.words[o])+a)>>26,this.words[o]=67108863&e;if(0===a&&o<r.length&&r!==this)for(;o<r.length;o++)this.words[o]=r.words[o];return this.length=Math.max(this.length,o),r!==this&&(this.negative=1),this.strip()},a.prototype.sub=function(t){return this.clone().isub(t)};var p=function(t,e,r){var n,i,a,o=t.words,s=e.words,l=r.words,c=0,u=0|o[0],h=8191&u,f=u>>>13,p=0|o[1],d=8191&p,g=p>>>13,v=0|o[2],m=8191&v,y=v>>>13,x=0|o[3],b=8191&x,_=x>>>13,w=0|o[4],k=8191&w,T=w>>>13,A=0|o[5],M=8191&A,S=A>>>13,E=0|o[6],C=8191&E,L=E>>>13,P=0|o[7],O=8191&P,z=P>>>13,I=0|o[8],D=8191&I,R=I>>>13,F=0|o[9],B=8191&F,N=F>>>13,j=0|s[0],U=8191&j,V=j>>>13,q=0|s[1],H=8191&q,G=q>>>13,Y=0|s[2],W=8191&Y,X=Y>>>13,Z=0|s[3],J=8191&Z,K=Z>>>13,$=0|s[4],Q=8191&$,tt=$>>>13,et=0|s[5],rt=8191&et,nt=et>>>13,it=0|s[6],at=8191&it,ot=it>>>13,st=0|s[7],lt=8191&st,ct=st>>>13,ut=0|s[8],ht=8191&ut,ft=ut>>>13,pt=0|s[9],dt=8191&pt,gt=pt>>>13;r.negative=t.negative^e.negative,r.length=19;var vt=(c+(n=Math.imul(h,U))|0)+((8191&(i=(i=Math.imul(h,V))+Math.imul(f,U)|0))<<13)|0;c=((a=Math.imul(f,V))+(i>>>13)|0)+(vt>>>26)|0,vt&=67108863,n=Math.imul(d,U),i=(i=Math.imul(d,V))+Math.imul(g,U)|0,a=Math.imul(g,V);var mt=(c+(n=n+Math.imul(h,H)|0)|0)+((8191&(i=(i=i+Math.imul(h,G)|0)+Math.imul(f,H)|0))<<13)|0;c=((a=a+Math.imul(f,G)|0)+(i>>>13)|0)+(mt>>>26)|0,mt&=67108863,n=Math.imul(m,U),i=(i=Math.imul(m,V))+Math.imul(y,U)|0,a=Math.imul(y,V),n=n+Math.imul(d,H)|0,i=(i=i+Math.imul(d,G)|0)+Math.imul(g,H)|0,a=a+Math.imul(g,G)|0;var yt=(c+(n=n+Math.imul(h,W)|0)|0)+((8191&(i=(i=i+Math.imul(h,X)|0)+Math.imul(f,W)|0))<<13)|0;c=((a=a+Math.imul(f,X)|0)+(i>>>13)|0)+(yt>>>26)|0,yt&=67108863,n=Math.imul(b,U),i=(i=Math.imul(b,V))+Math.imul(_,U)|0,a=Math.imul(_,V),n=n+Math.imul(m,H)|0,i=(i=i+Math.imul(m,G)|0)+Math.imul(y,H)|0,a=a+Math.imul(y,G)|0,n=n+Math.imul(d,W)|0,i=(i=i+Math.imul(d,X)|0)+Math.imul(g,W)|0,a=a+Math.imul(g,X)|0;var xt=(c+(n=n+Math.imul(h,J)|0)|0)+((8191&(i=(i=i+Math.imul(h,K)|0)+Math.imul(f,J)|0))<<13)|0;c=((a=a+Math.imul(f,K)|0)+(i>>>13)|0)+(xt>>>26)|0,xt&=67108863,n=Math.imul(k,U),i=(i=Math.imul(k,V))+Math.imul(T,U)|0,a=Math.imul(T,V),n=n+Math.imul(b,H)|0,i=(i=i+Math.imul(b,G)|0)+Math.imul(_,H)|0,a=a+Math.imul(_,G)|0,n=n+Math.imul(m,W)|0,i=(i=i+Math.imul(m,X)|0)+Math.imul(y,W)|0,a=a+Math.imul(y,X)|0,n=n+Math.imul(d,J)|0,i=(i=i+Math.imul(d,K)|0)+Math.imul(g,J)|0,a=a+Math.imul(g,K)|0;var bt=(c+(n=n+Math.imul(h,Q)|0)|0)+((8191&(i=(i=i+Math.imul(h,tt)|0)+Math.imul(f,Q)|0))<<13)|0;c=((a=a+Math.imul(f,tt)|0)+(i>>>13)|0)+(bt>>>26)|0,bt&=67108863,n=Math.imul(M,U),i=(i=Math.imul(M,V))+Math.imul(S,U)|0,a=Math.imul(S,V),n=n+Math.imul(k,H)|0,i=(i=i+Math.imul(k,G)|0)+Math.imul(T,H)|0,a=a+Math.imul(T,G)|0,n=n+Math.imul(b,W)|0,i=(i=i+Math.imul(b,X)|0)+Math.imul(_,W)|0,a=a+Math.imul(_,X)|0,n=n+Math.imul(m,J)|0,i=(i=i+Math.imul(m,K)|0)+Math.imul(y,J)|0,a=a+Math.imul(y,K)|0,n=n+Math.imul(d,Q)|0,i=(i=i+Math.imul(d,tt)|0)+Math.imul(g,Q)|0,a=a+Math.imul(g,tt)|0;var _t=(c+(n=n+Math.imul(h,rt)|0)|0)+((8191&(i=(i=i+Math.imul(h,nt)|0)+Math.imul(f,rt)|0))<<13)|0;c=((a=a+Math.imul(f,nt)|0)+(i>>>13)|0)+(_t>>>26)|0,_t&=67108863,n=Math.imul(C,U),i=(i=Math.imul(C,V))+Math.imul(L,U)|0,a=Math.imul(L,V),n=n+Math.imul(M,H)|0,i=(i=i+Math.imul(M,G)|0)+Math.imul(S,H)|0,a=a+Math.imul(S,G)|0,n=n+Math.imul(k,W)|0,i=(i=i+Math.imul(k,X)|0)+Math.imul(T,W)|0,a=a+Math.imul(T,X)|0,n=n+Math.imul(b,J)|0,i=(i=i+Math.imul(b,K)|0)+Math.imul(_,J)|0,a=a+Math.imul(_,K)|0,n=n+Math.imul(m,Q)|0,i=(i=i+Math.imul(m,tt)|0)+Math.imul(y,Q)|0,a=a+Math.imul(y,tt)|0,n=n+Math.imul(d,rt)|0,i=(i=i+Math.imul(d,nt)|0)+Math.imul(g,rt)|0,a=a+Math.imul(g,nt)|0;var wt=(c+(n=n+Math.imul(h,at)|0)|0)+((8191&(i=(i=i+Math.imul(h,ot)|0)+Math.imul(f,at)|0))<<13)|0;c=((a=a+Math.imul(f,ot)|0)+(i>>>13)|0)+(wt>>>26)|0,wt&=67108863,n=Math.imul(O,U),i=(i=Math.imul(O,V))+Math.imul(z,U)|0,a=Math.imul(z,V),n=n+Math.imul(C,H)|0,i=(i=i+Math.imul(C,G)|0)+Math.imul(L,H)|0,a=a+Math.imul(L,G)|0,n=n+Math.imul(M,W)|0,i=(i=i+Math.imul(M,X)|0)+Math.imul(S,W)|0,a=a+Math.imul(S,X)|0,n=n+Math.imul(k,J)|0,i=(i=i+Math.imul(k,K)|0)+Math.imul(T,J)|0,a=a+Math.imul(T,K)|0,n=n+Math.imul(b,Q)|0,i=(i=i+Math.imul(b,tt)|0)+Math.imul(_,Q)|0,a=a+Math.imul(_,tt)|0,n=n+Math.imul(m,rt)|0,i=(i=i+Math.imul(m,nt)|0)+Math.imul(y,rt)|0,a=a+Math.imul(y,nt)|0,n=n+Math.imul(d,at)|0,i=(i=i+Math.imul(d,ot)|0)+Math.imul(g,at)|0,a=a+Math.imul(g,ot)|0;var kt=(c+(n=n+Math.imul(h,lt)|0)|0)+((8191&(i=(i=i+Math.imul(h,ct)|0)+Math.imul(f,lt)|0))<<13)|0;c=((a=a+Math.imul(f,ct)|0)+(i>>>13)|0)+(kt>>>26)|0,kt&=67108863,n=Math.imul(D,U),i=(i=Math.imul(D,V))+Math.imul(R,U)|0,a=Math.imul(R,V),n=n+Math.imul(O,H)|0,i=(i=i+Math.imul(O,G)|0)+Math.imul(z,H)|0,a=a+Math.imul(z,G)|0,n=n+Math.imul(C,W)|0,i=(i=i+Math.imul(C,X)|0)+Math.imul(L,W)|0,a=a+Math.imul(L,X)|0,n=n+Math.imul(M,J)|0,i=(i=i+Math.imul(M,K)|0)+Math.imul(S,J)|0,a=a+Math.imul(S,K)|0,n=n+Math.imul(k,Q)|0,i=(i=i+Math.imul(k,tt)|0)+Math.imul(T,Q)|0,a=a+Math.imul(T,tt)|0,n=n+Math.imul(b,rt)|0,i=(i=i+Math.imul(b,nt)|0)+Math.imul(_,rt)|0,a=a+Math.imul(_,nt)|0,n=n+Math.imul(m,at)|0,i=(i=i+Math.imul(m,ot)|0)+Math.imul(y,at)|0,a=a+Math.imul(y,ot)|0,n=n+Math.imul(d,lt)|0,i=(i=i+Math.imul(d,ct)|0)+Math.imul(g,lt)|0,a=a+Math.imul(g,ct)|0;var Tt=(c+(n=n+Math.imul(h,ht)|0)|0)+((8191&(i=(i=i+Math.imul(h,ft)|0)+Math.imul(f,ht)|0))<<13)|0;c=((a=a+Math.imul(f,ft)|0)+(i>>>13)|0)+(Tt>>>26)|0,Tt&=67108863,n=Math.imul(B,U),i=(i=Math.imul(B,V))+Math.imul(N,U)|0,a=Math.imul(N,V),n=n+Math.imul(D,H)|0,i=(i=i+Math.imul(D,G)|0)+Math.imul(R,H)|0,a=a+Math.imul(R,G)|0,n=n+Math.imul(O,W)|0,i=(i=i+Math.imul(O,X)|0)+Math.imul(z,W)|0,a=a+Math.imul(z,X)|0,n=n+Math.imul(C,J)|0,i=(i=i+Math.imul(C,K)|0)+Math.imul(L,J)|0,a=a+Math.imul(L,K)|0,n=n+Math.imul(M,Q)|0,i=(i=i+Math.imul(M,tt)|0)+Math.imul(S,Q)|0,a=a+Math.imul(S,tt)|0,n=n+Math.imul(k,rt)|0,i=(i=i+Math.imul(k,nt)|0)+Math.imul(T,rt)|0,a=a+Math.imul(T,nt)|0,n=n+Math.imul(b,at)|0,i=(i=i+Math.imul(b,ot)|0)+Math.imul(_,at)|0,a=a+Math.imul(_,ot)|0,n=n+Math.imul(m,lt)|0,i=(i=i+Math.imul(m,ct)|0)+Math.imul(y,lt)|0,a=a+Math.imul(y,ct)|0,n=n+Math.imul(d,ht)|0,i=(i=i+Math.imul(d,ft)|0)+Math.imul(g,ht)|0,a=a+Math.imul(g,ft)|0;var At=(c+(n=n+Math.imul(h,dt)|0)|0)+((8191&(i=(i=i+Math.imul(h,gt)|0)+Math.imul(f,dt)|0))<<13)|0;c=((a=a+Math.imul(f,gt)|0)+(i>>>13)|0)+(At>>>26)|0,At&=67108863,n=Math.imul(B,H),i=(i=Math.imul(B,G))+Math.imul(N,H)|0,a=Math.imul(N,G),n=n+Math.imul(D,W)|0,i=(i=i+Math.imul(D,X)|0)+Math.imul(R,W)|0,a=a+Math.imul(R,X)|0,n=n+Math.imul(O,J)|0,i=(i=i+Math.imul(O,K)|0)+Math.imul(z,J)|0,a=a+Math.imul(z,K)|0,n=n+Math.imul(C,Q)|0,i=(i=i+Math.imul(C,tt)|0)+Math.imul(L,Q)|0,a=a+Math.imul(L,tt)|0,n=n+Math.imul(M,rt)|0,i=(i=i+Math.imul(M,nt)|0)+Math.imul(S,rt)|0,a=a+Math.imul(S,nt)|0,n=n+Math.imul(k,at)|0,i=(i=i+Math.imul(k,ot)|0)+Math.imul(T,at)|0,a=a+Math.imul(T,ot)|0,n=n+Math.imul(b,lt)|0,i=(i=i+Math.imul(b,ct)|0)+Math.imul(_,lt)|0,a=a+Math.imul(_,ct)|0,n=n+Math.imul(m,ht)|0,i=(i=i+Math.imul(m,ft)|0)+Math.imul(y,ht)|0,a=a+Math.imul(y,ft)|0;var Mt=(c+(n=n+Math.imul(d,dt)|0)|0)+((8191&(i=(i=i+Math.imul(d,gt)|0)+Math.imul(g,dt)|0))<<13)|0;c=((a=a+Math.imul(g,gt)|0)+(i>>>13)|0)+(Mt>>>26)|0,Mt&=67108863,n=Math.imul(B,W),i=(i=Math.imul(B,X))+Math.imul(N,W)|0,a=Math.imul(N,X),n=n+Math.imul(D,J)|0,i=(i=i+Math.imul(D,K)|0)+Math.imul(R,J)|0,a=a+Math.imul(R,K)|0,n=n+Math.imul(O,Q)|0,i=(i=i+Math.imul(O,tt)|0)+Math.imul(z,Q)|0,a=a+Math.imul(z,tt)|0,n=n+Math.imul(C,rt)|0,i=(i=i+Math.imul(C,nt)|0)+Math.imul(L,rt)|0,a=a+Math.imul(L,nt)|0,n=n+Math.imul(M,at)|0,i=(i=i+Math.imul(M,ot)|0)+Math.imul(S,at)|0,a=a+Math.imul(S,ot)|0,n=n+Math.imul(k,lt)|0,i=(i=i+Math.imul(k,ct)|0)+Math.imul(T,lt)|0,a=a+Math.imul(T,ct)|0,n=n+Math.imul(b,ht)|0,i=(i=i+Math.imul(b,ft)|0)+Math.imul(_,ht)|0,a=a+Math.imul(_,ft)|0;var St=(c+(n=n+Math.imul(m,dt)|0)|0)+((8191&(i=(i=i+Math.imul(m,gt)|0)+Math.imul(y,dt)|0))<<13)|0;c=((a=a+Math.imul(y,gt)|0)+(i>>>13)|0)+(St>>>26)|0,St&=67108863,n=Math.imul(B,J),i=(i=Math.imul(B,K))+Math.imul(N,J)|0,a=Math.imul(N,K),n=n+Math.imul(D,Q)|0,i=(i=i+Math.imul(D,tt)|0)+Math.imul(R,Q)|0,a=a+Math.imul(R,tt)|0,n=n+Math.imul(O,rt)|0,i=(i=i+Math.imul(O,nt)|0)+Math.imul(z,rt)|0,a=a+Math.imul(z,nt)|0,n=n+Math.imul(C,at)|0,i=(i=i+Math.imul(C,ot)|0)+Math.imul(L,at)|0,a=a+Math.imul(L,ot)|0,n=n+Math.imul(M,lt)|0,i=(i=i+Math.imul(M,ct)|0)+Math.imul(S,lt)|0,a=a+Math.imul(S,ct)|0,n=n+Math.imul(k,ht)|0,i=(i=i+Math.imul(k,ft)|0)+Math.imul(T,ht)|0,a=a+Math.imul(T,ft)|0;var Et=(c+(n=n+Math.imul(b,dt)|0)|0)+((8191&(i=(i=i+Math.imul(b,gt)|0)+Math.imul(_,dt)|0))<<13)|0;c=((a=a+Math.imul(_,gt)|0)+(i>>>13)|0)+(Et>>>26)|0,Et&=67108863,n=Math.imul(B,Q),i=(i=Math.imul(B,tt))+Math.imul(N,Q)|0,a=Math.imul(N,tt),n=n+Math.imul(D,rt)|0,i=(i=i+Math.imul(D,nt)|0)+Math.imul(R,rt)|0,a=a+Math.imul(R,nt)|0,n=n+Math.imul(O,at)|0,i=(i=i+Math.imul(O,ot)|0)+Math.imul(z,at)|0,a=a+Math.imul(z,ot)|0,n=n+Math.imul(C,lt)|0,i=(i=i+Math.imul(C,ct)|0)+Math.imul(L,lt)|0,a=a+Math.imul(L,ct)|0,n=n+Math.imul(M,ht)|0,i=(i=i+Math.imul(M,ft)|0)+Math.imul(S,ht)|0,a=a+Math.imul(S,ft)|0;var Ct=(c+(n=n+Math.imul(k,dt)|0)|0)+((8191&(i=(i=i+Math.imul(k,gt)|0)+Math.imul(T,dt)|0))<<13)|0;c=((a=a+Math.imul(T,gt)|0)+(i>>>13)|0)+(Ct>>>26)|0,Ct&=67108863,n=Math.imul(B,rt),i=(i=Math.imul(B,nt))+Math.imul(N,rt)|0,a=Math.imul(N,nt),n=n+Math.imul(D,at)|0,i=(i=i+Math.imul(D,ot)|0)+Math.imul(R,at)|0,a=a+Math.imul(R,ot)|0,n=n+Math.imul(O,lt)|0,i=(i=i+Math.imul(O,ct)|0)+Math.imul(z,lt)|0,a=a+Math.imul(z,ct)|0,n=n+Math.imul(C,ht)|0,i=(i=i+Math.imul(C,ft)|0)+Math.imul(L,ht)|0,a=a+Math.imul(L,ft)|0;var Lt=(c+(n=n+Math.imul(M,dt)|0)|0)+((8191&(i=(i=i+Math.imul(M,gt)|0)+Math.imul(S,dt)|0))<<13)|0;c=((a=a+Math.imul(S,gt)|0)+(i>>>13)|0)+(Lt>>>26)|0,Lt&=67108863,n=Math.imul(B,at),i=(i=Math.imul(B,ot))+Math.imul(N,at)|0,a=Math.imul(N,ot),n=n+Math.imul(D,lt)|0,i=(i=i+Math.imul(D,ct)|0)+Math.imul(R,lt)|0,a=a+Math.imul(R,ct)|0,n=n+Math.imul(O,ht)|0,i=(i=i+Math.imul(O,ft)|0)+Math.imul(z,ht)|0,a=a+Math.imul(z,ft)|0;var Pt=(c+(n=n+Math.imul(C,dt)|0)|0)+((8191&(i=(i=i+Math.imul(C,gt)|0)+Math.imul(L,dt)|0))<<13)|0;c=((a=a+Math.imul(L,gt)|0)+(i>>>13)|0)+(Pt>>>26)|0,Pt&=67108863,n=Math.imul(B,lt),i=(i=Math.imul(B,ct))+Math.imul(N,lt)|0,a=Math.imul(N,ct),n=n+Math.imul(D,ht)|0,i=(i=i+Math.imul(D,ft)|0)+Math.imul(R,ht)|0,a=a+Math.imul(R,ft)|0;var Ot=(c+(n=n+Math.imul(O,dt)|0)|0)+((8191&(i=(i=i+Math.imul(O,gt)|0)+Math.imul(z,dt)|0))<<13)|0;c=((a=a+Math.imul(z,gt)|0)+(i>>>13)|0)+(Ot>>>26)|0,Ot&=67108863,n=Math.imul(B,ht),i=(i=Math.imul(B,ft))+Math.imul(N,ht)|0,a=Math.imul(N,ft);var zt=(c+(n=n+Math.imul(D,dt)|0)|0)+((8191&(i=(i=i+Math.imul(D,gt)|0)+Math.imul(R,dt)|0))<<13)|0;c=((a=a+Math.imul(R,gt)|0)+(i>>>13)|0)+(zt>>>26)|0,zt&=67108863;var It=(c+(n=Math.imul(B,dt))|0)+((8191&(i=(i=Math.imul(B,gt))+Math.imul(N,dt)|0))<<13)|0;return c=((a=Math.imul(N,gt))+(i>>>13)|0)+(It>>>26)|0,It&=67108863,l[0]=vt,l[1]=mt,l[2]=yt,l[3]=xt,l[4]=bt,l[5]=_t,l[6]=wt,l[7]=kt,l[8]=Tt,l[9]=At,l[10]=Mt,l[11]=St,l[12]=Et,l[13]=Ct,l[14]=Lt,l[15]=Pt,l[16]=Ot,l[17]=zt,l[18]=It,0!==c&&(l[19]=c,r.length++),r};function d(t,e,r){return(new g).mulp(t,e,r)}function g(t,e){this.x=t,this.y=e}Math.imul||(p=f),a.prototype.mulTo=function(t,e){var r=this.length+t.length;return 10===this.length&&10===t.length?p(this,t,e):r<63?f(this,t,e):r<1024?function(t,e,r){r.negative=e.negative^t.negative,r.length=t.length+e.length;for(var n=0,i=0,a=0;a<r.length-1;a++){var o=i;i=0;for(var s=67108863&n,l=Math.min(a,e.length-1),c=Math.max(0,a-t.length+1);c<=l;c++){var u=a-c,h=(0|t.words[u])*(0|e.words[c]),f=67108863&h;s=67108863&(f=f+s|0),i+=(o=(o=o+(h/67108864|0)|0)+(f>>>26)|0)>>>26,o&=67108863}r.words[a]=s,n=o,o=i}return 0!==n?r.words[a]=n:r.length--,r.strip()}(this,t,e):d(this,t,e)},g.prototype.makeRBT=function(t){for(var e=new Array(t),r=a.prototype._countBits(t)-1,n=0;n<t;n++)e[n]=this.revBin(n,r,t);return e},g.prototype.revBin=function(t,e,r){if(0===t||t===r-1)return t;for(var n=0,i=0;i<e;i++)n|=(1&t)<<e-i-1,t>>=1;return n},g.prototype.permute=function(t,e,r,n,i,a){for(var o=0;o<a;o++)n[o]=e[t[o]],i[o]=r[t[o]]},g.prototype.transform=function(t,e,r,n,i,a){this.permute(a,t,e,r,n,i);for(var o=1;o<i;o<<=1)for(var s=o<<1,l=Math.cos(2*Math.PI/s),c=Math.sin(2*Math.PI/s),u=0;u<i;u+=s)for(var h=l,f=c,p=0;p<o;p++){var d=r[u+p],g=n[u+p],v=r[u+p+o],m=n[u+p+o],y=h*v-f*m;m=h*m+f*v,v=y,r[u+p]=d+v,n[u+p]=g+m,r[u+p+o]=d-v,n[u+p+o]=g-m,p!==s&&(y=l*h-c*f,f=l*f+c*h,h=y)}},g.prototype.guessLen13b=function(t,e){var r=1|Math.max(e,t),n=1&r,i=0;for(r=r/2|0;r;r>>>=1)i++;return 1<<i+1+n},g.prototype.conjugate=function(t,e,r){if(!(r<=1))for(var n=0;n<r/2;n++){var i=t[n];t[n]=t[r-n-1],t[r-n-1]=i,i=e[n],e[n]=-e[r-n-1],e[r-n-1]=-i}},g.prototype.normalize13b=function(t,e){for(var r=0,n=0;n<e/2;n++){var i=8192*Math.round(t[2*n+1]/e)+Math.round(t[2*n]/e)+r;t[n]=67108863&i,r=i<67108864?0:i/67108864|0}return t},g.prototype.convert13b=function(t,e,r,i){for(var a=0,o=0;o<e;o++)a+=0|t[o],r[2*o]=8191&a,a>>>=13,r[2*o+1]=8191&a,a>>>=13;for(o=2*e;o<i;++o)r[o]=0;n(0===a),n(0==(-8192&a))},g.prototype.stub=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=0;return e},g.prototype.mulp=function(t,e,r){var n=2*this.guessLen13b(t.length,e.length),i=this.makeRBT(n),a=this.stub(n),o=new Array(n),s=new Array(n),l=new Array(n),c=new Array(n),u=new Array(n),h=new Array(n),f=r.words;f.length=n,this.convert13b(t.words,t.length,o,n),this.convert13b(e.words,e.length,c,n),this.transform(o,a,s,l,n,i),this.transform(c,a,u,h,n,i);for(var p=0;p<n;p++){var d=s[p]*u[p]-l[p]*h[p];l[p]=s[p]*h[p]+l[p]*u[p],s[p]=d}return this.conjugate(s,l,n),this.transform(s,l,f,a,n,i),this.conjugate(f,a,n),this.normalize13b(f,n),r.negative=t.negative^e.negative,r.length=t.length+e.length,r.strip()},a.prototype.mul=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),this.mulTo(t,e)},a.prototype.mulf=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),d(this,t,e)},a.prototype.imul=function(t){return this.clone().mulTo(t,this)},a.prototype.imuln=function(t){n(\"number\"==typeof t),n(t<67108864);for(var e=0,r=0;r<this.length;r++){var i=(0|this.words[r])*t,a=(67108863&i)+(67108863&e);e>>=26,e+=i/67108864|0,e+=a>>>26,this.words[r]=67108863&a}return 0!==e&&(this.words[r]=e,this.length++),this},a.prototype.muln=function(t){return this.clone().imuln(t)},a.prototype.sqr=function(){return this.mul(this)},a.prototype.isqr=function(){return this.imul(this.clone())},a.prototype.pow=function(t){var e=function(t){for(var e=new Array(t.bitLength()),r=0;r<e.length;r++){var n=r/26|0,i=r%26;e[r]=(t.words[n]&1<<i)>>>i}return e}(t);if(0===e.length)return new a(1);for(var r=this,n=0;n<e.length&&0===e[n];n++,r=r.sqr());if(++n<e.length)for(var i=r.sqr();n<e.length;n++,i=i.sqr())0!==e[n]&&(r=r.mul(i));return r},a.prototype.iushln=function(t){n(\"number\"==typeof t&&t>=0);var e,r=t%26,i=(t-r)/26,a=67108863>>>26-r<<26-r;if(0!==r){var o=0;for(e=0;e<this.length;e++){var s=this.words[e]&a,l=(0|this.words[e])-s<<r;this.words[e]=l|o,o=s>>>26-r}o&&(this.words[e]=o,this.length++)}if(0!==i){for(e=this.length-1;e>=0;e--)this.words[e+i]=this.words[e];for(e=0;e<i;e++)this.words[e]=0;this.length+=i}return this.strip()},a.prototype.ishln=function(t){return n(0===this.negative),this.iushln(t)},a.prototype.iushrn=function(t,e,r){var i;n(\"number\"==typeof t&&t>=0),i=e?(e-e%26)/26:0;var a=t%26,o=Math.min((t-a)/26,this.length),s=67108863^67108863>>>a<<a,l=r;if(i-=o,i=Math.max(0,i),l){for(var c=0;c<o;c++)l.words[c]=this.words[c];l.length=o}if(0===o);else if(this.length>o)for(this.length-=o,c=0;c<this.length;c++)this.words[c]=this.words[c+o];else this.words[0]=0,this.length=1;var u=0;for(c=this.length-1;c>=0&&(0!==u||c>=i);c--){var h=0|this.words[c];this.words[c]=u<<26-a|h>>>a,u=h&s}return l&&0!==u&&(l.words[l.length++]=u),0===this.length&&(this.words[0]=0,this.length=1),this.strip()},a.prototype.ishrn=function(t,e,r){return n(0===this.negative),this.iushrn(t,e,r)},a.prototype.shln=function(t){return this.clone().ishln(t)},a.prototype.ushln=function(t){return this.clone().iushln(t)},a.prototype.shrn=function(t){return this.clone().ishrn(t)},a.prototype.ushrn=function(t){return this.clone().iushrn(t)},a.prototype.testn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26,i=1<<e;return!(this.length<=r)&&!!(this.words[r]&i)},a.prototype.imaskn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26;if(n(0===this.negative,\"imaskn works only with positive numbers\"),this.length<=r)return this;if(0!==e&&r++,this.length=Math.min(r,this.length),0!==e){var i=67108863^67108863>>>e<<e;this.words[this.length-1]&=i}return this.strip()},a.prototype.maskn=function(t){return this.clone().imaskn(t)},a.prototype.iaddn=function(t){return n(\"number\"==typeof t),n(t<67108864),t<0?this.isubn(-t):0!==this.negative?1===this.length&&(0|this.words[0])<t?(this.words[0]=t-(0|this.words[0]),this.negative=0,this):(this.negative=0,this.isubn(t),this.negative=1,this):this._iaddn(t)},a.prototype._iaddn=function(t){this.words[0]+=t;for(var e=0;e<this.length&&this.words[e]>=67108864;e++)this.words[e]-=67108864,e===this.length-1?this.words[e+1]=1:this.words[e+1]++;return this.length=Math.max(this.length,e+1),this},a.prototype.isubn=function(t){if(n(\"number\"==typeof t),n(t<67108864),t<0)return this.iaddn(-t);if(0!==this.negative)return this.negative=0,this.iaddn(t),this.negative=1,this;if(this.words[0]-=t,1===this.length&&this.words[0]<0)this.words[0]=-this.words[0],this.negative=1;else for(var e=0;e<this.length&&this.words[e]<0;e++)this.words[e]+=67108864,this.words[e+1]-=1;return this.strip()},a.prototype.addn=function(t){return this.clone().iaddn(t)},a.prototype.subn=function(t){return this.clone().isubn(t)},a.prototype.iabs=function(){return this.negative=0,this},a.prototype.abs=function(){return this.clone().iabs()},a.prototype._ishlnsubmul=function(t,e,r){var i,a,o=t.length+r;this._expand(o);var s=0;for(i=0;i<t.length;i++){a=(0|this.words[i+r])+s;var l=(0|t.words[i])*e;s=((a-=67108863&l)>>26)-(l/67108864|0),this.words[i+r]=67108863&a}for(;i<this.length-r;i++)s=(a=(0|this.words[i+r])+s)>>26,this.words[i+r]=67108863&a;if(0===s)return this.strip();for(n(-1===s),s=0,i=0;i<this.length;i++)s=(a=-(0|this.words[i])+s)>>26,this.words[i]=67108863&a;return this.negative=1,this.strip()},a.prototype._wordDiv=function(t,e){var r=(this.length,t.length),n=this.clone(),i=t,o=0|i.words[i.length-1];0!==(r=26-this._countBits(o))&&(i=i.ushln(r),n.iushln(r),o=0|i.words[i.length-1]);var s,l=n.length-i.length;if(\"mod\"!==e){(s=new a(null)).length=l+1,s.words=new Array(s.length);for(var c=0;c<s.length;c++)s.words[c]=0}var u=n.clone()._ishlnsubmul(i,1,l);0===u.negative&&(n=u,s&&(s.words[l]=1));for(var h=l-1;h>=0;h--){var f=67108864*(0|n.words[i.length+h])+(0|n.words[i.length+h-1]);for(f=Math.min(f/o|0,67108863),n._ishlnsubmul(i,f,h);0!==n.negative;)f--,n.negative=0,n._ishlnsubmul(i,1,h),n.isZero()||(n.negative^=1);s&&(s.words[h]=f)}return s&&s.strip(),n.strip(),\"div\"!==e&&0!==r&&n.iushrn(r),{div:s||null,mod:n}},a.prototype.divmod=function(t,e,r){return n(!t.isZero()),this.isZero()?{div:new a(0),mod:new a(0)}:0!==this.negative&&0===t.negative?(s=this.neg().divmod(t,e),\"mod\"!==e&&(i=s.div.neg()),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.iadd(t)),{div:i,mod:o}):0===this.negative&&0!==t.negative?(s=this.divmod(t.neg(),e),\"mod\"!==e&&(i=s.div.neg()),{div:i,mod:s.mod}):0!=(this.negative&t.negative)?(s=this.neg().divmod(t.neg(),e),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.isub(t)),{div:s.div,mod:o}):t.length>this.length||this.cmp(t)<0?{div:new a(0),mod:this}:1===t.length?\"div\"===e?{div:this.divn(t.words[0]),mod:null}:\"mod\"===e?{div:null,mod:new a(this.modn(t.words[0]))}:{div:this.divn(t.words[0]),mod:new a(this.modn(t.words[0]))}:this._wordDiv(t,e);var i,o,s},a.prototype.div=function(t){return this.divmod(t,\"div\",!1).div},a.prototype.mod=function(t){return this.divmod(t,\"mod\",!1).mod},a.prototype.umod=function(t){return this.divmod(t,\"mod\",!0).mod},a.prototype.divRound=function(t){var e=this.divmod(t);if(e.mod.isZero())return e.div;var r=0!==e.div.negative?e.mod.isub(t):e.mod,n=t.ushrn(1),i=t.andln(1),a=r.cmp(n);return a<0||1===i&&0===a?e.div:0!==e.div.negative?e.div.isubn(1):e.div.iaddn(1)},a.prototype.modn=function(t){n(t<=67108863);for(var e=(1<<26)%t,r=0,i=this.length-1;i>=0;i--)r=(e*r+(0|this.words[i]))%t;return r},a.prototype.idivn=function(t){n(t<=67108863);for(var e=0,r=this.length-1;r>=0;r--){var i=(0|this.words[r])+67108864*e;this.words[r]=i/t|0,e=i%t}return this.strip()},a.prototype.divn=function(t){return this.clone().idivn(t)},a.prototype.egcd=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i=new a(1),o=new a(0),s=new a(0),l=new a(1),c=0;e.isEven()&&r.isEven();)e.iushrn(1),r.iushrn(1),++c;for(var u=r.clone(),h=e.clone();!e.isZero();){for(var f=0,p=1;0==(e.words[0]&p)&&f<26;++f,p<<=1);if(f>0)for(e.iushrn(f);f-- >0;)(i.isOdd()||o.isOdd())&&(i.iadd(u),o.isub(h)),i.iushrn(1),o.iushrn(1);for(var d=0,g=1;0==(r.words[0]&g)&&d<26;++d,g<<=1);if(d>0)for(r.iushrn(d);d-- >0;)(s.isOdd()||l.isOdd())&&(s.iadd(u),l.isub(h)),s.iushrn(1),l.iushrn(1);e.cmp(r)>=0?(e.isub(r),i.isub(s),o.isub(l)):(r.isub(e),s.isub(i),l.isub(o))}return{a:s,b:l,gcd:r.iushln(c)}},a.prototype._invmp=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i,o=new a(1),s=new a(0),l=r.clone();e.cmpn(1)>0&&r.cmpn(1)>0;){for(var c=0,u=1;0==(e.words[0]&u)&&c<26;++c,u<<=1);if(c>0)for(e.iushrn(c);c-- >0;)o.isOdd()&&o.iadd(l),o.iushrn(1);for(var h=0,f=1;0==(r.words[0]&f)&&h<26;++h,f<<=1);if(h>0)for(r.iushrn(h);h-- >0;)s.isOdd()&&s.iadd(l),s.iushrn(1);e.cmp(r)>=0?(e.isub(r),o.isub(s)):(r.isub(e),s.isub(o))}return(i=0===e.cmpn(1)?o:s).cmpn(0)<0&&i.iadd(t),i},a.prototype.gcd=function(t){if(this.isZero())return t.abs();if(t.isZero())return this.abs();var e=this.clone(),r=t.clone();e.negative=0,r.negative=0;for(var n=0;e.isEven()&&r.isEven();n++)e.iushrn(1),r.iushrn(1);for(;;){for(;e.isEven();)e.iushrn(1);for(;r.isEven();)r.iushrn(1);var i=e.cmp(r);if(i<0){var a=e;e=r,r=a}else if(0===i||0===r.cmpn(1))break;e.isub(r)}return r.iushln(n)},a.prototype.invm=function(t){return this.egcd(t).a.umod(t)},a.prototype.isEven=function(){return 0==(1&this.words[0])},a.prototype.isOdd=function(){return 1==(1&this.words[0])},a.prototype.andln=function(t){return this.words[0]&t},a.prototype.bincn=function(t){n(\"number\"==typeof t);var e=t%26,r=(t-e)/26,i=1<<e;if(this.length<=r)return this._expand(r+1),this.words[r]|=i,this;for(var a=i,o=r;0!==a&&o<this.length;o++){var s=0|this.words[o];a=(s+=a)>>>26,s&=67108863,this.words[o]=s}return 0!==a&&(this.words[o]=a,this.length++),this},a.prototype.isZero=function(){return 1===this.length&&0===this.words[0]},a.prototype.cmpn=function(t){var e,r=t<0;if(0!==this.negative&&!r)return-1;if(0===this.negative&&r)return 1;if(this.strip(),this.length>1)e=1;else{r&&(t=-t),n(t<=67108863,\"Number is too big\");var i=0|this.words[0];e=i===t?0:i<t?-1:1}return 0!==this.negative?0|-e:e},a.prototype.cmp=function(t){if(0!==this.negative&&0===t.negative)return-1;if(0===this.negative&&0!==t.negative)return 1;var e=this.ucmp(t);return 0!==this.negative?0|-e:e},a.prototype.ucmp=function(t){if(this.length>t.length)return 1;if(this.length<t.length)return-1;for(var e=0,r=this.length-1;r>=0;r--){var n=0|this.words[r],i=0|t.words[r];if(n!==i){n<i?e=-1:n>i&&(e=1);break}}return e},a.prototype.gtn=function(t){return 1===this.cmpn(t)},a.prototype.gt=function(t){return 1===this.cmp(t)},a.prototype.gten=function(t){return this.cmpn(t)>=0},a.prototype.gte=function(t){return this.cmp(t)>=0},a.prototype.ltn=function(t){return-1===this.cmpn(t)},a.prototype.lt=function(t){return-1===this.cmp(t)},a.prototype.lten=function(t){return this.cmpn(t)<=0},a.prototype.lte=function(t){return this.cmp(t)<=0},a.prototype.eqn=function(t){return 0===this.cmpn(t)},a.prototype.eq=function(t){return 0===this.cmp(t)},a.red=function(t){return new w(t)},a.prototype.toRed=function(t){return n(!this.red,\"Already a number in reduction context\"),n(0===this.negative,\"red works only with positives\"),t.convertTo(this)._forceRed(t)},a.prototype.fromRed=function(){return n(this.red,\"fromRed works only with numbers in reduction context\"),this.red.convertFrom(this)},a.prototype._forceRed=function(t){return this.red=t,this},a.prototype.forceRed=function(t){return n(!this.red,\"Already a number in reduction context\"),this._forceRed(t)},a.prototype.redAdd=function(t){return n(this.red,\"redAdd works only with red numbers\"),this.red.add(this,t)},a.prototype.redIAdd=function(t){return n(this.red,\"redIAdd works only with red numbers\"),this.red.iadd(this,t)},a.prototype.redSub=function(t){return n(this.red,\"redSub works only with red numbers\"),this.red.sub(this,t)},a.prototype.redISub=function(t){return n(this.red,\"redISub works only with red numbers\"),this.red.isub(this,t)},a.prototype.redShl=function(t){return n(this.red,\"redShl works only with red numbers\"),this.red.shl(this,t)},a.prototype.redMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.mul(this,t)},a.prototype.redIMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.imul(this,t)},a.prototype.redSqr=function(){return n(this.red,\"redSqr works only with red numbers\"),this.red._verify1(this),this.red.sqr(this)},a.prototype.redISqr=function(){return n(this.red,\"redISqr works only with red numbers\"),this.red._verify1(this),this.red.isqr(this)},a.prototype.redSqrt=function(){return n(this.red,\"redSqrt works only with red numbers\"),this.red._verify1(this),this.red.sqrt(this)},a.prototype.redInvm=function(){return n(this.red,\"redInvm works only with red numbers\"),this.red._verify1(this),this.red.invm(this)},a.prototype.redNeg=function(){return n(this.red,\"redNeg works only with red numbers\"),this.red._verify1(this),this.red.neg(this)},a.prototype.redPow=function(t){return n(this.red&&!t.red,\"redPow(normalNum)\"),this.red._verify1(this),this.red.pow(this,t)};var v={k256:null,p224:null,p192:null,p25519:null};function m(t,e){this.name=t,this.p=new a(e,16),this.n=this.p.bitLength(),this.k=new a(1).iushln(this.n).isub(this.p),this.tmp=this._tmp()}function y(){m.call(this,\"k256\",\"ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffe fffffc2f\")}function x(){m.call(this,\"p224\",\"ffffffff ffffffff ffffffff ffffffff 00000000 00000000 00000001\")}function b(){m.call(this,\"p192\",\"ffffffff ffffffff ffffffff fffffffe ffffffff ffffffff\")}function _(){m.call(this,\"25519\",\"7fffffffffffffff ffffffffffffffff ffffffffffffffff ffffffffffffffed\")}function w(t){if(\"string\"==typeof t){var e=a._prime(t);this.m=e.p,this.prime=e}else n(t.gtn(1),\"modulus must be greater than 1\"),this.m=t,this.prime=null}function k(t){w.call(this,t),this.shift=this.m.bitLength(),this.shift%26!=0&&(this.shift+=26-this.shift%26),this.r=new a(1).iushln(this.shift),this.r2=this.imod(this.r.sqr()),this.rinv=this.r._invmp(this.m),this.minv=this.rinv.mul(this.r).isubn(1).div(this.m),this.minv=this.minv.umod(this.r),this.minv=this.r.sub(this.minv)}m.prototype._tmp=function(){var t=new a(null);return t.words=new Array(Math.ceil(this.n/13)),t},m.prototype.ireduce=function(t){var e,r=t;do{this.split(r,this.tmp),e=(r=(r=this.imulK(r)).iadd(this.tmp)).bitLength()}while(e>this.n);var n=e<this.n?-1:r.ucmp(this.p);return 0===n?(r.words[0]=0,r.length=1):n>0?r.isub(this.p):r.strip(),r},m.prototype.split=function(t,e){t.iushrn(this.n,0,e)},m.prototype.imulK=function(t){return t.imul(this.k)},i(y,m),y.prototype.split=function(t,e){for(var r=Math.min(t.length,9),n=0;n<r;n++)e.words[n]=t.words[n];if(e.length=r,t.length<=9)return t.words[0]=0,void(t.length=1);var i=t.words[9];for(e.words[e.length++]=4194303&i,n=10;n<t.length;n++){var a=0|t.words[n];t.words[n-10]=(4194303&a)<<4|i>>>22,i=a}i>>>=22,t.words[n-10]=i,0===i&&t.length>10?t.length-=10:t.length-=9},y.prototype.imulK=function(t){t.words[t.length]=0,t.words[t.length+1]=0,t.length+=2;for(var e=0,r=0;r<t.length;r++){var n=0|t.words[r];e+=977*n,t.words[r]=67108863&e,e=64*n+(e/67108864|0)}return 0===t.words[t.length-1]&&(t.length--,0===t.words[t.length-1]&&t.length--),t},i(x,m),i(b,m),i(_,m),_.prototype.imulK=function(t){for(var e=0,r=0;r<t.length;r++){var n=19*(0|t.words[r])+e,i=67108863&n;n>>>=26,t.words[r]=i,e=n}return 0!==e&&(t.words[t.length++]=e),t},a._prime=function(t){if(v[t])return v[t];var e;if(\"k256\"===t)e=new y;else if(\"p224\"===t)e=new x;else if(\"p192\"===t)e=new b;else{if(\"p25519\"!==t)throw new Error(\"Unknown prime \"+t);e=new _}return v[t]=e,e},w.prototype._verify1=function(t){n(0===t.negative,\"red works only with positives\"),n(t.red,\"red works only with red numbers\")},w.prototype._verify2=function(t,e){n(0==(t.negative|e.negative),\"red works only with positives\"),n(t.red&&t.red===e.red,\"red works only with red numbers\")},w.prototype.imod=function(t){return this.prime?this.prime.ireduce(t)._forceRed(this):t.umod(this.m)._forceRed(this)},w.prototype.neg=function(t){return t.isZero()?t.clone():this.m.sub(t)._forceRed(this)},w.prototype.add=function(t,e){this._verify2(t,e);var r=t.add(e);return r.cmp(this.m)>=0&&r.isub(this.m),r._forceRed(this)},w.prototype.iadd=function(t,e){this._verify2(t,e);var r=t.iadd(e);return r.cmp(this.m)>=0&&r.isub(this.m),r},w.prototype.sub=function(t,e){this._verify2(t,e);var r=t.sub(e);return r.cmpn(0)<0&&r.iadd(this.m),r._forceRed(this)},w.prototype.isub=function(t,e){this._verify2(t,e);var r=t.isub(e);return r.cmpn(0)<0&&r.iadd(this.m),r},w.prototype.shl=function(t,e){return this._verify1(t),this.imod(t.ushln(e))},w.prototype.imul=function(t,e){return this._verify2(t,e),this.imod(t.imul(e))},w.prototype.mul=function(t,e){return this._verify2(t,e),this.imod(t.mul(e))},w.prototype.isqr=function(t){return this.imul(t,t.clone())},w.prototype.sqr=function(t){return this.mul(t,t)},w.prototype.sqrt=function(t){if(t.isZero())return t.clone();var e=this.m.andln(3);if(n(e%2==1),3===e){var r=this.m.add(new a(1)).iushrn(2);return this.pow(t,r)}for(var i=this.m.subn(1),o=0;!i.isZero()&&0===i.andln(1);)o++,i.iushrn(1);n(!i.isZero());var s=new a(1).toRed(this),l=s.redNeg(),c=this.m.subn(1).iushrn(1),u=this.m.bitLength();for(u=new a(2*u*u).toRed(this);0!==this.pow(u,c).cmp(l);)u.redIAdd(l);for(var h=this.pow(u,i),f=this.pow(t,i.addn(1).iushrn(1)),p=this.pow(t,i),d=o;0!==p.cmp(s);){for(var g=p,v=0;0!==g.cmp(s);v++)g=g.redSqr();n(v<d);var m=this.pow(h,new a(1).iushln(d-v-1));f=f.redMul(m),h=m.redSqr(),p=p.redMul(h),d=v}return f},w.prototype.invm=function(t){var e=t._invmp(this.m);return 0!==e.negative?(e.negative=0,this.imod(e).redNeg()):this.imod(e)},w.prototype.pow=function(t,e){if(e.isZero())return new a(1).toRed(this);if(0===e.cmpn(1))return t.clone();var r=new Array(16);r[0]=new a(1).toRed(this),r[1]=t;for(var n=2;n<r.length;n++)r[n]=this.mul(r[n-1],t);var i=r[0],o=0,s=0,l=e.bitLength()%26;for(0===l&&(l=26),n=e.length-1;n>=0;n--){for(var c=e.words[n],u=l-1;u>=0;u--){var h=c>>u&1;i!==r[0]&&(i=this.sqr(i)),0!==h||0!==o?(o<<=1,o|=h,(4===++s||0===n&&0===u)&&(i=this.mul(i,r[o]),s=0,o=0)):s=0}l=26}return i},w.prototype.convertTo=function(t){var e=t.umod(this.m);return e===t?e.clone():e},w.prototype.convertFrom=function(t){var e=t.clone();return e.red=null,e},a.mont=function(t){return new k(t)},i(k,w),k.prototype.convertTo=function(t){return this.imod(t.ushln(this.shift))},k.prototype.convertFrom=function(t){var e=this.imod(t.mul(this.rinv));return e.red=null,e},k.prototype.imul=function(t,e){if(t.isZero()||e.isZero())return t.words[0]=0,t.length=1,t;var r=t.imul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),a=i;return i.cmp(this.m)>=0?a=i.isub(this.m):i.cmpn(0)<0&&(a=i.iadd(this.m)),a._forceRed(this)},k.prototype.mul=function(t,e){if(t.isZero()||e.isZero())return new a(0)._forceRed(this);var r=t.mul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),o=i;return i.cmp(this.m)>=0?o=i.isub(this.m):i.cmpn(0)<0&&(o=i.iadd(this.m)),o._forceRed(this)},k.prototype.invm=function(t){return this.imod(t._invmp(this.m).mul(this.r2))._forceRed(this)}}(\"undefined\"==typeof e||e,this)},{buffer:103}],95:[function(t,e,r){\"use strict\";e.exports=function(t){var e,r,n,i=t.length,a=0;for(e=0;e<i;++e)a+=t[e].length;var o=new Array(a),s=0;for(e=0;e<i;++e){var l=t[e],c=l.length;for(r=0;r<c;++r){var u=o[s++]=new Array(c-1),h=0;for(n=0;n<c;++n)n!==r&&(u[h++]=l[n]);if(1&r){var f=u[1];u[1]=u[0],u[0]=f}}}return o}},{}],96:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 1:return n=[],c(i=t,i,u,!0),n;case 2:return\"function\"==typeof e?c(t,t,e,!0):function(t,e){return n=[],c(t,e,u,!1),n}(t,e);case 3:return c(t,e,r,!1);default:throw new Error(\"box-intersect: Invalid arguments\")}var i};var n,i=t(\"typedarray-pool\"),a=t(\"./lib/sweep\"),o=t(\"./lib/intersect\");function s(t,e){for(var r=0;r<t;++r)if(!(e[r]<=e[r+t]))return!0;return!1}function l(t,e,r,n){for(var i=0,a=0,o=0,l=t.length;o<l;++o){var c=t[o];if(!s(e,c)){for(var u=0;u<2*e;++u)r[i++]=c[u];n[a++]=o}}return a}function c(t,e,r,n){var s=t.length,c=e.length;if(!(s<=0||c<=0)){var u=t[0].length>>>1;if(!(u<=0)){var h,f=i.mallocDouble(2*u*s),p=i.mallocInt32(s);if((s=l(t,u,f,p))>0){if(1===u&&n)a.init(s),h=a.sweepComplete(u,r,0,s,f,p,0,s,f,p);else{var d=i.mallocDouble(2*u*c),g=i.mallocInt32(c);(c=l(e,u,d,g))>0&&(a.init(s+c),h=1===u?a.sweepBipartite(u,r,0,s,f,p,0,c,d,g):o(u,r,n,s,f,p,c,d,g),i.free(d),i.free(g))}i.free(f),i.free(p)}return h}}}function u(t,e){n.push([t,e])}},{\"./lib/intersect\":98,\"./lib/sweep\":102,\"typedarray-pool\":545}],97:[function(t,e,r){\"use strict\";var n=\"d\",i=\"ax\",a=\"vv\",o=\"fp\",s=\"es\",l=\"rs\",c=\"re\",u=\"rb\",h=\"ri\",f=\"rp\",p=\"bs\",d=\"be\",g=\"bb\",v=\"bi\",m=\"bp\",y=\"rv\",x=\"Q\",b=[n,i,a,l,c,u,h,p,d,g,v];function _(t){var e=\"bruteForce\"+(t?\"Full\":\"Partial\"),r=[],_=b.slice();t||_.splice(3,0,o);var w=[\"function \"+e+\"(\"+_.join()+\"){\"];function k(e,o){var _=function(t,e,r){var o=\"bruteForce\"+(t?\"Red\":\"Blue\")+(e?\"Flip\":\"\")+(r?\"Full\":\"\"),_=[\"function \",o,\"(\",b.join(),\"){\",\"var \",s,\"=2*\",n,\";\"],w=\"for(var i=\"+l+\",\"+f+\"=\"+s+\"*\"+l+\";i<\"+c+\";++i,\"+f+\"+=\"+s+\"){var x0=\"+u+\"[\"+i+\"+\"+f+\"],x1=\"+u+\"[\"+i+\"+\"+f+\"+\"+n+\"],xi=\"+h+\"[i];\",k=\"for(var j=\"+p+\",\"+m+\"=\"+s+\"*\"+p+\";j<\"+d+\";++j,\"+m+\"+=\"+s+\"){var y0=\"+g+\"[\"+i+\"+\"+m+\"],\"+(r?\"y1=\"+g+\"[\"+i+\"+\"+m+\"+\"+n+\"],\":\"\")+\"yi=\"+v+\"[j];\";return t?_.push(w,x,\":\",k):_.push(k,x,\":\",w),r?_.push(\"if(y1<x0||x1<y0)continue;\"):e?_.push(\"if(y0<=x0||x1<y0)continue;\"):_.push(\"if(y0<x0||x1<y0)continue;\"),_.push(\"for(var k=\"+i+\"+1;k<\"+n+\";++k){var r0=\"+u+\"[k+\"+f+\"],r1=\"+u+\"[k+\"+n+\"+\"+f+\"],b0=\"+g+\"[k+\"+m+\"],b1=\"+g+\"[k+\"+n+\"+\"+m+\"];if(r1<b0||b1<r0)continue \"+x+\";}var \"+y+\"=\"+a+\"(\"),e?_.push(\"yi,xi\"):_.push(\"xi,yi\"),_.push(\");if(\"+y+\"!==void 0)return \"+y+\";}}}\"),{name:o,code:_.join(\"\")}}(e,o,t);r.push(_.code),w.push(\"return \"+_.name+\"(\"+b.join()+\");\")}w.push(\"if(\"+c+\"-\"+l+\">\"+d+\"-\"+p+\"){\"),t?(k(!0,!1),w.push(\"}else{\"),k(!1,!1)):(w.push(\"if(\"+o+\"){\"),k(!0,!0),w.push(\"}else{\"),k(!0,!1),w.push(\"}}else{if(\"+o+\"){\"),k(!1,!0),w.push(\"}else{\"),k(!1,!1),w.push(\"}\")),w.push(\"}}return \"+e);var T=r.join(\"\")+w.join(\"\");return new Function(T)()}r.partial=_(!1),r.full=_(!0)},{}],98:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,u,S,E,C,L){!function(t,e){var r=8*i.log2(e+1)*(t+1)|0,a=i.nextPow2(b*r);w.length<a&&(n.free(w),w=n.mallocInt32(a));var o=i.nextPow2(_*r);k<o&&(n.free(k),k=n.mallocDouble(o))}(t,a+E);var P,O=0,z=2*t;T(O++,0,0,a,0,E,r?16:0,-1/0,1/0),r||T(O++,0,0,E,0,a,1,-1/0,1/0);for(;O>0;){var I=(O-=1)*b,D=w[I],R=w[I+1],F=w[I+2],B=w[I+3],N=w[I+4],j=w[I+5],U=O*_,V=k[U],q=k[U+1],H=1&j,G=!!(16&j),Y=u,W=S,X=C,Z=L;if(H&&(Y=C,W=L,X=u,Z=S),!(2&j&&(F=v(t,D,R,F,Y,W,q),R>=F)||4&j&&(R=m(t,D,R,F,Y,W,V))>=F)){var J=F-R,K=N-B;if(G){if(t*J*(J+K)<p){if(void 0!==(P=l.scanComplete(t,D,e,R,F,Y,W,B,N,X,Z)))return P;continue}}else{if(t*Math.min(J,K)<h){if(void 0!==(P=o(t,D,e,H,R,F,Y,W,B,N,X,Z)))return P;continue}if(t*J*K<f){if(void 0!==(P=l.scanBipartite(t,D,e,H,R,F,Y,W,B,N,X,Z)))return P;continue}}var $=d(t,D,R,F,Y,W,V,q);if(R<$)if(t*($-R)<h){if(void 0!==(P=s(t,D+1,e,R,$,Y,W,B,N,X,Z)))return P}else if(D===t-2){if(void 0!==(P=H?l.sweepBipartite(t,e,B,N,X,Z,R,$,Y,W):l.sweepBipartite(t,e,R,$,Y,W,B,N,X,Z)))return P}else T(O++,D+1,R,$,B,N,H,-1/0,1/0),T(O++,D+1,B,N,R,$,1^H,-1/0,1/0);if($<F){var Q=c(t,D,B,N,X,Z),tt=X[z*Q+D],et=g(t,D,Q,N,X,Z,tt);if(et<N&&T(O++,D,$,F,et,N,(4|H)+(G?16:0),tt,q),B<Q&&T(O++,D,$,F,B,Q,(2|H)+(G?16:0),V,tt),Q+1===et){if(void 0!==(P=G?M(t,D,e,$,F,Y,W,Q,X,Z[Q]):A(t,D,e,H,$,F,Y,W,Q,X,Z[Q])))return P}else if(Q<et){var rt;if(G){if(rt=y(t,D,$,F,Y,W,tt),$<rt){var nt=g(t,D,$,rt,Y,W,tt);if(D===t-2){if($<nt&&void 0!==(P=l.sweepComplete(t,e,$,nt,Y,W,Q,et,X,Z)))return P;if(nt<rt&&void 0!==(P=l.sweepBipartite(t,e,nt,rt,Y,W,Q,et,X,Z)))return P}else $<nt&&T(O++,D+1,$,nt,Q,et,16,-1/0,1/0),nt<rt&&(T(O++,D+1,nt,rt,Q,et,0,-1/0,1/0),T(O++,D+1,Q,et,nt,rt,1,-1/0,1/0))}}else rt=H?x(t,D,$,F,Y,W,tt):y(t,D,$,F,Y,W,tt),$<rt&&(D===t-2?P=H?l.sweepBipartite(t,e,Q,et,X,Z,$,rt,Y,W):l.sweepBipartite(t,e,$,rt,Y,W,Q,et,X,Z):(T(O++,D+1,$,rt,Q,et,H,-1/0,1/0),T(O++,D+1,Q,et,$,rt,1^H,-1/0,1/0)))}}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./brute\"),o=a.partial,s=a.full,l=t(\"./sweep\"),c=t(\"./median\"),u=t(\"./partition\"),h=128,f=1<<22,p=1<<22,d=u(\"!(lo>=p0)&&!(p1>=hi)\",[\"p0\",\"p1\"]),g=u(\"lo===p0\",[\"p0\"]),v=u(\"lo<p0\",[\"p0\"]),m=u(\"hi<=p0\",[\"p0\"]),y=u(\"lo<=p0&&p0<=hi\",[\"p0\"]),x=u(\"lo<p0&&p0<=hi\",[\"p0\"]),b=6,_=2,w=n.mallocInt32(1024),k=n.mallocDouble(1024);function T(t,e,r,n,i,a,o,s,l){var c=b*t;w[c]=e,w[c+1]=r,w[c+2]=n,w[c+3]=i,w[c+4]=a,w[c+5]=o;var u=_*t;k[u]=s,k[u+1]=l}function A(t,e,r,n,i,a,o,s,l,c,u){var h=2*t,f=l*h,p=c[f+e];t:for(var d=i,g=i*h;d<a;++d,g+=h){var v=o[g+e],m=o[g+e+t];if(!(p<v||m<p)&&(!n||p!==v)){for(var y,x=s[d],b=e+1;b<t;++b){v=o[g+b],m=o[g+b+t];var _=c[f+b],w=c[f+b+t];if(m<_||w<v)continue t}if(void 0!==(y=n?r(u,x):r(x,u)))return y}}}function M(t,e,r,n,i,a,o,s,l,c){var u=2*t,h=s*u,f=l[h+e];t:for(var p=n,d=n*u;p<i;++p,d+=u){var g=o[p];if(g!==c){var v=a[d+e],m=a[d+e+t];if(!(f<v||m<f)){for(var y=e+1;y<t;++y){v=a[d+y],m=a[d+y+t];var x=l[h+y],b=l[h+y+t];if(m<x||b<v)continue t}var _=r(g,c);if(void 0!==_)return _}}}}},{\"./brute\":97,\"./median\":99,\"./partition\":100,\"./sweep\":102,\"bit-twiddle\":92,\"typedarray-pool\":545}],99:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,o,s,l){if(o<=r+1)return r;var c=r,u=o,h=o+r>>>1,f=2*t,p=h,d=s[f*h+e];for(;c<u;){if(u-c<i){a(t,e,c,u,s,l),d=s[f*h+e];break}var g=u-c,v=Math.random()*g+c|0,m=s[f*v+e],y=Math.random()*g+c|0,x=s[f*y+e],b=Math.random()*g+c|0,_=s[f*b+e];m<=x?_>=x?(p=y,d=x):m>=_?(p=v,d=m):(p=b,d=_):x>=_?(p=y,d=x):_>=m?(p=v,d=m):(p=b,d=_);for(var w=f*(u-1),k=f*p,T=0;T<f;++T,++w,++k){var A=s[w];s[w]=s[k],s[k]=A}var M=l[u-1];l[u-1]=l[p],l[p]=M,p=n(t,e,c,u-1,s,l,d);for(var w=f*(u-1),k=f*p,T=0;T<f;++T,++w,++k){var A=s[w];s[w]=s[k],s[k]=A}var M=l[u-1];if(l[u-1]=l[p],l[p]=M,h<p){for(u=p-1;c<u&&s[f*(u-1)+e]===d;)u-=1;u+=1}else{if(!(p<h))break;for(c=p+1;c<u&&s[f*c+e]===d;)c+=1}}return n(t,e,r,h,s,l,s[f*h+e])};var n=t(\"./partition\")(\"lo<p0\",[\"p0\"]),i=8;function a(t,e,r,n,i,a){for(var o=2*t,s=o*(r+1)+e,l=r+1;l<n;++l,s+=o)for(var c=i[s],u=l,h=o*(l-1);u>r&&i[h+e]>c;--u,h-=o){for(var f=h,p=h+o,d=0;d<o;++d,++f,++p){var g=i[f];i[f]=i[p],i[p]=g}var v=a[u];a[u]=a[u-1],a[u-1]=v}}},{\"./partition\":100}],100:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=\"abcdef\".split(\"\").concat(e),i=[];t.indexOf(\"lo\")>=0&&i.push(\"lo=e[k+n]\");t.indexOf(\"hi\")>=0&&i.push(\"hi=e[k+o]\");return r.push(n.replace(\"_\",i.join()).replace(\"$\",t)),Function.apply(void 0,r)};var n=\"for(var j=2*a,k=j*c,l=k,m=c,n=b,o=a+b,p=c;d>p;++p,k+=j){var _;if($)if(m===p)m+=1,l+=j;else{for(var s=0;j>s;++s){var t=e[k+s];e[k+s]=e[l],e[l++]=t}var u=f[p];f[p]=f[m],f[m++]=u}}return m\"},{}],101:[function(t,e,r){\"use strict\";e.exports=function(t,e){e<=4*n?i(0,e-1,t):function t(e,r,h){var f=(r-e+1)/6|0,p=e+f,d=r-f,g=e+r>>1,v=g-f,m=g+f,y=p,x=v,b=g,_=m,w=d,k=e+1,T=r-1,A=0;c(y,x,h)&&(A=y,y=x,x=A);c(_,w,h)&&(A=_,_=w,w=A);c(y,b,h)&&(A=y,y=b,b=A);c(x,b,h)&&(A=x,x=b,b=A);c(y,_,h)&&(A=y,y=_,_=A);c(b,_,h)&&(A=b,b=_,_=A);c(x,w,h)&&(A=x,x=w,w=A);c(x,b,h)&&(A=x,x=b,b=A);c(_,w,h)&&(A=_,_=w,w=A);var M=h[2*x];var S=h[2*x+1];var E=h[2*_];var C=h[2*_+1];var L=2*y;var P=2*b;var O=2*w;var z=2*p;var I=2*g;var D=2*d;for(var R=0;R<2;++R){var F=h[L+R],B=h[P+R],N=h[O+R];h[z+R]=F,h[I+R]=B,h[D+R]=N}o(v,e,h);o(m,r,h);for(var j=k;j<=T;++j)if(u(j,M,S,h))j!==k&&a(j,k,h),++k;else if(!u(j,E,C,h))for(;;){if(u(T,E,C,h)){u(T,M,S,h)?(s(j,k,T,h),++k,--T):(a(j,T,h),--T);break}if(--T<j)break}l(e,k-1,M,S,h);l(r,T+1,E,C,h);k-2-e<=n?i(e,k-2,h):t(e,k-2,h);r-(T+2)<=n?i(T+2,r,h):t(T+2,r,h);T-k<=n?i(k,T,h):t(k,T,h)}(0,e-1,t)};var n=32;function i(t,e,r){for(var n=2*(t+1),i=t+1;i<=e;++i){for(var a=r[n++],o=r[n++],s=i,l=n-2;s-- >t;){var c=r[l-2],u=r[l-1];if(c<a)break;if(c===a&&u<o)break;r[l]=c,r[l+1]=u,l-=2}r[l]=a,r[l+1]=o}}function a(t,e,r){e*=2;var n=r[t*=2],i=r[t+1];r[t]=r[e],r[t+1]=r[e+1],r[e]=n,r[e+1]=i}function o(t,e,r){e*=2,r[t*=2]=r[e],r[t+1]=r[e+1]}function s(t,e,r,n){e*=2,r*=2;var i=n[t*=2],a=n[t+1];n[t]=n[e],n[t+1]=n[e+1],n[e]=n[r],n[e+1]=n[r+1],n[r]=i,n[r+1]=a}function l(t,e,r,n,i){e*=2,i[t*=2]=i[e],i[e]=r,i[t+1]=i[e+1],i[e+1]=n}function c(t,e,r){e*=2;var n=r[t*=2],i=r[e];return!(n<i)&&(n!==i||r[t+1]>r[e+1])}function u(t,e,r,n){var i=n[t*=2];return i<e||i===e&&n[t+1]<r}},{}],102:[function(t,e,r){\"use strict\";e.exports={init:function(t){var e=i.nextPow2(t);s.length<e&&(n.free(s),s=n.mallocInt32(e));l.length<e&&(n.free(l),l=n.mallocInt32(e));c.length<e&&(n.free(c),c=n.mallocInt32(e));u.length<e&&(n.free(u),u=n.mallocInt32(e));h.length<e&&(n.free(h),h=n.mallocInt32(e));f.length<e&&(n.free(f),f=n.mallocInt32(e));var r=8*e;p.length<r&&(n.free(p),p=n.mallocDouble(r))},sweepBipartite:function(t,e,r,n,i,h,f,v,m,y){for(var x=0,b=2*t,_=t-1,w=b-1,k=r;k<n;++k){var T=h[k],A=b*k;p[x++]=i[A+_],p[x++]=-(T+1),p[x++]=i[A+w],p[x++]=T}for(var k=f;k<v;++k){var T=y[k]+o,M=b*k;p[x++]=m[M+_],p[x++]=-T,p[x++]=m[M+w],p[x++]=T}var S=x>>>1;a(p,S);for(var E=0,C=0,k=0;k<S;++k){var L=0|p[2*k+1];if(L>=o)d(c,u,C--,L=L-o|0);else if(L>=0)d(s,l,E--,L);else if(L<=-o){L=-L-o|0;for(var P=0;P<E;++P){var O=e(s[P],L);if(void 0!==O)return O}g(c,u,C++,L)}else{L=-L-1|0;for(var P=0;P<C;++P){var O=e(L,c[P]);if(void 0!==O)return O}g(s,l,E++,L)}}},sweepComplete:function(t,e,r,n,i,o,v,m,y,x){for(var b=0,_=2*t,w=t-1,k=_-1,T=r;T<n;++T){var A=o[T]+1<<1,M=_*T;p[b++]=i[M+w],p[b++]=-A,p[b++]=i[M+k],p[b++]=A}for(var T=v;T<m;++T){var A=x[T]+1<<1,S=_*T;p[b++]=y[S+w],p[b++]=1|-A,p[b++]=y[S+k],p[b++]=1|A}var E=b>>>1;a(p,E);for(var C=0,L=0,P=0,T=0;T<E;++T){var O=0|p[2*T+1],z=1&O;if(T<E-1&&O>>1==p[2*T+3]>>1&&(z=2,T+=1),O<0){for(var I=-(O>>1)-1,D=0;D<P;++D){var R=e(h[D],I);if(void 0!==R)return R}if(0!==z)for(var D=0;D<C;++D){var R=e(s[D],I);if(void 0!==R)return R}if(1!==z)for(var D=0;D<L;++D){var R=e(c[D],I);if(void 0!==R)return R}0===z?g(s,l,C++,I):1===z?g(c,u,L++,I):2===z&&g(h,f,P++,I)}else{var I=(O>>1)-1;0===z?d(s,l,C--,I):1===z?d(c,u,L--,I):2===z&&d(h,f,P--,I)}}},scanBipartite:function(t,e,r,n,i,c,u,h,f,v,m,y){var x=0,b=2*t,_=e,w=e+t,k=1,T=1;n?T=o:k=o;for(var A=i;A<c;++A){var M=A+k,S=b*A;p[x++]=u[S+_],p[x++]=-M,p[x++]=u[S+w],p[x++]=M}for(var A=f;A<v;++A){var M=A+T,E=b*A;p[x++]=m[E+_],p[x++]=-M}var C=x>>>1;a(p,C);for(var L=0,A=0;A<C;++A){var P=0|p[2*A+1];if(P<0){var M=-P,O=!1;if(M>=o?(O=!n,M-=o):(O=!!n,M-=1),O)g(s,l,L++,M);else{var z=y[M],I=b*M,D=m[I+e+1],R=m[I+e+1+t];t:for(var F=0;F<L;++F){var B=s[F],N=b*B;if(!(R<u[N+e+1]||u[N+e+1+t]<D)){for(var j=e+2;j<t;++j)if(m[I+j+t]<u[N+j]||u[N+j+t]<m[I+j])continue t;var U,V=h[B];if(void 0!==(U=n?r(z,V):r(V,z)))return U}}}}else d(s,l,L--,P-k)}},scanComplete:function(t,e,r,n,i,l,c,u,h,f,d){for(var g=0,v=2*t,m=e,y=e+t,x=n;x<i;++x){var b=x+o,_=v*x;p[g++]=l[_+m],p[g++]=-b,p[g++]=l[_+y],p[g++]=b}for(var x=u;x<h;++x){var b=x+1,w=v*x;p[g++]=f[w+m],p[g++]=-b}var k=g>>>1;a(p,k);for(var T=0,x=0;x<k;++x){var A=0|p[2*x+1];if(A<0){var b=-A;if(b>=o)s[T++]=b-o;else{var M=d[b-=1],S=v*b,E=f[S+e+1],C=f[S+e+1+t];t:for(var L=0;L<T;++L){var P=s[L],O=c[P];if(O===M)break;var z=v*P;if(!(C<l[z+e+1]||l[z+e+1+t]<E)){for(var I=e+2;I<t;++I)if(f[S+I+t]<l[z+I]||l[z+I+t]<f[S+I])continue t;var D=r(O,M);if(void 0!==D)return D}}}}else{for(var b=A-o,L=T-1;L>=0;--L)if(s[L]===b){for(var I=L+1;I<T;++I)s[I-1]=s[I];break}--T}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./sort\"),o=1<<28,s=n.mallocInt32(1024),l=n.mallocInt32(1024),c=n.mallocInt32(1024),u=n.mallocInt32(1024),h=n.mallocInt32(1024),f=n.mallocInt32(1024),p=n.mallocDouble(8192);function d(t,e,r,n){var i=e[n],a=t[r-1];t[i]=a,e[a]=i}function g(t,e,r,n){t[r]=n,e[n]=r}},{\"./sort\":101,\"bit-twiddle\":92,\"typedarray-pool\":545}],103:[function(t,e,r){},{}],104:[function(t,e,r){var n=Object.create||function(t){var e=function(){};return e.prototype=t,new e},i=Object.keys||function(t){var e=[];for(var r in t)Object.prototype.hasOwnProperty.call(t,r)&&e.push(r);return r},a=Function.prototype.bind||function(t){var e=this;return function(){return e.apply(t,arguments)}};function o(){this._events&&Object.prototype.hasOwnProperty.call(this,\"_events\")||(this._events=n(null),this._eventsCount=0),this._maxListeners=this._maxListeners||void 0}e.exports=o,o.EventEmitter=o,o.prototype._events=void 0,o.prototype._maxListeners=void 0;var s,l=10;try{var c={};Object.defineProperty&&Object.defineProperty(c,\"x\",{value:0}),s=0===c.x}catch(t){s=!1}function u(t){return void 0===t._maxListeners?o.defaultMaxListeners:t._maxListeners}function h(t,e,r,i){var a,o,s;if(\"function\"!=typeof r)throw new TypeError('\"listener\" argument must be a function');if((o=t._events)?(o.newListener&&(t.emit(\"newListener\",e,r.listener?r.listener:r),o=t._events),s=o[e]):(o=t._events=n(null),t._eventsCount=0),s){if(\"function\"==typeof s?s=o[e]=i?[r,s]:[s,r]:i?s.unshift(r):s.push(r),!s.warned&&(a=u(t))&&a>0&&s.length>a){s.warned=!0;var l=new Error(\"Possible EventEmitter memory leak detected. \"+s.length+' \"'+String(e)+'\" listeners added. Use emitter.setMaxListeners() to increase limit.');l.name=\"MaxListenersExceededWarning\",l.emitter=t,l.type=e,l.count=s.length,\"object\"==typeof console&&console.warn&&console.warn(\"%s: %s\",l.name,l.message)}}else s=o[e]=r,++t._eventsCount;return t}function f(){if(!this.fired)switch(this.target.removeListener(this.type,this.wrapFn),this.fired=!0,arguments.length){case 0:return this.listener.call(this.target);case 1:return this.listener.call(this.target,arguments[0]);case 2:return this.listener.call(this.target,arguments[0],arguments[1]);case 3:return this.listener.call(this.target,arguments[0],arguments[1],arguments[2]);default:for(var t=new Array(arguments.length),e=0;e<t.length;++e)t[e]=arguments[e];this.listener.apply(this.target,t)}}function p(t,e,r){var n={fired:!1,wrapFn:void 0,target:t,type:e,listener:r},i=a.call(f,n);return i.listener=r,n.wrapFn=i,i}function d(t,e,r){var n=t._events;if(!n)return[];var i=n[e];return i?\"function\"==typeof i?r?[i.listener||i]:[i]:r?function(t){for(var e=new Array(t.length),r=0;r<e.length;++r)e[r]=t[r].listener||t[r];return e}(i):v(i,i.length):[]}function g(t){var e=this._events;if(e){var r=e[t];if(\"function\"==typeof r)return 1;if(r)return r.length}return 0}function v(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t[n];return r}s?Object.defineProperty(o,\"defaultMaxListeners\",{enumerable:!0,get:function(){return l},set:function(t){if(\"number\"!=typeof t||t<0||t!=t)throw new TypeError('\"defaultMaxListeners\" must be a positive number');l=t}}):o.defaultMaxListeners=l,o.prototype.setMaxListeners=function(t){if(\"number\"!=typeof t||t<0||isNaN(t))throw new TypeError('\"n\" argument must be a positive number');return this._maxListeners=t,this},o.prototype.getMaxListeners=function(){return u(this)},o.prototype.emit=function(t){var e,r,n,i,a,o,s=\"error\"===t;if(o=this._events)s=s&&null==o.error;else if(!s)return!1;if(s){if(arguments.length>1&&(e=arguments[1]),e instanceof Error)throw e;var l=new Error('Unhandled \"error\" event. ('+e+\")\");throw l.context=e,l}if(!(r=o[t]))return!1;var c=\"function\"==typeof r;switch(n=arguments.length){case 1:!function(t,e,r){if(e)t.call(r);else for(var n=t.length,i=v(t,n),a=0;a<n;++a)i[a].call(r)}(r,c,this);break;case 2:!function(t,e,r,n){if(e)t.call(r,n);else for(var i=t.length,a=v(t,i),o=0;o<i;++o)a[o].call(r,n)}(r,c,this,arguments[1]);break;case 3:!function(t,e,r,n,i){if(e)t.call(r,n,i);else for(var a=t.length,o=v(t,a),s=0;s<a;++s)o[s].call(r,n,i)}(r,c,this,arguments[1],arguments[2]);break;case 4:!function(t,e,r,n,i,a){if(e)t.call(r,n,i,a);else for(var o=t.length,s=v(t,o),l=0;l<o;++l)s[l].call(r,n,i,a)}(r,c,this,arguments[1],arguments[2],arguments[3]);break;default:for(i=new Array(n-1),a=1;a<n;a++)i[a-1]=arguments[a];!function(t,e,r,n){if(e)t.apply(r,n);else for(var i=t.length,a=v(t,i),o=0;o<i;++o)a[o].apply(r,n)}(r,c,this,i)}return!0},o.prototype.addListener=function(t,e){return h(this,t,e,!1)},o.prototype.on=o.prototype.addListener,o.prototype.prependListener=function(t,e){return h(this,t,e,!0)},o.prototype.once=function(t,e){if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');return this.on(t,p(this,t,e)),this},o.prototype.prependOnceListener=function(t,e){if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');return this.prependListener(t,p(this,t,e)),this},o.prototype.removeListener=function(t,e){var r,i,a,o,s;if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');if(!(i=this._events))return this;if(!(r=i[t]))return this;if(r===e||r.listener===e)0==--this._eventsCount?this._events=n(null):(delete i[t],i.removeListener&&this.emit(\"removeListener\",t,r.listener||e));else if(\"function\"!=typeof r){for(a=-1,o=r.length-1;o>=0;o--)if(r[o]===e||r[o].listener===e){s=r[o].listener,a=o;break}if(a<0)return this;0===a?r.shift():function(t,e){for(var r=e,n=r+1,i=t.length;n<i;r+=1,n+=1)t[r]=t[n];t.pop()}(r,a),1===r.length&&(i[t]=r[0]),i.removeListener&&this.emit(\"removeListener\",t,s||e)}return this},o.prototype.removeAllListeners=function(t){var e,r,a;if(!(r=this._events))return this;if(!r.removeListener)return 0===arguments.length?(this._events=n(null),this._eventsCount=0):r[t]&&(0==--this._eventsCount?this._events=n(null):delete r[t]),this;if(0===arguments.length){var o,s=i(r);for(a=0;a<s.length;++a)\"removeListener\"!==(o=s[a])&&this.removeAllListeners(o);return this.removeAllListeners(\"removeListener\"),this._events=n(null),this._eventsCount=0,this}if(\"function\"==typeof(e=r[t]))this.removeListener(t,e);else if(e)for(a=e.length-1;a>=0;a--)this.removeListener(t,e[a]);return this},o.prototype.listeners=function(t){return d(this,t,!0)},o.prototype.rawListeners=function(t){return d(this,t,!1)},o.listenerCount=function(t,e){return\"function\"==typeof t.listenerCount?t.listenerCount(e):g.call(t,e)},o.prototype.listenerCount=g,o.prototype.eventNames=function(){return this._eventsCount>0?Reflect.ownKeys(this._events):[]}},{}],105:[function(t,e,r){(function(e){\"use strict\";var n=t(\"base64-js\"),i=t(\"ieee754\");r.Buffer=e,r.SlowBuffer=function(t){+t!=t&&(t=0);return e.alloc(+t)},r.INSPECT_MAX_BYTES=50;var a=2147483647;function o(t){if(t>a)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"');var r=new Uint8Array(t);return r.__proto__=e.prototype,r}function e(t,e,r){if(\"number\"==typeof t){if(\"string\"==typeof e)throw new TypeError('The \"string\" argument must be of type string. Received type number');return c(t)}return s(t,e,r)}function s(t,r,n){if(\"string\"==typeof t)return function(t,r){\"string\"==typeof r&&\"\"!==r||(r=\"utf8\");if(!e.isEncoding(r))throw new TypeError(\"Unknown encoding: \"+r);var n=0|f(t,r),i=o(n),a=i.write(t,r);a!==n&&(i=i.slice(0,a));return i}(t,r);if(ArrayBuffer.isView(t))return u(t);if(null==t)throw TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t);if(N(t,ArrayBuffer)||t&&N(t.buffer,ArrayBuffer))return function(t,r,n){if(r<0||t.byteLength<r)throw new RangeError('\"offset\" is outside of buffer bounds');if(t.byteLength<r+(n||0))throw new RangeError('\"length\" is outside of buffer bounds');var i;i=void 0===r&&void 0===n?new Uint8Array(t):void 0===n?new Uint8Array(t,r):new Uint8Array(t,r,n);return i.__proto__=e.prototype,i}(t,r,n);if(\"number\"==typeof t)throw new TypeError('The \"value\" argument must not be of type number. Received type number');var i=t.valueOf&&t.valueOf();if(null!=i&&i!==t)return e.from(i,r,n);var a=function(t){if(e.isBuffer(t)){var r=0|h(t.length),n=o(r);return 0===n.length?n:(t.copy(n,0,0,r),n)}if(void 0!==t.length)return\"number\"!=typeof t.length||j(t.length)?o(0):u(t);if(\"Buffer\"===t.type&&Array.isArray(t.data))return u(t.data)}(t);if(a)return a;if(\"undefined\"!=typeof Symbol&&null!=Symbol.toPrimitive&&\"function\"==typeof t[Symbol.toPrimitive])return e.from(t[Symbol.toPrimitive](\"string\"),r,n);throw new TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t)}function l(t){if(\"number\"!=typeof t)throw new TypeError('\"size\" argument must be of type number');if(t<0)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"')}function c(t){return l(t),o(t<0?0:0|h(t))}function u(t){for(var e=t.length<0?0:0|h(t.length),r=o(e),n=0;n<e;n+=1)r[n]=255&t[n];return r}function h(t){if(t>=a)throw new RangeError(\"Attempt to allocate Buffer larger than maximum size: 0x\"+a.toString(16)+\" bytes\");return 0|t}function f(t,r){if(e.isBuffer(t))return t.length;if(ArrayBuffer.isView(t)||N(t,ArrayBuffer))return t.byteLength;if(\"string\"!=typeof t)throw new TypeError('The \"string\" argument must be one of type string, Buffer, or ArrayBuffer. Received type '+typeof t);var n=t.length,i=arguments.length>2&&!0===arguments[2];if(!i&&0===n)return 0;for(var a=!1;;)switch(r){case\"ascii\":case\"latin1\":case\"binary\":return n;case\"utf8\":case\"utf-8\":return R(t).length;case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return 2*n;case\"hex\":return n>>>1;case\"base64\":return F(t).length;default:if(a)return i?-1:R(t).length;r=(\"\"+r).toLowerCase(),a=!0}}function p(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function d(t,r,n,i,a){if(0===t.length)return-1;if(\"string\"==typeof n?(i=n,n=0):n>2147483647?n=2147483647:n<-2147483648&&(n=-2147483648),j(n=+n)&&(n=a?0:t.length-1),n<0&&(n=t.length+n),n>=t.length){if(a)return-1;n=t.length-1}else if(n<0){if(!a)return-1;n=0}if(\"string\"==typeof r&&(r=e.from(r,i)),e.isBuffer(r))return 0===r.length?-1:g(t,r,n,i,a);if(\"number\"==typeof r)return r&=255,\"function\"==typeof Uint8Array.prototype.indexOf?a?Uint8Array.prototype.indexOf.call(t,r,n):Uint8Array.prototype.lastIndexOf.call(t,r,n):g(t,[r],n,i,a);throw new TypeError(\"val must be string, number or Buffer\")}function g(t,e,r,n,i){var a,o=1,s=t.length,l=e.length;if(void 0!==n&&(\"ucs2\"===(n=String(n).toLowerCase())||\"ucs-2\"===n||\"utf16le\"===n||\"utf-16le\"===n)){if(t.length<2||e.length<2)return-1;o=2,s/=2,l/=2,r/=2}function c(t,e){return 1===o?t[e]:t.readUInt16BE(e*o)}if(i){var u=-1;for(a=r;a<s;a++)if(c(t,a)===c(e,-1===u?0:a-u)){if(-1===u&&(u=a),a-u+1===l)return u*o}else-1!==u&&(a-=a-u),u=-1}else for(r+l>s&&(r=s-l),a=r;a>=0;a--){for(var h=!0,f=0;f<l;f++)if(c(t,a+f)!==c(e,f)){h=!1;break}if(h)return a}return-1}function v(t,e,r,n){r=Number(r)||0;var i=t.length-r;n?(n=Number(n))>i&&(n=i):n=i;var a=e.length;n>a/2&&(n=a/2);for(var o=0;o<n;++o){var s=parseInt(e.substr(2*o,2),16);if(j(s))return o;t[r+o]=s}return o}function m(t,e,r,n){return B(R(e,t.length-r),t,r,n)}function y(t,e,r,n){return B(function(t){for(var e=[],r=0;r<t.length;++r)e.push(255&t.charCodeAt(r));return e}(e),t,r,n)}function x(t,e,r,n){return y(t,e,r,n)}function b(t,e,r,n){return B(F(e),t,r,n)}function _(t,e,r,n){return B(function(t,e){for(var r,n,i,a=[],o=0;o<t.length&&!((e-=2)<0);++o)r=t.charCodeAt(o),n=r>>8,i=r%256,a.push(i),a.push(n);return a}(e,t.length-r),t,r,n)}function w(t,e,r){return 0===e&&r===t.length?n.fromByteArray(t):n.fromByteArray(t.slice(e,r))}function k(t,e,r){r=Math.min(t.length,r);for(var n=[],i=e;i<r;){var a,o,s,l,c=t[i],u=null,h=c>239?4:c>223?3:c>191?2:1;if(i+h<=r)switch(h){case 1:c<128&&(u=c);break;case 2:128==(192&(a=t[i+1]))&&(l=(31&c)<<6|63&a)>127&&(u=l);break;case 3:a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&(l=(15&c)<<12|(63&a)<<6|63&o)>2047&&(l<55296||l>57343)&&(u=l);break;case 4:a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&(l=(15&c)<<18|(63&a)<<12|(63&o)<<6|63&s)>65535&&l<1114112&&(u=l)}null===u?(u=65533,h=1):u>65535&&(u-=65536,n.push(u>>>10&1023|55296),u=56320|1023&u),n.push(u),i+=h}return function(t){var e=t.length;if(e<=T)return String.fromCharCode.apply(String,t);var r=\"\",n=0;for(;n<e;)r+=String.fromCharCode.apply(String,t.slice(n,n+=T));return r}(n)}r.kMaxLength=a,e.TYPED_ARRAY_SUPPORT=function(){try{var t=new Uint8Array(1);return t.__proto__={__proto__:Uint8Array.prototype,foo:function(){return 42}},42===t.foo()}catch(t){return!1}}(),e.TYPED_ARRAY_SUPPORT||\"undefined\"==typeof console||\"function\"!=typeof console.error||console.error(\"This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support.\"),Object.defineProperty(e.prototype,\"parent\",{enumerable:!0,get:function(){if(e.isBuffer(this))return this.buffer}}),Object.defineProperty(e.prototype,\"offset\",{enumerable:!0,get:function(){if(e.isBuffer(this))return this.byteOffset}}),\"undefined\"!=typeof Symbol&&null!=Symbol.species&&e[Symbol.species]===e&&Object.defineProperty(e,Symbol.species,{value:null,configurable:!0,enumerable:!1,writable:!1}),e.poolSize=8192,e.from=function(t,e,r){return s(t,e,r)},e.prototype.__proto__=Uint8Array.prototype,e.__proto__=Uint8Array,e.alloc=function(t,e,r){return function(t,e,r){return l(t),t<=0?o(t):void 0!==e?\"string\"==typeof r?o(t).fill(e,r):o(t).fill(e):o(t)}(t,e,r)},e.allocUnsafe=function(t){return c(t)},e.allocUnsafeSlow=function(t){return c(t)},e.isBuffer=function(t){return null!=t&&!0===t._isBuffer&&t!==e.prototype},e.compare=function(t,r){if(N(t,Uint8Array)&&(t=e.from(t,t.offset,t.byteLength)),N(r,Uint8Array)&&(r=e.from(r,r.offset,r.byteLength)),!e.isBuffer(t)||!e.isBuffer(r))throw new TypeError('The \"buf1\", \"buf2\" arguments must be one of type Buffer or Uint8Array');if(t===r)return 0;for(var n=t.length,i=r.length,a=0,o=Math.min(n,i);a<o;++a)if(t[a]!==r[a]){n=t[a],i=r[a];break}return n<i?-1:i<n?1:0},e.isEncoding=function(t){switch(String(t).toLowerCase()){case\"hex\":case\"utf8\":case\"utf-8\":case\"ascii\":case\"latin1\":case\"binary\":case\"base64\":case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return!0;default:return!1}},e.concat=function(t,r){if(!Array.isArray(t))throw new TypeError('\"list\" argument must be an Array of Buffers');if(0===t.length)return e.alloc(0);var n;if(void 0===r)for(r=0,n=0;n<t.length;++n)r+=t[n].length;var i=e.allocUnsafe(r),a=0;for(n=0;n<t.length;++n){var o=t[n];if(N(o,Uint8Array)&&(o=e.from(o)),!e.isBuffer(o))throw new TypeError('\"list\" argument must be an Array of Buffers');o.copy(i,a),a+=o.length}return i},e.byteLength=f,e.prototype._isBuffer=!0,e.prototype.swap16=function(){var t=this.length;if(t%2!=0)throw new RangeError(\"Buffer size must be a multiple of 16-bits\");for(var e=0;e<t;e+=2)p(this,e,e+1);return this},e.prototype.swap32=function(){var t=this.length;if(t%4!=0)throw new RangeError(\"Buffer size must be a multiple of 32-bits\");for(var e=0;e<t;e+=4)p(this,e,e+3),p(this,e+1,e+2);return this},e.prototype.swap64=function(){var t=this.length;if(t%8!=0)throw new RangeError(\"Buffer size must be a multiple of 64-bits\");for(var e=0;e<t;e+=8)p(this,e,e+7),p(this,e+1,e+6),p(this,e+2,e+5),p(this,e+3,e+4);return this},e.prototype.toString=function(){var t=this.length;return 0===t?\"\":0===arguments.length?k(this,0,t):function(t,e,r){var n=!1;if((void 0===e||e<0)&&(e=0),e>this.length)return\"\";if((void 0===r||r>this.length)&&(r=this.length),r<=0)return\"\";if((r>>>=0)<=(e>>>=0))return\"\";for(t||(t=\"utf8\");;)switch(t){case\"hex\":return S(this,e,r);case\"utf8\":case\"utf-8\":return k(this,e,r);case\"ascii\":return A(this,e,r);case\"latin1\":case\"binary\":return M(this,e,r);case\"base64\":return w(this,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return E(this,e,r);default:if(n)throw new TypeError(\"Unknown encoding: \"+t);t=(t+\"\").toLowerCase(),n=!0}}.apply(this,arguments)},e.prototype.toLocaleString=e.prototype.toString,e.prototype.equals=function(t){if(!e.isBuffer(t))throw new TypeError(\"Argument must be a Buffer\");return this===t||0===e.compare(this,t)},e.prototype.inspect=function(){var t=\"\",e=r.INSPECT_MAX_BYTES;return t=this.toString(\"hex\",0,e).replace(/(.{2})/g,\"$1 \").trim(),this.length>e&&(t+=\" ... \"),\"<Buffer \"+t+\">\"},e.prototype.compare=function(t,r,n,i,a){if(N(t,Uint8Array)&&(t=e.from(t,t.offset,t.byteLength)),!e.isBuffer(t))throw new TypeError('The \"target\" argument must be one of type Buffer or Uint8Array. Received type '+typeof t);if(void 0===r&&(r=0),void 0===n&&(n=t?t.length:0),void 0===i&&(i=0),void 0===a&&(a=this.length),r<0||n>t.length||i<0||a>this.length)throw new RangeError(\"out of range index\");if(i>=a&&r>=n)return 0;if(i>=a)return-1;if(r>=n)return 1;if(this===t)return 0;for(var o=(a>>>=0)-(i>>>=0),s=(n>>>=0)-(r>>>=0),l=Math.min(o,s),c=this.slice(i,a),u=t.slice(r,n),h=0;h<l;++h)if(c[h]!==u[h]){o=c[h],s=u[h];break}return o<s?-1:s<o?1:0},e.prototype.includes=function(t,e,r){return-1!==this.indexOf(t,e,r)},e.prototype.indexOf=function(t,e,r){return d(this,t,e,r,!0)},e.prototype.lastIndexOf=function(t,e,r){return d(this,t,e,r,!1)},e.prototype.write=function(t,e,r,n){if(void 0===e)n=\"utf8\",r=this.length,e=0;else if(void 0===r&&\"string\"==typeof e)n=e,r=this.length,e=0;else{if(!isFinite(e))throw new Error(\"Buffer.write(string, encoding, offset[, length]) is no longer supported\");e>>>=0,isFinite(r)?(r>>>=0,void 0===n&&(n=\"utf8\")):(n=r,r=void 0)}var i=this.length-e;if((void 0===r||r>i)&&(r=i),t.length>0&&(r<0||e<0)||e>this.length)throw new RangeError(\"Attempt to write outside buffer bounds\");n||(n=\"utf8\");for(var a=!1;;)switch(n){case\"hex\":return v(this,t,e,r);case\"utf8\":case\"utf-8\":return m(this,t,e,r);case\"ascii\":return y(this,t,e,r);case\"latin1\":case\"binary\":return x(this,t,e,r);case\"base64\":return b(this,t,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return _(this,t,e,r);default:if(a)throw new TypeError(\"Unknown encoding: \"+n);n=(\"\"+n).toLowerCase(),a=!0}},e.prototype.toJSON=function(){return{type:\"Buffer\",data:Array.prototype.slice.call(this._arr||this,0)}};var T=4096;function A(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(127&t[i]);return n}function M(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(t[i]);return n}function S(t,e,r){var n=t.length;(!e||e<0)&&(e=0),(!r||r<0||r>n)&&(r=n);for(var i=\"\",a=e;a<r;++a)i+=D(t[a]);return i}function E(t,e,r){for(var n=t.slice(e,r),i=\"\",a=0;a<n.length;a+=2)i+=String.fromCharCode(n[a]+256*n[a+1]);return i}function C(t,e,r){if(t%1!=0||t<0)throw new RangeError(\"offset is not uint\");if(t+e>r)throw new RangeError(\"Trying to access beyond buffer length\")}function L(t,r,n,i,a,o){if(!e.isBuffer(t))throw new TypeError('\"buffer\" argument must be a Buffer instance');if(r>a||r<o)throw new RangeError('\"value\" argument is out of bounds');if(n+i>t.length)throw new RangeError(\"Index out of range\")}function P(t,e,r,n,i,a){if(r+n>t.length)throw new RangeError(\"Index out of range\");if(r<0)throw new RangeError(\"Index out of range\")}function O(t,e,r,n,a){return e=+e,r>>>=0,a||P(t,0,r,4),i.write(t,e,r,n,23,4),r+4}function z(t,e,r,n,a){return e=+e,r>>>=0,a||P(t,0,r,8),i.write(t,e,r,n,52,8),r+8}e.prototype.slice=function(t,r){var n=this.length;(t=~~t)<0?(t+=n)<0&&(t=0):t>n&&(t=n),(r=void 0===r?n:~~r)<0?(r+=n)<0&&(r=0):r>n&&(r=n),r<t&&(r=t);var i=this.subarray(t,r);return i.__proto__=e.prototype,i},e.prototype.readUIntLE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n},e.prototype.readUIntBE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t+--e],i=1;e>0&&(i*=256);)n+=this[t+--e]*i;return n},e.prototype.readUInt8=function(t,e){return t>>>=0,e||C(t,1,this.length),this[t]},e.prototype.readUInt16LE=function(t,e){return t>>>=0,e||C(t,2,this.length),this[t]|this[t+1]<<8},e.prototype.readUInt16BE=function(t,e){return t>>>=0,e||C(t,2,this.length),this[t]<<8|this[t+1]},e.prototype.readUInt32LE=function(t,e){return t>>>=0,e||C(t,4,this.length),(this[t]|this[t+1]<<8|this[t+2]<<16)+16777216*this[t+3]},e.prototype.readUInt32BE=function(t,e){return t>>>=0,e||C(t,4,this.length),16777216*this[t]+(this[t+1]<<16|this[t+2]<<8|this[t+3])},e.prototype.readIntLE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n>=(i*=128)&&(n-=Math.pow(2,8*e)),n},e.prototype.readIntBE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=e,i=1,a=this[t+--n];n>0&&(i*=256);)a+=this[t+--n]*i;return a>=(i*=128)&&(a-=Math.pow(2,8*e)),a},e.prototype.readInt8=function(t,e){return t>>>=0,e||C(t,1,this.length),128&this[t]?-1*(255-this[t]+1):this[t]},e.prototype.readInt16LE=function(t,e){t>>>=0,e||C(t,2,this.length);var r=this[t]|this[t+1]<<8;return 32768&r?4294901760|r:r},e.prototype.readInt16BE=function(t,e){t>>>=0,e||C(t,2,this.length);var r=this[t+1]|this[t]<<8;return 32768&r?4294901760|r:r},e.prototype.readInt32LE=function(t,e){return t>>>=0,e||C(t,4,this.length),this[t]|this[t+1]<<8|this[t+2]<<16|this[t+3]<<24},e.prototype.readInt32BE=function(t,e){return t>>>=0,e||C(t,4,this.length),this[t]<<24|this[t+1]<<16|this[t+2]<<8|this[t+3]},e.prototype.readFloatLE=function(t,e){return t>>>=0,e||C(t,4,this.length),i.read(this,t,!0,23,4)},e.prototype.readFloatBE=function(t,e){return t>>>=0,e||C(t,4,this.length),i.read(this,t,!1,23,4)},e.prototype.readDoubleLE=function(t,e){return t>>>=0,e||C(t,8,this.length),i.read(this,t,!0,52,8)},e.prototype.readDoubleBE=function(t,e){return t>>>=0,e||C(t,8,this.length),i.read(this,t,!1,52,8)},e.prototype.writeUIntLE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||L(this,t,e,r,Math.pow(2,8*r)-1,0);var i=1,a=0;for(this[e]=255&t;++a<r&&(i*=256);)this[e+a]=t/i&255;return e+r},e.prototype.writeUIntBE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||L(this,t,e,r,Math.pow(2,8*r)-1,0);var i=r-1,a=1;for(this[e+i]=255&t;--i>=0&&(a*=256);)this[e+i]=t/a&255;return e+r},e.prototype.writeUInt8=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,1,255,0),this[e]=255&t,e+1},e.prototype.writeUInt16LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,65535,0),this[e]=255&t,this[e+1]=t>>>8,e+2},e.prototype.writeUInt16BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,65535,0),this[e]=t>>>8,this[e+1]=255&t,e+2},e.prototype.writeUInt32LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,4294967295,0),this[e+3]=t>>>24,this[e+2]=t>>>16,this[e+1]=t>>>8,this[e]=255&t,e+4},e.prototype.writeUInt32BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,4294967295,0),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},e.prototype.writeIntLE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);L(this,t,e,r,i-1,-i)}var a=0,o=1,s=0;for(this[e]=255&t;++a<r&&(o*=256);)t<0&&0===s&&0!==this[e+a-1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},e.prototype.writeIntBE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);L(this,t,e,r,i-1,-i)}var a=r-1,o=1,s=0;for(this[e+a]=255&t;--a>=0&&(o*=256);)t<0&&0===s&&0!==this[e+a+1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},e.prototype.writeInt8=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,1,127,-128),t<0&&(t=255+t+1),this[e]=255&t,e+1},e.prototype.writeInt16LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,32767,-32768),this[e]=255&t,this[e+1]=t>>>8,e+2},e.prototype.writeInt16BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,32767,-32768),this[e]=t>>>8,this[e+1]=255&t,e+2},e.prototype.writeInt32LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,2147483647,-2147483648),this[e]=255&t,this[e+1]=t>>>8,this[e+2]=t>>>16,this[e+3]=t>>>24,e+4},e.prototype.writeInt32BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,2147483647,-2147483648),t<0&&(t=4294967295+t+1),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},e.prototype.writeFloatLE=function(t,e,r){return O(this,t,e,!0,r)},e.prototype.writeFloatBE=function(t,e,r){return O(this,t,e,!1,r)},e.prototype.writeDoubleLE=function(t,e,r){return z(this,t,e,!0,r)},e.prototype.writeDoubleBE=function(t,e,r){return z(this,t,e,!1,r)},e.prototype.copy=function(t,r,n,i){if(!e.isBuffer(t))throw new TypeError(\"argument should be a Buffer\");if(n||(n=0),i||0===i||(i=this.length),r>=t.length&&(r=t.length),r||(r=0),i>0&&i<n&&(i=n),i===n)return 0;if(0===t.length||0===this.length)return 0;if(r<0)throw new RangeError(\"targetStart out of bounds\");if(n<0||n>=this.length)throw new RangeError(\"Index out of range\");if(i<0)throw new RangeError(\"sourceEnd out of bounds\");i>this.length&&(i=this.length),t.length-r<i-n&&(i=t.length-r+n);var a=i-n;if(this===t&&\"function\"==typeof Uint8Array.prototype.copyWithin)this.copyWithin(r,n,i);else if(this===t&&n<r&&r<i)for(var o=a-1;o>=0;--o)t[o+r]=this[o+n];else Uint8Array.prototype.set.call(t,this.subarray(n,i),r);return a},e.prototype.fill=function(t,r,n,i){if(\"string\"==typeof t){if(\"string\"==typeof r?(i=r,r=0,n=this.length):\"string\"==typeof n&&(i=n,n=this.length),void 0!==i&&\"string\"!=typeof i)throw new TypeError(\"encoding must be a string\");if(\"string\"==typeof i&&!e.isEncoding(i))throw new TypeError(\"Unknown encoding: \"+i);if(1===t.length){var a=t.charCodeAt(0);(\"utf8\"===i&&a<128||\"latin1\"===i)&&(t=a)}}else\"number\"==typeof t&&(t&=255);if(r<0||this.length<r||this.length<n)throw new RangeError(\"Out of range index\");if(n<=r)return this;var o;if(r>>>=0,n=void 0===n?this.length:n>>>0,t||(t=0),\"number\"==typeof t)for(o=r;o<n;++o)this[o]=t;else{var s=e.isBuffer(t)?t:e.from(t,i),l=s.length;if(0===l)throw new TypeError('The value \"'+t+'\" is invalid for argument \"value\"');for(o=0;o<n-r;++o)this[o+r]=s[o%l]}return this};var I=/[^+\\/0-9A-Za-z-_]/g;function D(t){return t<16?\"0\"+t.toString(16):t.toString(16)}function R(t,e){var r;e=e||1/0;for(var n=t.length,i=null,a=[],o=0;o<n;++o){if((r=t.charCodeAt(o))>55295&&r<57344){if(!i){if(r>56319){(e-=3)>-1&&a.push(239,191,189);continue}if(o+1===n){(e-=3)>-1&&a.push(239,191,189);continue}i=r;continue}if(r<56320){(e-=3)>-1&&a.push(239,191,189),i=r;continue}r=65536+(i-55296<<10|r-56320)}else i&&(e-=3)>-1&&a.push(239,191,189);if(i=null,r<128){if((e-=1)<0)break;a.push(r)}else if(r<2048){if((e-=2)<0)break;a.push(r>>6|192,63&r|128)}else if(r<65536){if((e-=3)<0)break;a.push(r>>12|224,r>>6&63|128,63&r|128)}else{if(!(r<1114112))throw new Error(\"Invalid code point\");if((e-=4)<0)break;a.push(r>>18|240,r>>12&63|128,r>>6&63|128,63&r|128)}}return a}function F(t){return n.toByteArray(function(t){if((t=(t=t.split(\"=\")[0]).trim().replace(I,\"\")).length<2)return\"\";for(;t.length%4!=0;)t+=\"=\";return t}(t))}function B(t,e,r,n){for(var i=0;i<n&&!(i+r>=e.length||i>=t.length);++i)e[i+r]=t[i];return i}function N(t,e){return t instanceof e||null!=t&&null!=t.constructor&&null!=t.constructor.name&&t.constructor.name===e.name}function j(t){return t!=t}}).call(this,t(\"buffer\").Buffer)},{\"base64-js\":74,buffer:105,ieee754:412}],106:[function(t,e,r){\"use strict\";var n=t(\"./lib/monotone\"),i=t(\"./lib/triangulation\"),a=t(\"./lib/delaunay\"),o=t(\"./lib/filter\");function s(t){return[Math.min(t[0],t[1]),Math.max(t[0],t[1])]}function l(t,e){return t[0]-e[0]||t[1]-e[1]}function c(t,e,r){return e in t?t[e]:r}e.exports=function(t,e,r){Array.isArray(e)?(r=r||{},e=e||[]):(r=e||{},e=[]);var u=!!c(r,\"delaunay\",!0),h=!!c(r,\"interior\",!0),f=!!c(r,\"exterior\",!0),p=!!c(r,\"infinity\",!1);if(!h&&!f||0===t.length)return[];var d=n(t,e);if(u||h!==f||p){for(var g=i(t.length,function(t){return t.map(s).sort(l)}(e)),v=0;v<d.length;++v){var m=d[v];g.addTriangle(m[0],m[1],m[2])}return u&&a(t,g),f?h?p?o(g,0,p):g.cells():o(g,1,p):o(g,-1)}return d}},{\"./lib/delaunay\":107,\"./lib/filter\":108,\"./lib/monotone\":109,\"./lib/triangulation\":110}],107:[function(t,e,r){\"use strict\";var n=t(\"robust-in-sphere\")[4];t(\"binary-search-bounds\");function i(t,e,r,i,a,o){var s=e.opposite(i,a);if(!(s<0)){if(a<i){var l=i;i=a,a=l,l=o,o=s,s=l}e.isConstraint(i,a)||n(t[i],t[a],t[o],t[s])<0&&r.push(i,a)}}e.exports=function(t,e){for(var r=[],a=t.length,o=e.stars,s=0;s<a;++s)for(var l=o[s],c=1;c<l.length;c+=2){var u=l[c];if(!(u<s)&&!e.isConstraint(s,u)){for(var h=l[c-1],f=-1,p=1;p<l.length;p+=2)if(l[p-1]===u){f=l[p];break}f<0||n(t[s],t[u],t[h],t[f])<0&&r.push(s,u)}}for(;r.length>0;){for(var u=r.pop(),s=r.pop(),h=-1,f=-1,l=o[s],d=1;d<l.length;d+=2){var g=l[d-1],v=l[d];g===u?f=v:v===u&&(h=g)}h<0||f<0||(n(t[s],t[u],t[h],t[f])>=0||(e.flip(s,u),i(t,e,r,h,s,f),i(t,e,r,s,f,h),i(t,e,r,f,u,h),i(t,e,r,u,h,f)))}}},{\"binary-search-bounds\":111,\"robust-in-sphere\":508}],108:[function(t,e,r){\"use strict\";var n,i=t(\"binary-search-bounds\");function a(t,e,r,n,i,a,o){this.cells=t,this.neighbor=e,this.flags=n,this.constraint=r,this.active=i,this.next=a,this.boundary=o}function o(t,e){return t[0]-e[0]||t[1]-e[1]||t[2]-e[2]}e.exports=function(t,e,r){var n=function(t,e){for(var r=t.cells(),n=r.length,i=0;i<n;++i){var s=r[i],l=s[0],c=s[1],u=s[2];c<u?c<l&&(s[0]=c,s[1]=u,s[2]=l):u<l&&(s[0]=u,s[1]=l,s[2]=c)}r.sort(o);for(var h=new Array(n),i=0;i<h.length;++i)h[i]=0;var f=[],p=[],d=new Array(3*n),g=new Array(3*n),v=null;e&&(v=[]);for(var m=new a(r,d,g,h,f,p,v),i=0;i<n;++i)for(var s=r[i],y=0;y<3;++y){var l=s[y],c=s[(y+1)%3],x=d[3*i+y]=m.locate(c,l,t.opposite(c,l)),b=g[3*i+y]=t.isConstraint(l,c);x<0&&(b?p.push(i):(f.push(i),h[i]=1),e&&v.push([c,l,-1]))}return m}(t,r);if(0===e)return r?n.cells.concat(n.boundary):n.cells;var i=1,s=n.active,l=n.next,c=n.flags,u=n.cells,h=n.constraint,f=n.neighbor;for(;s.length>0||l.length>0;){for(;s.length>0;){var p=s.pop();if(c[p]!==-i){c[p]=i;u[p];for(var d=0;d<3;++d){var g=f[3*p+d];g>=0&&0===c[g]&&(h[3*p+d]?l.push(g):(s.push(g),c[g]=i))}}}var v=l;l=s,s=v,l.length=0,i=-i}var m=function(t,e,r){for(var n=0,i=0;i<t.length;++i)e[i]===r&&(t[n++]=t[i]);return t.length=n,t}(u,c,e);if(r)return m.concat(n.boundary);return m},a.prototype.locate=(n=[0,0,0],function(t,e,r){var a=t,s=e,l=r;return e<r?e<t&&(a=e,s=r,l=t):r<t&&(a=r,s=t,l=e),a<0?-1:(n[0]=a,n[1]=s,n[2]=l,i.eq(this.cells,n,o))})},{\"binary-search-bounds\":111}],109:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"robust-orientation\")[3],a=0,o=1,s=2;function l(t,e,r,n,i){this.a=t,this.b=e,this.idx=r,this.lowerIds=n,this.upperIds=i}function c(t,e,r,n){this.a=t,this.b=e,this.type=r,this.idx=n}function u(t,e){var r=t.a[0]-e.a[0]||t.a[1]-e.a[1]||t.type-e.type;return r||(t.type!==a&&(r=i(t.a,t.b,e.b))?r:t.idx-e.idx)}function h(t,e){return i(t.a,t.b,e)}function f(t,e,r,a,o){for(var s=n.lt(e,a,h),l=n.gt(e,a,h),c=s;c<l;++c){for(var u=e[c],f=u.lowerIds,p=f.length;p>1&&i(r[f[p-2]],r[f[p-1]],a)>0;)t.push([f[p-1],f[p-2],o]),p-=1;f.length=p,f.push(o);var d=u.upperIds;for(p=d.length;p>1&&i(r[d[p-2]],r[d[p-1]],a)<0;)t.push([d[p-2],d[p-1],o]),p-=1;d.length=p,d.push(o)}}function p(t,e){var r;return(r=t.a[0]<e.a[0]?i(t.a,t.b,e.a):i(e.b,e.a,t.a))?r:(r=e.b[0]<t.b[0]?i(t.a,t.b,e.b):i(e.b,e.a,t.b))||t.idx-e.idx}function d(t,e,r){var i=n.le(t,r,p),a=t[i],o=a.upperIds,s=o[o.length-1];a.upperIds=[s],t.splice(i+1,0,new l(r.a,r.b,r.idx,[s],o))}function g(t,e,r){var i=r.a;r.a=r.b,r.b=i;var a=n.eq(t,r,p),o=t[a];t[a-1].upperIds=o.upperIds,t.splice(a,1)}e.exports=function(t,e){for(var r=t.length,n=e.length,i=[],h=0;h<r;++h)i.push(new c(t[h],null,a,h));for(var h=0;h<n;++h){var p=e[h],v=t[p[0]],m=t[p[1]];v[0]<m[0]?i.push(new c(v,m,s,h),new c(m,v,o,h)):v[0]>m[0]&&i.push(new c(m,v,s,h),new c(v,m,o,h))}i.sort(u);for(var y=i[0].a[0]-(1+Math.abs(i[0].a[0]))*Math.pow(2,-52),x=[new l([y,1],[y,0],-1,[],[],[],[])],b=[],h=0,_=i.length;h<_;++h){var w=i[h],k=w.type;k===a?f(b,x,t,w.a,w.idx):k===s?d(x,t,w):g(x,t,w)}return b}},{\"binary-search-bounds\":111,\"robust-orientation\":510}],110:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\");function i(t,e){this.stars=t,this.edges=e}e.exports=function(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=[];return new i(r,e)};var a=i.prototype;function o(t,e,r){for(var n=1,i=t.length;n<i;n+=2)if(t[n-1]===e&&t[n]===r)return t[n-1]=t[i-2],t[n]=t[i-1],void(t.length=i-2)}a.isConstraint=function(){var t=[0,0];function e(t,e){return t[0]-e[0]||t[1]-e[1]}return function(r,i){return t[0]=Math.min(r,i),t[1]=Math.max(r,i),n.eq(this.edges,t,e)>=0}}(),a.removeTriangle=function(t,e,r){var n=this.stars;o(n[t],e,r),o(n[e],r,t),o(n[r],t,e)},a.addTriangle=function(t,e,r){var n=this.stars;n[t].push(e,r),n[e].push(r,t),n[r].push(t,e)},a.opposite=function(t,e){for(var r=this.stars[e],n=1,i=r.length;n<i;n+=2)if(r[n]===t)return r[n-1];return-1},a.flip=function(t,e){var r=this.opposite(t,e),n=this.opposite(e,t);this.removeTriangle(t,e,r),this.removeTriangle(e,t,n),this.addTriangle(t,n,r),this.addTriangle(e,r,n)},a.edges=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2)e.push([i[a],i[a+1]]);return e},a.cells=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2){var s=i[a],l=i[a+1];r<Math.min(s,l)&&e.push([r,s,l])}return e}},{\"binary-search-bounds\":111}],111:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",i?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a[m]\"];return i?e.indexOf(\"c\")<0?a.push(\";if(x===y){return m}else if(x<=y){\"):a.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):a.push(\";if(\",e,\"){i=m;\"),r?a.push(\"l=m+1}else{h=m-1}\"):a.push(\"h=m-1}else{l=m+1}\"),a.push(\"}\"),i?a.push(\"return -1};\"):a.push(\"return i};\"),a.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(typeof(c)==='function'){return P(a,(l===void 0)?0:l|0,(h===void 0)?a.length-1:h|0,y,c)}else{return A(a,(c===void 0)?0:c|0,(l===void 0)?a.length-1:l|0,y)}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],112:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1,r=1;r<t.length;++r)for(var n=0;n<r;++n)if(t[r]<t[n])e=-e;else if(t[n]===t[r])return 0;return e}},{}],113:[function(t,e,r){\"use strict\";var n=t(\"dup\"),i=t(\"robust-linear-solve\");function a(t,e){for(var r=0,n=t.length,i=0;i<n;++i)r+=t[i]*e[i];return r}function o(t){var e=t.length;if(0===e)return[];t[0].length;var r=n([t.length+1,t.length+1],1),o=n([t.length+1],1);r[e][e]=0;for(var s=0;s<e;++s){for(var l=0;l<=s;++l)r[l][s]=r[s][l]=2*a(t[s],t[l]);o[s]=a(t[s],t[s])}var c=i(r,o),u=0,h=c[e+1];for(s=0;s<h.length;++s)u+=h[s];var f=new Array(e);for(s=0;s<e;++s){h=c[s];var p=0;for(l=0;l<h.length;++l)p+=h[l];f[s]=p/u}return f}function s(t){if(0===t.length)return[];for(var e=t[0].length,r=n([e]),i=o(t),a=0;a<t.length;++a)for(var s=0;s<e;++s)r[s]+=t[a][s]*i[a];return r}s.barycenetric=o,e.exports=s},{dup:170,\"robust-linear-solve\":509}],114:[function(t,e,r){e.exports=function(t){for(var e=n(t),r=0,i=0;i<t.length;++i)for(var a=t[i],o=0;o<e.length;++o)r+=Math.pow(a[o]-e[o],2);return Math.sqrt(r/t.length)};var n=t(\"circumcenter\")},{circumcenter:113}],115:[function(t,e,r){e.exports=function(t,e,r){return e<r?t<e?e:t>r?r:t:t<r?r:t>e?e:t}},{}],116:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n;if(r){n=e;for(var i=new Array(e.length),a=0;a<e.length;++a){var o=e[a];i[a]=[o[0],o[1],r[a]]}e=i}var s=function(t,e,r){var n=d(t,[],p(t));return m(e,n,r),!!n}(t,e,!!r);for(;y(t,e,!!r);)s=!0;if(r&&s){n.length=0,r.length=0;for(var a=0;a<e.length;++a){var o=e[a];n.push([o[0],o[1]]),r.push(o[2])}}return s};var n=t(\"union-find\"),i=t(\"box-intersect\"),a=t(\"robust-segment-intersect\"),o=t(\"big-rat\"),s=t(\"big-rat/cmp\"),l=t(\"big-rat/to-float\"),c=t(\"rat-vec\"),u=t(\"nextafter\"),h=t(\"./lib/rat-seg-intersect\");function f(t){var e=l(t);return[u(e,-1/0),u(e,1/0)]}function p(t){for(var e=new Array(t.length),r=0;r<t.length;++r){var n=t[r];e[r]=[u(n[0],-1/0),u(n[1],-1/0),u(n[0],1/0),u(n[1],1/0)]}return e}function d(t,e,r){for(var a=e.length,o=new n(a),s=[],l=0;l<e.length;++l){var c=e[l],h=f(c[0]),p=f(c[1]);s.push([u(h[0],-1/0),u(p[0],-1/0),u(h[1],1/0),u(p[1],1/0)])}i(s,function(t,e){o.link(t,e)});var d=!0,g=new Array(a);for(l=0;l<a;++l){(m=o.find(l))!==l&&(d=!1,t[m]=[Math.min(t[l][0],t[m][0]),Math.min(t[l][1],t[m][1])])}if(d)return null;var v=0;for(l=0;l<a;++l){var m;(m=o.find(l))===l?(g[l]=v,t[v++]=t[l]):g[l]=-1}t.length=v;for(l=0;l<a;++l)g[l]<0&&(g[l]=g[o.find(l)]);return g}function g(t,e){return t[0]-e[0]||t[1]-e[1]}function v(t,e){var r=t[0]-e[0]||t[1]-e[1];return r||(t[2]<e[2]?-1:t[2]>e[2]?1:0)}function m(t,e,r){if(0!==t.length){if(e)for(var n=0;n<t.length;++n){var i=e[(o=t[n])[0]],a=e[o[1]];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}else for(n=0;n<t.length;++n){var o;i=(o=t[n])[0],a=o[1];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}r?t.sort(v):t.sort(g);var s=1;for(n=1;n<t.length;++n){var l=t[n-1],c=t[n];(c[0]!==l[0]||c[1]!==l[1]||r&&c[2]!==l[2])&&(t[s++]=c)}t.length=s}}function y(t,e,r){var n=function(t,e){for(var r=new Array(e.length),n=0;n<e.length;++n){var i=e[n],a=t[i[0]],o=t[i[1]];r[n]=[u(Math.min(a[0],o[0]),-1/0),u(Math.min(a[1],o[1]),-1/0),u(Math.max(a[0],o[0]),1/0),u(Math.max(a[1],o[1]),1/0)]}return r}(t,e),f=function(t,e,r){var n=[];return i(r,function(r,i){var o=e[r],s=e[i];if(o[0]!==s[0]&&o[0]!==s[1]&&o[1]!==s[0]&&o[1]!==s[1]){var l=t[o[0]],c=t[o[1]],u=t[s[0]],h=t[s[1]];a(l,c,u,h)&&n.push([r,i])}}),n}(t,e,n),g=p(t),v=function(t,e,r,n){var o=[];return i(r,n,function(r,n){var i=e[r];if(i[0]!==n&&i[1]!==n){var s=t[n],l=t[i[0]],c=t[i[1]];a(l,c,s,s)&&o.push([r,n])}}),o}(t,e,n,g),y=d(t,function(t,e,r,n,i){var a,u,f=t.map(function(t){return[o(t[0]),o(t[1])]});for(a=0;a<r.length;++a){var p=r[a];u=p[0];var d=p[1],g=e[u],v=e[d],m=h(c(t[g[0]]),c(t[g[1]]),c(t[v[0]]),c(t[v[1]]));if(m){var y=t.length;t.push([l(m[0]),l(m[1])]),f.push(m),n.push([u,y],[d,y])}}for(n.sort(function(t,e){if(t[0]!==e[0])return t[0]-e[0];var r=f[t[1]],n=f[e[1]];return s(r[0],n[0])||s(r[1],n[1])}),a=n.length-1;a>=0;--a){var x=e[u=(S=n[a])[0]],b=x[0],_=x[1],w=t[b],k=t[_];if((w[0]-k[0]||w[1]-k[1])<0){var T=b;b=_,_=T}x[0]=b;var A,M=x[1]=S[1];for(i&&(A=x[2]);a>0&&n[a-1][0]===u;){var S,E=(S=n[--a])[1];i?e.push([M,E,A]):e.push([M,E]),M=E}i?e.push([M,_,A]):e.push([M,_])}return f}(t,e,f,v,r));return m(e,y,r),!!y||(f.length>0||v.length>0)}},{\"./lib/rat-seg-intersect\":117,\"big-rat\":78,\"big-rat/cmp\":76,\"big-rat/to-float\":90,\"box-intersect\":96,nextafter:451,\"rat-vec\":486,\"robust-segment-intersect\":513,\"union-find\":546}],117:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var a=s(e,t),h=s(n,r),f=u(a,h);if(0===o(f))return null;var p=s(t,r),d=u(h,p),g=i(d,f),v=c(a,g);return l(t,v)};var n=t(\"big-rat/mul\"),i=t(\"big-rat/div\"),a=t(\"big-rat/sub\"),o=t(\"big-rat/sign\"),s=t(\"rat-vec/sub\"),l=t(\"rat-vec/add\"),c=t(\"rat-vec/muls\");function u(t,e){return a(n(t[0],e[1]),n(t[1],e[0]))}},{\"big-rat/div\":77,\"big-rat/mul\":87,\"big-rat/sign\":88,\"big-rat/sub\":89,\"rat-vec/add\":485,\"rat-vec/muls\":487,\"rat-vec/sub\":488}],118:[function(t,e,r){\"use strict\";var n=t(\"clamp\");function i(t,e){null==e&&(e=!0);var r=t[0],i=t[1],a=t[2],o=t[3];return null==o&&(o=e?1:255),e&&(r*=255,i*=255,a*=255,o*=255),16777216*(r=255&n(r,0,255))+((i=255&n(i,0,255))<<16)+((a=255&n(a,0,255))<<8)+(o=255&n(o,0,255))}e.exports=i,e.exports.to=i,e.exports.from=function(t,e){var r=(t=+t)>>>24,n=(16711680&t)>>>16,i=(65280&t)>>>8,a=255&t;return!1===e?[r,n,i,a]:[r/255,n/255,i/255,a/255]}},{clamp:115}],119:[function(t,e,r){\"use strict\";e.exports={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]}},{}],120:[function(t,e,r){\"use strict\";var n=t(\"color-rgba\"),i=t(\"clamp\"),a=t(\"dtype\");e.exports=function(t,e){\"float\"!==e&&e||(e=\"array\"),\"uint\"===e&&(e=\"uint8\"),\"uint_clamped\"===e&&(e=\"uint8_clamped\");var r=new(a(e))(4),o=\"uint8\"!==e&&\"uint8_clamped\"!==e;return t.length&&\"string\"!=typeof t||((t=n(t))[0]/=255,t[1]/=255,t[2]/=255),function(t){return t instanceof Uint8Array||t instanceof Uint8ClampedArray||!!(Array.isArray(t)&&(t[0]>1||0===t[0])&&(t[1]>1||0===t[1])&&(t[2]>1||0===t[2])&&(!t[3]||t[3]>1))}(t)?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:255,o&&(r[0]/=255,r[1]/=255,r[2]/=255,r[3]/=255),r):(o?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:1):(r[0]=i(Math.floor(255*t[0]),0,255),r[1]=i(Math.floor(255*t[1]),0,255),r[2]=i(Math.floor(255*t[2]),0,255),r[3]=null==t[3]?255:i(Math.floor(255*t[3]),0,255)),r)}},{clamp:115,\"color-rgba\":122,dtype:169}],121:[function(t,e,r){(function(r){\"use strict\";var n=t(\"color-name\"),i=t(\"is-plain-obj\"),a=t(\"defined\");e.exports=function(t){var e,s,l=[],c=1;if(\"string\"==typeof t)if(n[t])l=n[t].slice(),s=\"rgb\";else if(\"transparent\"===t)c=0,s=\"rgb\",l=[0,0,0];else if(/^#[A-Fa-f0-9]+$/.test(t)){var u=t.slice(1),h=u.length,f=h<=4;c=1,f?(l=[parseInt(u[0]+u[0],16),parseInt(u[1]+u[1],16),parseInt(u[2]+u[2],16)],4===h&&(c=parseInt(u[3]+u[3],16)/255)):(l=[parseInt(u[0]+u[1],16),parseInt(u[2]+u[3],16),parseInt(u[4]+u[5],16)],8===h&&(c=parseInt(u[6]+u[7],16)/255)),l[0]||(l[0]=0),l[1]||(l[1]=0),l[2]||(l[2]=0),s=\"rgb\"}else if(e=/^((?:rgb|hs[lvb]|hwb|cmyk?|xy[zy]|gray|lab|lchu?v?|[ly]uv|lms)a?)\\s*\\(([^\\)]*)\\)/.exec(t)){var p=e[1],d=\"rgb\"===p,u=p.replace(/a$/,\"\");s=u;var h=\"cmyk\"===u?4:\"gray\"===u?1:3;l=e[2].trim().split(/\\s*,\\s*/).map(function(t,e){if(/%$/.test(t))return e===h?parseFloat(t)/100:\"rgb\"===u?255*parseFloat(t)/100:parseFloat(t);if(\"h\"===u[e]){if(/deg$/.test(t))return parseFloat(t);if(void 0!==o[t])return o[t]}return parseFloat(t)}),p===u&&l.push(1),c=d?1:void 0===l[h]?1:l[h],l=l.slice(0,h)}else t.length>10&&/[0-9](?:\\s|\\/)/.test(t)&&(l=t.match(/([0-9]+)/g).map(function(t){return parseFloat(t)}),s=t.match(/([a-z])/gi).join(\"\").toLowerCase());else if(isNaN(t))if(i(t)){var g=a(t.r,t.red,t.R,null);null!==g?(s=\"rgb\",l=[g,a(t.g,t.green,t.G),a(t.b,t.blue,t.B)]):(s=\"hsl\",l=[a(t.h,t.hue,t.H),a(t.s,t.saturation,t.S),a(t.l,t.lightness,t.L,t.b,t.brightness)]),c=a(t.a,t.alpha,t.opacity,1),null!=t.opacity&&(c/=100)}else(Array.isArray(t)||r.ArrayBuffer&&ArrayBuffer.isView&&ArrayBuffer.isView(t))&&(l=[t[0],t[1],t[2]],s=\"rgb\",c=4===t.length?t[3]:1);else s=\"rgb\",l=[t>>>16,(65280&t)>>>8,255&t];return{space:s,values:l,alpha:c}};var o={red:0,orange:60,yellow:120,green:180,blue:240,purple:300}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"color-name\":119,defined:164,\"is-plain-obj\":422}],122:[function(t,e,r){\"use strict\";var n=t(\"color-parse\"),i=t(\"color-space/hsl\"),a=t(\"clamp\");e.exports=function(t){var e,r=n(t);return r.space?((e=Array(3))[0]=a(r.values[0],0,255),e[1]=a(r.values[1],0,255),e[2]=a(r.values[2],0,255),\"h\"===r.space[0]&&(e=i.rgb(e)),e.push(a(r.alpha,0,1)),e):[]}},{clamp:115,\"color-parse\":121,\"color-space/hsl\":123}],123:[function(t,e,r){\"use strict\";var n=t(\"./rgb\");e.exports={name:\"hsl\",min:[0,0,0],max:[360,100,100],channel:[\"hue\",\"saturation\",\"lightness\"],alias:[\"HSL\"],rgb:function(t){var e,r,n,i,a,o=t[0]/360,s=t[1]/100,l=t[2]/100;if(0===s)return[a=255*l,a,a];e=2*l-(r=l<.5?l*(1+s):l+s-l*s),i=[0,0,0];for(var c=0;c<3;c++)(n=o+1/3*-(c-1))<0?n++:n>1&&n--,a=6*n<1?e+6*(r-e)*n:2*n<1?r:3*n<2?e+(r-e)*(2/3-n)*6:e,i[c]=255*a;return i}},n.hsl=function(t){var e,r,n=t[0]/255,i=t[1]/255,a=t[2]/255,o=Math.min(n,i,a),s=Math.max(n,i,a),l=s-o;return s===o?e=0:n===s?e=(i-a)/l:i===s?e=2+(a-n)/l:a===s&&(e=4+(n-i)/l),(e=Math.min(60*e,360))<0&&(e+=360),r=(o+s)/2,[e,100*(s===o?0:r<=.5?l/(s+o):l/(2-s-o)),100*r]}},{\"./rgb\":124}],124:[function(t,e,r){\"use strict\";e.exports={name:\"rgb\",min:[0,0,0],max:[255,255,255],channel:[\"red\",\"green\",\"blue\"],alias:[\"RGB\"]}},{}],125:[function(t,e,r){e.exports={jet:[{index:0,rgb:[0,0,131]},{index:.125,rgb:[0,60,170]},{index:.375,rgb:[5,255,255]},{index:.625,rgb:[255,255,0]},{index:.875,rgb:[250,0,0]},{index:1,rgb:[128,0,0]}],hsv:[{index:0,rgb:[255,0,0]},{index:.169,rgb:[253,255,2]},{index:.173,rgb:[247,255,2]},{index:.337,rgb:[0,252,4]},{index:.341,rgb:[0,252,10]},{index:.506,rgb:[1,249,255]},{index:.671,rgb:[2,0,253]},{index:.675,rgb:[8,0,253]},{index:.839,rgb:[255,0,251]},{index:.843,rgb:[255,0,245]},{index:1,rgb:[255,0,6]}],hot:[{index:0,rgb:[0,0,0]},{index:.3,rgb:[230,0,0]},{index:.6,rgb:[255,210,0]},{index:1,rgb:[255,255,255]}],cool:[{index:0,rgb:[0,255,255]},{index:1,rgb:[255,0,255]}],spring:[{index:0,rgb:[255,0,255]},{index:1,rgb:[255,255,0]}],summer:[{index:0,rgb:[0,128,102]},{index:1,rgb:[255,255,102]}],autumn:[{index:0,rgb:[255,0,0]},{index:1,rgb:[255,255,0]}],winter:[{index:0,rgb:[0,0,255]},{index:1,rgb:[0,255,128]}],bone:[{index:0,rgb:[0,0,0]},{index:.376,rgb:[84,84,116]},{index:.753,rgb:[169,200,200]},{index:1,rgb:[255,255,255]}],copper:[{index:0,rgb:[0,0,0]},{index:.804,rgb:[255,160,102]},{index:1,rgb:[255,199,127]}],greys:[{index:0,rgb:[0,0,0]},{index:1,rgb:[255,255,255]}],yignbu:[{index:0,rgb:[8,29,88]},{index:.125,rgb:[37,52,148]},{index:.25,rgb:[34,94,168]},{index:.375,rgb:[29,145,192]},{index:.5,rgb:[65,182,196]},{index:.625,rgb:[127,205,187]},{index:.75,rgb:[199,233,180]},{index:.875,rgb:[237,248,217]},{index:1,rgb:[255,255,217]}],greens:[{index:0,rgb:[0,68,27]},{index:.125,rgb:[0,109,44]},{index:.25,rgb:[35,139,69]},{index:.375,rgb:[65,171,93]},{index:.5,rgb:[116,196,118]},{index:.625,rgb:[161,217,155]},{index:.75,rgb:[199,233,192]},{index:.875,rgb:[229,245,224]},{index:1,rgb:[247,252,245]}],yiorrd:[{index:0,rgb:[128,0,38]},{index:.125,rgb:[189,0,38]},{index:.25,rgb:[227,26,28]},{index:.375,rgb:[252,78,42]},{index:.5,rgb:[253,141,60]},{index:.625,rgb:[254,178,76]},{index:.75,rgb:[254,217,118]},{index:.875,rgb:[255,237,160]},{index:1,rgb:[255,255,204]}],bluered:[{index:0,rgb:[0,0,255]},{index:1,rgb:[255,0,0]}],rdbu:[{index:0,rgb:[5,10,172]},{index:.35,rgb:[106,137,247]},{index:.5,rgb:[190,190,190]},{index:.6,rgb:[220,170,132]},{index:.7,rgb:[230,145,90]},{index:1,rgb:[178,10,28]}],picnic:[{index:0,rgb:[0,0,255]},{index:.1,rgb:[51,153,255]},{index:.2,rgb:[102,204,255]},{index:.3,rgb:[153,204,255]},{index:.4,rgb:[204,204,255]},{index:.5,rgb:[255,255,255]},{index:.6,rgb:[255,204,255]},{index:.7,rgb:[255,153,255]},{index:.8,rgb:[255,102,204]},{index:.9,rgb:[255,102,102]},{index:1,rgb:[255,0,0]}],rainbow:[{index:0,rgb:[150,0,90]},{index:.125,rgb:[0,0,200]},{index:.25,rgb:[0,25,255]},{index:.375,rgb:[0,152,255]},{index:.5,rgb:[44,255,150]},{index:.625,rgb:[151,255,0]},{index:.75,rgb:[255,234,0]},{index:.875,rgb:[255,111,0]},{index:1,rgb:[255,0,0]}],portland:[{index:0,rgb:[12,51,131]},{index:.25,rgb:[10,136,186]},{index:.5,rgb:[242,211,56]},{index:.75,rgb:[242,143,56]},{index:1,rgb:[217,30,30]}],blackbody:[{index:0,rgb:[0,0,0]},{index:.2,rgb:[230,0,0]},{index:.4,rgb:[230,210,0]},{index:.7,rgb:[255,255,255]},{index:1,rgb:[160,200,255]}],earth:[{index:0,rgb:[0,0,130]},{index:.1,rgb:[0,180,180]},{index:.2,rgb:[40,210,40]},{index:.4,rgb:[230,230,50]},{index:.6,rgb:[120,70,20]},{index:1,rgb:[255,255,255]}],electric:[{index:0,rgb:[0,0,0]},{index:.15,rgb:[30,0,100]},{index:.4,rgb:[120,0,100]},{index:.6,rgb:[160,90,0]},{index:.8,rgb:[230,200,0]},{index:1,rgb:[255,250,220]}],alpha:[{index:0,rgb:[255,255,255,0]},{index:1,rgb:[255,255,255,1]}],viridis:[{index:0,rgb:[68,1,84]},{index:.13,rgb:[71,44,122]},{index:.25,rgb:[59,81,139]},{index:.38,rgb:[44,113,142]},{index:.5,rgb:[33,144,141]},{index:.63,rgb:[39,173,129]},{index:.75,rgb:[92,200,99]},{index:.88,rgb:[170,220,50]},{index:1,rgb:[253,231,37]}],inferno:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[31,12,72]},{index:.25,rgb:[85,15,109]},{index:.38,rgb:[136,34,106]},{index:.5,rgb:[186,54,85]},{index:.63,rgb:[227,89,51]},{index:.75,rgb:[249,140,10]},{index:.88,rgb:[249,201,50]},{index:1,rgb:[252,255,164]}],magma:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[28,16,68]},{index:.25,rgb:[79,18,123]},{index:.38,rgb:[129,37,129]},{index:.5,rgb:[181,54,122]},{index:.63,rgb:[229,80,100]},{index:.75,rgb:[251,135,97]},{index:.88,rgb:[254,194,135]},{index:1,rgb:[252,253,191]}],plasma:[{index:0,rgb:[13,8,135]},{index:.13,rgb:[75,3,161]},{index:.25,rgb:[125,3,168]},{index:.38,rgb:[168,34,150]},{index:.5,rgb:[203,70,121]},{index:.63,rgb:[229,107,93]},{index:.75,rgb:[248,148,65]},{index:.88,rgb:[253,195,40]},{index:1,rgb:[240,249,33]}],warm:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[172,0,187]},{index:.25,rgb:[219,0,170]},{index:.38,rgb:[255,0,130]},{index:.5,rgb:[255,63,74]},{index:.63,rgb:[255,123,0]},{index:.75,rgb:[234,176,0]},{index:.88,rgb:[190,228,0]},{index:1,rgb:[147,255,0]}],cool:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[116,0,218]},{index:.25,rgb:[98,74,237]},{index:.38,rgb:[68,146,231]},{index:.5,rgb:[0,204,197]},{index:.63,rgb:[0,247,146]},{index:.75,rgb:[0,255,88]},{index:.88,rgb:[40,255,8]},{index:1,rgb:[147,255,0]}],\"rainbow-soft\":[{index:0,rgb:[125,0,179]},{index:.1,rgb:[199,0,180]},{index:.2,rgb:[255,0,121]},{index:.3,rgb:[255,108,0]},{index:.4,rgb:[222,194,0]},{index:.5,rgb:[150,255,0]},{index:.6,rgb:[0,255,55]},{index:.7,rgb:[0,246,150]},{index:.8,rgb:[50,167,222]},{index:.9,rgb:[103,51,235]},{index:1,rgb:[124,0,186]}],bathymetry:[{index:0,rgb:[40,26,44]},{index:.13,rgb:[59,49,90]},{index:.25,rgb:[64,76,139]},{index:.38,rgb:[63,110,151]},{index:.5,rgb:[72,142,158]},{index:.63,rgb:[85,174,163]},{index:.75,rgb:[120,206,163]},{index:.88,rgb:[187,230,172]},{index:1,rgb:[253,254,204]}],cdom:[{index:0,rgb:[47,15,62]},{index:.13,rgb:[87,23,86]},{index:.25,rgb:[130,28,99]},{index:.38,rgb:[171,41,96]},{index:.5,rgb:[206,67,86]},{index:.63,rgb:[230,106,84]},{index:.75,rgb:[242,149,103]},{index:.88,rgb:[249,193,135]},{index:1,rgb:[254,237,176]}],chlorophyll:[{index:0,rgb:[18,36,20]},{index:.13,rgb:[25,63,41]},{index:.25,rgb:[24,91,59]},{index:.38,rgb:[13,119,72]},{index:.5,rgb:[18,148,80]},{index:.63,rgb:[80,173,89]},{index:.75,rgb:[132,196,122]},{index:.88,rgb:[175,221,162]},{index:1,rgb:[215,249,208]}],density:[{index:0,rgb:[54,14,36]},{index:.13,rgb:[89,23,80]},{index:.25,rgb:[110,45,132]},{index:.38,rgb:[120,77,178]},{index:.5,rgb:[120,113,213]},{index:.63,rgb:[115,151,228]},{index:.75,rgb:[134,185,227]},{index:.88,rgb:[177,214,227]},{index:1,rgb:[230,241,241]}],\"freesurface-blue\":[{index:0,rgb:[30,4,110]},{index:.13,rgb:[47,14,176]},{index:.25,rgb:[41,45,236]},{index:.38,rgb:[25,99,212]},{index:.5,rgb:[68,131,200]},{index:.63,rgb:[114,156,197]},{index:.75,rgb:[157,181,203]},{index:.88,rgb:[200,208,216]},{index:1,rgb:[241,237,236]}],\"freesurface-red\":[{index:0,rgb:[60,9,18]},{index:.13,rgb:[100,17,27]},{index:.25,rgb:[142,20,29]},{index:.38,rgb:[177,43,27]},{index:.5,rgb:[192,87,63]},{index:.63,rgb:[205,125,105]},{index:.75,rgb:[216,162,148]},{index:.88,rgb:[227,199,193]},{index:1,rgb:[241,237,236]}],oxygen:[{index:0,rgb:[64,5,5]},{index:.13,rgb:[106,6,15]},{index:.25,rgb:[144,26,7]},{index:.38,rgb:[168,64,3]},{index:.5,rgb:[188,100,4]},{index:.63,rgb:[206,136,11]},{index:.75,rgb:[220,174,25]},{index:.88,rgb:[231,215,44]},{index:1,rgb:[248,254,105]}],par:[{index:0,rgb:[51,20,24]},{index:.13,rgb:[90,32,35]},{index:.25,rgb:[129,44,34]},{index:.38,rgb:[159,68,25]},{index:.5,rgb:[182,99,19]},{index:.63,rgb:[199,134,22]},{index:.75,rgb:[212,171,35]},{index:.88,rgb:[221,210,54]},{index:1,rgb:[225,253,75]}],phase:[{index:0,rgb:[145,105,18]},{index:.13,rgb:[184,71,38]},{index:.25,rgb:[186,58,115]},{index:.38,rgb:[160,71,185]},{index:.5,rgb:[110,97,218]},{index:.63,rgb:[50,123,164]},{index:.75,rgb:[31,131,110]},{index:.88,rgb:[77,129,34]},{index:1,rgb:[145,105,18]}],salinity:[{index:0,rgb:[42,24,108]},{index:.13,rgb:[33,50,162]},{index:.25,rgb:[15,90,145]},{index:.38,rgb:[40,118,137]},{index:.5,rgb:[59,146,135]},{index:.63,rgb:[79,175,126]},{index:.75,rgb:[120,203,104]},{index:.88,rgb:[193,221,100]},{index:1,rgb:[253,239,154]}],temperature:[{index:0,rgb:[4,35,51]},{index:.13,rgb:[23,51,122]},{index:.25,rgb:[85,59,157]},{index:.38,rgb:[129,79,143]},{index:.5,rgb:[175,95,130]},{index:.63,rgb:[222,112,101]},{index:.75,rgb:[249,146,66]},{index:.88,rgb:[249,196,65]},{index:1,rgb:[232,250,91]}],turbidity:[{index:0,rgb:[34,31,27]},{index:.13,rgb:[65,50,41]},{index:.25,rgb:[98,69,52]},{index:.38,rgb:[131,89,57]},{index:.5,rgb:[161,112,59]},{index:.63,rgb:[185,140,66]},{index:.75,rgb:[202,174,88]},{index:.88,rgb:[216,209,126]},{index:1,rgb:[233,246,171]}],\"velocity-blue\":[{index:0,rgb:[17,32,64]},{index:.13,rgb:[35,52,116]},{index:.25,rgb:[29,81,156]},{index:.38,rgb:[31,113,162]},{index:.5,rgb:[50,144,169]},{index:.63,rgb:[87,173,176]},{index:.75,rgb:[149,196,189]},{index:.88,rgb:[203,221,211]},{index:1,rgb:[254,251,230]}],\"velocity-green\":[{index:0,rgb:[23,35,19]},{index:.13,rgb:[24,64,38]},{index:.25,rgb:[11,95,45]},{index:.38,rgb:[39,123,35]},{index:.5,rgb:[95,146,12]},{index:.63,rgb:[152,165,18]},{index:.75,rgb:[201,186,69]},{index:.88,rgb:[233,216,137]},{index:1,rgb:[255,253,205]}],cubehelix:[{index:0,rgb:[0,0,0]},{index:.07,rgb:[22,5,59]},{index:.13,rgb:[60,4,105]},{index:.2,rgb:[109,1,135]},{index:.27,rgb:[161,0,147]},{index:.33,rgb:[210,2,142]},{index:.4,rgb:[251,11,123]},{index:.47,rgb:[255,29,97]},{index:.53,rgb:[255,54,69]},{index:.6,rgb:[255,85,46]},{index:.67,rgb:[255,120,34]},{index:.73,rgb:[255,157,37]},{index:.8,rgb:[241,191,57]},{index:.87,rgb:[224,220,93]},{index:.93,rgb:[218,241,142]},{index:1,rgb:[227,253,198]}]}},{}],126:[function(t,e,r){\"use strict\";var n=t(\"./colorScale\"),i=t(\"lerp\");function a(t){return[t[0]/255,t[1]/255,t[2]/255,t[3]]}function o(t){for(var e,r=\"#\",n=0;n<3;++n)r+=(\"00\"+(e=(e=t[n]).toString(16))).substr(e.length);return r}function s(t){return\"rgba(\"+t.join(\",\")+\")\"}e.exports=function(t){var e,r,l,c,u,h,f,p,d,g;t||(t={});p=(t.nshades||72)-1,f=t.format||\"hex\",(h=t.colormap)||(h=\"jet\");if(\"string\"==typeof h){if(h=h.toLowerCase(),!n[h])throw Error(h+\" not a supported colorscale\");u=n[h]}else{if(!Array.isArray(h))throw Error(\"unsupported colormap option\",h);u=h.slice()}if(u.length>p+1)throw new Error(h+\" map requires nshades to be at least size \"+u.length);d=Array.isArray(t.alpha)?2!==t.alpha.length?[1,1]:t.alpha.slice():\"number\"==typeof t.alpha?[t.alpha,t.alpha]:[1,1];e=u.map(function(t){return Math.round(t.index*p)}),d[0]=Math.min(Math.max(d[0],0),1),d[1]=Math.min(Math.max(d[1],0),1);var v=u.map(function(t,e){var r=u[e].index,n=u[e].rgb.slice();return 4===n.length&&n[3]>=0&&n[3]<=1?n:(n[3]=d[0]+(d[1]-d[0])*r,n)}),m=[];for(g=0;g<e.length-1;++g){c=e[g+1]-e[g],r=v[g],l=v[g+1];for(var y=0;y<c;y++){var x=y/c;m.push([Math.round(i(r[0],l[0],x)),Math.round(i(r[1],l[1],x)),Math.round(i(r[2],l[2],x)),i(r[3],l[3],x)])}}m.push(u[u.length-1].rgb.concat(d[1])),\"hex\"===f?m=m.map(o):\"rgbaString\"===f?m=m.map(s):\"float\"===f&&(m=m.map(a));return m}},{\"./colorScale\":125,lerp:425}],127:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a){var o=n(e,r,a);if(0===o){var s=i(n(t,e,r)),c=i(n(t,e,a));if(s===c){if(0===s){var u=l(t,e,r),h=l(t,e,a);return u===h?0:u?1:-1}return 0}return 0===c?s>0?-1:l(t,e,a)?-1:1:0===s?c>0?1:l(t,e,r)?1:-1:i(c-s)}var f=n(t,e,r);if(f>0)return o>0&&n(t,e,a)>0?1:-1;if(f<0)return o>0||n(t,e,a)>0?1:-1;var p=n(t,e,a);return p>0?1:l(t,e,r)?1:-1};var n=t(\"robust-orientation\"),i=t(\"signum\"),a=t(\"two-sum\"),o=t(\"robust-product\"),s=t(\"robust-sum\");function l(t,e,r){var n=a(t[0],-e[0]),i=a(t[1],-e[1]),l=a(r[0],-e[0]),c=a(r[1],-e[1]),u=s(o(n,l),o(i,c));return u[u.length-1]>=0}},{\"robust-orientation\":510,\"robust-product\":511,\"robust-sum\":515,signum:516,\"two-sum\":544}],128:[function(t,e,r){e.exports=function(t,e){var r=t.length,a=t.length-e.length;if(a)return a;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return t[0]+t[1]-e[0]-e[1]||n(t[0],t[1])-n(e[0],e[1]);case 3:var o=t[0]+t[1],s=e[0]+e[1];if(a=o+t[2]-(s+e[2]))return a;var l=n(t[0],t[1]),c=n(e[0],e[1]);return n(l,t[2])-n(c,e[2])||n(l+t[2],o)-n(c+e[2],s);case 4:var u=t[0],h=t[1],f=t[2],p=t[3],d=e[0],g=e[1],v=e[2],m=e[3];return u+h+f+p-(d+g+v+m)||n(u,h,f,p)-n(d,g,v,m,d)||n(u+h,u+f,u+p,h+f,h+p,f+p)-n(d+g,d+v,d+m,g+v,g+m,v+m)||n(u+h+f,u+h+p,u+f+p,h+f+p)-n(d+g+v,d+g+m,d+v+m,g+v+m);default:for(var y=t.slice().sort(i),x=e.slice().sort(i),b=0;b<r;++b)if(a=y[b]-x[b])return a;return 0}};var n=Math.min;function i(t,e){return t-e}},{}],129:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"cell-orientation\");e.exports=function(t,e){return n(t,e)||i(t)-i(e)}},{\"cell-orientation\":112,\"compare-cell\":128}],130:[function(t,e,r){\"use strict\";var n=t(\"./lib/ch1d\"),i=t(\"./lib/ch2d\"),a=t(\"./lib/chnd\");e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[[0]];var r=t[0].length;if(0===r)return[];if(1===r)return n(t);if(2===r)return i(t);return a(t,r)}},{\"./lib/ch1d\":131,\"./lib/ch2d\":132,\"./lib/chnd\":133}],131:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0,r=0,n=1;n<t.length;++n)t[n][0]<t[e][0]&&(e=n),t[n][0]>t[r][0]&&(r=n);return e<r?[[e],[r]]:e>r?[[r],[e]]:[[e]]}},{}],132:[function(t,e,r){\"use strict\";e.exports=function(t){var e=n(t),r=e.length;if(r<=2)return[];for(var i=new Array(r),a=e[r-1],o=0;o<r;++o){var s=e[o];i[o]=[a,s],a=s}return i};var n=t(\"monotone-convex-hull-2d\")},{\"monotone-convex-hull-2d\":434}],133:[function(t,e,r){\"use strict\";e.exports=function(t,e){try{return n(t,!0)}catch(s){var r=i(t);if(r.length<=e)return[];var a=function(t,e){for(var r=t.length,n=new Array(r),i=0;i<e.length;++i)n[i]=t[e[i]];for(var a=e.length,i=0;i<r;++i)e.indexOf(i)<0&&(n[a++]=t[i]);return n}(t,r),o=n(a,!0);return function(t,e){for(var r=t.length,n=e.length,i=0;i<r;++i)for(var a=t[i],o=0;o<a.length;++o){var s=a[o];if(s<n)a[o]=e[s];else{s-=n;for(var l=0;l<n;++l)s>=e[l]&&(s+=1);a[o]=s}}return t}(o,r)}};var n=t(\"incremental-convex-hull\"),i=t(\"affine-hull\")},{\"affine-hull\":62,\"incremental-convex-hull\":413}],134:[function(t,e,r){e.exports={AFG:\"afghan\",ALA:\"\\\\b\\\\wland\",ALB:\"albania\",DZA:\"algeria\",ASM:\"^(?=.*americ).*samoa\",AND:\"andorra\",AGO:\"angola\",AIA:\"anguill?a\",ATA:\"antarctica\",ATG:\"antigua\",ARG:\"argentin\",ARM:\"armenia\",ABW:\"^(?!.*bonaire).*\\\\baruba\",AUS:\"australia\",AUT:\"^(?!.*hungary).*austria|\\\\baustri.*\\\\bemp\",AZE:\"azerbaijan\",BHS:\"bahamas\",BHR:\"bahrain\",BGD:\"bangladesh|^(?=.*east).*paki?stan\",BRB:\"barbados\",BLR:\"belarus|byelo\",BEL:\"^(?!.*luxem).*belgium\",BLZ:\"belize|^(?=.*british).*honduras\",BEN:\"benin|dahome\",BMU:\"bermuda\",BTN:\"bhutan\",BOL:\"bolivia\",BES:\"^(?=.*bonaire).*eustatius|^(?=.*carib).*netherlands|\\\\bbes.?islands\",BIH:\"herzegovina|bosnia\",BWA:\"botswana|bechuana\",BVT:\"bouvet\",BRA:\"brazil\",IOT:\"british.?indian.?ocean\",BRN:\"brunei\",BGR:\"bulgaria\",BFA:\"burkina|\\\\bfaso|upper.?volta\",BDI:\"burundi\",CPV:\"verde\",KHM:\"cambodia|kampuchea|khmer\",CMR:\"cameroon\",CAN:\"canada\",CYM:\"cayman\",CAF:\"\\\\bcentral.african.republic\",TCD:\"\\\\bchad\",CHL:\"\\\\bchile\",CHN:\"^(?!.*\\\\bmac)(?!.*\\\\bhong)(?!.*\\\\btai)(?!.*\\\\brep).*china|^(?=.*peo)(?=.*rep).*china\",CXR:\"christmas\",CCK:\"\\\\bcocos|keeling\",COL:\"colombia\",COM:\"comoro\",COG:\"^(?!.*\\\\bdem)(?!.*\\\\bd[\\\\.]?r)(?!.*kinshasa)(?!.*zaire)(?!.*belg)(?!.*l.opoldville)(?!.*free).*\\\\bcongo\",COK:\"\\\\bcook\",CRI:\"costa.?rica\",CIV:\"ivoire|ivory\",HRV:\"croatia\",CUB:\"\\\\bcuba\",CUW:\"^(?!.*bonaire).*\\\\bcura(c|\\xe7)ao\",CYP:\"cyprus\",CSK:\"czechoslovakia\",CZE:\"^(?=.*rep).*czech|czechia|bohemia\",COD:\"\\\\bdem.*congo|congo.*\\\\bdem|congo.*\\\\bd[\\\\.]?r|\\\\bd[\\\\.]?r.*congo|belgian.?congo|congo.?free.?state|kinshasa|zaire|l.opoldville|drc|droc|rdc\",DNK:\"denmark\",DJI:\"djibouti\",DMA:\"dominica(?!n)\",DOM:\"dominican.rep\",ECU:\"ecuador\",EGY:\"egypt\",SLV:\"el.?salvador\",GNQ:\"guine.*eq|eq.*guine|^(?=.*span).*guinea\",ERI:\"eritrea\",EST:\"estonia\",ETH:\"ethiopia|abyssinia\",FLK:\"falkland|malvinas\",FRO:\"faroe|faeroe\",FJI:\"fiji\",FIN:\"finland\",FRA:\"^(?!.*\\\\bdep)(?!.*martinique).*france|french.?republic|\\\\bgaul\",GUF:\"^(?=.*french).*guiana\",PYF:\"french.?polynesia|tahiti\",ATF:\"french.?southern\",GAB:\"gabon\",GMB:\"gambia\",GEO:\"^(?!.*south).*georgia\",DDR:\"german.?democratic.?republic|democratic.?republic.*germany|east.germany\",DEU:\"^(?!.*east).*germany|^(?=.*\\\\bfed.*\\\\brep).*german\",GHA:\"ghana|gold.?coast\",GIB:\"gibraltar\",GRC:\"greece|hellenic|hellas\",GRL:\"greenland\",GRD:\"grenada\",GLP:\"guadeloupe\",GUM:\"\\\\bguam\",GTM:\"guatemala\",GGY:\"guernsey\",GIN:\"^(?!.*eq)(?!.*span)(?!.*bissau)(?!.*portu)(?!.*new).*guinea\",GNB:\"bissau|^(?=.*portu).*guinea\",GUY:\"guyana|british.?guiana\",HTI:\"haiti\",HMD:\"heard.*mcdonald\",VAT:\"holy.?see|vatican|papal.?st\",HND:\"^(?!.*brit).*honduras\",HKG:\"hong.?kong\",HUN:\"^(?!.*austr).*hungary\",ISL:\"iceland\",IND:\"india(?!.*ocea)\",IDN:\"indonesia\",IRN:\"\\\\biran|persia\",IRQ:\"\\\\biraq|mesopotamia\",IRL:\"(^ireland)|(^republic.*ireland)\",IMN:\"^(?=.*isle).*\\\\bman\",ISR:\"israel\",ITA:\"italy\",JAM:\"jamaica\",JPN:\"japan\",JEY:\"jersey\",JOR:\"jordan\",KAZ:\"kazak\",KEN:\"kenya|british.?east.?africa|east.?africa.?prot\",KIR:\"kiribati\",PRK:\"^(?=.*democrat|people|north|d.*p.*.r).*\\\\bkorea|dprk|korea.*(d.*p.*r)\",KWT:\"kuwait\",KGZ:\"kyrgyz|kirghiz\",LAO:\"\\\\blaos?\\\\b\",LVA:\"latvia\",LBN:\"lebanon\",LSO:\"lesotho|basuto\",LBR:\"liberia\",LBY:\"libya\",LIE:\"liechtenstein\",LTU:\"lithuania\",LUX:\"^(?!.*belg).*luxem\",MAC:\"maca(o|u)\",MDG:\"madagascar|malagasy\",MWI:\"malawi|nyasa\",MYS:\"malaysia\",MDV:\"maldive\",MLI:\"\\\\bmali\\\\b\",MLT:\"\\\\bmalta\",MHL:\"marshall\",MTQ:\"martinique\",MRT:\"mauritania\",MUS:\"mauritius\",MYT:\"\\\\bmayotte\",MEX:\"\\\\bmexic\",FSM:\"fed.*micronesia|micronesia.*fed\",MCO:\"monaco\",MNG:\"mongolia\",MNE:\"^(?!.*serbia).*montenegro\",MSR:\"montserrat\",MAR:\"morocco|\\\\bmaroc\",MOZ:\"mozambique\",MMR:\"myanmar|burma\",NAM:\"namibia\",NRU:\"nauru\",NPL:\"nepal\",NLD:\"^(?!.*\\\\bant)(?!.*\\\\bcarib).*netherlands\",ANT:\"^(?=.*\\\\bant).*(nether|dutch)\",NCL:\"new.?caledonia\",NZL:\"new.?zealand\",NIC:\"nicaragua\",NER:\"\\\\bniger(?!ia)\",NGA:\"nigeria\",NIU:\"niue\",NFK:\"norfolk\",MNP:\"mariana\",NOR:\"norway\",OMN:\"\\\\boman|trucial\",PAK:\"^(?!.*east).*paki?stan\",PLW:\"palau\",PSE:\"palestin|\\\\bgaza|west.?bank\",PAN:\"panama\",PNG:\"papua|new.?guinea\",PRY:\"paraguay\",PER:\"peru\",PHL:\"philippines\",PCN:\"pitcairn\",POL:\"poland\",PRT:\"portugal\",PRI:\"puerto.?rico\",QAT:\"qatar\",KOR:\"^(?!.*d.*p.*r)(?!.*democrat)(?!.*people)(?!.*north).*\\\\bkorea(?!.*d.*p.*r)\",MDA:\"moldov|b(a|e)ssarabia\",REU:\"r(e|\\xe9)union\",ROU:\"r(o|u|ou)mania\",RUS:\"\\\\brussia|soviet.?union|u\\\\.?s\\\\.?s\\\\.?r|socialist.?republics\",RWA:\"rwanda\",BLM:\"barth(e|\\xe9)lemy\",SHN:\"helena\",KNA:\"kitts|\\\\bnevis\",LCA:\"\\\\blucia\",MAF:\"^(?=.*collectivity).*martin|^(?=.*france).*martin(?!ique)|^(?=.*french).*martin(?!ique)\",SPM:\"miquelon\",VCT:\"vincent\",WSM:\"^(?!.*amer).*samoa\",SMR:\"san.?marino\",STP:\"\\\\bs(a|\\xe3)o.?tom(e|\\xe9)\",SAU:\"\\\\bsa\\\\w*.?arabia\",SEN:\"senegal\",SRB:\"^(?!.*monte).*serbia\",SYC:\"seychell\",SLE:\"sierra\",SGP:\"singapore\",SXM:\"^(?!.*martin)(?!.*saba).*maarten\",SVK:\"^(?!.*cze).*slovak\",SVN:\"slovenia\",SLB:\"solomon\",SOM:\"somali\",ZAF:\"south.africa|s\\\\\\\\..?africa\",SGS:\"south.?georgia|sandwich\",SSD:\"\\\\bs\\\\w*.?sudan\",ESP:\"spain\",LKA:\"sri.?lanka|ceylon\",SDN:\"^(?!.*\\\\bs(?!u)).*sudan\",SUR:\"surinam|dutch.?guiana\",SJM:\"svalbard\",SWZ:\"swaziland\",SWE:\"sweden\",CHE:\"switz|swiss\",SYR:\"syria\",TWN:\"taiwan|taipei|formosa|^(?!.*peo)(?=.*rep).*china\",TJK:\"tajik\",THA:\"thailand|\\\\bsiam\",MKD:\"macedonia|fyrom\",TLS:\"^(?=.*leste).*timor|^(?=.*east).*timor\",TGO:\"togo\",TKL:\"tokelau\",TON:\"tonga\",TTO:\"trinidad|tobago\",TUN:\"tunisia\",TUR:\"turkey\",TKM:\"turkmen\",TCA:\"turks\",TUV:\"tuvalu\",UGA:\"uganda\",UKR:\"ukrain\",ARE:\"emirates|^u\\\\.?a\\\\.?e\\\\.?$|united.?arab.?em\",GBR:\"united.?kingdom|britain|^u\\\\.?k\\\\.?$\",TZA:\"tanzania\",USA:\"united.?states\\\\b(?!.*islands)|\\\\bu\\\\.?s\\\\.?a\\\\.?\\\\b|^\\\\s*u\\\\.?s\\\\.?\\\\b(?!.*islands)\",UMI:\"minor.?outlying.?is\",URY:\"uruguay\",UZB:\"uzbek\",VUT:\"vanuatu|new.?hebrides\",VEN:\"venezuela\",VNM:\"^(?!.*republic).*viet.?nam|^(?=.*socialist).*viet.?nam\",VGB:\"^(?=.*\\\\bu\\\\.?\\\\s?k).*virgin|^(?=.*brit).*virgin|^(?=.*kingdom).*virgin\",VIR:\"^(?=.*\\\\bu\\\\.?\\\\s?s).*virgin|^(?=.*states).*virgin\",WLF:\"futuna|wallis\",ESH:\"western.sahara\",YEM:\"^(?!.*arab)(?!.*north)(?!.*sana)(?!.*peo)(?!.*dem)(?!.*south)(?!.*aden)(?!.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YMD:\"^(?=.*peo).*yemen|^(?!.*rep)(?=.*dem).*yemen|^(?=.*south).*yemen|^(?=.*aden).*yemen|^(?=.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YUG:\"yugoslavia\",ZMB:\"zambia|northern.?rhodesia\",EAZ:\"zanzibar\",ZWE:\"zimbabwe|^(?!.*northern).*rhodesia\"}},{}],135:[function(t,e,r){e.exports=[\"xx-small\",\"x-small\",\"small\",\"medium\",\"large\",\"x-large\",\"xx-large\",\"larger\",\"smaller\"]},{}],136:[function(t,e,r){e.exports=[\"normal\",\"condensed\",\"semi-condensed\",\"extra-condensed\",\"ultra-condensed\",\"expanded\",\"semi-expanded\",\"extra-expanded\",\"ultra-expanded\"]},{}],137:[function(t,e,r){e.exports=[\"normal\",\"italic\",\"oblique\"]},{}],138:[function(t,e,r){e.exports=[\"normal\",\"bold\",\"bolder\",\"lighter\",\"100\",\"200\",\"300\",\"400\",\"500\",\"600\",\"700\",\"800\",\"900\"]},{}],139:[function(t,e,r){\"use strict\";e.exports={parse:t(\"./parse\"),stringify:t(\"./stringify\")}},{\"./parse\":141,\"./stringify\":142}],140:[function(t,e,r){\"use strict\";var n=t(\"css-font-size-keywords\");e.exports={isSize:function(t){return/^[\\d\\.]/.test(t)||-1!==t.indexOf(\"/\")||-1!==n.indexOf(t)}}},{\"css-font-size-keywords\":135}],141:[function(t,e,r){\"use strict\";var n=t(\"unquote\"),i=t(\"css-global-keywords\"),a=t(\"css-system-font-keywords\"),o=t(\"css-font-weight-keywords\"),s=t(\"css-font-style-keywords\"),l=t(\"css-font-stretch-keywords\"),c=t(\"string-split-by\"),u=t(\"./lib/util\").isSize;e.exports=f;var h=f.cache={};function f(t){if(\"string\"!=typeof t)throw new Error(\"Font argument must be a string.\");if(h[t])return h[t];if(\"\"===t)throw new Error(\"Cannot parse an empty string.\");if(-1!==a.indexOf(t))return h[t]={system:t};for(var e,r={style:\"normal\",variant:\"normal\",weight:\"normal\",stretch:\"normal\",lineHeight:\"normal\",size:\"1rem\",family:[\"serif\"]},f=c(t,/\\s+/);e=f.shift();){if(-1!==i.indexOf(e))return[\"style\",\"variant\",\"weight\",\"stretch\"].forEach(function(t){r[t]=e}),h[t]=r;if(-1===s.indexOf(e))if(\"normal\"!==e&&\"small-caps\"!==e)if(-1===l.indexOf(e)){if(-1===o.indexOf(e)){if(u(e)){var d=c(e,\"/\");if(r.size=d[0],null!=d[1]?r.lineHeight=p(d[1]):\"/\"===f[0]&&(f.shift(),r.lineHeight=p(f.shift())),!f.length)throw new Error(\"Missing required font-family.\");return r.family=c(f.join(\" \"),/\\s*,\\s*/).map(n),h[t]=r}throw new Error(\"Unknown or unsupported font token: \"+e)}r.weight=e}else r.stretch=e;else r.variant=e;else r.style=e}throw new Error(\"Missing required font-size.\")}function p(t){var e=parseFloat(t);return e.toString()===t?e:t}},{\"./lib/util\":140,\"css-font-stretch-keywords\":136,\"css-font-style-keywords\":137,\"css-font-weight-keywords\":138,\"css-global-keywords\":143,\"css-system-font-keywords\":144,\"string-split-by\":529,unquote:548}],142:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\"),i=t(\"./lib/util\").isSize,a=g(t(\"css-global-keywords\")),o=g(t(\"css-system-font-keywords\")),s=g(t(\"css-font-weight-keywords\")),l=g(t(\"css-font-style-keywords\")),c=g(t(\"css-font-stretch-keywords\")),u={normal:1,\"small-caps\":1},h={serif:1,\"sans-serif\":1,monospace:1,cursive:1,fantasy:1,\"system-ui\":1},f=\"1rem\",p=\"serif\";function d(t,e){if(t&&!e[t]&&!a[t])throw Error(\"Unknown keyword `\"+t+\"`\");return t}function g(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=1;return e}e.exports=function(t){if((t=n(t,{style:\"style fontstyle fontStyle font-style slope distinction\",variant:\"variant font-variant fontVariant fontvariant var capitalization\",weight:\"weight w font-weight fontWeight fontweight\",stretch:\"stretch font-stretch fontStretch fontstretch width\",size:\"size s font-size fontSize fontsize height em emSize\",lineHeight:\"lh line-height lineHeight lineheight leading\",family:\"font family fontFamily font-family fontfamily type typeface face\",system:\"system reserved default global\"})).system)return t.system&&d(t.system,o),t.system;if(d(t.style,l),d(t.variant,u),d(t.weight,s),d(t.stretch,c),null==t.size&&(t.size=f),\"number\"==typeof t.size&&(t.size+=\"px\"),!i)throw Error(\"Bad size value `\"+t.size+\"`\");t.family||(t.family=p),Array.isArray(t.family)&&(t.family.length||(t.family=[p]),t.family=t.family.map(function(t){return h[t]?t:'\"'+t+'\"'}).join(\", \"));var e=[];return e.push(t.style),t.variant!==t.style&&e.push(t.variant),t.weight!==t.variant&&t.weight!==t.style&&e.push(t.weight),t.stretch!==t.weight&&t.stretch!==t.variant&&t.stretch!==t.style&&e.push(t.stretch),e.push(t.size+(null==t.lineHeight||\"normal\"===t.lineHeight||t.lineHeight+\"\"==\"1\"?\"\":\"/\"+t.lineHeight)),e.push(t.family),e.filter(Boolean).join(\" \")}},{\"./lib/util\":140,\"css-font-stretch-keywords\":136,\"css-font-style-keywords\":137,\"css-font-weight-keywords\":138,\"css-global-keywords\":143,\"css-system-font-keywords\":144,\"pick-by-alias\":465}],143:[function(t,e,r){e.exports=[\"inherit\",\"initial\",\"unset\"]},{}],144:[function(t,e,r){e.exports=[\"caption\",\"icon\",\"menu\",\"message-box\",\"small-caption\",\"status-bar\"]},{}],145:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i-1,s=i*i,l=o*o,c=(1+2*i)*l,u=i*l,h=s*(3-2*i),f=s*o;if(t.length){a||(a=new Array(t.length));for(var p=t.length-1;p>=0;--p)a[p]=c*t[p]+u*e[p]+h*r[p]+f*n[p];return a}return c*t+u*e+h*r+f*n},e.exports.derivative=function(t,e,r,n,i,a){var o=6*i*i-6*i,s=3*i*i-4*i+1,l=-6*i*i+6*i,c=3*i*i-2*i;if(t.length){a||(a=new Array(t.length));for(var u=t.length-1;u>=0;--u)a[u]=o*t[u]+s*e[u]+l*r[u]+c*n[u];return a}return o*t+s*e+l*r[u]+c*n}},{}],146:[function(t,e,r){\"use strict\";var n=t(\"./lib/thunk.js\");function i(){this.argTypes=[],this.shimArgs=[],this.arrayArgs=[],this.arrayBlockIndices=[],this.scalarArgs=[],this.offsetArgs=[],this.offsetArgIndex=[],this.indexArgs=[],this.shapeArgs=[],this.funcName=\"\",this.pre=null,this.body=null,this.post=null,this.debug=!1}e.exports=function(t){var e=new i;e.pre=t.pre,e.body=t.body,e.post=t.post;var r=t.args.slice(0);e.argTypes=r;for(var a=0;a<r.length;++a){var o=r[a];if(\"array\"===o||\"object\"==typeof o&&o.blockIndices){if(e.argTypes[a]=\"array\",e.arrayArgs.push(a),e.arrayBlockIndices.push(o.blockIndices?o.blockIndices:0),e.shimArgs.push(\"array\"+a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array args\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array args\")}else if(\"scalar\"===o)e.scalarArgs.push(a),e.shimArgs.push(\"scalar\"+a);else if(\"index\"===o){if(e.indexArgs.push(a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array index\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array index\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array index\")}else if(\"shape\"===o){if(e.shapeArgs.push(a),a<e.pre.args.length&&e.pre.args[a].lvalue)throw new Error(\"cwise: pre() block may not write to array shape\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array shape\");if(a<e.post.args.length&&e.post.args[a].lvalue)throw new Error(\"cwise: post() block may not write to array shape\")}else{if(\"object\"!=typeof o||!o.offset)throw new Error(\"cwise: Unknown argument type \"+r[a]);e.argTypes[a]=\"offset\",e.offsetArgs.push({array:o.array,offset:o.offset}),e.offsetArgIndex.push(a)}}if(e.arrayArgs.length<=0)throw new Error(\"cwise: No array arguments specified\");if(e.pre.args.length>r.length)throw new Error(\"cwise: Too many arguments in pre() block\");if(e.body.args.length>r.length)throw new Error(\"cwise: Too many arguments in body() block\");if(e.post.args.length>r.length)throw new Error(\"cwise: Too many arguments in post() block\");return e.debug=!!t.printCode||!!t.debug,e.funcName=t.funcName||\"cwise\",e.blockSize=t.blockSize||64,n(e)}},{\"./lib/thunk.js\":148}],147:[function(t,e,r){\"use strict\";var n=t(\"uniq\");function i(t,e,r){var n,i,a=t.length,o=e.arrayArgs.length,s=e.indexArgs.length>0,l=[],c=[],u=0,h=0;for(n=0;n<a;++n)c.push([\"i\",n,\"=0\"].join(\"\"));for(i=0;i<o;++i)for(n=0;n<a;++n)h=u,u=t[n],0===n?c.push([\"d\",i,\"s\",n,\"=t\",i,\"p\",u].join(\"\")):c.push([\"d\",i,\"s\",n,\"=(t\",i,\"p\",u,\"-s\",h,\"*t\",i,\"p\",h,\")\"].join(\"\"));for(c.length>0&&l.push(\"var \"+c.join(\",\")),n=a-1;n>=0;--n)u=t[n],l.push([\"for(i\",n,\"=0;i\",n,\"<s\",u,\";++i\",n,\"){\"].join(\"\"));for(l.push(r),n=0;n<a;++n){for(h=u,u=t[n],i=0;i<o;++i)l.push([\"p\",i,\"+=d\",i,\"s\",n].join(\"\"));s&&(n>0&&l.push([\"index[\",h,\"]-=s\",h].join(\"\")),l.push([\"++index[\",u,\"]\"].join(\"\"))),l.push(\"}\")}return l.join(\"\\n\")}function a(t,e,r){for(var n=t.body,i=[],a=[],o=0;o<t.args.length;++o){var s=t.args[o];if(!(s.count<=0)){var l=new RegExp(s.name,\"g\"),c=\"\",u=e.arrayArgs.indexOf(o);switch(e.argTypes[o]){case\"offset\":var h=e.offsetArgIndex.indexOf(o);u=e.offsetArgs[h].array,c=\"+q\"+h;case\"array\":c=\"p\"+u+c;var f=\"l\"+o,p=\"a\"+u;if(0===e.arrayBlockIndices[u])1===s.count?\"generic\"===r[u]?s.lvalue?(i.push([\"var \",f,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,f),a.push([p,\".set(\",c,\",\",f,\")\"].join(\"\"))):n=n.replace(l,[p,\".get(\",c,\")\"].join(\"\")):n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\")):\"generic\"===r[u]?(i.push([\"var \",f,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,f),s.lvalue&&a.push([p,\".set(\",c,\",\",f,\")\"].join(\"\"))):(i.push([\"var \",f,\"=\",p,\"[\",c,\"]\"].join(\"\")),n=n.replace(l,f),s.lvalue&&a.push([p,\"[\",c,\"]=\",f].join(\"\")));else{for(var d=[s.name],g=[c],v=0;v<Math.abs(e.arrayBlockIndices[u]);v++)d.push(\"\\\\s*\\\\[([^\\\\]]+)\\\\]\"),g.push(\"$\"+(v+1)+\"*t\"+u+\"b\"+v);if(l=new RegExp(d.join(\"\"),\"g\"),c=g.join(\"+\"),\"generic\"===r[u])throw new Error(\"cwise: Generic arrays not supported in combination with blocks!\");n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\"))}break;case\"scalar\":n=n.replace(l,\"Y\"+e.scalarArgs.indexOf(o));break;case\"index\":n=n.replace(l,\"index\");break;case\"shape\":n=n.replace(l,\"shape\")}}}return[i.join(\"\\n\"),n,a.join(\"\\n\")].join(\"\\n\").trim()}e.exports=function(t,e){for(var r=e[1].length-Math.abs(t.arrayBlockIndices[0])|0,o=new Array(t.arrayArgs.length),s=new Array(t.arrayArgs.length),l=0;l<t.arrayArgs.length;++l)s[l]=e[2*l],o[l]=e[2*l+1];var c=[],u=[],h=[],f=[],p=[];for(l=0;l<t.arrayArgs.length;++l){t.arrayBlockIndices[l]<0?(h.push(0),f.push(r),c.push(r),u.push(r+t.arrayBlockIndices[l])):(h.push(t.arrayBlockIndices[l]),f.push(t.arrayBlockIndices[l]+r),c.push(0),u.push(t.arrayBlockIndices[l]));for(var d=[],g=0;g<o[l].length;g++)h[l]<=o[l][g]&&o[l][g]<f[l]&&d.push(o[l][g]-h[l]);p.push(d)}var v=[\"SS\"],m=[\"'use strict'\"],y=[];for(g=0;g<r;++g)y.push([\"s\",g,\"=SS[\",g,\"]\"].join(\"\"));for(l=0;l<t.arrayArgs.length;++l){for(v.push(\"a\"+l),v.push(\"t\"+l),v.push(\"p\"+l),g=0;g<r;++g)y.push([\"t\",l,\"p\",g,\"=t\",l,\"[\",h[l]+g,\"]\"].join(\"\"));for(g=0;g<Math.abs(t.arrayBlockIndices[l]);++g)y.push([\"t\",l,\"b\",g,\"=t\",l,\"[\",c[l]+g,\"]\"].join(\"\"))}for(l=0;l<t.scalarArgs.length;++l)v.push(\"Y\"+l);if(t.shapeArgs.length>0&&y.push(\"shape=SS.slice(0)\"),t.indexArgs.length>0){var x=new Array(r);for(l=0;l<r;++l)x[l]=\"0\";y.push([\"index=[\",x.join(\",\"),\"]\"].join(\"\"))}for(l=0;l<t.offsetArgs.length;++l){var b=t.offsetArgs[l],_=[];for(g=0;g<b.offset.length;++g)0!==b.offset[g]&&(1===b.offset[g]?_.push([\"t\",b.array,\"p\",g].join(\"\")):_.push([b.offset[g],\"*t\",b.array,\"p\",g].join(\"\")));0===_.length?y.push(\"q\"+l+\"=0\"):y.push([\"q\",l,\"=\",_.join(\"+\")].join(\"\"))}var w=n([].concat(t.pre.thisVars).concat(t.body.thisVars).concat(t.post.thisVars));for((y=y.concat(w)).length>0&&m.push(\"var \"+y.join(\",\")),l=0;l<t.arrayArgs.length;++l)m.push(\"p\"+l+\"|=0\");t.pre.body.length>3&&m.push(a(t.pre,t,s));var k=a(t.body,t,s),T=function(t){for(var e=0,r=t[0].length;e<r;){for(var n=1;n<t.length;++n)if(t[n][e]!==t[0][e])return e;++e}return e}(p);T<r?m.push(function(t,e,r,n){for(var a=e.length,o=r.arrayArgs.length,s=r.blockSize,l=r.indexArgs.length>0,c=[],u=0;u<o;++u)c.push([\"var offset\",u,\"=p\",u].join(\"\"));for(u=t;u<a;++u)c.push([\"for(var j\"+u+\"=SS[\",e[u],\"]|0;j\",u,\">0;){\"].join(\"\")),c.push([\"if(j\",u,\"<\",s,\"){\"].join(\"\")),c.push([\"s\",e[u],\"=j\",u].join(\"\")),c.push([\"j\",u,\"=0\"].join(\"\")),c.push([\"}else{s\",e[u],\"=\",s].join(\"\")),c.push([\"j\",u,\"-=\",s,\"}\"].join(\"\")),l&&c.push([\"index[\",e[u],\"]=j\",u].join(\"\"));for(u=0;u<o;++u){for(var h=[\"offset\"+u],f=t;f<a;++f)h.push([\"j\",f,\"*t\",u,\"p\",e[f]].join(\"\"));c.push([\"p\",u,\"=(\",h.join(\"+\"),\")\"].join(\"\"))}for(c.push(i(e,r,n)),u=t;u<a;++u)c.push(\"}\");return c.join(\"\\n\")}(T,p[0],t,k)):m.push(i(p[0],t,k)),t.post.body.length>3&&m.push(a(t.post,t,s)),t.debug&&console.log(\"-----Generated cwise routine for \",e,\":\\n\"+m.join(\"\\n\")+\"\\n----------\");var A=[t.funcName||\"unnamed\",\"_cwise_loop_\",o[0].join(\"s\"),\"m\",T,function(t){for(var e=new Array(t.length),r=!0,n=0;n<t.length;++n){var i=t[n],a=i.match(/\\d+/);a=a?a[0]:\"\",0===i.charAt(0)?e[n]=\"u\"+i.charAt(1)+a:e[n]=i.charAt(0)+a,n>0&&(r=r&&e[n]===e[n-1])}return r?e[0]:e.join(\"\")}(s)].join(\"\");return new Function([\"function \",A,\"(\",v.join(\",\"),\"){\",m.join(\"\\n\"),\"} return \",A].join(\"\"))()}},{uniq:547}],148:[function(t,e,r){\"use strict\";var n=t(\"./compile.js\");e.exports=function(t){var e=[\"'use strict'\",\"var CACHED={}\"],r=[],i=t.funcName+\"_cwise_thunk\";e.push([\"return function \",i,\"(\",t.shimArgs.join(\",\"),\"){\"].join(\"\"));for(var a=[],o=[],s=[[\"array\",t.arrayArgs[0],\".shape.slice(\",Math.max(0,t.arrayBlockIndices[0]),t.arrayBlockIndices[0]<0?\",\"+t.arrayBlockIndices[0]+\")\":\")\"].join(\"\")],l=[],c=[],u=0;u<t.arrayArgs.length;++u){var h=t.arrayArgs[u];r.push([\"t\",h,\"=array\",h,\".dtype,\",\"r\",h,\"=array\",h,\".order\"].join(\"\")),a.push(\"t\"+h),a.push(\"r\"+h),o.push(\"t\"+h),o.push(\"r\"+h+\".join()\"),s.push(\"array\"+h+\".data\"),s.push(\"array\"+h+\".stride\"),s.push(\"array\"+h+\".offset|0\"),u>0&&(l.push(\"array\"+t.arrayArgs[0]+\".shape.length===array\"+h+\".shape.length+\"+(Math.abs(t.arrayBlockIndices[0])-Math.abs(t.arrayBlockIndices[u]))),c.push(\"array\"+t.arrayArgs[0]+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[0])+\"]===array\"+h+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[u])+\"]\"))}for(t.arrayArgs.length>1&&(e.push(\"if (!(\"+l.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same dimensionality!')\"),e.push(\"for(var shapeIndex=array\"+t.arrayArgs[0]+\".shape.length-\"+Math.abs(t.arrayBlockIndices[0])+\"; shapeIndex--\\x3e0;) {\"),e.push(\"if (!(\"+c.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same shape!')\"),e.push(\"}\")),u=0;u<t.scalarArgs.length;++u)s.push(\"scalar\"+t.scalarArgs[u]);return r.push([\"type=[\",o.join(\",\"),\"].join()\"].join(\"\")),r.push(\"proc=CACHED[type]\"),e.push(\"var \"+r.join(\",\")),e.push([\"if(!proc){\",\"CACHED[type]=proc=compile([\",a.join(\",\"),\"])}\",\"return proc(\",s.join(\",\"),\")}\"].join(\"\")),t.debug&&console.log(\"-----Generated thunk:\\n\"+e.join(\"\\n\")+\"\\n----------\"),new Function(\"compile\",e.join(\"\\n\"))(n.bind(void 0,t))}},{\"./compile.js\":147}],149:[function(t,e,r){e.exports=t(\"cwise-compiler\")},{\"cwise-compiler\":146}],150:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/copy\"),a=t(\"es5-ext/object/normalize-options\"),o=t(\"es5-ext/object/valid-callable\"),s=t(\"es5-ext/object/map\"),l=t(\"es5-ext/object/valid-callable\"),c=t(\"es5-ext/object/valid-value\"),u=Function.prototype.bind,h=Object.defineProperty,f=Object.prototype.hasOwnProperty;n=function(t,e,r){var n,a=c(e)&&l(e.value);return delete(n=i(e)).writable,delete n.value,n.get=function(){return!r.overwriteDefinition&&f.call(this,t)?a:(e.value=u.call(a,r.resolveContext?r.resolveContext(this):this),h(this,t,e),this[t])},n},e.exports=function(t){var e=a(arguments[1]);return null!=e.resolveContext&&o(e.resolveContext),s(t,function(t,r){return n(r,t,e)})}},{\"es5-ext/object/copy\":189,\"es5-ext/object/map\":198,\"es5-ext/object/normalize-options\":199,\"es5-ext/object/valid-callable\":203,\"es5-ext/object/valid-value\":205}],151:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/object/assign\"),i=t(\"es5-ext/object/normalize-options\"),a=t(\"es5-ext/object/is-callable\"),o=t(\"es5-ext/string/#/contains\");(e.exports=function(t,e){var r,a,s,l,c;return arguments.length<2||\"string\"!=typeof t?(l=e,e=t,t=null):l=arguments[2],null==t?(r=s=!0,a=!1):(r=o.call(t,\"c\"),a=o.call(t,\"e\"),s=o.call(t,\"w\")),c={value:e,configurable:r,enumerable:a,writable:s},l?n(i(l),c):c}).gs=function(t,e,r){var s,l,c,u;return\"string\"!=typeof t?(c=r,r=e,e=t,t=null):c=arguments[3],null==e?e=void 0:a(e)?null==r?r=void 0:a(r)||(c=r,r=void 0):(c=e,e=r=void 0),null==t?(s=!0,l=!1):(s=o.call(t,\"c\"),l=o.call(t,\"e\")),u={get:e,set:r,configurable:s,enumerable:l},c?n(i(c),u):u}},{\"es5-ext/object/assign\":186,\"es5-ext/object/is-callable\":192,\"es5-ext/object/normalize-options\":199,\"es5-ext/string/#/contains\":206}],152:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function r(t){var r;return 1===t.length&&(r=t,t=function(t,n){return e(r(t),n)}),{left:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}var n=r(e),i=n.right,a=n.left;function o(t,e){return[t,e]}function s(t){return null===t?NaN:+t}function l(t,e){var r,n,i=t.length,a=0,o=-1,l=0,c=0;if(null==e)for(;++o<i;)isNaN(r=s(t[o]))||(c+=(n=r-l)*(r-(l+=n/++a)));else for(;++o<i;)isNaN(r=s(e(t[o],o,t)))||(c+=(n=r-l)*(r-(l+=n/++a)));if(a>1)return c/(a-1)}function c(t,e){var r=l(t,e);return r?Math.sqrt(r):r}function u(t,e){var r,n,i,a=t.length,o=-1;if(null==e){for(;++o<a;)if(null!=(r=t[o])&&r>=r)for(n=i=r;++o<a;)null!=(r=t[o])&&(n>r&&(n=r),i<r&&(i=r))}else for(;++o<a;)if(null!=(r=e(t[o],o,t))&&r>=r)for(n=i=r;++o<a;)null!=(r=e(t[o],o,t))&&(n>r&&(n=r),i<r&&(i=r));return[n,i]}var h=Array.prototype,f=h.slice,p=h.map;function d(t){return function(){return t}}function g(t){return t}function v(t,e,r){t=+t,e=+e,r=(i=arguments.length)<2?(e=t,t=0,1):i<3?1:+r;for(var n=-1,i=0|Math.max(0,Math.ceil((e-t)/r)),a=new Array(i);++n<i;)a[n]=t+n*r;return a}var m=Math.sqrt(50),y=Math.sqrt(10),x=Math.sqrt(2);function b(t,e,r){var n=(e-t)/Math.max(0,r),i=Math.floor(Math.log(n)/Math.LN10),a=n/Math.pow(10,i);return i>=0?(a>=m?10:a>=y?5:a>=x?2:1)*Math.pow(10,i):-Math.pow(10,-i)/(a>=m?10:a>=y?5:a>=x?2:1)}function _(t,e,r){var n=Math.abs(e-t)/Math.max(0,r),i=Math.pow(10,Math.floor(Math.log(n)/Math.LN10)),a=n/i;return a>=m?i*=10:a>=y?i*=5:a>=x&&(i*=2),e<t?-i:i}function w(t){return Math.ceil(Math.log(t.length)/Math.LN2)+1}function k(t,e,r){if(null==r&&(r=s),n=t.length){if((e=+e)<=0||n<2)return+r(t[0],0,t);if(e>=1)return+r(t[n-1],n-1,t);var n,i=(n-1)*e,a=Math.floor(i),o=+r(t[a],a,t);return o+(+r(t[a+1],a+1,t)-o)*(i-a)}}function T(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&n>r&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&n>r&&(n=r);return n}function A(t){if(!(i=t.length))return[];for(var e=-1,r=T(t,M),n=new Array(r);++e<r;)for(var i,a=-1,o=n[e]=new Array(i);++a<i;)o[a]=t[a][e];return n}function M(t){return t.length}t.bisect=i,t.bisectRight=i,t.bisectLeft=a,t.ascending=e,t.bisector=r,t.cross=function(t,e,r){var n,i,a,s,l=t.length,c=e.length,u=new Array(l*c);for(null==r&&(r=o),n=a=0;n<l;++n)for(s=t[n],i=0;i<c;++i,++a)u[a]=r(s,e[i]);return u},t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.deviation=c,t.extent=u,t.histogram=function(){var t=g,e=u,r=w;function n(n){var a,o,s=n.length,l=new Array(s);for(a=0;a<s;++a)l[a]=t(n[a],a,n);var c=e(l),u=c[0],h=c[1],f=r(l,u,h);Array.isArray(f)||(f=_(u,h,f),f=v(Math.ceil(u/f)*f,h,f));for(var p=f.length;f[0]<=u;)f.shift(),--p;for(;f[p-1]>h;)f.pop(),--p;var d,g=new Array(p+1);for(a=0;a<=p;++a)(d=g[a]=[]).x0=a>0?f[a-1]:u,d.x1=a<p?f[a]:h;for(a=0;a<s;++a)u<=(o=l[a])&&o<=h&&g[i(f,o,0,p)].push(n[a]);return g}return n.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:d(e),n):t},n.domain=function(t){return arguments.length?(e=\"function\"==typeof t?t:d([t[0],t[1]]),n):e},n.thresholds=function(t){return arguments.length?(r=\"function\"==typeof t?t:Array.isArray(t)?d(f.call(t)):d(t),n):r},n},t.thresholdFreedmanDiaconis=function(t,r,n){return t=p.call(t,s).sort(e),Math.ceil((n-r)/(2*(k(t,.75)-k(t,.25))*Math.pow(t.length,-1/3)))},t.thresholdScott=function(t,e,r){return Math.ceil((r-e)/(3.5*c(t)*Math.pow(t.length,-1/3)))},t.thresholdSturges=w,t.max=function(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&r>n&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&r>n&&(n=r);return n},t.mean=function(t,e){var r,n=t.length,i=n,a=-1,o=0;if(null==e)for(;++a<n;)isNaN(r=s(t[a]))?--i:o+=r;else for(;++a<n;)isNaN(r=s(e(t[a],a,t)))?--i:o+=r;if(i)return o/i},t.median=function(t,r){var n,i=t.length,a=-1,o=[];if(null==r)for(;++a<i;)isNaN(n=s(t[a]))||o.push(n);else for(;++a<i;)isNaN(n=s(r(t[a],a,t)))||o.push(n);return k(o.sort(e),.5)},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r},t.min=T,t.pairs=function(t,e){null==e&&(e=o);for(var r=0,n=t.length-1,i=t[0],a=new Array(n<0?0:n);r<n;)a[r]=e(i,i=t[++r]);return a},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.quantile=k,t.range=v,t.scan=function(t,r){if(n=t.length){var n,i,a=0,o=0,s=t[o];for(null==r&&(r=e);++a<n;)(r(i=t[a],s)<0||0!==r(s,s))&&(s=i,o=a);return 0===r(s,s)?o:void 0}},t.shuffle=function(t,e,r){for(var n,i,a=(null==r?t.length:r)-(e=null==e?0:+e);a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.sum=function(t,e){var r,n=t.length,i=-1,a=0;if(null==e)for(;++i<n;)(r=+t[i])&&(a+=r);else for(;++i<n;)(r=+e(t[i],i,t))&&(a+=r);return a},t.ticks=function(t,e,r){var n,i,a,o,s=-1;if(r=+r,(t=+t)==(e=+e)&&r>0)return[t];if((n=e<t)&&(i=t,t=e,e=i),0===(o=b(t,e,r))||!isFinite(o))return[];if(o>0)for(t=Math.ceil(t/o),e=Math.floor(e/o),a=new Array(i=Math.ceil(e-t+1));++s<i;)a[s]=(t+s)*o;else for(t=Math.floor(t*o),e=Math.ceil(e*o),a=new Array(i=Math.ceil(t-e+1));++s<i;)a[s]=(t-s)/o;return n&&a.reverse(),a},t.tickIncrement=b,t.tickStep=_,t.transpose=A,t.variance=l,t.zip=function(){return A(arguments)},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],153:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(){}function r(t,r){var n=new e;if(t instanceof e)t.each(function(t,e){n.set(e,t)});else if(Array.isArray(t)){var i,a=-1,o=t.length;if(null==r)for(;++a<o;)n.set(a,t[a]);else for(;++a<o;)n.set(r(i=t[a],a,t),i)}else if(t)for(var s in t)n.set(s,t[s]);return n}e.prototype=r.prototype={constructor:e,has:function(t){return\"$\"+t in this},get:function(t){return this[\"$\"+t]},set:function(t,e){return this[\"$\"+t]=e,this},remove:function(t){var e=\"$\"+t;return e in this&&delete this[e]},clear:function(){for(var t in this)\"$\"===t[0]&&delete this[t]},keys:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(e.slice(1));return t},values:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(this[e]);return t},entries:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push({key:e.slice(1),value:this[e]});return t},size:function(){var t=0;for(var e in this)\"$\"===e[0]&&++t;return t},empty:function(){for(var t in this)if(\"$\"===t[0])return!1;return!0},each:function(t){for(var e in this)\"$\"===e[0]&&t(this[e],e.slice(1),this)}};function n(){return{}}function i(t,e,r){t[e]=r}function a(){return r()}function o(t,e,r){t.set(e,r)}function s(){}var l=r.prototype;function c(t,e){var r=new s;if(t instanceof s)t.each(function(t){r.add(t)});else if(t){var n=-1,i=t.length;if(null==e)for(;++n<i;)r.add(t[n]);else for(;++n<i;)r.add(e(t[n],n,t))}return r}s.prototype=c.prototype={constructor:s,has:l.has,add:function(t){return this[\"$\"+(t+=\"\")]=t,this},remove:l.remove,clear:l.clear,values:l.keys,size:l.size,empty:l.empty,each:l.each};t.nest=function(){var t,e,s,l=[],c=[];function u(n,i,a,o){if(i>=l.length)return null!=t&&n.sort(t),null!=e?e(n):n;for(var s,c,h,f=-1,p=n.length,d=l[i++],g=r(),v=a();++f<p;)(h=g.get(s=d(c=n[f])+\"\"))?h.push(c):g.set(s,[c]);return g.each(function(t,e){o(v,e,u(t,i,a,o))}),v}return s={object:function(t){return u(t,0,n,i)},map:function(t){return u(t,0,a,o)},entries:function(t){return function t(r,n){if(++n>l.length)return r;var i,a=c[n-1];return null!=e&&n>=l.length?i=r.entries():(i=[],r.each(function(e,r){i.push({key:r,values:t(e,n)})})),null!=a?i.sort(function(t,e){return a(t.key,e.key)}):i}(u(t,0,a,o),0)},key:function(t){return l.push(t),s},sortKeys:function(t){return c[l.length-1]=t,s},sortValues:function(e){return t=e,s},rollup:function(t){return e=t,s}}},t.set=c,t.map=r,t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],154:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e,r){t.prototype=e.prototype=r,r.constructor=t}function r(t,e){var r=Object.create(t.prototype);for(var n in e)r[n]=e[n];return r}function n(){}var i=\"\\\\s*([+-]?\\\\d+)\\\\s*\",a=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)\\\\s*\",o=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)%\\\\s*\",s=/^#([0-9a-f]{3})$/,l=/^#([0-9a-f]{6})$/,c=new RegExp(\"^rgb\\\\(\"+[i,i,i]+\"\\\\)$\"),u=new RegExp(\"^rgb\\\\(\"+[o,o,o]+\"\\\\)$\"),h=new RegExp(\"^rgba\\\\(\"+[i,i,i,a]+\"\\\\)$\"),f=new RegExp(\"^rgba\\\\(\"+[o,o,o,a]+\"\\\\)$\"),p=new RegExp(\"^hsl\\\\(\"+[a,o,o]+\"\\\\)$\"),d=new RegExp(\"^hsla\\\\(\"+[a,o,o,a]+\"\\\\)$\"),g={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};function v(t){var e;return t=(t+\"\").trim().toLowerCase(),(e=s.exec(t))?new _((e=parseInt(e[1],16))>>8&15|e>>4&240,e>>4&15|240&e,(15&e)<<4|15&e,1):(e=l.exec(t))?m(parseInt(e[1],16)):(e=c.exec(t))?new _(e[1],e[2],e[3],1):(e=u.exec(t))?new _(255*e[1]/100,255*e[2]/100,255*e[3]/100,1):(e=h.exec(t))?y(e[1],e[2],e[3],e[4]):(e=f.exec(t))?y(255*e[1]/100,255*e[2]/100,255*e[3]/100,e[4]):(e=p.exec(t))?k(e[1],e[2]/100,e[3]/100,1):(e=d.exec(t))?k(e[1],e[2]/100,e[3]/100,e[4]):g.hasOwnProperty(t)?m(g[t]):\"transparent\"===t?new _(NaN,NaN,NaN,0):null}function m(t){return new _(t>>16&255,t>>8&255,255&t,1)}function y(t,e,r,n){return n<=0&&(t=e=r=NaN),new _(t,e,r,n)}function x(t){return t instanceof n||(t=v(t)),t?new _((t=t.rgb()).r,t.g,t.b,t.opacity):new _}function b(t,e,r,n){return 1===arguments.length?x(t):new _(t,e,r,null==n?1:n)}function _(t,e,r,n){this.r=+t,this.g=+e,this.b=+r,this.opacity=+n}function w(t){return((t=Math.max(0,Math.min(255,Math.round(t)||0)))<16?\"0\":\"\")+t.toString(16)}function k(t,e,r,n){return n<=0?t=e=r=NaN:r<=0||r>=1?t=e=NaN:e<=0&&(t=NaN),new A(t,e,r,n)}function T(t,e,r,i){return 1===arguments.length?function(t){if(t instanceof A)return new A(t.h,t.s,t.l,t.opacity);if(t instanceof n||(t=v(t)),!t)return new A;if(t instanceof A)return t;var e=(t=t.rgb()).r/255,r=t.g/255,i=t.b/255,a=Math.min(e,r,i),o=Math.max(e,r,i),s=NaN,l=o-a,c=(o+a)/2;return l?(s=e===o?(r-i)/l+6*(r<i):r===o?(i-e)/l+2:(e-r)/l+4,l/=c<.5?o+a:2-o-a,s*=60):l=c>0&&c<1?0:s,new A(s,l,c,t.opacity)}(t):new A(t,e,r,null==i?1:i)}function A(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}function M(t,e,r){return 255*(t<60?e+(r-e)*t/60:t<180?r:t<240?e+(r-e)*(240-t)/60:e)}e(n,v,{displayable:function(){return this.rgb().displayable()},hex:function(){return this.rgb().hex()},toString:function(){return this.rgb()+\"\"}}),e(_,b,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new _(this.r*t,this.g*t,this.b*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new _(this.r*t,this.g*t,this.b*t,this.opacity)},rgb:function(){return this},displayable:function(){return 0<=this.r&&this.r<=255&&0<=this.g&&this.g<=255&&0<=this.b&&this.b<=255&&0<=this.opacity&&this.opacity<=1},hex:function(){return\"#\"+w(this.r)+w(this.g)+w(this.b)},toString:function(){var t=this.opacity;return(1===(t=isNaN(t)?1:Math.max(0,Math.min(1,t)))?\"rgb(\":\"rgba(\")+Math.max(0,Math.min(255,Math.round(this.r)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.g)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.b)||0))+(1===t?\")\":\", \"+t+\")\")}})),e(A,T,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new A(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new A(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=this.h%360+360*(this.h<0),e=isNaN(t)||isNaN(this.s)?0:this.s,r=this.l,n=r+(r<.5?r:1-r)*e,i=2*r-n;return new _(M(t>=240?t-240:t+120,i,n),M(t,i,n),M(t<120?t+240:t-120,i,n),this.opacity)},displayable:function(){return(0<=this.s&&this.s<=1||isNaN(this.s))&&0<=this.l&&this.l<=1&&0<=this.opacity&&this.opacity<=1}}));var S=Math.PI/180,E=180/Math.PI,C=.96422,L=1,P=.82521,O=4/29,z=6/29,I=3*z*z,D=z*z*z;function R(t){if(t instanceof B)return new B(t.l,t.a,t.b,t.opacity);if(t instanceof G){if(isNaN(t.h))return new B(t.l,0,0,t.opacity);var e=t.h*S;return new B(t.l,Math.cos(e)*t.c,Math.sin(e)*t.c,t.opacity)}t instanceof _||(t=x(t));var r,n,i=V(t.r),a=V(t.g),o=V(t.b),s=N((.2225045*i+.7168786*a+.0606169*o)/L);return i===a&&a===o?r=n=s:(r=N((.4360747*i+.3850649*a+.1430804*o)/C),n=N((.0139322*i+.0971045*a+.7141733*o)/P)),new B(116*s-16,500*(r-s),200*(s-n),t.opacity)}function F(t,e,r,n){return 1===arguments.length?R(t):new B(t,e,r,null==n?1:n)}function B(t,e,r,n){this.l=+t,this.a=+e,this.b=+r,this.opacity=+n}function N(t){return t>D?Math.pow(t,1/3):t/I+O}function j(t){return t>z?t*t*t:I*(t-O)}function U(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function V(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function q(t){if(t instanceof G)return new G(t.h,t.c,t.l,t.opacity);if(t instanceof B||(t=R(t)),0===t.a&&0===t.b)return new G(NaN,0,t.l,t.opacity);var e=Math.atan2(t.b,t.a)*E;return new G(e<0?e+360:e,Math.sqrt(t.a*t.a+t.b*t.b),t.l,t.opacity)}function H(t,e,r,n){return 1===arguments.length?q(t):new G(t,e,r,null==n?1:n)}function G(t,e,r,n){this.h=+t,this.c=+e,this.l=+r,this.opacity=+n}e(B,F,r(n,{brighter:function(t){return new B(this.l+18*(null==t?1:t),this.a,this.b,this.opacity)},darker:function(t){return new B(this.l-18*(null==t?1:t),this.a,this.b,this.opacity)},rgb:function(){var t=(this.l+16)/116,e=isNaN(this.a)?t:t+this.a/500,r=isNaN(this.b)?t:t-this.b/200;return new _(U(3.1338561*(e=C*j(e))-1.6168667*(t=L*j(t))-.4906146*(r=P*j(r))),U(-.9787684*e+1.9161415*t+.033454*r),U(.0719453*e-.2289914*t+1.4052427*r),this.opacity)}})),e(G,H,r(n,{brighter:function(t){return new G(this.h,this.c,this.l+18*(null==t?1:t),this.opacity)},darker:function(t){return new G(this.h,this.c,this.l-18*(null==t?1:t),this.opacity)},rgb:function(){return R(this).rgb()}}));var Y=-.14861,W=1.78277,X=-.29227,Z=-.90649,J=1.97294,K=J*Z,$=J*W,Q=W*X-Z*Y;function tt(t,e,r,n){return 1===arguments.length?function(t){if(t instanceof et)return new et(t.h,t.s,t.l,t.opacity);t instanceof _||(t=x(t));var e=t.r/255,r=t.g/255,n=t.b/255,i=(Q*n+K*e-$*r)/(Q+K-$),a=n-i,o=(J*(r-i)-X*a)/Z,s=Math.sqrt(o*o+a*a)/(J*i*(1-i)),l=s?Math.atan2(o,a)*E-120:NaN;return new et(l<0?l+360:l,s,i,t.opacity)}(t):new et(t,e,r,null==n?1:n)}function et(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}e(et,tt,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new et(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new et(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=isNaN(this.h)?0:(this.h+120)*S,e=+this.l,r=isNaN(this.s)?0:this.s*e*(1-e),n=Math.cos(t),i=Math.sin(t);return new _(255*(e+r*(Y*n+W*i)),255*(e+r*(X*n+Z*i)),255*(e+r*(J*n)),this.opacity)}})),t.color=v,t.rgb=b,t.hsl=T,t.lab=F,t.hcl=H,t.lch=function(t,e,r,n){return 1===arguments.length?q(t):new G(r,e,t,null==n?1:n)},t.gray=function(t,e){return new B(t,0,0,null==e?1:e)},t.cubehelix=tt,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],155:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e={value:function(){}};function r(){for(var t,e=0,r=arguments.length,i={};e<r;++e){if(!(t=arguments[e]+\"\")||t in i)throw new Error(\"illegal type: \"+t);i[t]=[]}return new n(i)}function n(t){this._=t}function i(t,e){for(var r,n=0,i=t.length;n<i;++n)if((r=t[n]).name===e)return r.value}function a(t,r,n){for(var i=0,a=t.length;i<a;++i)if(t[i].name===r){t[i]=e,t=t.slice(0,i).concat(t.slice(i+1));break}return null!=n&&t.push({name:r,value:n}),t}n.prototype=r.prototype={constructor:n,on:function(t,e){var r,n,o=this._,s=(n=o,(t+\"\").trim().split(/^|\\s+/).map(function(t){var e=\"\",r=t.indexOf(\".\");if(r>=0&&(e=t.slice(r+1),t=t.slice(0,r)),t&&!n.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);return{type:t,name:e}})),l=-1,c=s.length;if(!(arguments.length<2)){if(null!=e&&\"function\"!=typeof e)throw new Error(\"invalid callback: \"+e);for(;++l<c;)if(r=(t=s[l]).type)o[r]=a(o[r],t.name,e);else if(null==e)for(r in o)o[r]=a(o[r],t.name,null);return this}for(;++l<c;)if((r=(t=s[l]).type)&&(r=i(o[r],t.name)))return r},copy:function(){var t={},e=this._;for(var r in e)t[r]=e[r].slice();return new n(t)},call:function(t,e){if((r=arguments.length-2)>0)for(var r,n,i=new Array(r),a=0;a<r;++a)i[a]=arguments[a+2];if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(a=0,r=(n=this._[t]).length;a<r;++a)n[a].value.apply(e,i)},apply:function(t,e,r){if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(var n=this._[t],i=0,a=n.length;i<a;++i)n[i].value.apply(e,r)}},t.dispatch=r,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],156:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n,i){\"use strict\";var a=function(t){return function(){return t}},o=function(){return 1e-6*(Math.random()-.5)};function s(t){return t.x+t.vx}function l(t){return t.y+t.vy}function c(t){return t.index}function u(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function h(t){return t.x}function f(t){return t.y}var p=10,d=Math.PI*(3-Math.sqrt(5));t.forceCenter=function(t,e){var r;function n(){var n,i,a=r.length,o=0,s=0;for(n=0;n<a;++n)o+=(i=r[n]).x,s+=i.y;for(o=o/a-t,s=s/a-e,n=0;n<a;++n)(i=r[n]).x-=o,i.y-=s}return null==t&&(t=0),null==e&&(e=0),n.initialize=function(t){r=t},n.x=function(e){return arguments.length?(t=+e,n):t},n.y=function(t){return arguments.length?(e=+t,n):e},n},t.forceCollide=function(t){var r,n,i=1,c=1;function u(){for(var t,a,u,f,p,d,g,v=r.length,m=0;m<c;++m)for(a=e.quadtree(r,s,l).visitAfter(h),t=0;t<v;++t)u=r[t],d=n[u.index],g=d*d,f=u.x+u.vx,p=u.y+u.vy,a.visit(y);function y(t,e,r,n,a){var s=t.data,l=t.r,c=d+l;if(!s)return e>f+c||n<f-c||r>p+c||a<p-c;if(s.index>u.index){var h=f-s.x-s.vx,v=p-s.y-s.vy,m=h*h+v*v;m<c*c&&(0===h&&(m+=(h=o())*h),0===v&&(m+=(v=o())*v),m=(c-(m=Math.sqrt(m)))/m*i,u.vx+=(h*=m)*(c=(l*=l)/(g+l)),u.vy+=(v*=m)*c,s.vx-=h*(c=1-c),s.vy-=v*c)}}}function h(t){if(t.data)return t.r=n[t.data.index];for(var e=t.r=0;e<4;++e)t[e]&&t[e].r>t.r&&(t.r=t[e].r)}function f(){if(r){var e,i,a=r.length;for(n=new Array(a),e=0;e<a;++e)i=r[e],n[i.index]=+t(i,e,r)}}return\"function\"!=typeof t&&(t=a(null==t?1:+t)),u.initialize=function(t){r=t,f()},u.iterations=function(t){return arguments.length?(c=+t,u):c},u.strength=function(t){return arguments.length?(i=+t,u):i},u.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),f(),u):t},u},t.forceLink=function(t){var e,n,i,s,l,h=c,f=function(t){return 1/Math.min(s[t.source.index],s[t.target.index])},p=a(30),d=1;function g(r){for(var i=0,a=t.length;i<d;++i)for(var s,c,u,h,f,p,g,v=0;v<a;++v)c=(s=t[v]).source,h=(u=s.target).x+u.vx-c.x-c.vx||o(),f=u.y+u.vy-c.y-c.vy||o(),h*=p=((p=Math.sqrt(h*h+f*f))-n[v])/p*r*e[v],f*=p,u.vx-=h*(g=l[v]),u.vy-=f*g,c.vx+=h*(g=1-g),c.vy+=f*g}function v(){if(i){var a,o,c=i.length,f=t.length,p=r.map(i,h);for(a=0,s=new Array(c);a<f;++a)(o=t[a]).index=a,\"object\"!=typeof o.source&&(o.source=u(p,o.source)),\"object\"!=typeof o.target&&(o.target=u(p,o.target)),s[o.source.index]=(s[o.source.index]||0)+1,s[o.target.index]=(s[o.target.index]||0)+1;for(a=0,l=new Array(f);a<f;++a)o=t[a],l[a]=s[o.source.index]/(s[o.source.index]+s[o.target.index]);e=new Array(f),m(),n=new Array(f),y()}}function m(){if(i)for(var r=0,n=t.length;r<n;++r)e[r]=+f(t[r],r,t)}function y(){if(i)for(var e=0,r=t.length;e<r;++e)n[e]=+p(t[e],e,t)}return null==t&&(t=[]),g.initialize=function(t){i=t,v()},g.links=function(e){return arguments.length?(t=e,v(),g):t},g.id=function(t){return arguments.length?(h=t,g):h},g.iterations=function(t){return arguments.length?(d=+t,g):d},g.strength=function(t){return arguments.length?(f=\"function\"==typeof t?t:a(+t),m(),g):f},g.distance=function(t){return arguments.length?(p=\"function\"==typeof t?t:a(+t),y(),g):p},g},t.forceManyBody=function(){var t,r,n,i,s=a(-30),l=1,c=1/0,u=.81;function p(i){var a,o=t.length,s=e.quadtree(t,h,f).visitAfter(g);for(n=i,a=0;a<o;++a)r=t[a],s.visit(v)}function d(){if(t){var e,r,n=t.length;for(i=new Array(n),e=0;e<n;++e)r=t[e],i[r.index]=+s(r,e,t)}}function g(t){var e,r,n,a,o,s=0,l=0;if(t.length){for(n=a=o=0;o<4;++o)(e=t[o])&&(r=Math.abs(e.value))&&(s+=e.value,l+=r,n+=r*e.x,a+=r*e.y);t.x=n/l,t.y=a/l}else{(e=t).x=e.data.x,e.y=e.data.y;do{s+=i[e.data.index]}while(e=e.next)}t.value=s}function v(t,e,a,s){if(!t.value)return!0;var h=t.x-r.x,f=t.y-r.y,p=s-e,d=h*h+f*f;if(p*p/u<d)return d<c&&(0===h&&(d+=(h=o())*h),0===f&&(d+=(f=o())*f),d<l&&(d=Math.sqrt(l*d)),r.vx+=h*t.value*n/d,r.vy+=f*t.value*n/d),!0;if(!(t.length||d>=c)){(t.data!==r||t.next)&&(0===h&&(d+=(h=o())*h),0===f&&(d+=(f=o())*f),d<l&&(d=Math.sqrt(l*d)));do{t.data!==r&&(p=i[t.data.index]*n/d,r.vx+=h*p,r.vy+=f*p)}while(t=t.next)}}return p.initialize=function(e){t=e,d()},p.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),d(),p):s},p.distanceMin=function(t){return arguments.length?(l=t*t,p):Math.sqrt(l)},p.distanceMax=function(t){return arguments.length?(c=t*t,p):Math.sqrt(c)},p.theta=function(t){return arguments.length?(u=t*t,p):Math.sqrt(u)},p},t.forceRadial=function(t,e,r){var n,i,o,s=a(.1);function l(t){for(var a=0,s=n.length;a<s;++a){var l=n[a],c=l.x-e||1e-6,u=l.y-r||1e-6,h=Math.sqrt(c*c+u*u),f=(o[a]-h)*i[a]*t/h;l.vx+=c*f,l.vy+=u*f}}function c(){if(n){var e,r=n.length;for(i=new Array(r),o=new Array(r),e=0;e<r;++e)o[e]=+t(n[e],e,n),i[e]=isNaN(o[e])?0:+s(n[e],e,n)}}return\"function\"!=typeof t&&(t=a(+t)),null==e&&(e=0),null==r&&(r=0),l.initialize=function(t){n=t,c()},l.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),c(),l):s},l.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),c(),l):t},l.x=function(t){return arguments.length?(e=+t,l):e},l.y=function(t){return arguments.length?(r=+t,l):r},l},t.forceSimulation=function(t){var e,a=1,o=.001,s=1-Math.pow(o,1/300),l=0,c=.6,u=r.map(),h=i.timer(g),f=n.dispatch(\"tick\",\"end\");function g(){v(),f.call(\"tick\",e),a<o&&(h.stop(),f.call(\"end\",e))}function v(){var e,r,n=t.length;for(a+=(l-a)*s,u.each(function(t){t(a)}),e=0;e<n;++e)null==(r=t[e]).fx?r.x+=r.vx*=c:(r.x=r.fx,r.vx=0),null==r.fy?r.y+=r.vy*=c:(r.y=r.fy,r.vy=0)}function m(){for(var e,r=0,n=t.length;r<n;++r){if((e=t[r]).index=r,isNaN(e.x)||isNaN(e.y)){var i=p*Math.sqrt(r),a=r*d;e.x=i*Math.cos(a),e.y=i*Math.sin(a)}(isNaN(e.vx)||isNaN(e.vy))&&(e.vx=e.vy=0)}}function y(e){return e.initialize&&e.initialize(t),e}return null==t&&(t=[]),m(),e={tick:v,restart:function(){return h.restart(g),e},stop:function(){return h.stop(),e},nodes:function(r){return arguments.length?(t=r,m(),u.each(y),e):t},alpha:function(t){return arguments.length?(a=+t,e):a},alphaMin:function(t){return arguments.length?(o=+t,e):o},alphaDecay:function(t){return arguments.length?(s=+t,e):+s},alphaTarget:function(t){return arguments.length?(l=+t,e):l},velocityDecay:function(t){return arguments.length?(c=1-t,e):1-c},force:function(t,r){return arguments.length>1?(null==r?u.remove(t):u.set(t,y(r)),e):u.get(t)},find:function(e,r,n){var i,a,o,s,l,c=0,u=t.length;for(null==n?n=1/0:n*=n,c=0;c<u;++c)(o=(i=e-(s=t[c]).x)*i+(a=r-s.y)*a)<n&&(l=s,n=o);return l},on:function(t,r){return arguments.length>1?(f.on(t,r),e):f.on(t)}}},t.forceX=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vx+=(n[a]-i.x)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},t.forceY=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vy+=(n[a]-i.y)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.y=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-quadtree\"),t(\"d3-collection\"),t(\"d3-dispatch\"),t(\"d3-timer\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,n.d3)},{\"d3-collection\":153,\"d3-dispatch\":155,\"d3-quadtree\":160,\"d3-timer\":162}],157:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e){return t.parent===e.parent?1:2}function r(t,e){return t+e.x}function n(t,e){return Math.max(t,e.y)}function i(t){var e=0,r=t.children,n=r&&r.length;if(n)for(;--n>=0;)e+=r[n].value;else e=1;t.value=e}function a(t,e){var r,n,i,a,s,u=new c(t),h=+t.value&&(u.value=t.value),f=[u];for(null==e&&(e=o);r=f.pop();)if(h&&(r.value=+r.data.value),(i=e(r.data))&&(s=i.length))for(r.children=new Array(s),a=s-1;a>=0;--a)f.push(n=r.children[a]=new c(i[a])),n.parent=r,n.depth=r.depth+1;return u.eachBefore(l)}function o(t){return t.children}function s(t){t.data=t.data.data}function l(t){var e=0;do{t.height=e}while((t=t.parent)&&t.height<++e)}function c(t){this.data=t,this.depth=this.height=0,this.parent=null}c.prototype=a.prototype={constructor:c,count:function(){return this.eachAfter(i)},each:function(t){var e,r,n,i,a=this,o=[a];do{for(e=o.reverse(),o=[];a=e.pop();)if(t(a),r=a.children)for(n=0,i=r.length;n<i;++n)o.push(r[n])}while(o.length);return this},eachAfter:function(t){for(var e,r,n,i=this,a=[i],o=[];i=a.pop();)if(o.push(i),e=i.children)for(r=0,n=e.length;r<n;++r)a.push(e[r]);for(;i=o.pop();)t(i);return this},eachBefore:function(t){for(var e,r,n=this,i=[n];n=i.pop();)if(t(n),e=n.children)for(r=e.length-1;r>=0;--r)i.push(e[r]);return this},sum:function(t){return this.eachAfter(function(e){for(var r=+t(e.data)||0,n=e.children,i=n&&n.length;--i>=0;)r+=n[i].value;e.value=r})},sort:function(t){return this.eachBefore(function(e){e.children&&e.children.sort(t)})},path:function(t){for(var e=this,r=function(t,e){if(t===e)return t;var r=t.ancestors(),n=e.ancestors(),i=null;for(t=r.pop(),e=n.pop();t===e;)i=t,t=r.pop(),e=n.pop();return i}(e,t),n=[e];e!==r;)e=e.parent,n.push(e);for(var i=n.length;t!==r;)n.splice(i,0,t),t=t.parent;return n},ancestors:function(){for(var t=this,e=[t];t=t.parent;)e.push(t);return e},descendants:function(){var t=[];return this.each(function(e){t.push(e)}),t},leaves:function(){var t=[];return this.eachBefore(function(e){e.children||t.push(e)}),t},links:function(){var t=this,e=[];return t.each(function(r){r!==t&&e.push({source:r.parent,target:r})}),e},copy:function(){return a(this).eachBefore(s)}};var u=Array.prototype.slice;function h(t){for(var e,r,n=0,i=(t=function(t){for(var e,r,n=t.length;n;)r=Math.random()*n--|0,e=t[n],t[n]=t[r],t[r]=e;return t}(u.call(t))).length,a=[];n<i;)e=t[n],r&&d(r,e)?++n:(r=v(a=f(a,e)),n=0);return r}function f(t,e){var r,n;if(g(e,t))return[e];for(r=0;r<t.length;++r)if(p(e,t[r])&&g(m(t[r],e),t))return[t[r],e];for(r=0;r<t.length-1;++r)for(n=r+1;n<t.length;++n)if(p(m(t[r],t[n]),e)&&p(m(t[r],e),t[n])&&p(m(t[n],e),t[r])&&g(y(t[r],t[n],e),t))return[t[r],t[n],e];throw new Error}function p(t,e){var r=t.r-e.r,n=e.x-t.x,i=e.y-t.y;return r<0||r*r<n*n+i*i}function d(t,e){var r=t.r-e.r+1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function g(t,e){for(var r=0;r<e.length;++r)if(!d(t,e[r]))return!1;return!0}function v(t){switch(t.length){case 1:return{x:(e=t[0]).x,y:e.y,r:e.r};case 2:return m(t[0],t[1]);case 3:return y(t[0],t[1],t[2])}var e}function m(t,e){var r=t.x,n=t.y,i=t.r,a=e.x,o=e.y,s=e.r,l=a-r,c=o-n,u=s-i,h=Math.sqrt(l*l+c*c);return{x:(r+a+l/h*u)/2,y:(n+o+c/h*u)/2,r:(h+i+s)/2}}function y(t,e,r){var n=t.x,i=t.y,a=t.r,o=e.x,s=e.y,l=e.r,c=r.x,u=r.y,h=r.r,f=n-o,p=n-c,d=i-s,g=i-u,v=l-a,m=h-a,y=n*n+i*i-a*a,x=y-o*o-s*s+l*l,b=y-c*c-u*u+h*h,_=p*d-f*g,w=(d*b-g*x)/(2*_)-n,k=(g*v-d*m)/_,T=(p*x-f*b)/(2*_)-i,A=(f*m-p*v)/_,M=k*k+A*A-1,S=2*(a+w*k+T*A),E=w*w+T*T-a*a,C=-(M?(S+Math.sqrt(S*S-4*M*E))/(2*M):E/S);return{x:n+w+k*C,y:i+T+A*C,r:C}}function x(t,e,r){var n,i,a,o,s=t.x-e.x,l=t.y-e.y,c=s*s+l*l;c?(i=e.r+r.r,i*=i,o=t.r+r.r,i>(o*=o)?(n=(c+o-i)/(2*c),a=Math.sqrt(Math.max(0,o/c-n*n)),r.x=t.x-n*s-a*l,r.y=t.y-n*l+a*s):(n=(c+i-o)/(2*c),a=Math.sqrt(Math.max(0,i/c-n*n)),r.x=e.x+n*s-a*l,r.y=e.y+n*l+a*s)):(r.x=e.x+r.r,r.y=e.y)}function b(t,e){var r=t.r+e.r-1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function _(t){var e=t._,r=t.next._,n=e.r+r.r,i=(e.x*r.r+r.x*e.r)/n,a=(e.y*r.r+r.y*e.r)/n;return i*i+a*a}function w(t){this._=t,this.next=null,this.previous=null}function k(t){if(!(i=t.length))return 0;var e,r,n,i,a,o,s,l,c,u,f;if((e=t[0]).x=0,e.y=0,!(i>1))return e.r;if(r=t[1],e.x=-r.r,r.x=e.r,r.y=0,!(i>2))return e.r+r.r;x(r,e,n=t[2]),e=new w(e),r=new w(r),n=new w(n),e.next=n.previous=r,r.next=e.previous=n,n.next=r.previous=e;t:for(s=3;s<i;++s){x(e._,r._,n=t[s]),n=new w(n),l=r.next,c=e.previous,u=r._.r,f=e._.r;do{if(u<=f){if(b(l._,n._)){r=l,e.next=r,r.previous=e,--s;continue t}u+=l._.r,l=l.next}else{if(b(c._,n._)){(e=c).next=r,r.previous=e,--s;continue t}f+=c._.r,c=c.previous}}while(l!==c.next);for(n.previous=e,n.next=r,e.next=r.previous=r=n,a=_(e);(n=n.next)!==r;)(o=_(n))<a&&(e=n,a=o);r=e.next}for(e=[r._],n=r;(n=n.next)!==r;)e.push(n._);for(n=h(e),s=0;s<i;++s)(e=t[s]).x-=n.x,e.y-=n.y;return n.r}function T(t){if(\"function\"!=typeof t)throw new Error;return t}function A(){return 0}function M(t){return function(){return t}}function S(t){return Math.sqrt(t.value)}function E(t){return function(e){e.children||(e.r=Math.max(0,+t(e)||0))}}function C(t,e){return function(r){if(n=r.children){var n,i,a,o=n.length,s=t(r)*e||0;if(s)for(i=0;i<o;++i)n[i].r+=s;if(a=k(n),s)for(i=0;i<o;++i)n[i].r-=s;r.r=a+s}}}function L(t){return function(e){var r=e.parent;e.r*=t,r&&(e.x=r.x+t*e.x,e.y=r.y+t*e.y)}}function P(t){t.x0=Math.round(t.x0),t.y0=Math.round(t.y0),t.x1=Math.round(t.x1),t.y1=Math.round(t.y1)}function O(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(n-e)/t.value;++s<l;)(a=o[s]).y0=r,a.y1=i,a.x0=e,a.x1=e+=a.value*c}var z=\"$\",I={depth:-1},D={};function R(t){return t.id}function F(t){return t.parentId}function B(t,e){return t.parent===e.parent?1:2}function N(t){var e=t.children;return e?e[0]:t.t}function j(t){var e=t.children;return e?e[e.length-1]:t.t}function U(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function V(t,e,r){return t.a.parent===e.parent?t.a:r}function q(t,e){this._=t,this.parent=null,this.children=null,this.A=null,this.a=this,this.z=0,this.m=0,this.c=0,this.s=0,this.t=null,this.i=e}function H(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(i-r)/t.value;++s<l;)(a=o[s]).x0=e,a.x1=n,a.y0=r,a.y1=r+=a.value*c}q.prototype=Object.create(c.prototype);var G=(1+Math.sqrt(5))/2;function Y(t,e,r,n,i,a){for(var o,s,l,c,u,h,f,p,d,g,v,m=[],y=e.children,x=0,b=0,_=y.length,w=e.value;x<_;){l=i-r,c=a-n;do{u=y[b++].value}while(!u&&b<_);for(h=f=u,v=u*u*(g=Math.max(c/l,l/c)/(w*t)),d=Math.max(f/v,v/h);b<_;++b){if(u+=s=y[b].value,s<h&&(h=s),s>f&&(f=s),v=u*u*g,(p=Math.max(f/v,v/h))>d){u-=s;break}d=p}m.push(o={value:u,dice:l<c,children:y.slice(x,b)}),o.dice?O(o,r,n,i,w?n+=c*u/w:a):H(o,r,n,w?r+=l*u/w:i,a),w-=u,x=b}return m}var W=function t(e){function r(t,r,n,i,a){Y(e,t,r,n,i,a)}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);var X=function t(e){function r(t,r,n,i,a){if((o=t._squarify)&&o.ratio===e)for(var o,s,l,c,u,h=-1,f=o.length,p=t.value;++h<f;){for(l=(s=o[h]).children,c=s.value=0,u=l.length;c<u;++c)s.value+=l[c].value;s.dice?O(s,r,n,i,n+=(a-n)*s.value/p):H(s,r,n,r+=(i-r)*s.value/p,a),p-=s.value}else t._squarify=o=Y(e,t,r,n,i,a),o.ratio=e}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);t.cluster=function(){var t=e,i=1,a=1,o=!1;function s(e){var s,l=0;e.eachAfter(function(e){var i=e.children;i?(e.x=function(t){return t.reduce(r,0)/t.length}(i),e.y=function(t){return 1+t.reduce(n,0)}(i)):(e.x=s?l+=t(e,s):0,e.y=0,s=e)});var c=function(t){for(var e;e=t.children;)t=e[0];return t}(e),u=function(t){for(var e;e=t.children;)t=e[e.length-1];return t}(e),h=c.x-t(c,u)/2,f=u.x+t(u,c)/2;return e.eachAfter(o?function(t){t.x=(t.x-e.x)*i,t.y=(e.y-t.y)*a}:function(t){t.x=(t.x-h)/(f-h)*i,t.y=(1-(e.y?t.y/e.y:1))*a})}return s.separation=function(e){return arguments.length?(t=e,s):t},s.size=function(t){return arguments.length?(o=!1,i=+t[0],a=+t[1],s):o?null:[i,a]},s.nodeSize=function(t){return arguments.length?(o=!0,i=+t[0],a=+t[1],s):o?[i,a]:null},s},t.hierarchy=a,t.pack=function(){var t=null,e=1,r=1,n=A;function i(i){return i.x=e/2,i.y=r/2,t?i.eachBefore(E(t)).eachAfter(C(n,.5)).eachBefore(L(1)):i.eachBefore(E(S)).eachAfter(C(A,1)).eachAfter(C(n,i.r/Math.min(e,r))).eachBefore(L(Math.min(e,r)/(2*i.r))),i}return i.radius=function(e){return arguments.length?(t=null==(r=e)?null:T(r),i):t;var r},i.size=function(t){return arguments.length?(e=+t[0],r=+t[1],i):[e,r]},i.padding=function(t){return arguments.length?(n=\"function\"==typeof t?t:M(+t),i):n},i},t.packSiblings=function(t){return k(t),t},t.packEnclose=h,t.partition=function(){var t=1,e=1,r=0,n=!1;function i(i){var a=i.height+1;return i.x0=i.y0=r,i.x1=t,i.y1=e/a,i.eachBefore(function(t,e){return function(n){n.children&&O(n,n.x0,t*(n.depth+1)/e,n.x1,t*(n.depth+2)/e);var i=n.x0,a=n.y0,o=n.x1-r,s=n.y1-r;o<i&&(i=o=(i+o)/2),s<a&&(a=s=(a+s)/2),n.x0=i,n.y0=a,n.x1=o,n.y1=s}}(e,a)),n&&i.eachBefore(P),i}return i.round=function(t){return arguments.length?(n=!!t,i):n},i.size=function(r){return arguments.length?(t=+r[0],e=+r[1],i):[t,e]},i.padding=function(t){return arguments.length?(r=+t,i):r},i},t.stratify=function(){var t=R,e=F;function r(r){var n,i,a,o,s,u,h,f=r.length,p=new Array(f),d={};for(i=0;i<f;++i)n=r[i],s=p[i]=new c(n),null!=(u=t(n,i,r))&&(u+=\"\")&&(d[h=z+(s.id=u)]=h in d?D:s);for(i=0;i<f;++i)if(s=p[i],null!=(u=e(r[i],i,r))&&(u+=\"\")){if(!(o=d[z+u]))throw new Error(\"missing: \"+u);if(o===D)throw new Error(\"ambiguous: \"+u);o.children?o.children.push(s):o.children=[s],s.parent=o}else{if(a)throw new Error(\"multiple roots\");a=s}if(!a)throw new Error(\"no root\");if(a.parent=I,a.eachBefore(function(t){t.depth=t.parent.depth+1,--f}).eachBefore(l),a.parent=null,f>0)throw new Error(\"cycle\");return a}return r.id=function(e){return arguments.length?(t=T(e),r):t},r.parentId=function(t){return arguments.length?(e=T(t),r):e},r},t.tree=function(){var t=B,e=1,r=1,n=null;function i(i){var l=function(t){for(var e,r,n,i,a,o=new q(t,0),s=[o];e=s.pop();)if(n=e._.children)for(e.children=new Array(a=n.length),i=a-1;i>=0;--i)s.push(r=e.children[i]=new q(n[i],i)),r.parent=e;return(o.parent=new q(null,0)).children=[o],o}(i);if(l.eachAfter(a),l.parent.m=-l.z,l.eachBefore(o),n)i.eachBefore(s);else{var c=i,u=i,h=i;i.eachBefore(function(t){t.x<c.x&&(c=t),t.x>u.x&&(u=t),t.depth>h.depth&&(h=t)});var f=c===u?1:t(c,u)/2,p=f-c.x,d=e/(u.x+f+p),g=r/(h.depth||1);i.eachBefore(function(t){t.x=(t.x+p)*d,t.y=t.depth*g})}return i}function a(e){var r=e.children,n=e.parent.children,i=e.i?n[e.i-1]:null;if(r){!function(t){for(var e,r=0,n=0,i=t.children,a=i.length;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(e);var a=(r[0].z+r[r.length-1].z)/2;i?(e.z=i.z+t(e._,i._),e.m=e.z-a):e.z=a}else i&&(e.z=i.z+t(e._,i._));e.parent.A=function(e,r,n){if(r){for(var i,a=e,o=e,s=r,l=a.parent.children[0],c=a.m,u=o.m,h=s.m,f=l.m;s=j(s),a=N(a),s&&a;)l=N(l),(o=j(o)).a=e,(i=s.z+h-a.z-c+t(s._,a._))>0&&(U(V(s,e,n),e,i),c+=i,u+=i),h+=s.m,c+=a.m,f+=l.m,u+=o.m;s&&!j(o)&&(o.t=s,o.m+=h-u),a&&!N(l)&&(l.t=a,l.m+=c-f,n=e)}return n}(e,i,e.parent.A||n[0])}function o(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function s(t){t.x*=e,t.y=t.depth*r}return i.separation=function(e){return arguments.length?(t=e,i):t},i.size=function(t){return arguments.length?(n=!1,e=+t[0],r=+t[1],i):n?null:[e,r]},i.nodeSize=function(t){return arguments.length?(n=!0,e=+t[0],r=+t[1],i):n?[e,r]:null},i},t.treemap=function(){var t=W,e=!1,r=1,n=1,i=[0],a=A,o=A,s=A,l=A,c=A;function u(t){return t.x0=t.y0=0,t.x1=r,t.y1=n,t.eachBefore(h),i=[0],e&&t.eachBefore(P),t}function h(e){var r=i[e.depth],n=e.x0+r,u=e.y0+r,h=e.x1-r,f=e.y1-r;h<n&&(n=h=(n+h)/2),f<u&&(u=f=(u+f)/2),e.x0=n,e.y0=u,e.x1=h,e.y1=f,e.children&&(r=i[e.depth+1]=a(e)/2,n+=c(e)-r,u+=o(e)-r,(h-=s(e)-r)<n&&(n=h=(n+h)/2),(f-=l(e)-r)<u&&(u=f=(u+f)/2),t(e,n,u,h,f))}return u.round=function(t){return arguments.length?(e=!!t,u):e},u.size=function(t){return arguments.length?(r=+t[0],n=+t[1],u):[r,n]},u.tile=function(e){return arguments.length?(t=T(e),u):t},u.padding=function(t){return arguments.length?u.paddingInner(t).paddingOuter(t):u.paddingInner()},u.paddingInner=function(t){return arguments.length?(a=\"function\"==typeof t?t:M(+t),u):a},u.paddingOuter=function(t){return arguments.length?u.paddingTop(t).paddingRight(t).paddingBottom(t).paddingLeft(t):u.paddingTop()},u.paddingTop=function(t){return arguments.length?(o=\"function\"==typeof t?t:M(+t),u):o},u.paddingRight=function(t){return arguments.length?(s=\"function\"==typeof t?t:M(+t),u):s},u.paddingBottom=function(t){return arguments.length?(l=\"function\"==typeof t?t:M(+t),u):l},u.paddingLeft=function(t){return arguments.length?(c=\"function\"==typeof t?t:M(+t),u):c},u},t.treemapBinary=function(t,e,r,n,i){var a,o,s=t.children,l=s.length,c=new Array(l+1);for(c[0]=o=a=0;a<l;++a)c[a+1]=o+=s[a].value;!function t(e,r,n,i,a,o,l){if(e>=r-1){var u=s[e];return u.x0=i,u.y0=a,u.x1=o,void(u.y1=l)}for(var h=c[e],f=n/2+h,p=e+1,d=r-1;p<d;){var g=p+d>>>1;c[g]<f?p=g+1:d=g}f-c[p-1]<c[p]-f&&e+1<p&&--p;var v=c[p]-h,m=n-v;if(o-i>l-a){var y=(i*m+o*v)/n;t(e,p,v,i,a,y,l),t(p,r,m,y,a,o,l)}else{var x=(a*m+l*v)/n;t(e,p,v,i,a,o,x),t(p,r,m,i,x,o,l)}}(0,l,t.value,e,r,n,i)},t.treemapDice=O,t.treemapSlice=H,t.treemapSliceDice=function(t,e,r,n,i){(1&t.depth?H:O)(t,e,r,n,i)},t.treemapSquarify=W,t.treemapResquarify=X,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],158:[function(t,e,r){var n,i;n=this,i=function(t,e){\"use strict\";function r(t,e,r,n,i){var a=t*t,o=a*t;return((1-3*t+3*a-o)*e+(4-6*a+3*o)*r+(1+3*t+3*a-3*o)*n+o*i)/6}function n(t){var e=t.length-1;return function(n){var i=n<=0?n=0:n>=1?(n=1,e-1):Math.floor(n*e),a=t[i],o=t[i+1],s=i>0?t[i-1]:2*a-o,l=i<e-1?t[i+2]:2*o-a;return r((n-i/e)*e,s,a,o,l)}}function i(t){var e=t.length;return function(n){var i=Math.floor(((n%=1)<0?++n:n)*e),a=t[(i+e-1)%e],o=t[i%e],s=t[(i+1)%e],l=t[(i+2)%e];return r((n-i/e)*e,a,o,s,l)}}function a(t){return function(){return t}}function o(t,e){return function(r){return t+r*e}}function s(t,e){var r=e-t;return r?o(t,r>180||r<-180?r-360*Math.round(r/360):r):a(isNaN(t)?e:t)}function l(t){return 1==(t=+t)?c:function(e,r){return r-e?function(t,e,r){return t=Math.pow(t,r),e=Math.pow(e,r)-t,r=1/r,function(n){return Math.pow(t+n*e,r)}}(e,r,t):a(isNaN(e)?r:e)}}function c(t,e){var r=e-t;return r?o(t,r):a(isNaN(t)?e:t)}var u=function t(r){var n=l(r);function i(t,r){var i=n((t=e.rgb(t)).r,(r=e.rgb(r)).r),a=n(t.g,r.g),o=n(t.b,r.b),s=c(t.opacity,r.opacity);return function(e){return t.r=i(e),t.g=a(e),t.b=o(e),t.opacity=s(e),t+\"\"}}return i.gamma=t,i}(1);function h(t){return function(r){var n,i,a=r.length,o=new Array(a),s=new Array(a),l=new Array(a);for(n=0;n<a;++n)i=e.rgb(r[n]),o[n]=i.r||0,s[n]=i.g||0,l[n]=i.b||0;return o=t(o),s=t(s),l=t(l),i.opacity=1,function(t){return i.r=o(t),i.g=s(t),i.b=l(t),i+\"\"}}}var f=h(n),p=h(i);function d(t,e){var r,n=e?e.length:0,i=t?Math.min(n,t.length):0,a=new Array(i),o=new Array(n);for(r=0;r<i;++r)a[r]=_(t[r],e[r]);for(;r<n;++r)o[r]=e[r];return function(t){for(r=0;r<i;++r)o[r]=a[r](t);return o}}function g(t,e){var r=new Date;return e-=t=+t,function(n){return r.setTime(t+e*n),r}}function v(t,e){return e-=t=+t,function(r){return t+e*r}}function m(t,e){var r,n={},i={};for(r in null!==t&&\"object\"==typeof t||(t={}),null!==e&&\"object\"==typeof e||(e={}),e)r in t?n[r]=_(t[r],e[r]):i[r]=e[r];return function(t){for(r in n)i[r]=n[r](t);return i}}var y=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,x=new RegExp(y.source,\"g\");function b(t,e){var r,n,i,a=y.lastIndex=x.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=y.exec(t))&&(n=x.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:v(r,n)})),a=x.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?function(t){return function(e){return t(e)+\"\"}}(l[0].x):function(t){return function(){return t}}(e):(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}function _(t,r){var n,i=typeof r;return null==r||\"boolean\"===i?a(r):(\"number\"===i?v:\"string\"===i?(n=e.color(r))?(r=n,u):b:r instanceof e.color?u:r instanceof Date?g:Array.isArray(r)?d:\"function\"!=typeof r.valueOf&&\"function\"!=typeof r.toString||isNaN(r)?m:v)(t,r)}var w,k,T,A,M=180/Math.PI,S={translateX:0,translateY:0,rotate:0,skewX:0,scaleX:1,scaleY:1};function E(t,e,r,n,i,a){var o,s,l;return(o=Math.sqrt(t*t+e*e))&&(t/=o,e/=o),(l=t*r+e*n)&&(r-=t*l,n-=e*l),(s=Math.sqrt(r*r+n*n))&&(r/=s,n/=s,l/=s),t*n<e*r&&(t=-t,e=-e,l=-l,o=-o),{translateX:i,translateY:a,rotate:Math.atan2(e,t)*M,skewX:Math.atan(l)*M,scaleX:o,scaleY:s}}function C(t,e,r,n){function i(t){return t.length?t.pop()+\" \":\"\"}return function(a,o){var s=[],l=[];return a=t(a),o=t(o),function(t,n,i,a,o,s){if(t!==i||n!==a){var l=o.push(\"translate(\",null,e,null,r);s.push({i:l-4,x:v(t,i)},{i:l-2,x:v(n,a)})}else(i||a)&&o.push(\"translate(\"+i+e+a+r)}(a.translateX,a.translateY,o.translateX,o.translateY,s,l),function(t,e,r,a){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),a.push({i:r.push(i(r)+\"rotate(\",null,n)-2,x:v(t,e)})):e&&r.push(i(r)+\"rotate(\"+e+n)}(a.rotate,o.rotate,s,l),function(t,e,r,a){t!==e?a.push({i:r.push(i(r)+\"skewX(\",null,n)-2,x:v(t,e)}):e&&r.push(i(r)+\"skewX(\"+e+n)}(a.skewX,o.skewX,s,l),function(t,e,r,n,a,o){if(t!==r||e!==n){var s=a.push(i(a)+\"scale(\",null,\",\",null,\")\");o.push({i:s-4,x:v(t,r)},{i:s-2,x:v(e,n)})}else 1===r&&1===n||a.push(i(a)+\"scale(\"+r+\",\"+n+\")\")}(a.scaleX,a.scaleY,o.scaleX,o.scaleY,s,l),a=o=null,function(t){for(var e,r=-1,n=l.length;++r<n;)s[(e=l[r]).i]=e.x(t);return s.join(\"\")}}}var L=C(function(t){return\"none\"===t?S:(w||(w=document.createElement(\"DIV\"),k=document.documentElement,T=document.defaultView),w.style.transform=t,t=T.getComputedStyle(k.appendChild(w),null).getPropertyValue(\"transform\"),k.removeChild(w),E(+(t=t.slice(7,-1).split(\",\"))[0],+t[1],+t[2],+t[3],+t[4],+t[5]))},\"px, \",\"px)\",\"deg)\"),P=C(function(t){return null==t?S:(A||(A=document.createElementNS(\"http://www.w3.org/2000/svg\",\"g\")),A.setAttribute(\"transform\",t),(t=A.transform.baseVal.consolidate())?E((t=t.matrix).a,t.b,t.c,t.d,t.e,t.f):S)},\", \",\")\",\")\"),O=Math.SQRT2,z=2,I=4,D=1e-12;function R(t){return((t=Math.exp(t))+1/t)/2}function F(t){return function(r,n){var i=t((r=e.hsl(r)).h,(n=e.hsl(n)).h),a=c(r.s,n.s),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.s=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var B=F(s),N=F(c);function j(t){return function(r,n){var i=t((r=e.hcl(r)).h,(n=e.hcl(n)).h),a=c(r.c,n.c),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.c=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var U=j(s),V=j(c);function q(t){return function r(n){function i(r,i){var a=t((r=e.cubehelix(r)).h,(i=e.cubehelix(i)).h),o=c(r.s,i.s),s=c(r.l,i.l),l=c(r.opacity,i.opacity);return function(t){return r.h=a(t),r.s=o(t),r.l=s(Math.pow(t,n)),r.opacity=l(t),r+\"\"}}return n=+n,i.gamma=r,i}(1)}var H=q(s),G=q(c);t.interpolate=_,t.interpolateArray=d,t.interpolateBasis=n,t.interpolateBasisClosed=i,t.interpolateDate=g,t.interpolateDiscrete=function(t){var e=t.length;return function(r){return t[Math.max(0,Math.min(e-1,Math.floor(r*e)))]}},t.interpolateHue=function(t,e){var r=s(+t,+e);return function(t){var e=r(t);return e-360*Math.floor(e/360)}},t.interpolateNumber=v,t.interpolateObject=m,t.interpolateRound=function(t,e){return e-=t=+t,function(r){return Math.round(t+e*r)}},t.interpolateString=b,t.interpolateTransformCss=L,t.interpolateTransformSvg=P,t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,h=l-a,f=u*u+h*h;if(f<D)n=Math.log(c/o)/O,r=function(t){return[i+t*u,a+t*h,o*Math.exp(O*t*n)]};else{var p=Math.sqrt(f),d=(c*c-o*o+I*f)/(2*o*z*p),g=(c*c-o*o-I*f)/(2*c*z*p),v=Math.log(Math.sqrt(d*d+1)-d),m=Math.log(Math.sqrt(g*g+1)-g);n=(m-v)/O,r=function(t){var e,r=t*n,s=R(v),l=o/(z*p)*(s*(e=O*r+v,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(v));return[i+l*u,a+l*h,o*s/R(O*r+v)]}}return r.duration=1e3*n,r},t.interpolateRgb=u,t.interpolateRgbBasis=f,t.interpolateRgbBasisClosed=p,t.interpolateHsl=B,t.interpolateHslLong=N,t.interpolateLab=function(t,r){var n=c((t=e.lab(t)).l,(r=e.lab(r)).l),i=c(t.a,r.a),a=c(t.b,r.b),o=c(t.opacity,r.opacity);return function(e){return t.l=n(e),t.a=i(e),t.b=a(e),t.opacity=o(e),t+\"\"}},t.interpolateHcl=U,t.interpolateHclLong=V,t.interpolateCubehelix=H,t.interpolateCubehelixLong=G,t.piecewise=function(t,e){for(var r=0,n=e.length-1,i=e[0],a=new Array(n<0?0:n);r<n;)a[r]=t(i,i=e[++r]);return function(t){var e=Math.max(0,Math.min(n-1,Math.floor(t*=n)));return a[e](t-e)}},t.quantize=function(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t(n/(e-1));return r},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-color\")):i(n.d3=n.d3||{},n.d3)},{\"d3-color\":154}],159:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e=Math.PI,r=2*e,n=r-1e-6;function i(){this._x0=this._y0=this._x1=this._y1=null,this._=\"\"}function a(){return new i}i.prototype=a.prototype={constructor:i,moveTo:function(t,e){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)},closePath:function(){null!==this._x1&&(this._x1=this._x0,this._y1=this._y0,this._+=\"Z\")},lineTo:function(t,e){this._+=\"L\"+(this._x1=+t)+\",\"+(this._y1=+e)},quadraticCurveTo:function(t,e,r,n){this._+=\"Q\"+ +t+\",\"+ +e+\",\"+(this._x1=+r)+\",\"+(this._y1=+n)},bezierCurveTo:function(t,e,r,n,i,a){this._+=\"C\"+ +t+\",\"+ +e+\",\"+ +r+\",\"+ +n+\",\"+(this._x1=+i)+\",\"+(this._y1=+a)},arcTo:function(t,r,n,i,a){t=+t,r=+r,n=+n,i=+i,a=+a;var o=this._x1,s=this._y1,l=n-t,c=i-r,u=o-t,h=s-r,f=u*u+h*h;if(a<0)throw new Error(\"negative radius: \"+a);if(null===this._x1)this._+=\"M\"+(this._x1=t)+\",\"+(this._y1=r);else if(f>1e-6)if(Math.abs(h*l-c*u)>1e-6&&a){var p=n-o,d=i-s,g=l*l+c*c,v=p*p+d*d,m=Math.sqrt(g),y=Math.sqrt(f),x=a*Math.tan((e-Math.acos((g+f-v)/(2*m*y)))/2),b=x/y,_=x/m;Math.abs(b-1)>1e-6&&(this._+=\"L\"+(t+b*u)+\",\"+(r+b*h)),this._+=\"A\"+a+\",\"+a+\",0,0,\"+ +(h*p>u*d)+\",\"+(this._x1=t+_*l)+\",\"+(this._y1=r+_*c)}else this._+=\"L\"+(this._x1=t)+\",\"+(this._y1=r);else;},arc:function(t,i,a,o,s,l){t=+t,i=+i;var c=(a=+a)*Math.cos(o),u=a*Math.sin(o),h=t+c,f=i+u,p=1^l,d=l?o-s:s-o;if(a<0)throw new Error(\"negative radius: \"+a);null===this._x1?this._+=\"M\"+h+\",\"+f:(Math.abs(this._x1-h)>1e-6||Math.abs(this._y1-f)>1e-6)&&(this._+=\"L\"+h+\",\"+f),a&&(d<0&&(d=d%r+r),d>n?this._+=\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(t-c)+\",\"+(i-u)+\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(this._x1=h)+\",\"+(this._y1=f):d>1e-6&&(this._+=\"A\"+a+\",\"+a+\",0,\"+ +(d>=e)+\",\"+p+\",\"+(this._x1=t+a*Math.cos(s))+\",\"+(this._y1=i+a*Math.sin(s))))},rect:function(t,e,r,n){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)+\"h\"+ +r+\"v\"+ +n+\"h\"+-r+\"Z\"},toString:function(){return this._}},t.path=a,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],160:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e,r,n){if(isNaN(e)||isNaN(r))return t;var i,a,o,s,l,c,u,h,f,p=t._root,d={data:n},g=t._x0,v=t._y0,m=t._x1,y=t._y1;if(!p)return t._root=d,t;for(;p.length;)if((c=e>=(a=(g+m)/2))?g=a:m=a,(u=r>=(o=(v+y)/2))?v=o:y=o,i=p,!(p=p[h=u<<1|c]))return i[h]=d,t;if(s=+t._x.call(null,p.data),l=+t._y.call(null,p.data),e===s&&r===l)return d.next=p,i?i[h]=d:t._root=d,t;do{i=i?i[h]=new Array(4):t._root=new Array(4),(c=e>=(a=(g+m)/2))?g=a:m=a,(u=r>=(o=(v+y)/2))?v=o:y=o}while((h=u<<1|c)==(f=(l>=o)<<1|s>=a));return i[f]=p,i[h]=d,t}var r=function(t,e,r,n,i){this.node=t,this.x0=e,this.y0=r,this.x1=n,this.y1=i};function n(t){return t[0]}function i(t){return t[1]}function a(t,e,r){var a=new o(null==e?n:e,null==r?i:r,NaN,NaN,NaN,NaN);return null==t?a:a.addAll(t)}function o(t,e,r,n,i,a){this._x=t,this._y=e,this._x0=r,this._y0=n,this._x1=i,this._y1=a,this._root=void 0}function s(t){for(var e={data:t.data},r=e;t=t.next;)r=r.next={data:t.data};return e}var l=a.prototype=o.prototype;l.copy=function(){var t,e,r=new o(this._x,this._y,this._x0,this._y0,this._x1,this._y1),n=this._root;if(!n)return r;if(!n.length)return r._root=s(n),r;for(t=[{source:n,target:r._root=new Array(4)}];n=t.pop();)for(var i=0;i<4;++i)(e=n.source[i])&&(e.length?t.push({source:e,target:n.target[i]=new Array(4)}):n.target[i]=s(e));return r},l.add=function(t){var r=+this._x.call(null,t),n=+this._y.call(null,t);return e(this.cover(r,n),r,n,t)},l.addAll=function(t){var r,n,i,a,o=t.length,s=new Array(o),l=new Array(o),c=1/0,u=1/0,h=-1/0,f=-1/0;for(n=0;n<o;++n)isNaN(i=+this._x.call(null,r=t[n]))||isNaN(a=+this._y.call(null,r))||(s[n]=i,l[n]=a,i<c&&(c=i),i>h&&(h=i),a<u&&(u=a),a>f&&(f=a));for(h<c&&(c=this._x0,h=this._x1),f<u&&(u=this._y0,f=this._y1),this.cover(c,u).cover(h,f),n=0;n<o;++n)e(this,s[n],l[n],t[n]);return this},l.cover=function(t,e){if(isNaN(t=+t)||isNaN(e=+e))return this;var r=this._x0,n=this._y0,i=this._x1,a=this._y1;if(isNaN(r))i=(r=Math.floor(t))+1,a=(n=Math.floor(e))+1;else{if(!(r>t||t>i||n>e||e>a))return this;var o,s,l=i-r,c=this._root;switch(s=(e<(n+a)/2)<<1|t<(r+i)/2){case 0:do{(o=new Array(4))[s]=c,c=o}while(a=n+(l*=2),t>(i=r+l)||e>a);break;case 1:do{(o=new Array(4))[s]=c,c=o}while(a=n+(l*=2),(r=i-l)>t||e>a);break;case 2:do{(o=new Array(4))[s]=c,c=o}while(n=a-(l*=2),t>(i=r+l)||n>e);break;case 3:do{(o=new Array(4))[s]=c,c=o}while(n=a-(l*=2),(r=i-l)>t||n>e)}this._root&&this._root.length&&(this._root=c)}return this._x0=r,this._y0=n,this._x1=i,this._y1=a,this},l.data=function(){var t=[];return this.visit(function(e){if(!e.length)do{t.push(e.data)}while(e=e.next)}),t},l.extent=function(t){return arguments.length?this.cover(+t[0][0],+t[0][1]).cover(+t[1][0],+t[1][1]):isNaN(this._x0)?void 0:[[this._x0,this._y0],[this._x1,this._y1]]},l.find=function(t,e,n){var i,a,o,s,l,c,u,h=this._x0,f=this._y0,p=this._x1,d=this._y1,g=[],v=this._root;for(v&&g.push(new r(v,h,f,p,d)),null==n?n=1/0:(h=t-n,f=e-n,p=t+n,d=e+n,n*=n);c=g.pop();)if(!(!(v=c.node)||(a=c.x0)>p||(o=c.y0)>d||(s=c.x1)<h||(l=c.y1)<f))if(v.length){var m=(a+s)/2,y=(o+l)/2;g.push(new r(v[3],m,y,s,l),new r(v[2],a,y,m,l),new r(v[1],m,o,s,y),new r(v[0],a,o,m,y)),(u=(e>=y)<<1|t>=m)&&(c=g[g.length-1],g[g.length-1]=g[g.length-1-u],g[g.length-1-u]=c)}else{var x=t-+this._x.call(null,v.data),b=e-+this._y.call(null,v.data),_=x*x+b*b;if(_<n){var w=Math.sqrt(n=_);h=t-w,f=e-w,p=t+w,d=e+w,i=v.data}}return i},l.remove=function(t){if(isNaN(a=+this._x.call(null,t))||isNaN(o=+this._y.call(null,t)))return this;var e,r,n,i,a,o,s,l,c,u,h,f,p=this._root,d=this._x0,g=this._y0,v=this._x1,m=this._y1;if(!p)return this;if(p.length)for(;;){if((c=a>=(s=(d+v)/2))?d=s:v=s,(u=o>=(l=(g+m)/2))?g=l:m=l,e=p,!(p=p[h=u<<1|c]))return this;if(!p.length)break;(e[h+1&3]||e[h+2&3]||e[h+3&3])&&(r=e,f=h)}for(;p.data!==t;)if(n=p,!(p=p.next))return this;return(i=p.next)&&delete p.next,n?(i?n.next=i:delete n.next,this):e?(i?e[h]=i:delete e[h],(p=e[0]||e[1]||e[2]||e[3])&&p===(e[3]||e[2]||e[1]||e[0])&&!p.length&&(r?r[f]=p:this._root=p),this):(this._root=i,this)},l.removeAll=function(t){for(var e=0,r=t.length;e<r;++e)this.remove(t[e]);return this},l.root=function(){return this._root},l.size=function(){var t=0;return this.visit(function(e){if(!e.length)do{++t}while(e=e.next)}),t},l.visit=function(t){var e,n,i,a,o,s,l=[],c=this._root;for(c&&l.push(new r(c,this._x0,this._y0,this._x1,this._y1));e=l.pop();)if(!t(c=e.node,i=e.x0,a=e.y0,o=e.x1,s=e.y1)&&c.length){var u=(i+o)/2,h=(a+s)/2;(n=c[3])&&l.push(new r(n,u,h,o,s)),(n=c[2])&&l.push(new r(n,i,h,u,s)),(n=c[1])&&l.push(new r(n,u,a,o,h)),(n=c[0])&&l.push(new r(n,i,a,u,h))}return this},l.visitAfter=function(t){var e,n=[],i=[];for(this._root&&n.push(new r(this._root,this._x0,this._y0,this._x1,this._y1));e=n.pop();){var a=e.node;if(a.length){var o,s=e.x0,l=e.y0,c=e.x1,u=e.y1,h=(s+c)/2,f=(l+u)/2;(o=a[0])&&n.push(new r(o,s,l,h,f)),(o=a[1])&&n.push(new r(o,h,l,c,f)),(o=a[2])&&n.push(new r(o,s,f,h,u)),(o=a[3])&&n.push(new r(o,h,f,c,u))}i.push(e)}for(;e=i.pop();)t(e.node,e.x0,e.y0,e.x1,e.y1);return this},l.x=function(t){return arguments.length?(this._x=t,this):this._x},l.y=function(t){return arguments.length?(this._y=t,this):this._y},t.quadtree=a,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],161:[function(t,e,r){var n,i;n=this,i=function(t,e){\"use strict\";function r(t){return function(){return t}}var n=Math.abs,i=Math.atan2,a=Math.cos,o=Math.max,s=Math.min,l=Math.sin,c=Math.sqrt,u=1e-12,h=Math.PI,f=h/2,p=2*h;function d(t){return t>=1?f:t<=-1?-f:Math.asin(t)}function g(t){return t.innerRadius}function v(t){return t.outerRadius}function m(t){return t.startAngle}function y(t){return t.endAngle}function x(t){return t&&t.padAngle}function b(t,e,r,n,i,a,s){var l=t-r,u=e-n,h=(s?a:-a)/c(l*l+u*u),f=h*u,p=-h*l,d=t+f,g=e+p,v=r+f,m=n+p,y=(d+v)/2,x=(g+m)/2,b=v-d,_=m-g,w=b*b+_*_,k=i-a,T=d*m-v*g,A=(_<0?-1:1)*c(o(0,k*k*w-T*T)),M=(T*_-b*A)/w,S=(-T*b-_*A)/w,E=(T*_+b*A)/w,C=(-T*b+_*A)/w,L=M-y,P=S-x,O=E-y,z=C-x;return L*L+P*P>O*O+z*z&&(M=E,S=C),{cx:M,cy:S,x01:-f,y01:-p,x11:M*(i/k-1),y11:S*(i/k-1)}}function _(t){this._context=t}function w(t){return new _(t)}function k(t){return t[0]}function T(t){return t[1]}function A(){var t=k,n=T,i=r(!0),a=null,o=w,s=null;function l(r){var l,c,u,h=r.length,f=!1;for(null==a&&(s=o(u=e.path())),l=0;l<=h;++l)!(l<h&&i(c=r[l],l,r))===f&&((f=!f)?s.lineStart():s.lineEnd()),f&&s.point(+t(c,l,r),+n(c,l,r));if(u)return s=null,u+\"\"||null}return l.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),l):t},l.y=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),l):n},l.defined=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(!!t),l):i},l.curve=function(t){return arguments.length?(o=t,null!=a&&(s=o(a)),l):o},l.context=function(t){return arguments.length?(null==t?a=s=null:s=o(a=t),l):a},l}function M(){var t=k,n=null,i=r(0),a=T,o=r(!0),s=null,l=w,c=null;function u(r){var u,h,f,p,d,g=r.length,v=!1,m=new Array(g),y=new Array(g);for(null==s&&(c=l(d=e.path())),u=0;u<=g;++u){if(!(u<g&&o(p=r[u],u,r))===v)if(v=!v)h=u,c.areaStart(),c.lineStart();else{for(c.lineEnd(),c.lineStart(),f=u-1;f>=h;--f)c.point(m[f],y[f]);c.lineEnd(),c.areaEnd()}v&&(m[u]=+t(p,u,r),y[u]=+i(p,u,r),c.point(n?+n(p,u,r):m[u],a?+a(p,u,r):y[u]))}if(d)return c=null,d+\"\"||null}function h(){return A().defined(o).curve(l).context(s)}return u.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),n=null,u):t},u.x0=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),u):t},u.x1=function(t){return arguments.length?(n=null==t?null:\"function\"==typeof t?t:r(+t),u):n},u.y=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a=null,u):i},u.y0=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),u):i},u.y1=function(t){return arguments.length?(a=null==t?null:\"function\"==typeof t?t:r(+t),u):a},u.lineX0=u.lineY0=function(){return h().x(t).y(i)},u.lineY1=function(){return h().x(t).y(a)},u.lineX1=function(){return h().x(n).y(i)},u.defined=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(!!t),u):o},u.curve=function(t){return arguments.length?(l=t,null!=s&&(c=l(s)),u):l},u.context=function(t){return arguments.length?(null==t?s=c=null:c=l(s=t),u):s},u}function S(t,e){return e<t?-1:e>t?1:e>=t?0:NaN}function E(t){return t}_.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._point=0},lineEnd:function(){(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:this._context.lineTo(t,e)}}};var C=P(w);function L(t){this._curve=t}function P(t){function e(e){return new L(t(e))}return e._curve=t,e}function O(t){var e=t.curve;return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function z(){return O(A().curve(C))}function I(){var t=M().curve(C),e=t.curve,r=t.lineX0,n=t.lineX1,i=t.lineY0,a=t.lineY1;return t.angle=t.x,delete t.x,t.startAngle=t.x0,delete t.x0,t.endAngle=t.x1,delete t.x1,t.radius=t.y,delete t.y,t.innerRadius=t.y0,delete t.y0,t.outerRadius=t.y1,delete t.y1,t.lineStartAngle=function(){return O(r())},delete t.lineX0,t.lineEndAngle=function(){return O(n())},delete t.lineX1,t.lineInnerRadius=function(){return O(i())},delete t.lineY0,t.lineOuterRadius=function(){return O(a())},delete t.lineY1,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function D(t,e){return[(e=+e)*Math.cos(t-=Math.PI/2),e*Math.sin(t)]}L.prototype={areaStart:function(){this._curve.areaStart()},areaEnd:function(){this._curve.areaEnd()},lineStart:function(){this._curve.lineStart()},lineEnd:function(){this._curve.lineEnd()},point:function(t,e){this._curve.point(e*Math.sin(t),e*-Math.cos(t))}};var R=Array.prototype.slice;function F(t){return t.source}function B(t){return t.target}function N(t){var n=F,i=B,a=k,o=T,s=null;function l(){var r,l=R.call(arguments),c=n.apply(this,l),u=i.apply(this,l);if(s||(s=r=e.path()),t(s,+a.apply(this,(l[0]=c,l)),+o.apply(this,l),+a.apply(this,(l[0]=u,l)),+o.apply(this,l)),r)return s=null,r+\"\"||null}return l.source=function(t){return arguments.length?(n=t,l):n},l.target=function(t){return arguments.length?(i=t,l):i},l.x=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),l):a},l.y=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),l):o},l.context=function(t){return arguments.length?(s=null==t?null:t,l):s},l}function j(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e=(e+n)/2,r,e,i,n,i)}function U(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e,r=(r+i)/2,n,r,n,i)}function V(t,e,r,n,i){var a=D(e,r),o=D(e,r=(r+i)/2),s=D(n,r),l=D(n,i);t.moveTo(a[0],a[1]),t.bezierCurveTo(o[0],o[1],s[0],s[1],l[0],l[1])}var q={draw:function(t,e){var r=Math.sqrt(e/h);t.moveTo(r,0),t.arc(0,0,r,0,p)}},H={draw:function(t,e){var r=Math.sqrt(e/5)/2;t.moveTo(-3*r,-r),t.lineTo(-r,-r),t.lineTo(-r,-3*r),t.lineTo(r,-3*r),t.lineTo(r,-r),t.lineTo(3*r,-r),t.lineTo(3*r,r),t.lineTo(r,r),t.lineTo(r,3*r),t.lineTo(-r,3*r),t.lineTo(-r,r),t.lineTo(-3*r,r),t.closePath()}},G=Math.sqrt(1/3),Y=2*G,W={draw:function(t,e){var r=Math.sqrt(e/Y),n=r*G;t.moveTo(0,-r),t.lineTo(n,0),t.lineTo(0,r),t.lineTo(-n,0),t.closePath()}},X=Math.sin(h/10)/Math.sin(7*h/10),Z=Math.sin(p/10)*X,J=-Math.cos(p/10)*X,K={draw:function(t,e){var r=Math.sqrt(.8908130915292852*e),n=Z*r,i=J*r;t.moveTo(0,-r),t.lineTo(n,i);for(var a=1;a<5;++a){var o=p*a/5,s=Math.cos(o),l=Math.sin(o);t.lineTo(l*r,-s*r),t.lineTo(s*n-l*i,l*n+s*i)}t.closePath()}},$={draw:function(t,e){var r=Math.sqrt(e),n=-r/2;t.rect(n,n,r,r)}},Q=Math.sqrt(3),tt={draw:function(t,e){var r=-Math.sqrt(e/(3*Q));t.moveTo(0,2*r),t.lineTo(-Q*r,-r),t.lineTo(Q*r,-r),t.closePath()}},et=-.5,rt=Math.sqrt(3)/2,nt=1/Math.sqrt(12),it=3*(nt/2+1),at={draw:function(t,e){var r=Math.sqrt(e/it),n=r/2,i=r*nt,a=n,o=r*nt+r,s=-a,l=o;t.moveTo(n,i),t.lineTo(a,o),t.lineTo(s,l),t.lineTo(et*n-rt*i,rt*n+et*i),t.lineTo(et*a-rt*o,rt*a+et*o),t.lineTo(et*s-rt*l,rt*s+et*l),t.lineTo(et*n+rt*i,et*i-rt*n),t.lineTo(et*a+rt*o,et*o-rt*a),t.lineTo(et*s+rt*l,et*l-rt*s),t.closePath()}},ot=[q,H,W,$,K,tt,at];function st(){}function lt(t,e,r){t._context.bezierCurveTo((2*t._x0+t._x1)/3,(2*t._y0+t._y1)/3,(t._x0+2*t._x1)/3,(t._y0+2*t._y1)/3,(t._x0+4*t._x1+e)/6,(t._y0+4*t._y1+r)/6)}function ct(t){this._context=t}function ut(t){this._context=t}function ht(t){this._context=t}function ft(t,e){this._basis=new ct(t),this._beta=e}ct.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){switch(this._point){case 3:lt(this,this._x1,this._y1);case 2:this._context.lineTo(this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,this._context.lineTo((5*this._x0+this._x1)/6,(5*this._y0+this._y1)/6);default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ut.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._y0=this._y1=this._y2=this._y3=this._y4=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x2,this._y2),this._context.closePath();break;case 2:this._context.moveTo((this._x2+2*this._x3)/3,(this._y2+2*this._y3)/3),this._context.lineTo((this._x3+2*this._x2)/3,(this._y3+2*this._y2)/3),this._context.closePath();break;case 3:this.point(this._x2,this._y2),this.point(this._x3,this._y3),this.point(this._x4,this._y4)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x2=t,this._y2=e;break;case 1:this._point=2,this._x3=t,this._y3=e;break;case 2:this._point=3,this._x4=t,this._y4=e,this._context.moveTo((this._x0+4*this._x1+t)/6,(this._y0+4*this._y1+e)/6);break;default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ht.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3;var r=(this._x0+4*this._x1+t)/6,n=(this._y0+4*this._y1+e)/6;this._line?this._context.lineTo(r,n):this._context.moveTo(r,n);break;case 3:this._point=4;default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ft.prototype={lineStart:function(){this._x=[],this._y=[],this._basis.lineStart()},lineEnd:function(){var t=this._x,e=this._y,r=t.length-1;if(r>0)for(var n,i=t[0],a=e[0],o=t[r]-i,s=e[r]-a,l=-1;++l<=r;)n=l/r,this._basis.point(this._beta*t[l]+(1-this._beta)*(i+n*o),this._beta*e[l]+(1-this._beta)*(a+n*s));this._x=this._y=null,this._basis.lineEnd()},point:function(t,e){this._x.push(+t),this._y.push(+e)}};var pt=function t(e){function r(t){return 1===e?new ct(t):new ft(t,e)}return r.beta=function(e){return t(+e)},r}(.85);function dt(t,e,r){t._context.bezierCurveTo(t._x1+t._k*(t._x2-t._x0),t._y1+t._k*(t._y2-t._y0),t._x2+t._k*(t._x1-e),t._y2+t._k*(t._y1-r),t._x2,t._y2)}function gt(t,e){this._context=t,this._k=(1-e)/6}gt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:dt(this,this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2,this._x1=t,this._y1=e;break;case 2:this._point=3;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var vt=function t(e){function r(t){return new gt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function mt(t,e){this._context=t,this._k=(1-e)/6}mt.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var yt=function t(e){function r(t){return new mt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function xt(t,e){this._context=t,this._k=(1-e)/6}xt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var bt=function t(e){function r(t){return new xt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function _t(t,e,r){var n=t._x1,i=t._y1,a=t._x2,o=t._y2;if(t._l01_a>u){var s=2*t._l01_2a+3*t._l01_a*t._l12_a+t._l12_2a,l=3*t._l01_a*(t._l01_a+t._l12_a);n=(n*s-t._x0*t._l12_2a+t._x2*t._l01_2a)/l,i=(i*s-t._y0*t._l12_2a+t._y2*t._l01_2a)/l}if(t._l23_a>u){var c=2*t._l23_2a+3*t._l23_a*t._l12_a+t._l12_2a,h=3*t._l23_a*(t._l23_a+t._l12_a);a=(a*c+t._x1*t._l23_2a-e*t._l12_2a)/h,o=(o*c+t._y1*t._l23_2a-r*t._l12_2a)/h}t._context.bezierCurveTo(n,i,a,o,t._x2,t._y2)}function wt(t,e){this._context=t,this._alpha=e}wt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:this.point(this._x2,this._y2)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var kt=function t(e){function r(t){return e?new wt(t,e):new gt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Tt(t,e){this._context=t,this._alpha=e}Tt.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var At=function t(e){function r(t){return e?new Tt(t,e):new mt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Mt(t,e){this._context=t,this._alpha=e}Mt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var St=function t(e){function r(t){return e?new Mt(t,e):new xt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Et(t){this._context=t}function Ct(t){return t<0?-1:1}function Lt(t,e,r){var n=t._x1-t._x0,i=e-t._x1,a=(t._y1-t._y0)/(n||i<0&&-0),o=(r-t._y1)/(i||n<0&&-0),s=(a*i+o*n)/(n+i);return(Ct(a)+Ct(o))*Math.min(Math.abs(a),Math.abs(o),.5*Math.abs(s))||0}function Pt(t,e){var r=t._x1-t._x0;return r?(3*(t._y1-t._y0)/r-e)/2:e}function Ot(t,e,r){var n=t._x0,i=t._y0,a=t._x1,o=t._y1,s=(a-n)/3;t._context.bezierCurveTo(n+s,i+s*e,a-s,o-s*r,a,o)}function zt(t){this._context=t}function It(t){this._context=new Dt(t)}function Dt(t){this._context=t}function Rt(t){this._context=t}function Ft(t){var e,r,n=t.length-1,i=new Array(n),a=new Array(n),o=new Array(n);for(i[0]=0,a[0]=2,o[0]=t[0]+2*t[1],e=1;e<n-1;++e)i[e]=1,a[e]=4,o[e]=4*t[e]+2*t[e+1];for(i[n-1]=2,a[n-1]=7,o[n-1]=8*t[n-1]+t[n],e=1;e<n;++e)r=i[e]/a[e-1],a[e]-=r,o[e]-=r*o[e-1];for(i[n-1]=o[n-1]/a[n-1],e=n-2;e>=0;--e)i[e]=(o[e]-i[e+1])/a[e];for(a[n-1]=(t[n]+i[n-1])/2,e=0;e<n-1;++e)a[e]=2*t[e+1]-i[e+1];return[i,a]}function Bt(t,e){this._context=t,this._t=e}function Nt(t,e){if((i=t.length)>1)for(var r,n,i,a=1,o=t[e[0]],s=o.length;a<i;++a)for(n=o,o=t[e[a]],r=0;r<s;++r)o[r][1]+=o[r][0]=isNaN(n[r][1])?n[r][0]:n[r][1]}function jt(t){for(var e=t.length,r=new Array(e);--e>=0;)r[e]=e;return r}function Ut(t,e){return t[e]}function Vt(t){var e=t.map(qt);return jt(t).sort(function(t,r){return e[t]-e[r]})}function qt(t){for(var e,r=-1,n=0,i=t.length,a=-1/0;++r<i;)(e=+t[r][1])>a&&(a=e,n=r);return n}function Ht(t){var e=t.map(Gt);return jt(t).sort(function(t,r){return e[t]-e[r]})}function Gt(t){for(var e,r=0,n=-1,i=t.length;++n<i;)(e=+t[n][1])&&(r+=e);return r}Et.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._point=0},lineEnd:function(){this._point&&this._context.closePath()},point:function(t,e){t=+t,e=+e,this._point?this._context.lineTo(t,e):(this._point=1,this._context.moveTo(t,e))}},zt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=this._t0=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x1,this._y1);break;case 3:Ot(this,this._t0,Pt(this,this._t0))}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){var r=NaN;if(e=+e,(t=+t)!==this._x1||e!==this._y1){switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,Ot(this,Pt(this,r=Lt(this,t,e)),r);break;default:Ot(this,this._t0,r=Lt(this,t,e))}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e,this._t0=r}}},(It.prototype=Object.create(zt.prototype)).point=function(t,e){zt.prototype.point.call(this,e,t)},Dt.prototype={moveTo:function(t,e){this._context.moveTo(e,t)},closePath:function(){this._context.closePath()},lineTo:function(t,e){this._context.lineTo(e,t)},bezierCurveTo:function(t,e,r,n,i,a){this._context.bezierCurveTo(e,t,n,r,a,i)}},Rt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=[],this._y=[]},lineEnd:function(){var t=this._x,e=this._y,r=t.length;if(r)if(this._line?this._context.lineTo(t[0],e[0]):this._context.moveTo(t[0],e[0]),2===r)this._context.lineTo(t[1],e[1]);else for(var n=Ft(t),i=Ft(e),a=0,o=1;o<r;++a,++o)this._context.bezierCurveTo(n[0][a],i[0][a],n[1][a],i[1][a],t[o],e[o]);(this._line||0!==this._line&&1===r)&&this._context.closePath(),this._line=1-this._line,this._x=this._y=null},point:function(t,e){this._x.push(+t),this._y.push(+e)}},Bt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=this._y=NaN,this._point=0},lineEnd:function(){0<this._t&&this._t<1&&2===this._point&&this._context.lineTo(this._x,this._y),(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line>=0&&(this._t=1-this._t,this._line=1-this._line)},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:if(this._t<=0)this._context.lineTo(this._x,e),this._context.lineTo(t,e);else{var r=this._x*(1-this._t)+t*this._t;this._context.lineTo(r,this._y),this._context.lineTo(r,e)}}this._x=t,this._y=e}},t.arc=function(){var t=g,o=v,_=r(0),w=null,k=m,T=y,A=x,M=null;function S(){var r,g,v,m=+t.apply(this,arguments),y=+o.apply(this,arguments),x=k.apply(this,arguments)-f,S=T.apply(this,arguments)-f,E=n(S-x),C=S>x;if(M||(M=r=e.path()),y<m&&(g=y,y=m,m=g),y>u)if(E>p-u)M.moveTo(y*a(x),y*l(x)),M.arc(0,0,y,x,S,!C),m>u&&(M.moveTo(m*a(S),m*l(S)),M.arc(0,0,m,S,x,C));else{var L,P,O=x,z=S,I=x,D=S,R=E,F=E,B=A.apply(this,arguments)/2,N=B>u&&(w?+w.apply(this,arguments):c(m*m+y*y)),j=s(n(y-m)/2,+_.apply(this,arguments)),U=j,V=j;if(N>u){var q=d(N/m*l(B)),H=d(N/y*l(B));(R-=2*q)>u?(I+=q*=C?1:-1,D-=q):(R=0,I=D=(x+S)/2),(F-=2*H)>u?(O+=H*=C?1:-1,z-=H):(F=0,O=z=(x+S)/2)}var G=y*a(O),Y=y*l(O),W=m*a(D),X=m*l(D);if(j>u){var Z,J=y*a(z),K=y*l(z),$=m*a(I),Q=m*l(I);if(E<h&&(Z=function(t,e,r,n,i,a,o,s){var l=r-t,c=n-e,h=o-i,f=s-a,p=f*l-h*c;if(!(p*p<u))return[t+(p=(h*(e-a)-f*(t-i))/p)*l,e+p*c]}(G,Y,$,Q,J,K,W,X))){var tt=G-Z[0],et=Y-Z[1],rt=J-Z[0],nt=K-Z[1],it=1/l(((v=(tt*rt+et*nt)/(c(tt*tt+et*et)*c(rt*rt+nt*nt)))>1?0:v<-1?h:Math.acos(v))/2),at=c(Z[0]*Z[0]+Z[1]*Z[1]);U=s(j,(m-at)/(it-1)),V=s(j,(y-at)/(it+1))}}F>u?V>u?(L=b($,Q,G,Y,y,V,C),P=b(J,K,W,X,y,V,C),M.moveTo(L.cx+L.x01,L.cy+L.y01),V<j?M.arc(L.cx,L.cy,V,i(L.y01,L.x01),i(P.y01,P.x01),!C):(M.arc(L.cx,L.cy,V,i(L.y01,L.x01),i(L.y11,L.x11),!C),M.arc(0,0,y,i(L.cy+L.y11,L.cx+L.x11),i(P.cy+P.y11,P.cx+P.x11),!C),M.arc(P.cx,P.cy,V,i(P.y11,P.x11),i(P.y01,P.x01),!C))):(M.moveTo(G,Y),M.arc(0,0,y,O,z,!C)):M.moveTo(G,Y),m>u&&R>u?U>u?(L=b(W,X,J,K,m,-U,C),P=b(G,Y,$,Q,m,-U,C),M.lineTo(L.cx+L.x01,L.cy+L.y01),U<j?M.arc(L.cx,L.cy,U,i(L.y01,L.x01),i(P.y01,P.x01),!C):(M.arc(L.cx,L.cy,U,i(L.y01,L.x01),i(L.y11,L.x11),!C),M.arc(0,0,m,i(L.cy+L.y11,L.cx+L.x11),i(P.cy+P.y11,P.cx+P.x11),C),M.arc(P.cx,P.cy,U,i(P.y11,P.x11),i(P.y01,P.x01),!C))):M.arc(0,0,m,D,I,C):M.lineTo(W,X)}else M.moveTo(0,0);if(M.closePath(),r)return M=null,r+\"\"||null}return S.centroid=function(){var e=(+t.apply(this,arguments)+ +o.apply(this,arguments))/2,r=(+k.apply(this,arguments)+ +T.apply(this,arguments))/2-h/2;return[a(r)*e,l(r)*e]},S.innerRadius=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),S):t},S.outerRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),S):o},S.cornerRadius=function(t){return arguments.length?(_=\"function\"==typeof t?t:r(+t),S):_},S.padRadius=function(t){return arguments.length?(w=null==t?null:\"function\"==typeof t?t:r(+t),S):w},S.startAngle=function(t){return arguments.length?(k=\"function\"==typeof t?t:r(+t),S):k},S.endAngle=function(t){return arguments.length?(T=\"function\"==typeof t?t:r(+t),S):T},S.padAngle=function(t){return arguments.length?(A=\"function\"==typeof t?t:r(+t),S):A},S.context=function(t){return arguments.length?(M=null==t?null:t,S):M},S},t.area=M,t.line=A,t.pie=function(){var t=E,e=S,n=null,i=r(0),a=r(p),o=r(0);function s(r){var s,l,c,u,h,f=r.length,d=0,g=new Array(f),v=new Array(f),m=+i.apply(this,arguments),y=Math.min(p,Math.max(-p,a.apply(this,arguments)-m)),x=Math.min(Math.abs(y)/f,o.apply(this,arguments)),b=x*(y<0?-1:1);for(s=0;s<f;++s)(h=v[g[s]=s]=+t(r[s],s,r))>0&&(d+=h);for(null!=e?g.sort(function(t,r){return e(v[t],v[r])}):null!=n&&g.sort(function(t,e){return n(r[t],r[e])}),s=0,c=d?(y-f*b)/d:0;s<f;++s,m=u)l=g[s],u=m+((h=v[l])>0?h*c:0)+b,v[l]={data:r[l],index:s,value:h,startAngle:m,endAngle:u,padAngle:x};return v}return s.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),s):t},s.sortValues=function(t){return arguments.length?(e=t,n=null,s):e},s.sort=function(t){return arguments.length?(n=t,e=null,s):n},s.startAngle=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),s):i},s.endAngle=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),s):a},s.padAngle=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),s):o},s},t.areaRadial=I,t.radialArea=I,t.lineRadial=z,t.radialLine=z,t.pointRadial=D,t.linkHorizontal=function(){return N(j)},t.linkVertical=function(){return N(U)},t.linkRadial=function(){var t=N(V);return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t},t.symbol=function(){var t=r(q),n=r(64),i=null;function a(){var r;if(i||(i=r=e.path()),t.apply(this,arguments).draw(i,+n.apply(this,arguments)),r)return i=null,r+\"\"||null}return a.type=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(e),a):t},a.size=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),a):n},a.context=function(t){return arguments.length?(i=null==t?null:t,a):i},a},t.symbols=ot,t.symbolCircle=q,t.symbolCross=H,t.symbolDiamond=W,t.symbolSquare=$,t.symbolStar=K,t.symbolTriangle=tt,t.symbolWye=at,t.curveBasisClosed=function(t){return new ut(t)},t.curveBasisOpen=function(t){return new ht(t)},t.curveBasis=function(t){return new ct(t)},t.curveBundle=pt,t.curveCardinalClosed=yt,t.curveCardinalOpen=bt,t.curveCardinal=vt,t.curveCatmullRomClosed=At,t.curveCatmullRomOpen=St,t.curveCatmullRom=kt,t.curveLinearClosed=function(t){return new Et(t)},t.curveLinear=w,t.curveMonotoneX=function(t){return new zt(t)},t.curveMonotoneY=function(t){return new It(t)},t.curveNatural=function(t){return new Rt(t)},t.curveStep=function(t){return new Bt(t,.5)},t.curveStepAfter=function(t){return new Bt(t,1)},t.curveStepBefore=function(t){return new Bt(t,0)},t.stack=function(){var t=r([]),e=jt,n=Nt,i=Ut;function a(r){var a,o,s=t.apply(this,arguments),l=r.length,c=s.length,u=new Array(c);for(a=0;a<c;++a){for(var h,f=s[a],p=u[a]=new Array(l),d=0;d<l;++d)p[d]=h=[0,+i(r[d],f,d,r)],h.data=r[d];p.key=f}for(a=0,o=e(u);a<c;++a)u[o[a]].index=a;return n(u,o),u}return a.keys=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(R.call(e)),a):t},a.value=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a):i},a.order=function(t){return arguments.length?(e=null==t?jt:\"function\"==typeof t?t:r(R.call(t)),a):e},a.offset=function(t){return arguments.length?(n=null==t?Nt:t,a):n},a},t.stackOffsetExpand=function(t,e){if((n=t.length)>0){for(var r,n,i,a=0,o=t[0].length;a<o;++a){for(i=r=0;r<n;++r)i+=t[r][a][1]||0;if(i)for(r=0;r<n;++r)t[r][a][1]/=i}Nt(t,e)}},t.stackOffsetDiverging=function(t,e){if((s=t.length)>1)for(var r,n,i,a,o,s,l=0,c=t[e[0]].length;l<c;++l)for(a=o=0,r=0;r<s;++r)(i=(n=t[e[r]][l])[1]-n[0])>=0?(n[0]=a,n[1]=a+=i):i<0?(n[1]=o,n[0]=o+=i):n[0]=a},t.stackOffsetNone=Nt,t.stackOffsetSilhouette=function(t,e){if((r=t.length)>0){for(var r,n=0,i=t[e[0]],a=i.length;n<a;++n){for(var o=0,s=0;o<r;++o)s+=t[o][n][1]||0;i[n][1]+=i[n][0]=-s/2}Nt(t,e)}},t.stackOffsetWiggle=function(t,e){if((i=t.length)>0&&(n=(r=t[e[0]]).length)>0){for(var r,n,i,a=0,o=1;o<n;++o){for(var s=0,l=0,c=0;s<i;++s){for(var u=t[e[s]],h=u[o][1]||0,f=(h-(u[o-1][1]||0))/2,p=0;p<s;++p){var d=t[e[p]];f+=(d[o][1]||0)-(d[o-1][1]||0)}l+=h,c+=f*h}r[o-1][1]+=r[o-1][0]=a,l&&(a-=c/l)}r[o-1][1]+=r[o-1][0]=a,Nt(t,e)}},t.stackOrderAppearance=Vt,t.stackOrderAscending=Ht,t.stackOrderDescending=function(t){return Ht(t).reverse()},t.stackOrderInsideOut=function(t){var e,r,n=t.length,i=t.map(Gt),a=Vt(t),o=0,s=0,l=[],c=[];for(e=0;e<n;++e)r=a[e],o<s?(o+=i[r],l.push(r)):(s+=i[r],c.push(r));return c.reverse().concat(l)},t.stackOrderNone=jt,t.stackOrderReverse=function(t){return jt(t).reverse()},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-path\")):i(n.d3=n.d3||{},n.d3)},{\"d3-path\":159}],162:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e,r,n=0,i=0,a=0,o=1e3,s=0,l=0,c=0,u=\"object\"==typeof performance&&performance.now?performance:Date,h=\"object\"==typeof window&&window.requestAnimationFrame?window.requestAnimationFrame.bind(window):function(t){setTimeout(t,17)};function f(){return l||(h(p),l=u.now()+c)}function p(){l=0}function d(){this._call=this._time=this._next=null}function g(t,e,r){var n=new d;return n.restart(t,e,r),n}function v(){f(),++n;for(var t,r=e;r;)(t=l-r._time)>=0&&r._call.call(null,t),r=r._next;--n}function m(){l=(s=u.now())+c,n=i=0;try{v()}finally{n=0,function(){var t,n,i=e,a=1/0;for(;i;)i._call?(a>i._time&&(a=i._time),t=i,i=i._next):(n=i._next,i._next=null,i=t?t._next=n:e=n);r=t,x(a)}(),l=0}}function y(){var t=u.now(),e=t-s;e>o&&(c-=e,s=t)}function x(t){n||(i&&(i=clearTimeout(i)),t-l>24?(t<1/0&&(i=setTimeout(m,t-u.now()-c)),a&&(a=clearInterval(a))):(a||(s=u.now(),a=setInterval(y,o)),n=1,h(m)))}d.prototype=g.prototype={constructor:d,restart:function(t,n,i){if(\"function\"!=typeof t)throw new TypeError(\"callback is not a function\");i=(null==i?f():+i)+(null==n?0:+n),this._next||r===this||(r?r._next=this:e=this,r=this),this._call=t,this._time=i,x()},stop:function(){this._call&&(this._call=null,this._time=1/0,x())}};t.now=f,t.timer=g,t.timerFlush=v,t.timeout=function(t,e,r){var n=new d;return e=null==e?0:+e,n.restart(function(r){n.stop(),t(r+e)},e,r),n},t.interval=function(t,e,r){var n=new d,i=e;return null==e?(n.restart(t,e,r),n):(e=+e,r=null==r?f():+r,n.restart(function a(o){o+=i,n.restart(a,i+=e,r),t(o)},e,r),n)},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],163:[function(t,e,r){!function(){var t={version:\"3.5.17\"},r=[].slice,n=function(t){return r.call(t)},i=this.document;function a(t){return t&&(t.ownerDocument||t.document||t).documentElement}function o(t){return t&&(t.ownerDocument&&t.ownerDocument.defaultView||t.document&&t||t.defaultView)}if(i)try{n(i.documentElement.childNodes)[0].nodeType}catch(t){n=function(t){for(var e=t.length,r=new Array(e);e--;)r[e]=t[e];return r}}if(Date.now||(Date.now=function(){return+new Date}),i)try{i.createElement(\"DIV\").style.setProperty(\"opacity\",0,\"\")}catch(t){var s=this.Element.prototype,l=s.setAttribute,c=s.setAttributeNS,u=this.CSSStyleDeclaration.prototype,h=u.setProperty;s.setAttribute=function(t,e){l.call(this,t,e+\"\")},s.setAttributeNS=function(t,e,r){c.call(this,t,e,r+\"\")},u.setProperty=function(t,e,r){h.call(this,t,e+\"\",r)}}function f(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function p(t){return null===t?NaN:+t}function d(t){return!isNaN(t)}function g(t){return{left:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}t.ascending=f,t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.min=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&r>n&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&r>n&&(r=n)}return r},t.max=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&n>r&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&n>r&&(r=n)}return r},t.extent=function(t,e){var r,n,i,a=-1,o=t.length;if(1===arguments.length){for(;++a<o;)if(null!=(n=t[a])&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=t[a])&&(r>n&&(r=n),i<n&&(i=n))}else{for(;++a<o;)if(null!=(n=e.call(t,t[a],a))&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=e.call(t,t[a],a))&&(r>n&&(r=n),i<n&&(i=n))}return[r,i]},t.sum=function(t,e){var r,n=0,i=t.length,a=-1;if(1===arguments.length)for(;++a<i;)d(r=+t[a])&&(n+=r);else for(;++a<i;)d(r=+e.call(t,t[a],a))&&(n+=r);return n},t.mean=function(t,e){var r,n=0,i=t.length,a=-1,o=i;if(1===arguments.length)for(;++a<i;)d(r=p(t[a]))?n+=r:--o;else for(;++a<i;)d(r=p(e.call(t,t[a],a)))?n+=r:--o;if(o)return n/o},t.quantile=function(t,e){var r=(t.length-1)*e+1,n=Math.floor(r),i=+t[n-1],a=r-n;return a?i+a*(t[n]-i):i},t.median=function(e,r){var n,i=[],a=e.length,o=-1;if(1===arguments.length)for(;++o<a;)d(n=p(e[o]))&&i.push(n);else for(;++o<a;)d(n=p(r.call(e,e[o],o)))&&i.push(n);if(i.length)return t.quantile(i.sort(f),.5)},t.variance=function(t,e){var r,n,i=t.length,a=0,o=0,s=-1,l=0;if(1===arguments.length)for(;++s<i;)d(r=p(t[s]))&&(o+=(n=r-a)*(r-(a+=n/++l)));else for(;++s<i;)d(r=p(e.call(t,t[s],s)))&&(o+=(n=r-a)*(r-(a+=n/++l)));if(l>1)return o/(l-1)},t.deviation=function(){var e=t.variance.apply(this,arguments);return e?Math.sqrt(e):e};var v=g(f);function m(t){return t.length}t.bisectLeft=v.left,t.bisect=t.bisectRight=v.right,t.bisector=function(t){return g(1===t.length?function(e,r){return f(t(e),r)}:t)},t.shuffle=function(t,e,r){(a=arguments.length)<3&&(r=t.length,a<2&&(e=0));for(var n,i,a=r-e;a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.pairs=function(t){for(var e=0,r=t.length-1,n=t[0],i=new Array(r<0?0:r);e<r;)i[e]=[n,n=t[++e]];return i},t.transpose=function(e){if(!(a=e.length))return[];for(var r=-1,n=t.min(e,m),i=new Array(n);++r<n;)for(var a,o=-1,s=i[r]=new Array(a);++o<a;)s[o]=e[o][r];return i},t.zip=function(){return t.transpose(arguments)},t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r};var y=Math.abs;function x(t,e){for(var r in e)Object.defineProperty(t.prototype,r,{value:e[r],enumerable:!1})}function b(){this._=Object.create(null)}t.range=function(t,e,r){if(arguments.length<3&&(r=1,arguments.length<2&&(e=t,t=0)),(e-t)/r==1/0)throw new Error(\"infinite range\");var n,i=[],a=function(t){var e=1;for(;t*e%1;)e*=10;return e}(y(r)),o=-1;if(t*=a,e*=a,(r*=a)<0)for(;(n=t+r*++o)>e;)i.push(n/a);else for(;(n=t+r*++o)<e;)i.push(n/a);return i},t.map=function(t,e){var r=new b;if(t instanceof b)t.forEach(function(t,e){r.set(t,e)});else if(Array.isArray(t)){var n,i=-1,a=t.length;if(1===arguments.length)for(;++i<a;)r.set(i,t[i]);else for(;++i<a;)r.set(e.call(t,n=t[i],i),n)}else for(var o in t)r.set(o,t[o]);return r};var _=\"__proto__\",w=\"\\0\";function k(t){return(t+=\"\")===_||t[0]===w?w+t:t}function T(t){return(t+=\"\")[0]===w?t.slice(1):t}function A(t){return k(t)in this._}function M(t){return(t=k(t))in this._&&delete this._[t]}function S(){var t=[];for(var e in this._)t.push(T(e));return t}function E(){var t=0;for(var e in this._)++t;return t}function C(){for(var t in this._)return!1;return!0}function L(){this._=Object.create(null)}function P(t){return t}function O(t,e,r){return function(){var n=r.apply(e,arguments);return n===e?t:n}}function z(t,e){if(e in t)return e;e=e.charAt(0).toUpperCase()+e.slice(1);for(var r=0,n=I.length;r<n;++r){var i=I[r]+e;if(i in t)return i}}x(b,{has:A,get:function(t){return this._[k(t)]},set:function(t,e){return this._[k(t)]=e},remove:M,keys:S,values:function(){var t=[];for(var e in this._)t.push(this._[e]);return t},entries:function(){var t=[];for(var e in this._)t.push({key:T(e),value:this._[e]});return t},size:E,empty:C,forEach:function(t){for(var e in this._)t.call(this,T(e),this._[e])}}),t.nest=function(){var e,r,n={},i=[],a=[];function o(t,a,s){if(s>=i.length)return r?r.call(n,a):e?a.sort(e):a;for(var l,c,u,h,f=-1,p=a.length,d=i[s++],g=new b;++f<p;)(h=g.get(l=d(c=a[f])))?h.push(c):g.set(l,[c]);return t?(c=t(),u=function(e,r){c.set(e,o(t,r,s))}):(c={},u=function(e,r){c[e]=o(t,r,s)}),g.forEach(u),c}return n.map=function(t,e){return o(e,t,0)},n.entries=function(e){return function t(e,r){if(r>=i.length)return e;var n=[],o=a[r++];return e.forEach(function(e,i){n.push({key:e,values:t(i,r)})}),o?n.sort(function(t,e){return o(t.key,e.key)}):n}(o(t.map,e,0),0)},n.key=function(t){return i.push(t),n},n.sortKeys=function(t){return a[i.length-1]=t,n},n.sortValues=function(t){return e=t,n},n.rollup=function(t){return r=t,n},n},t.set=function(t){var e=new L;if(t)for(var r=0,n=t.length;r<n;++r)e.add(t[r]);return e},x(L,{has:A,add:function(t){return this._[k(t+=\"\")]=!0,t},remove:M,values:S,size:E,empty:C,forEach:function(t){for(var e in this._)t.call(this,T(e))}}),t.behavior={},t.rebind=function(t,e){for(var r,n=1,i=arguments.length;++n<i;)t[r=arguments[n]]=O(t,e,e[r]);return t};var I=[\"webkit\",\"ms\",\"moz\",\"Moz\",\"o\",\"O\"];function D(){}function R(){}function F(t){var e=[],r=new b;function n(){for(var r,n=e,i=-1,a=n.length;++i<a;)(r=n[i].on)&&r.apply(this,arguments);return t}return n.on=function(n,i){var a,o=r.get(n);return arguments.length<2?o&&o.on:(o&&(o.on=null,e=e.slice(0,a=e.indexOf(o)).concat(e.slice(a+1)),r.remove(n)),i&&e.push(r.set(n,{on:i})),t)},n}function B(){t.event.preventDefault()}function N(){for(var e,r=t.event;e=r.sourceEvent;)r=e;return r}function j(e){for(var r=new R,n=0,i=arguments.length;++n<i;)r[arguments[n]]=F(r);return r.of=function(n,i){return function(a){try{var o=a.sourceEvent=t.event;a.target=e,t.event=a,r[a.type].apply(n,i)}finally{t.event=o}}},r}t.dispatch=function(){for(var t=new R,e=-1,r=arguments.length;++e<r;)t[arguments[e]]=F(t);return t},R.prototype.on=function(t,e){var r=t.indexOf(\".\"),n=\"\";if(r>=0&&(n=t.slice(r+1),t=t.slice(0,r)),t)return arguments.length<2?this[t].on(n):this[t].on(n,e);if(2===arguments.length){if(null==e)for(t in this)this.hasOwnProperty(t)&&this[t].on(n,null);return this}},t.event=null,t.requote=function(t){return t.replace(U,\"\\\\$&\")};var U=/[\\\\\\^\\$\\*\\+\\?\\|\\[\\]\\(\\)\\.\\{\\}]/g,V={}.__proto__?function(t,e){t.__proto__=e}:function(t,e){for(var r in e)t[r]=e[r]};function q(t){return V(t,W),t}var H=function(t,e){return e.querySelector(t)},G=function(t,e){return e.querySelectorAll(t)},Y=function(t,e){var r=t.matches||t[z(t,\"matchesSelector\")];return(Y=function(t,e){return r.call(t,e)})(t,e)};\"function\"==typeof Sizzle&&(H=function(t,e){return Sizzle(t,e)[0]||null},G=Sizzle,Y=Sizzle.matchesSelector),t.selection=function(){return t.select(i.documentElement)};var W=t.selection.prototype=[];function X(t){return\"function\"==typeof t?t:function(){return H(t,this)}}function Z(t){return\"function\"==typeof t?t:function(){return G(t,this)}}W.select=function(t){var e,r,n,i,a=[];t=X(t);for(var o=-1,s=this.length;++o<s;){a.push(e=[]),e.parentNode=(n=this[o]).parentNode;for(var l=-1,c=n.length;++l<c;)(i=n[l])?(e.push(r=t.call(i,i.__data__,l,o)),r&&\"__data__\"in i&&(r.__data__=i.__data__)):e.push(null)}return q(a)},W.selectAll=function(t){var e,r,i=[];t=Z(t);for(var a=-1,o=this.length;++a<o;)for(var s=this[a],l=-1,c=s.length;++l<c;)(r=s[l])&&(i.push(e=n(t.call(r,r.__data__,l,a))),e.parentNode=r);return q(i)};var J=\"http://www.w3.org/1999/xhtml\",K={svg:\"http://www.w3.org/2000/svg\",xhtml:J,xlink:\"http://www.w3.org/1999/xlink\",xml:\"http://www.w3.org/XML/1998/namespace\",xmlns:\"http://www.w3.org/2000/xmlns/\"};function $(e,r){return e=t.ns.qualify(e),null==r?e.local?function(){this.removeAttributeNS(e.space,e.local)}:function(){this.removeAttribute(e)}:\"function\"==typeof r?e.local?function(){var t=r.apply(this,arguments);null==t?this.removeAttributeNS(e.space,e.local):this.setAttributeNS(e.space,e.local,t)}:function(){var t=r.apply(this,arguments);null==t?this.removeAttribute(e):this.setAttribute(e,t)}:e.local?function(){this.setAttributeNS(e.space,e.local,r)}:function(){this.setAttribute(e,r)}}function Q(t){return t.trim().replace(/\\s+/g,\" \")}function tt(e){return new RegExp(\"(?:^|\\\\s+)\"+t.requote(e)+\"(?:\\\\s+|$)\",\"g\")}function et(t){return(t+\"\").trim().split(/^|\\s+/)}function rt(t,e){var r=(t=et(t).map(nt)).length;return\"function\"==typeof e?function(){for(var n=-1,i=e.apply(this,arguments);++n<r;)t[n](this,i)}:function(){for(var n=-1;++n<r;)t[n](this,e)}}function nt(t){var e=tt(t);return function(r,n){if(i=r.classList)return n?i.add(t):i.remove(t);var i=r.getAttribute(\"class\")||\"\";n?(e.lastIndex=0,e.test(i)||r.setAttribute(\"class\",Q(i+\" \"+t))):r.setAttribute(\"class\",Q(i.replace(e,\" \")))}}function it(t,e,r){return null==e?function(){this.style.removeProperty(t)}:\"function\"==typeof e?function(){var n=e.apply(this,arguments);null==n?this.style.removeProperty(t):this.style.setProperty(t,n,r)}:function(){this.style.setProperty(t,e,r)}}function at(t,e){return null==e?function(){delete this[t]}:\"function\"==typeof e?function(){var r=e.apply(this,arguments);null==r?delete this[t]:this[t]=r}:function(){this[t]=e}}function ot(e){return\"function\"==typeof e?e:(e=t.ns.qualify(e)).local?function(){return this.ownerDocument.createElementNS(e.space,e.local)}:function(){var t=this.ownerDocument,r=this.namespaceURI;return r===J&&t.documentElement.namespaceURI===J?t.createElement(e):t.createElementNS(r,e)}}function st(){var t=this.parentNode;t&&t.removeChild(this)}function lt(t){return{__data__:t}}function ct(t){return function(){return Y(this,t)}}function ut(t,e){for(var r=0,n=t.length;r<n;r++)for(var i,a=t[r],o=0,s=a.length;o<s;o++)(i=a[o])&&e(i,o,r);return t}function ht(t){return V(t,ft),t}t.ns={prefix:K,qualify:function(t){var e=t.indexOf(\":\"),r=t;return e>=0&&\"xmlns\"!==(r=t.slice(0,e))&&(t=t.slice(e+1)),K.hasOwnProperty(r)?{space:K[r],local:t}:t}},W.attr=function(e,r){if(arguments.length<2){if(\"string\"==typeof e){var n=this.node();return(e=t.ns.qualify(e)).local?n.getAttributeNS(e.space,e.local):n.getAttribute(e)}for(r in e)this.each($(r,e[r]));return this}return this.each($(e,r))},W.classed=function(t,e){if(arguments.length<2){if(\"string\"==typeof t){var r=this.node(),n=(t=et(t)).length,i=-1;if(e=r.classList){for(;++i<n;)if(!e.contains(t[i]))return!1}else for(e=r.getAttribute(\"class\");++i<n;)if(!tt(t[i]).test(e))return!1;return!0}for(e in t)this.each(rt(e,t[e]));return this}return this.each(rt(t,e))},W.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.each(it(r,t[r],e));return this}if(n<2){var i=this.node();return o(i).getComputedStyle(i,null).getPropertyValue(t)}r=\"\"}return this.each(it(t,e,r))},W.property=function(t,e){if(arguments.length<2){if(\"string\"==typeof t)return this.node()[t];for(e in t)this.each(at(e,t[e]));return this}return this.each(at(t,e))},W.text=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.textContent=null==e?\"\":e}:null==t?function(){this.textContent=\"\"}:function(){this.textContent=t}):this.node().textContent},W.html=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.innerHTML=null==e?\"\":e}:null==t?function(){this.innerHTML=\"\"}:function(){this.innerHTML=t}):this.node().innerHTML},W.append=function(t){return t=ot(t),this.select(function(){return this.appendChild(t.apply(this,arguments))})},W.insert=function(t,e){return t=ot(t),e=X(e),this.select(function(){return this.insertBefore(t.apply(this,arguments),e.apply(this,arguments)||null)})},W.remove=function(){return this.each(st)},W.data=function(t,e){var r,n,i=-1,a=this.length;if(!arguments.length){for(t=new Array(a=(r=this[0]).length);++i<a;)(n=r[i])&&(t[i]=n.__data__);return t}function o(t,r){var n,i,a,o=t.length,u=r.length,h=Math.min(o,u),f=new Array(u),p=new Array(u),d=new Array(o);if(e){var g,v=new b,m=new Array(o);for(n=-1;++n<o;)(i=t[n])&&(v.has(g=e.call(i,i.__data__,n))?d[n]=i:v.set(g,i),m[n]=g);for(n=-1;++n<u;)(i=v.get(g=e.call(r,a=r[n],n)))?!0!==i&&(f[n]=i,i.__data__=a):p[n]=lt(a),v.set(g,!0);for(n=-1;++n<o;)n in m&&!0!==v.get(m[n])&&(d[n]=t[n])}else{for(n=-1;++n<h;)i=t[n],a=r[n],i?(i.__data__=a,f[n]=i):p[n]=lt(a);for(;n<u;++n)p[n]=lt(r[n]);for(;n<o;++n)d[n]=t[n]}p.update=f,p.parentNode=f.parentNode=d.parentNode=t.parentNode,s.push(p),l.push(f),c.push(d)}var s=ht([]),l=q([]),c=q([]);if(\"function\"==typeof t)for(;++i<a;)o(r=this[i],t.call(r,r.parentNode.__data__,i));else for(;++i<a;)o(r=this[i],t);return l.enter=function(){return s},l.exit=function(){return c},l},W.datum=function(t){return arguments.length?this.property(\"__data__\",t):this.property(\"__data__\")},W.filter=function(t){var e,r,n,i=[];\"function\"!=typeof t&&(t=ct(t));for(var a=0,o=this.length;a<o;a++){i.push(e=[]),e.parentNode=(r=this[a]).parentNode;for(var s=0,l=r.length;s<l;s++)(n=r[s])&&t.call(n,n.__data__,s,a)&&e.push(n)}return q(i)},W.order=function(){for(var t=-1,e=this.length;++t<e;)for(var r,n=this[t],i=n.length-1,a=n[i];--i>=0;)(r=n[i])&&(a&&a!==r.nextSibling&&a.parentNode.insertBefore(r,a),a=r);return this},W.sort=function(t){t=function(t){arguments.length||(t=f);return function(e,r){return e&&r?t(e.__data__,r.__data__):!e-!r}}.apply(this,arguments);for(var e=-1,r=this.length;++e<r;)this[e].sort(t);return this.order()},W.each=function(t){return ut(this,function(e,r,n){t.call(e,e.__data__,r,n)})},W.call=function(t){var e=n(arguments);return t.apply(e[0]=this,e),this},W.empty=function(){return!this.node()},W.node=function(){for(var t=0,e=this.length;t<e;t++)for(var r=this[t],n=0,i=r.length;n<i;n++){var a=r[n];if(a)return a}return null},W.size=function(){var t=0;return ut(this,function(){++t}),t};var ft=[];function pt(e,r,i){var a=\"__on\"+e,o=e.indexOf(\".\"),s=gt;o>0&&(e=e.slice(0,o));var l=dt.get(e);function c(){var t=this[a];t&&(this.removeEventListener(e,t,t.$),delete this[a])}return l&&(e=l,s=vt),o?r?function(){var t=s(r,n(arguments));c.call(this),this.addEventListener(e,this[a]=t,t.$=i),t._=r}:c:r?D:function(){var r,n=new RegExp(\"^__on([^.]+)\"+t.requote(e)+\"$\");for(var i in this)if(r=i.match(n)){var a=this[i];this.removeEventListener(r[1],a,a.$),delete this[i]}}}t.selection.enter=ht,t.selection.enter.prototype=ft,ft.append=W.append,ft.empty=W.empty,ft.node=W.node,ft.call=W.call,ft.size=W.size,ft.select=function(t){for(var e,r,n,i,a,o=[],s=-1,l=this.length;++s<l;){n=(i=this[s]).update,o.push(e=[]),e.parentNode=i.parentNode;for(var c=-1,u=i.length;++c<u;)(a=i[c])?(e.push(n[c]=r=t.call(i.parentNode,a.__data__,c,s)),r.__data__=a.__data__):e.push(null)}return q(o)},ft.insert=function(t,e){var r,n,i;return arguments.length<2&&(r=this,e=function(t,e,a){var o,s=r[a].update,l=s.length;for(a!=i&&(i=a,n=0),e>=n&&(n=e+1);!(o=s[n])&&++n<l;);return o}),W.insert.call(this,t,e)},t.select=function(t){var e;return\"string\"==typeof t?(e=[H(t,i)]).parentNode=i.documentElement:(e=[t]).parentNode=a(t),q([e])},t.selectAll=function(t){var e;return\"string\"==typeof t?(e=n(G(t,i))).parentNode=i.documentElement:(e=n(t)).parentNode=null,q([e])},W.on=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=!1),t)this.each(pt(r,t[r],e));return this}if(n<2)return(n=this.node()[\"__on\"+t])&&n._;r=!1}return this.each(pt(t,e,r))};var dt=t.map({mouseenter:\"mouseover\",mouseleave:\"mouseout\"});function gt(e,r){return function(n){var i=t.event;t.event=n,r[0]=this.__data__;try{e.apply(this,r)}finally{t.event=i}}}function vt(t,e){var r=gt(t,e);return function(t){var e=t.relatedTarget;e&&(e===this||8&e.compareDocumentPosition(this))||r.call(this,t)}}i&&dt.forEach(function(t){\"on\"+t in i&&dt.remove(t)});var mt,yt=0;function xt(e){var r=\".dragsuppress-\"+ ++yt,n=\"click\"+r,i=t.select(o(e)).on(\"touchmove\"+r,B).on(\"dragstart\"+r,B).on(\"selectstart\"+r,B);if(null==mt&&(mt=!(\"onselectstart\"in e)&&z(e.style,\"userSelect\")),mt){var s=a(e).style,l=s[mt];s[mt]=\"none\"}return function(t){if(i.on(r,null),mt&&(s[mt]=l),t){var e=function(){i.on(n,null)};i.on(n,function(){B(),e()},!0),setTimeout(e,0)}}}t.mouse=function(t){return _t(t,N())};var bt=this.navigator&&/WebKit/.test(this.navigator.userAgent)?-1:0;function _t(e,r){r.changedTouches&&(r=r.changedTouches[0]);var n=e.ownerSVGElement||e;if(n.createSVGPoint){var i=n.createSVGPoint();if(bt<0){var a=o(e);if(a.scrollX||a.scrollY){var s=(n=t.select(\"body\").append(\"svg\").style({position:\"absolute\",top:0,left:0,margin:0,padding:0,border:\"none\"},\"important\"))[0][0].getScreenCTM();bt=!(s.f||s.e),n.remove()}}return bt?(i.x=r.pageX,i.y=r.pageY):(i.x=r.clientX,i.y=r.clientY),[(i=i.matrixTransform(e.getScreenCTM().inverse())).x,i.y]}var l=e.getBoundingClientRect();return[r.clientX-l.left-e.clientLeft,r.clientY-l.top-e.clientTop]}function wt(){return t.event.changedTouches[0].identifier}t.touch=function(t,e,r){if(arguments.length<3&&(r=e,e=N().changedTouches),e)for(var n,i=0,a=e.length;i<a;++i)if((n=e[i]).identifier===r)return _t(t,n)},t.behavior.drag=function(){var e=j(a,\"drag\",\"dragstart\",\"dragend\"),r=null,n=s(D,t.mouse,o,\"mousemove\",\"mouseup\"),i=s(wt,t.touch,P,\"touchmove\",\"touchend\");function a(){this.on(\"mousedown.drag\",n).on(\"touchstart.drag\",i)}function s(n,i,a,o,s){return function(){var l,c=t.event.target.correspondingElement||t.event.target,u=this.parentNode,h=e.of(this,arguments),f=0,p=n(),d=\".drag\"+(null==p?\"\":\"-\"+p),g=t.select(a(c)).on(o+d,function(){var t,e,r=i(u,p);if(!r)return;t=r[0]-m[0],e=r[1]-m[1],f|=t|e,m=r,h({type:\"drag\",x:r[0]+l[0],y:r[1]+l[1],dx:t,dy:e})}).on(s+d,function(){if(!i(u,p))return;g.on(o+d,null).on(s+d,null),v(f),h({type:\"dragend\"})}),v=xt(c),m=i(u,p);l=r?[(l=r.apply(this,arguments)).x-m[0],l.y-m[1]]:[0,0],h({type:\"dragstart\"})}}return a.origin=function(t){return arguments.length?(r=t,a):r},t.rebind(a,e,\"on\")},t.touches=function(t,e){return arguments.length<2&&(e=N().touches),e?n(e).map(function(e){var r=_t(t,e);return r.identifier=e.identifier,r}):[]};var kt=1e-6,Tt=kt*kt,At=Math.PI,Mt=2*At,St=Mt-kt,Et=At/2,Ct=At/180,Lt=180/At;function Pt(t){return t>0?1:t<0?-1:0}function Ot(t,e,r){return(e[0]-t[0])*(r[1]-t[1])-(e[1]-t[1])*(r[0]-t[0])}function zt(t){return t>1?0:t<-1?At:Math.acos(t)}function It(t){return t>1?Et:t<-1?-Et:Math.asin(t)}function Dt(t){return((t=Math.exp(t))+1/t)/2}function Rt(t){return(t=Math.sin(t/2))*t}var Ft=Math.SQRT2;t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,h=l-a,f=u*u+h*h;if(f<Tt)n=Math.log(c/o)/Ft,r=function(t){return[i+t*u,a+t*h,o*Math.exp(Ft*t*n)]};else{var p=Math.sqrt(f),d=(c*c-o*o+4*f)/(2*o*2*p),g=(c*c-o*o-4*f)/(2*c*2*p),v=Math.log(Math.sqrt(d*d+1)-d),m=Math.log(Math.sqrt(g*g+1)-g);n=(m-v)/Ft,r=function(t){var e,r=t*n,s=Dt(v),l=o/(2*p)*(s*(e=Ft*r+v,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(v));return[i+l*u,a+l*h,o*s/Dt(Ft*r+v)]}}return r.duration=1e3*n,r},t.behavior.zoom=function(){var e,r,n,a,s,l,c,u,h,f={x:0,y:0,k:1},p=[960,500],d=jt,g=250,v=0,m=\"mousedown.zoom\",y=\"mousemove.zoom\",x=\"mouseup.zoom\",b=\"touchstart.zoom\",_=j(w,\"zoomstart\",\"zoom\",\"zoomend\");function w(t){t.on(m,P).on(Nt+\".zoom\",z).on(\"dblclick.zoom\",I).on(b,O)}function k(t){return[(t[0]-f.x)/f.k,(t[1]-f.y)/f.k]}function T(t){f.k=Math.max(d[0],Math.min(d[1],t))}function A(t,e){e=function(t){return[t[0]*f.k+f.x,t[1]*f.k+f.y]}(e),f.x+=t[0]-e[0],f.y+=t[1]-e[1]}function M(e,n,i,a){e.__chart__={x:f.x,y:f.y,k:f.k},T(Math.pow(2,a)),A(r=n,i),e=t.select(e),g>0&&(e=e.transition().duration(g)),e.call(w.event)}function S(){c&&c.domain(l.range().map(function(t){return(t-f.x)/f.k}).map(l.invert)),h&&h.domain(u.range().map(function(t){return(t-f.y)/f.k}).map(u.invert))}function E(t){v++||t({type:\"zoomstart\"})}function C(t){S(),t({type:\"zoom\",scale:f.k,translate:[f.x,f.y]})}function L(t){--v||(t({type:\"zoomend\"}),r=null)}function P(){var e=this,r=_.of(e,arguments),n=0,i=t.select(o(e)).on(y,function(){n=1,A(t.mouse(e),a),C(r)}).on(x,function(){i.on(y,null).on(x,null),s(n),L(r)}),a=k(t.mouse(e)),s=xt(e);hs.call(e),E(r)}function O(){var e,r=this,n=_.of(r,arguments),i={},a=0,o=\".zoom-\"+t.event.changedTouches[0].identifier,l=\"touchmove\"+o,c=\"touchend\"+o,u=[],h=t.select(r),p=xt(r);function d(){var n=t.touches(r);return e=f.k,n.forEach(function(t){t.identifier in i&&(i[t.identifier]=k(t))}),n}function g(){var e=t.event.target;t.select(e).on(l,v).on(c,y),u.push(e);for(var n=t.event.changedTouches,o=0,h=n.length;o<h;++o)i[n[o].identifier]=null;var p=d(),g=Date.now();if(1===p.length){if(g-s<500){var m=p[0];M(r,m,i[m.identifier],Math.floor(Math.log(f.k)/Math.LN2)+1),B()}s=g}else if(p.length>1){m=p[0];var x=p[1],b=m[0]-x[0],_=m[1]-x[1];a=b*b+_*_}}function v(){var o,l,c,u,h=t.touches(r);hs.call(r);for(var f=0,p=h.length;f<p;++f,u=null)if(c=h[f],u=i[c.identifier]){if(l)break;o=c,l=u}if(u){var d=(d=c[0]-o[0])*d+(d=c[1]-o[1])*d,g=a&&Math.sqrt(d/a);o=[(o[0]+c[0])/2,(o[1]+c[1])/2],l=[(l[0]+u[0])/2,(l[1]+u[1])/2],T(g*e)}s=null,A(o,l),C(n)}function y(){if(t.event.touches.length){for(var e=t.event.changedTouches,r=0,a=e.length;r<a;++r)delete i[e[r].identifier];for(var s in i)return void d()}t.selectAll(u).on(o,null),h.on(m,P).on(b,O),p(),L(n)}g(),E(n),h.on(m,null).on(b,g)}function z(){var i=_.of(this,arguments);a?clearTimeout(a):(hs.call(this),e=k(r=n||t.mouse(this)),E(i)),a=setTimeout(function(){a=null,L(i)},50),B(),T(Math.pow(2,.002*Bt())*f.k),A(r,e),C(i)}function I(){var e=t.mouse(this),r=Math.log(f.k)/Math.LN2;M(this,e,k(e),t.event.shiftKey?Math.ceil(r)-1:Math.floor(r)+1)}return Nt||(Nt=\"onwheel\"in i?(Bt=function(){return-t.event.deltaY*(t.event.deltaMode?120:1)},\"wheel\"):\"onmousewheel\"in i?(Bt=function(){return t.event.wheelDelta},\"mousewheel\"):(Bt=function(){return-t.event.detail},\"MozMousePixelScroll\")),w.event=function(e){e.each(function(){var e=_.of(this,arguments),n=f;ds?t.select(this).transition().each(\"start.zoom\",function(){f=this.__chart__||{x:0,y:0,k:1},E(e)}).tween(\"zoom:zoom\",function(){var i=p[0],a=p[1],o=r?r[0]:i/2,s=r?r[1]:a/2,l=t.interpolateZoom([(o-f.x)/f.k,(s-f.y)/f.k,i/f.k],[(o-n.x)/n.k,(s-n.y)/n.k,i/n.k]);return function(t){var r=l(t),n=i/r[2];this.__chart__=f={x:o-r[0]*n,y:s-r[1]*n,k:n},C(e)}}).each(\"interrupt.zoom\",function(){L(e)}).each(\"end.zoom\",function(){L(e)}):(this.__chart__=f,E(e),C(e),L(e))})},w.translate=function(t){return arguments.length?(f={x:+t[0],y:+t[1],k:f.k},S(),w):[f.x,f.y]},w.scale=function(t){return arguments.length?(f={x:f.x,y:f.y,k:null},T(+t),S(),w):f.k},w.scaleExtent=function(t){return arguments.length?(d=null==t?jt:[+t[0],+t[1]],w):d},w.center=function(t){return arguments.length?(n=t&&[+t[0],+t[1]],w):n},w.size=function(t){return arguments.length?(p=t&&[+t[0],+t[1]],w):p},w.duration=function(t){return arguments.length?(g=+t,w):g},w.x=function(t){return arguments.length?(c=t,l=t.copy(),f={x:0,y:0,k:1},w):c},w.y=function(t){return arguments.length?(h=t,u=t.copy(),f={x:0,y:0,k:1},w):h},t.rebind(w,_,\"on\")};var Bt,Nt,jt=[0,1/0];function Ut(){}function Vt(t,e,r){return this instanceof Vt?(this.h=+t,this.s=+e,void(this.l=+r)):arguments.length<2?t instanceof Vt?new Vt(t.h,t.s,t.l):ue(\"\"+t,he,Vt):new Vt(t,e,r)}t.color=Ut,Ut.prototype.toString=function(){return this.rgb()+\"\"},t.hsl=Vt;var qt=Vt.prototype=new Ut;function Ht(t,e,r){var n,i;function a(t){return Math.round(255*function(t){return t>360?t-=360:t<0&&(t+=360),t<60?n+(i-n)*t/60:t<180?i:t<240?n+(i-n)*(240-t)/60:n}(t))}return t=isNaN(t)?0:(t%=360)<0?t+360:t,e=isNaN(e)?0:e<0?0:e>1?1:e,n=2*(r=r<0?0:r>1?1:r)-(i=r<=.5?r*(1+e):r+e-r*e),new ae(a(t+120),a(t),a(t-120))}function Gt(e,r,n){return this instanceof Gt?(this.h=+e,this.c=+r,void(this.l=+n)):arguments.length<2?e instanceof Gt?new Gt(e.h,e.c,e.l):ee(e instanceof Xt?e.l:(e=fe((e=t.rgb(e)).r,e.g,e.b)).l,e.a,e.b):new Gt(e,r,n)}qt.brighter=function(t){return t=Math.pow(.7,arguments.length?t:1),new Vt(this.h,this.s,this.l/t)},qt.darker=function(t){return t=Math.pow(.7,arguments.length?t:1),new Vt(this.h,this.s,t*this.l)},qt.rgb=function(){return Ht(this.h,this.s,this.l)},t.hcl=Gt;var Yt=Gt.prototype=new Ut;function Wt(t,e,r){return isNaN(t)&&(t=0),isNaN(e)&&(e=0),new Xt(r,Math.cos(t*=Ct)*e,Math.sin(t)*e)}function Xt(t,e,r){return this instanceof Xt?(this.l=+t,this.a=+e,void(this.b=+r)):arguments.length<2?t instanceof Xt?new Xt(t.l,t.a,t.b):t instanceof Gt?Wt(t.h,t.c,t.l):fe((t=ae(t)).r,t.g,t.b):new Xt(t,e,r)}Yt.brighter=function(t){return new Gt(this.h,this.c,Math.min(100,this.l+Zt*(arguments.length?t:1)))},Yt.darker=function(t){return new Gt(this.h,this.c,Math.max(0,this.l-Zt*(arguments.length?t:1)))},Yt.rgb=function(){return Wt(this.h,this.c,this.l).rgb()},t.lab=Xt;var Zt=18,Jt=.95047,Kt=1,$t=1.08883,Qt=Xt.prototype=new Ut;function te(t,e,r){var n=(t+16)/116,i=n+e/500,a=n-r/200;return new ae(ie(3.2404542*(i=re(i)*Jt)-1.5371385*(n=re(n)*Kt)-.4985314*(a=re(a)*$t)),ie(-.969266*i+1.8760108*n+.041556*a),ie(.0556434*i-.2040259*n+1.0572252*a))}function ee(t,e,r){return t>0?new Gt(Math.atan2(r,e)*Lt,Math.sqrt(e*e+r*r),t):new Gt(NaN,NaN,t)}function re(t){return t>.206893034?t*t*t:(t-4/29)/7.787037}function ne(t){return t>.008856?Math.pow(t,1/3):7.787037*t+4/29}function ie(t){return Math.round(255*(t<=.00304?12.92*t:1.055*Math.pow(t,1/2.4)-.055))}function ae(t,e,r){return this instanceof ae?(this.r=~~t,this.g=~~e,void(this.b=~~r)):arguments.length<2?t instanceof ae?new ae(t.r,t.g,t.b):ue(\"\"+t,ae,Ht):new ae(t,e,r)}function oe(t){return new ae(t>>16,t>>8&255,255&t)}function se(t){return oe(t)+\"\"}Qt.brighter=function(t){return new Xt(Math.min(100,this.l+Zt*(arguments.length?t:1)),this.a,this.b)},Qt.darker=function(t){return new Xt(Math.max(0,this.l-Zt*(arguments.length?t:1)),this.a,this.b)},Qt.rgb=function(){return te(this.l,this.a,this.b)},t.rgb=ae;var le=ae.prototype=new Ut;function ce(t){return t<16?\"0\"+Math.max(0,t).toString(16):Math.min(255,t).toString(16)}function ue(t,e,r){var n,i,a,o=0,s=0,l=0;if(n=/([a-z]+)\\((.*)\\)/.exec(t=t.toLowerCase()))switch(i=n[2].split(\",\"),n[1]){case\"hsl\":return r(parseFloat(i[0]),parseFloat(i[1])/100,parseFloat(i[2])/100);case\"rgb\":return e(de(i[0]),de(i[1]),de(i[2]))}return(a=ge.get(t))?e(a.r,a.g,a.b):(null==t||\"#\"!==t.charAt(0)||isNaN(a=parseInt(t.slice(1),16))||(4===t.length?(o=(3840&a)>>4,o|=o>>4,s=240&a,s|=s>>4,l=15&a,l|=l<<4):7===t.length&&(o=(16711680&a)>>16,s=(65280&a)>>8,l=255&a)),e(o,s,l))}function he(t,e,r){var n,i,a=Math.min(t/=255,e/=255,r/=255),o=Math.max(t,e,r),s=o-a,l=(o+a)/2;return s?(i=l<.5?s/(o+a):s/(2-o-a),n=t==o?(e-r)/s+(e<r?6:0):e==o?(r-t)/s+2:(t-e)/s+4,n*=60):(n=NaN,i=l>0&&l<1?0:n),new Vt(n,i,l)}function fe(t,e,r){var n=ne((.4124564*(t=pe(t))+.3575761*(e=pe(e))+.1804375*(r=pe(r)))/Jt),i=ne((.2126729*t+.7151522*e+.072175*r)/Kt);return Xt(116*i-16,500*(n-i),200*(i-ne((.0193339*t+.119192*e+.9503041*r)/$t)))}function pe(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function de(t){var e=parseFloat(t);return\"%\"===t.charAt(t.length-1)?Math.round(2.55*e):e}le.brighter=function(t){t=Math.pow(.7,arguments.length?t:1);var e=this.r,r=this.g,n=this.b,i=30;return e||r||n?(e&&e<i&&(e=i),r&&r<i&&(r=i),n&&n<i&&(n=i),new ae(Math.min(255,e/t),Math.min(255,r/t),Math.min(255,n/t))):new ae(i,i,i)},le.darker=function(t){return new ae((t=Math.pow(.7,arguments.length?t:1))*this.r,t*this.g,t*this.b)},le.hsl=function(){return he(this.r,this.g,this.b)},le.toString=function(){return\"#\"+ce(this.r)+ce(this.g)+ce(this.b)};var ge=t.map({aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074});function ve(t){return\"function\"==typeof t?t:function(){return t}}function me(t){return function(e,r,n){return 2===arguments.length&&\"function\"==typeof r&&(n=r,r=null),ye(e,r,t,n)}}function ye(e,r,i,a){var o={},s=t.dispatch(\"beforesend\",\"progress\",\"load\",\"error\"),l={},c=new XMLHttpRequest,u=null;function h(){var t,e=c.status;if(!e&&function(t){var e=t.responseType;return e&&\"text\"!==e?t.response:t.responseText}(c)||e>=200&&e<300||304===e){try{t=i.call(o,c)}catch(t){return void s.error.call(o,t)}s.load.call(o,t)}else s.error.call(o,c)}return!this.XDomainRequest||\"withCredentials\"in c||!/^(http(s)?:)?\\/\\//.test(e)||(c=new XDomainRequest),\"onload\"in c?c.onload=c.onerror=h:c.onreadystatechange=function(){c.readyState>3&&h()},c.onprogress=function(e){var r=t.event;t.event=e;try{s.progress.call(o,c)}finally{t.event=r}},o.header=function(t,e){return t=(t+\"\").toLowerCase(),arguments.length<2?l[t]:(null==e?delete l[t]:l[t]=e+\"\",o)},o.mimeType=function(t){return arguments.length?(r=null==t?null:t+\"\",o):r},o.responseType=function(t){return arguments.length?(u=t,o):u},o.response=function(t){return i=t,o},[\"get\",\"post\"].forEach(function(t){o[t]=function(){return o.send.apply(o,[t].concat(n(arguments)))}}),o.send=function(t,n,i){if(2===arguments.length&&\"function\"==typeof n&&(i=n,n=null),c.open(t,e,!0),null==r||\"accept\"in l||(l.accept=r+\",*/*\"),c.setRequestHeader)for(var a in l)c.setRequestHeader(a,l[a]);return null!=r&&c.overrideMimeType&&c.overrideMimeType(r),null!=u&&(c.responseType=u),null!=i&&o.on(\"error\",i).on(\"load\",function(t){i(null,t)}),s.beforesend.call(o,c),c.send(null==n?null:n),o},o.abort=function(){return c.abort(),o},t.rebind(o,s,\"on\"),null==a?o:o.get(function(t){return 1===t.length?function(e,r){t(null==e?r:null)}:t}(a))}ge.forEach(function(t,e){ge.set(t,oe(e))}),t.functor=ve,t.xhr=me(P),t.dsv=function(t,e){var r=new RegExp('[\"'+t+\"\\n]\"),n=t.charCodeAt(0);function i(t,r,n){arguments.length<3&&(n=r,r=null);var i=ye(t,e,null==r?a:o(r),n);return i.row=function(t){return arguments.length?i.response(null==(r=t)?a:o(t)):r},i}function a(t){return i.parse(t.responseText)}function o(t){return function(e){return i.parse(e.responseText,t)}}function s(e){return e.map(l).join(t)}function l(t){return r.test(t)?'\"'+t.replace(/\\\"/g,'\"\"')+'\"':t}return i.parse=function(t,e){var r;return i.parseRows(t,function(t,n){if(r)return r(t,n-1);var i=new Function(\"d\",\"return {\"+t.map(function(t,e){return JSON.stringify(t)+\": d[\"+e+\"]\"}).join(\",\")+\"}\");r=e?function(t,r){return e(i(t),r)}:i})},i.parseRows=function(t,e){var r,i,a={},o={},s=[],l=t.length,c=0,u=0;function h(){if(c>=l)return o;if(i)return i=!1,a;var e=c;if(34===t.charCodeAt(e)){for(var r=e;r++<l;)if(34===t.charCodeAt(r)){if(34!==t.charCodeAt(r+1))break;++r}return c=r+2,13===(s=t.charCodeAt(r+1))?(i=!0,10===t.charCodeAt(r+2)&&++c):10===s&&(i=!0),t.slice(e+1,r).replace(/\"\"/g,'\"')}for(;c<l;){var s,u=1;if(10===(s=t.charCodeAt(c++)))i=!0;else if(13===s)i=!0,10===t.charCodeAt(c)&&(++c,++u);else if(s!==n)continue;return t.slice(e,c-u)}return t.slice(e)}for(;(r=h())!==o;){for(var f=[];r!==a&&r!==o;)f.push(r),r=h();e&&null==(f=e(f,u++))||s.push(f)}return s},i.format=function(e){if(Array.isArray(e[0]))return i.formatRows(e);var r=new L,n=[];return e.forEach(function(t){for(var e in t)r.has(e)||n.push(r.add(e))}),[n.map(l).join(t)].concat(e.map(function(e){return n.map(function(t){return l(e[t])}).join(t)})).join(\"\\n\")},i.formatRows=function(t){return t.map(s).join(\"\\n\")},i},t.csv=t.dsv(\",\",\"text/csv\"),t.tsv=t.dsv(\"\\t\",\"text/tab-separated-values\");var xe,be,_e,we,ke=this[z(this,\"requestAnimationFrame\")]||function(t){setTimeout(t,17)};function Te(t,e,r){var n=arguments.length;n<2&&(e=0),n<3&&(r=Date.now());var i={c:t,t:r+e,n:null};return be?be.n=i:xe=i,be=i,_e||(we=clearTimeout(we),_e=1,ke(Ae)),i}function Ae(){var t=Me(),e=Se()-t;e>24?(isFinite(e)&&(clearTimeout(we),we=setTimeout(Ae,e)),_e=0):(_e=1,ke(Ae))}function Me(){for(var t=Date.now(),e=xe;e;)t>=e.t&&e.c(t-e.t)&&(e.c=null),e=e.n;return t}function Se(){for(var t,e=xe,r=1/0;e;)e.c?(e.t<r&&(r=e.t),e=(t=e).n):e=t?t.n=e.n:xe=e.n;return be=t,r}function Ee(t,e){return e-(t?Math.ceil(Math.log(t)/Math.LN10):1)}t.timer=function(){Te.apply(this,arguments)},t.timer.flush=function(){Me(),Se()},t.round=function(t,e){return e?Math.round(t*(e=Math.pow(10,e)))/e:Math.round(t)};var Ce=[\"y\",\"z\",\"a\",\"f\",\"p\",\"n\",\"\\xb5\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\",\"P\",\"E\",\"Z\",\"Y\"].map(function(t,e){var r=Math.pow(10,3*y(8-e));return{scale:e>8?function(t){return t/r}:function(t){return t*r},symbol:t}});t.formatPrefix=function(e,r){var n=0;return(e=+e)&&(e<0&&(e*=-1),r&&(e=t.round(e,Ee(e,r))),n=1+Math.floor(1e-12+Math.log(e)/Math.LN10),n=Math.max(-24,Math.min(24,3*Math.floor((n-1)/3)))),Ce[8+n/3]};var Le=/(?:([^{])?([<>=^]))?([+\\- ])?([$#])?(0)?(\\d+)?(,)?(\\.-?\\d+)?([a-z%])?/i,Pe=t.map({b:function(t){return t.toString(2)},c:function(t){return String.fromCharCode(t)},o:function(t){return t.toString(8)},x:function(t){return t.toString(16)},X:function(t){return t.toString(16).toUpperCase()},g:function(t,e){return t.toPrecision(e)},e:function(t,e){return t.toExponential(e)},f:function(t,e){return t.toFixed(e)},r:function(e,r){return(e=t.round(e,Ee(e,r))).toFixed(Math.max(0,Math.min(20,Ee(e*(1+1e-15),r))))}});function Oe(t){return t+\"\"}var ze=t.time={},Ie=Date;function De(){this._=new Date(arguments.length>1?Date.UTC.apply(this,arguments):arguments[0])}De.prototype={getDate:function(){return this._.getUTCDate()},getDay:function(){return this._.getUTCDay()},getFullYear:function(){return this._.getUTCFullYear()},getHours:function(){return this._.getUTCHours()},getMilliseconds:function(){return this._.getUTCMilliseconds()},getMinutes:function(){return this._.getUTCMinutes()},getMonth:function(){return this._.getUTCMonth()},getSeconds:function(){return this._.getUTCSeconds()},getTime:function(){return this._.getTime()},getTimezoneOffset:function(){return 0},valueOf:function(){return this._.valueOf()},setDate:function(){Re.setUTCDate.apply(this._,arguments)},setDay:function(){Re.setUTCDay.apply(this._,arguments)},setFullYear:function(){Re.setUTCFullYear.apply(this._,arguments)},setHours:function(){Re.setUTCHours.apply(this._,arguments)},setMilliseconds:function(){Re.setUTCMilliseconds.apply(this._,arguments)},setMinutes:function(){Re.setUTCMinutes.apply(this._,arguments)},setMonth:function(){Re.setUTCMonth.apply(this._,arguments)},setSeconds:function(){Re.setUTCSeconds.apply(this._,arguments)},setTime:function(){Re.setTime.apply(this._,arguments)}};var Re=Date.prototype;function Fe(t,e,r){function n(e){var r=t(e),n=a(r,1);return e-r<n-e?r:n}function i(r){return e(r=t(new Ie(r-1)),1),r}function a(t,r){return e(t=new Ie(+t),r),t}function o(t,n,a){var o=i(t),s=[];if(a>1)for(;o<n;)r(o)%a||s.push(new Date(+o)),e(o,1);else for(;o<n;)s.push(new Date(+o)),e(o,1);return s}t.floor=t,t.round=n,t.ceil=i,t.offset=a,t.range=o;var s=t.utc=Be(t);return s.floor=s,s.round=Be(n),s.ceil=Be(i),s.offset=Be(a),s.range=function(t,e,r){try{Ie=De;var n=new De;return n._=t,o(n,e,r)}finally{Ie=Date}},t}function Be(t){return function(e,r){try{Ie=De;var n=new De;return n._=e,t(n,r)._}finally{Ie=Date}}}ze.year=Fe(function(t){return(t=ze.day(t)).setMonth(0,1),t},function(t,e){t.setFullYear(t.getFullYear()+e)},function(t){return t.getFullYear()}),ze.years=ze.year.range,ze.years.utc=ze.year.utc.range,ze.day=Fe(function(t){var e=new Ie(2e3,0);return e.setFullYear(t.getFullYear(),t.getMonth(),t.getDate()),e},function(t,e){t.setDate(t.getDate()+e)},function(t){return t.getDate()-1}),ze.days=ze.day.range,ze.days.utc=ze.day.utc.range,ze.dayOfYear=function(t){var e=ze.year(t);return Math.floor((t-e-6e4*(t.getTimezoneOffset()-e.getTimezoneOffset()))/864e5)},[\"sunday\",\"monday\",\"tuesday\",\"wednesday\",\"thursday\",\"friday\",\"saturday\"].forEach(function(t,e){e=7-e;var r=ze[t]=Fe(function(t){return(t=ze.day(t)).setDate(t.getDate()-(t.getDay()+e)%7),t},function(t,e){t.setDate(t.getDate()+7*Math.floor(e))},function(t){var r=ze.year(t).getDay();return Math.floor((ze.dayOfYear(t)+(r+e)%7)/7)-(r!==e)});ze[t+\"s\"]=r.range,ze[t+\"s\"].utc=r.utc.range,ze[t+\"OfYear\"]=function(t){var r=ze.year(t).getDay();return Math.floor((ze.dayOfYear(t)+(r+e)%7)/7)}}),ze.week=ze.sunday,ze.weeks=ze.sunday.range,ze.weeks.utc=ze.sunday.utc.range,ze.weekOfYear=ze.sundayOfYear;var Ne={\"-\":\"\",_:\" \",0:\"0\"},je=/^\\s*\\d+/,Ue=/^%/;function Ve(t,e,r){var n=t<0?\"-\":\"\",i=(n?-t:t)+\"\",a=i.length;return n+(a<r?new Array(r-a+1).join(e)+i:i)}function qe(e){return new RegExp(\"^(?:\"+e.map(t.requote).join(\"|\")+\")\",\"i\")}function He(t){for(var e=new b,r=-1,n=t.length;++r<n;)e.set(t[r].toLowerCase(),r);return e}function Ge(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+1));return n?(t.w=+n[0],r+n[0].length):-1}function Ye(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.U=+n[0],r+n[0].length):-1}function We(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.W=+n[0],r+n[0].length):-1}function Xe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+4));return n?(t.y=+n[0],r+n[0].length):-1}function Ze(t,e,r){je.lastIndex=0;var n,i=je.exec(e.slice(r,r+2));return i?(t.y=(n=+i[0])+(n>68?1900:2e3),r+i[0].length):-1}function Je(t,e,r){return/^[+-]\\d{4}$/.test(e=e.slice(r,r+5))?(t.Z=-e,r+5):-1}function Ke(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.m=n[0]-1,r+n[0].length):-1}function $e(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.d=+n[0],r+n[0].length):-1}function Qe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.j=+n[0],r+n[0].length):-1}function tr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.H=+n[0],r+n[0].length):-1}function er(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.M=+n[0],r+n[0].length):-1}function rr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.S=+n[0],r+n[0].length):-1}function nr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.L=+n[0],r+n[0].length):-1}function ir(t){var e=t.getTimezoneOffset(),r=e>0?\"-\":\"+\",n=y(e)/60|0,i=y(e)%60;return r+Ve(n,\"0\",2)+Ve(i,\"0\",2)}function ar(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r,r+1));return n?r+n[0].length:-1}function or(t){for(var e=t.length,r=-1;++r<e;)t[r][0]=this(t[r][0]);return function(e){for(var r=0,n=t[r];!n[1](e);)n=t[++r];return n[0](e)}}t.locale=function(e){return{numberFormat:function(e){var r=e.decimal,n=e.thousands,i=e.grouping,a=e.currency,o=i&&n?function(t,e){for(var r=t.length,a=[],o=0,s=i[0],l=0;r>0&&s>0&&(l+s+1>e&&(s=Math.max(1,e-l)),a.push(t.substring(r-=s,r+s)),!((l+=s+1)>e));)s=i[o=(o+1)%i.length];return a.reverse().join(n)}:P;return function(e){var n=Le.exec(e),i=n[1]||\" \",s=n[2]||\">\",l=n[3]||\"-\",c=n[4]||\"\",u=n[5],h=+n[6],f=n[7],p=n[8],d=n[9],g=1,v=\"\",m=\"\",y=!1,x=!0;switch(p&&(p=+p.substring(1)),(u||\"0\"===i&&\"=\"===s)&&(u=i=\"0\",s=\"=\"),d){case\"n\":f=!0,d=\"g\";break;case\"%\":g=100,m=\"%\",d=\"f\";break;case\"p\":g=100,m=\"%\",d=\"r\";break;case\"b\":case\"o\":case\"x\":case\"X\":\"#\"===c&&(v=\"0\"+d.toLowerCase());case\"c\":x=!1;case\"d\":y=!0,p=0;break;case\"s\":g=-1,d=\"r\"}\"$\"===c&&(v=a[0],m=a[1]),\"r\"!=d||p||(d=\"g\"),null!=p&&(\"g\"==d?p=Math.max(1,Math.min(21,p)):\"e\"!=d&&\"f\"!=d||(p=Math.max(0,Math.min(20,p)))),d=Pe.get(d)||Oe;var b=u&&f;return function(e){var n=m;if(y&&e%1)return\"\";var a=e<0||0===e&&1/e<0?(e=-e,\"-\"):\"-\"===l?\"\":l;if(g<0){var c=t.formatPrefix(e,p);e=c.scale(e),n=c.symbol+m}else e*=g;var _,w,k=(e=d(e,p)).lastIndexOf(\".\");if(k<0){var T=x?e.lastIndexOf(\"e\"):-1;T<0?(_=e,w=\"\"):(_=e.substring(0,T),w=e.substring(T))}else _=e.substring(0,k),w=r+e.substring(k+1);!u&&f&&(_=o(_,1/0));var A=v.length+_.length+w.length+(b?0:a.length),M=A<h?new Array(A=h-A+1).join(i):\"\";return b&&(_=o(M+_,M.length?h-w.length:1/0)),a+=v,e=_+w,(\"<\"===s?a+e+M:\">\"===s?M+a+e:\"^\"===s?M.substring(0,A>>=1)+a+e+M.substring(A):a+(b?e:M+e))+n}}}(e),timeFormat:function(e){var r=e.dateTime,n=e.date,i=e.time,a=e.periods,o=e.days,s=e.shortDays,l=e.months,c=e.shortMonths;function u(t){var e=t.length;function r(r){for(var n,i,a,o=[],s=-1,l=0;++s<e;)37===t.charCodeAt(s)&&(o.push(t.slice(l,s)),null!=(i=Ne[n=t.charAt(++s)])&&(n=t.charAt(++s)),(a=_[n])&&(n=a(r,null==i?\"e\"===n?\" \":\"0\":i)),o.push(n),l=s+1);return o.push(t.slice(l,s)),o.join(\"\")}return r.parse=function(e){var r={y:1900,m:0,d:1,H:0,M:0,S:0,L:0,Z:null};if(h(r,t,e,0)!=e.length)return null;\"p\"in r&&(r.H=r.H%12+12*r.p);var n=null!=r.Z&&Ie!==De,i=new(n?De:Ie);return\"j\"in r?i.setFullYear(r.y,0,r.j):\"W\"in r||\"U\"in r?(\"w\"in r||(r.w=\"W\"in r?1:0),i.setFullYear(r.y,0,1),i.setFullYear(r.y,0,\"W\"in r?(r.w+6)%7+7*r.W-(i.getDay()+5)%7:r.w+7*r.U-(i.getDay()+6)%7)):i.setFullYear(r.y,r.m,r.d),i.setHours(r.H+(r.Z/100|0),r.M+r.Z%100,r.S,r.L),n?i._:i},r.toString=function(){return t},r}function h(t,e,r,n){for(var i,a,o,s=0,l=e.length,c=r.length;s<l;){if(n>=c)return-1;if(37===(i=e.charCodeAt(s++))){if(o=e.charAt(s++),!(a=w[o in Ne?e.charAt(s++):o])||(n=a(t,r,n))<0)return-1}else if(i!=r.charCodeAt(n++))return-1}return n}u.utc=function(t){var e=u(t);function r(t){try{var r=new(Ie=De);return r._=t,e(r)}finally{Ie=Date}}return r.parse=function(t){try{Ie=De;var r=e.parse(t);return r&&r._}finally{Ie=Date}},r.toString=e.toString,r},u.multi=u.utc.multi=or;var f=t.map(),p=qe(o),d=He(o),g=qe(s),v=He(s),m=qe(l),y=He(l),x=qe(c),b=He(c);a.forEach(function(t,e){f.set(t.toLowerCase(),e)});var _={a:function(t){return s[t.getDay()]},A:function(t){return o[t.getDay()]},b:function(t){return c[t.getMonth()]},B:function(t){return l[t.getMonth()]},c:u(r),d:function(t,e){return Ve(t.getDate(),e,2)},e:function(t,e){return Ve(t.getDate(),e,2)},H:function(t,e){return Ve(t.getHours(),e,2)},I:function(t,e){return Ve(t.getHours()%12||12,e,2)},j:function(t,e){return Ve(1+ze.dayOfYear(t),e,3)},L:function(t,e){return Ve(t.getMilliseconds(),e,3)},m:function(t,e){return Ve(t.getMonth()+1,e,2)},M:function(t,e){return Ve(t.getMinutes(),e,2)},p:function(t){return a[+(t.getHours()>=12)]},S:function(t,e){return Ve(t.getSeconds(),e,2)},U:function(t,e){return Ve(ze.sundayOfYear(t),e,2)},w:function(t){return t.getDay()},W:function(t,e){return Ve(ze.mondayOfYear(t),e,2)},x:u(n),X:u(i),y:function(t,e){return Ve(t.getFullYear()%100,e,2)},Y:function(t,e){return Ve(t.getFullYear()%1e4,e,4)},Z:ir,\"%\":function(){return\"%\"}},w={a:function(t,e,r){g.lastIndex=0;var n=g.exec(e.slice(r));return n?(t.w=v.get(n[0].toLowerCase()),r+n[0].length):-1},A:function(t,e,r){p.lastIndex=0;var n=p.exec(e.slice(r));return n?(t.w=d.get(n[0].toLowerCase()),r+n[0].length):-1},b:function(t,e,r){x.lastIndex=0;var n=x.exec(e.slice(r));return n?(t.m=b.get(n[0].toLowerCase()),r+n[0].length):-1},B:function(t,e,r){m.lastIndex=0;var n=m.exec(e.slice(r));return n?(t.m=y.get(n[0].toLowerCase()),r+n[0].length):-1},c:function(t,e,r){return h(t,_.c.toString(),e,r)},d:$e,e:$e,H:tr,I:tr,j:Qe,L:nr,m:Ke,M:er,p:function(t,e,r){var n=f.get(e.slice(r,r+=2).toLowerCase());return null==n?-1:(t.p=n,r)},S:rr,U:Ye,w:Ge,W:We,x:function(t,e,r){return h(t,_.x.toString(),e,r)},X:function(t,e,r){return h(t,_.X.toString(),e,r)},y:Ze,Y:Xe,Z:Je,\"%\":ar};return u}(e)}};var sr=t.locale({decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],dateTime:\"%a %b %e %X %Y\",date:\"%m/%d/%Y\",time:\"%H:%M:%S\",periods:[\"AM\",\"PM\"],days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"]});function lr(){}t.format=sr.numberFormat,t.geo={},lr.prototype={s:0,t:0,add:function(t){ur(t,this.t,cr),ur(cr.s,this.s,this),this.s?this.t+=cr.t:this.s=cr.t},reset:function(){this.s=this.t=0},valueOf:function(){return this.s}};var cr=new lr;function ur(t,e,r){var n=r.s=t+e,i=n-t,a=n-i;r.t=t-a+(e-i)}function hr(t,e){t&&pr.hasOwnProperty(t.type)&&pr[t.type](t,e)}t.geo.stream=function(t,e){t&&fr.hasOwnProperty(t.type)?fr[t.type](t,e):hr(t,e)};var fr={Feature:function(t,e){hr(t.geometry,e)},FeatureCollection:function(t,e){for(var r=t.features,n=-1,i=r.length;++n<i;)hr(r[n].geometry,e)}},pr={Sphere:function(t,e){e.sphere()},Point:function(t,e){t=t.coordinates,e.point(t[0],t[1],t[2])},MultiPoint:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)t=r[n],e.point(t[0],t[1],t[2])},LineString:function(t,e){dr(t.coordinates,e,0)},MultiLineString:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)dr(r[n],e,0)},Polygon:function(t,e){gr(t.coordinates,e)},MultiPolygon:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)gr(r[n],e)},GeometryCollection:function(t,e){for(var r=t.geometries,n=-1,i=r.length;++n<i;)hr(r[n],e)}};function dr(t,e,r){var n,i=-1,a=t.length-r;for(e.lineStart();++i<a;)n=t[i],e.point(n[0],n[1],n[2]);e.lineEnd()}function gr(t,e){var r=-1,n=t.length;for(e.polygonStart();++r<n;)dr(t[r],e,1);e.polygonEnd()}t.geo.area=function(e){return vr=0,t.geo.stream(e,Cr),vr};var vr,mr,yr,xr,br,_r,wr,kr,Tr,Ar,Mr,Sr,Er=new lr,Cr={sphere:function(){vr+=4*At},point:D,lineStart:D,lineEnd:D,polygonStart:function(){Er.reset(),Cr.lineStart=Lr},polygonEnd:function(){var t=2*Er;vr+=t<0?4*At+t:t,Cr.lineStart=Cr.lineEnd=Cr.point=D}};function Lr(){var t,e,r,n,i;function a(t,e){e=e*Ct/2+At/4;var a=(t*=Ct)-r,o=a>=0?1:-1,s=o*a,l=Math.cos(e),c=Math.sin(e),u=i*c,h=n*l+u*Math.cos(s),f=u*o*Math.sin(s);Er.add(Math.atan2(f,h)),r=t,n=l,i=c}Cr.point=function(o,s){Cr.point=a,r=(t=o)*Ct,n=Math.cos(s=(e=s)*Ct/2+At/4),i=Math.sin(s)},Cr.lineEnd=function(){a(t,e)}}function Pr(t){var e=t[0],r=t[1],n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}function Or(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}function zr(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}function Ir(t,e){t[0]+=e[0],t[1]+=e[1],t[2]+=e[2]}function Dr(t,e){return[t[0]*e,t[1]*e,t[2]*e]}function Rr(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]+t[2]*t[2]);t[0]/=e,t[1]/=e,t[2]/=e}function Fr(t){return[Math.atan2(t[1],t[0]),It(t[2])]}function Br(t,e){return y(t[0]-e[0])<kt&&y(t[1]-e[1])<kt}t.geo.bounds=function(){var e,r,n,i,a,o,s,l,c,u,h,f={point:p,lineStart:g,lineEnd:v,polygonStart:function(){f.point=m,f.lineStart=x,f.lineEnd=b,c=0,Cr.polygonStart()},polygonEnd:function(){Cr.polygonEnd(),f.point=p,f.lineStart=g,f.lineEnd=v,Er<0?(e=-(n=180),r=-(i=90)):c>kt?i=90:c<-kt&&(r=-90),h[0]=e,h[1]=n}};function p(t,a){u.push(h=[e=t,n=t]),a<r&&(r=a),a>i&&(i=a)}function d(t,o){var s=Pr([t*Ct,o*Ct]);if(l){var c=zr(l,s),u=zr([c[1],-c[0],0],c);Rr(u),u=Fr(u);var h=t-a,f=h>0?1:-1,d=u[0]*Lt*f,g=y(h)>180;if(g^(f*a<d&&d<f*t))(v=u[1]*Lt)>i&&(i=v);else if(g^(f*a<(d=(d+360)%360-180)&&d<f*t)){var v;(v=-u[1]*Lt)<r&&(r=v)}else o<r&&(r=o),o>i&&(i=o);g?t<a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t):n>=e?(t<e&&(e=t),t>n&&(n=t)):t>a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t)}else p(t,o);l=s,a=t}function g(){f.point=d}function v(){h[0]=e,h[1]=n,f.point=p,l=null}function m(t,e){if(l){var r=t-a;c+=y(r)>180?r+(r>0?360:-360):r}else o=t,s=e;Cr.point(t,e),d(t,e)}function x(){Cr.lineStart()}function b(){m(o,s),Cr.lineEnd(),y(c)>kt&&(e=-(n=180)),h[0]=e,h[1]=n,l=null}function _(t,e){return(e-=t)<0?e+360:e}function w(t,e){return t[0]-e[0]}function k(t,e){return e[0]<=e[1]?e[0]<=t&&t<=e[1]:t<e[0]||e[1]<t}return function(a){if(i=n=-(e=r=1/0),u=[],t.geo.stream(a,f),c=u.length){u.sort(w);for(var o=1,s=[g=u[0]];o<c;++o)k((p=u[o])[0],g)||k(p[1],g)?(_(g[0],p[1])>_(g[0],g[1])&&(g[1]=p[1]),_(p[0],g[1])>_(g[0],g[1])&&(g[0]=p[0])):s.push(g=p);for(var l,c,p,d=-1/0,g=(o=0,s[c=s.length-1]);o<=c;g=p,++o)p=s[o],(l=_(g[1],p[0]))>d&&(d=l,e=p[0],n=g[1])}return u=h=null,e===1/0||r===1/0?[[NaN,NaN],[NaN,NaN]]:[[e,r],[n,i]]}}(),t.geo.centroid=function(e){mr=yr=xr=br=_r=wr=kr=Tr=Ar=Mr=Sr=0,t.geo.stream(e,Nr);var r=Ar,n=Mr,i=Sr,a=r*r+n*n+i*i;return a<Tt&&(r=wr,n=kr,i=Tr,yr<kt&&(r=xr,n=br,i=_r),(a=r*r+n*n+i*i)<Tt)?[NaN,NaN]:[Math.atan2(n,r)*Lt,It(i/Math.sqrt(a))*Lt]};var Nr={sphere:D,point:jr,lineStart:Vr,lineEnd:qr,polygonStart:function(){Nr.lineStart=Hr},polygonEnd:function(){Nr.lineStart=Vr}};function jr(t,e){t*=Ct;var r=Math.cos(e*=Ct);Ur(r*Math.cos(t),r*Math.sin(t),Math.sin(e))}function Ur(t,e,r){xr+=(t-xr)/++mr,br+=(e-br)/mr,_r+=(r-_r)/mr}function Vr(){var t,e,r;function n(n,i){n*=Ct;var a=Math.cos(i*=Ct),o=a*Math.cos(n),s=a*Math.sin(n),l=Math.sin(i),c=Math.atan2(Math.sqrt((c=e*l-r*s)*c+(c=r*o-t*l)*c+(c=t*s-e*o)*c),t*o+e*s+r*l);yr+=c,wr+=c*(t+(t=o)),kr+=c*(e+(e=s)),Tr+=c*(r+(r=l)),Ur(t,e,r)}Nr.point=function(i,a){i*=Ct;var o=Math.cos(a*=Ct);t=o*Math.cos(i),e=o*Math.sin(i),r=Math.sin(a),Nr.point=n,Ur(t,e,r)}}function qr(){Nr.point=jr}function Hr(){var t,e,r,n,i;function a(t,e){t*=Ct;var a=Math.cos(e*=Ct),o=a*Math.cos(t),s=a*Math.sin(t),l=Math.sin(e),c=n*l-i*s,u=i*o-r*l,h=r*s-n*o,f=Math.sqrt(c*c+u*u+h*h),p=r*o+n*s+i*l,d=f&&-zt(p)/f,g=Math.atan2(f,p);Ar+=d*c,Mr+=d*u,Sr+=d*h,yr+=g,wr+=g*(r+(r=o)),kr+=g*(n+(n=s)),Tr+=g*(i+(i=l)),Ur(r,n,i)}Nr.point=function(o,s){t=o,e=s,Nr.point=a,o*=Ct;var l=Math.cos(s*=Ct);r=l*Math.cos(o),n=l*Math.sin(o),i=Math.sin(s),Ur(r,n,i)},Nr.lineEnd=function(){a(t,e),Nr.lineEnd=qr,Nr.point=jr}}function Gr(t,e){function r(r,n){return r=t(r,n),e(r[0],r[1])}return t.invert&&e.invert&&(r.invert=function(r,n){return(r=e.invert(r,n))&&t.invert(r[0],r[1])}),r}function Yr(){return!0}function Wr(t,e,r,n,i){var a=[],o=[];if(t.forEach(function(t){if(!((e=t.length-1)<=0)){var e,r=t[0],n=t[e];if(Br(r,n)){i.lineStart();for(var s=0;s<e;++s)i.point((r=t[s])[0],r[1]);i.lineEnd()}else{var l=new Zr(r,t,null,!0),c=new Zr(r,null,l,!1);l.o=c,a.push(l),o.push(c),l=new Zr(n,t,null,!1),c=new Zr(n,null,l,!0),l.o=c,a.push(l),o.push(c)}}}),o.sort(e),Xr(a),Xr(o),a.length){for(var s=0,l=r,c=o.length;s<c;++s)o[s].e=l=!l;for(var u,h,f=a[0];;){for(var p=f,d=!0;p.v;)if((p=p.n)===f)return;u=p.z,i.lineStart();do{if(p.v=p.o.v=!0,p.e){if(d)for(s=0,c=u.length;s<c;++s)i.point((h=u[s])[0],h[1]);else n(p.x,p.n.x,1,i);p=p.n}else{if(d)for(s=(u=p.p.z).length-1;s>=0;--s)i.point((h=u[s])[0],h[1]);else n(p.x,p.p.x,-1,i);p=p.p}u=(p=p.o).z,d=!d}while(!p.v);i.lineEnd()}}}function Xr(t){if(e=t.length){for(var e,r,n=0,i=t[0];++n<e;)i.n=r=t[n],r.p=i,i=r;i.n=r=t[0],r.p=i}}function Zr(t,e,r,n){this.x=t,this.z=e,this.o=r,this.e=n,this.v=!1,this.n=this.p=null}function Jr(e,r,n,i){return function(a,o){var s,l=r(o),c=a.invert(i[0],i[1]),u={point:h,lineStart:p,lineEnd:d,polygonStart:function(){u.point=b,u.lineStart=_,u.lineEnd=w,s=[],g=[]},polygonEnd:function(){u.point=h,u.lineStart=p,u.lineEnd=d,s=t.merge(s);var e=function(t,e){var r=t[0],n=t[1],i=[Math.sin(r),-Math.cos(r),0],a=0,o=0;Er.reset();for(var s=0,l=e.length;s<l;++s){var c=e[s],u=c.length;if(u)for(var h=c[0],f=h[0],p=h[1]/2+At/4,d=Math.sin(p),g=Math.cos(p),v=1;;){v===u&&(v=0);var m=(t=c[v])[0],y=t[1]/2+At/4,x=Math.sin(y),b=Math.cos(y),_=m-f,w=_>=0?1:-1,k=w*_,T=k>At,A=d*x;if(Er.add(Math.atan2(A*w*Math.sin(k),g*b+A*Math.cos(k))),a+=T?_+w*Mt:_,T^f>=r^m>=r){var M=zr(Pr(h),Pr(t));Rr(M);var S=zr(i,M);Rr(S);var E=(T^_>=0?-1:1)*It(S[2]);(n>E||n===E&&(M[0]||M[1]))&&(o+=T^_>=0?1:-1)}if(!v++)break;f=m,d=x,g=b,h=t}}return(a<-kt||a<kt&&Er<-kt)^1&o}(c,g);s.length?(x||(o.polygonStart(),x=!0),Wr(s,Qr,e,n,o)):e&&(x||(o.polygonStart(),x=!0),o.lineStart(),n(null,null,1,o),o.lineEnd()),x&&(o.polygonEnd(),x=!1),s=g=null},sphere:function(){o.polygonStart(),o.lineStart(),n(null,null,1,o),o.lineEnd(),o.polygonEnd()}};function h(t,r){var n=a(t,r);e(t=n[0],r=n[1])&&o.point(t,r)}function f(t,e){var r=a(t,e);l.point(r[0],r[1])}function p(){u.point=f,l.lineStart()}function d(){u.point=h,l.lineEnd()}var g,v,m=$r(),y=r(m),x=!1;function b(t,e){v.push([t,e]);var r=a(t,e);y.point(r[0],r[1])}function _(){y.lineStart(),v=[]}function w(){b(v[0][0],v[0][1]),y.lineEnd();var t,e=y.clean(),r=m.buffer(),n=r.length;if(v.pop(),g.push(v),v=null,n)if(1&e){var i,a=-1;if((n=(t=r[0]).length-1)>0){for(x||(o.polygonStart(),x=!0),o.lineStart();++a<n;)o.point((i=t[a])[0],i[1]);o.lineEnd()}}else n>1&&2&e&&r.push(r.pop().concat(r.shift())),s.push(r.filter(Kr))}return u}}function Kr(t){return t.length>1}function $r(){var t,e=[];return{lineStart:function(){e.push(t=[])},point:function(e,r){t.push([e,r])},lineEnd:D,buffer:function(){var r=e;return e=[],t=null,r},rejoin:function(){e.length>1&&e.push(e.pop().concat(e.shift()))}}}function Qr(t,e){return((t=t.x)[0]<0?t[1]-Et-kt:Et-t[1])-((e=e.x)[0]<0?e[1]-Et-kt:Et-e[1])}var tn=Jr(Yr,function(t){var e,r=NaN,n=NaN,i=NaN;return{lineStart:function(){t.lineStart(),e=1},point:function(a,o){var s=a>0?At:-At,l=y(a-r);y(l-At)<kt?(t.point(r,n=(n+o)/2>0?Et:-Et),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),t.point(a,n),e=0):i!==s&&l>=At&&(y(r-i)<kt&&(r-=i*kt),y(a-s)<kt&&(a-=s*kt),n=function(t,e,r,n){var i,a,o=Math.sin(t-r);return y(o)>kt?Math.atan((Math.sin(e)*(a=Math.cos(n))*Math.sin(r)-Math.sin(n)*(i=Math.cos(e))*Math.sin(t))/(i*a*o)):(e+n)/2}(r,n,a,o),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),e=0),t.point(r=a,n=o),i=s},lineEnd:function(){t.lineEnd(),r=n=NaN},clean:function(){return 2-e}}},function(t,e,r,n){var i;if(null==t)i=r*Et,n.point(-At,i),n.point(0,i),n.point(At,i),n.point(At,0),n.point(At,-i),n.point(0,-i),n.point(-At,-i),n.point(-At,0),n.point(-At,i);else if(y(t[0]-e[0])>kt){var a=t[0]<e[0]?At:-At;i=r*a/2,n.point(-a,i),n.point(0,i),n.point(a,i)}else n.point(e[0],e[1])},[-At,-At/2]);function en(t,e,r,n){return function(i){var a,o=i.a,s=i.b,l=o.x,c=o.y,u=0,h=1,f=s.x-l,p=s.y-c;if(a=t-l,f||!(a>0)){if(a/=f,f<0){if(a<u)return;a<h&&(h=a)}else if(f>0){if(a>h)return;a>u&&(u=a)}if(a=r-l,f||!(a<0)){if(a/=f,f<0){if(a>h)return;a>u&&(u=a)}else if(f>0){if(a<u)return;a<h&&(h=a)}if(a=e-c,p||!(a>0)){if(a/=p,p<0){if(a<u)return;a<h&&(h=a)}else if(p>0){if(a>h)return;a>u&&(u=a)}if(a=n-c,p||!(a<0)){if(a/=p,p<0){if(a>h)return;a>u&&(u=a)}else if(p>0){if(a<u)return;a<h&&(h=a)}return u>0&&(i.a={x:l+u*f,y:c+u*p}),h<1&&(i.b={x:l+h*f,y:c+h*p}),i}}}}}}var rn=1e9;function nn(e,r,n,i){return function(l){var c,u,h,f,p,d,g,v,m,y,x,b=l,_=$r(),w=en(e,r,n,i),k={point:M,lineStart:function(){k.point=S,u&&u.push(h=[]);y=!0,m=!1,g=v=NaN},lineEnd:function(){c&&(S(f,p),d&&m&&_.rejoin(),c.push(_.buffer()));k.point=M,m&&l.lineEnd()},polygonStart:function(){l=_,c=[],u=[],x=!0},polygonEnd:function(){l=b,c=t.merge(c);var r=function(t){for(var e=0,r=u.length,n=t[1],i=0;i<r;++i)for(var a,o=1,s=u[i],l=s.length,c=s[0];o<l;++o)a=s[o],c[1]<=n?a[1]>n&&Ot(c,a,t)>0&&++e:a[1]<=n&&Ot(c,a,t)<0&&--e,c=a;return 0!==e}([e,i]),n=x&&r,a=c.length;(n||a)&&(l.polygonStart(),n&&(l.lineStart(),T(null,null,1,l),l.lineEnd()),a&&Wr(c,o,r,T,l),l.polygonEnd()),c=u=h=null}};function T(t,o,l,c){var u=0,h=0;if(null==t||(u=a(t,l))!==(h=a(o,l))||s(t,o)<0^l>0)do{c.point(0===u||3===u?e:n,u>1?i:r)}while((u=(u+l+4)%4)!==h);else c.point(o[0],o[1])}function A(t,a){return e<=t&&t<=n&&r<=a&&a<=i}function M(t,e){A(t,e)&&l.point(t,e)}function S(t,e){var r=A(t=Math.max(-rn,Math.min(rn,t)),e=Math.max(-rn,Math.min(rn,e)));if(u&&h.push([t,e]),y)f=t,p=e,d=r,y=!1,r&&(l.lineStart(),l.point(t,e));else if(r&&m)l.point(t,e);else{var n={a:{x:g,y:v},b:{x:t,y:e}};w(n)?(m||(l.lineStart(),l.point(n.a.x,n.a.y)),l.point(n.b.x,n.b.y),r||l.lineEnd(),x=!1):r&&(l.lineStart(),l.point(t,e),x=!1)}g=t,v=e,m=r}return k};function a(t,i){return y(t[0]-e)<kt?i>0?0:3:y(t[0]-n)<kt?i>0?2:1:y(t[1]-r)<kt?i>0?1:0:i>0?3:2}function o(t,e){return s(t.x,e.x)}function s(t,e){var r=a(t,1),n=a(e,1);return r!==n?r-n:0===r?e[1]-t[1]:1===r?t[0]-e[0]:2===r?t[1]-e[1]:e[0]-t[0]}}function an(t){var e=0,r=At/3,n=Cn(t),i=n(e,r);return i.parallels=function(t){return arguments.length?n(e=t[0]*At/180,r=t[1]*At/180):[e/At*180,r/At*180]},i}function on(t,e){var r=Math.sin(t),n=(r+Math.sin(e))/2,i=1+r*(2*n-r),a=Math.sqrt(i)/n;function o(t,e){var r=Math.sqrt(i-2*n*Math.sin(e))/n;return[r*Math.sin(t*=n),a-r*Math.cos(t)]}return o.invert=function(t,e){var r=a-e;return[Math.atan2(t,r)/n,It((i-(t*t+r*r)*n*n)/(2*n))]},o}t.geo.clipExtent=function(){var t,e,r,n,i,a,o={stream:function(t){return i&&(i.valid=!1),(i=a(t)).valid=!0,i},extent:function(s){return arguments.length?(a=nn(t=+s[0][0],e=+s[0][1],r=+s[1][0],n=+s[1][1]),i&&(i.valid=!1,i=null),o):[[t,e],[r,n]]}};return o.extent([[0,0],[960,500]])},(t.geo.conicEqualArea=function(){return an(on)}).raw=on,t.geo.albers=function(){return t.geo.conicEqualArea().rotate([96,0]).center([-.6,38.7]).parallels([29.5,45.5]).scale(1070)},t.geo.albersUsa=function(){var e,r,n,i,a=t.geo.albers(),o=t.geo.conicEqualArea().rotate([154,0]).center([-2,58.5]).parallels([55,65]),s=t.geo.conicEqualArea().rotate([157,0]).center([-3,19.9]).parallels([8,18]),l={point:function(t,r){e=[t,r]}};function c(t){var a=t[0],o=t[1];return e=null,r(a,o),e||(n(a,o),e)||i(a,o),e}return c.invert=function(t){var e=a.scale(),r=a.translate(),n=(t[0]-r[0])/e,i=(t[1]-r[1])/e;return(i>=.12&&i<.234&&n>=-.425&&n<-.214?o:i>=.166&&i<.234&&n>=-.214&&n<-.115?s:a).invert(t)},c.stream=function(t){var e=a.stream(t),r=o.stream(t),n=s.stream(t);return{point:function(t,i){e.point(t,i),r.point(t,i),n.point(t,i)},sphere:function(){e.sphere(),r.sphere(),n.sphere()},lineStart:function(){e.lineStart(),r.lineStart(),n.lineStart()},lineEnd:function(){e.lineEnd(),r.lineEnd(),n.lineEnd()},polygonStart:function(){e.polygonStart(),r.polygonStart(),n.polygonStart()},polygonEnd:function(){e.polygonEnd(),r.polygonEnd(),n.polygonEnd()}}},c.precision=function(t){return arguments.length?(a.precision(t),o.precision(t),s.precision(t),c):a.precision()},c.scale=function(t){return arguments.length?(a.scale(t),o.scale(.35*t),s.scale(t),c.translate(a.translate())):a.scale()},c.translate=function(t){if(!arguments.length)return a.translate();var e=a.scale(),u=+t[0],h=+t[1];return r=a.translate(t).clipExtent([[u-.455*e,h-.238*e],[u+.455*e,h+.238*e]]).stream(l).point,n=o.translate([u-.307*e,h+.201*e]).clipExtent([[u-.425*e+kt,h+.12*e+kt],[u-.214*e-kt,h+.234*e-kt]]).stream(l).point,i=s.translate([u-.205*e,h+.212*e]).clipExtent([[u-.214*e+kt,h+.166*e+kt],[u-.115*e-kt,h+.234*e-kt]]).stream(l).point,c},c.scale(1070)};var sn,ln,cn,un,hn,fn,pn={point:D,lineStart:D,lineEnd:D,polygonStart:function(){ln=0,pn.lineStart=dn},polygonEnd:function(){pn.lineStart=pn.lineEnd=pn.point=D,sn+=y(ln/2)}};function dn(){var t,e,r,n;function i(t,e){ln+=n*t-r*e,r=t,n=e}pn.point=function(a,o){pn.point=i,t=r=a,e=n=o},pn.lineEnd=function(){i(t,e)}}var gn={point:function(t,e){t<cn&&(cn=t);t>hn&&(hn=t);e<un&&(un=e);e>fn&&(fn=e)},lineStart:D,lineEnd:D,polygonStart:D,polygonEnd:D};function vn(){var t=mn(4.5),e=[],r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(e){return t=mn(e),r},result:function(){if(e.length){var t=e.join(\"\");return e=[],t}}};function n(r,n){e.push(\"M\",r,\",\",n,t)}function i(t,n){e.push(\"M\",t,\",\",n),r.point=a}function a(t,r){e.push(\"L\",t,\",\",r)}function o(){r.point=n}function s(){e.push(\"Z\")}return r}function mn(t){return\"m0,\"+t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+-2*t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+2*t+\"z\"}var yn,xn={point:bn,lineStart:_n,lineEnd:wn,polygonStart:function(){xn.lineStart=kn},polygonEnd:function(){xn.point=bn,xn.lineStart=_n,xn.lineEnd=wn}};function bn(t,e){xr+=t,br+=e,++_r}function _n(){var t,e;function r(r,n){var i=r-t,a=n-e,o=Math.sqrt(i*i+a*a);wr+=o*(t+r)/2,kr+=o*(e+n)/2,Tr+=o,bn(t=r,e=n)}xn.point=function(n,i){xn.point=r,bn(t=n,e=i)}}function wn(){xn.point=bn}function kn(){var t,e,r,n;function i(t,e){var i=t-r,a=e-n,o=Math.sqrt(i*i+a*a);wr+=o*(r+t)/2,kr+=o*(n+e)/2,Tr+=o,Ar+=(o=n*t-r*e)*(r+t),Mr+=o*(n+e),Sr+=3*o,bn(r=t,n=e)}xn.point=function(a,o){xn.point=i,bn(t=r=a,e=n=o)},xn.lineEnd=function(){i(t,e)}}function Tn(t){var e=4.5,r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(t){return e=t,r},result:D};function n(r,n){t.moveTo(r+e,n),t.arc(r,n,e,0,Mt)}function i(e,n){t.moveTo(e,n),r.point=a}function a(e,r){t.lineTo(e,r)}function o(){r.point=n}function s(){t.closePath()}return r}function An(t){var e=.5,r=Math.cos(30*Ct),n=16;function i(e){return(n?function(e){var r,i,o,s,l,c,u,h,f,p,d,g,v={point:m,lineStart:y,lineEnd:b,polygonStart:function(){e.polygonStart(),v.lineStart=_},polygonEnd:function(){e.polygonEnd(),v.lineStart=y}};function m(r,n){r=t(r,n),e.point(r[0],r[1])}function y(){h=NaN,v.point=x,e.lineStart()}function x(r,i){var o=Pr([r,i]),s=t(r,i);a(h,f,u,p,d,g,h=s[0],f=s[1],u=r,p=o[0],d=o[1],g=o[2],n,e),e.point(h,f)}function b(){v.point=m,e.lineEnd()}function _(){y(),v.point=w,v.lineEnd=k}function w(t,e){x(r=t,e),i=h,o=f,s=p,l=d,c=g,v.point=x}function k(){a(h,f,u,p,d,g,i,o,r,s,l,c,n,e),v.lineEnd=b,b()}return v}:function(e){return Sn(e,function(r,n){r=t(r,n),e.point(r[0],r[1])})})(e)}function a(n,i,o,s,l,c,u,h,f,p,d,g,v,m){var x=u-n,b=h-i,_=x*x+b*b;if(_>4*e&&v--){var w=s+p,k=l+d,T=c+g,A=Math.sqrt(w*w+k*k+T*T),M=Math.asin(T/=A),S=y(y(T)-1)<kt||y(o-f)<kt?(o+f)/2:Math.atan2(k,w),E=t(S,M),C=E[0],L=E[1],P=C-n,O=L-i,z=b*P-x*O;(z*z/_>e||y((x*P+b*O)/_-.5)>.3||s*p+l*d+c*g<r)&&(a(n,i,o,s,l,c,C,L,S,w/=A,k/=A,T,v,m),m.point(C,L),a(C,L,S,w,k,T,u,h,f,p,d,g,v,m))}}return i.precision=function(t){return arguments.length?(n=(e=t*t)>0&&16,i):Math.sqrt(e)},i}function Mn(t){this.stream=t}function Sn(t,e){return{point:e,sphere:function(){t.sphere()},lineStart:function(){t.lineStart()},lineEnd:function(){t.lineEnd()},polygonStart:function(){t.polygonStart()},polygonEnd:function(){t.polygonEnd()}}}function En(t){return Cn(function(){return t})()}function Cn(e){var r,n,i,a,o,s,l=An(function(t,e){return[(t=r(t,e))[0]*c+a,o-t[1]*c]}),c=150,u=480,h=250,f=0,p=0,d=0,g=0,v=0,m=tn,x=P,b=null,_=null;function w(t){return[(t=i(t[0]*Ct,t[1]*Ct))[0]*c+a,o-t[1]*c]}function k(t){return(t=i.invert((t[0]-a)/c,(o-t[1])/c))&&[t[0]*Lt,t[1]*Lt]}function T(){i=Gr(n=zn(d,g,v),r);var t=r(f,p);return a=u-t[0]*c,o=h+t[1]*c,A()}function A(){return s&&(s.valid=!1,s=null),w}return w.stream=function(t){return s&&(s.valid=!1),(s=Ln(m(n,l(x(t))))).valid=!0,s},w.clipAngle=function(t){return arguments.length?(m=null==t?(b=t,tn):function(t){var e=Math.cos(t),r=e>0,n=y(e)>kt;return Jr(i,function(t){var e,s,l,c,u;return{lineStart:function(){c=l=!1,u=1},point:function(h,f){var p,d=[h,f],g=i(h,f),v=r?g?0:o(h,f):g?o(h+(h<0?At:-At),f):0;if(!e&&(c=l=g)&&t.lineStart(),g!==l&&(p=a(e,d),(Br(e,p)||Br(d,p))&&(d[0]+=kt,d[1]+=kt,g=i(d[0],d[1]))),g!==l)u=0,g?(t.lineStart(),p=a(d,e),t.point(p[0],p[1])):(p=a(e,d),t.point(p[0],p[1]),t.lineEnd()),e=p;else if(n&&e&&r^g){var m;v&s||!(m=a(d,e,!0))||(u=0,r?(t.lineStart(),t.point(m[0][0],m[0][1]),t.point(m[1][0],m[1][1]),t.lineEnd()):(t.point(m[1][0],m[1][1]),t.lineEnd(),t.lineStart(),t.point(m[0][0],m[0][1])))}!g||e&&Br(e,d)||t.point(d[0],d[1]),e=d,l=g,s=v},lineEnd:function(){l&&t.lineEnd(),e=null},clean:function(){return u|(c&&l)<<1}}},Fn(t,6*Ct),r?[0,-t]:[-At,t-At]);function i(t,r){return Math.cos(t)*Math.cos(r)>e}function a(t,r,n){var i=[1,0,0],a=zr(Pr(t),Pr(r)),o=Or(a,a),s=a[0],l=o-s*s;if(!l)return!n&&t;var c=e*o/l,u=-e*s/l,h=zr(i,a),f=Dr(i,c);Ir(f,Dr(a,u));var p=h,d=Or(f,p),g=Or(p,p),v=d*d-g*(Or(f,f)-1);if(!(v<0)){var m=Math.sqrt(v),x=Dr(p,(-d-m)/g);if(Ir(x,f),x=Fr(x),!n)return x;var b,_=t[0],w=r[0],k=t[1],T=r[1];w<_&&(b=_,_=w,w=b);var A=w-_,M=y(A-At)<kt;if(!M&&T<k&&(b=k,k=T,T=b),M||A<kt?M?k+T>0^x[1]<(y(x[0]-_)<kt?k:T):k<=x[1]&&x[1]<=T:A>At^(_<=x[0]&&x[0]<=w)){var S=Dr(p,(-d+m)/g);return Ir(S,f),[x,Fr(S)]}}}function o(e,n){var i=r?t:At-t,a=0;return e<-i?a|=1:e>i&&(a|=2),n<-i?a|=4:n>i&&(a|=8),a}}((b=+t)*Ct),A()):b},w.clipExtent=function(t){return arguments.length?(_=t,x=t?nn(t[0][0],t[0][1],t[1][0],t[1][1]):P,A()):_},w.scale=function(t){return arguments.length?(c=+t,T()):c},w.translate=function(t){return arguments.length?(u=+t[0],h=+t[1],T()):[u,h]},w.center=function(t){return arguments.length?(f=t[0]%360*Ct,p=t[1]%360*Ct,T()):[f*Lt,p*Lt]},w.rotate=function(t){return arguments.length?(d=t[0]%360*Ct,g=t[1]%360*Ct,v=t.length>2?t[2]%360*Ct:0,T()):[d*Lt,g*Lt,v*Lt]},t.rebind(w,l,\"precision\"),function(){return r=e.apply(this,arguments),w.invert=r.invert&&k,T()}}function Ln(t){return Sn(t,function(e,r){t.point(e*Ct,r*Ct)})}function Pn(t,e){return[t,e]}function On(t,e){return[t>At?t-Mt:t<-At?t+Mt:t,e]}function zn(t,e,r){return t?e||r?Gr(Dn(t),Rn(e,r)):Dn(t):e||r?Rn(e,r):On}function In(t){return function(e,r){return[(e+=t)>At?e-Mt:e<-At?e+Mt:e,r]}}function Dn(t){var e=In(t);return e.invert=In(-t),e}function Rn(t,e){var r=Math.cos(t),n=Math.sin(t),i=Math.cos(e),a=Math.sin(e);function o(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*r+s*n;return[Math.atan2(l*i-u*a,s*r-c*n),It(u*i+l*a)]}return o.invert=function(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*i-l*a;return[Math.atan2(l*i+c*a,s*r+u*n),It(u*r-s*n)]},o}function Fn(t,e){var r=Math.cos(t),n=Math.sin(t);return function(i,a,o,s){var l=o*e;null!=i?(i=Bn(r,i),a=Bn(r,a),(o>0?i<a:i>a)&&(i+=o*Mt)):(i=t+o*Mt,a=t-.5*l);for(var c,u=i;o>0?u>a:u<a;u-=l)s.point((c=Fr([r,-n*Math.cos(u),-n*Math.sin(u)]))[0],c[1])}}function Bn(t,e){var r=Pr(e);r[0]-=t,Rr(r);var n=zt(-r[1]);return((-r[2]<0?-n:n)+2*Math.PI-kt)%(2*Math.PI)}function Nn(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map(function(e){return[t,e]})}}function jn(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map(function(e){return[e,t]})}}function Un(t){return t.source}function Vn(t){return t.target}t.geo.path=function(){var e,r,n,i,a,o=4.5;function s(e){return e&&(\"function\"==typeof o&&i.pointRadius(+o.apply(this,arguments)),a&&a.valid||(a=n(i)),t.geo.stream(e,a)),i.result()}function l(){return a=null,s}return s.area=function(e){return sn=0,t.geo.stream(e,n(pn)),sn},s.centroid=function(e){return xr=br=_r=wr=kr=Tr=Ar=Mr=Sr=0,t.geo.stream(e,n(xn)),Sr?[Ar/Sr,Mr/Sr]:Tr?[wr/Tr,kr/Tr]:_r?[xr/_r,br/_r]:[NaN,NaN]},s.bounds=function(e){return hn=fn=-(cn=un=1/0),t.geo.stream(e,n(gn)),[[cn,un],[hn,fn]]},s.projection=function(t){return arguments.length?(n=(e=t)?t.stream||(r=t,i=An(function(t,e){return r([t*Lt,e*Lt])}),function(t){return Ln(i(t))}):P,l()):e;var r,i},s.context=function(t){return arguments.length?(i=null==(r=t)?new vn:new Tn(t),\"function\"!=typeof o&&i.pointRadius(o),l()):r},s.pointRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:(i.pointRadius(+t),+t),s):o},s.projection(t.geo.albersUsa()).context(null)},t.geo.transform=function(t){return{stream:function(e){var r=new Mn(e);for(var n in t)r[n]=t[n];return r}}},Mn.prototype={point:function(t,e){this.stream.point(t,e)},sphere:function(){this.stream.sphere()},lineStart:function(){this.stream.lineStart()},lineEnd:function(){this.stream.lineEnd()},polygonStart:function(){this.stream.polygonStart()},polygonEnd:function(){this.stream.polygonEnd()}},t.geo.projection=En,t.geo.projectionMutator=Cn,(t.geo.equirectangular=function(){return En(Pn)}).raw=Pn.invert=Pn,t.geo.rotation=function(t){function e(e){return(e=t(e[0]*Ct,e[1]*Ct))[0]*=Lt,e[1]*=Lt,e}return t=zn(t[0]%360*Ct,t[1]*Ct,t.length>2?t[2]*Ct:0),e.invert=function(e){return(e=t.invert(e[0]*Ct,e[1]*Ct))[0]*=Lt,e[1]*=Lt,e},e},On.invert=Pn,t.geo.circle=function(){var t,e,r=[0,0],n=6;function i(){var t=\"function\"==typeof r?r.apply(this,arguments):r,n=zn(-t[0]*Ct,-t[1]*Ct,0).invert,i=[];return e(null,null,1,{point:function(t,e){i.push(t=n(t,e)),t[0]*=Lt,t[1]*=Lt}}),{type:\"Polygon\",coordinates:[i]}}return i.origin=function(t){return arguments.length?(r=t,i):r},i.angle=function(r){return arguments.length?(e=Fn((t=+r)*Ct,n*Ct),i):t},i.precision=function(r){return arguments.length?(e=Fn(t*Ct,(n=+r)*Ct),i):n},i.angle(90)},t.geo.distance=function(t,e){var r,n=(e[0]-t[0])*Ct,i=t[1]*Ct,a=e[1]*Ct,o=Math.sin(n),s=Math.cos(n),l=Math.sin(i),c=Math.cos(i),u=Math.sin(a),h=Math.cos(a);return Math.atan2(Math.sqrt((r=h*o)*r+(r=c*u-l*h*s)*r),l*u+c*h*s)},t.geo.graticule=function(){var e,r,n,i,a,o,s,l,c,u,h,f,p=10,d=p,g=90,v=360,m=2.5;function x(){return{type:\"MultiLineString\",coordinates:b()}}function b(){return t.range(Math.ceil(i/g)*g,n,g).map(h).concat(t.range(Math.ceil(l/v)*v,s,v).map(f)).concat(t.range(Math.ceil(r/p)*p,e,p).filter(function(t){return y(t%g)>kt}).map(c)).concat(t.range(Math.ceil(o/d)*d,a,d).filter(function(t){return y(t%v)>kt}).map(u))}return x.lines=function(){return b().map(function(t){return{type:\"LineString\",coordinates:t}})},x.outline=function(){return{type:\"Polygon\",coordinates:[h(i).concat(f(s).slice(1),h(n).reverse().slice(1),f(l).reverse().slice(1))]}},x.extent=function(t){return arguments.length?x.majorExtent(t).minorExtent(t):x.minorExtent()},x.majorExtent=function(t){return arguments.length?(i=+t[0][0],n=+t[1][0],l=+t[0][1],s=+t[1][1],i>n&&(t=i,i=n,n=t),l>s&&(t=l,l=s,s=t),x.precision(m)):[[i,l],[n,s]]},x.minorExtent=function(t){return arguments.length?(r=+t[0][0],e=+t[1][0],o=+t[0][1],a=+t[1][1],r>e&&(t=r,r=e,e=t),o>a&&(t=o,o=a,a=t),x.precision(m)):[[r,o],[e,a]]},x.step=function(t){return arguments.length?x.majorStep(t).minorStep(t):x.minorStep()},x.majorStep=function(t){return arguments.length?(g=+t[0],v=+t[1],x):[g,v]},x.minorStep=function(t){return arguments.length?(p=+t[0],d=+t[1],x):[p,d]},x.precision=function(t){return arguments.length?(m=+t,c=Nn(o,a,90),u=jn(r,e,m),h=Nn(l,s,90),f=jn(i,n,m),x):m},x.majorExtent([[-180,-90+kt],[180,90-kt]]).minorExtent([[-180,-80-kt],[180,80+kt]])},t.geo.greatArc=function(){var e,r,n=Un,i=Vn;function a(){return{type:\"LineString\",coordinates:[e||n.apply(this,arguments),r||i.apply(this,arguments)]}}return a.distance=function(){return t.geo.distance(e||n.apply(this,arguments),r||i.apply(this,arguments))},a.source=function(t){return arguments.length?(n=t,e=\"function\"==typeof t?null:t,a):n},a.target=function(t){return arguments.length?(i=t,r=\"function\"==typeof t?null:t,a):i},a.precision=function(){return arguments.length?a:0},a},t.geo.interpolate=function(t,e){return r=t[0]*Ct,n=t[1]*Ct,i=e[0]*Ct,a=e[1]*Ct,o=Math.cos(n),s=Math.sin(n),l=Math.cos(a),c=Math.sin(a),u=o*Math.cos(r),h=o*Math.sin(r),f=l*Math.cos(i),p=l*Math.sin(i),d=2*Math.asin(Math.sqrt(Rt(a-n)+o*l*Rt(i-r))),g=1/Math.sin(d),(v=d?function(t){var e=Math.sin(t*=d)*g,r=Math.sin(d-t)*g,n=r*u+e*f,i=r*h+e*p,a=r*s+e*c;return[Math.atan2(i,n)*Lt,Math.atan2(a,Math.sqrt(n*n+i*i))*Lt]}:function(){return[r*Lt,n*Lt]}).distance=d,v;var r,n,i,a,o,s,l,c,u,h,f,p,d,g,v},t.geo.length=function(e){return yn=0,t.geo.stream(e,qn),yn};var qn={sphere:D,point:D,lineStart:function(){var t,e,r;function n(n,i){var a=Math.sin(i*=Ct),o=Math.cos(i),s=y((n*=Ct)-t),l=Math.cos(s);yn+=Math.atan2(Math.sqrt((s=o*Math.sin(s))*s+(s=r*a-e*o*l)*s),e*a+r*o*l),t=n,e=a,r=o}qn.point=function(i,a){t=i*Ct,e=Math.sin(a*=Ct),r=Math.cos(a),qn.point=n},qn.lineEnd=function(){qn.point=qn.lineEnd=D}},lineEnd:D,polygonStart:D,polygonEnd:D};function Hn(t,e){function r(e,r){var n=Math.cos(e),i=Math.cos(r),a=t(n*i);return[a*i*Math.sin(e),a*Math.sin(r)]}return r.invert=function(t,r){var n=Math.sqrt(t*t+r*r),i=e(n),a=Math.sin(i),o=Math.cos(i);return[Math.atan2(t*a,n*o),Math.asin(n&&r*a/n)]},r}var Gn=Hn(function(t){return Math.sqrt(2/(1+t))},function(t){return 2*Math.asin(t/2)});(t.geo.azimuthalEqualArea=function(){return En(Gn)}).raw=Gn;var Yn=Hn(function(t){var e=Math.acos(t);return e&&e/Math.sin(e)},P);function Wn(t,e){var r=Math.cos(t),n=function(t){return Math.tan(At/4+t/2)},i=t===e?Math.sin(t):Math.log(r/Math.cos(e))/Math.log(n(e)/n(t)),a=r*Math.pow(n(t),i)/i;if(!i)return Jn;function o(t,e){a>0?e<-Et+kt&&(e=-Et+kt):e>Et-kt&&(e=Et-kt);var r=a/Math.pow(n(e),i);return[r*Math.sin(i*t),a-r*Math.cos(i*t)]}return o.invert=function(t,e){var r=a-e,n=Pt(i)*Math.sqrt(t*t+r*r);return[Math.atan2(t,r)/i,2*Math.atan(Math.pow(a/n,1/i))-Et]},o}function Xn(t,e){var r=Math.cos(t),n=t===e?Math.sin(t):(r-Math.cos(e))/(e-t),i=r/n+t;if(y(n)<kt)return Pn;function a(t,e){var r=i-e;return[r*Math.sin(n*t),i-r*Math.cos(n*t)]}return a.invert=function(t,e){var r=i-e;return[Math.atan2(t,r)/n,i-Pt(n)*Math.sqrt(t*t+r*r)]},a}(t.geo.azimuthalEquidistant=function(){return En(Yn)}).raw=Yn,(t.geo.conicConformal=function(){return an(Wn)}).raw=Wn,(t.geo.conicEquidistant=function(){return an(Xn)}).raw=Xn;var Zn=Hn(function(t){return 1/t},Math.atan);function Jn(t,e){return[t,Math.log(Math.tan(At/4+e/2))]}function Kn(t){var e,r=En(t),n=r.scale,i=r.translate,a=r.clipExtent;return r.scale=function(){var t=n.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.translate=function(){var t=i.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.clipExtent=function(t){var o=a.apply(r,arguments);if(o===r){if(e=null==t){var s=At*n(),l=i();a([[l[0]-s,l[1]-s],[l[0]+s,l[1]+s]])}}else e&&(o=null);return o},r.clipExtent(null)}(t.geo.gnomonic=function(){return En(Zn)}).raw=Zn,Jn.invert=function(t,e){return[t,2*Math.atan(Math.exp(e))-Et]},(t.geo.mercator=function(){return Kn(Jn)}).raw=Jn;var $n=Hn(function(){return 1},Math.asin);(t.geo.orthographic=function(){return En($n)}).raw=$n;var Qn=Hn(function(t){return 1/(1+t)},function(t){return 2*Math.atan(t)});function ti(t,e){return[Math.log(Math.tan(At/4+e/2)),-t]}function ei(t){return t[0]}function ri(t){return t[1]}function ni(t){for(var e=t.length,r=[0,1],n=2,i=2;i<e;i++){for(;n>1&&Ot(t[r[n-2]],t[r[n-1]],t[i])<=0;)--n;r[n++]=i}return r.slice(0,n)}function ii(t,e){return t[0]-e[0]||t[1]-e[1]}(t.geo.stereographic=function(){return En(Qn)}).raw=Qn,ti.invert=function(t,e){return[-e,2*Math.atan(Math.exp(t))-Et]},(t.geo.transverseMercator=function(){var t=Kn(ti),e=t.center,r=t.rotate;return t.center=function(t){return t?e([-t[1],t[0]]):[(t=e())[1],-t[0]]},t.rotate=function(t){return t?r([t[0],t[1],t.length>2?t[2]+90:90]):[(t=r())[0],t[1],t[2]-90]},r([0,0,90])}).raw=ti,t.geom={},t.geom.hull=function(t){var e=ei,r=ri;if(arguments.length)return n(t);function n(t){if(t.length<3)return[];var n,i=ve(e),a=ve(r),o=t.length,s=[],l=[];for(n=0;n<o;n++)s.push([+i.call(this,t[n],n),+a.call(this,t[n],n),n]);for(s.sort(ii),n=0;n<o;n++)l.push([s[n][0],-s[n][1]]);var c=ni(s),u=ni(l),h=u[0]===c[0],f=u[u.length-1]===c[c.length-1],p=[];for(n=c.length-1;n>=0;--n)p.push(t[s[c[n]][2]]);for(n=+h;n<u.length-f;++n)p.push(t[s[u[n]][2]]);return p}return n.x=function(t){return arguments.length?(e=t,n):e},n.y=function(t){return arguments.length?(r=t,n):r},n},t.geom.polygon=function(t){return V(t,ai),t};var ai=t.geom.polygon.prototype=[];function oi(t,e,r){return(r[0]-e[0])*(t[1]-e[1])<(r[1]-e[1])*(t[0]-e[0])}function si(t,e,r,n){var i=t[0],a=r[0],o=e[0]-i,s=n[0]-a,l=t[1],c=r[1],u=e[1]-l,h=n[1]-c,f=(s*(l-c)-h*(i-a))/(h*o-s*u);return[i+f*o,l+f*u]}function li(t){var e=t[0],r=t[t.length-1];return!(e[0]-r[0]||e[1]-r[1])}ai.area=function(){for(var t,e=-1,r=this.length,n=this[r-1],i=0;++e<r;)t=n,n=this[e],i+=t[1]*n[0]-t[0]*n[1];return.5*i},ai.centroid=function(t){var e,r,n=-1,i=this.length,a=0,o=0,s=this[i-1];for(arguments.length||(t=-1/(6*this.area()));++n<i;)e=s,s=this[n],r=e[0]*s[1]-s[0]*e[1],a+=(e[0]+s[0])*r,o+=(e[1]+s[1])*r;return[a*t,o*t]},ai.clip=function(t){for(var e,r,n,i,a,o,s=li(t),l=-1,c=this.length-li(this),u=this[c-1];++l<c;){for(e=t.slice(),t.length=0,i=this[l],a=e[(n=e.length-s)-1],r=-1;++r<n;)oi(o=e[r],u,i)?(oi(a,u,i)||t.push(si(a,o,u,i)),t.push(o)):oi(a,u,i)&&t.push(si(a,o,u,i)),a=o;s&&t.push(t[0]),u=i}return t};var ci,ui,hi,fi,pi,di=[],gi=[];function vi(){Ii(this),this.edge=this.site=this.circle=null}function mi(t){var e=di.pop()||new vi;return e.site=t,e}function yi(t){Si(t),hi.remove(t),di.push(t),Ii(t)}function xi(t){var e=t.circle,r=e.x,n=e.cy,i={x:r,y:n},a=t.P,o=t.N,s=[t];yi(t);for(var l=a;l.circle&&y(r-l.circle.x)<kt&&y(n-l.circle.cy)<kt;)a=l.P,s.unshift(l),yi(l),l=a;s.unshift(l),Si(l);for(var c=o;c.circle&&y(r-c.circle.x)<kt&&y(n-c.circle.cy)<kt;)o=c.N,s.push(c),yi(c),c=o;s.push(c),Si(c);var u,h=s.length;for(u=1;u<h;++u)c=s[u],l=s[u-1],Pi(c.edge,l.site,c.site,i);l=s[0],(c=s[h-1]).edge=Li(l.site,c.site,null,i),Mi(l),Mi(c)}function bi(t){for(var e,r,n,i,a=t.x,o=t.y,s=hi._;s;)if((n=_i(s,o)-a)>kt)s=s.L;else{if(!((i=a-wi(s,o))>kt)){n>-kt?(e=s.P,r=s):i>-kt?(e=s,r=s.N):e=r=s;break}if(!s.R){e=s;break}s=s.R}var l=mi(t);if(hi.insert(e,l),e||r){if(e===r)return Si(e),r=mi(e.site),hi.insert(l,r),l.edge=r.edge=Li(e.site,l.site),Mi(e),void Mi(r);if(r){Si(e),Si(r);var c=e.site,u=c.x,h=c.y,f=t.x-u,p=t.y-h,d=r.site,g=d.x-u,v=d.y-h,m=2*(f*v-p*g),y=f*f+p*p,x=g*g+v*v,b={x:(v*y-p*x)/m+u,y:(f*x-g*y)/m+h};Pi(r.edge,c,d,b),l.edge=Li(c,t,null,b),r.edge=Li(t,d,null,b),Mi(e),Mi(r)}else l.edge=Li(e.site,l.site)}}function _i(t,e){var r=t.site,n=r.x,i=r.y,a=i-e;if(!a)return n;var o=t.P;if(!o)return-1/0;var s=(r=o.site).x,l=r.y,c=l-e;if(!c)return s;var u=s-n,h=1/a-1/c,f=u/c;return h?(-f+Math.sqrt(f*f-2*h*(u*u/(-2*c)-l+c/2+i-a/2)))/h+n:(n+s)/2}function wi(t,e){var r=t.N;if(r)return _i(r,e);var n=t.site;return n.y===e?n.x:1/0}function ki(t){this.site=t,this.edges=[]}function Ti(t,e){return e.angle-t.angle}function Ai(){Ii(this),this.x=this.y=this.arc=this.site=this.cy=null}function Mi(t){var e=t.P,r=t.N;if(e&&r){var n=e.site,i=t.site,a=r.site;if(n!==a){var o=i.x,s=i.y,l=n.x-o,c=n.y-s,u=a.x-o,h=2*(l*(v=a.y-s)-c*u);if(!(h>=-Tt)){var f=l*l+c*c,p=u*u+v*v,d=(v*f-c*p)/h,g=(l*p-u*f)/h,v=g+s,m=gi.pop()||new Ai;m.arc=t,m.site=i,m.x=d+o,m.y=v+Math.sqrt(d*d+g*g),m.cy=v,t.circle=m;for(var y=null,x=pi._;x;)if(m.y<x.y||m.y===x.y&&m.x<=x.x){if(!x.L){y=x.P;break}x=x.L}else{if(!x.R){y=x;break}x=x.R}pi.insert(y,m),y||(fi=m)}}}}function Si(t){var e=t.circle;e&&(e.P||(fi=e.N),pi.remove(e),gi.push(e),Ii(e),t.circle=null)}function Ei(t,e){var r=t.b;if(r)return!0;var n,i,a=t.a,o=e[0][0],s=e[1][0],l=e[0][1],c=e[1][1],u=t.l,h=t.r,f=u.x,p=u.y,d=h.x,g=h.y,v=(f+d)/2,m=(p+g)/2;if(g===p){if(v<o||v>=s)return;if(f>d){if(a){if(a.y>=c)return}else a={x:v,y:l};r={x:v,y:c}}else{if(a){if(a.y<l)return}else a={x:v,y:c};r={x:v,y:l}}}else if(i=m-(n=(f-d)/(g-p))*v,n<-1||n>1)if(f>d){if(a){if(a.y>=c)return}else a={x:(l-i)/n,y:l};r={x:(c-i)/n,y:c}}else{if(a){if(a.y<l)return}else a={x:(c-i)/n,y:c};r={x:(l-i)/n,y:l}}else if(p<g){if(a){if(a.x>=s)return}else a={x:o,y:n*o+i};r={x:s,y:n*s+i}}else{if(a){if(a.x<o)return}else a={x:s,y:n*s+i};r={x:o,y:n*o+i}}return t.a=a,t.b=r,!0}function Ci(t,e){this.l=t,this.r=e,this.a=this.b=null}function Li(t,e,r,n){var i=new Ci(t,e);return ci.push(i),r&&Pi(i,t,e,r),n&&Pi(i,e,t,n),ui[t.i].edges.push(new Oi(i,t,e)),ui[e.i].edges.push(new Oi(i,e,t)),i}function Pi(t,e,r,n){t.a||t.b?t.l===r?t.b=n:t.a=n:(t.a=n,t.l=e,t.r=r)}function Oi(t,e,r){var n=t.a,i=t.b;this.edge=t,this.site=e,this.angle=r?Math.atan2(r.y-e.y,r.x-e.x):t.l===e?Math.atan2(i.x-n.x,n.y-i.y):Math.atan2(n.x-i.x,i.y-n.y)}function zi(){this._=null}function Ii(t){t.U=t.C=t.L=t.R=t.P=t.N=null}function Di(t,e){var r=e,n=e.R,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.R=n.L,r.R&&(r.R.U=r),n.L=r}function Ri(t,e){var r=e,n=e.L,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.L=n.R,r.L&&(r.L.U=r),n.R=r}function Fi(t){for(;t.L;)t=t.L;return t}function Bi(t,e){var r,n,i,a=t.sort(Ni).pop();for(ci=[],ui=new Array(t.length),hi=new zi,pi=new zi;;)if(i=fi,a&&(!i||a.y<i.y||a.y===i.y&&a.x<i.x))a.x===r&&a.y===n||(ui[a.i]=new ki(a),bi(a),r=a.x,n=a.y),a=t.pop();else{if(!i)break;xi(i.arc)}e&&(function(t){for(var e,r=ci,n=en(t[0][0],t[0][1],t[1][0],t[1][1]),i=r.length;i--;)(!Ei(e=r[i],t)||!n(e)||y(e.a.x-e.b.x)<kt&&y(e.a.y-e.b.y)<kt)&&(e.a=e.b=null,r.splice(i,1))}(e),function(t){for(var e,r,n,i,a,o,s,l,c,u,h=t[0][0],f=t[1][0],p=t[0][1],d=t[1][1],g=ui,v=g.length;v--;)if((a=g[v])&&a.prepare())for(l=(s=a.edges).length,o=0;o<l;)n=(u=s[o].end()).x,i=u.y,e=(c=s[++o%l].start()).x,r=c.y,(y(n-e)>kt||y(i-r)>kt)&&(s.splice(o,0,new Oi((m=a.site,x=u,b=y(n-h)<kt&&d-i>kt?{x:h,y:y(e-h)<kt?r:d}:y(i-d)<kt&&f-n>kt?{x:y(r-d)<kt?e:f,y:d}:y(n-f)<kt&&i-p>kt?{x:f,y:y(e-f)<kt?r:p}:y(i-p)<kt&&n-h>kt?{x:y(r-p)<kt?e:h,y:p}:null,_=void 0,_=new Ci(m,null),_.a=x,_.b=b,ci.push(_),_),a.site,null)),++l);var m,x,b,_}(e));var o={cells:ui,edges:ci};return hi=pi=ci=ui=null,o}function Ni(t,e){return e.y-t.y||e.x-t.x}ki.prototype.prepare=function(){for(var t,e=this.edges,r=e.length;r--;)(t=e[r].edge).b&&t.a||e.splice(r,1);return e.sort(Ti),e.length},Oi.prototype={start:function(){return this.edge.l===this.site?this.edge.a:this.edge.b},end:function(){return this.edge.l===this.site?this.edge.b:this.edge.a}},zi.prototype={insert:function(t,e){var r,n,i;if(t){if(e.P=t,e.N=t.N,t.N&&(t.N.P=e),t.N=e,t.R){for(t=t.R;t.L;)t=t.L;t.L=e}else t.R=e;r=t}else this._?(t=Fi(this._),e.P=null,e.N=t,t.P=t.L=e,r=t):(e.P=e.N=null,this._=e,r=null);for(e.L=e.R=null,e.U=r,e.C=!0,t=e;r&&r.C;)r===(n=r.U).L?(i=n.R)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.R&&(Di(this,r),r=(t=r).U),r.C=!1,n.C=!0,Ri(this,n)):(i=n.L)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.L&&(Ri(this,r),r=(t=r).U),r.C=!1,n.C=!0,Di(this,n)),r=t.U;this._.C=!1},remove:function(t){t.N&&(t.N.P=t.P),t.P&&(t.P.N=t.N),t.N=t.P=null;var e,r,n,i=t.U,a=t.L,o=t.R;if(r=a?o?Fi(o):a:o,i?i.L===t?i.L=r:i.R=r:this._=r,a&&o?(n=r.C,r.C=t.C,r.L=a,a.U=r,r!==o?(i=r.U,r.U=t.U,t=r.R,i.L=t,r.R=o,o.U=r):(r.U=i,i=r,t=r.R)):(n=t.C,t=r),t&&(t.U=i),!n)if(t&&t.C)t.C=!1;else{do{if(t===this._)break;if(t===i.L){if((e=i.R).C&&(e.C=!1,i.C=!0,Di(this,i),e=i.R),e.L&&e.L.C||e.R&&e.R.C){e.R&&e.R.C||(e.L.C=!1,e.C=!0,Ri(this,e),e=i.R),e.C=i.C,i.C=e.R.C=!1,Di(this,i),t=this._;break}}else if((e=i.L).C&&(e.C=!1,i.C=!0,Ri(this,i),e=i.L),e.L&&e.L.C||e.R&&e.R.C){e.L&&e.L.C||(e.R.C=!1,e.C=!0,Di(this,e),e=i.L),e.C=i.C,i.C=e.L.C=!1,Ri(this,i),t=this._;break}e.C=!0,t=i,i=i.U}while(!t.C);t&&(t.C=!1)}}},t.geom.voronoi=function(t){var e=ei,r=ri,n=e,i=r,a=ji;if(t)return o(t);function o(t){var e=new Array(t.length),r=a[0][0],n=a[0][1],i=a[1][0],o=a[1][1];return Bi(s(t),a).cells.forEach(function(a,s){var l=a.edges,c=a.site;(e[s]=l.length?l.map(function(t){var e=t.start();return[e.x,e.y]}):c.x>=r&&c.x<=i&&c.y>=n&&c.y<=o?[[r,o],[i,o],[i,n],[r,n]]:[]).point=t[s]}),e}function s(t){return t.map(function(t,e){return{x:Math.round(n(t,e)/kt)*kt,y:Math.round(i(t,e)/kt)*kt,i:e}})}return o.links=function(t){return Bi(s(t)).edges.filter(function(t){return t.l&&t.r}).map(function(e){return{source:t[e.l.i],target:t[e.r.i]}})},o.triangles=function(t){var e=[];return Bi(s(t)).cells.forEach(function(r,n){for(var i,a,o,s,l=r.site,c=r.edges.sort(Ti),u=-1,h=c.length,f=c[h-1].edge,p=f.l===l?f.r:f.l;++u<h;)f,i=p,p=(f=c[u].edge).l===l?f.r:f.l,n<i.i&&n<p.i&&(o=i,s=p,((a=l).x-s.x)*(o.y-a.y)-(a.x-o.x)*(s.y-a.y)<0)&&e.push([t[n],t[i.i],t[p.i]])}),e},o.x=function(t){return arguments.length?(n=ve(e=t),o):e},o.y=function(t){return arguments.length?(i=ve(r=t),o):r},o.clipExtent=function(t){return arguments.length?(a=null==t?ji:t,o):a===ji?null:a},o.size=function(t){return arguments.length?o.clipExtent(t&&[[0,0],t]):a===ji?null:a&&a[1]},o};var ji=[[-1e6,-1e6],[1e6,1e6]];function Ui(t){return t.x}function Vi(t){return t.y}function qi(e,r){e=t.rgb(e),r=t.rgb(r);var n=e.r,i=e.g,a=e.b,o=r.r-n,s=r.g-i,l=r.b-a;return function(t){return\"#\"+ce(Math.round(n+o*t))+ce(Math.round(i+s*t))+ce(Math.round(a+l*t))}}function Hi(t,e){var r,n={},i={};for(r in t)r in e?n[r]=Zi(t[r],e[r]):i[r]=t[r];for(r in e)r in t||(i[r]=e[r]);return function(t){for(r in n)i[r]=n[r](t);return i}}function Gi(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function Yi(t,e){var r,n,i,a=Wi.lastIndex=Xi.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=Wi.exec(t))&&(n=Xi.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:Gi(r,n)})),a=Xi.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?(e=l[0].x,function(t){return e(t)+\"\"}):function(){return e}:(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}t.geom.delaunay=function(e){return t.geom.voronoi().triangles(e)},t.geom.quadtree=function(t,e,r,n,i){var a,o=ei,s=ri;if(a=arguments.length)return o=Ui,s=Vi,3===a&&(i=r,n=e,r=e=0),l(t);function l(t){var l,c,u,h,f,p,d,g,v,m=ve(o),x=ve(s);if(null!=e)p=e,d=r,g=n,v=i;else if(g=v=-(p=d=1/0),c=[],u=[],f=t.length,a)for(h=0;h<f;++h)(l=t[h]).x<p&&(p=l.x),l.y<d&&(d=l.y),l.x>g&&(g=l.x),l.y>v&&(v=l.y),c.push(l.x),u.push(l.y);else for(h=0;h<f;++h){var b=+m(l=t[h],h),_=+x(l,h);b<p&&(p=b),_<d&&(d=_),b>g&&(g=b),_>v&&(v=_),c.push(b),u.push(_)}var w=g-p,k=v-d;function T(t,e,r,n,i,a,o,s){if(!isNaN(r)&&!isNaN(n))if(t.leaf){var l=t.x,c=t.y;if(null!=l)if(y(l-r)+y(c-n)<.01)A(t,e,r,n,i,a,o,s);else{var u=t.point;t.x=t.y=t.point=null,A(t,u,l,c,i,a,o,s),A(t,e,r,n,i,a,o,s)}else t.x=r,t.y=n,t.point=e}else A(t,e,r,n,i,a,o,s)}function A(t,e,r,n,i,a,o,s){var l=.5*(i+o),c=.5*(a+s),u=r>=l,h=n>=c,f=h<<1|u;t.leaf=!1,u?i=l:o=l,h?a=c:s=c,T(t=t.nodes[f]||(t.nodes[f]={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){T(M,t,+m(t,++h),+x(t,h),p,d,g,v)}}),e,r,n,i,a,o,s)}w>k?v=d+w:g=p+k;var M={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){T(M,t,+m(t,++h),+x(t,h),p,d,g,v)}};if(M.visit=function(t){!function t(e,r,n,i,a,o){if(!e(r,n,i,a,o)){var s=.5*(n+a),l=.5*(i+o),c=r.nodes;c[0]&&t(e,c[0],n,i,s,l),c[1]&&t(e,c[1],s,i,a,l),c[2]&&t(e,c[2],n,l,s,o),c[3]&&t(e,c[3],s,l,a,o)}}(t,M,p,d,g,v)},M.find=function(t){return function(t,e,r,n,i,a,o){var s,l=1/0;return function t(c,u,h,f,p){if(!(u>a||h>o||f<n||p<i)){if(d=c.point){var d,g=e-c.x,v=r-c.y,m=g*g+v*v;if(m<l){var y=Math.sqrt(l=m);n=e-y,i=r-y,a=e+y,o=r+y,s=d}}for(var x=c.nodes,b=.5*(u+f),_=.5*(h+p),w=(r>=_)<<1|e>=b,k=w+4;w<k;++w)if(c=x[3&w])switch(3&w){case 0:t(c,u,h,b,_);break;case 1:t(c,b,h,f,_);break;case 2:t(c,u,_,b,p);break;case 3:t(c,b,_,f,p)}}}(t,n,i,a,o),s}(M,t[0],t[1],p,d,g,v)},h=-1,null==e){for(;++h<f;)T(M,t[h],c[h],u[h],p,d,g,v);--h}else t.forEach(M.add);return c=u=t=l=null,M}return l.x=function(t){return arguments.length?(o=t,l):o},l.y=function(t){return arguments.length?(s=t,l):s},l.extent=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=+t[0][0],r=+t[0][1],n=+t[1][0],i=+t[1][1]),l):null==e?null:[[e,r],[n,i]]},l.size=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=r=0,n=+t[0],i=+t[1]),l):null==e?null:[n-e,i-r]},l},t.interpolateRgb=qi,t.interpolateObject=Hi,t.interpolateNumber=Gi,t.interpolateString=Yi;var Wi=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,Xi=new RegExp(Wi.source,\"g\");function Zi(e,r){for(var n,i=t.interpolators.length;--i>=0&&!(n=t.interpolators[i](e,r)););return n}function Ji(t,e){var r,n=[],i=[],a=t.length,o=e.length,s=Math.min(t.length,e.length);for(r=0;r<s;++r)n.push(Zi(t[r],e[r]));for(;r<a;++r)i[r]=t[r];for(;r<o;++r)i[r]=e[r];return function(t){for(r=0;r<s;++r)i[r]=n[r](t);return i}}t.interpolate=Zi,t.interpolators=[function(t,e){var r=typeof e;return(\"string\"===r?ge.has(e.toLowerCase())||/^(#|rgb\\(|hsl\\()/i.test(e)?qi:Yi:e instanceof Ut?qi:Array.isArray(e)?Ji:\"object\"===r&&isNaN(e)?Hi:Gi)(t,e)}],t.interpolateArray=Ji;var Ki=function(){return P},$i=t.map({linear:Ki,poly:function(t){return function(e){return Math.pow(e,t)}},quad:function(){return ra},cubic:function(){return na},sin:function(){return aa},exp:function(){return oa},circle:function(){return sa},elastic:function(t,e){var r;arguments.length<2&&(e=.45);arguments.length?r=e/Mt*Math.asin(1/t):(t=1,r=e/4);return function(n){return 1+t*Math.pow(2,-10*n)*Math.sin((n-r)*Mt/e)}},back:function(t){t||(t=1.70158);return function(e){return e*e*((t+1)*e-t)}},bounce:function(){return la}}),Qi=t.map({in:P,out:ta,\"in-out\":ea,\"out-in\":function(t){return ea(ta(t))}});function ta(t){return function(e){return 1-t(1-e)}}function ea(t){return function(e){return.5*(e<.5?t(2*e):2-t(2-2*e))}}function ra(t){return t*t}function na(t){return t*t*t}function ia(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}function aa(t){return 1-Math.cos(t*Et)}function oa(t){return Math.pow(2,10*(t-1))}function sa(t){return 1-Math.sqrt(1-t*t)}function la(t){return t<1/2.75?7.5625*t*t:t<2/2.75?7.5625*(t-=1.5/2.75)*t+.75:t<2.5/2.75?7.5625*(t-=2.25/2.75)*t+.9375:7.5625*(t-=2.625/2.75)*t+.984375}function ca(t,e){return e-=t,function(r){return Math.round(t+e*r)}}function ua(t){var e,r,n,i=[t.a,t.b],a=[t.c,t.d],o=fa(i),s=ha(i,a),l=fa(((e=a)[0]+=(n=-s)*(r=i)[0],e[1]+=n*r[1],e))||0;i[0]*a[1]<a[0]*i[1]&&(i[0]*=-1,i[1]*=-1,o*=-1,s*=-1),this.rotate=(o?Math.atan2(i[1],i[0]):Math.atan2(-a[0],a[1]))*Lt,this.translate=[t.e,t.f],this.scale=[o,l],this.skew=l?Math.atan2(s,l)*Lt:0}function ha(t,e){return t[0]*e[0]+t[1]*e[1]}function fa(t){var e=Math.sqrt(ha(t,t));return e&&(t[0]/=e,t[1]/=e),e}t.ease=function(t){var e,n=t.indexOf(\"-\"),i=n>=0?t.slice(0,n):t,a=n>=0?t.slice(n+1):\"in\";return i=$i.get(i)||Ki,a=Qi.get(a)||P,e=a(i.apply(null,r.call(arguments,1))),function(t){return t<=0?0:t>=1?1:e(t)}},t.interpolateHcl=function(e,r){e=t.hcl(e),r=t.hcl(r);var n=e.h,i=e.c,a=e.l,o=r.h-n,s=r.c-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.c:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Wt(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateHsl=function(e,r){e=t.hsl(e),r=t.hsl(r);var n=e.h,i=e.s,a=e.l,o=r.h-n,s=r.s-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.s:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Ht(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateLab=function(e,r){e=t.lab(e),r=t.lab(r);var n=e.l,i=e.a,a=e.b,o=r.l-n,s=r.a-i,l=r.b-a;return function(t){return te(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateRound=ca,t.transform=function(e){var r=i.createElementNS(t.ns.prefix.svg,\"g\");return(t.transform=function(t){if(null!=t){r.setAttribute(\"transform\",t);var e=r.transform.baseVal.consolidate()}return new ua(e?e.matrix:pa)})(e)},ua.prototype.toString=function(){return\"translate(\"+this.translate+\")rotate(\"+this.rotate+\")skewX(\"+this.skew+\")scale(\"+this.scale+\")\"};var pa={a:1,b:0,c:0,d:1,e:0,f:0};function da(t){return t.length?t.pop()+\",\":\"\"}function ga(e,r){var n=[],i=[];return e=t.transform(e),r=t.transform(r),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(\"translate(\",null,\",\",null,\")\");n.push({i:i-4,x:Gi(t[0],e[0])},{i:i-2,x:Gi(t[1],e[1])})}else(e[0]||e[1])&&r.push(\"translate(\"+e+\")\")}(e.translate,r.translate,n,i),function(t,e,r,n){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),n.push({i:r.push(da(r)+\"rotate(\",null,\")\")-2,x:Gi(t,e)})):e&&r.push(da(r)+\"rotate(\"+e+\")\")}(e.rotate,r.rotate,n,i),function(t,e,r,n){t!==e?n.push({i:r.push(da(r)+\"skewX(\",null,\")\")-2,x:Gi(t,e)}):e&&r.push(da(r)+\"skewX(\"+e+\")\")}(e.skew,r.skew,n,i),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(da(r)+\"scale(\",null,\",\",null,\")\");n.push({i:i-4,x:Gi(t[0],e[0])},{i:i-2,x:Gi(t[1],e[1])})}else 1===e[0]&&1===e[1]||r.push(da(r)+\"scale(\"+e+\")\")}(e.scale,r.scale,n,i),e=r=null,function(t){for(var e,r=-1,a=i.length;++r<a;)n[(e=i[r]).i]=e.x(t);return n.join(\"\")}}function va(t,e){return e=(e-=t=+t)||1/e,function(r){return(r-t)/e}}function ma(t,e){return e=(e-=t=+t)||1/e,function(r){return Math.max(0,Math.min(1,(r-t)/e))}}function ya(t){for(var e=t.source,r=t.target,n=function(t,e){if(t===e)return t;var r=xa(t),n=xa(e),i=r.pop(),a=n.pop(),o=null;for(;i===a;)o=i,i=r.pop(),a=n.pop();return o}(e,r),i=[e];e!==n;)e=e.parent,i.push(e);for(var a=i.length;r!==n;)i.splice(a,0,r),r=r.parent;return i}function xa(t){for(var e=[],r=t.parent;null!=r;)e.push(t),t=r,r=r.parent;return e.push(t),e}function ba(t){t.fixed|=2}function _a(t){t.fixed&=-7}function wa(t){t.fixed|=4,t.px=t.x,t.py=t.y}function ka(t){t.fixed&=-5}t.interpolateTransform=ga,t.layout={},t.layout.bundle=function(){return function(t){for(var e=[],r=-1,n=t.length;++r<n;)e.push(ya(t[r]));return e}},t.layout.chord=function(){var e,r,n,i,a,o,s,l={},c=0;function u(){var l,u,f,p,d,g={},v=[],m=t.range(i),y=[];for(e=[],r=[],l=0,p=-1;++p<i;){for(u=0,d=-1;++d<i;)u+=n[p][d];v.push(u),y.push(t.range(i)),l+=u}for(a&&m.sort(function(t,e){return a(v[t],v[e])}),o&&y.forEach(function(t,e){t.sort(function(t,r){return o(n[e][t],n[e][r])})}),l=(Mt-c*i)/l,u=0,p=-1;++p<i;){for(f=u,d=-1;++d<i;){var x=m[p],b=y[x][d],_=n[x][b],w=u,k=u+=_*l;g[x+\"-\"+b]={index:x,subindex:b,startAngle:w,endAngle:k,value:_}}r[x]={index:x,startAngle:f,endAngle:u,value:v[x]},u+=c}for(p=-1;++p<i;)for(d=p-1;++d<i;){var T=g[p+\"-\"+d],A=g[d+\"-\"+p];(T.value||A.value)&&e.push(T.value<A.value?{source:A,target:T}:{source:T,target:A})}s&&h()}function h(){e.sort(function(t,e){return s((t.source.value+t.target.value)/2,(e.source.value+e.target.value)/2)})}return l.matrix=function(t){return arguments.length?(i=(n=t)&&n.length,e=r=null,l):n},l.padding=function(t){return arguments.length?(c=t,e=r=null,l):c},l.sortGroups=function(t){return arguments.length?(a=t,e=r=null,l):a},l.sortSubgroups=function(t){return arguments.length?(o=t,e=null,l):o},l.sortChords=function(t){return arguments.length?(s=t,e&&h(),l):s},l.chords=function(){return e||u(),e},l.groups=function(){return r||u(),r},l},t.layout.force=function(){var e,r,n,i,a,o,s={},l=t.dispatch(\"start\",\"tick\",\"end\"),c=[1,1],u=.9,h=Ta,f=Aa,p=-30,d=Ma,g=.1,v=.64,m=[],y=[];function x(t){return function(e,r,n,i){if(e.point!==t){var a=e.cx-t.x,o=e.cy-t.y,s=i-r,l=a*a+o*o;if(s*s/v<l){if(l<d){var c=e.charge/l;t.px-=a*c,t.py-=o*c}return!0}if(e.point&&l&&l<d){c=e.pointCharge/l;t.px-=a*c,t.py-=o*c}}return!e.charge}}function b(e){e.px=t.event.x,e.py=t.event.y,s.resume()}return s.tick=function(){if((n*=.99)<.005)return e=null,l.end({type:\"end\",alpha:n=0}),!0;var r,s,h,f,d,v,b,_,w,k=m.length,T=y.length;for(s=0;s<T;++s)f=(h=y[s]).source,(v=(_=(d=h.target).x-f.x)*_+(w=d.y-f.y)*w)&&(_*=v=n*a[s]*((v=Math.sqrt(v))-i[s])/v,w*=v,d.x-=_*(b=f.weight+d.weight?f.weight/(f.weight+d.weight):.5),d.y-=w*b,f.x+=_*(b=1-b),f.y+=w*b);if((b=n*g)&&(_=c[0]/2,w=c[1]/2,s=-1,b))for(;++s<k;)(h=m[s]).x+=(_-h.x)*b,h.y+=(w-h.y)*b;if(p)for(!function t(e,r,n){var i=0,a=0;e.charge=0;if(!e.leaf)for(var o,s=e.nodes,l=s.length,c=-1;++c<l;)null!=(o=s[c])&&(t(o,r,n),e.charge+=o.charge,i+=o.charge*o.cx,a+=o.charge*o.cy);if(e.point){e.leaf||(e.point.x+=Math.random()-.5,e.point.y+=Math.random()-.5);var u=r*n[e.point.index];e.charge+=e.pointCharge=u,i+=u*e.point.x,a+=u*e.point.y}e.cx=i/e.charge;e.cy=a/e.charge}(r=t.geom.quadtree(m),n,o),s=-1;++s<k;)(h=m[s]).fixed||r.visit(x(h));for(s=-1;++s<k;)(h=m[s]).fixed?(h.x=h.px,h.y=h.py):(h.x-=(h.px-(h.px=h.x))*u,h.y-=(h.py-(h.py=h.y))*u);l.tick({type:\"tick\",alpha:n})},s.nodes=function(t){return arguments.length?(m=t,s):m},s.links=function(t){return arguments.length?(y=t,s):y},s.size=function(t){return arguments.length?(c=t,s):c},s.linkDistance=function(t){return arguments.length?(h=\"function\"==typeof t?t:+t,s):h},s.distance=s.linkDistance,s.linkStrength=function(t){return arguments.length?(f=\"function\"==typeof t?t:+t,s):f},s.friction=function(t){return arguments.length?(u=+t,s):u},s.charge=function(t){return arguments.length?(p=\"function\"==typeof t?t:+t,s):p},s.chargeDistance=function(t){return arguments.length?(d=t*t,s):Math.sqrt(d)},s.gravity=function(t){return arguments.length?(g=+t,s):g},s.theta=function(t){return arguments.length?(v=t*t,s):Math.sqrt(v)},s.alpha=function(t){return arguments.length?(t=+t,n?t>0?n=t:(e.c=null,e.t=NaN,e=null,l.end({type:\"end\",alpha:n=0})):t>0&&(l.start({type:\"start\",alpha:n=t}),e=Te(s.tick)),s):n},s.start=function(){var t,e,r,n=m.length,l=y.length,u=c[0],d=c[1];for(t=0;t<n;++t)(r=m[t]).index=t,r.weight=0;for(t=0;t<l;++t)\"number\"==typeof(r=y[t]).source&&(r.source=m[r.source]),\"number\"==typeof r.target&&(r.target=m[r.target]),++r.source.weight,++r.target.weight;for(t=0;t<n;++t)r=m[t],isNaN(r.x)&&(r.x=g(\"x\",u)),isNaN(r.y)&&(r.y=g(\"y\",d)),isNaN(r.px)&&(r.px=r.x),isNaN(r.py)&&(r.py=r.y);if(i=[],\"function\"==typeof h)for(t=0;t<l;++t)i[t]=+h.call(this,y[t],t);else for(t=0;t<l;++t)i[t]=h;if(a=[],\"function\"==typeof f)for(t=0;t<l;++t)a[t]=+f.call(this,y[t],t);else for(t=0;t<l;++t)a[t]=f;if(o=[],\"function\"==typeof p)for(t=0;t<n;++t)o[t]=+p.call(this,m[t],t);else for(t=0;t<n;++t)o[t]=p;function g(r,i){if(!e){for(e=new Array(n),c=0;c<n;++c)e[c]=[];for(c=0;c<l;++c){var a=y[c];e[a.source.index].push(a.target),e[a.target.index].push(a.source)}}for(var o,s=e[t],c=-1,u=s.length;++c<u;)if(!isNaN(o=s[c][r]))return o;return Math.random()*i}return s.resume()},s.resume=function(){return s.alpha(.1)},s.stop=function(){return s.alpha(0)},s.drag=function(){if(r||(r=t.behavior.drag().origin(P).on(\"dragstart.force\",ba).on(\"drag.force\",b).on(\"dragend.force\",_a)),!arguments.length)return r;this.on(\"mouseover.force\",wa).on(\"mouseout.force\",ka).call(r)},t.rebind(s,l,\"on\")};var Ta=20,Aa=1,Ma=1/0;function Sa(e,r){return t.rebind(e,r,\"sort\",\"children\",\"value\"),e.nodes=e,e.links=za,e}function Ea(t,e){for(var r=[t];null!=(t=r.pop());)if(e(t),(i=t.children)&&(n=i.length))for(var n,i;--n>=0;)r.push(i[n])}function Ca(t,e){for(var r=[t],n=[];null!=(t=r.pop());)if(n.push(t),(a=t.children)&&(i=a.length))for(var i,a,o=-1;++o<i;)r.push(a[o]);for(;null!=(t=n.pop());)e(t)}function La(t){return t.children}function Pa(t){return t.value}function Oa(t,e){return e.value-t.value}function za(e){return t.merge(e.map(function(t){return(t.children||[]).map(function(e){return{source:t,target:e}})}))}t.layout.hierarchy=function(){var t=Oa,e=La,r=Pa;function n(i){var a,o=[i],s=[];for(i.depth=0;null!=(a=o.pop());)if(s.push(a),(c=e.call(n,a,a.depth))&&(l=c.length)){for(var l,c,u;--l>=0;)o.push(u=c[l]),u.parent=a,u.depth=a.depth+1;r&&(a.value=0),a.children=c}else r&&(a.value=+r.call(n,a,a.depth)||0),delete a.children;return Ca(i,function(e){var n,i;t&&(n=e.children)&&n.sort(t),r&&(i=e.parent)&&(i.value+=e.value)}),s}return n.sort=function(e){return arguments.length?(t=e,n):t},n.children=function(t){return arguments.length?(e=t,n):e},n.value=function(t){return arguments.length?(r=t,n):r},n.revalue=function(t){return r&&(Ea(t,function(t){t.children&&(t.value=0)}),Ca(t,function(t){var e;t.children||(t.value=+r.call(n,t,t.depth)||0),(e=t.parent)&&(e.value+=t.value)})),t},n},t.layout.partition=function(){var e=t.layout.hierarchy(),r=[1,1];function n(t,n){var i=e.call(this,t,n);return function t(e,r,n,i){var a=e.children;if(e.x=r,e.y=e.depth*i,e.dx=n,e.dy=i,a&&(o=a.length)){var o,s,l,c=-1;for(n=e.value?n/e.value:0;++c<o;)t(s=a[c],r,l=s.value*n,i),r+=l}}(i[0],0,r[0],r[1]/function t(e){var r=e.children,n=0;if(r&&(i=r.length))for(var i,a=-1;++a<i;)n=Math.max(n,t(r[a]));return 1+n}(i[0])),i}return n.size=function(t){return arguments.length?(r=t,n):r},Sa(n,e)},t.layout.pie=function(){var e=Number,r=Ia,n=0,i=Mt,a=0;function o(s){var l,c=s.length,u=s.map(function(t,r){return+e.call(o,t,r)}),h=+(\"function\"==typeof n?n.apply(this,arguments):n),f=(\"function\"==typeof i?i.apply(this,arguments):i)-h,p=Math.min(Math.abs(f)/c,+(\"function\"==typeof a?a.apply(this,arguments):a)),d=p*(f<0?-1:1),g=t.sum(u),v=g?(f-c*d)/g:0,m=t.range(c),y=[];return null!=r&&m.sort(r===Ia?function(t,e){return u[e]-u[t]}:function(t,e){return r(s[t],s[e])}),m.forEach(function(t){y[t]={data:s[t],value:l=u[t],startAngle:h,endAngle:h+=l*v+d,padAngle:p}}),y}return o.value=function(t){return arguments.length?(e=t,o):e},o.sort=function(t){return arguments.length?(r=t,o):r},o.startAngle=function(t){return arguments.length?(n=t,o):n},o.endAngle=function(t){return arguments.length?(i=t,o):i},o.padAngle=function(t){return arguments.length?(a=t,o):a},o};var Ia={};function Da(t){return t.x}function Ra(t){return t.y}function Fa(t,e,r){t.y0=e,t.y=r}t.layout.stack=function(){var e=P,r=ja,n=Ua,i=Fa,a=Da,o=Ra;function s(l,c){if(!(p=l.length))return l;var u=l.map(function(t,r){return e.call(s,t,r)}),h=u.map(function(t){return t.map(function(t,e){return[a.call(s,t,e),o.call(s,t,e)]})}),f=r.call(s,h,c);u=t.permute(u,f),h=t.permute(h,f);var p,d,g,v,m=n.call(s,h,c),y=u[0].length;for(g=0;g<y;++g)for(i.call(s,u[0][g],v=m[g],h[0][g][1]),d=1;d<p;++d)i.call(s,u[d][g],v+=h[d-1][g][1],h[d][g][1]);return l}return s.values=function(t){return arguments.length?(e=t,s):e},s.order=function(t){return arguments.length?(r=\"function\"==typeof t?t:Ba.get(t)||ja,s):r},s.offset=function(t){return arguments.length?(n=\"function\"==typeof t?t:Na.get(t)||Ua,s):n},s.x=function(t){return arguments.length?(a=t,s):a},s.y=function(t){return arguments.length?(o=t,s):o},s.out=function(t){return arguments.length?(i=t,s):i},s};var Ba=t.map({\"inside-out\":function(e){var r,n,i=e.length,a=e.map(Va),o=e.map(qa),s=t.range(i).sort(function(t,e){return a[t]-a[e]}),l=0,c=0,u=[],h=[];for(r=0;r<i;++r)n=s[r],l<c?(l+=o[n],u.push(n)):(c+=o[n],h.push(n));return h.reverse().concat(u)},reverse:function(e){return t.range(e.length).reverse()},default:ja}),Na=t.map({silhouette:function(t){var e,r,n,i=t.length,a=t[0].length,o=[],s=0,l=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];n>s&&(s=n),o.push(n)}for(r=0;r<a;++r)l[r]=(s-o[r])/2;return l},wiggle:function(t){var e,r,n,i,a,o,s,l,c,u=t.length,h=t[0],f=h.length,p=[];for(p[0]=l=c=0,r=1;r<f;++r){for(e=0,i=0;e<u;++e)i+=t[e][r][1];for(e=0,a=0,s=h[r][0]-h[r-1][0];e<u;++e){for(n=0,o=(t[e][r][1]-t[e][r-1][1])/(2*s);n<e;++n)o+=(t[n][r][1]-t[n][r-1][1])/s;a+=o*t[e][r][1]}p[r]=l-=i?a/i*s:0,l<c&&(c=l)}for(r=0;r<f;++r)p[r]-=c;return p},expand:function(t){var e,r,n,i=t.length,a=t[0].length,o=1/i,s=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];if(n)for(e=0;e<i;e++)t[e][r][1]/=n;else for(e=0;e<i;e++)t[e][r][1]=o}for(r=0;r<a;++r)s[r]=0;return s},zero:Ua});function ja(e){return t.range(e.length)}function Ua(t){for(var e=-1,r=t[0].length,n=[];++e<r;)n[e]=0;return n}function Va(t){for(var e,r=1,n=0,i=t[0][1],a=t.length;r<a;++r)(e=t[r][1])>i&&(n=r,i=e);return n}function qa(t){return t.reduce(Ha,0)}function Ha(t,e){return t+e[1]}function Ga(t,e){return Ya(t,Math.ceil(Math.log(e.length)/Math.LN2+1))}function Ya(t,e){for(var r=-1,n=+t[0],i=(t[1]-n)/e,a=[];++r<=e;)a[r]=i*r+n;return a}function Wa(e){return[t.min(e),t.max(e)]}function Xa(t,e){return t.value-e.value}function Za(t,e){var r=t._pack_next;t._pack_next=e,e._pack_prev=t,e._pack_next=r,r._pack_prev=e}function Ja(t,e){t._pack_next=e,e._pack_prev=t}function Ka(t,e){var r=e.x-t.x,n=e.y-t.y,i=t.r+e.r;return.999*i*i>r*r+n*n}function $a(t){if((e=t.children)&&(l=e.length)){var e,r,n,i,a,o,s,l,c=1/0,u=-1/0,h=1/0,f=-1/0;if(e.forEach(Qa),(r=e[0]).x=-r.r,r.y=0,x(r),l>1&&((n=e[1]).x=n.r,n.y=0,x(n),l>2))for(eo(r,n,i=e[2]),x(i),Za(r,i),r._pack_prev=i,Za(i,n),n=r._pack_next,a=3;a<l;a++){eo(r,n,i=e[a]);var p=0,d=1,g=1;for(o=n._pack_next;o!==n;o=o._pack_next,d++)if(Ka(o,i)){p=1;break}if(1==p)for(s=r._pack_prev;s!==o._pack_prev&&!Ka(s,i);s=s._pack_prev,g++);p?(d<g||d==g&&n.r<r.r?Ja(r,n=o):Ja(r=s,n),a--):(Za(r,i),n=i,x(i))}var v=(c+u)/2,m=(h+f)/2,y=0;for(a=0;a<l;a++)(i=e[a]).x-=v,i.y-=m,y=Math.max(y,i.r+Math.sqrt(i.x*i.x+i.y*i.y));t.r=y,e.forEach(to)}function x(t){c=Math.min(t.x-t.r,c),u=Math.max(t.x+t.r,u),h=Math.min(t.y-t.r,h),f=Math.max(t.y+t.r,f)}}function Qa(t){t._pack_next=t._pack_prev=t}function to(t){delete t._pack_next,delete t._pack_prev}function eo(t,e,r){var n=t.r+r.r,i=e.x-t.x,a=e.y-t.y;if(n&&(i||a)){var o=e.r+r.r,s=i*i+a*a,l=.5+((n*=n)-(o*=o))/(2*s),c=Math.sqrt(Math.max(0,2*o*(n+s)-(n-=s)*n-o*o))/(2*s);r.x=t.x+l*i+c*a,r.y=t.y+l*a-c*i}else r.x=t.x+n,r.y=t.y}function ro(t,e){return t.parent==e.parent?1:2}function no(t){var e=t.children;return e.length?e[0]:t.t}function io(t){var e,r=t.children;return(e=r.length)?r[e-1]:t.t}function ao(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function oo(t,e,r){return t.a.parent===e.parent?t.a:r}function so(t){return{x:t.x,y:t.y,dx:t.dx,dy:t.dy}}function lo(t,e){var r=t.x+e[3],n=t.y+e[0],i=t.dx-e[1]-e[3],a=t.dy-e[0]-e[2];return i<0&&(r+=i/2,i=0),a<0&&(n+=a/2,a=0),{x:r,y:n,dx:i,dy:a}}function co(t){var e=t[0],r=t[t.length-1];return e<r?[e,r]:[r,e]}function uo(t){return t.rangeExtent?t.rangeExtent():co(t.range())}function ho(t,e,r,n){var i=r(t[0],t[1]),a=n(e[0],e[1]);return function(t){return a(i(t))}}function fo(t,e){var r,n=0,i=t.length-1,a=t[n],o=t[i];return o<a&&(r=n,n=i,i=r,r=a,a=o,o=r),t[n]=e.floor(a),t[i]=e.ceil(o),t}function po(t){return t?{floor:function(e){return Math.floor(e/t)*t},ceil:function(e){return Math.ceil(e/t)*t}}:go}t.layout.histogram=function(){var e=!0,r=Number,n=Wa,i=Ga;function a(a,o){for(var s,l,c=[],u=a.map(r,this),h=n.call(this,u,o),f=i.call(this,h,u,o),p=(o=-1,u.length),d=f.length-1,g=e?1:1/p;++o<d;)(s=c[o]=[]).dx=f[o+1]-(s.x=f[o]),s.y=0;if(d>0)for(o=-1;++o<p;)(l=u[o])>=h[0]&&l<=h[1]&&((s=c[t.bisect(f,l,1,d)-1]).y+=g,s.push(a[o]));return c}return a.value=function(t){return arguments.length?(r=t,a):r},a.range=function(t){return arguments.length?(n=ve(t),a):n},a.bins=function(t){return arguments.length?(i=\"number\"==typeof t?function(e){return Ya(e,t)}:ve(t),a):i},a.frequency=function(t){return arguments.length?(e=!!t,a):e},a},t.layout.pack=function(){var e,r=t.layout.hierarchy().sort(Xa),n=0,i=[1,1];function a(t,a){var o=r.call(this,t,a),s=o[0],l=i[0],c=i[1],u=null==e?Math.sqrt:\"function\"==typeof e?e:function(){return e};if(s.x=s.y=0,Ca(s,function(t){t.r=+u(t.value)}),Ca(s,$a),n){var h=n*(e?1:Math.max(2*s.r/l,2*s.r/c))/2;Ca(s,function(t){t.r+=h}),Ca(s,$a),Ca(s,function(t){t.r-=h})}return function t(e,r,n,i){var a=e.children;e.x=r+=i*e.x;e.y=n+=i*e.y;e.r*=i;if(a)for(var o=-1,s=a.length;++o<s;)t(a[o],r,n,i)}(s,l/2,c/2,e?1:1/Math.max(2*s.r/l,2*s.r/c)),o}return a.size=function(t){return arguments.length?(i=t,a):i},a.radius=function(t){return arguments.length?(e=null==t||\"function\"==typeof t?t:+t,a):e},a.padding=function(t){return arguments.length?(n=+t,a):n},Sa(a,r)},t.layout.tree=function(){var e=t.layout.hierarchy().sort(null).value(null),r=ro,n=[1,1],i=null;function a(t,a){var c=e.call(this,t,a),u=c[0],h=function(t){var e,r={A:null,children:[t]},n=[r];for(;null!=(e=n.pop());)for(var i,a=e.children,o=0,s=a.length;o<s;++o)n.push((a[o]=i={_:a[o],parent:e,children:(i=a[o].children)&&i.slice()||[],A:null,a:null,z:0,m:0,c:0,s:0,t:null,i:o}).a=i);return r.children[0]}(u);if(Ca(h,o),h.parent.m=-h.z,Ea(h,s),i)Ea(u,l);else{var f=u,p=u,d=u;Ea(u,function(t){t.x<f.x&&(f=t),t.x>p.x&&(p=t),t.depth>d.depth&&(d=t)});var g=r(f,p)/2-f.x,v=n[0]/(p.x+r(p,f)/2+g),m=n[1]/(d.depth||1);Ea(u,function(t){t.x=(t.x+g)*v,t.y=t.depth*m})}return c}function o(t){var e=t.children,n=t.parent.children,i=t.i?n[t.i-1]:null;if(e.length){!function(t){var e,r=0,n=0,i=t.children,a=i.length;for(;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(t);var a=(e[0].z+e[e.length-1].z)/2;i?(t.z=i.z+r(t._,i._),t.m=t.z-a):t.z=a}else i&&(t.z=i.z+r(t._,i._));t.parent.A=function(t,e,n){if(e){for(var i,a=t,o=t,s=e,l=a.parent.children[0],c=a.m,u=o.m,h=s.m,f=l.m;s=io(s),a=no(a),s&&a;)l=no(l),(o=io(o)).a=t,(i=s.z+h-a.z-c+r(s._,a._))>0&&(ao(oo(s,t,n),t,i),c+=i,u+=i),h+=s.m,c+=a.m,f+=l.m,u+=o.m;s&&!io(o)&&(o.t=s,o.m+=h-u),a&&!no(l)&&(l.t=a,l.m+=c-f,n=t)}return n}(t,i,t.parent.A||n[0])}function s(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function l(t){t.x*=n[0],t.y=t.depth*n[1]}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t)?l:null,a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null==(n=t)?null:l,a):i?n:null},Sa(a,e)},t.layout.cluster=function(){var e=t.layout.hierarchy().sort(null).value(null),r=ro,n=[1,1],i=!1;function a(a,o){var s,l=e.call(this,a,o),c=l[0],u=0;Ca(c,function(e){var n=e.children;n&&n.length?(e.x=function(t){return t.reduce(function(t,e){return t+e.x},0)/t.length}(n),e.y=function(e){return 1+t.max(e,function(t){return t.y})}(n)):(e.x=s?u+=r(e,s):0,e.y=0,s=e)});var h=function t(e){var r=e.children;return r&&r.length?t(r[0]):e}(c),f=function t(e){var r,n=e.children;return n&&(r=n.length)?t(n[r-1]):e}(c),p=h.x-r(h,f)/2,d=f.x+r(f,h)/2;return Ca(c,i?function(t){t.x=(t.x-c.x)*n[0],t.y=(c.y-t.y)*n[1]}:function(t){t.x=(t.x-p)/(d-p)*n[0],t.y=(1-(c.y?t.y/c.y:1))*n[1]}),l}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t),a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null!=(n=t),a):i?n:null},Sa(a,e)},t.layout.treemap=function(){var e,r=t.layout.hierarchy(),n=Math.round,i=[1,1],a=null,o=so,s=!1,l=\"squarify\",c=.5*(1+Math.sqrt(5));function u(t,e){for(var r,n,i=-1,a=t.length;++i<a;)n=(r=t[i]).value*(e<0?0:e),r.area=isNaN(n)||n<=0?0:n}function h(t){var e=t.children;if(e&&e.length){var r,n,i,a=o(t),s=[],c=e.slice(),f=1/0,g=\"slice\"===l?a.dx:\"dice\"===l?a.dy:\"slice-dice\"===l?1&t.depth?a.dy:a.dx:Math.min(a.dx,a.dy);for(u(c,a.dx*a.dy/t.value),s.area=0;(i=c.length)>0;)s.push(r=c[i-1]),s.area+=r.area,\"squarify\"!==l||(n=p(s,g))<=f?(c.pop(),f=n):(s.area-=s.pop().area,d(s,g,a,!1),g=Math.min(a.dx,a.dy),s.length=s.area=0,f=1/0);s.length&&(d(s,g,a,!0),s.length=s.area=0),e.forEach(h)}}function f(t){var e=t.children;if(e&&e.length){var r,n=o(t),i=e.slice(),a=[];for(u(i,n.dx*n.dy/t.value),a.area=0;r=i.pop();)a.push(r),a.area+=r.area,null!=r.z&&(d(a,r.z?n.dx:n.dy,n,!i.length),a.length=a.area=0);e.forEach(f)}}function p(t,e){for(var r,n=t.area,i=0,a=1/0,o=-1,s=t.length;++o<s;)(r=t[o].area)&&(r<a&&(a=r),r>i&&(i=r));return e*=e,(n*=n)?Math.max(e*i*c/n,n/(e*a*c)):1/0}function d(t,e,r,i){var a,o=-1,s=t.length,l=r.x,c=r.y,u=e?n(t.area/e):0;if(e==r.dx){for((i||u>r.dy)&&(u=r.dy);++o<s;)(a=t[o]).x=l,a.y=c,a.dy=u,l+=a.dx=Math.min(r.x+r.dx-l,u?n(a.area/u):0);a.z=!0,a.dx+=r.x+r.dx-l,r.y+=u,r.dy-=u}else{for((i||u>r.dx)&&(u=r.dx);++o<s;)(a=t[o]).x=l,a.y=c,a.dx=u,c+=a.dy=Math.min(r.y+r.dy-c,u?n(a.area/u):0);a.z=!1,a.dy+=r.y+r.dy-c,r.x+=u,r.dx-=u}}function g(t){var n=e||r(t),a=n[0];return a.x=a.y=0,a.value?(a.dx=i[0],a.dy=i[1]):a.dx=a.dy=0,e&&r.revalue(a),u([a],a.dx*a.dy/a.value),(e?f:h)(a),s&&(e=n),n}return g.size=function(t){return arguments.length?(i=t,g):i},g.padding=function(t){if(!arguments.length)return a;function e(e){return lo(e,t)}var r;return o=null==(a=t)?so:\"function\"==(r=typeof t)?function(e){var r=t.call(g,e,e.depth);return null==r?so(e):lo(e,\"number\"==typeof r?[r,r,r,r]:r)}:\"number\"===r?(t=[t,t,t,t],e):e,g},g.round=function(t){return arguments.length?(n=t?Math.round:Number,g):n!=Number},g.sticky=function(t){return arguments.length?(s=t,e=null,g):s},g.ratio=function(t){return arguments.length?(c=t,g):c},g.mode=function(t){return arguments.length?(l=t+\"\",g):l},Sa(g,r)},t.random={normal:function(t,e){var r=arguments.length;return r<2&&(e=1),r<1&&(t=0),function(){var r,n,i;do{i=(r=2*Math.random()-1)*r+(n=2*Math.random()-1)*n}while(!i||i>1);return t+e*r*Math.sqrt(-2*Math.log(i)/i)}},logNormal:function(){var e=t.random.normal.apply(t,arguments);return function(){return Math.exp(e())}},bates:function(e){var r=t.random.irwinHall(e);return function(){return r()/e}},irwinHall:function(t){return function(){for(var e=0,r=0;r<t;r++)e+=Math.random();return e}}},t.scale={};var go={floor:P,ceil:P};function vo(e,r,n,i){var a=[],o=[],s=0,l=Math.min(e.length,r.length)-1;for(e[l]<e[0]&&(e=e.slice().reverse(),r=r.slice().reverse());++s<=l;)a.push(n(e[s-1],e[s])),o.push(i(r[s-1],r[s]));return function(r){var n=t.bisect(e,r,1,l)-1;return o[n](a[n](r))}}function mo(e,r){return t.rebind(e,r,\"range\",\"rangeRound\",\"interpolate\",\"clamp\")}function yo(t,e){return fo(t,po(xo(t,e)[2])),fo(t,po(xo(t,e)[2])),t}function xo(t,e){null==e&&(e=10);var r=co(t),n=r[1]-r[0],i=Math.pow(10,Math.floor(Math.log(n/e)/Math.LN10)),a=e/n*i;return a<=.15?i*=10:a<=.35?i*=5:a<=.75&&(i*=2),r[0]=Math.ceil(r[0]/i)*i,r[1]=Math.floor(r[1]/i)*i+.5*i,r[2]=i,r}function bo(e,r){return t.range.apply(t,xo(e,r))}function _o(e,r,n){var i=xo(e,r);if(n){var a=Le.exec(n);if(a.shift(),\"s\"===a[8]){var o=t.formatPrefix(Math.max(y(i[0]),y(i[1])));return a[7]||(a[7]=\".\"+ko(o.scale(i[2]))),a[8]=\"f\",n=t.format(a.join(\"\")),function(t){return n(o.scale(t))+o.symbol}}a[7]||(a[7]=\".\"+function(t,e){var r=ko(e[2]);return t in wo?Math.abs(r-ko(Math.max(y(e[0]),y(e[1]))))+ +(\"e\"!==t):r-2*(\"%\"===t)}(a[8],i)),n=a.join(\"\")}else n=\",.\"+ko(i[2])+\"f\";return t.format(n)}t.scale.linear=function(){return function t(e,r,n,i){var a,o;function s(){var t=Math.min(e.length,r.length)>2?vo:ho,s=i?ma:va;return a=t(e,r,s,n),o=t(r,e,s,Zi),l}function l(t){return a(t)}l.invert=function(t){return o(t)};l.domain=function(t){return arguments.length?(e=t.map(Number),s()):e};l.range=function(t){return arguments.length?(r=t,s()):r};l.rangeRound=function(t){return l.range(t).interpolate(ca)};l.clamp=function(t){return arguments.length?(i=t,s()):i};l.interpolate=function(t){return arguments.length?(n=t,s()):n};l.ticks=function(t){return bo(e,t)};l.tickFormat=function(t,r){return _o(e,t,r)};l.nice=function(t){return yo(e,t),s()};l.copy=function(){return t(e,r,n,i)};return s()}([0,1],[0,1],Zi,!1)};var wo={s:1,g:1,p:1,r:1,e:1};function ko(t){return-Math.floor(Math.log(t)/Math.LN10+.01)}t.scale.log=function(){return function e(r,n,i,a){function o(t){return(i?Math.log(t<0?0:t):-Math.log(t>0?0:-t))/Math.log(n)}function s(t){return i?Math.pow(n,t):-Math.pow(n,-t)}function l(t){return r(o(t))}l.invert=function(t){return s(r.invert(t))};l.domain=function(t){return arguments.length?(i=t[0]>=0,r.domain((a=t.map(Number)).map(o)),l):a};l.base=function(t){return arguments.length?(n=+t,r.domain(a.map(o)),l):n};l.nice=function(){var t=fo(a.map(o),i?Math:Ao);return r.domain(t),a=t.map(s),l};l.ticks=function(){var t=co(a),e=[],r=t[0],l=t[1],c=Math.floor(o(r)),u=Math.ceil(o(l)),h=n%1?2:n;if(isFinite(u-c)){if(i){for(;c<u;c++)for(var f=1;f<h;f++)e.push(s(c)*f);e.push(s(c))}else for(e.push(s(c));c++<u;)for(var f=h-1;f>0;f--)e.push(s(c)*f);for(c=0;e[c]<r;c++);for(u=e.length;e[u-1]>l;u--);e=e.slice(c,u)}return e};l.tickFormat=function(e,r){if(!arguments.length)return To;arguments.length<2?r=To:\"function\"!=typeof r&&(r=t.format(r));var i=Math.max(1,n*e/l.ticks().length);return function(t){var e=t/s(Math.round(o(t)));return e*n<n-.5&&(e*=n),e<=i?r(t):\"\"}};l.copy=function(){return e(r.copy(),n,i,a)};return mo(l,r)}(t.scale.linear().domain([0,1]),10,!0,[1,10])};var To=t.format(\".0e\"),Ao={floor:function(t){return-Math.ceil(-t)},ceil:function(t){return-Math.floor(-t)}};function Mo(t){return function(e){return e<0?-Math.pow(-e,t):Math.pow(e,t)}}t.scale.pow=function(){return function t(e,r,n){var i=Mo(r),a=Mo(1/r);function o(t){return e(i(t))}o.invert=function(t){return a(e.invert(t))};o.domain=function(t){return arguments.length?(e.domain((n=t.map(Number)).map(i)),o):n};o.ticks=function(t){return bo(n,t)};o.tickFormat=function(t,e){return _o(n,t,e)};o.nice=function(t){return o.domain(yo(n,t))};o.exponent=function(t){return arguments.length?(i=Mo(r=t),a=Mo(1/r),e.domain(n.map(i)),o):r};o.copy=function(){return t(e.copy(),r,n)};return mo(o,e)}(t.scale.linear(),1,[0,1])},t.scale.sqrt=function(){return t.scale.pow().exponent(.5)},t.scale.ordinal=function(){return function e(r,n){var i,a,o;function s(t){return a[((i.get(t)||(\"range\"===n.t?i.set(t,r.push(t)):NaN))-1)%a.length]}function l(e,n){return t.range(r.length).map(function(t){return e+n*t})}s.domain=function(t){if(!arguments.length)return r;r=[],i=new b;for(var e,a=-1,o=t.length;++a<o;)i.has(e=t[a])||i.set(e,r.push(e));return s[n.t].apply(s,n.a)};s.range=function(t){return arguments.length?(a=t,o=0,n={t:\"range\",a:arguments},s):a};s.rangePoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=(i+c)/2,0):(c-i)/(r.length-1+e);return a=l(i+u*e/2,u),o=0,n={t:\"rangePoints\",a:arguments},s};s.rangeRoundPoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=c=Math.round((i+c)/2),0):(c-i)/(r.length-1+e)|0;return a=l(i+Math.round(u*e/2+(c-i-(r.length-1+e)*u)/2),u),o=0,n={t:\"rangeRoundPoints\",a:arguments},s};s.rangeBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],h=t[1-c],f=(h-u)/(r.length-e+2*i);return a=l(u+f*i,f),c&&a.reverse(),o=f*(1-e),n={t:\"rangeBands\",a:arguments},s};s.rangeRoundBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],h=t[1-c],f=Math.floor((h-u)/(r.length-e+2*i));return a=l(u+Math.round((h-u-(r.length-e)*f)/2),f),c&&a.reverse(),o=Math.round(f*(1-e)),n={t:\"rangeRoundBands\",a:arguments},s};s.rangeBand=function(){return o};s.rangeExtent=function(){return co(n.a[0])};s.copy=function(){return e(r,n)};return s.domain(r)}([],{t:\"range\",a:[[]]})},t.scale.category10=function(){return t.scale.ordinal().range(So)},t.scale.category20=function(){return t.scale.ordinal().range(Eo)},t.scale.category20b=function(){return t.scale.ordinal().range(Co)},t.scale.category20c=function(){return t.scale.ordinal().range(Lo)};var So=[2062260,16744206,2924588,14034728,9725885,9197131,14907330,8355711,12369186,1556175].map(se),Eo=[2062260,11454440,16744206,16759672,2924588,10018698,14034728,16750742,9725885,12955861,9197131,12885140,14907330,16234194,8355711,13092807,12369186,14408589,1556175,10410725].map(se),Co=[3750777,5395619,7040719,10264286,6519097,9216594,11915115,13556636,9202993,12426809,15186514,15190932,8666169,11356490,14049643,15177372,8077683,10834324,13528509,14589654].map(se),Lo=[3244733,7057110,10406625,13032431,15095053,16616764,16625259,16634018,3253076,7652470,10607003,13101504,7695281,10394312,12369372,14342891,6513507,9868950,12434877,14277081].map(se);function Po(){return 0}t.scale.quantile=function(){return function e(r,n){var i;function a(){var e=0,a=n.length;for(i=[];++e<a;)i[e-1]=t.quantile(r,e/a);return o}function o(e){if(!isNaN(e=+e))return n[t.bisect(i,e)]}o.domain=function(t){return arguments.length?(r=t.map(p).filter(d).sort(f),a()):r};o.range=function(t){return arguments.length?(n=t,a()):n};o.quantiles=function(){return i};o.invertExtent=function(t){return(t=n.indexOf(t))<0?[NaN,NaN]:[t>0?i[t-1]:r[0],t<i.length?i[t]:r[r.length-1]]};o.copy=function(){return e(r,n)};return a()}([],[])},t.scale.quantize=function(){return function t(e,r,n){var i,a;function o(t){return n[Math.max(0,Math.min(a,Math.floor(i*(t-e))))]}function s(){return i=n.length/(r-e),a=n.length-1,o}o.domain=function(t){return arguments.length?(e=+t[0],r=+t[t.length-1],s()):[e,r]};o.range=function(t){return arguments.length?(n=t,s()):n};o.invertExtent=function(t){return[t=(t=n.indexOf(t))<0?NaN:t/i+e,t+1/i]};o.copy=function(){return t(e,r,n)};return s()}(0,1,[0,1])},t.scale.threshold=function(){return function e(r,n){function i(e){if(e<=e)return n[t.bisect(r,e)]}i.domain=function(t){return arguments.length?(r=t,i):r};i.range=function(t){return arguments.length?(n=t,i):n};i.invertExtent=function(t){return t=n.indexOf(t),[r[t-1],r[t]]};i.copy=function(){return e(r,n)};return i}([.5],[0,1])},t.scale.identity=function(){return function t(e){function r(t){return+t}r.invert=r;r.domain=r.range=function(t){return arguments.length?(e=t.map(r),r):e};r.ticks=function(t){return bo(e,t)};r.tickFormat=function(t,r){return _o(e,t,r)};r.copy=function(){return t(e)};return r}([0,1])},t.svg={},t.svg.arc=function(){var t=zo,e=Io,r=Po,n=Oo,i=Do,a=Ro,o=Fo;function s(){var s=Math.max(0,+t.apply(this,arguments)),c=Math.max(0,+e.apply(this,arguments)),u=i.apply(this,arguments)-Et,h=a.apply(this,arguments)-Et,f=Math.abs(h-u),p=u>h?0:1;if(c<s&&(d=c,c=s,s=d),f>=St)return l(c,p)+(s?l(s,1-p):\"\")+\"Z\";var d,g,v,m,y,x,b,_,w,k,T,A,M=0,S=0,E=[];if((m=(+o.apply(this,arguments)||0)/2)&&(v=n===Oo?Math.sqrt(s*s+c*c):+n.apply(this,arguments),p||(S*=-1),c&&(S=It(v/c*Math.sin(m))),s&&(M=It(v/s*Math.sin(m)))),c){y=c*Math.cos(u+S),x=c*Math.sin(u+S),b=c*Math.cos(h-S),_=c*Math.sin(h-S);var C=Math.abs(h-u-2*S)<=At?0:1;if(S&&Bo(y,x,b,_)===p^C){var L=(u+h)/2;y=c*Math.cos(L),x=c*Math.sin(L),b=_=null}}else y=x=0;if(s){w=s*Math.cos(h-M),k=s*Math.sin(h-M),T=s*Math.cos(u+M),A=s*Math.sin(u+M);var P=Math.abs(u-h+2*M)<=At?0:1;if(M&&Bo(w,k,T,A)===1-p^P){var O=(u+h)/2;w=s*Math.cos(O),k=s*Math.sin(O),T=A=null}}else w=k=0;if(f>kt&&(d=Math.min(Math.abs(c-s)/2,+r.apply(this,arguments)))>.001){g=s<c^p?0:1;var z=d,I=d;if(f<At){var D=null==T?[w,k]:null==b?[y,x]:si([y,x],[T,A],[b,_],[w,k]),R=y-D[0],F=x-D[1],B=b-D[0],N=_-D[1],j=1/Math.sin(Math.acos((R*B+F*N)/(Math.sqrt(R*R+F*F)*Math.sqrt(B*B+N*N)))/2),U=Math.sqrt(D[0]*D[0]+D[1]*D[1]);I=Math.min(d,(s-U)/(j-1)),z=Math.min(d,(c-U)/(j+1))}if(null!=b){var V=No(null==T?[w,k]:[T,A],[y,x],c,z,p),q=No([b,_],[w,k],c,z,p);d===z?E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 0,\",g,\" \",V[1],\"A\",c,\",\",c,\" 0 \",1-p^Bo(V[1][0],V[1][1],q[1][0],q[1][1]),\",\",p,\" \",q[1],\"A\",z,\",\",z,\" 0 0,\",g,\" \",q[0]):E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 1,\",g,\" \",q[0])}else E.push(\"M\",y,\",\",x);if(null!=T){var H=No([y,x],[T,A],s,-I,p),G=No([w,k],null==b?[y,x]:[b,_],s,-I,p);d===I?E.push(\"L\",G[0],\"A\",I,\",\",I,\" 0 0,\",g,\" \",G[1],\"A\",s,\",\",s,\" 0 \",p^Bo(G[1][0],G[1][1],H[1][0],H[1][1]),\",\",1-p,\" \",H[1],\"A\",I,\",\",I,\" 0 0,\",g,\" \",H[0]):E.push(\"L\",G[0],\"A\",I,\",\",I,\" 0 0,\",g,\" \",H[0])}else E.push(\"L\",w,\",\",k)}else E.push(\"M\",y,\",\",x),null!=b&&E.push(\"A\",c,\",\",c,\" 0 \",C,\",\",p,\" \",b,\",\",_),E.push(\"L\",w,\",\",k),null!=T&&E.push(\"A\",s,\",\",s,\" 0 \",P,\",\",1-p,\" \",T,\",\",A);return E.push(\"Z\"),E.join(\"\")}function l(t,e){return\"M0,\"+t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+-t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+t}return s.innerRadius=function(e){return arguments.length?(t=ve(e),s):t},s.outerRadius=function(t){return arguments.length?(e=ve(t),s):e},s.cornerRadius=function(t){return arguments.length?(r=ve(t),s):r},s.padRadius=function(t){return arguments.length?(n=t==Oo?Oo:ve(t),s):n},s.startAngle=function(t){return arguments.length?(i=ve(t),s):i},s.endAngle=function(t){return arguments.length?(a=ve(t),s):a},s.padAngle=function(t){return arguments.length?(o=ve(t),s):o},s.centroid=function(){var r=(+t.apply(this,arguments)+ +e.apply(this,arguments))/2,n=(+i.apply(this,arguments)+ +a.apply(this,arguments))/2-Et;return[Math.cos(n)*r,Math.sin(n)*r]},s};var Oo=\"auto\";function zo(t){return t.innerRadius}function Io(t){return t.outerRadius}function Do(t){return t.startAngle}function Ro(t){return t.endAngle}function Fo(t){return t&&t.padAngle}function Bo(t,e,r,n){return(t-r)*e-(e-n)*t>0?0:1}function No(t,e,r,n,i){var a=t[0]-e[0],o=t[1]-e[1],s=(i?n:-n)/Math.sqrt(a*a+o*o),l=s*o,c=-s*a,u=t[0]+l,h=t[1]+c,f=e[0]+l,p=e[1]+c,d=(u+f)/2,g=(h+p)/2,v=f-u,m=p-h,y=v*v+m*m,x=r-n,b=u*p-f*h,_=(m<0?-1:1)*Math.sqrt(Math.max(0,x*x*y-b*b)),w=(b*m-v*_)/y,k=(-b*v-m*_)/y,T=(b*m+v*_)/y,A=(-b*v+m*_)/y,M=w-d,S=k-g,E=T-d,C=A-g;return M*M+S*S>E*E+C*C&&(w=T,k=A),[[w-l,k-c],[w*r/x,k*r/x]]}function jo(t){var e=ei,r=ri,n=Yr,i=Vo,a=i.key,o=.7;function s(a){var s,l=[],c=[],u=-1,h=a.length,f=ve(e),p=ve(r);function d(){l.push(\"M\",i(t(c),o))}for(;++u<h;)n.call(this,s=a[u],u)?c.push([+f.call(this,s,u),+p.call(this,s,u)]):c.length&&(d(),c=[]);return c.length&&d(),l.length?l.join(\"\"):null}return s.x=function(t){return arguments.length?(e=t,s):e},s.y=function(t){return arguments.length?(r=t,s):r},s.defined=function(t){return arguments.length?(n=t,s):n},s.interpolate=function(t){return arguments.length?(a=\"function\"==typeof t?i=t:(i=Uo.get(t)||Vo).key,s):a},s.tension=function(t){return arguments.length?(o=t,s):o},s}t.svg.line=function(){return jo(P)};var Uo=t.map({linear:Vo,\"linear-closed\":qo,step:function(t){var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];for(;++e<r;)i.push(\"H\",(n[0]+(n=t[e])[0])/2,\"V\",n[1]);r>1&&i.push(\"H\",n[0]);return i.join(\"\")},\"step-before\":Ho,\"step-after\":Go,basis:Xo,\"basis-open\":function(t){if(t.length<4)return Vo(t);var e,r=[],n=-1,i=t.length,a=[0],o=[0];for(;++n<3;)e=t[n],a.push(e[0]),o.push(e[1]);r.push(Zo($o,a)+\",\"+Zo($o,o)),--n;for(;++n<i;)e=t[n],a.shift(),a.push(e[0]),o.shift(),o.push(e[1]),Qo(r,a,o);return r.join(\"\")},\"basis-closed\":function(t){var e,r,n=-1,i=t.length,a=i+4,o=[],s=[];for(;++n<4;)r=t[n%i],o.push(r[0]),s.push(r[1]);e=[Zo($o,o),\",\",Zo($o,s)],--n;for(;++n<a;)r=t[n%i],o.shift(),o.push(r[0]),s.shift(),s.push(r[1]),Qo(e,o,s);return e.join(\"\")},bundle:function(t,e){var r=t.length-1;if(r)for(var n,i,a=t[0][0],o=t[0][1],s=t[r][0]-a,l=t[r][1]-o,c=-1;++c<=r;)n=t[c],i=c/r,n[0]=e*n[0]+(1-e)*(a+i*s),n[1]=e*n[1]+(1-e)*(o+i*l);return Xo(t)},cardinal:function(t,e){return t.length<3?Vo(t):t[0]+Yo(t,Wo(t,e))},\"cardinal-open\":function(t,e){return t.length<4?Vo(t):t[1]+Yo(t.slice(1,-1),Wo(t,e))},\"cardinal-closed\":function(t,e){return t.length<3?qo(t):t[0]+Yo((t.push(t[0]),t),Wo([t[t.length-2]].concat(t,[t[1]]),e))},monotone:function(t){return t.length<3?Vo(t):t[0]+Yo(t,function(t){var e,r,n,i,a=[],o=function(t){var e=0,r=t.length-1,n=[],i=t[0],a=t[1],o=n[0]=ts(i,a);for(;++e<r;)n[e]=(o+(o=ts(i=a,a=t[e+1])))/2;return n[e]=o,n}(t),s=-1,l=t.length-1;for(;++s<l;)e=ts(t[s],t[s+1]),y(e)<kt?o[s]=o[s+1]=0:(r=o[s]/e,n=o[s+1]/e,(i=r*r+n*n)>9&&(i=3*e/Math.sqrt(i),o[s]=i*r,o[s+1]=i*n));s=-1;for(;++s<=l;)i=(t[Math.min(l,s+1)][0]-t[Math.max(0,s-1)][0])/(6*(1+o[s]*o[s])),a.push([i||0,o[s]*i||0]);return a}(t))}});function Vo(t){return t.length>1?t.join(\"L\"):t+\"Z\"}function qo(t){return t.join(\"L\")+\"Z\"}function Ho(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"V\",(n=t[e])[1],\"H\",n[0]);return i.join(\"\")}function Go(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"H\",(n=t[e])[0],\"V\",n[1]);return i.join(\"\")}function Yo(t,e){if(e.length<1||t.length!=e.length&&t.length!=e.length+2)return Vo(t);var r=t.length!=e.length,n=\"\",i=t[0],a=t[1],o=e[0],s=o,l=1;if(r&&(n+=\"Q\"+(a[0]-2*o[0]/3)+\",\"+(a[1]-2*o[1]/3)+\",\"+a[0]+\",\"+a[1],i=t[1],l=2),e.length>1){s=e[1],a=t[l],l++,n+=\"C\"+(i[0]+o[0])+\",\"+(i[1]+o[1])+\",\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1];for(var c=2;c<e.length;c++,l++)a=t[l],s=e[c],n+=\"S\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1]}if(r){var u=t[l];n+=\"Q\"+(a[0]+2*s[0]/3)+\",\"+(a[1]+2*s[1]/3)+\",\"+u[0]+\",\"+u[1]}return n}function Wo(t,e){for(var r,n=[],i=(1-e)/2,a=t[0],o=t[1],s=1,l=t.length;++s<l;)r=a,a=o,o=t[s],n.push([i*(o[0]-r[0]),i*(o[1]-r[1])]);return n}function Xo(t){if(t.length<3)return Vo(t);var e=1,r=t.length,n=t[0],i=n[0],a=n[1],o=[i,i,i,(n=t[1])[0]],s=[a,a,a,n[1]],l=[i,\",\",a,\"L\",Zo($o,o),\",\",Zo($o,s)];for(t.push(t[r-1]);++e<=r;)n=t[e],o.shift(),o.push(n[0]),s.shift(),s.push(n[1]),Qo(l,o,s);return t.pop(),l.push(\"L\",n),l.join(\"\")}function Zo(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}Uo.forEach(function(t,e){e.key=t,e.closed=/-closed$/.test(t)});var Jo=[0,2/3,1/3,0],Ko=[0,1/3,2/3,0],$o=[0,1/6,2/3,1/6];function Qo(t,e,r){t.push(\"C\",Zo(Jo,e),\",\",Zo(Jo,r),\",\",Zo(Ko,e),\",\",Zo(Ko,r),\",\",Zo($o,e),\",\",Zo($o,r))}function ts(t,e){return(e[1]-t[1])/(e[0]-t[0])}function es(t){for(var e,r,n,i=-1,a=t.length;++i<a;)r=(e=t[i])[0],n=e[1]-Et,e[0]=r*Math.cos(n),e[1]=r*Math.sin(n);return t}function rs(t){var e=ei,r=ei,n=0,i=ri,a=Yr,o=Vo,s=o.key,l=o,c=\"L\",u=.7;function h(s){var h,f,p,d=[],g=[],v=[],m=-1,y=s.length,x=ve(e),b=ve(n),_=e===r?function(){return f}:ve(r),w=n===i?function(){return p}:ve(i);function k(){d.push(\"M\",o(t(v),u),c,l(t(g.reverse()),u),\"Z\")}for(;++m<y;)a.call(this,h=s[m],m)?(g.push([f=+x.call(this,h,m),p=+b.call(this,h,m)]),v.push([+_.call(this,h,m),+w.call(this,h,m)])):g.length&&(k(),g=[],v=[]);return g.length&&k(),d.length?d.join(\"\"):null}return h.x=function(t){return arguments.length?(e=r=t,h):r},h.x0=function(t){return arguments.length?(e=t,h):e},h.x1=function(t){return arguments.length?(r=t,h):r},h.y=function(t){return arguments.length?(n=i=t,h):i},h.y0=function(t){return arguments.length?(n=t,h):n},h.y1=function(t){return arguments.length?(i=t,h):i},h.defined=function(t){return arguments.length?(a=t,h):a},h.interpolate=function(t){return arguments.length?(s=\"function\"==typeof t?o=t:(o=Uo.get(t)||Vo).key,l=o.reverse||o,c=o.closed?\"M\":\"L\",h):s},h.tension=function(t){return arguments.length?(u=t,h):u},h}function ns(t){return t.radius}function is(t){return[t.x,t.y]}function as(){return 64}function os(){return\"circle\"}function ss(t){var e=Math.sqrt(t/At);return\"M0,\"+e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+-e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+e+\"Z\"}t.svg.line.radial=function(){var t=jo(es);return t.radius=t.x,delete t.x,t.angle=t.y,delete t.y,t},Ho.reverse=Go,Go.reverse=Ho,t.svg.area=function(){return rs(P)},t.svg.area.radial=function(){var t=rs(es);return t.radius=t.x,delete t.x,t.innerRadius=t.x0,delete t.x0,t.outerRadius=t.x1,delete t.x1,t.angle=t.y,delete t.y,t.startAngle=t.y0,delete t.y0,t.endAngle=t.y1,delete t.y1,t},t.svg.chord=function(){var t=Un,e=Vn,r=ns,n=Do,i=Ro;function a(r,n){var i,a,c=o(this,t,r,n),u=o(this,e,r,n);return\"M\"+c.p0+s(c.r,c.p1,c.a1-c.a0)+(a=u,(i=c).a0==a.a0&&i.a1==a.a1?l(c.r,c.p1,c.r,c.p0):l(c.r,c.p1,u.r,u.p0)+s(u.r,u.p1,u.a1-u.a0)+l(u.r,u.p1,c.r,c.p0))+\"Z\"}function o(t,e,a,o){var s=e.call(t,a,o),l=r.call(t,s,o),c=n.call(t,s,o)-Et,u=i.call(t,s,o)-Et;return{r:l,a0:c,a1:u,p0:[l*Math.cos(c),l*Math.sin(c)],p1:[l*Math.cos(u),l*Math.sin(u)]}}function s(t,e,r){return\"A\"+t+\",\"+t+\" 0 \"+ +(r>At)+\",1 \"+e}function l(t,e,r,n){return\"Q 0,0 \"+n}return a.radius=function(t){return arguments.length?(r=ve(t),a):r},a.source=function(e){return arguments.length?(t=ve(e),a):t},a.target=function(t){return arguments.length?(e=ve(t),a):e},a.startAngle=function(t){return arguments.length?(n=ve(t),a):n},a.endAngle=function(t){return arguments.length?(i=ve(t),a):i},a},t.svg.diagonal=function(){var t=Un,e=Vn,r=is;function n(n,i){var a=t.call(this,n,i),o=e.call(this,n,i),s=(a.y+o.y)/2,l=[a,{x:a.x,y:s},{x:o.x,y:s},o];return\"M\"+(l=l.map(r))[0]+\"C\"+l[1]+\" \"+l[2]+\" \"+l[3]}return n.source=function(e){return arguments.length?(t=ve(e),n):t},n.target=function(t){return arguments.length?(e=ve(t),n):e},n.projection=function(t){return arguments.length?(r=t,n):r},n},t.svg.diagonal.radial=function(){var e=t.svg.diagonal(),r=is,n=e.projection;return e.projection=function(t){return arguments.length?n(function(t){return function(){var e=t.apply(this,arguments),r=e[0],n=e[1]-Et;return[r*Math.cos(n),r*Math.sin(n)]}}(r=t)):r},e},t.svg.symbol=function(){var t=os,e=as;function r(r,n){return(ls.get(t.call(this,r,n))||ss)(e.call(this,r,n))}return r.type=function(e){return arguments.length?(t=ve(e),r):t},r.size=function(t){return arguments.length?(e=ve(t),r):e},r};var ls=t.map({circle:ss,cross:function(t){var e=Math.sqrt(t/5)/2;return\"M\"+-3*e+\",\"+-e+\"H\"+-e+\"V\"+-3*e+\"H\"+e+\"V\"+-e+\"H\"+3*e+\"V\"+e+\"H\"+e+\"V\"+3*e+\"H\"+-e+\"V\"+e+\"H\"+-3*e+\"Z\"},diamond:function(t){var e=Math.sqrt(t/(2*us)),r=e*us;return\"M0,\"+-e+\"L\"+r+\",0 0,\"+e+\" \"+-r+\",0Z\"},square:function(t){var e=Math.sqrt(t)/2;return\"M\"+-e+\",\"+-e+\"L\"+e+\",\"+-e+\" \"+e+\",\"+e+\" \"+-e+\",\"+e+\"Z\"},\"triangle-down\":function(t){var e=Math.sqrt(t/cs),r=e*cs/2;return\"M0,\"+r+\"L\"+e+\",\"+-r+\" \"+-e+\",\"+-r+\"Z\"},\"triangle-up\":function(t){var e=Math.sqrt(t/cs),r=e*cs/2;return\"M0,\"+-r+\"L\"+e+\",\"+r+\" \"+-e+\",\"+r+\"Z\"}});t.svg.symbolTypes=ls.keys();var cs=Math.sqrt(3),us=Math.tan(30*Ct);W.transition=function(t){for(var e,r,n=ds||++ms,i=bs(t),a=[],o=gs||{time:Date.now(),ease:ia,delay:0,duration:250},s=-1,l=this.length;++s<l;){a.push(e=[]);for(var c=this[s],u=-1,h=c.length;++u<h;)(r=c[u])&&_s(r,u,i,n,o),e.push(r)}return ps(a,i,n)},W.interrupt=function(t){return this.each(null==t?hs:fs(bs(t)))};var hs=fs(bs());function fs(t){return function(){var e,r,n;(e=this[t])&&(n=e[r=e.active])&&(n.timer.c=null,n.timer.t=NaN,--e.count?delete e[r]:delete this[t],e.active+=.5,n.event&&n.event.interrupt.call(this,this.__data__,n.index))}}function ps(t,e,r){return V(t,vs),t.namespace=e,t.id=r,t}var ds,gs,vs=[],ms=0;function ys(t,e,r,n){var i=t.id,a=t.namespace;return ut(t,\"function\"==typeof r?function(t,o,s){t[a][i].tween.set(e,n(r.call(t,t.__data__,o,s)))}:(r=n(r),function(t){t[a][i].tween.set(e,r)}))}function xs(t){return null==t&&(t=\"\"),function(){this.textContent=t}}function bs(t){return null==t?\"__transition__\":\"__transition_\"+t+\"__\"}function _s(t,e,r,n,i){var a,o,s,l,c,u=t[r]||(t[r]={active:0,count:0}),h=u[n];function f(r){var i=u.active,f=u[i];for(var d in f&&(f.timer.c=null,f.timer.t=NaN,--u.count,delete u[i],f.event&&f.event.interrupt.call(t,t.__data__,f.index)),u)if(+d<n){var g=u[d];g.timer.c=null,g.timer.t=NaN,--u.count,delete u[d]}o.c=p,Te(function(){return o.c&&p(r||1)&&(o.c=null,o.t=NaN),1},0,a),u.active=n,h.event&&h.event.start.call(t,t.__data__,e),c=[],h.tween.forEach(function(r,n){(n=n.call(t,t.__data__,e))&&c.push(n)}),l=h.ease,s=h.duration}function p(i){for(var a=i/s,o=l(a),f=c.length;f>0;)c[--f].call(t,o);if(a>=1)return h.event&&h.event.end.call(t,t.__data__,e),--u.count?delete u[n]:delete t[r],1}h||(a=i.time,o=Te(function(t){var e=h.delay;if(o.t=e+a,e<=t)return f(t-e);o.c=f},0,a),h=u[n]={tween:new b,time:a,timer:o,delay:i.delay,duration:i.duration,ease:i.ease,index:e},i=null,++u.count)}vs.call=W.call,vs.empty=W.empty,vs.node=W.node,vs.size=W.size,t.transition=function(e,r){return e&&e.transition?ds?e.transition(r):e:t.selection().transition(e)},t.transition.prototype=vs,vs.select=function(t){var e,r,n,i=this.id,a=this.namespace,o=[];t=X(t);for(var s=-1,l=this.length;++s<l;){o.push(e=[]);for(var c=this[s],u=-1,h=c.length;++u<h;)(n=c[u])&&(r=t.call(n,n.__data__,u,s))?(\"__data__\"in n&&(r.__data__=n.__data__),_s(r,u,a,i,n[a][i]),e.push(r)):e.push(null)}return ps(o,a,i)},vs.selectAll=function(t){var e,r,n,i,a,o=this.id,s=this.namespace,l=[];t=Z(t);for(var c=-1,u=this.length;++c<u;)for(var h=this[c],f=-1,p=h.length;++f<p;)if(n=h[f]){a=n[s][o],r=t.call(n,n.__data__,f,c),l.push(e=[]);for(var d=-1,g=r.length;++d<g;)(i=r[d])&&_s(i,d,s,o,a),e.push(i)}return ps(l,s,o)},vs.filter=function(t){var e,r,n=[];\"function\"!=typeof t&&(t=ct(t));for(var i=0,a=this.length;i<a;i++){n.push(e=[]);for(var o,s=0,l=(o=this[i]).length;s<l;s++)(r=o[s])&&t.call(r,r.__data__,s,i)&&e.push(r)}return ps(n,this.namespace,this.id)},vs.tween=function(t,e){var r=this.id,n=this.namespace;return arguments.length<2?this.node()[n][r].tween.get(t):ut(this,null==e?function(e){e[n][r].tween.remove(t)}:function(i){i[n][r].tween.set(t,e)})},vs.attr=function(e,r){if(arguments.length<2){for(r in e)this.attr(r,e[r]);return this}var n=\"transform\"==e?ga:Zi,i=t.ns.qualify(e);function a(){this.removeAttribute(i)}function o(){this.removeAttributeNS(i.space,i.local)}return ys(this,\"attr.\"+e,r,i.local?function(t){return null==t?o:(t+=\"\",function(){var e,r=this.getAttributeNS(i.space,i.local);return r!==t&&(e=n(r,t),function(t){this.setAttributeNS(i.space,i.local,e(t))})})}:function(t){return null==t?a:(t+=\"\",function(){var e,r=this.getAttribute(i);return r!==t&&(e=n(r,t),function(t){this.setAttribute(i,e(t))})})})},vs.attrTween=function(e,r){var n=t.ns.qualify(e);return this.tween(\"attr.\"+e,n.local?function(t,e){var i=r.call(this,t,e,this.getAttributeNS(n.space,n.local));return i&&function(t){this.setAttributeNS(n.space,n.local,i(t))}}:function(t,e){var i=r.call(this,t,e,this.getAttribute(n));return i&&function(t){this.setAttribute(n,i(t))}})},vs.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.style(r,t[r],e);return this}r=\"\"}function i(){this.style.removeProperty(t)}return ys(this,\"style.\"+t,e,function(e){return null==e?i:(e+=\"\",function(){var n,i=o(this).getComputedStyle(this,null).getPropertyValue(t);return i!==e&&(n=Zi(i,e),function(e){this.style.setProperty(t,n(e),r)})})})},vs.styleTween=function(t,e,r){return arguments.length<3&&(r=\"\"),this.tween(\"style.\"+t,function(n,i){var a=e.call(this,n,i,o(this).getComputedStyle(this,null).getPropertyValue(t));return a&&function(e){this.style.setProperty(t,a(e),r)}})},vs.text=function(t){return ys(this,\"text\",t,xs)},vs.remove=function(){var t=this.namespace;return this.each(\"end.transition\",function(){var e;this[t].count<2&&(e=this.parentNode)&&e.removeChild(this)})},vs.ease=function(e){var r=this.id,n=this.namespace;return arguments.length<1?this.node()[n][r].ease:(\"function\"!=typeof e&&(e=t.ease.apply(t,arguments)),ut(this,function(t){t[n][r].ease=e}))},vs.delay=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].delay:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].delay=+t.call(n,n.__data__,i,a)}:(t=+t,function(n){n[r][e].delay=t}))},vs.duration=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].duration:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].duration=Math.max(1,t.call(n,n.__data__,i,a))}:(t=Math.max(1,t),function(n){n[r][e].duration=t}))},vs.each=function(e,r){var n=this.id,i=this.namespace;if(arguments.length<2){var a=gs,o=ds;try{ds=n,ut(this,function(t,r,a){gs=t[i][n],e.call(t,t.__data__,r,a)})}finally{gs=a,ds=o}}else ut(this,function(a){var o=a[i][n];(o.event||(o.event=t.dispatch(\"start\",\"end\",\"interrupt\"))).on(e,r)});return this},vs.transition=function(){for(var t,e,r,n=this.id,i=++ms,a=this.namespace,o=[],s=0,l=this.length;s<l;s++){o.push(t=[]);for(var c,u=0,h=(c=this[s]).length;u<h;u++)(e=c[u])&&_s(e,u,a,i,{time:(r=e[a][n]).time,ease:r.ease,delay:r.delay+r.duration,duration:r.duration}),t.push(e)}return ps(o,a,i)},t.svg.axis=function(){var e,r=t.scale.linear(),i=ws,a=6,o=6,s=3,l=[10],c=null;function u(n){n.each(function(){var n,u=t.select(this),h=this.__chart__||r,f=this.__chart__=r.copy(),p=null==c?f.ticks?f.ticks.apply(f,l):f.domain():c,d=null==e?f.tickFormat?f.tickFormat.apply(f,l):P:e,g=u.selectAll(\".tick\").data(p,f),v=g.enter().insert(\"g\",\".domain\").attr(\"class\",\"tick\").style(\"opacity\",kt),m=t.transition(g.exit()).style(\"opacity\",kt).remove(),y=t.transition(g.order()).style(\"opacity\",1),x=Math.max(a,0)+s,b=uo(f),_=u.selectAll(\".domain\").data([0]),w=(_.enter().append(\"path\").attr(\"class\",\"domain\"),t.transition(_));v.append(\"line\"),v.append(\"text\");var k,T,A,M,S=v.select(\"line\"),E=y.select(\"line\"),C=g.select(\"text\").text(d),L=v.select(\"text\"),O=y.select(\"text\"),z=\"top\"===i||\"left\"===i?-1:1;if(\"bottom\"===i||\"top\"===i?(n=Ts,k=\"x\",A=\"y\",T=\"x2\",M=\"y2\",C.attr(\"dy\",z<0?\"0em\":\".71em\").style(\"text-anchor\",\"middle\"),w.attr(\"d\",\"M\"+b[0]+\",\"+z*o+\"V0H\"+b[1]+\"V\"+z*o)):(n=As,k=\"y\",A=\"x\",T=\"y2\",M=\"x2\",C.attr(\"dy\",\".32em\").style(\"text-anchor\",z<0?\"end\":\"start\"),w.attr(\"d\",\"M\"+z*o+\",\"+b[0]+\"H0V\"+b[1]+\"H\"+z*o)),S.attr(M,z*a),L.attr(A,z*x),E.attr(T,0).attr(M,z*a),O.attr(k,0).attr(A,z*x),f.rangeBand){var I=f,D=I.rangeBand()/2;h=f=function(t){return I(t)+D}}else h.rangeBand?h=f:m.call(n,f,h);v.call(n,h,f),y.call(n,f,f)})}return u.scale=function(t){return arguments.length?(r=t,u):r},u.orient=function(t){return arguments.length?(i=t in ks?t+\"\":ws,u):i},u.ticks=function(){return arguments.length?(l=n(arguments),u):l},u.tickValues=function(t){return arguments.length?(c=t,u):c},u.tickFormat=function(t){return arguments.length?(e=t,u):e},u.tickSize=function(t){var e=arguments.length;return e?(a=+t,o=+arguments[e-1],u):a},u.innerTickSize=function(t){return arguments.length?(a=+t,u):a},u.outerTickSize=function(t){return arguments.length?(o=+t,u):o},u.tickPadding=function(t){return arguments.length?(s=+t,u):s},u.tickSubdivide=function(){return arguments.length&&u},u};var ws=\"bottom\",ks={top:1,right:1,bottom:1,left:1};function Ts(t,e,r){t.attr(\"transform\",function(t){var n=e(t);return\"translate(\"+(isFinite(n)?n:r(t))+\",0)\"})}function As(t,e,r){t.attr(\"transform\",function(t){var n=e(t);return\"translate(0,\"+(isFinite(n)?n:r(t))+\")\"})}t.svg.brush=function(){var e,r,n=j(f,\"brushstart\",\"brush\",\"brushend\"),i=null,a=null,s=[0,0],l=[0,0],c=!0,u=!0,h=Ss[0];function f(e){e.each(function(){var e=t.select(this).style(\"pointer-events\",\"all\").style(\"-webkit-tap-highlight-color\",\"rgba(0,0,0,0)\").on(\"mousedown.brush\",v).on(\"touchstart.brush\",v),r=e.selectAll(\".background\").data([0]);r.enter().append(\"rect\").attr(\"class\",\"background\").style(\"visibility\",\"hidden\").style(\"cursor\",\"crosshair\"),e.selectAll(\".extent\").data([0]).enter().append(\"rect\").attr(\"class\",\"extent\").style(\"cursor\",\"move\");var n=e.selectAll(\".resize\").data(h,P);n.exit().remove(),n.enter().append(\"g\").attr(\"class\",function(t){return\"resize \"+t}).style(\"cursor\",function(t){return Ms[t]}).append(\"rect\").attr(\"x\",function(t){return/[ew]$/.test(t)?-3:null}).attr(\"y\",function(t){return/^[ns]/.test(t)?-3:null}).attr(\"width\",6).attr(\"height\",6).style(\"visibility\",\"hidden\"),n.style(\"display\",f.empty()?\"none\":null);var o,s=t.transition(e),l=t.transition(r);i&&(o=uo(i),l.attr(\"x\",o[0]).attr(\"width\",o[1]-o[0]),d(s)),a&&(o=uo(a),l.attr(\"y\",o[0]).attr(\"height\",o[1]-o[0]),g(s)),p(s)})}function p(t){t.selectAll(\".resize\").attr(\"transform\",function(t){return\"translate(\"+s[+/e$/.test(t)]+\",\"+l[+/^s/.test(t)]+\")\"})}function d(t){t.select(\".extent\").attr(\"x\",s[0]),t.selectAll(\".extent,.n>rect,.s>rect\").attr(\"width\",s[1]-s[0])}function g(t){t.select(\".extent\").attr(\"y\",l[0]),t.selectAll(\".extent,.e>rect,.w>rect\").attr(\"height\",l[1]-l[0])}function v(){var h,v,m=this,y=t.select(t.event.target),x=n.of(m,arguments),b=t.select(m),_=y.datum(),w=!/^(n|s)$/.test(_)&&i,k=!/^(e|w)$/.test(_)&&a,T=y.classed(\"extent\"),A=xt(m),M=t.mouse(m),S=t.select(o(m)).on(\"keydown.brush\",function(){32==t.event.keyCode&&(T||(h=null,M[0]-=s[1],M[1]-=l[1],T=2),B())}).on(\"keyup.brush\",function(){32==t.event.keyCode&&2==T&&(M[0]+=s[1],M[1]+=l[1],T=0,B())});if(t.event.changedTouches?S.on(\"touchmove.brush\",L).on(\"touchend.brush\",O):S.on(\"mousemove.brush\",L).on(\"mouseup.brush\",O),b.interrupt().selectAll(\"*\").interrupt(),T)M[0]=s[0]-M[0],M[1]=l[0]-M[1];else if(_){var E=+/w$/.test(_),C=+/^n/.test(_);v=[s[1-E]-M[0],l[1-C]-M[1]],M[0]=s[E],M[1]=l[C]}else t.event.altKey&&(h=M.slice());function L(){var e=t.mouse(m),r=!1;v&&(e[0]+=v[0],e[1]+=v[1]),T||(t.event.altKey?(h||(h=[(s[0]+s[1])/2,(l[0]+l[1])/2]),M[0]=s[+(e[0]<h[0])],M[1]=l[+(e[1]<h[1])]):h=null),w&&P(e,i,0)&&(d(b),r=!0),k&&P(e,a,1)&&(g(b),r=!0),r&&(p(b),x({type:\"brush\",mode:T?\"move\":\"resize\"}))}function P(t,n,i){var a,o,f=uo(n),p=f[0],d=f[1],g=M[i],v=i?l:s,m=v[1]-v[0];if(T&&(p-=g,d-=m+g),a=(i?u:c)?Math.max(p,Math.min(d,t[i])):t[i],T?o=(a+=g)+m:(h&&(g=Math.max(p,Math.min(d,2*h[i]-a))),g<a?(o=a,a=g):o=g),v[0]!=a||v[1]!=o)return i?r=null:e=null,v[0]=a,v[1]=o,!0}function O(){L(),b.style(\"pointer-events\",\"all\").selectAll(\".resize\").style(\"display\",f.empty()?\"none\":null),t.select(\"body\").style(\"cursor\",null),S.on(\"mousemove.brush\",null).on(\"mouseup.brush\",null).on(\"touchmove.brush\",null).on(\"touchend.brush\",null).on(\"keydown.brush\",null).on(\"keyup.brush\",null),A(),x({type:\"brushend\"})}b.style(\"pointer-events\",\"none\").selectAll(\".resize\").style(\"display\",null),t.select(\"body\").style(\"cursor\",y.style(\"cursor\")),x({type:\"brushstart\"}),L()}return f.event=function(i){i.each(function(){var i=n.of(this,arguments),a={x:s,y:l,i:e,j:r},o=this.__chart__||a;this.__chart__=a,ds?t.select(this).transition().each(\"start.brush\",function(){e=o.i,r=o.j,s=o.x,l=o.y,i({type:\"brushstart\"})}).tween(\"brush:brush\",function(){var t=Ji(s,a.x),n=Ji(l,a.y);return e=r=null,function(e){s=a.x=t(e),l=a.y=n(e),i({type:\"brush\",mode:\"resize\"})}}).each(\"end.brush\",function(){e=a.i,r=a.j,i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"})}):(i({type:\"brushstart\"}),i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"}))})},f.x=function(t){return arguments.length?(h=Ss[!(i=t)<<1|!a],f):i},f.y=function(t){return arguments.length?(h=Ss[!i<<1|!(a=t)],f):a},f.clamp=function(t){return arguments.length?(i&&a?(c=!!t[0],u=!!t[1]):i?c=!!t:a&&(u=!!t),f):i&&a?[c,u]:i?c:a?u:null},f.extent=function(t){var n,o,c,u,h;return arguments.length?(i&&(n=t[0],o=t[1],a&&(n=n[0],o=o[0]),e=[n,o],i.invert&&(n=i(n),o=i(o)),o<n&&(h=n,n=o,o=h),n==s[0]&&o==s[1]||(s=[n,o])),a&&(c=t[0],u=t[1],i&&(c=c[1],u=u[1]),r=[c,u],a.invert&&(c=a(c),u=a(u)),u<c&&(h=c,c=u,u=h),c==l[0]&&u==l[1]||(l=[c,u])),f):(i&&(e?(n=e[0],o=e[1]):(n=s[0],o=s[1],i.invert&&(n=i.invert(n),o=i.invert(o)),o<n&&(h=n,n=o,o=h))),a&&(r?(c=r[0],u=r[1]):(c=l[0],u=l[1],a.invert&&(c=a.invert(c),u=a.invert(u)),u<c&&(h=c,c=u,u=h))),i&&a?[[n,c],[o,u]]:i?[n,o]:a&&[c,u])},f.clear=function(){return f.empty()||(s=[0,0],l=[0,0],e=r=null),f},f.empty=function(){return!!i&&s[0]==s[1]||!!a&&l[0]==l[1]},t.rebind(f,n,\"on\")};var Ms={n:\"ns-resize\",e:\"ew-resize\",s:\"ns-resize\",w:\"ew-resize\",nw:\"nwse-resize\",ne:\"nesw-resize\",se:\"nwse-resize\",sw:\"nesw-resize\"},Ss=[[\"n\",\"e\",\"s\",\"w\",\"nw\",\"ne\",\"se\",\"sw\"],[\"e\",\"w\"],[\"n\",\"s\"],[]],Es=ze.format=sr.timeFormat,Cs=Es.utc,Ls=Cs(\"%Y-%m-%dT%H:%M:%S.%LZ\");function Ps(t){return t.toISOString()}function Os(e,r,n){function i(t){return e(t)}function a(e,n){var i=(e[1]-e[0])/n,a=t.bisect(Is,i);return a==Is.length?[r.year,xo(e.map(function(t){return t/31536e6}),n)[2]]:a?r[i/Is[a-1]<Is[a]/i?a-1:a]:[Fs,xo(e,n)[2]]}return i.invert=function(t){return zs(e.invert(t))},i.domain=function(t){return arguments.length?(e.domain(t),i):e.domain().map(zs)},i.nice=function(t,e){var r=i.domain(),n=co(r),o=null==t?a(n,10):\"number\"==typeof t&&a(n,t);function s(r){return!isNaN(r)&&!t.range(r,zs(+r+1),e).length}return o&&(t=o[0],e=o[1]),i.domain(fo(r,e>1?{floor:function(e){for(;s(e=t.floor(e));)e=zs(e-1);return e},ceil:function(e){for(;s(e=t.ceil(e));)e=zs(+e+1);return e}}:t))},i.ticks=function(t,e){var r=co(i.domain()),n=null==t?a(r,10):\"number\"==typeof t?a(r,t):!t.range&&[{range:t},e];return n&&(t=n[0],e=n[1]),t.range(r[0],zs(+r[1]+1),e<1?1:e)},i.tickFormat=function(){return n},i.copy=function(){return Os(e.copy(),r,n)},mo(i,e)}function zs(t){return new Date(t)}Es.iso=Date.prototype.toISOString&&+new Date(\"2000-01-01T00:00:00.000Z\")?Ps:Ls,Ps.parse=function(t){var e=new Date(t);return isNaN(e)?null:e},Ps.toString=Ls.toString,ze.second=Fe(function(t){return new Ie(1e3*Math.floor(t/1e3))},function(t,e){t.setTime(t.getTime()+1e3*Math.floor(e))},function(t){return t.getSeconds()}),ze.seconds=ze.second.range,ze.seconds.utc=ze.second.utc.range,ze.minute=Fe(function(t){return new Ie(6e4*Math.floor(t/6e4))},function(t,e){t.setTime(t.getTime()+6e4*Math.floor(e))},function(t){return t.getMinutes()}),ze.minutes=ze.minute.range,ze.minutes.utc=ze.minute.utc.range,ze.hour=Fe(function(t){var e=t.getTimezoneOffset()/60;return new Ie(36e5*(Math.floor(t/36e5-e)+e))},function(t,e){t.setTime(t.getTime()+36e5*Math.floor(e))},function(t){return t.getHours()}),ze.hours=ze.hour.range,ze.hours.utc=ze.hour.utc.range,ze.month=Fe(function(t){return(t=ze.day(t)).setDate(1),t},function(t,e){t.setMonth(t.getMonth()+e)},function(t){return t.getMonth()}),ze.months=ze.month.range,ze.months.utc=ze.month.utc.range;var Is=[1e3,5e3,15e3,3e4,6e4,3e5,9e5,18e5,36e5,108e5,216e5,432e5,864e5,1728e5,6048e5,2592e6,7776e6,31536e6],Ds=[[ze.second,1],[ze.second,5],[ze.second,15],[ze.second,30],[ze.minute,1],[ze.minute,5],[ze.minute,15],[ze.minute,30],[ze.hour,1],[ze.hour,3],[ze.hour,6],[ze.hour,12],[ze.day,1],[ze.day,2],[ze.week,1],[ze.month,1],[ze.month,3],[ze.year,1]],Rs=Es.multi([[\".%L\",function(t){return t.getMilliseconds()}],[\":%S\",function(t){return t.getSeconds()}],[\"%I:%M\",function(t){return t.getMinutes()}],[\"%I %p\",function(t){return t.getHours()}],[\"%a %d\",function(t){return t.getDay()&&1!=t.getDate()}],[\"%b %d\",function(t){return 1!=t.getDate()}],[\"%B\",function(t){return t.getMonth()}],[\"%Y\",Yr]]),Fs={range:function(e,r,n){return t.range(Math.ceil(e/n)*n,+r,n).map(zs)},floor:P,ceil:P};Ds.year=ze.year,ze.scale=function(){return Os(t.scale.linear(),Ds,Rs)};var Bs=Ds.map(function(t){return[t[0].utc,t[1]]}),Ns=Cs.multi([[\".%L\",function(t){return t.getUTCMilliseconds()}],[\":%S\",function(t){return t.getUTCSeconds()}],[\"%I:%M\",function(t){return t.getUTCMinutes()}],[\"%I %p\",function(t){return t.getUTCHours()}],[\"%a %d\",function(t){return t.getUTCDay()&&1!=t.getUTCDate()}],[\"%b %d\",function(t){return 1!=t.getUTCDate()}],[\"%B\",function(t){return t.getUTCMonth()}],[\"%Y\",Yr]]);function js(t){return JSON.parse(t.responseText)}function Us(t){var e=i.createRange();return e.selectNode(i.body),e.createContextualFragment(t.responseText)}Bs.year=ze.year.utc,ze.scale.utc=function(){return Os(t.scale.linear(),Bs,Ns)},t.text=me(function(t){return t.responseText}),t.json=function(t,e){return ye(t,\"application/json\",js,e)},t.html=function(t,e){return ye(t,\"text/html\",Us,e)},t.xml=me(function(t){return t.responseXML}),\"object\"==typeof e&&e.exports?e.exports=t:this.d3=t}()},{}],164:[function(t,e,r){e.exports=function(){for(var t=0;t<arguments.length;t++)if(void 0!==arguments[t])return arguments[t]}},{}],165:[function(t,e,r){\"use strict\";var n=t(\"incremental-convex-hull\"),i=t(\"uniq\");function a(t,e){this.point=t,this.index=e}function o(t,e){for(var r=t.point,n=e.point,i=r.length,a=0;a<i;++a){var o=n[a]-r[a];if(o)return o}return 0}e.exports=function(t,e){var r=t.length;if(0===r)return[];var s=t[0].length;if(s<1)return[];if(1===s)return function(t,e,r){if(1===t)return r?[[-1,0]]:[];var n=e.map(function(t,e){return[t[0],e]});n.sort(function(t,e){return t[0]-e[0]});for(var i=new Array(t-1),a=1;a<t;++a){var o=n[a-1],s=n[a];i[a-1]=[o[1],s[1]]}r&&i.push([-1,i[0][1]],[i[t-1][1],-1]);return i}(r,t,e);for(var l=new Array(r),c=1,u=0;u<r;++u){for(var h=t[u],f=new Array(s+1),p=0,d=0;d<s;++d){var g=h[d];f[d]=g,p+=g*g}f[s]=p,l[u]=new a(f,u),c=Math.max(p,c)}i(l,o),r=l.length;for(var v=new Array(r+s+1),m=new Array(r+s+1),y=(s+1)*(s+1)*c,x=new Array(s+1),u=0;u<=s;++u)x[u]=0;x[s]=y,v[0]=x.slice(),m[0]=-1;for(var u=0;u<=s;++u){var f=x.slice();f[u]=1,v[u+1]=f,m[u+1]=-1}for(var u=0;u<r;++u){var b=l[u];v[u+s+1]=b.point,m[u+s+1]=b.index}var _=n(v,!1);_=e?_.filter(function(t){for(var e=0,r=0;r<=s;++r){var n=m[t[r]];if(n<0&&++e>=2)return!1;t[r]=n}return!0}):_.filter(function(t){for(var e=0;e<=s;++e){var r=m[t[e]];if(r<0)return!1;t[e]=r}return!0});if(1&s)for(var u=0;u<_.length;++u){var b=_[u],f=b[0];b[0]=b[1],b[1]=f}return _}},{\"incremental-convex-hull\":413,uniq:547}],166:[function(t,e,r){\"use strict\";e.exports=a;var n=(a.canvas=document.createElement(\"canvas\")).getContext(\"2d\"),i=o([32,126]);function a(t,e){Array.isArray(t)&&(t=t.join(\", \"));var r,a={},s=16,l=.05;e&&(2===e.length&&\"number\"==typeof e[0]?r=o(e):Array.isArray(e)?r=e:(e.o?r=o(e.o):e.pairs&&(r=e.pairs),e.fontSize&&(s=e.fontSize),null!=e.threshold&&(l=e.threshold))),r||(r=i),n.font=s+\"px \"+t;for(var c=0;c<r.length;c++){var u=r[c],h=n.measureText(u[0]).width+n.measureText(u[1]).width,f=n.measureText(u).width;if(Math.abs(h-f)>s*l){var p=(f-h)/s;a[u]=1e3*p}}return a}function o(t){for(var e=[],r=t[0];r<=t[1];r++)for(var n=String.fromCharCode(r),i=t[0];i<t[1];i++){var a=n+String.fromCharCode(i);e.push(a)}return e}a.createPairs=o,a.ascii=i},{}],167:[function(t,e,r){(function(t){var r=!1;if(\"undefined\"!=typeof Float64Array){var n=new Float64Array(1),i=new Uint32Array(n.buffer);if(n[0]=1,r=!0,1072693248===i[1]){e.exports=function(t){return n[0]=t,[i[0],i[1]]},e.exports.pack=function(t,e){return i[0]=t,i[1]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[0]},e.exports.hi=function(t){return n[0]=t,i[1]}}else if(1072693248===i[0]){e.exports=function(t){return n[0]=t,[i[1],i[0]]},e.exports.pack=function(t,e){return i[1]=t,i[0]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[1]},e.exports.hi=function(t){return n[0]=t,i[0]}}else r=!1}if(!r){var a=new t(8);e.exports=function(t){return a.writeDoubleLE(t,0,!0),[a.readUInt32LE(0,!0),a.readUInt32LE(4,!0)]},e.exports.pack=function(t,e){return a.writeUInt32LE(t,0,!0),a.writeUInt32LE(e,4,!0),a.readDoubleLE(0,!0)},e.exports.lo=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(0,!0)},e.exports.hi=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(4,!0)}}e.exports.sign=function(t){return e.exports.hi(t)>>>31},e.exports.exponent=function(t){return(e.exports.hi(t)<<1>>>21)-1023},e.exports.fraction=function(t){var r=e.exports.lo(t),n=e.exports.hi(t),i=1048575&n;return 2146435072&n&&(i+=1<<20),[r,i]},e.exports.denormalized=function(t){return!(2146435072&e.exports.hi(t))}}).call(this,t(\"buffer\").Buffer)},{buffer:105}],168:[function(t,e,r){var n=t(\"abs-svg-path\"),i=t(\"normalize-svg-path\"),a={M:\"moveTo\",C:\"bezierCurveTo\"};e.exports=function(t,e){t.beginPath(),i(n(e)).forEach(function(e){var r=e[0],n=e.slice(1);t[a[r]].apply(t,n)}),t.closePath()}},{\"abs-svg-path\":60,\"normalize-svg-path\":452}],169:[function(t,e,r){e.exports=function(t){switch(t){case\"int8\":return Int8Array;case\"int16\":return Int16Array;case\"int32\":return Int32Array;case\"uint8\":return Uint8Array;case\"uint16\":return Uint16Array;case\"uint32\":return Uint32Array;case\"float32\":return Float32Array;case\"float64\":return Float64Array;case\"array\":return Array;case\"uint8_clamped\":return Uint8ClampedArray}}},{}],170:[function(t,e,r){\"use strict\";e.exports=function(t,e){switch(\"undefined\"==typeof e&&(e=0),typeof t){case\"number\":if(t>0)return function(t,e){var r,n;for(r=new Array(t),n=0;n<t;++n)r[n]=e;return r}(0|t,e);break;case\"object\":if(\"number\"==typeof t.length)return function t(e,r,n){var i=0|e[n];if(i<=0)return[];var a,o=new Array(i);if(n===e.length-1)for(a=0;a<i;++a)o[a]=r;else for(a=0;a<i;++a)o[a]=t(e,r,n+1);return o}(t,e,0)}return[]}},{}],171:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(\"number\"!=typeof e){e=0;for(var i=0;i<r;++i){var a=t[i];e=Math.max(e,a[0],a[1])}e=1+(0|e)}e|=0;for(var o=new Array(e),i=0;i<e;++i)o[i]=[];for(var i=0;i<r;++i){var a=t[i];o[a[0]].push(a[1]),o[a[1]].push(a[0])}for(var s=0;s<e;++s)n(o[s],function(t,e){return t-e});return o};var n=t(\"uniq\")},{uniq:547}],172:[function(t,e,r){var n=t(\"strongly-connected-components\");e.exports=function(t){var e,r=[],i=[],a=[],o={},s=[];function l(t){var r,n,u=!1;for(i.push(t),a[t]=!0,r=0;r<s[t].length;r++)(n=s[t][r])===e?(c(e,i),u=!0):a[n]||(u=l(n));if(u)!function t(e){a[e]=!1,o.hasOwnProperty(e)&&Object.keys(o[e]).forEach(function(r){delete o[e][r],a[r]&&t(r)})}(t);else for(r=0;r<s[t].length;r++){n=s[t][r];var h=o[n];h||(h={},o[n]=h),h[n]=!0}return i.pop(),u}function c(t,e){var n=[].concat(e).concat(t);r.push(n)}function u(e){!function(e){for(var r=0;r<t.length;r++)r<e&&(t[r]=[]),t[r]=t[r].filter(function(t){return t>=e})}(e);for(var r,i=n(t).components.filter(function(t){return t.length>1}),a=1/0,o=0;o<i.length;o++)for(var s=0;s<i[o].length;s++)i[o][s]<a&&(a=i[o][s],r=o);var l=i[r];return!!l&&{leastVertex:a,adjList:t.map(function(t,e){return-1===l.indexOf(e)?[]:t.filter(function(t){return-1!==l.indexOf(t)})})}}e=0;for(var h=t.length;e<h;){var f=u(e);if(e=f.leastVertex,s=f.adjList){for(var p=0;p<s.length;p++)for(var d=0;d<s[p].length;d++){var g=s[p][d];a[+g]=!1,o[g]={}}l(e),e+=1}else e=h}return r}},{\"strongly-connected-components\":530}],173:[function(t,e,r){\"use strict\";var n=t(\"../../object/valid-value\");e.exports=function(){return n(this).length=0,this}},{\"../../object/valid-value\":205}],174:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Array.from:t(\"./shim\")},{\"./is-implemented\":175,\"./shim\":176}],175:[function(t,e,r){\"use strict\";e.exports=function(){var t,e,r=Array.from;return\"function\"==typeof r&&(e=r(t=[\"raz\",\"dwa\"]),Boolean(e&&e!==t&&\"dwa\"===e[1]))}},{}],176:[function(t,e,r){\"use strict\";var n=t(\"es6-symbol\").iterator,i=t(\"../../function/is-arguments\"),a=t(\"../../function/is-function\"),o=t(\"../../number/to-pos-integer\"),s=t(\"../../object/valid-callable\"),l=t(\"../../object/valid-value\"),c=t(\"../../object/is-value\"),u=t(\"../../string/is-string\"),h=Array.isArray,f=Function.prototype.call,p={configurable:!0,enumerable:!0,writable:!0,value:null},d=Object.defineProperty;e.exports=function(t){var e,r,g,v,m,y,x,b,_,w,k=arguments[1],T=arguments[2];if(t=Object(l(t)),c(k)&&s(k),this&&this!==Array&&a(this))e=this;else{if(!k){if(i(t))return 1!==(m=t.length)?Array.apply(null,t):((v=new Array(1))[0]=t[0],v);if(h(t)){for(v=new Array(m=t.length),r=0;r<m;++r)v[r]=t[r];return v}}v=[]}if(!h(t))if(void 0!==(_=t[n])){for(x=s(_).call(t),e&&(v=new e),b=x.next(),r=0;!b.done;)w=k?f.call(k,T,b.value,r):b.value,e?(p.value=w,d(v,r,p)):v[r]=w,b=x.next(),++r;m=r}else if(u(t)){for(m=t.length,e&&(v=new e),r=0,g=0;r<m;++r)w=t[r],r+1<m&&(y=w.charCodeAt(0))>=55296&&y<=56319&&(w+=t[++r]),w=k?f.call(k,T,w,g):w,e?(p.value=w,d(v,g,p)):v[g]=w,++g;m=g}if(void 0===m)for(m=o(t.length),e&&(v=new e(m)),r=0;r<m;++r)w=k?f.call(k,T,t[r],r):t[r],e?(p.value=w,d(v,r,p)):v[r]=w;return e&&(p.value=null,v.length=m),v}},{\"../../function/is-arguments\":177,\"../../function/is-function\":178,\"../../number/to-pos-integer\":184,\"../../object/is-value\":194,\"../../object/valid-callable\":203,\"../../object/valid-value\":205,\"../../string/is-string\":209,\"es6-symbol\":219}],177:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(function(){return arguments}());e.exports=function(t){return n.call(t)===i}},{}],178:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(t(\"./noop\"));e.exports=function(t){return\"function\"==typeof t&&n.call(t)===i}},{\"./noop\":179}],179:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],180:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Math.sign:t(\"./shim\")},{\"./is-implemented\":181,\"./shim\":182}],181:[function(t,e,r){\"use strict\";e.exports=function(){var t=Math.sign;return\"function\"==typeof t&&(1===t(10)&&-1===t(-20))}},{}],182:[function(t,e,r){\"use strict\";e.exports=function(t){return t=Number(t),isNaN(t)||0===t?t:t>0?1:-1}},{}],183:[function(t,e,r){\"use strict\";var n=t(\"../math/sign\"),i=Math.abs,a=Math.floor;e.exports=function(t){return isNaN(t)?0:0!==(t=Number(t))&&isFinite(t)?n(t)*a(i(t)):t}},{\"../math/sign\":180}],184:[function(t,e,r){\"use strict\";var n=t(\"./to-integer\"),i=Math.max;e.exports=function(t){return i(0,n(t))}},{\"./to-integer\":183}],185:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./valid-value\"),a=Function.prototype.bind,o=Function.prototype.call,s=Object.keys,l=Object.prototype.propertyIsEnumerable;e.exports=function(t,e){return function(r,c){var u,h=arguments[2],f=arguments[3];return r=Object(i(r)),n(c),u=s(r),f&&u.sort(\"function\"==typeof f?a.call(f,r):void 0),\"function\"!=typeof t&&(t=u[t]),o.call(t,u,function(t,n){return l.call(r,t)?o.call(c,h,r[t],t,r,n):e})}}},{\"./valid-callable\":203,\"./valid-value\":205}],186:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.assign:t(\"./shim\")},{\"./is-implemented\":187,\"./shim\":188}],187:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=Object.assign;return\"function\"==typeof e&&(e(t={foo:\"raz\"},{bar:\"dwa\"},{trzy:\"trzy\"}),t.foo+t.bar+t.trzy===\"razdwatrzy\")}},{}],188:[function(t,e,r){\"use strict\";var n=t(\"../keys\"),i=t(\"../valid-value\"),a=Math.max;e.exports=function(t,e){var r,o,s,l=a(arguments.length,2);for(t=Object(i(t)),s=function(n){try{t[n]=e[n]}catch(t){r||(r=t)}},o=1;o<l;++o)e=arguments[o],n(e).forEach(s);if(void 0!==r)throw r;return t}},{\"../keys\":195,\"../valid-value\":205}],189:[function(t,e,r){\"use strict\";var n=t(\"../array/from\"),i=t(\"./assign\"),a=t(\"./valid-value\");e.exports=function(t){var e=Object(a(t)),r=arguments[1],o=Object(arguments[2]);if(e!==t&&!r)return e;var s={};return r?n(r,function(e){(o.ensure||e in t)&&(s[e]=t[e])}):i(s,t),s}},{\"../array/from\":174,\"./assign\":186,\"./valid-value\":205}],190:[function(t,e,r){\"use strict\";var n,i,a,o,s=Object.create;t(\"./set-prototype-of/is-implemented\")()||(n=t(\"./set-prototype-of/shim\")),e.exports=n?1!==n.level?s:(i={},a={},o={configurable:!1,enumerable:!1,writable:!0,value:void 0},Object.getOwnPropertyNames(Object.prototype).forEach(function(t){a[t]=\"__proto__\"!==t?o:{configurable:!0,enumerable:!1,writable:!0,value:void 0}}),Object.defineProperties(i,a),Object.defineProperty(n,\"nullPolyfill\",{configurable:!1,enumerable:!1,writable:!1,value:i}),function(t,e){return s(null===t?i:t,e)}):s},{\"./set-prototype-of/is-implemented\":201,\"./set-prototype-of/shim\":202}],191:[function(t,e,r){\"use strict\";e.exports=t(\"./_iterate\")(\"forEach\")},{\"./_iterate\":185}],192:[function(t,e,r){\"use strict\";e.exports=function(t){return\"function\"==typeof t}},{}],193:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i={function:!0,object:!0};e.exports=function(t){return n(t)&&i[typeof t]||!1}},{\"./is-value\":194}],194:[function(t,e,r){\"use strict\";var n=t(\"../function/noop\")();e.exports=function(t){return t!==n&&null!==t}},{\"../function/noop\":179}],195:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.keys:t(\"./shim\")},{\"./is-implemented\":196,\"./shim\":197}],196:[function(t,e,r){\"use strict\";e.exports=function(){try{return Object.keys(\"primitive\"),!0}catch(t){return!1}}},{}],197:[function(t,e,r){\"use strict\";var n=t(\"../is-value\"),i=Object.keys;e.exports=function(t){return i(n(t)?Object(t):t)}},{\"../is-value\":194}],198:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./for-each\"),a=Function.prototype.call;e.exports=function(t,e){var r={},o=arguments[2];return n(e),i(t,function(t,n,i,s){r[n]=a.call(e,o,t,n,i,s)}),r}},{\"./for-each\":191,\"./valid-callable\":203}],199:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i=Array.prototype.forEach,a=Object.create;e.exports=function(t){var e=a(null);return i.call(arguments,function(t){n(t)&&function(t,e){var r;for(r in t)e[r]=t[r]}(Object(t),e)}),e}},{\"./is-value\":194}],200:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.setPrototypeOf:t(\"./shim\")},{\"./is-implemented\":201,\"./shim\":202}],201:[function(t,e,r){\"use strict\";var n=Object.create,i=Object.getPrototypeOf,a={};e.exports=function(){var t=Object.setPrototypeOf,e=arguments[0]||n;return\"function\"==typeof t&&i(t(e(null),a))===a}},{}],202:[function(t,e,r){\"use strict\";var n,i,a,o,s=t(\"../is-object\"),l=t(\"../valid-value\"),c=Object.prototype.isPrototypeOf,u=Object.defineProperty,h={configurable:!0,enumerable:!1,writable:!0,value:void 0};n=function(t,e){if(l(t),null===e||s(e))return t;throw new TypeError(\"Prototype must be null or an object\")},e.exports=(i=function(){var t,e=Object.create(null),r={},n=Object.getOwnPropertyDescriptor(Object.prototype,\"__proto__\");if(n){try{(t=n.set).call(e,r)}catch(t){}if(Object.getPrototypeOf(e)===r)return{set:t,level:2}}return e.__proto__=r,Object.getPrototypeOf(e)===r?{level:2}:((e={}).__proto__=r,Object.getPrototypeOf(e)===r&&{level:1})}())?(2===i.level?i.set?(o=i.set,a=function(t,e){return o.call(n(t,e),e),t}):a=function(t,e){return n(t,e).__proto__=e,t}:a=function t(e,r){var i;return n(e,r),(i=c.call(t.nullPolyfill,e))&&delete t.nullPolyfill.__proto__,null===r&&(r=t.nullPolyfill),e.__proto__=r,i&&u(t.nullPolyfill,\"__proto__\",h),e},Object.defineProperty(a,\"level\",{configurable:!1,enumerable:!1,writable:!1,value:i.level})):null,t(\"../create\")},{\"../create\":190,\"../is-object\":193,\"../valid-value\":205}],203:[function(t,e,r){\"use strict\";e.exports=function(t){if(\"function\"!=typeof t)throw new TypeError(t+\" is not a function\");return t}},{}],204:[function(t,e,r){\"use strict\";var n=t(\"./is-object\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not an Object\");return t}},{\"./is-object\":193}],205:[function(t,e,r){\"use strict\";var n=t(\"./is-value\");e.exports=function(t){if(!n(t))throw new TypeError(\"Cannot use null or undefined\");return t}},{\"./is-value\":194}],206:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?String.prototype.contains:t(\"./shim\")},{\"./is-implemented\":207,\"./shim\":208}],207:[function(t,e,r){\"use strict\";var n=\"razdwatrzy\";e.exports=function(){return\"function\"==typeof n.contains&&(!0===n.contains(\"dwa\")&&!1===n.contains(\"foo\"))}},{}],208:[function(t,e,r){\"use strict\";var n=String.prototype.indexOf;e.exports=function(t){return n.call(this,t,arguments[1])>-1}},{}],209:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(\"\");e.exports=function(t){return\"string\"==typeof t||t&&\"object\"==typeof t&&(t instanceof String||n.call(t)===i)||!1}},{}],210:[function(t,e,r){\"use strict\";var n=Object.create(null),i=Math.random;e.exports=function(){var t;do{t=i().toString(36).slice(2)}while(n[t]);return t}},{}],211:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"es5-ext/string/#/contains\"),o=t(\"d\"),s=t(\"es6-symbol\"),l=t(\"./\"),c=Object.defineProperty;n=e.exports=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");l.call(this,t),e=e?a.call(e,\"key+value\")?\"key+value\":a.call(e,\"key\")?\"key\":\"value\":\"value\",c(this,\"__kind__\",o(\"\",e))},i&&i(n,l),delete n.prototype.constructor,n.prototype=Object.create(l.prototype,{_resolve:o(function(t){return\"value\"===this.__kind__?this.__list__[t]:\"key+value\"===this.__kind__?[t,this.__list__[t]]:t})}),c(n.prototype,s.toStringTag,o(\"c\",\"Array Iterator\"))},{\"./\":214,d:151,\"es5-ext/object/set-prototype-of\":200,\"es5-ext/string/#/contains\":206,\"es6-symbol\":219}],212:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/valid-callable\"),a=t(\"es5-ext/string/is-string\"),o=t(\"./get\"),s=Array.isArray,l=Function.prototype.call,c=Array.prototype.some;e.exports=function(t,e){var r,u,h,f,p,d,g,v,m=arguments[2];if(s(t)||n(t)?r=\"array\":a(t)?r=\"string\":t=o(t),i(e),h=function(){f=!0},\"array\"!==r)if(\"string\"!==r)for(u=t.next();!u.done;){if(l.call(e,m,u.value,h),f)return;u=t.next()}else for(d=t.length,p=0;p<d&&(g=t[p],p+1<d&&(v=g.charCodeAt(0))>=55296&&v<=56319&&(g+=t[++p]),l.call(e,m,g,h),!f);++p);else c.call(t,function(t){return l.call(e,m,t,h),f})}},{\"./get\":213,\"es5-ext/function/is-arguments\":177,\"es5-ext/object/valid-callable\":203,\"es5-ext/string/is-string\":209}],213:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/string/is-string\"),a=t(\"./array\"),o=t(\"./string\"),s=t(\"./valid-iterable\"),l=t(\"es6-symbol\").iterator;e.exports=function(t){return\"function\"==typeof s(t)[l]?t[l]():n(t)?new a(t):i(t)?new o(t):new a(t)}},{\"./array\":211,\"./string\":216,\"./valid-iterable\":217,\"es5-ext/function/is-arguments\":177,\"es5-ext/string/is-string\":209,\"es6-symbol\":219}],214:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/array/#/clear\"),a=t(\"es5-ext/object/assign\"),o=t(\"es5-ext/object/valid-callable\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"d\"),c=t(\"d/auto-bind\"),u=t(\"es6-symbol\"),h=Object.defineProperty,f=Object.defineProperties;e.exports=n=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");f(this,{__list__:l(\"w\",s(t)),__context__:l(\"w\",e),__nextIndex__:l(\"w\",0)}),e&&(o(e.on),e.on(\"_add\",this._onAdd),e.on(\"_delete\",this._onDelete),e.on(\"_clear\",this._onClear))},delete n.prototype.constructor,f(n.prototype,a({_next:l(function(){var t;if(this.__list__)return this.__redo__&&void 0!==(t=this.__redo__.shift())?t:this.__nextIndex__<this.__list__.length?this.__nextIndex__++:void this._unBind()}),next:l(function(){return this._createResult(this._next())}),_createResult:l(function(t){return void 0===t?{done:!0,value:void 0}:{done:!1,value:this._resolve(t)}}),_resolve:l(function(t){return this.__list__[t]}),_unBind:l(function(){this.__list__=null,delete this.__redo__,this.__context__&&(this.__context__.off(\"_add\",this._onAdd),this.__context__.off(\"_delete\",this._onDelete),this.__context__.off(\"_clear\",this._onClear),this.__context__=null)}),toString:l(function(){return\"[object \"+(this[u.toStringTag]||\"Object\")+\"]\"})},c({_onAdd:l(function(t){t>=this.__nextIndex__||(++this.__nextIndex__,this.__redo__?(this.__redo__.forEach(function(e,r){e>=t&&(this.__redo__[r]=++e)},this),this.__redo__.push(t)):h(this,\"__redo__\",l(\"c\",[t])))}),_onDelete:l(function(t){var e;t>=this.__nextIndex__||(--this.__nextIndex__,this.__redo__&&(-1!==(e=this.__redo__.indexOf(t))&&this.__redo__.splice(e,1),this.__redo__.forEach(function(e,r){e>t&&(this.__redo__[r]=--e)},this)))}),_onClear:l(function(){this.__redo__&&i.call(this.__redo__),this.__nextIndex__=0})}))),h(n.prototype,u.iterator,l(function(){return this}))},{d:151,\"d/auto-bind\":150,\"es5-ext/array/#/clear\":173,\"es5-ext/object/assign\":186,\"es5-ext/object/valid-callable\":203,\"es5-ext/object/valid-value\":205,\"es6-symbol\":219}],215:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/string/is-string\"),o=t(\"es6-symbol\").iterator,s=Array.isArray;e.exports=function(t){return!!i(t)&&(!!s(t)||(!!a(t)||(!!n(t)||\"function\"==typeof t[o])))}},{\"es5-ext/function/is-arguments\":177,\"es5-ext/object/is-value\":194,\"es5-ext/string/is-string\":209,\"es6-symbol\":219}],216:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"d\"),o=t(\"es6-symbol\"),s=t(\"./\"),l=Object.defineProperty;n=e.exports=function(t){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");t=String(t),s.call(this,t),l(this,\"__length__\",a(\"\",t.length))},i&&i(n,s),delete n.prototype.constructor,n.prototype=Object.create(s.prototype,{_next:a(function(){if(this.__list__)return this.__nextIndex__<this.__length__?this.__nextIndex__++:void this._unBind()}),_resolve:a(function(t){var e,r=this.__list__[t];return this.__nextIndex__===this.__length__?r:(e=r.charCodeAt(0))>=55296&&e<=56319?r+this.__list__[this.__nextIndex__++]:r})}),l(n.prototype,o.toStringTag,a(\"c\",\"String Iterator\"))},{\"./\":214,d:151,\"es5-ext/object/set-prototype-of\":200,\"es6-symbol\":219}],217:[function(t,e,r){\"use strict\";var n=t(\"./is-iterable\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not iterable\");return t}},{\"./is-iterable\":215}],218:[function(t,e,r){(function(n,i){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():t.ES6Promise=n()}(this,function(){\"use strict\";function e(t){return\"function\"==typeof t}var r=Array.isArray?Array.isArray:function(t){return\"[object Array]\"===Object.prototype.toString.call(t)},a=0,o=void 0,s=void 0,l=function(t,e){g[a]=t,g[a+1]=e,2===(a+=2)&&(s?s(v):_())};var c=\"undefined\"!=typeof window?window:void 0,u=c||{},h=u.MutationObserver||u.WebKitMutationObserver,f=\"undefined\"==typeof self&&\"undefined\"!=typeof n&&\"[object process]\"==={}.toString.call(n),p=\"undefined\"!=typeof Uint8ClampedArray&&\"undefined\"!=typeof importScripts&&\"undefined\"!=typeof MessageChannel;function d(){var t=setTimeout;return function(){return t(v,1)}}var g=new Array(1e3);function v(){for(var t=0;t<a;t+=2){(0,g[t])(g[t+1]),g[t]=void 0,g[t+1]=void 0}a=0}var m,y,x,b,_=void 0;function w(t,e){var r=arguments,n=this,i=new this.constructor(A);void 0===i[T]&&V(i);var a,o=n._state;return o?(a=r[o-1],l(function(){return j(o,i,a,n._result)})):R(n,i,t,e),i}function k(t){if(t&&\"object\"==typeof t&&t.constructor===this)return t;var e=new this(A);return O(e,t),e}f?_=function(){return n.nextTick(v)}:h?(y=0,x=new h(v),b=document.createTextNode(\"\"),x.observe(b,{characterData:!0}),_=function(){b.data=y=++y%2}):p?((m=new MessageChannel).port1.onmessage=v,_=function(){return m.port2.postMessage(0)}):_=void 0===c&&\"function\"==typeof t?function(){try{var e=t(\"vertx\");return o=e.runOnLoop||e.runOnContext,function(){o(v)}}catch(t){return d()}}():d();var T=Math.random().toString(36).substring(16);function A(){}var M=void 0,S=1,E=2,C=new B;function L(t){try{return t.then}catch(t){return C.error=t,C}}function P(t,r,n){r.constructor===t.constructor&&n===w&&r.constructor.resolve===k?function(t,e){e._state===S?I(t,e._result):e._state===E?D(t,e._result):R(e,void 0,function(e){return O(t,e)},function(e){return D(t,e)})}(t,r):n===C?D(t,C.error):void 0===n?I(t,r):e(n)?function(t,e,r){l(function(t){var n=!1,i=function(t,e,r,n){try{t.call(e,r,n)}catch(t){return t}}(r,e,function(r){n||(n=!0,e!==r?O(t,r):I(t,r))},function(e){n||(n=!0,D(t,e))},t._label);!n&&i&&(n=!0,D(t,i))},t)}(t,r,n):I(t,r)}function O(t,e){var r;t===e?D(t,new TypeError(\"You cannot resolve a promise with itself\")):\"function\"==typeof(r=e)||\"object\"==typeof r&&null!==r?P(t,e,L(e)):I(t,e)}function z(t){t._onerror&&t._onerror(t._result),F(t)}function I(t,e){t._state===M&&(t._result=e,t._state=S,0!==t._subscribers.length&&l(F,t))}function D(t,e){t._state===M&&(t._state=E,t._result=e,l(z,t))}function R(t,e,r,n){var i=t._subscribers,a=i.length;t._onerror=null,i[a]=e,i[a+S]=r,i[a+E]=n,0===a&&t._state&&l(F,t)}function F(t){var e=t._subscribers,r=t._state;if(0!==e.length){for(var n=void 0,i=void 0,a=t._result,o=0;o<e.length;o+=3)n=e[o],i=e[o+r],n?j(r,n,i,a):i(a);t._subscribers.length=0}}function B(){this.error=null}var N=new B;function j(t,r,n,i){var a=e(n),o=void 0,s=void 0,l=void 0,c=void 0;if(a){if((o=function(t,e){try{return t(e)}catch(t){return N.error=t,N}}(n,i))===N?(c=!0,s=o.error,o=null):l=!0,r===o)return void D(r,new TypeError(\"A promises callback cannot return that same promise.\"))}else o=i,l=!0;r._state!==M||(a&&l?O(r,o):c?D(r,s):t===S?I(r,o):t===E&&D(r,o))}var U=0;function V(t){t[T]=U++,t._state=void 0,t._result=void 0,t._subscribers=[]}function q(t,e){this._instanceConstructor=t,this.promise=new t(A),this.promise[T]||V(this.promise),r(e)?(this._input=e,this.length=e.length,this._remaining=e.length,this._result=new Array(this.length),0===this.length?I(this.promise,this._result):(this.length=this.length||0,this._enumerate(),0===this._remaining&&I(this.promise,this._result))):D(this.promise,new Error(\"Array Methods must be provided an Array\"))}function H(t){this[T]=U++,this._result=this._state=void 0,this._subscribers=[],A!==t&&(\"function\"!=typeof t&&function(){throw new TypeError(\"You must pass a resolver function as the first argument to the promise constructor\")}(),this instanceof H?function(t,e){try{e(function(e){O(t,e)},function(e){D(t,e)})}catch(e){D(t,e)}}(this,t):function(){throw new TypeError(\"Failed to construct 'Promise': Please use the 'new' operator, this object constructor cannot be called as a function.\")}())}function G(){var t=void 0;if(\"undefined\"!=typeof i)t=i;else if(\"undefined\"!=typeof self)t=self;else try{t=Function(\"return this\")()}catch(t){throw new Error(\"polyfill failed because global object is unavailable in this environment\")}var e=t.Promise;if(e){var r=null;try{r=Object.prototype.toString.call(e.resolve())}catch(t){}if(\"[object Promise]\"===r&&!e.cast)return}t.Promise=H}return q.prototype._enumerate=function(){for(var t=this.length,e=this._input,r=0;this._state===M&&r<t;r++)this._eachEntry(e[r],r)},q.prototype._eachEntry=function(t,e){var r=this._instanceConstructor,n=r.resolve;if(n===k){var i=L(t);if(i===w&&t._state!==M)this._settledAt(t._state,e,t._result);else if(\"function\"!=typeof i)this._remaining--,this._result[e]=t;else if(r===H){var a=new r(A);P(a,t,i),this._willSettleAt(a,e)}else this._willSettleAt(new r(function(e){return e(t)}),e)}else this._willSettleAt(n(t),e)},q.prototype._settledAt=function(t,e,r){var n=this.promise;n._state===M&&(this._remaining--,t===E?D(n,r):this._result[e]=r),0===this._remaining&&I(n,this._result)},q.prototype._willSettleAt=function(t,e){var r=this;R(t,void 0,function(t){return r._settledAt(S,e,t)},function(t){return r._settledAt(E,e,t)})},H.all=function(t){return new q(this,t).promise},H.race=function(t){var e=this;return r(t)?new e(function(r,n){for(var i=t.length,a=0;a<i;a++)e.resolve(t[a]).then(r,n)}):new e(function(t,e){return e(new TypeError(\"You must pass an array to race.\"))})},H.resolve=k,H.reject=function(t){var e=new this(A);return D(e,t),e},H._setScheduler=function(t){s=t},H._setAsap=function(t){l=t},H._asap=l,H.prototype={constructor:H,then:w,catch:function(t){return this.then(null,t)}},G(),H.polyfill=G,H.Promise=H,H})}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{_process:482}],219:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Symbol:t(\"./polyfill\")},{\"./is-implemented\":220,\"./polyfill\":222}],220:[function(t,e,r){\"use strict\";var n={object:!0,symbol:!0};e.exports=function(){var t;if(\"function\"!=typeof Symbol)return!1;t=Symbol(\"test symbol\");try{String(t)}catch(t){return!1}return!!n[typeof Symbol.iterator]&&(!!n[typeof Symbol.toPrimitive]&&!!n[typeof Symbol.toStringTag])}},{}],221:[function(t,e,r){\"use strict\";e.exports=function(t){return!!t&&(\"symbol\"==typeof t||!!t.constructor&&(\"Symbol\"===t.constructor.name&&\"Symbol\"===t[t.constructor.toStringTag]))}},{}],222:[function(t,e,r){\"use strict\";var n,i,a,o,s=t(\"d\"),l=t(\"./validate-symbol\"),c=Object.create,u=Object.defineProperties,h=Object.defineProperty,f=Object.prototype,p=c(null);if(\"function\"==typeof Symbol){n=Symbol;try{String(n()),o=!0}catch(t){}}var d,g=(d=c(null),function(t){for(var e,r,n=0;d[t+(n||\"\")];)++n;return d[t+=n||\"\"]=!0,h(f,e=\"@@\"+t,s.gs(null,function(t){r||(r=!0,h(this,e,s(t)),r=!1)})),e});a=function(t){if(this instanceof a)throw new TypeError(\"Symbol is not a constructor\");return i(t)},e.exports=i=function t(e){var r;if(this instanceof t)throw new TypeError(\"Symbol is not a constructor\");return o?n(e):(r=c(a.prototype),e=void 0===e?\"\":String(e),u(r,{__description__:s(\"\",e),__name__:s(\"\",g(e))}))},u(i,{for:s(function(t){return p[t]?p[t]:p[t]=i(String(t))}),keyFor:s(function(t){var e;for(e in l(t),p)if(p[e]===t)return e}),hasInstance:s(\"\",n&&n.hasInstance||i(\"hasInstance\")),isConcatSpreadable:s(\"\",n&&n.isConcatSpreadable||i(\"isConcatSpreadable\")),iterator:s(\"\",n&&n.iterator||i(\"iterator\")),match:s(\"\",n&&n.match||i(\"match\")),replace:s(\"\",n&&n.replace||i(\"replace\")),search:s(\"\",n&&n.search||i(\"search\")),species:s(\"\",n&&n.species||i(\"species\")),split:s(\"\",n&&n.split||i(\"split\")),toPrimitive:s(\"\",n&&n.toPrimitive||i(\"toPrimitive\")),toStringTag:s(\"\",n&&n.toStringTag||i(\"toStringTag\")),unscopables:s(\"\",n&&n.unscopables||i(\"unscopables\"))}),u(a.prototype,{constructor:s(i),toString:s(\"\",function(){return this.__name__})}),u(i.prototype,{toString:s(function(){return\"Symbol (\"+l(this).__description__+\")\"}),valueOf:s(function(){return l(this)})}),h(i.prototype,i.toPrimitive,s(\"\",function(){var t=l(this);return\"symbol\"==typeof t?t:t.toString()})),h(i.prototype,i.toStringTag,s(\"c\",\"Symbol\")),h(a.prototype,i.toStringTag,s(\"c\",i.prototype[i.toStringTag])),h(a.prototype,i.toPrimitive,s(\"c\",i.prototype[i.toPrimitive]))},{\"./validate-symbol\":223,d:151}],223:[function(t,e,r){\"use strict\";var n=t(\"./is-symbol\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not a symbol\");return t}},{\"./is-symbol\":221}],224:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=e||0,i=r||1;return[[t[12]+t[0],t[13]+t[1],t[14]+t[2],t[15]+t[3]],[t[12]-t[0],t[13]-t[1],t[14]-t[2],t[15]-t[3]],[t[12]+t[4],t[13]+t[5],t[14]+t[6],t[15]+t[7]],[t[12]-t[4],t[13]-t[5],t[14]-t[6],t[15]-t[7]],[n*t[12]+t[8],n*t[13]+t[9],n*t[14]+t[10],n*t[15]+t[11]],[i*t[12]-t[8],i*t[13]-t[9],i*t[14]-t[10],i*t[15]-t[11]]]}},{}],225:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\");e.exports=function(t){var e=typeof t;if(\"string\"===e){var r=t;if(0===(t=+t)&&n(r))return!1}else if(\"number\"!==e)return!1;return t-t<1}},{\"is-string-blank\":423}],226:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 0:return new o([0],[0],0);case 1:if(\"number\"==typeof t){var n=l(t);return new o(n,n,0)}return new o(t,l(t.length),0);case 2:if(\"number\"==typeof e){var n=l(t.length);return new o(t,n,+e)}r=0;case 3:if(t.length!==e.length)throw new Error(\"state and velocity lengths must match\");return new o(t,e,r)}};var n=t(\"cubic-hermite\"),i=t(\"binary-search-bounds\");function a(t,e,r){return Math.min(e,Math.max(t,r))}function o(t,e,r){this.dimension=t.length,this.bounds=[new Array(this.dimension),new Array(this.dimension)];for(var n=0;n<this.dimension;++n)this.bounds[0][n]=-1/0,this.bounds[1][n]=1/0;this._state=t.slice().reverse(),this._velocity=e.slice().reverse(),this._time=[r],this._scratch=[t.slice(),t.slice(),t.slice(),t.slice(),t.slice()]}var s=o.prototype;function l(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=0;return e}s.flush=function(t){var e=i.gt(this._time,t)-1;e<=0||(this._time.splice(0,e),this._state.splice(0,e*this.dimension),this._velocity.splice(0,e*this.dimension))},s.curve=function(t){var e=this._time,r=e.length,o=i.le(e,t),s=this._scratch[0],l=this._state,c=this._velocity,u=this.dimension,h=this.bounds;if(o<0)for(var f=u-1,p=0;p<u;++p,--f)s[p]=l[f];else if(o>=r-1){f=l.length-1;var d=t-e[r-1];for(p=0;p<u;++p,--f)s[p]=l[f]+d*c[f]}else{f=u*(o+1)-1;var g=e[o],v=e[o+1]-g||1,m=this._scratch[1],y=this._scratch[2],x=this._scratch[3],b=this._scratch[4],_=!0;for(p=0;p<u;++p,--f)m[p]=l[f],x[p]=c[f]*v,y[p]=l[f+u],b[p]=c[f+u]*v,_=_&&m[p]===y[p]&&x[p]===b[p]&&0===x[p];if(_)for(p=0;p<u;++p)s[p]=m[p];else n(m,x,y,b,(t-g)/v,s)}var w=h[0],k=h[1];for(p=0;p<u;++p)s[p]=a(w[p],k[p],s[p]);return s},s.dcurve=function(t){var e=this._time,r=e.length,a=i.le(e,t),o=this._scratch[0],s=this._state,l=this._velocity,c=this.dimension;if(a>=r-1)for(var u=s.length-1,h=(e[r-1],0);h<c;++h,--u)o[h]=l[u];else{u=c*(a+1)-1;var f=e[a],p=e[a+1]-f||1,d=this._scratch[1],g=this._scratch[2],v=this._scratch[3],m=this._scratch[4],y=!0;for(h=0;h<c;++h,--u)d[h]=s[u],v[h]=l[u]*p,g[h]=s[u+c],m[h]=l[u+c]*p,y=y&&d[h]===g[h]&&v[h]===m[h]&&0===v[h];if(y)for(h=0;h<c;++h)o[h]=0;else{n.derivative(d,v,g,m,(t-f)/p,o);for(h=0;h<c;++h)o[h]/=p}}return o},s.lastT=function(){var t=this._time;return t[t.length-1]},s.stable=function(){for(var t=this._velocity,e=t.length,r=this.dimension-1;r>=0;--r)if(t[--e])return!1;return!0},s.jump=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1];this._time.push(e,t);for(var u=0;u<2;++u)for(var h=0;h<r;++h)n.push(n[o++]),i.push(0);this._time.push(t);for(h=r;h>0;--h)n.push(a(l[h-1],c[h-1],arguments[h])),i.push(0)}},s.push=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=t-e,l=this.bounds,c=l[0],u=l[1],h=s>1e-6?1/s:0;this._time.push(t);for(var f=r;f>0;--f){var p=a(c[f-1],u[f-1],arguments[f]);n.push(p),i.push((p-n[o++])*h)}}},s.set=function(t){var e=this.dimension;if(!(t<this.lastT()||arguments.length!==e+1)){var r=this._state,n=this._velocity,i=this.bounds,o=i[0],s=i[1];this._time.push(t);for(var l=e;l>0;--l)r.push(a(o[l-1],s[l-1],arguments[l])),n.push(0)}},s.move=function(t){var e=this.lastT(),r=this.dimension;if(!(t<=e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1],u=t-e,h=u>1e-6?1/u:0;this._time.push(t);for(var f=r;f>0;--f){var p=arguments[f];n.push(a(l[f-1],c[f-1],n[o++]+p)),i.push(p*h)}}},s.idle=function(t){var e=this.lastT();if(!(t<e)){var r=this.dimension,n=this._state,i=this._velocity,o=n.length-r,s=this.bounds,l=s[0],c=s[1],u=t-e;this._time.push(t);for(var h=r-1;h>=0;--h)n.push(a(l[h],c[h],n[o]+u*i[o])),i.push(0),o+=1}}},{\"binary-search-bounds\":91,\"cubic-hermite\":145}],227:[function(t,e,r){var n=t(\"dtype\");e.exports=function(t,e,r){if(!t)throw new TypeError(\"must specify data as first parameter\");if(r=0|+(r||0),Array.isArray(t)&&t[0]&&\"number\"==typeof t[0][0]){var i,a,o,s,l=t[0].length,c=t.length*l;e&&\"string\"!=typeof e||(e=new(n(e||\"float32\"))(c+r));var u=e.length-r;if(c!==u)throw new Error(\"source length \"+c+\" (\"+l+\"x\"+t.length+\") does not match destination length \"+u);for(i=0,o=r;i<t.length;i++)for(a=0;a<l;a++)e[o++]=null===t[i][a]?NaN:t[i][a]}else if(e&&\"string\"!=typeof e)e.set(t,r);else{var h=n(e||\"float32\");if(Array.isArray(t)||\"array\"===e)for(e=new h(t.length+r),i=0,o=r,s=e.length;o<s;o++,i++)e[o]=null===t[i]?NaN:t[i];else 0===r?e=new h(t):(e=new h(t.length+r)).set(t,r)}return e}},{dtype:169}],228:[function(t,e,r){\"use strict\";var n=t(\"css-font/stringify\"),i=[32,126];e.exports=function(t){var e=(t=t||{}).shape?t.shape:t.canvas?[t.canvas.width,t.canvas.height]:[512,512],r=t.canvas||document.createElement(\"canvas\"),a=t.font,o=\"number\"==typeof t.step?[t.step,t.step]:t.step||[32,32],s=t.chars||i;a&&\"string\"!=typeof a&&(a=n(a));if(Array.isArray(s)){if(2===s.length&&\"number\"==typeof s[0]&&\"number\"==typeof s[1]){for(var l=[],c=s[0],u=0;c<=s[1];c++)l[u++]=String.fromCharCode(c);s=l}}else s=String(s).split(\"\");e=e.slice(),r.width=e[0],r.height=e[1];var h=r.getContext(\"2d\");h.fillStyle=\"#000\",h.fillRect(0,0,r.width,r.height),h.font=a,h.textAlign=\"center\",h.textBaseline=\"middle\",h.fillStyle=\"#fff\";for(var f=o[0]/2,p=o[1]/2,c=0;c<s.length;c++)h.fillText(s[c],f,p),(f+=o[0])>e[0]-o[0]/2&&(f=o[0]/2,p+=o[1]);return r}},{\"css-font/stringify\":142}],229:[function(t,e,r){\"use strict\";function n(t,e){e||(e={}),(\"string\"==typeof t||Array.isArray(t))&&(e.family=t);var r=Array.isArray(e.family)?e.family.join(\", \"):e.family;if(!r)throw Error(\"`family` must be defined\");var s=e.size||e.fontSize||e.em||48,l=e.weight||e.fontWeight||\"\",c=(t=[e.style||e.fontStyle||\"\",l,s].join(\" \")+\"px \"+r,e.origin||\"top\");if(n.cache[r]&&s<=n.cache[r].em)return i(n.cache[r],c);var u=e.canvas||n.canvas,h=u.getContext(\"2d\"),f={upper:void 0!==e.upper?e.upper:\"H\",lower:void 0!==e.lower?e.lower:\"x\",descent:void 0!==e.descent?e.descent:\"p\",ascent:void 0!==e.ascent?e.ascent:\"h\",tittle:void 0!==e.tittle?e.tittle:\"i\",overshoot:void 0!==e.overshoot?e.overshoot:\"O\"},p=Math.ceil(1.5*s);u.height=p,u.width=.5*p,h.font=t;var d={top:0};h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillStyle=\"black\",h.fillText(\"H\",0,0);var g=a(h.getImageData(0,0,p,p));h.clearRect(0,0,p,p),h.textBaseline=\"bottom\",h.fillText(\"H\",0,p);var v=a(h.getImageData(0,0,p,p));d.lineHeight=d.bottom=p-v+g,h.clearRect(0,0,p,p),h.textBaseline=\"alphabetic\",h.fillText(\"H\",0,p);var m=p-a(h.getImageData(0,0,p,p))-1+g;d.baseline=d.alphabetic=m,h.clearRect(0,0,p,p),h.textBaseline=\"middle\",h.fillText(\"H\",0,.5*p);var y=a(h.getImageData(0,0,p,p));d.median=d.middle=p-y-1+g-.5*p,h.clearRect(0,0,p,p),h.textBaseline=\"hanging\",h.fillText(\"H\",0,.5*p);var x=a(h.getImageData(0,0,p,p));d.hanging=p-x-1+g-.5*p,h.clearRect(0,0,p,p),h.textBaseline=\"ideographic\",h.fillText(\"H\",0,p);var b=a(h.getImageData(0,0,p,p));if(d.ideographic=p-b-1+g,f.upper&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.upper,0,0),d.upper=a(h.getImageData(0,0,p,p)),d.capHeight=d.baseline-d.upper),f.lower&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.lower,0,0),d.lower=a(h.getImageData(0,0,p,p)),d.xHeight=d.baseline-d.lower),f.tittle&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.tittle,0,0),d.tittle=a(h.getImageData(0,0,p,p))),f.ascent&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.ascent,0,0),d.ascent=a(h.getImageData(0,0,p,p))),f.descent&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.descent,0,0),d.descent=o(h.getImageData(0,0,p,p))),f.overshoot){h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.overshoot,0,0);var _=o(h.getImageData(0,0,p,p));d.overshoot=_-m}for(var w in d)d[w]/=s;return d.em=s,n.cache[r]=d,i(d,c)}function i(t,e){var r={};for(var n in\"string\"==typeof e&&(e=t[e]),t)\"em\"!==n&&(r[n]=t[n]-e);return r}function a(t){for(var e=t.height,r=t.data,n=3;n<r.length;n+=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}function o(t){for(var e=t.height,r=t.data,n=r.length-1;n>0;n-=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}e.exports=n,n.canvas=document.createElement(\"canvas\"),n.cache={}},{}],230:[function(t,e,r){\"use strict\";e.exports=function(t){return new c(t||d,null)};var n=0,i=1;function a(t,e,r,n,i,a){this._color=t,this.key=e,this.value=r,this.left=n,this.right=i,this._count=a}function o(t){return new a(t._color,t.key,t.value,t.left,t.right,t._count)}function s(t,e){return new a(t,e.key,e.value,e.left,e.right,e._count)}function l(t){t._count=1+(t.left?t.left._count:0)+(t.right?t.right._count:0)}function c(t,e){this._compare=t,this.root=e}var u=c.prototype;function h(t,e){this.tree=t,this._stack=e}Object.defineProperty(u,\"keys\",{get:function(){var t=[];return this.forEach(function(e,r){t.push(e)}),t}}),Object.defineProperty(u,\"values\",{get:function(){var t=[];return this.forEach(function(e,r){t.push(r)}),t}}),Object.defineProperty(u,\"length\",{get:function(){return this.root?this.root._count:0}}),u.insert=function(t,e){for(var r=this._compare,o=this.root,u=[],h=[];o;){var f=r(t,o.key);u.push(o),h.push(f),o=f<=0?o.left:o.right}u.push(new a(n,t,e,null,null,1));for(var p=u.length-2;p>=0;--p){o=u[p];h[p]<=0?u[p]=new a(o._color,o.key,o.value,u[p+1],o.right,o._count+1):u[p]=new a(o._color,o.key,o.value,o.left,u[p+1],o._count+1)}for(p=u.length-1;p>1;--p){var d=u[p-1];o=u[p];if(d._color===i||o._color===i)break;var g=u[p-2];if(g.left===d)if(d.left===o){if(!(v=g.right)||v._color!==n){if(g._color=n,g.left=d.right,d._color=i,d.right=g,u[p-2]=d,u[p-1]=o,l(g),l(d),p>=3)(m=u[p-3]).left===g?m.left=d:m.right=d;break}d._color=i,g.right=s(i,v),g._color=n,p-=1}else{if(!(v=g.right)||v._color!==n){if(d.right=o.left,g._color=n,g.left=o.right,o._color=i,o.left=d,o.right=g,u[p-2]=o,u[p-1]=d,l(g),l(d),l(o),p>=3)(m=u[p-3]).left===g?m.left=o:m.right=o;break}d._color=i,g.right=s(i,v),g._color=n,p-=1}else if(d.right===o){if(!(v=g.left)||v._color!==n){if(g._color=n,g.right=d.left,d._color=i,d.left=g,u[p-2]=d,u[p-1]=o,l(g),l(d),p>=3)(m=u[p-3]).right===g?m.right=d:m.left=d;break}d._color=i,g.left=s(i,v),g._color=n,p-=1}else{var v;if(!(v=g.left)||v._color!==n){var m;if(d.left=o.right,g._color=n,g.right=o.left,o._color=i,o.right=d,o.left=g,u[p-2]=o,u[p-1]=d,l(g),l(d),l(o),p>=3)(m=u[p-3]).right===g?m.right=o:m.left=o;break}d._color=i,g.left=s(i,v),g._color=n,p-=1}}return u[0]._color=i,new c(r,u[0])},u.forEach=function(t,e,r){if(this.root)switch(arguments.length){case 1:return function t(e,r){var n;if(r.left&&(n=t(e,r.left)))return n;return(n=e(r.key,r.value))||(r.right?t(e,r.right):void 0)}(t,this.root);case 2:return function t(e,r,n,i){if(r(e,i.key)<=0){var a;if(i.left&&(a=t(e,r,n,i.left)))return a;if(a=n(i.key,i.value))return a}if(i.right)return t(e,r,n,i.right)}(e,this._compare,t,this.root);case 3:if(this._compare(e,r)>=0)return;return function t(e,r,n,i,a){var o,s=n(e,a.key),l=n(r,a.key);if(s<=0){if(a.left&&(o=t(e,r,n,i,a.left)))return o;if(l>0&&(o=i(a.key,a.value)))return o}if(l>0&&a.right)return t(e,r,n,i,a.right)}(e,r,this._compare,t,this.root)}},Object.defineProperty(u,\"begin\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.left;return new h(this,t)}}),Object.defineProperty(u,\"end\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.right;return new h(this,t)}}),u.at=function(t){if(t<0)return new h(this,[]);for(var e=this.root,r=[];;){if(r.push(e),e.left){if(t<e.left._count){e=e.left;continue}t-=e.left._count}if(!t)return new h(this,r);if(t-=1,!e.right)break;if(t>=e.right._count)break;e=e.right}return new h(this,[])},u.ge=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<=0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},u.gt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},u.lt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},u.le=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>=0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},u.find=function(t){for(var e=this._compare,r=this.root,n=[];r;){var i=e(t,r.key);if(n.push(r),0===i)return new h(this,n);r=i<=0?r.left:r.right}return new h(this,[])},u.remove=function(t){var e=this.find(t);return e?e.remove():this},u.get=function(t){for(var e=this._compare,r=this.root;r;){var n=e(t,r.key);if(0===n)return r.value;r=n<=0?r.left:r.right}};var f=h.prototype;function p(t,e){t.key=e.key,t.value=e.value,t.left=e.left,t.right=e.right,t._color=e._color,t._count=e._count}function d(t,e){return t<e?-1:t>e?1:0}Object.defineProperty(f,\"valid\",{get:function(){return this._stack.length>0}}),Object.defineProperty(f,\"node\",{get:function(){return this._stack.length>0?this._stack[this._stack.length-1]:null},enumerable:!0}),f.clone=function(){return new h(this.tree,this._stack.slice())},f.remove=function(){var t=this._stack;if(0===t.length)return this.tree;var e=new Array(t.length),r=t[t.length-1];e[e.length-1]=new a(r._color,r.key,r.value,r.left,r.right,r._count);for(var u=t.length-2;u>=0;--u){(r=t[u]).left===t[u+1]?e[u]=new a(r._color,r.key,r.value,e[u+1],r.right,r._count):e[u]=new a(r._color,r.key,r.value,r.left,e[u+1],r._count)}if((r=e[e.length-1]).left&&r.right){var h=e.length;for(r=r.left;r.right;)e.push(r),r=r.right;var f=e[h-1];e.push(new a(r._color,f.key,f.value,r.left,r.right,r._count)),e[h-1].key=r.key,e[h-1].value=r.value;for(u=e.length-2;u>=h;--u)r=e[u],e[u]=new a(r._color,r.key,r.value,r.left,e[u+1],r._count);e[h-1].left=e[h]}if((r=e[e.length-1])._color===n){var d=e[e.length-2];d.left===r?d.left=null:d.right===r&&(d.right=null),e.pop();for(u=0;u<e.length;++u)e[u]._count--;return new c(this.tree._compare,e[0])}if(r.left||r.right){r.left?p(r,r.left):r.right&&p(r,r.right),r._color=i;for(u=0;u<e.length-1;++u)e[u]._count--;return new c(this.tree._compare,e[0])}if(1===e.length)return new c(this.tree._compare,null);for(u=0;u<e.length;++u)e[u]._count--;var g=e[e.length-2];return function(t){for(var e,r,a,c,u=t.length-1;u>=0;--u){if(e=t[u],0===u)return void(e._color=i);if((r=t[u-1]).left===e){if((a=r.right).right&&a.right._color===n)return c=(a=r.right=o(a)).right=o(a.right),r.right=a.left,a.left=r,a.right=c,a._color=r._color,e._color=i,r._color=i,c._color=i,l(r),l(a),u>1&&((h=t[u-2]).left===r?h.left=a:h.right=a),void(t[u-1]=a);if(a.left&&a.left._color===n)return c=(a=r.right=o(a)).left=o(a.left),r.right=c.left,a.left=c.right,c.left=r,c.right=a,c._color=r._color,r._color=i,a._color=i,e._color=i,l(r),l(a),l(c),u>1&&((h=t[u-2]).left===r?h.left=c:h.right=c),void(t[u-1]=c);if(a._color===i){if(r._color===n)return r._color=i,void(r.right=s(n,a));r.right=s(n,a);continue}a=o(a),r.right=a.left,a.left=r,a._color=r._color,r._color=n,l(r),l(a),u>1&&((h=t[u-2]).left===r?h.left=a:h.right=a),t[u-1]=a,t[u]=r,u+1<t.length?t[u+1]=e:t.push(e),u+=2}else{if((a=r.left).left&&a.left._color===n)return c=(a=r.left=o(a)).left=o(a.left),r.left=a.right,a.right=r,a.left=c,a._color=r._color,e._color=i,r._color=i,c._color=i,l(r),l(a),u>1&&((h=t[u-2]).right===r?h.right=a:h.left=a),void(t[u-1]=a);if(a.right&&a.right._color===n)return c=(a=r.left=o(a)).right=o(a.right),r.left=c.right,a.right=c.left,c.right=r,c.left=a,c._color=r._color,r._color=i,a._color=i,e._color=i,l(r),l(a),l(c),u>1&&((h=t[u-2]).right===r?h.right=c:h.left=c),void(t[u-1]=c);if(a._color===i){if(r._color===n)return r._color=i,void(r.left=s(n,a));r.left=s(n,a);continue}var h;a=o(a),r.left=a.right,a.right=r,a._color=r._color,r._color=n,l(r),l(a),u>1&&((h=t[u-2]).right===r?h.right=a:h.left=a),t[u-1]=a,t[u]=r,u+1<t.length?t[u+1]=e:t.push(e),u+=2}}}(e),g.left===r?g.left=null:g.right=null,new c(this.tree._compare,e[0])},Object.defineProperty(f,\"key\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].key},enumerable:!0}),Object.defineProperty(f,\"value\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].value},enumerable:!0}),Object.defineProperty(f,\"index\",{get:function(){var t=0,e=this._stack;if(0===e.length){var r=this.tree.root;return r?r._count:0}e[e.length-1].left&&(t=e[e.length-1].left._count);for(var n=e.length-2;n>=0;--n)e[n+1]===e[n].right&&(++t,e[n].left&&(t+=e[n].left._count));return t},enumerable:!0}),f.next=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.right)for(e=e.right;e;)t.push(e),e=e.left;else for(t.pop();t.length>0&&t[t.length-1].right===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(f,\"hasNext\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].right)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].left===t[e])return!0;return!1}}),f.update=function(t){var e=this._stack;if(0===e.length)throw new Error(\"Can't update empty node!\");var r=new Array(e.length),n=e[e.length-1];r[r.length-1]=new a(n._color,n.key,t,n.left,n.right,n._count);for(var i=e.length-2;i>=0;--i)(n=e[i]).left===e[i+1]?r[i]=new a(n._color,n.key,n.value,r[i+1],n.right,n._count):r[i]=new a(n._color,n.key,n.value,n.left,r[i+1],n._count);return new c(this.tree._compare,r[0])},f.prev=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.left)for(e=e.left;e;)t.push(e),e=e.right;else for(t.pop();t.length>0&&t[t.length-1].left===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(f,\"hasPrev\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].left)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].right===t[e])return!0;return!1}})},{}],231:[function(t,e,r){var n=[.9999999999998099,676.5203681218851,-1259.1392167224028,771.3234287776531,-176.6150291621406,12.507343278686905,-.13857109526572012,9984369578019572e-21,1.5056327351493116e-7],i=607/128,a=[.9999999999999971,57.15623566586292,-59.59796035547549,14.136097974741746,-.4919138160976202,3399464998481189e-20,4652362892704858e-20,-9837447530487956e-20,.0001580887032249125,-.00021026444172410488,.00021743961811521265,-.0001643181065367639,8441822398385275e-20,-26190838401581408e-21,36899182659531625e-22];function o(t){if(t<0)return Number(\"0/0\");for(var e=a[0],r=a.length-1;r>0;--r)e+=a[r]/(t+r);var n=t+i+.5;return.5*Math.log(2*Math.PI)+(t+.5)*Math.log(n)-n+Math.log(e)-Math.log(t)}e.exports=function t(e){if(e<.5)return Math.PI/(Math.sin(Math.PI*e)*t(1-e));if(e>100)return Math.exp(o(e));e-=1;for(var r=n[0],i=1;i<9;i++)r+=n[i]/(e+i);var a=e+7+.5;return Math.sqrt(2*Math.PI)*Math.pow(a,e+.5)*Math.exp(-a)*r},e.exports.log=o},{}],232:[function(t,e,r){e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"must specify type string\");if(e=e||{},\"undefined\"==typeof document&&!e.canvas)return null;var r=e.canvas||document.createElement(\"canvas\");\"number\"==typeof e.width&&(r.width=e.width);\"number\"==typeof e.height&&(r.height=e.height);var n,i=e;try{var a=[t];0===t.indexOf(\"webgl\")&&a.push(\"experimental-\"+t);for(var o=0;o<a.length;o++)if(n=r.getContext(a[o],i))return n}catch(t){n=null}return n||null}},{}],233:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=new u(t);return r.update(e),r};var n=t(\"./lib/text.js\"),i=t(\"./lib/lines.js\"),a=t(\"./lib/background.js\"),o=t(\"./lib/cube.js\"),s=t(\"./lib/ticks.js\"),l=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]);function c(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function u(t){this.gl=t,this.pixelRatio=1,this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.autoTicks=!0,this.tickSpacing=[1,1,1],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickAlign=[\"auto\",\"auto\",\"auto\"],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[10,10,10],this.lastCubeProps={cubeEdges:[0,0,0],axis:[0,0,0]},this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=\"sans-serif\",this.labelSize=[20,20,20],this.labelAngle=[0,0,0],this.labelAlign=[\"auto\",\"auto\",\"auto\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[10,10,10],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[0,0,0],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!1,!1,!1],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._firstInit=!0,this._text=null,this._lines=null,this._background=a(t)}var h=u.prototype;function f(){this.primalOffset=[0,0,0],this.primalMinor=[0,0,0],this.mirrorOffset=[0,0,0],this.mirrorMinor=[0,0,0]}h.update=function(t){function e(e,r,n){if(n in t){var i,a=t[n],o=this[n];(e?Array.isArray(a)&&Array.isArray(a[0]):Array.isArray(a))?this[n]=i=[r(a[0]),r(a[1]),r(a[2])]:this[n]=i=[r(a),r(a),r(a)];for(var s=0;s<3;++s)if(i[s]!==o[s])return!0}return!1}t=t||{};var r,a=e.bind(this,!1,Number),o=e.bind(this,!1,Boolean),l=e.bind(this,!1,String),c=e.bind(this,!0,function(t){if(Array.isArray(t)){if(3===t.length)return[+t[0],+t[1],+t[2],1];if(4===t.length)return[+t[0],+t[1],+t[2],+t[3]]}return[0,0,0,1]}),u=!1,h=!1;if(\"bounds\"in t)for(var f=t.bounds,p=0;p<2;++p)for(var d=0;d<3;++d)f[p][d]!==this.bounds[p][d]&&(h=!0),this.bounds[p][d]=f[p][d];if(\"ticks\"in t){r=t.ticks,u=!0,this.autoTicks=!1;for(p=0;p<3;++p)this.tickSpacing[p]=0}else a(\"tickSpacing\")&&(this.autoTicks=!0,h=!0);if(this._firstInit&&(\"ticks\"in t||\"tickSpacing\"in t||(this.autoTicks=!0),h=!0,u=!0,this._firstInit=!1),h&&this.autoTicks&&(r=s.create(this.bounds,this.tickSpacing),u=!0),u){for(p=0;p<3;++p)r[p].sort(function(t,e){return t.x-e.x});s.equal(r,this.ticks)?u=!1:this.ticks=r}o(\"tickEnable\"),l(\"tickFont\")&&(u=!0),a(\"tickSize\"),a(\"tickAngle\"),a(\"tickPad\"),c(\"tickColor\");var g=l(\"labels\");l(\"labelFont\")&&(g=!0),o(\"labelEnable\"),a(\"labelSize\"),a(\"labelPad\"),c(\"labelColor\"),o(\"lineEnable\"),o(\"lineMirror\"),a(\"lineWidth\"),c(\"lineColor\"),o(\"lineTickEnable\"),o(\"lineTickMirror\"),a(\"lineTickLength\"),a(\"lineTickWidth\"),c(\"lineTickColor\"),o(\"gridEnable\"),a(\"gridWidth\"),c(\"gridColor\"),o(\"zeroEnable\"),c(\"zeroLineColor\"),a(\"zeroLineWidth\"),o(\"backgroundEnable\"),c(\"backgroundColor\"),this._text?this._text&&(g||u)&&this._text.update(this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont):this._text=n(this.gl,this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont),this._lines&&u&&(this._lines.dispose(),this._lines=null),this._lines||(this._lines=i(this.gl,this.bounds,this.ticks))};var p=[new f,new f,new f];function d(t,e,r,n,i){for(var a=t.primalOffset,o=t.primalMinor,s=t.mirrorOffset,l=t.mirrorMinor,c=n[e],u=0;u<3;++u)if(e!==u){var h=a,f=s,p=o,d=l;c&1<<u&&(h=s,f=a,p=l,d=o),h[u]=r[0][u],f[u]=r[1][u],i[u]>0?(p[u]=-1,d[u]=0):(p[u]=0,d[u]=1)}}var g=[0,0,0],v={model:l,view:l,projection:l,_ortho:!1};h.isOpaque=function(){return!0},h.isTransparent=function(){return!1},h.drawTransparent=function(t){};var m=[0,0,0],y=[0,0,0],x=[0,0,0];h.draw=function(t){t=t||v;for(var e=this.gl,r=t.model||l,n=t.view||l,i=t.projection||l,a=this.bounds,s=t._ortho||!1,u=o(r,n,i,a,s),h=u.cubeEdges,f=u.axis,b=n[12],_=n[13],w=n[14],k=n[15],T=(s?2:1)*this.pixelRatio*(i[3]*b+i[7]*_+i[11]*w+i[15]*k)/e.drawingBufferHeight,A=0;A<3;++A)this.lastCubeProps.cubeEdges[A]=h[A],this.lastCubeProps.axis[A]=f[A];var M=p;for(A=0;A<3;++A)d(p[A],A,this.bounds,h,f);e=this.gl;var S,E=g;for(A=0;A<3;++A)this.backgroundEnable[A]?E[A]=f[A]:E[A]=0;this._background.draw(r,n,i,a,E,this.backgroundColor),this._lines.bind(r,n,i,this);for(A=0;A<3;++A){var C=[0,0,0];f[A]>0?C[A]=a[1][A]:C[A]=a[0][A];for(var L=0;L<2;++L){var P=(A+1+L)%3,O=(A+1+(1^L))%3;this.gridEnable[P]&&this._lines.drawGrid(P,O,this.bounds,C,this.gridColor[P],this.gridWidth[P]*this.pixelRatio)}for(L=0;L<2;++L){P=(A+1+L)%3,O=(A+1+(1^L))%3;this.zeroEnable[O]&&Math.min(a[0][O],a[1][O])<=0&&Math.max(a[0][O],a[1][O])>=0&&this._lines.drawZero(P,O,this.bounds,C,this.zeroLineColor[O],this.zeroLineWidth[O]*this.pixelRatio)}}for(A=0;A<3;++A){this.lineEnable[A]&&this._lines.drawAxisLine(A,this.bounds,M[A].primalOffset,this.lineColor[A],this.lineWidth[A]*this.pixelRatio),this.lineMirror[A]&&this._lines.drawAxisLine(A,this.bounds,M[A].mirrorOffset,this.lineColor[A],this.lineWidth[A]*this.pixelRatio);var z=c(m,M[A].primalMinor),I=c(y,M[A].mirrorMinor),D=this.lineTickLength;for(L=0;L<3;++L){var R=T/r[5*L];z[L]*=D[L]*R,I[L]*=D[L]*R}this.lineTickEnable[A]&&this._lines.drawAxisTicks(A,M[A].primalOffset,z,this.lineTickColor[A],this.lineTickWidth[A]*this.pixelRatio),this.lineTickMirror[A]&&this._lines.drawAxisTicks(A,M[A].mirrorOffset,I,this.lineTickColor[A],this.lineTickWidth[A]*this.pixelRatio)}this._lines.unbind(),this._text.bind(r,n,i,this.pixelRatio);var F,B;function N(t){(B=[0,0,0])[t]=1}function j(t,e,r){var n=(t+1)%3,i=(t+2)%3,a=e[n],o=e[i],s=r[n],l=r[i];a>0&&l>0?N(n):a>0&&l<0?N(n):a<0&&l>0?N(n):a<0&&l<0?N(n):o>0&&s>0?N(i):o>0&&s<0?N(i):o<0&&s>0?N(i):o<0&&s<0&&N(i)}for(A=0;A<3;++A){var U=M[A].primalMinor,V=M[A].mirrorMinor,q=c(x,M[A].primalOffset);for(L=0;L<3;++L)this.lineTickEnable[A]&&(q[L]+=T*U[L]*Math.max(this.lineTickLength[L],0)/r[5*L]);var H=[0,0,0];if(H[A]=1,this.tickEnable[A]){-3600===this.tickAngle[A]?(this.tickAngle[A]=0,this.tickAlign[A]=\"auto\"):this.tickAlign[A]=-1,F=1,\"auto\"===(S=[this.tickAlign[A],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]),B=[0,0,0],j(A,U,V);for(L=0;L<3;++L)q[L]+=T*U[L]*this.tickPad[L]/r[5*L];this._text.drawTicks(A,this.tickSize[A],this.tickAngle[A],q,this.tickColor[A],H,B,S)}if(this.labelEnable[A]){F=0,B=[0,0,0],this.labels[A].length>4&&(N(A),F=1),\"auto\"===(S=[this.labelAlign[A],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]);for(L=0;L<3;++L)q[L]+=T*U[L]*this.labelPad[L]/r[5*L];q[A]+=.5*(a[0][A]+a[1][A]),this._text.drawLabel(A,this.labelSize[A],this.labelAngle[A],q,this.labelColor[A],[0,0,0],B,S)}}this._text.unbind()},h.dispose=function(){this._text.dispose(),this._lines.dispose(),this._background.dispose(),this._lines=null,this._text=null,this._background=null,this.gl=null}},{\"./lib/background.js\":234,\"./lib/cube.js\":235,\"./lib/lines.js\":236,\"./lib/text.js\":238,\"./lib/ticks.js\":239}],234:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=[],r=[],s=0,l=0;l<3;++l)for(var c=(l+1)%3,u=(l+2)%3,h=[0,0,0],f=[0,0,0],p=-1;p<=1;p+=2){r.push(s,s+2,s+1,s+1,s+2,s+3),h[l]=p,f[l]=p;for(var d=-1;d<=1;d+=2){h[c]=d;for(var g=-1;g<=1;g+=2)h[u]=g,e.push(h[0],h[1],h[2],f[0],f[1],f[2]),s+=1}var v=c;c=u,u=v}var m=n(t,new Float32Array(e)),y=n(t,new Uint16Array(r),t.ELEMENT_ARRAY_BUFFER),x=i(t,[{buffer:m,type:t.FLOAT,size:3,offset:0,stride:24},{buffer:m,type:t.FLOAT,size:3,offset:12,stride:24}],y),b=a(t);return b.attributes.position.location=0,b.attributes.normal.location=1,new o(t,m,x,b)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").bg;function o(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n}var s=o.prototype;s.draw=function(t,e,r,n,i,a){for(var o=!1,s=0;s<3;++s)o=o||i[s];if(o){var l=this.gl;l.enable(l.POLYGON_OFFSET_FILL),l.polygonOffset(1,2),this.shader.bind(),this.shader.uniforms={model:t,view:e,projection:r,bounds:n,enable:i,colors:a},this.vao.bind(),this.vao.draw(this.gl.TRIANGLES,36),this.vao.unbind(),l.disable(l.POLYGON_OFFSET_FILL)}},s.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders\":237,\"gl-buffer\":241,\"gl-vao\":327}],235:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,p){i(s,e,t),i(s,r,s);for(var y=0,x=0;x<2;++x){u[2]=a[x][2];for(var b=0;b<2;++b){u[1]=a[b][1];for(var _=0;_<2;++_)u[0]=a[_][0],f(l[y],u,s),y+=1}}for(var w=-1,x=0;x<8;++x){for(var k=l[x][3],T=0;T<3;++T)c[x][T]=l[x][T]/k;p&&(c[x][2]*=-1),k<0&&(w<0?w=x:c[x][2]<c[w][2]&&(w=x))}if(w<0){w=0;for(var A=0;A<3;++A){for(var M=(A+2)%3,S=(A+1)%3,E=-1,C=-1,L=0;L<2;++L){var P=L<<A,O=P+(L<<M)+(1-L<<S),z=P+(1-L<<M)+(L<<S);o(c[P],c[O],c[z],h)<0||(L?E=1:C=1)}if(E<0||C<0)C>E&&(w|=1<<A);else{for(var L=0;L<2;++L){var P=L<<A,O=P+(L<<M)+(1-L<<S),z=P+(1-L<<M)+(L<<S),I=d([l[P],l[O],l[z],l[P+(1<<M)+(1<<S)]]);L?E=I:C=I}C>E&&(w|=1<<A)}}}for(var D=7^w,R=-1,x=0;x<8;++x)x!==w&&x!==D&&(R<0?R=x:c[R][1]>c[x][1]&&(R=x));for(var F=-1,x=0;x<3;++x){var B=R^1<<x;if(B!==w&&B!==D){F<0&&(F=B);var S=c[B];S[0]<c[F][0]&&(F=B)}}for(var N=-1,x=0;x<3;++x){var B=R^1<<x;if(B!==w&&B!==D&&B!==F){N<0&&(N=B);var S=c[B];S[0]>c[N][0]&&(N=B)}}var j=g;j[0]=j[1]=j[2]=0,j[n.log2(F^R)]=R&F,j[n.log2(R^N)]=R&N;var U=7^N;U===w||U===D?(U=7^F,j[n.log2(N^U)]=U&N):j[n.log2(F^U)]=U&F;for(var V=v,q=w,A=0;A<3;++A)V[A]=q&1<<A?-1:1;return m};var n=t(\"bit-twiddle\"),i=t(\"gl-mat4/multiply\"),a=t(\"split-polygon\"),o=t(\"robust-orientation\"),s=new Array(16),l=new Array(8),c=new Array(8),u=new Array(3),h=[0,0,0];function f(t,e,r){for(var n=0;n<4;++n){t[n]=r[12+n];for(var i=0;i<3;++i)t[n]+=e[i]*r[4*i+n]}}!function(){for(var t=0;t<8;++t)l[t]=[1,1,1,1],c[t]=[1,1,1]}();var p=[[0,0,1,0,0],[0,0,-1,1,0],[0,-1,0,1,0],[0,1,0,1,0],[-1,0,0,1,0],[1,0,0,1,0]];function d(t){for(var e=0;e<p.length;++e)if((t=a.positive(t,p[e])).length<3)return 0;var r=t[0],n=r[0]/r[3],i=r[1]/r[3],o=0;for(e=1;e+1<t.length;++e){var s=t[e],l=t[e+1],c=s[0]/s[3]-n,u=s[1]/s[3]-i,h=l[0]/l[3]-n,f=l[1]/l[3]-i;o+=Math.abs(c*f-u*h)}return o}var g=[1,1,1],v=[0,0,0],m={cubeEdges:g,axis:v}},{\"bit-twiddle\":92,\"gl-mat4/multiply\":267,\"robust-orientation\":510,\"split-polygon\":527}],236:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var o=[],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[0,0,0];o.push(0,0,1,0,1,1,0,0,-1,0,0,-1,0,1,1,0,1,-1);for(var h=0;h<3;++h){for(var f=o.length/3|0,d=0;d<r[h].length;++d){var g=+r[h][d].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var v=o.length/3|0;s[h]=f,l[h]=v-f;for(var f=o.length/3|0,m=0;m<r[h].length;++m){var g=+r[h][m].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var v=o.length/3|0;c[h]=f,u[h]=v-f}var y=n(t,new Float32Array(o)),x=i(t,[{buffer:y,type:t.FLOAT,size:3,stride:0,offset:0}]),b=a(t);return b.attributes.position.location=0,new p(t,y,x,b,l,s,u,c)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").line,o=[0,0,0],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[1,1];function h(t){return t[0]=t[1]=t[2]=0,t}function f(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function p(t,e,r,n,i,a,o,s){this.gl=t,this.vertBuffer=e,this.vao=r,this.shader=n,this.tickCount=i,this.tickOffset=a,this.gridCount=o,this.gridOffset=s}var d=p.prototype;d.bind=function(t,e,r){this.shader.bind(),this.shader.uniforms.model=t,this.shader.uniforms.view=e,this.shader.uniforms.projection=r,u[0]=this.gl.drawingBufferWidth,u[1]=this.gl.drawingBufferHeight,this.shader.uniforms.screenShape=u,this.vao.bind()},d.unbind=function(){this.vao.unbind()},d.drawAxisLine=function(t,e,r,n,i){var a=h(s);this.shader.uniforms.majorAxis=s,a[t]=e[1][t]-e[0][t],this.shader.uniforms.minorAxis=a;var o,u=f(c,r);u[t]+=e[0][t],this.shader.uniforms.offset=u,this.shader.uniforms.lineWidth=i,this.shader.uniforms.color=n,(o=h(l))[(t+2)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6),(o=h(l))[(t+1)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6)},d.drawAxisTicks=function(t,e,r,n,i){if(this.tickCount[t]){var a=h(o);a[t]=1,this.shader.uniforms.majorAxis=a,this.shader.uniforms.offset=e,this.shader.uniforms.minorAxis=r,this.shader.uniforms.color=n,this.shader.uniforms.lineWidth=i;var s=h(l);s[t]=1,this.shader.uniforms.screenAxis=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t])}},d.drawGrid=function(t,e,r,n,i,a){if(this.gridCount[t]){var u=h(s);u[e]=r[1][e]-r[0][e],this.shader.uniforms.minorAxis=u;var p=f(c,n);p[e]+=r[0][e],this.shader.uniforms.offset=p;var d=h(o);d[t]=1,this.shader.uniforms.majorAxis=d;var g=h(l);g[t]=1,this.shader.uniforms.screenAxis=g,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,this.gridCount[t],this.gridOffset[t])}},d.drawZero=function(t,e,r,n,i,a){var o=h(s);this.shader.uniforms.majorAxis=o,o[t]=r[1][t]-r[0][t],this.shader.uniforms.minorAxis=o;var u=f(c,n);u[t]+=r[0][t],this.shader.uniforms.offset=u;var p=h(l);p[e]=1,this.shader.uniforms.screenAxis=p,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,6)},d.dispose=function(){this.vao.dispose(),this.vertBuffer.dispose(),this.shader.dispose()}},{\"./shaders\":237,\"gl-buffer\":241,\"gl-vao\":327}],237:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, majorAxis, minorAxis, screenAxis;\\nuniform float lineWidth;\\nuniform vec2 screenShape;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nvoid main() {\\n  vec3 major = position.x * majorAxis;\\n  vec3 minor = position.y * minorAxis;\\n\\n  vec3 vPosition = major + minor + offset;\\n  vec3 pPosition = project(vPosition);\\n  vec3 offset = project(vPosition + screenAxis * position.z);\\n\\n  vec2 screen = normalize((offset - pPosition).xy * screenShape) / screenShape;\\n\\n  gl_Position = vec4(pPosition + vec3(0.5 * screen * lineWidth, 0), 1.0);\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.line=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"}])};var s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, axis, alignDir, alignOpt;\\nuniform float scale, angle, pixelScale;\\nuniform vec2 resolution;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nfloat computeViewAngle(vec3 a, vec3 b) {\\n  vec3 A = project(a);\\n  vec3 B = project(b);\\n\\n  return atan(\\n    (B.y - A.y) * resolution.y,\\n    (B.x - A.x) * resolution.x\\n  );\\n}\\n\\nconst float PI = 3.141592;\\nconst float TWO_PI = 2.0 * PI;\\nconst float HALF_PI = 0.5 * PI;\\nconst float ONE_AND_HALF_PI = 1.5 * PI;\\n\\nint option = int(floor(alignOpt.x + 0.001));\\nfloat hv_ratio =       alignOpt.y;\\nbool enableAlign =    (alignOpt.z != 0.0);\\n\\nfloat mod_angle(float a) {\\n  return mod(a, PI);\\n}\\n\\nfloat positive_angle(float a) {\\n  return mod_angle((a < 0.0) ?\\n    a + TWO_PI :\\n    a\\n  );\\n}\\n\\nfloat look_upwards(float a) {\\n  float b = positive_angle(a);\\n  return ((b > HALF_PI) && (b <= ONE_AND_HALF_PI)) ?\\n    b - PI :\\n    b;\\n}\\n\\nfloat look_horizontal_or_vertical(float a, float ratio) {\\n  // ratio controls the ratio between being horizontal to (vertical + horizontal)\\n  // if ratio is set to 0.5 then it is 50%, 50%.\\n  // when using a higher ratio e.g. 0.75 the result would\\n  // likely be more horizontal than vertical.\\n\\n  float b = positive_angle(a);\\n\\n  return\\n    (b < (      ratio) * HALF_PI) ? 0.0 :\\n    (b < (2.0 - ratio) * HALF_PI) ? -HALF_PI :\\n    (b < (2.0 + ratio) * HALF_PI) ? 0.0 :\\n    (b < (4.0 - ratio) * HALF_PI) ? HALF_PI :\\n                                    0.0;\\n}\\n\\nfloat roundTo(float a, float b) {\\n  return float(b * floor((a + 0.5 * b) / b));\\n}\\n\\nfloat look_round_n_directions(float a, int n) {\\n  float b = positive_angle(a);\\n  float div = TWO_PI / float(n);\\n  float c = roundTo(b, div);\\n  return look_upwards(c);\\n}\\n\\nfloat applyAlignOption(float rawAngle, float delta) {\\n  return\\n    (option >  2) ? look_round_n_directions(rawAngle + delta, option) :       // option 3-n: round to n directions\\n    (option == 2) ? look_horizontal_or_vertical(rawAngle + delta, hv_ratio) : // horizontal or vertical\\n    (option == 1) ? rawAngle + delta :       // use free angle, and flip to align with one direction of the axis\\n    (option == 0) ? look_upwards(rawAngle) : // use free angle, and stay upwards\\n    (option ==-1) ? 0.0 :                    // useful for backward compatibility, all texts remains horizontal\\n                    rawAngle;                // otherwise return back raw input angle\\n}\\n\\nbool isAxisTitle = (axis.x == 0.0) &&\\n                   (axis.y == 0.0) &&\\n                   (axis.z == 0.0);\\n\\nvoid main() {\\n  //Compute world offset\\n  float axisDistance = position.z;\\n  vec3 dataPosition = axisDistance * axis + offset;\\n\\n  float beta = angle; // i.e. user defined attributes for each tick\\n\\n  float axisAngle;\\n  float clipAngle;\\n  float flip;\\n\\n  if (enableAlign) {\\n    axisAngle = (isAxisTitle) ? HALF_PI :\\n                      computeViewAngle(dataPosition, dataPosition + axis);\\n    clipAngle = computeViewAngle(dataPosition, dataPosition + alignDir);\\n\\n    axisAngle += (sin(axisAngle) < 0.0) ? PI : 0.0;\\n    clipAngle += (sin(clipAngle) < 0.0) ? PI : 0.0;\\n\\n    flip = (dot(vec2(cos(axisAngle), sin(axisAngle)),\\n                vec2(sin(clipAngle),-cos(clipAngle))) > 0.0) ? 1.0 : 0.0;\\n\\n    beta += applyAlignOption(clipAngle, flip * PI);\\n  }\\n\\n  //Compute plane offset\\n  vec2 planeCoord = position.xy * pixelScale;\\n\\n  mat2 planeXform = scale * mat2(\\n     cos(beta), sin(beta),\\n    -sin(beta), cos(beta)\\n  );\\n\\n  vec2 viewOffset = 2.0 * planeXform * planeCoord / resolution;\\n\\n  //Compute clip position\\n  vec3 clipPosition = project(dataPosition);\\n\\n  //Apply text offset in clip coordinates\\n  clipPosition += vec3(viewOffset, 0.0);\\n\\n  //Done\\n  gl_Position = vec4(clipPosition, 1.0);\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.text=function(t){return i(t,s,l,null,[{name:\"position\",type:\"vec3\"}])};var c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec3 normal;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 enable;\\nuniform vec3 bounds[2];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n\\n  vec3 signAxis = sign(bounds[1] - bounds[0]);\\n\\n  vec3 realNormal = signAxis * normal;\\n\\n  if(dot(realNormal, enable) > 0.0) {\\n    vec3 minRange = min(bounds[0], bounds[1]);\\n    vec3 maxRange = max(bounds[0], bounds[1]);\\n    vec3 nPosition = mix(minRange, maxRange, 0.5 * (position + 1.0));\\n    gl_Position = projection * view * model * vec4(nPosition, 1.0);\\n  } else {\\n    gl_Position = vec4(0,0,0,0);\\n  }\\n\\n  colorChannel = abs(realNormal);\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 colors[3];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n  gl_FragColor = colorChannel.x * colors[0] +\\n                 colorChannel.y * colors[1] +\\n                 colorChannel.z * colors[2];\\n}\"]);r.bg=function(t){return i(t,c,u,null,[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}])}},{\"gl-shader\":301,glslify:409}],238:[function(t,e,r){(function(r){\"use strict\";e.exports=function(t,e,r,a,s,l){var u=n(t),h=i(t,[{buffer:u,size:3}]),f=o(t);f.attributes.position.location=0;var p=new c(t,f,u,h);return p.update(e,r,a,s,l),p};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"vectorize-text\"),o=t(\"./shaders\").text,s=window||r.global||{},l=s.__TEXT_CACHE||{};s.__TEXT_CACHE={};function c(t,e,r,n){this.gl=t,this.shader=e,this.buffer=r,this.vao=n,this.tickOffset=this.tickCount=this.labelOffset=this.labelCount=null}var u=c.prototype,h=[0,0];u.bind=function(t,e,r,n){this.vao.bind(),this.shader.bind();var i=this.shader.uniforms;i.model=t,i.view=e,i.projection=r,i.pixelScale=n,h[0]=this.gl.drawingBufferWidth,h[1]=this.gl.drawingBufferHeight,this.shader.uniforms.resolution=h},u.unbind=function(){this.vao.unbind()},u.update=function(t,e,r,n,i){var o=[];function s(t,e,r,n,i,s){var c=l[r];c||(c=l[r]={});var u=c[e];u||(u=c[e]=function(t,e){try{return a(t,e)}catch(e){return console.warn('error vectorizing text:\"'+t+'\" error:',e),{cells:[],positions:[]}}}(e,{triangles:!0,font:r,textAlign:\"center\",textBaseline:\"middle\",lineSpacing:i,styletags:s}));for(var h=(n||12)/12,f=u.positions,p=u.cells,d=0,g=p.length;d<g;++d)for(var v=p[d],m=2;m>=0;--m){var y=f[v[m]];o.push(h*y[0],-h*y[1],t)}}for(var c=[0,0,0],u=[0,0,0],h=[0,0,0],f=[0,0,0],p={breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},d=0;d<3;++d){h[d]=o.length/3|0,s(.5*(t[0][d]+t[1][d]),e[d],r[d],12,1.25,p),f[d]=(o.length/3|0)-h[d],c[d]=o.length/3|0;for(var g=0;g<n[d].length;++g)n[d][g].text&&s(n[d][g].x,n[d][g].text,n[d][g].font||i,n[d][g].fontSize||12,1.25,p);u[d]=(o.length/3|0)-c[d]}this.buffer.update(o),this.tickOffset=c,this.tickCount=u,this.labelOffset=h,this.labelCount=f},u.drawTicks=function(t,e,r,n,i,a,o,s){this.tickCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t]))},u.drawLabel=function(t,e,r,n,i,a,o,s){this.labelCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.labelCount[t],this.labelOffset[t]))},u.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()}}).call(this,t(\"_process\"))},{\"./shaders\":237,_process:482,\"gl-buffer\":241,\"gl-vao\":327,\"vectorize-text\":550}],239:[function(t,e,r){\"use strict\";function n(t,e){var r=t+\"\",n=r.indexOf(\".\"),i=0;n>=0&&(i=r.length-n-1);var a=Math.pow(10,i),o=Math.round(t*e*a),s=o+\"\";if(s.indexOf(\"e\")>=0)return s;var l=o/a,c=o%a;o<0?(l=0|-Math.ceil(l),c=0|-c):(l=0|Math.floor(l),c|=0);var u=\"\"+l;if(o<0&&(u=\"-\"+u),i){for(var h=\"\"+c;h.length<i;)h=\"0\"+h;return u+\".\"+h}return u}r.create=function(t,e){for(var r=[],i=0;i<3;++i){for(var a=[],o=(t[0][i],t[1][i],0);o*e[i]<=t[1][i];++o)a.push({x:o*e[i],text:n(e[i],o)});for(var o=-1;o*e[i]>=t[0][i];--o)a.push({x:o*e[i],text:n(e[i],o)});r.push(a)}return r},r.equal=function(t,e){for(var r=0;r<3;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;++n){var i=t[r][n],a=e[r][n];if(i.x!==a.x||i.text!==a.text||i.font!==a.font||i.fontColor!==a.fontColor||i.fontSize!==a.fontSize||i.dx!==a.dx||i.dy!==a.dy)return!1}}return!0}},{}],240:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,l,h){var f=e.model||c,p=e.view||c,m=e.projection||c,y=e._ortho||!1,x=t.bounds,b=(h=h||a(f,p,m,x,y)).axis;o(u,p,f),o(u,m,u);for(var _=g,w=0;w<3;++w)_[w].lo=1/0,_[w].hi=-1/0,_[w].pixelsPerDataUnit=1/0;var k=n(s(u,u));s(u,u);for(var T=0;T<3;++T){var A=(T+1)%3,M=(T+2)%3,S=v;t:for(var w=0;w<2;++w){var E=[];if(b[T]<0!=!!w){S[T]=x[w][T];for(var C=0;C<2;++C){S[A]=x[C^w][A];for(var L=0;L<2;++L)S[M]=x[L^C^w][M],E.push(S.slice())}for(var P=y?5:4,C=P;C===P;++C){if(0===E.length)continue t;E=i.positive(E,k[C])}for(var C=0;C<E.length;++C)for(var M=E[C],O=d(v,u,M,r,l),L=0;L<3;++L)_[L].lo=Math.min(_[L].lo,M[L]),_[L].hi=Math.max(_[L].hi,M[L]),L!==T&&(_[L].pixelsPerDataUnit=Math.min(_[L].pixelsPerDataUnit,Math.abs(O[L])))}}}return _};var n=t(\"extract-frustum-planes\"),i=t(\"split-polygon\"),a=t(\"./lib/cube.js\"),o=t(\"gl-mat4/multiply\"),s=t(\"gl-mat4/transpose\"),l=t(\"gl-vec4/transformMat4\"),c=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]),u=new Float32Array(16);function h(t,e,r){this.lo=t,this.hi=e,this.pixelsPerDataUnit=r}var f=[0,0,0,1],p=[0,0,0,1];function d(t,e,r,n,i){for(var a=0;a<3;++a){for(var o=f,s=p,c=0;c<3;++c)s[c]=o[c]=r[c];s[3]=o[3]=1,s[a]+=1,l(s,s,e),s[3]<0&&(t[a]=1/0),o[a]-=1,l(o,o,e),o[3]<0&&(t[a]=1/0);var u=(o[0]/o[3]-s[0]/s[3])*n,h=(o[1]/o[3]-s[1]/s[3])*i;t[a]=.25*Math.sqrt(u*u+h*h)}return t}var g=[new h(1/0,-1/0,1/0),new h(1/0,-1/0,1/0),new h(1/0,-1/0,1/0)],v=[0,0,0]},{\"./lib/cube.js\":235,\"extract-frustum-planes\":224,\"gl-mat4/multiply\":267,\"gl-mat4/transpose\":276,\"gl-vec4/transformMat4\":398,\"split-polygon\":527}],241:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"ndarray-ops\"),a=t(\"ndarray\"),o=[\"uint8\",\"uint8_clamped\",\"uint16\",\"uint32\",\"int8\",\"int16\",\"int32\",\"float32\"];function s(t,e,r,n,i){this.gl=t,this.type=e,this.handle=r,this.length=n,this.usage=i}var l=s.prototype;function c(t,e,r,n,i,a){var o=i.length*i.BYTES_PER_ELEMENT;if(a<0)return t.bufferData(e,i,n),o;if(o+a>r)throw new Error(\"gl-buffer: If resizing buffer, must not specify offset\");return t.bufferSubData(e,a,i),r}function u(t,e){for(var r=n.malloc(t.length,e),i=t.length,a=0;a<i;++a)r[a]=t[a];return r}l.bind=function(){this.gl.bindBuffer(this.type,this.handle)},l.unbind=function(){this.gl.bindBuffer(this.type,null)},l.dispose=function(){this.gl.deleteBuffer(this.handle)},l.update=function(t,e){if(\"number\"!=typeof e&&(e=-1),this.bind(),\"object\"==typeof t&&\"undefined\"!=typeof t.shape){var r=t.dtype;if(o.indexOf(r)<0&&(r=\"float32\"),this.type===this.gl.ELEMENT_ARRAY_BUFFER)r=gl.getExtension(\"OES_element_index_uint\")&&\"uint16\"!==r?\"uint32\":\"uint16\";if(r===t.dtype&&function(t,e){for(var r=1,n=e.length-1;n>=0;--n){if(e[n]!==r)return!1;r*=t[n]}return!0}(t.shape,t.stride))0===t.offset&&t.data.length===t.shape[0]?this.length=c(this.gl,this.type,this.length,this.usage,t.data,e):this.length=c(this.gl,this.type,this.length,this.usage,t.data.subarray(t.offset,t.shape[0]),e);else{var s=n.malloc(t.size,r),l=a(s,t.shape);i.assign(l,t),this.length=c(this.gl,this.type,this.length,this.usage,e<0?s:s.subarray(0,t.size),e),n.free(s)}}else if(Array.isArray(t)){var h;h=this.type===this.gl.ELEMENT_ARRAY_BUFFER?u(t,\"uint16\"):u(t,\"float32\"),this.length=c(this.gl,this.type,this.length,this.usage,e<0?h:h.subarray(0,t.length),e),n.free(h)}else if(\"object\"==typeof t&&\"number\"==typeof t.length)this.length=c(this.gl,this.type,this.length,this.usage,t,e);else{if(\"number\"!=typeof t&&void 0!==t)throw new Error(\"gl-buffer: Invalid data type\");if(e>=0)throw new Error(\"gl-buffer: Cannot specify offset when resizing buffer\");(t|=0)<=0&&(t=1),this.gl.bufferData(this.type,0|t,this.usage),this.length=t}},e.exports=function(t,e,r,n){if(r=r||t.ARRAY_BUFFER,n=n||t.DYNAMIC_DRAW,r!==t.ARRAY_BUFFER&&r!==t.ELEMENT_ARRAY_BUFFER)throw new Error(\"gl-buffer: Invalid type for webgl buffer, must be either gl.ARRAY_BUFFER or gl.ELEMENT_ARRAY_BUFFER\");if(n!==t.DYNAMIC_DRAW&&n!==t.STATIC_DRAW&&n!==t.STREAM_DRAW)throw new Error(\"gl-buffer: Invalid usage for buffer, must be either gl.DYNAMIC_DRAW, gl.STATIC_DRAW or gl.STREAM_DRAW\");var i=t.createBuffer(),a=new s(t,r,i,0,n);return a.update(e),a}},{ndarray:450,\"ndarray-ops\":444,\"typedarray-pool\":545}],242:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\"),i=function(t,e){for(var r=0;r<t.length;r++)if(t[r]>=e)return r-1;return r},a=n.create(),o=n.create(),s=function(t,e,r){return t<e?e:t>r?r:t},l=function(t,e,r,l){var c=t[0],u=t[1],h=t[2],f=r[0].length,p=r[1].length,d=r[2].length,g=i(r[0],c),v=i(r[1],u),m=i(r[2],h),y=g+1,x=v+1,b=m+1;if(l&&(g=s(g,0,f-1),y=s(y,0,f-1),v=s(v,0,p-1),x=s(x,0,p-1),m=s(m,0,d-1),b=s(b,0,d-1)),g<0||v<0||m<0||y>=f||x>=p||b>=d)return n.create();var _=(c-r[0][g])/(r[0][y]-r[0][g]),w=(u-r[1][v])/(r[1][x]-r[1][v]),k=(h-r[2][m])/(r[2][b]-r[2][m]);(_<0||_>1||isNaN(_))&&(_=0),(w<0||w>1||isNaN(w))&&(w=0),(k<0||k>1||isNaN(k))&&(k=0);var T=m*f*p,A=b*f*p,M=v*f,S=x*f,E=g,C=y,L=e[M+T+E],P=e[M+T+C],O=e[S+T+E],z=e[S+T+C],I=e[M+A+E],D=e[M+A+C],R=e[S+A+E],F=e[S+A+C],B=n.create();return n.lerp(B,L,P,_),n.lerp(a,O,z,_),n.lerp(B,B,a,w),n.lerp(a,I,D,_),n.lerp(o,R,F,_),n.lerp(a,a,o,w),n.lerp(B,B,a,k),B};e.exports=function(t,e){var r;r=t.positions?t.positions:function(t){for(var e=t[0],r=t[1],n=t[2],i=[],a=0;a<n.length;a++)for(var o=0;o<r.length;o++)for(var s=0;s<e.length;s++)i.push([n[a],r[o],e[s]]);return i}(t.meshgrid);var i=t.meshgrid,a=t.vectors,o={positions:[],vertexIntensity:[],vertexIntensityBounds:t.vertexIntensityBounds,vertexNormals:[],vectors:[],cells:[],coneOffset:t.coneOffset,colormap:t.colormap};if(0===t.positions.length)return e&&(e[0]=[0,0,0],e[1]=[0,0,0]),o;for(var s=0,c=1/0,u=-1/0,h=1/0,f=-1/0,p=1/0,d=-1/0,g=null,v=null,m=[],y=1/0,x=0;x<r.length;x++){var b,_=r[x];c=Math.min(_[0],c),u=Math.max(_[0],u),h=Math.min(_[1],h),f=Math.max(_[1],f),p=Math.min(_[2],p),d=Math.max(_[2],d),b=i?l(_,a,i,!0):a[x],n.length(b)>s&&(s=n.length(b)),x&&(y=Math.min(y,2*n.distance(g,_)/(n.length(v)+n.length(b)))),g=_,v=b,m.push(b)}var w=[c,h,p],k=[u,f,d];e&&(e[0]=w,e[1]=k),0===s&&(s=1);var T=1/s;isFinite(y)&&!isNaN(y)||(y=1),o.vectorScale=y;var A=function(t,e,r){var i=n.create();return void 0!==t&&n.set(i,t,e,r),i}(0,1,0),M=t.coneSize||.5;t.absoluteConeSize&&(M=t.absoluteConeSize*T),o.coneScale=M;x=0;for(var S=0;x<r.length;x++)for(var E=(_=r[x])[0],C=_[1],L=_[2],P=m[x],O=n.length(P)*T,z=0;z<8;z++){o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vertexIntensity.push(O,O,O),o.vertexIntensity.push(O,O,O),o.vertexNormals.push(A,A,A),o.vertexNormals.push(A,A,A);var I=o.positions.length;o.cells.push([I-6,I-5,I-4],[I-3,I-2,I-1])}return o},e.exports.createConeMesh=t(\"./lib/conemesh\")},{\"./lib/conemesh\":243,\"gl-vec3\":346}],243:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./shaders\"),g=d.meshShader,v=d.pickShader,m=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function y(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,y,x,b,_,w,k,T){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=i,this.triangleVectors=a,this.triangleColors=s,this.triangleNormals=c,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=u,this.triangleCount=0,this.lineWidth=1,this.edgePositions=h,this.edgeColors=p,this.edgeUVs=d,this.edgeIds=f,this.edgeVAO=g,this.edgeCount=0,this.pointPositions=v,this.pointColors=x,this.pointUVs=b,this.pointSizes=_,this.pointIds=y,this.pointVAO=w,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=k,this.contourVAO=T,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.coneScale=2,this.vectorScale=1,this.coneOffset=.25,this._model=m,this._view=m,this._projection=m,this._resolution=[1,1]}var x=y.prototype;function b(t){var e=n(t,v.vertex,v.fragment,null,v.attributes);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.vector.location=5,e}x.isOpaque=function(){return this.opacity>=1},x.isTransparent=function(){return this.opacity<1},x.pickSlots=1,x.setPickBase=function(t){this.pickId=t},x.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=i[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},x.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),void 0!==t.vectorScale&&(this.vectorScale=t.vectorScale),void 0!==t.coneScale&&(this.coneScale=t.coneScale),void 0!==t.coneOffset&&(this.coneOffset=t.coneOffset),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=h({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return u(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,i=t.vectors;if(n&&r&&i){var a=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[],w=[],k=[];this.cells=r,this.positions=n;var T=t.vertexNormals,A=t.cellNormals,M=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,S=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!A&&(A=s.faceNormals(r,n,S)),A||T||(T=s.vertexNormals(r,n,M));var E=t.vertexColors,C=t.cellColors,L=t.meshColor||[1,1,1,1],P=t.vertexUVs,O=t.vertexIntensity,z=t.cellUVs,I=t.cellIntensity,D=1/0,R=-1/0;if(!P&&!z)if(O)if(t.vertexIntensityBounds)D=+t.vertexIntensityBounds[0],R=+t.vertexIntensityBounds[1];else for(var F=0;F<O.length;++F){var B=O[F];D=Math.min(D,B),R=Math.max(R,B)}else if(I)for(F=0;F<I.length;++F){B=I[F];D=Math.min(D,B),R=Math.max(R,B)}else for(F=0;F<n.length;++F){B=n[F][2];D=Math.min(D,B),R=Math.max(R,B)}this.intensity=O||(I?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,I):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var N=t.pointSizes,j=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(F=0;F<n.length;++F)for(var U=n[F],V=0;V<3;++V)!isNaN(U[V])&&isFinite(U[V])&&(this.bounds[0][V]=Math.min(this.bounds[0][V],U[V]),this.bounds[1][V]=Math.max(this.bounds[1][V],U[V]));var q=0,H=0,G=0;t:for(F=0;F<r.length;++F){var Y=r[F];switch(Y.length){case 1:for(U=n[X=Y[0]],V=0;V<3;++V)if(isNaN(U[V])||!isFinite(U[V]))continue t;x.push(U[0],U[1],U[2],U[3]),3===(Z=E?E[X]:C?C[F]:L).length?b.push(Z[0],Z[1],Z[2],1):b.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],_.push(J[0],J[1]),N?w.push(N[X]):w.push(j),k.push(F),G+=1;break;case 2:for(V=0;V<2;++V){U=n[X=Y[V]];for(var W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t}for(V=0;V<2;++V){U=n[X=Y[V]];g.push(U[0],U[1],U[2]),3===(Z=E?E[X]:C?C[F]:L).length?v.push(Z[0],Z[1],Z[2],1):v.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],m.push(J[0],J[1]),y.push(F)}H+=1;break;case 3:for(V=0;V<3;++V)for(U=n[X=Y[V]],W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t;for(V=0;V<3;++V){var X;U=n[X=Y[2-V]];a.push(U[0],U[1],U[2],U[3]);var Z,J,K,$=i[X];l.push($[0],$[1],$[2]),3===(Z=E?E[X]:C?C[F]:L).length?c.push(Z[0],Z[1],Z[2],1):c.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],p.push(J[0],J[1]),K=T?T[X]:A[F],f.push(K[0],K[1],K[2]),d.push(F)}q+=1}}this.pointCount=G,this.edgeCount=H,this.triangleCount=q,this.pointPositions.update(x),this.pointColors.update(b),this.pointUVs.update(_),this.pointSizes.update(w),this.pointIds.update(new Uint32Array(k)),this.edgePositions.update(g),this.edgeColors.update(v),this.edgeUVs.update(m),this.edgeIds.update(new Uint32Array(y)),this.trianglePositions.update(a),this.triangleVectors.update(l),this.triangleColors.update(c),this.triangleUVs.update(p),this.triangleNormals.update(f),this.triangleIds.update(new Uint32Array(d))}},x.drawTransparent=x.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:m.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var f=u[12+o],p=0;p<3;++p)f+=u[4*p+o]*this.lightPosition[p];s.lightPosition[o]=f/h}if(this.triangleCount>0){var d=this.triShader;d.bind(),d.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},x.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:i,clipBounds:a,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind())},x.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3);return{index:Math.floor(r[1]/48),position:n,dataCoordinate:n}},x.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose()},e.exports=function(t,e){1===arguments.length&&(t=(e=t).gl);var r=e.triShader||function(t){var e=n(t,g.vertex,g.fragment,null,g.attributes);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.vector.location=5,e}(t),s=b(t),l=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));l.generateMipmap(),l.minFilter=t.LINEAR_MIPMAP_LINEAR,l.magFilter=t.LINEAR;var c=i(t),h=i(t),f=i(t),p=i(t),d=i(t),v=i(t),m=a(t,[{buffer:c,type:t.FLOAT,size:4},{buffer:v,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:f,type:t.FLOAT,size:4},{buffer:p,type:t.FLOAT,size:2},{buffer:d,type:t.FLOAT,size:3},{buffer:h,type:t.FLOAT,size:3}]),x=i(t),_=i(t),w=i(t),k=i(t),T=a(t,[{buffer:x,type:t.FLOAT,size:3},{buffer:k,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:_,type:t.FLOAT,size:4},{buffer:w,type:t.FLOAT,size:2}]),A=i(t),M=i(t),S=i(t),E=i(t),C=i(t),L=a(t,[{buffer:A,type:t.FLOAT,size:3},{buffer:C,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:M,type:t.FLOAT,size:4},{buffer:S,type:t.FLOAT,size:2},{buffer:E,type:t.FLOAT,size:1}]),P=i(t),O=new y(t,l,r,s,c,h,v,f,p,d,m,x,k,_,w,T,A,C,M,S,E,L,P,a(t,[{buffer:P,type:t.FLOAT,size:3}]));return O.update(e),O}},{\"./shaders\":244,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-shader\":301,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,normals:453,\"simplicial-complex-contour\":518,\"typedarray-pool\":545}],244:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\nuniform float vectorScale;\\nuniform float coneScale;\\n\\nuniform float coneOffset;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * conePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal,0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(conePosition, 1.0);\\n  vec4 t_position  = view * conePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = conePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular\\n            , opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nuniform float vectorScale;\\nuniform float coneScale;\\nuniform float coneOffset;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n  gl_Position = projection * view * conePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec3\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec3\"}]}},{glslify:409}],245:[function(t,e,r){e.exports={0:\"NONE\",1:\"ONE\",2:\"LINE_LOOP\",3:\"LINE_STRIP\",4:\"TRIANGLES\",5:\"TRIANGLE_STRIP\",6:\"TRIANGLE_FAN\",256:\"DEPTH_BUFFER_BIT\",512:\"NEVER\",513:\"LESS\",514:\"EQUAL\",515:\"LEQUAL\",516:\"GREATER\",517:\"NOTEQUAL\",518:\"GEQUAL\",519:\"ALWAYS\",768:\"SRC_COLOR\",769:\"ONE_MINUS_SRC_COLOR\",770:\"SRC_ALPHA\",771:\"ONE_MINUS_SRC_ALPHA\",772:\"DST_ALPHA\",773:\"ONE_MINUS_DST_ALPHA\",774:\"DST_COLOR\",775:\"ONE_MINUS_DST_COLOR\",776:\"SRC_ALPHA_SATURATE\",1024:\"STENCIL_BUFFER_BIT\",1028:\"FRONT\",1029:\"BACK\",1032:\"FRONT_AND_BACK\",1280:\"INVALID_ENUM\",1281:\"INVALID_VALUE\",1282:\"INVALID_OPERATION\",1285:\"OUT_OF_MEMORY\",1286:\"INVALID_FRAMEBUFFER_OPERATION\",2304:\"CW\",2305:\"CCW\",2849:\"LINE_WIDTH\",2884:\"CULL_FACE\",2885:\"CULL_FACE_MODE\",2886:\"FRONT_FACE\",2928:\"DEPTH_RANGE\",2929:\"DEPTH_TEST\",2930:\"DEPTH_WRITEMASK\",2931:\"DEPTH_CLEAR_VALUE\",2932:\"DEPTH_FUNC\",2960:\"STENCIL_TEST\",2961:\"STENCIL_CLEAR_VALUE\",2962:\"STENCIL_FUNC\",2963:\"STENCIL_VALUE_MASK\",2964:\"STENCIL_FAIL\",2965:\"STENCIL_PASS_DEPTH_FAIL\",2966:\"STENCIL_PASS_DEPTH_PASS\",2967:\"STENCIL_REF\",2968:\"STENCIL_WRITEMASK\",2978:\"VIEWPORT\",3024:\"DITHER\",3042:\"BLEND\",3088:\"SCISSOR_BOX\",3089:\"SCISSOR_TEST\",3106:\"COLOR_CLEAR_VALUE\",3107:\"COLOR_WRITEMASK\",3317:\"UNPACK_ALIGNMENT\",3333:\"PACK_ALIGNMENT\",3379:\"MAX_TEXTURE_SIZE\",3386:\"MAX_VIEWPORT_DIMS\",3408:\"SUBPIXEL_BITS\",3410:\"RED_BITS\",3411:\"GREEN_BITS\",3412:\"BLUE_BITS\",3413:\"ALPHA_BITS\",3414:\"DEPTH_BITS\",3415:\"STENCIL_BITS\",3553:\"TEXTURE_2D\",4352:\"DONT_CARE\",4353:\"FASTEST\",4354:\"NICEST\",5120:\"BYTE\",5121:\"UNSIGNED_BYTE\",5122:\"SHORT\",5123:\"UNSIGNED_SHORT\",5124:\"INT\",5125:\"UNSIGNED_INT\",5126:\"FLOAT\",5386:\"INVERT\",5890:\"TEXTURE\",6401:\"STENCIL_INDEX\",6402:\"DEPTH_COMPONENT\",6406:\"ALPHA\",6407:\"RGB\",6408:\"RGBA\",6409:\"LUMINANCE\",6410:\"LUMINANCE_ALPHA\",7680:\"KEEP\",7681:\"REPLACE\",7682:\"INCR\",7683:\"DECR\",7936:\"VENDOR\",7937:\"RENDERER\",7938:\"VERSION\",9728:\"NEAREST\",9729:\"LINEAR\",9984:\"NEAREST_MIPMAP_NEAREST\",9985:\"LINEAR_MIPMAP_NEAREST\",9986:\"NEAREST_MIPMAP_LINEAR\",9987:\"LINEAR_MIPMAP_LINEAR\",10240:\"TEXTURE_MAG_FILTER\",10241:\"TEXTURE_MIN_FILTER\",10242:\"TEXTURE_WRAP_S\",10243:\"TEXTURE_WRAP_T\",10497:\"REPEAT\",10752:\"POLYGON_OFFSET_UNITS\",16384:\"COLOR_BUFFER_BIT\",32769:\"CONSTANT_COLOR\",32770:\"ONE_MINUS_CONSTANT_COLOR\",32771:\"CONSTANT_ALPHA\",32772:\"ONE_MINUS_CONSTANT_ALPHA\",32773:\"BLEND_COLOR\",32774:\"FUNC_ADD\",32777:\"BLEND_EQUATION_RGB\",32778:\"FUNC_SUBTRACT\",32779:\"FUNC_REVERSE_SUBTRACT\",32819:\"UNSIGNED_SHORT_4_4_4_4\",32820:\"UNSIGNED_SHORT_5_5_5_1\",32823:\"POLYGON_OFFSET_FILL\",32824:\"POLYGON_OFFSET_FACTOR\",32854:\"RGBA4\",32855:\"RGB5_A1\",32873:\"TEXTURE_BINDING_2D\",32926:\"SAMPLE_ALPHA_TO_COVERAGE\",32928:\"SAMPLE_COVERAGE\",32936:\"SAMPLE_BUFFERS\",32937:\"SAMPLES\",32938:\"SAMPLE_COVERAGE_VALUE\",32939:\"SAMPLE_COVERAGE_INVERT\",32968:\"BLEND_DST_RGB\",32969:\"BLEND_SRC_RGB\",32970:\"BLEND_DST_ALPHA\",32971:\"BLEND_SRC_ALPHA\",33071:\"CLAMP_TO_EDGE\",33170:\"GENERATE_MIPMAP_HINT\",33189:\"DEPTH_COMPONENT16\",33306:\"DEPTH_STENCIL_ATTACHMENT\",33635:\"UNSIGNED_SHORT_5_6_5\",33648:\"MIRRORED_REPEAT\",33901:\"ALIASED_POINT_SIZE_RANGE\",33902:\"ALIASED_LINE_WIDTH_RANGE\",33984:\"TEXTURE0\",33985:\"TEXTURE1\",33986:\"TEXTURE2\",33987:\"TEXTURE3\",33988:\"TEXTURE4\",33989:\"TEXTURE5\",33990:\"TEXTURE6\",33991:\"TEXTURE7\",33992:\"TEXTURE8\",33993:\"TEXTURE9\",33994:\"TEXTURE10\",33995:\"TEXTURE11\",33996:\"TEXTURE12\",33997:\"TEXTURE13\",33998:\"TEXTURE14\",33999:\"TEXTURE15\",34000:\"TEXTURE16\",34001:\"TEXTURE17\",34002:\"TEXTURE18\",34003:\"TEXTURE19\",34004:\"TEXTURE20\",34005:\"TEXTURE21\",34006:\"TEXTURE22\",34007:\"TEXTURE23\",34008:\"TEXTURE24\",34009:\"TEXTURE25\",34010:\"TEXTURE26\",34011:\"TEXTURE27\",34012:\"TEXTURE28\",34013:\"TEXTURE29\",34014:\"TEXTURE30\",34015:\"TEXTURE31\",34016:\"ACTIVE_TEXTURE\",34024:\"MAX_RENDERBUFFER_SIZE\",34041:\"DEPTH_STENCIL\",34055:\"INCR_WRAP\",34056:\"DECR_WRAP\",34067:\"TEXTURE_CUBE_MAP\",34068:\"TEXTURE_BINDING_CUBE_MAP\",34069:\"TEXTURE_CUBE_MAP_POSITIVE_X\",34070:\"TEXTURE_CUBE_MAP_NEGATIVE_X\",34071:\"TEXTURE_CUBE_MAP_POSITIVE_Y\",34072:\"TEXTURE_CUBE_MAP_NEGATIVE_Y\",34073:\"TEXTURE_CUBE_MAP_POSITIVE_Z\",34074:\"TEXTURE_CUBE_MAP_NEGATIVE_Z\",34076:\"MAX_CUBE_MAP_TEXTURE_SIZE\",34338:\"VERTEX_ATTRIB_ARRAY_ENABLED\",34339:\"VERTEX_ATTRIB_ARRAY_SIZE\",34340:\"VERTEX_ATTRIB_ARRAY_STRIDE\",34341:\"VERTEX_ATTRIB_ARRAY_TYPE\",34342:\"CURRENT_VERTEX_ATTRIB\",34373:\"VERTEX_ATTRIB_ARRAY_POINTER\",34466:\"NUM_COMPRESSED_TEXTURE_FORMATS\",34467:\"COMPRESSED_TEXTURE_FORMATS\",34660:\"BUFFER_SIZE\",34661:\"BUFFER_USAGE\",34816:\"STENCIL_BACK_FUNC\",34817:\"STENCIL_BACK_FAIL\",34818:\"STENCIL_BACK_PASS_DEPTH_FAIL\",34819:\"STENCIL_BACK_PASS_DEPTH_PASS\",34877:\"BLEND_EQUATION_ALPHA\",34921:\"MAX_VERTEX_ATTRIBS\",34922:\"VERTEX_ATTRIB_ARRAY_NORMALIZED\",34930:\"MAX_TEXTURE_IMAGE_UNITS\",34962:\"ARRAY_BUFFER\",34963:\"ELEMENT_ARRAY_BUFFER\",34964:\"ARRAY_BUFFER_BINDING\",34965:\"ELEMENT_ARRAY_BUFFER_BINDING\",34975:\"VERTEX_ATTRIB_ARRAY_BUFFER_BINDING\",35040:\"STREAM_DRAW\",35044:\"STATIC_DRAW\",35048:\"DYNAMIC_DRAW\",35632:\"FRAGMENT_SHADER\",35633:\"VERTEX_SHADER\",35660:\"MAX_VERTEX_TEXTURE_IMAGE_UNITS\",35661:\"MAX_COMBINED_TEXTURE_IMAGE_UNITS\",35663:\"SHADER_TYPE\",35664:\"FLOAT_VEC2\",35665:\"FLOAT_VEC3\",35666:\"FLOAT_VEC4\",35667:\"INT_VEC2\",35668:\"INT_VEC3\",35669:\"INT_VEC4\",35670:\"BOOL\",35671:\"BOOL_VEC2\",35672:\"BOOL_VEC3\",35673:\"BOOL_VEC4\",35674:\"FLOAT_MAT2\",35675:\"FLOAT_MAT3\",35676:\"FLOAT_MAT4\",35678:\"SAMPLER_2D\",35680:\"SAMPLER_CUBE\",35712:\"DELETE_STATUS\",35713:\"COMPILE_STATUS\",35714:\"LINK_STATUS\",35715:\"VALIDATE_STATUS\",35716:\"INFO_LOG_LENGTH\",35717:\"ATTACHED_SHADERS\",35718:\"ACTIVE_UNIFORMS\",35719:\"ACTIVE_UNIFORM_MAX_LENGTH\",35720:\"SHADER_SOURCE_LENGTH\",35721:\"ACTIVE_ATTRIBUTES\",35722:\"ACTIVE_ATTRIBUTE_MAX_LENGTH\",35724:\"SHADING_LANGUAGE_VERSION\",35725:\"CURRENT_PROGRAM\",36003:\"STENCIL_BACK_REF\",36004:\"STENCIL_BACK_VALUE_MASK\",36005:\"STENCIL_BACK_WRITEMASK\",36006:\"FRAMEBUFFER_BINDING\",36007:\"RENDERBUFFER_BINDING\",36048:\"FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE\",36049:\"FRAMEBUFFER_ATTACHMENT_OBJECT_NAME\",36050:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL\",36051:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE\",36053:\"FRAMEBUFFER_COMPLETE\",36054:\"FRAMEBUFFER_INCOMPLETE_ATTACHMENT\",36055:\"FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT\",36057:\"FRAMEBUFFER_INCOMPLETE_DIMENSIONS\",36061:\"FRAMEBUFFER_UNSUPPORTED\",36064:\"COLOR_ATTACHMENT0\",36096:\"DEPTH_ATTACHMENT\",36128:\"STENCIL_ATTACHMENT\",36160:\"FRAMEBUFFER\",36161:\"RENDERBUFFER\",36162:\"RENDERBUFFER_WIDTH\",36163:\"RENDERBUFFER_HEIGHT\",36164:\"RENDERBUFFER_INTERNAL_FORMAT\",36168:\"STENCIL_INDEX8\",36176:\"RENDERBUFFER_RED_SIZE\",36177:\"RENDERBUFFER_GREEN_SIZE\",36178:\"RENDERBUFFER_BLUE_SIZE\",36179:\"RENDERBUFFER_ALPHA_SIZE\",36180:\"RENDERBUFFER_DEPTH_SIZE\",36181:\"RENDERBUFFER_STENCIL_SIZE\",36194:\"RGB565\",36336:\"LOW_FLOAT\",36337:\"MEDIUM_FLOAT\",36338:\"HIGH_FLOAT\",36339:\"LOW_INT\",36340:\"MEDIUM_INT\",36341:\"HIGH_INT\",36346:\"SHADER_COMPILER\",36347:\"MAX_VERTEX_UNIFORM_VECTORS\",36348:\"MAX_VARYING_VECTORS\",36349:\"MAX_FRAGMENT_UNIFORM_VECTORS\",37440:\"UNPACK_FLIP_Y_WEBGL\",37441:\"UNPACK_PREMULTIPLY_ALPHA_WEBGL\",37442:\"CONTEXT_LOST_WEBGL\",37443:\"UNPACK_COLORSPACE_CONVERSION_WEBGL\",37444:\"BROWSER_DEFAULT_WEBGL\"}},{}],246:[function(t,e,r){var n=t(\"./1.0/numbers\");e.exports=function(t){return n[t]}},{\"./1.0/numbers\":245}],247:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),o=i(e,[{buffer:r,type:e.FLOAT,size:3,offset:0,stride:40},{buffer:r,type:e.FLOAT,size:4,offset:12,stride:40},{buffer:r,type:e.FLOAT,size:3,offset:28,stride:40}]),l=a(e);l.attributes.position.location=0,l.attributes.color.location=1,l.attributes.offset.location=2;var c=new s(e,r,o,l);return c.update(t),c};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\"),o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.shader=n,this.buffer=e,this.vao=r,this.pixelRatio=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lineWidth=[1,1,1],this.capSize=[10,10,10],this.lineCount=[0,0,0],this.lineOffset=[0,0,0],this.opacity=1,this.hasAlpha=!1}var l=s.prototype;function c(t,e){for(var r=0;r<3;++r)t[0][r]=Math.min(t[0][r],e[r]),t[1][r]=Math.max(t[1][r],e[r])}l.isOpaque=function(){return!this.hasAlpha},l.isTransparent=function(){return this.hasAlpha},l.drawTransparent=l.draw=function(t){var e=this.gl,r=this.shader.uniforms;this.shader.bind();var n=r.view=t.view||o,i=r.projection=t.projection||o;r.model=t.model||o,r.clipBounds=this.clipBounds,r.opacity=this.opacity;var a=n[12],s=n[13],l=n[14],c=n[15],u=(t._ortho||!1?2:1)*this.pixelRatio*(i[3]*a+i[7]*s+i[11]*l+i[15]*c)/e.drawingBufferHeight;this.vao.bind();for(var h=0;h<3;++h)e.lineWidth(this.lineWidth[h]*this.pixelRatio),r.capSize=this.capSize[h]*u,this.lineCount[h]&&e.drawArrays(e.LINES,this.lineOffset[h],this.lineCount[h]);this.vao.unbind()};var u=function(){for(var t=new Array(3),e=0;e<3;++e){for(var r=[],n=1;n<=2;++n)for(var i=-1;i<=1;i+=2){var a=[0,0,0];a[(n+e)%3]=i,r.push(a)}t[e]=r}return t}();function h(t,e,r,n){for(var i=u[n],a=0;a<i.length;++a){var o=i[a];t.push(e[0],e[1],e[2],r[0],r[1],r[2],r[3],o[0],o[1],o[2])}return i.length}l.update=function(t){\"lineWidth\"in(t=t||{})&&(this.lineWidth=t.lineWidth,Array.isArray(this.lineWidth)||(this.lineWidth=[this.lineWidth,this.lineWidth,this.lineWidth])),\"capSize\"in t&&(this.capSize=t.capSize,Array.isArray(this.capSize)||(this.capSize=[this.capSize,this.capSize,this.capSize])),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var e=t.color||[[0,0,0],[0,0,0],[0,0,0]],r=t.position,n=t.error;if(Array.isArray(e[0])||(e=[e,e,e]),r&&n){var i=[],a=r.length,o=0;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.lineCount=[0,0,0];for(var s=0;s<3;++s){this.lineOffset[s]=o;t:for(var l=0;l<a;++l){for(var u=r[l],f=0;f<3;++f)if(isNaN(u[f])||!isFinite(u[f]))continue t;var p=n[l],d=e[s];if(Array.isArray(d[0])&&(d=e[l]),3===d.length?d=[d[0],d[1],d[2],1]:4===d.length&&(d=[d[0],d[1],d[2],d[3]],!this.hasAlpha&&d[3]<1&&(this.hasAlpha=!0)),!isNaN(p[0][s])&&!isNaN(p[1][s])){var g;if(p[0][s]<0)(g=u.slice())[s]+=p[0][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+h(i,g,d,s);if(p[1][s]>0)(g=u.slice())[s]+=p[1][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+h(i,g,d,s)}}this.lineCount[s]=o-this.lineOffset[s]}this.buffer.update(i)}},l.dispose=function(){this.shader.dispose(),this.buffer.dispose(),this.vao.dispose()}},{\"./shaders/index\":248,\"gl-buffer\":241,\"gl-vao\":327}],248:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, offset;\\nattribute vec4 color;\\nuniform mat4 model, view, projection;\\nuniform float capSize;\\nvarying vec4 fragColor;\\nvarying vec3 fragPosition;\\n\\nvoid main() {\\n  vec4 worldPosition  = model * vec4(position, 1.0);\\n  worldPosition       = (worldPosition / worldPosition.w) + vec4(capSize * offset, 0.0);\\n  gl_Position         = projection * view * worldPosition;\\n  fragColor           = color;\\n  fragPosition        = position;\\n}\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float opacity;\\nvarying vec3 fragPosition;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], fragPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  gl_FragColor = opacity * fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"offset\",type:\"vec3\"}])}},{\"gl-shader\":301,glslify:409}],249:[function(t,e,r){\"use strict\";var n=t(\"gl-texture2d\");e.exports=function(t,e,r,n){i||(i=t.FRAMEBUFFER_UNSUPPORTED,a=t.FRAMEBUFFER_INCOMPLETE_ATTACHMENT,o=t.FRAMEBUFFER_INCOMPLETE_DIMENSIONS,s=t.FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT);var c=t.getExtension(\"WEBGL_draw_buffers\");!l&&c&&function(t,e){var r=t.getParameter(e.MAX_COLOR_ATTACHMENTS_WEBGL);l=new Array(r+1);for(var n=0;n<=r;++n){for(var i=new Array(r),a=0;a<n;++a)i[a]=t.COLOR_ATTACHMENT0+a;for(var a=n;a<r;++a)i[a]=t.NONE;l[n]=i}}(t,c);Array.isArray(e)&&(n=r,r=0|e[1],e=0|e[0]);if(\"number\"!=typeof e)throw new Error(\"gl-fbo: Missing shape parameter\");var u=t.getParameter(t.MAX_RENDERBUFFER_SIZE);if(e<0||e>u||r<0||r>u)throw new Error(\"gl-fbo: Parameters are too large for FBO\");var h=1;if(\"color\"in(n=n||{})){if((h=Math.max(0|n.color,0))<0)throw new Error(\"gl-fbo: Must specify a nonnegative number of colors\");if(h>1){if(!c)throw new Error(\"gl-fbo: Multiple draw buffer extension not supported\");if(h>t.getParameter(c.MAX_COLOR_ATTACHMENTS_WEBGL))throw new Error(\"gl-fbo: Context does not support \"+h+\" draw buffers\")}}var f=t.UNSIGNED_BYTE,p=t.getExtension(\"OES_texture_float\");if(n.float&&h>0){if(!p)throw new Error(\"gl-fbo: Context does not support floating point textures\");f=t.FLOAT}else n.preferFloat&&h>0&&p&&(f=t.FLOAT);var g=!0;\"depth\"in n&&(g=!!n.depth);var v=!1;\"stencil\"in n&&(v=!!n.stencil);return new d(t,e,r,f,h,g,v,c)};var i,a,o,s,l=null;function c(t){return[t.getParameter(t.FRAMEBUFFER_BINDING),t.getParameter(t.RENDERBUFFER_BINDING),t.getParameter(t.TEXTURE_BINDING_2D)]}function u(t,e){t.bindFramebuffer(t.FRAMEBUFFER,e[0]),t.bindRenderbuffer(t.RENDERBUFFER,e[1]),t.bindTexture(t.TEXTURE_2D,e[2])}function h(t){switch(t){case i:throw new Error(\"gl-fbo: Framebuffer unsupported\");case a:throw new Error(\"gl-fbo: Framebuffer incomplete attachment\");case o:throw new Error(\"gl-fbo: Framebuffer incomplete dimensions\");case s:throw new Error(\"gl-fbo: Framebuffer incomplete missing attachment\");default:throw new Error(\"gl-fbo: Framebuffer failed for unspecified reason\")}}function f(t,e,r,i,a,o){if(!i)return null;var s=n(t,e,r,a,i);return s.magFilter=t.NEAREST,s.minFilter=t.NEAREST,s.mipSamples=1,s.bind(),t.framebufferTexture2D(t.FRAMEBUFFER,o,t.TEXTURE_2D,s.handle,0),s}function p(t,e,r,n,i){var a=t.createRenderbuffer();return t.bindRenderbuffer(t.RENDERBUFFER,a),t.renderbufferStorage(t.RENDERBUFFER,n,e,r),t.framebufferRenderbuffer(t.FRAMEBUFFER,i,t.RENDERBUFFER,a),a}function d(t,e,r,n,i,a,o,s){this.gl=t,this._shape=[0|e,0|r],this._destroyed=!1,this._ext=s,this.color=new Array(i);for(var d=0;d<i;++d)this.color[d]=null;this._color_rb=null,this.depth=null,this._depth_rb=null,this._colorType=n,this._useDepth=a,this._useStencil=o;var g=this,v=[0|e,0|r];Object.defineProperties(v,{0:{get:function(){return g._shape[0]},set:function(t){return g.width=t}},1:{get:function(){return g._shape[1]},set:function(t){return g.height=t}}}),this._shapeVector=v,function(t){var e=c(t.gl),r=t.gl,n=t.handle=r.createFramebuffer(),i=t._shape[0],a=t._shape[1],o=t.color.length,s=t._ext,d=t._useStencil,g=t._useDepth,v=t._colorType;r.bindFramebuffer(r.FRAMEBUFFER,n);for(var m=0;m<o;++m)t.color[m]=f(r,i,a,v,r.RGBA,r.COLOR_ATTACHMENT0+m);0===o?(t._color_rb=p(r,i,a,r.RGBA4,r.COLOR_ATTACHMENT0),s&&s.drawBuffersWEBGL(l[0])):o>1&&s.drawBuffersWEBGL(l[o]);var y=r.getExtension(\"WEBGL_depth_texture\");y?d?t.depth=f(r,i,a,y.UNSIGNED_INT_24_8_WEBGL,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g&&(t.depth=f(r,i,a,r.UNSIGNED_SHORT,r.DEPTH_COMPONENT,r.DEPTH_ATTACHMENT)):g&&d?t._depth_rb=p(r,i,a,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g?t._depth_rb=p(r,i,a,r.DEPTH_COMPONENT16,r.DEPTH_ATTACHMENT):d&&(t._depth_rb=p(r,i,a,r.STENCIL_INDEX,r.STENCIL_ATTACHMENT));var x=r.checkFramebufferStatus(r.FRAMEBUFFER);if(x!==r.FRAMEBUFFER_COMPLETE){for(t._destroyed=!0,r.bindFramebuffer(r.FRAMEBUFFER,null),r.deleteFramebuffer(t.handle),t.handle=null,t.depth&&(t.depth.dispose(),t.depth=null),t._depth_rb&&(r.deleteRenderbuffer(t._depth_rb),t._depth_rb=null),m=0;m<t.color.length;++m)t.color[m].dispose(),t.color[m]=null;t._color_rb&&(r.deleteRenderbuffer(t._color_rb),t._color_rb=null),u(r,e),h(x)}u(r,e)}(this)}var g=d.prototype;function v(t,e,r){if(t._destroyed)throw new Error(\"gl-fbo: Can't resize destroyed FBO\");if(t._shape[0]!==e||t._shape[1]!==r){var n=t.gl,i=n.getParameter(n.MAX_RENDERBUFFER_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-fbo: Can't resize FBO, invalid dimensions\");t._shape[0]=e,t._shape[1]=r;for(var a=c(n),o=0;o<t.color.length;++o)t.color[o].shape=t._shape;t._color_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._color_rb),n.renderbufferStorage(n.RENDERBUFFER,n.RGBA4,t._shape[0],t._shape[1])),t.depth&&(t.depth.shape=t._shape),t._depth_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._depth_rb),t._useDepth&&t._useStencil?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_STENCIL,t._shape[0],t._shape[1]):t._useDepth?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_COMPONENT16,t._shape[0],t._shape[1]):t._useStencil&&n.renderbufferStorage(n.RENDERBUFFER,n.STENCIL_INDEX,t._shape[0],t._shape[1])),n.bindFramebuffer(n.FRAMEBUFFER,t.handle);var s=n.checkFramebufferStatus(n.FRAMEBUFFER);s!==n.FRAMEBUFFER_COMPLETE&&(t.dispose(),u(n,a),h(s)),u(n,a)}}Object.defineProperties(g,{shape:{get:function(){return this._destroyed?[0,0]:this._shapeVector},set:function(t){if(Array.isArray(t)||(t=[0|t,0|t]),2!==t.length)throw new Error(\"gl-fbo: Shape vector must be length 2\");var e=0|t[0],r=0|t[1];return v(this,e,r),[e,r]},enumerable:!1},width:{get:function(){return this._destroyed?0:this._shape[0]},set:function(t){return v(this,t|=0,this._shape[1]),t},enumerable:!1},height:{get:function(){return this._destroyed?0:this._shape[1]},set:function(t){return t|=0,v(this,this._shape[0],t),t},enumerable:!1}}),g.bind=function(){if(!this._destroyed){var t=this.gl;t.bindFramebuffer(t.FRAMEBUFFER,this.handle),t.viewport(0,0,this._shape[0],this._shape[1])}},g.dispose=function(){if(!this._destroyed){this._destroyed=!0;var t=this.gl;t.deleteFramebuffer(this.handle),this.handle=null,this.depth&&(this.depth.dispose(),this.depth=null),this._depth_rb&&(t.deleteRenderbuffer(this._depth_rb),this._depth_rb=null);for(var e=0;e<this.color.length;++e)this.color[e].dispose(),this.color[e]=null;this._color_rb&&(t.deleteRenderbuffer(this._color_rb),this._color_rb=null)}}},{\"gl-texture2d\":322}],250:[function(t,e,r){var n=t(\"sprintf-js\").sprintf,i=t(\"gl-constants/lookup\"),a=t(\"glsl-shader-name\"),o=t(\"add-line-numbers\");e.exports=function(t,e,r){\"use strict\";var s=a(e)||\"of unknown name (see npm glsl-shader-name)\",l=\"unknown type\";void 0!==r&&(l=r===i.FRAGMENT_SHADER?\"fragment\":\"vertex\");for(var c=n(\"Error compiling %s shader %s:\\n\",l,s),u=n(\"%s%s\",c,t),h=t.split(\"\\n\"),f={},p=0;p<h.length;p++){var d=h[p];if(\"\"!==d&&\"\\0\"!==d){var g=parseInt(d.split(\":\")[2]);if(isNaN(g))throw new Error(n(\"Could not parse error: %s\",d));f[g]=d}}for(var v=o(e).split(\"\\n\"),p=0;p<v.length;p++)if(f[p+3]||f[p+2]||f[p+1]){var m=v[p];if(c+=m+\"\\n\",f[p+1]){var y=f[p+1];y=y.substr(y.split(\":\",3).join(\":\").length+1).trim(),c+=n(\"^^^ %s\\n\\n\",y)}}return{long:c.trim(),short:u.trim()}}},{\"add-line-numbers\":61,\"gl-constants/lookup\":246,\"glsl-shader-name\":401,\"sprintf-js\":528}],251:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.gl,n=o(r,l.vertex,l.fragment),i=o(r,l.pickVertex,l.pickFragment),a=s(r),u=s(r),h=s(r),f=s(r),p=new c(t,n,i,a,u,h,f);return p.update(e),t.addObject(p),p};var n=t(\"binary-search-bounds\"),i=t(\"iota-array\"),a=t(\"typedarray-pool\"),o=t(\"gl-shader\"),s=t(\"gl-buffer\"),l=t(\"./lib/shaders\");function c(t,e,r,n,i,a,o){this.plot=t,this.shader=e,this.pickShader=r,this.positionBuffer=n,this.weightBuffer=i,this.colorBuffer=a,this.idBuffer=o,this.xData=[],this.yData=[],this.shape=[0,0],this.bounds=[1/0,1/0,-1/0,-1/0],this.pickOffset=0}var u,h=c.prototype,f=[0,0,1,0,0,1,1,0,1,1,0,1];h.draw=(u=[1,0,0,0,1,0,0,0,1],function(){var t=this.plot,e=this.shader,r=this.bounds,n=this.numVertices;if(!(n<=0)){var i=t.gl,a=t.dataBox,o=r[2]-r[0],s=r[3]-r[1],l=a[2]-a[0],c=a[3]-a[1];u[0]=2*o/l,u[4]=2*s/c,u[6]=2*(r[0]-a[0])/l-1,u[7]=2*(r[1]-a[1])/c-1,e.bind();var h=e.uniforms;h.viewTransform=u,h.shape=this.shape;var f=e.attributes;this.positionBuffer.bind(),f.position.pointer(),this.weightBuffer.bind(),f.weight.pointer(i.UNSIGNED_BYTE,!1),this.colorBuffer.bind(),f.color.pointer(i.UNSIGNED_BYTE,!0),i.drawArrays(i.TRIANGLES,0,n)}}),h.drawPick=function(){var t=[1,0,0,0,1,0,0,0,1],e=[0,0,0,0];return function(r){var n=this.plot,i=this.pickShader,a=this.bounds,o=this.numVertices;if(!(o<=0)){var s=n.gl,l=n.dataBox,c=a[2]-a[0],u=a[3]-a[1],h=l[2]-l[0],f=l[3]-l[1];t[0]=2*c/h,t[4]=2*u/f,t[6]=2*(a[0]-l[0])/h-1,t[7]=2*(a[1]-l[1])/f-1;for(var p=0;p<4;++p)e[p]=r>>8*p&255;this.pickOffset=r,i.bind();var d=i.uniforms;d.viewTransform=t,d.pickOffset=e,d.shape=this.shape;var g=i.attributes;return this.positionBuffer.bind(),g.position.pointer(),this.weightBuffer.bind(),g.weight.pointer(s.UNSIGNED_BYTE,!1),this.idBuffer.bind(),g.pickId.pointer(s.UNSIGNED_BYTE,!1),s.drawArrays(s.TRIANGLES,0,o),r+this.shape[0]*this.shape[1]}}}(),h.pick=function(t,e,r){var n=this.pickOffset,i=this.shape[0]*this.shape[1];if(r<n||r>=n+i)return null;var a=r-n,o=this.xData,s=this.yData;return{object:this,pointId:a,dataCoord:[o[a%this.shape[0]],s[a/this.shape[0]|0]]}},h.update=function(t){var e=(t=t||{}).shape||[0,0],r=t.x||i(e[0]),o=t.y||i(e[1]),s=t.z||new Float32Array(e[0]*e[1]);this.xData=r,this.yData=o;var l=t.colorLevels||[0],c=t.colorValues||[0,0,0,1],u=l.length,h=this.bounds,p=h[0]=r[0],d=h[1]=o[0],g=1/((h[2]=r[r.length-1])-p),v=1/((h[3]=o[o.length-1])-d),m=e[0],y=e[1];this.shape=[m,y];var x=(m-1)*(y-1)*(f.length>>>1);this.numVertices=x;for(var b=a.mallocUint8(4*x),_=a.mallocFloat32(2*x),w=a.mallocUint8(2*x),k=a.mallocUint32(x),T=0,A=0;A<y-1;++A)for(var M=v*(o[A]-d),S=v*(o[A+1]-d),E=0;E<m-1;++E)for(var C=g*(r[E]-p),L=g*(r[E+1]-p),P=0;P<f.length;P+=2){var O,z,I,D,R=f[P],F=f[P+1],B=s[(A+F)*m+(E+R)],N=n.le(l,B);if(N<0)O=c[0],z=c[1],I=c[2],D=c[3];else if(N===u-1)O=c[4*u-4],z=c[4*u-3],I=c[4*u-2],D=c[4*u-1];else{var j=(B-l[N])/(l[N+1]-l[N]),U=1-j,V=4*N,q=4*(N+1);O=U*c[V]+j*c[q],z=U*c[V+1]+j*c[q+1],I=U*c[V+2]+j*c[q+2],D=U*c[V+3]+j*c[q+3]}b[4*T]=255*O,b[4*T+1]=255*z,b[4*T+2]=255*I,b[4*T+3]=255*D,_[2*T]=.5*C+.5*L,_[2*T+1]=.5*M+.5*S,w[2*T]=R,w[2*T+1]=F,k[T]=A*m+E,T+=1}this.positionBuffer.update(_),this.weightBuffer.update(w),this.colorBuffer.update(b),this.idBuffer.update(k),a.free(_),a.free(b),a.free(w),a.free(k)},h.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.positionBuffer.dispose(),this.weightBuffer.dispose(),this.colorBuffer.dispose(),this.idBuffer.dispose(),this.plot.removeObject(this)}},{\"./lib/shaders\":252,\"binary-search-bounds\":253,\"gl-buffer\":241,\"gl-shader\":301,\"iota-array\":416,\"typedarray-pool\":545}],252:[function(t,e,r){\"use strict\";var n=t(\"glslify\");e.exports={fragment:n([\"precision lowp float;\\n#define GLSLIFY 1\\nvarying vec4 fragColor;\\nvoid main() {\\n  gl_FragColor = vec4(fragColor.rgb * fragColor.a, fragColor.a);\\n}\\n\"]),vertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 color;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  fragColor = color;\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"]),pickFragment:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nuniform vec2 shape;\\nuniform vec4 pickOffset;\\n\\nvoid main() {\\n  vec2 d = step(.5, vWeight);\\n  vec4 id = fragId + pickOffset;\\n  id.x += d.x + d.y*shape.x;\\n\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  gl_FragColor = id/255.;\\n}\\n\"]),pickVertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nvoid main() {\\n  vWeight = weight;\\n\\n  fragId = pickId;\\n\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"])}},{glslify:409}],253:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],254:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, nextPosition;\\nattribute float arcLength, lineWidth;\\nattribute vec4 color;\\n\\nuniform vec2 screenShape;\\nuniform float pixelRatio;\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 fragColor;\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  vec4 startPoint = project(position);\\n  vec4 endPoint   = project(nextPosition);\\n\\n  vec2 A = startPoint.xy / startPoint.w;\\n  vec2 B =   endPoint.xy /   endPoint.w;\\n\\n  float clipAngle = atan(\\n    (B.y - A.y) * screenShape.y,\\n    (B.x - A.x) * screenShape.x\\n  );\\n\\n  vec2 offset = 0.5 * pixelRatio * lineWidth * vec2(\\n    sin(clipAngle),\\n    -cos(clipAngle)\\n  ) / screenShape;\\n\\n  gl_Position = vec4(startPoint.xy + startPoint.w * offset, startPoint.zw);\\n\\n  worldPosition = position;\\n  pixelArcLength = arcLength;\\n  fragColor = color;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3      clipBounds[2];\\nuniform sampler2D dashTexture;\\nuniform float     dashScale;\\nuniform float     opacity;\\n\\nvarying vec3    worldPosition;\\nvarying float   pixelArcLength;\\nvarying vec4    fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], worldPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  float dashWeight = texture2D(dashTexture, vec2(dashScale * pixelArcLength, 0)).r;\\n  if(dashWeight < 0.5) {\\n    discard;\\n  }\\n  gl_FragColor = fragColor * opacity;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\n#define FLOAT_MAX  1.70141184e38\\n#define FLOAT_MIN  1.17549435e-38\\n\\nlowp vec4 encode_float_1540259130(highp float v) {\\n  highp float av = abs(v);\\n\\n  //Handle special cases\\n  if(av < FLOAT_MIN) {\\n    return vec4(0.0, 0.0, 0.0, 0.0);\\n  } else if(v > FLOAT_MAX) {\\n    return vec4(127.0, 128.0, 0.0, 0.0) / 255.0;\\n  } else if(v < -FLOAT_MAX) {\\n    return vec4(255.0, 128.0, 0.0, 0.0) / 255.0;\\n  }\\n\\n  highp vec4 c = vec4(0,0,0,0);\\n\\n  //Compute exponent and mantissa\\n  highp float e = floor(log2(av));\\n  highp float m = av * pow(2.0, -e) - 1.0;\\n  \\n  //Unpack mantissa\\n  c[1] = floor(128.0 * m);\\n  m -= c[1] / 128.0;\\n  c[2] = floor(32768.0 * m);\\n  m -= c[2] / 32768.0;\\n  c[3] = floor(8388608.0 * m);\\n  \\n  //Unpack exponent\\n  highp float ebias = e + 127.0;\\n  c[0] = floor(ebias / 2.0);\\n  ebias -= c[0] * 2.0;\\n  c[1] += floor(ebias) * 128.0; \\n\\n  //Unpack sign bit\\n  c[0] += 128.0 * step(0.0, -v);\\n\\n  //Scale back to range\\n  return c / 255.0;\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform float pickId;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], worldPosition)) discard;\\n\\n  gl_FragColor = vec4(pickId/255.0, encode_float_1540259130(pixelArcLength).xyz);\\n}\"]),l=[{name:\"position\",type:\"vec3\"},{name:\"nextPosition\",type:\"vec3\"},{name:\"arcLength\",type:\"float\"},{name:\"lineWidth\",type:\"float\"},{name:\"color\",type:\"vec4\"}];r.createShader=function(t){return i(t,a,o,null,l)},r.createPickShader=function(t){return i(t,a,s,null,l)}},{\"gl-shader\":301,glslify:409}],255:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl||t.scene&&t.scene.gl,r=u(e);r.attributes.position.location=0,r.attributes.nextPosition.location=1,r.attributes.arcLength.location=2,r.attributes.lineWidth.location=3,r.attributes.color.location=4;var o=h(e);o.attributes.position.location=0,o.attributes.nextPosition.location=1,o.attributes.arcLength.location=2,o.attributes.lineWidth.location=3,o.attributes.color.location=4;for(var s=n(e),c=i(e,[{buffer:s,size:3,offset:0,stride:48},{buffer:s,size:3,offset:12,stride:48},{buffer:s,size:1,offset:24,stride:48},{buffer:s,size:1,offset:28,stride:48},{buffer:s,size:4,offset:32,stride:48}]),f=l(new Array(1024),[256,1,4]),p=0;p<1024;++p)f.data[p]=255;var d=a(e,f);d.wrap=e.REPEAT;var g=new v(e,r,o,s,c,d);return g.update(t),g};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"gl-texture2d\"),o=t(\"glsl-read-float\"),s=t(\"binary-search-bounds\"),l=t(\"ndarray\"),c=t(\"./lib/shaders\"),u=c.createShader,h=c.createPickShader,f=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function p(t,e){for(var r=0,n=0;n<3;++n){var i=t[n]-e[n];r+=i*i}return Math.sqrt(r)}function d(t){for(var e=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],r=0;r<3;++r)e[0][r]=Math.max(t[0][r],e[0][r]),e[1][r]=Math.min(t[1][r],e[1][r]);return e}function g(t,e,r,n){this.arcLength=t,this.position=e,this.index=r,this.dataCoordinate=n}function v(t,e,r,n,i,a){this.gl=t,this.shader=e,this.pickShader=r,this.buffer=n,this.vao=i,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.points=[],this.arcLength=[],this.vertexCount=0,this.bounds=[[0,0,0],[0,0,0]],this.pickId=0,this.lineWidth=1,this.texture=a,this.dashScale=1,this.opacity=1,this.hasAlpha=!1,this.dirty=!0,this.pixelRatio=1}var m=v.prototype;m.isTransparent=function(){return this.hasAlpha},m.isOpaque=function(){return!this.hasAlpha},m.pickSlots=1,m.setPickBase=function(t){this.pickId=t},m.drawTransparent=m.draw=function(t){if(this.vertexCount){var e=this.gl,r=this.shader,n=this.vao;r.bind(),r.uniforms={model:t.model||f,view:t.view||f,projection:t.projection||f,clipBounds:d(this.clipBounds),dashTexture:this.texture.bind(),dashScale:this.dashScale/this.arcLength[this.arcLength.length-1],opacity:this.opacity,screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},m.drawPick=function(t){if(this.vertexCount){var e=this.gl,r=this.pickShader,n=this.vao;r.bind(),r.uniforms={model:t.model||f,view:t.view||f,projection:t.projection||f,pickId:this.pickId,clipBounds:d(this.clipBounds),screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},m.update=function(t){var e,r;this.dirty=!0;var n=!!t.connectGaps;\"dashScale\"in t&&(this.dashScale=t.dashScale),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var i=[],a=[],o=[],c=0,u=0,h=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],f=t.position||t.positions;if(f){var d=t.color||t.colors||[0,0,0,1],g=t.lineWidth||1,v=!1;t:for(e=1;e<f.length;++e){var m,y,x,b=f[e-1],_=f[e];for(a.push(c),o.push(b.slice()),r=0;r<3;++r){if(isNaN(b[r])||isNaN(_[r])||!isFinite(b[r])||!isFinite(_[r])){if(!n&&i.length>0){for(var w=0;w<24;++w)i.push(i[i.length-12]);u+=2,v=!0}continue t}h[0][r]=Math.min(h[0][r],b[r],_[r]),h[1][r]=Math.max(h[1][r],b[r],_[r])}Array.isArray(d[0])?(m=d.length>e-1?d[e-1]:d.length>0?d[d.length-1]:[0,0,0,1],y=d.length>e?d[e]:d.length>0?d[d.length-1]:[0,0,0,1]):m=y=d,3===m.length&&(m=[m[0],m[1],m[2],1]),3===y.length&&(y=[y[0],y[1],y[2],1]),!this.hasAlpha&&m[3]<1&&(this.hasAlpha=!0),x=Array.isArray(g)?g.length>e-1?g[e-1]:g.length>0?g[g.length-1]:[0,0,0,1]:g;var k=c;if(c+=p(b,_),v){for(r=0;r<2;++r)i.push(b[0],b[1],b[2],_[0],_[1],_[2],k,x,m[0],m[1],m[2],m[3]);u+=2,v=!1}i.push(b[0],b[1],b[2],_[0],_[1],_[2],k,x,m[0],m[1],m[2],m[3],b[0],b[1],b[2],_[0],_[1],_[2],k,-x,m[0],m[1],m[2],m[3],_[0],_[1],_[2],b[0],b[1],b[2],c,-x,y[0],y[1],y[2],y[3],_[0],_[1],_[2],b[0],b[1],b[2],c,x,y[0],y[1],y[2],y[3]),u+=4}}if(this.buffer.update(i),a.push(c),o.push(f[f.length-1].slice()),this.bounds=h,this.vertexCount=u,this.points=o,this.arcLength=a,\"dashes\"in t){var T=t.dashes.slice();for(T.unshift(0),e=1;e<T.length;++e)T[e]=T[e-1]+T[e];var A=l(new Array(1024),[256,1,4]);for(e=0;e<256;++e){for(r=0;r<4;++r)A.set(e,0,r,0);1&s.le(T,T[T.length-1]*e/255)?A.set(e,0,0,0):A.set(e,0,0,255)}this.texture.setPixels(A)}},m.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()},m.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=o(t.value[0],t.value[1],t.value[2],0),r=s.le(this.arcLength,e);if(r<0)return null;if(r===this.arcLength.length-1)return new g(this.arcLength[this.arcLength.length-1],this.points[this.points.length-1].slice(),r);for(var n=this.points[r],i=this.points[Math.min(r+1,this.points.length-1)],a=(e-this.arcLength[r])/(this.arcLength[r+1]-this.arcLength[r]),l=1-a,c=[0,0,0],u=0;u<3;++u)c[u]=l*n[u]+a*i[u];var h=Math.min(a<.5?r:r+1,this.points.length-1);return new g(e,c,h,this.points[h])}},{\"./lib/shaders\":254,\"binary-search-bounds\":256,\"gl-buffer\":241,\"gl-texture2d\":322,\"gl-vao\":327,\"glsl-read-float\":400,ndarray:450}],256:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],257:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r*a-i*n;return o?(o=1/o,t[0]=a*o,t[1]=-n*o,t[2]=-i*o,t[3]=r*o,t):null}},{}],258:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=u*o-s*c,f=-u*a+s*l,p=c*a-o*l,d=r*h+n*f+i*p;return d?(d=1/d,t[0]=h*d,t[1]=(-u*n+i*c)*d,t[2]=(s*n-i*o)*d,t[3]=f*d,t[4]=(u*r-i*l)*d,t[5]=(-s*r+i*a)*d,t[6]=p*d,t[7]=(-c*r+n*l)*d,t[8]=(o*r-n*a)*d,t):null}},{}],259:[function(t,e,r){e.exports=function(t){var e=new Float32Array(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e}},{}],260:[function(t,e,r){e.exports=function(){var t=new Float32Array(16);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],261:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3],a=t[4],o=t[5],s=t[6],l=t[7],c=t[8],u=t[9],h=t[10],f=t[11],p=t[12],d=t[13],g=t[14],v=t[15];return(e*o-r*a)*(h*v-f*g)-(e*s-n*a)*(u*v-f*d)+(e*l-i*a)*(u*g-h*d)+(r*s-n*o)*(c*v-f*p)-(r*l-i*o)*(c*g-h*p)+(n*l-i*s)*(c*d-u*p)}},{}],262:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r+r,s=n+n,l=i+i,c=r*o,u=n*o,h=n*s,f=i*o,p=i*s,d=i*l,g=a*o,v=a*s,m=a*l;return t[0]=1-h-d,t[1]=u+m,t[2]=f-v,t[3]=0,t[4]=u-m,t[5]=1-c-d,t[6]=p+g,t[7]=0,t[8]=f+v,t[9]=p-g,t[10]=1-c-h,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],263:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=n+n,l=i+i,c=a+a,u=n*s,h=n*l,f=n*c,p=i*l,d=i*c,g=a*c,v=o*s,m=o*l,y=o*c;return t[0]=1-(p+g),t[1]=h+y,t[2]=f-m,t[3]=0,t[4]=h-y,t[5]=1-(u+g),t[6]=d+v,t[7]=0,t[8]=f+m,t[9]=d-v,t[10]=1-(u+p),t[11]=0,t[12]=r[0],t[13]=r[1],t[14]=r[2],t[15]=1,t}},{}],264:[function(t,e,r){e.exports=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],265:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],g=e[13],v=e[14],m=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,k=i*c-a*l,T=u*g-h*d,A=u*v-f*d,M=u*m-p*d,S=h*v-f*g,E=h*m-p*g,C=f*m-p*v,L=y*C-x*E+b*S+_*M-w*A+k*T;if(!L)return null;return L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(i*E-n*C-a*S)*L,t[2]=(g*k-v*w+m*_)*L,t[3]=(f*w-h*k-p*_)*L,t[4]=(l*M-o*C-c*A)*L,t[5]=(r*C-i*M+a*A)*L,t[6]=(v*b-d*k-m*x)*L,t[7]=(u*k-f*b+p*x)*L,t[8]=(o*E-s*M+c*T)*L,t[9]=(n*M-r*E-a*T)*L,t[10]=(d*w-g*b+m*y)*L,t[11]=(h*b-u*w-p*y)*L,t[12]=(s*A-o*S-l*T)*L,t[13]=(r*S-n*A+i*T)*L,t[14]=(g*x-d*_-v*y)*L,t[15]=(u*_-h*x+f*y)*L,t}},{}],266:[function(t,e,r){var n=t(\"./identity\");e.exports=function(t,e,r,i){var a,o,s,l,c,u,h,f,p,d,g=e[0],v=e[1],m=e[2],y=i[0],x=i[1],b=i[2],_=r[0],w=r[1],k=r[2];if(Math.abs(g-_)<1e-6&&Math.abs(v-w)<1e-6&&Math.abs(m-k)<1e-6)return n(t);h=g-_,f=v-w,p=m-k,d=1/Math.sqrt(h*h+f*f+p*p),a=x*(p*=d)-b*(f*=d),o=b*(h*=d)-y*p,s=y*f-x*h,(d=Math.sqrt(a*a+o*o+s*s))?(a*=d=1/d,o*=d,s*=d):(a=0,o=0,s=0);l=f*s-p*o,c=p*a-h*s,u=h*o-f*a,(d=Math.sqrt(l*l+c*c+u*u))?(l*=d=1/d,c*=d,u*=d):(l=0,c=0,u=0);return t[0]=a,t[1]=l,t[2]=h,t[3]=0,t[4]=o,t[5]=c,t[6]=f,t[7]=0,t[8]=s,t[9]=u,t[10]=p,t[11]=0,t[12]=-(a*g+o*v+s*m),t[13]=-(l*g+c*v+u*m),t[14]=-(h*g+f*v+p*m),t[15]=1,t}},{\"./identity\":264}],267:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],g=e[12],v=e[13],m=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*h+w*g,t[1]=x*i+b*l+_*f+w*v,t[2]=x*a+b*c+_*p+w*m,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*h+w*g,t[5]=x*i+b*l+_*f+w*v,t[6]=x*a+b*c+_*p+w*m,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*h+w*g,t[9]=x*i+b*l+_*f+w*v,t[10]=x*a+b*c+_*p+w*m,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*h+w*g,t[13]=x*i+b*l+_*f+w*v,t[14]=x*a+b*c+_*p+w*m,t[15]=x*o+b*u+_*d+w*y,t}},{}],268:[function(t,e,r){e.exports=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t}},{}],269:[function(t,e,r){e.exports=function(t,e,r,n,i){var a=1/Math.tan(e/2),o=1/(n-i);return t[0]=a/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=a,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=(i+n)*o,t[11]=-1,t[12]=0,t[13]=0,t[14]=2*i*n*o,t[15]=0,t}},{}],270:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_,w,k,T,A,M,S,E=n[0],C=n[1],L=n[2],P=Math.sqrt(E*E+C*C+L*L);if(Math.abs(P)<1e-6)return null;E*=P=1/P,C*=P,L*=P,i=Math.sin(r),a=Math.cos(r),o=1-a,s=e[0],l=e[1],c=e[2],u=e[3],h=e[4],f=e[5],p=e[6],d=e[7],g=e[8],v=e[9],m=e[10],y=e[11],x=E*E*o+a,b=C*E*o+L*i,_=L*E*o-C*i,w=E*C*o-L*i,k=C*C*o+a,T=L*C*o+E*i,A=E*L*o+C*i,M=C*L*o-E*i,S=L*L*o+a,t[0]=s*x+h*b+g*_,t[1]=l*x+f*b+v*_,t[2]=c*x+p*b+m*_,t[3]=u*x+d*b+y*_,t[4]=s*w+h*k+g*T,t[5]=l*w+f*k+v*T,t[6]=c*w+p*k+m*T,t[7]=u*w+d*k+y*T,t[8]=s*A+h*M+g*S,t[9]=l*A+f*M+v*S,t[10]=c*A+p*M+m*S,t[11]=u*A+d*M+y*S,e!==t&&(t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t}},{}],271:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+h*n,t[7]=l*i+f*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=h*i-s*n,t[11]=f*i-l*n,t}},{}],272:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[8],u=e[9],h=e[10],f=e[11];e!==t&&(t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i-c*n,t[1]=o*i-u*n,t[2]=s*i-h*n,t[3]=l*i-f*n,t[8]=a*n+c*i,t[9]=o*n+u*i,t[10]=s*n+h*i,t[11]=l*n+f*i,t}},{}],273:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+h*n,t[3]=l*i+f*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=h*i-s*n,t[7]=f*i-l*n,t}},{}],274:[function(t,e,r){e.exports=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},{}],275:[function(t,e,r){e.exports=function(t,e,r){var n,i,a,o,s,l,c,u,h,f,p,d,g=r[0],v=r[1],m=r[2];e===t?(t[12]=e[0]*g+e[4]*v+e[8]*m+e[12],t[13]=e[1]*g+e[5]*v+e[9]*m+e[13],t[14]=e[2]*g+e[6]*v+e[10]*m+e[14],t[15]=e[3]*g+e[7]*v+e[11]*m+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*g+s*v+h*m+e[12],t[13]=i*g+l*v+f*m+e[13],t[14]=a*g+c*v+p*m+e[14],t[15]=o*g+u*v+d*m+e[15]);return t}},{}],276:[function(t,e,r){e.exports=function(t,e){if(t===e){var r=e[1],n=e[2],i=e[3],a=e[6],o=e[7],s=e[11];t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=r,t[6]=e[9],t[7]=e[13],t[8]=n,t[9]=a,t[11]=e[14],t[12]=i,t[13]=o,t[14]=s}else t[0]=e[0],t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=e[1],t[5]=e[5],t[6]=e[9],t[7]=e[13],t[8]=e[2],t[9]=e[6],t[10]=e[10],t[11]=e[14],t[12]=e[3],t[13]=e[7],t[14]=e[11],t[15]=e[15];return t}},{}],277:[function(t,e,r){\"use strict\";e.exports=function(t,e){switch(e.length){case 0:break;case 1:t[0]=1/e[0];break;case 4:n(t,e);break;case 9:i(t,e);break;case 16:a(t,e);break;default:throw new Error(\"currently supports matrices up to 4x4\")}return t};var n=t(\"gl-mat2/invert\"),i=t(\"gl-mat3/invert\"),a=t(\"gl-mat4/invert\")},{\"gl-mat2/invert\":257,\"gl-mat3/invert\":258,\"gl-mat4/invert\":265}],278:[function(t,e,r){\"use strict\";var n=t(\"barycentric\"),i=t(\"polytope-closest-point/lib/closest_point_2d.js\");function a(t,e){for(var r=[0,0,0,0],n=0;n<4;++n)for(var i=0;i<4;++i)r[i]+=t[4*n+i]*e[n];return r}function o(t,e,r,n,i){for(var o=a(n,a(r,a(e,[t[0],t[1],t[2],1]))),s=0;s<3;++s)o[s]/=o[3];return[.5*i[0]*(1+o[0]),.5*i[1]*(1-o[1])]}e.exports=function(t,e,r,a,s,l){if(1===t.length)return[0,t[0].slice()];for(var c=new Array(t.length),u=0;u<t.length;++u)c[u]=o(t[u],r,a,s,l);for(var h=0,f=1/0,u=0;u<c.length;++u){for(var p=0,d=0;d<2;++d)p+=Math.pow(c[u][d]-e[d],2);p<f&&(f=p,h=u)}for(var g=function(t,e){if(2===t.length){for(var r=0,a=0,o=0;o<2;++o)r+=Math.pow(e[o]-t[0][o],2),a+=Math.pow(e[o]-t[1][o],2);return r=Math.sqrt(r),a=Math.sqrt(a),r+a<1e-6?[1,0]:[a/(r+a),r/(a+r)]}if(3===t.length){var s=[0,0];return i(t[0],t[1],t[2],e,s),n(t,s)}return[]}(c,e),v=0,u=0;u<3;++u){if(g[u]<-.001||g[u]>1.0001)return null;v+=g[u]}if(Math.abs(v-1)>.001)return null;return[h,function(t,e){for(var r=[0,0,0],n=0;n<t.length;++n)for(var i=t[n],a=e[n],o=0;o<3;++o)r[o]+=a*i[o];return r}(t,g),g]}},{barycentric:73,\"polytope-closest-point/lib/closest_point_2d.js\":481}],279:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, normal;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  gl_Position      = project(position);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * vec4(position , 1.0);\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal  = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  f_color          = color;\\n  f_data           = position;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\n//#pragma glslify: beckmann = require(glsl-specular-beckmann) // used in gl-surface3d\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (f_color.a == 0.0 ||\\n    outOfRange(clipBounds[0], clipBounds[1], f_data)\\n  ) discard;\\n\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  //float specular = max(0.0, beckmann(L, V, N, roughness)); // used in gl-surface3d\\n\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = vec4(f_color.rgb, 1.0) * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * f_color.a;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_color = color;\\n  f_data  = position;\\n  f_uv    = uv;\\n}\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_data)) discard;\\n\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\nattribute float pointSize;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0 ,0.0 ,0.0);\\n  } else {\\n    gl_Position = projection * view * model * vec4(position, 1.0);\\n  }\\n  gl_PointSize = pointSize;\\n  f_color = color;\\n  f_uv = uv;\\n}\"]),c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  vec2 pointR = gl_PointCoord.xy - vec2(0.5, 0.5);\\n  if(dot(pointR, pointR) > 0.25) {\\n    discard;\\n  }\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_id        = id;\\n  f_position  = position;\\n}\"]),h=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]),f=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3  position;\\nattribute float pointSize;\\nattribute vec4  id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0, 0.0, 0.0);\\n  } else {\\n    gl_Position  = projection * view * model * vec4(position, 1.0);\\n    gl_PointSize = pointSize;\\n  }\\n  f_id         = id;\\n  f_position   = position;\\n}\"]),p=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n}\"]),d=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec3 contourColor;\\n\\nvoid main() {\\n  gl_FragColor = vec4(contourColor, 1.0);\\n}\\n\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.wireShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.pointShader={vertex:l,fragment:c,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"pointSize\",type:\"float\"}]},r.pickShader={vertex:u,fragment:h,attributes:[{name:\"position\",type:\"vec3\"},{name:\"id\",type:\"vec4\"}]},r.pointPickShader={vertex:f,fragment:h,attributes:[{name:\"position\",type:\"vec3\"},{name:\"pointSize\",type:\"float\"},{name:\"id\",type:\"vec4\"}]},r.contourShader={vertex:p,fragment:d,attributes:[{name:\"position\",type:\"vec3\"}]}},{glslify:409}],280:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./lib/shaders\"),g=t(\"./lib/closest-point\"),v=d.meshShader,m=d.wireShader,y=d.pointShader,x=d.pickShader,b=d.pointPickShader,_=d.contourShader,w=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function k(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_,k,T,A,M,S){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.lineShader=n,this.pointShader=i,this.pickShader=a,this.pointPickShader=o,this.contourShader=s,this.trianglePositions=l,this.triangleColors=u,this.triangleNormals=f,this.triangleUVs=h,this.triangleIds=c,this.triangleVAO=p,this.triangleCount=0,this.lineWidth=1,this.edgePositions=d,this.edgeColors=v,this.edgeUVs=m,this.edgeIds=g,this.edgeVAO=y,this.edgeCount=0,this.pointPositions=x,this.pointColors=_,this.pointUVs=k,this.pointSizes=T,this.pointIds=b,this.pointVAO=A,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=M,this.contourVAO=S,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.hasAlpha=!1,this.opacityscale=!1,this._model=w,this._view=w,this._projection=w,this._resolution=[1,1]}var T=k.prototype;function A(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}function M(t){var e=n(t,y.vertex,y.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.pointSize.location=4,e}function S(t){var e=n(t,x.vertex,x.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e}function E(t){var e=n(t,b.vertex,b.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.pointSize.location=4,e}function C(t){var e=n(t,_.vertex,_.fragment);return e.attributes.position.location=0,e}T.isOpaque=function(){return!this.hasAlpha},T.isTransparent=function(){return this.hasAlpha},T.pickSlots=1,T.setPickBase=function(t){this.pickId=t},T.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=i[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},T.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=t.opacity,this.opacity<1&&(this.hasAlpha=!0)),\"opacityscale\"in t&&(this.opacityscale=t.opacityscale,this.hasAlpha=!0),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t,e){for(var r=h({colormap:t,nshades:256,format:\"rgba\"}),n=new Uint8Array(1024),i=0;i<256;++i){for(var a=r[i],o=0;o<3;++o)n[4*i+o]=a[o];n[4*i+3]=e?255*A(i/255,e):255*a[3]}return u(n,[256,256,4],[4,0,1])}(t.colormap,this.opacityscale)),this.texture.generateMipmap());var r=t.cells,n=t.positions;if(n&&r){var i=[],a=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[];this.cells=r,this.positions=n;var w=t.vertexNormals,k=t.cellNormals,T=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,M=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!k&&(k=s.faceNormals(r,n,M)),k||w||(w=s.vertexNormals(r,n,T));var S=t.vertexColors,E=t.cellColors,C=t.meshColor||[1,1,1,1],L=t.vertexUVs,P=t.vertexIntensity,O=t.cellUVs,z=t.cellIntensity,I=1/0,D=-1/0;if(!L&&!O)if(P)if(t.vertexIntensityBounds)I=+t.vertexIntensityBounds[0],D=+t.vertexIntensityBounds[1];else for(var R=0;R<P.length;++R){var F=P[R];I=Math.min(I,F),D=Math.max(D,F)}else if(z)for(R=0;R<z.length;++R){F=z[R];I=Math.min(I,F),D=Math.max(D,F)}else for(R=0;R<n.length;++R){F=n[R][2];I=Math.min(I,F),D=Math.max(D,F)}this.intensity=P||(z?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,z):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var B=t.pointSizes,N=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(R=0;R<n.length;++R)for(var j=n[R],U=0;U<3;++U)!isNaN(j[U])&&isFinite(j[U])&&(this.bounds[0][U]=Math.min(this.bounds[0][U],j[U]),this.bounds[1][U]=Math.max(this.bounds[1][U],j[U]));var V=0,q=0,H=0;t:for(R=0;R<r.length;++R){var G=r[R];switch(G.length){case 1:for(j=n[W=G[0]],U=0;U<3;++U)if(isNaN(j[U])||!isFinite(j[U]))continue t;m.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?y.push(X[0],X[1],X[2],this.opacity):(y.push(X[0],X[1],X[2],X[3]*this.opacity),!this.hasAlpha&&X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],x.push(Z[0],Z[1]),B?b.push(B[W]):b.push(N),_.push(R),H+=1;break;case 2:for(U=0;U<2;++U){j=n[W=G[U]];for(var Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t}for(U=0;U<2;++U){j=n[W=G[U]];p.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?d.push(X[0],X[1],X[2],this.opacity):(d.push(X[0],X[1],X[2],X[3]*this.opacity),!this.hasAlpha&&X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],g.push(Z[0],Z[1]),v.push(R)}q+=1;break;case 3:for(U=0;U<3;++U)for(j=n[W=G[U]],Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t;for(U=0;U<3;++U){var W,X,Z,J;j=n[W=G[2-U]];i.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?a.push(X[0],X[1],X[2],this.opacity):(a.push(X[0],X[1],X[2],X[3]*this.opacity),!this.hasAlpha&&X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],c.push(Z[0],Z[1]),J=w?w[W]:k[R],l.push(J[0],J[1],J[2]),f.push(R)}V+=1}}this.pointCount=H,this.edgeCount=q,this.triangleCount=V,this.pointPositions.update(m),this.pointColors.update(y),this.pointUVs.update(x),this.pointSizes.update(b),this.pointIds.update(new Uint32Array(_)),this.edgePositions.update(p),this.edgeColors.update(d),this.edgeUVs.update(g),this.edgeIds.update(new Uint32Array(v)),this.trianglePositions.update(i),this.triangleColors.update(a),this.triangleUVs.update(c),this.triangleNormals.update(l),this.triangleIds.update(new Uint32Array(f))}},T.drawTransparent=T.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:w.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h,f=u[15];for(o=0;o<3;++o)f+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];s.lightPosition[o]=p/f}this.triangleCount>0&&((h=this.triShader).bind(),h.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind());this.edgeCount>0&&this.lineWidth>0&&((h=this.lineShader).bind(),h.uniforms=s,this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind());this.pointCount>0&&((h=this.pointShader).bind(),h.uniforms=s,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind());this.contourEnable&&this.contourCount>0&&this.contourLineWidth>0&&((h=this.contourShader).bind(),h.uniforms=s,this.contourVAO.bind(),e.drawArrays(e.LINES,0,this.contourCount),this.contourVAO.unbind())},T.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s,l={model:r,view:n,projection:i,clipBounds:a,pickId:this.pickId/255};((s=this.pickShader).bind(),s.uniforms=l,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind()),this.pointCount>0)&&((s=this.pointPickShader).bind(),s.uniforms=l,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind())},T.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;for(var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions,i=new Array(r.length),a=0;a<r.length;++a)i[a]=n[r[a]];var o=g(i,[t.coord[0],this._resolution[1]-t.coord[1]],this._model,this._view,this._projection,this._resolution);if(!o)return null;var s=o[2],l=0;for(a=0;a<r.length;++a)l+=s[a]*this.intensity[r[a]];return{position:o[1],index:r[o[0]],cell:r,cellId:e,intensity:l,dataCoordinate:this.positions[r[o[0]]]}},T.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.lineShader.dispose(),this.pointShader.dispose(),this.pickShader.dispose(),this.pointPickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose(),this.contourShader.dispose()},e.exports=function(t,e){if(1===arguments.length&&(t=(e=t).gl),!(t.getExtension(\"OES_standard_derivatives\")||t.getExtension(\"MOZ_OES_standard_derivatives\")||t.getExtension(\"WEBKIT_OES_standard_derivatives\")))throw new Error(\"derivatives not supported\");var r=function(t){var e=n(t,v.vertex,v.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.normal.location=4,e}(t),s=function(t){var e=n(t,m.vertex,m.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e}(t),l=M(t),c=S(t),h=E(t),f=C(t),p=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));p.generateMipmap(),p.minFilter=t.LINEAR_MIPMAP_LINEAR,p.magFilter=t.LINEAR;var d=i(t),g=i(t),y=i(t),x=i(t),b=i(t),_=a(t,[{buffer:d,type:t.FLOAT,size:3},{buffer:b,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:g,type:t.FLOAT,size:4},{buffer:y,type:t.FLOAT,size:2},{buffer:x,type:t.FLOAT,size:3}]),w=i(t),T=i(t),A=i(t),L=i(t),P=a(t,[{buffer:w,type:t.FLOAT,size:3},{buffer:L,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:T,type:t.FLOAT,size:4},{buffer:A,type:t.FLOAT,size:2}]),O=i(t),z=i(t),I=i(t),D=i(t),R=i(t),F=a(t,[{buffer:O,type:t.FLOAT,size:3},{buffer:R,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:z,type:t.FLOAT,size:4},{buffer:I,type:t.FLOAT,size:2},{buffer:D,type:t.FLOAT,size:1}]),B=i(t),N=new k(t,p,r,s,l,c,h,f,d,b,g,y,x,_,w,L,T,A,P,O,R,z,I,D,F,B,a(t,[{buffer:B,type:t.FLOAT,size:3}]));return N.update(e),N}},{\"./lib/closest-point\":278,\"./lib/shaders\":279,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-shader\":301,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,normals:453,\"simplicial-complex-contour\":518,\"typedarray-pool\":545}],281:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[0,0,0,1,1,0,1,1]),s=i(e,a.boxVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawBox=(s=[0,0],l=[0,0],function(t,e,r,n,i){var a=this.plot,o=this.shader,c=a.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,o.uniforms.lo=s,o.uniforms.hi=l,o.uniforms.color=i,c.drawArrays(c.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":284,\"gl-buffer\":241,\"gl-shader\":301}],282:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,o.gridVert,o.gridFrag),l=i(e,o.tickVert,o.gridFrag);return new s(t,r,a,l)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"binary-search-bounds\"),o=t(\"./shaders\");function s(t,e,r,n){this.plot=t,this.vbo=e,this.shader=r,this.tickShader=n,this.ticks=[[],[]]}function l(t,e){return t-e}var c,u,h,f,p,d=s.prototype;d.draw=(c=[0,0],u=[0,0],h=[0,0],function(){for(var t=this.plot,e=this.vbo,r=this.shader,n=this.ticks,i=t.gl,a=t._tickBounds,o=t.dataBox,s=t.viewBox,l=t.gridLineWidth,f=t.gridLineColor,p=t.gridLineEnable,d=t.pixelRatio,g=0;g<2;++g){var v=a[g],m=a[g+2]-v,y=.5*(o[g+2]+o[g]),x=o[g+2]-o[g];u[g]=2*m/x,c[g]=2*(v-y)/x}r.bind(),e.bind(),r.attributes.dataCoord.pointer(),r.uniforms.dataShift=c,r.uniforms.dataScale=u;var b=0;for(g=0;g<2;++g){h[0]=h[1]=0,h[g]=1,r.uniforms.dataAxis=h,r.uniforms.lineWidth=l[g]/(s[g+2]-s[g])*d,r.uniforms.color=f[g];var _=6*n[g].length;p[g]&&_&&i.drawArrays(i.TRIANGLES,b,_),b+=_}}),d.drawTickMarks=function(){var t=[0,0],e=[0,0],r=[1,0],n=[0,1],i=[0,0],o=[0,0];return function(){for(var s=this.plot,c=this.vbo,u=this.tickShader,h=this.ticks,f=s.gl,p=s._tickBounds,d=s.dataBox,g=s.viewBox,v=s.pixelRatio,m=s.screenBox,y=m[2]-m[0],x=m[3]-m[1],b=g[2]-g[0],_=g[3]-g[1],w=0;w<2;++w){var k=p[w],T=p[w+2]-k,A=.5*(d[w+2]+d[w]),M=d[w+2]-d[w];e[w]=2*T/M,t[w]=2*(k-A)/M}e[0]*=b/y,t[0]*=b/y,e[1]*=_/x,t[1]*=_/x,u.bind(),c.bind(),u.attributes.dataCoord.pointer();var S=u.uniforms;S.dataShift=t,S.dataScale=e;var E=s.tickMarkLength,C=s.tickMarkWidth,L=s.tickMarkColor,P=6*h[0].length,O=Math.min(a.ge(h[0],(d[0]-p[0])/(p[2]-p[0]),l),h[0].length),z=Math.min(a.gt(h[0],(d[2]-p[0])/(p[2]-p[0]),l),h[0].length),I=0+6*O,D=6*Math.max(0,z-O),R=Math.min(a.ge(h[1],(d[1]-p[1])/(p[3]-p[1]),l),h[1].length),F=Math.min(a.gt(h[1],(d[3]-p[1])/(p[3]-p[1]),l),h[1].length),B=P+6*R,N=6*Math.max(0,F-R);i[0]=2*(g[0]-E[1])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=E[1]*v/y,o[1]=C[1]*v/x,N&&(S.color=L[1],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,f.drawArrays(f.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[1]-E[0])/x-1,o[0]=C[0]*v/y,o[1]=E[0]*v/x,D&&(S.color=L[0],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,f.drawArrays(f.TRIANGLES,I,D)),i[0]=2*(g[2]+E[3])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=E[3]*v/y,o[1]=C[3]*v/x,N&&(S.color=L[3],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,f.drawArrays(f.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[3]+E[2])/x-1,o[0]=C[2]*v/y,o[1]=E[2]*v/x,D&&(S.color=L[2],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,f.drawArrays(f.TRIANGLES,I,D))}}(),d.update=(f=[1,1,-1,-1,1,-1],p=[1,-1,1,1,-1,-1],function(t){for(var e=t.ticks,r=t.bounds,n=new Float32Array(18*(e[0].length+e[1].length)),i=(this.plot.zeroLineEnable,0),a=[[],[]],o=0;o<2;++o)for(var s=a[o],l=e[o],c=r[o],u=r[o+2],h=0;h<l.length;++h){var d=(l[h].x-c)/(u-c);s.push(d);for(var g=0;g<6;++g)n[i++]=d,n[i++]=f[g],n[i++]=p[g]}this.ticks=a,this.vbo.update(n)}),d.dispose=function(){this.vbo.dispose(),this.shader.dispose(),this.tickShader.dispose()}},{\"./shaders\":284,\"binary-search-bounds\":286,\"gl-buffer\":241,\"gl-shader\":301}],283:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[-1,-1,-1,1,1,-1,1,1]),s=i(e,a.lineVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawLine=(s=[0,0],l=[0,0],function(t,e,r,n,i,a){var o=this.plot,c=this.shader,u=o.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,c.uniforms.start=s,c.uniforms.end=l,c.uniforms.width=i*o.pixelRatio,c.uniforms.color=a,u.drawArrays(u.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":284,\"gl-buffer\":241,\"gl-shader\":301}],284:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision lowp float;\\n#define GLSLIFY 1\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = vec4(color.xyz * color.w, color.w);\\n}\\n\"]);e.exports={lineVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 start, end;\\nuniform float width;\\n\\nvec2 perp(vec2 v) {\\n  return vec2(v.y, -v.x);\\n}\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  vec2 delta = normalize(perp(start - end));\\n  vec2 offset = mix(start, end, 0.5 * (coord.y+1.0));\\n  gl_Position = vec4(screen(offset + 0.5 * width * delta * coord.x), 0, 1);\\n}\\n\"]),lineFrag:i,textVert:n([\"#define GLSLIFY 1\\nattribute vec3 textCoordinate;\\n\\nuniform vec2 dataScale, dataShift, dataAxis, screenOffset, textScale;\\nuniform float angle;\\n\\nvoid main() {\\n  float dataOffset  = textCoordinate.z;\\n  vec2 glyphOffset  = textCoordinate.xy;\\n  mat2 glyphMatrix = mat2(cos(angle), sin(angle), -sin(angle), cos(angle));\\n  vec2 screenCoordinate = dataAxis * (dataScale * dataOffset + dataShift) +\\n    glyphMatrix * glyphOffset * textScale + screenOffset;\\n  gl_Position = vec4(screenCoordinate, 0, 1);\\n}\\n\"]),textFrag:i,gridVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale;\\nuniform float lineWidth;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  pos += 10.0 * dataCoord.y * vec2(dataAxis.y, -dataAxis.x) + dataCoord.z * lineWidth;\\n  gl_Position = vec4(pos, 0, 1);\\n}\\n\"]),gridFrag:i,boxVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 lo, hi;\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  gl_Position = vec4(screen(mix(lo, hi, coord)), 0, 1);\\n}\\n\"]),tickVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale, screenOffset, tickScale;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  gl_Position = vec4(pos + tickScale*dataCoord.yz + screenOffset, 0, 1);\\n}\\n\"])}},{glslify:409}],285:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,s.textVert,s.textFrag);return new l(t,r,a)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"text-cache\"),o=t(\"binary-search-bounds\"),s=t(\"./shaders\");function l(t,e,r){this.plot=t,this.vbo=e,this.shader=r,this.tickOffset=[[],[]],this.tickX=[[],[]],this.labelOffset=[0,0],this.labelCount=[0,0]}var c,u,h,f,p,d,g=l.prototype;g.drawTicks=(c=[0,0],u=[0,0],h=[0,0],function(t){var e=this.plot,r=this.shader,n=this.tickX[t],i=this.tickOffset[t],a=e.gl,s=e.viewBox,l=e.dataBox,f=e.screenBox,p=e.pixelRatio,d=e.tickEnable,g=e.tickPad,v=e.tickColor,m=e.tickAngle,y=e.labelEnable,x=e.labelPad,b=e.labelColor,_=e.labelAngle,w=this.labelOffset[t],k=this.labelCount[t],T=o.lt(n,l[t]),A=o.le(n,l[t+2]);c[0]=c[1]=0,c[t]=1,u[t]=(s[2+t]+s[t])/(f[2+t]-f[t])-1;var M=2/f[2+(1^t)]-f[1^t];u[1^t]=M*s[1^t]-1,d[t]&&(u[1^t]-=M*p*g[t],T<A&&i[A]>i[T]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=v[t],r.uniforms.angle=m[t],a.drawArrays(a.TRIANGLES,i[T],i[A]-i[T]))),y[t]&&k&&(u[1^t]-=M*p*x[t],r.uniforms.dataAxis=h,r.uniforms.screenOffset=u,r.uniforms.color=b[t],r.uniforms.angle=_[t],a.drawArrays(a.TRIANGLES,w,k)),u[1^t]=M*s[2+(1^t)]-1,d[t+2]&&(u[1^t]+=M*p*g[t+2],T<A&&i[A]>i[T]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=v[t+2],r.uniforms.angle=m[t+2],a.drawArrays(a.TRIANGLES,i[T],i[A]-i[T]))),y[t+2]&&k&&(u[1^t]+=M*p*x[t+2],r.uniforms.dataAxis=h,r.uniforms.screenOffset=u,r.uniforms.color=b[t+2],r.uniforms.angle=_[t+2],a.drawArrays(a.TRIANGLES,w,k))}),g.drawTitle=function(){var t=[0,0],e=[0,0];return function(){var r=this.plot,n=this.shader,i=r.gl,a=r.screenBox,o=r.titleCenter,s=r.titleAngle,l=r.titleColor,c=r.pixelRatio;if(this.titleCount){for(var u=0;u<2;++u)e[u]=2*(o[u]*c-a[u])/(a[2+u]-a[u])-1;n.bind(),n.uniforms.dataAxis=t,n.uniforms.screenOffset=e,n.uniforms.angle=s,n.uniforms.color=l,i.drawArrays(i.TRIANGLES,this.titleOffset,this.titleCount)}}}(),g.bind=(f=[0,0],p=[0,0],d=[0,0],function(){var t=this.plot,e=this.shader,r=t._tickBounds,n=t.dataBox,i=t.screenBox,a=t.viewBox;e.bind();for(var o=0;o<2;++o){var s=r[o],l=r[o+2]-s,c=.5*(n[o+2]+n[o]),u=n[o+2]-n[o],h=a[o],g=a[o+2]-h,v=i[o],m=i[o+2]-v;p[o]=2*l/u*g/m,f[o]=2*(s-c)/u*g/m}d[1]=2*t.pixelRatio/(i[3]-i[1]),d[0]=d[1]*(i[3]-i[1])/(i[2]-i[0]),e.uniforms.dataScale=p,e.uniforms.dataShift=f,e.uniforms.textScale=d,this.vbo.bind(),e.attributes.textCoordinate.pointer()}),g.update=function(t){var e,r,n,i,o,s=[],l=t.ticks,c=t.bounds;for(o=0;o<2;++o){var u=[Math.floor(s.length/3)],h=[-1/0],f=l[o];for(e=0;e<f.length;++e){var p=f[e],d=p.x,g=p.text,v=p.font||\"sans-serif\";i=p.fontSize||12;for(var m=1/(c[o+2]-c[o]),y=c[o],x=g.split(\"\\n\"),b=0;b<x.length;b++)for(n=a(v,x[b]).data,r=0;r<n.length;r+=2)s.push(n[r]*i,-n[r+1]*i-b*i*1.2,(d-y)*m);u.push(Math.floor(s.length/3)),h.push(d)}this.tickOffset[o]=u,this.tickX[o]=h}for(o=0;o<2;++o){for(this.labelOffset[o]=Math.floor(s.length/3),n=a(t.labelFont[o],t.labels[o],{textAlign:\"center\"}).data,i=t.labelSize[o],e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.labelCount[o]=Math.floor(s.length/3)-this.labelOffset[o]}for(this.titleOffset=Math.floor(s.length/3),n=a(t.titleFont,t.title).data,i=t.titleSize,e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.titleCount=Math.floor(s.length/3)-this.titleOffset,this.vbo.update(s)},g.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":284,\"binary-search-bounds\":286,\"gl-buffer\":241,\"gl-shader\":301,\"text-cache\":536}],286:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],287:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[e.drawingBufferWidth,e.drawingBufferHeight]),c=new l(e,r);return c.grid=i(c),c.text=a(c),c.line=o(c),c.box=s(c),c.update(t),c};var n=t(\"gl-select-static\"),i=t(\"./lib/grid\"),a=t(\"./lib/text\"),o=t(\"./lib/line\"),s=t(\"./lib/box\");function l(t,e){this.gl=t,this.pickBuffer=e,this.screenBox=[0,0,t.drawingBufferWidth,t.drawingBufferHeight],this.viewBox=[0,0,0,0],this.dataBox=[-10,-10,10,10],this.gridLineEnable=[!0,!0],this.gridLineWidth=[1,1],this.gridLineColor=[[0,0,0,1],[0,0,0,1]],this.pixelRatio=1,this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickEnable=[!0,!0,!0,!0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[15,15,15,15],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelEnable=[!0,!0,!0,!0],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.titleCenter=[0,0],this.titleEnable=!0,this.titleAngle=0,this.titleColor=[0,0,0,1],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[4,4],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderLineEnable=[!0,!0,!0,!0],this.borderLineWidth=[2,2,2,2],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.grid=null,this.text=null,this.line=null,this.box=null,this.objects=[],this.overlays=[],this._tickBounds=[1/0,1/0,-1/0,-1/0],this.static=!1,this.dirty=!1,this.pickDirty=!1,this.pickDelay=120,this.pickRadius=10,this._pickTimeout=null,this._drawPick=this.drawPick.bind(this),this._depthCounter=0}var c=l.prototype;function u(t){for(var e=t.slice(),r=0;r<e.length;++r)e[r]=e[r].slice();return e}function h(t,e){return t.x-e.x}c.setDirty=function(){this.dirty=this.pickDirty=!0},c.setOverlayDirty=function(){this.dirty=!0},c.nextDepthValue=function(){return this._depthCounter++/65536},c.draw=function(){var t=this.gl,e=this.screenBox,r=this.viewBox,n=this.dataBox,i=this.pixelRatio,a=this.grid,o=this.line,s=this.text,l=this.objects;if(this._depthCounter=0,this.pickDirty&&(this._pickTimeout&&clearTimeout(this._pickTimeout),this.pickDirty=!1,this._pickTimeout=setTimeout(this._drawPick,this.pickDelay)),this.dirty){if(this.dirty=!1,t.bindFramebuffer(t.FRAMEBUFFER,null),t.enable(t.SCISSOR_TEST),t.disable(t.DEPTH_TEST),t.depthFunc(t.LESS),t.depthMask(!1),t.enable(t.BLEND),t.blendEquation(t.FUNC_ADD,t.FUNC_ADD),t.blendFunc(t.ONE,t.ONE_MINUS_SRC_ALPHA),this.borderColor){t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]);var c=this.borderColor;t.clearColor(c[0]*c[3],c[1]*c[3],c[2]*c[3],c[3]),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT)}t.scissor(r[0],r[1],r[2]-r[0],r[3]-r[1]),t.viewport(r[0],r[1],r[2]-r[0],r[3]-r[1]);var u=this.backgroundColor;t.clearColor(u[0]*u[3],u[1]*u[3],u[2]*u[3],u[3]),t.clear(t.COLOR_BUFFER_BIT),a.draw();var h=this.zeroLineEnable,f=this.zeroLineColor,p=this.zeroLineWidth;if(h[0]||h[1]){o.bind();for(var d=0;d<2;++d)if(h[d]&&n[d]<=0&&n[d+2]>=0){var g=e[d]-n[d]*(e[d+2]-e[d])/(n[d+2]-n[d]);0===d?o.drawLine(g,e[1],g,e[3],p[d],f[d]):o.drawLine(e[0],g,e[2],g,p[d],f[d])}}for(d=0;d<l.length;++d)l[d].draw();t.viewport(e[0],e[1],e[2]-e[0],e[3]-e[1]),t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]),this.grid.drawTickMarks(),o.bind();var v=this.borderLineEnable,m=this.borderLineWidth,y=this.borderLineColor;for(v[1]&&o.drawLine(r[0],r[1]-.5*m[1]*i,r[0],r[3]+.5*m[3]*i,m[1],y[1]),v[0]&&o.drawLine(r[0]-.5*m[0]*i,r[1],r[2]+.5*m[2]*i,r[1],m[0],y[0]),v[3]&&o.drawLine(r[2],r[1]-.5*m[1]*i,r[2],r[3]+.5*m[3]*i,m[3],y[3]),v[2]&&o.drawLine(r[0]-.5*m[0]*i,r[3],r[2]+.5*m[2]*i,r[3],m[2],y[2]),s.bind(),d=0;d<2;++d)s.drawTicks(d);this.titleEnable&&s.drawTitle();var x=this.overlays;for(d=0;d<x.length;++d)x[d].draw();t.disable(t.SCISSOR_TEST),t.disable(t.BLEND),t.depthMask(!0)}},c.drawPick=function(){if(!this.static){var t=this.pickBuffer;this.gl;this._pickTimeout=null,t.begin();for(var e=1,r=this.objects,n=0;n<r.length;++n)e=r[n].drawPick(e);t.end()}},c.pick=function(t,e){if(!this.static){var r=this.pixelRatio,n=this.pickPixelRatio,i=this.viewBox,a=0|Math.round((t-i[0]/r)*n),o=0|Math.round((e-i[1]/r)*n),s=this.pickBuffer.query(a,o,this.pickRadius);if(!s)return null;for(var l=s.id+(s.value[0]<<8)+(s.value[1]<<16)+(s.value[2]<<24),c=this.objects,u=0;u<c.length;++u){var h=c[u].pick(a,o,l);if(h)return h}return null}},c.setScreenBox=function(t){var e=this.screenBox,r=this.pixelRatio;e[0]=0|Math.round(t[0]*r),e[1]=0|Math.round(t[1]*r),e[2]=0|Math.round(t[2]*r),e[3]=0|Math.round(t[3]*r),this.setDirty()},c.setDataBox=function(t){var e=this.dataBox;(e[0]!==t[0]||e[1]!==t[1]||e[2]!==t[2]||e[3]!==t[3])&&(e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],this.setDirty())},c.setViewBox=function(t){var e=this.pixelRatio,r=this.viewBox;r[0]=0|Math.round(t[0]*e),r[1]=0|Math.round(t[1]*e),r[2]=0|Math.round(t[2]*e),r[3]=0|Math.round(t[3]*e);var n=this.pickPixelRatio;this.pickBuffer.shape=[0|Math.round((t[2]-t[0])*n),0|Math.round((t[3]-t[1])*n)],this.setDirty()},c.update=function(t){t=t||{};var e=this.gl;this.pixelRatio=t.pixelRatio||1;var r=this.pixelRatio;this.pickPixelRatio=Math.max(r,1),this.setScreenBox(t.screenBox||[0,0,e.drawingBufferWidth/r,e.drawingBufferHeight/r]);this.screenBox;this.setViewBox(t.viewBox||[.125*(this.screenBox[2]-this.screenBox[0])/r,.125*(this.screenBox[3]-this.screenBox[1])/r,.875*(this.screenBox[2]-this.screenBox[0])/r,.875*(this.screenBox[3]-this.screenBox[1])/r]);var n=this.viewBox,i=(n[2]-n[0])/(n[3]-n[1]);this.setDataBox(t.dataBox||[-10,-10/i,10,10/i]),this.borderColor=!1!==t.borderColor&&(t.borderColor||[0,0,0,0]).slice(),this.backgroundColor=(t.backgroundColor||[0,0,0,0]).slice(),this.gridLineEnable=(t.gridLineEnable||[!0,!0]).slice(),this.gridLineWidth=(t.gridLineWidth||[1,1]).slice(),this.gridLineColor=u(t.gridLineColor||[[.5,.5,.5,1],[.5,.5,.5,1]]),this.zeroLineEnable=(t.zeroLineEnable||[!0,!0]).slice(),this.zeroLineWidth=(t.zeroLineWidth||[4,4]).slice(),this.zeroLineColor=u(t.zeroLineColor||[[0,0,0,1],[0,0,0,1]]),this.tickMarkLength=(t.tickMarkLength||[0,0,0,0]).slice(),this.tickMarkWidth=(t.tickMarkWidth||[0,0,0,0]).slice(),this.tickMarkColor=u(t.tickMarkColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.titleCenter=(t.titleCenter||[.5*(n[0]+n[2])/r,(n[3]+120)/r]).slice(),this.titleEnable=!(\"titleEnable\"in t&&!t.titleEnable),this.titleAngle=t.titleAngle||0,this.titleColor=(t.titleColor||[0,0,0,1]).slice(),this.labelPad=(t.labelPad||[15,15,15,15]).slice(),this.labelAngle=(t.labelAngle||[0,Math.PI/2,0,3*Math.PI/2]).slice(),this.labelEnable=(t.labelEnable||[!0,!0,!0,!0]).slice(),this.labelColor=u(t.labelColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.tickPad=(t.tickPad||[15,15,15,15]).slice(),this.tickAngle=(t.tickAngle||[0,0,0,0]).slice(),this.tickEnable=(t.tickEnable||[!0,!0,!0,!0]).slice(),this.tickColor=u(t.tickColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.borderLineEnable=(t.borderLineEnable||[!0,!0,!0,!0]).slice(),this.borderLineWidth=(t.borderLineWidth||[2,2,2,2]).slice(),this.borderLineColor=u(t.borderLineColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]);var a=t.ticks||[[],[]],o=this._tickBounds;o[0]=o[1]=1/0,o[2]=o[3]=-1/0;for(var s=0;s<2;++s){var l=a[s].slice(0);0!==l.length&&(l.sort(h),o[s]=Math.min(o[s],l[0].x),o[s+2]=Math.max(o[s+2],l[l.length-1].x))}this.grid.update({bounds:o,ticks:a}),this.text.update({bounds:o,ticks:a,labels:t.labels||[\"x\",\"y\"],labelSize:t.labelSize||[12,12],labelFont:t.labelFont||[\"sans-serif\",\"sans-serif\"],title:t.title||\"\",titleSize:t.titleSize||18,titleFont:t.titleFont||\"sans-serif\"}),this.static=!!t.static,this.setDirty()},c.dispose=function(){this.box.dispose(),this.grid.dispose(),this.text.dispose(),this.line.dispose();for(var t=this.objects.length-1;t>=0;--t)this.objects[t].dispose();this.objects.length=0;for(t=this.overlays.length-1;t>=0;--t)this.overlays[t].dispose();this.overlays.length=0,this.gl=null},c.addObject=function(t){this.objects.indexOf(t)<0&&(this.objects.push(t),this.setDirty())},c.removeObject=function(t){for(var e=this.objects,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setDirty();break}},c.addOverlay=function(t){this.overlays.indexOf(t)<0&&(this.overlays.push(t),this.setOverlayDirty())},c.removeOverlay=function(t){for(var e=this.overlays,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setOverlayDirty();break}}},{\"./lib/box\":281,\"./lib/grid\":282,\"./lib/line\":283,\"./lib/text\":285,\"gl-select-static\":300}],288:[function(t,e,r){\"use strict\";e.exports=function(t,e){t=t||document.body,e=e||{};var r=[.01,1/0];\"distanceLimits\"in e&&(r[0]=e.distanceLimits[0],r[1]=e.distanceLimits[1]);\"zoomMin\"in e&&(r[0]=e.zoomMin);\"zoomMax\"in e&&(r[1]=e.zoomMax);var c=i({center:e.center||[0,0,0],up:e.up||[0,1,0],eye:e.eye||[0,0,10],mode:e.mode||\"orbit\",distanceLimits:r}),u=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],h=0,f=t.clientWidth,p=t.clientHeight,d={keyBindingMode:\"rotate\",enableWheel:!0,view:c,element:t,delay:e.delay||16,rotateSpeed:e.rotateSpeed||1,zoomSpeed:e.zoomSpeed||1,translateSpeed:e.translateSpeed||1,flipX:!!e.flipX,flipY:!!e.flipY,modes:c.modes,_ortho:e._ortho||e.projection&&\"orthographic\"===e.projection.type||!1,tick:function(){var e=n(),r=this.delay,i=e-2*r;c.idle(e-r),c.recalcMatrix(i),c.flush(e-(100+2*r));for(var a=!0,o=c.computedMatrix,s=0;s<16;++s)a=a&&u[s]===o[s],u[s]=o[s];var l=t.clientWidth===f&&t.clientHeight===p;return f=t.clientWidth,p=t.clientHeight,a?!l:(h=Math.exp(c.computedRadius[0]),!0)},lookAt:function(t,e,r){c.lookAt(c.lastT(),t,e,r)},rotate:function(t,e,r){c.rotate(c.lastT(),t,e,r)},pan:function(t,e,r){c.pan(c.lastT(),t,e,r)},translate:function(t,e,r){c.translate(c.lastT(),t,e,r)}};return Object.defineProperties(d,{matrix:{get:function(){return c.computedMatrix},set:function(t){return c.setMatrix(c.lastT(),t),c.computedMatrix},enumerable:!0},mode:{get:function(){return c.getMode()},set:function(t){var e=c.computedUp.slice(),r=c.computedEye.slice(),i=c.computedCenter.slice();if(c.setMode(t),\"turntable\"===t){var a=n();c._active.lookAt(a,r,i,e),c._active.lookAt(a+500,r,i,[0,0,1]),c._active.flush(a)}return c.getMode()},enumerable:!0},center:{get:function(){return c.computedCenter},set:function(t){return c.lookAt(c.lastT(),null,t),c.computedCenter},enumerable:!0},eye:{get:function(){return c.computedEye},set:function(t){return c.lookAt(c.lastT(),t),c.computedEye},enumerable:!0},up:{get:function(){return c.computedUp},set:function(t){return c.lookAt(c.lastT(),null,null,t),c.computedUp},enumerable:!0},distance:{get:function(){return h},set:function(t){return c.setDistance(c.lastT(),t),t},enumerable:!0},distanceLimits:{get:function(){return c.getDistanceLimits(r)},set:function(t){return c.setDistanceLimits(t),t},enumerable:!0}}),t.addEventListener(\"contextmenu\",function(t){return t.preventDefault(),!1}),d._lastX=-1,d._lastY=-1,d._lastMods={shift:!1,control:!1,alt:!1,meta:!1},d.enableMouseListeners=function(){function e(e,r,i,a){var o=d.keyBindingMode;if(!1!==o){var s=\"rotate\"===o,l=\"pan\"===o,u=\"zoom\"===o,f=!!a.control,p=!!a.alt,g=!!a.shift,v=!!(1&e),m=!!(2&e),y=!!(4&e),x=1/t.clientHeight,b=x*(r-d._lastX),_=x*(i-d._lastY),w=d.flipX?1:-1,k=d.flipY?1:-1,T=Math.PI*d.rotateSpeed,A=n();if(-1!==d._lastX&&-1!==d._lastY&&((s&&v&&!f&&!p&&!g||v&&!f&&!p&&g)&&c.rotate(A,w*T*b,-k*T*_,0),(l&&v&&!f&&!p&&!g||m||v&&f&&!p&&!g)&&c.pan(A,-d.translateSpeed*b*h,d.translateSpeed*_*h,0),u&&v&&!f&&!p&&!g||y||v&&!f&&p&&!g)){var M=-d.zoomSpeed*_/window.innerHeight*(A-c.lastT())*100;c.pan(A,0,0,h*(Math.exp(M)-1))}return d._lastX=r,d._lastY=i,d._lastMods=a,!0}}d.mouseListener=a(t,e),t.addEventListener(\"touchstart\",function(r){var n=s(r.changedTouches[0],t);e(0,n[0],n[1],d._lastMods),e(1,n[0],n[1],d._lastMods),r.preventDefault()},!!l&&{passive:!1}),t.addEventListener(\"touchmove\",function(r){var n=s(r.changedTouches[0],t);e(1,n[0],n[1],d._lastMods),r.preventDefault()},!!l&&{passive:!1}),t.addEventListener(\"touchend\",function(t){e(0,d._lastX,d._lastY,d._lastMods),t.preventDefault()},!!l&&{passive:!1}),d.wheelListener=o(t,function(t,e){if(!1!==d.keyBindingMode&&d.enableWheel){var r=d.flipX?1:-1,i=d.flipY?1:-1,a=n();if(Math.abs(t)>Math.abs(e))c.rotate(a,0,0,-t*r*Math.PI*d.rotateSpeed/window.innerWidth);else if(!d._ortho){var o=-d.zoomSpeed*i*e/window.innerHeight*(a-c.lastT())/20;c.pan(a,0,0,h*(Math.exp(o)-1))}}},!0)},d.enableMouseListeners(),d};var n=t(\"right-now\"),i=t(\"3d-view\"),a=t(\"mouse-change\"),o=t(\"mouse-wheel\"),s=t(\"mouse-event-offset\"),l=t(\"has-passive-events\")},{\"3d-view\":52,\"has-passive-events\":411,\"mouse-change\":435,\"mouse-event-offset\":436,\"mouse-wheel\":438,\"right-now\":504}],289:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\nattribute vec2 position;\\nvarying vec2 uv;\\nvoid main() {\\n  uv = position;\\n  gl_Position = vec4(position, 0, 1);\\n}\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D accumBuffer;\\nvarying vec2 uv;\\n\\nvoid main() {\\n  vec4 accum = texture2D(accumBuffer, 0.5 * (uv + 1.0));\\n  gl_FragColor = min(vec4(1,1,1,1), accum);\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec2\"}])}},{\"gl-shader\":301,glslify:409}],290:[function(t,e,r){\"use strict\";var n=t(\"./camera.js\"),i=t(\"gl-axes3d\"),a=t(\"gl-axes3d/properties\"),o=t(\"gl-spikes3d\"),s=t(\"gl-select-static\"),l=t(\"gl-fbo\"),c=t(\"a-big-triangle\"),u=t(\"mouse-change\"),h=t(\"mouse-wheel\"),f=t(\"gl-mat4/perspective\"),p=t(\"gl-mat4/ortho\"),d=t(\"./lib/shader\"),g=t(\"is-mobile\")({tablet:!0});function v(){this.mouse=[-1,-1],this.screen=null,this.distance=1/0,this.index=null,this.dataCoordinate=null,this.dataPosition=null,this.object=null,this.data=null}function m(t){var e=Math.round(Math.log(Math.abs(t))/Math.log(10));if(e<0){var r=Math.round(Math.pow(10,-e));return Math.ceil(t*r)/r}if(e>0){r=Math.round(Math.pow(10,e));return Math.ceil(t/r)*r}return Math.ceil(t)}function y(t){return\"boolean\"!=typeof t||t}e.exports={createScene:function(t){(t=t||{}).camera=t.camera||{};var e=t.canvas;if(!e)if(e=document.createElement(\"canvas\"),t.container){var r=t.container;r.appendChild(e)}else document.body.appendChild(e);var x=t.gl;x||(x=function(t,e){var r=null;try{(r=t.getContext(\"webgl\",e))||(r=t.getContext(\"experimental-webgl\",e))}catch(t){return null}return r}(e,t.glOptions||{premultipliedAlpha:!0,antialias:!0,preserveDrawingBuffer:g}));if(!x)throw new Error(\"webgl not supported\");var b=t.bounds||[[-10,-10,-10],[10,10,10]],_=new v,w=l(x,[x.drawingBufferWidth,x.drawingBufferHeight],{preferFloat:!g}),k=d(x),T=t.cameraObject&&!0===t.cameraObject._ortho||t.camera.projection&&\"orthographic\"===t.camera.projection.type||!1,A={eye:t.camera.eye||[2,0,0],center:t.camera.center||[0,0,0],up:t.camera.up||[0,1,0],zoomMin:t.camera.zoomMax||.1,zoomMax:t.camera.zoomMin||100,mode:t.camera.mode||\"turntable\",_ortho:T},M=t.axes||{},S=i(x,M);S.enable=!M.disable;var E=t.spikes||{},C=o(x,E),L=[],P=[],O=[],z=[],I=!0,D=!0,R=new Array(16),F=new Array(16),B={view:null,projection:R,model:F,_ortho:!1},D=!0,N=[x.drawingBufferWidth,x.drawingBufferHeight],j=t.cameraObject||n(e,A),U={gl:x,contextLost:!1,pixelRatio:t.pixelRatio||1,canvas:e,selection:_,camera:j,axes:S,axesPixels:null,spikes:C,bounds:b,objects:L,shape:N,aspect:t.aspectRatio||[1,1,1],pickRadius:t.pickRadius||10,zNear:t.zNear||.01,zFar:t.zFar||1e3,fovy:t.fovy||Math.PI/4,clearColor:t.clearColor||[0,0,0,0],autoResize:y(t.autoResize),autoBounds:y(t.autoBounds),autoScale:!!t.autoScale,autoCenter:y(t.autoCenter),clipToBounds:y(t.clipToBounds),snapToData:!!t.snapToData,onselect:t.onselect||null,onrender:t.onrender||null,onclick:t.onclick||null,cameraParams:B,oncontextloss:null,mouseListener:null,_stopped:!1},V=[x.drawingBufferWidth/U.pixelRatio|0,x.drawingBufferHeight/U.pixelRatio|0];function q(){if(!U._stopped&&U.autoResize){var t=e.parentNode,r=1,n=1;t&&t!==document.body?(r=t.clientWidth,n=t.clientHeight):(r=window.innerWidth,n=window.innerHeight);var i=0|Math.ceil(r*U.pixelRatio),a=0|Math.ceil(n*U.pixelRatio);if(i!==e.width||a!==e.height){e.width=i,e.height=a;var o=e.style;o.position=o.position||\"absolute\",o.left=\"0px\",o.top=\"0px\",o.width=r+\"px\",o.height=n+\"px\",I=!0}}}U.autoResize&&q();function H(){for(var t=L.length,e=z.length,r=0;r<e;++r)O[r]=0;t:for(var r=0;r<t;++r){var n=L[r],i=n.pickSlots;if(i){for(var a=0;a<e;++a)if(O[a]+i<255){P[r]=a,n.setPickBase(O[a]+1),O[a]+=i;continue t}var o=s(x,N);P[r]=e,z.push(o),O.push(i),n.setPickBase(1),e+=1}else P[r]=-1}for(;e>0&&0===O[e-1];)O.pop(),z.pop().dispose()}function G(){if(U.contextLost)return!0;x.isContextLost()&&(U.contextLost=!0,U.mouseListener.enabled=!1,U.selection.object=null,U.oncontextloss&&U.oncontextloss())}window.addEventListener(\"resize\",q),U.update=function(t){U._stopped||(t=t||{},I=!0,D=!0)},U.add=function(t){U._stopped||(t.axes=S,L.push(t),P.push(-1),I=!0,D=!0,H())},U.remove=function(t){if(!U._stopped){var e=L.indexOf(t);e<0||(L.splice(e,1),P.pop(),I=!0,D=!0,H())}},U.dispose=function(){if(!U._stopped&&(U._stopped=!0,window.removeEventListener(\"resize\",q),e.removeEventListener(\"webglcontextlost\",G),U.mouseListener.enabled=!1,!U.contextLost)){S.dispose(),C.dispose();for(var t=0;t<L.length;++t)L[t].dispose();w.dispose();for(var t=0;t<z.length;++t)z[t].dispose();k.dispose(),x=null,S=null,C=null,L=[]}},U.wheelListener=h(e,function(t,e){if(!1!==j.keyBindingMode&&j.enableWheel&&j._ortho){var r=t>e?1.1:1/1.1;U.aspect[0]*=r,U.aspect[1]*=r,U.aspect[2]*=r,U.redraw()}},!0),U._mouseRotating=!1,U._prevButtons=0,U.enableMouseListeners=function(){U.mouseListener=u(e,function(t,e,r){if(!U._stopped){var n=z.length,i=L.length,a=_.object;_.distance=1/0,_.mouse[0]=e,_.mouse[1]=r,_.object=null,_.screen=null,_.dataCoordinate=_.dataPosition=null;var o=!1;if(t&&U._prevButtons)U._mouseRotating=!0;else{U._mouseRotating&&(D=!0),U._mouseRotating=!1;for(var s=0;s<n;++s){var l=z[s].query(e,V[1]-r-1,U.pickRadius);if(l){if(l.distance>_.distance)continue;for(var c=0;c<i;++c){var u=L[c];if(P[c]===s){var h=u.pick(l);h&&(_.buttons=t,_.screen=l.coord,_.distance=l.distance,_.object=u,_.index=h.distance,_.dataPosition=h.position,_.dataCoordinate=h.dataCoordinate,_.data=h,o=!0)}}}}}a&&a!==_.object&&(a.highlight&&a.highlight(null),I=!0),_.object&&(_.object.highlight&&_.object.highlight(_.data),I=!0),(o=o||_.object!==a)&&U.onselect&&U.onselect(_),1&t&&!(1&U._prevButtons)&&U.onclick&&U.onclick(_),U._prevButtons=t}})},e.addEventListener(\"webglcontextlost\",G);var Y=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],W=[Y[0].slice(),Y[1].slice()];function X(){if(!G()){q();var t=U.camera.tick();B.view=U.camera.matrix,I=I||t,D=D||t,S.pixelRatio=U.pixelRatio,C.pixelRatio=U.pixelRatio;var e=L.length,r=Y[0],n=Y[1];r[0]=r[1]=r[2]=1/0,n[0]=n[1]=n[2]=-1/0;for(var i=0;i<e;++i){var o=L[i];o.pixelRatio=U.pixelRatio,o.axes=U.axes,I=I||!!o.dirty,D=D||!!o.dirty;var s=o.bounds;if(s)for(var l=s[0],u=s[1],h=0;h<3;++h)r[h]=Math.min(r[h],l[h]),n[h]=Math.max(n[h],u[h])}var d=U.bounds;if(U.autoBounds)for(var h=0;h<3;++h){if(n[h]<r[h])r[h]=-1,n[h]=1;else{r[h]===n[h]&&(r[h]-=1,n[h]+=1);var g=.05*(n[h]-r[h]);r[h]=r[h]-g,n[h]=n[h]+g}d[0][h]=r[h],d[1][h]=n[h]}for(var v=!1,h=0;h<3;++h)v=v||W[0][h]!==d[0][h]||W[1][h]!==d[1][h],W[0][h]=d[0][h],W[1][h]=d[1][h];if(D=D||v,I=I||v){if(v){for(var y=[0,0,0],i=0;i<3;++i)y[i]=m((d[1][i]-d[0][i])/10);S.autoTicks?S.update({bounds:d,tickSpacing:y}):S.update({bounds:d})}var b=x.drawingBufferWidth,A=x.drawingBufferHeight;N[0]=b,N[1]=A,V[0]=0|Math.max(b/U.pixelRatio,1),V[1]=0|Math.max(A/U.pixelRatio,1),T?(p(R,-b/A,b/A,-1,1,U.zNear,U.zFar),B._ortho=!0):(f(R,U.fovy,b/A,U.zNear,U.zFar),B._ortho=!1);for(var i=0;i<16;++i)F[i]=0;F[15]=1;for(var M=0,i=0;i<3;++i)M=Math.max(M,d[1][i]-d[0][i]);for(var i=0;i<3;++i)U.autoScale?F[5*i]=U.aspect[i]/(d[1][i]-d[0][i]):F[5*i]=1/M,U.autoCenter&&(F[12+i]=.5*-F[5*i]*(d[0][i]+d[1][i]));for(var i=0;i<e;++i){var o=L[i];o.axesBounds=d,U.clipToBounds&&(o.clipBounds=d)}_.object&&(U.snapToData?C.position=_.dataCoordinate:C.position=_.dataPosition,C.bounds=d),D&&(D=!1,function(){if(G())return;x.colorMask(!0,!0,!0,!0),x.depthMask(!0),x.disable(x.BLEND),x.enable(x.DEPTH_TEST);for(var t=L.length,e=z.length,r=0;r<e;++r){var n=z[r];n.shape=V,n.begin();for(var i=0;i<t;++i)if(P[i]===r){var a=L[i];a.drawPick&&(a.pixelRatio=1,a.drawPick(B))}n.end()}}()),U.axesPixels=a(U.axes,B,b,A),U.onrender&&U.onrender(),x.bindFramebuffer(x.FRAMEBUFFER,null),x.viewport(0,0,b,A);var E=U.clearColor;x.clearColor(E[0],E[1],E[2],E[3]),x.clear(x.COLOR_BUFFER_BIT|x.DEPTH_BUFFER_BIT),x.depthMask(!0),x.colorMask(!0,!0,!0,!0),x.enable(x.DEPTH_TEST),x.depthFunc(x.LEQUAL),x.disable(x.BLEND),x.disable(x.CULL_FACE);var O=!1;S.enable&&(O=O||S.isTransparent(),S.draw(B)),C.axes=S,_.object&&C.draw(B),x.disable(x.CULL_FACE);for(var i=0;i<e;++i){var o=L[i];o.axes=S,o.pixelRatio=U.pixelRatio,o.isOpaque&&o.isOpaque()&&o.draw(B),o.isTransparent&&o.isTransparent()&&(O=!0)}if(O){w.shape=N,w.bind(),x.clear(x.DEPTH_BUFFER_BIT),x.colorMask(!1,!1,!1,!1),x.depthMask(!0),x.depthFunc(x.LESS),S.enable&&S.isTransparent()&&S.drawTransparent(B);for(var i=0;i<e;++i){var o=L[i];o.isOpaque&&o.isOpaque()&&o.draw(B)}x.enable(x.BLEND),x.blendEquation(x.FUNC_ADD),x.blendFunc(x.ONE,x.ONE_MINUS_SRC_ALPHA),x.colorMask(!0,!0,!0,!0),x.depthMask(!1),x.clearColor(0,0,0,0),x.clear(x.COLOR_BUFFER_BIT),S.isTransparent()&&S.drawTransparent(B);for(var i=0;i<e;++i){var o=L[i];o.isTransparent&&o.isTransparent()&&o.drawTransparent(B)}x.bindFramebuffer(x.FRAMEBUFFER,null),x.blendFunc(x.ONE,x.ONE_MINUS_SRC_ALPHA),x.disable(x.DEPTH_TEST),k.bind(),w.color[0].bind(0),k.uniforms.accumBuffer=0,c(x),x.disable(x.BLEND)}I=!1;for(var i=0;i<e;++i)L[i].dirty=!1}}}return U.enableMouseListeners(),function t(){U._stopped||U.contextLost||(X(),requestAnimationFrame(t))}(),U.redraw=function(){U._stopped||(I=!0,X())},U},createCamera:n}},{\"./camera.js\":288,\"./lib/shader\":289,\"a-big-triangle\":59,\"gl-axes3d\":233,\"gl-axes3d/properties\":240,\"gl-fbo\":249,\"gl-mat4/ortho\":268,\"gl-mat4/perspective\":269,\"gl-select-static\":300,\"gl-spikes3d\":310,\"is-mobile\":420,\"mouse-change\":435,\"mouse-wheel\":438}],291:[function(t,e,r){var n=t(\"glslify\");r.pointVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform float pointCloud;\\n\\nhighp float rand(vec2 co) {\\n  highp float a = 12.9898;\\n  highp float b = 78.233;\\n  highp float c = 43758.5453;\\n  highp float d = dot(co.xy, vec2(a, b));\\n  highp float e = mod(d, 3.14);\\n  return fract(sin(e) * c);\\n}\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n    // if we don't jitter the point size a bit, overall point cloud\\n    // saturation 'jumps' on zooming, which is disturbing and confusing\\n  gl_PointSize = pointSize * ((19.5 + rand(position)) / 20.0);\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    // get the same square surface as circle would be\\n    gl_PointSize *= 0.886;\\n  }\\n}\"]),r.pointFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color, borderColor;\\nuniform float centerFraction;\\nuniform float pointCloud;\\n\\nvoid main() {\\n  float radius;\\n  vec4 baseColor;\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    if(centerFraction == 1.0) {\\n      gl_FragColor = color;\\n    } else {\\n      gl_FragColor = mix(borderColor, color, centerFraction);\\n    }\\n  } else {\\n    radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n    if(radius > 1.0) {\\n      discard;\\n    }\\n    baseColor = mix(borderColor, color, step(radius, centerFraction));\\n    gl_FragColor = vec4(baseColor.rgb * baseColor.a, baseColor.a);\\n  }\\n}\\n\"]),r.pickVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform vec4 pickOffset;\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n  gl_PointSize = pointSize;\\n\\n  vec4 id = pickId + pickOffset;\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  fragId = id;\\n}\\n\"]),r.pickFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  float radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n  if(radius > 1.0) {\\n    discard;\\n  }\\n  gl_FragColor = fragId / 255.0;\\n}\\n\"])},{glslify:409}],292:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"typedarray-pool\"),o=t(\"./lib/shader\");function s(t,e,r,n,i){this.plot=t,this.offsetBuffer=e,this.pickBuffer=r,this.shader=n,this.pickShader=i,this.sizeMin=.5,this.sizeMinCap=2,this.sizeMax=20,this.areaRatio=1,this.pointCount=0,this.color=[1,0,0,1],this.borderColor=[0,0,0,1],this.blend=!1,this.pickOffset=0,this.points=null}e.exports=function(t,e){var r=t.gl,a=i(r),l=i(r),c=n(r,o.pointVertex,o.pointFragment),u=n(r,o.pickVertex,o.pickFragment),h=new s(t,a,l,c,u);return h.update(e),t.addObject(h),h};var l,c,u=s.prototype;u.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.offsetBuffer.dispose(),this.pickBuffer.dispose(),this.plot.removeObject(this)},u.update=function(t){var e;function r(e,r){return e in t?t[e]:r}t=t||{},this.sizeMin=r(\"sizeMin\",.5),this.sizeMax=r(\"sizeMax\",20),this.color=r(\"color\",[1,0,0,1]).slice(),this.areaRatio=r(\"areaRatio\",1),this.borderColor=r(\"borderColor\",[0,0,0,1]).slice(),this.blend=r(\"blend\",!1);var n=t.positions.length>>>1,i=t.positions instanceof Float32Array,o=t.idToIndex instanceof Int32Array&&t.idToIndex.length>=n,s=t.positions,l=i?s:a.mallocFloat32(s.length),c=o?t.idToIndex:a.mallocInt32(n);if(i||l.set(s),!o)for(l.set(s),e=0;e<n;e++)c[e]=e;this.points=s,this.offsetBuffer.update(l),this.pickBuffer.update(c),i||a.free(l),o||a.free(c),this.pointCount=n,this.pickOffset=0},u.unifiedDraw=(l=[1,0,0,0,1,0,0,0,1],c=[0,0,0,0],function(t){var e=void 0!==t,r=e?this.pickShader:this.shader,n=this.plot.gl,i=this.plot.dataBox;if(0===this.pointCount)return t;var a=i[2]-i[0],o=i[3]-i[1],s=function(t,e){var r,n=0,i=t.length>>>1;for(r=0;r<i;r++){var a=t[2*r],o=t[2*r+1];a>=e[0]&&a<=e[2]&&o>=e[1]&&o<=e[3]&&n++}return n}(this.points,i),u=this.plot.pickPixelRatio*Math.max(Math.min(this.sizeMinCap,this.sizeMin),Math.min(this.sizeMax,this.sizeMax/Math.pow(s,.33333)));l[0]=2/a,l[4]=2/o,l[6]=-2*i[0]/a-1,l[7]=-2*i[1]/o-1,this.offsetBuffer.bind(),r.bind(),r.attributes.position.pointer(),r.uniforms.matrix=l,r.uniforms.color=this.color,r.uniforms.borderColor=this.borderColor,r.uniforms.pointCloud=u<5,r.uniforms.pointSize=u,r.uniforms.centerFraction=Math.min(1,Math.max(0,Math.sqrt(1-this.areaRatio))),e&&(c[0]=255&t,c[1]=t>>8&255,c[2]=t>>16&255,c[3]=t>>24&255,this.pickBuffer.bind(),r.attributes.pickId.pointer(n.UNSIGNED_BYTE),r.uniforms.pickOffset=c,this.pickOffset=t);var h=n.getParameter(n.BLEND),f=n.getParameter(n.DITHER);return h&&!this.blend&&n.disable(n.BLEND),f&&n.disable(n.DITHER),n.drawArrays(n.POINTS,0,this.pointCount),h&&!this.blend&&n.enable(n.BLEND),f&&n.enable(n.DITHER),t+this.pointCount}),u.draw=u.unifiedDraw,u.drawPick=u.unifiedDraw,u.pick=function(t,e,r){var n=this.pickOffset,i=this.pointCount;if(r<n||r>=n+i)return null;var a=r-n,o=this.points;return{object:this,pointId:a,dataCoord:[o[2*a],o[2*a+1]]}}},{\"./lib/shader\":291,\"gl-buffer\":241,\"gl-shader\":301,\"typedarray-pool\":545}],293:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c=e[0],u=e[1],h=e[2],f=e[3],p=r[0],d=r[1],g=r[2],v=r[3];(a=c*p+u*d+h*g+f*v)<0&&(a=-a,p=-p,d=-d,g=-g,v=-v);1-a>1e-6?(i=Math.acos(a),o=Math.sin(i),s=Math.sin((1-n)*i)/o,l=Math.sin(n*i)/o):(s=1-n,l=n);return t[0]=s*c+l*p,t[1]=s*u+l*d,t[2]=s*h+l*g,t[3]=s*f+l*v,t}},{}],294:[function(t,e,r){\"use strict\";e.exports=function(t){return t||0===t?t.toString():\"\"}},{}],295:[function(t,e,r){\"use strict\";var n=t(\"vectorize-text\");e.exports=function(t,e,r){var a=i[e];a||(a=i[e]={});if(t in a)return a[t];var o={textAlign:\"center\",textBaseline:\"middle\",lineHeight:1,font:e,lineSpacing:1.25,styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},triangles:!0},s=n(t,o);o.triangles=!1;var l,c,u=n(t,o);if(r&&1!==r){for(l=0;l<s.positions.length;++l)for(c=0;c<s.positions[l].length;++c)s.positions[l][c]/=r;for(l=0;l<u.positions.length;++l)for(c=0;c<u.positions[l].length;++c)u.positions[l][c]/=r}var h=[[1/0,1/0],[-1/0,-1/0]],f=u.positions.length;for(l=0;l<f;++l){var p=u.positions[l];for(c=0;c<2;++c)h[0][c]=Math.min(h[0][c],p[c]),h[1][c]=Math.max(h[1][c],p[c])}return a[t]=[s,u,h]};var i={}},{\"vectorize-text\":550}],296:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform vec4 highlightId;\\nuniform float highlightScale;\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = 1.0;\\n    if(distance(highlightId, id) < 0.0001) {\\n      scale = highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1);\\n    vec4 viewPosition = view * worldPosition;\\n    viewPosition = viewPosition / viewPosition.w;\\n    vec4 clipPosition = projection * (viewPosition + scale * vec4(glyph.x, -glyph.y, 0, 0));\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float highlightScale, pixelRatio;\\nuniform vec4 highlightId;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = pixelRatio;\\n    if(distance(highlightId.bgr, id.bgr) < 0.001) {\\n      scale *= highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1.0);\\n    vec4 viewPosition = view * worldPosition;\\n    vec4 clipPosition = projection * viewPosition;\\n    clipPosition /= clipPosition.w;\\n\\n    gl_Position = clipPosition + vec4(screenSize * scale * vec2(glyph.x, -glyph.y), 0.0, 0.0);\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform float highlightScale;\\nuniform vec4 highlightId;\\nuniform vec3 axes[2];\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float scale, pixelRatio;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float lscale = pixelRatio * scale;\\n    if(distance(highlightId, id) < 0.0001) {\\n      lscale *= highlightScale;\\n    }\\n\\n    vec4 clipCenter   = projection * view * model * vec4(position, 1);\\n    vec3 dataPosition = position + 0.5*lscale*(axes[0] * glyph.x + axes[1] * glyph.y) * clipCenter.w * screenSize.y;\\n    vec4 clipPosition = projection * view * model * vec4(dataPosition, 1);\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = dataPosition;\\n  }\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float opacity;\\n\\nvarying vec4 interpColor;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (\\n    outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate) ||\\n    interpColor.a * opacity == 0.\\n  ) discard;\\n  gl_FragColor = interpColor * opacity;\\n}\\n\"]),c=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float pickGroup;\\n\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate)) discard;\\n\\n  gl_FragColor = vec4(pickGroup, pickId.bgr);\\n}\"]),u=[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"glyph\",type:\"vec2\"},{name:\"id\",type:\"vec4\"}],h={vertex:a,fragment:l,attributes:u},f={vertex:o,fragment:l,attributes:u},p={vertex:s,fragment:l,attributes:u},d={vertex:a,fragment:c,attributes:u},g={vertex:o,fragment:c,attributes:u},v={vertex:s,fragment:c,attributes:u};function m(t,e){var r=n(t,e),i=r.attributes;return i.position.location=0,i.color.location=1,i.glyph.location=2,i.id.location=3,r}r.createPerspective=function(t){return m(t,h)},r.createOrtho=function(t){return m(t,f)},r.createProject=function(t){return m(t,p)},r.createPickPerspective=function(t){return m(t,d)},r.createPickOrtho=function(t){return m(t,g)},r.createPickProject=function(t){return m(t,v)}},{\"gl-shader\":301,glslify:409}],297:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"typedarray-pool\"),s=t(\"gl-mat4/multiply\"),l=t(\"./lib/shaders\"),c=t(\"./lib/glyphs\"),u=t(\"./lib/get-simple-string\"),h=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function f(t,e){var r=t[0],n=t[1],i=t[2],a=t[3];return t[0]=e[0]*r+e[4]*n+e[8]*i+e[12]*a,t[1]=e[1]*r+e[5]*n+e[9]*i+e[13]*a,t[2]=e[2]*r+e[6]*n+e[10]*i+e[14]*a,t[3]=e[3]*r+e[7]*n+e[11]*i+e[15]*a,t}function p(t,e,r,n){return f(n,n),f(n,n),f(n,n)}function d(t,e){this.index=t,this.dataCoordinate=this.position=e}function g(t){return!0===t?1:t>1?1:t}function v(t,e,r,n,i,a,o,s,l,c,u,h){this.gl=t,this.pixelRatio=1,this.shader=e,this.orthoShader=r,this.projectShader=n,this.pointBuffer=i,this.colorBuffer=a,this.glyphBuffer=o,this.idBuffer=s,this.vao=l,this.vertexCount=0,this.lineVertexCount=0,this.opacity=1,this.hasAlpha=!1,this.lineWidth=0,this.projectScale=[2/3,2/3,2/3],this.projectOpacity=[1,1,1],this.projectHasAlpha=!1,this.pickId=0,this.pickPerspectiveShader=c,this.pickOrthoShader=u,this.pickProjectShader=h,this.points=[],this._selectResult=new d(0,[0,0,0]),this.useOrtho=!0,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.axesProject=[!0,!0,!0],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.highlightId=[1,1,1,1],this.highlightScale=2,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.dirty=!0}e.exports=function(t){var e=t.gl,r=l.createPerspective(e),n=l.createOrtho(e),o=l.createProject(e),s=l.createPickPerspective(e),c=l.createPickOrtho(e),u=l.createPickProject(e),h=i(e),f=i(e),p=i(e),d=i(e),g=a(e,[{buffer:h,size:3,type:e.FLOAT},{buffer:f,size:4,type:e.FLOAT},{buffer:p,size:2,type:e.FLOAT},{buffer:d,size:4,type:e.UNSIGNED_BYTE,normalized:!0}]),m=new v(e,r,n,o,h,f,p,d,g,s,c,u);return m.update(t),m};var m=v.prototype;m.pickSlots=1,m.setPickBase=function(t){this.pickId=t},m.isTransparent=function(){if(this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&this.projectHasAlpha)return!0;return!1},m.isOpaque=function(){if(!this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&!this.projectHasAlpha)return!0;return!1};var y=[0,0],x=[0,0,0],b=[0,0,0],_=[0,0,0,1],w=[0,0,0,1],k=h.slice(),T=[0,0,0],A=[[0,0,0],[0,0,0]];function M(t){return t[0]=t[1]=t[2]=0,t}function S(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=1,t}function E(t,e,r,n){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[r]=n,t}function C(t,e,r,n){var i,a=e.axesProject,o=e.gl,l=t.uniforms,c=r.model||h,u=r.view||h,f=r.projection||h,d=e.axesBounds,g=function(t){for(var e=A,r=0;r<2;++r)for(var n=0;n<3;++n)e[r][n]=Math.max(Math.min(t[r][n],1e8),-1e8);return e}(e.clipBounds);i=e.axes&&e.axes.lastCubeProps?e.axes.lastCubeProps.axis:[1,1,1],y[0]=2/o.drawingBufferWidth,y[1]=2/o.drawingBufferHeight,t.bind(),l.view=u,l.projection=f,l.screenSize=y,l.highlightId=e.highlightId,l.highlightScale=e.highlightScale,l.clipBounds=g,l.pickGroup=e.pickId/255,l.pixelRatio=n;for(var v=0;v<3;++v)if(a[v]){l.scale=e.projectScale[v],l.opacity=e.projectOpacity[v];for(var m=k,C=0;C<16;++C)m[C]=0;for(C=0;C<4;++C)m[5*C]=1;m[5*v]=0,i[v]<0?m[12+v]=d[0][v]:m[12+v]=d[1][v],s(m,c,m),l.model=m;var L=(v+1)%3,P=(v+2)%3,O=M(x),z=M(b);O[L]=1,z[P]=1;var I=p(0,0,0,S(_,O)),D=p(0,0,0,S(w,z));if(Math.abs(I[1])>Math.abs(D[1])){var R=I;I=D,D=R,R=O,O=z,z=R;var F=L;L=P,P=F}I[0]<0&&(O[L]=-1),D[1]>0&&(z[P]=-1);var B=0,N=0;for(C=0;C<4;++C)B+=Math.pow(c[4*L+C],2),N+=Math.pow(c[4*P+C],2);O[L]/=Math.sqrt(B),z[P]/=Math.sqrt(N),l.axes[0]=O,l.axes[1]=z,l.fragClipBounds[0]=E(T,g[0],v,-1e8),l.fragClipBounds[1]=E(T,g[1],v,1e8),e.vao.bind(),e.vao.draw(o.TRIANGLES,e.vertexCount),e.lineWidth>0&&(o.lineWidth(e.lineWidth*n),e.vao.draw(o.LINES,e.lineVertexCount,e.vertexCount)),e.vao.unbind()}}var L=[[-1e8,-1e8,-1e8],[1e8,1e8,1e8]];function P(t,e,r,n,i,a,o){var s=r.gl;if((a===r.projectHasAlpha||o)&&C(e,r,n,i),a===r.hasAlpha||o){t.bind();var l=t.uniforms;l.model=n.model||h,l.view=n.view||h,l.projection=n.projection||h,y[0]=2/s.drawingBufferWidth,y[1]=2/s.drawingBufferHeight,l.screenSize=y,l.highlightId=r.highlightId,l.highlightScale=r.highlightScale,l.fragClipBounds=L,l.clipBounds=r.axes.bounds,l.opacity=r.opacity,l.pickGroup=r.pickId/255,l.pixelRatio=i,r.vao.bind(),r.vao.draw(s.TRIANGLES,r.vertexCount),r.lineWidth>0&&(s.lineWidth(r.lineWidth*i),r.vao.draw(s.LINES,r.lineVertexCount,r.vertexCount)),r.vao.unbind()}}function O(t,e,r,i){var a;a=Array.isArray(t)?e<t.length?t[e]:void 0:t,a=u(a);var o=!0;n(a)&&(a=\"\\u25bc\",o=!1);var s=c(a,r,i);return{mesh:s[0],lines:s[1],bounds:s[2],visible:o}}m.draw=function(t){P(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!1,!1)},m.drawTransparent=function(t){P(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!0,!1)},m.drawPick=function(t){P(this.useOrtho?this.pickOrthoShader:this.pickPerspectiveShader,this.pickProjectShader,this,t,1,!0,!0)},m.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[2]+(t.value[1]<<8)+(t.value[0]<<16);if(e>=this.pointCount||e<0)return null;var r=this.points[e],n=this._selectResult;n.index=e;for(var i=0;i<3;++i)n.position[i]=n.dataCoordinate[i]=r[i];return n},m.highlight=function(t){if(t){var e=t.index,r=255&e,n=e>>8&255,i=e>>16&255;this.highlightId=[r/255,n/255,i/255,0]}else this.highlightId=[1,1,1,1]},m.update=function(t){if(\"perspective\"in(t=t||{})&&(this.useOrtho=!t.perspective),\"orthographic\"in t&&(this.useOrtho=!!t.orthographic),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"project\"in t)if(Array.isArray(t.project))this.axesProject=t.project;else{var e=!!t.project;this.axesProject=[e,e,e]}if(\"projectScale\"in t)if(Array.isArray(t.projectScale))this.projectScale=t.projectScale.slice();else{var r=+t.projectScale;this.projectScale=[r,r,r]}if(this.projectHasAlpha=!1,\"projectOpacity\"in t){if(Array.isArray(t.projectOpacity))this.projectOpacity=t.projectOpacity.slice();else{r=+t.projectOpacity;this.projectOpacity=[r,r,r]}for(var n=0;n<3;++n)this.projectOpacity[n]=g(this.projectOpacity[n]),this.projectOpacity[n]<1&&(this.projectHasAlpha=!0)}this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=g(t.opacity),this.opacity<1&&(this.hasAlpha=!0)),this.dirty=!0;var i,a,s=t.position,l=t.font||\"normal\",c=t.alignment||[0,0];if(2===c.length)i=c[0],a=c[1];else{i=[],a=[];for(n=0;n<c.length;++n)i[n]=c[n][0],a[n]=c[n][1]}var u=[1/0,1/0,1/0],h=[-1/0,-1/0,-1/0],f=t.glyph,p=t.color,d=t.size,v=t.angle,m=t.lineColor,y=-1,x=0,b=0,_=0;if(s.length){_=s.length;t:for(n=0;n<_;++n){for(var w=s[n],k=0;k<3;++k)if(isNaN(w[k])||!isFinite(w[k]))continue t;var T=(N=O(f,n,l,this.pixelRatio)).mesh,A=N.lines,M=N.bounds;x+=3*T.cells.length,b+=2*A.edges.length}}var S=x+b,E=o.mallocFloat(3*S),C=o.mallocFloat(4*S),L=o.mallocFloat(2*S),P=o.mallocUint32(S);if(S>0){var z=0,I=x,D=[0,0,0,1],R=[0,0,0,1],F=Array.isArray(p)&&Array.isArray(p[0]),B=Array.isArray(m)&&Array.isArray(m[0]);t:for(n=0;n<_;++n){y+=1;for(w=s[n],k=0;k<3;++k){if(isNaN(w[k])||!isFinite(w[k]))continue t;h[k]=Math.max(h[k],w[k]),u[k]=Math.min(u[k],w[k])}T=(N=O(f,n,l,this.pixelRatio)).mesh,A=N.lines,M=N.bounds;var N,j=N.visible;if(j)if(Array.isArray(p)){if(3===(U=F?n<p.length?p[n]:[0,0,0,0]:p).length){for(k=0;k<3;++k)D[k]=U[k];D[3]=1}else if(4===U.length){for(k=0;k<4;++k)D[k]=U[k];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else D[0]=D[1]=D[2]=0,D[3]=1;else D=[1,1,1,0];if(j)if(Array.isArray(m)){var U;if(3===(U=B?n<m.length?m[n]:[0,0,0,0]:m).length){for(k=0;k<3;++k)R[k]=U[k];R[k]=1}else if(4===U.length){for(k=0;k<4;++k)R[k]=U[k];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else R[0]=R[1]=R[2]=0,R[3]=1;else R=[1,1,1,0];var V=.5;j?Array.isArray(d)?V=n<d.length?+d[n]:12:d?V=+d:this.useOrtho&&(V=12):V=0;var q=0;Array.isArray(v)?q=n<v.length?+v[n]:0:v&&(q=+v);var H=Math.cos(q),G=Math.sin(q);for(w=s[n],k=0;k<3;++k)h[k]=Math.max(h[k],w[k]),u[k]=Math.min(u[k],w[k]);var Y=i,W=a;Y=0;Array.isArray(i)?Y=n<i.length?i[n]:0:i&&(Y=i);W=0;Array.isArray(a)?W=n<a.length?a[n]:0:a&&(W=a);var X=[Y*=Y>0?1-M[0][0]:Y<0?1+M[1][0]:1,W*=W>0?1-M[0][1]:W<0?1+M[1][1]:1],Z=T.cells||[],J=T.positions||[];for(k=0;k<Z.length;++k)for(var K=Z[k],$=0;$<3;++$){for(var Q=0;Q<3;++Q)E[3*z+Q]=w[Q];for(Q=0;Q<4;++Q)C[4*z+Q]=D[Q];P[z]=y;var tt=J[K[$]];L[2*z]=V*(H*tt[0]-G*tt[1]+X[0]),L[2*z+1]=V*(G*tt[0]+H*tt[1]+X[1]),z+=1}for(Z=A.edges,J=A.positions,k=0;k<Z.length;++k)for(K=Z[k],$=0;$<2;++$){for(Q=0;Q<3;++Q)E[3*I+Q]=w[Q];for(Q=0;Q<4;++Q)C[4*I+Q]=R[Q];P[I]=y;tt=J[K[$]];L[2*I]=V*(H*tt[0]-G*tt[1]+X[0]),L[2*I+1]=V*(G*tt[0]+H*tt[1]+X[1]),I+=1}}}this.bounds=[u,h],this.points=s,this.pointCount=s.length,this.vertexCount=x,this.lineVertexCount=b,this.pointBuffer.update(E),this.colorBuffer.update(C),this.glyphBuffer.update(L),this.idBuffer.update(P),o.free(E),o.free(C),o.free(L),o.free(P)},m.dispose=function(){this.shader.dispose(),this.orthoShader.dispose(),this.pickPerspectiveShader.dispose(),this.pickOrthoShader.dispose(),this.vao.dispose(),this.pointBuffer.dispose(),this.colorBuffer.dispose(),this.glyphBuffer.dispose(),this.idBuffer.dispose()}},{\"./lib/get-simple-string\":294,\"./lib/glyphs\":295,\"./lib/shaders\":296,\"gl-buffer\":241,\"gl-mat4/multiply\":267,\"gl-vao\":327,\"is-string-blank\":423,\"typedarray-pool\":545}],298:[function(t,e,r){\"use strict\";var n=t(\"glslify\");r.boxVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 vertex;\\n\\nuniform vec2 cornerA, cornerB;\\n\\nvoid main() {\\n  gl_Position = vec4(mix(cornerA, cornerB, vertex), 0, 1);\\n}\\n\"]),r.boxFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\n\\nvoid main() {\\n  gl_FragColor = color;\\n}\\n\"])},{glslify:409}],299:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"./lib/shaders\");function o(t,e,r){this.plot=t,this.boxBuffer=e,this.boxShader=r,this.enabled=!0,this.selectBox=[1/0,1/0,-1/0,-1/0],this.borderColor=[0,0,0,1],this.innerFill=!1,this.innerColor=[0,0,0,.25],this.outerFill=!0,this.outerColor=[0,0,0,.5],this.borderWidth=10}e.exports=function(t,e){var r=t.gl,s=i(r,[0,0,0,1,1,0,1,1]),l=n(r,a.boxVertex,a.boxFragment),c=new o(t,s,l);return c.update(e),t.addOverlay(c),c};var s=o.prototype;s.draw=function(){if(this.enabled){var t=this.plot,e=this.selectBox,r=this.borderWidth,n=(this.innerFill,this.innerColor),i=(this.outerFill,this.outerColor),a=this.borderColor,o=t.box,s=t.screenBox,l=t.dataBox,c=t.viewBox,u=t.pixelRatio,h=(e[0]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],f=(e[1]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1],p=(e[2]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],d=(e[3]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1];if(h=Math.max(h,c[0]),f=Math.max(f,c[1]),p=Math.min(p,c[2]),d=Math.min(d,c[3]),!(p<h||d<f)){o.bind();var g=s[2]-s[0],v=s[3]-s[1];if(this.outerFill&&(o.drawBox(0,0,g,f,i),o.drawBox(0,f,h,d,i),o.drawBox(0,d,g,v,i),o.drawBox(p,f,g,d,i)),this.innerFill&&o.drawBox(h,f,p,d,n),r>0){var m=r*u;o.drawBox(h-m,f-m,p+m,f+m,a),o.drawBox(h-m,d-m,p+m,d+m,a),o.drawBox(h-m,f-m,h+m,d+m,a),o.drawBox(p-m,f-m,p+m,d+m,a)}}}},s.update=function(t){t=t||{},this.innerFill=!!t.innerFill,this.outerFill=!!t.outerFill,this.innerColor=(t.innerColor||[0,0,0,.5]).slice(),this.outerColor=(t.outerColor||[0,0,0,.5]).slice(),this.borderColor=(t.borderColor||[0,0,0,1]).slice(),this.borderWidth=t.borderWidth||0,this.selectBox=(t.selectBox||this.selectBox).slice()},s.dispose=function(){this.boxBuffer.dispose(),this.boxShader.dispose(),this.plot.removeOverlay(this)}},{\"./lib/shaders\":298,\"gl-buffer\":241,\"gl-shader\":301}],300:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=n(t,e),a=i.mallocUint8(e[0]*e[1]*4);return new c(t,r,a)};var n=t(\"gl-fbo\"),i=t(\"typedarray-pool\"),a=t(\"ndarray\"),o=t(\"bit-twiddle\").nextPow2,s=t(\"cwise/lib/wrapper\")({args:[\"array\",{offset:[0,0,1],array:0},{offset:[0,0,2],array:0},{offset:[0,0,3],array:0},\"scalar\",\"scalar\",\"index\"],pre:{body:\"{this_closestD2=1e8,this_closestX=-1,this_closestY=-1}\",args:[],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[]},body:{body:\"{if(_inline_16_arg0_<255||_inline_16_arg1_<255||_inline_16_arg2_<255||_inline_16_arg3_<255){var _inline_16_l=_inline_16_arg4_-_inline_16_arg6_[0],_inline_16_a=_inline_16_arg5_-_inline_16_arg6_[1],_inline_16_f=_inline_16_l*_inline_16_l+_inline_16_a*_inline_16_a;_inline_16_f<this_closestD2&&(this_closestD2=_inline_16_f,this_closestX=_inline_16_arg6_[0],this_closestY=_inline_16_arg6_[1])}}\",args:[{name:\"_inline_16_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg4_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg5_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg6_\",lvalue:!1,rvalue:!0,count:4}],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[\"_inline_16_a\",\"_inline_16_f\",\"_inline_16_l\"]},post:{body:\"{return[this_closestX,this_closestY,this_closestD2]}\",args:[],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[]},debug:!1,funcName:\"cwise\",blockSize:64});function l(t,e,r,n,i){this.coord=[t,e],this.id=r,this.value=n,this.distance=i}function c(t,e,r){this.gl=t,this.fbo=e,this.buffer=r,this._readTimeout=null;var n=this;this._readCallback=function(){n.gl&&(e.bind(),t.readPixels(0,0,e.shape[0],e.shape[1],t.RGBA,t.UNSIGNED_BYTE,n.buffer),n._readTimeout=null)}}var u=c.prototype;Object.defineProperty(u,\"shape\",{get:function(){return this.gl?this.fbo.shape.slice():[0,0]},set:function(t){if(this.gl){this.fbo.shape=t;var e=this.fbo.shape[0],r=this.fbo.shape[1];if(r*e*4>this.buffer.length){i.free(this.buffer);for(var n=this.buffer=i.mallocUint8(o(r*e*4)),a=0;a<r*e*4;++a)n[a]=255}return t}}}),u.begin=function(){var t=this.gl;this.shape;t&&(this.fbo.bind(),t.clearColor(1,1,1,1),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT))},u.end=function(){var t=this.gl;t&&(t.bindFramebuffer(t.FRAMEBUFFER,null),this._readTimeout||clearTimeout(this._readTimeout),this._readTimeout=setTimeout(this._readCallback,1))},u.query=function(t,e,r){if(!this.gl)return null;var n=this.fbo.shape.slice();t|=0,e|=0,\"number\"!=typeof r&&(r=1);var i=0|Math.min(Math.max(t-r,0),n[0]),o=0|Math.min(Math.max(t+r,0),n[0]),c=0|Math.min(Math.max(e-r,0),n[1]),u=0|Math.min(Math.max(e+r,0),n[1]);if(o<=i||u<=c)return null;var h=[o-i,u-c],f=a(this.buffer,[h[0],h[1],4],[4,4*n[0],1],4*(i+n[0]*c)),p=s(f.hi(h[0],h[1],1),r,r),d=p[0],g=p[1];return d<0||Math.pow(this.radius,2)<p[2]?null:new l(d+i|0,g+c|0,f.get(d,g,0),[f.get(d,g,1),f.get(d,g,2),f.get(d,g,3)],Math.sqrt(p[2]))},u.dispose=function(){this.gl&&(this.fbo.dispose(),i.free(this.buffer),this.gl=null,this._readTimeout&&clearTimeout(this._readTimeout))}},{\"bit-twiddle\":92,\"cwise/lib/wrapper\":149,\"gl-fbo\":249,ndarray:450,\"typedarray-pool\":545}],301:[function(t,e,r){\"use strict\";var n=t(\"./lib/create-uniforms\"),i=t(\"./lib/create-attributes\"),a=t(\"./lib/reflect\"),o=t(\"./lib/shader-cache\"),s=t(\"./lib/runtime-reflect\"),l=t(\"./lib/GLError\");function c(t){this.gl=t,this.gl.lastAttribCount=0,this._vref=this._fref=this._relink=this.vertShader=this.fragShader=this.program=this.attributes=this.uniforms=this.types=null}var u=c.prototype;function h(t,e){return t.name<e.name?-1:1}u.bind=function(){var t;this.program||this._relink();var e=this.gl.getProgramParameter(this.program,this.gl.ACTIVE_ATTRIBUTES),r=this.gl.lastAttribCount;if(e>r)for(t=r;t<e;t++)this.gl.enableVertexAttribArray(t);else if(r>e)for(t=e;t<r;t++)this.gl.disableVertexAttribArray(t);this.gl.lastAttribCount=e,this.gl.useProgram(this.program)},u.dispose=function(){for(var t=this.gl.lastAttribCount,e=0;e<t;e++)this.gl.disableVertexAttribArray(e);this.gl.lastAttribCount=0,this._fref&&this._fref.dispose(),this._vref&&this._vref.dispose(),this.attributes=this.types=this.vertShader=this.fragShader=this.program=this._relink=this._fref=this._vref=null},u.update=function(t,e,r,c){if(!e||1===arguments.length){var u=t;t=u.vertex,e=u.fragment,r=u.uniforms,c=u.attributes}var f=this,p=f.gl,d=f._vref;f._vref=o.shader(p,p.VERTEX_SHADER,t),d&&d.dispose(),f.vertShader=f._vref.shader;var g=this._fref;if(f._fref=o.shader(p,p.FRAGMENT_SHADER,e),g&&g.dispose(),f.fragShader=f._fref.shader,!r||!c){var v=p.createProgram();if(p.attachShader(v,f.fragShader),p.attachShader(v,f.vertShader),p.linkProgram(v),!p.getProgramParameter(v,p.LINK_STATUS)){var m=p.getProgramInfoLog(v);throw new l(m,\"Error linking program:\"+m)}r=r||s.uniforms(p,v),c=c||s.attributes(p,v),p.deleteProgram(v)}(c=c.slice()).sort(h);var y,x=[],b=[],_=[];for(y=0;y<c.length;++y){var w=c[y];if(w.type.indexOf(\"mat\")>=0){for(var k=0|w.type.charAt(w.type.length-1),T=new Array(k),A=0;A<k;++A)T[A]=_.length,b.push(w.name+\"[\"+A+\"]\"),\"number\"==typeof w.location?_.push(w.location+A):Array.isArray(w.location)&&w.location.length===k&&\"number\"==typeof w.location[A]?_.push(0|w.location[A]):_.push(-1);x.push({name:w.name,type:w.type,locations:T})}else x.push({name:w.name,type:w.type,locations:[_.length]}),b.push(w.name),\"number\"==typeof w.location?_.push(0|w.location):_.push(-1)}var M=0;for(y=0;y<_.length;++y)if(_[y]<0){for(;_.indexOf(M)>=0;)M+=1;_[y]=M}var S=new Array(r.length);function E(){f.program=o.program(p,f._vref,f._fref,b,_);for(var t=0;t<r.length;++t)S[t]=p.getUniformLocation(f.program,r[t].name)}E(),f._relink=E,f.types={uniforms:a(r),attributes:a(c)},f.attributes=i(p,f,x,_),Object.defineProperty(f,\"uniforms\",n(p,f,r,S))},e.exports=function(t,e,r,n,i){var a=new c(t);return a.update(e,r,n,i),a}},{\"./lib/GLError\":302,\"./lib/create-attributes\":303,\"./lib/create-uniforms\":304,\"./lib/reflect\":305,\"./lib/runtime-reflect\":306,\"./lib/shader-cache\":307}],302:[function(t,e,r){function n(t,e,r){this.shortMessage=e||\"\",this.longMessage=r||\"\",this.rawError=t||\"\",this.message=\"gl-shader: \"+(e||t||\"\")+(r?\"\\n\"+r:\"\"),this.stack=(new Error).stack}n.prototype=new Error,n.prototype.name=\"GLError\",n.prototype.constructor=n,e.exports=n},{}],303:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){for(var a={},l=0,c=r.length;l<c;++l){var u=r[l],h=u.name,f=u.type,p=u.locations;switch(f){case\"bool\":case\"int\":case\"float\":o(t,e,p[0],i,1,a,h);break;default:if(f.indexOf(\"vec\")>=0){var d=f.charCodeAt(f.length-1)-48;if(d<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+h+\": \"+f);o(t,e,p[0],i,d,a,h)}else{if(!(f.indexOf(\"mat\")>=0))throw new n(\"\",\"Unknown data type for attribute \"+h+\": \"+f);var d=f.charCodeAt(f.length-1)-48;if(d<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+h+\": \"+f);s(t,e,p,i,d,a,h)}}}return a};var n=t(\"./GLError\");function i(t,e,r,n,i,a){this._gl=t,this._wrapper=e,this._index=r,this._locations=n,this._dimension=i,this._constFunc=a}var a=i.prototype;function o(t,e,r,n,a,o,s){for(var l=[\"gl\",\"v\"],c=[],u=0;u<a;++u)l.push(\"x\"+u),c.push(\"x\"+u);l.push(\"if(x0.length===void 0){return gl.vertexAttrib\"+a+\"f(v,\"+c.join()+\")}else{return gl.vertexAttrib\"+a+\"fv(v,x0)}\");var h=Function.apply(null,l),f=new i(t,e,r,n,a,h);Object.defineProperty(o,s,{set:function(e){return t.disableVertexAttribArray(n[r]),h(t,n[r],e),e},get:function(){return f},enumerable:!0})}function s(t,e,r,n,i,a,s){for(var l=new Array(i),c=new Array(i),u=0;u<i;++u)o(t,e,r[u],n,i,l,u),c[u]=l[u];Object.defineProperty(l,\"location\",{set:function(t){if(Array.isArray(t))for(var e=0;e<i;++e)c[e].location=t[e];else for(e=0;e<i;++e)c[e].location=t+e;return t},get:function(){for(var t=new Array(i),e=0;e<i;++e)t[e]=n[r[e]];return t},enumerable:!0}),l.pointer=function(e,a,o,s){e=e||t.FLOAT,a=!!a,o=o||i*i,s=s||0;for(var l=0;l<i;++l){var c=n[r[l]];t.vertexAttribPointer(c,i,e,a,o,s+l*i),t.enableVertexAttribArray(c)}};var h=new Array(i),f=t[\"vertexAttrib\"+i+\"fv\"];Object.defineProperty(a,s,{set:function(e){for(var a=0;a<i;++a){var o=n[r[a]];if(t.disableVertexAttribArray(o),Array.isArray(e[0]))f.call(t,o,e[a]);else{for(var s=0;s<i;++s)h[s]=e[i*a+s];f.call(t,o,h)}}return e},get:function(){return l},enumerable:!0})}a.pointer=function(t,e,r,n){var i=this._gl,a=this._locations[this._index];i.vertexAttribPointer(a,this._dimension,t||i.FLOAT,!!e,r||0,n||0),i.enableVertexAttribArray(a)},a.set=function(t,e,r,n){return this._constFunc(this._locations[this._index],t,e,r,n)},Object.defineProperty(a,\"location\",{get:function(){return this._locations[this._index]},set:function(t){return t!==this._locations[this._index]&&(this._locations[this._index]=0|t,this._wrapper.program=null),0|t}})},{\"./GLError\":302}],304:[function(t,e,r){\"use strict\";var n=t(\"./reflect\"),i=t(\"./GLError\");function a(t){return new Function(\"y\",\"return function(){return y}\")(t)}function o(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}e.exports=function(t,e,r,s){function l(t,e,r){switch(r){case\"bool\":case\"int\":case\"sampler2D\":case\"samplerCube\":return\"gl.uniform1i(locations[\"+e+\"],obj\"+t+\")\";case\"float\":return\"gl.uniform1f(locations[\"+e+\"],obj\"+t+\")\";default:var n=r.indexOf(\"vec\");if(!(0<=n&&n<=1&&r.length===4+n)){if(0===r.indexOf(\"mat\")&&4===r.length){var a=r.charCodeAt(r.length-1)-48;if(a<2||a>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+r);return\"gl.uniformMatrix\"+a+\"fv(locations[\"+e+\"],false,obj\"+t+\")\"}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+r)}var a=r.charCodeAt(r.length-1)-48;if(a<2||a>4)throw new i(\"\",\"Invalid data type\");switch(r.charAt(0)){case\"b\":case\"i\":return\"gl.uniform\"+a+\"iv(locations[\"+e+\"],obj\"+t+\")\";case\"v\":return\"gl.uniform\"+a+\"fv(locations[\"+e+\"],obj\"+t+\")\";default:throw new i(\"\",\"Unrecognized data type for vector \"+name+\": \"+r)}}}function c(e){for(var n=[\"return function updateProperty(obj){\"],i=function t(e,r){if(\"object\"!=typeof r)return[[e,r]];var n=[];for(var i in r){var a=r[i],o=e;parseInt(i)+\"\"===i?o+=\"[\"+i+\"]\":o+=\".\"+i,\"object\"==typeof a?n.push.apply(n,t(o,a)):n.push([o,a])}return n}(\"\",e),a=0;a<i.length;++a){var o=i[a],c=o[0],u=o[1];s[u]&&n.push(l(c,u,r[u].type))}n.push(\"return obj}\");var h=new Function(\"gl\",\"locations\",n.join(\"\\n\"));return h(t,s)}function u(n,l,u){if(\"object\"==typeof u){var f=h(u);Object.defineProperty(n,l,{get:a(f),set:c(u),enumerable:!0,configurable:!1})}else s[u]?Object.defineProperty(n,l,{get:(p=u,new Function(\"gl\",\"wrapper\",\"locations\",\"return function(){return gl.getUniform(wrapper.program,locations[\"+p+\"])}\")(t,e,s)),set:c(u),enumerable:!0,configurable:!1}):n[l]=function(t){switch(t){case\"bool\":return!1;case\"int\":case\"sampler2D\":case\"samplerCube\":case\"float\":return 0;default:var e=t.indexOf(\"vec\");if(0<=e&&e<=1&&t.length===4+e){var r=t.charCodeAt(t.length-1)-48;if(r<2||r>4)throw new i(\"\",\"Invalid data type\");return\"b\"===t.charAt(0)?o(r,!1):o(r,0)}if(0===t.indexOf(\"mat\")&&4===t.length){var r=t.charCodeAt(t.length-1)-48;if(r<2||r>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+t);return o(r*r,0)}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+t)}}(r[u].type);var p}function h(t){var e;if(Array.isArray(t)){e=new Array(t.length);for(var r=0;r<t.length;++r)u(e,r,t[r])}else for(var n in e={},t)u(e,n,t[n]);return e}var f=n(r,!0);return{get:a(h(f)),set:c(f),enumerable:!0,configurable:!0}}},{\"./GLError\":302,\"./reflect\":305}],305:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r={},n=0;n<t.length;++n)for(var i=t[n].name,a=i.split(\".\"),o=r,s=0;s<a.length;++s){var l=a[s].split(\"[\");if(l.length>1){l[0]in o||(o[l[0]]=[]),o=o[l[0]];for(var c=1;c<l.length;++c){var u=parseInt(l[c]);c<l.length-1||s<a.length-1?(u in o||(c<l.length-1?o[u]=[]:o[u]={}),o=o[u]):o[u]=e?n:t[n].type}}else s<a.length-1?(l[0]in o||(o[l[0]]={}),o=o[l[0]]):o[l[0]]=e?n:t[n].type}return r}},{}],306:[function(t,e,r){\"use strict\";r.uniforms=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_UNIFORMS),n=[],i=0;i<r;++i){var o=t.getActiveUniform(e,i);if(o){var s=a(t,o.type);if(o.size>1)for(var l=0;l<o.size;++l)n.push({name:o.name.replace(\"[0]\",\"[\"+l+\"]\"),type:s});else n.push({name:o.name,type:s})}}return n},r.attributes=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_ATTRIBUTES),n=[],i=0;i<r;++i){var o=t.getActiveAttrib(e,i);o&&n.push({name:o.name,type:a(t,o.type)})}return n};var n={FLOAT:\"float\",FLOAT_VEC2:\"vec2\",FLOAT_VEC3:\"vec3\",FLOAT_VEC4:\"vec4\",INT:\"int\",INT_VEC2:\"ivec2\",INT_VEC3:\"ivec3\",INT_VEC4:\"ivec4\",BOOL:\"bool\",BOOL_VEC2:\"bvec2\",BOOL_VEC3:\"bvec3\",BOOL_VEC4:\"bvec4\",FLOAT_MAT2:\"mat2\",FLOAT_MAT3:\"mat3\",FLOAT_MAT4:\"mat4\",SAMPLER_2D:\"sampler2D\",SAMPLER_CUBE:\"samplerCube\"},i=null;function a(t,e){if(!i){var r=Object.keys(n);i={};for(var a=0;a<r.length;++a){var o=r[a];i[t[o]]=n[o]}}return i[e]}},{}],307:[function(t,e,r){\"use strict\";r.shader=function(t,e,r){return u(t).getShaderReference(e,r)},r.program=function(t,e,r,n,i){return u(t).getProgram(e,r,n,i)};var n=t(\"./GLError\"),i=t(\"gl-format-compiler-error\"),a=new(\"undefined\"==typeof WeakMap?t(\"weakmap-shim\"):WeakMap),o=0;function s(t,e,r,n,i,a,o){this.id=t,this.src=e,this.type=r,this.shader=n,this.count=a,this.programs=[],this.cache=o}function l(t){this.gl=t,this.shaders=[{},{}],this.programs={}}s.prototype.dispose=function(){if(0==--this.count){for(var t=this.cache,e=t.gl,r=this.programs,n=0,i=r.length;n<i;++n){var a=t.programs[r[n]];a&&(delete t.programs[n],e.deleteProgram(a))}e.deleteShader(this.shader),delete t.shaders[this.type===e.FRAGMENT_SHADER|0][this.src]}};var c=l.prototype;function u(t){var e=a.get(t);return e||(e=new l(t),a.set(t,e)),e}c.getShaderReference=function(t,e){var r=this.gl,a=this.shaders[t===r.FRAGMENT_SHADER|0],l=a[e];if(l&&r.isShader(l.shader))l.count+=1;else{var c=function(t,e,r){var a=t.createShader(e);if(t.shaderSource(a,r),t.compileShader(a),!t.getShaderParameter(a,t.COMPILE_STATUS)){var o=t.getShaderInfoLog(a);try{var s=i(o,r,e)}catch(t){throw console.warn(\"Failed to format compiler error: \"+t),new n(o,\"Error compiling shader:\\n\"+o)}throw new n(o,s.short,s.long)}return a}(r,t,e);l=a[e]=new s(o++,e,t,c,[],1,this)}return l},c.getProgram=function(t,e,r,i){var a=[t.id,e.id,r.join(\":\"),i.join(\":\")].join(\"@\"),o=this.programs[a];return o&&this.gl.isProgram(o)||(this.programs[a]=o=function(t,e,r,i,a){var o=t.createProgram();t.attachShader(o,e),t.attachShader(o,r);for(var s=0;s<i.length;++s)t.bindAttribLocation(o,a[s],i[s]);if(t.linkProgram(o),!t.getProgramParameter(o,t.LINK_STATUS)){var l=t.getProgramInfoLog(o);throw new n(l,\"Error linking program: \"+l)}return o}(this.gl,t.shader,e.shader,r,i),t.programs.push(a),e.programs.push(a)),o}},{\"./GLError\":302,\"gl-format-compiler-error\":250,\"weakmap-shim\":555}],308:[function(t,e,r){\"use strict\";function n(t){this.plot=t,this.enable=[!0,!0,!1,!1],this.width=[1,1,1,1],this.color=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.center=[1/0,1/0]}e.exports=function(t,e){var r=new n(t);return r.update(e),t.addOverlay(r),r};var i=n.prototype;i.update=function(t){t=t||{},this.enable=(t.enable||[!0,!0,!1,!1]).slice(),this.width=(t.width||[1,1,1,1]).slice(),this.color=(t.color||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]).map(function(t){return t.slice()}),this.center=(t.center||[1/0,1/0]).slice(),this.plot.setOverlayDirty()},i.draw=function(){var t=this.enable,e=this.width,r=this.color,n=this.center,i=this.plot,a=i.line,o=i.dataBox,s=i.viewBox;if(a.bind(),o[0]<=n[0]&&n[0]<=o[2]&&o[1]<=n[1]&&n[1]<=o[3]){var l=s[0]+(n[0]-o[0])/(o[2]-o[0])*(s[2]-s[0]),c=s[1]+(n[1]-o[1])/(o[3]-o[1])*(s[3]-s[1]);t[0]&&a.drawLine(l,c,s[0],c,e[0],r[0]),t[1]&&a.drawLine(l,c,l,s[1],e[1],r[1]),t[2]&&a.drawLine(l,c,s[2],c,e[2],r[2]),t[3]&&a.drawLine(l,c,l,s[3],e[3],r[3])}},i.dispose=function(){this.plot.removeOverlay(this)}},{}],309:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, color;\\nattribute float weight;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 coordinates[3];\\nuniform vec4 colors[3];\\nuniform vec2 screenShape;\\nuniform float lineWidth;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vertexPosition = mix(coordinates[0],\\n    mix(coordinates[2], coordinates[1], 0.5 * (position + 1.0)), abs(position));\\n\\n  vec4 clipPos = projection * view * model * vec4(vertexPosition, 1.0);\\n  vec2 clipOffset = (projection * view * model * vec4(color, 0.0)).xy;\\n  vec2 delta = weight * clipOffset * screenShape;\\n  vec2 lineOffset = normalize(vec2(delta.y, -delta.x)) / screenShape;\\n\\n  gl_Position   = vec4(clipPos.xy + clipPos.w * 0.5 * lineWidth * lineOffset, clipPos.z, clipPos.w);\\n  fragColor     = color.x * colors[0] + color.y * colors[1] + color.z * colors[2];\\n}\\n\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  gl_FragColor = fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec3\"},{name:\"weight\",type:\"float\"}])}},{\"gl-shader\":301,glslify:409}],310:[function(t,e,r){\"use strict\";var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\");e.exports=function(t,e){var r=[];function o(t,e,n,i,a,o){var s=[t,e,n,0,0,0,1];s[i+3]=1,s[i]=a,r.push.apply(r,s),s[6]=-1,r.push.apply(r,s),s[i]=o,r.push.apply(r,s),r.push.apply(r,s),s[6]=1,r.push.apply(r,s),s[i]=a,r.push.apply(r,s)}o(0,0,0,0,0,1),o(0,0,0,1,0,1),o(0,0,0,2,0,1),o(1,0,0,1,-1,1),o(1,0,0,2,-1,1),o(0,1,0,0,-1,1),o(0,1,0,2,-1,1),o(0,0,1,0,-1,1),o(0,0,1,1,-1,1);var l=n(t,r),c=i(t,[{type:t.FLOAT,buffer:l,size:3,offset:0,stride:28},{type:t.FLOAT,buffer:l,size:3,offset:12,stride:28},{type:t.FLOAT,buffer:l,size:1,offset:24,stride:28}]),u=a(t);u.attributes.position.location=0,u.attributes.color.location=1,u.attributes.weight.location=2;var h=new s(t,l,c,u);return h.update(e),h};var o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n,this.pixelRatio=1,this.bounds=[[-1e3,-1e3,-1e3],[1e3,1e3,1e3]],this.position=[0,0,0],this.lineWidth=[2,2,2],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.enabled=[!0,!0,!0],this.drawSides=[!0,!0,!0],this.axes=null}var l=s.prototype,c=[0,0,0],u=[0,0,0],h=[0,0];l.isTransparent=function(){return!1},l.drawTransparent=function(t){},l.draw=function(t){var e=this.gl,r=this.vao,n=this.shader;r.bind(),n.bind();var i,a=t.model||o,s=t.view||o,l=t.projection||o;this.axes&&(i=this.axes.lastCubeProps.axis);for(var f=c,p=u,d=0;d<3;++d)i&&i[d]<0?(f[d]=this.bounds[0][d],p[d]=this.bounds[1][d]):(f[d]=this.bounds[1][d],p[d]=this.bounds[0][d]);h[0]=e.drawingBufferWidth,h[1]=e.drawingBufferHeight,n.uniforms.model=a,n.uniforms.view=s,n.uniforms.projection=l,n.uniforms.coordinates=[this.position,f,p],n.uniforms.colors=this.colors,n.uniforms.screenShape=h;for(d=0;d<3;++d)n.uniforms.lineWidth=this.lineWidth[d]*this.pixelRatio,this.enabled[d]&&(r.draw(e.TRIANGLES,6,6*d),this.drawSides[d]&&r.draw(e.TRIANGLES,12,18+12*d));r.unbind()},l.update=function(t){t&&(\"bounds\"in t&&(this.bounds=t.bounds),\"position\"in t&&(this.position=t.position),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"colors\"in t&&(this.colors=t.colors),\"enabled\"in t&&(this.enabled=t.enabled),\"drawSides\"in t&&(this.drawSides=t.drawSides))},l.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders/index\":309,\"gl-buffer\":241,\"gl-vao\":327}],311:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\nuniform float vectorScale;\\nuniform float tubeScale;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * tubePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal,0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(tubePosition, 1.0);\\n  vec4 t_position  = view * tubePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = tubePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular\\n            , opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform float tubeScale;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  gl_Position = projection * view * tubePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec4\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec4\"}]}},{glslify:409}],312:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./shaders\"),g=d.meshShader,v=d.pickShader,m=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function y(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,y,x,b,_,w,k,T){this.gl=t,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=i,this.triangleVectors=a,this.triangleColors=s,this.triangleNormals=c,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=u,this.triangleCount=0,this.lineWidth=1,this.edgePositions=h,this.edgeColors=p,this.edgeUVs=d,this.edgeIds=f,this.edgeVAO=g,this.edgeCount=0,this.pointPositions=v,this.pointColors=x,this.pointUVs=b,this.pointSizes=_,this.pointIds=y,this.pointVAO=w,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=k,this.contourVAO=T,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!1,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.tubeScale=1,this._model=m,this._view=m,this._projection=m,this._resolution=[1,1],this.pixelRatio=1}var x=y.prototype;function b(t){var e=n(t,v.vertex,v.fragment,null,v.attributes);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.vector.location=5,e}x.isOpaque=function(){return this.opacity>=1},x.isTransparent=function(){return this.opacity<1},x.pickSlots=1,x.setPickBase=function(t){this.pickId=t},x.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=i[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},x.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=h({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return u(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,i=t.vectors;if(n&&r&&i){void 0!==t.tubeScale&&(this.tubeScale=t.tubeScale);var a=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[],w=[],k=[];this.cells=r,this.positions=n,this.vectors=i;var T=t.vertexNormals,A=t.cellNormals,M=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,S=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!A&&(A=s.faceNormals(r,n,S)),A||T||(T=s.vertexNormals(r,n,M));var E=t.vertexColors,C=t.cellColors,L=t.meshColor||[1,1,1,1],P=t.vertexUVs,O=t.vertexIntensity,z=t.cellUVs,I=t.cellIntensity,D=1/0,R=-1/0;if(!P&&!z)if(O)if(t.vertexIntensityBounds)D=+t.vertexIntensityBounds[0],R=+t.vertexIntensityBounds[1];else for(var F=0;F<O.length;++F){var B=O[F];D=Math.min(D,B),R=Math.max(R,B)}else if(I)for(F=0;F<I.length;++F){B=I[F];D=Math.min(D,B),R=Math.max(R,B)}else for(F=0;F<n.length;++F){B=n[F][2];D=Math.min(D,B),R=Math.max(R,B)}this.intensity=O||(I?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,I):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var N=t.pointSizes,j=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(F=0;F<n.length;++F)for(var U=n[F],V=0;V<3;++V)!isNaN(U[V])&&isFinite(U[V])&&(this.bounds[0][V]=Math.min(this.bounds[0][V],U[V]),this.bounds[1][V]=Math.max(this.bounds[1][V],U[V]));var q=0,H=0,G=0;t:for(F=0;F<r.length;++F){var Y=r[F];switch(Y.length){case 1:for(U=n[X=Y[0]],V=0;V<3;++V)if(isNaN(U[V])||!isFinite(U[V]))continue t;x.push(U[0],U[1],U[2],U[3]),3===(Z=E?E[X]:C?C[F]:L).length?b.push(Z[0],Z[1],Z[2],1):b.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],_.push(J[0],J[1]),N?w.push(N[X]):w.push(j),k.push(F),G+=1;break;case 2:for(V=0;V<2;++V){U=n[X=Y[V]];for(var W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t}for(V=0;V<2;++V){U=n[X=Y[V]];g.push(U[0],U[1],U[2]),3===(Z=E?E[X]:C?C[F]:L).length?v.push(Z[0],Z[1],Z[2],1):v.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],m.push(J[0],J[1]),y.push(F)}H+=1;break;case 3:for(V=0;V<3;++V)for(U=n[X=Y[V]],W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t;for(V=0;V<3;++V){var X;U=n[X=Y[2-V]];a.push(U[0],U[1],U[2],U[3]);var Z,J,K,$=i[X];l.push($[0],$[1],$[2],$[3]),3===(Z=E?E[X]:C?C[F]:L).length?c.push(Z[0],Z[1],Z[2],1):c.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],p.push(J[0],J[1]),K=T?T[X]:A[F],f.push(K[0],K[1],K[2]),d.push(F)}q+=1}}this.pointCount=G,this.edgeCount=H,this.triangleCount=q,this.pointPositions.update(x),this.pointColors.update(b),this.pointUVs.update(_),this.pointSizes.update(w),this.pointIds.update(new Uint32Array(k)),this.edgePositions.update(g),this.edgeColors.update(v),this.edgeUVs.update(m),this.edgeIds.update(new Uint32Array(y)),this.trianglePositions.update(a),this.triangleVectors.update(l),this.triangleColors.update(c),this.triangleUVs.update(p),this.triangleNormals.update(f),this.triangleIds.update(new Uint32Array(d))}},x.drawTransparent=x.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:m.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,tubeScale:this.tubeScale,contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var f=u[12+o],p=0;p<3;++p)f+=u[4*p+o]*this.lightPosition[p];s.lightPosition[o]=f/h}if(this.triangleCount>0){var d=this.triShader;d.bind(),d.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},x.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:i,clipBounds:a,tubeScale:this.tubeScale,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind())},x.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3);return{index:e,position:n,intensity:this.intensity[r[1]],velocity:this.vectors[r[1]].slice(0,3),divergence:this.vectors[r[1]][3],dataCoordinate:n}},x.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose()},e.exports=function(t,e){1===arguments.length&&(t=(e=t).gl);var r=e.triShader||function(t){var e=n(t,g.vertex,g.fragment,null,g.attributes);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.vector.location=5,e}(t),s=b(t),l=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));l.generateMipmap(),l.minFilter=t.LINEAR_MIPMAP_LINEAR,l.magFilter=t.LINEAR;var c=i(t),h=i(t),f=i(t),p=i(t),d=i(t),v=i(t),m=a(t,[{buffer:c,type:t.FLOAT,size:4},{buffer:v,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:f,type:t.FLOAT,size:4},{buffer:p,type:t.FLOAT,size:2},{buffer:d,type:t.FLOAT,size:3},{buffer:h,type:t.FLOAT,size:4}]),x=i(t),_=i(t),w=i(t),k=i(t),T=a(t,[{buffer:x,type:t.FLOAT,size:3},{buffer:k,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:_,type:t.FLOAT,size:4},{buffer:w,type:t.FLOAT,size:2}]),A=i(t),M=i(t),S=i(t),E=i(t),C=i(t),L=a(t,[{buffer:A,type:t.FLOAT,size:3},{buffer:C,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:M,type:t.FLOAT,size:4},{buffer:S,type:t.FLOAT,size:2},{buffer:E,type:t.FLOAT,size:1}]),P=i(t),O=new y(t,l,r,s,c,h,v,f,p,d,m,x,k,_,w,T,A,C,M,S,E,L,P,a(t,[{buffer:P,type:t.FLOAT,size:3}]));return O.update(e),O}},{\"./shaders\":311,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-shader\":301,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,normals:453,\"simplicial-complex-contour\":518,\"typedarray-pool\":545}],313:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\"),i=t(\"gl-vec4\"),a=function(t,e,r,a){for(var o=0,s=0;s<t.length;s++)for(var l=t[s].velocities,c=0;c<l.length;c++){var u=n.length(l[c]);u>o&&(o=u)}var h=t.map(function(t){return function(t,e,r,a){var o,s,l,c=t.points,u=t.velocities,h=t.divergences;n.set(n.create(),0,1,0),n.create(),n.create();n.create();for(var f=[],p=[],d=[],g=[],v=[],m=[],y=0,x=0,b=i.create(),_=i.create(),w=0;w<c.length;w++){o=c[w],s=u[w],l=h[w],0===e&&(l=.05*r),x=n.length(s)/a,b=i.create(),n.copy(b,s),b[3]=l;for(var k=0;k<8;k++)v[k]=[o[0],o[1],o[2],k];if(g.length>0)for(k=0;k<8;k++){var T=(k+1)%8;f.push(g[k],v[k],v[T],v[T],g[T],g[k]),d.push(_,b,b,b,_,_),m.push(y,x,x,x,y,y),p.push([f.length-6,f.length-5,f.length-4],[f.length-3,f.length-2,f.length-1])}var A=g;g=v,v=A,A=_,_=b,b=A,A=y,y=x,x=A}return{positions:f,cells:p,vectors:d,vertexIntensity:m}}(t,r,a,o)}),f=[],p=[],d=[],g=[];for(s=0;s<h.length;s++){var v=h[s],m=f.length;f=f.concat(v.positions),d=d.concat(v.vectors),g=g.concat(v.vertexIntensity);for(c=0;c<v.cells.length;c++){var y=v.cells[c],x=[];p.push(x);for(var b=0;b<y.length;b++)x.push(y[b]+m)}}return{positions:f,cells:p,vectors:d,vertexIntensity:g,colormap:e}},o=function(t,e){var r=n.create(),i=1e-4;n.add(r,t,[i,0,0]);var a=this.getVelocity(r);n.subtract(a,a,e),n.scale(a,a,1e4),n.add(r,t,[0,i,0]);var o=this.getVelocity(r);n.subtract(o,o,e),n.scale(o,o,1e4),n.add(r,t,[0,0,i]);var s=this.getVelocity(r);return n.subtract(s,s,e),n.scale(s,s,1e4),n.add(r,a,o),n.add(r,r,s),r},s=function(t){return f(t,this.vectors,this.meshgrid,this.clampBorders)},l=function(t,e){for(var r=0;r<t.length;r++){var n=t[r];if(n===e)return r;if(n>e)return r-1}return r},c=n.create(),u=n.create(),h=function(t,e,r){return t<e?e:t>r?r:t},f=function(t,e,r,i){var a=t[0],o=t[1],s=t[2],f=r[0].length,p=r[1].length,d=r[2].length,g=l(r[0],a),v=l(r[1],o),m=l(r[2],s),y=g+1,x=v+1,b=m+1;if(r[0][g]===a&&(y=g),r[1][v]===o&&(x=v),r[2][m]===s&&(b=m),i&&(g=h(g,0,f-1),y=h(y,0,f-1),v=h(v,0,p-1),x=h(x,0,p-1),m=h(m,0,d-1),b=h(b,0,d-1)),g<0||v<0||m<0||y>=f||x>=p||b>=d)return n.create();var _=(a-r[0][g])/(r[0][y]-r[0][g]),w=(o-r[1][v])/(r[1][x]-r[1][v]),k=(s-r[2][m])/(r[2][b]-r[2][m]);(_<0||_>1||isNaN(_))&&(_=0),(w<0||w>1||isNaN(w))&&(w=0),(k<0||k>1||isNaN(k))&&(k=0);var T=m*f*p,A=b*f*p,M=v*f,S=x*f,E=g,C=y,L=e[M+T+E],P=e[M+T+C],O=e[S+T+E],z=e[S+T+C],I=e[M+A+E],D=e[M+A+C],R=e[S+A+E],F=e[S+A+C],B=n.create();return n.lerp(B,L,P,_),n.lerp(c,O,z,_),n.lerp(B,B,c,w),n.lerp(c,I,D,_),n.lerp(u,R,F,_),n.lerp(c,c,u,w),n.lerp(B,B,c,k),B},p=function(t){var e=1/0;t.sort(function(t,e){return t-e});for(var r=1;r<t.length;r++){var n=Math.abs(t[r]-t[r-1]);n<e&&(e=n)}return e};e.exports=function(t,e){var r=t.startingPositions,i=t.maxLength||1e3,l=t.tubeSize||1,c=t.absoluteTubeSize;t.getDivergence||(t.getDivergence=o),t.getVelocity||(t.getVelocity=s),void 0===t.clampBorders&&(t.clampBorders=!0);var u=[],h=e[0][0],f=e[0][1],d=e[0][2],g=e[1][0],v=e[1][1],m=e[1][2],y=function(t,e){var r=e[0],n=e[1],i=e[2];return r>=h&&r<=g&&n>=f&&n<=v&&i>=d&&i<=m},x=10*n.distance(e[0],e[1])/i,b=x*x,_=1,w=0;n.create();r.length>=2&&(_=function(t){for(var e=[],r=[],n=[],i={},a={},o={},s=0;s<t.length;s++){var l=t[s],c=l[0],u=l[1],h=l[2];i[c]||(e.push(c),i[c]=!0),a[u]||(r.push(u),a[u]=!0),o[h]||(n.push(h),o[h]=!0)}var f=p(e),d=p(r),g=p(n),v=Math.min(f,d,g);return isFinite(v)?v:1}(r));for(var k=0;k<r.length;k++){var T=n.create();n.copy(T,r[k]);var A=[T],M=[],S=t.getVelocity(T),E=T;M.push(S);var C=[],L=t.getDivergence(T,S);(I=n.length(L))>w&&!isNaN(I)&&isFinite(I)&&(w=I),C.push(I),u.push({points:A,velocities:M,divergences:C});for(var P=0;P<100*i&&A.length<i&&y(0,T);){P++;var O=n.clone(S),z=n.squaredLength(O);if(0===z)break;if(z>b&&n.scale(O,O,x/Math.sqrt(z)),n.add(O,O,T),S=t.getVelocity(O),n.squaredDistance(E,O)-b>-1e-4*b){A.push(O),E=O,M.push(S);L=t.getDivergence(O,S);(I=n.length(L))>w&&!isNaN(I)&&isFinite(I)&&(w=I),C.push(I)}T=O}}for(k=0;k<C.length;k++){var I=C[k];!isNaN(I)&&isFinite(I)||(C[k]=w)}var D=a(u,t.colormap,w,_);return c?D.tubeScale=c:(0===w&&(w=1),D.tubeScale=.5*l*_/w),D},e.exports.createTubeMesh=t(\"./lib/tubemesh\")},{\"./lib/tubemesh\":312,\"gl-vec3\":346,\"gl-vec4\":382}],314:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute vec3 f;\\nattribute vec3 normal;\\n\\nuniform vec3 objectOffset;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 lightPosition, eyePosition;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 localCoordinate = vec3(uv.zw, f.x);\\n  worldCoordinate = objectOffset + localCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n  vec4 clipPosition = projection * view * worldPosition;\\n  gl_Position = clipPosition;\\n  kill = f.y;\\n  value = f.z;\\n  planeCoordinate = uv.xy;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * worldPosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  lightDirection = lightPosition - cameraCoordinate.xyz;\\n  eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  surfaceNormal  = normalize((vec4(normal,0) * inverseModel).xyz);\\n}\\n\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat beckmannSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness) {\\n  return beckmannDistribution(dot(surfaceNormal, normalize(lightDirection + viewDirection)), roughness);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 lowerBound, upperBound;\\nuniform float contourTint;\\nuniform vec4 contourColor;\\nuniform sampler2D colormap;\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform float vertexColor;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec3 N = normalize(surfaceNormal);\\n  vec3 V = normalize(eyeDirection);\\n  vec3 L = normalize(lightDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = max(beckmannSpecular(L, V, N, roughness), 0.);\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  //decide how to interpolate color \\u2014 in vertex or in fragment\\n  vec4 surfaceColor =\\n    step(vertexColor, .5) * texture2D(colormap, vec2(value, value)) +\\n    step(.5, vertexColor) * vColor;\\n\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = mix(litColor, contourColor, contourTint) * opacity;\\n}\\n\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute float f;\\n\\nuniform vec3 objectOffset;\\nuniform mat3 permutation;\\nuniform mat4 model, view, projection;\\nuniform float height, zOffset;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 dataCoordinate = permutation * vec3(uv.xy, height);\\n  worldCoordinate = objectOffset + dataCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n\\n  vec4 clipPosition = projection * view * worldPosition;\\n  clipPosition.z += zOffset;\\n\\n  gl_Position = clipPosition;\\n  value = f + objectOffset.z;\\n  kill = -1.0;\\n  planeCoordinate = uv.zw;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Don't do lighting for contours\\n  surfaceNormal   = vec3(1,0,0);\\n  eyeDirection    = vec3(0,1,0);\\n  lightDirection  = vec3(0,0,1);\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec2 shape;\\nuniform vec3 clipBounds[2];\\nuniform float pickId;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 surfaceNormal;\\n\\nvec2 splitFloat(float v) {\\n  float vh = 255.0 * v;\\n  float upper = floor(vh);\\n  float lower = fract(vh);\\n  return vec2(upper / 255.0, floor(lower * 16.0) / 16.0);\\n}\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec2 ux = splitFloat(planeCoordinate.x / shape.x);\\n  vec2 uy = splitFloat(planeCoordinate.y / shape.y);\\n  gl_FragColor = vec4(pickId, ux.x, uy.x, ux.y + (uy.y/16.0));\\n}\\n\"]);r.createShader=function(t){var e=n(t,a,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createPickShader=function(t){var e=n(t,a,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createContourShader=function(t){var e=n(t,s,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e},r.createPickContourShader=function(t){var e=n(t,s,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e}},{\"gl-shader\":301,glslify:409}],315:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],316:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=y(e),n=b(e),s=x(e),l=_(e),c=i(e),u=a(e,[{buffer:c,size:4,stride:w,offset:0},{buffer:c,size:3,stride:w,offset:16},{buffer:c,size:3,stride:w,offset:28}]),h=i(e),f=a(e,[{buffer:h,size:4,stride:20,offset:0},{buffer:h,size:1,stride:20,offset:16}]),p=i(e),d=a(e,[{buffer:p,size:2,type:e.FLOAT}]),g=o(e,1,S,e.RGBA,e.UNSIGNED_BYTE);g.minFilter=e.LINEAR,g.magFilter=e.LINEAR;var v=new E(e,[0,0],[[0,0,0],[0,0,0]],r,n,c,u,g,s,l,h,f,p,d,[0,0,0]),m={levels:[[],[],[]]};for(var k in t)m[k]=t[k];return m.colormap=m.colormap||\"jet\",v.update(m),v};var n=t(\"bit-twiddle\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"typedarray-pool\"),l=t(\"colormap\"),c=t(\"ndarray-ops\"),u=t(\"ndarray-pack\"),h=t(\"ndarray\"),f=t(\"surface-nets\"),p=t(\"gl-mat4/multiply\"),d=t(\"gl-mat4/invert\"),g=t(\"binary-search-bounds\"),v=t(\"ndarray-gradient\"),m=t(\"./lib/shaders\"),y=m.createShader,x=m.createContourShader,b=m.createPickShader,_=m.createPickContourShader,w=40,k=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1],T=[[0,0],[0,1],[1,0],[1,1],[1,0],[0,1]],A=[[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0]];function M(t,e,r,n,i){this.position=t,this.index=e,this.uv=r,this.level=n,this.dataCoordinate=i}!function(){for(var t=0;t<3;++t){var e=A[t],r=(t+2)%3;e[(t+1)%3+0]=1,e[r+3]=1,e[t+6]=1}}();var S=256;function E(t,e,r,n,i,a,o,l,c,u,f,p,d,g,v){this.gl=t,this.shape=e,this.bounds=r,this.objectOffset=v,this.intensityBounds=[],this._shader=n,this._pickShader=i,this._coordinateBuffer=a,this._vao=o,this._colorMap=l,this._contourShader=c,this._contourPickShader=u,this._contourBuffer=f,this._contourVAO=p,this._contourOffsets=[[],[],[]],this._contourCounts=[[],[],[]],this._vertexCount=0,this._pickResult=new M([0,0,0],[0,0],[0,0],[0,0,0],[0,0,0]),this._dynamicBuffer=d,this._dynamicVAO=g,this._dynamicOffsets=[0,0,0],this._dynamicCounts=[0,0,0],this.contourWidth=[1,1,1],this.contourLevels=[[1],[1],[1]],this.contourTint=[0,0,0],this.contourColor=[[.5,.5,.5,1],[.5,.5,.5,1],[.5,.5,.5,1]],this.showContour=!0,this.showSurface=!0,this.enableHighlight=[!0,!0,!0],this.highlightColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.highlightTint=[1,1,1],this.highlightLevel=[-1,-1,-1],this.enableDynamic=[!0,!0,!0],this.dynamicLevel=[NaN,NaN,NaN],this.dynamicColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.dynamicTint=[1,1,1],this.dynamicWidth=[1,1,1],this.axesBounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.surfaceProject=[!1,!1,!1],this.contourProject=[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],this.colorBounds=[!1,!1],this._field=[h(s.mallocFloat(1024),[0,0]),h(s.mallocFloat(1024),[0,0]),h(s.mallocFloat(1024),[0,0])],this.pickId=1,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.snapToData=!1,this.pixelRatio=1,this.opacity=1,this.lightPosition=[10,1e4,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.vertexColor=0,this.dirty=!0}var C=E.prototype;C.isTransparent=function(){return this.opacity<1},C.isOpaque=function(){if(this.opacity>=1)return!0;for(var t=0;t<3;++t)if(this._contourCounts[t].length>0||this._dynamicCounts[t]>0)return!0;return!1},C.pickSlots=1,C.setPickBase=function(t){this.pickId=t};var L=[0,0,0],P={showSurface:!1,showContour:!1,projections:[k.slice(),k.slice(),k.slice()],clipBounds:[[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]]]};function O(t,e){var r,n,i,a=e.axes&&e.axes.lastCubeProps.axis||L,o=e.showSurface,s=e.showContour;for(r=0;r<3;++r)for(o=o||e.surfaceProject[r],n=0;n<3;++n)s=s||e.contourProject[r][n];for(r=0;r<3;++r){var l=P.projections[r];for(n=0;n<16;++n)l[n]=0;for(n=0;n<4;++n)l[5*n]=1;l[5*r]=0,l[12+r]=e.axesBounds[+(a[r]>0)][r],p(l,t.model,l);var c=P.clipBounds[r];for(i=0;i<2;++i)for(n=0;n<3;++n)c[i][n]=t.clipBounds[i][n];c[0][r]=-1e8,c[1][r]=1e8}return P.showSurface=o,P.showContour=s,P}var z={model:k,view:k,projection:k,inverseModel:k.slice(),lowerBound:[0,0,0],upperBound:[0,0,0],colorMap:0,clipBounds:[[0,0,0],[0,0,0]],height:0,contourTint:0,contourColor:[0,0,0,1],permutation:[1,0,0,0,1,0,0,0,1],zOffset:-1e-4,objectOffset:[0,0,0],kambient:1,kdiffuse:1,kspecular:1,lightPosition:[1e3,1e3,1e3],eyePosition:[0,0,0],roughness:1,fresnel:1,opacity:1,vertexColor:0},I=k.slice(),D=[1,0,0,0,1,0,0,0,1];function R(t,e){t=t||{};var r=this.gl;r.disable(r.CULL_FACE),this._colorMap.bind(0);var n=z;n.model=t.model||k,n.view=t.view||k,n.projection=t.projection||k,n.lowerBound=[this.bounds[0][0],this.bounds[0][1],this.colorBounds[0]||this.bounds[0][2]],n.upperBound=[this.bounds[1][0],this.bounds[1][1],this.colorBounds[1]||this.bounds[1][2]],n.objectOffset=this.objectOffset,n.contourColor=this.contourColor[0],n.inverseModel=d(n.inverseModel,n.model);for(var i=0;i<2;++i)for(var a=n.clipBounds[i],o=0;o<3;++o)a[o]=Math.min(Math.max(this.clipBounds[i][o],-1e8),1e8);n.kambient=this.ambientLight,n.kdiffuse=this.diffuseLight,n.kspecular=this.specularLight,n.roughness=this.roughness,n.fresnel=this.fresnel,n.opacity=this.opacity,n.height=0,n.permutation=D,n.vertexColor=this.vertexColor;var s=I;for(p(s,n.view,n.model),p(s,n.projection,s),d(s,s),i=0;i<3;++i)n.eyePosition[i]=s[12+i]/s[15];var l=s[15];for(i=0;i<3;++i)l+=this.lightPosition[i]*s[4*i+3];for(i=0;i<3;++i){var c=s[12+i];for(o=0;o<3;++o)c+=s[4*o+i]*this.lightPosition[o];n.lightPosition[i]=c/l}var u=O(n,this);if(u.showSurface&&e===this.opacity<1){for(this._shader.bind(),this._shader.uniforms=n,this._vao.bind(),this.showSurface&&this._vertexCount&&this._vao.draw(r.TRIANGLES,this._vertexCount),i=0;i<3;++i)this.surfaceProject[i]&&this.vertexCount&&(this._shader.uniforms.model=u.projections[i],this._shader.uniforms.clipBounds=u.clipBounds[i],this._vao.draw(r.TRIANGLES,this._vertexCount));this._vao.unbind()}if(u.showContour&&!e){var h=this._contourShader;n.kambient=1,n.kdiffuse=0,n.kspecular=0,n.opacity=1,h.bind(),h.uniforms=n;var f=this._contourVAO;for(f.bind(),i=0;i<3;++i)for(h.uniforms.permutation=A[i],r.lineWidth(this.contourWidth[i]*this.pixelRatio),o=0;o<this.contourLevels[i].length;++o)o===this.highlightLevel[i]?(h.uniforms.contourColor=this.highlightColor[i],h.uniforms.contourTint=this.highlightTint[i]):0!==o&&o-1!==this.highlightLevel[i]||(h.uniforms.contourColor=this.contourColor[i],h.uniforms.contourTint=this.contourTint[i]),this._contourCounts[i][o]&&(h.uniforms.height=this.contourLevels[i][o],f.draw(r.LINES,this._contourCounts[i][o],this._contourOffsets[i][o]));for(i=0;i<3;++i)for(h.uniforms.model=u.projections[i],h.uniforms.clipBounds=u.clipBounds[i],o=0;o<3;++o)if(this.contourProject[i][o]){h.uniforms.permutation=A[o],r.lineWidth(this.contourWidth[o]*this.pixelRatio);for(var g=0;g<this.contourLevels[o].length;++g)g===this.highlightLevel[o]?(h.uniforms.contourColor=this.highlightColor[o],h.uniforms.contourTint=this.highlightTint[o]):0!==g&&g-1!==this.highlightLevel[o]||(h.uniforms.contourColor=this.contourColor[o],h.uniforms.contourTint=this.contourTint[o]),this._contourCounts[o][g]&&(h.uniforms.height=this.contourLevels[o][g],f.draw(r.LINES,this._contourCounts[o][g],this._contourOffsets[o][g]))}for(f.unbind(),(f=this._dynamicVAO).bind(),i=0;i<3;++i)if(0!==this._dynamicCounts[i])for(h.uniforms.model=n.model,h.uniforms.clipBounds=n.clipBounds,h.uniforms.permutation=A[i],r.lineWidth(this.dynamicWidth[i]*this.pixelRatio),h.uniforms.contourColor=this.dynamicColor[i],h.uniforms.contourTint=this.dynamicTint[i],h.uniforms.height=this.dynamicLevel[i],f.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]),o=0;o<3;++o)this.contourProject[o][i]&&(h.uniforms.model=u.projections[o],h.uniforms.clipBounds=u.clipBounds[o],f.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]));f.unbind()}}C.draw=function(t){return R.call(this,t,!1)},C.drawTransparent=function(t){return R.call(this,t,!0)};var F={model:k,view:k,projection:k,inverseModel:k,clipBounds:[[0,0,0],[0,0,0]],height:0,shape:[0,0],pickId:0,lowerBound:[0,0,0],upperBound:[0,0,0],zOffset:0,objectOffset:[0,0,0],permutation:[1,0,0,0,1,0,0,0,1],lightPosition:[0,0,0],eyePosition:[0,0,0]};function B(t,e){return Array.isArray(t)?[e(t[0]),e(t[1]),e(t[2])]:[e(t),e(t),e(t)]}function N(t){return Array.isArray(t)?3===t.length?[t[0],t[1],t[2],1]:[t[0],t[1],t[2],t[3]]:[0,0,0,1]}function j(t){if(Array.isArray(t)){if(Array.isArray(t))return[N(t[0]),N(t[1]),N(t[2])];var e=N(t);return[e.slice(),e.slice(),e.slice()]}}C.drawPick=function(t){t=t||{};var e=this.gl;e.disable(e.CULL_FACE);var r=F;r.model=t.model||k,r.view=t.view||k,r.projection=t.projection||k,r.shape=this._field[2].shape,r.pickId=this.pickId/255,r.lowerBound=this.bounds[0],r.upperBound=this.bounds[1],r.objectOffset=this.objectOffset,r.permutation=D;for(var n=0;n<2;++n)for(var i=r.clipBounds[n],a=0;a<3;++a)i[a]=Math.min(Math.max(this.clipBounds[n][a],-1e8),1e8);var o=O(r,this);if(o.showSurface){for(this._pickShader.bind(),this._pickShader.uniforms=r,this._vao.bind(),this._vao.draw(e.TRIANGLES,this._vertexCount),n=0;n<3;++n)this.surfaceProject[n]&&(this._pickShader.uniforms.model=o.projections[n],this._pickShader.uniforms.clipBounds=o.clipBounds[n],this._vao.draw(e.TRIANGLES,this._vertexCount));this._vao.unbind()}if(o.showContour){var s=this._contourPickShader;s.bind(),s.uniforms=r;var l=this._contourVAO;for(l.bind(),a=0;a<3;++a)for(e.lineWidth(this.contourWidth[a]*this.pixelRatio),s.uniforms.permutation=A[a],n=0;n<this.contourLevels[a].length;++n)this._contourCounts[a][n]&&(s.uniforms.height=this.contourLevels[a][n],l.draw(e.LINES,this._contourCounts[a][n],this._contourOffsets[a][n]));for(n=0;n<3;++n)for(s.uniforms.model=o.projections[n],s.uniforms.clipBounds=o.clipBounds[n],a=0;a<3;++a)if(this.contourProject[n][a]){s.uniforms.permutation=A[a],e.lineWidth(this.contourWidth[a]*this.pixelRatio);for(var c=0;c<this.contourLevels[a].length;++c)this._contourCounts[a][c]&&(s.uniforms.height=this.contourLevels[a][c],l.draw(e.LINES,this._contourCounts[a][c],this._contourOffsets[a][c]))}l.unbind()}},C.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=this._field[2].shape,r=this._pickResult,n=e[0]*(t.value[0]+(t.value[2]>>4)/16)/255,i=Math.floor(n),a=n-i,o=e[1]*(t.value[1]+(15&t.value[2])/16)/255,s=Math.floor(o),l=o-s;i+=1,s+=1;var c=r.position;c[0]=c[1]=c[2]=0;for(var u=0;u<2;++u)for(var h=u?a:1-a,f=0;f<2;++f)for(var p=i+u,d=s+f,v=h*(f?l:1-l),m=0;m<3;++m)c[m]+=this._field[m].get(p,d)*v;for(var y=this._pickResult.level,x=0;x<3;++x)if(y[x]=g.le(this.contourLevels[x],c[x]),y[x]<0)this.contourLevels[x].length>0&&(y[x]=0);else if(y[x]<this.contourLevels[x].length-1){var b=this.contourLevels[x][y[x]],_=this.contourLevels[x][y[x]+1];Math.abs(b-c[x])>Math.abs(_-c[x])&&(y[x]+=1)}for(r.index[0]=a<.5?i:i+1,r.index[1]=l<.5?s:s+1,r.uv[0]=n/e[0],r.uv[1]=o/e[1],m=0;m<3;++m)r.dataCoordinate[m]=this._field[m].get(r.index[0],r.index[1]);return r},C.padField=function(t,e){var r=e.shape.slice(),n=t.shape.slice();c.assign(t.lo(1,1).hi(r[0],r[1]),e),c.assign(t.lo(1).hi(r[0],1),e.hi(r[0],1)),c.assign(t.lo(1,n[1]-1).hi(r[0],1),e.lo(0,r[1]-1).hi(r[0],1)),c.assign(t.lo(0,1).hi(1,r[1]),e.hi(1)),c.assign(t.lo(n[0]-1,1).hi(1,r[1]),e.lo(r[0]-1)),t.set(0,0,e.get(0,0)),t.set(0,n[1]-1,e.get(0,r[1]-1)),t.set(n[0]-1,0,e.get(r[0]-1,0)),t.set(n[0]-1,n[1]-1,e.get(r[0]-1,r[1]-1))},C.update=function(t){t=t||{},this.objectOffset=t.objectOffset||this.objectOffset,this.dirty=!0,\"contourWidth\"in t&&(this.contourWidth=B(t.contourWidth,Number)),\"showContour\"in t&&(this.showContour=B(t.showContour,Boolean)),\"showSurface\"in t&&(this.showSurface=!!t.showSurface),\"contourTint\"in t&&(this.contourTint=B(t.contourTint,Boolean)),\"contourColor\"in t&&(this.contourColor=j(t.contourColor)),\"contourProject\"in t&&(this.contourProject=B(t.contourProject,function(t){return B(t,Boolean)})),\"surfaceProject\"in t&&(this.surfaceProject=t.surfaceProject),\"dynamicColor\"in t&&(this.dynamicColor=j(t.dynamicColor)),\"dynamicTint\"in t&&(this.dynamicTint=B(t.dynamicTint,Number)),\"dynamicWidth\"in t&&(this.dynamicWidth=B(t.dynamicWidth,Number)),\"opacity\"in t&&(this.opacity=t.opacity),\"colorBounds\"in t&&(this.colorBounds=t.colorBounds),\"vertexColor\"in t&&(this.vertexColor=t.vertexColor?1:0);var e=t.field||t.coords&&t.coords[2]||null,r=!1;if(e||(e=this._field[2].shape[0]||this._field[2].shape[2]?this._field[2].lo(1,1).hi(this._field[2].shape[0]-2,this._field[2].shape[1]-2):this._field[2].hi(0,0)),\"field\"in t||\"coords\"in t){var i=(e.shape[0]+2)*(e.shape[1]+2);i>this._field[2].data.length&&(s.freeFloat(this._field[2].data),this._field[2].data=s.mallocFloat(n.nextPow2(i))),this._field[2]=h(this._field[2].data,[e.shape[0]+2,e.shape[1]+2]),this.padField(this._field[2],e),this.shape=e.shape.slice();for(var a=this.shape,o=0;o<2;++o)this._field[2].size>this._field[o].data.length&&(s.freeFloat(this._field[o].data),this._field[o].data=s.mallocFloat(this._field[2].size)),this._field[o]=h(this._field[o].data,[a[0]+2,a[1]+2]);if(t.coords){var p=t.coords;if(!Array.isArray(p)||3!==p.length)throw new Error(\"gl-surface: invalid coordinates for x/y\");for(o=0;o<2;++o){var d=p[o];for(b=0;b<2;++b)if(d.shape[b]!==a[b])throw new Error(\"gl-surface: coords have incorrect shape\");this.padField(this._field[o],d)}}else if(t.ticks){var g=t.ticks;if(!Array.isArray(g)||2!==g.length)throw new Error(\"gl-surface: invalid ticks\");for(o=0;o<2;++o){var m=g[o];if((Array.isArray(m)||m.length)&&(m=h(m)),m.shape[0]!==a[o])throw new Error(\"gl-surface: invalid tick length\");var y=h(m.data,a);y.stride[o]=m.stride[0],y.stride[1^o]=0,this.padField(this._field[o],y)}}else{for(o=0;o<2;++o){var x=[0,0];x[o]=1,this._field[o]=h(this._field[o].data,[a[0]+2,a[1]+2],x,0)}this._field[0].set(0,0,0);for(var b=0;b<a[0];++b)this._field[0].set(b+1,0,b);for(this._field[0].set(a[0]+1,0,a[0]-1),this._field[1].set(0,0,0),b=0;b<a[1];++b)this._field[1].set(0,b+1,b);this._field[1].set(0,a[1]+1,a[1]-1)}var _=this._field,w=h(s.mallocFloat(3*_[2].size*2),[3,a[0]+2,a[1]+2,2]);for(o=0;o<3;++o)v(w.pick(o),_[o],\"mirror\");var k=h(s.mallocFloat(3*_[2].size),[a[0]+2,a[1]+2,3]);for(o=0;o<a[0]+2;++o)for(b=0;b<a[1]+2;++b){var A=w.get(0,o,b,0),M=w.get(0,o,b,1),E=w.get(1,o,b,0),C=w.get(1,o,b,1),L=w.get(2,o,b,0),P=w.get(2,o,b,1),O=E*P-C*L,z=L*M-P*A,I=A*C-M*E,D=Math.sqrt(O*O+z*z+I*I);D<1e-8?(D=Math.max(Math.abs(O),Math.abs(z),Math.abs(I)))<1e-8?(I=1,z=O=0,D=1):D=1/D:D=1/Math.sqrt(D),k.set(o,b,0,O*D),k.set(o,b,1,z*D),k.set(o,b,2,I*D)}s.free(w.data);var R=[1/0,1/0,1/0],F=[-1/0,-1/0,-1/0],N=1/0,U=-1/0,V=(a[0]-1)*(a[1]-1)*6,q=s.mallocFloat(n.nextPow2(10*V)),H=0,G=0;for(o=0;o<a[0]-1;++o)t:for(b=0;b<a[1]-1;++b){for(var Y=0;Y<2;++Y)for(var W=0;W<2;++W)for(var X=0;X<3;++X){var Z=this._field[X].get(1+o+Y,1+b+W);if(isNaN(Z)||!isFinite(Z))continue t}for(X=0;X<6;++X){var J=o+T[X][0],K=b+T[X][1],$=this._field[0].get(J+1,K+1),Q=this._field[1].get(J+1,K+1);Z=this._field[2].get(J+1,K+1),O=k.get(J+1,K+1,0),z=k.get(J+1,K+1,1),I=k.get(J+1,K+1,2),t.intensity&&(tt=t.intensity.get(J,K));var tt=t.intensity?t.intensity.get(J,K):Z+this.objectOffset[2];q[H++]=J,q[H++]=K,q[H++]=$,q[H++]=Q,q[H++]=Z,q[H++]=0,q[H++]=tt,q[H++]=O,q[H++]=z,q[H++]=I,R[0]=Math.min(R[0],$+this.objectOffset[0]),R[1]=Math.min(R[1],Q+this.objectOffset[1]),R[2]=Math.min(R[2],Z+this.objectOffset[2]),N=Math.min(N,tt),F[0]=Math.max(F[0],$+this.objectOffset[0]),F[1]=Math.max(F[1],Q+this.objectOffset[1]),F[2]=Math.max(F[2],Z+this.objectOffset[2]),U=Math.max(U,tt),G+=1}}for(t.intensityBounds&&(N=+t.intensityBounds[0],U=+t.intensityBounds[1]),o=6;o<H;o+=10)q[o]=(q[o]-N)/(U-N);this._vertexCount=G,this._coordinateBuffer.update(q.subarray(0,H)),s.freeFloat(q),s.free(k.data),this.bounds=[R,F],this.intensity=t.intensity||this._field[2],this.intensityBounds[0]===N&&this.intensityBounds[1]===U||(r=!0),this.intensityBounds=[N,U]}if(\"levels\"in t){var et=t.levels;for(et=Array.isArray(et[0])?et.slice():[[],[],et],o=0;o<3;++o)et[o]=et[o].slice(),et[o].sort(function(t,e){return t-e});for(o=0;o<3;++o)for(b=0;b<et[o].length;++b)et[o][b]-=this.objectOffset[o];t:for(o=0;o<3;++o){if(et[o].length!==this.contourLevels[o].length){r=!0;break}for(b=0;b<et[o].length;++b)if(et[o][b]!==this.contourLevels[o][b]){r=!0;break t}}this.contourLevels=et}if(r){_=this._field,a=this.shape;for(var rt=[],nt=0;nt<3;++nt){var it=this.contourLevels[nt],at=[],ot=[],st=[0,0,0];for(o=0;o<it.length;++o){var lt=f(this._field[nt],it[o]);at.push(rt.length/5|0),G=0;t:for(b=0;b<lt.cells.length;++b){var ct=lt.cells[b];for(X=0;X<2;++X){var ut=lt.positions[ct[X]],ht=ut[0],ft=0|Math.floor(ht),pt=ht-ft,dt=ut[1],gt=0|Math.floor(dt),vt=dt-gt,mt=!1;e:for(var yt=0;yt<3;++yt){st[yt]=0;var xt=(nt+yt+1)%3;for(Y=0;Y<2;++Y){var bt=Y?pt:1-pt;for(J=0|Math.min(Math.max(ft+Y,0),a[0]),W=0;W<2;++W){var _t=W?vt:1-vt;if(K=0|Math.min(Math.max(gt+W,0),a[1]),Z=yt<2?this._field[xt].get(J,K):(this.intensity.get(J,K)-this.intensityBounds[0])/(this.intensityBounds[1]-this.intensityBounds[0]),!isFinite(Z)||isNaN(Z)){mt=!0;break e}var wt=bt*_t;st[yt]+=wt*Z}}}if(mt){if(X>0){for(var kt=0;kt<5;++kt)rt.pop();G-=1}continue t}rt.push(st[0],st[1],ut[0],ut[1],st[2]),G+=1}}ot.push(G)}this._contourOffsets[nt]=at,this._contourCounts[nt]=ot}var Tt=s.mallocFloat(rt.length);for(o=0;o<rt.length;++o)Tt[o]=rt[o];this._contourBuffer.update(Tt),s.freeFloat(Tt)}t.colormap&&this._colorMap.setPixels(function(t){var e=u([l({colormap:t,nshades:S,format:\"rgba\"}).map(function(t){return[t[0],t[1],t[2],255*t[3]]})]);return c.divseq(e,255),e}(t.colormap))},C.dispose=function(){this._shader.dispose(),this._vao.dispose(),this._coordinateBuffer.dispose(),this._colorMap.dispose(),this._contourBuffer.dispose(),this._contourVAO.dispose(),this._contourShader.dispose(),this._contourPickShader.dispose(),this._dynamicBuffer.dispose(),this._dynamicVAO.dispose();for(var t=0;t<3;++t)s.freeFloat(this._field[t].data)},C.highlight=function(t){var e,r;if(!t)return this._dynamicCounts=[0,0,0],this.dyanamicLevel=[NaN,NaN,NaN],void(this.highlightLevel=[-1,-1,-1]);for(e=0;e<3;++e)this.enableHighlight[e]?this.highlightLevel[e]=t.level[e]:this.highlightLevel[e]=-1;for(r=this.snapToData?t.dataCoordinate:t.position,e=0;e<3;++e)r[e]-=this.objectOffset[e];if(this.enableDynamic[0]&&r[0]!==this.dynamicLevel[0]||this.enableDynamic[1]&&r[1]!==this.dynamicLevel[1]||this.enableDynamic[2]&&r[2]!==this.dynamicLevel[2]){for(var n=0,i=this.shape,a=s.mallocFloat(12*i[0]*i[1]),o=0;o<3;++o)if(this.enableDynamic[o]){this.dynamicLevel[o]=r[o];var l=(o+1)%3,c=(o+2)%3,u=this._field[o],h=this._field[l],p=this._field[c],d=f(u,r[o]),g=d.cells,v=d.positions;for(this._dynamicOffsets[o]=n,e=0;e<g.length;++e)for(var m=g[e],y=0;y<2;++y){var x=v[m[y]],b=+x[0],_=0|b,w=0|Math.min(_+1,i[0]),k=b-_,T=1-k,A=+x[1],M=0|A,S=0|Math.min(M+1,i[1]),E=A-M,C=1-E,L=T*C,P=T*E,O=k*C,z=k*E,I=L*h.get(_,M)+P*h.get(_,S)+O*h.get(w,M)+z*h.get(w,S),D=L*p.get(_,M)+P*p.get(_,S)+O*p.get(w,M)+z*p.get(w,S);if(isNaN(I)||isNaN(D)){y&&(n-=1);break}a[2*n+0]=I,a[2*n+1]=D,n+=1}this._dynamicCounts[o]=n-this._dynamicOffsets[o]}else this.dynamicLevel[o]=NaN,this._dynamicCounts[o]=0;this._dynamicBuffer.update(a.subarray(0,2*n)),s.freeFloat(a)}}},{\"./lib/shaders\":314,\"binary-search-bounds\":315,\"bit-twiddle\":92,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,\"ndarray-gradient\":441,\"ndarray-ops\":444,\"ndarray-pack\":445,\"surface-nets\":531,\"typedarray-pool\":545}],317:[function(t,e,r){\"use strict\";var n=t(\"css-font\"),i=t(\"pick-by-alias\"),a=t(\"regl\"),o=t(\"gl-util/context\"),s=t(\"es6-weak-map\"),l=t(\"color-normalize\"),c=t(\"font-atlas\"),u=t(\"typedarray-pool\"),h=t(\"parse-rect\"),f=t(\"is-plain-obj\"),p=t(\"parse-unit\"),d=t(\"to-px\"),g=t(\"detect-kerning\"),v=t(\"object-assign\"),m=t(\"font-measure\"),y=t(\"flatten-vertex-data\"),x=t(\"bit-twiddle\").nextPow2,b=new s,_=!1;if(document.body){var w=document.body.appendChild(document.createElement(\"div\"));w.style.font=\"italic small-caps bold condensed 16px/2 cursive\",getComputedStyle(w).fontStretch&&(_=!0),document.body.removeChild(w)}var k=function(t){!function(t){return\"function\"==typeof t&&t._gl&&t.prop&&t.texture&&t.buffer}(t)?this.gl=o(t):(t={regl:t},this.gl=t.regl._gl),this.shader=b.get(this.gl),this.shader?this.regl=this.shader.regl:this.regl=t.regl||a({gl:this.gl}),this.charBuffer=this.regl.buffer({type:\"uint8\",usage:\"stream\"}),this.sizeBuffer=this.regl.buffer({type:\"float\",usage:\"stream\"}),this.shader||(this.shader=this.createShader(),b.set(this.gl,this.shader)),this.batch=[],this.fontSize=[],this.font=[],this.fontAtlas=[],this.draw=this.shader.draw.bind(this),this.render=function(){this.regl._refresh(),this.draw(this.batch)},this.canvas=this.gl.canvas,this.update(f(t)?t:{})};k.prototype.createShader=function(){var t=this.regl,e=t({blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},stencil:{enable:!1},depth:{enable:!1},count:t.prop(\"count\"),offset:t.prop(\"offset\"),attributes:{charOffset:{offset:4,stride:8,buffer:t.this(\"sizeBuffer\")},width:{offset:0,stride:8,buffer:t.this(\"sizeBuffer\")},char:t.this(\"charBuffer\"),position:t.this(\"position\")},uniforms:{atlasSize:function(t,e){return[e.atlas.width,e.atlas.height]},atlasDim:function(t,e){return[e.atlas.cols,e.atlas.rows]},atlas:function(t,e){return e.atlas.texture},charStep:function(t,e){return e.atlas.step},em:function(t,e){return e.atlas.em},color:t.prop(\"color\"),opacity:t.prop(\"opacity\"),viewport:t.this(\"viewportArray\"),scale:t.this(\"scale\"),align:t.prop(\"align\"),baseline:t.prop(\"baseline\"),translate:t.this(\"translate\"),positionOffset:t.prop(\"positionOffset\")},primitive:\"points\",viewport:t.this(\"viewport\"),vert:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tattribute float width, charOffset, char;\\n\\t\\t\\tattribute vec2 position;\\n\\t\\t\\tuniform float fontSize, charStep, em, align, baseline;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tuniform vec4 color;\\n\\t\\t\\tuniform vec2 atlasSize, atlasDim, scale, translate, positionOffset;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\t\"+(k.normalViewport?\"\":\"vec2 positionOffset = vec2(positionOffset.x,- positionOffset.y);\")+\"\\n\\n\\t\\t\\t\\tvec2 offset = floor(em * (vec2(align + charOffset, baseline)\\n\\t\\t\\t\\t\\t+ positionOffset))\\n\\t\\t\\t\\t\\t/ (viewport.zw * scale.xy);\\n\\n\\t\\t\\t\\tvec2 position = (position + translate) * scale;\\n\\t\\t\\t\\tposition += offset * scale;\\n\\n\\t\\t\\t\\t\"+(k.normalViewport?\"position.y = 1. - position.y;\":\"\")+\"\\n\\n\\t\\t\\t\\tcharCoord = position * viewport.zw + viewport.xy;\\n\\n\\t\\t\\t\\tgl_Position = vec4(position * 2. - 1., 0, 1);\\n\\n\\t\\t\\t\\tgl_PointSize = charStep;\\n\\n\\t\\t\\t\\tcharId.x = mod(char, atlasDim.x);\\n\\t\\t\\t\\tcharId.y = floor(char / atlasDim.x);\\n\\n\\t\\t\\t\\tcharWidth = width * em;\\n\\n\\t\\t\\t\\tfontColor = color / 255.;\\n\\t\\t\\t}\",frag:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tuniform sampler2D atlas;\\n\\t\\t\\tuniform float fontSize, charStep, opacity;\\n\\t\\t\\tuniform vec2 atlasSize;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\n\\t\\t\\tfloat lightness(vec4 color) {\\n\\t\\t\\t\\treturn color.r * 0.299 + color.g * 0.587 + color.b * 0.114;\\n\\t\\t\\t}\\n\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\tvec2 uv = gl_FragCoord.xy - charCoord + charStep * .5;\\n\\t\\t\\t\\tfloat halfCharStep = floor(charStep * .5 + .5);\\n\\n\\t\\t\\t\\t// invert y and shift by 1px (FF expecially needs that)\\n\\t\\t\\t\\tuv.y = charStep - uv.y;\\n\\n\\t\\t\\t\\t// ignore points outside of character bounding box\\n\\t\\t\\t\\tfloat halfCharWidth = ceil(charWidth * .5);\\n\\t\\t\\t\\tif (floor(uv.x) > halfCharStep + halfCharWidth ||\\n\\t\\t\\t\\t\\tfloor(uv.x) < halfCharStep - halfCharWidth) return;\\n\\n\\t\\t\\t\\tuv += charId * charStep;\\n\\t\\t\\t\\tuv = uv / atlasSize;\\n\\n\\t\\t\\t\\tvec4 color = fontColor;\\n\\t\\t\\t\\tvec4 mask = texture2D(atlas, uv);\\n\\n\\t\\t\\t\\tfloat maskY = lightness(mask);\\n\\t\\t\\t\\t// float colorY = lightness(color);\\n\\t\\t\\t\\tcolor.a *= maskY;\\n\\t\\t\\t\\tcolor.a *= opacity;\\n\\n\\t\\t\\t\\t// color.a += .1;\\n\\n\\t\\t\\t\\t// antialiasing, see yiq color space y-channel formula\\n\\t\\t\\t\\t// color.rgb += (1. - color.rgb) * (1. - mask.rgb);\\n\\n\\t\\t\\t\\tgl_FragColor = color;\\n\\t\\t\\t}\"});return{regl:t,draw:e,atlas:{}}},k.prototype.update=function(t){var e=this;if(\"string\"==typeof t)t={text:t};else if(!t)return;null!=(t=i(t,{position:\"position positions coord coords coordinates\",font:\"font fontFace fontface typeface cssFont css-font family fontFamily\",fontSize:\"fontSize fontsize size font-size\",text:\"text texts chars characters value values symbols\",align:\"align alignment textAlign textbaseline\",baseline:\"baseline textBaseline textbaseline\",direction:\"dir direction textDirection\",color:\"color colour fill fill-color fillColor textColor textcolor\",kerning:\"kerning kern\",range:\"range dataBox\",viewport:\"vp viewport viewBox viewbox viewPort\",opacity:\"opacity alpha transparency visible visibility opaque\",offset:\"offset positionOffset padding shift indent indentation\"},!0)).opacity&&(Array.isArray(t.opacity)?this.opacity=t.opacity.map(function(t){return parseFloat(t)}):this.opacity=parseFloat(t.opacity)),null!=t.viewport&&(this.viewport=h(t.viewport),k.normalViewport&&(this.viewport.y=this.canvas.height-this.viewport.y-this.viewport.height),this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null==this.viewport&&(this.viewport={x:0,y:0,width:this.gl.drawingBufferWidth,height:this.gl.drawingBufferHeight},this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null!=t.kerning&&(this.kerning=t.kerning),null!=t.offset&&(\"number\"==typeof t.offset&&(t.offset=[t.offset,0]),this.positionOffset=y(t.offset)),t.direction&&(this.direction=t.direction),t.range&&(this.range=t.range,this.scale=[1/(t.range[2]-t.range[0]),1/(t.range[3]-t.range[1])],this.translate=[-t.range[0],-t.range[1]]),t.scale&&(this.scale=t.scale),t.translate&&(this.translate=t.translate),this.scale||(this.scale=[1/this.viewport.width,1/this.viewport.height]),this.translate||(this.translate=[0,0]),this.font.length||t.font||(t.font=k.baseFontSize+\"px sans-serif\");var r,a=!1,o=!1;if(t.font&&(Array.isArray(t.font)?t.font:[t.font]).forEach(function(t,r){if(\"string\"==typeof t)try{t=n.parse(t)}catch(e){t=n.parse(k.baseFontSize+\"px \"+t)}else t=n.parse(n.stringify(t));var i=n.stringify({size:k.baseFontSize,family:t.family,stretch:_?t.stretch:void 0,variant:t.variant,weight:t.weight,style:t.style}),s=p(t.size),l=Math.round(s[0]*d(s[1]));if(l!==e.fontSize[r]&&(o=!0,e.fontSize[r]=l),!(e.font[r]&&i==e.font[r].baseString||(a=!0,e.font[r]=k.fonts[i],e.font[r]))){var c=t.family.join(\", \"),u=[t.style];t.style!=t.variant&&u.push(t.variant),t.variant!=t.weight&&u.push(t.weight),_&&t.weight!=t.stretch&&u.push(t.stretch),e.font[r]={baseString:i,family:c,weight:t.weight,stretch:t.stretch,style:t.style,variant:t.variant,width:{},kerning:{},metrics:m(c,{origin:\"top\",fontSize:k.baseFontSize,fontStyle:u.join(\" \")})},k.fonts[i]=e.font[r]}}),(a||o)&&this.font.forEach(function(r,i){var a=n.stringify({size:e.fontSize[i],family:r.family,stretch:_?r.stretch:void 0,variant:r.variant,weight:r.weight,style:r.style});if(e.fontAtlas[i]=e.shader.atlas[a],!e.fontAtlas[i]){var o=r.metrics;e.shader.atlas[a]=e.fontAtlas[i]={fontString:a,step:2*Math.ceil(e.fontSize[i]*o.bottom*.5),em:e.fontSize[i],cols:0,rows:0,height:0,width:0,chars:[],ids:{},texture:e.regl.texture()}}null==t.text&&(t.text=e.text)}),\"string\"==typeof t.text&&t.position&&t.position.length>2){for(var s=Array(.5*t.position.length),f=0;f<s.length;f++)s[f]=t.text;t.text=s}if(null!=t.text||a){if(this.textOffsets=[0],Array.isArray(t.text)){this.count=t.text[0].length,this.counts=[this.count];for(var b=1;b<t.text.length;b++)this.textOffsets[b]=this.textOffsets[b-1]+t.text[b-1].length,this.count+=t.text[b].length,this.counts.push(t.text[b].length);this.text=t.text.join(\"\")}else this.text=t.text,this.count=this.text.length,this.counts=[this.count];r=[],this.font.forEach(function(t,n){k.atlasContext.font=t.baseString;for(var i=e.fontAtlas[n],a=0;a<e.text.length;a++){var o=e.text.charAt(a);if(null==i.ids[o]&&(i.ids[o]=i.chars.length,i.chars.push(o),r.push(o)),null==t.width[o]&&(t.width[o]=k.atlasContext.measureText(o).width/k.baseFontSize,e.kerning)){var s=[];for(var l in t.width)s.push(l+o,o+l);v(t.kerning,g(t.family,{pairs:s}))}}})}if(t.position)if(t.position.length>2){for(var w=!t.position[0].length,T=u.mallocFloat(2*this.count),A=0,M=0;A<this.counts.length;A++){var S=this.counts[A];if(w)for(var E=0;E<S;E++)T[M++]=t.position[2*A],T[M++]=t.position[2*A+1];else for(var C=0;C<S;C++)T[M++]=t.position[A][0],T[M++]=t.position[A][1]}this.position.call?this.position({type:\"float\",data:T}):this.position=this.regl.buffer({type:\"float\",data:T}),u.freeFloat(T)}else this.position.destroy&&this.position.destroy(),this.position={constant:t.position};if(t.text||a){var L=u.mallocUint8(this.count),P=u.mallocFloat(2*this.count);this.textWidth=[];for(var O=0,z=0;O<this.counts.length;O++){for(var I=this.counts[O],D=this.font[O]||this.font[0],R=this.fontAtlas[O]||this.fontAtlas[0],F=0;F<I;F++){var B=this.text.charAt(z),N=this.text.charAt(z-1);if(L[z]=R.ids[B],P[2*z]=D.width[B],F){var j=P[2*z-2],U=P[2*z],V=P[2*z-1]+.5*j+.5*U;if(this.kerning){var q=D.kerning[N+B];q&&(V+=.001*q)}P[2*z+1]=V}else P[2*z+1]=.5*P[2*z];z++}this.textWidth.push(P.length?.5*P[2*z-2]+P[2*z-1]:0)}t.align||(t.align=this.align),this.charBuffer({data:L,type:\"uint8\",usage:\"stream\"}),this.sizeBuffer({data:P,type:\"float\",usage:\"stream\"}),u.freeUint8(L),u.freeFloat(P),r.length&&this.font.forEach(function(t,r){var n=e.fontAtlas[r],i=n.step,a=Math.floor(k.maxAtlasSize/i),o=Math.min(a,n.chars.length),s=Math.ceil(n.chars.length/o),l=x(o*i),u=x(s*i);n.width=l,n.height=u,n.rows=s,n.cols=o,n.em&&n.texture({data:c({canvas:k.atlasCanvas,font:n.fontString,chars:n.chars,shape:[l,u],step:[i,i]})})})}if(t.align&&(this.align=t.align,this.alignOffset=this.textWidth.map(function(t,r){var n=Array.isArray(e.align)?e.align.length>1?e.align[r]:e.align[0]:e.align;if(\"number\"==typeof n)return n;switch(n){case\"right\":case\"end\":return-t;case\"center\":case\"centre\":case\"middle\":return.5*-t}return 0})),null==this.baseline&&null==t.baseline&&(t.baseline=0),null!=t.baseline&&(this.baseline=t.baseline,Array.isArray(this.baseline)||(this.baseline=[this.baseline]),this.baselineOffset=this.baseline.map(function(t,r){var n=(e.font[r]||e.font[0]).metrics,i=0;return i+=.5*n.bottom,i+=\"number\"==typeof t?t-n.baseline:-n[t],k.normalViewport||(i*=-1),i})),null!=t.color)if(t.color||(t.color=\"transparent\"),\"string\"!=typeof t.color&&isNaN(t.color)){var H;if(\"number\"==typeof t.color[0]&&t.color.length>this.counts.length){var G=t.color.length;H=u.mallocUint8(G);for(var Y=(t.color.subarray||t.color.slice).bind(t.color),W=0;W<G;W+=4)H.set(l(Y(W,W+4),\"uint8\"),W)}else{var X=t.color.length;H=u.mallocUint8(4*X);for(var Z=0;Z<X;Z++)H.set(l(t.color[Z]||0,\"uint8\"),4*Z)}this.color=H}else this.color=l(t.color,\"uint8\");if(t.position||t.text||t.color||t.baseline||t.align||t.font||t.offset||t.opacity)if(this.color.length>4||this.baselineOffset.length>1||this.align&&this.align.length>1||this.fontAtlas.length>1||this.positionOffset.length>2){var J=Math.max(.5*this.position.length||0,.25*this.color.length||0,this.baselineOffset.length||0,this.alignOffset.length||0,this.font.length||0,this.opacity.length||0,.5*this.positionOffset.length||0);this.batch=Array(J);for(var K=0;K<this.batch.length;K++)this.batch[K]={count:this.counts.length>1?this.counts[K]:this.counts[0],offset:this.textOffsets.length>1?this.textOffsets[K]:this.textOffsets[0],color:this.color?this.color.length<=4?this.color:this.color.subarray(4*K,4*K+4):[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[K]:this.opacity,baseline:null!=this.baselineOffset[K]?this.baselineOffset[K]:this.baselineOffset[0],align:this.align?null!=this.alignOffset[K]?this.alignOffset[K]:this.alignOffset[0]:0,atlas:this.fontAtlas[K]||this.fontAtlas[0],positionOffset:this.positionOffset.length>2?this.positionOffset.subarray(2*K,2*K+2):this.positionOffset}}else this.count?this.batch=[{count:this.count,offset:0,color:this.color||[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[0]:this.opacity,baseline:this.baselineOffset[0],align:this.alignOffset?this.alignOffset[0]:0,atlas:this.fontAtlas[0],positionOffset:this.positionOffset}]:this.batch=[]},k.prototype.destroy=function(){},k.prototype.kerning=!0,k.prototype.position={constant:new Float32Array(2)},k.prototype.translate=null,k.prototype.scale=null,k.prototype.font=null,k.prototype.text=\"\",k.prototype.positionOffset=[0,0],k.prototype.opacity=1,k.prototype.color=new Uint8Array([0,0,0,255]),k.prototype.alignOffset=[0,0],k.normalViewport=!1,k.maxAtlasSize=1024,k.atlasCanvas=document.createElement(\"canvas\"),k.atlasContext=k.atlasCanvas.getContext(\"2d\",{alpha:!1}),k.baseFontSize=64,k.fonts={},e.exports=k},{\"bit-twiddle\":92,\"color-normalize\":120,\"css-font\":139,\"detect-kerning\":166,\"es6-weak-map\":318,\"flatten-vertex-data\":227,\"font-atlas\":228,\"font-measure\":229,\"gl-util/context\":323,\"is-plain-obj\":422,\"object-assign\":454,\"parse-rect\":459,\"parse-unit\":461,\"pick-by-alias\":465,regl:502,\"to-px\":539,\"typedarray-pool\":545}],318:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?WeakMap:t(\"./polyfill\")},{\"./is-implemented\":319,\"./polyfill\":321}],319:[function(t,e,r){\"use strict\";e.exports=function(){var t,e;if(\"function\"!=typeof WeakMap)return!1;try{t=new WeakMap([[e={},\"one\"],[{},\"two\"],[{},\"three\"]])}catch(t){return!1}return\"[object WeakMap]\"===String(t)&&(\"function\"==typeof t.set&&(t.set({},1)===t&&(\"function\"==typeof t.delete&&(\"function\"==typeof t.has&&\"one\"===t.get(e)))))}},{}],320:[function(t,e,r){\"use strict\";e.exports=\"function\"==typeof WeakMap&&\"[object WeakMap]\"===Object.prototype.toString.call(new WeakMap)},{}],321:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/object/set-prototype-of\"),o=t(\"es5-ext/object/valid-object\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"es5-ext/string/random-uniq\"),c=t(\"d\"),u=t(\"es6-iterator/get\"),h=t(\"es6-iterator/for-of\"),f=t(\"es6-symbol\").toStringTag,p=t(\"./is-native-implemented\"),d=Array.isArray,g=Object.defineProperty,v=Object.prototype.hasOwnProperty,m=Object.getPrototypeOf;e.exports=n=function(){var t,e=arguments[0];if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");return t=p&&a&&WeakMap!==n?a(new WeakMap,m(this)):this,i(e)&&(d(e)||(e=u(e))),g(t,\"__weakMapData__\",c(\"c\",\"$weakMap$\"+l())),e?(h(e,function(e){s(e),t.set(e[0],e[1])}),t):t},p&&(a&&a(n,WeakMap),n.prototype=Object.create(WeakMap.prototype,{constructor:c(n)})),Object.defineProperties(n.prototype,{delete:c(function(t){return!!v.call(o(t),this.__weakMapData__)&&(delete t[this.__weakMapData__],!0)}),get:c(function(t){if(v.call(o(t),this.__weakMapData__))return t[this.__weakMapData__]}),has:c(function(t){return v.call(o(t),this.__weakMapData__)}),set:c(function(t,e){return g(o(t),this.__weakMapData__,c(\"c\",e)),this}),toString:c(function(){return\"[object WeakMap]\"})}),g(n.prototype,f,c(\"c\",\"WeakMap\"))},{\"./is-native-implemented\":320,d:151,\"es5-ext/object/is-value\":194,\"es5-ext/object/set-prototype-of\":200,\"es5-ext/object/valid-object\":204,\"es5-ext/object/valid-value\":205,\"es5-ext/string/random-uniq\":210,\"es6-iterator/for-of\":212,\"es6-iterator/get\":213,\"es6-symbol\":219}],322:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"ndarray-ops\"),a=t(\"typedarray-pool\");e.exports=function(t){if(arguments.length<=1)throw new Error(\"gl-texture2d: Missing arguments for texture2d constructor\");o||function(t){o=[t.LINEAR,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_NEAREST],s=[t.NEAREST,t.LINEAR,t.NEAREST_MIPMAP_NEAREST,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_LINEAR],l=[t.REPEAT,t.CLAMP_TO_EDGE,t.MIRRORED_REPEAT]}(t);if(\"number\"==typeof arguments[1])return v(t,arguments[1],arguments[2],arguments[3]||t.RGBA,arguments[4]||t.UNSIGNED_BYTE);if(Array.isArray(arguments[1]))return v(t,0|arguments[1][0],0|arguments[1][1],arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(\"object\"==typeof arguments[1]){var e=arguments[1],r=c(e)?e:e.raw;if(r)return function(t,e,r,n,i,a){var o=g(t);return t.texImage2D(t.TEXTURE_2D,0,i,i,a,e),new f(t,o,r,n,i,a)}(t,r,0|e.width,0|e.height,arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(e.shape&&e.data&&e.stride)return function(t,e){var r=e.dtype,o=e.shape.slice(),s=t.getParameter(t.MAX_TEXTURE_SIZE);if(o[0]<0||o[0]>s||o[1]<0||o[1]>s)throw new Error(\"gl-texture2d: Invalid texture size\");var l=d(o,e.stride.slice()),c=0;\"float32\"===r?c=t.FLOAT:\"float64\"===r?(c=t.FLOAT,l=!1,r=\"float32\"):\"uint8\"===r?c=t.UNSIGNED_BYTE:(c=t.UNSIGNED_BYTE,l=!1,r=\"uint8\");var h,p,v=0;if(2===o.length)v=t.LUMINANCE,o=[o[0],o[1],1],e=n(e.data,o,[e.stride[0],e.stride[1],1],e.offset);else{if(3!==o.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===o[2])v=t.ALPHA;else if(2===o[2])v=t.LUMINANCE_ALPHA;else if(3===o[2])v=t.RGB;else{if(4!==o[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");v=t.RGBA}}c!==t.FLOAT||t.getExtension(\"OES_texture_float\")||(c=t.UNSIGNED_BYTE,l=!1);var m=e.size;if(l)h=0===e.offset&&e.data.length===m?e.data:e.data.subarray(e.offset,e.offset+m);else{var y=[o[2],o[2]*o[0],1];p=a.malloc(m,r);var x=n(p,o,y,0);\"float32\"!==r&&\"float64\"!==r||c!==t.UNSIGNED_BYTE?i.assign(x,e):u(x,e),h=p.subarray(0,m)}var b=g(t);t.texImage2D(t.TEXTURE_2D,0,v,o[0],o[1],0,v,c,h),l||a.free(p);return new f(t,b,o[0],o[1],v,c)}(t,e)}throw new Error(\"gl-texture2d: Invalid arguments for texture2d constructor\")};var o=null,s=null,l=null;function c(t){return\"undefined\"!=typeof HTMLCanvasElement&&t instanceof HTMLCanvasElement||\"undefined\"!=typeof HTMLImageElement&&t instanceof HTMLImageElement||\"undefined\"!=typeof HTMLVideoElement&&t instanceof HTMLVideoElement||\"undefined\"!=typeof ImageData&&t instanceof ImageData}var u=function(t,e){i.muls(t,e,255)};function h(t,e,r){var n=t.gl,i=n.getParameter(n.MAX_TEXTURE_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-texture2d: Invalid texture size\");return t._shape=[e,r],t.bind(),n.texImage2D(n.TEXTURE_2D,0,t.format,e,r,0,t.format,t.type,null),t._mipLevels=[0],t}function f(t,e,r,n,i,a){this.gl=t,this.handle=e,this.format=i,this.type=a,this._shape=[r,n],this._mipLevels=[0],this._magFilter=t.NEAREST,this._minFilter=t.NEAREST,this._wrapS=t.CLAMP_TO_EDGE,this._wrapT=t.CLAMP_TO_EDGE,this._anisoSamples=1;var o=this,s=[this._wrapS,this._wrapT];Object.defineProperties(s,[{get:function(){return o._wrapS},set:function(t){return o.wrapS=t}},{get:function(){return o._wrapT},set:function(t){return o.wrapT=t}}]),this._wrapVector=s;var l=[this._shape[0],this._shape[1]];Object.defineProperties(l,[{get:function(){return o._shape[0]},set:function(t){return o.width=t}},{get:function(){return o._shape[1]},set:function(t){return o.height=t}}]),this._shapeVector=l}var p=f.prototype;function d(t,e){return 3===t.length?1===e[2]&&e[1]===t[0]*t[2]&&e[0]===t[2]:1===e[0]&&e[1]===t[0]}function g(t){var e=t.createTexture();return t.bindTexture(t.TEXTURE_2D,e),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MIN_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MAG_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_S,t.CLAMP_TO_EDGE),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_T,t.CLAMP_TO_EDGE),e}function v(t,e,r,n,i){var a=t.getParameter(t.MAX_TEXTURE_SIZE);if(e<0||e>a||r<0||r>a)throw new Error(\"gl-texture2d: Invalid texture shape\");if(i===t.FLOAT&&!t.getExtension(\"OES_texture_float\"))throw new Error(\"gl-texture2d: Floating point textures not supported on this platform\");var o=g(t);return t.texImage2D(t.TEXTURE_2D,0,n,e,r,0,n,i,null),new f(t,o,e,r,n,i)}Object.defineProperties(p,{minFilter:{get:function(){return this._minFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,t),this._minFilter=t}},magFilter:{get:function(){return this._magFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,t),this._magFilter=t}},mipSamples:{get:function(){return this._anisoSamples},set:function(t){var e=this._anisoSamples;if(this._anisoSamples=0|Math.max(t,1),e!==this._anisoSamples){var r=this.gl.getExtension(\"EXT_texture_filter_anisotropic\");r&&this.gl.texParameterf(this.gl.TEXTURE_2D,r.TEXTURE_MAX_ANISOTROPY_EXT,this._anisoSamples)}return this._anisoSamples}},wrapS:{get:function(){return this._wrapS},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_S,t),this._wrapS=t}},wrapT:{get:function(){return this._wrapT},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_T,t),this._wrapT=t}},wrap:{get:function(){return this._wrapVector},set:function(t){if(Array.isArray(t)||(t=[t,t]),2!==t.length)throw new Error(\"gl-texture2d: Must specify wrap mode for rows and columns\");for(var e=0;e<2;++e)if(l.indexOf(t[e])<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);this._wrapS=t[0],this._wrapT=t[1];var r=this.gl;return this.bind(),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_S,this._wrapS),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_T,this._wrapT),t}},shape:{get:function(){return this._shapeVector},set:function(t){if(Array.isArray(t)){if(2!==t.length)throw new Error(\"gl-texture2d: Invalid texture shape\")}else t=[0|t,0|t];return h(this,0|t[0],0|t[1]),[0|t[0],0|t[1]]}},width:{get:function(){return this._shape[0]},set:function(t){return h(this,t|=0,this._shape[1]),t}},height:{get:function(){return this._shape[1]},set:function(t){return t|=0,h(this,this._shape[0],t),t}}}),p.bind=function(t){var e=this.gl;return void 0!==t&&e.activeTexture(e.TEXTURE0+(0|t)),e.bindTexture(e.TEXTURE_2D,this.handle),void 0!==t?0|t:e.getParameter(e.ACTIVE_TEXTURE)-e.TEXTURE0},p.dispose=function(){this.gl.deleteTexture(this.handle)},p.generateMipmap=function(){this.bind(),this.gl.generateMipmap(this.gl.TEXTURE_2D);for(var t=Math.min(this._shape[0],this._shape[1]),e=0;t>0;++e,t>>>=1)this._mipLevels.indexOf(e)<0&&this._mipLevels.push(e)},p.setPixels=function(t,e,r,o){var s=this.gl;this.bind(),Array.isArray(e)?(o=r,r=0|e[1],e=0|e[0]):(e=e||0,r=r||0),o=o||0;var l=c(t)?t:t.raw;if(l){this._mipLevels.indexOf(o)<0?(s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,this.type,l),this._mipLevels.push(o)):s.texSubImage2D(s.TEXTURE_2D,o,e,r,this.format,this.type,l)}else{if(!(t.shape&&t.stride&&t.data))throw new Error(\"gl-texture2d: Unsupported data type\");if(t.shape.length<2||e+t.shape[1]>this._shape[1]>>>o||r+t.shape[0]>this._shape[0]>>>o||e<0||r<0)throw new Error(\"gl-texture2d: Texture dimensions are out of bounds\");!function(t,e,r,o,s,l,c,h){var f=h.dtype,p=h.shape.slice();if(p.length<2||p.length>3)throw new Error(\"gl-texture2d: Invalid ndarray, must be 2d or 3d\");var g=0,v=0,m=d(p,h.stride.slice());\"float32\"===f?g=t.FLOAT:\"float64\"===f?(g=t.FLOAT,m=!1,f=\"float32\"):\"uint8\"===f?g=t.UNSIGNED_BYTE:(g=t.UNSIGNED_BYTE,m=!1,f=\"uint8\");if(2===p.length)v=t.LUMINANCE,p=[p[0],p[1],1],h=n(h.data,p,[h.stride[0],h.stride[1],1],h.offset);else{if(3!==p.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===p[2])v=t.ALPHA;else if(2===p[2])v=t.LUMINANCE_ALPHA;else if(3===p[2])v=t.RGB;else{if(4!==p[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");v=t.RGBA}p[2]}v!==t.LUMINANCE&&v!==t.ALPHA||s!==t.LUMINANCE&&s!==t.ALPHA||(v=s);if(v!==s)throw new Error(\"gl-texture2d: Incompatible texture format for setPixels\");var y=h.size,x=c.indexOf(o)<0;x&&c.push(o);if(g===l&&m)0===h.offset&&h.data.length===y?x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,h.data):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,h.data):x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,h.data.subarray(h.offset,h.offset+y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,h.data.subarray(h.offset,h.offset+y));else{var b;b=l===t.FLOAT?a.mallocFloat32(y):a.mallocUint8(y);var _=n(b,p,[p[2],p[2]*p[0],1]);g===t.FLOAT&&l===t.UNSIGNED_BYTE?u(_,h):i.assign(_,h),x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,b.subarray(0,y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,b.subarray(0,y)),l===t.FLOAT?a.freeFloat32(b):a.freeUint8(b)}}(s,e,r,o,this.format,this.type,this._mipLevels,t)}}},{ndarray:450,\"ndarray-ops\":444,\"typedarray-pool\":545}],323:[function(t,e,r){(function(r){\"use strict\";var n=t(\"pick-by-alias\");function i(t){if(t.container)if(t.container==document.body)document.body.style.width||(t.canvas.width=t.width||t.pixelRatio*r.innerWidth),document.body.style.height||(t.canvas.height=t.height||t.pixelRatio*r.innerHeight);else{var e=t.container.getBoundingClientRect();t.canvas.width=t.width||e.right-e.left,t.canvas.height=t.height||e.bottom-e.top}}function a(t){return\"function\"==typeof t.getContext&&\"width\"in t&&\"height\"in t}function o(){var t=document.createElement(\"canvas\");return t.style.position=\"absolute\",t.style.top=0,t.style.left=0,t}e.exports=function(t){var e;if(t?\"string\"==typeof t&&(t={container:t}):t={},a(t)?t={container:t}:t=\"string\"==typeof(e=t).nodeName&&\"function\"==typeof e.appendChild&&\"function\"==typeof e.getBoundingClientRect?{container:t}:function(t){return\"function\"==typeof t.drawArrays||\"function\"==typeof t.drawElements}(t)?{gl:t}:n(t,{container:\"container target element el canvas holder parent parentNode wrapper use ref root node\",gl:\"gl context webgl glContext\",attrs:\"attributes attrs contextAttributes\",pixelRatio:\"pixelRatio pxRatio px ratio pxratio pixelratio\",width:\"w width\",height:\"h height\"},!0),t.pixelRatio||(t.pixelRatio=r.pixelRatio||1),t.gl)return t.gl;if(t.canvas&&(t.container=t.canvas.parentNode),t.container){if(\"string\"==typeof t.container){var s=document.querySelector(t.container);if(!s)throw Error(\"Element \"+t.container+\" is not found\");t.container=s}a(t.container)?(t.canvas=t.container,t.container=t.canvas.parentNode):t.canvas||(t.canvas=o(),t.container.appendChild(t.canvas),i(t))}else if(!t.canvas){if(\"undefined\"==typeof document)throw Error(\"Not DOM environment. Use headless-gl.\");t.container=document.body||document.documentElement,t.canvas=o(),t.container.appendChild(t.canvas),i(t)}if(!t.gl)try{t.gl=t.canvas.getContext(\"webgl\",t.attrs)}catch(e){try{t.gl=t.canvas.getContext(\"experimental-webgl\",t.attrs)}catch(e){t.gl=t.canvas.getContext(\"webgl-experimental\",t.attrs)}}return t.gl}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"pick-by-alias\":465}],324:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){e?e.bind():t.bindBuffer(t.ELEMENT_ARRAY_BUFFER,null);var n=0|t.getParameter(t.MAX_VERTEX_ATTRIBS);if(r){if(r.length>n)throw new Error(\"gl-vao: Too many vertex attributes\");for(var i=0;i<r.length;++i){var a=r[i];if(a.buffer){var o=a.buffer,s=a.size||4,l=a.type||t.FLOAT,c=!!a.normalized,u=a.stride||0,h=a.offset||0;o.bind(),t.enableVertexAttribArray(i),t.vertexAttribPointer(i,s,l,c,u,h)}else{if(\"number\"==typeof a)t.vertexAttrib1f(i,a);else if(1===a.length)t.vertexAttrib1f(i,a[0]);else if(2===a.length)t.vertexAttrib2f(i,a[0],a[1]);else if(3===a.length)t.vertexAttrib3f(i,a[0],a[1],a[2]);else{if(4!==a.length)throw new Error(\"gl-vao: Invalid vertex attribute\");t.vertexAttrib4f(i,a[0],a[1],a[2],a[3])}t.disableVertexAttribArray(i)}}for(;i<n;++i)t.disableVertexAttribArray(i)}else for(t.bindBuffer(t.ARRAY_BUFFER,null),i=0;i<n;++i)t.disableVertexAttribArray(i)}},{}],325:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t){this.gl=t,this._elements=null,this._attributes=null,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(){n(this.gl,this._elements,this._attributes)},i.prototype.update=function(t,e,r){this._elements=e,this._attributes=t,this._elementsType=r||this.gl.UNSIGNED_SHORT},i.prototype.dispose=function(){},i.prototype.unbind=function(){},i.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._elements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t){return new i(t)}},{\"./do-bind.js\":324}],326:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t,e,r,n,i,a){this.location=t,this.dimension=e,this.a=r,this.b=n,this.c=i,this.d=a}function a(t,e,r){this.gl=t,this._ext=e,this.handle=r,this._attribs=[],this._useElements=!1,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(t){switch(this.dimension){case 1:t.vertexAttrib1f(this.location,this.a);break;case 2:t.vertexAttrib2f(this.location,this.a,this.b);break;case 3:t.vertexAttrib3f(this.location,this.a,this.b,this.c);break;case 4:t.vertexAttrib4f(this.location,this.a,this.b,this.c,this.d)}},a.prototype.bind=function(){this._ext.bindVertexArrayOES(this.handle);for(var t=0;t<this._attribs.length;++t)this._attribs[t].bind(this.gl)},a.prototype.unbind=function(){this._ext.bindVertexArrayOES(null)},a.prototype.dispose=function(){this._ext.deleteVertexArrayOES(this.handle)},a.prototype.update=function(t,e,r){if(this.bind(),n(this.gl,e,t),this.unbind(),this._attribs.length=0,t)for(var a=0;a<t.length;++a){var o=t[a];\"number\"==typeof o?this._attribs.push(new i(a,1,o)):Array.isArray(o)&&this._attribs.push(new i(a,o.length,o[0],o[1],o[2],o[3]))}this._useElements=!!e,this._elementsType=r||this.gl.UNSIGNED_SHORT},a.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._useElements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t,e){return new a(t,e,e.createVertexArrayOES())}},{\"./do-bind.js\":324}],327:[function(t,e,r){\"use strict\";var n=t(\"./lib/vao-native.js\"),i=t(\"./lib/vao-emulated.js\");function a(t){this.bindVertexArrayOES=t.bindVertexArray.bind(t),this.createVertexArrayOES=t.createVertexArray.bind(t),this.deleteVertexArrayOES=t.deleteVertexArray.bind(t)}e.exports=function(t,e,r,o){var s,l=t.createVertexArray?new a(t):t.getExtension(\"OES_vertex_array_object\");return(s=l?n(t,l):i(t)).update(e,r,o),s}},{\"./lib/vao-emulated.js\":325,\"./lib/vao-native.js\":326}],328:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t}},{}],329:[function(t,e,r){e.exports=function(t,e){var r=n(t[0],t[1],t[2]),o=n(e[0],e[1],e[2]);i(r,r),i(o,o);var s=a(r,o);return s>1?0:Math.acos(s)};var n=t(\"./fromValues\"),i=t(\"./normalize\"),a=t(\"./dot\")},{\"./dot\":339,\"./fromValues\":345,\"./normalize\":356}],330:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.ceil(e[0]),t[1]=Math.ceil(e[1]),t[2]=Math.ceil(e[2]),t}},{}],331:[function(t,e,r){e.exports=function(t){var e=new Float32Array(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e}},{}],332:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}},{}],333:[function(t,e,r){e.exports=function(){var t=new Float32Array(3);return t[0]=0,t[1]=0,t[2]=0,t}},{}],334:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2];return t[0]=i*l-a*s,t[1]=a*o-n*l,t[2]=n*s-i*o,t}},{}],335:[function(t,e,r){e.exports=t(\"./distance\")},{\"./distance\":336}],336:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return Math.sqrt(r*r+n*n+i*i)}},{}],337:[function(t,e,r){e.exports=t(\"./divide\")},{\"./divide\":338}],338:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t}},{}],339:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}},{}],340:[function(t,e,r){e.exports=1e-6},{}],341:[function(t,e,r){e.exports=function(t,e){var r=t[0],i=t[1],a=t[2],o=e[0],s=e[1],l=e[2];return Math.abs(r-o)<=n*Math.max(1,Math.abs(r),Math.abs(o))&&Math.abs(i-s)<=n*Math.max(1,Math.abs(i),Math.abs(s))&&Math.abs(a-l)<=n*Math.max(1,Math.abs(a),Math.abs(l))};var n=t(\"./epsilon\")},{\"./epsilon\":340}],342:[function(t,e,r){e.exports=function(t,e){return t[0]===e[0]&&t[1]===e[1]&&t[2]===e[2]}},{}],343:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.floor(e[0]),t[1]=Math.floor(e[1]),t[2]=Math.floor(e[2]),t}},{}],344:[function(t,e,r){e.exports=function(t,e,r,i,a,o){var s,l;e||(e=3);r||(r=0);l=i?Math.min(i*e+r,t.length):t.length;for(s=r;s<l;s+=e)n[0]=t[s],n[1]=t[s+1],n[2]=t[s+2],a(n,n,o),t[s]=n[0],t[s+1]=n[1],t[s+2]=n[2];return t};var n=t(\"./create\")()},{\"./create\":333}],345:[function(t,e,r){e.exports=function(t,e,r){var n=new Float32Array(3);return n[0]=t,n[1]=e,n[2]=r,n}},{}],346:[function(t,e,r){e.exports={EPSILON:t(\"./epsilon\"),create:t(\"./create\"),clone:t(\"./clone\"),angle:t(\"./angle\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),equals:t(\"./equals\"),exactEquals:t(\"./exactEquals\"),add:t(\"./add\"),subtract:t(\"./subtract\"),sub:t(\"./sub\"),multiply:t(\"./multiply\"),mul:t(\"./mul\"),divide:t(\"./divide\"),div:t(\"./div\"),min:t(\"./min\"),max:t(\"./max\"),floor:t(\"./floor\"),ceil:t(\"./ceil\"),round:t(\"./round\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),dist:t(\"./dist\"),squaredDistance:t(\"./squaredDistance\"),sqrDist:t(\"./sqrDist\"),length:t(\"./length\"),len:t(\"./len\"),squaredLength:t(\"./squaredLength\"),sqrLen:t(\"./sqrLen\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),cross:t(\"./cross\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformMat3:t(\"./transformMat3\"),transformQuat:t(\"./transformQuat\"),rotateX:t(\"./rotateX\"),rotateY:t(\"./rotateY\"),rotateZ:t(\"./rotateZ\"),forEach:t(\"./forEach\")}},{\"./add\":328,\"./angle\":329,\"./ceil\":330,\"./clone\":331,\"./copy\":332,\"./create\":333,\"./cross\":334,\"./dist\":335,\"./distance\":336,\"./div\":337,\"./divide\":338,\"./dot\":339,\"./epsilon\":340,\"./equals\":341,\"./exactEquals\":342,\"./floor\":343,\"./forEach\":344,\"./fromValues\":345,\"./inverse\":347,\"./len\":348,\"./length\":349,\"./lerp\":350,\"./max\":351,\"./min\":352,\"./mul\":353,\"./multiply\":354,\"./negate\":355,\"./normalize\":356,\"./random\":357,\"./rotateX\":358,\"./rotateY\":359,\"./rotateZ\":360,\"./round\":361,\"./scale\":362,\"./scaleAndAdd\":363,\"./set\":364,\"./sqrDist\":365,\"./sqrLen\":366,\"./squaredDistance\":367,\"./squaredLength\":368,\"./sub\":369,\"./subtract\":370,\"./transformMat3\":371,\"./transformMat4\":372,\"./transformQuat\":373}],347:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t}},{}],348:[function(t,e,r){e.exports=t(\"./length\")},{\"./length\":349}],349:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return Math.sqrt(e*e+r*r+n*n)}},{}],350:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t}},{}],351:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t}},{}],352:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t}},{}],353:[function(t,e,r){e.exports=t(\"./multiply\")},{\"./multiply\":354}],354:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t}},{}],355:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t}},{}],356:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=r*r+n*n+i*i;a>0&&(a=1/Math.sqrt(a),t[0]=e[0]*a,t[1]=e[1]*a,t[2]=e[2]*a);return t}},{}],357:[function(t,e,r){e.exports=function(t,e){e=e||1;var r=2*Math.random()*Math.PI,n=2*Math.random()-1,i=Math.sqrt(1-n*n)*e;return t[0]=Math.cos(r)*i,t[1]=Math.sin(r)*i,t[2]=n*e,t}},{}],358:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[1],a=r[2],o=e[1]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=e[0],t[1]=i+o*c-s*l,t[2]=a+o*l+s*c,t}},{}],359:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[2],o=e[0]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+s*l+o*c,t[1]=e[1],t[2]=a+s*c-o*l,t}},{}],360:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[1],o=e[0]-i,s=e[1]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+o*c-s*l,t[1]=a+o*l+s*c,t[2]=e[2],t}},{}],361:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.round(e[0]),t[1]=Math.round(e[1]),t[2]=Math.round(e[2]),t}},{}],362:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t}},{}],363:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t}},{}],364:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e,t[1]=r,t[2]=n,t}},{}],365:[function(t,e,r){e.exports=t(\"./squaredDistance\")},{\"./squaredDistance\":367}],366:[function(t,e,r){e.exports=t(\"./squaredLength\")},{\"./squaredLength\":368}],367:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return r*r+n*n+i*i}},{}],368:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return e*e+r*r+n*n}},{}],369:[function(t,e,r){e.exports=t(\"./subtract\")},{\"./subtract\":370}],370:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t}},{}],371:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t}},{}],372:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[3]*n+r[7]*i+r[11]*a+r[15];return o=o||1,t[0]=(r[0]*n+r[4]*i+r[8]*a+r[12])/o,t[1]=(r[1]*n+r[5]*i+r[9]*a+r[13])/o,t[2]=(r[2]*n+r[6]*i+r[10]*a+r[14])/o,t}},{}],373:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,h=c*i+l*n-o*a,f=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+h*-l-f*-s,t[1]=h*c+p*-s+f*-o-u*-l,t[2]=f*c+p*-l+u*-s-h*-o,t}},{}],374:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t[3]=e[3]+r[3],t}},{}],375:[function(t,e,r){e.exports=function(t){var e=new Float32Array(4);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e}},{}],376:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t}},{}],377:[function(t,e,r){e.exports=function(){var t=new Float32Array(4);return t[0]=0,t[1]=0,t[2]=0,t[3]=0,t}},{}],378:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return Math.sqrt(r*r+n*n+i*i+a*a)}},{}],379:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t[3]=e[3]/r[3],t}},{}],380:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}},{}],381:[function(t,e,r){e.exports=function(t,e,r,n){var i=new Float32Array(4);return i[0]=t,i[1]=e,i[2]=r,i[3]=n,i}},{}],382:[function(t,e,r){e.exports={create:t(\"./create\"),clone:t(\"./clone\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),add:t(\"./add\"),subtract:t(\"./subtract\"),multiply:t(\"./multiply\"),divide:t(\"./divide\"),min:t(\"./min\"),max:t(\"./max\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),squaredDistance:t(\"./squaredDistance\"),length:t(\"./length\"),squaredLength:t(\"./squaredLength\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformQuat:t(\"./transformQuat\")}},{\"./add\":374,\"./clone\":375,\"./copy\":376,\"./create\":377,\"./distance\":378,\"./divide\":379,\"./dot\":380,\"./fromValues\":381,\"./inverse\":383,\"./length\":384,\"./lerp\":385,\"./max\":386,\"./min\":387,\"./multiply\":388,\"./negate\":389,\"./normalize\":390,\"./random\":391,\"./scale\":392,\"./scaleAndAdd\":393,\"./set\":394,\"./squaredDistance\":395,\"./squaredLength\":396,\"./subtract\":397,\"./transformMat4\":398,\"./transformQuat\":399}],383:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t[3]=1/e[3],t}},{}],384:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return Math.sqrt(e*e+r*r+n*n+i*i)}},{}],385:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2],s=e[3];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t[3]=s+n*(r[3]-s),t}},{}],386:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t[3]=Math.max(e[3],r[3]),t}},{}],387:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t[3]=Math.min(e[3],r[3]),t}},{}],388:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t[3]=e[3]*r[3],t}},{}],389:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t[3]=-e[3],t}},{}],390:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r*r+n*n+i*i+a*a;o>0&&(o=1/Math.sqrt(o),t[0]=r*o,t[1]=n*o,t[2]=i*o,t[3]=a*o);return t}},{}],391:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"./scale\");e.exports=function(t,e){return e=e||1,t[0]=Math.random(),t[1]=Math.random(),t[2]=Math.random(),t[3]=Math.random(),n(t,t),i(t,t,e),t}},{\"./normalize\":390,\"./scale\":392}],392:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t}},{}],393:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t[3]=e[3]+r[3]*n,t}},{}],394:[function(t,e,r){e.exports=function(t,e,r,n,i){return t[0]=e,t[1]=r,t[2]=n,t[3]=i,t}},{}],395:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return r*r+n*n+i*i+a*a}},{}],396:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return e*e+r*r+n*n+i*i}},{}],397:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t[3]=e[3]-r[3],t}},{}],398:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}},{}],399:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,h=c*i+l*n-o*a,f=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+h*-l-f*-s,t[1]=h*c+p*-s+f*-o-u*-l,t[2]=f*c+p*-l+u*-s-h*-o,t[3]=e[3],t}},{}],400:[function(t,e,r){e.exports=function(t,e,r,a){return n[0]=a,n[1]=r,n[2]=e,n[3]=t,i[0]};var n=new Uint8Array(4),i=new Float32Array(n.buffer)},{}],401:[function(t,e,r){var n=t(\"glsl-tokenizer\"),i=t(\"atob-lite\");e.exports=function(t){for(var e=Array.isArray(t)?t:n(t),r=0;r<e.length;r++){var a=e[r];if(\"preprocessor\"===a.type){var o=a.data.match(/\\#define\\s+SHADER_NAME(_B64)?\\s+(.+)$/);if(o&&o[2]){var s=o[1],l=o[2];return(s?i(l):l).trim()}}}}},{\"atob-lite\":72,\"glsl-tokenizer\":408}],402:[function(t,e,r){e.exports=function(t){var e,r,k,T=0,A=0,M=l,S=[],E=[],C=1,L=0,P=0,O=!1,z=!1,I=\"\",D=a,R=n;\"300 es\"===(t=t||{}).version&&(D=s,R=o);return function(t){return E=[],null!==t?function(t){var r;T=0,k=(I+=t).length;for(;e=I[T],T<k;){switch(r=T,M){case u:T=U();break;case h:case f:T=j();break;case p:T=V();break;case d:T=G();break;case _:T=H();break;case g:T=Y();break;case c:T=W();break;case x:T=N();break;case l:T=B()}if(r!==T)switch(I[r]){case\"\\n\":L=0,++C;break;default:++L}}return A+=T,I=I.slice(T),E}(t.replace?t.replace(/\\r\\n/g,\"\\n\"):t):function(t){S.length&&F(S.join(\"\"));return M=b,F(\"(eof)\"),E}()};function F(t){t.length&&E.push({type:w[M],data:t,position:P,line:C,column:L})}function B(){return S=S.length?[]:S,\"/\"===r&&\"*\"===e?(P=A+T-1,M=u,r=e,T+1):\"/\"===r&&\"/\"===e?(P=A+T-1,M=h,r=e,T+1):\"#\"===e?(M=f,P=A+T,T):/\\s/.test(e)?(M=x,P=A+T,T):(O=/\\d/.test(e),z=/[^\\w_]/.test(e),P=A+T,M=O?d:z?p:c,T)}function N(){return/[^\\s]/g.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function j(){return\"\\r\"!==e&&\"\\n\"!==e||\"\\\\\"===r?(S.push(e),r=e,T+1):(F(S.join(\"\")),M=l,T)}function U(){return\"/\"===e&&\"*\"===r?(S.push(e),F(S.join(\"\")),M=l,T+1):(S.push(e),r=e,T+1)}function V(){if(\".\"===r&&/\\d/.test(e))return M=g,T;if(\"/\"===r&&\"*\"===e)return M=u,T;if(\"/\"===r&&\"/\"===e)return M=h,T;if(\".\"===e&&S.length){for(;q(S););return M=g,T}if(\";\"===e||\")\"===e||\"(\"===e){if(S.length)for(;q(S););return F(e),M=l,T+1}var t=2===S.length&&\"=\"!==e;if(/[\\w_\\d\\s]/.test(e)||t){for(;q(S););return M=l,T}return S.push(e),r=e,T+1}function q(t){for(var e,r,n=0;;){if(e=i.indexOf(t.slice(0,t.length+n).join(\"\")),r=i[e],-1===e){if(n--+t.length>0)continue;r=t.slice(0,1).join(\"\")}return F(r),P+=r.length,(S=S.slice(r.length)).length}}function H(){return/[^a-fA-F0-9]/.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function G(){return\".\"===e?(S.push(e),M=g,r=e,T+1):/[eE]/.test(e)?(S.push(e),M=g,r=e,T+1):\"x\"===e&&1===S.length&&\"0\"===S[0]?(M=_,S.push(e),r=e,T+1):/[^\\d]/.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function Y(){return\"f\"===e&&(S.push(e),r=e,T+=1),/[eE]/.test(e)?(S.push(e),r=e,T+1):\"-\"===e&&/[eE]/.test(r)?(S.push(e),r=e,T+1):/[^\\d]/.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function W(){if(/[^\\d\\w_]/.test(e)){var t=S.join(\"\");return M=R.indexOf(t)>-1?y:D.indexOf(t)>-1?m:v,F(S.join(\"\")),M=l,T}return S.push(e),r=e,T+1}};var n=t(\"./lib/literals\"),i=t(\"./lib/operators\"),a=t(\"./lib/builtins\"),o=t(\"./lib/literals-300es\"),s=t(\"./lib/builtins-300es\"),l=999,c=9999,u=0,h=1,f=2,p=3,d=4,g=5,v=6,m=7,y=8,x=9,b=10,_=11,w=[\"block-comment\",\"line-comment\",\"preprocessor\",\"operator\",\"integer\",\"float\",\"ident\",\"builtin\",\"keyword\",\"whitespace\",\"eof\",\"integer\"]},{\"./lib/builtins\":404,\"./lib/builtins-300es\":403,\"./lib/literals\":406,\"./lib/literals-300es\":405,\"./lib/operators\":407}],403:[function(t,e,r){var n=t(\"./builtins\");n=n.slice().filter(function(t){return!/^(gl\\_|texture)/.test(t)}),e.exports=n.concat([\"gl_VertexID\",\"gl_InstanceID\",\"gl_Position\",\"gl_PointSize\",\"gl_FragCoord\",\"gl_FrontFacing\",\"gl_FragDepth\",\"gl_PointCoord\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexUniformVectors\",\"gl_MaxVertexOutputVectors\",\"gl_MaxFragmentInputVectors\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxTextureImageUnits\",\"gl_MaxFragmentUniformVectors\",\"gl_MaxDrawBuffers\",\"gl_MinProgramTexelOffset\",\"gl_MaxProgramTexelOffset\",\"gl_DepthRangeParameters\",\"gl_DepthRange\",\"trunc\",\"round\",\"roundEven\",\"isnan\",\"isinf\",\"floatBitsToInt\",\"floatBitsToUint\",\"intBitsToFloat\",\"uintBitsToFloat\",\"packSnorm2x16\",\"unpackSnorm2x16\",\"packUnorm2x16\",\"unpackUnorm2x16\",\"packHalf2x16\",\"unpackHalf2x16\",\"outerProduct\",\"transpose\",\"determinant\",\"inverse\",\"texture\",\"textureSize\",\"textureProj\",\"textureLod\",\"textureOffset\",\"texelFetch\",\"texelFetchOffset\",\"textureProjOffset\",\"textureLodOffset\",\"textureProjLod\",\"textureProjLodOffset\",\"textureGrad\",\"textureGradOffset\",\"textureProjGrad\",\"textureProjGradOffset\"])},{\"./builtins\":404}],404:[function(t,e,r){e.exports=[\"abs\",\"acos\",\"all\",\"any\",\"asin\",\"atan\",\"ceil\",\"clamp\",\"cos\",\"cross\",\"dFdx\",\"dFdy\",\"degrees\",\"distance\",\"dot\",\"equal\",\"exp\",\"exp2\",\"faceforward\",\"floor\",\"fract\",\"gl_BackColor\",\"gl_BackLightModelProduct\",\"gl_BackLightProduct\",\"gl_BackMaterial\",\"gl_BackSecondaryColor\",\"gl_ClipPlane\",\"gl_ClipVertex\",\"gl_Color\",\"gl_DepthRange\",\"gl_DepthRangeParameters\",\"gl_EyePlaneQ\",\"gl_EyePlaneR\",\"gl_EyePlaneS\",\"gl_EyePlaneT\",\"gl_Fog\",\"gl_FogCoord\",\"gl_FogFragCoord\",\"gl_FogParameters\",\"gl_FragColor\",\"gl_FragCoord\",\"gl_FragData\",\"gl_FragDepth\",\"gl_FragDepthEXT\",\"gl_FrontColor\",\"gl_FrontFacing\",\"gl_FrontLightModelProduct\",\"gl_FrontLightProduct\",\"gl_FrontMaterial\",\"gl_FrontSecondaryColor\",\"gl_LightModel\",\"gl_LightModelParameters\",\"gl_LightModelProducts\",\"gl_LightProducts\",\"gl_LightSource\",\"gl_LightSourceParameters\",\"gl_MaterialParameters\",\"gl_MaxClipPlanes\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxDrawBuffers\",\"gl_MaxFragmentUniformComponents\",\"gl_MaxLights\",\"gl_MaxTextureCoords\",\"gl_MaxTextureImageUnits\",\"gl_MaxTextureUnits\",\"gl_MaxVaryingFloats\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxVertexUniformComponents\",\"gl_ModelViewMatrix\",\"gl_ModelViewMatrixInverse\",\"gl_ModelViewMatrixInverseTranspose\",\"gl_ModelViewMatrixTranspose\",\"gl_ModelViewProjectionMatrix\",\"gl_ModelViewProjectionMatrixInverse\",\"gl_ModelViewProjectionMatrixInverseTranspose\",\"gl_ModelViewProjectionMatrixTranspose\",\"gl_MultiTexCoord0\",\"gl_MultiTexCoord1\",\"gl_MultiTexCoord2\",\"gl_MultiTexCoord3\",\"gl_MultiTexCoord4\",\"gl_MultiTexCoord5\",\"gl_MultiTexCoord6\",\"gl_MultiTexCoord7\",\"gl_Normal\",\"gl_NormalMatrix\",\"gl_NormalScale\",\"gl_ObjectPlaneQ\",\"gl_ObjectPlaneR\",\"gl_ObjectPlaneS\",\"gl_ObjectPlaneT\",\"gl_Point\",\"gl_PointCoord\",\"gl_PointParameters\",\"gl_PointSize\",\"gl_Position\",\"gl_ProjectionMatrix\",\"gl_ProjectionMatrixInverse\",\"gl_ProjectionMatrixInverseTranspose\",\"gl_ProjectionMatrixTranspose\",\"gl_SecondaryColor\",\"gl_TexCoord\",\"gl_TextureEnvColor\",\"gl_TextureMatrix\",\"gl_TextureMatrixInverse\",\"gl_TextureMatrixInverseTranspose\",\"gl_TextureMatrixTranspose\",\"gl_Vertex\",\"greaterThan\",\"greaterThanEqual\",\"inversesqrt\",\"length\",\"lessThan\",\"lessThanEqual\",\"log\",\"log2\",\"matrixCompMult\",\"max\",\"min\",\"mix\",\"mod\",\"normalize\",\"not\",\"notEqual\",\"pow\",\"radians\",\"reflect\",\"refract\",\"sign\",\"sin\",\"smoothstep\",\"sqrt\",\"step\",\"tan\",\"texture2D\",\"texture2DLod\",\"texture2DProj\",\"texture2DProjLod\",\"textureCube\",\"textureCubeLod\",\"texture2DLodEXT\",\"texture2DProjLodEXT\",\"textureCubeLodEXT\",\"texture2DGradEXT\",\"texture2DProjGradEXT\",\"textureCubeGradEXT\"]},{}],405:[function(t,e,r){var n=t(\"./literals\");e.exports=n.slice().concat([\"layout\",\"centroid\",\"smooth\",\"case\",\"mat2x2\",\"mat2x3\",\"mat2x4\",\"mat3x2\",\"mat3x3\",\"mat3x4\",\"mat4x2\",\"mat4x3\",\"mat4x4\",\"uint\",\"uvec2\",\"uvec3\",\"uvec4\",\"samplerCubeShadow\",\"sampler2DArray\",\"sampler2DArrayShadow\",\"isampler2D\",\"isampler3D\",\"isamplerCube\",\"isampler2DArray\",\"usampler2D\",\"usampler3D\",\"usamplerCube\",\"usampler2DArray\",\"coherent\",\"restrict\",\"readonly\",\"writeonly\",\"resource\",\"atomic_uint\",\"noperspective\",\"patch\",\"sample\",\"subroutine\",\"common\",\"partition\",\"active\",\"filter\",\"image1D\",\"image2D\",\"image3D\",\"imageCube\",\"iimage1D\",\"iimage2D\",\"iimage3D\",\"iimageCube\",\"uimage1D\",\"uimage2D\",\"uimage3D\",\"uimageCube\",\"image1DArray\",\"image2DArray\",\"iimage1DArray\",\"iimage2DArray\",\"uimage1DArray\",\"uimage2DArray\",\"image1DShadow\",\"image2DShadow\",\"image1DArrayShadow\",\"image2DArrayShadow\",\"imageBuffer\",\"iimageBuffer\",\"uimageBuffer\",\"sampler1DArray\",\"sampler1DArrayShadow\",\"isampler1D\",\"isampler1DArray\",\"usampler1D\",\"usampler1DArray\",\"isampler2DRect\",\"usampler2DRect\",\"samplerBuffer\",\"isamplerBuffer\",\"usamplerBuffer\",\"sampler2DMS\",\"isampler2DMS\",\"usampler2DMS\",\"sampler2DMSArray\",\"isampler2DMSArray\",\"usampler2DMSArray\"])},{\"./literals\":406}],406:[function(t,e,r){e.exports=[\"precision\",\"highp\",\"mediump\",\"lowp\",\"attribute\",\"const\",\"uniform\",\"varying\",\"break\",\"continue\",\"do\",\"for\",\"while\",\"if\",\"else\",\"in\",\"out\",\"inout\",\"float\",\"int\",\"void\",\"bool\",\"true\",\"false\",\"discard\",\"return\",\"mat2\",\"mat3\",\"mat4\",\"vec2\",\"vec3\",\"vec4\",\"ivec2\",\"ivec3\",\"ivec4\",\"bvec2\",\"bvec3\",\"bvec4\",\"sampler1D\",\"sampler2D\",\"sampler3D\",\"samplerCube\",\"sampler1DShadow\",\"sampler2DShadow\",\"struct\",\"asm\",\"class\",\"union\",\"enum\",\"typedef\",\"template\",\"this\",\"packed\",\"goto\",\"switch\",\"default\",\"inline\",\"noinline\",\"volatile\",\"public\",\"static\",\"extern\",\"external\",\"interface\",\"long\",\"short\",\"double\",\"half\",\"fixed\",\"unsigned\",\"input\",\"output\",\"hvec2\",\"hvec3\",\"hvec4\",\"dvec2\",\"dvec3\",\"dvec4\",\"fvec2\",\"fvec3\",\"fvec4\",\"sampler2DRect\",\"sampler3DRect\",\"sampler2DRectShadow\",\"sizeof\",\"cast\",\"namespace\",\"using\"]},{}],407:[function(t,e,r){e.exports=[\"<<=\",\">>=\",\"++\",\"--\",\"<<\",\">>\",\"<=\",\">=\",\"==\",\"!=\",\"&&\",\"||\",\"+=\",\"-=\",\"*=\",\"/=\",\"%=\",\"&=\",\"^^\",\"^=\",\"|=\",\"(\",\")\",\"[\",\"]\",\".\",\"!\",\"~\",\"*\",\"/\",\"%\",\"+\",\"-\",\"<\",\">\",\"&\",\"^\",\"|\",\"?\",\":\",\"=\",\",\",\";\",\"{\",\"}\"]},{}],408:[function(t,e,r){var n=t(\"./index\");e.exports=function(t,e){var r=n(e),i=[];return i=(i=i.concat(r(t))).concat(r(null))}},{\"./index\":402}],409:[function(t,e,r){e.exports=function(t){\"string\"==typeof t&&(t=[t]);for(var e=[].slice.call(arguments,1),r=[],n=0;n<t.length-1;n++)r.push(t[n],e[n]||\"\");return r.push(t[n]),r.join(\"\")}},{}],410:[function(t,e,r){(function(r){\"use strict\";var n,i=t(\"is-browser\");n=\"function\"==typeof r.matchMedia?!r.matchMedia(\"(hover: none)\").matches:i,e.exports=n}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"is-browser\":417}],411:[function(t,e,r){\"use strict\";var n=t(\"is-browser\");e.exports=n&&function(){var t=!1;try{var e=Object.defineProperty({},\"passive\",{get:function(){t=!0}});window.addEventListener(\"test\",null,e),window.removeEventListener(\"test\",null,e)}catch(e){t=!1}return t}()},{\"is-browser\":417}],412:[function(t,e,r){r.read=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?i-1:0,f=r?-1:1,p=t[e+h];for(h+=f,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+h],h+=f,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},r.write=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,h=u>>1,f=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,i),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g}},{}],413:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(0===r)throw new Error(\"Must have at least d+1 points\");var i=t[0].length;if(r<=i)throw new Error(\"Must input at least d+1 points\");var o=t.slice(0,i+1),s=n.apply(void 0,o);if(0===s)throw new Error(\"Input not in general position\");for(var l=new Array(i+1),u=0;u<=i;++u)l[u]=u;s<0&&(l[0]=1,l[1]=0);for(var h=new a(l,new Array(i+1),!1),f=h.adjacent,p=new Array(i+2),u=0;u<=i;++u){for(var d=l.slice(),g=0;g<=i;++g)g===u&&(d[g]=-1);var v=d[0];d[0]=d[1],d[1]=v;var m=new a(d,new Array(i+1),!0);f[u]=m,p[u]=m}p[i+1]=h;for(var u=0;u<=i;++u)for(var d=f[u].vertices,y=f[u].adjacent,g=0;g<=i;++g){var x=d[g];if(x<0)y[g]=h;else for(var b=0;b<=i;++b)f[b].vertices.indexOf(x)<0&&(y[g]=f[b])}for(var _=new c(i,o,p),w=!!e,u=i+1;u<r;++u)_.insert(t[u],w);return _.boundary()};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\").compareCells;function a(t,e,r){this.vertices=t,this.adjacent=e,this.boundary=r,this.lastVisited=-1}function o(t,e,r){this.vertices=t,this.cell=e,this.index=r}function s(t,e){return i(t.vertices,e.vertices)}a.prototype.flip=function(){var t=this.vertices[0];this.vertices[0]=this.vertices[1],this.vertices[1]=t;var e=this.adjacent[0];this.adjacent[0]=this.adjacent[1],this.adjacent[1]=e};var l=[];function c(t,e,r){this.dimension=t,this.vertices=e,this.simplices=r,this.interior=r.filter(function(t){return!t.boundary}),this.tuple=new Array(t+1);for(var i=0;i<=t;++i)this.tuple[i]=this.vertices[i];var a=l[t];a||(a=l[t]=function(t){for(var e=[\"function orient(){var tuple=this.tuple;return test(\"],r=0;r<=t;++r)r>0&&e.push(\",\"),e.push(\"tuple[\",r,\"]\");e.push(\")}return orient\");var i=new Function(\"test\",e.join(\"\")),a=n[t+1];return a||(a=n),i(a)}(t)),this.orient=a}var u=c.prototype;u.handleBoundaryDegeneracy=function(t,e){var r=this.dimension,n=this.vertices.length-1,i=this.tuple,a=this.vertices,o=[t];for(t.lastVisited=-n;o.length>0;){(t=o.pop()).vertices;for(var s=t.adjacent,l=0;l<=r;++l){var c=s[l];if(c.boundary&&!(c.lastVisited<=-n)){for(var u=c.vertices,h=0;h<=r;++h){var f=u[h];i[h]=f<0?e:a[f]}var p=this.orient();if(p>0)return c;c.lastVisited=-n,0===p&&o.push(c)}}}return null},u.walk=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,a=this.tuple,o=e?this.interior.length*Math.random()|0:this.interior.length-1,s=this.interior[o];t:for(;!s.boundary;){for(var l=s.vertices,c=s.adjacent,u=0;u<=n;++u)a[u]=i[l[u]];s.lastVisited=r;for(u=0;u<=n;++u){var h=c[u];if(!(h.lastVisited>=r)){var f=a[u];a[u]=t;var p=this.orient();if(a[u]=f,p<0){s=h;continue t}h.boundary?h.lastVisited=-r:h.lastVisited=r}}return}return s},u.addPeaks=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,l=this.tuple,c=this.interior,u=this.simplices,h=[e];e.lastVisited=r,e.vertices[e.vertices.indexOf(-1)]=r,e.boundary=!1,c.push(e);for(var f=[];h.length>0;){var p=(e=h.pop()).vertices,d=e.adjacent,g=p.indexOf(r);if(!(g<0))for(var v=0;v<=n;++v)if(v!==g){var m=d[v];if(m.boundary&&!(m.lastVisited>=r)){var y=m.vertices;if(m.lastVisited!==-r){for(var x=0,b=0;b<=n;++b)y[b]<0?(x=b,l[b]=t):l[b]=i[y[b]];if(this.orient()>0){y[x]=r,m.boundary=!1,c.push(m),h.push(m),m.lastVisited=r;continue}m.lastVisited=-r}var _=m.adjacent,w=p.slice(),k=d.slice(),T=new a(w,k,!0);u.push(T);var A=_.indexOf(e);if(!(A<0)){_[A]=T,k[g]=m,w[v]=-1,k[v]=e,d[v]=T,T.flip();for(b=0;b<=n;++b){var M=w[b];if(!(M<0||M===r)){for(var S=new Array(n-1),E=0,C=0;C<=n;++C){var L=w[C];L<0||C===b||(S[E++]=L)}f.push(new o(S,T,b))}}}}}}f.sort(s);for(v=0;v+1<f.length;v+=2){var P=f[v],O=f[v+1],z=P.index,I=O.index;z<0||I<0||(P.cell.adjacent[P.index]=O.cell,O.cell.adjacent[O.index]=P.cell)}},u.insert=function(t,e){var r=this.vertices;r.push(t);var n=this.walk(t,e);if(n){for(var i=this.dimension,a=this.tuple,o=0;o<=i;++o){var s=n.vertices[o];a[o]=s<0?t:r[s]}var l=this.orient(a);l<0||(0!==l||(n=this.handleBoundaryDegeneracy(n,t)))&&this.addPeaks(t,n)}},u.boundary=function(){for(var t=this.dimension,e=[],r=this.simplices,n=r.length,i=0;i<n;++i){var a=r[i];if(a.boundary){for(var o=new Array(t),s=a.vertices,l=0,c=0,u=0;u<=t;++u)s[u]>=0?o[l++]=s[u]:c=1&u;if(c===(1&t)){var h=o[0];o[0]=o[1],o[1]=h}e.push(o)}}return e}},{\"robust-orientation\":510,\"simplicial-complex\":520}],414:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=0,a=1;function o(t,e,r,n,i){this.mid=t,this.left=e,this.right=r,this.leftPoints=n,this.rightPoints=i,this.count=(e?e.count:0)+(r?r.count:0)+n.length}e.exports=function(t){if(!t||0===t.length)return new x(null);return new x(y(t))};var s=o.prototype;function l(t,e){t.mid=e.mid,t.left=e.left,t.right=e.right,t.leftPoints=e.leftPoints,t.rightPoints=e.rightPoints,t.count=e.count}function c(t,e){var r=y(e);t.mid=r.mid,t.left=r.left,t.right=r.right,t.leftPoints=r.leftPoints,t.rightPoints=r.rightPoints,t.count=r.count}function u(t,e){var r=t.intervals([]);r.push(e),c(t,r)}function h(t,e){var r=t.intervals([]),n=r.indexOf(e);return n<0?i:(r.splice(n,1),c(t,r),a)}function f(t,e,r){for(var n=0;n<t.length&&t[n][0]<=e;++n){var i=r(t[n]);if(i)return i}}function p(t,e,r){for(var n=t.length-1;n>=0&&t[n][1]>=e;--n){var i=r(t[n]);if(i)return i}}function d(t,e){for(var r=0;r<t.length;++r){var n=e(t[r]);if(n)return n}}function g(t,e){return t-e}function v(t,e){var r=t[0]-e[0];return r||t[1]-e[1]}function m(t,e){var r=t[1]-e[1];return r||t[0]-e[0]}function y(t){if(0===t.length)return null;for(var e=[],r=0;r<t.length;++r)e.push(t[r][0],t[r][1]);e.sort(g);var n=e[e.length>>1],i=[],a=[],s=[];for(r=0;r<t.length;++r){var l=t[r];l[1]<n?i.push(l):n<l[0]?a.push(l):s.push(l)}var c=s,u=s.slice();return c.sort(v),u.sort(m),new o(n,y(i),y(a),c,u)}function x(t){this.root=t}s.intervals=function(t){return t.push.apply(t,this.leftPoints),this.left&&this.left.intervals(t),this.right&&this.right.intervals(t),t},s.insert=function(t){var e=this.count-this.leftPoints.length;if(this.count+=1,t[1]<this.mid)this.left?4*(this.left.count+1)>3*(e+1)?u(this,t):this.left.insert(t):this.left=y([t]);else if(t[0]>this.mid)this.right?4*(this.right.count+1)>3*(e+1)?u(this,t):this.right.insert(t):this.right=y([t]);else{var r=n.ge(this.leftPoints,t,v),i=n.ge(this.rightPoints,t,m);this.leftPoints.splice(r,0,t),this.rightPoints.splice(i,0,t)}},s.remove=function(t){var e=this.count-this.leftPoints;if(t[1]<this.mid)return this.left?4*(this.right?this.right.count:0)>3*(e-1)?h(this,t):2===(c=this.left.remove(t))?(this.left=null,this.count-=1,a):(c===a&&(this.count-=1),c):i;if(t[0]>this.mid)return this.right?4*(this.left?this.left.count:0)>3*(e-1)?h(this,t):2===(c=this.right.remove(t))?(this.right=null,this.count-=1,a):(c===a&&(this.count-=1),c):i;if(1===this.count)return this.leftPoints[0]===t?2:i;if(1===this.leftPoints.length&&this.leftPoints[0]===t){if(this.left&&this.right){for(var r=this,o=this.left;o.right;)r=o,o=o.right;if(r===this)o.right=this.right;else{var s=this.left,c=this.right;r.count-=o.count,r.right=o.left,o.left=s,o.right=c}l(this,o),this.count=(this.left?this.left.count:0)+(this.right?this.right.count:0)+this.leftPoints.length}else this.left?l(this,this.left):l(this,this.right);return a}for(s=n.ge(this.leftPoints,t,v);s<this.leftPoints.length&&this.leftPoints[s][0]===t[0];++s)if(this.leftPoints[s]===t){this.count-=1,this.leftPoints.splice(s,1);for(c=n.ge(this.rightPoints,t,m);c<this.rightPoints.length&&this.rightPoints[c][1]===t[1];++c)if(this.rightPoints[c]===t)return this.rightPoints.splice(c,1),a}return i},s.queryPoint=function(t,e){if(t<this.mid){if(this.left)if(r=this.left.queryPoint(t,e))return r;return f(this.leftPoints,t,e)}if(t>this.mid){var r;if(this.right)if(r=this.right.queryPoint(t,e))return r;return p(this.rightPoints,t,e)}return d(this.leftPoints,e)},s.queryInterval=function(t,e,r){var n;if(t<this.mid&&this.left&&(n=this.left.queryInterval(t,e,r)))return n;if(e>this.mid&&this.right&&(n=this.right.queryInterval(t,e,r)))return n;return e<this.mid?f(this.leftPoints,e,r):t>this.mid?p(this.rightPoints,t,r):d(this.leftPoints,r)};var b=x.prototype;b.insert=function(t){this.root?this.root.insert(t):this.root=new o(t[0],null,null,[t],[t])},b.remove=function(t){if(this.root){var e=this.root.remove(t);return 2===e&&(this.root=null),e!==i}return!1},b.queryPoint=function(t,e){if(this.root)return this.root.queryPoint(t,e)},b.queryInterval=function(t,e,r){if(t<=e&&this.root)return this.root.queryInterval(t,e,r)},Object.defineProperty(b,\"count\",{get:function(){return this.root?this.root.count:0}}),Object.defineProperty(b,\"intervals\",{get:function(){return this.root?this.root.intervals([]):[]}})},{\"binary-search-bounds\":91}],415:[function(t,e,r){\"use strict\";e.exports=function(t,e){e=e||new Array(t.length);for(var r=0;r<t.length;++r)e[t[r]]=r;return e}},{}],416:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=r;return e}},{}],417:[function(t,e,r){e.exports=!0},{}],418:[function(t,e,r){function n(t){return!!t.constructor&&\"function\"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}e.exports=function(t){return null!=t&&(n(t)||function(t){return\"function\"==typeof t.readFloatLE&&\"function\"==typeof t.slice&&n(t.slice(0,0))}(t)||!!t._isBuffer)}},{}],419:[function(t,e,r){\"use strict\";e.exports=\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion))},{}],420:[function(t,e,r){\"use strict\";e.exports=a,e.exports.isMobile=a;var n=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i,i=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino|android|ipad|playbook|silk/i;function a(t){t||(t={});var e=t.ua;return e||\"undefined\"==typeof navigator||(e=navigator.userAgent),e&&e.headers&&\"string\"==typeof e.headers[\"user-agent\"]&&(e=e.headers[\"user-agent\"]),\"string\"==typeof e&&(t.tablet?i.test(e):n.test(e))}},{}],421:[function(t,e,r){\"use strict\";e.exports=function(t){var e=typeof t;return null!==t&&(\"object\"===e||\"function\"===e)}},{}],422:[function(t,e,r){\"use strict\";var n=Object.prototype.toString;e.exports=function(t){var e;return\"[object Object]\"===n.call(t)&&(null===(e=Object.getPrototypeOf(t))||e===Object.getPrototypeOf({}))}},{}],423:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=t.length,n=0;n<r;n++)if(((e=t.charCodeAt(n))<9||e>13)&&32!==e&&133!==e&&160!==e&&5760!==e&&6158!==e&&(e<8192||e>8205)&&8232!==e&&8233!==e&&8239!==e&&8287!==e&&8288!==e&&12288!==e&&65279!==e)return!1;return!0}},{}],424:[function(t,e,r){\"use strict\";e.exports=function(t){return\"string\"==typeof t&&(t=t.trim(),!!(/^[mzlhvcsqta]\\s*[-+.0-9][^mlhvzcsqta]+/i.test(t)&&/[\\dz]$/i.test(t)&&t.length>4))}},{}],425:[function(t,e,r){e.exports=function(t,e,r){return t*(1-r)+e*r}},{}],426:[function(t,e,r){var n,i;n=this,i=function(){\"use strict\";var t,e,r;function n(n,i){if(t)if(e){var a=\"var sharedChunk = {}; (\"+t+\")(sharedChunk); (\"+e+\")(sharedChunk);\",o={};t(o),(r=i(o)).workerUrl=window.URL.createObjectURL(new Blob([a],{type:\"text/javascript\"}))}else e=i;else t=i}return n(0,function(t){function e(t,e){return t(e={exports:{}},e.exports),e.exports}var r=n;function n(t,e,r,n){this.cx=3*t,this.bx=3*(r-t)-this.cx,this.ax=1-this.cx-this.bx,this.cy=3*e,this.by=3*(n-e)-this.cy,this.ay=1-this.cy-this.by,this.p1x=t,this.p1y=n,this.p2x=r,this.p2y=n}n.prototype.sampleCurveX=function(t){return((this.ax*t+this.bx)*t+this.cx)*t},n.prototype.sampleCurveY=function(t){return((this.ay*t+this.by)*t+this.cy)*t},n.prototype.sampleCurveDerivativeX=function(t){return(3*this.ax*t+2*this.bx)*t+this.cx},n.prototype.solveCurveX=function(t,e){var r,n,i,a,o;for(void 0===e&&(e=1e-6),i=t,o=0;o<8;o++){if(a=this.sampleCurveX(i)-t,Math.abs(a)<e)return i;var s=this.sampleCurveDerivativeX(i);if(Math.abs(s)<1e-6)break;i-=a/s}if((i=t)<(r=0))return r;if(i>(n=1))return n;for(;r<n;){if(a=this.sampleCurveX(i),Math.abs(a-t)<e)return i;t>a?r=i:n=i,i=.5*(n-r)+r}return i},n.prototype.solve=function(t,e){return this.sampleCurveY(this.solveCurveX(t,e))};var i=a;function a(t,e){this.x=t,this.y=e}function o(t,e){if(Array.isArray(t)){if(!Array.isArray(e)||t.length!==e.length)return!1;for(var r=0;r<t.length;r++)if(!o(t[r],e[r]))return!1;return!0}if(\"object\"==typeof t&&null!==t&&null!==e){if(\"object\"!=typeof e)return!1;if(Object.keys(t).length!==Object.keys(e).length)return!1;for(var n in t)if(!o(t[n],e[n]))return!1;return!0}return t===e}function s(t,e,n,i){var a=new r(t,e,n,i);return function(t){return a.solve(t)}}a.prototype={clone:function(){return new a(this.x,this.y)},add:function(t){return this.clone()._add(t)},sub:function(t){return this.clone()._sub(t)},multByPoint:function(t){return this.clone()._multByPoint(t)},divByPoint:function(t){return this.clone()._divByPoint(t)},mult:function(t){return this.clone()._mult(t)},div:function(t){return this.clone()._div(t)},rotate:function(t){return this.clone()._rotate(t)},rotateAround:function(t,e){return this.clone()._rotateAround(t,e)},matMult:function(t){return this.clone()._matMult(t)},unit:function(){return this.clone()._unit()},perp:function(){return this.clone()._perp()},round:function(){return this.clone()._round()},mag:function(){return Math.sqrt(this.x*this.x+this.y*this.y)},equals:function(t){return this.x===t.x&&this.y===t.y},dist:function(t){return Math.sqrt(this.distSqr(t))},distSqr:function(t){var e=t.x-this.x,r=t.y-this.y;return e*e+r*r},angle:function(){return Math.atan2(this.y,this.x)},angleTo:function(t){return Math.atan2(this.y-t.y,this.x-t.x)},angleWith:function(t){return this.angleWithSep(t.x,t.y)},angleWithSep:function(t,e){return Math.atan2(this.x*e-this.y*t,this.x*t+this.y*e)},_matMult:function(t){var e=t[0]*this.x+t[1]*this.y,r=t[2]*this.x+t[3]*this.y;return this.x=e,this.y=r,this},_add:function(t){return this.x+=t.x,this.y+=t.y,this},_sub:function(t){return this.x-=t.x,this.y-=t.y,this},_mult:function(t){return this.x*=t,this.y*=t,this},_div:function(t){return this.x/=t,this.y/=t,this},_multByPoint:function(t){return this.x*=t.x,this.y*=t.y,this},_divByPoint:function(t){return this.x/=t.x,this.y/=t.y,this},_unit:function(){return this._div(this.mag()),this},_perp:function(){var t=this.y;return this.y=this.x,this.x=-t,this},_rotate:function(t){var e=Math.cos(t),r=Math.sin(t),n=e*this.x-r*this.y,i=r*this.x+e*this.y;return this.x=n,this.y=i,this},_rotateAround:function(t,e){var r=Math.cos(t),n=Math.sin(t),i=e.x+r*(this.x-e.x)-n*(this.y-e.y),a=e.y+n*(this.x-e.x)+r*(this.y-e.y);return this.x=i,this.y=a,this},_round:function(){return this.x=Math.round(this.x),this.y=Math.round(this.y),this}},a.convert=function(t){return t instanceof a?t:Array.isArray(t)?new a(t[0],t[1]):t};var l=s(.25,.1,.25,1);function c(t,e,r){return Math.min(r,Math.max(e,t))}function u(t,e,r){var n=r-e,i=((t-e)%n+n)%n+e;return i===e?r:i}function h(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}var f=1;function p(){return f++}function d(){return function t(e){return e?(e^16*Math.random()>>e/4).toString(16):([1e7]+-[1e3]+-4e3+-8e3+-1e11).replace(/[018]/g,t)}()}function g(t){return!!t&&/^[0-9a-f]{8}-[0-9a-f]{4}-[4][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$/i.test(t)}function v(t,e){t.forEach(function(t){e[t]&&(e[t]=e[t].bind(e))})}function m(t,e){return-1!==t.indexOf(e,t.length-e.length)}function y(t,e,r){var n={};for(var i in t)n[i]=e.call(r||this,t[i],i,t);return n}function x(t,e,r){var n={};for(var i in t)e.call(r||this,t[i],i,t)&&(n[i]=t[i]);return n}function b(t){return Array.isArray(t)?t.map(b):\"object\"==typeof t&&t?y(t,b):t}var _={};function w(t){_[t]||(\"undefined\"!=typeof console&&console.warn(t),_[t]=!0)}function k(t,e,r){return(r.y-t.y)*(e.x-t.x)>(e.y-t.y)*(r.x-t.x)}function T(t){for(var e=0,r=0,n=t.length,i=n-1,a=void 0,o=void 0;r<n;i=r++)a=t[r],e+=((o=t[i]).x-a.x)*(a.y+o.y);return e}function A(t){var e={};if(t.replace(/(?:^|(?:\\s*\\,\\s*))([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)(?:\\=(?:([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)|(?:\\\"((?:[^\"\\\\]|\\\\.)*)\\\")))?/g,function(t,r,n,i){var a=n||i;return e[r]=!a||a.toLowerCase(),\"\"}),e[\"max-age\"]){var r=parseInt(e[\"max-age\"],10);isNaN(r)?delete e[\"max-age\"]:e[\"max-age\"]=r}return e}function M(t){try{var e=self[t];return e.setItem(\"_mapbox_test_\",1),e.removeItem(\"_mapbox_test_\"),!0}catch(t){return!1}}var S,E,C,L=self.performance&&self.performance.now?self.performance.now.bind(self.performance):Date.now.bind(Date),P=self.requestAnimationFrame||self.mozRequestAnimationFrame||self.webkitRequestAnimationFrame||self.msRequestAnimationFrame,O=self.cancelAnimationFrame||self.mozCancelAnimationFrame||self.webkitCancelAnimationFrame||self.msCancelAnimationFrame,z={now:L,frame:function(t){var e=P(t);return{cancel:function(){return O(e)}}},getImageData:function(t){var e=self.document.createElement(\"canvas\"),r=e.getContext(\"2d\");if(!r)throw new Error(\"failed to create canvas 2d context\");return e.width=t.width,e.height=t.height,r.drawImage(t,0,0,t.width,t.height),r.getImageData(0,0,t.width,t.height)},resolveURL:function(t){return S||(S=self.document.createElement(\"a\")),S.href=t,S.href},hardwareConcurrency:self.navigator.hardwareConcurrency||4,get devicePixelRatio(){return self.devicePixelRatio}},I={API_URL:\"https://api.mapbox.com\",get EVENTS_URL(){return this.API_URL?0===this.API_URL.indexOf(\"https://api.mapbox.cn\")?\"https://events.mapbox.cn/events/v2\":0===this.API_URL.indexOf(\"https://api.mapbox.com\")?\"https://events.mapbox.com/events/v2\":null:null},FEEDBACK_URL:\"https://apps.mapbox.com/feedback\",REQUIRE_ACCESS_TOKEN:!0,ACCESS_TOKEN:null,MAX_PARALLEL_IMAGE_REQUESTS:16},D={supported:!1,testSupport:function(t){!R&&C&&(F?B(t):E=t)}},R=!1,F=!1;function B(t){var e=t.createTexture();t.bindTexture(t.TEXTURE_2D,e);try{if(t.texImage2D(t.TEXTURE_2D,0,t.RGBA,t.RGBA,t.UNSIGNED_BYTE,C),t.isContextLost())return;D.supported=!0}catch(t){}t.deleteTexture(e),R=!0}self.document&&((C=self.document.createElement(\"img\")).onload=function(){E&&B(E),E=null,F=!0},C.onerror=function(){R=!0,E=null},C.src=\"data:image/webp;base64,UklGRh4AAABXRUJQVlA4TBEAAAAvAQAAAAfQ//73v/+BiOh/AAA=\");var N=\"01\",j=function(t){this._transformRequestFn=t,this._createSkuToken()};j.prototype._createSkuToken=function(){var t=function(){for(var t=\"\",e=0;e<10;e++)t+=\"0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ\"[Math.floor(62*Math.random())];return{token:[\"1\",N,t].join(\"\"),tokenExpiresAt:Date.now()+432e5}}();this._skuToken=t.token,this._skuTokenExpiresAt=t.tokenExpiresAt},j.prototype._isSkuTokenExpired=function(){return Date.now()>this._skuTokenExpiresAt},j.prototype.transformRequest=function(t,e){return this._transformRequestFn&&this._transformRequestFn(t,e)||{url:t}},j.prototype.normalizeStyleURL=function(t,e){return Y(t,e)},j.prototype.normalizeGlyphsURL=function(t,e){return W(t,e)},j.prototype.normalizeSourceURL=function(t,e){return X(t,e)},j.prototype.normalizeSpriteURL=function(t,e,r,n){return Z(t,e,r,n)},j.prototype.normalizeTileURL=function(t,e,r){return this._isSkuTokenExpired()&&this._createSkuToken(),K(t,e,r,this._skuToken)},j.prototype.canonicalizeTileURL=function(t){return Q(t)},j.prototype.canonicalizeTileset=function(t,e){return tt(t,e)};var U=\"See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\";function V(t,e){var r=rt(I.API_URL);if(t.protocol=r.protocol,t.authority=r.authority,\"/\"!==r.path&&(t.path=\"\"+r.path+t.path),!I.REQUIRE_ACCESS_TOKEN)return nt(t);if(!(e=e||I.ACCESS_TOKEN))throw new Error(\"An API access token is required to use Mapbox GL. \"+U);if(\"s\"===e[0])throw new Error(\"Use a public access token (pk.*) with Mapbox GL, not a secret access token (sk.*). \"+U);return t.params.push(\"access_token=\"+e),nt(t)}function q(t){return 0===t.indexOf(\"mapbox:\")}var H=/^((https?:)?\\/\\/)?([^\\/]+\\.)?mapbox\\.c(n|om)(\\/|\\?|$)/i;function G(t){return H.test(t)}var Y=function(t,e){if(!q(t))return t;var r=rt(t);return r.path=\"/styles/v1\"+r.path,V(r,e)},W=function(t,e){if(!q(t))return t;var r=rt(t);return r.path=\"/fonts/v1\"+r.path,V(r,e)},X=function(t,e){if(!q(t))return t;var r=rt(t);return r.path=\"/v4/\"+r.authority+\".json\",r.params.push(\"secure\"),V(r,e)},Z=function(t,e,r,n){var i=rt(t);return q(t)?(i.path=\"/styles/v1\"+i.path+\"/sprite\"+e+r,V(i,n)):(i.path+=\"\"+e+r,nt(i))},J=/(\\.(png|jpg)\\d*)(?=$)/,K=function(t,e,r,n){if(!e||!q(e))return t;var i=rt(t),a=z.devicePixelRatio>=2||512===r?\"@2x\":\"\",o=D.supported?\".webp\":\"$1\";return i.path=i.path.replace(J,\"\"+a+o),i.path=\"/v4\"+i.path,I.REQUIRE_ACCESS_TOKEN&&I.ACCESS_TOKEN&&n&&i.params.push(\"sku=\"+n),V(i)},$=/\\.[\\w]+$/,Q=function(t){var e=rt(t);if(!e.path.match(/(^\\/v4\\/)/)||!e.path.match($))return t;var r=\"mapbox://tiles/\";r+=e.path.replace(\"/v4/\",\"\");var n=e.params.filter(function(t){return!t.match(/^access_token=/)});return n.length&&(r+=\"?\"+n.join(\"&\")),r},tt=function(t,e){if(!q(e))return t.tiles||[];for(var r=[],n=0,i=t.tiles;n<i.length;n+=1){var a=i[n],o=Q(a);r.push(o)}return r},et=/^(\\w+):\\/\\/([^\\/?]*)(\\/[^?]+)?\\??(.+)?/;function rt(t){var e=t.match(et);if(!e)throw new Error(\"Unable to parse URL object\");return{protocol:e[1],authority:e[2],path:e[3]||\"/\",params:e[4]?e[4].split(\"&\"):[]}}function nt(t){var e=t.params.length?\"?\"+t.params.join(\"&\"):\"\";return t.protocol+\"://\"+t.authority+t.path+e}function it(t){if(!t)return null;var e,r=t.split(\".\");if(!r||3!==r.length)return null;try{return JSON.parse((e=r[1],decodeURIComponent(self.atob(e).split(\"\").map(function(t){return\"%\"+(\"00\"+t.charCodeAt(0).toString(16)).slice(-2)}).join(\"\"))))}catch(t){return null}}var at=function(t){this.type=t,this.anonId=null,this.eventData={},this.queue=[],this.pendingRequest=null};at.prototype.getStorageKey=function(t){var e,r=it(I.ACCESS_TOKEN),n=\"\";return r&&r.u?(e=r.u,n=self.btoa(encodeURIComponent(e).replace(/%([0-9A-F]{2})/g,function(t,e){return String.fromCharCode(Number(\"0x\"+e))}))):n=I.ACCESS_TOKEN||\"\",t?\"mapbox.eventData.\"+t+\":\"+n:\"mapbox.eventData:\"+n},at.prototype.fetchEventData=function(){var t=M(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{var n=self.localStorage.getItem(e);n&&(this.eventData=JSON.parse(n));var i=self.localStorage.getItem(r);i&&(this.anonId=i)}catch(t){w(\"Unable to read from LocalStorage\")}},at.prototype.saveEventData=function(){var t=M(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{self.localStorage.setItem(r,this.anonId),Object.keys(this.eventData).length>=1&&self.localStorage.setItem(e,JSON.stringify(this.eventData))}catch(t){w(\"Unable to write to LocalStorage\")}},at.prototype.processRequests=function(){},at.prototype.postEvent=function(t,e,r){var n=this;if(I.EVENTS_URL){var i=rt(I.EVENTS_URL);i.params.push(\"access_token=\"+(I.ACCESS_TOKEN||\"\"));var a={event:this.type,created:new Date(t).toISOString(),sdkIdentifier:\"mapbox-gl-js\",sdkVersion:\"1.1.1\",skuId:N,userId:this.anonId},o=e?h(a,e):a,s={url:nt(i),headers:{\"Content-Type\":\"text/plain\"},body:JSON.stringify([o])};this.pendingRequest=St(s,function(t){n.pendingRequest=null,r(t),n.saveEventData(),n.processRequests()})}},at.prototype.queueRequest=function(t){this.queue.push(t),this.processRequests()};var ot,st=function(t){function e(){t.call(this,\"map.load\"),this.success={},this.skuToken=\"\"}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.postMapLoadEvent=function(t,e,r){this.skuToken=r,I.EVENTS_URL&&I.ACCESS_TOKEN&&Array.isArray(t)&&t.some(function(t){return q(t)||G(t)})&&this.queueRequest({id:e,timestamp:Date.now()})},e.prototype.processRequests=function(){var t=this;if(!this.pendingRequest&&0!==this.queue.length){var e=this.queue.shift(),r=e.id,n=e.timestamp;r&&this.success[r]||(this.anonId||this.fetchEventData(),g(this.anonId)||(this.anonId=d()),this.postEvent(n,{skuToken:this.skuToken},function(e){e||r&&(t.success[r]=!0)}))}},e}(at),lt=new(function(t){function e(){t.call(this,\"appUserTurnstile\")}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.postTurnstileEvent=function(t){I.EVENTS_URL&&I.ACCESS_TOKEN&&Array.isArray(t)&&t.some(function(t){return q(t)||G(t)})&&this.queueRequest(Date.now())},e.prototype.processRequests=function(){var t=this;if(!this.pendingRequest&&0!==this.queue.length){this.anonId&&this.eventData.lastSuccess&&this.eventData.tokenU||this.fetchEventData();var e=it(I.ACCESS_TOKEN),r=e?e.u:I.ACCESS_TOKEN,n=r!==this.eventData.tokenU;g(this.anonId)||(this.anonId=d(),n=!0);var i=this.queue.shift();if(this.eventData.lastSuccess){var a=new Date(this.eventData.lastSuccess),o=new Date(i),s=(i-this.eventData.lastSuccess)/864e5;n=n||s>=1||s<-1||a.getDate()!==o.getDate()}else n=!0;if(!n)return this.processRequests();this.postEvent(i,{\"enabled.telemetry\":!1},function(e){e||(t.eventData.lastSuccess=i,t.eventData.tokenU=r)})}},e}(at)),ct=lt.postTurnstileEvent.bind(lt),ut=new st,ht=ut.postMapLoadEvent.bind(ut),ft=\"mapbox-tiles\",pt=500,dt=50,gt=42e4;function vt(t){var e=t.indexOf(\"?\");return e<0?t:t.slice(0,e)}var mt=1/0,yt={Unknown:\"Unknown\",Style:\"Style\",Source:\"Source\",Tile:\"Tile\",Glyphs:\"Glyphs\",SpriteImage:\"SpriteImage\",SpriteJSON:\"SpriteJSON\",Image:\"Image\"};\"function\"==typeof Object.freeze&&Object.freeze(yt);var xt=function(t){function e(e,r,n){401===r&&G(n)&&(e+=\": you may have provided an invalid Mapbox access token. See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\"),t.call(this,e),this.status=r,this.url=n,this.name=this.constructor.name,this.message=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.toString=function(){return this.name+\": \"+this.message+\" (\"+this.status+\"): \"+this.url},e}(Error);function bt(){return\"undefined\"!=typeof WorkerGlobalScope&&\"undefined\"!=typeof self&&self instanceof WorkerGlobalScope}var _t=bt()?function(){return self.worker&&self.worker.referrer}:function(){var t=self.location.origin;if(t&&\"null\"!==t&&\"file://\"!==t)return t+self.location.pathname};function wt(t,e){var r,n=new self.AbortController,i=new self.Request(t.url,{method:t.method||\"GET\",body:t.body,credentials:t.credentials,headers:t.headers,referrer:_t(),signal:n.signal}),a=!1,o=!1,s=(r=i.url).indexOf(\"sku=\")>0&&G(r);\"json\"===t.type&&i.headers.set(\"Accept\",\"application/json\");var l=function(r,n,a){if(!o){if(r&&\"SecurityError\"!==r.message&&w(r),n&&a)return c(n);var l=Date.now();self.fetch(i).then(function(r){if(r.ok){var n=s?r.clone():null;return c(r,n,l)}return e(new xt(r.statusText,r.status,t.url))}).catch(function(t){20!==t.code&&e(new Error(t.message))})}},c=function(r,n,s){(\"arrayBuffer\"===t.type?r.arrayBuffer():\"json\"===t.type?r.json():r.text()).then(function(t){o||(n&&s&&function(t,e,r){if(self.caches){var n={status:e.status,statusText:e.statusText,headers:new self.Headers};e.headers.forEach(function(t,e){return n.headers.set(e,t)});var i=A(e.headers.get(\"Cache-Control\")||\"\");i[\"no-store\"]||(i[\"max-age\"]&&n.headers.set(\"Expires\",new Date(r+1e3*i[\"max-age\"]).toUTCString()),new Date(n.headers.get(\"Expires\")).getTime()-r<gt||function(t,e){if(void 0===ot)try{new Response(new ReadableStream),ot=!0}catch(t){ot=!1}ot?e(t.body):t.blob().then(e)}(e,function(e){var r=new self.Response(e,n);self.caches.open(ft).then(function(e){return e.put(vt(t.url),r)})}))}}(i,n,s),a=!0,e(null,t,r.headers.get(\"Cache-Control\"),r.headers.get(\"Expires\")))}).catch(function(t){return e(new Error(t.message))})};return s?function(t,e){if(!self.caches)return e(null);var r=vt(t.url);self.caches.open(ft).catch(e).then(function(t){t.match(r).catch(e).then(function(n){var i=function(t){if(!t)return!1;var e=new Date(t.headers.get(\"Expires\")),r=A(t.headers.get(\"Cache-Control\")||\"\");return e>Date.now()&&!r[\"no-cache\"]}(n);t.delete(r),i&&t.put(r,n.clone()),e(null,n,i)})})}(i,l):l(null,null),{cancel:function(){o=!0,a||n.abort()}}}var kt,Tt,At=function(t,e){if(!/^file:/.test(t.url)){if(self.fetch&&self.Request&&self.AbortController&&self.Request.prototype.hasOwnProperty(\"signal\"))return wt(t,e);if(bt()&&self.worker&&self.worker.actor)return self.worker.actor.send(\"getResource\",t,e)}return function(t,e){var r=new self.XMLHttpRequest;for(var n in r.open(t.method||\"GET\",t.url,!0),\"arrayBuffer\"===t.type&&(r.responseType=\"arraybuffer\"),t.headers)r.setRequestHeader(n,t.headers[n]);return\"json\"===t.type&&r.setRequestHeader(\"Accept\",\"application/json\"),r.withCredentials=\"include\"===t.credentials,r.onerror=function(){e(new Error(r.statusText))},r.onload=function(){if((r.status>=200&&r.status<300||0===r.status)&&null!==r.response){var n=r.response;if(\"json\"===t.type)try{n=JSON.parse(r.response)}catch(t){return e(t)}e(null,n,r.getResponseHeader(\"Cache-Control\"),r.getResponseHeader(\"Expires\"))}else e(new xt(r.statusText,r.status,t.url))},r.send(t.body),{cancel:function(){return r.abort()}}}(t,e)},Mt=function(t,e){return At(h(t,{type:\"arrayBuffer\"}),e)},St=function(t,e){return At(h(t,{method:\"POST\"}),e)};kt=[],Tt=0;var Et=function(t,e){if(Tt>=I.MAX_PARALLEL_IMAGE_REQUESTS){var r={requestParameters:t,callback:e,cancelled:!1,cancel:function(){this.cancelled=!0}};return kt.push(r),r}Tt++;var n=!1,i=function(){if(!n)for(n=!0,Tt--;kt.length&&Tt<I.MAX_PARALLEL_IMAGE_REQUESTS;){var t=kt.shift(),e=t.requestParameters,r=t.callback;t.cancelled||(t.cancel=Et(e,r).cancel)}},a=Mt(t,function(t,r,n,a){if(i(),t)e(t);else if(r){var o=new self.Image,s=self.URL||self.webkitURL;o.onload=function(){e(null,o),s.revokeObjectURL(o.src)},o.onerror=function(){return e(new Error(\"Could not load image. Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.\"))};var l=new self.Blob([new Uint8Array(r)],{type:\"image/png\"});o.cacheControl=n,o.expires=a,o.src=r.byteLength?s.createObjectURL(l):\"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAC0lEQVQYV2NgAAIAAAUAAarVyFEAAAAASUVORK5CYII=\"}});return{cancel:function(){a.cancel(),i()}}};function Ct(t,e,r){r[t]&&-1!==r[t].indexOf(e)||(r[t]=r[t]||[],r[t].push(e))}function Lt(t,e,r){if(r&&r[t]){var n=r[t].indexOf(e);-1!==n&&r[t].splice(n,1)}}var Pt=function(t,e){void 0===e&&(e={}),h(this,e),this.type=t},Ot=function(t){function e(e,r){void 0===r&&(r={}),t.call(this,\"error\",h({error:e},r))}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Pt),zt=function(){};zt.prototype.on=function(t,e){return this._listeners=this._listeners||{},Ct(t,e,this._listeners),this},zt.prototype.off=function(t,e){return Lt(t,e,this._listeners),Lt(t,e,this._oneTimeListeners),this},zt.prototype.once=function(t,e){return this._oneTimeListeners=this._oneTimeListeners||{},Ct(t,e,this._oneTimeListeners),this},zt.prototype.fire=function(t,e){\"string\"==typeof t&&(t=new Pt(t,e||{}));var r=t.type;if(this.listens(r)){t.target=this;for(var n=0,i=this._listeners&&this._listeners[r]?this._listeners[r].slice():[];n<i.length;n+=1)i[n].call(this,t);for(var a=0,o=this._oneTimeListeners&&this._oneTimeListeners[r]?this._oneTimeListeners[r].slice():[];a<o.length;a+=1){var s=o[a];Lt(r,s,this._oneTimeListeners),s.call(this,t)}var l=this._eventedParent;l&&(h(t,\"function\"==typeof this._eventedParentData?this._eventedParentData():this._eventedParentData),l.fire(t))}else t instanceof Ot&&console.error(t.error);return this},zt.prototype.listens=function(t){return this._listeners&&this._listeners[t]&&this._listeners[t].length>0||this._oneTimeListeners&&this._oneTimeListeners[t]&&this._oneTimeListeners[t].length>0||this._eventedParent&&this._eventedParent.listens(t)},zt.prototype.setEventedParent=function(t,e){return this._eventedParent=t,this._eventedParentData=e,this};var It={$version:8,$root:{version:{required:!0,type:\"enum\",values:[8]},name:{type:\"string\"},metadata:{type:\"*\"},center:{type:\"array\",value:\"number\"},zoom:{type:\"number\"},bearing:{type:\"number\",default:0,period:360,units:\"degrees\"},pitch:{type:\"number\",default:0,units:\"degrees\"},light:{type:\"light\"},sources:{required:!0,type:\"sources\"},sprite:{type:\"string\"},glyphs:{type:\"string\"},transition:{type:\"transition\"},layers:{required:!0,type:\"array\",value:\"layer\"}},sources:{\"*\":{type:\"source\"}},source:[\"source_vector\",\"source_raster\",\"source_raster_dem\",\"source_geojson\",\"source_video\",\"source_image\"],source_vector:{type:{required:!0,type:\"enum\",values:{vector:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},attribution:{type:\"string\"},\"*\":{type:\"*\"}},source_raster:{type:{required:!0,type:\"enum\",values:{raster:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},attribution:{type:\"string\"},\"*\":{type:\"*\"}},source_raster_dem:{type:{required:!0,type:\"enum\",values:{\"raster-dem\":{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},attribution:{type:\"string\"},encoding:{type:\"enum\",values:{terrarium:{},mapbox:{}},default:\"mapbox\"},\"*\":{type:\"*\"}},source_geojson:{type:{required:!0,type:\"enum\",values:{geojson:{}}},data:{type:\"*\"},maxzoom:{type:\"number\",default:18},attribution:{type:\"string\"},buffer:{type:\"number\",default:128,maximum:512,minimum:0},tolerance:{type:\"number\",default:.375},cluster:{type:\"boolean\",default:!1},clusterRadius:{type:\"number\",default:50,minimum:0},clusterMaxZoom:{type:\"number\"},clusterProperties:{type:\"*\"},lineMetrics:{type:\"boolean\",default:!1},generateId:{type:\"boolean\",default:!1}},source_video:{type:{required:!0,type:\"enum\",values:{video:{}}},urls:{required:!0,type:\"array\",value:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},source_image:{type:{required:!0,type:\"enum\",values:{image:{}}},url:{required:!0,type:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},layer:{id:{type:\"string\",required:!0},type:{type:\"enum\",values:{fill:{},line:{},symbol:{},circle:{},heatmap:{},\"fill-extrusion\":{},raster:{},hillshade:{},background:{}},required:!0},metadata:{type:\"*\"},source:{type:\"string\"},\"source-layer\":{type:\"string\"},minzoom:{type:\"number\",minimum:0,maximum:24},maxzoom:{type:\"number\",minimum:0,maximum:24},filter:{type:\"filter\"},layout:{type:\"layout\"},paint:{type:\"paint\"}},layout:[\"layout_fill\",\"layout_line\",\"layout_circle\",\"layout_heatmap\",\"layout_fill-extrusion\",\"layout_symbol\",\"layout_raster\",\"layout_hillshade\",\"layout_background\"],layout_background:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_fill:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_circle:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_heatmap:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},\"layout_fill-extrusion\":{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_line:{\"line-cap\":{type:\"enum\",values:{butt:{},round:{},square:{}},default:\"butt\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-join\":{type:\"enum\",values:{bevel:{},round:{},miter:{}},default:\"miter\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"line-miter-limit\":{type:\"number\",default:2,requires:[{\"line-join\":\"miter\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-round-limit\":{type:\"number\",default:1.05,requires:[{\"line-join\":\"round\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_symbol:{\"symbol-placement\":{type:\"enum\",values:{point:{},line:{},\"line-center\":{}},default:\"point\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-spacing\":{type:\"number\",default:250,minimum:1,units:\"pixels\",requires:[{\"symbol-placement\":\"line\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-avoid-edges\":{type:\"boolean\",default:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"symbol-z-order\":{type:\"enum\",values:{auto:{},\"viewport-y\":{},source:{}},default:\"auto\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-optional\":{type:\"boolean\",default:!1,requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-size\":{type:\"number\",default:1,minimum:0,units:\"factor of the original icon size\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-text-fit\":{type:\"enum\",values:{none:{},width:{},height:{},both:{}},default:\"none\",requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-text-fit-padding\":{type:\"array\",value:\"number\",length:4,default:[0,0,0,0],units:\"pixels\",requires:[\"icon-image\",\"text-field\",{\"icon-text-fit\":[\"both\",\"width\",\"height\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-image\":{type:\"string\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-keep-upright\":{type:\"boolean\",default:!1,requires:[\"icon-image\",{\"icon-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-offset\":{type:\"array\",value:\"number\",length:2,default:[0,0],requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-anchor\":{type:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-field\":{type:\"formatted\",default:\"\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-font\":{type:\"array\",value:\"string\",default:[\"Open Sans Regular\",\"Arial Unicode MS Regular\"],requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-size\":{type:\"number\",default:16,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-width\":{type:\"number\",default:10,minimum:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-line-height\":{type:\"number\",default:1.2,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-letter-spacing\":{type:\"number\",default:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-justify\":{type:\"enum\",values:{auto:{},left:{},center:{},right:{}},default:\"center\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-radial-offset\":{type:\"number\",units:\"ems\",default:0,requires:[{\"!\":\"text-offset\"}],\"property-type\":\"data-driven\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]}},\"text-variable-anchor\":{type:\"array\",value:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},requires:[{\"!\":\"text-anchor\"},{\"!\":\"text-offset\"},{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-anchor\":{type:\"enum\",requires:[\"text-field\"],values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-angle\":{type:\"number\",default:45,units:\"degrees\",requires:[\"text-field\",{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-keep-upright\":{type:\"boolean\",default:!0,requires:[\"text-field\",{\"text-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-transform\":{type:\"enum\",values:{none:{},uppercase:{},lowercase:{}},default:\"none\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-offset\":{type:\"array\",value:\"number\",units:\"ems\",length:2,default:[0,0],requires:[\"text-field\",{\"!\":\"text-radial-offset\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-optional\":{type:\"boolean\",default:!1,requires:[\"text-field\",\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_raster:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_hillshade:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},filter:{type:\"array\",value:\"*\"},filter_operator:{type:\"enum\",values:{\"==\":{},\"!=\":{},\">\":{},\">=\":{},\"<\":{},\"<=\":{},in:{},\"!in\":{},all:{},any:{},none:{},has:{},\"!has\":{}}},geometry_type:{type:\"enum\",values:{Point:{},LineString:{},Polygon:{}}},function:{expression:{type:\"expression\"},stops:{type:\"array\",value:\"function_stop\"},base:{type:\"number\",default:1,minimum:0},property:{type:\"string\",default:\"$zoom\"},type:{type:\"enum\",values:{identity:{},exponential:{},interval:{},categorical:{}},default:\"exponential\"},colorSpace:{type:\"enum\",values:{rgb:{},lab:{},hcl:{}},default:\"rgb\"},default:{type:\"*\",required:!1}},function_stop:{type:\"array\",minimum:0,maximum:22,value:[\"number\",\"color\"],length:2},expression:{type:\"array\",value:\"*\",minimum:1},expression_name:{type:\"enum\",values:{let:{group:\"Variable binding\"},var:{group:\"Variable binding\"},literal:{group:\"Types\"},array:{group:\"Types\"},at:{group:\"Lookup\"},case:{group:\"Decision\"},match:{group:\"Decision\"},coalesce:{group:\"Decision\"},step:{group:\"Ramps, scales, curves\"},interpolate:{group:\"Ramps, scales, curves\"},\"interpolate-hcl\":{group:\"Ramps, scales, curves\"},\"interpolate-lab\":{group:\"Ramps, scales, curves\"},ln2:{group:\"Math\"},pi:{group:\"Math\"},e:{group:\"Math\"},typeof:{group:\"Types\"},string:{group:\"Types\"},number:{group:\"Types\"},boolean:{group:\"Types\"},object:{group:\"Types\"},collator:{group:\"Types\"},format:{group:\"Types\"},\"number-format\":{group:\"Types\"},\"to-string\":{group:\"Types\"},\"to-number\":{group:\"Types\"},\"to-boolean\":{group:\"Types\"},\"to-rgba\":{group:\"Color\"},\"to-color\":{group:\"Types\"},rgb:{group:\"Color\"},rgba:{group:\"Color\"},get:{group:\"Lookup\"},has:{group:\"Lookup\"},length:{group:\"Lookup\"},properties:{group:\"Feature data\"},\"feature-state\":{group:\"Feature data\"},\"geometry-type\":{group:\"Feature data\"},id:{group:\"Feature data\"},zoom:{group:\"Zoom\"},\"heatmap-density\":{group:\"Heatmap\"},\"line-progress\":{group:\"Feature data\"},accumulated:{group:\"Feature data\"},\"+\":{group:\"Math\"},\"*\":{group:\"Math\"},\"-\":{group:\"Math\"},\"/\":{group:\"Math\"},\"%\":{group:\"Math\"},\"^\":{group:\"Math\"},sqrt:{group:\"Math\"},log10:{group:\"Math\"},ln:{group:\"Math\"},log2:{group:\"Math\"},sin:{group:\"Math\"},cos:{group:\"Math\"},tan:{group:\"Math\"},asin:{group:\"Math\"},acos:{group:\"Math\"},atan:{group:\"Math\"},min:{group:\"Math\"},max:{group:\"Math\"},round:{group:\"Math\"},abs:{group:\"Math\"},ceil:{group:\"Math\"},floor:{group:\"Math\"},\"==\":{group:\"Decision\"},\"!=\":{group:\"Decision\"},\">\":{group:\"Decision\"},\"<\":{group:\"Decision\"},\">=\":{group:\"Decision\"},\"<=\":{group:\"Decision\"},all:{group:\"Decision\"},any:{group:\"Decision\"},\"!\":{group:\"Decision\"},\"is-supported-script\":{group:\"String\"},upcase:{group:\"String\"},downcase:{group:\"String\"},concat:{group:\"String\"},\"resolved-locale\":{group:\"String\"}}},light:{anchor:{type:\"enum\",default:\"viewport\",values:{map:{},viewport:{}},\"property-type\":\"data-constant\",transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]}},position:{type:\"array\",default:[1.15,210,30],length:3,value:\"number\",\"property-type\":\"data-constant\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]}},color:{type:\"color\",\"property-type\":\"data-constant\",default:\"#ffffff\",expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0},intensity:{type:\"number\",\"property-type\":\"data-constant\",default:.5,minimum:0,maximum:1,expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0}},paint:[\"paint_fill\",\"paint_line\",\"paint_circle\",\"paint_heatmap\",\"paint_fill-extrusion\",\"paint_symbol\",\"paint_raster\",\"paint_hillshade\",\"paint_background\"],paint_fill:{\"fill-antialias\":{type:\"boolean\",default:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-outline-color\":{type:\"color\",transition:!0,requires:[{\"!\":\"fill-pattern\"},{\"fill-antialias\":!0}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"}},\"paint_fill-extrusion\":{\"fill-extrusion-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-extrusion-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-extrusion-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"fill-extrusion-height\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-base\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,requires:[\"fill-extrusion-height\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-vertical-gradient\":{type:\"boolean\",default:!0,transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_line:{\"line-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"line-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-width\":{type:\"number\",default:1,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-gap-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-offset\":{type:\"number\",default:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-dasharray\":{type:\"array\",value:\"number\",minimum:0,transition:!0,units:\"line widths\",requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"line-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"line-gradient\":{type:\"color\",transition:!1,requires:[{\"!\":\"line-dasharray\"},{\"!\":\"line-pattern\"},{source:\"geojson\",has:{lineMetrics:!0}}],expression:{interpolated:!0,parameters:[\"line-progress\"]},\"property-type\":\"color-ramp\"}},paint_circle:{\"circle-radius\":{type:\"number\",default:5,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-blur\":{type:\"number\",default:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"circle-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-scale\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-stroke-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"}},paint_heatmap:{\"heatmap-radius\":{type:\"number\",default:30,minimum:1,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-weight\":{type:\"number\",default:1,minimum:0,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-intensity\":{type:\"number\",default:1,minimum:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"heatmap-color\":{type:\"color\",default:[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,\"rgba(0, 0, 255, 0)\",.1,\"royalblue\",.3,\"cyan\",.5,\"lime\",.7,\"yellow\",1,\"red\"],transition:!1,expression:{interpolated:!0,parameters:[\"heatmap-density\"]},\"property-type\":\"color-ramp\"},\"heatmap-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_symbol:{\"icon-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"icon-image\",\"icon-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"text-field\",\"text-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_raster:{\"raster-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-hue-rotate\":{type:\"number\",default:0,period:360,transition:!0,units:\"degrees\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-min\":{type:\"number\",default:0,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-max\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-saturation\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-contrast\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-resampling\":{type:\"enum\",values:{linear:{},nearest:{}},default:\"linear\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-fade-duration\":{type:\"number\",default:300,minimum:0,transition:!1,units:\"milliseconds\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_hillshade:{\"hillshade-illumination-direction\":{type:\"number\",default:335,minimum:0,maximum:359,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-illumination-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-exaggeration\":{type:\"number\",default:.5,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-shadow-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-highlight-color\":{type:\"color\",default:\"#FFFFFF\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-accent-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_background:{\"background-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"background-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"background-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"background-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},transition:{duration:{type:\"number\",default:300,minimum:0,units:\"milliseconds\"},delay:{type:\"number\",default:0,minimum:0,units:\"milliseconds\"}},\"property-type\":{\"data-driven\":{type:\"property-type\"},\"cross-faded\":{type:\"property-type\"},\"cross-faded-data-driven\":{type:\"property-type\"},\"color-ramp\":{type:\"property-type\"},\"data-constant\":{type:\"property-type\"},constant:{type:\"property-type\"}}},Dt=function(t,e,r,n){this.message=(t?t+\": \":\"\")+r,n&&(this.identifier=n),null!=e&&e.__line__&&(this.line=e.__line__)};function Rt(t){var e=t.key,r=t.value;return r?[new Dt(e,r,\"constants have been deprecated as of v8\")]:[]}function Ft(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}function Bt(t){return t instanceof Number||t instanceof String||t instanceof Boolean}function Nt(t){return Bt(t)?t.valueOf():t}function jt(t){if(Array.isArray(t))return t.map(jt);if(t instanceof Object&&!Bt(t)){var e={};for(var r in t)e[r]=jt(t[r]);return e}return Nt(t)}var Ut=function(t){function e(e,r){t.call(this,r),this.message=r,this.key=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Error),Vt=function(t,e){void 0===e&&(e=[]),this.parent=t,this.bindings={};for(var r=0,n=e;r<n.length;r+=1){var i=n[r],a=i[0],o=i[1];this.bindings[a]=o}};Vt.prototype.concat=function(t){return new Vt(this,t)},Vt.prototype.get=function(t){if(this.bindings[t])return this.bindings[t];if(this.parent)return this.parent.get(t);throw new Error(t+\" not found in scope.\")},Vt.prototype.has=function(t){return!!this.bindings[t]||!!this.parent&&this.parent.has(t)};var qt={kind:\"null\"},Ht={kind:\"number\"},Gt={kind:\"string\"},Yt={kind:\"boolean\"},Wt={kind:\"color\"},Xt={kind:\"object\"},Zt={kind:\"value\"},Jt={kind:\"collator\"},Kt={kind:\"formatted\"};function $t(t,e){return{kind:\"array\",itemType:t,N:e}}function Qt(t){if(\"array\"===t.kind){var e=Qt(t.itemType);return\"number\"==typeof t.N?\"array<\"+e+\", \"+t.N+\">\":\"value\"===t.itemType.kind?\"array\":\"array<\"+e+\">\"}return t.kind}var te=[qt,Ht,Gt,Yt,Wt,Kt,Xt,$t(Zt)];function ee(t,e){if(\"error\"===e.kind)return null;if(\"array\"===t.kind){if(\"array\"===e.kind&&(0===e.N&&\"value\"===e.itemType.kind||!ee(t.itemType,e.itemType))&&(\"number\"!=typeof t.N||t.N===e.N))return null}else{if(t.kind===e.kind)return null;if(\"value\"===t.kind)for(var r=0,n=te;r<n.length;r+=1)if(!ee(n[r],e))return null}return\"Expected \"+Qt(t)+\" but found \"+Qt(e)+\" instead.\"}var re=e(function(t,e){var r={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],rebeccapurple:[102,51,153,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function n(t){return(t=Math.round(t))<0?0:t>255?255:t}function i(t){return t<0?0:t>1?1:t}function a(t){return\"%\"===t[t.length-1]?n(parseFloat(t)/100*255):n(parseInt(t))}function o(t){return\"%\"===t[t.length-1]?i(parseFloat(t)/100):i(parseFloat(t))}function s(t,e,r){return r<0?r+=1:r>1&&(r-=1),6*r<1?t+(e-t)*r*6:2*r<1?e:3*r<2?t+(e-t)*(2/3-r)*6:t}try{e.parseCSSColor=function(t){var e,i=t.replace(/ /g,\"\").toLowerCase();if(i in r)return r[i].slice();if(\"#\"===i[0])return 4===i.length?(e=parseInt(i.substr(1),16))>=0&&e<=4095?[(3840&e)>>4|(3840&e)>>8,240&e|(240&e)>>4,15&e|(15&e)<<4,1]:null:7===i.length&&(e=parseInt(i.substr(1),16))>=0&&e<=16777215?[(16711680&e)>>16,(65280&e)>>8,255&e,1]:null;var l=i.indexOf(\"(\"),c=i.indexOf(\")\");if(-1!==l&&c+1===i.length){var u=i.substr(0,l),h=i.substr(l+1,c-(l+1)).split(\",\"),f=1;switch(u){case\"rgba\":if(4!==h.length)return null;f=o(h.pop());case\"rgb\":return 3!==h.length?null:[a(h[0]),a(h[1]),a(h[2]),f];case\"hsla\":if(4!==h.length)return null;f=o(h.pop());case\"hsl\":if(3!==h.length)return null;var p=(parseFloat(h[0])%360+360)%360/360,d=o(h[1]),g=o(h[2]),v=g<=.5?g*(d+1):g+d-g*d,m=2*g-v;return[n(255*s(m,v,p+1/3)),n(255*s(m,v,p)),n(255*s(m,v,p-1/3)),f];default:return null}}return null}}catch(t){}}).parseCSSColor,ne=function(t,e,r,n){void 0===n&&(n=1),this.r=t,this.g=e,this.b=r,this.a=n};ne.parse=function(t){if(t){if(t instanceof ne)return t;if(\"string\"==typeof t){var e=re(t);if(e)return new ne(e[0]/255*e[3],e[1]/255*e[3],e[2]/255*e[3],e[3])}}},ne.prototype.toString=function(){var t=this.toArray(),e=t[0],r=t[1],n=t[2],i=t[3];return\"rgba(\"+Math.round(e)+\",\"+Math.round(r)+\",\"+Math.round(n)+\",\"+i+\")\"},ne.prototype.toArray=function(){var t=this.r,e=this.g,r=this.b,n=this.a;return 0===n?[0,0,0,0]:[255*t/n,255*e/n,255*r/n,n]},ne.black=new ne(0,0,0,1),ne.white=new ne(1,1,1,1),ne.transparent=new ne(0,0,0,0),ne.red=new ne(1,0,0,1);var ie=function(t,e,r){this.sensitivity=t?e?\"variant\":\"case\":e?\"accent\":\"base\",this.locale=r,this.collator=new Intl.Collator(this.locale?this.locale:[],{sensitivity:this.sensitivity,usage:\"search\"})};ie.prototype.compare=function(t,e){return this.collator.compare(t,e)},ie.prototype.resolvedLocale=function(){return new Intl.Collator(this.locale?this.locale:[]).resolvedOptions().locale};var ae=function(t,e,r){this.text=t,this.scale=e,this.fontStack=r},oe=function(t){this.sections=t};function se(t,e,r,n){return\"number\"==typeof t&&t>=0&&t<=255&&\"number\"==typeof e&&e>=0&&e<=255&&\"number\"==typeof r&&r>=0&&r<=255?void 0===n||\"number\"==typeof n&&n>=0&&n<=1?null:\"Invalid rgba value [\"+[t,e,r,n].join(\", \")+\"]: 'a' must be between 0 and 1.\":\"Invalid rgba value [\"+(\"number\"==typeof n?[t,e,r,n]:[t,e,r]).join(\", \")+\"]: 'r', 'g', and 'b' must be between 0 and 255.\"}function le(t){if(null===t)return qt;if(\"string\"==typeof t)return Gt;if(\"boolean\"==typeof t)return Yt;if(\"number\"==typeof t)return Ht;if(t instanceof ne)return Wt;if(t instanceof ie)return Jt;if(t instanceof oe)return Kt;if(Array.isArray(t)){for(var e,r=t.length,n=0,i=t;n<i.length;n+=1){var a=le(i[n]);if(e){if(e===a)continue;e=Zt;break}e=a}return $t(e||Zt,r)}return Xt}function ce(t){var e=typeof t;return null===t?\"\":\"string\"===e||\"number\"===e||\"boolean\"===e?String(t):t instanceof ne||t instanceof oe?t.toString():JSON.stringify(t)}oe.fromString=function(t){return new oe([new ae(t,null,null)])},oe.prototype.toString=function(){return this.sections.map(function(t){return t.text}).join(\"\")},oe.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.text);var i={};n.fontStack&&(i[\"text-font\"]=[\"literal\",n.fontStack.split(\",\")]),n.scale&&(i[\"font-scale\"]=n.scale),t.push(i)}return t};var ue=function(t,e){this.type=t,this.value=e};ue.parse=function(t,e){if(2!==t.length)return e.error(\"'literal' expression requires exactly one argument, but found \"+(t.length-1)+\" instead.\");if(!function t(e){if(null===e)return!0;if(\"string\"==typeof e)return!0;if(\"boolean\"==typeof e)return!0;if(\"number\"==typeof e)return!0;if(e instanceof ne)return!0;if(e instanceof ie)return!0;if(e instanceof oe)return!0;if(Array.isArray(e)){for(var r=0,n=e;r<n.length;r+=1)if(!t(n[r]))return!1;return!0}if(\"object\"==typeof e){for(var i in e)if(!t(e[i]))return!1;return!0}return!1}(t[1]))return e.error(\"invalid value\");var r=t[1],n=le(r),i=e.expectedType;return\"array\"!==n.kind||0!==n.N||!i||\"array\"!==i.kind||\"number\"==typeof i.N&&0!==i.N||(n=i),new ue(n,r)},ue.prototype.evaluate=function(){return this.value},ue.prototype.eachChild=function(){},ue.prototype.possibleOutputs=function(){return[this.value]},ue.prototype.serialize=function(){return\"array\"===this.type.kind||\"object\"===this.type.kind?[\"literal\",this.value]:this.value instanceof ne?[\"rgba\"].concat(this.value.toArray()):this.value instanceof oe?this.value.serialize():this.value};var he=function(t){this.name=\"ExpressionEvaluationError\",this.message=t};he.prototype.toJSON=function(){return this.message};var fe={string:Gt,number:Ht,boolean:Yt,object:Xt},pe=function(t,e){this.type=t,this.args=e};pe.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r,n=1,i=t[0];if(\"array\"===i){var a,o;if(t.length>2){var s=t[1];if(\"string\"!=typeof s||!(s in fe)||\"object\"===s)return e.error('The item type argument of \"array\" must be one of string, number, boolean',1);a=fe[s],n++}else a=Zt;if(t.length>3){if(null!==t[2]&&(\"number\"!=typeof t[2]||t[2]<0||t[2]!==Math.floor(t[2])))return e.error('The length argument to \"array\" must be a positive integer literal',2);o=t[2],n++}r=$t(a,o)}else r=fe[i];for(var l=[];n<t.length;n++){var c=e.parse(t[n],n,Zt);if(!c)return null;l.push(c)}return new pe(r,l)},pe.prototype.evaluate=function(t){for(var e=0;e<this.args.length;e++){var r=this.args[e].evaluate(t);if(!ee(this.type,le(r)))return r;if(e===this.args.length-1)throw new he(\"Expected value to be of type \"+Qt(this.type)+\", but found \"+Qt(le(r))+\" instead.\")}return null},pe.prototype.eachChild=function(t){this.args.forEach(t)},pe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},pe.prototype.serialize=function(){var t=this.type,e=[t.kind];if(\"array\"===t.kind){var r=t.itemType;if(\"string\"===r.kind||\"number\"===r.kind||\"boolean\"===r.kind){e.push(r.kind);var n=t.N;(\"number\"==typeof n||this.args.length>1)&&e.push(n)}}return e.concat(this.args.map(function(t){return t.serialize()}))};var de=function(t){this.type=Kt,this.sections=t};de.parse=function(t,e){if(t.length<3)return e.error(\"Expected at least two arguments.\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");for(var r=[],n=1;n<t.length-1;n+=2){var i=e.parse(t[n],1,Zt);if(!i)return null;var a=i.type.kind;if(\"string\"!==a&&\"value\"!==a&&\"null\"!==a)return e.error(\"Formatted text type must be 'string', 'value', or 'null'.\");var o=t[n+1];if(\"object\"!=typeof o||Array.isArray(o))return e.error(\"Format options argument must be an object.\");var s=null;if(o[\"font-scale\"]&&!(s=e.parse(o[\"font-scale\"],1,Ht)))return null;var l=null;if(o[\"text-font\"]&&!(l=e.parse(o[\"text-font\"],1,$t(Gt))))return null;r.push({text:i,scale:s,font:l})}return new de(r)},de.prototype.evaluate=function(t){return new oe(this.sections.map(function(e){return new ae(ce(e.text.evaluate(t)),e.scale?e.scale.evaluate(t):null,e.font?e.font.evaluate(t).join(\",\"):null)}))},de.prototype.eachChild=function(t){for(var e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t(n.text),n.scale&&t(n.scale),n.font&&t(n.font)}},de.prototype.possibleOutputs=function(){return[void 0]},de.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.text.serialize());var i={};n.scale&&(i[\"font-scale\"]=n.scale.serialize()),n.font&&(i[\"text-font\"]=n.font.serialize()),t.push(i)}return t};var ge={\"to-boolean\":Yt,\"to-color\":Wt,\"to-number\":Ht,\"to-string\":Gt},ve=function(t,e){this.type=t,this.args=e};ve.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r=t[0];if((\"to-boolean\"===r||\"to-string\"===r)&&2!==t.length)return e.error(\"Expected one argument.\");for(var n=ge[r],i=[],a=1;a<t.length;a++){var o=e.parse(t[a],a,Zt);if(!o)return null;i.push(o)}return new ve(n,i)},ve.prototype.evaluate=function(t){if(\"boolean\"===this.type.kind)return Boolean(this.args[0].evaluate(t));if(\"color\"===this.type.kind){for(var e,r,n=0,i=this.args;n<i.length;n+=1){if(r=null,(e=i[n].evaluate(t))instanceof ne)return e;if(\"string\"==typeof e){var a=t.parseColor(e);if(a)return a}else if(Array.isArray(e)&&!(r=e.length<3||e.length>4?\"Invalid rbga value \"+JSON.stringify(e)+\": expected an array containing either three or four numeric values.\":se(e[0],e[1],e[2],e[3])))return new ne(e[0]/255,e[1]/255,e[2]/255,e[3])}throw new he(r||\"Could not parse color from value '\"+(\"string\"==typeof e?e:String(JSON.stringify(e)))+\"'\")}if(\"number\"===this.type.kind){for(var o=null,s=0,l=this.args;s<l.length;s+=1){if(null===(o=l[s].evaluate(t)))return 0;var c=Number(o);if(!isNaN(c))return c}throw new he(\"Could not convert \"+JSON.stringify(o)+\" to number.\")}return\"formatted\"===this.type.kind?oe.fromString(ce(this.args[0].evaluate(t))):ce(this.args[0].evaluate(t))},ve.prototype.eachChild=function(t){this.args.forEach(t)},ve.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},ve.prototype.serialize=function(){if(\"formatted\"===this.type.kind)return new de([{text:this.args[0],scale:null,font:null}]).serialize();var t=[\"to-\"+this.type.kind];return this.eachChild(function(e){t.push(e.serialize())}),t};var me=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],ye=function(){this.globals=null,this.feature=null,this.featureState=null,this._parseColorCache={}};ye.prototype.id=function(){return this.feature&&\"id\"in this.feature?this.feature.id:null},ye.prototype.geometryType=function(){return this.feature?\"number\"==typeof this.feature.type?me[this.feature.type]:this.feature.type:null},ye.prototype.properties=function(){return this.feature&&this.feature.properties||{}},ye.prototype.parseColor=function(t){var e=this._parseColorCache[t];return e||(e=this._parseColorCache[t]=ne.parse(t)),e};var xe=function(t,e,r,n){this.name=t,this.type=e,this._evaluate=r,this.args=n};xe.prototype.evaluate=function(t){return this._evaluate(t,this.args)},xe.prototype.eachChild=function(t){this.args.forEach(t)},xe.prototype.possibleOutputs=function(){return[void 0]},xe.prototype.serialize=function(){return[this.name].concat(this.args.map(function(t){return t.serialize()}))},xe.parse=function(t,e){var r,n=t[0],i=xe.definitions[n];if(!i)return e.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0);for(var a=Array.isArray(i)?i[0]:i.type,o=Array.isArray(i)?[[i[1],i[2]]]:i.overloads,s=o.filter(function(e){var r=e[0];return!Array.isArray(r)||r.length===t.length-1}),l=null,c=0,u=s;c<u.length;c+=1){var h=u[c],f=h[0],p=h[1];l=new Ae(e.registry,e.path,null,e.scope);for(var d=[],g=!1,v=1;v<t.length;v++){var m=t[v],y=Array.isArray(f)?f[v-1]:f.type,x=l.parse(m,1+d.length,y);if(!x){g=!0;break}d.push(x)}if(!g)if(Array.isArray(f)&&f.length!==d.length)l.error(\"Expected \"+f.length+\" arguments, but found \"+d.length+\" instead.\");else{for(var b=0;b<d.length;b++){var _=Array.isArray(f)?f[b]:f.type,w=d[b];l.concat(b+1).checkSubtype(_,w.type)}if(0===l.errors.length)return new xe(n,a,p,d)}}if(1===s.length)(r=e.errors).push.apply(r,l.errors);else{for(var k=(s.length?s:o).map(function(t){var e;return e=t[0],Array.isArray(e)?\"(\"+e.map(Qt).join(\", \")+\")\":\"(\"+Qt(e.type)+\"...)\"}).join(\" | \"),T=[],A=1;A<t.length;A++){var M=e.parse(t[A],1+T.length);if(!M)return null;T.push(Qt(M.type))}e.error(\"Expected arguments of type \"+k+\", but found (\"+T.join(\", \")+\") instead.\")}return null},xe.register=function(t,e){for(var r in xe.definitions=e,e)t[r]=xe};var be=function(t,e,r){this.type=Jt,this.locale=r,this.caseSensitive=t,this.diacriticSensitive=e};function _e(t){if(t instanceof xe){if(\"get\"===t.name&&1===t.args.length)return!1;if(\"feature-state\"===t.name)return!1;if(\"has\"===t.name&&1===t.args.length)return!1;if(\"properties\"===t.name||\"geometry-type\"===t.name||\"id\"===t.name)return!1;if(/^filter-/.test(t.name))return!1}var e=!0;return t.eachChild(function(t){e&&!_e(t)&&(e=!1)}),e}function we(t){if(t instanceof xe&&\"feature-state\"===t.name)return!1;var e=!0;return t.eachChild(function(t){e&&!we(t)&&(e=!1)}),e}function ke(t,e){if(t instanceof xe&&e.indexOf(t.name)>=0)return!1;var r=!0;return t.eachChild(function(t){r&&!ke(t,e)&&(r=!1)}),r}be.parse=function(t,e){if(2!==t.length)return e.error(\"Expected one argument.\");var r=t[1];if(\"object\"!=typeof r||Array.isArray(r))return e.error(\"Collator options argument must be an object.\");var n=e.parse(void 0!==r[\"case-sensitive\"]&&r[\"case-sensitive\"],1,Yt);if(!n)return null;var i=e.parse(void 0!==r[\"diacritic-sensitive\"]&&r[\"diacritic-sensitive\"],1,Yt);if(!i)return null;var a=null;return r.locale&&!(a=e.parse(r.locale,1,Gt))?null:new be(n,i,a)},be.prototype.evaluate=function(t){return new ie(this.caseSensitive.evaluate(t),this.diacriticSensitive.evaluate(t),this.locale?this.locale.evaluate(t):null)},be.prototype.eachChild=function(t){t(this.caseSensitive),t(this.diacriticSensitive),this.locale&&t(this.locale)},be.prototype.possibleOutputs=function(){return[void 0]},be.prototype.serialize=function(){var t={};return t[\"case-sensitive\"]=this.caseSensitive.serialize(),t[\"diacritic-sensitive\"]=this.diacriticSensitive.serialize(),this.locale&&(t.locale=this.locale.serialize()),[\"collator\",t]};var Te=function(t,e){this.type=e.type,this.name=t,this.boundExpression=e};Te.parse=function(t,e){if(2!==t.length||\"string\"!=typeof t[1])return e.error(\"'var' expression requires exactly one string literal argument.\");var r=t[1];return e.scope.has(r)?new Te(r,e.scope.get(r)):e.error('Unknown variable \"'+r+'\". Make sure \"'+r+'\" has been bound in an enclosing \"let\" expression before using it.',1)},Te.prototype.evaluate=function(t){return this.boundExpression.evaluate(t)},Te.prototype.eachChild=function(){},Te.prototype.possibleOutputs=function(){return[void 0]},Te.prototype.serialize=function(){return[\"var\",this.name]};var Ae=function(t,e,r,n,i){void 0===e&&(e=[]),void 0===n&&(n=new Vt),void 0===i&&(i=[]),this.registry=t,this.path=e,this.key=e.map(function(t){return\"[\"+t+\"]\"}).join(\"\"),this.scope=n,this.errors=i,this.expectedType=r};function Me(t,e){for(var r,n,i=t.length-1,a=0,o=i,s=0;a<=o;)if(r=t[s=Math.floor((a+o)/2)],n=t[s+1],r<=e){if(s===i||e<n)return s;a=s+1}else{if(!(r>e))throw new he(\"Input is not a number.\");o=s-1}return 0}Ae.prototype.parse=function(t,e,r,n,i){return void 0===i&&(i={}),e?this.concat(e,r,n)._parse(t,i):this._parse(t,i)},Ae.prototype._parse=function(t,e){function r(t,e,r){return\"assert\"===r?new pe(e,[t]):\"coerce\"===r?new ve(e,[t]):t}if(null!==t&&\"string\"!=typeof t&&\"boolean\"!=typeof t&&\"number\"!=typeof t||(t=[\"literal\",t]),Array.isArray(t)){if(0===t.length)return this.error('Expected an array with at least one element. If you wanted a literal array, use [\"literal\", []].');var n=t[0];if(\"string\"!=typeof n)return this.error(\"Expression name must be a string, but found \"+typeof n+' instead. If you wanted a literal array, use [\"literal\", [...]].',0),null;var i=this.registry[n];if(i){var a=i.parse(t,this);if(!a)return null;if(this.expectedType){var o=this.expectedType,s=a.type;if(\"string\"!==o.kind&&\"number\"!==o.kind&&\"boolean\"!==o.kind&&\"object\"!==o.kind&&\"array\"!==o.kind||\"value\"!==s.kind)if(\"color\"!==o.kind&&\"formatted\"!==o.kind||\"value\"!==s.kind&&\"string\"!==s.kind){if(this.checkSubtype(o,s))return null}else a=r(a,o,e.typeAnnotation||\"coerce\");else a=r(a,o,e.typeAnnotation||\"assert\")}if(!(a instanceof ue)&&function t(e){if(e instanceof Te)return t(e.boundExpression);if(e instanceof xe&&\"error\"===e.name)return!1;if(e instanceof be)return!1;var r=e instanceof ve||e instanceof pe,n=!0;return e.eachChild(function(e){n=r?n&&t(e):n&&e instanceof ue}),!!n&&(_e(e)&&ke(e,[\"zoom\",\"heatmap-density\",\"line-progress\",\"accumulated\",\"is-supported-script\"]))}(a)){var l=new ye;try{a=new ue(a.type,a.evaluate(l))}catch(t){return this.error(t.message),null}}return a}return this.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0)}return void 0===t?this.error(\"'undefined' value invalid. Use null instead.\"):\"object\"==typeof t?this.error('Bare objects invalid. Use [\"literal\", {...}] instead.'):this.error(\"Expected an array, but found \"+typeof t+\" instead.\")},Ae.prototype.concat=function(t,e,r){var n=\"number\"==typeof t?this.path.concat(t):this.path,i=r?this.scope.concat(r):this.scope;return new Ae(this.registry,n,e||null,i,this.errors)},Ae.prototype.error=function(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];var n=\"\"+this.key+e.map(function(t){return\"[\"+t+\"]\"}).join(\"\");this.errors.push(new Ut(n,t))},Ae.prototype.checkSubtype=function(t,e){var r=ee(t,e);return r&&this.error(r),r};var Se=function(t,e,r){this.type=t,this.input=e,this.labels=[],this.outputs=[];for(var n=0,i=r;n<i.length;n+=1){var a=i[n],o=a[0],s=a[1];this.labels.push(o),this.outputs.push(s)}};function Ee(t,e,r){return t*(1-r)+e*r}Se.parse=function(t,e){if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");var r=e.parse(t[1],1,Ht);if(!r)return null;var n=[],i=null;e.expectedType&&\"value\"!==e.expectedType.kind&&(i=e.expectedType);for(var a=1;a<t.length;a+=2){var o=1===a?-1/0:t[a],s=t[a+1],l=a,c=a+1;if(\"number\"!=typeof o)return e.error('Input/output pairs for \"step\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',l);if(n.length&&n[n.length-1][0]>=o)return e.error('Input/output pairs for \"step\" expressions must be arranged with input values in strictly ascending order.',l);var u=e.parse(s,c,i);if(!u)return null;i=i||u.type,n.push([o,u])}return new Se(i,r,n)},Se.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;return n>=e[i-1]?r[i-1].evaluate(t):r[Me(e,n)].evaluate(t)},Se.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},Se.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()}))},Se.prototype.serialize=function(){for(var t=[\"step\",this.input.serialize()],e=0;e<this.labels.length;e++)e>0&&t.push(this.labels[e]),t.push(this.outputs[e].serialize());return t};var Ce=Object.freeze({number:Ee,color:function(t,e,r){return new ne(Ee(t.r,e.r,r),Ee(t.g,e.g,r),Ee(t.b,e.b,r),Ee(t.a,e.a,r))},array:function(t,e,r){return t.map(function(t,n){return Ee(t,e[n],r)})}}),Le=.95047,Pe=1,Oe=1.08883,ze=4/29,Ie=6/29,De=3*Ie*Ie,Re=Ie*Ie*Ie,Fe=Math.PI/180,Be=180/Math.PI;function Ne(t){return t>Re?Math.pow(t,1/3):t/De+ze}function je(t){return t>Ie?t*t*t:De*(t-ze)}function Ue(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function Ve(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function qe(t){var e=Ve(t.r),r=Ve(t.g),n=Ve(t.b),i=Ne((.4124564*e+.3575761*r+.1804375*n)/Le),a=Ne((.2126729*e+.7151522*r+.072175*n)/Pe);return{l:116*a-16,a:500*(i-a),b:200*(a-Ne((.0193339*e+.119192*r+.9503041*n)/Oe)),alpha:t.a}}function He(t){var e=(t.l+16)/116,r=isNaN(t.a)?e:e+t.a/500,n=isNaN(t.b)?e:e-t.b/200;return e=Pe*je(e),r=Le*je(r),n=Oe*je(n),new ne(Ue(3.2404542*r-1.5371385*e-.4985314*n),Ue(-.969266*r+1.8760108*e+.041556*n),Ue(.0556434*r-.2040259*e+1.0572252*n),t.alpha)}var Ge={forward:qe,reverse:He,interpolate:function(t,e,r){return{l:Ee(t.l,e.l,r),a:Ee(t.a,e.a,r),b:Ee(t.b,e.b,r),alpha:Ee(t.alpha,e.alpha,r)}}},Ye={forward:function(t){var e=qe(t),r=e.l,n=e.a,i=e.b,a=Math.atan2(i,n)*Be;return{h:a<0?a+360:a,c:Math.sqrt(n*n+i*i),l:r,alpha:t.a}},reverse:function(t){var e=t.h*Fe,r=t.c;return He({l:t.l,a:Math.cos(e)*r,b:Math.sin(e)*r,alpha:t.alpha})},interpolate:function(t,e,r){return{h:function(t,e,r){var n=e-t;return t+r*(n>180||n<-180?n-360*Math.round(n/360):n)}(t.h,e.h,r),c:Ee(t.c,e.c,r),l:Ee(t.l,e.l,r),alpha:Ee(t.alpha,e.alpha,r)}}},We=Object.freeze({lab:Ge,hcl:Ye}),Xe=function(t,e,r,n,i){this.type=t,this.operator=e,this.interpolation=r,this.input=n,this.labels=[],this.outputs=[];for(var a=0,o=i;a<o.length;a+=1){var s=o[a],l=s[0],c=s[1];this.labels.push(l),this.outputs.push(c)}};function Ze(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}Xe.interpolationFactor=function(t,e,n,i){var a=0;if(\"exponential\"===t.name)a=Ze(e,t.base,n,i);else if(\"linear\"===t.name)a=Ze(e,1,n,i);else if(\"cubic-bezier\"===t.name){var o=t.controlPoints;a=new r(o[0],o[1],o[2],o[3]).solve(Ze(e,1,n,i))}return a},Xe.parse=function(t,e){var r=t[0],n=t[1],i=t[2],a=t.slice(3);if(!Array.isArray(n)||0===n.length)return e.error(\"Expected an interpolation type expression.\",1);if(\"linear\"===n[0])n={name:\"linear\"};else if(\"exponential\"===n[0]){var o=n[1];if(\"number\"!=typeof o)return e.error(\"Exponential interpolation requires a numeric base.\",1,1);n={name:\"exponential\",base:o}}else{if(\"cubic-bezier\"!==n[0])return e.error(\"Unknown interpolation type \"+String(n[0]),1,0);var s=n.slice(1);if(4!==s.length||s.some(function(t){return\"number\"!=typeof t||t<0||t>1}))return e.error(\"Cubic bezier interpolation requires four numeric arguments with values between 0 and 1.\",1);n={name:\"cubic-bezier\",controlPoints:s}}if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");if(!(i=e.parse(i,2,Ht)))return null;var l=[],c=null;\"interpolate-hcl\"===r||\"interpolate-lab\"===r?c=Wt:e.expectedType&&\"value\"!==e.expectedType.kind&&(c=e.expectedType);for(var u=0;u<a.length;u+=2){var h=a[u],f=a[u+1],p=u+3,d=u+4;if(\"number\"!=typeof h)return e.error('Input/output pairs for \"interpolate\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',p);if(l.length&&l[l.length-1][0]>=h)return e.error('Input/output pairs for \"interpolate\" expressions must be arranged with input values in strictly ascending order.',p);var g=e.parse(f,d,c);if(!g)return null;c=c||g.type,l.push([h,g])}return\"number\"===c.kind||\"color\"===c.kind||\"array\"===c.kind&&\"number\"===c.itemType.kind&&\"number\"==typeof c.N?new Xe(c,r,n,i,l):e.error(\"Type \"+Qt(c)+\" is not interpolatable.\")},Xe.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;if(n>=e[i-1])return r[i-1].evaluate(t);var a=Me(e,n),o=e[a],s=e[a+1],l=Xe.interpolationFactor(this.interpolation,n,o,s),c=r[a].evaluate(t),u=r[a+1].evaluate(t);return\"interpolate\"===this.operator?Ce[this.type.kind.toLowerCase()](c,u,l):\"interpolate-hcl\"===this.operator?Ye.reverse(Ye.interpolate(Ye.forward(c),Ye.forward(u),l)):Ge.reverse(Ge.interpolate(Ge.forward(c),Ge.forward(u),l))},Xe.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},Xe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()}))},Xe.prototype.serialize=function(){var t;t=\"linear\"===this.interpolation.name?[\"linear\"]:\"exponential\"===this.interpolation.name?1===this.interpolation.base?[\"linear\"]:[\"exponential\",this.interpolation.base]:[\"cubic-bezier\"].concat(this.interpolation.controlPoints);for(var e=[this.operator,t,this.input.serialize()],r=0;r<this.labels.length;r++)e.push(this.labels[r],this.outputs[r].serialize());return e};var Je=function(t,e){this.type=t,this.args=e};Je.parse=function(t,e){if(t.length<2)return e.error(\"Expectected at least one argument.\");var r=null,n=e.expectedType;n&&\"value\"!==n.kind&&(r=n);for(var i=[],a=0,o=t.slice(1);a<o.length;a+=1){var s=o[a],l=e.parse(s,1+i.length,r,void 0,{typeAnnotation:\"omit\"});if(!l)return null;r=r||l.type,i.push(l)}var c=n&&i.some(function(t){return ee(n,t.type)});return new Je(c?Zt:r,i)},Je.prototype.evaluate=function(t){for(var e=null,r=0,n=this.args;r<n.length&&null===(e=n[r].evaluate(t));r+=1);return e},Je.prototype.eachChild=function(t){this.args.forEach(t)},Je.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},Je.prototype.serialize=function(){var t=[\"coalesce\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var Ke=function(t,e){this.type=e.type,this.bindings=[].concat(t),this.result=e};Ke.prototype.evaluate=function(t){return this.result.evaluate(t)},Ke.prototype.eachChild=function(t){for(var e=0,r=this.bindings;e<r.length;e+=1)t(r[e][1]);t(this.result)},Ke.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found \"+(t.length-1)+\" instead.\");for(var r=[],n=1;n<t.length-1;n+=2){var i=t[n];if(\"string\"!=typeof i)return e.error(\"Expected string, but found \"+typeof i+\" instead.\",n);if(/[^a-zA-Z0-9_]/.test(i))return e.error(\"Variable names must contain only alphanumeric characters or '_'.\",n);var a=e.parse(t[n+1],n+1);if(!a)return null;r.push([i,a])}var o=e.parse(t[t.length-1],t.length-1,e.expectedType,r);return o?new Ke(r,o):null},Ke.prototype.possibleOutputs=function(){return this.result.possibleOutputs()},Ke.prototype.serialize=function(){for(var t=[\"let\"],e=0,r=this.bindings;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];t.push(i,a.serialize())}return t.push(this.result.serialize()),t};var $e=function(t,e,r){this.type=t,this.index=e,this.input=r};$e.parse=function(t,e){if(3!==t.length)return e.error(\"Expected 2 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,Ht),n=e.parse(t[2],2,$t(e.expectedType||Zt));if(!r||!n)return null;var i=n.type;return new $e(i.itemType,r,n)},$e.prototype.evaluate=function(t){var e=this.index.evaluate(t),r=this.input.evaluate(t);if(e<0)throw new he(\"Array index out of bounds: \"+e+\" < 0.\");if(e>=r.length)throw new he(\"Array index out of bounds: \"+e+\" > \"+(r.length-1)+\".\");if(e!==Math.floor(e))throw new he(\"Array index must be an integer, but found \"+e+\" instead.\");return r[e]},$e.prototype.eachChild=function(t){t(this.index),t(this.input)},$e.prototype.possibleOutputs=function(){return[void 0]},$e.prototype.serialize=function(){return[\"at\",this.index.serialize(),this.input.serialize()]};var Qe=function(t,e,r,n,i,a){this.inputType=t,this.type=e,this.input=r,this.cases=n,this.outputs=i,this.otherwise=a};Qe.parse=function(t,e){if(t.length<5)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=1)return e.error(\"Expected an even number of arguments.\");var r,n;e.expectedType&&\"value\"!==e.expectedType.kind&&(n=e.expectedType);for(var i={},a=[],o=2;o<t.length-1;o+=2){var s=t[o],l=t[o+1];Array.isArray(s)||(s=[s]);var c=e.concat(o);if(0===s.length)return c.error(\"Expected at least one branch label.\");for(var u=0,h=s;u<h.length;u+=1){var f=h[u];if(\"number\"!=typeof f&&\"string\"!=typeof f)return c.error(\"Branch labels must be numbers or strings.\");if(\"number\"==typeof f&&Math.abs(f)>Number.MAX_SAFE_INTEGER)return c.error(\"Branch labels must be integers no larger than \"+Number.MAX_SAFE_INTEGER+\".\");if(\"number\"==typeof f&&Math.floor(f)!==f)return c.error(\"Numeric branch labels must be integer values.\");if(r){if(c.checkSubtype(r,le(f)))return null}else r=le(f);if(void 0!==i[String(f)])return c.error(\"Branch labels must be unique.\");i[String(f)]=a.length}var p=e.parse(l,o,n);if(!p)return null;n=n||p.type,a.push(p)}var d=e.parse(t[1],1,Zt);if(!d)return null;var g=e.parse(t[t.length-1],t.length-1,n);return g?\"value\"!==d.type.kind&&e.concat(1).checkSubtype(r,d.type)?null:new Qe(r,n,d,i,a,g):null},Qe.prototype.evaluate=function(t){var e=this.input.evaluate(t);return(le(e)===this.inputType&&this.outputs[this.cases[e]]||this.otherwise).evaluate(t)},Qe.prototype.eachChild=function(t){t(this.input),this.outputs.forEach(t),t(this.otherwise)},Qe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()})).concat(this.otherwise.possibleOutputs())},Qe.prototype.serialize=function(){for(var t=this,e=[\"match\",this.input.serialize()],r=[],n={},i=0,a=Object.keys(this.cases).sort();i<a.length;i+=1){var o=a[i];void 0===(h=n[this.cases[o]])?(n[this.cases[o]]=r.length,r.push([this.cases[o],[o]])):r[h][1].push(o)}for(var s=function(e){return\"number\"===t.inputType.kind?Number(e):e},l=0,c=r;l<c.length;l+=1){var u=c[l],h=u[0],f=u[1];1===f.length?e.push(s(f[0])):e.push(f.map(s)),e.push(this.outputs[outputIndex$1].serialize())}return e.push(this.otherwise.serialize()),e};var tr=function(t,e,r){this.type=t,this.branches=e,this.otherwise=r};function er(t,e){return\"==\"===t||\"!=\"===t?\"boolean\"===e.kind||\"string\"===e.kind||\"number\"===e.kind||\"null\"===e.kind||\"value\"===e.kind:\"string\"===e.kind||\"number\"===e.kind||\"value\"===e.kind}function rr(t,e,r,n){return 0===n.compare(e,r)}function nr(t,e,r){var n=\"==\"!==t&&\"!=\"!==t;return function(){function i(t,e,r){this.type=Yt,this.lhs=t,this.rhs=e,this.collator=r,this.hasUntypedArgument=\"value\"===t.type.kind||\"value\"===e.type.kind}return i.parse=function(t,e){if(3!==t.length&&4!==t.length)return e.error(\"Expected two or three arguments.\");var r=t[0],a=e.parse(t[1],1,Zt);if(!a)return null;if(!er(r,a.type))return e.concat(1).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Qt(a.type)+\"'.\");var o=e.parse(t[2],2,Zt);if(!o)return null;if(!er(r,o.type))return e.concat(2).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Qt(o.type)+\"'.\");if(a.type.kind!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot compare types '\"+Qt(a.type)+\"' and '\"+Qt(o.type)+\"'.\");n&&(\"value\"===a.type.kind&&\"value\"!==o.type.kind?a=new pe(o.type,[a]):\"value\"!==a.type.kind&&\"value\"===o.type.kind&&(o=new pe(a.type,[o])));var s=null;if(4===t.length){if(\"string\"!==a.type.kind&&\"string\"!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot use collator to compare non-string types.\");if(!(s=e.parse(t[3],3,Jt)))return null}return new i(a,o,s)},i.prototype.evaluate=function(i){var a=this.lhs.evaluate(i),o=this.rhs.evaluate(i);if(n&&this.hasUntypedArgument){var s=le(a),l=le(o);if(s.kind!==l.kind||\"string\"!==s.kind&&\"number\"!==s.kind)throw new he('Expected arguments for \"'+t+'\" to be (string, string) or (number, number), but found ('+s.kind+\", \"+l.kind+\") instead.\")}if(this.collator&&!n&&this.hasUntypedArgument){var c=le(a),u=le(o);if(\"string\"!==c.kind||\"string\"!==u.kind)return e(i,a,o)}return this.collator?r(i,a,o,this.collator.evaluate(i)):e(i,a,o)},i.prototype.eachChild=function(t){t(this.lhs),t(this.rhs),this.collator&&t(this.collator)},i.prototype.possibleOutputs=function(){return[!0,!1]},i.prototype.serialize=function(){var e=[t];return this.eachChild(function(t){e.push(t.serialize())}),e},i}()}tr.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=0)return e.error(\"Expected an odd number of arguments.\");var r;e.expectedType&&\"value\"!==e.expectedType.kind&&(r=e.expectedType);for(var n=[],i=1;i<t.length-1;i+=2){var a=e.parse(t[i],i,Yt);if(!a)return null;var o=e.parse(t[i+1],i+1,r);if(!o)return null;n.push([a,o]),r=r||o.type}var s=e.parse(t[t.length-1],t.length-1,r);return s?new tr(r,n,s):null},tr.prototype.evaluate=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];if(i.evaluate(t))return a.evaluate(t)}return this.otherwise.evaluate(t)},tr.prototype.eachChild=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];t(i),t(a)}t(this.otherwise)},tr.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.branches.map(function(t){return t[0],t[1].possibleOutputs()})).concat(this.otherwise.possibleOutputs())},tr.prototype.serialize=function(){var t=[\"case\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var ir=nr(\"==\",function(t,e,r){return e===r},rr),ar=nr(\"!=\",function(t,e,r){return e!==r},function(t,e,r,n){return!rr(0,e,r,n)}),or=nr(\"<\",function(t,e,r){return e<r},function(t,e,r,n){return n.compare(e,r)<0}),sr=nr(\">\",function(t,e,r){return e>r},function(t,e,r,n){return n.compare(e,r)>0}),lr=nr(\"<=\",function(t,e,r){return e<=r},function(t,e,r,n){return n.compare(e,r)<=0}),cr=nr(\">=\",function(t,e,r){return e>=r},function(t,e,r,n){return n.compare(e,r)>=0}),ur=function(t,e,r,n,i){this.type=Gt,this.number=t,this.locale=e,this.currency=r,this.minFractionDigits=n,this.maxFractionDigits=i};ur.parse=function(t,e){if(3!==t.length)return e.error(\"Expected two arguments.\");var r=e.parse(t[1],1,Ht);if(!r)return null;var n=t[2];if(\"object\"!=typeof n||Array.isArray(n))return e.error(\"NumberFormat options argument must be an object.\");var i=null;if(n.locale&&!(i=e.parse(n.locale,1,Gt)))return null;var a=null;if(n.currency&&!(a=e.parse(n.currency,1,Gt)))return null;var o=null;if(n[\"min-fraction-digits\"]&&!(o=e.parse(n[\"min-fraction-digits\"],1,Ht)))return null;var s=null;return n[\"max-fraction-digits\"]&&!(s=e.parse(n[\"max-fraction-digits\"],1,Ht))?null:new ur(r,i,a,o,s)},ur.prototype.evaluate=function(t){return new Intl.NumberFormat(this.locale?this.locale.evaluate(t):[],{style:this.currency?\"currency\":\"decimal\",currency:this.currency?this.currency.evaluate(t):void 0,minimumFractionDigits:this.minFractionDigits?this.minFractionDigits.evaluate(t):void 0,maximumFractionDigits:this.maxFractionDigits?this.maxFractionDigits.evaluate(t):void 0}).format(this.number.evaluate(t))},ur.prototype.eachChild=function(t){t(this.number),this.locale&&t(this.locale),this.currency&&t(this.currency),this.minFractionDigits&&t(this.minFractionDigits),this.maxFractionDigits&&t(this.maxFractionDigits)},ur.prototype.possibleOutputs=function(){return[void 0]},ur.prototype.serialize=function(){var t={};return this.locale&&(t.locale=this.locale.serialize()),this.currency&&(t.currency=this.currency.serialize()),this.minFractionDigits&&(t[\"min-fraction-digits\"]=this.minFractionDigits.serialize()),this.maxFractionDigits&&(t[\"max-fraction-digits\"]=this.maxFractionDigits.serialize()),[\"number-format\",this.number.serialize(),t]};var hr=function(t){this.type=Ht,this.input=t};hr.parse=function(t,e){if(2!==t.length)return e.error(\"Expected 1 argument, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1);return r?\"array\"!==r.type.kind&&\"string\"!==r.type.kind&&\"value\"!==r.type.kind?e.error(\"Expected argument of type string or array, but found \"+Qt(r.type)+\" instead.\"):new hr(r):null},hr.prototype.evaluate=function(t){var e=this.input.evaluate(t);if(\"string\"==typeof e)return e.length;if(Array.isArray(e))return e.length;throw new he(\"Expected value to be of type string or array, but found \"+Qt(le(e))+\" instead.\")},hr.prototype.eachChild=function(t){t(this.input)},hr.prototype.possibleOutputs=function(){return[void 0]},hr.prototype.serialize=function(){var t=[\"length\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var fr={\"==\":ir,\"!=\":ar,\">\":sr,\"<\":or,\">=\":cr,\"<=\":lr,array:pe,at:$e,boolean:pe,case:tr,coalesce:Je,collator:be,format:de,interpolate:Xe,\"interpolate-hcl\":Xe,\"interpolate-lab\":Xe,length:hr,let:Ke,literal:ue,match:Qe,number:pe,\"number-format\":ur,object:pe,step:Se,string:pe,\"to-boolean\":ve,\"to-color\":ve,\"to-number\":ve,\"to-string\":ve,var:Te};function pr(t,e){var r=e[0],n=e[1],i=e[2],a=e[3];r=r.evaluate(t),n=n.evaluate(t),i=i.evaluate(t);var o=a?a.evaluate(t):1,s=se(r,n,i,o);if(s)throw new he(s);return new ne(r/255*o,n/255*o,i/255*o,o)}function dr(t,e){return t in e}function gr(t,e){var r=e[t];return void 0===r?null:r}function vr(t){return{type:t}}function mr(t){return{result:\"success\",value:t}}function yr(t){return{result:\"error\",value:t}}function xr(t){return\"data-driven\"===t[\"property-type\"]||\"cross-faded-data-driven\"===t[\"property-type\"]}function br(t){return!!t.expression&&t.expression.parameters.indexOf(\"zoom\")>-1}function _r(t){return!!t.expression&&t.expression.interpolated}function wr(t){return t instanceof Number?\"number\":t instanceof String?\"string\":t instanceof Boolean?\"boolean\":Array.isArray(t)?\"array\":null===t?\"null\":typeof t}function kr(t){return\"object\"==typeof t&&null!==t&&!Array.isArray(t)}function Tr(t){return t}function Ar(t,e,r){return void 0!==t?t:void 0!==e?e:void 0!==r?r:void 0}function Mr(t,e,r,n,i){return Ar(typeof r===i?n[r]:void 0,t.default,e.default)}function Sr(t,e,r){if(\"number\"!==wr(r))return Ar(t.default,e.default);var n=t.stops.length;if(1===n)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[n-1][0])return t.stops[n-1][1];var i=Me(t.stops.map(function(t){return t[0]}),r);return t.stops[i][1]}function Er(t,e,r){var n=void 0!==t.base?t.base:1;if(\"number\"!==wr(r))return Ar(t.default,e.default);var i=t.stops.length;if(1===i)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[i-1][0])return t.stops[i-1][1];var a=Me(t.stops.map(function(t){return t[0]}),r),o=function(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}(r,n,t.stops[a][0],t.stops[a+1][0]),s=t.stops[a][1],l=t.stops[a+1][1],c=Ce[e.type]||Tr;if(t.colorSpace&&\"rgb\"!==t.colorSpace){var u=We[t.colorSpace];c=function(t,e){return u.reverse(u.interpolate(u.forward(t),u.forward(e),o))}}return\"function\"==typeof s.evaluate?{evaluate:function(){for(var t=[],e=arguments.length;e--;)t[e]=arguments[e];var r=s.evaluate.apply(void 0,t),n=l.evaluate.apply(void 0,t);if(void 0!==r&&void 0!==n)return c(r,n,o)}}:c(s,l,o)}function Cr(t,e,r){return\"color\"===e.type?r=ne.parse(r):\"formatted\"===e.type?r=oe.fromString(r.toString()):wr(r)===e.type||\"enum\"===e.type&&e.values[r]||(r=void 0),Ar(r,t.default,e.default)}xe.register(fr,{error:[{kind:\"error\"},[Gt],function(t,e){var r=e[0];throw new he(r.evaluate(t))}],typeof:[Gt,[Zt],function(t,e){return Qt(le(e[0].evaluate(t)))}],\"to-rgba\":[$t(Ht,4),[Wt],function(t,e){return e[0].evaluate(t).toArray()}],rgb:[Wt,[Ht,Ht,Ht],pr],rgba:[Wt,[Ht,Ht,Ht,Ht],pr],has:{type:Yt,overloads:[[[Gt],function(t,e){return dr(e[0].evaluate(t),t.properties())}],[[Gt,Xt],function(t,e){var r=e[0],n=e[1];return dr(r.evaluate(t),n.evaluate(t))}]]},get:{type:Zt,overloads:[[[Gt],function(t,e){return gr(e[0].evaluate(t),t.properties())}],[[Gt,Xt],function(t,e){var r=e[0],n=e[1];return gr(r.evaluate(t),n.evaluate(t))}]]},\"feature-state\":[Zt,[Gt],function(t,e){return gr(e[0].evaluate(t),t.featureState||{})}],properties:[Xt,[],function(t){return t.properties()}],\"geometry-type\":[Gt,[],function(t){return t.geometryType()}],id:[Zt,[],function(t){return t.id()}],zoom:[Ht,[],function(t){return t.globals.zoom}],\"heatmap-density\":[Ht,[],function(t){return t.globals.heatmapDensity||0}],\"line-progress\":[Ht,[],function(t){return t.globals.lineProgress||0}],accumulated:[Zt,[],function(t){return void 0===t.globals.accumulated?null:t.globals.accumulated}],\"+\":[Ht,vr(Ht),function(t,e){for(var r=0,n=0,i=e;n<i.length;n+=1)r+=i[n].evaluate(t);return r}],\"*\":[Ht,vr(Ht),function(t,e){for(var r=1,n=0,i=e;n<i.length;n+=1)r*=i[n].evaluate(t);return r}],\"-\":{type:Ht,overloads:[[[Ht,Ht],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)-n.evaluate(t)}],[[Ht],function(t,e){return-e[0].evaluate(t)}]]},\"/\":[Ht,[Ht,Ht],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)/n.evaluate(t)}],\"%\":[Ht,[Ht,Ht],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)%n.evaluate(t)}],ln2:[Ht,[],function(){return Math.LN2}],pi:[Ht,[],function(){return Math.PI}],e:[Ht,[],function(){return Math.E}],\"^\":[Ht,[Ht,Ht],function(t,e){var r=e[0],n=e[1];return Math.pow(r.evaluate(t),n.evaluate(t))}],sqrt:[Ht,[Ht],function(t,e){var r=e[0];return Math.sqrt(r.evaluate(t))}],log10:[Ht,[Ht],function(t,e){var r=e[0];return Math.log(r.evaluate(t))/Math.LN10}],ln:[Ht,[Ht],function(t,e){var r=e[0];return Math.log(r.evaluate(t))}],log2:[Ht,[Ht],function(t,e){var r=e[0];return Math.log(r.evaluate(t))/Math.LN2}],sin:[Ht,[Ht],function(t,e){var r=e[0];return Math.sin(r.evaluate(t))}],cos:[Ht,[Ht],function(t,e){var r=e[0];return Math.cos(r.evaluate(t))}],tan:[Ht,[Ht],function(t,e){var r=e[0];return Math.tan(r.evaluate(t))}],asin:[Ht,[Ht],function(t,e){var r=e[0];return Math.asin(r.evaluate(t))}],acos:[Ht,[Ht],function(t,e){var r=e[0];return Math.acos(r.evaluate(t))}],atan:[Ht,[Ht],function(t,e){var r=e[0];return Math.atan(r.evaluate(t))}],min:[Ht,vr(Ht),function(t,e){return Math.min.apply(Math,e.map(function(e){return e.evaluate(t)}))}],max:[Ht,vr(Ht),function(t,e){return Math.max.apply(Math,e.map(function(e){return e.evaluate(t)}))}],abs:[Ht,[Ht],function(t,e){var r=e[0];return Math.abs(r.evaluate(t))}],round:[Ht,[Ht],function(t,e){var r=e[0].evaluate(t);return r<0?-Math.round(-r):Math.round(r)}],floor:[Ht,[Ht],function(t,e){var r=e[0];return Math.floor(r.evaluate(t))}],ceil:[Ht,[Ht],function(t,e){var r=e[0];return Math.ceil(r.evaluate(t))}],\"filter-==\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1];return t.properties()[r.value]===n.value}],\"filter-id-==\":[Yt,[Zt],function(t,e){var r=e[0];return t.id()===r.value}],\"filter-type-==\":[Yt,[Gt],function(t,e){var r=e[0];return t.geometryType()===r.value}],\"filter-<\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<a}],\"filter-id-<\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<i}],\"filter->\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>a}],\"filter-id->\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>i}],\"filter-<=\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<=a}],\"filter-id-<=\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<=i}],\"filter->=\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>=a}],\"filter-id->=\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>=i}],\"filter-has\":[Yt,[Zt],function(t,e){return e[0].value in t.properties()}],\"filter-has-id\":[Yt,[],function(t){return null!==t.id()}],\"filter-type-in\":[Yt,[$t(Gt)],function(t,e){return e[0].value.indexOf(t.geometryType())>=0}],\"filter-id-in\":[Yt,[$t(Zt)],function(t,e){return e[0].value.indexOf(t.id())>=0}],\"filter-in-small\":[Yt,[Gt,$t(Zt)],function(t,e){var r=e[0];return e[1].value.indexOf(t.properties()[r.value])>=0}],\"filter-in-large\":[Yt,[Gt,$t(Zt)],function(t,e){var r=e[0],n=e[1];return function(t,e,r,n){for(;r<=n;){var i=r+n>>1;if(e[i]===t)return!0;e[i]>t?n=i-1:r=i+1}return!1}(t.properties()[r.value],n.value,0,n.value.length-1)}],all:{type:Yt,overloads:[[[Yt,Yt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)&&n.evaluate(t)}],[vr(Yt),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(!n[r].evaluate(t))return!1;return!0}]]},any:{type:Yt,overloads:[[[Yt,Yt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)||n.evaluate(t)}],[vr(Yt),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(n[r].evaluate(t))return!0;return!1}]]},\"!\":[Yt,[Yt],function(t,e){return!e[0].evaluate(t)}],\"is-supported-script\":[Yt,[Gt],function(t,e){var r=e[0],n=t.globals&&t.globals.isSupportedScript;return!n||n(r.evaluate(t))}],upcase:[Gt,[Gt],function(t,e){return e[0].evaluate(t).toUpperCase()}],downcase:[Gt,[Gt],function(t,e){return e[0].evaluate(t).toLowerCase()}],concat:[Gt,vr(Zt),function(t,e){return e.map(function(e){return ce(e.evaluate(t))}).join(\"\")}],\"resolved-locale\":[Gt,[Jt],function(t,e){return e[0].evaluate(t).resolvedLocale()}]});var Lr=function(t,e){var r;this.expression=t,this._warningHistory={},this._evaluator=new ye,this._defaultValue=e?\"color\"===(r=e).type&&kr(r.default)?new ne(0,0,0,0):\"color\"===r.type?ne.parse(r.default)||null:void 0===r.default?null:r.default:null,this._enumValues=e&&\"enum\"===e.type?e.values:null};function Pr(t){return Array.isArray(t)&&t.length>0&&\"string\"==typeof t[0]&&t[0]in fr}function Or(t,e){var r=new Ae(fr,[],e?function(t){var e={color:Wt,string:Gt,number:Ht,enum:Gt,boolean:Yt,formatted:Kt};return\"array\"===t.type?$t(e[t.value]||Zt,t.length):e[t.type]}(e):void 0),n=r.parse(t,void 0,void 0,void 0,e&&\"string\"===e.type?{typeAnnotation:\"coerce\"}:void 0);return n?mr(new Lr(n,e)):yr(r.errors)}Lr.prototype.evaluateWithoutErrorHandling=function(t,e,r){return this._evaluator.globals=t,this._evaluator.feature=e,this._evaluator.featureState=r,this.expression.evaluate(this._evaluator)},Lr.prototype.evaluate=function(t,e,r){this._evaluator.globals=t,this._evaluator.feature=e||null,this._evaluator.featureState=r||null;try{var n=this.expression.evaluate(this._evaluator);if(null==n)return this._defaultValue;if(this._enumValues&&!(n in this._enumValues))throw new he(\"Expected value to be one of \"+Object.keys(this._enumValues).map(function(t){return JSON.stringify(t)}).join(\", \")+\", but found \"+JSON.stringify(n)+\" instead.\");return n}catch(t){return this._warningHistory[t.message]||(this._warningHistory[t.message]=!0,\"undefined\"!=typeof console&&console.warn(t.message)),this._defaultValue}};var zr=function(t,e){this.kind=t,this._styleExpression=e,this.isStateDependent=\"constant\"!==t&&!we(e.expression)};zr.prototype.evaluateWithoutErrorHandling=function(t,e,r){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r)},zr.prototype.evaluate=function(t,e,r){return this._styleExpression.evaluate(t,e,r)};var Ir=function(t,e,r){this.kind=t,this.zoomStops=r.labels,this._styleExpression=e,this.isStateDependent=\"camera\"!==t&&!we(e.expression),r instanceof Xe&&(this.interpolationType=r.interpolation)};function Dr(t,e){if(\"error\"===(t=Or(t,e)).result)return t;var r=t.value.expression,n=_e(r);if(!n&&!xr(e))return yr([new Ut(\"\",\"data expressions not supported\")]);var i=ke(r,[\"zoom\"]);if(!i&&!br(e))return yr([new Ut(\"\",\"zoom expressions not supported\")]);var a=function t(e){var r=null;if(e instanceof Ke)r=t(e.result);else if(e instanceof Je)for(var n=0,i=e.args;n<i.length;n+=1){var a=i[n];if(r=t(a))break}else(e instanceof Se||e instanceof Xe)&&e.input instanceof xe&&\"zoom\"===e.input.name&&(r=e);return r instanceof Ut?r:(e.eachChild(function(e){var n=t(e);n instanceof Ut?r=n:!r&&n?r=new Ut(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.'):r&&n&&r!==n&&(r=new Ut(\"\",'Only one zoom-based \"step\" or \"interpolate\" subexpression may be used in an expression.'))}),r)}(r);return a||i?a instanceof Ut?yr([a]):a instanceof Xe&&!_r(e)?yr([new Ut(\"\",'\"interpolate\" expressions cannot be used with this property')]):mr(a?new Ir(n?\"camera\":\"composite\",t.value,a):new zr(n?\"constant\":\"source\",t.value)):yr([new Ut(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.')])}Ir.prototype.evaluateWithoutErrorHandling=function(t,e,r){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r)},Ir.prototype.evaluate=function(t,e,r){return this._styleExpression.evaluate(t,e,r)},Ir.prototype.interpolationFactor=function(t,e,r){return this.interpolationType?Xe.interpolationFactor(this.interpolationType,t,e,r):0};var Rr=function(t,e){this._parameters=t,this._specification=e,Ft(this,function t(e,r){var n,i,a,o=\"color\"===r.type,s=e.stops&&\"object\"==typeof e.stops[0][0],l=s||void 0!==e.property,c=s||!l,u=e.type||(_r(r)?\"exponential\":\"interval\");if(o&&((e=Ft({},e)).stops&&(e.stops=e.stops.map(function(t){return[t[0],ne.parse(t[1])]})),e.default?e.default=ne.parse(e.default):e.default=ne.parse(r.default)),e.colorSpace&&\"rgb\"!==e.colorSpace&&!We[e.colorSpace])throw new Error(\"Unknown color space: \"+e.colorSpace);if(\"exponential\"===u)n=Er;else if(\"interval\"===u)n=Sr;else if(\"categorical\"===u){n=Mr,i=Object.create(null);for(var h=0,f=e.stops;h<f.length;h+=1){var p=f[h];i[p[0]]=p[1]}a=typeof e.stops[0][0]}else{if(\"identity\"!==u)throw new Error('Unknown function type \"'+u+'\"');n=Cr}if(s){for(var d={},g=[],v=0;v<e.stops.length;v++){var m=e.stops[v],y=m[0].zoom;void 0===d[y]&&(d[y]={zoom:y,type:e.type,property:e.property,default:e.default,stops:[]},g.push(y)),d[y].stops.push([m[0].value,m[1]])}for(var x=[],b=0,_=g;b<_.length;b+=1){var w=_[b];x.push([d[w].zoom,t(d[w],r)])}var k={name:\"linear\"};return{kind:\"composite\",interpolationType:k,interpolationFactor:Xe.interpolationFactor.bind(void 0,k),zoomStops:x.map(function(t){return t[0]}),evaluate:function(t,n){var i=t.zoom;return Er({stops:x,base:e.base},r,i).evaluate(i,n)}}}if(c){var T=\"exponential\"===u?{name:\"exponential\",base:void 0!==e.base?e.base:1}:null;return{kind:\"camera\",interpolationType:T,interpolationFactor:Xe.interpolationFactor.bind(void 0,T),zoomStops:e.stops.map(function(t){return t[0]}),evaluate:function(t){var o=t.zoom;return n(e,r,o,i,a)}}}return{kind:\"source\",evaluate:function(t,o){var s=o&&o.properties?o.properties[e.property]:void 0;return void 0===s?Ar(e.default,r.default):n(e,r,s,i,a)}}}(this._parameters,this._specification))};function Fr(t){var e=t.key,r=t.value,n=t.valueSpec||{},i=t.objectElementValidators||{},a=t.style,o=t.styleSpec,s=[],l=wr(r);if(\"object\"!==l)return[new Dt(e,r,\"object expected, \"+l+\" found\")];for(var c in r){var u=c.split(\".\")[0],h=n[u]||n[\"*\"],f=void 0;if(i[u])f=i[u];else if(n[u])f=ln;else if(i[\"*\"])f=i[\"*\"];else{if(!n[\"*\"]){s.push(new Dt(e,r[c],'unknown property \"'+c+'\"'));continue}f=ln}s=s.concat(f({key:(e?e+\".\":e)+c,value:r[c],valueSpec:h,style:a,styleSpec:o,object:r,objectKey:c},r))}for(var p in n)i[p]||n[p].required&&void 0===n[p].default&&void 0===r[p]&&s.push(new Dt(e,r,'missing required property \"'+p+'\"'));return s}function Br(t){var e=t.value,r=t.valueSpec,n=t.style,i=t.styleSpec,a=t.key,o=t.arrayElementValidator||ln;if(\"array\"!==wr(e))return[new Dt(a,e,\"array expected, \"+wr(e)+\" found\")];if(r.length&&e.length!==r.length)return[new Dt(a,e,\"array length \"+r.length+\" expected, length \"+e.length+\" found\")];if(r[\"min-length\"]&&e.length<r[\"min-length\"])return[new Dt(a,e,\"array length at least \"+r[\"min-length\"]+\" expected, length \"+e.length+\" found\")];var s={type:r.value,values:r.values};i.$version<7&&(s.function=r.function),\"object\"===wr(r.value)&&(s=r.value);for(var l=[],c=0;c<e.length;c++)l=l.concat(o({array:e,arrayIndex:c,value:e[c],valueSpec:s,style:n,styleSpec:i,key:a+\"[\"+c+\"]\"}));return l}function Nr(t){var e=t.key,r=t.value,n=t.valueSpec,i=wr(r);return\"number\"!==i?[new Dt(e,r,\"number expected, \"+i+\" found\")]:\"minimum\"in n&&r<n.minimum?[new Dt(e,r,r+\" is less than the minimum value \"+n.minimum)]:\"maximum\"in n&&r>n.maximum?[new Dt(e,r,r+\" is greater than the maximum value \"+n.maximum)]:[]}function jr(t){var e,r,n,i=t.valueSpec,a=Nt(t.value.type),o={},s=\"categorical\"!==a&&void 0===t.value.property,l=!s,c=\"array\"===wr(t.value.stops)&&\"array\"===wr(t.value.stops[0])&&\"object\"===wr(t.value.stops[0][0]),u=Fr({key:t.key,value:t.value,valueSpec:t.styleSpec.function,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{stops:function(t){if(\"identity\"===a)return[new Dt(t.key,t.value,'identity function may not have a \"stops\" property')];var e=[],r=t.value;return e=e.concat(Br({key:t.key,value:r,valueSpec:t.valueSpec,style:t.style,styleSpec:t.styleSpec,arrayElementValidator:h})),\"array\"===wr(r)&&0===r.length&&e.push(new Dt(t.key,r,\"array must have at least one stop\")),e},default:function(t){return ln({key:t.key,value:t.value,valueSpec:i,style:t.style,styleSpec:t.styleSpec})}}});return\"identity\"===a&&s&&u.push(new Dt(t.key,t.value,'missing required property \"property\"')),\"identity\"===a||t.value.stops||u.push(new Dt(t.key,t.value,'missing required property \"stops\"')),\"exponential\"===a&&t.valueSpec.expression&&!_r(t.valueSpec)&&u.push(new Dt(t.key,t.value,\"exponential functions not supported\")),t.styleSpec.$version>=8&&(l&&!xr(t.valueSpec)?u.push(new Dt(t.key,t.value,\"property functions not supported\")):s&&!br(t.valueSpec)&&u.push(new Dt(t.key,t.value,\"zoom functions not supported\"))),\"categorical\"!==a&&!c||void 0!==t.value.property||u.push(new Dt(t.key,t.value,'\"property\" property is required')),u;function h(t){var e=[],a=t.value,s=t.key;if(\"array\"!==wr(a))return[new Dt(s,a,\"array expected, \"+wr(a)+\" found\")];if(2!==a.length)return[new Dt(s,a,\"array length 2 expected, length \"+a.length+\" found\")];if(c){if(\"object\"!==wr(a[0]))return[new Dt(s,a,\"object expected, \"+wr(a[0])+\" found\")];if(void 0===a[0].zoom)return[new Dt(s,a,\"object stop key must have zoom\")];if(void 0===a[0].value)return[new Dt(s,a,\"object stop key must have value\")];if(n&&n>Nt(a[0].zoom))return[new Dt(s,a[0].zoom,\"stop zoom values must appear in ascending order\")];Nt(a[0].zoom)!==n&&(n=Nt(a[0].zoom),r=void 0,o={}),e=e.concat(Fr({key:s+\"[0]\",value:a[0],valueSpec:{zoom:{}},style:t.style,styleSpec:t.styleSpec,objectElementValidators:{zoom:Nr,value:f}}))}else e=e.concat(f({key:s+\"[0]\",value:a[0],valueSpec:{},style:t.style,styleSpec:t.styleSpec},a));return Pr(jt(a[1]))?e.concat([new Dt(s+\"[1]\",a[1],\"expressions are not allowed in function stops.\")]):e.concat(ln({key:s+\"[1]\",value:a[1],valueSpec:i,style:t.style,styleSpec:t.styleSpec}))}function f(t,n){var s=wr(t.value),l=Nt(t.value),c=null!==t.value?t.value:n;if(e){if(s!==e)return[new Dt(t.key,c,s+\" stop domain type must match previous stop domain type \"+e)]}else e=s;if(\"number\"!==s&&\"string\"!==s&&\"boolean\"!==s)return[new Dt(t.key,c,\"stop domain value must be a number, string, or boolean\")];if(\"number\"!==s&&\"categorical\"!==a){var u=\"number expected, \"+s+\" found\";return xr(i)&&void 0===a&&(u+='\\nIf you intended to use a categorical function, specify `\"type\": \"categorical\"`.'),[new Dt(t.key,c,u)]}return\"categorical\"!==a||\"number\"!==s||isFinite(l)&&Math.floor(l)===l?\"categorical\"!==a&&\"number\"===s&&void 0!==r&&l<r?[new Dt(t.key,c,\"stop domain values must appear in ascending order\")]:(r=l,\"categorical\"===a&&l in o?[new Dt(t.key,c,\"stop domain values must be unique\")]:(o[l]=!0,[])):[new Dt(t.key,c,\"integer expected, found \"+l)]}}function Ur(t){var e=(\"property\"===t.expressionContext?Dr:Or)(jt(t.value),t.valueSpec);if(\"error\"===e.result)return e.value.map(function(e){return new Dt(\"\"+t.key+e.key,t.value,e.message)});var r=e.value.expression||e.value._styleExpression.expression;if(\"property\"===t.expressionContext&&\"text-font\"===t.propertyKey&&-1!==r.possibleOutputs().indexOf(void 0))return[new Dt(t.key,t.value,'Invalid data expression for \"'+t.propertyKey+'\". Output values must be contained as literals within the expression.')];if(\"property\"===t.expressionContext&&\"layout\"===t.propertyType&&!we(r))return[new Dt(t.key,t.value,'\"feature-state\" data expressions are not supported with layout properties.')];if(\"filter\"===t.expressionContext&&!we(r))return[new Dt(t.key,t.value,'\"feature-state\" data expressions are not supported with filters.')];if(t.expressionContext&&0===t.expressionContext.indexOf(\"cluster\")){if(!ke(r,[\"zoom\",\"feature-state\"]))return[new Dt(t.key,t.value,'\"zoom\" and \"feature-state\" expressions are not supported with cluster properties.')];if(\"cluster-initial\"===t.expressionContext&&!_e(r))return[new Dt(t.key,t.value,\"Feature data expressions are not supported with initial expression part of cluster properties.\")]}return[]}function Vr(t){var e=t.key,r=t.value,n=t.valueSpec,i=[];return Array.isArray(n.values)?-1===n.values.indexOf(Nt(r))&&i.push(new Dt(e,r,\"expected one of [\"+n.values.join(\", \")+\"], \"+JSON.stringify(r)+\" found\")):-1===Object.keys(n.values).indexOf(Nt(r))&&i.push(new Dt(e,r,\"expected one of [\"+Object.keys(n.values).join(\", \")+\"], \"+JSON.stringify(r)+\" found\")),i}function qr(t){if(!0===t||!1===t)return!0;if(!Array.isArray(t)||0===t.length)return!1;switch(t[0]){case\"has\":return t.length>=2&&\"$id\"!==t[1]&&\"$type\"!==t[1];case\"in\":case\"!in\":case\"!has\":case\"none\":return!1;case\"==\":case\"!=\":case\">\":case\">=\":case\"<\":case\"<=\":return 3!==t.length||Array.isArray(t[1])||Array.isArray(t[2]);case\"any\":case\"all\":for(var e=0,r=t.slice(1);e<r.length;e+=1){var n=r[e];if(!qr(n)&&\"boolean\"!=typeof n)return!1}return!0;default:return!0}}Rr.deserialize=function(t){return new Rr(t._parameters,t._specification)},Rr.serialize=function(t){return{_parameters:t._parameters,_specification:t._specification}};var Hr={type:\"boolean\",default:!1,transition:!1,\"property-type\":\"data-driven\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]}};function Gr(t){if(null==t)return function(){return!0};qr(t)||(t=Wr(t));var e=Or(t,Hr);if(\"error\"===e.result)throw new Error(e.value.map(function(t){return t.key+\": \"+t.message}).join(\", \"));return function(t,r){return e.value.evaluate(t,r)}}function Yr(t,e){return t<e?-1:t>e?1:0}function Wr(t){if(!t)return!0;var e,r=t[0];return t.length<=1?\"any\"!==r:\"==\"===r?Xr(t[1],t[2],\"==\"):\"!=\"===r?Kr(Xr(t[1],t[2],\"==\")):\"<\"===r||\">\"===r||\"<=\"===r||\">=\"===r?Xr(t[1],t[2],r):\"any\"===r?(e=t.slice(1),[\"any\"].concat(e.map(Wr))):\"all\"===r?[\"all\"].concat(t.slice(1).map(Wr)):\"none\"===r?[\"all\"].concat(t.slice(1).map(Wr).map(Kr)):\"in\"===r?Zr(t[1],t.slice(2)):\"!in\"===r?Kr(Zr(t[1],t.slice(2))):\"has\"===r?Jr(t[1]):\"!has\"!==r||Kr(Jr(t[1]))}function Xr(t,e,r){switch(t){case\"$type\":return[\"filter-type-\"+r,e];case\"$id\":return[\"filter-id-\"+r,e];default:return[\"filter-\"+r,t,e]}}function Zr(t,e){if(0===e.length)return!1;switch(t){case\"$type\":return[\"filter-type-in\",[\"literal\",e]];case\"$id\":return[\"filter-id-in\",[\"literal\",e]];default:return e.length>200&&!e.some(function(t){return typeof t!=typeof e[0]})?[\"filter-in-large\",t,[\"literal\",e.sort(Yr)]]:[\"filter-in-small\",t,[\"literal\",e]]}}function Jr(t){switch(t){case\"$type\":return!0;case\"$id\":return[\"filter-has-id\"];default:return[\"filter-has\",t]}}function Kr(t){return[\"!\",t]}function $r(t){return qr(jt(t.value))?Ur(Ft({},t,{expressionContext:\"filter\",valueSpec:{value:\"boolean\"}})):function t(e){var r=e.value,n=e.key;if(\"array\"!==wr(r))return[new Dt(n,r,\"array expected, \"+wr(r)+\" found\")];var i,a=e.styleSpec,o=[];if(r.length<1)return[new Dt(n,r,\"filter array must have at least 1 element\")];switch(o=o.concat(Vr({key:n+\"[0]\",value:r[0],valueSpec:a.filter_operator,style:e.style,styleSpec:e.styleSpec})),Nt(r[0])){case\"<\":case\"<=\":case\">\":case\">=\":r.length>=2&&\"$type\"===Nt(r[1])&&o.push(new Dt(n,r,'\"$type\" cannot be use with operator \"'+r[0]+'\"'));case\"==\":case\"!=\":3!==r.length&&o.push(new Dt(n,r,'filter array for operator \"'+r[0]+'\" must have 3 elements'));case\"in\":case\"!in\":r.length>=2&&\"string\"!==(i=wr(r[1]))&&o.push(new Dt(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"));for(var s=2;s<r.length;s++)i=wr(r[s]),\"$type\"===Nt(r[1])?o=o.concat(Vr({key:n+\"[\"+s+\"]\",value:r[s],valueSpec:a.geometry_type,style:e.style,styleSpec:e.styleSpec})):\"string\"!==i&&\"number\"!==i&&\"boolean\"!==i&&o.push(new Dt(n+\"[\"+s+\"]\",r[s],\"string, number, or boolean expected, \"+i+\" found\"));break;case\"any\":case\"all\":case\"none\":for(var l=1;l<r.length;l++)o=o.concat(t({key:n+\"[\"+l+\"]\",value:r[l],style:e.style,styleSpec:e.styleSpec}));break;case\"has\":case\"!has\":i=wr(r[1]),2!==r.length?o.push(new Dt(n,r,'filter array for \"'+r[0]+'\" operator must have 2 elements')):\"string\"!==i&&o.push(new Dt(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"))}return o}(t)}function Qr(t,e){var r=t.key,n=t.style,i=t.styleSpec,a=t.value,o=t.objectKey,s=i[e+\"_\"+t.layerType];if(!s)return[];var l=o.match(/^(.*)-transition$/);if(\"paint\"===e&&l&&s[l[1]]&&s[l[1]].transition)return ln({key:r,value:a,valueSpec:i.transition,style:n,styleSpec:i});var c,u=t.valueSpec||s[o];if(!u)return[new Dt(r,a,'unknown property \"'+o+'\"')];if(\"string\"===wr(a)&&xr(u)&&!u.tokens&&(c=/^{([^}]+)}$/.exec(a)))return[new Dt(r,a,'\"'+o+'\" does not support interpolation syntax\\nUse an identity property function instead: `{ \"type\": \"identity\", \"property\": '+JSON.stringify(c[1])+\" }`.\")];var h=[];return\"symbol\"===t.layerType&&(\"text-field\"===o&&n&&!n.glyphs&&h.push(new Dt(r,a,'use of \"text-field\" requires a style \"glyphs\" property')),\"text-font\"===o&&kr(jt(a))&&\"identity\"===Nt(a.type)&&h.push(new Dt(r,a,'\"text-font\" does not support identity functions'))),h.concat(ln({key:t.key,value:a,valueSpec:u,style:n,styleSpec:i,expressionContext:\"property\",propertyType:e,propertyKey:o}))}function tn(t){return Qr(t,\"paint\")}function en(t){return Qr(t,\"layout\")}function rn(t){var e=[],r=t.value,n=t.key,i=t.style,a=t.styleSpec;r.type||r.ref||e.push(new Dt(n,r,'either \"type\" or \"ref\" is required'));var o,s=Nt(r.type),l=Nt(r.ref);if(r.id)for(var c=Nt(r.id),u=0;u<t.arrayIndex;u++){var h=i.layers[u];Nt(h.id)===c&&e.push(new Dt(n,r.id,'duplicate layer id \"'+r.id+'\", previously used at line '+h.id.__line__))}if(\"ref\"in r)[\"type\",\"source\",\"source-layer\",\"filter\",\"layout\"].forEach(function(t){t in r&&e.push(new Dt(n,r[t],'\"'+t+'\" is prohibited for ref layers'))}),i.layers.forEach(function(t){Nt(t.id)===l&&(o=t)}),o?o.ref?e.push(new Dt(n,r.ref,\"ref cannot reference another ref layer\")):s=Nt(o.type):e.push(new Dt(n,r.ref,'ref layer \"'+l+'\" not found'));else if(\"background\"!==s)if(r.source){var f=i.sources&&i.sources[r.source],p=f&&Nt(f.type);f?\"vector\"===p&&\"raster\"===s?e.push(new Dt(n,r.source,'layer \"'+r.id+'\" requires a raster source')):\"raster\"===p&&\"raster\"!==s?e.push(new Dt(n,r.source,'layer \"'+r.id+'\" requires a vector source')):\"vector\"!==p||r[\"source-layer\"]?\"raster-dem\"===p&&\"hillshade\"!==s?e.push(new Dt(n,r.source,\"raster-dem source can only be used with layer type 'hillshade'.\")):\"line\"!==s||!r.paint||!r.paint[\"line-gradient\"]||\"geojson\"===p&&f.lineMetrics||e.push(new Dt(n,r,'layer \"'+r.id+'\" specifies a line-gradient, which requires a GeoJSON source with `lineMetrics` enabled.')):e.push(new Dt(n,r,'layer \"'+r.id+'\" must specify a \"source-layer\"')):e.push(new Dt(n,r.source,'source \"'+r.source+'\" not found'))}else e.push(new Dt(n,r,'missing required property \"source\"'));return e=e.concat(Fr({key:n,value:r,valueSpec:a.layer,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(){return[]},type:function(){return ln({key:n+\".type\",value:r.type,valueSpec:a.layer.type,style:t.style,styleSpec:t.styleSpec,object:r,objectKey:\"type\"})},filter:$r,layout:function(t){return Fr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return en(Ft({layerType:s},t))}}})},paint:function(t){return Fr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return tn(Ft({layerType:s},t))}}})}}}))}function nn(t){var e=t.value,r=t.key,n=t.styleSpec,i=t.style;if(!e.type)return[new Dt(r,e,'\"type\" is required')];var a,o=Nt(e.type);switch(o){case\"vector\":case\"raster\":case\"raster-dem\":if(a=Fr({key:r,value:e,valueSpec:n[\"source_\"+o.replace(\"-\",\"_\")],style:t.style,styleSpec:n}),\"url\"in e)for(var s in e)[\"type\",\"url\",\"tileSize\"].indexOf(s)<0&&a.push(new Dt(r+\".\"+s,e[s],'a source with a \"url\" property may not include a \"'+s+'\" property'));return a;case\"geojson\":if(a=Fr({key:r,value:e,valueSpec:n.source_geojson,style:i,styleSpec:n}),e.cluster)for(var l in e.clusterProperties){var c=e.clusterProperties[l],u=c[0],h=c[1],f=\"string\"==typeof u?[u,[\"accumulated\"],[\"get\",l]]:u;a.push.apply(a,Ur({key:r+\".\"+l+\".map\",value:h,expressionContext:\"cluster-map\"})),a.push.apply(a,Ur({key:r+\".\"+l+\".reduce\",value:f,expressionContext:\"cluster-reduce\"}))}return a;case\"video\":return Fr({key:r,value:e,valueSpec:n.source_video,style:i,styleSpec:n});case\"image\":return Fr({key:r,value:e,valueSpec:n.source_image,style:i,styleSpec:n});case\"canvas\":return[new Dt(r,null,\"Please use runtime APIs to add canvas sources, rather than including them in stylesheets.\",\"source.canvas\")];default:return Vr({key:r+\".type\",value:e.type,valueSpec:{values:[\"vector\",\"raster\",\"raster-dem\",\"geojson\",\"video\",\"image\"]},style:i,styleSpec:n})}}function an(t){var e=t.value,r=t.styleSpec,n=r.light,i=t.style,a=[],o=wr(e);if(void 0===e)return a;if(\"object\"!==o)return a.concat([new Dt(\"light\",e,\"object expected, \"+o+\" found\")]);for(var s in e){var l=s.match(/^(.*)-transition$/);a=l&&n[l[1]]&&n[l[1]].transition?a.concat(ln({key:s,value:e[s],valueSpec:r.transition,style:i,styleSpec:r})):n[s]?a.concat(ln({key:s,value:e[s],valueSpec:n[s],style:i,styleSpec:r})):a.concat([new Dt(s,e[s],'unknown property \"'+s+'\"')])}return a}function on(t){var e=t.value,r=t.key,n=wr(e);return\"string\"!==n?[new Dt(r,e,\"string expected, \"+n+\" found\")]:[]}var sn={\"*\":function(){return[]},array:Br,boolean:function(t){var e=t.value,r=t.key,n=wr(e);return\"boolean\"!==n?[new Dt(r,e,\"boolean expected, \"+n+\" found\")]:[]},number:Nr,color:function(t){var e=t.key,r=t.value,n=wr(r);return\"string\"!==n?[new Dt(e,r,\"color expected, \"+n+\" found\")]:null===re(r)?[new Dt(e,r,'color expected, \"'+r+'\" found')]:[]},constants:Rt,enum:Vr,filter:$r,function:jr,layer:rn,object:Fr,source:nn,light:an,string:on,formatted:function(t){return 0===on(t).length?[]:Ur(t)}};function ln(t){var e=t.value,r=t.valueSpec,n=t.styleSpec;return r.expression&&kr(Nt(e))?jr(t):r.expression&&Pr(jt(e))?Ur(t):r.type&&sn[r.type]?sn[r.type](t):Fr(Ft({},t,{valueSpec:r.type?n[r.type]:r}))}function cn(t){var e=t.value,r=t.key,n=on(t);return n.length?n:(-1===e.indexOf(\"{fontstack}\")&&n.push(new Dt(r,e,'\"glyphs\" url must include a \"{fontstack}\" token')),-1===e.indexOf(\"{range}\")&&n.push(new Dt(r,e,'\"glyphs\" url must include a \"{range}\" token')),n)}function un(t,e){e=e||It;var r=[];return r=r.concat(ln({key:\"\",value:t,valueSpec:e.$root,styleSpec:e,style:t,objectElementValidators:{glyphs:cn,\"*\":function(){return[]}}})),t.constants&&(r=r.concat(Rt({key:\"constants\",value:t.constants,style:t,styleSpec:e}))),hn(r)}function hn(t){return[].concat(t).sort(function(t,e){return t.line-e.line})}function fn(t){return function(){for(var e=[],r=arguments.length;r--;)e[r]=arguments[r];return hn(t.apply(this,e))}}un.source=fn(nn),un.light=fn(an),un.layer=fn(rn),un.filter=fn($r),un.paintProperty=fn(tn),un.layoutProperty=fn(en);var pn=un,dn=pn.light,gn=pn.paintProperty,vn=pn.layoutProperty;function mn(t,e){var r=!1;if(e&&e.length)for(var n=0,i=e;n<i.length;n+=1){var a=i[n];t.fire(new Ot(new Error(a.message))),r=!0}return r}var yn=bn,xn=3;function bn(t,e,r){var n=this.cells=[];if(t instanceof ArrayBuffer){this.arrayBuffer=t;var i=new Int32Array(this.arrayBuffer);t=i[0],e=i[1],r=i[2],this.d=e+2*r;for(var a=0;a<this.d*this.d;a++){var o=i[xn+a],s=i[xn+a+1];n.push(o===s?null:i.subarray(o,s))}var l=i[xn+n.length],c=i[xn+n.length+1];this.keys=i.subarray(l,c),this.bboxes=i.subarray(c),this.insert=this._insertReadonly}else{this.d=e+2*r;for(var u=0;u<this.d*this.d;u++)n.push([]);this.keys=[],this.bboxes=[]}this.n=e,this.extent=t,this.padding=r,this.scale=e/t,this.uid=0;var h=r/e*t;this.min=-h,this.max=t+h}bn.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertCell,this.uid++),this.keys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},bn.prototype._insertReadonly=function(){throw\"Cannot insert into a GridIndex created from an ArrayBuffer.\"},bn.prototype._insertCell=function(t,e,r,n,i,a){this.cells[i].push(a)},bn.prototype.query=function(t,e,r,n,i){var a=this.min,o=this.max;if(t<=a&&e<=a&&o<=r&&o<=n&&!i)return Array.prototype.slice.call(this.keys);var s=[];return this._forEachCell(t,e,r,n,this._queryCell,s,{},i),s},bn.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=this.cells[i];if(null!==l)for(var c=this.keys,u=this.bboxes,h=0;h<l.length;h++){var f=l[h];if(void 0===o[f]){var p=4*f;(s?s(u[p+0],u[p+1],u[p+2],u[p+3]):t<=u[p+2]&&e<=u[p+3]&&r>=u[p+0]&&n>=u[p+1])?(o[f]=!0,a.push(c[f])):o[f]=!1}}},bn.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToCellCoord(t),c=this._convertToCellCoord(e),u=this._convertToCellCoord(r),h=this._convertToCellCoord(n),f=l;f<=u;f++)for(var p=c;p<=h;p++){var d=this.d*p+f;if((!s||s(this._convertFromCellCoord(f),this._convertFromCellCoord(p),this._convertFromCellCoord(f+1),this._convertFromCellCoord(p+1)))&&i.call(this,t,e,r,n,d,a,o,s))return}},bn.prototype._convertFromCellCoord=function(t){return(t-this.padding)/this.scale},bn.prototype._convertToCellCoord=function(t){return Math.max(0,Math.min(this.d-1,Math.floor(t*this.scale)+this.padding))},bn.prototype.toArrayBuffer=function(){if(this.arrayBuffer)return this.arrayBuffer;for(var t=this.cells,e=xn+this.cells.length+1+1,r=0,n=0;n<this.cells.length;n++)r+=this.cells[n].length;var i=new Int32Array(e+r+this.keys.length+this.bboxes.length);i[0]=this.extent,i[1]=this.n,i[2]=this.padding;for(var a=e,o=0;o<t.length;o++){var s=t[o];i[xn+o]=a,i.set(s,a),a+=s.length}return i[xn+t.length]=a,i.set(this.keys,a),a+=this.keys.length,i[xn+t.length+1]=a,i.set(this.bboxes,a),a+=this.bboxes.length,i.buffer};var _n=self.ImageData,wn={};function kn(t,e,r){void 0===r&&(r={}),Object.defineProperty(e,\"_classRegistryKey\",{value:t,writeable:!1}),wn[t]={klass:e,omit:r.omit||[],shallow:r.shallow||[]}}for(var Tn in kn(\"Object\",Object),yn.serialize=function(t,e){var r=t.toArrayBuffer();return e&&e.push(r),{buffer:r}},yn.deserialize=function(t){return new yn(t.buffer)},kn(\"Grid\",yn),kn(\"Color\",ne),kn(\"Error\",Error),kn(\"StylePropertyFunction\",Rr),kn(\"StyleExpression\",Lr,{omit:[\"_evaluator\"]}),kn(\"ZoomDependentExpression\",Ir),kn(\"ZoomConstantExpression\",zr),kn(\"CompoundExpression\",xe,{omit:[\"_evaluate\"]}),fr)fr[Tn]._classRegistryKey||kn(\"Expression_\"+Tn,fr[Tn]);function An(t,e){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp)return t;if(t instanceof ArrayBuffer)return e&&e.push(t),t;if(ArrayBuffer.isView(t)){var r=t;return e&&e.push(r.buffer),r}if(t instanceof _n)return e&&e.push(t.data.buffer),t;if(Array.isArray(t)){for(var n=[],i=0,a=t;i<a.length;i+=1){var o=a[i];n.push(An(o,e))}return n}if(\"object\"==typeof t){var s=t.constructor,l=s._classRegistryKey;if(!l)throw new Error(\"can't serialize object of unregistered class\");var c=s.serialize?s.serialize(t,e):{};if(!s.serialize){for(var u in t)if(t.hasOwnProperty(u)&&!(wn[l].omit.indexOf(u)>=0)){var h=t[u];c[u]=wn[l].shallow.indexOf(u)>=0?h:An(h,e)}t instanceof Error&&(c.message=t.message)}if(c.$name)throw new Error(\"$name property is reserved for worker serialization logic.\");return\"Object\"!==l&&(c.$name=l),c}throw new Error(\"can't serialize object of type \"+typeof t)}function Mn(t){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp||t instanceof ArrayBuffer||ArrayBuffer.isView(t)||t instanceof _n)return t;if(Array.isArray(t))return t.map(Mn);if(\"object\"==typeof t){var e=t.$name||\"Object\",r=wn[e].klass;if(!r)throw new Error(\"can't deserialize unregistered class \"+e);if(r.deserialize)return r.deserialize(t);for(var n=Object.create(r.prototype),i=0,a=Object.keys(t);i<a.length;i+=1){var o=a[i];if(\"$name\"!==o){var s=t[o];n[o]=wn[e].shallow.indexOf(o)>=0?s:Mn(s)}}return n}throw new Error(\"can't deserialize object of type \"+typeof t)}var Sn=function(){this.first=!0};Sn.prototype.update=function(t,e){var r=Math.floor(t);return this.first?(this.first=!1,this.lastIntegerZoom=r,this.lastIntegerZoomTime=0,this.lastZoom=t,this.lastFloorZoom=r,!0):(this.lastFloorZoom>r?(this.lastIntegerZoom=r+1,this.lastIntegerZoomTime=e):this.lastFloorZoom<r&&(this.lastIntegerZoom=r,this.lastIntegerZoomTime=e),t!==this.lastZoom&&(this.lastZoom=t,this.lastFloorZoom=r,!0))};var En={\"Latin-1 Supplement\":function(t){return t>=128&&t<=255},Arabic:function(t){return t>=1536&&t<=1791},\"Arabic Supplement\":function(t){return t>=1872&&t<=1919},\"Arabic Extended-A\":function(t){return t>=2208&&t<=2303},\"Hangul Jamo\":function(t){return t>=4352&&t<=4607},\"Unified Canadian Aboriginal Syllabics\":function(t){return t>=5120&&t<=5759},Khmer:function(t){return t>=6016&&t<=6143},\"Unified Canadian Aboriginal Syllabics Extended\":function(t){return t>=6320&&t<=6399},\"General Punctuation\":function(t){return t>=8192&&t<=8303},\"Letterlike Symbols\":function(t){return t>=8448&&t<=8527},\"Number Forms\":function(t){return t>=8528&&t<=8591},\"Miscellaneous Technical\":function(t){return t>=8960&&t<=9215},\"Control Pictures\":function(t){return t>=9216&&t<=9279},\"Optical Character Recognition\":function(t){return t>=9280&&t<=9311},\"Enclosed Alphanumerics\":function(t){return t>=9312&&t<=9471},\"Geometric Shapes\":function(t){return t>=9632&&t<=9727},\"Miscellaneous Symbols\":function(t){return t>=9728&&t<=9983},\"Miscellaneous Symbols and Arrows\":function(t){return t>=11008&&t<=11263},\"CJK Radicals Supplement\":function(t){return t>=11904&&t<=12031},\"Kangxi Radicals\":function(t){return t>=12032&&t<=12255},\"Ideographic Description Characters\":function(t){return t>=12272&&t<=12287},\"CJK Symbols and Punctuation\":function(t){return t>=12288&&t<=12351},Hiragana:function(t){return t>=12352&&t<=12447},Katakana:function(t){return t>=12448&&t<=12543},Bopomofo:function(t){return t>=12544&&t<=12591},\"Hangul Compatibility Jamo\":function(t){return t>=12592&&t<=12687},Kanbun:function(t){return t>=12688&&t<=12703},\"Bopomofo Extended\":function(t){return t>=12704&&t<=12735},\"CJK Strokes\":function(t){return t>=12736&&t<=12783},\"Katakana Phonetic Extensions\":function(t){return t>=12784&&t<=12799},\"Enclosed CJK Letters and Months\":function(t){return t>=12800&&t<=13055},\"CJK Compatibility\":function(t){return t>=13056&&t<=13311},\"CJK Unified Ideographs Extension A\":function(t){return t>=13312&&t<=19903},\"Yijing Hexagram Symbols\":function(t){return t>=19904&&t<=19967},\"CJK Unified Ideographs\":function(t){return t>=19968&&t<=40959},\"Yi Syllables\":function(t){return t>=40960&&t<=42127},\"Yi Radicals\":function(t){return t>=42128&&t<=42191},\"Hangul Jamo Extended-A\":function(t){return t>=43360&&t<=43391},\"Hangul Syllables\":function(t){return t>=44032&&t<=55215},\"Hangul Jamo Extended-B\":function(t){return t>=55216&&t<=55295},\"Private Use Area\":function(t){return t>=57344&&t<=63743},\"CJK Compatibility Ideographs\":function(t){return t>=63744&&t<=64255},\"Arabic Presentation Forms-A\":function(t){return t>=64336&&t<=65023},\"Vertical Forms\":function(t){return t>=65040&&t<=65055},\"CJK Compatibility Forms\":function(t){return t>=65072&&t<=65103},\"Small Form Variants\":function(t){return t>=65104&&t<=65135},\"Arabic Presentation Forms-B\":function(t){return t>=65136&&t<=65279},\"Halfwidth and Fullwidth Forms\":function(t){return t>=65280&&t<=65519}};function Cn(t){for(var e=0,r=t;e<r.length;e+=1)if(On(r[e].charCodeAt(0)))return!0;return!1}function Ln(t){for(var e=0,r=t;e<r.length;e+=1)if(!Pn(r[e].charCodeAt(0)))return!1;return!0}function Pn(t){return!(En.Arabic(t)||En[\"Arabic Supplement\"](t)||En[\"Arabic Extended-A\"](t)||En[\"Arabic Presentation Forms-A\"](t)||En[\"Arabic Presentation Forms-B\"](t))}function On(t){return!!(746===t||747===t||!(t<4352)&&(En[\"Bopomofo Extended\"](t)||En.Bopomofo(t)||En[\"CJK Compatibility Forms\"](t)&&!(t>=65097&&t<=65103)||En[\"CJK Compatibility Ideographs\"](t)||En[\"CJK Compatibility\"](t)||En[\"CJK Radicals Supplement\"](t)||En[\"CJK Strokes\"](t)||!(!En[\"CJK Symbols and Punctuation\"](t)||t>=12296&&t<=12305||t>=12308&&t<=12319||12336===t)||En[\"CJK Unified Ideographs Extension A\"](t)||En[\"CJK Unified Ideographs\"](t)||En[\"Enclosed CJK Letters and Months\"](t)||En[\"Hangul Compatibility Jamo\"](t)||En[\"Hangul Jamo Extended-A\"](t)||En[\"Hangul Jamo Extended-B\"](t)||En[\"Hangul Jamo\"](t)||En[\"Hangul Syllables\"](t)||En.Hiragana(t)||En[\"Ideographic Description Characters\"](t)||En.Kanbun(t)||En[\"Kangxi Radicals\"](t)||En[\"Katakana Phonetic Extensions\"](t)||En.Katakana(t)&&12540!==t||!(!En[\"Halfwidth and Fullwidth Forms\"](t)||65288===t||65289===t||65293===t||t>=65306&&t<=65310||65339===t||65341===t||65343===t||t>=65371&&t<=65503||65507===t||t>=65512&&t<=65519)||!(!En[\"Small Form Variants\"](t)||t>=65112&&t<=65118||t>=65123&&t<=65126)||En[\"Unified Canadian Aboriginal Syllabics\"](t)||En[\"Unified Canadian Aboriginal Syllabics Extended\"](t)||En[\"Vertical Forms\"](t)||En[\"Yijing Hexagram Symbols\"](t)||En[\"Yi Syllables\"](t)||En[\"Yi Radicals\"](t)))}function zn(t){return!(On(t)||function(t){return!!(En[\"Latin-1 Supplement\"](t)&&(167===t||169===t||174===t||177===t||188===t||189===t||190===t||215===t||247===t)||En[\"General Punctuation\"](t)&&(8214===t||8224===t||8225===t||8240===t||8241===t||8251===t||8252===t||8258===t||8263===t||8264===t||8265===t||8273===t)||En[\"Letterlike Symbols\"](t)||En[\"Number Forms\"](t)||En[\"Miscellaneous Technical\"](t)&&(t>=8960&&t<=8967||t>=8972&&t<=8991||t>=8996&&t<=9e3||9003===t||t>=9085&&t<=9114||t>=9150&&t<=9165||9167===t||t>=9169&&t<=9179||t>=9186&&t<=9215)||En[\"Control Pictures\"](t)&&9251!==t||En[\"Optical Character Recognition\"](t)||En[\"Enclosed Alphanumerics\"](t)||En[\"Geometric Shapes\"](t)||En[\"Miscellaneous Symbols\"](t)&&!(t>=9754&&t<=9759)||En[\"Miscellaneous Symbols and Arrows\"](t)&&(t>=11026&&t<=11055||t>=11088&&t<=11097||t>=11192&&t<=11243)||En[\"CJK Symbols and Punctuation\"](t)||En.Katakana(t)||En[\"Private Use Area\"](t)||En[\"CJK Compatibility Forms\"](t)||En[\"Small Form Variants\"](t)||En[\"Halfwidth and Fullwidth Forms\"](t)||8734===t||8756===t||8757===t||t>=9984&&t<=10087||t>=10102&&t<=10131||65532===t||65533===t)}(t))}function In(t,e){return!(!e&&(t>=1424&&t<=2303||En[\"Arabic Presentation Forms-A\"](t)||En[\"Arabic Presentation Forms-B\"](t))||t>=2304&&t<=3583||t>=3840&&t<=4255||En.Khmer(t))}var Dn,Rn=!1,Fn=null,Bn=!1,Nn=new zt,jn={applyArabicShaping:null,processBidirectionalText:null,processStyledBidirectionalText:null,isLoaded:function(){return Bn||null!=jn.applyArabicShaping}},Un=function(t,e){this.zoom=t,e?(this.now=e.now,this.fadeDuration=e.fadeDuration,this.zoomHistory=e.zoomHistory,this.transition=e.transition):(this.now=0,this.fadeDuration=0,this.zoomHistory=new Sn,this.transition={})};Un.prototype.isSupportedScript=function(t){return function(t,e){for(var r=0,n=t;r<n.length;r+=1)if(!In(n[r].charCodeAt(0),e))return!1;return!0}(t,jn.isLoaded())},Un.prototype.crossFadingFactor=function(){return 0===this.fadeDuration?1:Math.min((this.now-this.zoomHistory.lastIntegerZoomTime)/this.fadeDuration,1)},Un.prototype.getCrossfadeParameters=function(){var t=this.zoom,e=t-Math.floor(t),r=this.crossFadingFactor();return t>this.zoomHistory.lastIntegerZoom?{fromScale:2,toScale:1,t:e+(1-e)*r}:{fromScale:.5,toScale:1,t:1-(1-r)*e}};var Vn=function(t,e){this.property=t,this.value=e,this.expression=function(t,e){if(kr(t))return new Rr(t,e);if(Pr(t)){var r=Dr(t,e);if(\"error\"===r.result)throw new Error(r.value.map(function(t){return t.key+\": \"+t.message}).join(\", \"));return r.value}var n=t;return\"string\"==typeof t&&\"color\"===e.type&&(n=ne.parse(t)),{kind:\"constant\",evaluate:function(){return n}}}(void 0===e?t.specification.default:e,t.specification)};Vn.prototype.isDataDriven=function(){return\"source\"===this.expression.kind||\"composite\"===this.expression.kind},Vn.prototype.possiblyEvaluate=function(t){return this.property.possiblyEvaluate(this,t)};var qn=function(t){this.property=t,this.value=new Vn(t,void 0)};qn.prototype.transitioned=function(t,e){return new Gn(this.property,this.value,e,h({},t.transition,this.transition),t.now)},qn.prototype.untransitioned=function(){return new Gn(this.property,this.value,null,{},0)};var Hn=function(t){this._properties=t,this._values=Object.create(t.defaultTransitionablePropertyValues)};Hn.prototype.getValue=function(t){return b(this._values[t].value.value)},Hn.prototype.setValue=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new qn(this._values[t].property)),this._values[t].value=new Vn(this._values[t].property,null===e?void 0:b(e))},Hn.prototype.getTransition=function(t){return b(this._values[t].transition)},Hn.prototype.setTransition=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new qn(this._values[t].property)),this._values[t].transition=b(e)||void 0},Hn.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i);var a=this.getTransition(n);void 0!==a&&(t[n+\"-transition\"]=a)}return t},Hn.prototype.transitioned=function(t,e){for(var r=new Yn(this._properties),n=0,i=Object.keys(this._values);n<i.length;n+=1){var a=i[n];r._values[a]=this._values[a].transitioned(t,e._values[a])}return r},Hn.prototype.untransitioned=function(){for(var t=new Yn(this._properties),e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e];t._values[n]=this._values[n].untransitioned()}return t};var Gn=function(t,e,r,n,i){this.property=t,this.value=e,this.begin=i+n.delay||0,this.end=this.begin+n.duration||0,t.specification.transition&&(n.delay||n.duration)&&(this.prior=r)};Gn.prototype.possiblyEvaluate=function(t){var e=t.now||0,r=this.value.possiblyEvaluate(t),n=this.prior;if(n){if(e>this.end)return this.prior=null,r;if(this.value.isDataDriven())return this.prior=null,r;if(e<this.begin)return n.possiblyEvaluate(t);var i=(e-this.begin)/(this.end-this.begin);return this.property.interpolate(n.possiblyEvaluate(t),r,function(t){if(i<=0)return 0;if(i>=1)return 1;var e=i*i,r=e*i;return 4*(i<.5?r:3*(i-e)+r-.75)}())}return r};var Yn=function(t){this._properties=t,this._values=Object.create(t.defaultTransitioningPropertyValues)};Yn.prototype.possiblyEvaluate=function(t){for(var e=new Zn(this._properties),r=0,n=Object.keys(this._values);r<n.length;r+=1){var i=n[r];e._values[i]=this._values[i].possiblyEvaluate(t)}return e},Yn.prototype.hasTransition=function(){for(var t=0,e=Object.keys(this._values);t<e.length;t+=1){var r=e[t];if(this._values[r].prior)return!0}return!1};var Wn=function(t){this._properties=t,this._values=Object.create(t.defaultPropertyValues)};Wn.prototype.getValue=function(t){return b(this._values[t].value)},Wn.prototype.setValue=function(t,e){this._values[t]=new Vn(this._values[t].property,null===e?void 0:b(e))},Wn.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i)}return t},Wn.prototype.possiblyEvaluate=function(t){for(var e=new Zn(this._properties),r=0,n=Object.keys(this._values);r<n.length;r+=1){var i=n[r];e._values[i]=this._values[i].possiblyEvaluate(t)}return e};var Xn=function(t,e,r){this.property=t,this.value=e,this.parameters=r};Xn.prototype.isConstant=function(){return\"constant\"===this.value.kind},Xn.prototype.constantOr=function(t){return\"constant\"===this.value.kind?this.value.value:t},Xn.prototype.evaluate=function(t,e){return this.property.evaluate(this.value,this.parameters,t,e)};var Zn=function(t){this._properties=t,this._values=Object.create(t.defaultPossiblyEvaluatedValues)};Zn.prototype.get=function(t){return this._values[t]};var Jn=function(t){this.specification=t};Jn.prototype.possiblyEvaluate=function(t,e){return t.expression.evaluate(e)},Jn.prototype.interpolate=function(t,e,r){var n=Ce[this.specification.type];return n?n(t,e,r):t};var Kn=function(t){this.specification=t};Kn.prototype.possiblyEvaluate=function(t,e){return\"constant\"===t.expression.kind||\"camera\"===t.expression.kind?new Xn(this,{kind:\"constant\",value:t.expression.evaluate(e)},e):new Xn(this,t.expression,e)},Kn.prototype.interpolate=function(t,e,r){if(\"constant\"!==t.value.kind||\"constant\"!==e.value.kind)return t;if(void 0===t.value.value||void 0===e.value.value)return new Xn(this,{kind:\"constant\",value:void 0},t.parameters);var n=Ce[this.specification.type];return n?new Xn(this,{kind:\"constant\",value:n(t.value.value,e.value.value,r)},t.parameters):t},Kn.prototype.evaluate=function(t,e,r,n){return\"constant\"===t.kind?t.value:t.evaluate(e,r,n)};var $n=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(t,e){if(void 0===t.value)return new Xn(this,{kind:\"constant\",value:void 0},e);if(\"constant\"===t.expression.kind){var r=t.expression.evaluate(e),n=this._calculate(r,r,r,e);return new Xn(this,{kind:\"constant\",value:n},e)}if(\"camera\"===t.expression.kind){var i=this._calculate(t.expression.evaluate({zoom:e.zoom-1}),t.expression.evaluate({zoom:e.zoom}),t.expression.evaluate({zoom:e.zoom+1}),e);return new Xn(this,{kind:\"constant\",value:i},e)}return new Xn(this,t.expression,e)},e.prototype.evaluate=function(t,e,r,n){if(\"source\"===t.kind){var i=t.evaluate(e,r,n);return this._calculate(i,i,i,e)}return\"composite\"===t.kind?this._calculate(t.evaluate({zoom:Math.floor(e.zoom)-1},r,n),t.evaluate({zoom:Math.floor(e.zoom)},r,n),t.evaluate({zoom:Math.floor(e.zoom)+1},r,n),e):t.value},e.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},e.prototype.interpolate=function(t){return t},e}(Kn),Qn=function(t){this.specification=t};Qn.prototype.possiblyEvaluate=function(t,e){if(void 0!==t.value){if(\"constant\"===t.expression.kind){var r=t.expression.evaluate(e);return this._calculate(r,r,r,e)}return this._calculate(t.expression.evaluate(new Un(Math.floor(e.zoom-1),e)),t.expression.evaluate(new Un(Math.floor(e.zoom),e)),t.expression.evaluate(new Un(Math.floor(e.zoom+1),e)),e)}},Qn.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},Qn.prototype.interpolate=function(t){return t};var ti=function(t){this.specification=t};ti.prototype.possiblyEvaluate=function(t,e){return!!t.expression.evaluate(e)},ti.prototype.interpolate=function(){return!1};var ei=function(t){for(var e in this.properties=t,this.defaultPropertyValues={},this.defaultTransitionablePropertyValues={},this.defaultTransitioningPropertyValues={},this.defaultPossiblyEvaluatedValues={},t){var r=t[e],n=this.defaultPropertyValues[e]=new Vn(r,void 0),i=this.defaultTransitionablePropertyValues[e]=new qn(r);this.defaultTransitioningPropertyValues[e]=i.untransitioned(),this.defaultPossiblyEvaluatedValues[e]=n.possiblyEvaluate({})}};kn(\"DataDrivenProperty\",Kn),kn(\"DataConstantProperty\",Jn),kn(\"CrossFadedDataDrivenProperty\",$n),kn(\"CrossFadedProperty\",Qn),kn(\"ColorRampProperty\",ti);var ri=function(t){function e(e,r){if(t.call(this),this.id=e.id,this.type=e.type,this._featureFilter=function(){return!0},\"custom\"!==e.type&&(e=e,this.metadata=e.metadata,this.minzoom=e.minzoom,this.maxzoom=e.maxzoom,\"background\"!==e.type&&(this.source=e.source,this.sourceLayer=e[\"source-layer\"],this.filter=e.filter),r.layout&&(this._unevaluatedLayout=new Wn(r.layout)),r.paint)){for(var n in this._transitionablePaint=new Hn(r.paint),e.paint)this.setPaintProperty(n,e.paint[n],{validate:!1});for(var i in e.layout)this.setLayoutProperty(i,e.layout[i],{validate:!1});this._transitioningPaint=this._transitionablePaint.untransitioned()}}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getCrossfadeParameters=function(){return this._crossfadeParameters},e.prototype.getLayoutProperty=function(t){return\"visibility\"===t?this.visibility:this._unevaluatedLayout.getValue(t)},e.prototype.setLayoutProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e){var n=\"layers.\"+this.id+\".layout.\"+t;if(this._validate(vn,n,t,e,r))return}\"visibility\"!==t?this._unevaluatedLayout.setValue(t,e):this.visibility=e},e.prototype.getPaintProperty=function(t){return m(t,\"-transition\")?this._transitionablePaint.getTransition(t.slice(0,-\"-transition\".length)):this._transitionablePaint.getValue(t)},e.prototype.setPaintProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e){var n=\"layers.\"+this.id+\".paint.\"+t;if(this._validate(gn,n,t,e,r))return!1}if(m(t,\"-transition\"))return this._transitionablePaint.setTransition(t.slice(0,-\"-transition\".length),e||void 0),!1;var i=this._transitionablePaint._values[t],a=\"cross-faded-data-driven\"===i.property.specification[\"property-type\"],o=i.value.isDataDriven();return this._transitionablePaint.setValue(t,e),this._handleSpecialPaintPropertyUpdate(t),this._transitionablePaint._values[t].value.isDataDriven()||o||a},e.prototype._handleSpecialPaintPropertyUpdate=function(t){},e.prototype.isHidden=function(t){return!!(this.minzoom&&t<this.minzoom)||!!(this.maxzoom&&t>=this.maxzoom)||\"none\"===this.visibility},e.prototype.updateTransitions=function(t){this._transitioningPaint=this._transitionablePaint.transitioned(t,this._transitioningPaint)},e.prototype.hasTransition=function(){return this._transitioningPaint.hasTransition()},e.prototype.recalculate=function(t){t.getCrossfadeParameters&&(this._crossfadeParameters=t.getCrossfadeParameters()),this._unevaluatedLayout&&(this.layout=this._unevaluatedLayout.possiblyEvaluate(t)),this.paint=this._transitioningPaint.possiblyEvaluate(t)},e.prototype.serialize=function(){var t={id:this.id,type:this.type,source:this.source,\"source-layer\":this.sourceLayer,metadata:this.metadata,minzoom:this.minzoom,maxzoom:this.maxzoom,filter:this.filter,layout:this._unevaluatedLayout&&this._unevaluatedLayout.serialize(),paint:this._transitionablePaint&&this._transitionablePaint.serialize()};return this.visibility&&(t.layout=t.layout||{},t.layout.visibility=this.visibility),x(t,function(t,e){return!(void 0===t||\"layout\"===e&&!Object.keys(t).length||\"paint\"===e&&!Object.keys(t).length)})},e.prototype._validate=function(t,e,r,n,i){return void 0===i&&(i={}),(!i||!1!==i.validate)&&mn(this,t.call(pn,{key:e,layerType:this.type,objectKey:r,value:n,styleSpec:It,style:{glyphs:!0,sprite:!0}}))},e.prototype.is3D=function(){return!1},e.prototype.isTileClipped=function(){return!1},e.prototype.hasOffscreenPass=function(){return!1},e.prototype.resize=function(){},e.prototype.isStateDependent=function(){for(var t in this.paint._values){var e=this.paint.get(t);if(e instanceof Xn&&xr(e.property.specification)&&(\"source\"===e.value.kind||\"composite\"===e.value.kind)&&e.value.isStateDependent)return!0}return!1},e}(zt),ni={Int8:Int8Array,Uint8:Uint8Array,Int16:Int16Array,Uint16:Uint16Array,Int32:Int32Array,Uint32:Uint32Array,Float32:Float32Array},ii=function(t,e){this._structArray=t,this._pos1=e*this.size,this._pos2=this._pos1/2,this._pos4=this._pos1/4,this._pos8=this._pos1/8},ai=function(){this.isTransferred=!1,this.capacity=-1,this.resize(0)};function oi(t,e){void 0===e&&(e=1);var r=0,n=0;return{members:t.map(function(t){var i,a=(i=t.type,ni[i].BYTES_PER_ELEMENT),o=r=si(r,Math.max(e,a)),s=t.components||1;return n=Math.max(n,a),r+=a*s,{name:t.name,type:t.type,components:s,offset:o}}),size:si(r,Math.max(n,e)),alignment:e}}function si(t,e){return Math.ceil(t/e)*e}ai.serialize=function(t,e){return t._trim(),e&&(t.isTransferred=!0,e.push(t.arrayBuffer)),{length:t.length,arrayBuffer:t.arrayBuffer}},ai.deserialize=function(t){var e=Object.create(this.prototype);return e.arrayBuffer=t.arrayBuffer,e.length=t.length,e.capacity=t.arrayBuffer.byteLength/e.bytesPerElement,e._refreshViews(),e},ai.prototype._trim=function(){this.length!==this.capacity&&(this.capacity=this.length,this.arrayBuffer=this.arrayBuffer.slice(0,this.length*this.bytesPerElement),this._refreshViews())},ai.prototype.clear=function(){this.length=0},ai.prototype.resize=function(t){this.reserve(t),this.length=t},ai.prototype.reserve=function(t){if(t>this.capacity){this.capacity=Math.max(t,Math.floor(5*this.capacity),128),this.arrayBuffer=new ArrayBuffer(this.capacity*this.bytesPerElement);var e=this.uint8;this._refreshViews(),e&&this.uint8.set(e)}},ai.prototype._refreshViews=function(){throw new Error(\"_refreshViews() must be implemented by each concrete StructArray layout\")};var li=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.int16[n+0]=e,this.int16[n+1]=r,t},e}(ai);li.prototype.bytesPerElement=4,kn(\"StructArrayLayout2i4\",li);var ci=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.int16[a+0]=e,this.int16[a+1]=r,this.int16[a+2]=n,this.int16[a+3]=i,t},e}(ai);ci.prototype.bytesPerElement=8,kn(\"StructArrayLayout4i8\",ci);var ui=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(ai);ui.prototype.bytesPerElement=12,kn(\"StructArrayLayout2i4i12\",ui);var hi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=4*t,l=8*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.uint8[l+4]=n,this.uint8[l+5]=i,this.uint8[l+6]=a,this.uint8[l+7]=o,t},e}(ai);hi.prototype.bytesPerElement=8,kn(\"StructArrayLayout2i4ub8\",hi);var fi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s){var l=this.length;return this.resize(l+1),this.emplace(l,t,e,r,n,i,a,o,s)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l){var c=8*t;return this.uint16[c+0]=e,this.uint16[c+1]=r,this.uint16[c+2]=n,this.uint16[c+3]=i,this.uint16[c+4]=a,this.uint16[c+5]=o,this.uint16[c+6]=s,this.uint16[c+7]=l,t},e}(ai);fi.prototype.bytesPerElement=16,kn(\"StructArrayLayout8ui16\",fi);var pi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s){var l=this.length;return this.resize(l+1),this.emplace(l,t,e,r,n,i,a,o,s)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l){var c=8*t;return this.int16[c+0]=e,this.int16[c+1]=r,this.int16[c+2]=n,this.int16[c+3]=i,this.uint16[c+4]=a,this.uint16[c+5]=o,this.uint16[c+6]=s,this.uint16[c+7]=l,t},e}(ai);pi.prototype.bytesPerElement=16,kn(\"StructArrayLayout4i4ui16\",pi);var di=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.float32[i+0]=e,this.float32[i+1]=r,this.float32[i+2]=n,t},e}(ai);di.prototype.bytesPerElement=12,kn(\"StructArrayLayout3f12\",di);var gi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.uint32[r+0]=e,t},e}(ai);gi.prototype.bytesPerElement=4,kn(\"StructArrayLayout1ul4\",gi);var vi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u){var h=this.length;return this.resize(h+1),this.emplace(h,t,e,r,n,i,a,o,s,l,c,u)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h){var f=12*t,p=6*t;return this.int16[f+0]=e,this.int16[f+1]=r,this.int16[f+2]=n,this.int16[f+3]=i,this.int16[f+4]=a,this.int16[f+5]=o,this.uint32[p+3]=s,this.uint16[f+8]=l,this.uint16[f+9]=c,this.int16[f+10]=u,this.int16[f+11]=h,t},e}(ai);vi.prototype.bytesPerElement=24,kn(\"StructArrayLayout6i1ul2ui2i24\",vi);var mi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(ai);mi.prototype.bytesPerElement=12,kn(\"StructArrayLayout2i2i2i12\",mi);var yi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=12*t,o=3*t;return this.uint8[a+0]=e,this.uint8[a+1]=r,this.float32[o+1]=n,this.float32[o+2]=i,t},e}(ai);yi.prototype.bytesPerElement=12,kn(\"StructArrayLayout2ub2f12\",yi);var xi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d){var g=this.length;return this.resize(g+1),this.emplace(g,t,e,r,n,i,a,o,s,l,c,u,h,f,p,d)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g){var v=22*t,m=11*t,y=44*t;return this.int16[v+0]=e,this.int16[v+1]=r,this.uint16[v+2]=n,this.uint16[v+3]=i,this.uint32[m+2]=a,this.uint32[m+3]=o,this.uint32[m+4]=s,this.uint16[v+10]=l,this.uint16[v+11]=c,this.uint16[v+12]=u,this.float32[m+7]=h,this.float32[m+8]=f,this.uint8[y+36]=p,this.uint8[y+37]=d,this.uint32[m+10]=g,t},e}(ai);xi.prototype.bytesPerElement=44,kn(\"StructArrayLayout2i2ui3ul3ui2f2ub1ul44\",xi);var bi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m){var y=this.length;return this.resize(y+1),this.emplace(y,t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m,y){var x=22*t,b=11*t;return this.int16[x+0]=e,this.int16[x+1]=r,this.int16[x+2]=n,this.int16[x+3]=i,this.int16[x+4]=a,this.int16[x+5]=o,this.uint16[x+6]=s,this.uint16[x+7]=l,this.uint16[x+8]=c,this.uint16[x+9]=u,this.uint16[x+10]=h,this.uint16[x+11]=f,this.uint16[x+12]=p,this.uint16[x+13]=d,this.uint16[x+14]=g,this.uint32[b+8]=v,this.float32[b+9]=m,this.float32[b+10]=y,t},e}(ai);bi.prototype.bytesPerElement=44,kn(\"StructArrayLayout6i9ui1ul2f44\",bi);var _i=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.float32[r+0]=e,t},e}(ai);_i.prototype.bytesPerElement=4,kn(\"StructArrayLayout1f4\",_i);var wi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.int16[i+0]=e,this.int16[i+1]=r,this.int16[i+2]=n,t},e}(ai);wi.prototype.bytesPerElement=6,kn(\"StructArrayLayout3i6\",wi);var ki=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=2*t,a=4*t;return this.uint32[i+0]=e,this.uint16[a+2]=r,this.uint16[a+3]=n,t},e}(ai);ki.prototype.bytesPerElement=8,kn(\"StructArrayLayout1ul2ui8\",ki);var Ti=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.uint16[i+0]=e,this.uint16[i+1]=r,this.uint16[i+2]=n,t},e}(ai);Ti.prototype.bytesPerElement=6,kn(\"StructArrayLayout3ui6\",Ti);var Ai=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.uint16[n+0]=e,this.uint16[n+1]=r,t},e}(ai);Ai.prototype.bytesPerElement=4,kn(\"StructArrayLayout2ui4\",Ai);var Mi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.uint16[r+0]=e,t},e}(ai);Mi.prototype.bytesPerElement=2,kn(\"StructArrayLayout1ui2\",Mi);var Si=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.float32[n+0]=e,this.float32[n+1]=r,t},e}(ai);Si.prototype.bytesPerElement=8,kn(\"StructArrayLayout2f8\",Si);var Ei=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.float32[a+0]=e,this.float32[a+1]=r,this.float32[a+2]=n,this.float32[a+3]=i,t},e}(ai);Ei.prototype.bytesPerElement=16,kn(\"StructArrayLayout4f16\",Ei);var Ci=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorPointX:{configurable:!0},anchorPointY:{configurable:!0},x1:{configurable:!0},y1:{configurable:!0},x2:{configurable:!0},y2:{configurable:!0},featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0},radius:{configurable:!0},signedDistanceFromAnchor:{configurable:!0},anchorPoint:{configurable:!0}};return r.anchorPointX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorPointX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorPointY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorPointY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.x1.get=function(){return this._structArray.int16[this._pos2+2]},r.x1.set=function(t){this._structArray.int16[this._pos2+2]=t},r.y1.get=function(){return this._structArray.int16[this._pos2+3]},r.y1.set=function(t){this._structArray.int16[this._pos2+3]=t},r.x2.get=function(){return this._structArray.int16[this._pos2+4]},r.x2.set=function(t){this._structArray.int16[this._pos2+4]=t},r.y2.get=function(){return this._structArray.int16[this._pos2+5]},r.y2.set=function(t){this._structArray.int16[this._pos2+5]=t},r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.featureIndex.set=function(t){this._structArray.uint32[this._pos4+3]=t},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.sourceLayerIndex.set=function(t){this._structArray.uint16[this._pos2+8]=t},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.bucketIndex.set=function(t){this._structArray.uint16[this._pos2+9]=t},r.radius.get=function(){return this._structArray.int16[this._pos2+10]},r.radius.set=function(t){this._structArray.int16[this._pos2+10]=t},r.signedDistanceFromAnchor.get=function(){return this._structArray.int16[this._pos2+11]},r.signedDistanceFromAnchor.set=function(t){this._structArray.int16[this._pos2+11]=t},r.anchorPoint.get=function(){return new i(this.anchorPointX,this.anchorPointY)},Object.defineProperties(e.prototype,r),e}(ii);Ci.prototype.size=24;var Li=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Ci(this,t)},e}(vi);kn(\"CollisionBoxArray\",Li);var Pi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},glyphStartIndex:{configurable:!0},numGlyphs:{configurable:!0},vertexStartIndex:{configurable:!0},lineStartIndex:{configurable:!0},lineLength:{configurable:!0},segment:{configurable:!0},lowerSize:{configurable:!0},upperSize:{configurable:!0},lineOffsetX:{configurable:!0},lineOffsetY:{configurable:!0},writingMode:{configurable:!0},hidden:{configurable:!0},crossTileID:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.glyphStartIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.glyphStartIndex.set=function(t){this._structArray.uint16[this._pos2+2]=t},r.numGlyphs.get=function(){return this._structArray.uint16[this._pos2+3]},r.numGlyphs.set=function(t){this._structArray.uint16[this._pos2+3]=t},r.vertexStartIndex.get=function(){return this._structArray.uint32[this._pos4+2]},r.vertexStartIndex.set=function(t){this._structArray.uint32[this._pos4+2]=t},r.lineStartIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.lineStartIndex.set=function(t){this._structArray.uint32[this._pos4+3]=t},r.lineLength.get=function(){return this._structArray.uint32[this._pos4+4]},r.lineLength.set=function(t){this._structArray.uint32[this._pos4+4]=t},r.segment.get=function(){return this._structArray.uint16[this._pos2+10]},r.segment.set=function(t){this._structArray.uint16[this._pos2+10]=t},r.lowerSize.get=function(){return this._structArray.uint16[this._pos2+11]},r.lowerSize.set=function(t){this._structArray.uint16[this._pos2+11]=t},r.upperSize.get=function(){return this._structArray.uint16[this._pos2+12]},r.upperSize.set=function(t){this._structArray.uint16[this._pos2+12]=t},r.lineOffsetX.get=function(){return this._structArray.float32[this._pos4+7]},r.lineOffsetX.set=function(t){this._structArray.float32[this._pos4+7]=t},r.lineOffsetY.get=function(){return this._structArray.float32[this._pos4+8]},r.lineOffsetY.set=function(t){this._structArray.float32[this._pos4+8]=t},r.writingMode.get=function(){return this._structArray.uint8[this._pos1+36]},r.writingMode.set=function(t){this._structArray.uint8[this._pos1+36]=t},r.hidden.get=function(){return this._structArray.uint8[this._pos1+37]},r.hidden.set=function(t){this._structArray.uint8[this._pos1+37]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+10]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+10]=t},Object.defineProperties(e.prototype,r),e}(ii);Pi.prototype.size=44;var Oi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Pi(this,t)},e}(xi);kn(\"PlacedSymbolArray\",Oi);var zi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},rightJustifiedTextSymbolIndex:{configurable:!0},centerJustifiedTextSymbolIndex:{configurable:!0},leftJustifiedTextSymbolIndex:{configurable:!0},verticalPlacedTextSymbolIndex:{configurable:!0},key:{configurable:!0},textBoxStartIndex:{configurable:!0},textBoxEndIndex:{configurable:!0},iconBoxStartIndex:{configurable:!0},iconBoxEndIndex:{configurable:!0},featureIndex:{configurable:!0},numHorizontalGlyphVertices:{configurable:!0},numVerticalGlyphVertices:{configurable:!0},numIconVertices:{configurable:!0},crossTileID:{configurable:!0},textBoxScale:{configurable:!0},radialTextOffset:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.rightJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+2]},r.rightJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+2]=t},r.centerJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+3]},r.centerJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+3]=t},r.leftJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+4]},r.leftJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+4]=t},r.verticalPlacedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+5]},r.verticalPlacedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+5]=t},r.key.get=function(){return this._structArray.uint16[this._pos2+6]},r.key.set=function(t){this._structArray.uint16[this._pos2+6]=t},r.textBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+7]},r.textBoxStartIndex.set=function(t){this._structArray.uint16[this._pos2+7]=t},r.textBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.textBoxEndIndex.set=function(t){this._structArray.uint16[this._pos2+8]=t},r.iconBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.iconBoxStartIndex.set=function(t){this._structArray.uint16[this._pos2+9]=t},r.iconBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+10]},r.iconBoxEndIndex.set=function(t){this._structArray.uint16[this._pos2+10]=t},r.featureIndex.get=function(){return this._structArray.uint16[this._pos2+11]},r.featureIndex.set=function(t){this._structArray.uint16[this._pos2+11]=t},r.numHorizontalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+12]},r.numHorizontalGlyphVertices.set=function(t){this._structArray.uint16[this._pos2+12]=t},r.numVerticalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+13]},r.numVerticalGlyphVertices.set=function(t){this._structArray.uint16[this._pos2+13]=t},r.numIconVertices.get=function(){return this._structArray.uint16[this._pos2+14]},r.numIconVertices.set=function(t){this._structArray.uint16[this._pos2+14]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+8]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+8]=t},r.textBoxScale.get=function(){return this._structArray.float32[this._pos4+9]},r.textBoxScale.set=function(t){this._structArray.float32[this._pos4+9]=t},r.radialTextOffset.get=function(){return this._structArray.float32[this._pos4+10]},r.radialTextOffset.set=function(t){this._structArray.float32[this._pos4+10]=t},Object.defineProperties(e.prototype,r),e}(ii);zi.prototype.size=44;var Ii=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new zi(this,t)},e}(bi);kn(\"SymbolInstanceArray\",Ii);var Di=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={offsetX:{configurable:!0}};return r.offsetX.get=function(){return this._structArray.float32[this._pos4+0]},r.offsetX.set=function(t){this._structArray.float32[this._pos4+0]=t},Object.defineProperties(e.prototype,r),e}(ii);Di.prototype.size=4;var Ri=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getoffsetX=function(t){return this.float32[1*t+0]},e.prototype.get=function(t){return new Di(this,t)},e}(_i);kn(\"GlyphOffsetArray\",Ri);var Fi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={x:{configurable:!0},y:{configurable:!0},tileUnitDistanceFromAnchor:{configurable:!0}};return r.x.get=function(){return this._structArray.int16[this._pos2+0]},r.x.set=function(t){this._structArray.int16[this._pos2+0]=t},r.y.get=function(){return this._structArray.int16[this._pos2+1]},r.y.set=function(t){this._structArray.int16[this._pos2+1]=t},r.tileUnitDistanceFromAnchor.get=function(){return this._structArray.int16[this._pos2+2]},r.tileUnitDistanceFromAnchor.set=function(t){this._structArray.int16[this._pos2+2]=t},Object.defineProperties(e.prototype,r),e}(ii);Fi.prototype.size=6;var Bi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getx=function(t){return this.int16[3*t+0]},e.prototype.gety=function(t){return this.int16[3*t+1]},e.prototype.gettileUnitDistanceFromAnchor=function(t){return this.int16[3*t+2]},e.prototype.get=function(t){return new Fi(this,t)},e}(wi);kn(\"SymbolLineVertexArray\",Bi);var Ni=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0}};return r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+0]},r.featureIndex.set=function(t){this._structArray.uint32[this._pos4+0]=t},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.sourceLayerIndex.set=function(t){this._structArray.uint16[this._pos2+2]=t},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+3]},r.bucketIndex.set=function(t){this._structArray.uint16[this._pos2+3]=t},Object.defineProperties(e.prototype,r),e}(ii);Ni.prototype.size=8;var ji=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Ni(this,t)},e}(ki);kn(\"FeatureIndexArray\",ji);var Ui=oi([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,Vi=function(t){void 0===t&&(t=[]),this.segments=t};function qi(t,e){return 256*(t=c(Math.floor(t),0,255))+c(Math.floor(e),0,255)}Vi.prototype.prepareSegment=function(t,e,r,n){var i=this.segments[this.segments.length-1];return t>Vi.MAX_VERTEX_ARRAY_LENGTH&&w(\"Max vertices per segment is \"+Vi.MAX_VERTEX_ARRAY_LENGTH+\": bucket requested \"+t),(!i||i.vertexLength+t>Vi.MAX_VERTEX_ARRAY_LENGTH||i.sortKey!==n)&&(i={vertexOffset:e.length,primitiveOffset:r.length,vertexLength:0,primitiveLength:0},void 0!==n&&(i.sortKey=n),this.segments.push(i)),i},Vi.prototype.get=function(){return this.segments},Vi.prototype.destroy=function(){for(var t=0,e=this.segments;t<e.length;t+=1){var r=e[t];for(var n in r.vaos)r.vaos[n].destroy()}},Vi.simpleSegment=function(t,e,r,n){return new Vi([{vertexOffset:t,primitiveOffset:e,vertexLength:r,primitiveLength:n,vaos:{},sortKey:0}])},Vi.MAX_VERTEX_ARRAY_LENGTH=Math.pow(2,16)-1,kn(\"SegmentVector\",Vi);var Hi=function(){this.ids=[],this.positions=[],this.indexed=!1};function Gi(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}Hi.prototype.add=function(t,e,r,n){this.ids.push(t),this.positions.push(e,r,n)},Hi.prototype.getPositions=function(t){for(var e=0,r=this.ids.length-1;e<r;){var n=e+r>>1;this.ids[n]>=t?r=n:e=n+1}for(var i=[];this.ids[e]===t;){var a=this.positions[3*e],o=this.positions[3*e+1],s=this.positions[3*e+2];i.push({index:a,start:o,end:s}),e++}return i},Hi.serialize=function(t,e){var r=new Float64Array(t.ids),n=new Uint32Array(t.positions);return function t(e,r,n,i){if(!(n>=i)){for(var a=e[n+i>>1],o=n-1,s=i+1;;){do{o++}while(e[o]<a);do{s--}while(e[s]>a);if(o>=s)break;Gi(e,o,s),Gi(r,3*o,3*s),Gi(r,3*o+1,3*s+1),Gi(r,3*o+2,3*s+2)}t(e,r,n,s),t(e,r,s+1,i)}}(r,n,0,r.length-1),e.push(r.buffer,n.buffer),{ids:r,positions:n}},Hi.deserialize=function(t){var e=new Hi;return e.ids=t.ids,e.positions=t.positions,e.indexed=!0,e},kn(\"FeaturePositionMap\",Hi);var Yi=function(t,e){this.gl=t.gl,this.location=e},Wi=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1i(this.location,t))},e}(Yi),Xi=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1f(this.location,t))},e}(Yi),Zi=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]||(this.current=t,this.gl.uniform2f(this.location,t[0],t[1]))},e}(Yi),Ji=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]||(this.current=t,this.gl.uniform3f(this.location,t[0],t[1],t[2]))},e}(Yi),Ki=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]&&t[3]===this.current[3]||(this.current=t,this.gl.uniform4f(this.location,t[0],t[1],t[2],t[3]))},e}(Yi),$i=function(t){function e(e,r){t.call(this,e,r),this.current=ne.transparent}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t.r===this.current.r&&t.g===this.current.g&&t.b===this.current.b&&t.a===this.current.a||(this.current=t,this.gl.uniform4f(this.location,t.r,t.g,t.b,t.a))},e}(Yi),Qi=new Float32Array(16),ta=function(t){function e(e,r){t.call(this,e,r),this.current=Qi}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(t[12]!==this.current[12]||t[0]!==this.current[0])return this.current=t,void this.gl.uniformMatrix4fv(this.location,!1,t);for(var e=1;e<16;e++)if(t[e]!==this.current[e]){this.current=t,this.gl.uniformMatrix4fv(this.location,!1,t);break}},e}(Yi);function ea(t){return[qi(255*t.r,255*t.g),qi(255*t.b,255*t.a)]}var ra=function(t,e,r){this.value=t,this.names=e,this.uniformNames=this.names.map(function(t){return\"u_\"+t}),this.type=r,this.maxValue=-1/0};ra.prototype.defines=function(){return this.names.map(function(t){return\"#define HAS_UNIFORM_u_\"+t})},ra.prototype.setConstantPatternPositions=function(){},ra.prototype.populatePaintArray=function(){},ra.prototype.updatePaintArray=function(){},ra.prototype.upload=function(){},ra.prototype.destroy=function(){},ra.prototype.setUniforms=function(t,e,r,n){e.set(n.constantOr(this.value))},ra.prototype.getBinding=function(t,e){return\"color\"===this.type?new $i(t,e):new Xi(t,e)},ra.serialize=function(t){var e=t.value,r=t.names,n=t.type;return{value:An(e),names:r,type:n}},ra.deserialize=function(t){var e=t.value,r=t.names,n=t.type;return new ra(Mn(e),r,n)};var na=function(t,e,r){this.value=t,this.names=e,this.uniformNames=this.names.map(function(t){return\"u_\"+t}),this.type=r,this.maxValue=-1/0,this.patternPositions={patternTo:null,patternFrom:null}};na.prototype.defines=function(){return this.names.map(function(t){return\"#define HAS_UNIFORM_u_\"+t})},na.prototype.populatePaintArray=function(){},na.prototype.updatePaintArray=function(){},na.prototype.upload=function(){},na.prototype.destroy=function(){},na.prototype.setConstantPatternPositions=function(t,e){this.patternPositions.patternTo=t.tlbr,this.patternPositions.patternFrom=e.tlbr},na.prototype.setUniforms=function(t,e,r,n,i){var a=this.patternPositions;\"u_pattern_to\"===i&&a.patternTo&&e.set(a.patternTo),\"u_pattern_from\"===i&&a.patternFrom&&e.set(a.patternFrom)},na.prototype.getBinding=function(t,e){return new Ki(t,e)};var ia=function(t,e,r,n){this.expression=t,this.names=e,this.type=r,this.uniformNames=this.names.map(function(t){return\"a_\"+t}),this.maxValue=-1/0,this.paintVertexAttributes=e.map(function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?2:1,offset:0}}),this.paintVertexArray=new n};ia.prototype.defines=function(){return[]},ia.prototype.setConstantPatternPositions=function(){},ia.prototype.populatePaintArray=function(t,e){var r=this.paintVertexArray,n=r.length;r.reserve(t);var i=this.expression.evaluate(new Un(0),e,{});if(\"color\"===this.type)for(var a=ea(i),o=n;o<t;o++)r.emplaceBack(a[0],a[1]);else{for(var s=n;s<t;s++)r.emplaceBack(i);this.maxValue=Math.max(this.maxValue,i)}},ia.prototype.updatePaintArray=function(t,e,r,n){var i=this.paintVertexArray,a=this.expression.evaluate({zoom:0},r,n);if(\"color\"===this.type)for(var o=ea(a),s=t;s<e;s++)i.emplace(s,o[0],o[1]);else{for(var l=t;l<e;l++)i.emplace(l,a);this.maxValue=Math.max(this.maxValue,a)}},ia.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},ia.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},ia.prototype.setUniforms=function(t,e){e.set(0)},ia.prototype.getBinding=function(t,e){return new Xi(t,e)};var aa=function(t,e,r,n,i,a){this.expression=t,this.names=e,this.uniformNames=this.names.map(function(t){return\"u_\"+t+\"_t\"}),this.type=r,this.useIntegerZoom=n,this.zoom=i,this.maxValue=-1/0;var o=a;this.paintVertexAttributes=e.map(function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?4:2,offset:0}}),this.paintVertexArray=new o};aa.prototype.defines=function(){return[]},aa.prototype.setConstantPatternPositions=function(){},aa.prototype.populatePaintArray=function(t,e){var r=this.paintVertexArray,n=r.length;r.reserve(t);var i=this.expression.evaluate(new Un(this.zoom),e,{}),a=this.expression.evaluate(new Un(this.zoom+1),e,{});if(\"color\"===this.type)for(var o=ea(i),s=ea(a),l=n;l<t;l++)r.emplaceBack(o[0],o[1],s[0],s[1]);else{for(var c=n;c<t;c++)r.emplaceBack(i,a);this.maxValue=Math.max(this.maxValue,i,a)}},aa.prototype.updatePaintArray=function(t,e,r,n){var i=this.paintVertexArray,a=this.expression.evaluate({zoom:this.zoom},r,n),o=this.expression.evaluate({zoom:this.zoom+1},r,n);if(\"color\"===this.type)for(var s=ea(a),l=ea(o),c=t;c<e;c++)i.emplace(c,s[0],s[1],l[0],l[1]);else{for(var u=t;u<e;u++)i.emplace(u,a,o);this.maxValue=Math.max(this.maxValue,a,o)}},aa.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},aa.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},aa.prototype.interpolationFactor=function(t){return this.useIntegerZoom?this.expression.interpolationFactor(Math.floor(t),this.zoom,this.zoom+1):this.expression.interpolationFactor(t,this.zoom,this.zoom+1)},aa.prototype.setUniforms=function(t,e,r){e.set(this.interpolationFactor(r.zoom))},aa.prototype.getBinding=function(t,e){return new Xi(t,e)};var oa=function(t,e,r,n,i,a,o){this.expression=t,this.names=e,this.type=r,this.uniformNames=this.names.map(function(t){return\"u_\"+t+\"_t\"}),this.useIntegerZoom=n,this.zoom=i,this.maxValue=-1/0,this.layerId=o,this.paintVertexAttributes=e.map(function(t){return{name:\"a_\"+t,type:\"Uint16\",components:4,offset:0}}),this.zoomInPaintVertexArray=new a,this.zoomOutPaintVertexArray=new a};oa.prototype.defines=function(){return[]},oa.prototype.setConstantPatternPositions=function(){},oa.prototype.populatePaintArray=function(t,e,r){var n=this.zoomInPaintVertexArray,i=this.zoomOutPaintVertexArray,a=this.layerId,o=n.length;if(n.reserve(t),i.reserve(t),r&&e.patterns&&e.patterns[a]){var s=e.patterns[a],l=s.min,c=s.mid,u=s.max,h=r[l],f=r[c],p=r[u];if(!h||!f||!p)return;for(var d=o;d<t;d++)n.emplaceBack(f.tl[0],f.tl[1],f.br[0],f.br[1],h.tl[0],h.tl[1],h.br[0],h.br[1]),i.emplaceBack(f.tl[0],f.tl[1],f.br[0],f.br[1],p.tl[0],p.tl[1],p.br[0],p.br[1])}},oa.prototype.updatePaintArray=function(t,e,r,n,i){var a=this.zoomInPaintVertexArray,o=this.zoomOutPaintVertexArray,s=this.layerId;if(i&&r.patterns&&r.patterns[s]){var l=r.patterns[s],c=l.min,u=l.mid,h=l.max,f=i[c],p=i[u],d=i[h];if(!f||!p||!d)return;for(var g=t;g<e;g++)a.emplace(g,p.tl[0],p.tl[1],p.br[0],p.br[1],f.tl[0],f.tl[1],f.br[0],f.br[1]),o.emplace(g,p.tl[0],p.tl[1],p.br[0],p.br[1],d.tl[0],d.tl[1],d.br[0],d.br[1])}},oa.prototype.upload=function(t){this.zoomInPaintVertexArray&&this.zoomInPaintVertexArray.arrayBuffer&&this.zoomOutPaintVertexArray&&this.zoomOutPaintVertexArray.arrayBuffer&&(this.zoomInPaintVertexBuffer=t.createVertexBuffer(this.zoomInPaintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent),this.zoomOutPaintVertexBuffer=t.createVertexBuffer(this.zoomOutPaintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},oa.prototype.destroy=function(){this.zoomOutPaintVertexBuffer&&this.zoomOutPaintVertexBuffer.destroy(),this.zoomInPaintVertexBuffer&&this.zoomInPaintVertexBuffer.destroy()},oa.prototype.setUniforms=function(t,e){e.set(0)},oa.prototype.getBinding=function(t,e){return new Xi(t,e)};var sa=function(){this.binders={},this.cacheKey=\"\",this._buffers=[],this._featureMap=new Hi,this._bufferOffset=0};sa.createDynamic=function(t,e,r){var n=new sa,i=[];for(var a in t.paint._values)if(r(a)){var o=t.paint.get(a);if(o instanceof Xn&&xr(o.property.specification)){var s=ca(a,t.type),l=o.property.specification.type,c=o.property.useIntegerZoom;if(\"cross-faded\"===o.property.specification[\"property-type\"]||\"cross-faded-data-driven\"===o.property.specification[\"property-type\"])if(\"constant\"===o.value.kind)n.binders[a]=new na(o.value.value,s,l),i.push(\"/u_\"+a);else{var u=ua(a,l,\"source\");n.binders[a]=new oa(o.value,s,l,c,e,u,t.id),i.push(\"/a_\"+a)}else if(\"constant\"===o.value.kind)n.binders[a]=new ra(o.value.value,s,l),i.push(\"/u_\"+a);else if(\"source\"===o.value.kind){var h=ua(a,l,\"source\");n.binders[a]=new ia(o.value,s,l,h),i.push(\"/a_\"+a)}else{var f=ua(a,l,\"composite\");n.binders[a]=new aa(o.value,s,l,c,e,f),i.push(\"/z_\"+a)}}}return n.cacheKey=i.sort().join(\"\"),n},sa.prototype.populatePaintArrays=function(t,e,r,n){for(var i in this.binders)this.binders[i].populatePaintArray(t,e,n);void 0!==e.id&&this._featureMap.add(+e.id,r,this._bufferOffset,t),this._bufferOffset=t},sa.prototype.setConstantPatternPositions=function(t,e){for(var r in this.binders)this.binders[r].setConstantPatternPositions(t,e)},sa.prototype.updatePaintArrays=function(t,e,r,n){var i=!1;for(var a in t)for(var o=0,s=this._featureMap.getPositions(+a);o<s.length;o+=1){var l=s[o],c=e.feature(l.index);for(var u in this.binders){var h=this.binders[u];if(!(h instanceof ra||h instanceof na)&&!0===h.expression.isStateDependent){var f=r.paint.get(u);h.expression=f.value,h.updatePaintArray(l.start,l.end,c,t[a],n),i=!0}}}return i},sa.prototype.defines=function(){var t=[];for(var e in this.binders)t.push.apply(t,this.binders[e].defines());return t},sa.prototype.getPaintVertexBuffers=function(){return this._buffers},sa.prototype.getUniforms=function(t,e){var r=[];for(var n in this.binders)for(var i=this.binders[n],a=0,o=i.uniformNames;a<o.length;a+=1){var s=o[a];if(e[s]){var l=i.getBinding(t,e[s]);r.push({name:s,property:n,binding:l})}}return r},sa.prototype.setUniforms=function(t,e,r,n){for(var i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.name,l=o.property,c=o.binding;this.binders[l].setUniforms(t,c,n,r.get(l),s)}},sa.prototype.updatePatternPaintBuffers=function(t){var e=[];for(var r in this.binders){var n=this.binders[r];if(n instanceof oa){var i=2===t.fromScale?n.zoomInPaintVertexBuffer:n.zoomOutPaintVertexBuffer;i&&e.push(i)}else(n instanceof ia||n instanceof aa)&&n.paintVertexBuffer&&e.push(n.paintVertexBuffer)}this._buffers=e},sa.prototype.upload=function(t){for(var e in this.binders)this.binders[e].upload(t);var r=[];for(var n in this.binders){var i=this.binders[n];(i instanceof ia||i instanceof aa)&&i.paintVertexBuffer&&r.push(i.paintVertexBuffer)}this._buffers=r},sa.prototype.destroy=function(){for(var t in this.binders)this.binders[t].destroy()};var la=function(t,e,r,n){void 0===n&&(n=function(){return!0}),this.programConfigurations={};for(var i=0,a=e;i<a.length;i+=1){var o=a[i];this.programConfigurations[o.id]=sa.createDynamic(o,r,n),this.programConfigurations[o.id].layoutAttributes=t}this.needsUpload=!1};function ca(t,e){return{\"text-opacity\":[\"opacity\"],\"icon-opacity\":[\"opacity\"],\"text-color\":[\"fill_color\"],\"icon-color\":[\"fill_color\"],\"text-halo-color\":[\"halo_color\"],\"icon-halo-color\":[\"halo_color\"],\"text-halo-blur\":[\"halo_blur\"],\"icon-halo-blur\":[\"halo_blur\"],\"text-halo-width\":[\"halo_width\"],\"icon-halo-width\":[\"halo_width\"],\"line-gap-width\":[\"gapwidth\"],\"line-pattern\":[\"pattern_to\",\"pattern_from\"],\"fill-pattern\":[\"pattern_to\",\"pattern_from\"],\"fill-extrusion-pattern\":[\"pattern_to\",\"pattern_from\"]}[t]||[t.replace(e+\"-\",\"\").replace(/-/g,\"_\")]}function ua(t,e,r){var n={color:{source:Si,composite:Ei},number:{source:_i,composite:Si}},i=function(t){return{\"line-pattern\":{source:fi,composite:fi},\"fill-pattern\":{source:fi,composite:fi},\"fill-extrusion-pattern\":{source:fi,composite:fi}}[t]}(t);return i&&i[r]||n[e][r]}la.prototype.populatePaintArrays=function(t,e,r,n){for(var i in this.programConfigurations)this.programConfigurations[i].populatePaintArrays(t,e,r,n);this.needsUpload=!0},la.prototype.updatePaintArrays=function(t,e,r,n){for(var i=0,a=r;i<a.length;i+=1){var o=a[i];this.needsUpload=this.programConfigurations[o.id].updatePaintArrays(t,e,o,n)||this.needsUpload}},la.prototype.get=function(t){return this.programConfigurations[t]},la.prototype.upload=function(t){if(this.needsUpload){for(var e in this.programConfigurations)this.programConfigurations[e].upload(t);this.needsUpload=!1}},la.prototype.destroy=function(){for(var t in this.programConfigurations)this.programConfigurations[t].destroy()},kn(\"ConstantBinder\",ra),kn(\"CrossFadedConstantBinder\",na),kn(\"SourceExpressionBinder\",ia),kn(\"CrossFadedCompositeBinder\",oa),kn(\"CompositeExpressionBinder\",aa),kn(\"ProgramConfiguration\",sa,{omit:[\"_buffers\"]}),kn(\"ProgramConfigurationSet\",la);var ha=8192,fa=(16,{min:-1*Math.pow(2,15),max:Math.pow(2,15)-1});function pa(t){for(var e=ha/t.extent,r=t.loadGeometry(),n=0;n<r.length;n++)for(var i=r[n],a=0;a<i.length;a++){var o=i[a];o.x=Math.round(o.x*e),o.y=Math.round(o.y*e),(o.x<fa.min||o.x>fa.max||o.y<fa.min||o.y>fa.max)&&w(\"Geometry exceeds allowed extent, reduce your vector tile buffer size\")}return r}function da(t,e,r,n,i){t.emplaceBack(2*e+(n+1)/2,2*r+(i+1)/2)}var ga=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new li,this.indexArray=new Ti,this.segments=new Vi,this.programConfigurations=new la(Ui,t.layers,t.zoom),this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function va(t,e){for(var r=0;r<t.length;r++)if(Aa(e,t[r]))return!0;for(var n=0;n<e.length;n++)if(Aa(t,e[n]))return!0;return!!ba(t,e)}function ma(t,e,r){return!!Aa(t,e)||!!wa(e,t,r)}function ya(t,e){if(1===t.length)return Ta(e,t[0]);for(var r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++)if(Aa(t,n[i]))return!0;for(var a=0;a<t.length;a++)if(Ta(e,t[a]))return!0;for(var o=0;o<e.length;o++)if(ba(t,e[o]))return!0;return!1}function xa(t,e,r){if(t.length>1){if(ba(t,e))return!0;for(var n=0;n<e.length;n++)if(wa(e[n],t,r))return!0}for(var i=0;i<t.length;i++)if(wa(t[i],e,r))return!0;return!1}function ba(t,e){if(0===t.length||0===e.length)return!1;for(var r=0;r<t.length-1;r++)for(var n=t[r],i=t[r+1],a=0;a<e.length-1;a++)if(_a(n,i,e[a],e[a+1]))return!0;return!1}function _a(t,e,r,n){return k(t,r,n)!==k(e,r,n)&&k(t,e,r)!==k(t,e,n)}function wa(t,e,r){var n=r*r;if(1===e.length)return t.distSqr(e[0])<n;for(var i=1;i<e.length;i++)if(ka(t,e[i-1],e[i])<n)return!0;return!1}function ka(t,e,r){var n=e.distSqr(r);if(0===n)return t.distSqr(e);var i=((t.x-e.x)*(r.x-e.x)+(t.y-e.y)*(r.y-e.y))/n;return i<0?t.distSqr(e):i>1?t.distSqr(r):t.distSqr(r.sub(e)._mult(i)._add(e))}function Ta(t,e){for(var r,n,i,a=!1,o=0;o<t.length;o++)for(var s=0,l=(r=t[o]).length-1;s<r.length;l=s++)n=r[s],i=r[l],n.y>e.y!=i.y>e.y&&e.x<(i.x-n.x)*(e.y-n.y)/(i.y-n.y)+n.x&&(a=!a);return a}function Aa(t,e){for(var r=!1,n=0,i=t.length-1;n<t.length;i=n++){var a=t[n],o=t[i];a.y>e.y!=o.y>e.y&&e.x<(o.x-a.x)*(e.y-a.y)/(o.y-a.y)+a.x&&(r=!r)}return r}function Ma(t,e,r){var n=r[0],i=r[2];if(t.x<n.x&&e.x<n.x||t.x>i.x&&e.x>i.x||t.y<n.y&&e.y<n.y||t.y>i.y&&e.y>i.y)return!1;var a=k(t,e,r[0]);return a!==k(t,e,r[1])||a!==k(t,e,r[2])||a!==k(t,e,r[3])}function Sa(t,e,r){var n=e.paint.get(t).value;return\"constant\"===n.kind?n.value:r.programConfigurations.get(e.id).binders[t].maxValue}function Ea(t){return Math.sqrt(t[0]*t[0]+t[1]*t[1])}function Ca(t,e,r,n,a){if(!e[0]&&!e[1])return t;var o=i.convert(e)._mult(a);\"viewport\"===r&&o._rotate(-n);for(var s=[],l=0;l<t.length;l++){var c=t[l];s.push(c.sub(o))}return s}ga.prototype.populate=function(t,e){for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a);this.addFeature(a,l,o),e.featureIndex.insert(a,l,o,s,this.index)}}},ga.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},ga.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},ga.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},ga.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ui),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},ga.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},ga.prototype.addFeature=function(t,e,r){for(var n=0,i=e;n<i.length;n+=1)for(var a=0,o=i[n];a<o.length;a+=1){var s=o[a],l=s.x,c=s.y;if(!(l<0||l>=ha||c<0||c>=ha)){var u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),h=u.vertexLength;da(this.layoutVertexArray,l,c,-1,-1),da(this.layoutVertexArray,l,c,1,-1),da(this.layoutVertexArray,l,c,1,1),da(this.layoutVertexArray,l,c,-1,1),this.indexArray.emplaceBack(h,h+1,h+2),this.indexArray.emplaceBack(h,h+3,h+2),u.vertexLength+=4,u.primitiveLength+=2}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,{})},kn(\"CircleBucket\",ga,{omit:[\"layers\"]});var La={paint:new ei({\"circle-radius\":new Kn(It.paint_circle[\"circle-radius\"]),\"circle-color\":new Kn(It.paint_circle[\"circle-color\"]),\"circle-blur\":new Kn(It.paint_circle[\"circle-blur\"]),\"circle-opacity\":new Kn(It.paint_circle[\"circle-opacity\"]),\"circle-translate\":new Jn(It.paint_circle[\"circle-translate\"]),\"circle-translate-anchor\":new Jn(It.paint_circle[\"circle-translate-anchor\"]),\"circle-pitch-scale\":new Jn(It.paint_circle[\"circle-pitch-scale\"]),\"circle-pitch-alignment\":new Jn(It.paint_circle[\"circle-pitch-alignment\"]),\"circle-stroke-width\":new Kn(It.paint_circle[\"circle-stroke-width\"]),\"circle-stroke-color\":new Kn(It.paint_circle[\"circle-stroke-color\"]),\"circle-stroke-opacity\":new Kn(It.paint_circle[\"circle-stroke-opacity\"])})},Pa=\"undefined\"!=typeof Float32Array?Float32Array:Array;function Oa(){var t=new Pa(9);return Pa!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[5]=0,t[6]=0,t[7]=0),t[0]=1,t[4]=1,t[8]=1,t}function za(){var t=new Pa(3);return Pa!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0),t}function Ia(t,e,r){var n=new Pa(3);return n[0]=t,n[1]=e,n[2]=r,n}Math.PI;function Da(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}function Ra(){var t=new Pa(4);return Pa!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0),t[3]=1,t}za(),function(){var t;t=new Pa(4),Pa!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0,t[3]=0)}();za(),Ia(1,0,0),Ia(0,1,0),Ra(),Ra(),Oa(),function(){var t;t=new Pa(2),Pa!=Float32Array&&(t[0]=0,t[1]=0)}();var Fa=function(t){function e(e){t.call(this,e,La)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new ga(t)},e.prototype.queryRadius=function(t){var e=t;return Sa(\"circle-radius\",this,e)+Sa(\"circle-stroke-width\",this,e)+Ea(this.paint.get(\"circle-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o,s){for(var l=Ca(t,this.paint.get(\"circle-translate\"),this.paint.get(\"circle-translate-anchor\"),a.angle,o),c=this.paint.get(\"circle-radius\").evaluate(e,r)+this.paint.get(\"circle-stroke-width\").evaluate(e,r),u=\"map\"===this.paint.get(\"circle-pitch-alignment\"),h=u?l:function(t,e){return l.map(function(t){return Ba(t,e)})}(0,s),f=u?c*o:c,p=0,d=n;p<d.length;p+=1)for(var g=0,v=d[p];g<v.length;g+=1){var m=v[g],y=u?m:Ba(m,s),x=f,b=Da([],[m.x,m.y,0,1],s);if(\"viewport\"===this.paint.get(\"circle-pitch-scale\")&&\"map\"===this.paint.get(\"circle-pitch-alignment\")?x*=b[3]/a.cameraToCenterDistance:\"map\"===this.paint.get(\"circle-pitch-scale\")&&\"viewport\"===this.paint.get(\"circle-pitch-alignment\")&&(x*=a.cameraToCenterDistance/b[3]),ma(h,y,x))return!0}return!1},e}(ri);function Ba(t,e){var r=Da([],[t.x,t.y,0,1],e);return new i(r[0]/r[3],r[1]/r[3])}var Na=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ga);function ja(t,e,r,n){var i=e.width,a=e.height;if(n){if(n instanceof Uint8ClampedArray)n=new Uint8Array(n.buffer);else if(n.length!==i*a*r)throw new RangeError(\"mismatched image size\")}else n=new Uint8Array(i*a*r);return t.width=i,t.height=a,t.data=n,t}function Ua(t,e,r){var n=e.width,i=e.height;if(n!==t.width||i!==t.height){var a=ja({},{width:n,height:i},r);Va(t,a,{x:0,y:0},{x:0,y:0},{width:Math.min(t.width,n),height:Math.min(t.height,i)},r),t.width=n,t.height=i,t.data=a.data}}function Va(t,e,r,n,i,a){if(0===i.width||0===i.height)return e;if(i.width>t.width||i.height>t.height||r.x>t.width-i.width||r.y>t.height-i.height)throw new RangeError(\"out of range source coordinates for image copy\");if(i.width>e.width||i.height>e.height||n.x>e.width-i.width||n.y>e.height-i.height)throw new RangeError(\"out of range destination coordinates for image copy\");for(var o=t.data,s=e.data,l=0;l<i.height;l++)for(var c=((r.y+l)*t.width+r.x)*a,u=((n.y+l)*e.width+n.x)*a,h=0;h<i.width*a;h++)s[u+h]=o[c+h];return e}kn(\"HeatmapBucket\",Na,{omit:[\"layers\"]});var qa=function(t,e){ja(this,t,1,e)};qa.prototype.resize=function(t){Ua(this,t,1)},qa.prototype.clone=function(){return new qa({width:this.width,height:this.height},new Uint8Array(this.data))},qa.copy=function(t,e,r,n,i){Va(t,e,r,n,i,1)};var Ha=function(t,e){ja(this,t,4,e)};Ha.prototype.resize=function(t){Ua(this,t,4)},Ha.prototype.replace=function(t,e){e?this.data.set(t):t instanceof Uint8ClampedArray?this.data=new Uint8Array(t.buffer):this.data=t},Ha.prototype.clone=function(){return new Ha({width:this.width,height:this.height},new Uint8Array(this.data))},Ha.copy=function(t,e,r,n,i){Va(t,e,r,n,i,4)},kn(\"AlphaImage\",qa),kn(\"RGBAImage\",Ha);var Ga={paint:new ei({\"heatmap-radius\":new Kn(It.paint_heatmap[\"heatmap-radius\"]),\"heatmap-weight\":new Kn(It.paint_heatmap[\"heatmap-weight\"]),\"heatmap-intensity\":new Jn(It.paint_heatmap[\"heatmap-intensity\"]),\"heatmap-color\":new ti(It.paint_heatmap[\"heatmap-color\"]),\"heatmap-opacity\":new Jn(It.paint_heatmap[\"heatmap-opacity\"])})};function Ya(t,e){for(var r=new Uint8Array(1024),n={},i=0,a=0;i<256;i++,a+=4){n[e]=i/255;var o=t.evaluate(n);r[a+0]=Math.floor(255*o.r/o.a),r[a+1]=Math.floor(255*o.g/o.a),r[a+2]=Math.floor(255*o.b/o.a),r[a+3]=Math.floor(255*o.a)}return new Ha({width:256,height:1},r)}var Wa=function(t){function e(e){t.call(this,e,Ga),this._updateColorRamp()}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new Na(t)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"heatmap-color\"===t&&this._updateColorRamp()},e.prototype._updateColorRamp=function(){var t=this._transitionablePaint._values[\"heatmap-color\"].value.expression;this.colorRamp=Ya(t,\"heatmapDensity\"),this.colorRampTexture=null},e.prototype.resize=function(){this.heatmapFbo&&(this.heatmapFbo.destroy(),this.heatmapFbo=null)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"heatmap-opacity\")&&\"none\"!==this.visibility},e}(ri),Xa={paint:new ei({\"hillshade-illumination-direction\":new Jn(It.paint_hillshade[\"hillshade-illumination-direction\"]),\"hillshade-illumination-anchor\":new Jn(It.paint_hillshade[\"hillshade-illumination-anchor\"]),\"hillshade-exaggeration\":new Jn(It.paint_hillshade[\"hillshade-exaggeration\"]),\"hillshade-shadow-color\":new Jn(It.paint_hillshade[\"hillshade-shadow-color\"]),\"hillshade-highlight-color\":new Jn(It.paint_hillshade[\"hillshade-highlight-color\"]),\"hillshade-accent-color\":new Jn(It.paint_hillshade[\"hillshade-accent-color\"])})},Za=function(t){function e(e){t.call(this,e,Xa)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"hillshade-exaggeration\")&&\"none\"!==this.visibility},e}(ri),Ja=oi([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,Ka=Qa,$a=Qa;function Qa(t,e,r){r=r||2;var n,i,a,o,s,l,c,u=e&&e.length,h=u?e[0]*r:t.length,f=to(t,0,h,r,!0),p=[];if(!f||f.next===f.prev)return p;if(u&&(f=function(t,e,r,n){var i,a,o,s=[];for(i=0,a=e.length;i<a;i++)(o=to(t,e[i]*n,i<a-1?e[i+1]*n:t.length,n,!1))===o.next&&(o.steiner=!0),s.push(uo(o));for(s.sort(so),i=0;i<s.length;i++)lo(s[i],r),r=eo(r,r.next);return r}(t,e,f,r)),t.length>80*r){n=a=t[0],i=o=t[1];for(var d=r;d<h;d+=r)(s=t[d])<n&&(n=s),(l=t[d+1])<i&&(i=l),s>a&&(a=s),l>o&&(o=l);c=0!==(c=Math.max(a-n,o-i))?1/c:0}return ro(f,p,r,n,i,c),p}function to(t,e,r,n,i){var a,o;if(i===wo(t,e,r,n)>0)for(a=e;a<r;a+=n)o=xo(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=xo(a,t[a],t[a+1],o);return o&&go(o,o.next)&&(bo(o),o=o.next),o}function eo(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!go(n,n.next)&&0!==po(n.prev,n,n.next))n=n.next;else{if(bo(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function ro(t,e,r,n,i,a,o){if(t){!o&&a&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=co(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,a);for(var s,l,c=t;t.prev!==t.next;)if(s=t.prev,l=t.next,a?io(t,n,i,a):no(t))e.push(s.i/r),e.push(t.i/r),e.push(l.i/r),bo(t),t=l.next,c=l.next;else if((t=l)===c){o?1===o?ro(t=ao(t,e,r),e,r,n,i,a,2):2===o&&oo(t,e,r,n,i,a):ro(eo(t),e,r,n,i,a,1);break}}}function no(t){var e=t.prev,r=t,n=t.next;if(po(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(ho(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&po(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function io(t,e,r,n){var i=t.prev,a=t,o=t.next;if(po(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,h=co(s,l,e,r,n),f=co(c,u,e,r,n),p=t.prevZ,d=t.nextZ;p&&p.z>=h&&d&&d.z<=f;){if(p!==t.prev&&p!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&po(p.prev,p,p.next)>=0)return!1;if(p=p.prevZ,d!==t.prev&&d!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&po(d.prev,d,d.next)>=0)return!1;d=d.nextZ}for(;p&&p.z>=h;){if(p!==t.prev&&p!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&po(p.prev,p,p.next)>=0)return!1;p=p.prevZ}for(;d&&d.z<=f;){if(d!==t.prev&&d!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&po(d.prev,d,d.next)>=0)return!1;d=d.nextZ}return!0}function ao(t,e,r){var n=t;do{var i=n.prev,a=n.next.next;!go(i,a)&&vo(i,n,n.next,a)&&mo(i,a)&&mo(a,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(a.i/r),bo(n),bo(n.next),n=t=a),n=n.next}while(n!==t);return n}function oo(t,e,r,n,i,a){var o=t;do{for(var s=o.next.next;s!==o.prev;){if(o.i!==s.i&&fo(o,s)){var l=yo(o,s);return o=eo(o,o.next),l=eo(l,l.next),ro(o,e,r,n,i,a),void ro(l,e,r,n,i,a)}s=s.next}o=o.next}while(o!==t)}function so(t,e){return t.x-e.x}function lo(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r.prev;var l,c=r,u=r.x,h=r.y,f=1/0;for(n=r.next;n!==c;)i>=n.x&&n.x>=u&&i!==n.x&&ho(a<h?i:o,a,u,h,a<h?o:i,a,n.x,n.y)&&((l=Math.abs(a-n.y)/(i-n.x))<f||l===f&&n.x>r.x)&&mo(n,t)&&(r=n,f=l),n=n.next;return r}(t,e)){var r=yo(e,t);eo(r,r.next)}}function co(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function uo(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function ho(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function fo(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&vo(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&mo(t,e)&&mo(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)}function po(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function go(t,e){return t.x===e.x&&t.y===e.y}function vo(t,e,r,n){return!!(go(t,e)&&go(r,n)||go(t,n)&&go(r,e))||po(t,e,r)>0!=po(t,e,n)>0&&po(r,n,t)>0!=po(r,n,e)>0}function mo(t,e){return po(t.prev,t,t.next)<0?po(t,e,t.next)>=0&&po(t,t.prev,e)>=0:po(t,e,t.prev)<0||po(t,t.next,e)<0}function yo(t,e){var r=new _o(t.i,t.x,t.y),n=new _o(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function xo(t,e,r,n){var i=new _o(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function bo(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function _o(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function wo(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}function ko(t,e,r,n,i){!function t(e,r,n,i,a){for(;i>n;){if(i-n>600){var o=i-n+1,s=r-n+1,l=Math.log(o),c=.5*Math.exp(2*l/3),u=.5*Math.sqrt(l*c*(o-c)/o)*(s-o/2<0?-1:1);t(e,r,Math.max(n,Math.floor(r-s*c/o+u)),Math.min(i,Math.floor(r+(o-s)*c/o+u)),a)}var h=e[r],f=n,p=i;for(To(e,n,r),a(e[i],h)>0&&To(e,n,i);f<p;){for(To(e,f,p),f++,p--;a(e[f],h)<0;)f++;for(;a(e[p],h)>0;)p--}0===a(e[n],h)?To(e,n,p):To(e,++p,i),p<=r&&(n=p+1),r<=p&&(i=p-1)}}(t,e,r||0,n||t.length-1,i||Ao)}function To(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function Ao(t,e){return t<e?-1:t>e?1:0}function Mo(t,e){var r=t.length;if(r<=1)return[t];for(var n,i,a=[],o=0;o<r;o++){var s=T(t[o]);0!==s&&(t[o].area=Math.abs(s),void 0===i&&(i=s<0),i===s<0?(n&&a.push(n),n=[t[o]]):n.push(t[o]))}if(n&&a.push(n),e>1)for(var l=0;l<a.length;l++)a[l].length<=e||(ko(a[l],e,1,a[l].length-1,So),a[l]=a[l].slice(0,e));return a}function So(t,e){return e.area-t.area}function Eo(t,e,r){for(var n=r.patternDependencies,i=!1,a=0,o=e;a<o.length;a+=1){var s=o[a].paint.get(t+\"-pattern\");s.isConstant()||(i=!0);var l=s.constantOr(null);l&&(i=!0,n[l.to]=!0,n[l.from]=!0)}return i}function Co(t,e,r,n,i){for(var a=i.patternDependencies,o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.paint.get(t+\"-pattern\").value;if(\"constant\"!==c.kind){var u=c.evaluate({zoom:n-1},r,{}),h=c.evaluate({zoom:n},r,{}),f=c.evaluate({zoom:n+1},r,{});a[u]=!0,a[h]=!0,a[f]=!0,r.patterns[l.id]={min:u,mid:h,max:f}}}return r}Qa.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(wo(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(wo(t,c,u,r))}var h=0;for(s=0;s<n.length;s+=3){var f=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;h+=Math.abs((t[f]-t[d])*(t[p+1]-t[f+1])-(t[f]-t[p])*(t[d+1]-t[f+1]))}return 0===o&&0===h?0:Math.abs((h-o)/o)},Qa.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r},Ka.default=$a;var Lo=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new li,this.indexArray=new Ti,this.indexArray2=new Ai,this.programConfigurations=new la(Ja,t.layers,t.zoom),this.segments=new Vi,this.segments2=new Vi,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};Lo.prototype.populate=function(t,e){this.features=[],this.hasPattern=Eo(\"fill\",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a),c={sourceLayerIndex:s,index:o,geometry:l,properties:a.properties,type:a.type,patterns:{}};void 0!==a.id&&(c.id=a.id),this.hasPattern?this.features.push(Co(\"fill\",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(a,l,o,s,this.index)}}},Lo.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Lo.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var i=n[r],a=i.geometry;this.addFeature(i,a,i.index,e)}},Lo.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Lo.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Lo.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ja),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.indexBuffer2=t.createIndexBuffer(this.indexArray2)),this.programConfigurations.upload(t),this.uploaded=!0},Lo.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.indexBuffer2.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.segments2.destroy())},Lo.prototype.addFeature=function(t,e,r,n){for(var i=0,a=Mo(e,500);i<a.length;i+=1){for(var o=a[i],s=0,l=0,c=o;l<c.length;l+=1)s+=c[l].length;for(var u=this.segments.prepareSegment(s,this.layoutVertexArray,this.indexArray),h=u.vertexLength,f=[],p=[],d=0,g=o;d<g.length;d+=1){var v=g[d];if(0!==v.length){v!==o[0]&&p.push(f.length/2);var m=this.segments2.prepareSegment(v.length,this.layoutVertexArray,this.indexArray2),y=m.vertexLength;this.layoutVertexArray.emplaceBack(v[0].x,v[0].y),this.indexArray2.emplaceBack(y+v.length-1,y),f.push(v[0].x),f.push(v[0].y);for(var x=1;x<v.length;x++)this.layoutVertexArray.emplaceBack(v[x].x,v[x].y),this.indexArray2.emplaceBack(y+x-1,y+x),f.push(v[x].x),f.push(v[x].y);m.vertexLength+=v.length,m.primitiveLength+=v.length}}for(var b=Ka(f,p),_=0;_<b.length;_+=3)this.indexArray.emplaceBack(h+b[_],h+b[_+1],h+b[_+2]);u.vertexLength+=s,u.primitiveLength+=b.length/3}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,n)},kn(\"FillBucket\",Lo,{omit:[\"layers\",\"features\"]});var Po={paint:new ei({\"fill-antialias\":new Jn(It.paint_fill[\"fill-antialias\"]),\"fill-opacity\":new Kn(It.paint_fill[\"fill-opacity\"]),\"fill-color\":new Kn(It.paint_fill[\"fill-color\"]),\"fill-outline-color\":new Kn(It.paint_fill[\"fill-outline-color\"]),\"fill-translate\":new Jn(It.paint_fill[\"fill-translate\"]),\"fill-translate-anchor\":new Jn(It.paint_fill[\"fill-translate-anchor\"]),\"fill-pattern\":new $n(It.paint_fill[\"fill-pattern\"])})},Oo=function(t){function e(e){t.call(this,e,Po)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e);var r=this.paint._values[\"fill-outline-color\"];\"constant\"===r.value.kind&&void 0===r.value.value&&(this.paint._values[\"fill-outline-color\"]=this.paint._values[\"fill-color\"])},e.prototype.createBucket=function(t){return new Lo(t)},e.prototype.queryRadius=function(){return Ea(this.paint.get(\"fill-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o){return ya(Ca(t,this.paint.get(\"fill-translate\"),this.paint.get(\"fill-translate-anchor\"),a.angle,o),n)},e.prototype.isTileClipped=function(){return!0},e}(ri),zo=oi([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_normal_ed\",components:4,type:\"Int16\"}],4).members,Io=Do;function Do(t,e,r,n,i){this.properties={},this.extent=r,this.type=0,this._pbf=t,this._geometry=-1,this._keys=n,this._values=i,t.readFields(Ro,this,e)}function Ro(t,e,r){1==t?e.id=r.readVarint():2==t?function(t,e){for(var r=t.readVarint()+t.pos;t.pos<r;){var n=e._keys[t.readVarint()],i=e._values[t.readVarint()];e.properties[n]=i}}(r,e):3==t?e.type=r.readVarint():4==t&&(e._geometry=r.pos)}function Fo(t){for(var e,r,n=0,i=0,a=t.length,o=a-1;i<a;o=i++)e=t[i],n+=((r=t[o]).x-e.x)*(e.y+r.y);return n}Do.types=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],Do.prototype.loadGeometry=function(){var t=this._pbf;t.pos=this._geometry;for(var e,r=t.readVarint()+t.pos,n=1,a=0,o=0,s=0,l=[];t.pos<r;){if(a<=0){var c=t.readVarint();n=7&c,a=c>>3}if(a--,1===n||2===n)o+=t.readSVarint(),s+=t.readSVarint(),1===n&&(e&&l.push(e),e=[]),e.push(new i(o,s));else{if(7!==n)throw new Error(\"unknown command \"+n);e&&e.push(e[0].clone())}}return e&&l.push(e),l},Do.prototype.bbox=function(){var t=this._pbf;t.pos=this._geometry;for(var e=t.readVarint()+t.pos,r=1,n=0,i=0,a=0,o=1/0,s=-1/0,l=1/0,c=-1/0;t.pos<e;){if(n<=0){var u=t.readVarint();r=7&u,n=u>>3}if(n--,1===r||2===r)(i+=t.readSVarint())<o&&(o=i),i>s&&(s=i),(a+=t.readSVarint())<l&&(l=a),a>c&&(c=a);else if(7!==r)throw new Error(\"unknown command \"+r)}return[o,l,s,c]},Do.prototype.toGeoJSON=function(t,e,r){var n,i,a=this.extent*Math.pow(2,r),o=this.extent*t,s=this.extent*e,l=this.loadGeometry(),c=Do.types[this.type];function u(t){for(var e=0;e<t.length;e++){var r=t[e],n=180-360*(r.y+s)/a;t[e]=[360*(r.x+o)/a-180,360/Math.PI*Math.atan(Math.exp(n*Math.PI/180))-90]}}switch(this.type){case 1:var h=[];for(n=0;n<l.length;n++)h[n]=l[n][0];u(l=h);break;case 2:for(n=0;n<l.length;n++)u(l[n]);break;case 3:for(l=function(t){var e=t.length;if(e<=1)return[t];for(var r,n,i=[],a=0;a<e;a++){var o=Fo(t[a]);0!==o&&(void 0===n&&(n=o<0),n===o<0?(r&&i.push(r),r=[t[a]]):r.push(t[a]))}return r&&i.push(r),i}(l),n=0;n<l.length;n++)for(i=0;i<l[n].length;i++)u(l[n][i])}1===l.length?l=l[0]:c=\"Multi\"+c;var f={type:\"Feature\",geometry:{type:c,coordinates:l},properties:this.properties};return\"id\"in this&&(f.id=this.id),f};var Bo=No;function No(t,e){this.version=1,this.name=null,this.extent=4096,this.length=0,this._pbf=t,this._keys=[],this._values=[],this._features=[],t.readFields(jo,this,e),this.length=this._features.length}function jo(t,e,r){15===t?e.version=r.readVarint():1===t?e.name=r.readString():5===t?e.extent=r.readVarint():2===t?e._features.push(r.pos):3===t?e._keys.push(r.readString()):4===t&&e._values.push(function(t){for(var e=null,r=t.readVarint()+t.pos;t.pos<r;){var n=t.readVarint()>>3;e=1===n?t.readString():2===n?t.readFloat():3===n?t.readDouble():4===n?t.readVarint64():5===n?t.readVarint():6===n?t.readSVarint():7===n?t.readBoolean():null}return e}(r))}function Uo(t,e,r){if(3===t){var n=new Bo(r,r.readVarint()+r.pos);n.length&&(e[n.name]=n)}}No.prototype.feature=function(t){if(t<0||t>=this._features.length)throw new Error(\"feature index out of bounds\");this._pbf.pos=this._features[t];var e=this._pbf.readVarint()+this._pbf.pos;return new Io(this._pbf,e,this.extent,this._keys,this._values)};var Vo={VectorTile:function(t,e){this.layers=t.readFields(Uo,{},e)},VectorTileFeature:Io,VectorTileLayer:Bo},qo=Vo.VectorTileFeature.types,Ho=Math.pow(2,13);function Go(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,2*Math.floor(n*Ho)+o,i*Ho*2,a*Ho*2,Math.round(s))}var Yo=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new ui,this.indexArray=new Ti,this.programConfigurations=new la(zo,t.layers,t.zoom),this.segments=new Vi,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function Wo(t,e){return t.x===e.x&&(t.x<0||t.x>ha)||t.y===e.y&&(t.y<0||t.y>ha)}function Xo(t){return t.every(function(t){return t.x<0})||t.every(function(t){return t.x>ha})||t.every(function(t){return t.y<0})||t.every(function(t){return t.y>ha})}Yo.prototype.populate=function(t,e){this.features=[],this.hasPattern=Eo(\"fill-extrusion\",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a),c={sourceLayerIndex:s,index:o,geometry:l,properties:a.properties,type:a.type,patterns:{}};void 0!==a.id&&(c.id=a.id),this.hasPattern?this.features.push(Co(\"fill-extrusion\",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(a,l,o,s,this.index,!0)}}},Yo.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var i=n[r],a=i.geometry;this.addFeature(i,a,i.index,e)}},Yo.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Yo.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Yo.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Yo.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,zo),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Yo.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Yo.prototype.addFeature=function(t,e,r,n){for(var i=0,a=Mo(e,500);i<a.length;i+=1){for(var o=a[i],s=0,l=0,c=o;l<c.length;l+=1)s+=c[l].length;for(var u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),h=0,f=o;h<f.length;h+=1){var p=f[h];if(0!==p.length&&!Xo(p))for(var d=0,g=0;g<p.length;g++){var v=p[g];if(g>=1){var m=p[g-1];if(!Wo(v,m)){u.vertexLength+4>Vi.MAX_VERTEX_ARRAY_LENGTH&&(u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray));var y=v.sub(m)._perp()._unit(),x=m.dist(v);d+x>32768&&(d=0),Go(this.layoutVertexArray,v.x,v.y,y.x,y.y,0,0,d),Go(this.layoutVertexArray,v.x,v.y,y.x,y.y,0,1,d),d+=x,Go(this.layoutVertexArray,m.x,m.y,y.x,y.y,0,0,d),Go(this.layoutVertexArray,m.x,m.y,y.x,y.y,0,1,d);var b=u.vertexLength;this.indexArray.emplaceBack(b,b+2,b+1),this.indexArray.emplaceBack(b+1,b+2,b+3),u.vertexLength+=4,u.primitiveLength+=2}}}}if(u.vertexLength+s>Vi.MAX_VERTEX_ARRAY_LENGTH&&(u=this.segments.prepareSegment(s,this.layoutVertexArray,this.indexArray)),\"Polygon\"===qo[t.type]){for(var _=[],w=[],k=u.vertexLength,T=0,A=o;T<A.length;T+=1){var M=A[T];if(0!==M.length){M!==o[0]&&w.push(_.length/2);for(var S=0;S<M.length;S++){var E=M[S];Go(this.layoutVertexArray,E.x,E.y,0,0,1,1,0),_.push(E.x),_.push(E.y)}}}for(var C=Ka(_,w),L=0;L<C.length;L+=3)this.indexArray.emplaceBack(k+C[L],k+C[L+2],k+C[L+1]);u.primitiveLength+=C.length/3,u.vertexLength+=s}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,n)},kn(\"FillExtrusionBucket\",Yo,{omit:[\"layers\",\"features\"]});var Zo={paint:new ei({\"fill-extrusion-opacity\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-opacity\"]),\"fill-extrusion-color\":new Kn(It[\"paint_fill-extrusion\"][\"fill-extrusion-color\"]),\"fill-extrusion-translate\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-translate\"]),\"fill-extrusion-translate-anchor\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-translate-anchor\"]),\"fill-extrusion-pattern\":new $n(It[\"paint_fill-extrusion\"][\"fill-extrusion-pattern\"]),\"fill-extrusion-height\":new Kn(It[\"paint_fill-extrusion\"][\"fill-extrusion-height\"]),\"fill-extrusion-base\":new Kn(It[\"paint_fill-extrusion\"][\"fill-extrusion-base\"]),\"fill-extrusion-vertical-gradient\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-vertical-gradient\"])})},Jo=function(t){function e(e){t.call(this,e,Zo)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new Yo(t)},e.prototype.queryRadius=function(){return Ea(this.paint.get(\"fill-extrusion-translate\"))},e.prototype.is3D=function(){return!0},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s,l){var c=Ca(t,this.paint.get(\"fill-extrusion-translate\"),this.paint.get(\"fill-extrusion-translate-anchor\"),o.angle,s),u=this.paint.get(\"fill-extrusion-height\").evaluate(e,r),h=this.paint.get(\"fill-extrusion-base\").evaluate(e,r),f=function(t,e,r,n){for(var a=[],o=0,s=t;o<s.length;o+=1){var l=s[o],c=[l.x,l.y,0,1];Da(c,c,e),a.push(new i(c[0]/c[3],c[1]/c[3]))}return a}(c,l),p=function(t,e,r,n){for(var a=[],o=[],s=n[8]*e,l=n[9]*e,c=n[10]*e,u=n[11]*e,h=n[8]*r,f=n[9]*r,p=n[10]*r,d=n[11]*r,g=0,v=t;g<v.length;g+=1){for(var m=[],y=[],x=0,b=v[g];x<b.length;x+=1){var _=b[x],w=_.x,k=_.y,T=n[0]*w+n[4]*k+n[12],A=n[1]*w+n[5]*k+n[13],M=n[2]*w+n[6]*k+n[14],S=n[3]*w+n[7]*k+n[15],E=M+c,C=S+u,L=T+h,P=A+f,O=M+p,z=S+d,I=new i((T+s)/C,(A+l)/C);I.z=E/C,m.push(I);var D=new i(L/z,P/z);D.z=O/z,y.push(D)}a.push(m),o.push(y)}return[a,o]}(n,h,u,l);return function(t,e,r){var n=1/0;ya(r,e)&&(n=$o(r,e[0]));for(var i=0;i<e.length;i++)for(var a=e[i],o=t[i],s=0;s<a.length-1;s++){var l=a[s],c=a[s+1],u=o[s],h=[l,c,o[s+1],u,l];va(r,h)&&(n=Math.min(n,$o(r,h)))}return n!==1/0&&n}(p[0],p[1],f)},e}(ri);function Ko(t,e){return t.x*e.x+t.y*e.y}function $o(t,e){if(1===t.length){var r=e[0],n=e[1],i=e[3],a=t[0],o=n.sub(r),s=i.sub(r),l=a.sub(r),c=Ko(o,o),u=Ko(o,s),h=Ko(s,s),f=Ko(l,o),p=Ko(l,s),d=c*h-u*u,g=(h*f-u*p)/d,v=(c*p-u*f)/d,m=1-g-v;return r.z*m+n.z*g+i.z*v}for(var y=1/0,x=0,b=e;x<b.length;x+=1){var _=b[x];y=Math.min(y,_.z)}return y}var Qo=oi([{name:\"a_pos_normal\",components:2,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint8\"}],4).members,ts=Vo.VectorTileFeature.types,es=63,rs=Math.cos(Math.PI/180*37.5),ns=.5,is=Math.pow(2,14)/ns;function as(t,e,r,n,i,a,o){t.emplaceBack((e.x<<1)+(n?1:0),(e.y<<1)+(i?1:0),Math.round(es*r.x)+128,Math.round(es*r.y)+128,1+(0===a?0:a<0?-1:1)|(o*ns&63)<<2,o*ns>>6)}var os=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.features=[],this.hasPattern=!1,this.layoutVertexArray=new hi,this.indexArray=new Ti,this.programConfigurations=new la(Qo,t.layers,t.zoom),this.segments=new Vi,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function ss(t,e){return(t/e.tileTotal*(e.end-e.start)+e.start)*(is-1)}os.prototype.populate=function(t,e){this.features=[],this.hasPattern=Eo(\"line\",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a),c={sourceLayerIndex:s,index:o,geometry:l,properties:a.properties,type:a.type,patterns:{}};void 0!==a.id&&(c.id=a.id),this.hasPattern?this.features.push(Co(\"line\",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(a,l,o,s,this.index)}}},os.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},os.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var i=n[r],a=i.geometry;this.addFeature(i,a,i.index,e)}},os.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},os.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},os.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Qo),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},os.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},os.prototype.addFeature=function(t,e,r,n){for(var i=this.layers[0].layout,a=i.get(\"line-join\").evaluate(t,{}),o=i.get(\"line-cap\"),s=i.get(\"line-miter-limit\"),l=i.get(\"line-round-limit\"),c=0,u=e;c<u.length;c+=1){var h=u[c];this.addLine(h,t,a,o,s,l,r,n)}},os.prototype.addLine=function(t,e,r,n,i,a,o,s){var l=null;e.properties&&e.properties.hasOwnProperty(\"mapbox_clip_start\")&&e.properties.hasOwnProperty(\"mapbox_clip_end\")&&(l={start:e.properties.mapbox_clip_start,end:e.properties.mapbox_clip_end,tileTotal:void 0});for(var c=\"Polygon\"===ts[e.type],u=t.length;u>=2&&t[u-1].equals(t[u-2]);)u--;for(var h=0;h<u-1&&t[h].equals(t[h+1]);)h++;if(!(u<(c?3:2))){l&&(l.tileTotal=function(t,e,r){for(var n,i,a=0,o=h;o<r-1;o++)n=t[o],i=t[o+1],a+=n.dist(i);return a}(t,0,u)),\"bevel\"===r&&(i=1.05);var f=ha/(512*this.overscaling)*15,p=t[h],d=this.segments.prepareSegment(10*u,this.layoutVertexArray,this.indexArray);this.distance=0;var g,v,m,y=n,x=c?\"butt\":n,b=!0,_=void 0,w=void 0,k=void 0,T=void 0;this.e1=this.e2=this.e3=-1,c&&(g=t[u-2],T=p.sub(g)._unit()._perp());for(var A=h;A<u;A++)if(!(w=c&&A===u-1?t[h+1]:t[A+1])||!t[A].equals(w)){T&&(k=T),g&&(_=g),g=t[A],T=w?w.sub(g)._unit()._perp():k;var M=(k=k||T).add(T);0===M.x&&0===M.y||M._unit();var S=M.x*T.x+M.y*T.y,E=0!==S?1/S:1/0,C=S<rs&&_&&w;if(C&&A>h){var L=g.dist(_);if(L>2*f){var P=g.sub(g.sub(_)._mult(f/L)._round());this.distance+=P.dist(_),this.addCurrentVertex(P,this.distance,k.mult(1),0,0,!1,d,l),_=P}}var O=_&&w,z=O?r:w?y:x;if(O&&\"round\"===z&&(E<a?z=\"miter\":E<=2&&(z=\"fakeround\")),\"miter\"===z&&E>i&&(z=\"bevel\"),\"bevel\"===z&&(E>2&&(z=\"flipbevel\"),E<i&&(z=\"miter\")),_&&(this.distance+=g.dist(_)),\"miter\"===z)M._mult(E),this.addCurrentVertex(g,this.distance,M,0,0,!1,d,l);else if(\"flipbevel\"===z){if(E>100)M=T.clone().mult(-1);else{var I=k.x*T.y-k.y*T.x>0?-1:1,D=E*k.add(T).mag()/k.sub(T).mag();M._perp()._mult(D*I)}this.addCurrentVertex(g,this.distance,M,0,0,!1,d,l),this.addCurrentVertex(g,this.distance,M.mult(-1),0,0,!1,d,l)}else if(\"bevel\"===z||\"fakeround\"===z){var R=k.x*T.y-k.y*T.x>0,F=-Math.sqrt(E*E-1);if(R?(m=0,v=F):(v=0,m=F),b||this.addCurrentVertex(g,this.distance,k,v,m,!1,d,l),\"fakeround\"===z){for(var B=Math.floor(8*(.5-(S-.5))),N=void 0,j=0;j<B;j++)N=T.mult((j+1)/(B+1))._add(k)._unit(),this.addPieSliceVertex(g,this.distance,N,R,d,l);this.addPieSliceVertex(g,this.distance,M,R,d,l);for(var U=B-1;U>=0;U--)N=k.mult((U+1)/(B+1))._add(T)._unit(),this.addPieSliceVertex(g,this.distance,N,R,d,l)}w&&this.addCurrentVertex(g,this.distance,T,-v,-m,!1,d,l)}else\"butt\"===z?(b||this.addCurrentVertex(g,this.distance,k,0,0,!1,d,l),w&&this.addCurrentVertex(g,this.distance,T,0,0,!1,d,l)):\"square\"===z?(b||(this.addCurrentVertex(g,this.distance,k,1,1,!1,d,l),this.e1=this.e2=-1),w&&this.addCurrentVertex(g,this.distance,T,-1,-1,!1,d,l)):\"round\"===z&&(b||(this.addCurrentVertex(g,this.distance,k,0,0,!1,d,l),this.addCurrentVertex(g,this.distance,k,1,1,!0,d,l),this.e1=this.e2=-1),w&&(this.addCurrentVertex(g,this.distance,T,-1,-1,!0,d,l),this.addCurrentVertex(g,this.distance,T,0,0,!1,d,l)));if(C&&A<u-1){var V=g.dist(w);if(V>2*f){var q=g.add(w.sub(g)._mult(f/V)._round());this.distance+=q.dist(g),this.addCurrentVertex(q,this.distance,T.mult(1),0,0,!1,d,l),g=q}}b=!1}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,e,o,s)}},os.prototype.addCurrentVertex=function(t,e,r,n,i,a,o,s){var l,c=this.layoutVertexArray,u=this.indexArray;s&&(e=ss(e,s)),l=r.clone(),n&&l._sub(r.perp()._mult(n)),as(c,t,l,a,!1,n,e),this.e3=o.vertexLength++,this.e1>=0&&this.e2>=0&&(u.emplaceBack(this.e1,this.e2,this.e3),o.primitiveLength++),this.e1=this.e2,this.e2=this.e3,l=r.mult(-1),i&&l._sub(r.perp()._mult(i)),as(c,t,l,a,!0,-i,e),this.e3=o.vertexLength++,this.e1>=0&&this.e2>=0&&(u.emplaceBack(this.e1,this.e2,this.e3),o.primitiveLength++),this.e1=this.e2,this.e2=this.e3,e>is/2&&!s&&(this.distance=0,this.addCurrentVertex(t,this.distance,r,n,i,a,o))},os.prototype.addPieSliceVertex=function(t,e,r,n,i,a){r=r.mult(n?-1:1);var o=this.layoutVertexArray,s=this.indexArray;a&&(e=ss(e,a)),as(o,t,r,!1,n,0,e),this.e3=i.vertexLength++,this.e1>=0&&this.e2>=0&&(s.emplaceBack(this.e1,this.e2,this.e3),i.primitiveLength++),n?this.e2=this.e3:this.e1=this.e3},kn(\"LineBucket\",os,{omit:[\"layers\",\"features\"]});var ls=new ei({\"line-cap\":new Jn(It.layout_line[\"line-cap\"]),\"line-join\":new Kn(It.layout_line[\"line-join\"]),\"line-miter-limit\":new Jn(It.layout_line[\"line-miter-limit\"]),\"line-round-limit\":new Jn(It.layout_line[\"line-round-limit\"])}),cs={paint:new ei({\"line-opacity\":new Kn(It.paint_line[\"line-opacity\"]),\"line-color\":new Kn(It.paint_line[\"line-color\"]),\"line-translate\":new Jn(It.paint_line[\"line-translate\"]),\"line-translate-anchor\":new Jn(It.paint_line[\"line-translate-anchor\"]),\"line-width\":new Kn(It.paint_line[\"line-width\"]),\"line-gap-width\":new Kn(It.paint_line[\"line-gap-width\"]),\"line-offset\":new Kn(It.paint_line[\"line-offset\"]),\"line-blur\":new Kn(It.paint_line[\"line-blur\"]),\"line-dasharray\":new Qn(It.paint_line[\"line-dasharray\"]),\"line-pattern\":new $n(It.paint_line[\"line-pattern\"]),\"line-gradient\":new ti(It.paint_line[\"line-gradient\"])}),layout:ls},us=new(function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(e,r){return r=new Un(Math.floor(r.zoom),{now:r.now,fadeDuration:r.fadeDuration,zoomHistory:r.zoomHistory,transition:r.transition}),t.prototype.possiblyEvaluate.call(this,e,r)},e.prototype.evaluate=function(e,r,n,i){return r=h({},r,{zoom:Math.floor(r.zoom)}),t.prototype.evaluate.call(this,e,r,n,i)},e}(Kn))(cs.paint.properties[\"line-width\"].specification);us.useIntegerZoom=!0;var hs=function(t){function e(e){t.call(this,e,cs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"line-gradient\"===t&&this._updateGradient()},e.prototype._updateGradient=function(){var t=this._transitionablePaint._values[\"line-gradient\"].value.expression;this.gradient=Ya(t,\"lineProgress\"),this.gradientTexture=null},e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e),this.paint._values[\"line-floorwidth\"]=us.possiblyEvaluate(this._transitioningPaint._values[\"line-width\"].value,e)},e.prototype.createBucket=function(t){return new os(t)},e.prototype.queryRadius=function(t){var e=t,r=fs(Sa(\"line-width\",this,e),Sa(\"line-gap-width\",this,e)),n=Sa(\"line-offset\",this,e);return r/2+Math.abs(n)+Ea(this.paint.get(\"line-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s){var l=Ca(t,this.paint.get(\"line-translate\"),this.paint.get(\"line-translate-anchor\"),o.angle,s),c=s/2*fs(this.paint.get(\"line-width\").evaluate(e,r),this.paint.get(\"line-gap-width\").evaluate(e,r)),u=this.paint.get(\"line-offset\").evaluate(e,r);return u&&(n=function(t,e){for(var r=[],n=new i(0,0),a=0;a<t.length;a++){for(var o=t[a],s=[],l=0;l<o.length;l++){var c=o[l-1],u=o[l],h=o[l+1],f=0===l?n:u.sub(c)._unit()._perp(),p=l===o.length-1?n:h.sub(u)._unit()._perp(),d=f._add(p)._unit(),g=d.x*p.x+d.y*p.y;d._mult(1/g),s.push(d._mult(e)._add(u))}r.push(s)}return r}(n,u*s)),function(t,e,r){for(var n=0;n<e.length;n++){var i=e[n];if(t.length>=3)for(var a=0;a<i.length;a++)if(Aa(t,i[a]))return!0;if(xa(t,i,r))return!0}return!1}(l,n,c)},e.prototype.isTileClipped=function(){return!0},e}(ri);function fs(t,e){return e>0?e+2*t:t}var ps=oi([{name:\"a_pos_offset\",components:4,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint16\"}]),ds=oi([{name:\"a_projected_pos\",components:3,type:\"Float32\"}],4),gs=(oi([{name:\"a_fade_opacity\",components:1,type:\"Uint32\"}],4),oi([{name:\"a_placed\",components:2,type:\"Uint8\"},{name:\"a_shift\",components:2,type:\"Float32\"}])),vs=(oi([{type:\"Int16\",name:\"anchorPointX\"},{type:\"Int16\",name:\"anchorPointY\"},{type:\"Int16\",name:\"x1\"},{type:\"Int16\",name:\"y1\"},{type:\"Int16\",name:\"x2\"},{type:\"Int16\",name:\"y2\"},{type:\"Uint32\",name:\"featureIndex\"},{type:\"Uint16\",name:\"sourceLayerIndex\"},{type:\"Uint16\",name:\"bucketIndex\"},{type:\"Int16\",name:\"radius\"},{type:\"Int16\",name:\"signedDistanceFromAnchor\"}]),oi([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4)),ms=oi([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4);function ys(t,e,r){return t.sections.forEach(function(t){t.text=function(t,e,r){var n=e.layout.get(\"text-transform\").evaluate(r,{});return\"uppercase\"===n?t=t.toLocaleUpperCase():\"lowercase\"===n&&(t=t.toLocaleLowerCase()),jn.applyArabicShaping&&(t=jn.applyArabicShaping(t)),t}(t.text,e,r)}),t}oi([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Uint16\",name:\"glyphStartIndex\"},{type:\"Uint16\",name:\"numGlyphs\"},{type:\"Uint32\",name:\"vertexStartIndex\"},{type:\"Uint32\",name:\"lineStartIndex\"},{type:\"Uint32\",name:\"lineLength\"},{type:\"Uint16\",name:\"segment\"},{type:\"Uint16\",name:\"lowerSize\"},{type:\"Uint16\",name:\"upperSize\"},{type:\"Float32\",name:\"lineOffsetX\"},{type:\"Float32\",name:\"lineOffsetY\"},{type:\"Uint8\",name:\"writingMode\"},{type:\"Uint8\",name:\"hidden\"},{type:\"Uint32\",name:\"crossTileID\"}]),oi([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Int16\",name:\"rightJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"centerJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"leftJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"verticalPlacedTextSymbolIndex\"},{type:\"Uint16\",name:\"key\"},{type:\"Uint16\",name:\"textBoxStartIndex\"},{type:\"Uint16\",name:\"textBoxEndIndex\"},{type:\"Uint16\",name:\"iconBoxStartIndex\"},{type:\"Uint16\",name:\"iconBoxEndIndex\"},{type:\"Uint16\",name:\"featureIndex\"},{type:\"Uint16\",name:\"numHorizontalGlyphVertices\"},{type:\"Uint16\",name:\"numVerticalGlyphVertices\"},{type:\"Uint16\",name:\"numIconVertices\"},{type:\"Uint32\",name:\"crossTileID\"},{type:\"Float32\",name:\"textBoxScale\"},{type:\"Float32\",name:\"radialTextOffset\"}]),oi([{type:\"Float32\",name:\"offsetX\"}]),oi([{type:\"Int16\",name:\"x\"},{type:\"Int16\",name:\"y\"},{type:\"Int16\",name:\"tileUnitDistanceFromAnchor\"}]);var xs={\"!\":\"\\ufe15\",\"#\":\"\\uff03\",$:\"\\uff04\",\"%\":\"\\uff05\",\"&\":\"\\uff06\",\"(\":\"\\ufe35\",\")\":\"\\ufe36\",\"*\":\"\\uff0a\",\"+\":\"\\uff0b\",\",\":\"\\ufe10\",\"-\":\"\\ufe32\",\".\":\"\\u30fb\",\"/\":\"\\uff0f\",\":\":\"\\ufe13\",\";\":\"\\ufe14\",\"<\":\"\\ufe3f\",\"=\":\"\\uff1d\",\">\":\"\\ufe40\",\"?\":\"\\ufe16\",\"@\":\"\\uff20\",\"[\":\"\\ufe47\",\"\\\\\":\"\\uff3c\",\"]\":\"\\ufe48\",\"^\":\"\\uff3e\",_:\"\\ufe33\",\"`\":\"\\uff40\",\"{\":\"\\ufe37\",\"|\":\"\\u2015\",\"}\":\"\\ufe38\",\"~\":\"\\uff5e\",\"\\xa2\":\"\\uffe0\",\"\\xa3\":\"\\uffe1\",\"\\xa5\":\"\\uffe5\",\"\\xa6\":\"\\uffe4\",\"\\xac\":\"\\uffe2\",\"\\xaf\":\"\\uffe3\",\"\\u2013\":\"\\ufe32\",\"\\u2014\":\"\\ufe31\",\"\\u2018\":\"\\ufe43\",\"\\u2019\":\"\\ufe44\",\"\\u201c\":\"\\ufe41\",\"\\u201d\":\"\\ufe42\",\"\\u2026\":\"\\ufe19\",\"\\u2027\":\"\\u30fb\",\"\\u20a9\":\"\\uffe6\",\"\\u3001\":\"\\ufe11\",\"\\u3002\":\"\\ufe12\",\"\\u3008\":\"\\ufe3f\",\"\\u3009\":\"\\ufe40\",\"\\u300a\":\"\\ufe3d\",\"\\u300b\":\"\\ufe3e\",\"\\u300c\":\"\\ufe41\",\"\\u300d\":\"\\ufe42\",\"\\u300e\":\"\\ufe43\",\"\\u300f\":\"\\ufe44\",\"\\u3010\":\"\\ufe3b\",\"\\u3011\":\"\\ufe3c\",\"\\u3014\":\"\\ufe39\",\"\\u3015\":\"\\ufe3a\",\"\\u3016\":\"\\ufe17\",\"\\u3017\":\"\\ufe18\",\"\\uff01\":\"\\ufe15\",\"\\uff08\":\"\\ufe35\",\"\\uff09\":\"\\ufe36\",\"\\uff0c\":\"\\ufe10\",\"\\uff0d\":\"\\ufe32\",\"\\uff0e\":\"\\u30fb\",\"\\uff1a\":\"\\ufe13\",\"\\uff1b\":\"\\ufe14\",\"\\uff1c\":\"\\ufe3f\",\"\\uff1e\":\"\\ufe40\",\"\\uff1f\":\"\\ufe16\",\"\\uff3b\":\"\\ufe47\",\"\\uff3d\":\"\\ufe48\",\"\\uff3f\":\"\\ufe33\",\"\\uff5b\":\"\\ufe37\",\"\\uff5c\":\"\\u2015\",\"\\uff5d\":\"\\ufe38\",\"\\uff5f\":\"\\ufe35\",\"\\uff60\":\"\\ufe36\",\"\\uff61\":\"\\ufe12\",\"\\uff62\":\"\\ufe41\",\"\\uff63\":\"\\ufe42\"},bs=function(t){function e(e,r,n,i){t.call(this,e,r),this.angle=n,void 0!==i&&(this.segment=i)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.clone=function(){return new e(this.x,this.y,this.angle,this.segment)},e}(i);kn(\"Anchor\",bs);var _s=256;function ws(t,e){var r=e.expression;if(\"constant\"===r.kind)return{kind:\"constant\",layoutSize:r.evaluate(new Un(t+1))};if(\"source\"===r.kind)return{kind:\"source\"};for(var n=r.zoomStops,i=r.interpolationType,a=0;a<n.length&&n[a]<=t;)a++;for(var o=a=Math.max(0,a-1);o<n.length&&n[o]<t+1;)o++;o=Math.min(n.length-1,o);var s=n[a],l=n[o];return\"composite\"===r.kind?{kind:\"composite\",minZoom:s,maxZoom:l,interpolationType:i}:{kind:\"camera\",minZoom:s,maxZoom:l,minSize:r.evaluate(new Un(s)),maxSize:r.evaluate(new Un(l)),interpolationType:i}}function ks(t,e,r){var n=e.uSize,i=e.uSizeT,a=r.lowerSize,o=r.upperSize;return\"source\"===t.kind?a/_s:\"composite\"===t.kind?Ee(a/_s,o/_s,i):n}function Ts(t,e){var r=0,n=0;if(\"constant\"===t.kind)n=t.layoutSize;else if(\"source\"!==t.kind){var i=t.interpolationType,a=t.minZoom,o=t.maxZoom,s=i?c(Xe.interpolationFactor(i,e,a,o),0,1):0;\"camera\"===t.kind?n=Ee(t.minSize,t.maxSize,s):r=s}return{uSizeT:r,uSize:n}}var As=Object.freeze({getSizeData:ws,evaluateSizeForFeature:ks,evaluateSizeForZoom:Ts,SIZE_PACK_FACTOR:_s}),Ms=Vo.VectorTileFeature.types,Ss=[{name:\"a_fade_opacity\",components:1,type:\"Uint8\",offset:0}];function Es(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,Math.round(32*n),Math.round(32*i),a,o,s?s[0]:0,s?s[1]:0)}function Cs(t,e,r){t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r)}var Ls=function(t){this.layoutVertexArray=new pi,this.indexArray=new Ti,this.programConfigurations=t,this.segments=new Vi,this.dynamicLayoutVertexArray=new di,this.opacityVertexArray=new gi,this.placedSymbolArray=new Oi};Ls.prototype.upload=function(t,e,r,n){r&&(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,ps.members),this.indexBuffer=t.createIndexBuffer(this.indexArray,e),this.dynamicLayoutVertexBuffer=t.createVertexBuffer(this.dynamicLayoutVertexArray,ds.members,!0),this.opacityVertexBuffer=t.createVertexBuffer(this.opacityVertexArray,Ss,!0),this.opacityVertexBuffer.itemSize=1),(r||n)&&this.programConfigurations.upload(t)},Ls.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.dynamicLayoutVertexBuffer.destroy(),this.opacityVertexBuffer.destroy())},kn(\"SymbolBuffers\",Ls);var Ps=function(t,e,r){this.layoutVertexArray=new t,this.layoutAttributes=e,this.indexArray=new r,this.segments=new Vi,this.collisionVertexArray=new yi};Ps.prototype.upload=function(t){this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,this.layoutAttributes),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.collisionVertexBuffer=t.createVertexBuffer(this.collisionVertexArray,gs.members,!0)},Ps.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.segments.destroy(),this.collisionVertexBuffer.destroy())},kn(\"CollisionBuffers\",Ps);var Os=function(t){this.collisionBoxArray=t.collisionBoxArray,this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.pixelRatio=t.pixelRatio,this.sourceLayerIndex=t.sourceLayerIndex,this.hasPattern=!1;var e=this.layers[0]._unevaluatedLayout._values;this.textSizeData=ws(this.zoom,e[\"text-size\"]),this.iconSizeData=ws(this.zoom,e[\"icon-size\"]);var r=this.layers[0].layout,n=r.get(\"symbol-sort-key\"),i=r.get(\"symbol-z-order\");this.sortFeaturesByKey=\"viewport-y\"!==i&&void 0!==n.constantOr(1);var a=\"viewport-y\"===i||\"auto\"===i&&!this.sortFeaturesByKey;this.sortFeaturesByY=a&&(r.get(\"text-allow-overlap\")||r.get(\"icon-allow-overlap\")||r.get(\"text-ignore-placement\")||r.get(\"icon-ignore-placement\")),this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id}),this.sourceID=t.sourceID};Os.prototype.createArrays=function(){this.text=new Ls(new la(ps.members,this.layers,this.zoom,function(t){return/^text/.test(t)})),this.icon=new Ls(new la(ps.members,this.layers,this.zoom,function(t){return/^icon/.test(t)})),this.collisionBox=new Ps(mi,vs.members,Ai),this.collisionCircle=new Ps(mi,ms.members,Ti),this.glyphOffsetArray=new Ri,this.lineVertexArray=new Bi,this.symbolInstances=new Ii},Os.prototype.calculateGlyphDependencies=function(t,e,r,n){for(var i=0;i<t.length;i++)if(e[t.charCodeAt(i)]=!0,r&&n){var a=xs[t.charAt(i)];a&&(e[a.charCodeAt(0)]=!0)}},Os.prototype.populate=function(t,e){var r=this.layers[0],n=r.layout,i=n.get(\"text-font\"),a=n.get(\"text-field\"),o=n.get(\"icon-image\"),s=(\"constant\"!==a.value.kind||a.value.value.toString().length>0)&&(\"constant\"!==i.value.kind||i.value.value.length>0),l=\"constant\"!==o.value.kind||o.value.value&&o.value.value.length>0,c=n.get(\"symbol-sort-key\");if(this.features=[],s||l){for(var u=e.iconDependencies,h=e.glyphDependencies,f=new Un(this.zoom),p=0,d=t;p<d.length;p+=1){var g=d[p],v=g.feature,m=g.index,y=g.sourceLayerIndex;if(r._featureFilter(f,v)){var x=void 0;if(s){var b=r.getValueAndResolveTokens(\"text-field\",v);x=ys(b instanceof oe?b:oe.fromString(b),r,v)}var _=void 0;if(l&&(_=r.getValueAndResolveTokens(\"icon-image\",v)),x||_){var w=this.sortFeaturesByKey?c.evaluate(v,{}):void 0,k={text:x,icon:_,index:m,sourceLayerIndex:y,geometry:pa(v),properties:v.properties,type:Ms[v.type],sortKey:w};if(void 0!==v.id&&(k.id=v.id),this.features.push(k),_&&(u[_]=!0),x)for(var T=i.evaluate(v,{}).join(\",\"),A=\"map\"===n.get(\"text-rotation-alignment\")&&\"point\"!==n.get(\"symbol-placement\"),M=0,S=x.sections;M<S.length;M+=1){var E=S[M],C=Cn(x.toString()),L=E.fontStack||T,P=h[L]=h[L]||{};this.calculateGlyphDependencies(E.text,P,A,C)}}}}\"line\"===n.get(\"symbol-placement\")&&(this.features=function(t){var e={},r={},n=[],i=0;function a(e){n.push(t[e]),i++}function o(t,e,i){var a=r[t];return delete r[t],r[e]=a,n[a].geometry[0].pop(),n[a].geometry[0]=n[a].geometry[0].concat(i[0]),a}function s(t,r,i){var a=e[r];return delete e[r],e[t]=a,n[a].geometry[0].shift(),n[a].geometry[0]=i[0].concat(n[a].geometry[0]),a}function l(t,e,r){var n=r?e[0][e[0].length-1]:e[0][0];return t+\":\"+n.x+\":\"+n.y}for(var c=0;c<t.length;c++){var u=t[c],h=u.geometry,f=u.text?u.text.toString():null;if(f){var p=l(f,h),d=l(f,h,!0);if(p in r&&d in e&&r[p]!==e[d]){var g=s(p,d,h),v=o(p,d,n[g].geometry);delete e[p],delete r[d],r[l(f,n[v].geometry,!0)]=v,n[g].geometry=null}else p in r?o(p,d,h):d in e?s(p,d,h):(a(c),e[p]=i-1,r[d]=i-1)}else a(c)}return n.filter(function(t){return t.geometry})}(this.features)),this.sortFeaturesByKey&&this.features.sort(function(t,e){return t.sortKey-e.sortKey})}},Os.prototype.update=function(t,e,r){this.stateDependentLayers.length&&(this.text.programConfigurations.updatePaintArrays(t,e,this.layers,r),this.icon.programConfigurations.updatePaintArrays(t,e,this.layers,r))},Os.prototype.isEmpty=function(){return 0===this.symbolInstances.length},Os.prototype.uploadPending=function(){return!this.uploaded||this.text.programConfigurations.needsUpload||this.icon.programConfigurations.needsUpload},Os.prototype.upload=function(t){this.uploaded||(this.collisionBox.upload(t),this.collisionCircle.upload(t)),this.text.upload(t,this.sortFeaturesByY,!this.uploaded,this.text.programConfigurations.needsUpload),this.icon.upload(t,this.sortFeaturesByY,!this.uploaded,this.icon.programConfigurations.needsUpload),this.uploaded=!0},Os.prototype.destroy=function(){this.text.destroy(),this.icon.destroy(),this.collisionBox.destroy(),this.collisionCircle.destroy()},Os.prototype.addToLineVertexArray=function(t,e){var r=this.lineVertexArray.length;if(void 0!==t.segment){for(var n=t.dist(e[t.segment+1]),i=t.dist(e[t.segment]),a={},o=t.segment+1;o<e.length;o++)a[o]={x:e[o].x,y:e[o].y,tileUnitDistanceFromAnchor:n},o<e.length-1&&(n+=e[o+1].dist(e[o]));for(var s=t.segment||0;s>=0;s--)a[s]={x:e[s].x,y:e[s].y,tileUnitDistanceFromAnchor:i},s>0&&(i+=e[s-1].dist(e[s]));for(var l=0;l<e.length;l++){var c=a[l];this.lineVertexArray.emplaceBack(c.x,c.y,c.tileUnitDistanceFromAnchor)}}return{lineStartIndex:r,lineLength:this.lineVertexArray.length-r}},Os.prototype.addSymbols=function(t,e,r,n,i,a,o,s,l,c){for(var u=t.indexArray,h=t.layoutVertexArray,f=t.dynamicLayoutVertexArray,p=t.segments.prepareSegment(4*e.length,t.layoutVertexArray,t.indexArray,a.sortKey),d=this.glyphOffsetArray.length,g=p.vertexLength,v=0,m=e;v<m.length;v+=1){var y=m[v],x=y.tl,b=y.tr,_=y.bl,w=y.br,k=y.tex,T=p.vertexLength,A=y.glyphOffset[1];Es(h,s.x,s.y,x.x,A+x.y,k.x,k.y,r),Es(h,s.x,s.y,b.x,A+b.y,k.x+k.w,k.y,r),Es(h,s.x,s.y,_.x,A+_.y,k.x,k.y+k.h,r),Es(h,s.x,s.y,w.x,A+w.y,k.x+k.w,k.y+k.h,r),Cs(f,s,0),u.emplaceBack(T,T+1,T+2),u.emplaceBack(T+1,T+2,T+3),p.vertexLength+=4,p.primitiveLength+=2,this.glyphOffsetArray.emplaceBack(y.glyphOffset[0])}t.placedSymbolArray.emplaceBack(s.x,s.y,d,this.glyphOffsetArray.length-d,g,l,c,s.segment,r?r[0]:0,r?r[1]:0,n[0],n[1],o,!1,0),t.programConfigurations.populatePaintArrays(t.layoutVertexArray.length,a,a.index,{})},Os.prototype._addCollisionDebugVertex=function(t,e,r,n,i,a){return e.emplaceBack(0,0),t.emplaceBack(r.x,r.y,n,i,Math.round(a.x),Math.round(a.y))},Os.prototype.addCollisionDebugVertices=function(t,e,r,n,a,o,s,l){var c=a.segments.prepareSegment(4,a.layoutVertexArray,a.indexArray),u=c.vertexLength,h=a.layoutVertexArray,f=a.collisionVertexArray,p=s.anchorX,d=s.anchorY;if(this._addCollisionDebugVertex(h,f,o,p,d,new i(t,e)),this._addCollisionDebugVertex(h,f,o,p,d,new i(r,e)),this._addCollisionDebugVertex(h,f,o,p,d,new i(r,n)),this._addCollisionDebugVertex(h,f,o,p,d,new i(t,n)),c.vertexLength+=4,l){var g=a.indexArray;g.emplaceBack(u,u+1,u+2),g.emplaceBack(u,u+2,u+3),c.primitiveLength+=2}else{var v=a.indexArray;v.emplaceBack(u,u+1),v.emplaceBack(u+1,u+2),v.emplaceBack(u+2,u+3),v.emplaceBack(u+3,u),c.primitiveLength+=4}},Os.prototype.addDebugCollisionBoxes=function(t,e,r){for(var n=t;n<e;n++){var i=this.collisionBoxArray.get(n),a=i.x1,o=i.y1,s=i.x2,l=i.y2,c=i.radius>0;this.addCollisionDebugVertices(a,o,s,l,c?this.collisionCircle:this.collisionBox,i.anchorPoint,r,c)}},Os.prototype.generateCollisionDebugBuffers=function(){for(var t=0;t<this.symbolInstances.length;t++){var e=this.symbolInstances.get(t);this.addDebugCollisionBoxes(e.textBoxStartIndex,e.textBoxEndIndex,e),this.addDebugCollisionBoxes(e.iconBoxStartIndex,e.iconBoxEndIndex,e)}},Os.prototype._deserializeCollisionBoxesForSymbol=function(t,e,r,n,i){for(var a={},o=e;o<r;o++){var s=t.get(o);if(0===s.radius){a.textBox={x1:s.x1,y1:s.y1,x2:s.x2,y2:s.y2,anchorPointX:s.anchorPointX,anchorPointY:s.anchorPointY},a.textFeatureIndex=s.featureIndex;break}a.textCircles||(a.textCircles=[],a.textFeatureIndex=s.featureIndex),a.textCircles.push(s.anchorPointX,s.anchorPointY,s.radius,s.signedDistanceFromAnchor,1)}for(var l=n;l<i;l++){var c=t.get(l);if(0===c.radius){a.iconBox={x1:c.x1,y1:c.y1,x2:c.x2,y2:c.y2,anchorPointX:c.anchorPointX,anchorPointY:c.anchorPointY},a.iconFeatureIndex=c.featureIndex;break}}return a},Os.prototype.deserializeCollisionBoxes=function(t){this.collisionArrays=[];for(var e=0;e<this.symbolInstances.length;e++){var r=this.symbolInstances.get(e);this.collisionArrays.push(this._deserializeCollisionBoxesForSymbol(t,r.textBoxStartIndex,r.textBoxEndIndex,r.iconBoxStartIndex,r.iconBoxEndIndex))}},Os.prototype.hasTextData=function(){return this.text.segments.get().length>0},Os.prototype.hasIconData=function(){return this.icon.segments.get().length>0},Os.prototype.hasCollisionBoxData=function(){return this.collisionBox.segments.get().length>0},Os.prototype.hasCollisionCircleData=function(){return this.collisionCircle.segments.get().length>0},Os.prototype.addIndicesForPlacedTextSymbol=function(t){for(var e=this.text.placedSymbolArray.get(t),r=e.vertexStartIndex+4*e.numGlyphs,n=e.vertexStartIndex;n<r;n+=4)this.text.indexArray.emplaceBack(n,n+1,n+2),this.text.indexArray.emplaceBack(n+1,n+2,n+3)},Os.prototype.getSortedSymbolIndexes=function(t){if(this.sortedAngle===t&&void 0!==this.symbolInstanceIndexes)return this.symbolInstanceIndexes;for(var e=Math.sin(t),r=Math.cos(t),n=[],i=[],a=[],o=0;o<this.symbolInstances.length;++o){a.push(o);var s=this.symbolInstances.get(o);n.push(0|Math.round(e*s.anchorX+r*s.anchorY)),i.push(s.featureIndex)}return a.sort(function(t,e){return n[t]-n[e]||i[e]-i[t]}),a},Os.prototype.sortFeatures=function(t){var e=this;if(this.sortFeaturesByY&&this.sortedAngle!==t&&!(this.text.segments.get().length>1||this.icon.segments.get().length>1)){this.symbolInstanceIndexes=this.getSortedSymbolIndexes(t),this.sortedAngle=t,this.text.indexArray.clear(),this.icon.indexArray.clear(),this.featureSortOrder=[];for(var r=0,n=this.symbolInstanceIndexes;r<n.length;r+=1){var i=n[r],a=this.symbolInstances.get(i);this.featureSortOrder.push(a.featureIndex),[a.rightJustifiedTextSymbolIndex,a.centerJustifiedTextSymbolIndex,a.leftJustifiedTextSymbolIndex].forEach(function(t,r,n){t>=0&&n.indexOf(t)===r&&e.addIndicesForPlacedTextSymbol(t)}),a.verticalPlacedTextSymbolIndex>=0&&this.addIndicesForPlacedTextSymbol(a.verticalPlacedTextSymbolIndex);var o=this.icon.placedSymbolArray.get(i);if(o.numGlyphs){var s=o.vertexStartIndex;this.icon.indexArray.emplaceBack(s,s+1,s+2),this.icon.indexArray.emplaceBack(s+1,s+2,s+3)}}this.text.indexBuffer&&this.text.indexBuffer.updateData(this.text.indexArray),this.icon.indexBuffer&&this.icon.indexBuffer.updateData(this.icon.indexArray)}},kn(\"SymbolBucket\",Os,{omit:[\"layers\",\"collisionBoxArray\",\"features\",\"compareText\"]}),Os.MAX_GLYPHS=65535,Os.addDynamicAttributes=Cs;var zs=new ei({\"symbol-placement\":new Jn(It.layout_symbol[\"symbol-placement\"]),\"symbol-spacing\":new Jn(It.layout_symbol[\"symbol-spacing\"]),\"symbol-avoid-edges\":new Jn(It.layout_symbol[\"symbol-avoid-edges\"]),\"symbol-sort-key\":new Kn(It.layout_symbol[\"symbol-sort-key\"]),\"symbol-z-order\":new Jn(It.layout_symbol[\"symbol-z-order\"]),\"icon-allow-overlap\":new Jn(It.layout_symbol[\"icon-allow-overlap\"]),\"icon-ignore-placement\":new Jn(It.layout_symbol[\"icon-ignore-placement\"]),\"icon-optional\":new Jn(It.layout_symbol[\"icon-optional\"]),\"icon-rotation-alignment\":new Jn(It.layout_symbol[\"icon-rotation-alignment\"]),\"icon-size\":new Kn(It.layout_symbol[\"icon-size\"]),\"icon-text-fit\":new Jn(It.layout_symbol[\"icon-text-fit\"]),\"icon-text-fit-padding\":new Jn(It.layout_symbol[\"icon-text-fit-padding\"]),\"icon-image\":new Kn(It.layout_symbol[\"icon-image\"]),\"icon-rotate\":new Kn(It.layout_symbol[\"icon-rotate\"]),\"icon-padding\":new Jn(It.layout_symbol[\"icon-padding\"]),\"icon-keep-upright\":new Jn(It.layout_symbol[\"icon-keep-upright\"]),\"icon-offset\":new Kn(It.layout_symbol[\"icon-offset\"]),\"icon-anchor\":new Kn(It.layout_symbol[\"icon-anchor\"]),\"icon-pitch-alignment\":new Jn(It.layout_symbol[\"icon-pitch-alignment\"]),\"text-pitch-alignment\":new Jn(It.layout_symbol[\"text-pitch-alignment\"]),\"text-rotation-alignment\":new Jn(It.layout_symbol[\"text-rotation-alignment\"]),\"text-field\":new Kn(It.layout_symbol[\"text-field\"]),\"text-font\":new Kn(It.layout_symbol[\"text-font\"]),\"text-size\":new Kn(It.layout_symbol[\"text-size\"]),\"text-max-width\":new Kn(It.layout_symbol[\"text-max-width\"]),\"text-line-height\":new Jn(It.layout_symbol[\"text-line-height\"]),\"text-letter-spacing\":new Kn(It.layout_symbol[\"text-letter-spacing\"]),\"text-justify\":new Kn(It.layout_symbol[\"text-justify\"]),\"text-radial-offset\":new Kn(It.layout_symbol[\"text-radial-offset\"]),\"text-variable-anchor\":new Jn(It.layout_symbol[\"text-variable-anchor\"]),\"text-anchor\":new Kn(It.layout_symbol[\"text-anchor\"]),\"text-max-angle\":new Jn(It.layout_symbol[\"text-max-angle\"]),\"text-rotate\":new Kn(It.layout_symbol[\"text-rotate\"]),\"text-padding\":new Jn(It.layout_symbol[\"text-padding\"]),\"text-keep-upright\":new Jn(It.layout_symbol[\"text-keep-upright\"]),\"text-transform\":new Kn(It.layout_symbol[\"text-transform\"]),\"text-offset\":new Kn(It.layout_symbol[\"text-offset\"]),\"text-allow-overlap\":new Jn(It.layout_symbol[\"text-allow-overlap\"]),\"text-ignore-placement\":new Jn(It.layout_symbol[\"text-ignore-placement\"]),\"text-optional\":new Jn(It.layout_symbol[\"text-optional\"])}),Is={paint:new ei({\"icon-opacity\":new Kn(It.paint_symbol[\"icon-opacity\"]),\"icon-color\":new Kn(It.paint_symbol[\"icon-color\"]),\"icon-halo-color\":new Kn(It.paint_symbol[\"icon-halo-color\"]),\"icon-halo-width\":new Kn(It.paint_symbol[\"icon-halo-width\"]),\"icon-halo-blur\":new Kn(It.paint_symbol[\"icon-halo-blur\"]),\"icon-translate\":new Jn(It.paint_symbol[\"icon-translate\"]),\"icon-translate-anchor\":new Jn(It.paint_symbol[\"icon-translate-anchor\"]),\"text-opacity\":new Kn(It.paint_symbol[\"text-opacity\"]),\"text-color\":new Kn(It.paint_symbol[\"text-color\"]),\"text-halo-color\":new Kn(It.paint_symbol[\"text-halo-color\"]),\"text-halo-width\":new Kn(It.paint_symbol[\"text-halo-width\"]),\"text-halo-blur\":new Kn(It.paint_symbol[\"text-halo-blur\"]),\"text-translate\":new Jn(It.paint_symbol[\"text-translate\"]),\"text-translate-anchor\":new Jn(It.paint_symbol[\"text-translate-anchor\"])}),layout:zs},Ds=function(t){function e(e){t.call(this,e,Is)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e),\"auto\"===this.layout.get(\"icon-rotation-alignment\")&&(\"point\"!==this.layout.get(\"symbol-placement\")?this.layout._values[\"icon-rotation-alignment\"]=\"map\":this.layout._values[\"icon-rotation-alignment\"]=\"viewport\"),\"auto\"===this.layout.get(\"text-rotation-alignment\")&&(\"point\"!==this.layout.get(\"symbol-placement\")?this.layout._values[\"text-rotation-alignment\"]=\"map\":this.layout._values[\"text-rotation-alignment\"]=\"viewport\"),\"auto\"===this.layout.get(\"text-pitch-alignment\")&&(this.layout._values[\"text-pitch-alignment\"]=this.layout.get(\"text-rotation-alignment\")),\"auto\"===this.layout.get(\"icon-pitch-alignment\")&&(this.layout._values[\"icon-pitch-alignment\"]=this.layout.get(\"icon-rotation-alignment\"))},e.prototype.getValueAndResolveTokens=function(t,e){var r,n=this.layout.get(t).evaluate(e,{}),i=this._unevaluatedLayout._values[t];return i.isDataDriven()||Pr(i.value)?n:(r=e.properties,n.replace(/{([^{}]+)}/g,function(t,e){return e in r?String(r[e]):\"\"}))},e.prototype.createBucket=function(t){return new Os(t)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e}(ri),Rs={paint:new ei({\"background-color\":new Jn(It.paint_background[\"background-color\"]),\"background-pattern\":new Qn(It.paint_background[\"background-pattern\"]),\"background-opacity\":new Jn(It.paint_background[\"background-opacity\"])})},Fs=function(t){function e(e){t.call(this,e,Rs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ri),Bs={paint:new ei({\"raster-opacity\":new Jn(It.paint_raster[\"raster-opacity\"]),\"raster-hue-rotate\":new Jn(It.paint_raster[\"raster-hue-rotate\"]),\"raster-brightness-min\":new Jn(It.paint_raster[\"raster-brightness-min\"]),\"raster-brightness-max\":new Jn(It.paint_raster[\"raster-brightness-max\"]),\"raster-saturation\":new Jn(It.paint_raster[\"raster-saturation\"]),\"raster-contrast\":new Jn(It.paint_raster[\"raster-contrast\"]),\"raster-resampling\":new Jn(It.paint_raster[\"raster-resampling\"]),\"raster-fade-duration\":new Jn(It.paint_raster[\"raster-fade-duration\"])})},Ns=function(t){function e(e){t.call(this,e,Bs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ri),js=function(t){function e(e){t.call(this,e,{}),this.implementation=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.is3D=function(){return\"3d\"===this.implementation.renderingMode},e.prototype.hasOffscreenPass=function(){return void 0!==this.implementation.prerender},e.prototype.recalculate=function(){},e.prototype.updateTransitions=function(){},e.prototype.hasTransition=function(){},e.prototype.serialize=function(){},e.prototype.onAdd=function(t){this.implementation.onAdd&&this.implementation.onAdd(t,t.painter.context.gl)},e.prototype.onRemove=function(t){this.implementation.onRemove&&this.implementation.onRemove(t,t.painter.context.gl)},e}(ri),Us={circle:Fa,heatmap:Wa,hillshade:Za,fill:Oo,\"fill-extrusion\":Jo,line:hs,symbol:Ds,background:Fs,raster:Ns};function Vs(t){for(var e=0,r=0,n=0,i=t;n<i.length;n+=1){var a=i[n];e+=a.w*a.h,r=Math.max(r,a.w)}t.sort(function(t,e){return e.h-t.h});for(var o=[{x:0,y:0,w:Math.max(Math.ceil(Math.sqrt(e/.95)),r),h:1/0}],s=0,l=0,c=0,u=t;c<u.length;c+=1)for(var h=u[c],f=o.length-1;f>=0;f--){var p=o[f];if(!(h.w>p.w||h.h>p.h)){if(h.x=p.x,h.y=p.y,l=Math.max(l,h.y+h.h),s=Math.max(s,h.x+h.w),h.w===p.w&&h.h===p.h){var d=o.pop();f<o.length&&(o[f]=d)}else h.h===p.h?(p.x+=h.w,p.w-=h.w):h.w===p.w?(p.y+=h.h,p.h-=h.h):(o.push({x:p.x+h.w,y:p.y,w:p.w-h.w,h:h.h}),p.y+=h.h,p.h-=h.h);break}}return{w:s,h:l,fill:e/(s*l)||0}}var qs=function(t,e){var r=e.pixelRatio,n=e.version;this.paddedRect=t,this.pixelRatio=r,this.version=n},Hs={tl:{configurable:!0},br:{configurable:!0},tlbr:{configurable:!0},displaySize:{configurable:!0}};Hs.tl.get=function(){return[this.paddedRect.x+1,this.paddedRect.y+1]},Hs.br.get=function(){return[this.paddedRect.x+this.paddedRect.w-1,this.paddedRect.y+this.paddedRect.h-1]},Hs.tlbr.get=function(){return this.tl.concat(this.br)},Hs.displaySize.get=function(){return[(this.paddedRect.w-2)/this.pixelRatio,(this.paddedRect.h-2)/this.pixelRatio]},Object.defineProperties(qs.prototype,Hs);var Gs=function(t,e){var r={},n={};this.haveRenderCallbacks=[];var i=[];this.addImages(t,r,i),this.addImages(e,n,i);var a=Vs(i),o=a.w,s=a.h,l=new Ha({width:o||1,height:s||1});for(var c in t){var u=t[c],h=r[c].paddedRect;Ha.copy(u.data,l,{x:0,y:0},{x:h.x+1,y:h.y+1},u.data)}for(var f in e){var p=e[f],d=n[f].paddedRect,g=d.x+1,v=d.y+1,m=p.data.width,y=p.data.height;Ha.copy(p.data,l,{x:0,y:0},{x:g,y:v},p.data),Ha.copy(p.data,l,{x:0,y:y-1},{x:g,y:v-1},{width:m,height:1}),Ha.copy(p.data,l,{x:0,y:0},{x:g,y:v+y},{width:m,height:1}),Ha.copy(p.data,l,{x:m-1,y:0},{x:g-1,y:v},{width:1,height:y}),Ha.copy(p.data,l,{x:0,y:0},{x:g+m,y:v},{width:1,height:y})}this.image=l,this.iconPositions=r,this.patternPositions=n};Gs.prototype.addImages=function(t,e,r){for(var n in t){var i=t[n],a={x:0,y:0,w:i.data.width+2,h:i.data.height+2};r.push(a),e[n]=new qs(a,i),i.hasRenderCallback&&this.haveRenderCallbacks.push(n)}},Gs.prototype.patchUpdatedImages=function(t,e){for(var r in t.dispatchRenderCallbacks(this.haveRenderCallbacks),t.updatedImages)this.patchUpdatedImage(this.iconPositions[r],t.getImage(r),e),this.patchUpdatedImage(this.patternPositions[r],t.getImage(r),e)},Gs.prototype.patchUpdatedImage=function(t,e,r){if(t&&e&&t.version!==e.version){t.version=e.version;var n=t.tl,i=n[0],a=n[1];r.update(e.data,void 0,{x:i,y:a})}},kn(\"ImagePosition\",qs),kn(\"ImageAtlas\",Gs);var Ys=self.HTMLImageElement,Ws=self.HTMLCanvasElement,Xs=self.HTMLVideoElement,Zs=self.ImageData,Js=function(t,e,r,n){this.context=t,this.format=r,this.texture=t.gl.createTexture(),this.update(e,n)};Js.prototype.update=function(t,e,r){var n=t.width,i=t.height,a=!(this.size&&this.size[0]===n&&this.size[1]===i||r),o=this.context,s=o.gl;if(this.useMipmap=Boolean(e&&e.useMipmap),s.bindTexture(s.TEXTURE_2D,this.texture),o.pixelStoreUnpackFlipY.set(!1),o.pixelStoreUnpack.set(1),o.pixelStoreUnpackPremultiplyAlpha.set(this.format===s.RGBA&&(!e||!1!==e.premultiply)),a)this.size=[n,i],t instanceof Ys||t instanceof Ws||t instanceof Xs||t instanceof Zs?s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,s.UNSIGNED_BYTE,t):s.texImage2D(s.TEXTURE_2D,0,this.format,n,i,0,this.format,s.UNSIGNED_BYTE,t.data);else{var l=r||{x:0,y:0},c=l.x,u=l.y;t instanceof Ys||t instanceof Ws||t instanceof Xs||t instanceof Zs?s.texSubImage2D(s.TEXTURE_2D,0,c,u,s.RGBA,s.UNSIGNED_BYTE,t):s.texSubImage2D(s.TEXTURE_2D,0,c,u,n,i,s.RGBA,s.UNSIGNED_BYTE,t.data)}this.useMipmap&&this.isSizePowerOfTwo()&&s.generateMipmap(s.TEXTURE_2D)},Js.prototype.bind=function(t,e,r){var n=this.context.gl;n.bindTexture(n.TEXTURE_2D,this.texture),r!==n.LINEAR_MIPMAP_NEAREST||this.isSizePowerOfTwo()||(r=n.LINEAR),t!==this.filter&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,t),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,r||t),this.filter=t),e!==this.wrap&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,e),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,e),this.wrap=e)},Js.prototype.isSizePowerOfTwo=function(){return this.size[0]===this.size[1]&&Math.log(this.size[0])/Math.LN2%1==0},Js.prototype.destroy=function(){this.context.gl.deleteTexture(this.texture),this.texture=null};var Ks=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?i-1:0,f=r?-1:1,p=t[e+h];for(h+=f,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+h],h+=f,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},$s=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,h=u>>1,f=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,i),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g},Qs=tl;function tl(t){this.buf=ArrayBuffer.isView&&ArrayBuffer.isView(t)?t:new Uint8Array(t||0),this.pos=0,this.type=0,this.length=this.buf.length}function el(t){return t.type===tl.Bytes?t.readVarint()+t.pos:t.pos+1}function rl(t,e,r){return r?4294967296*e+(t>>>0):4294967296*(e>>>0)+(t>>>0)}function nl(t,e,r){var n=e<=16383?1:e<=2097151?2:e<=268435455?3:Math.floor(Math.log(e)/(7*Math.LN2));r.realloc(n);for(var i=r.pos-1;i>=t;i--)r.buf[i+n]=r.buf[i]}function il(t,e){for(var r=0;r<t.length;r++)e.writeVarint(t[r])}function al(t,e){for(var r=0;r<t.length;r++)e.writeSVarint(t[r])}function ol(t,e){for(var r=0;r<t.length;r++)e.writeFloat(t[r])}function sl(t,e){for(var r=0;r<t.length;r++)e.writeDouble(t[r])}function ll(t,e){for(var r=0;r<t.length;r++)e.writeBoolean(t[r])}function cl(t,e){for(var r=0;r<t.length;r++)e.writeFixed32(t[r])}function ul(t,e){for(var r=0;r<t.length;r++)e.writeSFixed32(t[r])}function hl(t,e){for(var r=0;r<t.length;r++)e.writeFixed64(t[r])}function fl(t,e){for(var r=0;r<t.length;r++)e.writeSFixed64(t[r])}function pl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+16777216*t[e+3]}function dl(t,e,r){t[r]=e,t[r+1]=e>>>8,t[r+2]=e>>>16,t[r+3]=e>>>24}function gl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+(t[e+3]<<24)}tl.Varint=0,tl.Fixed64=1,tl.Bytes=2,tl.Fixed32=5,tl.prototype={destroy:function(){this.buf=null},readFields:function(t,e,r){for(r=r||this.length;this.pos<r;){var n=this.readVarint(),i=n>>3,a=this.pos;this.type=7&n,t(i,e,this),this.pos===a&&this.skip(n)}return e},readMessage:function(t,e){return this.readFields(t,e,this.readVarint()+this.pos)},readFixed32:function(){var t=pl(this.buf,this.pos);return this.pos+=4,t},readSFixed32:function(){var t=gl(this.buf,this.pos);return this.pos+=4,t},readFixed64:function(){var t=pl(this.buf,this.pos)+4294967296*pl(this.buf,this.pos+4);return this.pos+=8,t},readSFixed64:function(){var t=pl(this.buf,this.pos)+4294967296*gl(this.buf,this.pos+4);return this.pos+=8,t},readFloat:function(){var t=Ks(this.buf,this.pos,!0,23,4);return this.pos+=4,t},readDouble:function(){var t=Ks(this.buf,this.pos,!0,52,8);return this.pos+=8,t},readVarint:function(t){var e,r,n=this.buf;return e=127&(r=n[this.pos++]),r<128?e:(e|=(127&(r=n[this.pos++]))<<7,r<128?e:(e|=(127&(r=n[this.pos++]))<<14,r<128?e:(e|=(127&(r=n[this.pos++]))<<21,r<128?e:function(t,e,r){var n,i,a=r.buf;if(n=(112&(i=a[r.pos++]))>>4,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<3,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<10,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<17,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<24,i<128)return rl(t,n,e);if(n|=(1&(i=a[r.pos++]))<<31,i<128)return rl(t,n,e);throw new Error(\"Expected varint not more than 10 bytes\")}(e|=(15&(r=n[this.pos]))<<28,t,this))))},readVarint64:function(){return this.readVarint(!0)},readSVarint:function(){var t=this.readVarint();return t%2==1?(t+1)/-2:t/2},readBoolean:function(){return Boolean(this.readVarint())},readString:function(){var t=this.readVarint()+this.pos,e=function(t,e,r){for(var n=\"\",i=e;i<r;){var a,o,s,l=t[i],c=null,u=l>239?4:l>223?3:l>191?2:1;if(i+u>r)break;1===u?l<128&&(c=l):2===u?128==(192&(a=t[i+1]))&&(c=(31&l)<<6|63&a)<=127&&(c=null):3===u?(a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&((c=(15&l)<<12|(63&a)<<6|63&o)<=2047||c>=55296&&c<=57343)&&(c=null)):4===u&&(a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&((c=(15&l)<<18|(63&a)<<12|(63&o)<<6|63&s)<=65535||c>=1114112)&&(c=null)),null===c?(c=65533,u=1):c>65535&&(c-=65536,n+=String.fromCharCode(c>>>10&1023|55296),c=56320|1023&c),n+=String.fromCharCode(c),i+=u}return n}(this.buf,this.pos,t);return this.pos=t,e},readBytes:function(){var t=this.readVarint()+this.pos,e=this.buf.subarray(this.pos,t);return this.pos=t,e},readPackedVarint:function(t,e){if(this.type!==tl.Bytes)return t.push(this.readVarint(e));var r=el(this);for(t=t||[];this.pos<r;)t.push(this.readVarint(e));return t},readPackedSVarint:function(t){if(this.type!==tl.Bytes)return t.push(this.readSVarint());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSVarint());return t},readPackedBoolean:function(t){if(this.type!==tl.Bytes)return t.push(this.readBoolean());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readBoolean());return t},readPackedFloat:function(t){if(this.type!==tl.Bytes)return t.push(this.readFloat());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFloat());return t},readPackedDouble:function(t){if(this.type!==tl.Bytes)return t.push(this.readDouble());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readDouble());return t},readPackedFixed32:function(t){if(this.type!==tl.Bytes)return t.push(this.readFixed32());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFixed32());return t},readPackedSFixed32:function(t){if(this.type!==tl.Bytes)return t.push(this.readSFixed32());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed32());return t},readPackedFixed64:function(t){if(this.type!==tl.Bytes)return t.push(this.readFixed64());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFixed64());return t},readPackedSFixed64:function(t){if(this.type!==tl.Bytes)return t.push(this.readSFixed64());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed64());return t},skip:function(t){var e=7&t;if(e===tl.Varint)for(;this.buf[this.pos++]>127;);else if(e===tl.Bytes)this.pos=this.readVarint()+this.pos;else if(e===tl.Fixed32)this.pos+=4;else{if(e!==tl.Fixed64)throw new Error(\"Unimplemented type: \"+e);this.pos+=8}},writeTag:function(t,e){this.writeVarint(t<<3|e)},realloc:function(t){for(var e=this.length||16;e<this.pos+t;)e*=2;if(e!==this.length){var r=new Uint8Array(e);r.set(this.buf),this.buf=r,this.length=e}},finish:function(){return this.length=this.pos,this.pos=0,this.buf.subarray(0,this.length)},writeFixed32:function(t){this.realloc(4),dl(this.buf,t,this.pos),this.pos+=4},writeSFixed32:function(t){this.realloc(4),dl(this.buf,t,this.pos),this.pos+=4},writeFixed64:function(t){this.realloc(8),dl(this.buf,-1&t,this.pos),dl(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeSFixed64:function(t){this.realloc(8),dl(this.buf,-1&t,this.pos),dl(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeVarint:function(t){(t=+t||0)>268435455||t<0?function(t,e){var r,n;if(t>=0?(r=t%4294967296|0,n=t/4294967296|0):(n=~(-t/4294967296),4294967295^(r=~(-t%4294967296))?r=r+1|0:(r=0,n=n+1|0)),t>=0x10000000000000000||t<-0x10000000000000000)throw new Error(\"Given varint doesn't fit into 10 bytes\");e.realloc(10),function(t,e,r){r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos]=127&t}(r,0,e),function(t,e){var r=(7&t)<<4;e.buf[e.pos++]|=r|((t>>>=3)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t)))))}(n,e)}(t,this):(this.realloc(4),this.buf[this.pos++]=127&t|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=t>>>7&127))))},writeSVarint:function(t){this.writeVarint(t<0?2*-t-1:2*t)},writeBoolean:function(t){this.writeVarint(Boolean(t))},writeString:function(t){t=String(t),this.realloc(4*t.length),this.pos++;var e=this.pos;this.pos=function(t,e,r){for(var n,i,a=0;a<e.length;a++){if((n=e.charCodeAt(a))>55295&&n<57344){if(!i){n>56319||a+1===e.length?(t[r++]=239,t[r++]=191,t[r++]=189):i=n;continue}if(n<56320){t[r++]=239,t[r++]=191,t[r++]=189,i=n;continue}n=i-55296<<10|n-56320|65536,i=null}else i&&(t[r++]=239,t[r++]=191,t[r++]=189,i=null);n<128?t[r++]=n:(n<2048?t[r++]=n>>6|192:(n<65536?t[r++]=n>>12|224:(t[r++]=n>>18|240,t[r++]=n>>12&63|128),t[r++]=n>>6&63|128),t[r++]=63&n|128)}return r}(this.buf,t,this.pos);var r=this.pos-e;r>=128&&nl(e,r,this),this.pos=e-1,this.writeVarint(r),this.pos+=r},writeFloat:function(t){this.realloc(4),$s(this.buf,t,this.pos,!0,23,4),this.pos+=4},writeDouble:function(t){this.realloc(8),$s(this.buf,t,this.pos,!0,52,8),this.pos+=8},writeBytes:function(t){var e=t.length;this.writeVarint(e),this.realloc(e);for(var r=0;r<e;r++)this.buf[this.pos++]=t[r]},writeRawMessage:function(t,e){this.pos++;var r=this.pos;t(e,this);var n=this.pos-r;n>=128&&nl(r,n,this),this.pos=r-1,this.writeVarint(n),this.pos+=n},writeMessage:function(t,e,r){this.writeTag(t,tl.Bytes),this.writeRawMessage(e,r)},writePackedVarint:function(t,e){e.length&&this.writeMessage(t,il,e)},writePackedSVarint:function(t,e){e.length&&this.writeMessage(t,al,e)},writePackedBoolean:function(t,e){e.length&&this.writeMessage(t,ll,e)},writePackedFloat:function(t,e){e.length&&this.writeMessage(t,ol,e)},writePackedDouble:function(t,e){e.length&&this.writeMessage(t,sl,e)},writePackedFixed32:function(t,e){e.length&&this.writeMessage(t,cl,e)},writePackedSFixed32:function(t,e){e.length&&this.writeMessage(t,ul,e)},writePackedFixed64:function(t,e){e.length&&this.writeMessage(t,hl,e)},writePackedSFixed64:function(t,e){e.length&&this.writeMessage(t,fl,e)},writeBytesField:function(t,e){this.writeTag(t,tl.Bytes),this.writeBytes(e)},writeFixed32Field:function(t,e){this.writeTag(t,tl.Fixed32),this.writeFixed32(e)},writeSFixed32Field:function(t,e){this.writeTag(t,tl.Fixed32),this.writeSFixed32(e)},writeFixed64Field:function(t,e){this.writeTag(t,tl.Fixed64),this.writeFixed64(e)},writeSFixed64Field:function(t,e){this.writeTag(t,tl.Fixed64),this.writeSFixed64(e)},writeVarintField:function(t,e){this.writeTag(t,tl.Varint),this.writeVarint(e)},writeSVarintField:function(t,e){this.writeTag(t,tl.Varint),this.writeSVarint(e)},writeStringField:function(t,e){this.writeTag(t,tl.Bytes),this.writeString(e)},writeFloatField:function(t,e){this.writeTag(t,tl.Fixed32),this.writeFloat(e)},writeDoubleField:function(t,e){this.writeTag(t,tl.Fixed64),this.writeDouble(e)},writeBooleanField:function(t,e){this.writeVarintField(t,Boolean(e))}};var vl=3;function ml(t,e,r){1===t&&r.readMessage(yl,e)}function yl(t,e,r){if(3===t){var n=r.readMessage(xl,{}),i=n.id,a=n.bitmap,o=n.width,s=n.height,l=n.left,c=n.top,u=n.advance;e.push({id:i,bitmap:new qa({width:o+2*vl,height:s+2*vl},a),metrics:{width:o,height:s,left:l,top:c,advance:u}})}}function xl(t,e,r){1===t?e.id=r.readVarint():2===t?e.bitmap=r.readBytes():3===t?e.width=r.readVarint():4===t?e.height=r.readVarint():5===t?e.left=r.readSVarint():6===t?e.top=r.readSVarint():7===t&&(e.advance=r.readVarint())}var bl=vl,_l=function(t,e,r){this.target=t,this.parent=e,this.mapId=r,this.callbacks={},this.callbackID=0,v([\"receive\"],this),this.target.addEventListener(\"message\",this.receive,!1)};function wl(t,e,r){var n=2*Math.PI*6378137/256/Math.pow(2,r);return[t*n-2*Math.PI*6378137/2,e*n-2*Math.PI*6378137/2]}_l.prototype.send=function(t,e,r,n){var i=this,a=r?this.mapId+\":\"+this.callbackID++:null;r&&(this.callbacks[a]=r);var o=[];if(this.target.postMessage({targetMapId:n,sourceMapId:this.mapId,type:t,id:String(a),data:An(e,o)},o),r)return{cancel:function(){i.callbacks[a]=null,i.target.postMessage({targetMapId:n,sourceMapId:i.mapId,type:\"<cancel>\",id:String(a)})}}},_l.prototype.receive=function(t){var e,r=this,n=t.data,i=n.id;if(!n.targetMapId||this.mapId===n.targetMapId){var a=function(t,e){delete r.callbacks[i];var n=[];r.target.postMessage({sourceMapId:r.mapId,type:\"<response>\",id:String(i),error:t?An(t):null,data:An(e,n)},n)};if(\"<response>\"===n.type||\"<cancel>\"===n.type)e=this.callbacks[n.id],delete this.callbacks[n.id],e&&n.error?e(Mn(n.error)):e&&e(null,Mn(n.data));else if(void 0!==n.id&&this.parent[n.type]){this.callbacks[n.id]=null;var o=this.parent[n.type](n.sourceMapId,Mn(n.data),a);o&&null===this.callbacks[n.id]&&(this.callbacks[n.id]=o.cancel)}else if(void 0!==n.id&&this.parent.getWorkerSource){var s=n.type.split(\".\"),l=Mn(n.data);this.parent.getWorkerSource(n.sourceMapId,s[0],l.source)[s[1]](l,a)}else this.parent[n.type](Mn(n.data))}},_l.prototype.remove=function(){this.target.removeEventListener(\"message\",this.receive,!1)};var kl=function(t,e){t&&(e?this.setSouthWest(t).setNorthEast(e):4===t.length?this.setSouthWest([t[0],t[1]]).setNorthEast([t[2],t[3]]):this.setSouthWest(t[0]).setNorthEast(t[1]))};kl.prototype.setNorthEast=function(t){return this._ne=t instanceof Tl?new Tl(t.lng,t.lat):Tl.convert(t),this},kl.prototype.setSouthWest=function(t){return this._sw=t instanceof Tl?new Tl(t.lng,t.lat):Tl.convert(t),this},kl.prototype.extend=function(t){var e,r,n=this._sw,i=this._ne;if(t instanceof Tl)e=t,r=t;else{if(!(t instanceof kl))return Array.isArray(t)?t.every(Array.isArray)?this.extend(kl.convert(t)):this.extend(Tl.convert(t)):this;if(e=t._sw,r=t._ne,!e||!r)return this}return n||i?(n.lng=Math.min(e.lng,n.lng),n.lat=Math.min(e.lat,n.lat),i.lng=Math.max(r.lng,i.lng),i.lat=Math.max(r.lat,i.lat)):(this._sw=new Tl(e.lng,e.lat),this._ne=new Tl(r.lng,r.lat)),this},kl.prototype.getCenter=function(){return new Tl((this._sw.lng+this._ne.lng)/2,(this._sw.lat+this._ne.lat)/2)},kl.prototype.getSouthWest=function(){return this._sw},kl.prototype.getNorthEast=function(){return this._ne},kl.prototype.getNorthWest=function(){return new Tl(this.getWest(),this.getNorth())},kl.prototype.getSouthEast=function(){return new Tl(this.getEast(),this.getSouth())},kl.prototype.getWest=function(){return this._sw.lng},kl.prototype.getSouth=function(){return this._sw.lat},kl.prototype.getEast=function(){return this._ne.lng},kl.prototype.getNorth=function(){return this._ne.lat},kl.prototype.toArray=function(){return[this._sw.toArray(),this._ne.toArray()]},kl.prototype.toString=function(){return\"LngLatBounds(\"+this._sw.toString()+\", \"+this._ne.toString()+\")\"},kl.prototype.isEmpty=function(){return!(this._sw&&this._ne)},kl.convert=function(t){return!t||t instanceof kl?t:new kl(t)};var Tl=function(t,e){if(isNaN(t)||isNaN(e))throw new Error(\"Invalid LngLat object: (\"+t+\", \"+e+\")\");if(this.lng=+t,this.lat=+e,this.lat>90||this.lat<-90)throw new Error(\"Invalid LngLat latitude value: must be between -90 and 90\")};function Al(t){return 2*Math.PI*6378137*Math.cos(t*Math.PI/180)}function Ml(t){return(180+t)/360}function Sl(t){return(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+t*Math.PI/360)))/360}function El(t,e){return t/Al(e)}function Cl(t){var e=180-360*t;return 360/Math.PI*Math.atan(Math.exp(e*Math.PI/180))-90}Tl.prototype.wrap=function(){return new Tl(u(this.lng,-180,180),this.lat)},Tl.prototype.toArray=function(){return[this.lng,this.lat]},Tl.prototype.toString=function(){return\"LngLat(\"+this.lng+\", \"+this.lat+\")\"},Tl.prototype.toBounds=function(t){void 0===t&&(t=0);var e=360*t/40075017,r=e/Math.cos(Math.PI/180*this.lat);return new kl(new Tl(this.lng-r,this.lat-e),new Tl(this.lng+r,this.lat+e))},Tl.convert=function(t){if(t instanceof Tl)return t;if(Array.isArray(t)&&(2===t.length||3===t.length))return new Tl(Number(t[0]),Number(t[1]));if(!Array.isArray(t)&&\"object\"==typeof t&&null!==t)return new Tl(Number(\"lng\"in t?t.lng:t.lon),Number(t.lat));throw new Error(\"`LngLatLike` argument must be specified as a LngLat instance, an object {lng: <lng>, lat: <lat>}, an object {lon: <lng>, lat: <lat>}, or an array of [<lng>, <lat>]\")};var Ll=function(t,e,r){void 0===r&&(r=0),this.x=+t,this.y=+e,this.z=+r};Ll.fromLngLat=function(t,e){void 0===e&&(e=0);var r=Tl.convert(t);return new Ll(Ml(r.lng),Sl(r.lat),El(e,r.lat))},Ll.prototype.toLngLat=function(){return new Tl(360*this.x-180,Cl(this.y))},Ll.prototype.toAltitude=function(){return this.z*Al(Cl(this.y))};var Pl=function(t,e,r){this.z=t,this.x=e,this.y=r,this.key=Il(0,t,e,r)};Pl.prototype.equals=function(t){return this.z===t.z&&this.x===t.x&&this.y===t.y},Pl.prototype.url=function(t,e){var r,n,i,a,o,s=(r=this.x,n=this.y,i=this.z,a=wl(256*r,256*(n=Math.pow(2,i)-n-1),i),o=wl(256*(r+1),256*(n+1),i),a[0]+\",\"+a[1]+\",\"+o[0]+\",\"+o[1]),l=function(t,e,r){for(var n,i=\"\",a=t;a>0;a--)i+=(e&(n=1<<a-1)?1:0)+(r&n?2:0);return i}(this.z,this.x,this.y);return t[(this.x+this.y)%t.length].replace(\"{prefix}\",(this.x%16).toString(16)+(this.y%16).toString(16)).replace(\"{z}\",String(this.z)).replace(\"{x}\",String(this.x)).replace(\"{y}\",String(\"tms\"===e?Math.pow(2,this.z)-this.y-1:this.y)).replace(\"{quadkey}\",l).replace(\"{bbox-epsg-3857}\",s)},Pl.prototype.getTilePoint=function(t){var e=Math.pow(2,this.z);return new i((t.x*e-this.x)*ha,(t.y*e-this.y)*ha)};var Ol=function(t,e){this.wrap=t,this.canonical=e,this.key=Il(t,e.z,e.x,e.y)},zl=function(t,e,r,n,i){this.overscaledZ=t,this.wrap=e,this.canonical=new Pl(r,+n,+i),this.key=Il(e,t,n,i)};function Il(t,e,r,n){(t*=2)<0&&(t=-1*t-1);var i=1<<e;return 32*(i*i*t+i*n+r)+e}zl.prototype.equals=function(t){return this.overscaledZ===t.overscaledZ&&this.wrap===t.wrap&&this.canonical.equals(t.canonical)},zl.prototype.scaledTo=function(t){var e=this.canonical.z-t;return t>this.canonical.z?new zl(t,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y):new zl(t,this.wrap,t,this.canonical.x>>e,this.canonical.y>>e)},zl.prototype.isChildOf=function(t){if(t.wrap!==this.wrap)return!1;var e=this.canonical.z-t.canonical.z;return 0===t.overscaledZ||t.overscaledZ<this.overscaledZ&&t.canonical.x===this.canonical.x>>e&&t.canonical.y===this.canonical.y>>e},zl.prototype.children=function(t){if(this.overscaledZ>=t)return[new zl(this.overscaledZ+1,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y)];var e=this.canonical.z+1,r=2*this.canonical.x,n=2*this.canonical.y;return[new zl(e,this.wrap,e,r,n),new zl(e,this.wrap,e,r+1,n),new zl(e,this.wrap,e,r,n+1),new zl(e,this.wrap,e,r+1,n+1)]},zl.prototype.isLessThan=function(t){return this.wrap<t.wrap||!(this.wrap>t.wrap)&&(this.overscaledZ<t.overscaledZ||!(this.overscaledZ>t.overscaledZ)&&(this.canonical.x<t.canonical.x||!(this.canonical.x>t.canonical.x)&&this.canonical.y<t.canonical.y))},zl.prototype.wrapped=function(){return new zl(this.overscaledZ,0,this.canonical.z,this.canonical.x,this.canonical.y)},zl.prototype.unwrapTo=function(t){return new zl(this.overscaledZ,t,this.canonical.z,this.canonical.x,this.canonical.y)},zl.prototype.overscaleFactor=function(){return Math.pow(2,this.overscaledZ-this.canonical.z)},zl.prototype.toUnwrapped=function(){return new Ol(this.wrap,this.canonical)},zl.prototype.toString=function(){return this.overscaledZ+\"/\"+this.canonical.x+\"/\"+this.canonical.y},zl.prototype.getTilePoint=function(t){return this.canonical.getTilePoint(new Ll(t.x-this.wrap,t.y))},kn(\"CanonicalTileID\",Pl),kn(\"OverscaledTileID\",zl,{omit:[\"posMatrix\"]});var Dl=function(t,e,r){if(this.uid=t,e.height!==e.width)throw new RangeError(\"DEM tiles must be square\");if(r&&\"mapbox\"!==r&&\"terrarium\"!==r)return w('\"'+r+'\" is not a valid encoding type. Valid types include \"mapbox\" and \"terrarium\".');var n=this.dim=e.height;this.stride=this.dim+2,this.data=new Int32Array(this.stride*this.stride);for(var i=e.data,a=\"terrarium\"===r?this._unpackTerrarium:this._unpackMapbox,o=0;o<n;o++)for(var s=0;s<n;s++){var l=4*(o*n+s);this.set(s,o,a(i[l],i[l+1],i[l+2]))}for(var c=0;c<n;c++)this.set(-1,c,this.get(0,c)),this.set(n,c,this.get(n-1,c)),this.set(c,-1,this.get(c,0)),this.set(c,n,this.get(c,n-1));this.set(-1,-1,this.get(0,0)),this.set(n,-1,this.get(n-1,0)),this.set(-1,n,this.get(0,n-1)),this.set(n,n,this.get(n-1,n-1))};Dl.prototype.set=function(t,e,r){this.data[this._idx(t,e)]=r+65536},Dl.prototype.get=function(t,e){return this.data[this._idx(t,e)]-65536},Dl.prototype._idx=function(t,e){if(t<-1||t>=this.dim+1||e<-1||e>=this.dim+1)throw new RangeError(\"out of range source coordinates for DEM data\");return(e+1)*this.stride+(t+1)},Dl.prototype._unpackMapbox=function(t,e,r){return(256*t*256+256*e+r)/10-1e4},Dl.prototype._unpackTerrarium=function(t,e,r){return 256*t+e+r/256-32768},Dl.prototype.getPixels=function(){return new Ha({width:this.stride,height:this.stride},new Uint8Array(this.data.buffer))},Dl.prototype.backfillBorder=function(t,e,r){if(this.dim!==t.dim)throw new Error(\"dem dimension mismatch\");var n=e*this.dim,i=e*this.dim+this.dim,a=r*this.dim,o=r*this.dim+this.dim;switch(e){case-1:n=i-1;break;case 1:i=n+1}switch(r){case-1:a=o-1;break;case 1:o=a+1}for(var s=-e*this.dim,l=-r*this.dim,c=a;c<o;c++)for(var u=n;u<i;u++)this.set(u,c,t.get(u+s,c+l))},kn(\"DEMData\",Dl);var Rl=oi([{name:\"a_pos\",type:\"Int16\",components:2},{name:\"a_texture_pos\",type:\"Int16\",components:2}]),Fl=function(t){this._stringToNumber={},this._numberToString=[];for(var e=0;e<t.length;e++){var r=t[e];this._stringToNumber[r]=e,this._numberToString[e]=r}};Fl.prototype.encode=function(t){return this._stringToNumber[t]},Fl.prototype.decode=function(t){return this._numberToString[t]};var Bl=function(t,e,r,n){this.type=\"Feature\",this._vectorTileFeature=t,t._z=e,t._x=r,t._y=n,this.properties=t.properties,null!=t.id&&(this.id=t.id)},Nl={geometry:{configurable:!0}};Nl.geometry.get=function(){return void 0===this._geometry&&(this._geometry=this._vectorTileFeature.toGeoJSON(this._vectorTileFeature._x,this._vectorTileFeature._y,this._vectorTileFeature._z).geometry),this._geometry},Nl.geometry.set=function(t){this._geometry=t},Bl.prototype.toJSON=function(){var t={geometry:this.geometry};for(var e in this)\"_geometry\"!==e&&\"_vectorTileFeature\"!==e&&(t[e]=this[e]);return t},Object.defineProperties(Bl.prototype,Nl);var jl=function(){this.state={},this.stateChanges={},this.deletedStates={}};jl.prototype.updateState=function(t,e,r){var n=String(e);if(this.stateChanges[t]=this.stateChanges[t]||{},this.stateChanges[t][n]=this.stateChanges[t][n]||{},h(this.stateChanges[t][n],r),null===this.deletedStates[t])for(var i in this.deletedStates[t]={},this.state[t])i!==n&&(this.deletedStates[t][i]=null);else if(this.deletedStates[t]&&null===this.deletedStates[t][n])for(var a in this.deletedStates[t][n]={},this.state[t][n])r[a]||(this.deletedStates[t][n][a]=null);else for(var o in r)this.deletedStates[t]&&this.deletedStates[t][n]&&null===this.deletedStates[t][n][o]&&delete this.deletedStates[t][n][o]},jl.prototype.removeFeatureState=function(t,e,r){if(null!==this.deletedStates[t]){var n=String(e);if(this.deletedStates[t]=this.deletedStates[t]||{},r&&void 0!==e&&e>=0)null!==this.deletedStates[t][n]&&(this.deletedStates[t][n]=this.deletedStates[t][n]||{},this.deletedStates[t][n][r]=null);else if(void 0!==e&&e>=0)if(this.stateChanges[t]&&this.stateChanges[t][n])for(r in this.deletedStates[t][n]={},this.stateChanges[t][n])this.deletedStates[t][n][r]=null;else this.deletedStates[t][n]=null;else this.deletedStates[t]=null}},jl.prototype.getState=function(t,e){var r=String(e),n=this.state[t]||{},i=this.stateChanges[t]||{},a=h({},n[r],i[r]);if(null===this.deletedStates[t])return{};if(this.deletedStates[t]){var o=this.deletedStates[t][e];if(null===o)return{};for(var s in o)delete a[s]}return a},jl.prototype.initializeTileState=function(t,e){t.setFeatureState(this.state,e)},jl.prototype.coalesceChanges=function(t,e){var r={};for(var n in this.stateChanges){this.state[n]=this.state[n]||{};var i={};for(var a in this.stateChanges[n])this.state[n][a]||(this.state[n][a]={}),h(this.state[n][a],this.stateChanges[n][a]),i[a]=this.state[n][a];r[n]=i}for(var o in this.deletedStates){this.state[o]=this.state[o]||{};var s={};if(null===this.deletedStates[o])for(var l in this.state[o])s[l]={},this.state[o][l]={};else for(var c in this.deletedStates[o]){if(null===this.deletedStates[o][c])this.state[o][c]={};else for(var u=0,f=Object.keys(this.deletedStates[o][c]);u<f.length;u+=1){var p=f[u];delete this.state[o][c][p]}s[c]=this.state[o][c]}r[o]=r[o]||{},h(r[o],s)}if(this.stateChanges={},this.deletedStates={},0!==Object.keys(r).length)for(var d in t)t[d].setFeatureState(r,e)};var Ul=function(t,e,r){this.tileID=t,this.x=t.canonical.x,this.y=t.canonical.y,this.z=t.canonical.z,this.grid=e||new yn(ha,16,0),this.grid3D=new yn(ha,16,0),this.featureIndexArray=r||new ji};function Vl(t){for(var e=1/0,r=1/0,n=-1/0,i=-1/0,a=0,o=t;a<o.length;a+=1){var s=o[a];e=Math.min(e,s.x),r=Math.min(r,s.y),n=Math.max(n,s.x),i=Math.max(i,s.y)}return{minX:e,minY:r,maxX:n,maxY:i}}function ql(t,e){return e-t}Ul.prototype.insert=function(t,e,r,n,i,a){var o=this.featureIndexArray.length;this.featureIndexArray.emplaceBack(r,n,i);for(var s=a?this.grid3D:this.grid,l=0;l<e.length;l++){for(var c=e[l],u=[1/0,1/0,-1/0,-1/0],h=0;h<c.length;h++){var f=c[h];u[0]=Math.min(u[0],f.x),u[1]=Math.min(u[1],f.y),u[2]=Math.max(u[2],f.x),u[3]=Math.max(u[3],f.y)}u[0]<ha&&u[1]<ha&&u[2]>=0&&u[3]>=0&&s.insert(o,u[0],u[1],u[2],u[3])}},Ul.prototype.loadVTLayers=function(){return this.vtLayers||(this.vtLayers=new Vo.VectorTile(new Qs(this.rawTileData)).layers,this.sourceLayerCoder=new Fl(this.vtLayers?Object.keys(this.vtLayers).sort():[\"_geojsonTileLayer\"])),this.vtLayers},Ul.prototype.query=function(t,e,r){var n=this;this.loadVTLayers();for(var a=t.params||{},o=ha/t.tileSize/t.scale,s=Gr(a.filter),l=t.queryGeometry,c=t.queryPadding*o,u=Vl(l),h=this.grid.query(u.minX-c,u.minY-c,u.maxX+c,u.maxY+c),f=Vl(t.cameraQueryGeometry),p=0,d=this.grid3D.query(f.minX-c,f.minY-c,f.maxX+c,f.maxY+c,function(e,r,n,a){return function(t,e,r,n,a){for(var o=0,s=t;o<s.length;o+=1){var l=s[o];if(e<=l.x&&r<=l.y&&n>=l.x&&a>=l.y)return!0}var c=[new i(e,r),new i(e,a),new i(n,a),new i(n,r)];if(t.length>2)for(var u=0,h=c;u<h.length;u+=1)if(Aa(t,h[u]))return!0;for(var f=0;f<t.length-1;f++)if(Ma(t[f],t[f+1],c))return!0;return!1}(t.cameraQueryGeometry,e-c,r-c,n+c,a+c)});p<d.length;p+=1){var g=d[p];h.push(g)}h.sort(ql);for(var v,m={},y=function(i){var c=h[i];if(c!==v){v=c;var u=n.featureIndexArray.get(c),f=null;n.loadMatchingFeature(m,u.bucketIndex,u.sourceLayerIndex,u.featureIndex,s,a.layers,e,function(e,i){f||(f=pa(e));var a={};return e.id&&(a=r.getState(i.sourceLayer||\"_geojsonTileLayer\",e.id)),i.queryIntersectsFeature(l,e,a,f,n.z,t.transform,o,t.pixelPosMatrix)})}},x=0;x<h.length;x++)y(x);return m},Ul.prototype.loadMatchingFeature=function(t,e,r,n,i,a,o,s){var l=this.bucketLayerIDs[e];if(!a||function(t,e){for(var r=0;r<t.length;r++)if(e.indexOf(t[r])>=0)return!0;return!1}(a,l)){var c=this.sourceLayerCoder.decode(r),u=this.vtLayers[c].feature(n);if(i(new Un(this.tileID.overscaledZ),u))for(var h=0;h<l.length;h++){var f=l[h];if(!(a&&a.indexOf(f)<0)){var p=o[f];if(p){var d=!s||s(u,p);if(d){var g=new Bl(u,this.z,this.x,this.y);g.layer=p.serialize();var v=t[f];void 0===v&&(v=t[f]=[]),v.push({featureIndex:n,feature:g,intersectionZ:d})}}}}}},Ul.prototype.lookupSymbolFeatures=function(t,e,r,n,i,a){var o={};this.loadVTLayers();for(var s=Gr(n),l=0,c=t;l<c.length;l+=1){var u=c[l];this.loadMatchingFeature(o,e,r,u,s,i,a)}return o},Ul.prototype.hasLayer=function(t){for(var e=0,r=this.bucketLayerIDs;e<r.length;e+=1)for(var n=0,i=r[e];n<i.length;n+=1)if(t===i[n])return!0;return!1},kn(\"FeatureIndex\",Ul,{omit:[\"rawTileData\",\"sourceLayerCoder\"]});var Hl=function(t,e){this.tileID=t,this.uid=p(),this.uses=0,this.tileSize=e,this.buckets={},this.expirationTime=null,this.queryPadding=0,this.hasSymbolBuckets=!1,this.expiredRequestCount=0,this.state=\"loading\"};Hl.prototype.registerFadeDuration=function(t){var e=t+this.timeAdded;e<z.now()||this.fadeEndTime&&e<this.fadeEndTime||(this.fadeEndTime=e)},Hl.prototype.wasRequested=function(){return\"errored\"===this.state||\"loaded\"===this.state||\"reloading\"===this.state},Hl.prototype.loadVectorData=function(t,e,r){if(this.hasData()&&this.unloadVectorData(),this.state=\"loaded\",t){for(var n in t.featureIndex&&(this.latestFeatureIndex=t.featureIndex,t.rawTileData?(this.latestRawTileData=t.rawTileData,this.latestFeatureIndex.rawTileData=t.rawTileData):this.latestRawTileData&&(this.latestFeatureIndex.rawTileData=this.latestRawTileData)),this.collisionBoxArray=t.collisionBoxArray,this.buckets=function(t,e){var r={};if(!e)return r;for(var n=function(){var t=a[i],n=t.layerIds.map(function(t){return e.getLayer(t)}).filter(Boolean);if(0!==n.length){t.layers=n,t.stateDependentLayerIds&&(t.stateDependentLayers=t.stateDependentLayerIds.map(function(t){return n.filter(function(e){return e.id===t})[0]}));for(var o=0,s=n;o<s.length;o+=1){var l=s[o];r[l.id]=t}}},i=0,a=t;i<a.length;i+=1)n();return r}(t.buckets,e.style),this.hasSymbolBuckets=!1,this.buckets){var i=this.buckets[n];if(i instanceof Os){if(this.hasSymbolBuckets=!0,!r)break;i.justReloaded=!0}}for(var a in this.queryPadding=0,this.buckets){var o=this.buckets[a];this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(a).queryRadius(o))}t.imageAtlas&&(this.imageAtlas=t.imageAtlas),t.glyphAtlasImage&&(this.glyphAtlasImage=t.glyphAtlasImage)}else this.collisionBoxArray=new Li},Hl.prototype.unloadVectorData=function(){for(var t in this.buckets)this.buckets[t].destroy();this.buckets={},this.imageAtlasTexture&&this.imageAtlasTexture.destroy(),this.imageAtlas&&(this.imageAtlas=null),this.glyphAtlasTexture&&this.glyphAtlasTexture.destroy(),this.latestFeatureIndex=null,this.state=\"unloaded\"},Hl.prototype.unloadDEMData=function(){this.dem=null,this.neighboringTiles=null,this.state=\"unloaded\"},Hl.prototype.getBucket=function(t){return this.buckets[t.id]},Hl.prototype.upload=function(t){for(var e in this.buckets){var r=this.buckets[e];r.uploadPending()&&r.upload(t)}var n=t.gl;this.imageAtlas&&!this.imageAtlas.uploaded&&(this.imageAtlasTexture=new Js(t,this.imageAtlas.image,n.RGBA),this.imageAtlas.uploaded=!0),this.glyphAtlasImage&&(this.glyphAtlasTexture=new Js(t,this.glyphAtlasImage,n.ALPHA),this.glyphAtlasImage=null)},Hl.prototype.prepare=function(t){this.imageAtlas&&this.imageAtlas.patchUpdatedImages(t,this.imageAtlasTexture)},Hl.prototype.queryRenderedFeatures=function(t,e,r,n,i,a,o,s,l){return this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData?this.latestFeatureIndex.query({queryGeometry:r,cameraQueryGeometry:n,scale:i,tileSize:this.tileSize,pixelPosMatrix:l,transform:o,params:a,queryPadding:this.queryPadding*s},t,e):{}},Hl.prototype.querySourceFeatures=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData){var r=this.latestFeatureIndex.loadVTLayers(),n=e?e.sourceLayer:\"\",i=r._geojsonTileLayer||r[n];if(i)for(var a=Gr(e&&e.filter),o=this.tileID.canonical,s=o.z,l=o.x,c=o.y,u={z:s,x:l,y:c},h=0;h<i.length;h++){var f=i.feature(h);if(a(new Un(this.tileID.overscaledZ),f)){var p=new Bl(f,s,l,c);p.tile=u,t.push(p)}}}},Hl.prototype.clearMask=function(){this.segments&&(this.segments.destroy(),delete this.segments),this.maskedBoundsBuffer&&(this.maskedBoundsBuffer.destroy(),delete this.maskedBoundsBuffer),this.maskedIndexBuffer&&(this.maskedIndexBuffer.destroy(),delete this.maskedIndexBuffer)},Hl.prototype.setMask=function(t,e){if(!o(this.mask,t)&&(this.mask=t,this.clearMask(),!o(t,{0:!0}))){var r=new ci,n=new Ti;this.segments=new Vi,this.segments.prepareSegment(0,r,n);for(var a=Object.keys(t),s=0;s<a.length;s++){var l=t[+a[s]],c=ha>>l.z,u=new i(l.x*c,l.y*c),h=new i(u.x+c,u.y+c),f=this.segments.prepareSegment(4,r,n);r.emplaceBack(u.x,u.y,u.x,u.y),r.emplaceBack(h.x,u.y,h.x,u.y),r.emplaceBack(u.x,h.y,u.x,h.y),r.emplaceBack(h.x,h.y,h.x,h.y);var p=f.vertexLength;n.emplaceBack(p,p+1,p+2),n.emplaceBack(p+1,p+2,p+3),f.vertexLength+=4,f.primitiveLength+=2}this.maskedBoundsBuffer=e.createVertexBuffer(r,Rl.members),this.maskedIndexBuffer=e.createIndexBuffer(n)}},Hl.prototype.hasData=function(){return\"loaded\"===this.state||\"reloading\"===this.state||\"expired\"===this.state},Hl.prototype.patternsLoaded=function(){return this.imageAtlas&&!!Object.keys(this.imageAtlas.patternPositions).length},Hl.prototype.setExpiryData=function(t){var e=this.expirationTime;if(t.cacheControl){var r=A(t.cacheControl);r[\"max-age\"]&&(this.expirationTime=Date.now()+1e3*r[\"max-age\"])}else t.expires&&(this.expirationTime=new Date(t.expires).getTime());if(this.expirationTime){var n=Date.now(),i=!1;if(this.expirationTime>n)i=!1;else if(e)if(this.expirationTime<e)i=!0;else{var a=this.expirationTime-e;a?this.expirationTime=n+Math.max(a,3e4):i=!0}else i=!0;i?(this.expiredRequestCount++,this.state=\"expired\"):this.expiredRequestCount=0}},Hl.prototype.getExpiryTimeout=function(){if(this.expirationTime)return this.expiredRequestCount?1e3*(1<<Math.min(this.expiredRequestCount-1,31)):Math.min(this.expirationTime-(new Date).getTime(),Math.pow(2,31)-1)},Hl.prototype.setFeatureState=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData&&0!==Object.keys(t).length){var r=this.latestFeatureIndex.loadVTLayers();for(var n in this.buckets){var i=this.buckets[n],a=i.layers[0].sourceLayer||\"_geojsonTileLayer\",o=r[a],s=t[a];o&&s&&0!==Object.keys(s).length&&(i.update(s,o,this.imageAtlas&&this.imageAtlas.patternPositions||{}),e&&e.style&&(this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(n).queryRadius(i))))}}},Hl.prototype.holdingForFade=function(){return void 0!==this.symbolFadeHoldUntil},Hl.prototype.symbolFadeFinished=function(){return!this.symbolFadeHoldUntil||this.symbolFadeHoldUntil<z.now()},Hl.prototype.clearFadeHold=function(){this.symbolFadeHoldUntil=void 0},Hl.prototype.setHoldDuration=function(t){this.symbolFadeHoldUntil=z.now()+t};var Gl=24,Yl={horizontal:1,vertical:2,horizontalOnly:3},Wl=function(){this.text=\"\",this.sectionIndex=[],this.sections=[]};function Xl(t,e,r,n,i,a,o,s,l,c){var u,h=Wl.fromFeature(t,r);c===Yl.vertical&&h.verticalizePunctuation();var f=jn.processBidirectionalText,p=jn.processStyledBidirectionalText;if(f&&1===h.sections.length){u=[];for(var d=0,g=f(h.toString(),tc(h,s,n,e));d<g.length;d+=1){var v=g[d],m=new Wl;m.text=v,m.sections=h.sections;for(var y=0;y<v.length;y++)m.sectionIndex.push(0);u.push(m)}}else if(p){u=[];for(var x=0,b=p(h.text,h.sectionIndex,tc(h,s,n,e));x<b.length;x+=1){var _=b[x],w=new Wl;w.text=_[0],w.sectionIndex=_[1],w.sections=h.sections,u.push(w)}}else u=function(t,e){for(var r=[],n=t.text,i=0,a=0,o=e;a<o.length;a+=1){var s=o[a];r.push(t.substring(i,s)),i=s}return i<n.length&&r.push(t.substring(i,n.length)),r}(h,tc(h,s,n,e));var k=[],T={positionedGlyphs:k,text:h.toString(),top:l[1],bottom:l[1],left:l[0],right:l[0],writingMode:c,lineCount:u.length};return function(t,e,r,n,i,a,o,s){for(var l=0,c=-17,u=0,h=t.positionedGlyphs,f=\"right\"===a?1:\"left\"===a?0:.5,p=0,d=r;p<d.length;p+=1){var g=d[p];g.trim();var v=g.getMaxScale();if(g.length()){for(var m=h.length,y=0;y<g.length();y++){var x=g.getSection(y),b=g.getCharCode(y),_=24*(v-x.scale),w=e[x.fontStack],k=w&&w[b];k&&(On(b)&&o!==Yl.horizontal?(h.push({glyph:b,x:l,y:_,vertical:!0,scale:x.scale,fontStack:x.fontStack}),l+=Gl*x.scale+s):(h.push({glyph:b,x:l,y:c+_,vertical:!1,scale:x.scale,fontStack:x.fontStack}),l+=k.metrics.advance*x.scale+s))}if(h.length!==m){var T=l-s;u=Math.max(T,u),rc(h,e,m,h.length-1,f)}l=0,c+=n*v}else c+=n}var A=ec(i),M=A.horizontalAlign,S=A.verticalAlign;!function(t,e,r,n,i,a,o){for(var s=(e-r)*i,l=(-n*o+.5)*a,c=0;c<t.length;c++)t[c].x+=s,t[c].y+=l}(h,f,M,S,u,n,r.length);var E=c- -17;t.top+=-S*E,t.bottom=t.top+E,t.left+=-M*u,t.right=t.left+u}(T,e,u,i,a,o,c,s),!!k.length&&T}Wl.fromFeature=function(t,e){for(var r=new Wl,n=0;n<t.sections.length;n++){var i=t.sections[n];r.sections.push({scale:i.scale||1,fontStack:i.fontStack||e}),r.text+=i.text;for(var a=0;a<i.text.length;a++)r.sectionIndex.push(n)}return r},Wl.prototype.length=function(){return this.text.length},Wl.prototype.getSection=function(t){return this.sections[this.sectionIndex[t]]},Wl.prototype.getCharCode=function(t){return this.text.charCodeAt(t)},Wl.prototype.verticalizePunctuation=function(){this.text=function(t){for(var e=\"\",r=0;r<t.length;r++){var n=t.charCodeAt(r+1)||null,i=t.charCodeAt(r-1)||null;n&&zn(n)&&!xs[t[r+1]]||i&&zn(i)&&!xs[t[r-1]]||!xs[t[r]]?e+=t[r]:e+=xs[t[r]]}return e}(this.text)},Wl.prototype.trim=function(){for(var t=0,e=0;e<this.text.length&&Zl[this.text.charCodeAt(e)];e++)t++;for(var r=this.text.length,n=this.text.length-1;n>=0&&n>=t&&Zl[this.text.charCodeAt(n)];n--)r--;this.text=this.text.substring(t,r),this.sectionIndex=this.sectionIndex.slice(t,r)},Wl.prototype.substring=function(t,e){var r=new Wl;return r.text=this.text.substring(t,e),r.sectionIndex=this.sectionIndex.slice(t,e),r.sections=this.sections,r},Wl.prototype.toString=function(){return this.text},Wl.prototype.getMaxScale=function(){var t=this;return this.sectionIndex.reduce(function(e,r){return Math.max(e,t.sections[r].scale)},0)};var Zl={9:!0,10:!0,11:!0,12:!0,13:!0,32:!0},Jl={};function Kl(t,e,r,n){var i=Math.pow(t-e,2);return n?t<e?i/2:2*i:i+Math.abs(r)*r}function $l(t,e,r){var n=0;return 10===t&&(n-=1e4),r&&(n+=150),40!==t&&65288!==t||(n+=50),41!==e&&65289!==e||(n+=50),n}function Ql(t,e,r,n,i,a){for(var o=null,s=Kl(e,r,i,a),l=0,c=n;l<c.length;l+=1){var u=c[l],h=Kl(e-u.x,r,i,a)+u.badness;h<=s&&(o=u,s=h)}return{index:t,x:e,priorBreak:o,badness:s}}function tc(t,e,r,n){if(!r)return[];if(!t)return[];for(var i,a=[],o=function(t,e,r,n){for(var i=0,a=0;a<t.length();a++){var o=t.getSection(a),s=n[o.fontStack],l=s&&s[t.getCharCode(a)];l&&(i+=l.metrics.advance*o.scale+e)}return i/Math.max(1,Math.ceil(i/r))}(t,e,r,n),s=t.text.indexOf(\"\\u200b\")>=0,l=0,c=0;c<t.length();c++){var u=t.getSection(c),h=t.getCharCode(c),f=n[u.fontStack],p=f&&f[h];if(p&&!Zl[h]&&(l+=p.metrics.advance*u.scale+e),c<t.length()-1){var d=!((i=h)<11904||!(En[\"Bopomofo Extended\"](i)||En.Bopomofo(i)||En[\"CJK Compatibility Forms\"](i)||En[\"CJK Compatibility Ideographs\"](i)||En[\"CJK Compatibility\"](i)||En[\"CJK Radicals Supplement\"](i)||En[\"CJK Strokes\"](i)||En[\"CJK Symbols and Punctuation\"](i)||En[\"CJK Unified Ideographs Extension A\"](i)||En[\"CJK Unified Ideographs\"](i)||En[\"Enclosed CJK Letters and Months\"](i)||En[\"Halfwidth and Fullwidth Forms\"](i)||En.Hiragana(i)||En[\"Ideographic Description Characters\"](i)||En[\"Kangxi Radicals\"](i)||En[\"Katakana Phonetic Extensions\"](i)||En.Katakana(i)||En[\"Vertical Forms\"](i)||En[\"Yi Radicals\"](i)||En[\"Yi Syllables\"](i)));(Jl[h]||d)&&a.push(Ql(c+1,l,o,a,$l(h,t.getCharCode(c+1),d&&s),!1))}}return function t(e){return e?t(e.priorBreak).concat(e.index):[]}(Ql(t.length(),l,o,a,0,!0))}function ec(t){var e=.5,r=.5;switch(t){case\"right\":case\"top-right\":case\"bottom-right\":e=1;break;case\"left\":case\"top-left\":case\"bottom-left\":e=0}switch(t){case\"bottom\":case\"bottom-right\":case\"bottom-left\":r=1;break;case\"top\":case\"top-right\":case\"top-left\":r=0}return{horizontalAlign:e,verticalAlign:r}}function rc(t,e,r,n,i){if(i){var a=t[n],o=e[a.fontStack],s=o&&o[a.glyph];if(s)for(var l=s.metrics.advance*a.scale,c=(t[n].x+l)*i,u=r;u<=n;u++)t[u].x-=c}}function nc(t,e,r){var n=ec(r),i=n.horizontalAlign,a=n.verticalAlign,o=e[0],s=e[1],l=o-t.displaySize[0]*i,c=l+t.displaySize[0],u=s-t.displaySize[1]*a;return{image:t,top:u,bottom:u+t.displaySize[1],left:l,right:c}}function ic(t,e,r,n,i){if(void 0===e.segment)return!0;for(var a=e,o=e.segment+1,s=0;s>-r/2;){if(--o<0)return!1;s-=t[o].dist(a),a=t[o]}s+=t[o].dist(t[o+1]),o++;for(var l=[],c=0;s<r/2;){var u=t[o-1],h=t[o],f=t[o+1];if(!f)return!1;var p=u.angleTo(h)-h.angleTo(f);for(p=Math.abs((p+3*Math.PI)%(2*Math.PI)-Math.PI),l.push({distance:s,angleDelta:p}),c+=p;s-l[0].distance>n;)c-=l.shift().angleDelta;if(c>i)return!1;o++,s+=h.dist(f)}return!0}function ac(t){for(var e=0,r=0;r<t.length-1;r++)e+=t[r].dist(t[r+1]);return e}function oc(t,e,r){return t?.6*e*r:0}function sc(t,e){return Math.max(t?t.right-t.left:0,e?e.right-e.left:0)}function lc(t,e,r,n,i,a){for(var o=oc(r,i,a),s=sc(r,n)*a,l=0,c=ac(t)/2,u=0;u<t.length-1;u++){var h=t[u],f=t[u+1],p=h.dist(f);if(l+p>c){var d=(c-l)/p,g=Ee(h.x,f.x,d),v=Ee(h.y,f.y,d),m=new bs(g,v,f.angleTo(h),u);return m._round(),!o||ic(t,m,s,o,e)?m:void 0}l+=p}}function cc(t,e,r,n,i,a,o,s,l){var c=oc(n,a,o),u=sc(n,i),h=u*o,f=0===t[0].x||t[0].x===l||0===t[0].y||t[0].y===l;return e-h<e/4&&(e=h+e/4),function t(e,r,n,i,a,o,s,l,c){for(var u=o/2,h=ac(e),f=0,p=r-n,d=[],g=0;g<e.length-1;g++){for(var v=e[g],m=e[g+1],y=v.dist(m),x=m.angleTo(v);p+n<f+y;){var b=((p+=n)-f)/y,_=Ee(v.x,m.x,b),w=Ee(v.y,m.y,b);if(_>=0&&_<c&&w>=0&&w<c&&p-u>=0&&p+u<=h){var k=new bs(_,w,x,g);k._round(),i&&!ic(e,k,o,i,a)||d.push(k)}}f+=y}return l||d.length||s||(d=t(e,f/2,n,i,a,o,s,!0,c)),d}(t,f?e/2*s%e:(u/2+2*a)*o*s%e,e,c,r,h,f,!1,l)}Jl[10]=!0,Jl[32]=!0,Jl[38]=!0,Jl[40]=!0,Jl[41]=!0,Jl[43]=!0,Jl[45]=!0,Jl[47]=!0,Jl[173]=!0,Jl[183]=!0,Jl[8203]=!0,Jl[8208]=!0,Jl[8211]=!0,Jl[8231]=!0;var uc=function(t,e,r,n,a,o,s,l,c,u,h,f){var p=s.top*l-c,d=s.bottom*l+c,g=s.left*l-c,v=s.right*l+c;if(this.boxStartIndex=t.length,u){var m=d-p,y=v-g;m>0&&(m=Math.max(10*l,m),this._addLineCollisionCircles(t,e,r,r.segment,y,m,n,a,o,h))}else{if(f){var x=new i(g,p),b=new i(v,p),_=new i(g,d),w=new i(v,d),k=f*Math.PI/180;x._rotate(k),b._rotate(k),_._rotate(k),w._rotate(k),g=Math.min(x.x,b.x,_.x,w.x),v=Math.max(x.x,b.x,_.x,w.x),p=Math.min(x.y,b.y,_.y,w.y),d=Math.max(x.y,b.y,_.y,w.y)}t.emplaceBack(r.x,r.y,g,p,v,d,n,a,o,0,0)}this.boxEndIndex=t.length};uc.prototype._addLineCollisionCircles=function(t,e,r,n,i,a,o,s,l,c){var u=a/2,h=Math.floor(i/u)||1,f=1+.4*Math.log(c)/Math.LN2,p=Math.floor(h*f/2),d=-a/2,g=r,v=n+1,m=d,y=-i/2,x=y-i/4;do{if(--v<0){if(m>y)return;v=0;break}m-=e[v].dist(g),g=e[v]}while(m>x);for(var b=e[v].dist(e[v+1]),_=-p;_<h+p;_++){var w=_*u,k=y+w;if(w<0&&(k+=w),w>i&&(k+=w-i),!(k<m)){for(;m+b<k;){if(m+=b,++v+1>=e.length)return;b=e[v].dist(e[v+1])}var T=k-m,A=e[v],M=e[v+1].sub(A)._unit()._mult(T)._add(A)._round(),S=Math.abs(k-d)<u?0:.8*(k-d);t.emplaceBack(M.x,M.y,-a/2,-a/2,a/2,a/2,o,s,l,a/2,S)}}};var hc=function(t,e){if(void 0===t&&(t=[]),void 0===e&&(e=fc),this.data=t,this.length=this.data.length,this.compare=e,this.length>0)for(var r=(this.length>>1)-1;r>=0;r--)this._down(r)};function fc(t,e){return t<e?-1:t>e?1:0}function pc(t,e,r){void 0===e&&(e=1),void 0===r&&(r=!1);for(var n=1/0,a=1/0,o=-1/0,s=-1/0,l=t[0],c=0;c<l.length;c++){var u=l[c];(!c||u.x<n)&&(n=u.x),(!c||u.y<a)&&(a=u.y),(!c||u.x>o)&&(o=u.x),(!c||u.y>s)&&(s=u.y)}var h=o-n,f=s-a,p=Math.min(h,f),d=p/2,g=new hc([],dc);if(0===p)return new i(n,a);for(var v=n;v<o;v+=p)for(var m=a;m<s;m+=p)g.push(new gc(v+d,m+d,d,t));for(var y=function(t){for(var e=0,r=0,n=0,i=t[0],a=0,o=i.length,s=o-1;a<o;s=a++){var l=i[a],c=i[s],u=l.x*c.y-c.x*l.y;r+=(l.x+c.x)*u,n+=(l.y+c.y)*u,e+=3*u}return new gc(r/e,n/e,0,t)}(t),x=g.length;g.length;){var b=g.pop();(b.d>y.d||!y.d)&&(y=b,r&&console.log(\"found best %d after %d probes\",Math.round(1e4*b.d)/1e4,x)),b.max-y.d<=e||(d=b.h/2,g.push(new gc(b.p.x-d,b.p.y-d,d,t)),g.push(new gc(b.p.x+d,b.p.y-d,d,t)),g.push(new gc(b.p.x-d,b.p.y+d,d,t)),g.push(new gc(b.p.x+d,b.p.y+d,d,t)),x+=4)}return r&&(console.log(\"num probes: \"+x),console.log(\"best distance: \"+y.d)),y.p}function dc(t,e){return e.max-t.max}function gc(t,e,r,n){this.p=new i(t,e),this.h=r,this.d=function(t,e){for(var r=!1,n=1/0,i=0;i<e.length;i++)for(var a=e[i],o=0,s=a.length,l=s-1;o<s;l=o++){var c=a[o],u=a[l];c.y>t.y!=u.y>t.y&&t.x<(u.x-c.x)*(t.y-c.y)/(u.y-c.y)+c.x&&(r=!r),n=Math.min(n,ka(t,c,u))}return(r?1:-1)*Math.sqrt(n)}(this.p,n),this.max=this.d+this.h*Math.SQRT2}hc.prototype.push=function(t){this.data.push(t),this.length++,this._up(this.length-1)},hc.prototype.pop=function(){if(0!==this.length){var t=this.data[0];return this.length--,this.length>0&&(this.data[0]=this.data[this.length],this._down(0)),this.data.pop(),t}},hc.prototype.peek=function(){return this.data[0]},hc.prototype._up=function(t){for(var e=this.data,r=this.compare,n=e[t];t>0;){var i=t-1>>1,a=e[i];if(r(n,a)>=0)break;e[t]=a,t=i}e[t]=n},hc.prototype._down=function(t){for(var e=this.data,r=this.compare,n=this.length>>1,i=e[t];t<n;){var a=1+(t<<1),o=e[a],s=a+1;if(s<this.length&&r(e[s],o)<0&&(a=s,o=e[s]),r(o,i)>=0)break;e[t]=o,t=a}e[t]=i};var vc=e(function(t){t.exports=function(t,e){var r,n,i,a,o,s,l,c;for(r=3&t.length,n=t.length-r,i=e,o=3432918353,s=461845907,c=0;c<n;)l=255&t.charCodeAt(c)|(255&t.charCodeAt(++c))<<8|(255&t.charCodeAt(++c))<<16|(255&t.charCodeAt(++c))<<24,++c,i=27492+(65535&(a=5*(65535&(i=(i^=l=(65535&(l=(l=(65535&l)*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295)<<13|i>>>19))+((5*(i>>>16)&65535)<<16)&4294967295))+((58964+(a>>>16)&65535)<<16);switch(l=0,r){case 3:l^=(255&t.charCodeAt(c+2))<<16;case 2:l^=(255&t.charCodeAt(c+1))<<8;case 1:i^=l=(65535&(l=(l=(65535&(l^=255&t.charCodeAt(c)))*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295}return i^=t.length,i=2246822507*(65535&(i^=i>>>16))+((2246822507*(i>>>16)&65535)<<16)&4294967295,i=3266489909*(65535&(i^=i>>>13))+((3266489909*(i>>>16)&65535)<<16)&4294967295,(i^=i>>>16)>>>0}}),mc=e(function(t){t.exports=function(t,e){for(var r,n=t.length,i=e^n,a=0;n>=4;)r=1540483477*(65535&(r=255&t.charCodeAt(a)|(255&t.charCodeAt(++a))<<8|(255&t.charCodeAt(++a))<<16|(255&t.charCodeAt(++a))<<24))+((1540483477*(r>>>16)&65535)<<16),i=1540483477*(65535&i)+((1540483477*(i>>>16)&65535)<<16)^(r=1540483477*(65535&(r^=r>>>24))+((1540483477*(r>>>16)&65535)<<16)),n-=4,++a;switch(n){case 3:i^=(255&t.charCodeAt(a+2))<<16;case 2:i^=(255&t.charCodeAt(a+1))<<8;case 1:i=1540483477*(65535&(i^=255&t.charCodeAt(a)))+((1540483477*(i>>>16)&65535)<<16)}return i=1540483477*(65535&(i^=i>>>13))+((1540483477*(i>>>16)&65535)<<16),(i^=i>>>15)>>>0}}),yc=vc,xc=vc,bc=mc;yc.murmur3=xc,yc.murmur2=bc;var _c=7;function wc(t,e){var r=0,n=0,i=e/Math.sqrt(2);switch(t){case\"top-right\":case\"top-left\":n=i-_c;break;case\"bottom-right\":case\"bottom-left\":n=-i+_c;break;case\"bottom\":n=-e+_c;break;case\"top\":n=e-_c}switch(t){case\"top-right\":case\"bottom-right\":r=-i;break;case\"top-left\":case\"bottom-left\":r=i;break;case\"left\":r=e;break;case\"right\":r=-e}return[r,n]}function kc(t){switch(t){case\"right\":case\"top-right\":case\"bottom-right\":return\"right\";case\"left\":case\"top-left\":case\"bottom-left\":return\"left\"}return\"center\"}function Tc(t,e,r,n,a,o,s){var l=o.layoutTextSize.evaluate(e,{}),c=o.layoutIconSize.evaluate(e,{}),u=o.textMaxSize.evaluate(e,{});void 0===u&&(u=l);var h=t.layers[0].layout,f=h.get(\"icon-offset\").evaluate(e,{}),p=Sc(r.horizontal),d=l/24,g=t.tilePixelRatio*d,v=t.tilePixelRatio*u/24,m=t.tilePixelRatio*c,y=t.tilePixelRatio*h.get(\"symbol-spacing\"),x=h.get(\"text-padding\")*t.tilePixelRatio,b=h.get(\"icon-padding\")*t.tilePixelRatio,_=h.get(\"text-max-angle\")/180*Math.PI,k=\"map\"===h.get(\"text-rotation-alignment\")&&\"point\"!==h.get(\"symbol-placement\"),T=\"map\"===h.get(\"icon-rotation-alignment\")&&\"point\"!==h.get(\"symbol-placement\"),A=h.get(\"symbol-placement\"),M=y/2,S=function(l,c){c.x<0||c.x>=ha||c.y<0||c.y>=ha||function(t,e,r,n,a,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_){var k,T,A=t.addToLineVertexArray(e,r),M=0,S=0,E=0,C={},L=yc(\"\"),P=(o.layout.get(\"text-radial-offset\").evaluate(x,{})||0)*Gl;for(var O in n.horizontal){var z=n.horizontal[O];if(!k){L=yc(z.text);var I=o.layout.get(\"text-rotate\").evaluate(x,{});k=new uc(s,r,e,l,c,u,z,h,f,p,t.overscaling,I)}var D=1===z.lineCount;if(S+=Mc(t,e,z,o,p,x,d,A,n.vertical?Yl.horizontal:Yl.horizontalOnly,D?Object.keys(n.horizontal):[O],C,b,_),D)break}n.vertical&&(E+=Mc(t,e,n.vertical,o,p,x,d,A,Yl.vertical,[\"vertical\"],C,b,_));var R=k?k.boxStartIndex:t.collisionBoxArray.length,F=k?k.boxEndIndex:t.collisionBoxArray.length;if(a){var B=function(t,e,r,n,a,o){var s,l,c,u,h=e.image,f=r.layout,p=e.top-1/h.pixelRatio,d=e.left-1/h.pixelRatio,g=e.bottom+1/h.pixelRatio,v=e.right+1/h.pixelRatio;if(\"none\"!==f.get(\"icon-text-fit\")&&a){var m=v-d,y=g-p,x=f.get(\"text-size\").evaluate(o,{})/24,b=a.left*x,_=a.right*x,w=a.top*x,k=_-b,T=a.bottom*x-w,A=f.get(\"icon-text-fit-padding\")[0],M=f.get(\"icon-text-fit-padding\")[1],S=f.get(\"icon-text-fit-padding\")[2],E=f.get(\"icon-text-fit-padding\")[3],C=\"width\"===f.get(\"icon-text-fit\")?.5*(T-y):0,L=\"height\"===f.get(\"icon-text-fit\")?.5*(k-m):0,P=\"width\"===f.get(\"icon-text-fit\")||\"both\"===f.get(\"icon-text-fit\")?k:m,O=\"height\"===f.get(\"icon-text-fit\")||\"both\"===f.get(\"icon-text-fit\")?T:y;s=new i(b+L-E,w+C-A),l=new i(b+L+M+P,w+C-A),c=new i(b+L+M+P,w+C+S+O),u=new i(b+L-E,w+C+S+O)}else s=new i(d,p),l=new i(v,p),c=new i(v,g),u=new i(d,g);var z=r.layout.get(\"icon-rotate\").evaluate(o,{})*Math.PI/180;if(z){var I=Math.sin(z),D=Math.cos(z),R=[D,-I,I,D];s._matMult(R),l._matMult(R),u._matMult(R),c._matMult(R)}return[{tl:s,tr:l,bl:u,br:c,tex:h.paddedRect,writingMode:void 0,glyphOffset:[0,0]}]}(0,a,o,0,Sc(n.horizontal),x),N=o.layout.get(\"icon-rotate\").evaluate(x,{});T=new uc(s,r,e,l,c,u,a,g,v,!1,t.overscaling,N),M=4*B.length;var j=t.iconSizeData,U=null;\"source\"===j.kind?(U=[_s*o.layout.get(\"icon-size\").evaluate(x,{})])[0]>Ac&&w(t.layerIds[0]+': Value for \"icon-size\" is >= 256. Reduce your \"icon-size\".'):\"composite\"===j.kind&&((U=[_s*_.compositeIconSizes[0].evaluate(x,{}),_s*_.compositeIconSizes[1].evaluate(x,{})])[0]>Ac||U[1]>Ac)&&w(t.layerIds[0]+': Value for \"icon-size\" is >= 256. Reduce your \"icon-size\".'),t.addSymbols(t.icon,B,U,y,m,x,!1,e,A.lineStartIndex,A.lineLength)}var V=T?T.boxStartIndex:t.collisionBoxArray.length,q=T?T.boxEndIndex:t.collisionBoxArray.length;t.glyphOffsetArray.length>=Os.MAX_GLYPHS&&w(\"Too many glyphs being rendered in a tile. See https://github.com/mapbox/mapbox-gl-js/issues/2907\"),t.symbolInstances.emplaceBack(e.x,e.y,C.right>=0?C.right:-1,C.center>=0?C.center:-1,C.left>=0?C.left:-1,C.vertical||-1,L,R,F,V,q,l,S,E,M,0,h,P)}(t,c,l,r,n,t.layers[0],t.collisionBoxArray,e.index,e.sourceLayerIndex,t.index,g,x,k,s,m,b,T,f,e,a,o)};if(\"line\"===A)for(var E=0,C=function(t,e,r,n,a){for(var o=[],s=0;s<t.length;s++)for(var l=t[s],c=void 0,u=0;u<l.length-1;u++){var h=l[u],f=l[u+1];h.x<0&&f.x<0||(h.x<0?h=new i(0,h.y+(f.y-h.y)*((0-h.x)/(f.x-h.x)))._round():f.x<0&&(f=new i(0,h.y+(f.y-h.y)*((0-h.x)/(f.x-h.x)))._round()),h.y<0&&f.y<0||(h.y<0?h=new i(h.x+(f.x-h.x)*((0-h.y)/(f.y-h.y)),0)._round():f.y<0&&(f=new i(h.x+(f.x-h.x)*((0-h.y)/(f.y-h.y)),0)._round()),h.x>=n&&f.x>=n||(h.x>=n?h=new i(n,h.y+(f.y-h.y)*((n-h.x)/(f.x-h.x)))._round():f.x>=n&&(f=new i(n,h.y+(f.y-h.y)*((n-h.x)/(f.x-h.x)))._round()),h.y>=a&&f.y>=a||(h.y>=a?h=new i(h.x+(f.x-h.x)*((a-h.y)/(f.y-h.y)),a)._round():f.y>=a&&(f=new i(h.x+(f.x-h.x)*((a-h.y)/(f.y-h.y)),a)._round()),c&&h.equals(c[c.length-1])||(c=[h],o.push(c)),c.push(f)))))}return o}(e.geometry,0,0,ha,ha);E<C.length;E+=1)for(var L=C[E],P=0,O=cc(L,y,_,r.vertical||p,n,24,v,t.overscaling,ha);P<O.length;P+=1){var z=O[P];p&&Ec(t,p.text,M,z)||S(L,z)}else if(\"line-center\"===A)for(var I=0,D=e.geometry;I<D.length;I+=1){var R=D[I];if(R.length>1){var F=lc(R,_,r.vertical||p,n,24,v);F&&S(R,F)}}else if(\"Polygon\"===e.type)for(var B=0,N=Mo(e.geometry,0);B<N.length;B+=1){var j=N[B],U=pc(j,16);S(j[0],new bs(U.x,U.y,0))}else if(\"LineString\"===e.type)for(var V=0,q=e.geometry;V<q.length;V+=1){var H=q[V];S(H,new bs(H[0].x,H[0].y,0))}else if(\"Point\"===e.type)for(var G=0,Y=e.geometry;G<Y.length;G+=1)for(var W=0,X=Y[G];W<X.length;W+=1){var Z=X[W];S([Z],new bs(Z.x,Z.y,0))}}var Ac=65535;function Mc(t,e,r,n,a,o,s,l,c,u,h,f,p){var d=function(t,e,r,n,a,o,s){for(var l=n.layout.get(\"text-rotate\").evaluate(o,{})*Math.PI/180,c=e.positionedGlyphs,u=[],h=0;h<c.length;h++){var f=c[h],p=s[f.fontStack],d=p&&p[f.glyph];if(d){var g=d.rect;if(g){var v=bl+1,m=d.metrics.advance*f.scale/2,y=a?[f.x+m,f.y]:[0,0],x=a?[0,0]:[f.x+m+r[0],f.y+r[1]],b=(d.metrics.left-v)*f.scale-m+x[0],_=(-d.metrics.top-v)*f.scale+x[1],w=b+g.w*f.scale,k=_+g.h*f.scale,T=new i(b,_),A=new i(w,_),M=new i(b,k),S=new i(w,k);if(a&&f.vertical){var E=new i(-m,m),C=-Math.PI/2,L=new i(5,0);T._rotateAround(C,E)._add(L),A._rotateAround(C,E)._add(L),M._rotateAround(C,E)._add(L),S._rotateAround(C,E)._add(L)}if(l){var P=Math.sin(l),O=Math.cos(l),z=[O,-P,P,O];T._matMult(z),A._matMult(z),M._matMult(z),S._matMult(z)}u.push({tl:T,tr:A,bl:M,br:S,tex:g,writingMode:e.writingMode,glyphOffset:y})}}}return u}(0,r,s,n,a,o,f),g=t.textSizeData,v=null;\"source\"===g.kind?(v=[_s*n.layout.get(\"text-size\").evaluate(o,{})])[0]>Ac&&w(t.layerIds[0]+': Value for \"text-size\" is >= 256. Reduce your \"text-size\".'):\"composite\"===g.kind&&((v=[_s*p.compositeTextSizes[0].evaluate(o,{}),_s*p.compositeTextSizes[1].evaluate(o,{})])[0]>Ac||v[1]>Ac)&&w(t.layerIds[0]+': Value for \"text-size\" is >= 256. Reduce your \"text-size\".'),t.addSymbols(t.text,d,v,s,a,o,c,e,l.lineStartIndex,l.lineLength);for(var m=0,y=u;m<y.length;m+=1)h[y[m]]=t.text.placedSymbolArray.length-1;return 4*d.length}function Sc(t){for(var e in t)return t[e];return null}function Ec(t,e,r,n){var i=t.compareText;if(e in i){for(var a=i[e],o=a.length-1;o>=0;o--)if(n.dist(a[o])<r)return!0}else i[e]=[];return i[e].push(n),!1}t.Actor=_l,t.AlphaImage=qa,t.CanonicalTileID=Pl,t.CollisionBoxArray=Li,t.Color=ne,t.DEMData=Dl,t.DataConstantProperty=Jn,t.DictionaryCoder=Fl,t.EXTENT=ha,t.ErrorEvent=Ot,t.EvaluationParameters=Un,t.Event=Pt,t.Evented=zt,t.FeatureIndex=Ul,t.FillBucket=Lo,t.FillExtrusionBucket=Yo,t.ImageAtlas=Gs,t.ImagePosition=qs,t.LineBucket=os,t.LngLat=Tl,t.LngLatBounds=kl,t.MercatorCoordinate=Ll,t.ONE_EM=Gl,t.OverscaledTileID=zl,t.Point=i,t.Point$1=i,t.ProgramConfiguration=sa,t.Properties=ei,t.Protobuf=Qs,t.RGBAImage=Ha,t.RequestManager=j,t.ResourceType=yt,t.SegmentVector=Vi,t.SourceFeatureState=jl,t.StructArrayLayout1ui2=Mi,t.StructArrayLayout2i4=li,t.StructArrayLayout2ui4=Ai,t.StructArrayLayout3ui6=Ti,t.StructArrayLayout4i8=ci,t.SymbolBucket=Os,t.Texture=Js,t.Tile=Hl,t.Transitionable=Hn,t.Uniform1f=Xi,t.Uniform1i=Wi,t.Uniform2f=Zi,t.Uniform3f=Ji,t.Uniform4f=Ki,t.UniformColor=$i,t.UniformMatrix4f=ta,t.UnwrappedTileID=Ol,t.ValidationError=Dt,t.WritingMode=Yl,t.ZoomHistory=Sn,t.addDynamicAttributes=Cs,t.asyncAll=function(t,e,r){if(!t.length)return r(null,[]);var n=t.length,i=new Array(t.length),a=null;t.forEach(function(t,o){e(t,function(t,e){t&&(a=t),i[o]=e,0==--n&&r(a,i)})})},t.bezier=s,t.bindAll=v,t.browser=z,t.cacheEntryPossiblyAdded=function(t){++mt>dt&&(t.send(\"enforceCacheSizeLimit\",pt),mt=0)},t.clamp=c,t.clearTileCache=function(t){var e=self.caches.delete(ft);t&&e.catch(t).then(function(){return t()})},t.clone=function(t){var e=new Pa(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e},t.clone$1=b,t.config=I,t.create=function(){var t=new Pa(16);return Pa!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=0,t[12]=0,t[13]=0,t[14]=0),t[0]=1,t[5]=1,t[10]=1,t[15]=1,t},t.create$1=Oa,t.create$2=function(){var t=new Pa(4);return Pa!=Float32Array&&(t[1]=0,t[2]=0),t[0]=1,t[3]=1,t},t.createCommonjsModule=e,t.createExpression=Or,t.createLayout=oi,t.createStyleLayer=function(t){return\"custom\"===t.type?new js(t):new Us[t.type](t)},t.deepEqual=o,t.ease=l,t.emitValidationErrors=mn,t.endsWith=m,t.enforceCacheSizeLimit=function(t){self.caches&&self.caches.open(ft).then(function(e){e.keys().then(function(r){for(var n=0;n<r.length-t;n++)e.delete(r[n])})})},t.evaluateRadialOffset=wc,t.evaluateSizeForFeature=ks,t.evaluateSizeForZoom=Ts,t.evented=Nn,t.extend=h,t.featureFilter=Gr,t.filterObject=x,t.fromRotation=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=r,t[2]=0,t[3]=-r,t[4]=n,t[5]=0,t[6]=0,t[7]=0,t[8]=1,t},t.getAnchorAlignment=ec,t.getAnchorJustification=kc,t.getArrayBuffer=Mt,t.getImage=Et,t.getJSON=function(t,e){return At(h(t,{type:\"json\"}),e)},t.getReferrer=_t,t.getVideo=function(t,e){var r,n,i=self.document.createElement(\"video\");i.muted=!0,i.onloadstart=function(){e(null,i)};for(var a=0;a<t.length;a++){var o=self.document.createElement(\"source\");r=t[a],n=void 0,(n=self.document.createElement(\"a\")).href=r,(n.protocol!==self.document.location.protocol||n.host!==self.document.location.host)&&(i.crossOrigin=\"Anonymous\"),o.src=t[a],i.appendChild(o)}return{cancel:function(){}}},t.identity=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t},t.invert=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],g=e[13],v=e[14],m=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,k=i*c-a*l,T=u*g-h*d,A=u*v-f*d,M=u*m-p*d,S=h*v-f*g,E=h*m-p*g,C=f*m-p*v,L=y*C-x*E+b*S+_*M-w*A+k*T;return L?(L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(i*E-n*C-a*S)*L,t[2]=(g*k-v*w+m*_)*L,t[3]=(f*w-h*k-p*_)*L,t[4]=(l*M-o*C-c*A)*L,t[5]=(r*C-i*M+a*A)*L,t[6]=(v*b-d*k-m*x)*L,t[7]=(u*k-f*b+p*x)*L,t[8]=(o*E-s*M+c*T)*L,t[9]=(n*M-r*E-a*T)*L,t[10]=(d*w-g*b+m*y)*L,t[11]=(h*b-u*w-p*y)*L,t[12]=(s*A-o*S-l*T)*L,t[13]=(r*S-n*A+i*T)*L,t[14]=(g*x-d*_-v*y)*L,t[15]=(u*_-h*x+f*y)*L,t):null},t.isChar=En,t.isMapboxURL=q,t.keysDifference=function(t,e){var r=[];for(var n in t)n in e||r.push(n);return r},t.makeRequest=At,t.mapObject=y,t.mercatorXfromLng=Ml,t.mercatorYfromLat=Sl,t.mercatorZfromAltitude=El,t.multiply=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],g=e[12],v=e[13],m=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*h+w*g,t[1]=x*i+b*l+_*f+w*v,t[2]=x*a+b*c+_*p+w*m,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*h+w*g,t[5]=x*i+b*l+_*f+w*v,t[6]=x*a+b*c+_*p+w*m,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*h+w*g,t[9]=x*i+b*l+_*f+w*v,t[10]=x*a+b*c+_*p+w*m,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*h+w*g,t[13]=x*i+b*l+_*f+w*v,t[14]=x*a+b*c+_*p+w*m,t[15]=x*o+b*u+_*d+w*y,t},t.mvt=Vo,t.number=Ee,t.ortho=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t},t.parseGlyphPBF=function(t){return new Qs(t).readFields(ml,[])},t.pbf=Qs,t.performSymbolLayout=function(t,e,r,n,i,a){t.createArrays();var o=512*t.overscaling;t.tilePixelRatio=ha/o,t.compareText={},t.iconsNeedLinear=!1;var s=t.layers[0].layout,l=t.layers[0]._unevaluatedLayout._values,c={};if(\"composite\"===t.textSizeData.kind){var u=t.textSizeData,h=u.minZoom,f=u.maxZoom;c.compositeTextSizes=[l[\"text-size\"].possiblyEvaluate(new Un(h)),l[\"text-size\"].possiblyEvaluate(new Un(f))]}if(\"composite\"===t.iconSizeData.kind){var p=t.iconSizeData,d=p.minZoom,g=p.maxZoom;c.compositeIconSizes=[l[\"icon-size\"].possiblyEvaluate(new Un(d)),l[\"icon-size\"].possiblyEvaluate(new Un(g))]}c.layoutTextSize=l[\"text-size\"].possiblyEvaluate(new Un(t.zoom+1)),c.layoutIconSize=l[\"icon-size\"].possiblyEvaluate(new Un(t.zoom+1)),c.textMaxSize=l[\"text-size\"].possiblyEvaluate(new Un(18));for(var v=s.get(\"text-line-height\")*Gl,m=\"map\"===s.get(\"text-rotation-alignment\")&&\"point\"!==s.get(\"symbol-placement\"),y=s.get(\"text-keep-upright\"),x=0,b=t.features;x<b.length;x+=1){var _=b[x],k=s.get(\"text-font\").evaluate(_,{}).join(\",\"),T=r,A={horizontal:{},vertical:void 0},M=_.text,S=[0,0];if(M){var E=M.toString(),C=s.get(\"text-letter-spacing\").evaluate(_,{})*Gl,L=Ln(E)?C:0,P=s.get(\"text-anchor\").evaluate(_,{}),O=s.get(\"text-variable-anchor\"),z=s.get(\"text-radial-offset\").evaluate(_,{});O||(S=z?wc(P,z*Gl):s.get(\"text-offset\").evaluate(_,{}).map(function(t){return t*Gl}));var I=m?\"center\":s.get(\"text-justify\").evaluate(_,{}),D=\"point\"===s.get(\"symbol-placement\")?s.get(\"text-max-width\").evaluate(_,{})*Gl:0;if(!m&&O)for(var R=\"auto\"===I?O.map(function(t){return kc(t)}):[I],F=!1,B=0;B<R.length;B++){var N=R[B];if(!A.horizontal[N])if(F)A.horizontal[N]=A.horizontal[0];else{var j=Xl(M,e,k,D,v,\"center\",N,L,S,Yl.horizontal);j&&(A.horizontal[N]=j,F=1===j.lineCount)}}else{\"auto\"===I&&(I=kc(P));var U=Xl(M,e,k,D,v,P,I,L,S,Yl.horizontal);U&&(A.horizontal[I]=U),Cn(E)&&m&&y&&(A.vertical=Xl(M,e,k,D,v,P,I,L,S,Yl.vertical))}}var V=void 0;if(_.icon){var q=n[_.icon];q&&(V=nc(i[_.icon],s.get(\"icon-offset\").evaluate(_,{}),s.get(\"icon-anchor\").evaluate(_,{})),void 0===t.sdfIcons?t.sdfIcons=q.sdf:t.sdfIcons!==q.sdf&&w(\"Style sheet warning: Cannot mix SDF and non-SDF icons in one buffer\"),q.pixelRatio!==t.pixelRatio?t.iconsNeedLinear=!0:0!==s.get(\"icon-rotate\").constantOr(1)&&(t.iconsNeedLinear=!0))}(Object.keys(A.horizontal).length||V)&&Tc(t,_,A,V,T,c,S)}a&&t.generateCollisionDebugBuffers()},t.perspective=function(t,e,r,n,i){var a,o=1/Math.tan(e/2);return t[0]=o/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=o,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=-1,t[12]=0,t[13]=0,t[15]=0,null!=i&&i!==1/0?(a=1/(n-i),t[10]=(i+n)*a,t[14]=2*i*n*a):(t[10]=-1,t[14]=-2*n),t},t.pick=function(t,e){for(var r={},n=0;n<e.length;n++){var i=e[n];i in t&&(r[i]=t[i])}return r},t.plugin=jn,t.polygonIntersectsPolygon=va,t.postMapLoadEvent=ht,t.postTurnstileEvent=ct,t.potpack=Vs,t.rasterBoundsAttributes=Rl,t.refProperties=[\"type\",\"source\",\"source-layer\",\"minzoom\",\"maxzoom\",\"filter\",\"layout\"],t.register=kn,t.registerForPluginAvailability=function(t){return Fn?t({pluginURL:Fn,completionCallback:Dn}):Nn.once(\"pluginAvailable\",t),t},t.rotate=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=Math.sin(r),l=Math.cos(r);return t[0]=n*l+a*s,t[1]=i*l+o*s,t[2]=n*-s+a*l,t[3]=i*-s+o*l,t},t.rotateX=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];return e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+h*n,t[7]=l*i+f*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=h*i-s*n,t[11]=f*i-l*n,t},t.rotateZ=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];return e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+h*n,t[3]=l*i+f*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=h*i-s*n,t[7]=f*i-l*n,t},t.scale=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t},t.setCacheLimits=function(t,e){pt=t,dt=e},t.setRTLTextPlugin=function(t,e){if(Rn)throw new Error(\"setRTLTextPlugin cannot be called multiple times.\");Rn=!0,Fn=z.resolveURL(t),Dn=function(t){t?(Rn=!1,Fn=null,e&&e(t)):Bn=!0},Nn.fire(new Pt(\"pluginAvailable\",{pluginURL:Fn,completionCallback:Dn}))},t.sphericalToCartesian=function(t){var e=t[0],r=t[1],n=t[2];return r+=90,r*=Math.PI/180,n*=Math.PI/180,{x:e*Math.cos(r)*Math.sin(n),y:e*Math.sin(r)*Math.sin(n),z:e*Math.cos(n)}},t.styleSpec=It,t.symbolSize=As,t.transformMat3=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t},t.transformMat4=Da,t.translate=function(t,e,r){var n,i,a,o,s,l,c,u,h,f,p,d,g=r[0],v=r[1],m=r[2];return e===t?(t[12]=e[0]*g+e[4]*v+e[8]*m+e[12],t[13]=e[1]*g+e[5]*v+e[9]*m+e[13],t[14]=e[2]*g+e[6]*v+e[10]*m+e[14],t[15]=e[3]*g+e[7]*v+e[11]*m+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*g+s*v+h*m+e[12],t[13]=i*g+l*v+f*m+e[13],t[14]=a*g+c*v+p*m+e[14],t[15]=o*g+u*v+d*m+e[15]),t},t.uniqueId=p,t.validateCustomStyleLayer=function(t){var e=[],r=t.id;return void 0===r&&e.push({message:\"layers.\"+r+': missing required property \"id\"'}),void 0===t.render&&e.push({message:\"layers.\"+r+': missing required method \"render\"'}),t.renderingMode&&\"2d\"!==t.renderingMode&&\"3d\"!==t.renderingMode&&e.push({message:\"layers.\"+r+': property \"renderingMode\" must be either \"2d\" or \"3d\"'}),e},t.validateLight=dn,t.validateStyle=pn,t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.vectorTile=Vo,t.version=\"1.1.1\",t.warnOnce=w,t.webpSupported=D,t.window=self,t.wrap=u}),n(0,function(t){function e(t){var r=typeof t;if(\"number\"===r||\"boolean\"===r||\"string\"===r||null==t)return JSON.stringify(t);if(Array.isArray(t)){for(var n=\"[\",i=0,a=t;i<a.length;i+=1)n+=e(a[i])+\",\";return n+\"]\"}for(var o=Object.keys(t).sort(),s=\"{\",l=0;l<o.length;l++)s+=JSON.stringify(o[l])+\":\"+e(t[o[l]])+\",\";return s+\"}\"}function r(r){for(var n=\"\",i=0,a=t.refProperties;i<a.length;i+=1)n+=\"/\"+e(r[a[i]]);return n}var n=function(t){this.keyCache={},t&&this.replace(t)};n.prototype.replace=function(t){this._layerConfigs={},this._layers={},this.update(t,[])},n.prototype.update=function(e,n){for(var i=this,a=0,o=e;a<o.length;a+=1){var s=o[a];this._layerConfigs[s.id]=s;var l=this._layers[s.id]=t.createStyleLayer(s);l._featureFilter=t.featureFilter(l.filter),this.keyCache[s.id]&&delete this.keyCache[s.id]}for(var c=0,u=n;c<u.length;c+=1){var h=u[c];delete this.keyCache[h],delete this._layerConfigs[h],delete this._layers[h]}this.familiesBySource={};for(var f=0,p=function(t,e){for(var n={},i=0;i<t.length;i++){var a=e&&e[t[i].id]||r(t[i]);e&&(e[t[i].id]=a);var o=n[a];o||(o=n[a]=[]),o.push(t[i])}var s=[];for(var l in n)s.push(n[l]);return s}(t.values(this._layerConfigs),this.keyCache);f<p.length;f+=1){var d=p[f].map(function(t){return i._layers[t.id]}),g=d[0];if(\"none\"!==g.visibility){var v=g.source||\"\",m=this.familiesBySource[v];m||(m=this.familiesBySource[v]={});var y=g.sourceLayer||\"_geojsonTileLayer\",x=m[y];x||(x=m[y]=[]),x.push(d)}}};var i=function(e){var r={},n=[];for(var i in e){var a=e[i],o=r[i]={};for(var s in a){var l=a[+s];if(l&&0!==l.bitmap.width&&0!==l.bitmap.height){var c={x:0,y:0,w:l.bitmap.width+2,h:l.bitmap.height+2};n.push(c),o[s]={rect:c,metrics:l.metrics}}}}var u=t.potpack(n),h=u.w,f=u.h,p=new t.AlphaImage({width:h||1,height:f||1});for(var d in e){var g=e[d];for(var v in g){var m=g[+v];if(m&&0!==m.bitmap.width&&0!==m.bitmap.height){var y=r[d][v].rect;t.AlphaImage.copy(m.bitmap,p,{x:0,y:0},{x:y.x+1,y:y.y+1},m.bitmap)}}}this.image=p,this.positions=r};t.register(\"GlyphAtlas\",i);var a=function(e){this.tileID=new t.OverscaledTileID(e.tileID.overscaledZ,e.tileID.wrap,e.tileID.canonical.z,e.tileID.canonical.x,e.tileID.canonical.y),this.uid=e.uid,this.zoom=e.zoom,this.pixelRatio=e.pixelRatio,this.tileSize=e.tileSize,this.source=e.source,this.overscaling=this.tileID.overscaleFactor(),this.showCollisionBoxes=e.showCollisionBoxes,this.collectResourceTiming=!!e.collectResourceTiming,this.returnDependencies=!!e.returnDependencies};function o(e,r){for(var n=new t.EvaluationParameters(r),i=0,a=e;i<a.length;i+=1)a[i].recalculate(n)}a.prototype.parse=function(e,r,n,a){var s=this;this.status=\"parsing\",this.data=e,this.collisionBoxArray=new t.CollisionBoxArray;var l=new t.DictionaryCoder(Object.keys(e.layers).sort()),c=new t.FeatureIndex(this.tileID);c.bucketLayerIDs=[];var u,h,f,p,d={},g={featureIndex:c,iconDependencies:{},patternDependencies:{},glyphDependencies:{}},v=r.familiesBySource[this.source];for(var m in v){var y=e.layers[m];if(y){1===y.version&&t.warnOnce('Vector tile source \"'+this.source+'\" layer \"'+m+'\" does not use vector tile spec v2 and therefore may have some rendering errors.');for(var x=l.encode(m),b=[],_=0;_<y.length;_++){var w=y.feature(_);b.push({feature:w,index:_,sourceLayerIndex:x})}for(var k=0,T=v[m];k<T.length;k+=1){var A=T[k],M=A[0];M.minzoom&&this.zoom<Math.floor(M.minzoom)||M.maxzoom&&this.zoom>=M.maxzoom||\"none\"!==M.visibility&&(o(A,this.zoom),(d[M.id]=M.createBucket({index:c.bucketLayerIDs.length,layers:A,zoom:this.zoom,pixelRatio:this.pixelRatio,overscaling:this.overscaling,collisionBoxArray:this.collisionBoxArray,sourceLayerIndex:x,sourceID:this.source})).populate(b,g),c.bucketLayerIDs.push(A.map(function(t){return t.id})))}}}var S=t.mapObject(g.glyphDependencies,function(t){return Object.keys(t).map(Number)});Object.keys(S).length?n.send(\"getGlyphs\",{uid:this.uid,stacks:S},function(t,e){u||(u=t,h=e,L.call(s))}):h={};var E=Object.keys(g.iconDependencies);E.length?n.send(\"getImages\",{icons:E},function(t,e){u||(u=t,f=e,L.call(s))}):f={};var C=Object.keys(g.patternDependencies);function L(){if(u)return a(u);if(h&&f&&p){var e=new i(h),r=new t.ImageAtlas(f,p);for(var n in d){var s=d[n];s instanceof t.SymbolBucket?(o(s.layers,this.zoom),t.performSymbolLayout(s,h,e.positions,f,r.iconPositions,this.showCollisionBoxes)):s.hasPattern&&(s instanceof t.LineBucket||s instanceof t.FillBucket||s instanceof t.FillExtrusionBucket)&&(o(s.layers,this.zoom),s.addFeatures(g,r.patternPositions))}this.status=\"done\",a(null,{buckets:t.values(d).filter(function(t){return!t.isEmpty()}),featureIndex:c,collisionBoxArray:this.collisionBoxArray,glyphAtlasImage:e.image,imageAtlas:r,glyphMap:this.returnDependencies?h:null,iconMap:this.returnDependencies?f:null,glyphPositions:this.returnDependencies?e.positions:null})}}C.length?n.send(\"getImages\",{icons:C},function(t,e){u||(u=t,p=e,L.call(s))}):p={},L.call(this)};var s=\"undefined\"!=typeof performance,l={getEntriesByName:function(t){return!!(s&&performance&&performance.getEntriesByName)&&performance.getEntriesByName(t)},mark:function(t){return!!(s&&performance&&performance.mark)&&performance.mark(t)},measure:function(t,e,r){return!!(s&&performance&&performance.measure)&&performance.measure(t,e,r)},clearMarks:function(t){return!!(s&&performance&&performance.clearMarks)&&performance.clearMarks(t)},clearMeasures:function(t){return!!(s&&performance&&performance.clearMeasures)&&performance.clearMeasures(t)}},c=function(t){this._marks={start:[t.url,\"start\"].join(\"#\"),end:[t.url,\"end\"].join(\"#\"),measure:t.url.toString()},l.mark(this._marks.start)};function u(e,r){var n=t.getArrayBuffer(e.request,function(e,n,i,a){e?r(e):n&&r(null,{vectorTile:new t.vectorTile.VectorTile(new t.pbf(n)),rawData:n,cacheControl:i,expires:a})});return function(){n.cancel(),r()}}c.prototype.finish=function(){l.mark(this._marks.end);var t=l.getEntriesByName(this._marks.measure);return 0===t.length&&(l.measure(this._marks.measure,this._marks.start,this._marks.end),t=l.getEntriesByName(this._marks.measure),l.clearMarks(this._marks.start),l.clearMarks(this._marks.end),l.clearMeasures(this._marks.measure)),t},l.Performance=c;var h=function(t,e,r){this.actor=t,this.layerIndex=e,this.loadVectorData=r||u,this.loading={},this.loaded={}};h.prototype.loadTile=function(e,r){var n=this,i=e.uid;this.loading||(this.loading={});var o=!!(e&&e.request&&e.request.collectResourceTiming)&&new l.Performance(e.request),s=this.loading[i]=new a(e);s.abort=this.loadVectorData(e,function(e,a){if(delete n.loading[i],e||!a)return s.status=\"done\",n.loaded[i]=s,r(e);var l=a.rawData,c={};a.expires&&(c.expires=a.expires),a.cacheControl&&(c.cacheControl=a.cacheControl);var u={};if(o){var h=o.finish();h&&(u.resourceTiming=JSON.parse(JSON.stringify(h)))}s.vectorTile=a.vectorTile,s.parse(a.vectorTile,n.layerIndex,n.actor,function(e,n){if(e||!n)return r(e);r(null,t.extend({rawTileData:l.slice(0)},n,c,u))}),n.loaded=n.loaded||{},n.loaded[i]=s})},h.prototype.reloadTile=function(t,e){var r=this.loaded,n=t.uid,i=this;if(r&&r[n]){var a=r[n];a.showCollisionBoxes=t.showCollisionBoxes;var o=function(t,r){var n=a.reloadCallback;n&&(delete a.reloadCallback,a.parse(a.vectorTile,i.layerIndex,i.actor,n)),e(t,r)};\"parsing\"===a.status?a.reloadCallback=o:\"done\"===a.status&&(a.vectorTile?a.parse(a.vectorTile,this.layerIndex,this.actor,o):o())}},h.prototype.abortTile=function(t,e){var r=this.loading,n=t.uid;r&&r[n]&&r[n].abort&&(r[n].abort(),delete r[n]),e()},h.prototype.removeTile=function(t,e){var r=this.loaded,n=t.uid;r&&r[n]&&delete r[n],e()};var f=function(){this.loaded={}};f.prototype.loadTile=function(e,r){var n=e.uid,i=e.encoding,a=e.rawImageData,o=new t.DEMData(n,a,i);this.loaded=this.loaded||{},this.loaded[n]=o,r(null,o)},f.prototype.removeTile=function(t){var e=this.loaded,r=t.uid;e&&e[r]&&delete e[r]};var p={RADIUS:6378137,FLATTENING:1/298.257223563,POLAR_RADIUS:6356752.3142};function d(t){var e=0;if(t&&t.length>0){e+=Math.abs(g(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(g(t[r]))}return e}function g(t){var e,r,n,i,a,o,s=0,l=t.length;if(l>2){for(o=0;o<l;o++)o===l-2?(n=l-2,i=l-1,a=0):o===l-1?(n=l-1,i=0,a=1):(n=o,i=o+1,a=o+2),e=t[n],r=t[i],s+=(v(t[a][0])-v(e[0]))*Math.sin(v(r[1]));s=s*p.RADIUS*p.RADIUS/2}return s}function v(t){return t*Math.PI/180}var m={geometry:function t(e){var r,n=0;switch(e.type){case\"Polygon\":return d(e.coordinates);case\"MultiPolygon\":for(r=0;r<e.coordinates.length;r++)n+=d(e.coordinates[r]);return n;case\"Point\":case\"MultiPoint\":case\"LineString\":case\"MultiLineString\":return 0;case\"GeometryCollection\":for(r=0;r<e.geometries.length;r++)n+=t(e.geometries[r]);return n}},ring:g};function y(t,e){return function(r){return t(r,e)}}function x(t,e){e=!!e,t[0]=b(t[0],e);for(var r=1;r<t.length;r++)t[r]=b(t[r],!e);return t}function b(t,e){return function(t){return m.ring(t)>=0}(t)===e?t:t.reverse()}var _=t.vectorTile.VectorTileFeature.prototype.toGeoJSON,w=function(e){this._feature=e,this.extent=t.EXTENT,this.type=e.type,this.properties=e.tags,\"id\"in e&&!isNaN(e.id)&&(this.id=parseInt(e.id,10))};w.prototype.loadGeometry=function(){if(1===this._feature.type){for(var e=[],r=0,n=this._feature.geometry;r<n.length;r+=1){var i=n[r];e.push([new t.Point$1(i[0],i[1])])}return e}for(var a=[],o=0,s=this._feature.geometry;o<s.length;o+=1){for(var l=[],c=0,u=s[o];c<u.length;c+=1){var h=u[c];l.push(new t.Point$1(h[0],h[1]))}a.push(l)}return a},w.prototype.toGeoJSON=function(t,e,r){return _.call(this,t,e,r)};var k=function(e){this.layers={_geojsonTileLayer:this},this.name=\"_geojsonTileLayer\",this.extent=t.EXTENT,this.length=e.length,this._features=e};k.prototype.feature=function(t){return new w(this._features[t])};var T=t.vectorTile.VectorTileFeature,A=M;function M(t,e){this.options=e||{},this.features=t,this.length=t.length}function S(t,e){this.id=\"number\"==typeof t.id?t.id:void 0,this.type=t.type,this.rawGeometry=1===t.type?[t.geometry]:t.geometry,this.properties=t.tags,this.extent=e||4096}M.prototype.feature=function(t){return new S(this.features[t],this.options.extent)},S.prototype.loadGeometry=function(){var e=this.rawGeometry;this.geometry=[];for(var r=0;r<e.length;r++){for(var n=e[r],i=[],a=0;a<n.length;a++)i.push(new t.Point$1(n[a][0],n[a][1]));this.geometry.push(i)}return this.geometry},S.prototype.bbox=function(){this.geometry||this.loadGeometry();for(var t=this.geometry,e=1/0,r=-1/0,n=1/0,i=-1/0,a=0;a<t.length;a++)for(var o=t[a],s=0;s<o.length;s++){var l=o[s];e=Math.min(e,l.x),r=Math.max(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.y)}return[e,n,r,i]},S.prototype.toGeoJSON=T.prototype.toGeoJSON;var E=P,C=P,L=A;function P(e){var r=new t.pbf;return function(t,e){for(var r in t.layers)e.writeMessage(3,O,t.layers[r])}(e,r),r.finish()}function O(t,e){var r;e.writeVarintField(15,t.version||1),e.writeStringField(1,t.name||\"\"),e.writeVarintField(5,t.extent||4096);var n={keys:[],values:[],keycache:{},valuecache:{}};for(r=0;r<t.length;r++)n.feature=t.feature(r),e.writeMessage(2,z,n);var i=n.keys;for(r=0;r<i.length;r++)e.writeStringField(3,i[r]);var a=n.values;for(r=0;r<a.length;r++)e.writeMessage(4,B,a[r])}function z(t,e){var r=t.feature;void 0!==r.id&&e.writeVarintField(1,r.id),e.writeMessage(2,I,t),e.writeVarintField(3,r.type),e.writeMessage(4,F,r)}function I(t,e){var r=t.feature,n=t.keys,i=t.values,a=t.keycache,o=t.valuecache;for(var s in r.properties){var l=a[s];void 0===l&&(n.push(s),l=n.length-1,a[s]=l),e.writeVarint(l);var c=r.properties[s],u=typeof c;\"string\"!==u&&\"boolean\"!==u&&\"number\"!==u&&(c=JSON.stringify(c));var h=u+\":\"+c,f=o[h];void 0===f&&(i.push(c),f=i.length-1,o[h]=f),e.writeVarint(f)}}function D(t,e){return(e<<3)+(7&t)}function R(t){return t<<1^t>>31}function F(t,e){for(var r=t.loadGeometry(),n=t.type,i=0,a=0,o=r.length,s=0;s<o;s++){var l=r[s],c=1;1===n&&(c=l.length),e.writeVarint(D(1,c));for(var u=3===n?l.length-1:l.length,h=0;h<u;h++){1===h&&1!==n&&e.writeVarint(D(2,u-1));var f=l[h].x-i,p=l[h].y-a;e.writeVarint(R(f)),e.writeVarint(R(p)),i+=f,a+=p}3===n&&e.writeVarint(D(7,1))}}function B(t,e){var r=typeof t;\"string\"===r?e.writeStringField(1,t):\"boolean\"===r?e.writeBooleanField(7,t):\"number\"===r&&(t%1!=0?e.writeDoubleField(3,t):t<0?e.writeSVarintField(6,t):e.writeVarintField(5,t))}function N(t,e,r,n){j(t,r,n),j(e,2*r,2*n),j(e,2*r+1,2*n+1)}function j(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function U(t,e,r,n){var i=t-r,a=e-n;return i*i+a*a}E.fromVectorTileJs=C,E.fromGeojsonVt=function(t,e){e=e||{};var r={};for(var n in t)r[n]=new A(t[n].features,e),r[n].name=n,r[n].version=e.version,r[n].extent=e.extent;return P({layers:r})},E.GeoJSONWrapper=L;var V=function(t){return t[0]},q=function(t){return t[1]},H=function(t,e,r,n,i){void 0===e&&(e=V),void 0===r&&(r=q),void 0===n&&(n=64),void 0===i&&(i=Float64Array),this.nodeSize=n,this.points=t;for(var a=t.length<65536?Uint16Array:Uint32Array,o=this.ids=new a(t.length),s=this.coords=new i(2*t.length),l=0;l<t.length;l++)o[l]=l,s[2*l]=e(t[l]),s[2*l+1]=r(t[l]);!function t(e,r,n,i,a,o){if(!(a-i<=n)){var s=i+a>>1;!function t(e,r,n,i,a,o){for(;a>i;){if(a-i>600){var s=a-i+1,l=n-i+1,c=Math.log(s),u=.5*Math.exp(2*c/3),h=.5*Math.sqrt(c*u*(s-u)/s)*(l-s/2<0?-1:1);t(e,r,n,Math.max(i,Math.floor(n-l*u/s+h)),Math.min(a,Math.floor(n+(s-l)*u/s+h)),o)}var f=r[2*n+o],p=i,d=a;for(N(e,r,i,n),r[2*a+o]>f&&N(e,r,i,a);p<d;){for(N(e,r,p,d),p++,d--;r[2*p+o]<f;)p++;for(;r[2*d+o]>f;)d--}r[2*i+o]===f?N(e,r,i,d):N(e,r,++d,a),d<=n&&(i=d+1),n<=d&&(a=d-1)}}(e,r,s,i,a,o%2),t(e,r,n,i,s-1,o+1),t(e,r,n,s+1,a,o+1)}}(o,s,n,0,o.length-1,0)};H.prototype.range=function(t,e,r,n){return function(t,e,r,n,i,a,o){for(var s,l,c=[0,t.length-1,0],u=[];c.length;){var h=c.pop(),f=c.pop(),p=c.pop();if(f-p<=o)for(var d=p;d<=f;d++)s=e[2*d],l=e[2*d+1],s>=r&&s<=i&&l>=n&&l<=a&&u.push(t[d]);else{var g=Math.floor((p+f)/2);s=e[2*g],l=e[2*g+1],s>=r&&s<=i&&l>=n&&l<=a&&u.push(t[g]);var v=(h+1)%2;(0===h?r<=s:n<=l)&&(c.push(p),c.push(g-1),c.push(v)),(0===h?i>=s:a>=l)&&(c.push(g+1),c.push(f),c.push(v))}}return u}(this.ids,this.coords,t,e,r,n,this.nodeSize)},H.prototype.within=function(t,e,r){return function(t,e,r,n,i,a){for(var o=[0,t.length-1,0],s=[],l=i*i;o.length;){var c=o.pop(),u=o.pop(),h=o.pop();if(u-h<=a)for(var f=h;f<=u;f++)U(e[2*f],e[2*f+1],r,n)<=l&&s.push(t[f]);else{var p=Math.floor((h+u)/2),d=e[2*p],g=e[2*p+1];U(d,g,r,n)<=l&&s.push(t[p]);var v=(c+1)%2;(0===c?r-i<=d:n-i<=g)&&(o.push(h),o.push(p-1),o.push(v)),(0===c?r+i>=d:n+i>=g)&&(o.push(p+1),o.push(u),o.push(v))}}return s}(this.ids,this.coords,t,e,r,this.nodeSize)};var G={minZoom:0,maxZoom:16,radius:40,extent:512,nodeSize:64,log:!1,reduce:null,map:function(t){return t}},Y=function(t){this.options=Q(Object.create(G),t),this.trees=new Array(this.options.maxZoom+1)};function W(t,e,r,n,i){return{x:t,y:e,zoom:1/0,id:r,parentId:-1,numPoints:n,properties:i}}function X(t,e){var r=t.geometry.coordinates,n=r[0],i=r[1];return{x:K(n),y:$(i),zoom:1/0,index:e,parentId:-1}}function Z(t){return{type:\"Feature\",id:t.id,properties:J(t),geometry:{type:\"Point\",coordinates:[(n=t.x,360*(n-.5)),(e=t.y,r=(180-360*e)*Math.PI/180,360*Math.atan(Math.exp(r))/Math.PI-90)]}};var e,r,n}function J(t){var e=t.numPoints,r=e>=1e4?Math.round(e/1e3)+\"k\":e>=1e3?Math.round(e/100)/10+\"k\":e;return Q(Q({},t.properties),{cluster:!0,cluster_id:t.id,point_count:e,point_count_abbreviated:r})}function K(t){return t/360+.5}function $(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function Q(t,e){for(var r in e)t[r]=e[r];return t}function tt(t){return t.x}function et(t){return t.y}function rt(t,e,r,n,i,a){var o=i-r,s=a-n;if(0!==o||0!==s){var l=((t-r)*o+(e-n)*s)/(o*o+s*s);l>1?(r=i,n=a):l>0&&(r+=o*l,n+=s*l)}return(o=t-r)*o+(s=e-n)*s}function nt(t,e,r,n){var i={id:void 0===t?null:t,type:e,geometry:r,tags:n,minX:1/0,minY:1/0,maxX:-1/0,maxY:-1/0};return function(t){var e=t.geometry,r=t.type;if(\"Point\"===r||\"MultiPoint\"===r||\"LineString\"===r)it(t,e);else if(\"Polygon\"===r||\"MultiLineString\"===r)for(var n=0;n<e.length;n++)it(t,e[n]);else if(\"MultiPolygon\"===r)for(n=0;n<e.length;n++)for(var i=0;i<e[n].length;i++)it(t,e[n][i])}(i),i}function it(t,e){for(var r=0;r<e.length;r+=3)t.minX=Math.min(t.minX,e[r]),t.minY=Math.min(t.minY,e[r+1]),t.maxX=Math.max(t.maxX,e[r]),t.maxY=Math.max(t.maxY,e[r+1])}function at(t,e,r,n){if(e.geometry){var i=e.geometry.coordinates,a=e.geometry.type,o=Math.pow(r.tolerance/((1<<r.maxZoom)*r.extent),2),s=[],l=e.id;if(r.promoteId?l=e.properties[r.promoteId]:r.generateId&&(l=n||0),\"Point\"===a)ot(i,s);else if(\"MultiPoint\"===a)for(var c=0;c<i.length;c++)ot(i[c],s);else if(\"LineString\"===a)st(i,s,o,!1);else if(\"MultiLineString\"===a){if(r.lineMetrics){for(c=0;c<i.length;c++)s=[],st(i[c],s,o,!1),t.push(nt(l,\"LineString\",s,e.properties));return}lt(i,s,o,!1)}else if(\"Polygon\"===a)lt(i,s,o,!0);else{if(\"MultiPolygon\"!==a){if(\"GeometryCollection\"===a){for(c=0;c<e.geometry.geometries.length;c++)at(t,{id:l,geometry:e.geometry.geometries[c],properties:e.properties},r,n);return}throw new Error(\"Input data is not a valid GeoJSON object.\")}for(c=0;c<i.length;c++){var u=[];lt(i[c],u,o,!0),s.push(u)}}t.push(nt(l,a,s,e.properties))}}function ot(t,e){e.push(ct(t[0])),e.push(ut(t[1])),e.push(0)}function st(t,e,r,n){for(var i,a,o=0,s=0;s<t.length;s++){var l=ct(t[s][0]),c=ut(t[s][1]);e.push(l),e.push(c),e.push(0),s>0&&(o+=n?(i*c-l*a)/2:Math.sqrt(Math.pow(l-i,2)+Math.pow(c-a,2))),i=l,a=c}var u=e.length-3;e[2]=1,function t(e,r,n,i){for(var a,o=i,s=n-r>>1,l=n-r,c=e[r],u=e[r+1],h=e[n],f=e[n+1],p=r+3;p<n;p+=3){var d=rt(e[p],e[p+1],c,u,h,f);if(d>o)a=p,o=d;else if(d===o){var g=Math.abs(p-s);g<l&&(a=p,l=g)}}o>i&&(a-r>3&&t(e,r,a,i),e[a+2]=o,n-a>3&&t(e,a,n,i))}(e,0,u,r),e[u+2]=1,e.size=Math.abs(o),e.start=0,e.end=e.size}function lt(t,e,r,n){for(var i=0;i<t.length;i++){var a=[];st(t[i],a,r,n),e.push(a)}}function ct(t){return t/360+.5}function ut(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function ht(t,e,r,n,i,a,o,s){if(n/=e,a>=(r/=e)&&o<n)return t;if(o<r||a>=n)return null;for(var l=[],c=0;c<t.length;c++){var u=t[c],h=u.geometry,f=u.type,p=0===i?u.minX:u.minY,d=0===i?u.maxX:u.maxY;if(p>=r&&d<n)l.push(u);else if(!(d<r||p>=n)){var g=[];if(\"Point\"===f||\"MultiPoint\"===f)ft(h,g,r,n,i);else if(\"LineString\"===f)pt(h,g,r,n,i,!1,s.lineMetrics);else if(\"MultiLineString\"===f)gt(h,g,r,n,i,!1);else if(\"Polygon\"===f)gt(h,g,r,n,i,!0);else if(\"MultiPolygon\"===f)for(var v=0;v<h.length;v++){var m=[];gt(h[v],m,r,n,i,!0),m.length&&g.push(m)}if(g.length){if(s.lineMetrics&&\"LineString\"===f){for(v=0;v<g.length;v++)l.push(nt(u.id,f,g[v],u.tags));continue}\"LineString\"!==f&&\"MultiLineString\"!==f||(1===g.length?(f=\"LineString\",g=g[0]):f=\"MultiLineString\"),\"Point\"!==f&&\"MultiPoint\"!==f||(f=3===g.length?\"Point\":\"MultiPoint\"),l.push(nt(u.id,f,g,u.tags))}}}return l.length?l:null}function ft(t,e,r,n,i){for(var a=0;a<t.length;a+=3){var o=t[a+i];o>=r&&o<=n&&(e.push(t[a]),e.push(t[a+1]),e.push(t[a+2]))}}function pt(t,e,r,n,i,a,o){for(var s,l,c=dt(t),u=0===i?mt:yt,h=t.start,f=0;f<t.length-3;f+=3){var p=t[f],d=t[f+1],g=t[f+2],v=t[f+3],m=t[f+4],y=0===i?p:d,x=0===i?v:m,b=!1;o&&(s=Math.sqrt(Math.pow(p-v,2)+Math.pow(d-m,2))),y<r?x>r&&(l=u(c,p,d,v,m,r),o&&(c.start=h+s*l)):y>n?x<n&&(l=u(c,p,d,v,m,n),o&&(c.start=h+s*l)):vt(c,p,d,g),x<r&&y>=r&&(l=u(c,p,d,v,m,r),b=!0),x>n&&y<=n&&(l=u(c,p,d,v,m,n),b=!0),!a&&b&&(o&&(c.end=h+s*l),e.push(c),c=dt(t)),o&&(h+=s)}var _=t.length-3;p=t[_],d=t[_+1],g=t[_+2],(y=0===i?p:d)>=r&&y<=n&&vt(c,p,d,g),_=c.length-3,a&&_>=3&&(c[_]!==c[0]||c[_+1]!==c[1])&&vt(c,c[0],c[1],c[2]),c.length&&e.push(c)}function dt(t){var e=[];return e.size=t.size,e.start=t.start,e.end=t.end,e}function gt(t,e,r,n,i,a){for(var o=0;o<t.length;o++)pt(t[o],e,r,n,i,a,!1)}function vt(t,e,r,n){t.push(e),t.push(r),t.push(n)}function mt(t,e,r,n,i,a){var o=(a-e)/(n-e);return t.push(a),t.push(r+(i-r)*o),t.push(1),o}function yt(t,e,r,n,i,a){var o=(a-r)/(i-r);return t.push(e+(n-e)*o),t.push(a),t.push(1),o}function xt(t,e){for(var r=[],n=0;n<t.length;n++){var i,a=t[n],o=a.type;if(\"Point\"===o||\"MultiPoint\"===o||\"LineString\"===o)i=bt(a.geometry,e);else if(\"MultiLineString\"===o||\"Polygon\"===o){i=[];for(var s=0;s<a.geometry.length;s++)i.push(bt(a.geometry[s],e))}else if(\"MultiPolygon\"===o)for(i=[],s=0;s<a.geometry.length;s++){for(var l=[],c=0;c<a.geometry[s].length;c++)l.push(bt(a.geometry[s][c],e));i.push(l)}r.push(nt(a.id,o,i,a.tags))}return r}function bt(t,e){var r=[];r.size=t.size,void 0!==t.start&&(r.start=t.start,r.end=t.end);for(var n=0;n<t.length;n+=3)r.push(t[n]+e,t[n+1],t[n+2]);return r}function _t(t,e){if(t.transformed)return t;var r,n,i,a=1<<t.z,o=t.x,s=t.y;for(r=0;r<t.features.length;r++){var l=t.features[r],c=l.geometry,u=l.type;if(l.geometry=[],1===u)for(n=0;n<c.length;n+=2)l.geometry.push(wt(c[n],c[n+1],e,a,o,s));else for(n=0;n<c.length;n++){var h=[];for(i=0;i<c[n].length;i+=2)h.push(wt(c[n][i],c[n][i+1],e,a,o,s));l.geometry.push(h)}}return t.transformed=!0,t}function wt(t,e,r,n,i,a){return[Math.round(r*(t*n-i)),Math.round(r*(e*n-a))]}function kt(t,e,r,n,i){for(var a=e===i.maxZoom?0:i.tolerance/((1<<e)*i.extent),o={features:[],numPoints:0,numSimplified:0,numFeatures:0,source:null,x:r,y:n,z:e,transformed:!1,minX:2,minY:1,maxX:-1,maxY:0},s=0;s<t.length;s++){o.numFeatures++,Tt(o,t[s],a,i);var l=t[s].minX,c=t[s].minY,u=t[s].maxX,h=t[s].maxY;l<o.minX&&(o.minX=l),c<o.minY&&(o.minY=c),u>o.maxX&&(o.maxX=u),h>o.maxY&&(o.maxY=h)}return o}function Tt(t,e,r,n){var i=e.geometry,a=e.type,o=[];if(\"Point\"===a||\"MultiPoint\"===a)for(var s=0;s<i.length;s+=3)o.push(i[s]),o.push(i[s+1]),t.numPoints++,t.numSimplified++;else if(\"LineString\"===a)At(o,i,t,r,!1,!1);else if(\"MultiLineString\"===a||\"Polygon\"===a)for(s=0;s<i.length;s++)At(o,i[s],t,r,\"Polygon\"===a,0===s);else if(\"MultiPolygon\"===a)for(var l=0;l<i.length;l++){var c=i[l];for(s=0;s<c.length;s++)At(o,c[s],t,r,!0,0===s)}if(o.length){var u=e.tags||null;if(\"LineString\"===a&&n.lineMetrics){for(var h in u={},e.tags)u[h]=e.tags[h];u.mapbox_clip_start=i.start/i.size,u.mapbox_clip_end=i.end/i.size}var f={geometry:o,type:\"Polygon\"===a||\"MultiPolygon\"===a?3:\"LineString\"===a||\"MultiLineString\"===a?2:1,tags:u};null!==e.id&&(f.id=e.id),t.features.push(f)}}function At(t,e,r,n,i,a){var o=n*n;if(n>0&&e.size<(i?o:n))r.numPoints+=e.length/3;else{for(var s=[],l=0;l<e.length;l+=3)(0===n||e[l+2]>o)&&(r.numSimplified++,s.push(e[l]),s.push(e[l+1])),r.numPoints++;i&&function(t,e){for(var r=0,n=0,i=t.length,a=i-2;n<i;a=n,n+=2)r+=(t[n]-t[a])*(t[n+1]+t[a+1]);if(r>0===e)for(n=0,i=t.length;n<i/2;n+=2){var o=t[n],s=t[n+1];t[n]=t[i-2-n],t[n+1]=t[i-1-n],t[i-2-n]=o,t[i-1-n]=s}}(s,a),t.push(s)}}function Mt(t,e){var r=(e=this.options=function(t,e){for(var r in e)t[r]=e[r];return t}(Object.create(this.options),e)).debug;if(r&&console.time(\"preprocess data\"),e.maxZoom<0||e.maxZoom>24)throw new Error(\"maxZoom should be in the 0-24 range\");if(e.promoteId&&e.generateId)throw new Error(\"promoteId and generateId cannot be used together.\");var n=function(t,e){var r=[];if(\"FeatureCollection\"===t.type)for(var n=0;n<t.features.length;n++)at(r,t.features[n],e,n);else\"Feature\"===t.type?at(r,t,e):at(r,{geometry:t},e);return r}(t,e);this.tiles={},this.tileCoords=[],r&&(console.timeEnd(\"preprocess data\"),console.log(\"index: maxZoom: %d, maxPoints: %d\",e.indexMaxZoom,e.indexMaxPoints),console.time(\"generate tiles\"),this.stats={},this.total=0),(n=function(t,e){var r=e.buffer/e.extent,n=t,i=ht(t,1,-1-r,r,0,-1,2,e),a=ht(t,1,1-r,2+r,0,-1,2,e);return(i||a)&&(n=ht(t,1,-r,1+r,0,-1,2,e)||[],i&&(n=xt(i,1).concat(n)),a&&(n=n.concat(xt(a,-1)))),n}(n,e)).length&&this.splitTile(n,0,0,0),r&&(n.length&&console.log(\"features: %d, points: %d\",this.tiles[0].numFeatures,this.tiles[0].numPoints),console.timeEnd(\"generate tiles\"),console.log(\"tiles generated:\",this.total,JSON.stringify(this.stats)))}function St(t,e,r){return 32*((1<<t)*r+e)+t}function Et(t,e){var r=t.tileID.canonical;if(!this._geoJSONIndex)return e(null,null);var n=this._geoJSONIndex.getTile(r.z,r.x,r.y);if(!n)return e(null,null);var i=new k(n.features),a=E(i);0===a.byteOffset&&a.byteLength===a.buffer.byteLength||(a=new Uint8Array(a)),e(null,{vectorTile:i,rawData:a.buffer})}Y.prototype.load=function(t){var e=this.options,r=e.log,n=e.minZoom,i=e.maxZoom,a=e.nodeSize;r&&console.time(\"total time\");var o=\"prepare \"+t.length+\" points\";r&&console.time(o),this.points=t;for(var s=[],l=0;l<t.length;l++)t[l].geometry&&s.push(X(t[l],l));this.trees[i+1]=new H(s,tt,et,a,Float32Array),r&&console.timeEnd(o);for(var c=i;c>=n;c--){var u=+Date.now();s=this._cluster(s,c),this.trees[c]=new H(s,tt,et,a,Float32Array),r&&console.log(\"z%d: %d clusters in %dms\",c,s.length,+Date.now()-u)}return r&&console.timeEnd(\"total time\"),this},Y.prototype.getClusters=function(t,e){var r=((t[0]+180)%360+360)%360-180,n=Math.max(-90,Math.min(90,t[1])),i=180===t[2]?180:((t[2]+180)%360+360)%360-180,a=Math.max(-90,Math.min(90,t[3]));if(t[2]-t[0]>=360)r=-180,i=180;else if(r>i){var o=this.getClusters([r,n,180,a],e),s=this.getClusters([-180,n,i,a],e);return o.concat(s)}for(var l=this.trees[this._limitZoom(e)],c=[],u=0,h=l.range(K(r),$(a),K(i),$(n));u<h.length;u+=1){var f=h[u],p=l.points[f];c.push(p.numPoints?Z(p):this.points[p.index])}return c},Y.prototype.getChildren=function(t){var e=t>>5,r=t%32,n=\"No cluster with the specified id.\",i=this.trees[r];if(!i)throw new Error(n);var a=i.points[e];if(!a)throw new Error(n);for(var o=this.options.radius/(this.options.extent*Math.pow(2,r-1)),s=[],l=0,c=i.within(a.x,a.y,o);l<c.length;l+=1){var u=c[l],h=i.points[u];h.parentId===t&&s.push(h.numPoints?Z(h):this.points[h.index])}if(0===s.length)throw new Error(n);return s},Y.prototype.getLeaves=function(t,e,r){e=e||10,r=r||0;var n=[];return this._appendLeaves(n,t,e,r,0),n},Y.prototype.getTile=function(t,e,r){var n=this.trees[this._limitZoom(t)],i=Math.pow(2,t),a=this.options,o=a.extent,s=a.radius/o,l=(r-s)/i,c=(r+1+s)/i,u={features:[]};return this._addTileFeatures(n.range((e-s)/i,l,(e+1+s)/i,c),n.points,e,r,i,u),0===e&&this._addTileFeatures(n.range(1-s/i,l,1,c),n.points,i,r,i,u),e===i-1&&this._addTileFeatures(n.range(0,l,s/i,c),n.points,-1,r,i,u),u.features.length?u:null},Y.prototype.getClusterExpansionZoom=function(t){for(var e=t%32-1;e<=this.options.maxZoom;){var r=this.getChildren(t);if(e++,1!==r.length)break;t=r[0].properties.cluster_id}return e},Y.prototype._appendLeaves=function(t,e,r,n,i){for(var a=0,o=this.getChildren(e);a<o.length;a+=1){var s=o[a],l=s.properties;if(l&&l.cluster?i+l.point_count<=n?i+=l.point_count:i=this._appendLeaves(t,l.cluster_id,r,n,i):i<n?i++:t.push(s),t.length===r)break}return i},Y.prototype._addTileFeatures=function(t,e,r,n,i,a){for(var o=0,s=t;o<s.length;o+=1){var l=e[s[o]],c={type:1,geometry:[[Math.round(this.options.extent*(l.x*i-r)),Math.round(this.options.extent*(l.y*i-n))]],tags:l.numPoints?J(l):this.points[l.index].properties},u=l.numPoints?l.id:this.points[l.index].id;void 0!==u&&(c.id=u),a.features.push(c)}},Y.prototype._limitZoom=function(t){return Math.max(this.options.minZoom,Math.min(t,this.options.maxZoom+1))},Y.prototype._cluster=function(t,e){for(var r=[],n=this.options,i=n.radius,a=n.extent,o=n.reduce,s=i/(a*Math.pow(2,e)),l=0;l<t.length;l++){var c=t[l];if(!(c.zoom<=e)){c.zoom=e;for(var u=this.trees[e+1],h=u.within(c.x,c.y,s),f=c.numPoints||1,p=c.x*f,d=c.y*f,g=o?this._map(c,!0):null,v=(l<<5)+(e+1),m=0,y=h;m<y.length;m+=1){var x=y[m],b=u.points[x];if(!(b.zoom<=e)){b.zoom=e;var _=b.numPoints||1;p+=b.x*_,d+=b.y*_,f+=_,b.parentId=v,o&&o(g,this._map(b))}}1===f?r.push(c):(c.parentId=v,r.push(W(p/f,d/f,v,f,g)))}}return r},Y.prototype._map=function(t,e){if(t.numPoints)return e?Q({},t.properties):t.properties;var r=this.points[t.index].properties,n=this.options.map(r);return e&&n===r?Q({},n):n},Mt.prototype.options={maxZoom:14,indexMaxZoom:5,indexMaxPoints:1e5,tolerance:3,extent:4096,buffer:64,lineMetrics:!1,promoteId:null,generateId:!1,debug:0},Mt.prototype.splitTile=function(t,e,r,n,i,a,o){for(var s=[t,e,r,n],l=this.options,c=l.debug;s.length;){n=s.pop(),r=s.pop(),e=s.pop(),t=s.pop();var u=1<<e,h=St(e,r,n),f=this.tiles[h];if(!f&&(c>1&&console.time(\"creation\"),f=this.tiles[h]=kt(t,e,r,n,l),this.tileCoords.push({z:e,x:r,y:n}),c)){c>1&&(console.log(\"tile z%d-%d-%d (features: %d, points: %d, simplified: %d)\",e,r,n,f.numFeatures,f.numPoints,f.numSimplified),console.timeEnd(\"creation\"));var p=\"z\"+e;this.stats[p]=(this.stats[p]||0)+1,this.total++}if(f.source=t,i){if(e===l.maxZoom||e===i)continue;var d=1<<i-e;if(r!==Math.floor(a/d)||n!==Math.floor(o/d))continue}else if(e===l.indexMaxZoom||f.numPoints<=l.indexMaxPoints)continue;if(f.source=null,0!==t.length){c>1&&console.time(\"clipping\");var g,v,m,y,x,b,_=.5*l.buffer/l.extent,w=.5-_,k=.5+_,T=1+_;g=v=m=y=null,x=ht(t,u,r-_,r+k,0,f.minX,f.maxX,l),b=ht(t,u,r+w,r+T,0,f.minX,f.maxX,l),t=null,x&&(g=ht(x,u,n-_,n+k,1,f.minY,f.maxY,l),v=ht(x,u,n+w,n+T,1,f.minY,f.maxY,l),x=null),b&&(m=ht(b,u,n-_,n+k,1,f.minY,f.maxY,l),y=ht(b,u,n+w,n+T,1,f.minY,f.maxY,l),b=null),c>1&&console.timeEnd(\"clipping\"),s.push(g||[],e+1,2*r,2*n),s.push(v||[],e+1,2*r,2*n+1),s.push(m||[],e+1,2*r+1,2*n),s.push(y||[],e+1,2*r+1,2*n+1)}}},Mt.prototype.getTile=function(t,e,r){var n=this.options,i=n.extent,a=n.debug;if(t<0||t>24)return null;var o=1<<t,s=St(t,e=(e%o+o)%o,r);if(this.tiles[s])return _t(this.tiles[s],i);a>1&&console.log(\"drilling down to z%d-%d-%d\",t,e,r);for(var l,c=t,u=e,h=r;!l&&c>0;)c--,u=Math.floor(u/2),h=Math.floor(h/2),l=this.tiles[St(c,u,h)];return l&&l.source?(a>1&&console.log(\"found parent tile z%d-%d-%d\",c,u,h),a>1&&console.time(\"drilling down\"),this.splitTile(l.source,c,u,h,t,e,r),a>1&&console.timeEnd(\"drilling down\"),this.tiles[s]?_t(this.tiles[s],i):null):null};var Ct=function(e){function r(t,r,n){e.call(this,t,r,Et),n&&(this.loadGeoJSON=n)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadData=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),this._pendingCallback=e,this._pendingLoadDataParams=t,this._state&&\"Idle\"!==this._state?this._state=\"NeedsLoadData\":(this._state=\"Coalescing\",this._loadData())},r.prototype._loadData=function(){var e=this;if(this._pendingCallback&&this._pendingLoadDataParams){var r=this._pendingCallback,n=this._pendingLoadDataParams;delete this._pendingCallback,delete this._pendingLoadDataParams;var i=!!(n&&n.request&&n.request.collectResourceTiming)&&new l.Performance(n.request);this.loadGeoJSON(n,function(a,o){if(a||!o)return r(a);if(\"object\"!=typeof o)return r(new Error(\"Input data given to '\"+n.source+\"' is not a valid GeoJSON object.\"));!function t(e,r){switch(e&&e.type||null){case\"FeatureCollection\":return e.features=e.features.map(y(t,r)),e;case\"GeometryCollection\":return e.geometries=e.geometries.map(y(t,r)),e;case\"Feature\":return e.geometry=t(e.geometry,r),e;case\"Polygon\":case\"MultiPolygon\":return function(t,e){return\"Polygon\"===t.type?t.coordinates=x(t.coordinates,e):\"MultiPolygon\"===t.type&&(t.coordinates=t.coordinates.map(y(x,e))),t}(e,r);default:return e}}(o,!0);try{e._geoJSONIndex=n.cluster?new Y(function(e){var r=e.superclusterOptions,n=e.clusterProperties;if(!n||!r)return r;for(var i={},a={},o={accumulated:null,zoom:0},s={properties:null},l=Object.keys(n),c=0,u=l;c<u.length;c+=1){var h=u[c],f=n[h],p=f[0],d=f[1],g=t.createExpression(d),v=t.createExpression(\"string\"==typeof p?[p,[\"accumulated\"],[\"get\",h]]:p);i[h]=g.value,a[h]=v.value}return r.map=function(t){s.properties=t;for(var e={},r=0,n=l;r<n.length;r+=1){var a=n[r];e[a]=i[a].evaluate(o,s)}return e},r.reduce=function(t,e){s.properties=e;for(var r=0,n=l;r<n.length;r+=1){var i=n[r];o.accumulated=t[i],t[i]=a[i].evaluate(o,s)}},r}(n)).load(o.features):new Mt(o,n.geojsonVtOptions)}catch(a){return r(a)}e.loaded={};var s={};if(i){var l=i.finish();l&&(s.resourceTiming={},s.resourceTiming[n.source]=JSON.parse(JSON.stringify(l)))}r(null,s)})}},r.prototype.coalesce=function(){\"Coalescing\"===this._state?this._state=\"Idle\":\"NeedsLoadData\"===this._state&&(this._state=\"Coalescing\",this._loadData())},r.prototype.reloadTile=function(t,r){var n=this.loaded,i=t.uid;return n&&n[i]?e.prototype.reloadTile.call(this,t,r):this.loadTile(t,r)},r.prototype.loadGeoJSON=function(e,r){if(e.request)t.getJSON(e.request,r);else{if(\"string\"!=typeof e.data)return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"));try{return r(null,JSON.parse(e.data))}catch(t){return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"))}}},r.prototype.removeSource=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),e()},r.prototype.getClusterExpansionZoom=function(t,e){e(null,this._geoJSONIndex.getClusterExpansionZoom(t.clusterId))},r.prototype.getClusterChildren=function(t,e){e(null,this._geoJSONIndex.getChildren(t.clusterId))},r.prototype.getClusterLeaves=function(t,e){e(null,this._geoJSONIndex.getLeaves(t.clusterId,t.limit,t.offset))},r}(h),Lt=function(e){var r=this;this.self=e,this.actor=new t.Actor(e,this),this.layerIndexes={},this.workerSourceTypes={vector:h,geojson:Ct},this.workerSources={},this.demWorkerSources={},this.self.registerWorkerSource=function(t,e){if(r.workerSourceTypes[t])throw new Error('Worker source with name \"'+t+'\" already registered.');r.workerSourceTypes[t]=e},this.self.registerRTLTextPlugin=function(e){if(t.plugin.isLoaded())throw new Error(\"RTL text plugin already registered.\");t.plugin.applyArabicShaping=e.applyArabicShaping,t.plugin.processBidirectionalText=e.processBidirectionalText,t.plugin.processStyledBidirectionalText=e.processStyledBidirectionalText}};return Lt.prototype.setReferrer=function(t,e){this.referrer=e},Lt.prototype.setLayers=function(t,e,r){this.getLayerIndex(t).replace(e),r()},Lt.prototype.updateLayers=function(t,e,r){this.getLayerIndex(t).update(e.layers,e.removedIds),r()},Lt.prototype.loadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).loadTile(e,r)},Lt.prototype.loadDEMTile=function(t,e,r){this.getDEMWorkerSource(t,e.source).loadTile(e,r)},Lt.prototype.reloadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).reloadTile(e,r)},Lt.prototype.abortTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).abortTile(e,r)},Lt.prototype.removeTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).removeTile(e,r)},Lt.prototype.removeDEMTile=function(t,e){this.getDEMWorkerSource(t,e.source).removeTile(e)},Lt.prototype.removeSource=function(t,e,r){if(this.workerSources[t]&&this.workerSources[t][e.type]&&this.workerSources[t][e.type][e.source]){var n=this.workerSources[t][e.type][e.source];delete this.workerSources[t][e.type][e.source],void 0!==n.removeSource?n.removeSource(e,r):r()}},Lt.prototype.loadWorkerSource=function(t,e,r){try{this.self.importScripts(e.url),r()}catch(t){r(t.toString())}},Lt.prototype.loadRTLTextPlugin=function(e,r,n){try{t.plugin.isLoaded()||(this.self.importScripts(r),n(t.plugin.isLoaded()?null:new Error(\"RTL Text Plugin failed to import scripts from \"+r)))}catch(t){n(t.toString())}},Lt.prototype.getLayerIndex=function(t){var e=this.layerIndexes[t];return e||(e=this.layerIndexes[t]=new n),e},Lt.prototype.getWorkerSource=function(t,e,r){var n=this;if(this.workerSources[t]||(this.workerSources[t]={}),this.workerSources[t][e]||(this.workerSources[t][e]={}),!this.workerSources[t][e][r]){var i={send:function(e,r,i){n.actor.send(e,r,i,t)}};this.workerSources[t][e][r]=new this.workerSourceTypes[e](i,this.getLayerIndex(t))}return this.workerSources[t][e][r]},Lt.prototype.getDEMWorkerSource=function(t,e){return this.demWorkerSources[t]||(this.demWorkerSources[t]={}),this.demWorkerSources[t][e]||(this.demWorkerSources[t][e]=new f),this.demWorkerSources[t][e]},Lt.prototype.enforceCacheSizeLimit=function(e,r){t.enforceCacheSizeLimit(r)},\"undefined\"!=typeof WorkerGlobalScope&&void 0!==t.window&&t.window instanceof WorkerGlobalScope&&(t.window.worker=new Lt(t.window)),Lt}),n(0,function(t){var e=t.createCommonjsModule(function(t){function e(t){return!!(\"undefined\"!=typeof window&&\"undefined\"!=typeof document&&Array.prototype&&Array.prototype.every&&Array.prototype.filter&&Array.prototype.forEach&&Array.prototype.indexOf&&Array.prototype.lastIndexOf&&Array.prototype.map&&Array.prototype.some&&Array.prototype.reduce&&Array.prototype.reduceRight&&Array.isArray&&Function.prototype&&Function.prototype.bind&&Object.keys&&Object.create&&Object.getPrototypeOf&&Object.getOwnPropertyNames&&Object.isSealed&&Object.isFrozen&&Object.isExtensible&&Object.getOwnPropertyDescriptor&&Object.defineProperty&&Object.defineProperties&&Object.seal&&Object.freeze&&Object.preventExtensions&&\"JSON\"in window&&\"parse\"in JSON&&\"stringify\"in JSON&&function(){if(!(\"Worker\"in window&&\"Blob\"in window&&\"URL\"in window))return!1;var t,e,r=new Blob([\"\"],{type:\"text/javascript\"}),n=URL.createObjectURL(r);try{e=new Worker(n),t=!0}catch(e){t=!1}return e&&e.terminate(),URL.revokeObjectURL(n),t}()&&\"Uint8ClampedArray\"in window&&ArrayBuffer.isView&&function(t){return void 0===r[t]&&(r[t]=function(t){var r=document.createElement(\"canvas\"),n=Object.create(e.webGLContextAttributes);return n.failIfMajorPerformanceCaveat=t,r.probablySupportsContext?r.probablySupportsContext(\"webgl\",n)||r.probablySupportsContext(\"experimental-webgl\",n):r.supportsContext?r.supportsContext(\"webgl\",n)||r.supportsContext(\"experimental-webgl\",n):r.getContext(\"webgl\",n)||r.getContext(\"experimental-webgl\",n)}(t)),r[t]}(t&&t.failIfMajorPerformanceCaveat))}t.exports?t.exports=e:window&&(window.mapboxgl=window.mapboxgl||{},window.mapboxgl.supported=e);var r={};e.webGLContextAttributes={antialias:!1,alpha:!0,stencil:!0,depth:!0}}),r={create:function(e,r,n){var i=t.window.document.createElement(e);return void 0!==r&&(i.className=r),n&&n.appendChild(i),i},createNS:function(e,r){return t.window.document.createElementNS(e,r)}},n=t.window.document.documentElement.style;function i(t){if(!n)return t[0];for(var e=0;e<t.length;e++)if(t[e]in n)return t[e];return t[0]}var a,o=i([\"userSelect\",\"MozUserSelect\",\"WebkitUserSelect\",\"msUserSelect\"]);r.disableDrag=function(){n&&o&&(a=n[o],n[o]=\"none\")},r.enableDrag=function(){n&&o&&(n[o]=a)};var s=i([\"transform\",\"WebkitTransform\"]);r.setTransform=function(t,e){t.style[s]=e};var l=!1;try{var c=Object.defineProperty({},\"passive\",{get:function(){l=!0}});t.window.addEventListener(\"test\",c,c),t.window.removeEventListener(\"test\",c,c)}catch(t){l=!1}r.addEventListener=function(t,e,r,n){void 0===n&&(n={}),\"passive\"in n&&l?t.addEventListener(e,r,n):t.addEventListener(e,r,n.capture)},r.removeEventListener=function(t,e,r,n){void 0===n&&(n={}),\"passive\"in n&&l?t.removeEventListener(e,r,n):t.removeEventListener(e,r,n.capture)};var u=function(e){e.preventDefault(),e.stopPropagation(),t.window.removeEventListener(\"click\",u,!0)};function h(t){var e=t.userImage;return!!(e&&e.render&&e.render())&&(t.data.replace(new Uint8Array(e.data.buffer)),!0)}r.suppressClick=function(){t.window.addEventListener(\"click\",u,!0),t.window.setTimeout(function(){t.window.removeEventListener(\"click\",u,!0)},0)},r.mousePos=function(e,r){var n=e.getBoundingClientRect(),i=t.window.TouchEvent&&r instanceof t.window.TouchEvent?r.touches[0]:r;return new t.Point(i.clientX-n.left-e.clientLeft,i.clientY-n.top-e.clientTop)},r.touchPos=function(e,r){for(var n=e.getBoundingClientRect(),i=[],a=\"touchend\"===r.type?r.changedTouches:r.touches,o=0;o<a.length;o++)i.push(new t.Point(a[o].clientX-n.left-e.clientLeft,a[o].clientY-n.top-e.clientTop));return i},r.mouseButton=function(e){return void 0!==t.window.InstallTrigger&&2===e.button&&e.ctrlKey&&t.window.navigator.platform.toUpperCase().indexOf(\"MAC\")>=0?0:e.button},r.remove=function(t){t.parentNode&&t.parentNode.removeChild(t)};var f=function(e){function r(){e.call(this),this.images={},this.updatedImages={},this.callbackDispatchedThisFrame={},this.loaded=!1,this.requestors=[],this.patterns={},this.atlasImage=new t.RGBAImage({width:1,height:1}),this.dirty=!0}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.isLoaded=function(){return this.loaded},r.prototype.setLoaded=function(t){if(this.loaded!==t&&(this.loaded=t,t)){for(var e=0,r=this.requestors;e<r.length;e+=1){var n=r[e],i=n.ids,a=n.callback;this._notify(i,a)}this.requestors=[]}},r.prototype.getImage=function(t){return this.images[t]},r.prototype.addImage=function(t,e){this.images[t]=e},r.prototype.updateImage=function(t,e){var r=this.images[t];e.version=r.version+1,this.images[t]=e,this.updatedImages[t]=!0},r.prototype.removeImage=function(t){var e=this.images[t];delete this.images[t],delete this.patterns[t],e.userImage&&e.userImage.onRemove&&e.userImage.onRemove()},r.prototype.listImages=function(){return Object.keys(this.images)},r.prototype.getImages=function(t,e){var r=!0;if(!this.isLoaded())for(var n=0,i=t;n<i.length;n+=1){var a=i[n];this.images[a]||(r=!1)}this.isLoaded()||r?this._notify(t,e):this.requestors.push({ids:t,callback:e})},r.prototype._notify=function(e,r){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i];this.images[o]||this.fire(new t.Event(\"styleimagemissing\",{id:o}));var s=this.images[o];s?n[o]={data:s.data.clone(),pixelRatio:s.pixelRatio,sdf:s.sdf,version:s.version,hasRenderCallback:Boolean(s.userImage&&s.userImage.render)}:t.warnOnce('Image \"'+o+'\" could not be loaded. Please make sure you have added the image with map.addImage() or a \"sprite\" property in your style. You can provide missing images by listening for the \"styleimagemissing\" map event.')}r(null,n)},r.prototype.getPixelSize=function(){var t=this.atlasImage;return{width:t.width,height:t.height}},r.prototype.getPattern=function(e){var r=this.patterns[e],n=this.getImage(e);if(!n)return null;if(r&&r.position.version===n.version)return r.position;if(r)r.position.version=n.version;else{var i={w:n.data.width+2,h:n.data.height+2,x:0,y:0},a=new t.ImagePosition(i,n);this.patterns[e]={bin:i,position:a}}return this._updatePatternAtlas(),this.patterns[e].position},r.prototype.bind=function(e){var r=e.gl;this.atlasTexture?this.dirty&&(this.atlasTexture.update(this.atlasImage),this.dirty=!1):this.atlasTexture=new t.Texture(e,this.atlasImage,r.RGBA),this.atlasTexture.bind(r.LINEAR,r.CLAMP_TO_EDGE)},r.prototype._updatePatternAtlas=function(){var e=[];for(var r in this.patterns)e.push(this.patterns[r].bin);var n=t.potpack(e),i=n.w,a=n.h,o=this.atlasImage;for(var s in o.resize({width:i||1,height:a||1}),this.patterns){var l=this.patterns[s].bin,c=l.x+1,u=l.y+1,h=this.images[s].data,f=h.width,p=h.height;t.RGBAImage.copy(h,o,{x:0,y:0},{x:c,y:u},{width:f,height:p}),t.RGBAImage.copy(h,o,{x:0,y:p-1},{x:c,y:u-1},{width:f,height:1}),t.RGBAImage.copy(h,o,{x:0,y:0},{x:c,y:u+p},{width:f,height:1}),t.RGBAImage.copy(h,o,{x:f-1,y:0},{x:c-1,y:u},{width:1,height:p}),t.RGBAImage.copy(h,o,{x:0,y:0},{x:c+f,y:u},{width:1,height:p})}this.dirty=!0},r.prototype.beginFrame=function(){this.callbackDispatchedThisFrame={}},r.prototype.dispatchRenderCallbacks=function(t){for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!this.callbackDispatchedThisFrame[n]){this.callbackDispatchedThisFrame[n]=!0;var i=this.images[n];h(i)&&this.updateImage(n,i)}}},r}(t.Evented),p=g,d=1e20;function g(t,e,r,n,i,a){this.fontSize=t||24,this.buffer=void 0===e?3:e,this.cutoff=n||.25,this.fontFamily=i||\"sans-serif\",this.fontWeight=a||\"normal\",this.radius=r||8;var o=this.size=this.fontSize+2*this.buffer;this.canvas=document.createElement(\"canvas\"),this.canvas.width=this.canvas.height=o,this.ctx=this.canvas.getContext(\"2d\"),this.ctx.font=this.fontWeight+\" \"+this.fontSize+\"px \"+this.fontFamily,this.ctx.textBaseline=\"middle\",this.ctx.fillStyle=\"black\",this.gridOuter=new Float64Array(o*o),this.gridInner=new Float64Array(o*o),this.f=new Float64Array(o),this.d=new Float64Array(o),this.z=new Float64Array(o+1),this.v=new Int16Array(o),this.middle=Math.round(o/2*(navigator.userAgent.indexOf(\"Gecko/\")>=0?1.2:1))}function v(t,e,r,n,i,a,o){for(var s=0;s<e;s++){for(var l=0;l<r;l++)n[l]=t[l*e+s];for(m(n,i,a,o,r),l=0;l<r;l++)t[l*e+s]=i[l]}for(l=0;l<r;l++){for(s=0;s<e;s++)n[s]=t[l*e+s];for(m(n,i,a,o,e),s=0;s<e;s++)t[l*e+s]=Math.sqrt(i[s])}}function m(t,e,r,n,i){r[0]=0,n[0]=-d,n[1]=+d;for(var a=1,o=0;a<i;a++){for(var s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);s<=n[o];)o--,s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);r[++o]=a,n[o]=s,n[o+1]=+d}for(a=0,o=0;a<i;a++){for(;n[o+1]<a;)o++;e[a]=(a-r[o])*(a-r[o])+t[r[o]]}}g.prototype.draw=function(t){this.ctx.clearRect(0,0,this.size,this.size),this.ctx.fillText(t,this.buffer,this.middle);for(var e=this.ctx.getImageData(0,0,this.size,this.size),r=new Uint8ClampedArray(this.size*this.size),n=0;n<this.size*this.size;n++){var i=e.data[4*n+3]/255;this.gridOuter[n]=1===i?0:0===i?d:Math.pow(Math.max(0,.5-i),2),this.gridInner[n]=1===i?d:0===i?0:Math.pow(Math.max(0,i-.5),2)}for(v(this.gridOuter,this.size,this.size,this.f,this.d,this.v,this.z),v(this.gridInner,this.size,this.size,this.f,this.d,this.v,this.z),n=0;n<this.size*this.size;n++){var a=this.gridOuter[n]-this.gridInner[n];r[n]=Math.max(0,Math.min(255,Math.round(255-255*(a/this.radius+this.cutoff))))}return r};var y=function(t,e){this.requestManager=t,this.localIdeographFontFamily=e,this.entries={}};y.prototype.setURL=function(t){this.url=t},y.prototype.getGlyphs=function(e,r){var n=this,i=[];for(var a in e)for(var o=0,s=e[a];o<s.length;o+=1){var l=s[o];i.push({stack:a,id:l})}t.asyncAll(i,function(t,e){var r=t.stack,i=t.id,a=n.entries[r];a||(a=n.entries[r]={glyphs:{},requests:{}});var o=a.glyphs[i];if(void 0===o)if(o=n._tinySDF(a,r,i))e(null,{stack:r,id:i,glyph:o});else{var s=Math.floor(i/256);if(256*s>65535)e(new Error(\"glyphs > 65535 not supported\"));else{var l=a.requests[s];l||(l=a.requests[s]=[],y.loadGlyphRange(r,s,n.url,n.requestManager,function(t,e){if(e)for(var r in e)a.glyphs[+r]=e[+r];for(var n=0,i=l;n<i.length;n+=1)(0,i[n])(t,e);delete a.requests[s]})),l.push(function(t,n){t?e(t):n&&e(null,{stack:r,id:i,glyph:n[i]||null})})}}else e(null,{stack:r,id:i,glyph:o})},function(t,e){if(t)r(t);else if(e){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.stack,l=o.id,c=o.glyph;(n[s]||(n[s]={}))[l]=c&&{id:c.id,bitmap:c.bitmap.clone(),metrics:c.metrics}}r(null,n)}})},y.prototype._tinySDF=function(e,r,n){var i=this.localIdeographFontFamily;if(i&&(t.isChar[\"CJK Unified Ideographs\"](n)||t.isChar[\"Hangul Syllables\"](n)||t.isChar.Hiragana(n)||t.isChar.Katakana(n))){var a=e.tinySDF;if(!a){var o=\"400\";/bold/i.test(r)?o=\"900\":/medium/i.test(r)?o=\"500\":/light/i.test(r)&&(o=\"200\"),a=e.tinySDF=new y.TinySDF(24,3,8,.25,i,o)}return{id:n,bitmap:new t.AlphaImage({width:30,height:30},a.draw(String.fromCharCode(n))),metrics:{width:24,height:24,left:0,top:-8,advance:24}}}},y.loadGlyphRange=function(e,r,n,i,a){var o=256*r,s=o+255,l=i.transformRequest(i.normalizeGlyphsURL(n).replace(\"{fontstack}\",e).replace(\"{range}\",o+\"-\"+s),t.ResourceType.Glyphs);t.getArrayBuffer(l,function(e,r){if(e)a(e);else if(r){for(var n={},i=0,o=t.parseGlyphPBF(r);i<o.length;i+=1){var s=o[i];n[s.id]=s}a(null,n)}})},y.TinySDF=p;var x=function(){this.specification=t.styleSpec.light.position};x.prototype.possiblyEvaluate=function(e,r){return t.sphericalToCartesian(e.expression.evaluate(r))},x.prototype.interpolate=function(e,r,n){return{x:t.number(e.x,r.x,n),y:t.number(e.y,r.y,n),z:t.number(e.z,r.z,n)}};var b=new t.Properties({anchor:new t.DataConstantProperty(t.styleSpec.light.anchor),position:new x,color:new t.DataConstantProperty(t.styleSpec.light.color),intensity:new t.DataConstantProperty(t.styleSpec.light.intensity)}),_=function(e){function r(r){e.call(this),this._transitionable=new t.Transitionable(b),this.setLight(r),this._transitioning=this._transitionable.untransitioned()}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getLight=function(){return this._transitionable.serialize()},r.prototype.setLight=function(e,r){if(void 0===r&&(r={}),!this._validate(t.validateLight,e,r))for(var n in e){var i=e[n];t.endsWith(n,\"-transition\")?this._transitionable.setTransition(n.slice(0,-\"-transition\".length),i):this._transitionable.setValue(n,i)}},r.prototype.updateTransitions=function(t){this._transitioning=this._transitionable.transitioned(t,this._transitioning)},r.prototype.hasTransition=function(){return this._transitioning.hasTransition()},r.prototype.recalculate=function(t){this.properties=this._transitioning.possiblyEvaluate(t)},r.prototype._validate=function(e,r,n){return(!n||!1!==n.validate)&&t.emitValidationErrors(this,e.call(t.validateStyle,t.extend({value:r,style:{glyphs:!0,sprite:!0},styleSpec:t.styleSpec})))},r}(t.Evented),w=function(t,e){this.width=t,this.height=e,this.nextRow=0,this.bytes=4,this.data=new Uint8Array(this.width*this.height*this.bytes),this.positions={}};w.prototype.getDash=function(t,e){var r=t.join(\",\")+String(e);return this.positions[r]||(this.positions[r]=this.addDash(t,e)),this.positions[r]},w.prototype.addDash=function(e,r){var n=r?7:0,i=2*n+1;if(this.nextRow+i>this.height)return t.warnOnce(\"LineAtlas out of space\"),null;for(var a=0,o=0;o<e.length;o++)a+=e[o];for(var s=this.width/a,l=s/2,c=e.length%2==1,u=-n;u<=n;u++)for(var h=this.nextRow+n+u,f=this.width*h,p=c?-e[e.length-1]:0,d=e[0],g=1,v=0;v<this.width;v++){for(;d<v/s;)p=d,d+=e[g],c&&g===e.length-1&&(d+=e[0]),g++;var m=Math.abs(v-p*s),y=Math.abs(v-d*s),x=Math.min(m,y),b=g%2==1,_=void 0;if(r){var w=n?u/n*(l+1):0;if(b){var k=l-Math.abs(w);_=Math.sqrt(x*x+k*k)}else _=l-Math.sqrt(x*x+w*w)}else _=(b?1:-1)*x;this.data[3+4*(f+v)]=Math.max(0,Math.min(255,_+128))}var T={y:(this.nextRow+n+.5)/this.height,height:2*n/this.height,width:a};return this.nextRow+=i,this.dirty=!0,T},w.prototype.bind=function(t){var e=t.gl;this.texture?(e.bindTexture(e.TEXTURE_2D,this.texture),this.dirty&&(this.dirty=!1,e.texSubImage2D(e.TEXTURE_2D,0,0,0,this.width,this.height,e.RGBA,e.UNSIGNED_BYTE,this.data))):(this.texture=e.createTexture(),e.bindTexture(e.TEXTURE_2D,this.texture),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_S,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_T,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,e.LINEAR),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,e.LINEAR),e.texImage2D(e.TEXTURE_2D,0,e.RGBA,this.width,this.height,0,e.RGBA,e.UNSIGNED_BYTE,this.data))};var k=function e(r,n){this.workerPool=r,this.actors=[],this.currentActor=0,this.id=t.uniqueId();for(var i=this.workerPool.acquire(this.id),a=0;a<i.length;a++){var o=i[a],s=new e.Actor(o,n,this.id);s.name=\"Worker \"+a,this.actors.push(s)}};function T(e,r,n){var i=function(i,a){if(i)return n(i);if(a){var o=t.pick(a,[\"tiles\",\"minzoom\",\"maxzoom\",\"attribution\",\"mapbox_logo\",\"bounds\"]);a.vector_layers&&(o.vectorLayers=a.vector_layers,o.vectorLayerIds=o.vectorLayers.map(function(t){return t.id})),e.url&&(o.tiles=r.canonicalizeTileset(o,e.url)),n(null,o)}};return e.url?t.getJSON(r.transformRequest(r.normalizeSourceURL(e.url),t.ResourceType.Source),i):t.browser.frame(function(){return i(null,e)})}k.prototype.broadcast=function(e,r,n){n=n||function(){},t.asyncAll(this.actors,function(t,n){t.send(e,r,n)},n)},k.prototype.send=function(t,e,r,n){return(\"number\"!=typeof n||isNaN(n))&&(n=this.currentActor=(this.currentActor+1)%this.actors.length),this.actors[n].send(t,e,r),n},k.prototype.remove=function(){this.actors.forEach(function(t){t.remove()}),this.actors=[],this.workerPool.release(this.id)},k.Actor=t.Actor;var A=function(e,r,n){this.bounds=t.LngLatBounds.convert(this.validateBounds(e)),this.minzoom=r||0,this.maxzoom=n||24};A.prototype.validateBounds=function(t){return Array.isArray(t)&&4===t.length?[Math.max(-180,t[0]),Math.max(-90,t[1]),Math.min(180,t[2]),Math.min(90,t[3])]:[-180,-90,180,90]},A.prototype.contains=function(e){var r=Math.pow(2,e.z),n=Math.floor(t.mercatorXfromLng(this.bounds.getWest())*r),i=Math.floor(t.mercatorYfromLat(this.bounds.getNorth())*r),a=Math.ceil(t.mercatorXfromLng(this.bounds.getEast())*r),o=Math.ceil(t.mercatorYfromLat(this.bounds.getSouth())*r);return e.x>=n&&e.x<a&&e.y>=i&&e.y<o};var M=function(e){function r(r,n,i,a){if(e.call(this),this.id=r,this.dispatcher=i,this.type=\"vector\",this.minzoom=0,this.maxzoom=22,this.scheme=\"xyz\",this.tileSize=512,this.reparseOverscaled=!0,this.isTileClipped=!0,t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"])),this._options=t.extend({type:\"vector\"},n),this._collectResourceTiming=n.collectResourceTiming,512!==this.tileSize)throw new Error(\"vector tile sources must have a tileSize of 512\");this.setEventedParent(a)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=T(this._options,this.map._requestManager,function(r,n){e._tileJSONRequest=null,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))})},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,null),i={request:this.map._requestManager.transformRequest(n,t.ResourceType.Tile),uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,tileSize:this.tileSize*e.tileID.overscaleFactor(),type:this.type,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes};function a(n,i){return e.aborted?r(null):n&&404!==n.status?r(n):(i&&i.resourceTiming&&(e.resourceTiming=i.resourceTiming),this.map._refreshExpiredTiles&&i&&e.setExpiryData(i),e.loadVectorData(i,this.map.painter),t.cacheEntryPossiblyAdded(this.dispatcher),r(null),void(e.reloadCallback&&(this.loadTile(e,e.reloadCallback),e.reloadCallback=null)))}i.request.collectResourceTiming=this._collectResourceTiming,void 0===e.workerID||\"expired\"===e.state?e.workerID=this.dispatcher.send(\"loadTile\",i,a.bind(this)):\"loading\"===e.state?e.reloadCallback=r:this.dispatcher.send(\"reloadTile\",i,a.bind(this),e.workerID)},r.prototype.abortTile=function(t){this.dispatcher.send(\"abortTile\",{uid:t.uid,type:this.type,source:this.id},void 0,t.workerID)},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.dispatcher.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},void 0,t.workerID)},r.prototype.hasTransition=function(){return!1},r}(t.Evented),S=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.dispatcher=i,this.setEventedParent(a),this.type=\"raster\",this.minzoom=0,this.maxzoom=22,this.roundZoom=!0,this.scheme=\"xyz\",this.tileSize=512,this._loaded=!1,this._options=t.extend({},n),t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"]))}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=T(this._options,this.map._requestManager,function(r,n){e._tileJSONRequest=null,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))})},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.loadTile=function(e,r){var n=this,i=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(i,t.ResourceType.Tile),function(i,a){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(i)e.state=\"errored\",r(i);else if(a){n.map._refreshExpiredTiles&&e.setExpiryData(a),delete a.cacheControl,delete a.expires;var o=n.map.painter.context,s=o.gl;e.texture=n.map.painter.getTileTexture(a.width),e.texture?e.texture.update(a,{useMipmap:!0}):(e.texture=new t.Texture(o,a,s.RGBA,{useMipmap:!0}),e.texture.bind(s.LINEAR,s.CLAMP_TO_EDGE,s.LINEAR_MIPMAP_NEAREST),o.extTextureFilterAnisotropic&&s.texParameterf(s.TEXTURE_2D,o.extTextureFilterAnisotropic.TEXTURE_MAX_ANISOTROPY_EXT,o.extTextureFilterAnisotropicMax)),e.state=\"loaded\",t.cacheEntryPossiblyAdded(n.dispatcher),r(null)}})},r.prototype.abortTile=function(t,e){t.request&&(t.request.cancel(),delete t.request),e()},r.prototype.unloadTile=function(t,e){t.texture&&this.map.painter.saveTileTexture(t.texture),e()},r.prototype.hasTransition=function(){return!1},r}(t.Evented),E=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),this.type=\"raster-dem\",this.maxzoom=22,this._options=t.extend({},n),this.encoding=n.encoding||\"mapbox\"}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.serialize=function(){return{type:\"raster-dem\",url:this.url,tileSize:this.tileSize,tiles:this.tiles,bounds:this.bounds,encoding:this.encoding}},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(n,t.ResourceType.Tile),function(n,i){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(n)e.state=\"errored\",r(n);else if(i){this.map._refreshExpiredTiles&&e.setExpiryData(i),delete i.cacheControl,delete i.expires;var a=t.browser.getImageData(i),o={uid:e.uid,coord:e.tileID,source:this.id,rawImageData:a,encoding:this.encoding};e.workerID&&\"expired\"!==e.state||(e.workerID=this.dispatcher.send(\"loadDEMTile\",o,function(t,n){t&&(e.state=\"errored\",r(t)),n&&(e.dem=n,e.needsHillshadePrepare=!0,e.state=\"loaded\",r(null))}.bind(this)))}}.bind(this)),e.neighboringTiles=this._getNeighboringTiles(e.tileID)},r.prototype._getNeighboringTiles=function(e){var r=e.canonical,n=Math.pow(2,r.z),i=(r.x-1+n)%n,a=0===r.x?e.wrap-1:e.wrap,o=(r.x+1+n)%n,s=r.x+1===n?e.wrap+1:e.wrap,l={};return l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y).key]={backfilled:!1},r.y>0&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y-1).key]={backfilled:!1}),r.y+1<n&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y+1).key]={backfilled:!1}),l},r.prototype.unloadTile=function(t){t.demTexture&&this.map.painter.saveTileTexture(t.demTexture),t.fbo&&(t.fbo.destroy(),delete t.fbo),t.dem&&delete t.dem,delete t.neighboringTiles,t.state=\"unloaded\",this.dispatcher.send(\"removeDEMTile\",{uid:t.uid,source:this.id},void 0,t.workerID)},r}(S),C=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.type=\"geojson\",this.minzoom=0,this.maxzoom=18,this.tileSize=512,this.isTileClipped=!0,this.reparseOverscaled=!0,this._removed=!1,this.dispatcher=i,this.setEventedParent(a),this._data=n.data,this._options=t.extend({},n),this._collectResourceTiming=n.collectResourceTiming,this._resourceTiming=[],void 0!==n.maxzoom&&(this.maxzoom=n.maxzoom),n.type&&(this.type=n.type),n.attribution&&(this.attribution=n.attribution);var o=t.EXTENT/this.tileSize;this.workerOptions=t.extend({source:this.id,cluster:n.cluster||!1,geojsonVtOptions:{buffer:(void 0!==n.buffer?n.buffer:128)*o,tolerance:(void 0!==n.tolerance?n.tolerance:.375)*o,extent:t.EXTENT,maxZoom:this.maxzoom,lineMetrics:n.lineMetrics||!1,generateId:n.generateId||!1},superclusterOptions:{maxZoom:void 0!==n.clusterMaxZoom?Math.min(n.clusterMaxZoom,this.maxzoom-1):this.maxzoom-1,extent:t.EXTENT,radius:(n.clusterRadius||50)*o,log:!1},clusterProperties:n.clusterProperties},n.workerOptions)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData(function(r){if(r)e.fire(new t.ErrorEvent(r));else{var n={dataType:\"source\",sourceDataType:\"metadata\"};e._collectResourceTiming&&e._resourceTiming&&e._resourceTiming.length>0&&(n.resourceTiming=e._resourceTiming,e._resourceTiming=[]),e.fire(new t.Event(\"data\",n))}})},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setData=function(e){var r=this;return this._data=e,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData(function(e){if(e)r.fire(new t.ErrorEvent(e));else{var n={dataType:\"source\",sourceDataType:\"content\"};r._collectResourceTiming&&r._resourceTiming&&r._resourceTiming.length>0&&(n.resourceTiming=r._resourceTiming,r._resourceTiming=[]),r.fire(new t.Event(\"data\",n))}}),this},r.prototype.getClusterExpansionZoom=function(t,e){return this.dispatcher.send(\"geojson.getClusterExpansionZoom\",{clusterId:t,source:this.id},e,this.workerID),this},r.prototype.getClusterChildren=function(t,e){return this.dispatcher.send(\"geojson.getClusterChildren\",{clusterId:t,source:this.id},e,this.workerID),this},r.prototype.getClusterLeaves=function(t,e,r,n){return this.dispatcher.send(\"geojson.getClusterLeaves\",{source:this.id,clusterId:t,limit:e,offset:r},n,this.workerID),this},r.prototype._updateWorkerData=function(e){var r=this,n=t.extend({},this.workerOptions),i=this._data;\"string\"==typeof i?(n.request=this.map._requestManager.transformRequest(t.browser.resolveURL(i),t.ResourceType.Source),n.request.collectResourceTiming=this._collectResourceTiming):n.data=JSON.stringify(i),this.workerID=this.dispatcher.send(this.type+\".loadData\",n,function(t,i){r._removed||i&&i.abandoned||(r._loaded=!0,i&&i.resourceTiming&&i.resourceTiming[r.id]&&(r._resourceTiming=i.resourceTiming[r.id].slice(0)),r.dispatcher.send(r.type+\".coalesce\",{source:n.source},null,r.workerID),e(t))},this.workerID)},r.prototype.loadTile=function(e,r){var n=this,i=void 0===e.workerID?\"loadTile\":\"reloadTile\",a={type:this.type,uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,maxZoom:this.maxzoom,tileSize:this.tileSize,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes};e.workerID=this.dispatcher.send(i,a,function(t,a){return e.unloadVectorData(),e.aborted?r(null):t?r(t):(e.loadVectorData(a,n.map.painter,\"reloadTile\"===i),r(null))},this.workerID)},r.prototype.abortTile=function(t){t.aborted=!0},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.dispatcher.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},null,t.workerID)},r.prototype.onRemove=function(){this._removed=!0,this.dispatcher.send(\"removeSource\",{type:this.type,source:this.id},null,this.workerID)},r.prototype.serialize=function(){return t.extend({},this._options,{type:this.type,data:this._data})},r.prototype.hasTransition=function(){return!1},r}(t.Evented),L=function(e){function r(t,r,n,i){e.call(this),this.id=t,this.dispatcher=n,this.coordinates=r.coordinates,this.type=\"image\",this.minzoom=0,this.maxzoom=22,this.tileSize=512,this.tiles={},this.setEventedParent(i),this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(e,r){var n=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this.url=this.options.url,t.getImage(this.map._requestManager.transformRequest(this.url,t.ResourceType.Image),function(i,a){i?n.fire(new t.ErrorEvent(i)):a&&(n.image=a,e&&(n.coordinates=e),r&&r(),n._finishLoading())})},r.prototype.updateImage=function(t){var e=this;return this.image&&t.url?(this.options.url=t.url,this.load(t.coordinates,function(){e.texture=null}),this):this},r.prototype._finishLoading=function(){this.map&&(this.setCoordinates(this.coordinates),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setCoordinates=function(e){var r=this;this.coordinates=e;var n=e.map(t.MercatorCoordinate.fromLngLat);this.tileID=function(e){for(var r=1/0,n=1/0,i=-1/0,a=-1/0,o=0,s=e;o<s.length;o+=1){var l=s[o];r=Math.min(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.x),a=Math.max(a,l.y)}var c=i-r,u=a-n,h=Math.max(c,u),f=Math.max(0,Math.floor(-Math.log(h)/Math.LN2)),p=Math.pow(2,f);return new t.CanonicalTileID(f,Math.floor((r+i)/2*p),Math.floor((n+a)/2*p))}(n),this.minzoom=this.maxzoom=this.tileID.z;var i=n.map(function(t){return r.tileID.getTilePoint(t)._round()});return this._boundsArray=new t.StructArrayLayout4i8,this._boundsArray.emplaceBack(i[0].x,i[0].y,0,0),this._boundsArray.emplaceBack(i[1].x,i[1].y,t.EXTENT,0),this._boundsArray.emplaceBack(i[3].x,i[3].y,0,t.EXTENT),this._boundsArray.emplaceBack(i[2].x,i[2].y,t.EXTENT,t.EXTENT),this.boundsBuffer&&(this.boundsBuffer.destroy(),delete this.boundsBuffer),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})),this},r.prototype.prepare=function(){if(0!==Object.keys(this.tiles).length&&this.image){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture||(this.texture=new t.Texture(e,this.image,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.loadTile=function(t,e){this.tileID&&this.tileID.equals(t.tileID.canonical)?(this.tiles[String(t.tileID.wrap)]=t,t.buckets={},e(null)):(t.state=\"errored\",e(null))},r.prototype.serialize=function(){return{type:\"image\",url:this.options.url,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return!1},r}(t.Evented),P=function(e){function r(t,r,n,i){e.call(this,t,r,n,i),this.roundZoom=!0,this.type=\"video\",this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this,r=this.options;this.urls=[];for(var n=0,i=r.urls;n<i.length;n+=1){var a=i[n];this.urls.push(this.map._requestManager.transformRequest(a,t.ResourceType.Source).url)}t.getVideo(this.urls,function(r,n){r?e.fire(new t.ErrorEvent(r)):n&&(e.video=n,e.video.loop=!0,e.video.addEventListener(\"playing\",function(){e.map.triggerRepaint()}),e.map&&e.video.play(),e._finishLoading())})},r.prototype.getVideo=function(){return this.video},r.prototype.onAdd=function(t){this.map||(this.map=t,this.load(),this.video&&(this.video.play(),this.setCoordinates(this.coordinates)))},r.prototype.prepare=function(){if(!(0===Object.keys(this.tiles).length||this.video.readyState<2)){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?this.video.paused||(this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE),r.texSubImage2D(r.TEXTURE_2D,0,0,0,r.RGBA,r.UNSIGNED_BYTE,this.video)):(this.texture=new t.Texture(e,this.video,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"video\",urls:this.urls,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this.video&&!this.video.paused},r}(L),O=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),n.coordinates?Array.isArray(n.coordinates)&&4===n.coordinates.length&&!n.coordinates.some(function(t){return!Array.isArray(t)||2!==t.length||t.some(function(t){return\"number\"!=typeof t})})||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"coordinates\" property must be an array of 4 longitude/latitude array pairs'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"coordinates\"'))),n.animate&&\"boolean\"!=typeof n.animate&&this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'optional \"animate\" property must be a boolean value'))),n.canvas?\"string\"==typeof n.canvas||n.canvas instanceof t.window.HTMLCanvasElement||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"canvas\" must be either a string representing the ID of the canvas element from which to read, or an HTMLCanvasElement instance'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"canvas\"'))),this.options=n,this.animate=void 0===n.animate||n.animate}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){this.canvas||(this.canvas=this.options.canvas instanceof t.window.HTMLCanvasElement?this.options.canvas:t.window.document.getElementById(this.options.canvas)),this.width=this.canvas.width,this.height=this.canvas.height,this._hasInvalidDimensions()?this.fire(new t.ErrorEvent(new Error(\"Canvas dimensions cannot be less than or equal to zero.\"))):(this.play=function(){this._playing=!0,this.map.triggerRepaint()},this.pause=function(){this._playing&&(this.prepare(),this._playing=!1)},this._finishLoading())},r.prototype.getCanvas=function(){return this.canvas},r.prototype.onAdd=function(t){this.map=t,this.load(),this.canvas&&this.animate&&this.play()},r.prototype.onRemove=function(){this.pause()},r.prototype.prepare=function(){var e=!1;if(this.canvas.width!==this.width&&(this.width=this.canvas.width,e=!0),this.canvas.height!==this.height&&(this.height=this.canvas.height,e=!0),!this._hasInvalidDimensions()&&0!==Object.keys(this.tiles).length){var r=this.map.painter.context,n=r.gl;for(var i in this.boundsBuffer||(this.boundsBuffer=r.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?(e||this._playing)&&this.texture.update(this.canvas,{premultiply:!0}):this.texture=new t.Texture(r,this.canvas,n.RGBA,{premultiply:!0}),this.tiles){var a=this.tiles[i];\"loaded\"!==a.state&&(a.state=\"loaded\",a.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"canvas\",coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this._playing},r.prototype._hasInvalidDimensions=function(){for(var t=0,e=[this.canvas.width,this.canvas.height];t<e.length;t+=1){var r=e[t];if(isNaN(r)||r<=0)return!0}return!1},r}(L),z={vector:M,raster:S,\"raster-dem\":E,geojson:C,video:P,image:L,canvas:O},I=function(e,r,n,i){var a=new z[r.type](e,r,n,i);if(a.id!==e)throw new Error(\"Expected Source id to be \"+e+\" instead of \"+a.id);return t.bindAll([\"load\",\"abort\",\"unload\",\"serialize\",\"prepare\"],a),a};function D(e,r){var n=t.identity([]);return t.translate(n,n,[1,1,0]),t.scale(n,n,[.5*e.width,.5*e.height,1]),t.multiply(n,n,e.calculatePosMatrix(r.toUnwrapped()))}function R(t,e,r,n,i){var a=function(t,e,r){if(t)for(var n=0,i=t;n<i.length;n+=1){var a=e[i[n]];if(a&&a.source===r&&\"fill-extrusion\"===a.type)return!0}else for(var o in e){var s=e[o];if(s.source===r&&\"fill-extrusion\"===s.type)return!0}return!1}(n&&n.layers,e,t.id),o=i.maxPitchScaleFactor(),s=t.tilesIn(r,o,a);s.sort(F);for(var l=[],c=0,u=s;c<u.length;c+=1){var h=u[c];l.push({wrappedTileID:h.tileID.wrapped().key,queryResults:h.tile.queryRenderedFeatures(e,t._state,h.queryGeometry,h.cameraQueryGeometry,h.scale,n,i,o,D(t.transform,h.tileID))})}var f=function(t){for(var e={},r={},n=0,i=t;n<i.length;n+=1){var a=i[n],o=a.queryResults,s=a.wrappedTileID,l=r[s]=r[s]||{};for(var c in o)for(var u=o[c],h=l[c]=l[c]||{},f=e[c]=e[c]||[],p=0,d=u;p<d.length;p+=1){var g=d[p];h[g.featureIndex]||(h[g.featureIndex]=!0,f.push(g))}}return e}(l);for(var p in f)f[p].forEach(function(e){var r=e.feature,n=t.getFeatureState(r.layer[\"source-layer\"],r.id);r.source=r.layer.source,r.layer[\"source-layer\"]&&(r.sourceLayer=r.layer[\"source-layer\"]),r.state=n});return f}function F(t,e){var r=t.tileID,n=e.tileID;return r.overscaledZ-n.overscaledZ||r.canonical.y-n.canonical.y||r.wrap-n.wrap||r.canonical.x-n.canonical.x}var B=function(t,e){this.max=t,this.onRemove=e,this.reset()};B.prototype.reset=function(){for(var t in this.data)for(var e=0,r=this.data[t];e<r.length;e+=1){var n=r[e];n.timeout&&clearTimeout(n.timeout),this.onRemove(n.value)}return this.data={},this.order=[],this},B.prototype.add=function(t,e,r){var n=this,i=t.wrapped().key;void 0===this.data[i]&&(this.data[i]=[]);var a={value:e,timeout:void 0};if(void 0!==r&&(a.timeout=setTimeout(function(){n.remove(t,a)},r)),this.data[i].push(a),this.order.push(i),this.order.length>this.max){var o=this._getAndRemoveByKey(this.order[0]);o&&this.onRemove(o)}return this},B.prototype.has=function(t){return t.wrapped().key in this.data},B.prototype.getAndRemove=function(t){return this.has(t)?this._getAndRemoveByKey(t.wrapped().key):null},B.prototype._getAndRemoveByKey=function(t){var e=this.data[t].shift();return e.timeout&&clearTimeout(e.timeout),0===this.data[t].length&&delete this.data[t],this.order.splice(this.order.indexOf(t),1),e.value},B.prototype.get=function(t){return this.has(t)?this.data[t.wrapped().key][0].value:null},B.prototype.remove=function(t,e){if(!this.has(t))return this;var r=t.wrapped().key,n=void 0===e?0:this.data[r].indexOf(e),i=this.data[r][n];return this.data[r].splice(n,1),i.timeout&&clearTimeout(i.timeout),0===this.data[r].length&&delete this.data[r],this.onRemove(i.value),this.order.splice(this.order.indexOf(r),1),this},B.prototype.setMaxSize=function(t){for(this.max=t;this.order.length>this.max;){var e=this._getAndRemoveByKey(this.order[0]);e&&this.onRemove(e)}return this};var N=function(t,e,r){this.context=t;var n=t.gl;this.buffer=n.createBuffer(),this.dynamicDraw=Boolean(r),this.context.unbindVAO(),t.bindElementBuffer.set(this.buffer),n.bufferData(n.ELEMENT_ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?n.DYNAMIC_DRAW:n.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};N.prototype.bind=function(){this.context.bindElementBuffer.set(this.buffer)},N.prototype.updateData=function(t){var e=this.context.gl;this.context.unbindVAO(),this.bind(),e.bufferSubData(e.ELEMENT_ARRAY_BUFFER,0,t.arrayBuffer)},N.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var j={Int8:\"BYTE\",Uint8:\"UNSIGNED_BYTE\",Int16:\"SHORT\",Uint16:\"UNSIGNED_SHORT\",Int32:\"INT\",Uint32:\"UNSIGNED_INT\",Float32:\"FLOAT\"},U=function(t,e,r,n){this.length=e.length,this.attributes=r,this.itemSize=e.bytesPerElement,this.dynamicDraw=n,this.context=t;var i=t.gl;this.buffer=i.createBuffer(),t.bindVertexBuffer.set(this.buffer),i.bufferData(i.ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?i.DYNAMIC_DRAW:i.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};U.prototype.bind=function(){this.context.bindVertexBuffer.set(this.buffer)},U.prototype.updateData=function(t){var e=this.context.gl;this.bind(),e.bufferSubData(e.ARRAY_BUFFER,0,t.arrayBuffer)},U.prototype.enableAttributes=function(t,e){for(var r=0;r<this.attributes.length;r++){var n=this.attributes[r],i=e.attributes[n.name];void 0!==i&&t.enableVertexAttribArray(i)}},U.prototype.setVertexAttribPointers=function(t,e,r){for(var n=0;n<this.attributes.length;n++){var i=this.attributes[n],a=e.attributes[i.name];void 0!==a&&t.vertexAttribPointer(a,i.components,t[j[i.type]],!1,this.itemSize,i.offset+this.itemSize*(r||0))}},U.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var V=function(t){this.gl=t.gl,this.default=this.getDefault(),this.current=this.default,this.dirty=!1};V.prototype.get=function(){return this.current},V.prototype.set=function(t){},V.prototype.getDefault=function(){return this.default},V.prototype.setDefault=function(){this.set(this.default)};var q=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.clearColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(V),H=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 1},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearDepth(t),this.current=t,this.dirty=!1)},e}(V),G=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearStencil(t),this.current=t,this.dirty=!1)},e}(V),Y=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return[!0,!0,!0,!0]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.colorMask(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(V),W=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthMask(t),this.current=t,this.dirty=!1)},e}(V),X=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 255},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.stencilMask(t),this.current=t,this.dirty=!1)},e}(V),Z=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return{func:this.gl.ALWAYS,ref:0,mask:255}},e.prototype.set=function(t){var e=this.current;(t.func!==e.func||t.ref!==e.ref||t.mask!==e.mask||this.dirty)&&(this.gl.stencilFunc(t.func,t.ref,t.mask),this.current=t,this.dirty=!1)},e}(V),J=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.KEEP,t.KEEP,t.KEEP]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||this.dirty)&&(this.gl.stencilOp(t[0],t[1],t[2]),this.current=t,this.dirty=!1)},e}(V),K=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.STENCIL_TEST):e.disable(e.STENCIL_TEST),this.current=t,this.dirty=!1}},e}(V),$=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return[0,1]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.depthRange(t[0],t[1]),this.current=t,this.dirty=!1)},e}(V),Q=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.DEPTH_TEST):e.disable(e.DEPTH_TEST),this.current=t,this.dirty=!1}},e}(V),tt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.LESS},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthFunc(t),this.current=t,this.dirty=!1)},e}(V),et=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.BLEND):e.disable(e.BLEND),this.current=t,this.dirty=!1}},e}(V),rt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.ONE,t.ZERO]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.blendFunc(t[0],t[1]),this.current=t,this.dirty=!1)},e}(V),nt=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.blendColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(V),it=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.FUNC_ADD},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.blendEquation(t),this.current=t,this.dirty=!1)},e}(V),at=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.CULL_FACE):e.disable(e.CULL_FACE),this.current=t,this.dirty=!1}},e}(V),ot=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.BACK},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.cullFace(t),this.current=t,this.dirty=!1)},e}(V),st=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.CCW},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.frontFace(t),this.current=t,this.dirty=!1)},e}(V),lt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.useProgram(t),this.current=t,this.dirty=!1)},e}(V),ct=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.TEXTURE0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.activeTexture(t),this.current=t,this.dirty=!1)},e}(V),ut=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[0,0,t.drawingBufferWidth,t.drawingBufferHeight]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.viewport(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(V),ht=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindFramebuffer(e.FRAMEBUFFER,t),this.current=t,this.dirty=!1}},e}(V),ft=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindRenderbuffer(e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(V),pt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindTexture(e.TEXTURE_2D,t),this.current=t,this.dirty=!1}},e}(V),dt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindBuffer(e.ARRAY_BUFFER,t),this.current=t,this.dirty=!1}},e}(V),gt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){var e=this.gl;e.bindBuffer(e.ELEMENT_ARRAY_BUFFER,t),this.current=t,this.dirty=!1},e}(V),vt=function(t){function e(e){t.call(this,e),this.vao=e.extVertexArrayObject}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){this.vao&&(t!==this.current||this.dirty)&&(this.vao.bindVertexArrayOES(t),this.current=t,this.dirty=!1)},e}(V),mt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 4},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_ALIGNMENT,t),this.current=t,this.dirty=!1}},e}(V),yt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_PREMULTIPLY_ALPHA_WEBGL,t),this.current=t,this.dirty=!1}},e}(V),xt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_FLIP_Y_WEBGL,t),this.current=t,this.dirty=!1}},e}(V),bt=function(t){function e(e,r){t.call(this,e),this.context=e,this.parent=r}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e}(V),_t=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.setDirty=function(){this.dirty=!0},e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferTexture2D(e.FRAMEBUFFER,e.COLOR_ATTACHMENT0,e.TEXTURE_2D,t,0),this.current=t,this.dirty=!1}},e}(bt),wt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferRenderbuffer(e.FRAMEBUFFER,e.DEPTH_ATTACHMENT,e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(bt),kt=function(t,e,r){this.context=t,this.width=e,this.height=r;var n=t.gl,i=this.framebuffer=n.createFramebuffer();this.colorAttachment=new _t(t,i),this.depthAttachment=new wt(t,i)};kt.prototype.destroy=function(){var t=this.context.gl,e=this.colorAttachment.get();e&&t.deleteTexture(e);var r=this.depthAttachment.get();r&&t.deleteRenderbuffer(r),t.deleteFramebuffer(this.framebuffer)};var Tt=function(t,e,r){this.func=t,this.mask=e,this.range=r};Tt.ReadOnly=!1,Tt.ReadWrite=!0,Tt.disabled=new Tt(519,Tt.ReadOnly,[0,1]);var At=function(t,e,r,n,i,a){this.test=t,this.ref=e,this.mask=r,this.fail=n,this.depthFail=i,this.pass=a};At.disabled=new At({func:519,mask:0},0,0,7680,7680,7680);var Mt=function(t,e,r){this.blendFunction=t,this.blendColor=e,this.mask=r};Mt.disabled=new Mt(Mt.Replace=[1,0],t.Color.transparent,[!1,!1,!1,!1]),Mt.unblended=new Mt(Mt.Replace,t.Color.transparent,[!0,!0,!0,!0]),Mt.alphaBlended=new Mt([1,771],t.Color.transparent,[!0,!0,!0,!0]);var St=function(t,e,r){this.enable=t,this.mode=e,this.frontFace=r};St.disabled=new St(!1,1029,2305),St.backCCW=new St(!0,1029,2305);var Et=function(t){this.gl=t,this.extVertexArrayObject=this.gl.getExtension(\"OES_vertex_array_object\"),this.clearColor=new q(this),this.clearDepth=new H(this),this.clearStencil=new G(this),this.colorMask=new Y(this),this.depthMask=new W(this),this.stencilMask=new X(this),this.stencilFunc=new Z(this),this.stencilOp=new J(this),this.stencilTest=new K(this),this.depthRange=new $(this),this.depthTest=new Q(this),this.depthFunc=new tt(this),this.blend=new et(this),this.blendFunc=new rt(this),this.blendColor=new nt(this),this.blendEquation=new it(this),this.cullFace=new at(this),this.cullFaceSide=new ot(this),this.frontFace=new st(this),this.program=new lt(this),this.activeTexture=new ct(this),this.viewport=new ut(this),this.bindFramebuffer=new ht(this),this.bindRenderbuffer=new ft(this),this.bindTexture=new pt(this),this.bindVertexBuffer=new dt(this),this.bindElementBuffer=new gt(this),this.bindVertexArrayOES=this.extVertexArrayObject&&new vt(this),this.pixelStoreUnpack=new mt(this),this.pixelStoreUnpackPremultiplyAlpha=new yt(this),this.pixelStoreUnpackFlipY=new xt(this),this.extTextureFilterAnisotropic=t.getExtension(\"EXT_texture_filter_anisotropic\")||t.getExtension(\"MOZ_EXT_texture_filter_anisotropic\")||t.getExtension(\"WEBKIT_EXT_texture_filter_anisotropic\"),this.extTextureFilterAnisotropic&&(this.extTextureFilterAnisotropicMax=t.getParameter(this.extTextureFilterAnisotropic.MAX_TEXTURE_MAX_ANISOTROPY_EXT)),this.extTextureHalfFloat=t.getExtension(\"OES_texture_half_float\"),this.extTextureHalfFloat&&t.getExtension(\"OES_texture_half_float_linear\")};Et.prototype.setDefault=function(){this.unbindVAO(),this.clearColor.setDefault(),this.clearDepth.setDefault(),this.clearStencil.setDefault(),this.colorMask.setDefault(),this.depthMask.setDefault(),this.stencilMask.setDefault(),this.stencilFunc.setDefault(),this.stencilOp.setDefault(),this.stencilTest.setDefault(),this.depthRange.setDefault(),this.depthTest.setDefault(),this.depthFunc.setDefault(),this.blend.setDefault(),this.blendFunc.setDefault(),this.blendColor.setDefault(),this.blendEquation.setDefault(),this.cullFace.setDefault(),this.cullFaceSide.setDefault(),this.frontFace.setDefault(),this.program.setDefault(),this.activeTexture.setDefault(),this.bindFramebuffer.setDefault(),this.pixelStoreUnpack.setDefault(),this.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.pixelStoreUnpackFlipY.setDefault()},Et.prototype.setDirty=function(){this.clearColor.dirty=!0,this.clearDepth.dirty=!0,this.clearStencil.dirty=!0,this.colorMask.dirty=!0,this.depthMask.dirty=!0,this.stencilMask.dirty=!0,this.stencilFunc.dirty=!0,this.stencilOp.dirty=!0,this.stencilTest.dirty=!0,this.depthRange.dirty=!0,this.depthTest.dirty=!0,this.depthFunc.dirty=!0,this.blend.dirty=!0,this.blendFunc.dirty=!0,this.blendColor.dirty=!0,this.blendEquation.dirty=!0,this.cullFace.dirty=!0,this.cullFaceSide.dirty=!0,this.frontFace.dirty=!0,this.program.dirty=!0,this.activeTexture.dirty=!0,this.viewport.dirty=!0,this.bindFramebuffer.dirty=!0,this.bindRenderbuffer.dirty=!0,this.bindTexture.dirty=!0,this.bindVertexBuffer.dirty=!0,this.bindElementBuffer.dirty=!0,this.extVertexArrayObject&&(this.bindVertexArrayOES.dirty=!0),this.pixelStoreUnpack.dirty=!0,this.pixelStoreUnpackPremultiplyAlpha.dirty=!0,this.pixelStoreUnpackFlipY.dirty=!0},Et.prototype.createIndexBuffer=function(t,e){return new N(this,t,e)},Et.prototype.createVertexBuffer=function(t,e,r){return new U(this,t,e,r)},Et.prototype.createRenderbuffer=function(t,e,r){var n=this.gl,i=n.createRenderbuffer();return this.bindRenderbuffer.set(i),n.renderbufferStorage(n.RENDERBUFFER,t,e,r),this.bindRenderbuffer.set(null),i},Et.prototype.createFramebuffer=function(t,e){return new kt(this,t,e)},Et.prototype.clear=function(t){var e=t.color,r=t.depth,n=this.gl,i=0;e&&(i|=n.COLOR_BUFFER_BIT,this.clearColor.set(e),this.colorMask.set([!0,!0,!0,!0])),void 0!==r&&(i|=n.DEPTH_BUFFER_BIT,this.depthRange.set([0,1]),this.clearDepth.set(r),this.depthMask.set(!0)),n.clear(i)},Et.prototype.setCullFace=function(t){!1===t.enable?this.cullFace.set(!1):(this.cullFace.set(!0),this.cullFaceSide.set(t.mode),this.frontFace.set(t.frontFace))},Et.prototype.setDepthMode=function(t){t.func!==this.gl.ALWAYS||t.mask?(this.depthTest.set(!0),this.depthFunc.set(t.func),this.depthMask.set(t.mask),this.depthRange.set(t.range)):this.depthTest.set(!1)},Et.prototype.setStencilMode=function(t){t.test.func!==this.gl.ALWAYS||t.mask?(this.stencilTest.set(!0),this.stencilMask.set(t.mask),this.stencilOp.set([t.fail,t.depthFail,t.pass]),this.stencilFunc.set({func:t.test.func,ref:t.ref,mask:t.test.mask})):this.stencilTest.set(!1)},Et.prototype.setColorMode=function(e){t.deepEqual(e.blendFunction,Mt.Replace)?this.blend.set(!1):(this.blend.set(!0),this.blendFunc.set(e.blendFunction),this.blendColor.set(e.blendColor)),this.colorMask.set(e.mask)},Et.prototype.unbindVAO=function(){this.extVertexArrayObject&&this.bindVertexArrayOES.set(null)};var Ct=function(e){function r(r,n,i){var a=this;e.call(this),this.id=r,this.dispatcher=i,this.on(\"data\",function(t){\"source\"===t.dataType&&\"metadata\"===t.sourceDataType&&(a._sourceLoaded=!0),a._sourceLoaded&&!a._paused&&\"source\"===t.dataType&&\"content\"===t.sourceDataType&&(a.reload(),a.transform&&a.update(a.transform))}),this.on(\"error\",function(){a._sourceErrored=!0}),this._source=I(r,n,i,this),this._tiles={},this._cache=new B(0,this._unloadTile.bind(this)),this._timers={},this._cacheTimers={},this._maxTileCacheSize=null,this._coveredTiles={},this._state=new t.SourceFeatureState}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.onAdd=function(t){this.map=t,this._maxTileCacheSize=t?t._maxTileCacheSize:null,this._source&&this._source.onAdd&&this._source.onAdd(t)},r.prototype.onRemove=function(t){this._source&&this._source.onRemove&&this._source.onRemove(t)},r.prototype.loaded=function(){if(this._sourceErrored)return!0;if(!this._sourceLoaded)return!1;for(var t in this._tiles){var e=this._tiles[t];if(\"loaded\"!==e.state&&\"errored\"!==e.state)return!1}return!0},r.prototype.getSource=function(){return this._source},r.prototype.pause=function(){this._paused=!0},r.prototype.resume=function(){if(this._paused){var t=this._shouldReloadOnResume;this._paused=!1,this._shouldReloadOnResume=!1,t&&this.reload(),this.transform&&this.update(this.transform)}},r.prototype._loadTile=function(t,e){return this._source.loadTile(t,e)},r.prototype._unloadTile=function(t){if(this._source.unloadTile)return this._source.unloadTile(t,function(){})},r.prototype._abortTile=function(t){if(this._source.abortTile)return this._source.abortTile(t,function(){})},r.prototype.serialize=function(){return this._source.serialize()},r.prototype.prepare=function(t){for(var e in this._source.prepare&&this._source.prepare(),this._state.coalesceChanges(this._tiles,this.map?this.map.painter:null),this._tiles){var r=this._tiles[e];r.upload(t),r.prepare(this.map.style.imageManager)}},r.prototype.getIds=function(){return Object.keys(this._tiles).map(Number).sort(Lt)},r.prototype.getRenderableIds=function(e){var r=this,n=[];for(var i in this._tiles)this._isIdRenderable(+i,e)&&n.push(+i);return e?n.sort(function(e,n){var i=r._tiles[e].tileID,a=r._tiles[n].tileID,o=new t.Point(i.canonical.x,i.canonical.y)._rotate(r.transform.angle),s=new t.Point(a.canonical.x,a.canonical.y)._rotate(r.transform.angle);return i.overscaledZ-a.overscaledZ||s.y-o.y||s.x-o.x}):n.sort(Lt)},r.prototype.hasRenderableParent=function(t){var e=this.findLoadedParent(t,0);return!!e&&this._isIdRenderable(e.tileID.key)},r.prototype._isIdRenderable=function(t,e){return this._tiles[t]&&this._tiles[t].hasData()&&!this._coveredTiles[t]&&(e||!this._tiles[t].holdingForFade())},r.prototype.reload=function(){if(this._paused)this._shouldReloadOnResume=!0;else for(var t in this._cache.reset(),this._tiles)\"errored\"!==this._tiles[t].state&&this._reloadTile(t,\"reloading\")},r.prototype._reloadTile=function(t,e){var r=this._tiles[t];r&&(\"loading\"!==r.state&&(r.state=e),this._loadTile(r,this._tileLoaded.bind(this,r,t,e)))},r.prototype._tileLoaded=function(e,r,n,i){if(i)return e.state=\"errored\",void(404!==i.status?this._source.fire(new t.ErrorEvent(i,{tile:e})):this.update(this.transform));e.timeAdded=t.browser.now(),\"expired\"===n&&(e.refreshedUponExpiration=!0),this._setTileReloadTimer(r,e),\"raster-dem\"===this.getSource().type&&e.dem&&this._backfillDEM(e),this._state.initializeTileState(e,this.map?this.map.painter:null),this._source.fire(new t.Event(\"data\",{dataType:\"source\",tile:e,coord:e.tileID}))},r.prototype._backfillDEM=function(t){for(var e=this.getRenderableIds(),r=0;r<e.length;r++){var n=e[r];if(t.neighboringTiles&&t.neighboringTiles[n]){var i=this.getTileByID(n);a(t,i),a(i,t)}}function a(t,e){t.needsHillshadePrepare=!0;var r=e.tileID.canonical.x-t.tileID.canonical.x,n=e.tileID.canonical.y-t.tileID.canonical.y,i=Math.pow(2,t.tileID.canonical.z),a=e.tileID.key;0===r&&0===n||Math.abs(n)>1||(Math.abs(r)>1&&(1===Math.abs(r+i)?r+=i:1===Math.abs(r-i)&&(r-=i)),e.dem&&t.dem&&(t.dem.backfillBorder(e.dem,r,n),t.neighboringTiles&&t.neighboringTiles[a]&&(t.neighboringTiles[a].backfilled=!0)))}},r.prototype.getTile=function(t){return this.getTileByID(t.key)},r.prototype.getTileByID=function(t){return this._tiles[t]},r.prototype.getZoom=function(t){return t.zoom+t.scaleZoom(t.tileSize/this._source.tileSize)},r.prototype._retainLoadedChildren=function(t,e,r,n){for(var i in this._tiles){var a=this._tiles[i];if(!(n[i]||!a.hasData()||a.tileID.overscaledZ<=e||a.tileID.overscaledZ>r)){for(var o=a.tileID;a&&a.tileID.overscaledZ>e+1;){var s=a.tileID.scaledTo(a.tileID.overscaledZ-1);(a=this._tiles[s.key])&&a.hasData()&&(o=s)}for(var l=o;l.overscaledZ>e;)if(t[(l=l.scaledTo(l.overscaledZ-1)).key]){n[o.key]=o;break}}}},r.prototype.findLoadedParent=function(t,e){for(var r=t.overscaledZ-1;r>=e;r--){var n=t.scaledTo(r);if(!n)return;var i=String(n.key),a=this._tiles[i];if(a&&a.hasData())return a;if(this._cache.has(n))return this._cache.get(n)}},r.prototype.updateCacheSize=function(t){var e=(Math.ceil(t.width/this._source.tileSize)+1)*(Math.ceil(t.height/this._source.tileSize)+1),r=Math.floor(5*e),n=\"number\"==typeof this._maxTileCacheSize?Math.min(this._maxTileCacheSize,r):r;this._cache.setMaxSize(n)},r.prototype.handleWrapJump=function(t){var e=(t-(void 0===this._prevLng?t:this._prevLng))/360,r=Math.round(e);if(this._prevLng=t,r){var n={};for(var i in this._tiles){var a=this._tiles[i];a.tileID=a.tileID.unwrapTo(a.tileID.wrap+r),n[a.tileID.key]=a}for(var o in this._tiles=n,this._timers)clearTimeout(this._timers[o]),delete this._timers[o];for(var s in this._tiles){var l=this._tiles[s];this._setTileReloadTimer(s,l)}}},r.prototype.update=function(e){var n=this;if(this.transform=e,this._sourceLoaded&&!this._paused){var i;this.updateCacheSize(e),this.handleWrapJump(this.transform.center.lng),this._coveredTiles={},this.used?this._source.tileID?i=e.getVisibleUnwrappedCoordinates(this._source.tileID).map(function(e){return new t.OverscaledTileID(e.canonical.z,e.wrap,e.canonical.z,e.canonical.x,e.canonical.y)}):(i=e.coveringTiles({tileSize:this._source.tileSize,minzoom:this._source.minzoom,maxzoom:this._source.maxzoom,roundZoom:this._source.roundZoom,reparseOverscaled:this._source.reparseOverscaled}),this._source.hasTile&&(i=i.filter(function(t){return n._source.hasTile(t)}))):i=[];var a=(this._source.roundZoom?Math.round:Math.floor)(this.getZoom(e)),o=Math.max(a-r.maxOverzooming,this._source.minzoom),s=Math.max(a+r.maxUnderzooming,this._source.minzoom),l=this._updateRetainedTiles(i,a);if(Pt(this._source.type)){for(var c={},u={},h=0,f=Object.keys(l);h<f.length;h+=1){var p=f[h],d=l[p],g=this._tiles[p];if(g&&!(g.fadeEndTime&&g.fadeEndTime<=t.browser.now())){var v=this.findLoadedParent(d,o);v&&(this._addTile(v.tileID),c[v.tileID.key]=v.tileID),u[p]=d}}for(var m in this._retainLoadedChildren(u,a,s,l),c)l[m]||(this._coveredTiles[m]=!0,l[m]=c[m])}for(var y in l)this._tiles[y].clearFadeHold();for(var x=0,b=t.keysDifference(this._tiles,l);x<b.length;x+=1){var _=b[x],w=this._tiles[_];w.hasSymbolBuckets&&!w.holdingForFade()?w.setHoldDuration(this.map._fadeDuration):w.hasSymbolBuckets&&!w.symbolFadeFinished()||this._removeTile(_)}}},r.prototype.releaseSymbolFadeTiles=function(){for(var t in this._tiles)this._tiles[t].holdingForFade()&&this._removeTile(t)},r.prototype._updateRetainedTiles=function(t,e){for(var n={},i={},a=Math.max(e-r.maxOverzooming,this._source.minzoom),o=Math.max(e+r.maxUnderzooming,this._source.minzoom),s={},l=0,c=t;l<c.length;l+=1){var u=c[l],h=this._addTile(u);n[u.key]=u,h.hasData()||e<this._source.maxzoom&&(s[u.key]=u)}this._retainLoadedChildren(s,e,o,n);for(var f=0,p=t;f<p.length;f+=1){var d=p[f],g=this._tiles[d.key];if(!g.hasData()){if(e+1>this._source.maxzoom){var v=d.children(this._source.maxzoom)[0],m=this.getTile(v);if(m&&m.hasData()){n[v.key]=v;continue}}else{var y=d.children(this._source.maxzoom);if(n[y[0].key]&&n[y[1].key]&&n[y[2].key]&&n[y[3].key])continue}for(var x=g.wasRequested(),b=d.overscaledZ-1;b>=a;--b){var _=d.scaledTo(b);if(i[_.key])break;if(i[_.key]=!0,!(g=this.getTile(_))&&x&&(g=this._addTile(_)),g&&(n[_.key]=_,x=g.wasRequested(),g.hasData()))break}}}return n},r.prototype._addTile=function(e){var r=this._tiles[e.key];if(r)return r;(r=this._cache.getAndRemove(e))&&(this._setTileReloadTimer(e.key,r),r.tileID=e,this._state.initializeTileState(r,this.map?this.map.painter:null),this._cacheTimers[e.key]&&(clearTimeout(this._cacheTimers[e.key]),delete this._cacheTimers[e.key],this._setTileReloadTimer(e.key,r)));var n=Boolean(r);return n||(r=new t.Tile(e,this._source.tileSize*e.overscaleFactor()),this._loadTile(r,this._tileLoaded.bind(this,r,e.key,r.state))),r?(r.uses++,this._tiles[e.key]=r,n||this._source.fire(new t.Event(\"dataloading\",{tile:r,coord:r.tileID,dataType:\"source\"})),r):null},r.prototype._setTileReloadTimer=function(t,e){var r=this;t in this._timers&&(clearTimeout(this._timers[t]),delete this._timers[t]);var n=e.getExpiryTimeout();n&&(this._timers[t]=setTimeout(function(){r._reloadTile(t,\"expired\"),delete r._timers[t]},n))},r.prototype._removeTile=function(t){var e=this._tiles[t];e&&(e.uses--,delete this._tiles[t],this._timers[t]&&(clearTimeout(this._timers[t]),delete this._timers[t]),e.uses>0||(e.hasData()?this._cache.add(e.tileID,e,e.getExpiryTimeout()):(e.aborted=!0,this._abortTile(e),this._unloadTile(e))))},r.prototype.clearTiles=function(){for(var t in this._shouldReloadOnResume=!1,this._paused=!1,this._tiles)this._removeTile(t);this._cache.reset()},r.prototype.tilesIn=function(e,r,n){var i=this,a=[],o=this.transform;if(!o)return a;for(var s=n?o.getCameraQueryGeometry(e):e,l=e.map(function(t){return o.pointCoordinate(t)}),c=s.map(function(t){return o.pointCoordinate(t)}),u=this.getIds(),h=1/0,f=1/0,p=-1/0,d=-1/0,g=0,v=c;g<v.length;g+=1){var m=v[g];h=Math.min(h,m.x),f=Math.min(f,m.y),p=Math.max(p,m.x),d=Math.max(d,m.y)}for(var y=function(e){var n=i._tiles[u[e]];if(!n.holdingForFade()){var s=n.tileID,g=Math.pow(2,o.zoom-n.tileID.overscaledZ),v=r*n.queryPadding*t.EXTENT/n.tileSize/g,m=[s.getTilePoint(new t.MercatorCoordinate(h,f)),s.getTilePoint(new t.MercatorCoordinate(p,d))];if(m[0].x-v<t.EXTENT&&m[0].y-v<t.EXTENT&&m[1].x+v>=0&&m[1].y+v>=0){var y=l.map(function(t){return s.getTilePoint(t)}),x=c.map(function(t){return s.getTilePoint(t)});a.push({tile:n,tileID:s,queryGeometry:y,cameraQueryGeometry:x,scale:g})}}},x=0;x<u.length;x++)y(x);return a},r.prototype.getVisibleCoordinates=function(t){for(var e=this,r=this.getRenderableIds(t).map(function(t){return e._tiles[t].tileID}),n=0,i=r;n<i.length;n+=1){var a=i[n];a.posMatrix=this.transform.calculatePosMatrix(a.toUnwrapped())}return r},r.prototype.hasTransition=function(){if(this._source.hasTransition())return!0;if(Pt(this._source.type))for(var e in this._tiles){var r=this._tiles[e];if(void 0!==r.fadeEndTime&&r.fadeEndTime>=t.browser.now())return!0}return!1},r.prototype.setFeatureState=function(t,e,r){t=t||\"_geojsonTileLayer\",this._state.updateState(t,e,r)},r.prototype.removeFeatureState=function(t,e,r){t=t||\"_geojsonTileLayer\",this._state.removeFeatureState(t,e,r)},r.prototype.getFeatureState=function(t,e){return t=t||\"_geojsonTileLayer\",this._state.getState(t,e)},r}(t.Evented);function Lt(t,e){return t%32-e%32||e-t}function Pt(t){return\"raster\"===t||\"image\"===t||\"video\"===t}function Ot(){return new t.window.Worker(Jn.workerUrl)}Ct.maxOverzooming=10,Ct.maxUnderzooming=3;var zt=function(){this.active={}};zt.prototype.acquire=function(t){if(!this.workers)for(this.workers=[];this.workers.length<zt.workerCount;)this.workers.push(new Ot);return this.active[t]=!0,this.workers.slice()},zt.prototype.release=function(t){delete this.active[t],0===Object.keys(this.active).length&&(this.workers.forEach(function(t){t.terminate()}),this.workers=null)};var It,Dt=Math.floor(t.browser.hardwareConcurrency/2);function Rt(e,r){var n={};for(var i in e)\"ref\"!==i&&(n[i]=e[i]);return t.refProperties.forEach(function(t){t in r&&(n[t]=r[t])}),n}function Ft(t){t=t.slice();for(var e=Object.create(null),r=0;r<t.length;r++)e[t[r].id]=t[r];for(var n=0;n<t.length;n++)\"ref\"in t[n]&&(t[n]=Rt(t[n],e[t[n].ref]));return t}zt.workerCount=Math.max(Math.min(Dt,6),1);var Bt={setStyle:\"setStyle\",addLayer:\"addLayer\",removeLayer:\"removeLayer\",setPaintProperty:\"setPaintProperty\",setLayoutProperty:\"setLayoutProperty\",setFilter:\"setFilter\",addSource:\"addSource\",removeSource:\"removeSource\",setGeoJSONSourceData:\"setGeoJSONSourceData\",setLayerZoomRange:\"setLayerZoomRange\",setLayerProperty:\"setLayerProperty\",setCenter:\"setCenter\",setZoom:\"setZoom\",setBearing:\"setBearing\",setPitch:\"setPitch\",setSprite:\"setSprite\",setGlyphs:\"setGlyphs\",setTransition:\"setTransition\",setLight:\"setLight\"};function Nt(t,e,r){r.push({command:Bt.addSource,args:[t,e[t]]})}function jt(t,e,r){e.push({command:Bt.removeSource,args:[t]}),r[t]=!0}function Ut(t,e,r,n){jt(t,r,n),Nt(t,e,r)}function Vt(e,r,n){var i;for(i in e[n])if(e[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;for(i in r[n])if(r[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;return!0}function qt(e,r,n,i,a,o){var s;for(s in r=r||{},e=e||{})e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}));for(s in r)r.hasOwnProperty(s)&&!e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}))}function Ht(t){return t.id}function Gt(t,e){return t[e.id]=e,t}var Yt=function(t,e,r){var n=this.boxCells=[],i=this.circleCells=[];this.xCellCount=Math.ceil(t/r),this.yCellCount=Math.ceil(e/r);for(var a=0;a<this.xCellCount*this.yCellCount;a++)n.push([]),i.push([]);this.circleKeys=[],this.boxKeys=[],this.bboxes=[],this.circles=[],this.width=t,this.height=e,this.xScale=this.xCellCount/t,this.yScale=this.yCellCount/e,this.boxUid=0,this.circleUid=0};function Wt(e,r,n,i,a){var o=t.create();return r?(t.scale(o,o,[1/a,1/a,1]),n||t.rotateZ(o,o,i.angle)):t.multiply(o,i.labelPlaneMatrix,e),o}function Xt(e,r,n,i,a){if(r){var o=t.clone(e);return t.scale(o,o,[a,a,1]),n||t.rotateZ(o,o,-i.angle),o}return i.glCoordMatrix}function Zt(e,r){var n=[e.x,e.y,0,1];ae(n,n,r);var i=n[3];return{point:new t.Point(n[0]/i,n[1]/i),signedDistanceFromCamera:i}}function Jt(t,e){var r=t[0]/t[3],n=t[1]/t[3];return r>=-e[0]&&r<=e[0]&&n>=-e[1]&&n<=e[1]}function Kt(e,r,n,i,a,o,s,l){var c=i?e.textSizeData:e.iconSizeData,u=t.evaluateSizeForZoom(c,n.transform.zoom),h=[256/n.width*2+1,256/n.height*2+1],f=i?e.text.dynamicLayoutVertexArray:e.icon.dynamicLayoutVertexArray;f.clear();for(var p=e.lineVertexArray,d=i?e.text.placedSymbolArray:e.icon.placedSymbolArray,g=n.transform.width/n.transform.height,v=!1,m=0;m<d.length;m++){var y=d.get(m);if(y.hidden||y.writingMode===t.WritingMode.vertical&&!v)ie(y.numGlyphs,f);else{v=!1;var x=[y.anchorX,y.anchorY,0,1];if(t.transformMat4(x,x,r),Jt(x,h)){var b=.5+x[3]/n.transform.cameraToCenterDistance*.5,_=t.evaluateSizeForFeature(c,u,y),w=s?_*b:_/b,k=new t.Point(y.anchorX,y.anchorY),T=Zt(k,a).point,A={},M=te(y,w,!1,l,r,a,o,e.glyphOffsetArray,p,f,T,k,A,g);v=M.useVertical,(M.notEnoughRoom||v||M.needsFlipping&&te(y,w,!0,l,r,a,o,e.glyphOffsetArray,p,f,T,k,A,g).notEnoughRoom)&&ie(y.numGlyphs,f)}else ie(y.numGlyphs,f)}}i?e.text.dynamicLayoutVertexBuffer.updateData(f):e.icon.dynamicLayoutVertexBuffer.updateData(f)}function $t(t,e,r,n,i,a,o,s,l,c,u,h){var f=s.glyphStartIndex+s.numGlyphs,p=s.lineStartIndex,d=s.lineStartIndex+s.lineLength,g=e.getoffsetX(s.glyphStartIndex),v=e.getoffsetX(f-1),m=re(t*g,r,n,i,a,o,s.segment,p,d,l,c,u,h);if(!m)return null;var y=re(t*v,r,n,i,a,o,s.segment,p,d,l,c,u,h);return y?{first:m,last:y}:null}function Qt(e,r,n,i){return e===t.WritingMode.horizontal&&Math.abs(n.y-r.y)>Math.abs(n.x-r.x)*i?{useVertical:!0}:(e===t.WritingMode.vertical?r.y<n.y:r.x>n.x)?{needsFlipping:!0}:null}function te(e,r,n,i,a,o,s,l,c,u,h,f,p,d){var g,v=r/24,m=e.lineOffsetX*v,y=e.lineOffsetY*v;if(e.numGlyphs>1){var x=e.glyphStartIndex+e.numGlyphs,b=e.lineStartIndex,_=e.lineStartIndex+e.lineLength,w=$t(v,l,m,y,n,h,f,e,c,o,p,!1);if(!w)return{notEnoughRoom:!0};var k=Zt(w.first.point,s).point,T=Zt(w.last.point,s).point;if(i&&!n){var A=Qt(e.writingMode,k,T,d);if(A)return A}g=[w.first];for(var M=e.glyphStartIndex+1;M<x-1;M++)g.push(re(v*l.getoffsetX(M),m,y,n,h,f,e.segment,b,_,c,o,p,!1));g.push(w.last)}else{if(i&&!n){var S=Zt(f,a).point,E=e.lineStartIndex+e.segment+1,C=new t.Point(c.getx(E),c.gety(E)),L=Zt(C,a),P=L.signedDistanceFromCamera>0?L.point:ee(f,C,S,1,a),O=Qt(e.writingMode,S,P,d);if(O)return O}var z=re(v*l.getoffsetX(e.glyphStartIndex),m,y,n,h,f,e.segment,e.lineStartIndex,e.lineStartIndex+e.lineLength,c,o,p,!1);if(!z)return{notEnoughRoom:!0};g=[z]}for(var I=0,D=g;I<D.length;I+=1){var R=D[I];t.addDynamicAttributes(u,R.point,R.angle)}return{}}function ee(t,e,r,n,i){var a=Zt(t.add(t.sub(e)._unit()),i).point,o=r.sub(a);return r.add(o._mult(n/o.mag()))}function re(e,r,n,i,a,o,s,l,c,u,h,f,p){var d=i?e-r:e+r,g=d>0?1:-1,v=0;i&&(g*=-1,v=Math.PI),g<0&&(v+=Math.PI);for(var m=g>0?l+s:l+s+1,y=m,x=a,b=a,_=0,w=0,k=Math.abs(d);_+w<=k;){if((m+=g)<l||m>=c)return null;if(b=x,void 0===(x=f[m])){var T=new t.Point(u.getx(m),u.gety(m)),A=Zt(T,h);if(A.signedDistanceFromCamera>0)x=f[m]=A.point;else{var M=m-g;x=ee(0===_?o:new t.Point(u.getx(M),u.gety(M)),T,b,k-_+1,h)}}_+=w,w=b.dist(x)}var S=(k-_)/w,E=x.sub(b),C=E.mult(S)._add(b);return C._add(E._unit()._perp()._mult(n*g)),{point:C,angle:v+Math.atan2(x.y-b.y,x.x-b.x),tileDistance:p?{prevTileDistance:m-g===y?0:u.gettileUnitDistanceFromAnchor(m-g),lastSegmentViewportDistance:k-_}:null}}Yt.prototype.keysLength=function(){return this.boxKeys.length+this.circleKeys.length},Yt.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertBoxCell,this.boxUid++),this.boxKeys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},Yt.prototype.insertCircle=function(t,e,r,n){this._forEachCell(e-n,r-n,e+n,r+n,this._insertCircleCell,this.circleUid++),this.circleKeys.push(t),this.circles.push(e),this.circles.push(r),this.circles.push(n)},Yt.prototype._insertBoxCell=function(t,e,r,n,i,a){this.boxCells[i].push(a)},Yt.prototype._insertCircleCell=function(t,e,r,n,i,a){this.circleCells[i].push(a)},Yt.prototype._query=function(t,e,r,n,i,a){if(r<0||t>this.width||n<0||e>this.height)return!i&&[];var o=[];if(t<=0&&e<=0&&this.width<=r&&this.height<=n){if(i)return!0;for(var s=0;s<this.boxKeys.length;s++)o.push({key:this.boxKeys[s],x1:this.bboxes[4*s],y1:this.bboxes[4*s+1],x2:this.bboxes[4*s+2],y2:this.bboxes[4*s+3]});for(var l=0;l<this.circleKeys.length;l++){var c=this.circles[3*l],u=this.circles[3*l+1],h=this.circles[3*l+2];o.push({key:this.circleKeys[l],x1:c-h,y1:u-h,x2:c+h,y2:u+h})}return a?o.filter(a):o}var f={hitTest:i,seenUids:{box:{},circle:{}}};return this._forEachCell(t,e,r,n,this._queryCell,o,f,a),i?o.length>0:o},Yt.prototype._queryCircle=function(t,e,r,n,i){var a=t-r,o=t+r,s=e-r,l=e+r;if(o<0||a>this.width||l<0||s>this.height)return!n&&[];var c=[],u={hitTest:n,circle:{x:t,y:e,radius:r},seenUids:{box:{},circle:{}}};return this._forEachCell(a,s,o,l,this._queryCellCircle,c,u,i),n?c.length>0:c},Yt.prototype.query=function(t,e,r,n,i){return this._query(t,e,r,n,!1,i)},Yt.prototype.hitTest=function(t,e,r,n,i){return this._query(t,e,r,n,!0,i)},Yt.prototype.hitTestCircle=function(t,e,r,n){return this._queryCircle(t,e,r,!0,n)},Yt.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=o.seenUids,c=this.boxCells[i];if(null!==c)for(var u=this.bboxes,h=0,f=c;h<f.length;h+=1){var p=f[h];if(!l.box[p]){l.box[p]=!0;var d=4*p;if(t<=u[d+2]&&e<=u[d+3]&&r>=u[d+0]&&n>=u[d+1]&&(!s||s(this.boxKeys[p]))){if(o.hitTest)return a.push(!0),!0;a.push({key:this.boxKeys[p],x1:u[d],y1:u[d+1],x2:u[d+2],y2:u[d+3]})}}}var g=this.circleCells[i];if(null!==g)for(var v=this.circles,m=0,y=g;m<y.length;m+=1){var x=y[m];if(!l.circle[x]){l.circle[x]=!0;var b=3*x;if(this._circleAndRectCollide(v[b],v[b+1],v[b+2],t,e,r,n)&&(!s||s(this.circleKeys[x]))){if(o.hitTest)return a.push(!0),!0;var _=v[b],w=v[b+1],k=v[b+2];a.push({key:this.circleKeys[x],x1:_-k,y1:w-k,x2:_+k,y2:w+k})}}}},Yt.prototype._queryCellCircle=function(t,e,r,n,i,a,o,s){var l=o.circle,c=o.seenUids,u=this.boxCells[i];if(null!==u)for(var h=this.bboxes,f=0,p=u;f<p.length;f+=1){var d=p[f];if(!c.box[d]){c.box[d]=!0;var g=4*d;if(this._circleAndRectCollide(l.x,l.y,l.radius,h[g+0],h[g+1],h[g+2],h[g+3])&&(!s||s(this.boxKeys[d])))return a.push(!0),!0}}var v=this.circleCells[i];if(null!==v)for(var m=this.circles,y=0,x=v;y<x.length;y+=1){var b=x[y];if(!c.circle[b]){c.circle[b]=!0;var _=3*b;if(this._circlesCollide(m[_],m[_+1],m[_+2],l.x,l.y,l.radius)&&(!s||s(this.circleKeys[b])))return a.push(!0),!0}}},Yt.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToXCellCoord(t),c=this._convertToYCellCoord(e),u=this._convertToXCellCoord(r),h=this._convertToYCellCoord(n),f=l;f<=u;f++)for(var p=c;p<=h;p++){var d=this.xCellCount*p+f;if(i.call(this,t,e,r,n,d,a,o,s))return}},Yt.prototype._convertToXCellCoord=function(t){return Math.max(0,Math.min(this.xCellCount-1,Math.floor(t*this.xScale)))},Yt.prototype._convertToYCellCoord=function(t){return Math.max(0,Math.min(this.yCellCount-1,Math.floor(t*this.yScale)))},Yt.prototype._circlesCollide=function(t,e,r,n,i,a){var o=n-t,s=i-e,l=r+a;return l*l>o*o+s*s},Yt.prototype._circleAndRectCollide=function(t,e,r,n,i,a,o){var s=(a-n)/2,l=Math.abs(t-(n+s));if(l>s+r)return!1;var c=(o-i)/2,u=Math.abs(e-(i+c));if(u>c+r)return!1;if(l<=s||u<=c)return!0;var h=l-s,f=u-c;return h*h+f*f<=r*r};var ne=new Float32Array([-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0]);function ie(t,e){for(var r=0;r<t;r++){var n=e.length;e.resize(n+4),e.float32.set(ne,3*n)}}function ae(t,e,r){var n=e[0],i=e[1];return t[0]=r[0]*n+r[4]*i+r[12],t[1]=r[1]*n+r[5]*i+r[13],t[3]=r[3]*n+r[7]*i+r[15],t}var oe=function(t,e,r){void 0===e&&(e=new Yt(t.width+200,t.height+200,25)),void 0===r&&(r=new Yt(t.width+200,t.height+200,25)),this.transform=t,this.grid=e,this.ignoredGrid=r,this.pitchfactor=Math.cos(t._pitch)*t.cameraToCenterDistance,this.screenRightBoundary=t.width+100,this.screenBottomBoundary=t.height+100,this.gridRightBoundary=t.width+200,this.gridBottomBoundary=t.height+200};function se(t,e,r){t[e+4]=r?1:0}function le(e,r,n){return r*(t.EXTENT/(e.tileSize*Math.pow(2,n-e.tileID.overscaledZ)))}oe.prototype.placeCollisionBox=function(t,e,r,n,i){var a=this.projectAndGetPerspectiveRatio(n,t.anchorPointX,t.anchorPointY),o=r*a.perspectiveRatio,s=t.x1*o+a.point.x,l=t.y1*o+a.point.y,c=t.x2*o+a.point.x,u=t.y2*o+a.point.y;return!this.isInsideGrid(s,l,c,u)||!e&&this.grid.hitTest(s,l,c,u,i)?{box:[],offscreen:!1}:{box:[s,l,c,u],offscreen:this.isOffscreen(s,l,c,u)}},oe.prototype.approximateTileDistance=function(t,e,r,n,i){var a=i?1:n/this.pitchfactor,o=t.lastSegmentViewportDistance*r;return t.prevTileDistance+o+(a-1)*o*Math.abs(Math.sin(e))},oe.prototype.placeCollisionCircles=function(e,r,n,i,a,o,s,l,c,u,h,f,p){var d=[],g=this.projectAnchor(c,a.anchorX,a.anchorY),v=l/24,m=a.lineOffsetX*l,y=a.lineOffsetY*l,x=new t.Point(a.anchorX,a.anchorY),b=$t(v,s,m,y,!1,Zt(x,u).point,x,a,o,u,{},!0),_=!1,w=!1,k=!0,T=g.perspectiveRatio*i,A=1/(i*n),M=0,S=0;b&&(M=this.approximateTileDistance(b.first.tileDistance,b.first.angle,A,g.cameraDistance,f),S=this.approximateTileDistance(b.last.tileDistance,b.last.angle,A,g.cameraDistance,f));for(var E=0;E<e.length;E+=5){var C=e[E],L=e[E+1],P=e[E+2],O=e[E+3];if(!b||O<-M||O>S)se(e,E,!1);else{var z=this.projectPoint(c,C,L),I=P*T;if(d.length>0){var D=z.x-d[d.length-4],R=z.y-d[d.length-3];if(I*I*2>D*D+R*R&&E+8<e.length){var F=e[E+8];if(F>-M&&F<S){se(e,E,!1);continue}}}var B=E/5;d.push(z.x,z.y,I,B),se(e,E,!0);var N=z.x-I,j=z.y-I,U=z.x+I,V=z.y+I;if(k=k&&this.isOffscreen(N,j,U,V),w=w||this.isInsideGrid(N,j,U,V),!r&&this.grid.hitTestCircle(z.x,z.y,I,p)){if(!h)return{circles:[],offscreen:!1};_=!0}}}return{circles:_||!w?[]:d,offscreen:k}},oe.prototype.queryRenderedSymbols=function(e){if(0===e.length||0===this.grid.keysLength()&&0===this.ignoredGrid.keysLength())return{};for(var r=[],n=1/0,i=1/0,a=-1/0,o=-1/0,s=0,l=e;s<l.length;s+=1){var c=l[s],u=new t.Point(c.x+100,c.y+100);n=Math.min(n,u.x),i=Math.min(i,u.y),a=Math.max(a,u.x),o=Math.max(o,u.y),r.push(u)}for(var h={},f={},p=0,d=this.grid.query(n,i,a,o).concat(this.ignoredGrid.query(n,i,a,o));p<d.length;p+=1){var g=d[p],v=g.key;if(void 0===h[v.bucketInstanceId]&&(h[v.bucketInstanceId]={}),!h[v.bucketInstanceId][v.featureIndex]){var m=[new t.Point(g.x1,g.y1),new t.Point(g.x2,g.y1),new t.Point(g.x2,g.y2),new t.Point(g.x1,g.y2)];t.polygonIntersectsPolygon(r,m)&&(h[v.bucketInstanceId][v.featureIndex]=!0,void 0===f[v.bucketInstanceId]&&(f[v.bucketInstanceId]=[]),f[v.bucketInstanceId].push(v.featureIndex))}}return f},oe.prototype.insertCollisionBox=function(t,e,r,n,i){var a={bucketInstanceId:r,featureIndex:n,collisionGroupID:i};(e?this.ignoredGrid:this.grid).insert(a,t[0],t[1],t[2],t[3])},oe.prototype.insertCollisionCircles=function(t,e,r,n,i){for(var a=e?this.ignoredGrid:this.grid,o={bucketInstanceId:r,featureIndex:n,collisionGroupID:i},s=0;s<t.length;s+=4)a.insertCircle(o,t[s],t[s+1],t[s+2])},oe.prototype.projectAnchor=function(t,e,r){var n=[e,r,0,1];return ae(n,n,t),{perspectiveRatio:.5+this.transform.cameraToCenterDistance/n[3]*.5,cameraDistance:n[3]}},oe.prototype.projectPoint=function(e,r,n){var i=[r,n,0,1];return ae(i,i,e),new t.Point((i[0]/i[3]+1)/2*this.transform.width+100,(-i[1]/i[3]+1)/2*this.transform.height+100)},oe.prototype.projectAndGetPerspectiveRatio=function(e,r,n){var i=[r,n,0,1];return ae(i,i,e),{point:new t.Point((i[0]/i[3]+1)/2*this.transform.width+100,(-i[1]/i[3]+1)/2*this.transform.height+100),perspectiveRatio:.5+this.transform.cameraToCenterDistance/i[3]*.5}},oe.prototype.isOffscreen=function(t,e,r,n){return r<100||t>=this.screenRightBoundary||n<100||e>this.screenBottomBoundary},oe.prototype.isInsideGrid=function(t,e,r,n){return r>=0&&t<this.gridRightBoundary&&n>=0&&e<this.gridBottomBoundary};var ce=function(t,e,r,n){this.opacity=t?Math.max(0,Math.min(1,t.opacity+(t.placed?e:-e))):n&&r?1:0,this.placed=r};ce.prototype.isHidden=function(){return 0===this.opacity&&!this.placed};var ue=function(t,e,r,n,i){this.text=new ce(t?t.text:null,e,r,i),this.icon=new ce(t?t.icon:null,e,n,i)};ue.prototype.isHidden=function(){return this.text.isHidden()&&this.icon.isHidden()};var he=function(t,e,r){this.text=t,this.icon=e,this.skipFade=r},fe=function(t,e,r,n,i){this.bucketInstanceId=t,this.featureIndex=e,this.sourceLayerIndex=r,this.bucketIndex=n,this.tileID=i},pe=function(t){this.crossSourceCollisions=t,this.maxGroupID=0,this.collisionGroups={}};function de(e,r,n,i,a){var o=t.getAnchorAlignment(e),s=-(o.horizontalAlign-.5)*r,l=-(o.verticalAlign-.5)*n,c=t.evaluateRadialOffset(e,i);return new t.Point(s+c[0]*a,l+c[1]*a)}pe.prototype.get=function(t){if(this.crossSourceCollisions)return{ID:0,predicate:null};if(!this.collisionGroups[t]){var e=++this.maxGroupID;this.collisionGroups[t]={ID:e,predicate:function(t){return t.collisionGroupID===e}}}return this.collisionGroups[t]};var ge=function(t,e,r,n){this.transform=t.clone(),this.collisionIndex=new oe(this.transform),this.placements={},this.opacities={},this.variableOffsets={},this.stale=!1,this.commitTime=0,this.fadeDuration=e,this.retainedQueryData={},this.collisionGroups=new pe(r),this.prevPlacement=n,n&&(n.prevPlacement=void 0)};function ve(t,e,r,n,i){t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0)}ge.prototype.placeLayerTile=function(e,r,n,i){var a=r.getBucket(e),o=r.latestFeatureIndex;if(a&&o&&e.id===a.layerIds[0]){var s=r.collisionBoxArray,l=a.layers[0].layout,c=Math.pow(2,this.transform.zoom-r.tileID.overscaledZ),u=r.tileSize/t.EXTENT,h=this.transform.calculatePosMatrix(r.tileID.toUnwrapped()),f=Wt(h,\"map\"===l.get(\"text-pitch-alignment\"),\"map\"===l.get(\"text-rotation-alignment\"),this.transform,le(r,1,this.transform.zoom)),p=Wt(h,\"map\"===l.get(\"icon-pitch-alignment\"),\"map\"===l.get(\"icon-rotation-alignment\"),this.transform,le(r,1,this.transform.zoom));this.retainedQueryData[a.bucketInstanceId]=new fe(a.bucketInstanceId,o,a.sourceLayerIndex,a.index,r.tileID),this.placeLayerBucket(a,h,f,p,c,u,n,r.holdingForFade(),i,s)}},ge.prototype.attemptAnchorPlacement=function(e,r,n,i,a,o,s,l,c,u,h,f,p,d){var g,v=de(e,n,i,a,o),m=this.collisionIndex.placeCollisionBox(function(e,r,n,i,a,o){var s=e.x1,l=e.x2,c=e.y1,u=e.y2,h=e.anchorPointX,f=e.anchorPointY,p=new t.Point(r,n);return i&&p._rotate(a?o:-o),{x1:s+p.x,y1:c+p.y,x2:l+p.x,y2:u+p.y,anchorPointX:h,anchorPointY:f}}(r,v.x,v.y,s,l,this.transform.angle),f,c,u,h.predicate);if(m.box.length>0)return this.prevPlacement&&this.prevPlacement.variableOffsets[p.crossTileID]&&this.prevPlacement.placements[p.crossTileID]&&this.prevPlacement.placements[p.crossTileID].text&&(g=this.prevPlacement.variableOffsets[p.crossTileID].anchor),this.variableOffsets[p.crossTileID]={radialOffset:a,width:n,height:i,anchor:e,textBoxScale:o,prevAnchor:g},this.markUsedJustification(d,e,p),m},ge.prototype.placeLayerBucket=function(e,r,n,i,a,o,s,l,c,u){var h=this,f=e.layers[0].layout,p=t.evaluateSizeForZoom(e.textSizeData,this.transform.zoom),d=f.get(\"text-optional\"),g=f.get(\"icon-optional\"),v=f.get(\"text-allow-overlap\"),m=f.get(\"icon-allow-overlap\"),y=v&&(m||!e.hasIconData()||g),x=m&&(v||!e.hasTextData()||d),b=this.collisionGroups.get(e.sourceID),_=\"map\"===f.get(\"text-rotation-alignment\"),w=\"map\"===f.get(\"text-pitch-alignment\"),k=\"viewport-y\"===f.get(\"symbol-z-order\");!e.collisionArrays&&u&&e.deserializeCollisionBoxes(u);var T=function(i,u){if(!c[i.crossTileID])if(l)h.placements[i.crossTileID]=new he(!1,!1,!1);else{var m=!1,k=!1,T=!0,A=null,M=null,S=null,E=0,C=0;u.textFeatureIndex&&(E=u.textFeatureIndex);var L=u.textBox;if(L)if(f.get(\"text-variable-anchor\")){var P=L.x2-L.x1,O=L.y2-L.y1,z=i.textBoxScale,I=f.get(\"text-variable-anchor\");if(h.prevPlacement&&h.prevPlacement.variableOffsets[i.crossTileID]){var D=h.prevPlacement.variableOffsets[i.crossTileID];I[0]!==D.anchor&&(I=I.filter(function(t){return t!==D.anchor})).unshift(D.anchor)}for(var R=0,F=I;R<F.length;R+=1){var B=F[R];if(A=h.attemptAnchorPlacement(B,L,P,O,i.radialTextOffset,z,_,w,o,r,b,v,i,e)){m=!0;break}}if(!h.variableOffsets[i.crossTileID]&&h.prevPlacement){var N=h.prevPlacement.variableOffsets[i.crossTileID];N&&(h.variableOffsets[i.crossTileID]=N,h.markUsedJustification(e,N.anchor,i))}}else m=(A=h.collisionIndex.placeCollisionBox(L,f.get(\"text-allow-overlap\"),o,r,b.predicate)).box.length>0;T=A&&A.offscreen;var j=u.textCircles;if(j){var U=e.text.placedSymbolArray.get(i.centerJustifiedTextSymbolIndex),V=t.evaluateSizeForFeature(e.textSizeData,p,U);M=h.collisionIndex.placeCollisionCircles(j,f.get(\"text-allow-overlap\"),a,o,U,e.lineVertexArray,e.glyphOffsetArray,V,r,n,s,w,b.predicate),m=f.get(\"text-allow-overlap\")||M.circles.length>0,T=T&&M.offscreen}u.iconFeatureIndex&&(C=u.iconFeatureIndex),u.iconBox&&(k=(S=h.collisionIndex.placeCollisionBox(u.iconBox,f.get(\"icon-allow-overlap\"),o,r,b.predicate)).box.length>0,T=T&&S.offscreen);var q=d||0===i.numHorizontalGlyphVertices&&0===i.numVerticalGlyphVertices,H=g||0===i.numIconVertices;q||H?H?q||(k=k&&m):m=k&&m:k=m=k&&m,m&&A&&h.collisionIndex.insertCollisionBox(A.box,f.get(\"text-ignore-placement\"),e.bucketInstanceId,E,b.ID),k&&S&&h.collisionIndex.insertCollisionBox(S.box,f.get(\"icon-ignore-placement\"),e.bucketInstanceId,C,b.ID),m&&M&&h.collisionIndex.insertCollisionCircles(M.circles,f.get(\"text-ignore-placement\"),e.bucketInstanceId,E,b.ID),h.placements[i.crossTileID]=new he(m||y,k||x,T||e.justReloaded),c[i.crossTileID]=!0}};if(k)for(var A=e.getSortedSymbolIndexes(this.transform.angle),M=A.length-1;M>=0;--M){var S=A[M];T(e.symbolInstances.get(S),e.collisionArrays[S])}else for(var E=0;E<e.symbolInstances.length;++E)T(e.symbolInstances.get(E),e.collisionArrays[E]);e.justReloaded=!1},ge.prototype.markUsedJustification=function(e,r,n){var i={left:n.leftJustifiedTextSymbolIndex,center:n.centerJustifiedTextSymbolIndex,right:n.rightJustifiedTextSymbolIndex},a=i[t.getAnchorJustification(r)];for(var o in i){var s=i[o];s>=0&&(e.text.placedSymbolArray.get(s).crossTileID=a>=0&&s!==a?0:n.crossTileID)}},ge.prototype.commit=function(t){this.commitTime=t;var e=this.prevPlacement,r=!1,n=e&&0!==this.fadeDuration?(this.commitTime-e.commitTime)/this.fadeDuration:1,i=e?e.opacities:{},a=e?e.variableOffsets:{};for(var o in this.placements){var s=this.placements[o],l=i[o];l?(this.opacities[o]=new ue(l,n,s.text,s.icon),r=r||s.text!==l.text.placed||s.icon!==l.icon.placed):(this.opacities[o]=new ue(null,n,s.text,s.icon,s.skipFade),r=r||s.text||s.icon)}for(var c in i){var u=i[c];if(!this.opacities[c]){var h=new ue(u,n,!1,!1);h.isHidden()||(this.opacities[c]=h,r=r||u.text.placed||u.icon.placed)}}for(var f in a)this.variableOffsets[f]||!this.opacities[f]||this.opacities[f].isHidden()||(this.variableOffsets[f]=a[f]);r?this.lastPlacementChangeTime=t:\"number\"!=typeof this.lastPlacementChangeTime&&(this.lastPlacementChangeTime=e?e.lastPlacementChangeTime:t)},ge.prototype.updateLayerOpacities=function(t,e){for(var r={},n=0,i=e;n<i.length;n+=1){var a=i[n],o=a.getBucket(t);o&&a.latestFeatureIndex&&t.id===o.layerIds[0]&&this.updateBucketOpacities(o,r,a.collisionBoxArray)}},ge.prototype.updateBucketOpacities=function(e,r,n){e.hasTextData()&&e.text.opacityVertexArray.clear(),e.hasIconData()&&e.icon.opacityVertexArray.clear(),e.hasCollisionBoxData()&&e.collisionBox.collisionVertexArray.clear(),e.hasCollisionCircleData()&&e.collisionCircle.collisionVertexArray.clear();var i=e.layers[0].layout,a=new ue(null,0,!1,!1,!0),o=i.get(\"text-allow-overlap\"),s=i.get(\"icon-allow-overlap\"),l=i.get(\"text-variable-anchor\"),c=\"map\"===i.get(\"text-rotation-alignment\"),u=\"map\"===i.get(\"text-pitch-alignment\"),h=new ue(null,0,o&&(s||!e.hasIconData()||i.get(\"icon-optional\")),s&&(o||!e.hasTextData()||i.get(\"text-optional\")),!0);!e.collisionArrays&&n&&(e.hasCollisionBoxData()||e.hasCollisionCircleData())&&e.deserializeCollisionBoxes(n);for(var f=0;f<e.symbolInstances.length;f++){var p=e.symbolInstances.get(f),d=p.numHorizontalGlyphVertices,g=p.numVerticalGlyphVertices,v=p.crossTileID,m=r[v],y=this.opacities[v];m?y=a:y||(y=h,this.opacities[v]=y),r[v]=!0;var x=d>0||g>0,b=p.numIconVertices>0;if(x){for(var _=Te(y.text),w=(d+g)/4,k=0;k<w;k++)e.text.opacityVertexArray.emplaceBack(_);var T=y.text.isHidden()?1:0;[p.rightJustifiedTextSymbolIndex,p.centerJustifiedTextSymbolIndex,p.leftJustifiedTextSymbolIndex,p.verticalPlacedTextSymbolIndex].forEach(function(t){t>=0&&(e.text.placedSymbolArray.get(t).hidden=T)});var A=this.variableOffsets[p.crossTileID];A&&this.markUsedJustification(e,A.anchor,p)}if(b){for(var M=Te(y.icon),S=0;S<p.numIconVertices/4;S++)e.icon.opacityVertexArray.emplaceBack(M);e.icon.placedSymbolArray.get(f).hidden=y.icon.isHidden()}if(e.hasCollisionBoxData()||e.hasCollisionCircleData()){var E=e.collisionArrays[f];if(E){if(E.textBox){var C=new t.Point(0,0),L=!0;if(l){var P=this.variableOffsets[v];P?(C=de(P.anchor,P.width,P.height,P.radialOffset,P.textBoxScale),c&&C._rotate(u?this.transform.angle:-this.transform.angle)):L=!1}ve(e.collisionBox.collisionVertexArray,y.text.placed,!L,C.x,C.y)}E.iconBox&&ve(e.collisionBox.collisionVertexArray,y.icon.placed,!1);var O=E.textCircles;if(O&&e.hasCollisionCircleData())for(var z=0;z<O.length;z+=5){var I=m||0===O[z+4];ve(e.collisionCircle.collisionVertexArray,y.text.placed,I)}}}}e.sortFeatures(this.transform.angle),this.retainedQueryData[e.bucketInstanceId]&&(this.retainedQueryData[e.bucketInstanceId].featureSortOrder=e.featureSortOrder),e.hasTextData()&&e.text.opacityVertexBuffer&&e.text.opacityVertexBuffer.updateData(e.text.opacityVertexArray),e.hasIconData()&&e.icon.opacityVertexBuffer&&e.icon.opacityVertexBuffer.updateData(e.icon.opacityVertexArray),e.hasCollisionBoxData()&&e.collisionBox.collisionVertexBuffer&&e.collisionBox.collisionVertexBuffer.updateData(e.collisionBox.collisionVertexArray),e.hasCollisionCircleData()&&e.collisionCircle.collisionVertexBuffer&&e.collisionCircle.collisionVertexBuffer.updateData(e.collisionCircle.collisionVertexArray)},ge.prototype.symbolFadeChange=function(t){return 0===this.fadeDuration?1:(t-this.commitTime)/this.fadeDuration},ge.prototype.hasTransitions=function(t){return this.stale||t-this.lastPlacementChangeTime<this.fadeDuration},ge.prototype.stillRecent=function(t){return this.commitTime+this.fadeDuration>t},ge.prototype.setStale=function(){this.stale=!0};var me=Math.pow(2,25),ye=Math.pow(2,24),xe=Math.pow(2,17),be=Math.pow(2,16),_e=Math.pow(2,9),we=Math.pow(2,8),ke=Math.pow(2,1);function Te(t){if(0===t.opacity&&!t.placed)return 0;if(1===t.opacity&&t.placed)return 4294967295;var e=t.placed?1:0,r=Math.floor(127*t.opacity);return r*me+e*ye+r*xe+e*be+r*_e+e*we+r*ke+e}var Ae=function(){this._currentTileIndex=0,this._seenCrossTileIDs={}};Ae.prototype.continuePlacement=function(t,e,r,n,i){for(;this._currentTileIndex<t.length;){var a=t[this._currentTileIndex];if(e.placeLayerTile(n,a,r,this._seenCrossTileIDs),this._currentTileIndex++,i())return!0}};var Me=function(t,e,r,n,i,a,o){this.placement=new ge(t,i,a,o),this._currentPlacementIndex=e.length-1,this._forceFullPlacement=r,this._showCollisionBoxes=n,this._done=!1};Me.prototype.isDone=function(){return this._done},Me.prototype.continuePlacement=function(e,r,n){for(var i=this,a=t.browser.now(),o=function(){var e=t.browser.now()-a;return!i._forceFullPlacement&&e>2};this._currentPlacementIndex>=0;){var s=r[e[this._currentPlacementIndex]],l=this.placement.collisionIndex.transform.zoom;if(\"symbol\"===s.type&&(!s.minzoom||s.minzoom<=l)&&(!s.maxzoom||s.maxzoom>l)){if(this._inProgressLayer||(this._inProgressLayer=new Ae),this._inProgressLayer.continuePlacement(n[s.source],this.placement,this._showCollisionBoxes,s,o))return;delete this._inProgressLayer}this._currentPlacementIndex--}this._done=!0},Me.prototype.commit=function(t){return this.placement.commit(t),this.placement};var Se=512/t.EXTENT/2,Ee=function(t,e,r){this.tileID=t,this.indexedSymbolInstances={},this.bucketInstanceId=r;for(var n=0;n<e.length;n++){var i=e.get(n),a=i.key;this.indexedSymbolInstances[a]||(this.indexedSymbolInstances[a]=[]),this.indexedSymbolInstances[a].push({crossTileID:i.crossTileID,coord:this.getScaledCoordinates(i,t)})}};Ee.prototype.getScaledCoordinates=function(e,r){var n=r.canonical.z-this.tileID.canonical.z,i=Se/Math.pow(2,n);return{x:Math.floor((r.canonical.x*t.EXTENT+e.anchorX)*i),y:Math.floor((r.canonical.y*t.EXTENT+e.anchorY)*i)}},Ee.prototype.findMatches=function(t,e,r){for(var n=this.tileID.canonical.z<e.canonical.z?1:Math.pow(2,this.tileID.canonical.z-e.canonical.z),i=0;i<t.length;i++){var a=t.get(i);if(!a.crossTileID){var o=this.indexedSymbolInstances[a.key];if(o)for(var s=this.getScaledCoordinates(a,e),l=0,c=o;l<c.length;l+=1){var u=c[l];if(Math.abs(u.coord.x-s.x)<=n&&Math.abs(u.coord.y-s.y)<=n&&!r[u.crossTileID]){r[u.crossTileID]=!0,a.crossTileID=u.crossTileID;break}}}}};var Ce=function(){this.maxCrossTileID=0};Ce.prototype.generate=function(){return++this.maxCrossTileID};var Le=function(){this.indexes={},this.usedCrossTileIDs={},this.lng=0};Le.prototype.handleWrapJump=function(t){var e=Math.round((t-this.lng)/360);if(0!==e)for(var r in this.indexes){var n=this.indexes[r],i={};for(var a in n){var o=n[a];o.tileID=o.tileID.unwrapTo(o.tileID.wrap+e),i[o.tileID.key]=o}this.indexes[r]=i}this.lng=t},Le.prototype.addBucket=function(t,e,r){if(this.indexes[t.overscaledZ]&&this.indexes[t.overscaledZ][t.key]){if(this.indexes[t.overscaledZ][t.key].bucketInstanceId===e.bucketInstanceId)return!1;this.removeBucketCrossTileIDs(t.overscaledZ,this.indexes[t.overscaledZ][t.key])}for(var n=0;n<e.symbolInstances.length;n++)e.symbolInstances.get(n).crossTileID=0;this.usedCrossTileIDs[t.overscaledZ]||(this.usedCrossTileIDs[t.overscaledZ]={});var i=this.usedCrossTileIDs[t.overscaledZ];for(var a in this.indexes){var o=this.indexes[a];if(Number(a)>t.overscaledZ)for(var s in o){var l=o[s];l.tileID.isChildOf(t)&&l.findMatches(e.symbolInstances,t,i)}else{var c=o[t.scaledTo(Number(a)).key];c&&c.findMatches(e.symbolInstances,t,i)}}for(var u=0;u<e.symbolInstances.length;u++){var h=e.symbolInstances.get(u);h.crossTileID||(h.crossTileID=r.generate(),i[h.crossTileID]=!0)}return void 0===this.indexes[t.overscaledZ]&&(this.indexes[t.overscaledZ]={}),this.indexes[t.overscaledZ][t.key]=new Ee(t,e.symbolInstances,e.bucketInstanceId),!0},Le.prototype.removeBucketCrossTileIDs=function(t,e){for(var r in e.indexedSymbolInstances)for(var n=0,i=e.indexedSymbolInstances[r];n<i.length;n+=1){var a=i[n];delete this.usedCrossTileIDs[t][a.crossTileID]}},Le.prototype.removeStaleBuckets=function(t){var e=!1;for(var r in this.indexes){var n=this.indexes[r];for(var i in n)t[n[i].bucketInstanceId]||(this.removeBucketCrossTileIDs(r,n[i]),delete n[i],e=!0)}return e};var Pe=function(){this.layerIndexes={},this.crossTileIDs=new Ce,this.maxBucketInstanceId=0,this.bucketsInCurrentPlacement={}};Pe.prototype.addLayer=function(t,e,r){var n=this.layerIndexes[t.id];void 0===n&&(n=this.layerIndexes[t.id]=new Le);var i=!1,a={};n.handleWrapJump(r);for(var o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.getBucket(t);c&&t.id===c.layerIds[0]&&(c.bucketInstanceId||(c.bucketInstanceId=++this.maxBucketInstanceId),n.addBucket(l.tileID,c,this.crossTileIDs)&&(i=!0),a[c.bucketInstanceId]=!0)}return n.removeStaleBuckets(a)&&(i=!0),i},Pe.prototype.pruneUnusedLayers=function(t){var e={};for(var r in t.forEach(function(t){e[t]=!0}),this.layerIndexes)e[r]||delete this.layerIndexes[r]};var Oe=function(e,r){return t.emitValidationErrors(e,r&&r.filter(function(t){return\"source.canvas\"!==t.identifier}))},ze=t.pick(Bt,[\"addLayer\",\"removeLayer\",\"setPaintProperty\",\"setLayoutProperty\",\"setFilter\",\"addSource\",\"removeSource\",\"setLayerZoomRange\",\"setLight\",\"setTransition\",\"setGeoJSONSourceData\"]),Ie=t.pick(Bt,[\"setCenter\",\"setZoom\",\"setBearing\",\"setPitch\"]),De=function(e){function r(n,i){var a=this;void 0===i&&(i={}),e.call(this),this.map=n,this.dispatcher=new k((It||(It=new zt),It),this),this.imageManager=new f,this.imageManager.setEventedParent(this),this.glyphManager=new y(n._requestManager,i.localIdeographFontFamily),this.lineAtlas=new w(256,512),this.crossTileSymbolIndex=new Pe,this._layers={},this._order=[],this.sourceCaches={},this.zoomHistory=new t.ZoomHistory,this._loaded=!1,this._resetUpdates(),this.dispatcher.broadcast(\"setReferrer\",t.getReferrer());var o=this;this._rtlTextPluginCallback=r.registerForPluginAvailability(function(t){for(var e in o.dispatcher.broadcast(\"loadRTLTextPlugin\",t.pluginURL,t.completionCallback),o.sourceCaches)o.sourceCaches[e].reload()}),this.on(\"data\",function(t){if(\"source\"===t.dataType&&\"metadata\"===t.sourceDataType){var e=a.sourceCaches[t.sourceId];if(e){var r=e.getSource();if(r&&r.vectorLayerIds)for(var n in a._layers){var i=a._layers[n];i.source===r.id&&a._validateLayer(i)}}}})}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadURL=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"}));var i=\"boolean\"==typeof r.validate?r.validate:!t.isMapboxURL(e);e=this.map._requestManager.normalizeStyleURL(e,r.accessToken);var a=this.map._requestManager.transformRequest(e,t.ResourceType.Style);this._request=t.getJSON(a,function(e,r){n._request=null,e?n.fire(new t.ErrorEvent(e)):r&&n._load(r,i)})},r.prototype.loadJSON=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"})),this._request=t.browser.frame(function(){n._request=null,n._load(e,!1!==r.validate)})},r.prototype._load=function(e,r){var n=this;if(!r||!Oe(this,t.validateStyle(e))){for(var i in this._loaded=!0,this.stylesheet=e,e.sources)this.addSource(i,e.sources[i],{validate:!1});e.sprite?this._spriteRequest=function(e,r,n){var i,a,o,s=t.browser.devicePixelRatio>1?\"@2x\":\"\",l=t.getJSON(r.transformRequest(r.normalizeSpriteURL(e,s,\".json\"),t.ResourceType.SpriteJSON),function(t,e){l=null,o||(o=t,i=e,u())}),c=t.getImage(r.transformRequest(r.normalizeSpriteURL(e,s,\".png\"),t.ResourceType.SpriteImage),function(t,e){c=null,o||(o=t,a=e,u())});function u(){if(o)n(o);else if(i&&a){var e=t.browser.getImageData(a),r={};for(var s in i){var l=i[s],c=l.width,u=l.height,h=l.x,f=l.y,p=l.sdf,d=l.pixelRatio,g=new t.RGBAImage({width:c,height:u});t.RGBAImage.copy(e,g,{x:h,y:f},{x:0,y:0},{width:c,height:u}),r[s]={data:g,pixelRatio:d,sdf:p}}n(null,r)}}return{cancel:function(){l&&(l.cancel(),l=null),c&&(c.cancel(),c=null)}}}(e.sprite,this.map._requestManager,function(e,r){if(n._spriteRequest=null,e)n.fire(new t.ErrorEvent(e));else if(r)for(var i in r)n.imageManager.addImage(i,r[i]);n.imageManager.setLoaded(!0),n.fire(new t.Event(\"data\",{dataType:\"style\"}))}):this.imageManager.setLoaded(!0),this.glyphManager.setURL(e.glyphs);var a=Ft(this.stylesheet.layers);this._order=a.map(function(t){return t.id}),this._layers={};for(var o=0,s=a;o<s.length;o+=1){var l=s[o];(l=t.createStyleLayer(l)).setEventedParent(this,{layer:{id:l.id}}),this._layers[l.id]=l}this.dispatcher.broadcast(\"setLayers\",this._serializeLayers(this._order)),this.light=new _(this.stylesheet.light),this.fire(new t.Event(\"data\",{dataType:\"style\"})),this.fire(new t.Event(\"style.load\"))}},r.prototype._validateLayer=function(e){var r=this.sourceCaches[e.source];if(r){var n=e.sourceLayer;if(n){var i=r.getSource();(\"geojson\"===i.type||i.vectorLayerIds&&-1===i.vectorLayerIds.indexOf(n))&&this.fire(new t.ErrorEvent(new Error('Source layer \"'+n+'\" does not exist on source \"'+i.id+'\" as specified by style layer \"'+e.id+'\"')))}}},r.prototype.loaded=function(){if(!this._loaded)return!1;if(Object.keys(this._updatedSources).length)return!1;for(var t in this.sourceCaches)if(!this.sourceCaches[t].loaded())return!1;return!!this.imageManager.isLoaded()},r.prototype._serializeLayers=function(t){for(var e=[],r=0,n=t;r<n.length;r+=1){var i=n[r],a=this._layers[i];\"custom\"!==a.type&&e.push(a.serialize())}return e},r.prototype.hasTransitions=function(){if(this.light&&this.light.hasTransition())return!0;for(var t in this.sourceCaches)if(this.sourceCaches[t].hasTransition())return!0;for(var e in this._layers)if(this._layers[e].hasTransition())return!0;return!1},r.prototype._checkLoaded=function(){if(!this._loaded)throw new Error(\"Style is not done loading\")},r.prototype.update=function(e){if(this._loaded){var r=this._changed;if(this._changed){var n=Object.keys(this._updatedLayers),i=Object.keys(this._removedLayers);for(var a in(n.length||i.length)&&this._updateWorkerLayers(n,i),this._updatedSources){var o=this._updatedSources[a];\"reload\"===o?this._reloadSource(a):\"clear\"===o&&this._clearSource(a)}for(var s in this._updatedPaintProps)this._layers[s].updateTransitions(e);this.light.updateTransitions(e),this._resetUpdates()}for(var l in this.sourceCaches)this.sourceCaches[l].used=!1;for(var c=0,u=this._order;c<u.length;c+=1){var h=u[c],f=this._layers[h];f.recalculate(e),!f.isHidden(e.zoom)&&f.source&&(this.sourceCaches[f.source].used=!0)}this.light.recalculate(e),this.z=e.zoom,r&&this.fire(new t.Event(\"data\",{dataType:\"style\"}))}},r.prototype._updateWorkerLayers=function(t,e){this.dispatcher.broadcast(\"updateLayers\",{layers:this._serializeLayers(t),removedIds:e})},r.prototype._resetUpdates=function(){this._changed=!1,this._updatedLayers={},this._removedLayers={},this._updatedSources={},this._updatedPaintProps={}},r.prototype.setState=function(e){var r=this;if(this._checkLoaded(),Oe(this,t.validateStyle(e)))return!1;(e=t.clone$1(e)).layers=Ft(e.layers);var n=function(e,r){if(!e)return[{command:Bt.setStyle,args:[r]}];var n=[];try{if(!t.deepEqual(e.version,r.version))return[{command:Bt.setStyle,args:[r]}];t.deepEqual(e.center,r.center)||n.push({command:Bt.setCenter,args:[r.center]}),t.deepEqual(e.zoom,r.zoom)||n.push({command:Bt.setZoom,args:[r.zoom]}),t.deepEqual(e.bearing,r.bearing)||n.push({command:Bt.setBearing,args:[r.bearing]}),t.deepEqual(e.pitch,r.pitch)||n.push({command:Bt.setPitch,args:[r.pitch]}),t.deepEqual(e.sprite,r.sprite)||n.push({command:Bt.setSprite,args:[r.sprite]}),t.deepEqual(e.glyphs,r.glyphs)||n.push({command:Bt.setGlyphs,args:[r.glyphs]}),t.deepEqual(e.transition,r.transition)||n.push({command:Bt.setTransition,args:[r.transition]}),t.deepEqual(e.light,r.light)||n.push({command:Bt.setLight,args:[r.light]});var i={},a=[];!function(e,r,n,i){var a;for(a in r=r||{},e=e||{})e.hasOwnProperty(a)&&(r.hasOwnProperty(a)||jt(a,n,i));for(a in r)r.hasOwnProperty(a)&&(e.hasOwnProperty(a)?t.deepEqual(e[a],r[a])||(\"geojson\"===e[a].type&&\"geojson\"===r[a].type&&Vt(e,r,a)?n.push({command:Bt.setGeoJSONSourceData,args:[a,r[a].data]}):Ut(a,r,n,i)):Nt(a,r,n))}(e.sources,r.sources,a,i);var o=[];e.layers&&e.layers.forEach(function(t){i[t.source]?n.push({command:Bt.removeLayer,args:[t.id]}):o.push(t)}),n=n.concat(a),function(e,r,n){r=r||[];var i,a,o,s,l,c,u,h=(e=e||[]).map(Ht),f=r.map(Ht),p=e.reduce(Gt,{}),d=r.reduce(Gt,{}),g=h.slice(),v=Object.create(null);for(i=0,a=0;i<h.length;i++)o=h[i],d.hasOwnProperty(o)?a++:(n.push({command:Bt.removeLayer,args:[o]}),g.splice(g.indexOf(o,a),1));for(i=0,a=0;i<f.length;i++)o=f[f.length-1-i],g[g.length-1-i]!==o&&(p.hasOwnProperty(o)?(n.push({command:Bt.removeLayer,args:[o]}),g.splice(g.lastIndexOf(o,g.length-a),1)):a++,c=g[g.length-i],n.push({command:Bt.addLayer,args:[d[o],c]}),g.splice(g.length-i,0,o),v[o]=!0);for(i=0;i<f.length;i++)if(s=p[o=f[i]],l=d[o],!v[o]&&!t.deepEqual(s,l))if(t.deepEqual(s.source,l.source)&&t.deepEqual(s[\"source-layer\"],l[\"source-layer\"])&&t.deepEqual(s.type,l.type)){for(u in qt(s.layout,l.layout,n,o,null,Bt.setLayoutProperty),qt(s.paint,l.paint,n,o,null,Bt.setPaintProperty),t.deepEqual(s.filter,l.filter)||n.push({command:Bt.setFilter,args:[o,l.filter]}),t.deepEqual(s.minzoom,l.minzoom)&&t.deepEqual(s.maxzoom,l.maxzoom)||n.push({command:Bt.setLayerZoomRange,args:[o,l.minzoom,l.maxzoom]}),s)s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?qt(s[u],l[u],n,o,u.slice(6),Bt.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Bt.setLayerProperty,args:[o,u,l[u]]}));for(u in l)l.hasOwnProperty(u)&&!s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?qt(s[u],l[u],n,o,u.slice(6),Bt.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Bt.setLayerProperty,args:[o,u,l[u]]}))}else n.push({command:Bt.removeLayer,args:[o]}),c=g[g.lastIndexOf(o)+1],n.push({command:Bt.addLayer,args:[l,c]})}(o,r.layers,n)}catch(t){console.warn(\"Unable to compute style diff:\",t),n=[{command:Bt.setStyle,args:[r]}]}return n}(this.serialize(),e).filter(function(t){return!(t.command in Ie)});if(0===n.length)return!1;var i=n.filter(function(t){return!(t.command in ze)});if(i.length>0)throw new Error(\"Unimplemented: \"+i.map(function(t){return t.command}).join(\", \")+\".\");return n.forEach(function(t){\"setTransition\"!==t.command&&r[t.command].apply(r,t.args)}),this.stylesheet=e,!0},r.prototype.addImage=function(e,r){if(this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"An image with this name already exists.\")));this.imageManager.addImage(e,r),this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.updateImage=function(t,e){this.imageManager.updateImage(t,e)},r.prototype.getImage=function(t){return this.imageManager.getImage(t)},r.prototype.removeImage=function(e){if(!this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"No image with this name exists.\")));this.imageManager.removeImage(e),this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.listImages=function(){return this._checkLoaded(),this.imageManager.listImages()},r.prototype.addSource=function(e,r,n){var i=this;if(void 0===n&&(n={}),this._checkLoaded(),void 0!==this.sourceCaches[e])throw new Error(\"There is already a source with this ID\");if(!r.type)throw new Error(\"The type property must be defined, but the only the following properties were given: \"+Object.keys(r).join(\", \")+\".\");if(!([\"vector\",\"raster\",\"geojson\",\"video\",\"image\"].indexOf(r.type)>=0&&this._validate(t.validateStyle.source,\"sources.\"+e,r,null,n))){this.map&&this.map._collectResourceTiming&&(r.collectResourceTiming=!0);var a=this.sourceCaches[e]=new Ct(e,r,this.dispatcher);a.style=this,a.setEventedParent(this,function(){return{isSourceLoaded:i.loaded(),source:a.serialize(),sourceId:e}}),a.onAdd(this.map),this._changed=!0}},r.prototype.removeSource=function(e){if(this._checkLoaded(),void 0===this.sourceCaches[e])throw new Error(\"There is no source with this ID\");for(var r in this._layers)if(this._layers[r].source===e)return this.fire(new t.ErrorEvent(new Error('Source \"'+e+'\" cannot be removed while layer \"'+r+'\" is using it.')));var n=this.sourceCaches[e];delete this.sourceCaches[e],delete this._updatedSources[e],n.fire(new t.Event(\"data\",{sourceDataType:\"metadata\",dataType:\"source\",sourceId:e})),n.setEventedParent(null),n.clearTiles(),n.onRemove&&n.onRemove(this.map),this._changed=!0},r.prototype.setGeoJSONSourceData=function(t,e){this._checkLoaded(),this.sourceCaches[t].getSource().setData(e),this._changed=!0},r.prototype.getSource=function(t){return this.sourceCaches[t]&&this.sourceCaches[t].getSource()},r.prototype.addLayer=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=e.id;if(this.getLayer(i))this.fire(new t.ErrorEvent(new Error('Layer with id \"'+i+'\" already exists on this map')));else{var a;if(\"custom\"===e.type){if(Oe(this,t.validateCustomStyleLayer(e)))return;a=t.createStyleLayer(e)}else{if(\"object\"==typeof e.source&&(this.addSource(i,e.source),e=t.clone$1(e),e=t.extend(e,{source:i})),this._validate(t.validateStyle.layer,\"layers.\"+i,e,{arrayIndex:-1},n))return;a=t.createStyleLayer(e),this._validateLayer(a),a.setEventedParent(this,{layer:{id:i}})}var o=r?this._order.indexOf(r):this._order.length;if(r&&-1===o)this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.')));else{if(this._order.splice(o,0,i),this._layerOrderChanged=!0,this._layers[i]=a,this._removedLayers[i]&&a.source&&\"custom\"!==a.type){var s=this._removedLayers[i];delete this._removedLayers[i],s.type!==a.type?this._updatedSources[a.source]=\"clear\":(this._updatedSources[a.source]=\"reload\",this.sourceCaches[a.source].pause())}this._updateLayer(a),a.onAdd&&a.onAdd(this.map)}}},r.prototype.moveLayer=function(e,r){if(this._checkLoaded(),this._changed=!0,this._layers[e]){if(e!==r){var n=this._order.indexOf(e);this._order.splice(n,1);var i=r?this._order.indexOf(r):this._order.length;r&&-1===i?this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.'))):(this._order.splice(i,0,e),this._layerOrderChanged=!0)}}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be moved.\")))},r.prototype.removeLayer=function(e){this._checkLoaded();var r=this._layers[e];if(r){r.setEventedParent(null);var n=this._order.indexOf(e);this._order.splice(n,1),this._layerOrderChanged=!0,this._changed=!0,this._removedLayers[e]=r,delete this._layers[e],delete this._updatedLayers[e],delete this._updatedPaintProps[e],r.onRemove&&r.onRemove(this.map)}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be removed.\")))},r.prototype.getLayer=function(t){return this._layers[t]},r.prototype.setLayerZoomRange=function(e,r,n){this._checkLoaded();var i=this.getLayer(e);i?i.minzoom===r&&i.maxzoom===n||(null!=r&&(i.minzoom=r),null!=n&&(i.maxzoom=n),this._updateLayer(i)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot have zoom extent.\")))},r.prototype.setFilter=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=this.getLayer(e);if(i){if(!t.deepEqual(i.filter,r))return null==r?(i.filter=void 0,void this._updateLayer(i)):void(this._validate(t.validateStyle.filter,\"layers.\"+i.id+\".filter\",r,null,n)||(i.filter=t.clone$1(r),this._updateLayer(i)))}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be filtered.\")))},r.prototype.getFilter=function(e){return t.clone$1(this.getLayer(e).filter)},r.prototype.setLayoutProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getLayoutProperty(r),n)||(a.setLayoutProperty(r,n,i),this._updateLayer(a)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getLayoutProperty=function(e,r){var n=this.getLayer(e);if(n)return n.getLayoutProperty(r);this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style.\")))},r.prototype.setPaintProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getPaintProperty(r),n)||(a.setPaintProperty(r,n,i)&&this._updateLayer(a),this._changed=!0,this._updatedPaintProps[e]=!0):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getPaintProperty=function(t,e){return this.getLayer(t).getPaintProperty(e)},r.prototype.setFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=e.sourceLayer,a=this.sourceCaches[n],o=parseInt(e.id,10);if(void 0!==a){var s=a.getSource().type;\"geojson\"===s&&i?this.fire(new t.ErrorEvent(new Error(\"GeoJSON sources cannot have a sourceLayer parameter.\"))):\"vector\"!==s||i?isNaN(o)||o<0?this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided and non-negative.\"))):a.setFeatureState(i,o,r):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.removeFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=this.sourceCaches[n];if(void 0!==i){var a=i.getSource().type,o=\"vector\"===a?e.sourceLayer:void 0,s=parseInt(e.id,10);\"vector\"!==a||o?void 0!==e.id&&isNaN(s)||s<0?this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be non-negative.\"))):r&&\"string\"!=typeof e.id&&\"number\"!=typeof e.id?this.fire(new t.ErrorEvent(new Error(\"A feature id is requred to remove its specific state property.\"))):i.removeFeatureState(o,s,r):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.getFeatureState=function(e){this._checkLoaded();var r=e.source,n=e.sourceLayer,i=this.sourceCaches[r],a=parseInt(e.id,10);if(void 0!==i)if(\"vector\"!==i.getSource().type||n){if(!(isNaN(a)||a<0))return i.getFeatureState(n,a);this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided and non-negative.\")))}else this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")));else this.fire(new t.ErrorEvent(new Error(\"The source '\"+r+\"' does not exist in the map's style.\")))},r.prototype.getTransition=function(){return t.extend({duration:300,delay:0},this.stylesheet&&this.stylesheet.transition)},r.prototype.serialize=function(){return t.filterObject({version:this.stylesheet.version,name:this.stylesheet.name,metadata:this.stylesheet.metadata,light:this.stylesheet.light,center:this.stylesheet.center,zoom:this.stylesheet.zoom,bearing:this.stylesheet.bearing,pitch:this.stylesheet.pitch,sprite:this.stylesheet.sprite,glyphs:this.stylesheet.glyphs,transition:this.stylesheet.transition,sources:t.mapObject(this.sourceCaches,function(t){return t.serialize()}),layers:this._serializeLayers(this._order)},function(t){return void 0!==t})},r.prototype._updateLayer=function(t){this._updatedLayers[t.id]=!0,t.source&&!this._updatedSources[t.source]&&(this._updatedSources[t.source]=\"reload\",this.sourceCaches[t.source].pause()),this._changed=!0},r.prototype._flattenAndSortRenderedFeatures=function(t){for(var e=this,r=function(t){return\"fill-extrusion\"===e._layers[t].type},n={},i=[],a=this._order.length-1;a>=0;a--){var o=this._order[a];if(r(o)){n[o]=a;for(var s=0,l=t;s<l.length;s+=1){var c=l[s][o];if(c)for(var u=0,h=c;u<h.length;u+=1){var f=h[u];i.push(f)}}}}i.sort(function(t,e){return e.intersectionZ-t.intersectionZ});for(var p=[],d=this._order.length-1;d>=0;d--){var g=this._order[d];if(r(g))for(var v=i.length-1;v>=0;v--){var m=i[v].feature;if(n[m.layer.id]<d)break;p.push(m),i.pop()}else for(var y=0,x=t;y<x.length;y+=1){var b=x[y][g];if(b)for(var _=0,w=b;_<w.length;_+=1){var k=w[_];p.push(k.feature)}}}return p},r.prototype.queryRenderedFeatures=function(e,r,n){r&&r.filter&&this._validate(t.validateStyle.filter,\"queryRenderedFeatures.filter\",r.filter,null,r);var i={};if(r&&r.layers){if(!Array.isArray(r.layers))return this.fire(new t.ErrorEvent(new Error(\"parameters.layers must be an Array.\"))),[];for(var a=0,o=r.layers;a<o.length;a+=1){var s=o[a],l=this._layers[s];if(!l)return this.fire(new t.ErrorEvent(new Error(\"The layer '\"+s+\"' does not exist in the map's style and cannot be queried for features.\"))),[];i[l.source]=!0}}var c=[];for(var u in this.sourceCaches)r.layers&&!i[u]||c.push(R(this.sourceCaches[u],this._layers,e,r,n));return this.placement&&c.push(function(t,e,r,n,i,a){for(var o={},s=i.queryRenderedSymbols(r),l=[],c=0,u=Object.keys(s).map(Number);c<u.length;c+=1){var h=u[c];l.push(a[h])}l.sort(F);for(var f=function(){var e=d[p],r=e.featureIndex.lookupSymbolFeatures(s[e.bucketInstanceId],e.bucketIndex,e.sourceLayerIndex,n.filter,n.layers,t);for(var i in r){var a=o[i]=o[i]||[],l=r[i];l.sort(function(t,r){var n=e.featureSortOrder;if(n){var i=n.indexOf(t.featureIndex);return n.indexOf(r.featureIndex)-i}return r.featureIndex-t.featureIndex});for(var c=0,u=l;c<u.length;c+=1){var h=u[c];a.push(h)}}},p=0,d=l;p<d.length;p+=1)f();var g=function(r){o[r].forEach(function(n){var i=n.feature,a=t[r],o=e[a.source].getFeatureState(i.layer[\"source-layer\"],i.id);i.source=i.layer.source,i.layer[\"source-layer\"]&&(i.sourceLayer=i.layer[\"source-layer\"]),i.state=o})};for(var v in o)g(v);return o}(this._layers,this.sourceCaches,e,r,this.placement.collisionIndex,this.placement.retainedQueryData)),this._flattenAndSortRenderedFeatures(c)},r.prototype.querySourceFeatures=function(e,r){r&&r.filter&&this._validate(t.validateStyle.filter,\"querySourceFeatures.filter\",r.filter,null,r);var n=this.sourceCaches[e];return n?function(t,e){for(var r=t.getRenderableIds().map(function(e){return t.getTileByID(e)}),n=[],i={},a=0;a<r.length;a++){var o=r[a],s=o.tileID.canonical.key;i[s]||(i[s]=!0,o.querySourceFeatures(n,e))}return n}(n,r):[]},r.prototype.addSourceType=function(t,e,n){return r.getSourceType(t)?n(new Error('A source type called \"'+t+'\" already exists.')):(r.setSourceType(t,e),e.workerSourceURL?void this.dispatcher.broadcast(\"loadWorkerSource\",{name:t,url:e.workerSourceURL},n):n(null,null))},r.prototype.getLight=function(){return this.light.getLight()},r.prototype.setLight=function(e,r){void 0===r&&(r={}),this._checkLoaded();var n=this.light.getLight(),i=!1;for(var a in e)if(!t.deepEqual(e[a],n[a])){i=!0;break}if(i){var o={now:t.browser.now(),transition:t.extend({duration:300,delay:0},this.stylesheet.transition)};this.light.setLight(e,r),this.light.updateTransitions(o)}},r.prototype._validate=function(e,r,n,i,a){return void 0===a&&(a={}),(!a||!1!==a.validate)&&Oe(this,e.call(t.validateStyle,t.extend({key:r,style:this.serialize(),value:n,styleSpec:t.styleSpec},i)))},r.prototype._remove=function(){for(var e in this._request&&(this._request.cancel(),this._request=null),this._spriteRequest&&(this._spriteRequest.cancel(),this._spriteRequest=null),t.evented.off(\"pluginAvailable\",this._rtlTextPluginCallback),this.sourceCaches)this.sourceCaches[e].clearTiles();this.dispatcher.remove()},r.prototype._clearSource=function(t){this.sourceCaches[t].clearTiles()},r.prototype._reloadSource=function(t){this.sourceCaches[t].resume(),this.sourceCaches[t].reload()},r.prototype._updateSources=function(t){for(var e in this.sourceCaches)this.sourceCaches[e].update(t)},r.prototype._generateCollisionBoxes=function(){for(var t in this.sourceCaches)this._reloadSource(t)},r.prototype._updatePlacement=function(e,r,n,i){for(var a=!1,o=!1,s={},l=0,c=this._order;l<c.length;l+=1){var u=c[l],h=this._layers[u];if(\"symbol\"===h.type){if(!s[h.source]){var f=this.sourceCaches[h.source];s[h.source]=f.getRenderableIds(!0).map(function(t){return f.getTileByID(t)}).sort(function(t,e){return e.tileID.overscaledZ-t.tileID.overscaledZ||(t.tileID.isLessThan(e.tileID)?-1:1)})}var p=this.crossTileSymbolIndex.addLayer(h,s[h.source],e.center.lng);a=a||p}}this.crossTileSymbolIndex.pruneUnusedLayers(this._order);var d=this._layerOrderChanged||0===n;if((d||!this.pauseablePlacement||this.pauseablePlacement.isDone()&&!this.placement.stillRecent(t.browser.now()))&&(this.pauseablePlacement=new Me(e,this._order,d,r,n,i,this.placement),this._layerOrderChanged=!1),this.pauseablePlacement.isDone()?this.placement.setStale():(this.pauseablePlacement.continuePlacement(this._order,this._layers,s),this.pauseablePlacement.isDone()&&(this.placement=this.pauseablePlacement.commit(t.browser.now()),o=!0),a&&this.pauseablePlacement.placement.setStale()),o||a)for(var g=0,v=this._order;g<v.length;g+=1){var m=v[g],y=this._layers[m];\"symbol\"===y.type&&this.placement.updateLayerOpacities(y,s[y.source])}return!this.pauseablePlacement.isDone()||this.placement.hasTransitions(t.browser.now())},r.prototype._releaseSymbolFadeTiles=function(){for(var t in this.sourceCaches)this.sourceCaches[t].releaseSymbolFadeTiles()},r.prototype.getImages=function(t,e,r){this.imageManager.getImages(e.icons,r)},r.prototype.getGlyphs=function(t,e,r){this.glyphManager.getGlyphs(e.stacks,r)},r.prototype.getResource=function(e,r,n){return t.makeRequest(r,n)},r}(t.Evented);De.getSourceType=function(t){return z[t]},De.setSourceType=function(t,e){z[t]=e},De.registerForPluginAvailability=t.registerForPluginAvailability;var Re=t.createLayout([{name:\"a_pos\",type:\"Int16\",components:2}]),Fe=lr(\"#ifdef GL_ES\\nprecision mediump float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\",\"#ifdef GL_ES\\nprecision highp float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\\nvec2 unpack_float(const float packedValue) {int packedIntValue=int(packedValue);int v0=packedIntValue/256;return vec2(v0,packedIntValue-v0*256);}vec2 unpack_opacity(const float packedOpacity) {int intOpacity=int(packedOpacity)/2;return vec2(float(intOpacity)/127.0,mod(packedOpacity,2.0));}vec4 decode_color(const vec2 encodedColor) {return vec4(unpack_float(encodedColor[0])/255.0,unpack_float(encodedColor[1])/255.0\\n);}float unpack_mix_vec2(const vec2 packedValue,const float t) {return mix(packedValue[0],packedValue[1],t);}vec4 unpack_mix_color(const vec4 packedColors,const float t) {vec4 minColor=decode_color(vec2(packedColors[0],packedColors[1]));vec4 maxColor=decode_color(vec2(packedColors[2],packedColors[3]));return mix(minColor,maxColor,t);}vec2 get_pattern_pos(const vec2 pixel_coord_upper,const vec2 pixel_coord_lower,const vec2 pattern_size,const float tile_units_to_pixels,const vec2 pos) {vec2 offset=mod(mod(mod(pixel_coord_upper,pattern_size)*256.0,pattern_size)*256.0+pixel_coord_lower,pattern_size);return (tile_units_to_pixels*pos+offset)/pattern_size;}\"),Be=lr(\"uniform vec4 u_color;uniform float u_opacity;void main() {gl_FragColor=u_color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),Ne=lr(\"uniform vec2 u_pattern_tl_a;uniform vec2 u_pattern_br_a;uniform vec2 u_pattern_tl_b;uniform vec2 u_pattern_br_b;uniform vec2 u_texsize;uniform float u_mix;uniform float u_opacity;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(u_pattern_tl_a/u_texsize,u_pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(u_pattern_tl_b/u_texsize,u_pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_mix)*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pattern_size_a;uniform vec2 u_pattern_size_b;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_scale_a;uniform float u_scale_b;uniform float u_tile_units_to_pixels;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_a*u_pattern_size_a,u_tile_units_to_pixels,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_b*u_pattern_size_b,u_tile_units_to_pixels,a_pos);}\"),je=lr(\"varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=v_data.xy;float extrude_length=length(extrude);lowp float antialiasblur=v_data.z;float antialiased_blur=-max(blur,antialiasblur);float opacity_t=smoothstep(0.0,antialiased_blur,extrude_length-1.0);float color_t=stroke_width < 0.01 ? 0.0 : smoothstep(antialiased_blur,0.0,extrude_length-radius/(radius+stroke_width));gl_FragColor=opacity_t*mix(color*opacity,stroke_color*stroke_opacity,color_t);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform bool u_scale_with_map;uniform bool u_pitch_with_map;uniform vec2 u_extrude_scale;uniform lowp float u_device_pixel_ratio;uniform highp float u_camera_to_center_distance;attribute vec2 a_pos;varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main(void) {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=vec2(mod(a_pos,2.0)*2.0-1.0);vec2 circle_center=floor(a_pos*0.5);if (u_pitch_with_map) {vec2 corner_position=circle_center;if (u_scale_with_map) {corner_position+=extrude*(radius+stroke_width)*u_extrude_scale;} else {vec4 projected_center=u_matrix*vec4(circle_center,0,1);corner_position+=extrude*(radius+stroke_width)*u_extrude_scale*(projected_center.w/u_camera_to_center_distance);}gl_Position=u_matrix*vec4(corner_position,0,1);} else {gl_Position=u_matrix*vec4(circle_center,0,1);if (u_scale_with_map) {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*u_camera_to_center_distance;} else {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*gl_Position.w;}}lowp float antialiasblur=1.0/u_device_pixel_ratio/(radius+stroke_width);v_data=vec3(extrude.x,extrude.y,antialiasblur);}\"),Ue=lr(\"void main() {gl_FragColor=vec4(1.0);}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),Ve=lr(\"uniform highp float u_intensity;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main() {\\n#pragma mapbox: initialize highp float weight\\nfloat d=-0.5*3.0*3.0*dot(v_extrude,v_extrude);float val=weight*u_intensity*GAUSS_COEF*exp(d);gl_FragColor=vec4(val,1.0,1.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform float u_extrude_scale;uniform float u_opacity;uniform float u_intensity;attribute vec2 a_pos;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#pragma mapbox: define mediump float radius\\nconst highp float ZERO=1.0/255.0/16.0;\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main(void) {\\n#pragma mapbox: initialize highp float weight\\n#pragma mapbox: initialize mediump float radius\\nvec2 unscaled_extrude=vec2(mod(a_pos,2.0)*2.0-1.0);float S=sqrt(-2.0*log(ZERO/weight/u_intensity/GAUSS_COEF))/3.0;v_extrude=S*unscaled_extrude;vec2 extrude=v_extrude*radius*u_extrude_scale;vec4 pos=vec4(floor(a_pos*0.5)+extrude,0,1);gl_Position=u_matrix*pos;}\"),qe=lr(\"uniform sampler2D u_image;uniform sampler2D u_color_ramp;uniform float u_opacity;varying vec2 v_pos;void main() {float t=texture2D(u_image,v_pos).r;vec4 color=texture2D(u_color_ramp,vec2(t,0.5));gl_FragColor=color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(0.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;attribute vec2 a_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos*u_world,0,1);v_pos.x=a_pos.x;v_pos.y=1.0-a_pos.y;}\"),He=lr(\"varying float v_placed;varying float v_notUsed;void main() {float alpha=0.5;gl_FragColor=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {gl_FragColor=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {gl_FragColor*=.1;}}\",\"attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;attribute vec2 a_shift;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);gl_Position.xy+=(a_extrude+a_shift)*u_extrude_scale*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;}\"),Ge=lr(\"uniform float u_overscale_factor;varying float v_placed;varying float v_notUsed;varying float v_radius;varying vec2 v_extrude;varying vec2 v_extrude_scale;void main() {float alpha=0.5;vec4 color=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {color=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {color*=.2;}float extrude_scale_length=length(v_extrude_scale);float extrude_length=length(v_extrude)*extrude_scale_length;float stroke_width=15.0*extrude_scale_length/u_overscale_factor;float radius=v_radius*extrude_scale_length;float distance_to_edge=abs(extrude_length-radius);float opacity_t=smoothstep(-stroke_width,0.0,-distance_to_edge);gl_FragColor=opacity_t*color;}\",\"attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;varying float v_radius;varying vec2 v_extrude;varying vec2 v_extrude_scale;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);highp float padding_factor=1.2;gl_Position.xy+=a_extrude*u_extrude_scale*padding_factor*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;v_radius=abs(a_extrude.y);v_extrude=a_extrude*padding_factor;v_extrude_scale=u_extrude_scale*u_camera_to_center_distance*collision_perspective_ratio;}\"),Ye=lr(\"uniform highp vec4 u_color;void main() {gl_FragColor=u_color;}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),We=lr(\"#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_FragColor=color*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);}\"),Xe=lr(\"varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=outline_color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;uniform vec2 u_world;varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),Ze=lr(\"uniform vec2 u_texsize;uniform sampler2D u_image;uniform float u_fade;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);float dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=mix(color1,color2,u_fade)*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec4 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;gl_Position=u_matrix*vec4(a_pos,0,1);vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,a_pos);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),Je=lr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_fade)*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec4 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileZoomRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileZoomRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileZoomRatio,a_pos);}\"),Ke=lr(\"varying vec4 v_color;void main() {gl_FragColor=v_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;uniform float u_vertical_gradient;uniform lowp float u_opacity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec4 v_color;\\n#pragma mapbox: define highp float base\\n#pragma mapbox: define highp float height\\n#pragma mapbox: define highp vec4 color\\nvoid main() {\\n#pragma mapbox: initialize highp float base\\n#pragma mapbox: initialize highp float height\\n#pragma mapbox: initialize highp vec4 color\\nvec3 normal=a_normal_ed.xyz;base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);gl_Position=u_matrix*vec4(a_pos,t > 0.0 ? height : base,1);float colorvalue=color.r*0.2126+color.g*0.7152+color.b*0.0722;v_color=vec4(0.0,0.0,0.0,1.0);vec4 ambientlight=vec4(0.03,0.03,0.03,1.0);color+=ambientlight;float directional=clamp(dot(normal/16384.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((1.0-colorvalue+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_color.r+=clamp(color.r*directional*u_lightcolor.r,mix(0.0,0.3,1.0-u_lightcolor.r),1.0);v_color.g+=clamp(color.g*directional*u_lightcolor.g,mix(0.0,0.3,1.0-u_lightcolor.g),1.0);v_color.b+=clamp(color.b*directional*u_lightcolor.b,mix(0.0,0.3,1.0-u_lightcolor.b),1.0);v_color*=u_opacity;}\"),$e=lr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);vec4 mixedColor=mix(color1,color2,u_fade);gl_FragColor=mixedColor*v_lighting;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_height_factor;uniform vec4 u_scale;uniform float u_vertical_gradient;uniform lowp float u_opacity;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec3 normal=a_normal_ed.xyz;float edgedistance=a_normal_ed.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);float z=t > 0.0 ? height : base;gl_Position=u_matrix*vec4(a_pos,z,1);vec2 pos=normal.x==1.0 && normal.y==0.0 && normal.z==16384.0\\n? a_pos\\n: vec2(edgedistance,z*u_height_factor);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,pos);v_lighting=vec4(0.0,0.0,0.0,1.0);float directional=clamp(dot(normal/16383.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((0.5+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_lighting.rgb+=clamp(directional*u_lightcolor,mix(vec3(0.0),vec3(0.3),1.0-u_lightcolor),vec3(1.0));v_lighting*=u_opacity;}\"),Qe=lr(\"#ifdef GL_ES\\nprecision highp float;\\n#endif\\nuniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_dimension;uniform float u_zoom;uniform float u_maxzoom;float getElevation(vec2 coord,float bias) {vec4 data=texture2D(u_image,coord)*255.0;return (data.r+data.g*256.0+data.b*256.0*256.0)/4.0;}void main() {vec2 epsilon=1.0/u_dimension;float a=getElevation(v_pos+vec2(-epsilon.x,-epsilon.y),0.0);float b=getElevation(v_pos+vec2(0,-epsilon.y),0.0);float c=getElevation(v_pos+vec2(epsilon.x,-epsilon.y),0.0);float d=getElevation(v_pos+vec2(-epsilon.x,0),0.0);float e=getElevation(v_pos,0.0);float f=getElevation(v_pos+vec2(epsilon.x,0),0.0);float g=getElevation(v_pos+vec2(-epsilon.x,epsilon.y),0.0);float h=getElevation(v_pos+vec2(0,epsilon.y),0.0);float i=getElevation(v_pos+vec2(epsilon.x,epsilon.y),0.0);float exaggeration=u_zoom < 2.0 ? 0.4 : u_zoom < 4.5 ? 0.35 : 0.3;vec2 deriv=vec2((c+f+f+i)-(a+d+d+g),(g+h+h+i)-(a+b+b+c))/ pow(2.0,(u_zoom-u_maxzoom)*exaggeration+19.2562-u_zoom);gl_FragColor=clamp(vec4(deriv.x/2.0+0.5,deriv.y/2.0+0.5,1.0,1.0),0.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_dimension;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);highp vec2 epsilon=1.0/u_dimension;float scale=(u_dimension.x-2.0)/u_dimension.x;v_pos=(a_texture_pos/8192.0)*scale+epsilon;}\"),tr=lr(\"uniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_latrange;uniform vec2 u_light;uniform vec4 u_shadow;uniform vec4 u_highlight;uniform vec4 u_accent;\\n#define PI 3.141592653589793\\nvoid main() {vec4 pixel=texture2D(u_image,v_pos);vec2 deriv=((pixel.rg*2.0)-1.0);float scaleFactor=cos(radians((u_latrange[0]-u_latrange[1])*(1.0-v_pos.y)+u_latrange[1]));float slope=atan(1.25*length(deriv)/scaleFactor);float aspect=deriv.x !=0.0 ? atan(deriv.y,-deriv.x) : PI/2.0*(deriv.y > 0.0 ? 1.0 :-1.0);float intensity=u_light.x;float azimuth=u_light.y+PI;float base=1.875-intensity*1.75;float maxValue=0.5*PI;float scaledSlope=intensity !=0.5 ? ((pow(base,slope)-1.0)/(pow(base,maxValue)-1.0))*maxValue : slope;float accent=cos(scaledSlope);vec4 accent_color=(1.0-accent)*u_accent*clamp(intensity*2.0,0.0,1.0);float shade=abs(mod((aspect+azimuth)/PI+0.5,2.0)-1.0);vec4 shade_color=mix(u_shadow,u_highlight,shade)*sin(scaledSlope)*clamp(intensity*2.0,0.0,1.0);gl_FragColor=accent_color*(1.0-shade_color.a)+shade_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos=a_texture_pos/8192.0;}\"),er=lr(\"uniform lowp float u_device_pixel_ratio;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform vec2 u_units_to_pixels;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_linesofar;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),rr=lr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);vec4 color=texture2D(u_image,vec2(v_lineprogress,0.5));gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define MAX_LINE_DISTANCE 32767.0\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_lineprogress=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0/MAX_LINE_DISTANCE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),nr=lr(\"uniform lowp float u_device_pixel_ratio;uniform vec2 u_texsize;uniform float u_fade;uniform mediump vec4 u_scale;uniform sampler2D u_image;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileZoomRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);vec2 pattern_size_a=vec2(display_size_a.x*fromScale/tileZoomRatio,display_size_a.y);vec2 pattern_size_b=vec2(display_size_b.x*toScale/tileZoomRatio,display_size_b.y);float dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float x_a=mod(v_linesofar/pattern_size_a.x,1.0);float x_b=mod(v_linesofar/pattern_size_b.x,1.0);float y_a=0.5+(v_normal.y*clamp(v_width2.s,0.0,(pattern_size_a.y+2.0)/2.0)/pattern_size_a.y);float y_b=0.5+(v_normal.y*clamp(v_width2.s,0.0,(pattern_size_b.y+2.0)/2.0)/pattern_size_b.y);vec2 pos_a=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,vec2(x_a,y_a));vec2 pos_b=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,vec2(x_b,y_b));vec4 color=mix(texture2D(u_image,pos_a),texture2D(u_image,pos_b),u_fade);gl_FragColor=color*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform vec2 u_units_to_pixels;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_linesofar=a_linesofar;v_width2=vec2(outset,inset);}\"),ir=lr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;uniform float u_sdfgamma;uniform float u_mix;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float sdfdist_a=texture2D(u_image,v_tex_a).a;float sdfdist_b=texture2D(u_image,v_tex_b).a;float sdfdist=mix(sdfdist_a,sdfdist_b,u_mix);alpha*=smoothstep(0.5-u_sdfgamma/floorwidth,0.5+u_sdfgamma/floorwidth,sdfdist);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_patternscale_a;uniform float u_tex_y_a;uniform vec2 u_patternscale_b;uniform float u_tex_y_b;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_tex_a=vec2(a_linesofar*u_patternscale_a.x/floorwidth,normal.y*u_patternscale_a.y+u_tex_y_a);v_tex_b=vec2(a_linesofar*u_patternscale_b.x/floorwidth,normal.y*u_patternscale_b.y+u_tex_y_b);v_width2=vec2(outset,inset);}\"),ar=lr(\"uniform float u_fade_t;uniform float u_opacity;uniform sampler2D u_image0;uniform sampler2D u_image1;varying vec2 v_pos0;varying vec2 v_pos1;uniform float u_brightness_low;uniform float u_brightness_high;uniform float u_saturation_factor;uniform float u_contrast_factor;uniform vec3 u_spin_weights;void main() {vec4 color0=texture2D(u_image0,v_pos0);vec4 color1=texture2D(u_image1,v_pos1);if (color0.a > 0.0) {color0.rgb=color0.rgb/color0.a;}if (color1.a > 0.0) {color1.rgb=color1.rgb/color1.a;}vec4 color=mix(color0,color1,u_fade_t);color.a*=u_opacity;vec3 rgb=color.rgb;rgb=vec3(dot(rgb,u_spin_weights.xyz),dot(rgb,u_spin_weights.zxy),dot(rgb,u_spin_weights.yzx));float average=(color.r+color.g+color.b)/3.0;rgb+=(average-rgb)*u_saturation_factor;rgb=(rgb-0.5)*u_contrast_factor+0.5;vec3 u_high_vec=vec3(u_brightness_low,u_brightness_low,u_brightness_low);vec3 u_low_vec=vec3(u_brightness_high,u_brightness_high,u_brightness_high);gl_FragColor=vec4(mix(u_high_vec,u_low_vec,rgb)*color.a,color.a);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_tl_parent;uniform float u_scale_parent;uniform float u_buffer_scale;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos0;varying vec2 v_pos1;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos0=(((a_texture_pos/8192.0)-0.5)/u_buffer_scale )+0.5;v_pos1=(v_pos0*u_scale_parent)+u_tl_parent;}\"),or=lr(\"uniform sampler2D u_texture;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nlowp float alpha=opacity*v_fade_opacity;gl_FragColor=texture2D(u_texture,v_tex)*alpha;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform highp float u_camera_to_center_distance;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform float u_fade_change;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform vec2 u_texsize;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size[0],a_size[1],u_size_t)/256.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size[0]/256.0;} else if (!u_is_size_zoom_constant && u_is_size_feature_constant) {size=u_size;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);v_tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;v_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));}\"),sr=lr(\"#define SDF_PX 8.0\\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;uniform bool u_is_text;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nfloat EDGE_GAMMA=0.105/u_device_pixel_ratio;vec2 tex=v_data0.xy;float gamma_scale=v_data1.x;float size=v_data1.y;float fade_opacity=v_data1[2];float fontScale=u_is_text ? size/24.0 : size;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size[0],a_size[1],u_size_t)/256.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size[0]/256.0;} else if (!u_is_size_zoom_constant && u_is_size_feature_constant) {size=u_size;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);float gamma_scale=gl_Position.w;vec2 tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));v_data0=vec2(tex.x,tex.y);v_data1=vec3(gamma_scale,size,interpolated_fade_opacity);}\");function lr(t,e){var r=/#pragma mapbox: ([\\w]+) ([\\w]+) ([\\w]+) ([\\w]+)/g,n={};return{fragmentSource:t=t.replace(r,function(t,e,r,i,a){return n[a]=!0,\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"\\n#ifdef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"}),vertexSource:e=e.replace(r,function(t,e,r,i,a){var o=\"float\"===i?\"vec2\":\"vec4\",s=a.match(/color/)?\"color\":o;return n[a]?\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"})}}var cr=Object.freeze({prelude:Fe,background:Be,backgroundPattern:Ne,circle:je,clippingMask:Ue,heatmap:Ve,heatmapTexture:qe,collisionBox:He,collisionCircle:Ge,debug:Ye,fill:We,fillOutline:Xe,fillOutlinePattern:Ze,fillPattern:Je,fillExtrusion:Ke,fillExtrusionPattern:$e,hillshadePrepare:Qe,hillshade:tr,line:er,lineGradient:rr,linePattern:nr,lineSDF:ir,raster:ar,symbolIcon:or,symbolSDF:sr}),ur=function(){this.boundProgram=null,this.boundLayoutVertexBuffer=null,this.boundPaintVertexBuffers=[],this.boundIndexBuffer=null,this.boundVertexOffset=null,this.boundDynamicVertexBuffer=null,this.vao=null};ur.prototype.bind=function(t,e,r,n,i,a,o,s){this.context=t;for(var l=this.boundPaintVertexBuffers.length!==n.length,c=0;!l&&c<n.length;c++)this.boundPaintVertexBuffers[c]!==n[c]&&(l=!0);var u=!this.vao||this.boundProgram!==e||this.boundLayoutVertexBuffer!==r||l||this.boundIndexBuffer!==i||this.boundVertexOffset!==a||this.boundDynamicVertexBuffer!==o||this.boundDynamicVertexBuffer2!==s;!t.extVertexArrayObject||u?this.freshBind(e,r,n,i,a,o,s):(t.bindVertexArrayOES.set(this.vao),o&&o.bind(),i&&i.dynamicDraw&&i.bind(),s&&s.bind())},ur.prototype.freshBind=function(t,e,r,n,i,a,o){var s,l=t.numAttributes,c=this.context,u=c.gl;if(c.extVertexArrayObject)this.vao&&this.destroy(),this.vao=c.extVertexArrayObject.createVertexArrayOES(),c.bindVertexArrayOES.set(this.vao),s=0,this.boundProgram=t,this.boundLayoutVertexBuffer=e,this.boundPaintVertexBuffers=r,this.boundIndexBuffer=n,this.boundVertexOffset=i,this.boundDynamicVertexBuffer=a,this.boundDynamicVertexBuffer2=o;else{s=c.currentNumAttributes||0;for(var h=l;h<s;h++)u.disableVertexAttribArray(h)}e.enableAttributes(u,t);for(var f=0,p=r;f<p.length;f+=1)p[f].enableAttributes(u,t);a&&a.enableAttributes(u,t),o&&o.enableAttributes(u,t),e.bind(),e.setVertexAttribPointers(u,t,i);for(var d=0,g=r;d<g.length;d+=1){var v=g[d];v.bind(),v.setVertexAttribPointers(u,t,i)}a&&(a.bind(),a.setVertexAttribPointers(u,t,i)),n&&n.bind(),o&&(o.bind(),o.setVertexAttribPointers(u,t,i)),c.currentNumAttributes=l},ur.prototype.destroy=function(){this.vao&&(this.context.extVertexArrayObject.deleteVertexArrayOES(this.vao),this.vao=null)};var hr=function(t,e,r,n,i){var a=t.gl;this.program=a.createProgram();var o=r.defines();i&&o.push(\"#define OVERDRAW_INSPECTOR;\");var s=o.concat(Fe.fragmentSource,e.fragmentSource).join(\"\\n\"),l=o.concat(Fe.vertexSource,e.vertexSource).join(\"\\n\"),c=a.createShader(a.FRAGMENT_SHADER);a.shaderSource(c,s),a.compileShader(c),a.attachShader(this.program,c);var u=a.createShader(a.VERTEX_SHADER);a.shaderSource(u,l),a.compileShader(u),a.attachShader(this.program,u);for(var h=r.layoutAttributes||[],f=0;f<h.length;f++)a.bindAttribLocation(this.program,f,h[f].name);a.linkProgram(this.program),this.numAttributes=a.getProgramParameter(this.program,a.ACTIVE_ATTRIBUTES),this.attributes={};for(var p={},d=0;d<this.numAttributes;d++){var g=a.getActiveAttrib(this.program,d);g&&(this.attributes[g.name]=a.getAttribLocation(this.program,g.name))}for(var v=a.getProgramParameter(this.program,a.ACTIVE_UNIFORMS),m=0;m<v;m++){var y=a.getActiveUniform(this.program,m);y&&(p[y.name]=a.getUniformLocation(this.program,y.name))}this.fixedUniforms=n(t,p),this.binderUniforms=r.getUniforms(t,p)};function fr(e,r,n){var i=1/le(n,1,r.transform.tileZoom),a=Math.pow(2,n.tileID.overscaledZ),o=n.tileSize*Math.pow(2,r.transform.tileZoom)/a,s=o*(n.tileID.canonical.x+n.tileID.wrap*a),l=o*n.tileID.canonical.y;return{u_image:0,u_texsize:n.imageAtlasTexture.size,u_scale:[t.browser.devicePixelRatio,i,e.fromScale,e.toScale],u_fade:e.t,u_pixel_coord_upper:[s>>16,l>>16],u_pixel_coord_lower:[65535&s,65535&l]}}hr.prototype.draw=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g){var v,m=t.gl;for(var y in t.program.set(this.program),t.setDepthMode(r),t.setStencilMode(n),t.setColorMode(i),t.setCullFace(a),this.fixedUniforms)this.fixedUniforms[y].set(o[y]);p&&p.setUniforms(t,this.binderUniforms,h,{zoom:f});for(var x=(v={},v[m.LINES]=2,v[m.TRIANGLES]=3,v[m.LINE_STRIP]=1,v)[e],b=0,_=u.get();b<_.length;b+=1){var w=_[b],k=w.vaos||(w.vaos={});(k[s]||(k[s]=new ur)).bind(t,this,l,p?p.getPaintVertexBuffers():[],c,w.vertexOffset,d,g),m.drawElements(e,w.primitiveLength*x,m.UNSIGNED_SHORT,w.primitiveOffset*x*2)}};var pr=function(e,r,n,i){var a=r.style.light,o=a.properties.get(\"position\"),s=[o.x,o.y,o.z],l=t.create$1();\"viewport\"===a.properties.get(\"anchor\")&&t.fromRotation(l,-r.transform.angle),t.transformMat3(s,s,l);var c=a.properties.get(\"color\");return{u_matrix:e,u_lightpos:s,u_lightintensity:a.properties.get(\"intensity\"),u_lightcolor:[c.r,c.g,c.b],u_vertical_gradient:+n,u_opacity:i}},dr=function(e,r,n,i,a,o,s){return t.extend(pr(e,r,n,i),fr(o,r,s),{u_height_factor:-Math.pow(2,a.overscaledZ)/s.tileSize/8})},gr=function(t){return{u_matrix:t}},vr=function(e,r,n,i){return t.extend(gr(e),fr(n,r,i))},mr=function(t,e){return{u_matrix:t,u_world:e}},yr=function(e,r,n,i,a){return t.extend(vr(e,r,n,i),{u_world:a})},xr=function(e,r,n,i){var a,o,s=e.transform;if(\"map\"===i.paint.get(\"circle-pitch-alignment\")){var l=le(n,1,s.zoom);a=!0,o=[l,l]}else a=!1,o=s.pixelsToGLUnits;return{u_camera_to_center_distance:s.cameraToCenterDistance,u_scale_with_map:+(\"map\"===i.paint.get(\"circle-pitch-scale\")),u_matrix:e.translatePosMatrix(r.posMatrix,n,i.paint.get(\"circle-translate\"),i.paint.get(\"circle-translate-anchor\")),u_pitch_with_map:+a,u_device_pixel_ratio:t.browser.devicePixelRatio,u_extrude_scale:o}},br=function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pixels_to_tile_units:new t.Uniform1f(e,r.u_pixels_to_tile_units),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_overscale_factor:new t.Uniform1f(e,r.u_overscale_factor)}},_r=function(t,e,r){var n=le(r,1,e.zoom),i=Math.pow(2,e.zoom-r.tileID.overscaledZ),a=r.tileID.overscaleFactor();return{u_matrix:t,u_camera_to_center_distance:e.cameraToCenterDistance,u_pixels_to_tile_units:n,u_extrude_scale:[e.pixelsToGLUnits[0]/(n*i),e.pixelsToGLUnits[1]/(n*i)],u_overscale_factor:a}},wr=function(t,e){return{u_matrix:t,u_color:e}},kr=function(t){return{u_matrix:t}},Tr=function(t,e,r,n){return{u_matrix:t,u_extrude_scale:le(e,1,r),u_intensity:n}},Ar=function(t,e,r){var n=r.paint.get(\"hillshade-shadow-color\"),i=r.paint.get(\"hillshade-highlight-color\"),a=r.paint.get(\"hillshade-accent-color\"),o=r.paint.get(\"hillshade-illumination-direction\")*(Math.PI/180);\"viewport\"===r.paint.get(\"hillshade-illumination-anchor\")&&(o-=t.transform.angle);var s=!t.options.moving;return{u_matrix:t.transform.calculatePosMatrix(e.tileID.toUnwrapped(),s),u_image:0,u_latrange:Sr(t,e.tileID),u_light:[r.paint.get(\"hillshade-exaggeration\"),o],u_shadow:n,u_highlight:i,u_accent:a}},Mr=function(e,r){var n=e.dem.stride,i=t.create();return t.ortho(i,0,t.EXTENT,-t.EXTENT,0,0,1),t.translate(i,i,[0,-t.EXTENT,0]),{u_matrix:i,u_image:1,u_dimension:[n,n],u_zoom:e.tileID.overscaledZ,u_maxzoom:r}};function Sr(e,r){var n=Math.pow(2,r.canonical.z),i=r.canonical.y;return[new t.MercatorCoordinate(0,i/n).toLngLat().lat,new t.MercatorCoordinate(0,(i+1)/n).toLngLat().lat]}var Er=function(e,r,n){var i=e.transform;return{u_matrix:zr(e,r,n),u_ratio:1/le(r,1,i.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_units_to_pixels:[1/i.pixelsToGLUnits[0],1/i.pixelsToGLUnits[1]]}},Cr=function(e,r,n){return t.extend(Er(e,r,n),{u_image:0})},Lr=function(e,r,n,i){var a=e.transform,o=Or(r,a);return{u_matrix:zr(e,r,n),u_texsize:r.imageAtlasTexture.size,u_ratio:1/le(r,1,a.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_image:0,u_scale:[t.browser.devicePixelRatio,o,i.fromScale,i.toScale],u_fade:i.t,u_units_to_pixels:[1/a.pixelsToGLUnits[0],1/a.pixelsToGLUnits[1]]}},Pr=function(e,r,n,i,a){var o=e.transform,s=e.lineAtlas,l=Or(r,o),c=\"round\"===n.layout.get(\"line-cap\"),u=s.getDash(i.from,c),h=s.getDash(i.to,c),f=u.width*a.fromScale,p=h.width*a.toScale;return t.extend(Er(e,r,n),{u_patternscale_a:[l/f,-u.height/2],u_patternscale_b:[l/p,-h.height/2],u_sdfgamma:s.width/(256*Math.min(f,p)*t.browser.devicePixelRatio)/2,u_image:0,u_tex_y_a:u.y,u_tex_y_b:h.y,u_mix:a.t})};function Or(t,e){return 1/le(t,1,e.tileZoom)}function zr(t,e,r){return t.translatePosMatrix(e.tileID.posMatrix,e,r.paint.get(\"line-translate\"),r.paint.get(\"line-translate-anchor\"))}var Ir=function(t,e,r,n,i){return{u_matrix:t,u_tl_parent:e,u_scale_parent:r,u_buffer_scale:1,u_fade_t:n.mix,u_opacity:n.opacity*i.paint.get(\"raster-opacity\"),u_image0:0,u_image1:1,u_brightness_low:i.paint.get(\"raster-brightness-min\"),u_brightness_high:i.paint.get(\"raster-brightness-max\"),u_saturation_factor:(o=i.paint.get(\"raster-saturation\"),o>0?1-1/(1.001-o):-o),u_contrast_factor:(a=i.paint.get(\"raster-contrast\"),a>0?1/(1-a):1+a),u_spin_weights:function(t){t*=Math.PI/180;var e=Math.sin(t),r=Math.cos(t);return[(2*r+1)/3,(-Math.sqrt(3)*e-r+1)/3,(Math.sqrt(3)*e-r+1)/3]}(i.paint.get(\"raster-hue-rotate\"))};var a,o};var Dr=function(t,e,r,n,i,a,o,s,l,c){var u=i.transform;return{u_is_size_zoom_constant:+(\"constant\"===t||\"source\"===t),u_is_size_feature_constant:+(\"constant\"===t||\"camera\"===t),u_size_t:e?e.uSizeT:0,u_size:e?e.uSize:0,u_camera_to_center_distance:u.cameraToCenterDistance,u_pitch:u.pitch/360*2*Math.PI,u_rotate_symbol:+r,u_aspect_ratio:u.width/u.height,u_fade_change:i.options.fadeDuration?i.symbolFadeChange:1,u_matrix:a,u_label_plane_matrix:o,u_coord_matrix:s,u_is_text:+l,u_pitch_with_map:+n,u_texsize:c,u_texture:0}},Rr=function(e,r,n,i,a,o,s,l,c,u,h){var f=a.transform;return t.extend(Dr(e,r,n,i,a,o,s,l,c,u),{u_gamma_scale:i?Math.cos(f._pitch)*f.cameraToCenterDistance:1,u_device_pixel_ratio:t.browser.devicePixelRatio,u_is_halo:+h})},Fr=function(t,e,r){return{u_matrix:t,u_opacity:e,u_color:r}},Br=function(e,r,n,i,a,o){return t.extend(function(t,e,r,n){var i=r.imageManager.getPattern(t.from),a=r.imageManager.getPattern(t.to),o=r.imageManager.getPixelSize(),s=o.width,l=o.height,c=Math.pow(2,n.tileID.overscaledZ),u=n.tileSize*Math.pow(2,r.transform.tileZoom)/c,h=u*(n.tileID.canonical.x+n.tileID.wrap*c),f=u*n.tileID.canonical.y;return{u_image:0,u_pattern_tl_a:i.tl,u_pattern_br_a:i.br,u_pattern_tl_b:a.tl,u_pattern_br_b:a.br,u_texsize:[s,l],u_mix:e.t,u_pattern_size_a:i.displaySize,u_pattern_size_b:a.displaySize,u_scale_a:e.fromScale,u_scale_b:e.toScale,u_tile_units_to_pixels:1/le(n,1,r.transform.tileZoom),u_pixel_coord_upper:[h>>16,f>>16],u_pixel_coord_lower:[65535&h,65535&f]}}(i,o,n,a),{u_matrix:e,u_opacity:r})},Nr={fillExtrusion:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fillExtrusionPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_height_factor:new t.Uniform1f(e,r.u_height_factor),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fill:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},fillPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},fillOutline:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world)}},fillOutlinePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},circle:function(e,r){return{u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_scale_with_map:new t.Uniform1i(e,r.u_scale_with_map),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},collisionBox:br,collisionCircle:br,debug:function(e,r){return{u_color:new t.UniformColor(e,r.u_color),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},clippingMask:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmap:function(e,r){return{u_extrude_scale:new t.Uniform1f(e,r.u_extrude_scale),u_intensity:new t.Uniform1f(e,r.u_intensity),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmapTexture:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_color_ramp:new t.Uniform1i(e,r.u_color_ramp),u_opacity:new t.Uniform1f(e,r.u_opacity)}},hillshade:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_latrange:new t.Uniform2f(e,r.u_latrange),u_light:new t.Uniform2f(e,r.u_light),u_shadow:new t.UniformColor(e,r.u_shadow),u_highlight:new t.UniformColor(e,r.u_highlight),u_accent:new t.UniformColor(e,r.u_accent)}},hillshadePrepare:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_dimension:new t.Uniform2f(e,r.u_dimension),u_zoom:new t.Uniform1f(e,r.u_zoom),u_maxzoom:new t.Uniform1f(e,r.u_maxzoom)}},line:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels)}},lineGradient:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_image:new t.Uniform1i(e,r.u_image)}},linePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_texsize:new t.Uniform2f(e,r.u_texsize),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_image:new t.Uniform1i(e,r.u_image),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},lineSDF:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_patternscale_a:new t.Uniform2f(e,r.u_patternscale_a),u_patternscale_b:new t.Uniform2f(e,r.u_patternscale_b),u_sdfgamma:new t.Uniform1f(e,r.u_sdfgamma),u_image:new t.Uniform1i(e,r.u_image),u_tex_y_a:new t.Uniform1f(e,r.u_tex_y_a),u_tex_y_b:new t.Uniform1f(e,r.u_tex_y_b),u_mix:new t.Uniform1f(e,r.u_mix)}},raster:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_tl_parent:new t.Uniform2f(e,r.u_tl_parent),u_scale_parent:new t.Uniform1f(e,r.u_scale_parent),u_buffer_scale:new t.Uniform1f(e,r.u_buffer_scale),u_fade_t:new t.Uniform1f(e,r.u_fade_t),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image0:new t.Uniform1i(e,r.u_image0),u_image1:new t.Uniform1i(e,r.u_image1),u_brightness_low:new t.Uniform1f(e,r.u_brightness_low),u_brightness_high:new t.Uniform1f(e,r.u_brightness_high),u_saturation_factor:new t.Uniform1f(e,r.u_saturation_factor),u_contrast_factor:new t.Uniform1f(e,r.u_contrast_factor),u_spin_weights:new t.Uniform3f(e,r.u_spin_weights)}},symbolIcon:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1f(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture)}},symbolSDF:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1f(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture),u_gamma_scale:new t.Uniform1f(e,r.u_gamma_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_is_halo:new t.Uniform1f(e,r.u_is_halo)}},background:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_color:new t.UniformColor(e,r.u_color)}},backgroundPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image:new t.Uniform1i(e,r.u_image),u_pattern_tl_a:new t.Uniform2f(e,r.u_pattern_tl_a),u_pattern_br_a:new t.Uniform2f(e,r.u_pattern_br_a),u_pattern_tl_b:new t.Uniform2f(e,r.u_pattern_tl_b),u_pattern_br_b:new t.Uniform2f(e,r.u_pattern_br_b),u_texsize:new t.Uniform2f(e,r.u_texsize),u_mix:new t.Uniform1f(e,r.u_mix),u_pattern_size_a:new t.Uniform2f(e,r.u_pattern_size_a),u_pattern_size_b:new t.Uniform2f(e,r.u_pattern_size_b),u_scale_a:new t.Uniform1f(e,r.u_scale_a),u_scale_b:new t.Uniform1f(e,r.u_scale_b),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_tile_units_to_pixels:new t.Uniform1f(e,r.u_tile_units_to_pixels)}}};function jr(e,r){for(var n=e.sort(function(t,e){return t.tileID.isLessThan(e.tileID)?-1:e.tileID.isLessThan(t.tileID)?1:0}),i=0;i<n.length;i++){var a={},o=n[i],s=n.slice(i+1);Ur(o.tileID.wrapped(),o.tileID,s,new t.OverscaledTileID(0,o.tileID.wrap+1,0,0,0),a),o.setMask(a,r)}}function Ur(e,r,n,i,a){for(var o=0;o<n.length;o++){var s=n[o];if(i.isLessThan(s.tileID))break;if(r.key===s.tileID.key)return;if(s.tileID.isChildOf(r)){for(var l=r.children(1/0),c=0;c<l.length;c++)Ur(e,l[c],n.slice(o),i,a);return}}var u=r.overscaledZ-e.overscaledZ,h=new t.CanonicalTileID(u,r.canonical.x-(e.canonical.x<<u),r.canonical.y-(e.canonical.y<<u));a[h.key]=a[h.key]||h}function Vr(t,e,r,n,i){for(var a=t.context,o=a.gl,s=i?t.useProgram(\"collisionCircle\"):t.useProgram(\"collisionBox\"),l=0;l<n.length;l++){var c=n[l],u=e.getTile(c),h=u.getBucket(r);if(h){var f=i?h.collisionCircle:h.collisionBox;f&&s.draw(a,i?o.TRIANGLES:o.LINES,Tt.disabled,At.disabled,t.colorModeForRenderPass(),St.disabled,_r(c.posMatrix,t.transform,u),r.id,f.layoutVertexBuffer,f.indexBuffer,f.segments,null,t.transform.zoom,null,null,f.collisionVertexBuffer)}}}var qr=t.identity(new Float32Array(16));function Hr(e,r,n,i,a,o){var s=t.getAnchorAlignment(e),l=-(s.horizontalAlign-.5)*r,c=-(s.verticalAlign-.5)*n,u=t.evaluateRadialOffset(e,i);return new t.Point((l/a+u[0])*o,(c/a+u[1])*o)}function Gr(e,r,n,i,a,o,s,l,c,u){var h=e.text.placedSymbolArray,f=e.text.dynamicLayoutVertexArray;f.clear();for(var p=0;p<h.length;p++){var d=h.get(p),g=!d.hidden&&d.crossTileID?i[d.crossTileID]:null;if(g){var v=new t.Point(d.anchorX,d.anchorY),m=Zt(v,n?l:s),y=.5+o.cameraToCenterDistance/m.signedDistanceFromCamera*.5,x=a.evaluateSizeForFeature(e.textSizeData,u,d)*y/t.ONE_EM;n&&(x*=e.tilePixelRatio/c);for(var b=g.width,_=g.height,w=g.radialOffset,k=g.textBoxScale,T=Hr(g.anchor,b,_,w,k,x),A=n?Zt(v.add(T),s).point:m.point.add(r?T.rotate(-o.angle):T),M=0;M<d.numGlyphs;M++)t.addDynamicAttributes(f,A,0)}else ie(d.numGlyphs,f)}e.text.dynamicLayoutVertexBuffer.updateData(f)}function Yr(e,r,n,i,a,o,s,l,c,u,h,f,p){for(var d,g,v=e.context,m=v.gl,y=e.transform,x=\"map\"===l,b=\"map\"===c,_=x&&\"point\"!==n.layout.get(\"symbol-placement\"),w=x&&!b&&!_,k=void 0!==n.layout.get(\"symbol-sort-key\").constantOr(1),T=e.depthModeForSublayer(0,Tt.ReadOnly),A=n.layout.get(\"text-variable-anchor\"),M=[],S=0,E=i;S<E.length;S+=1){var C=E[S],L=r.getTile(C),P=L.getBucket(n);if(P){var O=a?P.text:P.icon;if(O&&O.segments.get().length){var z=O.programConfigurations.get(n.id),I=a||P.sdfIcons,D=a?P.textSizeData:P.iconSizeData;d||(d=e.useProgram(I?\"symbolSDF\":\"symbolIcon\",z),g=t.evaluateSizeForZoom(D,y.zoom)),v.activeTexture.set(m.TEXTURE0);var R=void 0,F=void 0,B=void 0;if(a)F=L.glyphAtlasTexture,B=m.LINEAR,R=L.glyphAtlasTexture.size;else{var N=1!==n.layout.get(\"icon-size\").constantOr(0)||P.iconsNeedLinear,j=b||0!==y.pitch;F=L.imageAtlasTexture,B=I||e.options.rotating||e.options.zooming||N||j?m.LINEAR:m.NEAREST,R=L.imageAtlasTexture.size}var U=le(L,1,e.transform.zoom),V=Wt(C.posMatrix,b,x,e.transform,U),q=Xt(C.posMatrix,b,x,e.transform,U);if(_)Kt(P,C.posMatrix,e,a,V,q,b,u);else if(a&&g&&A){var H=Math.pow(2,y.zoom-L.tileID.overscaledZ);Gr(P,x,b,p,t.symbolSize,y,V,C.posMatrix,H,g)}var G=e.translatePosMatrix(C.posMatrix,L,o,s),Y=_||a&&A?qr:V,W=e.translatePosMatrix(q,L,o,s,!0),X=I&&0!==n.paint.get(a?\"text-halo-width\":\"icon-halo-width\").constantOr(1),Z={program:d,buffers:O,uniformValues:I?Rr(D.kind,g,w,b,e,G,Y,W,a,R,!0):Dr(D.kind,g,w,b,e,G,Y,W,a,R),atlasTexture:F,atlasInterpolation:B,isSDF:I,hasHalo:X};if(k)for(var J=0,K=O.segments.get();J<K.length;J+=1){var $=K[J];M.push({segments:new t.SegmentVector([$]),sortKey:$.sortKey,state:Z})}else M.push({segments:O.segments,sortKey:0,state:Z})}}}k&&M.sort(function(t,e){return t.sortKey-e.sortKey});for(var Q=0,tt=M;Q<tt.length;Q+=1){var et=tt[Q],rt=et.state;if(rt.atlasTexture.bind(rt.atlasInterpolation,m.CLAMP_TO_EDGE),rt.isSDF){var nt=rt.uniformValues;rt.hasHalo&&(nt.u_is_halo=1,Wr(rt.buffers,et.segments,n,e,rt.program,T,h,f,nt)),nt.u_is_halo=0}Wr(rt.buffers,et.segments,n,e,rt.program,T,h,f,rt.uniformValues)}}function Wr(t,e,r,n,i,a,o,s,l){var c=n.context,u=c.gl;i.draw(c,u.TRIANGLES,a,o,s,St.disabled,l,r.id,t.layoutVertexBuffer,t.indexBuffer,e,r.paint,n.transform.zoom,t.programConfigurations.get(r.id),t.dynamicLayoutVertexBuffer,t.opacityVertexBuffer)}function Xr(t,e,r,n,i,a,o){var s,l,c,u,h,f=t.context.gl,p=r.paint.get(\"fill-pattern\"),d=p&&p.constantOr(1),g=r.getCrossfadeParameters();o?(l=d&&!r.getPaintProperty(\"fill-outline-color\")?\"fillOutlinePattern\":\"fillOutline\",s=f.LINES):(l=d?\"fillPattern\":\"fill\",s=f.TRIANGLES);for(var v=0,m=n;v<m.length;v+=1){var y=m[v],x=e.getTile(y);if(!d||x.patternsLoaded()){var b=x.getBucket(r);if(b){var _=b.programConfigurations.get(r.id),w=t.useProgram(l,_);d&&(t.context.activeTexture.set(f.TEXTURE0),x.imageAtlasTexture.bind(f.LINEAR,f.CLAMP_TO_EDGE),_.updatePatternPaintBuffers(g));var k=p.constantOr(null);if(k&&x.imageAtlas){var T=x.imageAtlas.patternPositions[k.to],A=x.imageAtlas.patternPositions[k.from];T&&A&&_.setConstantPatternPositions(T,A)}var M=t.translatePosMatrix(y.posMatrix,x,r.paint.get(\"fill-translate\"),r.paint.get(\"fill-translate-anchor\"));if(o){u=b.indexBuffer2,h=b.segments2;var S=[f.drawingBufferWidth,f.drawingBufferHeight];c=\"fillOutlinePattern\"===l&&d?yr(M,t,g,x,S):mr(M,S)}else u=b.indexBuffer,h=b.segments,c=d?vr(M,t,g,x):gr(M);w.draw(t.context,s,i,t.stencilModeForClipping(y),a,St.disabled,c,r.id,b.layoutVertexBuffer,u,h,r.paint,t.transform.zoom,_)}}}}function Zr(t,e,r,n,i,a,o){for(var s=t.context,l=s.gl,c=r.paint.get(\"fill-extrusion-pattern\"),u=c.constantOr(1),h=r.getCrossfadeParameters(),f=r.paint.get(\"fill-extrusion-opacity\"),p=0,d=n;p<d.length;p+=1){var g=d[p],v=e.getTile(g),m=v.getBucket(r);if(m){var y=m.programConfigurations.get(r.id),x=t.useProgram(u?\"fillExtrusionPattern\":\"fillExtrusion\",y);u&&(t.context.activeTexture.set(l.TEXTURE0),v.imageAtlasTexture.bind(l.LINEAR,l.CLAMP_TO_EDGE),y.updatePatternPaintBuffers(h));var b=c.constantOr(null);if(b&&v.imageAtlas){var _=v.imageAtlas.patternPositions[b.to],w=v.imageAtlas.patternPositions[b.from];_&&w&&y.setConstantPatternPositions(_,w)}var k=t.translatePosMatrix(g.posMatrix,v,r.paint.get(\"fill-extrusion-translate\"),r.paint.get(\"fill-extrusion-translate-anchor\")),T=r.paint.get(\"fill-extrusion-vertical-gradient\"),A=u?dr(k,t,T,f,g,h,v):pr(k,t,T,f);x.draw(s,s.gl.TRIANGLES,i,a,o,St.backCCW,A,r.id,m.layoutVertexBuffer,m.indexBuffer,m.segments,r.paint,t.transform.zoom,y)}}}function Jr(t,e,r,n,i,a){var o=t.context,s=o.gl,l=e.fbo;if(l){var c=t.useProgram(\"hillshade\");o.activeTexture.set(s.TEXTURE0),s.bindTexture(s.TEXTURE_2D,l.colorAttachment.get());var u=Ar(t,e,r);e.maskedBoundsBuffer&&e.maskedIndexBuffer&&e.segments?c.draw(o,s.TRIANGLES,n,i,a,St.disabled,u,r.id,e.maskedBoundsBuffer,e.maskedIndexBuffer,e.segments):c.draw(o,s.TRIANGLES,n,i,a,St.disabled,u,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}}function Kr(e,r,n,i,a,o,s){var l=e.context,c=l.gl;if(r.dem&&r.dem.data){var u=r.dem.dim,h=r.dem.stride,f=r.dem.getPixels();if(l.activeTexture.set(c.TEXTURE1),l.pixelStoreUnpackPremultiplyAlpha.set(!1),r.demTexture=r.demTexture||e.getTileTexture(h),r.demTexture){var p=r.demTexture;p.update(f,{premultiply:!1}),p.bind(c.NEAREST,c.CLAMP_TO_EDGE)}else r.demTexture=new t.Texture(l,f,c.RGBA,{premultiply:!1}),r.demTexture.bind(c.NEAREST,c.CLAMP_TO_EDGE);l.activeTexture.set(c.TEXTURE0);var d=r.fbo;if(!d){var g=new t.Texture(l,{width:u,height:u,data:null},c.RGBA);g.bind(c.LINEAR,c.CLAMP_TO_EDGE),(d=r.fbo=l.createFramebuffer(u,u)).colorAttachment.set(g.texture)}l.bindFramebuffer.set(d.framebuffer),l.viewport.set([0,0,u,u]),e.useProgram(\"hillshadePrepare\").draw(l,c.TRIANGLES,a,o,s,St.disabled,Mr(r,i),n.id,e.rasterBoundsBuffer,e.quadTriangleIndexBuffer,e.rasterBoundsSegments),r.needsHillshadePrepare=!1}}function $r(e,r,n,i,a){var o=i.paint.get(\"raster-fade-duration\");if(o>0){var s=t.browser.now(),l=(s-e.timeAdded)/o,c=r?(s-r.timeAdded)/o:-1,u=n.getSource(),h=a.coveringZoomLevel({tileSize:u.tileSize,roundZoom:u.roundZoom}),f=!r||Math.abs(r.tileID.overscaledZ-h)>Math.abs(e.tileID.overscaledZ-h),p=f&&e.refreshedUponExpiration?1:t.clamp(f?l:1-c,0,1);return e.refreshedUponExpiration&&l>=1&&(e.refreshedUponExpiration=!1),r?{opacity:1,mix:1-p}:{opacity:p,mix:0}}return{opacity:1,mix:0}}function Qr(e,r,n){var i=e.context,a=i.gl,o=n.posMatrix,s=e.useProgram(\"debug\"),l=Tt.disabled,c=At.disabled,u=e.colorModeForRenderPass(),h=\"$debug\";s.draw(i,a.LINE_STRIP,l,c,u,St.disabled,wr(o,t.Color.red),h,e.debugBuffer,e.tileBorderIndexBuffer,e.debugSegments);for(var f=r.getTileByID(n.key).latestRawTileData,p=f&&f.byteLength||0,d=Math.floor(p/1024),g=function(t,e,r,n){n=n||1;var i,a,o,s,l,c,u,h,f=[];for(i=0,a=t.length;i<a;i++)if(l=tn[t[i]]){for(h=null,o=0,s=l[1].length;o<s;o+=2)-1===l[1][o]&&-1===l[1][o+1]?h=null:(c=e+l[1][o]*n,u=200-l[1][o+1]*n,h&&f.push(h.x,h.y,c,u),h={x:c,y:u});e+=l[0]*n}return f}(n.toString()+\" \"+d+\"kb\",50,0,5),v=new t.StructArrayLayout2i4,m=new t.StructArrayLayout2ui4,y=0;y<g.length;y+=2)v.emplaceBack(g[y],g[y+1]),m.emplaceBack(y,y+1);for(var x=i.createVertexBuffer(v,Re.members),b=i.createIndexBuffer(m),_=t.SegmentVector.simpleSegment(0,0,v.length/2,v.length/2),w=r.getTile(n).tileSize,k=t.EXTENT/(Math.pow(2,e.transform.zoom-n.overscaledZ)*w),T=[[-1,-1],[-1,1],[1,-1],[1,1]],A=0;A<T.length;A++){var M=T[A];s.draw(i,a.LINES,l,c,u,St.disabled,wr(t.translate([],o,[k*M[0],k*M[1],0]),t.Color.white),h,x,b,_)}s.draw(i,a.LINES,l,c,u,St.disabled,wr(o,t.Color.black),h,x,b,_)}var tn={\" \":[16,[]],\"!\":[10,[5,21,5,7,-1,-1,5,2,4,1,5,0,6,1,5,2]],'\"':[16,[4,21,4,14,-1,-1,12,21,12,14]],\"#\":[21,[11,25,4,-7,-1,-1,17,25,10,-7,-1,-1,4,12,18,12,-1,-1,3,6,17,6]],$:[20,[8,25,8,-4,-1,-1,12,25,12,-4,-1,-1,17,18,15,20,12,21,8,21,5,20,3,18,3,16,4,14,5,13,7,12,13,10,15,9,16,8,17,6,17,3,15,1,12,0,8,0,5,1,3,3]],\"%\":[24,[21,21,3,0,-1,-1,8,21,10,19,10,17,9,15,7,14,5,14,3,16,3,18,4,20,6,21,8,21,10,20,13,19,16,19,19,20,21,21,-1,-1,17,7,15,6,14,4,14,2,16,0,18,0,20,1,21,3,21,5,19,7,17,7]],\"&\":[26,[23,12,23,13,22,14,21,14,20,13,19,11,17,6,15,3,13,1,11,0,7,0,5,1,4,2,3,4,3,6,4,8,5,9,12,13,13,14,14,16,14,18,13,20,11,21,9,20,8,18,8,16,9,13,11,10,16,3,18,1,20,0,22,0,23,1,23,2]],\"'\":[10,[5,19,4,20,5,21,6,20,6,18,5,16,4,15]],\"(\":[14,[11,25,9,23,7,20,5,16,4,11,4,7,5,2,7,-2,9,-5,11,-7]],\")\":[14,[3,25,5,23,7,20,9,16,10,11,10,7,9,2,7,-2,5,-5,3,-7]],\"*\":[16,[8,21,8,9,-1,-1,3,18,13,12,-1,-1,13,18,3,12]],\"+\":[26,[13,18,13,0,-1,-1,4,9,22,9]],\",\":[10,[6,1,5,0,4,1,5,2,6,1,6,-1,5,-3,4,-4]],\"-\":[26,[4,9,22,9]],\".\":[10,[5,2,4,1,5,0,6,1,5,2]],\"/\":[22,[20,25,2,-7]],0:[20,[9,21,6,20,4,17,3,12,3,9,4,4,6,1,9,0,11,0,14,1,16,4,17,9,17,12,16,17,14,20,11,21,9,21]],1:[20,[6,17,8,18,11,21,11,0]],2:[20,[4,16,4,17,5,19,6,20,8,21,12,21,14,20,15,19,16,17,16,15,15,13,13,10,3,0,17,0]],3:[20,[5,21,16,21,10,13,13,13,15,12,16,11,17,8,17,6,16,3,14,1,11,0,8,0,5,1,4,2,3,4]],4:[20,[13,21,3,7,18,7,-1,-1,13,21,13,0]],5:[20,[15,21,5,21,4,12,5,13,8,14,11,14,14,13,16,11,17,8,17,6,16,3,14,1,11,0,8,0,5,1,4,2,3,4]],6:[20,[16,18,15,20,12,21,10,21,7,20,5,17,4,12,4,7,5,3,7,1,10,0,11,0,14,1,16,3,17,6,17,7,16,10,14,12,11,13,10,13,7,12,5,10,4,7]],7:[20,[17,21,7,0,-1,-1,3,21,17,21]],8:[20,[8,21,5,20,4,18,4,16,5,14,7,13,11,12,14,11,16,9,17,7,17,4,16,2,15,1,12,0,8,0,5,1,4,2,3,4,3,7,4,9,6,11,9,12,13,13,15,14,16,16,16,18,15,20,12,21,8,21]],9:[20,[16,14,15,11,13,9,10,8,9,8,6,9,4,11,3,14,3,15,4,18,6,20,9,21,10,21,13,20,15,18,16,14,16,9,15,4,13,1,10,0,8,0,5,1,4,3]],\":\":[10,[5,14,4,13,5,12,6,13,5,14,-1,-1,5,2,4,1,5,0,6,1,5,2]],\";\":[10,[5,14,4,13,5,12,6,13,5,14,-1,-1,6,1,5,0,4,1,5,2,6,1,6,-1,5,-3,4,-4]],\"<\":[24,[20,18,4,9,20,0]],\"=\":[26,[4,12,22,12,-1,-1,4,6,22,6]],\">\":[24,[4,18,20,9,4,0]],\"?\":[18,[3,16,3,17,4,19,5,20,7,21,11,21,13,20,14,19,15,17,15,15,14,13,13,12,9,10,9,7,-1,-1,9,2,8,1,9,0,10,1,9,2]],\"@\":[27,[18,13,17,15,15,16,12,16,10,15,9,14,8,11,8,8,9,6,11,5,14,5,16,6,17,8,-1,-1,12,16,10,14,9,11,9,8,10,6,11,5,-1,-1,18,16,17,8,17,6,19,5,21,5,23,7,24,10,24,12,23,15,22,17,20,19,18,20,15,21,12,21,9,20,7,19,5,17,4,15,3,12,3,9,4,6,5,4,7,2,9,1,12,0,15,0,18,1,20,2,21,3,-1,-1,19,16,18,8,18,6,19,5]],A:[18,[9,21,1,0,-1,-1,9,21,17,0,-1,-1,4,7,14,7]],B:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,15,17,13,16,12,13,11,-1,-1,4,11,13,11,16,10,17,9,18,7,18,4,17,2,16,1,13,0,4,0]],C:[21,[18,16,17,18,15,20,13,21,9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5]],D:[21,[4,21,4,0,-1,-1,4,21,11,21,14,20,16,18,17,16,18,13,18,8,17,5,16,3,14,1,11,0,4,0]],E:[19,[4,21,4,0,-1,-1,4,21,17,21,-1,-1,4,11,12,11,-1,-1,4,0,17,0]],F:[18,[4,21,4,0,-1,-1,4,21,17,21,-1,-1,4,11,12,11]],G:[21,[18,16,17,18,15,20,13,21,9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,18,8,-1,-1,13,8,18,8]],H:[22,[4,21,4,0,-1,-1,18,21,18,0,-1,-1,4,11,18,11]],I:[8,[4,21,4,0]],J:[16,[12,21,12,5,11,2,10,1,8,0,6,0,4,1,3,2,2,5,2,7]],K:[21,[4,21,4,0,-1,-1,18,21,4,7,-1,-1,9,12,18,0]],L:[17,[4,21,4,0,-1,-1,4,0,16,0]],M:[24,[4,21,4,0,-1,-1,4,21,12,0,-1,-1,20,21,12,0,-1,-1,20,21,20,0]],N:[22,[4,21,4,0,-1,-1,4,21,18,0,-1,-1,18,21,18,0]],O:[22,[9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,19,8,19,13,18,16,17,18,15,20,13,21,9,21]],P:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,14,17,12,16,11,13,10,4,10]],Q:[22,[9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,19,8,19,13,18,16,17,18,15,20,13,21,9,21,-1,-1,12,4,18,-2]],R:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,15,17,13,16,12,13,11,4,11,-1,-1,11,11,18,0]],S:[20,[17,18,15,20,12,21,8,21,5,20,3,18,3,16,4,14,5,13,7,12,13,10,15,9,16,8,17,6,17,3,15,1,12,0,8,0,5,1,3,3]],T:[16,[8,21,8,0,-1,-1,1,21,15,21]],U:[22,[4,21,4,6,5,3,7,1,10,0,12,0,15,1,17,3,18,6,18,21]],V:[18,[1,21,9,0,-1,-1,17,21,9,0]],W:[24,[2,21,7,0,-1,-1,12,21,7,0,-1,-1,12,21,17,0,-1,-1,22,21,17,0]],X:[20,[3,21,17,0,-1,-1,17,21,3,0]],Y:[18,[1,21,9,11,9,0,-1,-1,17,21,9,11]],Z:[20,[17,21,3,0,-1,-1,3,21,17,21,-1,-1,3,0,17,0]],\"[\":[14,[4,25,4,-7,-1,-1,5,25,5,-7,-1,-1,4,25,11,25,-1,-1,4,-7,11,-7]],\"\\\\\":[14,[0,21,14,-3]],\"]\":[14,[9,25,9,-7,-1,-1,10,25,10,-7,-1,-1,3,25,10,25,-1,-1,3,-7,10,-7]],\"^\":[16,[6,15,8,18,10,15,-1,-1,3,12,8,17,13,12,-1,-1,8,17,8,0]],_:[16,[0,-2,16,-2]],\"`\":[10,[6,21,5,20,4,18,4,16,5,15,6,16,5,17]],a:[19,[15,14,15,0,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],b:[19,[4,21,4,0,-1,-1,4,11,6,13,8,14,11,14,13,13,15,11,16,8,16,6,15,3,13,1,11,0,8,0,6,1,4,3]],c:[18,[15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],d:[19,[15,21,15,0,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],e:[18,[3,8,15,8,15,10,14,12,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],f:[12,[10,21,8,21,6,20,5,17,5,0,-1,-1,2,14,9,14]],g:[19,[15,14,15,-2,14,-5,13,-6,11,-7,8,-7,6,-6,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],h:[19,[4,21,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0]],i:[8,[3,21,4,20,5,21,4,22,3,21,-1,-1,4,14,4,0]],j:[10,[5,21,6,20,7,21,6,22,5,21,-1,-1,6,14,6,-3,5,-6,3,-7,1,-7]],k:[17,[4,21,4,0,-1,-1,14,14,4,4,-1,-1,8,8,15,0]],l:[8,[4,21,4,0]],m:[30,[4,14,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0,-1,-1,15,10,18,13,20,14,23,14,25,13,26,10,26,0]],n:[19,[4,14,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0]],o:[19,[8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3,16,6,16,8,15,11,13,13,11,14,8,14]],p:[19,[4,14,4,-7,-1,-1,4,11,6,13,8,14,11,14,13,13,15,11,16,8,16,6,15,3,13,1,11,0,8,0,6,1,4,3]],q:[19,[15,14,15,-7,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],r:[13,[4,14,4,0,-1,-1,4,8,5,11,7,13,9,14,12,14]],s:[17,[14,11,13,13,10,14,7,14,4,13,3,11,4,9,6,8,11,7,13,6,14,4,14,3,13,1,10,0,7,0,4,1,3,3]],t:[12,[5,21,5,4,6,1,8,0,10,0,-1,-1,2,14,9,14]],u:[19,[4,14,4,4,5,1,7,0,10,0,12,1,15,4,-1,-1,15,14,15,0]],v:[16,[2,14,8,0,-1,-1,14,14,8,0]],w:[22,[3,14,7,0,-1,-1,11,14,7,0,-1,-1,11,14,15,0,-1,-1,19,14,15,0]],x:[17,[3,14,14,0,-1,-1,14,14,3,0]],y:[16,[2,14,8,0,-1,-1,14,14,8,0,6,-4,4,-6,2,-7,1,-7]],z:[17,[14,14,3,0,-1,-1,3,14,14,14,-1,-1,3,0,14,0]],\"{\":[14,[9,25,7,24,6,23,5,21,5,19,6,17,7,16,8,14,8,12,6,10,-1,-1,7,24,6,22,6,20,7,18,8,17,9,15,9,13,8,11,4,9,8,7,9,5,9,3,8,1,7,0,6,-2,6,-4,7,-6,-1,-1,6,8,8,6,8,4,7,2,6,1,5,-1,5,-3,6,-5,7,-6,9,-7]],\"|\":[8,[4,25,4,-7]],\"}\":[14,[5,25,7,24,8,23,9,21,9,19,8,17,7,16,6,14,6,12,8,10,-1,-1,7,24,8,22,8,20,7,18,6,17,5,15,5,13,6,11,10,9,6,7,5,5,5,3,6,1,7,0,8,-2,8,-4,7,-6,-1,-1,8,8,6,6,6,4,7,2,8,1,9,-1,9,-3,8,-5,7,-6,5,-7]],\"~\":[24,[3,6,3,8,4,11,6,12,8,12,10,11,14,8,16,7,18,7,20,8,21,10,-1,-1,3,8,4,10,6,11,8,11,10,10,14,7,16,6,18,6,20,7,21,10,21,12]]},en={symbol:function(t,e,r,n,i){if(\"translucent\"===t.renderPass){var a=At.disabled,o=t.colorModeForRenderPass();0!==r.paint.get(\"icon-opacity\").constantOr(1)&&Yr(t,e,r,n,!1,r.paint.get(\"icon-translate\"),r.paint.get(\"icon-translate-anchor\"),r.layout.get(\"icon-rotation-alignment\"),r.layout.get(\"icon-pitch-alignment\"),r.layout.get(\"icon-keep-upright\"),a,o,i),0!==r.paint.get(\"text-opacity\").constantOr(1)&&Yr(t,e,r,n,!0,r.paint.get(\"text-translate\"),r.paint.get(\"text-translate-anchor\"),r.layout.get(\"text-rotation-alignment\"),r.layout.get(\"text-pitch-alignment\"),r.layout.get(\"text-keep-upright\"),a,o,i),e.map.showCollisionBoxes&&function(t,e,r,n){Vr(t,e,r,n,!1),Vr(t,e,r,n,!0)}(t,e,r,n)}},circle:function(t,e,r,n){if(\"translucent\"===t.renderPass){var i=r.paint.get(\"circle-opacity\"),a=r.paint.get(\"circle-stroke-width\"),o=r.paint.get(\"circle-stroke-opacity\");if(0!==i.constantOr(1)||0!==a.constantOr(1)&&0!==o.constantOr(1))for(var s=t.context,l=s.gl,c=t.depthModeForSublayer(0,Tt.ReadOnly),u=At.disabled,h=t.colorModeForRenderPass(),f=0;f<n.length;f++){var p=n[f],d=e.getTile(p),g=d.getBucket(r);if(g){var v=g.programConfigurations.get(r.id);t.useProgram(\"circle\",v).draw(s,l.TRIANGLES,c,u,h,St.disabled,xr(t,p,d,r),r.id,g.layoutVertexBuffer,g.indexBuffer,g.segments,r.paint,t.transform.zoom,v)}}}},heatmap:function(e,r,n,i){if(0!==n.paint.get(\"heatmap-opacity\"))if(\"offscreen\"===e.renderPass){var a=e.context,o=a.gl,s=e.depthModeForSublayer(0,Tt.ReadOnly),l=At.disabled,c=new Mt([o.ONE,o.ONE],t.Color.transparent,[!0,!0,!0,!0]);!function(t,e,r){var n=t.gl;t.activeTexture.set(n.TEXTURE1),t.viewport.set([0,0,e.width/4,e.height/4]);var i=r.heatmapFbo;if(i)n.bindTexture(n.TEXTURE_2D,i.colorAttachment.get()),t.bindFramebuffer.set(i.framebuffer);else{var a=n.createTexture();n.bindTexture(n.TEXTURE_2D,a),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,n.LINEAR),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,n.LINEAR),i=r.heatmapFbo=t.createFramebuffer(e.width/4,e.height/4),function t(e,r,n,i){var a=e.gl;a.texImage2D(a.TEXTURE_2D,0,a.RGBA,r.width/4,r.height/4,0,a.RGBA,e.extTextureHalfFloat?e.extTextureHalfFloat.HALF_FLOAT_OES:a.UNSIGNED_BYTE,null),i.colorAttachment.set(n),e.extTextureHalfFloat&&a.checkFramebufferStatus(a.FRAMEBUFFER)!==a.FRAMEBUFFER_COMPLETE&&(e.extTextureHalfFloat=null,i.colorAttachment.setDirty(),t(e,r,n,i))}(t,e,a,i)}}(a,e,n),a.clear({color:t.Color.transparent});for(var u=0;u<i.length;u++){var h=i[u];if(!r.hasRenderableParent(h)){var f=r.getTile(h),p=f.getBucket(n);if(p){var d=p.programConfigurations.get(n.id),g=e.useProgram(\"heatmap\",d),v=e.transform.zoom;g.draw(a,o.TRIANGLES,s,l,c,St.disabled,Tr(h.posMatrix,f,v,n.paint.get(\"heatmap-intensity\")),n.id,p.layoutVertexBuffer,p.indexBuffer,p.segments,n.paint,e.transform.zoom,d)}}}a.viewport.set([0,0,e.width,e.height])}else\"translucent\"===e.renderPass&&(e.context.setColorMode(e.colorModeForRenderPass()),function(e,r){var n=e.context,i=n.gl,a=r.heatmapFbo;if(a){n.activeTexture.set(i.TEXTURE0),i.bindTexture(i.TEXTURE_2D,a.colorAttachment.get()),n.activeTexture.set(i.TEXTURE1);var o=r.colorRampTexture;o||(o=r.colorRampTexture=new t.Texture(n,r.colorRamp,i.RGBA)),o.bind(i.LINEAR,i.CLAMP_TO_EDGE),e.useProgram(\"heatmapTexture\").draw(n,i.TRIANGLES,Tt.disabled,At.disabled,e.colorModeForRenderPass(),St.disabled,function(e,r,n,i){var a=t.create();t.ortho(a,0,e.width,e.height,0,0,1);var o=e.context.gl;return{u_matrix:a,u_world:[o.drawingBufferWidth,o.drawingBufferHeight],u_image:n,u_color_ramp:i,u_opacity:r.paint.get(\"heatmap-opacity\")}}(e,r,0,1),r.id,e.viewportBuffer,e.quadTriangleIndexBuffer,e.viewportSegments,r.paint,e.transform.zoom)}}(e,n))},line:function(e,r,n,i){if(\"translucent\"===e.renderPass){var a=n.paint.get(\"line-opacity\"),o=n.paint.get(\"line-width\");if(0!==a.constantOr(1)&&0!==o.constantOr(1)){var s=e.depthModeForSublayer(0,Tt.ReadOnly),l=e.colorModeForRenderPass(),c=n.paint.get(\"line-dasharray\"),u=n.paint.get(\"line-pattern\"),h=u.constantOr(1),f=n.paint.get(\"line-gradient\"),p=n.getCrossfadeParameters(),d=c?\"lineSDF\":h?\"linePattern\":f?\"lineGradient\":\"line\",g=e.context,v=g.gl,m=!0;if(f){g.activeTexture.set(v.TEXTURE0);var y=n.gradientTexture;if(!n.gradient)return;y||(y=n.gradientTexture=new t.Texture(g,n.gradient,v.RGBA)),y.bind(v.LINEAR,v.CLAMP_TO_EDGE)}for(var x=0,b=i;x<b.length;x+=1){var _=b[x],w=r.getTile(_);if(!h||w.patternsLoaded()){var k=w.getBucket(n);if(k){var T=k.programConfigurations.get(n.id),A=e.context.program.get(),M=e.useProgram(d,T),S=m||M.program!==A,E=u.constantOr(null);if(E&&w.imageAtlas){var C=w.imageAtlas.patternPositions[E.to],L=w.imageAtlas.patternPositions[E.from];C&&L&&T.setConstantPatternPositions(C,L)}var P=c?Pr(e,w,n,c,p):h?Lr(e,w,n,p):f?Cr(e,w,n):Er(e,w,n);c&&(S||e.lineAtlas.dirty)?(g.activeTexture.set(v.TEXTURE0),e.lineAtlas.bind(g)):h&&(g.activeTexture.set(v.TEXTURE0),w.imageAtlasTexture.bind(v.LINEAR,v.CLAMP_TO_EDGE),T.updatePatternPaintBuffers(p)),M.draw(g,v.TRIANGLES,s,e.stencilModeForClipping(_),l,St.disabled,P,n.id,k.layoutVertexBuffer,k.indexBuffer,k.segments,n.paint,e.transform.zoom,T),m=!1}}}}}},fill:function(e,r,n,i){var a=n.paint.get(\"fill-color\"),o=n.paint.get(\"fill-opacity\");if(0!==o.constantOr(1)){var s=e.colorModeForRenderPass(),l=n.paint.get(\"fill-pattern\"),c=e.opaquePassEnabledForLayer()&&!l.constantOr(1)&&1===a.constantOr(t.Color.transparent).a&&1===o.constantOr(0)?\"opaque\":\"translucent\";if(e.renderPass===c){var u=e.depthModeForSublayer(1,\"opaque\"===e.renderPass?Tt.ReadWrite:Tt.ReadOnly);Xr(e,r,n,i,u,s,!1)}if(\"translucent\"===e.renderPass&&n.paint.get(\"fill-antialias\")){var h=e.depthModeForSublayer(n.getPaintProperty(\"fill-outline-color\")?2:0,Tt.ReadOnly);Xr(e,r,n,i,h,s,!0)}}},\"fill-extrusion\":function(t,e,r,n){var i=r.paint.get(\"fill-extrusion-opacity\");if(0!==i&&\"translucent\"===t.renderPass){var a=new Tt(t.context.gl.LEQUAL,Tt.ReadWrite,t.depthRangeFor3D);if(1!==i||r.paint.get(\"fill-extrusion-pattern\").constantOr(1))Zr(t,e,r,n,a,At.disabled,Mt.disabled),Zr(t,e,r,n,a,t.stencilModeFor3D(),t.colorModeForRenderPass());else{var o=t.colorModeForRenderPass();Zr(t,e,r,n,a,At.disabled,o)}}},hillshade:function(t,e,r,n){if(\"offscreen\"===t.renderPass||\"translucent\"===t.renderPass){for(var i=t.context,a=e.getSource().maxzoom,o=t.depthModeForSublayer(0,Tt.ReadOnly),s=At.disabled,l=t.colorModeForRenderPass(),c=0,u=n;c<u.length;c+=1){var h=u[c],f=e.getTile(h);f.needsHillshadePrepare&&\"offscreen\"===t.renderPass?Kr(t,f,r,a,o,s,l):\"translucent\"===t.renderPass&&Jr(t,f,r,o,s,l)}i.viewport.set([0,0,t.width,t.height])}},raster:function(t,e,r,n){if(\"translucent\"===t.renderPass&&0!==r.paint.get(\"raster-opacity\"))for(var i=t.context,a=i.gl,o=e.getSource(),s=t.useProgram(\"raster\"),l=At.disabled,c=t.colorModeForRenderPass(),u=n.length&&n[0].overscaledZ,h=!t.options.moving,f=0,p=n;f<p.length;f+=1){var d=p[f],g=t.depthModeForSublayer(d.overscaledZ-u,1===r.paint.get(\"raster-opacity\")?Tt.ReadWrite:Tt.ReadOnly,a.LESS),v=e.getTile(d),m=t.transform.calculatePosMatrix(d.toUnwrapped(),h);v.registerFadeDuration(r.paint.get(\"raster-fade-duration\"));var y=e.findLoadedParent(d,0),x=$r(v,y,e,r,t.transform),b=void 0,_=void 0,w=\"nearest\"===r.paint.get(\"raster-resampling\")?a.NEAREST:a.LINEAR;i.activeTexture.set(a.TEXTURE0),v.texture.bind(w,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),i.activeTexture.set(a.TEXTURE1),y?(y.texture.bind(w,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),b=Math.pow(2,y.tileID.overscaledZ-v.tileID.overscaledZ),_=[v.tileID.canonical.x*b%1,v.tileID.canonical.y*b%1]):v.texture.bind(w,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST);var k=Ir(m,_||[0,0],b||1,x,r);o instanceof L?s.draw(i,a.TRIANGLES,g,l,c,St.disabled,k,r.id,o.boundsBuffer,t.quadTriangleIndexBuffer,o.boundsSegments):v.maskedBoundsBuffer&&v.maskedIndexBuffer&&v.segments?s.draw(i,a.TRIANGLES,g,l,c,St.disabled,k,r.id,v.maskedBoundsBuffer,v.maskedIndexBuffer,v.segments,r.paint,t.transform.zoom):s.draw(i,a.TRIANGLES,g,l,c,St.disabled,k,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}},background:function(t,e,r){var n=r.paint.get(\"background-color\"),i=r.paint.get(\"background-opacity\");if(0!==i){var a=t.context,o=a.gl,s=t.transform,l=s.tileSize,c=r.paint.get(\"background-pattern\");if(!t.isPatternMissing(c)){var u=c||1!==n.a||1!==i?\"translucent\":\"opaque\";if(t.renderPass===u){var h=At.disabled,f=t.depthModeForSublayer(0,\"opaque\"===u?Tt.ReadWrite:Tt.ReadOnly),p=t.colorModeForRenderPass(),d=t.useProgram(c?\"backgroundPattern\":\"background\"),g=s.coveringTiles({tileSize:l});c&&(a.activeTexture.set(o.TEXTURE0),t.imageManager.bind(t.context));for(var v=r.getCrossfadeParameters(),m=0,y=g;m<y.length;m+=1){var x=y[m],b=t.transform.calculatePosMatrix(x.toUnwrapped()),_=c?Br(b,i,t,c,{tileID:x,tileSize:l},v):Fr(b,i,n);d.draw(a,o.TRIANGLES,f,h,p,St.disabled,_,r.id,t.tileExtentBuffer,t.quadTriangleIndexBuffer,t.tileExtentSegments)}}}}},debug:function(t,e,r){for(var n=0;n<r.length;n++)Qr(t,e,r[n])},custom:function(t,e,r){var n=t.context,i=r.implementation;if(\"offscreen\"===t.renderPass){var a=i.prerender;a&&(t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),a.call(i,n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState())}else if(\"translucent\"===t.renderPass){t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),n.setStencilMode(At.disabled);var o=\"3d\"===i.renderingMode?new Tt(t.context.gl.LEQUAL,Tt.ReadWrite,t.depthRangeFor3D):t.depthModeForSublayer(0,Tt.ReadOnly);n.setDepthMode(o),i.render(n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState(),n.bindFramebuffer.set(null)}}},rn=function(e,r){this.context=new Et(e),this.transform=r,this._tileTextures={},this.setup(),this.numSublayers=Ct.maxUnderzooming+Ct.maxOverzooming+1,this.depthEpsilon=1/Math.pow(2,16),this.depthRboNeedsClear=!0,this.emptyProgramConfiguration=new t.ProgramConfiguration,this.crossTileSymbolIndex=new Pe};function nn(t,e){if(t.y>e.y){var r=t;t=e,e=r}return{x0:t.x,y0:t.y,x1:e.x,y1:e.y,dx:e.x-t.x,dy:e.y-t.y}}function an(t,e,r,n,i){var a=Math.max(r,Math.floor(e.y0)),o=Math.min(n,Math.ceil(e.y1));if(t.x0===e.x0&&t.y0===e.y0?t.x0+e.dy/t.dy*t.dx<e.x1:t.x1-e.dy/t.dy*t.dx<e.x0){var s=t;t=e,e=s}for(var l=t.dx/t.dy,c=e.dx/e.dy,u=t.dx>0,h=e.dx<0,f=a;f<o;f++){var p=l*Math.max(0,Math.min(t.dy,f+u-t.y0))+t.x0,d=c*Math.max(0,Math.min(e.dy,f+h-e.y0))+e.x0;i(Math.floor(d),Math.ceil(p),f)}}function on(t,e,r,n,i,a){var o,s=nn(t,e),l=nn(e,r),c=nn(r,t);s.dy>l.dy&&(o=s,s=l,l=o),s.dy>c.dy&&(o=s,s=c,c=o),l.dy>c.dy&&(o=l,l=c,c=o),s.dy&&an(c,s,n,i,a),l.dy&&an(c,l,n,i,a)}rn.prototype.resize=function(e,r){var n=this.context.gl;if(this.width=e*t.browser.devicePixelRatio,this.height=r*t.browser.devicePixelRatio,this.context.viewport.set([0,0,this.width,this.height]),this.style)for(var i=0,a=this.style._order;i<a.length;i+=1){var o=a[i];this.style._layers[o].resize()}this.depthRbo&&(n.deleteRenderbuffer(this.depthRbo),this.depthRbo=null)},rn.prototype.setup=function(){var e=this.context,r=new t.StructArrayLayout2i4;r.emplaceBack(0,0),r.emplaceBack(t.EXTENT,0),r.emplaceBack(0,t.EXTENT),r.emplaceBack(t.EXTENT,t.EXTENT),this.tileExtentBuffer=e.createVertexBuffer(r,Re.members),this.tileExtentSegments=t.SegmentVector.simpleSegment(0,0,4,2);var n=new t.StructArrayLayout2i4;n.emplaceBack(0,0),n.emplaceBack(t.EXTENT,0),n.emplaceBack(0,t.EXTENT),n.emplaceBack(t.EXTENT,t.EXTENT),this.debugBuffer=e.createVertexBuffer(n,Re.members),this.debugSegments=t.SegmentVector.simpleSegment(0,0,4,5);var i=new t.StructArrayLayout4i8;i.emplaceBack(0,0,0,0),i.emplaceBack(t.EXTENT,0,t.EXTENT,0),i.emplaceBack(0,t.EXTENT,0,t.EXTENT),i.emplaceBack(t.EXTENT,t.EXTENT,t.EXTENT,t.EXTENT),this.rasterBoundsBuffer=e.createVertexBuffer(i,t.rasterBoundsAttributes.members),this.rasterBoundsSegments=t.SegmentVector.simpleSegment(0,0,4,2);var a=new t.StructArrayLayout2i4;a.emplaceBack(0,0),a.emplaceBack(1,0),a.emplaceBack(0,1),a.emplaceBack(1,1),this.viewportBuffer=e.createVertexBuffer(a,Re.members),this.viewportSegments=t.SegmentVector.simpleSegment(0,0,4,2);var o=new t.StructArrayLayout1ui2;o.emplaceBack(0),o.emplaceBack(1),o.emplaceBack(3),o.emplaceBack(2),o.emplaceBack(0),this.tileBorderIndexBuffer=e.createIndexBuffer(o);var s=new t.StructArrayLayout3ui6;s.emplaceBack(0,1,2),s.emplaceBack(2,1,3),this.quadTriangleIndexBuffer=e.createIndexBuffer(s);var l=this.context.gl;this.stencilClearMode=new At({func:l.ALWAYS,mask:0},0,255,l.ZERO,l.ZERO,l.ZERO)},rn.prototype.clearStencil=function(){var e=this.context,r=e.gl;this.nextStencilID=1,this.currentStencilSource=void 0;var n=t.create();t.ortho(n,0,this.width,this.height,0,0,1),t.scale(n,n,[r.drawingBufferWidth,r.drawingBufferHeight,0]),this.useProgram(\"clippingMask\").draw(e,r.TRIANGLES,Tt.disabled,this.stencilClearMode,Mt.disabled,St.disabled,kr(n),\"$clipping\",this.viewportBuffer,this.quadTriangleIndexBuffer,this.viewportSegments)},rn.prototype._renderTileClippingMasks=function(t,e){if(this.currentStencilSource!==t.source&&t.isTileClipped()&&e&&e.length){this.currentStencilSource=t.source;var r=this.context,n=r.gl;this.nextStencilID+e.length>256&&this.clearStencil(),r.setColorMode(Mt.disabled),r.setDepthMode(Tt.disabled);var i=this.useProgram(\"clippingMask\");this._tileClippingMaskIDs={};for(var a=0,o=e;a<o.length;a+=1){var s=o[a],l=this._tileClippingMaskIDs[s.key]=this.nextStencilID++;i.draw(r,n.TRIANGLES,Tt.disabled,new At({func:n.ALWAYS,mask:0},l,255,n.KEEP,n.KEEP,n.REPLACE),Mt.disabled,St.disabled,kr(s.posMatrix),\"$clipping\",this.tileExtentBuffer,this.quadTriangleIndexBuffer,this.tileExtentSegments)}}},rn.prototype.stencilModeFor3D=function(){this.nextStencilID+1>256&&this.clearStencil();var t=this.nextStencilID++,e=this.context.gl;return new At({func:e.NOTEQUAL,mask:255},t,255,e.KEEP,e.KEEP,e.REPLACE)},rn.prototype.stencilModeForClipping=function(t){var e=this.context.gl;return new At({func:e.EQUAL,mask:255},this._tileClippingMaskIDs[t.key],0,e.KEEP,e.KEEP,e.REPLACE)},rn.prototype.colorModeForRenderPass=function(){var e=this.context.gl;return this._showOverdrawInspector?new Mt([e.CONSTANT_COLOR,e.ONE],new t.Color(1/8,1/8,1/8,0),[!0,!0,!0,!0]):\"opaque\"===this.renderPass?Mt.unblended:Mt.alphaBlended},rn.prototype.depthModeForSublayer=function(t,e,r){if(!this.opaquePassEnabledForLayer())return Tt.disabled;var n=1-((1+this.currentLayer)*this.numSublayers+t)*this.depthEpsilon;return new Tt(r||this.context.gl.LEQUAL,e,[n,n])},rn.prototype.opaquePassEnabledForLayer=function(){return this.currentLayer<this.opaquePassCutoff},rn.prototype.render=function(e,r){this.style=e,this.options=r,this.lineAtlas=e.lineAtlas,this.imageManager=e.imageManager,this.glyphManager=e.glyphManager,this.symbolFadeChange=e.placement.symbolFadeChange(t.browser.now()),this.imageManager.beginFrame();var n=this.style._order,i=this.style.sourceCaches;for(var a in i){var o=i[a];o.used&&o.prepare(this.context)}var s={},l={},c={};for(var u in i){var h=i[u];s[u]=h.getVisibleCoordinates(),l[u]=s[u].slice().reverse(),c[u]=h.getVisibleCoordinates(!0).reverse()}for(var f in i){var p=i[f],d=p.getSource();if(\"raster\"===d.type||\"raster-dem\"===d.type){for(var g=[],v=0,m=s[f];v<m.length;v+=1){var y=m[v];g.push(p.getTile(y))}jr(g,this.context)}}this.opaquePassCutoff=1/0;for(var x=0;x<n.length;x++){var b=n[x];if(this.style._layers[b].is3D()){this.opaquePassCutoff=x;break}}this.renderPass=\"offscreen\",this.depthRboNeedsClear=!0;for(var _=0,w=n;_<w.length;_+=1){var k=w[_],T=this.style._layers[k];if(T.hasOffscreenPass()&&!T.isHidden(this.transform.zoom)){var A=l[T.source];(\"custom\"===T.type||A.length)&&this.renderLayer(this,i[T.source],T,A)}}for(this.context.bindFramebuffer.set(null),this.context.clear({color:r.showOverdrawInspector?t.Color.black:t.Color.transparent,depth:1}),this.clearStencil(),this._showOverdrawInspector=r.showOverdrawInspector,this.depthRangeFor3D=[0,1-(e._order.length+2)*this.numSublayers*this.depthEpsilon],this.renderPass=\"opaque\",this.currentLayer=n.length-1;this.currentLayer>=0;this.currentLayer--){var M=this.style._layers[n[this.currentLayer]],S=i[M.source],E=s[M.source];this._renderTileClippingMasks(M,E),this.renderLayer(this,S,M,E)}for(this.renderPass=\"translucent\",this.currentLayer=0;this.currentLayer<n.length;this.currentLayer++){var C=this.style._layers[n[this.currentLayer]],L=i[C.source],P=(\"symbol\"===C.type?c:l)[C.source];this._renderTileClippingMasks(C,s[C.source]),this.renderLayer(this,L,C,P)}if(this.options.showTileBoundaries)for(var O in i){en.debug(this,i[O],s[O]);break}this.context.setDefault()},rn.prototype.setupOffscreenDepthRenderbuffer=function(){var t=this.context;this.depthRbo||(this.depthRbo=t.createRenderbuffer(t.gl.DEPTH_COMPONENT16,this.width,this.height))},rn.prototype.renderLayer=function(t,e,r,n){r.isHidden(this.transform.zoom)||(\"background\"===r.type||\"custom\"===r.type||n.length)&&(this.id=r.id,en[r.type](t,e,r,n,this.style.placement.variableOffsets))},rn.prototype.translatePosMatrix=function(e,r,n,i,a){if(!n[0]&&!n[1])return e;var o=a?\"map\"===i?this.transform.angle:0:\"viewport\"===i?-this.transform.angle:0;if(o){var s=Math.sin(o),l=Math.cos(o);n=[n[0]*l-n[1]*s,n[0]*s+n[1]*l]}var c=[a?n[0]:le(r,n[0],this.transform.zoom),a?n[1]:le(r,n[1],this.transform.zoom),0],u=new Float32Array(16);return t.translate(u,e,c),u},rn.prototype.saveTileTexture=function(t){var e=this._tileTextures[t.size[0]];e?e.push(t):this._tileTextures[t.size[0]]=[t]},rn.prototype.getTileTexture=function(t){var e=this._tileTextures[t];return e&&e.length>0?e.pop():null},rn.prototype.isPatternMissing=function(t){if(!t)return!1;var e=this.imageManager.getPattern(t.from),r=this.imageManager.getPattern(t.to);return!e||!r},rn.prototype.useProgram=function(t,e){void 0===e&&(e=this.emptyProgramConfiguration),this.cache=this.cache||{};var r=\"\"+t+(e.cacheKey||\"\")+(this._showOverdrawInspector?\"/overdraw\":\"\");return this.cache[r]||(this.cache[r]=new hr(this.context,cr[t],e,Nr[t],this._showOverdrawInspector)),this.cache[r]},rn.prototype.setCustomLayerDefaults=function(){this.context.unbindVAO(),this.context.cullFace.setDefault(),this.context.activeTexture.setDefault(),this.context.pixelStoreUnpack.setDefault(),this.context.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.context.pixelStoreUnpackFlipY.setDefault()},rn.prototype.setBaseState=function(){var t=this.context.gl;this.context.cullFace.set(!1),this.context.viewport.set([0,0,this.width,this.height]),this.context.blendEquation.set(t.FUNC_ADD)};var sn=function(e,r,n){this.tileSize=512,this.maxValidLatitude=85.051129,this._renderWorldCopies=void 0===n||n,this._minZoom=e||0,this._maxZoom=r||22,this.setMaxBounds(),this.width=0,this.height=0,this._center=new t.LngLat(0,0),this.zoom=0,this.angle=0,this._fov=.6435011087932844,this._pitch=0,this._unmodified=!0,this._posMatrixCache={},this._alignedPosMatrixCache={}},ln={minZoom:{configurable:!0},maxZoom:{configurable:!0},renderWorldCopies:{configurable:!0},worldSize:{configurable:!0},centerPoint:{configurable:!0},size:{configurable:!0},bearing:{configurable:!0},pitch:{configurable:!0},fov:{configurable:!0},zoom:{configurable:!0},center:{configurable:!0},unmodified:{configurable:!0},point:{configurable:!0}};sn.prototype.clone=function(){var t=new sn(this._minZoom,this._maxZoom,this._renderWorldCopies);return t.tileSize=this.tileSize,t.latRange=this.latRange,t.width=this.width,t.height=this.height,t._center=this._center,t.zoom=this.zoom,t.angle=this.angle,t._fov=this._fov,t._pitch=this._pitch,t._unmodified=this._unmodified,t._calcMatrices(),t},ln.minZoom.get=function(){return this._minZoom},ln.minZoom.set=function(t){this._minZoom!==t&&(this._minZoom=t,this.zoom=Math.max(this.zoom,t))},ln.maxZoom.get=function(){return this._maxZoom},ln.maxZoom.set=function(t){this._maxZoom!==t&&(this._maxZoom=t,this.zoom=Math.min(this.zoom,t))},ln.renderWorldCopies.get=function(){return this._renderWorldCopies},ln.renderWorldCopies.set=function(t){void 0===t?t=!0:null===t&&(t=!1),this._renderWorldCopies=t},ln.worldSize.get=function(){return this.tileSize*this.scale},ln.centerPoint.get=function(){return this.size._div(2)},ln.size.get=function(){return new t.Point(this.width,this.height)},ln.bearing.get=function(){return-this.angle/Math.PI*180},ln.bearing.set=function(e){var r=-t.wrap(e,-180,180)*Math.PI/180;this.angle!==r&&(this._unmodified=!1,this.angle=r,this._calcMatrices(),this.rotationMatrix=t.create$2(),t.rotate(this.rotationMatrix,this.rotationMatrix,this.angle))},ln.pitch.get=function(){return this._pitch/Math.PI*180},ln.pitch.set=function(e){var r=t.clamp(e,0,60)/180*Math.PI;this._pitch!==r&&(this._unmodified=!1,this._pitch=r,this._calcMatrices())},ln.fov.get=function(){return this._fov/Math.PI*180},ln.fov.set=function(t){t=Math.max(.01,Math.min(60,t)),this._fov!==t&&(this._unmodified=!1,this._fov=t/180*Math.PI,this._calcMatrices())},ln.zoom.get=function(){return this._zoom},ln.zoom.set=function(t){var e=Math.min(Math.max(t,this.minZoom),this.maxZoom);this._zoom!==e&&(this._unmodified=!1,this._zoom=e,this.scale=this.zoomScale(e),this.tileZoom=Math.floor(e),this.zoomFraction=e-this.tileZoom,this._constrain(),this._calcMatrices())},ln.center.get=function(){return this._center},ln.center.set=function(t){t.lat===this._center.lat&&t.lng===this._center.lng||(this._unmodified=!1,this._center=t,this._constrain(),this._calcMatrices())},sn.prototype.coveringZoomLevel=function(t){return(t.roundZoom?Math.round:Math.floor)(this.zoom+this.scaleZoom(this.tileSize/t.tileSize))},sn.prototype.getVisibleUnwrappedCoordinates=function(e){var r=[new t.UnwrappedTileID(0,e)];if(this._renderWorldCopies)for(var n=this.pointCoordinate(new t.Point(0,0)),i=this.pointCoordinate(new t.Point(this.width,0)),a=this.pointCoordinate(new t.Point(this.width,this.height)),o=this.pointCoordinate(new t.Point(0,this.height)),s=Math.floor(Math.min(n.x,i.x,a.x,o.x)),l=Math.floor(Math.max(n.x,i.x,a.x,o.x)),c=s-1;c<=l+1;c++)0!==c&&r.push(new t.UnwrappedTileID(c,e));return r},sn.prototype.coveringTiles=function(e){var r=this.coveringZoomLevel(e),n=r;if(void 0!==e.minzoom&&r<e.minzoom)return[];void 0!==e.maxzoom&&r>e.maxzoom&&(r=e.maxzoom);var i=t.MercatorCoordinate.fromLngLat(this.center),a=Math.pow(2,r),o=new t.Point(a*i.x-.5,a*i.y-.5);return function(e,r,n,i){void 0===i&&(i=!0);var a=1<<e,o={};function s(r,s,l){var c,u,h,f;if(l>=0&&l<=a)for(c=r;c<s;c++)u=Math.floor(c/a),h=(c%a+a)%a,0!==u&&!0!==i||(f=new t.OverscaledTileID(n,u,e,h,l),o[f.key]=f)}var l=r.map(function(e){return new t.Point(e.x,e.y)._mult(a)});return on(l[0],l[1],l[2],0,a,s),on(l[2],l[3],l[0],0,a,s),Object.keys(o).map(function(t){return o[t]})}(r,[this.pointCoordinate(new t.Point(0,0)),this.pointCoordinate(new t.Point(this.width,0)),this.pointCoordinate(new t.Point(this.width,this.height)),this.pointCoordinate(new t.Point(0,this.height))],e.reparseOverscaled?n:r,this._renderWorldCopies).sort(function(t,e){return o.dist(t.canonical)-o.dist(e.canonical)})},sn.prototype.resize=function(t,e){this.width=t,this.height=e,this.pixelsToGLUnits=[2/t,-2/e],this._constrain(),this._calcMatrices()},ln.unmodified.get=function(){return this._unmodified},sn.prototype.zoomScale=function(t){return Math.pow(2,t)},sn.prototype.scaleZoom=function(t){return Math.log(t)/Math.LN2},sn.prototype.project=function(e){var r=t.clamp(e.lat,-this.maxValidLatitude,this.maxValidLatitude);return new t.Point(t.mercatorXfromLng(e.lng)*this.worldSize,t.mercatorYfromLat(r)*this.worldSize)},sn.prototype.unproject=function(e){return new t.MercatorCoordinate(e.x/this.worldSize,e.y/this.worldSize).toLngLat()},ln.point.get=function(){return this.project(this.center)},sn.prototype.setLocationAtPoint=function(e,r){var n=this.pointCoordinate(r),i=this.pointCoordinate(this.centerPoint),a=this.locationCoordinate(e),o=new t.MercatorCoordinate(a.x-(n.x-i.x),a.y-(n.y-i.y));this.center=this.coordinateLocation(o),this._renderWorldCopies&&(this.center=this.center.wrap())},sn.prototype.locationPoint=function(t){return this.coordinatePoint(this.locationCoordinate(t))},sn.prototype.pointLocation=function(t){return this.coordinateLocation(this.pointCoordinate(t))},sn.prototype.locationCoordinate=function(e){return t.MercatorCoordinate.fromLngLat(e)},sn.prototype.coordinateLocation=function(t){return t.toLngLat()},sn.prototype.pointCoordinate=function(e){var r=[e.x,e.y,0,1],n=[e.x,e.y,1,1];t.transformMat4(r,r,this.pixelMatrixInverse),t.transformMat4(n,n,this.pixelMatrixInverse);var i=r[3],a=n[3],o=r[0]/i,s=n[0]/a,l=r[1]/i,c=n[1]/a,u=r[2]/i,h=n[2]/a,f=u===h?0:(0-u)/(h-u);return new t.MercatorCoordinate(t.number(o,s,f)/this.worldSize,t.number(l,c,f)/this.worldSize)},sn.prototype.coordinatePoint=function(e){var r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix),new t.Point(r[0]/r[3],r[1]/r[3])},sn.prototype.getBounds=function(){return(new t.LngLatBounds).extend(this.pointLocation(new t.Point(0,0))).extend(this.pointLocation(new t.Point(this.width,0))).extend(this.pointLocation(new t.Point(this.width,this.height))).extend(this.pointLocation(new t.Point(0,this.height)))},sn.prototype.getMaxBounds=function(){return this.latRange&&2===this.latRange.length&&this.lngRange&&2===this.lngRange.length?new t.LngLatBounds([this.lngRange[0],this.latRange[0]],[this.lngRange[1],this.latRange[1]]):null},sn.prototype.setMaxBounds=function(t){t?(this.lngRange=[t.getWest(),t.getEast()],this.latRange=[t.getSouth(),t.getNorth()],this._constrain()):(this.lngRange=null,this.latRange=[-this.maxValidLatitude,this.maxValidLatitude])},sn.prototype.calculatePosMatrix=function(e,r){void 0===r&&(r=!1);var n=e.key,i=r?this._alignedPosMatrixCache:this._posMatrixCache;if(i[n])return i[n];var a=e.canonical,o=this.worldSize/this.zoomScale(a.z),s=a.x+Math.pow(2,a.z)*e.wrap,l=t.identity(new Float64Array(16));return t.translate(l,l,[s*o,a.y*o,0]),t.scale(l,l,[o/t.EXTENT,o/t.EXTENT,1]),t.multiply(l,r?this.alignedProjMatrix:this.projMatrix,l),i[n]=new Float32Array(l),i[n]},sn.prototype.customLayerMatrix=function(){return this.mercatorMatrix.slice()},sn.prototype._constrain=function(){if(this.center&&this.width&&this.height&&!this._constraining){this._constraining=!0;var e,r,n,i,a=-90,o=90,s=-180,l=180,c=this.size,u=this._unmodified;if(this.latRange){var h=this.latRange;a=t.mercatorYfromLat(h[1])*this.worldSize,e=(o=t.mercatorYfromLat(h[0])*this.worldSize)-a<c.y?c.y/(o-a):0}if(this.lngRange){var f=this.lngRange;s=t.mercatorXfromLng(f[0])*this.worldSize,r=(l=t.mercatorXfromLng(f[1])*this.worldSize)-s<c.x?c.x/(l-s):0}var p=this.point,d=Math.max(r||0,e||0);if(d)return this.center=this.unproject(new t.Point(r?(l+s)/2:p.x,e?(o+a)/2:p.y)),this.zoom+=this.scaleZoom(d),this._unmodified=u,void(this._constraining=!1);if(this.latRange){var g=p.y,v=c.y/2;g-v<a&&(i=a+v),g+v>o&&(i=o-v)}if(this.lngRange){var m=p.x,y=c.x/2;m-y<s&&(n=s+y),m+y>l&&(n=l-y)}void 0===n&&void 0===i||(this.center=this.unproject(new t.Point(void 0!==n?n:p.x,void 0!==i?i:p.y))),this._unmodified=u,this._constraining=!1}},sn.prototype._calcMatrices=function(){if(this.height){this.cameraToCenterDistance=.5/Math.tan(this._fov/2)*this.height;var e=this._fov/2,r=Math.PI/2+this._pitch,n=Math.sin(e)*this.cameraToCenterDistance/Math.sin(Math.PI-r-e),i=this.point,a=i.x,o=i.y,s=1.01*(Math.cos(Math.PI/2-this._pitch)*n+this.cameraToCenterDistance),l=new Float64Array(16);t.perspective(l,this._fov,this.width/this.height,1,s),t.scale(l,l,[1,-1,1]),t.translate(l,l,[0,0,-this.cameraToCenterDistance]),t.rotateX(l,l,this._pitch),t.rotateZ(l,l,this.angle),t.translate(l,l,[-a,-o,0]),this.mercatorMatrix=t.scale([],l,[this.worldSize,this.worldSize,this.worldSize]),t.scale(l,l,[1,1,t.mercatorZfromAltitude(1,this.center.lat)*this.worldSize,1]),this.projMatrix=l;var c=this.width%2/2,u=this.height%2/2,h=Math.cos(this.angle),f=Math.sin(this.angle),p=a-Math.round(a)+h*c+f*u,d=o-Math.round(o)+h*u+f*c,g=new Float64Array(l);if(t.translate(g,g,[p>.5?p-1:p,d>.5?d-1:d,0]),this.alignedProjMatrix=g,l=t.create(),t.scale(l,l,[this.width/2,-this.height/2,1]),t.translate(l,l,[1,-1,0]),this.labelPlaneMatrix=l,l=t.create(),t.scale(l,l,[1,-1,1]),t.translate(l,l,[-1,-1,0]),t.scale(l,l,[2/this.width,2/this.height,1]),this.glCoordMatrix=l,this.pixelMatrix=t.multiply(new Float64Array(16),this.labelPlaneMatrix,this.projMatrix),!(l=t.invert(new Float64Array(16),this.pixelMatrix)))throw new Error(\"failed to invert matrix\");this.pixelMatrixInverse=l,this._posMatrixCache={},this._alignedPosMatrixCache={}}},sn.prototype.maxPitchScaleFactor=function(){if(!this.pixelMatrixInverse)return 1;var e=this.pointCoordinate(new t.Point(0,0)),r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix)[3]/this.cameraToCenterDistance},sn.prototype.getCameraPoint=function(){var e=this._pitch,r=Math.tan(e)*(this.cameraToCenterDistance||1);return this.centerPoint.add(new t.Point(0,r))},sn.prototype.getCameraQueryGeometry=function(e){var r=this.getCameraPoint();if(1===e.length)return[e[0],r];for(var n=r.x,i=r.y,a=r.x,o=r.y,s=0,l=e;s<l.length;s+=1){var c=l[s];n=Math.min(n,c.x),i=Math.min(i,c.y),a=Math.max(a,c.x),o=Math.max(o,c.y)}return[new t.Point(n,i),new t.Point(a,i),new t.Point(a,o),new t.Point(n,o),new t.Point(n,i)]},Object.defineProperties(sn.prototype,ln);var cn=function(){var e,r,n,i;t.bindAll([\"_onHashChange\",\"_updateHash\"],this),this._updateHash=(e=this._updateHashUnthrottled.bind(this),300,r=!1,n=null,i=function(){n=null,r&&(e(),n=setTimeout(i,300),r=!1)},function(){return r=!0,n||i(),n})};cn.prototype.addTo=function(e){return this._map=e,t.window.addEventListener(\"hashchange\",this._onHashChange,!1),this._map.on(\"moveend\",this._updateHash),this},cn.prototype.remove=function(){return t.window.removeEventListener(\"hashchange\",this._onHashChange,!1),this._map.off(\"moveend\",this._updateHash),clearTimeout(this._updateHash()),delete this._map,this},cn.prototype.getHashString=function(t){var e=this._map.getCenter(),r=Math.round(100*this._map.getZoom())/100,n=Math.ceil((r*Math.LN2+Math.log(512/360/.5))/Math.LN10),i=Math.pow(10,n),a=Math.round(e.lng*i)/i,o=Math.round(e.lat*i)/i,s=this._map.getBearing(),l=this._map.getPitch(),c=\"\";return c+=t?\"#/\"+a+\"/\"+o+\"/\"+r:\"#\"+r+\"/\"+o+\"/\"+a,(s||l)&&(c+=\"/\"+Math.round(10*s)/10),l&&(c+=\"/\"+Math.round(l)),c},cn.prototype._onHashChange=function(){var e=t.window.location.hash.replace(\"#\",\"\").split(\"/\");return e.length>=3&&(this._map.jumpTo({center:[+e[2],+e[1]],zoom:+e[0],bearing:+(e[3]||0),pitch:+(e[4]||0)}),!0)},cn.prototype._updateHashUnthrottled=function(){var e=this.getHashString();try{t.window.history.replaceState(t.window.history.state,\"\",e)}catch(t){}};var un=function(e){function n(n,i,a,o){void 0===o&&(o={});var s=r.mousePos(i.getCanvasContainer(),a),l=i.unproject(s);e.call(this,n,t.extend({point:s,lngLat:l,originalEvent:a},o)),this._defaultPrevented=!1,this.target=i}e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),hn=function(e){function n(n,i,a){var o=r.touchPos(i.getCanvasContainer(),a),s=o.map(function(t){return i.unproject(t)}),l=o.reduce(function(t,e,r,n){return t.add(e.div(n.length))},new t.Point(0,0)),c=i.unproject(l);e.call(this,n,{points:o,point:l,lngLats:s,lngLat:c,originalEvent:a}),this._defaultPrevented=!1}e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),fn=function(t){function e(e,r,n){t.call(this,e,{originalEvent:n}),this._defaultPrevented=!1}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={defaultPrevented:{configurable:!0}};return e.prototype.preventDefault=function(){this._defaultPrevented=!0},r.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(e.prototype,r),e}(t.Event),pn=function(e){this._map=e,this._el=e.getCanvasContainer(),this._delta=0,this._defaultZoomRate=.01,this._wheelZoomRate=1/450,t.bindAll([\"_onWheel\",\"_onTimeout\",\"_onScrollFrame\",\"_onScrollFinished\"],this)};pn.prototype.setZoomRate=function(t){this._defaultZoomRate=t},pn.prototype.setWheelZoomRate=function(t){this._wheelZoomRate=t},pn.prototype.isEnabled=function(){return!!this._enabled},pn.prototype.isActive=function(){return!!this._active},pn.prototype.isZooming=function(){return!!this._zooming},pn.prototype.enable=function(t){this.isEnabled()||(this._enabled=!0,this._aroundCenter=t&&\"center\"===t.around)},pn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},pn.prototype.onWheel=function(e){if(this.isEnabled()){var r=e.deltaMode===t.window.WheelEvent.DOM_DELTA_LINE?40*e.deltaY:e.deltaY,n=t.browser.now(),i=n-(this._lastWheelEventTime||0);this._lastWheelEventTime=n,0!==r&&r%4.000244140625==0?this._type=\"wheel\":0!==r&&Math.abs(r)<4?this._type=\"trackpad\":i>400?(this._type=null,this._lastValue=r,this._timeout=setTimeout(this._onTimeout,40,e)):this._type||(this._type=Math.abs(i*r)<200?\"trackpad\":\"wheel\",this._timeout&&(clearTimeout(this._timeout),this._timeout=null,r+=this._lastValue)),e.shiftKey&&r&&(r/=4),this._type&&(this._lastWheelEvent=e,this._delta-=r,this.isActive()||this._start(e)),e.preventDefault()}},pn.prototype._onTimeout=function(t){this._type=\"wheel\",this._delta-=this._lastValue,this.isActive()||this._start(t)},pn.prototype._start=function(e){if(this._delta){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),this._active=!0,this.isZooming()||(this._zooming=!0,this._map.fire(new t.Event(\"movestart\",{originalEvent:e})),this._map.fire(new t.Event(\"zoomstart\",{originalEvent:e}))),this._finishTimeout&&clearTimeout(this._finishTimeout);var n=r.mousePos(this._el,e);this._around=t.LngLat.convert(this._aroundCenter?this._map.getCenter():this._map.unproject(n)),this._aroundPoint=this._map.transform.locationPoint(this._around),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onScrollFrame))}},pn.prototype._onScrollFrame=function(){var e=this;if(this._frameId=null,this.isActive()){var r=this._map.transform;if(0!==this._delta){var n=\"wheel\"===this._type&&Math.abs(this._delta)>4.000244140625?this._wheelZoomRate:this._defaultZoomRate,i=2/(1+Math.exp(-Math.abs(this._delta*n)));this._delta<0&&0!==i&&(i=1/i);var a=\"number\"==typeof this._targetZoom?r.zoomScale(this._targetZoom):r.scale;this._targetZoom=Math.min(r.maxZoom,Math.max(r.minZoom,r.scaleZoom(a*i))),\"wheel\"===this._type&&(this._startZoom=r.zoom,this._easing=this._smoothOutEasing(200)),this._delta=0}var o=\"number\"==typeof this._targetZoom?this._targetZoom:r.zoom,s=this._startZoom,l=this._easing,c=!1;if(\"wheel\"===this._type&&s&&l){var u=Math.min((t.browser.now()-this._lastWheelEventTime)/200,1),h=l(u);r.zoom=t.number(s,o,h),u<1?this._frameId||(this._frameId=this._map._requestRenderFrame(this._onScrollFrame)):c=!0}else r.zoom=o,c=!0;r.setLocationAtPoint(this._around,this._aroundPoint),this._map.fire(new t.Event(\"move\",{originalEvent:this._lastWheelEvent})),this._map.fire(new t.Event(\"zoom\",{originalEvent:this._lastWheelEvent})),c&&(this._active=!1,this._finishTimeout=setTimeout(function(){e._zooming=!1,e._map.fire(new t.Event(\"zoomend\",{originalEvent:e._lastWheelEvent})),e._map.fire(new t.Event(\"moveend\",{originalEvent:e._lastWheelEvent})),delete e._targetZoom},200))}},pn.prototype._smoothOutEasing=function(e){var r=t.ease;if(this._prevEase){var n=this._prevEase,i=(t.browser.now()-n.start)/n.duration,a=n.easing(i+.01)-n.easing(i),o=.27/Math.sqrt(a*a+1e-4)*.01,s=Math.sqrt(.0729-o*o);r=t.bezier(o,s,.25,1)}return this._prevEase={start:t.browser.now(),duration:e,easing:r},r};var dn=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._container=e.getContainer(),this._clickTolerance=r.clickTolerance||1,t.bindAll([\"_onMouseMove\",\"_onMouseUp\",\"_onKeyDown\"],this)};dn.prototype.isEnabled=function(){return!!this._enabled},dn.prototype.isActive=function(){return!!this._active},dn.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},dn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},dn.prototype.onMouseDown=function(e){this.isEnabled()&&e.shiftKey&&0===e.button&&(t.window.document.addEventListener(\"mousemove\",this._onMouseMove,!1),t.window.document.addEventListener(\"keydown\",this._onKeyDown,!1),t.window.document.addEventListener(\"mouseup\",this._onMouseUp,!1),r.disableDrag(),this._startPos=this._lastPos=r.mousePos(this._el,e),this._active=!0)},dn.prototype._onMouseMove=function(t){var e=r.mousePos(this._el,t);if(!(this._lastPos.equals(e)||!this._box&&e.dist(this._startPos)<this._clickTolerance)){var n=this._startPos;this._lastPos=e,this._box||(this._box=r.create(\"div\",\"mapboxgl-boxzoom\",this._container),this._container.classList.add(\"mapboxgl-crosshair\"),this._fireEvent(\"boxzoomstart\",t));var i=Math.min(n.x,e.x),a=Math.max(n.x,e.x),o=Math.min(n.y,e.y),s=Math.max(n.y,e.y);r.setTransform(this._box,\"translate(\"+i+\"px,\"+o+\"px)\"),this._box.style.width=a-i+\"px\",this._box.style.height=s-o+\"px\"}},dn.prototype._onMouseUp=function(e){if(0===e.button){var n=this._startPos,i=r.mousePos(this._el,e);this._finish(),r.suppressClick(),n.x===i.x&&n.y===i.y?this._fireEvent(\"boxzoomcancel\",e):this._map.fitScreenCoordinates(n,i,this._map.getBearing(),{linear:!0}).fire(new t.Event(\"boxzoomend\",{originalEvent:e}))}},dn.prototype._onKeyDown=function(t){27===t.keyCode&&(this._finish(),this._fireEvent(\"boxzoomcancel\",t))},dn.prototype._finish=function(){this._active=!1,t.window.document.removeEventListener(\"mousemove\",this._onMouseMove,!1),t.window.document.removeEventListener(\"keydown\",this._onKeyDown,!1),t.window.document.removeEventListener(\"mouseup\",this._onMouseUp,!1),this._container.classList.remove(\"mapboxgl-crosshair\"),this._box&&(r.remove(this._box),this._box=null),r.enableDrag(),delete this._startPos,delete this._lastPos},dn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,{originalEvent:r}))};var gn=t.bezier(0,0,.25,1),vn=function(e,r){this._map=e,this._el=r.element||e.getCanvasContainer(),this._state=\"disabled\",this._button=r.button||\"right\",this._bearingSnap=r.bearingSnap||0,this._pitchWithRotate=!1!==r.pitchWithRotate,t.bindAll([\"onMouseDown\",\"_onMouseMove\",\"_onMouseUp\",\"_onBlur\",\"_onDragFrame\"],this)};vn.prototype.isEnabled=function(){return\"disabled\"!==this._state},vn.prototype.isActive=function(){return\"active\"===this._state},vn.prototype.enable=function(){this.isEnabled()||(this._state=\"enabled\")},vn.prototype.disable=function(){if(this.isEnabled())switch(this._state){case\"active\":this._state=\"disabled\",this._unbind(),this._deactivate(),this._fireEvent(\"rotateend\"),this._pitchWithRotate&&this._fireEvent(\"pitchend\"),this._fireEvent(\"moveend\");break;case\"pending\":this._state=\"disabled\",this._unbind();break;default:this._state=\"disabled\"}},vn.prototype.onMouseDown=function(e){if(\"enabled\"===this._state){if(\"right\"===this._button){if(this._eventButton=r.mouseButton(e),this._eventButton!==(e.ctrlKey?0:2))return}else{if(e.ctrlKey||0!==r.mouseButton(e))return;this._eventButton=0}r.disableDrag(),t.window.document.addEventListener(\"mousemove\",this._onMouseMove,{capture:!0}),t.window.document.addEventListener(\"mouseup\",this._onMouseUp),t.window.addEventListener(\"blur\",this._onBlur),this._state=\"pending\",this._inertia=[[t.browser.now(),this._map.getBearing()]],this._startPos=this._lastPos=r.mousePos(this._el,e),this._center=this._map.transform.centerPoint,e.preventDefault()}},vn.prototype._onMouseMove=function(t){var e=r.mousePos(this._el,t);this._lastPos.equals(e)||(this._lastMoveEvent=t,this._lastPos=e,\"pending\"===this._state&&(this._state=\"active\",this._fireEvent(\"rotatestart\",t),this._fireEvent(\"movestart\",t),this._pitchWithRotate&&this._fireEvent(\"pitchstart\",t)),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onDragFrame)))},vn.prototype._onDragFrame=function(){this._frameId=null;var e=this._lastMoveEvent;if(e){var r=this._map.transform,n=this._startPos,i=this._lastPos,a=.8*(n.x-i.x),o=-.5*(n.y-i.y),s=r.bearing-a,l=r.pitch-o,c=this._inertia,u=c[c.length-1];this._drainInertiaBuffer(),c.push([t.browser.now(),this._map._normalizeBearing(s,u[1])]),r.bearing=s,this._pitchWithRotate&&(this._fireEvent(\"pitch\",e),r.pitch=l),this._fireEvent(\"rotate\",e),this._fireEvent(\"move\",e),delete this._lastMoveEvent,this._startPos=this._lastPos}},vn.prototype._onMouseUp=function(t){if(r.mouseButton(t)===this._eventButton)switch(this._state){case\"active\":this._state=\"enabled\",r.suppressClick(),this._unbind(),this._deactivate(),this._inertialRotate(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},vn.prototype._onBlur=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._fireEvent(\"rotateend\",t),this._pitchWithRotate&&this._fireEvent(\"pitchend\",t),this._fireEvent(\"moveend\",t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},vn.prototype._unbind=function(){t.window.document.removeEventListener(\"mousemove\",this._onMouseMove,{capture:!0}),t.window.document.removeEventListener(\"mouseup\",this._onMouseUp),t.window.removeEventListener(\"blur\",this._onBlur),r.enableDrag()},vn.prototype._deactivate=function(){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._lastMoveEvent,delete this._startPos,delete this._lastPos},vn.prototype._inertialRotate=function(t){var e=this;this._fireEvent(\"rotateend\",t),this._drainInertiaBuffer();var r=this._map,n=r.getBearing(),i=this._inertia,a=function(){Math.abs(n)<e._bearingSnap?r.resetNorth({noMoveStart:!0},{originalEvent:t}):e._fireEvent(\"moveend\",t),e._pitchWithRotate&&e._fireEvent(\"pitchend\",t)};if(i.length<2)a();else{var o=i[0],s=i[i.length-1],l=i[i.length-2],c=r._normalizeBearing(n,l[1]),u=s[1]-o[1],h=u<0?-1:1,f=(s[0]-o[0])/1e3;if(0!==u&&0!==f){var p=Math.abs(u*(.25/f));p>180&&(p=180);var d=p/180;c+=h*p*(d/2),Math.abs(r._normalizeBearing(c,0))<this._bearingSnap&&(c=r._normalizeBearing(0,c)),r.rotateTo(c,{duration:1e3*d,easing:gn,noMoveStart:!0},{originalEvent:t})}else a()}},vn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},vn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>0&&r-e[0][0]>160;)e.shift()};var mn=t.bezier(0,0,.3,1),yn=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._state=\"disabled\",this._clickTolerance=r.clickTolerance||1,t.bindAll([\"_onMove\",\"_onMouseUp\",\"_onTouchEnd\",\"_onBlur\",\"_onDragFrame\"],this)};yn.prototype.isEnabled=function(){return\"disabled\"!==this._state},yn.prototype.isActive=function(){return\"active\"===this._state},yn.prototype.enable=function(){this.isEnabled()||(this._el.classList.add(\"mapboxgl-touch-drag-pan\"),this._state=\"enabled\")},yn.prototype.disable=function(){if(this.isEnabled())switch(this._el.classList.remove(\"mapboxgl-touch-drag-pan\"),this._state){case\"active\":this._state=\"disabled\",this._unbind(),this._deactivate(),this._fireEvent(\"dragend\"),this._fireEvent(\"moveend\");break;case\"pending\":this._state=\"disabled\",this._unbind();break;default:this._state=\"disabled\"}},yn.prototype.onMouseDown=function(e){\"enabled\"===this._state&&(e.ctrlKey||0!==r.mouseButton(e)||(r.addEventListener(t.window.document,\"mousemove\",this._onMove,{capture:!0}),r.addEventListener(t.window.document,\"mouseup\",this._onMouseUp),this._start(e)))},yn.prototype.onTouchStart=function(e){\"enabled\"===this._state&&(e.touches.length>1||(r.addEventListener(t.window.document,\"touchmove\",this._onMove,{capture:!0,passive:!1}),r.addEventListener(t.window.document,\"touchend\",this._onTouchEnd),this._start(e)))},yn.prototype._start=function(e){t.window.addEventListener(\"blur\",this._onBlur),this._state=\"pending\",this._startPos=this._mouseDownPos=this._lastPos=r.mousePos(this._el,e),this._inertia=[[t.browser.now(),this._startPos]]},yn.prototype._onMove=function(e){e.preventDefault();var n=r.mousePos(this._el,e);this._lastPos.equals(n)||\"pending\"===this._state&&n.dist(this._mouseDownPos)<this._clickTolerance||(this._lastMoveEvent=e,this._lastPos=n,this._drainInertiaBuffer(),this._inertia.push([t.browser.now(),this._lastPos]),\"pending\"===this._state&&(this._state=\"active\",this._fireEvent(\"dragstart\",e),this._fireEvent(\"movestart\",e)),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onDragFrame)))},yn.prototype._onDragFrame=function(){this._frameId=null;var t=this._lastMoveEvent;if(t){var e=this._map.transform;e.setLocationAtPoint(e.pointLocation(this._startPos),this._lastPos),this._fireEvent(\"drag\",t),this._fireEvent(\"move\",t),this._startPos=this._lastPos,delete this._lastMoveEvent}},yn.prototype._onMouseUp=function(t){if(0===r.mouseButton(t))switch(this._state){case\"active\":this._state=\"enabled\",r.suppressClick(),this._unbind(),this._deactivate(),this._inertialPan(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},yn.prototype._onTouchEnd=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._inertialPan(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},yn.prototype._onBlur=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._fireEvent(\"dragend\",t),this._fireEvent(\"moveend\",t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},yn.prototype._unbind=function(){r.removeEventListener(t.window.document,\"touchmove\",this._onMove,{capture:!0,passive:!1}),r.removeEventListener(t.window.document,\"touchend\",this._onTouchEnd),r.removeEventListener(t.window.document,\"mousemove\",this._onMove,{capture:!0}),r.removeEventListener(t.window.document,\"mouseup\",this._onMouseUp),r.removeEventListener(t.window,\"blur\",this._onBlur)},yn.prototype._deactivate=function(){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._lastMoveEvent,delete this._startPos,delete this._mouseDownPos,delete this._lastPos},yn.prototype._inertialPan=function(t){this._fireEvent(\"dragend\",t),this._drainInertiaBuffer();var e=this._inertia;if(e.length<2)this._fireEvent(\"moveend\",t);else{var r=e[e.length-1],n=e[0],i=r[1].sub(n[1]),a=(r[0]-n[0])/1e3;if(0===a||r[1].equals(n[1]))this._fireEvent(\"moveend\",t);else{var o=i.mult(.3/a),s=o.mag();s>1400&&(s=1400,o._unit()._mult(s));var l=s/750,c=o.mult(-l/2);this._map.panBy(c,{duration:1e3*l,easing:mn,noMoveStart:!0},{originalEvent:t})}}},yn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},yn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>0&&r-e[0][0]>160;)e.shift()};var xn=function(e){this._map=e,this._el=e.getCanvasContainer(),t.bindAll([\"_onKeyDown\"],this)};function bn(t){return t*(2-t)}xn.prototype.isEnabled=function(){return!!this._enabled},xn.prototype.enable=function(){this.isEnabled()||(this._el.addEventListener(\"keydown\",this._onKeyDown,!1),this._enabled=!0)},xn.prototype.disable=function(){this.isEnabled()&&(this._el.removeEventListener(\"keydown\",this._onKeyDown),this._enabled=!1)},xn.prototype._onKeyDown=function(t){if(!(t.altKey||t.ctrlKey||t.metaKey)){var e=0,r=0,n=0,i=0,a=0;switch(t.keyCode){case 61:case 107:case 171:case 187:e=1;break;case 189:case 109:case 173:e=-1;break;case 37:t.shiftKey?r=-1:(t.preventDefault(),i=-1);break;case 39:t.shiftKey?r=1:(t.preventDefault(),i=1);break;case 38:t.shiftKey?n=1:(t.preventDefault(),a=-1);break;case 40:t.shiftKey?n=-1:(a=1,t.preventDefault());break;default:return}var o=this._map,s=o.getZoom(),l={duration:300,delayEndEvents:500,easing:bn,zoom:e?Math.round(s)+e*(t.shiftKey?2:1):s,bearing:o.getBearing()+15*r,pitch:o.getPitch()+10*n,offset:[100*-i,100*-a],center:o.getCenter()};o.easeTo(l,{originalEvent:t})}};var _n=function(e){this._map=e,t.bindAll([\"_onDblClick\",\"_onZoomEnd\"],this)};_n.prototype.isEnabled=function(){return!!this._enabled},_n.prototype.isActive=function(){return!!this._active},_n.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},_n.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},_n.prototype.onTouchStart=function(t){var e=this;if(this.isEnabled()&&!(t.points.length>1))if(this._tapped){var r=t.points[0],n=this._tappedPoint;if(n&&n.dist(r)<=30){t.originalEvent.preventDefault();var i=function(){e._tapped&&e._zoom(t),e._map.off(\"touchcancel\",a),e._resetTapped()},a=function(){e._map.off(\"touchend\",i),e._resetTapped()};this._map.once(\"touchend\",i),this._map.once(\"touchcancel\",a)}else this._resetTapped()}else this._tappedPoint=t.points[0],this._tapped=setTimeout(function(){e._tapped=null,e._tappedPoint=null},300)},_n.prototype._resetTapped=function(){clearTimeout(this._tapped),this._tapped=null,this._tappedPoint=null},_n.prototype.onDblClick=function(t){this.isEnabled()&&(t.originalEvent.preventDefault(),this._zoom(t))},_n.prototype._zoom=function(t){this._active=!0,this._map.on(\"zoomend\",this._onZoomEnd),this._map.zoomTo(this._map.getZoom()+(t.originalEvent.shiftKey?-1:1),{around:t.lngLat},t)},_n.prototype._onZoomEnd=function(){this._active=!1,this._map.off(\"zoomend\",this._onZoomEnd)};var wn=t.bezier(0,0,.15,1),kn=function(e){this._map=e,this._el=e.getCanvasContainer(),t.bindAll([\"_onMove\",\"_onEnd\",\"_onTouchFrame\"],this)};kn.prototype.isEnabled=function(){return!!this._enabled},kn.prototype.enable=function(t){this.isEnabled()||(this._el.classList.add(\"mapboxgl-touch-zoom-rotate\"),this._enabled=!0,this._aroundCenter=!!t&&\"center\"===t.around)},kn.prototype.disable=function(){this.isEnabled()&&(this._el.classList.remove(\"mapboxgl-touch-zoom-rotate\"),this._enabled=!1)},kn.prototype.disableRotation=function(){this._rotationDisabled=!0},kn.prototype.enableRotation=function(){this._rotationDisabled=!1},kn.prototype.onStart=function(e){if(this.isEnabled()&&2===e.touches.length){var n=r.mousePos(this._el,e.touches[0]),i=r.mousePos(this._el,e.touches[1]),a=n.add(i).div(2);this._startVec=n.sub(i),this._startAround=this._map.transform.pointLocation(a),this._gestureIntent=void 0,this._inertia=[],r.addEventListener(t.window.document,\"touchmove\",this._onMove,{passive:!1}),r.addEventListener(t.window.document,\"touchend\",this._onEnd)}},kn.prototype._getTouchEventData=function(t){var e=r.mousePos(this._el,t.touches[0]),n=r.mousePos(this._el,t.touches[1]),i=e.sub(n);return{vec:i,center:e.add(n).div(2),scale:i.mag()/this._startVec.mag(),bearing:this._rotationDisabled?0:180*i.angleWith(this._startVec)/Math.PI}},kn.prototype._onMove=function(e){if(2===e.touches.length){var r=this._getTouchEventData(e),n=r.vec,i=r.scale,a=r.bearing;if(!this._gestureIntent){var o=this._rotationDisabled&&1!==i||Math.abs(1-i)>.15;Math.abs(a)>10?this._gestureIntent=\"rotate\":o&&(this._gestureIntent=\"zoom\"),this._gestureIntent&&(this._map.fire(new t.Event(this._gestureIntent+\"start\",{originalEvent:e})),this._map.fire(new t.Event(\"movestart\",{originalEvent:e})),this._startVec=n)}this._lastTouchEvent=e,this._frameId||(this._frameId=this._map._requestRenderFrame(this._onTouchFrame)),e.preventDefault()}},kn.prototype._onTouchFrame=function(){this._frameId=null;var e=this._gestureIntent;if(e){var r=this._map.transform;this._startScale||(this._startScale=r.scale,this._startBearing=r.bearing);var n=this._getTouchEventData(this._lastTouchEvent),i=n.center,a=n.bearing,o=n.scale,s=r.pointLocation(i),l=r.locationPoint(s);\"rotate\"===e&&(r.bearing=this._startBearing+a),r.zoom=r.scaleZoom(this._startScale*o),r.setLocationAtPoint(this._startAround,l),this._map.fire(new t.Event(e,{originalEvent:this._lastTouchEvent})),this._map.fire(new t.Event(\"move\",{originalEvent:this._lastTouchEvent})),this._drainInertiaBuffer(),this._inertia.push([t.browser.now(),o,i])}},kn.prototype._onEnd=function(e){r.removeEventListener(t.window.document,\"touchmove\",this._onMove,{passive:!1}),r.removeEventListener(t.window.document,\"touchend\",this._onEnd);var n=this._gestureIntent,i=this._startScale;if(this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._gestureIntent,delete this._startScale,delete this._startBearing,delete this._lastTouchEvent,n){this._map.fire(new t.Event(n+\"end\",{originalEvent:e})),this._drainInertiaBuffer();var a=this._inertia,o=this._map;if(a.length<2)o.snapToNorth({},{originalEvent:e});else{var s=a[a.length-1],l=a[0],c=o.transform.scaleZoom(i*s[1]),u=o.transform.scaleZoom(i*l[1]),h=c-u,f=(s[0]-l[0])/1e3,p=s[2];if(0!==f&&c!==u){var d=.15*h/f;Math.abs(d)>2.5&&(d=d>0?2.5:-2.5);var g=1e3*Math.abs(d/(12*.15)),v=c+d*g/2e3;v<0&&(v=0),o.easeTo({zoom:v,duration:g,easing:wn,around:this._aroundCenter?o.getCenter():o.unproject(p),noMoveStart:!0},{originalEvent:e})}else o.snapToNorth({},{originalEvent:e})}}},kn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>2&&r-e[0][0]>160;)e.shift()};var Tn={scrollZoom:pn,boxZoom:dn,dragRotate:vn,dragPan:yn,keyboard:xn,doubleClickZoom:_n,touchZoomRotate:kn},An=function(e){function r(r,n){e.call(this),this._moving=!1,this._zooming=!1,this.transform=r,this._bearingSnap=n.bearingSnap,t.bindAll([\"_renderFrameCallback\"],this)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getCenter=function(){return new t.LngLat(this.transform.center.lng,this.transform.center.lat)},r.prototype.setCenter=function(t,e){return this.jumpTo({center:t},e)},r.prototype.panBy=function(e,r,n){return e=t.Point.convert(e).mult(-1),this.panTo(this.transform.center,t.extend({offset:e},r),n)},r.prototype.panTo=function(e,r,n){return this.easeTo(t.extend({center:e},r),n)},r.prototype.getZoom=function(){return this.transform.zoom},r.prototype.setZoom=function(t,e){return this.jumpTo({zoom:t},e),this},r.prototype.zoomTo=function(e,r,n){return this.easeTo(t.extend({zoom:e},r),n)},r.prototype.zoomIn=function(t,e){return this.zoomTo(this.getZoom()+1,t,e),this},r.prototype.zoomOut=function(t,e){return this.zoomTo(this.getZoom()-1,t,e),this},r.prototype.getBearing=function(){return this.transform.bearing},r.prototype.setBearing=function(t,e){return this.jumpTo({bearing:t},e),this},r.prototype.rotateTo=function(e,r,n){return this.easeTo(t.extend({bearing:e},r),n)},r.prototype.resetNorth=function(e,r){return this.rotateTo(0,t.extend({duration:1e3},e),r),this},r.prototype.snapToNorth=function(t,e){return Math.abs(this.getBearing())<this._bearingSnap?this.resetNorth(t,e):this},r.prototype.getPitch=function(){return this.transform.pitch},r.prototype.setPitch=function(t,e){return this.jumpTo({pitch:t},e),this},r.prototype.cameraForBounds=function(e,r){return e=t.LngLatBounds.convert(e),this._cameraForBoxAndBearing(e.getNorthWest(),e.getSouthEast(),0,r)},r.prototype._cameraForBoxAndBearing=function(e,r,n,i){if(\"number\"==typeof(i=t.extend({padding:{top:0,bottom:0,right:0,left:0},offset:[0,0],maxZoom:this.transform.maxZoom},i)).padding){var a=i.padding;i.padding={top:a,bottom:a,right:a,left:a}}if(t.deepEqual(Object.keys(i.padding).sort(function(t,e){return t<e?-1:t>e?1:0}),[\"bottom\",\"left\",\"right\",\"top\"])){var o=this.transform,s=o.project(t.LngLat.convert(e)),l=o.project(t.LngLat.convert(r)),c=s.rotate(-n*Math.PI/180),u=l.rotate(-n*Math.PI/180),h=new t.Point(Math.max(c.x,u.x),Math.max(c.y,u.y)),f=new t.Point(Math.min(c.x,u.x),Math.min(c.y,u.y)),p=h.sub(f),d=(o.width-i.padding.left-i.padding.right)/p.x,g=(o.height-i.padding.top-i.padding.bottom)/p.y;if(!(g<0||d<0)){var v=Math.min(o.scaleZoom(o.scale*Math.min(d,g)),i.maxZoom),m=t.Point.convert(i.offset),y=(i.padding.left-i.padding.right)/2,x=(i.padding.top-i.padding.bottom)/2,b=new t.Point(m.x+y,m.y+x).mult(o.scale/o.zoomScale(v));return{center:o.unproject(s.add(l).div(2).sub(b)),zoom:v,bearing:n}}t.warnOnce(\"Map cannot fit within canvas with the given bounds, padding, and/or offset.\")}else t.warnOnce(\"options.padding must be a positive number, or an Object with keys 'bottom', 'left', 'right', 'top'\")},r.prototype.fitBounds=function(t,e,r){return this._fitInternal(this.cameraForBounds(t,e),e,r)},r.prototype.fitScreenCoordinates=function(e,r,n,i,a){return this._fitInternal(this._cameraForBoxAndBearing(this.transform.pointLocation(t.Point.convert(e)),this.transform.pointLocation(t.Point.convert(r)),n,i),i,a)},r.prototype._fitInternal=function(e,r,n){return e?(r=t.extend(e,r)).linear?this.easeTo(r,n):this.flyTo(r,n):this},r.prototype.jumpTo=function(e,r){this.stop();var n=this.transform,i=!1,a=!1,o=!1;return\"zoom\"in e&&n.zoom!==+e.zoom&&(i=!0,n.zoom=+e.zoom),void 0!==e.center&&(n.center=t.LngLat.convert(e.center)),\"bearing\"in e&&n.bearing!==+e.bearing&&(a=!0,n.bearing=+e.bearing),\"pitch\"in e&&n.pitch!==+e.pitch&&(o=!0,n.pitch=+e.pitch),this.fire(new t.Event(\"movestart\",r)).fire(new t.Event(\"move\",r)),i&&this.fire(new t.Event(\"zoomstart\",r)).fire(new t.Event(\"zoom\",r)).fire(new t.Event(\"zoomend\",r)),a&&this.fire(new t.Event(\"rotatestart\",r)).fire(new t.Event(\"rotate\",r)).fire(new t.Event(\"rotateend\",r)),o&&this.fire(new t.Event(\"pitchstart\",r)).fire(new t.Event(\"pitch\",r)).fire(new t.Event(\"pitchend\",r)),this.fire(new t.Event(\"moveend\",r))},r.prototype.easeTo=function(e,r){var n=this;this.stop(),!1===(e=t.extend({offset:[0,0],duration:500,easing:t.ease},e)).animate&&(e.duration=0);var i=this.transform,a=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=\"zoom\"in e?+e.zoom:a,c=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,u=\"pitch\"in e?+e.pitch:s,h=i.centerPoint.add(t.Point.convert(e.offset)),f=i.pointLocation(h),p=t.LngLat.convert(e.center||f);this._normalizeCenter(p);var d,g,v=i.project(f),m=i.project(p).sub(v),y=i.zoomScale(l-a);return e.around&&(d=t.LngLat.convert(e.around),g=i.locationPoint(d)),this._zooming=l!==a,this._rotating=o!==c,this._pitching=u!==s,this._prepareEase(r,e.noMoveStart),clearTimeout(this._easeEndTimeoutID),this._ease(function(e){if(n._zooming&&(i.zoom=t.number(a,l,e)),n._rotating&&(i.bearing=t.number(o,c,e)),n._pitching&&(i.pitch=t.number(s,u,e)),d)i.setLocationAtPoint(d,g);else{var f=i.zoomScale(i.zoom-a),p=l>a?Math.min(2,y):Math.max(.5,y),x=Math.pow(p,1-e),b=i.unproject(v.add(m.mult(e*x)).mult(f));i.setLocationAtPoint(i.renderWorldCopies?b.wrap():b,h)}n._fireMoveEvents(r)},function(){e.delayEndEvents?n._easeEndTimeoutID=setTimeout(function(){return n._afterEase(r)},e.delayEndEvents):n._afterEase(r)},e),this},r.prototype._prepareEase=function(e,r){this._moving=!0,r||this.fire(new t.Event(\"movestart\",e)),this._zooming&&this.fire(new t.Event(\"zoomstart\",e)),this._rotating&&this.fire(new t.Event(\"rotatestart\",e)),this._pitching&&this.fire(new t.Event(\"pitchstart\",e))},r.prototype._fireMoveEvents=function(e){this.fire(new t.Event(\"move\",e)),this._zooming&&this.fire(new t.Event(\"zoom\",e)),this._rotating&&this.fire(new t.Event(\"rotate\",e)),this._pitching&&this.fire(new t.Event(\"pitch\",e))},r.prototype._afterEase=function(e){var r=this._zooming,n=this._rotating,i=this._pitching;this._moving=!1,this._zooming=!1,this._rotating=!1,this._pitching=!1,r&&this.fire(new t.Event(\"zoomend\",e)),n&&this.fire(new t.Event(\"rotateend\",e)),i&&this.fire(new t.Event(\"pitchend\",e)),this.fire(new t.Event(\"moveend\",e))},r.prototype.flyTo=function(e,r){var n=this;this.stop(),e=t.extend({offset:[0,0],speed:1.2,curve:1.42,easing:t.ease},e);var i=this.transform,a=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=\"zoom\"in e?t.clamp(+e.zoom,i.minZoom,i.maxZoom):a,c=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,u=\"pitch\"in e?+e.pitch:s,h=i.zoomScale(l-a),f=i.centerPoint.add(t.Point.convert(e.offset)),p=i.pointLocation(f),d=t.LngLat.convert(e.center||p);this._normalizeCenter(d);var g=i.project(p),v=i.project(d).sub(g),m=e.curve,y=Math.max(i.width,i.height),x=y/h,b=v.mag();if(\"minZoom\"in e){var _=t.clamp(Math.min(e.minZoom,a,l),i.minZoom,i.maxZoom),w=y/i.zoomScale(_-a);m=Math.sqrt(w/b*2)}var k=m*m;function T(t){var e=(x*x-y*y+(t?-1:1)*k*k*b*b)/(2*(t?x:y)*k*b);return Math.log(Math.sqrt(e*e+1)-e)}function A(t){return(Math.exp(t)-Math.exp(-t))/2}function M(t){return(Math.exp(t)+Math.exp(-t))/2}var S=T(0),E=function(t){return M(S)/M(S+m*t)},C=function(t){return y*((M(S)*(A(e=S+m*t)/M(e))-A(S))/k)/b;var e},L=(T(1)-S)/m;if(Math.abs(b)<1e-6||!isFinite(L)){if(Math.abs(y-x)<1e-6)return this.easeTo(e,r);var P=x<y?-1:1;L=Math.abs(Math.log(x/y))/m,C=function(){return 0},E=function(t){return Math.exp(P*m*t)}}if(\"duration\"in e)e.duration=+e.duration;else{var O=\"screenSpeed\"in e?+e.screenSpeed/m:+e.speed;e.duration=1e3*L/O}return e.maxDuration&&e.duration>e.maxDuration&&(e.duration=0),this._zooming=!0,this._rotating=o!==c,this._pitching=u!==s,this._prepareEase(r,!1),this._ease(function(e){var h=e*L,p=1/E(h);i.zoom=1===e?l:a+i.scaleZoom(p),n._rotating&&(i.bearing=t.number(o,c,e)),n._pitching&&(i.pitch=t.number(s,u,e));var m=1===e?d:i.unproject(g.add(v.mult(C(h))).mult(p));i.setLocationAtPoint(i.renderWorldCopies?m.wrap():m,f),n._fireMoveEvents(r)},function(){return n._afterEase(r)},e),this},r.prototype.isEasing=function(){return!!this._easeFrameId},r.prototype.stop=function(){if(this._easeFrameId&&(this._cancelRenderFrame(this._easeFrameId),delete this._easeFrameId,delete this._onEaseFrame),this._onEaseEnd){var t=this._onEaseEnd;delete this._onEaseEnd,t.call(this)}return this},r.prototype._ease=function(e,r,n){!1===n.animate||0===n.duration?(e(1),r()):(this._easeStart=t.browser.now(),this._easeOptions=n,this._onEaseFrame=e,this._onEaseEnd=r,this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback))},r.prototype._renderFrameCallback=function(){var e=Math.min((t.browser.now()-this._easeStart)/this._easeOptions.duration,1);this._onEaseFrame(this._easeOptions.easing(e)),e<1?this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback):this.stop()},r.prototype._normalizeBearing=function(e,r){e=t.wrap(e,-180,180);var n=Math.abs(e-r);return Math.abs(e-360-r)<n&&(e-=360),Math.abs(e+360-r)<n&&(e+=360),e},r.prototype._normalizeCenter=function(t){var e=this.transform;if(e.renderWorldCopies&&!e.lngRange){var r=t.lng-e.center.lng;t.lng+=r>180?-360:r<-180?360:0}},r}(t.Evented),Mn=function(e){void 0===e&&(e={}),this.options=e,t.bindAll([\"_updateEditLink\",\"_updateData\",\"_updateCompact\"],this)};Mn.prototype.getDefaultPosition=function(){return\"bottom-right\"},Mn.prototype.onAdd=function(t){var e=this.options&&this.options.compact;return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-attrib\"),this._innerContainer=r.create(\"div\",\"mapboxgl-ctrl-attrib-inner\",this._container),e&&this._container.classList.add(\"mapboxgl-compact\"),this._updateAttributions(),this._updateEditLink(),this._map.on(\"styledata\",this._updateData),this._map.on(\"sourcedata\",this._updateData),this._map.on(\"moveend\",this._updateEditLink),void 0===e&&(this._map.on(\"resize\",this._updateCompact),this._updateCompact()),this._container},Mn.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"styledata\",this._updateData),this._map.off(\"sourcedata\",this._updateData),this._map.off(\"moveend\",this._updateEditLink),this._map.off(\"resize\",this._updateCompact),this._map=void 0},Mn.prototype._updateEditLink=function(){var e=this._editLink;e||(e=this._editLink=this._container.querySelector(\".mapbox-improve-map\"));var r=[{key:\"owner\",value:this.styleOwner},{key:\"id\",value:this.styleId},{key:\"access_token\",value:t.config.ACCESS_TOKEN}];if(e){var n=r.reduce(function(t,e,n){return e.value&&(t+=e.key+\"=\"+e.value+(n<r.length-1?\"&\":\"\")),t},\"?\");e.href=t.config.FEEDBACK_URL+\"/\"+n+(this._map._hash?this._map._hash.getHashString(!0):\"\"),e.rel=\"noopener nofollow\"}},Mn.prototype._updateData=function(t){!t||\"metadata\"!==t.sourceDataType&&\"style\"!==t.dataType||(this._updateAttributions(),this._updateEditLink())},Mn.prototype._updateAttributions=function(){if(this._map.style){var t=[];if(this.options.customAttribution&&(Array.isArray(this.options.customAttribution)?t=t.concat(this.options.customAttribution.map(function(t){return\"string\"!=typeof t?\"\":t})):\"string\"==typeof this.options.customAttribution&&t.push(this.options.customAttribution)),this._map.style.stylesheet){var e=this._map.style.stylesheet;this.styleOwner=e.owner,this.styleId=e.id}var r=this._map.style.sourceCaches;for(var n in r){var i=r[n];if(i.used){var a=i.getSource();a.attribution&&t.indexOf(a.attribution)<0&&t.push(a.attribution)}}t.sort(function(t,e){return t.length-e.length});var o=(t=t.filter(function(e,r){for(var n=r+1;n<t.length;n++)if(t[n].indexOf(e)>=0)return!1;return!0})).join(\" | \");o!==this._attribHTML&&(this._attribHTML=o,t.length?(this._innerContainer.innerHTML=o,this._container.classList.remove(\"mapboxgl-attrib-empty\")):this._container.classList.add(\"mapboxgl-attrib-empty\"),this._editLink=null)}},Mn.prototype._updateCompact=function(){this._map.getCanvasContainer().offsetWidth<=640?this._container.classList.add(\"mapboxgl-compact\"):this._container.classList.remove(\"mapboxgl-compact\")};var Sn=function(){t.bindAll([\"_updateLogo\"],this),t.bindAll([\"_updateCompact\"],this)};Sn.prototype.onAdd=function(t){this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl\");var e=r.create(\"a\",\"mapboxgl-ctrl-logo\");return e.target=\"_blank\",e.rel=\"noopener nofollow\",e.href=\"https://www.mapbox.com/\",e.setAttribute(\"aria-label\",\"Mapbox logo\"),e.setAttribute(\"rel\",\"noopener nofollow\"),this._container.appendChild(e),this._container.style.display=\"none\",this._map.on(\"sourcedata\",this._updateLogo),this._updateLogo(),this._map.on(\"resize\",this._updateCompact),this._updateCompact(),this._container},Sn.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"sourcedata\",this._updateLogo),this._map.off(\"resize\",this._updateCompact)},Sn.prototype.getDefaultPosition=function(){return\"bottom-left\"},Sn.prototype._updateLogo=function(t){t&&\"metadata\"!==t.sourceDataType||(this._container.style.display=this._logoRequired()?\"block\":\"none\")},Sn.prototype._logoRequired=function(){if(this._map.style){var t=this._map.style.sourceCaches;for(var e in t)if(t[e].getSource().mapbox_logo)return!0;return!1}},Sn.prototype._updateCompact=function(){var t=this._container.children;if(t.length){var e=t[0];this._map.getCanvasContainer().offsetWidth<250?e.classList.add(\"mapboxgl-compact\"):e.classList.remove(\"mapboxgl-compact\")}};var En=function(){this._queue=[],this._id=0,this._cleared=!1,this._currentlyRunning=!1};En.prototype.add=function(t){var e=++this._id;return this._queue.push({callback:t,id:e,cancelled:!1}),e},En.prototype.remove=function(t){for(var e=this._currentlyRunning,r=0,n=e?this._queue.concat(e):this._queue;r<n.length;r+=1){var i=n[r];if(i.id===t)return void(i.cancelled=!0)}},En.prototype.run=function(){var t=this._currentlyRunning=this._queue;this._queue=[];for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!n.cancelled&&(n.callback(),this._cleared))break}this._cleared=!1,this._currentlyRunning=!1},En.prototype.clear=function(){this._currentlyRunning&&(this._cleared=!0),this._queue=[]};var Cn=t.window.HTMLImageElement,Ln=t.window.HTMLElement,Pn={center:[0,0],zoom:0,bearing:0,pitch:0,minZoom:0,maxZoom:22,interactive:!0,scrollZoom:!0,boxZoom:!0,dragRotate:!0,dragPan:!0,keyboard:!0,doubleClickZoom:!0,touchZoomRotate:!0,bearingSnap:7,clickTolerance:3,hash:!1,attributionControl:!0,failIfMajorPerformanceCaveat:!1,preserveDrawingBuffer:!1,trackResize:!0,renderWorldCopies:!0,refreshExpiredTiles:!0,maxTileCacheSize:null,localIdeographFontFamily:\"sans-serif\",transformRequest:null,fadeDuration:300,crossSourceCollisions:!0},On=function(n){function i(e){var i=this;if(null!=(e=t.extend({},Pn,e)).minZoom&&null!=e.maxZoom&&e.minZoom>e.maxZoom)throw new Error(\"maxZoom must be greater than minZoom\");var a=new sn(e.minZoom,e.maxZoom,e.renderWorldCopies);if(n.call(this,a,e),this._interactive=e.interactive,this._maxTileCacheSize=e.maxTileCacheSize,this._failIfMajorPerformanceCaveat=e.failIfMajorPerformanceCaveat,this._preserveDrawingBuffer=e.preserveDrawingBuffer,this._antialias=e.antialias,this._trackResize=e.trackResize,this._bearingSnap=e.bearingSnap,this._refreshExpiredTiles=e.refreshExpiredTiles,this._fadeDuration=e.fadeDuration,this._crossSourceCollisions=e.crossSourceCollisions,this._crossFadingFactor=1,this._collectResourceTiming=e.collectResourceTiming,this._renderTaskQueue=new En,this._controls=[],this._mapId=t.uniqueId(),this._requestManager=new t.RequestManager(e.transformRequest),\"string\"==typeof e.container){if(this._container=t.window.document.getElementById(e.container),!this._container)throw new Error(\"Container '\"+e.container+\"' not found.\")}else{if(!(e.container instanceof Ln))throw new Error(\"Invalid type: 'container' must be a String or HTMLElement.\");this._container=e.container}if(e.maxBounds&&this.setMaxBounds(e.maxBounds),t.bindAll([\"_onWindowOnline\",\"_onWindowResize\",\"_contextLost\",\"_contextRestored\"],this),this._setupContainer(),this._setupPainter(),void 0===this.painter)throw new Error(\"Failed to initialize WebGL.\");this.on(\"move\",function(){return i._update(!1)}),this.on(\"moveend\",function(){return i._update(!1)}),this.on(\"zoom\",function(){return i._update(!0)}),void 0!==t.window&&(t.window.addEventListener(\"online\",this._onWindowOnline,!1),t.window.addEventListener(\"resize\",this._onWindowResize,!1)),function(t,e){var n=t.getCanvasContainer(),i=null,a=!1,o=null;for(var s in Tn)t[s]=new Tn[s](t,e),e.interactive&&e[s]&&t[s].enable(e[s]);r.addEventListener(n,\"mouseout\",function(e){t.fire(new un(\"mouseout\",t,e))}),r.addEventListener(n,\"mousedown\",function(i){a=!0,o=r.mousePos(n,i);var s=new un(\"mousedown\",t,i);t.fire(s),s.defaultPrevented||(e.interactive&&!t.doubleClickZoom.isActive()&&t.stop(),t.boxZoom.onMouseDown(i),t.boxZoom.isActive()||t.dragPan.isActive()||t.dragRotate.onMouseDown(i),t.boxZoom.isActive()||t.dragRotate.isActive()||t.dragPan.onMouseDown(i))}),r.addEventListener(n,\"mouseup\",function(e){var r=t.dragRotate.isActive();i&&!r&&t.fire(new un(\"contextmenu\",t,i)),i=null,a=!1,t.fire(new un(\"mouseup\",t,e))}),r.addEventListener(n,\"mousemove\",function(e){if(!t.dragPan.isActive()&&!t.dragRotate.isActive()){for(var r=e.target;r&&r!==n;)r=r.parentNode;r===n&&t.fire(new un(\"mousemove\",t,e))}}),r.addEventListener(n,\"mouseover\",function(e){for(var r=e.target;r&&r!==n;)r=r.parentNode;r===n&&t.fire(new un(\"mouseover\",t,e))}),r.addEventListener(n,\"touchstart\",function(r){var n=new hn(\"touchstart\",t,r);t.fire(n),n.defaultPrevented||(e.interactive&&t.stop(),t.boxZoom.isActive()||t.dragRotate.isActive()||t.dragPan.onTouchStart(r),t.touchZoomRotate.onStart(r),t.doubleClickZoom.onTouchStart(n))},{passive:!1}),r.addEventListener(n,\"touchmove\",function(e){t.fire(new hn(\"touchmove\",t,e))},{passive:!1}),r.addEventListener(n,\"touchend\",function(e){t.fire(new hn(\"touchend\",t,e))}),r.addEventListener(n,\"touchcancel\",function(e){t.fire(new hn(\"touchcancel\",t,e))}),r.addEventListener(n,\"click\",function(i){var a=r.mousePos(n,i);(a.equals(o)||a.dist(o)<e.clickTolerance)&&t.fire(new un(\"click\",t,i))}),r.addEventListener(n,\"dblclick\",function(e){var r=new un(\"dblclick\",t,e);t.fire(r),r.defaultPrevented||t.doubleClickZoom.onDblClick(r)}),r.addEventListener(n,\"contextmenu\",function(e){var r=t.dragRotate.isActive();a||r?a&&(i=e):t.fire(new un(\"contextmenu\",t,e)),(t.dragRotate.isEnabled()||t.listens(\"contextmenu\"))&&e.preventDefault()}),r.addEventListener(n,\"wheel\",function(r){e.interactive&&t.stop();var n=new fn(\"wheel\",t,r);t.fire(n),n.defaultPrevented||t.scrollZoom.onWheel(r)},{passive:!1})}(this,e),this._hash=e.hash&&(new cn).addTo(this),this._hash&&this._hash._onHashChange()||(this.jumpTo({center:e.center,zoom:e.zoom,bearing:e.bearing,pitch:e.pitch}),e.bounds&&(this.resize(),this.fitBounds(e.bounds,t.extend({},e.fitBoundsOptions,{duration:0})))),this.resize(),this._localIdeographFontFamily=e.localIdeographFontFamily,e.style&&this.setStyle(e.style,{localIdeographFontFamily:e.localIdeographFontFamily}),e.attributionControl&&this.addControl(new Mn({customAttribution:e.customAttribution})),this.addControl(new Sn,e.logoPosition),this.on(\"style.load\",function(){i.transform.unmodified&&i.jumpTo(i.style.stylesheet)}),this.on(\"data\",function(e){i._update(\"style\"===e.dataType),i.fire(new t.Event(e.dataType+\"data\",e))}),this.on(\"dataloading\",function(e){i.fire(new t.Event(e.dataType+\"dataloading\",e))})}n&&(i.__proto__=n),i.prototype=Object.create(n&&n.prototype),i.prototype.constructor=i;var a={showTileBoundaries:{configurable:!0},showCollisionBoxes:{configurable:!0},showOverdrawInspector:{configurable:!0},repaint:{configurable:!0},vertices:{configurable:!0}};return i.prototype._getMapId=function(){return this._mapId},i.prototype.addControl=function(e,r){if(void 0===r&&e.getDefaultPosition&&(r=e.getDefaultPosition()),void 0===r&&(r=\"top-right\"),!e||!e.onAdd)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.addControl(). Argument must be a control with onAdd and onRemove methods.\")));var n=e.onAdd(this);this._controls.push(e);var i=this._controlPositions[r];return-1!==r.indexOf(\"bottom\")?i.insertBefore(n,i.firstChild):i.appendChild(n),this},i.prototype.removeControl=function(e){if(!e||!e.onRemove)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.removeControl(). Argument must be a control with onAdd and onRemove methods.\")));var r=this._controls.indexOf(e);return r>-1&&this._controls.splice(r,1),e.onRemove(this),this},i.prototype.resize=function(e){var r=this._containerDimensions(),n=r[0],i=r[1];return this._resizeCanvas(n,i),this.transform.resize(n,i),this.painter.resize(n,i),this.fire(new t.Event(\"movestart\",e)).fire(new t.Event(\"move\",e)).fire(new t.Event(\"resize\",e)).fire(new t.Event(\"moveend\",e)),this},i.prototype.getBounds=function(){return this.transform.getBounds()},i.prototype.getMaxBounds=function(){return this.transform.getMaxBounds()},i.prototype.setMaxBounds=function(e){return this.transform.setMaxBounds(t.LngLatBounds.convert(e)),this._update()},i.prototype.setMinZoom=function(t){if((t=null==t?0:t)>=0&&t<=this.transform.maxZoom)return this.transform.minZoom=t,this._update(),this.getZoom()<t&&this.setZoom(t),this;throw new Error(\"minZoom must be between 0 and the current maxZoom, inclusive\")},i.prototype.getMinZoom=function(){return this.transform.minZoom},i.prototype.setMaxZoom=function(t){if((t=null==t?22:t)>=this.transform.minZoom)return this.transform.maxZoom=t,this._update(),this.getZoom()>t&&this.setZoom(t),this;throw new Error(\"maxZoom must be greater than the current minZoom\")},i.prototype.getRenderWorldCopies=function(){return this.transform.renderWorldCopies},i.prototype.setRenderWorldCopies=function(t){return this.transform.renderWorldCopies=t,this._update()},i.prototype.getMaxZoom=function(){return this.transform.maxZoom},i.prototype.project=function(e){return this.transform.locationPoint(t.LngLat.convert(e))},i.prototype.unproject=function(e){return this.transform.pointLocation(t.Point.convert(e))},i.prototype.isMoving=function(){return this._moving||this.dragPan.isActive()||this.dragRotate.isActive()||this.scrollZoom.isActive()},i.prototype.isZooming=function(){return this._zooming||this.scrollZoom.isZooming()},i.prototype.isRotating=function(){return this._rotating||this.dragRotate.isActive()},i.prototype.on=function(t,e,r){var i=this;if(void 0===r)return n.prototype.on.call(this,t,e);var a=function(){var n;if(\"mouseenter\"===t||\"mouseover\"===t){var a=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){var o=i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[];o.length?a||(a=!0,r.call(i,new un(t,i,n.originalEvent,{features:o}))):a=!1},mouseout:function(){a=!1}}}}if(\"mouseleave\"===t||\"mouseout\"===t){var o=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){(i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[]).length?o=!0:o&&(o=!1,r.call(i,new un(t,i,n.originalEvent)))},mouseout:function(e){o&&(o=!1,r.call(i,new un(t,i,e.originalEvent)))}}}}return{layer:e,listener:r,delegates:(n={},n[t]=function(t){var n=i.getLayer(e)?i.queryRenderedFeatures(t.point,{layers:[e]}):[];n.length&&(t.features=n,r.call(i,t),delete t.features)},n)}}();for(var o in this._delegatedListeners=this._delegatedListeners||{},this._delegatedListeners[t]=this._delegatedListeners[t]||[],this._delegatedListeners[t].push(a),a.delegates)this.on(o,a.delegates[o]);return this},i.prototype.off=function(t,e,r){if(void 0===r)return n.prototype.off.call(this,t,e);if(this._delegatedListeners&&this._delegatedListeners[t])for(var i=this._delegatedListeners[t],a=0;a<i.length;a++){var o=i[a];if(o.layer===e&&o.listener===r){for(var s in o.delegates)this.off(s,o.delegates[s]);return i.splice(a,1),this}}return this},i.prototype.queryRenderedFeatures=function(e,r){if(!this.style)return[];var n;if(void 0!==r||void 0===e||e instanceof t.Point||Array.isArray(e)||(r=e,e=void 0),r=r||{},(e=e||[[0,0],[this.transform.width,this.transform.height]])instanceof t.Point||\"number\"==typeof e[0])n=[t.Point.convert(e)];else{var i=t.Point.convert(e[0]),a=t.Point.convert(e[1]);n=[i,new t.Point(a.x,i.y),a,new t.Point(i.x,a.y),i]}return this.style.queryRenderedFeatures(n,r,this.transform)},i.prototype.querySourceFeatures=function(t,e){return this.style.querySourceFeatures(t,e)},i.prototype.setStyle=function(e,r){return!1!==(r=t.extend({},{localIdeographFontFamily:Pn.localIdeographFontFamily},r)).diff&&r.localIdeographFontFamily===this._localIdeographFontFamily&&this.style&&e?(this._diffStyle(e,r),this):(this._localIdeographFontFamily=r.localIdeographFontFamily,this._updateStyle(e,r))},i.prototype._updateStyle=function(t,e){return this.style&&(this.style.setEventedParent(null),this.style._remove()),t?(this.style=new De(this,e||{}),this.style.setEventedParent(this,{style:this.style}),\"string\"==typeof t?this.style.loadURL(t):this.style.loadJSON(t),this):(delete this.style,this)},i.prototype._diffStyle=function(e,r){var n=this;if(\"string\"==typeof e){var i=this._requestManager.normalizeStyleURL(e),a=this._requestManager.transformRequest(i,t.ResourceType.Style);t.getJSON(a,function(e,i){e?n.fire(new t.ErrorEvent(e)):i&&n._updateDiff(i,r)})}else\"object\"==typeof e&&this._updateDiff(e,r)},i.prototype._updateDiff=function(e,r){try{this.style.setState(e)&&this._update(!0)}catch(n){t.warnOnce(\"Unable to perform style diff: \"+(n.message||n.error||n)+\".  Rebuilding the style from scratch.\"),this._updateStyle(e,r)}},i.prototype.getStyle=function(){if(this.style)return this.style.serialize()},i.prototype.isStyleLoaded=function(){return this.style?this.style.loaded():t.warnOnce(\"There is no style added to the map.\")},i.prototype.addSource=function(t,e){return this.style.addSource(t,e),this._update(!0)},i.prototype.isSourceLoaded=function(e){var r=this.style&&this.style.sourceCaches[e];if(void 0!==r)return r.loaded();this.fire(new t.ErrorEvent(new Error(\"There is no source with ID '\"+e+\"'\")))},i.prototype.areTilesLoaded=function(){var t=this.style&&this.style.sourceCaches;for(var e in t){var r=t[e]._tiles;for(var n in r){var i=r[n];if(\"loaded\"!==i.state&&\"errored\"!==i.state)return!1}}return!0},i.prototype.addSourceType=function(t,e,r){return this.style.addSourceType(t,e,r)},i.prototype.removeSource=function(t){return this.style.removeSource(t),this._update(!0)},i.prototype.getSource=function(t){return this.style.getSource(t)},i.prototype.addImage=function(e,r,n){void 0===n&&(n={});var i=n.pixelRatio;void 0===i&&(i=1);var a=n.sdf;if(void 0===a&&(a=!1),r instanceof Cn){var o=t.browser.getImageData(r),s=o.width,l=o.height,c=o.data;this.style.addImage(e,{data:new t.RGBAImage({width:s,height:l},c),pixelRatio:i,sdf:a,version:0})}else{if(void 0===r.width||void 0===r.height)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.addImage(). The second argument must be an `HTMLImageElement`, `ImageData`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));var u=r.width,h=r.height,f=r.data,p=r;this.style.addImage(e,{data:new t.RGBAImage({width:u,height:h},new Uint8Array(f)),pixelRatio:i,sdf:a,version:0,userImage:p}),p.onAdd&&p.onAdd(this,e)}},i.prototype.updateImage=function(e,r){var n=this.style.getImage(e);if(!n)return this.fire(new t.ErrorEvent(new Error(\"The map has no image with that id. If you are adding a new image use `map.addImage(...)` instead.\")));var i=r instanceof Cn?t.browser.getImageData(r):r,a=i.width,o=i.height,s=i.data;if(void 0===a||void 0===o)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.updateImage(). The second argument must be an `HTMLImageElement`, `ImageData`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));if(a!==n.data.width||o!==n.data.height)return this.fire(new t.ErrorEvent(new Error(\"The width and height of the updated image must be that same as the previous version of the image\")));var l=!(r instanceof Cn);n.data.replace(s,l),this.style.updateImage(e,n)},i.prototype.hasImage=function(e){return e?!!this.style.getImage(e):(this.fire(new t.ErrorEvent(new Error(\"Missing required image id\"))),!1)},i.prototype.removeImage=function(t){this.style.removeImage(t)},i.prototype.loadImage=function(e,r){t.getImage(this._requestManager.transformRequest(e,t.ResourceType.Image),r)},i.prototype.listImages=function(){return this.style.listImages()},i.prototype.addLayer=function(t,e){return this.style.addLayer(t,e),this._update(!0)},i.prototype.moveLayer=function(t,e){return this.style.moveLayer(t,e),this._update(!0)},i.prototype.removeLayer=function(t){return this.style.removeLayer(t),this._update(!0)},i.prototype.getLayer=function(t){return this.style.getLayer(t)},i.prototype.setFilter=function(t,e,r){return void 0===r&&(r={}),this.style.setFilter(t,e,r),this._update(!0)},i.prototype.setLayerZoomRange=function(t,e,r){return this.style.setLayerZoomRange(t,e,r),this._update(!0)},i.prototype.getFilter=function(t){return this.style.getFilter(t)},i.prototype.setPaintProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setPaintProperty(t,e,r,n),this._update(!0)},i.prototype.getPaintProperty=function(t,e){return this.style.getPaintProperty(t,e)},i.prototype.setLayoutProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setLayoutProperty(t,e,r,n),this._update(!0)},i.prototype.getLayoutProperty=function(t,e){return this.style.getLayoutProperty(t,e)},i.prototype.setLight=function(t,e){return void 0===e&&(e={}),this.style.setLight(t,e),this._update(!0)},i.prototype.getLight=function(){return this.style.getLight()},i.prototype.setFeatureState=function(t,e){return this.style.setFeatureState(t,e),this._update()},i.prototype.removeFeatureState=function(t,e){return this.style.removeFeatureState(t,e),this._update()},i.prototype.getFeatureState=function(t){return this.style.getFeatureState(t)},i.prototype.getContainer=function(){return this._container},i.prototype.getCanvasContainer=function(){return this._canvasContainer},i.prototype.getCanvas=function(){return this._canvas},i.prototype._containerDimensions=function(){var t=0,e=0;return this._container&&(t=this._container.clientWidth||400,e=this._container.clientHeight||300),[t,e]},i.prototype._detectMissingCSS=function(){\"rgb(250, 128, 114)\"!==t.window.getComputedStyle(this._missingCSSCanary).getPropertyValue(\"background-color\")&&t.warnOnce(\"This page appears to be missing CSS declarations for Mapbox GL JS, which may cause the map to display incorrectly. Please ensure your page includes mapbox-gl.css, as described in https://www.mapbox.com/mapbox-gl-js/api/.\")},i.prototype._setupContainer=function(){var t=this._container;t.classList.add(\"mapboxgl-map\"),(this._missingCSSCanary=r.create(\"div\",\"mapboxgl-canary\",t)).style.visibility=\"hidden\",this._detectMissingCSS();var e=this._canvasContainer=r.create(\"div\",\"mapboxgl-canvas-container\",t);this._interactive&&e.classList.add(\"mapboxgl-interactive\"),this._canvas=r.create(\"canvas\",\"mapboxgl-canvas\",e),this._canvas.style.position=\"absolute\",this._canvas.addEventListener(\"webglcontextlost\",this._contextLost,!1),this._canvas.addEventListener(\"webglcontextrestored\",this._contextRestored,!1),this._canvas.setAttribute(\"tabindex\",\"0\"),this._canvas.setAttribute(\"aria-label\",\"Map\");var n=this._containerDimensions();this._resizeCanvas(n[0],n[1]);var i=this._controlContainer=r.create(\"div\",\"mapboxgl-control-container\",t),a=this._controlPositions={};[\"top-left\",\"top-right\",\"bottom-left\",\"bottom-right\"].forEach(function(t){a[t]=r.create(\"div\",\"mapboxgl-ctrl-\"+t,i)})},i.prototype._resizeCanvas=function(e,r){var n=t.window.devicePixelRatio||1;this._canvas.width=n*e,this._canvas.height=n*r,this._canvas.style.width=e+\"px\",this._canvas.style.height=r+\"px\"},i.prototype._setupPainter=function(){var r=t.extend({},e.webGLContextAttributes,{failIfMajorPerformanceCaveat:this._failIfMajorPerformanceCaveat,preserveDrawingBuffer:this._preserveDrawingBuffer,antialias:this._antialias||!1}),n=this._canvas.getContext(\"webgl\",r)||this._canvas.getContext(\"experimental-webgl\",r);n?(this.painter=new rn(n,this.transform),t.webpSupported.testSupport(n)):this.fire(new t.ErrorEvent(new Error(\"Failed to initialize WebGL\")))},i.prototype._contextLost=function(e){e.preventDefault(),this._frame&&(this._frame.cancel(),this._frame=null),this.fire(new t.Event(\"webglcontextlost\",{originalEvent:e}))},i.prototype._contextRestored=function(e){this._setupPainter(),this.resize(),this._update(),this.fire(new t.Event(\"webglcontextrestored\",{originalEvent:e}))},i.prototype.loaded=function(){return!this._styleDirty&&!this._sourcesDirty&&!!this.style&&this.style.loaded()},i.prototype._update=function(t){return this.style?(this._styleDirty=this._styleDirty||t,this._sourcesDirty=!0,this.triggerRepaint(),this):this},i.prototype._requestRenderFrame=function(t){return this._update(),this._renderTaskQueue.add(t)},i.prototype._cancelRenderFrame=function(t){this._renderTaskQueue.remove(t)},i.prototype._render=function(){this.painter.context.setDirty(),this.painter.setBaseState(),this._renderTaskQueue.run();var e=!1;if(this.style&&this._styleDirty){this._styleDirty=!1;var r=this.transform.zoom,n=t.browser.now();this.style.zoomHistory.update(r,n);var i=new t.EvaluationParameters(r,{now:n,fadeDuration:this._fadeDuration,zoomHistory:this.style.zoomHistory,transition:this.style.getTransition()}),a=i.crossFadingFactor();1===a&&a===this._crossFadingFactor||(e=!0,this._crossFadingFactor=a),this.style.update(i)}return this.style&&this._sourcesDirty&&(this._sourcesDirty=!1,this.style._updateSources(this.transform)),this._placementDirty=this.style&&this.style._updatePlacement(this.painter.transform,this.showCollisionBoxes,this._fadeDuration,this._crossSourceCollisions),this.painter.render(this.style,{showTileBoundaries:this.showTileBoundaries,showOverdrawInspector:this._showOverdrawInspector,rotating:this.isRotating(),zooming:this.isZooming(),moving:this.isMoving(),fadeDuration:this._fadeDuration}),this.fire(new t.Event(\"render\")),this.loaded()&&!this._loaded&&(this._loaded=!0,this.fire(new t.Event(\"load\"))),this.style&&(this.style.hasTransitions()||e)&&(this._styleDirty=!0),this.style&&!this._placementDirty&&this.style._releaseSymbolFadeTiles(),this._sourcesDirty||this._repaint||this._styleDirty||this._placementDirty?this.triggerRepaint():!this.isMoving()&&this.loaded()&&this.fire(new t.Event(\"idle\")),this},i.prototype.remove=function(){this._hash&&this._hash.remove();for(var e=0,r=this._controls;e<r.length;e+=1)r[e].onRemove(this);this._controls=[],this._frame&&(this._frame.cancel(),this._frame=null),this._renderTaskQueue.clear(),this.setStyle(null),void 0!==t.window&&(t.window.removeEventListener(\"resize\",this._onWindowResize,!1),t.window.removeEventListener(\"online\",this._onWindowOnline,!1));var n=this.painter.context.gl.getExtension(\"WEBGL_lose_context\");n&&n.loseContext(),zn(this._canvasContainer),zn(this._controlContainer),zn(this._missingCSSCanary),this._container.classList.remove(\"mapboxgl-map\"),this.fire(new t.Event(\"remove\"))},i.prototype.triggerRepaint=function(){var e=this;this.style&&!this._frame&&(this._frame=t.browser.frame(function(){e._frame=null,e._render()}))},i.prototype._onWindowOnline=function(){this._update()},i.prototype._onWindowResize=function(){this._trackResize&&this.resize()._update()},a.showTileBoundaries.get=function(){return!!this._showTileBoundaries},a.showTileBoundaries.set=function(t){this._showTileBoundaries!==t&&(this._showTileBoundaries=t,this._update())},a.showCollisionBoxes.get=function(){return!!this._showCollisionBoxes},a.showCollisionBoxes.set=function(t){this._showCollisionBoxes!==t&&(this._showCollisionBoxes=t,t?this.style._generateCollisionBoxes():this._update())},a.showOverdrawInspector.get=function(){return!!this._showOverdrawInspector},a.showOverdrawInspector.set=function(t){this._showOverdrawInspector!==t&&(this._showOverdrawInspector=t,this._update())},a.repaint.get=function(){return!!this._repaint},a.repaint.set=function(t){this._repaint!==t&&(this._repaint=t,this.triggerRepaint())},a.vertices.get=function(){return!!this._vertices},a.vertices.set=function(t){this._vertices=t,this._update()},i.prototype._setCacheLimits=function(e,r){t.setCacheLimits(e,r)},Object.defineProperties(i.prototype,a),i}(An);function zn(t){t.parentNode&&t.parentNode.removeChild(t)}var In={showCompass:!0,showZoom:!0},Dn=function(e){var n=this;this.options=t.extend({},In,e),this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),this._container.addEventListener(\"contextmenu\",function(t){return t.preventDefault()}),this.options.showZoom&&(t.bindAll([\"_updateZoomButtons\"],this),this._zoomInButton=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-zoom-in\",\"Zoom in\",function(){return n._map.zoomIn()}),this._zoomOutButton=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-zoom-out\",\"Zoom out\",function(){return n._map.zoomOut()})),this.options.showCompass&&(t.bindAll([\"_rotateCompassArrow\"],this),this._compass=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-compass\",\"Reset bearing to north\",function(){return n._map.resetNorth()}),this._compassArrow=r.create(\"span\",\"mapboxgl-ctrl-compass-arrow\",this._compass))};function Rn(e,r,n){if(e=new t.LngLat(e.lng,e.lat),r){var i=new t.LngLat(e.lng-360,e.lat),a=new t.LngLat(e.lng+360,e.lat),o=n.locationPoint(e).distSqr(r);n.locationPoint(i).distSqr(r)<o?e=i:n.locationPoint(a).distSqr(r)<o&&(e=a)}for(;Math.abs(e.lng-n.center.lng)>180;){var s=n.locationPoint(e);if(s.x>=0&&s.y>=0&&s.x<=n.width&&s.y<=n.height)break;e.lng>n.center.lng?e.lng-=360:e.lng+=360}return e}Dn.prototype._updateZoomButtons=function(){var t=this._map.getZoom();this._zoomInButton.classList.toggle(\"mapboxgl-ctrl-icon-disabled\",t===this._map.getMaxZoom()),this._zoomOutButton.classList.toggle(\"mapboxgl-ctrl-icon-disabled\",t===this._map.getMinZoom())},Dn.prototype._rotateCompassArrow=function(){var t=\"rotate(\"+this._map.transform.angle*(180/Math.PI)+\"deg)\";this._compassArrow.style.transform=t},Dn.prototype.onAdd=function(t){return this._map=t,this.options.showZoom&&(this._map.on(\"zoom\",this._updateZoomButtons),this._updateZoomButtons()),this.options.showCompass&&(this._map.on(\"rotate\",this._rotateCompassArrow),this._rotateCompassArrow(),this._handler=new vn(t,{button:\"left\",element:this._compass}),r.addEventListener(this._compass,\"mousedown\",this._handler.onMouseDown),this._handler.enable()),this._container},Dn.prototype.onRemove=function(){r.remove(this._container),this.options.showZoom&&this._map.off(\"zoom\",this._updateZoomButtons),this.options.showCompass&&(this._map.off(\"rotate\",this._rotateCompassArrow),r.removeEventListener(this._compass,\"mousedown\",this._handler.onMouseDown),this._handler.disable(),delete this._handler),delete this._map},Dn.prototype._createButton=function(t,e,n){var i=r.create(\"button\",t,this._container);return i.type=\"button\",i.title=e,i.setAttribute(\"aria-label\",e),i.addEventListener(\"click\",n),i};var Fn={center:\"translate(-50%,-50%)\",top:\"translate(-50%,0)\",\"top-left\":\"translate(0,0)\",\"top-right\":\"translate(-100%,0)\",bottom:\"translate(-50%,-100%)\",\"bottom-left\":\"translate(0,-100%)\",\"bottom-right\":\"translate(-100%,-100%)\",left:\"translate(0,-50%)\",right:\"translate(-100%,-50%)\"};function Bn(t,e,r){var n=t.classList;for(var i in Fn)n.remove(\"mapboxgl-\"+r+\"-anchor-\"+i);n.add(\"mapboxgl-\"+r+\"-anchor-\"+e)}var Nn,jn=function(e){function n(n,i){if(e.call(this),(n instanceof t.window.HTMLElement||i)&&(n=t.extend({element:n},i)),t.bindAll([\"_update\",\"_onMove\",\"_onUp\",\"_addDragHandler\",\"_onMapClick\"],this),this._anchor=n&&n.anchor||\"center\",this._color=n&&n.color||\"#3FB1CE\",this._draggable=n&&n.draggable||!1,this._state=\"inactive\",n&&n.element)this._element=n.element,this._offset=t.Point.convert(n&&n.offset||[0,0]);else{this._defaultMarker=!0,this._element=r.create(\"div\");var a=r.createNS(\"http://www.w3.org/2000/svg\",\"svg\");a.setAttributeNS(null,\"display\",\"block\"),a.setAttributeNS(null,\"height\",\"41px\"),a.setAttributeNS(null,\"width\",\"27px\"),a.setAttributeNS(null,\"viewBox\",\"0 0 27 41\");var o=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");o.setAttributeNS(null,\"stroke\",\"none\"),o.setAttributeNS(null,\"stroke-width\",\"1\"),o.setAttributeNS(null,\"fill\",\"none\"),o.setAttributeNS(null,\"fill-rule\",\"evenodd\");var s=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");s.setAttributeNS(null,\"fill-rule\",\"nonzero\");var l=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");l.setAttributeNS(null,\"transform\",\"translate(3.0, 29.0)\"),l.setAttributeNS(null,\"fill\",\"#000000\");for(var c=0,u=[{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"9.5\",ry:\"4.77275007\"},{rx:\"8.5\",ry:\"4.29549936\"},{rx:\"7.5\",ry:\"3.81822308\"},{rx:\"6.5\",ry:\"3.34094679\"},{rx:\"5.5\",ry:\"2.86367051\"},{rx:\"4.5\",ry:\"2.38636864\"}];c<u.length;c+=1){var h=u[c],f=r.createNS(\"http://www.w3.org/2000/svg\",\"ellipse\");f.setAttributeNS(null,\"opacity\",\"0.04\"),f.setAttributeNS(null,\"cx\",\"10.5\"),f.setAttributeNS(null,\"cy\",\"5.80029008\"),f.setAttributeNS(null,\"rx\",h.rx),f.setAttributeNS(null,\"ry\",h.ry),l.appendChild(f)}var p=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");p.setAttributeNS(null,\"fill\",this._color);var d=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");d.setAttributeNS(null,\"d\",\"M27,13.5 C27,19.074644 20.250001,27.000002 14.75,34.500002 C14.016665,35.500004 12.983335,35.500004 12.25,34.500002 C6.7499993,27.000002 0,19.222562 0,13.5 C0,6.0441559 6.0441559,0 13.5,0 C20.955844,0 27,6.0441559 27,13.5 Z\"),p.appendChild(d);var g=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");g.setAttributeNS(null,\"opacity\",\"0.25\"),g.setAttributeNS(null,\"fill\",\"#000000\");var v=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");v.setAttributeNS(null,\"d\",\"M13.5,0 C6.0441559,0 0,6.0441559 0,13.5 C0,19.222562 6.7499993,27 12.25,34.5 C13,35.522727 14.016664,35.500004 14.75,34.5 C20.250001,27 27,19.074644 27,13.5 C27,6.0441559 20.955844,0 13.5,0 Z M13.5,1 C20.415404,1 26,6.584596 26,13.5 C26,15.898657 24.495584,19.181431 22.220703,22.738281 C19.945823,26.295132 16.705119,30.142167 13.943359,33.908203 C13.743445,34.180814 13.612715,34.322738 13.5,34.441406 C13.387285,34.322738 13.256555,34.180814 13.056641,33.908203 C10.284481,30.127985 7.4148684,26.314159 5.015625,22.773438 C2.6163816,19.232715 1,15.953538 1,13.5 C1,6.584596 6.584596,1 13.5,1 Z\"),g.appendChild(v);var m=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");m.setAttributeNS(null,\"transform\",\"translate(6.0, 7.0)\"),m.setAttributeNS(null,\"fill\",\"#FFFFFF\");var y=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");y.setAttributeNS(null,\"transform\",\"translate(8.0, 8.0)\");var x=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");x.setAttributeNS(null,\"fill\",\"#000000\"),x.setAttributeNS(null,\"opacity\",\"0.25\"),x.setAttributeNS(null,\"cx\",\"5.5\"),x.setAttributeNS(null,\"cy\",\"5.5\"),x.setAttributeNS(null,\"r\",\"5.4999962\");var b=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");b.setAttributeNS(null,\"fill\",\"#FFFFFF\"),b.setAttributeNS(null,\"cx\",\"5.5\"),b.setAttributeNS(null,\"cy\",\"5.5\"),b.setAttributeNS(null,\"r\",\"5.4999962\"),y.appendChild(x),y.appendChild(b),s.appendChild(l),s.appendChild(p),s.appendChild(g),s.appendChild(m),s.appendChild(y),a.appendChild(s),this._element.appendChild(a),this._offset=t.Point.convert(n&&n.offset||[0,-14])}this._element.classList.add(\"mapboxgl-marker\"),this._element.addEventListener(\"dragstart\",function(t){t.preventDefault()}),Bn(this._element,this._anchor,\"marker\"),this._popup=null}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.addTo=function(t){return this.remove(),this._map=t,t.getCanvasContainer().appendChild(this._element),t.on(\"move\",this._update),t.on(\"moveend\",this._update),this.setDraggable(this._draggable),this._update(),this._map.on(\"click\",this._onMapClick),this},n.prototype.remove=function(){return this._map&&(this._map.off(\"click\",this._onMapClick),this._map.off(\"move\",this._update),this._map.off(\"moveend\",this._update),this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler),this._map.off(\"mouseup\",this._onUp),this._map.off(\"touchend\",this._onUp),delete this._map),r.remove(this._element),this._popup&&this._popup.remove(),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._popup&&this._popup.setLngLat(this._lngLat),this._update(),this},n.prototype.getElement=function(){return this._element},n.prototype.setPopup=function(t){if(this._popup&&(this._popup.remove(),this._popup=null),t){if(!(\"offset\"in t.options)){var e=Math.sqrt(Math.pow(13.5,2)/2);t.options.offset=this._defaultMarker?{top:[0,0],\"top-left\":[0,0],\"top-right\":[0,0],bottom:[0,-38.1],\"bottom-left\":[e,-1*(24.6+e)],\"bottom-right\":[-e,-1*(24.6+e)],left:[13.5,-24.6],right:[-13.5,-24.6]}:this._offset}this._popup=t,this._lngLat&&this._popup.setLngLat(this._lngLat)}return this},n.prototype._onMapClick=function(t){var e=t.originalEvent.target,r=this._element;this._popup&&(e===r||r.contains(e))&&this.togglePopup()},n.prototype.getPopup=function(){return this._popup},n.prototype.togglePopup=function(){var t=this._popup;return t?(t.isOpen()?t.remove():t.addTo(this._map),this):this},n.prototype._update=function(t){this._map&&(this._map.transform.renderWorldCopies&&(this._lngLat=Rn(this._lngLat,this._pos,this._map.transform)),this._pos=this._map.project(this._lngLat)._add(this._offset),t&&\"moveend\"!==t.type||(this._pos=this._pos.round()),r.setTransform(this._element,Fn[this._anchor]+\" translate(\"+this._pos.x+\"px, \"+this._pos.y+\"px)\"))},n.prototype.getOffset=function(){return this._offset},n.prototype.setOffset=function(e){return this._offset=t.Point.convert(e),this._update(),this},n.prototype._onMove=function(e){this._pos=e.point.sub(this._positionDelta),this._lngLat=this._map.unproject(this._pos),this.setLngLat(this._lngLat),this._element.style.pointerEvents=\"none\",\"pending\"===this._state&&(this._state=\"active\",this.fire(new t.Event(\"dragstart\"))),this.fire(new t.Event(\"drag\"))},n.prototype._onUp=function(){this._element.style.pointerEvents=\"auto\",this._positionDelta=null,this._map.off(\"mousemove\",this._onMove),this._map.off(\"touchmove\",this._onMove),\"active\"===this._state&&this.fire(new t.Event(\"dragend\")),this._state=\"inactive\"},n.prototype._addDragHandler=function(t){this._element.contains(t.originalEvent.target)&&(t.preventDefault(),this._positionDelta=t.point.sub(this._pos).add(this._offset),this._state=\"pending\",this._map.on(\"mousemove\",this._onMove),this._map.on(\"touchmove\",this._onMove),this._map.once(\"mouseup\",this._onUp),this._map.once(\"touchend\",this._onUp))},n.prototype.setDraggable=function(t){return this._draggable=!!t,this._map&&(t?(this._map.on(\"mousedown\",this._addDragHandler),this._map.on(\"touchstart\",this._addDragHandler)):(this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler))),this},n.prototype.isDraggable=function(){return this._draggable},n}(t.Evented),Un={positionOptions:{enableHighAccuracy:!1,maximumAge:0,timeout:6e3},fitBoundsOptions:{maxZoom:15},trackUserLocation:!1,showUserLocation:!0},Vn=function(e){function n(r){e.call(this),this.options=t.extend({},Un,r),t.bindAll([\"_onSuccess\",\"_onError\",\"_finish\",\"_setupUI\",\"_updateCamera\",\"_updateMarker\"],this)}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.onAdd=function(e){var n;return this._map=e,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),n=this._setupUI,void 0!==Nn?n(Nn):void 0!==t.window.navigator.permissions?t.window.navigator.permissions.query({name:\"geolocation\"}).then(function(t){Nn=\"denied\"!==t.state,n(Nn)}):(Nn=!!t.window.navigator.geolocation,n(Nn)),this._container},n.prototype.onRemove=function(){void 0!==this._geolocationWatchID&&(t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0),this.options.showUserLocation&&this._userLocationDotMarker&&this._userLocationDotMarker.remove(),r.remove(this._container),this._map=void 0},n.prototype._onSuccess=function(e){if(this.options.trackUserLocation)switch(this._lastKnownPosition=e,this._watchState){case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"BACKGROUND\":case\"BACKGROUND_ERROR\":this._watchState=\"BACKGROUND\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\")}this.options.showUserLocation&&\"OFF\"!==this._watchState&&this._updateMarker(e),this.options.trackUserLocation&&\"ACTIVE_LOCK\"!==this._watchState||this._updateCamera(e),this.options.showUserLocation&&this._dotElement.classList.remove(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"geolocate\",e)),this._finish()},n.prototype._updateCamera=function(e){var r=new t.LngLat(e.coords.longitude,e.coords.latitude),n=e.coords.accuracy,i=this._map.getBearing(),a=t.extend({bearing:i},this.options.fitBoundsOptions);this._map.fitBounds(r.toBounds(n),a,{geolocateSource:!0})},n.prototype._updateMarker=function(t){t?this._userLocationDotMarker.setLngLat([t.coords.longitude,t.coords.latitude]).addTo(this._map):this._userLocationDotMarker.remove()},n.prototype._onError=function(e){if(this.options.trackUserLocation)if(1===e.code)this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),void 0!==this._geolocationWatchID&&this._clearWatch();else switch(this._watchState){case\"WAITING_ACTIVE\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"ACTIVE_LOCK\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\");break;case\"BACKGROUND\":this._watchState=\"BACKGROUND_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\")}\"OFF\"!==this._watchState&&this.options.showUserLocation&&this._dotElement.classList.add(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"error\",e)),this._finish()},n.prototype._finish=function(){this._timeoutId&&clearTimeout(this._timeoutId),this._timeoutId=void 0},n.prototype._setupUI=function(e){var n=this;!1!==e?(this._container.addEventListener(\"contextmenu\",function(t){return t.preventDefault()}),this._geolocateButton=r.create(\"button\",\"mapboxgl-ctrl-icon mapboxgl-ctrl-geolocate\",this._container),this._geolocateButton.type=\"button\",this._geolocateButton.setAttribute(\"aria-label\",\"Geolocate\"),this.options.trackUserLocation&&(this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this._watchState=\"OFF\"),this.options.showUserLocation&&(this._dotElement=r.create(\"div\",\"mapboxgl-user-location-dot\"),this._userLocationDotMarker=new jn(this._dotElement),this.options.trackUserLocation&&(this._watchState=\"OFF\")),this._geolocateButton.addEventListener(\"click\",this.trigger.bind(this)),this._setup=!0,this.options.trackUserLocation&&this._map.on(\"movestart\",function(e){e.geolocateSource||\"ACTIVE_LOCK\"!==n._watchState||(n._watchState=\"BACKGROUND\",n._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\"),n._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),n.fire(new t.Event(\"trackuserlocationend\")))})):t.warnOnce(\"Geolocation support is not available, the GeolocateControl will not be visible.\")},n.prototype.trigger=function(){if(!this._setup)return t.warnOnce(\"Geolocate control triggered before added to a map\"),!1;if(this.options.trackUserLocation){switch(this._watchState){case\"OFF\":this._watchState=\"WAITING_ACTIVE\",this.fire(new t.Event(\"trackuserlocationstart\"));break;case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":case\"BACKGROUND_ERROR\":this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this.fire(new t.Event(\"trackuserlocationend\"));break;case\"BACKGROUND\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._lastKnownPosition&&this._updateCamera(this._lastKnownPosition),this.fire(new t.Event(\"trackuserlocationstart\"))}switch(this._watchState){case\"WAITING_ACTIVE\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_LOCK\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"BACKGROUND\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\");break;case\"BACKGROUND_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\")}\"OFF\"===this._watchState&&void 0!==this._geolocationWatchID?this._clearWatch():void 0===this._geolocationWatchID&&(this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"true\"),this._geolocationWatchID=t.window.navigator.geolocation.watchPosition(this._onSuccess,this._onError,this.options.positionOptions))}else t.window.navigator.geolocation.getCurrentPosition(this._onSuccess,this._onError,this.options.positionOptions),this._timeoutId=setTimeout(this._finish,1e4);return!0},n.prototype._clearWatch=function(){t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0,this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this.options.showUserLocation&&this._updateMarker(null)},n}(t.Evented),qn={maxWidth:100,unit:\"metric\"},Hn=function(e){this.options=t.extend({},qn,e),t.bindAll([\"_onMove\",\"setUnit\"],this)};function Gn(t,e,r){var n,i,a,o,s,l,c=r&&r.maxWidth||100,u=t._container.clientHeight/2,h=(n=t.unproject([0,u]),i=t.unproject([c,u]),a=Math.PI/180,o=n.lat*a,s=i.lat*a,l=Math.sin(o)*Math.sin(s)+Math.cos(o)*Math.cos(s)*Math.cos((i.lng-n.lng)*a),6371e3*Math.acos(Math.min(l,1)));if(r&&\"imperial\"===r.unit){var f=3.2808*h;f>5280?Yn(e,c,f/5280,\"mi\"):Yn(e,c,f,\"ft\")}else r&&\"nautical\"===r.unit?Yn(e,c,h/1852,\"nm\"):Yn(e,c,h,\"m\")}function Yn(t,e,r,n){var i,a,o,s=(i=r,(a=Math.pow(10,(\"\"+Math.floor(i)).length-1))*(o=(o=i/a)>=10?10:o>=5?5:o>=3?3:o>=2?2:o>=1?1:function(t){var e=Math.pow(10,Math.ceil(-Math.log(t)/Math.LN10));return Math.round(t*e)/e}(o))),l=s/r;\"m\"===n&&s>=1e3&&(s/=1e3,n=\"km\"),t.style.width=e*l+\"px\",t.innerHTML=s+n}Hn.prototype.getDefaultPosition=function(){return\"bottom-left\"},Hn.prototype._onMove=function(){Gn(this._map,this._container,this.options)},Hn.prototype.onAdd=function(t){return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-scale\",t.getContainer()),this._map.on(\"move\",this._onMove),this._onMove(),this._container},Hn.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"move\",this._onMove),this._map=void 0},Hn.prototype.setUnit=function(t){this.options.unit=t,Gn(this._map,this._container,this.options)};var Wn=function(e){this._fullscreen=!1,e&&e.container&&(e.container instanceof t.window.HTMLElement?this._container=e.container:t.warnOnce(\"Full screen control 'container' must be a DOM element.\")),t.bindAll([\"_onClickFullscreen\",\"_changeIcon\"],this),\"onfullscreenchange\"in t.window.document?this._fullscreenchange=\"fullscreenchange\":\"onmozfullscreenchange\"in t.window.document?this._fullscreenchange=\"mozfullscreenchange\":\"onwebkitfullscreenchange\"in t.window.document?this._fullscreenchange=\"webkitfullscreenchange\":\"onmsfullscreenchange\"in t.window.document&&(this._fullscreenchange=\"MSFullscreenChange\"),this._className=\"mapboxgl-ctrl\"};Wn.prototype.onAdd=function(e){return this._map=e,this._container||(this._container=this._map.getContainer()),this._controlContainer=r.create(\"div\",this._className+\" mapboxgl-ctrl-group\"),this._checkFullscreenSupport()?this._setupUI():(this._controlContainer.style.display=\"none\",t.warnOnce(\"This device does not support fullscreen mode.\")),this._controlContainer},Wn.prototype.onRemove=function(){r.remove(this._controlContainer),this._map=null,t.window.document.removeEventListener(this._fullscreenchange,this._changeIcon)},Wn.prototype._checkFullscreenSupport=function(){return!!(t.window.document.fullscreenEnabled||t.window.document.mozFullScreenEnabled||t.window.document.msFullscreenEnabled||t.window.document.webkitFullscreenEnabled)},Wn.prototype._setupUI=function(){(this._fullscreenButton=r.create(\"button\",this._className+\"-icon \"+this._className+\"-fullscreen\",this._controlContainer)).type=\"button\",this._updateTitle(),this._fullscreenButton.addEventListener(\"click\",this._onClickFullscreen),t.window.document.addEventListener(this._fullscreenchange,this._changeIcon)},Wn.prototype._updateTitle=function(){var t=this._isFullscreen()?\"Exit fullscreen\":\"Enter fullscreen\";this._fullscreenButton.setAttribute(\"aria-label\",t),this._fullscreenButton.title=t},Wn.prototype._isFullscreen=function(){return this._fullscreen},Wn.prototype._changeIcon=function(){(t.window.document.fullscreenElement||t.window.document.mozFullScreenElement||t.window.document.webkitFullscreenElement||t.window.document.msFullscreenElement)===this._container!==this._fullscreen&&(this._fullscreen=!this._fullscreen,this._fullscreenButton.classList.toggle(this._className+\"-shrink\"),this._fullscreenButton.classList.toggle(this._className+\"-fullscreen\"),this._updateTitle())},Wn.prototype._onClickFullscreen=function(){this._isFullscreen()?t.window.document.exitFullscreen?t.window.document.exitFullscreen():t.window.document.mozCancelFullScreen?t.window.document.mozCancelFullScreen():t.window.document.msExitFullscreen?t.window.document.msExitFullscreen():t.window.document.webkitCancelFullScreen&&t.window.document.webkitCancelFullScreen():this._container.requestFullscreen?this._container.requestFullscreen():this._container.mozRequestFullScreen?this._container.mozRequestFullScreen():this._container.msRequestFullscreen?this._container.msRequestFullscreen():this._container.webkitRequestFullscreen&&this._container.webkitRequestFullscreen()};var Xn={closeButton:!0,closeOnClick:!0,className:\"\",maxWidth:\"240px\"},Zn=function(e){function n(r){e.call(this),this.options=t.extend(Object.create(Xn),r),t.bindAll([\"_update\",\"_onClickClose\",\"remove\"],this)}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.addTo=function(e){var r=this;return this._map=e,this.options.closeOnClick&&this._map.on(\"click\",this._onClickClose),this._map.on(\"remove\",this.remove),this._update(),this._trackPointer?(this._map.on(\"mousemove\",function(t){r._update(t.point)}),this._map.on(\"mouseup\",function(t){r._update(t.point)}),this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")):this._map.on(\"move\",this._update),this.fire(new t.Event(\"open\")),this},n.prototype.isOpen=function(){return!!this._map},n.prototype.remove=function(){return this._content&&r.remove(this._content),this._container&&(r.remove(this._container),delete this._container),this._map&&(this._map.off(\"move\",this._update),this._map.off(\"click\",this._onClickClose),this._map.off(\"remove\",this.remove),this._map.off(\"mousemove\"),delete this._map),this.fire(new t.Event(\"close\")),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._map&&(this._map.on(\"move\",this._update),this._map.off(\"mousemove\"),this._container.classList.remove(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.remove(\"mapboxgl-track-pointer\")),this._trackPointer=!1,this._update(),this},n.prototype.trackPointer=function(){var t=this;return this._trackPointer=!0,this._pos=null,this._map&&(this._map.off(\"move\",this._update),this._map.on(\"mousemove\",function(e){t._update(e.point)}),this._map.on(\"drag\",function(e){t._update(e.point)}),this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")),this},n.prototype.getElement=function(){return this._container},n.prototype.setText=function(e){return this.setDOMContent(t.window.document.createTextNode(e))},n.prototype.setHTML=function(e){var r,n=t.window.document.createDocumentFragment(),i=t.window.document.createElement(\"body\");for(i.innerHTML=e;r=i.firstChild;)n.appendChild(r);return this.setDOMContent(n)},n.prototype.getMaxWidth=function(){return this._container.style.maxWidth},n.prototype.setMaxWidth=function(t){return this.options.maxWidth=t,this._update(),this},n.prototype.setDOMContent=function(t){return this._createContent(),this._content.appendChild(t),this._update(),this},n.prototype._createContent=function(){this._content&&r.remove(this._content),this._content=r.create(\"div\",\"mapboxgl-popup-content\",this._container),this.options.closeButton&&(this._closeButton=r.create(\"button\",\"mapboxgl-popup-close-button\",this._content),this._closeButton.type=\"button\",this._closeButton.setAttribute(\"aria-label\",\"Close popup\"),this._closeButton.innerHTML=\"&#215;\",this._closeButton.addEventListener(\"click\",this._onClickClose))},n.prototype._update=function(e){var n=this,i=this._lngLat||this._trackPointer;if(this._map&&i&&this._content&&(this._container||(this._container=r.create(\"div\",\"mapboxgl-popup\",this._map.getContainer()),this._tip=r.create(\"div\",\"mapboxgl-popup-tip\",this._container),this._container.appendChild(this._content),this.options.className&&this.options.className.split(\" \").forEach(function(t){return n._container.classList.add(t)})),this.options.maxWidth&&this._container.style.maxWidth!==this.options.maxWidth&&(this._container.style.maxWidth=this.options.maxWidth),this._map.transform.renderWorldCopies&&!this._trackPointer&&(this._lngLat=Rn(this._lngLat,this._pos,this._map.transform)),!this._trackPointer||e)){var a=this._pos=this._trackPointer&&e?e:this._map.project(this._lngLat),o=this.options.anchor,s=function e(r){if(r){if(\"number\"==typeof r){var n=Math.round(Math.sqrt(.5*Math.pow(r,2)));return{center:new t.Point(0,0),top:new t.Point(0,r),\"top-left\":new t.Point(n,n),\"top-right\":new t.Point(-n,n),bottom:new t.Point(0,-r),\"bottom-left\":new t.Point(n,-n),\"bottom-right\":new t.Point(-n,-n),left:new t.Point(r,0),right:new t.Point(-r,0)}}if(r instanceof t.Point||Array.isArray(r)){var i=t.Point.convert(r);return{center:i,top:i,\"top-left\":i,\"top-right\":i,bottom:i,\"bottom-left\":i,\"bottom-right\":i,left:i,right:i}}return{center:t.Point.convert(r.center||[0,0]),top:t.Point.convert(r.top||[0,0]),\"top-left\":t.Point.convert(r[\"top-left\"]||[0,0]),\"top-right\":t.Point.convert(r[\"top-right\"]||[0,0]),bottom:t.Point.convert(r.bottom||[0,0]),\"bottom-left\":t.Point.convert(r[\"bottom-left\"]||[0,0]),\"bottom-right\":t.Point.convert(r[\"bottom-right\"]||[0,0]),left:t.Point.convert(r.left||[0,0]),right:t.Point.convert(r.right||[0,0])}}return e(new t.Point(0,0))}(this.options.offset);if(!o){var l,c=this._container.offsetWidth,u=this._container.offsetHeight;l=a.y+s.bottom.y<u?[\"top\"]:a.y>this._map.transform.height-u?[\"bottom\"]:[],a.x<c/2?l.push(\"left\"):a.x>this._map.transform.width-c/2&&l.push(\"right\"),o=0===l.length?\"bottom\":l.join(\"-\")}var h=a.add(s[o]).round();r.setTransform(this._container,Fn[o]+\" translate(\"+h.x+\"px,\"+h.y+\"px)\"),Bn(this._container,o,\"popup\")}},n.prototype._onClickClose=function(){this.remove()},n}(t.Evented),Jn={version:t.version,supported:e,setRTLTextPlugin:t.setRTLTextPlugin,Map:On,NavigationControl:Dn,GeolocateControl:Vn,AttributionControl:Mn,ScaleControl:Hn,FullscreenControl:Wn,Popup:Zn,Marker:jn,Style:De,LngLat:t.LngLat,LngLatBounds:t.LngLatBounds,Point:t.Point,MercatorCoordinate:t.MercatorCoordinate,Evented:t.Evented,config:t.config,get accessToken(){return t.config.ACCESS_TOKEN},set accessToken(e){t.config.ACCESS_TOKEN=e},get baseApiUrl(){return t.config.API_URL},set baseApiUrl(e){t.config.API_URL=e},get workerCount(){return zt.workerCount},set workerCount(t){zt.workerCount=t},get maxParallelImageRequests(){return t.config.MAX_PARALLEL_IMAGE_REQUESTS},set maxParallelImageRequests(e){t.config.MAX_PARALLEL_IMAGE_REQUESTS=e},clearStorage:function(e){t.clearTileCache(e)},workerUrl:\"\"};return Jn}),r},\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=i():(n=n||self).mapboxgl=i()},{}],427:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1<<t+1,r=new Array(e),n=0;n<e;++n)r[n]=a(t,n);return r};var n=t(\"convex-hull\");function i(t,e,r){for(var n=new Array(t),i=0;i<t;++i)n[i]=0,i===e&&(n[i]+=.5),i===r&&(n[i]+=.5);return n}function a(t,e){if(0===e||e===(1<<t+1)-1)return[];for(var r=[],a=[],o=0;o<=t;++o)if(e&1<<o){r.push(i(t,o-1,o-1)),a.push(null);for(var s=0;s<=t;++s)~e&1<<s&&(r.push(i(t,o-1,s-1)),a.push([o,s]))}var l=n(r),c=[];t:for(o=0;o<l.length;++o){var u=l[o],h=[];for(s=0;s<u.length;++s){if(!a[u[s]])continue t;h.push(a[u[s]].slice())}c.push(h)}return c}},{\"convex-hull\":130}],428:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"gl-mat4/create\"),a=t(\"gl-mat4/clone\"),o=t(\"gl-mat4/determinant\"),s=t(\"gl-mat4/invert\"),l=t(\"gl-mat4/transpose\"),c={length:t(\"gl-vec3/length\"),normalize:t(\"gl-vec3/normalize\"),dot:t(\"gl-vec3/dot\"),cross:t(\"gl-vec3/cross\")},u=i(),h=i(),f=[0,0,0,0],p=[[0,0,0],[0,0,0],[0,0,0]],d=[0,0,0];function g(t,e,r,n,i){t[0]=e[0]*n+r[0]*i,t[1]=e[1]*n+r[1]*i,t[2]=e[2]*n+r[2]*i}e.exports=function(t,e,r,i,v,m){if(e||(e=[0,0,0]),r||(r=[0,0,0]),i||(i=[0,0,0]),v||(v=[0,0,0,1]),m||(m=[0,0,0,1]),!n(u,t))return!1;if(a(h,u),h[3]=0,h[7]=0,h[11]=0,h[15]=1,Math.abs(o(h)<1e-8))return!1;var y,x,b,_,w,k,T,A=u[3],M=u[7],S=u[11],E=u[12],C=u[13],L=u[14],P=u[15];if(0!==A||0!==M||0!==S){if(f[0]=A,f[1]=M,f[2]=S,f[3]=P,!s(h,h))return!1;l(h,h),y=v,b=h,_=(x=f)[0],w=x[1],k=x[2],T=x[3],y[0]=b[0]*_+b[4]*w+b[8]*k+b[12]*T,y[1]=b[1]*_+b[5]*w+b[9]*k+b[13]*T,y[2]=b[2]*_+b[6]*w+b[10]*k+b[14]*T,y[3]=b[3]*_+b[7]*w+b[11]*k+b[15]*T}else v[0]=v[1]=v[2]=0,v[3]=1;if(e[0]=E,e[1]=C,e[2]=L,function(t,e){t[0][0]=e[0],t[0][1]=e[1],t[0][2]=e[2],t[1][0]=e[4],t[1][1]=e[5],t[1][2]=e[6],t[2][0]=e[8],t[2][1]=e[9],t[2][2]=e[10]}(p,u),r[0]=c.length(p[0]),c.normalize(p[0],p[0]),i[0]=c.dot(p[0],p[1]),g(p[1],p[1],p[0],1,-i[0]),r[1]=c.length(p[1]),c.normalize(p[1],p[1]),i[0]/=r[1],i[1]=c.dot(p[0],p[2]),g(p[2],p[2],p[0],1,-i[1]),i[2]=c.dot(p[1],p[2]),g(p[2],p[2],p[1],1,-i[2]),r[2]=c.length(p[2]),c.normalize(p[2],p[2]),i[1]/=r[2],i[2]/=r[2],c.cross(d,p[1],p[2]),c.dot(p[0],d)<0)for(var O=0;O<3;O++)r[O]*=-1,p[O][0]*=-1,p[O][1]*=-1,p[O][2]*=-1;return m[0]=.5*Math.sqrt(Math.max(1+p[0][0]-p[1][1]-p[2][2],0)),m[1]=.5*Math.sqrt(Math.max(1-p[0][0]+p[1][1]-p[2][2],0)),m[2]=.5*Math.sqrt(Math.max(1-p[0][0]-p[1][1]+p[2][2],0)),m[3]=.5*Math.sqrt(Math.max(1+p[0][0]+p[1][1]+p[2][2],0)),p[2][1]>p[1][2]&&(m[0]=-m[0]),p[0][2]>p[2][0]&&(m[1]=-m[1]),p[1][0]>p[0][1]&&(m[2]=-m[2]),!0}},{\"./normalize\":429,\"gl-mat4/clone\":259,\"gl-mat4/create\":260,\"gl-mat4/determinant\":261,\"gl-mat4/invert\":265,\"gl-mat4/transpose\":276,\"gl-vec3/cross\":334,\"gl-vec3/dot\":339,\"gl-vec3/length\":349,\"gl-vec3/normalize\":356}],429:[function(t,e,r){e.exports=function(t,e){var r=e[15];if(0===r)return!1;for(var n=1/r,i=0;i<16;i++)t[i]=e[i]*n;return!0}},{}],430:[function(t,e,r){var n=t(\"gl-vec3/lerp\"),i=t(\"mat4-recompose\"),a=t(\"mat4-decompose\"),o=t(\"gl-mat4/determinant\"),s=t(\"quat-slerp\"),l=h(),c=h(),u=h();function h(){return{translate:f(),scale:f(1),skew:f(),perspective:[0,0,0,1],quaternion:[0,0,0,1]}}function f(t){return[t||0,t||0,t||0]}e.exports=function(t,e,r,h){if(0===o(e)||0===o(r))return!1;var f=a(e,l.translate,l.scale,l.skew,l.perspective,l.quaternion),p=a(r,c.translate,c.scale,c.skew,c.perspective,c.quaternion);return!(!f||!p||(n(u.translate,l.translate,c.translate,h),n(u.skew,l.skew,c.skew,h),n(u.scale,l.scale,c.scale,h),n(u.perspective,l.perspective,c.perspective,h),s(u.quaternion,l.quaternion,c.quaternion,h),i(t,u.translate,u.scale,u.skew,u.perspective,u.quaternion),0))}},{\"gl-mat4/determinant\":261,\"gl-vec3/lerp\":350,\"mat4-decompose\":428,\"mat4-recompose\":431,\"quat-slerp\":483}],431:[function(t,e,r){var n={identity:t(\"gl-mat4/identity\"),translate:t(\"gl-mat4/translate\"),multiply:t(\"gl-mat4/multiply\"),create:t(\"gl-mat4/create\"),scale:t(\"gl-mat4/scale\"),fromRotationTranslation:t(\"gl-mat4/fromRotationTranslation\")},i=(n.create(),n.create());e.exports=function(t,e,r,a,o,s){return n.identity(t),n.fromRotationTranslation(t,s,e),t[3]=o[0],t[7]=o[1],t[11]=o[2],t[15]=o[3],n.identity(i),0!==a[2]&&(i[9]=a[2],n.multiply(t,t,i)),0!==a[1]&&(i[9]=0,i[8]=a[1],n.multiply(t,t,i)),0!==a[0]&&(i[8]=0,i[4]=a[0],n.multiply(t,t,i)),n.scale(t,t,r),t}},{\"gl-mat4/create\":260,\"gl-mat4/fromRotationTranslation\":263,\"gl-mat4/identity\":264,\"gl-mat4/multiply\":267,\"gl-mat4/scale\":274,\"gl-mat4/translate\":275}],432:[function(t,e,r){\"use strict\";e.exports=Math.log2||function(t){return Math.log(t)*Math.LOG2E}},{}],433:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"mat4-interpolate\"),a=t(\"gl-mat4/invert\"),o=t(\"gl-mat4/rotateX\"),s=t(\"gl-mat4/rotateY\"),l=t(\"gl-mat4/rotateZ\"),c=t(\"gl-mat4/lookAt\"),u=t(\"gl-mat4/translate\"),h=(t(\"gl-mat4/scale\"),t(\"gl-vec3/normalize\")),f=[0,0,0];function p(t){this._components=t.slice(),this._time=[0],this.prevMatrix=t.slice(),this.nextMatrix=t.slice(),this.computedMatrix=t.slice(),this.computedInverse=t.slice(),this.computedEye=[0,0,0],this.computedUp=[0,0,0],this.computedCenter=[0,0,0],this.computedRadius=[0],this._limits=[-1/0,1/0]}e.exports=function(t){return new p((t=t||{}).matrix||[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1])};var d=p.prototype;d.recalcMatrix=function(t){var e=this._time,r=n.le(e,t),o=this.computedMatrix;if(!(r<0)){var s=this._components;if(r===e.length-1)for(var l=16*r,c=0;c<16;++c)o[c]=s[l++];else{var u=e[r+1]-e[r],f=(l=16*r,this.prevMatrix),p=!0;for(c=0;c<16;++c)f[c]=s[l++];var d=this.nextMatrix;for(c=0;c<16;++c)d[c]=s[l++],p=p&&f[c]===d[c];if(u<1e-6||p)for(c=0;c<16;++c)o[c]=f[c];else i(o,f,d,(t-e[r])/u)}var g=this.computedUp;g[0]=o[1],g[1]=o[5],g[2]=o[9],h(g,g);var v=this.computedInverse;a(v,o);var m=this.computedEye,y=v[15];m[0]=v[12]/y,m[1]=v[13]/y,m[2]=v[14]/y;var x=this.computedCenter,b=Math.exp(this.computedRadius[0]);for(c=0;c<3;++c)x[c]=m[c]-o[2+4*c]*b}},d.idle=function(t){if(!(t<this.lastT())){for(var e=this._components,r=e.length-16,n=0;n<16;++n)e.push(e[r++]);this._time.push(t)}},d.flush=function(t){var e=n.gt(this._time,t)-2;e<0||(this._time.splice(0,e),this._components.splice(0,16*e))},d.lastT=function(){return this._time[this._time.length-1]},d.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||f,n=n||this.computedUp,this.setMatrix(t,c(this.computedMatrix,e,r,n));for(var i=0,a=0;a<3;++a)i+=Math.pow(r[a]-e[a],2);i=Math.log(Math.sqrt(i)),this.computedRadius[0]=i},d.rotate=function(t,e,r,n){this.recalcMatrix(t);var i=this.computedInverse;e&&s(i,i,e),r&&o(i,i,r),n&&l(i,i,n),this.setMatrix(t,a(this.computedMatrix,i))};var g=[0,0,0];d.pan=function(t,e,r,n){g[0]=-(e||0),g[1]=-(r||0),g[2]=-(n||0),this.recalcMatrix(t);var i=this.computedInverse;u(i,i,g),this.setMatrix(t,a(i,i))},d.translate=function(t,e,r,n){g[0]=e||0,g[1]=r||0,g[2]=n||0,this.recalcMatrix(t);var i=this.computedMatrix;u(i,i,g),this.setMatrix(t,i)},d.setMatrix=function(t,e){if(!(t<this.lastT())){this._time.push(t);for(var r=0;r<16;++r)this._components.push(e[r])}},d.setDistance=function(t,e){this.computedRadius[0]=e},d.setDistanceLimits=function(t,e){var r=this._limits;r[0]=t,r[1]=e},d.getDistanceLimits=function(t){var e=this._limits;return t?(t[0]=e[0],t[1]=e[1],t):e}},{\"binary-search-bounds\":91,\"gl-mat4/invert\":265,\"gl-mat4/lookAt\":266,\"gl-mat4/rotateX\":271,\"gl-mat4/rotateY\":272,\"gl-mat4/rotateZ\":273,\"gl-mat4/scale\":274,\"gl-mat4/translate\":275,\"gl-vec3/normalize\":356,\"mat4-interpolate\":430}],434:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<3){for(var r=new Array(e),i=0;i<e;++i)r[i]=i;return 2===e&&t[0][0]===t[1][0]&&t[0][1]===t[1][1]?[0]:r}for(var a=new Array(e),i=0;i<e;++i)a[i]=i;a.sort(function(e,r){var n=t[e][0]-t[r][0];return n||t[e][1]-t[r][1]});for(var o=[a[0],a[1]],s=[a[0],a[1]],i=2;i<e;++i){for(var l=a[i],c=t[l],u=o.length;u>1&&n(t[o[u-2]],t[o[u-1]],c)<=0;)u-=1,o.pop();for(o.push(l),u=s.length;u>1&&n(t[s[u-2]],t[s[u-1]],c)>=0;)u-=1,s.pop();s.push(l)}for(var r=new Array(s.length+o.length-2),h=0,i=0,f=o.length;i<f;++i)r[h++]=o[i];for(var p=s.length-2;p>0;--p)r[h++]=s[p];return r};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":510}],435:[function(t,e,r){\"use strict\";e.exports=function(t,e){e||(e=t,t=window);var r=0,i=0,a=0,o={shift:!1,alt:!1,control:!1,meta:!1},s=!1;function l(t){var e=!1;return\"altKey\"in t&&(e=e||t.altKey!==o.alt,o.alt=!!t.altKey),\"shiftKey\"in t&&(e=e||t.shiftKey!==o.shift,o.shift=!!t.shiftKey),\"ctrlKey\"in t&&(e=e||t.ctrlKey!==o.control,o.control=!!t.ctrlKey),\"metaKey\"in t&&(e=e||t.metaKey!==o.meta,o.meta=!!t.metaKey),e}function c(t,s){var c=n.x(s),u=n.y(s);\"buttons\"in s&&(t=0|s.buttons),(t!==r||c!==i||u!==a||l(s))&&(r=0|t,i=c||0,a=u||0,e&&e(r,i,a,o))}function u(t){c(0,t)}function h(){(r||i||a||o.shift||o.alt||o.meta||o.control)&&(i=a=0,r=0,o.shift=o.alt=o.control=o.meta=!1,e&&e(0,0,0,o))}function f(t){l(t)&&e&&e(r,i,a,o)}function p(t){0===n.buttons(t)?c(0,t):c(r,t)}function d(t){c(r|n.buttons(t),t)}function g(t){c(r&~n.buttons(t),t)}function v(){s||(s=!0,t.addEventListener(\"mousemove\",p),t.addEventListener(\"mousedown\",d),t.addEventListener(\"mouseup\",g),t.addEventListener(\"mouseleave\",u),t.addEventListener(\"mouseenter\",u),t.addEventListener(\"mouseout\",u),t.addEventListener(\"mouseover\",u),t.addEventListener(\"blur\",h),t.addEventListener(\"keyup\",f),t.addEventListener(\"keydown\",f),t.addEventListener(\"keypress\",f),t!==window&&(window.addEventListener(\"blur\",h),window.addEventListener(\"keyup\",f),window.addEventListener(\"keydown\",f),window.addEventListener(\"keypress\",f)))}v();var m={element:t};return Object.defineProperties(m,{enabled:{get:function(){return s},set:function(e){e?v():s&&(s=!1,t.removeEventListener(\"mousemove\",p),t.removeEventListener(\"mousedown\",d),t.removeEventListener(\"mouseup\",g),t.removeEventListener(\"mouseleave\",u),t.removeEventListener(\"mouseenter\",u),t.removeEventListener(\"mouseout\",u),t.removeEventListener(\"mouseover\",u),t.removeEventListener(\"blur\",h),t.removeEventListener(\"keyup\",f),t.removeEventListener(\"keydown\",f),t.removeEventListener(\"keypress\",f),t!==window&&(window.removeEventListener(\"blur\",h),window.removeEventListener(\"keyup\",f),window.removeEventListener(\"keydown\",f),window.removeEventListener(\"keypress\",f)))},enumerable:!0},buttons:{get:function(){return r},enumerable:!0},x:{get:function(){return i},enumerable:!0},y:{get:function(){return a},enumerable:!0},mods:{get:function(){return o},enumerable:!0}}),m};var n=t(\"mouse-event\")},{\"mouse-event\":437}],436:[function(t,e,r){var n={left:0,top:0};e.exports=function(t,e,r){e=e||t.currentTarget||t.srcElement,Array.isArray(r)||(r=[0,0]);var i=t.clientX||0,a=t.clientY||0,o=(s=e,s===window||s===document||s===document.body?n:s.getBoundingClientRect());var s;return r[0]=i-o.left,r[1]=a-o.top,r}},{}],437:[function(t,e,r){\"use strict\";function n(t){return t.target||t.srcElement||window}r.buttons=function(t){if(\"object\"==typeof t){if(\"buttons\"in t)return t.buttons;if(\"which\"in t){if(2===(e=t.which))return 4;if(3===e)return 2;if(e>0)return 1<<e-1}else if(\"button\"in t){var e;if(1===(e=t.button))return 4;if(2===e)return 2;if(e>=0)return 1<<e}}return 0},r.element=n,r.x=function(t){if(\"object\"==typeof t){if(\"offsetX\"in t)return t.offsetX;var e=n(t).getBoundingClientRect();return t.clientX-e.left}return 0},r.y=function(t){if(\"object\"==typeof t){if(\"offsetY\"in t)return t.offsetY;var e=n(t).getBoundingClientRect();return t.clientY-e.top}return 0}},{}],438:[function(t,e,r){\"use strict\";var n=t(\"to-px\");e.exports=function(t,e,r){\"function\"==typeof t&&(r=!!e,e=t,t=window);var i=n(\"ex\",t),a=function(t){r&&t.preventDefault();var n=t.deltaX||0,a=t.deltaY||0,o=t.deltaZ||0,s=t.deltaMode,l=1;switch(s){case 1:l=i;break;case 2:l=window.innerHeight}if(a*=l,o*=l,(n*=l)||a||o)return e(n,a,o,t)};return t.addEventListener(\"wheel\",a),a}},{\"to-px\":539}],439:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\");function i(t){return\"a\"+t}function a(t){return\"d\"+t}function o(t,e){return\"c\"+t+\"_\"+e}function s(t){return\"s\"+t}function l(t,e){return\"t\"+t+\"_\"+e}function c(t){return\"o\"+t}function u(t){return\"x\"+t}function h(t){return\"p\"+t}function f(t,e){return\"d\"+t+\"_\"+e}function p(t){return\"i\"+t}function d(t,e){return\"u\"+t+\"_\"+e}function g(t){return\"b\"+t}function v(t){return\"y\"+t}function m(t){return\"e\"+t}function y(t){return\"v\"+t}e.exports=function(t){function e(t){throw new Error(\"ndarray-extract-contour: \"+t)}\"object\"!=typeof t&&e(\"Must specify arguments\");var r=t.order;Array.isArray(r)||e(\"Must specify order\");var M=t.arrayArguments||1;M<1&&e(\"Must have at least one array argument\");var S=t.scalarArguments||0;S<0&&e(\"Scalar arg count must be > 0\");\"function\"!=typeof t.vertex&&e(\"Must specify vertex creation function\");\"function\"!=typeof t.cell&&e(\"Must specify cell creation function\");\"function\"!=typeof t.phase&&e(\"Must specify phase function\");for(var E=t.getters||[],C=new Array(M),L=0;L<M;++L)E.indexOf(L)>=0?C[L]=!0:C[L]=!1;return function(t,e,r,M,S,E){var C=E.length,L=S.length;if(L<2)throw new Error(\"ndarray-extract-contour: Dimension must be at least 2\");for(var P=\"extractContour\"+S.join(\"_\"),O=[],z=[],I=[],D=0;D<C;++D)I.push(i(D));for(var D=0;D<M;++D)I.push(u(D));for(var D=0;D<L;++D)z.push(s(D)+\"=\"+i(0)+\".shape[\"+D+\"]|0\");for(var D=0;D<C;++D){z.push(a(D)+\"=\"+i(D)+\".data\",c(D)+\"=\"+i(D)+\".offset|0\");for(var R=0;R<L;++R)z.push(l(D,R)+\"=\"+i(D)+\".stride[\"+R+\"]|0\")}for(var D=0;D<C;++D){z.push(h(D)+\"=\"+c(D)),z.push(o(D,0));for(var R=1;R<1<<L;++R){for(var F=[],B=0;B<L;++B)R&1<<B&&F.push(\"-\"+l(D,B));z.push(f(D,R)+\"=(\"+F.join(\"\")+\")|0\"),z.push(o(D,R)+\"=0\")}}for(var D=0;D<C;++D)for(var R=0;R<L;++R){var N=[l(D,S[R])];R>0&&N.push(l(D,S[R-1])+\"*\"+s(S[R-1])),z.push(d(D,S[R])+\"=(\"+N.join(\"-\")+\")|0\")}for(var D=0;D<L;++D)z.push(p(D)+\"=0\");z.push(_+\"=0\");for(var j=[\"2\"],D=L-2;D>=0;--D)j.push(s(S[D]));z.push(w+\"=(\"+j.join(\"*\")+\")|0\",b+\"=mallocUint32(\"+w+\")\",x+\"=mallocUint32(\"+w+\")\",k+\"=0\"),z.push(g(0)+\"=0\");for(var R=1;R<1<<L;++R){for(var U=[],V=[],B=0;B<L;++B)R&1<<B&&(0===V.length?U.push(\"1\"):U.unshift(V.join(\"*\"))),V.push(s(S[B]));var q=\"\";U[0].indexOf(s(S[L-2]))<0&&(q=\"-\");var H=A(L,R,S);z.push(m(H)+\"=(-\"+U.join(\"-\")+\")|0\",v(H)+\"=(\"+q+U.join(\"-\")+\")|0\",g(H)+\"=0\")}function G(t,e){O.push(\"for(\",p(S[t]),\"=\",e,\";\",p(S[t]),\"<\",s(S[t]),\";\",\"++\",p(S[t]),\"){\")}function Y(t){for(var e=0;e<C;++e)O.push(h(e),\"+=\",d(e,S[t]),\";\");O.push(\"}\")}function W(){for(var t=1;t<1<<L;++t)O.push(T,\"=\",m(t),\";\",m(t),\"=\",v(t),\";\",v(t),\"=\",T,\";\")}z.push(y(0)+\"=0\",T+\"=0\"),function t(e,r){if(e<0)return void function(t){for(var e=0;e<C;++e)E[e]?O.push(o(e,0),\"=\",a(e),\".get(\",h(e),\");\"):O.push(o(e,0),\"=\",a(e),\"[\",h(e),\"];\");for(var r=[],e=0;e<C;++e)r.push(o(e,0));for(var e=0;e<M;++e)r.push(u(e));O.push(g(0),\"=\",b,\"[\",k,\"]=phase(\",r.join(),\");\");for(var n=1;n<1<<L;++n)O.push(g(n),\"=\",b,\"[\",k,\"+\",m(n),\"];\");for(var i=[],n=1;n<1<<L;++n)i.push(\"(\"+g(0)+\"!==\"+g(n)+\")\");O.push(\"if(\",i.join(\"||\"),\"){\");for(var s=[],e=0;e<L;++e)s.push(p(e));for(var e=0;e<C;++e){s.push(o(e,0));for(var n=1;n<1<<L;++n)E[e]?O.push(o(e,n),\"=\",a(e),\".get(\",h(e),\"+\",f(e,n),\");\"):O.push(o(e,n),\"=\",a(e),\"[\",h(e),\"+\",f(e,n),\"];\"),s.push(o(e,n))}for(var e=0;e<1<<L;++e)s.push(g(e));for(var e=0;e<M;++e)s.push(u(e));O.push(\"vertex(\",s.join(),\");\",y(0),\"=\",x,\"[\",k,\"]=\",_,\"++;\");for(var l=(1<<L)-1,c=g(l),n=0;n<L;++n)if(0==(t&~(1<<n))){for(var d=l^1<<n,v=g(d),w=[],T=d;T>0;T=T-1&d)w.push(x+\"[\"+k+\"+\"+m(T)+\"]\");w.push(y(0));for(var T=0;T<C;++T)1&n?w.push(o(T,l),o(T,d)):w.push(o(T,d),o(T,l));1&n?w.push(c,v):w.push(v,c);for(var T=0;T<M;++T)w.push(u(T));O.push(\"if(\",c,\"!==\",v,\"){\",\"face(\",w.join(),\")}\")}O.push(\"}\",k,\"+=1;\")}(r);!function(t){for(var e=t-1;e>=0;--e)G(e,0);for(var r=[],e=0;e<C;++e)E[e]?r.push(a(e)+\".get(\"+h(e)+\")\"):r.push(a(e)+\"[\"+h(e)+\"]\");for(var e=0;e<M;++e)r.push(u(e));O.push(b,\"[\",k,\"++]=phase(\",r.join(),\");\");for(var e=0;e<t;++e)Y(e);for(var n=0;n<C;++n)O.push(h(n),\"+=\",d(n,S[t]),\";\")}(e);O.push(\"if(\",s(S[e]),\">0){\",p(S[e]),\"=1;\");t(e-1,r|1<<S[e]);for(var n=0;n<C;++n)O.push(h(n),\"+=\",d(n,S[e]),\";\");e===L-1&&(O.push(k,\"=0;\"),W());G(e,2);t(e-1,r);e===L-1&&(O.push(\"if(\",p(S[L-1]),\"&1){\",k,\"=0;}\"),W());Y(e);O.push(\"}\")}(L-1,0),O.push(\"freeUint32(\",x,\");freeUint32(\",b,\");\");var X=[\"'use strict';\",\"function \",P,\"(\",I.join(),\"){\",\"var \",z.join(),\";\",O.join(\"\"),\"}\",\"return \",P].join(\"\");return new Function(\"vertex\",\"face\",\"phase\",\"mallocUint32\",\"freeUint32\",X)(t,e,r,n.mallocUint32,n.freeUint32)}(t.vertex,t.cell,t.phase,S,r,C)};var x=\"V\",b=\"P\",_=\"N\",w=\"Q\",k=\"X\",T=\"T\";function A(t,e,r){for(var n=0,i=0;i<t;++i)e&1<<i&&(n|=1<<r[i]);return n}},{\"typedarray-pool\":545}],440:[function(t,e,r){\"use strict\";var n=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{_inline_1_arg1_=_inline_1_arg2_.apply(void 0,_inline_1_arg0_)}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"cwise\",blockSize:64});e.exports=function(t,e){return n(t,e),t}},{\"cwise/lib/wrapper\":149}],441:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(Array.isArray(r)){if(r.length!==e.dimension)throw new Error(\"ndarray-gradient: invalid boundary conditions\")}else r=n(e.dimension,\"string\"==typeof r?r:\"clamp\");if(t.dimension!==e.dimension+1)throw new Error(\"ndarray-gradient: output dimension must be +1 input dimension\");if(t.shape[e.dimension]!==e.dimension)throw new Error(\"ndarray-gradient: output shape must match input shape\");for(var i=0;i<e.dimension;++i)if(t.shape[i]!==e.shape[i])throw new Error(\"ndarray-gradient: shape mismatch\");if(0===e.size)return t;if(e.dimension<=0)return t.set(0),t;return function(t){var e=t.join();if(m=o[e])return m;var r=t.length,n=[\"function gradient(dst,src){var s=src.shape.slice();\"];function i(e){for(var i=r-e.length,a=[],o=[],s=[],l=0;l<r;++l)e.indexOf(l+1)>=0?s.push(\"0\"):e.indexOf(-(l+1))>=0?s.push(\"s[\"+l+\"]-1\"):(s.push(\"-1\"),a.push(\"1\"),o.push(\"s[\"+l+\"]-2\"));var c=\".lo(\"+a.join()+\").hi(\"+o.join()+\")\";if(0===a.length&&(c=\"\"),i>0){n.push(\"if(1\");for(var l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\"&&s[\",l,\"]>2\");n.push(\"){grad\",i,\"(src.pick(\",s.join(),\")\",c);for(var l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\",dst.pick(\",s.join(),\",\",l,\")\",c);n.push(\");\")}for(var l=0;l<e.length;++l){var u=Math.abs(e[l])-1,h=\"dst.pick(\"+s.join()+\",\"+u+\")\"+c;switch(t[u]){case\"clamp\":var f=s.slice(),p=s.slice();e[l]<0?f[u]=\"s[\"+u+\"]-2\":p[u]=\"1\",0===i?n.push(\"if(s[\",u,\"]>1){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",f.join(),\")-src.get(\",p.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>1){diff(\",h,\",src.pick(\",f.join(),\")\",c,\",src.pick(\",p.join(),\")\",c,\");}else{zero(\",h,\");};\");break;case\"mirror\":0===i?n.push(\"dst.set(\",s.join(),\",\",u,\",0);\"):n.push(\"zero(\",h,\");\");break;case\"wrap\":var d=s.slice(),g=s.slice();e[l]<0?(d[u]=\"s[\"+u+\"]-2\",g[u]=\"0\"):(d[u]=\"s[\"+u+\"]-1\",g[u]=\"1\"),0===i?n.push(\"if(s[\",u,\"]>2){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",d.join(),\")-src.get(\",g.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>2){diff(\",h,\",src.pick(\",d.join(),\")\",c,\",src.pick(\",g.join(),\")\",c,\");}else{zero(\",h,\");};\");break;default:throw new Error(\"ndarray-gradient: Invalid boundary condition\")}}i>0&&n.push(\"};\")}for(var s=0;s<1<<r;++s){for(var h=[],f=0;f<r;++f)s&1<<f&&h.push(f+1);for(var p=0;p<1<<h.length;++p){for(var d=h.slice(),f=0;f<h.length;++f)p&1<<f&&(d[f]=-d[f]);i(d)}}n.push(\"return dst;};return gradient\");for(var g=[\"diff\",\"zero\"],v=[l,c],s=1;s<=r;++s)g.push(\"grad\"+s),v.push(u(s));g.push(n.join(\"\"));var m=Function.apply(void 0,g).apply(void 0,v);return a[e]=m,m}(r)(t,e)};var n=t(\"dup\"),i=t(\"cwise-compiler\"),a={},o={},s={body:\"\",args:[],thisVars:[],localVars:[]},l=i({args:[\"array\",\"array\",\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1},{name:\"left\",lvalue:!1,rvalue:!0,count:1},{name:\"right\",lvalue:!1,rvalue:!0,count:1}],body:\"out=0.5*(left-right)\",thisVars:[],localVars:[]},funcName:\"cdiff\"}),c=i({args:[\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1}],body:\"out=0\",thisVars:[],localVars:[]},funcName:\"zero\"});function u(t){if(t in a)return a[t];for(var e=[],r=0;r<t;++r)e.push(\"out\",r,\"s=0.5*(inp\",r,\"l-inp\",r,\"r);\");var o=[\"array\"],l=[\"junk\"];for(r=0;r<t;++r){o.push(\"array\"),l.push(\"out\"+r+\"s\");var c=n(t);c[r]=-1,o.push({array:0,offset:c.slice()}),c[r]=1,o.push({array:0,offset:c.slice()}),l.push(\"inp\"+r+\"l\",\"inp\"+r+\"r\")}return a[t]=i({args:o,pre:s,post:s,body:{body:e.join(\"\"),args:l.map(function(t){return{name:t,lvalue:0===t.indexOf(\"out\"),rvalue:0===t.indexOf(\"inp\"),count:\"junk\"!==t|0}}),thisVars:[],localVars:[]},funcName:\"fdTemplate\"+t})}},{\"cwise-compiler\":146,dup:170}],442:[function(t,e,r){\"use strict\";var n=t(\"ndarray-warp\"),i=t(\"gl-matrix-invert\");e.exports=function(t,e,r){var a=e.dimension,o=i([],r);return n(t,e,function(t,e){for(var r=0;r<a;++r){t[r]=o[(a+1)*a+r];for(var n=0;n<a;++n)t[r]+=o[(a+1)*n+r]*e[n]}var i=o[(a+1)*(a+1)-1];for(n=0;n<a;++n)i+=o[(a+1)*n+a]*e[n];var s=1/i;for(r=0;r<a;++r)t[r]*=s;return t}),t}},{\"gl-matrix-invert\":277,\"ndarray-warp\":449}],443:[function(t,e,r){\"use strict\";function n(t,e){var r=Math.floor(e),n=e-r,i=0<=r&&r<t.shape[0],a=0<=r+1&&r+1<t.shape[0];return(1-n)*(i?+t.get(r):0)+n*(a?+t.get(r+1):0)}function i(t,e,r){var n=Math.floor(e),i=e-n,a=0<=n&&n<t.shape[0],o=0<=n+1&&n+1<t.shape[0],s=Math.floor(r),l=r-s,c=0<=s&&s<t.shape[1],u=0<=s+1&&s+1<t.shape[1],h=a&&c?t.get(n,s):0,f=a&&u?t.get(n,s+1):0;return(1-l)*((1-i)*h+i*(o&&c?t.get(n+1,s):0))+l*((1-i)*f+i*(o&&u?t.get(n+1,s+1):0))}function a(t,e,r,n){var i=Math.floor(e),a=e-i,o=0<=i&&i<t.shape[0],s=0<=i+1&&i+1<t.shape[0],l=Math.floor(r),c=r-l,u=0<=l&&l<t.shape[1],h=0<=l+1&&l+1<t.shape[1],f=Math.floor(n),p=n-f,d=0<=f&&f<t.shape[2],g=0<=f+1&&f+1<t.shape[2],v=o&&u&&d?t.get(i,l,f):0,m=o&&h&&d?t.get(i,l+1,f):0,y=s&&u&&d?t.get(i+1,l,f):0,x=s&&h&&d?t.get(i+1,l+1,f):0,b=o&&u&&g?t.get(i,l,f+1):0,_=o&&h&&g?t.get(i,l+1,f+1):0;return(1-p)*((1-c)*((1-a)*v+a*y)+c*((1-a)*m+a*x))+p*((1-c)*((1-a)*b+a*(s&&u&&g?t.get(i+1,l,f+1):0))+c*((1-a)*_+a*(s&&h&&g?t.get(i+1,l+1,f+1):0)))}e.exports=function(t,e,r,o){switch(t.shape.length){case 0:return 0;case 1:return n(t,e);case 2:return i(t,e,r);case 3:return a(t,e,r,o);default:return function(t){var e,r,n=0|t.shape.length,i=new Array(n),a=new Array(n),o=new Array(n),s=new Array(n);for(e=0;e<n;++e)r=+arguments[e+1],i[e]=Math.floor(r),a[e]=r-i[e],o[e]=0<=i[e]&&i[e]<t.shape[e],s[e]=0<=i[e]+1&&i[e]+1<t.shape[e];var l,c,u,h=0;t:for(e=0;e<1<<n;++e){for(c=1,u=t.offset,l=0;l<n;++l)if(e&1<<l){if(!s[l])continue t;c*=a[l],u+=t.stride[l]*(i[l]+1)}else{if(!o[l])continue t;c*=1-a[l],u+=t.stride[l]*i[l]}h+=c*t.data[u]}return h}.apply(void 0,arguments)}},e.exports.d1=n,e.exports.d2=i,e.exports.d3=a},{}],444:[function(t,e,r){\"use strict\";var n=t(\"cwise-compiler\"),i={body:\"\",args:[],thisVars:[],localVars:[]};function a(t){if(!t)return i;for(var e=0;e<t.args.length;++e){var r=t.args[e];t.args[e]=0===e?{name:r,lvalue:!0,rvalue:!!t.rvalue,count:t.count||1}:{name:r,lvalue:!1,rvalue:!0,count:1}}return t.thisVars||(t.thisVars=[]),t.localVars||(t.localVars=[]),t}function o(t){for(var e=[],r=0;r<t.args.length;++r)e.push(\"a\"+r);return new Function(\"P\",[\"return function \",t.funcName,\"_ndarrayops(\",e.join(\",\"),\") {P(\",e.join(\",\"),\");return a0}\"].join(\"\"))(function(t){return n({args:t.args,pre:a(t.pre),body:a(t.body),post:a(t.proc),funcName:t.funcName})}(t))}var s={add:\"+\",sub:\"-\",mul:\"*\",div:\"/\",mod:\"%\",band:\"&\",bor:\"|\",bxor:\"^\",lshift:\"<<\",rshift:\">>\",rrshift:\">>>\"};!function(){for(var t in s){var e=s[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a\"+e+\"=b\"},rvalue:!0,funcName:t+\"eq\"}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a\"+e+\"=s\"},rvalue:!0,funcName:t+\"seq\"})}}();var l={not:\"!\",bnot:\"~\",neg:\"-\",recip:\"1.0/\"};!function(){for(var t in l){var e=l[t];r[t]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=\"+e+\"b\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\"],body:{args:[\"a\"],body:\"a=\"+e+\"a\"},rvalue:!0,count:2,funcName:t+\"eq\"})}}();var c={and:\"&&\",or:\"||\",eq:\"===\",neq:\"!==\",lt:\"<\",gt:\">\",leq:\"<=\",geq:\">=\"};!function(){for(var t in c){var e=c[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=a\"+e+\"b\"},rvalue:!0,count:2,funcName:t+\"eq\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a=a\"+e+\"s\"},rvalue:!0,count:2,funcName:t+\"seq\"})}}();var u=[\"abs\",\"acos\",\"asin\",\"atan\",\"ceil\",\"cos\",\"exp\",\"floor\",\"log\",\"round\",\"sin\",\"sqrt\",\"tan\"];!function(){for(var t=0;t<u.length;++t){var e=u[t];r[e]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"eq\"]=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f(a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"})}}();var h=[\"max\",\"min\",\"atan2\",\"pow\"];!function(){for(var t=0;t<h.length;++t){var e=h[t];r[e]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e+\"s\"}),r[e+\"eq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"}),r[e+\"seq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"seq\"})}}();var f=[\"atan2\",\"pow\"];!function(){for(var t=0;t<f.length;++t){var e=f[t];r[e+\"op\"]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"op\"}),r[e+\"ops\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"ops\"}),r[e+\"opeq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opeq\"}),r[e+\"opseq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opseq\"})}}(),r.any=n({args:[\"array\"],pre:i,body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"if(a){return true}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return false\"},funcName:\"any\"}),r.all=n({args:[\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1}],body:\"if(!x){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"all\"}),r.sum=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s+=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"sum\"}),r.prod=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=1\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s*=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"prod\"}),r.norm2squared=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm2squared\"}),r.norm2=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return Math.sqrt(this_s)\"},funcName:\"norm2\"}),r.norminf=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:4}],body:\"if(-a>this_s){this_s=-a}else if(a>this_s){this_s=a}\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norminf\"}),r.norm1=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:3}],body:\"this_s+=a<0?-a:a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm1\"}),r.sup=n({args:[\"array\"],pre:{body:\"this_h=-Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_>this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.inf=n({args:[\"array\"],pre:{body:\"this_h=Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_<this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.argmin=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_<this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.argmax=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=-Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_>this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.random=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.random\",thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f()\",thisVars:[\"this_f\"]},funcName:\"random\"}),r.assign=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assign\"}),r.assigns=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assigns\"}),r.equals=n({args:[\"array\",\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1},{name:\"y\",lvalue:!1,rvalue:!0,count:1}],body:\"if(x!==y){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"equals\"})},{\"cwise-compiler\":146}],445:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"./doConvert.js\");e.exports=function(t,e){for(var r=[],a=t,o=1;Array.isArray(a);)r.push(a.length),o*=a.length,a=a[0];return 0===r.length?n():(e||(e=n(new Float64Array(o),r)),i(e,t),e)}},{\"./doConvert.js\":446,ndarray:450}],446:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\nvar _inline_1_v=_inline_1_arg1_,_inline_1_i\\nfor(_inline_1_i=0;_inline_1_i<_inline_1_arg2_.length-1;++_inline_1_i) {\\n_inline_1_v=_inline_1_v[_inline_1_arg2_[_inline_1_i]]\\n}\\n_inline_1_arg0_=_inline_1_v[_inline_1_arg2_[_inline_1_arg2_.length-1]]\\n}\",args:[{name:\"_inline_1_arg0_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:4}],thisVars:[],localVars:[\"_inline_1_i\",\"_inline_1_v\"]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},funcName:\"convert\",blockSize:64})},{\"cwise-compiler\":146}],447:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=32;function a(t){switch(t){case\"uint8\":return[n.mallocUint8,n.freeUint8];case\"uint16\":return[n.mallocUint16,n.freeUint16];case\"uint32\":return[n.mallocUint32,n.freeUint32];case\"int8\":return[n.mallocInt8,n.freeInt8];case\"int16\":return[n.mallocInt16,n.freeInt16];case\"int32\":return[n.mallocInt32,n.freeInt32];case\"float32\":return[n.mallocFloat,n.freeFloat];case\"float64\":return[n.mallocDouble,n.freeDouble];default:return null}}function o(t){for(var e=[],r=0;r<t;++r)e.push(\"s\"+r);for(r=0;r<t;++r)e.push(\"n\"+r);for(r=1;r<t;++r)e.push(\"d\"+r);for(r=1;r<t;++r)e.push(\"e\"+r);for(r=1;r<t;++r)e.push(\"f\"+r);return e}e.exports=function(t,e){var r=[\"'use strict'\"],n=[\"ndarraySortWrapper\",t.join(\"d\"),e].join(\"\");r.push([\"function \",n,\"(\",[\"array\"].join(\",\"),\"){\"].join(\"\"));for(var s=[\"data=array.data,offset=array.offset|0,shape=array.shape,stride=array.stride\"],l=0;l<t.length;++l)s.push([\"s\",l,\"=stride[\",l,\"]|0,n\",l,\"=shape[\",l,\"]|0\"].join(\"\"));var c=new Array(t.length),u=[];for(l=0;l<t.length;++l)0!==(p=t[l])&&(0===u.length?c[p]=\"1\":c[p]=u.join(\"*\"),u.push(\"n\"+p));var h=-1,f=-1;for(l=0;l<t.length;++l){var p,d=t[l];0!==d&&(h>0?s.push([\"d\",d,\"=s\",d,\"-d\",h,\"*n\",h].join(\"\")):s.push([\"d\",d,\"=s\",d].join(\"\")),h=d),0!=(p=t.length-1-l)&&(f>0?s.push([\"e\",p,\"=s\",p,\"-e\",f,\"*n\",f,\",f\",p,\"=\",c[p],\"-f\",f,\"*n\",f].join(\"\")):s.push([\"e\",p,\"=s\",p,\",f\",p,\"=\",c[p]].join(\"\")),f=p)}r.push(\"var \"+s.join(\",\"));var g=[\"0\",\"n0-1\",\"data\",\"offset\"].concat(o(t.length));r.push([\"if(n0<=\",i,\"){\",\"insertionSort(\",g.join(\",\"),\")}else{\",\"quickSort(\",g.join(\",\"),\")}\"].join(\"\")),r.push(\"}return \"+n);var v=new Function(\"insertionSort\",\"quickSort\",r.join(\"\\n\")),m=function(t,e){var r=[\"'use strict'\"],n=[\"ndarrayInsertionSort\",t.join(\"d\"),e].join(\"\"),i=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),s=a(e),l=[\"i,j,cptr,ptr=left*s0+offset\"];if(t.length>1){for(var c=[],u=1;u<t.length;++u)l.push(\"i\"+u),c.push(\"n\"+u);s?l.push(\"scratch=malloc(\"+c.join(\"*\")+\")\"):l.push(\"scratch=new Array(\"+c.join(\"*\")+\")\"),l.push(\"dptr\",\"sptr\",\"a\",\"b\")}else l.push(\"scratch\");function h(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function f(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}if(r.push([\"function \",n,\"(\",i.join(\",\"),\"){var \",l.join(\",\")].join(\"\"),\"for(i=left+1;i<=right;++i){\",\"j=i;ptr+=s0\",\"cptr=ptr\"),t.length>1){for(r.push(\"dptr=0;sptr=ptr\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(\"scratch[dptr++]=\",h(\"sptr\")),u=0;u<t.length;++u)0!==(p=t[u])&&r.push(\"sptr+=d\"+p,\"}\");for(r.push(\"__g:while(j--\\x3eleft){\",\"dptr=0\",\"sptr=cptr-s0\"),u=1;u<t.length;++u)1===u&&r.push(\"__l:\"),r.push([\"for(i\",u,\"=0;i\",u,\"<n\",u,\";++i\",u,\"){\"].join(\"\"));for(r.push([\"a=\",h(\"sptr\"),\"\\nb=scratch[dptr]\\nif(a<b){break __g}\\nif(a>b){break __l}\"].join(\"\")),u=t.length-1;u>=1;--u)r.push(\"sptr+=e\"+u,\"dptr+=f\"+u,\"}\");for(r.push(\"dptr=cptr;sptr=cptr-s0\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(f(\"dptr\",h(\"sptr\"))),u=0;u<t.length;++u)0!==(p=t[u])&&r.push([\"dptr+=d\",p,\";sptr+=d\",p].join(\"\"),\"}\");for(r.push(\"cptr-=s0\\n}\"),r.push(\"dptr=cptr;sptr=0\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(f(\"dptr\",\"scratch[sptr++]\")),u=0;u<t.length;++u){var p;0!==(p=t[u])&&r.push(\"dptr+=d\"+p,\"}\")}}else r.push(\"scratch=\"+h(\"ptr\"),\"while((j--\\x3eleft)&&(\"+h(\"cptr-s0\")+\">scratch)){\",f(\"cptr\",h(\"cptr-s0\")),\"cptr-=s0\",\"}\",f(\"cptr\",\"scratch\"));return r.push(\"}\"),t.length>1&&s&&r.push(\"free(scratch)\"),r.push(\"} return \"+n),s?new Function(\"malloc\",\"free\",r.join(\"\\n\"))(s[0],s[1]):new Function(r.join(\"\\n\"))()}(t,e),y=function(t,e,r){var n=[\"'use strict'\"],s=[\"ndarrayQuickSort\",t.join(\"d\"),e].join(\"\"),l=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),c=a(e),u=0;n.push([\"function \",s,\"(\",l.join(\",\"),\"){\"].join(\"\"));var h=[\"sixth=((right-left+1)/6)|0\",\"index1=left+sixth\",\"index5=right-sixth\",\"index3=(left+right)>>1\",\"index2=index3-sixth\",\"index4=index3+sixth\",\"el1=index1\",\"el2=index2\",\"el3=index3\",\"el4=index4\",\"el5=index5\",\"less=left+1\",\"great=right-1\",\"pivots_are_equal=true\",\"tmp\",\"tmp0\",\"x\",\"y\",\"z\",\"k\",\"ptr0\",\"ptr1\",\"ptr2\",\"comp_pivot1=0\",\"comp_pivot2=0\",\"comp=0\"];if(t.length>1){for(var f=[],p=1;p<t.length;++p)f.push(\"n\"+p),h.push(\"i\"+p);for(p=0;p<8;++p)h.push(\"b_ptr\"+p);h.push(\"ptr3\",\"ptr4\",\"ptr5\",\"ptr6\",\"ptr7\",\"pivot_ptr\",\"ptr_shift\",\"elementSize=\"+f.join(\"*\")),c?h.push(\"pivot1=malloc(elementSize)\",\"pivot2=malloc(elementSize)\"):h.push(\"pivot1=new Array(elementSize),pivot2=new Array(elementSize)\")}else h.push(\"pivot1\",\"pivot2\");function d(t){return[\"(offset+\",t,\"*s0)\"].join(\"\")}function g(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function v(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}function m(e,r,i){if(1===e.length)n.push(\"ptr0=\"+d(e[0]));else for(var a=0;a<e.length;++a)n.push([\"b_ptr\",a,\"=s0*\",e[a]].join(\"\"));for(r&&n.push(\"pivot_ptr=0\"),n.push(\"ptr_shift=offset\"),a=t.length-1;a>=0;--a)0!==(o=t[a])&&n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"));if(e.length>1)for(a=0;a<e.length;++a)n.push([\"ptr\",a,\"=b_ptr\",a,\"+ptr_shift\"].join(\"\"));for(n.push(i),r&&n.push(\"++pivot_ptr\"),a=0;a<t.length;++a){var o;0!==(o=t[a])&&(e.length>1?n.push(\"ptr_shift+=d\"+o):n.push(\"ptr0+=d\"+o),n.push(\"}\"))}}function y(e,r,i,a){if(1===r.length)n.push(\"ptr0=\"+d(r[0]));else{for(var o=0;o<r.length;++o)n.push([\"b_ptr\",o,\"=s0*\",r[o]].join(\"\"));n.push(\"ptr_shift=offset\")}for(i&&n.push(\"pivot_ptr=0\"),e&&n.push(e+\":\"),o=1;o<t.length;++o)n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"));if(r.length>1)for(o=0;o<r.length;++o)n.push([\"ptr\",o,\"=b_ptr\",o,\"+ptr_shift\"].join(\"\"));for(n.push(a),o=t.length-1;o>=1;--o)i&&n.push(\"pivot_ptr+=f\"+o),r.length>1?n.push(\"ptr_shift+=e\"+o):n.push(\"ptr0+=e\"+o),n.push(\"}\")}function x(){t.length>1&&c&&n.push(\"free(pivot1)\",\"free(pivot2)\")}function b(e,r){var i=\"el\"+e,a=\"el\"+r;if(t.length>1){var o=\"__l\"+ ++u;y(o,[i,a],!1,[\"comp=\",g(\"ptr0\"),\"-\",g(\"ptr1\"),\"\\n\",\"if(comp>0){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0;break \",o,\"}\\n\",\"if(comp<0){break \",o,\"}\"].join(\"\"))}else n.push([\"if(\",g(d(i)),\">\",g(d(a)),\"){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0}\"].join(\"\"))}function _(e,r){t.length>1?m([e,r],!1,v(\"ptr0\",g(\"ptr1\"))):n.push(v(d(e),g(d(r))))}function w(e,r,i){if(t.length>1){var a=\"__l\"+ ++u;y(a,[r],!0,[e,\"=\",g(\"ptr0\"),\"-pivot\",i,\"[pivot_ptr]\\n\",\"if(\",e,\"!==0){break \",a,\"}\"].join(\"\"))}else n.push([e,\"=\",g(d(r)),\"-pivot\",i].join(\"\"))}function k(e,r){t.length>1?m([e,r],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",\"tmp\")].join(\"\")):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",\"tmp\")].join(\"\"))}function T(e,r,i){t.length>1?(m([e,r,i],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",g(\"ptr2\")),\"\\n\",v(\"ptr2\",\"tmp\")].join(\"\")),n.push(\"++\"+r,\"--\"+i)):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"ptr2=\",d(i),\"\\n\",\"++\",r,\"\\n\",\"--\",i,\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",g(\"ptr2\")),\"\\n\",v(\"ptr2\",\"tmp\")].join(\"\"))}function A(t,e){k(t,e),n.push(\"--\"+e)}function M(e,r,i){t.length>1?m([e,r],!0,[v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",[\"pivot\",i,\"[pivot_ptr]\"].join(\"\"))].join(\"\")):n.push(v(d(e),g(d(r))),v(d(r),\"pivot\"+i))}function S(e,r){n.push([\"if((\",r,\"-\",e,\")<=\",i,\"){\\n\",\"insertionSort(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}else{\\n\",s,\"(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}\"].join(\"\"))}function E(e,r,i){t.length>1?(n.push([\"__l\",++u,\":while(true){\"].join(\"\")),m([e],!0,[\"if(\",g(\"ptr0\"),\"!==pivot\",r,\"[pivot_ptr]){break __l\",u,\"}\"].join(\"\")),n.push(i,\"}\")):n.push([\"while(\",g(d(e)),\"===pivot\",r,\"){\",i,\"}\"].join(\"\"))}return n.push(\"var \"+h.join(\",\")),b(1,2),b(4,5),b(1,3),b(2,3),b(1,4),b(3,4),b(2,5),b(2,3),b(4,5),t.length>1?m([\"el1\",\"el2\",\"el3\",\"el4\",\"el5\",\"index1\",\"index3\",\"index5\"],!0,[\"pivot1[pivot_ptr]=\",g(\"ptr1\"),\"\\n\",\"pivot2[pivot_ptr]=\",g(\"ptr3\"),\"\\n\",\"pivots_are_equal=pivots_are_equal&&(pivot1[pivot_ptr]===pivot2[pivot_ptr])\\n\",\"x=\",g(\"ptr0\"),\"\\n\",\"y=\",g(\"ptr2\"),\"\\n\",\"z=\",g(\"ptr4\"),\"\\n\",v(\"ptr5\",\"x\"),\"\\n\",v(\"ptr6\",\"y\"),\"\\n\",v(\"ptr7\",\"z\")].join(\"\")):n.push([\"pivot1=\",g(d(\"el2\")),\"\\n\",\"pivot2=\",g(d(\"el4\")),\"\\n\",\"pivots_are_equal=pivot1===pivot2\\n\",\"x=\",g(d(\"el1\")),\"\\n\",\"y=\",g(d(\"el3\")),\"\\n\",\"z=\",g(d(\"el5\")),\"\\n\",v(d(\"index1\"),\"x\"),\"\\n\",v(d(\"index3\"),\"y\"),\"\\n\",v(d(\"index5\"),\"z\")].join(\"\")),_(\"index2\",\"left\"),_(\"index4\",\"right\"),n.push(\"if(pivots_are_equal){\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp\",\"k\",1),n.push(\"if(comp===0){continue}\"),n.push(\"if(comp<0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),n.push(\"while(true){\"),w(\"comp\",\"great\",1),n.push(\"if(comp>0){\"),n.push(\"great--\"),n.push(\"}else if(comp<0){\"),T(\"k\",\"less\",\"great\"),n.push(\"break\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}else{\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1<0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2>0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp>0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),T(\"k\",\"less\",\"great\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),M(\"left\",\"(less-1)\",1),M(\"right\",\"(great+1)\",2),S(\"left\",\"(less-2)\"),S(\"(great+2)\",\"right\"),n.push(\"if(pivots_are_equal){\"),x(),n.push(\"return\"),n.push(\"}\"),n.push(\"if(less<index1&&great>index5){\"),E(\"less\",1,\"++less\"),E(\"great\",2,\"--great\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1===0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2===0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp===0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),T(\"k\",\"less\",\"great\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),x(),S(\"less\",\"great\"),n.push(\"}return \"+s),t.length>1&&c?new Function(\"insertionSort\",\"malloc\",\"free\",n.join(\"\\n\"))(r,c[0],c[1]):new Function(\"insertionSort\",n.join(\"\\n\"))(r)}(t,e,m);return v(m,y)}},{\"typedarray-pool\":545}],448:[function(t,e,r){\"use strict\";var n=t(\"./lib/compile_sort.js\"),i={};e.exports=function(t){var e=t.order,r=t.dtype,a=[e,r].join(\":\"),o=i[a];return o||(i[a]=o=n(e,r)),o(t),t}},{\"./lib/compile_sort.js\":447}],449:[function(t,e,r){\"use strict\";var n=t(\"ndarray-linear-interpolate\"),i=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=new Array(_inline_3_arg4_)}\",args:[{name:\"_inline_3_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg2_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg3_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_4_arg2_(this_warped,_inline_4_arg0_),_inline_4_arg1_=_inline_4_arg3_.apply(void 0,this_warped)}\",args:[{name:\"_inline_4_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_4_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg4_\",lvalue:!1,rvalue:!1,count:0}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warpND\",blockSize:64}),a=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_7_arg2_(this_warped,_inline_7_arg0_),_inline_7_arg1_=_inline_7_arg3_(_inline_7_arg4_,this_warped[0])}\",args:[{name:\"_inline_7_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_7_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp1D\",blockSize:64}),o=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0,0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_10_arg2_(this_warped,_inline_10_arg0_),_inline_10_arg1_=_inline_10_arg3_(_inline_10_arg4_,this_warped[0],this_warped[1])}\",args:[{name:\"_inline_10_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_10_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp2D\",blockSize:64}),s=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0,0,0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_13_arg2_(this_warped,_inline_13_arg0_),_inline_13_arg1_=_inline_13_arg3_(_inline_13_arg4_,this_warped[0],this_warped[1],this_warped[2])}\",args:[{name:\"_inline_13_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_13_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp3D\",blockSize:64});e.exports=function(t,e,r){switch(e.shape.length){case 1:a(t,r,n.d1,e);break;case 2:o(t,r,n.d2,e);break;case 3:s(t,r,n.d3,e);break;default:i(t,r,n.bind(void 0,e),e.shape.length)}return t}},{\"cwise/lib/wrapper\":149,\"ndarray-linear-interpolate\":443}],450:[function(t,e,r){var n=t(\"iota-array\"),i=t(\"is-buffer\"),a=\"undefined\"!=typeof Float64Array;function o(t,e){return t[0]-e[0]}function s(){var t,e=this.stride,r=new Array(e.length);for(t=0;t<r.length;++t)r[t]=[Math.abs(e[t]),t];r.sort(o);var n=new Array(r.length);for(t=0;t<n.length;++t)n[t]=r[t][1];return n}function l(t,e){var r=[\"View\",e,\"d\",t].join(\"\");e<0&&(r=\"View_Nil\"+t);var i=\"generic\"===t;if(-1===e){var a=\"function \"+r+\"(a){this.data=a;};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return -1};proto.size=0;proto.dimension=-1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function(){return new \"+r+\"(this.data);};proto.get=proto.set=function(){};proto.pick=function(){return null};return function construct_\"+r+\"(a){return new \"+r+\"(a);}\";return new Function(a)()}if(0===e){a=\"function \"+r+\"(a,d) {this.data = a;this.offset = d};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return this.offset};proto.dimension=0;proto.size=1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function \"+r+\"_copy() {return new \"+r+\"(this.data,this.offset)};proto.pick=function \"+r+\"_pick(){return TrivialArray(this.data);};proto.valueOf=proto.get=function \"+r+\"_get(){return \"+(i?\"this.data.get(this.offset)\":\"this.data[this.offset]\")+\"};proto.set=function \"+r+\"_set(v){return \"+(i?\"this.data.set(this.offset,v)\":\"this.data[this.offset]=v\")+\"};return function construct_\"+r+\"(a,b,c,d){return new \"+r+\"(a,d)}\";return new Function(\"TrivialArray\",a)(c[t][0])}a=[\"'use strict'\"];var o=n(e),l=o.map(function(t){return\"i\"+t}),u=\"this.offset+\"+o.map(function(t){return\"this.stride[\"+t+\"]*i\"+t}).join(\"+\"),h=o.map(function(t){return\"b\"+t}).join(\",\"),f=o.map(function(t){return\"c\"+t}).join(\",\");a.push(\"function \"+r+\"(a,\"+h+\",\"+f+\",d){this.data=a\",\"this.shape=[\"+h+\"]\",\"this.stride=[\"+f+\"]\",\"this.offset=d|0}\",\"var proto=\"+r+\".prototype\",\"proto.dtype='\"+t+\"'\",\"proto.dimension=\"+e),a.push(\"Object.defineProperty(proto,'size',{get:function \"+r+\"_size(){return \"+o.map(function(t){return\"this.shape[\"+t+\"]\"}).join(\"*\"),\"}})\"),1===e?a.push(\"proto.order=[0]\"):(a.push(\"Object.defineProperty(proto,'order',{get:\"),e<4?(a.push(\"function \"+r+\"_order(){\"),2===e?a.push(\"return (Math.abs(this.stride[0])>Math.abs(this.stride[1]))?[1,0]:[0,1]}})\"):3===e&&a.push(\"var s0=Math.abs(this.stride[0]),s1=Math.abs(this.stride[1]),s2=Math.abs(this.stride[2]);if(s0>s1){if(s1>s2){return [2,1,0];}else if(s0>s2){return [1,2,0];}else{return [1,0,2];}}else if(s0>s2){return [2,0,1];}else if(s2>s1){return [0,1,2];}else{return [0,2,1];}}})\")):a.push(\"ORDER})\")),a.push(\"proto.set=function \"+r+\"_set(\"+l.join(\",\")+\",v){\"),i?a.push(\"return this.data.set(\"+u+\",v)}\"):a.push(\"return this.data[\"+u+\"]=v}\"),a.push(\"proto.get=function \"+r+\"_get(\"+l.join(\",\")+\"){\"),i?a.push(\"return this.data.get(\"+u+\")}\"):a.push(\"return this.data[\"+u+\"]}\"),a.push(\"proto.index=function \"+r+\"_index(\",l.join(),\"){return \"+u+\"}\"),a.push(\"proto.hi=function \"+r+\"_hi(\"+l.join(\",\")+\"){return new \"+r+\"(this.data,\"+o.map(function(t){return[\"(typeof i\",t,\"!=='number'||i\",t,\"<0)?this.shape[\",t,\"]:i\",t,\"|0\"].join(\"\")}).join(\",\")+\",\"+o.map(function(t){return\"this.stride[\"+t+\"]\"}).join(\",\")+\",this.offset)}\");var p=o.map(function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"}),d=o.map(function(t){return\"c\"+t+\"=this.stride[\"+t+\"]\"});a.push(\"proto.lo=function \"+r+\"_lo(\"+l.join(\",\")+\"){var b=this.offset,d=0,\"+p.join(\",\")+\",\"+d.join(\",\"));for(var g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){d=i\"+g+\"|0;b+=c\"+g+\"*d;a\"+g+\"-=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map(function(t){return\"a\"+t}).join(\",\")+\",\"+o.map(function(t){return\"c\"+t}).join(\",\")+\",b)}\"),a.push(\"proto.step=function \"+r+\"_step(\"+l.join(\",\")+\"){var \"+o.map(function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"}).join(\",\")+\",\"+o.map(function(t){return\"b\"+t+\"=this.stride[\"+t+\"]\"}).join(\",\")+\",c=this.offset,d=0,ceil=Math.ceil\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'){d=i\"+g+\"|0;if(d<0){c+=b\"+g+\"*(a\"+g+\"-1);a\"+g+\"=ceil(-a\"+g+\"/d)}else{a\"+g+\"=ceil(a\"+g+\"/d)}b\"+g+\"*=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map(function(t){return\"a\"+t}).join(\",\")+\",\"+o.map(function(t){return\"b\"+t}).join(\",\")+\",c)}\");var v=new Array(e),m=new Array(e);for(g=0;g<e;++g)v[g]=\"a[i\"+g+\"]\",m[g]=\"b[i\"+g+\"]\";a.push(\"proto.transpose=function \"+r+\"_transpose(\"+l+\"){\"+l.map(function(t,e){return t+\"=(\"+t+\"===undefined?\"+e+\":\"+t+\"|0)\"}).join(\";\"),\"var a=this.shape,b=this.stride;return new \"+r+\"(this.data,\"+v.join(\",\")+\",\"+m.join(\",\")+\",this.offset)}\"),a.push(\"proto.pick=function \"+r+\"_pick(\"+l+\"){var a=[],b=[],c=this.offset\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){c=(c+this.stride[\"+g+\"]*i\"+g+\")|0}else{a.push(this.shape[\"+g+\"]);b.push(this.stride[\"+g+\"])}\");return a.push(\"var ctor=CTOR_LIST[a.length+1];return ctor(this.data,a,b,c)}\"),a.push(\"return function construct_\"+r+\"(data,shape,stride,offset){return new \"+r+\"(data,\"+o.map(function(t){return\"shape[\"+t+\"]\"}).join(\",\")+\",\"+o.map(function(t){return\"stride[\"+t+\"]\"}).join(\",\")+\",offset)}\"),new Function(\"CTOR_LIST\",\"ORDER\",a.join(\"\\n\"))(c[t],s)}var c={float32:[],float64:[],int8:[],int16:[],int32:[],uint8:[],uint16:[],uint32:[],array:[],uint8_clamped:[],buffer:[],generic:[]};e.exports=function(t,e,r,n){if(void 0===t)return(0,c.array[0])([]);\"number\"==typeof t&&(t=[t]),void 0===e&&(e=[t.length]);var o=e.length;if(void 0===r){r=new Array(o);for(var s=o-1,u=1;s>=0;--s)r[s]=u,u*=e[s]}if(void 0===n)for(n=0,s=0;s<o;++s)r[s]<0&&(n-=(e[s]-1)*r[s]);for(var h=function(t){if(i(t))return\"buffer\";if(a)switch(Object.prototype.toString.call(t)){case\"[object Float64Array]\":return\"float64\";case\"[object Float32Array]\":return\"float32\";case\"[object Int8Array]\":return\"int8\";case\"[object Int16Array]\":return\"int16\";case\"[object Int32Array]\":return\"int32\";case\"[object Uint8Array]\":return\"uint8\";case\"[object Uint16Array]\":return\"uint16\";case\"[object Uint32Array]\":return\"uint32\";case\"[object Uint8ClampedArray]\":return\"uint8_clamped\"}return Array.isArray(t)?\"array\":\"generic\"}(t),f=c[h];f.length<=o+1;)f.push(l(h,f.length-1));return(0,f[o+1])(t,e,r,n)}},{\"iota-array\":416,\"is-buffer\":418}],451:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=Math.pow(2,-1074),a=-1>>>0;e.exports=function(t,e){if(isNaN(t)||isNaN(e))return NaN;if(t===e)return t;if(0===t)return e<0?-i:i;var r=n.hi(t),o=n.lo(t);e>t==t>0?o===a?(r+=1,o=0):o+=1:0===o?(o=a,r-=1):o-=1;return n.pack(o,r)}},{\"double-bits\":167}],452:[function(t,e,r){var n=Math.PI,i=c(120);function a(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function o(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}function s(t,e,r,a,o,c,u,h,f,p){if(p)k=p[0],T=p[1],_=p[2],w=p[3];else{var d=l(t,e,-o);t=d.x,e=d.y;var g=(t-(h=(d=l(h,f,-o)).x))/2,v=(e-(f=d.y))/2,m=g*g/(r*r)+v*v/(a*a);m>1&&(r*=m=Math.sqrt(m),a*=m);var y=r*r,x=a*a,b=(c==u?-1:1)*Math.sqrt(Math.abs((y*x-y*v*v-x*g*g)/(y*v*v+x*g*g)));b==1/0&&(b=1);var _=b*r*v/a+(t+h)/2,w=b*-a*g/r+(e+f)/2,k=Math.asin(((e-w)/a).toFixed(9)),T=Math.asin(((f-w)/a).toFixed(9));(k=t<_?n-k:k)<0&&(k=2*n+k),(T=h<_?n-T:T)<0&&(T=2*n+T),u&&k>T&&(k-=2*n),!u&&T>k&&(T-=2*n)}if(Math.abs(T-k)>i){var A=T,M=h,S=f;T=k+i*(u&&T>k?1:-1);var E=s(h=_+r*Math.cos(T),f=w+a*Math.sin(T),r,a,o,0,u,M,S,[T,A,_,w])}var C=Math.tan((T-k)/4),L=4/3*r*C,P=4/3*a*C,O=[2*t-(t+L*Math.sin(k)),2*e-(e-P*Math.cos(k)),h+L*Math.sin(T),f-P*Math.cos(T),h,f];if(p)return O;E&&(O=O.concat(E));for(var z=0;z<O.length;){var I=l(O[z],O[z+1],o);O[z++]=I.x,O[z++]=I.y}return O}function l(t,e,r){return{x:t*Math.cos(r)-e*Math.sin(r),y:t*Math.sin(r)+e*Math.cos(r)}}function c(t){return t*(n/180)}e.exports=function(t){for(var e,r=[],n=0,i=0,l=0,u=0,h=null,f=null,p=0,d=0,g=0,v=t.length;g<v;g++){var m=t[g],y=m[0];switch(y){case\"M\":l=m[1],u=m[2];break;case\"A\":(m=s(p,d,m[1],m[2],c(m[3]),m[4],m[5],m[6],m[7])).unshift(\"C\"),m.length>7&&(r.push(m.splice(0,7)),m.unshift(\"C\"));break;case\"S\":var x=p,b=d;\"C\"!=e&&\"S\"!=e||(x+=x-n,b+=b-i),m=[\"C\",x,b,m[1],m[2],m[3],m[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(h=2*p-h,f=2*d-f):(h=p,f=d),m=o(p,d,h,f,m[1],m[2]);break;case\"Q\":h=m[1],f=m[2],m=o(p,d,m[1],m[2],m[3],m[4]);break;case\"L\":m=a(p,d,m[1],m[2]);break;case\"H\":m=a(p,d,m[1],d);break;case\"V\":m=a(p,d,p,m[1]);break;case\"Z\":m=a(p,d,l,u)}e=y,p=m[m.length-2],d=m[m.length-1],m.length>4?(n=m[m.length-4],i=m[m.length-3]):(n=p,i=d),r.push(m)}return r}},{}],453:[function(t,e,r){r.vertexNormals=function(t,e,r){for(var n=e.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o)i[o]=[0,0,0];for(o=0;o<t.length;++o)for(var s=t[o],l=0,c=s[s.length-1],u=s[0],h=0;h<s.length;++h){l=c,c=u,u=s[(h+1)%s.length];for(var f=e[l],p=e[c],d=e[u],g=new Array(3),v=0,m=new Array(3),y=0,x=0;x<3;++x)g[x]=f[x]-p[x],v+=g[x]*g[x],m[x]=d[x]-p[x],y+=m[x]*m[x];if(v*y>a){var b=i[c],_=1/Math.sqrt(v*y);for(x=0;x<3;++x){var w=(x+1)%3,k=(x+2)%3;b[x]+=_*(m[w]*g[k]-m[k]*g[w])}}}for(o=0;o<n;++o){b=i[o];var T=0;for(x=0;x<3;++x)T+=b[x]*b[x];if(T>a)for(_=1/Math.sqrt(T),x=0;x<3;++x)b[x]*=_;else for(x=0;x<3;++x)b[x]=0}return i},r.faceNormals=function(t,e,r){for(var n=t.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o){for(var s=t[o],l=new Array(3),c=0;c<3;++c)l[c]=e[s[c]];var u=new Array(3),h=new Array(3);for(c=0;c<3;++c)u[c]=l[1][c]-l[0][c],h[c]=l[2][c]-l[0][c];var f=new Array(3),p=0;for(c=0;c<3;++c){var d=(c+1)%3,g=(c+2)%3;f[c]=u[d]*h[g]-u[g]*h[d],p+=f[c]*f[c]}p=p>a?1/Math.sqrt(p):0;for(c=0;c<3;++c)f[c]*=p;i[o]=f}return i}},{}],454:[function(t,e,r){\"use strict\";var n=Object.getOwnPropertySymbols,i=Object.prototype.hasOwnProperty,a=Object.prototype.propertyIsEnumerable;e.exports=function(){try{if(!Object.assign)return!1;var t=new String(\"abc\");if(t[5]=\"de\",\"5\"===Object.getOwnPropertyNames(t)[0])return!1;for(var e={},r=0;r<10;r++)e[\"_\"+String.fromCharCode(r)]=r;if(\"0123456789\"!==Object.getOwnPropertyNames(e).map(function(t){return e[t]}).join(\"\"))return!1;var n={};return\"abcdefghijklmnopqrst\".split(\"\").forEach(function(t){n[t]=t}),\"abcdefghijklmnopqrst\"===Object.keys(Object.assign({},n)).join(\"\")}catch(t){return!1}}()?Object.assign:function(t,e){for(var r,o,s=function(t){if(null==t)throw new TypeError(\"Object.assign cannot be called with null or undefined\");return Object(t)}(t),l=1;l<arguments.length;l++){for(var c in r=Object(arguments[l]))i.call(r,c)&&(s[c]=r[c]);if(n){o=n(r);for(var u=0;u<o.length;u++)a.call(r,o[u])&&(s[o[u]]=r[o[u]])}}return s}},{}],455:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a,o,s,l,c){var u=e+a+c;if(h>0){var h=Math.sqrt(u+1);t[0]=.5*(o-l)/h,t[1]=.5*(s-n)/h,t[2]=.5*(r-a)/h,t[3]=.5*h}else{var f=Math.max(e,a,c),h=Math.sqrt(2*f-u+1);e>=f?(t[0]=.5*h,t[1]=.5*(i+r)/h,t[2]=.5*(s+n)/h,t[3]=.5*(o-l)/h):a>=f?(t[0]=.5*(r+i)/h,t[1]=.5*h,t[2]=.5*(l+o)/h,t[3]=.5*(s-n)/h):(t[0]=.5*(n+s)/h,t[1]=.5*(o+l)/h,t[2]=.5*h,t[3]=.5*(r-i)/h)}return t}},{}],456:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.rotation||[0,0,0,1],n=t.radius||1;e=[].slice.call(e,0,3),u(r=[].slice.call(r,0,4),r);var i=new h(r,e,Math.log(n));i.setDistanceLimits(t.zoomMin,t.zoomMax),(\"eye\"in t||\"up\"in t)&&i.lookAt(0,t.eye,t.center,t.up);return i};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/lookAt\"),a=t(\"gl-mat4/fromQuat\"),o=t(\"gl-mat4/invert\"),s=t(\"./lib/quatFromFrame\");function l(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function c(t,e,r,n){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2)+Math.pow(n,2))}function u(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=c(r,n,i,a);o>1e-6?(t[0]=r/o,t[1]=n/o,t[2]=i/o,t[3]=a/o):(t[0]=t[1]=t[2]=0,t[3]=1)}function h(t,e,r){this.radius=n([r]),this.center=n(e),this.rotation=n(t),this.computedRadius=this.radius.curve(0),this.computedCenter=this.center.curve(0),this.computedRotation=this.rotation.curve(0),this.computedUp=[.1,0,0],this.computedEye=[.1,0,0],this.computedMatrix=[.1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],this.recalcMatrix(0)}var f=h.prototype;f.lastT=function(){return Math.max(this.radius.lastT(),this.center.lastT(),this.rotation.lastT())},f.recalcMatrix=function(t){this.radius.curve(t),this.center.curve(t),this.rotation.curve(t);var e=this.computedRotation;u(e,e);var r=this.computedMatrix;a(r,e);var n=this.computedCenter,i=this.computedEye,o=this.computedUp,s=Math.exp(this.computedRadius[0]);i[0]=n[0]+s*r[2],i[1]=n[1]+s*r[6],i[2]=n[2]+s*r[10],o[0]=r[1],o[1]=r[5],o[2]=r[9];for(var l=0;l<3;++l){for(var c=0,h=0;h<3;++h)c+=r[l+4*h]*i[h];r[12+l]=-c}},f.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r},f.idle=function(t){this.center.idle(t),this.radius.idle(t),this.rotation.idle(t)},f.flush=function(t){this.center.flush(t),this.radius.flush(t),this.rotation.flush(t)},f.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=i[1],o=i[5],s=i[9],c=l(a,o,s);a/=c,o/=c,s/=c;var u=i[0],h=i[4],f=i[8],p=u*a+h*o+f*s,d=l(u-=a*p,h-=o*p,f-=s*p);u/=d,h/=d,f/=d;var g=i[2],v=i[6],m=i[10],y=g*a+v*o+m*s,x=g*u+v*h+m*f,b=l(g-=y*a+x*u,v-=y*o+x*h,m-=y*s+x*f);g/=b,v/=b,m/=b;var _=u*e+a*r,w=h*e+o*r,k=f*e+s*r;this.center.move(t,_,w,k);var T=Math.exp(this.computedRadius[0]);T=Math.max(1e-4,T+n),this.radius.set(t,Math.log(T))},f.rotate=function(t,e,r,n){this.recalcMatrix(t),e=e||0,r=r||0;var i=this.computedMatrix,a=i[0],o=i[4],s=i[8],u=i[1],h=i[5],f=i[9],p=i[2],d=i[6],g=i[10],v=e*a+r*u,m=e*o+r*h,y=e*s+r*f,x=-(d*y-g*m),b=-(g*v-p*y),_=-(p*m-d*v),w=Math.sqrt(Math.max(0,1-Math.pow(x,2)-Math.pow(b,2)-Math.pow(_,2))),k=c(x,b,_,w);k>1e-6?(x/=k,b/=k,_/=k,w/=k):(x=b=_=0,w=1);var T=this.computedRotation,A=T[0],M=T[1],S=T[2],E=T[3],C=A*w+E*x+M*_-S*b,L=M*w+E*b+S*x-A*_,P=S*w+E*_+A*b-M*x,O=E*w-A*x-M*b-S*_;if(n){x=p,b=d,_=g;var z=Math.sin(n)/l(x,b,_);x*=z,b*=z,_*=z,O=O*(w=Math.cos(e))-(C=C*w+O*x+L*_-P*b)*x-(L=L*w+O*b+P*x-C*_)*b-(P=P*w+O*_+C*b-L*x)*_}var I=c(C,L,P,O);I>1e-6?(C/=I,L/=I,P/=I,O/=I):(C=L=P=0,O=1),this.rotation.set(t,C,L,P,O)},f.lookAt=function(t,e,r,n){this.recalcMatrix(t),r=r||this.computedCenter,e=e||this.computedEye,n=n||this.computedUp;var a=this.computedMatrix;i(a,e,r,n);var o=this.computedRotation;s(o,a[0],a[1],a[2],a[4],a[5],a[6],a[8],a[9],a[10]),u(o,o),this.rotation.set(t,o[0],o[1],o[2],o[3]);for(var l=0,c=0;c<3;++c)l+=Math.pow(r[c]-e[c],2);this.radius.set(t,.5*Math.log(Math.max(l,1e-6))),this.center.set(t,r[0],r[1],r[2])},f.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},f.setMatrix=function(t,e){var r=this.computedRotation;s(r,e[0],e[1],e[2],e[4],e[5],e[6],e[8],e[9],e[10]),u(r,r),this.rotation.set(t,r[0],r[1],r[2],r[3]);var n=this.computedMatrix;o(n,e);var i=n[15];if(Math.abs(i)>1e-6){var a=n[12]/i,l=n[13]/i,c=n[14]/i;this.recalcMatrix(t);var h=Math.exp(this.computedRadius[0]);this.center.set(t,a-n[2]*h,l-n[6]*h,c-n[10]*h),this.radius.idle(t)}else this.center.idle(t),this.radius.idle(t)},f.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},f.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},f.getDistanceLimits=function(t){var e=this.radius.bounds;return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},f.toJSON=function(){return this.recalcMatrix(this.lastT()),{center:this.computedCenter.slice(),rotation:this.computedRotation.slice(),distance:Math.log(this.computedRadius[0]),zoomMin:this.radius.bounds[0][0],zoomMax:this.radius.bounds[1][0]}},f.fromJSON=function(t){var e=this.lastT(),r=t.center;r&&this.center.set(e,r[0],r[1],r[2]);var n=t.rotation;n&&this.rotation.set(e,n[0],n[1],n[2],n[3]);var i=t.distance;i&&i>0&&this.radius.set(e,Math.log(i)),this.setDistanceLimits(t.zoomMin,t.zoomMax)}},{\"./lib/quatFromFrame\":455,\"filtered-vector\":226,\"gl-mat4/fromQuat\":262,\"gl-mat4/invert\":265,\"gl-mat4/lookAt\":266}],457:[function(t,e,r){\"use strict\";var n=t(\"repeat-string\");e.exports=function(t,e,r){return n(r=\"undefined\"!=typeof r?r+\"\":\" \",e)+t}},{\"repeat-string\":503}],458:[function(t,e,r){\"use strict\";function n(t,e){if(\"string\"!=typeof t)return[t];var r=[t];\"string\"==typeof e||Array.isArray(e)?e={brackets:e}:e||(e={});var n=e.brackets?Array.isArray(e.brackets)?e.brackets:[e.brackets]:[\"{}\",\"[]\",\"()\"],i=e.escape||\"___\",a=!!e.flat;n.forEach(function(t){var e=new RegExp([\"\\\\\",t[0],\"[^\\\\\",t[0],\"\\\\\",t[1],\"]*\\\\\",t[1]].join(\"\")),n=[];function a(e,a,o){var s=r.push(e.slice(t[0].length,-t[1].length))-1;return n.push(s),i+s+i}r.forEach(function(t,n){for(var i,o=0;t!=i;)if(i=t,t=t.replace(e,a),o++>1e4)throw Error(\"References have circular dependency. Please, check them.\");r[n]=t}),n=n.reverse(),r=r.map(function(e){return n.forEach(function(r){e=e.replace(new RegExp(\"(\\\\\"+i+r+\"\\\\\"+i+\")\",\"g\"),t[0]+\"$1\"+t[1])}),e})});var o=new RegExp(\"\\\\\"+i+\"([0-9]+)\\\\\"+i);return a?r:function t(e,r,n){for(var i,a=[],s=0;i=o.exec(e);){if(s++>1e4)throw Error(\"Circular references in parenthesis\");a.push(e.slice(0,i.index)),a.push(t(r[i[1]],r)),e=e.slice(i.index+i[0].length)}return a.push(e),a}(r[0],r)}function i(t,e){if(e&&e.flat){var r,n=e&&e.escape||\"___\",i=t[0];if(!i)return\"\";for(var a=new RegExp(\"\\\\\"+n+\"([0-9]+)\\\\\"+n),o=0;i!=r;){if(o++>1e4)throw Error(\"Circular references in \"+t);r=i,i=i.replace(a,s)}return i}return t.reduce(function t(e,r){return Array.isArray(r)&&(r=r.reduce(t,\"\")),e+r},\"\");function s(e,r){if(null==t[r])throw Error(\"Reference \"+r+\"is undefined\");return t[r]}}function a(t,e){return Array.isArray(t)?i(t,e):n(t,e)}a.parse=n,a.stringify=i,e.exports=a},{}],459:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\");e.exports=function(t){var e;arguments.length>1&&(t=arguments);\"string\"==typeof t?t=t.split(/\\s/).map(parseFloat):\"number\"==typeof t&&(t=[t]);t.length&&\"number\"==typeof t[0]?e=1===t.length?{width:t[0],height:t[0],x:0,y:0}:2===t.length?{width:t[0],height:t[1],x:0,y:0}:{x:t[0],y:t[1],width:t[2]-t[0]||0,height:t[3]-t[1]||0}:t&&(t=n(t,{left:\"x l left Left\",top:\"y t top Top\",width:\"w width W Width\",height:\"h height W Width\",bottom:\"b bottom Bottom\",right:\"r right Right\"}),e={x:t.left||0,y:t.top||0},null==t.width?t.right?e.width=t.right-e.x:e.width=0:e.width=t.width,null==t.height?t.bottom?e.height=t.bottom-e.y:e.height=0:e.height=t.height);return e}},{\"pick-by-alias\":465}],460:[function(t,e,r){e.exports=function(t){var e=[];return t.replace(i,function(t,r,i){var o=r.toLowerCase();for(i=function(t){var e=t.match(a);return e?e.map(Number):[]}(i),\"m\"==o&&i.length>2&&(e.push([r].concat(i.splice(0,2))),o=\"l\",r=\"m\"==r?\"l\":\"L\");;){if(i.length==n[o])return i.unshift(r),e.push(i);if(i.length<n[o])throw new Error(\"malformed path data\");e.push([r].concat(i.splice(0,n[o])))}}),e};var n={a:7,c:6,h:1,l:2,m:2,q:4,s:4,t:2,v:1,z:0},i=/([astvzqmhlc])([^astvzqmhlc]*)/gi;var a=/-?[0-9]*\\.?[0-9]+(?:e[-+]?\\d+)?/gi},{}],461:[function(t,e,r){e.exports=function(t,e){e||(e=[0,\"\"]),t=String(t);var r=parseFloat(t,10);return e[0]=r,e[1]=t.match(/[\\d.\\-\\+]*\\s*(.*)/)[1]||\"\",e}},{}],462:[function(t,e,r){(function(t){(function(){var r,n,i,a,o,s;\"undefined\"!=typeof performance&&null!==performance&&performance.now?e.exports=function(){return performance.now()}:\"undefined\"!=typeof t&&null!==t&&t.hrtime?(e.exports=function(){return(r()-o)/1e6},n=t.hrtime,a=(r=function(){var t;return 1e9*(t=n())[0]+t[1]})(),s=1e9*t.uptime(),o=a-s):Date.now?(e.exports=function(){return Date.now()-i},i=Date.now()):(e.exports=function(){return(new Date).getTime()-i},i=(new Date).getTime())}).call(this)}).call(this,t(\"_process\"))},{_process:482}],463:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<n){for(var r=1,a=0;a<e;++a)for(var o=0;o<a;++o)if(t[a]<t[o])r=-r;else if(t[a]===t[o])return 0;return r}for(var s=i.mallocUint8(e),a=0;a<e;++a)s[a]=0;for(var r=1,a=0;a<e;++a)if(!s[a]){var l=1;s[a]=1;for(var o=t[a];o!==a;o=t[o]){if(s[o])return i.freeUint8(s),0;l+=1,s[o]=1}1&l||(r=-r)}return i.freeUint8(s),r};var n=32,i=t(\"typedarray-pool\")},{\"typedarray-pool\":545}],464:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"invert-permutation\");r.rank=function(t){var e=t.length;switch(e){case 0:case 1:return 0;case 2:return t[1]}var r,a,o,s=n.mallocUint32(e),l=n.mallocUint32(e),c=0;for(i(t,l),o=0;o<e;++o)s[o]=t[o];for(o=e-1;o>0;--o)a=l[o],r=s[o],s[o]=s[a],s[a]=r,l[o]=l[r],l[r]=a,c=(c+r)*o;return n.freeUint32(l),n.freeUint32(s),c},r.unrank=function(t,e,r){switch(t){case 0:return r||[];case 1:return r?(r[0]=0,r):[0];case 2:return r?(e?(r[0]=0,r[1]=1):(r[0]=1,r[1]=0),r):e?[0,1]:[1,0]}var n,i,a,o=1;for((r=r||new Array(t))[0]=0,a=1;a<t;++a)r[a]=a,o=o*a|0;for(a=t-1;a>0;--a)e=e-(n=e/o|0)*o|0,o=o/a|0,i=0|r[a],r[a]=0|r[n],r[n]=0|i;return r}},{\"invert-permutation\":415,\"typedarray-pool\":545}],465:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n,a,o={};if(\"string\"==typeof e&&(e=i(e)),Array.isArray(e)){var s={};for(a=0;a<e.length;a++)s[e[a]]=!0;e=s}for(n in e)e[n]=i(e[n]);var l={};for(n in e){var c=e[n];if(Array.isArray(c))for(a=0;a<c.length;a++){var u=c[a];if(r&&(l[u]=!0),u in t){if(o[n]=t[u],r)for(var h=a;h<c.length;h++)l[c[h]]=!0;break}}else n in t&&(e[n]&&(o[n]=t[n]),r&&(l[n]=!0))}if(r)for(n in t)l[n]||(o[n]=t[n]);return o};var n={};function i(t){return n[t]?n[t]:(\"string\"==typeof t&&(t=n[t]=t.split(/\\s*,\\s*|\\s+/)),t)}},{}],466:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=0|e.length,i=t.length,a=[new Array(r),new Array(r)],o=0;o<r;++o)a[0][o]=[],a[1][o]=[];for(var o=0;o<i;++o){var s=t[o];a[0][s[0]].push(s),a[1][s[1]].push(s)}for(var l=[],o=0;o<r;++o)a[0][o].length+a[1][o].length===0&&l.push([o]);function c(t,e){var r=a[e][t[e]];r.splice(r.indexOf(t),1)}function u(t,r,i){for(var o,s,l,u=0;u<2;++u)if(a[u][r].length>0){o=a[u][r][0],l=u;break}s=o[1^l];for(var h=0;h<2;++h)for(var f=a[h][r],p=0;p<f.length;++p){var d=f[p],g=d[1^h],v=n(e[t],e[r],e[s],e[g]);v>0&&(o=d,s=g,l=h)}return i?s:(o&&c(o,l),s)}function h(t,r){var i=a[r][t][0],o=[t];c(i,r);for(var s=i[1^r];;){for(;s!==t;)o.push(s),s=u(o[o.length-2],s,!1);if(a[0][t].length+a[1][t].length===0)break;var l=o[o.length-1],h=t,f=o[1],p=u(l,h,!0);if(n(e[l],e[h],e[f],e[p])<0)break;o.push(t),s=u(l,h)}return o}function f(t,e){return e[1]===e[e.length-1]}for(var o=0;o<r;++o)for(var p=0;p<2;++p){for(var d=[];a[p][o].length>0;){a[0][o].length;var g=h(o,p);f(d,g)?d.push.apply(d,g):(d.length>0&&l.push(d),d=g)}d.length>0&&l.push(d)}return l};var n=t(\"compare-angle\")},{\"compare-angle\":127}],467:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=n(t,e.length),i=new Array(e.length),a=new Array(e.length),o=[],s=0;s<e.length;++s){var l=r[s].length;a[s]=l,i[s]=!0,l<=1&&o.push(s)}for(;o.length>0;){var c=o.pop();i[c]=!1;for(var u=r[c],s=0;s<u.length;++s){var h=u[s];0==--a[h]&&o.push(h)}}for(var f=new Array(e.length),p=[],s=0;s<e.length;++s)if(i[s]){var c=p.length;f[s]=c,p.push(e[s])}else f[s]=-1;for(var d=[],s=0;s<t.length;++s){var g=t[s];i[g[0]]&&i[g[1]]&&d.push([f[g[0]],f[g[1]]])}return[d,p]};var n=t(\"edges-to-adjacency-list\")},{\"edges-to-adjacency-list\":171}],468:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=c(t,e);t=r[0];for(var h=(e=r[1]).length,f=(t.length,n(t,e.length)),p=0;p<h;++p)if(f[p].length%2==1)throw new Error(\"planar-graph-to-polyline: graph must be manifold\");var d=i(t,e);for(var g=(d=d.filter(function(t){for(var r=t.length,n=[0],i=0;i<r;++i){var a=e[t[i]],l=e[t[(i+1)%r]],c=o(-a[0],a[1]),u=o(-a[0],l[1]),h=o(l[0],a[1]),f=o(l[0],l[1]);n=s(n,s(s(c,u),s(h,f)))}return n[n.length-1]>0})).length,v=new Array(g),m=new Array(g),p=0;p<g;++p){v[p]=p;var y=new Array(g),x=d[p].map(function(t){return e[t]}),b=a([x]),_=0;t:for(var w=0;w<g;++w)if(y[w]=0,p!==w){for(var k=d[w],T=k.length,A=0;A<T;++A){var M=b(e[k[A]]);if(0!==M){M<0&&(y[w]=1,_+=1);continue t}}y[w]=1,_+=1}m[p]=[_,p,y]}m.sort(function(t,e){return e[0]-t[0]});for(var p=0;p<g;++p)for(var y=m[p],S=y[1],E=y[2],w=0;w<g;++w)E[w]&&(v[w]=S);for(var C=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=[];return e}(g),p=0;p<g;++p)C[p].push(v[p]),C[v[p]].push(p);for(var L={},P=u(h,!1),p=0;p<g;++p)for(var k=d[p],T=k.length,w=0;w<T;++w){var O=k[w],z=k[(w+1)%T],I=Math.min(O,z)+\":\"+Math.max(O,z);if(I in L){var D=L[I];C[D].push(p),C[p].push(D),P[O]=P[z]=!0}else L[I]=p}function R(t){for(var e=t.length,r=0;r<e;++r)if(!P[t[r]])return!1;return!0}for(var F=[],B=u(g,-1),p=0;p<g;++p)v[p]!==p||R(d[p])?B[p]=-1:(F.push(p),B[p]=0);var r=[];for(;F.length>0;){var N=F.pop(),j=C[N];l(j,function(t,e){return t-e});var U,V=j.length,q=B[N];if(0===q){var k=d[N];U=[k]}for(var p=0;p<V;++p){var H=j[p];if(!(B[H]>=0)&&(B[H]=1^q,F.push(H),0===q)){var k=d[H];R(k)||(k.reverse(),U.push(k))}}0===q&&r.push(U)}return r};var n=t(\"edges-to-adjacency-list\"),i=t(\"planar-dual\"),a=t(\"point-in-big-polygon\"),o=t(\"two-product\"),s=t(\"robust-sum\"),l=t(\"uniq\"),c=t(\"./lib/trim-leaves\");function u(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}},{\"./lib/trim-leaves\":467,\"edges-to-adjacency-list\":171,\"planar-dual\":466,\"point-in-big-polygon\":472,\"robust-sum\":515,\"two-product\":543,uniq:547}],469:[function(t,e,r){\"use strict\";e.exports=t(\"./quad\")},{\"./quad\":471}],470:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],471:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"clamp\"),a=t(\"parse-rect\"),o=t(\"array-bounds\"),s=t(\"pick-by-alias\"),l=t(\"defined\"),c=t(\"flatten-vertex-data\"),u=t(\"is-obj\"),h=t(\"dtype\"),f=t(\"math-log2\");function p(t,e){for(var r=e[0],n=e[1],a=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=i((t[2*l]-r)*a,0,1),s[2*l+1]=i((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,\"float64\"),e=s(e,{bounds:\"range bounds dataBox databox\",maxDepth:\"depth maxDepth maxdepth level maxLevel maxlevel levels\",dtype:\"type dtype format out dst output destination\"});var r=l(e.maxDepth,255),i=l(e.bounds,o(t,2));i[0]===i[2]&&i[2]++,i[1]===i[3]&&i[3]++;var d,g=p(t,i),v=t.length>>>1;e.dtype||(e.dtype=\"array\"),\"string\"==typeof e.dtype?d=new(h(e.dtype))(v):e.dtype&&(d=e.dtype,Array.isArray(d)&&(d.length=v));for(var m=0;m<v;++m)d[m]=m;var y=[],x=[],b=[],_=[];!function t(e,n,i,a,o,s){if(!a.length)return null;var l=y[o]||(y[o]=[]);var c=b[o]||(b[o]=[]);var u=x[o]||(x[o]=[]);var h=l.length;o++;if(o>r){for(var f=0;f<a.length;f++)l.push(a[f]),c.push(s),u.push(null,null,null,null);return h}l.push(a[0]);c.push(s);if(a.length<=1)return u.push(null,null,null,null),h;var p=.5*i;var d=e+p,v=n+p;var m=[],_=[],w=[],k=[];for(var T=1,A=a.length;T<A;T++){var M=a[T],S=g[2*M],E=g[2*M+1];S<d?E<v?m.push(M):_.push(M):E<v?w.push(M):k.push(M)}s<<=2;u.push(t(e,n,p,m,o,s),t(e,v,p,_,o,s+1),t(d,n,p,w,o,s+2),t(d,v,p,k,o,s+3));return h}(0,0,1,d,0,1);for(var w=0,k=0;k<y.length;k++){var T=y[k];if(d.set)d.set(T,w);else for(var A=0,M=T.length;A<M;A++)d[A+w]=T[A];var S=w+y[k].length;_[k]=[w,S],w=S}return d.range=function(){var e,r=[],o=arguments.length;for(;o--;)r[o]=arguments[o];if(u(r[r.length-1])){var c=r.pop();r.length||null==c.x&&null==c.l&&null==c.left||(r=[c],e={}),e=s(c,{level:\"level maxLevel\",d:\"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize\",lod:\"lod details ranges offsets\"})}else e={};r.length||(r=i);var h=a.apply(void 0,r),d=[Math.min(h.x,h.x+h.width),Math.min(h.y,h.y+h.height),Math.max(h.x,h.x+h.width),Math.max(h.y,h.y+h.height)],g=d[0],v=d[1],m=d[2],w=d[3],k=p([g,v,m,w],i),T=k[0],A=k[1],M=k[2],S=k[3],C=l(e.level,y.length);if(null!=e.d){var L;\"number\"==typeof e.d?L=[e.d,e.d]:e.d.length&&(L=e.d),C=Math.min(Math.max(Math.ceil(-f(Math.abs(L[0])/(i[2]-i[0]))),Math.ceil(-f(Math.abs(L[1])/(i[3]-i[1])))),C)}if(C=Math.min(C,y.length),e.lod)return function(t,e,r,i,a){for(var o=[],s=0;s<a;s++){var l=b[s],c=_[s][0],u=E(t,e,s),h=E(r,i,s),f=n.ge(l,u),p=n.gt(l,h,f,l.length-1);o[s]=[f+c,p+c]}return o}(T,A,M,S,C);var P=[];return function e(r,n,i,a,o,s){if(null!==o&&null!==s){var l=r+i,c=n+i;if(!(T>l||A>c||M<r||S<n||a>=C||o===s)){var u=y[a];void 0===s&&(s=u.length);for(var h=o;h<s;h++){var f=u[h],p=t[2*f],d=t[2*f+1];p>=g&&p<=m&&d>=v&&d<=w&&P.push(f)}var b=x[a],_=b[4*o+0],k=b[4*o+1],E=b[4*o+2],L=b[4*o+3],O=function(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}(b,o+1),z=.5*i,I=a+1;e(r,n,z,I,_,k||E||L||O),e(r,n+z,z,I,k,E||L||O),e(r+z,n,z,I,E,L||O),e(r+z,n+z,z,I,L,O)}}}(0,0,1,0,0,1),P},d;function E(t,e,r){for(var n=1,i=.5,a=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<i?e<a?0:1:e<a?2:3,o*=.5,i+=t<i?-o:o,a+=e<a?-o:o;return n}}},{\"array-bounds\":65,\"binary-search-bounds\":470,clamp:115,defined:164,dtype:169,\"flatten-vertex-data\":227,\"is-obj\":421,\"math-log2\":432,\"parse-rect\":459,\"pick-by-alias\":465}],472:[function(t,e,r){e.exports=function(t){for(var e=t.length,r=[],a=[],s=0;s<e;++s)for(var u=t[s],h=u.length,f=h-1,p=0;p<h;f=p++){var d=u[f],g=u[p];d[0]===g[0]?a.push([d,g]):r.push([d,g])}if(0===r.length)return 0===a.length?c:(v=l(a),function(t){return v(t[0],t[1])?0:1});var v;var m=i(r),y=function(t,e){return function(r){var i=o.le(e,r[0]);if(i<0)return 1;var a=t[i];if(!a){if(!(i>0&&e[i]===r[0]))return 1;a=t[i-1]}for(var s=1;a;){var l=a.key,c=n(r,l[0],l[1]);if(l[0][0]<l[1][0])if(c<0)a=a.left;else{if(!(c>0))return 0;s=-1,a=a.right}else if(c>0)a=a.left;else{if(!(c<0))return 0;s=1,a=a.right}}return s}}(m.slabs,m.coordinates);return 0===a.length?y:function(t,e){return function(r){return t(r[0],r[1])?0:e(r)}}(l(a),y)};var n=t(\"robust-orientation\")[3],i=t(\"slab-decomposition\"),a=t(\"interval-tree-1d\"),o=t(\"binary-search-bounds\");function s(){return!0}function l(t){for(var e={},r=0;r<t.length;++r){var n=t[r],i=n[0][0],o=n[0][1],l=n[1][1],c=[Math.min(o,l),Math.max(o,l)];i in e?e[i].push(c):e[i]=[c]}var u={},h=Object.keys(e);for(r=0;r<h.length;++r){var f=e[h[r]];u[h[r]]=a(f)}return function(t){return function(e,r){var n=t[e];return!!n&&!!n.queryPoint(r,s)}}(u)}function c(t){return 1}},{\"binary-search-bounds\":91,\"interval-tree-1d\":414,\"robust-orientation\":510,\"slab-decomposition\":526}],473:[function(t,e,r){var n,i=t(\"./lib/build-log\"),a=t(\"./lib/epsilon\"),o=t(\"./lib/intersecter\"),s=t(\"./lib/segment-chainer\"),l=t(\"./lib/segment-selector\"),c=t(\"./lib/geojson\"),u=!1,h=a();function f(t,e,r){var i=n.segments(t),a=n.segments(e),o=r(n.combine(i,a));return n.polygon(o)}n={buildLog:function(t){return!0===t?u=i():!1===t&&(u=!1),!1!==u&&u.list},epsilon:function(t){return h.epsilon(t)},segments:function(t){var e=o(!0,h,u);return t.regions.forEach(e.addRegion),{segments:e.calculate(t.inverted),inverted:t.inverted}},combine:function(t,e){return{combined:o(!1,h,u).calculate(t.segments,t.inverted,e.segments,e.inverted),inverted1:t.inverted,inverted2:e.inverted}},selectUnion:function(t){return{segments:l.union(t.combined,u),inverted:t.inverted1||t.inverted2}},selectIntersect:function(t){return{segments:l.intersect(t.combined,u),inverted:t.inverted1&&t.inverted2}},selectDifference:function(t){return{segments:l.difference(t.combined,u),inverted:t.inverted1&&!t.inverted2}},selectDifferenceRev:function(t){return{segments:l.differenceRev(t.combined,u),inverted:!t.inverted1&&t.inverted2}},selectXor:function(t){return{segments:l.xor(t.combined,u),inverted:t.inverted1!==t.inverted2}},polygon:function(t){return{regions:s(t.segments,h,u),inverted:t.inverted}},polygonFromGeoJSON:function(t){return c.toPolygon(n,t)},polygonToGeoJSON:function(t){return c.fromPolygon(n,h,t)},union:function(t,e){return f(t,e,n.selectUnion)},intersect:function(t,e){return f(t,e,n.selectIntersect)},difference:function(t,e){return f(t,e,n.selectDifference)},differenceRev:function(t,e){return f(t,e,n.selectDifferenceRev)},xor:function(t,e){return f(t,e,n.selectXor)}},\"object\"==typeof window&&(window.PolyBool=n),e.exports=n},{\"./lib/build-log\":474,\"./lib/epsilon\":475,\"./lib/geojson\":476,\"./lib/intersecter\":477,\"./lib/segment-chainer\":479,\"./lib/segment-selector\":480}],474:[function(t,e,r){e.exports=function(){var t,e=0,r=!1;function n(e,r){return t.list.push({type:e,data:r?JSON.parse(JSON.stringify(r)):void 0}),t}return t={list:[],segmentId:function(){return e++},checkIntersection:function(t,e){return n(\"check\",{seg1:t,seg2:e})},segmentChop:function(t,e){return n(\"div_seg\",{seg:t,pt:e}),n(\"chop\",{seg:t,pt:e})},statusRemove:function(t){return n(\"pop_seg\",{seg:t})},segmentUpdate:function(t){return n(\"seg_update\",{seg:t})},segmentNew:function(t,e){return n(\"new_seg\",{seg:t,primary:e})},segmentRemove:function(t){return n(\"rem_seg\",{seg:t})},tempStatus:function(t,e,r){return n(\"temp_status\",{seg:t,above:e,below:r})},rewind:function(t){return n(\"rewind\",{seg:t})},status:function(t,e,r){return n(\"status\",{seg:t,above:e,below:r})},vert:function(e){return e===r?t:(r=e,n(\"vert\",{x:e}))},log:function(t){return\"string\"!=typeof t&&(t=JSON.stringify(t,!1,\"  \")),n(\"log\",{txt:t})},reset:function(){return n(\"reset\")},selected:function(t){return n(\"selected\",{segs:t})},chainStart:function(t){return n(\"chain_start\",{seg:t})},chainRemoveHead:function(t,e){return n(\"chain_rem_head\",{index:t,pt:e})},chainRemoveTail:function(t,e){return n(\"chain_rem_tail\",{index:t,pt:e})},chainNew:function(t,e){return n(\"chain_new\",{pt1:t,pt2:e})},chainMatch:function(t){return n(\"chain_match\",{index:t})},chainClose:function(t){return n(\"chain_close\",{index:t})},chainAddHead:function(t,e){return n(\"chain_add_head\",{index:t,pt:e})},chainAddTail:function(t,e){return n(\"chain_add_tail\",{index:t,pt:e})},chainConnect:function(t,e){return n(\"chain_con\",{index1:t,index2:e})},chainReverse:function(t){return n(\"chain_rev\",{index:t})},chainJoin:function(t,e){return n(\"chain_join\",{index1:t,index2:e})},done:function(){return n(\"done\")}}}},{}],475:[function(t,e,r){e.exports=function(t){\"number\"!=typeof t&&(t=1e-10);var e={epsilon:function(e){return\"number\"==typeof e&&(t=e),t},pointAboveOrOnLine:function(e,r,n){var i=r[0],a=r[1],o=n[0],s=n[1],l=e[0];return(o-i)*(e[1]-a)-(s-a)*(l-i)>=-t},pointBetween:function(e,r,n){var i=e[1]-r[1],a=n[0]-r[0],o=e[0]-r[0],s=n[1]-r[1],l=o*a+i*s;return!(l<t||l-(a*a+s*s)>-t)},pointsSameX:function(e,r){return Math.abs(e[0]-r[0])<t},pointsSameY:function(e,r){return Math.abs(e[1]-r[1])<t},pointsSame:function(t,r){return e.pointsSameX(t,r)&&e.pointsSameY(t,r)},pointsCompare:function(t,r){return e.pointsSameX(t,r)?e.pointsSameY(t,r)?0:t[1]<r[1]?-1:1:t[0]<r[0]?-1:1},pointsCollinear:function(e,r,n){var i=e[0]-r[0],a=e[1]-r[1],o=r[0]-n[0],s=r[1]-n[1];return Math.abs(i*s-o*a)<t},linesIntersect:function(e,r,n,i){var a=r[0]-e[0],o=r[1]-e[1],s=i[0]-n[0],l=i[1]-n[1],c=a*l-o*s;if(Math.abs(c)<t)return!1;var u=e[0]-n[0],h=e[1]-n[1],f=(s*h-l*u)/c,p=(a*h-o*u)/c,d={alongA:0,alongB:0,pt:[e[0]+f*a,e[1]+f*o]};return d.alongA=f<=-t?-2:f<t?-1:f-1<=-t?0:f-1<t?1:2,d.alongB=p<=-t?-2:p<t?-1:p-1<=-t?0:p-1<t?1:2,d},pointInsideRegion:function(e,r){for(var n=e[0],i=e[1],a=r[r.length-1][0],o=r[r.length-1][1],s=!1,l=0;l<r.length;l++){var c=r[l][0],u=r[l][1];u-i>t!=o-i>t&&(a-c)*(i-u)/(o-u)+c-n>t&&(s=!s),a=c,o=u}return s}};return e}},{}],476:[function(t,e,r){var n={toPolygon:function(t,e){function r(e){if(e.length<=0)return t.segments({inverted:!1,regions:[]});function r(e){var r=e.slice(0,e.length-1);return t.segments({inverted:!1,regions:[r]})}for(var n=r(e[0]),i=1;i<e.length;i++)n=t.selectDifference(t.combine(n,r(e[i])));return n}if(\"Polygon\"===e.type)return t.polygon(r(e.coordinates));if(\"MultiPolygon\"===e.type){for(var n=t.segments({inverted:!1,regions:[]}),i=0;i<e.coordinates.length;i++)n=t.selectUnion(t.combine(n,r(e.coordinates[i])));return t.polygon(n)}throw new Error(\"PolyBool: Cannot convert GeoJSON object to PolyBool polygon\")},fromPolygon:function(t,e,r){function n(t,r){return e.pointInsideRegion([.5*(t[0][0]+t[1][0]),.5*(t[0][1]+t[1][1])],r)}function i(t){return{region:t,children:[]}}r=t.polygon(t.segments(r));var a=i(null);function o(t,e){for(var r=0;r<t.children.length;r++){if(n(e,(s=t.children[r]).region))return void o(s,e)}var a=i(e);for(r=0;r<t.children.length;r++){var s;n((s=t.children[r]).region,e)&&(a.children.push(s),t.children.splice(r,1),r--)}t.children.push(a)}for(var s=0;s<r.regions.length;s++){var l=r.regions[s];l.length<3||o(a,l)}function c(t,e){for(var r=0,n=t[t.length-1][0],i=t[t.length-1][1],a=[],o=0;o<t.length;o++){var s=t[o][0],l=t[o][1];a.push([s,l]),r+=l*n-s*i,n=s,i=l}return r<0!==e&&a.reverse(),a.push([a[0][0],a[0][1]]),a}var u=[];function h(t){var e=[c(t.region,!1)];u.push(e);for(var r=0;r<t.children.length;r++)e.push(f(t.children[r]))}function f(t){for(var e=0;e<t.children.length;e++)h(t.children[e]);return c(t.region,!0)}for(s=0;s<a.children.length;s++)h(a.children[s]);return u.length<=0?{type:\"Polygon\",coordinates:[]}:1==u.length?{type:\"Polygon\",coordinates:u[0]}:{type:\"MultiPolygon\",coordinates:u}}};e.exports=n},{}],477:[function(t,e,r){var n=t(\"./linked-list\");e.exports=function(t,e,r){function i(t,e,n){return{id:r?r.segmentId():-1,start:t,end:e,myFill:{above:n.myFill.above,below:n.myFill.below},otherFill:null}}var a=n.create();function o(t,r){a.insertBefore(t,function(n){return function(t,r,n,i,a,o){var s=e.pointsCompare(r,a);return 0!==s?s:e.pointsSame(n,o)?0:t!==i?t?1:-1:e.pointAboveOrOnLine(n,i?a:o,i?o:a)?1:-1}(t.isStart,t.pt,r,n.isStart,n.pt,n.other.pt)<0})}function s(t,e){var r=function(t,e){var r=n.node({isStart:!0,pt:t.start,seg:t,primary:e,other:null,status:null});return o(r,t.end),r}(t,e);return function(t,e,r){var i=n.node({isStart:!1,pt:e.end,seg:e,primary:r,other:t,status:null});t.other=i,o(i,t.pt)}(r,t,e),r}function l(t,e){var n=i(e,t.seg.end,t.seg);return function(t,e){r&&r.segmentChop(t.seg,e),t.other.remove(),t.seg.end=e,t.other.pt=e,o(t.other,t.pt)}(t,e),s(n,t.primary)}function c(i,o){var s=n.create();function c(t){return s.findTransition(function(r){var n,i,a,o,s,l;return n=t,i=r.ev,a=n.seg.start,o=n.seg.end,s=i.seg.start,l=i.seg.end,(e.pointsCollinear(a,s,l)?e.pointsCollinear(o,s,l)?1:e.pointAboveOrOnLine(o,s,l)?1:-1:e.pointAboveOrOnLine(a,s,l)?1:-1)>0})}function u(t,n){var i=t.seg,a=n.seg,o=i.start,s=i.end,c=a.start,u=a.end;r&&r.checkIntersection(i,a);var h=e.linesIntersect(o,s,c,u);if(!1===h){if(!e.pointsCollinear(o,s,c))return!1;if(e.pointsSame(o,u)||e.pointsSame(s,c))return!1;var f=e.pointsSame(o,c),p=e.pointsSame(s,u);if(f&&p)return n;var d=!f&&e.pointBetween(o,c,u),g=!p&&e.pointBetween(s,c,u);if(f)return g?l(n,s):l(t,u),n;d&&(p||(g?l(n,s):l(t,u)),l(n,o))}else 0===h.alongA&&(-1===h.alongB?l(t,c):0===h.alongB?l(t,h.pt):1===h.alongB&&l(t,u)),0===h.alongB&&(-1===h.alongA?l(n,o):0===h.alongA?l(n,h.pt):1===h.alongA&&l(n,s));return!1}for(var h=[];!a.isEmpty();){var f=a.getHead();if(r&&r.vert(f.pt[0]),f.isStart){r&&r.segmentNew(f.seg,f.primary);var p=c(f),d=p.before?p.before.ev:null,g=p.after?p.after.ev:null;function v(){if(d){var t=u(f,d);if(t)return t}return!!g&&u(f,g)}r&&r.tempStatus(f.seg,!!d&&d.seg,!!g&&g.seg);var m,y,x=v();if(x)t?(y=null===f.seg.myFill.below||f.seg.myFill.above!==f.seg.myFill.below)&&(x.seg.myFill.above=!x.seg.myFill.above):x.seg.otherFill=f.seg.myFill,r&&r.segmentUpdate(x.seg),f.other.remove(),f.remove();if(a.getHead()!==f){r&&r.rewind(f.seg);continue}t?(y=null===f.seg.myFill.below||f.seg.myFill.above!==f.seg.myFill.below,f.seg.myFill.below=g?g.seg.myFill.above:i,f.seg.myFill.above=y?!f.seg.myFill.below:f.seg.myFill.below):null===f.seg.otherFill&&(m=g?f.primary===g.primary?g.seg.otherFill.above:g.seg.myFill.above:f.primary?o:i,f.seg.otherFill={above:m,below:m}),r&&r.status(f.seg,!!d&&d.seg,!!g&&g.seg),f.other.status=p.insert(n.node({ev:f}))}else{var b=f.status;if(null===b)throw new Error(\"PolyBool: Zero-length segment detected; your epsilon is probably too small or too large\");if(s.exists(b.prev)&&s.exists(b.next)&&u(b.prev.ev,b.next.ev),r&&r.statusRemove(b.ev.seg),b.remove(),!f.primary){var _=f.seg.myFill;f.seg.myFill=f.seg.otherFill,f.seg.otherFill=_}h.push(f.seg)}a.getHead().remove()}return r&&r.done(),h}return t?{addRegion:function(t){for(var n,i,a,o=t[t.length-1],l=0;l<t.length;l++){n=o,o=t[l];var c=e.pointsCompare(n,o);0!==c&&s((i=c<0?n:o,a=c<0?o:n,{id:r?r.segmentId():-1,start:i,end:a,myFill:{above:null,below:null},otherFill:null}),!0)}},calculate:function(t){return c(t,!1)}}:{calculate:function(t,e,r,n){return t.forEach(function(t){s(i(t.start,t.end,t),!0)}),r.forEach(function(t){s(i(t.start,t.end,t),!1)}),c(e,n)}}}},{\"./linked-list\":478}],478:[function(t,e,r){e.exports={create:function(){var t={root:{root:!0,next:null},exists:function(e){return null!==e&&e!==t.root},isEmpty:function(){return null===t.root.next},getHead:function(){return t.root.next},insertBefore:function(e,r){for(var n=t.root,i=t.root.next;null!==i;){if(r(i))return e.prev=i.prev,e.next=i,i.prev.next=e,void(i.prev=e);n=i,i=i.next}n.next=e,e.prev=n,e.next=null},findTransition:function(e){for(var r=t.root,n=t.root.next;null!==n&&!e(n);)r=n,n=n.next;return{before:r===t.root?null:r,after:n,insert:function(t){return t.prev=r,t.next=n,r.next=t,null!==n&&(n.prev=t),t}}}};return t},node:function(t){return t.prev=null,t.next=null,t.remove=function(){t.prev.next=t.next,t.next&&(t.next.prev=t.prev),t.prev=null,t.next=null},t}}},{}],479:[function(t,e,r){e.exports=function(t,e,r){var n=[],i=[];return t.forEach(function(t){var a=t.start,o=t.end;if(e.pointsSame(a,o))console.warn(\"PolyBool: Warning: Zero-length segment detected; your epsilon is probably too small or too large\");else{r&&r.chainStart(t);for(var s={index:0,matches_head:!1,matches_pt1:!1},l={index:0,matches_head:!1,matches_pt1:!1},c=s,u=0;u<n.length;u++){var h=(v=n[u])[0],f=(v[1],v[v.length-1]);if(v[v.length-2],e.pointsSame(h,a)){if(T(u,!0,!0))break}else if(e.pointsSame(h,o)){if(T(u,!0,!1))break}else if(e.pointsSame(f,a)){if(T(u,!1,!0))break}else if(e.pointsSame(f,o)&&T(u,!1,!1))break}if(c===s)return n.push([a,o]),void(r&&r.chainNew(a,o));if(c===l){r&&r.chainMatch(s.index);var p=s.index,d=s.matches_pt1?o:a,g=s.matches_head,v=n[p],m=g?v[0]:v[v.length-1],y=g?v[1]:v[v.length-2],x=g?v[v.length-1]:v[0],b=g?v[v.length-2]:v[1];return e.pointsCollinear(y,m,d)&&(g?(r&&r.chainRemoveHead(s.index,d),v.shift()):(r&&r.chainRemoveTail(s.index,d),v.pop()),m=y),e.pointsSame(x,d)?(n.splice(p,1),e.pointsCollinear(b,x,m)&&(g?(r&&r.chainRemoveTail(s.index,m),v.pop()):(r&&r.chainRemoveHead(s.index,m),v.shift())),r&&r.chainClose(s.index),void i.push(v)):void(g?(r&&r.chainAddHead(s.index,d),v.unshift(d)):(r&&r.chainAddTail(s.index,d),v.push(d)))}var _=s.index,w=l.index;r&&r.chainConnect(_,w);var k=n[_].length<n[w].length;s.matches_head?l.matches_head?k?(A(_),M(_,w)):(A(w),M(w,_)):M(w,_):l.matches_head?M(_,w):k?(A(_),M(w,_)):(A(w),M(_,w))}function T(t,e,r){return c.index=t,c.matches_head=e,c.matches_pt1=r,c===s?(c=l,!1):(c=null,!0)}function A(t){r&&r.chainReverse(t),n[t].reverse()}function M(t,i){var a=n[t],o=n[i],s=a[a.length-1],l=a[a.length-2],c=o[0],u=o[1];e.pointsCollinear(l,s,c)&&(r&&r.chainRemoveTail(t,s),a.pop(),s=l),e.pointsCollinear(s,c,u)&&(r&&r.chainRemoveHead(i,c),o.shift()),r&&r.chainJoin(t,i),n[t]=a.concat(o),n.splice(i,1)}}),i}},{}],480:[function(t,e,r){function n(t,e,r){var n=[];return t.forEach(function(t){var i=(t.myFill.above?8:0)+(t.myFill.below?4:0)+(t.otherFill&&t.otherFill.above?2:0)+(t.otherFill&&t.otherFill.below?1:0);0!==e[i]&&n.push({id:r?r.segmentId():-1,start:t.start,end:t.end,myFill:{above:1===e[i],below:2===e[i]},otherFill:null})}),r&&r.selected(n),n}var i={union:function(t,e){return n(t,[0,2,1,0,2,2,0,0,1,0,1,0,0,0,0,0],e)},intersect:function(t,e){return n(t,[0,0,0,0,0,2,0,2,0,0,1,1,0,2,1,0],e)},difference:function(t,e){return n(t,[0,0,0,0,2,0,2,0,1,1,0,0,0,1,2,0],e)},differenceRev:function(t,e){return n(t,[0,2,1,0,0,0,1,1,0,2,0,2,0,0,0,0],e)},xor:function(t,e){return n(t,[0,2,1,0,2,0,0,1,1,0,0,2,0,1,2,0],e)}};e.exports=i},{}],481:[function(t,e,r){\"use strict\";var n=new Float64Array(4),i=new Float64Array(4),a=new Float64Array(4);e.exports=function(t,e,r,o,s){n.length<o.length&&(n=new Float64Array(o.length),i=new Float64Array(o.length),a=new Float64Array(o.length));for(var l=0;l<o.length;++l)n[l]=t[l]-o[l],i[l]=e[l]-t[l],a[l]=r[l]-t[l];var c=0,u=0,h=0,f=0,p=0,d=0;for(l=0;l<o.length;++l){var g=i[l],v=a[l],m=n[l];c+=g*g,u+=g*v,h+=v*v,f+=m*g,p+=m*v,d+=m*m}var y,x,b,_,w,k=Math.abs(c*h-u*u),T=u*p-h*f,A=u*f-c*p;if(T+A<=k)if(T<0)A<0&&f<0?(A=0,-f>=c?(T=1,y=c+2*f+d):y=f*(T=-f/c)+d):(T=0,p>=0?(A=0,y=d):-p>=h?(A=1,y=h+2*p+d):y=p*(A=-p/h)+d);else if(A<0)A=0,f>=0?(T=0,y=d):-f>=c?(T=1,y=c+2*f+d):y=f*(T=-f/c)+d;else{var M=1/k;y=(T*=M)*(c*T+u*(A*=M)+2*f)+A*(u*T+h*A+2*p)+d}else T<0?(b=h+p)>(x=u+f)?(_=b-x)>=(w=c-2*u+h)?(T=1,A=0,y=c+2*f+d):y=(T=_/w)*(c*T+u*(A=1-T)+2*f)+A*(u*T+h*A+2*p)+d:(T=0,b<=0?(A=1,y=h+2*p+d):p>=0?(A=0,y=d):y=p*(A=-p/h)+d):A<0?(b=c+f)>(x=u+p)?(_=b-x)>=(w=c-2*u+h)?(A=1,T=0,y=h+2*p+d):y=(T=1-(A=_/w))*(c*T+u*A+2*f)+A*(u*T+h*A+2*p)+d:(A=0,b<=0?(T=1,y=c+2*f+d):f>=0?(T=0,y=d):y=f*(T=-f/c)+d):(_=h+p-u-f)<=0?(T=0,A=1,y=h+2*p+d):_>=(w=c-2*u+h)?(T=1,A=0,y=c+2*f+d):y=(T=_/w)*(c*T+u*(A=1-T)+2*f)+A*(u*T+h*A+2*p)+d;var S=1-T-A;for(l=0;l<o.length;++l)s[l]=S*t[l]+T*e[l]+A*r[l];return y<0?0:y}},{}],482:[function(t,e,r){var n,i,a=e.exports={};function o(){throw new Error(\"setTimeout has not been defined\")}function s(){throw new Error(\"clearTimeout has not been defined\")}function l(t){if(n===setTimeout)return setTimeout(t,0);if((n===o||!n)&&setTimeout)return n=setTimeout,setTimeout(t,0);try{return n(t,0)}catch(e){try{return n.call(null,t,0)}catch(e){return n.call(this,t,0)}}}!function(){try{n=\"function\"==typeof setTimeout?setTimeout:o}catch(t){n=o}try{i=\"function\"==typeof clearTimeout?clearTimeout:s}catch(t){i=s}}();var c,u=[],h=!1,f=-1;function p(){h&&c&&(h=!1,c.length?u=c.concat(u):f=-1,u.length&&d())}function d(){if(!h){var t=l(p);h=!0;for(var e=u.length;e;){for(c=u,u=[];++f<e;)c&&c[f].run();f=-1,e=u.length}c=null,h=!1,function(t){if(i===clearTimeout)return clearTimeout(t);if((i===s||!i)&&clearTimeout)return i=clearTimeout,clearTimeout(t);try{i(t)}catch(e){try{return i.call(null,t)}catch(e){return i.call(this,t)}}}(t)}}function g(t,e){this.fun=t,this.array=e}function v(){}a.nextTick=function(t){var e=new Array(arguments.length-1);if(arguments.length>1)for(var r=1;r<arguments.length;r++)e[r-1]=arguments[r];u.push(new g(t,e)),1!==u.length||h||l(d)},g.prototype.run=function(){this.fun.apply(null,this.array)},a.title=\"browser\",a.browser=!0,a.env={},a.argv=[],a.version=\"\",a.versions={},a.on=v,a.addListener=v,a.once=v,a.off=v,a.removeListener=v,a.removeAllListeners=v,a.emit=v,a.prependListener=v,a.prependOnceListener=v,a.listeners=function(t){return[]},a.binding=function(t){throw new Error(\"process.binding is not supported\")},a.cwd=function(){return\"/\"},a.chdir=function(t){throw new Error(\"process.chdir is not supported\")},a.umask=function(){return 0}},{}],483:[function(t,e,r){e.exports=t(\"gl-quat/slerp\")},{\"gl-quat/slerp\":293}],484:[function(t,e,r){(function(r){for(var n=t(\"performance-now\"),i=\"undefined\"==typeof window?r:window,a=[\"moz\",\"webkit\"],o=\"AnimationFrame\",s=i[\"request\"+o],l=i[\"cancel\"+o]||i[\"cancelRequest\"+o],c=0;!s&&c<a.length;c++)s=i[a[c]+\"Request\"+o],l=i[a[c]+\"Cancel\"+o]||i[a[c]+\"CancelRequest\"+o];if(!s||!l){var u=0,h=0,f=[];s=function(t){if(0===f.length){var e=n(),r=Math.max(0,1e3/60-(e-u));u=r+e,setTimeout(function(){var t=f.slice(0);f.length=0;for(var e=0;e<t.length;e++)if(!t[e].cancelled)try{t[e].callback(u)}catch(t){setTimeout(function(){throw t},0)}},Math.round(r))}return f.push({handle:++h,callback:t,cancelled:!1}),h},l=function(t){for(var e=0;e<f.length;e++)f[e].handle===t&&(f[e].cancelled=!0)}}e.exports=function(t){return s.call(i,t)},e.exports.cancel=function(){l.apply(i,arguments)},e.exports.polyfill=function(t){t||(t=i),t.requestAnimationFrame=s,t.cancelAnimationFrame=l}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"performance-now\":462}],485:[function(t,e,r){\"use strict\";var n=t(\"big-rat/add\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/add\":75}],486:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t.length),r=0;r<t.length;++r)e[r]=n(t[r]);return e};var n=t(\"big-rat\")},{\"big-rat\":78}],487:[function(t,e,r){\"use strict\";var n=t(\"big-rat\"),i=t(\"big-rat/mul\");e.exports=function(t,e){for(var r=n(e),a=t.length,o=new Array(a),s=0;s<a;++s)o[s]=i(t[s],r);return o}},{\"big-rat\":78,\"big-rat/mul\":87}],488:[function(t,e,r){\"use strict\";var n=t(\"big-rat/sub\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/sub\":89}],489:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"compare-oriented-cell\"),a=t(\"cell-orientation\");e.exports=function(t){t.sort(i);for(var e=t.length,r=0,o=0;o<e;++o){var s=t[o],l=a(s);if(0!==l){if(r>0){var c=t[r-1];if(0===n(s,c)&&a(c)!==l){r-=1;continue}}t[r++]=s}}return t.length=r,t}},{\"cell-orientation\":112,\"compare-cell\":128,\"compare-oriented-cell\":129}],490:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\"),i=t(\"color-normalize\"),a=t(\"update-diff\"),o=t(\"pick-by-alias\"),s=t(\"object-assign\"),l=t(\"flatten-vertex-data\"),c=t(\"to-float32\"),u=c.float32,h=c.fract32;e.exports=function(t,e){\"function\"==typeof t?(e||(e={}),e.regl=t):e=t;e.length&&(e.positions=e);if(!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");var r,c,p,d,g,v,m=t._gl,y={color:\"black\",capSize:5,lineWidth:1,opacity:1,viewport:null,range:null,offset:0,count:0,bounds:null,positions:[],errors:[]},x=[];return d=t.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array(0)}),c=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),p=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),g=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),v=t.buffer({usage:\"static\",type:\"float\",data:f}),k(e),r=t({vert:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tattribute vec2 position, positionFract;\\n\\t\\tattribute vec4 error;\\n\\t\\tattribute vec4 color;\\n\\n\\t\\tattribute vec2 direction, lineOffset, capOffset;\\n\\n\\t\\tuniform vec4 viewport;\\n\\t\\tuniform float lineWidth, capSize;\\n\\t\\tuniform vec2 scale, scaleFract, translate, translateFract;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tfragColor = color / 255.;\\n\\n\\t\\t\\tvec2 pixelOffset = lineWidth * lineOffset + (capSize + lineWidth) * capOffset;\\n\\n\\t\\t\\tvec2 dxy = -step(.5, direction.xy) * error.xz + step(direction.xy, vec2(-.5)) * error.yw;\\n\\n\\t\\t\\tvec2 position = position + dxy;\\n\\n\\t\\t\\tvec2 pos = (position + translate) * scale\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scale\\n\\t\\t\\t\\t+ (position + translate) * scaleFract\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scaleFract;\\n\\n\\t\\t\\tpos += pixelOffset / viewport.zw;\\n\\n\\t\\t\\tgl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\t\\t}\\n\\t\\t\",frag:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tuniform float opacity;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tgl_FragColor = fragColor;\\n\\t\\t\\tgl_FragColor.a *= opacity;\\n\\t\\t}\\n\\t\\t\",uniforms:{range:t.prop(\"range\"),lineWidth:t.prop(\"lineWidth\"),capSize:t.prop(\"capSize\"),opacity:t.prop(\"opacity\"),scale:t.prop(\"scale\"),translate:t.prop(\"translate\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{color:{buffer:d,offset:function(t,e){return 4*e.offset},divisor:1},position:{buffer:c,offset:function(t,e){return 8*e.offset},divisor:1},positionFract:{buffer:p,offset:function(t,e){return 8*e.offset},divisor:1},error:{buffer:g,offset:function(t,e){return 16*e.offset},divisor:1},direction:{buffer:v,stride:24,offset:0},lineOffset:{buffer:v,stride:24,offset:8},capOffset:{buffer:v,stride:24,offset:16}},primitive:\"triangles\",blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:!1,instances:t.prop(\"count\"),count:f.length}),s(b,{update:k,draw:_,destroy:T,regl:t,gl:m,canvas:m.canvas,groups:x}),b;function b(t){t?k(t):null===t&&T(),_()}function _(e){if(\"number\"==typeof e)return w(e);e&&!Array.isArray(e)&&(e=[e]),t._refresh(),x.forEach(function(t,r){t&&(e&&(e[r]?t.draw=!0:t.draw=!1),t.draw?w(r):t.draw=!0)})}function w(t){\"number\"==typeof t&&(t=x[t]),null!=t&&t&&t.count&&t.color&&t.opacity&&t.positions&&t.positions.length>1&&(t.scaleRatio=[t.scale[0]*t.viewport.width,t.scale[1]*t.viewport.height],r(t),t.after&&t.after(t))}function k(t){if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var e=0,r=0;if(b.groups=x=t.map(function(t,c){var u=x[c];return t?(\"function\"==typeof t?t={after:t}:\"number\"==typeof t[0]&&(t={positions:t}),t=o(t,{color:\"color colors fill\",capSize:\"capSize cap capsize cap-size\",lineWidth:\"lineWidth line-width width line thickness\",opacity:\"opacity alpha\",range:\"range dataBox\",viewport:\"viewport viewBox\",errors:\"errors error\",positions:\"positions position data points\"}),u||(x[c]=u={id:c,scale:null,translate:null,scaleFract:null,translateFract:null,draw:!0},t=s({},y,t)),a(u,t,[{lineWidth:function(t){return.5*+t},capSize:function(t){return.5*+t},opacity:parseFloat,errors:function(t){return t=l(t),r+=t.length,t},positions:function(t,r){return t=l(t,\"float64\"),r.count=Math.floor(t.length/2),r.bounds=n(t,2),r.offset=e,e+=r.count,t}},{color:function(t,e){var r=e.count;if(t||(t=\"transparent\"),!Array.isArray(t)||\"number\"==typeof t[0]){var n=t;t=Array(r);for(var a=0;a<r;a++)t[a]=n}if(t.length<r)throw Error(\"Not enough colors\");for(var o=new Uint8Array(4*r),s=0;s<r;s++){var l=i(t[s],\"uint8\");o.set(l,4*s)}return o},range:function(t,e,r){var n=e.bounds;return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=h(e.scale),e.translateFract=h(e.translate),t},viewport:function(t){var e;return Array.isArray(t)?e={x:t[0],y:t[1],width:t[2]-t[0],height:t[3]-t[1]}:t?(e={x:t.x||t.left||0,y:t.y||t.top||0},t.right?e.width=t.right-e.x:e.width=t.w||t.width||0,t.bottom?e.height=t.bottom-e.y:e.height=t.h||t.height||0):e={x:0,y:0,width:m.drawingBufferWidth,height:m.drawingBufferHeight},e}}]),u):u}),e||r){var f=x.reduce(function(t,e,r){return t+(e?e.count:0)},0),v=new Float64Array(2*f),_=new Uint8Array(4*f),w=new Float32Array(4*f);x.forEach(function(t,e){if(t){var r=t.positions,n=t.count,i=t.offset,a=t.color,o=t.errors;n&&(_.set(a,4*i),w.set(o,4*i),v.set(r,2*i))}}),c(u(v)),p(h(v)),d(_),g(w)}}}function T(){c.destroy(),p.destroy(),d.destroy(),g.destroy(),v.destroy()}};var f=[[1,0,0,1,0,0],[1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,1,0,0],[1,0,0,1,0,0],[1,0,-1,0,0,1],[1,0,-1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,1],[1,0,-1,0,0,1],[-1,0,-1,0,0,1],[-1,0,-1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,1],[-1,0,-1,0,0,1],[0,1,1,0,0,0],[0,1,-1,0,0,0],[0,-1,-1,0,0,0],[0,-1,-1,0,0,0],[0,1,1,0,0,0],[0,-1,1,0,0,0],[0,1,0,-1,1,0],[0,1,0,-1,-1,0],[0,1,0,1,-1,0],[0,1,0,1,1,0],[0,1,0,-1,1,0],[0,1,0,1,-1,0],[0,-1,0,-1,1,0],[0,-1,0,-1,-1,0],[0,-1,0,1,-1,0],[0,-1,0,1,1,0],[0,-1,0,-1,1,0],[0,-1,0,1,-1,0]]},{\"array-bounds\":65,\"color-normalize\":120,\"flatten-vertex-data\":227,\"object-assign\":454,\"pick-by-alias\":465,\"to-float32\":538,\"update-diff\":549}],491:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\"),i=t(\"array-bounds\"),a=t(\"object-assign\"),o=t(\"glslify\"),s=t(\"pick-by-alias\"),l=t(\"flatten-vertex-data\"),c=t(\"earcut\"),u=t(\"array-normalize\"),h=t(\"to-float32\"),f=h.float32,p=h.fract32,d=t(\"es6-weak-map\"),g=t(\"parse-rect\");function v(t,e){if(!(this instanceof v))return new v(t,e);if(\"function\"==typeof t?(e||(e={}),e.regl=t):e=t,e.length&&(e.positions=e),!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");this.gl=t._gl,this.regl=t,this.passes=[],this.shaders=v.shaders.has(t)?v.shaders.get(t):v.shaders.set(t,v.createShaders(t)).get(t),this.update(e)}e.exports=v,v.dashMult=2,v.maxPatternLength=256,v.precisionThreshold=3e6,v.maxPoints=1e4,v.maxLines=2048,v.shaders=new d,v.createShaders=function(t){var e,r=t.buffer({usage:\"static\",type:\"float\",data:[0,1,0,0,1,1,1,0]}),n={primitive:\"triangle strip\",instances:t.prop(\"count\"),count:4,offset:0,uniforms:{miterMode:function(t,e){return\"round\"===e.join?2:1},miterLimit:t.prop(\"miterLimit\"),scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),thickness:t.prop(\"thickness\"),dashPattern:t.prop(\"dashTexture\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),dashSize:t.prop(\"dashLength\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]},depth:t.prop(\"depth\")},blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:function(t,e){return!e.overlay}},stencil:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\")},i=t(a({vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, aCoordFract, bCoordFract;\\nattribute vec4 color;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvec2 project(vec2 position, vec2 positionFract, vec2 scale, vec2 scaleFract, vec2 translate, vec2 translateFract) {\\n\\t// the order is important\\n\\treturn position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n}\\n\\nvoid main() {\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineOffset = lineTop * 2. - 1.;\\n\\n\\tvec2 diff = (bCoord + bCoordFract - aCoord - aCoordFract);\\n\\ttangent = normalize(diff * scale * viewport.zw);\\n\\tvec2 normal = vec2(-tangent.y, tangent.x);\\n\\n\\tvec2 position = project(aCoord, aCoordFract, scale, scaleFract, translate, translateFract) * lineStart\\n\\t\\t+ project(bCoord, bCoordFract, scale, scaleFract, translate, translateFract) * lineEnd\\n\\n\\t\\t+ thickness * normal * .5 * lineOffset / viewport.zw;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\n\\nuniform float dashSize, pixelRatio, thickness, opacity, id;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvoid main() {\\n\\tfloat alpha = 1.;\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},aCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8,divisor:1},bCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:16,divisor:1},color:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1}}},n));try{e=t(a({cull:{enable:!0,face:\"back\"},vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, nextCoord, prevCoord;\\nattribute vec4 aColor, bColor;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, translate;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\nuniform float miterLimit, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 tangent;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nconst float REVERSE_THRESHOLD = -.875;\\nconst float MIN_DIFF = 1e-6;\\n\\n// TODO: possible optimizations: avoid overcalculating all for vertices and calc just one instead\\n// TODO: precalculate dot products, normalize things beforehead etc.\\n// TODO: refactor to rectangular algorithm\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nbool isNaN( float val ){\\n  return ( val < 0.0 || 0.0 < val || val == 0.0 ) ? false : true;\\n}\\n\\nvoid main() {\\n\\tvec2 aCoord = aCoord, bCoord = bCoord, prevCoord = prevCoord, nextCoord = nextCoord;\\n\\n  vec2 adjustedScale;\\n  adjustedScale.x = (abs(scale.x) < MIN_DIFF) ? MIN_DIFF : scale.x;\\n  adjustedScale.y = (abs(scale.y) < MIN_DIFF) ? MIN_DIFF : scale.y;\\n\\n  vec2 scaleRatio = adjustedScale * viewport.zw;\\n\\tvec2 normalWidth = thickness / scaleRatio;\\n\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineBot = 1. - lineTop;\\n\\n\\tfragColor = (lineStart * aColor + lineEnd * bColor) / 255.;\\n\\n\\tif (isNaN(aCoord.x) || isNaN(aCoord.y) || isNaN(bCoord.x) || isNaN(bCoord.y)) return;\\n\\n\\tif (aCoord == prevCoord) prevCoord = aCoord + normalize(bCoord - aCoord);\\n\\tif (bCoord == nextCoord) nextCoord = bCoord - normalize(bCoord - aCoord);\\n\\n\\tvec2 prevDiff = aCoord - prevCoord;\\n\\tvec2 currDiff = bCoord - aCoord;\\n\\tvec2 nextDiff = nextCoord - bCoord;\\n\\n\\tvec2 prevTangent = normalize(prevDiff * scaleRatio);\\n\\tvec2 currTangent = normalize(currDiff * scaleRatio);\\n\\tvec2 nextTangent = normalize(nextDiff * scaleRatio);\\n\\n\\tvec2 prevNormal = vec2(-prevTangent.y, prevTangent.x);\\n\\tvec2 currNormal = vec2(-currTangent.y, currTangent.x);\\n\\tvec2 nextNormal = vec2(-nextTangent.y, nextTangent.x);\\n\\n\\tvec2 startJoinDirection = normalize(prevTangent - currTangent);\\n\\tvec2 endJoinDirection = normalize(currTangent - nextTangent);\\n\\n\\t// collapsed/unidirectional segment cases\\n\\t// FIXME: there should be more elegant solution\\n\\tvec2 prevTanDiff = abs(prevTangent - currTangent);\\n\\tvec2 nextTanDiff = abs(nextTangent - currTangent);\\n\\tif (max(prevTanDiff.x, prevTanDiff.y) < MIN_DIFF) {\\n\\t\\tstartJoinDirection = currNormal;\\n\\t}\\n\\tif (max(nextTanDiff.x, nextTanDiff.y) < MIN_DIFF) {\\n\\t\\tendJoinDirection = currNormal;\\n\\t}\\n\\tif (aCoord == bCoord) {\\n\\t\\tendJoinDirection = startJoinDirection;\\n\\t\\tcurrNormal = prevNormal;\\n\\t\\tcurrTangent = prevTangent;\\n\\t}\\n\\n\\ttangent = currTangent;\\n\\n\\t//calculate join shifts relative to normals\\n\\tfloat startJoinShift = dot(currNormal, startJoinDirection);\\n\\tfloat endJoinShift = dot(currNormal, endJoinDirection);\\n\\n\\tfloat startMiterRatio = abs(1. / startJoinShift);\\n\\tfloat endMiterRatio = abs(1. / endJoinShift);\\n\\n\\tvec2 startJoin = startJoinDirection * startMiterRatio;\\n\\tvec2 endJoin = endJoinDirection * endMiterRatio;\\n\\n\\tvec2 startTopJoin, startBotJoin, endTopJoin, endBotJoin;\\n\\tstartTopJoin = sign(startJoinShift) * startJoin * .5;\\n\\tstartBotJoin = -startTopJoin;\\n\\n\\tendTopJoin = sign(endJoinShift) * endJoin * .5;\\n\\tendBotJoin = -endTopJoin;\\n\\n\\tvec2 aTopCoord = aCoord + normalWidth * startTopJoin;\\n\\tvec2 bTopCoord = bCoord + normalWidth * endTopJoin;\\n\\tvec2 aBotCoord = aCoord + normalWidth * startBotJoin;\\n\\tvec2 bBotCoord = bCoord + normalWidth * endBotJoin;\\n\\n\\t//miter anti-clipping\\n\\tfloat baClipping = distToLine(bCoord, aCoord, aBotCoord) / dot(normalize(normalWidth * endBotJoin), normalize(normalWidth.yx * vec2(-startBotJoin.y, startBotJoin.x)));\\n\\tfloat abClipping = distToLine(aCoord, bCoord, bTopCoord) / dot(normalize(normalWidth * startBotJoin), normalize(normalWidth.yx * vec2(-endBotJoin.y, endBotJoin.x)));\\n\\n\\t//prevent close to reverse direction switch\\n\\tbool prevReverse = dot(currTangent, prevTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, prevNormal)) * min(length(prevDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\tbool nextReverse = dot(currTangent, nextTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, nextNormal)) * min(length(nextDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\n\\tif (prevReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * startJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / startMiterRatio, 1.);\\n\\t\\taBotCoord = aCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\taTopCoord = aCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!nextReverse && baClipping > 0. && baClipping < length(normalWidth * endBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\tbTopCoord -= normalWidth * endTopJoin;\\n\\t\\tbTopCoord += normalize(endTopJoin * normalWidth) * baClipping;\\n\\t}\\n\\n\\tif (nextReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * endJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / endMiterRatio, 1.);\\n\\t\\tbBotCoord = bCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\tbTopCoord = bCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!prevReverse && abClipping > 0. && abClipping < length(normalWidth * startBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\taBotCoord -= normalWidth * startBotJoin;\\n\\t\\taBotCoord += normalize(startBotJoin * normalWidth) * abClipping;\\n\\t}\\n\\n\\tvec2 aTopPosition = (aTopCoord) * adjustedScale + translate;\\n\\tvec2 aBotPosition = (aBotCoord) * adjustedScale + translate;\\n\\n\\tvec2 bTopPosition = (bTopCoord) * adjustedScale + translate;\\n\\tvec2 bBotPosition = (bBotCoord) * adjustedScale + translate;\\n\\n\\t//position is normalized 0..1 coord on the screen\\n\\tvec2 position = (aTopPosition * lineTop + aBotPosition * lineBot) * lineStart + (bTopPosition * lineTop + bBotPosition * lineBot) * lineEnd;\\n\\n\\tstartCoord = aCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\tendCoord = bCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\n\\tgl_Position = vec4(position  * 2.0 - 1.0, depth, 1);\\n\\n\\tenableStartMiter = step(dot(currTangent, prevTangent), .5);\\n\\tenableEndMiter = step(dot(currTangent, nextTangent), .5);\\n\\n\\t//bevel miter cutoffs\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n\\n\\t//round miter cutoffs\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * abs(dot(startJoinDirection, currNormal)) * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * abs(dot(endJoinDirection, currNormal)) * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\nuniform float dashSize, pixelRatio, thickness, opacity, id, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nvoid main() {\\n\\tfloat alpha = 1., distToStart, distToEnd;\\n\\tfloat cutoff = thickness * .5;\\n\\n\\t//bevel miter\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToStart + 1., 0.), 1.);\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToEnd + 1., 0.), 1.);\\n\\t\\t}\\n\\t}\\n\\n\\t// round miter\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - startCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - endCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\t}\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1},bColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:4,divisor:1},prevCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:0,divisor:1},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},nextCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:24,divisor:1}}},n))}catch(t){e=i}return{fill:t({primitive:\"triangle\",elements:function(t,e){return e.triangles},offset:0,vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position, positionFract;\\n\\nuniform vec4 color;\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio, id;\\nuniform vec4 viewport;\\nuniform float opacity;\\n\\nvarying vec4 fragColor;\\n\\nconst float MAX_LINES = 256.;\\n\\nvoid main() {\\n\\tfloat depth = (MAX_LINES - 4. - id) / (MAX_LINES);\\n\\n\\tvec2 position = position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n\\tfragColor.a *= opacity;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n\\tgl_FragColor = fragColor;\\n}\\n\"]),uniforms:{scale:t.prop(\"scale\"),color:t.prop(\"fill\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{position:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8},positionFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8}},blend:n.blend,depth:{enable:!1},scissor:n.scissor,stencil:n.stencil,viewport:n.viewport}),rect:i,miter:e}},v.defaults={dashes:null,join:\"miter\",miterLimit:1,thickness:10,cap:\"square\",color:\"black\",opacity:1,overlay:!1,viewport:null,range:null,close:!1,fill:null},v.prototype.render=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];e.length&&(t=this).update.apply(t,e),this.draw()},v.prototype.draw=function(){for(var t=this,e=[],r=arguments.length;r--;)e[r]=arguments[r];return(e.length?e:this.passes).forEach(function(e,r){var n;if(e&&Array.isArray(e))return(n=t).draw.apply(n,e);\"number\"==typeof e&&(e=t.passes[e]),e&&e.count>1&&e.opacity&&(t.regl._refresh(),e.fill&&e.triangles&&e.triangles.length>2&&t.shaders.fill(e),e.thickness&&(e.scale[0]*e.viewport.width>v.precisionThreshold||e.scale[1]*e.viewport.height>v.precisionThreshold?t.shaders.rect(e):\"rect\"===e.join||!e.join&&(e.thickness<=2||e.count>=v.maxPoints)?t.shaders.rect(e):t.shaders.miter(e)))}),this},v.prototype.update=function(t){var e=this;if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var r=this.regl,o=this.gl;if(t.forEach(function(t,h){var d=e.passes[h];if(void 0!==t)if(null!==t){if(\"number\"==typeof t[0]&&(t={positions:t}),t=s(t,{positions:\"positions points data coords\",thickness:\"thickness lineWidth lineWidths line-width linewidth width stroke-width strokewidth strokeWidth\",join:\"lineJoin linejoin join type mode\",miterLimit:\"miterlimit miterLimit\",dashes:\"dash dashes dasharray dash-array dashArray\",color:\"color colour stroke colors colours stroke-color strokeColor\",fill:\"fill fill-color fillColor\",opacity:\"alpha opacity\",overlay:\"overlay crease overlap intersect\",close:\"closed close closed-path closePath\",range:\"range dataBox\",viewport:\"viewport viewBox\",hole:\"holes hole hollow\"}),d||(e.passes[h]=d={id:h,scale:null,scaleFract:null,translate:null,translateFract:null,count:0,hole:[],depth:0,dashLength:1,dashTexture:r.texture({channels:1,data:new Uint8Array([255]),width:1,height:1,mag:\"linear\",min:\"linear\"}),colorBuffer:r.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array}),positionBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),positionFractBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array})},t=a({},v.defaults,t)),null!=t.thickness&&(d.thickness=parseFloat(t.thickness)),null!=t.opacity&&(d.opacity=parseFloat(t.opacity)),null!=t.miterLimit&&(d.miterLimit=parseFloat(t.miterLimit)),null!=t.overlay&&(d.overlay=!!t.overlay,h<v.maxLines&&(d.depth=2*(v.maxLines-1-h%v.maxLines)/v.maxLines-1)),null!=t.join&&(d.join=t.join),null!=t.hole&&(d.hole=t.hole),null!=t.fill&&(d.fill=t.fill?n(t.fill,\"uint8\"):null),null!=t.viewport&&(d.viewport=g(t.viewport)),d.viewport||(d.viewport=g([o.drawingBufferWidth,o.drawingBufferHeight])),null!=t.close&&(d.close=t.close),null===t.positions&&(t.positions=[]),t.positions){var m,y;if(t.positions.x&&t.positions.y){var x=t.positions.x,b=t.positions.y;y=d.count=Math.max(x.length,b.length),m=new Float64Array(2*y);for(var _=0;_<y;_++)m[2*_]=x[_],m[2*_+1]=b[_]}else m=l(t.positions,\"float64\"),y=d.count=Math.floor(m.length/2);var w=d.bounds=i(m,2);if(d.fill){for(var k=[],T={},A=0,M=0,S=0,E=d.count;M<E;M++){var C=m[2*M],L=m[2*M+1];isNaN(C)||isNaN(L)||null==C||null==L?(C=m[2*A],L=m[2*A+1],T[M]=A):A=M,k[S++]=C,k[S++]=L}for(var P=c(k,d.hole||[]),O=0,z=P.length;O<z;O++)null!=T[P[O]]&&(P[O]=T[P[O]]);d.triangles=P}var I=new Float64Array(m);u(I,2,w);var D=new Float64Array(2*y+6);d.close?m[0]===m[2*y-2]&&m[1]===m[2*y-1]?(D[0]=I[2*y-4],D[1]=I[2*y-3]):(D[0]=I[2*y-2],D[1]=I[2*y-1]):(D[0]=I[0],D[1]=I[1]),D.set(I,2),d.close?m[0]===m[2*y-2]&&m[1]===m[2*y-1]?(D[2*y+2]=I[2],D[2*y+3]=I[3],d.count-=1):(D[2*y+2]=I[0],D[2*y+3]=I[1],D[2*y+4]=I[2],D[2*y+5]=I[3]):(D[2*y+2]=I[2*y-2],D[2*y+3]=I[2*y-1],D[2*y+4]=I[2*y-2],D[2*y+5]=I[2*y-1]),d.positionBuffer(f(D)),d.positionFractBuffer(p(D))}if(t.range?d.range=t.range:d.range||(d.range=d.bounds),(t.range||t.positions)&&d.count){var R=d.bounds,F=R[2]-R[0],B=R[3]-R[1],N=d.range[2]-d.range[0],j=d.range[3]-d.range[1];d.scale=[F/N,B/j],d.translate=[-d.range[0]/N+R[0]/N||0,-d.range[1]/j+R[1]/j||0],d.scaleFract=p(d.scale),d.translateFract=p(d.translate)}if(t.dashes){var U,V=0;if(!t.dashes||t.dashes.length<2)V=1,U=new Uint8Array([255,255,255,255,255,255,255,255]);else{V=0;for(var q=0;q<t.dashes.length;++q)V+=t.dashes[q];U=new Uint8Array(V*v.dashMult);for(var H=0,G=255,Y=0;Y<2;Y++)for(var W=0;W<t.dashes.length;++W){for(var X=0,Z=t.dashes[W]*v.dashMult*.5;X<Z;++X)U[H++]=G;G^=255}}d.dashLength=V,d.dashTexture({channels:1,data:U,width:U.length,height:1,mag:\"linear\",min:\"linear\"},0,0)}if(t.color){var J=d.count,K=t.color;K||(K=\"transparent\");var $=new Uint8Array(4*J+4);if(Array.isArray(K)&&\"number\"!=typeof K[0]){for(var Q=0;Q<J;Q++){var tt=n(K[Q],\"uint8\");$.set(tt,4*Q)}$.set(n(K[0],\"uint8\"),4*J)}else for(var et=n(K,\"uint8\"),rt=0;rt<J+1;rt++)$.set(et,4*rt);d.colorBuffer({usage:\"dynamic\",type:\"uint8\",data:$})}}else e.passes[h]=null}),t.length<this.passes.length){for(var h=t.length;h<this.passes.length;h++){var d=e.passes[h];d&&(d.colorBuffer.destroy(),d.positionBuffer.destroy(),d.dashTexture.destroy())}this.passes.length=t.length}for(var m=[],y=0;y<this.passes.length;y++)null!==e.passes[y]&&m.push(e.passes[y]);return this.passes=m,this}},v.prototype.destroy=function(){return this.passes.forEach(function(t){t.colorBuffer.destroy(),t.positionBuffer.destroy(),t.dashTexture.destroy()}),this.passes.length=0,this}},{\"array-bounds\":65,\"array-normalize\":66,\"color-normalize\":120,earcut:492,\"es6-weak-map\":493,\"flatten-vertex-data\":227,glslify:409,\"object-assign\":454,\"parse-rect\":459,\"pick-by-alias\":465,\"to-float32\":538}],492:[function(t,e,r){\"use strict\";function n(t,e,r){r=r||2;var n,s,l,c,u,p,g,v=e&&e.length,m=v?e[0]*r:t.length,y=i(t,0,m,r,!0),x=[];if(!y||y.next===y.prev)return x;if(v&&(y=function(t,e,r,n){var o,s,l,c,u,p=[];for(o=0,s=e.length;o<s;o++)l=e[o]*n,c=o<s-1?e[o+1]*n:t.length,(u=i(t,l,c,n,!1))===u.next&&(u.steiner=!0),p.push(d(u));for(p.sort(h),o=0;o<p.length;o++)f(p[o],r),r=a(r,r.next);return r}(t,e,y,r)),t.length>80*r){n=l=t[0],s=c=t[1];for(var b=r;b<m;b+=r)(u=t[b])<n&&(n=u),(p=t[b+1])<s&&(s=p),u>l&&(l=u),p>c&&(c=p);g=0!==(g=Math.max(l-n,c-s))?1/g:0}return o(y,x,r,n,s,g),x}function i(t,e,r,n,i){var a,o;if(i===A(t,e,r,n)>0)for(a=e;a<r;a+=n)o=w(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=w(a,t[a],t[a+1],o);return o&&y(o,o.next)&&(k(o),o=o.next),o}function a(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!y(n,n.next)&&0!==m(n.prev,n,n.next))n=n.next;else{if(k(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function o(t,e,r,n,i,h,f){if(t){!f&&h&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=p(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,h);for(var d,g,v=t;t.prev!==t.next;)if(d=t.prev,g=t.next,h?l(t,n,i,h):s(t))e.push(d.i/r),e.push(t.i/r),e.push(g.i/r),k(t),t=g.next,v=g.next;else if((t=g)===v){f?1===f?o(t=c(t,e,r),e,r,n,i,h,2):2===f&&u(t,e,r,n,i,h):o(a(t),e,r,n,i,h,1);break}}}function s(t){var e=t.prev,r=t,n=t.next;if(m(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(g(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&m(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function l(t,e,r,n){var i=t.prev,a=t,o=t.next;if(m(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,h=p(s,l,e,r,n),f=p(c,u,e,r,n),d=t.prevZ,v=t.nextZ;d&&d.z>=h&&v&&v.z<=f;){if(d!==t.prev&&d!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&m(d.prev,d,d.next)>=0)return!1;if(d=d.prevZ,v!==t.prev&&v!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,v.x,v.y)&&m(v.prev,v,v.next)>=0)return!1;v=v.nextZ}for(;d&&d.z>=h;){if(d!==t.prev&&d!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&m(d.prev,d,d.next)>=0)return!1;d=d.prevZ}for(;v&&v.z<=f;){if(v!==t.prev&&v!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,v.x,v.y)&&m(v.prev,v,v.next)>=0)return!1;v=v.nextZ}return!0}function c(t,e,r){var n=t;do{var i=n.prev,a=n.next.next;!y(i,a)&&x(i,n,n.next,a)&&b(i,a)&&b(a,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(a.i/r),k(n),k(n.next),n=t=a),n=n.next}while(n!==t);return n}function u(t,e,r,n,i,s){var l=t;do{for(var c=l.next.next;c!==l.prev;){if(l.i!==c.i&&v(l,c)){var u=_(l,c);return l=a(l,l.next),u=a(u,u.next),o(l,e,r,n,i,s),void o(u,e,r,n,i,s)}c=c.next}l=l.next}while(l!==t)}function h(t,e){return t.x-e.x}function f(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r.prev;var l,c=r,u=r.x,h=r.y,f=1/0;n=r.next;for(;n!==c;)i>=n.x&&n.x>=u&&i!==n.x&&g(a<h?i:o,a,u,h,a<h?o:i,a,n.x,n.y)&&((l=Math.abs(a-n.y)/(i-n.x))<f||l===f&&n.x>r.x)&&b(n,t)&&(r=n,f=l),n=n.next;return r}(t,e)){var r=_(e,t);a(r,r.next)}}function p(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function d(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function g(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function v(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&x(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&b(t,e)&&b(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)}function m(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function y(t,e){return t.x===e.x&&t.y===e.y}function x(t,e,r,n){return!!(y(t,e)&&y(r,n)||y(t,n)&&y(r,e))||m(t,e,r)>0!=m(t,e,n)>0&&m(r,n,t)>0!=m(r,n,e)>0}function b(t,e){return m(t.prev,t,t.next)<0?m(t,e,t.next)>=0&&m(t,t.prev,e)>=0:m(t,e,t.prev)<0||m(t,t.next,e)<0}function _(t,e){var r=new T(t.i,t.x,t.y),n=new T(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function w(t,e,r,n){var i=new T(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function k(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function T(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function A(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}e.exports=n,e.exports.default=n,n.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(A(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(A(t,c,u,r))}var h=0;for(s=0;s<n.length;s+=3){var f=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;h+=Math.abs((t[f]-t[d])*(t[p+1]-t[f+1])-(t[f]-t[p])*(t[d+1]-t[f+1]))}return 0===o&&0===h?0:Math.abs((h-o)/o)},n.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r}},{}],493:[function(t,e,r){arguments[4][318][0].apply(r,arguments)},{\"./is-implemented\":494,\"./polyfill\":496,dup:318}],494:[function(t,e,r){arguments[4][319][0].apply(r,arguments)},{dup:319}],495:[function(t,e,r){arguments[4][320][0].apply(r,arguments)},{dup:320}],496:[function(t,e,r){arguments[4][321][0].apply(r,arguments)},{\"./is-native-implemented\":495,d:151,dup:321,\"es5-ext/object/is-value\":194,\"es5-ext/object/set-prototype-of\":200,\"es5-ext/object/valid-object\":204,\"es5-ext/object/valid-value\":205,\"es5-ext/string/random-uniq\":210,\"es6-iterator/for-of\":212,\"es6-iterator/get\":213,\"es6-symbol\":219}],497:[function(t,e,r){\"use strict\";function n(t,e){return function(t){if(Array.isArray(t))return t}(t)||function(t,e){var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{n||null==s.return||s.return()}finally{if(i)throw a}}return r}(t,e)||function(){throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")}()}function i(t){return function(t){if(Array.isArray(t)){for(var e=0,r=new Array(t.length);e<t.length;e++)r[e]=t[e];return r}}(t)||function(t){if(Symbol.iterator in Object(t)||\"[object Arguments]\"===Object.prototype.toString.call(t))return Array.from(t)}(t)||function(){throw new TypeError(\"Invalid attempt to spread non-iterable instance\")}()}var a=t(\"color-normalize\"),o=t(\"array-bounds\"),s=t(\"color-id\"),l=t(\"point-cluster\"),c=t(\"object-assign\"),u=t(\"glslify\"),h=t(\"pick-by-alias\"),f=t(\"update-diff\"),p=t(\"flatten-vertex-data\"),d=t(\"is-iexplorer\"),g=t(\"to-float32\"),v=t(\"parse-rect\"),m=y;function y(t,e){var r=this;if(!(this instanceof y))return new y(t,e);\"function\"==typeof t?(e||(e={}),e.regl=t):(e=t,t=null),e&&e.length&&(e.positions=e);var n,i=(t=e.regl)._gl,a=[];this.tooManyColors=d,n=t.texture({data:new Uint8Array(1020),width:255,height:1,type:\"uint8\",format:\"rgba\",wrapS:\"clamp\",wrapT:\"clamp\",mag:\"nearest\",min:\"nearest\"}),c(this,{regl:t,gl:i,groups:[],markerCache:[null],markerTextures:[null],palette:a,paletteIds:{},paletteTexture:n,maxColors:255,maxSize:100,canvas:i.canvas}),this.update(e);var o={uniforms:{pixelRatio:t.context(\"pixelRatio\"),palette:n,paletteSize:function(t,e){return[r.tooManyColors?0:255,n.height]},scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translate:t.prop(\"translate\"),translateFract:t.prop(\"translateFract\"),opacity:t.prop(\"opacity\"),marker:t.prop(\"markerTexture\")},attributes:{x:function(t,e){return e.xAttr||{buffer:e.positionBuffer,stride:8,offset:0}},y:function(t,e){return e.yAttr||{buffer:e.positionBuffer,stride:8,offset:4}},xFract:function(t,e){return e.xAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:0}},yFract:function(t,e){return e.yAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:4}},size:function(t,e){return e.size.length?{buffer:e.sizeBuffer,stride:2,offset:0}:{constant:[Math.round(255*e.size/r.maxSize)]}},borderSize:function(t,e){return e.borderSize.length?{buffer:e.sizeBuffer,stride:2,offset:1}:{constant:[Math.round(255*e.borderSize/r.maxSize)]}},colorId:function(t,e){return e.color.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:0}:{constant:r.tooManyColors?a.slice(4*e.color,4*e.color+4):[e.color]}},borderColorId:function(t,e){return e.borderColor.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:r.tooManyColors?4:2}:{constant:r.tooManyColors?a.slice(4*e.borderColor,4*e.borderColor+4):[e.borderColor]}},isActive:function(t,e){return!0===e.activation?{constant:[1]}:e.activation?e.activation:{constant:[0]}}},blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:{enable:!1},depth:{enable:!1},elements:t.prop(\"elements\"),count:t.prop(\"count\"),offset:t.prop(\"offset\"),primitive:\"points\"},s=c({},o);s.frag=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nuniform sampler2D marker;\\nuniform float pixelRatio, opacity;\\n\\nfloat smoothStep(float x, float y) {\\n  return 1.0 / (1.0 + exp(50.0*(x - y)));\\n}\\n\\nvoid main() {\\n  float dist = texture2D(marker, gl_PointCoord).r, delta = fragWidth;\\n\\n  // max-distance alpha\\n  if (dist < 0.003) discard;\\n\\n  // null-border case\\n  if (fragBorderColorLevel == fragColorLevel || fragBorderColor.a == 0.) {\\n    float colorAmt = smoothstep(.5 - delta, .5 + delta, dist);\\n    gl_FragColor = vec4(fragColor.rgb, colorAmt * fragColor.a * opacity);\\n  }\\n  else {\\n    float borderColorAmt = smoothstep(fragBorderColorLevel - delta, fragBorderColorLevel + delta, dist);\\n    float colorAmt = smoothstep(fragColorLevel - delta, fragColorLevel + delta, dist);\\n\\n    vec4 color = fragBorderColor;\\n    color.a *= borderColorAmt;\\n    color = mix(color, fragColor, colorAmt);\\n    color.a *= opacity;\\n\\n    gl_FragColor = color;\\n  }\\n\\n}\\n\"]),s.vert=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract, paletteSize;\\nuniform float pixelRatio;\\nuniform sampler2D palette;\\n\\nconst float maxSize = 100.;\\nconst float borderLevel = .5;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragPointSize, fragBorderRadius, fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = 2. * size * pixelRatio;\\n  fragPointSize = size * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\n  fragColor = color;\\n  fragBorderColor = borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n\\n  fragBorderColorLevel = clamp(borderLevel - borderLevel * borderSize / size, 0., 1.);\\n  fragColorLevel = clamp(borderLevel + (1. - borderLevel) * borderSize / size, 0., 1.);\\n}\"]),this.drawMarker=t(s);var l=c({},o);l.frag=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\n\\nuniform float opacity;\\nvarying float fragBorderRadius, fragWidth;\\n\\nfloat smoothStep(float edge0, float edge1, float x) {\\n\\tfloat t;\\n\\tt = clamp((x - edge0) / (edge1 - edge0), 0.0, 1.0);\\n\\treturn t * t * (3.0 - 2.0 * t);\\n}\\n\\nvoid main() {\\n\\tfloat radius, alpha = 1.0, delta = fragWidth;\\n\\n\\tradius = length(2.0 * gl_PointCoord.xy - 1.0);\\n\\n\\tif (radius > 1.0 + delta) {\\n\\t\\tdiscard;\\n\\t}\\n\\n\\talpha -= smoothstep(1.0 - delta, 1.0 + delta, radius);\\n\\n\\tfloat borderRadius = fragBorderRadius;\\n\\tfloat ratio = smoothstep(borderRadius - delta, borderRadius + delta, radius);\\n\\tvec4 color = mix(fragColor, fragBorderColor, ratio);\\n\\tcolor.a *= alpha * opacity;\\n\\tgl_FragColor = color;\\n}\\n\"]),l.vert=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio;\\nuniform sampler2D palette;\\nuniform vec2 paletteSize;\\n\\nconst float maxSize = 100.;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragBorderRadius, fragWidth;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  // ignore inactive points\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = (size + borderSize) * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\n  fragBorderRadius = 1. - 2. * borderSize / (size + borderSize);\\n  fragColor = color;\\n  fragBorderColor = borderColor.a == 0. || borderSize == 0. ? vec4(color.rgb, 0.) : borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n}\\n\"]),d&&(l.frag=l.frag.replace(\"smoothstep\",\"smoothStep\"),s.frag=s.frag.replace(\"smoothstep\",\"smoothStep\")),this.drawCircle=t(l)}y.defaults={color:\"black\",borderColor:\"transparent\",borderSize:0,size:12,opacity:1,marker:void 0,viewport:null,range:null,pixelSize:null,count:0,offset:0,bounds:null,positions:[],snap:1e4},y.prototype.render=function(){return arguments.length&&this.update.apply(this,arguments),this.draw(),this},y.prototype.draw=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var i=this.groups;if(1===r.length&&Array.isArray(r[0])&&(null===r[0][0]||Array.isArray(r[0][0]))&&(r=r[0]),this.regl._refresh(),r.length)for(var a=0;a<r.length;a++)this.drawItem(a,r[a]);else i.forEach(function(e,r){t.drawItem(r)});return this},y.prototype.drawItem=function(t,e){var r=this.groups,n=r[t];if(\"number\"==typeof e&&(t=e,n=r[e],e=null),n&&n.count&&n.opacity){n.activation[0]&&this.drawCircle(this.getMarkerDrawOptions(0,n,e));for(var a=[],o=1;o<n.activation.length;o++)n.activation[o]&&(!0===n.activation[o]||n.activation[o].data.length)&&a.push.apply(a,i(this.getMarkerDrawOptions(o,n,e)));a.length&&this.drawMarker(a)}},y.prototype.getMarkerDrawOptions=function(t,e,r){var i=e.range,a=e.tree,o=e.viewport,s=e.activation,l=e.selectionBuffer,u=e.count;this.regl;if(!a)return r?[c({},e,{markerTexture:this.markerTextures[t],activation:s[t],count:r.length,elements:r,offset:0})]:[c({},e,{markerTexture:this.markerTextures[t],activation:s[t],offset:0})];var h=[],f=a.range(i,{lod:!0,px:[(i[2]-i[0])/o.width,(i[3]-i[1])/o.height]});if(r){for(var p=s[t].data,d=new Uint8Array(u),g=0;g<r.length;g++){var v=r[g];d[v]=p?p[v]:1}l.subdata(d)}for(var m=f.length;m--;){var y=n(f[m],2),x=y[0],b=y[1];h.push(c({},e,{markerTexture:this.markerTextures[t],activation:r?l:s[t],offset:x,count:b-x}))}return h},y.prototype.update=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];if(r.length){1===r.length&&Array.isArray(r[0])&&(r=r[0]);var i=this.groups,a=this.gl,s=this.regl,u=this.maxSize,d=this.maxColors,m=this.palette;this.groups=i=r.map(function(e,r){var n=i[r];if(void 0===e)return n;null===e?e={positions:null}:\"function\"==typeof e?e={ondraw:e}:\"number\"==typeof e[0]&&(e={positions:e}),null===(e=h(e,{positions:\"positions data points\",snap:\"snap cluster lod tree\",size:\"sizes size radius\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",color:\"colors color fill fill-color fillColor\",borderColor:\"borderColors borderColor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range dataBox databox\",viewport:\"viewport viewPort viewBox viewbox\",opacity:\"opacity alpha transparency\",bounds:\"bound bounds boundaries limits\",tooManyColors:\"tooManyColors palette paletteMode optimizePalette enablePalette\"})).positions&&(e.positions=[]),null!=e.tooManyColors&&(t.tooManyColors=e.tooManyColors),n||(i[r]=n={id:r,scale:null,translate:null,scaleFract:null,translateFract:null,activation:[],selectionBuffer:s.buffer({data:new Uint8Array(0),usage:\"stream\",type:\"uint8\"}),sizeBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),colorBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),positionBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"}),positionFractBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"})},e=c({},y.defaults,e)),!e.positions||\"marker\"in e||(e.marker=n.marker,delete n.marker),!e.marker||\"positions\"in e||(e.positions=n.positions,delete n.positions);var x=0,b=0;if(f(n,e,[{snap:!0,size:function(t,e){return null==t&&(t=y.defaults.size),x+=t&&t.length?1:0,t},borderSize:function(t,e){return null==t&&(t=y.defaults.borderSize),x+=t&&t.length?1:0,t},opacity:parseFloat,color:function(e,r){return null==e&&(e=y.defaults.color),e=t.updateColor(e),b++,e},borderColor:function(e,r){return null==e&&(e=y.defaults.borderColor),e=t.updateColor(e),b++,e},bounds:function(t,e,r){return\"range\"in r||(r.range=null),t},positions:function(t,e,r){var n=e.snap,i=e.positionBuffer,a=e.positionFractBuffer,c=e.selectionBuffer;if(t.x||t.y)return t.x.length?e.xAttr={buffer:s.buffer(t.x),offset:0,stride:4,count:t.x.length}:e.xAttr={buffer:t.x.buffer,offset:4*t.x.offset||0,stride:4*(t.x.stride||1),count:t.x.count},t.y.length?e.yAttr={buffer:s.buffer(t.y),offset:0,stride:4,count:t.y.length}:e.yAttr={buffer:t.y.buffer,offset:4*t.y.offset||0,stride:4*(t.y.stride||1),count:t.y.count},e.count=Math.max(e.xAttr.count,e.yAttr.count),t;t=p(t,\"float64\");var u=e.count=Math.floor(t.length/2),h=e.bounds=u?o(t,2):null;if(r.range||e.range||(delete e.range,r.range=h),r.marker||e.marker||(delete e.marker,r.marker=null),n&&(!0===n||u>n)?e.tree=l(t,{bounds:h}):n&&n.length&&(e.tree=n),e.tree){var f={primitive:\"points\",usage:\"static\",data:e.tree,type:\"uint32\"};e.elements?e.elements(f):e.elements=s.elements(f)}return i({data:g.float(t),usage:\"dynamic\"}),a({data:g.fract(t),usage:\"dynamic\"}),c({data:new Uint8Array(u),type:\"uint8\",usage:\"stream\"}),t}},{marker:function(e,r,n){var i=r.activation;if(i.forEach(function(t){return t&&t.destroy&&t.destroy()}),i.length=0,e&&\"number\"!=typeof e[0]){for(var a=[],o=0,l=Math.min(e.length,r.count);o<l;o++){var c=t.addMarker(e[o]);a[c]||(a[c]=new Uint8Array(r.count)),a[c][o]=1}for(var u=0;u<a.length;u++)if(a[u]){var h={data:a[u],type:\"uint8\",usage:\"static\"};i[u]?i[u](h):i[u]=s.buffer(h),i[u].data=a[u]}}else{i[t.addMarker(e)]=!0}return e},range:function(t,e,r){var n=e.bounds;if(n)return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=g.fract(e.scale),e.translateFract=g.fract(e.translate),t},viewport:function(t){return v(t||[a.drawingBufferWidth,a.drawingBufferHeight])}}]),x){var _=n,w=_.count,k=_.size,T=_.borderSize,A=_.sizeBuffer,M=new Uint8Array(2*w);if(k.length||T.length)for(var S=0;S<w;S++)M[2*S]=Math.round(255*(null==k[S]?k:k[S])/u),M[2*S+1]=Math.round(255*(null==T[S]?T:T[S])/u);A({data:M,usage:\"dynamic\"})}if(b){var E,C=n,L=C.count,P=C.color,O=C.borderColor,z=C.colorBuffer;if(t.tooManyColors){if(P.length||O.length){E=new Uint8Array(8*L);for(var I=0;I<L;I++){var D=P[I];E[8*I]=m[4*D],E[8*I+1]=m[4*D+1],E[8*I+2]=m[4*D+2],E[8*I+3]=m[4*D+3];var R=O[I];E[8*I+4]=m[4*R],E[8*I+5]=m[4*R+1],E[8*I+6]=m[4*R+2],E[8*I+7]=m[4*R+3]}}}else if(P.length||O.length){E=new Uint8Array(4*L+2);for(var F=0;F<L;F++)null!=P[F]&&(E[4*F]=P[F]%d,E[4*F+1]=Math.floor(P[F]/d)),null!=O[F]&&(E[4*F+2]=O[F]%d,E[4*F+3]=Math.floor(O[F]/d))}z({data:E||new Uint8Array(0),type:\"uint8\",usage:\"dynamic\"})}return n})}},y.prototype.addMarker=function(t){var e,r=this.markerTextures,n=this.regl,i=this.markerCache,a=null==t?0:i.indexOf(t);if(a>=0)return a;if(t instanceof Uint8Array||t instanceof Uint8ClampedArray)e=t;else{e=new Uint8Array(t.length);for(var o=0,s=t.length;o<s;o++)e[o]=255*t[o]}var l=Math.floor(Math.sqrt(e.length));return a=r.length,i.push(t),r.push(n.texture({channels:1,data:e,radius:l,mag:\"linear\",min:\"linear\"})),a},y.prototype.updateColor=function(t){var e=this.paletteIds,r=this.palette,n=this.maxColors;Array.isArray(t)||(t=[t]);var i=[];if(\"number\"==typeof t[0]){var o=[];if(Array.isArray(t))for(var l=0;l<t.length;l+=4)o.push(t.slice(l,l+4));else for(var c=0;c<t.length;c+=4)o.push(t.subarray(c,c+4));t=o}for(var u=0;u<t.length;u++){var h=t[u];h=a(h,\"uint8\");var f=s(h,!1);if(null==e[f]){var p=r.length;e[f]=Math.floor(p/4),r[p]=h[0],r[p+1]=h[1],r[p+2]=h[2],r[p+3]=h[3]}i[u]=e[f]}return!this.tooManyColors&&r.length>4*n&&(this.tooManyColors=!0),this.updatePalette(r),1===i.length?i[0]:i},y.prototype.updatePalette=function(t){if(!this.tooManyColors){var e=this.maxColors,r=this.paletteTexture,n=Math.ceil(.25*t.length/e);if(n>1)for(var i=.25*(t=t.slice()).length%e;i<n*e;i++)t.push(0,0,0,0);r.height<n&&r.resize(e,n),r.subimage({width:Math.min(.25*t.length,e),height:n,data:t},0,0)}},y.prototype.destroy=function(){return this.groups.forEach(function(t){t.sizeBuffer.destroy(),t.positionBuffer.destroy(),t.positionFractBuffer.destroy(),t.colorBuffer.destroy(),t.activation.forEach(function(t){return t&&t.destroy&&t.destroy()}),t.selectionBuffer.destroy(),t.elements&&t.elements.destroy()}),this.groups.length=0,this.paletteTexture.destroy(),this.markerTextures.forEach(function(t){return t&&t.destroy&&t.destroy()}),this};var x=t(\"object-assign\");e.exports=function(t,e){var r=new m(t,e),n=r.render.bind(r);return x(n,{render:n,update:r.update.bind(r),draw:r.draw.bind(r),destroy:r.destroy.bind(r),regl:r.regl,gl:r.gl,canvas:r.gl.canvas,groups:r.groups,markers:r.markerCache,palette:r.palette}),n}},{\"array-bounds\":65,\"color-id\":118,\"color-normalize\":120,\"flatten-vertex-data\":227,glslify:409,\"is-iexplorer\":419,\"object-assign\":454,\"parse-rect\":459,\"pick-by-alias\":465,\"point-cluster\":499,\"to-float32\":538,\"update-diff\":549}],498:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],499:[function(t,e,r){\"use strict\";e.exports=t(\"./quad\")},{\"./quad\":500}],500:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"clamp\"),a=t(\"parse-rect\"),o=t(\"array-bounds\"),s=t(\"pick-by-alias\"),l=t(\"defined\"),c=t(\"flatten-vertex-data\"),u=t(\"is-obj\"),h=t(\"dtype\"),f=t(\"math-log2\"),p=1073741824;function d(t,e){for(var r=e[0],n=e[1],a=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=i((t[2*l]-r)*a,0,1),s[2*l+1]=i((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,\"float64\"),e=s(e,{bounds:\"range bounds dataBox databox\",maxDepth:\"depth maxDepth maxdepth level maxLevel maxlevel levels\",dtype:\"type dtype format out dst output destination\"});var r=l(e.maxDepth,255),i=l(e.bounds,o(t,2));i[0]===i[2]&&i[2]++,i[1]===i[3]&&i[3]++;var g,v=d(t,i),m=t.length>>>1;e.dtype||(e.dtype=\"array\"),\"string\"==typeof e.dtype?g=new(h(e.dtype))(m):e.dtype&&(g=e.dtype,Array.isArray(g)&&(g.length=m));for(var y=0;y<m;++y)g[y]=y;var x=[],b=[],_=[],w=[];!function t(e,n,i,a,o,s){if(!a.length)return null;var l=x[o]||(x[o]=[]);var c=_[o]||(_[o]=[]);var u=b[o]||(b[o]=[]);var h=l.length;o++;if(o>r||s>p){for(var f=0;f<a.length;f++)l.push(a[f]),c.push(s),u.push(null,null,null,null);return h}l.push(a[0]);c.push(s);if(a.length<=1)return u.push(null,null,null,null),h;var d=.5*i;var g=e+d,m=n+d;var y=[],w=[],k=[],T=[];for(var A=1,M=a.length;A<M;A++){var S=a[A],E=v[2*S],C=v[2*S+1];E<g?C<m?y.push(S):w.push(S):C<m?k.push(S):T.push(S)}s<<=2;u.push(t(e,n,d,y,o,s),t(e,m,d,w,o,s+1),t(g,n,d,k,o,s+2),t(g,m,d,T,o,s+3));return h}(0,0,1,g,0,1);for(var k=0,T=0;T<x.length;T++){var A=x[T];if(g.set)g.set(A,k);else for(var M=0,S=A.length;M<S;M++)g[M+k]=A[M];var E=k+x[T].length;w[T]=[k,E],k=E}return g.range=function(){var e,r=[],o=arguments.length;for(;o--;)r[o]=arguments[o];if(u(r[r.length-1])){var c=r.pop();r.length||null==c.x&&null==c.l&&null==c.left||(r=[c],e={}),e=s(c,{level:\"level maxLevel\",d:\"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize\",lod:\"lod details ranges offsets\"})}else e={};r.length||(r=i);var h=a.apply(void 0,r),p=[Math.min(h.x,h.x+h.width),Math.min(h.y,h.y+h.height),Math.max(h.x,h.x+h.width),Math.max(h.y,h.y+h.height)],g=p[0],v=p[1],m=p[2],y=p[3],k=d([g,v,m,y],i),T=k[0],A=k[1],M=k[2],S=k[3],E=l(e.level,x.length);if(null!=e.d){var L;\"number\"==typeof e.d?L=[e.d,e.d]:e.d.length&&(L=e.d),E=Math.min(Math.max(Math.ceil(-f(Math.abs(L[0])/(i[2]-i[0]))),Math.ceil(-f(Math.abs(L[1])/(i[3]-i[1])))),E)}if(E=Math.min(E,x.length),e.lod)return function(t,e,r,i,a){for(var o=[],s=0;s<a;s++){var l=_[s],c=w[s][0],u=C(t,e,s),h=C(r,i,s),f=n.ge(l,u),p=n.gt(l,h,f,l.length-1);o[s]=[f+c,p+c]}return o}(T,A,M,S,E);var P=[];return function e(r,n,i,a,o,s){if(null!==o&&null!==s){var l=r+i,c=n+i;if(!(T>l||A>c||M<r||S<n||a>=E||o===s)){var u=x[a];void 0===s&&(s=u.length);for(var h=o;h<s;h++){var f=u[h],p=t[2*f],d=t[2*f+1];p>=g&&p<=m&&d>=v&&d<=y&&P.push(f)}var _=b[a],w=_[4*o+0],k=_[4*o+1],C=_[4*o+2],L=_[4*o+3],O=function(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}(_,o+1),z=.5*i,I=a+1;e(r,n,z,I,w,k||C||L||O),e(r,n+z,z,I,k,C||L||O),e(r+z,n,z,I,C,L||O),e(r+z,n+z,z,I,L,O)}}}(0,0,1,0,0,1),P},g;function C(t,e,r){for(var n=1,i=.5,a=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<i?e<a?0:1:e<a?2:3,o*=.5,i+=t<i?-o:o,a+=e<a?-o:o;return n}}},{\"array-bounds\":65,\"binary-search-bounds\":498,clamp:115,defined:164,dtype:169,\"flatten-vertex-data\":227,\"is-obj\":421,\"math-log2\":432,\"parse-rect\":459,\"pick-by-alias\":465}],501:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"pick-by-alias\"),a=t(\"array-bounds\"),o=t(\"raf\"),s=t(\"array-range\"),l=t(\"parse-rect\"),c=t(\"flatten-vertex-data\");function u(t,e){if(!(this instanceof u))return new u(t,e);this.traces=[],this.passes={},this.regl=t,this.scatter=n(t),this.canvas=this.scatter.canvas}function h(t,e,r){return(null!=t.id?t.id:t)<<16|(255&e)<<8|255&r}function f(t,e,r){var n,i,a,o,s=t[e],l=t[r];return s.length>2?(s[0],s[2],n=s[1],i=s[3]):s.length?(n=s[0],i=s[1]):(s.x,n=s.y,s.x+s.width,i=s.y+s.height),l.length>2?(a=l[0],o=l[2],l[1],l[3]):l.length?(a=l[0],o=l[1]):(a=l.x,l.y,o=l.x+l.width,l.y+l.height),[a,n,o,i]}function p(t){if(\"number\"==typeof t)return[t,t,t,t];if(2===t.length)return[t[0],t[1],t[0],t[1]];var e=l(t);return[e.x,e.y,e.x+e.width,e.y+e.height]}e.exports=u,u.prototype.render=function(){for(var t,e=this,r=[],n=arguments.length;n--;)r[n]=arguments[n];return r.length&&(t=this).update.apply(t,r),this.regl.attributes.preserveDrawingBuffer?this.draw():(this.dirty?null==this.planned&&(this.planned=o(function(){e.draw(),e.dirty=!0,e.planned=null})):(this.draw(),this.dirty=!0,o(function(){e.dirty=!1})),this)},u.prototype.update=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=0;n<e.length;n++)this.updateItem(n,e[n]);this.traces=this.traces.filter(Boolean);for(var i=[],a=0,o=0;o<this.traces.length;o++){for(var s=this.traces[o],l=this.traces[o].passes,c=0;c<l.length;c++)i.push(this.passes[l[c]]);s.passOffset=a,a+=s.passes.length}return(t=this.scatter).update.apply(t,i),this}},u.prototype.updateItem=function(t,e){var r=this.regl;if(null===e)return this.traces[t]=null,this;if(!e)return this;var n,o=i(e,{data:\"data items columns rows values dimensions samples x\",snap:\"snap cluster\",size:\"sizes size radius\",color:\"colors color fill fill-color fillColor\",opacity:\"opacity alpha transparency opaque\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",borderColor:\"borderColors borderColor bordercolor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range ranges databox dataBox\",viewport:\"viewport viewBox viewbox\",domain:\"domain domains area areas\",padding:\"pad padding paddings pads margin margins\",transpose:\"transpose transposed\",diagonal:\"diagonal diag showDiagonal\",upper:\"upper up top upperhalf upperHalf showupperhalf showUpper showUpperHalf\",lower:\"lower low bottom lowerhalf lowerHalf showlowerhalf showLowerHalf showLower\"}),s=this.traces[t]||(this.traces[t]={id:t,buffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),color:\"black\",marker:null,size:12,borderColor:\"transparent\",borderSize:1,viewport:l([r._gl.drawingBufferWidth,r._gl.drawingBufferHeight]),padding:[0,0,0,0],opacity:1,diagonal:!0,upper:!0,lower:!0});if(null!=o.color&&(s.color=o.color),null!=o.size&&(s.size=o.size),null!=o.marker&&(s.marker=o.marker),null!=o.borderColor&&(s.borderColor=o.borderColor),null!=o.borderSize&&(s.borderSize=o.borderSize),null!=o.opacity&&(s.opacity=o.opacity),o.viewport&&(s.viewport=l(o.viewport)),null!=o.diagonal&&(s.diagonal=o.diagonal),null!=o.upper&&(s.upper=o.upper),null!=o.lower&&(s.lower=o.lower),o.data){s.buffer(c(o.data)),s.columns=o.data.length,s.count=o.data[0].length,s.bounds=[];for(var u=0;u<s.columns;u++)s.bounds[u]=a(o.data[u],1)}o.range&&(s.range=o.range,n=s.range&&\"number\"!=typeof s.range[0]),o.domain&&(s.domain=o.domain);var d=!1;null!=o.padding&&(Array.isArray(o.padding)&&o.padding.length===s.columns&&\"number\"==typeof o.padding[o.padding.length-1]?(s.padding=o.padding.map(p),d=!0):s.padding=p(o.padding));var g=s.columns,v=s.count,m=s.viewport.width,y=s.viewport.height,x=s.viewport.x,b=s.viewport.y,_=m/g,w=y/g;s.passes=[];for(var k=0;k<g;k++)for(var T=0;T<g;T++)if((s.diagonal||T!==k)&&(s.upper||!(k>T))&&(s.lower||!(k<T))){var A=h(s.id,k,T),M=this.passes[A]||(this.passes[A]={});if(o.data&&(o.transpose?M.positions={x:{buffer:s.buffer,offset:T,count:v,stride:g},y:{buffer:s.buffer,offset:k,count:v,stride:g}}:M.positions={x:{buffer:s.buffer,offset:T*v,count:v},y:{buffer:s.buffer,offset:k*v,count:v}},M.bounds=f(s.bounds,k,T)),o.domain||o.viewport||o.data){var S=d?f(s.padding,k,T):s.padding;if(s.domain){var E=f(s.domain,k,T),C=E[0],L=E[1],P=E[2],O=E[3];M.viewport=[x+C*m+S[0],b+L*y+S[1],x+P*m-S[2],b+O*y-S[3]]}else M.viewport=[x+T*_+_*S[0],b+k*w+w*S[1],x+(T+1)*_-_*S[2],b+(k+1)*w-w*S[3]]}o.color&&(M.color=s.color),o.size&&(M.size=s.size),o.marker&&(M.marker=s.marker),o.borderSize&&(M.borderSize=s.borderSize),o.borderColor&&(M.borderColor=s.borderColor),o.opacity&&(M.opacity=s.opacity),o.range&&(M.range=n?f(s.range,k,T):s.range||M.bounds),s.passes.push(A)}return this},u.prototype.draw=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=[],i=0;i<e.length;i++)if(\"number\"==typeof e[i]){var a=this.traces[e[i]],o=a.passes,l=a.passOffset;n.push.apply(n,s(l,l+o.length))}else if(e[i].length){var c=e[i],u=this.traces[i],h=u.passes,f=u.passOffset;h=h.map(function(t,e){n[f+e]=c})}(t=this.scatter).draw.apply(t,n)}else this.scatter.draw();return this},u.prototype.destroy=function(){return this.traces.forEach(function(t){t.buffer&&t.buffer.destroy&&t.buffer.destroy()}),this.traces=null,this.passes=null,this.scatter.destroy(),this}},{\"array-bounds\":65,\"array-range\":67,\"flatten-vertex-data\":227,\"parse-rect\":459,\"pick-by-alias\":465,raf:484,\"regl-scatter2d\":497}],502:[function(t,e,r){var n,i;n=this,i=function(){function t(t,e){this.id=U++,this.type=t,this.data=e}function e(t){return\"[\"+function t(e){if(0===e.length)return[];var r=e.charAt(0),n=e.charAt(e.length-1);if(1<e.length&&r===n&&('\"'===r||\"'\"===r))return['\"'+e.substr(1,e.length-2).replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];if(r=/\\[(false|true|null|\\d+|'[^']*'|\"[^\"]*\")\\]/.exec(e))return t(e.substr(0,r.index)).concat(t(r[1])).concat(t(e.substr(r.index+r[0].length)));if(1===(r=e.split(\".\")).length)return['\"'+e.replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];for(e=[],n=0;n<r.length;++n)e=e.concat(t(r[n]));return e}(t).join(\"][\")+\"]\"}function r(t){return\"string\"==typeof t?t.split():t}function n(t){return\"string\"==typeof t?document.querySelector(t):t}function i(t){var e,i,a,o,s=t||{};t={};var l=[],c=[],u=\"undefined\"==typeof window?1:window.devicePixelRatio,h=!1,f=function(t){},p=function(){};if(\"string\"==typeof s?e=document.querySelector(s):\"object\"==typeof s&&(\"string\"==typeof s.nodeName&&\"function\"==typeof s.appendChild&&\"function\"==typeof s.getBoundingClientRect?e=s:\"function\"==typeof s.drawArrays||\"function\"==typeof s.drawElements?a=(o=s).canvas:(\"gl\"in s?o=s.gl:\"canvas\"in s?a=n(s.canvas):\"container\"in s&&(i=n(s.container)),\"attributes\"in s&&(t=s.attributes),\"extensions\"in s&&(l=r(s.extensions)),\"optionalExtensions\"in s&&(c=r(s.optionalExtensions)),\"onDone\"in s&&(f=s.onDone),\"profile\"in s&&(h=!!s.profile),\"pixelRatio\"in s&&(u=+s.pixelRatio))),e&&(\"canvas\"===e.nodeName.toLowerCase()?a=e:i=e),!o){if(!a){if(!(e=function(t,e,r){function n(){var e=window.innerWidth,n=window.innerHeight;t!==document.body&&(e=(n=t.getBoundingClientRect()).right-n.left,n=n.bottom-n.top),i.width=r*e,i.height=r*n,j(i.style,{width:e+\"px\",height:n+\"px\"})}var i=document.createElement(\"canvas\");return j(i.style,{border:0,margin:0,padding:0,top:0,left:0}),t.appendChild(i),t===document.body&&(i.style.position=\"absolute\",j(t.style,{margin:0,padding:0})),window.addEventListener(\"resize\",n,!1),n(),{canvas:i,onDestroy:function(){window.removeEventListener(\"resize\",n),t.removeChild(i)}}}(i||document.body,0,u)))return null;a=e.canvas,p=e.onDestroy}o=function(t,e){function r(r){try{return t.getContext(r,e)}catch(t){return null}}return r(\"webgl\")||r(\"experimental-webgl\")||r(\"webgl-experimental\")}(a,t)}return o?{gl:o,canvas:a,container:i,extensions:l,optionalExtensions:c,pixelRatio:u,profile:h,onDone:f,onDestroy:p}:(p(),f(\"webgl not supported, try upgrading your browser or graphics drivers http://get.webgl.org\"),null)}function a(t,e){for(var r=Array(t),n=0;n<t;++n)r[n]=e(n);return r}function o(t){var e,r;return e=(65535<t)<<4,e|=r=(255<(t>>>=e))<<3,(e|=r=(15<(t>>>=r))<<2)|(r=(3<(t>>>=r))<<1)|t>>>r>>1}function s(){function t(t){t:{for(var e=16;268435456>=e;e*=16)if(t<=e){t=e;break t}t=0}return 0<(e=r[o(t)>>2]).length?e.pop():new ArrayBuffer(t)}function e(t){r[o(t.byteLength)>>2].push(t)}var r=a(8,function(){return[]});return{alloc:t,free:e,allocType:function(e,r){var n=null;switch(e){case 5120:n=new Int8Array(t(r),0,r);break;case 5121:n=new Uint8Array(t(r),0,r);break;case 5122:n=new Int16Array(t(2*r),0,r);break;case 5123:n=new Uint16Array(t(2*r),0,r);break;case 5124:n=new Int32Array(t(4*r),0,r);break;case 5125:n=new Uint32Array(t(4*r),0,r);break;case 5126:n=new Float32Array(t(4*r),0,r);break;default:return null}return n.length!==r?n.subarray(0,r):n},freeType:function(t){e(t.buffer)}}}function l(t){return!!t&&\"object\"==typeof t&&Array.isArray(t.shape)&&Array.isArray(t.stride)&&\"number\"==typeof t.offset&&t.shape.length===t.stride.length&&(Array.isArray(t.data)||W(t.data))}function c(t,e,r,n,i,a){for(var o=0;o<e;++o)for(var s=t[o],l=0;l<r;++l)for(var c=s[l],u=0;u<n;++u)i[a++]=c[u]}function u(t){return 0|J[Object.prototype.toString.call(t)]}function h(t,e){for(var r=0;r<e.length;++r)t[r]=e[r]}function f(t,e,r,n,i,a,o){for(var s=0,l=0;l<r;++l)for(var c=0;c<n;++c)t[s++]=e[i*l+a*c+o]}function p(t,e,r,n){function i(e){this.id=c++,this.buffer=t.createBuffer(),this.type=e,this.usage=35044,this.byteLength=0,this.dimension=1,this.dtype=5121,this.persistentData=null,r.profile&&(this.stats={size:0})}function a(e,r,n){e.byteLength=r.byteLength,t.bufferData(e.type,r,n)}function o(t,e,r,n,i,o){if(t.usage=r,Array.isArray(e)){if(t.dtype=n||5126,0<e.length)if(Array.isArray(e[0])){i=tt(e);for(var s=n=1;s<i.length;++s)n*=i[s];t.dimension=n,a(t,e=Q(e,i,t.dtype),r),o?t.persistentData=e:G.freeType(e)}else\"number\"==typeof e[0]?(t.dimension=i,h(i=G.allocType(t.dtype,e.length),e),a(t,i,r),o?t.persistentData=i:G.freeType(i)):W(e[0])&&(t.dimension=e[0].length,t.dtype=n||u(e[0])||5126,a(t,e=Q(e,[e.length,e[0].length],t.dtype),r),o?t.persistentData=e:G.freeType(e))}else if(W(e))t.dtype=n||u(e),t.dimension=i,a(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e.buffer)));else if(l(e)){i=e.shape;var c=e.stride,p=(s=e.offset,0),d=0,g=0,v=0;1===i.length?(p=i[0],d=1,g=c[0],v=0):2===i.length&&(p=i[0],d=i[1],g=c[0],v=c[1]),t.dtype=n||u(e.data)||5126,t.dimension=d,f(i=G.allocType(t.dtype,p*d),e.data,p,d,g,v,s),a(t,i,r),o?t.persistentData=i:G.freeType(i)}}function s(r){e.bufferCount--;for(var i=0;i<n.state.length;++i){var a=n.state[i];a.buffer===r&&(t.disableVertexAttribArray(i),a.buffer=null)}t.deleteBuffer(r.buffer),r.buffer=null,delete p[r.id]}var c=0,p={};i.prototype.bind=function(){t.bindBuffer(this.type,this.buffer)},i.prototype.destroy=function(){s(this)};var d=[];return r.profile&&(e.getTotalBufferSize=function(){var t=0;return Object.keys(p).forEach(function(e){t+=p[e].stats.size}),t}),{create:function(n,a,c,d){function g(e){var n=35044,i=null,a=0,s=0,c=1;return Array.isArray(e)||W(e)||l(e)?i=e:\"number\"==typeof e?a=0|e:e&&(\"data\"in e&&(i=e.data),\"usage\"in e&&(n=$[e.usage]),\"type\"in e&&(s=K[e.type]),\"dimension\"in e&&(c=0|e.dimension),\"length\"in e&&(a=0|e.length)),v.bind(),i?o(v,i,n,s,c,d):(a&&t.bufferData(v.type,a,n),v.dtype=s||5121,v.usage=n,v.dimension=c,v.byteLength=a),r.profile&&(v.stats.size=v.byteLength*et[v.dtype]),g}e.bufferCount++;var v=new i(a);return p[v.id]=v,c||g(n),g._reglType=\"buffer\",g._buffer=v,g.subdata=function(e,r){var n,i=0|(r||0);if(v.bind(),W(e))t.bufferSubData(v.type,i,e);else if(Array.isArray(e)){if(0<e.length)if(\"number\"==typeof e[0]){var a=G.allocType(v.dtype,e.length);h(a,e),t.bufferSubData(v.type,i,a),G.freeType(a)}else(Array.isArray(e[0])||W(e[0]))&&(n=tt(e),a=Q(e,n,v.dtype),t.bufferSubData(v.type,i,a),G.freeType(a))}else if(l(e)){n=e.shape;var o=e.stride,s=a=0,c=0,p=0;1===n.length?(a=n[0],s=1,c=o[0],p=0):2===n.length&&(a=n[0],s=n[1],c=o[0],p=o[1]),n=Array.isArray(e.data)?v.dtype:u(e.data),f(n=G.allocType(n,a*s),e.data,a,s,c,p,e.offset),t.bufferSubData(v.type,i,n),G.freeType(n)}return g},r.profile&&(g.stats=v.stats),g.destroy=function(){s(v)},g},createStream:function(t,e){var r=d.pop();return r||(r=new i(t)),r.bind(),o(r,e,35040,0,1,!1),r},destroyStream:function(t){d.push(t)},clear:function(){X(p).forEach(s),d.forEach(s)},getBuffer:function(t){return t&&t._buffer instanceof i?t._buffer:null},restore:function(){X(p).forEach(function(e){e.buffer=t.createBuffer(),t.bindBuffer(e.type,e.buffer),t.bufferData(e.type,e.persistentData||e.byteLength,e.usage)})},_initBuffer:o}}function d(t,e,r,n){function i(t){this.id=c++,s[this.id]=this,this.buffer=t,this.primType=4,this.type=this.vertCount=0}function a(n,i,a,o,s,c,u){if(n.buffer.bind(),i){var h=u;u||W(i)&&(!l(i)||W(i.data))||(h=e.oes_element_index_uint?5125:5123),r._initBuffer(n.buffer,i,a,h,3)}else t.bufferData(34963,c,a),n.buffer.dtype=h||5121,n.buffer.usage=a,n.buffer.dimension=3,n.buffer.byteLength=c;if(h=u,!u){switch(n.buffer.dtype){case 5121:case 5120:h=5121;break;case 5123:case 5122:h=5123;break;case 5125:case 5124:h=5125}n.buffer.dtype=h}n.type=h,0>(i=s)&&(i=n.buffer.byteLength,5123===h?i>>=1:5125===h&&(i>>=2)),n.vertCount=i,i=o,0>o&&(i=4,1===(o=n.buffer.dimension)&&(i=0),2===o&&(i=1),3===o&&(i=4)),n.primType=i}function o(t){n.elementsCount--,delete s[t.id],t.buffer.destroy(),t.buffer=null}var s={},c=0,u={uint8:5121,uint16:5123};e.oes_element_index_uint&&(u.uint32=5125),i.prototype.bind=function(){this.buffer.bind()};var h=[];return{create:function(t,e){function s(t){if(t)if(\"number\"==typeof t)c(t),h.primType=4,h.vertCount=0|t,h.type=5121;else{var e=null,r=35044,n=-1,i=-1,o=0,f=0;Array.isArray(t)||W(t)||l(t)?e=t:(\"data\"in t&&(e=t.data),\"usage\"in t&&(r=$[t.usage]),\"primitive\"in t&&(n=rt[t.primitive]),\"count\"in t&&(i=0|t.count),\"type\"in t&&(f=u[t.type]),\"length\"in t?o=0|t.length:(o=i,5123===f||5122===f?o*=2:5125!==f&&5124!==f||(o*=4))),a(h,e,r,n,i,o,f)}else c(),h.primType=4,h.vertCount=0,h.type=5121;return s}var c=r.create(null,34963,!0),h=new i(c._buffer);return n.elementsCount++,s(t),s._reglType=\"elements\",s._elements=h,s.subdata=function(t,e){return c.subdata(t,e),s},s.destroy=function(){o(h)},s},createStream:function(t){var e=h.pop();return e||(e=new i(r.create(null,34963,!0,!1)._buffer)),a(e,t,35040,-1,-1,0,0),e},destroyStream:function(t){h.push(t)},getElements:function(t){return\"function\"==typeof t&&t._elements instanceof i?t._elements:null},clear:function(){X(s).forEach(o)}}}function g(t){for(var e=G.allocType(5123,t.length),r=0;r<t.length;++r)if(isNaN(t[r]))e[r]=65535;else if(1/0===t[r])e[r]=31744;else if(-1/0===t[r])e[r]=64512;else{nt[0]=t[r];var n=(a=it[0])>>>31<<15,i=(a<<1>>>24)-127,a=a>>13&1023;e[r]=-24>i?n:-14>i?n+(a+1024>>-14-i):15<i?n+31744:n+(i+15<<10)+a}return e}function v(t){return Array.isArray(t)||W(t)}function m(t){return\"[object \"+t+\"]\"}function y(t){return Array.isArray(t)&&(0===t.length||\"number\"==typeof t[0])}function x(t){return!(!Array.isArray(t)||0===t.length||!v(t[0]))}function b(t){return Object.prototype.toString.call(t)}function _(t){if(!t)return!1;var e=b(t);return 0<=pt.indexOf(e)||(y(t)||x(t)||l(t))}function w(t,e){36193===t.type?(t.data=g(e),G.freeType(e)):t.data=e}function k(t,e,r,n,i,a){if(t=\"undefined\"!=typeof gt[t]?gt[t]:st[t]*dt[e],a&&(t*=6),i){for(n=0;1<=r;)n+=t*r*r,r/=2;return n}return t*r*n}function T(t,e,r,n,i,a,o){function s(){this.format=this.internalformat=6408,this.type=5121,this.flipY=this.premultiplyAlpha=this.compressed=!1,this.unpackAlignment=1,this.colorSpace=37444,this.channels=this.height=this.width=0}function c(t,e){t.internalformat=e.internalformat,t.format=e.format,t.type=e.type,t.compressed=e.compressed,t.premultiplyAlpha=e.premultiplyAlpha,t.flipY=e.flipY,t.unpackAlignment=e.unpackAlignment,t.colorSpace=e.colorSpace,t.width=e.width,t.height=e.height,t.channels=e.channels}function u(t,e){if(\"object\"==typeof e&&e){\"premultiplyAlpha\"in e&&(t.premultiplyAlpha=e.premultiplyAlpha),\"flipY\"in e&&(t.flipY=e.flipY),\"alignment\"in e&&(t.unpackAlignment=e.alignment),\"colorSpace\"in e&&(t.colorSpace=q[e.colorSpace]),\"type\"in e&&(t.type=H[e.type]);var r=t.width,n=t.height,i=t.channels,a=!1;\"shape\"in e?(r=e.shape[0],n=e.shape[1],3===e.shape.length&&(i=e.shape[2],a=!0)):(\"radius\"in e&&(r=n=e.radius),\"width\"in e&&(r=e.width),\"height\"in e&&(n=e.height),\"channels\"in e&&(i=e.channels,a=!0)),t.width=0|r,t.height=0|n,t.channels=0|i,r=!1,\"format\"in e&&(r=e.format,n=t.internalformat=Y[r],t.format=pt[n],r in H&&!(\"type\"in e)&&(t.type=H[r]),r in K&&(t.compressed=!0),r=!0),!a&&r?t.channels=st[t.format]:a&&!r&&t.channels!==ot[t.format]&&(t.format=t.internalformat=ot[t.channels])}}function h(e){t.pixelStorei(37440,e.flipY),t.pixelStorei(37441,e.premultiplyAlpha),t.pixelStorei(37443,e.colorSpace),t.pixelStorei(3317,e.unpackAlignment)}function f(){s.call(this),this.yOffset=this.xOffset=0,this.data=null,this.needsFree=!1,this.element=null,this.needsCopy=!1}function p(t,e){var r=null;if(_(e)?r=e:e&&(u(t,e),\"x\"in e&&(t.xOffset=0|e.x),\"y\"in e&&(t.yOffset=0|e.y),_(e.data)&&(r=e.data)),e.copy){var n=i.viewportWidth,a=i.viewportHeight;t.width=t.width||n-t.xOffset,t.height=t.height||a-t.yOffset,t.needsCopy=!0}else if(r){if(W(r))t.channels=t.channels||4,t.data=r,\"type\"in e||5121!==t.type||(t.type=0|J[Object.prototype.toString.call(r)]);else if(y(r)){switch(t.channels=t.channels||4,a=(n=r).length,t.type){case 5121:case 5123:case 5125:case 5126:(a=G.allocType(t.type,a)).set(n),t.data=a;break;case 36193:t.data=g(n)}t.alignment=1,t.needsFree=!0}else if(l(r)){n=r.data,Array.isArray(n)||5121!==t.type||(t.type=0|J[Object.prototype.toString.call(n)]);a=r.shape;var o,s,c,h,f=r.stride;3===a.length?(c=a[2],h=f[2]):h=c=1,o=a[0],s=a[1],a=f[0],f=f[1],t.alignment=1,t.width=o,t.height=s,t.channels=c,t.format=t.internalformat=ot[c],t.needsFree=!0,o=h,r=r.offset,c=t.width,h=t.height,s=t.channels;for(var p=G.allocType(36193===t.type?5126:t.type,c*h*s),d=0,m=0;m<h;++m)for(var k=0;k<c;++k)for(var T=0;T<s;++T)p[d++]=n[a*k+f*m+o*T+r];w(t,p)}else if(b(r)===lt||b(r)===ct)b(r)===lt?t.element=r:t.element=r.canvas,t.width=t.element.width,t.height=t.element.height,t.channels=4;else if(b(r)===ut)t.element=r,t.width=r.width,t.height=r.height,t.channels=4;else if(b(r)===ht)t.element=r,t.width=r.naturalWidth,t.height=r.naturalHeight,t.channels=4;else if(b(r)===ft)t.element=r,t.width=r.videoWidth,t.height=r.videoHeight,t.channels=4;else if(x(r)){for(n=t.width||r[0].length,a=t.height||r.length,f=t.channels,f=v(r[0][0])?f||r[0][0].length:f||1,o=Z.shape(r),c=1,h=0;h<o.length;++h)c*=o[h];c=G.allocType(36193===t.type?5126:t.type,c),Z.flatten(r,o,\"\",c),w(t,c),t.alignment=1,t.width=n,t.height=a,t.channels=f,t.format=t.internalformat=ot[f],t.needsFree=!0}}else t.width=t.width||1,t.height=t.height||1,t.channels=t.channels||4}function d(e,r,i,a,o){var s=e.element,l=e.data,c=e.internalformat,u=e.format,f=e.type,p=e.width,d=e.height;h(e),s?t.texSubImage2D(r,o,i,a,u,f,s):e.compressed?t.compressedTexSubImage2D(r,o,i,a,c,p,d,l):e.needsCopy?(n(),t.copyTexSubImage2D(r,o,i,a,e.xOffset,e.yOffset,p,d)):t.texSubImage2D(r,o,i,a,p,d,u,f,l)}function m(){return dt.pop()||new f}function T(t){t.needsFree&&G.freeType(t.data),f.call(t),dt.push(t)}function A(){s.call(this),this.genMipmaps=!1,this.mipmapHint=4352,this.mipmask=0,this.images=Array(16)}function M(t,e,r){var n=t.images[0]=m();t.mipmask=1,n.width=t.width=e,n.height=t.height=r,n.channels=t.channels=4}function S(t,e){var r=null;if(_(e))c(r=t.images[0]=m(),t),p(r,e),t.mipmask=1;else if(u(t,e),Array.isArray(e.mipmap))for(var n=e.mipmap,i=0;i<n.length;++i)c(r=t.images[i]=m(),t),r.width>>=i,r.height>>=i,p(r,n[i]),t.mipmask|=1<<i;else c(r=t.images[0]=m(),t),p(r,e),t.mipmask=1;c(t,t.images[0])}function E(e,r){for(var i=e.images,a=0;a<i.length&&i[a];++a){var o=i[a],s=r,l=a,c=o.element,u=o.data,f=o.internalformat,p=o.format,d=o.type,g=o.width,v=o.height,m=o.channels;h(o),c?t.texImage2D(s,l,p,p,d,c):o.compressed?t.compressedTexImage2D(s,l,f,g,v,0,u):o.needsCopy?(n(),t.copyTexImage2D(s,l,p,o.xOffset,o.yOffset,g,v,0)):((o=!u)&&(u=G.zero.allocType(d,g*v*m)),t.texImage2D(s,l,p,g,v,0,p,d,u),o&&u&&G.zero.freeType(u))}}function C(){var t=gt.pop()||new A;s.call(t);for(var e=t.mipmask=0;16>e;++e)t.images[e]=null;return t}function L(t){for(var e=t.images,r=0;r<e.length;++r)e[r]&&T(e[r]),e[r]=null;gt.push(t)}function P(){this.magFilter=this.minFilter=9728,this.wrapT=this.wrapS=33071,this.anisotropic=1,this.genMipmaps=!1,this.mipmapHint=4352}function O(t,e){\"min\"in e&&(t.minFilter=V[e.min],0<=at.indexOf(t.minFilter)&&!(\"faces\"in e)&&(t.genMipmaps=!0)),\"mag\"in e&&(t.magFilter=U[e.mag]);var r=t.wrapS,n=t.wrapT;if(\"wrap\"in e){var i=e.wrap;\"string\"==typeof i?r=n=N[i]:Array.isArray(i)&&(r=N[i[0]],n=N[i[1]])}else\"wrapS\"in e&&(r=N[e.wrapS]),\"wrapT\"in e&&(n=N[e.wrapT]);if(t.wrapS=r,t.wrapT=n,\"anisotropic\"in e&&(t.anisotropic=e.anisotropic),\"mipmap\"in e){switch(r=!1,typeof e.mipmap){case\"string\":t.mipmapHint=B[e.mipmap],r=t.genMipmaps=!0;break;case\"boolean\":r=t.genMipmaps=e.mipmap;break;case\"object\":t.genMipmaps=!1,r=!0}!r||\"min\"in e||(t.minFilter=9984)}}function z(r,n){t.texParameteri(n,10241,r.minFilter),t.texParameteri(n,10240,r.magFilter),t.texParameteri(n,10242,r.wrapS),t.texParameteri(n,10243,r.wrapT),e.ext_texture_filter_anisotropic&&t.texParameteri(n,34046,r.anisotropic),r.genMipmaps&&(t.hint(33170,r.mipmapHint),t.generateMipmap(n))}function I(e){s.call(this),this.mipmask=0,this.internalformat=6408,this.id=vt++,this.refCount=1,this.target=e,this.texture=t.createTexture(),this.unit=-1,this.bindCount=0,this.texInfo=new P,o.profile&&(this.stats={size:0})}function D(e){t.activeTexture(33984),t.bindTexture(e.target,e.texture)}function R(){var e=xt[0];e?t.bindTexture(e.target,e.texture):t.bindTexture(3553,null)}function F(e){var r=e.texture,n=e.unit,i=e.target;0<=n&&(t.activeTexture(33984+n),t.bindTexture(i,null),xt[n]=null),t.deleteTexture(r),e.texture=null,e.params=null,e.pixels=null,e.refCount=0,delete mt[e.id],a.textureCount--}var B={\"don't care\":4352,\"dont care\":4352,nice:4354,fast:4353},N={repeat:10497,clamp:33071,mirror:33648},U={nearest:9728,linear:9729},V=j({mipmap:9987,\"nearest mipmap nearest\":9984,\"linear mipmap nearest\":9985,\"nearest mipmap linear\":9986,\"linear mipmap linear\":9987},U),q={none:0,browser:37444},H={uint8:5121,rgba4:32819,rgb565:33635,\"rgb5 a1\":32820},Y={alpha:6406,luminance:6409,\"luminance alpha\":6410,rgb:6407,rgba:6408,rgba4:32854,\"rgb5 a1\":32855,rgb565:36194},K={};e.ext_srgb&&(Y.srgb=35904,Y.srgba=35906),e.oes_texture_float&&(H.float32=H.float=5126),e.oes_texture_half_float&&(H.float16=H[\"half float\"]=36193),e.webgl_depth_texture&&(j(Y,{depth:6402,\"depth stencil\":34041}),j(H,{uint16:5123,uint32:5125,\"depth stencil\":34042})),e.webgl_compressed_texture_s3tc&&j(K,{\"rgb s3tc dxt1\":33776,\"rgba s3tc dxt1\":33777,\"rgba s3tc dxt3\":33778,\"rgba s3tc dxt5\":33779}),e.webgl_compressed_texture_atc&&j(K,{\"rgb atc\":35986,\"rgba atc explicit alpha\":35987,\"rgba atc interpolated alpha\":34798}),e.webgl_compressed_texture_pvrtc&&j(K,{\"rgb pvrtc 4bppv1\":35840,\"rgb pvrtc 2bppv1\":35841,\"rgba pvrtc 4bppv1\":35842,\"rgba pvrtc 2bppv1\":35843}),e.webgl_compressed_texture_etc1&&(K[\"rgb etc1\"]=36196);var $=Array.prototype.slice.call(t.getParameter(34467));Object.keys(K).forEach(function(t){var e=K[t];0<=$.indexOf(e)&&(Y[t]=e)});var Q=Object.keys(Y);r.textureFormats=Q;var tt=[];Object.keys(Y).forEach(function(t){tt[Y[t]]=t});var et=[];Object.keys(H).forEach(function(t){et[H[t]]=t});var rt=[];Object.keys(U).forEach(function(t){rt[U[t]]=t});var nt=[];Object.keys(V).forEach(function(t){nt[V[t]]=t});var it=[];Object.keys(N).forEach(function(t){it[N[t]]=t});var pt=Q.reduce(function(t,e){var r=Y[e];return 6409===r||6406===r||6409===r||6410===r||6402===r||34041===r?t[r]=r:32855===r||0<=e.indexOf(\"rgba\")?t[r]=6408:t[r]=6407,t},{}),dt=[],gt=[],vt=0,mt={},yt=r.maxTextureUnits,xt=Array(yt).map(function(){return null});return j(I.prototype,{bind:function(){this.bindCount+=1;var e=this.unit;if(0>e){for(var r=0;r<yt;++r){var n=xt[r];if(n){if(0<n.bindCount)continue;n.unit=-1}xt[r]=this,e=r;break}o.profile&&a.maxTextureUnits<e+1&&(a.maxTextureUnits=e+1),this.unit=e,t.activeTexture(33984+e),t.bindTexture(this.target,this.texture)}return e},unbind:function(){--this.bindCount},decRef:function(){0>=--this.refCount&&F(this)}}),o.profile&&(a.getTotalTextureSize=function(){var t=0;return Object.keys(mt).forEach(function(e){t+=mt[e].stats.size}),t}),{create2D:function(e,r){function n(t,e){var r=i.texInfo;P.call(r);var a=C();return\"number\"==typeof t?M(a,0|t,\"number\"==typeof e?0|e:0|t):t?(O(r,t),S(a,t)):M(a,1,1),r.genMipmaps&&(a.mipmask=(a.width<<1)-1),i.mipmask=a.mipmask,c(i,a),i.internalformat=a.internalformat,n.width=a.width,n.height=a.height,D(i),E(a,3553),z(r,3553),R(),L(a),o.profile&&(i.stats.size=k(i.internalformat,i.type,a.width,a.height,r.genMipmaps,!1)),n.format=tt[i.internalformat],n.type=et[i.type],n.mag=rt[r.magFilter],n.min=nt[r.minFilter],n.wrapS=it[r.wrapS],n.wrapT=it[r.wrapT],n}var i=new I(3553);return mt[i.id]=i,a.textureCount++,n(e,r),n.subimage=function(t,e,r,a){e|=0,r|=0,a|=0;var o=m();return c(o,i),o.width=0,o.height=0,p(o,t),o.width=o.width||(i.width>>a)-e,o.height=o.height||(i.height>>a)-r,D(i),d(o,3553,e,r,a),R(),T(o),n},n.resize=function(e,r){var a=0|e,s=0|r||a;if(a===i.width&&s===i.height)return n;n.width=i.width=a,n.height=i.height=s,D(i);for(var l,c=i.channels,u=i.type,h=0;i.mipmask>>h;++h){var f=a>>h,p=s>>h;if(!f||!p)break;l=G.zero.allocType(u,f*p*c),t.texImage2D(3553,h,i.format,f,p,0,i.format,i.type,l),l&&G.zero.freeType(l)}return R(),o.profile&&(i.stats.size=k(i.internalformat,i.type,a,s,!1,!1)),n},n._reglType=\"texture2d\",n._texture=i,o.profile&&(n.stats=i.stats),n.destroy=function(){i.decRef()},n},createCube:function(e,r,n,i,s,l){function h(t,e,r,n,i,a){var s,l=f.texInfo;for(P.call(l),s=0;6>s;++s)g[s]=C();if(\"number\"!=typeof t&&t){if(\"object\"==typeof t)if(e)S(g[0],t),S(g[1],e),S(g[2],r),S(g[3],n),S(g[4],i),S(g[5],a);else if(O(l,t),u(f,t),\"faces\"in t)for(t=t.faces,s=0;6>s;++s)c(g[s],f),S(g[s],t[s]);else for(s=0;6>s;++s)S(g[s],t)}else for(t=0|t||1,s=0;6>s;++s)M(g[s],t,t);for(c(f,g[0]),f.mipmask=l.genMipmaps?(g[0].width<<1)-1:g[0].mipmask,f.internalformat=g[0].internalformat,h.width=g[0].width,h.height=g[0].height,D(f),s=0;6>s;++s)E(g[s],34069+s);for(z(l,34067),R(),o.profile&&(f.stats.size=k(f.internalformat,f.type,h.width,h.height,l.genMipmaps,!0)),h.format=tt[f.internalformat],h.type=et[f.type],h.mag=rt[l.magFilter],h.min=nt[l.minFilter],h.wrapS=it[l.wrapS],h.wrapT=it[l.wrapT],s=0;6>s;++s)L(g[s]);return h}var f=new I(34067);mt[f.id]=f,a.cubeCount++;var g=Array(6);return h(e,r,n,i,s,l),h.subimage=function(t,e,r,n,i){r|=0,n|=0,i|=0;var a=m();return c(a,f),a.width=0,a.height=0,p(a,e),a.width=a.width||(f.width>>i)-r,a.height=a.height||(f.height>>i)-n,D(f),d(a,34069+t,r,n,i),R(),T(a),h},h.resize=function(e){if((e|=0)!==f.width){h.width=f.width=e,h.height=f.height=e,D(f);for(var r=0;6>r;++r)for(var n=0;f.mipmask>>n;++n)t.texImage2D(34069+r,n,f.format,e>>n,e>>n,0,f.format,f.type,null);return R(),o.profile&&(f.stats.size=k(f.internalformat,f.type,h.width,h.height,!1,!0)),h}},h._reglType=\"textureCube\",h._texture=f,o.profile&&(h.stats=f.stats),h.destroy=function(){f.decRef()},h},clear:function(){for(var e=0;e<yt;++e)t.activeTexture(33984+e),t.bindTexture(3553,null),xt[e]=null;X(mt).forEach(F),a.cubeCount=0,a.textureCount=0},getTexture:function(t){return null},restore:function(){for(var e=0;e<yt;++e){var r=xt[e];r&&(r.bindCount=0,r.unit=-1,xt[e]=null)}X(mt).forEach(function(e){e.texture=t.createTexture(),t.bindTexture(e.target,e.texture);for(var r=0;32>r;++r)if(0!=(e.mipmask&1<<r))if(3553===e.target)t.texImage2D(3553,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);else for(var n=0;6>n;++n)t.texImage2D(34069+n,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);z(e.texInfo,e.target)})}}}function A(t,e,r,n,i,a){function o(t,e,r){this.target=t,this.texture=e,this.renderbuffer=r;var n=t=0;e?(t=e.width,n=e.height):r&&(t=r.width,n=r.height),this.width=t,this.height=n}function s(t){t&&(t.texture&&t.texture._texture.decRef(),t.renderbuffer&&t.renderbuffer._renderbuffer.decRef())}function l(t,e,r){t&&(t.texture?t.texture._texture.refCount+=1:t.renderbuffer._renderbuffer.refCount+=1)}function c(e,r){r&&(r.texture?t.framebufferTexture2D(36160,e,r.target,r.texture._texture.texture,0):t.framebufferRenderbuffer(36160,e,36161,r.renderbuffer._renderbuffer.renderbuffer))}function u(t){var e=3553,r=null,n=null,i=t;return\"object\"==typeof t&&(i=t.data,\"target\"in t&&(e=0|t.target)),\"texture2d\"===(t=i._reglType)?r=i:\"textureCube\"===t?r=i:\"renderbuffer\"===t&&(n=i,e=36161),new o(e,r,n)}function h(t,e,r,a,s){return r?((t=n.create2D({width:t,height:e,format:a,type:s}))._texture.refCount=0,new o(3553,t,null)):((t=i.create({width:t,height:e,format:a}))._renderbuffer.refCount=0,new o(36161,null,t))}function f(t){return t&&(t.texture||t.renderbuffer)}function p(t,e,r){t&&(t.texture?t.texture.resize(e,r):t.renderbuffer&&t.renderbuffer.resize(e,r),t.width=e,t.height=r)}function d(){this.id=k++,T[this.id]=this,this.framebuffer=t.createFramebuffer(),this.height=this.width=0,this.colorAttachments=[],this.depthStencilAttachment=this.stencilAttachment=this.depthAttachment=null}function g(t){t.colorAttachments.forEach(s),s(t.depthAttachment),s(t.stencilAttachment),s(t.depthStencilAttachment)}function v(e){t.deleteFramebuffer(e.framebuffer),e.framebuffer=null,a.framebufferCount--,delete T[e.id]}function m(e){var n;t.bindFramebuffer(36160,e.framebuffer);var i=e.colorAttachments;for(n=0;n<i.length;++n)c(36064+n,i[n]);for(n=i.length;n<r.maxColorAttachments;++n)t.framebufferTexture2D(36160,36064+n,3553,null,0);t.framebufferTexture2D(36160,33306,3553,null,0),t.framebufferTexture2D(36160,36096,3553,null,0),t.framebufferTexture2D(36160,36128,3553,null,0),c(36096,e.depthAttachment),c(36128,e.stencilAttachment),c(33306,e.depthStencilAttachment),t.checkFramebufferStatus(36160),t.isContextLost(),t.bindFramebuffer(36160,x.next?x.next.framebuffer:null),x.cur=x.next,t.getError()}function y(t,e){function r(t,e){var i,a=0,o=0,s=!0,c=!0;i=null;var p=!0,d=\"rgba\",v=\"uint8\",y=1,x=null,w=null,k=null,T=!1;\"number\"==typeof t?(a=0|t,o=0|e||a):t?(\"shape\"in t?(a=(o=t.shape)[0],o=o[1]):(\"radius\"in t&&(a=o=t.radius),\"width\"in t&&(a=t.width),\"height\"in t&&(o=t.height)),(\"color\"in t||\"colors\"in t)&&(i=t.color||t.colors,Array.isArray(i)),i||(\"colorCount\"in t&&(y=0|t.colorCount),\"colorTexture\"in t&&(p=!!t.colorTexture,d=\"rgba4\"),\"colorType\"in t&&(v=t.colorType,!p)&&(\"half float\"===v||\"float16\"===v?d=\"rgba16f\":\"float\"!==v&&\"float32\"!==v||(d=\"rgba32f\")),\"colorFormat\"in t&&(d=t.colorFormat,0<=b.indexOf(d)?p=!0:0<=_.indexOf(d)&&(p=!1))),(\"depthTexture\"in t||\"depthStencilTexture\"in t)&&(T=!(!t.depthTexture&&!t.depthStencilTexture)),\"depth\"in t&&(\"boolean\"==typeof t.depth?s=t.depth:(x=t.depth,c=!1)),\"stencil\"in t&&(\"boolean\"==typeof t.stencil?c=t.stencil:(w=t.stencil,s=!1)),\"depthStencil\"in t&&(\"boolean\"==typeof t.depthStencil?s=c=t.depthStencil:(k=t.depthStencil,c=s=!1))):a=o=1;var A=null,M=null,S=null,E=null;if(Array.isArray(i))A=i.map(u);else if(i)A=[u(i)];else for(A=Array(y),i=0;i<y;++i)A[i]=h(a,o,p,d,v);for(a=a||A[0].width,o=o||A[0].height,x?M=u(x):s&&!c&&(M=h(a,o,T,\"depth\",\"uint32\")),w?S=u(w):c&&!s&&(S=h(a,o,!1,\"stencil\",\"uint8\")),k?E=u(k):!x&&!w&&c&&s&&(E=h(a,o,T,\"depth stencil\",\"depth stencil\")),s=null,i=0;i<A.length;++i)l(A[i]),A[i]&&A[i].texture&&(c=yt[A[i].texture._texture.format]*xt[A[i].texture._texture.type],null===s&&(s=c));return l(M),l(S),l(E),g(n),n.width=a,n.height=o,n.colorAttachments=A,n.depthAttachment=M,n.stencilAttachment=S,n.depthStencilAttachment=E,r.color=A.map(f),r.depth=f(M),r.stencil=f(S),r.depthStencil=f(E),r.width=n.width,r.height=n.height,m(n),r}var n=new d;return a.framebufferCount++,r(t,e),j(r,{resize:function(t,e){var i=Math.max(0|t,1),a=Math.max(0|e||i,1);if(i===n.width&&a===n.height)return r;for(var o=n.colorAttachments,s=0;s<o.length;++s)p(o[s],i,a);return p(n.depthAttachment,i,a),p(n.stencilAttachment,i,a),p(n.depthStencilAttachment,i,a),n.width=r.width=i,n.height=r.height=a,m(n),r},_reglType:\"framebuffer\",_framebuffer:n,destroy:function(){v(n),g(n)},use:function(t){x.setFBO({framebuffer:r},t)}})}var x={cur:null,next:null,dirty:!1,setFBO:null},b=[\"rgba\"],_=[\"rgba4\",\"rgb565\",\"rgb5 a1\"];e.ext_srgb&&_.push(\"srgba\"),e.ext_color_buffer_half_float&&_.push(\"rgba16f\",\"rgb16f\"),e.webgl_color_buffer_float&&_.push(\"rgba32f\");var w=[\"uint8\"];e.oes_texture_half_float&&w.push(\"half float\",\"float16\"),e.oes_texture_float&&w.push(\"float\",\"float32\");var k=0,T={};return j(x,{getFramebuffer:function(t){return\"function\"==typeof t&&\"framebuffer\"===t._reglType&&(t=t._framebuffer)instanceof d?t:null},create:y,createCube:function(t){function e(t){var i,a={color:null},o=0,s=null;i=\"rgba\";var l=\"uint8\",c=1;if(\"number\"==typeof t?o=0|t:t?(\"shape\"in t?o=t.shape[0]:(\"radius\"in t&&(o=0|t.radius),\"width\"in t?o=0|t.width:\"height\"in t&&(o=0|t.height)),(\"color\"in t||\"colors\"in t)&&(s=t.color||t.colors,Array.isArray(s)),s||(\"colorCount\"in t&&(c=0|t.colorCount),\"colorType\"in t&&(l=t.colorType),\"colorFormat\"in t&&(i=t.colorFormat)),\"depth\"in t&&(a.depth=t.depth),\"stencil\"in t&&(a.stencil=t.stencil),\"depthStencil\"in t&&(a.depthStencil=t.depthStencil)):o=1,s)if(Array.isArray(s))for(t=[],i=0;i<s.length;++i)t[i]=s[i];else t=[s];else for(t=Array(c),s={radius:o,format:i,type:l},i=0;i<c;++i)t[i]=n.createCube(s);for(a.color=Array(t.length),i=0;i<t.length;++i)c=t[i],o=o||c.width,a.color[i]={target:34069,data:t[i]};for(i=0;6>i;++i){for(c=0;c<t.length;++c)a.color[c].target=34069+i;0<i&&(a.depth=r[0].depth,a.stencil=r[0].stencil,a.depthStencil=r[0].depthStencil),r[i]?r[i](a):r[i]=y(a)}return j(e,{width:o,height:o,color:t})}var r=Array(6);return e(t),j(e,{faces:r,resize:function(t){var n=0|t;if(n===e.width)return e;var i=e.color;for(t=0;t<i.length;++t)i[t].resize(n);for(t=0;6>t;++t)r[t].resize(n);return e.width=e.height=n,e},_reglType:\"framebufferCube\",destroy:function(){r.forEach(function(t){t.destroy()})}})},clear:function(){X(T).forEach(v)},restore:function(){x.cur=null,x.next=null,x.dirty=!0,X(T).forEach(function(e){e.framebuffer=t.createFramebuffer(),m(e)})}})}function M(){this.w=this.z=this.y=this.x=this.state=0,this.buffer=null,this.size=0,this.normalized=!1,this.type=5126,this.divisor=this.stride=this.offset=0}function S(t,e,r,n){function i(t,e,r,n){this.name=t,this.id=e,this.location=r,this.info=n}function a(t,e){for(var r=0;r<t.length;++r)if(t[r].id===e.id)return void(t[r].location=e.location);t.push(e)}function o(r,n,i){if(!(o=(i=35632===r?c:u)[n])){var a=e.str(n),o=t.createShader(r);t.shaderSource(o,a),t.compileShader(o),i[n]=o}return o}function s(t,e){this.id=p++,this.fragId=t,this.vertId=e,this.program=null,this.uniforms=[],this.attributes=[],n.profile&&(this.stats={uniformsCount:0,attributesCount:0})}function l(r,s){var l,c;l=o(35632,r.fragId),c=o(35633,r.vertId);var u=r.program=t.createProgram();t.attachShader(u,l),t.attachShader(u,c),t.linkProgram(u);var h=t.getProgramParameter(u,35718);n.profile&&(r.stats.uniformsCount=h);var f=r.uniforms;for(l=0;l<h;++l)if(c=t.getActiveUniform(u,l))if(1<c.size)for(var p=0;p<c.size;++p){var d=c.name.replace(\"[0]\",\"[\"+p+\"]\");a(f,new i(d,e.id(d),t.getUniformLocation(u,d),c))}else a(f,new i(c.name,e.id(c.name),t.getUniformLocation(u,c.name),c));for(h=t.getProgramParameter(u,35721),n.profile&&(r.stats.attributesCount=h),f=r.attributes,l=0;l<h;++l)(c=t.getActiveAttrib(u,l))&&a(f,new i(c.name,e.id(c.name),t.getAttribLocation(u,c.name),c))}var c={},u={},h={},f=[],p=0;return n.profile&&(r.getMaxUniformsCount=function(){var t=0;return f.forEach(function(e){e.stats.uniformsCount>t&&(t=e.stats.uniformsCount)}),t},r.getMaxAttributesCount=function(){var t=0;return f.forEach(function(e){e.stats.attributesCount>t&&(t=e.stats.attributesCount)}),t}),{clear:function(){var e=t.deleteShader.bind(t);X(c).forEach(e),c={},X(u).forEach(e),u={},f.forEach(function(e){t.deleteProgram(e.program)}),f.length=0,h={},r.shaderCount=0},program:function(t,e,n){var i=h[e];i||(i=h[e]={});var a=i[t];return a||(a=new s(e,t),r.shaderCount++,l(a),i[t]=a,f.push(a)),a},restore:function(){c={},u={};for(var t=0;t<f.length;++t)l(f[t])},shader:o,frag:-1,vert:-1}}function E(t,e,r,n,i,a,o){function s(i){var a;a=null===e.next?5121:e.next.colorAttachments[0].texture._texture.type;var o=0,s=0,l=n.framebufferWidth,c=n.framebufferHeight,u=null;return W(i)?u=i:i&&(o=0|i.x,s=0|i.y,l=0|(i.width||n.framebufferWidth-o),c=0|(i.height||n.framebufferHeight-s),u=i.data||null),r(),i=l*c*4,u||(5121===a?u=new Uint8Array(i):5126===a&&(u=u||new Float32Array(i))),t.pixelStorei(3333,4),t.readPixels(o,s,l,c,6408,a,u),u}return function(t){return t&&\"framebuffer\"in t?function(t){var r;return e.setFBO({framebuffer:t.framebuffer},function(){r=s(t)}),r}(t):s(t)}}function C(t){return Array.prototype.slice.call(t)}function L(t){return C(t).join(\"\")}function P(){function t(){var t=[],e=[];return j(function(){t.push.apply(t,C(arguments))},{def:function(){var n=\"v\"+r++;return e.push(n),0<arguments.length&&(t.push(n,\"=\"),t.push.apply(t,C(arguments)),t.push(\";\")),n},toString:function(){return L([0<e.length?\"var \"+e+\";\":\"\",L(t)])}})}function e(){function e(t,e){n(t,e,\"=\",r.def(t,e),\";\")}var r=t(),n=t(),i=r.toString,a=n.toString;return j(function(){r.apply(r,C(arguments))},{def:r.def,entry:r,exit:n,save:e,set:function(t,n,i){e(t,n),r(t,n,\"=\",i,\";\")},toString:function(){return i()+a()}})}var r=0,n=[],i=[],a=t(),o={};return{global:a,link:function(t){for(var e=0;e<i.length;++e)if(i[e]===t)return n[e];return e=\"g\"+r++,n.push(e),i.push(t),e},block:t,proc:function(t,r){function n(){var t=\"a\"+i.length;return i.push(t),t}var i=[];r=r||0;for(var a=0;a<r;++a)n();var s=(a=e()).toString;return o[t]=j(a,{arg:n,toString:function(){return L([\"function(\",i.join(),\"){\",s(),\"}\"])}})},scope:e,cond:function(){var t=L(arguments),r=e(),n=e(),i=r.toString,a=n.toString;return j(r,{then:function(){return r.apply(r,C(arguments)),this},else:function(){return n.apply(n,C(arguments)),this},toString:function(){var e=a();return e&&(e=\"else{\"+e+\"}\"),L([\"if(\",t,\"){\",i(),\"}\",e])}})},compile:function(){var t=['\"use strict\";',a,\"return {\"];Object.keys(o).forEach(function(e){t.push('\"',e,'\":',o[e].toString(),\",\")}),t.push(\"}\");var e=L(t).replace(/;/g,\";\\n\").replace(/}/g,\"}\\n\").replace(/{/g,\"{\\n\");return Function.apply(null,n.concat(e)).apply(null,i)}}}function O(t){return Array.isArray(t)||W(t)||l(t)}function z(t){return t.sort(function(t,e){return\"viewport\"===t?-1:\"viewport\"===e?1:t<e?-1:1})}function I(t,e,r,n){this.thisDep=t,this.contextDep=e,this.propDep=r,this.append=n}function D(t){return t&&!(t.thisDep||t.contextDep||t.propDep)}function R(t){return new I(!1,!1,!1,t)}function F(t,e){var r=t.type;return 0===r?new I(!0,1<=(r=t.data.length),2<=r,e):4===r?new I((r=t.data).thisDep,r.contextDep,r.propDep,e):new I(3===r,2===r,1===r,e)}function B(t,e,r,n,i,o,s,l,c,u,h,f,p,d,g){function m(t){return t.replace(\".\",\"_\")}function y(t,e,r){var n=m(t);nt.push(t),et[n]=tt[n]=!!r,it[n]=e}function x(t,e,r){var n=m(t);nt.push(t),Array.isArray(r)?(tt[n]=r.slice(),et[n]=r.slice()):tt[n]=et[n]=r,at[n]=e}function b(){var t=P(),r=t.link,n=t.global;t.id=lt++,t.batchId=\"0\";var i=r(ot),a=t.shared={props:\"a0\"};Object.keys(ot).forEach(function(t){a[t]=n.def(i,\".\",t)});var o=t.next={},s=t.current={};Object.keys(at).forEach(function(t){Array.isArray(tt[t])&&(o[t]=n.def(a.next,\".\",t),s[t]=n.def(a.current,\".\",t))});var l=t.constants={};Object.keys(st).forEach(function(t){l[t]=n.def(JSON.stringify(st[t]))}),t.invoke=function(e,n){switch(n.type){case 0:var i=[\"this\",a.context,a.props,t.batchId];return e.def(r(n.data),\".call(\",i.slice(0,Math.max(n.data.length+1,4)),\")\");case 1:return e.def(a.props,n.data);case 2:return e.def(a.context,n.data);case 3:return e.def(\"this\",n.data);case 4:return n.data.append(t,e),n.data.ref}},t.attribCache={};var c={};return t.scopeAttrib=function(t){if((t=e.id(t))in c)return c[t];var n=u.scope[t];return n||(n=u.scope[t]=new Z),c[t]=r(n)},t}function _(t,e){var r=t.static,n=t.dynamic;if(\"framebuffer\"in r){var i=r.framebuffer;return i?(i=l.getFramebuffer(i),R(function(t,e){var r=t.link(i),n=t.shared;return e.set(n.framebuffer,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\".width\"),e.set(n,\".framebufferHeight\",r+\".height\"),r})):R(function(t,e){var r=t.shared;return e.set(r.framebuffer,\".next\",\"null\"),r=r.context,e.set(r,\".framebufferWidth\",r+\".drawingBufferWidth\"),e.set(r,\".framebufferHeight\",r+\".drawingBufferHeight\"),\"null\"})}if(\"framebuffer\"in n){var a=n.framebuffer;return F(a,function(t,e){var r=t.invoke(e,a),n=t.shared,i=n.framebuffer;r=e.def(i,\".getFramebuffer(\",r,\")\");return e.set(i,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\"?\"+r+\".width:\"+n+\".drawingBufferWidth\"),e.set(n,\".framebufferHeight\",r+\"?\"+r+\".height:\"+n+\".drawingBufferHeight\"),r})}return null}function w(t){function r(t){if(t in n){var r=e.id(n[t]);return(t=R(function(){return r})).id=r,t}if(t in i){var a=i[t];return F(a,function(t,e){var r=t.invoke(e,a);return e.def(t.shared.strings,\".id(\",r,\")\")})}return null}var n=t.static,i=t.dynamic,a=r(\"frag\"),o=r(\"vert\"),s=null;return D(a)&&D(o)?(s=h.program(o.id,a.id),t=R(function(t,e){return t.link(s)})):t=new I(a&&a.thisDep||o&&o.thisDep,a&&a.contextDep||o&&o.contextDep,a&&a.propDep||o&&o.propDep,function(t,e){var r,n,i=t.shared.shader;return r=a?a.append(t,e):e.def(i,\".\",\"frag\"),n=o?o.append(t,e):e.def(i,\".\",\"vert\"),e.def(i+\".program(\"+n+\",\"+r+\")\")}),{frag:a,vert:o,progVar:t,program:s}}function k(t,e){function r(t,e){if(t in n){var r=0|n[t];return R(function(t,n){return e&&(t.OFFSET=r),r})}if(t in i){var o=i[t];return F(o,function(t,r){var n=t.invoke(r,o);return e&&(t.OFFSET=n),n})}return e&&a?R(function(t,e){return t.OFFSET=\"0\",0}):null}var n=t.static,i=t.dynamic,a=function(){if(\"elements\"in n){var t=n.elements;O(t)?t=o.getElements(o.create(t,!0)):t&&(t=o.getElements(t));var e=R(function(e,r){if(t){var n=e.link(t);return e.ELEMENTS=n}return e.ELEMENTS=null});return e.value=t,e}if(\"elements\"in i){var r=i.elements;return F(r,function(t,e){var n=(i=t.shared).isBufferArgs,i=i.elements,a=t.invoke(e,r),o=e.def(\"null\");n=e.def(n,\"(\",a,\")\"),a=t.cond(n).then(o,\"=\",i,\".createStream(\",a,\");\").else(o,\"=\",i,\".getElements(\",a,\");\");return e.entry(a),e.exit(t.cond(n).then(i,\".destroyStream(\",o,\");\")),t.ELEMENTS=o})}return null}(),s=r(\"offset\",!0);return{elements:a,primitive:function(){if(\"primitive\"in n){var t=n.primitive;return R(function(e,r){return rt[t]})}if(\"primitive\"in i){var e=i.primitive;return F(e,function(t,r){var n=t.constants.primTypes,i=t.invoke(r,e);return r.def(n,\"[\",i,\"]\")})}return a?D(a)?a.value?R(function(t,e){return e.def(t.ELEMENTS,\".primType\")}):R(function(){return 4}):new I(a.thisDep,a.contextDep,a.propDep,function(t,e){var r=t.ELEMENTS;return e.def(r,\"?\",r,\".primType:\",4)}):null}(),count:function(){if(\"count\"in n){var t=0|n.count;return R(function(){return t})}if(\"count\"in i){var e=i.count;return F(e,function(t,r){return t.invoke(r,e)})}return a?D(a)?a?s?new I(s.thisDep,s.contextDep,s.propDep,function(t,e){return e.def(t.ELEMENTS,\".vertCount-\",t.OFFSET)}):R(function(t,e){return e.def(t.ELEMENTS,\".vertCount\")}):R(function(){return-1}):new I(a.thisDep||s.thisDep,a.contextDep||s.contextDep,a.propDep||s.propDep,function(t,e){var r=t.ELEMENTS;return t.OFFSET?e.def(r,\"?\",r,\".vertCount-\",t.OFFSET,\":-1\"):e.def(r,\"?\",r,\".vertCount:-1\")}):null}(),instances:r(\"instances\",!1),offset:s}}function T(t,r){var n=t.static,a=t.dynamic,o={};return Object.keys(n).forEach(function(t){var r=n[t],a=e.id(t),s=new Z;if(O(r))s.state=1,s.buffer=i.getBuffer(i.create(r,34962,!1,!0)),s.type=0;else if(c=i.getBuffer(r))s.state=1,s.buffer=c,s.type=0;else if(\"constant\"in r){var l=r.constant;s.buffer=\"null\",s.state=2,\"number\"==typeof l?s.x=l:bt.forEach(function(t,e){e<l.length&&(s[t]=l[e])})}else{var c=O(r.buffer)?i.getBuffer(i.create(r.buffer,34962,!1,!0)):i.getBuffer(r.buffer),u=0|r.offset,h=0|r.stride,f=0|r.size,p=!!r.normalized,d=0;\"type\"in r&&(d=K[r.type]),r=0|r.divisor,s.buffer=c,s.state=1,s.size=f,s.normalized=p,s.type=d||c.dtype,s.offset=u,s.stride=h,s.divisor=r}o[t]=R(function(t,e){var r=t.attribCache;if(a in r)return r[a];var n={isStream:!1};return Object.keys(s).forEach(function(t){n[t]=s[t]}),s.buffer&&(n.buffer=t.link(s.buffer),n.type=n.type||n.buffer+\".dtype\"),r[a]=n})}),Object.keys(a).forEach(function(t){var e=a[t];o[t]=F(e,function(t,r){function n(t){r(l[t],\"=\",i,\".\",t,\"|0;\")}var i=t.invoke(r,e),a=t.shared,o=a.isBufferArgs,s=a.buffer,l={isStream:r.def(!1)},c=new Z;c.state=1,Object.keys(c).forEach(function(t){l[t]=r.def(\"\"+c[t])});var u=l.buffer,h=l.type;return r(\"if(\",o,\"(\",i,\")){\",l.isStream,\"=true;\",u,\"=\",s,\".createStream(\",34962,\",\",i,\");\",h,\"=\",u,\".dtype;\",\"}else{\",u,\"=\",s,\".getBuffer(\",i,\");\",\"if(\",u,\"){\",h,\"=\",u,\".dtype;\",'}else if(\"constant\" in ',i,\"){\",l.state,\"=\",2,\";\",\"if(typeof \"+i+'.constant === \"number\"){',l[bt[0]],\"=\",i,\".constant;\",bt.slice(1).map(function(t){return l[t]}).join(\"=\"),\"=0;\",\"}else{\",bt.map(function(t,e){return l[t]+\"=\"+i+\".constant.length>\"+e+\"?\"+i+\".constant[\"+e+\"]:0;\"}).join(\"\"),\"}}else{\",\"if(\",o,\"(\",i,\".buffer)){\",u,\"=\",s,\".createStream(\",34962,\",\",i,\".buffer);\",\"}else{\",u,\"=\",s,\".getBuffer(\",i,\".buffer);\",\"}\",h,'=\"type\" in ',i,\"?\",a.glTypes,\"[\",i,\".type]:\",u,\".dtype;\",l.normalized,\"=!!\",i,\".normalized;\"),n(\"size\"),n(\"offset\"),n(\"stride\"),n(\"divisor\"),r(\"}}\"),r.exit(\"if(\",l.isStream,\"){\",s,\".destroyStream(\",u,\");\",\"}\"),l})}),o}function A(t,e,r,n,i){var o=_(t),s=function(t,e,r){function n(t){if(t in i){var r=i[t];t=!0;var n,o,s=0|r.x,l=0|r.y;return\"width\"in r?n=0|r.width:t=!1,\"height\"in r?o=0|r.height:t=!1,new I(!t&&e&&e.thisDep,!t&&e&&e.contextDep,!t&&e&&e.propDep,function(t,e){var i=t.shared.context,a=n;\"width\"in r||(a=e.def(i,\".\",\"framebufferWidth\",\"-\",s));var c=o;return\"height\"in r||(c=e.def(i,\".\",\"framebufferHeight\",\"-\",l)),[s,l,a,c]})}if(t in a){var c=a[t];return t=F(c,function(t,e){var r=t.invoke(e,c),n=t.shared.context,i=e.def(r,\".x|0\"),a=e.def(r,\".y|0\");return[i,a,e.def('\"width\" in ',r,\"?\",r,\".width|0:\",\"(\",n,\".\",\"framebufferWidth\",\"-\",i,\")\"),r=e.def('\"height\" in ',r,\"?\",r,\".height|0:\",\"(\",n,\".\",\"framebufferHeight\",\"-\",a,\")\")]}),e&&(t.thisDep=t.thisDep||e.thisDep,t.contextDep=t.contextDep||e.contextDep,t.propDep=t.propDep||e.propDep),t}return e?new I(e.thisDep,e.contextDep,e.propDep,function(t,e){var r=t.shared.context;return[0,0,e.def(r,\".\",\"framebufferWidth\"),e.def(r,\".\",\"framebufferHeight\")]}):null}var i=t.static,a=t.dynamic;if(t=n(\"viewport\")){var o=t;t=new I(t.thisDep,t.contextDep,t.propDep,function(t,e){var r=o.append(t,e),n=t.shared.context;return e.set(n,\".viewportWidth\",r[2]),e.set(n,\".viewportHeight\",r[3]),r})}return{viewport:t,scissor_box:n(\"scissor.box\")}}(t,o),l=k(t),c=function(t,e){var r=t.static,n=t.dynamic,i={};return nt.forEach(function(t){function e(e,a){if(t in r){var s=e(r[t]);i[o]=R(function(){return s})}else if(t in n){var l=n[t];i[o]=F(l,function(t,e){return a(t,e,t.invoke(e,l))})}}var o=m(t);switch(t){case\"cull.enable\":case\"blend.enable\":case\"dither\":case\"stencil.enable\":case\"depth.enable\":case\"scissor.enable\":case\"polygonOffset.enable\":case\"sample.alpha\":case\"sample.enable\":case\"depth.mask\":return e(function(t){return t},function(t,e,r){return r});case\"depth.func\":return e(function(t){return kt[t]},function(t,e,r){return e.def(t.constants.compareFuncs,\"[\",r,\"]\")});case\"depth.range\":return e(function(t){return t},function(t,e,r){return[e.def(\"+\",r,\"[0]\"),e=e.def(\"+\",r,\"[1]\")]});case\"blend.func\":return e(function(t){return[wt[\"srcRGB\"in t?t.srcRGB:t.src],wt[\"dstRGB\"in t?t.dstRGB:t.dst],wt[\"srcAlpha\"in t?t.srcAlpha:t.src],wt[\"dstAlpha\"in t?t.dstAlpha:t.dst]]},function(t,e,r){function n(t,n){return e.def('\"',t,n,'\" in ',r,\"?\",r,\".\",t,n,\":\",r,\".\",t)}t=t.constants.blendFuncs;var i=n(\"src\",\"RGB\"),a=n(\"dst\",\"RGB\"),o=(i=e.def(t,\"[\",i,\"]\"),e.def(t,\"[\",n(\"src\",\"Alpha\"),\"]\"));return[i,a=e.def(t,\"[\",a,\"]\"),o,t=e.def(t,\"[\",n(\"dst\",\"Alpha\"),\"]\")]});case\"blend.equation\":return e(function(t){return\"string\"==typeof t?[J[t],J[t]]:\"object\"==typeof t?[J[t.rgb],J[t.alpha]]:void 0},function(t,e,r){var n=t.constants.blendEquations,i=e.def(),a=e.def();return(t=t.cond(\"typeof \",r,'===\"string\"')).then(i,\"=\",a,\"=\",n,\"[\",r,\"];\"),t.else(i,\"=\",n,\"[\",r,\".rgb];\",a,\"=\",n,\"[\",r,\".alpha];\"),e(t),[i,a]});case\"blend.color\":return e(function(t){return a(4,function(e){return+t[e]})},function(t,e,r){return a(4,function(t){return e.def(\"+\",r,\"[\",t,\"]\")})});case\"stencil.mask\":return e(function(t){return 0|t},function(t,e,r){return e.def(r,\"|0\")});case\"stencil.func\":return e(function(t){return[kt[t.cmp||\"keep\"],t.ref||0,\"mask\"in t?t.mask:-1]},function(t,e,r){return[t=e.def('\"cmp\" in ',r,\"?\",t.constants.compareFuncs,\"[\",r,\".cmp]\",\":\",7680),e.def(r,\".ref|0\"),e=e.def('\"mask\" in ',r,\"?\",r,\".mask|0:-1\")]});case\"stencil.opFront\":case\"stencil.opBack\":return e(function(e){return[\"stencil.opBack\"===t?1029:1028,Tt[e.fail||\"keep\"],Tt[e.zfail||\"keep\"],Tt[e.zpass||\"keep\"]]},function(e,r,n){function i(t){return r.def('\"',t,'\" in ',n,\"?\",a,\"[\",n,\".\",t,\"]:\",7680)}var a=e.constants.stencilOps;return[\"stencil.opBack\"===t?1029:1028,i(\"fail\"),i(\"zfail\"),i(\"zpass\")]});case\"polygonOffset.offset\":return e(function(t){return[0|t.factor,0|t.units]},function(t,e,r){return[e.def(r,\".factor|0\"),e=e.def(r,\".units|0\")]});case\"cull.face\":return e(function(t){var e=0;return\"front\"===t?e=1028:\"back\"===t&&(e=1029),e},function(t,e,r){return e.def(r,'===\"front\"?',1028,\":\",1029)});case\"lineWidth\":return e(function(t){return t},function(t,e,r){return r});case\"frontFace\":return e(function(t){return At[t]},function(t,e,r){return e.def(r+'===\"cw\"?2304:2305')});case\"colorMask\":return e(function(t){return t.map(function(t){return!!t})},function(t,e,r){return a(4,function(t){return\"!!\"+r+\"[\"+t+\"]\"})});case\"sample.coverage\":return e(function(t){return[\"value\"in t?t.value:1,!!t.invert]},function(t,e,r){return[e.def('\"value\" in ',r,\"?+\",r,\".value:1\"),e=e.def(\"!!\",r,\".invert\")]})}}),i}(t),u=w(t),h=s.viewport;return h&&(c.viewport=h),(s=s[h=m(\"scissor.box\")])&&(c[h]=s),(o={framebuffer:o,draw:l,shader:u,state:c,dirty:s=0<Object.keys(c).length}).profile=function(t){var e,r=t.static;if(t=t.dynamic,\"profile\"in r){var n=!!r.profile;(e=R(function(t,e){return n})).enable=n}else if(\"profile\"in t){var i=t.profile;e=F(i,function(t,e){return t.invoke(e,i)})}return e}(t),o.uniforms=function(t,e){var r=t.static,n=t.dynamic,i={};return Object.keys(r).forEach(function(t){var e,n=r[t];if(\"number\"==typeof n||\"boolean\"==typeof n)e=R(function(){return n});else if(\"function\"==typeof n){var o=n._reglType;\"texture2d\"===o||\"textureCube\"===o?e=R(function(t){return t.link(n)}):\"framebuffer\"!==o&&\"framebufferCube\"!==o||(e=R(function(t){return t.link(n.color[0])}))}else v(n)&&(e=R(function(t){return t.global.def(\"[\",a(n.length,function(t){return n[t]}),\"]\")}));e.value=n,i[t]=e}),Object.keys(n).forEach(function(t){var e=n[t];i[t]=F(e,function(t,r){return t.invoke(r,e)})}),i}(r),o.attributes=T(e),o.context=function(t){var e=t.static,r=t.dynamic,n={};return Object.keys(e).forEach(function(t){var r=e[t];n[t]=R(function(t,e){return\"number\"==typeof r||\"boolean\"==typeof r?\"\"+r:t.link(r)})}),Object.keys(r).forEach(function(t){var e=r[t];n[t]=F(e,function(t,r){return t.invoke(r,e)})}),n}(n),o}function M(t,e,r){var n=t.shared.context,i=t.scope();Object.keys(r).forEach(function(a){e.save(n,\".\"+a),i(n,\".\",a,\"=\",r[a].append(t,e),\";\")}),e(i)}function S(t,e,r,n){var i,a=(s=t.shared).gl,o=s.framebuffer;Q&&(i=e.def(s.extensions,\".webgl_draw_buffers\"));var s=(l=t.constants).drawBuffer,l=l.backBuffer;t=r?r.append(t,e):e.def(o,\".next\"),n||e(\"if(\",t,\"!==\",o,\".cur){\"),e(\"if(\",t,\"){\",a,\".bindFramebuffer(\",36160,\",\",t,\".framebuffer);\"),Q&&e(i,\".drawBuffersWEBGL(\",s,\"[\",t,\".colorAttachments.length]);\"),e(\"}else{\",a,\".bindFramebuffer(\",36160,\",null);\"),Q&&e(i,\".drawBuffersWEBGL(\",l,\");\"),e(\"}\",o,\".cur=\",t,\";\"),n||e(\"}\")}function E(t,e,r){var n=t.shared,i=n.gl,o=t.current,s=t.next,l=n.current,c=n.next,u=t.cond(l,\".dirty\");nt.forEach(function(e){var n,h;if(!((e=m(e))in r.state))if(e in s){n=s[e],h=o[e];var f=a(tt[e].length,function(t){return u.def(n,\"[\",t,\"]\")});u(t.cond(f.map(function(t,e){return t+\"!==\"+h+\"[\"+e+\"]\"}).join(\"||\")).then(i,\".\",at[e],\"(\",f,\");\",f.map(function(t,e){return h+\"[\"+e+\"]=\"+t}).join(\";\"),\";\"))}else n=u.def(c,\".\",e),f=t.cond(n,\"!==\",l,\".\",e),u(f),e in it?f(t.cond(n).then(i,\".enable(\",it[e],\");\").else(i,\".disable(\",it[e],\");\"),l,\".\",e,\"=\",n,\";\"):f(i,\".\",at[e],\"(\",n,\");\",l,\".\",e,\"=\",n,\";\")}),0===Object.keys(r.state).length&&u(l,\".dirty=false;\"),e(u)}function C(t,e,r,n){var i=t.shared,a=t.current,o=i.current,s=i.gl;z(Object.keys(r)).forEach(function(i){var l=r[i];if(!n||n(l)){var c=l.append(t,e);if(it[i]){var u=it[i];D(l)?e(s,c?\".enable(\":\".disable(\",u,\");\"):e(t.cond(c).then(s,\".enable(\",u,\");\").else(s,\".disable(\",u,\");\")),e(o,\".\",i,\"=\",c,\";\")}else if(v(c)){var h=a[i];e(s,\".\",at[i],\"(\",c,\");\",c.map(function(t,e){return h+\"[\"+e+\"]=\"+t}).join(\";\"),\";\")}else e(s,\".\",at[i],\"(\",c,\");\",o,\".\",i,\"=\",c,\";\")}})}function L(t,e){$&&(t.instancing=e.def(t.shared.extensions,\".angle_instanced_arrays\"))}function B(t,e,r,n,i){function a(){return\"undefined\"==typeof performance?\"Date.now()\":\"performance.now()\"}function o(t){t(c=e.def(),\"=\",a(),\";\"),\"string\"==typeof i?t(f,\".count+=\",i,\";\"):t(f,\".count++;\"),d&&(n?t(u=e.def(),\"=\",g,\".getNumPendingQueries();\"):t(g,\".beginQuery(\",f,\");\"))}function s(t){t(f,\".cpuTime+=\",a(),\"-\",c,\";\"),d&&(n?t(g,\".pushScopeStats(\",u,\",\",g,\".getNumPendingQueries(),\",f,\");\"):t(g,\".endQuery();\"))}function l(t){var r=e.def(p,\".profile\");e(p,\".profile=\",t,\";\"),e.exit(p,\".profile=\",r,\";\")}var c,u,h=t.shared,f=t.stats,p=h.current,g=h.timer;if(r=r.profile){if(D(r))return void(r.enable?(o(e),s(e.exit),l(\"true\")):l(\"false\"));l(r=r.append(t,e))}else r=e.def(p,\".profile\");o(h=t.block()),e(\"if(\",r,\"){\",h,\"}\"),s(t=t.block()),e.exit(\"if(\",r,\"){\",t,\"}\")}function N(t,e,r,n,i){function a(r,n,i){function a(){e(\"if(!\",u,\".buffer){\",l,\".enableVertexAttribArray(\",c,\");}\");var r,a=i.type;r=i.size?e.def(i.size,\"||\",n):n,e(\"if(\",u,\".type!==\",a,\"||\",u,\".size!==\",r,\"||\",p.map(function(t){return u+\".\"+t+\"!==\"+i[t]}).join(\"||\"),\"){\",l,\".bindBuffer(\",34962,\",\",h,\".buffer);\",l,\".vertexAttribPointer(\",[c,r,a,i.normalized,i.stride,i.offset],\");\",u,\".type=\",a,\";\",u,\".size=\",r,\";\",p.map(function(t){return u+\".\"+t+\"=\"+i[t]+\";\"}).join(\"\"),\"}\"),$&&(a=i.divisor,e(\"if(\",u,\".divisor!==\",a,\"){\",t.instancing,\".vertexAttribDivisorANGLE(\",[c,a],\");\",u,\".divisor=\",a,\";}\"))}function s(){e(\"if(\",u,\".buffer){\",l,\".disableVertexAttribArray(\",c,\");\",\"}if(\",bt.map(function(t,e){return u+\".\"+t+\"!==\"+f[e]}).join(\"||\"),\"){\",l,\".vertexAttrib4f(\",c,\",\",f,\");\",bt.map(function(t,e){return u+\".\"+t+\"=\"+f[e]+\";\"}).join(\"\"),\"}\")}var l=o.gl,c=e.def(r,\".location\"),u=e.def(o.attributes,\"[\",c,\"]\");r=i.state;var h=i.buffer,f=[i.x,i.y,i.z,i.w],p=[\"buffer\",\"normalized\",\"offset\",\"stride\"];1===r?a():2===r?s():(e(\"if(\",r,\"===\",1,\"){\"),a(),e(\"}else{\"),s(),e(\"}\"))}var o=t.shared;n.forEach(function(n){var o,s=n.name,l=r.attributes[s];if(l){if(!i(l))return;o=l.append(t,e)}else{if(!i(Mt))return;var c=t.scopeAttrib(s);o={},Object.keys(new Z).forEach(function(t){o[t]=e.def(c,\".\",t)})}a(t.link(n),function(t){switch(t){case 35664:case 35667:case 35671:return 2;case 35665:case 35668:case 35672:return 3;case 35666:case 35669:case 35673:return 4;default:return 1}}(n.info.type),o)})}function j(t,r,n,i,o){for(var s,l=t.shared,c=l.gl,u=0;u<i.length;++u){var h,f=(g=i[u]).name,p=g.info.type,d=n.uniforms[f],g=t.link(g)+\".location\";if(d){if(!o(d))continue;if(D(d)){if(f=d.value,35678===p||35680===p)r(c,\".uniform1i(\",g,\",\",(p=t.link(f._texture||f.color[0]._texture))+\".bind());\"),r.exit(p,\".unbind();\");else if(35674===p||35675===p||35676===p)d=2,35675===p?d=3:35676===p&&(d=4),r(c,\".uniformMatrix\",d,\"fv(\",g,\",false,\",f=t.global.def(\"new Float32Array([\"+Array.prototype.slice.call(f)+\"])\"),\");\");else{switch(p){case 5126:s=\"1f\";break;case 35664:s=\"2f\";break;case 35665:s=\"3f\";break;case 35666:s=\"4f\";break;case 35670:case 5124:s=\"1i\";break;case 35671:case 35667:s=\"2i\";break;case 35672:case 35668:s=\"3i\";break;case 35673:s=\"4i\";break;case 35669:s=\"4i\"}r(c,\".uniform\",s,\"(\",g,\",\",v(f)?Array.prototype.slice.call(f):f,\");\")}continue}h=d.append(t,r)}else{if(!o(Mt))continue;h=r.def(l.uniforms,\"[\",e.id(f),\"]\")}switch(35678===p?r(\"if(\",h,\"&&\",h,'._reglType===\"framebuffer\"){',h,\"=\",h,\".color[0];\",\"}\"):35680===p&&r(\"if(\",h,\"&&\",h,'._reglType===\"framebufferCube\"){',h,\"=\",h,\".color[0];\",\"}\"),f=1,p){case 35678:case 35680:p=r.def(h,\"._texture\"),r(c,\".uniform1i(\",g,\",\",p,\".bind());\"),r.exit(p,\".unbind();\");continue;case 5124:case 35670:s=\"1i\";break;case 35667:case 35671:s=\"2i\",f=2;break;case 35668:case 35672:s=\"3i\",f=3;break;case 35669:case 35673:s=\"4i\",f=4;break;case 5126:s=\"1f\";break;case 35664:s=\"2f\",f=2;break;case 35665:s=\"3f\",f=3;break;case 35666:s=\"4f\",f=4;break;case 35674:s=\"Matrix2fv\";break;case 35675:s=\"Matrix3fv\";break;case 35676:s=\"Matrix4fv\"}if(r(c,\".uniform\",s,\"(\",g,\",\"),\"M\"===s.charAt(0)){g=Math.pow(p-35674+2,2);var m=t.global.def(\"new Float32Array(\",g,\")\");r(\"false,(Array.isArray(\",h,\")||\",h,\" instanceof Float32Array)?\",h,\":(\",a(g,function(t){return m+\"[\"+t+\"]=\"+h+\"[\"+t+\"]\"}),\",\",m,\")\")}else r(1<f?a(f,function(t){return h+\"[\"+t+\"]\"}):h);r(\");\")}}function U(t,e,r,n){function i(i){var a=f[i];return a?a.contextDep&&n.contextDynamic||a.propDep?a.append(t,r):a.append(t,e):e.def(h,\".\",i)}function a(){function t(){r(l,\".drawElementsInstancedANGLE(\",[d,v,m,g+\"<<((\"+m+\"-5121)>>1)\",s],\");\")}function e(){r(l,\".drawArraysInstancedANGLE(\",[d,g,v,s],\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}function o(){function t(){r(u+\".drawElements(\"+[d,v,m,g+\"<<((\"+m+\"-5121)>>1)\"]+\");\")}function e(){r(u+\".drawArrays(\"+[d,g,v]+\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}var s,l,c=t.shared,u=c.gl,h=c.draw,f=n.draw,p=function(){var i=f.elements,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(h,\".\",\"elements\"),i&&a(\"if(\"+i+\")\"+u+\".bindBuffer(34963,\"+i+\".buffer.buffer);\"),i}(),d=i(\"primitive\"),g=i(\"offset\"),v=function(){var i=f.count,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(h,\".\",\"count\"),i}();if(\"number\"==typeof v){if(0===v)return}else r(\"if(\",v,\"){\"),r.exit(\"}\");$&&(s=i(\"instances\"),l=t.instancing);var m=p+\".type\",y=f.elements&&D(f.elements);$&&(\"number\"!=typeof s||0<=s)?\"string\"==typeof s?(r(\"if(\",s,\">0){\"),a(),r(\"}else if(\",s,\"<0){\"),o(),r(\"}\")):a():o()}function q(t,e,r,n,i){return i=(e=b()).proc(\"body\",i),$&&(e.instancing=i.def(e.shared.extensions,\".angle_instanced_arrays\")),t(e,i,r,n),e.compile().body}function H(t,e,r,n){L(t,e),N(t,e,r,n.attributes,function(){return!0}),j(t,e,r,n.uniforms,function(){return!0}),U(t,e,e,r)}function G(t,e,r,n){function i(){return!0}t.batchId=\"a1\",L(t,e),N(t,e,r,n.attributes,i),j(t,e,r,n.uniforms,i),U(t,e,e,r)}function Y(t,e,r,n){function i(t){return t.contextDep&&o||t.propDep}function a(t){return!i(t)}L(t,e);var o=r.contextDep,s=e.def(),l=e.def();t.shared.props=l,t.batchId=s;var c=t.scope(),u=t.scope();e(c.entry,\"for(\",s,\"=0;\",s,\"<\",\"a1\",\";++\",s,\"){\",l,\"=\",\"a0\",\"[\",s,\"];\",u,\"}\",c.exit),r.needsContext&&M(t,u,r.context),r.needsFramebuffer&&S(t,u,r.framebuffer),C(t,u,r.state,i),r.profile&&i(r.profile)&&B(t,u,r,!1,!0),n?(N(t,c,r,n.attributes,a),N(t,u,r,n.attributes,i),j(t,c,r,n.uniforms,a),j(t,u,r,n.uniforms,i),U(t,c,u,r)):(e=t.global.def(\"{}\"),n=r.shader.progVar.append(t,u),l=u.def(n,\".id\"),c=u.def(e,\"[\",l,\"]\"),u(t.shared.gl,\".useProgram(\",n,\".program);\",\"if(!\",c,\"){\",c,\"=\",e,\"[\",l,\"]=\",t.link(function(e){return q(G,t,r,e,2)}),\"(\",n,\");}\",c,\".call(this,a0[\",s,\"],\",s,\");\"))}function W(t,r){function n(e){var n=r.shader[e];n&&i.set(a.shader,\".\"+e,n.append(t,i))}var i=t.proc(\"scope\",3);t.batchId=\"a2\";var a=t.shared,o=a.current;M(t,i,r.context),r.framebuffer&&r.framebuffer.append(t,i),z(Object.keys(r.state)).forEach(function(e){var n=r.state[e].append(t,i);v(n)?n.forEach(function(r,n){i.set(t.next[e],\"[\"+n+\"]\",r)}):i.set(a.next,\".\"+e,n)}),B(t,i,r,!0,!0),[\"elements\",\"offset\",\"count\",\"instances\",\"primitive\"].forEach(function(e){var n=r.draw[e];n&&i.set(a.draw,\".\"+e,\"\"+n.append(t,i))}),Object.keys(r.uniforms).forEach(function(n){i.set(a.uniforms,\"[\"+e.id(n)+\"]\",r.uniforms[n].append(t,i))}),Object.keys(r.attributes).forEach(function(e){var n=r.attributes[e].append(t,i),a=t.scopeAttrib(e);Object.keys(new Z).forEach(function(t){i.set(a,\".\"+t,n[t])})}),n(\"vert\"),n(\"frag\"),0<Object.keys(r.state).length&&(i(o,\".dirty=true;\"),i.exit(o,\".dirty=true;\")),i(\"a1(\",t.shared.context,\",a0,\",t.batchId,\");\")}function X(t,e,r){var n=e.static[r];if(n&&function(t){if(\"object\"==typeof t&&!v(t)){for(var e=Object.keys(t),r=0;r<e.length;++r)if(V.isDynamic(t[e[r]]))return!0;return!1}}(n)){var i=t.global,a=Object.keys(n),o=!1,s=!1,l=!1,c=t.global.def(\"{}\");a.forEach(function(e){var r=n[e];if(V.isDynamic(r))\"function\"==typeof r&&(r=n[e]=V.unbox(r)),e=F(r,null),o=o||e.thisDep,l=l||e.propDep,s=s||e.contextDep;else{switch(i(c,\".\",e,\"=\"),typeof r){case\"number\":i(r);break;case\"string\":i('\"',r,'\"');break;case\"object\":Array.isArray(r)&&i(\"[\",r.join(),\"]\");break;default:i(t.link(r))}i(\";\")}}),e.dynamic[r]=new V.DynamicVariable(4,{thisDep:o,contextDep:s,propDep:l,ref:c,append:function(t,e){a.forEach(function(r){var i=n[r];V.isDynamic(i)&&(i=t.invoke(e,i),e(c,\".\",r,\"=\",i,\";\"))})}}),delete e.static[r]}}var Z=u.Record,J={add:32774,subtract:32778,\"reverse subtract\":32779};r.ext_blend_minmax&&(J.min=32775,J.max=32776);var $=r.angle_instanced_arrays,Q=r.webgl_draw_buffers,tt={dirty:!0,profile:g.profile},et={},nt=[],it={},at={};y(\"dither\",3024),y(\"blend.enable\",3042),x(\"blend.color\",\"blendColor\",[0,0,0,0]),x(\"blend.equation\",\"blendEquationSeparate\",[32774,32774]),x(\"blend.func\",\"blendFuncSeparate\",[1,0,1,0]),y(\"depth.enable\",2929,!0),x(\"depth.func\",\"depthFunc\",513),x(\"depth.range\",\"depthRange\",[0,1]),x(\"depth.mask\",\"depthMask\",!0),x(\"colorMask\",\"colorMask\",[!0,!0,!0,!0]),y(\"cull.enable\",2884),x(\"cull.face\",\"cullFace\",1029),x(\"frontFace\",\"frontFace\",2305),x(\"lineWidth\",\"lineWidth\",1),y(\"polygonOffset.enable\",32823),x(\"polygonOffset.offset\",\"polygonOffset\",[0,0]),y(\"sample.alpha\",32926),y(\"sample.enable\",32928),x(\"sample.coverage\",\"sampleCoverage\",[1,!1]),y(\"stencil.enable\",2960),x(\"stencil.mask\",\"stencilMask\",-1),x(\"stencil.func\",\"stencilFunc\",[519,0,-1]),x(\"stencil.opFront\",\"stencilOpSeparate\",[1028,7680,7680,7680]),x(\"stencil.opBack\",\"stencilOpSeparate\",[1029,7680,7680,7680]),y(\"scissor.enable\",3089),x(\"scissor.box\",\"scissor\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]),x(\"viewport\",\"viewport\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]);var ot={gl:t,context:p,strings:e,next:et,current:tt,draw:f,elements:o,buffer:i,shader:h,attributes:u.state,uniforms:c,framebuffer:l,extensions:r,timer:d,isBufferArgs:O},st={primTypes:rt,compareFuncs:kt,blendFuncs:wt,blendEquations:J,stencilOps:Tt,glTypes:K,orientationType:At};Q&&(st.backBuffer=[1029],st.drawBuffer=a(n.maxDrawbuffers,function(t){return 0===t?[0]:a(t,function(t){return 36064+t})}));var lt=0;return{next:et,current:tt,procs:function(){var t=b(),e=t.proc(\"poll\"),r=t.proc(\"refresh\"),i=t.block();e(i),r(i);var o,s=t.shared,l=s.gl,c=s.next,u=s.current;i(u,\".dirty=false;\"),S(t,e),S(t,r,null,!0),$&&(o=t.link($));for(var h=0;h<n.maxAttributes;++h){var f=r.def(s.attributes,\"[\",h,\"]\"),p=t.cond(f,\".buffer\");p.then(l,\".enableVertexAttribArray(\",h,\");\",l,\".bindBuffer(\",34962,\",\",f,\".buffer.buffer);\",l,\".vertexAttribPointer(\",h,\",\",f,\".size,\",f,\".type,\",f,\".normalized,\",f,\".stride,\",f,\".offset);\").else(l,\".disableVertexAttribArray(\",h,\");\",l,\".vertexAttrib4f(\",h,\",\",f,\".x,\",f,\".y,\",f,\".z,\",f,\".w);\",f,\".buffer=null;\"),r(p),$&&r(o,\".vertexAttribDivisorANGLE(\",h,\",\",f,\".divisor);\")}return Object.keys(it).forEach(function(n){var a=it[n],o=i.def(c,\".\",n),s=t.block();s(\"if(\",o,\"){\",l,\".enable(\",a,\")}else{\",l,\".disable(\",a,\")}\",u,\".\",n,\"=\",o,\";\"),r(s),e(\"if(\",o,\"!==\",u,\".\",n,\"){\",s,\"}\")}),Object.keys(at).forEach(function(n){var o,s,h=at[n],f=tt[n],p=t.block();p(l,\".\",h,\"(\"),v(f)?(h=f.length,o=t.global.def(c,\".\",n),s=t.global.def(u,\".\",n),p(a(h,function(t){return o+\"[\"+t+\"]\"}),\");\",a(h,function(t){return s+\"[\"+t+\"]=\"+o+\"[\"+t+\"];\"}).join(\"\")),e(\"if(\",a(h,function(t){return o+\"[\"+t+\"]!==\"+s+\"[\"+t+\"]\"}).join(\"||\"),\"){\",p,\"}\")):(o=i.def(c,\".\",n),s=i.def(u,\".\",n),p(o,\");\",u,\".\",n,\"=\",o,\";\"),e(\"if(\",o,\"!==\",s,\"){\",p,\"}\")),r(p)}),t.compile()}(),compile:function(t,e,r,n,i){var a=b();return a.stats=a.link(i),Object.keys(e.static).forEach(function(t){X(a,e,t)}),_t.forEach(function(e){X(a,t,e)}),r=A(t,e,r,n),function(t,e){var r=t.proc(\"draw\",1);L(t,r),M(t,r,e.context),S(t,r,e.framebuffer),E(t,r,e),C(t,r,e.state),B(t,r,e,!1,!0);var n=e.shader.progVar.append(t,r);if(r(t.shared.gl,\".useProgram(\",n,\".program);\"),e.shader.program)H(t,r,e,e.shader.program);else{var i=t.global.def(\"{}\"),a=r.def(n,\".id\"),o=r.def(i,\"[\",a,\"]\");r(t.cond(o).then(o,\".call(this,a0);\").else(o,\"=\",i,\"[\",a,\"]=\",t.link(function(r){return q(H,t,e,r,1)}),\"(\",n,\");\",o,\".call(this,a0);\"))}0<Object.keys(e.state).length&&r(t.shared.current,\".dirty=true;\")}(a,r),W(a,r),function(t,e){function r(t){return t.contextDep&&i||t.propDep}var n=t.proc(\"batch\",2);t.batchId=\"0\",L(t,n);var i=!1,a=!0;Object.keys(e.context).forEach(function(t){i=i||e.context[t].propDep}),i||(M(t,n,e.context),a=!1);var o=!1;if((s=e.framebuffer)?(s.propDep?i=o=!0:s.contextDep&&i&&(o=!0),o||S(t,n,s)):S(t,n,null),e.state.viewport&&e.state.viewport.propDep&&(i=!0),E(t,n,e),C(t,n,e.state,function(t){return!r(t)}),e.profile&&r(e.profile)||B(t,n,e,!1,\"a1\"),e.contextDep=i,e.needsContext=a,e.needsFramebuffer=o,(a=e.shader.progVar).contextDep&&i||a.propDep)Y(t,n,e,null);else if(a=a.append(t,n),n(t.shared.gl,\".useProgram(\",a,\".program);\"),e.shader.program)Y(t,n,e,e.shader.program);else{var s=t.global.def(\"{}\"),l=(o=n.def(a,\".id\"),n.def(s,\"[\",o,\"]\"));n(t.cond(l).then(l,\".call(this,a0,a1);\").else(l,\"=\",s,\"[\",o,\"]=\",t.link(function(r){return q(Y,t,e,r,2)}),\"(\",a,\");\",l,\".call(this,a0,a1);\"))}0<Object.keys(e.state).length&&n(t.shared.current,\".dirty=true;\")}(a,r),a.compile()}}}function N(t,e){for(var r=0;r<t.length;++r)if(t[r]===e)return r;return-1}var j=function(t,e){for(var r=Object.keys(e),n=0;n<r.length;++n)t[r[n]]=e[r[n]];return t},U=0,V={DynamicVariable:t,define:function(r,n){return new t(r,e(n+\"\"))},isDynamic:function(e){return\"function\"==typeof e&&!e._reglType||e instanceof t},unbox:function(e,r){return\"function\"==typeof e?new t(0,e):e},accessor:e},q={next:\"function\"==typeof requestAnimationFrame?function(t){return requestAnimationFrame(t)}:function(t){return setTimeout(t,16)},cancel:\"function\"==typeof cancelAnimationFrame?function(t){return cancelAnimationFrame(t)}:clearTimeout},H=\"undefined\"!=typeof performance&&performance.now?function(){return performance.now()}:function(){return+new Date},G=s();G.zero=s();var Y=function(t,e){var r=1;e.ext_texture_filter_anisotropic&&(r=t.getParameter(34047));var n=1,i=1;e.webgl_draw_buffers&&(n=t.getParameter(34852),i=t.getParameter(36063));var a=!!e.oes_texture_float;if(a){a=t.createTexture(),t.bindTexture(3553,a),t.texImage2D(3553,0,6408,1,1,0,6408,5126,null);var o=t.createFramebuffer();if(t.bindFramebuffer(36160,o),t.framebufferTexture2D(36160,36064,3553,a,0),t.bindTexture(3553,null),36053!==t.checkFramebufferStatus(36160))a=!1;else{t.viewport(0,0,1,1),t.clearColor(1,0,0,1),t.clear(16384);var s=G.allocType(5126,4);t.readPixels(0,0,1,1,6408,5126,s),t.getError()?a=!1:(t.deleteFramebuffer(o),t.deleteTexture(a),a=1===s[0]),G.freeType(s)}}return s=!0,\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion)||/Edge/.test(navigator.userAgent))||(s=t.createTexture(),o=G.allocType(5121,36),t.activeTexture(33984),t.bindTexture(34067,s),t.texImage2D(34069,0,6408,3,3,0,6408,5121,o),G.freeType(o),t.bindTexture(34067,null),t.deleteTexture(s),s=!t.getError()),{colorBits:[t.getParameter(3410),t.getParameter(3411),t.getParameter(3412),t.getParameter(3413)],depthBits:t.getParameter(3414),stencilBits:t.getParameter(3415),subpixelBits:t.getParameter(3408),extensions:Object.keys(e).filter(function(t){return!!e[t]}),maxAnisotropic:r,maxDrawbuffers:n,maxColorAttachments:i,pointSizeDims:t.getParameter(33901),lineWidthDims:t.getParameter(33902),maxViewportDims:t.getParameter(3386),maxCombinedTextureUnits:t.getParameter(35661),maxCubeMapSize:t.getParameter(34076),maxRenderbufferSize:t.getParameter(34024),maxTextureUnits:t.getParameter(34930),maxTextureSize:t.getParameter(3379),maxAttributes:t.getParameter(34921),maxVertexUniforms:t.getParameter(36347),maxVertexTextureUnits:t.getParameter(35660),maxVaryingVectors:t.getParameter(36348),maxFragmentUniforms:t.getParameter(36349),glsl:t.getParameter(35724),renderer:t.getParameter(7937),vendor:t.getParameter(7936),version:t.getParameter(7938),readFloat:a,npotTextureCube:s}},W=function(t){return t instanceof Uint8Array||t instanceof Uint16Array||t instanceof Uint32Array||t instanceof Int8Array||t instanceof Int16Array||t instanceof Int32Array||t instanceof Float32Array||t instanceof Float64Array||t instanceof Uint8ClampedArray},X=function(t){return Object.keys(t).map(function(e){return t[e]})},Z={shape:function(t){for(var e=[];t.length;t=t[0])e.push(t.length);return e},flatten:function(t,e,r,n){var i=1;if(e.length)for(var a=0;a<e.length;++a)i*=e[a];else i=0;switch(r=n||G.allocType(r,i),e.length){case 0:break;case 1:for(n=e[0],e=0;e<n;++e)r[e]=t[e];break;case 2:for(n=e[0],e=e[1],a=i=0;a<n;++a)for(var o=t[a],s=0;s<e;++s)r[i++]=o[s];break;case 3:c(t,e[0],e[1],e[2],r,0);break;default:!function t(e,r,n,i,a){for(var o=1,s=n+1;s<r.length;++s)o*=r[s];var l=r[n];if(4==r.length-n){var u=r[n+1],h=r[n+2];for(r=r[n+3],s=0;s<l;++s)c(e[s],u,h,r,i,a),a+=o}else for(s=0;s<l;++s)t(e[s],r,n+1,i,a),a+=o}(t,e,0,r,0)}return r}},J={\"[object Int8Array]\":5120,\"[object Int16Array]\":5122,\"[object Int32Array]\":5124,\"[object Uint8Array]\":5121,\"[object Uint8ClampedArray]\":5121,\"[object Uint16Array]\":5123,\"[object Uint32Array]\":5125,\"[object Float32Array]\":5126,\"[object Float64Array]\":5121,\"[object ArrayBuffer]\":5121},K={int8:5120,int16:5122,int32:5124,uint8:5121,uint16:5123,uint32:5125,float:5126,float32:5126},$={dynamic:35048,stream:35040,static:35044},Q=Z.flatten,tt=Z.shape,et=[];et[5120]=1,et[5122]=2,et[5124]=4,et[5121]=1,et[5123]=2,et[5125]=4,et[5126]=4;var rt={points:0,point:0,lines:1,line:1,triangles:4,triangle:4,\"line loop\":2,\"line strip\":3,\"triangle strip\":5,\"triangle fan\":6},nt=new Float32Array(1),it=new Uint32Array(nt.buffer),at=[9984,9986,9985,9987],ot=[0,6409,6410,6407,6408],st={};st[6409]=st[6406]=st[6402]=1,st[34041]=st[6410]=2,st[6407]=st[35904]=3,st[6408]=st[35906]=4;var lt=m(\"HTMLCanvasElement\"),ct=m(\"CanvasRenderingContext2D\"),ut=m(\"ImageBitmap\"),ht=m(\"HTMLImageElement\"),ft=m(\"HTMLVideoElement\"),pt=Object.keys(J).concat([lt,ct,ut,ht,ft]),dt=[];dt[5121]=1,dt[5126]=4,dt[36193]=2,dt[5123]=2,dt[5125]=4;var gt=[];gt[32854]=2,gt[32855]=2,gt[36194]=2,gt[34041]=4,gt[33776]=.5,gt[33777]=.5,gt[33778]=1,gt[33779]=1,gt[35986]=.5,gt[35987]=1,gt[34798]=1,gt[35840]=.5,gt[35841]=.25,gt[35842]=.5,gt[35843]=.25,gt[36196]=.5;var vt=[];vt[32854]=2,vt[32855]=2,vt[36194]=2,vt[33189]=2,vt[36168]=1,vt[34041]=4,vt[35907]=4,vt[34836]=16,vt[34842]=8,vt[34843]=6;var mt=function(t,e,r,n,i){function a(t){this.id=c++,this.refCount=1,this.renderbuffer=t,this.format=32854,this.height=this.width=0,i.profile&&(this.stats={size:0})}function o(e){var r=e.renderbuffer;t.bindRenderbuffer(36161,null),t.deleteRenderbuffer(r),e.renderbuffer=null,e.refCount=0,delete u[e.id],n.renderbufferCount--}var s={rgba4:32854,rgb565:36194,\"rgb5 a1\":32855,depth:33189,stencil:36168,\"depth stencil\":34041};e.ext_srgb&&(s.srgba=35907),e.ext_color_buffer_half_float&&(s.rgba16f=34842,s.rgb16f=34843),e.webgl_color_buffer_float&&(s.rgba32f=34836);var l=[];Object.keys(s).forEach(function(t){l[s[t]]=t});var c=0,u={};return a.prototype.decRef=function(){0>=--this.refCount&&o(this)},i.profile&&(n.getTotalRenderbufferSize=function(){var t=0;return Object.keys(u).forEach(function(e){t+=u[e].stats.size}),t}),{create:function(e,r){function o(e,r){var n=0,a=0,u=32854;if(\"object\"==typeof e&&e?(\"shape\"in e?(n=0|(a=e.shape)[0],a=0|a[1]):(\"radius\"in e&&(n=a=0|e.radius),\"width\"in e&&(n=0|e.width),\"height\"in e&&(a=0|e.height)),\"format\"in e&&(u=s[e.format])):\"number\"==typeof e?(n=0|e,a=\"number\"==typeof r?0|r:n):e||(n=a=1),n!==c.width||a!==c.height||u!==c.format)return o.width=c.width=n,o.height=c.height=a,c.format=u,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,u,n,a),i.profile&&(c.stats.size=vt[c.format]*c.width*c.height),o.format=l[c.format],o}var c=new a(t.createRenderbuffer());return u[c.id]=c,n.renderbufferCount++,o(e,r),o.resize=function(e,r){var n=0|e,a=0|r||n;return n===c.width&&a===c.height?o:(o.width=c.width=n,o.height=c.height=a,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,c.format,n,a),i.profile&&(c.stats.size=vt[c.format]*c.width*c.height),o)},o._reglType=\"renderbuffer\",o._renderbuffer=c,i.profile&&(o.stats=c.stats),o.destroy=function(){c.decRef()},o},clear:function(){X(u).forEach(o)},restore:function(){X(u).forEach(function(e){e.renderbuffer=t.createRenderbuffer(),t.bindRenderbuffer(36161,e.renderbuffer),t.renderbufferStorage(36161,e.format,e.width,e.height)}),t.bindRenderbuffer(36161,null)}}},yt=[];yt[6408]=4,yt[6407]=3;var xt=[];xt[5121]=1,xt[5126]=4,xt[36193]=2;var bt=[\"x\",\"y\",\"z\",\"w\"],_t=\"blend.func blend.equation stencil.func stencil.opFront stencil.opBack sample.coverage viewport scissor.box polygonOffset.offset\".split(\" \"),wt={0:0,1:1,zero:0,one:1,\"src color\":768,\"one minus src color\":769,\"src alpha\":770,\"one minus src alpha\":771,\"dst color\":774,\"one minus dst color\":775,\"dst alpha\":772,\"one minus dst alpha\":773,\"constant color\":32769,\"one minus constant color\":32770,\"constant alpha\":32771,\"one minus constant alpha\":32772,\"src alpha saturate\":776},kt={never:512,less:513,\"<\":513,equal:514,\"=\":514,\"==\":514,\"===\":514,lequal:515,\"<=\":515,greater:516,\">\":516,notequal:517,\"!=\":517,\"!==\":517,gequal:518,\">=\":518,always:519},Tt={0:0,zero:0,keep:7680,replace:7681,increment:7682,decrement:7683,\"increment wrap\":34055,\"decrement wrap\":34056,invert:5386},At={cw:2304,ccw:2305},Mt=new I(!1,!1,!1,function(){});return function(t){function e(){if(0===Z.length)w&&w.update(),Q=null;else{Q=q.next(e),h();for(var t=Z.length-1;0<=t;--t){var r=Z[t];r&&r(P,null,0)}v.flush(),w&&w.update()}}function r(){!Q&&0<Z.length&&(Q=q.next(e))}function n(){Q&&(q.cancel(e),Q=null)}function a(t){t.preventDefault(),n(),J.forEach(function(t){t()})}function o(t){v.getError(),y.restore(),D.restore(),z.restore(),R.restore(),F.restore(),U.restore(),w&&w.restore(),G.procs.refresh(),r(),K.forEach(function(t){t()})}function s(t){function e(t){var e={},r={};return Object.keys(t).forEach(function(n){var i=t[n];V.isDynamic(i)?r[n]=V.unbox(i,n):e[n]=i}),{dynamic:r,static:e}}var r=e(t.context||{}),n=e(t.uniforms||{}),i=e(t.attributes||{}),a=e(function(t){function e(t){if(t in r){var e=r[t];delete r[t],Object.keys(e).forEach(function(n){r[t+\".\"+n]=e[n]})}}var r=j({},t);return delete r.uniforms,delete r.attributes,delete r.context,\"stencil\"in r&&r.stencil.op&&(r.stencil.opBack=r.stencil.opFront=r.stencil.op,delete r.stencil.op),e(\"blend\"),e(\"depth\"),e(\"cull\"),e(\"stencil\"),e(\"polygonOffset\"),e(\"scissor\"),e(\"sample\"),r}(t));t={gpuTime:0,cpuTime:0,count:0};var o=(r=G.compile(a,i,n,r,t)).draw,s=r.batch,l=r.scope,c=[];return j(function(t,e){var r;if(\"function\"==typeof t)return l.call(this,null,t,0);if(\"function\"==typeof e)if(\"number\"==typeof t)for(r=0;r<t;++r)l.call(this,null,e,r);else{if(!Array.isArray(t))return l.call(this,t,e,0);for(r=0;r<t.length;++r)l.call(this,t[r],e,r)}else if(\"number\"==typeof t){if(0<t)return s.call(this,function(t){for(;c.length<t;)c.push(null);return c}(0|t),0|t)}else{if(!Array.isArray(t))return o.call(this,t);if(t.length)return s.call(this,t,t.length)}},{stats:t})}function l(t,e){var r=0;G.procs.poll();var n=e.color;n&&(v.clearColor(+n[0]||0,+n[1]||0,+n[2]||0,+n[3]||0),r|=16384),\"depth\"in e&&(v.clearDepth(+e.depth),r|=256),\"stencil\"in e&&(v.clearStencil(0|e.stencil),r|=1024),v.clear(r)}function c(t){return Z.push(t),r(),{cancel:function(){var e=N(Z,t);Z[e]=function t(){var e=N(Z,t);Z[e]=Z[Z.length-1],--Z.length,0>=Z.length&&n()}}}}function u(){var t=W.viewport,e=W.scissor_box;t[0]=t[1]=e[0]=e[1]=0,P.viewportWidth=P.framebufferWidth=P.drawingBufferWidth=t[2]=e[2]=v.drawingBufferWidth,P.viewportHeight=P.framebufferHeight=P.drawingBufferHeight=t[3]=e[3]=v.drawingBufferHeight}function h(){P.tick+=1,P.time=g(),u(),G.procs.poll()}function f(){u(),G.procs.refresh(),w&&w.update()}function g(){return(H()-k)/1e3}if(!(t=i(t)))return null;var v=t.gl,m=v.getContextAttributes();v.isContextLost();var y=function(t,e){function r(e){var r;e=e.toLowerCase();try{r=n[e]=t.getExtension(e)}catch(t){}return!!r}for(var n={},i=0;i<e.extensions.length;++i){var a=e.extensions[i];if(!r(a))return e.onDestroy(),e.onDone('\"'+a+'\" extension is not supported by the current WebGL context, try upgrading your system or a different browser'),null}return e.optionalExtensions.forEach(r),{extensions:n,restore:function(){Object.keys(n).forEach(function(t){if(n[t]&&!r(t))throw Error(\"(regl): error restoring extension \"+t)})}}}(v,t);if(!y)return null;var x=function(){var t={\"\":0},e=[\"\"];return{id:function(r){var n=t[r];return n||(n=t[r]=e.length,e.push(r),n)},str:function(t){return e[t]}}}(),b={bufferCount:0,elementsCount:0,framebufferCount:0,shaderCount:0,textureCount:0,cubeCount:0,renderbufferCount:0,maxTextureUnits:0},_=y.extensions,w=function(t,e){function r(){this.endQueryIndex=this.startQueryIndex=-1,this.sum=0,this.stats=null}function n(t,e,n){var i=o.pop()||new r;i.startQueryIndex=t,i.endQueryIndex=e,i.sum=0,i.stats=n,s.push(i)}if(!e.ext_disjoint_timer_query)return null;var i=[],a=[],o=[],s=[],l=[],c=[];return{beginQuery:function(t){var r=i.pop()||e.ext_disjoint_timer_query.createQueryEXT();e.ext_disjoint_timer_query.beginQueryEXT(35007,r),a.push(r),n(a.length-1,a.length,t)},endQuery:function(){e.ext_disjoint_timer_query.endQueryEXT(35007)},pushScopeStats:n,update:function(){var t,r;if(0!==(t=a.length)){c.length=Math.max(c.length,t+1),l.length=Math.max(l.length,t+1),l[0]=0;var n=c[0]=0;for(r=t=0;r<a.length;++r){var u=a[r];e.ext_disjoint_timer_query.getQueryObjectEXT(u,34919)?(n+=e.ext_disjoint_timer_query.getQueryObjectEXT(u,34918),i.push(u)):a[t++]=u,l[r+1]=n,c[r+1]=t}for(a.length=t,r=t=0;r<s.length;++r){var h=(n=s[r]).startQueryIndex;u=n.endQueryIndex,n.sum+=l[u]-l[h],h=c[h],(u=c[u])===h?(n.stats.gpuTime+=n.sum/1e6,o.push(n)):(n.startQueryIndex=h,n.endQueryIndex=u,s[t++]=n)}s.length=t}},getNumPendingQueries:function(){return a.length},clear:function(){i.push.apply(i,a);for(var t=0;t<i.length;t++)e.ext_disjoint_timer_query.deleteQueryEXT(i[t]);a.length=0,i.length=0},restore:function(){a.length=0,i.length=0}}}(0,_),k=H(),C=v.drawingBufferWidth,L=v.drawingBufferHeight,P={tick:0,time:0,viewportWidth:C,viewportHeight:L,framebufferWidth:C,framebufferHeight:L,drawingBufferWidth:C,drawingBufferHeight:L,pixelRatio:t.pixelRatio},O=Y(v,_),z=(C=function(t,e,r,n){for(t=r.maxAttributes,e=Array(t),r=0;r<t;++r)e[r]=new M;return{Record:M,scope:{},state:e}}(v,_,O),p(v,b,t,C)),I=d(v,_,z,b),D=S(v,x,b,t),R=T(v,_,O,function(){G.procs.poll()},P,b,t),F=mt(v,_,0,b,t),U=A(v,_,O,R,F,b),G=B(v,x,_,O,z,I,0,U,{},C,D,{elements:null,primitive:4,count:-1,offset:0,instances:-1},P,w,t),W=(x=E(v,U,G.procs.poll,P),G.next),X=v.canvas,Z=[],J=[],K=[],$=[t.onDestroy],Q=null;X&&(X.addEventListener(\"webglcontextlost\",a,!1),X.addEventListener(\"webglcontextrestored\",o,!1));var tt=U.setFBO=s({framebuffer:V.define.call(null,1,\"framebuffer\")});return f(),m=j(s,{clear:function(t){if(\"framebuffer\"in t)if(t.framebuffer&&\"framebufferCube\"===t.framebuffer_reglType)for(var e=0;6>e;++e)tt(j({framebuffer:t.framebuffer.faces[e]},t),l);else tt(t,l);else l(0,t)},prop:V.define.bind(null,1),context:V.define.bind(null,2),this:V.define.bind(null,3),draw:s({}),buffer:function(t){return z.create(t,34962,!1,!1)},elements:function(t){return I.create(t,!1)},texture:R.create2D,cube:R.createCube,renderbuffer:F.create,framebuffer:U.create,framebufferCube:U.createCube,attributes:m,frame:c,on:function(t,e){var r;switch(t){case\"frame\":return c(e);case\"lost\":r=J;break;case\"restore\":r=K;break;case\"destroy\":r=$}return r.push(e),{cancel:function(){for(var t=0;t<r.length;++t)if(r[t]===e){r[t]=r[r.length-1],r.pop();break}}}},limits:O,hasExtension:function(t){return 0<=O.extensions.indexOf(t.toLowerCase())},read:x,destroy:function(){Z.length=0,n(),X&&(X.removeEventListener(\"webglcontextlost\",a),X.removeEventListener(\"webglcontextrestored\",o)),D.clear(),U.clear(),F.clear(),R.clear(),I.clear(),z.clear(),w&&w.clear(),$.forEach(function(t){t()})},_gl:v,_refresh:f,poll:function(){h(),w&&w.update()},now:g,stats:b}),t.onDone(null,m),m}},\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=i():n.createREGL=i()},{}],503:[function(t,e,r){\"use strict\";var n,i=\"\";e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"expected a string\");if(1===e)return t;if(2===e)return t+t;var r=t.length*e;if(n!==t||\"undefined\"==typeof n)n=t,i=\"\";else if(i.length>=r)return i.substr(0,r);for(;r>i.length&&e>1;)1&e&&(i+=t),e>>=1,t+=t;return i=(i+=t).substr(0,r)}},{}],504:[function(t,e,r){(function(t){e.exports=t.performance&&t.performance.now?function(){return performance.now()}:Date.now||function(){return+new Date}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{}],505:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=t[t.length-1],n=e,i=e-2;i>=0;--i){var a=r,o=t[i],s=(r=a+o)-a,l=o-s;l&&(t[--n]=r,r=l)}for(var c=0,i=n;i<e;++i){var a=t[i],o=r,s=(r=a+o)-a,l=o-s;l&&(t[c++]=l)}return t[c++]=r,t.length=c,t}},{}],506:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-compress\"),s=6;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(2===t.length)return[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\");for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(l(t,r)),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return function t(e){if(1===e.length)return e[0];if(2===e.length)return[\"sum(\",e[0],\",\",e[1],\")\"].join(\"\");var r=e.length>>1;return[\"sum(\",t(e.slice(0,r)),\",\",t(e.slice(r)),\")\"].join(\"\")}(e);var n}function u(t){return new Function(\"sum\",\"scale\",\"prod\",\"compress\",[\"function robustDeterminant\",t,\"(m){return compress(\",c(function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m[\",r,\"][\",n,\"]\"].join(\"\")}return e}(t)),\")};return robustDeterminant\",t].join(\"\"))(i,a,n,o)}var h=[function(){return[0]},function(t){return[t[0][0]]}];!function(){for(;h.length<s;)h.push(u(h.length));for(var t=[],r=[\"function robustDeterminant(m){switch(m.length){\"],n=0;n<s;++n)t.push(\"det\"+n),r.push(\"case \",n,\":return det\",n,\"(m);\");r.push(\"}var det=CACHE[m.length];if(!det)det=CACHE[m.length]=gen(m.length);return det(m);}return robustDeterminant\"),t.push(\"CACHE\",\"gen\",r.join(\"\"));var i=Function.apply(void 0,t);for(e.exports=i.apply(void 0,h.concat([h,u])),n=0;n<h.length;++n)e.exports[n]=h[n]}()},{\"robust-compress\":505,\"robust-scale\":512,\"robust-sum\":515,\"two-product\":543}],507:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\");e.exports=function(t,e){for(var r=n(t[0],e[0]),a=1;a<t.length;++a)r=i(r,n(t[a],e[a]));return r}},{\"robust-sum\":515,\"two-product\":543}],508:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-subtract\"),o=t(\"robust-scale\"),s=6;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",c(t.slice(0,e)),\",\",c(t.slice(e)),\")\"].join(\"\")}function u(t,e){if(\"m\"===t.charAt(0)){if(\"w\"===e.charAt(0)){var r=t.split(\"[\");return[\"w\",e.substr(1),\"m\",r[0].substr(1)].join(\"\")}return[\"prod(\",t,\",\",e,\")\"].join(\"\")}return u(e,t)}function h(t){if(2===t.length)return[[\"diff(\",u(t[0][0],t[1][1]),\",\",u(t[1][0],t[0][1]),\")\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(h(l(t,r))),\",\",(n=r,!0&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function f(t,e){for(var r=[],n=0;n<e-2;++n)r.push([\"prod(m\",t,\"[\",n,\"],m\",t,\"[\",n,\"])\"].join(\"\"));return c(r)}function p(t){for(var e=[],r=[],s=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-2,\"]\"].join(\"\")}return e}(t),u=0;u<t;++u)s[0][u]=\"1\",s[t-1][u]=\"w\"+u;for(u=0;u<t;++u)0==(1&u)?e.push.apply(e,h(l(s,u))):r.push.apply(r,h(l(s,u)));var p=c(e),d=c(r),g=\"exactInSphere\"+t,v=[];for(u=0;u<t;++u)v.push(\"m\"+u);var m=[\"function \",g,\"(\",v.join(),\"){\"];for(u=0;u<t;++u){m.push(\"var w\",u,\"=\",f(u,t),\";\");for(var y=0;y<t;++y)y!==u&&m.push(\"var w\",u,\"m\",y,\"=scale(w\",u,\",m\",y,\"[0]);\")}return m.push(\"var p=\",p,\",n=\",d,\",d=diff(p,n);return d[d.length-1];}return \",g),new Function(\"sum\",\"diff\",\"prod\",\"scale\",m.join(\"\"))(i,a,n,o)}var d=[function(){return 0},function(){return 0},function(){return 0}];!function(){for(;d.length<=s;)d.push(p(d.length));for(var t=[],r=[\"slow\"],n=0;n<=s;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function testInSphere(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=s;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return testInSphere\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[function(t){var e=d[t.length];return e||(e=d[t.length]=p(t.length)),e.apply(void 0,t)}].concat(d)),n=0;n<=s;++n)e.exports[n]=d[n]}()},{\"robust-scale\":512,\"robust-subtract\":514,\"robust-sum\":515,\"two-product\":543}],509:[function(t,e,r){\"use strict\";var n=t(\"robust-determinant\"),i=6;function a(t){for(var e=\"robustLinearSolve\"+t+\"d\",r=[\"function \",e,\"(A,b){return [\"],i=0;i<t;++i){r.push(\"det([\");for(var a=0;a<t;++a){a>0&&r.push(\",\"),r.push(\"[\");for(var o=0;o<t;++o)o>0&&r.push(\",\"),o===i?r.push(\"+b[\",a,\"]\"):r.push(\"+A[\",a,\"][\",o,\"]\");r.push(\"]\")}r.push(\"]),\")}r.push(\"det(A)]}return \",e);var s=new Function(\"det\",r.join(\"\"));return s(t<6?n[t]:n)}var o=[function(){return[0]},function(t,e){return[[e[0]],[t[0][0]]]}];!function(){for(;o.length<i;)o.push(a(o.length));for(var t=[],r=[\"function dispatchLinearSolve(A,b){switch(A.length){\"],n=0;n<i;++n)t.push(\"s\"+n),r.push(\"case \",n,\":return s\",n,\"(A,b);\");r.push(\"}var s=CACHE[A.length];if(!s)s=CACHE[A.length]=g(A.length);return s(A,b)}return dispatchLinearSolve\"),t.push(\"CACHE\",\"g\",r.join(\"\"));var s=Function.apply(void 0,t);for(e.exports=s.apply(void 0,o.concat([o,a])),n=0;n<i;++n)e.exports[n]=o[n]}()},{\"robust-determinant\":506}],510:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-subtract\"),s=5;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",c(t.slice(0,e)),\",\",c(t.slice(e)),\")\"].join(\"\")}function u(t){if(2===t.length)return[[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(u(l(t,r))),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function h(t){for(var e=[],r=[],s=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-1,\"]\"].join(\"\")}return e}(t),h=[],f=0;f<t;++f)0==(1&f)?e.push.apply(e,u(l(s,f))):r.push.apply(r,u(l(s,f))),h.push(\"m\"+f);var p=c(e),d=c(r),g=\"orientation\"+t+\"Exact\",v=[\"function \",g,\"(\",h.join(),\"){var p=\",p,\",n=\",d,\",d=sub(p,n);return d[d.length-1];};return \",g].join(\"\");return new Function(\"sum\",\"prod\",\"scale\",\"sub\",v)(i,n,a,o)}var f=h(3),p=h(4),d=[function(){return 0},function(){return 0},function(t,e){return e[0]-t[0]},function(t,e,r){var n,i=(t[1]-r[1])*(e[0]-r[0]),a=(t[0]-r[0])*(e[1]-r[1]),o=i-a;if(i>0){if(a<=0)return o;n=i+a}else{if(!(i<0))return o;if(a>=0)return o;n=-(i+a)}var s=3.3306690738754716e-16*n;return o>=s||o<=-s?o:f(t,e,r)},function(t,e,r,n){var i=t[0]-n[0],a=e[0]-n[0],o=r[0]-n[0],s=t[1]-n[1],l=e[1]-n[1],c=r[1]-n[1],u=t[2]-n[2],h=e[2]-n[2],f=r[2]-n[2],d=a*c,g=o*l,v=o*s,m=i*c,y=i*l,x=a*s,b=u*(d-g)+h*(v-m)+f*(y-x),_=7.771561172376103e-16*((Math.abs(d)+Math.abs(g))*Math.abs(u)+(Math.abs(v)+Math.abs(m))*Math.abs(h)+(Math.abs(y)+Math.abs(x))*Math.abs(f));return b>_||-b>_?b:p(t,e,r,n)}];!function(){for(;d.length<=s;)d.push(h(d.length));for(var t=[],r=[\"slow\"],n=0;n<=s;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function getOrientation(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=s;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return getOrientation\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[function(t){var e=d[t.length];return e||(e=d[t.length]=h(t.length)),e.apply(void 0,t)}].concat(d)),n=0;n<=s;++n)e.exports[n]=d[n]}()},{\"robust-scale\":512,\"robust-subtract\":514,\"robust-sum\":515,\"two-product\":543}],511:[function(t,e,r){\"use strict\";var n=t(\"robust-sum\"),i=t(\"robust-scale\");e.exports=function(t,e){if(1===t.length)return i(e,t[0]);if(1===e.length)return i(t,e[0]);if(0===t.length||0===e.length)return[0];var r=[0];if(t.length<e.length)for(var a=0;a<t.length;++a)r=n(r,i(e,t[a]));else for(var a=0;a<e.length;++a)r=n(r,i(t,e[a]));return r}},{\"robust-scale\":512,\"robust-sum\":515}],512:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"two-sum\");e.exports=function(t,e){var r=t.length;if(1===r){var a=n(t[0],e);return a[0]?a:[a[1]]}var o=new Array(2*r),s=[.1,.1],l=[.1,.1],c=0;n(t[0],e,s),s[0]&&(o[c++]=s[0]);for(var u=1;u<r;++u){n(t[u],e,l);var h=s[1];i(h,l[0],s),s[0]&&(o[c++]=s[0]);var f=l[1],p=s[1],d=f+p,g=d-f,v=p-g;s[1]=d,v&&(o[c++]=v)}s[1]&&(o[c++]=s[1]);0===c&&(o[c++]=0);return o.length=c,o}},{\"two-product\":543,\"two-sum\":544}],513:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){var a=n(t,r,i),o=n(e,r,i);if(a>0&&o>0||a<0&&o<0)return!1;var s=n(r,t,e),l=n(i,t,e);if(s>0&&l>0||s<0&&l<0)return!1;if(0===a&&0===o&&0===s&&0===l)return function(t,e,r,n){for(var i=0;i<2;++i){var a=t[i],o=e[i],s=Math.min(a,o),l=Math.max(a,o),c=r[i],u=n[i],h=Math.min(c,u),f=Math.max(c,u);if(f<s||l<h)return!1}return!0}(t,e,r,i);return!0};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":510}],514:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],-e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,h=t[l],f=u(h),p=-e[c],d=u(p);f<d?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=-e[c],d=u(p)));l<r&&f<d||c>=n?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p)));var g,v,m=i+a,y=m-i,x=a-y,b=x,_=m;for(;l<r&&c<n;)f<d?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p))),(x=(a=b)-(y=(m=i+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g;for(;l<r;)(x=(a=b)-(y=(m=(i=h)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(l+=1)<r&&(h=t[l]);for(;c<n;)(x=(a=b)-(y=(m=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(c+=1)<n&&(p=-e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],515:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,h=t[l],f=u(h),p=e[c],d=u(p);f<d?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=e[c],d=u(p)));l<r&&f<d||c>=n?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=e[c],d=u(p)));var g,v,m=i+a,y=m-i,x=a-y,b=x,_=m;for(;l<r&&c<n;)f<d?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=e[c],d=u(p))),(x=(a=b)-(y=(m=i+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g;for(;l<r;)(x=(a=b)-(y=(m=(i=h)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(l+=1)<r&&(h=t[l]);for(;c<n;)(x=(a=b)-(y=(m=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(c+=1)<n&&(p=e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],516:[function(t,e,r){\"use strict\";e.exports=function(t){return t<0?-1:t>0?1:0}},{}],517:[function(t,e,r){\"use strict\";e.exports=function(t){return i(n(t))};var n=t(\"boundary-cells\"),i=t(\"reduce-simplicial-complex\")},{\"boundary-cells\":95,\"reduce-simplicial-complex\":489}],518:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,s){r=r||0,\"undefined\"==typeof s&&(s=function(t){for(var e=t.length,r=0,n=0;n<e;++n)r=0|Math.max(r,t[n].length);return r-1}(t));if(0===t.length||s<1)return{cells:[],vertexIds:[],vertexWeights:[]};var l=function(t,e){for(var r=t.length,n=i.mallocUint8(r),a=0;a<r;++a)n[a]=t[a]<e|0;return n}(e,+r),c=function(t,e){for(var r=t.length,o=e*(e+1)/2*r|0,s=i.mallocUint32(2*o),l=0,c=0;c<r;++c)for(var u=t[c],e=u.length,h=0;h<e;++h)for(var f=0;f<h;++f){var p=u[f],d=u[h];s[l++]=0|Math.min(p,d),s[l++]=0|Math.max(p,d)}a(n(s,[l/2|0,2]));for(var g=2,c=2;c<l;c+=2)s[c-2]===s[c]&&s[c-1]===s[c+1]||(s[g++]=s[c],s[g++]=s[c+1]);return n(s,[g/2|0,2])}(t,s),u=function(t,e,r,a){for(var o=t.data,s=t.shape[0],l=i.mallocDouble(s),c=0,u=0;u<s;++u){var h=o[2*u],f=o[2*u+1];if(r[h]!==r[f]){var p=e[h],d=e[f];o[2*c]=h,o[2*c+1]=f,l[c++]=(d-a)/(d-p)}}return t.shape[0]=c,n(l,[c])}(c,e,l,+r),h=function(t,e){var r=i.mallocInt32(2*e),n=t.shape[0],a=t.data;r[0]=0;for(var o=0,s=0;s<n;++s){var l=a[2*s];if(l!==o){for(r[2*o+1]=s;++o<l;)r[2*o]=s,r[2*o+1]=s;r[2*o]=s}}r[2*o+1]=n;for(;++o<e;)r[2*o]=r[2*o+1]=n;return r}(c,0|e.length),f=o(s)(t,c.data,h,l),p=function(t){for(var e=0|t.shape[0],r=t.data,n=new Array(e),i=0;i<e;++i)n[i]=[r[2*i],r[2*i+1]];return n}(c),d=[].slice.call(u.data,0,u.shape[0]);return i.free(l),i.free(c.data),i.free(u.data),i.free(h),{cells:f,vertexIds:p,vertexWeights:d}};var n=t(\"ndarray\"),i=t(\"typedarray-pool\"),a=t(\"ndarray-sort\"),o=t(\"./lib/codegen\")},{\"./lib/codegen\":519,ndarray:450,\"ndarray-sort\":448,\"typedarray-pool\":545}],519:[function(t,e,r){\"use strict\";e.exports=function(t){var e=a[t];e||(e=a[t]=function(t){var e=0,r=new Array(t+1);r[0]=[[]];for(var a=1;a<=t;++a)for(var o=r[a]=i(a),s=0;s<o.length;++s)e=Math.max(e,o[a].length);var l=[\"function B(C,E,i,j){\",\"var a=Math.min(i,j)|0,b=Math.max(i,j)|0,l=C[2*a],h=C[2*a+1];\",\"while(l<h){\",\"var m=(l+h)>>1,v=E[2*m+1];\",\"if(v===b){return m}\",\"if(b<v){h=m}else{l=m+1}\",\"}\",\"return l;\",\"};\",\"function getContour\",t,\"d(F,E,C,S){\",\"var n=F.length,R=[];\",\"for(var i=0;i<n;++i){var c=F[i],l=c.length;\"];function c(t){if(!(t.length<=0)){l.push(\"R.push(\");for(var e=0;e<t.length;++e){var r=t[e];e>0&&l.push(\",\"),l.push(\"[\");for(var n=0;n<r.length;++n){var i=r[n];n>0&&l.push(\",\"),l.push(\"B(C,E,c[\",i[0],\"],c[\",i[1],\"])\")}l.push(\"]\")}l.push(\");\")}}for(var a=t+1;a>1;--a){a<t+1&&l.push(\"else \"),l.push(\"if(l===\",a,\"){\");for(var u=[],s=0;s<a;++s)u.push(\"(S[c[\"+s+\"]]<<\"+s+\")\");l.push(\"var M=\",u.join(\"+\"),\";if(M===0||M===\",(1<<a)-1,\"){continue}switch(M){\");for(var o=r[a-1],s=0;s<o.length;++s)l.push(\"case \",s,\":\"),c(o[s]),l.push(\"break;\");l.push(\"}}\")}return l.push(\"}return R;};return getContour\",t,\"d\"),new Function(\"pool\",l.join(\"\"))(n)}(t));return e};var n=t(\"typedarray-pool\"),i=t(\"marching-simplex-table\"),a={}},{\"marching-simplex-table\":427,\"typedarray-pool\":545}],520:[function(t,e,r){\"use strict\";var n=t(\"bit-twiddle\"),i=t(\"union-find\");function a(t,e){var r=t.length,n=t.length-e.length,i=Math.min;if(n)return n;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return(s=t[0]+t[1]-e[0]-e[1])||i(t[0],t[1])-i(e[0],e[1]);case 3:var a=t[0]+t[1],o=e[0]+e[1];if(s=a+t[2]-(o+e[2]))return s;var s,l=i(t[0],t[1]),c=i(e[0],e[1]);return(s=i(l,t[2])-i(c,e[2]))||i(l+t[2],a)-i(c+e[2],o);default:var u=t.slice(0);u.sort();var h=e.slice(0);h.sort();for(var f=0;f<r;++f)if(n=u[f]-h[f])return n;return 0}}function o(t,e){return a(t[0],e[0])}function s(t,e){if(e){for(var r=t.length,n=new Array(r),i=0;i<r;++i)n[i]=[t[i],e[i]];n.sort(o);for(i=0;i<r;++i)t[i]=n[i][0],e[i]=n[i][1];return t}return t.sort(a),t}function l(t){if(0===t.length)return[];for(var e=1,r=t.length,n=1;n<r;++n){var i=t[n];if(a(i,t[n-1])){if(n===e){e++;continue}t[e++]=i}}return t.length=e,t}function c(t,e){for(var r=0,n=t.length-1,i=-1;r<=n;){var o=r+n>>1,s=a(t[o],e);s<=0?(0===s&&(i=o),r=o+1):s>0&&(n=o-1)}return i}function u(t,e){for(var r=new Array(t.length),i=0,o=r.length;i<o;++i)r[i]=[];for(var s=[],l=(i=0,e.length);i<l;++i)for(var u=e[i],h=u.length,f=1,p=1<<h;f<p;++f){s.length=n.popCount(f);for(var d=0,g=0;g<h;++g)f&1<<g&&(s[d++]=u[g]);var v=c(t,s);if(!(v<0))for(;r[v++].push(i),!(v>=t.length||0!==a(t[v],s)););}return r}function h(t,e){if(e<0)return[];for(var r=[],i=(1<<e+1)-1,a=0;a<t.length;++a)for(var o=t[a],l=i;l<1<<o.length;l=n.nextCombination(l)){for(var c=new Array(e+1),u=0,h=0;h<o.length;++h)l&1<<h&&(c[u++]=o[h]);r.push(c)}return s(r)}r.dimension=function(t){for(var e=0,r=Math.max,n=0,i=t.length;n<i;++n)e=r(e,t[n].length);return e-1},r.countVertices=function(t){for(var e=-1,r=Math.max,n=0,i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)e=r(e,a[o]);return e+1},r.cloneCells=function(t){for(var e=new Array(t.length),r=0,n=t.length;r<n;++r)e[r]=t[r].slice(0);return e},r.compareCells=a,r.normalize=s,r.unique=l,r.findCell=c,r.incidence=u,r.dual=function(t,e){if(!e)return u(l(h(t,0)),t);for(var r=new Array(e),n=0;n<e;++n)r[n]=[];n=0;for(var i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)r[a[o]].push(n);return r},r.explode=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0|i.length,o=1,l=1<<a;o<l;++o){for(var c=[],u=0;u<a;++u)o>>>u&1&&c.push(i[u]);e.push(c)}return s(e)},r.skeleton=h,r.boundary=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;++a){for(var l=new Array(i.length-1),c=0,u=0;c<o;++c)c!==a&&(l[u++]=i[c]);e.push(l)}return s(e)},r.connectedComponents=function(t,e){return e?function(t,e){for(var r=new i(e),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var s=o+1;s<a.length;++s)r.link(a[o],a[s]);var l=[],c=r.ranks;for(n=0;n<c.length;++n)c[n]=-1;for(n=0;n<t.length;++n){var u=r.find(t[n][0]);c[u]<0?(c[u]=l.length,l.push([t[n].slice(0)])):l[c[u]].push(t[n].slice(0))}return l}(t,e):function(t){for(var e=l(s(h(t,0))),r=new i(e.length),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var u=c(e,[a[o]]),f=o+1;f<a.length;++f)r.link(u,c(e,[a[f]]));var p=[],d=r.ranks;for(n=0;n<d.length;++n)d[n]=-1;for(n=0;n<t.length;++n){var g=r.find(c(e,[t[n][0]]));d[g]<0?(d[g]=p.length,p.push([t[n].slice(0)])):p[d[g]].push(t[n].slice(0))}return p}(t)}},{\"bit-twiddle\":92,\"union-find\":546}],521:[function(t,e,r){arguments[4][92][0].apply(r,arguments)},{dup:92}],522:[function(t,e,r){arguments[4][520][0].apply(r,arguments)},{\"bit-twiddle\":521,dup:520,\"union-find\":523}],523:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n,n.prototype.length=function(){return this.roots.length},n.prototype.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},n.prototype.find=function(t){for(var e=this.roots;e[t]!==t;){var r=e[t];e[t]=e[r],t=r}return t},n.prototype.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],524:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){for(var a=e.length,o=t.length,s=new Array(a),l=new Array(a),c=new Array(a),u=new Array(a),h=0;h<a;++h)s[h]=l[h]=-1,c[h]=1/0,u[h]=!1;for(var h=0;h<o;++h){var f=t[h];if(2!==f.length)throw new Error(\"Input must be a graph\");var p=f[1],d=f[0];-1!==l[d]?l[d]=-2:l[d]=p,-1!==s[p]?s[p]=-2:s[p]=d}function g(t){if(u[t])return 1/0;var r,i,a,o,c,h=s[t],f=l[t];return h<0||f<0?1/0:(r=e[t],i=e[h],a=e[f],o=Math.abs(n(r,i,a)),c=Math.sqrt(Math.pow(i[0]-a[0],2)+Math.pow(i[1]-a[1],2)),o/c)}function v(t,e){var r=T[t],n=T[e];T[t]=n,T[e]=r,A[r]=e,A[n]=t}function m(t){return c[T[t]]}function y(t){return 1&t?t-1>>1:(t>>1)-1}function x(t){for(var e=m(t);;){var r=e,n=2*t+1,i=2*(t+1),a=t;if(n<S){var o=m(n);o<r&&(a=n,r=o)}if(i<S){var s=m(i);s<r&&(a=i)}if(a===t)return t;v(t,a),t=a}}function b(t){for(var e=m(t);t>0;){var r=y(t);if(r>=0){var n=m(r);if(e<n){v(t,r),t=r;continue}}return t}}function _(){if(S>0){var t=T[0];return v(0,S-1),S-=1,x(0),t}return-1}function w(t,e){var r=T[t];return c[r]===e?t:(c[r]=-1/0,b(t),_(),c[r]=e,b((S+=1)-1))}function k(t){if(!u[t]){u[t]=!0;var e=s[t],r=l[t];s[r]>=0&&(s[r]=e),l[e]>=0&&(l[e]=r),A[e]>=0&&w(A[e],g(e)),A[r]>=0&&w(A[r],g(r))}}for(var T=[],A=new Array(a),h=0;h<a;++h){var M=c[h]=g(h);M<1/0?(A[h]=T.length,T.push(h)):A[h]=-1}for(var S=T.length,h=S>>1;h>=0;--h)x(h);for(;;){var E=_();if(E<0||c[E]>r)break;k(E)}for(var C=[],h=0;h<a;++h)u[h]||(A[h]=C.length,C.push(e[h].slice()));C.length;function L(t,e){if(t[e]<0)return e;var r=e,n=e;do{var i=t[n];if(!u[n]||i<0||i===n)break;if(i=t[n=i],!u[n]||i<0||i===n)break;n=i,r=t[r]}while(r!==n);for(var a=e;a!==n;a=t[a])t[a]=n;return n}var P=[];return t.forEach(function(t){var e=L(s,t[0]),r=L(l,t[1]);if(e>=0&&r>=0&&e!==r){var n=A[e],i=A[r];n!==i&&P.push([n,i])}}),i.unique(i.normalize(P)),{positions:C,edges:P}};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\")},{\"robust-orientation\":510,\"simplicial-complex\":522}],525:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,a,o,s;if(e[0][0]<e[1][0])r=e[0],a=e[1];else{if(!(e[0][0]>e[1][0]))return i(e,t);r=e[1],a=e[0]}if(t[0][0]<t[1][0])o=t[0],s=t[1];else{if(!(t[0][0]>t[1][0]))return-i(t,e);o=t[1],s=t[0]}var l=n(r,a,s),c=n(r,a,o);if(l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;if(l=n(s,o,a),c=n(s,o,r),l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;return a[0]-s[0]};var n=t(\"robust-orientation\");function i(t,e){var r,i,a,o;if(e[0][0]<e[1][0])r=e[0],i=e[1];else{if(!(e[0][0]>e[1][0])){var s=Math.min(t[0][1],t[1][1]),l=Math.max(t[0][1],t[1][1]),c=Math.min(e[0][1],e[1][1]),u=Math.max(e[0][1],e[1][1]);return l<c?l-c:s>u?s-u:l-u}r=e[1],i=e[0]}t[0][1]<t[1][1]?(a=t[0],o=t[1]):(a=t[1],o=t[0]);var h=n(i,r,a);return h||((h=n(i,r,o))||o-i)}},{\"robust-orientation\":510}],526:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=2*e,n=new Array(r),a=0;a<e;++a){var l=t[a],c=l[0][0]<l[1][0];n[2*a]=new h(l[0][0],l,c,a),n[2*a+1]=new h(l[1][0],l,!c,a)}n.sort(function(t,e){var r=t.x-e.x;return r||((r=t.create-e.create)||Math.min(t.segment[0][1],t.segment[1][1])-Math.min(e.segment[0][1],e.segment[1][1]))});for(var f=i(o),p=[],d=[],g=[],a=0;a<r;){for(var v=n[a].x,m=[];a<r;){var y=n[a];if(y.x!==v)break;a+=1,y.segment[0][0]===y.x&&y.segment[1][0]===y.x?y.create&&(y.segment[0][1]<y.segment[1][1]?(m.push(new u(y.segment[0][1],y.index,!0,!0)),m.push(new u(y.segment[1][1],y.index,!1,!1))):(m.push(new u(y.segment[1][1],y.index,!0,!1)),m.push(new u(y.segment[0][1],y.index,!1,!0)))):f=y.create?f.insert(y.segment,y.index):f.remove(y.segment)}p.push(f.root),d.push(v),g.push(m)}return new s(p,d,g)};var n=t(\"binary-search-bounds\"),i=t(\"functional-red-black-tree\"),a=t(\"robust-orientation\"),o=t(\"./lib/order-segments\");function s(t,e,r){this.slabs=t,this.coordinates=e,this.horizontal=r}function l(t,e){return t.y-e}function c(t,e){for(var r=null;t;){var n,i,o=t.key;o[0][0]<o[1][0]?(n=o[0],i=o[1]):(n=o[1],i=o[0]);var s=a(n,i,e);if(s<0)t=t.left;else if(s>0)if(e[0]!==o[1][0])r=t,t=t.right;else{if(l=c(t.right,e))return l;t=t.left}else{if(e[0]!==o[1][0])return t;var l;if(l=c(t.right,e))return l;t=t.left}}return r}function u(t,e,r,n){this.y=t,this.index=e,this.start=r,this.closed=n}function h(t,e,r,n){this.x=t,this.segment=e,this.create=r,this.index=n}s.prototype.castUp=function(t){var e=n.le(this.coordinates,t[0]);if(e<0)return-1;this.slabs[e];var r=c(this.slabs[e],t),i=-1;if(r&&(i=r.value),this.coordinates[e]===t[0]){var s=null;if(r&&(s=r.key),e>0){var u=c(this.slabs[e-1],t);u&&(s?o(u.key,s)>0&&(s=u.key,i=u.value):(i=u.value,s=u.key))}var h=this.horizontal[e];if(h.length>0){var f=n.ge(h,t[1],l);if(f<h.length){var p=h[f];if(t[1]===p.y){if(p.closed)return p.index;for(;f<h.length-1&&h[f+1].y===t[1];)if((p=h[f+=1]).closed)return p.index;if(p.y===t[1]&&!p.start){if((f+=1)>=h.length)return i;p=h[f]}}if(p.start)if(s){var d=a(s[0],s[1],[t[0],p.y]);s[0][0]>s[1][0]&&(d=-d),d>0&&(i=p.index)}else i=p.index;else p.y!==t[1]&&(i=p.index)}}}return i}},{\"./lib/order-segments\":525,\"binary-search-bounds\":91,\"functional-red-black-tree\":230,\"robust-orientation\":510}],527:[function(t,e,r){\"use strict\";var n=t(\"robust-dot-product\"),i=t(\"robust-sum\");function a(t,e){var r=i(n(t,e),[e[e.length-1]]);return r[r.length-1]}function o(t,e,r,n){var i=-e/(n-e);i<0?i=0:i>1&&(i=1);for(var a=1-i,o=t.length,s=new Array(o),l=0;l<o;++l)s[l]=i*t[l]+a*r[l];return s}e.exports=function(t,e){for(var r=[],n=[],i=a(t[t.length-1],e),s=t[t.length-1],l=t[0],c=0;c<t.length;++c,s=l){var u=a(l=t[c],e);if(i<0&&u>0||i>0&&u<0){var h=o(s,u,l,i);r.push(h),n.push(h.slice())}u<0?n.push(l.slice()):u>0?r.push(l.slice()):(r.push(l.slice()),n.push(l.slice())),i=u}return{positive:r,negative:n}},e.exports.positive=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c>=0&&r.push(s.slice()),n=c}return r},e.exports.negative=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c<=0&&r.push(s.slice()),n=c}return r}},{\"robust-dot-product\":507,\"robust-sum\":515}],528:[function(t,e,r){!function(){\"use strict\";var t={not_string:/[^s]/,not_bool:/[^t]/,not_type:/[^T]/,not_primitive:/[^v]/,number:/[diefg]/,numeric_arg:/[bcdiefguxX]/,json:/[j]/,not_json:/[^j]/,text:/^[^\\x25]+/,modulo:/^\\x25{2}/,placeholder:/^\\x25(?:([1-9]\\d*)\\$|\\(([^)]+)\\))?(\\+)?(0|'[^$])?(-)?(\\d+)?(?:\\.(\\d+))?([b-gijostTuvxX])/,key:/^([a-z_][a-z_\\d]*)/i,key_access:/^\\.([a-z_][a-z_\\d]*)/i,index_access:/^\\[(\\d+)\\]/,sign:/^[+-]/};function e(r){return function(r,n){var i,a,o,s,l,c,u,h,f,p=1,d=r.length,g=\"\";for(a=0;a<d;a++)if(\"string\"==typeof r[a])g+=r[a];else if(\"object\"==typeof r[a]){if((s=r[a]).keys)for(i=n[p],o=0;o<s.keys.length;o++){if(null==i)throw new Error(e('[sprintf] Cannot access property \"%s\" of undefined value \"%s\"',s.keys[o],s.keys[o-1]));i=i[s.keys[o]]}else i=s.param_no?n[s.param_no]:n[p++];if(t.not_type.test(s.type)&&t.not_primitive.test(s.type)&&i instanceof Function&&(i=i()),t.numeric_arg.test(s.type)&&\"number\"!=typeof i&&isNaN(i))throw new TypeError(e(\"[sprintf] expecting number but found %T\",i));switch(t.number.test(s.type)&&(h=i>=0),s.type){case\"b\":i=parseInt(i,10).toString(2);break;case\"c\":i=String.fromCharCode(parseInt(i,10));break;case\"d\":case\"i\":i=parseInt(i,10);break;case\"j\":i=JSON.stringify(i,null,s.width?parseInt(s.width):0);break;case\"e\":i=s.precision?parseFloat(i).toExponential(s.precision):parseFloat(i).toExponential();break;case\"f\":i=s.precision?parseFloat(i).toFixed(s.precision):parseFloat(i);break;case\"g\":i=s.precision?String(Number(i.toPrecision(s.precision))):parseFloat(i);break;case\"o\":i=(parseInt(i,10)>>>0).toString(8);break;case\"s\":i=String(i),i=s.precision?i.substring(0,s.precision):i;break;case\"t\":i=String(!!i),i=s.precision?i.substring(0,s.precision):i;break;case\"T\":i=Object.prototype.toString.call(i).slice(8,-1).toLowerCase(),i=s.precision?i.substring(0,s.precision):i;break;case\"u\":i=parseInt(i,10)>>>0;break;case\"v\":i=i.valueOf(),i=s.precision?i.substring(0,s.precision):i;break;case\"x\":i=(parseInt(i,10)>>>0).toString(16);break;case\"X\":i=(parseInt(i,10)>>>0).toString(16).toUpperCase()}t.json.test(s.type)?g+=i:(!t.number.test(s.type)||h&&!s.sign?f=\"\":(f=h?\"+\":\"-\",i=i.toString().replace(t.sign,\"\")),c=s.pad_char?\"0\"===s.pad_char?\"0\":s.pad_char.charAt(1):\" \",u=s.width-(f+i).length,l=s.width&&u>0?c.repeat(u):\"\",g+=s.align?f+i+l:\"0\"===c?f+l+i:l+f+i)}return g}(function(e){if(i[e])return i[e];var r,n=e,a=[],o=0;for(;n;){if(null!==(r=t.text.exec(n)))a.push(r[0]);else if(null!==(r=t.modulo.exec(n)))a.push(\"%\");else{if(null===(r=t.placeholder.exec(n)))throw new SyntaxError(\"[sprintf] unexpected placeholder\");if(r[2]){o|=1;var s=[],l=r[2],c=[];if(null===(c=t.key.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");for(s.push(c[1]);\"\"!==(l=l.substring(c[0].length));)if(null!==(c=t.key_access.exec(l)))s.push(c[1]);else{if(null===(c=t.index_access.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");s.push(c[1])}r[2]=s}else o|=2;if(3===o)throw new Error(\"[sprintf] mixing positional and named placeholders is not (yet) supported\");a.push({placeholder:r[0],param_no:r[1],keys:r[2],sign:r[3],pad_char:r[4],align:r[5],width:r[6],precision:r[7],type:r[8]})}n=n.substring(r[0].length)}return i[e]=a}(r),arguments)}function n(t,r){return e.apply(null,[t].concat(r||[]))}var i=Object.create(null);\"undefined\"!=typeof r&&(r.sprintf=e,r.vsprintf=n),\"undefined\"!=typeof window&&(window.sprintf=e,window.vsprintf=n)}()},{}],529:[function(t,e,r){\"use strict\";var n=t(\"parenthesis\");e.exports=function(t,e,r){if(null==t)throw Error(\"First argument should be a string\");if(null==e)throw Error(\"Separator should be a string or a RegExp\");r?(\"string\"==typeof r||Array.isArray(r))&&(r={ignore:r}):r={},null==r.escape&&(r.escape=!0),null==r.ignore?r.ignore=[\"[]\",\"()\",\"{}\",\"<>\",'\"\"',\"''\",\"``\",\"\\u201c\\u201d\",\"\\xab\\xbb\"]:(\"string\"==typeof r.ignore&&(r.ignore=[r.ignore]),r.ignore=r.ignore.map(function(t){return 1===t.length&&(t+=t),t}));var i=n.parse(t,{flat:!0,brackets:r.ignore}),a=i[0].split(e);if(r.escape){for(var o=[],s=0;s<a.length;s++){var l=a[s],c=a[s+1];\"\\\\\"===l[l.length-1]&&\"\\\\\"!==l[l.length-2]?(o.push(l+e+c),s++):o.push(l)}a=o}for(s=0;s<a.length;s++)i[0]=a[s],a[s]=n.stringify(i,{flat:!0});return a}},{parenthesis:458}],530:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=new Array(e),n=new Array(e),i=new Array(e),a=new Array(e),o=new Array(e),s=new Array(e),l=0;l<e;++l)r[l]=-1,n[l]=0,i[l]=!1,a[l]=0,o[l]=-1,s[l]=[];var c,u=0,h=[],f=[];function p(e){var l=[e],c=[e];for(r[e]=n[e]=u,i[e]=!0,u+=1;c.length>0;){e=c[c.length-1];var p=t[e];if(a[e]<p.length){for(var d=a[e];d<p.length;++d){var g=p[d];if(r[g]<0){r[g]=n[g]=u,i[g]=!0,u+=1,l.push(g),c.push(g);break}i[g]&&(n[e]=0|Math.min(n[e],n[g])),o[g]>=0&&s[e].push(o[g])}a[e]=d}else{if(n[e]===r[e]){for(var v=[],m=[],y=0,d=l.length-1;d>=0;--d){var x=l[d];if(i[x]=!1,v.push(x),m.push(s[x]),y+=s[x].length,o[x]=h.length,x===e){l.length=d;break}}h.push(v);for(var b=new Array(y),d=0;d<m.length;d++)for(var _=0;_<m[d].length;_++)b[--y]=m[d][_];f.push(b)}c.pop()}}}for(var l=0;l<e;++l)r[l]<0&&p(l);for(var l=0;l<f.length;l++){var d=f[l];if(0!==d.length){d.sort(function(t,e){return t-e}),c=[d[0]];for(var g=1;g<d.length;g++)d[g]!==d[g-1]&&c.push(d[g]);f[l]=c}}return{components:h,adjacencyList:f}}},{}],531:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(t.dimension<=0)return{positions:[],cells:[]};if(1===t.dimension)return function(t,e){for(var r=a(t,e),n=r.length,i=new Array(n),o=new Array(n),s=0;s<n;++s)i[s]=[r[s]],o[s]=[s];return{positions:i,cells:o}}(t,e);var r=t.order.join()+\"-\"+t.dtype,s=o[r],e=+e||0;s||(s=o[r]=function(t,e){var r=t.length,a=[\"'use strict';\"],o=\"surfaceNets\"+t.join(\"_\")+\"d\"+e;a.push(\"var contour=genContour({\",\"order:[\",t.join(),\"],\",\"scalarArguments: 3,\",\"phase:function phaseFunc(p,a,b,c) { return (p > c)|0 },\"),\"generic\"===e&&a.push(\"getters:[0],\");for(var s=[],l=[],c=0;c<r;++c)s.push(\"d\"+c),l.push(\"d\"+c);for(var c=0;c<1<<r;++c)s.push(\"v\"+c),l.push(\"v\"+c);for(var c=0;c<1<<r;++c)s.push(\"p\"+c),l.push(\"p\"+c);s.push(\"a\",\"b\",\"c\"),l.push(\"a\",\"c\"),a.push(\"vertex:function vertexFunc(\",s.join(),\"){\");for(var u=[],c=0;c<1<<r;++c)u.push(\"(p\"+c+\"<<\"+c+\")\");a.push(\"var m=(\",u.join(\"+\"),\")|0;if(m===0||m===\",(1<<(1<<r))-1,\"){return}\");var h=[],f=[];1<<(1<<r)<=128?(a.push(\"switch(m){\"),f=a):a.push(\"switch(m>>>7){\");for(var c=0;c<1<<(1<<r);++c){if(1<<(1<<r)>128&&c%128==0){h.length>0&&f.push(\"}}\");var p=\"vExtra\"+h.length;a.push(\"case \",c>>>7,\":\",p,\"(m&0x7f,\",l.join(),\");break;\"),f=[\"function \",p,\"(m,\",l.join(),\"){switch(m){\"],h.push(f)}f.push(\"case \",127&c,\":\");for(var d=new Array(r),g=new Array(r),v=new Array(r),m=new Array(r),y=0,x=0;x<r;++x)d[x]=[],g[x]=[],v[x]=0,m[x]=0;for(var x=0;x<1<<r;++x)for(var b=0;b<r;++b){var _=x^1<<b;if(!(_>x)&&!(c&1<<_)!=!(c&1<<x)){var w=1;c&1<<_?g[b].push(\"v\"+_+\"-v\"+x):(g[b].push(\"v\"+x+\"-v\"+_),w=-w),w<0?(d[b].push(\"-v\"+x+\"-v\"+_),v[b]+=2):(d[b].push(\"v\"+x+\"+v\"+_),v[b]-=2),y+=1;for(var k=0;k<r;++k)k!==b&&(_&1<<k?m[k]+=1:m[k]-=1)}}for(var T=[],b=0;b<r;++b)if(0===d[b].length)T.push(\"d\"+b+\"-0.5\");else{var A=\"\";v[b]<0?A=v[b]+\"*c\":v[b]>0&&(A=\"+\"+v[b]+\"*c\");var M=d[b].length/y*.5,S=.5+m[b]/y*.5;T.push(\"d\"+b+\"-\"+S+\"-\"+M+\"*(\"+d[b].join(\"+\")+A+\")/(\"+g[b].join(\"+\")+\")\")}f.push(\"a.push([\",T.join(),\"]);\",\"break;\")}a.push(\"}},\"),h.length>0&&f.push(\"}}\");for(var E=[],c=0;c<1<<r-1;++c)E.push(\"v\"+c);E.push(\"c0\",\"c1\",\"p0\",\"p1\",\"a\",\"b\",\"c\"),a.push(\"cell:function cellFunc(\",E.join(),\"){\");var C=i(r-1);a.push(\"if(p0){b.push(\",C.map(function(t){return\"[\"+t.map(function(t){return\"v\"+t})+\"]\"}).join(),\")}else{b.push(\",C.map(function(t){var e=t.slice();return e.reverse(),\"[\"+e.map(function(t){return\"v\"+t})+\"]\"}).join(),\")}}});function \",o,\"(array,level){var verts=[],cells=[];contour(array,verts,cells,level);return {positions:verts,cells:cells};} return \",o,\";\");for(var c=0;c<h.length;++c)a.push(h[c].join(\"\"));return new Function(\"genContour\",a.join(\"\"))(n)}(t.order,t.dtype));return s(t,e)};var n=t(\"ndarray-extract-contour\"),i=t(\"triangulate-hypercube\"),a=t(\"zero-crossings\");var o={}},{\"ndarray-extract-contour\":439,\"triangulate-hypercube\":541,\"zero-crossings\":574}],532:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=function(){return function(t,e){if(Array.isArray(t))return t;if(Symbol.iterator in Object(t))return function(t,e){var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{!n&&s.return&&s.return()}finally{if(i)throw a}}return r}(t,e);throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")}}(),i=2*Math.PI,a=function(t,e,r,n,i,a,o){var s=t.x,l=t.y;return{x:n*(s*=e)-i*(l*=r)+a,y:i*s+n*l+o}},o=function(t,e){var r=.551915024494*(e<0?-1:1),n=Math.cos(t),i=Math.sin(t),a=Math.cos(t+e),o=Math.sin(t+e);return[{x:n-i*r,y:i+n*r},{x:a+o*r,y:o-a*r},{x:a,y:o}]},s=function(t,e,r,n){var i=t*n-e*r<0?-1:1,a=(t*r+e*n)/(Math.sqrt(t*t+e*e)*Math.sqrt(t*t+e*e));return a>1&&(a=1),a<-1&&(a=-1),i*Math.acos(a)};r.default=function(t){var e=t.px,r=t.py,l=t.cx,c=t.cy,u=t.rx,h=t.ry,f=t.xAxisRotation,p=void 0===f?0:f,d=t.largeArcFlag,g=void 0===d?0:d,v=t.sweepFlag,m=void 0===v?0:v,y=[];if(0===u||0===h)return[];var x=Math.sin(p*i/360),b=Math.cos(p*i/360),_=b*(e-l)/2+x*(r-c)/2,w=-x*(e-l)/2+b*(r-c)/2;if(0===_&&0===w)return[];u=Math.abs(u),h=Math.abs(h);var k=Math.pow(_,2)/Math.pow(u,2)+Math.pow(w,2)/Math.pow(h,2);k>1&&(u*=Math.sqrt(k),h*=Math.sqrt(k));var T=function(t,e,r,n,a,o,l,c,u,h,f,p){var d=Math.pow(a,2),g=Math.pow(o,2),v=Math.pow(f,2),m=Math.pow(p,2),y=d*g-d*m-g*v;y<0&&(y=0),y/=d*m+g*v;var x=(y=Math.sqrt(y)*(l===c?-1:1))*a/o*p,b=y*-o/a*f,_=h*x-u*b+(t+r)/2,w=u*x+h*b+(e+n)/2,k=(f-x)/a,T=(p-b)/o,A=(-f-x)/a,M=(-p-b)/o,S=s(1,0,k,T),E=s(k,T,A,M);return 0===c&&E>0&&(E-=i),1===c&&E<0&&(E+=i),[_,w,S,E]}(e,r,l,c,u,h,g,m,x,b,_,w),A=n(T,4),M=A[0],S=A[1],E=A[2],C=A[3],L=Math.abs(C)/(i/4);Math.abs(1-L)<1e-7&&(L=1);var P=Math.max(Math.ceil(L),1);C/=P;for(var O=0;O<P;O++)y.push(o(E,C)),E+=C;return y.map(function(t){var e=a(t[0],u,h,b,x,M,S),r=e.x,n=e.y,i=a(t[1],u,h,b,x,M,S),o=i.x,s=i.y,l=a(t[2],u,h,b,x,M,S);return{x1:r,y1:n,x2:o,y2:s,x:l.x,y:l.y}})},e.exports=r.default},{}],533:[function(t,e,r){\"use strict\";var n=t(\"parse-svg-path\"),i=t(\"abs-svg-path\"),a=t(\"normalize-svg-path\"),o=t(\"is-svg-path\"),s=t(\"assert\");e.exports=function(t){Array.isArray(t)&&1===t.length&&\"string\"==typeof t[0]&&(t=t[0]);\"string\"==typeof t&&(s(o(t),\"String is not an SVG path.\"),t=n(t));if(s(Array.isArray(t),\"Argument should be a string or an array of path segments.\"),t=i(t),!(t=a(t)).length)return[0,0,0,0];for(var e=[1/0,1/0,-1/0,-1/0],r=0,l=t.length;r<l;r++)for(var c=t[r].slice(1),u=0;u<c.length;u+=2)c[u+0]<e[0]&&(e[0]=c[u+0]),c[u+1]<e[1]&&(e[1]=c[u+1]),c[u+0]>e[2]&&(e[2]=c[u+0]),c[u+1]>e[3]&&(e[3]=c[u+1]);return e}},{\"abs-svg-path\":60,assert:68,\"is-svg-path\":424,\"normalize-svg-path\":534,\"parse-svg-path\":460}],534:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=[],o=0,s=0,l=0,c=0,u=null,h=null,f=0,p=0,d=0,g=t.length;d<g;d++){var v=t[d],m=v[0];switch(m){case\"M\":l=v[1],c=v[2];break;case\"A\":var y=n({px:f,py:p,cx:v[6],cy:v[7],rx:v[1],ry:v[2],xAxisRotation:v[3],largeArcFlag:v[4],sweepFlag:v[5]});if(!y.length)continue;for(var x,b=0;b<y.length;b++)x=y[b],v=[\"C\",x.x1,x.y1,x.x2,x.y2,x.x,x.y],b<y.length-1&&r.push(v);break;case\"S\":var _=f,w=p;\"C\"!=e&&\"S\"!=e||(_+=_-o,w+=w-s),v=[\"C\",_,w,v[1],v[2],v[3],v[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(u=2*f-u,h=2*p-h):(u=f,h=p),v=a(f,p,u,h,v[1],v[2]);break;case\"Q\":u=v[1],h=v[2],v=a(f,p,v[1],v[2],v[3],v[4]);break;case\"L\":v=i(f,p,v[1],v[2]);break;case\"H\":v=i(f,p,v[1],p);break;case\"V\":v=i(f,p,f,v[1]);break;case\"Z\":v=i(f,p,l,c)}e=m,f=v[v.length-2],p=v[v.length-1],v.length>4?(o=v[v.length-4],s=v[v.length-3]):(o=f,s=p),r.push(v)}return r};var n=t(\"svg-arc-to-cubic-bezier\");function i(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function a(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}},{\"svg-arc-to-cubic-bezier\":532}],535:[function(t,e,r){\"use strict\";var n,i=t(\"svg-path-bounds\"),a=t(\"parse-svg-path\"),o=t(\"draw-svg-path\"),s=t(\"is-svg-path\"),l=t(\"bitmap-sdf\"),c=document.createElement(\"canvas\"),u=c.getContext(\"2d\");e.exports=function(t,e){if(!s(t))throw Error(\"Argument should be valid svg path string\");e||(e={});var r,h;e.shape?(r=e.shape[0],h=e.shape[1]):(r=c.width=e.w||e.width||200,h=c.height=e.h||e.height||200);var f=Math.min(r,h),p=e.stroke||0,d=e.viewbox||e.viewBox||i(t),g=[r/(d[2]-d[0]),h/(d[3]-d[1])],v=Math.min(g[0]||0,g[1]||0)/2;u.fillStyle=\"black\",u.fillRect(0,0,r,h),u.fillStyle=\"white\",p&&(\"number\"!=typeof p&&(p=1),u.strokeStyle=p>0?\"white\":\"black\",u.lineWidth=Math.abs(p));if(u.translate(.5*r,.5*h),u.scale(v,v),function(){if(null!=n)return n;var t=document.createElement(\"canvas\").getContext(\"2d\");if(t.canvas.width=t.canvas.height=1,!window.Path2D)return n=!1;var e=new Path2D(\"M0,0h1v1h-1v-1Z\");t.fillStyle=\"black\",t.fill(e);var r=t.getImageData(0,0,1,1);return n=r&&r.data&&255===r.data[3]}()){var m=new Path2D(t);u.fill(m),p&&u.stroke(m)}else{var y=a(t);o(u,y),u.fill(),p&&u.stroke()}return u.setTransform(1,0,0,1,0,0),l(u,{cutoff:null!=e.cutoff?e.cutoff:.5,radius:null!=e.radius?e.radius:.5*f})}},{\"bitmap-sdf\":93,\"draw-svg-path\":168,\"is-svg-path\":424,\"parse-svg-path\":460,\"svg-path-bounds\":533}],536:[function(t,e,r){(function(r){\"use strict\";e.exports=function t(e,r,i){var i=i||{};var o=a[e];o||(o=a[e]={\" \":{data:new Float32Array(0),shape:.2}});var s=o[r];if(!s)if(r.length<=1||!/\\d/.test(r))s=o[r]=function(t){for(var e=t.cells,r=t.positions,n=new Float32Array(6*e.length),i=0,a=0,o=0;o<e.length;++o)for(var s=e[o],l=0;l<3;++l){var c=r[s[l]];n[i++]=c[0],n[i++]=c[1]+1.4,a=Math.max(c[0],a)}return{data:n,shape:a}}(n(r,{triangles:!0,font:e,textAlign:i.textAlign||\"left\",textBaseline:\"alphabetic\",styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0}}));else{for(var l=r.split(/(\\d|\\s)/),c=new Array(l.length),u=0,h=0,f=0;f<l.length;++f)c[f]=t(e,l[f]),u+=c[f].data.length,h+=c[f].shape,f>0&&(h+=.02);for(var p=new Float32Array(u),d=0,g=-.5*h,f=0;f<c.length;++f){for(var v=c[f].data,m=0;m<v.length;m+=2)p[d++]=v[m]+g,p[d++]=v[m+1];g+=c[f].shape+.02}s=o[r]={data:p,shape:h}}return s};var n=t(\"vectorize-text\"),i=window||r.global||{},a=i.__TEXT_CACHE||{};i.__TEXT_CACHE={}}).call(this,t(\"_process\"))},{_process:482,\"vectorize-text\":550}],537:[function(t,e,r){!function(t){var r=/^\\s+/,n=/\\s+$/,i=0,a=t.round,o=t.min,s=t.max,l=t.random;function c(e,l){if(l=l||{},(e=e||\"\")instanceof c)return e;if(!(this instanceof c))return new c(e,l);var u=function(e){var i={r:0,g:0,b:0},a=1,l=null,c=null,u=null,h=!1,f=!1;\"string\"==typeof e&&(e=function(t){t=t.replace(r,\"\").replace(n,\"\").toLowerCase();var e,i=!1;if(S[t])t=S[t],i=!0;else if(\"transparent\"==t)return{r:0,g:0,b:0,a:0,format:\"name\"};if(e=j.rgb.exec(t))return{r:e[1],g:e[2],b:e[3]};if(e=j.rgba.exec(t))return{r:e[1],g:e[2],b:e[3],a:e[4]};if(e=j.hsl.exec(t))return{h:e[1],s:e[2],l:e[3]};if(e=j.hsla.exec(t))return{h:e[1],s:e[2],l:e[3],a:e[4]};if(e=j.hsv.exec(t))return{h:e[1],s:e[2],v:e[3]};if(e=j.hsva.exec(t))return{h:e[1],s:e[2],v:e[3],a:e[4]};if(e=j.hex8.exec(t))return{r:O(e[1]),g:O(e[2]),b:O(e[3]),a:R(e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex6.exec(t))return{r:O(e[1]),g:O(e[2]),b:O(e[3]),format:i?\"name\":\"hex\"};if(e=j.hex4.exec(t))return{r:O(e[1]+\"\"+e[1]),g:O(e[2]+\"\"+e[2]),b:O(e[3]+\"\"+e[3]),a:R(e[4]+\"\"+e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex3.exec(t))return{r:O(e[1]+\"\"+e[1]),g:O(e[2]+\"\"+e[2]),b:O(e[3]+\"\"+e[3]),format:i?\"name\":\"hex\"};return!1}(e));\"object\"==typeof e&&(U(e.r)&&U(e.g)&&U(e.b)?(p=e.r,d=e.g,g=e.b,i={r:255*L(p,255),g:255*L(d,255),b:255*L(g,255)},h=!0,f=\"%\"===String(e.r).substr(-1)?\"prgb\":\"rgb\"):U(e.h)&&U(e.s)&&U(e.v)?(l=I(e.s),c=I(e.v),i=function(e,r,n){e=6*L(e,360),r=L(r,100),n=L(n,100);var i=t.floor(e),a=e-i,o=n*(1-r),s=n*(1-a*r),l=n*(1-(1-a)*r),c=i%6;return{r:255*[n,s,o,o,l,n][c],g:255*[l,n,n,s,o,o][c],b:255*[o,o,l,n,n,s][c]}}(e.h,l,c),h=!0,f=\"hsv\"):U(e.h)&&U(e.s)&&U(e.l)&&(l=I(e.s),u=I(e.l),i=function(t,e,r){var n,i,a;function o(t,e,r){return r<0&&(r+=1),r>1&&(r-=1),r<1/6?t+6*(e-t)*r:r<.5?e:r<2/3?t+(e-t)*(2/3-r)*6:t}if(t=L(t,360),e=L(e,100),r=L(r,100),0===e)n=i=a=r;else{var s=r<.5?r*(1+e):r+e-r*e,l=2*r-s;n=o(l,s,t+1/3),i=o(l,s,t),a=o(l,s,t-1/3)}return{r:255*n,g:255*i,b:255*a}}(e.h,l,u),h=!0,f=\"hsl\"),e.hasOwnProperty(\"a\")&&(a=e.a));var p,d,g;return a=C(a),{ok:h,format:e.format||f,r:o(255,s(i.r,0)),g:o(255,s(i.g,0)),b:o(255,s(i.b,0)),a:a}}(e);this._originalInput=e,this._r=u.r,this._g=u.g,this._b=u.b,this._a=u.a,this._roundA=a(100*this._a)/100,this._format=l.format||u.format,this._gradientType=l.gradientType,this._r<1&&(this._r=a(this._r)),this._g<1&&(this._g=a(this._g)),this._b<1&&(this._b=a(this._b)),this._ok=u.ok,this._tc_id=i++}function u(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=(a+l)/2;if(a==l)n=i=0;else{var u=a-l;switch(i=c>.5?u/(2-a-l):u/(a+l),a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,l:c}}function h(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=a,u=a-l;if(i=0===a?0:u/a,a==l)n=0;else{switch(a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,v:c}}function f(t,e,r,n){var i=[z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16))];return n&&i[0].charAt(0)==i[0].charAt(1)&&i[1].charAt(0)==i[1].charAt(1)&&i[2].charAt(0)==i[2].charAt(1)?i[0].charAt(0)+i[1].charAt(0)+i[2].charAt(0):i.join(\"\")}function p(t,e,r,n){return[z(D(n)),z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16))].join(\"\")}function d(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s-=e/100,r.s=P(r.s),c(r)}function g(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s+=e/100,r.s=P(r.s),c(r)}function v(t){return c(t).desaturate(100)}function m(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l+=e/100,r.l=P(r.l),c(r)}function y(t,e){e=0===e?0:e||10;var r=c(t).toRgb();return r.r=s(0,o(255,r.r-a(-e/100*255))),r.g=s(0,o(255,r.g-a(-e/100*255))),r.b=s(0,o(255,r.b-a(-e/100*255))),c(r)}function x(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l-=e/100,r.l=P(r.l),c(r)}function b(t,e){var r=c(t).toHsl(),n=(r.h+e)%360;return r.h=n<0?360+n:n,c(r)}function _(t){var e=c(t).toHsl();return e.h=(e.h+180)%360,c(e)}function w(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+120)%360,s:e.s,l:e.l}),c({h:(r+240)%360,s:e.s,l:e.l})]}function k(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+90)%360,s:e.s,l:e.l}),c({h:(r+180)%360,s:e.s,l:e.l}),c({h:(r+270)%360,s:e.s,l:e.l})]}function T(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+72)%360,s:e.s,l:e.l}),c({h:(r+216)%360,s:e.s,l:e.l})]}function A(t,e,r){e=e||6,r=r||30;var n=c(t).toHsl(),i=360/r,a=[c(t)];for(n.h=(n.h-(i*e>>1)+720)%360;--e;)n.h=(n.h+i)%360,a.push(c(n));return a}function M(t,e){e=e||6;for(var r=c(t).toHsv(),n=r.h,i=r.s,a=r.v,o=[],s=1/e;e--;)o.push(c({h:n,s:i,v:a})),a=(a+s)%1;return o}c.prototype={isDark:function(){return this.getBrightness()<128},isLight:function(){return!this.isDark()},isValid:function(){return this._ok},getOriginalInput:function(){return this._originalInput},getFormat:function(){return this._format},getAlpha:function(){return this._a},getBrightness:function(){var t=this.toRgb();return(299*t.r+587*t.g+114*t.b)/1e3},getLuminance:function(){var e,r,n,i=this.toRgb();return e=i.r/255,r=i.g/255,n=i.b/255,.2126*(e<=.03928?e/12.92:t.pow((e+.055)/1.055,2.4))+.7152*(r<=.03928?r/12.92:t.pow((r+.055)/1.055,2.4))+.0722*(n<=.03928?n/12.92:t.pow((n+.055)/1.055,2.4))},setAlpha:function(t){return this._a=C(t),this._roundA=a(100*this._a)/100,this},toHsv:function(){var t=h(this._r,this._g,this._b);return{h:360*t.h,s:t.s,v:t.v,a:this._a}},toHsvString:function(){var t=h(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.v);return 1==this._a?\"hsv(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsva(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHsl:function(){var t=u(this._r,this._g,this._b);return{h:360*t.h,s:t.s,l:t.l,a:this._a}},toHslString:function(){var t=u(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.l);return 1==this._a?\"hsl(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsla(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHex:function(t){return f(this._r,this._g,this._b,t)},toHexString:function(t){return\"#\"+this.toHex(t)},toHex8:function(t){return function(t,e,r,n,i){var o=[z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16)),z(D(n))];if(i&&o[0].charAt(0)==o[0].charAt(1)&&o[1].charAt(0)==o[1].charAt(1)&&o[2].charAt(0)==o[2].charAt(1)&&o[3].charAt(0)==o[3].charAt(1))return o[0].charAt(0)+o[1].charAt(0)+o[2].charAt(0)+o[3].charAt(0);return o.join(\"\")}(this._r,this._g,this._b,this._a,t)},toHex8String:function(t){return\"#\"+this.toHex8(t)},toRgb:function(){return{r:a(this._r),g:a(this._g),b:a(this._b),a:this._a}},toRgbString:function(){return 1==this._a?\"rgb(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\")\":\"rgba(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\", \"+this._roundA+\")\"},toPercentageRgb:function(){return{r:a(100*L(this._r,255))+\"%\",g:a(100*L(this._g,255))+\"%\",b:a(100*L(this._b,255))+\"%\",a:this._a}},toPercentageRgbString:function(){return 1==this._a?\"rgb(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%)\":\"rgba(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%, \"+this._roundA+\")\"},toName:function(){return 0===this._a?\"transparent\":!(this._a<1)&&(E[f(this._r,this._g,this._b,!0)]||!1)},toFilter:function(t){var e=\"#\"+p(this._r,this._g,this._b,this._a),r=e,n=this._gradientType?\"GradientType = 1, \":\"\";if(t){var i=c(t);r=\"#\"+p(i._r,i._g,i._b,i._a)}return\"progid:DXImageTransform.Microsoft.gradient(\"+n+\"startColorstr=\"+e+\",endColorstr=\"+r+\")\"},toString:function(t){var e=!!t;t=t||this._format;var r=!1,n=this._a<1&&this._a>=0;return e||!n||\"hex\"!==t&&\"hex6\"!==t&&\"hex3\"!==t&&\"hex4\"!==t&&\"hex8\"!==t&&\"name\"!==t?(\"rgb\"===t&&(r=this.toRgbString()),\"prgb\"===t&&(r=this.toPercentageRgbString()),\"hex\"!==t&&\"hex6\"!==t||(r=this.toHexString()),\"hex3\"===t&&(r=this.toHexString(!0)),\"hex4\"===t&&(r=this.toHex8String(!0)),\"hex8\"===t&&(r=this.toHex8String()),\"name\"===t&&(r=this.toName()),\"hsl\"===t&&(r=this.toHslString()),\"hsv\"===t&&(r=this.toHsvString()),r||this.toHexString()):\"name\"===t&&0===this._a?this.toName():this.toRgbString()},clone:function(){return c(this.toString())},_applyModification:function(t,e){var r=t.apply(null,[this].concat([].slice.call(e)));return this._r=r._r,this._g=r._g,this._b=r._b,this.setAlpha(r._a),this},lighten:function(){return this._applyModification(m,arguments)},brighten:function(){return this._applyModification(y,arguments)},darken:function(){return this._applyModification(x,arguments)},desaturate:function(){return this._applyModification(d,arguments)},saturate:function(){return this._applyModification(g,arguments)},greyscale:function(){return this._applyModification(v,arguments)},spin:function(){return this._applyModification(b,arguments)},_applyCombination:function(t,e){return t.apply(null,[this].concat([].slice.call(e)))},analogous:function(){return this._applyCombination(A,arguments)},complement:function(){return this._applyCombination(_,arguments)},monochromatic:function(){return this._applyCombination(M,arguments)},splitcomplement:function(){return this._applyCombination(T,arguments)},triad:function(){return this._applyCombination(w,arguments)},tetrad:function(){return this._applyCombination(k,arguments)}},c.fromRatio=function(t,e){if(\"object\"==typeof t){var r={};for(var n in t)t.hasOwnProperty(n)&&(r[n]=\"a\"===n?t[n]:I(t[n]));t=r}return c(t,e)},c.equals=function(t,e){return!(!t||!e)&&c(t).toRgbString()==c(e).toRgbString()},c.random=function(){return c.fromRatio({r:l(),g:l(),b:l()})},c.mix=function(t,e,r){r=0===r?0:r||50;var n=c(t).toRgb(),i=c(e).toRgb(),a=r/100;return c({r:(i.r-n.r)*a+n.r,g:(i.g-n.g)*a+n.g,b:(i.b-n.b)*a+n.b,a:(i.a-n.a)*a+n.a})},c.readability=function(e,r){var n=c(e),i=c(r);return(t.max(n.getLuminance(),i.getLuminance())+.05)/(t.min(n.getLuminance(),i.getLuminance())+.05)},c.isReadable=function(t,e,r){var n,i,a=c.readability(t,e);switch(i=!1,(n=function(t){var e,r;e=((t=t||{level:\"AA\",size:\"small\"}).level||\"AA\").toUpperCase(),r=(t.size||\"small\").toLowerCase(),\"AA\"!==e&&\"AAA\"!==e&&(e=\"AA\");\"small\"!==r&&\"large\"!==r&&(r=\"small\");return{level:e,size:r}}(r)).level+n.size){case\"AAsmall\":case\"AAAlarge\":i=a>=4.5;break;case\"AAlarge\":i=a>=3;break;case\"AAAsmall\":i=a>=7}return i},c.mostReadable=function(t,e,r){var n,i,a,o,s=null,l=0;i=(r=r||{}).includeFallbackColors,a=r.level,o=r.size;for(var u=0;u<e.length;u++)(n=c.readability(t,e[u]))>l&&(l=n,s=c(e[u]));return c.isReadable(t,s,{level:a,size:o})||!i?s:(r.includeFallbackColors=!1,c.mostReadable(t,[\"#fff\",\"#000\"],r))};var S=c.names={aliceblue:\"f0f8ff\",antiquewhite:\"faebd7\",aqua:\"0ff\",aquamarine:\"7fffd4\",azure:\"f0ffff\",beige:\"f5f5dc\",bisque:\"ffe4c4\",black:\"000\",blanchedalmond:\"ffebcd\",blue:\"00f\",blueviolet:\"8a2be2\",brown:\"a52a2a\",burlywood:\"deb887\",burntsienna:\"ea7e5d\",cadetblue:\"5f9ea0\",chartreuse:\"7fff00\",chocolate:\"d2691e\",coral:\"ff7f50\",cornflowerblue:\"6495ed\",cornsilk:\"fff8dc\",crimson:\"dc143c\",cyan:\"0ff\",darkblue:\"00008b\",darkcyan:\"008b8b\",darkgoldenrod:\"b8860b\",darkgray:\"a9a9a9\",darkgreen:\"006400\",darkgrey:\"a9a9a9\",darkkhaki:\"bdb76b\",darkmagenta:\"8b008b\",darkolivegreen:\"556b2f\",darkorange:\"ff8c00\",darkorchid:\"9932cc\",darkred:\"8b0000\",darksalmon:\"e9967a\",darkseagreen:\"8fbc8f\",darkslateblue:\"483d8b\",darkslategray:\"2f4f4f\",darkslategrey:\"2f4f4f\",darkturquoise:\"00ced1\",darkviolet:\"9400d3\",deeppink:\"ff1493\",deepskyblue:\"00bfff\",dimgray:\"696969\",dimgrey:\"696969\",dodgerblue:\"1e90ff\",firebrick:\"b22222\",floralwhite:\"fffaf0\",forestgreen:\"228b22\",fuchsia:\"f0f\",gainsboro:\"dcdcdc\",ghostwhite:\"f8f8ff\",gold:\"ffd700\",goldenrod:\"daa520\",gray:\"808080\",green:\"008000\",greenyellow:\"adff2f\",grey:\"808080\",honeydew:\"f0fff0\",hotpink:\"ff69b4\",indianred:\"cd5c5c\",indigo:\"4b0082\",ivory:\"fffff0\",khaki:\"f0e68c\",lavender:\"e6e6fa\",lavenderblush:\"fff0f5\",lawngreen:\"7cfc00\",lemonchiffon:\"fffacd\",lightblue:\"add8e6\",lightcoral:\"f08080\",lightcyan:\"e0ffff\",lightgoldenrodyellow:\"fafad2\",lightgray:\"d3d3d3\",lightgreen:\"90ee90\",lightgrey:\"d3d3d3\",lightpink:\"ffb6c1\",lightsalmon:\"ffa07a\",lightseagreen:\"20b2aa\",lightskyblue:\"87cefa\",lightslategray:\"789\",lightslategrey:\"789\",lightsteelblue:\"b0c4de\",lightyellow:\"ffffe0\",lime:\"0f0\",limegreen:\"32cd32\",linen:\"faf0e6\",magenta:\"f0f\",maroon:\"800000\",mediumaquamarine:\"66cdaa\",mediumblue:\"0000cd\",mediumorchid:\"ba55d3\",mediumpurple:\"9370db\",mediumseagreen:\"3cb371\",mediumslateblue:\"7b68ee\",mediumspringgreen:\"00fa9a\",mediumturquoise:\"48d1cc\",mediumvioletred:\"c71585\",midnightblue:\"191970\",mintcream:\"f5fffa\",mistyrose:\"ffe4e1\",moccasin:\"ffe4b5\",navajowhite:\"ffdead\",navy:\"000080\",oldlace:\"fdf5e6\",olive:\"808000\",olivedrab:\"6b8e23\",orange:\"ffa500\",orangered:\"ff4500\",orchid:\"da70d6\",palegoldenrod:\"eee8aa\",palegreen:\"98fb98\",paleturquoise:\"afeeee\",palevioletred:\"db7093\",papayawhip:\"ffefd5\",peachpuff:\"ffdab9\",peru:\"cd853f\",pink:\"ffc0cb\",plum:\"dda0dd\",powderblue:\"b0e0e6\",purple:\"800080\",rebeccapurple:\"663399\",red:\"f00\",rosybrown:\"bc8f8f\",royalblue:\"4169e1\",saddlebrown:\"8b4513\",salmon:\"fa8072\",sandybrown:\"f4a460\",seagreen:\"2e8b57\",seashell:\"fff5ee\",sienna:\"a0522d\",silver:\"c0c0c0\",skyblue:\"87ceeb\",slateblue:\"6a5acd\",slategray:\"708090\",slategrey:\"708090\",snow:\"fffafa\",springgreen:\"00ff7f\",steelblue:\"4682b4\",tan:\"d2b48c\",teal:\"008080\",thistle:\"d8bfd8\",tomato:\"ff6347\",turquoise:\"40e0d0\",violet:\"ee82ee\",wheat:\"f5deb3\",white:\"fff\",whitesmoke:\"f5f5f5\",yellow:\"ff0\",yellowgreen:\"9acd32\"},E=c.hexNames=function(t){var e={};for(var r in t)t.hasOwnProperty(r)&&(e[t[r]]=r);return e}(S);function C(t){return t=parseFloat(t),(isNaN(t)||t<0||t>1)&&(t=1),t}function L(e,r){(function(t){return\"string\"==typeof t&&-1!=t.indexOf(\".\")&&1===parseFloat(t)})(e)&&(e=\"100%\");var n=function(t){return\"string\"==typeof t&&-1!=t.indexOf(\"%\")}(e);return e=o(r,s(0,parseFloat(e))),n&&(e=parseInt(e*r,10)/100),t.abs(e-r)<1e-6?1:e%r/parseFloat(r)}function P(t){return o(1,s(0,t))}function O(t){return parseInt(t,16)}function z(t){return 1==t.length?\"0\"+t:\"\"+t}function I(t){return t<=1&&(t=100*t+\"%\"),t}function D(e){return t.round(255*parseFloat(e)).toString(16)}function R(t){return O(t)/255}var F,B,N,j=(B=\"[\\\\s|\\\\(]+(\"+(F=\"(?:[-\\\\+]?\\\\d*\\\\.\\\\d+%?)|(?:[-\\\\+]?\\\\d+%?)\")+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",N=\"[\\\\s|\\\\(]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",{CSS_UNIT:new RegExp(F),rgb:new RegExp(\"rgb\"+B),rgba:new RegExp(\"rgba\"+N),hsl:new RegExp(\"hsl\"+B),hsla:new RegExp(\"hsla\"+N),hsv:new RegExp(\"hsv\"+B),hsva:new RegExp(\"hsva\"+N),hex3:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex6:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/,hex4:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex8:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/});function U(t){return!!j.CSS_UNIT.exec(t)}\"undefined\"!=typeof e&&e.exports?e.exports=c:window.tinycolor=c}(Math)},{}],538:[function(t,e,r){\"use strict\";e.exports=i,e.exports.float32=e.exports.float=i,e.exports.fract32=e.exports.fract=function(t){if(t.length){for(var e=i(t),r=0,n=e.length;r<n;r++)e[r]=t[r]-e[r];return e}return i(t-i(t))};var n=new Float32Array(1);function i(t){if(t.length){if(t instanceof Float32Array)return t;var e=new Float32Array(t);return e.set(t),e}return n[0]=t,n[0]}},{}],539:[function(t,e,r){\"use strict\";var n=t(\"parse-unit\");e.exports=o;var i=96;function a(t,e){var r=n(getComputedStyle(t).getPropertyValue(e));return r[0]*o(r[1],t)}function o(t,e){switch(e=e||document.body,t=(t||\"px\").trim().toLowerCase(),e!==window&&e!==document||(e=document.body),t){case\"%\":return e.clientHeight/100;case\"ch\":case\"ex\":return function(t,e){var r=document.createElement(\"div\");r.style[\"font-size\"]=\"128\"+t,e.appendChild(r);var n=a(r,\"font-size\")/128;return e.removeChild(r),n}(t,e);case\"em\":return a(e,\"font-size\");case\"rem\":return a(document.body,\"font-size\");case\"vw\":return window.innerWidth/100;case\"vh\":return window.innerHeight/100;case\"vmin\":return Math.min(window.innerWidth,window.innerHeight)/100;case\"vmax\":return Math.max(window.innerWidth,window.innerHeight)/100;case\"in\":return i;case\"cm\":return i/2.54;case\"mm\":return i/25.4;case\"pt\":return i/72;case\"pc\":return i/6}return 1}},{\"parse-unit\":461}],540:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e=function(t){return t},r=function(t){if(null==(r=t.transform))return e;var r,n,i,a=r.scale[0],o=r.scale[1],s=r.translate[0],l=r.translate[1];return function(t,e){return e||(n=i=0),t[0]=(n+=t[0])*a+s,t[1]=(i+=t[1])*o+l,t}},n=function(t){var e=t.bbox;function n(t){l[0]=t[0],l[1]=t[1],s(l),l[0]<c&&(c=l[0]),l[0]>h&&(h=l[0]),l[1]<u&&(u=l[1]),l[1]>f&&(f=l[1])}function i(t){switch(t.type){case\"GeometryCollection\":t.geometries.forEach(i);break;case\"Point\":n(t.coordinates);break;case\"MultiPoint\":t.coordinates.forEach(n)}}if(!e){var a,o,s=r(t),l=new Array(2),c=1/0,u=c,h=-c,f=-c;for(o in t.arcs.forEach(function(t){for(var e=-1,r=t.length;++e<r;)a=t[e],l[0]=a[0],l[1]=a[1],s(l,e),l[0]<c&&(c=l[0]),l[0]>h&&(h=l[0]),l[1]<u&&(u=l[1]),l[1]>f&&(f=l[1])}),t.objects)i(t.objects[o]);e=t.bbox=[c,u,h,f]}return e},i=function(t,e){for(var r,n=t.length,i=n-e;i<--n;)r=t[i],t[i++]=t[n],t[n]=r};function a(t,e){var r=e.id,n=e.bbox,i=null==e.properties?{}:e.properties,a=o(t,e);return null==r&&null==n?{type:\"Feature\",properties:i,geometry:a}:null==n?{type:\"Feature\",id:r,properties:i,geometry:a}:{type:\"Feature\",id:r,bbox:n,properties:i,geometry:a}}function o(t,e){var n=r(t),a=t.arcs;function o(t,e){e.length&&e.pop();for(var r=a[t<0?~t:t],o=0,s=r.length;o<s;++o)e.push(n(r[o].slice(),o));t<0&&i(e,s)}function s(t){return n(t.slice())}function l(t){for(var e=[],r=0,n=t.length;r<n;++r)o(t[r],e);return e.length<2&&e.push(e[0].slice()),e}function c(t){for(var e=l(t);e.length<4;)e.push(e[0].slice());return e}function u(t){return t.map(c)}return function t(e){var r,n=e.type;switch(n){case\"GeometryCollection\":return{type:n,geometries:e.geometries.map(t)};case\"Point\":r=s(e.coordinates);break;case\"MultiPoint\":r=e.coordinates.map(s);break;case\"LineString\":r=l(e.arcs);break;case\"MultiLineString\":r=e.arcs.map(l);break;case\"Polygon\":r=u(e.arcs);break;case\"MultiPolygon\":r=e.arcs.map(u);break;default:return null}return{type:n,coordinates:r}}(e)}var s=function(t,e){var r={},n={},i={},a=[],o=-1;function s(t,e){for(var n in t){var i=t[n];delete e[i.start],delete i.start,delete i.end,i.forEach(function(t){r[t<0?~t:t]=1}),a.push(i)}}return e.forEach(function(r,n){var i,a=t.arcs[r<0?~r:r];a.length<3&&!a[1][0]&&!a[1][1]&&(i=e[++o],e[o]=r,e[n]=i)}),e.forEach(function(e){var r,a,o=function(e){var r,n=t.arcs[e<0?~e:e],i=n[0];t.transform?(r=[0,0],n.forEach(function(t){r[0]+=t[0],r[1]+=t[1]})):r=n[n.length-1];return e<0?[r,i]:[i,r]}(e),s=o[0],l=o[1];if(r=i[s])if(delete i[r.end],r.push(e),r.end=l,a=n[l]){delete n[a.start];var c=a===r?r:r.concat(a);n[c.start=r.start]=i[c.end=a.end]=c}else n[r.start]=i[r.end]=r;else if(r=n[l])if(delete n[r.start],r.unshift(e),r.start=s,a=i[s]){delete i[a.end];var u=a===r?r:a.concat(r);n[u.start=a.start]=i[u.end=r.end]=u}else n[r.start]=i[r.end]=r;else n[(r=[e]).start=s]=i[r.end=l]=r}),s(i,n),s(n,i),e.forEach(function(t){r[t<0?~t:t]||a.push([t])}),a};function l(t,e,r){var n,i,a;if(arguments.length>1)n=function(t,e,r){var n,i=[],a=[];function o(t){var e=t<0?~t:t;(a[e]||(a[e]=[])).push({i:t,g:n})}function s(t){t.forEach(o)}function l(t){t.forEach(s)}return function t(e){switch(n=e,e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"LineString\":s(e.arcs);break;case\"MultiLineString\":case\"Polygon\":l(e.arcs);break;case\"MultiPolygon\":e.arcs.forEach(l)}}(e),a.forEach(null==r?function(t){i.push(t[0].i)}:function(t){r(t[0].g,t[t.length-1].g)&&i.push(t[0].i)}),i}(0,e,r);else for(i=0,n=new Array(a=t.arcs.length);i<a;++i)n[i]=i;return{type:\"MultiLineString\",arcs:s(t,n)}}function c(t,e){var r={},n=[],i=[];function a(t){t.forEach(function(e){e.forEach(function(e){(r[e=e<0?~e:e]||(r[e]=[])).push(t)})}),n.push(t)}function l(e){return function(t){for(var e,r=-1,n=t.length,i=t[n-1],a=0;++r<n;)e=i,i=t[r],a+=e[0]*i[1]-e[1]*i[0];return Math.abs(a)}(o(t,{type:\"Polygon\",arcs:[e]}).coordinates[0])}return e.forEach(function t(e){switch(e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"Polygon\":a(e.arcs);break;case\"MultiPolygon\":e.arcs.forEach(a)}}),n.forEach(function(t){if(!t._){var e=[],n=[t];for(t._=1,i.push(e);t=n.pop();)e.push(t),t.forEach(function(t){t.forEach(function(t){r[t<0?~t:t].forEach(function(t){t._||(t._=1,n.push(t))})})})}}),n.forEach(function(t){delete t._}),{type:\"MultiPolygon\",arcs:i.map(function(e){var n,i=[];if(e.forEach(function(t){t.forEach(function(t){t.forEach(function(t){r[t<0?~t:t].length<2&&i.push(t)})})}),(n=(i=s(t,i)).length)>1)for(var a,o,c=1,u=l(i[0]);c<n;++c)(a=l(i[c]))>u&&(o=i[0],i[0]=i[c],i[c]=o,u=a);return i})}}var u=function(t,e){for(var r=0,n=t.length;r<n;){var i=r+n>>>1;t[i]<e?r=i+1:n=i}return r};t.bbox=n,t.feature=function(t,e){return\"GeometryCollection\"===e.type?{type:\"FeatureCollection\",features:e.geometries.map(function(e){return a(t,e)})}:a(t,e)},t.mesh=function(t){return o(t,l.apply(this,arguments))},t.meshArcs=l,t.merge=function(t){return o(t,c.apply(this,arguments))},t.mergeArcs=c,t.neighbors=function(t){var e={},r=t.map(function(){return[]});function n(t,r){t.forEach(function(t){t<0&&(t=~t);var n=e[t];n?n.push(r):e[t]=[r]})}function i(t,e){t.forEach(function(t){n(t,e)})}var a={LineString:n,MultiLineString:i,Polygon:i,MultiPolygon:function(t,e){t.forEach(function(t){i(t,e)})}};for(var o in t.forEach(function t(e,r){\"GeometryCollection\"===e.type?e.geometries.forEach(function(e){t(e,r)}):e.type in a&&a[e.type](e.arcs,r)}),e)for(var s=e[o],l=s.length,c=0;c<l;++c)for(var h=c+1;h<l;++h){var f,p=s[c],d=s[h];(f=r[p])[o=u(f,d)]!==d&&f.splice(o,0,d),(f=r[d])[o=u(f,p)]!==p&&f.splice(o,0,p)}return r},t.quantize=function(t,e){if(!((e=Math.floor(e))>=2))throw new Error(\"n must be \\u22652\");if(t.transform)throw new Error(\"already quantized\");var r,i=n(t),a=i[0],o=(i[2]-a)/(e-1)||1,s=i[1],l=(i[3]-s)/(e-1)||1;function c(t){t[0]=Math.round((t[0]-a)/o),t[1]=Math.round((t[1]-s)/l)}function u(t){switch(t.type){case\"GeometryCollection\":t.geometries.forEach(u);break;case\"Point\":c(t.coordinates);break;case\"MultiPoint\":t.coordinates.forEach(c)}}for(r in t.arcs.forEach(function(t){for(var e,r,n,i=1,c=1,u=t.length,h=t[0],f=h[0]=Math.round((h[0]-a)/o),p=h[1]=Math.round((h[1]-s)/l);i<u;++i)h=t[i],r=Math.round((h[0]-a)/o),n=Math.round((h[1]-s)/l),r===f&&n===p||((e=t[c++])[0]=r-f,f=r,e[1]=n-p,p=n);c<2&&((e=t[c++])[0]=0,e[1]=0),t.length=c}),t.objects)u(t.objects[r]);return t.transform={scale:[o,l],translate:[a,s]},t},t.transform=r,t.untransform=function(t){if(null==(r=t.transform))return e;var r,n,i,a=r.scale[0],o=r.scale[1],s=r.translate[0],l=r.translate[1];return function(t,e){e||(n=i=0);var r=Math.round((t[0]-s)/a),c=Math.round((t[1]-l)/o);return t[0]=r-n,n=r,t[1]=c-i,i=c,t}},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.topojson=n.topojson||{})},{}],541:[function(t,e,r){\"use strict\";e.exports=function(t){if(t<0)return[];if(0===t)return[[0]];for(var e=0|Math.round(a(t+1)),r=[],o=0;o<e;++o){for(var s=n.unrank(t,o),l=[0],c=0,u=0;u<s.length;++u)c+=1<<s[u],l.push(c);i(s)<1&&(l[0]=c,l[t]=0),r.push(l)}return r};var n=t(\"permutation-rank\"),i=t(\"permutation-parity\"),a=t(\"gamma\")},{gamma:231,\"permutation-parity\":463,\"permutation-rank\":464}],542:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.up||[0,1,0],n=t.right||h(r),i=t.radius||1,a=t.theta||0,u=t.phi||0;if(e=[].slice.call(e,0,3),r=[].slice.call(r,0,3),s(r,r),n=[].slice.call(n,0,3),s(n,n),\"eye\"in t){var p=t.eye,d=[p[0]-e[0],p[1]-e[1],p[2]-e[2]];o(n,d,r),c(n[0],n[1],n[2])<1e-6?n=h(r):s(n,n),i=c(d[0],d[1],d[2]);var g=l(r,d)/i,v=l(n,d)/i;u=Math.acos(g),a=Math.acos(v)}return i=Math.log(i),new f(t.zoomMin,t.zoomMax,e,r,n,i,a,u)};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/invert\"),a=t(\"gl-mat4/rotate\"),o=t(\"gl-vec3/cross\"),s=t(\"gl-vec3/normalize\"),l=t(\"gl-vec3/dot\");function c(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function u(t){return Math.min(1,Math.max(-1,t))}function h(t){var e=Math.abs(t[0]),r=Math.abs(t[1]),n=Math.abs(t[2]),i=[0,0,0];e>Math.max(r,n)?i[2]=1:r>Math.max(e,n)?i[0]=1:i[1]=1;for(var a=0,o=0,l=0;l<3;++l)a+=t[l]*t[l],o+=i[l]*t[l];for(l=0;l<3;++l)i[l]-=o/a*t[l];return s(i,i),i}function f(t,e,r,i,a,o,s,l){this.center=n(r),this.up=n(i),this.right=n(a),this.radius=n([o]),this.angle=n([s,l]),this.angle.bounds=[[-1/0,-Math.PI/2],[1/0,Math.PI/2]],this.setDistanceLimits(t,e),this.computedCenter=this.center.curve(0),this.computedUp=this.up.curve(0),this.computedRight=this.right.curve(0),this.computedRadius=this.radius.curve(0),this.computedAngle=this.angle.curve(0),this.computedToward=[0,0,0],this.computedEye=[0,0,0],this.computedMatrix=new Array(16);for(var c=0;c<16;++c)this.computedMatrix[c]=.5;this.recalcMatrix(0)}var p=f.prototype;p.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},p.getDistanceLimits=function(t){var e=this.radius.bounds[0];return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},p.recalcMatrix=function(t){this.center.curve(t),this.up.curve(t),this.right.curve(t),this.radius.curve(t),this.angle.curve(t);for(var e=this.computedUp,r=this.computedRight,n=0,i=0,a=0;a<3;++a)i+=e[a]*r[a],n+=e[a]*e[a];var l=Math.sqrt(n),u=0;for(a=0;a<3;++a)r[a]-=e[a]*i/n,u+=r[a]*r[a],e[a]/=l;var h=Math.sqrt(u);for(a=0;a<3;++a)r[a]/=h;var f=this.computedToward;o(f,e,r),s(f,f);var p=Math.exp(this.computedRadius[0]),d=this.computedAngle[0],g=this.computedAngle[1],v=Math.cos(d),m=Math.sin(d),y=Math.cos(g),x=Math.sin(g),b=this.computedCenter,_=v*y,w=m*y,k=x,T=-v*x,A=-m*x,M=y,S=this.computedEye,E=this.computedMatrix;for(a=0;a<3;++a){var C=_*r[a]+w*f[a]+k*e[a];E[4*a+1]=T*r[a]+A*f[a]+M*e[a],E[4*a+2]=C,E[4*a+3]=0}var L=E[1],P=E[5],O=E[9],z=E[2],I=E[6],D=E[10],R=P*D-O*I,F=O*z-L*D,B=L*I-P*z,N=c(R,F,B);R/=N,F/=N,B/=N,E[0]=R,E[4]=F,E[8]=B;for(a=0;a<3;++a)S[a]=b[a]+E[2+4*a]*p;for(a=0;a<3;++a){u=0;for(var j=0;j<3;++j)u+=E[a+4*j]*S[j];E[12+a]=-u}E[15]=1},p.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r};var d=[0,0,0];p.rotate=function(t,e,r,n){if(this.angle.move(t,e,r),n){this.recalcMatrix(t);var i=this.computedMatrix;d[0]=i[2],d[1]=i[6],d[2]=i[10];for(var o=this.computedUp,s=this.computedRight,l=this.computedToward,c=0;c<3;++c)i[4*c]=o[c],i[4*c+1]=s[c],i[4*c+2]=l[c];a(i,i,n,d);for(c=0;c<3;++c)o[c]=i[4*c],s[c]=i[4*c+1];this.up.set(t,o[0],o[1],o[2]),this.right.set(t,s[0],s[1],s[2])}},p.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=(Math.exp(this.computedRadius[0]),i[1]),o=i[5],s=i[9],l=c(a,o,s);a/=l,o/=l,s/=l;var u=i[0],h=i[4],f=i[8],p=u*a+h*o+f*s,d=c(u-=a*p,h-=o*p,f-=s*p),g=(u/=d)*e+a*r,v=(h/=d)*e+o*r,m=(f/=d)*e+s*r;this.center.move(t,g,v,m);var y=Math.exp(this.computedRadius[0]);y=Math.max(1e-4,y+n),this.radius.set(t,Math.log(y))},p.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},p.setMatrix=function(t,e,r,n){var a=1;\"number\"==typeof r&&(a=0|r),(a<0||a>3)&&(a=1);var o=(a+2)%3;e||(this.recalcMatrix(t),e=this.computedMatrix);var s=e[a],l=e[a+4],h=e[a+8];if(n){var f=Math.abs(s),p=Math.abs(l),d=Math.abs(h),g=Math.max(f,p,d);f===g?(s=s<0?-1:1,l=h=0):d===g?(h=h<0?-1:1,s=l=0):(l=l<0?-1:1,s=h=0)}else{var v=c(s,l,h);s/=v,l/=v,h/=v}var m,y,x=e[o],b=e[o+4],_=e[o+8],w=x*s+b*l+_*h,k=c(x-=s*w,b-=l*w,_-=h*w),T=l*(_/=k)-h*(b/=k),A=h*(x/=k)-s*_,M=s*b-l*x,S=c(T,A,M);if(T/=S,A/=S,M/=S,this.center.jump(t,H,G,Y),this.radius.idle(t),this.up.jump(t,s,l,h),this.right.jump(t,x,b,_),2===a){var E=e[1],C=e[5],L=e[9],P=E*x+C*b+L*_,O=E*T+C*A+L*M;m=R<0?-Math.PI/2:Math.PI/2,y=Math.atan2(O,P)}else{var z=e[2],I=e[6],D=e[10],R=z*s+I*l+D*h,F=z*x+I*b+D*_,B=z*T+I*A+D*M;m=Math.asin(u(R)),y=Math.atan2(B,F)}this.angle.jump(t,y,m),this.recalcMatrix(t);var N=e[2],j=e[6],U=e[10],V=this.computedMatrix;i(V,e);var q=V[15],H=V[12]/q,G=V[13]/q,Y=V[14]/q,W=Math.exp(this.computedRadius[0]);this.center.jump(t,H-N*W,G-j*W,Y-U*W)},p.lastT=function(){return Math.max(this.center.lastT(),this.up.lastT(),this.right.lastT(),this.radius.lastT(),this.angle.lastT())},p.idle=function(t){this.center.idle(t),this.up.idle(t),this.right.idle(t),this.radius.idle(t),this.angle.idle(t)},p.flush=function(t){this.center.flush(t),this.up.flush(t),this.right.flush(t),this.radius.flush(t),this.angle.flush(t)},p.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},p.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||this.computedCenter;var i=(n=n||this.computedUp)[0],a=n[1],o=n[2],s=c(i,a,o);if(!(s<1e-6)){i/=s,a/=s,o/=s;var l=e[0]-r[0],h=e[1]-r[1],f=e[2]-r[2],p=c(l,h,f);if(!(p<1e-6)){l/=p,h/=p,f/=p;var d=this.computedRight,g=d[0],v=d[1],m=d[2],y=i*g+a*v+o*m,x=c(g-=y*i,v-=y*a,m-=y*o);if(!(x<.01&&(x=c(g=a*f-o*h,v=o*l-i*f,m=i*h-a*l))<1e-6)){g/=x,v/=x,m/=x,this.up.set(t,i,a,o),this.right.set(t,g,v,m),this.center.set(t,r[0],r[1],r[2]),this.radius.set(t,Math.log(p));var b=a*m-o*v,_=o*g-i*m,w=i*v-a*g,k=c(b,_,w),T=i*l+a*h+o*f,A=g*l+v*h+m*f,M=(b/=k)*l+(_/=k)*h+(w/=k)*f,S=Math.asin(u(T)),E=Math.atan2(M,A),C=this.angle._state,L=C[C.length-1],P=C[C.length-2];L%=2*Math.PI;var O=Math.abs(L+2*Math.PI-E),z=Math.abs(L-E),I=Math.abs(L-2*Math.PI-E);O<z&&(L+=2*Math.PI),I<z&&(L-=2*Math.PI),this.angle.jump(this.angle.lastT(),L,P),this.angle.set(t,E,S)}}}}},{\"filtered-vector\":226,\"gl-mat4/invert\":265,\"gl-mat4/rotate\":270,\"gl-vec3/cross\":334,\"gl-vec3/dot\":339,\"gl-vec3/normalize\":356}],543:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var i=t*e,a=n*t,o=a-(a-t),s=t-o,l=n*e,c=l-(l-e),u=e-c,h=s*u-(i-o*c-s*c-o*u);if(r)return r[0]=h,r[1]=i,r;return[h,i]};var n=+(Math.pow(2,27)+1)},{}],544:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=t+e,i=n-t,a=e-i,o=t-(n-i);if(r)return r[0]=o+a,r[1]=n,r;return[o+a,n]}},{}],545:[function(t,e,r){(function(e,n){\"use strict\";var i=t(\"bit-twiddle\"),a=t(\"dup\");e.__TYPEDARRAY_POOL||(e.__TYPEDARRAY_POOL={UINT8:a([32,0]),UINT16:a([32,0]),UINT32:a([32,0]),INT8:a([32,0]),INT16:a([32,0]),INT32:a([32,0]),FLOAT:a([32,0]),DOUBLE:a([32,0]),DATA:a([32,0]),UINT8C:a([32,0]),BUFFER:a([32,0])});var o=\"undefined\"!=typeof Uint8ClampedArray,s=e.__TYPEDARRAY_POOL;s.UINT8C||(s.UINT8C=a([32,0])),s.BUFFER||(s.BUFFER=a([32,0]));var l=s.DATA,c=s.BUFFER;function u(t){if(t){var e=t.length||t.byteLength,r=i.log2(e);l[r].push(t)}}function h(t){t=i.nextPow2(t);var e=i.log2(t),r=l[e];return r.length>0?r.pop():new ArrayBuffer(t)}function f(t){return new Uint8Array(h(t),0,t)}function p(t){return new Uint16Array(h(2*t),0,t)}function d(t){return new Uint32Array(h(4*t),0,t)}function g(t){return new Int8Array(h(t),0,t)}function v(t){return new Int16Array(h(2*t),0,t)}function m(t){return new Int32Array(h(4*t),0,t)}function y(t){return new Float32Array(h(4*t),0,t)}function x(t){return new Float64Array(h(8*t),0,t)}function b(t){return o?new Uint8ClampedArray(h(t),0,t):f(t)}function _(t){return new DataView(h(t),0,t)}function w(t){t=i.nextPow2(t);var e=i.log2(t),r=c[e];return r.length>0?r.pop():new n(t)}r.free=function(t){if(n.isBuffer(t))c[i.log2(t.length)].push(t);else{if(\"[object ArrayBuffer]\"!==Object.prototype.toString.call(t)&&(t=t.buffer),!t)return;var e=t.length||t.byteLength,r=0|i.log2(e);l[r].push(t)}},r.freeUint8=r.freeUint16=r.freeUint32=r.freeInt8=r.freeInt16=r.freeInt32=r.freeFloat32=r.freeFloat=r.freeFloat64=r.freeDouble=r.freeUint8Clamped=r.freeDataView=function(t){u(t.buffer)},r.freeArrayBuffer=u,r.freeBuffer=function(t){c[i.log2(t.length)].push(t)},r.malloc=function(t,e){if(void 0===e||\"arraybuffer\"===e)return h(t);switch(e){case\"uint8\":return f(t);case\"uint16\":return p(t);case\"uint32\":return d(t);case\"int8\":return g(t);case\"int16\":return v(t);case\"int32\":return m(t);case\"float\":case\"float32\":return y(t);case\"double\":case\"float64\":return x(t);case\"uint8_clamped\":return b(t);case\"buffer\":return w(t);case\"data\":case\"dataview\":return _(t);default:return null}return null},r.mallocArrayBuffer=h,r.mallocUint8=f,r.mallocUint16=p,r.mallocUint32=d,r.mallocInt8=g,r.mallocInt16=v,r.mallocInt32=m,r.mallocFloat32=r.mallocFloat=y,r.mallocFloat64=r.mallocDouble=x,r.mallocUint8Clamped=b,r.mallocDataView=_,r.mallocBuffer=w,r.clearCache=function(){for(var t=0;t<32;++t)s.UINT8[t].length=0,s.UINT16[t].length=0,s.UINT32[t].length=0,s.INT8[t].length=0,s.INT16[t].length=0,s.INT32[t].length=0,s.FLOAT[t].length=0,s.DOUBLE[t].length=0,s.UINT8C[t].length=0,l[t].length=0,c[t].length=0}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{},t(\"buffer\").Buffer)},{\"bit-twiddle\":92,buffer:105,dup:170}],546:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n;var i=n.prototype;Object.defineProperty(i,\"length\",{get:function(){return this.roots.length}}),i.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},i.find=function(t){for(var e=t,r=this.roots;r[t]!==t;)t=r[t];for(;r[e]!==t;){var n=r[e];r[e]=t,e=n}return t},i.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],547:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return 0===t.length?t:e?(r||t.sort(e),function(t,e){for(var r=1,n=t.length,i=t[0],a=t[0],o=1;o<n;++o)if(a=i,e(i=t[o],a)){if(o===r){r++;continue}t[r++]=i}return t.length=r,t}(t,e)):(r||t.sort(),function(t){for(var e=1,r=t.length,n=t[0],i=t[0],a=1;a<r;++a,i=n)if(i=n,(n=t[a])!==i){if(a===e){e++;continue}t[e++]=n}return t.length=e,t}(t))}},{}],548:[function(t,e,r){var n=/[\\'\\\"]/;e.exports=function(t){return t?(n.test(t.charAt(0))&&(t=t.substr(1)),n.test(t.charAt(t.length-1))&&(t=t.substr(0,t.length-1)),t):\"\"}},{}],549:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){Array.isArray(r)||(r=[].slice.call(arguments,2));for(var n=0,i=r.length;n<i;n++){var a=r[n];for(var o in a)if((void 0===e[o]||Array.isArray(e[o])||t[o]!==e[o])&&o in e){var s;if(!0===a[o])s=e[o];else{if(!1===a[o])continue;if(\"function\"==typeof a[o]&&void 0===(s=a[o](e[o],t,e)))continue}t[o]=s}}return t}},{}],550:[function(t,e,r){\"use strict\";e.exports=function(t,e){\"object\"==typeof e&&null!==e||(e={});return n(t,e.canvas||i,e.context||a,e)};var n=t(\"./lib/vtext\"),i=null,a=null;\"undefined\"!=typeof document&&((i=document.createElement(\"canvas\")).width=8192,i.height=1024,a=i.getContext(\"2d\"))},{\"./lib/vtext\":551}],551:[function(t,e,r){e.exports=function(t,e,r,n){var a=64,o=1.25,s={breaklines:!1,bolds:!1,italics:!1,subscripts:!1,superscripts:!1};n&&(n.size&&n.size>0&&(a=n.size),n.lineSpacing&&n.lineSpacing>0&&(o=n.lineSpacing),n.styletags&&n.styletags.breaklines&&(s.breaklines=!!n.styletags.breaklines),n.styletags&&n.styletags.bolds&&(s.bolds=!!n.styletags.bolds),n.styletags&&n.styletags.italics&&(s.italics=!!n.styletags.italics),n.styletags&&n.styletags.subscripts&&(s.subscripts=!!n.styletags.subscripts),n.styletags&&n.styletags.superscripts&&(s.superscripts=!!n.styletags.superscripts));return r.font=[n.fontStyle,n.fontVariant,n.fontWeight,a+\"px\",n.font].filter(function(t){return t}).join(\" \"),r.textAlign=\"start\",r.textBaseline=\"alphabetic\",r.direction=\"ltr\",w(function(t,e,r,n,a,o){r=r.replace(/\\n/g,\"\"),r=!0===o.breaklines?r.replace(/\\<br\\>/g,\"\\n\"):r.replace(/\\<br\\>/g,\" \");var s=\"\",l=[];for(k=0;k<r.length;++k)l[k]=s;!0===o.bolds&&(l=x(c,u,r,l)),!0===o.italics&&(l=x(h,f,r,l)),!0===o.superscripts&&(l=x(p,g,r,l)),!0===o.subscripts&&(l=x(v,y,r,l));var b=[],_=\"\";for(k=0;k<r.length;++k)null!==l[k]&&(_+=r[k],b.push(l[k]));var w,k,T,A,M,S=_.split(\"\\n\"),E=S.length,C=Math.round(a*n),L=n,P=2*n,O=0,z=E*C+P;t.height<z&&(t.height=z),e.fillStyle=\"#000\",e.fillRect(0,0,t.width,t.height),e.fillStyle=\"#fff\";var I=0,D=\"\";function R(){if(\"\"!==D){var t=e.measureText(D).width;e.fillText(D,L+T,P+A),T+=t}}function F(){return Math.round(M)+\"px \"}function B(t,r){var n=\"\"+e.font;if(!0===o.subscripts){var i=t.indexOf(m),a=r.indexOf(m),s=i>-1?parseInt(t[1+i]):0,l=a>-1?parseInt(r[1+a]):0;s!==l&&(n=n.replace(F(),\"?px \"),M*=Math.pow(.75,l-s),n=n.replace(\"?px \",F())),A+=.25*C*(l-s)}if(!0===o.superscripts){var c=t.indexOf(d),h=r.indexOf(d),p=c>-1?parseInt(t[1+c]):0,g=h>-1?parseInt(r[1+h]):0;p!==g&&(n=n.replace(F(),\"?px \"),M*=Math.pow(.75,g-p),n=n.replace(\"?px \",F())),A-=.25*C*(g-p)}if(!0===o.bolds){var v=t.indexOf(u)>-1,y=r.indexOf(u)>-1;!v&&y&&(n=x?n.replace(\"italic \",\"italic bold \"):\"bold \"+n),v&&!y&&(n=n.replace(\"bold \",\"\"))}if(!0===o.italics){var x=t.indexOf(f)>-1,b=r.indexOf(f)>-1;!x&&b&&(n=\"italic \"+n),x&&!b&&(n=n.replace(\"italic \",\"\"))}e.font=n}for(w=0;w<E;++w){var N=S[w]+\"\\n\";for(T=0,A=w*C,M=n,D=\"\",k=0;k<N.length;++k){var j=k+I<b.length?b[k+I]:b[b.length-1];s===j?D+=N[k]:(R(),D=N[k],void 0!==j&&(B(s,j),s=j))}R(),I+=N.length;var U=0|Math.round(T+2*L);O<U&&(O=U)}var V=O,q=P+C*E;return i(e.getImageData(0,0,V,q).data,[q,V,4]).pick(-1,-1,0).transpose(1,0)}(e,r,t,a,o,s),n,a)},e.exports.processPixels=w;var n=t(\"surface-nets\"),i=t(\"ndarray\"),a=t(\"simplify-planar-graph\"),o=t(\"clean-pslg\"),s=t(\"cdt2d\"),l=t(\"planar-graph-to-polyline\"),c=\"b\",u=\"b|\",h=\"i\",f=\"i|\",p=\"sup\",d=\"+\",g=\"+1\",v=\"sub\",m=\"-\",y=\"-1\";function x(t,e,r,n){for(var i=\"<\"+t+\">\",a=\"</\"+t+\">\",o=i.length,s=a.length,l=e[0]===d||e[0]===m,c=0,u=-s;c>-1&&-1!==(c=r.indexOf(i,c))&&-1!==(u=r.indexOf(a,c+o))&&!(u<=c);){for(var h=c;h<u+s;++h)if(h<c+o||h>=u)n[h]=null,r=r.substr(0,h)+\" \"+r.substr(h+1);else if(null!==n[h]){var f=n[h].indexOf(e[0]);-1===f?n[h]+=e:l&&(n[h]=n[h].substr(0,f+1)+(1+parseInt(n[h][f+1]))+n[h].substr(f+2))}var p=c+o,g=r.substr(p,u-p).indexOf(i);c=-1!==g?g:u+s}return n}function b(t,e){var r=n(t,128);return e?a(r.cells,r.positions,.25):{edges:r.cells,positions:r.positions}}function _(t,e,r,n){var i=b(t,n),a=function(t,e,r){for(var n=e.textAlign||\"start\",i=e.textBaseline||\"alphabetic\",a=[1<<30,1<<30],o=[0,0],s=t.length,l=0;l<s;++l)for(var c=t[l],u=0;u<2;++u)a[u]=0|Math.min(a[u],c[u]),o[u]=0|Math.max(o[u],c[u]);var h=0;switch(n){case\"center\":h=-.5*(a[0]+o[0]);break;case\"right\":case\"end\":h=-o[0];break;case\"left\":case\"start\":h=-a[0];break;default:throw new Error(\"vectorize-text: Unrecognized textAlign: '\"+n+\"'\")}var f=0;switch(i){case\"hanging\":case\"top\":f=-a[1];break;case\"middle\":f=-.5*(a[1]+o[1]);break;case\"alphabetic\":case\"ideographic\":f=-3*r;break;case\"bottom\":f=-o[1];break;default:throw new Error(\"vectorize-text: Unrecoginized textBaseline: '\"+i+\"'\")}var p=1/r;return\"lineHeight\"in e?p*=+e.lineHeight:\"width\"in e?p=e.width/(o[0]-a[0]):\"height\"in e&&(p=e.height/(o[1]-a[1])),t.map(function(t){return[p*(t[0]+h),p*(t[1]+f)]})}(i.positions,e,r),c=i.edges,u=\"ccw\"===e.orientation;if(o(a,c),e.polygons||e.polygon||e.polyline){for(var h=l(c,a),f=new Array(h.length),p=0;p<h.length;++p){for(var d=h[p],g=new Array(d.length),v=0;v<d.length;++v){for(var m=d[v],y=new Array(m.length),x=0;x<m.length;++x)y[x]=a[m[x]].slice();u&&y.reverse(),g[v]=y}f[p]=g}return f}return e.triangles||e.triangulate||e.triangle?{cells:s(a,c,{delaunay:!1,exterior:!1,interior:!0}),positions:a}:{edges:c,positions:a}}function w(t,e,r){try{return _(t,e,r,!0)}catch(t){}try{return _(t,e,r,!1)}catch(t){}return e.polygons||e.polyline||e.polygon?[]:e.triangles||e.triangulate||e.triangle?{cells:[],positions:[]}:{edges:[],positions:[]}}},{cdt2d:106,\"clean-pslg\":116,ndarray:450,\"planar-graph-to-polyline\":468,\"simplify-planar-graph\":524,\"surface-nets\":531}],552:[function(t,e,r){!function(){\"use strict\";if(\"undefined\"==typeof ses||!ses.ok||ses.ok()){\"undefined\"!=typeof ses&&(ses.weakMapPermitHostObjects=v);var t=!1;if(\"function\"==typeof WeakMap){var r=WeakMap;if(\"undefined\"!=typeof navigator&&/Firefox/.test(navigator.userAgent));else{var n=new r,i=Object.freeze({});if(n.set(i,1),1===n.get(i))return void(e.exports=WeakMap);t=!0}}Object.prototype.hasOwnProperty;var a=Object.getOwnPropertyNames,o=Object.defineProperty,s=Object.isExtensible,l=\"weakmap:\",c=l+\"ident:\"+Math.random()+\"___\";if(\"undefined\"!=typeof crypto&&\"function\"==typeof crypto.getRandomValues&&\"function\"==typeof ArrayBuffer&&\"function\"==typeof Uint8Array){var u=new ArrayBuffer(25),h=new Uint8Array(u);crypto.getRandomValues(h),c=l+\"rand:\"+Array.prototype.map.call(h,function(t){return(t%36).toString(36)}).join(\"\")+\"___\"}if(o(Object,\"getOwnPropertyNames\",{value:function(t){return a(t).filter(m)}}),\"getPropertyNames\"in Object){var f=Object.getPropertyNames;o(Object,\"getPropertyNames\",{value:function(t){return f(t).filter(m)}})}!function(){var t=Object.freeze;o(Object,\"freeze\",{value:function(e){return y(e),t(e)}});var e=Object.seal;o(Object,\"seal\",{value:function(t){return y(t),e(t)}});var r=Object.preventExtensions;o(Object,\"preventExtensions\",{value:function(t){return y(t),r(t)}})}();var p=!1,d=0,g=function(){this instanceof g||b();var t=[],e=[],r=d++;return Object.create(g.prototype,{get___:{value:x(function(n,i){var a,o=y(n);return o?r in o?o[r]:i:(a=t.indexOf(n))>=0?e[a]:i})},has___:{value:x(function(e){var n=y(e);return n?r in n:t.indexOf(e)>=0})},set___:{value:x(function(n,i){var a,o=y(n);return o?o[r]=i:(a=t.indexOf(n))>=0?e[a]=i:(a=t.length,e[a]=i,t[a]=n),this})},delete___:{value:x(function(n){var i,a,o=y(n);return o?r in o&&delete o[r]:!((i=t.indexOf(n))<0||(a=t.length-1,t[i]=void 0,e[i]=e[a],t[i]=t[a],t.length=a,e.length=a,0))})}})};g.prototype=Object.create(Object.prototype,{get:{value:function(t,e){return this.get___(t,e)},writable:!0,configurable:!0},has:{value:function(t){return this.has___(t)},writable:!0,configurable:!0},set:{value:function(t,e){return this.set___(t,e)},writable:!0,configurable:!0},delete:{value:function(t){return this.delete___(t)},writable:!0,configurable:!0}}),\"function\"==typeof r?function(){function n(){this instanceof g||b();var e,n=new r,i=void 0,a=!1;return e=t?function(t,e){return n.set(t,e),n.has(t)||(i||(i=new g),i.set(t,e)),this}:function(t,e){if(a)try{n.set(t,e)}catch(r){i||(i=new g),i.set___(t,e)}else n.set(t,e);return this},Object.create(g.prototype,{get___:{value:x(function(t,e){return i?n.has(t)?n.get(t):i.get___(t,e):n.get(t,e)})},has___:{value:x(function(t){return n.has(t)||!!i&&i.has___(t)})},set___:{value:x(e)},delete___:{value:x(function(t){var e=!!n.delete(t);return i&&i.delete___(t)||e})},permitHostObjects___:{value:x(function(t){if(t!==v)throw new Error(\"bogus call to permitHostObjects___\");a=!0})}})}t&&\"undefined\"!=typeof Proxy&&(Proxy=void 0),n.prototype=g.prototype,e.exports=n,Object.defineProperty(WeakMap.prototype,\"constructor\",{value:WeakMap,enumerable:!1,configurable:!0,writable:!0})}():(\"undefined\"!=typeof Proxy&&(Proxy=void 0),e.exports=g)}function v(t){t.permitHostObjects___&&t.permitHostObjects___(v)}function m(t){return!(t.substr(0,l.length)==l&&\"___\"===t.substr(t.length-3))}function y(t){if(t!==Object(t))throw new TypeError(\"Not an object: \"+t);var e=t[c];if(e&&e.key===t)return e;if(s(t)){e={key:t};try{return o(t,c,{value:e,writable:!1,enumerable:!1,configurable:!1}),e}catch(t){return}}}function x(t){return t.prototype=null,Object.freeze(t)}function b(){p||\"undefined\"==typeof console||(p=!0,console.warn(\"WeakMap should be invoked as new WeakMap(), not WeakMap(). This will be an error in the future.\"))}}()},{}],553:[function(t,e,r){var n=t(\"./hidden-store.js\");e.exports=function(){var t={};return function(e){if((\"object\"!=typeof e||null===e)&&\"function\"!=typeof e)throw new Error(\"Weakmap-shim: Key must be object\");var r=e.valueOf(t);return r&&r.identity===t?r:n(e,t)}}},{\"./hidden-store.js\":554}],554:[function(t,e,r){e.exports=function(t,e){var r={identity:e},n=t.valueOf;return Object.defineProperty(t,\"valueOf\",{value:function(t){return t!==e?n.apply(this,arguments):r},writable:!0}),r}},{}],555:[function(t,e,r){var n=t(\"./create-store.js\");e.exports=function(){var t=n();return{get:function(e,r){var n=t(e);return n.hasOwnProperty(\"value\")?n.value:r},set:function(e,r){return t(e).value=r,this},has:function(e){return\"value\"in t(e)},delete:function(e){return delete t(e).value}}}},{\"./create-store.js\":553}],556:[function(t,e,r){var n=t(\"get-canvas-context\");e.exports=function(t){return n(\"webgl\",t)}},{\"get-canvas-context\":232}],557:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Chinese\",jdEpoch:1721425.5,hasYearZero:!1,minMonth:0,firstMonth:0,minDay:1,regionalOptions:{\"\":{name:\"Chinese\",epochs:[\"BEC\",\"EC\"],monthNumbers:function(t,e){if(\"string\"==typeof t){var r=t.match(l);return r?r[0]:\"\"}var n=this._validateYear(t),i=t.month(),a=\"\"+this.toChineseMonth(n,i);return e&&a.length<2&&(a=\"0\"+a),this.isIntercalaryMonth(n,i)&&(a+=\"i\"),a},monthNames:function(t){if(\"string\"==typeof t){var e=t.match(c);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\\u6708\",\"\\u4e8c\\u6708\",\"\\u4e09\\u6708\",\"\\u56db\\u6708\",\"\\u4e94\\u6708\",\"\\u516d\\u6708\",\"\\u4e03\\u6708\",\"\\u516b\\u6708\",\"\\u4e5d\\u6708\",\"\\u5341\\u6708\",\"\\u5341\\u4e00\\u6708\",\"\\u5341\\u4e8c\\u6708\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},monthNamesShort:function(t){if(\"string\"==typeof t){var e=t.match(u);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},parseMonth:function(t,e){t=this._validateYear(t);var r,n=parseInt(e);if(isNaN(n))\"\\u95f0\"===e[0]&&(r=!0,e=e.substring(1)),\"\\u6708\"===e[e.length-1]&&(e=e.substring(0,e.length-1)),n=1+[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"].indexOf(e);else{var i=e[e.length-1];r=\"i\"===i||\"I\"===i}return this.toMonthIndex(t,n,r)},dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},_validateYear:function(t,e){if(t.year&&(t=t.year()),\"number\"!=typeof t||t<1888||t>2111)throw e.replace(/\\{0\\}/,this.local.name);return t},toMonthIndex:function(t,e,r){var i=this.intercalaryMonth(t);if(r&&e!==i||e<1||e>12)throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return i?!r&&e<=i?e-1:e:e-1},toChineseMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);if(e<0||e>(r?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r?e<r?e+1:e:e+1},intercalaryMonth:function(t){return t=this._validateYear(t),h[t-h[0]]>>13},isIntercalaryMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);return!!r&&r===e},leapYear:function(t){return 0!==this.intercalaryMonth(t)},weekOfYear:function(t,e,r){var i,o=this._validateYear(t,n.local.invalidyear),s=f[o-f[0]],l=s>>9&4095,c=s>>5&15,u=31&s;(i=a.newDate(l,c,u)).add(4-(i.dayOfWeek()||7),\"d\");var h=this.toJD(t,e,r)-i.toJD();return 1+Math.floor(h/7)},monthsInYear:function(t){return this.leapYear(t)?13:12},daysInMonth:function(t,e){t.year&&(e=t.month(),t=t.year()),t=this._validateYear(t);var r=h[t-h[0]];if(e>(r>>13?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r&1<<12-e?30:29},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,s,r,n.local.invalidDate);t=this._validateYear(i.year()),e=i.month(),r=i.day();var o=this.isIntercalaryMonth(t,e),s=this.toChineseMonth(t,e),l=function(t,e,r,n,i){var a,o,s;if(\"object\"==typeof t)o=t,a=e||{};else{var l=\"number\"==typeof t&&t>=1888&&t<=2111;if(!l)throw new Error(\"Lunar year outside range 1888-2111\");var c=\"number\"==typeof e&&e>=1&&e<=12;if(!c)throw new Error(\"Lunar month outside range 1 - 12\");var u,p=\"number\"==typeof r&&r>=1&&r<=30;if(!p)throw new Error(\"Lunar day outside range 1 - 30\");\"object\"==typeof n?(u=!1,a=n):(u=!!n,a=i||{}),o={year:t,month:e,day:r,isIntercalary:u}}s=o.day-1;var d,g=h[o.year-h[0]],v=g>>13;d=v?o.month>v?o.month:o.isIntercalary?o.month:o.month-1:o.month-1;for(var m=0;m<d;m++){var y=g&1<<12-m?30:29;s+=y}var x=f[o.year-f[0]],b=new Date(x>>9&4095,(x>>5&15)-1,(31&x)+s);return a.year=b.getFullYear(),a.month=1+b.getMonth(),a.day=b.getDate(),a}(t,s,r,o);return a.toJD(l.year,l.month,l.day)},fromJD:function(t){var e=a.fromJD(t),r=function(t,e,r,n){var i,a;if(\"object\"==typeof t)i=t,a=e||{};else{var o=\"number\"==typeof t&&t>=1888&&t<=2111;if(!o)throw new Error(\"Solar year outside range 1888-2111\");var s=\"number\"==typeof e&&e>=1&&e<=12;if(!s)throw new Error(\"Solar month outside range 1 - 12\");var l=\"number\"==typeof r&&r>=1&&r<=31;if(!l)throw new Error(\"Solar day outside range 1 - 31\");i={year:t,month:e,day:r},a=n||{}}var c=f[i.year-f[0]],u=i.year<<9|i.month<<5|i.day;a.year=u>=c?i.year:i.year-1,c=f[a.year-f[0]];var p,d=new Date(c>>9&4095,(c>>5&15)-1,31&c),g=new Date(i.year,i.month-1,i.day);p=Math.round((g-d)/864e5);var v,m=h[a.year-h[0]];for(v=0;v<13;v++){var y=m&1<<12-v?30:29;if(p<y)break;p-=y}var x=m>>13;!x||v<x?(a.isIntercalary=!1,a.month=1+v):v===x?(a.isIntercalary=!0,a.month=v):(a.isIntercalary=!1,a.month=v);return a.day=1+p,a}(e.year(),e.month(),e.day()),n=this.toMonthIndex(r.year,r.month,r.isIntercalary);return this.newDate(r.year,n,r.day)},fromString:function(t){var e=t.match(s),r=this._validateYear(+e[1]),n=+e[2],i=!!e[3],a=this.toMonthIndex(r,n,i),o=+e[4];return this.newDate(r,a,o)},add:function(t,e,r){var n=t.year(),i=t.month(),a=this.isIntercalaryMonth(n,i),s=this.toChineseMonth(n,i),l=Object.getPrototypeOf(o.prototype).add.call(this,t,e,r);if(\"y\"===r){var c=l.year(),u=l.month(),h=this.isIntercalaryMonth(c,s),f=a&&h?this.toMonthIndex(c,s,!0):this.toMonthIndex(c,s,!1);f!==u&&l.month(f)}return l}});var s=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)[-\\/](\\d?\\d)([iI]?)[-\\/](\\d?\\d)/m,l=/^\\d?\\d[iI]?/m,c=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?\\u6708/m,u=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?/m;n.calendars.chinese=o;var h=[1887,5780,5802,19157,2742,50359,1198,2646,46378,7466,3412,30122,5482,67949,2396,5294,43597,6732,6954,36181,2772,4954,18781,2396,54427,5274,6730,47781,5800,6868,21210,4790,59703,2350,5270,46667,3402,3496,38325,1388,4782,18735,2350,52374,6804,7498,44457,2906,1388,29294,4700,63789,6442,6804,56138,5802,2772,38235,1210,4698,22827,5418,63125,3476,5802,43701,2484,5302,27223,2646,70954,7466,3412,54698,5482,2412,38062,5294,2636,32038,6954,60245,2772,4826,43357,2394,5274,39501,6730,72357,5800,5844,53978,4790,2358,38039,5270,87627,3402,3496,54708,5484,4782,43311,2350,3222,27978,7498,68965,2904,5484,45677,4700,6444,39573,6804,6986,19285,2772,62811,1210,4698,47403,5418,5780,38570,5546,76469,2420,5302,51799,2646,5414,36501,3412,5546,18869,2412,54446,5276,6732,48422,6822,2900,28010,4826,92509,2394,5274,55883,6730,6820,47956,5812,2778,18779,2358,62615,5270,5450,46757,3492,5556,27318,4718,67887,2350,3222,52554,7498,3428,38252,5468,4700,31022,6444,64149,6804,6986,43861,2772,5338,35421,2650,70955,5418,5780,54954,5546,2740,38074,5302,2646,29991,3366,61011,3412,5546,43445,2412,5294,35406,6732,72998,6820,6996,52586,2778,2396,38045,5274,6698,23333,6820,64338,5812,2746,43355,2358,5270,39499,5450,79525,3492,5548],f=[1887,966732,967231,967733,968265,968766,969297,969798,970298,970829,971330,971830,972362,972863,973395,973896,974397,974928,975428,975929,976461,976962,977462,977994,978494,979026,979526,980026,980558,981059,981559,982091,982593,983124,983624,984124,984656,985157,985656,986189,986690,987191,987722,988222,988753,989254,989754,990286,990788,991288,991819,992319,992851,993352,993851,994383,994885,995385,995917,996418,996918,997450,997949,998481,998982,999483,1000014,1000515,1001016,1001548,1002047,1002578,1003080,1003580,1004111,1004613,1005113,1005645,1006146,1006645,1007177,1007678,1008209,1008710,1009211,1009743,1010243,1010743,1011275,1011775,1012306,1012807,1013308,1013840,1014341,1014841,1015373,1015874,1016404,1016905,1017405,1017937,1018438,1018939,1019471,1019972,1020471,1021002,1021503,1022035,1022535,1023036,1023568,1024069,1024568,1025100,1025601,1026102,1026633,1027133,1027666,1028167,1028666,1029198,1029699,1030199,1030730,1031231,1031763,1032264,1032764,1033296,1033797,1034297,1034828,1035329,1035830,1036362,1036861,1037393,1037894,1038394,1038925,1039427,1039927,1040459,1040959,1041491,1041992,1042492,1043023,1043524,1044024,1044556,1045057,1045558,1046090,1046590,1047121,1047622,1048122,1048654,1049154,1049655,1050187,1050689,1051219,1051720,1052220,1052751,1053252,1053752,1054284,1054786,1055285,1055817,1056317,1056849,1057349,1057850,1058382,1058883,1059383,1059915,1060415,1060947,1061447,1061947,1062479,1062981,1063480,1064012,1064514,1065014,1065545,1066045,1066577,1067078,1067578,1068110,1068611,1069112,1069642,1070142,1070674,1071175,1071675,1072207,1072709,1073209,1073740,1074241,1074741,1075273,1075773,1076305,1076807,1077308,1077839,1078340,1078840,1079372,1079871,1080403,1080904]},{\"../main\":571,\"object-assign\":454}],558:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Coptic\",jdEpoch:1825029.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Coptic\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Thout\",\"Paopi\",\"Hathor\",\"Koiak\",\"Tobi\",\"Meshir\",\"Paremhat\",\"Paremoude\",\"Pashons\",\"Paoni\",\"Epip\",\"Mesori\",\"Pi Kogi Enavot\"],monthNamesShort:[\"Tho\",\"Pao\",\"Hath\",\"Koi\",\"Tob\",\"Mesh\",\"Pat\",\"Pad\",\"Pash\",\"Pao\",\"Epi\",\"Meso\",\"PiK\"],dayNames:[\"Tkyriaka\",\"Pesnau\",\"Pshoment\",\"Peftoou\",\"Ptiou\",\"Psoou\",\"Psabbaton\"],dayNamesShort:[\"Tky\",\"Pes\",\"Psh\",\"Pef\",\"Pti\",\"Pso\",\"Psa\"],dayNamesMin:[\"Tk\",\"Pes\",\"Psh\",\"Pef\",\"Pt\",\"Pso\",\"Psa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.coptic=a},{\"../main\":571,\"object-assign\":454}],559:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Discworld\",jdEpoch:1721425.5,daysPerMonth:[16,32,32,32,32,32,32,32,32,32,32,32,32],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Discworld\",epochs:[\"BUC\",\"UC\"],monthNames:[\"Ick\",\"Offle\",\"February\",\"March\",\"April\",\"May\",\"June\",\"Grune\",\"August\",\"Spune\",\"Sektober\",\"Ember\",\"December\"],monthNamesShort:[\"Ick\",\"Off\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Gru\",\"Aug\",\"Spu\",\"Sek\",\"Emb\",\"Dec\"],dayNames:[\"Sunday\",\"Octeday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Oct\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Oc\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:2,isRTL:!1}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),13},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),400},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/8)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]},daysInWeek:function(){return 8},dayOfWeek:function(t,e,r){return(this._validate(t,e,r,n.local.invalidDate).day()+1)%8},weekDay:function(t,e,r){var n=this.dayOfWeek(t,e,r);return n>=2&&n<=6},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{century:o[Math.floor((i.year()-1)/100)+1]||\"\"}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year()+(i.year()<0?1:0),e=i.month(),(r=i.day())+(e>1?16:0)+(e>2?32*(e-2):0)+400*(t-1)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t+.5)-Math.floor(this.jdEpoch)-1;var e=Math.floor(t/400)+1;t-=400*(e-1),t+=t>15?16:0;var r=Math.floor(t/32)+1,n=t-32*(r-1)+1;return this.newDate(e<=0?e-1:e,r,n)}});var o={20:\"Fruitbat\",21:\"Anchovy\"};n.calendars.discworld=a},{\"../main\":571,\"object-assign\":454}],560:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Ethiopian\",jdEpoch:1724220.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Ethiopian\",epochs:[\"BEE\",\"EE\"],monthNames:[\"Meskerem\",\"Tikemet\",\"Hidar\",\"Tahesas\",\"Tir\",\"Yekatit\",\"Megabit\",\"Miazia\",\"Genbot\",\"Sene\",\"Hamle\",\"Nehase\",\"Pagume\"],monthNamesShort:[\"Mes\",\"Tik\",\"Hid\",\"Tah\",\"Tir\",\"Yek\",\"Meg\",\"Mia\",\"Gen\",\"Sen\",\"Ham\",\"Neh\",\"Pag\"],dayNames:[\"Ehud\",\"Segno\",\"Maksegno\",\"Irob\",\"Hamus\",\"Arb\",\"Kidame\"],dayNamesShort:[\"Ehu\",\"Seg\",\"Mak\",\"Iro\",\"Ham\",\"Arb\",\"Kid\"],dayNamesMin:[\"Eh\",\"Se\",\"Ma\",\"Ir\",\"Ha\",\"Ar\",\"Ki\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.ethiopian=a},{\"../main\":571,\"object-assign\":454}],561:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Hebrew\",jdEpoch:347995.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29,29],hasYearZero:!1,minMonth:1,firstMonth:7,minDay:1,regionalOptions:{\"\":{name:\"Hebrew\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Nisan\",\"Iyar\",\"Sivan\",\"Tammuz\",\"Av\",\"Elul\",\"Tishrei\",\"Cheshvan\",\"Kislev\",\"Tevet\",\"Shevat\",\"Adar\",\"Adar II\"],monthNamesShort:[\"Nis\",\"Iya\",\"Siv\",\"Tam\",\"Av\",\"Elu\",\"Tis\",\"Che\",\"Kis\",\"Tev\",\"She\",\"Ada\",\"Ad2\"],dayNames:[\"Yom Rishon\",\"Yom Sheni\",\"Yom Shlishi\",\"Yom Revi'i\",\"Yom Chamishi\",\"Yom Shishi\",\"Yom Shabbat\"],dayNamesShort:[\"Ris\",\"She\",\"Shl\",\"Rev\",\"Cha\",\"Shi\",\"Sha\"],dayNamesMin:[\"Ri\",\"She\",\"Shl\",\"Re\",\"Ch\",\"Shi\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return this._leapYear(e.year())},_leapYear:function(t){return o(7*(t=t<0?t+1:t)+1,19)<7},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),this._leapYear(t.year?t.year():t)?13:12},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),this.toJD(-1===t?1:t+1,7,1)-this.toJD(t,7,1)},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),12===e&&this.leapYear(t)?30:8===e&&5===o(this.daysInYear(t),10)?30:9===e&&3===o(this.daysInYear(t),10)?29:this.daysPerMonth[e-1]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{yearType:(this.leapYear(i)?\"embolismic\":\"common\")+\" \"+[\"deficient\",\"regular\",\"complete\"][this.daysInYear(i)%10-3]}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t<=0?t+1:t,o=this.jdEpoch+this._delay1(a)+this._delay2(a)+r+1;if(e<7){for(var s=7;s<=this.monthsInYear(t);s++)o+=this.daysInMonth(t,s);for(s=1;s<e;s++)o+=this.daysInMonth(t,s)}else for(s=7;s<e;s++)o+=this.daysInMonth(t,s);return o},_delay1:function(t){var e=Math.floor((235*t-234)/19),r=12084+13753*e,n=29*e+Math.floor(r/25920);return o(3*(n+1),7)<3&&n++,n},_delay2:function(t){var e=this._delay1(t-1),r=this._delay1(t);return this._delay1(t+1)-r==356?2:r-e==382?1:0},fromJD:function(t){t=Math.floor(t)+.5;for(var e=Math.floor(98496*(t-this.jdEpoch)/35975351)-1;t>=this.toJD(-1===e?1:e+1,7,1);)e++;for(var r=t<this.toJD(e,1,1)?7:1;t>this.toJD(e,r,this.daysInMonth(e,r));)r++;var n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.hebrew=a},{\"../main\":571,\"object-assign\":454}],562:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Islamic\",jdEpoch:1948439.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Islamic\",epochs:[\"BH\",\"AH\"],monthNames:[\"Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' al-thani\",\"Jumada al-awwal\",\"Jumada al-thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-ahad\",\"Yawm al-ithnayn\",\"Yawm ath-thulaathaa'\",\"Yawm al-arbi'aa'\",\"Yawm al-kham\\u012bs\",\"Yawm al-jum'a\",\"Yawm as-sabt\"],dayNamesShort:[\"Aha\",\"Ith\",\"Thu\",\"Arb\",\"Kha\",\"Jum\",\"Sab\"],dayNamesMin:[\"Ah\",\"It\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){return(11*this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year()+14)%30<11},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return this.leapYear(t)?355:354},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),t=t<=0?t+1:t,(r=i.day())+Math.ceil(29.5*(e-1))+354*(t-1)+Math.floor((3+11*t)/30)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t)+.5;var e=Math.floor((30*(t-this.jdEpoch)+10646)/10631);e=e<=0?e-1:e;var r=Math.min(12,Math.ceil((t-29-this.toJD(e,1,1))/29.5)+1),n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.islamic=a},{\"../main\":571,\"object-assign\":454}],563:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Julian\",jdEpoch:1721423.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Julian\",epochs:[\"BC\",\"AD\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()<0?e.year()+1:e.year())%4==0},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),r=i.day(),t<0&&t++,e<=2&&(t--,e+=12),Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r-1524.5},fromJD:function(t){var e=Math.floor(t+.5)+1524,r=Math.floor((e-122.1)/365.25),n=Math.floor(365.25*r),i=Math.floor((e-n)/30.6001),a=i-Math.floor(i<14?1:13),o=r-Math.floor(a>2?4716:4715),s=e-n-Math.floor(30.6001*i);return o<=0&&o--,this.newDate(o,a,s)}}),n.calendars.julian=a},{\"../main\":571,\"object-assign\":454}],564:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}function s(t,e){return o(t-1,e)+1}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Mayan\",jdEpoch:584282.5,hasYearZero:!0,minMonth:0,firstMonth:0,minDay:0,regionalOptions:{\"\":{name:\"Mayan\",epochs:[\"\",\"\"],monthNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],monthNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],dayNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesMin:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],digits:null,dateFormat:\"YYYY.m.d\",firstDay:0,isRTL:!1,haabMonths:[\"Pop\",\"Uo\",\"Zip\",\"Zotz\",\"Tzec\",\"Xul\",\"Yaxkin\",\"Mol\",\"Chen\",\"Yax\",\"Zac\",\"Ceh\",\"Mac\",\"Kankin\",\"Muan\",\"Pax\",\"Kayab\",\"Cumku\",\"Uayeb\"],tzolkinMonths:[\"Imix\",\"Ik\",\"Akbal\",\"Kan\",\"Chicchan\",\"Cimi\",\"Manik\",\"Lamat\",\"Muluc\",\"Oc\",\"Chuen\",\"Eb\",\"Ben\",\"Ix\",\"Men\",\"Cib\",\"Caban\",\"Etznab\",\"Cauac\",\"Ahau\"]}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},formatYear:function(t){t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year();var e=Math.floor(t/400);return t%=400,t+=t<0?400:0,e+\".\"+Math.floor(t/20)+\".\"+t%20},forYear:function(t){if((t=t.split(\".\")).length<3)throw\"Invalid Mayan year\";for(var e=0,r=0;r<t.length;r++){var n=parseInt(t[r],10);if(Math.abs(n)>19||r>0&&n<0)throw\"Invalid Mayan year\";e=20*e+n}return e},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),18},weekOfYear:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),0},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),360},daysInMonth:function(t,e){return this._validate(t,e,this.minDay,n.local.invalidMonth),20},daysInWeek:function(){return 5},dayOfWeek:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate).day()},weekDay:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),!0},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate).toJD(),a=this._toHaab(i),o=this._toTzolkin(i);return{haabMonthName:this.local.haabMonths[a[0]-1],haabMonth:a[0],haabDay:a[1],tzolkinDayName:this.local.tzolkinMonths[o[0]-1],tzolkinDay:o[0],tzolkinTrecena:o[1]}},_toHaab:function(t){var e=o((t-=this.jdEpoch)+8+340,365);return[Math.floor(e/20)+1,o(e,20)]},_toTzolkin:function(t){return[s((t-=this.jdEpoch)+20,20),s(t+4,13)]},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return i.day()+20*i.month()+360*i.year()+this.jdEpoch},fromJD:function(t){t=Math.floor(t)+.5-this.jdEpoch;var e=Math.floor(t/360);t%=360,t+=t<0?360:0;var r=Math.floor(t/20),n=t%20;return this.newDate(e,r,n)}}),n.calendars.mayan=a},{\"../main\":571,\"object-assign\":454}],565:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar;var o=n.instance(\"gregorian\");i(a.prototype,{name:\"Nanakshahi\",jdEpoch:2257673.5,daysPerMonth:[31,31,31,31,31,30,30,30,30,30,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Nanakshahi\",epochs:[\"BN\",\"AN\"],monthNames:[\"Chet\",\"Vaisakh\",\"Jeth\",\"Harh\",\"Sawan\",\"Bhadon\",\"Assu\",\"Katak\",\"Maghar\",\"Poh\",\"Magh\",\"Phagun\"],monthNamesShort:[\"Che\",\"Vai\",\"Jet\",\"Har\",\"Saw\",\"Bha\",\"Ass\",\"Kat\",\"Mgr\",\"Poh\",\"Mgh\",\"Pha\"],dayNames:[\"Somvaar\",\"Mangalvar\",\"Budhvaar\",\"Veervaar\",\"Shukarvaar\",\"Sanicharvaar\",\"Etvaar\"],dayNamesShort:[\"Som\",\"Mangal\",\"Budh\",\"Veer\",\"Shukar\",\"Sanichar\",\"Et\"],dayNamesMin:[\"So\",\"Ma\",\"Bu\",\"Ve\",\"Sh\",\"Sa\",\"Et\"],digits:null,dateFormat:\"dd-mm-yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear);return o.leapYear(e.year()+(e.year()<1?1:0)+1469)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(1-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidMonth);(t=i.year())<0&&t++;for(var a=i.day(),s=1;s<i.month();s++)a+=this.daysPerMonth[s-1];return a+o.toJD(t+1468,3,13)},fromJD:function(t){t=Math.floor(t+.5);for(var e=Math.floor((t-(this.jdEpoch-1))/366);t>=this.toJD(e+1,1,1);)e++;for(var r=t-Math.floor(this.toJD(e,1,1)+.5)+1,n=1;r>this.daysInMonth(e,n);)r-=this.daysInMonth(e,n),n++;return this.newDate(e,n,r)}}),n.calendars.nanakshahi=a},{\"../main\":571,\"object-assign\":454}],566:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Nepali\",jdEpoch:1700709.5,daysPerMonth:[31,31,32,32,31,30,30,29,30,29,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,daysPerYear:365,regionalOptions:{\"\":{name:\"Nepali\",epochs:[\"BBS\",\"ABS\"],monthNames:[\"Baisakh\",\"Jestha\",\"Ashadh\",\"Shrawan\",\"Bhadra\",\"Ashwin\",\"Kartik\",\"Mangsir\",\"Paush\",\"Mangh\",\"Falgun\",\"Chaitra\"],monthNamesShort:[\"Bai\",\"Je\",\"As\",\"Shra\",\"Bha\",\"Ash\",\"Kar\",\"Mang\",\"Pau\",\"Ma\",\"Fal\",\"Chai\"],dayNames:[\"Aaitabaar\",\"Sombaar\",\"Manglbaar\",\"Budhabaar\",\"Bihibaar\",\"Shukrabaar\",\"Shanibaar\"],dayNamesShort:[\"Aaita\",\"Som\",\"Mangl\",\"Budha\",\"Bihi\",\"Shukra\",\"Shani\"],dayNamesMin:[\"Aai\",\"So\",\"Man\",\"Bu\",\"Bi\",\"Shu\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:1,isRTL:!1}},leapYear:function(t){return this.daysInYear(t)!==this.daysPerYear},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){if(t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t])return this.daysPerYear;for(var e=0,r=this.minMonth;r<=12;r++)e+=this.NEPALI_CALENDAR_DATA[t][r];return e},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t]?this.daysPerMonth[e-1]:this.NEPALI_CALENDAR_DATA[t][e]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=n.instance(),o=0,s=e,l=t;this._createMissingCalendarData(t);var c=t-(s>9||9===s&&r>=this.NEPALI_CALENDAR_DATA[l][0]?56:57);for(9!==e&&(o=r,s--);9!==s;)s<=0&&(s=12,l--),o+=this.NEPALI_CALENDAR_DATA[l][s],s--;return 9===e?(o+=r-this.NEPALI_CALENDAR_DATA[l][0])<0&&(o+=a.daysInYear(c)):o+=this.NEPALI_CALENDAR_DATA[l][9]-this.NEPALI_CALENDAR_DATA[l][0],a.newDate(c,1,1).add(o,\"d\").toJD()},fromJD:function(t){var e=n.instance().fromJD(t),r=e.year(),i=e.dayOfYear(),a=r+56;this._createMissingCalendarData(a);for(var o=9,s=this.NEPALI_CALENDAR_DATA[a][0],l=this.NEPALI_CALENDAR_DATA[a][o]-s+1;i>l;)++o>12&&(o=1,a++),l+=this.NEPALI_CALENDAR_DATA[a][o];var c=this.NEPALI_CALENDAR_DATA[a][o]-(l-i);return this.newDate(a,o,c)},_createMissingCalendarData:function(t){var e=this.daysPerMonth.slice(0);e.unshift(17);for(var r=t-1;r<t+2;r++)\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[r]&&(this.NEPALI_CALENDAR_DATA[r]=e)},NEPALI_CALENDAR_DATA:{1970:[18,31,31,32,31,31,31,30,29,30,29,30,30],1971:[18,31,31,32,31,32,30,30,29,30,29,30,30],1972:[17,31,32,31,32,31,30,30,30,29,29,30,30],1973:[19,30,32,31,32,31,30,30,30,29,30,29,31],1974:[19,31,31,32,30,31,31,30,29,30,29,30,30],1975:[18,31,31,32,32,30,31,30,29,30,29,30,30],1976:[17,31,32,31,32,31,30,30,30,29,29,30,31],1977:[18,31,32,31,32,31,31,29,30,29,30,29,31],1978:[18,31,31,32,31,31,31,30,29,30,29,30,30],1979:[18,31,31,32,32,31,30,30,29,30,29,30,30],1980:[17,31,32,31,32,31,30,30,30,29,29,30,31],1981:[18,31,31,31,32,31,31,29,30,30,29,30,30],1982:[18,31,31,32,31,31,31,30,29,30,29,30,30],1983:[18,31,31,32,32,31,30,30,29,30,29,30,30],1984:[17,31,32,31,32,31,30,30,30,29,29,30,31],1985:[18,31,31,31,32,31,31,29,30,30,29,30,30],1986:[18,31,31,32,31,31,31,30,29,30,29,30,30],1987:[18,31,32,31,32,31,30,30,29,30,29,30,30],1988:[17,31,32,31,32,31,30,30,30,29,29,30,31],1989:[18,31,31,31,32,31,31,30,29,30,29,30,30],1990:[18,31,31,32,31,31,31,30,29,30,29,30,30],1991:[18,31,32,31,32,31,30,30,29,30,29,30,30],1992:[17,31,32,31,32,31,30,30,30,29,30,29,31],1993:[18,31,31,31,32,31,31,30,29,30,29,30,30],1994:[18,31,31,32,31,31,31,30,29,30,29,30,30],1995:[17,31,32,31,32,31,30,30,30,29,29,30,30],1996:[17,31,32,31,32,31,30,30,30,29,30,29,31],1997:[18,31,31,32,31,31,31,30,29,30,29,30,30],1998:[18,31,31,32,31,31,31,30,29,30,29,30,30],1999:[17,31,32,31,32,31,30,30,30,29,29,30,31],2000:[17,30,32,31,32,31,30,30,30,29,30,29,31],2001:[18,31,31,32,31,31,31,30,29,30,29,30,30],2002:[18,31,31,32,32,31,30,30,29,30,29,30,30],2003:[17,31,32,31,32,31,30,30,30,29,29,30,31],2004:[17,30,32,31,32,31,30,30,30,29,30,29,31],2005:[18,31,31,32,31,31,31,30,29,30,29,30,30],2006:[18,31,31,32,32,31,30,30,29,30,29,30,30],2007:[17,31,32,31,32,31,30,30,30,29,29,30,31],2008:[17,31,31,31,32,31,31,29,30,30,29,29,31],2009:[18,31,31,32,31,31,31,30,29,30,29,30,30],2010:[18,31,31,32,32,31,30,30,29,30,29,30,30],2011:[17,31,32,31,32,31,30,30,30,29,29,30,31],2012:[17,31,31,31,32,31,31,29,30,30,29,30,30],2013:[18,31,31,32,31,31,31,30,29,30,29,30,30],2014:[18,31,31,32,32,31,30,30,29,30,29,30,30],2015:[17,31,32,31,32,31,30,30,30,29,29,30,31],2016:[17,31,31,31,32,31,31,29,30,30,29,30,30],2017:[18,31,31,32,31,31,31,30,29,30,29,30,30],2018:[18,31,32,31,32,31,30,30,29,30,29,30,30],2019:[17,31,32,31,32,31,30,30,30,29,30,29,31],2020:[17,31,31,31,32,31,31,30,29,30,29,30,30],2021:[18,31,31,32,31,31,31,30,29,30,29,30,30],2022:[17,31,32,31,32,31,30,30,30,29,29,30,30],2023:[17,31,32,31,32,31,30,30,30,29,30,29,31],2024:[17,31,31,31,32,31,31,30,29,30,29,30,30],2025:[18,31,31,32,31,31,31,30,29,30,29,30,30],2026:[17,31,32,31,32,31,30,30,30,29,29,30,31],2027:[17,30,32,31,32,31,30,30,30,29,30,29,31],2028:[17,31,31,32,31,31,31,30,29,30,29,30,30],2029:[18,31,31,32,31,32,30,30,29,30,29,30,30],2030:[17,31,32,31,32,31,30,30,30,30,30,30,31],2031:[17,31,32,31,32,31,31,31,31,31,31,31,31],2032:[17,32,32,32,32,32,32,32,32,32,32,32,32],2033:[18,31,31,32,32,31,30,30,29,30,29,30,30],2034:[17,31,32,31,32,31,30,30,30,29,29,30,31],2035:[17,30,32,31,32,31,31,29,30,30,29,29,31],2036:[17,31,31,32,31,31,31,30,29,30,29,30,30],2037:[18,31,31,32,32,31,30,30,29,30,29,30,30],2038:[17,31,32,31,32,31,30,30,30,29,29,30,31],2039:[17,31,31,31,32,31,31,29,30,30,29,30,30],2040:[17,31,31,32,31,31,31,30,29,30,29,30,30],2041:[18,31,31,32,32,31,30,30,29,30,29,30,30],2042:[17,31,32,31,32,31,30,30,30,29,29,30,31],2043:[17,31,31,31,32,31,31,29,30,30,29,30,30],2044:[17,31,31,32,31,31,31,30,29,30,29,30,30],2045:[18,31,32,31,32,31,30,30,29,30,29,30,30],2046:[17,31,32,31,32,31,30,30,30,29,29,30,31],2047:[17,31,31,31,32,31,31,30,29,30,29,30,30],2048:[17,31,31,32,31,31,31,30,29,30,29,30,30],2049:[17,31,32,31,32,31,30,30,30,29,29,30,30],2050:[17,31,32,31,32,31,30,30,30,29,30,29,31],2051:[17,31,31,31,32,31,31,30,29,30,29,30,30],2052:[17,31,31,32,31,31,31,30,29,30,29,30,30],2053:[17,31,32,31,32,31,30,30,30,29,29,30,30],2054:[17,31,32,31,32,31,30,30,30,29,30,29,31],2055:[17,31,31,32,31,31,31,30,29,30,30,29,30],2056:[17,31,31,32,31,32,30,30,29,30,29,30,30],2057:[17,31,32,31,32,31,30,30,30,29,29,30,31],2058:[17,30,32,31,32,31,30,30,30,29,30,29,31],2059:[17,31,31,32,31,31,31,30,29,30,29,30,30],2060:[17,31,31,32,32,31,30,30,29,30,29,30,30],2061:[17,31,32,31,32,31,30,30,30,29,29,30,31],2062:[17,30,32,31,32,31,31,29,30,29,30,29,31],2063:[17,31,31,32,31,31,31,30,29,30,29,30,30],2064:[17,31,31,32,32,31,30,30,29,30,29,30,30],2065:[17,31,32,31,32,31,30,30,30,29,29,30,31],2066:[17,31,31,31,32,31,31,29,30,30,29,29,31],2067:[17,31,31,32,31,31,31,30,29,30,29,30,30],2068:[17,31,31,32,32,31,30,30,29,30,29,30,30],2069:[17,31,32,31,32,31,30,30,30,29,29,30,31],2070:[17,31,31,31,32,31,31,29,30,30,29,30,30],2071:[17,31,31,32,31,31,31,30,29,30,29,30,30],2072:[17,31,32,31,32,31,30,30,29,30,29,30,30],2073:[17,31,32,31,32,31,30,30,30,29,29,30,31],2074:[17,31,31,31,32,31,31,30,29,30,29,30,30],2075:[17,31,31,32,31,31,31,30,29,30,29,30,30],2076:[16,31,32,31,32,31,30,30,30,29,29,30,30],2077:[17,31,32,31,32,31,30,30,30,29,30,29,31],2078:[17,31,31,31,32,31,31,30,29,30,29,30,30],2079:[17,31,31,32,31,31,31,30,29,30,29,30,30],2080:[16,31,32,31,32,31,30,30,30,29,29,30,30],2081:[17,31,31,32,32,31,30,30,30,29,30,30,30],2082:[17,31,32,31,32,31,30,30,30,29,30,30,30],2083:[17,31,31,32,31,31,30,30,30,29,30,30,30],2084:[17,31,31,32,31,31,30,30,30,29,30,30,30],2085:[17,31,32,31,32,31,31,30,30,29,30,30,30],2086:[17,31,32,31,32,31,30,30,30,29,30,30,30],2087:[16,31,31,32,31,31,31,30,30,29,30,30,30],2088:[16,30,31,32,32,30,31,30,30,29,30,30,30],2089:[17,31,32,31,32,31,30,30,30,29,30,30,30],2090:[17,31,32,31,32,31,30,30,30,29,30,30,30],2091:[16,31,31,32,31,31,31,30,30,29,30,30,30],2092:[16,31,31,32,32,31,30,30,30,29,30,30,30],2093:[17,31,32,31,32,31,30,30,30,29,30,30,30],2094:[17,31,31,32,31,31,30,30,30,29,30,30,30],2095:[17,31,31,32,31,31,31,30,29,30,30,30,30],2096:[17,30,31,32,32,31,30,30,29,30,29,30,30],2097:[17,31,32,31,32,31,30,30,30,29,30,30,30],2098:[17,31,31,32,31,31,31,29,30,29,30,30,31],2099:[17,31,31,32,31,31,31,30,29,29,30,30,30],2100:[17,31,32,31,32,30,31,30,29,30,29,30,30]}}),n.calendars.nepali=a},{\"../main\":571,\"object-assign\":454}],567:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Persian\",jdEpoch:1948320.5,daysPerMonth:[31,31,31,31,31,31,30,30,30,30,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Persian\",epochs:[\"BP\",\"AP\"],monthNames:[\"Farvardin\",\"Ordibehesht\",\"Khordad\",\"Tir\",\"Mordad\",\"Shahrivar\",\"Mehr\",\"Aban\",\"Azar\",\"Day\",\"Bahman\",\"Esfand\"],monthNamesShort:[\"Far\",\"Ord\",\"Kho\",\"Tir\",\"Mor\",\"Sha\",\"Meh\",\"Aba\",\"Aza\",\"Day\",\"Bah\",\"Esf\"],dayNames:[\"Yekshambe\",\"Doshambe\",\"Seshambe\",\"Ch\\xe6harshambe\",\"Panjshambe\",\"Jom'e\",\"Shambe\"],dayNamesShort:[\"Yek\",\"Do\",\"Se\",\"Ch\\xe6\",\"Panj\",\"Jom\",\"Sha\"],dayNamesMin:[\"Ye\",\"Do\",\"Se\",\"Ch\",\"Pa\",\"Jo\",\"Sh\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 682*((e.year()-(e.year()>0?474:473))%2820+474+38)%2816<682},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-(n.dayOfWeek()+1)%7,\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t-(t>=0?474:473),s=474+o(a,2820);return r+(e<=7?31*(e-1):30*(e-1)+6)+Math.floor((682*s-110)/2816)+365*(s-1)+1029983*Math.floor(a/2820)+this.jdEpoch-1},fromJD:function(t){var e=(t=Math.floor(t)+.5)-this.toJD(475,1,1),r=Math.floor(e/1029983),n=o(e,1029983),i=2820;if(1029982!==n){var a=Math.floor(n/366),s=o(n,366);i=Math.floor((2134*a+2816*s+2815)/1028522)+a+1}var l=i+2820*r+474;l=l<=0?l-1:l;var c=t-this.toJD(l,1,1)+1,u=c<=186?Math.ceil(c/31):Math.ceil((c-6)/30),h=t-this.toJD(l,u,1)+1;return this.newDate(l,u,h)}}),n.calendars.persian=a,n.calendars.jalali=a},{\"../main\":571,\"object-assign\":454}],568:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Taiwan\",jdEpoch:2419402.5,yearsOffset:1911,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Taiwan\",epochs:[\"BROC\",\"ROC\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)},_g2tYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)}}),n.calendars.taiwan=o},{\"../main\":571,\"object-assign\":454}],569:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Thai\",jdEpoch:1523098.5,yearsOffset:543,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Thai\",epochs:[\"BBE\",\"BE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)},_g2tYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)}}),n.calendars.thai=o},{\"../main\":571,\"object-assign\":454}],570:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"UmmAlQura\",hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Umm al-Qura\",epochs:[\"BH\",\"AH\"],monthNames:[\"Al-Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' Al-Thani\",\"Jumada Al-Awwal\",\"Jumada Al-Thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-Ahad\",\"Yawm al-Ithnain\",\"Yawm al-Thal\\u0101th\\u0101\\u2019\",\"Yawm al-Arba\\u2018\\u0101\\u2019\",\"Yawm al-Kham\\u012bs\",\"Yawm al-Jum\\u2018a\",\"Yawm al-Sabt\"],dayNamesMin:[\"Ah\",\"Ith\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!0}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 355===this.daysInYear(e.year())},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){for(var e=0,r=1;r<=12;r++)e+=this.daysInMonth(t,r);return e},daysInMonth:function(t,e){for(var r=this._validate(t,e,this.minDay,n.local.invalidMonth).toJD()-24e5+.5,i=0,a=0;a<o.length;a++){if(o[a]>r)return o[i]-o[i-1];i++}return 30},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate),a=12*(i.year()-1)+i.month()-15292;return i.day()+o[a-1]-1+24e5-.5},fromJD:function(t){for(var e=t-24e5+.5,r=0,n=0;n<o.length&&!(o[n]>e);n++)r++;var i=r+15292,a=Math.floor((i-1)/12),s=a+1,l=i-12*a,c=e-o[r-1]+1;return this.newDate(s,l,c)},isValid:function(t,e,r){var i=n.baseCalendar.prototype.isValid.apply(this,arguments);return i&&(i=(t=null!=t.year?t.year:t)>=1276&&t<=1500),i},_validate:function(t,e,r,i){var a=n.baseCalendar.prototype._validate.apply(this,arguments);if(a.year<1276||a.year>1500)throw i.replace(/\\{0\\}/,this.local.name);return a}}),n.calendars.ummalqura=a;var o=[20,50,79,109,138,168,197,227,256,286,315,345,374,404,433,463,492,522,551,581,611,641,670,700,729,759,788,818,847,877,906,936,965,995,1024,1054,1083,1113,1142,1172,1201,1231,1260,1290,1320,1350,1379,1409,1438,1468,1497,1527,1556,1586,1615,1645,1674,1704,1733,1763,1792,1822,1851,1881,1910,1940,1969,1999,2028,2058,2087,2117,2146,2176,2205,2235,2264,2294,2323,2353,2383,2413,2442,2472,2501,2531,2560,2590,2619,2649,2678,2708,2737,2767,2796,2826,2855,2885,2914,2944,2973,3003,3032,3062,3091,3121,3150,3180,3209,3239,3268,3298,3327,3357,3386,3416,3446,3476,3505,3535,3564,3594,3623,3653,3682,3712,3741,3771,3800,3830,3859,3889,3918,3948,3977,4007,4036,4066,4095,4125,4155,4185,4214,4244,4273,4303,4332,4362,4391,4421,4450,4480,4509,4539,4568,4598,4627,4657,4686,4716,4745,4775,4804,4834,4863,4893,4922,4952,4981,5011,5040,5070,5099,5129,5158,5188,5218,5248,5277,5307,5336,5366,5395,5425,5454,5484,5513,5543,5572,5602,5631,5661,5690,5720,5749,5779,5808,5838,5867,5897,5926,5956,5985,6015,6044,6074,6103,6133,6162,6192,6221,6251,6281,6311,6340,6370,6399,6429,6458,6488,6517,6547,6576,6606,6635,6665,6694,6724,6753,6783,6812,6842,6871,6901,6930,6960,6989,7019,7048,7078,7107,7137,7166,7196,7225,7255,7284,7314,7344,7374,7403,7433,7462,7492,7521,7551,7580,7610,7639,7669,7698,7728,7757,7787,7816,7846,7875,7905,7934,7964,7993,8023,8053,8083,8112,8142,8171,8201,8230,8260,8289,8319,8348,8378,8407,8437,8466,8496,8525,8555,8584,8614,8643,8673,8702,8732,8761,8791,8821,8850,8880,8909,8938,8968,8997,9027,9056,9086,9115,9145,9175,9205,9234,9264,9293,9322,9352,9381,9410,9440,9470,9499,9529,9559,9589,9618,9648,9677,9706,9736,9765,9794,9824,9853,9883,9913,9943,9972,10002,10032,10061,10090,10120,10149,10178,10208,10237,10267,10297,10326,10356,10386,10415,10445,10474,10504,10533,10562,10592,10621,10651,10680,10710,10740,10770,10799,10829,10858,10888,10917,10947,10976,11005,11035,11064,11094,11124,11153,11183,11213,11242,11272,11301,11331,11360,11389,11419,11448,11478,11507,11537,11567,11596,11626,11655,11685,11715,11744,11774,11803,11832,11862,11891,11921,11950,11980,12010,12039,12069,12099,12128,12158,12187,12216,12246,12275,12304,12334,12364,12393,12423,12453,12483,12512,12542,12571,12600,12630,12659,12688,12718,12747,12777,12807,12837,12866,12896,12926,12955,12984,13014,13043,13072,13102,13131,13161,13191,13220,13250,13280,13310,13339,13368,13398,13427,13456,13486,13515,13545,13574,13604,13634,13664,13693,13723,13752,13782,13811,13840,13870,13899,13929,13958,13988,14018,14047,14077,14107,14136,14166,14195,14224,14254,14283,14313,14342,14372,14401,14431,14461,14490,14520,14550,14579,14609,14638,14667,14697,14726,14756,14785,14815,14844,14874,14904,14933,14963,14993,15021,15051,15081,15110,15140,15169,15199,15228,15258,15287,15317,15347,15377,15406,15436,15465,15494,15524,15553,15582,15612,15641,15671,15701,15731,15760,15790,15820,15849,15878,15908,15937,15966,15996,16025,16055,16085,16114,16144,16174,16204,16233,16262,16292,16321,16350,16380,16409,16439,16468,16498,16528,16558,16587,16617,16646,16676,16705,16734,16764,16793,16823,16852,16882,16912,16941,16971,17001,17030,17060,17089,17118,17148,17177,17207,17236,17266,17295,17325,17355,17384,17414,17444,17473,17502,17532,17561,17591,17620,17650,17679,17709,17738,17768,17798,17827,17857,17886,17916,17945,17975,18004,18034,18063,18093,18122,18152,18181,18211,18241,18270,18300,18330,18359,18388,18418,18447,18476,18506,18535,18565,18595,18625,18654,18684,18714,18743,18772,18802,18831,18860,18890,18919,18949,18979,19008,19038,19068,19098,19127,19156,19186,19215,19244,19274,19303,19333,19362,19392,19422,19452,19481,19511,19540,19570,19599,19628,19658,19687,19717,19746,19776,19806,19836,19865,19895,19924,19954,19983,20012,20042,20071,20101,20130,20160,20190,20219,20249,20279,20308,20338,20367,20396,20426,20455,20485,20514,20544,20573,20603,20633,20662,20692,20721,20751,20780,20810,20839,20869,20898,20928,20957,20987,21016,21046,21076,21105,21135,21164,21194,21223,21253,21282,21312,21341,21371,21400,21430,21459,21489,21519,21548,21578,21607,21637,21666,21696,21725,21754,21784,21813,21843,21873,21902,21932,21962,21991,22021,22050,22080,22109,22138,22168,22197,22227,22256,22286,22316,22346,22375,22405,22434,22464,22493,22522,22552,22581,22611,22640,22670,22700,22730,22759,22789,22818,22848,22877,22906,22936,22965,22994,23024,23054,23083,23113,23143,23173,23202,23232,23261,23290,23320,23349,23379,23408,23438,23467,23497,23527,23556,23586,23616,23645,23674,23704,23733,23763,23792,23822,23851,23881,23910,23940,23970,23999,24029,24058,24088,24117,24147,24176,24206,24235,24265,24294,24324,24353,24383,24413,24442,24472,24501,24531,24560,24590,24619,24648,24678,24707,24737,24767,24796,24826,24856,24885,24915,24944,24974,25003,25032,25062,25091,25121,25150,25180,25210,25240,25269,25299,25328,25358,25387,25416,25446,25475,25505,25534,25564,25594,25624,25653,25683,25712,25742,25771,25800,25830,25859,25888,25918,25948,25977,26007,26037,26067,26096,26126,26155,26184,26214,26243,26272,26302,26332,26361,26391,26421,26451,26480,26510,26539,26568,26598,26627,26656,26686,26715,26745,26775,26805,26834,26864,26893,26923,26952,26982,27011,27041,27070,27099,27129,27159,27188,27218,27248,27277,27307,27336,27366,27395,27425,27454,27484,27513,27542,27572,27602,27631,27661,27691,27720,27750,27779,27809,27838,27868,27897,27926,27956,27985,28015,28045,28074,28104,28134,28163,28193,28222,28252,28281,28310,28340,28369,28399,28428,28458,28488,28517,28547,28577,28607,28636,28665,28695,28724,28754,28783,28813,28843,28872,28901,28931,28960,28990,29019,29049,29078,29108,29137,29167,29196,29226,29255,29285,29315,29345,29375,29404,29434,29463,29492,29522,29551,29580,29610,29640,29669,29699,29729,29759,29788,29818,29847,29876,29906,29935,29964,29994,30023,30053,30082,30112,30141,30171,30200,30230,30259,30289,30318,30348,30378,30408,30437,30467,30496,30526,30555,30585,30614,30644,30673,30703,30732,30762,30791,30821,30850,30880,30909,30939,30968,30998,31027,31057,31086,31116,31145,31175,31204,31234,31263,31293,31322,31352,31381,31411,31441,31471,31500,31530,31559,31589,31618,31648,31676,31706,31736,31766,31795,31825,31854,31884,31913,31943,31972,32002,32031,32061,32090,32120,32150,32180,32209,32239,32268,32298,32327,32357,32386,32416,32445,32475,32504,32534,32563,32593,32622,32652,32681,32711,32740,32770,32799,32829,32858,32888,32917,32947,32976,33006,33035,33065,33094,33124,33153,33183,33213,33243,33272,33302,33331,33361,33390,33420,33450,33479,33509,33539,33568,33598,33627,33657,33686,33716,33745,33775,33804,33834,33863,33893,33922,33952,33981,34011,34040,34069,34099,34128,34158,34187,34217,34247,34277,34306,34336,34365,34395,34424,34454,34483,34512,34542,34571,34601,34631,34660,34690,34719,34749,34778,34808,34837,34867,34896,34926,34955,34985,35015,35044,35074,35103,35133,35162,35192,35222,35251,35280,35310,35340,35370,35399,35429,35458,35488,35517,35547,35576,35605,35635,35665,35694,35723,35753,35782,35811,35841,35871,35901,35930,35960,35989,36019,36048,36078,36107,36136,36166,36195,36225,36254,36284,36314,36343,36373,36403,36433,36462,36492,36521,36551,36580,36610,36639,36669,36698,36728,36757,36786,36816,36845,36875,36904,36934,36963,36993,37022,37052,37081,37111,37141,37170,37200,37229,37259,37288,37318,37347,37377,37406,37436,37465,37495,37524,37554,37584,37613,37643,37672,37701,37731,37760,37790,37819,37849,37878,37908,37938,37967,37997,38027,38056,38085,38115,38144,38174,38203,38233,38262,38292,38322,38351,38381,38410,38440,38469,38499,38528,38558,38587,38617,38646,38676,38705,38735,38764,38794,38823,38853,38882,38912,38941,38971,39001,39030,39059,39089,39118,39148,39178,39208,39237,39267,39297,39326,39355,39385,39414,39444,39473,39503,39532,39562,39592,39621,39650,39680,39709,39739,39768,39798,39827,39857,39886,39916,39946,39975,40005,40035,40064,40094,40123,40153,40182,40212,40241,40271,40300,40330,40359,40389,40418,40448,40477,40507,40536,40566,40595,40625,40655,40685,40714,40744,40773,40803,40832,40862,40892,40921,40951,40980,41009,41039,41068,41098,41127,41157,41186,41216,41245,41275,41304,41334,41364,41393,41422,41452,41481,41511,41540,41570,41599,41629,41658,41688,41718,41748,41777,41807,41836,41865,41894,41924,41953,41983,42012,42042,42072,42102,42131,42161,42190,42220,42249,42279,42308,42337,42367,42397,42426,42456,42485,42515,42545,42574,42604,42633,42662,42692,42721,42751,42780,42810,42839,42869,42899,42929,42958,42988,43017,43046,43076,43105,43135,43164,43194,43223,43253,43283,43312,43342,43371,43401,43430,43460,43489,43519,43548,43578,43607,43637,43666,43696,43726,43755,43785,43814,43844,43873,43903,43932,43962,43991,44021,44050,44080,44109,44139,44169,44198,44228,44258,44287,44317,44346,44375,44405,44434,44464,44493,44523,44553,44582,44612,44641,44671,44700,44730,44759,44788,44818,44847,44877,44906,44936,44966,44996,45025,45055,45084,45114,45143,45172,45202,45231,45261,45290,45320,45350,45380,45409,45439,45468,45498,45527,45556,45586,45615,45644,45674,45704,45733,45763,45793,45823,45852,45882,45911,45940,45970,45999,46028,46058,46088,46117,46147,46177,46206,46236,46265,46295,46324,46354,46383,46413,46442,46472,46501,46531,46560,46590,46620,46649,46679,46708,46738,46767,46797,46826,46856,46885,46915,46944,46974,47003,47033,47063,47092,47122,47151,47181,47210,47240,47269,47298,47328,47357,47387,47417,47446,47476,47506,47535,47565,47594,47624,47653,47682,47712,47741,47771,47800,47830,47860,47890,47919,47949,47978,48008,48037,48066,48096,48125,48155,48184,48214,48244,48273,48303,48333,48362,48392,48421,48450,48480,48509,48538,48568,48598,48627,48657,48687,48717,48746,48776,48805,48834,48864,48893,48922,48952,48982,49011,49041,49071,49100,49130,49160,49189,49218,49248,49277,49306,49336,49365,49395,49425,49455,49484,49514,49543,49573,49602,49632,49661,49690,49720,49749,49779,49809,49838,49868,49898,49927,49957,49986,50016,50045,50075,50104,50133,50163,50192,50222,50252,50281,50311,50340,50370,50400,50429,50459,50488,50518,50547,50576,50606,50635,50665,50694,50724,50754,50784,50813,50843,50872,50902,50931,50960,50990,51019,51049,51078,51108,51138,51167,51197,51227,51256,51286,51315,51345,51374,51403,51433,51462,51492,51522,51552,51582,51611,51641,51670,51699,51729,51758,51787,51816,51846,51876,51906,51936,51965,51995,52025,52054,52083,52113,52142,52171,52200,52230,52260,52290,52319,52349,52379,52408,52438,52467,52497,52526,52555,52585,52614,52644,52673,52703,52733,52762,52792,52822,52851,52881,52910,52939,52969,52998,53028,53057,53087,53116,53146,53176,53205,53235,53264,53294,53324,53353,53383,53412,53441,53471,53500,53530,53559,53589,53619,53648,53678,53708,53737,53767,53796,53825,53855,53884,53913,53943,53973,54003,54032,54062,54092,54121,54151,54180,54209,54239,54268,54297,54327,54357,54387,54416,54446,54476,54505,54535,54564,54593,54623,54652,54681,54711,54741,54770,54800,54830,54859,54889,54919,54948,54977,55007,55036,55066,55095,55125,55154,55184,55213,55243,55273,55302,55332,55361,55391,55420,55450,55479,55508,55538,55567,55597,55627,55657,55686,55716,55745,55775,55804,55834,55863,55892,55922,55951,55981,56011,56040,56070,56100,56129,56159,56188,56218,56247,56276,56306,56335,56365,56394,56424,56454,56483,56513,56543,56572,56601,56631,56660,56690,56719,56749,56778,56808,56837,56867,56897,56926,56956,56985,57015,57044,57074,57103,57133,57162,57192,57221,57251,57280,57310,57340,57369,57399,57429,57458,57487,57517,57546,57576,57605,57634,57664,57694,57723,57753,57783,57813,57842,57871,57901,57930,57959,57989,58018,58048,58077,58107,58137,58167,58196,58226,58255,58285,58314,58343,58373,58402,58432,58461,58491,58521,58551,58580,58610,58639,58669,58698,58727,58757,58786,58816,58845,58875,58905,58934,58964,58994,59023,59053,59082,59111,59141,59170,59200,59229,59259,59288,59318,59348,59377,59407,59436,59466,59495,59525,59554,59584,59613,59643,59672,59702,59731,59761,59791,59820,59850,59879,59909,59939,59968,59997,60027,60056,60086,60115,60145,60174,60204,60234,60264,60293,60323,60352,60381,60411,60440,60469,60499,60528,60558,60588,60618,60648,60677,60707,60736,60765,60795,60824,60853,60883,60912,60942,60972,61002,61031,61061,61090,61120,61149,61179,61208,61237,61267,61296,61326,61356,61385,61415,61445,61474,61504,61533,61563,61592,61621,61651,61680,61710,61739,61769,61799,61828,61858,61888,61917,61947,61976,62006,62035,62064,62094,62123,62153,62182,62212,62242,62271,62301,62331,62360,62390,62419,62448,62478,62507,62537,62566,62596,62625,62655,62685,62715,62744,62774,62803,62832,62862,62891,62921,62950,62980,63009,63039,63069,63099,63128,63157,63187,63216,63246,63275,63305,63334,63363,63393,63423,63453,63482,63512,63541,63571,63600,63630,63659,63689,63718,63747,63777,63807,63836,63866,63895,63925,63955,63984,64014,64043,64073,64102,64131,64161,64190,64220,64249,64279,64309,64339,64368,64398,64427,64457,64486,64515,64545,64574,64603,64633,64663,64692,64722,64752,64782,64811,64841,64870,64899,64929,64958,64987,65017,65047,65076,65106,65136,65166,65195,65225,65254,65283,65313,65342,65371,65401,65431,65460,65490,65520,65549,65579,65608,65638,65667,65697,65726,65755,65785,65815,65844,65874,65903,65933,65963,65992,66022,66051,66081,66110,66140,66169,66199,66228,66258,66287,66317,66346,66376,66405,66435,66465,66494,66524,66553,66583,66612,66641,66671,66700,66730,66760,66789,66819,66849,66878,66908,66937,66967,66996,67025,67055,67084,67114,67143,67173,67203,67233,67262,67292,67321,67351,67380,67409,67439,67468,67497,67527,67557,67587,67617,67646,67676,67705,67735,67764,67793,67823,67852,67882,67911,67941,67971,68e3,68030,68060,68089,68119,68148,68177,68207,68236,68266,68295,68325,68354,68384,68414,68443,68473,68502,68532,68561,68591,68620,68650,68679,68708,68738,68768,68797,68827,68857,68886,68916,68946,68975,69004,69034,69063,69092,69122,69152,69181,69211,69240,69270,69300,69330,69359,69388,69418,69447,69476,69506,69535,69565,69595,69624,69654,69684,69713,69743,69772,69802,69831,69861,69890,69919,69949,69978,70008,70038,70067,70097,70126,70156,70186,70215,70245,70274,70303,70333,70362,70392,70421,70451,70481,70510,70540,70570,70599,70629,70658,70687,70717,70746,70776,70805,70835,70864,70894,70924,70954,70983,71013,71042,71071,71101,71130,71159,71189,71218,71248,71278,71308,71337,71367,71397,71426,71455,71485,71514,71543,71573,71602,71632,71662,71691,71721,71751,71781,71810,71839,71869,71898,71927,71957,71986,72016,72046,72075,72105,72135,72164,72194,72223,72253,72282,72311,72341,72370,72400,72429,72459,72489,72518,72548,72577,72607,72637,72666,72695,72725,72754,72784,72813,72843,72872,72902,72931,72961,72991,73020,73050,73080,73109,73139,73168,73197,73227,73256,73286,73315,73345,73375,73404,73434,73464,73493,73523,73552,73581,73611,73640,73669,73699,73729,73758,73788,73818,73848,73877,73907,73936,73965,73995,74024,74053,74083,74113,74142,74172,74202,74231,74261,74291,74320,74349,74379,74408,74437,74467,74497,74526,74556,74586,74615,74645,74675,74704,74733,74763,74792,74822,74851,74881,74910,74940,74969,74999,75029,75058,75088,75117,75147,75176,75206,75235,75264,75294,75323,75353,75383,75412,75442,75472,75501,75531,75560,75590,75619,75648,75678,75707,75737,75766,75796,75826,75856,75885,75915,75944,75974,76003,76032,76062,76091,76121,76150,76180,76210,76239,76269,76299,76328,76358,76387,76416,76446,76475,76505,76534,76564,76593,76623,76653,76682,76712,76741,76771,76801,76830,76859,76889,76918,76948,76977,77007,77036,77066,77096,77125,77155,77185,77214,77243,77273,77302,77332,77361,77390,77420,77450,77479,77509,77539,77569,77598,77627,77657,77686,77715,77745,77774,77804,77833,77863,77893,77923,77952,77982,78011,78041,78070,78099,78129,78158,78188,78217,78247,78277,78307,78336,78366,78395,78425,78454,78483,78513,78542,78572,78601,78631,78661,78690,78720,78750,78779,78808,78838,78867,78897,78926,78956,78985,79015,79044,79074,79104,79133,79163,79192,79222,79251,79281,79310,79340,79369,79399,79428,79458,79487,79517,79546,79576,79606,79635,79665,79695,79724,79753,79783,79812,79841,79871,79900,79930,79960,79990]},{\"../main\":571,\"object-assign\":454}],571:[function(t,e,r){var n=t(\"object-assign\");function i(){this.regionalOptions=[],this.regionalOptions[\"\"]={invalidCalendar:\"Calendar {0} not found\",invalidDate:\"Invalid {0} date\",invalidMonth:\"Invalid {0} month\",invalidYear:\"Invalid {0} year\",differentCalendars:\"Cannot mix {0} and {1} dates\"},this.local=this.regionalOptions[\"\"],this.calendars={},this._localCals={}}function a(t,e,r,n){if(this._calendar=t,this._year=e,this._month=r,this._day=n,0===this._calendar._validateLevel&&!this._calendar.isValid(this._year,this._month,this._day))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name)}function o(t,e){return\"000000\".substring(0,e-(t=\"\"+t).length)+t}function s(){this.shortYearCutoff=\"+10\"}function l(t){this.local=this.regionalOptions[t]||this.regionalOptions[\"\"]}n(i.prototype,{instance:function(t,e){t=(t||\"gregorian\").toLowerCase(),e=e||\"\";var r=this._localCals[t+\"-\"+e];if(!r&&this.calendars[t]&&(r=new this.calendars[t](e),this._localCals[t+\"-\"+e]=r),!r)throw(this.local.invalidCalendar||this.regionalOptions[\"\"].invalidCalendar).replace(/\\{0\\}/,t);return r},newDate:function(t,e,r,n,i){return(n=(null!=t&&t.year?t.calendar():\"string\"==typeof n?this.instance(n,i):n)||this.instance()).newDate(t,e,r)},substituteDigits:function(t){return function(e){return(e+\"\").replace(/[0-9]/g,function(e){return t[e]})}},substituteChineseDigits:function(t,e){return function(r){for(var n=\"\",i=0;r>0;){var a=r%10;n=(0===a?\"\":t[a]+e[i])+n,i++,r=Math.floor(r/10)}return 0===n.indexOf(t[1]+e[1])&&(n=n.substr(1)),n||t[0]}}}),n(a.prototype,{newDate:function(t,e,r){return this._calendar.newDate(null==t?this:t,e,r)},year:function(t){return 0===arguments.length?this._year:this.set(t,\"y\")},month:function(t){return 0===arguments.length?this._month:this.set(t,\"m\")},day:function(t){return 0===arguments.length?this._day:this.set(t,\"d\")},date:function(t,e,r){if(!this._calendar.isValid(t,e,r))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name);return this._year=t,this._month=e,this._day=r,this},leapYear:function(){return this._calendar.leapYear(this)},epoch:function(){return this._calendar.epoch(this)},formatYear:function(){return this._calendar.formatYear(this)},monthOfYear:function(){return this._calendar.monthOfYear(this)},weekOfYear:function(){return this._calendar.weekOfYear(this)},daysInYear:function(){return this._calendar.daysInYear(this)},dayOfYear:function(){return this._calendar.dayOfYear(this)},daysInMonth:function(){return this._calendar.daysInMonth(this)},dayOfWeek:function(){return this._calendar.dayOfWeek(this)},weekDay:function(){return this._calendar.weekDay(this)},extraInfo:function(){return this._calendar.extraInfo(this)},add:function(t,e){return this._calendar.add(this,t,e)},set:function(t,e){return this._calendar.set(this,t,e)},compareTo:function(t){if(this._calendar.name!==t._calendar.name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this._calendar.local.name).replace(/\\{1\\}/,t._calendar.local.name);var e=this._year!==t._year?this._year-t._year:this._month!==t._month?this.monthOfYear()-t.monthOfYear():this._day-t._day;return 0===e?0:e<0?-1:1},calendar:function(){return this._calendar},toJD:function(){return this._calendar.toJD(this)},fromJD:function(t){return this._calendar.fromJD(t)},toJSDate:function(){return this._calendar.toJSDate(this)},fromJSDate:function(t){return this._calendar.fromJSDate(t)},toString:function(){return(this.year()<0?\"-\":\"\")+o(Math.abs(this.year()),4)+\"-\"+o(this.month(),2)+\"-\"+o(this.day(),2)}}),n(s.prototype,{_validateLevel:0,newDate:function(t,e,r){return null==t?this.today():(t.year&&(this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),r=t.day(),e=t.month(),t=t.year()),new a(this,t,e,r))},today:function(){return this.fromJSDate(new Date)},epoch:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear).year()<0?this.local.epochs[0]:this.local.epochs[1]},formatYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(e.year()<0?\"-\":\"\")+o(Math.abs(e.year()),4)},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear),12},monthOfYear:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return(r.month()+this.monthsInYear(r)-this.firstMonth)%this.monthsInYear(r)+this.minMonth},fromMonthOfYear:function(t,e){var r=(e+this.firstMonth-2*this.minMonth)%this.monthsInYear(t)+this.minMonth;return this._validate(t,r,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth),r},daysInYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return this.leapYear(e)?366:365},dayOfYear:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return n.toJD()-this.newDate(n.year(),this.fromMonthOfYear(n.year(),this.minMonth),this.minDay).toJD()+1},daysInWeek:function(){return 7},dayOfWeek:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return(Math.floor(this.toJD(n))+2)%this.daysInWeek()},extraInfo:function(t,e,r){return this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),{}},add:function(t,e,r){return this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),this._correctAdd(t,this._add(t,e,r),e,r)},_add:function(t,e,r){if(this._validateLevel++,\"d\"===r||\"w\"===r){var n=t.toJD()+e*(\"w\"===r?this.daysInWeek():1),i=t.calendar().fromJD(n);return this._validateLevel--,[i.year(),i.month(),i.day()]}try{var a=t.year()+(\"y\"===r?e:0),o=t.monthOfYear()+(\"m\"===r?e:0);i=t.day();\"y\"===r?(t.month()!==this.fromMonthOfYear(a,o)&&(o=this.newDate(a,t.month(),this.minDay).monthOfYear()),o=Math.min(o,this.monthsInYear(a)),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o)))):\"m\"===r&&(!function(t){for(;o<t.minMonth;)a--,o+=t.monthsInYear(a);for(var e=t.monthsInYear(a);o>e-1+t.minMonth;)a++,o-=e,e=t.monthsInYear(a)}(this),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o))));var s=[a,this.fromMonthOfYear(a,o),i];return this._validateLevel--,s}catch(t){throw this._validateLevel--,t}},_correctAdd:function(t,e,r,n){if(!(this.hasYearZero||\"y\"!==n&&\"m\"!==n||0!==e[0]&&t.year()>0==e[0]>0)){var i={y:[1,1,\"y\"],m:[1,this.monthsInYear(-1),\"m\"],w:[this.daysInWeek(),this.daysInYear(-1),\"d\"],d:[1,this.daysInYear(-1),\"d\"]}[n],a=r<0?-1:1;e=this._add(t,r*i[0]+a*i[1],i[2])}return t.date(e[0],e[1],e[2])},set:function(t,e,r){this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);var n=\"y\"===r?e:t.year(),i=\"m\"===r?e:t.month(),a=\"d\"===r?e:t.day();return\"y\"!==r&&\"m\"!==r||(a=Math.min(a,this.daysInMonth(n,i))),t.date(n,i,a)},isValid:function(t,e,r){this._validateLevel++;var n=this.hasYearZero||0!==t;if(n){var i=this.newDate(t,e,this.minDay);n=e>=this.minMonth&&e-this.minMonth<this.monthsInYear(i)&&r>=this.minDay&&r-this.minDay<this.daysInMonth(i)}return this._validateLevel--,n},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return c.instance().fromJD(this.toJD(n)).toJSDate()},fromJSDate:function(t){return this.fromJD(c.instance().fromJSDate(t).toJD())},_validate:function(t,e,r,n){if(t.year){if(0===this._validateLevel&&this.name!==t.calendar().name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this.local.name).replace(/\\{1\\}/,t.calendar().local.name);return t}try{if(this._validateLevel++,1===this._validateLevel&&!this.isValid(t,e,r))throw n.replace(/\\{0\\}/,this.local.name);var i=this.newDate(t,e,r);return this._validateLevel--,i}catch(t){throw this._validateLevel--,t}}}),l.prototype=new s,n(l.prototype,{name:\"Gregorian\",jdEpoch:1721425.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Gregorian\",epochs:[\"BCE\",\"CE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==0&&(t%100!=0||t%400==0)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);t=n.year(),e=n.month(),r=n.day(),t<0&&t++,e<3&&(e+=12,t--);var i=Math.floor(t/100),a=2-i+Math.floor(i/4);return Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r+a-1524.5},fromJD:function(t){var e=Math.floor(t+.5),r=Math.floor((e-1867216.25)/36524.25),n=(r=e+1+r-Math.floor(r/4))+1524,i=Math.floor((n-122.1)/365.25),a=Math.floor(365.25*i),o=Math.floor((n-a)/30.6001),s=n-a-Math.floor(30.6001*o),l=o-(o>13.5?13:1),c=i-(l>2.5?4716:4715);return c<=0&&c--,this.newDate(c,l,s)},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),i=new Date(n.year(),n.month()-1,n.day());return i.setHours(0),i.setMinutes(0),i.setSeconds(0),i.setMilliseconds(0),i.setHours(i.getHours()>12?i.getHours()+2:0),i},fromJSDate:function(t){return this.newDate(t.getFullYear(),t.getMonth()+1,t.getDate())}});var c=e.exports=new i;c.cdate=a,c.baseCalendar=s,c.calendars.gregorian=l},{\"object-assign\":454}],572:[function(t,e,r){var n=t(\"object-assign\"),i=t(\"./main\");n(i.regionalOptions[\"\"],{invalidArguments:\"Invalid arguments\",invalidFormat:\"Cannot format a date from another calendar\",missingNumberAt:\"Missing number at position {0}\",unknownNameAt:\"Unknown name at position {0}\",unexpectedLiteralAt:\"Unexpected literal at position {0}\",unexpectedText:\"Additional text found at end\"}),i.local=i.regionalOptions[\"\"],n(i.cdate.prototype,{formatDate:function(t,e){return\"string\"!=typeof t&&(e=t,t=\"\"),this._calendar.formatDate(t||\"\",this,e)}}),n(i.baseCalendar.prototype,{UNIX_EPOCH:i.instance().newDate(1970,1,1).toJD(),SECS_PER_DAY:86400,TICKS_EPOCH:i.instance().jdEpoch,TICKS_PER_DAY:864e9,ATOM:\"yyyy-mm-dd\",COOKIE:\"D, dd M yyyy\",FULL:\"DD, MM d, yyyy\",ISO_8601:\"yyyy-mm-dd\",JULIAN:\"J\",RFC_822:\"D, d M yy\",RFC_850:\"DD, dd-M-yy\",RFC_1036:\"D, d M yy\",RFC_1123:\"D, d M yyyy\",RFC_2822:\"D, d M yyyy\",RSS:\"D, d M yy\",TICKS:\"!\",TIMESTAMP:\"@\",W3C:\"yyyy-mm-dd\",formatDate:function(t,e,r){if(\"string\"!=typeof t&&(r=e,e=t,t=\"\"),!e)return\"\";if(e.calendar()!==this)throw i.local.invalidFormat||i.regionalOptions[\"\"].invalidFormat;t=t||this.local.dateFormat;for(var n,a,o,s,l=(r=r||{}).dayNamesShort||this.local.dayNamesShort,c=r.dayNames||this.local.dayNames,u=r.monthNumbers||this.local.monthNumbers,h=r.monthNamesShort||this.local.monthNamesShort,f=r.monthNames||this.local.monthNames,p=(r.calculateWeek||this.local.calculateWeek,function(e,r){for(var n=1;w+n<t.length&&t.charAt(w+n)===e;)n++;return w+=n-1,Math.floor(n/(r||1))>1}),d=function(t,e,r,n){var i=\"\"+e;if(p(t,n))for(;i.length<r;)i=\"0\"+i;return i},g=this,v=function(t){return\"function\"==typeof u?u.call(g,t,p(\"m\")):x(d(\"m\",t.month(),2))},m=function(t,e){return e?\"function\"==typeof f?f.call(g,t):f[t.month()-g.minMonth]:\"function\"==typeof h?h.call(g,t):h[t.month()-g.minMonth]},y=this.local.digits,x=function(t){return r.localNumbers&&y?y(t):t},b=\"\",_=!1,w=0;w<t.length;w++)if(_)\"'\"!==t.charAt(w)||p(\"'\")?b+=t.charAt(w):_=!1;else switch(t.charAt(w)){case\"d\":b+=x(d(\"d\",e.day(),2));break;case\"D\":b+=(n=\"D\",a=e.dayOfWeek(),o=l,s=c,p(n)?s[a]:o[a]);break;case\"o\":b+=d(\"o\",e.dayOfYear(),3);break;case\"w\":b+=d(\"w\",e.weekOfYear(),2);break;case\"m\":b+=v(e);break;case\"M\":b+=m(e,p(\"M\"));break;case\"y\":b+=p(\"y\",2)?e.year():(e.year()%100<10?\"0\":\"\")+e.year()%100;break;case\"Y\":p(\"Y\",2),b+=e.formatYear();break;case\"J\":b+=e.toJD();break;case\"@\":b+=(e.toJD()-this.UNIX_EPOCH)*this.SECS_PER_DAY;break;case\"!\":b+=(e.toJD()-this.TICKS_EPOCH)*this.TICKS_PER_DAY;break;case\"'\":p(\"'\")?b+=\"'\":_=!0;break;default:b+=t.charAt(w)}return b},parseDate:function(t,e,r){if(null==e)throw i.local.invalidArguments||i.regionalOptions[\"\"].invalidArguments;if(\"\"===(e=\"object\"==typeof e?e.toString():e+\"\"))return null;t=t||this.local.dateFormat;var n=(r=r||{}).shortYearCutoff||this.shortYearCutoff;n=\"string\"!=typeof n?n:this.today().year()%100+parseInt(n,10);for(var a=r.dayNamesShort||this.local.dayNamesShort,o=r.dayNames||this.local.dayNames,s=r.parseMonth||this.local.parseMonth,l=r.monthNumbers||this.local.monthNumbers,c=r.monthNamesShort||this.local.monthNamesShort,u=r.monthNames||this.local.monthNames,h=-1,f=-1,p=-1,d=-1,g=-1,v=!1,m=!1,y=function(e,r){for(var n=1;M+n<t.length&&t.charAt(M+n)===e;)n++;return M+=n-1,Math.floor(n/(r||1))>1},x=function(t,r){var n=y(t,r),a=[2,3,n?4:2,n?4:2,10,11,20][\"oyYJ@!\".indexOf(t)+1],o=new RegExp(\"^-?\\\\d{1,\"+a+\"}\"),s=e.substring(A).match(o);if(!s)throw(i.local.missingNumberAt||i.regionalOptions[\"\"].missingNumberAt).replace(/\\{0\\}/,A);return A+=s[0].length,parseInt(s[0],10)},b=this,_=function(){if(\"function\"==typeof l){y(\"m\");var t=l.call(b,e.substring(A));return A+=t.length,t}return x(\"m\")},w=function(t,r,n,a){for(var o=y(t,a)?n:r,s=0;s<o.length;s++)if(e.substr(A,o[s].length).toLowerCase()===o[s].toLowerCase())return A+=o[s].length,s+b.minMonth;throw(i.local.unknownNameAt||i.regionalOptions[\"\"].unknownNameAt).replace(/\\{0\\}/,A)},k=function(){if(\"function\"==typeof u){var t=y(\"M\")?u.call(b,e.substring(A)):c.call(b,e.substring(A));return A+=t.length,t}return w(\"M\",c,u)},T=function(){if(e.charAt(A)!==t.charAt(M))throw(i.local.unexpectedLiteralAt||i.regionalOptions[\"\"].unexpectedLiteralAt).replace(/\\{0\\}/,A);A++},A=0,M=0;M<t.length;M++)if(m)\"'\"!==t.charAt(M)||y(\"'\")?T():m=!1;else switch(t.charAt(M)){case\"d\":d=x(\"d\");break;case\"D\":w(\"D\",a,o);break;case\"o\":g=x(\"o\");break;case\"w\":x(\"w\");break;case\"m\":p=_();break;case\"M\":p=k();break;case\"y\":var S=M;v=!y(\"y\",2),M=S,f=x(\"y\",2);break;case\"Y\":f=x(\"Y\",2);break;case\"J\":h=x(\"J\")+.5,\".\"===e.charAt(A)&&(A++,x(\"J\"));break;case\"@\":h=x(\"@\")/this.SECS_PER_DAY+this.UNIX_EPOCH;break;case\"!\":h=x(\"!\")/this.TICKS_PER_DAY+this.TICKS_EPOCH;break;case\"*\":A=e.length;break;case\"'\":y(\"'\")?T():m=!0;break;default:T()}if(A<e.length)throw i.local.unexpectedText||i.regionalOptions[\"\"].unexpectedText;if(-1===f?f=this.today().year():f<100&&v&&(f+=-1===n?1900:this.today().year()-this.today().year()%100-(f<=n?0:100)),\"string\"==typeof p&&(p=s.call(this,f,p)),g>-1){p=1,d=g;for(var E=this.daysInMonth(f,p);d>E;E=this.daysInMonth(f,p))p++,d-=E}return h>-1?this.fromJD(h):this.newDate(f,p,d)},determineDate:function(t,e,r,n,i){r&&\"object\"!=typeof r&&(i=n,n=r,r=null),\"string\"!=typeof n&&(i=n,n=\"\");var a=this;return e=e?e.newDate():null,t=null==t?e:\"string\"==typeof t?function(t){try{return a.parseDate(n,t,i)}catch(t){}for(var e=((t=t.toLowerCase()).match(/^c/)&&r?r.newDate():null)||a.today(),o=/([+-]?[0-9]+)\\s*(d|w|m|y)?/g,s=o.exec(t);s;)e.add(parseInt(s[1],10),s[2]||\"d\"),s=o.exec(t);return e}(t):\"number\"==typeof t?isNaN(t)||t===1/0||t===-1/0?e:a.today().add(t,\"d\"):a.newDate(t)}})},{\"./main\":571,\"object-assign\":454}],573:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",{offset:[1],array:0},\"scalar\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\n        var _inline_1_da = _inline_1_arg0_ - _inline_1_arg3_\\n        var _inline_1_db = _inline_1_arg1_ - _inline_1_arg3_\\n        if((_inline_1_da >= 0) !== (_inline_1_db >= 0)) {\\n          _inline_1_arg2_.push(_inline_1_arg4_[0] + 0.5 + 0.5 * (_inline_1_da + _inline_1_db) / (_inline_1_da - _inline_1_db))\\n        }\\n      }\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg3_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[\"_inline_1_da\",\"_inline_1_db\"]},funcName:\"zeroCrossings\"})},{\"cwise-compiler\":146}],574:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=[];return e=+e||0,n(t.hi(t.shape[0]-1),r,e),r};var n=t(\"./lib/zc-core\")},{\"./lib/zc-core\":573}],575:[function(t,e,r){\"use strict\";e.exports=[{path:\"\",backoff:0},{path:\"M-2.4,-3V3L0.6,0Z\",backoff:.6},{path:\"M-3.7,-2.5V2.5L1.3,0Z\",backoff:1.3},{path:\"M-4.45,-3L-1.65,-0.2V0.2L-4.45,3L1.55,0Z\",backoff:1.55},{path:\"M-2.2,-2.2L-0.2,-0.2V0.2L-2.2,2.2L-1.4,3L1.6,0L-1.4,-3Z\",backoff:1.6},{path:\"M-4.4,-2.1L-0.6,-0.2V0.2L-4.4,2.1L-4,3L2,0L-4,-3Z\",backoff:2},{path:\"M2,0A2,2 0 1,1 0,-2A2,2 0 0,1 2,0Z\",backoff:0,noRotate:!0},{path:\"M2,2V-2H-2V2Z\",backoff:0,noRotate:!0}]},{}],576:[function(t,e,r){\"use strict\";var n=t(\"./arrow_paths\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../plots/cartesian/constants\"),o=t(\"../../plot_api/plot_template\").templatedArray;e.exports=o(\"annotation\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},text:{valType:\"string\",editType:\"calc+arraydraw\"},textangle:{valType:\"angle\",dflt:0,editType:\"calc+arraydraw\"},font:i({editType:\"calc+arraydraw\",colorEditType:\"arraydraw\"}),width:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},height:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"center\",editType:\"arraydraw\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"arraydraw\"},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},borderpad:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},showarrow:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},arrowcolor:{valType:\"color\",editType:\"arraydraw\"},arrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},startarrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},arrowside:{valType:\"flaglist\",flags:[\"end\",\"start\"],extras:[\"none\"],dflt:\"end\",editType:\"arraydraw\"},arrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},startarrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},arrowwidth:{valType:\"number\",min:.1,editType:\"calc+arraydraw\"},standoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},startstandoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},ax:{valType:\"any\",editType:\"calc+arraydraw\"},ay:{valType:\"any\",editType:\"calc+arraydraw\"},axref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.x.toString()],editType:\"calc\"},ayref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.y.toString()],editType:\"calc\"},xref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.x.toString()],editType:\"calc\"},x:{valType:\"any\",editType:\"calc+arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"auto\",editType:\"calc+arraydraw\"},xshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.y.toString()],editType:\"calc\"},y:{valType:\"any\",editType:\"calc+arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"calc+arraydraw\"},yshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},clicktoshow:{valType:\"enumerated\",values:[!1,\"onoff\",\"onout\"],dflt:!1,editType:\"arraydraw\"},xclick:{valType:\"any\",editType:\"arraydraw\"},yclick:{valType:\"any\",editType:\"arraydraw\"},hovertext:{valType:\"string\",editType:\"arraydraw\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",editType:\"arraydraw\"},font:i({editType:\"arraydraw\"}),editType:\"arraydraw\"},captureevents:{valType:\"boolean\",editType:\"arraydraw\"},editType:\"calc\",_deprecated:{ref:{valType:\"string\",editType:\"calc\"}}})},{\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773,\"../../plots/font_attributes\":793,\"./arrow_paths\":575}],577:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./draw\").draw;function o(t){var e=t._fullLayout;n.filterVisible(e.annotations).forEach(function(e){var r=i.getFromId(t,e.xref),n=i.getFromId(t,e.yref);e._extremes={},r&&s(e,r),n&&s(e,n)})}function s(t,e){var r,n=e._id,a=n.charAt(0),o=t[a],s=t[\"a\"+a],l=t[a+\"ref\"],c=t[\"a\"+a+\"ref\"],u=t[\"_\"+a+\"padplus\"],h=t[\"_\"+a+\"padminus\"],f={x:1,y:-1}[a]*t[a+\"shift\"],p=3*t.arrowsize*t.arrowwidth||0,d=p+f,g=p-f,v=3*t.startarrowsize*t.arrowwidth||0,m=v+f,y=v-f;if(c===l){var x=i.findExtremes(e,[e.r2c(o)],{ppadplus:d,ppadminus:g}),b=i.findExtremes(e,[e.r2c(s)],{ppadplus:Math.max(u,m),ppadminus:Math.max(h,y)});r={min:[x.min[0],b.min[0]],max:[x.max[0],b.max[0]]}}else m=s?m+s:m,y=s?y-s:y,r=i.findExtremes(e,[e.r2c(o)],{ppadplus:Math.max(u,d,m),ppadminus:Math.max(h,g,y)});t._extremes[n]=r}e.exports=function(t){var e=t._fullLayout;if(n.filterVisible(e.annotations).length&&t._fullData.length)return n.syncOrAsync([a,o],t)}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./draw\":582}],578:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../plot_api/plot_template\").arrayEditor;function o(t,e){var r,n,i,a,o,l,c,u=t._fullLayout.annotations,h=[],f=[],p=[],d=(e||[]).length;for(r=0;r<u.length;r++)if(a=(i=u[r]).clicktoshow){for(n=0;n<d;n++)if(l=(o=e[n]).xaxis,c=o.yaxis,l._id===i.xref&&c._id===i.yref&&l.d2r(o.x)===s(i._xclick,l)&&c.d2r(o.y)===s(i._yclick,c)){(i.visible?\"onout\"===a?f:p:h).push(r);break}n===d&&i.visible&&\"onout\"===a&&f.push(r)}return{on:h,off:f,explicitOff:p}}function s(t,e){return\"log\"===e.type?e.l2r(t):e.d2r(t)}e.exports={hasClickToShow:function(t,e){var r=o(t,e);return r.on.length>0||r.explicitOff.length>0},onClick:function(t,e){var r,s,l=o(t,e),c=l.on,u=l.off.concat(l.explicitOff),h={},f=t._fullLayout.annotations;if(!c.length&&!u.length)return;for(r=0;r<c.length;r++)(s=a(t.layout,\"annotations\",f[c[r]])).modifyItem(\"visible\",!0),n.extendFlat(h,s.getUpdateObj());for(r=0;r<u.length;r++)(s=a(t.layout,\"annotations\",f[u[r]])).modifyItem(\"visible\",!1),n.extendFlat(h,s.getUpdateObj());return i.call(\"update\",t,{},h)}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../registry\":847}],579:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\");e.exports=function(t,e,r,a){a(\"opacity\");var o=a(\"bgcolor\"),s=a(\"bordercolor\"),l=i.opacity(s);a(\"borderpad\");var c=a(\"borderwidth\"),u=a(\"showarrow\");if(a(\"text\",u?\" \":r._dfltTitle.annotation),a(\"textangle\"),n.coerceFont(a,\"font\",r.font),a(\"width\"),a(\"align\"),a(\"height\")&&a(\"valign\"),u){var h,f,p=a(\"arrowside\");-1!==p.indexOf(\"end\")&&(h=a(\"arrowhead\"),f=a(\"arrowsize\")),-1!==p.indexOf(\"start\")&&(a(\"startarrowhead\",h),a(\"startarrowsize\",f)),a(\"arrowcolor\",l?e.bordercolor:i.defaultLine),a(\"arrowwidth\",2*(l&&c||1)),a(\"standoff\"),a(\"startstandoff\")}var d=a(\"hovertext\"),g=r.hoverlabel||{};if(d){var v=a(\"hoverlabel.bgcolor\",g.bgcolor||(i.opacity(o)?i.rgb(o):i.defaultLine)),m=a(\"hoverlabel.bordercolor\",g.bordercolor||i.contrast(v));n.coerceFont(a,\"hoverlabel.font\",{family:g.font.family,size:g.font.size,color:g.font.color||m})}a(\"captureevents\",!!d)}},{\"../../lib\":719,\"../color\":593}],580:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.annotations,h=e._id.charAt(0),f=0;f<u.length;f++)l=u[f],c=\"annotations[\"+f+\"].\",l[h+\"ref\"]===e._id&&p(h),l[\"a\"+h+\"ref\"]===e._id&&p(\"a\"+h);function p(t){var r=l[t],s=null;s=o?i(r,e.range):Math.pow(10,r),n(s)||(s=null),a(c+t,s)}}},{\"../../lib/to_log_range\":745,\"fast-isnumeric\":225}],581:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./common_defaults\"),s=t(\"./attributes\");function l(t,e,r){function a(r,i){return n.coerce(t,e,s,r,i)}var l=a(\"visible\"),c=a(\"clicktoshow\");if(l||c){o(t,e,r,a);for(var u=e.showarrow,h=[\"x\",\"y\"],f=[-10,-30],p={_fullLayout:r},d=0;d<2;d++){var g=h[d],v=i.coerceRef(t,e,p,g,\"\",\"paper\");if(\"paper\"!==v)i.getFromId(p,v)._annIndices.push(e._index);if(i.coercePosition(e,p,a,v,g,.5),u){var m=\"a\"+g,y=i.coerceRef(t,e,p,m,\"pixel\");\"pixel\"!==y&&y!==v&&(y=e[m]=\"pixel\");var x=\"pixel\"===y?f[d]:.4;i.coercePosition(e,p,a,y,m,x)}a(g+\"anchor\"),a(g+\"shift\")}if(n.noneOrAll(t,e,[\"x\",\"y\"]),u&&n.noneOrAll(t,e,[\"ax\",\"ay\"]),c){var b=a(\"xclick\"),_=a(\"yclick\");e._xclick=void 0===b?e.x:i.cleanPosition(b,p,e.xref),e._yclick=void 0===_?e.y:i.cleanPosition(_,p,e.yref)}}}e.exports=function(t,e){a(t,e,{name:\"annotations\",handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"./attributes\":576,\"./common_defaults\":579}],582:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../color\"),c=t(\"../drawing\"),u=t(\"../fx\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"../../lib/setcursor\"),p=t(\"../dragelement\"),d=t(\"../../plot_api/plot_template\").arrayEditor,g=t(\"./draw_arrow_head\");function v(t,e){var r=t._fullLayout.annotations[e]||{},n=s.getFromId(t,r.xref),i=s.getFromId(t,r.yref);n&&n.setScale(),i&&i.setScale(),m(t,r,e,!1,n,i)}function m(t,e,r,a,s,v){var m,y,x=t._fullLayout,b=t._fullLayout._size,_=t._context.edits;a?(m=\"annotation-\"+a,y=a+\".annotations\"):(m=\"annotation\",y=\"annotations\");var w=d(t.layout,y,e),k=w.modifyBase,T=w.modifyItem,A=w.getUpdateObj;x._infolayer.selectAll(\".\"+m+'[data-index=\"'+r+'\"]').remove();var M=\"clip\"+x._uid+\"_ann\"+r;if(e._input&&!1!==e.visible){var S={x:{},y:{}},E=+e.textangle||0,C=x._infolayer.append(\"g\").classed(m,!0).attr(\"data-index\",String(r)).style(\"opacity\",e.opacity),L=C.append(\"g\").classed(\"annotation-text-g\",!0),P=_[e.showarrow?\"annotationTail\":\"annotationPosition\"],O=e.captureevents||_.annotationText||P,z=L.append(\"g\").style(\"pointer-events\",O?\"all\":null).call(f,\"pointer\").on(\"click\",function(){t._dragging=!1,t.emit(\"plotly_clickannotation\",q(n.event))});e.hovertext&&z.on(\"mouseover\",function(){var r=e.hoverlabel,n=r.font,i=this.getBoundingClientRect(),a=t.getBoundingClientRect();u.loneHover({x0:i.left-a.left,x1:i.right-a.left,y:(i.top+i.bottom)/2-a.top,text:e.hovertext,color:r.bgcolor,borderColor:r.bordercolor,fontFamily:n.family,fontSize:n.size,fontColor:n.color},{container:x._hoverlayer.node(),outerContainer:x._paper.node(),gd:t})}).on(\"mouseout\",function(){u.loneUnhover(x._hoverlayer.node())});var I=e.borderwidth,D=e.borderpad,R=I+D,F=z.append(\"rect\").attr(\"class\",\"bg\").style(\"stroke-width\",I+\"px\").call(l.stroke,e.bordercolor).call(l.fill,e.bgcolor),B=e.width||e.height,N=x._topclips.selectAll(\"#\"+M).data(B?[0]:[]);N.enter().append(\"clipPath\").classed(\"annclip\",!0).attr(\"id\",M).append(\"rect\"),N.exit().remove();var j=e.font,U=x._meta?o.templateString(e.text,x._meta):e.text,V=z.append(\"text\").classed(\"annotation-text\",!0).text(U);_.annotationText?V.call(h.makeEditable,{delegate:z,gd:t}).call(H).on(\"edit\",function(r){e.text=r,this.call(H),T(\"text\",r),s&&s.autorange&&k(s._name+\".autorange\",!0),v&&v.autorange&&k(v._name+\".autorange\",!0),i.call(\"_guiRelayout\",t,A())}):V.call(H)}else n.selectAll(\"#\"+M).remove();function q(t){var n={index:r,annotation:e._input,fullAnnotation:e,event:t};return a&&(n.subplotId=a),n}function H(r){return r.call(c.font,j).attr({\"text-anchor\":{left:\"start\",right:\"end\"}[e.align]||\"middle\"}),h.convertToTspans(r,t,G),r}function G(){var r=V.selectAll(\"a\");1===r.size()&&r.text()===V.text()&&z.insert(\"a\",\":first-child\").attr({\"xlink:xlink:href\":r.attr(\"xlink:href\"),\"xlink:xlink:show\":r.attr(\"xlink:show\")}).style({cursor:\"pointer\"}).node().appendChild(F.node());var n=z.select(\".annotation-text-math-group\"),u=!n.empty(),d=c.bBox((u?n:V).node()),m=d.width,y=d.height,w=e.width||m,O=e.height||y,D=Math.round(w+2*R),j=Math.round(O+2*R);function U(t,e){return\"auto\"===e&&(e=t<1/3?\"left\":t>2/3?\"right\":\"center\"),{center:0,middle:0,left:.5,bottom:-.5,right:-.5,top:.5}[e]}for(var H=!1,G=[\"x\",\"y\"],Y=0;Y<G.length;Y++){var W,X,Z,J,K,$=G[Y],Q=e[$+\"ref\"]||$,tt=e[\"a\"+$+\"ref\"],et={x:s,y:v}[$],rt=(E+(\"x\"===$?0:-90))*Math.PI/180,nt=D*Math.cos(rt),it=j*Math.sin(rt),at=Math.abs(nt)+Math.abs(it),ot=e[$+\"anchor\"],st=e[$+\"shift\"]*(\"x\"===$?1:-1),lt=S[$];if(et){var ct=et.r2fraction(e[$]);(ct<0||ct>1)&&(tt===Q?((ct=et.r2fraction(e[\"a\"+$]))<0||ct>1)&&(H=!0):H=!0),W=et._offset+et.r2p(e[$]),J=.5}else\"x\"===$?(Z=e[$],W=b.l+b.w*Z):(Z=1-e[$],W=b.t+b.h*Z),J=e.showarrow?.5:Z;if(e.showarrow){lt.head=W;var ut=e[\"a\"+$];K=nt*U(.5,e.xanchor)-it*U(.5,e.yanchor),tt===Q?(lt.tail=et._offset+et.r2p(ut),X=K):(lt.tail=W+ut,X=K+ut),lt.text=lt.tail+K;var ht=x[\"x\"===$?\"width\":\"height\"];if(\"paper\"===Q&&(lt.head=o.constrain(lt.head,1,ht-1)),\"pixel\"===tt){var ft=-Math.max(lt.tail-3,lt.text),pt=Math.min(lt.tail+3,lt.text)-ht;ft>0?(lt.tail+=ft,lt.text+=ft):pt>0&&(lt.tail-=pt,lt.text-=pt)}lt.tail+=st,lt.head+=st}else X=K=at*U(J,ot),lt.text=W+K;lt.text+=st,K+=st,X+=st,e[\"_\"+$+\"padplus\"]=at/2+X,e[\"_\"+$+\"padminus\"]=at/2-X,e[\"_\"+$+\"size\"]=at,e[\"_\"+$+\"shift\"]=K}if(t._dragging||!H){var dt=0,gt=0;if(\"left\"!==e.align&&(dt=(w-m)*(\"center\"===e.align?.5:1)),\"top\"!==e.valign&&(gt=(O-y)*(\"middle\"===e.valign?.5:1)),u)n.select(\"svg\").attr({x:R+dt-1,y:R+gt}).call(c.setClipUrl,B?M:null,t);else{var vt=R+gt-d.top,mt=R+dt-d.left;V.call(h.positionText,mt,vt).call(c.setClipUrl,B?M:null,t)}N.select(\"rect\").call(c.setRect,R,R,w,O),F.call(c.setRect,I/2,I/2,D-I,j-I),z.call(c.setTranslate,Math.round(S.x.text-D/2),Math.round(S.y.text-j/2)),L.attr({transform:\"rotate(\"+E+\",\"+S.x.text+\",\"+S.y.text+\")\"});var yt,xt=function(r,n){C.selectAll(\".annotation-arrow-g\").remove();var u=S.x.head,h=S.y.head,f=S.x.tail+r,d=S.y.tail+n,m=S.x.text+r,y=S.y.text+n,x=o.rotationXYMatrix(E,m,y),w=o.apply2DTransform(x),M=o.apply2DTransform2(x),P=+F.attr(\"width\"),O=+F.attr(\"height\"),I=m-.5*P,D=I+P,R=y-.5*O,B=R+O,N=[[I,R,I,B],[I,B,D,B],[D,B,D,R],[D,R,I,R]].map(M);if(!N.reduce(function(t,e){return t^!!o.segmentsIntersect(u,h,u+1e6,h+1e6,e[0],e[1],e[2],e[3])},!1)){N.forEach(function(t){var e=o.segmentsIntersect(f,d,u,h,t[0],t[1],t[2],t[3]);e&&(f=e.x,d=e.y)});var j=e.arrowwidth,U=e.arrowcolor,V=e.arrowside,q=C.append(\"g\").style({opacity:l.opacity(U)}).classed(\"annotation-arrow-g\",!0),H=q.append(\"path\").attr(\"d\",\"M\"+f+\",\"+d+\"L\"+u+\",\"+h).style(\"stroke-width\",j+\"px\").call(l.stroke,l.rgb(U));if(g(H,V,e),_.annotationPosition&&H.node().parentNode&&!a){var G=u,Y=h;if(e.standoff){var W=Math.sqrt(Math.pow(u-f,2)+Math.pow(h-d,2));G+=e.standoff*(f-u)/W,Y+=e.standoff*(d-h)/W}var X,Z,J=q.append(\"path\").classed(\"annotation-arrow\",!0).classed(\"anndrag\",!0).classed(\"cursor-move\",!0).attr({d:\"M3,3H-3V-3H3ZM0,0L\"+(f-G)+\",\"+(d-Y),transform:\"translate(\"+G+\",\"+Y+\")\"}).style(\"stroke-width\",j+6+\"px\").call(l.stroke,\"rgba(0,0,0,0)\").call(l.fill,\"rgba(0,0,0,0)\");p.init({element:J.node(),gd:t,prepFn:function(){var t=c.getTranslate(z);X=t.x,Z=t.y,s&&s.autorange&&k(s._name+\".autorange\",!0),v&&v.autorange&&k(v._name+\".autorange\",!0)},moveFn:function(t,r){var n=w(X,Z),i=n[0]+t,a=n[1]+r;z.call(c.setTranslate,i,a),T(\"x\",s?s.p2r(s.r2p(e.x)+t):e.x+t/b.w),T(\"y\",v?v.p2r(v.r2p(e.y)+r):e.y-r/b.h),e.axref===e.xref&&T(\"ax\",s.p2r(s.r2p(e.ax)+t)),e.ayref===e.yref&&T(\"ay\",v.p2r(v.r2p(e.ay)+r)),q.attr(\"transform\",\"translate(\"+t+\",\"+r+\")\"),L.attr({transform:\"rotate(\"+E+\",\"+i+\",\"+a+\")\"})},doneFn:function(){i.call(\"_guiRelayout\",t,A());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}}};if(e.showarrow&&xt(0,0),P)p.init({element:z.node(),gd:t,prepFn:function(){yt=L.attr(\"transform\")},moveFn:function(t,r){var n=\"pointer\";if(e.showarrow)e.axref===e.xref?T(\"ax\",s.p2r(s.r2p(e.ax)+t)):T(\"ax\",e.ax+t),e.ayref===e.yref?T(\"ay\",v.p2r(v.r2p(e.ay)+r)):T(\"ay\",e.ay+r),xt(t,r);else{if(a)return;var i,o;if(s)i=s.p2r(s.r2p(e.x)+t);else{var l=e._xsize/b.w,c=e.x+(e._xshift-e.xshift)/b.w-l/2;i=p.align(c+t/b.w,l,0,1,e.xanchor)}if(v)o=v.p2r(v.r2p(e.y)+r);else{var u=e._ysize/b.h,h=e.y-(e._yshift+e.yshift)/b.h-u/2;o=p.align(h-r/b.h,u,0,1,e.yanchor)}T(\"x\",i),T(\"y\",o),s&&v||(n=p.getCursor(s?.5:i,v?.5:o,e.xanchor,e.yanchor))}L.attr({transform:\"translate(\"+t+\",\"+r+\")\"+yt}),f(z,n)},clickFn:function(r,n){e.captureevents&&t.emit(\"plotly_clickannotation\",q(n))},doneFn:function(){f(z),i.call(\"_guiRelayout\",t,A());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}else z.remove()}}e.exports={draw:function(t){var e=t._fullLayout;e._infolayer.selectAll(\".annotation\").remove();for(var r=0;r<e.annotations.length;r++)e.annotations[r].visible&&v(t,r);return a.previousPromises(t)},drawOne:v,drawRaw:m}},{\"../../lib\":719,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/axes\":767,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"../fx\":632,\"./draw_arrow_head\":583,d3:163}],583:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\"),a=t(\"./arrow_paths\");e.exports=function(t,e,r){var o,s,l,c,u=t.node(),h=a[r.arrowhead||0],f=a[r.startarrowhead||0],p=(r.arrowwidth||1)*(r.arrowsize||1),d=(r.arrowwidth||1)*(r.startarrowsize||1),g=e.indexOf(\"start\")>=0,v=e.indexOf(\"end\")>=0,m=h.backoff*p+r.standoff,y=f.backoff*d+r.startstandoff;if(\"line\"===u.nodeName){o={x:+t.attr(\"x1\"),y:+t.attr(\"y1\")},s={x:+t.attr(\"x2\"),y:+t.attr(\"y2\")};var x=o.x-s.x,b=o.y-s.y;if(c=(l=Math.atan2(b,x))+Math.PI,m&&y&&m+y>Math.sqrt(x*x+b*b))return void P();if(m){if(m*m>x*x+b*b)return void P();var _=m*Math.cos(l),w=m*Math.sin(l);s.x+=_,s.y+=w,t.attr({x2:s.x,y2:s.y})}if(y){if(y*y>x*x+b*b)return void P();var k=y*Math.cos(l),T=y*Math.sin(l);o.x-=k,o.y-=T,t.attr({x1:o.x,y1:o.y})}}else if(\"path\"===u.nodeName){var A=u.getTotalLength(),M=\"\";if(A<m+y)return void P();var S=u.getPointAtLength(0),E=u.getPointAtLength(.1);l=Math.atan2(S.y-E.y,S.x-E.x),o=u.getPointAtLength(Math.min(y,A)),M=\"0px,\"+y+\"px,\";var C=u.getPointAtLength(A),L=u.getPointAtLength(A-.1);c=Math.atan2(C.y-L.y,C.x-L.x),s=u.getPointAtLength(Math.max(0,A-m)),M+=A-(M?y+m:m)+\"px,\"+A+\"px\",t.style(\"stroke-dasharray\",M)}function P(){t.style(\"stroke-dasharray\",\"0px,100px\")}function O(e,a,o,s){e.path&&(e.noRotate&&(o=0),n.select(u.parentNode).append(\"path\").attr({class:t.attr(\"class\"),d:e.path,transform:\"translate(\"+a.x+\",\"+a.y+\")\"+(o?\"rotate(\"+180*o/Math.PI+\")\":\"\")+\"scale(\"+s+\")\"}).style({fill:i.rgb(r.arrowcolor),\"stroke-width\":0}))}g&&O(f,o,l,d),v&&O(h,s,c,p)}},{\"../color\":593,\"./arrow_paths\":575,d3:163}],584:[function(t,e,r){\"use strict\";var n=t(\"./draw\"),i=t(\"./click\");e.exports={moduleType:\"component\",name:\"annotations\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"annotations\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne,drawRaw:n.drawRaw,hasClickToShow:i.hasClickToShow,onClick:i.onClick,convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":777,\"./attributes\":576,\"./calc_autorange\":577,\"./click\":578,\"./convert_coords\":580,\"./defaults\":581,\"./draw\":582}],585:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"../../plot_api/plot_template\").templatedArray;e.exports=i(a(\"annotation\",{visible:n.visible,x:{valType:\"any\"},y:{valType:\"any\"},z:{valType:\"any\"},ax:{valType:\"number\"},ay:{valType:\"number\"},xanchor:n.xanchor,xshift:n.xshift,yanchor:n.yanchor,yshift:n.yshift,text:n.text,textangle:n.textangle,font:n.font,width:n.width,height:n.height,opacity:n.opacity,align:n.align,valign:n.valign,bgcolor:n.bgcolor,bordercolor:n.bordercolor,borderpad:n.borderpad,borderwidth:n.borderwidth,showarrow:n.showarrow,arrowcolor:n.arrowcolor,arrowhead:n.arrowhead,startarrowhead:n.startarrowhead,arrowside:n.arrowside,arrowsize:n.arrowsize,startarrowsize:n.startarrowsize,arrowwidth:n.arrowwidth,standoff:n.standoff,startstandoff:n.startstandoff,hovertext:n.hovertext,hoverlabel:n.hoverlabel,captureevents:n.captureevents}),\"calc\",\"from-root\")},{\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../annotations/attributes\":576}],586:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\");function a(t,e){var r=e.fullSceneLayout.domain,a=e.fullLayout._size,o={pdata:null,type:\"linear\",autorange:!1,range:[-1/0,1/0]};t._xa={},n.extendFlat(t._xa,o),i.setConvert(t._xa),t._xa._offset=a.l+r.x[0]*a.w,t._xa.l2p=function(){return.5*(1+t._pdata[0]/t._pdata[3])*a.w*(r.x[1]-r.x[0])},t._ya={},n.extendFlat(t._ya,o),i.setConvert(t._ya),t._ya._offset=a.t+(1-r.y[1])*a.h,t._ya.l2p=function(){return.5*(1-t._pdata[1]/t._pdata[3])*a.h*(r.y[1]-r.y[0])}}e.exports=function(t){for(var e=t.fullSceneLayout.annotations,r=0;r<e.length;r++)a(e[r],t);t.fullLayout._infolayer.selectAll(\".annotation-\"+t.id).remove()}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767}],587:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"../annotations/common_defaults\"),s=t(\"./attributes\");function l(t,e,r,a){function l(r,i){return n.coerce(t,e,s,r,i)}function c(t){var n=t+\"axis\",a={_fullLayout:{}};return a._fullLayout[n]=r[n],i.coercePosition(e,a,l,t,t,.5)}l(\"visible\")&&(o(t,e,a.fullLayout,l),c(\"x\"),c(\"y\"),c(\"z\"),n.noneOrAll(t,e,[\"x\",\"y\",\"z\"]),e.xref=\"x\",e.yref=\"y\",e.zref=\"z\",l(\"xanchor\"),l(\"yanchor\"),l(\"xshift\"),l(\"yshift\"),e.showarrow&&(e.axref=\"pixel\",e.ayref=\"pixel\",l(\"ax\",-10),l(\"ay\",-30),n.noneOrAll(t,e,[\"ax\",\"ay\"])))}e.exports=function(t,e,r){a(t,e,{name:\"annotations\",handleItemDefaults:l,fullLayout:r.fullLayout})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"../annotations/common_defaults\":579,\"./attributes\":585}],588:[function(t,e,r){\"use strict\";var n=t(\"../annotations/draw\").drawRaw,i=t(\"../../plots/gl3d/project\"),a=[\"x\",\"y\",\"z\"];e.exports=function(t){for(var e=t.fullSceneLayout,r=t.dataScale,o=e.annotations,s=0;s<o.length;s++){for(var l=o[s],c=!1,u=0;u<3;u++){var h=a[u],f=l[h],p=e[h+\"axis\"].r2fraction(f);if(p<0||p>1){c=!0;break}}c?t.fullLayout._infolayer.select(\".annotation-\"+t.id+'[data-index=\"'+s+'\"]').remove():(l._pdata=i(t.glplot.cameraParams,[e.xaxis.r2l(l.x)*r[0],e.yaxis.r2l(l.y)*r[1],e.zaxis.r2l(l.z)*r[2]]),n(t.graphDiv,l,s,t.id,l._xa,l._ya))}}},{\"../../plots/gl3d/project\":816,\"../annotations/draw\":582}],589:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports={moduleType:\"component\",name:\"annotations3d\",schema:{subplots:{scene:{annotations:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),includeBasePlot:function(t,e){var r=n.subplotsRegistry.gl3d;if(!r)return;for(var a=r.attrRegex,o=Object.keys(t),s=0;s<o.length;s++){var l=o[s];a.test(l)&&(t[l].annotations||[]).length&&(i.pushUnique(e._basePlotModules,r),i.pushUnique(e._subplots.gl3d,l))}},convert:t(\"./convert\"),draw:t(\"./draw\")}},{\"../../lib\":719,\"../../registry\":847,\"./attributes\":585,\"./convert\":586,\"./defaults\":587,\"./draw\":588}],590:[function(t,e,r){\"use strict\";e.exports=t(\"world-calendars/dist/main\"),t(\"world-calendars/dist/plus\"),t(\"world-calendars/dist/calendars/chinese\"),t(\"world-calendars/dist/calendars/coptic\"),t(\"world-calendars/dist/calendars/discworld\"),t(\"world-calendars/dist/calendars/ethiopian\"),t(\"world-calendars/dist/calendars/hebrew\"),t(\"world-calendars/dist/calendars/islamic\"),t(\"world-calendars/dist/calendars/julian\"),t(\"world-calendars/dist/calendars/mayan\"),t(\"world-calendars/dist/calendars/nanakshahi\"),t(\"world-calendars/dist/calendars/nepali\"),t(\"world-calendars/dist/calendars/persian\"),t(\"world-calendars/dist/calendars/taiwan\"),t(\"world-calendars/dist/calendars/thai\"),t(\"world-calendars/dist/calendars/ummalqura\")},{\"world-calendars/dist/calendars/chinese\":557,\"world-calendars/dist/calendars/coptic\":558,\"world-calendars/dist/calendars/discworld\":559,\"world-calendars/dist/calendars/ethiopian\":560,\"world-calendars/dist/calendars/hebrew\":561,\"world-calendars/dist/calendars/islamic\":562,\"world-calendars/dist/calendars/julian\":563,\"world-calendars/dist/calendars/mayan\":564,\"world-calendars/dist/calendars/nanakshahi\":565,\"world-calendars/dist/calendars/nepali\":566,\"world-calendars/dist/calendars/persian\":567,\"world-calendars/dist/calendars/taiwan\":568,\"world-calendars/dist/calendars/thai\":569,\"world-calendars/dist/calendars/ummalqura\":570,\"world-calendars/dist/main\":571,\"world-calendars/dist/plus\":572}],591:[function(t,e,r){\"use strict\";var n=t(\"./calendars\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\"),o=a.EPOCHJD,s=a.ONEDAY,l={valType:\"enumerated\",values:Object.keys(n.calendars),editType:\"calc\",dflt:\"gregorian\"},c=function(t,e,r,n){var a={};return a[r]=l,i.coerce(t,e,a,r,n)},u=\"##\",h={d:{0:\"dd\",\"-\":\"d\"},e:{0:\"d\",\"-\":\"d\"},a:{0:\"D\",\"-\":\"D\"},A:{0:\"DD\",\"-\":\"DD\"},j:{0:\"oo\",\"-\":\"o\"},W:{0:\"ww\",\"-\":\"w\"},m:{0:\"mm\",\"-\":\"m\"},b:{0:\"M\",\"-\":\"M\"},B:{0:\"MM\",\"-\":\"MM\"},y:{0:\"yy\",\"-\":\"yy\"},Y:{0:\"yyyy\",\"-\":\"yyyy\"},U:u,w:u,c:{0:\"D M d %X yyyy\",\"-\":\"D M d %X yyyy\"},x:{0:\"mm/dd/yyyy\",\"-\":\"mm/dd/yyyy\"}};var f={};function p(t){var e=f[t];return e||(e=f[t]=n.instance(t))}function d(t){return i.extendFlat({},l,{description:t})}function g(t){return\"Sets the calendar system to use with `\"+t+\"` date data.\"}var v={xcalendar:d(g(\"x\"))},m=i.extendFlat({},v,{ycalendar:d(g(\"y\"))}),y=i.extendFlat({},m,{zcalendar:d(g(\"z\"))}),x=d([\"Sets the calendar system to use for `range` and `tick0`\",\"if this is a date axis. This does not set the calendar for\",\"interpreting data on this axis, that's specified in the trace\",\"or via the global `layout.calendar`\"].join(\" \"));e.exports={moduleType:\"component\",name:\"calendars\",schema:{traces:{scatter:m,bar:m,box:m,heatmap:m,contour:m,histogram:m,histogram2d:m,histogram2dcontour:m,scatter3d:y,surface:y,mesh3d:y,scattergl:m,ohlc:v,candlestick:v},layout:{calendar:d([\"Sets the default calendar system to use for interpreting and\",\"displaying dates throughout the plot.\"].join(\" \"))},subplots:{xaxis:{calendar:x},yaxis:{calendar:x},scene:{xaxis:{calendar:x},yaxis:{calendar:x},zaxis:{calendar:x}},polar:{radialaxis:{calendar:x}}},transforms:{filter:{valuecalendar:d([\"Sets the calendar system to use for `value`, if it is a date.\"].join(\" \")),targetcalendar:d([\"Sets the calendar system to use for `target`, if it is an\",\"array of dates. If `target` is a string (eg *x*) we use the\",\"corresponding trace attribute (eg `xcalendar`) if it exists,\",\"even if `targetcalendar` is provided.\"].join(\" \"))}}},layoutAttributes:l,handleDefaults:c,handleTraceDefaults:function(t,e,r,n){for(var i=0;i<r.length;i++)c(t,e,r[i]+\"calendar\",n.calendar)},CANONICAL_SUNDAY:{chinese:\"2000-01-02\",coptic:\"2000-01-03\",discworld:\"2000-01-03\",ethiopian:\"2000-01-05\",hebrew:\"5000-01-01\",islamic:\"1000-01-02\",julian:\"2000-01-03\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-05\",nepali:\"2000-01-05\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-04\",thai:\"2000-01-04\",ummalqura:\"1400-01-06\"},CANONICAL_TICK:{chinese:\"2000-01-01\",coptic:\"2000-01-01\",discworld:\"2000-01-01\",ethiopian:\"2000-01-01\",hebrew:\"5000-01-01\",islamic:\"1000-01-01\",julian:\"2000-01-01\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-01\",nepali:\"2000-01-01\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-01\",thai:\"2000-01-01\",ummalqura:\"1400-01-01\"},DFLTRANGE:{chinese:[\"2000-01-01\",\"2001-01-01\"],coptic:[\"1700-01-01\",\"1701-01-01\"],discworld:[\"1800-01-01\",\"1801-01-01\"],ethiopian:[\"2000-01-01\",\"2001-01-01\"],hebrew:[\"5700-01-01\",\"5701-01-01\"],islamic:[\"1400-01-01\",\"1401-01-01\"],julian:[\"2000-01-01\",\"2001-01-01\"],mayan:[\"5200-01-01\",\"5201-01-01\"],nanakshahi:[\"0500-01-01\",\"0501-01-01\"],nepali:[\"2000-01-01\",\"2001-01-01\"],persian:[\"1400-01-01\",\"1401-01-01\"],jalali:[\"1400-01-01\",\"1401-01-01\"],taiwan:[\"0100-01-01\",\"0101-01-01\"],thai:[\"2500-01-01\",\"2501-01-01\"],ummalqura:[\"1400-01-01\",\"1401-01-01\"]},getCal:p,worldCalFmt:function(t,e,r){for(var n,i,a,l,c,f=Math.floor((e+.05)/s)+o,d=p(r).fromJD(f),g=0;-1!==(g=t.indexOf(\"%\",g));)\"0\"===(n=t.charAt(g+1))||\"-\"===n||\"_\"===n?(a=3,i=t.charAt(g+2),\"_\"===n&&(n=\"-\")):(i=n,n=\"0\",a=2),(l=h[i])?(c=l===u?u:d.formatDate(l[n]),t=t.substr(0,g)+c+t.substr(g+a),g+=c.length):g+=a;return t}}},{\"../../constants/numerical\":695,\"../../lib\":719,\"./calendars\":590}],592:[function(t,e,r){\"use strict\";r.defaults=[\"#1f77b4\",\"#ff7f0e\",\"#2ca02c\",\"#d62728\",\"#9467bd\",\"#8c564b\",\"#e377c2\",\"#7f7f7f\",\"#bcbd22\",\"#17becf\"],r.defaultLine=\"#444\",r.lightLine=\"#eee\",r.background=\"#fff\",r.borderLine=\"#BEC8D9\",r.lightFraction=1e3/11},{}],593:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i=t(\"fast-isnumeric\"),a=e.exports={},o=t(\"./attributes\");a.defaults=o.defaults;var s=a.defaultLine=o.defaultLine;a.lightLine=o.lightLine;var l=a.background=o.background;function c(t){if(i(t)||\"string\"!=typeof t)return t;var e=t.trim();if(\"rgb\"!==e.substr(0,3))return t;var r=e.match(/^rgba?\\s*\\(([^()]*)\\)$/);if(!r)return t;var n=r[1].trim().split(/\\s*[\\s,]\\s*/),a=\"a\"===e.charAt(3)&&4===n.length;if(!a&&3!==n.length)return t;for(var o=0;o<n.length;o++){if(!n[o].length)return t;if(n[o]=Number(n[o]),!(n[o]>=0))return t;if(3===o)n[o]>1&&(n[o]=1);else if(n[o]>=1)return t}var s=Math.round(255*n[0])+\", \"+Math.round(255*n[1])+\", \"+Math.round(255*n[2]);return a?\"rgba(\"+s+\", \"+n[3]+\")\":\"rgb(\"+s+\")\"}a.tinyRGB=function(t){var e=t.toRgb();return\"rgb(\"+Math.round(e.r)+\", \"+Math.round(e.g)+\", \"+Math.round(e.b)+\")\"},a.rgb=function(t){return a.tinyRGB(n(t))},a.opacity=function(t){return t?n(t).getAlpha():0},a.addOpacity=function(t,e){var r=n(t).toRgb();return\"rgba(\"+Math.round(r.r)+\", \"+Math.round(r.g)+\", \"+Math.round(r.b)+\", \"+e+\")\"},a.combine=function(t,e){var r=n(t).toRgb();if(1===r.a)return n(t).toRgbString();var i=n(e||l).toRgb(),a=1===i.a?i:{r:255*(1-i.a)+i.r*i.a,g:255*(1-i.a)+i.g*i.a,b:255*(1-i.a)+i.b*i.a},o={r:a.r*(1-r.a)+r.r*r.a,g:a.g*(1-r.a)+r.g*r.a,b:a.b*(1-r.a)+r.b*r.a};return n(o).toRgbString()},a.contrast=function(t,e,r){var i=n(t);return 1!==i.getAlpha()&&(i=n(a.combine(t,l))),(i.isDark()?e?i.lighten(e):l:r?i.darken(r):s).toString()},a.stroke=function(t,e){var r=n(e);t.style({stroke:a.tinyRGB(r),\"stroke-opacity\":r.getAlpha()})},a.fill=function(t,e){var r=n(e);t.style({fill:a.tinyRGB(r),\"fill-opacity\":r.getAlpha()})},a.clean=function(t){if(t&&\"object\"==typeof t){var e,r,n,i,o=Object.keys(t);for(e=0;e<o.length;e++)if(i=t[n=o[e]],\"color\"===n.substr(n.length-5))if(Array.isArray(i))for(r=0;r<i.length;r++)i[r]=c(i[r]);else t[n]=c(i);else if(\"colorscale\"===n.substr(n.length-10)&&Array.isArray(i))for(r=0;r<i.length;r++)Array.isArray(i[r])&&(i[r][1]=c(i[r][1]));else if(Array.isArray(i)){var s=i[0];if(!Array.isArray(s)&&s&&\"object\"==typeof s)for(r=0;r<i.length;r++)a.clean(i[r])}else i&&\"object\"==typeof i&&a.clean(i)}}},{\"./attributes\":592,\"fast-isnumeric\":225,tinycolor2:537}],594:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/layout_attributes\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll;e.exports=o({thicknessmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"pixels\"},thickness:{valType:\"number\",min:0,dflt:30},lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",dflt:1.02,min:-2,max:3},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},xpad:{valType:\"number\",min:0,dflt:10},y:{valType:\"number\",dflt:.5,min:-2,max:3},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\"},ypad:{valType:\"number\",min:0,dflt:10},outlinecolor:n.linecolor,outlinewidth:n.linewidth,bordercolor:n.linecolor,borderwidth:{valType:\"number\",min:0,dflt:0},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\"},tickmode:n.tickmode,nticks:n.nticks,tick0:n.tick0,dtick:n.dtick,tickvals:n.tickvals,ticktext:n.ticktext,ticks:a({},n.ticks,{dflt:\"\"}),ticklen:n.ticklen,tickwidth:n.tickwidth,tickcolor:n.tickcolor,showticklabels:n.showticklabels,tickfont:i({}),tickangle:n.tickangle,tickformat:n.tickformat,tickformatstops:n.tickformatstops,tickprefix:n.tickprefix,showtickprefix:n.showtickprefix,ticksuffix:n.ticksuffix,showticksuffix:n.showticksuffix,separatethousands:n.separatethousands,exponentformat:n.exponentformat,showexponent:n.showexponent,title:{text:{valType:\"string\"},font:i({}),side:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}},_deprecated:{title:{valType:\"string\"},titlefont:i({}),titleside:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}}},\"colorbars\",\"from-root\")},{\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/font_attributes\":793}],595:[function(t,e,r){\"use strict\";e.exports={cn:{colorbar:\"colorbar\",cbbg:\"cbbg\",cbfill:\"cbfill\",cbfills:\"cbfills\",cbline:\"cbline\",cblines:\"cblines\",cbaxis:\"cbaxis\",cbtitleunshift:\"cbtitleunshift\",cbtitle:\"cbtitle\",cboutline:\"cboutline\",crisp:\"crisp\",jsPlaceholder:\"js-placeholder\"}}},{}],596:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/tick_value_defaults\"),o=t(\"../../plots/cartesian/tick_mark_defaults\"),s=t(\"../../plots/cartesian/tick_label_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r){var c=i.newContainer(e,\"colorbar\"),u=t.colorbar||{};function h(t,e){return n.coerce(u,c,l,t,e)}var f=h(\"thicknessmode\");h(\"thickness\",\"fraction\"===f?30/(r.width-r.margin.l-r.margin.r):30);var p=h(\"lenmode\");h(\"len\",\"fraction\"===p?1:r.height-r.margin.t-r.margin.b),h(\"x\"),h(\"xanchor\"),h(\"xpad\"),h(\"y\"),h(\"yanchor\"),h(\"ypad\"),n.noneOrAll(u,c,[\"x\",\"y\"]),h(\"outlinecolor\"),h(\"outlinewidth\"),h(\"bordercolor\"),h(\"borderwidth\"),h(\"bgcolor\"),a(u,c,h,\"linear\");var d={outerTicks:!1,font:r.font};s(u,c,h,\"linear\",d),o(u,c,h,\"linear\",d),h(\"title.text\",r._dfltTitle.colorbar),n.coerceFont(h,\"title.font\",r.font),h(\"title.side\")}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/tick_label_defaults\":786,\"../../plots/cartesian/tick_mark_defaults\":787,\"../../plots/cartesian/tick_value_defaults\":788,\"./attributes\":594}],597:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../dragelement\"),c=t(\"../../lib\"),u=t(\"../../lib/extend\").extendFlat,h=t(\"../../lib/setcursor\"),f=t(\"../drawing\"),p=t(\"../color\"),d=t(\"../titles\"),g=t(\"../../lib/svg_text_utils\"),v=t(\"../colorscale/helpers\").flipScale,m=t(\"../../plots/cartesian/axis_defaults\"),y=t(\"../../plots/cartesian/position_defaults\"),x=t(\"../../plots/cartesian/layout_attributes\"),b=t(\"../../constants/alignment\"),_=b.LINE_SPACING,w=b.FROM_TL,k=b.FROM_BR,T=t(\"./constants\").cn;e.exports={draw:function(t){var e=t._fullLayout._infolayer.selectAll(\"g.\"+T.colorbar).data(function(t){var e,r,n,i,a=t._fullLayout,o=t.calcdata,s=[];function l(t){return u(t,{_fillcolor:null,_line:{color:null,width:null,dash:null},_levels:{start:null,end:null,size:null},_filllevels:null,_fillgradient:null,_zrange:null})}function c(){\"function\"==typeof i.calc?i.calc(t,n,e):(e._fillgradient=r.reversescale?v(r.colorscale):r.colorscale,e._zrange=[r[i.min],r[i.max]])}for(var h=0;h<o.length;h++){var f=o[h],p=(n=f[0].trace)._module.colorbar;if(!0===n.visible&&p)for(var d=Array.isArray(p),g=d?p:[p],m=0;m<g.length;m++){var y=(i=g[m]).container;(r=y?n[y]:n)&&r.showscale&&((e=l(r.colorbar))._id=\"cb\"+n.uid+(d&&y?\"-\"+y:\"\"),e._traceIndex=n.index,e._propPrefix=(y?y+\".\":\"\")+\"colorbar.\",e._meta=n._meta,c(),s.push(e))}}for(var x in a._colorAxes)if((r=a[x]).showscale){var b=a._colorAxes[x];(e=l(r.colorbar))._id=\"cb\"+x,e._propPrefix=x+\".colorbar.\",e._meta=a._meta,i={min:\"cmin\",max:\"cmax\"},\"heatmap\"!==b[0]&&(n=b[1],i.calc=n._module.colorbar.calc),c(),s.push(e)}return s}(t),function(t){return t._id});e.enter().append(\"g\").attr(\"class\",function(t){return t._id}).classed(T.colorbar,!0),e.each(function(e){var r=n.select(this);c.ensureSingle(r,\"rect\",T.cbbg),c.ensureSingle(r,\"g\",T.cbfills),c.ensureSingle(r,\"g\",T.cblines),c.ensureSingle(r,\"g\",T.cbaxis,function(t){t.classed(T.crisp,!0)}),c.ensureSingle(r,\"g\",T.cbtitleunshift,function(t){t.append(\"g\").classed(T.cbtitle,!0)}),c.ensureSingle(r,\"rect\",T.cboutline);var v=function(t,e,r){var o=r._fullLayout,l=o._size,h=e._fillcolor,v=e._line,b=e.title,A=b.side,M=e._zrange||n.extent((\"function\"==typeof h?h:v.color).domain()),S=\"function\"==typeof v.color?v.color:function(){return v.color},E=\"function\"==typeof h?h:function(){return h},C=e._levels,L=function(t,e,r){var n,i,a=e._levels,o=[],s=[],l=a.end+a.size/100,c=a.size,u=1.001*r[0]-.001*r[1],h=1.001*r[1]-.001*r[0];for(i=0;i<1e5&&(n=a.start+i*c,!(c>0?n>=l:n<=l));i++)n>u&&n<h&&o.push(n);if(e._fillgradient)s=[0];else if(\"function\"==typeof e._fillcolor){var f=e._filllevels;if(f)for(l=f.end+f.size/100,c=f.size,i=0;i<1e5&&(n=f.start+i*c,!(c>0?n>=l:n<=l));i++)n>r[0]&&n<r[1]&&s.push(n);else(s=o.map(function(t){return t-a.size/2})).push(s[s.length-1]+a.size)}else e._fillcolor&&\"string\"==typeof e._fillcolor&&(s=[0]);return a.size<0&&(o.reverse(),s.reverse()),{line:o,fill:s}}(0,e,M),P=L.fill,O=L.line,z=Math.round(e.thickness*(\"fraction\"===e.thicknessmode?l.w:1)),I=z/l.w,D=Math.round(e.len*(\"fraction\"===e.lenmode?l.h:1)),R=D/l.h,F=e.xpad/l.w,B=(e.borderwidth+e.outlinewidth)/2,N=e.ypad/l.h,j=Math.round(e.x*l.w+e.xpad),U=e.x-I*({middle:.5,right:1}[e.xanchor]||0),V=e.y+R*(({top:-.5,bottom:.5}[e.yanchor]||0)-.5),q=Math.round(l.h*(1-V)),H=q-D;e._lenFrac=R,e._thickFrac=I,e._xLeftFrac=U,e._yBottomFrac=V;var G=function(t,e,r){var n=t._fullLayout,i={type:\"linear\",range:r,tickmode:e.tickmode,nticks:e.nticks,tick0:e.tick0,dtick:e.dtick,tickvals:e.tickvals,ticktext:e.ticktext,ticks:e.ticks,ticklen:e.ticklen,tickwidth:e.tickwidth,tickcolor:e.tickcolor,showticklabels:e.showticklabels,tickfont:e.tickfont,tickangle:e.tickangle,tickformat:e.tickformat,exponentformat:e.exponentformat,separatethousands:e.separatethousands,showexponent:e.showexponent,showtickprefix:e.showtickprefix,tickprefix:e.tickprefix,showticksuffix:e.showticksuffix,ticksuffix:e.ticksuffix,title:e.title,showline:!0,anchor:\"free\",side:\"right\",position:1},a={type:\"linear\",_id:\"y\"+e._id},o={letter:\"y\",font:n.font,noHover:!0,noTickson:!0,calendar:n.calendar};function s(t,e){return c.coerce(i,a,x,t,e)}return m(i,a,s,o,n),y(i,a,s,o),a}(r,e,M);if(G.position=e.x+F+I,-1!==[\"top\",\"bottom\"].indexOf(A)&&(G.title.side=A,G.titlex=e.x+F,G.titley=V+(\"top\"===b.side?R-N:N)),v.color&&\"auto\"===e.tickmode){G.tickmode=\"linear\",G.tick0=C.start;var Y=C.size,W=c.constrain((q-H)/50,4,15)+1,X=(M[1]-M[0])/((e.nticks||W)*Y);if(X>1){var Z=Math.pow(10,Math.floor(Math.log(X)/Math.LN10));Y*=Z*c.roundUp(X/Z,[2,5,10]),(Math.abs(C.start)/C.size+1e-6)%1<2e-6&&(G.tick0=0)}G.dtick=Y}G.domain=[V+N,V+R-N],G.setScale(),t.attr(\"transform\",\"translate(\"+Math.round(l.l)+\",\"+Math.round(l.t)+\")\");var J,K=t.select(\".\"+T.cbtitleunshift).attr(\"transform\",\"translate(-\"+Math.round(l.l)+\",-\"+Math.round(l.t)+\")\"),$=t.select(\".\"+T.cbaxis),Q=0;function tt(n,i){var a={propContainer:G,propName:e._propPrefix+\"title\",traceIndex:e._traceIndex,_meta:e._meta,placeholder:o._dfltTitle.colorbar,containerGroup:t.select(\".\"+T.cbtitle)},s=\"h\"===n.charAt(0)?n.substr(1):\"h\"+n;t.selectAll(\".\"+s+\",.\"+s+\"-math-group\").remove(),d.draw(r,n,u(a,i||{}))}return c.syncOrAsync([a.previousPromises,function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var t,r=l.l+(e.x+F)*l.w,n=G.title.font.size;t=\"top\"===A?(1-(V+R-N))*l.h+l.t+3+.75*n:(1-(V+N))*l.h+l.t-3-.25*n,tt(G._id+\"title\",{attributes:{x:r,y:t,\"text-anchor\":\"start\"}})}},function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var a=t.select(\".\"+T.cbtitle),o=a.select(\"text\"),u=[-e.outlinewidth/2,e.outlinewidth/2],h=a.select(\".h\"+G._id+\"title-math-group\").node(),p=15.6;if(o.node()&&(p=parseInt(o.node().style.fontSize,10)*_),h?(Q=f.bBox(h).height)>p&&(u[1]-=(Q-p)/2):o.node()&&!o.classed(T.jsPlaceholder)&&(Q=f.bBox(o.node()).height),Q){if(Q+=5,\"top\"===A)G.domain[1]-=Q/l.h,u[1]*=-1;else{G.domain[0]+=Q/l.h;var d=g.lineCount(o);u[1]+=(1-d)*p}a.attr(\"transform\",\"translate(\"+u+\")\"),G.setScale()}}t.selectAll(\".\"+T.cbfills+\",.\"+T.cblines).attr(\"transform\",\"translate(0,\"+Math.round(l.h*(1-G.domain[1]))+\")\"),$.attr(\"transform\",\"translate(0,\"+Math.round(-l.t)+\")\");var m=t.select(\".\"+T.cbfills).selectAll(\"rect.\"+T.cbfill).data(P);m.enter().append(\"rect\").classed(T.cbfill,!0).style(\"stroke\",\"none\"),m.exit().remove();var y=M.map(G.c2p).map(Math.round).sort(function(t,e){return t-e});m.each(function(t,a){var o=[0===a?M[0]:(P[a]+P[a-1])/2,a===P.length-1?M[1]:(P[a]+P[a+1])/2].map(G.c2p).map(Math.round);o[1]=c.constrain(o[1]+(o[1]>o[0])?1:-1,y[0],y[1]);var s=n.select(this).attr({x:j,width:Math.max(z,2),y:n.min(o),height:Math.max(n.max(o)-n.min(o),2)});if(e._fillgradient)f.gradient(s,r,e._id,\"vertical\",e._fillgradient,\"fill\");else{var l=E(t).replace(\"e-\",\"\");s.attr(\"fill\",i(l).toHexString())}});var x=t.select(\".\"+T.cblines).selectAll(\"path.\"+T.cbline).data(v.color&&v.width?O:[]);x.enter().append(\"path\").classed(T.cbline,!0),x.exit().remove(),x.each(function(t){n.select(this).attr(\"d\",\"M\"+j+\",\"+(Math.round(G.c2p(t))+v.width/2%1)+\"h\"+z).call(f.lineGroupStyle,v.width,S(t),v.dash)}),$.selectAll(\"g.\"+G._id+\"tick,path\").remove();var b=j+z+(e.outlinewidth||0)/2-(\"outside\"===e.ticks?1:0),w=s.calcTicks(G),k=s.makeTransFn(G),C=s.getTickSigns(G)[2];return s.drawTicks(r,G,{vals:\"inside\"===G.ticks?s.clipEnds(G,w):w,layer:$,path:s.makeTickPath(G,b,C),transFn:k}),s.drawLabels(r,G,{vals:w,layer:$,transFn:k,labelFns:s.makeLabelFns(G,b)})},function(){if(-1===[\"top\",\"bottom\"].indexOf(A)){var t=G.title.font.size,e=G._offset+G._length/2,i=l.l+(G.position||0)*l.w+(\"right\"===G.side?10+t*(G.showticklabels?1:.5):-10-t*(G.showticklabels?.5:0));tt(\"h\"+G._id+\"title\",{avoid:{selection:n.select(r).selectAll(\"g.\"+G._id+\"tick\"),side:A,offsetLeft:l.l,offsetTop:0,maxShift:o.width},attributes:{x:i,y:e,\"text-anchor\":\"middle\"},transform:{rotate:\"-90\",offset:0}})}},a.previousPromises,function(){var n=z+e.outlinewidth/2+f.bBox($.node()).width;if((J=K.select(\"text\")).node()&&!J.classed(T.jsPlaceholder)){var i,o=K.select(\".h\"+G._id+\"title-math-group\").node();i=o&&-1!==[\"top\",\"bottom\"].indexOf(A)?f.bBox(o).width:f.bBox(K.node()).right-j-l.l,n=Math.max(n,i)}var s=2*e.xpad+n+e.borderwidth+e.outlinewidth/2,c=q-H;t.select(\".\"+T.cbbg).attr({x:j-e.xpad-(e.borderwidth+e.outlinewidth)/2,y:H-B,width:Math.max(s,2),height:Math.max(c+2*B,2)}).call(p.fill,e.bgcolor).call(p.stroke,e.bordercolor).style(\"stroke-width\",e.borderwidth),t.selectAll(\".\"+T.cboutline).attr({x:j,y:H+e.ypad+(\"top\"===A?Q:0),width:Math.max(z,2),height:Math.max(c-2*e.ypad-Q,2)}).call(p.stroke,e.outlinecolor).style({fill:\"none\",\"stroke-width\":e.outlinewidth});var u=({center:.5,right:1}[e.xanchor]||0)*s;t.attr(\"transform\",\"translate(\"+(l.l-u)+\",\"+l.t+\")\");var h={},d=w[e.yanchor],g=k[e.yanchor];\"pixels\"===e.lenmode?(h.y=e.y,h.t=c*d,h.b=c*g):(h.t=h.b=0,h.yt=e.y+e.len*d,h.yb=e.y-e.len*g);var v=w[e.xanchor],m=k[e.xanchor];if(\"pixels\"===e.thicknessmode)h.x=e.x,h.l=s*v,h.r=s*m;else{var y=s-z;h.l=y*v,h.r=y*m,h.xl=e.x-e.thickness*v,h.xr=e.x+e.thickness*m}a.autoMargin(r,e._id,h)}],r)}(r,e,t);v&&v.then&&(t._promises||[]).push(v),t._context.edits.colorbarPosition&&function(t,e,r){var n,i,a,s=r._fullLayout._size;l.init({element:t.node(),gd:r,prepFn:function(){n=t.attr(\"transform\"),h(t)},moveFn:function(r,o){t.attr(\"transform\",n+\" translate(\"+r+\",\"+o+\")\"),i=l.align(e._xLeftFrac+r/s.w,e._thickFrac,0,1,e.xanchor),a=l.align(e._yBottomFrac-o/s.h,e._lenFrac,0,1,e.yanchor);var c=l.getCursor(i,a,e.xanchor,e.yanchor);h(t,c)},doneFn:function(){if(h(t),void 0!==i&&void 0!==a){var n={};n[e._propPrefix+\"x\"]=i,n[e._propPrefix+\"y\"]=a,void 0!==e._traceIndex?o.call(\"_guiRestyle\",r,n,e._traceIndex):o.call(\"_guiRelayout\",r,n)}}})}(r,e,t)}),e.exit().each(function(e){a.autoMargin(t,e._id)}).remove(),e.order()}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/extend\":710,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_defaults\":769,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/cartesian/position_defaults\":782,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../colorscale/helpers\":604,\"../dragelement\":611,\"../drawing\":614,\"../titles\":681,\"./constants\":595,d3:163,tinycolor2:537}],598:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t){return n.isPlainObject(t.colorbar)}},{\"../../lib\":719}],599:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"colorbar\",attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),draw:t(\"./draw\").draw,hasColorbar:t(\"./has_colorbar\")}},{\"./attributes\":594,\"./defaults\":596,\"./draw\":597,\"./has_colorbar\":598}],600:[function(t,e,r){\"use strict\";var n=t(\"../colorbar/attributes\"),i=t(\"../../lib/regex\").counter,a=t(\"./scales.js\").scales;Object.keys(a);function o(t){return\"`\"+t+\"`\"}e.exports=function(t,e){t=t||\"\";var r,s=(e=e||{}).cLetter||\"c\",l=(\"onlyIfNumerical\"in e?e.onlyIfNumerical:Boolean(t),\"noScale\"in e?e.noScale:\"marker.line\"===t),c=\"showScaleDflt\"in e?e.showScaleDflt:\"z\"===s,u=\"string\"==typeof e.colorscaleDflt?a[e.colorscaleDflt]:null,h=e.editTypeOverride||\"\",f=t?t+\".\":\"\";\"colorAttr\"in e?(r=e.colorAttr,e.colorAttr):o(f+(r={z:\"z\",c:\"color\"}[s]));var p=s+\"auto\",d=s+\"min\",g=s+\"max\",v=s+\"mid\",m=(o(f+p),o(f+d),o(f+g),{});m[d]=m[g]=void 0;var y={};y[p]=!1;var x={};return\"color\"===r&&(x.color={valType:\"color\",arrayOk:!0,editType:h||\"style\"},e.anim&&(x.color.anim=!0)),x[p]={valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:m},x[d]={valType:\"number\",dflt:null,editType:h||\"plot\",impliedEdits:y},x[g]={valType:\"number\",dflt:null,editType:h||\"plot\",impliedEdits:y},x[v]={valType:\"number\",dflt:null,editType:\"calc\",impliedEdits:m},x.colorscale={valType:\"colorscale\",editType:\"calc\",dflt:u,impliedEdits:{autocolorscale:!1}},x.autocolorscale={valType:\"boolean\",dflt:!1!==e.autoColorDflt,editType:\"calc\",impliedEdits:{colorscale:void 0}},x.reversescale={valType:\"boolean\",dflt:!1,editType:\"plot\"},l||(x.showscale={valType:\"boolean\",dflt:c,editType:\"calc\"},x.colorbar=n),e.noColorAxis||(x.coloraxis={valType:\"subplotid\",regex:i(\"coloraxis\"),dflt:null,editType:\"calc\"}),x}},{\"../../lib/regex\":735,\"../colorbar/attributes\":594,\"./scales.js\":608}],601:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"./helpers\").extractOpts;e.exports=function(t,e,r){var o,s=t._fullLayout,l=r.vals,c=r.containerStr,u=c?i.nestedProperty(e,c).get():e,h=a(u),f=!1!==h.auto,p=h.min,d=h.max,g=h.mid,v=function(){return i.aggNums(Math.min,null,l)},m=function(){return i.aggNums(Math.max,null,l)};(void 0===p?p=v():f&&(p=u._colorAx&&n(p)?Math.min(p,v()):v()),void 0===d?d=m():f&&(d=u._colorAx&&n(d)?Math.max(d,m()):m()),f&&void 0!==g&&(d-g>g-p?p=g-(d-g):d-g<g-p&&(d=g+(g-p))),p===d&&(p-=.5,d+=.5),h._sync(\"min\",p),h._sync(\"max\",d),h.autocolorscale)&&(o=p*d<0?s.colorscale.diverging:p>=0?s.colorscale.sequential:s.colorscale.sequentialminus,h._sync(\"colorscale\",o))}},{\"../../lib\":719,\"./helpers\":604,\"fast-isnumeric\":225}],602:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./helpers\").hasColorscale,a=t(\"./helpers\").extractOpts;e.exports=function(t,e){function r(t,e){var r=t[\"_\"+e];void 0!==r&&(t[e]=r)}function o(t,i){var o=i.container?n.nestedProperty(t,i.container).get():t;if(o)if(o.coloraxis)o._colorAx=e[o.coloraxis];else{var s=a(o),l=s.auto;(l||void 0===s.min)&&r(o,i.min),(l||void 0===s.max)&&r(o,i.max),s.autocolorscale&&r(o,\"colorscale\")}}for(var s=0;s<t.length;s++){var l=t[s],c=l._module.colorbar;if(c)if(Array.isArray(c))for(var u=0;u<c.length;u++)o(l,c[u]);else o(l,c);i(l,\"marker.line\")&&o(l,{container:\"marker.line\",min:\"cmin\",max:\"cmax\"})}for(var h in e._colorAxes)o(e[h],{min:\"cmin\",max:\"cmax\"})}},{\"../../lib\":719,\"./helpers\":604}],603:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../colorbar/has_colorbar\"),o=t(\"../colorbar/defaults\"),s=t(\"./scales\").isValid,l=t(\"../../registry\").traceIs;function c(t,e){var r=e.slice(0,e.length-1);return e?i.nestedProperty(t,r).get()||{}:t}e.exports=function t(e,r,u,h,f){var p=f.prefix,d=f.cLetter,g=\"_module\"in r,v=c(e,p),m=c(r,p),y=c(r._template||{},p)||{},x=function(){return delete e.coloraxis,delete r.coloraxis,t(e,r,u,h,f)};if(g){var b=u._colorAxes||{},_=h(p+\"coloraxis\");if(_){var w=l(r,\"contour\")&&i.nestedProperty(r,\"contours.coloring\").get()||\"heatmap\",k=b[_];return void(k?(k[2].push(x),k[0]!==w&&(k[0]=!1,i.warn([\"Ignoring coloraxis:\",_,\"setting\",\"as it is linked to incompatible colorscales.\"].join(\" \")))):b[_]=[w,r,[x]])}}var T=v[d+\"min\"],A=v[d+\"max\"],M=n(T)&&n(A)&&T<A;h(p+d+\"auto\",!M)?h(p+d+\"mid\"):(h(p+d+\"min\"),h(p+d+\"max\"));var S,E,C=v.colorscale,L=y.colorscale;(void 0!==C&&(S=!s(C)),void 0!==L&&(S=!s(L)),h(p+\"autocolorscale\",S),h(p+\"colorscale\"),h(p+\"reversescale\"),\"marker.line.\"!==p)&&(p&&g&&(E=a(v)),h(p+\"showscale\",E)&&o(v,m,u))}},{\"../../lib\":719,\"../../registry\":847,\"../colorbar/defaults\":596,\"../colorbar/has_colorbar\":598,\"./scales\":608,\"fast-isnumeric\":225}],604:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"fast-isnumeric\"),o=t(\"../../lib\"),s=t(\"../color\"),l=t(\"./scales\").isValid;var c=[\"showscale\",\"autocolorscale\",\"colorscale\",\"reversescale\",\"colorbar\"],u=[\"min\",\"max\",\"mid\",\"auto\"];function h(t){var e,r,n,i=t._colorAx,a=i||t,o={};for(r=0;r<c.length;r++)o[n=c[r]]=a[n];if(i)for(e=\"c\",r=0;r<u.length;r++)o[n=u[r]]=a[\"c\"+n];else{var s;for(r=0;r<u.length;r++)(s=\"c\"+(n=u[r]))in a?o[n]=a[s]:(s=\"z\"+n)in a&&(o[n]=a[s]);e=s.charAt(0)}return o._sync=function(t,r){var n=-1!==u.indexOf(t)?e+t:t;a[n]=a[\"_\"+n]=r},o}function f(t){for(var e=h(t),r=e.min,n=e.max,i=e.reversescale?p(e.colorscale):e.colorscale,a=i.length,o=new Array(a),s=new Array(a),l=0;l<a;l++){var c=i[l];o[l]=r+c[0]*(n-r),s[l]=c[1]}return{domain:o,range:s}}function p(t){for(var e=t.length,r=new Array(e),n=e-1,i=0;n>=0;n--,i++){var a=t[n];r[i]=[1-a[0],a[1]]}return r}function d(t,e){e=e||{};for(var r=t.domain,o=t.range,l=o.length,c=new Array(l),u=0;u<l;u++){var h=i(o[u]).toRgb();c[u]=[h.r,h.g,h.b,h.a]}var f,p=n.scale.linear().domain(r).range(c).clamp(!0),d=e.noNumericCheck,v=e.returnArray;return(f=d&&v?p:d?function(t){return g(p(t))}:v?function(t){return a(t)?p(t):i(t).isValid()?t:s.defaultLine}:function(t){return a(t)?g(p(t)):i(t).isValid()?t:s.defaultLine}).domain=p.domain,f.range=function(){return o},f}function g(t){var e={r:t[0],g:t[1],b:t[2],a:t[3]};return i(e).toRgbString()}e.exports={hasColorscale:function(t,e){var r=e?o.nestedProperty(t,e).get()||{}:t,n=r.color,i=!1;if(o.isArrayOrTypedArray(n))for(var s=0;s<n.length;s++)if(a(n[s])){i=!0;break}return o.isPlainObject(r)&&(i||!0===r.showscale||a(r.cmin)&&a(r.cmax)||l(r.colorscale)||o.isPlainObject(r.colorbar))},extractOpts:h,extractScale:f,flipScale:p,makeColorScaleFunc:d,makeColorScaleFuncFromTrace:function(t,e){return d(f(t),e)}}},{\"../../lib\":719,\"../color\":593,\"./scales\":608,d3:163,\"fast-isnumeric\":225,tinycolor2:537}],605:[function(t,e,r){\"use strict\";var n=t(\"./scales\"),i=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"colorscale\",attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),handleDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\"),scales:n.scales,defaultScale:n.defaultScale,getScale:n.get,isValidScale:n.isValid,hasColorscale:i.hasColorscale,extractOpts:i.extractOpts,extractScale:i.extractScale,flipScale:i.flipScale,makeColorScaleFunc:i.makeColorScaleFunc,makeColorScaleFuncFromTrace:i.makeColorScaleFuncFromTrace}},{\"./attributes\":600,\"./calc\":601,\"./cross_trace_defaults\":602,\"./defaults\":603,\"./helpers\":604,\"./layout_attributes\":606,\"./layout_defaults\":607,\"./scales\":608}],606:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"./attributes\"),a=t(\"./scales\").scales;e.exports={editType:\"calc\",colorscale:{editType:\"calc\",sequential:{valType:\"colorscale\",dflt:a.Reds,editType:\"calc\"},sequentialminus:{valType:\"colorscale\",dflt:a.Blues,editType:\"calc\"},diverging:{valType:\"colorscale\",dflt:a.RdBu,editType:\"calc\"}},coloraxis:n({_isSubplotObj:!0,editType:\"calc\"},i(\"\",{colorAttr:\"corresponding trace color array(s)\",noColorAxis:!0,showScaleDflt:!0}))}},{\"../../lib/extend\":710,\"./attributes\":600,\"./scales\":608}],607:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"./layout_attributes\"),o=t(\"./defaults\");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r(\"colorscale.sequential\"),r(\"colorscale.sequentialminus\"),r(\"colorscale.diverging\");var s,l,c=e._colorAxes;function u(t,e){return n.coerce(s,l,a.coloraxis,t,e)}for(var h in c){var f=c[h];if(f[0])s=t[h]||{},(l=i.newContainer(e,h,\"coloraxis\"))._name=h,o(s,l,e,u,{prefix:\"\",cLetter:\"c\"});else{for(var p=0;p<f[2].length;p++)f[2][p]();delete e._colorAxes[h]}}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"./defaults\":603,\"./layout_attributes\":606}],608:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i={Greys:[[0,\"rgb(0,0,0)\"],[1,\"rgb(255,255,255)\"]],YlGnBu:[[0,\"rgb(8,29,88)\"],[.125,\"rgb(37,52,148)\"],[.25,\"rgb(34,94,168)\"],[.375,\"rgb(29,145,192)\"],[.5,\"rgb(65,182,196)\"],[.625,\"rgb(127,205,187)\"],[.75,\"rgb(199,233,180)\"],[.875,\"rgb(237,248,217)\"],[1,\"rgb(255,255,217)\"]],Greens:[[0,\"rgb(0,68,27)\"],[.125,\"rgb(0,109,44)\"],[.25,\"rgb(35,139,69)\"],[.375,\"rgb(65,171,93)\"],[.5,\"rgb(116,196,118)\"],[.625,\"rgb(161,217,155)\"],[.75,\"rgb(199,233,192)\"],[.875,\"rgb(229,245,224)\"],[1,\"rgb(247,252,245)\"]],YlOrRd:[[0,\"rgb(128,0,38)\"],[.125,\"rgb(189,0,38)\"],[.25,\"rgb(227,26,28)\"],[.375,\"rgb(252,78,42)\"],[.5,\"rgb(253,141,60)\"],[.625,\"rgb(254,178,76)\"],[.75,\"rgb(254,217,118)\"],[.875,\"rgb(255,237,160)\"],[1,\"rgb(255,255,204)\"]],Bluered:[[0,\"rgb(0,0,255)\"],[1,\"rgb(255,0,0)\"]],RdBu:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(106,137,247)\"],[.5,\"rgb(190,190,190)\"],[.6,\"rgb(220,170,132)\"],[.7,\"rgb(230,145,90)\"],[1,\"rgb(178,10,28)\"]],Reds:[[0,\"rgb(220,220,220)\"],[.2,\"rgb(245,195,157)\"],[.4,\"rgb(245,160,105)\"],[1,\"rgb(178,10,28)\"]],Blues:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(40,60,190)\"],[.5,\"rgb(70,100,245)\"],[.6,\"rgb(90,120,245)\"],[.7,\"rgb(106,137,247)\"],[1,\"rgb(220,220,220)\"]],Picnic:[[0,\"rgb(0,0,255)\"],[.1,\"rgb(51,153,255)\"],[.2,\"rgb(102,204,255)\"],[.3,\"rgb(153,204,255)\"],[.4,\"rgb(204,204,255)\"],[.5,\"rgb(255,255,255)\"],[.6,\"rgb(255,204,255)\"],[.7,\"rgb(255,153,255)\"],[.8,\"rgb(255,102,204)\"],[.9,\"rgb(255,102,102)\"],[1,\"rgb(255,0,0)\"]],Rainbow:[[0,\"rgb(150,0,90)\"],[.125,\"rgb(0,0,200)\"],[.25,\"rgb(0,25,255)\"],[.375,\"rgb(0,152,255)\"],[.5,\"rgb(44,255,150)\"],[.625,\"rgb(151,255,0)\"],[.75,\"rgb(255,234,0)\"],[.875,\"rgb(255,111,0)\"],[1,\"rgb(255,0,0)\"]],Portland:[[0,\"rgb(12,51,131)\"],[.25,\"rgb(10,136,186)\"],[.5,\"rgb(242,211,56)\"],[.75,\"rgb(242,143,56)\"],[1,\"rgb(217,30,30)\"]],Jet:[[0,\"rgb(0,0,131)\"],[.125,\"rgb(0,60,170)\"],[.375,\"rgb(5,255,255)\"],[.625,\"rgb(255,255,0)\"],[.875,\"rgb(250,0,0)\"],[1,\"rgb(128,0,0)\"]],Hot:[[0,\"rgb(0,0,0)\"],[.3,\"rgb(230,0,0)\"],[.6,\"rgb(255,210,0)\"],[1,\"rgb(255,255,255)\"]],Blackbody:[[0,\"rgb(0,0,0)\"],[.2,\"rgb(230,0,0)\"],[.4,\"rgb(230,210,0)\"],[.7,\"rgb(255,255,255)\"],[1,\"rgb(160,200,255)\"]],Earth:[[0,\"rgb(0,0,130)\"],[.1,\"rgb(0,180,180)\"],[.2,\"rgb(40,210,40)\"],[.4,\"rgb(230,230,50)\"],[.6,\"rgb(120,70,20)\"],[1,\"rgb(255,255,255)\"]],Electric:[[0,\"rgb(0,0,0)\"],[.15,\"rgb(30,0,100)\"],[.4,\"rgb(120,0,100)\"],[.6,\"rgb(160,90,0)\"],[.8,\"rgb(230,200,0)\"],[1,\"rgb(255,250,220)\"]],Viridis:[[0,\"#440154\"],[.06274509803921569,\"#48186a\"],[.12549019607843137,\"#472d7b\"],[.18823529411764706,\"#424086\"],[.25098039215686274,\"#3b528b\"],[.3137254901960784,\"#33638d\"],[.3764705882352941,\"#2c728e\"],[.4392156862745098,\"#26828e\"],[.5019607843137255,\"#21918c\"],[.5647058823529412,\"#1fa088\"],[.6274509803921569,\"#28ae80\"],[.6901960784313725,\"#3fbc73\"],[.7529411764705882,\"#5ec962\"],[.8156862745098039,\"#84d44b\"],[.8784313725490196,\"#addc30\"],[.9411764705882353,\"#d8e219\"],[1,\"#fde725\"]],Cividis:[[0,\"rgb(0,32,76)\"],[.058824,\"rgb(0,42,102)\"],[.117647,\"rgb(0,52,110)\"],[.176471,\"rgb(39,63,108)\"],[.235294,\"rgb(60,74,107)\"],[.294118,\"rgb(76,85,107)\"],[.352941,\"rgb(91,95,109)\"],[.411765,\"rgb(104,106,112)\"],[.470588,\"rgb(117,117,117)\"],[.529412,\"rgb(131,129,120)\"],[.588235,\"rgb(146,140,120)\"],[.647059,\"rgb(161,152,118)\"],[.705882,\"rgb(176,165,114)\"],[.764706,\"rgb(192,177,109)\"],[.823529,\"rgb(209,191,102)\"],[.882353,\"rgb(225,204,92)\"],[.941176,\"rgb(243,219,79)\"],[1,\"rgb(255,233,69)\"]]},a=i.RdBu;function o(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var i=t[r];if(2!==i.length||+i[0]<e||!n(i[1]).isValid())return!1;e=+i[0]}return!0}e.exports={scales:i,defaultScale:a,get:function(t,e){if(e||(e=a),!t)return e;function r(){try{t=i[t]||JSON.parse(t)}catch(r){t=e}}return\"string\"==typeof t&&(r(),\"string\"==typeof t&&r()),o(t)?t:e},isValid:function(t){return void 0!==i[t]||o(t)}}},{tinycolor2:537}],609:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=(t-r)/(n-r),o=a+e/(n-r),s=(a+o)/2;return\"left\"===i||\"bottom\"===i?a:\"center\"===i||\"middle\"===i?s:\"right\"===i||\"top\"===i?o:a<2/3-s?a:o>4/3-s?o:s}},{}],610:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[\"sw-resize\",\"s-resize\",\"se-resize\"],[\"w-resize\",\"move\",\"e-resize\"],[\"nw-resize\",\"n-resize\",\"ne-resize\"]];e.exports=function(t,e,r,a){return t=\"left\"===r?0:\"center\"===r?1:\"right\"===r?2:n.constrain(Math.floor(3*t),0,2),e=\"bottom\"===a?0:\"middle\"===a?1:\"top\"===a?2:n.constrain(Math.floor(3*e),0,2),i[e][t]}},{\"../../lib\":719}],611:[function(t,e,r){\"use strict\";var n=t(\"mouse-event-offset\"),i=t(\"has-hover\"),a=t(\"has-passive-events\"),o=t(\"../../lib\").removeElement,s=t(\"../../plots/cartesian/constants\"),l=e.exports={};l.align=t(\"./align\"),l.getCursor=t(\"./cursor\");var c=t(\"./unhover\");function u(){var t=document.createElement(\"div\");t.className=\"dragcover\";var e=t.style;return e.position=\"fixed\",e.left=0,e.right=0,e.top=0,e.bottom=0,e.zIndex=999999999,e.background=\"none\",document.body.appendChild(t),t}function h(t){return n(t.changedTouches?t.changedTouches[0]:t,document.body)}l.unhover=c.wrapped,l.unhoverRaw=c.raw,l.init=function(t){var e,r,n,c,f,p,d,g,v=t.gd,m=1,y=v._context.doubleClickDelay,x=t.element;v._mouseDownTime||(v._mouseDownTime=0),x.style.pointerEvents=\"all\",x.onmousedown=_,a?(x._ontouchstart&&x.removeEventListener(\"touchstart\",x._ontouchstart),x._ontouchstart=_,x.addEventListener(\"touchstart\",_,{passive:!1})):x.ontouchstart=_;var b=t.clampFn||function(t,e,r){return Math.abs(t)<r&&(t=0),Math.abs(e)<r&&(e=0),[t,e]};function _(a){v._dragged=!1,v._dragging=!0;var o=h(a);e=o[0],r=o[1],d=a.target,p=a,g=2===a.buttons||a.ctrlKey,\"undefined\"==typeof a.clientX&&\"undefined\"==typeof a.clientY&&(a.clientX=e,a.clientY=r),(n=(new Date).getTime())-v._mouseDownTime<y?m+=1:(m=1,v._mouseDownTime=n),t.prepFn&&t.prepFn(a,e,r),i&&!g?(f=u()).style.cursor=window.getComputedStyle(x).cursor:i||(f=document,c=window.getComputedStyle(document.documentElement).cursor,document.documentElement.style.cursor=window.getComputedStyle(x).cursor),document.addEventListener(\"mouseup\",k),document.addEventListener(\"touchend\",k),!1!==t.dragmode&&(a.preventDefault(),document.addEventListener(\"mousemove\",w),document.addEventListener(\"touchmove\",w))}function w(n){n.preventDefault();var i=h(n),a=t.minDrag||s.MINDRAG,o=b(i[0]-e,i[1]-r,a),c=o[0],u=o[1];(c||u)&&(v._dragged=!0,l.unhover(v)),v._dragged&&t.moveFn&&!g&&(v._dragdata={element:x,dx:c,dy:u},t.moveFn(c,u))}function k(e){if(delete v._dragdata,!1!==t.dragmode&&(e.preventDefault(),document.removeEventListener(\"mousemove\",w),document.removeEventListener(\"touchmove\",w)),document.removeEventListener(\"mouseup\",k),document.removeEventListener(\"touchend\",k),i?o(f):c&&(f.documentElement.style.cursor=c,c=null),v._dragging){if(v._dragging=!1,(new Date).getTime()-v._mouseDownTime>y&&(m=Math.max(m-1,1)),v._dragged)t.doneFn&&t.doneFn();else if(t.clickFn&&t.clickFn(m,p),!g){var r;try{r=new MouseEvent(\"click\",e)}catch(t){var n=h(e);(r=document.createEvent(\"MouseEvents\")).initMouseEvent(\"click\",e.bubbles,e.cancelable,e.view,e.detail,e.screenX,e.screenY,n[0],n[1],e.ctrlKey,e.altKey,e.shiftKey,e.metaKey,e.button,e.relatedTarget)}d.dispatchEvent(r)}v._dragging=!1,v._dragged=!1}else v._dragged=!1}},l.coverSlip=u},{\"../../lib\":719,\"../../plots/cartesian/constants\":773,\"./align\":609,\"./cursor\":610,\"./unhover\":612,\"has-hover\":410,\"has-passive-events\":411,\"mouse-event-offset\":436}],612:[function(t,e,r){\"use strict\";var n=t(\"../../lib/events\"),i=t(\"../../lib/throttle\"),a=t(\"../../lib/dom\").getGraphDiv,o=t(\"../fx/constants\"),s=e.exports={};s.wrapped=function(t,e,r){(t=a(t))._fullLayout&&i.clear(t._fullLayout._uid+o.HOVERID),s.raw(t,e,r)},s.raw=function(t,e){var r=t._fullLayout,i=t._hoverdata;e||(e={}),e.target&&!1===n.triggerHandler(t,\"plotly_beforehover\",e)||(r._hoverlayer.selectAll(\"g\").remove(),r._hoverlayer.selectAll(\"line\").remove(),r._hoverlayer.selectAll(\"circle\").remove(),t._hoverdata=void 0,e.target&&i&&t.emit(\"plotly_unhover\",{event:e,points:i}))}},{\"../../lib/dom\":708,\"../../lib/events\":709,\"../../lib/throttle\":744,\"../fx/constants\":626}],613:[function(t,e,r){\"use strict\";r.dash={valType:\"string\",values:[\"solid\",\"dot\",\"dash\",\"longdash\",\"dashdot\",\"longdashdot\"],dflt:\"solid\",editType:\"style\"}},{}],614:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../registry\"),s=t(\"../color\"),l=t(\"../colorscale\"),c=t(\"../../lib\"),u=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/xmlns_namespaces\"),f=t(\"../../constants/alignment\").LINE_SPACING,p=t(\"../../constants/interactions\").DESELECTDIM,d=t(\"../../traces/scatter/subtypes\"),g=t(\"../../traces/scatter/make_bubble_size_func\"),v=e.exports={};v.font=function(t,e,r,n){c.isPlainObject(e)&&(n=e.color,r=e.size,e=e.family),e&&t.style(\"font-family\",e),r+1&&t.style(\"font-size\",r+\"px\"),n&&t.call(s.fill,n)},v.setPosition=function(t,e,r){t.attr(\"x\",e).attr(\"y\",r)},v.setSize=function(t,e,r){t.attr(\"width\",e).attr(\"height\",r)},v.setRect=function(t,e,r,n,i){t.call(v.setPosition,e,r).call(v.setSize,n,i)},v.translatePoint=function(t,e,r,n){var a=r.c2p(t.x),o=n.c2p(t.y);return!!(i(a)&&i(o)&&e.node())&&(\"text\"===e.node().nodeName?e.attr(\"x\",a).attr(\"y\",o):e.attr(\"transform\",\"translate(\"+a+\",\"+o+\")\"),!0)},v.translatePoints=function(t,e,r){t.each(function(t){var i=n.select(this);v.translatePoint(t,i,e,r)})},v.hideOutsideRangePoint=function(t,e,r,n,i,a){e.attr(\"display\",r.isPtWithinRange(t,i)&&n.isPtWithinRange(t,a)?null:\"none\")},v.hideOutsideRangePoints=function(t,e){if(e._hasClipOnAxisFalse){var r=e.xaxis,i=e.yaxis;t.each(function(e){var a=e[0].trace,s=a.xcalendar,l=a.ycalendar,c=o.traceIs(a,\"bar-like\")?\".bartext\":\".point,.textpoint\";t.selectAll(c).each(function(t){v.hideOutsideRangePoint(t,n.select(this),r,i,s,l)})})}},v.crispRound=function(t,e,r){return e&&i(e)?t._context.staticPlot?e:e<1?1:Math.round(e):r||0},v.singleLineStyle=function(t,e,r,n,i){e.style(\"fill\",\"none\");var a=(((t||[])[0]||{}).trace||{}).line||{},o=r||a.width||0,l=i||a.dash||\"\";s.stroke(e,n||a.color),v.dashLine(e,l,o)},v.lineGroupStyle=function(t,e,r,i){t.style(\"fill\",\"none\").each(function(t){var a=(((t||[])[0]||{}).trace||{}).line||{},o=e||a.width||0,l=i||a.dash||\"\";n.select(this).call(s.stroke,r||a.color).call(v.dashLine,l,o)})},v.dashLine=function(t,e,r){r=+r||0,e=v.dashStyle(e,r),t.style({\"stroke-dasharray\":e,\"stroke-width\":r+\"px\"})},v.dashStyle=function(t,e){e=+e||1;var r=Math.max(e,3);return\"solid\"===t?t=\"\":\"dot\"===t?t=r+\"px,\"+r+\"px\":\"dash\"===t?t=3*r+\"px,\"+3*r+\"px\":\"longdash\"===t?t=5*r+\"px,\"+5*r+\"px\":\"dashdot\"===t?t=3*r+\"px,\"+r+\"px,\"+r+\"px,\"+r+\"px\":\"longdashdot\"===t&&(t=5*r+\"px,\"+2*r+\"px,\"+r+\"px,\"+2*r+\"px\"),t},v.singleFillStyle=function(t){var e=(((n.select(t.node()).data()[0]||[])[0]||{}).trace||{}).fillcolor;e&&t.call(s.fill,e)},v.fillGroupStyle=function(t){t.style(\"stroke-width\",0).each(function(t){var e=n.select(this);t[0].trace&&e.call(s.fill,t[0].trace.fillcolor)})};var m=t(\"./symbol_defs\");v.symbolNames=[],v.symbolFuncs=[],v.symbolNeedLines={},v.symbolNoDot={},v.symbolNoFill={},v.symbolList=[],Object.keys(m).forEach(function(t){var e=m[t];v.symbolList=v.symbolList.concat([e.n,t,e.n+100,t+\"-open\"]),v.symbolNames[e.n]=t,v.symbolFuncs[e.n]=e.f,e.needLine&&(v.symbolNeedLines[e.n]=!0),e.noDot?v.symbolNoDot[e.n]=!0:v.symbolList=v.symbolList.concat([e.n+200,t+\"-dot\",e.n+300,t+\"-open-dot\"]),e.noFill&&(v.symbolNoFill[e.n]=!0)});var y=v.symbolNames.length,x=\"M0,0.5L0.5,0L0,-0.5L-0.5,0Z\";function b(t,e){var r=t%100;return v.symbolFuncs[r](e)+(t>=200?x:\"\")}v.symbolNumber=function(t){if(\"string\"==typeof t){var e=0;t.indexOf(\"-open\")>0&&(e=100,t=t.replace(\"-open\",\"\")),t.indexOf(\"-dot\")>0&&(e+=200,t=t.replace(\"-dot\",\"\")),(t=v.symbolNames.indexOf(t))>=0&&(t+=e)}return t%100>=y||t>=400?0:Math.floor(Math.max(t,0))};var _={x1:1,x2:0,y1:0,y2:0},w={x1:0,x2:0,y1:1,y2:0},k=n.format(\"~.1f\"),T={radial:{node:\"radialGradient\"},radialreversed:{node:\"radialGradient\",reversed:!0},horizontal:{node:\"linearGradient\",attrs:_},horizontalreversed:{node:\"linearGradient\",attrs:_,reversed:!0},vertical:{node:\"linearGradient\",attrs:w},verticalreversed:{node:\"linearGradient\",attrs:w,reversed:!0}};v.gradient=function(t,e,r,i,o,l){for(var u=o.length,h=T[i],f=new Array(u),p=0;p<u;p++)h.reversed?f[u-1-p]=[k(100*(1-o[p][0])),o[p][1]]:f[p]=[k(100*o[p][0]),o[p][1]];var d=\"g\"+e._fullLayout._uid+\"-\"+r,g=e._fullLayout._defs.select(\".gradients\").selectAll(\"#\"+d).data([i+f.join(\";\")],c.identity);g.exit().remove(),g.enter().append(h.node).each(function(){var t=n.select(this);h.attrs&&t.attr(h.attrs),t.attr(\"id\",d);var e=t.selectAll(\"stop\").data(f);e.exit().remove(),e.enter().append(\"stop\"),e.each(function(t){var e=a(t[1]);n.select(this).attr({offset:t[0]+\"%\",\"stop-color\":s.tinyRGB(e),\"stop-opacity\":e.getAlpha()})})}),t.style(l,I(d,e)).style(l+\"-opacity\",null)},v.initGradients=function(t){c.ensureSingle(t._fullLayout._defs,\"g\",\"gradients\").selectAll(\"linearGradient,radialGradient\").remove()},v.pointStyle=function(t,e,r){if(t.size()){var i=v.makePointStyleFns(e);t.each(function(t){v.singlePointStyle(t,n.select(this),e,i,r)})}},v.singlePointStyle=function(t,e,r,n,i){var a=r.marker,o=a.line;if(e.style(\"opacity\",n.selectedOpacityFn?n.selectedOpacityFn(t):void 0===t.mo?a.opacity:t.mo),n.ms2mrc){var l;l=\"various\"===t.ms||\"various\"===a.size?3:n.ms2mrc(t.ms),t.mrc=l,n.selectedSizeFn&&(l=t.mrc=n.selectedSizeFn(t));var u=v.symbolNumber(t.mx||a.symbol)||0;t.om=u%200>=100,e.attr(\"d\",b(u,l))}var h,f,p,d=!1;if(t.so)p=o.outlierwidth,f=o.outliercolor,h=a.outliercolor;else{var g=(o||{}).width;p=(t.mlw+1||g+1||(t.trace?(t.trace.marker.line||{}).width:0)+1)-1||0,f=\"mlc\"in t?t.mlcc=n.lineScale(t.mlc):c.isArrayOrTypedArray(o.color)?s.defaultLine:o.color,c.isArrayOrTypedArray(a.color)&&(h=s.defaultLine,d=!0),h=\"mc\"in t?t.mcc=n.markerScale(t.mc):a.color||\"rgba(0,0,0,0)\",n.selectedColorFn&&(h=n.selectedColorFn(t))}if(t.om)e.call(s.stroke,h).style({\"stroke-width\":(p||1)+\"px\",fill:\"none\"});else{e.style(\"stroke-width\",p+\"px\");var m=a.gradient,y=t.mgt;if(y?d=!0:y=m&&m.type,Array.isArray(y)&&(y=y[0],T[y]||(y=0)),y&&\"none\"!==y){var x=t.mgc;x?d=!0:x=m.color;var _=r.uid;d&&(_+=\"-\"+t.i),v.gradient(e,i,_,y,[[0,x],[1,h]],\"fill\")}else s.fill(e,h);p&&s.stroke(e,f)}},v.makePointStyleFns=function(t){var e={},r=t.marker;return e.markerScale=v.tryColorscale(r,\"\"),e.lineScale=v.tryColorscale(r,\"line\"),o.traceIs(t,\"symbols\")&&(e.ms2mrc=d.isBubble(t)?g(t):function(){return(r.size||6)/2}),t.selectedpoints&&c.extendFlat(e,v.makeSelectedPointStyleFns(t)),e},v.makeSelectedPointStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.marker||{},a=r.marker||{},s=n.marker||{},l=i.opacity,u=a.opacity,h=s.opacity,f=void 0!==u,d=void 0!==h;(c.isArrayOrTypedArray(l)||f||d)&&(e.selectedOpacityFn=function(t){var e=void 0===t.mo?i.opacity:t.mo;return t.selected?f?u:e:d?h:p*e});var g=i.color,v=a.color,m=s.color;(v||m)&&(e.selectedColorFn=function(t){var e=t.mcc||g;return t.selected?v||e:m||e});var y=i.size,x=a.size,b=s.size,_=void 0!==x,w=void 0!==b;return o.traceIs(t,\"symbols\")&&(_||w)&&(e.selectedSizeFn=function(t){var e=t.mrc||y/2;return t.selected?_?x/2:e:w?b/2:e}),e},v.makeSelectedTextStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.textfont||{},a=r.textfont||{},o=n.textfont||{},l=i.color,c=a.color,u=o.color;return e.selectedTextColorFn=function(t){var e=t.tc||l;return t.selected?c||e:u||(c?e:s.addOpacity(e,p))},e},v.selectedPointStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=v.makeSelectedPointStyleFns(e),i=e.marker||{},a=[];r.selectedOpacityFn&&a.push(function(t,e){t.style(\"opacity\",r.selectedOpacityFn(e))}),r.selectedColorFn&&a.push(function(t,e){s.fill(t,r.selectedColorFn(e))}),r.selectedSizeFn&&a.push(function(t,e){var n=e.mx||i.symbol||0,a=r.selectedSizeFn(e);t.attr(\"d\",b(v.symbolNumber(n),a)),e.mrc2=a}),a.length&&t.each(function(t){for(var e=n.select(this),r=0;r<a.length;r++)a[r](e,t)})}},v.tryColorscale=function(t,e){var r=e?c.nestedProperty(t,e).get():t;if(r){var n=r.color;if((r.colorscale||r._colorAx)&&c.isArrayOrTypedArray(n))return l.makeColorScaleFuncFromTrace(r)}return c.identity};var A={start:1,end:-1,middle:0,bottom:1,top:-1};function M(t,e,r,i){var a=n.select(t.node().parentNode),o=-1!==e.indexOf(\"top\")?\"top\":-1!==e.indexOf(\"bottom\")?\"bottom\":\"middle\",s=-1!==e.indexOf(\"left\")?\"end\":-1!==e.indexOf(\"right\")?\"start\":\"middle\",l=i?i/.8+1:0,c=(u.lineCount(t)-1)*f+1,h=A[s]*l,p=.75*r+A[o]*l+(A[o]-1)*c*r/2;t.attr(\"text-anchor\",s),a.attr(\"transform\",\"translate(\"+h+\",\"+p+\")\")}function S(t,e){var r=t.ts||e.textfont.size;return i(r)&&r>0?r:0}v.textPointStyle=function(t,e,r){if(t.size()){var i;if(e.selectedpoints){var a=v.makeSelectedTextStyleFns(e);i=a.selectedTextColorFn}t.each(function(t){var a=n.select(this),o=c.extractOption(t,e,\"tx\",\"text\");if(o||0===o){var s=t.tp||e.textposition,l=S(t,e),h=i?i(t):t.tc||e.textfont.color;a.call(v.font,t.tf||e.textfont.family,l,h).text(o).call(u.convertToTspans,r).call(M,s,l,t.mrc)}else a.remove()})}},v.selectedTextStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=v.makeSelectedTextStyleFns(e);t.each(function(t){var i=n.select(this),a=r.selectedTextColorFn(t),o=t.tp||e.textposition,l=S(t,e);s.fill(i,a),M(i,o,l,t.mrc2||t.mrc)})}};var E=.5;function C(t,e,r,i){var a=t[0]-e[0],o=t[1]-e[1],s=r[0]-e[0],l=r[1]-e[1],c=Math.pow(a*a+o*o,E/2),u=Math.pow(s*s+l*l,E/2),h=(u*u*a-c*c*s)*i,f=(u*u*o-c*c*l)*i,p=3*u*(c+u),d=3*c*(c+u);return[[n.round(e[0]+(p&&h/p),2),n.round(e[1]+(p&&f/p),2)],[n.round(e[0]-(d&&h/d),2),n.round(e[1]-(d&&f/d),2)]]}v.smoothopen=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\");var r,n=\"M\"+t[0],i=[];for(r=1;r<t.length-1;r++)i.push(C(t[r-1],t[r],t[r+1],e));for(n+=\"Q\"+i[0][0]+\" \"+t[1],r=2;r<t.length-1;r++)n+=\"C\"+i[r-2][1]+\" \"+i[r-1][0]+\" \"+t[r];return n+=\"Q\"+i[t.length-3][1]+\" \"+t[t.length-1]},v.smoothclosed=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\")+\"Z\";var r,n=\"M\"+t[0],i=t.length-1,a=[C(t[i],t[0],t[1],e)];for(r=1;r<i;r++)a.push(C(t[r-1],t[r],t[r+1],e));for(a.push(C(t[i-1],t[i],t[0],e)),r=1;r<=i;r++)n+=\"C\"+a[r-1][1]+\" \"+a[r][0]+\" \"+t[r];return n+=\"C\"+a[i][1]+\" \"+a[0][0]+\" \"+t[0]+\"Z\"};var L={hv:function(t,e){return\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)},vh:function(t,e){return\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},hvh:function(t,e){return\"H\"+n.round((t[0]+e[0])/2,2)+\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},vhv:function(t,e){return\"V\"+n.round((t[1]+e[1])/2,2)+\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)}},P=function(t,e){return\"L\"+n.round(e[0],2)+\",\"+n.round(e[1],2)};v.steps=function(t){var e=L[t]||P;return function(t){for(var r=\"M\"+n.round(t[0][0],2)+\",\"+n.round(t[0][1],2),i=1;i<t.length;i++)r+=e(t[i-1],t[i]);return r}},v.makeTester=function(){var t=c.ensureSingleById(n.select(\"body\"),\"svg\",\"js-plotly-tester\",function(t){t.attr(h.svgAttrs).style({position:\"absolute\",left:\"-10000px\",top:\"-10000px\",width:\"9000px\",height:\"9000px\",\"z-index\":\"1\"})}),e=c.ensureSingle(t,\"path\",\"js-reference-point\",function(t){t.attr(\"d\",\"M0,0H1V1H0Z\").style({\"stroke-width\":0,fill:\"black\"})});v.tester=t,v.testref=e},v.savedBBoxes={};var O=0;function z(t){var e=t.getAttribute(\"data-unformatted\");if(null!==e)return e+t.getAttribute(\"data-math\")+t.getAttribute(\"text-anchor\")+t.getAttribute(\"style\")}function I(t,e){if(!t)return null;var r=e._context;return\"url('\"+(r._exportedPlot?\"\":r._baseUrl||\"\")+\"#\"+t+\"')\"}v.bBox=function(t,e,r){var i,a,o;if(r||(r=z(t)),r){if(i=v.savedBBoxes[r])return c.extendFlat({},i)}else if(1===t.childNodes.length){var s=t.childNodes[0];if(r=z(s)){var l=+s.getAttribute(\"x\")||0,h=+s.getAttribute(\"y\")||0,f=s.getAttribute(\"transform\");if(!f){var p=v.bBox(s,!1,r);return l&&(p.left+=l,p.right+=l),h&&(p.top+=h,p.bottom+=h),p}if(r+=\"~\"+l+\"~\"+h+\"~\"+f,i=v.savedBBoxes[r])return c.extendFlat({},i)}}e?a=t:(o=v.tester.node(),a=t.cloneNode(!0),o.appendChild(a)),n.select(a).attr(\"transform\",null).call(u.positionText,0,0);var d=a.getBoundingClientRect(),g=v.testref.node().getBoundingClientRect();e||o.removeChild(a);var m={height:d.height,width:d.width,left:d.left-g.left,top:d.top-g.top,right:d.right-g.left,bottom:d.bottom-g.top};return O>=1e4&&(v.savedBBoxes={},O=0),r&&(v.savedBBoxes[r]=m),O++,c.extendFlat({},m)},v.setClipUrl=function(t,e,r){t.attr(\"clip-path\",I(e,r))},v.getTranslate=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\btranslate\\((-?\\d*\\.?\\d*)[^-\\d]*(-?\\d*\\.?\\d*)[^\\d].*/,function(t,e,r){return[e,r].join(\" \")}).split(\" \");return{x:+e[0]||0,y:+e[1]||0}},v.setTranslate=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||0,r=r||0,a=a.replace(/(\\btranslate\\(.*?\\);?)/,\"\").trim(),a=(a+=\" translate(\"+e+\", \"+r+\")\").trim(),t[i](\"transform\",a),a},v.getScale=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\bscale\\((\\d*\\.?\\d*)[^\\d]*(\\d*\\.?\\d*)[^\\d].*/,function(t,e,r){return[e,r].join(\" \")}).split(\" \");return{x:+e[0]||1,y:+e[1]||1}},v.setScale=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||1,r=r||1,a=a.replace(/(\\bscale\\(.*?\\);?)/,\"\").trim(),a=(a+=\" scale(\"+e+\", \"+r+\")\").trim(),t[i](\"transform\",a),a};var D=/\\s*sc.*/;v.setPointGroupScale=function(t,e,r){if(e=e||1,r=r||1,t){var n=1===e&&1===r?\"\":\" scale(\"+e+\",\"+r+\")\";t.each(function(){var t=(this.getAttribute(\"transform\")||\"\").replace(D,\"\");t=(t+=n).trim(),this.setAttribute(\"transform\",t)})}};var R=/translate\\([^)]*\\)\\s*$/;v.setTextPointsScale=function(t,e,r){t&&t.each(function(){var t,i=n.select(this),a=i.select(\"text\");if(a.node()){var o=parseFloat(a.attr(\"x\")||0),s=parseFloat(a.attr(\"y\")||0),l=(i.attr(\"transform\")||\"\").match(R);t=1===e&&1===r?[]:[\"translate(\"+o+\",\"+s+\")\",\"scale(\"+e+\",\"+r+\")\",\"translate(\"+-o+\",\"+-s+\")\"],l&&t.push(l),i.attr(\"transform\",t.join(\" \"))}})}},{\"../../constants/alignment\":688,\"../../constants/interactions\":694,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../registry\":847,\"../../traces/scatter/make_bubble_size_func\":1128,\"../../traces/scatter/subtypes\":1135,\"../color\":593,\"../colorscale\":605,\"./symbol_defs\":615,d3:163,\"fast-isnumeric\":225,tinycolor2:537}],615:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports={circle:{n:0,f:function(t){var e=n.round(t,2);return\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"}},square:{n:1,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"}},diamond:{n:2,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"Z\"}},cross:{n:3,f:function(t){var e=n.round(.4*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H\"+e+\"V\"+r+\"H-\"+e+\"V\"+e+\"H-\"+r+\"V-\"+e+\"H-\"+e+\"V-\"+r+\"H\"+e+\"V-\"+e+\"H\"+r+\"Z\"}},x:{n:4,f:function(t){var e=n.round(.8*t/Math.sqrt(2),2),r=\"l\"+e+\",\"+e,i=\"l\"+e+\",-\"+e,a=\"l-\"+e+\",-\"+e,o=\"l-\"+e+\",\"+e;return\"M0,\"+e+r+i+a+i+a+o+a+o+r+o+r+\"Z\"}},\"triangle-up\":{n:5,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",\"+n.round(t/2,2)+\"H\"+e+\"L0,-\"+n.round(t,2)+\"Z\"}},\"triangle-down\":{n:6,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",-\"+n.round(t/2,2)+\"H\"+e+\"L0,\"+n.round(t,2)+\"Z\"}},\"triangle-left\":{n:7,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L-\"+n.round(t,2)+\",0Z\"}},\"triangle-right\":{n:8,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L\"+n.round(t,2)+\",0Z\"}},\"triangle-ne\":{n:9,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+r+\",-\"+e+\"H\"+e+\"V\"+r+\"Z\"}},\"triangle-se\":{n:10,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+e+\",-\"+r+\"V\"+e+\"H-\"+r+\"Z\"}},\"triangle-sw\":{n:11,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H-\"+e+\"V-\"+r+\"Z\"}},\"triangle-nw\":{n:12,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+e+\",\"+r+\"V-\"+e+\"H\"+r+\"Z\"}},pentagon:{n:13,f:function(t){var e=n.round(.951*t,2),r=n.round(.588*t,2),i=n.round(-t,2),a=n.round(-.309*t,2);return\"M\"+e+\",\"+a+\"L\"+r+\",\"+n.round(.809*t,2)+\"H-\"+r+\"L-\"+e+\",\"+a+\"L0,\"+i+\"Z\"}},hexagon:{n:14,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M\"+i+\",-\"+r+\"V\"+r+\"L0,\"+e+\"L-\"+i+\",\"+r+\"V-\"+r+\"L0,-\"+e+\"Z\"}},hexagon2:{n:15,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M-\"+r+\",\"+i+\"H\"+r+\"L\"+e+\",0L\"+r+\",-\"+i+\"H-\"+r+\"L-\"+e+\",0Z\"}},octagon:{n:16,f:function(t){var e=n.round(.924*t,2),r=n.round(.383*t,2);return\"M-\"+r+\",-\"+e+\"H\"+r+\"L\"+e+\",-\"+r+\"V\"+r+\"L\"+r+\",\"+e+\"H-\"+r+\"L-\"+e+\",\"+r+\"V-\"+r+\"Z\"}},star:{n:17,f:function(t){var e=1.4*t,r=n.round(.225*e,2),i=n.round(.951*e,2),a=n.round(.363*e,2),o=n.round(.588*e,2),s=n.round(-e,2),l=n.round(-.309*e,2),c=n.round(.118*e,2),u=n.round(.809*e,2);return\"M\"+r+\",\"+l+\"H\"+i+\"L\"+a+\",\"+c+\"L\"+o+\",\"+u+\"L0,\"+n.round(.382*e,2)+\"L-\"+o+\",\"+u+\"L-\"+a+\",\"+c+\"L-\"+i+\",\"+l+\"H-\"+r+\"L0,\"+s+\"Z\"}},hexagram:{n:18,f:function(t){var e=n.round(.66*t,2),r=n.round(.38*t,2),i=n.round(.76*t,2);return\"M-\"+i+\",0l-\"+r+\",-\"+e+\"h\"+i+\"l\"+r+\",-\"+e+\"l\"+r+\",\"+e+\"h\"+i+\"l-\"+r+\",\"+e+\"l\"+r+\",\"+e+\"h-\"+i+\"l-\"+r+\",\"+e+\"l-\"+r+\",-\"+e+\"h-\"+i+\"Z\"}},\"star-triangle-up\":{n:19,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M-\"+e+\",\"+r+o+e+\",\"+r+o+\"0,-\"+i+o+\"-\"+e+\",\"+r+\"Z\"}},\"star-triangle-down\":{n:20,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M\"+e+\",-\"+r+o+\"-\"+e+\",-\"+r+o+\"0,\"+i+o+e+\",-\"+r+\"Z\"}},\"star-square\":{n:21,f:function(t){var e=n.round(1.1*t,2),r=n.round(2*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",-\"+e+i+\"-\"+e+\",\"+e+i+e+\",\"+e+i+e+\",-\"+e+i+\"-\"+e+\",-\"+e+\"Z\"}},\"star-diamond\":{n:22,f:function(t){var e=n.round(1.4*t,2),r=n.round(1.9*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",0\"+i+\"0,\"+e+i+e+\",0\"+i+\"0,-\"+e+i+\"-\"+e+\",0Z\"}},\"diamond-tall\":{n:23,f:function(t){var e=n.round(.7*t,2),r=n.round(1.4*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},\"diamond-wide\":{n:24,f:function(t){var e=n.round(1.4*t,2),r=n.round(.7*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},hourglass:{n:25,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"L\"+e+\",-\"+e+\"H-\"+e+\"Z\"},noDot:!0},bowtie:{n:26,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"V-\"+e+\"L-\"+e+\",\"+e+\"V-\"+e+\"Z\"},noDot:!0},\"circle-cross\":{n:27,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"circle-x\":{n:28,f:function(t){var e=n.round(t,2),r=n.round(t/Math.sqrt(2),2);return\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"square-cross\":{n:29,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"square-x\":{n:30,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"diamond-cross\":{n:31,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM0,-\"+e+\"V\"+e+\"M-\"+e+\",0H\"+e},needLine:!0,noDot:!0},\"diamond-x\":{n:32,f:function(t){var e=n.round(1.3*t,2),r=n.round(.65*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM-\"+r+\",-\"+r+\"L\"+r+\",\"+r+\"M-\"+r+\",\"+r+\"L\"+r+\",-\"+r},needLine:!0,noDot:!0},\"cross-thin\":{n:33,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"x-thin\":{n:34,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},asterisk:{n:35,f:function(t){var e=n.round(1.2*t,2),r=n.round(.85*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r},needLine:!0,noDot:!0,noFill:!0},hash:{n:36,f:function(t){var e=n.round(t/2,2),r=n.round(t,2);return\"M\"+e+\",\"+r+\"V-\"+r+\"m-\"+r+\",0V\"+r+\"M\"+r+\",\"+e+\"H-\"+r+\"m0,-\"+r+\"H\"+r},needLine:!0,noFill:!0},\"y-up\":{n:37,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",\"+i+\"L0,0M\"+e+\",\"+i+\"L0,0M0,-\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-down\":{n:38,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",-\"+i+\"L0,0M\"+e+\",-\"+i+\"L0,0M0,\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-left\":{n:39,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M\"+i+\",\"+e+\"L0,0M\"+i+\",-\"+e+\"L0,0M-\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-right\":{n:40,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+i+\",\"+e+\"L0,0M-\"+i+\",-\"+e+\"L0,0M\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"line-ew\":{n:41,f:function(t){var e=n.round(1.4*t,2);return\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ns\":{n:42,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ne\":{n:43,f:function(t){var e=n.round(t,2);return\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-nw\":{n:44,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e},needLine:!0,noDot:!0,noFill:!0}}},{d3:163}],616:[function(t,e,r){\"use strict\";e.exports={visible:{valType:\"boolean\",editType:\"calc\"},type:{valType:\"enumerated\",values:[\"percent\",\"constant\",\"sqrt\",\"data\"],editType:\"calc\"},symmetric:{valType:\"boolean\",editType:\"calc\"},array:{valType:\"data_array\",editType:\"calc\"},arrayminus:{valType:\"data_array\",editType:\"calc\"},value:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},valueminus:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},traceref:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},tracerefminus:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},copy_ystyle:{valType:\"boolean\",editType:\"plot\"},copy_zstyle:{valType:\"boolean\",editType:\"style\"},color:{valType:\"color\",editType:\"style\"},thickness:{valType:\"number\",min:0,dflt:2,editType:\"style\"},width:{valType:\"number\",min:0,editType:\"plot\"},editType:\"calc\",_deprecated:{opacity:{valType:\"number\",editType:\"style\"}}}},{}],617:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=t(\"./compute_error\");function l(t,e,r,i){var l=e[\"error_\"+i]||{},c=[];if(l.visible&&-1!==[\"linear\",\"log\"].indexOf(r.type)){for(var u=s(l),h=0;h<t.length;h++){var f=t[h],p=f.i;if(void 0===p)p=h;else if(null===p)continue;var d=f[i];if(n(r.c2l(d))){var g=u(d,p);if(n(g[0])&&n(g[1])){var v=f[i+\"s\"]=d-g[0],m=f[i+\"h\"]=d+g[1];c.push(v,m)}}}var y=r._id,x=e._extremes[y],b=a.findExtremes(r,c,o.extendFlat({tozero:x.opts.tozero},{padded:!0}));x.min=x.min.concat(b.min),x.max=x.max.concat(b.max)}}e.exports=function(t){for(var e=t.calcdata,r=0;r<e.length;r++){var n=e[r],o=n[0].trace;if(!0===o.visible&&i.traceIs(o,\"errorBarsOK\")){var s=a.getFromId(t,o.xaxis),c=a.getFromId(t,o.yaxis);l(n,o,s,\"x\"),l(n,o,c,\"y\")}}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./compute_error\":618,\"fast-isnumeric\":225}],618:[function(t,e,r){\"use strict\";function n(t,e){return\"percent\"===t?function(t){return Math.abs(t*e/100)}:\"constant\"===t?function(){return Math.abs(e)}:\"sqrt\"===t?function(t){return Math.sqrt(Math.abs(t))}:void 0}e.exports=function(t){var e=t.type,r=t.symmetric;if(\"data\"===e){var i=t.array||[];if(r)return function(t,e){var r=+i[e];return[r,r]};var a=t.arrayminus||[];return function(t,e){var r=+i[e],n=+a[e];return isNaN(r)&&isNaN(n)?[NaN,NaN]:[n||0,r||0]}}var o=n(e,t.value),s=n(e,t.valueminus);return r||void 0===t.valueminus?function(t){var e=o(t);return[e,e]}:function(t){return[s(t),o(t)]}}},{}],619:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../plot_api/plot_template\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){var c=\"error_\"+l.axis,u=o.newContainer(e,c),h=t[c]||{};function f(t,e){return a.coerce(h,u,s,t,e)}if(!1!==f(\"visible\",void 0!==h.array||void 0!==h.value||\"sqrt\"===h.type)){var p=f(\"type\",\"array\"in h?\"data\":\"percent\"),d=!0;\"sqrt\"!==p&&(d=f(\"symmetric\",!((\"data\"===p?\"arrayminus\":\"valueminus\")in h))),\"data\"===p?(f(\"array\"),f(\"traceref\"),d||(f(\"arrayminus\"),f(\"tracerefminus\"))):\"percent\"!==p&&\"constant\"!==p||(f(\"value\"),d||f(\"valueminus\"));var g=\"copy_\"+l.inherit+\"style\";if(l.inherit)(e[\"error_\"+l.inherit]||{}).visible&&f(g,!(h.color||n(h.thickness)||n(h.width)));l.inherit&&u[g]||(f(\"color\",r),f(\"thickness\"),f(\"width\",i.traceIs(e,\"gl3d\")?0:4))}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../registry\":847,\"./attributes\":616,\"fast-isnumeric\":225}],620:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"./attributes\"),o={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a)};delete o.error_x.copy_zstyle,delete o.error_y.copy_zstyle,delete o.error_y.copy_ystyle;var s={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a),error_z:n.extendFlat({},a)};delete s.error_x.copy_ystyle,delete s.error_y.copy_ystyle,delete s.error_z.copy_ystyle,delete s.error_z.copy_zstyle,e.exports={moduleType:\"component\",name:\"errorbars\",schema:{traces:{scatter:o,bar:o,histogram:o,scatter3d:i(s,\"calc\",\"nested\"),scattergl:i(o,\"calc\",\"nested\")}},supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),makeComputeError:t(\"./compute_error\"),plot:t(\"./plot\"),style:t(\"./style\"),hoverInfo:function(t,e,r){(e.error_y||{}).visible&&(r.yerr=t.yh-t.y,e.error_y.symmetric||(r.yerrneg=t.y-t.ys));(e.error_x||{}).visible&&(r.xerr=t.xh-t.x,e.error_x.symmetric||(r.xerrneg=t.x-t.xs))}}},{\"../../lib\":719,\"../../plot_api/edit_types\":750,\"./attributes\":616,\"./calc\":617,\"./compute_error\":618,\"./defaults\":619,\"./plot\":621,\"./style\":622}],621:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../drawing\"),o=t(\"../../traces/scatter/subtypes\");e.exports=function(t,e,r,s){var l=r.xaxis,c=r.yaxis,u=s&&s.duration>0;e.each(function(e){var h,f=e[0].trace,p=f.error_x||{},d=f.error_y||{};f.ids&&(h=function(t){return t.id});var g=o.hasMarkers(f)&&f.marker.maxdisplayed>0;d.visible||p.visible||(e=[]);var v=n.select(this).selectAll(\"g.errorbar\").data(e,h);if(v.exit().remove(),e.length){p.visible||v.selectAll(\"path.xerror\").remove(),d.visible||v.selectAll(\"path.yerror\").remove(),v.style(\"opacity\",1);var m=v.enter().append(\"g\").classed(\"errorbar\",!0);u&&m.style(\"opacity\",0).transition().duration(s.duration).style(\"opacity\",1),a.setClipUrl(v,r.layerClipId,t),v.each(function(t){var e=n.select(this),r=function(t,e,r){var n={x:e.c2p(t.x),y:r.c2p(t.y)};void 0!==t.yh&&(n.yh=r.c2p(t.yh),n.ys=r.c2p(t.ys),i(n.ys)||(n.noYS=!0,n.ys=r.c2p(t.ys,!0)));void 0!==t.xh&&(n.xh=e.c2p(t.xh),n.xs=e.c2p(t.xs),i(n.xs)||(n.noXS=!0,n.xs=e.c2p(t.xs,!0)));return n}(t,l,c);if(!g||t.vis){var a,o=e.select(\"path.yerror\");if(d.visible&&i(r.x)&&i(r.yh)&&i(r.ys)){var h=d.width;a=\"M\"+(r.x-h)+\",\"+r.yh+\"h\"+2*h+\"m-\"+h+\",0V\"+r.ys,r.noYS||(a+=\"m-\"+h+\",0h\"+2*h),!o.size()?o=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"yerror\",!0):u&&(o=o.transition().duration(s.duration).ease(s.easing)),o.attr(\"d\",a)}else o.remove();var f=e.select(\"path.xerror\");if(p.visible&&i(r.y)&&i(r.xh)&&i(r.xs)){var v=(p.copy_ystyle?d:p).width;a=\"M\"+r.xh+\",\"+(r.y-v)+\"v\"+2*v+\"m0,-\"+v+\"H\"+r.xs,r.noXS||(a+=\"m0,-\"+v+\"v\"+2*v),!f.size()?f=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"xerror\",!0):u&&(f=f.transition().duration(s.duration).ease(s.easing)),f.attr(\"d\",a)}else f.remove()}})}})}},{\"../../traces/scatter/subtypes\":1135,\"../drawing\":614,d3:163,\"fast-isnumeric\":225}],622:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\");e.exports=function(t){t.each(function(t){var e=t[0].trace,r=e.error_y||{},a=e.error_x||{},o=n.select(this);o.selectAll(\"path.yerror\").style(\"stroke-width\",r.thickness+\"px\").call(i.stroke,r.color),a.copy_ystyle&&(a=r),o.selectAll(\"path.xerror\").style(\"stroke-width\",a.thickness+\"px\").call(i.stroke,a.color)})}},{\"../color\":593,d3:163}],623:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./layout_attributes\").hoverlabel,a=t(\"../../lib/extend\").extendFlat;e.exports={hoverlabel:{bgcolor:a({},i.bgcolor,{arrayOk:!0}),bordercolor:a({},i.bordercolor,{arrayOk:!0}),font:n({arrayOk:!0,editType:\"none\"}),align:a({},i.align,{arrayOk:!0}),namelength:a({},i.namelength,{arrayOk:!0}),editType:\"none\"}}},{\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"./layout_attributes\":633}],624:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");function a(t,e,r,i){i=i||n.identity,Array.isArray(t)&&(e[0][r]=i(t))}e.exports=function(t){var e=t.calcdata,r=t._fullLayout;function o(t){return function(e){return n.coerceHoverinfo({hoverinfo:e},{_module:t._module},r)}}for(var s=0;s<e.length;s++){var l=e[s],c=l[0].trace;if(!i.traceIs(c,\"pie-like\")){var u=i.traceIs(c,\"2dMap\")?a:n.fillArray;u(c.hoverinfo,l,\"hi\",o(c)),c.hovertemplate&&u(c.hovertemplate,l,\"ht\"),c.hoverlabel&&(u(c.hoverlabel.bgcolor,l,\"hbg\"),u(c.hoverlabel.bordercolor,l,\"hbc\"),u(c.hoverlabel.font.size,l,\"hts\"),u(c.hoverlabel.font.color,l,\"htc\"),u(c.hoverlabel.font.family,l,\"htf\"),u(c.hoverlabel.namelength,l,\"hnl\"),u(c.hoverlabel.align,l,\"hta\"))}}}},{\"../../lib\":719,\"../../registry\":847}],625:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./hover\").hover;e.exports=function(t,e,r){var a=n.getComponentMethod(\"annotations\",\"onClick\")(t,t._hoverdata);function o(){t.emit(\"plotly_click\",{points:t._hoverdata,event:e})}void 0!==r&&i(t,e,r,!0),t._hoverdata&&e&&e.target&&(a&&a.then?a.then(o):o(),e.stopImmediatePropagation&&e.stopImmediatePropagation())}},{\"../../registry\":847,\"./hover\":629}],626:[function(t,e,r){\"use strict\";e.exports={YANGLE:60,HOVERARROWSIZE:6,HOVERTEXTPAD:3,HOVERFONTSIZE:13,HOVERFONT:\"Arial, sans-serif\",HOVERMINTIME:50,HOVERID:\"-hover\"}},{}],627:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./hoverlabel_defaults\");e.exports=function(t,e,r,o){var s=n.extendFlat({},o.hoverlabel);e.hovertemplate&&(s.namelength=-1),a(t,e,function(r,a){return n.coerce(t,e,i,r,a)},s)}},{\"../../lib\":719,\"./attributes\":623,\"./hoverlabel_defaults\":630}],628:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");r.getSubplot=function(t){return t.subplot||t.xaxis+t.yaxis||t.geo},r.isTraceInSubplots=function(t,e){if(\"splom\"===t.type){for(var n=t.xaxes||[],i=t.yaxes||[],a=0;a<n.length;a++)for(var o=0;o<i.length;o++)if(-1!==e.indexOf(n[a]+i[o]))return!0;return!1}return-1!==e.indexOf(r.getSubplot(t))},r.flat=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=e;return r},r.p2c=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=t[n].p2c(e);return r},r.getDistanceFunction=function(t,e,n,i){return\"closest\"===t?i||r.quadrature(e,n):\"x\"===t?e:n},r.getClosest=function(t,e,r){if(!1!==r.index)r.index>=0&&r.index<t.length?r.distance=0:r.index=!1;else for(var n=0;n<t.length;n++){var i=e(t[n]);i<=r.distance&&(r.index=n,r.distance=i)}return r},r.inbox=function(t,e,r){return t*e<0||0===t?r:1/0},r.quadrature=function(t,e){return function(r){var n=t(r),i=e(r);return Math.sqrt(n*n+i*i)}},r.makeEventData=function(t,e,n){var i=\"index\"in t?t.index:t.pointNumber,a={data:e._input,fullData:e,curveNumber:e.index,pointNumber:i};if(e._indexToPoints){var o=e._indexToPoints[i];1===o.length?a.pointIndex=o[0]:a.pointIndices=o}else a.pointIndex=i;return e._module.eventData?a=e._module.eventData(a,t,e,n,i):(\"xVal\"in t?a.x=t.xVal:\"x\"in t&&(a.x=t.x),\"yVal\"in t?a.y=t.yVal:\"y\"in t&&(a.y=t.y),t.xa&&(a.xaxis=t.xa),t.ya&&(a.yaxis=t.ya),void 0!==t.zLabelVal&&(a.z=t.zLabelVal)),r.appendArrayPointValue(a,e,i),a},r.appendArrayPointValue=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){var u=o(n.nestedProperty(e,l).get(),r);void 0!==u&&(t[c]=u)}}},r.appendArrayMultiPointValues=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){for(var u=n.nestedProperty(e,l).get(),h=new Array(r.length),f=0;f<r.length;f++)h[f]=o(u,r[f]);t[c]=h}}};var i={ids:\"id\",locations:\"location\",labels:\"label\",values:\"value\",\"marker.colors\":\"color\",parents:\"parent\"};function a(t){return i[t]||t}function o(t,e){return Array.isArray(e)?Array.isArray(t)&&Array.isArray(t[e[0]])?t[e[0]][e[1]]:void 0:t[e]}},{\"../../lib\":719}],629:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../lib\"),s=t(\"../../lib/events\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib/override_cursor\"),u=t(\"../drawing\"),h=t(\"../color\"),f=t(\"../dragelement\"),p=t(\"../../plots/cartesian/axes\"),d=t(\"../../registry\"),g=t(\"./helpers\"),v=t(\"./constants\"),m=v.YANGLE,y=Math.PI*m/180,x=1/Math.sin(y),b=Math.cos(y),_=Math.sin(y),w=v.HOVERARROWSIZE,k=v.HOVERTEXTPAD;r.hover=function(t,e,r,a){t=o.getGraphDiv(t),o.throttle(t._fullLayout._uid+v.HOVERID,v.HOVERMINTIME,function(){!function(t,e,r,a){r||(r=\"xy\");var l=Array.isArray(r)?r:[r],u=t._fullLayout,v=u._plots||[],m=v[r],y=u._has(\"cartesian\");if(m){var b=m.overlays.map(function(t){return t.id});l=l.concat(b)}for(var _=l.length,w=new Array(_),k=new Array(_),T=!1,L=0;L<_;L++){var P=l[L],O=v[P];if(O)T=!0,w[L]=p.getFromId(t,O.xaxis._id),k[L]=p.getFromId(t,O.yaxis._id);else{var z=u[P]._subplot;w[L]=z.xaxis,k[L]=z.yaxis}}var I=e.hovermode||u.hovermode;I&&!T&&(I=\"closest\");if(-1===[\"x\",\"y\",\"closest\"].indexOf(I)||!t.calcdata||t.querySelector(\".zoombox\")||t._dragging)return f.unhoverRaw(t,e);var D,R,F,B,N,j,U,V,q,H,G,Y,W,X=-1===u.hoverdistance?1/0:u.hoverdistance,Z=-1===u.spikedistance?1/0:u.spikedistance,J=[],K=[],$={hLinePoint:null,vLinePoint:null},Q=!1;if(Array.isArray(e))for(I=\"array\",F=0;F<e.length;F++)(N=t.calcdata[e[F].curveNumber||0])&&(j=N[0].trace,\"skip\"!==N[0].trace.hoverinfo&&(K.push(N),\"h\"===j.orientation&&(Q=!0)));else{for(B=0;B<t.calcdata.length;B++)N=t.calcdata[B],\"skip\"!==(j=N[0].trace).hoverinfo&&g.isTraceInSubplots(j,l)&&(K.push(N),\"h\"===j.orientation&&(Q=!0));var tt,et,rt=!e.target;if(rt)tt=\"xpx\"in e?e.xpx:w[0]._length/2,et=\"ypx\"in e?e.ypx:k[0]._length/2;else{if(!1===s.triggerHandler(t,\"plotly_beforehover\",e))return;var nt=e.target.getBoundingClientRect();if(tt=e.clientX-nt.left,et=e.clientY-nt.top,tt<0||tt>w[0]._length||et<0||et>k[0]._length)return f.unhoverRaw(t,e)}if(e.pointerX=tt+w[0]._offset,e.pointerY=et+k[0]._offset,D=\"xval\"in e?g.flat(l,e.xval):g.p2c(w,tt),R=\"yval\"in e?g.flat(l,e.yval):g.p2c(k,et),!i(D[0])||!i(R[0]))return o.warn(\"Fx.hover failed\",e,t),f.unhoverRaw(t,e)}var it=1/0;for(B=0;B<K.length;B++)if((N=K[B])&&N[0]&&N[0].trace&&!0===(j=N[0].trace).visible&&0!==j._length&&-1===[\"carpet\",\"contourcarpet\"].indexOf(j._module.name)){if(\"splom\"===j.type?U=l[V=0]:(U=g.getSubplot(j),V=l.indexOf(U)),q=I,Y={cd:N,trace:j,xa:w[V],ya:k[V],maxHoverDistance:X,maxSpikeDistance:Z,index:!1,distance:Math.min(it,X),spikeDistance:1/0,xSpike:void 0,ySpike:void 0,color:h.defaultLine,name:j.name,x0:void 0,x1:void 0,y0:void 0,y1:void 0,xLabelVal:void 0,yLabelVal:void 0,zLabelVal:void 0,text:void 0},u[U]&&(Y.subplot=u[U]._subplot),u._splomScenes&&u._splomScenes[j.uid]&&(Y.scene=u._splomScenes[j.uid]),W=J.length,\"array\"===q){var at=e[B];\"pointNumber\"in at?(Y.index=at.pointNumber,q=\"closest\"):(q=\"\",\"xval\"in at&&(H=at.xval,q=\"x\"),\"yval\"in at&&(G=at.yval,q=q?\"closest\":\"y\"))}else H=D[V],G=R[V];if(0!==X)if(j._module&&j._module.hoverPoints){var ot=j._module.hoverPoints(Y,H,G,q,u._hoverlayer);if(ot)for(var st,lt=0;lt<ot.length;lt++)st=ot[lt],i(st.x0)&&i(st.y0)&&J.push(S(st,I))}else o.log(\"Unrecognized trace type in hover:\",j);if(\"closest\"===I&&J.length>W&&(J.splice(0,W),it=J[0].distance),y&&0!==Z&&0===J.length){Y.distance=Z,Y.index=!1;var ct=j._module.hoverPoints(Y,H,G,\"closest\",u._hoverlayer);if(ct&&(ct=ct.filter(function(t){return t.spikeDistance<=Z})),ct&&ct.length){var ut,ht=ct.filter(function(t){return t.xa.showspikes});if(ht.length){var ft=ht[0];i(ft.x0)&&i(ft.y0)&&(ut=vt(ft),(!$.vLinePoint||$.vLinePoint.spikeDistance>ut.spikeDistance)&&($.vLinePoint=ut))}var pt=ct.filter(function(t){return t.ya.showspikes});if(pt.length){var dt=pt[0];i(dt.x0)&&i(dt.y0)&&(ut=vt(dt),(!$.hLinePoint||$.hLinePoint.spikeDistance>ut.spikeDistance)&&($.hLinePoint=ut))}}}}function gt(t,e){for(var r,n=null,i=1/0,a=0;a<t.length;a++)(r=t[a].spikeDistance)<i&&r<=e&&(n=t[a],i=r);return n}function vt(t){return t?{xa:t.xa,ya:t.ya,x:void 0!==t.xSpike?t.xSpike:(t.x0+t.x1)/2,y:void 0!==t.ySpike?t.ySpike:(t.y0+t.y1)/2,distance:t.distance,spikeDistance:t.spikeDistance,curveNumber:t.trace.index,color:t.color,pointNumber:t.index}:null}var mt={fullLayout:u,container:u._hoverlayer,outerContainer:u._paperdiv,event:e},yt=t._spikepoints,xt={vLinePoint:$.vLinePoint,hLinePoint:$.hLinePoint};if(t._spikepoints=xt,y&&0!==Z&&0!==J.length){var bt=J.filter(function(t){return t.ya.showspikes}),_t=gt(bt,Z);$.hLinePoint=vt(_t);var wt=J.filter(function(t){return t.xa.showspikes}),kt=gt(wt,Z);$.vLinePoint=vt(kt)}if(0===J.length){var Tt=f.unhoverRaw(t,e);return!y||null===$.hLinePoint&&null===$.vLinePoint||C(yt)&&E($,mt),Tt}y&&C(yt)&&E($,mt);J.sort(function(t,e){return t.distance-e.distance});var At=t._hoverdata,Mt=[];for(F=0;F<J.length;F++){var St=J[F],Et=g.makeEventData(St,St.trace,St.cd);if(!1!==St.hovertemplate){var Ct=!1;St.cd[St.index]&&St.cd[St.index].ht&&(Ct=St.cd[St.index].ht),St.hovertemplate=Ct||St.trace.hovertemplate||!1}St.eventData=[Et],Mt.push(Et)}t._hoverdata=Mt;var Lt=\"y\"===I&&(K.length>1||J.length>1)||\"closest\"===I&&Q&&J.length>1,Pt=h.combine(u.plot_bgcolor||h.background,u.paper_bgcolor),Ot={hovermode:I,rotateLabels:Lt,bgColor:Pt,container:u._hoverlayer,outerContainer:u._paperdiv,commonLabelOpts:u.hoverlabel,hoverdistance:u.hoverdistance},zt=A(J,Ot,t);if(function(t,e,r){var n,i,a,o,s,l,c,u=0,h=1,f=t.size(),p=new Array(f),d=0;function g(t){var e=t[0],r=t[t.length-1];if(i=e.pmin-e.pos-e.dp+e.size,a=r.pos+r.dp+r.size-e.pmax,i>.01){for(s=t.length-1;s>=0;s--)t[s].dp+=i;n=!1}if(!(a<.01)){if(i<-.01){for(s=t.length-1;s>=0;s--)t[s].dp-=a;n=!1}if(n){var c=0;for(o=0;o<t.length;o++)(l=t[o]).pos+l.dp+l.size>e.pmax&&c++;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos>e.pmax-1&&(l.del=!0,c--);for(o=0;o<t.length&&!(c<=0);o++)if((l=t[o]).pos<e.pmin+1)for(l.del=!0,c--,a=2*l.size,s=t.length-1;s>=0;s--)t[s].dp-=a;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos+l.dp+l.size>e.pmax&&(l.del=!0,c--)}}}for(t.each(function(t){var n=t[e],i=\"x\"===n._id.charAt(0),a=n.range;0===d&&a&&a[0]>a[1]!==i&&(h=-1),p[d++]=[{datum:t,traceIndex:t.trace.index,dp:0,pos:t.pos,posref:t.posref,size:t.by*(i?x:1)/2,pmin:0,pmax:i?r.width:r.height}]}),p.sort(function(t,e){return t[0].posref-e[0].posref||h*(e[0].traceIndex-t[0].traceIndex)});!n&&u<=f;){for(u++,n=!0,o=0;o<p.length-1;){var v=p[o],m=p[o+1],y=v[v.length-1],b=m[0];if((i=y.pos+y.dp+y.size-b.pos-b.dp+b.size)>.01&&y.pmin===b.pmin&&y.pmax===b.pmax){for(s=m.length-1;s>=0;s--)m[s].dp+=i;for(v.push.apply(v,m),p.splice(o+1,1),c=0,s=v.length-1;s>=0;s--)c+=v[s].dp;for(a=c/v.length,s=v.length-1;s>=0;s--)v[s].dp-=a;n=!1}else o++}p.forEach(g)}for(o=p.length-1;o>=0;o--){var _=p[o];for(s=_.length-1;s>=0;s--){var w=_[s],k=w.datum;k.offset=w.dp,k.del=w.del}}}(zt,Lt?\"xa\":\"ya\",u),M(zt,Lt),e.target&&e.target.tagName){var It=d.getComponentMethod(\"annotations\",\"hasClickToShow\")(t,Mt);c(n.select(e.target),It?\"pointer\":\"\")}if(!e.target||a||!function(t,e,r){if(!r||r.length!==t._hoverdata.length)return!0;for(var n=r.length-1;n>=0;n--){var i=r[n],a=t._hoverdata[n];if(i.curveNumber!==a.curveNumber||String(i.pointNumber)!==String(a.pointNumber)||String(i.pointNumbers)!==String(a.pointNumbers))return!0}return!1}(t,0,At))return;At&&t.emit(\"plotly_unhover\",{event:e,points:At});t.emit(\"plotly_hover\",{event:e,points:t._hoverdata,xaxes:w,yaxes:k,xvals:D,yvals:R})}(t,e,r,a)})},r.loneHover=function(t,e){var r=!0;Array.isArray(t)||(r=!1,t=[t]);var i=t.map(function(t){return{color:t.color||h.defaultLine,x0:t.x0||t.x||0,x1:t.x1||t.x||0,y0:t.y0||t.y||0,y1:t.y1||t.y||0,xLabel:t.xLabel,yLabel:t.yLabel,zLabel:t.zLabel,text:t.text,name:t.name,idealAlign:t.idealAlign,borderColor:t.borderColor,fontFamily:t.fontFamily,fontSize:t.fontSize,fontColor:t.fontColor,nameLength:t.nameLength,textAlign:t.textAlign,trace:t.trace||{index:0,hoverinfo:\"\"},xa:{_offset:0},ya:{_offset:0},index:0,hovertemplate:t.hovertemplate||!1,eventData:t.eventData||!1,hovertemplateLabels:t.hovertemplateLabels||!1}}),a=n.select(e.container),o=e.outerContainer?n.select(e.outerContainer):a,s={hovermode:\"closest\",rotateLabels:!1,bgColor:e.bgColor||h.background,container:a,outerContainer:o},l=A(i,s,e.gd),c=0,u=0;return l.sort(function(t,e){return t.y0-e.y0}).each(function(t,r){var n=t.y0-t.by/2;t.offset=n-5<c?c-n+5:0,c=n+t.by+t.offset,r===e.anchorIndex&&(u=t.offset)}).each(function(t){t.offset-=u}),M(l,s.rotateLabels),r?l:l.node()};var T=/<extra>([\\s\\S]*)<\\/extra>/;function A(t,e,r){var i=r._fullLayout,a=e.hovermode,s=e.rotateLabels,c=e.bgColor,f=e.container,p=e.outerContainer,d=e.commonLabelOpts||{},g=e.fontFamily||v.HOVERFONT,y=e.fontSize||v.HOVERFONTSIZE,x=t[0],b=x.xa,_=x.ya,A=\"y\"===a?\"yLabel\":\"xLabel\",M=x[A],S=(String(M)||\"\").split(\" \")[0],E=p.node().getBoundingClientRect(),C=E.top,P=E.width,O=E.height,z=void 0!==M&&x.distance<=e.hoverdistance&&(\"x\"===a||\"y\"===a);if(z){var I,D,R=!0;for(I=0;I<t.length;I++)if(R&&void 0===t[I].zLabel&&(R=!1),D=t[I].hoverinfo||t[I].trace.hoverinfo){var F=Array.isArray(D)?D:D.split(\"+\");if(-1===F.indexOf(\"all\")&&-1===F.indexOf(a)){z=!1;break}}R&&(z=!1)}var B=f.selectAll(\"g.axistext\").data(z?[0]:[]);B.enter().append(\"g\").classed(\"axistext\",!0),B.exit().remove(),B.each(function(){var e=n.select(this),i=o.ensureSingle(e,\"path\",\"\",function(t){t.style({\"stroke-width\":\"1px\"})}),s=o.ensureSingle(e,\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),c=d.bgcolor||h.defaultLine,f=d.bordercolor||h.contrast(c),p=h.contrast(c);i.style({fill:c,stroke:f}),s.text(M).call(u.font,d.font.family||g,d.font.size||y,d.font.color||p).call(l.positionText,0,0).call(l.convertToTspans,r),e.attr(\"transform\",\"\");var v=s.node().getBoundingClientRect();if(\"x\"===a){s.attr(\"text-anchor\",\"middle\").call(l.positionText,0,\"top\"===b.side?C-v.bottom-w-k:C-v.top+w+k);var m=\"top\"===b.side?\"-\":\"\";i.attr(\"d\",\"M0,0L\"+w+\",\"+m+w+\"H\"+(k+v.width/2)+\"v\"+m+(2*k+v.height)+\"H-\"+(k+v.width/2)+\"V\"+m+w+\"H-\"+w+\"Z\"),e.attr(\"transform\",\"translate(\"+(b._offset+(x.x0+x.x1)/2)+\",\"+(_._offset+(\"top\"===b.side?0:_._length))+\")\")}else{s.attr(\"text-anchor\",\"right\"===_.side?\"start\":\"end\").call(l.positionText,(\"right\"===_.side?1:-1)*(k+w),C-v.top-v.height/2);var T=\"right\"===_.side?\"\":\"-\";i.attr(\"d\",\"M0,0L\"+T+w+\",\"+w+\"V\"+(k+v.height/2)+\"h\"+T+(2*k+v.width)+\"V-\"+(k+v.height/2)+\"H\"+T+w+\"V-\"+w+\"Z\"),e.attr(\"transform\",\"translate(\"+(b._offset+(\"right\"===_.side?b._length:0))+\",\"+(_._offset+(x.y0+x.y1)/2)+\")\")}t=t.filter(function(t){return void 0!==t.zLabelVal||(t[A]||\"\").split(\" \")[0]===S})});var N=f.selectAll(\"g.hovertext\").data(t,function(t){return[t.trace.index,t.index,t.x0,t.y0,t.name,t.attr,t.xa,t.ya||\"\"].join(\",\")});return N.enter().append(\"g\").classed(\"hovertext\",!0).each(function(){var t=n.select(this);t.append(\"rect\").call(h.fill,h.addOpacity(c,.8)),t.append(\"text\").classed(\"name\",!0),t.append(\"path\").style(\"stroke-width\",\"1px\"),t.append(\"text\").classed(\"nums\",!0).call(u.font,g,y)}),N.exit().remove(),N.each(function(t){var e=n.select(this).attr(\"transform\",\"\"),f=\"\",p=\"\",d=t.bgcolor||t.color,v=h.combine(h.opacity(d)?d:h.defaultLine,c),x=h.combine(h.opacity(t.color)?t.color:h.defaultLine,c),b=t.borderColor||h.contrast(v);void 0!==t.nameOverride&&(t.name=t.nameOverride),t.name&&(t.trace._meta&&(t.name=o.templateString(t.name,t.trace._meta)),f=L(t.name,t.nameLength)),void 0!==t.zLabel?(void 0!==t.xLabel&&(p+=\"x: \"+t.xLabel+\"<br>\"),void 0!==t.yLabel&&(p+=\"y: \"+t.yLabel+\"<br>\"),\"choropleth\"!==t.trace.type&&\"choroplethmapbox\"!==t.trace.type&&(p+=(p?\"z: \":\"\")+t.zLabel)):z&&t[a+\"Label\"]===M?p=t[(\"x\"===a?\"y\":\"x\")+\"Label\"]||\"\":void 0===t.xLabel?void 0!==t.yLabel&&\"scattercarpet\"!==t.trace.type&&(p=t.yLabel):p=void 0===t.yLabel?t.xLabel:\"(\"+t.xLabel+\", \"+t.yLabel+\")\",!t.text&&0!==t.text||Array.isArray(t.text)||(p+=(p?\"<br>\":\"\")+t.text),void 0!==t.extraText&&(p+=(p?\"<br>\":\"\")+t.extraText),\"\"!==p||t.hovertemplate||(\"\"===f&&e.remove(),p=f);var _=i._d3locale,A=t.hovertemplate||!1,S=t.hovertemplateLabels||t,E=t.eventData[0]||{};A&&(p=(p=o.hovertemplateString(A,S,_,E,t.trace._meta)).replace(T,function(e,r){return f=L(r,t.nameLength),\"\"}));var I=e.select(\"text.nums\").call(u.font,t.fontFamily||g,t.fontSize||y,t.fontColor||b).text(p).attr(\"data-notex\",1).call(l.positionText,0,0).call(l.convertToTspans,r),D=e.select(\"text.name\"),R=0,F=0;if(f&&f!==p){D.call(u.font,t.fontFamily||g,t.fontSize||y,x).text(f).attr(\"data-notex\",1).call(l.positionText,0,0).call(l.convertToTspans,r);var B=D.node().getBoundingClientRect();R=B.width+2*k,F=B.height+2*k}else D.remove(),e.select(\"rect\").remove();e.select(\"path\").style({fill:v,stroke:b});var N,j,U=I.node().getBoundingClientRect(),V=t.xa._offset+(t.x0+t.x1)/2,q=t.ya._offset+(t.y0+t.y1)/2,H=Math.abs(t.x1-t.x0),G=Math.abs(t.y1-t.y0),Y=U.width+w+k+R;if(t.ty0=C-U.top,t.bx=U.width+2*k,t.by=Math.max(U.height+2*k,F),t.anchor=\"start\",t.txwidth=U.width,t.tx2width=R,t.offset=0,s)t.pos=V,N=q+G/2+Y<=O,j=q-G/2-Y>=0,\"top\"!==t.idealAlign&&N||!j?N?(q+=G/2,t.anchor=\"start\"):t.anchor=\"middle\":(q-=G/2,t.anchor=\"end\");else if(t.pos=q,N=V+H/2+Y<=P,j=V-H/2-Y>=0,\"left\"!==t.idealAlign&&N||!j)if(N)V+=H/2,t.anchor=\"start\";else{t.anchor=\"middle\";var W=Y/2,X=V+W-P,Z=V-W;X>0&&(V-=X),Z<0&&(V+=-Z)}else V-=H/2,t.anchor=\"end\";I.attr(\"text-anchor\",t.anchor),R&&D.attr(\"text-anchor\",t.anchor),e.attr(\"transform\",\"translate(\"+V+\",\"+q+\")\"+(s?\"rotate(\"+m+\")\":\"\"))}),N}function M(t,e){t.each(function(t){var r=n.select(this);if(t.del)return r.remove();var i=r.select(\"text.nums\"),a=t.anchor,o=\"end\"===a?-1:1,s={start:1,end:-1,middle:0}[a],c=s*(w+k),h=c+s*(t.txwidth+k),f=0,p=t.offset;\"middle\"===a&&(c-=t.tx2width/2,h+=t.txwidth/2+k),e&&(p*=-_,f=t.offset*b),r.select(\"path\").attr(\"d\",\"middle\"===a?\"M-\"+(t.bx/2+t.tx2width/2)+\",\"+(p-t.by/2)+\"h\"+t.bx+\"v\"+t.by+\"h-\"+t.bx+\"Z\":\"M0,0L\"+(o*w+f)+\",\"+(w+p)+\"v\"+(t.by/2-w)+\"h\"+o*t.bx+\"v-\"+t.by+\"H\"+(o*w+f)+\"V\"+(p-w)+\"Z\");var d=c+f,g=p+t.ty0-t.by/2+k,v=t.textAlign||\"auto\";\"auto\"!==v&&(\"left\"===v&&\"start\"!==a?(i.attr(\"text-anchor\",\"start\"),d=\"middle\"===a?-t.bx/2-t.tx2width/2+k:-t.bx-k):\"right\"===v&&\"end\"!==a&&(i.attr(\"text-anchor\",\"end\"),d=\"middle\"===a?t.bx/2-t.tx2width/2-k:t.bx+k)),i.call(l.positionText,d,g),t.tx2width&&(r.select(\"text.name\").call(l.positionText,h+s*k+f,p+t.ty0-t.by/2+k),r.select(\"rect\").call(u.setRect,h+(s-1)*t.tx2width/2+f,p-t.by/2-1,t.tx2width,t.by+2))})}function S(t,e){var r=t.index,n=t.trace||{},a=t.cd[0],s=t.cd[r]||{};function l(t){return t||i(t)&&0===t}var c=Array.isArray(r)?function(t,e){var i=o.castOption(a,r,t);return l(i)?i:o.extractOption({},n,\"\",e)}:function(t,e){return o.extractOption(s,n,t,e)};function u(e,r,n){var i=c(r,n);l(i)&&(t[e]=i)}if(u(\"hoverinfo\",\"hi\",\"hoverinfo\"),u(\"bgcolor\",\"hbg\",\"hoverlabel.bgcolor\"),u(\"borderColor\",\"hbc\",\"hoverlabel.bordercolor\"),u(\"fontFamily\",\"htf\",\"hoverlabel.font.family\"),u(\"fontSize\",\"hts\",\"hoverlabel.font.size\"),u(\"fontColor\",\"htc\",\"hoverlabel.font.color\"),u(\"nameLength\",\"hnl\",\"hoverlabel.namelength\"),u(\"textAlign\",\"hta\",\"hoverlabel.align\"),t.posref=\"y\"===e||\"closest\"===e&&\"h\"===n.orientation?t.xa._offset+(t.x0+t.x1)/2:t.ya._offset+(t.y0+t.y1)/2,t.x0=o.constrain(t.x0,0,t.xa._length),t.x1=o.constrain(t.x1,0,t.xa._length),t.y0=o.constrain(t.y0,0,t.ya._length),t.y1=o.constrain(t.y1,0,t.ya._length),void 0!==t.xLabelVal&&(t.xLabel=\"xLabel\"in t?t.xLabel:p.hoverLabelText(t.xa,t.xLabelVal),t.xVal=t.xa.c2d(t.xLabelVal)),void 0!==t.yLabelVal&&(t.yLabel=\"yLabel\"in t?t.yLabel:p.hoverLabelText(t.ya,t.yLabelVal),t.yVal=t.ya.c2d(t.yLabelVal)),void 0!==t.zLabelVal&&void 0===t.zLabel&&(t.zLabel=String(t.zLabelVal)),!(isNaN(t.xerr)||\"log\"===t.xa.type&&t.xerr<=0)){var h=p.tickText(t.xa,t.xa.c2l(t.xerr),\"hover\").text;void 0!==t.xerrneg?t.xLabel+=\" +\"+h+\" / -\"+p.tickText(t.xa,t.xa.c2l(t.xerrneg),\"hover\").text:t.xLabel+=\" \\xb1 \"+h,\"x\"===e&&(t.distance+=1)}if(!(isNaN(t.yerr)||\"log\"===t.ya.type&&t.yerr<=0)){var f=p.tickText(t.ya,t.ya.c2l(t.yerr),\"hover\").text;void 0!==t.yerrneg?t.yLabel+=\" +\"+f+\" / -\"+p.tickText(t.ya,t.ya.c2l(t.yerrneg),\"hover\").text:t.yLabel+=\" \\xb1 \"+f,\"y\"===e&&(t.distance+=1)}var d=t.hoverinfo||t.trace.hoverinfo;return d&&\"all\"!==d&&(-1===(d=Array.isArray(d)?d:d.split(\"+\")).indexOf(\"x\")&&(t.xLabel=void 0),-1===d.indexOf(\"y\")&&(t.yLabel=void 0),-1===d.indexOf(\"z\")&&(t.zLabel=void 0),-1===d.indexOf(\"text\")&&(t.text=void 0),-1===d.indexOf(\"name\")&&(t.name=void 0)),t}function E(t,e){var r,n,i=e.container,o=e.fullLayout,s=e.event,l=!!t.hLinePoint,c=!!t.vLinePoint;if(i.selectAll(\".spikeline\").remove(),c||l){var f=h.combine(o.plot_bgcolor,o.paper_bgcolor);if(l){var p,d,g=t.hLinePoint;r=g&&g.xa,\"cursor\"===(n=g&&g.ya).spikesnap?(p=s.pointerX,d=s.pointerY):(p=r._offset+g.x,d=n._offset+g.y);var v,m,y=a.readability(g.color,f)<1.5?h.contrast(f):g.color,x=n.spikemode,b=n.spikethickness,_=n.spikecolor||y,w=n._boundingBox,k=(w.left+w.right)/2<p?w.right:w.left;-1===x.indexOf(\"toaxis\")&&-1===x.indexOf(\"across\")||(-1!==x.indexOf(\"toaxis\")&&(v=k,m=p),-1!==x.indexOf(\"across\")&&(v=n._counterSpan[0],m=n._counterSpan[1]),i.insert(\"line\",\":first-child\").attr({x1:v,x2:m,y1:d,y2:d,\"stroke-width\":b,stroke:_,\"stroke-dasharray\":u.dashStyle(n.spikedash,b)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),i.insert(\"line\",\":first-child\").attr({x1:v,x2:m,y1:d,y2:d,\"stroke-width\":b+2,stroke:f}).classed(\"spikeline\",!0).classed(\"crisp\",!0)),-1!==x.indexOf(\"marker\")&&i.insert(\"circle\",\":first-child\").attr({cx:k+(\"right\"!==n.side?b:-b),cy:d,r:b,fill:_}).classed(\"spikeline\",!0)}if(c){var T,A,M=t.vLinePoint;r=M&&M.xa,n=M&&M.ya,\"cursor\"===r.spikesnap?(T=s.pointerX,A=s.pointerY):(T=r._offset+M.x,A=n._offset+M.y);var S,E,C=a.readability(M.color,f)<1.5?h.contrast(f):M.color,L=r.spikemode,P=r.spikethickness,O=r.spikecolor||C,z=r._boundingBox,I=(z.top+z.bottom)/2<A?z.bottom:z.top;-1===L.indexOf(\"toaxis\")&&-1===L.indexOf(\"across\")||(-1!==L.indexOf(\"toaxis\")&&(S=I,E=A),-1!==L.indexOf(\"across\")&&(S=r._counterSpan[0],E=r._counterSpan[1]),i.insert(\"line\",\":first-child\").attr({x1:T,x2:T,y1:S,y2:E,\"stroke-width\":P,stroke:O,\"stroke-dasharray\":u.dashStyle(r.spikedash,P)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),i.insert(\"line\",\":first-child\").attr({x1:T,x2:T,y1:S,y2:E,\"stroke-width\":P+2,stroke:f}).classed(\"spikeline\",!0).classed(\"crisp\",!0)),-1!==L.indexOf(\"marker\")&&i.insert(\"circle\",\":first-child\").attr({cx:T,cy:I-(\"top\"!==r.side?P:-P),r:P,fill:O}).classed(\"spikeline\",!0)}}}function C(t,e){return!e||(e.vLinePoint!==t._spikepoints.vLinePoint||e.hLinePoint!==t._spikepoints.hLinePoint)}function L(t,e){return l.plainText(t||\"\",{len:e,allowedTags:[\"br\",\"sub\",\"sup\",\"b\",\"i\",\"em\"]})}},{\"../../lib\":719,\"../../lib/events\":709,\"../../lib/override_cursor\":730,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"./constants\":626,\"./helpers\":628,d3:163,\"fast-isnumeric\":225,tinycolor2:537}],630:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i){r(\"hoverlabel.bgcolor\",(i=i||{}).bgcolor),r(\"hoverlabel.bordercolor\",i.bordercolor),r(\"hoverlabel.namelength\",i.namelength),n.coerceFont(r,\"hoverlabel.font\",i.font),r(\"hoverlabel.align\",i.align)}},{\"../../lib\":719}],631:[function(t,e,r){\"use strict\";t(\"../../constants/docs\").FORMAT_LINK;e.exports=function(t,e){t=t||{};(e=e||{}).description&&e.description;var r=e.keys||[];if(r.length>0){for(var n=[],i=0;i<r.length;i++)n[i]=\"`\"+r[i]+\"`\";\"Finally, the template string has access to \",1===r.length?\"variable \"+n[0]:\"variables \"+n.slice(0,-1).join(\", \")+\" and \"+n.slice(-1)+\".\"}var a={valType:\"string\",dflt:\"\",editType:t.editType||\"none\"};return!1!==t.arrayOk&&(a.arrayOk=!0),a}},{\"../../constants/docs\":690}],632:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../dragelement\"),o=t(\"./helpers\"),s=t(\"./layout_attributes\"),l=t(\"./hover\");e.exports={moduleType:\"component\",name:\"fx\",constants:t(\"./constants\"),schema:{layout:s},attributes:t(\"./attributes\"),layoutAttributes:s,supplyLayoutGlobalDefaults:t(\"./layout_global_defaults\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),getDistanceFunction:o.getDistanceFunction,getClosest:o.getClosest,inbox:o.inbox,quadrature:o.quadrature,appendArrayPointValue:o.appendArrayPointValue,castHoverOption:function(t,e,r){return i.castOption(t,e,\"hoverlabel.\"+r)},castHoverinfo:function(t,e,r){return i.castOption(t,r,\"hoverinfo\",function(r){return i.coerceHoverinfo({hoverinfo:r},{_module:t._module},e)})},hover:l.hover,unhover:a.unhover,loneHover:l.loneHover,loneUnhover:function(t){var e=i.isD3Selection(t)?t:n.select(t);e.selectAll(\"g.hovertext\").remove(),e.selectAll(\".spikeline\").remove()},click:t(\"./click\")}},{\"../../lib\":719,\"../dragelement\":611,\"./attributes\":623,\"./calc\":624,\"./click\":625,\"./constants\":626,\"./defaults\":627,\"./helpers\":628,\"./hover\":629,\"./layout_attributes\":633,\"./layout_defaults\":634,\"./layout_global_defaults\":635,d3:163}],633:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../plots/font_attributes\")({editType:\"none\"});i.family.dflt=n.HOVERFONT,i.size.dflt=n.HOVERFONTSIZE,e.exports={clickmode:{valType:\"flaglist\",flags:[\"event\",\"select\"],dflt:\"event\",editType:\"plot\",extras:[\"none\"]},dragmode:{valType:\"enumerated\",values:[\"zoom\",\"pan\",\"select\",\"lasso\",\"orbit\",\"turntable\",!1],dflt:\"zoom\",editType:\"modebar\"},hovermode:{valType:\"enumerated\",values:[\"x\",\"y\",\"closest\",!1],editType:\"modebar\"},hoverdistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},spikedistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"none\"},bordercolor:{valType:\"color\",editType:\"none\"},font:i,align:{valType:\"enumerated\",values:[\"left\",\"right\",\"auto\"],dflt:\"auto\",editType:\"none\"},namelength:{valType:\"integer\",min:-1,dflt:15,editType:\"none\"},editType:\"none\"},selectdirection:{valType:\"enumerated\",values:[\"h\",\"v\",\"d\",\"any\"],dflt:\"any\",editType:\"none\"}}},{\"../../plots/font_attributes\":793,\"./constants\":626}],634:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){function a(r,a){return n.coerce(t,e,i,r,a)}var o,s=a(\"clickmode\");\"select\"===a(\"dragmode\")&&a(\"selectdirection\"),e._has(\"cartesian\")?s.indexOf(\"select\")>-1?o=\"closest\":(e._isHoriz=function(t,e){for(var r=e._scatterStackOpts||{},n=0;n<t.length;n++){var i=t[n],a=i.xaxis+i.yaxis,o=r[a]||{},s=o[i.stackgroup]||{};if(\"h\"!==i.orientation&&\"h\"!==s.orientation)return!1}return!0}(r,e),o=e._isHoriz?\"y\":\"x\"):o=\"closest\",a(\"hovermode\",o)&&(a(\"hoverdistance\"),a(\"spikedistance\"));var l=e._has(\"mapbox\"),c=e._has(\"geo\"),u=e._basePlotModules.length;\"zoom\"===e.dragmode&&((l||c)&&1===u||l&&c&&2===u)&&(e.dragmode=\"pan\")}},{\"../../lib\":719,\"./layout_attributes\":633}],635:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./hoverlabel_defaults\"),a=t(\"./layout_attributes\");e.exports=function(t,e){i(t,e,function(r,i){return n.coerce(t,e,a,r,i)})}},{\"../../lib\":719,\"./hoverlabel_defaults\":630,\"./layout_attributes\":633}],636:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/regex\").counter,a=t(\"../../plots/domain\").attributes,o=t(\"../../plots/cartesian/constants\").idRegex,s=t(\"../../plot_api/plot_template\"),l={rows:{valType:\"integer\",min:1,editType:\"plot\"},roworder:{valType:\"enumerated\",values:[\"top to bottom\",\"bottom to top\"],dflt:\"top to bottom\",editType:\"plot\"},columns:{valType:\"integer\",min:1,editType:\"plot\"},subplots:{valType:\"info_array\",freeLength:!0,dimensions:2,items:{valType:\"enumerated\",values:[i(\"xy\").toString(),\"\"],editType:\"plot\"},editType:\"plot\"},xaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.x.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},yaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.y.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},pattern:{valType:\"enumerated\",values:[\"independent\",\"coupled\"],dflt:\"coupled\",editType:\"plot\"},xgap:{valType:\"number\",min:0,max:1,editType:\"plot\"},ygap:{valType:\"number\",min:0,max:1,editType:\"plot\"},domain:a({name:\"grid\",editType:\"plot\",noGridCell:!0},{}),xside:{valType:\"enumerated\",values:[\"bottom\",\"bottom plot\",\"top plot\",\"top\"],dflt:\"bottom plot\",editType:\"plot\"},yside:{valType:\"enumerated\",values:[\"left\",\"left plot\",\"right plot\",\"right\"],dflt:\"left plot\",editType:\"plot\"},editType:\"plot\"};function c(t,e,r){var n=e[r+\"axes\"],i=Object.keys((t._splomAxes||{})[r]||{});return Array.isArray(n)?n:i.length?i:void 0}function u(t,e,r,n,i,a){var o=e(t+\"gap\",r),s=e(\"domain.\"+t);e(t+\"side\",n);for(var l=new Array(i),c=s[0],u=(s[1]-c)/(i-o),h=u*(1-o),f=0;f<i;f++){var p=c+u*f;l[a?i-1-f:f]=[p,p+h]}return l}function h(t,e,r,n,i){var a,o=new Array(r);function s(t,r){-1!==e.indexOf(r)&&void 0===n[r]?(o[t]=r,n[r]=t):o[t]=\"\"}if(Array.isArray(t))for(a=0;a<r;a++)s(a,t[a]);else for(s(0,i),a=1;a<r;a++)s(a,i+(a+1));return o}e.exports={moduleType:\"component\",name:\"grid\",schema:{layout:{grid:l}},layoutAttributes:l,sizeDefaults:function(t,e){var r=t.grid||{},i=c(e,r,\"x\"),a=c(e,r,\"y\");if(t.grid||i||a){var o,h,f=Array.isArray(r.subplots)&&Array.isArray(r.subplots[0]),p=Array.isArray(i),d=Array.isArray(a),g=p&&i!==r.xaxes&&d&&a!==r.yaxes;f?(o=r.subplots.length,h=r.subplots[0].length):(d&&(o=a.length),p&&(h=i.length));var v=s.newContainer(e,\"grid\"),m=T(\"rows\",o),y=T(\"columns\",h);if(m*y>1){f||p||d||\"independent\"===T(\"pattern\")&&(f=!0),v._hasSubplotGrid=f;var x,b,_=\"top to bottom\"===T(\"roworder\"),w=f?.2:.1,k=f?.3:.1;g&&e._splomGridDflt&&(x=e._splomGridDflt.xside,b=e._splomGridDflt.yside),v._domains={x:u(\"x\",T,w,x,y),y:u(\"y\",T,k,b,m,_)}}else delete e.grid}function T(t,e){return n.coerce(r,v,l,t,e)}},contentDefaults:function(t,e){var r=e.grid;if(r&&r._domains){var n,i,a,o,s,l,u,f=t.grid||{},p=e._subplots,d=r._hasSubplotGrid,g=r.rows,v=r.columns,m=\"independent\"===r.pattern,y=r._axisMap={};if(d){var x=f.subplots||[];l=r.subplots=new Array(g);var b=1;for(n=0;n<g;n++){var _=l[n]=new Array(v),w=x[n]||[];for(i=0;i<v;i++)if(m?(s=1===b?\"xy\":\"x\"+b+\"y\"+b,b++):s=w[i],_[i]=\"\",-1!==p.cartesian.indexOf(s)){if(u=s.indexOf(\"y\"),a=s.slice(0,u),o=s.slice(u),void 0!==y[a]&&y[a]!==i||void 0!==y[o]&&y[o]!==n)continue;_[i]=s,y[a]=i,y[o]=n}}}else{var k=c(e,f,\"x\"),T=c(e,f,\"y\");r.xaxes=h(k,p.xaxis,v,y,\"x\"),r.yaxes=h(T,p.yaxis,g,y,\"y\")}var A=r._anchors={},M=\"top to bottom\"===r.roworder;for(var S in y){var E,C,L,P=S.charAt(0),O=r[P+\"side\"];if(O.length<8)A[S]=\"free\";else if(\"x\"===P){if(\"t\"===O.charAt(0)===M?(E=0,C=1,L=g):(E=g-1,C=-1,L=-1),d){var z=y[S];for(n=E;n!==L;n+=C)if((s=l[n][z])&&(u=s.indexOf(\"y\"),s.slice(0,u)===S)){A[S]=s.slice(u);break}}else for(n=E;n!==L;n+=C)if(o=r.yaxes[n],-1!==p.cartesian.indexOf(S+o)){A[S]=o;break}}else if(\"l\"===O.charAt(0)?(E=0,C=1,L=v):(E=v-1,C=-1,L=-1),d){var I=y[S];for(n=E;n!==L;n+=C)if((s=l[I][n])&&(u=s.indexOf(\"y\"),s.slice(u)===S)){A[S]=s.slice(0,u);break}}else for(n=E;n!==L;n+=C)if(a=r.xaxes[n],-1!==p.cartesian.indexOf(a+S)){A[S]=a;break}}}}}},{\"../../lib\":719,\"../../lib/regex\":735,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773,\"../../plots/domain\":792}],637:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/constants\"),i=t(\"../../plot_api/plot_template\").templatedArray;e.exports=i(\"image\",{visible:{valType:\"boolean\",dflt:!0,editType:\"arraydraw\"},source:{valType:\"string\",editType:\"arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},sizex:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizey:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizing:{valType:\"enumerated\",values:[\"fill\",\"contain\",\"stretch\"],dflt:\"contain\",editType:\"arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},x:{valType:\"any\",dflt:0,editType:\"arraydraw\"},y:{valType:\"any\",dflt:0,editType:\"arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"top\",editType:\"arraydraw\"},xref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.x.toString()],dflt:\"paper\",editType:\"arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.y.toString()],dflt:\"paper\",editType:\"arraydraw\"},editType:\"arraydraw\"})},{\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773}],638:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.images,h=e._id.charAt(0),f=0;f<u.length;f++)if(c=\"images[\"+f+\"].\",(l=u[f])[h+\"ref\"]===e._id){var p=l[h],d=l[\"size\"+h],g=null,v=null;if(o){g=i(p,e.range);var m=d/Math.pow(10,g)/2;v=2*Math.log(m+Math.sqrt(1+m*m))/Math.LN10}else v=(g=Math.pow(10,p))*(Math.pow(10,d/2)-Math.pow(10,-d/2));n(g)?n(v)||(v=null):(g=null,v=null),a(c+h,g),a(c+\"size\"+h,v)}}},{\"../../lib/to_log_range\":745,\"fast-isnumeric\":225}],639:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\");function s(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}var s=a(\"source\");if(!a(\"visible\",!!s))return e;a(\"layer\"),a(\"xanchor\"),a(\"yanchor\"),a(\"sizex\"),a(\"sizey\"),a(\"sizing\"),a(\"opacity\");for(var l={_fullLayout:r},c=[\"x\",\"y\"],u=0;u<2;u++){var h=c[u],f=i.coerceRef(t,e,l,h,\"paper\");if(\"paper\"!==f)i.getFromId(l,f)._imgIndices.push(e._index);i.coercePosition(e,l,a,f,h,0)}return e}e.exports=function(t,e){a(t,e,{name:\"images\",handleItemDefaults:s})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"./attributes\":637}],640:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../drawing\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/xmlns_namespaces\");e.exports=function(t){var e,r,s=t._fullLayout,l=[],c={},u=[];for(r=0;r<s.images.length;r++){var h=s.images[r];if(h.visible)if(\"below\"===h.layer&&\"paper\"!==h.xref&&\"paper\"!==h.yref){e=h.xref+h.yref;var f=s._plots[e];if(!f){u.push(h);continue}f.mainplot&&(e=f.mainplot.id),c[e]||(c[e]=[]),c[e].push(h)}else\"above\"===h.layer?l.push(h):u.push(h)}var p={x:{left:{sizing:\"xMin\",offset:0},center:{sizing:\"xMid\",offset:-.5},right:{sizing:\"xMax\",offset:-1}},y:{top:{sizing:\"YMin\",offset:0},middle:{sizing:\"YMid\",offset:-.5},bottom:{sizing:\"YMax\",offset:-1}}};function d(e){var r=n.select(this);if(!this.img||this.img.src!==e.source){r.attr(\"xmlns\",o.svg);var i=new Promise(function(t){var n=new Image;function i(){r.remove(),t()}this.img=n,n.setAttribute(\"crossOrigin\",\"anonymous\"),n.onerror=i,n.onload=function(){var e=document.createElement(\"canvas\");e.width=this.width,e.height=this.height,e.getContext(\"2d\").drawImage(this,0,0);var n=e.toDataURL(\"image/png\");r.attr(\"xlink:href\",n),t()},r.on(\"error\",i),n.src=e.source}.bind(this));t._promises.push(i)}}function g(e){var r=n.select(this),o=a.getFromId(t,e.xref),l=a.getFromId(t,e.yref),c=s._size,u=o?Math.abs(o.l2p(e.sizex)-o.l2p(0)):e.sizex*c.w,h=l?Math.abs(l.l2p(e.sizey)-l.l2p(0)):e.sizey*c.h,f=u*p.x[e.xanchor].offset,d=h*p.y[e.yanchor].offset,g=p.x[e.xanchor].sizing+p.y[e.yanchor].sizing,v=(o?o.r2p(e.x)+o._offset:e.x*c.w+c.l)+f,m=(l?l.r2p(e.y)+l._offset:c.h-e.y*c.h+c.t)+d;switch(e.sizing){case\"fill\":g+=\" slice\";break;case\"stretch\":g=\"none\"}r.attr({x:v,y:m,width:u,height:h,preserveAspectRatio:g,opacity:e.opacity});var y=(o?o._id:\"\")+(l?l._id:\"\");i.setClipUrl(r,y?\"clip\"+s._uid+y:null,t)}var v=s._imageLowerLayer.selectAll(\"image\").data(u),m=s._imageUpperLayer.selectAll(\"image\").data(l);v.enter().append(\"image\"),m.enter().append(\"image\"),v.exit().remove(),m.exit().remove(),v.each(function(t){d.bind(this)(t),g.bind(this)(t)}),m.each(function(t){d.bind(this)(t),g.bind(this)(t)});var y=Object.keys(s._plots);for(r=0;r<y.length;r++){e=y[r];var x=s._plots[e];if(x.imagelayer){var b=x.imagelayer.selectAll(\"image\").data(c[e]||[]);b.enter().append(\"image\"),b.exit().remove(),b.each(function(t){d.bind(this)(t),g.bind(this)(t)})}}}},{\"../../constants/xmlns_namespaces\":696,\"../../plots/cartesian/axes\":767,\"../drawing\":614,d3:163}],641:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"images\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"images\"),draw:t(\"./draw\"),convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":777,\"./attributes\":637,\"./convert_coords\":638,\"./defaults\":639,\"./draw\":640}],642:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",editType:\"legend\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"legend\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"legend\"},font:n({editType:\"legend\"}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"v\",editType:\"legend\"},traceorder:{valType:\"flaglist\",flags:[\"reversed\",\"grouped\"],extras:[\"normal\"],editType:\"legend\"},tracegroupgap:{valType:\"number\",min:0,dflt:10,editType:\"legend\"},itemsizing:{valType:\"enumerated\",values:[\"trace\",\"constant\"],dflt:\"trace\",editType:\"legend\"},itemclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggle\",editType:\"legend\"},itemdoubleclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggleothers\",editType:\"legend\"},x:{valType:\"number\",min:-2,max:3,dflt:1.02,editType:\"legend\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"legend\"},y:{valType:\"number\",min:-2,max:3,dflt:1,editType:\"legend\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"legend\"},uirevision:{valType:\"any\",editType:\"none\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"legend\"},editType:\"legend\"}},{\"../../plots/font_attributes\":793,\"../color/attributes\":592}],643:[function(t,e,r){\"use strict\";e.exports={scrollBarWidth:6,scrollBarMinHeight:20,scrollBarColor:\"#808BA4\",scrollBarMargin:4,textOffsetX:40}},{}],644:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plot_api/plot_template\"),o=t(\"./attributes\"),s=t(\"../../plots/layout_attributes\"),l=t(\"./helpers\");e.exports=function(t,e,r){for(var c,u,h,f,p=t.legend||{},d=0,g=!1,v=\"normal\",m=0;m<r.length;m++){var y=r[m];y.visible&&((y.showlegend||y._dfltShowLegend)&&(d++,y.showlegend&&(g=!0,(n.traceIs(y,\"pie-like\")||!0===y._input.showlegend)&&d++)),(n.traceIs(y,\"bar\")&&\"stack\"===e.barmode||-1!==[\"tonextx\",\"tonexty\"].indexOf(y.fill))&&(v=l.isGrouped({traceorder:v})?\"grouped+reversed\":\"reversed\"),void 0!==y.legendgroup&&\"\"!==y.legendgroup&&(v=l.isReversed({traceorder:v})?\"reversed+grouped\":\"grouped\"))}var x=i.coerce(t,e,s,\"showlegend\",g&&d>1);if(!1!==x||p.uirevision){var b=a.newContainer(e,\"legend\");if(w(\"uirevision\",e.uirevision),!1!==x){if(w(\"bgcolor\",e.paper_bgcolor),w(\"bordercolor\"),w(\"borderwidth\"),i.coerceFont(w,\"font\",e.font),w(\"orientation\"),\"h\"===b.orientation){var _=t.xaxis;n.getComponentMethod(\"rangeslider\",\"isVisible\")(_)?(c=0,h=\"left\",u=1.1,f=\"bottom\"):(c=0,h=\"left\",u=-.1,f=\"top\")}w(\"traceorder\",v),l.isGrouped(e.legend)&&w(\"tracegroupgap\"),w(\"itemsizing\"),w(\"itemclick\"),w(\"itemdoubleclick\"),w(\"x\",c),w(\"xanchor\",h),w(\"y\",u),w(\"yanchor\",f),w(\"valign\"),i.noneOrAll(p,b,[\"x\",\"y\"])}}function w(t,e){return i.coerce(p,b,o,t,e)}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/layout_attributes\":819,\"../../registry\":847,\"./attributes\":642,\"./helpers\":648}],645:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib/events\"),l=t(\"../dragelement\"),c=t(\"../drawing\"),u=t(\"../color\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"./handle_click\"),p=t(\"./constants\"),d=t(\"../../constants/alignment\"),g=d.LINE_SPACING,v=d.FROM_TL,m=d.FROM_BR,y=t(\"./get_legend_data\"),x=t(\"./style\"),b=t(\"./helpers\");function _(t,e,r,n,i){var a=r.data()[0][0].trace,l={event:i,node:r.node(),curveNumber:a.index,expandedIndex:a._expandedIndex,data:t.data,layout:t.layout,frames:t._transitionData._frames,config:t._context,fullData:t._fullData,fullLayout:t._fullLayout};if(a._group&&(l.group=a._group),o.traceIs(a,\"pie-like\")&&(l.label=r.datum()[0].label),!1!==s.triggerHandler(t,\"plotly_legendclick\",l))if(1===n)e._clickTimeout=setTimeout(function(){f(r,t,n)},t._context.doubleClickDelay);else if(2===n){e._clickTimeout&&clearTimeout(e._clickTimeout),t._legendMouseDownTime=0,!1!==s.triggerHandler(t,\"plotly_legenddoubleclick\",l)&&f(r,t,n)}}function w(t,e,r){var n=t.data()[0][0],a=e._fullLayout,s=n.trace,l=o.traceIs(s,\"pie-like\"),u=s.index,f=e._context.edits.legendText&&!l,d=l?n.label:s.name;s._meta&&(d=i.templateString(d,s._meta));var v=i.ensureSingle(t,\"text\",\"legendtext\");function m(r){h.convertToTspans(r,e,function(){!function(t,e){var r=t.data()[0][0];if(!r.trace.showlegend)return void t.remove();var n,i,a=t.select(\"g[class*=math-group]\"),o=a.node(),s=e._fullLayout.legend.font.size*g;if(o){var l=c.bBox(o);n=l.height,i=l.width,c.setTranslate(a,0,n/4)}else{var u=t.select(\".legendtext\"),f=h.lineCount(u),d=u.node();n=s*f,i=d?c.bBox(d).width:0;var v=s*(.3+(1-f)/2);h.positionText(u,p.textOffsetX,v)}r.lineHeight=s,r.height=Math.max(n,16)+3,r.width=i}(t,e)})}v.attr(\"text-anchor\",\"start\").classed(\"user-select-none\",!0).call(c.font,a.legend.font).text(f?k(d,r):d),h.positionText(v,p.textOffsetX,0),f?v.call(h.makeEditable,{gd:e,text:d}).call(m).on(\"edit\",function(t){this.text(k(t,r)).call(m);var a=n.trace._fullInput||{},s={};if(o.hasTransform(a,\"groupby\")){var l=o.getTransformIndices(a,\"groupby\"),c=l[l.length-1],h=i.keyedContainer(a,\"transforms[\"+c+\"].styles\",\"target\",\"value.name\");h.set(n.trace._group,t),s=h.constructUpdate()}else s.name=t;return o.call(\"_guiRestyle\",e,s,u)}):m(v)}function k(t,e){var r=Math.max(4,e);if(t&&t.trim().length>=r/2)return t;for(var n=r-(t=t||\"\").length;n>0;n--)t+=\" \";return t}function T(t,e){var r,a=e._context.doubleClickDelay,o=1,s=i.ensureSingle(t,\"rect\",\"legendtoggle\",function(t){t.style(\"cursor\",\"pointer\").attr(\"pointer-events\",\"all\").call(u.fill,\"rgba(0,0,0,0)\")});s.on(\"mousedown\",function(){(r=(new Date).getTime())-e._legendMouseDownTime<a?o+=1:(o=1,e._legendMouseDownTime=r)}),s.on(\"mouseup\",function(){if(!e._dragged&&!e._editing){var r=e._fullLayout.legend;(new Date).getTime()-e._legendMouseDownTime>a&&(o=Math.max(o-1,1)),_(e,r,t,o,n.event)}})}function A(t,e,r){var a=t._fullLayout,o=a.legend,s=o.borderwidth,l=b.isGrouped(o),u=0;if(o._width=0,o._height=0,b.isVertical(o))l&&e.each(function(t,e){c.setTranslate(this,0,e*o.tracegroupgap)}),r.each(function(t){var e=t[0],r=e.height,n=e.width;c.setTranslate(this,s,5+s+o._height+r/2),o._height+=r,o._width=Math.max(o._width,n)}),o._width+=45+2*s,o._height+=10+2*s,l&&(o._height+=(o._lgroupsLength-1)*o.tracegroupgap),u=40;else if(l){var h,f=0,p=0,d=e.data(),g=0;for(h=0;h<d.length;h++){var v=d[h],m=v.map(function(t){return t[0].width}),y=i.aggNums(Math.max,null,m),x=v.reduce(function(t,e){return t+e[0].height},0);p=Math.max(p,y),f=Math.max(f,x),g=Math.max(g,v.length)}p+=5,p+=40;var _=[o._width],w=[],k=0;for(h=0;h<d.length;h++){a._size.w<s+o._width+5+p?(_[_.length-1]=_[0],o._width=p,k++):o._width+=p+s;var T=k*f;T+=k>0?o.tracegroupgap:0,w.push(T),_.push(o._width)}e.each(function(t,e){c.setTranslate(this,_[e],w[e])}),e.each(function(){var t=n.select(this).selectAll(\"g.traces\"),e=0;t.each(function(t){var r=t[0].height;c.setTranslate(this,0,5+s+e+r/2),e+=r})});var A=w[w.length-1]+f;o._height=10+2*s+A;var M=Math.max.apply(null,_);o._width=M+p+40,o._width+=2*s}else{var S=0,E=0,C=0,L=0,P=0;r.each(function(t){C=Math.max(40+t[0].width,C),P+=40+t[0].width+5});var O=a._size.w>s+P-5;r.each(function(t){var e=t[0],r=O?40+t[0].width:C;s+L+5+r>a._size.w&&(L=0,S+=E,o._height+=E,E=0),c.setTranslate(this,s+L,5+s+e.height/2+S),o._width+=5+r,L+=5+r,E=Math.max(e.height,E)}),O?o._height=E:o._height+=E,o._width+=2*s,o._height+=10+2*s}o._width=Math.ceil(o._width),o._height=Math.ceil(o._height);var z=t._context.edits.legendText||t._context.edits.legendPosition;r.each(function(t){var e=t[0],r=n.select(this).select(\".legendtoggle\");c.setRect(r,0,-e.height/2,(z?0:o._width)+u,e.height)})}function M(t){var e=t._fullLayout.legend,r=\"left\";i.isRightAnchor(e)?r=\"right\":i.isCenterAnchor(e)&&(r=\"center\");var n=\"top\";i.isBottomAnchor(e)?n=\"bottom\":i.isMiddleAnchor(e)&&(n=\"middle\"),a.autoMargin(t,\"legend\",{x:e.x,y:e.y,l:e._width*v[r],r:e._width*m[r],b:e._height*m[n],t:e._height*v[n]})}e.exports=function(t){var e=t._fullLayout,r=\"legend\"+e._uid;if(e._infolayer&&t.calcdata){t._legendMouseDownTime||(t._legendMouseDownTime=0);var s=e.legend,h=e.showlegend&&y(t.calcdata,s),f=e.hiddenlabels||[];if(!e.showlegend||!h.length)return e._infolayer.selectAll(\".legend\").remove(),e._topdefs.select(\"#\"+r).remove(),void a.autoMargin(t,\"legend\");for(var d=0,g=0;g<h.length;g++)for(var b=0;b<h[g].length;b++){var k=h[g][b][0],S=k.trace,E=o.traceIs(S,\"pie-like\")?k.label:S.name;d=Math.max(d,E&&E.length||0)}var C=!1,L=i.ensureSingle(e._infolayer,\"g\",\"legend\",function(t){t.attr(\"pointer-events\",\"all\"),C=!0}),P=i.ensureSingleById(e._topdefs,\"clipPath\",r,function(t){t.append(\"rect\")}),O=i.ensureSingle(L,\"rect\",\"bg\",function(t){t.attr(\"shape-rendering\",\"crispEdges\")});O.call(u.stroke,s.bordercolor).call(u.fill,s.bgcolor).style(\"stroke-width\",s.borderwidth+\"px\");var z=i.ensureSingle(L,\"g\",\"scrollbox\"),I=i.ensureSingle(L,\"rect\",\"scrollbar\",function(t){t.attr({rx:20,ry:3,width:0,height:0}).call(u.fill,\"#808BA4\")}),D=z.selectAll(\"g.groups\").data(h);D.enter().append(\"g\").attr(\"class\",\"groups\"),D.exit().remove();var R=D.selectAll(\"g.traces\").data(i.identity);R.enter().append(\"g\").attr(\"class\",\"traces\"),R.exit().remove(),R.style(\"opacity\",function(t){var e=t[0].trace;return o.traceIs(e,\"pie-like\")?-1!==f.indexOf(t[0].label)?.5:1:\"legendonly\"===e.visible?.5:1}).each(function(){n.select(this).call(w,t,d)}).call(x,t).each(function(){n.select(this).call(T,t)}),i.syncOrAsync([a.previousPromises,function(){C&&(A(t,D,R),M(t));var u=e.width,h=e.height;A(t,D,R),s._height>h?function(t){var e=t._fullLayout.legend,r=\"left\";i.isRightAnchor(e)?r=\"right\":i.isCenterAnchor(e)&&(r=\"center\");a.autoMargin(t,\"legend\",{x:e.x,y:.5,l:e._width*v[r],r:e._width*m[r],b:0,t:0})}(t):M(t);var f=e._size,d=f.l+f.w*s.x,g=f.t+f.h*(1-s.y);i.isRightAnchor(s)?d-=s._width:i.isCenterAnchor(s)&&(d-=s._width/2),i.isBottomAnchor(s)?g-=s._height:i.isMiddleAnchor(s)&&(g-=s._height/2);var y=s._width,x=f.w;y>x?(d=f.l,y=x):(d+y>u&&(d=u-y),d<0&&(d=0),y=Math.min(u-d,s._width));var b,w,k,T,S=s._height,E=f.h;if(S>E?(g=f.t,S=E):(g+S>h&&(g=h-S),g<0&&(g=0),S=Math.min(h-g,s._height)),c.setTranslate(L,d,g),I.on(\".drag\",null),L.on(\"wheel\",null),s._height<=S||t._context.staticPlot)O.attr({width:y-s.borderwidth,height:S-s.borderwidth,x:s.borderwidth/2,y:s.borderwidth/2}),c.setTranslate(z,0,0),P.select(\"rect\").attr({width:y-2*s.borderwidth,height:S-2*s.borderwidth,x:s.borderwidth,y:s.borderwidth}),c.setClipUrl(z,r,t),c.setRect(I,0,0,0,0),delete s._scrollY;else{var F,B,N=Math.max(p.scrollBarMinHeight,S*S/s._height),j=S-N-2*p.scrollBarMargin,U=s._height-S,V=j/U,q=Math.min(s._scrollY||0,U);O.attr({width:y-2*s.borderwidth+p.scrollBarWidth+p.scrollBarMargin,height:S-s.borderwidth,x:s.borderwidth/2,y:s.borderwidth/2}),P.select(\"rect\").attr({width:y-2*s.borderwidth+p.scrollBarWidth+p.scrollBarMargin,height:S-2*s.borderwidth,x:s.borderwidth,y:s.borderwidth+q}),c.setClipUrl(z,r,t),G(q,N,V),L.on(\"wheel\",function(){G(q=i.constrain(s._scrollY+n.event.deltaY/j*U,0,U),N,V),0!==q&&q!==U&&n.event.preventDefault()});var H=n.behavior.drag().on(\"dragstart\",function(){F=n.event.sourceEvent.clientY,B=q}).on(\"drag\",function(){var t=n.event.sourceEvent;2===t.buttons||t.ctrlKey||G(q=i.constrain((t.clientY-F)/V+B,0,U),N,V)});I.call(H)}function G(e,r,n){s._scrollY=t._fullLayout.legend._scrollY=e,c.setTranslate(z,0,-e),c.setRect(I,y,p.scrollBarMargin+e*n,p.scrollBarWidth,r),P.select(\"rect\").attr({y:s.borderwidth+e})}t._context.edits.legendPosition&&(L.classed(\"cursor-move\",!0),l.init({element:L.node(),gd:t,prepFn:function(){var t=c.getTranslate(L);k=t.x,T=t.y},moveFn:function(t,e){var r=k+t,n=T+e;c.setTranslate(L,r,n),b=l.align(r,0,f.l,f.l+f.w,s.xanchor),w=l.align(n,0,f.t+f.h,f.t,s.yanchor)},doneFn:function(){void 0!==b&&void 0!==w&&o.call(\"_guiRelayout\",t,{\"legend.x\":b,\"legend.y\":w})},clickFn:function(r,n){var i=e._infolayer.selectAll(\"g.traces\").filter(function(){var t=this.getBoundingClientRect();return n.clientX>=t.left&&n.clientX<=t.right&&n.clientY>=t.top&&n.clientY<=t.bottom});i.size()>0&&_(t,L,i,r,n)}}))}],t)}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/events\":709,\"../../lib/svg_text_utils\":743,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"./constants\":643,\"./get_legend_data\":646,\"./handle_click\":647,\"./helpers\":648,\"./style\":650,d3:163}],646:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./helpers\");e.exports=function(t,e){var r,a,o={},s=[],l=!1,c={},u=0;function h(t,r){if(\"\"!==t&&i.isGrouped(e))-1===s.indexOf(t)?(s.push(t),l=!0,o[t]=[[r]]):o[t].push([r]);else{var n=\"~~i\"+u;s.push(n),o[n]=[[r]],u++}}for(r=0;r<t.length;r++){var f=t[r],p=f[0],d=p.trace,g=d.legendgroup;if(d.visible&&d.showlegend)if(n.traceIs(d,\"pie-like\"))for(c[g]||(c[g]={}),a=0;a<f.length;a++){var v=f[a].label;c[g][v]||(h(g,{label:v,color:f[a].color,i:f[a].i,trace:d,pts:f[a].pts}),c[g][v]=!0)}else h(g,p)}if(!s.length)return[];var m,y,x=s.length;if(l&&i.isGrouped(e))for(y=new Array(x),r=0;r<x;r++)m=o[s[r]],y[r]=i.isReversed(e)?m.reverse():m;else{for(y=[new Array(x)],r=0;r<x;r++)m=o[s[r]][0],y[0][i.isReversed(e)?x-r-1:r]=m;x=1}return e._lgroupsLength=x,y}},{\"../../registry\":847,\"./helpers\":648}],647:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=!0;e.exports=function(t,e,r){var o=e._fullLayout;if(!e._dragged&&!e._editing){var s,l=o.legend.itemclick,c=o.legend.itemdoubleclick;if(1===r&&\"toggle\"===l&&\"toggleothers\"===c&&a&&e.data&&e._context.showTips?(n.notifier(n._(e,\"Double-click on legend to isolate one trace\"),\"long\"),a=!1):a=!1,1===r?s=l:2===r&&(s=c),s){var u,h,f,p,d,g=o.hiddenlabels?o.hiddenlabels.slice():[],v=t.data()[0][0],m=e._fullData,y=v.trace,x=y.legendgroup,b={},_=[],w=[],k=[];if(i.traceIs(y,\"pie-like\")){var T=v.label,A=g.indexOf(T);\"toggle\"===s?-1===A?g.push(T):g.splice(A,1):\"toggleothers\"===s&&(g=[],e.calcdata[0].forEach(function(t){T!==t.label&&g.push(t.label)}),e._fullLayout.hiddenlabels&&e._fullLayout.hiddenlabels.length===g.length&&-1===A&&(g=[])),i.call(\"_guiRelayout\",e,\"hiddenlabels\",g)}else{var M,S=x&&x.length,E=[];if(S)for(u=0;u<m.length;u++)(M=m[u]).visible&&M.legendgroup===x&&E.push(u);if(\"toggle\"===s){var C;switch(y.visible){case!0:C=\"legendonly\";break;case!1:C=!1;break;case\"legendonly\":C=!0}if(S)for(u=0;u<m.length;u++)!1!==m[u].visible&&m[u].legendgroup===x&&R(m[u],C);else R(y,C)}else if(\"toggleothers\"===s){var L,P,O=!0;for(u=0;u<m.length;u++)if(!(m[u]===y)&&!(L=S&&m[u].legendgroup===x)&&!0===m[u].visible&&!i.traceIs(m[u],\"notLegendIsolatable\")){O=!1;break}for(u=0;u<m.length;u++)if(!1!==m[u].visible&&!i.traceIs(m[u],\"notLegendIsolatable\"))switch(y.visible){case\"legendonly\":R(m[u],!0);break;case!0:P=!!O||\"legendonly\",L=m[u]===y||S&&m[u].legendgroup===x,R(m[u],!!L||P)}}for(u=0;u<w.length;u++)if(f=w[u]){var z=f.constructUpdate(),I=Object.keys(z);for(h=0;h<I.length;h++)p=I[h],(b[p]=b[p]||[])[k[u]]=z[p]}for(d=Object.keys(b),u=0;u<d.length;u++)for(p=d[u],h=0;h<_.length;h++)b[p].hasOwnProperty(h)||(b[p][h]=void 0);i.call(\"_guiRestyle\",e,b,_)}}}function D(t,e,r){var n=_.indexOf(t),i=b[e];return i||(i=b[e]=[]),-1===_.indexOf(t)&&(_.push(t),n=_.length-1),i[n]=r,n}function R(t,e){var r=t._fullInput;if(i.hasTransform(r,\"groupby\")){var a=w[r.index];if(!a){var o=i.getTransformIndices(r,\"groupby\"),s=o[o.length-1];a=n.keyedContainer(r,\"transforms[\"+s+\"].styles\",\"target\",\"value.visible\"),w[r.index]=a}var l=a.get(t._group);void 0===l&&(l=!0),!1!==l&&a.set(t._group,e),k[r.index]=D(r.index,\"visible\",!1!==r.visible)}else{var c=!1!==r.visible&&e;D(r.index,\"visible\",c)}}}},{\"../../lib\":719,\"../../registry\":847}],648:[function(t,e,r){\"use strict\";r.isGrouped=function(t){return-1!==(t.traceorder||\"\").indexOf(\"grouped\")},r.isVertical=function(t){return\"h\"!==t.orientation},r.isReversed=function(t){return-1!==(t.traceorder||\"\").indexOf(\"reversed\")}},{}],649:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"legend\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\"),style:t(\"./style\")}},{\"./attributes\":642,\"./defaults\":644,\"./draw\":645,\"./style\":650}],650:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../drawing\"),s=t(\"../color\"),l=t(\"../../traces/scatter/subtypes\"),c=t(\"../../traces/pie/style_one\"),u=t(\"../../traces/pie/helpers\").castOption,h=12,f=5,p=2,d=10,g=5;e.exports=function(t,e){var r=e._fullLayout.legend,v=\"constant\"===r.itemsizing;function m(t,e,r,n){var i;if(t+1)i=t;else{if(!(e&&e.width>0))return 0;i=e.width}return v?n:Math.min(i,r)}function y(t,e,r){var a=t[0].trace,o=a.marker||{},l=o.line||{},c=r?a.type===r&&a.visible:i.traceIs(a,\"bar\"),u=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(c?[t]:[]);u.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),u.exit().remove(),u.each(function(t){var e=n.select(this),r=t[0],i=m(r.mlw,o.line,g,p);e.style(\"stroke-width\",i+\"px\").call(s.fill,r.mc||o.color),i&&s.stroke(e,r.mlc||l.color)})}function x(t,e,r){var o=t[0],s=o.trace,l=r?s.type===r&&s.visible:i.traceIs(s,r),h=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(l?[t]:[]);if(h.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),h.exit().remove(),h.size()){var f=(s.marker||{}).line,d=m(u(f.width,o.pts),f,g,p),v=a.minExtend(s,{marker:{line:{width:d}}});v.marker.line.color=f.color;var y=a.minExtend(o,{trace:v});c(h,y,v)}}t.each(function(t){var e=n.select(this),i=a.ensureSingle(e,\"g\",\"layers\");i.style(\"opacity\",t[0].trace.opacity);var o=r.valign,s=t[0].lineHeight,l=t[0].height;if(\"middle\"!==o&&s&&l){var c={top:1,bottom:-1}[o]*(.5*(s-l+3));i.attr(\"transform\",\"translate(0,\"+c+\")\")}else i.attr(\"transform\",null);i.selectAll(\"g.legendfill\").data([t]).enter().append(\"g\").classed(\"legendfill\",!0),i.selectAll(\"g.legendlines\").data([t]).enter().append(\"g\").classed(\"legendlines\",!0);var u=i.selectAll(\"g.legendsymbols\").data([t]);u.enter().append(\"g\").classed(\"legendsymbols\",!0),u.selectAll(\"g.legendpoints\").data([t]).enter().append(\"g\").classed(\"legendpoints\",!0)}).each(function(t){var e=t[0].trace,r=[];\"waterfall\"===e.type&&e.visible&&(r=t[0].hasTotals?[[\"increasing\",\"M-6,-6V6H0Z\"],[\"totals\",\"M6,6H0L-6,-6H-0Z\"],[\"decreasing\",\"M6,6V-6H0Z\"]]:[[\"increasing\",\"M-6,-6V6H6Z\"],[\"decreasing\",\"M6,6V-6H-6Z\"]]);var i=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendwaterfall\").data(r);i.enter().append(\"path\").classed(\"legendwaterfall\",!0).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),i.exit().remove(),i.each(function(t){var r=n.select(this),i=e[t[0]].marker,a=m(void 0,i.line,g,p);r.attr(\"d\",t[1]).style(\"stroke-width\",a+\"px\").call(s.fill,i.color),a&&r.call(s.stroke,i.line.color)})}).each(function(t){y(t,this,\"funnel\")}).each(function(t){y(t,this)}).each(function(t){var r=t[0].trace,l=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendbox\").data(i.traceIs(r,\"box-violin\")&&r.visible?[t]:[]);l.enter().append(\"path\").classed(\"legendbox\",!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),l.exit().remove(),l.each(function(){var t=n.select(this);if(\"all\"!==r.boxpoints&&\"all\"!==r.points||0!==s.opacity(r.fillcolor)||0!==s.opacity((r.line||{}).color)){var i=m(void 0,r.line,g,p);t.style(\"stroke-width\",i+\"px\").call(s.fill,r.fillcolor),i&&s.stroke(t,r.line.color)}else{var c=a.minExtend(r,{marker:{size:v?h:a.constrain(r.marker.size,2,16),sizeref:1,sizemin:1,sizemode:\"diameter\"}});l.call(o.pointStyle,c,e)}})}).each(function(t){x(t,this,\"funnelarea\")}).each(function(t){x(t,this,\"pie\")}).each(function(t){var r,i,s=t[0],c=s.trace,u=c.visible&&c.fill&&\"none\"!==c.fill,h=l.hasLines(c),p=c.contours,g=!1,v=!1;if(p){var y=p.coloring;\"lines\"===y?g=!0:h=\"none\"===y||\"heatmap\"===y||p.showlines,\"constraint\"===p.type?u=\"=\"!==p._operation:\"fill\"!==y&&\"heatmap\"!==y||(v=!0)}var x=l.hasMarkers(c)||l.hasText(c),b=u||v,_=h||g,w=x||!b?\"M5,0\":_?\"M5,-2\":\"M5,-3\",k=n.select(this),T=k.select(\".legendfill\").selectAll(\"path\").data(u||v?[t]:[]);if(T.enter().append(\"path\").classed(\"js-fill\",!0),T.exit().remove(),T.attr(\"d\",w+\"h30v6h-30z\").call(u?o.fillGroupStyle:function(t){if(t.size()){var r=\"legendfill-\"+c.uid;o.gradient(t,e,r,\"horizontalreversed\",c.colorscale,\"fill\")}}),h||g){var A=m(void 0,c.line,d,f);i=a.minExtend(c,{line:{width:A}}),r=[a.minExtend(s,{trace:i})]}var M=k.select(\".legendlines\").selectAll(\"path\").data(h||g?[r]:[]);M.enter().append(\"path\").classed(\"js-line\",!0),M.exit().remove(),M.attr(\"d\",w+(g?\"l30,0.0001\":\"h30\")).call(h?o.lineGroupStyle:function(t){if(t.size()){var r=\"legendline-\"+c.uid;o.lineGroupStyle(t),o.gradient(t,e,r,\"horizontalreversed\",c.colorscale,\"stroke\")}})}).each(function(t){var r,i,s=t[0],c=s.trace,u=l.hasMarkers(c),d=l.hasText(c),g=l.hasLines(c);function m(t,e,r,n){var i=a.nestedProperty(c,t).get(),o=a.isArrayOrTypedArray(i)&&e?e(i):i;if(v&&o&&void 0!==n&&(o=n),r){if(o<r[0])return r[0];if(o>r[1])return r[1]}return o}function y(t){return t[0]}if(u||d||g){var x={},b={};if(u){x.mc=m(\"marker.color\",y),x.mx=m(\"marker.symbol\",y),x.mo=m(\"marker.opacity\",a.mean,[.2,1]),x.mlc=m(\"marker.line.color\",y),x.mlw=m(\"marker.line.width\",a.mean,[0,5],p),b.marker={sizeref:1,sizemin:1,sizemode:\"diameter\"};var _=m(\"marker.size\",a.mean,[2,16],h);x.ms=_,b.marker.size=_}g&&(b.line={width:m(\"line.width\",y,[0,10],f)}),d&&(x.tx=\"Aa\",x.tp=m(\"textposition\",y),x.ts=10,x.tc=m(\"textfont.color\",y),x.tf=m(\"textfont.family\",y)),r=[a.minExtend(s,x)],(i=a.minExtend(c,b)).selectedpoints=null}var w=n.select(this).select(\"g.legendpoints\"),k=w.selectAll(\"path.scatterpts\").data(u?r:[]);k.enter().insert(\"path\",\":first-child\").classed(\"scatterpts\",!0).attr(\"transform\",\"translate(20,0)\"),k.exit().remove(),k.call(o.pointStyle,i,e),u&&(r[0].mrc=3);var T=w.selectAll(\"g.pointtext\").data(d?r:[]);T.enter().append(\"g\").classed(\"pointtext\",!0).append(\"text\").attr(\"transform\",\"translate(20,0)\"),T.exit().remove(),T.selectAll(\"text\").call(o.textPointStyle,i,e)}).each(function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendcandle\").data(\"candlestick\"===e.type&&e.visible?[t,t]:[]);r.enter().append(\"path\").classed(\"legendcandle\",!0).attr(\"d\",function(t,e){return e?\"M-15,0H-8M-8,6V-6H8Z\":\"M15,0H8M8,-6V6H-8Z\"}).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),r.exit().remove(),r.each(function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],o=m(void 0,a.line,g,p);i.style(\"stroke-width\",o+\"px\").call(s.fill,a.fillcolor),o&&s.stroke(i,a.line.color)})}).each(function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendohlc\").data(\"ohlc\"===e.type&&e.visible?[t,t]:[]);r.enter().append(\"path\").classed(\"legendohlc\",!0).attr(\"d\",function(t,e){return e?\"M-15,0H0M-8,-6V0\":\"M15,0H0M8,6V0\"}).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),r.exit().remove(),r.each(function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],l=m(void 0,a.line,g,p);i.style(\"fill\",\"none\").call(o.dashLine,a.line.dash,l),l&&s.stroke(i,a.line.color)})})}},{\"../../lib\":719,\"../../registry\":847,\"../../traces/pie/helpers\":1091,\"../../traces/pie/style_one\":1097,\"../../traces/scatter/subtypes\":1135,\"../color\":593,\"../drawing\":614,d3:163}],651:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/plots\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../lib\"),s=t(\"../../fonts/ploticon\"),l=o._,c=e.exports={};function u(t,e){var r,i,o=e.currentTarget,s=o.getAttribute(\"data-attr\"),l=o.getAttribute(\"data-val\")||!0,c=t._fullLayout,u={},h=a.list(t,null,!0),f=\"on\";if(\"zoom\"===s){var p,d=\"in\"===l?.5:2,g=(1+d)/2,v=(1-d)/2;for(i=0;i<h.length;i++)if(!(r=h[i]).fixedrange)if(p=r._name,\"auto\"===l)u[p+\".autorange\"]=!0;else if(\"reset\"===l){if(void 0===r._rangeInitial)u[p+\".autorange\"]=!0;else{var m=r._rangeInitial.slice();u[p+\".range[0]\"]=m[0],u[p+\".range[1]\"]=m[1]}void 0!==r._showSpikeInitial&&(u[p+\".showspikes\"]=r._showSpikeInitial,\"on\"!==f||r._showSpikeInitial||(f=\"off\"))}else{var y=[r.r2l(r.range[0]),r.r2l(r.range[1])],x=[g*y[0]+v*y[1],g*y[1]+v*y[0]];u[p+\".range[0]\"]=r.l2r(x[0]),u[p+\".range[1]\"]=r.l2r(x[1])}c._cartesianSpikesEnabled=f}else{if(\"hovermode\"!==s||\"x\"!==l&&\"y\"!==l){if(\"hovermode\"===s&&\"closest\"===l){for(i=0;i<h.length;i++)r=h[i],\"on\"!==f||r.showspikes||(f=\"off\");c._cartesianSpikesEnabled=f}}else l=c._isHoriz?\"y\":\"x\",o.setAttribute(\"data-val\",l);u[s]=l}n.call(\"_guiRelayout\",t,u)}function h(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout._subplots.gl3d,s={},l=i.split(\".\"),c=0;c<o.length;c++)s[o[c]+\".\"+l[1]]=a;var u=\"pan\"===a?a:\"zoom\";s.dragmode=u,n.call(\"_guiRelayout\",t,s)}function f(t,e){for(var r=e.currentTarget.getAttribute(\"data-attr\"),i=t._fullLayout,a=i._subplots.gl3d,o={},s=0;s<a.length;s++){var l=a[s],c=l+\".camera\",u=i[l]._scene;\"resetLastSave\"===r?(o[c+\".up\"]=u.viewInitial.up,o[c+\".eye\"]=u.viewInitial.eye,o[c+\".center\"]=u.viewInitial.center):\"resetDefault\"===r&&(o[c+\".up\"]=null,o[c+\".eye\"]=null,o[c+\".center\"]=null)}n.call(\"_guiRelayout\",t,o)}function p(t,e){var r=e.currentTarget,n=r._previousVal,i=t._fullLayout,a=i._subplots.gl3d,o=[\"xaxis\",\"yaxis\",\"zaxis\"],s={},l={};if(n)l=n,r._previousVal=null;else{for(var c=0;c<a.length;c++){var u=a[c],h=i[u],f=u+\".hovermode\";s[f]=h.hovermode,l[f]=!1;for(var p=0;p<3;p++){var d=o[p],g=u+\".\"+d+\".showspikes\";l[g]=!1,s[g]=h[d].showspikes}}r._previousVal=s}return l}function d(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout,s=o._subplots.geo,l=0;l<s.length;l++){var c=s[l],u=o[c];if(\"zoom\"===i){var h=u.projection.scale,f=\"in\"===a?2*h:.5*h;n.call(\"_guiRelayout\",t,c+\".projection.scale\",f)}else\"reset\"===i&&m(t,\"geo\")}}function g(t){var e=t._fullLayout;return!e.hovermode&&(e._has(\"cartesian\")?e._isHoriz?\"y\":\"x\":\"closest\")}function v(t){var e=g(t);n.call(\"_guiRelayout\",t,\"hovermode\",e)}function m(t,e){for(var r=t._fullLayout,i=r._subplots[e],a={},o=0;o<i.length;o++)for(var s=i[o],l=r[s]._subplot.viewInitial,c=Object.keys(l),u=0;u<c.length;u++){var h=c[u];a[s+\".\"+h]=l[h]}n.call(\"_guiRelayout\",t,a)}c.toImage={name:\"toImage\",title:function(t){var e=(t._context.toImageButtonOptions||{}).format||\"png\";return l(t,\"png\"===e?\"Download plot as a png\":\"Download plot\")},icon:s.camera,click:function(t){var e=t._context.toImageButtonOptions,r={format:e.format||\"png\"};o.notifier(l(t,\"Taking snapshot - this may take a few seconds\"),\"long\"),\"svg\"!==r.format&&o.isIE()&&(o.notifier(l(t,\"IE only supports svg.  Changing format to svg.\"),\"long\"),r.format=\"svg\"),[\"filename\",\"width\",\"height\",\"scale\"].forEach(function(t){t in e&&(r[t]=e[t])}),n.call(\"downloadImage\",t,r).then(function(e){o.notifier(l(t,\"Snapshot succeeded\")+\" - \"+e,\"long\")}).catch(function(){o.notifier(l(t,\"Sorry, there was a problem downloading your snapshot!\"),\"long\")})}},c.sendDataToCloud={name:\"sendDataToCloud\",title:function(t){return l(t,\"Edit in Chart Studio\")},icon:s.disk,click:function(t){i.sendDataToCloud(t)}},c.editInChartStudio={name:\"editInChartStudio\",title:function(t){return l(t,\"Edit in Chart Studio\")},icon:s.pencil,click:function(t){i.sendDataToCloud(t)}},c.zoom2d={name:\"zoom2d\",title:function(t){return l(t,\"Zoom\")},attr:\"dragmode\",val:\"zoom\",icon:s.zoombox,click:u},c.pan2d={name:\"pan2d\",title:function(t){return l(t,\"Pan\")},attr:\"dragmode\",val:\"pan\",icon:s.pan,click:u},c.select2d={name:\"select2d\",title:function(t){return l(t,\"Box Select\")},attr:\"dragmode\",val:\"select\",icon:s.selectbox,click:u},c.lasso2d={name:\"lasso2d\",title:function(t){return l(t,\"Lasso Select\")},attr:\"dragmode\",val:\"lasso\",icon:s.lasso,click:u},c.zoomIn2d={name:\"zoomIn2d\",title:function(t){return l(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:s.zoom_plus,click:u},c.zoomOut2d={name:\"zoomOut2d\",title:function(t){return l(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:s.zoom_minus,click:u},c.autoScale2d={name:\"autoScale2d\",title:function(t){return l(t,\"Autoscale\")},attr:\"zoom\",val:\"auto\",icon:s.autoscale,click:u},c.resetScale2d={name:\"resetScale2d\",title:function(t){return l(t,\"Reset axes\")},attr:\"zoom\",val:\"reset\",icon:s.home,click:u},c.hoverClosestCartesian={name:\"hoverClosestCartesian\",title:function(t){return l(t,\"Show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:s.tooltip_basic,gravity:\"ne\",click:u},c.hoverCompareCartesian={name:\"hoverCompareCartesian\",title:function(t){return l(t,\"Compare data on hover\")},attr:\"hovermode\",val:function(t){return t._fullLayout._isHoriz?\"y\":\"x\"},icon:s.tooltip_compare,gravity:\"ne\",click:u},c.zoom3d={name:\"zoom3d\",title:function(t){return l(t,\"Zoom\")},attr:\"scene.dragmode\",val:\"zoom\",icon:s.zoombox,click:h},c.pan3d={name:\"pan3d\",title:function(t){return l(t,\"Pan\")},attr:\"scene.dragmode\",val:\"pan\",icon:s.pan,click:h},c.orbitRotation={name:\"orbitRotation\",title:function(t){return l(t,\"Orbital rotation\")},attr:\"scene.dragmode\",val:\"orbit\",icon:s[\"3d_rotate\"],click:h},c.tableRotation={name:\"tableRotation\",title:function(t){return l(t,\"Turntable rotation\")},attr:\"scene.dragmode\",val:\"turntable\",icon:s[\"z-axis\"],click:h},c.resetCameraDefault3d={name:\"resetCameraDefault3d\",title:function(t){return l(t,\"Reset camera to default\")},attr:\"resetDefault\",icon:s.home,click:f},c.resetCameraLastSave3d={name:\"resetCameraLastSave3d\",title:function(t){return l(t,\"Reset camera to last save\")},attr:\"resetLastSave\",icon:s.movie,click:f},c.hoverClosest3d={name:\"hoverClosest3d\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=p(t,e);n.call(\"_guiRelayout\",t,r)}},c.zoomInGeo={name:\"zoomInGeo\",title:function(t){return l(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:s.zoom_plus,click:d},c.zoomOutGeo={name:\"zoomOutGeo\",title:function(t){return l(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:s.zoom_minus,click:d},c.resetGeo={name:\"resetGeo\",title:function(t){return l(t,\"Reset\")},attr:\"reset\",val:null,icon:s.autoscale,click:d},c.hoverClosestGeo={name:\"hoverClosestGeo\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:v},c.hoverClosestGl2d={name:\"hoverClosestGl2d\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:v},c.hoverClosestPie={name:\"hoverClosestPie\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:s.tooltip_basic,gravity:\"ne\",click:v},c.resetViewSankey={name:\"resetSankeyGroup\",title:function(t){return l(t,\"Reset view\")},icon:s.home,click:function(t){for(var e={\"node.groups\":[],\"node.x\":[],\"node.y\":[]},r=0;r<t._fullData.length;r++){var i=t._fullData[r]._viewInitial;e[\"node.groups\"].push(i.node.groups.slice()),e[\"node.x\"].push(i.node.x.slice()),e[\"node.y\"].push(i.node.y.slice())}n.call(\"restyle\",t,e)}},c.toggleHover={name:\"toggleHover\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=p(t,e);r.hovermode=g(t),n.call(\"_guiRelayout\",t,r)}},c.resetViews={name:\"resetViews\",title:function(t){return l(t,\"Reset views\")},icon:s.home,click:function(t,e){var r=e.currentTarget;r.setAttribute(\"data-attr\",\"zoom\"),r.setAttribute(\"data-val\",\"reset\"),u(t,e),r.setAttribute(\"data-attr\",\"resetLastSave\"),f(t,e),m(t,\"geo\"),m(t,\"mapbox\")}},c.toggleSpikelines={name:\"toggleSpikelines\",title:function(t){return l(t,\"Toggle Spike Lines\")},icon:s.spikeline,attr:\"_cartesianSpikesEnabled\",val:\"on\",click:function(t){var e=t._fullLayout;e._cartesianSpikesEnabled=\"on\"===e._cartesianSpikesEnabled?\"off\":\"on\";var r=function(t){for(var e,r,n=t._fullLayout,i=a.list(t,null,!0),o={},s=0;s<i.length;s++)e=i[s],r=e._name,o[r+\".showspikes\"]=\"on\"===n._cartesianSpikesEnabled||e._showSpikeInitial;return o}(t);n.call(\"_guiRelayout\",t,r)}},c.resetViewMapbox={name:\"resetViewMapbox\",title:function(t){return l(t,\"Reset view\")},attr:\"reset\",icon:s.home,click:function(t){m(t,\"mapbox\")}}},{\"../../fonts/ploticon\":699,\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../../plots/plots\":828,\"../../registry\":847}],652:[function(t,e,r){\"use strict\";r.manage=t(\"./manage\")},{\"./manage\":653}],653:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"../../traces/scatter/subtypes\"),a=t(\"../../registry\"),o=t(\"./modebar\"),s=t(\"./buttons\");e.exports=function(t){var e=t._fullLayout,r=t._context,l=e._modeBar;if(r.displayModeBar||r.watermark){if(!Array.isArray(r.modeBarButtonsToRemove))throw new Error([\"*modeBarButtonsToRemove* configuration options\",\"must be an array.\"].join(\" \"));if(!Array.isArray(r.modeBarButtonsToAdd))throw new Error([\"*modeBarButtonsToAdd* configuration options\",\"must be an array.\"].join(\" \"));var c,u=r.modeBarButtons;c=Array.isArray(u)&&u.length?function(t){for(var e=0;e<t.length;e++)for(var r=t[e],n=0;n<r.length;n++){var i=r[n];if(\"string\"==typeof i){if(void 0===s[i])throw new Error([\"*modeBarButtons* configuration options\",\"invalid button name\"].join(\" \"));t[e][n]=s[i]}}return t}(u):!r.displayModeBar&&r.watermark?[]:function(t){var e=t._fullLayout,r=t._fullData,o=t._context,l=o.modeBarButtonsToRemove,c=o.modeBarButtonsToAdd,u=e._has(\"cartesian\"),h=e._has(\"gl3d\"),f=e._has(\"geo\"),p=e._has(\"pie\"),d=e._has(\"funnelarea\"),g=e._has(\"gl2d\"),v=e._has(\"ternary\"),m=e._has(\"mapbox\"),y=e._has(\"polar\"),x=e._has(\"sankey\"),b=function(t){for(var e=n.list({_fullLayout:t},null,!0),r=0;r<e.length;r++)if(!e[r].fixedrange)return!1;return!0}(e),_=[];function w(t){if(t.length){for(var e=[],r=0;r<t.length;r++){var n=t[r];-1===l.indexOf(n)&&e.push(s[n])}_.push(e)}}var k=[\"toImage\"];o.showEditInChartStudio?k.push(\"editInChartStudio\"):o.showSendToCloud&&k.push(\"sendDataToCloud\");w(k);var T=[],A=[],M=[],S=[];(u||g||p||d||v)+f+h+m+y>1?(A=[\"toggleHover\"],M=[\"resetViews\"]):f?(T=[\"zoomInGeo\",\"zoomOutGeo\"],A=[\"hoverClosestGeo\"],M=[\"resetGeo\"]):h?(A=[\"hoverClosest3d\"],M=[\"resetCameraDefault3d\",\"resetCameraLastSave3d\"]):m?(A=[\"toggleHover\"],M=[\"resetViewMapbox\"]):g?A=[\"hoverClosestGl2d\"]:p?A=[\"hoverClosestPie\"]:x?(A=[\"hoverClosestCartesian\",\"hoverCompareCartesian\"],M=[\"resetViewSankey\"]):A=[\"toggleHover\"];u&&(A=[\"toggleSpikelines\",\"hoverClosestCartesian\",\"hoverCompareCartesian\"]);(function(t){for(var e=0;e<t.length;e++)if(!a.traceIs(t[e],\"noHover\"))return!1;return!0})(r)&&(A=[]);!u&&!g||b||(T=[\"zoomIn2d\",\"zoomOut2d\",\"autoScale2d\"],\"resetViews\"!==M[0]&&(M=[\"resetScale2d\"]));h?S=[\"zoom3d\",\"pan3d\",\"orbitRotation\",\"tableRotation\"]:(u||g)&&!b||v?S=[\"zoom2d\",\"pan2d\"]:m||f?S=[\"pan2d\"]:y&&(S=[\"zoom2d\"]);(function(t){for(var e=!1,r=0;r<t.length&&!e;r++){var n=t[r];n._module&&n._module.selectPoints&&(a.traceIs(n,\"scatter-like\")?(i.hasMarkers(n)||i.hasText(n))&&(e=!0):a.traceIs(n,\"box-violin\")&&\"all\"!==n.boxpoints&&\"all\"!==n.points||(e=!0))}return e})(r)&&S.push(\"select2d\",\"lasso2d\");return w(S),w(T.concat(M)),w(A),function(t,e){if(e.length)if(Array.isArray(e[0]))for(var r=0;r<e.length;r++)t.push(e[r]);else t.push(e);return t}(_,c)}(t),l?l.update(t,c):e._modeBar=o(t,c)}else l&&(l.destroy(),delete e._modeBar)}},{\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../../traces/scatter/subtypes\":1135,\"./buttons\":651,\"./modebar\":654}],654:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../fonts/ploticon\"),s=new DOMParser;function l(t){this.container=t.container,this.element=document.createElement(\"div\"),this.update(t.graphInfo,t.buttons),this.container.appendChild(this.element)}var c=l.prototype;c.update=function(t,e){this.graphInfo=t;var r=this.graphInfo._context,n=this.graphInfo._fullLayout,i=\"modebar-\"+n._uid;this.element.setAttribute(\"id\",i),this._uid=i,this.element.className=\"modebar\",\"hover\"===r.displayModeBar&&(this.element.className+=\" modebar--hover ease-bg\"),\"v\"===n.modebar.orientation&&(this.element.className+=\" vertical\",e=e.reverse());var o=n.modebar,s=\"hover\"===r.displayModeBar?\".js-plotly-plot .plotly:hover \":\"\";a.deleteRelatedStyleRule(i),a.addRelatedStyleRule(i,s+\"#\"+i+\" .modebar-group\",\"background-color: \"+o.bgcolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn .icon path\",\"fill: \"+o.color),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn:hover .icon path\",\"fill: \"+o.activecolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn.active .icon path\",\"fill: \"+o.activecolor);var l=!this.hasButtons(e),c=this.hasLogo!==r.displaylogo,u=this.locale!==r.locale;if(this.locale=r.locale,(l||c||u)&&(this.removeAllButtons(),this.updateButtons(e),r.watermark||r.displaylogo)){var h=this.getLogo();r.watermark&&(h.className=h.className+\" watermark\"),\"v\"===n.modebar.orientation?this.element.insertBefore(h,this.element.childNodes[0]):this.element.appendChild(h),this.hasLogo=!0}this.updateActiveButton()},c.updateButtons=function(t){var e=this;this.buttons=t,this.buttonElements=[],this.buttonsNames=[],this.buttons.forEach(function(t){var r=e.createGroup();t.forEach(function(t){var n=t.name;if(!n)throw new Error(\"must provide button 'name' in button config\");if(-1!==e.buttonsNames.indexOf(n))throw new Error(\"button name '\"+n+\"' is taken\");e.buttonsNames.push(n);var i=e.createButton(t);e.buttonElements.push(i),r.appendChild(i)}),e.element.appendChild(r)})},c.createGroup=function(){var t=document.createElement(\"div\");return t.className=\"modebar-group\",t},c.createButton=function(t){var e=this,r=document.createElement(\"a\");r.setAttribute(\"rel\",\"tooltip\"),r.className=\"modebar-btn\";var i=t.title;void 0===i?i=t.name:\"function\"==typeof i&&(i=i(this.graphInfo)),(i||0===i)&&r.setAttribute(\"data-title\",i),void 0!==t.attr&&r.setAttribute(\"data-attr\",t.attr);var a=t.val;if(void 0!==a&&(\"function\"==typeof a&&(a=a(this.graphInfo)),r.setAttribute(\"data-val\",a)),\"function\"!=typeof t.click)throw new Error(\"must provide button 'click' function in button config\");r.addEventListener(\"click\",function(r){t.click(e.graphInfo,r),e.updateActiveButton(r.currentTarget)}),r.setAttribute(\"data-toggle\",t.toggle||!1),t.toggle&&n.select(r).classed(\"active\",!0);var s=t.icon;return\"function\"==typeof s?r.appendChild(s()):r.appendChild(this.createIcon(s||o.question)),r.setAttribute(\"data-gravity\",t.gravity||\"n\"),r},c.createIcon=function(t){var e,r=i(t.height)?Number(t.height):t.ascent-t.descent,n=\"http://www.w3.org/2000/svg\";if(t.path){(e=document.createElementNS(n,\"svg\")).setAttribute(\"viewBox\",[0,0,t.width,r].join(\" \")),e.setAttribute(\"class\",\"icon\");var a=document.createElementNS(n,\"path\");a.setAttribute(\"d\",t.path),t.transform?a.setAttribute(\"transform\",t.transform):void 0!==t.ascent&&a.setAttribute(\"transform\",\"matrix(1 0 0 -1 0 \"+t.ascent+\")\"),e.appendChild(a)}t.svg&&(e=s.parseFromString(t.svg,\"application/xml\").childNodes[0]);return e.setAttribute(\"height\",\"1em\"),e.setAttribute(\"width\",\"1em\"),e},c.updateActiveButton=function(t){var e=this.graphInfo._fullLayout,r=void 0!==t?t.getAttribute(\"data-attr\"):null;this.buttonElements.forEach(function(t){var i=t.getAttribute(\"data-val\")||!0,o=t.getAttribute(\"data-attr\"),s=\"true\"===t.getAttribute(\"data-toggle\"),l=n.select(t);if(s)o===r&&l.classed(\"active\",!l.classed(\"active\"));else{var c=null===o?o:a.nestedProperty(e,o).get();l.classed(\"active\",c===i)}})},c.hasButtons=function(t){var e=this.buttons;if(!e)return!1;if(t.length!==e.length)return!1;for(var r=0;r<t.length;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;n++)if(t[r][n].name!==e[r][n].name)return!1}return!0},c.getLogo=function(){var t=this.createGroup(),e=document.createElement(\"a\");return e.href=\"https://plot.ly/\",e.target=\"_blank\",e.setAttribute(\"data-title\",a._(this.graphInfo,\"Produced with Plotly\")),e.className=\"modebar-btn plotlyjsicon modebar-btn--logo\",e.appendChild(this.createIcon(o.newplotlylogo)),t.appendChild(e),t},c.removeAllButtons=function(){for(;this.element.firstChild;)this.element.removeChild(this.element.firstChild);this.hasLogo=!1},c.destroy=function(){a.removeElement(this.container.querySelector(\".modebar\")),a.deleteRelatedStyleRule(this._uid)},e.exports=function(t,e){var r=t._fullLayout,i=new l({graphInfo:t,container:r._modebardiv.node(),buttons:e});return r._privateplot&&n.select(i.element).append(\"span\").classed(\"badge-private float--left\",!0).text(\"PRIVATE\"),i}},{\"../../fonts/ploticon\":699,\"../../lib\":719,d3:163,\"fast-isnumeric\":225}],655:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=(0,t(\"../../plot_api/plot_template\").templatedArray)(\"button\",{visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},step:{valType:\"enumerated\",values:[\"month\",\"year\",\"day\",\"hour\",\"minute\",\"second\",\"all\"],dflt:\"month\",editType:\"plot\"},stepmode:{valType:\"enumerated\",values:[\"backward\",\"todate\"],dflt:\"backward\",editType:\"plot\"},count:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},label:{valType:\"string\",editType:\"plot\"},editType:\"plot\"});e.exports={visible:{valType:\"boolean\",editType:\"plot\"},buttons:a,x:{valType:\"number\",min:-2,max:3,editType:\"plot\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"plot\"},y:{valType:\"number\",min:-2,max:3,editType:\"plot\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"bottom\",editType:\"plot\"},font:n({editType:\"plot\"}),bgcolor:{valType:\"color\",dflt:i.lightLine,editType:\"plot\"},activecolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"plot\"}},{\"../../plot_api/plot_template\":757,\"../../plots/font_attributes\":793,\"../color/attributes\":592}],656:[function(t,e,r){\"use strict\";e.exports={yPad:.02,minButtonWidth:30,rx:3,ry:3,lightAmount:25,darkAmount:10}},{}],657:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../../plots/array_container_defaults\"),s=t(\"./attributes\"),l=t(\"./constants\");function c(t,e,r,i){var a=i.calendar;function o(r,i){return n.coerce(t,e,s.buttons,r,i)}if(o(\"visible\")){var l=o(\"step\");\"all\"!==l&&(!a||\"gregorian\"===a||\"month\"!==l&&\"year\"!==l?o(\"stepmode\"):e.stepmode=\"backward\",o(\"count\")),o(\"label\")}}e.exports=function(t,e,r,u,h){var f=t.rangeselector||{},p=a.newContainer(e,\"rangeselector\");function d(t,e){return n.coerce(f,p,s,t,e)}if(d(\"visible\",o(f,p,{name:\"buttons\",handleItemDefaults:c,calendar:h}).length>0)){var g=function(t,e,r){for(var n=r.filter(function(r){return e[r].anchor===t._id}),i=0,a=0;a<n.length;a++){var o=e[n[a]].domain;o&&(i=Math.max(o[1],i))}return[t.domain[0],i+l.yPad]}(e,r,u);d(\"x\",g[0]),d(\"y\",g[1]),n.noneOrAll(t,e,[\"x\",\"y\"]),d(\"xanchor\"),d(\"yanchor\"),n.coerceFont(d,\"font\",r.font);var v=d(\"bgcolor\");d(\"activecolor\",i.contrast(v,l.lightAmount,l.darkAmount)),d(\"bordercolor\"),d(\"borderwidth\")}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/array_container_defaults\":763,\"../color\":593,\"./attributes\":655,\"./constants\":656}],658:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../color\"),s=t(\"../drawing\"),l=t(\"../../lib\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"../../plots/cartesian/axis_ids\"),h=t(\"../../constants/alignment\"),f=h.LINE_SPACING,p=h.FROM_TL,d=h.FROM_BR,g=t(\"./constants\"),v=t(\"./get_update_object\");function m(t){return t._id}function y(t,e,r){var n=l.ensureSingle(t,\"rect\",\"selector-rect\",function(t){t.attr(\"shape-rendering\",\"crispEdges\")});n.attr({rx:g.rx,ry:g.ry}),n.call(o.stroke,e.bordercolor).call(o.fill,function(t,e){return e._isActive||e._isHovered?t.activecolor:t.bgcolor}(e,r)).style(\"stroke-width\",e.borderwidth+\"px\")}function x(t,e,r,n){l.ensureSingle(t,\"text\",\"selector-text\",function(t){t.classed(\"user-select-none\",!0).attr(\"text-anchor\",\"middle\")}).call(s.font,e.font).text(function(t,e){if(t.label)return e?l.templateString(t.label,e):t.label;return\"all\"===t.step?\"all\":t.count+t.step.charAt(0)}(r,n._fullLayout._meta)).call(function(t){c.convertToTspans(t,n)})}e.exports=function(t){var e=t._fullLayout._infolayer.selectAll(\".rangeselector\").data(function(t){for(var e=u.list(t,\"x\",!0),r=[],n=0;n<e.length;n++){var i=e[n];i.rangeselector&&i.rangeselector.visible&&r.push(i)}return r}(t),m);e.enter().append(\"g\").classed(\"rangeselector\",!0),e.exit().remove(),e.style({cursor:\"pointer\",\"pointer-events\":\"all\"}),e.each(function(e){var r=n.select(this),o=e,u=o.rangeselector,h=r.selectAll(\"g.button\").data(l.filterVisible(u.buttons));h.enter().append(\"g\").classed(\"button\",!0),h.exit().remove(),h.each(function(e){var r=n.select(this),a=v(o,e);e._isActive=function(t,e,r){if(\"all\"===e.step)return!0===t.autorange;var n=Object.keys(r);return t.range[0]===r[n[0]]&&t.range[1]===r[n[1]]}(o,e,a),r.call(y,u,e),r.call(x,u,e,t),r.on(\"click\",function(){t._dragged||i.call(\"_guiRelayout\",t,a)}),r.on(\"mouseover\",function(){e._isHovered=!0,r.call(y,u,e)}),r.on(\"mouseout\",function(){e._isHovered=!1,r.call(y,u,e)})}),function(t,e,r,i,o){var u=0,h=0,v=r.borderwidth;e.each(function(){var t=n.select(this),e=t.select(\".selector-text\"),i=r.font.size*f,a=Math.max(i*c.lineCount(e),16)+3;h=Math.max(h,a)}),e.each(function(){var t=n.select(this),e=t.select(\".selector-rect\"),i=t.select(\".selector-text\"),a=i.node()&&s.bBox(i.node()).width,o=r.font.size*f,l=c.lineCount(i),p=Math.max(a+10,g.minButtonWidth);t.attr(\"transform\",\"translate(\"+(v+u)+\",\"+v+\")\"),e.attr({x:0,y:0,width:p,height:h}),c.positionText(i,p/2,h/2-(l-1)*o/2+3),u+=p+5});var m=t._fullLayout._size,y=m.l+m.w*r.x,x=m.t+m.h*(1-r.y),b=\"left\";l.isRightAnchor(r)&&(y-=u,b=\"right\");l.isCenterAnchor(r)&&(y-=u/2,b=\"center\");var _=\"top\";l.isBottomAnchor(r)&&(x-=h,_=\"bottom\");l.isMiddleAnchor(r)&&(x-=h/2,_=\"middle\");u=Math.ceil(u),h=Math.ceil(h),y=Math.round(y),x=Math.round(x),a.autoMargin(t,i+\"-range-selector\",{x:r.x,y:r.y,l:u*p[b],r:u*d[b],b:h*d[_],t:h*p[_]}),o.attr(\"transform\",\"translate(\"+y+\",\"+x+\")\")}(t,h,u,o._name,r)})}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axis_ids\":770,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../drawing\":614,\"./constants\":656,\"./get_update_object\":659,d3:163}],659:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e){var r=t._name,i={};if(\"all\"===e.step)i[r+\".autorange\"]=!0;else{var a=function(t,e){var r,i=t.range,a=new Date(t.r2l(i[1])),o=e.step,s=e.count;switch(e.stepmode){case\"backward\":r=t.l2r(+n.time[o].utc.offset(a,-s));break;case\"todate\":var l=n.time[o].utc.offset(a,-s);r=t.l2r(+n.time[o].utc.ceil(l))}var c=i[1];return[r,c]}(t,e);i[r+\".range[0]\"]=a[0],i[r+\".range[1]\"]=a[1]}return i}},{d3:163}],660:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"rangeselector\",schema:{subplots:{xaxis:{rangeselector:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":655,\"./defaults\":657,\"./draw\":658}],661:[function(t,e,r){\"use strict\";var n=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",dflt:n.background,editType:\"plot\"},bordercolor:{valType:\"color\",dflt:n.defaultLine,editType:\"plot\"},borderwidth:{valType:\"integer\",dflt:0,min:0,editType:\"plot\"},autorange:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}}],editType:\"calc\",impliedEdits:{autorange:!1}},thickness:{valType:\"number\",dflt:.15,min:0,max:1,editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"}},{\"../color/attributes\":592}],662:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\").list,i=t(\"../../plots/cartesian/autorange\").getAutoRange,a=t(\"./constants\");e.exports=function(t){for(var e=n(t,\"x\",!0),r=0;r<e.length;r++){var o=e[r],s=o[a.name];s&&s.visible&&s.autorange&&(s._input.autorange=!0,s._input.range=s.range=i(t,o))}}},{\"../../plots/cartesian/autorange\":766,\"../../plots/cartesian/axis_ids\":770,\"./constants\":663}],663:[function(t,e,r){\"use strict\";e.exports={name:\"rangeslider\",containerClassName:\"rangeslider-container\",bgClassName:\"rangeslider-bg\",rangePlotClassName:\"rangeslider-rangeplot\",maskMinClassName:\"rangeslider-mask-min\",maskMaxClassName:\"rangeslider-mask-max\",slideBoxClassName:\"rangeslider-slidebox\",grabberMinClassName:\"rangeslider-grabber-min\",grabAreaMinClassName:\"rangeslider-grabarea-min\",handleMinClassName:\"rangeslider-handle-min\",grabberMaxClassName:\"rangeslider-grabber-max\",grabAreaMaxClassName:\"rangeslider-grabarea-max\",handleMaxClassName:\"rangeslider-handle-max\",maskMinOppAxisClassName:\"rangeslider-mask-min-opp-axis\",maskMaxOppAxisClassName:\"rangeslider-mask-max-opp-axis\",maskColor:\"rgba(0,0,0,0.4)\",maskOppAxisColor:\"rgba(0,0,0,0.2)\",slideBoxFill:\"transparent\",slideBoxCursor:\"ew-resize\",grabAreaFill:\"transparent\",grabAreaCursor:\"col-resize\",grabAreaWidth:10,handleWidth:4,handleRadius:1,handleStrokeWidth:1,extraPad:15}},{}],664:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"./attributes\"),s=t(\"./oppaxis_attributes\");e.exports=function(t,e,r){var l=t[r],c=e[r];if(l.rangeslider||e._requestRangeslider[c._id]){n.isPlainObject(l.rangeslider)||(l.rangeslider={});var u,h,f=l.rangeslider,p=i.newContainer(c,\"rangeslider\");if(_(\"visible\")){_(\"bgcolor\",e.plot_bgcolor),_(\"bordercolor\"),_(\"borderwidth\"),_(\"thickness\"),_(\"autorange\",!c.isValidRange(f.range)),_(\"range\");var d=e._subplots;if(d)for(var g=d.cartesian.filter(function(t){return t.substr(0,t.indexOf(\"y\"))===a.name2id(r)}).map(function(t){return t.substr(t.indexOf(\"y\"),t.length)}),v=n.simpleMap(g,a.id2name),m=0;m<v.length;m++){var y=v[m];u=f[y]||{},h=i.newContainer(p,y,\"yaxis\");var x,b=e[y];u.range&&b.isValidRange(u.range)&&(x=\"fixed\"),\"match\"!==w(\"rangemode\",x)&&w(\"range\",b.range.slice())}p._input=f}}function _(t,e){return n.coerce(f,p,o,t,e)}function w(t,e){return n.coerce(u,h,s,t,e)}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/axis_ids\":770,\"./attributes\":661,\"./oppaxis_attributes\":668}],665:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=t(\"../drawing\"),l=t(\"../color\"),c=t(\"../titles\"),u=t(\"../../plots/cartesian\"),h=t(\"../../plots/cartesian/axis_ids\"),f=t(\"../dragelement\"),p=t(\"../../lib/setcursor\"),d=t(\"./constants\");function g(t,e,r,n){var i=o.ensureSingle(t,\"rect\",d.bgClassName,function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})}),a=n.borderwidth%2==0?n.borderwidth:n.borderwidth-1,l=-n._offsetShift,c=s.crispRound(e,n.borderwidth);i.attr({width:n._width+a,height:n._height+a,transform:\"translate(\"+l+\",\"+l+\")\",fill:n.bgcolor,stroke:n.bordercolor,\"stroke-width\":c})}function v(t,e,r,n){var i=e._fullLayout;o.ensureSingleById(i._topdefs,\"clipPath\",n._clipId,function(t){t.append(\"rect\").attr({x:0,y:0})}).select(\"rect\").attr({width:n._width,height:n._height})}function m(t,e,r,i){var l,c=e.calcdata,f=t.selectAll(\"g.\"+d.rangePlotClassName).data(r._subplotsWith,o.identity);f.enter().append(\"g\").attr(\"class\",function(t){return d.rangePlotClassName+\" \"+t}).call(s.setClipUrl,i._clipId,e),f.order(),f.exit().remove(),f.each(function(t,o){var s=n.select(this),f=0===o,p=h.getFromId(e,t,\"y\"),d=p._name,g=i[d],v={data:[],layout:{xaxis:{type:r.type,domain:[0,1],range:i.range.slice(),calendar:r.calendar},width:i._width,height:i._height,margin:{t:0,b:0,l:0,r:0}},_context:e._context};v.layout[d]={type:p.type,domain:[0,1],range:\"match\"!==g.rangemode?g.range.slice():p.range.slice(),calendar:p.calendar},a.supplyDefaults(v);var m=v._fullLayout.xaxis,y=v._fullLayout[d];m.clearCalc(),m.setScale(),y.clearCalc(),y.setScale();var x={id:t,plotgroup:s,xaxis:m,yaxis:y,isRangePlot:!0};f?l=x:(x.mainplot=\"xy\",x.mainplotinfo=l),u.rangePlot(e,x,function(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n],a=i[0].trace;a.xaxis+a.yaxis===e&&r.push(i)}return r}(c,t))})}function y(t,e,r,n,i){(o.ensureSingle(t,\"rect\",d.maskMinClassName,function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"height\",n._height).call(l.fill,d.maskColor),o.ensureSingle(t,\"rect\",d.maskMaxClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"height\",n._height).call(l.fill,d.maskColor),\"match\"!==i.rangemode)&&(o.ensureSingle(t,\"rect\",d.maskMinOppAxisClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"width\",n._width).call(l.fill,d.maskOppAxisColor),o.ensureSingle(t,\"rect\",d.maskMaxOppAxisClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"width\",n._width).style(\"border-top\",d.maskOppBorder).call(l.fill,d.maskOppAxisColor))}function x(t,e,r,n){e._context.staticPlot||o.ensureSingle(t,\"rect\",d.slideBoxClassName,function(t){t.attr({y:0,cursor:d.slideBoxCursor,\"shape-rendering\":\"crispEdges\"})}).attr({height:n._height,fill:d.slideBoxFill})}function b(t,e,r,n){var i=o.ensureSingle(t,\"g\",d.grabberMinClassName),a=o.ensureSingle(t,\"g\",d.grabberMaxClassName),s={x:0,width:d.handleWidth,rx:d.handleRadius,fill:l.background,stroke:l.defaultLine,\"stroke-width\":d.handleStrokeWidth,\"shape-rendering\":\"crispEdges\"},c={y:Math.round(n._height/4),height:Math.round(n._height/2)};if(o.ensureSingle(i,\"rect\",d.handleMinClassName,function(t){t.attr(s)}).attr(c),o.ensureSingle(a,\"rect\",d.handleMaxClassName,function(t){t.attr(s)}).attr(c),!e._context.staticPlot){var u={width:d.grabAreaWidth,x:0,y:0,fill:d.grabAreaFill,cursor:d.grabAreaCursor};o.ensureSingle(i,\"rect\",d.grabAreaMinClassName,function(t){t.attr(u)}).attr(\"height\",n._height),o.ensureSingle(a,\"rect\",d.grabAreaMaxClassName,function(t){t.attr(u)}).attr(\"height\",n._height)}}e.exports=function(t){for(var e=t._fullLayout,r=e._rangeSliderData,a=0;a<r.length;a++){var s=r[a][d.name];s._clipId=s._id+\"-\"+e._uid}var l=e._infolayer.selectAll(\"g.\"+d.containerClassName).data(r,function(t){return t._name});l.exit().each(function(t){var r=t[d.name];e._topdefs.select(\"#\"+r._clipId).remove()}).remove(),0!==r.length&&(l.enter().append(\"g\").classed(d.containerClassName,!0).attr(\"pointer-events\",\"all\"),l.each(function(r){var a=n.select(this),s=r[d.name],l=e[h.id2name(r.anchor)],u=s[h.id2name(r.anchor)];if(s.range){var _,w=o.simpleMap(s.range,r.r2l),k=o.simpleMap(r.range,r.r2l);_=k[0]<k[1]?[Math.min(w[0],k[0]),Math.max(w[1],k[1])]:[Math.max(w[0],k[0]),Math.min(w[1],k[1])],s.range=s._input.range=o.simpleMap(_,r.l2r)}r.cleanRange(\"rangeslider.range\");var T=e.margin,A=e._size,M=r.domain,S=s._tickHeight,E=s._oppBottom;s._width=A.w*(M[1]-M[0]);var C=Math.round(T.l+A.w*M[0]),L=Math.round(A.t+A.h*(1-E)+S+s._offsetShift+d.extraPad);a.attr(\"transform\",\"translate(\"+C+\",\"+L+\")\");var P=r.r2l(s.range[0]),O=r.r2l(s.range[1]),z=O-P;if(s.p2d=function(t){return t/s._width*z+P},s.d2p=function(t){return(t-P)/z*s._width},s._rl=[P,O],\"match\"!==u.rangemode){var I=l.r2l(u.range[0]),D=l.r2l(u.range[1])-I;s.d2pOppAxis=function(t){return(t-I)/D*s._height}}a.call(g,t,r,s).call(v,t,r,s).call(m,t,r,s).call(y,t,r,s,u).call(x,t,r,s).call(b,t,r,s),function(t,e,r,a){var s=t.select(\"rect.\"+d.slideBoxClassName).node(),l=t.select(\"rect.\"+d.grabAreaMinClassName).node(),c=t.select(\"rect.\"+d.grabAreaMaxClassName).node();t.on(\"mousedown\",function(){var u=n.event,h=u.target,d=u.clientX,g=d-t.node().getBoundingClientRect().left,v=a.d2p(r._rl[0]),m=a.d2p(r._rl[1]),y=f.coverSlip();function x(t){var u,f,x,b=+t.clientX-d;switch(h){case s:x=\"ew-resize\",u=v+b,f=m+b;break;case l:x=\"col-resize\",u=v+b,f=m;break;case c:x=\"col-resize\",u=v,f=m+b;break;default:x=\"ew-resize\",u=g,f=g+b}if(f<u){var _=f;f=u,u=_}a._pixelMin=u,a._pixelMax=f,p(n.select(y),x),function(t,e,r,n){function a(t){return r.l2r(o.constrain(t,n._rl[0],n._rl[1]))}var s=a(n.p2d(n._pixelMin)),l=a(n.p2d(n._pixelMax));window.requestAnimationFrame(function(){i.call(\"_guiRelayout\",e,r._name+\".range\",[s,l])})}(0,e,r,a)}y.addEventListener(\"mousemove\",x),y.addEventListener(\"mouseup\",function t(){y.removeEventListener(\"mousemove\",x);y.removeEventListener(\"mouseup\",t);o.removeElement(y)})})}(a,t,r,s),function(t,e,r,n,i,a){var s=d.handleWidth/2;function l(t){return o.constrain(t,0,n._width)}function c(t){return o.constrain(t,0,n._height)}function u(t){return o.constrain(t,-s,n._width+s)}var h=l(n.d2p(r._rl[0])),f=l(n.d2p(r._rl[1]));if(t.select(\"rect.\"+d.slideBoxClassName).attr(\"x\",h).attr(\"width\",f-h),t.select(\"rect.\"+d.maskMinClassName).attr(\"width\",h),t.select(\"rect.\"+d.maskMaxClassName).attr(\"x\",f).attr(\"width\",n._width-f),\"match\"!==a.rangemode){var p=n._height-c(n.d2pOppAxis(i._rl[1])),g=n._height-c(n.d2pOppAxis(i._rl[0]));t.select(\"rect.\"+d.maskMinOppAxisClassName).attr(\"x\",h).attr(\"height\",p).attr(\"width\",f-h),t.select(\"rect.\"+d.maskMaxOppAxisClassName).attr(\"x\",h).attr(\"y\",g).attr(\"height\",n._height-g).attr(\"width\",f-h),t.select(\"rect.\"+d.slideBoxClassName).attr(\"y\",p).attr(\"height\",g-p)}var v=Math.round(u(h-s))-.5,m=Math.round(u(f-s))+.5;t.select(\"g.\"+d.grabberMinClassName).attr(\"transform\",\"translate(\"+v+\",0.5)\"),t.select(\"g.\"+d.grabberMaxClassName).attr(\"transform\",\"translate(\"+m+\",0.5)\")}(a,0,r,s,l,u),\"bottom\"===r.side&&c.draw(t,r._id+\"title\",{propContainer:r,propName:r._name+\".title\",placeholder:e._dfltTitle.x,attributes:{x:r._offset+r._length/2,y:L+s._height+s._offsetShift+10+1.5*r.title.font.size,\"text-anchor\":\"middle\"}})}))}},{\"../../lib\":719,\"../../lib/setcursor\":739,\"../../plots/cartesian\":778,\"../../plots/cartesian/axis_ids\":770,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"../titles\":681,\"./constants\":663,d3:163}],666:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"./constants\"),a=i.name;function o(t){var e=t&&t[a];return e&&e.visible}r.isVisible=o,r.makeData=function(t){var e=n.list({_fullLayout:t},\"x\",!0),r=t.margin,i=[];if(!t._has(\"gl2d\"))for(var s=0;s<e.length;s++){var l=e[s];if(o(l)){i.push(l);var c=l[a];c._id=a+l._id,c._height=(t.height-r.b-r.t)*c.thickness,c._offsetShift=Math.floor(c.borderwidth/2)}}t._rangeSliderData=i},r.autoMarginOpts=function(t,e){for(var r=e[a],o=1/0,s=e._counterAxes,l=0;l<s.length;l++){var c=s[l],u=n.getFromId(t,c);o=Math.min(o,u.domain[0])}r._oppBottom=o;var h=\"bottom\"===e.side&&e._boundingBox.height||0;return r._tickHeight=h,{x:0,y:o,l:0,r:0,t:0,b:r._height+t._fullLayout.margin.b+h,pad:i.extraPad+2*r._offsetShift}}},{\"../../plots/cartesian/axis_ids\":770,\"./constants\":663}],667:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./oppaxis_attributes\"),o=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"rangeslider\",schema:{subplots:{xaxis:{rangeslider:n.extendFlat({},i,{yaxis:a})}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),calcAutorange:t(\"./calc_autorange\"),draw:t(\"./draw\"),isVisible:o.isVisible,makeData:o.makeData,autoMarginOpts:o.autoMarginOpts}},{\"../../lib\":719,\"./attributes\":661,\"./calc_autorange\":662,\"./defaults\":664,\"./draw\":665,\"./helpers\":666,\"./oppaxis_attributes\":668}],668:[function(t,e,r){\"use strict\";e.exports={_isSubplotObj:!0,rangemode:{valType:\"enumerated\",values:[\"auto\",\"fixed\",\"match\"],dflt:\"match\",editType:\"calc\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"plot\"},{valType:\"any\",editType:\"plot\"}],editType:\"plot\"},editType:\"calc\"}},{}],669:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../traces/scatter/attributes\").line,a=t(\"../drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray;e.exports=s(\"shape\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},type:{valType:\"enumerated\",values:[\"circle\",\"rect\",\"path\",\"line\"],editType:\"calc+arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},xref:o({},n.xref,{}),xsizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},xanchor:{valType:\"any\",editType:\"calc+arraydraw\"},x0:{valType:\"any\",editType:\"calc+arraydraw\"},x1:{valType:\"any\",editType:\"calc+arraydraw\"},yref:o({},n.yref,{}),ysizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},yanchor:{valType:\"any\",editType:\"calc+arraydraw\"},y0:{valType:\"any\",editType:\"calc+arraydraw\"},y1:{valType:\"any\",editType:\"calc+arraydraw\"},path:{valType:\"string\",editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},line:{color:o({},i.color,{editType:\"arraydraw\"}),width:o({},i.width,{editType:\"calc+arraydraw\"}),dash:o({},a,{editType:\"arraydraw\"}),editType:\"calc+arraydraw\"},fillcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},editType:\"arraydraw\"})},{\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../../traces/scatter/attributes\":1112,\"../annotations/attributes\":576,\"../drawing/attributes\":613}],670:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./constants\"),o=t(\"./helpers\");function s(t){return c(t.line.width,t.xsizemode,t.x0,t.x1,t.path,!1)}function l(t){return c(t.line.width,t.ysizemode,t.y0,t.y1,t.path,!0)}function c(t,e,r,i,s,l){var c=t/2,u=l;if(\"pixel\"===e){var h=s?o.extractPathCoords(s,l?a.paramIsY:a.paramIsX):[r,i],f=n.aggNums(Math.max,null,h),p=n.aggNums(Math.min,null,h),d=p<0?Math.abs(p)+c:c,g=f>0?f+c:c;return{ppad:c,ppadplus:u?d:g,ppadminus:u?g:d}}return{ppad:c}}function u(t,e,r,n,i){var s=\"category\"===t.type||\"multicategory\"===t.type?t.r2c:t.d2c;if(void 0!==e)return[s(e),s(r)];if(n){var l,c,u,h,f=1/0,p=-1/0,d=n.match(a.segmentRE);for(\"date\"===t.type&&(s=o.decodeDate(s)),l=0;l<d.length;l++)void 0!==(c=i[d[l].charAt(0)].drawn)&&(!(u=d[l].substr(1).match(a.paramRE))||u.length<c||((h=s(u[c]))<f&&(f=h),h>p&&(p=h)));return p>=f?[f,p]:void 0}}e.exports=function(t){var e=t._fullLayout,r=n.filterVisible(e.shapes);if(r.length&&t._fullData.length)for(var o=0;o<r.length;o++){var c,h,f=r[o];if(f._extremes={},\"paper\"!==f.xref){var p=\"pixel\"===f.xsizemode?f.xanchor:f.x0,d=\"pixel\"===f.xsizemode?f.xanchor:f.x1;(h=u(c=i.getFromId(t,f.xref),p,d,f.path,a.paramIsX))&&(f._extremes[c._id]=i.findExtremes(c,h,s(f)))}if(\"paper\"!==f.yref){var g=\"pixel\"===f.ysizemode?f.yanchor:f.y0,v=\"pixel\"===f.ysizemode?f.yanchor:f.y1;(h=u(c=i.getFromId(t,f.yref),g,v,f.path,a.paramIsY))&&(f._extremes[c._id]=i.findExtremes(c,h,l(f)))}}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./constants\":671,\"./helpers\":674}],671:[function(t,e,r){\"use strict\";e.exports={segmentRE:/[MLHVQCTSZ][^MLHVQCTSZ]*/g,paramRE:/[^\\s,]+/g,paramIsX:{M:{0:!0,drawn:0},L:{0:!0,drawn:0},H:{0:!0,drawn:0},V:{},Q:{0:!0,2:!0,drawn:2},C:{0:!0,2:!0,4:!0,drawn:4},T:{0:!0,drawn:0},S:{0:!0,2:!0,drawn:2},Z:{}},paramIsY:{M:{1:!0,drawn:1},L:{1:!0,drawn:1},H:{},V:{0:!0,drawn:0},Q:{1:!0,3:!0,drawn:3},C:{1:!0,3:!0,5:!0,drawn:5},T:{1:!0,drawn:1},S:{1:!0,3:!0,drawn:5},Z:{}},numParams:{M:2,L:2,H:1,V:1,Q:4,C:6,T:2,S:4,Z:0}}},{}],672:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\"),s=t(\"./helpers\");function l(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}if(a(\"visible\")){a(\"layer\"),a(\"opacity\"),a(\"fillcolor\"),a(\"line.color\"),a(\"line.width\"),a(\"line.dash\");for(var l=a(\"type\",t.path?\"path\":\"rect\"),c=a(\"xsizemode\"),u=a(\"ysizemode\"),h=[\"x\",\"y\"],f=0;f<2;f++){var p,d,g,v=h[f],m=v+\"anchor\",y=\"x\"===v?c:u,x={_fullLayout:r},b=i.coerceRef(t,e,x,v,\"\",\"paper\");if(\"paper\"!==b?((p=i.getFromId(x,b))._shapeIndices.push(e._index),g=s.rangeToShapePosition(p),d=s.shapePositionToRange(p)):d=g=n.identity,\"path\"!==l){var _=v+\"0\",w=v+\"1\",k=t[_],T=t[w];t[_]=d(t[_],!0),t[w]=d(t[w],!0),\"pixel\"===y?(a(_,0),a(w,10)):(i.coercePosition(e,x,a,b,_,.25),i.coercePosition(e,x,a,b,w,.75)),e[_]=g(e[_]),e[w]=g(e[w]),t[_]=k,t[w]=T}if(\"pixel\"===y){var A=t[m];t[m]=d(t[m],!0),i.coercePosition(e,x,a,b,m,.25),e[m]=g(e[m]),t[m]=A}}\"path\"===l?a(\"path\"):n.noneOrAll(t,e,[\"x0\",\"x1\",\"y0\",\"y1\"])}}e.exports=function(t,e){a(t,e,{name:\"shapes\",handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"./attributes\":669,\"./helpers\":674}],673:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../color\"),s=t(\"../drawing\"),l=t(\"../../plot_api/plot_template\").arrayEditor,c=t(\"../dragelement\"),u=t(\"../../lib/setcursor\"),h=t(\"./constants\"),f=t(\"./helpers\");function p(t,e){t._fullLayout._paperdiv.selectAll('.shapelayer [data-index=\"'+e+'\"]').remove();var r=t._fullLayout.shapes[e]||{};if(r._input&&!1!==r.visible)if(\"below\"!==r.layer)m(t._fullLayout._shapeUpperLayer);else if(\"paper\"===r.xref||\"paper\"===r.yref)m(t._fullLayout._shapeLowerLayer);else{var p=t._fullLayout._plots[r.xref+r.yref];if(p)m((p.mainplotinfo||p).shapelayer);else m(t._fullLayout._shapeLowerLayer)}function m(p){var m={\"data-index\":e,\"fill-rule\":\"evenodd\",d:g(t,r)},y=r.line.width?r.line.color:\"rgba(0,0,0,0)\",x=p.append(\"path\").attr(m).style(\"opacity\",r.opacity).call(o.stroke,y).call(o.fill,r.fillcolor).call(s.dashLine,r.line.dash,r.line.width);d(x,t,r),t._context.edits.shapePosition&&function(t,e,r,o,p){var m,y,x,b,_,w,k,T,A,M,S,E,C,L,P,O,z=10,I=10,D=\"pixel\"===r.xsizemode,R=\"pixel\"===r.ysizemode,F=\"line\"===r.type,B=\"path\"===r.type,N=l(t.layout,\"shapes\",r),j=N.modifyItem,U=a.getFromId(t,r.xref),V=a.getFromId(t,r.yref),q=f.getDataToPixel(t,U),H=f.getDataToPixel(t,V,!0),G=f.getPixelToData(t,U),Y=f.getPixelToData(t,V,!0),W=F?function(){var t=Math.max(r.line.width,10),n=p.append(\"g\").attr(\"data-index\",o);n.append(\"path\").attr(\"d\",e.attr(\"d\")).style({cursor:\"move\",\"stroke-width\":t,\"stroke-opacity\":\"0\"});var i={\"fill-opacity\":\"0\"},a=t/2>10?t/2:10;return n.append(\"circle\").attr({\"data-line-point\":\"start-point\",cx:D?q(r.xanchor)+r.x0:q(r.x0),cy:R?H(r.yanchor)-r.y0:H(r.y0),r:a}).style(i).classed(\"cursor-grab\",!0),n.append(\"circle\").attr({\"data-line-point\":\"end-point\",cx:D?q(r.xanchor)+r.x1:q(r.x1),cy:R?H(r.yanchor)-r.y1:H(r.y1),r:a}).style(i).classed(\"cursor-grab\",!0),n}():e,X={element:W.node(),gd:t,prepFn:function(n){D&&(_=q(r.xanchor));R&&(w=H(r.yanchor));\"path\"===r.type?P=r.path:(m=D?r.x0:q(r.x0),y=R?r.y0:H(r.y0),x=D?r.x1:q(r.x1),b=R?r.y1:H(r.y1));m<x?(A=m,C=\"x0\",M=x,L=\"x1\"):(A=x,C=\"x1\",M=m,L=\"x0\");!R&&y<b||R&&y>b?(k=y,S=\"y0\",T=b,E=\"y1\"):(k=b,S=\"y1\",T=y,E=\"y0\");Z(n),$(p,r),function(t,e,r){var n=e.xref,i=e.yref,o=a.getFromId(r,n),l=a.getFromId(r,i),c=\"\";\"paper\"===n||o.autorange||(c+=n);\"paper\"===i||l.autorange||(c+=i);s.setClipUrl(t,c?\"clip\"+r._fullLayout._uid+c:null,r)}(e,r,t),X.moveFn=\"move\"===O?J:K},doneFn:function(){u(e),Q(p),d(e,t,r),n.call(\"_guiRelayout\",t,N.getUpdateObj())},clickFn:function(){Q(p)}};function Z(t){if(F)O=\"path\"===t.target.tagName?\"move\":\"start-point\"===t.target.attributes[\"data-line-point\"].value?\"resize-over-start-point\":\"resize-over-end-point\";else{var r=X.element.getBoundingClientRect(),n=r.right-r.left,i=r.bottom-r.top,a=t.clientX-r.left,o=t.clientY-r.top,s=!B&&n>z&&i>I&&!t.shiftKey?c.getCursor(a/n,1-o/i):\"move\";u(e,s),O=s.split(\"-\")[0]}}function J(n,i){if(\"path\"===r.type){var a=function(t){return t},o=a,s=a;D?j(\"xanchor\",r.xanchor=G(_+n)):(o=function(t){return G(q(t)+n)},U&&\"date\"===U.type&&(o=f.encodeDate(o))),R?j(\"yanchor\",r.yanchor=Y(w+i)):(s=function(t){return Y(H(t)+i)},V&&\"date\"===V.type&&(s=f.encodeDate(s))),j(\"path\",r.path=v(P,o,s))}else D?j(\"xanchor\",r.xanchor=G(_+n)):(j(\"x0\",r.x0=G(m+n)),j(\"x1\",r.x1=G(x+n))),R?j(\"yanchor\",r.yanchor=Y(w+i)):(j(\"y0\",r.y0=Y(y+i)),j(\"y1\",r.y1=Y(b+i)));e.attr(\"d\",g(t,r)),$(p,r)}function K(n,i){if(B){var a=function(t){return t},o=a,s=a;D?j(\"xanchor\",r.xanchor=G(_+n)):(o=function(t){return G(q(t)+n)},U&&\"date\"===U.type&&(o=f.encodeDate(o))),R?j(\"yanchor\",r.yanchor=Y(w+i)):(s=function(t){return Y(H(t)+i)},V&&\"date\"===V.type&&(s=f.encodeDate(s))),j(\"path\",r.path=v(P,o,s))}else if(F){if(\"resize-over-start-point\"===O){var l=m+n,c=R?y-i:y+i;j(\"x0\",r.x0=D?l:G(l)),j(\"y0\",r.y0=R?c:Y(c))}else if(\"resize-over-end-point\"===O){var u=x+n,h=R?b-i:b+i;j(\"x1\",r.x1=D?u:G(u)),j(\"y1\",r.y1=R?h:Y(h))}}else{var d=~O.indexOf(\"n\")?k+i:k,N=~O.indexOf(\"s\")?T+i:T,W=~O.indexOf(\"w\")?A+n:A,X=~O.indexOf(\"e\")?M+n:M;~O.indexOf(\"n\")&&R&&(d=k-i),~O.indexOf(\"s\")&&R&&(N=T-i),(!R&&N-d>I||R&&d-N>I)&&(j(S,r[S]=R?d:Y(d)),j(E,r[E]=R?N:Y(N))),X-W>z&&(j(C,r[C]=D?W:G(W)),j(L,r[L]=D?X:G(X)))}e.attr(\"d\",g(t,r)),$(p,r)}function $(t,e){(D||R)&&function(){var r=\"path\"!==e.type,n=t.selectAll(\".visual-cue\").data([0]);n.enter().append(\"path\").attr({fill:\"#fff\",\"fill-rule\":\"evenodd\",stroke:\"#000\",\"stroke-width\":1}).classed(\"visual-cue\",!0);var a=q(D?e.xanchor:i.midRange(r?[e.x0,e.x1]:f.extractPathCoords(e.path,h.paramIsX))),o=H(R?e.yanchor:i.midRange(r?[e.y0,e.y1]:f.extractPathCoords(e.path,h.paramIsY)));if(a=f.roundPositionForSharpStrokeRendering(a,1),o=f.roundPositionForSharpStrokeRendering(o,1),D&&R){var s=\"M\"+(a-1-1)+\",\"+(o-1-1)+\"h-8v2h8 v8h2v-8 h8v-2h-8 v-8h-2 Z\";n.attr(\"d\",s)}else if(D){var l=\"M\"+(a-1-1)+\",\"+(o-9-1)+\"v18 h2 v-18 Z\";n.attr(\"d\",l)}else{var c=\"M\"+(a-9-1)+\",\"+(o-1-1)+\"h18 v2 h-18 Z\";n.attr(\"d\",c)}}()}function Q(t){t.selectAll(\".visual-cue\").remove()}c.init(X),W.node().onmousemove=Z}(t,x,r,e,p)}}function d(t,e,r){var n=(r.xref+r.yref).replace(/paper/g,\"\");s.setClipUrl(t,n?\"clip\"+e._fullLayout._uid+n:null,e)}function g(t,e){var r,n,o,s,l,c,u,p,d=e.type,g=a.getFromId(t,e.xref),v=a.getFromId(t,e.yref),m=t._fullLayout._size;if(g?(r=f.shapePositionToRange(g),n=function(t){return g._offset+g.r2p(r(t,!0))}):n=function(t){return m.l+m.w*t},v?(o=f.shapePositionToRange(v),s=function(t){return v._offset+v.r2p(o(t,!0))}):s=function(t){return m.t+m.h*(1-t)},\"path\"===d)return g&&\"date\"===g.type&&(n=f.decodeDate(n)),v&&\"date\"===v.type&&(s=f.decodeDate(s)),function(t,e,r){var n=t.path,a=t.xsizemode,o=t.ysizemode,s=t.xanchor,l=t.yanchor;return n.replace(h.segmentRE,function(t){var n=0,c=t.charAt(0),u=h.paramIsX[c],f=h.paramIsY[c],p=h.numParams[c],d=t.substr(1).replace(h.paramRE,function(t){return u[n]?t=\"pixel\"===a?e(s)+Number(t):e(t):f[n]&&(t=\"pixel\"===o?r(l)-Number(t):r(t)),++n>p&&(t=\"X\"),t});return n>p&&(d=d.replace(/[\\s,]*X.*/,\"\"),i.log(\"Ignoring extra params in segment \"+t)),c+d})}(e,n,s);if(\"pixel\"===e.xsizemode){var y=n(e.xanchor);l=y+e.x0,c=y+e.x1}else l=n(e.x0),c=n(e.x1);if(\"pixel\"===e.ysizemode){var x=s(e.yanchor);u=x-e.y0,p=x-e.y1}else u=s(e.y0),p=s(e.y1);if(\"line\"===d)return\"M\"+l+\",\"+u+\"L\"+c+\",\"+p;if(\"rect\"===d)return\"M\"+l+\",\"+u+\"H\"+c+\"V\"+p+\"H\"+l+\"Z\";var b=(l+c)/2,_=(u+p)/2,w=Math.abs(b-l),k=Math.abs(_-u),T=\"A\"+w+\",\"+k,A=b+w+\",\"+_;return\"M\"+A+T+\" 0 1,1 \"+(b+\",\"+(_-k))+T+\" 0 0,1 \"+A+\"Z\"}function v(t,e,r){return t.replace(h.segmentRE,function(t){var n=0,i=t.charAt(0),a=h.paramIsX[i],o=h.paramIsY[i],s=h.numParams[i];return i+t.substr(1).replace(h.paramRE,function(t){return n>=s?t:(a[n]?t=e(t):o[n]&&(t=r(t)),n++,t)})})}e.exports={draw:function(t){var e=t._fullLayout;for(var r in e._shapeUpperLayer.selectAll(\"path\").remove(),e._shapeLowerLayer.selectAll(\"path\").remove(),e._plots){var n=e._plots[r].shapelayer;n&&n.selectAll(\"path\").remove()}for(var i=0;i<e.shapes.length;i++)e.shapes[i].visible&&p(t,i)},drawOne:p}},{\"../../lib\":719,\"../../lib/setcursor\":739,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"./constants\":671,\"./helpers\":674}],674:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib\");r.rangeToShapePosition=function(t){return\"log\"===t.type?t.r2d:function(t){return t}},r.shapePositionToRange=function(t){return\"log\"===t.type?t.d2r:function(t){return t}},r.decodeDate=function(t){return function(e){return e.replace&&(e=e.replace(\"_\",\" \")),t(e)}},r.encodeDate=function(t){return function(e){return t(e).replace(\" \",\"_\")}},r.extractPathCoords=function(t,e){var r=[];return t.match(n.segmentRE).forEach(function(t){var a=e[t.charAt(0)].drawn;if(void 0!==a){var o=t.substr(1).match(n.paramRE);!o||o.length<a||r.push(i.cleanNumber(o[a]))}}),r},r.getDataToPixel=function(t,e,n){var i,a=t._fullLayout._size;if(e){var o=r.shapePositionToRange(e);i=function(t){return e._offset+e.r2p(o(t,!0))},\"date\"===e.type&&(i=r.decodeDate(i))}else i=n?function(t){return a.t+a.h*(1-t)}:function(t){return a.l+a.w*t};return i},r.getPixelToData=function(t,e,n){var i,a=t._fullLayout._size;if(e){var o=r.rangeToShapePosition(e);i=function(t){return o(e.p2r(t-e._offset))}}else i=n?function(t){return 1-(t-a.t)/a.h}:function(t){return(t-a.l)/a.w};return i},r.roundPositionForSharpStrokeRendering=function(t,e){var r=1===Math.round(e%2),n=Math.round(t);return r?n+.5:n}},{\"../../lib\":719,\"./constants\":671}],675:[function(t,e,r){\"use strict\";var n=t(\"./draw\");e.exports={moduleType:\"component\",name:\"shapes\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"shapes\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne}},{\"../../plots/cartesian/include_components\":777,\"./attributes\":669,\"./calc_autorange\":670,\"./defaults\":672,\"./draw\":673}],676:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/pad_attributes\"),a=t(\"../../lib/extend\").extendDeepAll,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/animation_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"./constants\"),u=l(\"step\",{visible:{valType:\"boolean\",dflt:!0},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\"},value:{valType:\"string\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"slider\",{visible:{valType:\"boolean\",dflt:!0},active:{valType:\"number\",min:0,dflt:0},steps:u,lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",min:-2,max:3,dflt:0},pad:a(i({editType:\"arraydraw\"}),{},{t:{dflt:20}}),xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\"},y:{valType:\"number\",min:-2,max:3,dflt:0},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},transition:{duration:{valType:\"number\",min:0,dflt:150},easing:{valType:\"enumerated\",values:s.transition.easing.values,dflt:\"cubic-in-out\"}},currentvalue:{visible:{valType:\"boolean\",dflt:!0},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},offset:{valType:\"number\",dflt:10},prefix:{valType:\"string\"},suffix:{valType:\"string\"},font:n({})},font:n({}),activebgcolor:{valType:\"color\",dflt:c.gripBgActiveColor},bgcolor:{valType:\"color\",dflt:c.railBgColor},bordercolor:{valType:\"color\",dflt:c.railBorderColor},borderwidth:{valType:\"number\",min:0,dflt:c.railBorderWidth},ticklen:{valType:\"number\",min:0,dflt:c.tickLength},tickcolor:{valType:\"color\",dflt:c.tickColor},tickwidth:{valType:\"number\",min:0,dflt:1},minorticklen:{valType:\"number\",min:0,dflt:c.minorTickLength}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/animation_attributes\":762,\"../../plots/font_attributes\":793,\"../../plots/pad_attributes\":827,\"./constants\":677}],677:[function(t,e,r){\"use strict\";e.exports={name:\"sliders\",containerClassName:\"slider-container\",groupClassName:\"slider-group\",inputAreaClass:\"slider-input-area\",railRectClass:\"slider-rail-rect\",railTouchRectClass:\"slider-rail-touch-rect\",gripRectClass:\"slider-grip-rect\",tickRectClass:\"slider-tick-rect\",inputProxyClass:\"slider-input-proxy\",labelsClass:\"slider-labels\",labelGroupClass:\"slider-label-group\",labelClass:\"slider-label\",currentValueClass:\"slider-current-value\",railHeight:5,menuIndexAttrName:\"slider-active-index\",autoMarginIdRoot:\"slider-\",minWidth:30,minHeight:30,textPadX:40,arrowOffsetX:4,railRadius:2,railWidth:5,railBorder:4,railBorderWidth:1,railBorderColor:\"#bec8d9\",railBgColor:\"#f8fafc\",railInset:8,stepInset:10,gripRadius:10,gripWidth:20,gripHeight:20,gripBorder:20,gripBorderWidth:1,gripBorderColor:\"#bec8d9\",gripBgColor:\"#f6f8fa\",gripBgActiveColor:\"#dbdde0\",labelPadding:8,labelOffset:0,tickWidth:1,tickColor:\"#333\",tickOffset:25,tickLength:7,minorTickOffset:25,minorTickColor:\"#333\",minorTickLength:4,currentValuePadding:8,currentValueInset:0}},{}],678:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.steps;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}for(var s=i(t,e,{name:\"steps\",handleItemDefaults:c}),l=0,u=0;u<s.length;u++)s[u].visible&&l++;if(l<2?e.visible=!1:o(\"visible\")){e._stepCount=l;var h=e._visibleSteps=n.filterVisible(s);(s[o(\"active\")]||{}).visible||(e.active=h[0]._index),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"len\"),o(\"lenmode\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"currentvalue.visible\")&&(o(\"currentvalue.xanchor\"),o(\"currentvalue.prefix\"),o(\"currentvalue.suffix\"),o(\"currentvalue.offset\"),n.coerceFont(o,\"currentvalue.font\",e.font)),o(\"transition.duration\"),o(\"transition.easing\"),o(\"bgcolor\"),o(\"activebgcolor\"),o(\"bordercolor\"),o(\"borderwidth\"),o(\"ticklen\"),o(\"tickwidth\"),o(\"tickcolor\"),o(\"minorticklen\")}}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}if(\"skip\"===t.method||Array.isArray(t.args)?r(\"visible\"):e.visible=!1){r(\"method\"),r(\"args\");var i=r(\"label\",\"step-\"+e._index);r(\"value\",i),r(\"execute\")}}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"./attributes\":676,\"./constants\":677}],679:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"./constants\"),h=t(\"../../constants/alignment\"),f=h.LINE_SPACING,p=h.FROM_TL,d=h.FROM_BR;function g(t){return u.autoMarginIdRoot+t._index}function v(t){return t._index}function m(t,e){var r=o.tester.selectAll(\"g.\"+u.labelGroupClass).data(e._visibleSteps);r.enter().append(\"g\").classed(u.labelGroupClass,!0);var a=0,c=0;r.each(function(t){var r=b(n.select(this),{step:t},e).node();if(r){var i=o.bBox(r);c=Math.max(c,i.height),a=Math.max(a,i.width)}}),r.remove();var h=e._dims={};h.inputAreaWidth=Math.max(u.railWidth,u.gripHeight);var f=t._fullLayout._size;h.lx=f.l+f.w*e.x,h.ly=f.t+f.h*(1-e.y),\"fraction\"===e.lenmode?h.outerLength=Math.round(f.w*e.len):h.outerLength=e.len,h.inputAreaStart=0,h.inputAreaLength=Math.round(h.outerLength-e.pad.l-e.pad.r);var v=(h.inputAreaLength-2*u.stepInset)/(e._stepCount-1),m=a+u.labelPadding;if(h.labelStride=Math.max(1,Math.ceil(m/v)),h.labelHeight=c,h.currentValueMaxWidth=0,h.currentValueHeight=0,h.currentValueTotalHeight=0,h.currentValueMaxLines=1,e.currentvalue.visible){var x=o.tester.append(\"g\");r.each(function(t){var r=y(x,e,t.label),n=r.node()&&o.bBox(r.node())||{width:0,height:0},i=l.lineCount(r);h.currentValueMaxWidth=Math.max(h.currentValueMaxWidth,Math.ceil(n.width)),h.currentValueHeight=Math.max(h.currentValueHeight,Math.ceil(n.height)),h.currentValueMaxLines=Math.max(h.currentValueMaxLines,i)}),h.currentValueTotalHeight=h.currentValueHeight+e.currentvalue.offset,x.remove()}h.height=h.currentValueTotalHeight+u.tickOffset+e.ticklen+u.labelOffset+h.labelHeight+e.pad.t+e.pad.b;var _=\"left\";s.isRightAnchor(e)&&(h.lx-=h.outerLength,_=\"right\"),s.isCenterAnchor(e)&&(h.lx-=h.outerLength/2,_=\"center\");var w=\"top\";s.isBottomAnchor(e)&&(h.ly-=h.height,w=\"bottom\"),s.isMiddleAnchor(e)&&(h.ly-=h.height/2,w=\"middle\"),h.outerLength=Math.ceil(h.outerLength),h.height=Math.ceil(h.height),h.lx=Math.round(h.lx),h.ly=Math.round(h.ly);var k={y:e.y,b:h.height*d[w],t:h.height*p[w]};\"fraction\"===e.lenmode?(k.l=0,k.xl=e.x-e.len*p[_],k.r=0,k.xr=e.x+e.len*d[_]):(k.x=e.x,k.l=h.outerLength*p[_],k.r=h.outerLength*d[_]),i.autoMargin(t,g(e),k)}function y(t,e,r){if(e.currentvalue.visible){var n,i,a=e._dims;switch(e.currentvalue.xanchor){case\"right\":n=a.inputAreaLength-u.currentValueInset-a.currentValueMaxWidth,i=\"left\";break;case\"center\":n=.5*a.inputAreaLength,i=\"middle\";break;default:n=u.currentValueInset,i=\"left\"}var c=s.ensureSingle(t,\"text\",u.labelClass,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":i,\"data-notex\":1})}),h=e.currentvalue.prefix?e.currentvalue.prefix:\"\";if(\"string\"==typeof r)h+=r;else{var p=e.steps[e.active].label,d=e._gd._fullLayout._meta;d&&(p=s.templateString(p,d)),h+=p}e.currentvalue.suffix&&(h+=e.currentvalue.suffix),c.call(o.font,e.currentvalue.font).text(h).call(l.convertToTspans,e._gd);var g=l.lineCount(c),v=(a.currentValueMaxLines+1-g)*e.currentvalue.font.size*f;return l.positionText(c,n,v),c}}function x(t,e,r){s.ensureSingle(t,\"rect\",u.gripRectClass,function(n){n.call(T,e,t,r).style(\"pointer-events\",\"all\")}).attr({width:u.gripWidth,height:u.gripHeight,rx:u.gripRadius,ry:u.gripRadius}).call(a.stroke,r.bordercolor).call(a.fill,r.bgcolor).style(\"stroke-width\",r.borderwidth+\"px\")}function b(t,e,r){var n=s.ensureSingle(t,\"text\",u.labelClass,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":\"middle\",\"data-notex\":1})}),i=e.step.label,a=r._gd._fullLayout._meta;return a&&(i=s.templateString(i,a)),n.call(o.font,r.font).text(i).call(l.convertToTspans,r._gd),n}function _(t,e){var r=s.ensureSingle(t,\"g\",u.labelsClass),i=e._dims,a=r.selectAll(\"g.\"+u.labelGroupClass).data(i.labelSteps);a.enter().append(\"g\").classed(u.labelGroupClass,!0),a.exit().remove(),a.each(function(t){var r=n.select(this);r.call(b,t,e),o.setTranslate(r,S(e,t.fraction),u.tickOffset+e.ticklen+e.font.size*f+u.labelOffset+i.currentValueTotalHeight)})}function w(t,e,r,n,i){var a=Math.round(n*(r._stepCount-1)),o=r._visibleSteps[a]._index;o!==r.active&&k(t,e,r,o,!0,i)}function k(t,e,r,n,a,o){var s=r.active;r.active=n,c(t.layout,u.name,r).applyUpdate(\"active\",n);var l=r.steps[r.active];e.call(M,r,o),e.call(y,r),t.emit(\"plotly_sliderchange\",{slider:r,step:r.steps[r.active],interaction:a,previousActive:s}),l&&l.method&&a&&(e._nextMethod?(e._nextMethod.step=l,e._nextMethod.doCallback=a,e._nextMethod.doTransition=o):(e._nextMethod={step:l,doCallback:a,doTransition:o},e._nextMethodRaf=window.requestAnimationFrame(function(){var r=e._nextMethod.step;r.method&&(r.execute&&i.executeAPICommand(t,r.method,r.args),e._nextMethod=null,e._nextMethodRaf=null)})))}function T(t,e,r){var i=r.node(),o=n.select(e);function s(){return r.data()[0]}t.on(\"mousedown\",function(){var t=s();e.emit(\"plotly_sliderstart\",{slider:t});var l=r.select(\".\"+u.gripRectClass);n.event.stopPropagation(),n.event.preventDefault(),l.call(a.fill,t.activebgcolor);var c=E(t,n.mouse(i)[0]);w(e,r,t,c,!0),t._dragging=!0,o.on(\"mousemove\",function(){var t=s(),a=E(t,n.mouse(i)[0]);w(e,r,t,a,!1)}),o.on(\"mouseup\",function(){var t=s();t._dragging=!1,l.call(a.fill,t.bgcolor),o.on(\"mouseup\",null),o.on(\"mousemove\",null),e.emit(\"plotly_sliderend\",{slider:t,step:t.steps[t.active]})})})}function A(t,e){var r=t.selectAll(\"rect.\"+u.tickRectClass).data(e._visibleSteps),i=e._dims;r.enter().append(\"rect\").classed(u.tickRectClass,!0),r.exit().remove(),r.attr({width:e.tickwidth+\"px\",\"shape-rendering\":\"crispEdges\"}),r.each(function(t,r){var s=r%i.labelStride==0,l=n.select(this);l.attr({height:s?e.ticklen:e.minorticklen}).call(a.fill,e.tickcolor),o.setTranslate(l,S(e,r/(e._stepCount-1))-.5*e.tickwidth,(s?u.tickOffset:u.minorTickOffset)+i.currentValueTotalHeight)})}function M(t,e,r){for(var n=t.select(\"rect.\"+u.gripRectClass),i=0,a=0;a<e._stepCount;a++)if(e._visibleSteps[a]._index===e.active){i=a;break}var o=S(e,i/(e._stepCount-1));if(!e._invokingCommand){var s=n;r&&e.transition.duration>0&&(s=s.transition().duration(e.transition.duration).ease(e.transition.easing)),s.attr(\"transform\",\"translate(\"+(o-.5*u.gripWidth)+\",\"+e._dims.currentValueTotalHeight+\")\")}}function S(t,e){var r=t._dims;return r.inputAreaStart+u.stepInset+(r.inputAreaLength-2*u.stepInset)*Math.min(1,Math.max(0,e))}function E(t,e){var r=t._dims;return Math.min(1,Math.max(0,(e-u.stepInset-r.inputAreaStart)/(r.inputAreaLength-2*u.stepInset-2*r.inputAreaStart)))}function C(t,e,r){var n=r._dims,i=s.ensureSingle(t,\"rect\",u.railTouchRectClass,function(n){n.call(T,e,t,r).style(\"pointer-events\",\"all\")});i.attr({width:n.inputAreaLength,height:Math.max(n.inputAreaWidth,u.tickOffset+r.ticklen+n.labelHeight)}).call(a.fill,r.bgcolor).attr(\"opacity\",0),o.setTranslate(i,0,n.currentValueTotalHeight)}function L(t,e){var r=e._dims,n=r.inputAreaLength-2*u.railInset,i=s.ensureSingle(t,\"rect\",u.railRectClass);i.attr({width:n,height:u.railWidth,rx:u.railRadius,ry:u.railRadius,\"shape-rendering\":\"crispEdges\"}).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\"),o.setTranslate(i,u.railInset,.5*(r.inputAreaWidth-u.railWidth)+r.currentValueTotalHeight)}e.exports=function(t){var e=t._fullLayout,r=function(t,e){for(var r=t[u.name],n=[],i=0;i<r.length;i++){var a=r[i];a.visible&&(a._gd=e,n.push(a))}return n}(e,t),a=e._infolayer.selectAll(\"g.\"+u.containerClassName).data(r.length>0?[0]:[]);function s(e){e._commandObserver&&(e._commandObserver.remove(),delete e._commandObserver),i.autoMargin(t,g(e))}if(a.enter().append(\"g\").classed(u.containerClassName,!0).style(\"cursor\",\"ew-resize\"),a.exit().each(function(){n.select(this).selectAll(\"g.\"+u.groupClassName).each(s)}).remove(),0!==r.length){var l=a.selectAll(\"g.\"+u.groupClassName).data(r,v);l.enter().append(\"g\").classed(u.groupClassName,!0),l.exit().each(s).remove();for(var c=0;c<r.length;c++){var h=r[c];m(t,h)}l.each(function(e){var r=n.select(this);!function(t){var e=t._dims;e.labelSteps=[];for(var r=t._stepCount,n=0;n<r;n+=e.labelStride)e.labelSteps.push({fraction:n/(r-1),step:t._visibleSteps[n]})}(e),i.manageCommandObserver(t,e,e._visibleSteps,function(e){var n=r.data()[0];n.active!==e.index&&(n._dragging||k(t,r,n,e.index,!1,!0))}),function(t,e,r){(r.steps[r.active]||{}).visible||(r.active=r._visibleSteps[0]._index);e.call(y,r).call(L,r).call(_,r).call(A,r).call(C,t,r).call(x,t,r);var n=r._dims;o.setTranslate(e,n.lx+r.pad.l,n.ly+r.pad.t),e.call(M,r,!1),e.call(y,r)}(t,n.select(this),e)})}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_template\":757,\"../../plots/plots\":828,\"../color\":593,\"../drawing\":614,\"./constants\":677,d3:163}],680:[function(t,e,r){\"use strict\";var n=t(\"./constants\");e.exports={moduleType:\"component\",name:n.name,layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":676,\"./constants\":677,\"./defaults\":678,\"./draw\":679}],681:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../drawing\"),c=t(\"../color\"),u=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/interactions\");e.exports={draw:function(t,e,r){var p,d=r.propContainer,g=r.propName,v=r.placeholder,m=r.traceIndex,y=r.avoid||{},x=r.attributes,b=r.transform,_=r.containerGroup,w=t._fullLayout,k=1,T=!1,A=d.title,M=(A&&A.text?A.text:\"\").trim(),S=A&&A.font?A.font:{},E=S.family,C=S.size,L=S.color;\"title.text\"===g?p=\"titleText\":-1!==g.indexOf(\"axis\")?p=\"axisTitleText\":g.indexOf(!0)&&(p=\"colorbarTitleText\");var P=t._context.edits[p];\"\"===M?k=0:M.replace(f,\" % \")===v.replace(f,\" % \")&&(k=.2,T=!0,P||(M=\"\"));r._meta?M=s.templateString(M,r._meta):w._meta&&(M=s.templateString(M,w._meta));var O=M||P;_||(_=s.ensureSingle(w._infolayer,\"g\",\"g-\"+e));var z=_.selectAll(\"text\").data(O?[0]:[]);if(z.enter().append(\"text\"),z.text(M).attr(\"class\",e),z.exit().remove(),!O)return _;function I(t){s.syncOrAsync([D,R],t)}function D(e){var r;return b?(r=\"\",b.rotate&&(r+=\"rotate(\"+[b.rotate,x.x,x.y]+\")\"),b.offset&&(r+=\"translate(0, \"+b.offset+\")\")):r=null,e.attr(\"transform\",r),e.style({\"font-family\":E,\"font-size\":n.round(C,2)+\"px\",fill:c.rgb(L),opacity:k*c.opacity(L),\"font-weight\":a.fontWeight}).attr(x).call(u.convertToTspans,t),a.previousPromises(t)}function R(t){var e=n.select(t.node().parentNode);if(y&&y.selection&&y.side&&M){e.attr(\"transform\",null);var r=0,a={left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}[y.side],o=-1!==[\"left\",\"top\"].indexOf(y.side)?-1:1,c=i(y.pad)?y.pad:2,u=l.bBox(e.node()),h={left:0,top:0,right:w.width,bottom:w.height},f=y.maxShift||(h[y.side]-u[y.side])*(\"left\"===y.side||\"top\"===y.side?-1:1);if(f<0)r=f;else{var p=y.offsetLeft||0,d=y.offsetTop||0;u.left-=p,u.right-=p,u.top-=d,u.bottom-=d,y.selection.each(function(){var t=l.bBox(this);s.bBoxIntersect(u,t,c)&&(r=Math.max(r,o*(t[y.side]-u[a])+c))}),r=Math.min(f,r)}if(r>0||f<0){var g={left:[-r,0],right:[r,0],top:[0,-r],bottom:[0,r]}[y.side];e.attr(\"transform\",\"translate(\"+g+\")\")}}}z.call(I),P&&(M?z.on(\".opacity\",null):(k=0,T=!0,z.text(v).on(\"mouseover.opacity\",function(){n.select(this).transition().duration(h.SHOW_PLACEHOLDER).style(\"opacity\",1)}).on(\"mouseout.opacity\",function(){n.select(this).transition().duration(h.HIDE_PLACEHOLDER).style(\"opacity\",0)})),z.call(u.makeEditable,{gd:t}).on(\"edit\",function(e){void 0!==m?o.call(\"_guiRestyle\",t,g,e,m):o.call(\"_guiRelayout\",t,g,e)}).on(\"cancel\",function(){this.text(this.attr(\"data-unformatted\")).call(I)}).on(\"input\",function(t){this.text(t||\" \").call(u.positionText,x.x,x.y)}));return z.classed(\"js-placeholder\",T),_}};var f=/ [XY][0-9]* /},{\"../../constants/interactions\":694,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../drawing\":614,d3:163,\"fast-isnumeric\":225}],682:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/pad_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=l(\"button\",{visible:{valType:\"boolean\"},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\",dflt:\"\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"updatemenu\",{_arrayAttrRegexps:[/^updatemenus\\[(0|[1-9][0-9]+)\\]\\.buttons/],visible:{valType:\"boolean\"},type:{valType:\"enumerated\",values:[\"dropdown\",\"buttons\"],dflt:\"dropdown\"},direction:{valType:\"enumerated\",values:[\"left\",\"right\",\"up\",\"down\"],dflt:\"down\"},active:{valType:\"integer\",min:-1,dflt:0},showactive:{valType:\"boolean\",dflt:!0},buttons:c,x:{valType:\"number\",min:-2,max:3,dflt:-.05},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"right\"},y:{valType:\"number\",min:-2,max:3,dflt:1},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},pad:a(s({editType:\"arraydraw\"}),{}),font:n({}),bgcolor:{valType:\"color\"},bordercolor:{valType:\"color\",dflt:i.borderLine},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"arraydraw\"}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/font_attributes\":793,\"../../plots/pad_attributes\":827,\"../color/attributes\":592}],683:[function(t,e,r){\"use strict\";e.exports={name:\"updatemenus\",containerClassName:\"updatemenu-container\",headerGroupClassName:\"updatemenu-header-group\",headerClassName:\"updatemenu-header\",headerArrowClassName:\"updatemenu-header-arrow\",dropdownButtonGroupClassName:\"updatemenu-dropdown-button-group\",dropdownButtonClassName:\"updatemenu-dropdown-button\",buttonClassName:\"updatemenu-button\",itemRectClassName:\"updatemenu-item-rect\",itemTextClassName:\"updatemenu-item-text\",menuIndexAttrName:\"updatemenu-active-index\",autoMarginIdRoot:\"updatemenu-\",blankHeaderOpts:{label:\"  \"},minWidth:30,minHeight:30,textPadX:24,arrowPadX:16,rx:2,ry:2,textOffsetX:12,textOffsetY:3,arrowOffsetX:4,gapButtonHeader:5,gapButton:2,activeColor:\"#F4FAFF\",hoverColor:\"#F4FAFF\",arrowSymbol:{left:\"\\u25c4\",right:\"\\u25ba\",up:\"\\u25b2\",down:\"\\u25bc\"}}},{}],684:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.buttons;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}o(\"visible\",i(t,e,{name:\"buttons\",handleItemDefaults:c}).length>0)&&(o(\"active\"),o(\"direction\"),o(\"type\"),o(\"showactive\"),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"bgcolor\",r.paper_bgcolor),o(\"bordercolor\"),o(\"borderwidth\"))}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}r(\"visible\",\"skip\"===t.method||Array.isArray(t.args))&&(r(\"method\"),r(\"args\"),r(\"label\"),r(\"execute\"))}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"./attributes\":682,\"./constants\":683}],685:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"../../constants/alignment\").LINE_SPACING,h=t(\"./constants\"),f=t(\"./scrollbox\");function p(t){return t._index}function d(t,e){return+t.attr(h.menuIndexAttrName)===e._index}function g(t,e,r,n,i,a,o,s){e.active=o,c(t.layout,h.name,e).applyUpdate(\"active\",o),\"buttons\"===e.type?m(t,n,null,null,e):\"dropdown\"===e.type&&(i.attr(h.menuIndexAttrName,\"-1\"),v(t,n,i,a,e),s||m(t,n,i,a,e))}function v(t,e,r,n,i){var a=s.ensureSingle(e,\"g\",h.headerClassName,function(t){t.style(\"pointer-events\",\"all\")}),l=i._dims,c=i.active,u=i.buttons[c]||h.blankHeaderOpts,f={y:i.pad.t,yPad:0,x:i.pad.l,xPad:0,index:0},p={width:l.headerWidth,height:l.headerHeight};a.call(y,i,u,t).call(M,i,f,p),s.ensureSingle(e,\"text\",h.headerArrowClassName,function(t){t.classed(\"user-select-none\",!0).attr(\"text-anchor\",\"end\").call(o.font,i.font).text(h.arrowSymbol[i.direction])}).attr({x:l.headerWidth-h.arrowOffsetX+i.pad.l,y:l.headerHeight/2+h.textOffsetY+i.pad.t}),a.on(\"click\",function(){r.call(S,String(d(r,i)?-1:i._index)),m(t,e,r,n,i)}),a.on(\"mouseover\",function(){a.call(w)}),a.on(\"mouseout\",function(){a.call(k,i)}),o.setTranslate(e,l.lx,l.ly)}function m(t,e,r,a,o){r||(r=e).attr(\"pointer-events\",\"all\");var l=function(t){return-1==+t.attr(h.menuIndexAttrName)}(r)&&\"buttons\"!==o.type?[]:o.buttons,c=\"dropdown\"===o.type?h.dropdownButtonClassName:h.buttonClassName,u=r.selectAll(\"g.\"+c).data(s.filterVisible(l)),f=u.enter().append(\"g\").classed(c,!0),p=u.exit();\"dropdown\"===o.type?(f.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\"),p.transition().attr(\"opacity\",\"0\").remove()):p.remove();var d=0,v=0,m=o._dims,x=-1!==[\"up\",\"down\"].indexOf(o.direction);\"dropdown\"===o.type&&(x?v=m.headerHeight+h.gapButtonHeader:d=m.headerWidth+h.gapButtonHeader),\"dropdown\"===o.type&&\"up\"===o.direction&&(v=-h.gapButtonHeader+h.gapButton-m.openHeight),\"dropdown\"===o.type&&\"left\"===o.direction&&(d=-h.gapButtonHeader+h.gapButton-m.openWidth);var b={x:m.lx+d+o.pad.l,y:m.ly+v+o.pad.t,yPad:h.gapButton,xPad:h.gapButton,index:0},T={l:b.x+o.borderwidth,t:b.y+o.borderwidth};u.each(function(s,l){var c=n.select(this);c.call(y,o,s,t).call(M,o,b),c.on(\"click\",function(){n.event.defaultPrevented||(g(t,o,0,e,r,a,l),s.execute&&i.executeAPICommand(t,s.method,s.args),t.emit(\"plotly_buttonclicked\",{menu:o,button:s,active:o.active}))}),c.on(\"mouseover\",function(){c.call(w)}),c.on(\"mouseout\",function(){c.call(k,o),u.call(_,o)})}),u.call(_,o),x?(T.w=Math.max(m.openWidth,m.headerWidth),T.h=b.y-T.t):(T.w=b.x-T.l,T.h=Math.max(m.openHeight,m.headerHeight)),T.direction=o.direction,a&&(u.size()?function(t,e,r,n,i,a){var o,s,l,c=i.direction,u=\"up\"===c||\"down\"===c,f=i._dims,p=i.active;if(u)for(s=0,l=0;l<p;l++)s+=f.heights[l]+h.gapButton;else for(o=0,l=0;l<p;l++)o+=f.widths[l]+h.gapButton;n.enable(a,o,s),n.hbar&&n.hbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\");n.vbar&&n.vbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\")}(0,0,0,a,o,T):function(t){var e=!!t.hbar,r=!!t.vbar;e&&t.hbar.transition().attr(\"opacity\",\"0\").each(\"end\",function(){e=!1,r||t.disable()});r&&t.vbar.transition().attr(\"opacity\",\"0\").each(\"end\",function(){r=!1,e||t.disable()})}(a))}function y(t,e,r,n){t.call(x,e).call(b,e,r,n)}function x(t,e){s.ensureSingle(t,\"rect\",h.itemRectClassName,function(t){t.attr({rx:h.rx,ry:h.ry,\"shape-rendering\":\"crispEdges\"})}).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\")}function b(t,e,r,n){var i=s.ensureSingle(t,\"text\",h.itemTextClassName,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":\"start\",\"data-notex\":1})}),a=r.label,c=n._fullLayout._meta;c&&(a=s.templateString(a,c)),i.call(o.font,e.font).text(a).call(l.convertToTspans,n)}function _(t,e){var r=e.active;t.each(function(t,i){var o=n.select(this);i===r&&e.showactive&&o.select(\"rect.\"+h.itemRectClassName).call(a.fill,h.activeColor)})}function w(t){t.select(\"rect.\"+h.itemRectClassName).call(a.fill,h.hoverColor)}function k(t,e){t.select(\"rect.\"+h.itemRectClassName).call(a.fill,e.bgcolor)}function T(t,e){var r=e._dims={width1:0,height1:0,heights:[],widths:[],totalWidth:0,totalHeight:0,openWidth:0,openHeight:0,lx:0,ly:0},a=o.tester.selectAll(\"g.\"+h.dropdownButtonClassName).data(s.filterVisible(e.buttons));a.enter().append(\"g\").classed(h.dropdownButtonClassName,!0);var c=-1!==[\"up\",\"down\"].indexOf(e.direction);a.each(function(i,a){var s=n.select(this);s.call(y,e,i,t);var f=s.select(\".\"+h.itemTextClassName),p=f.node()&&o.bBox(f.node()).width,d=Math.max(p+h.textPadX,h.minWidth),g=e.font.size*u,v=l.lineCount(f),m=Math.max(g*v,h.minHeight)+h.textOffsetY;m=Math.ceil(m),d=Math.ceil(d),r.widths[a]=d,r.heights[a]=m,r.height1=Math.max(r.height1,m),r.width1=Math.max(r.width1,d),c?(r.totalWidth=Math.max(r.totalWidth,d),r.openWidth=r.totalWidth,r.totalHeight+=m+h.gapButton,r.openHeight+=m+h.gapButton):(r.totalWidth+=d+h.gapButton,r.openWidth+=d+h.gapButton,r.totalHeight=Math.max(r.totalHeight,m),r.openHeight=r.totalHeight)}),c?r.totalHeight-=h.gapButton:r.totalWidth-=h.gapButton,r.headerWidth=r.width1+h.arrowPadX,r.headerHeight=r.height1,\"dropdown\"===e.type&&(c?(r.width1+=h.arrowPadX,r.totalHeight=r.height1):r.totalWidth=r.width1,r.totalWidth+=h.arrowPadX),a.remove();var f=r.totalWidth+e.pad.l+e.pad.r,p=r.totalHeight+e.pad.t+e.pad.b,d=t._fullLayout._size;r.lx=d.l+d.w*e.x,r.ly=d.t+d.h*(1-e.y);var g=\"left\";s.isRightAnchor(e)&&(r.lx-=f,g=\"right\"),s.isCenterAnchor(e)&&(r.lx-=f/2,g=\"center\");var v=\"top\";s.isBottomAnchor(e)&&(r.ly-=p,v=\"bottom\"),s.isMiddleAnchor(e)&&(r.ly-=p/2,v=\"middle\"),r.totalWidth=Math.ceil(r.totalWidth),r.totalHeight=Math.ceil(r.totalHeight),r.lx=Math.round(r.lx),r.ly=Math.round(r.ly),i.autoMargin(t,A(e),{x:e.x,y:e.y,l:f*({right:1,center:.5}[g]||0),r:f*({left:1,center:.5}[g]||0),b:p*({top:1,middle:.5}[v]||0),t:p*({bottom:1,middle:.5}[v]||0)})}function A(t){return h.autoMarginIdRoot+t._index}function M(t,e,r,n){n=n||{};var i=t.select(\".\"+h.itemRectClassName),a=t.select(\".\"+h.itemTextClassName),s=e.borderwidth,c=r.index,f=e._dims;o.setTranslate(t,s+r.x,s+r.y);var p=-1!==[\"up\",\"down\"].indexOf(e.direction),d=n.height||(p?f.heights[c]:f.height1);i.attr({x:0,y:0,width:n.width||(p?f.width1:f.widths[c]),height:d});var g=e.font.size*u,v=(l.lineCount(a)-1)*g/2;l.positionText(a,h.textOffsetX,d/2-v+h.textOffsetY),p?r.y+=f.heights[c]+r.yPad:r.x+=f.widths[c]+r.xPad,r.index++}function S(t,e){t.attr(h.menuIndexAttrName,e||\"-1\").selectAll(\"g.\"+h.dropdownButtonClassName).remove()}e.exports=function(t){var e=t._fullLayout,r=s.filterVisible(e[h.name]);function a(e){i.autoMargin(t,A(e))}var o=e._menulayer.selectAll(\"g.\"+h.containerClassName).data(r.length>0?[0]:[]);if(o.enter().append(\"g\").classed(h.containerClassName,!0).style(\"cursor\",\"pointer\"),o.exit().each(function(){n.select(this).selectAll(\"g.\"+h.headerGroupClassName).each(a)}).remove(),0!==r.length){var l=o.selectAll(\"g.\"+h.headerGroupClassName).data(r,p);l.enter().append(\"g\").classed(h.headerGroupClassName,!0);for(var c=s.ensureSingle(o,\"g\",h.dropdownButtonGroupClassName,function(t){t.style(\"pointer-events\",\"all\")}),u=0;u<r.length;u++){var y=r[u];T(t,y)}var x=\"updatemenus\"+e._uid,b=new f(t,c,x);l.enter().size()&&(c.node().parentNode.appendChild(c.node()),c.call(S)),l.exit().each(function(t){c.call(S),a(t)}).remove(),l.each(function(e){var r=n.select(this),a=\"dropdown\"===e.type?c:null;i.manageCommandObserver(t,e,e.buttons,function(n){g(t,e,e.buttons[n.index],r,a,b,n.index,!0)}),\"dropdown\"===e.type?(v(t,r,c,b,e),d(c,e)&&m(t,r,c,b,e)):m(t,r,null,null,e)})}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_template\":757,\"../../plots/plots\":828,\"../color\":593,\"../drawing\":614,\"./constants\":683,\"./scrollbox\":687,d3:163}],686:[function(t,e,r){arguments[4][680][0].apply(r,arguments)},{\"./attributes\":682,\"./constants\":683,\"./defaults\":684,\"./draw\":685,dup:680}],687:[function(t,e,r){\"use strict\";e.exports=s;var n=t(\"d3\"),i=t(\"../color\"),a=t(\"../drawing\"),o=t(\"../../lib\");function s(t,e,r){this.gd=t,this.container=e,this.id=r,this.position=null,this.translateX=null,this.translateY=null,this.hbar=null,this.vbar=null,this.bg=this.container.selectAll(\"rect.scrollbox-bg\").data([0]),this.bg.exit().on(\".drag\",null).on(\"wheel\",null).remove(),this.bg.enter().append(\"rect\").classed(\"scrollbox-bg\",!0).style(\"pointer-events\",\"all\").attr({opacity:0,x:0,y:0,width:0,height:0})}s.barWidth=2,s.barLength=20,s.barRadius=2,s.barPad=1,s.barColor=\"#808BA4\",s.prototype.enable=function(t,e,r){var o=this.gd._fullLayout,l=o.width,c=o.height;this.position=t;var u,h,f,p,d=this.position.l,g=this.position.w,v=this.position.t,m=this.position.h,y=this.position.direction,x=\"down\"===y,b=\"left\"===y,_=\"up\"===y,w=g,k=m;x||b||\"right\"===y||_||(this.position.direction=\"down\",x=!0),x||_?(h=(u=d)+w,x?(f=v,k=(p=Math.min(f+k,c))-f):k=(p=v+k)-(f=Math.max(p-k,0))):(p=(f=v)+k,b?w=(h=d+w)-(u=Math.max(h-w,0)):(u=d,w=(h=Math.min(u+w,l))-u)),this._box={l:u,t:f,w:w,h:k};var T=g>w,A=s.barLength+2*s.barPad,M=s.barWidth+2*s.barPad,S=d,E=v+m;E+M>c&&(E=c-M);var C=this.container.selectAll(\"rect.scrollbar-horizontal\").data(T?[0]:[]);C.exit().on(\".drag\",null).remove(),C.enter().append(\"rect\").classed(\"scrollbar-horizontal\",!0).call(i.fill,s.barColor),T?(this.hbar=C.attr({rx:s.barRadius,ry:s.barRadius,x:S,y:E,width:A,height:M}),this._hbarXMin=S+A/2,this._hbarTranslateMax=w-A):(delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax);var L=m>k,P=s.barWidth+2*s.barPad,O=s.barLength+2*s.barPad,z=d+g,I=v;z+P>l&&(z=l-P);var D=this.container.selectAll(\"rect.scrollbar-vertical\").data(L?[0]:[]);D.exit().on(\".drag\",null).remove(),D.enter().append(\"rect\").classed(\"scrollbar-vertical\",!0).call(i.fill,s.barColor),L?(this.vbar=D.attr({rx:s.barRadius,ry:s.barRadius,x:z,y:I,width:P,height:O}),this._vbarYMin=I+O/2,this._vbarTranslateMax=k-O):(delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax);var R=this.id,F=u-.5,B=L?h+P+.5:h+.5,N=f-.5,j=T?p+M+.5:p+.5,U=o._topdefs.selectAll(\"#\"+R).data(T||L?[0]:[]);if(U.exit().remove(),U.enter().append(\"clipPath\").attr(\"id\",R).append(\"rect\"),T||L?(this._clipRect=U.select(\"rect\").attr({x:Math.floor(F),y:Math.floor(N),width:Math.ceil(B)-Math.floor(F),height:Math.ceil(j)-Math.floor(N)}),this.container.call(a.setClipUrl,R,this.gd),this.bg.attr({x:d,y:v,width:g,height:m})):(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),T||L){var V=n.behavior.drag().on(\"dragstart\",function(){n.event.sourceEvent.preventDefault()}).on(\"drag\",this._onBoxDrag.bind(this));this.container.on(\"wheel\",null).on(\"wheel\",this._onBoxWheel.bind(this)).on(\".drag\",null).call(V);var q=n.behavior.drag().on(\"dragstart\",function(){n.event.sourceEvent.preventDefault(),n.event.sourceEvent.stopPropagation()}).on(\"drag\",this._onBarDrag.bind(this));T&&this.hbar.on(\".drag\",null).call(q),L&&this.vbar.on(\".drag\",null).call(q)}this.setTranslate(e,r)},s.prototype.disable=function(){(this.hbar||this.vbar)&&(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),this.hbar&&(this.hbar.on(\".drag\",null),this.hbar.remove(),delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax),this.vbar&&(this.vbar.on(\".drag\",null),this.vbar.remove(),delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax)},s.prototype._onBoxDrag=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t-=n.event.dx),this.vbar&&(e-=n.event.dy),this.setTranslate(t,e)},s.prototype._onBoxWheel=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t+=n.event.deltaY),this.vbar&&(e+=n.event.deltaY),this.setTranslate(t,e)},s.prototype._onBarDrag=function(){var t=this.translateX,e=this.translateY;if(this.hbar){var r=t+this._hbarXMin,i=r+this._hbarTranslateMax;t=(o.constrain(n.event.x,r,i)-r)/(i-r)*(this.position.w-this._box.w)}if(this.vbar){var a=e+this._vbarYMin,s=a+this._vbarTranslateMax;e=(o.constrain(n.event.y,a,s)-a)/(s-a)*(this.position.h-this._box.h)}this.setTranslate(t,e)},s.prototype.setTranslate=function(t,e){var r=this.position.w-this._box.w,n=this.position.h-this._box.h;if(t=o.constrain(t||0,0,r),e=o.constrain(e||0,0,n),this.translateX=t,this.translateY=e,this.container.call(a.setTranslate,this._box.l-this.position.l-t,this._box.t-this.position.t-e),this._clipRect&&this._clipRect.attr({x:Math.floor(this.position.l+t-.5),y:Math.floor(this.position.t+e-.5)}),this.hbar){var i=t/r;this.hbar.call(a.setTranslate,t+i*this._hbarTranslateMax,e)}if(this.vbar){var s=e/n;this.vbar.call(a.setTranslate,t,e+s*this._vbarTranslateMax)}}},{\"../../lib\":719,\"../color\":593,\"../drawing\":614,d3:163}],688:[function(t,e,r){\"use strict\";e.exports={FROM_BL:{left:0,center:.5,right:1,bottom:0,middle:.5,top:1},FROM_TL:{left:0,center:.5,right:1,bottom:1,middle:.5,top:0},FROM_BR:{left:1,center:.5,right:0,bottom:0,middle:.5,top:1},LINE_SPACING:1.3,CAP_SHIFT:.7,MID_SHIFT:.35,OPPOSITE_SIDE:{left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}}},{}],689:[function(t,e,r){\"use strict\";e.exports={INCREASING:{COLOR:\"#3D9970\",SYMBOL:\"\\u25b2\"},DECREASING:{COLOR:\"#FF4136\",SYMBOL:\"\\u25bc\"}}},{}],690:[function(t,e,r){\"use strict\";e.exports={FORMAT_LINK:\"https://github.com/d3/d3-3.x-api-reference/blob/master/Formatting.md#d3_format\",DATE_FORMAT_LINK:\"https://github.com/d3/d3-3.x-api-reference/blob/master/Time-Formatting.md#format\"}},{}],691:[function(t,e,r){\"use strict\";e.exports={COMPARISON_OPS:[\"=\",\"!=\",\"<\",\">=\",\">\",\"<=\"],COMPARISON_OPS2:[\"=\",\"<\",\">=\",\">\",\"<=\"],INTERVAL_OPS:[\"[]\",\"()\",\"[)\",\"(]\",\"][\",\")(\",\"](\",\")[\"],SET_OPS:[\"{}\",\"}{\"],CONSTRAINT_REDUCTION:{\"=\":\"=\",\"<\":\"<\",\"<=\":\"<\",\">\":\">\",\">=\":\">\",\"[]\":\"[]\",\"()\":\"[]\",\"[)\":\"[]\",\"(]\":\"[]\",\"][\":\"][\",\")(\":\"][\",\"](\":\"][\",\")[\":\"][\"}}},{}],692:[function(t,e,r){\"use strict\";e.exports={solid:[[],0],dot:[[.5,1],200],dash:[[.5,1],50],longdash:[[.5,1],10],dashdot:[[.5,.625,.875,1],50],longdashdot:[[.5,.7,.8,1],10]}},{}],693:[function(t,e,r){\"use strict\";e.exports={circle:\"\\u25cf\",\"circle-open\":\"\\u25cb\",square:\"\\u25a0\",\"square-open\":\"\\u25a1\",diamond:\"\\u25c6\",\"diamond-open\":\"\\u25c7\",cross:\"+\",x:\"\\u274c\"}},{}],694:[function(t,e,r){\"use strict\";e.exports={SHOW_PLACEHOLDER:100,HIDE_PLACEHOLDER:1e3,DESELECTDIM:.2}},{}],695:[function(t,e,r){\"use strict\";e.exports={BADNUM:void 0,FP_SAFE:Number.MAX_VALUE/1e4,ONEAVGYEAR:315576e5,ONEAVGMONTH:26298e5,ONEDAY:864e5,ONEHOUR:36e5,ONEMIN:6e4,ONESEC:1e3,EPOCHJD:2440587.5,ALMOST_EQUAL:1-1e-6,LOG_CLIP:10,MINUS_SIGN:\"\\u2212\"}},{}],696:[function(t,e,r){\"use strict\";r.xmlns=\"http://www.w3.org/2000/xmlns/\",r.svg=\"http://www.w3.org/2000/svg\",r.xlink=\"http://www.w3.org/1999/xlink\",r.svgAttrs={xmlns:r.svg,\"xmlns:xlink\":r.xlink}},{}],697:[function(t,e,r){\"use strict\";r.version=\"1.49.1\",t(\"es6-promise\").polyfill(),t(\"../build/plotcss\"),t(\"./fonts/mathjax_config\")();for(var n=t(\"./registry\"),i=r.register=n.register,a=t(\"./plot_api\"),o=Object.keys(a),s=0;s<o.length;s++){var l=o[s];\"_\"!==l.charAt(0)&&(r[l]=a[l]),i({moduleType:\"apiMethod\",name:l,fn:a[l]})}i(t(\"./traces/scatter\")),i([t(\"./components/fx\"),t(\"./components/legend\"),t(\"./components/annotations\"),t(\"./components/annotations3d\"),t(\"./components/shapes\"),t(\"./components/images\"),t(\"./components/updatemenus\"),t(\"./components/sliders\"),t(\"./components/rangeslider\"),t(\"./components/rangeselector\"),t(\"./components/grid\"),t(\"./components/errorbars\"),t(\"./components/colorscale\"),t(\"./components/colorbar\")]),i([t(\"./locale-en\"),t(\"./locale-en-us\")]),r.Icons=t(\"./fonts/ploticon\"),r.Plots=t(\"./plots/plots\"),r.Fx=t(\"./components/fx\"),r.Snapshot=t(\"./snapshot\"),r.PlotSchema=t(\"./plot_api/plot_schema\"),r.Queue=t(\"./lib/queue\"),r.d3=t(\"d3\")},{\"../build/plotcss\":1,\"./components/annotations\":584,\"./components/annotations3d\":589,\"./components/colorbar\":599,\"./components/colorscale\":605,\"./components/errorbars\":620,\"./components/fx\":632,\"./components/grid\":636,\"./components/images\":641,\"./components/legend\":649,\"./components/rangeselector\":660,\"./components/rangeslider\":667,\"./components/shapes\":675,\"./components/sliders\":680,\"./components/updatemenus\":686,\"./fonts/mathjax_config\":698,\"./fonts/ploticon\":699,\"./lib/queue\":734,\"./locale-en\":748,\"./locale-en-us\":747,\"./plot_api\":752,\"./plot_api/plot_schema\":756,\"./plots/plots\":828,\"./registry\":847,\"./snapshot\":852,\"./traces/scatter\":1123,d3:163,\"es6-promise\":218}],698:[function(t,e,r){\"use strict\";e.exports=function(){\"undefined\"!=typeof MathJax&&(\"local\"!==(window.PlotlyConfig||{}).MathJaxConfig&&(MathJax.Hub.Config({messageStyle:\"none\",skipStartupTypeset:!0,displayAlign:\"left\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]}}),MathJax.Hub.Configured()))}},{}],699:[function(t,e,r){\"use strict\";e.exports={undo:{width:857.1,height:1e3,path:\"m857 350q0-87-34-166t-91-137-137-92-166-34q-96 0-183 41t-147 114q-4 6-4 13t5 11l76 77q6 5 14 5 9-1 13-7 41-53 100-82t126-29q58 0 110 23t92 61 61 91 22 111-22 111-61 91-92 61-110 23q-55 0-105-20t-90-57l77-77q17-16 8-38-10-23-33-23h-250q-15 0-25 11t-11 25v250q0 24 22 33 22 10 39-8l72-72q60 57 137 88t159 31q87 0 166-34t137-92 91-137 34-166z\",transform:\"matrix(1 0 0 -1 0 850)\"},home:{width:928.6,height:1e3,path:\"m786 296v-267q0-15-11-26t-25-10h-214v214h-143v-214h-214q-15 0-25 10t-11 26v267q0 1 0 2t0 2l321 264 321-264q1-1 1-4z m124 39l-34-41q-5-5-12-6h-2q-7 0-12 3l-386 322-386-322q-7-4-13-4-7 2-12 7l-35 41q-4 5-3 13t6 12l401 334q18 15 42 15t43-15l136-114v109q0 8 5 13t13 5h107q8 0 13-5t5-13v-227l122-102q5-5 6-12t-4-13z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"camera-retro\":{width:1e3,height:1e3,path:\"m518 386q0 8-5 13t-13 5q-37 0-63-27t-26-63q0-8 5-13t13-5 12 5 5 13q0 23 16 38t38 16q8 0 13 5t5 13z m125-73q0-59-42-101t-101-42-101 42-42 101 42 101 101 42 101-42 42-101z m-572-320h858v71h-858v-71z m643 320q0 89-62 152t-152 62-151-62-63-152 63-151 151-63 152 63 62 151z m-571 358h214v72h-214v-72z m-72-107h858v143h-462l-36-71h-360v-72z m929 143v-714q0-30-21-51t-50-21h-858q-29 0-50 21t-21 51v714q0 30 21 51t50 21h858q29 0 50-21t21-51z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoombox:{width:1e3,height:1e3,path:\"m1000-25l-250 251c40 63 63 138 63 218 0 224-182 406-407 406-224 0-406-182-406-406s183-406 407-406c80 0 155 22 218 62l250-250 125 125z m-812 250l0 438 437 0 0-438-437 0z m62 375l313 0 0-312-313 0 0 312z\",transform:\"matrix(1 0 0 -1 0 850)\"},pan:{width:1e3,height:1e3,path:\"m1000 350l-187 188 0-125-250 0 0 250 125 0-188 187-187-187 125 0 0-250-250 0 0 125-188-188 186-187 0 125 252 0 0-250-125 0 187-188 188 188-125 0 0 250 250 0 0-126 187 188z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_plus:{width:875,height:1e3,path:\"m1 787l0-875 875 0 0 875-875 0z m687-500l-187 0 0-187-125 0 0 187-188 0 0 125 188 0 0 187 125 0 0-187 187 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_minus:{width:875,height:1e3,path:\"m0 788l0-876 875 0 0 876-875 0z m688-500l-500 0 0 125 500 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},autoscale:{width:1e3,height:1e3,path:\"m250 850l-187 0-63 0 0-62 0-188 63 0 0 188 187 0 0 62z m688 0l-188 0 0-62 188 0 0-188 62 0 0 188 0 62-62 0z m-875-938l0 188-63 0 0-188 0-62 63 0 187 0 0 62-187 0z m875 188l0-188-188 0 0-62 188 0 62 0 0 62 0 188-62 0z m-125 188l-1 0-93-94-156 156 156 156 92-93 2 0 0 250-250 0 0-2 93-92-156-156-156 156 94 92 0 2-250 0 0-250 0 0 93 93 157-156-157-156-93 94 0 0 0-250 250 0 0 0-94 93 156 157 156-157-93-93 0 0 250 0 0 250z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_basic:{width:1500,height:1e3,path:\"m375 725l0 0-375-375 375-374 0-1 1125 0 0 750-1125 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_compare:{width:1125,height:1e3,path:\"m187 786l0 2-187-188 188-187 0 0 937 0 0 373-938 0z m0-499l0 1-187-188 188-188 0 0 937 0 0 376-938-1z\",transform:\"matrix(1 0 0 -1 0 850)\"},plotlylogo:{width:1542,height:1e3,path:\"m0-10h182v-140h-182v140z m228 146h183v-286h-183v286z m225 714h182v-1000h-182v1000z m225-285h182v-715h-182v715z m225 142h183v-857h-183v857z m231-428h182v-429h-182v429z m225-291h183v-138h-183v138z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"z-axis\":{width:1e3,height:1e3,path:\"m833 5l-17 108v41l-130-65 130-66c0 0 0 38 0 39 0-1 36-14 39-25 4-15-6-22-16-30-15-12-39-16-56-20-90-22-187-23-279-23-261 0-341 34-353 59 3 60 228 110 228 110-140-8-351-35-351-116 0-120 293-142 474-142 155 0 477 22 477 142 0 50-74 79-163 96z m-374 94c-58-5-99-21-99-40 0-24 65-43 144-43 79 0 143 19 143 43 0 19-42 34-98 40v216h87l-132 135-133-135h88v-216z m167 515h-136v1c16 16 31 34 46 52l84 109v54h-230v-71h124v-1c-16-17-28-32-44-51l-89-114v-51h245v72z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"3d_rotate\":{width:1e3,height:1e3,path:\"m922 660c-5 4-9 7-14 11-359 263-580-31-580-31l-102 28 58-400c0 1 1 1 2 2 118 108 351 249 351 249s-62 27-100 42c88 83 222 183 347 122 16-8 30-17 44-27-2 1-4 2-6 4z m36-329c0 0 64 229-88 296-62 27-124 14-175-11 157-78 225-208 249-266 8-19 11-31 11-31 2 5 6 15 11 32-5-13-8-20-8-20z m-775-239c70-31 117-50 198-32-121 80-199 346-199 346l-96-15-58-12c0 0 55-226 155-287z m603 133l-317-139c0 0 4-4 19-14 7-5 24-15 24-15s-177-147-389 4c235-287 536-112 536-112l31-22 100 299-4-1z m-298-153c6-4 14-9 24-15 0 0-17 10-24 15z\",transform:\"matrix(1 0 0 -1 0 850)\"},camera:{width:1e3,height:1e3,path:\"m500 450c-83 0-150-67-150-150 0-83 67-150 150-150 83 0 150 67 150 150 0 83-67 150-150 150z m400 150h-120c-16 0-34 13-39 29l-31 93c-6 15-23 28-40 28h-340c-16 0-34-13-39-28l-31-94c-6-15-23-28-40-28h-120c-55 0-100-45-100-100v-450c0-55 45-100 100-100h800c55 0 100 45 100 100v450c0 55-45 100-100 100z m-400-550c-138 0-250 112-250 250 0 138 112 250 250 250 138 0 250-112 250-250 0-138-112-250-250-250z m365 380c-19 0-35 16-35 35 0 19 16 35 35 35 19 0 35-16 35-35 0-19-16-35-35-35z\",transform:\"matrix(1 0 0 -1 0 850)\"},movie:{width:1e3,height:1e3,path:\"m938 413l-188-125c0 37-17 71-44 94 64 38 107 107 107 187 0 121-98 219-219 219-121 0-219-98-219-219 0-61 25-117 66-156h-115c30 33 49 76 49 125 0 103-84 187-187 187s-188-84-188-187c0-57 26-107 65-141-38-22-65-62-65-109v-250c0-70 56-126 125-126h500c69 0 125 56 125 126l188-126c34 0 62 28 62 63v375c0 35-28 63-62 63z m-750 0c-69 0-125 56-125 125s56 125 125 125 125-56 125-125-56-125-125-125z m406-1c-87 0-157 70-157 157 0 86 70 156 157 156s156-70 156-156-70-157-156-157z\",transform:\"matrix(1 0 0 -1 0 850)\"},question:{width:857.1,height:1e3,path:\"m500 82v107q0 8-5 13t-13 5h-107q-8 0-13-5t-5-13v-107q0-8 5-13t13-5h107q8 0 13 5t5 13z m143 375q0 49-31 91t-77 65-95 23q-136 0-207-119-9-14 4-24l74-55q4-4 10-4 9 0 14 7 30 38 48 51 19 14 48 14 27 0 48-15t21-33q0-21-11-34t-38-25q-35-16-65-48t-29-70v-20q0-8 5-13t13-5h107q8 0 13 5t5 13q0 10 12 27t30 28q18 10 28 16t25 19 25 27 16 34 7 45z m214-107q0-117-57-215t-156-156-215-58-216 58-155 156-58 215 58 215 155 156 216 58 215-58 156-156 57-215z\",transform:\"matrix(1 0 0 -1 0 850)\"},disk:{width:857.1,height:1e3,path:\"m214-7h429v214h-429v-214z m500 0h72v500q0 8-6 21t-11 20l-157 156q-5 6-19 12t-22 5v-232q0-22-15-38t-38-16h-322q-22 0-37 16t-16 38v232h-72v-714h72v232q0 22 16 38t37 16h465q22 0 38-16t15-38v-232z m-214 518v178q0 8-5 13t-13 5h-107q-7 0-13-5t-5-13v-178q0-8 5-13t13-5h107q7 0 13 5t5 13z m357-18v-518q0-22-15-38t-38-16h-750q-23 0-38 16t-16 38v750q0 22 16 38t38 16h517q23 0 50-12t42-26l156-157q16-15 27-42t11-49z\",transform:\"matrix(1 0 0 -1 0 850)\"},lasso:{width:1031,height:1e3,path:\"m1018 538c-36 207-290 336-568 286-277-48-473-256-436-463 10-57 36-108 76-151-13-66 11-137 68-183 34-28 75-41 114-42l-55-70 0 0c-2-1-3-2-4-3-10-14-8-34 5-45 14-11 34-8 45 4 1 1 2 3 2 5l0 0 113 140c16 11 31 24 45 40 4 3 6 7 8 11 48-3 100 0 151 9 278 48 473 255 436 462z m-624-379c-80 14-149 48-197 96 42 42 109 47 156 9 33-26 47-66 41-105z m-187-74c-19 16-33 37-39 60 50-32 109-55 174-68-42-25-95-24-135 8z m360 75c-34-7-69-9-102-8 8 62-16 128-68 170-73 59-175 54-244-5-9 20-16 40-20 61-28 159 121 317 333 354s407-60 434-217c28-159-121-318-333-355z\",transform:\"matrix(1 0 0 -1 0 850)\"},selectbox:{width:1e3,height:1e3,path:\"m0 850l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-285l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},spikeline:{width:1e3,height:1e3,path:\"M512 409c0-57-46-104-103-104-57 0-104 47-104 104 0 57 47 103 104 103 57 0 103-46 103-103z m-327-39l92 0 0 92-92 0z m-185 0l92 0 0 92-92 0z m370-186l92 0 0 93-92 0z m0-184l92 0 0 92-92 0z\",transform:\"matrix(1.5 0 0 -1.5 0 850)\"},pencil:{width:1792,height:1792,path:\"M491 1536l91-91-235-235-91 91v107h128v128h107zm523-928q0-22-22-22-10 0-17 7l-542 542q-7 7-7 17 0 22 22 22 10 0 17-7l542-542q7-7 7-17zm-54-192l416 416-832 832h-416v-416zm683 96q0 53-37 90l-166 166-416-416 166-165q36-38 90-38 53 0 91 38l235 234q37 39 37 91z\",transform:\"matrix(1 0 0 1 0 1)\"},newplotlylogo:{name:\"newplotlylogo\",svg:\"<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 132 132'><defs><style>.cls-1 {fill: #119dff;} .cls-2 {fill: #25fefd;} .cls-3 {fill: #fff;}</style></defs><title>plotly-logomark</title><g id='symbol'><rect class='cls-1' width='132' height='132' rx='6' ry='6'/><circle class='cls-2' cx='78' cy='54' r='6'/><circle class='cls-2' cx='102' cy='30' r='6'/><circle class='cls-2' cx='78' cy='30' r='6'/><circle class='cls-2' cx='54' cy='30' r='6'/><circle class='cls-2' cx='30' cy='30' r='6'/><circle class='cls-2' cx='30' cy='54' r='6'/><path class='cls-3' d='M30,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,30,72Z'/><path class='cls-3' d='M78,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,78,72Z'/><path class='cls-3' d='M54,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,54,48Z'/><path class='cls-3' d='M102,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,102,48Z'/></g></svg>\"}}},{}],700:[function(t,e,r){\"use strict\";r.isLeftAnchor=function(t){return\"left\"===t.xanchor||\"auto\"===t.xanchor&&t.x<=1/3},r.isCenterAnchor=function(t){return\"center\"===t.xanchor||\"auto\"===t.xanchor&&t.x>1/3&&t.x<2/3},r.isRightAnchor=function(t){return\"right\"===t.xanchor||\"auto\"===t.xanchor&&t.x>=2/3},r.isTopAnchor=function(t){return\"top\"===t.yanchor||\"auto\"===t.yanchor&&t.y>=2/3},r.isMiddleAnchor=function(t){return\"middle\"===t.yanchor||\"auto\"===t.yanchor&&t.y>1/3&&t.y<2/3},r.isBottomAnchor=function(t){return\"bottom\"===t.yanchor||\"auto\"===t.yanchor&&t.y<=1/3}},{}],701:[function(t,e,r){\"use strict\";var n=t(\"./mod\"),i=n.mod,a=n.modHalf,o=Math.PI,s=2*o;function l(t){return Math.abs(t[1]-t[0])>s-1e-14}function c(t,e){return a(e-t,s)}function u(t,e){if(l(e))return!0;var r,n;e[0]<e[1]?(r=e[0],n=e[1]):(r=e[1],n=e[0]),(r=i(r,s))>(n=i(n,s))&&(n+=s);var a=i(t,s),o=a+s;return a>=r&&a<=n||o>=r&&o<=n}function h(t,e,r,n,i,a,c){i=i||0,a=a||0;var u,h,f,p,d,g=l([r,n]);function v(t,e){return[t*Math.cos(e)+i,a-t*Math.sin(e)]}g?(u=0,h=o,f=s):r<n?(u=r,f=n):(u=n,f=r),t<e?(p=t,d=e):(p=e,d=t);var m,y=Math.abs(f-u)<=o?0:1;function x(t,e,r){return\"A\"+[t,t]+\" \"+[0,y,r]+\" \"+v(t,e)}return g?m=null===p?\"M\"+v(d,u)+x(d,h,0)+x(d,f,0)+\"Z\":\"M\"+v(p,u)+x(p,h,0)+x(p,f,0)+\"ZM\"+v(d,u)+x(d,h,1)+x(d,f,1)+\"Z\":null===p?(m=\"M\"+v(d,u)+x(d,f,0),c&&(m+=\"L0,0Z\")):m=\"M\"+v(p,u)+\"L\"+v(d,u)+x(d,f,0)+\"L\"+v(p,f)+x(p,u,1)+\"Z\",m}e.exports={deg2rad:function(t){return t/180*o},rad2deg:function(t){return t/o*180},angleDelta:c,angleDist:function(t,e){return Math.abs(c(t,e))},isFullCircle:l,isAngleInsideSector:u,isPtInsideSector:function(t,e,r,n){return!!u(e,n)&&(r[0]<r[1]?(i=r[0],a=r[1]):(i=r[1],a=r[0]),t>=i&&t<=a);var i,a},pathArc:function(t,e,r,n,i){return h(null,t,e,r,n,i,0)},pathSector:function(t,e,r,n,i){return h(null,t,e,r,n,i,1)},pathAnnulus:function(t,e,r,n,i,a){return h(t,e,r,n,i,a,1)}}},{\"./mod\":726}],702:[function(t,e,r){\"use strict\";var n=Array.isArray,i=\"undefined\"!=typeof ArrayBuffer&&ArrayBuffer.isView?ArrayBuffer:{isView:function(){return!1}},a=\"undefined\"==typeof DataView?function(){}:DataView;function o(t){return i.isView(t)&&!(t instanceof a)}function s(t){return n(t)||o(t)}function l(t,e,r){if(s(t)){if(s(t[0])){for(var n=r,i=0;i<t.length;i++)n=e(n,t[i].length);return n}return t.length}return 0}r.isTypedArray=o,r.isArrayOrTypedArray=s,r.isArray1D=function(t){return!s(t[0])},r.ensureArray=function(t,e){return n(t)||(t=[]),t.length=e,t},r.concat=function(){var t,e,r,i,a,o,s,l,c=[],u=!0,h=0;for(r=0;r<arguments.length;r++)(o=(i=arguments[r]).length)&&(e?c.push(i):(e=i,a=o),n(i)?t=!1:(u=!1,h?t!==i.constructor&&(t=!1):t=i.constructor),h+=o);if(!h)return[];if(!c.length)return e;if(u)return e.concat.apply(e,c);if(t){for((s=new t(h)).set(e),r=0;r<c.length;r++)i=c[r],s.set(i,a),a+=i.length;return s}for(s=new Array(h),l=0;l<e.length;l++)s[l]=e[l];for(r=0;r<c.length;r++){for(i=c[r],l=0;l<i.length;l++)s[a+l]=i[l];a+=l}return s},r.maxRowLength=function(t){return l(t,Math.max,0)},r.minRowLength=function(t){return l(t,Math.min,1/0)}},{}],703:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../constants/numerical\").BADNUM,a=/^['\"%,$#\\s']+|[, ]|['\"%,$#\\s']+$/g;e.exports=function(t){return\"string\"==typeof t&&(t=t.replace(a,\"\")),n(t)?Number(t):i}},{\"../constants/numerical\":695,\"fast-isnumeric\":225}],704:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t._fullLayout;e._glcanvas&&e._glcanvas.size()&&e._glcanvas.each(function(t){t.regl&&t.regl.clear({color:!0,depth:!0})})}},{}],705:[function(t,e,r){\"use strict\";e.exports=function(t){t._responsiveChartHandler&&(window.removeEventListener(\"resize\",t._responsiveChartHandler),delete t._responsiveChartHandler)}},{}],706:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../plots/attributes\"),o=t(\"../components/colorscale/scales\"),s=t(\"../constants/interactions\").DESELECTDIM,l=t(\"./nested_property\"),c=t(\"./regex\").counter,u=t(\"./mod\").modHalf,h=t(\"./array\").isArrayOrTypedArray;function f(t,e){var n=r.valObjectMeta[e.valType];if(e.arrayOk&&h(t))return!0;if(n.validateFunction)return n.validateFunction(t,e);var i={},a=i,o={set:function(t){a=t}};return n.coerceFunction(t,o,i,e),a!==i}r.valObjectMeta={data_array:{coerceFunction:function(t,e,r){h(t)?e.set(t):void 0!==r&&e.set(r)}},enumerated:{coerceFunction:function(t,e,r,n){n.coerceNumber&&(t=+t),-1===n.values.indexOf(t)?e.set(r):e.set(t)},validateFunction:function(t,e){e.coerceNumber&&(t=+t);for(var r=e.values,n=0;n<r.length;n++){var i=String(r[n]);if(\"/\"===i.charAt(0)&&\"/\"===i.charAt(i.length-1)){if(new RegExp(i.substr(1,i.length-2)).test(t))return!0}else if(t===r[n])return!0}return!1}},boolean:{coerceFunction:function(t,e,r){!0===t||!1===t?e.set(t):e.set(r)}},number:{coerceFunction:function(t,e,r,i){!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},integer:{coerceFunction:function(t,e,r,i){t%1||!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},string:{coerceFunction:function(t,e,r,n){if(\"string\"!=typeof t){var i=\"number\"==typeof t;!0!==n.strict&&i?e.set(String(t)):e.set(r)}else n.noBlank&&!t?e.set(r):e.set(t)}},color:{coerceFunction:function(t,e,r){i(t).isValid()?e.set(t):e.set(r)}},colorlist:{coerceFunction:function(t,e,r){Array.isArray(t)&&t.length&&t.every(function(t){return i(t).isValid()})?e.set(t):e.set(r)}},colorscale:{coerceFunction:function(t,e,r){e.set(o.get(t,r))}},angle:{coerceFunction:function(t,e,r){\"auto\"===t?e.set(\"auto\"):n(t)?e.set(u(+t,360)):e.set(r)}},subplotid:{coerceFunction:function(t,e,r,n){var i=n.regex||c(r);\"string\"==typeof t&&i.test(t)?e.set(t):e.set(r)},validateFunction:function(t,e){var r=e.dflt;return t===r||\"string\"==typeof t&&!!c(r).test(t)}},flaglist:{coerceFunction:function(t,e,r,n){if(\"string\"==typeof t)if(-1===(n.extras||[]).indexOf(t)){for(var i=t.split(\"+\"),a=0;a<i.length;){var o=i[a];-1===n.flags.indexOf(o)||i.indexOf(o)<a?i.splice(a,1):a++}i.length?e.set(i.join(\"+\")):e.set(r)}else e.set(t);else e.set(r)}},any:{coerceFunction:function(t,e,r){void 0===t?e.set(r):e.set(t)}},info_array:{coerceFunction:function(t,e,n,i){function a(t,e,n){var i,a={set:function(t){i=t}};return void 0===n&&(n=e.dflt),r.valObjectMeta[e.valType].coerceFunction(t,a,n,e),i}var o=2===i.dimensions||\"1-2\"===i.dimensions&&Array.isArray(t)&&Array.isArray(t[0]);if(Array.isArray(t)){var s,l,c,u,h,f,p=i.items,d=[],g=Array.isArray(p),v=g&&o&&Array.isArray(p[0]),m=o&&g&&!v,y=g&&!m?p.length:t.length;if(n=Array.isArray(n)?n:[],o)for(s=0;s<y;s++)for(d[s]=[],c=Array.isArray(t[s])?t[s]:[],h=m?p.length:g?p[s].length:c.length,l=0;l<h;l++)u=m?p[l]:g?p[s][l]:p,void 0!==(f=a(c[l],u,(n[s]||[])[l]))&&(d[s][l]=f);else for(s=0;s<y;s++)void 0!==(f=a(t[s],g?p[s]:p,n[s]))&&(d[s]=f);e.set(d)}else e.set(n)},validateFunction:function(t,e){if(!Array.isArray(t))return!1;var r=e.items,n=Array.isArray(r),i=2===e.dimensions;if(!e.freeLength&&t.length!==r.length)return!1;for(var a=0;a<t.length;a++)if(i){if(!Array.isArray(t[a])||!e.freeLength&&t[a].length!==r[a].length)return!1;for(var o=0;o<t[a].length;o++)if(!f(t[a][o],n?r[a][o]:r))return!1}else if(!f(t[a],n?r[a]:r))return!1;return!0}}},r.coerce=function(t,e,n,i,a){var o=l(n,i).get(),s=l(t,i),c=l(e,i),u=s.get(),p=e._template;if(void 0===u&&p&&(u=l(p,i).get(),p=0),void 0===a&&(a=o.dflt),o.arrayOk&&h(u))return c.set(u),u;var d=r.valObjectMeta[o.valType].coerceFunction;d(u,c,a,o);var g=c.get();return p&&g===a&&!f(u,o)&&(d(u=l(p,i).get(),c,a,o),g=c.get()),g},r.coerce2=function(t,e,n,i,a){var o=l(t,i),s=r.coerce(t,e,n,i,a),c=o.get();return null!=c&&s},r.coerceFont=function(t,e,r){var n={};return r=r||{},n.family=t(e+\".family\",r.family),n.size=t(e+\".size\",r.size),n.color=t(e+\".color\",r.color),n},r.coerceHoverinfo=function(t,e,n){var i,o=e._module.attributes,s=o.hoverinfo?o:a,l=s.hoverinfo;if(1===n._dataLength){var c=\"all\"===l.dflt?l.flags.slice():l.dflt.split(\"+\");c.splice(c.indexOf(\"name\"),1),i=c.join(\"+\")}return r.coerce(t,e,s,\"hoverinfo\",i)},r.coerceSelectionMarkerOpacity=function(t,e){if(t.marker){var r,n,i=t.marker.opacity;if(void 0!==i)h(i)||t.selected||t.unselected||(r=i,n=s*i),e(\"selected.marker.opacity\",r),e(\"unselected.marker.opacity\",n)}},r.validate=f},{\"../components/colorscale/scales\":608,\"../constants/interactions\":694,\"../plots/attributes\":764,\"./array\":702,\"./mod\":726,\"./nested_property\":727,\"./regex\":735,\"fast-isnumeric\":225,tinycolor2:537}],707:[function(t,e,r){\"use strict\";var n,i,a=t(\"d3\"),o=t(\"fast-isnumeric\"),s=t(\"./loggers\"),l=t(\"./mod\").mod,c=t(\"../constants/numerical\"),u=c.BADNUM,h=c.ONEDAY,f=c.ONEHOUR,p=c.ONEMIN,d=c.ONESEC,g=c.EPOCHJD,v=t(\"../registry\"),m=a.time.format.utc,y=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\d)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d:?\\d\\d)?)?)?)?)?\\s*$/m,x=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\di?)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d:?\\d\\d)?)?)?)?)?\\s*$/m,b=(new Date).getFullYear()-70;function _(t){return t&&v.componentsRegistry.calendars&&\"string\"==typeof t&&\"gregorian\"!==t}function w(t,e){return String(t+Math.pow(10,e)).substr(1)}r.dateTick0=function(t,e){return _(t)?e?v.getComponentMethod(\"calendars\",\"CANONICAL_SUNDAY\")[t]:v.getComponentMethod(\"calendars\",\"CANONICAL_TICK\")[t]:e?\"2000-01-02\":\"2000-01-01\"},r.dfltRange=function(t){return _(t)?v.getComponentMethod(\"calendars\",\"DFLTRANGE\")[t]:[\"2000-01-01\",\"2001-01-01\"]},r.isJSDate=function(t){return\"object\"==typeof t&&null!==t&&\"function\"==typeof t.getTime},r.dateTime2ms=function(t,e){if(r.isJSDate(t)){var a=t.getTimezoneOffset()*p,o=(t.getUTCMinutes()-t.getMinutes())*p+(t.getUTCSeconds()-t.getSeconds())*d+(t.getUTCMilliseconds()-t.getMilliseconds());if(o){var s=3*p;a=a-s/2+l(o-a+s/2,s)}return(t=Number(t)-a)>=n&&t<=i?t:u}if(\"string\"!=typeof t&&\"number\"!=typeof t)return u;t=String(t);var c=_(e),m=t.charAt(0);!c||\"G\"!==m&&\"g\"!==m||(t=t.substr(1),e=\"\");var w=c&&\"chinese\"===e.substr(0,7),k=t.match(w?x:y);if(!k)return u;var T=k[1],A=k[3]||\"1\",M=Number(k[5]||1),S=Number(k[7]||0),E=Number(k[9]||0),C=Number(k[11]||0);if(c){if(2===T.length)return u;var L;T=Number(T);try{var P=v.getComponentMethod(\"calendars\",\"getCal\")(e);if(w){var O=\"i\"===A.charAt(A.length-1);A=parseInt(A,10),L=P.newDate(T,P.toMonthIndex(T,A,O),M)}else L=P.newDate(T,Number(A),M)}catch(t){return u}return L?(L.toJD()-g)*h+S*f+E*p+C*d:u}T=2===T.length?(Number(T)+2e3-b)%100+b:Number(T),A-=1;var z=new Date(Date.UTC(2e3,A,M,S,E));return z.setUTCFullYear(T),z.getUTCMonth()!==A?u:z.getUTCDate()!==M?u:z.getTime()+C*d},n=r.MIN_MS=r.dateTime2ms(\"-9999\"),i=r.MAX_MS=r.dateTime2ms(\"9999-12-31 23:59:59.9999\"),r.isDateTime=function(t,e){return r.dateTime2ms(t,e)!==u};var k=90*h,T=3*f,A=5*p;function M(t,e,r,n,i){if((e||r||n||i)&&(t+=\" \"+w(e,2)+\":\"+w(r,2),(n||i)&&(t+=\":\"+w(n,2),i))){for(var a=4;i%10==0;)a-=1,i/=10;t+=\".\"+w(i,a)}return t}r.ms2DateTime=function(t,e,r){if(\"number\"!=typeof t||!(t>=n&&t<=i))return u;e||(e=0);var a,o,s,c,y,x,b=Math.floor(10*l(t+.05,1)),w=Math.round(t-b/10);if(_(r)){var S=Math.floor(w/h)+g,E=Math.floor(l(t,h));try{a=v.getComponentMethod(\"calendars\",\"getCal\")(r).fromJD(S).formatDate(\"yyyy-mm-dd\")}catch(t){a=m(\"G%Y-%m-%d\")(new Date(w))}if(\"-\"===a.charAt(0))for(;a.length<11;)a=\"-0\"+a.substr(1);else for(;a.length<10;)a=\"0\"+a;o=e<k?Math.floor(E/f):0,s=e<k?Math.floor(E%f/p):0,c=e<T?Math.floor(E%p/d):0,y=e<A?E%d*10+b:0}else x=new Date(w),a=m(\"%Y-%m-%d\")(x),o=e<k?x.getUTCHours():0,s=e<k?x.getUTCMinutes():0,c=e<T?x.getUTCSeconds():0,y=e<A?10*x.getUTCMilliseconds()+b:0;return M(a,o,s,c,y)},r.ms2DateTimeLocal=function(t){if(!(t>=n+h&&t<=i-h))return u;var e=Math.floor(10*l(t+.05,1)),r=new Date(Math.round(t-e/10));return M(a.time.format(\"%Y-%m-%d\")(r),r.getHours(),r.getMinutes(),r.getSeconds(),10*r.getUTCMilliseconds()+e)},r.cleanDate=function(t,e,n){if(t===u)return e;if(r.isJSDate(t)||\"number\"==typeof t&&isFinite(t)){if(_(n))return s.error(\"JS Dates and milliseconds are incompatible with world calendars\",t),e;if(!(t=r.ms2DateTimeLocal(+t))&&void 0!==e)return e}else if(!r.isDateTime(t,n))return s.error(\"unrecognized date\",t),e;return t};var S=/%\\d?f/g;function E(t,e,r,n){t=t.replace(S,function(t){var r=Math.min(+t.charAt(1)||6,6);return(e/1e3%1+2).toFixed(r).substr(2).replace(/0+$/,\"\")||\"0\"});var i=new Date(Math.floor(e+.05));if(_(n))try{t=v.getComponentMethod(\"calendars\",\"worldCalFmt\")(t,e,n)}catch(t){return\"Invalid\"}return r(t)(i)}var C=[59,59.9,59.99,59.999,59.9999];r.formatDate=function(t,e,r,n,i,a){if(i=_(i)&&i,!e)if(\"y\"===r)e=a.year;else if(\"m\"===r)e=a.month;else{if(\"d\"!==r)return function(t,e){var r=l(t+.05,h),n=w(Math.floor(r/f),2)+\":\"+w(l(Math.floor(r/p),60),2);if(\"M\"!==e){o(e)||(e=0);var i=(100+Math.min(l(t/d,60),C[e])).toFixed(e).substr(1);e>0&&(i=i.replace(/0+$/,\"\").replace(/[\\.]$/,\"\")),n+=\":\"+i}return n}(t,r)+\"\\n\"+E(a.dayMonthYear,t,n,i);e=a.dayMonth+\"\\n\"+a.year}return E(e,t,n,i)};var L=3*h;r.incrementMonth=function(t,e,r){r=_(r)&&r;var n=l(t,h);if(t=Math.round(t-n),r)try{var i=Math.round(t/h)+g,a=v.getComponentMethod(\"calendars\",\"getCal\")(r),o=a.fromJD(i);return e%12?a.add(o,e,\"m\"):a.add(o,e/12,\"y\"),(o.toJD()-g)*h+n}catch(e){s.error(\"invalid ms \"+t+\" in calendar \"+r)}var c=new Date(t+L);return c.setUTCMonth(c.getUTCMonth()+e)+n-L},r.findExactDates=function(t,e){for(var r,n,i=0,a=0,s=0,l=0,c=_(e)&&v.getComponentMethod(\"calendars\",\"getCal\")(e),u=0;u<t.length;u++)if(n=t[u],o(n)){if(!(n%h))if(c)try{1===(r=c.fromJD(n/h+g)).day()?1===r.month()?i++:a++:s++}catch(t){}else 1===(r=new Date(n)).getUTCDate()?0===r.getUTCMonth()?i++:a++:s++}else l++;s+=a+=i;var f=t.length-l;return{exactYears:i/f,exactMonths:a/f,exactDays:s/f}}},{\"../constants/numerical\":695,\"../registry\":847,\"./loggers\":723,\"./mod\":726,d3:163,\"fast-isnumeric\":225}],708:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./loggers\");function a(t){var e=t&&t.parentNode;e&&e.removeChild(t)}function o(t,e,r){var n=\"plotly.js-style-\"+t,a=document.getElementById(n);a||((a=document.createElement(\"style\")).setAttribute(\"id\",n),a.appendChild(document.createTextNode(\"\")),document.head.appendChild(a));var o=a.sheet;o.insertRule?o.insertRule(e+\"{\"+r+\"}\",0):o.addRule?o.addRule(e,r,0):i.warn(\"addStyleRule failed\")}e.exports={getGraphDiv:function(t){var e;if(\"string\"==typeof t){if(null===(e=document.getElementById(t)))throw new Error(\"No DOM element with id '\"+t+\"' exists on the page.\");return e}if(null==t)throw new Error(\"DOM element provided is null or undefined\");return t},isPlotDiv:function(t){var e=n.select(t);return e.node()instanceof HTMLElement&&e.size()&&e.classed(\"js-plotly-plot\")},removeElement:a,addStyleRule:function(t,e){o(\"global\",t,e)},addRelatedStyleRule:o,deleteRelatedStyleRule:function(t){var e=\"plotly.js-style-\"+t,r=document.getElementById(e);r&&a(r)}}},{\"./loggers\":723,d3:163}],709:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i={init:function(t){if(t._ev instanceof n)return t;var e=new n,r=new n;return t._ev=e,t._internalEv=r,t.on=e.on.bind(e),t.once=e.once.bind(e),t.removeListener=e.removeListener.bind(e),t.removeAllListeners=e.removeAllListeners.bind(e),t._internalOn=r.on.bind(r),t._internalOnce=r.once.bind(r),t._removeInternalListener=r.removeListener.bind(r),t._removeAllInternalListeners=r.removeAllListeners.bind(r),t.emit=function(n,i){\"undefined\"!=typeof jQuery&&jQuery(t).trigger(n,i),e.emit(n,i),r.emit(n,i)},t},triggerHandler:function(t,e,r){var n,i;\"undefined\"!=typeof jQuery&&(n=jQuery(t).triggerHandler(e,r));var a=t._ev;if(!a)return n;var o,s=a._events[e];if(!s)return n;function l(t){return t.listener?(a.removeListener(e,t.listener),t.fired?void 0:(t.fired=!0,t.listener.apply(a,[r]))):t.apply(a,[r])}for(s=Array.isArray(s)?s:[s],o=0;o<s.length-1;o++)l(s[o]);return i=l(s[o]),void 0!==n?n:i},purge:function(t){return delete t._ev,delete t.on,delete t.once,delete t.removeListener,delete t.removeAllListeners,delete t.emit,delete t._ev,delete t._internalEv,delete t._internalOn,delete t._internalOnce,delete t._removeInternalListener,delete t._removeAllInternalListeners,t}};e.exports=i},{events:104}],710:[function(t,e,r){\"use strict\";var n=t(\"./is_plain_object.js\"),i=Array.isArray;function a(t,e,r,o){var s,l,c,u,h,f,p=t[0],d=t.length;if(2===d&&i(p)&&i(t[1])&&0===p.length){if(function(t,e){var r,n;for(r=0;r<t.length;r++){if(null!==(n=t[r])&&\"object\"==typeof n)return!1;void 0!==n&&(e[r]=n)}return!0}(t[1],p))return p;p.splice(0,p.length)}for(var g=1;g<d;g++)for(l in s=t[g])c=p[l],u=s[l],o&&i(u)?p[l]=u:e&&u&&(n(u)||(h=i(u)))?(h?(h=!1,f=c&&i(c)?c:[]):f=c&&n(c)?c:{},p[l]=a([f,u],e,r,o)):(\"undefined\"!=typeof u||r)&&(p[l]=u);return p}r.extendFlat=function(){return a(arguments,!1,!1,!1)},r.extendDeep=function(){return a(arguments,!0,!1,!1)},r.extendDeepAll=function(){return a(arguments,!0,!0,!1)},r.extendDeepNoArrays=function(){return a(arguments,!0,!1,!0)}},{\"./is_plain_object.js\":720}],711:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e={},r=[],n=0,i=0;i<t.length;i++){var a=t[i];1!==e[a]&&(e[a]=1,r[n++]=a)}return r}},{}],712:[function(t,e,r){\"use strict\";function n(t){return!0===t.visible}function i(t){var e=t[0].trace;return!0===e.visible&&0!==e._length}e.exports=function(t){for(var e,r=(e=t,Array.isArray(e)&&Array.isArray(e[0])&&e[0][0]&&e[0][0].trace?i:n),a=[],o=0;o<t.length;o++){var s=t[o];r(s)&&a.push(s)}return a}},{}],713:[function(t,e,r){\"use strict\";var n=t(\"country-regex\"),i=t(\"../lib\"),a=Object.keys(n),o={\"ISO-3\":i.identity,\"USA-states\":i.identity,\"country names\":function(t){for(var e=0;e<a.length;e++){var r=a[e],o=new RegExp(n[r]);if(o.test(t.trim().toLowerCase()))return r}return i.log(\"Unrecognized country name: \"+t+\".\"),!1}};e.exports={locationToFeature:function(t,e,r){if(!e||\"string\"!=typeof e)return!1;var n,a,s,l=o[t](e);if(l){if(\"USA-states\"===t)for(n=[],s=0;s<r.length;s++)(a=r[s]).properties&&a.properties.gu&&\"USA\"===a.properties.gu&&n.push(a);else n=r;for(s=0;s<n.length;s++)if((a=n[s]).id===l)return a;i.log([\"Location with id\",l,\"does not have a matching topojson feature at this resolution.\"].join(\" \"))}return!1}}},{\"../lib\":719,\"country-regex\":134}],714:[function(t,e,r){\"use strict\";var n=t(\"../constants/numerical\").BADNUM;r.calcTraceToLineCoords=function(t){for(var e=t[0].trace.connectgaps,r=[],i=[],a=0;a<t.length;a++){var o=t[a].lonlat;o[0]!==n?i.push(o):!e&&i.length>0&&(r.push(i),i=[])}return i.length>0&&r.push(i),r},r.makeLine=function(t){return 1===t.length?{type:\"LineString\",coordinates:t[0]}:{type:\"MultiLineString\",coordinates:t}},r.makePolygon=function(t){if(1===t.length)return{type:\"Polygon\",coordinates:t};for(var e=new Array(t.length),r=0;r<t.length;r++)e[r]=[t[r]];return{type:\"MultiPolygon\",coordinates:e}},r.makeBlank=function(){return{type:\"Point\",coordinates:[]}}},{\"../constants/numerical\":695}],715:[function(t,e,r){\"use strict\";var n,i,a,o=t(\"./mod\").mod;function s(t,e,r,n,i,a,o,s){var l=r-t,c=i-t,u=o-i,h=n-e,f=a-e,p=s-a,d=l*p-u*h;if(0===d)return null;var g=(c*p-u*f)/d,v=(c*h-l*f)/d;return v<0||v>1||g<0||g>1?null:{x:t+l*g,y:e+h*g}}function l(t,e,r,n,i){var a=n*t+i*e;if(a<0)return n*n+i*i;if(a>r){var o=n-t,s=i-e;return o*o+s*s}var l=n*e-i*t;return l*l/r}r.segmentsIntersect=s,r.segmentDistance=function(t,e,r,n,i,a,o,c){if(s(t,e,r,n,i,a,o,c))return 0;var u=r-t,h=n-e,f=o-i,p=c-a,d=u*u+h*h,g=f*f+p*p,v=Math.min(l(u,h,d,i-t,a-e),l(u,h,d,o-t,c-e),l(f,p,g,t-i,e-a),l(f,p,g,r-i,n-a));return Math.sqrt(v)},r.getTextLocation=function(t,e,r,s){if(t===i&&s===a||(n={},i=t,a=s),n[r])return n[r];var l=t.getPointAtLength(o(r-s/2,e)),c=t.getPointAtLength(o(r+s/2,e)),u=Math.atan((c.y-l.y)/(c.x-l.x)),h=t.getPointAtLength(o(r,e)),f={x:(4*h.x+l.x+c.x)/6,y:(4*h.y+l.y+c.y)/6,theta:u};return n[r]=f,f},r.clearLocationCache=function(){i=null},r.getVisibleSegment=function(t,e,r){var n,i,a=e.left,o=e.right,s=e.top,l=e.bottom,c=0,u=t.getTotalLength(),h=u;function f(e){var r=t.getPointAtLength(e);0===e?n=r:e===u&&(i=r);var c=r.x<a?a-r.x:r.x>o?r.x-o:0,h=r.y<s?s-r.y:r.y>l?r.y-l:0;return Math.sqrt(c*c+h*h)}for(var p=f(c);p;){if((c+=p+r)>h)return;p=f(c)}for(p=f(h);p;){if(c>(h-=p+r))return;p=f(h)}return{min:c,max:h,len:h-c,total:u,isClosed:0===c&&h===u&&Math.abs(n.x-i.x)<.1&&Math.abs(n.y-i.y)<.1}},r.findPointOnPath=function(t,e,r,n){for(var i,a,o,s=(n=n||{}).pathLength||t.getTotalLength(),l=n.tolerance||.001,c=n.iterationLimit||30,u=t.getPointAtLength(0)[r]>t.getPointAtLength(s)[r]?-1:1,h=0,f=0,p=s;h<c;){if(i=(f+p)/2,o=(a=t.getPointAtLength(i))[r]-e,Math.abs(o)<l)return a;u*o>0?p=i:f=i,h++}return a}},{\"./mod\":726}],716:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"color-normalize\"),o=t(\"../components/colorscale\"),s=t(\"../components/color/attributes\").defaultLine,l=t(\"./array\").isArrayOrTypedArray,c=a(s),u=1;function h(t,e){var r=t;return r[3]*=e,r}function f(t){if(n(t))return c;var e=a(t);return e.length?e:c}function p(t){return n(t)?t:u}e.exports={formatColor:function(t,e,r){var n,i,s,d,g,v=t.color,m=l(v),y=l(e),x=o.extractOpts(t),b=[];if(n=void 0!==x.colorscale?o.makeColorScaleFuncFromTrace(t):f,i=m?function(t,e){return void 0===t[e]?c:a(n(t[e]))}:f,s=y?function(t,e){return void 0===t[e]?u:p(t[e])}:p,m||y)for(var _=0;_<r;_++)d=i(v,_),g=s(e,_),b[_]=h(d,g);else b=h(a(v),e);return b},parseColorScale:function(t,e){void 0===e&&(e=1);var r=o.extractOpts(t);return(r.reversescale?o.flipScale(r.colorscale):r.colorscale).map(function(t){var r=t[0],n=i(t[1]).toRgb();return{index:r,rgb:[n.r,n.g,n.b,e]}})}}},{\"../components/color/attributes\":592,\"../components/colorscale\":605,\"./array\":702,\"color-normalize\":120,\"fast-isnumeric\":225,tinycolor2:537}],717:[function(t,e,r){\"use strict\";var n=t(\"./identity\");function i(t){return[t]}e.exports={keyFun:function(t){return t.key},repeat:i,descend:n,wrap:i,unwrap:function(t){return t[0]}}},{\"./identity\":718}],718:[function(t,e,r){\"use strict\";e.exports=function(t){return t}},{}],719:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../constants/numerical\"),o=a.FP_SAFE,s=a.BADNUM,l=e.exports={};l.nestedProperty=t(\"./nested_property\"),l.keyedContainer=t(\"./keyed_container\"),l.relativeAttr=t(\"./relative_attr\"),l.isPlainObject=t(\"./is_plain_object\"),l.toLogRange=t(\"./to_log_range\"),l.relinkPrivateKeys=t(\"./relink_private\");var c=t(\"./array\");l.isTypedArray=c.isTypedArray,l.isArrayOrTypedArray=c.isArrayOrTypedArray,l.isArray1D=c.isArray1D,l.ensureArray=c.ensureArray,l.concat=c.concat,l.maxRowLength=c.maxRowLength,l.minRowLength=c.minRowLength;var u=t(\"./mod\");l.mod=u.mod,l.modHalf=u.modHalf;var h=t(\"./coerce\");l.valObjectMeta=h.valObjectMeta,l.coerce=h.coerce,l.coerce2=h.coerce2,l.coerceFont=h.coerceFont,l.coerceHoverinfo=h.coerceHoverinfo,l.coerceSelectionMarkerOpacity=h.coerceSelectionMarkerOpacity,l.validate=h.validate;var f=t(\"./dates\");l.dateTime2ms=f.dateTime2ms,l.isDateTime=f.isDateTime,l.ms2DateTime=f.ms2DateTime,l.ms2DateTimeLocal=f.ms2DateTimeLocal,l.cleanDate=f.cleanDate,l.isJSDate=f.isJSDate,l.formatDate=f.formatDate,l.incrementMonth=f.incrementMonth,l.dateTick0=f.dateTick0,l.dfltRange=f.dfltRange,l.findExactDates=f.findExactDates,l.MIN_MS=f.MIN_MS,l.MAX_MS=f.MAX_MS;var p=t(\"./search\");l.findBin=p.findBin,l.sorterAsc=p.sorterAsc,l.sorterDes=p.sorterDes,l.distinctVals=p.distinctVals,l.roundUp=p.roundUp,l.sort=p.sort,l.findIndexOfMin=p.findIndexOfMin;var d=t(\"./stats\");l.aggNums=d.aggNums,l.len=d.len,l.mean=d.mean,l.median=d.median,l.midRange=d.midRange,l.variance=d.variance,l.stdev=d.stdev,l.interp=d.interp;var g=t(\"./matrix\");l.init2dArray=g.init2dArray,l.transposeRagged=g.transposeRagged,l.dot=g.dot,l.translationMatrix=g.translationMatrix,l.rotationMatrix=g.rotationMatrix,l.rotationXYMatrix=g.rotationXYMatrix,l.apply2DTransform=g.apply2DTransform,l.apply2DTransform2=g.apply2DTransform2;var v=t(\"./angles\");l.deg2rad=v.deg2rad,l.rad2deg=v.rad2deg,l.angleDelta=v.angleDelta,l.angleDist=v.angleDist,l.isFullCircle=v.isFullCircle,l.isAngleInsideSector=v.isAngleInsideSector,l.isPtInsideSector=v.isPtInsideSector,l.pathArc=v.pathArc,l.pathSector=v.pathSector,l.pathAnnulus=v.pathAnnulus;var m=t(\"./anchor_utils\");l.isLeftAnchor=m.isLeftAnchor,l.isCenterAnchor=m.isCenterAnchor,l.isRightAnchor=m.isRightAnchor,l.isTopAnchor=m.isTopAnchor,l.isMiddleAnchor=m.isMiddleAnchor,l.isBottomAnchor=m.isBottomAnchor;var y=t(\"./geometry2d\");l.segmentsIntersect=y.segmentsIntersect,l.segmentDistance=y.segmentDistance,l.getTextLocation=y.getTextLocation,l.clearLocationCache=y.clearLocationCache,l.getVisibleSegment=y.getVisibleSegment,l.findPointOnPath=y.findPointOnPath;var x=t(\"./extend\");l.extendFlat=x.extendFlat,l.extendDeep=x.extendDeep,l.extendDeepAll=x.extendDeepAll,l.extendDeepNoArrays=x.extendDeepNoArrays;var b=t(\"./loggers\");l.log=b.log,l.warn=b.warn,l.error=b.error;var _=t(\"./regex\");l.counterRegex=_.counter;var w=t(\"./throttle\");l.throttle=w.throttle,l.throttleDone=w.done,l.clearThrottle=w.clear;var k=t(\"./dom\");function T(t){var e={};for(var r in t)for(var n=t[r],i=0;i<n.length;i++)e[n[i]]=+r;return e}l.getGraphDiv=k.getGraphDiv,l.isPlotDiv=k.isPlotDiv,l.removeElement=k.removeElement,l.addStyleRule=k.addStyleRule,l.addRelatedStyleRule=k.addRelatedStyleRule,l.deleteRelatedStyleRule=k.deleteRelatedStyleRule,l.clearResponsive=t(\"./clear_responsive\"),l.makeTraceGroups=t(\"./make_trace_groups\"),l._=t(\"./localize\"),l.notifier=t(\"./notifier\"),l.filterUnique=t(\"./filter_unique\"),l.filterVisible=t(\"./filter_visible\"),l.pushUnique=t(\"./push_unique\"),l.cleanNumber=t(\"./clean_number\"),l.ensureNumber=function(t){return i(t)?(t=Number(t))<-o||t>o?s:i(t)?Number(t):s:s},l.isIndex=function(t,e){return!(void 0!==e&&t>=e)&&(i(t)&&t>=0&&t%1==0)},l.noop=t(\"./noop\"),l.identity=t(\"./identity\"),l.repeat=function(t,e){for(var r=new Array(e),n=0;n<e;n++)r[n]=t;return r},l.swapAttrs=function(t,e,r,n){r||(r=\"x\"),n||(n=\"y\");for(var i=0;i<e.length;i++){var a=e[i],o=l.nestedProperty(t,a.replace(\"?\",r)),s=l.nestedProperty(t,a.replace(\"?\",n)),c=o.get();o.set(s.get()),s.set(c)}},l.raiseToTop=function(t){t.parentNode.appendChild(t)},l.cancelTransition=function(t){return t.transition().duration(0)},l.constrain=function(t,e,r){return e>r?Math.max(r,Math.min(e,t)):Math.max(e,Math.min(r,t))},l.bBoxIntersect=function(t,e,r){return r=r||0,t.left<=e.right+r&&e.left<=t.right+r&&t.top<=e.bottom+r&&e.top<=t.bottom+r},l.simpleMap=function(t,e,r,n){for(var i=t.length,a=new Array(i),o=0;o<i;o++)a[o]=e(t[o],r,n);return a},l.randstr=function t(e,r,n,i){if(n||(n=16),void 0===r&&(r=24),r<=0)return\"0\";var a,o,s=Math.log(Math.pow(2,r))/Math.log(n),c=\"\";for(a=2;s===1/0;a*=2)s=Math.log(Math.pow(2,r/a))/Math.log(n)*a;var u=s-Math.floor(s);for(a=0;a<Math.floor(s);a++)c=Math.floor(Math.random()*n).toString(n)+c;u&&(o=Math.pow(n,u),c=Math.floor(Math.random()*o).toString(n)+c);var h=parseInt(c,n);return e&&e[c]||h!==1/0&&h>=Math.pow(2,r)?i>10?(l.warn(\"randstr failed uniqueness\"),c):t(e,r,n,(i||0)+1):c},l.OptionControl=function(t,e){t||(t={}),e||(e=\"opt\");var r={optionList:[],_newoption:function(n){n[e]=t,r[n.name]=n,r.optionList.push(n)}};return r[\"_\"+e]=t,r},l.smooth=function(t,e){if((e=Math.round(e)||0)<2)return t;var r,n,i,a,o=t.length,s=2*o,l=2*e-1,c=new Array(l),u=new Array(o);for(r=0;r<l;r++)c[r]=(1-Math.cos(Math.PI*(r+1)/e))/(2*e);for(r=0;r<o;r++){for(a=0,n=0;n<l;n++)(i=r+n+1-e)<-o?i-=s*Math.round(i/s):i>=s&&(i-=s*Math.floor(i/s)),i<0?i=-1-i:i>=o&&(i=s-1-i),a+=t[i]*c[n];u[r]=a}return u},l.syncOrAsync=function(t,e,r){var n;function i(){return l.syncOrAsync(t,e,r)}for(;t.length;)if((n=(0,t.splice(0,1)[0])(e))&&n.then)return n.then(i).then(void 0,l.promiseError);return r&&r(e)},l.stripTrailingSlash=function(t){return\"/\"===t.substr(-1)?t.substr(0,t.length-1):t},l.noneOrAll=function(t,e,r){if(t){var n,i=!1,a=!0;for(n=0;n<r.length;n++)null!=t[r[n]]?i=!0:a=!1;if(i&&!a)for(n=0;n<r.length;n++)t[r[n]]=e[r[n]]}},l.mergeArray=function(t,e,r,n){var i=\"function\"==typeof n;if(l.isArrayOrTypedArray(t))for(var a=Math.min(t.length,e.length),o=0;o<a;o++){var s=t[o];e[o][r]=i?n(s):s}},l.mergeArrayCastPositive=function(t,e,r){return l.mergeArray(t,e,r,function(t){var e=+t;return isFinite(e)&&e>0?e:0})},l.fillArray=function(t,e,r,n){if(n=n||l.identity,l.isArrayOrTypedArray(t))for(var i=0;i<e.length;i++)e[i][r]=n(t[i])},l.castOption=function(t,e,r,n){n=n||l.identity;var i=l.nestedProperty(t,r).get();return l.isArrayOrTypedArray(i)?Array.isArray(e)&&l.isArrayOrTypedArray(i[e[0]])?n(i[e[0]][e[1]]):n(i[e]):i},l.extractOption=function(t,e,r,n){if(r in t)return t[r];var i=l.nestedProperty(e,n).get();return Array.isArray(i)?void 0:i},l.tagSelected=function(t,e,r){var n,i,a=e.selectedpoints,o=e._indexToPoints;o&&(n=T(o));for(var s=0;s<a.length;s++){var c=a[s];if(l.isIndex(c)){var u=n?n[c]:c,h=r?r[u]:u;void 0!==(i=h)&&i<t.length&&(t[h].selected=1)}}},l.selIndices2selPoints=function(t){var e=t.selectedpoints,r=t._indexToPoints;if(r){for(var n=T(r),i=[],a=0;a<e.length;a++){var o=e[a];if(l.isIndex(o)){var s=n[o];l.isIndex(s)&&i.push(s)}}return i}return e},l.getTargetArray=function(t,e){var r=e.target;if(\"string\"==typeof r&&r){var n=l.nestedProperty(t,r).get();return!!Array.isArray(n)&&n}return!!Array.isArray(r)&&r},l.minExtend=function(t,e){var r={};\"object\"!=typeof e&&(e={});var n,i,a,o=Object.keys(t);for(n=0;n<o.length;n++)a=t[i=o[n]],\"_\"!==i.charAt(0)&&\"function\"!=typeof a&&(\"module\"===i?r[i]=a:Array.isArray(a)?r[i]=\"colorscale\"===i?a.slice():a.slice(0,3):r[i]=a&&\"object\"==typeof a?l.minExtend(t[i],e[i]):a);for(o=Object.keys(e),n=0;n<o.length;n++)\"object\"==typeof(a=e[i=o[n]])&&i in r&&\"object\"==typeof r[i]||(r[i]=a);return r},l.titleCase=function(t){return t.charAt(0).toUpperCase()+t.substr(1)},l.containsAny=function(t,e){for(var r=0;r<e.length;r++)if(-1!==t.indexOf(e[r]))return!0;return!1},l.isIE=function(){return\"undefined\"!=typeof window.navigator.msSaveBlob};var A=/MSIE [1-9]\\./;l.isIE9orBelow=function(){return l.isIE()&&A.test(window.navigator.userAgent)};var M=/Version\\/[\\d\\.]+.*Safari/;l.isSafari=function(){return M.test(window.navigator.userAgent)},l.isD3Selection=function(t){return t&&\"function\"==typeof t.classed},l.ensureSingle=function(t,e,r,n){var i=t.select(e+(r?\".\"+r:\"\"));if(i.size())return i;var a=t.append(e);return r&&a.classed(r,!0),n&&a.call(n),a},l.ensureSingleById=function(t,e,r,n){var i=t.select(e+\"#\"+r);if(i.size())return i;var a=t.append(e).attr(\"id\",r);return n&&a.call(n),a},l.objectFromPath=function(t,e){for(var r,n=t.split(\".\"),i=r={},a=0;a<n.length;a++){var o=n[a],s=null,l=n[a].match(/(.*)\\[([0-9]+)\\]/);l?(o=l[1],s=l[2],r=r[o]=[],a===n.length-1?r[s]=e:r[s]={},r=r[s]):(a===n.length-1?r[o]=e:r[o]={},r=r[o])}return i};var S=/^([^\\[\\.]+)\\.(.+)?/,E=/^([^\\.]+)\\[([0-9]+)\\](\\.)?(.+)?/;l.expandObjectPaths=function(t){var e,r,n,i,a,o,s;if(\"object\"==typeof t&&!Array.isArray(t))for(r in t)t.hasOwnProperty(r)&&((e=r.match(S))?(i=t[r],n=e[1],delete t[r],t[n]=l.extendDeepNoArrays(t[n]||{},l.objectFromPath(r,l.expandObjectPaths(i))[n])):(e=r.match(E))?(i=t[r],n=e[1],a=parseInt(e[2]),delete t[r],t[n]=t[n]||[],\".\"===e[3]?(s=e[4],o=t[n][a]=t[n][a]||{},l.extendDeepNoArrays(o,l.objectFromPath(s,l.expandObjectPaths(i)))):t[n][a]=l.expandObjectPaths(i)):t[r]=l.expandObjectPaths(t[r]));return t},l.numSeparate=function(t,e,r){if(r||(r=!1),\"string\"!=typeof e||0===e.length)throw new Error(\"Separator string required for formatting!\");\"number\"==typeof t&&(t=String(t));var n=/(\\d+)(\\d{3})/,i=e.charAt(0),a=e.charAt(1),o=t.split(\".\"),s=o[0],l=o.length>1?i+o[1]:\"\";if(a&&(o.length>1||s.length>4||r))for(;n.test(s);)s=s.replace(n,\"$1\"+a+\"$2\");return s+l},l.TEMPLATE_STRING_REGEX=/%{([^\\s%{}:]*)(:[^}]*)?}/g;var C=/^\\w*$/;l.templateString=function(t,e){var r={};return t.replace(l.TEMPLATE_STRING_REGEX,function(t,n){return C.test(n)?e[n]||\"\":(r[n]=r[n]||l.nestedProperty(e,n).get,r[n]()||\"\")})};var L=/^:/,P=0;l.hovertemplateString=function(t,e,r){var i=arguments,a={};return t.replace(l.TEMPLATE_STRING_REGEX,function(t,o,s){var c,u,h;for(h=3;h<i.length;h++){if((c=i[h]).hasOwnProperty(o)){u=c[o];break}if(C.test(o)||(u=a[o]||l.nestedProperty(c,o).get())&&(a[o]=u),void 0!==u)break}(void 0===u&&(P<10&&(l.warn(\"Variable '\"+o+\"' in hovertemplate could not be found!\"),u=t),10===P&&l.warn(\"Too many hovertemplate warnings - additional warnings will be suppressed\"),P++),s)?u=(r?r.numberFormat:n.format)(s.replace(L,\"\"))(u):e.hasOwnProperty(o+\"Label\")&&(u=e[o+\"Label\"]);return u})};l.subplotSort=function(t,e){for(var r=Math.min(t.length,e.length)+1,n=0,i=0,a=0;a<r;a++){var o=t.charCodeAt(a)||0,s=e.charCodeAt(a)||0,l=o>=48&&o<=57,c=s>=48&&s<=57;if(l&&(n=10*n+o-48),c&&(i=10*i+s-48),!l||!c){if(n!==i)return n-i;if(o!==s)return o-s}}return i-n};var O=2e9;l.seedPseudoRandom=function(){O=2e9},l.pseudoRandom=function(){var t=O;return O=(69069*O+1)%4294967296,Math.abs(O-t)<429496729?l.pseudoRandom():O/4294967296},l.fillText=function(t,e,r){var n=Array.isArray(r)?function(t){r.push(t)}:function(t){r.text=t},i=l.extractOption(t,e,\"htx\",\"hovertext\");if(l.isValidTextValue(i))return n(i);var a=l.extractOption(t,e,\"tx\",\"text\");return l.isValidTextValue(a)?n(a):void 0},l.isValidTextValue=function(t){return t||0===t},l.formatPercent=function(t,e){e=e||0;for(var r=(Math.round(100*t*Math.pow(10,e))*Math.pow(.1,e)).toFixed(e)+\"%\",n=0;n<e;n++)-1!==r.indexOf(\".\")&&(r=(r=r.replace(\"0%\",\"%\")).replace(\".%\",\"%\"));return r},l.isHidden=function(t){var e=window.getComputedStyle(t).display;return!e||\"none\"===e}},{\"../constants/numerical\":695,\"./anchor_utils\":700,\"./angles\":701,\"./array\":702,\"./clean_number\":703,\"./clear_responsive\":705,\"./coerce\":706,\"./dates\":707,\"./dom\":708,\"./extend\":710,\"./filter_unique\":711,\"./filter_visible\":712,\"./geometry2d\":715,\"./identity\":718,\"./is_plain_object\":720,\"./keyed_container\":721,\"./localize\":722,\"./loggers\":723,\"./make_trace_groups\":724,\"./matrix\":725,\"./mod\":726,\"./nested_property\":727,\"./noop\":728,\"./notifier\":729,\"./push_unique\":733,\"./regex\":735,\"./relative_attr\":736,\"./relink_private\":737,\"./search\":738,\"./stats\":741,\"./throttle\":744,\"./to_log_range\":745,d3:163,\"fast-isnumeric\":225}],720:[function(t,e,r){\"use strict\";e.exports=function(t){return window&&window.process&&window.process.versions?\"[object Object]\"===Object.prototype.toString.call(t):\"[object Object]\"===Object.prototype.toString.call(t)&&Object.getPrototypeOf(t)===Object.prototype}},{}],721:[function(t,e,r){\"use strict\";var n=t(\"./nested_property\"),i=/^\\w*$/;e.exports=function(t,e,r,a){var o,s,l;r=r||\"name\",a=a||\"value\";var c={};e&&e.length?(l=n(t,e),s=l.get()):s=t,e=e||\"\";var u={};if(s)for(o=0;o<s.length;o++)u[s[o][r]]=o;var h=i.test(a),f={set:function(t,e){var i=null===e?4:0;if(!s){if(!l||4===i)return;s=[],l.set(s)}var o=u[t];if(void 0===o){if(4===i)return;i|=3,o=s.length,u[t]=o}else e!==(h?s[o][a]:n(s[o],a).get())&&(i|=2);var p=s[o]=s[o]||{};return p[r]=t,h?p[a]=e:n(p,a).set(e),null!==e&&(i&=-5),c[o]=c[o]|i,f},get:function(t){if(s){var e=u[t];return void 0===e?void 0:h?s[e][a]:n(s[e],a).get()}},rename:function(t,e){var n=u[t];return void 0===n?f:(c[n]=1|c[n],u[e]=n,delete u[t],s[n][r]=e,f)},remove:function(t){var e=u[t];if(void 0===e)return f;var i=s[e];if(Object.keys(i).length>2)return c[e]=2|c[e],f.set(t,null);if(h){for(o=e;o<s.length;o++)c[o]=3|c[o];for(o=e;o<s.length;o++)u[s[o][r]]--;s.splice(e,1),delete u[t]}else n(i,a).set(null),c[e]=6|c[e];return f},constructUpdate:function(){for(var t,i,o={},l=Object.keys(c),u=0;u<l.length;u++)i=l[u],t=e+\"[\"+i+\"]\",s[i]?(1&c[i]&&(o[t+\".\"+r]=s[i][r]),2&c[i]&&(o[t+\".\"+a]=h?4&c[i]?null:s[i][a]:4&c[i]?null:n(s[i],a).get())):o[t]=null;return o}};return f}},{\"./nested_property\":727}],722:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t,e){for(var r=t._context.locale,i=0;i<2;i++){for(var a=t._context.locales,o=0;o<2;o++){var s=(a[r]||{}).dictionary;if(s){var l=s[e];if(l)return l}a=n.localeRegistry}var c=r.split(\"-\")[0];if(c===r)break;r=c}return e}},{\"../registry\":847}],723:[function(t,e,r){\"use strict\";var n=t(\"../plot_api/plot_config\").dfltConfig,i=e.exports={};function a(t,e){if(t&&t.apply)try{return void t.apply(console,e)}catch(t){}for(var r=0;r<e.length;r++)try{t(e[r])}catch(t){console.log(e[r])}}i.log=function(){if(n.logging>1){for(var t=[\"LOG:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.trace||console.log,t)}},i.warn=function(){if(n.logging>0){for(var t=[\"WARN:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.trace||console.log,t)}},i.error=function(){if(n.logging>0){for(var t=[\"ERROR:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.error,t)}}},{\"../plot_api/plot_config\":755}],724:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e,r){var i=t.selectAll(\"g.\"+r.replace(/\\s/g,\".\")).data(e,function(t){return t[0].trace.uid});i.exit().remove(),i.enter().append(\"g\").attr(\"class\",r),i.order();var a=t.classed(\"rangeplot\")?\"nodeRangePlot3\":\"node3\";return i.each(function(t){t[0][a]=n.select(this)}),i}},{d3:163}],725:[function(t,e,r){\"use strict\";r.init2dArray=function(t,e){for(var r=new Array(t),n=0;n<t;n++)r[n]=new Array(e);return r},r.transposeRagged=function(t){var e,r,n=0,i=t.length;for(e=0;e<i;e++)n=Math.max(n,t[e].length);var a=new Array(n);for(e=0;e<n;e++)for(a[e]=new Array(i),r=0;r<i;r++)a[e][r]=t[r][e];return a},r.dot=function(t,e){if(!t.length||!e.length||t.length!==e.length)return null;var n,i,a=t.length;if(t[0].length)for(n=new Array(a),i=0;i<a;i++)n[i]=r.dot(t[i],e);else if(e[0].length){var o=r.transposeRagged(e);for(n=new Array(o.length),i=0;i<o.length;i++)n[i]=r.dot(t,o[i])}else for(n=0,i=0;i<a;i++)n+=t[i]*e[i];return n},r.translationMatrix=function(t,e){return[[1,0,t],[0,1,e],[0,0,1]]},r.rotationMatrix=function(t){var e=t*Math.PI/180;return[[Math.cos(e),-Math.sin(e),0],[Math.sin(e),Math.cos(e),0],[0,0,1]]},r.rotationXYMatrix=function(t,e,n){return r.dot(r.dot(r.translationMatrix(e,n),r.rotationMatrix(t)),r.translationMatrix(-e,-n))},r.apply2DTransform=function(t){return function(){var e=arguments;3===e.length&&(e=e[0]);var n=1===arguments.length?e[0]:[e[0],e[1]];return r.dot(t,[n[0],n[1],1]).slice(0,2)}},r.apply2DTransform2=function(t){var e=r.apply2DTransform(t);return function(t){return e(t.slice(0,2)).concat(e(t.slice(2,4)))}}},{}],726:[function(t,e,r){\"use strict\";e.exports={mod:function(t,e){var r=t%e;return r<0?r+e:r},modHalf:function(t,e){return Math.abs(t)>e/2?t-Math.round(t/e)*e:t}}},{}],727:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;e.exports=function(t,e){if(n(e))e=String(e);else if(\"string\"!=typeof e||\"[-1]\"===e.substr(e.length-4))throw\"bad property string\";for(var r,a,o,l=0,c=e.split(\".\");l<c.length;){if(r=String(c[l]).match(/^([^\\[\\]]*)((\\[\\-?[0-9]*\\])+)$/)){if(r[1])c[l]=r[1];else{if(0!==l)throw\"bad property string\";c.splice(0,1)}for(a=r[2].substr(1,r[2].length-2).split(\"][\"),o=0;o<a.length;o++)l++,c.splice(l,0,Number(a[o]))}l++}return\"object\"!=typeof t?function(t,e,r){return{set:function(){throw\"bad container\"},get:function(){},astr:e,parts:r,obj:t}}(t,e,c):{set:s(t,c,e),get:function t(e,r){return function(){var n,a,o,s,l,c=e;for(s=0;s<r.length-1;s++){if(-1===(n=r[s])){for(a=!0,o=[],l=0;l<c.length;l++)o[l]=t(c[l],r.slice(s+1))(),o[l]!==o[0]&&(a=!1);return a?o[0]:o}if(\"number\"==typeof n&&!i(c))return;if(\"object\"!=typeof(c=c[n])||null===c)return}if(\"object\"==typeof c&&null!==c&&null!==(o=c[r[s]]))return o}}(t,c),astr:e,parts:c,obj:t}};var a=/(^|\\.)args\\[/;function o(t,e){return void 0===t||null===t&&!e.match(a)}function s(t,e,r){return function(n){var a,s,h=t,f=\"\",p=[[t,f]],d=o(n,r);for(s=0;s<e.length-1;s++){if(\"number\"==typeof(a=e[s])&&!i(h))throw\"array index but container is not an array\";if(-1===a){if(d=!c(h,e.slice(s+1),n,r))break;return}if(!u(h,a,e[s+1],d))break;if(\"object\"!=typeof(h=h[a])||null===h)throw\"container is not an object\";f=l(f,a),p.push([h,f])}if(d){if(s===e.length-1&&(delete h[e[s]],Array.isArray(h)&&+e[s]==h.length-1))for(;h.length&&void 0===h[h.length-1];)h.pop()}else h[e[s]]=n}}function l(t,e){var r=e;return n(e)?r=\"[\"+e+\"]\":t&&(r=\".\"+e),t+r}function c(t,e,r,n){var a,l=i(r),c=!0,h=r,f=n.replace(\"-1\",0),p=!l&&o(r,f),d=e[0];for(a=0;a<t.length;a++)f=n.replace(\"-1\",a),l&&(p=o(h=r[a%r.length],f)),p&&(c=!1),u(t,a,d,p)&&s(t[a],e,n.replace(\"-1\",a))(h);return c}function u(t,e,r,n){if(void 0===t[e]){if(n)return!1;t[e]=\"number\"==typeof r?[]:{}}return!0}},{\"./array\":702,\"fast-isnumeric\":225}],728:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],729:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=[];e.exports=function(t,e){if(-1===a.indexOf(t)){a.push(t);var r=1e3;i(e)?r=e:\"long\"===e&&(r=3e3);var o=n.select(\"body\").selectAll(\".plotly-notifier\").data([0]);o.enter().append(\"div\").classed(\"plotly-notifier\",!0),o.selectAll(\".notifier-note\").data(a).enter().append(\"div\").classed(\"notifier-note\",!0).style(\"opacity\",0).each(function(t){var e=n.select(this);e.append(\"button\").classed(\"notifier-close\",!0).html(\"&times;\").on(\"click\",function(){e.transition().call(s)});for(var i=e.append(\"p\"),a=t.split(/<br\\s*\\/?>/g),o=0;o<a.length;o++)o&&i.append(\"br\"),i.append(\"span\").text(a[o]);e.transition().duration(700).style(\"opacity\",1).transition().delay(r).call(s)})}function s(t){t.duration(700).style(\"opacity\",0).each(\"end\",function(t){var e=a.indexOf(t);-1!==e&&a.splice(e,1),n.select(this).remove()})}}},{d3:163,\"fast-isnumeric\":225}],730:[function(t,e,r){\"use strict\";var n=t(\"./setcursor\"),i=\"data-savedcursor\";e.exports=function(t,e){var r=t.attr(i);if(e){if(!r){for(var a=(t.attr(\"class\")||\"\").split(\" \"),o=0;o<a.length;o++){var s=a[o];0===s.indexOf(\"cursor-\")&&t.attr(i,s.substr(7)).classed(s,!1)}t.attr(i)||t.attr(i,\"!!\")}n(t,e)}else r&&(t.attr(i,null),\"!!\"===r?n(t):n(t,r))}},{\"./setcursor\":739}],731:[function(t,e,r){\"use strict\";var n=t(\"./matrix\").dot,i=t(\"../constants/numerical\").BADNUM,a=e.exports={};a.tester=function(t){var e,r=t.slice(),n=r[0][0],a=n,o=r[0][1],s=o;for(r.push(r[0]),e=1;e<r.length;e++)n=Math.min(n,r[e][0]),a=Math.max(a,r[e][0]),o=Math.min(o,r[e][1]),s=Math.max(s,r[e][1]);var l,c=!1;5===r.length&&(r[0][0]===r[1][0]?r[2][0]===r[3][0]&&r[0][1]===r[3][1]&&r[1][1]===r[2][1]&&(c=!0,l=function(t){return t[0]===r[0][0]}):r[0][1]===r[1][1]&&r[2][1]===r[3][1]&&r[0][0]===r[3][0]&&r[1][0]===r[2][0]&&(c=!0,l=function(t){return t[1]===r[0][1]}));var u=!0,h=r[0];for(e=1;e<r.length;e++)if(h[0]!==r[e][0]||h[1]!==r[e][1]){u=!1;break}return{xmin:n,xmax:a,ymin:o,ymax:s,pts:r,contains:c?function(t,e){var r=t[0],c=t[1];return!(r===i||r<n||r>a||c===i||c<o||c>s||e&&l(t))}:function(t,e){var l=t[0],c=t[1];if(l===i||l<n||l>a||c===i||c<o||c>s)return!1;var u,h,f,p,d,g=r.length,v=r[0][0],m=r[0][1],y=0;for(u=1;u<g;u++)if(h=v,f=m,v=r[u][0],m=r[u][1],!(l<(p=Math.min(h,v))||l>Math.max(h,v)||c>Math.max(f,m)))if(c<Math.min(f,m))l!==p&&y++;else{if(c===(d=v===h?c:f+(l-h)*(m-f)/(v-h)))return 1!==u||!e;c<=d&&l!==p&&y++}return y%2==1},isRect:c,degenerate:u}},a.isSegmentBent=function(t,e,r,i){var a,o,s,l=t[e],c=[t[r][0]-l[0],t[r][1]-l[1]],u=n(c,c),h=Math.sqrt(u),f=[-c[1]/h,c[0]/h];for(a=e+1;a<r;a++)if(o=[t[a][0]-l[0],t[a][1]-l[1]],(s=n(o,c))<0||s>u||Math.abs(n(o,f))>i)return!0;return!1},a.filter=function(t,e){var r=[t[0]],n=0,i=0;function o(o){t.push(o);var s=r.length,l=n;r.splice(i+1);for(var c=l+1;c<t.length;c++)(c===t.length-1||a.isSegmentBent(t,l,c+1,e))&&(r.push(t[c]),r.length<s-2&&(n=c,i=r.length-1),l=c)}t.length>1&&o(t.pop());return{addPt:o,raw:t,filtered:r}}},{\"../constants/numerical\":695,\"./matrix\":725}],732:[function(t,e,r){(function(r){\"use strict\";var n=t(\"./show_no_webgl_msg\"),i=t(\"regl\");e.exports=function(t,e){var a=t._fullLayout,o=!0;return a._glcanvas.each(function(n){if(!n.regl&&(!n.pick||a._has(\"parcoords\"))){try{n.regl=i({canvas:this,attributes:{antialias:!n.pick,preserveDrawingBuffer:!0},pixelRatio:t._context.plotGlPixelRatio||r.devicePixelRatio,extensions:e||[]})}catch(t){o=!1}o&&this.addEventListener(\"webglcontextlost\",function(e){t&&t.emit&&t.emit(\"plotly_webglcontextlost\",{event:e,layer:n.key})},!1)}}),o||n({container:a._glcontainer.node()}),o}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./show_no_webgl_msg\":740,regl:502}],733:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(e instanceof RegExp){for(var r=e.toString(),n=0;n<t.length;n++)if(t[n]instanceof RegExp&&t[n].toString()===r)return t;t.push(e)}else!e&&0!==e||-1!==t.indexOf(e)||t.push(e);return t}},{}],734:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_config\").dfltConfig;var a={add:function(t,e,r,n,a){var o,s;t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},s=t.undoQueue.index,t.autoplay?t.undoQueue.inSequence||(t.autoplay=!1):(!t.undoQueue.sequence||t.undoQueue.beginSequence?(o={undo:{calls:[],args:[]},redo:{calls:[],args:[]}},t.undoQueue.queue.splice(s,t.undoQueue.queue.length-s,o),t.undoQueue.index+=1):o=t.undoQueue.queue[s-1],t.undoQueue.beginSequence=!1,o&&(o.undo.calls.unshift(e),o.undo.args.unshift(r),o.redo.calls.push(n),o.redo.args.push(a)),t.undoQueue.queue.length>i.queueLength&&(t.undoQueue.queue.shift(),t.undoQueue.index--))},startSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!0,t.undoQueue.beginSequence=!0},stopSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!1,t.undoQueue.beginSequence=!1},undo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.undo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index<=0)){for(t.undoQueue.index--,e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.undo.calls.length;r++)a.plotDo(t,e.undo.calls[r],e.undo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1}},redo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.redo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index>=t.undoQueue.queue.length)){for(e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.redo.calls.length;r++)a.plotDo(t,e.redo.calls[r],e.redo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1,t.undoQueue.index++}}};a.plotDo=function(t,e,r){t.autoplay=!0,r=function(t,e){for(var r,i=[],a=0;a<e.length;a++)r=e[a],i[a]=r===t?r:\"object\"==typeof r?Array.isArray(r)?n.extendDeep([],r):n.extendDeepAll({},r):r;return i}(t,r),e.apply(null,r)},e.exports=a},{\"../lib\":719,\"../plot_api/plot_config\":755}],735:[function(t,e,r){\"use strict\";r.counter=function(t,e,r,n){var i=(e||\"\")+(r?\"\":\"$\"),a=!1===n?\"\":\"^\";return\"xy\"===t?new RegExp(a+\"x([2-9]|[1-9][0-9]+)?y([2-9]|[1-9][0-9]+)?\"+i):new RegExp(a+t+\"([2-9]|[1-9][0-9]+)?\"+i)}},{}],736:[function(t,e,r){\"use strict\";var n=/^(.*)(\\.[^\\.\\[\\]]+|\\[\\d\\])$/,i=/^[^\\.\\[\\]]+$/;e.exports=function(t,e){for(;e;){var r=t.match(n);if(r)t=r[1];else{if(!t.match(i))throw new Error(\"bad relativeAttr call:\"+[t,e]);t=\"\"}if(\"^\"!==e.charAt(0))break;e=e.slice(1)}return t&&\"[\"!==e.charAt(0)?t+\".\"+e:t+e}},{}],737:[function(t,e,r){\"use strict\";var n=t(\"./array\").isArrayOrTypedArray,i=t(\"./is_plain_object\");e.exports=function t(e,r){for(var a in r){var o=r[a],s=e[a];if(s!==o)if(\"_\"===a.charAt(0)||\"function\"==typeof o){if(a in e)continue;e[a]=o}else if(n(o)&&n(s)&&i(o[0])){if(\"customdata\"===a||\"ids\"===a)continue;for(var l=Math.min(o.length,s.length),c=0;c<l;c++)s[c]!==o[c]&&i(o[c])&&i(s[c])&&t(s[c],o[c])}else i(o)&&i(s)&&(t(s,o),Object.keys(s).length||delete e[a])}}},{\"./array\":702,\"./is_plain_object\":720}],738:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./loggers\"),a=t(\"./identity\");function o(t,e){return t<e}function s(t,e){return t<=e}function l(t,e){return t>e}function c(t,e){return t>=e}r.findBin=function(t,e,r){if(n(e.start))return r?Math.ceil((t-e.start)/e.size-1e-9)-1:Math.floor((t-e.start)/e.size+1e-9);var a,u,h=0,f=e.length,p=0,d=f>1?(e[f-1]-e[0])/(f-1):1;for(u=d>=0?r?o:s:r?c:l,t+=1e-9*d*(r?-1:1)*(d>=0?1:-1);h<f&&p++<100;)u(e[a=Math.floor((h+f)/2)],t)?h=a+1:f=a;return p>90&&i.log(\"Long binary search...\"),h-1},r.sorterAsc=function(t,e){return t-e},r.sorterDes=function(t,e){return e-t},r.distinctVals=function(t){var e=t.slice();e.sort(r.sorterAsc);for(var n=e.length-1,i=e[n]-e[0]||1,a=i/(n||1)/1e4,o=[e[0]],s=0;s<n;s++)e[s+1]>e[s]+a&&(i=Math.min(i,e[s+1]-e[s]),o.push(e[s+1]));return{vals:o,minDiff:i}},r.roundUp=function(t,e,r){for(var n,i=0,a=e.length-1,o=0,s=r?0:1,l=r?1:0,c=r?Math.ceil:Math.floor;i<a&&o++<100;)e[n=c((i+a)/2)]<=t?i=n+s:a=n-l;return e[i]},r.sort=function(t,e){for(var r=0,n=0,i=1;i<t.length;i++){var a=e(t[i],t[i-1]);if(a<0?r=1:a>0&&(n=1),r&&n)return t.sort(e)}return n?t:t.reverse()},r.findIndexOfMin=function(t,e){e=e||a;for(var r,n=1/0,i=0;i<t.length;i++){var o=e(t[i]);o<n&&(n=o,r=i)}return r}},{\"./identity\":718,\"./loggers\":723,\"fast-isnumeric\":225}],739:[function(t,e,r){\"use strict\";e.exports=function(t,e){(t.attr(\"class\")||\"\").split(\" \").forEach(function(e){0===e.indexOf(\"cursor-\")&&t.classed(e,!1)}),e&&t.classed(\"cursor-\"+e,!0)}},{}],740:[function(t,e,r){\"use strict\";var n=t(\"../components/color\"),i=function(){};e.exports=function(t){for(var e in t)\"function\"==typeof t[e]&&(t[e]=i);t.destroy=function(){t.container.parentNode.removeChild(t.container)};var r=document.createElement(\"div\");r.className=\"no-webgl\",r.style.cursor=\"pointer\",r.style.fontSize=\"24px\",r.style.color=n.defaults[0],r.style.position=\"absolute\",r.style.left=r.style.top=\"0px\",r.style.width=r.style.height=\"100%\",r.style[\"background-color\"]=n.lightLine,r.style[\"z-index\"]=30;var a=document.createElement(\"p\");return a.textContent=\"WebGL is not supported by your browser - visit https://get.webgl.org for more info\",a.style.position=\"relative\",a.style.top=\"50%\",a.style.left=\"50%\",a.style.height=\"30%\",a.style.width=\"50%\",a.style.margin=\"-15% 0 0 -25%\",r.appendChild(a),t.container.appendChild(r),t.container.style.background=\"#FFFFFF\",t.container.onclick=function(){window.open(\"https://get.webgl.org\")},!1}},{\"../components/color\":593}],741:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;r.aggNums=function(t,e,a,o){var s,l;if((!o||o>a.length)&&(o=a.length),n(e)||(e=!1),i(a[0])){for(l=new Array(o),s=0;s<o;s++)l[s]=r.aggNums(t,e,a[s]);a=l}for(s=0;s<o;s++)n(e)?n(a[s])&&(e=t(+e,+a[s])):e=a[s];return e},r.len=function(t){return r.aggNums(function(t){return t+1},0,t)},r.mean=function(t,e){return e||(e=r.len(t)),r.aggNums(function(t,e){return t+e},0,t)/e},r.midRange=function(t){if(void 0!==t&&0!==t.length)return(r.aggNums(Math.max,null,t)+r.aggNums(Math.min,null,t))/2},r.variance=function(t,e,i){return e||(e=r.len(t)),n(i)||(i=r.mean(t,e)),r.aggNums(function(t,e){return t+Math.pow(e-i,2)},0,t)/e},r.stdev=function(t,e,n){return Math.sqrt(r.variance(t,e,n))},r.median=function(t){var e=t.slice().sort();return r.interp(e,.5)},r.interp=function(t,e){if(!n(e))throw\"n should be a finite number\";if((e=e*t.length-.5)<0)return t[0];if(e>t.length-1)return t[t.length-1];var r=e%1;return r*t[Math.ceil(e)]+(1-r)*t[Math.floor(e)]}},{\"./array\":702,\"fast-isnumeric\":225}],742:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\");e.exports=function(t){return t?n(t):[0,0,0,1]}},{\"color-normalize\":120}],743:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=t(\"../constants/xmlns_namespaces\"),o=t(\"../constants/alignment\").LINE_SPACING;function s(t,e){return t.node().getBoundingClientRect()[e]}var l=/([^$]*)([$]+[^$]*[$]+)([^$]*)/;r.convertToTspans=function(t,e,M){var S=t.text(),C=!t.attr(\"data-notex\")&&\"undefined\"!=typeof MathJax&&S.match(l),L=n.select(t.node().parentNode);if(!L.empty()){var P=t.attr(\"class\")?t.attr(\"class\").split(\" \")[0]:\"text\";return P+=\"-math\",L.selectAll(\"svg.\"+P).remove(),L.selectAll(\"g.\"+P+\"-group\").remove(),t.style(\"display\",null).attr({\"data-unformatted\":S,\"data-math\":\"N\"}),C?(e&&e._promises||[]).push(new Promise(function(e){t.style(\"display\",\"none\");var r=parseInt(t.node().style.fontSize,10),a={fontSize:r};!function(t,e,r){var a,o,s,l;MathJax.Hub.Queue(function(){return o=i.extendDeepAll({},MathJax.Hub.config),s=MathJax.Hub.processSectionDelay,void 0!==MathJax.Hub.processSectionDelay&&(MathJax.Hub.processSectionDelay=0),MathJax.Hub.Config({messageStyle:\"none\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]},displayAlign:\"left\"})},function(){if(\"SVG\"!==(a=MathJax.Hub.config.menuSettings.renderer))return MathJax.Hub.setRenderer(\"SVG\")},function(){var r=\"math-output-\"+i.randstr({},64);return l=n.select(\"body\").append(\"div\").attr({id:r}).style({visibility:\"hidden\",position:\"absolute\"}).style({\"font-size\":e.fontSize+\"px\"}).text(t.replace(c,\"\\\\lt \").replace(u,\"\\\\gt \")),MathJax.Hub.Typeset(l.node())},function(){var e=n.select(\"body\").select(\"#MathJax_SVG_glyphs\");if(l.select(\".MathJax_SVG\").empty()||!l.select(\"svg\").node())i.log(\"There was an error in the tex syntax.\",t),r();else{var o=l.select(\"svg\").node().getBoundingClientRect();r(l.select(\".MathJax_SVG\"),e,o)}if(l.remove(),\"SVG\"!==a)return MathJax.Hub.setRenderer(a)},function(){return void 0!==s&&(MathJax.Hub.processSectionDelay=s),MathJax.Hub.Config(o)})}(C[2],a,function(n,i,a){L.selectAll(\"svg.\"+P).remove(),L.selectAll(\"g.\"+P+\"-group\").remove();var o=n&&n.select(\"svg\");if(!o||!o.node())return O(),void e();var l=L.append(\"g\").classed(P+\"-group\",!0).attr({\"pointer-events\":\"none\",\"data-unformatted\":S,\"data-math\":\"Y\"});l.node().appendChild(o.node()),i&&i.node()&&o.node().insertBefore(i.node().cloneNode(!0),o.node().firstChild),o.attr({class:P,height:a.height,preserveAspectRatio:\"xMinYMin meet\"}).style({overflow:\"visible\",\"pointer-events\":\"none\"});var c=t.node().style.fill||\"black\",u=o.select(\"g\");u.attr({fill:c,stroke:c});var h=s(u,\"width\"),f=s(u,\"height\"),p=+t.attr(\"x\")-h*{start:0,middle:.5,end:1}[t.attr(\"text-anchor\")||\"start\"],d=-(r||s(t,\"height\"))/4;\"y\"===P[0]?(l.attr({transform:\"rotate(\"+[-90,+t.attr(\"x\"),+t.attr(\"y\")]+\") translate(\"+[-h/2,d-f/2]+\")\"}),o.attr({x:+t.attr(\"x\"),y:+t.attr(\"y\")})):\"l\"===P[0]?o.attr({x:t.attr(\"x\"),y:d-f/2}):\"a\"===P[0]&&0!==P.indexOf(\"atitle\")?o.attr({x:0,y:d}):o.attr({x:p,y:+t.attr(\"y\")+d-f/2}),M&&M.call(t,l),e(l)})})):O(),t}function O(){L.empty()||(P=t.attr(\"class\")+\"-math\",L.select(\"svg.\"+P).remove()),t.text(\"\").style(\"white-space\",\"pre\"),function(t,e){e=e.replace(v,\" \");var r,s=!1,l=[],c=-1;function u(){c++;var e=document.createElementNS(a.svg,\"tspan\");n.select(e).attr({class:\"line\",dy:c*o+\"em\"}),t.appendChild(e),r=e;var i=l;if(l=[{node:e}],i.length>1)for(var s=1;s<i.length;s++)M(i[s])}function M(t){var e,i=t.type,o={};if(\"a\"===i){e=\"a\";var s=t.target,c=t.href,u=t.popup;c&&(o={\"xlink:xlink:show\":\"_blank\"===s||\"_\"!==s.charAt(0)?\"new\":\"replace\",target:s,\"xlink:xlink:href\":c},u&&(o.onclick='window.open(this.href.baseVal,this.target.baseVal,\"'+u+'\");return false;'))}else e=\"tspan\";t.style&&(o.style=t.style);var h=document.createElementNS(a.svg,e);if(\"sup\"===i||\"sub\"===i){S(r,d),r.appendChild(h);var g=document.createElementNS(a.svg,\"tspan\");S(g,d),n.select(g).attr(\"dy\",p[i]),o.dy=f[i],r.appendChild(h),r.appendChild(g)}else r.appendChild(h);n.select(h).attr(o),r=t.node=h,l.push(t)}function S(t,e){t.appendChild(document.createTextNode(e))}function C(t){if(1!==l.length){var n=l.pop();t!==n.type&&i.log(\"Start tag <\"+n.type+\"> doesnt match end tag <\"+t+\">. Pretending it did match.\",e),r=l[l.length-1].node}else i.log(\"Ignoring unexpected end tag </\"+t+\">.\",e)}x.test(e)?u():(r=t,l=[{node:t}]);for(var L=e.split(m),P=0;P<L.length;P++){var O=L[P],z=O.match(y),I=z&&z[2].toLowerCase(),D=h[I];if(\"br\"===I)u();else if(void 0===D)S(r,E(O));else if(z[1])C(I);else{var R=z[4],F={type:I},B=T(R,b);if(B?(B=B.replace(A,\"$1 fill:\"),D&&(B+=\";\"+D)):D&&(B=D),B&&(F.style=B),\"a\"===I){s=!0;var N=T(R,_);if(N){var j=document.createElement(\"a\");j.href=N,-1!==g.indexOf(j.protocol)&&(F.href=encodeURI(decodeURI(N)),F.target=T(R,w)||\"_blank\",F.popup=T(R,k))}}M(F)}}return s}(t.node(),S)&&t.style(\"pointer-events\",\"all\"),r.positionText(t),M&&M.call(t)}};var c=/(<|&lt;|&#60;)/g,u=/(>|&gt;|&#62;)/g;var h={sup:\"font-size:70%\",sub:\"font-size:70%\",b:\"font-weight:bold\",i:\"font-style:italic\",a:\"cursor:pointer\",span:\"\",em:\"font-style:italic;font-weight:bold\"},f={sub:\"0.3em\",sup:\"-0.6em\"},p={sub:\"-0.21em\",sup:\"0.42em\"},d=\"\\u200b\",g=[\"http:\",\"https:\",\"mailto:\",\"\",void 0,\":\"],v=/(\\r\\n?|\\n)/g,m=/(<[^<>]*>)/,y=/<(\\/?)([^ >]*)(\\s+(.*))?>/i,x=/<br(\\s+.*)?>/i,b=/(^|[\\s\"'])style\\s*=\\s*(\"([^\"]*);?\"|'([^']*);?')/i,_=/(^|[\\s\"'])href\\s*=\\s*(\"([^\"]*)\"|'([^']*)')/i,w=/(^|[\\s\"'])target\\s*=\\s*(\"([^\"\\s]*)\"|'([^'\\s]*)')/i,k=/(^|[\\s\"'])popup\\s*=\\s*(\"([\\w=,]*)\"|'([\\w=,]*)')/i;function T(t,e){if(!t)return null;var r=t.match(e),n=r&&(r[3]||r[4]);return n&&E(n)}var A=/(^|;)\\s*color:/;r.plainText=function(t,e){for(var r=void 0!==(e=e||{}).len&&-1!==e.len?e.len:1/0,n=void 0!==e.allowedTags?e.allowedTags:[\"br\"],i=\"...\".length,a=t.split(m),o=[],s=\"\",l=0,c=0;c<a.length;c++){var u=a[c],h=u.match(y),f=h&&h[2].toLowerCase();if(f)-1!==n.indexOf(f)&&(o.push(u),s=f);else{var p=u.length;if(l+p<r)o.push(u),l+=p;else if(l<r){var d=r-l;s&&(\"br\"!==s||d<=i||p<=i)&&o.pop(),r>i?o.push(u.substr(0,d-i)+\"...\"):o.push(u.substr(0,d));break}s=\"\"}}return o.join(\"\")};var M={mu:\"\\u03bc\",amp:\"&\",lt:\"<\",gt:\">\",nbsp:\"\\xa0\",times:\"\\xd7\",plusmn:\"\\xb1\",deg:\"\\xb0\"},S=/&(#\\d+|#x[\\da-fA-F]+|[a-z]+);/g;function E(t){return t.replace(S,function(t,e){return(\"#\"===e.charAt(0)?function(t){if(t>1114111)return;var e=String.fromCodePoint;if(e)return e(t);var r=String.fromCharCode;return t<=65535?r(t):r(55232+(t>>10),t%1024+56320)}(\"x\"===e.charAt(1)?parseInt(e.substr(2),16):parseInt(e.substr(1),10)):M[e])||t})}function C(t,e,r){var n,i,a,o=r.horizontalAlign,s=r.verticalAlign||\"top\",l=t.node().getBoundingClientRect(),c=e.node().getBoundingClientRect();return i=\"bottom\"===s?function(){return l.bottom-n.height}:\"middle\"===s?function(){return l.top+(l.height-n.height)/2}:function(){return l.top},a=\"right\"===o?function(){return l.right-n.width}:\"center\"===o?function(){return l.left+(l.width-n.width)/2}:function(){return l.left},function(){return n=this.node().getBoundingClientRect(),this.style({top:i()-c.top+\"px\",left:a()-c.left+\"px\",\"z-index\":1e3}),this}}r.convertEntities=E,r.lineCount=function(t){return t.selectAll(\"tspan.line\").size()||1},r.positionText=function(t,e,r){return t.each(function(){var t=n.select(this);function i(e,r){return void 0===r?null===(r=t.attr(e))&&(t.attr(e,0),r=0):t.attr(e,r),r}var a=i(\"x\",e),o=i(\"y\",r);\"text\"===this.nodeName&&t.selectAll(\"tspan.line\").attr({x:a,y:o})})},r.makeEditable=function(t,e){var r=e.gd,i=e.delegate,a=n.dispatch(\"edit\",\"input\",\"cancel\"),o=i||t;if(t.style({\"pointer-events\":i?\"none\":\"all\"}),1!==t.size())throw new Error(\"boo\");function s(){!function(){var i=n.select(r).select(\".svg-container\"),o=i.append(\"div\"),s=t.node().style,c=parseFloat(s.fontSize||12),u=e.text;void 0===u&&(u=t.attr(\"data-unformatted\"));o.classed(\"plugin-editable editable\",!0).style({position:\"absolute\",\"font-family\":s.fontFamily||\"Arial\",\"font-size\":c,color:e.fill||s.fill||\"black\",opacity:1,\"background-color\":e.background||\"transparent\",outline:\"#ffffff33 1px solid\",margin:[-c/8+1,0,0,-1].join(\"px \")+\"px\",padding:\"0\",\"box-sizing\":\"border-box\"}).attr({contenteditable:!0}).text(u).call(C(t,i,e)).on(\"blur\",function(){r._editing=!1,t.text(this.textContent).style({opacity:1});var e,i=n.select(this).attr(\"class\");(e=i?\".\"+i.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(e).style({opacity:0});var o=this.textContent;n.select(this).transition().duration(0).remove(),n.select(document).on(\"mouseup\",null),a.edit.call(t,o)}).on(\"focus\",function(){var t=this;r._editing=!0,n.select(document).on(\"mouseup\",function(){if(n.event.target===t)return!1;document.activeElement===o.node()&&o.node().blur()})}).on(\"keyup\",function(){27===n.event.which?(r._editing=!1,t.style({opacity:1}),n.select(this).style({opacity:0}).on(\"blur\",function(){return!1}).transition().remove(),a.cancel.call(t,this.textContent)):(a.input.call(t,this.textContent),n.select(this).call(C(t,i,e)))}).on(\"keydown\",function(){13===n.event.which&&this.blur()}).call(l)}(),t.style({opacity:0});var i,s=o.attr(\"class\");(i=s?\".\"+s.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(i).style({opacity:0})}function l(t){var e=t.node(),r=document.createRange();r.selectNodeContents(e);var n=window.getSelection();n.removeAllRanges(),n.addRange(r),e.focus()}return e.immediate?s():o.on(\"click\",s),n.rebind(t,a,\"on\")}},{\"../constants/alignment\":688,\"../constants/xmlns_namespaces\":696,\"../lib\":719,d3:163}],744:[function(t,e,r){\"use strict\";var n={};function i(t){t&&null!==t.timer&&(clearTimeout(t.timer),t.timer=null)}r.throttle=function(t,e,r){var a=n[t],o=Date.now();if(!a){for(var s in n)n[s].ts<o-6e4&&delete n[s];a=n[t]={ts:0,timer:null}}function l(){r(),a.ts=Date.now(),a.onDone&&(a.onDone(),a.onDone=null)}i(a),o>a.ts+e?l():a.timer=setTimeout(function(){l(),a.timer=null},e)},r.done=function(t){var e=n[t];return e&&e.timer?new Promise(function(t){var r=e.onDone;e.onDone=function(){r&&r(),t(),e.onDone=null}}):Promise.resolve()},r.clear=function(t){if(t)i(n[t]),delete n[t];else for(var e in n)r.clear(e)}},{}],745:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t,e){if(t>0)return Math.log(t)/Math.LN10;var r=Math.log(Math.min(e[0],e[1]))/Math.LN10;return n(r)||(r=Math.log(Math.max(e[0],e[1]))/Math.LN10-6),r}},{\"fast-isnumeric\":225}],746:[function(t,e,r){\"use strict\";var n=e.exports={},i=t(\"../plots/geo/constants\").locationmodeToLayer,a=t(\"topojson-client\").feature;n.getTopojsonName=function(t){return[t.scope.replace(/ /g,\"-\"),\"_\",t.resolution.toString(),\"m\"].join(\"\")},n.getTopojsonPath=function(t,e){return t+e+\".json\"},n.getTopojsonFeatures=function(t,e){var r=i[t.locationmode],n=e.objects[r];return a(e,n).features}},{\"../plots/geo/constants\":795,\"topojson-client\":540}],747:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en-US\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colorscale title\"},format:{date:\"%m/%d/%Y\"}}},{}],748:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colourscale title\"},format:{days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],periods:[\"AM\",\"PM\"],dateTime:\"%a %b %e %X %Y\",date:\"%d/%m/%Y\",time:\"%H:%M:%S\",decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],year:\"%Y\",month:\"%b %Y\",dayMonth:\"%b %-d\",dayMonthYear:\"%b %-d, %Y\"}}},{}],749:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t){for(var e,r,i=n.layoutArrayContainers,a=n.layoutArrayRegexes,o=t.split(\"[\")[0],s=0;s<a.length;s++)if((r=t.match(a[s]))&&0===r.index){e=r[0];break}if(e||(e=i[i.indexOf(o)]),!e)return!1;var l=t.substr(e.length);return l?!!(r=l.match(/^\\[(0|[1-9][0-9]*)\\](\\.(.+))?$/))&&{array:e,index:Number(r[1]),property:r[3]||\"\"}:{array:e,index:\"\",property:\"\"}}},{\"../registry\":847}],750:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.extendFlat,a=n.isPlainObject,o={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"clearAxisTypes\",\"plot\",\"style\",\"markerSize\",\"colorbars\"]},s={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"plot\",\"legend\",\"ticks\",\"axrange\",\"layoutstyle\",\"modebar\",\"camera\",\"arraydraw\",\"colorbars\"]},l=o.flags.slice().concat([\"fullReplot\"]),c=s.flags.slice().concat(\"layoutReplot\");function u(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=!1;return e}function h(t,e,r){var n=i({},t);for(var o in n){var s=n[o];a(s)&&(n[o]=f(s,e,r,o))}return\"from-root\"===r&&(n.editType=e),n}function f(t,e,r,n){if(t.valType){var a=i({},t);if(a.editType=e,Array.isArray(t.items)){a.items=new Array(t.items.length);for(var o=0;o<t.items.length;o++)a.items[o]=f(t.items[o],e,\"from-root\")}return a}return h(t,e,\"_\"===n.charAt(0)?\"nested\":\"from-root\")}e.exports={traces:o,layout:s,traceFlags:function(){return u(l)},layoutFlags:function(){return u(c)},update:function(t,e){var r=e.editType;if(r&&\"none\"!==r)for(var n=r.split(\"+\"),i=0;i<n.length;i++)t[n[i]]=!0},overrideAll:h}},{\"../lib\":719}],751:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"gl-mat4/fromQuat\"),a=t(\"../registry\"),o=t(\"../lib\"),s=t(\"../plots/plots\"),l=t(\"../plots/cartesian/axis_ids\"),c=t(\"../components/color\"),u=l.cleanId,h=l.getFromTrace,f=a.traceIs;function p(t,e){var r=t[e],n=e.charAt(0);r&&\"paper\"!==r&&(t[e]=u(r,n))}function d(t){function e(e,r){var n=t[e],i=t.title&&t.title[r];n&&!i&&(t.title||(t.title={}),t.title[r]=t[e],delete t[e])}t&&(\"string\"!=typeof t.title&&\"number\"!=typeof t.title||(t.title={text:t.title}),e(\"titlefont\",\"font\"),e(\"titleposition\",\"position\"),e(\"titleside\",\"side\"),e(\"titleoffset\",\"offset\"))}function g(t){if(!o.isPlainObject(t))return!1;var e=t.name;return delete t.name,delete t.showlegend,(\"string\"==typeof e||\"number\"==typeof e)&&String(e)}function v(t,e,r,n){if(r&&!n)return t;if(n&&!r)return e;if(!t.trim())return e;if(!e.trim())return t;var i,a=Math.min(t.length,e.length);for(i=0;i<a&&t.charAt(i)===e.charAt(i);i++);return t.substr(0,i).trim()}function m(t){var e=\"middle\",r=\"center\";return\"string\"==typeof t&&(-1!==t.indexOf(\"top\")?e=\"top\":-1!==t.indexOf(\"bottom\")&&(e=\"bottom\"),-1!==t.indexOf(\"left\")?r=\"left\":-1!==t.indexOf(\"right\")&&(r=\"right\")),e+\" \"+r}function y(t,e){return e in t&&\"object\"==typeof t[e]&&0===Object.keys(t[e]).length}r.clearPromiseQueue=function(t){Array.isArray(t._promises)&&t._promises.length>0&&o.log(\"Clearing previous rejected promises from queue.\"),t._promises=[]},r.cleanLayout=function(t){var e,n;t||(t={}),t.xaxis1&&(t.xaxis||(t.xaxis=t.xaxis1),delete t.xaxis1),t.yaxis1&&(t.yaxis||(t.yaxis=t.yaxis1),delete t.yaxis1),t.scene1&&(t.scene||(t.scene=t.scene1),delete t.scene1);var a=(s.subplotsRegistry.cartesian||{}).attrRegex,l=(s.subplotsRegistry.polar||{}).attrRegex,h=(s.subplotsRegistry.ternary||{}).attrRegex,f=(s.subplotsRegistry.gl3d||{}).attrRegex,g=Object.keys(t);for(e=0;e<g.length;e++){var v=g[e];if(a&&a.test(v)){var m=t[v];m.anchor&&\"free\"!==m.anchor&&(m.anchor=u(m.anchor)),m.overlaying&&(m.overlaying=u(m.overlaying)),m.type||(m.isdate?m.type=\"date\":m.islog?m.type=\"log\":!1===m.isdate&&!1===m.islog&&(m.type=\"linear\")),\"withzero\"!==m.autorange&&\"tozero\"!==m.autorange||(m.autorange=!0,m.rangemode=\"tozero\"),delete m.islog,delete m.isdate,delete m.categories,y(m,\"domain\")&&delete m.domain,void 0!==m.autotick&&(void 0===m.tickmode&&(m.tickmode=m.autotick?\"auto\":\"linear\"),delete m.autotick),d(m)}else if(l&&l.test(v)){d(t[v].radialaxis)}else if(h&&h.test(v)){var x=t[v];d(x.aaxis),d(x.baxis),d(x.caxis)}else if(f&&f.test(v)){var b=t[v],_=b.cameraposition;if(Array.isArray(_)&&4===_[0].length){var w=_[0],k=_[1],T=_[2],A=i([],w),M=[];for(n=0;n<3;++n)M[n]=k[n]+T*A[2+4*n];b.camera={eye:{x:M[0],y:M[1],z:M[2]},center:{x:k[0],y:k[1],z:k[2]},up:{x:0,y:0,z:1}},delete b.cameraposition}d(b.xaxis),d(b.yaxis),d(b.zaxis)}}var S=Array.isArray(t.annotations)?t.annotations.length:0;for(e=0;e<S;e++){var E=t.annotations[e];o.isPlainObject(E)&&(E.ref&&(\"paper\"===E.ref?(E.xref=\"paper\",E.yref=\"paper\"):\"data\"===E.ref&&(E.xref=\"x\",E.yref=\"y\"),delete E.ref),p(E,\"xref\"),p(E,\"yref\"))}var C=Array.isArray(t.shapes)?t.shapes.length:0;for(e=0;e<C;e++){var L=t.shapes[e];o.isPlainObject(L)&&(p(L,\"xref\"),p(L,\"yref\"))}var P=t.legend;return P&&(P.x>3?(P.x=1.02,P.xanchor=\"left\"):P.x<-2&&(P.x=-.02,P.xanchor=\"right\"),P.y>3?(P.y=1.02,P.yanchor=\"bottom\"):P.y<-2&&(P.y=-.02,P.yanchor=\"top\")),d(t),\"rotate\"===t.dragmode&&(t.dragmode=\"orbit\"),c.clean(t),t.template&&t.template.layout&&r.cleanLayout(t.template.layout),t},r.cleanData=function(t){for(var e=0;e<t.length;e++){var n,i=t[e];if(\"histogramy\"===i.type&&\"xbins\"in i&&!(\"ybins\"in i)&&(i.ybins=i.xbins,delete i.xbins),i.error_y&&\"opacity\"in i.error_y){var l=c.defaults,h=i.error_y.color||(f(i,\"bar\")?c.defaultLine:l[e%l.length]);i.error_y.color=c.addOpacity(c.rgb(h),c.opacity(h)*i.error_y.opacity),delete i.error_y.opacity}if(\"bardir\"in i&&(\"h\"!==i.bardir||!f(i,\"bar\")&&\"histogram\"!==i.type.substr(0,9)||(i.orientation=\"h\",r.swapXYData(i)),delete i.bardir),\"histogramy\"===i.type&&r.swapXYData(i),\"histogramx\"!==i.type&&\"histogramy\"!==i.type||(i.type=\"histogram\"),\"scl\"in i&&!(\"colorscale\"in i)&&(i.colorscale=i.scl,delete i.scl),\"reversescl\"in i&&!(\"reversescale\"in i)&&(i.reversescale=i.reversescl,delete i.reversescl),i.xaxis&&(i.xaxis=u(i.xaxis,\"x\")),i.yaxis&&(i.yaxis=u(i.yaxis,\"y\")),f(i,\"gl3d\")&&i.scene&&(i.scene=s.subplotsRegistry.gl3d.cleanId(i.scene)),!f(i,\"pie-like\")&&!f(i,\"bar-like\"))if(Array.isArray(i.textposition))for(n=0;n<i.textposition.length;n++)i.textposition[n]=m(i.textposition[n]);else i.textposition&&(i.textposition=m(i.textposition));var p=a.getModule(i);if(p&&p.colorbar){var x=p.colorbar.container,b=x?i[x]:i;b&&b.colorscale&&(\"YIGnBu\"===b.colorscale&&(b.colorscale=\"YlGnBu\"),\"YIOrRd\"===b.colorscale&&(b.colorscale=\"YlOrRd\"))}if(\"surface\"===i.type&&o.isPlainObject(i.contours)){var _=[\"x\",\"y\",\"z\"];for(n=0;n<_.length;n++){var w=i.contours[_[n]];o.isPlainObject(w)&&(w.highlightColor&&(w.highlightcolor=w.highlightColor,delete w.highlightColor),w.highlightWidth&&(w.highlightwidth=w.highlightWidth,delete w.highlightWidth))}}if(\"candlestick\"===i.type||\"ohlc\"===i.type){var k=!1!==(i.increasing||{}).showlegend,T=!1!==(i.decreasing||{}).showlegend,A=g(i.increasing),M=g(i.decreasing);if(!1!==A&&!1!==M){var S=v(A,M,k,T);S&&(i.name=S)}else!A&&!M||i.name||(i.name=A||M)}if(Array.isArray(i.transforms)){var E=i.transforms;for(n=0;n<E.length;n++){var C=E[n];if(o.isPlainObject(C))switch(C.type){case\"filter\":C.filtersrc&&(C.target=C.filtersrc,delete C.filtersrc),C.calendar&&(C.valuecalendar||(C.valuecalendar=C.calendar),delete C.calendar);break;case\"groupby\":if(C.styles=C.styles||C.style,C.styles&&!Array.isArray(C.styles)){var L=C.styles,P=Object.keys(L);C.styles=[];for(var O=0;O<P.length;O++)C.styles.push({target:P[O],value:L[P[O]]})}}}}y(i,\"line\")&&delete i.line,\"marker\"in i&&(y(i.marker,\"line\")&&delete i.marker.line,y(i,\"marker\")&&delete i.marker),c.clean(i),i.autobinx&&(delete i.autobinx,delete i.xbins),i.autobiny&&(delete i.autobiny,delete i.ybins),d(i),i.colorbar&&d(i.colorbar),i.marker&&i.marker.colorbar&&d(i.marker.colorbar),i.line&&i.line.colorbar&&d(i.line.colorbar),i.aaxis&&d(i.aaxis),i.baxis&&d(i.baxis)}},r.swapXYData=function(t){var e;if(o.swapAttrs(t,[\"?\",\"?0\",\"d?\",\"?bins\",\"nbins?\",\"autobin?\",\"?src\",\"error_?\"]),Array.isArray(t.z)&&Array.isArray(t.z[0])&&(t.transpose?delete t.transpose:t.transpose=!0),t.error_x&&t.error_y){var r=t.error_y,n=\"copy_ystyle\"in r?r.copy_ystyle:!(r.color||r.thickness||r.width);o.swapAttrs(t,[\"error_?.copy_ystyle\"]),n&&o.swapAttrs(t,[\"error_?.color\",\"error_?.thickness\",\"error_?.width\"])}if(\"string\"==typeof t.hoverinfo){var i=t.hoverinfo.split(\"+\");for(e=0;e<i.length;e++)\"x\"===i[e]?i[e]=\"y\":\"y\"===i[e]&&(i[e]=\"x\");t.hoverinfo=i.join(\"+\")}},r.coerceTraceIndices=function(t,e){if(n(e))return[e];if(!Array.isArray(e)||!e.length)return t.data.map(function(t,e){return e});if(Array.isArray(e)){for(var r=[],i=0;i<e.length;i++)o.isIndex(e[i],t.data.length)?r.push(e[i]):o.warn(\"trace index (\",e[i],\") is not a number or is out of bounds\");return r}return e},r.manageArrayContainers=function(t,e,r){var i=t.obj,a=t.parts,s=a.length,l=a[s-1],c=n(l);if(c&&null===e){var u=a.slice(0,s-1).join(\".\");o.nestedProperty(i,u).get().splice(l,1)}else c&&void 0===t.get()?(void 0===t.get()&&(r[t.astr]=null),t.set(e)):t.set(e)};var x=/(\\.[^\\[\\]\\.]+|\\[[^\\[\\]\\.]+\\])$/;function b(t){var e=t.search(x);if(e>0)return t.substr(0,e)}r.hasParent=function(t,e){for(var r=b(e);r;){if(r in t)return!0;r=b(r)}return!1};var _=[\"x\",\"y\",\"z\"];r.clearAxisTypes=function(t,e,r){for(var n=0;n<e.length;n++)for(var i=t._fullData[n],a=0;a<3;a++){var s=h(t,i,_[a]);if(s&&\"log\"!==s.type){var l=s._name,c=s._id.substr(1);if(\"scene\"===c.substr(0,5)){if(void 0!==r[c])continue;l=c+\".\"+l}var u=l+\".type\";void 0===r[l]&&void 0===r[u]&&o.nestedProperty(t.layout,u).set(null)}}}},{\"../components/color\":593,\"../lib\":719,\"../plots/cartesian/axis_ids\":770,\"../plots/plots\":828,\"../registry\":847,\"fast-isnumeric\":225,\"gl-mat4/fromQuat\":262}],752:[function(t,e,r){\"use strict\";var n=t(\"./plot_api\");r.plot=n.plot,r.newPlot=n.newPlot,r.restyle=n.restyle,r.relayout=n.relayout,r.redraw=n.redraw,r.update=n.update,r._guiRestyle=n._guiRestyle,r._guiRelayout=n._guiRelayout,r._guiUpdate=n._guiUpdate,r._storeDirectGUIEdit=n._storeDirectGUIEdit,r.react=n.react,r.extendTraces=n.extendTraces,r.prependTraces=n.prependTraces,r.addTraces=n.addTraces,r.deleteTraces=n.deleteTraces,r.moveTraces=n.moveTraces,r.purge=n.purge,r.addFrames=n.addFrames,r.deleteFrames=n.deleteFrames,r.animate=n.animate,r.setPlotConfig=n.setPlotConfig,r.toImage=t(\"./to_image\"),r.validate=t(\"./validate\"),r.downloadImage=t(\"../snapshot/download\");var i=t(\"./template_api\");r.makeTemplate=i.makeTemplate,r.validateTemplate=i.validateTemplate},{\"../snapshot/download\":849,\"./plot_api\":754,\"./template_api\":759,\"./to_image\":760,\"./validate\":761}],753:[function(t,e,r){\"use strict\";var n=t(\"../lib/is_plain_object\"),i=t(\"../lib/noop\"),a=t(\"../lib/loggers\"),o=t(\"../lib/search\").sorterAsc,s=t(\"../registry\");r.containerArrayMatch=t(\"./container_array_match\");var l=r.isAddVal=function(t){return\"add\"===t||n(t)},c=r.isRemoveVal=function(t){return null===t||\"remove\"===t};r.applyContainerArrayChanges=function(t,e,r,n,u){var h=e.astr,f=s.getComponentMethod(h,\"supplyLayoutDefaults\"),p=s.getComponentMethod(h,\"draw\"),d=s.getComponentMethod(h,\"drawOne\"),g=n.replot||n.recalc||f===i||p===i,v=t.layout,m=t._fullLayout;if(r[\"\"]){Object.keys(r).length>1&&a.warn(\"Full array edits are incompatible with other edits\",h);var y=r[\"\"][\"\"];if(c(y))e.set(null);else{if(!Array.isArray(y))return a.warn(\"Unrecognized full array edit value\",h,y),!0;e.set(y)}return!g&&(f(v,m),p(t),!0)}var x,b,_,w,k,T,A,M,S=Object.keys(r).map(Number).sort(o),E=e.get(),C=E||[],L=u(m,h).get(),P=[],O=-1,z=C.length;for(x=0;x<S.length;x++)if(w=r[_=S[x]],k=Object.keys(w),T=w[\"\"],A=l(T),_<0||_>C.length-(A?0:1))a.warn(\"index out of range\",h,_);else if(void 0!==T)k.length>1&&a.warn(\"Insertion & removal are incompatible with edits to the same index.\",h,_),c(T)?P.push(_):A?(\"add\"===T&&(T={}),C.splice(_,0,T),L&&L.splice(_,0,{})):a.warn(\"Unrecognized full object edit value\",h,_,T),-1===O&&(O=_);else for(b=0;b<k.length;b++)M=h+\"[\"+_+\"].\",u(C[_],k[b],M).set(w[k[b]]);for(x=P.length-1;x>=0;x--)C.splice(P[x],1),L&&L.splice(P[x],1);if(C.length?E||e.set(C):e.set(null),g)return!1;if(f(v,m),d!==i){var I;if(-1===O)I=S;else{for(z=Math.max(C.length,z),I=[],x=0;x<S.length&&!((_=S[x])>=O);x++)I.push(_);for(x=O;x<z;x++)I.push(x)}for(x=0;x<I.length;x++)d(t,I[x])}else p(t);return!0}},{\"../lib/is_plain_object\":720,\"../lib/loggers\":723,\"../lib/noop\":728,\"../lib/search\":738,\"../registry\":847,\"./container_array_match\":749}],754:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"has-hover\"),o=t(\"../lib\"),s=o.nestedProperty,l=t(\"../lib/events\"),c=t(\"../lib/queue\"),u=t(\"../registry\"),h=t(\"./plot_schema\"),f=t(\"../plots/plots\"),p=t(\"../plots/polar/legacy\"),d=t(\"../plots/cartesian/axes\"),g=t(\"../components/drawing\"),v=t(\"../components/color\"),m=t(\"../plots/cartesian/graph_interact\").initInteractions,y=t(\"../constants/xmlns_namespaces\"),x=t(\"../lib/svg_text_utils\"),b=t(\"../plots/cartesian/select\").clearSelect,_=t(\"./plot_config\").dfltConfig,w=t(\"./manage_arrays\"),k=t(\"./helpers\"),T=t(\"./subroutines\"),A=t(\"./edit_types\"),M=t(\"../plots/cartesian/constants\").AX_NAME_PATTERN,S=0,E=5;function C(t){var e=t._fullLayout;e._redrawFromAutoMarginCount?e._redrawFromAutoMarginCount--:t.emit(\"plotly_afterplot\")}function L(t,e){try{t._fullLayout._paper.style(\"background\",e)}catch(t){o.error(t)}}function P(t,e){L(t,v.combine(e,\"white\"))}function O(t,e){if(!t._context){t._context=o.extendDeep({},_);var r=n.select(\"base\");t._context._baseUrl=r.size()&&r.attr(\"href\")?window.location.href.split(\"#\")[0]:\"\"}var i,s,l,c=t._context;if(e){for(s=Object.keys(e),i=0;i<s.length;i++)\"editable\"!==(l=s[i])&&\"edits\"!==l&&l in c&&(\"setBackground\"===l&&\"opaque\"===e[l]?c[l]=P:c[l]=e[l]);e.plot3dPixelRatio&&!c.plotGlPixelRatio&&(c.plotGlPixelRatio=c.plot3dPixelRatio);var u=e.editable;if(void 0!==u)for(c.editable=u,s=Object.keys(c.edits),i=0;i<s.length;i++)c.edits[s[i]]=u;if(e.edits)for(s=Object.keys(e.edits),i=0;i<s.length;i++)(l=s[i])in c.edits&&(c.edits[l]=e.edits[l]);c._exportedPlot=e._exportedPlot}c.staticPlot&&(c.editable=!1,c.edits={},c.autosizable=!1,c.scrollZoom=!1,c.doubleClick=!1,c.showTips=!1,c.showLink=!1,c.displayModeBar=!1),\"hover\"!==c.displayModeBar||a||(c.displayModeBar=!0),\"transparent\"!==c.setBackground&&\"function\"==typeof c.setBackground||(c.setBackground=L),c._hasZeroHeight=c._hasZeroHeight||0===t.clientHeight,c._hasZeroWidth=c._hasZeroWidth||0===t.clientWidth;var h=c.scrollZoom,f=c._scrollZoom={};if(!0===h)f.cartesian=1,f.gl3d=1,f.geo=1,f.mapbox=1;else if(\"string\"==typeof h){var p=h.split(\"+\");for(i=0;i<p.length;i++)f[p[i]]=1}else!1!==h&&(f.gl3d=1,f.geo=1,f.mapbox=1)}function z(t,e){var r,n,i=e+1,a=[];for(r=0;r<t.length;r++)(n=t[r])<0?a.push(i+n):a.push(n);return a}function I(t,e,r){var n,i;for(n=0;n<e.length;n++){if((i=e[n])!==parseInt(i,10))throw new Error(\"all values in \"+r+\" must be integers\");if(i>=t.data.length||i<-t.data.length)throw new Error(r+\" must be valid indices for gd.data.\");if(e.indexOf(i,n+1)>-1||i>=0&&e.indexOf(-t.data.length+i)>-1||i<0&&e.indexOf(t.data.length+i)>-1)throw new Error(\"each index in \"+r+\" must be unique.\")}}function D(t,e,r){if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"currentIndices is a required argument.\");if(Array.isArray(e)||(e=[e]),I(t,e,\"currentIndices\"),\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&I(t,r,\"newIndices\"),\"undefined\"!=typeof r&&e.length!==r.length)throw new Error(\"current and new indices must be of equal length.\")}function R(t,e,r,n,a){!function(t,e,r,n){var i=o.isPlainObject(n);if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array\");if(!o.isPlainObject(e))throw new Error(\"update must be a key:value object\");if(\"undefined\"==typeof r)throw new Error(\"indices must be an integer or array of integers\");for(var a in I(t,r,\"indices\"),e){if(!Array.isArray(e[a])||e[a].length!==r.length)throw new Error(\"attribute \"+a+\" must be an array of length equal to indices array length\");if(i&&(!(a in n)||!Array.isArray(n[a])||n[a].length!==e[a].length))throw new Error(\"when maxPoints is set as a key:value object it must contain a 1:1 corrispondence with the keys and number of traces in the update object\")}}(t,e,r,n);for(var l=function(t,e,r,n){var a,l,c,u,h,f=o.isPlainObject(n),p=[];for(var d in Array.isArray(r)||(r=[r]),r=z(r,t.data.length-1),e)for(var g=0;g<r.length;g++){if(a=t.data[r[g]],l=(c=s(a,d)).get(),u=e[d][g],!o.isArrayOrTypedArray(u))throw new Error(\"attribute: \"+d+\" index: \"+g+\" must be an array\");if(!o.isArrayOrTypedArray(l))throw new Error(\"cannot extend missing or non-array attribute: \"+d);if(l.constructor!==u.constructor)throw new Error(\"cannot extend array with an array of a different type: \"+d);h=f?n[d][g]:n,i(h)||(h=-1),p.push({prop:c,target:l,insert:u,maxp:Math.floor(h)})}return p}(t,e,r,n),c={},u={},h=0;h<l.length;h++){var f=l[h].prop,p=l[h].maxp,d=a(l[h].target,l[h].insert,p);f.set(d[0]),Array.isArray(c[f.astr])||(c[f.astr]=[]),c[f.astr].push(d[1]),Array.isArray(u[f.astr])||(u[f.astr]=[]),u[f.astr].push(l[h].target.length)}return{update:c,maxPoints:u}}function F(t,e){var r=new t.constructor(t.length+e.length);return r.set(t),r.set(e,t.length),r}function B(t,e,n,i){t=o.getGraphDiv(t),k.clearPromiseQueue(t);var a={};if(\"string\"==typeof e)a[e]=n;else{if(!o.isPlainObject(e))return o.warn(\"Restyle fail.\",e,n,i),Promise.reject();a=o.extendFlat({},e),void 0===i&&(i=n)}Object.keys(a).length&&(t.changed=!0);var s=k.coerceTraceIndices(t,i),l=V(t,a,s),u=l.flags;u.calc&&(t.calcdata=void 0),u.clearAxisTypes&&k.clearAxisTypes(t,s,{});var h=[];u.fullReplot?h.push(r.plot):(h.push(f.previousPromises),f.supplyDefaults(t),u.markerSize&&(f.doCalcdata(t),Y(h)),u.style&&h.push(T.doTraceStyle),u.colorbars&&h.push(T.doColorBars),h.push(C)),h.push(f.rehover,f.redrag),c.add(t,B,[t,l.undoit,l.traces],B,[t,l.redoit,l.traces]);var p=o.syncOrAsync(h,t);return p&&p.then||(p=Promise.resolve()),p.then(function(){return t.emit(\"plotly_restyle\",l.eventData),t})}function N(t){return void 0===t?null:t}function j(t,e){return e?function(e,r,n){var i=s(e,r),a=i.set;return i.set=function(e){U((n||\"\")+r,i.get(),e,t),a(e)},i}:s}function U(t,e,r,n){if(Array.isArray(e)||Array.isArray(r))for(var i=Array.isArray(e)?e:[],a=Array.isArray(r)?r:[],s=Math.max(i.length,a.length),l=0;l<s;l++)U(t+\"[\"+l+\"]\",i[l],a[l],n);else if(o.isPlainObject(e)||o.isPlainObject(r)){var c=o.isPlainObject(e)?e:{},u=o.isPlainObject(r)?r:{},h=o.extendFlat({},c,u);for(var f in h)U(t+\".\"+f,c[f],u[f],n)}else void 0===n[t]&&(n[t]=N(e))}function V(t,e,r){var n,i=t._fullLayout,a=t._fullData,l=t.data,c=i._guiEditing,p=j(i._preGUI,c),g=o.extendDeepAll({},e);q(e);var v,m=A.traceFlags(),y={},x={};function b(){return r.map(function(){})}function _(t){var e=d.id2name(t);-1===v.indexOf(e)&&v.push(e)}function w(t){return\"LAYOUT\"+t+\".autorange\"}function T(t){return\"LAYOUT\"+t+\".range\"}function M(t){for(var e=t;e<a.length;e++)if(a[e]._input===l[t])return a[e]}function S(n,a,o){if(Array.isArray(n))n.forEach(function(t){S(t,a,o)});else if(!(n in e||k.hasParent(e,n))){var s;if(\"LAYOUT\"===n.substr(0,6))s=p(t.layout,n.replace(\"LAYOUT\",\"\"));else{var u=r[o];s=j(i._tracePreGUI[M(u)._fullInput.uid],c)(l[u],n)}n in x||(x[n]=b()),void 0===x[n][o]&&(x[n][o]=N(s.get())),void 0!==a&&s.set(a)}}function E(t){return function(e){return a[e][t]}}function C(t){return function(e,n){return!1===e?a[r[n]][t]:null}}for(var L in e){if(k.hasParent(e,L))throw new Error(\"cannot set \"+L+\" and a parent attribute simultaneously\");var P,O,z,I,D,R,F=e[L];if(\"autobinx\"!==L&&\"autobiny\"!==L||(L=L.charAt(L.length-1)+\"bins\",F=Array.isArray(F)?F.map(C(L)):!1===F?r.map(E(L)):null),y[L]=F,\"LAYOUT\"!==L.substr(0,6)){for(x[L]=b(),n=0;n<r.length;n++){if(P=l[r[n]],O=M(r[n]),I=(z=j(i._tracePreGUI[O._fullInput.uid],c)(P,L)).get(),void 0!==(D=Array.isArray(F)?F[n%F.length]:F)){var B=z.parts[z.parts.length-1],U=L.substr(0,L.length-B.length-1),V=U?U+\".\":\"\",H=U?s(O,U).get():O;if((R=h.getTraceValObject(O,z.parts))&&R.impliedEdits&&null!==D)for(var G in R.impliedEdits)S(o.relativeAttr(L,G),R.impliedEdits[G],n);else if(\"thicknessmode\"!==B&&\"lenmode\"!==B||I===D||\"fraction\"!==D&&\"pixels\"!==D||!H){if(\"type\"===L&&(\"pie\"===D!=(\"pie\"===I)||\"funnelarea\"===D!=(\"funnelarea\"===I))){var Y=\"x\",W=\"y\";\"bar\"!==D&&\"bar\"!==I||\"h\"!==P.orientation||(Y=\"y\",W=\"x\"),o.swapAttrs(P,[\"?\",\"?src\"],\"labels\",Y),o.swapAttrs(P,[\"d?\",\"?0\"],\"label\",Y),o.swapAttrs(P,[\"?\",\"?src\"],\"values\",W),\"pie\"===I||\"funnelarea\"===I?(s(P,\"marker.color\").set(s(P,\"marker.colors\").get()),i._pielayer.selectAll(\"g.trace\").remove()):u.traceIs(P,\"cartesian\")&&s(P,\"marker.colors\").set(s(P,\"marker.color\").get())}}else{var X=i._size,Z=H.orient,J=\"top\"===Z||\"bottom\"===Z;if(\"thicknessmode\"===B){var K=J?X.h:X.w;S(V+\"thickness\",H.thickness*(\"fraction\"===D?1/K:K),n)}else{var $=J?X.w:X.h;S(V+\"len\",H.len*(\"fraction\"===D?1/$:$),n)}}x[L][n]=N(I);if(-1!==[\"swapxy\",\"swapxyaxes\",\"orientation\",\"orientationaxes\"].indexOf(L)){if(\"orientation\"===L){z.set(D);var Q=P.x&&!P.y?\"h\":\"v\";if((z.get()||Q)===O.orientation)continue}else\"orientationaxes\"===L&&(P.orientation={v:\"h\",h:\"v\"}[O.orientation]);k.swapXYData(P),m.calc=m.clearAxisTypes=!0}else-1!==f.dataArrayContainers.indexOf(z.parts[0])?(k.manageArrayContainers(z,D,x),m.calc=!0):(R?R.arrayOk&&!u.traceIs(O,\"regl\")&&(o.isArrayOrTypedArray(D)||o.isArrayOrTypedArray(I))?m.calc=!0:A.update(m,R):m.calc=!0,z.set(D))}}if(-1!==[\"swapxyaxes\",\"orientationaxes\"].indexOf(L)&&d.swap(t,r),\"orientationaxes\"===L){var tt=s(t.layout,\"hovermode\");\"x\"===tt.get()?tt.set(\"y\"):\"y\"===tt.get()&&tt.set(\"x\")}if(-1!==[\"orientation\",\"type\"].indexOf(L)){for(v=[],n=0;n<r.length;n++){var et=l[r[n]];u.traceIs(et,\"cartesian\")&&(_(et.xaxis||\"x\"),_(et.yaxis||\"y\"))}S(v.map(w),!0,0),S(v.map(T),[0,1],0)}}else z=p(t.layout,L.replace(\"LAYOUT\",\"\")),x[L]=[N(z.get())],z.set(Array.isArray(F)?F[0]:F),m.calc=!0}return(m.calc||m.plot)&&(m.fullReplot=!0),{flags:m,undoit:x,redoit:y,traces:r,eventData:o.extendDeepNoArrays([],[g,r])}}function q(t){var e,r,n,i=o.counterRegex(\"axis\",\".title\",!1,!1),a=/colorbar\\.title$/,s=Object.keys(t);for(e=0;e<s.length;e++)r=s[e],n=t[r],\"title\"!==r&&!i.test(r)&&!a.test(r)||\"string\"!=typeof n&&\"number\"!=typeof n?r.indexOf(\"titlefont\")>-1?l(r,r.replace(\"titlefont\",\"title.font\")):r.indexOf(\"titleposition\")>-1?l(r,r.replace(\"titleposition\",\"title.position\")):r.indexOf(\"titleside\")>-1?l(r,r.replace(\"titleside\",\"title.side\")):r.indexOf(\"titleoffset\")>-1&&l(r,r.replace(\"titleoffset\",\"title.offset\")):l(r,r.replace(\"title\",\"title.text\"));function l(e,r){t[r]=t[e],delete t[e]}}function H(t,e,r){if(t=o.getGraphDiv(t),k.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);var n={};if(\"string\"==typeof e)n[e]=r;else{if(!o.isPlainObject(e))return o.warn(\"Relayout fail.\",e,r),Promise.reject();n=o.extendFlat({},e)}Object.keys(n).length&&(t.changed=!0);var i=J(t,n),a=i.flags;a.calc&&(t.calcdata=void 0);var s=[f.previousPromises];a.layoutReplot?s.push(T.layoutReplot):Object.keys(n).length&&(G(t,a,i)||f.supplyDefaults(t),a.legend&&s.push(T.doLegend),a.layoutstyle&&s.push(T.layoutStyles),a.axrange&&Y(s,i.rangesAltered),a.ticks&&s.push(T.doTicksRelayout),a.modebar&&s.push(T.doModeBar),a.camera&&s.push(T.doCamera),a.colorbars&&s.push(T.doColorBars),s.push(C)),s.push(f.rehover,f.redrag),c.add(t,H,[t,i.undoit],H,[t,i.redoit]);var l=o.syncOrAsync(s,t);return l&&l.then||(l=Promise.resolve(t)),l.then(function(){return t.emit(\"plotly_relayout\",i.eventData),t})}function G(t,e,r){var n=t._fullLayout;if(!e.axrange)return!1;for(var i in e)if(\"axrange\"!==i&&e[i])return!1;for(var a in r.rangesAltered){var o=d.id2name(a),s=t.layout[o],l=n[o];if(l.autorange=s.autorange,l.range=s.range.slice(),l.cleanRange(),l._matchGroup)for(var c in l._matchGroup)if(c!==a){var u=n[d.id2name(c)];u.autorange=l.autorange,u.range=l.range.slice(),u._input.range=l.range.slice()}}return!0}function Y(t,e){var r=e?function(t){var r=[],n=!0;for(var i in e){var a=d.getFromId(t,i);if(r.push(i),a._matchGroup)for(var o in a._matchGroup)e[o]||r.push(o);a.automargin&&(n=!1)}return d.draw(t,r,{skipTitle:n})}:function(t){return d.draw(t,\"redraw\")};t.push(b,T.doAutoRangeAndConstraints,r,T.drawData,T.finalDraw)}var W=/^[xyz]axis[0-9]*\\.range(\\[[0|1]\\])?$/,X=/^[xyz]axis[0-9]*\\.autorange$/,Z=/^[xyz]axis[0-9]*\\.domain(\\[[0|1]\\])?$/;function J(t,e){var r,n,i,a=t.layout,l=t._fullLayout,c=l._guiEditing,f=j(l._preGUI,c),p=Object.keys(e),g=d.list(t),v=o.extendDeepAll({},e),m={};for(q(e),p=Object.keys(e),n=0;n<p.length;n++)if(0===p[n].indexOf(\"allaxes\")){for(i=0;i<g.length;i++){var y=g[i]._id.substr(1),x=-1!==y.indexOf(\"scene\")?y+\".\":\"\",b=p[n].replace(\"allaxes\",x+g[i]._name);e[b]||(e[b]=e[p[n]])}delete e[p[n]]}var _=A.layoutFlags(),T={},S={};function E(t,r){if(Array.isArray(t))t.forEach(function(t){E(t,r)});else if(!(t in e||k.hasParent(e,t))){var n=f(a,t);t in S||(S[t]=N(n.get())),void 0!==r&&n.set(r)}}var C,L={};function P(t){var e=d.name2id(t.split(\".\")[0]);return L[e]=1,e}for(var O in e){if(k.hasParent(e,O))throw new Error(\"cannot set \"+O+\" and a parent attribute simultaneously\");for(var z=f(a,O),I=e[O],D=z.parts.length-1;D>0&&\"string\"!=typeof z.parts[D];)D--;var R=z.parts[D],F=z.parts[D-1]+\".\"+R,B=z.parts.slice(0,D).join(\".\"),U=s(t.layout,B).get(),V=s(l,B).get(),H=z.get();if(void 0!==I){T[O]=I,S[O]=\"reverse\"===R?I:N(H);var G=h.getLayoutValObject(l,z.parts);if(G&&G.impliedEdits&&null!==I)for(var Y in G.impliedEdits)E(o.relativeAttr(O,Y),G.impliedEdits[Y]);if(-1!==[\"width\",\"height\"].indexOf(O))if(I){E(\"autosize\",null);var J=\"height\"===O?\"width\":\"height\";E(J,l[J])}else l[O]=t._initialAutoSize[O];else if(\"autosize\"===O)E(\"width\",I?null:l.width),E(\"height\",I?null:l.height);else if(F.match(W))P(F),s(l,B+\"._inputRange\").set(null);else if(F.match(X)){P(F),s(l,B+\"._inputRange\").set(null);var $=s(l,B).get();$._inputDomain&&($._input.domain=$._inputDomain.slice())}else F.match(Z)&&s(l,B+\"._inputDomain\").set(null);if(\"type\"===R){var Q=U,tt=\"linear\"===V.type&&\"log\"===I,et=\"log\"===V.type&&\"linear\"===I;if(tt||et){if(Q&&Q.range)if(V.autorange)tt&&(Q.range=Q.range[1]>Q.range[0]?[1,2]:[2,1]);else{var rt=Q.range[0],nt=Q.range[1];tt?(rt<=0&&nt<=0&&E(B+\".autorange\",!0),rt<=0?rt=nt/1e6:nt<=0&&(nt=rt/1e6),E(B+\".range[0]\",Math.log(rt)/Math.LN10),E(B+\".range[1]\",Math.log(nt)/Math.LN10)):(E(B+\".range[0]\",Math.pow(10,rt)),E(B+\".range[1]\",Math.pow(10,nt)))}else E(B+\".autorange\",!0);Array.isArray(l._subplots.polar)&&l._subplots.polar.length&&l[z.parts[0]]&&\"radialaxis\"===z.parts[1]&&delete l[z.parts[0]]._subplot.viewInitial[\"radialaxis.range\"],u.getComponentMethod(\"annotations\",\"convertCoords\")(t,V,I,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,V,I,E)}else E(B+\".autorange\",!0),E(B+\".range\",null);s(l,B+\"._inputRange\").set(null)}else if(R.match(M)){var it=s(l,O).get(),at=(I||{}).type;at&&\"-\"!==at||(at=\"linear\"),u.getComponentMethod(\"annotations\",\"convertCoords\")(t,it,at,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,it,at,E)}var ot=w.containerArrayMatch(O);if(ot){r=ot.array,n=ot.index;var st=ot.property,lt=G||{editType:\"calc\"};\"\"!==n&&\"\"===st&&(w.isAddVal(I)?S[O]=null:w.isRemoveVal(I)?S[O]=(s(a,r).get()||[])[n]:o.warn(\"unrecognized full object value\",e)),A.update(_,lt),m[r]||(m[r]={});var ct=m[r][n];ct||(ct=m[r][n]={}),ct[st]=I,delete e[O]}else\"reverse\"===R?(U.range?U.range.reverse():(E(B+\".autorange\",!0),U.range=[1,0]),V.autorange?_.calc=!0:_.plot=!0):(l._has(\"scatter-like\")&&l._has(\"regl\")&&\"dragmode\"===O&&(\"lasso\"===I||\"select\"===I)&&\"lasso\"!==H&&\"select\"!==H?_.plot=!0:l._has(\"gl2d\")?_.plot=!0:G?A.update(_,G):_.calc=!0,z.set(I))}}for(r in m){w.applyContainerArrayChanges(t,f(a,r),m[r],_,f)||(_.plot=!0)}var ut=l._axisConstraintGroups||[];for(C in L)for(n=0;n<ut.length;n++){var ht=ut[n];if(ht[C])for(var ft in _.calc=!0,ht)L[ft]||(d.getFromId(t,ft)._constraintShrinkable=!0)}return(K(t)||e.height||e.width)&&(_.plot=!0),(_.plot||_.calc)&&(_.layoutReplot=!0),{flags:_,rangesAltered:L,undoit:S,redoit:T,eventData:v}}function K(t){var e=t._fullLayout,r=e.width,n=e.height;return t.layout.autosize&&f.plotAutoSize(t,t.layout,e),e.width!==r||e.height!==n}function $(t,e,n,i){if(t=o.getGraphDiv(t),k.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);o.isPlainObject(e)||(e={}),o.isPlainObject(n)||(n={}),Object.keys(e).length&&(t.changed=!0),Object.keys(n).length&&(t.changed=!0);var a=k.coerceTraceIndices(t,i),s=V(t,o.extendFlat({},e),a),l=s.flags,u=J(t,o.extendFlat({},n)),h=u.flags;(l.calc||h.calc)&&(t.calcdata=void 0),l.clearAxisTypes&&k.clearAxisTypes(t,a,n);var p=[];h.layoutReplot?p.push(T.layoutReplot):l.fullReplot?p.push(r.plot):(p.push(f.previousPromises),G(t,h,u)||f.supplyDefaults(t),l.style&&p.push(T.doTraceStyle),(l.colorbars||h.colorbars)&&p.push(T.doColorBars),h.legend&&p.push(T.doLegend),h.layoutstyle&&p.push(T.layoutStyles),h.axrange&&Y(p,u.rangesAltered),h.ticks&&p.push(T.doTicksRelayout),h.modebar&&p.push(T.doModeBar),h.camera&&p.push(T.doCamera),p.push(C)),p.push(f.rehover,f.redrag),c.add(t,$,[t,s.undoit,u.undoit,s.traces],$,[t,s.redoit,u.redoit,s.traces]);var d=o.syncOrAsync(p,t);return d&&d.then||(d=Promise.resolve(t)),d.then(function(){return t.emit(\"plotly_update\",{data:s.eventData,layout:u.eventData}),t})}function Q(t){return function(e){e._fullLayout._guiEditing=!0;var r=t.apply(null,arguments);return e._fullLayout._guiEditing=!1,r}}var tt=[{pattern:/^hiddenlabels/,attr:\"legend.uirevision\"},{pattern:/^((x|y)axis\\d*)\\.((auto)?range|title\\.text)/},{pattern:/axis\\d*\\.showspikes$/,attr:\"modebar.uirevision\"},{pattern:/(hover|drag)mode$/,attr:\"modebar.uirevision\"},{pattern:/^(scene\\d*)\\.camera/},{pattern:/^(geo\\d*)\\.(projection|center)/},{pattern:/^(ternary\\d*\\.[abc]axis)\\.(min|title\\.text)$/},{pattern:/^(polar\\d*\\.radialaxis)\\.((auto)?range|angle|title\\.text)/},{pattern:/^(polar\\d*\\.angularaxis)\\.rotation/},{pattern:/^(mapbox\\d*)\\.(center|zoom|bearing|pitch)/},{pattern:/^legend\\.(x|y)$/,attr:\"editrevision\"},{pattern:/^(shapes|annotations)/,attr:\"editrevision\"},{pattern:/^title\\.text$/,attr:\"editrevision\"}],et=[{pattern:/^selectedpoints$/,attr:\"selectionrevision\"},{pattern:/(^|value\\.)visible$/,attr:\"legend.uirevision\"},{pattern:/^dimensions\\[\\d+\\]\\.constraintrange/},{pattern:/^node\\.(x|y|groups)/},{pattern:/^level$/},{pattern:/(^|value\\.)name$/},{pattern:/colorbar\\.title\\.text$/},{pattern:/colorbar\\.(x|y)$/,attr:\"editrevision\"}];function rt(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=t.match(n.pattern);if(i)return{head:i[1],attr:n.attr}}}function nt(t,e){var r=s(e,t).get();if(void 0!==r)return r;var n=t.split(\".\");for(n.pop();n.length>1;)if(n.pop(),void 0!==(r=s(e,n.join(\".\")+\".uirevision\").get()))return r;return e.uirevision}function it(t,e){for(var r=0;r<e.length;r++)if(e[r]._fullInput.uid===t)return r;return-1}function at(t,e,r){for(var n=0;n<e.length;n++)if(e[n].uid===t)return n;return!e[r]||e[r].uid?-1:r}function ot(t,e){var r=o.isPlainObject(t),n=Array.isArray(t);return r||n?(r&&o.isPlainObject(e)||n&&Array.isArray(e))&&JSON.stringify(t)===JSON.stringify(e):t===e}function st(t,e,r,n){var i,a,l,c=n.getValObject,u=n.flags,h=n.immutable,f=n.inArray,p=n.arrayIndex;function d(){var t=i.editType;f&&-1!==t.indexOf(\"arraydraw\")?o.pushUnique(u.arrays[f],p):(A.update(u,i),\"none\"!==t&&u.nChanges++,n.transition&&i.anim&&u.nChangesAnim++,(W.test(l)||X.test(l))&&(u.rangesAltered[r[0]]=1),Z.test(l)&&s(e,\"_inputDomain\").set(null),\"datarevision\"===a&&(u.newDataRevision=1))}function g(t){return\"data_array\"===t.valType||t.arrayOk}for(a in t){if(u.calc&&!n.transition)return;var v=t[a],m=e[a],y=r.concat(a);if(l=y.join(\".\"),\"_\"!==a.charAt(0)&&\"function\"!=typeof v&&v!==m){if((\"tick0\"===a||\"dtick\"===a)&&\"geo\"!==r[0]){var x=e.tickmode;if(\"auto\"===x||\"array\"===x||!x)continue}if((\"range\"!==a||!e.autorange)&&(\"zmin\"!==a&&\"zmax\"!==a||\"contourcarpet\"!==e.type)&&(i=c(y))&&(!i._compareAsJSON||JSON.stringify(v)!==JSON.stringify(m))){var b,_=i.valType,w=g(i),k=Array.isArray(v),T=Array.isArray(m);if(k&&T){var M=\"_input_\"+a,S=t[M],E=e[M];if(Array.isArray(S)&&S===E)continue}if(void 0===m)w&&k?u.calc=!0:d();else if(i._isLinkedToArray){var C=[],L=!1;f||(u.arrays[a]=C);var P=Math.min(v.length,m.length),O=Math.max(v.length,m.length);if(P!==O){if(\"arraydraw\"!==i.editType){d();continue}L=!0}for(b=0;b<P;b++)st(v[b],m[b],y.concat(b),o.extendFlat({inArray:a,arrayIndex:b},n));if(L)for(b=P;b<O;b++)C.push(b)}else!_&&o.isPlainObject(v)?st(v,m,y,n):w?k&&T?(h&&(u.calc=!0),(h||n.newDataRevision)&&d()):k!==T?u.calc=!0:d():k&&T&&v.length===m.length&&String(v)===String(m)||d()}}}for(a in e)if(!(a in t||\"_\"===a.charAt(0)||\"function\"==typeof e[a])){if(g(i=c(r.concat(a)))&&Array.isArray(e[a]))return void(u.calc=!0);d()}}function lt(t){var e=n.select(t),r=t._fullLayout;if(r._container=e.selectAll(\".plot-container\").data([0]),r._container.enter().insert(\"div\",\":first-child\").classed(\"plot-container\",!0).classed(\"plotly\",!0),r._paperdiv=r._container.selectAll(\".svg-container\").data([0]),r._paperdiv.enter().append(\"div\").classed(\"svg-container\",!0).style(\"position\",\"relative\"),r._glcontainer=r._paperdiv.selectAll(\".gl-container\").data([{}]),r._glcontainer.enter().append(\"div\").classed(\"gl-container\",!0),r._paperdiv.selectAll(\".main-svg\").remove(),r._paperdiv.select(\".modebar-container\").remove(),r._paper=r._paperdiv.insert(\"svg\",\":first-child\").classed(\"main-svg\",!0),r._toppaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),r._modebardiv=r._paperdiv.append(\"div\"),r._hoverpaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),!r._uid){var i={};n.selectAll(\"defs\").each(function(){this.id&&(i[this.id.split(\"-\")[1]]=1)}),r._uid=o.randstr(i)}r._paperdiv.selectAll(\".main-svg\").attr(y.svgAttrs),r._defs=r._paper.append(\"defs\").attr(\"id\",\"defs-\"+r._uid),r._clips=r._defs.append(\"g\").classed(\"clips\",!0),r._topdefs=r._toppaper.append(\"defs\").attr(\"id\",\"topdefs-\"+r._uid),r._topclips=r._topdefs.append(\"g\").classed(\"clips\",!0),r._bgLayer=r._paper.append(\"g\").classed(\"bglayer\",!0),r._draggers=r._paper.append(\"g\").classed(\"draglayer\",!0);var a=r._paper.append(\"g\").classed(\"layer-below\",!0);r._imageLowerLayer=a.append(\"g\").classed(\"imagelayer\",!0),r._shapeLowerLayer=a.append(\"g\").classed(\"shapelayer\",!0),r._cartesianlayer=r._paper.append(\"g\").classed(\"cartesianlayer\",!0),r._polarlayer=r._paper.append(\"g\").classed(\"polarlayer\",!0),r._ternarylayer=r._paper.append(\"g\").classed(\"ternarylayer\",!0),r._geolayer=r._paper.append(\"g\").classed(\"geolayer\",!0),r._funnelarealayer=r._paper.append(\"g\").classed(\"funnelarealayer\",!0),r._pielayer=r._paper.append(\"g\").classed(\"pielayer\",!0),r._sunburstlayer=r._paper.append(\"g\").classed(\"sunburstlayer\",!0),r._indicatorlayer=r._toppaper.append(\"g\").classed(\"indicatorlayer\",!0),r._glimages=r._paper.append(\"g\").classed(\"glimages\",!0);var s=r._toppaper.append(\"g\").classed(\"layer-above\",!0);r._imageUpperLayer=s.append(\"g\").classed(\"imagelayer\",!0),r._shapeUpperLayer=s.append(\"g\").classed(\"shapelayer\",!0),r._infolayer=r._toppaper.append(\"g\").classed(\"infolayer\",!0),r._menulayer=r._toppaper.append(\"g\").classed(\"menulayer\",!0),r._zoomlayer=r._toppaper.append(\"g\").classed(\"zoomlayer\",!0),r._hoverlayer=r._hoverpaper.append(\"g\").classed(\"hoverlayer\",!0),r._modebardiv.classed(\"modebar-container\",!0).style(\"position\",\"absolute\").style(\"top\",\"0px\").style(\"right\",\"0px\"),t.emit(\"plotly_framework\")}r.animate=function(t,e,r){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before animating it. For more details, see https://plot.ly/javascript/animations/\");var n=t._transitionData;n._frameQueue||(n._frameQueue=[]);var i=(r=f.supplyAnimationDefaults(r)).transition,a=r.frame;function s(t){return Array.isArray(i)?t>=i.length?i[0]:i[t]:i}function l(t){return Array.isArray(a)?t>=a.length?a[0]:a[t]:a}function c(t,e){var r=0;return function(){if(t&&++r===e)return t()}}return void 0===n._frameWaitingCnt&&(n._frameWaitingCnt=0),new Promise(function(a,u){function h(){n._currentFrame&&n._currentFrame.onComplete&&n._currentFrame.onComplete();var e=n._currentFrame=n._frameQueue.shift();if(e){var r=e.name?e.name.toString():null;t._fullLayout._currentFrame=r,n._lastFrameAt=Date.now(),n._timeToNext=e.frameOpts.duration,f.transition(t,e.frame.data,e.frame.layout,k.coerceTraceIndices(t,e.frame.traces),e.frameOpts,e.transitionOpts).then(function(){e.onComplete&&e.onComplete()}),t.emit(\"plotly_animatingframe\",{name:r,frame:e.frame,animation:{frame:e.frameOpts,transition:e.transitionOpts}})}else t.emit(\"plotly_animated\"),window.cancelAnimationFrame(n._animationRaf),n._animationRaf=null}function p(){t.emit(\"plotly_animating\"),n._lastFrameAt=-1/0,n._timeToNext=0,n._runningTransitions=0,n._currentFrame=null;var e=function(){n._animationRaf=window.requestAnimationFrame(e),Date.now()-n._lastFrameAt>n._timeToNext&&h()};e()}var d,g,v=0;function m(t){return Array.isArray(i)?v>=i.length?t.transitionOpts=i[v]:t.transitionOpts=i[0]:t.transitionOpts=i,v++,t}var y=[],x=null==e,b=Array.isArray(e);if(x||b||!o.isPlainObject(e)){if(x||-1!==[\"string\",\"number\"].indexOf(typeof e))for(d=0;d<n._frames.length;d++)(g=n._frames[d])&&(x||String(g.group)===String(e))&&y.push({type:\"byname\",name:String(g.name),data:m({name:g.name})});else if(b)for(d=0;d<e.length;d++){var _=e[d];-1!==[\"number\",\"string\"].indexOf(typeof _)?(_=String(_),y.push({type:\"byname\",name:_,data:m({name:_})})):o.isPlainObject(_)&&y.push({type:\"object\",data:m(o.extendFlat({},_))})}}else y.push({type:\"object\",data:m(o.extendFlat({},e))});for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&!n._frameHash[g.data.name])return o.warn('animate failure: frame not found: \"'+g.data.name+'\"'),void u();-1!==[\"next\",\"immediate\"].indexOf(r.mode)&&function(){if(0!==n._frameQueue.length){for(;n._frameQueue.length;){var e=n._frameQueue.pop();e.onInterrupt&&e.onInterrupt()}t.emit(\"plotly_animationinterrupted\",[])}}(),\"reverse\"===r.direction&&y.reverse();var w=t._fullLayout._currentFrame;if(w&&r.fromcurrent){var T=-1;for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&g.name===w){T=d;break}if(T>0&&T<y.length-1){var A=[];for(d=0;d<y.length;d++)g=y[d],(\"byname\"!==y[d].type||d>T)&&A.push(g);y=A}}y.length>0?function(e){if(0!==e.length){for(var i=0;i<e.length;i++){var o;o=\"byname\"===e[i].type?f.computeFrame(t,e[i].name):e[i].data;var h=l(i),d=s(i);d.duration=Math.min(d.duration,h.duration);var g={frame:o,name:e[i].name,frameOpts:h,transitionOpts:d};i===e.length-1&&(g.onComplete=c(a,2),g.onInterrupt=u),n._frameQueue.push(g)}\"immediate\"===r.mode&&(n._lastFrameAt=-1/0),n._animationRaf||p()}}(y):(t.emit(\"plotly_animated\"),a())})},r.addFrames=function(t,e,r){if(t=o.getGraphDiv(t),null==e)return Promise.resolve();if(!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before adding frames. For more details, see https://plot.ly/javascript/animations/\");var n,i,a,s,l=t._transitionData._frames,u=t._transitionData._frameHash;if(!Array.isArray(e))throw new Error(\"addFrames failure: frameList must be an Array of frame definitions\"+e);var h=l.length+2*e.length,p=[],d={};for(n=e.length-1;n>=0;n--)if(o.isPlainObject(e[n])){var g=e[n].name,v=(u[g]||d[g]||{}).name,m=e[n].name,y=u[v]||d[v];v&&m&&\"number\"==typeof m&&y&&S<E&&(S++,o.warn('addFrames: overwriting frame \"'+(u[v]||d[v]).name+'\" with a frame whose name of type \"number\" also equates to \"'+v+'\". This is valid but may potentially lead to unexpected behavior since all plotly.js frame names are stored internally as strings.'),S===E&&o.warn(\"addFrames: This API call has yielded too many of these warnings. For the rest of this call, further warnings about numeric frame names will be suppressed.\")),d[g]={name:g},p.push({frame:f.supplyFrameDefaults(e[n]),index:r&&void 0!==r[n]&&null!==r[n]?r[n]:h+n})}p.sort(function(t,e){return t.index>e.index?-1:t.index<e.index?1:0});var x=[],b=[],_=l.length;for(n=p.length-1;n>=0;n--){if(\"number\"==typeof(i=p[n].frame).name&&o.warn(\"Warning: addFrames accepts frames with numeric names, but the numbers areimplicitly cast to strings\"),!i.name)for(;u[i.name=\"frame \"+t._transitionData._counter++];);if(u[i.name]){for(a=0;a<l.length&&(l[a]||{}).name!==i.name;a++);x.push({type:\"replace\",index:a,value:i}),b.unshift({type:\"replace\",index:a,value:l[a]})}else s=Math.max(0,Math.min(p[n].index,_)),x.push({type:\"insert\",index:s,value:i}),b.unshift({type:\"delete\",index:s}),_++}var w=f.modifyFrames,k=f.modifyFrames,T=[t,b],A=[t,x];return c&&c.add(t,w,T,k,A),f.modifyFrames(t,x)},r.deleteFrames=function(t,e){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);var r,n,i=t._transitionData._frames,a=[],s=[];if(!e)for(e=[],r=0;r<i.length;r++)e.push(r);for((e=e.slice()).sort(),r=e.length-1;r>=0;r--)n=e[r],a.push({type:\"delete\",index:n}),s.unshift({type:\"insert\",index:n,value:i[n]});var l=f.modifyFrames,u=f.modifyFrames,h=[t,s],p=[t,a];return c&&c.add(t,l,h,u,p),f.modifyFrames(t,a)},r.addTraces=function t(e,n,i){e=o.getGraphDiv(e);var a,s,l=[],u=r.deleteTraces,h=t,f=[e,l],p=[e,n];for(function(t,e,r){var n,i;if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"traces must be defined.\");for(Array.isArray(e)||(e=[e]),n=0;n<e.length;n++)if(\"object\"!=typeof(i=e[n])||Array.isArray(i)||null===i)throw new Error(\"all values in traces array must be non-array objects\");if(\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&r.length!==e.length)throw new Error(\"if indices is specified, traces.length must equal indices.length\")}(e,n,i),Array.isArray(n)||(n=[n]),n=n.map(function(t){return o.extendFlat({},t)}),k.cleanData(n),a=0;a<n.length;a++)e.data.push(n[a]);for(a=0;a<n.length;a++)l.push(-n.length+a);if(\"undefined\"==typeof i)return s=r.redraw(e),c.add(e,u,f,h,p),s;Array.isArray(i)||(i=[i]);try{D(e,l,i)}catch(t){throw e.data.splice(e.data.length-n.length,n.length),t}return c.startSequence(e),c.add(e,u,f,h,p),s=r.moveTraces(e,l,i),c.stopSequence(e),s},r.deleteTraces=function t(e,n){e=o.getGraphDiv(e);var i,a,s=[],l=r.addTraces,u=t,h=[e,s,n],f=[e,n];if(\"undefined\"==typeof n)throw new Error(\"indices must be an integer or array of integers.\");for(Array.isArray(n)||(n=[n]),I(e,n,\"indices\"),(n=z(n,e.data.length-1)).sort(o.sorterDes),i=0;i<n.length;i+=1)a=e.data.splice(n[i],1)[0],s.push(a);var p=r.redraw(e);return c.add(e,l,h,u,f),p},r.extendTraces=function t(e,n,i,a){var s=R(e=o.getGraphDiv(e),n,i,a,function(t,e,r){var n,i;if(o.isTypedArray(t))if(r<0){var a=new t.constructor(0),s=F(t,e);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(l)),i.set(t),i.set(e.subarray(0,l),t.length)}else{var c=r-e.length,u=t.length-c;n.set(t.subarray(u)),n.set(e,c),i.set(t.subarray(0,u))}else n=t.concat(e),i=r>=0&&r<n.length?n.splice(0,n.length-r):[];return[n,i]}),l=r.redraw(e),u=[e,s.update,i,s.maxPoints];return c.add(e,r.prependTraces,u,t,arguments),l},r.moveTraces=function t(e,n,i){var a,s=[],l=[],u=t,h=t,f=[e=o.getGraphDiv(e),i,n],p=[e,n,i];if(D(e,n,i),n=Array.isArray(n)?n:[n],\"undefined\"==typeof i)for(i=[],a=0;a<n.length;a++)i.push(-n.length+a);for(i=Array.isArray(i)?i:[i],n=z(n,e.data.length-1),i=z(i,e.data.length-1),a=0;a<e.data.length;a++)-1===n.indexOf(a)&&s.push(e.data[a]);for(a=0;a<n.length;a++)l.push({newIndex:i[a],trace:e.data[n[a]]});for(l.sort(function(t,e){return t.newIndex-e.newIndex}),a=0;a<l.length;a+=1)s.splice(l[a].newIndex,0,l[a].trace);e.data=s;var d=r.redraw(e);return c.add(e,u,f,h,p),d},r.prependTraces=function t(e,n,i,a){var s=R(e=o.getGraphDiv(e),n,i,a,function(t,e,r){var n,i;if(o.isTypedArray(t))if(r<=0){var a=new t.constructor(0),s=F(e,t);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(0,l)),i.set(e.subarray(l)),i.set(t,l)}else{var c=r-e.length;n.set(e),n.set(t.subarray(0,c),e.length),i.set(t.subarray(c))}else n=e.concat(t),i=r>=0&&r<n.length?n.splice(r,n.length):[];return[n,i]}),l=r.redraw(e),u=[e,s.update,i,s.maxPoints];return c.add(e,r.extendTraces,u,t,arguments),l},r.newPlot=function(t,e,n,i){return t=o.getGraphDiv(t),f.cleanPlot([],{},t._fullData||[],t._fullLayout||{}),f.purge(t),r.plot(t,e,n,i)},r.plot=function(t,e,i,a){var s;if(t=o.getGraphDiv(t),l.init(t),o.isPlainObject(e)){var c=e;e=c.data,i=c.layout,a=c.config,s=c.frames}if(!1===l.triggerHandler(t,\"plotly_beforeplot\",[e,i,a]))return Promise.reject();e||i||o.isPlotDiv(t)||o.warn(\"Calling Plotly.plot as if redrawing but this container doesn't yet have a plot.\",t),O(t,a),i||(i={}),n.select(t).classed(\"js-plotly-plot\",!0),g.makeTester(),Array.isArray(t._promises)||(t._promises=[]);var h=0===(t.data||[]).length&&Array.isArray(e);Array.isArray(e)&&(k.cleanData(e),h?t.data=e:t.data.push.apply(t.data,e),t.empty=!1),t.layout&&!h||(t.layout=k.cleanLayout(i)),f.supplyDefaults(t);var v=t._fullLayout,y=v._has(\"cartesian\");if(!v._has(\"polar\")&&e&&e[0]&&e[0].r)return o.log(\"Legacy polar charts are deprecated!\"),function(t,e,r){var i=n.select(t).selectAll(\".plot-container\").data([0]);i.enter().insert(\"div\",\":first-child\").classed(\"plot-container plotly\",!0);var a=i.selectAll(\".svg-container\").data([0]);a.enter().append(\"div\").classed(\"svg-container\",!0).style(\"position\",\"relative\"),a.html(\"\"),e&&(t.data=e),r&&(t.layout=r),p.manager.fillLayout(t),a.style({width:t._fullLayout.width+\"px\",height:t._fullLayout.height+\"px\"}),t.framework=p.manager.framework(t),t.framework({data:t.data,layout:t.layout},a.node()),t.framework.setUndoPoint();var s=t.framework.svg(),l=1,c=t._fullLayout.title?t._fullLayout.title.text:\"\";\"\"!==c&&c||(l=0);var u=function(){this.call(x.convertToTspans,t)},h=s.select(\".title-group text\").call(u);if(t._context.edits.titleText){var d=o._(t,\"Click to enter Plot title\");c&&c!==d||(l=.2,h.attr({\"data-unformatted\":d}).text(d).style({opacity:l}).on(\"mouseover.opacity\",function(){n.select(this).transition().duration(100).style(\"opacity\",1)}).on(\"mouseout.opacity\",function(){n.select(this).transition().duration(1e3).style(\"opacity\",0)}));var g=function(){this.call(x.makeEditable,{gd:t}).on(\"edit\",function(e){t.framework({layout:{title:{text:e}}}),this.text(e).call(u),this.call(g)}).on(\"cancel\",function(){var t=this.attr(\"data-unformatted\");this.text(t).call(u)})};h.call(g)}return t._context.setBackground(t,t._fullLayout.paper_bgcolor),f.addLinks(t),Promise.resolve()}(t,e,i);v._replotting=!0,h&&lt(t),t.framework!==lt&&(t.framework=lt,lt(t)),g.initGradients(t),h&&d.saveShowSpikeInitial(t);var b=!t.calcdata||t.calcdata.length!==(t._fullData||[]).length;b&&f.doCalcdata(t);for(var _=0;_<t.calcdata.length;_++)t.calcdata[_][0].trace=t._fullData[_];t._context.responsive?t._responsiveChartHandler||(t._responsiveChartHandler=function(){o.isHidden(t)||f.resize(t)},window.addEventListener(\"resize\",t._responsiveChartHandler)):o.clearResponsive(t);var w=o.extendFlat({},v._size),A=0;function M(){return f.clearAutoMarginIds(t),T.drawMarginPushers(t),d.allowAutoMargin(t),f.doAutoMargin(t),f.previousPromises(t)}function S(){t._transitioning||(T.doAutoRangeAndConstraints(t),h&&d.saveRangeInitial(t),u.getComponentMethod(\"rangeslider\",\"calcAutorange\")(t))}var E=[f.previousPromises,function(){if(s)return r.addFrames(t,s)},function e(){for(var r=v._basePlotModules,n=0;n<r.length;n++)r[n].drawFramework&&r[n].drawFramework(t);if(!v._glcanvas&&v._has(\"gl\")&&(v._glcanvas=v._glcontainer.selectAll(\".gl-canvas\").data([{key:\"contextLayer\",context:!0,pick:!1},{key:\"focusLayer\",context:!1,pick:!1},{key:\"pickLayer\",context:!1,pick:!0}],function(t){return t.key}),v._glcanvas.enter().append(\"canvas\").attr(\"class\",function(t){return\"gl-canvas gl-canvas-\"+t.key.replace(\"Layer\",\"\")}).style({position:\"absolute\",top:0,left:0,overflow:\"visible\",\"pointer-events\":\"none\"})),v._glcanvas){v._glcanvas.attr(\"width\",v.width).attr(\"height\",v.height);var i=v._glcanvas.data()[0].regl;if(i&&(Math.floor(v.width)!==i._gl.drawingBufferWidth||Math.floor(v.height)!==i._gl.drawingBufferHeight)){var a=\"WebGL context buffer and canvas dimensions do not match due to browser/WebGL bug.\";if(!A)return o.log(a+\" Clearing graph and plotting again.\"),f.cleanPlot([],{},t._fullData,v),f.supplyDefaults(t),v=t._fullLayout,f.doCalcdata(t),A++,e();o.error(a)}}return\"h\"===v.modebar.orientation?v._modebardiv.style(\"height\",null).style(\"width\",\"100%\"):v._modebardiv.style(\"width\",null).style(\"height\",v.height+\"px\"),f.previousPromises(t)},M,function(){if(f.didMarginChange(w,v._size))return o.syncOrAsync([M,T.layoutStyles],t)}];y&&E.push(function(){if(b)return o.syncOrAsync([u.getComponentMethod(\"shapes\",\"calcAutorange\"),u.getComponentMethod(\"annotations\",\"calcAutorange\"),S],t);S()}),E.push(T.layoutStyles),y&&E.push(function(){return d.draw(t,h?\"\":\"redraw\")}),E.push(T.drawData,T.finalDraw,m,f.addLinks,f.rehover,f.redrag,f.doAutoMargin,f.previousPromises);var L=o.syncOrAsync(E,t);return L&&L.then||(L=Promise.resolve()),L.then(function(){return C(t),t})},r.purge=function(t){var e=(t=o.getGraphDiv(t))._fullLayout||{},r=t._fullData||[];return f.cleanPlot([],{},r,e),f.purge(t),l.purge(t),e._container&&e._container.remove(),delete t._context,t},r.react=function(t,e,n,i){var a,l,c=(t=o.getGraphDiv(t))._fullData,p=t._fullLayout;if(o.isPlotDiv(t)&&c&&p){if(o.isPlainObject(e)){var d=e;e=d.data,n=d.layout,i=d.config,a=d.frames}var g=!1;if(i){var v=o.extendDeep({},t._context);t._context=void 0,O(t,i),g=function t(e,r){var n;for(n in e)if(\"_\"!==n.charAt(0)){var i=e[n],a=r[n];if(i!==a)if(o.isPlainObject(i)&&o.isPlainObject(a)){if(t(i,a))return!0}else{if(!Array.isArray(i)||!Array.isArray(a))return!0;if(i.length!==a.length)return!0;for(var s=0;s<i.length;s++)if(i[s]!==a[s]){if(!o.isPlainObject(i[s])||!o.isPlainObject(a[s]))return!0;if(t(i[s],a[s]))return!0}}}}(v,t._context)}t.data=e||[],k.cleanData(t.data),t.layout=n||{},k.cleanLayout(t.layout),function(t,e,r,n){var i,a,l,c,u,h,f,p,d=n._preGUI,g=[],v={};for(i in d){if(u=rt(i,tt)){if(a=u.attr||u.head+\".uirevision\",(c=(l=s(n,a).get())&&nt(a,e))&&c===l&&(null===(h=d[i])&&(h=void 0),ot(p=(f=s(e,i)).get(),h))){void 0===p&&\"autorange\"===i.substr(i.length-9)&&g.push(i.substr(0,i.length-10)),f.set(N(s(n,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i);delete d[i],\"range[\"===i.substr(i.length-8,6)&&(v[i.substr(0,i.length-9)]=1)}for(var m=0;m<g.length;m++){var y=g[m];if(v[y]){var x=s(e,y).get();x&&delete x.autorange}}var b=n._tracePreGUI;for(var _ in b){var w,k=b[_],T=null;for(i in k){if(!T){var A=it(_,r);if(A<0){delete b[_];break}var M=at(_,t,(w=r[A]._fullInput).index);if(M<0){delete b[_];break}T=t[M]}if(u=rt(i,et)){if(u.attr?c=(l=s(n,u.attr).get())&&nt(u.attr,e):(l=w.uirevision,void 0===(c=T.uirevision)&&(c=e.uirevision)),c&&c===l&&(null===(h=k[i])&&(h=void 0),ot(p=(f=s(T,i)).get(),h))){f.set(N(s(w,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i+\" in trace uid \"+_);delete k[i]}}}(t.data,t.layout,c,p),f.supplyDefaults(t,{skipUpdateCalc:!0});var m=t._fullData,y=t._fullLayout,x=void 0===y.datarevision,b=y.transition,_=function(t,e,r,n,i){var a=A.layoutFlags();return a.arrays={},a.rangesAltered={},a.nChanges=0,a.nChangesAnim=0,st(e,r,[],{getValObject:function(t){return h.getLayoutValObject(r,t)},flags:a,immutable:n,transition:i,gd:t}),(a.plot||a.calc)&&(a.layoutReplot=!0),i&&a.nChanges&&a.nChangesAnim&&(a.anim=a.nChanges===a.nChangesAnim?\"all\":\"some\"),a}(t,p,y,x,b),w=_.newDataRevision,M=function(t,e,r,n,i,a){var o=e.length===r.length;if(!i&&!o)return{fullReplot:!0,calc:!0};var s,l,c=A.traceFlags();c.arrays={},c.nChanges=0,c.nChangesAnim=0;var u={getValObject:function(t){var e=h.getTraceValObject(l,t);return!l._module.animatable&&e.anim&&(e.anim=!1),e},flags:c,immutable:n,transition:i,newDataRevision:a,gd:t},p={};for(s=0;s<e.length;s++)if(r[s]){if(l=r[s]._fullInput,f.hasMakesDataTransform(l)&&(l=r[s]),p[l.uid])continue;p[l.uid]=1,st(e[s]._fullInput,l,[],u)}return(c.calc||c.plot)&&(c.fullReplot=!0),i&&c.nChanges&&c.nChangesAnim&&(c.anim=c.nChanges===c.nChangesAnim&&o?\"all\":\"some\"),c}(t,c,m,x,b,w);K(t)&&(_.layoutReplot=!0),M.calc||_.calc?t.calcdata=void 0:f.supplyDefaultsUpdateCalc(t.calcdata,m);var S=[];if(a&&(t._transitionData={},f.createTransitionData(t),S.push(function(){return r.addFrames(t,a)})),y.transition&&!g&&(M.anim||_.anim))f.doCalcdata(t),T.doAutoRangeAndConstraints(t),S.push(function(){return f.transitionFromReact(t,M,_,p)});else if(M.fullReplot||_.layoutReplot||g)t._fullLayout._skipDefaults=!0,S.push(r.plot);else{for(var E in _.arrays){var L=_.arrays[E];if(L.length){var P=u.getComponentMethod(E,\"drawOne\");if(P!==o.noop)for(var z=0;z<L.length;z++)P(t,L[z]);else{var I=u.getComponentMethod(E,\"draw\");if(I===o.noop)throw new Error(\"cannot draw components: \"+E);I(t)}}}S.push(f.previousPromises),M.style&&S.push(T.doTraceStyle),(M.colorbars||_.colorbars)&&S.push(T.doColorBars),_.legend&&S.push(T.doLegend),_.layoutstyle&&S.push(T.layoutStyles),_.axrange&&Y(S),_.ticks&&S.push(T.doTicksRelayout),_.modebar&&S.push(T.doModeBar),_.camera&&S.push(T.doCamera),S.push(C)}S.push(f.rehover,f.redrag),(l=o.syncOrAsync(S,t))&&l.then||(l=Promise.resolve(t))}else l=r.newPlot(t,e,n,i);return l.then(function(){return t.emit(\"plotly_react\",{data:e,layout:n}),t})},r.redraw=function(t){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);return k.cleanData(t.data),k.cleanLayout(t.layout),t.calcdata=void 0,r.plot(t).then(function(){return t.emit(\"plotly_redraw\"),t})},r.relayout=H,r.restyle=B,r.setPlotConfig=function(t){return o.extendFlat(_,t)},r.update=$,r._guiRelayout=Q(H),r._guiRestyle=Q(B),r._guiUpdate=Q($),r._storeDirectGUIEdit=function(t,e,r){for(var n in r)U(n,s(t,n).get(),r[n],e)}},{\"../components/color\":593,\"../components/drawing\":614,\"../constants/xmlns_namespaces\":696,\"../lib\":719,\"../lib/events\":709,\"../lib/queue\":734,\"../lib/svg_text_utils\":743,\"../plots/cartesian/axes\":767,\"../plots/cartesian/constants\":773,\"../plots/cartesian/graph_interact\":776,\"../plots/cartesian/select\":784,\"../plots/plots\":828,\"../plots/polar/legacy\":836,\"../registry\":847,\"./edit_types\":750,\"./helpers\":751,\"./manage_arrays\":753,\"./plot_config\":755,\"./plot_schema\":756,\"./subroutines\":758,d3:163,\"fast-isnumeric\":225,\"has-hover\":410}],755:[function(t,e,r){\"use strict\";var n={staticPlot:{valType:\"boolean\",dflt:!1},plotlyServerURL:{valType:\"string\",dflt:\"https://plot.ly\"},editable:{valType:\"boolean\",dflt:!1},edits:{annotationPosition:{valType:\"boolean\",dflt:!1},annotationTail:{valType:\"boolean\",dflt:!1},annotationText:{valType:\"boolean\",dflt:!1},axisTitleText:{valType:\"boolean\",dflt:!1},colorbarPosition:{valType:\"boolean\",dflt:!1},colorbarTitleText:{valType:\"boolean\",dflt:!1},legendPosition:{valType:\"boolean\",dflt:!1},legendText:{valType:\"boolean\",dflt:!1},shapePosition:{valType:\"boolean\",dflt:!1},titleText:{valType:\"boolean\",dflt:!1}},autosizable:{valType:\"boolean\",dflt:!1},responsive:{valType:\"boolean\",dflt:!1},fillFrame:{valType:\"boolean\",dflt:!1},frameMargins:{valType:\"number\",dflt:0,min:0,max:.5},scrollZoom:{valType:\"flaglist\",flags:[\"cartesian\",\"gl3d\",\"geo\",\"mapbox\"],extras:[!0,!1],dflt:\"gl3d+geo+mapbox\"},doubleClick:{valType:\"enumerated\",values:[!1,\"reset\",\"autosize\",\"reset+autosize\"],dflt:\"reset+autosize\"},doubleClickDelay:{valType:\"number\",dflt:300,min:0},showAxisDragHandles:{valType:\"boolean\",dflt:!0},showAxisRangeEntryBoxes:{valType:\"boolean\",dflt:!0},showTips:{valType:\"boolean\",dflt:!0},showLink:{valType:\"boolean\",dflt:!1},linkText:{valType:\"string\",dflt:\"Edit chart\",noBlank:!0},sendData:{valType:\"boolean\",dflt:!0},showSources:{valType:\"any\",dflt:!1},displayModeBar:{valType:\"enumerated\",values:[\"hover\",!0,!1],dflt:\"hover\"},showSendToCloud:{valType:\"boolean\",dflt:!1},showEditInChartStudio:{valType:\"boolean\",dflt:!1},modeBarButtonsToRemove:{valType:\"any\",dflt:[]},modeBarButtonsToAdd:{valType:\"any\",dflt:[]},modeBarButtons:{valType:\"any\",dflt:!1},toImageButtonOptions:{valType:\"any\",dflt:{}},displaylogo:{valType:\"boolean\",dflt:!0},watermark:{valType:\"boolean\",dflt:!1},plotGlPixelRatio:{valType:\"number\",dflt:2,min:1,max:4},setBackground:{valType:\"any\",dflt:\"transparent\"},topojsonURL:{valType:\"string\",noBlank:!0,dflt:\"https://cdn.plot.ly/\"},mapboxAccessToken:{valType:\"string\",dflt:null},logging:{valType:\"boolean\",dflt:1},queueLength:{valType:\"integer\",min:0,dflt:0},globalTransforms:{valType:\"any\",dflt:[]},locale:{valType:\"string\",dflt:\"en-US\"},locales:{valType:\"any\",dflt:{}}},i={};!function t(e,r){for(var n in e){var i=e[n];i.valType?r[n]=i.dflt:(r[n]||(r[n]={}),t(i,r[n]))}}(n,i),e.exports={configAttributes:n,dfltConfig:i}},{}],756:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=t(\"../plots/attributes\"),o=t(\"../plots/layout_attributes\"),s=t(\"../plots/frame_attributes\"),l=t(\"../plots/animation_attributes\"),c=t(\"./plot_config\").configAttributes,u=t(\"../plots/polar/legacy/area_attributes\"),h=t(\"../plots/polar/legacy/axis_attributes\"),f=t(\"./edit_types\"),p=i.extendFlat,d=i.extendDeepAll,g=i.isPlainObject,v=i.isArrayOrTypedArray,m=i.nestedProperty,y=i.valObjectMeta,x=\"_isSubplotObj\",b=\"_isLinkedToArray\",_=[x,b,\"_arrayAttrRegexps\",\"_deprecated\"];function w(t,e,r){if(!t)return!1;if(t._isLinkedToArray)if(k(e[r]))r++;else if(r<e.length)return!1;for(;r<e.length;r++){var n=t[e[r]];if(!g(n))break;if(t=n,r===e.length-1)break;if(t._isLinkedToArray){if(!k(e[++r]))return!1}else if(\"info_array\"===t.valType){var i=e[++r];if(!k(i))return!1;var a=t.items;if(Array.isArray(a)){if(i>=a.length)return!1;if(2===t.dimensions){if(r++,e.length===r)return t;var o=e[r];if(!k(o))return!1;t=a[i][o]}else t=a[i]}else t=a}}return t}function k(t){return t===Math.round(t)&&t>=0}function T(t){return function(t){r.crawl(t,function(t,e,n){r.isValObject(t)?\"data_array\"===t.valType?(t.role=\"data\",n[e+\"src\"]={valType:\"string\",editType:\"none\"}):!0===t.arrayOk&&(n[e+\"src\"]={valType:\"string\",editType:\"none\"}):g(t)&&(t.role=\"object\")})}(t),function(t){r.crawl(t,function(t,e,r){if(!t)return;var n=t[b];if(!n)return;delete t[b],r[e]={items:{}},r[e].items[n]=t,r[e].role=\"object\"})}(t),function(t){!function t(e){for(var r in e)if(g(e[r]))t(e[r]);else if(Array.isArray(e[r]))for(var n=0;n<e[r].length;n++)t(e[r][n]);else e[r]instanceof RegExp&&(e[r]=e[r].toString())}(t)}(t),t}function A(t,e,r){var n=m(t,r),i=d({},e.layoutAttributes);i[x]=!0,n.set(i)}function M(t,e,r){var n=m(t,r);n.set(d(n.get()||{},e))}r.IS_SUBPLOT_OBJ=x,r.IS_LINKED_TO_ARRAY=b,r.DEPRECATED=\"_deprecated\",r.UNDERSCORE_ATTRS=_,r.get=function(){var t={};n.allTypes.concat(\"area\").forEach(function(e){t[e]=function(t){var e,i;\"area\"===t?(e={attributes:u},i={}):(e=n.modules[t]._module,i=e.basePlotModule);var o={type:null},s=d({},a),l=d({},e.attributes);r.crawl(l,function(t,e,r,n,i){m(s,i).set(void 0),void 0===t&&m(l,i).set(void 0)}),d(o,s),n.traceIs(t,\"noOpacity\")&&delete o.opacity;n.traceIs(t,\"showLegend\")||(delete o.showlegend,delete o.legendgroup);n.traceIs(t,\"noHover\")&&(delete o.hoverinfo,delete o.hoverlabel);e.selectPoints||delete o.selectedpoints;d(o,l),i.attributes&&d(o,i.attributes);o.type=t;var c={meta:e.meta||{},categories:e.categories||{},animatable:Boolean(e.animatable),type:t,attributes:T(o)};if(e.layoutAttributes){var h={};d(h,e.layoutAttributes),c.layoutAttributes=T(h)}e.animatable||r.crawl(c,function(t){r.isValObject(t)&&\"anim\"in t&&delete t.anim});return c}(e)});var e,i={};return Object.keys(n.transformsRegistry).forEach(function(t){i[t]=function(t){var e=n.transformsRegistry[t],r=d({},e.attributes);return Object.keys(n.componentsRegistry).forEach(function(e){var i=n.componentsRegistry[e];i.schema&&i.schema.transforms&&i.schema.transforms[t]&&Object.keys(i.schema.transforms[t]).forEach(function(e){M(r,i.schema.transforms[t][e],e)})}),{attributes:T(r)}}(t)}),{defs:{valObjects:y,metaKeys:_.concat([\"description\",\"role\",\"editType\",\"impliedEdits\"]),editType:{traces:f.traces,layout:f.layout},impliedEdits:{}},traces:t,layout:function(){var t,e,r={};for(t in d(r,o),n.subplotsRegistry)if((e=n.subplotsRegistry[t]).layoutAttributes)if(Array.isArray(e.attr))for(var i=0;i<e.attr.length;i++)A(r,e,e.attr[i]);else{var a=\"subplot\"===e.attr?e.name:e.attr;A(r,e,a)}for(t in r=function(t){return p(t,{radialaxis:h.radialaxis,angularaxis:h.angularaxis}),p(t,h.layout),t}(r),n.componentsRegistry){var s=(e=n.componentsRegistry[t]).schema;if(s&&(s.subplots||s.layout)){var l=s.subplots;if(l&&l.xaxis&&!l.yaxis)for(var c in l.xaxis)delete r.yaxis[c]}else\"colorscale\"===e.name?d(r,e.layoutAttributes):e.layoutAttributes&&M(r,e.layoutAttributes,e.name)}return{layoutAttributes:T(r)}}(),transforms:i,frames:(e={frames:d({},s)},T(e),e.frames),animation:T(l),config:T(c)}},r.crawl=function(t,e,n,i){var a=n||0;i=i||\"\",Object.keys(t).forEach(function(n){var o=t[n];if(-1===_.indexOf(n)){var s=(i?i+\".\":\"\")+n;e(o,n,t,a,s),r.isValObject(o)||g(o)&&\"impliedEdits\"!==n&&r.crawl(o,e,a+1,s)}})},r.isValObject=function(t){return t&&void 0!==t.valType},r.findArrayAttributes=function(t){var e,n,i=[],o=[],s=[];function l(t,r,a,l){o=o.slice(0,l).concat([r]),s=s.slice(0,l).concat([t&&t._isLinkedToArray]),t&&(\"data_array\"===t.valType||!0===t.arrayOk)&&!(\"colorbar\"===o[l-1]&&(\"ticktext\"===r||\"tickvals\"===r))&&function t(e,r,a){var l=e[o[r]];var c=a+o[r];if(r===o.length-1)v(l)&&i.push(n+c);else if(s[r]){if(Array.isArray(l))for(var u=0;u<l.length;u++)g(l[u])&&t(l[u],r+1,c+\"[\"+u+\"].\")}else g(l)&&t(l,r+1,c+\".\")}(e,0,\"\")}e=t,n=\"\",r.crawl(a,l),t._module&&t._module.attributes&&r.crawl(t._module.attributes,l);var c=t.transforms;if(c)for(var u=0;u<c.length;u++){var h=c[u],f=h._module;f&&(n=\"transforms[\"+u+\"].\",e=h,r.crawl(f.attributes,l))}return i},r.getTraceValObject=function(t,e){var r,i,o=e[0],s=1;if(\"transforms\"===o){if(1===e.length)return a.transforms;var l=t.transforms;if(!Array.isArray(l)||!l.length)return!1;var c=e[1];if(!k(c)||c>=l.length)return!1;i=(r=(n.transformsRegistry[l[c].type]||{}).attributes)&&r[e[2]],s=3}else if(\"area\"===t.type)i=u[o];else{var h=t._module;if(h||(h=(n.modules[t.type||a.type.dflt]||{})._module),!h)return!1;if(!(i=(r=h.attributes)&&r[o])){var f=h.basePlotModule;f&&f.attributes&&(i=f.attributes[o])}i||(i=a[o])}return w(i,e,s)},r.getLayoutValObject=function(t,e){return w(function(t,e){var r,i,a,s,l=t._basePlotModules;if(l){var c;for(r=0;r<l.length;r++){if((a=l[r]).attrRegex&&a.attrRegex.test(e)){if(a.layoutAttrOverrides)return a.layoutAttrOverrides;!c&&a.layoutAttributes&&(c=a.layoutAttributes)}var u=a.baseLayoutAttrOverrides;if(u&&e in u)return u[e]}if(c)return c}var f=t._modules;if(f)for(r=0;r<f.length;r++)if((s=f[r].layoutAttributes)&&e in s)return s[e];for(i in n.componentsRegistry){if(\"colorscale\"===(a=n.componentsRegistry[i]).name&&0===e.indexOf(\"coloraxis\"))return a.layoutAttributes[e];if(!a.schema&&e===a.name)return a.layoutAttributes}if(e in o)return o[e];if(\"radialaxis\"===e||\"angularaxis\"===e)return h[e];return h.layout[e]||!1}(t,e[0]),e,1)}},{\"../lib\":719,\"../plots/animation_attributes\":762,\"../plots/attributes\":764,\"../plots/frame_attributes\":794,\"../plots/layout_attributes\":819,\"../plots/polar/legacy/area_attributes\":834,\"../plots/polar/legacy/axis_attributes\":835,\"../registry\":847,\"./edit_types\":750,\"./plot_config\":755}],757:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/attributes\"),a=\"templateitemname\",o={name:{valType:\"string\",editType:\"none\"}};function s(t){return t&&\"string\"==typeof t}function l(t){var e=t.length-1;return\"s\"!==t.charAt(e)&&n.warn(\"bad argument to arrayDefaultKey: \"+t),t.substr(0,t.length-1)+\"defaults\"}o[a]={valType:\"string\",editType:\"calc\"},r.templatedArray=function(t,e){return e._isLinkedToArray=t,e.name=o.name,e[a]=o[a],e},r.traceTemplater=function(t){var e,r,a={};for(e in t)r=t[e],Array.isArray(r)&&r.length&&(a[e]=0);return{newTrace:function(o){var s={type:e=n.coerce(o,{},i,\"type\"),_template:null};if(e in a){r=t[e];var l=a[e]%r.length;a[e]++,s._template=r[l]}return s}}},r.newContainer=function(t,e,r){var i=t._template,a=i&&(i[e]||r&&i[r]);return n.isPlainObject(a)||(a=null),t[e]={_template:a}},r.arrayTemplater=function(t,e,r){var n=t._template,i=n&&n[l(e)],o=n&&n[e];Array.isArray(o)&&o.length||(o=[]);var c={};return{newItem:function(t){var e={name:t.name,_input:t},n=e[a]=t[a];if(!s(n))return e._template=i,e;for(var l=0;l<o.length;l++){var u=o[l];if(u.name===n)return c[n]=1,e._template=u,e}return e[r]=t[r]||!1,e._template=!1,e},defaultItems:function(){for(var t=[],e=0;e<o.length;e++){var r=o[e],n=r.name;if(s(n)&&!c[n]){var i={_template:r,name:n,_input:{_templateitemname:n}};i[a]=r[a],t.push(i),c[n]=1}}return t}}},r.arrayDefaultKey=l,r.arrayEditor=function(t,e,r){var i=(n.nestedProperty(t,e).get()||[]).length,o=r._index,s=o>=i&&(r._input||{})._templateitemname;s&&(o=i);var l,c=e+\"[\"+o+\"]\";function u(){l={},s&&(l[c]={},l[c][a]=s)}function h(t,e){s?n.nestedProperty(l[c],t).set(e):l[c+\".\"+t]=e}function f(){var t=l;return u(),t}return u(),{modifyBase:function(t,e){l[t]=e},modifyItem:h,getUpdateObj:f,applyUpdate:function(e,r){e&&h(e,r);var i=f();for(var a in i)n.nestedProperty(t,a).set(i[a])}}}},{\"../lib\":719,\"../plots/attributes\":764}],758:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../registry\"),a=t(\"../plots/plots\"),o=t(\"../lib\"),s=t(\"../lib/clear_gl_canvases\"),l=t(\"../components/color\"),c=t(\"../components/drawing\"),u=t(\"../components/titles\"),h=t(\"../components/modebar\"),f=t(\"../plots/cartesian/axes\"),p=t(\"../constants/alignment\"),d=t(\"../plots/cartesian/constraints\"),g=d.enforce,v=d.clean,m=t(\"../plots/cartesian/autorange\").doAutoRange,y=\"start\",x=\"middle\",b=\"end\";function _(t,e,r){for(var n=0;n<r.length;n++){var i=r[n][0],a=r[n][1];if(!(i[0]>=t[1]||i[1]<=t[0])&&(a[0]<e[1]&&a[1]>e[0]))return!0}return!1}function w(t){var e,i,a,s,u,d,g=t._fullLayout,v=g._size,m=v.p,y=f.list(t,\"\",!0);if(g._paperdiv.style({width:t._context.responsive&&g.autosize&&!t._context._hasZeroWidth&&!t.layout.width?\"100%\":g.width+\"px\",height:t._context.responsive&&g.autosize&&!t._context._hasZeroHeight&&!t.layout.height?\"100%\":g.height+\"px\"}).selectAll(\".main-svg\").call(c.setSize,g.width,g.height),t._context.setBackground(t,g.paper_bgcolor),r.drawMainTitle(t),h.manage(t),!g._has(\"cartesian\"))return t._promises.length&&Promise.all(t._promises);function x(t,e,r){var n=t._lw/2;return\"x\"===t._id.charAt(0)?e?\"top\"===r?e._offset-m-n:e._offset+e._length+m+n:v.t+v.h*(1-(t.position||0))+n%1:e?\"right\"===r?e._offset+e._length+m+n:e._offset-m-n:v.l+v.w*(t.position||0)+n%1}for(e=0;e<y.length;e++){var b=(s=y[e])._anchorAxis;s._linepositions={},s._lw=c.crispRound(t,s.linewidth,1),s._mainLinePosition=x(s,b,s.side),s._mainMirrorPosition=s.mirror&&b?x(s,b,p.OPPOSITE_SIDE[s.side]):null}var w=[],T=[],M=[],S=1===l.opacity(g.paper_bgcolor)&&1===l.opacity(g.plot_bgcolor)&&g.paper_bgcolor===g.plot_bgcolor;for(i in g._plots)if((a=g._plots[i]).mainplot)a.bg&&a.bg.remove(),a.bg=void 0;else{var E=a.xaxis.domain,C=a.yaxis.domain,L=a.plotgroup;if(_(E,C,M)){var P=L.node(),O=a.bg=o.ensureSingle(L,\"rect\",\"bg\");P.insertBefore(O.node(),P.childNodes[0]),T.push(i)}else L.select(\"rect.bg\").remove(),M.push([E,C]),S||(w.push(i),T.push(i))}var z,I,D,R,F,B,N,j,U,V,q,H,G,Y=g._bgLayer.selectAll(\".bg\").data(w);for(Y.enter().append(\"rect\").classed(\"bg\",!0),Y.exit().remove(),Y.each(function(t){g._plots[t].bg=n.select(this)}),e=0;e<T.length;e++)a=g._plots[T[e]],u=a.xaxis,d=a.yaxis,a.bg&&a.bg.call(c.setRect,u._offset-m,d._offset-m,u._length+2*m,d._length+2*m).call(l.fill,g.plot_bgcolor).style(\"stroke-width\",0);if(!g._hasOnlyLargeSploms)for(i in g._plots){a=g._plots[i],u=a.xaxis,d=a.yaxis;var W,X,Z=a.clipId=\"clip\"+g._uid+i+\"plot\",J=o.ensureSingleById(g._clips,\"clipPath\",Z,function(t){t.classed(\"plotclip\",!0).append(\"rect\")});a.clipRect=J.select(\"rect\").attr({width:u._length,height:d._length}),c.setTranslate(a.plot,u._offset,d._offset),a._hasClipOnAxisFalse?(W=null,X=Z):(W=Z,X=null),c.setClipUrl(a.plot,W,t),a.layerClipId=X}function K(t){return\"M\"+z+\",\"+t+\"H\"+I}function $(t){return\"M\"+u._offset+\",\"+t+\"h\"+u._length}function Q(t){return\"M\"+t+\",\"+j+\"V\"+N}function tt(t){return\"M\"+t+\",\"+d._offset+\"v\"+d._length}function et(t,e,r){if(!t.showline||i!==t._mainSubplot)return\"\";if(!t._anchorAxis)return r(t._mainLinePosition);var n=e(t._mainLinePosition);return t.mirror&&(n+=e(t._mainMirrorPosition)),n}for(i in g._plots){a=g._plots[i],u=a.xaxis,d=a.yaxis;var rt=\"M0,0\";k(u,i)&&(F=A(u,\"left\",d,y),z=u._offset-(F?m+F:0),B=A(u,\"right\",d,y),I=u._offset+u._length+(B?m+B:0),D=x(u,d,\"bottom\"),R=x(u,d,\"top\"),!(G=!u._anchorAxis||i!==u._mainSubplot)||\"allticks\"!==u.mirror&&\"all\"!==u.mirror||(u._linepositions[i]=[D,R]),rt=et(u,K,$),G&&u.showline&&(\"all\"===u.mirror||\"allticks\"===u.mirror)&&(rt+=K(D)+K(R)),a.xlines.style(\"stroke-width\",u._lw+\"px\").call(l.stroke,u.showline?u.linecolor:\"rgba(0,0,0,0)\")),a.xlines.attr(\"d\",rt);var nt=\"M0,0\";k(d,i)&&(q=A(d,\"bottom\",u,y),N=d._offset+d._length+(q?m:0),H=A(d,\"top\",u,y),j=d._offset-(H?m:0),U=x(d,u,\"left\"),V=x(d,u,\"right\"),!(G=!d._anchorAxis||i!==d._mainSubplot)||\"allticks\"!==d.mirror&&\"all\"!==d.mirror||(d._linepositions[i]=[U,V]),nt=et(d,Q,tt),G&&d.showline&&(\"all\"===d.mirror||\"allticks\"===d.mirror)&&(nt+=Q(U)+Q(V)),a.ylines.style(\"stroke-width\",d._lw+\"px\").call(l.stroke,d.showline?d.linecolor:\"rgba(0,0,0,0)\")),a.ylines.attr(\"d\",nt)}return f.makeClipPaths(t),t._promises.length&&Promise.all(t._promises)}function k(t,e){return(t.ticks||t.showline)&&(e===t._mainSubplot||\"all\"===t.mirror||\"allticks\"===t.mirror)}function T(t,e,r){if(!r.showline||!r._lw)return!1;if(\"all\"===r.mirror||\"allticks\"===r.mirror)return!0;var n=r._anchorAxis;if(!n)return!1;var i=p.FROM_BL[e];return r.side===e?n.domain[i]===t.domain[i]:r.mirror&&n.domain[1-i]===t.domain[1-i]}function A(t,e,r,n){if(T(t,e,r))return r._lw;for(var i=0;i<n.length;i++){var a=n[i];if(a._mainAxis===r._mainAxis&&T(t,e,a))return a._lw}return 0}r.layoutStyles=function(t){return o.syncOrAsync([a.doAutoMargin,w],t)},r.drawMainTitle=function(t){var e=t._fullLayout,r=function(t){var e=t.title,r=x;o.isRightAnchor(e)?r=b:o.isLeftAnchor(e)&&(r=y);return r}(e),n=function(t){var e=t.title,r=\"0em\";o.isTopAnchor(e)?r=p.CAP_SHIFT+\"em\":o.isMiddleAnchor(e)&&(r=p.MID_SHIFT+\"em\");return r}(e);u.draw(t,\"gtitle\",{propContainer:e,propName:\"title.text\",placeholder:e._dfltTitle.plot,attributes:{x:function(t,e){var r=t.title,n=t._size,i=0;e===y?i=r.pad.l:e===b&&(i=-r.pad.r);switch(r.xref){case\"paper\":return n.l+n.w*r.x+i;case\"container\":default:return t.width*r.x+i}}(e,r),y:function(t,e){var r=t.title,n=t._size,i=0;\"0em\"!==e&&e?e===p.CAP_SHIFT+\"em\"&&(i=r.pad.t):i=-r.pad.b;if(\"auto\"===r.y)return n.t/2;switch(r.yref){case\"paper\":return n.t+n.h-n.h*r.y+i;case\"container\":default:return t.height-t.height*r.y+i}}(e,n),\"text-anchor\":r,dy:n}})},r.doTraceStyle=function(t){var e,n=t.calcdata,o=[];for(e=0;e<n.length;e++){var l=n[e],c=l[0]||{},u=c.trace||{},h=u._module||{},f=h.arraysToCalcdata;f&&f(l,u);var p=h.editStyle;p&&o.push({fn:p,cd0:c})}if(o.length){for(e=0;e<o.length;e++){var d=o[e];d.fn(t,d.cd0)}s(t),r.redrawReglTraces(t)}return a.style(t),i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doColorBars=function(t){return i.getComponentMethod(\"colorbar\",\"draw\")(t),a.previousPromises(t)},r.layoutReplot=function(t){var e=t.layout;return t.layout=void 0,i.call(\"plot\",t,\"\",e)},r.doLegend=function(t){return i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doTicksRelayout=function(t){return f.draw(t,\"redraw\"),t._fullLayout._hasOnlyLargeSploms&&(i.subplotsRegistry.splom.updateGrid(t),s(t),r.redrawReglTraces(t)),r.drawMainTitle(t),a.previousPromises(t)},r.doModeBar=function(t){var e=t._fullLayout;h.manage(t);for(var r=0;r<e._basePlotModules.length;r++){var n=e._basePlotModules[r].updateFx;n&&n(t)}return a.previousPromises(t)},r.doCamera=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){var i=e[r[n]],a=i._scene,o=i.camera;a.setCamera(o)}},r.drawData=function(t){var e=t._fullLayout;s(t);for(var n=e._basePlotModules,o=0;o<n.length;o++)n[o].plot(t);return r.redrawReglTraces(t),a.style(t),i.getComponentMethod(\"shapes\",\"draw\")(t),i.getComponentMethod(\"annotations\",\"draw\")(t),e._replotting=!1,a.previousPromises(t)},r.redrawReglTraces=function(t){var e=t._fullLayout;if(e._has(\"regl\")){var r,n,i=t._fullData,a=[],s=[];for(e._hasOnlyLargeSploms&&e._splomGrid.draw(),r=0;r<i.length;r++){var l=i[r];!0===l.visible&&0!==l._length&&(\"splom\"===l.type?e._splomScenes[l.uid].draw():\"scattergl\"===l.type?o.pushUnique(a,l.xaxis+l.yaxis):\"scatterpolargl\"===l.type&&o.pushUnique(s,l.subplot))}for(r=0;r<a.length;r++)(n=e._plots[a[r]])._scene&&n._scene.draw();for(r=0;r<s.length;r++)(n=e[s[r]]._subplot)._scene&&n._scene.draw()}},r.doAutoRangeAndConstraints=function(t){for(var e,r,n=t._fullLayout,i=f.list(t,\"\",!0),a=n._axisMatchGroups||[],s=0;s<i.length;s++)e=i[s],v(t,e),m(t,e);g(t);t:for(var l=0;l<a.length;l++){var c,u=a[l],h=null;for(c in u){if(!1===(e=f.getFromId(t,c)).autorange)continue t;r=o.simpleMap(e.range,e.r2l),h?h[0]<h[1]?(h[0]=Math.min(h[0],r[0]),h[1]=Math.max(h[1],r[1])):(h[0]=Math.max(h[0],r[0]),h[1]=Math.min(h[1],r[1])):h=r}for(c in u)(e=f.getFromId(t,c)).range=o.simpleMap(h,e.l2r),e._input.range=e.range.slice(),e.setScale()}},r.finalDraw=function(t){i.getComponentMethod(\"shapes\",\"draw\")(t),i.getComponentMethod(\"images\",\"draw\")(t),i.getComponentMethod(\"annotations\",\"draw\")(t),i.getComponentMethod(\"rangeslider\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t)},r.drawMarginPushers=function(t){i.getComponentMethod(\"legend\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t),i.getComponentMethod(\"sliders\",\"draw\")(t),i.getComponentMethod(\"updatemenus\",\"draw\")(t),i.getComponentMethod(\"colorbar\",\"draw\")(t)}},{\"../components/color\":593,\"../components/drawing\":614,\"../components/modebar\":652,\"../components/titles\":681,\"../constants/alignment\":688,\"../lib\":719,\"../lib/clear_gl_canvases\":704,\"../plots/cartesian/autorange\":766,\"../plots/cartesian/axes\":767,\"../plots/cartesian/constraints\":774,\"../plots/plots\":828,\"../registry\":847,d3:163}],759:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.isPlainObject,a=t(\"./plot_schema\"),o=t(\"../plots/plots\"),s=t(\"../plots/attributes\"),l=t(\"./plot_template\"),c=t(\"./plot_config\").dfltConfig;function u(t,e){t=n.extendDeep({},t);var r,a,o=Object.keys(t).sort();function s(e,r,n){if(i(r)&&i(e))u(e,r);else if(Array.isArray(r)&&Array.isArray(e)){var o=l.arrayTemplater({_template:t},n);for(a=0;a<r.length;a++){var s=r[a],c=o.newItem(s)._template;c&&u(c,s)}var h=o.defaultItems();for(a=0;a<h.length;a++)r.push(h[a]._template);for(a=0;a<r.length;a++)delete r[a].templateitemname}}for(r=0;r<o.length;r++){var c=o[r],f=t[c];if(c in e?s(f,e[c],c):e[c]=f,h(c)===c)for(var p in e){var d=h(p);p===d||d!==c||p in t||s(f,e[p],c)}}}function h(t){return t.replace(/[0-9]+$/,\"\")}function f(t,e,r,a,o){var s=o&&r(o);for(var c in t){var u=t[c],d=p(t,c,a),g=p(t,c,o),v=r(g);if(!v){var m=h(c);m!==c&&(v=r(g=p(t,m,o)))}if((!s||s!==v)&&!(!v||v._noTemplating||\"data_array\"===v.valType||v.arrayOk&&Array.isArray(u)))if(!v.valType&&i(u))f(u,e,r,d,g);else if(v._isLinkedToArray&&Array.isArray(u))for(var y=!1,x=0,b={},_=0;_<u.length;_++){var w=u[_];if(i(w)){var k=w.name;if(k)b[k]||(f(w,e,r,p(u,x,d),p(u,x,g)),x++,b[k]=1);else if(!y){var T=p(t,l.arrayDefaultKey(c),a),A=p(u,x,d);f(w,e,r,A,p(u,x,g));var M=n.nestedProperty(e,A);n.nestedProperty(e,T).set(M.get()),M.set(null),y=!0}}}else{n.nestedProperty(e,d).set(u)}}}function p(t,e,r){return r?Array.isArray(t)?r+\"[\"+e+\"]\":r+\".\"+e:e}function d(t){for(var e=0;e<t.length;e++)if(i(t[e]))return!0}function g(t){var e;switch(t.code){case\"data\":e=\"The template has no key data.\";break;case\"layout\":e=\"The template has no key layout.\";break;case\"missing\":e=t.path?\"There are no templates for item \"+t.path+\" with name \"+t.templateitemname:\"There are no templates for trace \"+t.index+\", of type \"+t.traceType+\".\";break;case\"unused\":e=t.path?\"The template item at \"+t.path+\" was not used in constructing the plot.\":t.dataCount?\"Some of the templates of type \"+t.traceType+\" were not used. The template has \"+t.templateCount+\" traces, the data only has \"+t.dataCount+\" of this type.\":\"The template has \"+t.templateCount+\" traces of type \"+t.traceType+\" but there are none in the data.\";break;case\"reused\":e=\"Some of the templates of type \"+t.traceType+\" were used more than once. The template has \"+t.templateCount+\" traces, the data has \"+t.dataCount+\" of this type.\"}return t.msg=e,t}r.makeTemplate=function(t){t=n.isPlainObject(t)?t:n.getGraphDiv(t),t=n.extendDeep({_context:c},{data:t.data,layout:t.layout}),o.supplyDefaults(t);var e=t.data||[],r=t.layout||{};r._basePlotModules=t._fullLayout._basePlotModules,r._modules=t._fullLayout._modules;var l={data:{},layout:{}};e.forEach(function(t){var e={};f(t,e,function(t,e){return a.getTraceValObject(t,n.nestedProperty({},e).parts)}.bind(null,t));var r=n.coerce(t,{},s,\"type\"),i=l.data[r];i||(i=l.data[r]=[]),i.push(e)}),f(r,l.layout,function(t,e){return a.getLayoutValObject(t,n.nestedProperty({},e).parts)}.bind(null,r)),delete l.layout.template;var h=r.template;if(i(h)){var p,d,g,v,m,y,x=h.layout;i(x)&&u(x,l.layout);var b=h.data;if(i(b)){for(d in l.data)if(g=b[d],Array.isArray(g)){for(y=(m=l.data[d]).length,v=g.length,p=0;p<y;p++)u(g[p%v],m[p]);for(p=y;p<v;p++)m.push(n.extendDeep({},g[p]))}for(d in b)d in l.data||(l.data[d]=n.extendDeep([],b[d]))}}return l},r.validateTemplate=function(t,e){var r=n.extendDeep({},{_context:c,data:t.data,layout:t.layout}),a=r.layout||{};i(e)||(e=a.template||{});var s=e.layout,l=e.data,u=[];r.layout=a,r.layout.template=e,o.supplyDefaults(r);var f=r._fullLayout,v=r._fullData,m={};if(i(s)?(!function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)&&i(e[n])){var a,o=h(n),s=[];for(a=0;a<r.length;a++)s.push(p(e,n,r[a])),o!==n&&s.push(p(e,o,r[a]));for(a=0;a<s.length;a++)m[s[a]]=1;t(e[n],s)}}(f,[\"layout\"]),function t(e,r){for(var n in e)if(-1===n.indexOf(\"defaults\")&&i(e[n])){var a=p(e,n,r);m[a]?t(e[n],a):u.push({code:\"unused\",path:a})}}(s,\"layout\")):u.push({code:\"layout\"}),i(l)){for(var y,x={},b=0;b<v.length;b++){var _=v[b];x[y=_.type]=(x[y]||0)+1,_._fullInput._template||u.push({code:\"missing\",index:_._fullInput.index,traceType:y})}for(y in l){var w=l[y].length,k=x[y]||0;w>k?u.push({code:\"unused\",traceType:y,templateCount:w,dataCount:k}):k>w&&u.push({code:\"reused\",traceType:y,templateCount:w,dataCount:k})}}else u.push({code:\"data\"});if(function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)){var a=e[n],o=p(e,n,r);i(a)?(Array.isArray(e)&&!1===a._template&&a.templateitemname&&u.push({code:\"missing\",path:o,templateitemname:a.templateitemname}),t(a,o)):Array.isArray(a)&&d(a)&&t(a,o)}}({data:v,layout:f},\"\"),u.length)return u.map(g)}},{\"../lib\":719,\"../plots/attributes\":764,\"../plots/plots\":828,\"./plot_config\":755,\"./plot_schema\":756,\"./plot_template\":757}],760:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./plot_api\"),a=t(\"../lib\"),o=t(\"../snapshot/helpers\"),s=t(\"../snapshot/tosvg\"),l=t(\"../snapshot/svgtoimg\"),c={format:{valType:\"enumerated\",values:[\"png\",\"jpeg\",\"webp\",\"svg\"],dflt:\"png\"},width:{valType:\"number\",min:1},height:{valType:\"number\",min:1},scale:{valType:\"number\",min:0,dflt:1},setBackground:{valType:\"any\",dflt:!1},imageDataOnly:{valType:\"boolean\",dflt:!1}};e.exports=function(t,e){var r,u,h,f;function p(t){return!(t in e)||a.validate(e[t],c[t])}if(e=e||{},a.isPlainObject(t)?(r=t.data||[],u=t.layout||{},h=t.config||{},f={}):(t=a.getGraphDiv(t),r=a.extendDeep([],t.data),u=a.extendDeep({},t.layout),h=t._context,f=t._fullLayout||{}),!p(\"width\")&&null!==e.width||!p(\"height\")&&null!==e.height)throw new Error(\"Height and width should be pixel values.\");if(!p(\"format\"))throw new Error(\"Image format is not jpeg, png, svg or webp.\");var d={};function g(t,r){return a.coerce(e,d,c,t,r)}var v=g(\"format\"),m=g(\"width\"),y=g(\"height\"),x=g(\"scale\"),b=g(\"setBackground\"),_=g(\"imageDataOnly\"),w=document.createElement(\"div\");w.style.position=\"absolute\",w.style.left=\"-5000px\",document.body.appendChild(w);var k=a.extendFlat({},u);m?k.width=m:null===e.width&&n(f.width)&&(k.width=f.width),y?k.height=y:null===e.height&&n(f.height)&&(k.height=f.height);var T=a.extendFlat({},h,{_exportedPlot:!0,staticPlot:!0,setBackground:b}),A=o.getRedrawFunc(w);function M(){return new Promise(function(t){setTimeout(t,o.getDelay(w._fullLayout))})}function S(){return new Promise(function(t,e){var r=s(w,v,x),n=w._fullLayout.width,c=w._fullLayout.height;if(i.purge(w),document.body.removeChild(w),\"svg\"===v)return t(_?r:o.encodeSVG(r));var u=document.createElement(\"canvas\");u.id=a.randstr(),l({format:v,width:n,height:c,scale:x,canvas:u,svg:r,promise:!0}).then(t).catch(e)})}return new Promise(function(t,e){i.plot(w,r,k,T).then(A).then(M).then(S).then(function(e){t(function(t){return _?t.replace(o.IMAGE_URL_PREFIX,\"\"):t}(e))}).catch(function(t){e(t)})})}},{\"../lib\":719,\"../snapshot/helpers\":851,\"../snapshot/svgtoimg\":853,\"../snapshot/tosvg\":855,\"./plot_api\":754,\"fast-isnumeric\":225}],761:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/plots\"),a=t(\"./plot_schema\"),o=t(\"./plot_config\").dfltConfig,s=n.isPlainObject,l=Array.isArray,c=n.isArrayOrTypedArray;function u(t,e,r,i,a,o){o=o||[];for(var h=Object.keys(t),f=0;f<h.length;f++){var v=h[f];if(\"transforms\"!==v){var m=o.slice();m.push(v);var y=t[v],x=e[v],b=g(r,v),_=\"info_array\"===(b||{}).valType,w=\"colorscale\"===(b||{}).valType,k=(b||{}).items;if(d(r,v))if(s(y)&&s(x))u(y,x,b,i,a,m);else if(_&&l(y)){y.length>x.length&&i.push(p(\"unused\",a,m.concat(x.length)));var T,A,M,S,E,C=x.length,L=Array.isArray(k);if(L&&(C=Math.min(C,k.length)),2===b.dimensions)for(A=0;A<C;A++)if(l(y[A])){y[A].length>x[A].length&&i.push(p(\"unused\",a,m.concat(A,x[A].length)));var P=x[A].length;for(T=0;T<(L?Math.min(P,k[A].length):P);T++)M=L?k[A][T]:k,S=y[A][T],E=x[A][T],n.validate(S,M)?E!==S&&E!==+S&&i.push(p(\"dynamic\",a,m.concat(A,T),S,E)):i.push(p(\"value\",a,m.concat(A,T),S))}else i.push(p(\"array\",a,m.concat(A),y[A]));else for(A=0;A<C;A++)M=L?k[A]:k,S=y[A],E=x[A],n.validate(S,M)?E!==S&&E!==+S&&i.push(p(\"dynamic\",a,m.concat(A),S,E)):i.push(p(\"value\",a,m.concat(A),S))}else if(b.items&&!_&&l(y)){var O,z,I=k[Object.keys(k)[0]],D=[];for(O=0;O<x.length;O++){var R=x[O]._index||O;if((z=m.slice()).push(R),s(y[R])&&s(x[O])){D.push(R);var F=y[R],B=x[O];s(F)&&!1!==F.visible&&!1===B.visible?i.push(p(\"invisible\",a,z)):u(F,B,I,i,a,z)}}for(O=0;O<y.length;O++)(z=m.slice()).push(O),s(y[O])?-1===D.indexOf(O)&&i.push(p(\"unused\",a,z)):i.push(p(\"object\",a,z,y[O]))}else!s(y)&&s(x)?i.push(p(\"object\",a,m,y)):c(y)||!c(x)||_||w?v in e?n.validate(y,b)?\"enumerated\"===b.valType&&(b.coerceNumber&&y!==+x||y!==x)&&i.push(p(\"dynamic\",a,m,y,x)):i.push(p(\"value\",a,m,y)):i.push(p(\"unused\",a,m,y)):i.push(p(\"array\",a,m,y));else i.push(p(\"schema\",a,m))}}return i}e.exports=function(t,e){var r,c,h=a.get(),f=[],d={_context:n.extendFlat({},o)};l(t)?(d.data=n.extendDeep([],t),r=t):(d.data=[],r=[],f.push(p(\"array\",\"data\"))),s(e)?(d.layout=n.extendDeep({},e),c=e):(d.layout={},c={},arguments.length>1&&f.push(p(\"object\",\"layout\"))),i.supplyDefaults(d);for(var g=d._fullData,v=r.length,m=0;m<v;m++){var y=r[m],x=[\"data\",m];if(s(y)){var b=g[m],_=b.type,w=h.traces[_].attributes;w.type={valType:\"enumerated\",values:[_]},!1===b.visible&&!1!==y.visible&&f.push(p(\"invisible\",x)),u(y,b,w,f,x);var k=y.transforms,T=b.transforms;if(k){l(k)||f.push(p(\"array\",x,[\"transforms\"])),x.push(\"transforms\");for(var A=0;A<k.length;A++){var M=[\"transforms\",A],S=k[A].type;if(s(k[A])){var E=h.transforms[S]?h.transforms[S].attributes:{};E.type={valType:\"enumerated\",values:Object.keys(h.transforms)},u(k[A],T[A],E,f,x,M)}else f.push(p(\"object\",x,M))}}}else f.push(p(\"object\",x))}return u(c,d._fullLayout,function(t,e){for(var r=t.layout.layoutAttributes,i=0;i<e.length;i++){var a=e[i],o=t.traces[a.type],s=o.layoutAttributes;s&&(a.subplot?n.extendFlat(r[o.attributes.subplot.dflt],s):n.extendFlat(r,s))}return r}(h,g),f,\"layout\"),0===f.length?void 0:f};var h={object:function(t,e){return(\"layout\"===t&&\"\"===e?\"The layout argument\":\"data\"===t[0]&&\"\"===e?\"Trace \"+t[1]+\" in the data argument\":f(t)+\"key \"+e)+\" must be linked to an object container\"},array:function(t,e){return(\"data\"===t?\"The data argument\":f(t)+\"key \"+e)+\" must be linked to an array container\"},schema:function(t,e){return f(t)+\"key \"+e+\" is not part of the schema\"},unused:function(t,e,r){var n=s(r)?\"container\":\"key\";return f(t)+n+\" \"+e+\" did not get coerced\"},dynamic:function(t,e,r,n){return[f(t)+\"key\",e,\"(set to '\"+r+\"')\",\"got reset to\",\"'\"+n+\"'\",\"during defaults.\"].join(\" \")},invisible:function(t,e){return(e?f(t)+\"item \"+e:\"Trace \"+t[1])+\" got defaulted to be not visible\"},value:function(t,e,r){return[f(t)+\"key \"+e,\"is set to an invalid value (\"+r+\")\"].join(\" \")}};function f(t){return l(t)?\"In data trace \"+t[1]+\", \":\"In \"+t+\", \"}function p(t,e,r,i,a){var o,s;r=r||\"\",l(e)?(o=e[0],s=e[1]):(o=e,s=null);var c=function(t){if(!l(t))return String(t);for(var e=\"\",r=0;r<t.length;r++){var n=t[r];\"number\"==typeof n?e=e.substr(0,e.length-1)+\"[\"+n+\"]\":e+=n,r<t.length-1&&(e+=\".\")}return e}(r),u=h[t](e,c,i,a);return n.log(u),{code:t,container:o,trace:s,path:r,astr:c,msg:u}}function d(t,e){var r=m(e),n=r.keyMinusId,i=r.id;return!!(n in t&&t[n]._isSubplotObj&&i)||e in t}function g(t,e){return e in t?t[e]:t[m(e).keyMinusId]}var v=n.counterRegex(\"([a-z]+)\");function m(t){var e=t.match(v);return{keyMinusId:e&&e[1],id:e&&e[2]}}},{\"../lib\":719,\"../plots/plots\":828,\"./plot_config\":755,\"./plot_schema\":756}],762:[function(t,e,r){\"use strict\";e.exports={mode:{valType:\"enumerated\",dflt:\"afterall\",values:[\"immediate\",\"next\",\"afterall\"]},direction:{valType:\"enumerated\",values:[\"forward\",\"reverse\"],dflt:\"forward\"},fromcurrent:{valType:\"boolean\",dflt:!1},frame:{duration:{valType:\"number\",min:0,dflt:500},redraw:{valType:\"boolean\",dflt:!0}},transition:{duration:{valType:\"number\",min:0,dflt:500,editType:\"none\"},easing:{valType:\"enumerated\",dflt:\"cubic-in-out\",values:[\"linear\",\"quad\",\"cubic\",\"sin\",\"exp\",\"circle\",\"elastic\",\"back\",\"bounce\",\"linear-in\",\"quad-in\",\"cubic-in\",\"sin-in\",\"exp-in\",\"circle-in\",\"elastic-in\",\"back-in\",\"bounce-in\",\"linear-out\",\"quad-out\",\"cubic-out\",\"sin-out\",\"exp-out\",\"circle-out\",\"elastic-out\",\"back-out\",\"bounce-out\",\"linear-in-out\",\"quad-in-out\",\"cubic-in-out\",\"sin-in-out\",\"exp-in-out\",\"circle-in-out\",\"elastic-in-out\",\"back-in-out\",\"bounce-in-out\"],editType:\"none\"},ordering:{valType:\"enumerated\",values:[\"layout first\",\"traces first\"],dflt:\"layout first\",editType:\"none\"}}}},{}],763:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\");e.exports=function(t,e,r){var a,o,s=r.name,l=r.inclusionAttr||\"visible\",c=e[s],u=n.isArrayOrTypedArray(t[s])?t[s]:[],h=e[s]=[],f=i.arrayTemplater(e,s,l);for(a=0;a<u.length;a++){var p=u[a];n.isPlainObject(p)?o=f.newItem(p):(o=f.newItem({}))[l]=!1,o._index=a,!1!==o[l]&&r.handleItemDefaults(p,o,e,r),h.push(o)}var d=f.defaultItems();for(a=0;a<d.length;a++)(o=d[a])._index=h.length,r.handleItemDefaults({},o,e,r,{}),h.push(o);if(n.isArrayOrTypedArray(c)){var g=Math.min(c.length,h.length);for(a=0;a<g;a++)n.relinkPrivateKeys(h[a],c[a])}return h}},{\"../lib\":719,\"../plot_api/plot_template\":757}],764:[function(t,e,r){\"use strict\";var n=t(\"../components/fx/attributes\");e.exports={type:{valType:\"enumerated\",values:[],dflt:\"scatter\",editType:\"calc+clearAxisTypes\",_noTemplating:!0},visible:{valType:\"enumerated\",values:[!0,!1,\"legendonly\"],dflt:!0,editType:\"calc\"},showlegend:{valType:\"boolean\",dflt:!0,editType:\"style\"},legendgroup:{valType:\"string\",dflt:\"\",editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"style\"},name:{valType:\"string\",editType:\"style\"},uid:{valType:\"string\",editType:\"plot\",anim:!0},ids:{valType:\"data_array\",editType:\"calc\",anim:!0},customdata:{valType:\"data_array\",editType:\"calc\"},meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},selectedpoints:{valType:\"any\",editType:\"calc\"},hoverinfo:{valType:\"flaglist\",flags:[\"x\",\"y\",\"z\",\"text\",\"name\"],extras:[\"all\",\"none\",\"skip\"],arrayOk:!0,dflt:\"all\",editType:\"none\"},hoverlabel:n.hoverlabel,stream:{token:{valType:\"string\",noBlank:!0,strict:!0,editType:\"calc\"},maxpoints:{valType:\"number\",min:0,max:1e4,dflt:500,editType:\"calc\"},editType:\"calc\"},transforms:{_isLinkedToArray:\"transform\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"}}},{\"../components/fx/attributes\":623}],765:[function(t,e,r){\"use strict\";e.exports={xaxis:{valType:\"subplotid\",dflt:\"x\",editType:\"calc+clearAxisTypes\"},yaxis:{valType:\"subplotid\",dflt:\"y\",editType:\"calc+clearAxisTypes\"}}},{}],766:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").FP_SAFE,o=t(\"../../registry\");function s(t,e){var r,n,a=[],o=l(e),s=c(t,e),u=s.min,h=s.max;if(0===u.length||0===h.length)return i.simpleMap(e.range,e.r2l);var f=u[0].val,p=h[0].val;for(r=1;r<u.length&&f===p;r++)f=Math.min(f,u[r].val);for(r=1;r<h.length&&f===p;r++)p=Math.max(p,h[r].val);var d=!1;if(e.range){var g=i.simpleMap(e.range,e.r2l);d=g[1]<g[0]}\"reversed\"===e.autorange&&(d=!0,e.autorange=!0);var v,m,y,x,b,_,w=e.rangemode,k=\"tozero\"===w,T=\"nonnegative\"===w,A=e._length,M=A/10,S=0;for(r=0;r<u.length;r++)for(v=u[r],n=0;n<h.length;n++)(_=(m=h[n]).val-v.val)>0&&((b=A-o(v)-o(m))>M?_/b>S&&(y=v,x=m,S=_/b):_/A>S&&(y={val:v.val,pad:0},x={val:m.val,pad:0},S=_/A));if(f===p){var E=f-1,C=f+1;if(k)if(0===f)a=[0,1];else{var L=(f>0?h:u).reduce(function(t,e){return Math.max(t,o(e))},0),P=f/(1-Math.min(.5,L/A));a=f>0?[0,P]:[P,0]}else a=T?[Math.max(0,E),Math.max(1,C)]:[E,C]}else k?(y.val>=0&&(y={val:0,pad:0}),x.val<=0&&(x={val:0,pad:0})):T&&(y.val-S*o(y)<0&&(y={val:0,pad:0}),x.val<=0&&(x={val:1,pad:0})),S=(x.val-y.val)/(A-o(y)-o(x)),a=[y.val-S*o(y),x.val+S*o(x)];return d&&a.reverse(),i.simpleMap(a,e.l2r||Number)}function l(t){var e=t._length/20;return\"domain\"===t.constrain&&t._inputDomain&&(e*=(t._inputDomain[1]-t._inputDomain[0])/(t.domain[1]-t.domain[0])),function(t){return t.pad+(t.extrapad?e:0)}}function c(t,e){var r,n,i,a=e._id,o=t._fullData,s=t._fullLayout,l=[],c=[];function f(t,e){for(r=0;r<e.length;r++){var o=t[e[r]],s=(o._extremes||{})[a];if(!0===o.visible&&s){for(n=0;n<s.min.length;n++)i=s.min[n],u(l,i.val,i.pad,{extrapad:i.extrapad});for(n=0;n<s.max.length;n++)i=s.max[n],h(c,i.val,i.pad,{extrapad:i.extrapad})}}}return f(o,e._traceIndices),f(s.annotations||[],e._annIndices||[]),f(s.shapes||[],e._shapeIndices||[]),{min:l,max:c}}function u(t,e,r,n){f(t,e,r,n,d)}function h(t,e,r,n){f(t,e,r,n,g)}function f(t,e,r,n,i){for(var a=n.tozero,o=n.extrapad,s=!0,l=0;l<t.length&&s;l++){var c=t[l];if(i(c.val,e)&&c.pad>=r&&(c.extrapad||!o)){s=!1;break}i(e,c.val)&&c.pad<=r&&(o||!c.extrapad)&&(t.splice(l,1),l--)}if(s){var u=a&&0===e;t.push({val:e,pad:u?0:r,extrapad:!u&&o})}}function p(t){return n(t)&&Math.abs(t)<a}function d(t,e){return t<=e}function g(t,e){return t>=e}e.exports={getAutoRange:s,makePadFn:l,doAutoRange:function(t,e){if(e.setScale(),e.autorange){e.range=s(t,e),e._r=e.range.slice(),e._rl=i.simpleMap(e._r,e.r2l);var r=e._input,n={};n[e._attr+\".range\"]=e.range,n[e._attr+\".autorange\"]=e.autorange,o.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,n),r.range=e.range.slice(),r.autorange=e.autorange}var a=e._anchorAxis;if(a&&a.rangeslider){var l=a.rangeslider[e._name];l&&\"auto\"===l.rangemode&&(l.range=s(t,e)),a._input.rangeslider[e._name]=i.extendFlat({},l)}},findExtremes:function(t,e,r){r||(r={});t._m||t.setScale();var i,o,s,l,c,f,d,g,v,m=[],y=[],x=e.length,b=r.padded||!1,_=r.tozero&&(\"linear\"===t.type||\"-\"===t.type),w=\"log\"===t.type,k=!1;function T(t){if(Array.isArray(t))return k=!0,function(e){return Math.max(Number(t[e]||0),0)};var e=Math.max(Number(t||0),0);return function(){return e}}var A=T((t._m>0?r.ppadplus:r.ppadminus)||r.ppad||0),M=T((t._m>0?r.ppadminus:r.ppadplus)||r.ppad||0),S=T(r.vpadplus||r.vpad),E=T(r.vpadminus||r.vpad);if(!k){if(g=1/0,v=-1/0,w)for(i=0;i<x;i++)(o=e[i])<g&&o>0&&(g=o),o>v&&o<a&&(v=o);else for(i=0;i<x;i++)(o=e[i])<g&&o>-a&&(g=o),o>v&&o<a&&(v=o);e=[g,v],x=2}var C={tozero:_,extrapad:b};function L(r){s=e[r],n(s)&&(f=A(r),d=M(r),g=s-E(r),v=s+S(r),w&&g<v/10&&(g=v/10),l=t.c2l(g),c=t.c2l(v),_&&(l=Math.min(0,l),c=Math.max(0,c)),p(l)&&u(m,l,d,C),p(c)&&h(y,c,f,C))}var P=Math.min(6,x);for(i=0;i<P;i++)L(i);for(i=x-1;i>=P;i--)L(i);return{min:m,max:y,opts:r}},concatExtremes:c}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../registry\":847,\"fast-isnumeric\":225}],767:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../components/titles\"),u=t(\"../../components/color\"),h=t(\"../../components/drawing\"),f=t(\"./layout_attributes\"),p=t(\"./clean_ticks\"),d=t(\"../../constants/numerical\"),g=d.ONEAVGYEAR,v=d.ONEAVGMONTH,m=d.ONEDAY,y=d.ONEHOUR,x=d.ONEMIN,b=d.ONESEC,_=d.MINUS_SIGN,w=d.BADNUM,k=t(\"../../constants/alignment\").MID_SHIFT,T=t(\"../../constants/alignment\").LINE_SPACING,A=e.exports={};A.setConvert=t(\"./set_convert\");var M=t(\"./axis_autotype\"),S=t(\"./axis_ids\");A.id2name=S.id2name,A.name2id=S.name2id,A.cleanId=S.cleanId,A.list=S.list,A.listIds=S.listIds,A.getFromId=S.getFromId,A.getFromTrace=S.getFromTrace;var E=t(\"./autorange\");A.getAutoRange=E.getAutoRange,A.findExtremes=E.findExtremes,A.coerceRef=function(t,e,r,n,i,a){var o=n.charAt(n.length-1),l=r._fullLayout._subplots[o+\"axis\"],c=n+\"ref\",u={};return i||(i=l[0]||a),a||(a=i),u[c]={valType:\"enumerated\",values:l.concat(a?[a]:[]),dflt:i},s.coerce(t,e,u,c)},A.coercePosition=function(t,e,r,n,i,a){var o,l;if(\"paper\"===n||\"pixel\"===n)o=s.ensureNumber,l=r(i,a);else{var c=A.getFromId(e,n);l=r(i,a=c.fraction2r(a)),o=c.cleanPos}t[i]=o(l)},A.cleanPosition=function(t,e,r){return(\"paper\"===r||\"pixel\"===r?s.ensureNumber:A.getFromId(e,r).cleanPos)(t)},A.redrawComponents=function(t,e){e=e||A.listIds(t);var r=t._fullLayout;function n(n,i,a,s){for(var l=o.getComponentMethod(n,i),c={},u=0;u<e.length;u++)for(var h=r[A.id2name(e[u])][a],f=0;f<h.length;f++){var p=h[f];if(!c[p]&&(l(t,p),c[p]=1,s))return}}n(\"annotations\",\"drawOne\",\"_annIndices\"),n(\"shapes\",\"drawOne\",\"_shapeIndices\"),n(\"images\",\"draw\",\"_imgIndices\",!0)};var C=A.getDataConversions=function(t,e,r,n){var i,a=\"x\"===r||\"y\"===r||\"z\"===r?r:n;if(Array.isArray(a)){if(i={type:M(n),_categories:[]},A.setConvert(i),\"category\"===i.type)for(var o=0;o<n.length;o++)i.d2c(n[o])}else i=A.getFromTrace(t,e,a);return i?{d2c:i.d2c,c2d:i.c2d}:\"ids\"===a?{d2c:P,c2d:P}:{d2c:L,c2d:L}};function L(t){return+t}function P(t){return String(t)}A.getDataToCoordFunc=function(t,e,r,n){return C(t,e,r,n).d2c},A.counterLetter=function(t){var e=t.charAt(0);return\"x\"===e?\"y\":\"y\"===e?\"x\":void 0},A.minDtick=function(t,e,r,n){-1===[\"log\",\"category\",\"multicategory\"].indexOf(t.type)&&n?void 0===t._minDtick?(t._minDtick=e,t._forceTick0=r):t._minDtick&&((t._minDtick/e+1e-6)%1<2e-6&&((r-t._forceTick0)/e%1+1.000001)%1<2e-6?(t._minDtick=e,t._forceTick0=r):((e/t._minDtick+1e-6)%1>2e-6||((r-t._forceTick0)/t._minDtick%1+1.000001)%1>2e-6)&&(t._minDtick=0)):t._minDtick=0},A.saveRangeInitial=function(t,e){for(var r=A.list(t,\"\",!0),n=!1,i=0;i<r.length;i++){var a=r[i],o=void 0===a._rangeInitial,s=o||!(a.range[0]===a._rangeInitial[0]&&a.range[1]===a._rangeInitial[1]);(o&&!1===a.autorange||e&&s)&&(a._rangeInitial=a.range.slice(),n=!0)}return n},A.saveShowSpikeInitial=function(t,e){for(var r=A.list(t,\"\",!0),n=!1,i=\"on\",a=0;a<r.length;a++){var o=r[a],s=void 0===o._showSpikeInitial,l=s||!(o.showspikes===o._showspikes);(s||e&&l)&&(o._showSpikeInitial=o.showspikes,n=!0),\"on\"!==i||o.showspikes||(i=\"off\")}return t._fullLayout._cartesianSpikesEnabled=i,n},A.autoBin=function(t,e,r,n,a,o){var l,c=s.aggNums(Math.min,null,t),u=s.aggNums(Math.max,null,t);if(\"category\"===e.type||\"multicategory\"===e.type)return{start:c-.5,end:u+.5,size:Math.max(1,Math.round(o)||1),_dataSpan:u-c};if(a||(a=e.calendar),l=\"log\"===e.type?{type:\"linear\",range:[c,u]}:{type:e.type,range:s.simpleMap([c,u],e.c2r,0,a),calendar:a},A.setConvert(l),o=o&&p.dtick(o,l.type))l.dtick=o,l.tick0=p.tick0(void 0,l.type,a);else{var h;if(r)h=(u-c)/r;else{var f=s.distinctVals(t),d=Math.pow(10,Math.floor(Math.log(f.minDiff)/Math.LN10)),g=d*s.roundUp(f.minDiff/d,[.9,1.9,4.9,9.9],!0);h=Math.max(g,2*s.stdev(t)/Math.pow(t.length,n?.25:.4)),i(h)||(h=1)}A.autoTicks(l,h)}var v,y=l.dtick,x=A.tickIncrement(A.tickFirst(l),y,\"reverse\",a);if(\"number\"==typeof y)v=(x=function(t,e,r,n,a){var o=0,s=0,l=0,c=0;function u(e){return(1+100*(e-t)/r.dtick)%100<2}for(var h=0;h<e.length;h++)e[h]%1==0?l++:i(e[h])||c++,u(e[h])&&o++,u(e[h]+r.dtick/2)&&s++;var f=e.length-c;if(l===f&&\"date\"!==r.type)r.dtick<1?t=n-.5*r.dtick:(t-=.5)+r.dtick<n&&(t+=r.dtick);else if(s<.1*f&&(o>.3*f||u(n)||u(a))){var p=r.dtick/2;t+=t+p<n?p:-p}return t}(x,t,l,c,u))+(1+Math.floor((u-x)/y))*y;else for(\"M\"===l.dtick.charAt(0)&&(x=function(t,e,r,n,i){var a=s.findExactDates(e,i);if(a.exactDays>.8){var o=Number(r.substr(1));a.exactYears>.8&&o%12==0?t=A.tickIncrement(t,\"M6\",\"reverse\")+1.5*m:a.exactMonths>.8?t=A.tickIncrement(t,\"M1\",\"reverse\")+15.5*m:t-=m/2;var l=A.tickIncrement(t,r);if(l<=n)return l}return t}(x,t,y,c,a)),v=x,0;v<=u;)v=A.tickIncrement(v,y,!1,a),0;return{start:e.c2r(x,0,a),end:e.c2r(v,0,a),size:y,_dataSpan:u-c}},A.prepTicks=function(t){var e=s.simpleMap(t.range,t.r2l);if(\"auto\"===t.tickmode||!t.dtick){var r,n=t.nticks;n||(\"category\"===t.type||\"multicategory\"===t.type?(r=t.tickfont?1.2*(t.tickfont.size||12):15,n=t._length/r):(r=\"y\"===t._id.charAt(0)?40:80,n=s.constrain(t._length/r,4,9)+1),\"radialaxis\"===t._name&&(n*=2)),\"array\"===t.tickmode&&(n*=100),A.autoTicks(t,Math.abs(e[1]-e[0])/n),t._minDtick>0&&t.dtick<2*t._minDtick&&(t.dtick=t._minDtick,t.tick0=t.l2r(t._forceTick0))}t.tick0||(t.tick0=\"date\"===t.type?\"2000-01-01\":0),\"date\"===t.type&&t.dtick<.1&&(t.dtick=.1),j(t)},A.calcTicks=function(t){A.prepTicks(t);var e=s.simpleMap(t.range,t.r2l);if(\"array\"===t.tickmode)return function(t){var e=t.tickvals,r=t.ticktext,n=new Array(e.length),i=s.simpleMap(t.range,t.r2l),a=1.0001*i[0]-1e-4*i[1],o=1.0001*i[1]-1e-4*i[0],l=Math.min(a,o),c=Math.max(a,o),u=0;Array.isArray(r)||(r=[]);var h=\"category\"===t.type?t.d2l_noadd:t.d2l;\"log\"===t.type&&\"L\"!==String(t.dtick).charAt(0)&&(t.dtick=\"L\"+Math.pow(10,Math.floor(Math.min(t.range[0],t.range[1]))-1));for(var f=0;f<e.length;f++){var p=h(e[f]);p>l&&p<c&&(void 0===r[f]?n[u]=A.tickText(t,p):n[u]=U(t,p,String(r[f])),u++)}u<e.length&&n.splice(u,e.length-u);return n}(t);t._tmin=A.tickFirst(t);var r=1.0001*e[0]-1e-4*e[1],n=1.0001*e[1]-1e-4*e[0],a=e[1]<e[0];if(t._tmin<r!==a)return[];var o=[];\"category\"!==t.type&&\"multicategory\"!==t.type||(n=a?Math.max(-.5,n):Math.min(t._categories.length-.5,n));for(var l=\"log\"===t.type&&!(i(t.dtick)||\"L\"===t.dtick.charAt(0)),c=null,u=Math.max(1e3,t._length||0),h=t._tmin;(a?h>=n:h<=n)&&!(o.length>u||h===c);h=A.tickIncrement(h,t.dtick,a,t.calendar)){c=h;var f=!1;l&&h!==(0|h)&&(f=!0),o.push({minor:f,value:h})}rt(t)&&360===Math.abs(e[1]-e[0])&&o.pop(),t._tmax=(o[o.length-1]||{}).value,t._prevDateHead=\"\",t._inCalcTicks=!0;for(var p=new Array(o.length),d=0;d<o.length;d++)p[d]=A.tickText(t,o[d].value,!1,o[d].minor);return t._inCalcTicks=!1,p};var O=[2,5,10],z=[1,2,3,6,12],I=[1,2,5,10,15,30],D=[1,2,3,7,14],R=[-.046,0,.301,.477,.602,.699,.778,.845,.903,.954,1],F=[-.301,0,.301,.699,1],B=[15,30,45,90,180];function N(t,e,r){return e*s.roundUp(t/e,r)}function j(t){var e=t.dtick;if(t._tickexponent=0,i(e)||\"string\"==typeof e||(e=1),\"category\"!==t.type&&\"multicategory\"!==t.type||(t._tickround=null),\"date\"===t.type){var r=t.r2l(t.tick0),n=t.l2r(r).replace(/(^-|i)/g,\"\"),a=n.length;if(\"M\"===String(e).charAt(0))a>10||\"01-01\"!==n.substr(5)?t._tickround=\"d\":t._tickround=+e.substr(1)%12==0?\"y\":\"m\";else if(e>=m&&a<=10||e>=15*m)t._tickround=\"d\";else if(e>=x&&a<=16||e>=y)t._tickround=\"M\";else if(e>=b&&a<=19||e>=x)t._tickround=\"S\";else{var o=t.l2r(r+e).replace(/^-/,\"\").length;t._tickround=Math.max(a,o)-20,t._tickround<0&&(t._tickround=4)}}else if(i(e)||\"L\"===e.charAt(0)){var s=t.range.map(t.r2d||Number);i(e)||(e=Number(e.substr(1))),t._tickround=2-Math.floor(Math.log(e)/Math.LN10+.01);var l=Math.max(Math.abs(s[0]),Math.abs(s[1])),c=Math.floor(Math.log(l)/Math.LN10+.01);Math.abs(c)>3&&(q(t.exponentformat)&&!H(c)?t._tickexponent=3*Math.round((c-1)/3):t._tickexponent=c)}else t._tickround=null}function U(t,e,r){var n=t.tickfont||{};return{x:e,dx:0,dy:0,text:r||\"\",fontSize:n.size,font:n.family,fontColor:n.color}}A.autoTicks=function(t,e){var r;function n(t){return Math.pow(t,Math.floor(Math.log(e)/Math.LN10))}if(\"date\"===t.type){t.tick0=s.dateTick0(t.calendar);var a=2*e;a>g?(e/=g,r=n(10),t.dtick=\"M\"+12*N(e,r,O)):a>v?(e/=v,t.dtick=\"M\"+N(e,1,z)):a>m?(t.dtick=N(e,m,D),t.tick0=s.dateTick0(t.calendar,!0)):a>y?t.dtick=N(e,y,z):a>x?t.dtick=N(e,x,I):a>b?t.dtick=N(e,b,I):(r=n(10),t.dtick=N(e,r,O))}else if(\"log\"===t.type){t.tick0=0;var o=s.simpleMap(t.range,t.r2l);if(e>.7)t.dtick=Math.ceil(e);else if(Math.abs(o[1]-o[0])<1){var l=1.5*Math.abs((o[1]-o[0])/e);e=Math.abs(Math.pow(10,o[1])-Math.pow(10,o[0]))/l,r=n(10),t.dtick=\"L\"+N(e,r,O)}else t.dtick=e>.3?\"D2\":\"D1\"}else\"category\"===t.type||\"multicategory\"===t.type?(t.tick0=0,t.dtick=Math.ceil(Math.max(e,1))):rt(t)?(t.tick0=0,r=1,t.dtick=N(e,r,B)):(t.tick0=0,r=n(10),t.dtick=N(e,r,O));if(0===t.dtick&&(t.dtick=1),!i(t.dtick)&&\"string\"!=typeof t.dtick){var c=t.dtick;throw t.dtick=1,\"ax.dtick error: \"+String(c)}},A.tickIncrement=function(t,e,r,a){var o=r?-1:1;if(i(e))return t+o*e;var l=e.charAt(0),c=o*Number(e.substr(1));if(\"M\"===l)return s.incrementMonth(t,c,a);if(\"L\"===l)return Math.log(Math.pow(10,t)+c)/Math.LN10;if(\"D\"===l){var u=\"D2\"===e?F:R,h=t+.01*o,f=s.roundUp(s.mod(h,1),u,r);return Math.floor(h)+Math.log(n.round(Math.pow(10,f),1))/Math.LN10}throw\"unrecognized dtick \"+String(e)},A.tickFirst=function(t){var e=t.r2l||Number,r=s.simpleMap(t.range,e),a=r[1]<r[0],o=a?Math.floor:Math.ceil,l=1.0001*r[0]-1e-4*r[1],c=t.dtick,u=e(t.tick0);if(i(c)){var h=o((l-u)/c)*c+u;return\"category\"!==t.type&&\"multicategory\"!==t.type||(h=s.constrain(h,0,t._categories.length-1)),h}var f=c.charAt(0),p=Number(c.substr(1));if(\"M\"===f){for(var d,g,v,m=0,y=u;m<10;){if(((d=A.tickIncrement(y,c,a,t.calendar))-l)*(y-l)<=0)return a?Math.min(y,d):Math.max(y,d);g=(l-(y+d)/2)/(d-y),v=f+(Math.abs(Math.round(g))||1)*p,y=A.tickIncrement(y,v,g<0?!a:a,t.calendar),m++}return s.error(\"tickFirst did not converge\",t),y}if(\"L\"===f)return Math.log(o((Math.pow(10,l)-u)/p)*p+u)/Math.LN10;if(\"D\"===f){var x=\"D2\"===c?F:R,b=s.roundUp(s.mod(l,1),x,a);return Math.floor(l)+Math.log(n.round(Math.pow(10,b),1))/Math.LN10}throw\"unrecognized dtick \"+String(c)},A.tickText=function(t,e,r,n){var a,o=U(t,e),l=\"array\"===t.tickmode,c=r||l,u=t.type,h=\"category\"===u?t.d2l_noadd:t.d2l;if(l&&Array.isArray(t.ticktext)){var f=s.simpleMap(t.range,t.r2l),p=Math.abs(f[1]-f[0])/1e4;for(a=0;a<t.ticktext.length&&!(Math.abs(e-h(t.tickvals[a]))<p);a++);if(a<t.ticktext.length)return o.text=String(t.ticktext[a]),o}function d(n){if(void 0===n)return!0;if(r)return\"none\"===n;var i={first:t._tmin,last:t._tmax}[n];return\"all\"!==n&&e!==i}var g=r?\"never\":\"none\"!==t.exponentformat&&d(t.showexponent)?\"hide\":\"\";if(\"date\"===u?function(t,e,r,n){var a=t._tickround,o=r&&t.hoverformat||A.getTickFormat(t);n&&(a=i(a)?4:{y:\"m\",m:\"d\",d:\"M\",M:\"S\",S:4}[a]);var l,c=s.formatDate(e.x,o,a,t._dateFormat,t.calendar,t._extraFormat),u=c.indexOf(\"\\n\");-1!==u&&(l=c.substr(u+1),c=c.substr(0,u));n&&(\"00:00:00\"===c||\"00:00\"===c?(c=l,l=\"\"):8===c.length&&(c=c.replace(/:00$/,\"\")));l&&(r?\"d\"===a?c+=\", \"+l:c=l+(c?\", \"+c:\"\"):t._inCalcTicks&&l===t._prevDateHead||(c+=\"<br>\"+l,t._prevDateHead=l));e.text=c}(t,o,r,c):\"log\"===u?function(t,e,r,n,a){var o=t.dtick,l=e.x,c=t.tickformat,u=\"string\"==typeof o&&o.charAt(0);\"never\"===a&&(a=\"\");n&&\"L\"!==u&&(o=\"L3\",u=\"L\");if(c||\"L\"===u)e.text=G(Math.pow(10,l),t,a,n);else if(i(o)||\"D\"===u&&s.mod(l+.01,1)<.1){var h=Math.round(l),f=Math.abs(h),p=t.exponentformat;\"power\"===p||q(p)&&H(h)?(e.text=0===h?1:1===h?\"10\":\"10<sup>\"+(h>1?\"\":_)+f+\"</sup>\",e.fontSize*=1.25):(\"e\"===p||\"E\"===p)&&f>2?e.text=\"1\"+p+(h>0?\"+\":_)+f:(e.text=G(Math.pow(10,l),t,\"\",\"fakehover\"),\"D1\"===o&&\"y\"===t._id.charAt(0)&&(e.dy-=e.fontSize/6))}else{if(\"D\"!==u)throw\"unrecognized dtick \"+String(o);e.text=String(Math.round(Math.pow(10,s.mod(l,1)))),e.fontSize*=.75}if(\"D1\"===t.dtick){var d=String(e.text).charAt(0);\"0\"!==d&&\"1\"!==d||(\"y\"===t._id.charAt(0)?e.dx-=e.fontSize/4:(e.dy+=e.fontSize/2,e.dx+=(t.range[1]>t.range[0]?1:-1)*e.fontSize*(l<0?.5:.25)))}}(t,o,0,c,g):\"category\"===u?function(t,e){var r=t._categories[Math.round(e.x)];void 0===r&&(r=\"\");e.text=String(r)}(t,o):\"multicategory\"===u?function(t,e,r){var n=Math.round(e.x),i=t._categories[n]||[],a=void 0===i[1]?\"\":String(i[1]),o=void 0===i[0]?\"\":String(i[0]);r?e.text=o+\" - \"+a:(e.text=a,e.text2=o)}(t,o,r):rt(t)?function(t,e,r,n,i){if(\"radians\"!==t.thetaunit||r)e.text=G(e.x,t,i,n);else{var a=e.x/180;if(0===a)e.text=\"0\";else{var o=function(t){function e(t,e){return Math.abs(t-e)<=1e-6}var r=function(t){var r=1;for(;!e(Math.round(t*r)/r,t);)r*=10;return r}(t),n=t*r,i=Math.abs(function t(r,n){return e(n,0)?r:t(n,r%n)}(n,r));return[Math.round(n/i),Math.round(r/i)]}(a);if(o[1]>=100)e.text=G(s.deg2rad(e.x),t,i,n);else{var l=e.x<0;1===o[1]?1===o[0]?e.text=\"\\u03c0\":e.text=o[0]+\"\\u03c0\":e.text=[\"<sup>\",o[0],\"</sup>\",\"\\u2044\",\"<sub>\",o[1],\"</sub>\",\"\\u03c0\"].join(\"\"),l&&(e.text=_+e.text)}}}}(t,o,r,c,g):function(t,e,r,n,i){\"never\"===i?i=\"\":\"all\"===t.showexponent&&Math.abs(e.x/t.dtick)<1e-6&&(i=\"hide\");e.text=G(e.x,t,i,n)}(t,o,0,c,g),n||(t.tickprefix&&!d(t.showtickprefix)&&(o.text=t.tickprefix+o.text),t.ticksuffix&&!d(t.showticksuffix)&&(o.text+=t.ticksuffix)),\"boundaries\"===t.tickson||t.showdividers){var v=function(e){var r=t.l2p(e);return r>=0&&r<=t._length?e:null};o.xbnd=[v(o.x-.5),v(o.x+t.dtick-.5)]}return o},A.hoverLabelText=function(t,e,r){if(r!==w&&r!==e)return A.hoverLabelText(t,e)+\" - \"+A.hoverLabelText(t,r);var n=\"log\"===t.type&&e<=0,i=A.tickText(t,t.c2l(n?-e:e),\"hover\").text;return n?0===e?\"0\":_+i:i};var V=[\"f\",\"p\",\"n\",\"\\u03bc\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\"];function q(t){return\"SI\"===t||\"B\"===t}function H(t){return t>14||t<-15}function G(t,e,r,n){var a=t<0,o=e._tickround,l=r||e.exponentformat||\"B\",c=e._tickexponent,u=A.getTickFormat(e),h=e.separatethousands;if(n){var f={exponentformat:l,dtick:\"none\"===e.showexponent?e.dtick:i(t)&&Math.abs(t)||1,range:\"none\"===e.showexponent?e.range.map(e.r2d):[0,t||1]};j(f),o=(Number(f._tickround)||0)+4,c=f._tickexponent,e.hoverformat&&(u=e.hoverformat)}if(u)return e._numFormat(u)(t).replace(/-/g,_);var p,d=Math.pow(10,-o)/2;if(\"none\"===l&&(c=0),(t=Math.abs(t))<d)t=\"0\",a=!1;else{if(t+=d,c&&(t*=Math.pow(10,-c),o+=c),0===o)t=String(Math.floor(t));else if(o<0){t=(t=String(Math.round(t))).substr(0,t.length+o);for(var g=o;g<0;g++)t+=\"0\"}else{var v=(t=String(t)).indexOf(\".\")+1;v&&(t=t.substr(0,v+o).replace(/\\.?0+$/,\"\"))}t=s.numSeparate(t,e._separators,h)}c&&\"hide\"!==l&&(q(l)&&H(c)&&(l=\"power\"),p=c<0?_+-c:\"power\"!==l?\"+\"+c:String(c),\"e\"===l||\"E\"===l?t+=l+p:\"power\"===l?t+=\"\\xd710<sup>\"+p+\"</sup>\":\"B\"===l&&9===c?t+=\"B\":q(l)&&(t+=V[c/3+5]));return a?_+t:t}function Y(t,e){var r=t._id.charAt(0),n=t._tickAngles[e]||0,i=s.deg2rad(n),a=Math.sin(i),o=Math.cos(i),l=0,c=0;return t._selections[e].each(function(){var t=J(this),e=h.bBox(t.node()),r=e.width,n=e.height;l=Math.max(l,o*r,a*n),c=Math.max(c,a*r,o*n)}),{x:c,y:l}[r]}function W(t){return[t.text,t.x,t.axInfo,t.font,t.fontSize,t.fontColor].join(\"_\")}function X(t,e){var r,n=t._fullLayout._size,i=e._id.charAt(0),a=e.side;return\"free\"!==e.anchor?r=S.getFromId(t,e.anchor):\"x\"===i?r={_offset:n.t+(1-(e.position||0))*n.h,_length:0}:\"y\"===i&&(r={_offset:n.l+(e.position||0)*n.w,_length:0}),\"top\"===a||\"left\"===a?r._offset:\"bottom\"===a||\"right\"===a?r._offset+r._length:void 0}function Z(t,e){var r=t.l2p(e);return r>1&&r<t._length-1}function J(t){var e=n.select(t),r=e.select(\".text-math-group\");return r.empty()?e.select(\"text\"):r}function K(t){return t._id+\".automargin\"}function $(t){return t._id+\".rangeslider\"}function Q(t,e){for(var r=0;r<e.length;r++)-1===t.indexOf(e[r])&&t.push(e[r])}function tt(t,e,r){var n,i,a=[],o=[],l=t.layout;for(n=0;n<e.length;n++)a.push(A.getFromId(t,e[n]));for(n=0;n<r.length;n++)o.push(A.getFromId(t,r[n]));var c=Object.keys(f),u=[\"anchor\",\"domain\",\"overlaying\",\"position\",\"side\",\"tickangle\",\"editType\"],h=[\"linear\",\"log\"];for(n=0;n<c.length;n++){var p=c[n],d=a[0][p],g=o[0][p],v=!0,m=!1,y=!1;if(\"_\"!==p.charAt(0)&&\"function\"!=typeof d&&-1===u.indexOf(p)){for(i=1;i<a.length&&v;i++){var x=a[i][p];\"type\"===p&&-1!==h.indexOf(d)&&-1!==h.indexOf(x)&&d!==x?m=!0:x!==d&&(v=!1)}for(i=1;i<o.length&&v;i++){var b=o[i][p];\"type\"===p&&-1!==h.indexOf(g)&&-1!==h.indexOf(b)&&g!==b?y=!0:o[i][p]!==g&&(v=!1)}v&&(m&&(l[a[0]._name].type=\"linear\"),y&&(l[o[0]._name].type=\"linear\"),et(l,p,a,o,t._fullLayout._dfltTitle))}}for(n=0;n<t._fullLayout.annotations.length;n++){var _=t._fullLayout.annotations[n];-1!==e.indexOf(_.xref)&&-1!==r.indexOf(_.yref)&&s.swapAttrs(l.annotations[n],[\"?\"])}}function et(t,e,r,n,i){var a,o=s.nestedProperty,l=o(t[r[0]._name],e).get(),c=o(t[n[0]._name],e).get();for(\"title\"===e&&(l&&l.text===i.x&&(l.text=i.y),c&&c.text===i.y&&(c.text=i.x)),a=0;a<r.length;a++)o(t,r[a]._name+\".\"+e).set(c);for(a=0;a<n.length;a++)o(t,n[a]._name+\".\"+e).set(l)}function rt(t){return\"angularaxis\"===t._id}A.getTickFormat=function(t){var e,r,n,i,a,o,s,l;function c(t){return\"string\"!=typeof t?t:Number(t.replace(\"M\",\"\"))*v}function u(t,e){var r=[\"L\",\"D\"];if(typeof t==typeof e){if(\"number\"==typeof t)return t-e;var n=r.indexOf(t.charAt(0)),i=r.indexOf(e.charAt(0));return n===i?Number(t.replace(/(L|D)/g,\"\"))-Number(e.replace(/(L|D)/g,\"\")):n-i}return\"number\"==typeof t?1:-1}function h(t,e){var r=null===e[0],n=null===e[1],i=u(t,e[0])>=0,a=u(t,e[1])<=0;return(r||i)&&(n||a)}if(t.tickformatstops&&t.tickformatstops.length>0)switch(t.type){case\"date\":case\"linear\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&(i=t.dtick,a=n.dtickrange,o=void 0,void 0,void 0,o=c||function(t){return t},s=a[0],l=a[1],(!s&&\"number\"!=typeof s||o(s)<=o(i))&&(!l&&\"number\"!=typeof l||o(l)>=o(i)))){r=n;break}break;case\"log\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&h(t.dtick,n.dtickrange)){r=n;break}}return r?r.value:t.tickformat},A.getSubplots=function(t,e){var r=t._fullLayout._subplots,n=r.cartesian.concat(r.gl2d||[]),i=e?A.findSubplotsWithAxis(n,e):n;return i.sort(function(t,e){var r=t.substr(1).split(\"y\"),n=e.substr(1).split(\"y\");return r[0]===n[0]?+r[1]-+n[1]:+r[0]-+n[0]}),i},A.findSubplotsWithAxis=function(t,e){for(var r=new RegExp(\"x\"===e._id.charAt(0)?\"^\"+e._id+\"y\":e._id+\"$\"),n=[],i=0;i<t.length;i++){var a=t[i];r.test(a)&&n.push(a)}return n},A.makeClipPaths=function(t){var e=t._fullLayout;if(!e._hasOnlyLargeSploms){var r,i,a={_offset:0,_length:e.width,_id:\"\"},o={_offset:0,_length:e.height,_id:\"\"},s=A.list(t,\"x\",!0),l=A.list(t,\"y\",!0),c=[];for(r=0;r<s.length;r++)for(c.push({x:s[r],y:o}),i=0;i<l.length;i++)0===r&&c.push({x:a,y:l[i]}),c.push({x:s[r],y:l[i]});var u=e._clips.selectAll(\".axesclip\").data(c,function(t){return t.x._id+t.y._id});u.enter().append(\"clipPath\").classed(\"axesclip\",!0).attr(\"id\",function(t){return\"clip\"+e._uid+t.x._id+t.y._id}).append(\"rect\"),u.exit().remove(),u.each(function(t){n.select(this).select(\"rect\").attr({x:t.x._offset||0,y:t.y._offset||0,width:t.x._length||1,height:t.y._length||1})})}},A.draw=function(t,e,r){var n=t._fullLayout;\"redraw\"===e&&n._paper.selectAll(\"g.subplot\").each(function(t){var e=t[0],r=n._plots[e],i=r.xaxis,a=r.yaxis;r.xaxislayer.selectAll(\".\"+i._id+\"tick\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"tick2\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick2\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"divider\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"divider\").remove(),r.gridlayer&&r.gridlayer.selectAll(\"path\").remove(),r.zerolinelayer&&r.zerolinelayer.selectAll(\"path\").remove(),n._infolayer.select(\".g-\"+i._id+\"title\").remove(),n._infolayer.select(\".g-\"+a._id+\"title\").remove()});var i=e&&\"redraw\"!==e?e:A.listIds(t);return s.syncOrAsync(i.map(function(e){return function(){if(e){var n=A.getFromId(t,e),i=A.drawOne(t,n,r);return n._r=n.range.slice(),n._rl=s.simpleMap(n._r,n.r2l),i}}}))},A.drawOne=function(t,e,r){var n,i,l;r=r||{},e.setScale();var f=t._fullLayout,p=e._id,d=p.charAt(0),g=A.counterLetter(p),v=e._mainSubplot,m=e._mainLinePosition,y=e._mainMirrorPosition,x=f._plots[v][d+\"axislayer\"],b=e._subplotsWith,_=e._vals=A.calcTicks(e),w=[e.mirror,m,y].join(\"_\");for(n=0;n<_.length;n++)_[n].axInfo=w;if(e.visible){e._selections={},e._tickAngles={};var k,M,S=A.makeTransFn(e);if(\"boundaries\"===e.tickson){var E=function(t,e){var r,n=[],i=function(t,e){var r=t.xbnd[e];null!==r&&n.push(s.extendFlat({},t,{x:r}))};if(e.length){for(r=0;r<e.length;r++)i(e[r],0);i(e[r-1],1)}return n}(0,_);M=A.clipEnds(e,E),k=\"inside\"===e.ticks?M:E}else M=A.clipEnds(e,_),k=\"inside\"===e.ticks?M:_;var C=e._gridVals=M,L=function(t,e){var r,n,i=[],a=function(t,e){var r=t.xbnd[e];null!==r&&i.push(s.extendFlat({},t,{x:r}))};if(t.showdividers&&e.length){for(r=0;r<e.length;r++){var o=e[r];o.text2!==n&&a(o,0),n=o.text2}a(e[r-1],1)}return i}(e,_);if(!f._hasOnlyLargeSploms){var P={};for(n=0;n<b.length;n++){i=b[n];var O=(l=f._plots[i])[g+\"axis\"],z=O._mainAxis._id;if(!P[z]){P[z]=1;var I=\"x\"===d?\"M0,\"+O._offset+\"v\"+O._length:\"M\"+O._offset+\",0h\"+O._length;A.drawGrid(t,e,{vals:C,counterAxis:O,layer:l.gridlayer.select(\".\"+p),path:I,transFn:S}),A.drawZeroLine(t,e,{counterAxis:O,layer:l.zerolinelayer,path:I,transFn:S})}}}var D=A.getTickSigns(e),R=[];if(e.ticks){var F,B,N,j=A.makeTickPath(e,m,D[2]);if(e._anchorAxis&&e.mirror&&!0!==e.mirror?(F=A.makeTickPath(e,y,D[3]),B=j+F):(F=\"\",B=j),e.showdividers&&\"outside\"===e.ticks&&\"boundaries\"===e.tickson){var V={};for(n=0;n<L.length;n++)V[L[n].x]=1;N=function(t){return V[t.x]?F:B}}else N=B;A.drawTicks(t,e,{vals:k,layer:x,path:N,transFn:S}),R=Object.keys(e._linepositions||{})}for(n=0;n<R.length;n++){i=R[n],l=f._plots[i];var q=e._linepositions[i]||[],H=A.makeTickPath(e,q[0],D[0])+A.makeTickPath(e,q[1],D[1]);A.drawTicks(t,e,{vals:k,layer:l[d+\"axislayer\"],path:H,transFn:S})}var G=[];if(G.push(function(){return A.drawLabels(t,e,{vals:_,layer:x,transFn:S,labelFns:A.makeLabelFns(e,m)})}),\"multicategory\"===e.type){var Z=0,J={x:2,y:10}[d],Q=D[2]*(\"inside\"===e.ticks?-1:1);G.push(function(){return Z+=Y(e,p+\"tick\")+J,Z+=e._tickAngles[p+\"tick\"]?e.tickfont.size*T:0,A.drawLabels(t,e,{vals:function(t,e){for(var r=[],n={},i=0;i<e.length;i++){var a=e[i];n[a.text2]?n[a.text2].push(a.x):n[a.text2]=[a.x]}for(var o in n)r.push(U(t,s.interp(n[o],.5),o));return r}(e,_),layer:x,cls:p+\"tick2\",repositionOnUpdate:!0,secondary:!0,transFn:S,labelFns:A.makeLabelFns(e,m+Z*Q)})}),G.push(function(){return Z+=Y(e,p+\"tick2\"),e._labelLength=Z,function(t,e,r){var n=e._id+\"divider\",i=r.vals,a=r.layer.selectAll(\"path.\"+n).data(i,W);a.exit().remove(),a.enter().insert(\"path\",\":first-child\").classed(n,1).classed(\"crisp\",1).call(u.stroke,e.dividercolor).style(\"stroke-width\",h.crispRound(t,e.dividerwidth,1)+\"px\"),a.attr(\"transform\",r.transFn).attr(\"d\",r.path)}(t,e,{vals:L,layer:x,path:A.makeTickPath(e,m,Q,Z),transFn:S})})}var tt=o.getComponentMethod(\"rangeslider\",\"isVisible\")(e);return G.push(function(){if(e.showticklabels){var r=t.getBoundingClientRect(),n=x.node().getBoundingClientRect();e._boundingBox={width:n.width,height:n.height,left:n.left-r.left,right:n.right-r.left,top:n.top-r.top,bottom:n.bottom-r.top}}else{var i,a=f._size;\"x\"===d?(i=\"free\"===e.anchor?a.t+a.h*(1-e.position):a.t+a.h*(1-e._anchorAxis.domain[{bottom:0,top:1}[e.side]]),e._boundingBox={top:i,bottom:i,left:e._offset,right:e._offset+e._length,width:e._length,height:0}):(i=\"free\"===e.anchor?a.l+a.w*e.position:a.l+a.w*e._anchorAxis.domain[{left:0,right:1}[e.side]],e._boundingBox={left:i,right:i,bottom:e._offset+e._length,top:e._offset,height:e._length,width:0})}if(b){for(var o=e._counterSpan=[1/0,-1/0],s=0;s<b.length;s++){var l=f._plots[b[s]][\"x\"===d?\"yaxis\":\"xaxis\"];et(o,[l._offset,l._offset+l._length])}\"free\"===e.anchor&&et(o,\"x\"===d?[e._boundingBox.bottom,e._boundingBox.top]:[e._boundingBox.right,e._boundingBox.left])}},function(){var r,n,i=e.side.charAt(0);if(tt&&(n=o.getComponentMethod(\"rangeslider\",\"autoMarginOpts\")(t,e)),a.autoMargin(t,$(e),n),e.automargin&&(!tt||\"b\"!==i)){r={x:0,y:0,r:0,l:0,t:0,b:0};var s,l,c=e._boundingBox,u=X(t,e);switch(d+i){case\"xb\":s=0,l=c.top-u,r[i]=c.height;break;case\"xt\":s=1,l=u-c.bottom,r[i]=c.height;break;case\"yl\":s=0,l=u-c.right,r[i]=c.width;break;case\"yr\":s=1,l=c.left-u,r[i]=c.width}if(r[g]=\"free\"===e.anchor?e.position:e._anchorAxis.domain[s],r[i]>0&&(r[i]+=l),e.title.text!==f._dfltTitle[d]&&(r[i]+=e.title.font.size),\"x\"===d&&c.width>0){var h=c.right-(e._offset+e._length);h>0&&(r.x=1,r.r=h);var p=e._offset-c.left;p>0&&(r.x=0,r.l=p)}else if(\"y\"===d&&c.height>0){var v=c.bottom-(e._offset+e._length);v>0&&(r.y=0,r.b=v);var m=e._offset-c.top;m>0&&(r.y=1,r.t=m)}}a.autoMargin(t,K(e),r)}),r.skipTitle||tt&&e._boundingBox&&\"bottom\"===e.side||G.push(function(){return function(t,e){var r,n=t._fullLayout,i=e._id,a=i.charAt(0),o=e.title.font.size;if(\"multicategory\"===e.type)r=e._labelLength;else{r=10+1.5*o+(e.linewidth?e.linewidth-1:0)}var s,l,u,f,p=X(t,e);\"x\"===a?(l=e._offset+e._length/2,u=\"top\"===e.side?-r-o*(e.showticklabels?1:0):r+o*(e.showticklabels?1.5:.5),u+=p):(u=e._offset+e._length/2,l=\"right\"===e.side?r+o*(e.showticklabels?1:.5):-r-o*(e.showticklabels?.5:0),l+=p,s={rotate:\"-90\",offset:0});if(\"multicategory\"!==e.type){var d=e._selections[e._id+\"tick\"];if(f={selection:d,side:e.side},d&&d.node()&&d.node().parentNode){var g=h.getTranslate(d.node().parentNode);f.offsetLeft=g.x,f.offsetTop=g.y}}return c.draw(t,i+\"title\",{propContainer:e,propName:e._name+\".title.text\",placeholder:n._dfltTitle[a],avoid:f,transform:s,attributes:{x:l,y:u,\"text-anchor\":\"middle\"}})}(t,e)}),s.syncOrAsync(G)}function et(t,e){t[0]=Math.min(t[0],e[0]),t[1]=Math.max(t[1],e[1])}},A.getTickSigns=function(t){var e=t._id.charAt(0),r={x:\"top\",y:\"right\"}[e],n=t.side===r?1:-1,i=[-1,1,n,-n];return\"inside\"!==t.ticks==(\"x\"===e)&&(i=i.map(function(t){return-t})),i},A.makeTransFn=function(t){var e=t._id.charAt(0),r=t._offset;return\"x\"===e?function(e){return\"translate(\"+(r+t.l2p(e.x))+\",0)\"}:function(e){return\"translate(0,\"+(r+t.l2p(e.x))+\")\"}},A.makeTickPath=function(t,e,r,n){n=void 0!==n?n:t.ticklen;var i=t._id.charAt(0),a=(t.linewidth||1)/2;return\"x\"===i?\"M0,\"+(e+a*r)+\"v\"+n*r:\"M\"+(e+a*r)+\",0h\"+n*r},A.makeLabelFns=function(t,e,r){var n=t._id.charAt(0),a=\"boundaries\"!==t.tickson&&\"outside\"===t.ticks,o=0,l=0;if(a&&(o+=t.ticklen),r&&\"outside\"===t.ticks){var c=s.deg2rad(r);o=t.ticklen*Math.cos(c)+1,l=t.ticklen*Math.sin(c)}t.showticklabels&&(a||t.showline)&&(o+=.2*t.tickfont.size);var u,h,f,p,d={labelStandoff:o+=(t.linewidth||1)/2,labelShift:l};return\"x\"===n?(p=\"bottom\"===t.side?1:-1,u=l*p,h=e+o*p,f=\"bottom\"===t.side?1:-.2,d.xFn=function(t){return t.dx+u},d.yFn=function(t){return t.dy+h+t.fontSize*f},d.anchorFn=function(t,e){return i(e)&&0!==e&&180!==e?e*p<0?\"end\":\"start\":\"middle\"},d.heightFn=function(e,r,n){return r<-60||r>60?-.5*n:\"top\"===t.side?-n:0}):\"y\"===n&&(p=\"right\"===t.side?1:-1,u=o,h=-l*p,f=90===Math.abs(t.tickangle)?.5:0,d.xFn=function(t){return t.dx+e+(u+t.fontSize*f)*p},d.yFn=function(t){return t.dy+h+t.fontSize*k},d.anchorFn=function(e,r){return i(r)&&90===Math.abs(r)?\"middle\":\"right\"===t.side?\"start\":\"end\"},d.heightFn=function(e,r,n){return(r*=\"left\"===t.side?1:-1)<-30?-n:r<30?-.5*n:0}),d},A.drawTicks=function(t,e,r){r=r||{};var n=e._id+\"tick\",i=r.layer.selectAll(\"path.\"+n).data(e.ticks?r.vals:[],W);i.exit().remove(),i.enter().append(\"path\").classed(n,1).classed(\"ticks\",1).classed(\"crisp\",!1!==r.crisp).call(u.stroke,e.tickcolor).style(\"stroke-width\",h.crispRound(t,e.tickwidth,1)+\"px\").attr(\"d\",r.path),i.attr(\"transform\",r.transFn)},A.drawGrid=function(t,e,r){r=r||{};var n=e._id+\"grid\",i=r.vals,a=r.counterAxis;if(!1===e.showgrid)i=[];else if(a&&A.shouldShowZeroLine(t,e,a))for(var o=\"array\"===e.tickmode,s=0;s<i.length;s++){var l=i[s].x;if(o?!l:Math.abs(l)<e.dtick/100){if(i=i.slice(0,s).concat(i.slice(s+1)),!o)break;s--}}var c=r.layer.selectAll(\"path.\"+n).data(i,W);c.exit().remove(),c.enter().append(\"path\").classed(n,1).classed(\"crisp\",!1!==r.crisp),e._gw=h.crispRound(t,e.gridwidth,1),c.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(u.stroke,e.gridcolor||\"#ddd\").style(\"stroke-width\",e._gw+\"px\"),\"function\"==typeof r.path&&c.attr(\"d\",r.path)},A.drawZeroLine=function(t,e,r){r=r||r;var n=e._id+\"zl\",i=A.shouldShowZeroLine(t,e,r.counterAxis),a=r.layer.selectAll(\"path.\"+n).data(i?[{x:0,id:e._id}]:[]);a.exit().remove(),a.enter().append(\"path\").classed(n,1).classed(\"zl\",1).classed(\"crisp\",!1!==r.crisp).each(function(){r.layer.selectAll(\"path\").sort(function(t,e){return S.idSort(t.id,e.id)})}),a.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(u.stroke,e.zerolinecolor||u.defaultLine).style(\"stroke-width\",h.crispRound(t,e.zerolinewidth,e._gw||1)+\"px\")},A.drawLabels=function(t,e,r){r=r||{};var a=e._id,o=a.charAt(0),c=r.cls||a+\"tick\",u=r.vals,f=r.labelFns,p=r.secondary?0:e.tickangle,d=(e._tickAngles||{})[c],g=r.layer.selectAll(\"g.\"+c).data(e.showticklabels?u:[],W),v=[];function m(t,e){t.each(function(t){var a=n.select(this),o=a.select(\".text-math-group\"),s=f.anchorFn(t,e),c=r.transFn.call(a.node(),t)+(i(e)&&0!=+e?\" rotate(\"+e+\",\"+f.xFn(t)+\",\"+(f.yFn(t)-t.fontSize/2)+\")\":\"\"),u=l.lineCount(a),p=T*t.fontSize,d=f.heightFn(t,i(e)?+e:0,(u-1)*p);if(d&&(c+=\" translate(0, \"+d+\")\"),o.empty())a.select(\"text\").attr({transform:c,\"text-anchor\":s});else{var g=h.bBox(o.node()).width*{end:-.5,start:.5}[s];o.attr(\"transform\",c+(g?\"translate(\"+g+\",0)\":\"\"))}})}g.enter().append(\"g\").classed(c,1).append(\"text\").attr(\"text-anchor\",\"middle\").each(function(e){var r=n.select(this),i=t._promises.length;r.call(l.positionText,f.xFn(e),f.yFn(e)).call(h.font,e.font,e.fontSize,e.fontColor).text(e.text).call(l.convertToTspans,t),t._promises[i]?v.push(t._promises.pop().then(function(){m(r,p)})):m(r,p)}),g.exit().remove(),r.repositionOnUpdate&&g.each(function(t){n.select(this).select(\"text\").call(l.positionText,f.xFn(t),f.yFn(t))}),m(g,d||p),e._selections&&(e._selections[c]=g);var y=s.syncOrAsync([function(){return v.length&&Promise.all(v)},function(){m(g,p);var t=null;if(u.length&&\"x\"===o&&!i(p)&&(\"log\"!==e.type||\"D\"!==String(e.dtick).charAt(0))){t=0;var n,a=0,l=[];if(g.each(function(t){a=Math.max(a,t.fontSize);var r=e.l2p(t.x),n=J(this),i=h.bBox(n.node());l.push({top:0,bottom:10,height:10,left:r-i.width/2,right:r+i.width/2+2,width:i.width+2})}),\"boundaries\"!==e.tickson&&!e.showdividers||r.secondary){var f=u.length,d=Math.abs((u[f-1].x-u[0].x)*e._m)/(f-1)<2.5*a||\"multicategory\"===e.type;for(n=0;n<l.length-1;n++)if(s.bBoxIntersect(l[n],l[n+1])){t=d?90:30;break}}else{var v=2;for(e.ticks&&(v+=e.tickwidth/2),n=0;n<l.length;n++){var y=u[n].xbnd,x=l[n];if(null!==y[0]&&x.left-e.l2p(y[0])<v||null!==y[1]&&e.l2p(y[1])-x.right<v){t=90;break}}}t&&m(g,t)}e._tickAngles&&(e._tickAngles[c]=null===t?i(p)?p:0:t)}]);return y&&y.then&&t._promises.push(y),y},A.shouldShowZeroLine=function(t,e,r){var n=s.simpleMap(e.range,e.r2l);return n[0]*n[1]<=0&&e.zeroline&&(\"linear\"===e.type||\"-\"===e.type)&&e._gridVals.length&&(Z(e,0)||!function(t,e,r,n){var i=r._mainAxis;if(!i)return;var a=t._fullLayout,o=e._id.charAt(0),s=A.counterLetter(e._id),l=e._offset+(Math.abs(n[0])<Math.abs(n[1])==(\"x\"===o)?0:e._length);function c(t){if(!t.showline||!t.linewidth)return!1;var r=Math.max((t.linewidth+e.zerolinewidth)/2,1);function n(t){return\"number\"==typeof t&&Math.abs(t-l)<r}if(n(t._mainLinePosition)||n(t._mainMirrorPosition))return!0;var i=t._linepositions||{};for(var a in i)if(n(i[a][0])||n(i[a][1]))return!0}var u=a._plots[r._mainSubplot];if(!(u.mainplotinfo||u).overlays.length)return c(r);for(var h=A.list(t,s),f=0;f<h.length;f++){var p=h[f];if(p._mainAxis===i&&c(p))return!0}}(t,e,r,n)||function(t,e){for(var r=t._fullData,n=e._mainSubplot,i=e._id.charAt(0),a=0;a<r.length;a++){var s=r[a];if(!0===s.visible&&s.xaxis+s.yaxis===n){if(o.traceIs(s,\"bar-like\")&&s.orientation==={x:\"h\",y:\"v\"}[i])return!0;if(s.fill&&s.fill.charAt(s.fill.length-1)===i)return!0}}return!1}(t,e))},A.clipEnds=function(t,e){return e.filter(function(e){return Z(t,e.x)})},A.allowAutoMargin=function(t){for(var e=A.list(t,\"\",!0),r=0;r<e.length;r++){var n=e[r];n.automargin&&a.allowAutoMargin(t,K(n)),o.getComponentMethod(\"rangeslider\",\"isVisible\")(n)&&a.allowAutoMargin(t,$(n))}},A.swap=function(t,e){for(var r=function(t,e){var r,n,i=[];for(r=0;r<e.length;r++){var a=[],o=t._fullData[e[r]].xaxis,s=t._fullData[e[r]].yaxis;if(o&&s){for(n=0;n<i.length;n++)-1===i[n].x.indexOf(o)&&-1===i[n].y.indexOf(s)||a.push(n);if(a.length){var l,c=i[a[0]];if(a.length>1)for(n=1;n<a.length;n++)l=i[a[n]],Q(c.x,l.x),Q(c.y,l.y);Q(c.x,[o]),Q(c.y,[s])}else i.push({x:[o],y:[s]})}}return i}(t,e),n=0;n<r.length;n++)tt(t,r[n].x,r[n].y)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../components/titles\":681,\"../../constants/alignment\":688,\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/plots\":828,\"../../registry\":847,\"./autorange\":766,\"./axis_autotype\":768,\"./axis_ids\":770,\"./clean_ticks\":772,\"./layout_attributes\":779,\"./set_convert\":785,d3:163,\"fast-isnumeric\":225}],768:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){return!(r=r||{}).noMultiCategory&&(o=t,i.isArrayOrTypedArray(o[0])&&i.isArrayOrTypedArray(o[1]))?\"multicategory\":function(t,e){for(var r=Math.max(1,(t.length-1)/1e3),a=0,o=0,s={},l=0;l<t.length;l+=r){var c=t[Math.round(l)],u=String(c);s[u]||(s[u]=1,i.isDateTime(c,e)&&(a+=1),n(c)&&(o+=1))}return a>2*o}(t,e)?\"date\":function(t){for(var e=Math.max(1,(t.length-1)/1e3),r=0,n=0,o={},s=0;s<t.length;s+=e){var l=t[Math.round(s)],c=String(l);o[c]||(o[c]=1,\"boolean\"==typeof l?n++:i.cleanNumber(l)!==a?r++:\"string\"==typeof l&&n++)}return n>2*r}(t)?\"category\":function(t){if(!t)return!1;for(var e=0;e<t.length;e++)if(n(t[e]))return!0;return!1}(t)?\"linear\":\"-\";var o}},{\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],769:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./layout_attributes\"),o=t(\"./tick_value_defaults\"),s=t(\"./tick_mark_defaults\"),l=t(\"./tick_label_defaults\"),c=t(\"./category_order_defaults\"),u=t(\"./line_grid_defaults\"),h=t(\"./set_convert\");e.exports=function(t,e,r,f,p){var d=f.letter,g=f.font||{},v=f.splomStash||{},m=r(\"visible\",!f.visibleDflt),y=e.type;\"date\"===y&&n.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",f.calendar);h(e,p);var x=!e.isValidRange(t.range);x&&f.reverseDflt&&(x=\"reversed\"),!r(\"autorange\",x)||\"linear\"!==y&&\"-\"!==y||r(\"rangemode\"),r(\"range\"),e.cleanRange(),c(t,e,r,f),\"category\"===y||f.noHover||r(\"hoverformat\");var b=r(\"color\"),_=b!==a.color.dflt?b:g.color,w=v.label||p._dfltTitle[d];if(l(t,e,r,y,f,{pass:1}),!m)return e;r(\"title.text\",w),i.coerceFont(r,\"title.font\",{family:g.family,size:Math.round(1.2*g.size),color:_}),o(t,e,r,y),l(t,e,r,y,f,{pass:2}),s(t,e,r,f),u(t,e,r,{dfltColor:b,bgColor:f.bgColor,showGrid:f.showGrid,attributes:a}),(e.showline||e.ticks)&&r(\"mirror\"),f.automargin&&r(\"automargin\");var k,T=\"multicategory\"===e.type;f.noTickson||\"category\"!==e.type&&!T||!e.ticks&&!e.showgrid||(T&&(k=\"boundaries\"),r(\"tickson\",k));T&&(r(\"showdividers\")&&(r(\"dividercolor\"),r(\"dividerwidth\")));return e}},{\"../../lib\":719,\"../../registry\":847,\"./category_order_defaults\":771,\"./layout_attributes\":779,\"./line_grid_defaults\":781,\"./set_convert\":785,\"./tick_label_defaults\":786,\"./tick_mark_defaults\":787,\"./tick_value_defaults\":788}],770:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./constants\");r.id2name=function(t){if(\"string\"==typeof t&&t.match(i.AX_ID_PATTERN)){var e=t.substr(1);return\"1\"===e&&(e=\"\"),t.charAt(0)+\"axis\"+e}},r.name2id=function(t){if(t.match(i.AX_NAME_PATTERN)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),t.charAt(0)+e}},r.cleanId=function(t,e){if(t.match(i.AX_ID_PATTERN)&&(!e||t.charAt(0)===e)){var r=t.substr(1).replace(/^0+/,\"\");return\"1\"===r&&(r=\"\"),t.charAt(0)+r}},r.list=function(t,e,n){var i=t._fullLayout;if(!i)return[];var a,o=r.listIds(t,e),s=new Array(o.length);for(a=0;a<o.length;a++){var l=o[a];s[a]=i[l.charAt(0)+\"axis\"+l.substr(1)]}if(!n){var c=i._subplots.gl3d||[];for(a=0;a<c.length;a++){var u=i[c[a]];e?s.push(u[e+\"axis\"]):s.push(u.xaxis,u.yaxis,u.zaxis)}}return s},r.listIds=function(t,e){var r=t._fullLayout;if(!r)return[];var n=r._subplots;return e?n[e+\"axis\"]:n.xaxis.concat(n.yaxis)},r.getFromId=function(t,e,n){var i=t._fullLayout;return\"x\"===n?e=e.replace(/y[0-9]*/,\"\"):\"y\"===n&&(e=e.replace(/x[0-9]*/,\"\")),i[r.id2name(e)]},r.getFromTrace=function(t,e,i){var a=t._fullLayout,o=null;if(n.traceIs(e,\"gl3d\")){var s=e.scene;\"scene\"===s.substr(0,5)&&(o=a[s][i+\"axis\"])}else o=r.getFromId(t,e[i+\"axis\"]||i);return o},r.idSort=function(t,e){var r=t.charAt(0),n=e.charAt(0);return r!==n?r>n?1:-1:+(t.substr(1)||1)-+(e.substr(1)||1)},r.getAxisGroup=function(t,e){for(var r=t._axisMatchGroups,n=0;n<r.length;n++){if(r[n][e])return\"g\"+n}return e}},{\"../../registry\":847,\"./constants\":773}],771:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){if(\"category\"===e.type){var i,a=t.categoryarray,o=Array.isArray(a)&&a.length>0;o&&(i=\"array\");var s,l=r(\"categoryorder\",i);\"array\"===l&&(s=r(\"categoryarray\")),o||\"array\"!==l||(l=e.categoryorder=\"trace\"),\"trace\"===l?e._initialCategories=[]:\"array\"===l?e._initialCategories=s.slice():(s=function(t,e){var r,n,i,a=e.dataAttr||t._id.charAt(0),o={};if(e.axData)r=e.axData;else for(r=[],n=0;n<e.data.length;n++){var s=e.data[n];s[a+\"axis\"]===t._id&&r.push(s)}for(n=0;n<r.length;n++){var l=r[n][a];for(i=0;i<l.length;i++){var c=l[i];null!=c&&(o[c]=1)}}return Object.keys(o)}(e,n).sort(),\"category ascending\"===l?e._initialCategories=s:\"category descending\"===l&&(e._initialCategories=s.reverse()))}}},{}],772:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").ONEDAY;r.dtick=function(t,e){var r=\"log\"===e,i=\"date\"===e,o=\"category\"===e,s=i?a:1;if(!t)return s;if(n(t))return(t=Number(t))<=0?s:o?Math.max(1,Math.round(t)):i?Math.max(.1,t):t;if(\"string\"!=typeof t||!i&&!r)return s;var l=t.charAt(0),c=t.substr(1);return(c=n(c)?Number(c):0)<=0||!(i&&\"M\"===l&&c===Math.round(c)||r&&\"L\"===l||r&&\"D\"===l&&(1===c||2===c))?s:t},r.tick0=function(t,e,r,a){return\"date\"===e?i.cleanDate(t,i.dateTick0(r)):\"D1\"!==a&&\"D2\"!==a?n(t)?Number(t):0:void 0}},{\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],773:[function(t,e,r){\"use strict\";var n=t(\"../../lib/regex\").counter;e.exports={idRegex:{x:n(\"x\"),y:n(\"y\")},attrRegex:n(\"[xy]axis\"),xAxisMatch:n(\"xaxis\"),yAxisMatch:n(\"yaxis\"),AX_ID_PATTERN:/^[xyz][0-9]*$/,AX_NAME_PATTERN:/^[xyz]axis[0-9]*$/,SUBPLOT_PATTERN:/^x([0-9]*)y([0-9]*)$/,MINDRAG:8,MINSELECT:12,MINZOOM:20,DRAGGERSIZE:20,BENDPX:1.5,REDRAWDELAY:50,SELECTDELAY:100,SELECTID:\"-select\",DFLTRANGEX:[-1,6],DFLTRANGEY:[-1,4],traceLayerClasses:[\"heatmaplayer\",\"contourcarpetlayer\",\"contourlayer\",\"funnellayer\",\"waterfalllayer\",\"barlayer\",\"carpetlayer\",\"violinlayer\",\"boxlayer\",\"ohlclayer\",\"scattercarpetlayer\",\"scatterlayer\"],clipOnAxisFalseQuery:[\".scatterlayer\",\".barlayer\",\".funnellayer\",\".waterfalllayer\"],layerValue2layerClass:{\"above traces\":\"above\",\"below traces\":\"below\"}}},{\"../../lib/regex\":735}],774:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./axis_ids\").id2name,a=t(\"./scale_zoom\"),o=t(\"./autorange\").makePadFn,s=t(\"./autorange\").concatExtremes,l=t(\"../../constants/numerical\").ALMOST_EQUAL,c=t(\"../../constants/alignment\").FROM_BL;function u(t,e,r,n,a){var o,s,l,c,u=\"range\"!==a,h=n[i(e)].type,f=[];for(s=0;s<r.length;s++)if((l=r[s])!==e&&(c=n[i(l)]).type===h)if(c.fixedrange){if(u&&c.anchor){n[i(c.anchor)].fixedrange&&f.push(l)}}else f.push(l);for(o=0;o<t.length;o++)if(t[o][e]){var p=t[o],d=[];for(s=0;s<f.length;s++)p[l=f[s]]||d.push(l);return{linkableAxes:d,thisGroup:p}}return{linkableAxes:f,thisGroup:null}}function h(t,e,r,n,i){var a,o,s,l,c;null===e?((e={})[r]=1,c=t.length,t.push(e)):c=t.indexOf(e);var u=Object.keys(e);for(a=0;a<t.length;a++)if(s=t[a],a!==c&&s[n]){var h=s[n];for(o=0;o<u.length;o++)s[l=u[o]]=h*i*e[l];return void t.splice(c,1)}if(1!==i)for(o=0;o<u.length;o++)e[u[o]]*=i;e[n]=1}function f(t,e){var r=t._inputDomain,n=c[t.constraintoward],i=r[0]+(r[1]-r[0])*n;t.domain=t._input.domain=[i+(r[0]-i)/e,i+(r[1]-i)/e],t.setScale()}r.handleConstraintDefaults=function(t,e,r,i,a){var o,s,l,c,f=a._axisConstraintGroups,p=a._axisMatchGroups,d=e._id,g=d.charAt(0),v=((a._splomAxes||{})[g]||{})[d]||{},m=e._id,y=m.charAt(0),x=r(\"constrain\");if(n.coerce(t,e,{constraintoward:{valType:\"enumerated\",values:\"x\"===y?[\"left\",\"center\",\"right\"]:[\"bottom\",\"middle\",\"top\"],dflt:\"x\"===y?\"center\":\"middle\"}},\"constraintoward\"),!t.matches&&!v.matches||e.fixedrange||(s=u(p,m,i,a),o=n.coerce(t,e,{matches:{valType:\"enumerated\",values:s.linkableAxes||[],dflt:v.matches}},\"matches\")),o||!t.scaleanchor||e.fixedrange&&\"domain\"!==x||(c=u(f,m,i,a,x),l=n.coerce(t,e,{scaleanchor:{valType:\"enumerated\",values:c.linkableAxes||[]}},\"scaleanchor\")),o?(delete e.constrain,h(p,s.thisGroup,m,o,1)):-1!==i.indexOf(t.matches)&&n.warn(\"ignored \"+e._name+'.matches: \"'+t.matches+'\" to avoid either an infinite loop or because the target axis has fixed range.'),l){var b=r(\"scaleratio\");b||(b=e.scaleratio=1),h(f,c.thisGroup,m,l,b)}else-1!==i.indexOf(t.scaleanchor)&&n.warn(\"ignored \"+e._name+'.scaleanchor: \"'+t.scaleanchor+'\" to avoid either an infinite loop and possibly inconsistent scaleratios, or because the target axis has fixed range or this axis declares a *matches* constraint.')},r.enforce=function(t){var e,r,n,c,u,h,p,d=t._fullLayout,g=d._axisConstraintGroups||[];for(e=0;e<g.length;e++){var v=g[e],m=Object.keys(v),y=1/0,x=0,b=1/0,_={},w={},k=!1;for(r=0;r<m.length;r++)w[n=m[r]]=c=d[i(n)],c._inputDomain?c.domain=c._inputDomain.slice():c._inputDomain=c.domain.slice(),c._inputRange||(c._inputRange=c.range.slice()),c.setScale(),_[n]=u=Math.abs(c._m)/v[n],y=Math.min(y,u),\"domain\"!==c.constrain&&c._constraintShrinkable||(b=Math.min(b,u)),delete c._constraintShrinkable,x=Math.max(x,u),\"domain\"===c.constrain&&(k=!0);if(!(y>l*x)||k)for(r=0;r<m.length;r++)if(u=_[n=m[r]],h=(c=w[n]).constrain,u!==b||\"domain\"===h)if(p=u/b,\"range\"===h)a(c,p);else{var T=c._inputDomain,A=(c.domain[1]-c.domain[0])/(T[1]-T[0]),M=(c.r2l(c.range[1])-c.r2l(c.range[0]))/(c.r2l(c._inputRange[1])-c.r2l(c._inputRange[0]));if((p/=A)*M<1){c.domain=c._input.domain=T.slice(),a(c,p);continue}if(M<1&&(c.range=c._input.range=c._inputRange.slice(),p*=M),c.autorange){var S=c.r2l(c.range[0]),E=c.r2l(c.range[1]),C=(S+E)/2,L=C,P=C,O=Math.abs(E-C),z=C-O*p*1.0001,I=C+O*p*1.0001,D=o(c);f(c,p);var R,F,B=Math.abs(c._m),N=s(t,c),j=N.min,U=N.max;for(F=0;F<j.length;F++)(R=j[F].val-D(j[F])/B)>z&&R<L&&(L=R);for(F=0;F<U.length;F++)(R=U[F].val+D(U[F])/B)<I&&R>P&&(P=R);p/=(P-L)/(2*O),L=c.l2r(L),P=c.l2r(P),c.range=c._input.range=S<E?[L,P]:[P,L]}f(c,p)}}},r.clean=function(t,e){if(e._inputDomain){for(var r=!1,n=e._id,i=t._fullLayout._axisConstraintGroups,a=0;a<i.length;a++)if(i[a][n]){r=!0;break}r&&\"domain\"===e.constrain||(e._input.domain=e.domain=e._inputDomain,delete e._inputDomain)}}},{\"../../constants/alignment\":688,\"../../constants/numerical\":695,\"../../lib\":719,\"./autorange\":766,\"./axis_ids\":770,\"./scale_zoom\":783}],775:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"has-passive-events\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../components/color\"),u=t(\"../../components/drawing\"),h=t(\"../../components/fx\"),f=t(\"./axes\"),p=t(\"../../lib/setcursor\"),d=t(\"../../components/dragelement\"),g=t(\"../../constants/alignment\").FROM_TL,v=t(\"../../lib/clear_gl_canvases\"),m=t(\"../../plot_api/subroutines\").redrawReglTraces,y=t(\"../plots\"),x=t(\"./axis_ids\").getFromId,b=t(\"./select\").prepSelect,_=t(\"./select\").clearSelect,w=t(\"./select\").selectOnClick,k=t(\"./scale_zoom\"),T=t(\"./constants\"),A=T.MINDRAG,M=T.MINZOOM,S=!0;function E(t,e,r,n){var i=s.ensureSingle(t.draglayer,e,r,function(e){e.classed(\"drag\",!0).style({fill:\"transparent\",\"stroke-width\":0}).attr(\"data-subplot\",t.id)});return i.call(p,n),i.node()}function C(t,e,r,i,a,o,s){var l=E(t,\"rect\",e,r);return n.select(l).call(u.setRect,i,a,o,s),l}function L(t,e){for(var r=0;r<t.length;r++)if(!t[r].fixedrange)return e;return\"\"}function P(t,e,r,n,i){for(var a=0;a<t.length;a++){var o=t[a];if(!o.fixedrange){var s=o._rl[0],l=o._rl[1]-s;n[o._name+\".range[0]\"]=o.l2r(s+l*e),n[o._name+\".range[1]\"]=o.l2r(s+l*r)}}if(i&&i.length){var c=(e+(1-r))/2;P(i,c,1-c,n,[])}}function O(t,e){for(var r=0;r<t.length;r++){var n=t[r];n.fixedrange||(n.range=[n.l2r(n._rl[0]-e/n._m),n.l2r(n._rl[1]-e/n._m)])}}function z(t){return 1-(t>=0?Math.min(t,.9):1/(1/Math.max(t,-.3)+3.222))}function I(t,e,r,n,i){return t.append(\"path\").attr(\"class\",\"zoombox\").style({fill:e>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"transform\",\"translate(\"+r+\", \"+n+\")\").attr(\"d\",i+\"Z\")}function D(t,e,r){return t.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:c.background,stroke:c.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"transform\",\"translate(\"+e+\", \"+r+\")\").attr(\"d\",\"M0,0Z\")}function R(t,e,r,n,i,a){t.attr(\"d\",n+\"M\"+r.l+\",\"+r.t+\"v\"+r.h+\"h\"+r.w+\"v-\"+r.h+\"h-\"+r.w+\"Z\"),F(t,e,i,a)}function F(t,e,r,n){r||(t.transition().style(\"fill\",n>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),e.transition().style(\"opacity\",1).duration(200))}function B(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}function N(t){S&&t.data&&t._context.showTips&&(s.notifier(s._(t,\"Double-click to zoom back out\"),\"long\"),S=!1)}function j(t){return\"lasso\"===t||\"select\"===t}function U(t){var e=Math.floor(Math.min(t.b-t.t,t.r-t.l,M)/2);return\"M\"+(t.l-3.5)+\",\"+(t.t-.5+e)+\"h3v\"+-e+\"h\"+e+\"v-3h-\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.t-.5+e)+\"h-3v\"+-e+\"h\"+-e+\"v-3h\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.b+.5-e)+\"h-3v\"+e+\"h\"+-e+\"v3h\"+(e+3)+\"ZM\"+(t.l-3.5)+\",\"+(t.b+.5-e)+\"h3v\"+e+\"h\"+e+\"v3h-\"+(e+3)+\"Z\"}function V(t,e,r,n){for(var i,a,o,l,c=!1,u={},h={},f=0;f<e.length;f++){var p=e[f];for(i in r)if(p[i]){for(o in p)(\"x\"===o.charAt(0)?r:n)[o]||(u[o]=i);for(a in n)p[a]&&(c=!0)}for(a in n)if(p[a])for(l in p)(\"x\"===l.charAt(0)?r:n)[l]||(h[l]=a)}c&&(s.extendFlat(u,h),h={});var d={},g=[];for(o in u){var v=x(t,o);g.push(v),d[v._id]=v}var m={},y=[];for(l in h){var b=x(t,l);y.push(b),m[b._id]=b}return{xaHash:d,yaHash:m,xaxes:g,yaxes:y,xLinks:u,yLinks:h,isSubplotConstrained:c}}function q(t,e){if(a){var r=void 0!==t.onwheel?\"wheel\":\"mousewheel\";t._onwheel&&t.removeEventListener(r,t._onwheel),t._onwheel=e,t.addEventListener(r,e,{passive:!1})}else void 0!==t.onwheel?t.onwheel=e:void 0!==t.onmousewheel&&(t.onmousewheel=e)}function H(t){var e=[];for(var r in t)e.push(t[r]);return e}e.exports={makeDragBox:function(t,e,r,a,c,p,S,E){var F,G,Y,W,X,Z,J,K,$,Q,tt,et,rt,nt,it,at,ot,st,lt,ct,ut,ht=t._fullLayout._zoomlayer,ft=S+E===\"nsew\",pt=1===(S+E).length;function dt(){if(F=e.xaxis,G=e.yaxis,$=F._length,Q=G._length,J=F._offset,K=G._offset,(Y={})[F._id]=F,(W={})[G._id]=G,S&&E)for(var r=e.overlays,n=0;n<r.length;n++){var i=r[n].xaxis;Y[i._id]=i;var a=r[n].yaxis;W[a._id]=a}X=H(Y),Z=H(W),rt=L(X,E),nt=L(Z,S),it=!nt&&!rt,tt=V(t,t._fullLayout._axisConstraintGroups,Y,W),et=V(t,t._fullLayout._axisMatchGroups,Y,W),at=E||tt.isSubplotConstrained||et.isSubplotConstrained,ot=S||tt.isSubplotConstrained||et.isSubplotConstrained;var o=t._fullLayout;st=o._has(\"scattergl\"),lt=o._has(\"splom\"),ct=o._has(\"svg\")}dt();var gt=function(t,e,r){return t?\"nsew\"===t?r?\"\":\"pan\"===e?\"move\":\"crosshair\":t.toLowerCase()+\"-resize\":\"pointer\"}(nt+rt,t._fullLayout.dragmode,ft),vt=C(e,S+E+\"drag\",gt,r,a,c,p);if(it&&!ft)return vt.onmousedown=null,vt.style.pointerEvents=\"none\",vt;var mt,yt,xt,bt,_t,wt,kt,Tt,At,Mt,St={element:vt,gd:t,plotinfo:e};function Et(){St.plotinfo.selection=!1,_(t)}function Ct(r,i){var a=t._fullLayout.clickmode;if(B(t),2!==r||pt||function(){if(!t._transitioningWithDuration){var e=t._context.doubleClick,r=[];rt&&(r=r.concat(X)),nt&&(r=r.concat(Z)),et.xaxes&&(r=r.concat(et.xaxes)),et.yaxes&&(r=r.concat(et.yaxes));var n,i,a,s={};if(\"reset+autosize\"===e)for(e=\"autosize\",i=0;i<r.length;i++)if((n=r[i])._rangeInitial&&(n.range[0]!==n._rangeInitial[0]||n.range[1]!==n._rangeInitial[1])||!n._rangeInitial&&!n.autorange){e=\"reset\";break}if(\"autosize\"===e)for(i=0;i<r.length;i++)(n=r[i]).fixedrange||(s[n._name+\".autorange\"]=!0);else if(\"reset\"===e)for((rt||tt.isSubplotConstrained)&&(r=r.concat(tt.xaxes)),nt&&!tt.isSubplotConstrained&&(r=r.concat(tt.yaxes)),tt.isSubplotConstrained&&(rt?nt||(r=r.concat(Z)):r=r.concat(X)),i=0;i<r.length;i++)(n=r[i]).fixedrange||(n._rangeInitial?(a=n._rangeInitial,s[n._name+\".range[0]\"]=a[0],s[n._name+\".range[1]\"]=a[1]):s[n._name+\".autorange\"]=!0);t.emit(\"plotly_doubleclick\",null),o.call(\"_guiRelayout\",t,s)}}(),ft)a.indexOf(\"select\")>-1&&w(i,t,X,Z,e.id,St),a.indexOf(\"event\")>-1&&h.click(t,i,e.id);else if(1===r&&pt){var s=S?G:F,c=\"s\"===S||\"w\"===E?0:1,u=s._name+\".range[\"+c+\"]\",f=function(t,e){var r,i=t.range[e],a=Math.abs(i-t.range[1-e]);return\"date\"===t.type?i:\"log\"===t.type?(r=Math.ceil(Math.max(0,-Math.log(a)/Math.LN10))+3,n.format(\".\"+r+\"g\")(Math.pow(10,i))):(r=Math.floor(Math.log(Math.abs(i))/Math.LN10)-Math.floor(Math.log(a)/Math.LN10)+4,n.format(\".\"+String(r)+\"g\")(i))}(s,c),p=\"left\",d=\"middle\";if(s.fixedrange)return;S?(d=\"n\"===S?\"top\":\"bottom\",\"right\"===s.side&&(p=\"right\")):\"e\"===E&&(p=\"right\"),t._context.showAxisRangeEntryBoxes&&n.select(vt).call(l.makeEditable,{gd:t,immediate:!0,background:t._fullLayout.paper_bgcolor,text:String(f),fill:s.tickfont?s.tickfont.color:\"#444\",horizontalAlign:p,verticalAlign:d}).on(\"edit\",function(e){var r=s.d2r(e);void 0!==r&&o.call(\"_guiRelayout\",t,u,r)})}}function Lt(e,r){if(t._transitioningWithDuration)return!1;var n=Math.max(0,Math.min($,e+mt)),i=Math.max(0,Math.min(Q,r+yt)),a=Math.abs(n-mt),o=Math.abs(i-yt);function s(){kt=\"\",xt.r=xt.l,xt.t=xt.b,At.attr(\"d\",\"M0,0Z\")}if(xt.l=Math.min(mt,n),xt.r=Math.max(mt,n),xt.t=Math.min(yt,i),xt.b=Math.max(yt,i),tt.isSubplotConstrained)a>M||o>M?(kt=\"xy\",a/$>o/Q?(o=a*Q/$,yt>i?xt.t=yt-o:xt.b=yt+o):(a=o*$/Q,mt>n?xt.l=mt-a:xt.r=mt+a),At.attr(\"d\",U(xt))):s();else if(et.isSubplotConstrained)if(a>M||o>M){kt=\"xy\";var l=Math.min(xt.l/$,(Q-xt.b)/Q),c=Math.max(xt.r/$,(Q-xt.t)/Q);xt.l=l*$,xt.r=c*$,xt.b=(1-l)*Q,xt.t=(1-c)*Q,At.attr(\"d\",U(xt))}else s();else!nt||o<Math.min(Math.max(.6*a,A),M)?a<A||!rt?s():(xt.t=0,xt.b=Q,kt=\"x\",At.attr(\"d\",function(t,e){return\"M\"+(t.l-.5)+\",\"+(e-M-.5)+\"h-3v\"+(2*M+1)+\"h3ZM\"+(t.r+.5)+\",\"+(e-M-.5)+\"h3v\"+(2*M+1)+\"h-3Z\"}(xt,yt))):!rt||a<Math.min(.6*o,M)?(xt.l=0,xt.r=$,kt=\"y\",At.attr(\"d\",function(t,e){return\"M\"+(e-M-.5)+\",\"+(t.t-.5)+\"v-3h\"+(2*M+1)+\"v3ZM\"+(e-M-.5)+\",\"+(t.b+.5)+\"v3h\"+(2*M+1)+\"v-3Z\"}(xt,mt))):(kt=\"xy\",At.attr(\"d\",U(xt)));xt.w=xt.r-xt.l,xt.h=xt.b-xt.t,kt&&(Mt=!0),t._dragged=Mt,R(Tt,At,xt,_t,wt,bt),Pt(),t.emit(\"plotly_relayouting\",ut),wt=!0}function Pt(){ut={},\"xy\"!==kt&&\"x\"!==kt||(P(X,xt.l/$,xt.r/$,ut,tt.xaxes),Bt(\"x\",ut)),\"xy\"!==kt&&\"y\"!==kt||(P(Z,(Q-xt.b)/Q,(Q-xt.t)/Q,ut,tt.yaxes),Bt(\"y\",ut))}function Ot(){if(Math.min(xt.h,xt.w)<2*A)return B(t);Pt(),B(t),jt(),N(t)}St.prepFn=function(e,r,n){var a=St.dragmode,o=t._fullLayout.dragmode;o!==a&&(St.dragmode=o),dt(),it||(ft?e.shiftKey?\"pan\"===o?o=\"zoom\":j(o)||(o=\"pan\"):e.ctrlKey&&(o=\"pan\"):o=\"pan\"),St.minDrag=\"lasso\"===o?1:void 0,j(o)?(St.xaxes=X,St.yaxes=Z,b(e,r,n,St,o)):(St.clickFn=Ct,j(a)&&Et(),it||(\"zoom\"===o?(St.moveFn=Lt,St.doneFn=Ot,St.minDrag=1,function(e,r,n){var a=vt.getBoundingClientRect();mt=r-a.left,yt=n-a.top,xt={l:mt,r:mt,w:0,t:yt,b:yt,h:0},bt=t._hmpixcount?t._hmlumcount/t._hmpixcount:i(t._fullLayout.plot_bgcolor).getLuminance(),wt=!1,kt=\"xy\",Mt=!1,Tt=I(ht,bt,J,K,_t=\"M0,0H\"+$+\"V\"+Q+\"H0V0\"),At=D(ht,J,K)}(0,r,n)):\"pan\"===o&&(St.moveFn=Ft,St.doneFn=jt))),t._fullLayout._redrag=function(){var e=t._dragdata;e&&e.element===vt&&(j(t._fullLayout.dragmode)||(dt(),Ut([0,0,$,Q]),St.moveFn(e.dx,e.dy)))}},d.init(St);var zt=[0,0,$,Q],It=null,Dt=T.REDRAWDELAY,Rt=e.mainplot?t._fullLayout._plots[e.mainplot]:e;function Ft(e,r){if(!t._transitioningWithDuration){if(t._fullLayout._replotting=!0,\"ew\"===rt||\"ns\"===nt)return rt&&(O(X,e),Bt(\"x\")),nt&&(O(Z,r),Bt(\"y\")),Ut([rt?-e:0,nt?-r:0,$,Q]),Nt(),void t.emit(\"plotly_relayouting\",ut);if(tt.isSubplotConstrained&&rt&&nt){var n=\"w\"===rt==(\"n\"===nt)?1:-1,i=(e/$+n*r/Q)/2;e=i*$,r=n*i*Q}\"w\"===rt?e=l(X,0,e):\"e\"===rt?e=l(X,1,-e):rt||(e=0),\"n\"===nt?r=l(Z,1,r):\"s\"===nt?r=l(Z,0,-r):nt||(r=0);var a=\"w\"===rt?e:0,o=\"n\"===nt?r:0;if(tt.isSubplotConstrained){var s;if(!rt&&1===nt.length){for(s=0;s<X.length;s++)X[s].range=X[s]._r.slice(),k(X[s],1-r/Q);a=(e=r*$/Q)/2}if(!nt&&1===rt.length){for(s=0;s<Z.length;s++)Z[s].range=Z[s]._r.slice(),k(Z[s],1-e/$);o=(r=e*Q/$)/2}}Bt(\"x\"),Bt(\"y\"),Ut([a,o,$-e,Q-r]),Nt(),t.emit(\"plotly_relayouting\",ut)}function l(t,e,r){for(var n,i,a=1-e,o=0;o<t.length;o++){var s=t[o];if(!s.fixedrange){n=s,i=s._rl[a]+(s._rl[e]-s._rl[a])/z(r/s._length);var l=s.l2r(i);!1!==l&&void 0!==l&&(s.range[e]=l)}}return n._length*(n._rl[e]-i)/(n._rl[e]-n._rl[a])}}function Bt(t,e){for(var r=et.isSubplotConstrained?{x:Z,y:X}[t]:et[t+\"axes\"],n=et.isSubplotConstrained?{x:X,y:Z}[t]:[],i=0;i<r.length;i++){var a=r[i],o=a._id,s=et.xLinks[o]||et.yLinks[o],l=n[0]||Y[s]||W[s];l&&(e?(e[a._name+\".range[0]\"]=e[l._name+\".range[0]\"],e[a._name+\".range[1]\"]=e[l._name+\".range[1]\"]):a.range=l.range.slice())}}function Nt(){var e,r=[];function n(t){for(e=0;e<t.length;e++)t[e].fixedrange||r.push(t[e]._id)}for(at&&(n(X),n(tt.xaxes),n(et.xaxes)),ot&&(n(Z),n(tt.yaxes),n(et.yaxes)),ut={},e=0;e<r.length;e++){var i=r[e],a=x(t,i);f.drawOne(t,a,{skipTitle:!0}),ut[a._name+\".range[0]\"]=a.range[0],ut[a._name+\".range[1]\"]=a.range[1]}f.redrawComponents(t,r)}function jt(){Ut([0,0,$,Q]),s.syncOrAsync([y.previousPromises,function(){t._fullLayout._replotting=!1,o.call(\"_guiRelayout\",t,ut)}],t)}function Ut(e){var r,n,i,a,l=t._fullLayout,c=l._plots,h=l._subplots.cartesian;if(lt&&o.subplotsRegistry.splom.drag(t),st)for(r=0;r<h.length;r++)if(i=(n=c[h[r]]).xaxis,a=n.yaxis,n._scene){var f=s.simpleMap(i.range,i.r2l),p=s.simpleMap(a.range,a.r2l);n._scene.update({range:[f[0],p[0],f[1],p[1]]})}if((lt||st)&&(v(t),m(t)),ct){var d=e[2]/F._length,g=e[3]/G._length;for(r=0;r<h.length;r++){i=(n=c[h[r]]).xaxis,a=n.yaxis;var y,x,b,_,w=at&&!i.fixedrange&&Y[i._id],k=ot&&!a.fixedrange&&W[a._id];if(w?(y=d,b=E?e[0]:Ht(i,y)):et.xaHash[i._id]?(y=d,b=e[0]*i._length/F._length):et.yaHash[i._id]?(y=g,b=\"ns\"===nt?-e[1]*i._length/G._length:Ht(i,y,{n:\"top\",s:\"bottom\"}[nt])):b=qt(i,y=Vt(i,d,g)),k?(x=g,_=S?e[1]:Ht(a,x)):et.yaHash[a._id]?(x=g,_=e[1]*a._length/G._length):et.xaHash[a._id]?(x=d,_=\"ew\"===rt?-e[0]*a._length/F._length:Ht(a,x,{e:\"right\",w:\"left\"}[rt])):_=qt(a,x=Vt(a,d,g)),y||x){y||(y=1),x||(x=1);var T=i._offset-b/y,A=a._offset-_/x;n.clipRect.call(u.setTranslate,b,_).call(u.setScale,y,x),n.plot.call(u.setTranslate,T,A).call(u.setScale,1/y,1/x),y===n.xScaleFactor&&x===n.yScaleFactor||(u.setPointGroupScale(n.zoomScalePts,y,x),u.setTextPointsScale(n.zoomScaleTxt,y,x)),u.hideOutsideRangePoints(n.clipOnAxisFalseTraces,n),n.xScaleFactor=y,n.yScaleFactor=x}}}}function Vt(t,e,r){return t.fixedrange?0:at&&tt.xaHash[t._id]?e:ot&&(tt.isSubplotConstrained?tt.xaHash:tt.yaHash)[t._id]?r:0}function qt(t,e){return e?(t.range=t._r.slice(),k(t,e),Ht(t,e)):0}function Ht(t,e,r){return t._length*(1-e)*g[r||t.constraintoward||\"middle\"]}return S.length*E.length!=1&&q(vt,function(e){if(t._context._scrollZoom.cartesian||t._fullLayout._enablescrollzoom){if(Et(),t._transitioningWithDuration)return e.preventDefault(),void e.stopPropagation();dt(),clearTimeout(It);var r=-e.deltaY;if(isFinite(r)||(r=e.wheelDelta/10),isFinite(r)){var n,i=Math.exp(-Math.min(Math.max(r,-20),20)/200),a=Rt.draglayer.select(\".nsewdrag\").node().getBoundingClientRect(),o=(e.clientX-a.left)/a.width,l=(a.bottom-e.clientY)/a.height;if(at){for(E||(o=.5),n=0;n<X.length;n++)c(X[n],o,i);Bt(\"x\"),zt[2]*=i,zt[0]+=zt[2]*o*(1/i-1)}if(ot){for(S||(l=.5),n=0;n<Z.length;n++)c(Z[n],l,i);Bt(\"y\"),zt[3]*=i,zt[1]+=zt[3]*(1-l)*(1/i-1)}Ut(zt),Nt(),t.emit(\"plotly_relayouting\",ut),It=setTimeout(function(){zt=[0,0,$,Q],jt()},Dt),e.preventDefault()}else s.log(\"Did not find wheel motion attributes: \",e)}function c(t,e,r){if(!t.fixedrange){var n=s.simpleMap(t.range,t.r2l),i=n[0]+(n[1]-n[0])*e;t.range=n.map(function(e){return t.l2r(i+(e-i)*r)})}}}),vt},makeDragger:E,makeRectDragger:C,makeZoombox:I,makeCorners:D,updateZoombox:R,xyCorners:U,transitionZoombox:F,removeZoombox:B,showDoubleClickNotifier:N,attachWheelEventHandler:q}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/clear_gl_canvases\":704,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../plot_api/subroutines\":758,\"../../registry\":847,\"../plots\":828,\"./axes\":767,\"./axis_ids\":770,\"./constants\":773,\"./scale_zoom\":783,\"./select\":784,d3:163,\"has-passive-events\":411,tinycolor2:537}],776:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/fx\"),a=t(\"../../components/dragelement\"),o=t(\"../../lib/setcursor\"),s=t(\"./dragbox\").makeDragBox,l=t(\"./constants\").DRAGGERSIZE;r.initInteractions=function(t){var e=t._fullLayout;if(t._context.staticPlot)n.select(t).selectAll(\".drag\").remove();else if(e._has(\"cartesian\")||e._has(\"splom\")){Object.keys(e._plots||{}).sort(function(t,r){if((e._plots[t].mainplot&&!0)===(e._plots[r].mainplot&&!0)){var n=t.split(\"y\"),i=r.split(\"y\");return n[0]===i[0]?Number(n[1]||1)-Number(i[1]||1):Number(n[0]||1)-Number(i[0]||1)}return e._plots[t].mainplot?1:-1}).forEach(function(r){var n=e._plots[r],o=n.xaxis,c=n.yaxis;if(!n.mainplot){var u=s(t,n,o._offset,c._offset,o._length,c._length,\"ns\",\"ew\");u.onmousemove=function(e){t._fullLayout._rehover=function(){t._fullLayout._hoversubplot===r&&i.hover(t,e,r)},i.hover(t,e,r),t._fullLayout._lasthover=u,t._fullLayout._hoversubplot=r},u.onmouseout=function(e){t._dragging||(t._fullLayout._hoversubplot=null,a.unhover(t,e))},t._context.showAxisDragHandles&&(s(t,n,o._offset-l,c._offset-l,l,l,\"n\",\"w\"),s(t,n,o._offset+o._length,c._offset-l,l,l,\"n\",\"e\"),s(t,n,o._offset-l,c._offset+c._length,l,l,\"s\",\"w\"),s(t,n,o._offset+o._length,c._offset+c._length,l,l,\"s\",\"e\"))}if(t._context.showAxisDragHandles){if(r===o._mainSubplot){var h=o._mainLinePosition;\"top\"===o.side&&(h-=l),s(t,n,o._offset+.1*o._length,h,.8*o._length,l,\"\",\"ew\"),s(t,n,o._offset,h,.1*o._length,l,\"\",\"w\"),s(t,n,o._offset+.9*o._length,h,.1*o._length,l,\"\",\"e\")}if(r===c._mainSubplot){var f=c._mainLinePosition;\"right\"!==c.side&&(f-=l),s(t,n,f,c._offset+.1*c._length,l,.8*c._length,\"ns\",\"\"),s(t,n,f,c._offset+.9*c._length,l,.1*c._length,\"s\",\"\"),s(t,n,f,c._offset,l,.1*c._length,\"n\",\"\")}}});var o=e._hoverlayer.node();o.onmousemove=function(r){r.target=t._fullLayout._lasthover,i.hover(t,r,e._hoversubplot)},o.onclick=function(e){e.target=t._fullLayout._lasthover,i.click(t,e)},o.onmousedown=function(e){t._fullLayout._lasthover.onmousedown(e)},r.updateFx(t)}},r.updateFx=function(t){var e=t._fullLayout,r=\"pan\"===e.dragmode?\"move\":\"crosshair\";o(e._draggers,r)}},{\"../../components/dragelement\":611,\"../../components/fx\":632,\"../../lib/setcursor\":739,\"./constants\":773,\"./dragbox\":775,d3:163}],777:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t){return function(e,r){var a=e[t];if(Array.isArray(a))for(var o=n.subplotsRegistry.cartesian,s=o.idRegex,l=r._subplots,c=l.xaxis,u=l.yaxis,h=l.cartesian,f=r._has(\"cartesian\")||r._has(\"gl2d\"),p=0;p<a.length;p++){var d=a[p];if(i.isPlainObject(d)){var g=d.xref,v=d.yref,m=s.x.test(g),y=s.y.test(v);if(m||y){f||i.pushUnique(r._basePlotModules,o);var x=!1;m&&-1===c.indexOf(g)&&(c.push(g),x=!0),y&&-1===u.indexOf(v)&&(u.push(v),x=!0),x&&m&&y&&h.push(g+v)}}}}}},{\"../../lib\":719,\"../../registry\":847}],778:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../plots\"),s=t(\"../../components/drawing\"),l=t(\"../get_data\").getModuleCalcData,c=t(\"./axis_ids\"),u=t(\"./constants\"),h=t(\"../../constants/xmlns_namespaces\"),f=a.ensureSingle;function p(t,e,r){return a.ensureSingle(t,e,r,function(t){t.datum(r)})}function d(t,e,r,a,o){for(var c,h,f,p=u.traceLayerClasses,d=t._fullLayout,g=d._modules,v=[],m=[],y=0;y<g.length;y++){var x=(c=g[y]).name,b=i.modules[x].categories;if(b.svg){var _=c.layerName||x+\"layer\",w=c.plot;f=(h=l(r,w))[0],r=h[1],f.length&&v.push({i:p.indexOf(_),className:_,plotMethod:w,cdModule:f}),b.zoomScale&&m.push(\".\"+_)}}v.sort(function(t,e){return t.i-e.i});var k=e.plot.selectAll(\"g.mlayer\").data(v,function(t){return t.className});if(k.enter().append(\"g\").attr(\"class\",function(t){return t.className}).classed(\"mlayer\",!0).classed(\"rangeplot\",e.isRangePlot),k.exit().remove(),k.order(),k.each(function(r){var i=n.select(this),l=r.className;r.plotMethod(t,e,r.cdModule,i,a,o),-1===u.clipOnAxisFalseQuery.indexOf(\".\"+l)&&s.setClipUrl(i,e.layerClipId,t)}),d._has(\"scattergl\")&&(c=i.getModule(\"scattergl\"),f=l(r,c)[0],c.plot(t,e,f)),!t._context.staticPlot&&(e._hasClipOnAxisFalse&&(e.clipOnAxisFalseTraces=e.plot.selectAll(u.clipOnAxisFalseQuery.join(\",\")).selectAll(\".trace\")),m.length)){var T=e.plot.selectAll(m.join(\",\")).selectAll(\".trace\");e.zoomScalePts=T.selectAll(\"path.point\"),e.zoomScaleTxt=T.selectAll(\".textpoint\")}}function g(t,e){var r=e.plotgroup,n=e.id,i=u.layerValue2layerClass[e.xaxis.layer],a=u.layerValue2layerClass[e.yaxis.layer],o=t._fullLayout._hasOnlyLargeSploms;if(e.mainplot){var s=e.mainplotinfo,l=s.plotgroup,h=n+\"-x\",d=n+\"-y\";e.gridlayer=s.gridlayer,e.zerolinelayer=s.zerolinelayer,f(s.overlinesBelow,\"path\",h),f(s.overlinesBelow,\"path\",d),f(s.overaxesBelow,\"g\",h),f(s.overaxesBelow,\"g\",d),e.plot=f(s.overplot,\"g\",n),f(s.overlinesAbove,\"path\",h),f(s.overlinesAbove,\"path\",d),f(s.overaxesAbove,\"g\",h),f(s.overaxesAbove,\"g\",d),e.xlines=l.select(\".overlines-\"+i).select(\".\"+h),e.ylines=l.select(\".overlines-\"+a).select(\".\"+d),e.xaxislayer=l.select(\".overaxes-\"+i).select(\".\"+h),e.yaxislayer=l.select(\".overaxes-\"+a).select(\".\"+d)}else if(o)e.xlines=f(r,\"path\",\"xlines-above\"),e.ylines=f(r,\"path\",\"ylines-above\"),e.xaxislayer=f(r,\"g\",\"xaxislayer-above\"),e.yaxislayer=f(r,\"g\",\"yaxislayer-above\");else{var g=f(r,\"g\",\"layer-subplot\");e.shapelayer=f(g,\"g\",\"shapelayer\"),e.imagelayer=f(g,\"g\",\"imagelayer\"),e.gridlayer=f(r,\"g\",\"gridlayer\"),e.zerolinelayer=f(r,\"g\",\"zerolinelayer\"),f(r,\"path\",\"xlines-below\"),f(r,\"path\",\"ylines-below\"),e.overlinesBelow=f(r,\"g\",\"overlines-below\"),f(r,\"g\",\"xaxislayer-below\"),f(r,\"g\",\"yaxislayer-below\"),e.overaxesBelow=f(r,\"g\",\"overaxes-below\"),e.plot=f(r,\"g\",\"plot\"),e.overplot=f(r,\"g\",\"overplot\"),e.xlines=f(r,\"path\",\"xlines-above\"),e.ylines=f(r,\"path\",\"ylines-above\"),e.overlinesAbove=f(r,\"g\",\"overlines-above\"),f(r,\"g\",\"xaxislayer-above\"),f(r,\"g\",\"yaxislayer-above\"),e.overaxesAbove=f(r,\"g\",\"overaxes-above\"),e.xlines=r.select(\".xlines-\"+i),e.ylines=r.select(\".ylines-\"+a),e.xaxislayer=r.select(\".xaxislayer-\"+i),e.yaxislayer=r.select(\".yaxislayer-\"+a)}o||(p(e.gridlayer,\"g\",e.xaxis._id),p(e.gridlayer,\"g\",e.yaxis._id),e.gridlayer.selectAll(\"g\").map(function(t){return t[0]}).sort(c.idSort)),e.xlines.style(\"fill\",\"none\").classed(\"crisp\",!0),e.ylines.style(\"fill\",\"none\").classed(\"crisp\",!0)}function v(t,e){if(t){var r={};for(var i in t.each(function(t){var i=t[0];n.select(this).remove(),m(i,e),r[i]=!0}),e._plots)for(var a=e._plots[i].overlays||[],o=0;o<a.length;o++){var s=a[o];r[s.id]&&s.plot.selectAll(\".trace\").remove()}}}function m(t,e){e._draggers.selectAll(\"g.\"+t).remove(),e._defs.select(\"#clip\"+e._uid+t+\"plot\").remove()}r.name=\"cartesian\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=u.idRegex,r.attrRegex=u.attrRegex,r.attributes=t(\"./attributes\"),r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.transitionAxes=t(\"./transition_axes\"),r.finalizeSubplots=function(t,e){var r,n,i,o=e._subplots,s=o.xaxis,l=o.yaxis,h=o.cartesian,f=h.concat(o.gl2d||[]),p={},d={};for(r=0;r<f.length;r++){var g=f[r].split(\"y\");p[g[0]]=1,d[\"y\"+g[1]]=1}for(r=0;r<s.length;r++)p[n=s[r]]||(i=(t[c.id2name(n)]||{}).anchor,u.idRegex.y.test(i)||(i=\"y\"),h.push(n+i),f.push(n+i),d[i]||(d[i]=1,a.pushUnique(l,i)));for(r=0;r<l.length;r++)d[i=l[r]]||(n=(t[c.id2name(i)]||{}).anchor,u.idRegex.x.test(n)||(n=\"x\"),h.push(n+i),f.push(n+i),p[n]||(p[n]=1,a.pushUnique(s,n)));if(!f.length){for(var v in n=\"\",i=\"\",t){if(u.attrRegex.test(v))\"x\"===v.charAt(0)?(!n||+v.substr(5)<+n.substr(5))&&(n=v):(!i||+v.substr(5)<+i.substr(5))&&(i=v)}n=n?c.name2id(n):\"x\",i=i?c.name2id(i):\"y\",s.push(n),l.push(i),h.push(n+i)}},r.plot=function(t,e,r,n){var i,a=t._fullLayout,o=a._subplots.cartesian,s=t.calcdata;if(!Array.isArray(e))for(e=[],i=0;i<s.length;i++)e.push(i);for(i=0;i<o.length;i++){for(var l,c=o[i],u=a._plots[c],h=[],f=0;f<s.length;f++){var p=s[f],g=p[0].trace;g.xaxis+g.yaxis===c&&((-1!==e.indexOf(g.index)||g.carpet)&&(l&&l[0].trace.xaxis+l[0].trace.yaxis===c&&-1!==[\"tonextx\",\"tonexty\",\"tonext\"].indexOf(g.fill)&&-1===h.indexOf(l)&&h.push(l),h.push(p)),l=p)}d(t,u,h,r,n)}},r.clean=function(t,e,r,n){var i,a,o,s=n._plots||{},l=e._plots||{},u=n._subplots||{};if(n._hasOnlyLargeSploms&&!e._hasOnlyLargeSploms)for(o in s)(i=s[o]).plotgroup&&i.plotgroup.remove();var h=n._has&&n._has(\"gl\"),f=e._has&&e._has(\"gl\");if(h&&!f)for(o in s)(i=s[o])._scene&&i._scene.destroy();if(u.xaxis&&u.yaxis){var p=c.listIds({_fullLayout:n});for(a=0;a<p.length;a++){var d=p[a];e[c.id2name(d)]||n._infolayer.selectAll(\".g-\"+d+\"title\").remove()}}var g=n._has&&n._has(\"cartesian\"),y=e._has&&e._has(\"cartesian\");if(g&&!y)v(n._cartesianlayer.selectAll(\".subplot\"),n),n._defs.selectAll(\".axesclip\").remove(),delete n._axisConstraintGroups;else if(u.cartesian)for(a=0;a<u.cartesian.length;a++){var x=u.cartesian[a];if(!l[x]){var b=\".\"+x+\",.\"+x+\"-x,.\"+x+\"-y\";n._cartesianlayer.selectAll(b).remove(),m(x,n)}}},r.drawFramework=function(t){var e=t._fullLayout,r=function(t){var e,r,n,i,a,o,s=t._fullLayout,l=s._subplots.cartesian,c=l.length,u=[],h=[];for(e=0;e<c;e++){n=l[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var f=a._mainAxis,p=o._mainAxis,d=f._id+p._id,g=s._plots[d];i.overlays=[],d!==n&&g?(i.mainplot=d,i.mainplotinfo=g,h.push(n)):(i.mainplot=void 0,i.mainPlotinfo=void 0,u.push(n))}for(e=0;e<h.length;e++)n=h[e],(i=s._plots[n]).mainplotinfo.overlays.push(i);var v=u.concat(h),m=new Array(c);for(e=0;e<c;e++){n=v[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var y=[n,a.layer,o.layer,a.overlaying||\"\",o.overlaying||\"\"];for(r=0;r<i.overlays.length;r++)y.push(i.overlays[r].id);m[e]=y}return m}(t),i=e._cartesianlayer.selectAll(\".subplot\").data(r,String);i.enter().append(\"g\").attr(\"class\",function(t){return\"subplot \"+t[0]}),i.order(),i.exit().call(v,e),i.each(function(r){var i=r[0],a=e._plots[i];a.plotgroup=n.select(this),g(t,a),a.draglayer=f(e._draggers,\"g\",i)})},r.rangePlot=function(t,e,r){g(t,e),d(t,e,r),o.style(t)},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter(function(t,e){return e===r.size()-1}).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each(function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:h.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})})},r.updateFx=t(\"./graph_interact\").updateFx},{\"../../components/drawing\":614,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../registry\":847,\"../get_data\":802,\"../plots\":828,\"./attributes\":765,\"./axis_ids\":770,\"./constants\":773,\"./graph_interact\":776,\"./layout_attributes\":779,\"./layout_defaults\":780,\"./transition_axes\":789,d3:163}],779:[function(t,e,r){\"use strict\";var n=t(\"../font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray,l=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").DATE_FORMAT_LINK,t(\"./constants\"));e.exports={visible:{valType:\"boolean\",editType:\"plot\"},color:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},title:{text:{valType:\"string\",editType:\"ticks\"},font:n({editType:\"ticks\"}),editType:\"ticks\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"log\",\"date\",\"category\",\"multicategory\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"axrange\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0},{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0}],editType:\"axrange\",impliedEdits:{autorange:!1},anim:!0},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},scaleanchor:{valType:\"enumerated\",values:[l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},scaleratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},constrain:{valType:\"enumerated\",values:[\"range\",\"domain\"],dflt:\"range\",editType:\"plot\"},constraintoward:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\",\"top\",\"middle\",\"bottom\"],editType:\"plot\"},matches:{valType:\"enumerated\",values:[l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"calc\"},tickmode:{valType:\"enumerated\",values:[\"auto\",\"linear\",\"array\"],editType:\"ticks\",impliedEdits:{tick0:void 0,dtick:void 0}},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"ticks\"},tick0:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},dtick:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},tickvals:{valType:\"data_array\",editType:\"ticks\"},ticktext:{valType:\"data_array\",editType:\"ticks\"},ticks:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"\"],editType:\"ticks\"},tickson:{valType:\"enumerated\",values:[\"labels\",\"boundaries\"],dflt:\"labels\",editType:\"ticks\"},mirror:{valType:\"enumerated\",values:[!0,\"ticks\",!1,\"all\",\"allticks\"],dflt:!1,editType:\"ticks+layoutstyle\"},ticklen:{valType:\"number\",min:0,dflt:5,editType:\"ticks\"},tickwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},tickcolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},showticklabels:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},automargin:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},showspikes:{valType:\"boolean\",dflt:!1,editType:\"modebar\"},spikecolor:{valType:\"color\",dflt:null,editType:\"none\"},spikethickness:{valType:\"number\",dflt:3,editType:\"none\"},spikedash:o({},a,{dflt:\"dash\",editType:\"none\"}),spikemode:{valType:\"flaglist\",flags:[\"toaxis\",\"across\",\"marker\"],dflt:\"toaxis\",editType:\"none\"},spikesnap:{valType:\"enumerated\",values:[\"data\",\"cursor\"],dflt:\"data\",editType:\"none\"},tickfont:n({editType:\"ticks\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"ticks\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"ticks\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"ticks\"},tickformatstops:s(\"tickformatstop\",{enabled:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dtickrange:{valType:\"info_array\",items:[{valType:\"any\",editType:\"ticks\"},{valType:\"any\",editType:\"ticks\"}],editType:\"ticks\"},value:{valType:\"string\",dflt:\"\",editType:\"ticks\"},editType:\"ticks\"}),hoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},showline:{valType:\"boolean\",dflt:!1,editType:\"ticks+layoutstyle\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"layoutstyle\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks+layoutstyle\"},showgrid:{valType:\"boolean\",editType:\"ticks\"},gridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"ticks\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},zeroline:{valType:\"boolean\",editType:\"ticks\"},zerolinecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},zerolinewidth:{valType:\"number\",dflt:1,editType:\"ticks\"},showdividers:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dividercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},dividerwidth:{valType:\"number\",dflt:1,editType:\"ticks\"},anchor:{valType:\"enumerated\",values:[\"free\",l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},side:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],editType:\"plot\"},overlaying:{valType:\"enumerated\",values:[\"free\",l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},layer:{valType:\"enumerated\",values:[\"above traces\",\"below traces\"],dflt:\"above traces\",editType:\"plot\"},domain:{valType:\"info_array\",items:[{valType:\"number\",min:0,max:1,editType:\"plot\"},{valType:\"number\",min:0,max:1,editType:\"plot\"}],dflt:[0,1],editType:\"plot\"},position:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\",\"total ascending\",\"total descending\",\"min ascending\",\"min descending\",\"max ascending\",\"max descending\",\"sum ascending\",\"sum descending\",\"mean ascending\",\"mean descending\",\"median ascending\",\"median descending\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{autotick:{valType:\"boolean\",editType:\"ticks\"},title:{valType:\"string\",editType:\"ticks\"},titlefont:n({editType:\"ticks\"})}}},{\"../../components/color/attributes\":592,\"../../components/drawing/attributes\":613,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../font_attributes\":793,\"./constants\":773}],780:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../layout_attributes\"),s=t(\"./layout_attributes\"),l=t(\"./type_defaults\"),c=t(\"./axis_defaults\"),u=t(\"./constraints\").handleConstraintDefaults,h=t(\"./position_defaults\"),f=t(\"./axis_ids\"),p=f.id2name,d=f.name2id,g=t(\"../../registry\"),v=g.traceIs,m=g.getComponentMethod;function y(t,e,r){Array.isArray(t[e])?t[e].push(r):t[e]=[r]}e.exports=function(t,e,r){var f,g,x={},b={},_={},w={},k={},T={},A={},M={},S={};for(f=0;f<r.length;f++){var E=r[f];if(v(E,\"cartesian\")||v(E,\"gl2d\")){var C,L;if(E.xaxis)y(x,C=p(E.xaxis),E);else if(E.xaxes)for(g=0;g<E.xaxes.length;g++)y(x,p(E.xaxes[g]),E);if(E.yaxis)y(x,L=p(E.yaxis),E);else if(E.yaxes)for(g=0;g<E.yaxes.length;g++)y(x,p(E.yaxes[g]),E);if(\"funnel\"===E.type?\"h\"===E.orientation?(C&&(b[C]=!0),L&&(A[L]=!0)):L&&(_[L]=!0):(L&&(k[L]=!0,T[L]=!0),v(E,\"carpet\")&&(\"carpet\"!==E.type||E._cheater)||C&&(w[C]=!0)),\"carpet\"===E.type&&E._cheater&&C&&(b[C]=!0),v(E,\"2dMap\")&&(M[C]=!0,M[L]=!0),v(E,\"oriented\"))S[\"h\"===E.orientation?L:C]=!0}}var P=e._subplots,O=P.xaxis,z=P.yaxis,I=n.simpleMap(O,p),D=n.simpleMap(z,p),R=I.concat(D),F=i.background;O.length&&z.length&&(F=n.coerce(t,e,o,\"plot_bgcolor\"));var B,N,j,U,V=i.combine(F,e.paper_bgcolor);function q(t,e){return n.coerce(j,U,s,t,e)}function H(t,e){return n.coerce2(j,U,s,t,e)}function G(t){return\"x\"===t?z:O}var Y={x:G(\"x\"),y:G(\"y\")},W=Y.x.concat(Y.y);function X(e,r){for(var n=\"x\"===e?I:D,i=[],a=0;a<n.length;a++){var o=n[a];o===r||(t[o]||{}).overlaying||i.push(d(o))}return i}for(f=0;f<R.length;f++){N=(B=R[f]).charAt(0),n.isPlainObject(t[B])||(t[B]={}),j=t[B],U=a.newContainer(e,B,N+\"axis\");var Z=x[B]||[];U._traceIndices=Z.map(function(t){return t._expandedIndex}),U._annIndices=[],U._shapeIndices=[],U._imgIndices=[],U._subplotsWith=[],U._counterAxes=[],U._name=U._attr=B;var J=U._id=d(B),K=X(N,B),$=\"x\"===N&&!w[B]&&b[B]||\"y\"===N&&!k[B]&&_[B],Q=\"y\"===N&&!T[B]&&A[B],tt={letter:N,font:e.font,outerTicks:M[B],showGrid:!S[B],data:Z,bgColor:V,calendar:e.calendar,automargin:!0,visibleDflt:$,reverseDflt:Q,splomStash:((e._splomAxes||{})[N]||{})[J]};q(\"uirevision\",e.uirevision),l(j,U,q,tt),c(j,U,q,tt,e);var et=H(\"spikecolor\"),rt=H(\"spikethickness\"),nt=H(\"spikedash\"),it=H(\"spikemode\"),at=H(\"spikesnap\");q(\"showspikes\",!!(et||rt||nt||it||at))||(delete U.spikecolor,delete U.spikethickness,delete U.spikedash,delete U.spikemode,delete U.spikesnap),h(j,U,q,{letter:N,counterAxes:Y[N],overlayableAxes:K,grid:e.grid}),U._input=j}var ot=m(\"rangeslider\",\"handleDefaults\"),st=m(\"rangeselector\",\"handleDefaults\");for(f=0;f<I.length;f++)B=I[f],j=t[B],U=e[B],ot(t,e,B),\"date\"===U.type&&st(j,U,e,D,U.calendar),q(\"fixedrange\");for(f=0;f<D.length;f++){B=D[f],j=t[B],U=e[B];var lt=e[p(U.anchor)];q(\"fixedrange\",m(\"rangeslider\",\"isVisible\")(lt))}var ct=e._axisConstraintGroups=[],ut=e._axisMatchGroups=[];for(f=0;f<R.length;f++)N=(B=R[f]).charAt(0),j=t[B],U=e[B],u(j,U,q,W,e);for(f=0;f<ut.length;f++){var ht,ft=ut[f],pt=null,dt=null;for(ht in ft)(U=e[p(ht)]).matches||(pt=U.range,dt=U.autorange);if(null===pt||null===dt)for(ht in ft){pt=(U=e[p(ht)]).range,dt=U.autorange;break}for(ht in ft)(U=e[p(ht)]).matches&&(U.range=pt.slice(),U.autorange=dt),U._matchGroup=ft;if(ct.length)for(ht in ft)for(g=0;g<ct.length;g++){var gt=ct[g];for(var vt in gt)ht===vt&&(n.warn(\"Axis \"+vt+\" is set with both a *scaleanchor* and *matches* constraint; ignoring the scale constraint.\"),delete gt[vt],Object.keys(gt).length<2&&ct.splice(g,1))}}}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../registry\":847,\"../layout_attributes\":819,\"./axis_defaults\":769,\"./axis_ids\":770,\"./constraints\":774,\"./layout_attributes\":779,\"./position_defaults\":782,\"./type_defaults\":790}],781:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../components/color/attributes\").lightFraction,a=t(\"../../lib\");e.exports=function(t,e,r,o){var s=(o=o||{}).dfltColor;function l(r,n){return a.coerce2(t,e,o.attributes,r,n)}var c=l(\"linecolor\",s),u=l(\"linewidth\");r(\"showline\",o.showLine||!!c||!!u)||(delete e.linecolor,delete e.linewidth);var h=l(\"gridcolor\",n(s,o.bgColor,o.blend||i).toRgbString()),f=l(\"gridwidth\");if(r(\"showgrid\",o.showGrid||!!h||!!f)||(delete e.gridcolor,delete e.gridwidth),!o.noZeroLine){var p=l(\"zerolinecolor\",s),d=l(\"zerolinewidth\");r(\"zeroline\",o.showGrid||!!p||!!d)||(delete e.zerolinecolor,delete e.zerolinewidth)}}},{\"../../components/color/attributes\":592,\"../../lib\":719,tinycolor2:537}],782:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o,s,l,c,u=a.counterAxes||[],h=a.overlayableAxes||[],f=a.letter,p=a.grid;p&&(s=p._domains[f][p._axisMap[e._id]],o=p._anchors[e._id],s&&(l=p[f+\"side\"].split(\" \")[0],c=p.domain[f][\"right\"===l||\"top\"===l?1:0])),s=s||[0,1],o=o||(n(t.position)?\"free\":u[0]||\"free\"),l=l||(\"x\"===f?\"bottom\":\"left\"),c=c||0,\"free\"===i.coerce(t,e,{anchor:{valType:\"enumerated\",values:[\"free\"].concat(u),dflt:o}},\"anchor\")&&r(\"position\",c),i.coerce(t,e,{side:{valType:\"enumerated\",values:\"x\"===f?[\"bottom\",\"top\"]:[\"left\",\"right\"],dflt:l}},\"side\");var d=!1;if(h.length&&(d=i.coerce(t,e,{overlaying:{valType:\"enumerated\",values:[!1].concat(h),dflt:!1}},\"overlaying\")),!d){var g=r(\"domain\",s);g[0]>g[1]-1/4096&&(e.domain=s),i.noneOrAll(t.domain,e.domain,s)}return r(\"layer\"),e}},{\"../../lib\":719,\"fast-isnumeric\":225}],783:[function(t,e,r){\"use strict\";var n=t(\"../../constants/alignment\").FROM_BL;e.exports=function(t,e,r){void 0===r&&(r=n[t.constraintoward||\"center\"]);var i=[t.r2l(t.range[0]),t.r2l(t.range[1])],a=i[0]+(i[1]-i[0])*r;t.range=t._input.range=[t.l2r(a+(i[0]-a)*e),t.l2r(a+(i[1]-a)*e)]}},{\"../../constants/alignment\":688}],784:[function(t,e,r){\"use strict\";var n=t(\"polybooljs\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../../components/fx\"),s=t(\"../../lib\"),l=t(\"../../lib/polygon\"),c=t(\"../../lib/throttle\"),u=t(\"../../components/fx/helpers\").makeEventData,h=t(\"./axis_ids\").getFromId,f=t(\"../../lib/clear_gl_canvases\"),p=t(\"../../plot_api/subroutines\").redrawReglTraces,d=t(\"./constants\"),g=d.MINSELECT,v=l.filter,m=l.tester;function y(t){return t._id}function x(t,e,r,n,i,a,o){var s,l,c,u,h,f,p,d,g,v=e._hoverdata,m=e._fullLayout.clickmode.indexOf(\"event\")>-1,y=[];if(function(t){return t&&Array.isArray(t)&&!0!==t[0].hoverOnBox}(v)){k(t,e,a);var x=function(t,e){var r,n,i=t[0],a=-1,o=[];for(n=0;n<e.length;n++)if(r=e[n],i.fullData._expandedIndex===r.cd[0].trace._expandedIndex){if(!0===i.hoverOnBox)break;void 0!==i.pointNumber?a=i.pointNumber:void 0!==i.binNumber&&(a=i.binNumber,o=i.pointNumbers);break}return{pointNumber:a,pointNumbers:o,searchInfo:r}}(v,s=A(e,r,n,i));if(x.pointNumbers.length>0?function(t,e){var r,n,i,a=[];for(i=0;i<t.length;i++)(r=t[i]).cd[0].trace.selectedpoints&&r.cd[0].trace.selectedpoints.length>0&&a.push(r);if(1===a.length&&a[0]===e.searchInfo&&(n=e.searchInfo.cd[0].trace).selectedpoints.length===e.pointNumbers.length){for(i=0;i<e.pointNumbers.length;i++)if(n.selectedpoints.indexOf(e.pointNumbers[i])<0)return!1;return!0}return!1}(s,x):function(t){var e,r,n,i=0;for(n=0;n<t.length;n++)if(e=t[n],(r=e.cd[0].trace).selectedpoints){if(r.selectedpoints.length>1)return!1;if((i+=r.selectedpoints.length)>1)return!1}return 1===i}(s)&&(f=S(x))){for(o&&o.remove(),g=0;g<s.length;g++)(l=s[g])._module.selectPoints(l,!1);E(e,s),T(a),m&&e.emit(\"plotly_deselect\",null)}else{for(p=t.shiftKey&&(void 0!==f?f:S(x)),c=function(t,e,r){return{pointNumber:t,searchInfo:e,subtract:r}}(x.pointNumber,x.searchInfo,p),u=w(a.selectionDefs.concat([c])),g=0;g<s.length;g++)if(h=C(s[g]._module.selectPoints(s[g],u),s[g]),y.length)for(var b=0;b<h.length;b++)y.push(h[b]);else y=h;E(e,s,d={points:y}),c&&a&&a.selectionDefs.push(c),o&&M(a.mergedPolygons,o),m&&e.emit(\"plotly_selected\",d)}}}function b(t){return\"pointNumber\"in t&&\"searchInfo\"in t}function _(t){return{xmin:0,xmax:0,ymin:0,ymax:0,pts:[],contains:function(e,r,n,i){var a=t.searchInfo.cd[0].trace._expandedIndex;return i.cd[0].trace._expandedIndex===a&&n===t.pointNumber},isRect:!1,degenerate:!1,subtract:t.subtract}}function w(t){for(var e=[],r=b(t[0])?0:t[0][0][0],n=r,i=b(t[0])?0:t[0][0][1],a=i,o=0;o<t.length;o++)if(b(t[o]))e.push(_(t[o]));else{var s=l.tester(t[o]);s.subtract=t[o].subtract,e.push(s),r=Math.min(r,s.xmin),n=Math.max(n,s.xmax),i=Math.min(i,s.ymin),a=Math.max(a,s.ymax)}return{xmin:r,xmax:n,ymin:i,ymax:a,pts:[],contains:function(t,r,n,i){for(var a=!1,o=0;o<e.length;o++)e[o].contains(t,r,n,i)&&(a=!1===e[o].subtract);return a},isRect:!1,degenerate:!1}}function k(t,e,r){var n=e._fullLayout,i=r.plotinfo,a=n._lastSelectedSubplot&&n._lastSelectedSubplot===i.id,o=t.shiftKey||t.altKey;a&&o&&i.selection&&i.selection.selectionDefs&&!r.selectionDefs?(r.selectionDefs=i.selection.selectionDefs,r.mergedPolygons=i.selection.mergedPolygons):o&&i.selection||T(r),a||(L(e),n._lastSelectedSubplot=i.id)}function T(t){var e=t.plotinfo;e.selection={},e.selection.selectionDefs=t.selectionDefs=[],e.selection.mergedPolygons=t.mergedPolygons=[]}function A(t,e,r,n){var i,a,o,s=[],l=e.map(y),c=r.map(y);for(o=0;o<t.calcdata.length;o++)if(!0===(a=(i=t.calcdata[o])[0].trace).visible&&a._module&&a._module.selectPoints)if(!n||a.subplot!==n&&a.geo!==n)if(\"splom\"===a.type&&a._xaxes[l[0]]&&a._yaxes[c[0]]){var u=p(a._module,i,e[0],r[0]);u.scene=t._fullLayout._splomScenes[a.uid],s.push(u)}else if(\"sankey\"===a.type){var f=p(a._module,i,e[0],r[0]);s.push(f)}else{if(-1===l.indexOf(a.xaxis))continue;if(-1===c.indexOf(a.yaxis))continue;s.push(p(a._module,i,h(t,a.xaxis),h(t,a.yaxis)))}else s.push(p(a._module,i,e[0],r[0]));return s;function p(t,e,r,n){return{_module:t,cd:e,xaxis:r,yaxis:n}}}function M(t,e){var r,n,i=[];for(r=0;r<t.length;r++){var a=t[r];i.push(a.join(\"L\")+\"L\"+a[0])}n=t.length>0?\"M\"+i.join(\"M\")+\"Z\":\"M0,0Z\",e.attr(\"d\",n)}function S(t){var e=t.searchInfo.cd[0].trace,r=t.pointNumber,n=t.pointNumbers,i=n.length>0?n[0]:r;return!!e.selectedpoints&&e.selectedpoints.indexOf(i)>-1}function E(t,e,r){var n,a,o,s;for(n=0;n<e.length;n++){var l=e[n].cd[0].trace._fullInput,c=t._fullLayout._tracePreGUI[l.uid]||{};void 0===c.selectedpoints&&(c.selectedpoints=l._input.selectedpoints||null)}if(r){var u=r.points||[];for(n=0;n<e.length;n++)(s=e[n].cd[0].trace)._input.selectedpoints=s._fullInput.selectedpoints=[],s._fullInput!==s&&(s.selectedpoints=[]);for(n=0;n<u.length;n++){var h=u[n],d=h.data,g=h.fullData;h.pointIndices?([].push.apply(d.selectedpoints,h.pointIndices),s._fullInput!==s&&[].push.apply(g.selectedpoints,h.pointIndices)):(d.selectedpoints.push(h.pointIndex),s._fullInput!==s&&g.selectedpoints.push(h.pointIndex))}}else for(n=0;n<e.length;n++)delete(s=e[n].cd[0].trace).selectedpoints,delete s._input.selectedpoints,s._fullInput!==s&&delete s._fullInput.selectedpoints;var v=!1;for(n=0;n<e.length;n++){s=(o=(a=e[n]).cd)[0].trace,i.traceIs(s,\"regl\")&&(v=!0);var m=a._module,y=m.styleOnSelect||m.style;y&&(y(t,o,o[0].node3),o[0].nodeRangePlot3&&y(t,o,o[0].nodeRangePlot3))}v&&(f(t),p(t))}function C(t,e){if(Array.isArray(t))for(var r=e.cd,n=e.cd[0].trace,i=0;i<t.length;i++)t[i]=u(t[i],n,r);return t}function L(t){var e=(t._fullLayout||{})._zoomlayer;e&&e.selectAll(\".select-outline\").remove()}e.exports={prepSelect:function(t,e,r,i,l){var u,h,f,p,y,b,_,S=i.gd,L=S._fullLayout,P=L._zoomlayer,O=i.element.getBoundingClientRect(),z=i.plotinfo,I=z.xaxis._offset,D=z.yaxis._offset,R=e-O.left,F=r-O.top,B=R,N=F,j=\"M\"+R+\",\"+F,U=i.xaxes[0]._length,V=i.yaxes[0]._length,q=i.xaxes.concat(i.yaxes),H=t.altKey;k(t,S,i),\"lasso\"===l&&(u=v([[R,F]],d.BENDPX));var G=P.selectAll(\"path.select-outline-\"+z.id).data([1,2]);G.enter().append(\"path\").attr(\"class\",function(t){return\"select-outline select-outline-\"+t+\" select-outline-\"+z.id}).attr(\"transform\",\"translate(\"+I+\", \"+D+\")\").attr(\"d\",j+\"Z\");var Y,W=P.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:a.background,stroke:a.defaultLine,\"stroke-width\":1}).attr(\"transform\",\"translate(\"+I+\", \"+D+\")\").attr(\"d\",\"M0,0Z\"),X=L._uid+d.SELECTID,Z=[],J=A(S,i.xaxes,i.yaxes,i.subplot);function K(t,e){return\"log\"===t.type?t.p2d(e):t.p2r(e)}function $(t){var e=\"y\"===t._id.charAt(0)?1:0;return function(r){return K(t,r[e])}}function Q(t,e){return t-e}Y=z.fillRangeItems?z.fillRangeItems:\"select\"===l?function(t,e){var r=t.range={};for(y=0;y<q.length;y++){var n=q[y],i=n._id.charAt(0);r[n._id]=[K(n,e[i+\"min\"]),K(n,e[i+\"max\"])].sort(Q)}}:function(t,e,r){var n=t.lassoPoints={};for(y=0;y<q.length;y++){var i=q[y];n[i._id]=r.filtered.map($(i))}},i.moveFn=function(t,e){B=Math.max(0,Math.min(U,t+R)),N=Math.max(0,Math.min(V,e+F));var r=Math.abs(B-R),a=Math.abs(N-F);if(\"select\"===l){var o=L.selectdirection;\"h\"===(o=\"any\"===L.selectdirection?a<Math.min(.6*r,g)?\"h\":r<Math.min(.6*a,g)?\"v\":\"d\":L.selectdirection)?((p=[[R,0],[R,V],[B,V],[B,0]]).xmin=Math.min(R,B),p.xmax=Math.max(R,B),p.ymin=Math.min(0,V),p.ymax=Math.max(0,V),W.attr(\"d\",\"M\"+p.xmin+\",\"+(F-g)+\"h-4v\"+2*g+\"h4ZM\"+(p.xmax-1)+\",\"+(F-g)+\"h4v\"+2*g+\"h-4Z\")):\"v\"===o?((p=[[0,F],[0,N],[U,N],[U,F]]).xmin=Math.min(0,U),p.xmax=Math.max(0,U),p.ymin=Math.min(F,N),p.ymax=Math.max(F,N),W.attr(\"d\",\"M\"+(R-g)+\",\"+p.ymin+\"v-4h\"+2*g+\"v4ZM\"+(R-g)+\",\"+(p.ymax-1)+\"v4h\"+2*g+\"v-4Z\")):\"d\"===o&&((p=[[R,F],[R,N],[B,N],[B,F]]).xmin=Math.min(R,B),p.xmax=Math.max(R,B),p.ymin=Math.min(F,N),p.ymax=Math.max(F,N),W.attr(\"d\",\"M0,0Z\"))}else\"lasso\"===l&&(u.addPt([B,N]),p=u.filtered);i.selectionDefs&&i.selectionDefs.length?(f=function(t,e,r){return r?n.difference({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions:n.union({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions}(i.mergedPolygons,p,H),p.subtract=H,h=w(i.selectionDefs.concat([p]))):(f=[p],h=m(p)),M(f,G),c.throttle(X,d.SELECTDELAY,function(){var t;Z=[];var e,r=[];for(y=0;y<J.length;y++)if(e=(b=J[y])._module.selectPoints(b,h),r.push(e),t=C(e,b),Z.length)for(var n=0;n<t.length;n++)Z.push(t[n]);else Z=t;E(S,J,_={points:Z}),Y(_,p,u),i.gd.emit(\"plotly_selecting\",_)})},i.clickFn=function(t,e){var r=L.clickmode;W.remove(),c.done(X).then(function(){if(c.clear(X),2===t){for(G.remove(),y=0;y<J.length;y++)(b=J[y])._module.selectPoints(b,!1);E(S,J),T(i),S.emit(\"plotly_deselect\",null)}else r.indexOf(\"select\")>-1&&x(e,S,i.xaxes,i.yaxes,i.subplot,i,G),\"event\"===r&&S.emit(\"plotly_selected\",void 0);o.click(S,e)}).catch(s.error)},i.doneFn=function(){W.remove(),c.done(X).then(function(){c.clear(X),i.gd.emit(\"plotly_selected\",_),p&&i.selectionDefs&&(p.subtract=H,i.selectionDefs.push(p),i.mergedPolygons.length=0,[].push.apply(i.mergedPolygons,f)),i.doneFnCompleted&&i.doneFnCompleted(Z)}).catch(s.error)}},clearSelect:L,selectOnClick:x}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../components/fx/helpers\":628,\"../../lib\":719,\"../../lib/clear_gl_canvases\":704,\"../../lib/polygon\":731,\"../../lib/throttle\":744,\"../../plot_api/subroutines\":758,\"../../registry\":847,\"./axis_ids\":770,\"./constants\":773,polybooljs:473}],785:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=a.cleanNumber,s=a.ms2DateTime,l=a.dateTime2ms,c=a.ensureNumber,u=a.isArrayOrTypedArray,h=t(\"../../constants/numerical\"),f=h.FP_SAFE,p=h.BADNUM,d=h.LOG_CLIP,g=t(\"./constants\"),v=t(\"./axis_ids\");function m(t){return Math.pow(10,t)}function y(t){return null!=t}e.exports=function(t,e){e=e||{};var r=t._id||\"x\",h=r.charAt(0);function x(e,r){if(e>0)return Math.log(e)/Math.LN10;if(e<=0&&r&&t.range&&2===t.range.length){var n=t.range[0],i=t.range[1];return.5*(n+i-2*d*Math.abs(n-i))}return p}function b(e,r,n){var o=l(e,n||t.calendar);if(o===p){if(!i(e))return p;e=+e;var s=Math.floor(10*a.mod(e+.05,1)),c=Math.round(e-s/10);o=l(new Date(c))+s/10}return o}function _(e,r,n){return s(e,r,n||t.calendar)}function w(e){return t._categories[Math.round(e)]}function k(e){if(y(e)){if(void 0===t._categoriesMap&&(t._categoriesMap={}),void 0!==t._categoriesMap[e])return t._categoriesMap[e];t._categories.push(\"number\"==typeof e?String(e):e);var r=t._categories.length-1;return t._categoriesMap[e]=r,r}return p}function T(e){if(t._categoriesMap)return t._categoriesMap[e]}function A(t){var e=T(t);return void 0!==e?e:i(t)?+t:void 0}function M(e){return i(e)?n.round(t._b+t._m*e,2):p}function S(e){return(e-t._b)/t._m}t.c2l=\"log\"===t.type?x:c,t.l2c=\"log\"===t.type?m:c,t.l2p=M,t.p2l=S,t.c2p=\"log\"===t.type?function(t,e){return M(x(t,e))}:M,t.p2c=\"log\"===t.type?function(t){return m(S(t))}:S,-1!==[\"linear\",\"-\"].indexOf(t.type)?(t.d2r=t.r2d=t.d2c=t.r2c=t.d2l=t.r2l=o,t.c2d=t.c2r=t.l2d=t.l2r=c,t.d2p=t.r2p=function(e){return t.l2p(o(e))},t.p2d=t.p2r=S,t.cleanPos=c):\"log\"===t.type?(t.d2r=t.d2l=function(t,e){return x(o(t),e)},t.r2d=t.r2c=function(t){return m(o(t))},t.d2c=t.r2l=o,t.c2d=t.l2r=c,t.c2r=x,t.l2d=m,t.d2p=function(e,r){return t.l2p(t.d2r(e,r))},t.p2d=function(t){return m(S(t))},t.r2p=function(e){return t.l2p(o(e))},t.p2r=S,t.cleanPos=c):\"date\"===t.type?(t.d2r=t.r2d=a.identity,t.d2c=t.r2c=t.d2l=t.r2l=b,t.c2d=t.c2r=t.l2d=t.l2r=_,t.d2p=t.r2p=function(e,r,n){return t.l2p(b(e,0,n))},t.p2d=t.p2r=function(t,e,r){return _(S(t),e,r)},t.cleanPos=function(e){return a.cleanDate(e,p,t.calendar)}):\"category\"===t.type?(t.d2c=t.d2l=k,t.r2d=t.c2d=t.l2d=w,t.d2r=t.d2l_noadd=A,t.r2c=function(e){var r=A(e);return void 0!==r?r:t.fraction2r(.5)},t.l2r=t.c2r=c,t.r2l=A,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return w(S(t))},t.r2p=t.d2p,t.p2r=S,t.cleanPos=function(t){return\"string\"==typeof t&&\"\"!==t?t:c(t)}):\"multicategory\"===t.type&&(t.r2d=t.c2d=t.l2d=w,t.d2r=t.d2l_noadd=A,t.r2c=function(e){var r=A(e);return void 0!==r?r:t.fraction2r(.5)},t.r2c_just_indices=T,t.l2r=t.c2r=c,t.r2l=A,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return w(S(t))},t.r2p=t.d2p,t.p2r=S,t.cleanPos=function(t){return Array.isArray(t)||\"string\"==typeof t&&\"\"!==t?t:c(t)},t.setupMultiCategory=function(n){var i,o,s=t._traceIndices,l=e._axisMatchGroups;if(l&&l.length&&0===t._categories.length)for(i=0;i<l.length;i++){var c=l[i];if(c[r])for(var f in c)if(f!==r){var p=e[v.id2name(f)];s=s.concat(p._traceIndices)}}var d=[[0,{}],[0,{}]],g=[];for(i=0;i<s.length;i++){var m=n[s[i]];if(h in m){var x=m[h],b=m._length||a.minRowLength(x);if(u(x[0])&&u(x[1]))for(o=0;o<b;o++){var _=x[0][o],w=x[1][o];y(_)&&y(w)&&(g.push([_,w]),_ in d[0][1]||(d[0][1][_]=d[0][0]++),w in d[1][1]||(d[1][1][w]=d[1][0]++))}}}for(g.sort(function(t,e){var r=d[0][1],n=r[t[0]]-r[e[0]];if(n)return n;var i=d[1][1];return i[t[1]]-i[e[1]]}),i=0;i<g.length;i++)k(g[i])}),t.fraction2r=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return t.l2r(r+e*(n-r))},t.r2fraction=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return(t.r2l(e)-r)/(n-r)},t.cleanRange=function(e,r){r||(r={}),e||(e=\"range\");var n,o,s=a.nestedProperty(t,e).get();if(o=(o=\"date\"===t.type?a.dfltRange(t.calendar):\"y\"===h?g.DFLTRANGEY:r.dfltRange||g.DFLTRANGEX).slice(),s&&2===s.length)for(\"date\"!==t.type||t.autorange||(s[0]=a.cleanDate(s[0],p,t.calendar),s[1]=a.cleanDate(s[1],p,t.calendar)),n=0;n<2;n++)if(\"date\"===t.type){if(!a.isDateTime(s[n],t.calendar)){t[e]=o;break}if(t.r2l(s[0])===t.r2l(s[1])){var l=a.constrain(t.r2l(s[0]),a.MIN_MS+1e3,a.MAX_MS-1e3);s[0]=t.l2r(l-1e3),s[1]=t.l2r(l+1e3);break}}else{if(!i(s[n])){if(!i(s[1-n])){t[e]=o;break}s[n]=s[1-n]*(n?10:.1)}if(s[n]<-f?s[n]=-f:s[n]>f&&(s[n]=f),s[0]===s[1]){var c=Math.max(1,Math.abs(1e-6*s[0]));s[0]-=c,s[1]+=c}}else a.nestedProperty(t,e).set(o)},t.setScale=function(r){var n=e._size;if(t.overlaying){var i=v.getFromId({_fullLayout:e},t.overlaying);t.domain=i.domain}var a=r&&t._r?\"_r\":\"range\",o=t.calendar;t.cleanRange(a);var s=t.r2l(t[a][0],o),l=t.r2l(t[a][1],o);if(\"y\"===h?(t._offset=n.t+(1-t.domain[1])*n.h,t._length=n.h*(t.domain[1]-t.domain[0]),t._m=t._length/(s-l),t._b=-t._m*l):(t._offset=n.l+t.domain[0]*n.w,t._length=n.w*(t.domain[1]-t.domain[0]),t._m=t._length/(l-s),t._b=-t._m*s),!isFinite(t._m)||!isFinite(t._b)||t._length<0)throw e._replotting=!1,new Error(\"Something went wrong with axis scaling\")},t.makeCalcdata=function(e,r){var n,i,o,s,l=t.type,c=\"date\"===l&&e[r+\"calendar\"];if(r in e){if(n=e[r],s=e._length||a.minRowLength(n),a.isTypedArray(n)&&(\"linear\"===l||\"log\"===l)){if(s===n.length)return n;if(n.subarray)return n.subarray(0,s)}if(\"multicategory\"===l)return function(t,e){for(var r=new Array(e),n=0;n<e;n++){var i=(t[0]||[])[n],a=(t[1]||[])[n];r[n]=T([i,a])}return r}(n,s);for(i=new Array(s),o=0;o<s;o++)i[o]=t.d2c(n[o],0,c)}else{var u=r+\"0\"in e?t.d2c(e[r+\"0\"],0,c):0,h=e[\"d\"+r]?Number(e[\"d\"+r]):1;for(n=e[{x:\"y\",y:\"x\"}[r]],s=e._length||n.length,i=new Array(s),o=0;o<s;o++)i[o]=u+o*h}return i},t.isValidRange=function(e){return Array.isArray(e)&&2===e.length&&i(t.r2l(e[0]))&&i(t.r2l(e[1]))},t.isPtWithinRange=function(e,r){var n=t.c2l(e[h],null,r),i=t.r2l(t.range[0]),a=t.r2l(t.range[1]);return i<a?i<=n&&n<=a:a<=n&&n<=i},t.clearCalc=function(){var n=function(){t._categories=[],t._categoriesMap={}},i=e._axisMatchGroups;if(i&&i.length){for(var a=!1,o=0;o<i.length;o++){var s=i[o];if(s[r]){a=!0;var l=null,c=null;for(var u in s){var h=e[v.id2name(u)];if(h._categories){l=h._categories,c=h._categoriesMap;break}}l&&c?(t._categories=l,t._categoriesMap=c):n();break}}a||n()}else n();if(t._initialCategories)for(var f=0;f<t._initialCategories.length;f++)k(t._initialCategories[f])},t.sortByInitialCategories=function(){var n=[];if(t._categories=[],t._categoriesMap={},t._initialCategories)for(var i=0;i<t._initialCategories.length;i++)k(t._initialCategories[i]);n=n.concat(t._traceIndices);var a=t._matchGroup;for(var o in a)if(r!==o){var s=e[v.id2name(o)];s._categories=t._categories,s._categoriesMap=t._categoriesMap,n=n.concat(s._traceIndices)}return n};var E=e._d3locale;\"date\"===t.type&&(t._dateFormat=E?E.timeFormat.utc:n.time.format.utc,t._extraFormat=e._extraFormat),t._separators=e.separators,t._numFormat=E?E.numberFormat:n.format,delete t._minDtick,delete t._forceTick0}},{\"../../constants/numerical\":695,\"../../lib\":719,\"./axis_ids\":770,\"./constants\":773,d3:163,\"fast-isnumeric\":225}],786:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"../array_container_defaults\");function o(t){var e=[\"showexponent\",\"showtickprefix\",\"showticksuffix\"].filter(function(e){return void 0!==t[e]});if(e.every(function(r){return t[r]===t[e[0]]})||1===e.length)return t[e[0]]}function s(t,e){function r(r,a){return n.coerce(t,e,i.tickformatstops,r,a)}r(\"enabled\")&&(r(\"dtickrange\"),r(\"value\"))}e.exports=function(t,e,r,l,c,u){u&&1!==u.pass||function(t,e,r,n,i){var a=o(t);r(\"tickprefix\")&&r(\"showtickprefix\",a);r(\"ticksuffix\",i.tickSuffixDflt)&&r(\"showticksuffix\",a)}(t,0,r,0,c),u&&2!==u.pass||function(t,e,r,l,c){var u=o(t);r(\"tickprefix\")&&r(\"showtickprefix\",u);r(\"ticksuffix\",c.tickSuffixDflt)&&r(\"showticksuffix\",u);if(r(\"showticklabels\")){var h=c.font||{},f=e.color,p=f&&f!==i.color.dflt?f:h.color;if(n.coerceFont(r,\"tickfont\",{family:h.family,size:h.size,color:p}),r(\"tickangle\"),\"category\"!==l){var d=r(\"tickformat\"),g=t.tickformatstops;Array.isArray(g)&&g.length&&a(t,e,{name:\"tickformatstops\",inclusionAttr:\"enabled\",handleItemDefaults:s}),d||\"date\"===l||(r(\"showexponent\",u),r(\"exponentformat\"),r(\"separatethousands\"))}}}(t,e,r,l,c)}},{\"../../lib\":719,\"../array_container_defaults\":763,\"./layout_attributes\":779}],787:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r,a){var o=n.coerce2(t,e,i,\"ticklen\"),s=n.coerce2(t,e,i,\"tickwidth\"),l=n.coerce2(t,e,i,\"tickcolor\",e.color);r(\"ticks\",a.outerTicks||o||s||l?\"outside\":\"\")||(delete e.ticklen,delete e.tickwidth,delete e.tickcolor)}},{\"../../lib\":719,\"./layout_attributes\":779}],788:[function(t,e,r){\"use strict\";var n=t(\"./clean_ticks\");e.exports=function(t,e,r,i){var a;\"array\"!==t.tickmode||\"log\"!==i&&\"date\"!==i?a=r(\"tickmode\",Array.isArray(t.tickvals)?\"array\":t.dtick?\"linear\":\"auto\"):a=e.tickmode=\"auto\";if(\"auto\"===a)r(\"nticks\");else if(\"linear\"===a){var o=e.dtick=n.dtick(t.dtick,i);e.tick0=n.tick0(t.tick0,i,e.calendar,o)}else if(\"multicategory\"!==i){void 0===r(\"tickvals\")?e.tickmode=\"auto\":r(\"ticktext\")}}},{\"./clean_ticks\":772}],789:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../components/drawing\"),o=t(\"./axes\");e.exports=function(t,e,r,s){var l=t._fullLayout;if(0!==e.length){var c,u,h,f;s&&(c=s());var p=n.ease(r.easing);return t._transitionData._interruptCallbacks.push(function(){return window.cancelAnimationFrame(f),f=null,function(){for(var r={},n=0;n<e.length;n++){var a=e[n];a.xr0&&(r[a.plotinfo.xaxis._name+\".range\"]=a.xr0.slice()),a.yr0&&(r[a.plotinfo.yaxis._name+\".range\"]=a.yr0.slice())}return i.call(\"relayout\",t,r).then(function(){for(var t=0;t<e.length;t++)d(e[t].plotinfo)})}()}),u=Date.now(),f=window.requestAnimationFrame(function n(){h=Date.now();for(var a=Math.min(1,(h-u)/r.duration),o=p(a),s=0;s<e.length;s++)g(e[s],o);h-u>r.duration?(function(){for(var r={},n=0;n<e.length;n++){var a=e[n];a.xr1&&(r[a.plotinfo.xaxis._name+\".range\"]=a.xr1.slice()),a.yr1&&(r[a.plotinfo.yaxis._name+\".range\"]=a.yr1.slice())}c&&c(),i.call(\"relayout\",t,r).then(function(){for(var t=0;t<e.length;t++)d(e[t].plotinfo)})}(),f=window.cancelAnimationFrame(n)):f=window.requestAnimationFrame(n)}),Promise.resolve()}function d(t){var e=t.xaxis,r=t.yaxis;l._defs.select(\"#\"+t.clipId+\"> rect\").call(a.setTranslate,0,0).call(a.setScale,1,1),t.plot.call(a.setTranslate,e._offset,r._offset).call(a.setScale,1,1);var n=t.plot.selectAll(\".scatterlayer .trace\");n.selectAll(\".point\").call(a.setPointGroupScale,1,1),n.selectAll(\".textpoint\").call(a.setTextPointsScale,1,1),n.call(a.hideOutsideRangePoints,t)}function g(e,r){var n=e.plotinfo,i=n.xaxis,s=n.yaxis,l=e.xr0,c=e.xr1,u=i._length,h=e.yr0,f=e.yr1,p=s._length,d=!!c,g=!!f,v=[];if(d){var m=l[1]-l[0],y=c[1]-c[0];v[0]=(l[0]*(1-r)+r*c[0]-l[0])/(l[1]-l[0])*u,v[2]=u*(1-r+r*y/m),i.range[0]=l[0]*(1-r)+r*c[0],i.range[1]=l[1]*(1-r)+r*c[1]}else v[0]=0,v[2]=u;if(g){var x=h[1]-h[0],b=f[1]-f[0];v[1]=(h[1]*(1-r)+r*f[1]-h[1])/(h[0]-h[1])*p,v[3]=p*(1-r+r*b/x),s.range[0]=h[0]*(1-r)+r*f[0],s.range[1]=h[1]*(1-r)+r*f[1]}else v[1]=0,v[3]=p;o.drawOne(t,i,{skipTitle:!0}),o.drawOne(t,s,{skipTitle:!0}),o.redrawComponents(t,[i._id,s._id]);var _=d?u/v[2]:1,w=g?p/v[3]:1,k=d?v[0]:0,T=g?v[1]:0,A=d?v[0]/v[2]*u:0,M=g?v[1]/v[3]*p:0,S=i._offset-A,E=s._offset-M;n.clipRect.call(a.setTranslate,k,T).call(a.setScale,1/_,1/w),n.plot.call(a.setTranslate,S,E).call(a.setScale,_,w),a.setPointGroupScale(n.zoomScalePts,1/_,1/w),a.setTextPointsScale(n.zoomScaleTxt,1/_,1/w)}o.redrawComponents(t)}},{\"../../components/drawing\":614,\"../../registry\":847,\"./axes\":767,d3:163}],790:[function(t,e,r){\"use strict\";var n=t(\"../../registry\").traceIs,i=t(\"./axis_autotype\");function a(t){return{v:\"x\",h:\"y\"}[t.orientation||\"v\"]}function o(t,e){var r=a(t),i=n(t,\"box-violin\"),o=n(t._fullInput||{},\"candlestick\");return i&&!o&&e===r&&void 0===t[r]&&void 0===t[r+\"0\"]}e.exports=function(t,e,r,s){\"-\"===r(\"type\",(s.splomStash||{}).type)&&(!function(t,e){if(\"-\"!==t.type)return;var r=t._id,s=r.charAt(0);-1!==r.indexOf(\"scene\")&&(r=s);var l=function(t,e,r){for(var n=0;n<t.length;n++){var i=t[n];if(\"splom\"===i.type&&i._length>0&&(i[\"_\"+r+\"axes\"]||{})[e])return i;if((i[r+\"axis\"]||r)===e){if(o(i,r))return i;if((i[r]||[]).length||i[r+\"0\"])return i}}}(e,r,s);if(!l)return;if(\"histogram\"===l.type&&s==={v:\"y\",h:\"x\"}[l.orientation||\"v\"])return void(t.type=\"linear\");var c,u=s+\"calendar\",h=l[u],f={noMultiCategory:!n(l,\"cartesian\")||n(l,\"noMultiCategory\")};if(o(l,s)){var p=a(l),d=[];for(c=0;c<e.length;c++){var g=e[c];n(g,\"box-violin\")&&(g[s+\"axis\"]||s)===r&&(void 0!==g[p]?d.push(g[p][0]):void 0!==g.name?d.push(g.name):d.push(\"text\"),g[u]!==h&&(h=void 0))}t.type=i(d,h,f)}else if(\"splom\"===l.type){var v=l.dimensions,m=v[l._axesDim[r]];m.visible&&(t.type=i(m.values,h,f))}else t.type=i(l[s]||[l[s+\"0\"]],h,f)}(e,s.data),\"-\"===e.type?e.type=\"linear\":t.type=e.type)}},{\"../../registry\":847,\"./axis_autotype\":768}],791:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\");function a(t,e,r){var n,a,o,s=!1;if(\"data\"===e.type)n=t._fullData[null!==e.traces?e.traces[0]:0];else{if(\"layout\"!==e.type)return!1;n=t._fullLayout}return a=i.nestedProperty(n,e.prop).get(),(o=r[e.type]=r[e.type]||{}).hasOwnProperty(e.prop)&&o[e.prop]!==a&&(s=!0),o[e.prop]=a,{changed:s,value:a}}function o(t,e){var r=[],n=e[0],a={};if(\"string\"==typeof n)a[n]=e[1];else{if(!i.isPlainObject(n))return r;a=n}return l(a,function(t,e,n){r.push({type:\"layout\",prop:t,value:n})},\"\",0),r}function s(t,e){var r,n,a,o,s=[];if(n=e[0],a=e[1],r=e[2],o={},\"string\"==typeof n)o[n]=a;else{if(!i.isPlainObject(n))return s;o=n,void 0===r&&(r=a)}return void 0===r&&(r=null),l(o,function(e,n,i){var a,o;if(Array.isArray(i)){o=i.slice();var l=Math.min(o.length,t.data.length);r&&(l=Math.min(l,r.length)),a=[];for(var c=0;c<l;c++)a[c]=r?r[c]:c}else o=i,a=r?r.slice():null;if(null===a)Array.isArray(o)&&(o=o[0]);else if(Array.isArray(a)){if(!Array.isArray(o)){var u=o;o=[];for(var h=0;h<a.length;h++)o[h]=u}o.length=Math.min(a.length,o.length)}s.push({type:\"data\",prop:e,traces:a,value:o})},\"\",0),s}function l(t,e,r,n){Object.keys(t).forEach(function(a){var o=t[a];if(\"_\"!==a[0]){var s=r+(n>0?\".\":\"\")+a;i.isPlainObject(o)?l(o,e,s,n+1):e(s,a,o)}})}r.manageCommandObserver=function(t,e,n,o){var s={},l=!0;e&&e._commandObserver&&(s=e._commandObserver),s.cache||(s.cache={}),s.lookupTable={};var c=r.hasSimpleAPICommandBindings(t,n,s.lookupTable);if(e&&e._commandObserver){if(c)return s;if(e._commandObserver.remove)return e._commandObserver.remove(),e._commandObserver=null,s}if(c){a(t,c,s.cache),s.check=function(){if(l){var e=a(t,c,s.cache);return e.changed&&o&&void 0!==s.lookupTable[e.value]&&(s.disable(),Promise.resolve(o({value:e.value,type:c.type,prop:c.prop,traces:c.traces,index:s.lookupTable[e.value]})).then(s.enable,s.enable)),e.changed}};for(var u=[\"plotly_relayout\",\"plotly_redraw\",\"plotly_restyle\",\"plotly_update\",\"plotly_animatingframe\",\"plotly_afterplot\"],h=0;h<u.length;h++)t._internalOn(u[h],s.check);s.remove=function(){for(var e=0;e<u.length;e++)t._removeInternalListener(u[e],s.check)}}else i.log(\"Unable to automatically bind plot updates to API command\"),s.lookupTable={},s.remove=function(){};return s.disable=function(){l=!1},s.enable=function(){l=!0},e&&(e._commandObserver=s),s},r.hasSimpleAPICommandBindings=function(t,e,n){var i,a,o=e.length;for(i=0;i<o;i++){var s,l=e[i],c=l.method,u=l.args;if(Array.isArray(u)||(u=[]),!c)return!1;var h=r.computeAPICommandBindings(t,c,u);if(1!==h.length)return!1;if(a){if((s=h[0]).type!==a.type)return!1;if(s.prop!==a.prop)return!1;if(Array.isArray(a.traces)){if(!Array.isArray(s.traces))return!1;s.traces.sort();for(var f=0;f<a.traces.length;f++)if(a.traces[f]!==s.traces[f])return!1}else if(s.prop!==a.prop)return!1}else a=h[0],Array.isArray(a.traces)&&a.traces.sort();var p=(s=h[0]).value;if(Array.isArray(p)){if(1!==p.length)return!1;p=p[0]}n&&(n[p]=i)}return a},r.executeAPICommand=function(t,e,r){if(\"skip\"===e)return Promise.resolve();var a=n.apiMethodRegistry[e],o=[t];Array.isArray(r)||(r=[]);for(var s=0;s<r.length;s++)o.push(r[s]);return a.apply(null,o).catch(function(t){return i.warn(\"API call to Plotly.\"+e+\" rejected.\",t),Promise.reject(t)})},r.computeAPICommandBindings=function(t,e,r){var n;switch(Array.isArray(r)||(r=[]),e){case\"restyle\":n=s(t,r);break;case\"relayout\":n=o(t,r);break;case\"update\":n=s(t,[r[0],r[2]]).concat(o(t,[r[1]]));break;case\"animate\":n=function(t,e){return Array.isArray(e[0])&&1===e[0].length&&-1!==[\"string\",\"number\"].indexOf(typeof e[0][0])?[{type:\"layout\",prop:\"_currentFrame\",value:e[0][0].toString()}]:[]}(0,r);break;default:n=[]}return n}},{\"../lib\":719,\"../registry\":847}],792:[function(t,e,r){\"use strict\";var n=t(\"../lib/extend\").extendFlat;r.attributes=function(t,e){e=e||{};var r={valType:\"info_array\",editType:(t=t||{}).editType,items:[{valType:\"number\",min:0,max:1,editType:t.editType},{valType:\"number\",min:0,max:1,editType:t.editType}],dflt:[0,1]},i=(t.name&&t.name,t.trace,e.description&&e.description,{x:n({},r,{}),y:n({},r,{}),editType:t.editType});return t.noGridCell||(i.row={valType:\"integer\",min:0,dflt:0,editType:t.editType},i.column={valType:\"integer\",min:0,dflt:0,editType:t.editType}),i},r.defaults=function(t,e,r,n){var i=n&&n.x||[0,1],a=n&&n.y||[0,1],o=e.grid;if(o){var s=r(\"domain.column\");void 0!==s&&(s<o.columns?i=o._domains.x[s]:delete t.domain.column);var l=r(\"domain.row\");void 0!==l&&(l<o.rows?a=o._domains.y[l]:delete t.domain.row)}r(\"domain.x\",i),r(\"domain.y\",a)}},{\"../lib/extend\":710}],793:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType,r=t.colorEditType;void 0===r&&(r=e);var n={family:{valType:\"string\",noBlank:!0,strict:!0,editType:e},size:{valType:\"number\",min:1,editType:e},color:{valType:\"color\",editType:r},editType:e};return t.arrayOk&&(n.family.arrayOk=!0,n.size.arrayOk=!0,n.color.arrayOk=!0),n}},{}],794:[function(t,e,r){\"use strict\";e.exports={_isLinkedToArray:\"frames_entry\",group:{valType:\"string\"},name:{valType:\"string\"},traces:{valType:\"any\"},baseframe:{valType:\"string\"},data:{valType:\"any\"},layout:{valType:\"any\"}}},{}],795:[function(t,e,r){\"use strict\";r.projNames={equirectangular:\"equirectangular\",mercator:\"mercator\",orthographic:\"orthographic\",\"natural earth\":\"naturalEarth\",kavrayskiy7:\"kavrayskiy7\",miller:\"miller\",robinson:\"robinson\",eckert4:\"eckert4\",\"azimuthal equal area\":\"azimuthalEqualArea\",\"azimuthal equidistant\":\"azimuthalEquidistant\",\"conic equal area\":\"conicEqualArea\",\"conic conformal\":\"conicConformal\",\"conic equidistant\":\"conicEquidistant\",gnomonic:\"gnomonic\",stereographic:\"stereographic\",mollweide:\"mollweide\",hammer:\"hammer\",\"transverse mercator\":\"transverseMercator\",\"albers usa\":\"albersUsa\",\"winkel tripel\":\"winkel3\",aitoff:\"aitoff\",sinusoidal:\"sinusoidal\"},r.axesNames=[\"lonaxis\",\"lataxis\"],r.lonaxisSpan={orthographic:180,\"azimuthal equal area\":360,\"azimuthal equidistant\":360,\"conic conformal\":180,gnomonic:160,stereographic:180,\"transverse mercator\":180,\"*\":360},r.lataxisSpan={\"conic conformal\":150,stereographic:179.5,\"*\":180},r.scopeDefaults={world:{lonaxisRange:[-180,180],lataxisRange:[-90,90],projType:\"equirectangular\",projRotate:[0,0,0]},usa:{lonaxisRange:[-180,-50],lataxisRange:[15,80],projType:\"albers usa\"},europe:{lonaxisRange:[-30,60],lataxisRange:[30,85],projType:\"conic conformal\",projRotate:[15,0,0],projParallels:[0,60]},asia:{lonaxisRange:[22,160],lataxisRange:[-15,55],projType:\"mercator\",projRotate:[0,0,0]},africa:{lonaxisRange:[-30,60],lataxisRange:[-40,40],projType:\"mercator\",projRotate:[0,0,0]},\"north america\":{lonaxisRange:[-180,-45],lataxisRange:[5,85],projType:\"conic conformal\",projRotate:[-100,0,0],projParallels:[29.5,45.5]},\"south america\":{lonaxisRange:[-100,-30],lataxisRange:[-60,15],projType:\"mercator\",projRotate:[0,0,0]}},r.clipPad=.001,r.precision=.1,r.landColor=\"#F0DC82\",r.waterColor=\"#3399FF\",r.locationmodeToLayer={\"ISO-3\":\"countries\",\"USA-states\":\"subunits\",\"country names\":\"countries\"},r.sphereSVG={type:\"Sphere\"},r.fillLayers={ocean:1,land:1,lakes:1},r.lineLayers={subunits:1,countries:1,coastlines:1,rivers:1,frame:1},r.layers=[\"bg\",\"ocean\",\"land\",\"lakes\",\"subunits\",\"countries\",\"coastlines\",\"rivers\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"frontplot\"],r.layersForChoropleth=[\"bg\",\"ocean\",\"land\",\"subunits\",\"countries\",\"coastlines\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"rivers\",\"lakes\",\"frontplot\"],r.layerNameToAdjective={ocean:\"ocean\",land:\"land\",lakes:\"lake\",subunits:\"subunit\",countries:\"country\",coastlines:\"coastline\",rivers:\"river\",frame:\"frame\"}},{}],796:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"../../components/fx\"),c=t(\"../plots\"),u=t(\"../cartesian/axes\"),h=t(\"../../components/dragelement\"),f=t(\"../cartesian/select\").prepSelect,p=t(\"../cartesian/select\").selectOnClick,d=t(\"./zoom\"),g=t(\"./constants\"),v=t(\"../../lib/topojson_utils\"),m=t(\"topojson-client\").feature;function y(t){this.id=t.id,this.graphDiv=t.graphDiv,this.container=t.container,this.topojsonURL=t.topojsonURL,this.isStatic=t.staticPlot,this.topojsonName=null,this.topojson=null,this.projection=null,this.scope=null,this.viewInitial=null,this.fitScale=null,this.bounds=null,this.midPt=null,this.hasChoropleth=!1,this.traceHash={},this.layers={},this.basePaths={},this.dataPaths={},this.dataPoints={},this.clipDef=null,this.clipRect=null,this.bgRect=null,this.makeFramework()}t(\"./projections\")(n);var x=y.prototype;e.exports=function(t){return new y(t)},x.plot=function(t,e,r){var n=this,i=e[this.id],a=!1;for(var o in g.layerNameToAdjective)if(\"frame\"!==o&&i[\"show\"+o]){a=!0;break}for(var s=0;s<t.length;s++)if(t[0][0].trace.locationmode){a=!0;break}if(!a)return n.update(t,e);var l=v.getTopojsonName(i);null===n.topojson||l!==n.topojsonName?(n.topojsonName=l,void 0===PlotlyGeoAssets.topojson[n.topojsonName]?r.push(n.fetchTopojson().then(function(r){PlotlyGeoAssets.topojson[n.topojsonName]=r,n.topojson=r,n.update(t,e)})):(n.topojson=PlotlyGeoAssets.topojson[n.topojsonName],n.update(t,e))):n.update(t,e)},x.fetchTopojson=function(){var t=v.getTopojsonPath(this.topojsonURL,this.topojsonName);return new Promise(function(e,r){n.json(t,function(n,i){if(n)return 404===n.status?r(new Error([\"plotly.js could not find topojson file at\",t,\".\",\"Make sure the *topojsonURL* plot config option\",\"is set properly.\"].join(\" \"))):r(new Error([\"unexpected error while fetching topojson file at\",t].join(\" \")));e(i)})})},x.update=function(t,e){var r=e[this.id];if(!this.updateProjection(e,r)){this.hasChoropleth=!1;for(var n=0;n<t.length;n++)if(\"choropleth\"===t[n][0].trace.type){this.hasChoropleth=!0;break}this.viewInitial&&this.scope===r.scope||this.saveViewInitial(r),this.scope=r.scope,this.updateBaseLayers(e,r),this.updateDims(e,r),this.updateFx(e,r),c.generalUpdatePerTraceModule(this.graphDiv,this,t,r);var i=this.layers.frontplot.select(\".scatterlayer\");this.dataPoints.point=i.selectAll(\".point\"),this.dataPoints.text=i.selectAll(\"text\"),this.dataPaths.line=i.selectAll(\".js-line\");var a=this.layers.backplot.select(\".choroplethlayer\");this.dataPaths.choropleth=a.selectAll(\"path\"),this.render()}},x.updateProjection=function(t,e){var r=t._size,o=e.domain,s=e.projection,l=s.rotation||{},c=e.center||{},u=this.projection=function(t){for(var e=t.projection.type,r=n.geo[g.projNames[e]](),i=t._isClipped?g.lonaxisSpan[e]/2:null,a=[\"center\",\"rotate\",\"parallels\",\"clipExtent\"],o=function(t){return t?r:[]},s=0;s<a.length;s++){var l=a[s];\"function\"!=typeof r[l]&&(r[l]=o)}r.isLonLatOverEdges=function(t){if(null===r(t))return!0;if(i){var e=r.rotate();return n.geo.distance(t,[-e[0],-e[1]])>i*Math.PI/180}return!1},r.getPath=function(){return n.geo.path().projection(r)},r.getBounds=function(t){return r.getPath().bounds(t)},r.fitExtent=function(t,e){var n=t[1][0]-t[0][0],i=t[1][1]-t[0][1],a=r.clipExtent&&r.clipExtent();r.scale(150).translate([0,0]),a&&r.clipExtent(null);var o=r.getBounds(e),s=Math.min(n/(o[1][0]-o[0][0]),i/(o[1][1]-o[0][1])),l=+t[0][0]+(n-s*(o[1][0]+o[0][0]))/2,c=+t[0][1]+(i-s*(o[1][1]+o[0][1]))/2;return a&&r.clipExtent(a),r.scale(150*s).translate([l,c])},r.precision(g.precision),i&&r.clipAngle(i-g.clipPad);return r}(e);u.center([c.lon-l.lon,c.lat-l.lat]).rotate([-l.lon,-l.lat,l.roll]).parallels(s.parallels);var h=[[r.l+r.w*o.x[0],r.t+r.h*(1-o.y[1])],[r.l+r.w*o.x[1],r.t+r.h*(1-o.y[0])]],f=e.lonaxis,p=e.lataxis,d=function(t,e){var r=g.clipPad,n=t[0]+r,i=t[1]-r,a=e[0]+r,o=e[1]-r;n>0&&i<0&&(i+=360);var s=(i-n)/4;return{type:\"Polygon\",coordinates:[[[n,a],[n,o],[n+s,o],[n+2*s,o],[n+3*s,o],[i,o],[i,a],[i-s,a],[i-2*s,a],[i-3*s,a],[n,a]]]}}(f.range,p.range);u.fitExtent(h,d);var v=this.bounds=u.getBounds(d),m=this.fitScale=u.scale(),y=u.translate();if(!isFinite(v[0][0])||!isFinite(v[0][1])||!isFinite(v[1][0])||!isFinite(v[1][1])||isNaN(y[0])||isNaN(y[0])){for(var x=this.graphDiv,b=[\"projection.rotation\",\"center\",\"lonaxis.range\",\"lataxis.range\"],_=\"Invalid geo settings, relayout'ing to default view.\",w={},k=0;k<b.length;k++)w[this.id+\".\"+b[k]]=null;return this.viewInitial=null,a.warn(_),x._promises.push(i.call(\"relayout\",x,w)),_}var T=this.midPt=[(v[0][0]+v[1][0])/2,(v[0][1]+v[1][1])/2];if(u.scale(s.scale*m).translate([y[0]+(T[0]-y[0]),y[1]+(T[1]-y[1])]).clipExtent(v),e._isAlbersUsa){var A=u([c.lon,c.lat]),M=u.translate();u.translate([M[0]-(A[0]-M[0]),M[1]-(A[1]-M[1])])}},x.updateBaseLayers=function(t,e){var r=this,i=r.topojson,a=r.layers,l=r.basePaths;function c(t){return\"lonaxis\"===t||\"lataxis\"===t}function h(t){return Boolean(g.lineLayers[t])}function f(t){return Boolean(g.fillLayers[t])}var p=(this.hasChoropleth?g.layersForChoropleth:g.layers).filter(function(t){return h(t)||f(t)?e[\"show\"+t]:!c(t)||e[t].showgrid}),d=r.framework.selectAll(\".layer\").data(p,String);d.exit().each(function(t){delete a[t],delete l[t],n.select(this).remove()}),d.enter().append(\"g\").attr(\"class\",function(t){return\"layer \"+t}).each(function(t){var e=a[t]=n.select(this);\"bg\"===t?r.bgRect=e.append(\"rect\").style(\"pointer-events\",\"all\"):c(t)?l[t]=e.append(\"path\").style(\"fill\",\"none\"):\"backplot\"===t?e.append(\"g\").classed(\"choroplethlayer\",!0):\"frontplot\"===t?e.append(\"g\").classed(\"scatterlayer\",!0):h(t)?l[t]=e.append(\"path\").style(\"fill\",\"none\").style(\"stroke-miterlimit\",2):f(t)&&(l[t]=e.append(\"path\").style(\"stroke\",\"none\"))}),d.order(),d.each(function(r){var n=l[r],a=g.layerNameToAdjective[r];\"frame\"===r?n.datum(g.sphereSVG):h(r)||f(r)?n.datum(m(i,i.objects[r])):c(r)&&n.datum(function(t,e,r){var n,i,a,o=e[t],s=g.scopeDefaults[e.scope];\"lonaxis\"===t?(n=s.lonaxisRange,i=s.lataxisRange,a=function(t,e){return[t,e]}):\"lataxis\"===t&&(n=s.lataxisRange,i=s.lonaxisRange,a=function(t,e){return[e,t]});var l={type:\"linear\",range:[n[0],n[1]-1e-6],tick0:o.tick0,dtick:o.dtick};u.setConvert(l,r);var c=u.calcTicks(l);e.isScoped||\"lonaxis\"!==t||c.pop();for(var h=c.length,f=new Array(h),p=0;p<h;p++)for(var d=c[p].x,v=f[p]=[],m=i[0];m<i[1]+2.5;m+=2.5)v.push(a(d,m));return{type:\"MultiLineString\",coordinates:f}}(r,e,t)).call(o.stroke,e[r].gridcolor).call(s.dashLine,\"\",e[r].gridwidth),h(r)?n.call(o.stroke,e[a+\"color\"]).call(s.dashLine,\"\",e[a+\"width\"]):f(r)&&n.call(o.fill,e[a+\"color\"])})},x.updateDims=function(t,e){var r=this.bounds,n=(e.framewidth||0)/2,i=r[0][0]-n,a=r[0][1]-n,l=r[1][0]-i+n,c=r[1][1]-a+n;s.setRect(this.clipRect,i,a,l,c),this.bgRect.call(s.setRect,i,a,l,c).call(o.fill,e.bgcolor),this.xaxis._offset=i,this.xaxis._length=l,this.yaxis._offset=a,this.yaxis._length=c},x.updateFx=function(t,e){var r=this,a=r.graphDiv,o=r.bgRect,s=t.dragmode,c=t.clickmode;if(!r.isStatic){var u;\"select\"===s?u=function(t,e){(t.range={})[r.id]=[v([e.xmin,e.ymin]),v([e.xmax,e.ymax])]}:\"lasso\"===s&&(u=function(t,e,n){(t.lassoPoints={})[r.id]=n.filtered.map(v)});var g={element:r.bgRect.node(),gd:a,plotinfo:{id:r.id,xaxis:r.xaxis,yaxis:r.yaxis,fillRangeItems:u},xaxes:[r.xaxis],yaxes:[r.yaxis],subplot:r.id,clickFn:function(e){2===e&&t._zoomlayer.selectAll(\".select-outline\").remove()}};\"pan\"===s?(o.node().onmousedown=null,o.call(d(r,e)),o.on(\"dblclick.zoom\",function(){var t=r.viewInitial,e={};for(var n in t)e[r.id+\".\"+n]=t[n];i.call(\"_guiRelayout\",a,e),a.emit(\"plotly_doubleclick\",null)}),a._context._scrollZoom.geo||o.on(\"wheel.zoom\",null)):\"select\"!==s&&\"lasso\"!==s||(o.on(\".zoom\",null),g.prepFn=function(t,e,r){f(t,e,r,g,s)},h.init(g)),o.on(\"mousemove\",function(){var t=r.projection.invert(n.mouse(this));if(!t||isNaN(t[0])||isNaN(t[1]))return h.unhover(a,n.event);r.xaxis.p2c=function(){return t[0]},r.yaxis.p2c=function(){return t[1]},l.hover(a,n.event,r.id)}),o.on(\"mouseout\",function(){a._dragging||h.unhover(a,n.event)}),o.on(\"click\",function(){\"select\"!==s&&\"lasso\"!==s&&(c.indexOf(\"select\")>-1&&p(n.event,a,[r.xaxis],[r.yaxis],r.id,g),c.indexOf(\"event\")>-1&&l.click(a,n.event))})}function v(t){return r.projection.invert([t[0]+r.xaxis._offset,t[1]+r.yaxis._offset])}},x.makeFramework=function(){var t=this,e=t.graphDiv,r=e._fullLayout,i=\"clip\"+r._uid+t.id;t.clipDef=r._clips.append(\"clipPath\").attr(\"id\",i),t.clipRect=t.clipDef.append(\"rect\"),t.framework=n.select(t.container).append(\"g\").attr(\"class\",\"geo \"+t.id).call(s.setClipUrl,i,e),t.project=function(e){var r=t.projection(e);return r?[r[0]-t.xaxis._offset,r[1]-t.yaxis._offset]:[null,null]},t.xaxis={_id:\"x\",c2p:function(e){return t.project(e)[0]}},t.yaxis={_id:\"y\",c2p:function(e){return t.project(e)[1]}},t.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},u.setConvert(t.mockAxis,r)},x.saveViewInitial=function(t){var e=t.center||{},r=t.projection,n=r.rotation||{};t._isScoped?this.viewInitial={\"center.lon\":e.lon,\"center.lat\":e.lat,\"projection.scale\":r.scale}:t._isClipped?this.viewInitial={\"projection.scale\":r.scale,\"projection.rotation.lon\":n.lon,\"projection.rotation.lat\":n.lat}:this.viewInitial={\"center.lon\":e.lon,\"center.lat\":e.lat,\"projection.scale\":r.scale,\"projection.rotation.lon\":n.lon}},x.render=function(){var t,e=this.projection,r=e.getPath();function n(t){var r=e(t.lonlat);return r?\"translate(\"+r[0]+\",\"+r[1]+\")\":null}function i(t){return e.isLonLatOverEdges(t.lonlat)?\"none\":null}for(t in this.basePaths)this.basePaths[t].attr(\"d\",r);for(t in this.dataPaths)this.dataPaths[t].attr(\"d\",function(t){return r(t.geojson)});for(t in this.dataPoints)this.dataPoints[t].attr(\"display\",i).attr(\"transform\",n)}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../lib\":719,\"../../lib/topojson_utils\":746,\"../../registry\":847,\"../cartesian/axes\":767,\"../cartesian/select\":784,\"../plots\":828,\"./constants\":795,\"./projections\":800,\"./zoom\":801,d3:163,\"topojson-client\":540}],797:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./geo\"),o=\"geo\",s=i(o),l={};l[o]={valType:\"subplotid\",dflt:o,editType:\"calc\"},e.exports={attr:o,name:o,idRoot:o,idRegex:s,attrRegex:s,attributes:l,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[o],s=0;s<i.length;s++){var l=i[s],c=n(r,o,l),u=e[l]._subplot;u||(u=a({id:l,graphDiv:t,container:e._geolayer.node(),topojsonURL:t._context.topojsonURL,staticPlot:t._context.staticPlot}),e[l]._subplot=u),u.plot(c,e,t._promises)}},updateFx:function(t){for(var e=t._fullLayout,r=e._subplots[o],n=0;n<r.length;n++){var i=e[r[n]];i._subplot.updateFx(e,i)}},clean:function(t,e,r,n){for(var i=n._subplots[o]||[],a=0;a<i.length;a++){var s=i[a],l=n[s]._subplot;!e[s]&&l&&(l.framework.remove(),l.clipDef.remove())}}}},{\"../../lib\":719,\"../../plots/get_data\":802,\"./geo\":796,\"./layout_attributes\":798,\"./layout_defaults\":799}],798:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"./constants\"),o=t(\"../../plot_api/edit_types\").overrideAll,s={range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},showgrid:{valType:\"boolean\",dflt:!1},tick0:{valType:\"number\",dflt:0},dtick:{valType:\"number\"},gridcolor:{valType:\"color\",dflt:n.lightLine},gridwidth:{valType:\"number\",min:0,dflt:1}};(e.exports=o({domain:i({name:\"geo\"},{}),resolution:{valType:\"enumerated\",values:[110,50],dflt:110,coerceNumber:!0},scope:{valType:\"enumerated\",values:Object.keys(a.scopeDefaults),dflt:\"world\"},projection:{type:{valType:\"enumerated\",values:Object.keys(a.projNames)},rotation:{lon:{valType:\"number\"},lat:{valType:\"number\"},roll:{valType:\"number\"}},parallels:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},scale:{valType:\"number\",min:0,dflt:1}},center:{lon:{valType:\"number\"},lat:{valType:\"number\"}},showcoastlines:{valType:\"boolean\"},coastlinecolor:{valType:\"color\",dflt:n.defaultLine},coastlinewidth:{valType:\"number\",min:0,dflt:1},showland:{valType:\"boolean\",dflt:!1},landcolor:{valType:\"color\",dflt:a.landColor},showocean:{valType:\"boolean\",dflt:!1},oceancolor:{valType:\"color\",dflt:a.waterColor},showlakes:{valType:\"boolean\",dflt:!1},lakecolor:{valType:\"color\",dflt:a.waterColor},showrivers:{valType:\"boolean\",dflt:!1},rivercolor:{valType:\"color\",dflt:a.waterColor},riverwidth:{valType:\"number\",min:0,dflt:1},showcountries:{valType:\"boolean\"},countrycolor:{valType:\"color\",dflt:n.defaultLine},countrywidth:{valType:\"number\",min:0,dflt:1},showsubunits:{valType:\"boolean\"},subunitcolor:{valType:\"color\",dflt:n.defaultLine},subunitwidth:{valType:\"number\",min:0,dflt:1},showframe:{valType:\"boolean\"},framecolor:{valType:\"color\",dflt:n.defaultLine},framewidth:{valType:\"number\",min:0,dflt:1},bgcolor:{valType:\"color\",dflt:n.background},lonaxis:s,lataxis:s},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":592,\"../../plot_api/edit_types\":750,\"../domain\":792,\"./constants\":795}],799:[function(t,e,r){\"use strict\";var n=t(\"../subplot_defaults\"),i=t(\"./constants\"),a=t(\"./layout_attributes\"),o=i.axesNames;function s(t,e,r){var n=r(\"resolution\"),a=r(\"scope\"),s=i.scopeDefaults[a],l=r(\"projection.type\",s.projType),c=e._isAlbersUsa=\"albers usa\"===l;c&&(a=e.scope=\"usa\");var u=e._isScoped=\"world\"!==a,h=e._isConic=-1!==l.indexOf(\"conic\");e._isClipped=!!i.lonaxisSpan[l];for(var f=0;f<o.length;f++){var p,d=o[f],g=[30,10][f];if(u)p=s[d+\"Range\"];else{var v=i[d+\"Span\"],m=(v[l]||v[\"*\"])/2,y=r(\"projection.rotation.\"+d.substr(0,3),s.projRotate[f]);p=[y-m,y+m]}r(d+\".range\",p),r(d+\".tick0\"),r(d+\".dtick\",g),r(d+\".showgrid\")&&(r(d+\".gridcolor\"),r(d+\".gridwidth\"))}var x=e.lonaxis.range,b=e.lataxis.range,_=x[0],w=x[1];_>0&&w<0&&(w+=360);var k,T,A,M=(_+w)/2;if(!c){var S=u?s.projRotate:[M,0,0];k=r(\"projection.rotation.lon\",S[0]),r(\"projection.rotation.lat\",S[1]),r(\"projection.rotation.roll\",S[2]),r(\"showcoastlines\",!u)&&(r(\"coastlinecolor\"),r(\"coastlinewidth\")),r(\"showocean\")&&r(\"oceancolor\")}(c?(T=-96.6,A=38.7):(T=u?M:k,A=(b[0]+b[1])/2),r(\"center.lon\",T),r(\"center.lat\",A),h)&&r(\"projection.parallels\",s.projParallels||[0,60]);r(\"projection.scale\"),r(\"showland\")&&r(\"landcolor\"),r(\"showlakes\")&&r(\"lakecolor\"),r(\"showrivers\")&&(r(\"rivercolor\"),r(\"riverwidth\")),r(\"showcountries\",u&&\"usa\"!==a)&&(r(\"countrycolor\"),r(\"countrywidth\")),(\"usa\"===a||\"north america\"===a&&50===n)&&(r(\"showsubunits\",!0),r(\"subunitcolor\"),r(\"subunitwidth\")),u||r(\"showframe\",!0)&&(r(\"framecolor\"),r(\"framewidth\")),r(\"bgcolor\")}e.exports=function(t,e,r){n(t,e,r,{type:\"geo\",attributes:a,handleDefaults:s,partition:\"y\"})}},{\"../subplot_defaults\":842,\"./constants\":795,\"./layout_attributes\":798}],800:[function(t,e,r){\"use strict\";e.exports=function(t){function e(t,e){return{type:\"Feature\",id:t.id,properties:t.properties,geometry:r(t.geometry,e)}}function r(e,n){if(!e)return null;if(\"GeometryCollection\"===e.type)return{type:\"GeometryCollection\",geometries:object.geometries.map(function(t){return r(t,n)})};if(!c.hasOwnProperty(e.type))return null;var i=c[e.type];return t.geo.stream(e,n(i)),i.result()}t.geo.project=function(t,e){var i=e.stream;if(!i)throw new Error(\"not yet supported\");return(t&&n.hasOwnProperty(t.type)?n[t.type]:r)(t,i)};var n={Feature:e,FeatureCollection:function(t,r){return{type:\"FeatureCollection\",features:t.features.map(function(t){return e(t,r)})}}},i=[],a=[],o={point:function(t,e){i.push([t,e])},result:function(){var t=i.length?i.length<2?{type:\"Point\",coordinates:i[0]}:{type:\"MultiPoint\",coordinates:i}:null;return i=[],t}},s={lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){i.length&&(a.push(i),i=[])},result:function(){var t=a.length?a.length<2?{type:\"LineString\",coordinates:a[0]}:{type:\"MultiLineString\",coordinates:a}:null;return a=[],t}},l={polygonStart:u,lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){var t=i.length;if(t){do{i.push(i[0].slice())}while(++t<4);a.push(i),i=[]}},polygonEnd:u,result:function(){if(!a.length)return null;var t=[],e=[];return a.forEach(function(r){!function(t){if((e=t.length)<4)return!1;for(var e,r=0,n=t[e-1][1]*t[0][0]-t[e-1][0]*t[0][1];++r<e;)n+=t[r-1][1]*t[r][0]-t[r-1][0]*t[r][1];return n<=0}(r)?e.push(r):t.push([r])}),e.forEach(function(e){var r=e[0];t.some(function(t){if(function(t,e){for(var r=e[0],n=e[1],i=!1,a=0,o=t.length,s=o-1;a<o;s=a++){var l=t[a],c=l[0],u=l[1],h=t[s],f=h[0],p=h[1];u>n^p>n&&r<(f-c)*(n-u)/(p-u)+c&&(i=!i)}return i}(t[0],r))return t.push(e),!0})||t.push([e])}),a=[],t.length?t.length>1?{type:\"MultiPolygon\",coordinates:t}:{type:\"Polygon\",coordinates:t[0]}:null}},c={Point:o,MultiPoint:o,LineString:s,MultiLineString:s,Polygon:l,MultiPolygon:l,Sphere:l};function u(){}var h=1e-6,f=h*h,p=Math.PI,d=p/2,g=(Math.sqrt(p),p/180),v=180/p;function m(t){return t>1?d:t<-1?-d:Math.asin(t)}function y(t){return t>1?0:t<-1?p:Math.acos(t)}var x=t.geo.projection,b=t.geo.projectionMutator;function _(t,e){var r=(2+d)*Math.sin(e);e/=2;for(var n=0,i=1/0;n<10&&Math.abs(i)>h;n++){var a=Math.cos(e);e-=i=(e+Math.sin(e)*(a+2)-r)/(2*a*(1+a))}return[2/Math.sqrt(p*(4+p))*t*(1+Math.cos(e)),2*Math.sqrt(p/(4+p))*Math.sin(e)]}t.geo.interrupt=function(e){var r,n=[[[[-p,0],[0,d],[p,0]]],[[[-p,0],[0,-d],[p,0]]]];function i(t,r){for(var i=r<0?-1:1,a=n[+(r<0)],o=0,s=a.length-1;o<s&&t>a[o][2][0];++o);var l=e(t-a[o][1][0],r);return l[0]+=e(a[o][1][0],i*r>i*a[o][0][1]?a[o][0][1]:r)[0],l}e.invert&&(i.invert=function(t,a){for(var o=r[+(a<0)],s=n[+(a<0)],c=0,u=o.length;c<u;++c){var h=o[c];if(h[0][0]<=t&&t<h[1][0]&&h[0][1]<=a&&a<h[1][1]){var f=e.invert(t-e(s[c][1][0],0)[0],a);return f[0]+=s[c][1][0],l(i(f[0],f[1]),[t,a])?f:null}}});var a=t.geo.projection(i),o=a.stream;function s(t,e){for(var r,n,i,a=-1,o=t.length,s=t[0],l=[];++a<o;){n=((r=t[a])[0]-s[0])/e,i=(r[1]-s[1])/e;for(var c=0;c<e;++c)l.push([s[0]+c*n,s[1]+c*i]);s=r}return l.push(r),l}function l(t,e){return Math.abs(t[0]-e[0])<h&&Math.abs(t[1]-e[1])<h}return a.stream=function(e){var r=a.rotate(),i=o(e),l=(a.rotate([0,0]),o(e));return a.rotate(r),i.sphere=function(){t.geo.stream(function(){for(var e=1e-6,r=[],i=0,a=n[0].length;i<a;++i){var o=n[0][i],l=180*o[0][0]/p,c=180*o[0][1]/p,u=180*o[1][1]/p,h=180*o[2][0]/p,f=180*o[2][1]/p;r.push(s([[l+e,c+e],[l+e,u-e],[h-e,u-e],[h-e,f+e]],30))}for(var i=n[1].length-1;i>=0;--i){var o=n[1][i],l=180*o[0][0]/p,c=180*o[0][1]/p,u=180*o[1][1]/p,h=180*o[2][0]/p,f=180*o[2][1]/p;r.push(s([[h-e,f-e],[h-e,u+e],[l+e,u+e],[l+e,c-e]],30))}return{type:\"Polygon\",coordinates:[t.merge(r)]}}(),l)},i},a.lobes=function(t){return arguments.length?(n=t.map(function(t){return t.map(function(t){return[[t[0][0]*p/180,t[0][1]*p/180],[t[1][0]*p/180,t[1][1]*p/180],[t[2][0]*p/180,t[2][1]*p/180]]})}),r=n.map(function(t){return t.map(function(t){var r,n=e(t[0][0],t[0][1])[0],i=e(t[2][0],t[2][1])[0],a=e(t[1][0],t[0][1])[1],o=e(t[1][0],t[1][1])[1];return a>o&&(r=a,a=o,o=r),[[n,a],[i,o]]})}),a):n.map(function(t){return t.map(function(t){return[[180*t[0][0]/p,180*t[0][1]/p],[180*t[1][0]/p,180*t[1][1]/p],[180*t[2][0]/p,180*t[2][1]/p]]})})},a},_.invert=function(t,e){var r=.5*e*Math.sqrt((4+p)/p),n=m(r),i=Math.cos(n);return[t/(2/Math.sqrt(p*(4+p))*(1+i)),m((n+r*(i+2))/(2+d))]},(t.geo.eckert4=function(){return x(_)}).raw=_;var w=t.geo.azimuthalEqualArea.raw;function k(t,e){if(arguments.length<2&&(e=t),1===e)return w;if(e===1/0)return T;function r(r,n){var i=w(r/e,n);return i[0]*=t,i}return r.invert=function(r,n){var i=w.invert(r/t,n);return i[0]*=e,i},r}function T(t,e){return[t*Math.cos(e)/Math.cos(e/=2),2*Math.sin(e)]}function A(t,e){return[3*t/(2*p)*Math.sqrt(p*p/3-e*e),e]}function M(t,e){return[t,1.25*Math.log(Math.tan(p/4+.4*e))]}function S(t){return function(e){var r,n=t*Math.sin(e),i=30;do{e-=r=(e+Math.sin(e)-n)/(1+Math.cos(e))}while(Math.abs(r)>h&&--i>0);return e/2}}T.invert=function(t,e){var r=2*m(e/2);return[t*Math.cos(r/2)/Math.cos(r),r]},(t.geo.hammer=function(){var t=2,e=b(k),r=e(t);return r.coefficient=function(r){return arguments.length?e(t=+r):t},r}).raw=k,A.invert=function(t,e){return[2/3*p*t/Math.sqrt(p*p/3-e*e),e]},(t.geo.kavrayskiy7=function(){return x(A)}).raw=A,M.invert=function(t,e){return[t,2.5*Math.atan(Math.exp(.8*e))-.625*p]},(t.geo.miller=function(){return x(M)}).raw=M,S(p);var E=function(t,e,r){var n=S(r);function i(r,i){return[t*r*Math.cos(i=n(i)),e*Math.sin(i)]}return i.invert=function(n,i){var a=m(i/e);return[n/(t*Math.cos(a)),m((2*a+Math.sin(2*a))/r)]},i}(Math.SQRT2/d,Math.SQRT2,p);function C(t,e){var r=e*e,n=r*r;return[t*(.8707-.131979*r+n*(n*(.003971*r-.001529*n)-.013791)),e*(1.007226+r*(.015085+n*(.028874*r-.044475-.005916*n)))]}(t.geo.mollweide=function(){return x(E)}).raw=E,C.invert=function(t,e){var r,n=e,i=25;do{var a=n*n,o=a*a;n-=r=(n*(1.007226+a*(.015085+o*(.028874*a-.044475-.005916*o)))-e)/(1.007226+a*(.045255+o*(.259866*a-.311325-.005916*11*o)))}while(Math.abs(r)>h&&--i>0);return[t/(.8707+(a=n*n)*(a*(a*a*a*(.003971-.001529*a)-.013791)-.131979)),n]},(t.geo.naturalEarth=function(){return x(C)}).raw=C;var L=[[.9986,-.062],[1,0],[.9986,.062],[.9954,.124],[.99,.186],[.9822,.248],[.973,.31],[.96,.372],[.9427,.434],[.9216,.4958],[.8962,.5571],[.8679,.6176],[.835,.6769],[.7986,.7346],[.7597,.7903],[.7186,.8435],[.6732,.8936],[.6213,.9394],[.5722,.9761],[.5322,1]];function P(t,e){var r,n=Math.min(18,36*Math.abs(e)/p),i=Math.floor(n),a=n-i,o=(r=L[i])[0],s=r[1],l=(r=L[++i])[0],c=r[1],u=(r=L[Math.min(19,++i)])[0],h=r[1];return[t*(l+a*(u-o)/2+a*a*(u-2*l+o)/2),(e>0?d:-d)*(c+a*(h-s)/2+a*a*(h-2*c+s)/2)]}function O(t,e){return[t*Math.cos(e),e]}function z(t,e){var r,n=Math.cos(e),i=(r=y(n*Math.cos(t/=2)))?r/Math.sin(r):1;return[2*n*Math.sin(t)*i,Math.sin(e)*i]}function I(t,e){var r=z(t,e);return[(r[0]+t/d)/2,(r[1]+e)/2]}L.forEach(function(t){t[1]*=1.0144}),P.invert=function(t,e){var r=e/d,n=90*r,i=Math.min(18,Math.abs(n/5)),a=Math.max(0,Math.floor(i));do{var o=L[a][1],s=L[a+1][1],l=L[Math.min(19,a+2)][1],c=l-o,u=l-2*s+o,h=2*(Math.abs(r)-s)/c,p=u/c,m=h*(1-p*h*(1-2*p*h));if(m>=0||1===a){n=(e>=0?5:-5)*(m+i);var y,x=50;do{m=(i=Math.min(18,Math.abs(n)/5))-(a=Math.floor(i)),o=L[a][1],s=L[a+1][1],l=L[Math.min(19,a+2)][1],n-=(y=(e>=0?d:-d)*(s+m*(l-o)/2+m*m*(l-2*s+o)/2)-e)*v}while(Math.abs(y)>f&&--x>0);break}}while(--a>=0);var b=L[a][0],_=L[a+1][0],w=L[Math.min(19,a+2)][0];return[t/(_+m*(w-b)/2+m*m*(w-2*_+b)/2),n*g]},(t.geo.robinson=function(){return x(P)}).raw=P,O.invert=function(t,e){return[t/Math.cos(e),e]},(t.geo.sinusoidal=function(){return x(O)}).raw=O,z.invert=function(t,e){if(!(t*t+4*e*e>p*p+h)){var r=t,n=e,i=25;do{var a,o=Math.sin(r),s=Math.sin(r/2),l=Math.cos(r/2),c=Math.sin(n),u=Math.cos(n),f=Math.sin(2*n),d=c*c,g=u*u,v=s*s,m=1-g*l*l,x=m?y(u*l)*Math.sqrt(a=1/m):a=0,b=2*x*u*s-t,_=x*c-e,w=a*(g*v+x*u*l*d),k=a*(.5*o*f-2*x*c*s),T=.25*a*(f*s-x*c*g*o),A=a*(d*l+x*v*u),M=k*T-A*w;if(!M)break;var S=(_*k-b*A)/M,E=(b*T-_*w)/M;r-=S,n-=E}while((Math.abs(S)>h||Math.abs(E)>h)&&--i>0);return[r,n]}},(t.geo.aitoff=function(){return x(z)}).raw=z,I.invert=function(t,e){var r=t,n=e,i=25;do{var a,o=Math.cos(n),s=Math.sin(n),l=Math.sin(2*n),c=s*s,u=o*o,f=Math.sin(r),p=Math.cos(r/2),g=Math.sin(r/2),v=g*g,m=1-u*p*p,x=m?y(o*p)*Math.sqrt(a=1/m):a=0,b=.5*(2*x*o*g+r/d)-t,_=.5*(x*s+n)-e,w=.5*a*(u*v+x*o*p*c)+.5/d,k=a*(f*l/4-x*s*g),T=.125*a*(l*g-x*s*u*f),A=.5*a*(c*p+x*v*o)+.5,M=k*T-A*w,S=(_*k-b*A)/M,E=(b*T-_*w)/M;r-=S,n-=E}while((Math.abs(S)>h||Math.abs(E)>h)&&--i>0);return[r,n]},(t.geo.winkel3=function(){return x(I)}).raw=I}},{}],801:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=Math.PI/180,s=180/Math.PI,l={cursor:\"pointer\"},c={cursor:\"auto\"};function u(t,e){return n.behavior.zoom().translate(e.translate()).scale(e.scale())}function h(t,e,r){var n=t.id,o=t.graphDiv,s=o.layout,l=s[n],c=o._fullLayout,u=c[n],h={},f={};function p(t,e){h[n+\".\"+t]=i.nestedProperty(l,t).get(),a.call(\"_storeDirectGUIEdit\",s,c._preGUI,h);var r=i.nestedProperty(u,t);r.get()!==e&&(r.set(e),i.nestedProperty(l,t).set(e),f[n+\".\"+t]=e)}r(p),p(\"projection.scale\",e.scale()/t.fitScale),o.emit(\"plotly_relayout\",f)}function f(t,e){var r=u(0,e);function i(r){var n=e.invert(t.midPt);r(\"center.lon\",n[0]),r(\"center.lat\",n[1])}return r.on(\"zoomstart\",function(){n.select(this).style(l)}).on(\"zoom\",function(){e.scale(n.event.scale).translate(n.event.translate),t.render();var r=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":r[0],\"geo.center.lat\":r[1]})}).on(\"zoomend\",function(){n.select(this).style(c),h(t,e,i)}),r}function p(t,e){var r,i,a,o,s,f,p,d,g,v=u(0,e),m=2;function y(t){return e.invert(t)}function x(r){var n=e.rotate(),i=e.invert(t.midPt);r(\"projection.rotation.lon\",-n[0]),r(\"center.lon\",i[0]),r(\"center.lat\",i[1])}return v.on(\"zoomstart\",function(){n.select(this).style(l),r=n.mouse(this),i=e.rotate(),a=e.translate(),o=i,s=y(r)}).on(\"zoom\",function(){if(f=n.mouse(this),function(t){var r=y(t);if(!r)return!0;var n=e(r);return Math.abs(n[0]-t[0])>m||Math.abs(n[1]-t[1])>m}(r))return v.scale(e.scale()),void v.translate(e.translate());e.scale(n.event.scale),e.translate([a[0],n.event.translate[1]]),s?y(f)&&(d=y(f),p=[o[0]+(d[0]-s[0]),i[1],i[2]],e.rotate(p),o=p):s=y(r=f),g=!0,t.render();var l=e.rotate(),c=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":c[0],\"geo.center.lat\":c[1],\"geo.projection.rotation.lon\":-l[0]})}).on(\"zoomend\",function(){n.select(this).style(c),g&&h(t,e,x)}),v}function d(t,e){var r,i={r:e.rotate(),k:e.scale()},a=u(0,e),f=function(t){var e=0,r=arguments.length,i=[];for(;++e<r;)i.push(arguments[e]);var a=n.dispatch.apply(null,i);return a.of=function(e,r){return function(i){var o;try{o=i.sourceEvent=n.event,i.target=t,n.event=i,a[i.type].apply(e,r)}finally{n.event=o}}},a}(a,\"zoomstart\",\"zoom\",\"zoomend\"),p=0,d=a.on;function m(t){var r=e.rotate();t(\"projection.rotation.lon\",-r[0]),t(\"projection.rotation.lat\",-r[1])}return a.on(\"zoomstart\",function(){n.select(this).style(l);var t,c,u,h,m,b,_,w,k,T,A,M=n.mouse(this),S=e.rotate(),E=S,C=e.translate(),L=(c=.5*(t=S)[0]*o,u=.5*t[1]*o,h=.5*t[2]*o,m=Math.sin(c),b=Math.cos(c),_=Math.sin(u),w=Math.cos(u),k=Math.sin(h),T=Math.cos(h),[b*w*T+m*_*k,m*w*T-b*_*k,b*_*T+m*w*k,b*w*k-m*_*T]);r=g(e,M),d.call(a,\"zoom\",function(){var t,a,o,l,c,u,h,p,d,m,b=n.mouse(this);if(e.scale(i.k=n.event.scale),r){if(g(e,b)){e.rotate(S).translate(C);var _=g(e,b),w=function(t,e){if(!t||!e)return;var r=function(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}(t,e),n=Math.sqrt(x(r,r)),i=.5*Math.acos(Math.max(-1,Math.min(1,x(t,e)))),a=Math.sin(i)/n;return n&&[Math.cos(i),r[2]*a,-r[1]*a,r[0]*a]}(r,_),k=function(t){return[Math.atan2(2*(t[0]*t[1]+t[2]*t[3]),1-2*(t[1]*t[1]+t[2]*t[2]))*s,Math.asin(Math.max(-1,Math.min(1,2*(t[0]*t[2]-t[3]*t[1]))))*s,Math.atan2(2*(t[0]*t[3]+t[1]*t[2]),1-2*(t[2]*t[2]+t[3]*t[3]))*s]}((a=w,o=(t=L)[0],l=t[1],c=t[2],u=t[3],h=a[0],p=a[1],d=a[2],m=a[3],[o*h-l*p-c*d-u*m,o*p+l*h+c*m-u*d,o*d-l*m+c*h+u*p,o*m+l*d-c*p+u*h])),T=i.r=function(t,e,r){var n=y(e,2,t[0]);n=y(n,1,t[1]),n=y(n,0,t[2]-r[2]);var i,a,o=e[0],l=e[1],c=e[2],u=n[0],h=n[1],f=n[2],p=Math.atan2(l,o)*s,d=Math.sqrt(o*o+l*l);Math.abs(h)>d?(a=(h>0?90:-90)-p,i=0):(a=Math.asin(h/d)*s-p,i=Math.sqrt(d*d-h*h));var g=180-a-2*p,m=(Math.atan2(f,u)-Math.atan2(c,i))*s,x=(Math.atan2(f,u)-Math.atan2(c,-i))*s,b=v(r[0],r[1],a,m),_=v(r[0],r[1],g,x);return b<=_?[a,m,r[2]]:[g,x,r[2]]}(k,r,E);isFinite(T[0])&&isFinite(T[1])&&isFinite(T[2])||(T=E),e.rotate(T),E=T}}else r=g(e,M=b);f.of(this,arguments)({type:\"zoom\"})}),A=f.of(this,arguments),p++||A({type:\"zoomstart\"})}).on(\"zoomend\",function(){var r;n.select(this).style(c),d.call(a,\"zoom\",null),r=f.of(this,arguments),--p||r({type:\"zoomend\"}),h(t,e,m)}).on(\"zoom.redraw\",function(){t.render();var r=e.rotate();t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.projection.rotation.lon\":-r[0],\"geo.projection.rotation.lat\":-r[1]})}),n.rebind(a,f,\"on\")}function g(t,e){var r=t.invert(e);return r&&isFinite(r[0])&&isFinite(r[1])&&function(t){var e=t[0]*o,r=t[1]*o,n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}(r)}function v(t,e,r,n){var i=m(r-t),a=m(n-e);return Math.sqrt(i*i+a*a)}function m(t){return(t%360+540)%360-180}function y(t,e,r){var n=r*o,i=t.slice(),a=0===e?1:0,s=2===e?1:2,l=Math.cos(n),c=Math.sin(n);return i[a]=t[a]*l-t[s]*c,i[s]=t[s]*l+t[a]*c,i}function x(t,e){for(var r=0,n=0,i=t.length;n<i;++n)r+=t[n]*e[n];return r}e.exports=function(t,e){var r=t.projection;return(e._isScoped?f:e._isClipped?d:p)(t,r)}},{\"../../lib\":719,\"../../registry\":847,d3:163}],802:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"./cartesian/constants\").SUBPLOT_PATTERN;r.getSubplotCalcData=function(t,e,r){var i=n.subplotsRegistry[e];if(!i)return[];for(var a=i.attr,o=[],s=0;s<t.length;s++){var l=t[s];l[0].trace[a]===r&&o.push(l)}return o},r.getModuleCalcData=function(t,e){var r,i=[],a=[];if(!(r=\"string\"==typeof e?n.getModule(e).plot:\"function\"==typeof e?e:e.plot))return[i,t];for(var o=0;o<t.length;o++){var s=t[o],l=s[0].trace;!0===l.visible&&0!==l._length&&(l._module.plot===r?i.push(s):a.push(s))}return[i,a]},r.getSubplotData=function(t,e,r){if(!n.subplotsRegistry[e])return[];var a,o,s,l=n.subplotsRegistry[e].attr,c=[];if(\"gl2d\"===e){var u=r.match(i);o=\"x\"+u[1],s=\"y\"+u[2]}for(var h=0;h<t.length;h++)a=t[h],\"gl2d\"===e&&n.traceIs(a,\"gl2d\")?a[l[0]]===o&&a[l[1]]===s&&c.push(a):a[l]===r&&c.push(a);return c}},{\"../registry\":847,\"./cartesian/constants\":773}],803:[function(t,e,r){\"use strict\";var n=t(\"mouse-change\"),i=t(\"mouse-wheel\"),a=t(\"mouse-event-offset\"),o=t(\"../cartesian/constants\"),s=t(\"has-passive-events\");function l(t,e){this.element=t,this.plot=e,this.mouseListener=null,this.wheelListener=null,this.lastInputTime=Date.now(),this.lastPos=[0,0],this.boxEnabled=!1,this.boxInited=!1,this.boxStart=[0,0],this.boxEnd=[0,0],this.dragStart=[0,0]}e.exports=function(t){var e=t.mouseContainer,r=t.glplot,c=new l(e,r);function u(){t.xaxis.autorange=!1,t.yaxis.autorange=!1}function h(e,n,i){var a,s,l=t.calcDataBox(),h=r.viewBox,f=c.lastPos[0],p=c.lastPos[1],d=o.MINDRAG*r.pixelRatio,g=o.MINZOOM*r.pixelRatio;function v(e,r,n){var i=Math.min(r,n),a=Math.max(r,n);i!==a?(l[e]=i,l[e+2]=a,c.dataBox=l,t.setRanges(l)):(t.selectBox.selectBox=[0,0,1,1],t.glplot.setDirty())}switch(n*=r.pixelRatio,i*=r.pixelRatio,i=h[3]-h[1]-i,t.fullLayout.dragmode){case\"zoom\":if(e){var m=n/(h[2]-h[0])*(l[2]-l[0])+l[0],y=i/(h[3]-h[1])*(l[3]-l[1])+l[1];c.boxInited||(c.boxStart[0]=m,c.boxStart[1]=y,c.dragStart[0]=n,c.dragStart[1]=i),c.boxEnd[0]=m,c.boxEnd[1]=y,c.boxInited=!0,c.boxEnabled||c.boxStart[0]===c.boxEnd[0]&&c.boxStart[1]===c.boxEnd[1]||(c.boxEnabled=!0);var x=Math.abs(c.dragStart[0]-n)<g,b=Math.abs(c.dragStart[1]-i)<g;if(!function(){for(var e=t.graphDiv._fullLayout._axisConstraintGroups,r=t.xaxis._id,n=t.yaxis._id,i=0;i<e.length;i++)if(-1!==e[i][r]){if(-1!==e[i][n])return!0;break}return!1}()||x&&b)x&&(c.boxEnd[0]=c.boxStart[0]),b&&(c.boxEnd[1]=c.boxStart[1]);else{a=c.boxEnd[0]-c.boxStart[0],s=c.boxEnd[1]-c.boxStart[1];var _=(l[3]-l[1])/(l[2]-l[0]);Math.abs(a*_)>Math.abs(s)?(c.boxEnd[1]=c.boxStart[1]+Math.abs(a)*_*(s>=0?1:-1),c.boxEnd[1]<l[1]?(c.boxEnd[1]=l[1],c.boxEnd[0]=c.boxStart[0]+(l[1]-c.boxStart[1])/Math.abs(_)):c.boxEnd[1]>l[3]&&(c.boxEnd[1]=l[3],c.boxEnd[0]=c.boxStart[0]+(l[3]-c.boxStart[1])/Math.abs(_))):(c.boxEnd[0]=c.boxStart[0]+Math.abs(s)/_*(a>=0?1:-1),c.boxEnd[0]<l[0]?(c.boxEnd[0]=l[0],c.boxEnd[1]=c.boxStart[1]+(l[0]-c.boxStart[0])*Math.abs(_)):c.boxEnd[0]>l[2]&&(c.boxEnd[0]=l[2],c.boxEnd[1]=c.boxStart[1]+(l[2]-c.boxStart[0])*Math.abs(_)))}}else c.boxEnabled?(a=c.boxStart[0]!==c.boxEnd[0],s=c.boxStart[1]!==c.boxEnd[1],a||s?(a&&(v(0,c.boxStart[0],c.boxEnd[0]),t.xaxis.autorange=!1),s&&(v(1,c.boxStart[1],c.boxEnd[1]),t.yaxis.autorange=!1),t.relayoutCallback()):t.glplot.setDirty(),c.boxEnabled=!1,c.boxInited=!1):c.boxInited&&(c.boxInited=!1);break;case\"pan\":c.boxEnabled=!1,c.boxInited=!1,e?(c.panning||(c.dragStart[0]=n,c.dragStart[1]=i),Math.abs(c.dragStart[0]-n)<d&&(n=c.dragStart[0]),Math.abs(c.dragStart[1]-i)<d&&(i=c.dragStart[1]),a=(f-n)*(l[2]-l[0])/(r.viewBox[2]-r.viewBox[0]),s=(p-i)*(l[3]-l[1])/(r.viewBox[3]-r.viewBox[1]),l[0]+=a,l[2]+=a,l[1]+=s,l[3]+=s,t.setRanges(l),c.panning=!0,c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations()):c.panning&&(c.panning=!1,t.relayoutCallback())}c.lastPos[0]=n,c.lastPos[1]=i}return c.mouseListener=n(e,h),e.addEventListener(\"touchstart\",function(t){var r=a(t.changedTouches[0],e);h(0,r[0],r[1]),h(1,r[0],r[1]),t.preventDefault()},!!s&&{passive:!1}),e.addEventListener(\"touchmove\",function(t){t.preventDefault();var r=a(t.changedTouches[0],e);h(1,r[0],r[1]),t.preventDefault()},!!s&&{passive:!1}),e.addEventListener(\"touchend\",function(t){h(0,c.lastPos[0],c.lastPos[1]),t.preventDefault()},!!s&&{passive:!1}),c.wheelListener=i(e,function(e,n){if(!t.scrollZoom)return!1;var i=t.calcDataBox(),a=r.viewBox,o=c.lastPos[0],s=c.lastPos[1],l=Math.exp(5*n/(a[3]-a[1])),h=o/(a[2]-a[0])*(i[2]-i[0])+i[0],f=s/(a[3]-a[1])*(i[3]-i[1])+i[1];return i[0]=(i[0]-h)*l+h,i[2]=(i[2]-h)*l+h,i[1]=(i[1]-f)*l+f,i[3]=(i[3]-f)*l+f,t.setRanges(i),c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations(),t.relayoutCallback(),!0},!0),c}},{\"../cartesian/constants\":773,\"has-passive-events\":411,\"mouse-change\":435,\"mouse-event-offset\":436,\"mouse-wheel\":438}],804:[function(t,e,r){\"use strict\";var n=t(\"../cartesian/axes\"),i=t(\"../../lib/str2rgbarray\");function a(t){this.scene=t,this.gl=t.gl,this.pixelRatio=t.pixelRatio,this.screenBox=[0,0,1,1],this.viewBox=[0,0,1,1],this.dataBox=[-1,-1,1,1],this.borderLineEnable=[!1,!1,!1,!1],this.borderLineWidth=[1,1,1,1],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.ticks=[[],[]],this.tickEnable=[!0,!0,!1,!1],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labels=[\"x\",\"y\"],this.labelEnable=[!0,!0,!1,!1],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelPad=[15,15,15,15],this.labelSize=[12,12],this.labelFont=[\"sans-serif\",\"sans-serif\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.title=\"\",this.titleEnable=!0,this.titleCenter=[0,0,0,0],this.titleAngle=0,this.titleColor=[0,0,0,1],this.titleFont=\"sans-serif\",this.titleSize=18,this.gridLineEnable=[!0,!0],this.gridLineColor=[[0,0,0,.5],[0,0,0,.5]],this.gridLineWidth=[1,1],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[1,1],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.static=this.scene.staticPlot}var o=a.prototype,s=[\"xaxis\",\"yaxis\"];o.merge=function(t){var e,r,n,a,o,l,c,u,h,f,p;for(this.titleEnable=!1,this.backgroundColor=i(t.plot_bgcolor),f=0;f<2;++f){var d=(e=s[f]).charAt(0);for(n=(r=t[this.scene[e]._name]).title.text===this.scene.fullLayout._dfltTitle[d]?\"\":r.title.text,p=0;p<=2;p+=2)this.labelEnable[f+p]=!1,this.labels[f+p]=n,this.labelColor[f+p]=i(r.title.font.color),this.labelFont[f+p]=r.title.font.family,this.labelSize[f+p]=r.title.font.size,this.labelPad[f+p]=this.getLabelPad(e,r),this.tickEnable[f+p]=!1,this.tickColor[f+p]=i((r.tickfont||{}).color),this.tickAngle[f+p]=\"auto\"===r.tickangle?0:Math.PI*-r.tickangle/180,this.tickPad[f+p]=this.getTickPad(r),this.tickMarkLength[f+p]=0,this.tickMarkWidth[f+p]=r.tickwidth||0,this.tickMarkColor[f+p]=i(r.tickcolor),this.borderLineEnable[f+p]=!1,this.borderLineColor[f+p]=i(r.linecolor),this.borderLineWidth[f+p]=r.linewidth||0;c=this.hasSharedAxis(r),o=this.hasAxisInDfltPos(e,r)&&!c,l=this.hasAxisInAltrPos(e,r)&&!c,a=r.mirror||!1,u=c?-1!==String(a).indexOf(\"all\"):!!a,h=c?\"allticks\"===a:-1!==String(a).indexOf(\"ticks\"),o?this.labelEnable[f]=!0:l&&(this.labelEnable[f+2]=!0),o?this.tickEnable[f]=r.showticklabels:l&&(this.tickEnable[f+2]=r.showticklabels),(o||u)&&(this.borderLineEnable[f]=r.showline),(l||u)&&(this.borderLineEnable[f+2]=r.showline),(o||h)&&(this.tickMarkLength[f]=this.getTickMarkLength(r)),(l||h)&&(this.tickMarkLength[f+2]=this.getTickMarkLength(r)),this.gridLineEnable[f]=r.showgrid,this.gridLineColor[f]=i(r.gridcolor),this.gridLineWidth[f]=r.gridwidth,this.zeroLineEnable[f]=r.zeroline,this.zeroLineColor[f]=i(r.zerolinecolor),this.zeroLineWidth[f]=r.zerolinewidth}},o.hasSharedAxis=function(t){var e=this.scene,r=e.fullLayout._subplots.gl2d;return 0!==n.findSubplotsWithAxis(r,t).indexOf(e.id)},o.hasAxisInDfltPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"bottom\"===r:\"yaxis\"===t?\"left\"===r:void 0},o.hasAxisInAltrPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"top\"===r:\"yaxis\"===t?\"right\"===r:void 0},o.getLabelPad=function(t,e){var r=e.title.font.size,n=e.showticklabels;return\"xaxis\"===t?\"top\"===e.side?r*(1.5+(n?1:0))-10:r*(1.5+(n?.5:0))-10:\"yaxis\"===t?\"right\"===e.side?10+r*(1.5+(n?1:.5)):10+r*(1.5+(n?.5:0)):void 0},o.getTickPad=function(t){return\"outside\"===t.ticks?10+t.ticklen:15},o.getTickMarkLength=function(t){if(!t.ticks)return 0;var e=t.ticklen;return\"inside\"===t.ticks?-e:e},e.exports=function(t){return new a(t)}},{\"../../lib/str2rgbarray\":742,\"../cartesian/axes\":767}],805:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"./scene2d\"),a=t(\"../layout_attributes\"),o=t(\"../../constants/xmlns_namespaces\"),s=t(\"../cartesian/constants\"),l=t(\"../cartesian\"),c=t(\"../../components/fx/layout_attributes\"),u=t(\"../get_data\").getSubplotData;r.name=\"gl2d\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=s.idRegex,r.attrRegex=s.attrRegex,r.attributes=t(\"../cartesian/attributes\"),r.supplyLayoutDefaults=function(t,e,r){e._has(\"cartesian\")||l.supplyLayoutDefaults(t,e,r)},r.layoutAttrOverrides=n(l.layoutAttributes,\"plot\",\"from-root\"),r.baseLayoutAttrOverrides=n({plot_bgcolor:a.plot_bgcolor,hoverlabel:c.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl2d,a=0;a<n.length;a++){var o=n[a],s=e._plots[o],l=u(r,\"gl2d\",o),c=s._scene2d;void 0===c&&(c=new i({id:o,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio},e),s._scene2d=c),c.plot(l,t.calcdata,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl2d||[],a=0;a<i.length;a++){var o=i[a],s=n._plots[o];if(s._scene2d)0===u(t,\"gl2d\",o).length&&(s._scene2d.destroy(),delete n._plots[o])}l.clean.apply(this,arguments)},r.drawFramework=function(t){t._context.staticPlot||l.drawFramework(t)},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){var i=e._plots[r[n]]._scene2d,a=i.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":a,x:0,y:0,width:\"100%\",height:\"100%\",preserveAspectRatio:\"none\"}),i.destroy()}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){e._plots[r[n]]._scene2d.updateFx(e.dragmode)}}},{\"../../components/fx/layout_attributes\":633,\"../../constants/xmlns_namespaces\":696,\"../../plot_api/edit_types\":750,\"../cartesian\":778,\"../cartesian/attributes\":765,\"../cartesian/constants\":773,\"../get_data\":802,\"../layout_attributes\":819,\"./scene2d\":806}],806:[function(t,e,r){\"use strict\";var n,i,a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../../components/fx\"),l=t(\"gl-plot2d\"),c=t(\"gl-spikes2d\"),u=t(\"gl-select-box\"),h=t(\"webgl-context\"),f=t(\"./convert\"),p=t(\"./camera\"),d=t(\"../../lib/show_no_webgl_msg\"),g=t(\"../cartesian/constraints\"),v=g.enforce,m=g.clean,y=t(\"../cartesian/autorange\").doAutoRange,x=[\"xaxis\",\"yaxis\"],b=t(\"../cartesian/constants\").SUBPLOT_PATTERN;function _(t,e){this.container=t.container,this.graphDiv=t.graphDiv,this.pixelRatio=t.plotGlPixelRatio||window.devicePixelRatio,this.id=t.id,this.staticPlot=!!t.staticPlot,this.scrollZoom=this.graphDiv._context._scrollZoom.cartesian,this.fullData=null,this.updateRefs(e),this.makeFramework(),this.stopped||(this.glplotOptions=f(this),this.glplotOptions.merge(e),this.glplot=l(this.glplotOptions),this.camera=p(this),this.traces={},this.spikes=c(this.glplot),this.selectBox=u(this.glplot,{innerFill:!1,outerFill:!0}),this.lastButtonState=0,this.pickResult=null,this.isMouseOver=!0,this.stopped=!1,this.redraw=this.draw.bind(this),this.redraw())}e.exports=_;var w=_.prototype;w.makeFramework=function(){if(this.staticPlot){if(!(i||(n=document.createElement(\"canvas\"),i=h({canvas:n,preserveDrawingBuffer:!1,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"Error creating static canvas/context for image server\");this.canvas=n,this.gl=i}else{var t=this.container.querySelector(\".gl-canvas-focus\"),e=h({canvas:t,preserveDrawingBuffer:!0,premultipliedAlpha:!0});if(!e)return d(this),void(this.stopped=!0);this.canvas=t,this.gl=e}var r=this.canvas;r.style.width=\"100%\",r.style.height=\"100%\",r.style.position=\"absolute\",r.style.top=\"0px\",r.style.left=\"0px\",r.style[\"pointer-events\"]=\"none\",this.updateSize(r),r.className+=\" user-select-none\";var a=this.svgContainer=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");a.style.position=\"absolute\",a.style.top=a.style.left=\"0px\",a.style.width=a.style.height=\"100%\",a.style[\"z-index\"]=20,a.style[\"pointer-events\"]=\"none\";var o=this.mouseContainer=document.createElement(\"div\");o.style.position=\"absolute\",o.style[\"pointer-events\"]=\"auto\",this.pickCanvas=this.container.querySelector(\".gl-canvas-pick\");var s=this.container;s.appendChild(a),s.appendChild(o);var l=this;o.addEventListener(\"mouseout\",function(){l.isMouseOver=!1,l.unhover()}),o.addEventListener(\"mouseover\",function(){l.isMouseOver=!0})},w.toImage=function(t){t||(t=\"png\"),this.stopped=!0,this.staticPlot&&this.container.appendChild(n),this.updateSize(this.canvas);var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.clearColor(1,1,1,0),e.clear(e.COLOR_BUFFER_BIT|e.DEPTH_BUFFER_BIT),this.glplot.setDirty(),this.glplot.draw(),e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a);for(var o=0,s=i-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=a[4*(r*o+l)+c];a[4*(r*o+l)+c]=a[4*(r*s+l)+c],a[4*(r*s+l)+c]=u}var h=document.createElement(\"canvas\");h.width=r,h.height=i;var f,p=h.getContext(\"2d\"),d=p.createImageData(r,i);switch(d.data.set(a),p.putImageData(d,0,0),t){case\"jpeg\":f=h.toDataURL(\"image/jpeg\");break;case\"webp\":f=h.toDataURL(\"image/webp\");break;default:f=h.toDataURL(\"image/png\")}return this.staticPlot&&this.container.removeChild(n),f},w.updateSize=function(t){t||(t=this.canvas);var e=this.pixelRatio,r=this.fullLayout,n=r.width,i=r.height,a=0|Math.ceil(e*n),o=0|Math.ceil(e*i);return t.width===a&&t.height===o||(t.width=a,t.height=o),t},w.computeTickMarks=function(){this.xaxis.setScale(),this.yaxis.setScale();for(var t=[o.calcTicks(this.xaxis),o.calcTicks(this.yaxis)],e=0;e<2;++e)for(var r=0;r<t[e].length;++r)t[e][r].text=t[e][r].text+\"\";return t},w.updateRefs=function(t){this.fullLayout=t;var e=this.id.match(b),r=\"xaxis\"+e[1],n=\"yaxis\"+e[2];this.xaxis=this.fullLayout[r],this.yaxis=this.fullLayout[n]},w.relayoutCallback=function(){var t=this.graphDiv,e=this.xaxis,r=this.yaxis,n=t.layout,i={},o=i[e._name+\".range\"]=e.range.slice(),s=i[r._name+\".range\"]=r.range.slice();i[e._name+\".autorange\"]=e.autorange,i[r._name+\".autorange\"]=r.autorange,a.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,i);var l=n[e._name];l.range=o,l.autorange=e.autorange;var c=n[r._name];c.range=s,c.autorange=r.autorange,i.lastInputTime=this.camera.lastInputTime,t.emit(\"plotly_relayout\",i)},w.cameraChanged=function(){var t=this.camera;this.glplot.setDataBox(this.calcDataBox());var e=this.computeTickMarks();(function(t,e){for(var r=0;r<2;++r){var n=t[r],i=e[r];if(n.length!==i.length)return!0;for(var a=0;a<n.length;++a)if(n[a].x!==i[a].x)return!0}return!1})(e,this.glplotOptions.ticks)&&(this.glplotOptions.ticks=e,this.glplotOptions.dataBox=t.dataBox,this.glplot.update(this.glplotOptions),this.handleAnnotations())},w.handleAnnotations=function(){for(var t=this.graphDiv,e=this.fullLayout.annotations,r=0;r<e.length;r++){var n=e[r];n.xref===this.xaxis._id&&n.yref===this.yaxis._id&&a.getComponentMethod(\"annotations\",\"drawOne\")(t,r)}},w.destroy=function(){if(this.glplot){var t=this.traces;t&&Object.keys(t).map(function(e){t[e].dispose(),delete t[e]}),this.glplot.dispose(),this.container.removeChild(this.svgContainer),this.container.removeChild(this.mouseContainer),this.fullData=null,this.glplot=null,this.stopped=!0,this.camera.mouseListener.enabled=!1,this.mouseContainer.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=null}},w.plot=function(t,e,r){var n=this.glplot;this.updateRefs(r),this.xaxis.clearCalc(),this.yaxis.clearCalc(),this.updateTraces(t,e),this.updateFx(r.dragmode);var i=r.width,a=r.height;this.updateSize(this.canvas);var o=this.glplotOptions;o.merge(r),o.screenBox=[0,0,i,a];var s={_fullLayout:{_axisConstraintGroups:this.graphDiv._fullLayout._axisConstraintGroups,xaxis:this.xaxis,yaxis:this.yaxis}};m(s,this.xaxis),m(s,this.yaxis);var l,c,u=r._size,h=this.xaxis.domain,f=this.yaxis.domain;for(o.viewBox=[u.l+h[0]*u.w,u.b+f[0]*u.h,i-u.r-(1-h[1])*u.w,a-u.t-(1-f[1])*u.h],this.mouseContainer.style.width=u.w*(h[1]-h[0])+\"px\",this.mouseContainer.style.height=u.h*(f[1]-f[0])+\"px\",this.mouseContainer.height=u.h*(f[1]-f[0]),this.mouseContainer.style.left=u.l+h[0]*u.w+\"px\",this.mouseContainer.style.top=u.t+(1-f[1])*u.h+\"px\",c=0;c<2;++c)(l=this[x[c]])._length=o.viewBox[c+2]-o.viewBox[c],y(this.graphDiv,l),l.setScale();v(s),o.ticks=this.computeTickMarks(),o.dataBox=this.calcDataBox(),o.merge(r),n.update(o),this.glplot.draw()},w.calcDataBox=function(){var t=this.xaxis,e=this.yaxis,r=t.range,n=e.range,i=t.r2l,a=e.r2l;return[i(r[0]),a(n[0]),i(r[1]),a(n[1])]},w.setRanges=function(t){var e=this.xaxis,r=this.yaxis,n=e.l2r,i=r.l2r;e.range=[n(t[0]),n(t[2])],r.range=[i(t[1]),i(t[3])]},w.updateTraces=function(t,e){var r,n,i,a=Object.keys(this.traces);this.fullData=t;t:for(r=0;r<a.length;r++){var o=a[r],s=this.traces[o];for(n=0;n<t.length;n++)if((i=t[n]).uid===o&&i.type===s.type)continue t;s.dispose(),delete this.traces[o]}for(r=0;r<t.length;r++){i=t[r];var l=e[r],c=this.traces[i.uid];c?c.update(i,l):(c=i._module.plot(this,i,l),this.traces[i.uid]=c)}this.glplot.objects.sort(function(t,e){return t._trace.index-e._trace.index})},w.updateFx=function(t){\"lasso\"===t||\"select\"===t?(this.pickCanvas.style[\"pointer-events\"]=\"none\",this.mouseContainer.style[\"pointer-events\"]=\"none\"):(this.pickCanvas.style[\"pointer-events\"]=\"auto\",this.mouseContainer.style[\"pointer-events\"]=\"auto\"),this.mouseContainer.style.cursor=\"pan\"===t?\"move\":\"zoom\"===t?\"crosshair\":null},w.emitPointAction=function(t,e){for(var r,n=t.trace.uid,i=t.pointIndex,a=0;a<this.fullData.length;a++)this.fullData[a].uid===n&&(r=this.fullData[a]);var o={x:t.traceCoord[0],y:t.traceCoord[1],curveNumber:r.index,pointNumber:i,data:r._input,fullData:this.fullData,xaxis:this.xaxis,yaxis:this.yaxis};s.appendArrayPointValue(o,r,i),this.graphDiv.emit(e,{points:[o]})},w.draw=function(){if(!this.stopped){requestAnimationFrame(this.redraw);var t=this.glplot,e=this.camera,r=e.mouseListener,n=1===this.lastButtonState&&0===r.buttons,i=this.fullLayout;this.lastButtonState=r.buttons,this.cameraChanged();var a,o=r.x*t.pixelRatio,l=this.canvas.height-t.pixelRatio*r.y;if(e.boxEnabled&&\"zoom\"===i.dragmode){this.selectBox.enabled=!0;for(var c=this.selectBox.selectBox=[Math.min(e.boxStart[0],e.boxEnd[0]),Math.min(e.boxStart[1],e.boxEnd[1]),Math.max(e.boxStart[0],e.boxEnd[0]),Math.max(e.boxStart[1],e.boxEnd[1])],u=0;u<2;u++)e.boxStart[u]===e.boxEnd[u]&&(c[u]=t.dataBox[u],c[u+2]=t.dataBox[u+2]);t.setDirty()}else if(!e.panning&&this.isMouseOver){this.selectBox.enabled=!1;var h=i._size,f=this.xaxis.domain,p=this.yaxis.domain,d=(a=t.pick(o/t.pixelRatio+h.l+f[0]*h.w,l/t.pixelRatio-(h.t+(1-p[1])*h.h)))&&a.object._trace.handlePick(a);if(d&&n&&this.emitPointAction(d,\"plotly_click\"),a&&\"skip\"!==a.object._trace.hoverinfo&&i.hovermode&&d&&(!this.lastPickResult||this.lastPickResult.traceUid!==d.trace.uid||this.lastPickResult.dataCoord[0]!==d.dataCoord[0]||this.lastPickResult.dataCoord[1]!==d.dataCoord[1])){var g=d;this.lastPickResult={traceUid:d.trace?d.trace.uid:null,dataCoord:d.dataCoord.slice()},this.spikes.update({center:a.dataCoord}),g.screenCoord=[((t.viewBox[2]-t.viewBox[0])*(a.dataCoord[0]-t.dataBox[0])/(t.dataBox[2]-t.dataBox[0])+t.viewBox[0])/t.pixelRatio,(this.canvas.height-(t.viewBox[3]-t.viewBox[1])*(a.dataCoord[1]-t.dataBox[1])/(t.dataBox[3]-t.dataBox[1])-t.viewBox[1])/t.pixelRatio],this.emitPointAction(d,\"plotly_hover\");var v=this.fullData[g.trace.index]||{},m=g.pointIndex,y=s.castHoverinfo(v,i,m);if(y&&\"all\"!==y){var x=y.split(\"+\");-1===x.indexOf(\"x\")&&(g.traceCoord[0]=void 0),-1===x.indexOf(\"y\")&&(g.traceCoord[1]=void 0),-1===x.indexOf(\"z\")&&(g.traceCoord[2]=void 0),-1===x.indexOf(\"text\")&&(g.textLabel=void 0),-1===x.indexOf(\"name\")&&(g.name=void 0)}s.loneHover({x:g.screenCoord[0],y:g.screenCoord[1],xLabel:this.hoverFormatter(\"xaxis\",g.traceCoord[0]),yLabel:this.hoverFormatter(\"yaxis\",g.traceCoord[1]),zLabel:g.traceCoord[2],text:g.textLabel,name:g.name,color:s.castHoverOption(v,m,\"bgcolor\")||g.color,borderColor:s.castHoverOption(v,m,\"bordercolor\"),fontFamily:s.castHoverOption(v,m,\"font.family\"),fontSize:s.castHoverOption(v,m,\"font.size\"),fontColor:s.castHoverOption(v,m,\"font.color\"),nameLength:s.castHoverOption(v,m,\"namelength\"),textAlign:s.castHoverOption(v,m,\"align\")},{container:this.svgContainer,gd:this.graphDiv})}}a||this.unhover(),t.draw()}},w.unhover=function(){this.lastPickResult&&(this.spikes.update({}),this.lastPickResult=null,this.graphDiv.emit(\"plotly_unhover\"),s.loneUnhover(this.svgContainer))},w.hoverFormatter=function(t,e){if(void 0!==e){var r=this[t];return o.tickText(r,r.c2l(e),\"hover\").text}}},{\"../../components/fx\":632,\"../../lib/show_no_webgl_msg\":740,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../cartesian/autorange\":766,\"../cartesian/constants\":773,\"../cartesian/constraints\":774,\"./camera\":803,\"./convert\":804,\"gl-plot2d\":287,\"gl-select-box\":299,\"gl-spikes2d\":308,\"webgl-context\":556}],807:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../components/fx/layout_attributes\"),a=t(\"./scene\"),o=t(\"../get_data\").getSubplotData,s=t(\"../../lib\"),l=t(\"../../constants/xmlns_namespaces\");r.name=\"gl3d\",r.attr=\"scene\",r.idRoot=\"scene\",r.idRegex=r.attrRegex=s.counterRegex(\"scene\"),r.attributes=t(\"./layout/attributes\"),r.layoutAttributes=t(\"./layout/layout_attributes\"),r.baseLayoutAttrOverrides=n({hoverlabel:i.hoverlabel},\"plot\",\"nested\"),r.supplyLayoutDefaults=t(\"./layout/defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl3d,i=0;i<n.length;i++){var s=n[i],l=o(r,\"gl3d\",s),c=e[s],u=c.camera,h=c._scene;h||(h=new a({id:s,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio,camera:u},e),c._scene=h),h.viewInitial||(h.viewInitial={up:{x:u.up.x,y:u.up.y,z:u.up.z},eye:{x:u.eye.x,y:u.eye.y,z:u.eye.z},center:{x:u.center.x,y:u.center.y,z:u.center.z}}),h.plot(l,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl3d||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._scene&&(n[o]._scene.destroy(),n._infolayer&&n._infolayer.selectAll(\".annotation-\"+o).remove())}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=e._size,i=0;i<r.length;i++){var a=e[r[i]],o=a.domain,s=a._scene,c=s.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:l.svg,\"xlink:href\":c,x:n.l+n.w*o.x[0],y:n.t+n.h*(1-o.y[1]),width:n.w*(o.x[1]-o.x[0]),height:n.h*(o.y[1]-o.y[0]),preserveAspectRatio:\"none\"}),s.destroy()}},r.cleanId=function(t){if(t.match(/^scene[0-9]*$/)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),\"scene\"+e}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){e[r[n]]._scene.updateFx(e.dragmode,e.hovermode)}}},{\"../../components/fx/layout_attributes\":633,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../plot_api/edit_types\":750,\"../get_data\":802,\"./layout/attributes\":808,\"./layout/defaults\":812,\"./layout/layout_attributes\":813,\"./scene\":817}],808:[function(t,e,r){\"use strict\";e.exports={scene:{valType:\"subplotid\",dflt:\"scene\",editType:\"calc+clearAxisTypes\"}}},{}],809:[function(t,e,r){\"use strict\";var n=t(\"../../../components/color\"),i=t(\"../../cartesian/layout_attributes\"),a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../plot_api/edit_types\").overrideAll;e.exports=o({visible:i.visible,showspikes:{valType:\"boolean\",dflt:!0},spikesides:{valType:\"boolean\",dflt:!0},spikethickness:{valType:\"number\",min:0,dflt:2},spikecolor:{valType:\"color\",dflt:n.defaultLine},showbackground:{valType:\"boolean\",dflt:!1},backgroundcolor:{valType:\"color\",dflt:\"rgba(204, 204, 204, 0.5)\"},showaxeslabels:{valType:\"boolean\",dflt:!0},color:i.color,categoryorder:i.categoryorder,categoryarray:i.categoryarray,title:i.title,type:a({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autorange:i.autorange,rangemode:i.rangemode,range:a({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],anim:!1}),tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,mirror:i.mirror,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,tickfont:i.tickfont,tickangle:i.tickangle,tickprefix:i.tickprefix,showtickprefix:i.showtickprefix,ticksuffix:i.ticksuffix,showticksuffix:i.showticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,separatethousands:i.separatethousands,tickformat:i.tickformat,tickformatstops:i.tickformatstops,hoverformat:i.hoverformat,showline:i.showline,linecolor:i.linecolor,linewidth:i.linewidth,showgrid:i.showgrid,gridcolor:a({},i.gridcolor,{dflt:\"rgb(204, 204, 204)\"}),gridwidth:i.gridwidth,zeroline:i.zeroline,zerolinecolor:i.zerolinecolor,zerolinewidth:i.zerolinewidth,_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}},\"plot\",\"from-root\")},{\"../../../components/color\":593,\"../../../lib/extend\":710,\"../../../plot_api/edit_types\":750,\"../../cartesian/layout_attributes\":779}],810:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../../lib\"),a=t(\"../../../plot_api/plot_template\"),o=t(\"./axis_attributes\"),s=t(\"../../cartesian/type_defaults\"),l=t(\"../../cartesian/axis_defaults\"),c=[\"xaxis\",\"yaxis\",\"zaxis\"];e.exports=function(t,e,r){var u,h;function f(t,e){return i.coerce(u,h,o,t,e)}for(var p=0;p<c.length;p++){var d=c[p];u=t[d]||{},(h=a.newContainer(e,d))._id=d[0]+r.scene,h._name=d,s(u,h,f,r),l(u,h,f,{font:r.font,letter:d[0],data:r.data,showGrid:!0,noTickson:!0,bgColor:r.bgColor,calendar:r.calendar},r.fullLayout),f(\"gridcolor\",n(h.color,r.bgColor,13600/187).toRgbString()),f(\"title.text\",d[0]),h.setScale=i.noop,f(\"showspikes\")&&(f(\"spikesides\"),f(\"spikethickness\"),f(\"spikecolor\",h.color)),f(\"showaxeslabels\"),f(\"showbackground\")&&f(\"backgroundcolor\")}}},{\"../../../lib\":719,\"../../../plot_api/plot_template\":757,\"../../cartesian/axis_defaults\":769,\"../../cartesian/type_defaults\":790,\"./axis_attributes\":809,tinycolor2:537}],811:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"];function o(){this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[18,18,18],this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=[\"Open Sans\",\"Open Sans\",\"Open Sans\"],this.labelSize=[20,20,20],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[30,30,30],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[10,10,10],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!0,!0,!0],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._defaultTickPad=this.tickPad.slice(),this._defaultLabelPad=this.labelPad.slice(),this._defaultLineTickLength=this.lineTickLength.slice()}o.prototype.merge=function(t,e){for(var r=0;r<3;++r){var o=e[a[r]];o.visible?(this.labels[r]=t._meta?i.templateString(o.title.text,t._meta):o.title.text,\"font\"in o.title&&(o.title.font.color&&(this.labelColor[r]=n(o.title.font.color)),o.title.font.family&&(this.labelFont[r]=o.title.font.family),o.title.font.size&&(this.labelSize[r]=o.title.font.size)),\"showline\"in o&&(this.lineEnable[r]=o.showline),\"linecolor\"in o&&(this.lineColor[r]=n(o.linecolor)),\"linewidth\"in o&&(this.lineWidth[r]=o.linewidth),\"showgrid\"in o&&(this.gridEnable[r]=o.showgrid),\"gridcolor\"in o&&(this.gridColor[r]=n(o.gridcolor)),\"gridwidth\"in o&&(this.gridWidth[r]=o.gridwidth),\"log\"===o.type?this.zeroEnable[r]=!1:\"zeroline\"in o&&(this.zeroEnable[r]=o.zeroline),\"zerolinecolor\"in o&&(this.zeroLineColor[r]=n(o.zerolinecolor)),\"zerolinewidth\"in o&&(this.zeroLineWidth[r]=o.zerolinewidth),\"ticks\"in o&&o.ticks?this.lineTickEnable[r]=!0:this.lineTickEnable[r]=!1,\"ticklen\"in o&&(this.lineTickLength[r]=this._defaultLineTickLength[r]=o.ticklen),\"tickcolor\"in o&&(this.lineTickColor[r]=n(o.tickcolor)),\"tickwidth\"in o&&(this.lineTickWidth[r]=o.tickwidth),\"tickangle\"in o&&(this.tickAngle[r]=\"auto\"===o.tickangle?-3600:Math.PI*-o.tickangle/180),\"showticklabels\"in o&&(this.tickEnable[r]=o.showticklabels),\"tickfont\"in o&&(o.tickfont.color&&(this.tickColor[r]=n(o.tickfont.color)),o.tickfont.family&&(this.tickFont[r]=o.tickfont.family),o.tickfont.size&&(this.tickSize[r]=o.tickfont.size)),\"mirror\"in o?-1!==[\"ticks\",\"all\",\"allticks\"].indexOf(o.mirror)?(this.lineTickMirror[r]=!0,this.lineMirror[r]=!0):!0===o.mirror?(this.lineTickMirror[r]=!1,this.lineMirror[r]=!0):(this.lineTickMirror[r]=!1,this.lineMirror[r]=!1):this.lineMirror[r]=!1,\"showbackground\"in o&&!1!==o.showbackground?(this.backgroundEnable[r]=!0,this.backgroundColor[r]=n(o.backgroundcolor)):this.backgroundEnable[r]=!1):(this.tickEnable[r]=!1,this.labelEnable[r]=!1,this.lineEnable[r]=!1,this.lineTickEnable[r]=!1,this.gridEnable[r]=!1,this.zeroEnable[r]=!1,this.backgroundEnable[r]=!1)}},e.exports=function(t,e){var r=new o;return r.merge(t,e),r}},{\"../../../lib\":719,\"../../../lib/str2rgbarray\":742}],812:[function(t,e,r){\"use strict\";var n=t(\"../../../lib\"),i=t(\"../../../components/color\"),a=t(\"../../../registry\"),o=t(\"../../subplot_defaults\"),s=t(\"./axis_defaults\"),l=t(\"./layout_attributes\"),c=t(\"../../get_data\").getSubplotData,u=\"gl3d\";function h(t,e,r,n){for(var o=r(\"bgcolor\"),l=i.combine(o,n.paper_bgcolor),h=[\"up\",\"center\",\"eye\"],f=0;f<h.length;f++)r(\"camera.\"+h[f]+\".x\"),r(\"camera.\"+h[f]+\".y\"),r(\"camera.\"+h[f]+\".z\");r(\"camera.projection.type\");var p=!!r(\"aspectratio.x\")&&!!r(\"aspectratio.y\")&&!!r(\"aspectratio.z\"),d=r(\"aspectmode\",p?\"manual\":\"auto\");p||(t.aspectratio=e.aspectratio={x:1,y:1,z:1},\"manual\"===d&&(e.aspectmode=\"auto\"),t.aspectmode=e.aspectmode);var g=c(n.fullData,u,n.id);s(t,e,{font:n.font,scene:n.id,data:g,bgColor:l,calendar:n.calendar,fullLayout:n.fullLayout}),a.getComponentMethod(\"annotations3d\",\"handleDefaults\")(t,e,n);var v=n.getDfltFromLayout(\"dragmode\");if(!1!==v&&!v)if(v=\"orbit\",t.camera&&t.camera.up){var m=t.camera.up.x,y=t.camera.up.y,x=t.camera.up.z;0!==x&&(m&&y&&x?x/Math.sqrt(m*m+y*y+x*x)>.999&&(v=\"turntable\"):v=\"turntable\")}else v=\"turntable\";r(\"dragmode\",v),r(\"hovermode\",n.getDfltFromLayout(\"hovermode\"))}e.exports=function(t,e,r){var i=e._basePlotModules.length>1;o(t,e,r,{type:u,attributes:l,handleDefaults:h,fullLayout:e,font:e.font,fullData:r,getDfltFromLayout:function(e){if(!i)return n.validate(t[e],l[e])?t[e]:void 0},paper_bgcolor:e.paper_bgcolor,calendar:e.calendar})}},{\"../../../components/color\":593,\"../../../lib\":719,\"../../../registry\":847,\"../../get_data\":802,\"../../subplot_defaults\":842,\"./axis_defaults\":810,\"./layout_attributes\":813}],813:[function(t,e,r){\"use strict\";var n=t(\"./axis_attributes\"),i=t(\"../../domain\").attributes,a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../lib\").counterRegex;function s(t,e,r){return{x:{valType:\"number\",dflt:t,editType:\"camera\"},y:{valType:\"number\",dflt:e,editType:\"camera\"},z:{valType:\"number\",dflt:r,editType:\"camera\"},editType:\"camera\"}}e.exports={_arrayAttrRegexps:[o(\"scene\",\".annotations\",!0)],bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"plot\"},camera:{up:a(s(0,0,1),{}),center:a(s(0,0,0),{}),eye:a(s(1.25,1.25,1.25),{}),projection:{type:{valType:\"enumerated\",values:[\"perspective\",\"orthographic\"],dflt:\"perspective\",editType:\"calc\"},editType:\"calc\"},editType:\"camera\"},domain:i({name:\"scene\",editType:\"plot\"}),aspectmode:{valType:\"enumerated\",values:[\"auto\",\"cube\",\"data\",\"manual\"],dflt:\"auto\",editType:\"plot\",impliedEdits:{\"aspectratio.x\":void 0,\"aspectratio.y\":void 0,\"aspectratio.z\":void 0}},aspectratio:{x:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},y:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},z:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},editType:\"plot\",impliedEdits:{aspectmode:\"manual\"}},xaxis:n,yaxis:n,zaxis:n,dragmode:{valType:\"enumerated\",values:[\"orbit\",\"turntable\",\"zoom\",\"pan\",!1],editType:\"plot\"},hovermode:{valType:\"enumerated\",values:[\"closest\",!1],dflt:\"closest\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"plot\",_deprecated:{cameraposition:{valType:\"info_array\",editType:\"camera\"}}}},{\"../../../lib\":719,\"../../../lib/extend\":710,\"../../domain\":792,\"./axis_attributes\":809}],814:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=[\"xaxis\",\"yaxis\",\"zaxis\"];function a(){this.enabled=[!0,!0,!0],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.drawSides=[!0,!0,!0],this.lineWidth=[1,1,1]}a.prototype.merge=function(t){for(var e=0;e<3;++e){var r=t[i[e]];r.visible?(this.enabled[e]=r.showspikes,this.colors[e]=n(r.spikecolor),this.drawSides[e]=r.spikesides,this.lineWidth[e]=r.spikethickness):(this.enabled[e]=!1,this.drawSides[e]=!1)}},e.exports=function(t){var e=new a;return e.merge(t),e}},{\"../../../lib/str2rgbarray\":742}],815:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.axesOptions,r=t.glplot.axesPixels,s=t.fullSceneLayout,l=[[],[],[]],c=0;c<3;++c){var u=s[a[c]];if(u._length=(r[c].hi-r[c].lo)*r[c].pixelsPerDataUnit/t.dataScale[c],Math.abs(u._length)===1/0||isNaN(u._length))l[c]=[];else{u._input_range=u.range.slice(),u.range[0]=r[c].lo/t.dataScale[c],u.range[1]=r[c].hi/t.dataScale[c],u._m=1/(t.dataScale[c]*r[c].pixelsPerDataUnit),u.range[0]===u.range[1]&&(u.range[0]-=1,u.range[1]+=1);var h=u.tickmode;if(\"auto\"===u.tickmode){u.tickmode=\"linear\";var f=u.nticks||i.constrain(u._length/40,4,9);n.autoTicks(u,Math.abs(u.range[1]-u.range[0])/f)}for(var p=n.calcTicks(u),d=0;d<p.length;++d)p[d].x=p[d].x*t.dataScale[c],\"date\"===u.type&&(p[d].text=p[d].text.replace(/\\<br\\>/g,\" \"));l[c]=p,u.tickmode=h}}e.ticks=l;for(var c=0;c<3;++c){o[c]=.5*(t.glplot.bounds[0][c]+t.glplot.bounds[1][c]);for(var d=0;d<2;++d)e.bounds[d][c]=t.glplot.bounds[d][c]}t.contourLevels=function(t){for(var e=new Array(3),r=0;r<3;++r){for(var n=t[r],i=new Array(n.length),a=0;a<n.length;++a)i[a]=n[a].x;e[r]=i}return e}(l)};var n=t(\"../../cartesian/axes\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"],o=[0,0,0]},{\"../../../lib\":719,\"../../cartesian/axes\":767}],816:[function(t,e,r){\"use strict\";function n(t,e){var r,n,i=[0,0,0,0];for(r=0;r<4;++r)for(n=0;n<4;++n)i[n]+=t[4*r+n]*e[r];return i}e.exports=function(t,e){return n(t.projection,n(t.view,n(t.model,[e[0],e[1],e[2],1])))}},{}],817:[function(t,e,r){\"use strict\";var n,i,a=t(\"gl-plot3d\").createCamera,o=t(\"gl-plot3d\").createScene,s=t(\"webgl-context\"),l=t(\"has-passive-events\"),c=t(\"../../registry\"),u=t(\"../../lib\"),h=t(\"../../plots/cartesian/axes\"),f=t(\"../../components/fx\"),p=t(\"../../lib/str2rgbarray\"),d=t(\"../../lib/show_no_webgl_msg\"),g=t(\"./project\"),v=t(\"./layout/convert\"),m=t(\"./layout/spikes\"),y=t(\"./layout/tick_marks\");function x(t,e,r,a){if(t.initializeGLCamera(),!function(t,e,r,a,l){var c={canvas:a,gl:l,container:t.container,axes:t.axesOptions,spikes:t.spikeOptions,pickRadius:10,snapToData:!0,autoScale:!0,autoBounds:!1,cameraObject:e,pixelRatio:r};if(t.staticMode){if(!(i||(n=document.createElement(\"canvas\"),i=s({canvas:n,preserveDrawingBuffer:!0,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"error creating static canvas/context for image server\");c.pixelRatio=t.pixelRatio,c.gl=i,c.canvas=n}try{t.glplot=o(c)}catch(t){return!1}return!0}(t,t.camera,e,r,a))return d(t);var c=t.graphDiv,p=function(t){if(!1!==t.fullSceneLayout.dragmode){var e={};e[t.id+\".camera\"]=T(t.camera),t.saveCamera(c.layout),t.graphDiv.emit(\"plotly_relayout\",e)}};return t.glplot.canvas.addEventListener(\"mouseup\",function(){p(t)}),t.glplot.canvas.addEventListener(\"wheel\",function(){c._context._scrollZoom.gl3d&&p(t)},!!l&&{passive:!1}),t.glplot.canvas.addEventListener(\"mousemove\",function(){if(!1!==t.fullSceneLayout.dragmode&&0!==t.camera.mouseListener.buttons){var e={};e[t.id+\".camera\"]=T(t.camera),t.graphDiv.emit(\"plotly_relayouting\",e)}}),t.staticMode||t.glplot.canvas.addEventListener(\"webglcontextlost\",function(e){c&&c.emit&&c.emit(\"plotly_webglcontextlost\",{event:e,layer:t.id})},!1),t.glplot.camera=t.camera,t.glplot.oncontextloss=function(){t.recoverContext()},t.glplot.onrender=function(t){var e,r=t.graphDiv,n=t.svgContainer,i=t.container.getBoundingClientRect(),a=i.width,o=i.height;n.setAttributeNS(null,\"viewBox\",\"0 0 \"+a+\" \"+o),n.setAttributeNS(null,\"width\",a),n.setAttributeNS(null,\"height\",o),y(t),t.glplot.axes.update(t.axesOptions);for(var s,l=Object.keys(t.traces),c=null,p=t.glplot.selection,d=0;d<l.length;++d)\"skip\"!==(e=t.traces[l[d]]).data.hoverinfo&&e.handlePick(p)&&(c=e),e.setContourLevels&&e.setContourLevels();function v(e,r){var n=t.fullSceneLayout[e];return h.tickText(n,n.d2l(r),\"hover\").text}if(null!==c){var m=g(t.glplot.cameraParams,p.dataCoordinate);e=c.data;var x,b=r._fullData[e.index],_=p.index,w={xLabel:v(\"xaxis\",p.traceCoordinate[0]),yLabel:v(\"yaxis\",p.traceCoordinate[1]),zLabel:v(\"zaxis\",p.traceCoordinate[2])},k=f.castHoverinfo(b,t.fullLayout,_),T=(k||\"\").split(\"+\"),A=k&&\"all\"===k;b.hovertemplate||A||(-1===T.indexOf(\"x\")&&(w.xLabel=void 0),-1===T.indexOf(\"y\")&&(w.yLabel=void 0),-1===T.indexOf(\"z\")&&(w.zLabel=void 0),-1===T.indexOf(\"text\")&&(p.textLabel=void 0),-1===T.indexOf(\"name\")&&(c.name=void 0));var M=[];\"cone\"===e.type||\"streamtube\"===e.type?(w.uLabel=v(\"xaxis\",p.traceCoordinate[3]),(A||-1!==T.indexOf(\"u\"))&&M.push(\"u: \"+w.uLabel),w.vLabel=v(\"yaxis\",p.traceCoordinate[4]),(A||-1!==T.indexOf(\"v\"))&&M.push(\"v: \"+w.vLabel),w.wLabel=v(\"zaxis\",p.traceCoordinate[5]),(A||-1!==T.indexOf(\"w\"))&&M.push(\"w: \"+w.wLabel),w.normLabel=p.traceCoordinate[6].toPrecision(3),(A||-1!==T.indexOf(\"norm\"))&&M.push(\"norm: \"+w.normLabel),\"streamtube\"===e.type&&(w.divergenceLabel=p.traceCoordinate[7].toPrecision(3),(A||-1!==T.indexOf(\"divergence\"))&&M.push(\"divergence: \"+w.divergenceLabel)),p.textLabel&&M.push(p.textLabel),x=M.join(\"<br>\")):\"isosurface\"===e.type||\"volume\"===e.type?(w.valueLabel=h.tickText(t.mockAxis,t.mockAxis.d2l(p.traceCoordinate[3]),\"hover\").text,M.push(\"value: \"+w.valueLabel),p.textLabel&&M.push(p.textLabel),x=M.join(\"<br>\")):x=p.textLabel;var S={x:p.traceCoordinate[0],y:p.traceCoordinate[1],z:p.traceCoordinate[2],data:b._input,fullData:b,curveNumber:b.index,pointNumber:_};f.appendArrayPointValue(S,b,_),e._module.eventData&&(S=b._module.eventData(S,p,b,{},_));var E={points:[S]};t.fullSceneLayout.hovermode&&f.loneHover({trace:b,x:(.5+.5*m[0]/m[3])*a,y:(.5-.5*m[1]/m[3])*o,xLabel:w.xLabel,yLabel:w.yLabel,zLabel:w.zLabel,text:x,name:c.name,color:f.castHoverOption(b,_,\"bgcolor\")||c.color,borderColor:f.castHoverOption(b,_,\"bordercolor\"),fontFamily:f.castHoverOption(b,_,\"font.family\"),fontSize:f.castHoverOption(b,_,\"font.size\"),fontColor:f.castHoverOption(b,_,\"font.color\"),nameLength:f.castHoverOption(b,_,\"namelength\"),textAlign:f.castHoverOption(b,_,\"align\"),hovertemplate:u.castOption(b,_,\"hovertemplate\"),hovertemplateLabels:u.extendFlat({},S,w),eventData:[S]},{container:n,gd:r}),p.buttons&&p.distance<5?r.emit(\"plotly_click\",E):r.emit(\"plotly_hover\",E),s=E}else f.loneUnhover(n),r.emit(\"plotly_unhover\",s);t.drawAnnotations(t)}.bind(null,t),t.traces={},t.make4thDimension(),!0}function b(t,e){var r=document.createElement(\"div\"),n=t.container;this.graphDiv=t.graphDiv;var i=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");i.style.position=\"absolute\",i.style.top=i.style.left=\"0px\",i.style.width=i.style.height=\"100%\",i.style[\"z-index\"]=20,i.style[\"pointer-events\"]=\"none\",r.appendChild(i),this.svgContainer=i,r.id=t.id,r.style.position=\"absolute\",r.style.top=r.style.left=\"0px\",r.style.width=r.style.height=\"100%\",n.appendChild(r),this.fullLayout=e,this.id=t.id||\"scene\",this.fullSceneLayout=e[this.id],this.plotArgs=[[],{},{}],this.axesOptions=v(e,e[this.id]),this.spikeOptions=m(e[this.id]),this.container=r,this.staticMode=!!t.staticPlot,this.pixelRatio=this.pixelRatio||t.plotGlPixelRatio||2,this.dataScale=[1,1,1],this.contourLevels=[[],[],[]],this.convertAnnotations=c.getComponentMethod(\"annotations3d\",\"convert\"),this.drawAnnotations=c.getComponentMethod(\"annotations3d\",\"draw\"),x(this,this.pixelRatio)}var _=b.prototype;_.initializeGLCamera=function(){var t=this.fullSceneLayout.camera,e=\"orthographic\"===t.projection.type;this.camera=a(this.container,{center:[t.center.x,t.center.y,t.center.z],eye:[t.eye.x,t.eye.y,t.eye.z],up:[t.up.x,t.up.y,t.up.z],_ortho:e,zoomMin:.01,zoomMax:100,mode:\"orbit\"})},_.recoverContext=function(){var t=this,e=this.glplot.gl,r=this.glplot.canvas,n=this.glplot.camera,i=this.glplot.pixelRatio;this.glplot.dispose(),requestAnimationFrame(function a(){e.isContextLost()?requestAnimationFrame(a):x(t,n,i,r)?t.plot.apply(t,t.plotArgs):u.error(\"Catastrophic and unrecoverable WebGL error. Context lost.\")})};var w=[\"xaxis\",\"yaxis\",\"zaxis\"];function k(t,e,r){for(var n=t.fullSceneLayout,i=0;i<3;i++){var a=w[i],o=a.charAt(0),s=n[a],l=e[o],c=e[o+\"calendar\"],h=e[\"_\"+o+\"length\"];if(u.isArrayOrTypedArray(l))for(var f,p=0;p<(h||l.length);p++)if(u.isArrayOrTypedArray(l[p]))for(var d=0;d<l[p].length;++d)f=s.d2l(l[p][d],0,c),!isNaN(f)&&isFinite(f)&&(r[0][i]=Math.min(r[0][i],f),r[1][i]=Math.max(r[1][i],f));else f=s.d2l(l[p],0,c),!isNaN(f)&&isFinite(f)&&(r[0][i]=Math.min(r[0][i],f),r[1][i]=Math.max(r[1][i],f));else r[0][i]=Math.min(r[0][i],0),r[1][i]=Math.max(r[1][i],h-1)}}function T(t){return{up:{x:t.up[0],y:t.up[1],z:t.up[2]},center:{x:t.center[0],y:t.center[1],z:t.center[2]},eye:{x:t.eye[0],y:t.eye[1],z:t.eye[2]},projection:{type:!0===t._ortho?\"orthographic\":\"perspective\"}}}_.plot=function(t,e,r){if(this.plotArgs=[t,e,r],!this.glplot.contextLost){var n,i,a,o,s,l,c=e[this.id],u=r[this.id];c.bgcolor?this.glplot.clearColor=p(c.bgcolor):this.glplot.clearColor=[0,0,0,0],this.glplot.snapToData=!0,this.fullLayout=e,this.fullSceneLayout=c,this.glplotLayout=c,this.axesOptions.merge(e,c),this.spikeOptions.merge(c),this.setCamera(c.camera),this.updateFx(c.dragmode,c.hovermode),this.camera.enableWheel=this.graphDiv._context._scrollZoom.gl3d,this.glplot.update({}),this.setConvert(s),t?Array.isArray(t)||(t=[t]):t=[];var h=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&k(this,n,h);!function(t,e){for(var r=t.fullSceneLayout,n=r.annotations||[],i=0;i<3;i++)for(var a=w[i],o=a.charAt(0),s=r[a],l=0;l<n.length;l++){var c=n[l];if(c.visible){var u=s.r2l(c[o]);!isNaN(u)&&isFinite(u)&&(e[0][i]=Math.min(e[0][i],u),e[1][i]=Math.max(e[1][i],u))}}}(this,h);var f=[1,1,1];for(o=0;o<3;++o)h[1][o]===h[0][o]?f[o]=1:f[o]=1/(h[1][o]-h[0][o]);for(this.dataScale=f,this.convertAnnotations(this),a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&((i=this.traces[n.uid])?i.data.type===n.type?i.update(n):(i.dispose(),i=n._module.plot(this,n),this.traces[n.uid]=i):(i=n._module.plot(this,n),this.traces[n.uid]=i),i.name=n.name);var d=Object.keys(this.traces);t:for(a=0;a<d.length;++a){for(o=0;o<t.length;++o)if(t[o].uid===d[a]&&!0===t[o].visible&&0!==t[o]._length)continue t;(i=this.traces[d[a]]).dispose(),delete this.traces[d[a]]}this.glplot.objects.sort(function(t,e){return t._trace.data.index-e._trace.data.index});var g=[[0,0,0],[0,0,0]],v=[],m={};for(a=0;a<3;++a){if((l=(s=c[w[a]]).type)in m?(m[l].acc*=f[a],m[l].count+=1):m[l]={acc:f[a],count:1},s.autorange){g[0][a]=1/0,g[1][a]=-1/0;var y=this.glplot.objects,x=this.fullSceneLayout.annotations||[],b=s._name.charAt(0);for(o=0;o<y.length;o++){var _=y[o],T=_.bounds,A=_._trace.data._pad||0;\"ErrorBars\"===_.constructor.name&&s._lowerLogErrorBound?g[0][a]=Math.min(g[0][a],s._lowerLogErrorBound):g[0][a]=Math.min(g[0][a],T[0][a]/f[a]-A),g[1][a]=Math.max(g[1][a],T[1][a]/f[a]+A)}for(o=0;o<x.length;o++){var M=x[o];if(M.visible){var S=s.r2l(M[b]);g[0][a]=Math.min(g[0][a],S),g[1][a]=Math.max(g[1][a],S)}}if(\"rangemode\"in s&&\"tozero\"===s.rangemode&&(g[0][a]=Math.min(g[0][a],0),g[1][a]=Math.max(g[1][a],0)),g[0][a]>g[1][a])g[0][a]=-1,g[1][a]=1;else{var E=g[1][a]-g[0][a];g[0][a]-=E/32,g[1][a]+=E/32}if(\"reversed\"===s.autorange){var C=g[0][a];g[0][a]=g[1][a],g[1][a]=C}}else{var L=s.range;g[0][a]=s.r2l(L[0]),g[1][a]=s.r2l(L[1])}g[0][a]===g[1][a]&&(g[0][a]-=1,g[1][a]+=1),v[a]=g[1][a]-g[0][a],this.glplot.bounds[0][a]=g[0][a]*f[a],this.glplot.bounds[1][a]=g[1][a]*f[a]}var P=[1,1,1];for(a=0;a<3;++a){var O=m[l=(s=c[w[a]]).type];P[a]=Math.pow(O.acc,1/O.count)/f[a]}var z;if(\"auto\"===c.aspectmode)z=Math.max.apply(null,P)/Math.min.apply(null,P)<=4?P:[1,1,1];else if(\"cube\"===c.aspectmode)z=[1,1,1];else if(\"data\"===c.aspectmode)z=P;else{if(\"manual\"!==c.aspectmode)throw new Error(\"scene.js aspectRatio was not one of the enumerated types\");var I=c.aspectratio;z=[I.x,I.y,I.z]}c.aspectratio.x=u.aspectratio.x=z[0],c.aspectratio.y=u.aspectratio.y=z[1],c.aspectratio.z=u.aspectratio.z=z[2],this.glplot.aspect=z;var D=c.domain||null,R=e._size||null;if(D&&R){var F=this.container.style;F.position=\"absolute\",F.left=R.l+D.x[0]*R.w+\"px\",F.top=R.t+(1-D.y[1])*R.h+\"px\",F.width=R.w*(D.x[1]-D.x[0])+\"px\",F.height=R.h*(D.y[1]-D.y[0])+\"px\"}this.glplot.redraw()}},_.destroy=function(){this.glplot&&(this.camera.mouseListener.enabled=!1,this.container.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=this.glplot.camera=null,this.glplot.dispose(),this.container.parentNode.removeChild(this.container),this.glplot=null)},_.getCamera=function(){return this.glplot.camera.view.recalcMatrix(this.camera.view.lastT()),T(this.glplot.camera)},_.setCamera=function(t){var e;this.glplot.camera.lookAt.apply(this,[[(e=t).eye.x,e.eye.y,e.eye.z],[e.center.x,e.center.y,e.center.z],[e.up.x,e.up.y,e.up.z]]);var r=\"orthographic\"===t.projection.type;if(r!==this.glplot.camera._ortho){this.glplot.redraw();var n=this.glplot.pixelRatio,i=this.glplot.clearColor;this.glplot.gl.clearColor(i[0],i[1],i[2],i[3]),this.glplot.gl.clear(this.glplot.gl.DEPTH_BUFFER_BIT|this.glplot.gl.COLOR_BUFFER_BIT),this.glplot.dispose(),x(this,n),this.glplot.camera._ortho=r}},_.saveCamera=function(t){var e=this.fullLayout,r=this.getCamera(),n=u.nestedProperty(t,this.id+\".camera\"),i=n.get(),a=!1;function o(t,e,r,n){var i=[\"up\",\"center\",\"eye\"],a=[\"x\",\"y\",\"z\"];return e[i[r]]&&t[i[r]][a[n]]===e[i[r]][a[n]]}if(void 0===i)a=!0;else{for(var s=0;s<3;s++)for(var l=0;l<3;l++)if(!o(r,i,s,l)){a=!0;break}(!i.projection||r.projection&&r.projection.type!==i.projection.type)&&(a=!0)}if(a){var h={};h[this.id+\".camera\"]=i,c.call(\"_storeDirectGUIEdit\",t,e._preGUI,h),n.set(r),u.nestedProperty(e,this.id+\".camera\").set(r)}return a},_.updateFx=function(t,e){var r=this.camera;if(r)if(\"orbit\"===t)r.mode=\"orbit\",r.keyBindingMode=\"rotate\";else if(\"turntable\"===t){r.up=[0,0,1],r.mode=\"turntable\",r.keyBindingMode=\"rotate\";var n=this.graphDiv,i=n._fullLayout,a=this.fullSceneLayout.camera,o=a.up.x,s=a.up.y,l=a.up.z;if(l/Math.sqrt(o*o+s*s+l*l)<.999){var h=this.id+\".camera.up\",f={x:0,y:0,z:1},p={};p[h]=f;var d=n.layout;c.call(\"_storeDirectGUIEdit\",d,i._preGUI,p),a.up=f,u.nestedProperty(d,h).set(f)}}else r.keyBindingMode=t;this.fullSceneLayout.hovermode=e},_.toImage=function(t){t||(t=\"png\"),this.staticMode&&this.container.appendChild(n),this.glplot.redraw();var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a);for(var o=0,s=i-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=a[4*(r*o+l)+c];a[4*(r*o+l)+c]=a[4*(r*s+l)+c],a[4*(r*s+l)+c]=u}var h=document.createElement(\"canvas\");h.width=r,h.height=i;var f,p=h.getContext(\"2d\"),d=p.createImageData(r,i);switch(d.data.set(a),p.putImageData(d,0,0),t){case\"jpeg\":f=h.toDataURL(\"image/jpeg\");break;case\"webp\":f=h.toDataURL(\"image/webp\");break;default:f=h.toDataURL(\"image/png\")}return this.staticMode&&this.container.removeChild(n),f},_.setConvert=function(){for(var t=0;t<3;t++){var e=this.fullSceneLayout[w[t]];h.setConvert(e,this.fullLayout),e.setScale=u.noop}},_.make4thDimension=function(){var t=this.graphDiv._fullLayout;this.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},h.setConvert(this.mockAxis,t)},e.exports=b},{\"../../components/fx\":632,\"../../lib\":719,\"../../lib/show_no_webgl_msg\":740,\"../../lib/str2rgbarray\":742,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./layout/convert\":811,\"./layout/spikes\":814,\"./layout/tick_marks\":815,\"./project\":816,\"gl-plot3d\":290,\"has-passive-events\":411,\"webgl-context\":556}],818:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){n=n||t.length;for(var i=new Array(n),a=0;a<n;a++)i[a]=[t[a],e[a],r[a]];return i}},{}],819:[function(t,e,r){\"use strict\";var n=t(\"./font_attributes\"),i=t(\"./animation_attributes\"),a=t(\"../components/color/attributes\"),o=t(\"./pad_attributes\"),s=t(\"../lib/extend\").extendFlat,l=n({editType:\"calc\"});l.family.dflt='\"Open Sans\", verdana, arial, sans-serif',l.size.dflt=12,l.color.dflt=a.defaultLine,e.exports={font:l,title:{text:{valType:\"string\",editType:\"layoutstyle\"},font:n({editType:\"layoutstyle\"}),xref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},yref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},x:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"layoutstyle\"},y:{valType:\"number\",min:0,max:1,dflt:\"auto\",editType:\"layoutstyle\"},xanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"left\",\"center\",\"right\"],editType:\"layoutstyle\"},yanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],editType:\"layoutstyle\"},pad:s(o({editType:\"layoutstyle\"}),{}),editType:\"layoutstyle\"},autosize:{valType:\"boolean\",dflt:!1,editType:\"none\"},width:{valType:\"number\",min:10,dflt:700,editType:\"plot\"},height:{valType:\"number\",min:10,dflt:450,editType:\"plot\"},margin:{l:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},r:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},t:{valType:\"number\",min:0,dflt:100,editType:\"plot\"},b:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},pad:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},autoexpand:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},paper_bgcolor:{valType:\"color\",dflt:a.background,editType:\"plot\"},plot_bgcolor:{valType:\"color\",dflt:a.background,editType:\"layoutstyle\"},separators:{valType:\"string\",editType:\"plot\"},hidesources:{valType:\"boolean\",dflt:!1,editType:\"plot\"},showlegend:{valType:\"boolean\",editType:\"legend\"},colorway:{valType:\"colorlist\",dflt:a.defaults,editType:\"calc\"},datarevision:{valType:\"any\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editrevision:{valType:\"any\",editType:\"none\"},selectionrevision:{valType:\"any\",editType:\"none\"},template:{valType:\"any\",editType:\"calc\"},modebar:{orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\",editType:\"modebar\"},bgcolor:{valType:\"color\",editType:\"modebar\"},color:{valType:\"color\",editType:\"modebar\"},activecolor:{valType:\"color\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"modebar\"},meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},transition:s({},i.transition,{editType:\"none\"}),_deprecated:{title:{valType:\"string\",editType:\"layoutstyle\"},titlefont:n({editType:\"layoutstyle\"})}}},{\"../components/color/attributes\":592,\"../lib/extend\":710,\"./animation_attributes\":762,\"./font_attributes\":793,\"./pad_attributes\":827}],820:[function(t,e,r){\"use strict\";var n={\"open-street-map\":{id:\"osm\",version:8,sources:{\"plotly-osm-tiles\":{type:\"raster\",attribution:'<a href=\"http://www.openstreetmap.org/about/\" target=\"_blank\">\\xa9 OpenStreetMap</a>',tiles:[\"https://a.tile.openstreetmap.org/{z}/{x}/{y}.png\",\"https://b.tile.openstreetmap.org/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-osm-tiles\",type:\"raster\",source:\"plotly-osm-tiles\",minzoom:0,maxzoom:22}]},\"white-bg\":{id:\"white-bg\",version:8,sources:{},layers:[{id:\"white-bg\",type:\"background\",paint:{\"background-color\":\"#FFFFFF\"},minzoom:0,maxzoom:22}]},\"carto-positron\":{id:\"carto-positron\",version:8,sources:{\"plotly-carto-positron\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/light_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-positron\",type:\"raster\",source:\"plotly-carto-positron\",minzoom:0,maxzoom:22}]},\"carto-darkmatter\":{id:\"carto-darkmatter\",version:8,sources:{\"plotly-carto-darkmatter\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/dark_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-darkmatter\",type:\"raster\",source:\"plotly-carto-darkmatter\",minzoom:0,maxzoom:22}]},\"stamen-terrain\":{id:\"stamen-terrain\",version:8,sources:{\"plotly-stamen-terrain\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/terrain/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-terrain\",type:\"raster\",source:\"plotly-stamen-terrain\",minzoom:0,maxzoom:22}]},\"stamen-toner\":{id:\"stamen-toner\",version:8,sources:{\"plotly-stamen-toner\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/toner/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-toner\",type:\"raster\",source:\"plotly-stamen-toner\",minzoom:0,maxzoom:22}]},\"stamen-watercolor\":{id:\"stamen-watercolor\",version:8,sources:{\"plotly-stamen-watercolor\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://creativecommons.org/licenses/by-sa/3.0\">CC BY SA</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/watercolor/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-watercolor\",type:\"raster\",source:\"plotly-stamen-watercolor\",minzoom:0,maxzoom:22}]}},i=Object.keys(n);e.exports={requiredVersion:\"1.1.1\",styleUrlPrefix:\"mapbox://styles/mapbox/\",styleUrlSuffix:\"v9\",styleValuesMapbox:[\"basic\",\"streets\",\"outdoors\",\"light\",\"dark\",\"satellite\",\"satellite-streets\"],styleValueDflt:\"basic\",stylesNonMapbox:n,styleValuesNonMapbox:i,traceLayerPrefix:\"plotly-trace-layer-\",layoutLayerPrefix:\"plotly-layout-layer-\",wrongVersionErrorMsg:[\"Your custom plotly.js bundle is not using the correct mapbox-gl version\",\"Please install mapbox-gl@1.1.1.\"].join(\"\\n\"),noAccessTokenErrorMsg:[\"Missing Mapbox access token.\",\"Mapbox trace type require a Mapbox access token to be registered.\",\"For example:\",\"  Plotly.plot(gd, data, layout, { mapboxAccessToken: 'my-access-token' });\",\"More info here: https://www.mapbox.com/help/define-access-token/\"].join(\"\\n\"),missingStyleErrorMsg:[\"No valid mapbox style found, please set `mapbox.style` to one of:\",i.join(\", \"),\"or register a Mapbox access token to use a Mapbox-served style.\"].join(\"\\n\"),multipleTokensErrorMsg:[\"Set multiple mapbox access token across different mapbox subplot,\",\"using first token found as mapbox-gl does not allow multipleaccess tokens on the same page.\"].join(\"\\n\"),mapOnErrorMsg:\"Mapbox error.\",mapboxLogo:{path0:\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\",path1:\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\",path2:\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\",polygon:\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34\"},styleRules:{map:\"overflow:hidden;position:relative;\",\"missing-css\":\"display:none;\",canary:\"background-color:salmon;\",\"ctrl-bottom-left\":\"position: absolute; pointer-events: none; z-index: 2; bottom: 0; left: 0;\",\"ctrl-bottom-right\":\"position: absolute; pointer-events: none; z-index: 2; right: 0; bottom: 0;\",ctrl:\"clear: both; pointer-events: auto; transform: translate(0, 0);\",\"ctrl-attrib.mapboxgl-compact .mapboxgl-ctrl-attrib-inner\":\"display: none;\",\"ctrl-attrib.mapboxgl-compact:hover .mapboxgl-ctrl-attrib-inner\":\"display: block; margin-top:2px\",\"ctrl-attrib.mapboxgl-compact:hover\":\"padding: 2px 24px 2px 4px; visibility: visible; margin-top: 6px;\",\"ctrl-attrib.mapboxgl-compact::after\":'content: \"\"; cursor: pointer; position: absolute; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3Csvg viewBox=\"0 0 20 20\" xmlns=\"http://www.w3.org/2000/svg\"%3E %3Cpath fill=\"%23333333\" fill-rule=\"evenodd\" d=\"M4,10a6,6 0 1,0 12,0a6,6 0 1,0 -12,0 M9,7a1,1 0 1,0 2,0a1,1 0 1,0 -2,0 M9,10a1,1 0 1,1 2,0l0,3a1,1 0 1,1 -2,0\"/%3E %3C/svg%3E\\'); background-color: rgba(255, 255, 255, 0.5); width: 24px; height: 24px; box-sizing: border-box; border-radius: 12px;',\"ctrl-attrib.mapboxgl-compact\":\"min-height: 20px; padding: 0; margin: 10px; position: relative; background-color: #fff; border-radius: 3px 12px 12px 3px;\",\"ctrl-bottom-right > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; right: 0\",\"ctrl-bottom-left > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; left: 0\",\"ctrl-bottom-left .mapboxgl-ctrl\":\"margin: 0 0 10px 10px; float: left;\",\"ctrl-bottom-right .mapboxgl-ctrl\":\"margin: 0 10px 10px 0; float: right;\",\"ctrl-attrib\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a:hover\":\"color: inherit; text-decoration: underline;\",\"ctrl-attrib .mapbox-improve-map\":\"font-weight: bold; margin-left: 2px;\",\"attrib-empty\":\"display: none;\",\"ctrl-logo\":'display:block; width: 21px; height: 21px; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3C?xml version=\"1.0\" encoding=\"utf-8\"?%3E %3Csvg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\" viewBox=\"0 0 21 21\" style=\"enable-background:new 0 0 21 21;\" xml:space=\"preserve\"%3E%3Cg transform=\"translate(0,0.01)\"%3E%3Cpath d=\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3Cpath d=\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpath d=\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpolygon points=\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34 \" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3C/g%3E%3C/svg%3E\\')'}}},{}],821:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t.split(\" \"),i=r[0],a=r[1],o=n.isArrayOrTypedArray(e)?n.mean(e):e,s=.5+o/100,l=1.5+o/100,c=[\"\",\"\"],u=[0,0];switch(i){case\"top\":c[0]=\"top\",u[1]=-l;break;case\"bottom\":c[0]=\"bottom\",u[1]=l}switch(a){case\"left\":c[1]=\"right\",u[0]=-s;break;case\"right\":c[1]=\"left\",u[0]=s}return{anchor:c[0]&&c[1]?c.join(\"-\"):c[0]?c[0]:c[1]?c[1]:\"center\",offset:u}}},{\"../../lib\":719}],822:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"../../lib\"),a=t(\"../../plots/get_data\").getSubplotCalcData,o=t(\"../../constants/xmlns_namespaces\"),s=t(\"d3\"),l=t(\"../../components/drawing\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"./mapbox\"),h=r.constants=t(\"./constants\");function f(t){return\"string\"==typeof t&&-1!==h.styleValuesMapbox.indexOf(t)}r.name=\"mapbox\",r.attr=\"subplot\",r.idRoot=\"mapbox\",r.idRegex=r.attrRegex=i.counterRegex(\"mapbox\"),r.attributes={subplot:{valType:\"subplotid\",dflt:\"mapbox\",editType:\"calc\"}},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){var e=t._fullLayout,r=t.calcdata,o=e._subplots.mapbox;if(n.version!==h.requiredVersion)throw new Error(h.wrongVersionErrorMsg);var s=function(t,e){var r=t._fullLayout;if(\"\"===t._context.mapboxAccessToken)return\"\";for(var n=[],a=[],o=!1,s=!1,l=0;l<e.length;l++){var c=r[e[l]],u=c.accesstoken;f(c.style)&&(u?i.pushUnique(n,u):(f(c._input.style)&&(i.error(\"Uses Mapbox map style, but did not set an access token.\"),o=!0),s=!0)),u&&i.pushUnique(a,u)}if(s){var p=o?h.noAccessTokenErrorMsg:h.missingStyleErrorMsg;throw new Error(p)}return n.length?(n.length>1&&i.warn(h.multipleTokensErrorMsg),n[0]):(a.length&&i.log([\"Listed mapbox access token(s)\",a.join(\",\"),\"but did not use a Mapbox map style, ignoring token(s).\"].join(\" \")),\"\")}(t,o);n.accessToken=s;for(var l=0;l<o.length;l++){var c=o[l],p=a(r,\"mapbox\",c),d=e[c],g=d._subplot;g||(g=new u(t,c),e[c]._subplot=g),g.viewInitial||(g.viewInitial={center:i.extendFlat({},d.center),zoom:d.zoom,bearing:d.bearing,pitch:d.pitch}),g.plot(p,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.mapbox||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._subplot&&n[o]._subplot.destroy()}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=e._size,i=0;i<r.length;i++){var a=e[r[i]],u=a.domain,f=a._subplot.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":f,x:n.l+n.w*u.x[0],y:n.t+n.h*(1-u.y[1]),width:n.w*(u.x[1]-u.x[0]),height:n.h*(u.y[1]-u.y[0]),preserveAspectRatio:\"none\"});var p=s.select(a._subplot.div);if(!(null===p.select(\".mapboxgl-ctrl-logo\").node().offsetParent)){var d=e._glimages.append(\"g\");d.attr(\"transform\",\"translate(\"+(n.l+n.w*u.x[0]+10)+\", \"+(n.t+n.h*(1-u.y[0])-31)+\")\"),d.append(\"path\").attr(\"d\",h.mapboxLogo.path0).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"}),d.append(\"path\").attr(\"d\",h.mapboxLogo.path1).style(\"opacity\",.35).style(\"enable-background\",\"new\"),d.append(\"path\").attr(\"d\",h.mapboxLogo.path2).style(\"opacity\",.35).style(\"enable-background\",\"new\"),d.append(\"polygon\").attr(\"points\",h.mapboxLogo.polygon).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"})}var g=p.select(\".mapboxgl-ctrl-attrib\").text().replace(\"Improve this map\",\"\"),v=e._glimages.append(\"g\"),m=v.append(\"text\");m.text(g).classed(\"static-attribution\",!0).attr({\"font-size\":12,\"font-family\":\"Arial\",color:\"rgba(0, 0, 0, 0.75)\",\"text-anchor\":\"end\",\"data-unformatted\":g});var y=l.bBox(m.node()),x=n.w*(u.x[1]-u.x[0]);if(y.width>x/2){var b=g.split(\"|\").join(\"<br>\");m.text(b).attr(\"data-unformatted\",b).call(c.convertToTspans,t),y=l.bBox(m.node())}m.attr(\"transform\",\"translate(-3, \"+(8-y.height)+\")\"),v.insert(\"rect\",\".static-attribution\").attr({x:-y.width-6,y:-y.height-3,width:y.width+6,height:y.height+3,fill:\"rgba(255, 255, 255, 0.75)\"});var _=1;y.width+6>x&&(_=x/(y.width+6));var w=[n.l+n.w*u.x[1],n.t+n.h*(1-u.y[0])];v.attr(\"transform\",\"translate(\"+w[0]+\",\"+w[1]+\") scale(\"+_+\")\")}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=0;n<r.length;n++){e[r[n]]._subplot.updateFx(e)}}},{\"../../components/drawing\":614,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/get_data\":802,\"./constants\":820,\"./layout_attributes\":824,\"./layout_defaults\":825,\"./mapbox\":826,d3:163,\"mapbox-gl\":426}],823:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./convert_text_opts\"),a=t(\"./constants\");function o(t,e){this.subplot=t,this.uid=t.uid+\"-\"+e,this.index=e,this.idSource=\"source-\"+this.uid,this.idLayer=a.layoutLayerPrefix+this.uid,this.sourceType=null,this.source=null,this.layerType=null,this.below=null,this.visible=!1}var s=o.prototype;function l(t){var e=t.source;return t.visible&&(n.isPlainObject(e)||(\"string\"==typeof e||Array.isArray(e))&&e.length>0)}function c(t){var e={},r={};switch(t.type){case\"circle\":n.extendFlat(r,{\"circle-radius\":t.circle.radius,\"circle-color\":t.color,\"circle-opacity\":t.opacity});break;case\"line\":n.extendFlat(r,{\"line-width\":t.line.width,\"line-color\":t.color,\"line-opacity\":t.opacity,\"line-dasharray\":t.line.dash});break;case\"fill\":n.extendFlat(r,{\"fill-color\":t.color,\"fill-outline-color\":t.fill.outlinecolor,\"fill-opacity\":t.opacity});break;case\"symbol\":var a=t.symbol,o=i(a.textposition,a.iconsize);n.extendFlat(e,{\"icon-image\":a.icon+\"-15\",\"icon-size\":a.iconsize/10,\"text-field\":a.text,\"text-size\":a.textfont.size,\"text-anchor\":o.anchor,\"text-offset\":o.offset,\"symbol-placement\":a.placement}),n.extendFlat(r,{\"icon-color\":t.color,\"text-color\":a.textfont.color,\"text-opacity\":t.opacity})}return{layout:e,paint:r}}s.update=function(t){this.visible?this.needsNewSource(t)?(this.removeLayer(),this.updateSource(t),this.updateLayer(t)):this.needsNewLayer(t)?this.updateLayer(t):this.updateStyle(t):(this.updateSource(t),this.updateLayer(t)),this.visible=l(t)},s.needsNewSource=function(t){return this.sourceType!==t.sourcetype||this.source!==t.source||this.layerType!==t.type},s.needsNewLayer=function(t){return this.layerType!==t.type||this.below!==this.subplot.belowLookup[\"layout-\"+this.index]},s.updateSource=function(t){var e=this.subplot.map;if(e.getSource(this.idSource)&&e.removeSource(this.idSource),this.sourceType=t.sourcetype,this.source=t.source,l(t)){var r=function(t){var e,r=t.sourcetype,n=t.source,i={type:r};\"geojson\"===r?e=\"data\":\"vector\"===r?e=\"string\"==typeof n?\"url\":\"tiles\":\"raster\"===r?(e=\"tiles\",i.tileSize=256):\"image\"===r&&(e=\"url\",i.coordinates=t.coordinates);i[e]=n,t.sourceattribution&&(i.attribution=t.sourceattribution);return i}(t);e.addSource(this.idSource,r)}},s.updateLayer=function(t){var e,r=this.subplot,n=c(t),i=this.subplot.belowLookup[\"layout-\"+this.index];if(\"traces\"===i)for(var o=r.getMapLayers(),s=0;s<o.length;s++){var u=o[s].id;if(\"string\"==typeof u&&0===u.indexOf(a.traceLayerPrefix)){e=u;break}}else e=i;this.removeLayer(),l(t)&&r.addLayer({id:this.idLayer,source:this.idSource,\"source-layer\":t.sourcelayer||\"\",type:t.type,minzoom:t.minzoom,maxzoom:t.maxzoom,layout:n.layout,paint:n.paint},e),this.layerType=t.type,this.below=i},s.updateStyle=function(t){if(l(t)){var e=c(t);this.subplot.setOptions(this.idLayer,\"setLayoutProperty\",e.layout),this.subplot.setOptions(this.idLayer,\"setPaintProperty\",e.paint)}},s.removeLayer=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer)},s.dispose=function(){var t=this.subplot.map;t.removeLayer(this.idLayer),t.removeSource(this.idSource)},e.exports=function(t,e,r){var n=new o(t,e);return n.update(r),n}},{\"../../lib\":719,\"./constants\":820,\"./convert_text_opts\":821}],824:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\").defaultLine,a=t(\"../domain\").attributes,o=t(\"../font_attributes\"),s=t(\"../../traces/scatter/attributes\").textposition,l=t(\"../../plot_api/edit_types\").overrideAll,c=t(\"../../plot_api/plot_template\").templatedArray,u=t(\"./constants\"),h=o({});h.family.dflt=\"Open Sans Regular, Arial Unicode MS Regular\",(e.exports=l({_arrayAttrRegexps:[n.counterRegex(\"mapbox\",\".layers\",!0)],domain:a({name:\"mapbox\"}),accesstoken:{valType:\"string\",noBlank:!0,strict:!0},style:{valType:\"any\",values:u.styleValuesMapbox.concat(u.styleValuesNonMapbox),dflt:u.styleValueDflt},center:{lon:{valType:\"number\",dflt:0},lat:{valType:\"number\",dflt:0}},zoom:{valType:\"number\",dflt:1},bearing:{valType:\"number\",dflt:0},pitch:{valType:\"number\",dflt:0},layers:c(\"layer\",{visible:{valType:\"boolean\",dflt:!0},sourcetype:{valType:\"enumerated\",values:[\"geojson\",\"vector\",\"raster\",\"image\"],dflt:\"geojson\"},source:{valType:\"any\"},sourcelayer:{valType:\"string\",dflt:\"\"},sourceattribution:{valType:\"string\"},type:{valType:\"enumerated\",values:[\"circle\",\"line\",\"fill\",\"symbol\",\"raster\"],dflt:\"circle\"},coordinates:{valType:\"any\"},below:{valType:\"string\"},color:{valType:\"color\",dflt:i},opacity:{valType:\"number\",min:0,max:1,dflt:1},minzoom:{valType:\"number\",min:0,max:24,dflt:0},maxzoom:{valType:\"number\",min:0,max:24,dflt:24},circle:{radius:{valType:\"number\",dflt:15}},line:{width:{valType:\"number\",dflt:2},dash:{valType:\"data_array\"}},fill:{outlinecolor:{valType:\"color\",dflt:i}},symbol:{icon:{valType:\"string\",dflt:\"marker\"},iconsize:{valType:\"number\",dflt:10},text:{valType:\"string\",dflt:\"\"},placement:{valType:\"enumerated\",values:[\"point\",\"line\",\"line-center\"],dflt:\"point\"},textfont:h,textposition:n.extendFlat({},s,{arrayOk:!1})}})},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../traces/scatter/attributes\":1112,\"../domain\":792,\"../font_attributes\":793,\"./constants\":820}],825:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../subplot_defaults\"),a=t(\"../array_container_defaults\"),o=t(\"./layout_attributes\");function s(t,e,r,n){r(\"accesstoken\",n.accessToken),r(\"style\"),r(\"center.lon\"),r(\"center.lat\"),r(\"zoom\"),r(\"bearing\"),r(\"pitch\"),a(t,e,{name:\"layers\",handleItemDefaults:l}),e._input=t}function l(t,e){function r(r,i){return n.coerce(t,e,o.layers,r,i)}if(r(\"visible\")){var i,a=r(\"sourcetype\"),s=\"raster\"===a||\"image\"===a;r(\"source\"),r(\"sourceattribution\"),\"vector\"===a&&r(\"sourcelayer\"),\"image\"===a&&r(\"coordinates\"),s&&(i=\"raster\");var l=r(\"type\",i);s&&\"raster\"!==l&&(l=e.type=\"raster\",n.log(\"Source types *raster* and *image* must drawn *raster* layer type.\")),r(\"below\"),r(\"color\"),r(\"opacity\"),r(\"minzoom\"),r(\"maxzoom\"),\"circle\"===l&&r(\"circle.radius\"),\"line\"===l&&(r(\"line.width\"),r(\"line.dash\")),\"fill\"===l&&r(\"fill.outlinecolor\"),\"symbol\"===l&&(r(\"symbol.icon\"),r(\"symbol.iconsize\"),r(\"symbol.text\"),n.coerceFont(r,\"symbol.textfont\"),r(\"symbol.textposition\"),r(\"symbol.placement\"))}}e.exports=function(t,e,r){i(t,e,r,{type:\"mapbox\",attributes:o,handleDefaults:s,partition:\"y\",accessToken:e._mapboxAccessToken})}},{\"../../lib\":719,\"../array_container_defaults\":763,\"../subplot_defaults\":842,\"./layout_attributes\":824}],826:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"d3\"),a=t(\"../../components/fx\"),o=t(\"../../lib\"),s=t(\"../../registry\"),l=t(\"../cartesian/axes\"),c=t(\"../../components/dragelement\"),u=t(\"../cartesian/select\").prepSelect,h=t(\"../cartesian/select\").selectOnClick,f=t(\"./constants\"),p=t(\"./layers\");function d(t,e){this.id=e,this.gd=t;var r=t._fullLayout,n=t._context;this.container=r._glcontainer.node(),this.isStatic=n.staticPlot,this.uid=r._uid+\"-\"+this.id,this.div=null,this.xaxis=null,this.yaxis=null,this.createFramework(r),this.map=null,this.accessToken=null,this.styleObj=null,this.traceHash={},this.layerList=[],this.belowLookup={}}var g=d.prototype;g.plot=function(t,e,r){var n,i=this,a=e[i.id];i.map&&a.accesstoken!==i.accessToken&&(i.map.remove(),i.map=null,i.styleObj=null,i.traceHash=[],i.layerList={}),n=i.map?new Promise(function(r,n){i.updateMap(t,e,r,n)}):new Promise(function(r,n){i.createMap(t,e,r,n)}),r.push(n)},g.createMap=function(t,e,r,i){var a=this,o=e[a.id],s=a.styleObj=m(o.style);a.accessToken=o.accesstoken;var l=a.map=new n.Map({container:a.div,style:s.style,center:x(o.center),zoom:o.zoom,bearing:o.bearing,pitch:o.pitch,interactive:!a.isStatic,preserveDrawingBuffer:a.isStatic,doubleClickZoom:!1,boxZoom:!1,attributionControl:!1}).addControl(new n.AttributionControl({compact:!0}));l._canvas.style.left=\"0px\",l._canvas.style.top=\"0px\",a.rejectOnError(i),a.isStatic||a.initFx(t,e);var c=[];c.push(new Promise(function(t){l.once(\"load\",t)})),c=c.concat(a.fetchMapData(t,e)),Promise.all(c).then(function(){a.fillBelowLookup(t,e),a.updateData(t),a.updateLayout(e),a.resolveOnRender(r)}).catch(i)},g.fetchMapData=function(t){var e=[];function r(t){return new Promise(function(e,r){i.json(t,function(n,i){if(n){delete PlotlyGeoAssets[t];var a=404===n.status?'GeoJSON at URL \"'+t+'\" does not exist.':\"Unexpected error while fetching from \"+t;return r(new Error(a))}PlotlyGeoAssets[t]=i,e(i)})})}for(var n=0;n<t.length;n++){var a=t[n][0].trace.geojson;\"string\"!=typeof a||PlotlyGeoAssets[a]||(PlotlyGeoAssets[a]=\"pending\",e.push(r(a)))}return e},g.updateMap=function(t,e,r,n){var i=this,a=i.map,o=e[this.id];i.rejectOnError(n);var s=[],l=m(o.style);i.styleObj.id!==l.id&&(i.styleObj=l,a.setStyle(l.style),i.traceHash={},s.push(new Promise(function(t){a.once(\"styledata\",t)}))),s=s.concat(i.fetchMapData(t,e)),Promise.all(s).then(function(){i.fillBelowLookup(t,e),i.updateData(t),i.updateLayout(e),i.resolveOnRender(r)}).catch(n)},g.fillBelowLookup=function(t,e){var r,n,i=e[this.id].layers,a=this.belowLookup={},o=!1;for(r=0;r<t.length;r++){var s=t[r][0].trace,l=s._module;\"string\"==typeof s.below?n=s.below:l.getBelow&&(n=l.getBelow(s,this)),\"\"===n&&(o=!0),a[\"trace-\"+s.uid]=n||\"\"}for(r=0;r<i.length;r++){var c=i[r];n=\"string\"==typeof c.below?c.below:o?\"traces\":\"\",a[\"layout-\"+r]=n}var u,h,f={};for(u in a)f[n=a[u]]?f[n].push(u):f[n]=[u];for(n in f){var p=f[n];if(p.length>1)for(r=0;r<p.length;r++)0===(u=p[r]).indexOf(\"trace-\")?(h=u.split(\"trace-\")[1],this.traceHash[h]&&(this.traceHash[h].below=null)):0===u.indexOf(\"layout-\")&&(h=u.split(\"layout-\")[1],this.layerList[h]&&(this.layerList[h].below=null))}};var v={choroplethmapbox:0,densitymapbox:1,scattermapbox:2};function m(t){var e={};return o.isPlainObject(t)?(e.id=t.id,e.style=t):\"string\"==typeof t?(e.id=t,-1!==f.styleValuesMapbox.indexOf(t)?e.style=y(t):f.stylesNonMapbox[t]?e.style=f.stylesNonMapbox[t]:e.style=t):(e.id=f.styleValueDflt,e.style=y(f.styleValueDflt)),e.transition={duration:0,delay:0},e}function y(t){return f.styleUrlPrefix+t+\"-\"+f.styleUrlSuffix}function x(t){return[t.lon,t.lat]}g.updateData=function(t){var e,r,n,i,a=this.traceHash,o=t.slice().sort(function(t,e){return v[t[0].trace.type]-v[e[0].trace.type]});for(n=0;n<o.length;n++){var s=o[n];(e=a[(r=s[0].trace).uid])?e.update(s):r._module&&(a[r.uid]=r._module.plot(this,s))}var l=Object.keys(a);t:for(n=0;n<l.length;n++){var c=l[n];for(i=0;i<t.length;i++)if(c===(r=t[i][0].trace).uid)continue t;(e=a[c]).dispose(),delete a[c]}},g.updateLayout=function(t){var e=this.map,r=t[this.id];e.setCenter(x(r.center)),e.setZoom(r.zoom),e.setBearing(r.bearing),e.setPitch(r.pitch),this.updateLayers(t),this.updateFramework(t),this.updateFx(t),this.map.resize(),this.gd._context._scrollZoom.mapbox?e.scrollZoom.enable():e.scrollZoom.disable()},g.resolveOnRender=function(t){var e=this.map;e.on(\"render\",function r(){e.loaded()&&(e.off(\"render\",r),setTimeout(t,0))})},g.rejectOnError=function(t){var e=this.map;function r(){t(new Error(f.mapOnErrorMsg))}e.once(\"error\",r),e.once(\"style.error\",r),e.once(\"source.error\",r),e.once(\"tile.error\",r),e.once(\"layer.error\",r)},g.createFramework=function(t){var e=this,r=e.div=document.createElement(\"div\");r.id=e.uid,r.style.position=\"absolute\",e.container.appendChild(r),e.xaxis={_id:\"x\",c2p:function(t){return e.project(t).x}},e.yaxis={_id:\"y\",c2p:function(t){return e.project(t).y}},e.updateFramework(t),e.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},l.setConvert(e.mockAxis,t)},g.initFx=function(t,e){var r=this,n=r.gd,i=r.map,o=!1;function l(){a.loneUnhover(e._hoverlayer)}function c(){var t=r.getView();n.emit(\"plotly_relayouting\",r.getViewEdits(t))}i.on(\"moveend\",function(t){if(r.map){var e=n._fullLayout;if(t.originalEvent||o){var i=e[r.id];s.call(\"_storeDirectGUIEdit\",n.layout,e._preGUI,r.getViewEdits(i));var a=r.getView();i._input.center=i.center=a.center,i._input.zoom=i.zoom=a.zoom,i._input.bearing=i.bearing=a.bearing,i._input.pitch=i.pitch=a.pitch,n.emit(\"plotly_relayout\",r.getViewEdits(a))}o=!1,e._rehover&&e._rehover()}}),i.on(\"wheel\",function(){o=!0}),i.on(\"mousemove\",function(t){var e=r.div.getBoundingClientRect();t.clientX=t.point.x+e.left,t.clientY=t.point.y+e.top,t.target.getBoundingClientRect=function(){return e},r.xaxis.p2c=function(){return t.lngLat.lng},r.yaxis.p2c=function(){return t.lngLat.lat},n._fullLayout._rehover=function(){n._fullLayout._hoversubplot===r.id&&a.hover(n,t,r.id)},a.hover(n,t,r.id),n._fullLayout._hoversubplot=r.id}),i.on(\"dragstart\",l),i.on(\"zoomstart\",l),i.on(\"mouseout\",function(){n._fullLayout._hoversubplot=null}),i.on(\"drag\",c),i.on(\"zoom\",c),i.on(\"dblclick\",function(){var t=n._fullLayout[r.id];s.call(\"_storeDirectGUIEdit\",n.layout,n._fullLayout._preGUI,r.getViewEdits(t));var e=r.viewInitial;i.setCenter(x(e.center)),i.setZoom(e.zoom),i.setBearing(e.bearing),i.setPitch(e.pitch);var a=r.getView();t._input.center=t.center=a.center,t._input.zoom=t.zoom=a.zoom,t._input.bearing=t.bearing=a.bearing,t._input.pitch=t.pitch=a.pitch,n.emit(\"plotly_doubleclick\",null),n.emit(\"plotly_relayout\",r.getViewEdits(a))}),r.clearSelect=function(){n._fullLayout._zoomlayer.selectAll(\".select-outline\").remove()},r.onClickInPanFn=function(t){return function(e){var i=n._fullLayout.clickmode;i.indexOf(\"select\")>-1&&h(e.originalEvent,n,[r.xaxis],[r.yaxis],r.id,t),i.indexOf(\"event\")>-1&&a.click(n,e.originalEvent)}}},g.updateFx=function(t){var e=this,r=e.map,n=e.gd;if(!e.isStatic){var i,a=t.dragmode;i=\"select\"===a?function(t,r){(t.range={})[e.id]=[l([r.xmin,r.ymin]),l([r.xmax,r.ymax])]}:function(t,r,n){(t.lassoPoints={})[e.id]=n.filtered.map(l)};var s=e.dragOptions;e.dragOptions=o.extendDeep(s||{},{element:e.div,gd:n,plotinfo:{id:e.id,xaxis:e.xaxis,yaxis:e.yaxis,fillRangeItems:i},xaxes:[e.xaxis],yaxes:[e.yaxis],subplot:e.id}),r.off(\"click\",e.onClickInPanHandler),\"select\"===a||\"lasso\"===a?(r.dragPan.disable(),r.on(\"zoomstart\",e.clearSelect),e.dragOptions.prepFn=function(t,r,n){u(t,r,n,e.dragOptions,a)},c.init(e.dragOptions)):(r.dragPan.enable(),r.off(\"zoomstart\",e.clearSelect),e.div.onmousedown=null,e.onClickInPanHandler=e.onClickInPanFn(e.dragOptions),r.on(\"click\",e.onClickInPanHandler))}function l(t){var r=e.map.unproject(t);return[r.lng,r.lat]}},g.updateFramework=function(t){var e=t[this.id].domain,r=t._size,n=this.div.style;n.width=r.w*(e.x[1]-e.x[0])+\"px\",n.height=r.h*(e.y[1]-e.y[0])+\"px\",n.left=r.l+e.x[0]*r.w+\"px\",n.top=r.t+(1-e.y[1])*r.h+\"px\",this.xaxis._offset=r.l+e.x[0]*r.w,this.xaxis._length=r.w*(e.x[1]-e.x[0]),this.yaxis._offset=r.t+(1-e.y[1])*r.h,this.yaxis._length=r.h*(e.y[1]-e.y[0])},g.updateLayers=function(t){var e,r=t[this.id].layers,n=this.layerList;if(r.length!==n.length){for(e=0;e<n.length;e++)n[e].dispose();for(n=this.layerList=[],e=0;e<r.length;e++)n.push(p(this,e,r[e]))}else for(e=0;e<r.length;e++)n[e].update(r[e])},g.destroy=function(){this.map&&(this.map.remove(),this.map=null,this.container.removeChild(this.div))},g.toImage=function(){return this.map.stop(),this.map.getCanvas().toDataURL()},g.setOptions=function(t,e,r){for(var n in r)this.map[e](t,n,r[n])},g.getMapLayers=function(){return this.map.getStyle().layers},g.addLayer=function(t,e){var r=this.map;if(\"string\"==typeof e){if(\"\"===e)return void r.addLayer(t,e);for(var n=this.getMapLayers(),i=0;i<n.length;i++)if(e===n[i].id)return void r.addLayer(t,e);o.warn([\"Trying to add layer with *below* value\",e,\"referencing a layer that does not exist\",\"or that does not yet exist.\"].join(\" \"))}r.addLayer(t)},g.project=function(t){return this.map.project(new n.LngLat(t[0],t[1]))},g.getView=function(){var t=this.map,e=t.getCenter();return{center:{lon:e.lng,lat:e.lat},zoom:t.getZoom(),bearing:t.getBearing(),pitch:t.getPitch()}},g.getViewEdits=function(t){for(var e=this.id,r=[\"center\",\"zoom\",\"bearing\",\"pitch\"],n={},i=0;i<r.length;i++){var a=r[i];n[e+\".\"+a]=t[a]}return n},e.exports=d},{\"../../components/dragelement\":611,\"../../components/fx\":632,\"../../lib\":719,\"../../registry\":847,\"../cartesian/axes\":767,\"../cartesian/select\":784,\"./constants\":820,\"./layers\":823,d3:163,\"mapbox-gl\":426}],827:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType;return{t:{valType:\"number\",dflt:0,editType:e},r:{valType:\"number\",dflt:0,editType:e},b:{valType:\"number\",dflt:0,editType:e},l:{valType:\"number\",dflt:0,editType:e},editType:e}}},{}],828:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../registry\"),o=t(\"../plot_api/plot_schema\"),s=t(\"../plot_api/plot_template\"),l=t(\"../lib\"),c=t(\"../components/color\"),u=t(\"../constants/numerical\").BADNUM,h=t(\"./cartesian/axis_ids\"),f=t(\"./animation_attributes\"),p=t(\"./frame_attributes\"),d=l.relinkPrivateKeys,g=l._,v=e.exports={};l.extendFlat(v,a),v.attributes=t(\"./attributes\"),v.attributes.type.values=v.allTypes,v.fontAttrs=t(\"./font_attributes\"),v.layoutAttributes=t(\"./layout_attributes\"),v.fontWeight=\"normal\";var m=v.transformsRegistry,y=t(\"./command\");v.executeAPICommand=y.executeAPICommand,v.computeAPICommandBindings=y.computeAPICommandBindings,v.manageCommandObserver=y.manageCommandObserver,v.hasSimpleAPICommandBindings=y.hasSimpleAPICommandBindings,v.redrawText=function(t){var e=(t=l.getGraphDiv(t))._fullLayout||{};if(!(!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r))return new Promise(function(e){setTimeout(function(){a.getComponentMethod(\"annotations\",\"draw\")(t),a.getComponentMethod(\"legend\",\"draw\")(t),a.getComponentMethod(\"colorbar\",\"draw\")(t),e(v.previousPromises(t))},300)})},v.resize=function(t){return t=l.getGraphDiv(t),new Promise(function(e,r){t&&!l.isHidden(t)||r(new Error(\"Resize must be passed a displayed plot div element.\")),t._redrawTimer&&clearTimeout(t._redrawTimer),t._redrawTimer=setTimeout(function(){if(!t.layout||t.layout.width&&t.layout.height||l.isHidden(t))e(t);else{delete t.layout.width,delete t.layout.height;var r=t.changed;t.autoplay=!0,a.call(\"relayout\",t,{autosize:!0}).then(function(){t.changed=r,e(t)})}},100)})},v.previousPromises=function(t){if((t._promises||[]).length)return Promise.all(t._promises).then(function(){t._promises=[]})},v.addLinks=function(t){if(t._context.showLink||t._context.showSources){var e=t._fullLayout,r=l.ensureSingle(e._paper,\"text\",\"js-plot-link-container\",function(t){t.style({\"font-family\":'\"Open Sans\", Arial, sans-serif',\"font-size\":\"12px\",fill:c.defaultLine,\"pointer-events\":\"all\"}).each(function(){var t=n.select(this);t.append(\"tspan\").classed(\"js-link-to-tool\",!0),t.append(\"tspan\").classed(\"js-link-spacer\",!0),t.append(\"tspan\").classed(\"js-sourcelinks\",!0)})}),i=r.node(),a={y:e._paper.attr(\"height\")-9};document.body.contains(i)&&i.getComputedTextLength()>=e.width-20?(a[\"text-anchor\"]=\"start\",a.x=5):(a[\"text-anchor\"]=\"end\",a.x=e._paper.attr(\"width\")-7),r.attr(a);var o=r.select(\".js-link-to-tool\"),s=r.select(\".js-link-spacer\"),u=r.select(\".js-sourcelinks\");t._context.showSources&&t._context.showSources(t),t._context.showLink&&function(t,e){e.text(\"\");var r=e.append(\"a\").attr({\"xlink:xlink:href\":\"#\",class:\"link--impt link--embedview\",\"font-weight\":\"bold\"}).text(t._context.linkText+\" \"+String.fromCharCode(187));if(t._context.sendData)r.on(\"click\",function(){v.sendDataToCloud(t)});else{var n=window.location.pathname.split(\"/\"),i=window.location.search;r.attr({\"xlink:xlink:show\":\"new\",\"xlink:xlink:href\":\"/\"+n[2].split(\".\")[0]+\"/\"+n[1]+i})}}(t,o),s.text(o.text()&&u.text()?\" - \":\"\")}},v.sendDataToCloud=function(t){t.emit(\"plotly_beforeexport\");var e=(window.PLOTLYENV||{}).BASE_URL||t._context.plotlyServerURL,r=n.select(t).append(\"div\").attr(\"id\",\"hiddenform\").style(\"display\",\"none\"),i=r.append(\"form\").attr({action:e+\"/external\",method:\"post\",target:\"_blank\"});return i.append(\"input\").attr({type:\"text\",name:\"data\"}).node().value=v.graphJson(t,!1,\"keepdata\"),i.node().submit(),r.remove(),t.emit(\"plotly_afterexport\"),!1};var x=[\"days\",\"shortDays\",\"months\",\"shortMonths\",\"periods\",\"dateTime\",\"date\",\"time\",\"decimal\",\"thousands\",\"grouping\",\"currency\"],b=[\"year\",\"month\",\"dayMonth\",\"dayMonthYear\"];function _(t,e){var r=t._context.locale,n=!1,i={};function o(t){for(var r=!0,a=0;a<e.length;a++){var o=e[a];i[o]||(t[o]?i[o]=t[o]:r=!1)}r&&(n=!0)}for(var s=0;s<2;s++){for(var l=t._context.locales,c=0;c<2;c++){var u=(l[r]||{}).format;if(u&&(o(u),n))break;l=a.localeRegistry}var h=r.split(\"-\")[0];if(n||h===r)break;r=h}return n||o(a.localeRegistry.en.format),i}function w(t,e){var r={_fullLayout:e},n=\"x\"===t._id.charAt(0),i=t._mainAxis._anchorAxis,a=\"\",o=\"\",s=\"\";if(i&&(s=i._mainAxis._id,a=n?t._id+s:s+t._id),!a||!e._plots[a]){a=\"\";for(var l=t._counterAxes,c=0;c<l.length;c++){var u=l[c],f=n?t._id+u:u+t._id;o||(o=f);var p=h.getFromId(r,u);if(s&&p.overlaying===s){a=f;break}}}return a||o}function k(t){var e=t.transforms;if(Array.isArray(e)&&e.length)for(var r=0;r<e.length;r++){var n=e[r],i=n._module||m[n.type];if(i&&i.makesData)return!0}return!1}function T(t,e,r,n){for(var i=t.transforms,a=[t],o=0;o<i.length;o++){var s=i[o],l=m[s.type];l&&l.transform&&(a=l.transform(a,{transform:s,fullTrace:t,fullData:e,layout:r,fullLayout:n,transformIndex:o}))}return a}function A(t){var e=t.margin;if(!t._size){var r=t._size={l:Math.round(e.l),r:Math.round(e.r),t:Math.round(e.t),b:Math.round(e.b),p:Math.round(e.pad)};r.w=Math.round(t.width)-r.l-r.r,r.h=Math.round(t.height)-r.t-r.b}t._pushmargin||(t._pushmargin={}),t._pushmarginIds||(t._pushmarginIds={})}v.supplyDefaults=function(t,e){var r=e&&e.skipUpdateCalc,i=t._fullLayout||{};if(i._skipDefaults)delete i._skipDefaults;else{var o,s=t._fullLayout={},c=t.layout||{},u=t._fullData||[],h=t._fullData=[],f=t.data||[],p=t.calcdata||[],m=t._context||{};t._transitionData||v.createTransitionData(t),s._dfltTitle={plot:g(t,\"Click to enter Plot title\"),x:g(t,\"Click to enter X axis title\"),y:g(t,\"Click to enter Y axis title\"),colorbar:g(t,\"Click to enter Colorscale title\"),annotation:g(t,\"new text\")},s._traceWord=g(t,\"trace\");var y=_(t,x);if(s._mapboxAccessToken=m.mapboxAccessToken,i._initialAutoSizeIsDone){var w=i.width,k=i.height;v.supplyLayoutGlobalDefaults(c,s,y),c.width||(s.width=w),c.height||(s.height=k),v.sanitizeMargins(s)}else{v.supplyLayoutGlobalDefaults(c,s,y);var T=!c.width||!c.height,M=s.autosize,S=m.autosizable;T&&(M||S)?v.plotAutoSize(t,c,s):T&&v.sanitizeMargins(s),!M&&T&&(c.width=s.width,c.height=s.height)}s._d3locale=function(t,e){return t.decimal=e.charAt(0),t.thousands=e.charAt(1),n.locale(t)}(y,s.separators),s._extraFormat=_(t,b),s._initialAutoSizeIsDone=!0,s._dataLength=f.length,s._modules=[],s._visibleModules=[],s._basePlotModules=[];var E=s._subplots=function(){var t,e,r=a.collectableSubplotTypes,n={};if(!r){r=[];var i=a.subplotsRegistry;for(var o in i){var s=i[o],c=s.attr;if(c&&(r.push(o),Array.isArray(c)))for(e=0;e<c.length;e++)l.pushUnique(r,c[e])}}for(t=0;t<r.length;t++)n[r[t]]=[];return n}(),C=s._splomAxes={x:{},y:{}},L=s._splomSubplots={};s._splomGridDflt={},s._scatterStackOpts={},s._firstScatter={},s._alignmentOpts={},s._colorAxes={},s._requestRangeslider={},s._traceUids=function(t,e){var r,n,i=e.length,a=[];for(r=0;r<t.length;r++){var o=t[r]._fullInput;o!==n&&a.push(o),n=o}var s=a.length,c=new Array(i),u={};function h(t,e){c[e]=t,u[t]=1}function f(t,e){if(t&&\"string\"==typeof t&&!u[t])return h(t,e),!0}for(r=0;r<i;r++){var p=e[r].uid;\"number\"==typeof p&&(p=String(p)),f(p,r)||(r<s&&f(a[r].uid,r)||h(l.randstr(u),r))}return c}(u,f),s._globalTransforms=(t._context||{}).globalTransforms,v.supplyDataDefaults(f,h,c,s);var P=Object.keys(C.x),O=Object.keys(C.y);if(P.length>1&&O.length>1){for(a.getComponentMethod(\"grid\",\"sizeDefaults\")(c,s),o=0;o<P.length;o++)l.pushUnique(E.xaxis,P[o]);for(o=0;o<O.length;o++)l.pushUnique(E.yaxis,O[o]);for(var z in L)l.pushUnique(E.cartesian,z)}if(s._has=v._hasPlotType.bind(s),u.length===h.length)for(o=0;o<h.length;o++)d(h[o],u[o]);v.supplyLayoutModuleDefaults(c,s,h,t._transitionData);var I=s._visibleModules,D=[];for(o=0;o<I.length;o++){var R=I[o].crossTraceDefaults;R&&l.pushUnique(D,R)}for(o=0;o<D.length;o++)D[o](h,s);s._hasOnlyLargeSploms=1===s._basePlotModules.length&&\"splom\"===s._basePlotModules[0].name&&P.length>15&&O.length>15&&0===s.shapes.length&&0===s.images.length,s._hasCartesian=s._has(\"cartesian\"),s._hasGeo=s._has(\"geo\"),s._hasGL3D=s._has(\"gl3d\"),s._hasGL2D=s._has(\"gl2d\"),s._hasTernary=s._has(\"ternary\"),s._hasPie=s._has(\"pie\"),v.linkSubplots(h,s,u,i),v.cleanPlot(h,s,u,i),i._zoomlayer&&!t._dragging&&i._zoomlayer.selectAll(\".select-outline\").remove(),function(t,e){var r,n=[];e.meta&&(r=e._meta={meta:e.meta,layout:{meta:e.meta}});for(var i=0;i<t.length;i++){var a=t[i];a.meta?n[a.index]=a._meta={meta:a.meta}:e.meta&&(a._meta={meta:e.meta}),e.meta&&(a._meta.layout={meta:e.meta})}n.length&&(r||(r=e._meta={}),r.data=n)}(h,s),d(s,i),a.getComponentMethod(\"colorscale\",\"crossTraceDefaults\")(h,s),s._preGUI||(s._preGUI={}),s._tracePreGUI||(s._tracePreGUI={});var F,B=s._tracePreGUI,N={};for(F in B)N[F]=\"old\";for(o=0;o<h.length;o++)N[F=h[o]._fullInput.uid]||(B[F]={}),N[F]=\"new\";for(F in N)\"old\"===N[F]&&delete B[F];A(s),a.getComponentMethod(\"rangeslider\",\"makeData\")(s),r||p.length!==h.length||v.supplyDefaultsUpdateCalc(p,h)}},v.supplyDefaultsUpdateCalc=function(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=(t[r]||[])[0];if(i&&i.trace){var a=i.trace;if(a._hasCalcTransform){var o,s,c,u=a._arrayAttrs;for(o=0;o<u.length;o++)s=u[o],c=l.nestedProperty(a,s).get().slice(),l.nestedProperty(n,s).set(c)}i.trace=n}}},v.createTransitionData=function(t){t._transitionData||(t._transitionData={}),t._transitionData._frames||(t._transitionData._frames=[]),t._transitionData._frameHash||(t._transitionData._frameHash={}),t._transitionData._counter||(t._transitionData._counter=0),t._transitionData._interruptCallbacks||(t._transitionData._interruptCallbacks=[])},v._hasPlotType=function(t){var e,r=this._basePlotModules||[];for(e=0;e<r.length;e++)if(r[e].name===t)return!0;var n=this._modules||[];for(e=0;e<n.length;e++){var i=n[e].name;if(i===t)return!0;var o=a.modules[i];if(o&&o.categories[t])return!0}return!1},v.cleanPlot=function(t,e,r,n){var i,a,o=n._basePlotModules||[];for(i=0;i<o.length;i++){var s=o[i];s.clean&&s.clean(t,e,r,n)}var l=n._has&&n._has(\"gl\"),c=e._has&&e._has(\"gl\");l&&!c&&void 0!==n._glcontainer&&(n._glcontainer.selectAll(\".gl-canvas\").remove(),n._glcontainer.selectAll(\".no-webgl\").remove(),n._glcanvas=null);var u=!!n._infolayer;t:for(i=0;i<r.length;i++){var h=r[i].uid;for(a=0;a<t.length;a++){if(h===t[a].uid)continue t}u&&n._infolayer.select(\".cb\"+h).remove()}},v.linkSubplots=function(t,e,r,n){var i,a,o=n._plots||{},s=e._plots={},c=e._subplots,u={_fullData:t,_fullLayout:e},f=c.cartesian.concat(c.gl2d||[]);for(i=0;i<f.length;i++){var p,d=f[i],g=o[d],v=h.getFromId(u,d,\"x\"),m=h.getFromId(u,d,\"y\");for(g?p=s[d]=g:(p=s[d]={}).id=d,v._counterAxes.push(m._id),m._counterAxes.push(v._id),v._subplotsWith.push(d),m._subplotsWith.push(d),p.xaxis=v,p.yaxis=m,p._hasClipOnAxisFalse=!1,a=0;a<t.length;a++){var y=t[a];if(y.xaxis===p.xaxis._id&&y.yaxis===p.yaxis._id&&!1===y.cliponaxis){p._hasClipOnAxisFalse=!0;break}}}var x,b=h.list(u,null,!0);for(i=0;i<b.length;i++){var _=null;(x=b[i]).overlaying&&(_=h.getFromId(u,x.overlaying))&&_.overlaying&&(x.overlaying=!1,_=null),x._mainAxis=_||x,_&&(x.domain=_.domain.slice()),x._anchorAxis=\"free\"===x.anchor?null:h.getFromId(u,x.anchor)}for(i=0;i<b.length;i++)(x=b[i])._counterAxes.sort(h.idSort),x._subplotsWith.sort(l.subplotSort),x._mainSubplot=w(x,e)},v.clearExpandedTraceDefaultColors=function(t){var e,r,n;for(r=[],(e=t._module._colorAttrs)||(t._module._colorAttrs=e=[],o.crawl(t._module.attributes,function(t,n,i,a){r[a]=n,r.length=a+1,\"color\"===t.valType&&void 0===t.dflt&&e.push(r.join(\".\"))})),n=0;n<e.length;n++){l.nestedProperty(t,\"_input.\"+e[n]).get()||l.nestedProperty(t,e[n]).set(null)}},v.supplyDataDefaults=function(t,e,r,n){var i,o,c,u=n._modules,h=n._visibleModules,f=n._basePlotModules,p=0,g=0;function m(t){e.push(t);var r=t._module;r&&(l.pushUnique(u,r),!0===t.visible&&l.pushUnique(h,r),l.pushUnique(f,t._module.basePlotModule),p++,!1!==t._input.visible&&g++)}n._transformModules=[];var y={},x=[],b=(r.template||{}).data||{},_=s.traceTemplater(b);for(i=0;i<t.length;i++){if(c=t[i],(o=_.newTrace(c)).uid=n._traceUids[i],v.supplyTraceDefaults(c,o,g,n,i),o.index=i,o._input=c,o._expandedIndex=p,o.transforms&&o.transforms.length)for(var w=!1!==c.visible&&!1===o.visible,k=T(o,e,r,n),A=0;A<k.length;A++){var M=k[A],S={_template:o._template,type:o.type,uid:o.uid+A};w&&!1===M.visible&&delete M.visible,v.supplyTraceDefaults(M,S,p,n,i),d(S,M),S.index=i,S._input=c,S._fullInput=o,S._expandedIndex=p,S._expandedInput=M,m(S)}else o._fullInput=o,o._expandedInput=o,m(o);a.traceIs(o,\"carpetAxis\")&&(y[o.carpet]=o),a.traceIs(o,\"carpetDependent\")&&x.push(i)}for(i=0;i<x.length;i++)if((o=e[x[i]]).visible){var E=y[o.carpet];o._carpet=E,E&&E.visible?(o.xaxis=E.xaxis,o.yaxis=E.yaxis):o.visible=!1}},v.supplyAnimationDefaults=function(t){var e;t=t||{};var r={};function n(e,n){return l.coerce(t||{},r,f,e,n)}if(n(\"mode\"),n(\"direction\"),n(\"fromcurrent\"),Array.isArray(t.frame))for(r.frame=[],e=0;e<t.frame.length;e++)r.frame[e]=v.supplyAnimationFrameDefaults(t.frame[e]||{});else r.frame=v.supplyAnimationFrameDefaults(t.frame||{});if(Array.isArray(t.transition))for(r.transition=[],e=0;e<t.transition.length;e++)r.transition[e]=v.supplyAnimationTransitionDefaults(t.transition[e]||{});else r.transition=v.supplyAnimationTransitionDefaults(t.transition||{});return r},v.supplyAnimationFrameDefaults=function(t){var e={};function r(r,n){return l.coerce(t||{},e,f.frame,r,n)}return r(\"duration\"),r(\"redraw\"),e},v.supplyAnimationTransitionDefaults=function(t){var e={};function r(r,n){return l.coerce(t||{},e,f.transition,r,n)}return r(\"duration\"),r(\"easing\"),e},v.supplyFrameDefaults=function(t){var e={};function r(r,n){return l.coerce(t,e,p,r,n)}return r(\"group\"),r(\"name\"),r(\"traces\"),r(\"baseframe\"),r(\"data\"),r(\"layout\"),e},v.supplyTraceDefaults=function(t,e,r,n,i){var o,s=n.colorway||c.defaults,u=s[r%s.length];function h(r,n){return l.coerce(t,e,v.attributes,r,n)}var f=h(\"visible\");h(\"type\"),h(\"name\",n._traceWord+\" \"+i),h(\"uirevision\",n.uirevision);var p=v.getModule(e);if(e._module=p,p){var d=p.basePlotModule,g=d.attr,m=d.attributes;if(g&&m){var y=n._subplots,x=\"\";if(\"gl2d\"!==d.name||f){if(Array.isArray(g))for(o=0;o<g.length;o++){var b=g[o],_=l.coerce(t,e,m,b);y[b]&&l.pushUnique(y[b],_),x+=_}else x=l.coerce(t,e,m,g);y[d.name]&&l.pushUnique(y[d.name],x)}}}return f&&(h(\"customdata\"),h(\"ids\"),h(\"meta\"),a.traceIs(e,\"showLegend\")?(e._dfltShowLegend=!0,h(\"showlegend\"),h(\"legendgroup\")):e._dfltShowLegend=!1,p&&p.supplyDefaults(t,e,u,n),a.traceIs(e,\"noOpacity\")||h(\"opacity\"),a.traceIs(e,\"notLegendIsolatable\")&&(e.visible=!!e.visible),a.traceIs(e,\"noHover\")||(e.hovertemplate||l.coerceHoverinfo(t,e,n),\"parcats\"!==e.type&&a.getComponentMethod(\"fx\",\"supplyDefaults\")(t,e,u,n)),p&&p.selectPoints&&h(\"selectedpoints\"),v.supplyTransformDefaults(t,e,n)),e},v.hasMakesDataTransform=k,v.supplyTransformDefaults=function(t,e,r){if(e._length||k(t)){var n=r._globalTransforms||[],i=r._transformModules||[];if(Array.isArray(t.transforms)||0!==n.length)for(var a=t.transforms||[],o=n.concat(a),s=e.transforms=[],c=0;c<o.length;c++){var u,h=o[c],f=h.type,p=m[f],d=!(h._module&&h._module===p),g=p&&\"function\"==typeof p.transform;p||l.warn(\"Unrecognized transform type \"+f+\".\"),p&&p.supplyDefaults&&(d||g)?((u=p.supplyDefaults(h,e,r,t)).type=f,u._module=p,l.pushUnique(i,p)):u=l.extendFlat({},h),s.push(u)}}},v.supplyLayoutGlobalDefaults=function(t,e,r){function n(r,n){return l.coerce(t,e,v.layoutAttributes,r,n)}var i=t.template;l.isPlainObject(i)&&(e.template=i,e._template=i.layout,e._dataTemplate=i.data);var o=l.coerceFont(n,\"font\");n(\"title.text\",e._dfltTitle.plot),l.coerceFont(n,\"title.font\",{family:o.family,size:Math.round(1.4*o.size),color:o.color}),n(\"title.xref\"),n(\"title.yref\"),n(\"title.x\"),n(\"title.y\"),n(\"title.xanchor\"),n(\"title.yanchor\"),n(\"title.pad.t\"),n(\"title.pad.r\"),n(\"title.pad.b\"),n(\"title.pad.l\"),n(\"autosize\",!(t.width&&t.height)),n(\"width\"),n(\"height\"),n(\"margin.l\"),n(\"margin.r\"),n(\"margin.t\"),n(\"margin.b\"),n(\"margin.pad\"),n(\"margin.autoexpand\"),t.width&&t.height&&v.sanitizeMargins(e),a.getComponentMethod(\"grid\",\"sizeDefaults\")(t,e),n(\"paper_bgcolor\"),n(\"separators\",r.decimal+r.thousands),n(\"hidesources\"),n(\"colorway\"),n(\"datarevision\");var s=n(\"uirevision\");n(\"editrevision\",s),n(\"selectionrevision\",s),n(\"modebar.orientation\"),n(\"modebar.bgcolor\",c.addOpacity(e.paper_bgcolor,.5));var u=c.contrast(c.rgb(e.modebar.bgcolor));n(\"modebar.color\",c.addOpacity(u,.3)),n(\"modebar.activecolor\",c.addOpacity(u,.7)),n(\"modebar.uirevision\",s),n(\"meta\"),l.isPlainObject(t.transition)&&(n(\"transition.duration\"),n(\"transition.easing\"),n(\"transition.ordering\")),a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\"),a.getComponentMethod(\"fx\",\"supplyLayoutGlobalDefaults\")(t,e,n)},v.plotAutoSize=function(t,e,r){var n,a,o=t._context||{},s=o.frameMargins,c=l.isPlotDiv(t);if(c&&t.emit(\"plotly_autosize\"),o.fillFrame)n=window.innerWidth,a=window.innerHeight,document.body.style.overflow=\"hidden\";else{var u=c?window.getComputedStyle(t):{};if(n=parseFloat(u.width)||parseFloat(u.maxWidth)||r.width,a=parseFloat(u.height)||parseFloat(u.maxHeight)||r.height,i(s)&&s>0){var h=1-2*s;n=Math.round(h*n),a=Math.round(h*a)}}var f=v.layoutAttributes.width.min,p=v.layoutAttributes.height.min;n<f&&(n=f),a<p&&(a=p);var d=!e.width&&Math.abs(r.width-n)>1,g=!e.height&&Math.abs(r.height-a)>1;(g||d)&&(d&&(r.width=n),g&&(r.height=a)),t._initialAutoSize||(t._initialAutoSize={width:n,height:a}),v.sanitizeMargins(r)},v.supplyLayoutModuleDefaults=function(t,e,r,n){var i,o,s,c=a.componentsRegistry,u=e._basePlotModules,h=a.subplotsRegistry.cartesian;for(i in c)(s=c[i]).includeBasePlot&&s.includeBasePlot(t,e);for(var f in u.length||u.push(h),e._has(\"cartesian\")&&(a.getComponentMethod(\"grid\",\"contentDefaults\")(t,e),h.finalizeSubplots(t,e)),e._subplots)e._subplots[f].sort(l.subplotSort);for(o=0;o<u.length;o++)(s=u[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var p=e._modules;for(o=0;o<p.length;o++)(s=p[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var d=e._transformModules;for(o=0;o<d.length;o++)(s=d[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r,n);for(i in c)(s=c[i]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r)},v.purge=function(t){var e=t._fullLayout||{};void 0!==e._glcontainer&&(e._glcontainer.selectAll(\".gl-canvas\").remove(),e._glcontainer.remove(),e._glcanvas=null),void 0!==e._geocontainer&&e._geocontainer.remove(),e._modeBar&&e._modeBar.destroy(),t._transitionData&&(t._transitionData._interruptCallbacks&&(t._transitionData._interruptCallbacks.length=0),t._transitionData._animationRaf&&window.cancelAnimationFrame(t._transitionData._animationRaf)),l.clearThrottle(),l.clearResponsive(t),delete t.data,delete t.layout,delete t._fullData,delete t._fullLayout,delete t.calcdata,delete t.framework,delete t.empty,delete t.fid,delete t.undoqueue,delete t.undonum,delete t.autoplay,delete t.changed,delete t._promises,delete t._redrawTimer,delete t._hmlumcount,delete t._hmpixcount,delete t._transitionData,delete t._transitioning,delete t._initialAutoSize,delete t._transitioningWithDuration,delete t._dragging,delete t._dragged,delete t._dragdata,delete t._hoverdata,delete t._snapshotInProgress,delete t._editing,delete t._mouseDownTime,delete t._legendMouseDownTime,t.removeAllListeners&&t.removeAllListeners()},v.style=function(t){var e,r=t._fullLayout._visibleModules,n=[];for(e=0;e<r.length;e++){var i=r[e];i.style&&l.pushUnique(n,i.style)}for(e=0;e<n.length;e++)n[e](t)},v.sanitizeMargins=function(t){if(t&&t.margin){var e,r=t.width,n=t.height,i=t.margin,a=r-(i.l+i.r),o=n-(i.t+i.b);a<0&&(e=(r-1)/(i.l+i.r),i.l=Math.floor(e*i.l),i.r=Math.floor(e*i.r)),o<0&&(e=(n-1)/(i.t+i.b),i.t=Math.floor(e*i.t),i.b=Math.floor(e*i.b))}},v.clearAutoMarginIds=function(t){t._fullLayout._pushmarginIds={}},v.allowAutoMargin=function(t,e){t._fullLayout._pushmarginIds[e]=1},v.autoMargin=function(t,e,r){var n=t._fullLayout,i=n._pushmargin,a=n._pushmarginIds;if(!1!==n.margin.autoexpand){if(r){var o=r.pad;if(void 0===o){var s=n.margin;o=Math.min(12,s.l,s.r,s.t,s.b)}r.l+r.r>.5*n.width&&(r.l=r.r=0),r.b+r.t>.5*n.height&&(r.b=r.t=0);var l=void 0!==r.xl?r.xl:r.x,c=void 0!==r.xr?r.xr:r.x,u=void 0!==r.yt?r.yt:r.y,h=void 0!==r.yb?r.yb:r.y;i[e]={l:{val:l,size:r.l+o},r:{val:c,size:r.r+o},b:{val:h,size:r.b+o},t:{val:u,size:r.t+o}},a[e]=1}else delete i[e],delete a[e];n._replotting||v.doAutoMargin(t)}},v.doAutoMargin=function(t){var e=t._fullLayout;e._size||(e._size={}),A(e);var r=e._size,n=e.margin,o=l.extendFlat({},r),s=n.l,c=n.r,u=n.t,h=n.b,f=e.width,p=e.height,d=e._pushmargin,g=e._pushmarginIds;if(!1!==e.margin.autoexpand){for(var m in d)g[m]||delete d[m];for(var y in d.base={l:{val:0,size:s},r:{val:1,size:c},t:{val:1,size:u},b:{val:0,size:h}},d){var x=d[y].l||{},b=d[y].b||{},_=x.val,w=x.size,k=b.val,T=b.size;for(var M in d){if(i(w)&&d[M].r){var S=d[M].r.val,E=d[M].r.size;if(S>_){var C=(w*S+(E-f)*_)/(S-_),L=(E*(1-_)+(w-f)*(1-S))/(S-_);C>=0&&L>=0&&f-(C+L)>0&&C+L>s+c&&(s=C,c=L)}}if(i(T)&&d[M].t){var P=d[M].t.val,O=d[M].t.size;if(P>k){var z=(T*P+(O-p)*k)/(P-k),I=(O*(1-k)+(T-p)*(1-P))/(P-k);z>=0&&I>=0&&p-(I+z)>0&&z+I>h+u&&(h=z,u=I)}}}}}if(r.l=Math.round(s),r.r=Math.round(c),r.t=Math.round(u),r.b=Math.round(h),r.p=Math.round(n.pad),r.w=Math.round(f)-r.l-r.r,r.h=Math.round(p)-r.t-r.b,!e._replotting&&v.didMarginChange(o,r))return\"_redrawFromAutoMarginCount\"in e?e._redrawFromAutoMarginCount++:e._redrawFromAutoMarginCount=1,a.call(\"plot\",t)};var M=[\"l\",\"r\",\"t\",\"b\",\"p\",\"w\",\"h\"];function S(t,e,r){var n=!1;var i=[v.previousPromises,function(){if(t._transitionData)return t._transitioning=!1,function(t){var e=Promise.resolve();if(!t)return e;for(;t.length;)e=e.then(t.shift());return e}(t._transitionData._interruptCallbacks)},r.prepareFn,v.rehover,function(){return t.emit(\"plotly_transitioning\",[]),new Promise(function(i){t._transitioning=!0,e.duration>0&&(t._transitioningWithDuration=!0),t._transitionData._interruptCallbacks.push(function(){n=!0}),r.redraw&&t._transitionData._interruptCallbacks.push(function(){return a.call(\"redraw\",t)}),t._transitionData._interruptCallbacks.push(function(){t.emit(\"plotly_transitioninterrupted\",[])});var o=0,s=0;function l(){return o++,function(){var e;s++,n||s!==o||(e=i,t._transitionData&&(function(t){if(t)for(;t.length;)t.shift()}(t._transitionData._interruptCallbacks),Promise.resolve().then(function(){if(r.redraw)return a.call(\"redraw\",t)}).then(function(){t._transitioning=!1,t._transitioningWithDuration=!1,t.emit(\"plotly_transitioned\",[])}).then(e)))}}r.runFn(l),setTimeout(l())})}],o=l.syncOrAsync(i,t);return o&&o.then||(o=Promise.resolve()),o.then(function(){return t})}v.didMarginChange=function(t,e){for(var r=0;r<M.length;r++){var n=M[r],a=t[n],o=e[n];if(!i(a)||Math.abs(o-a)>1)return!0}return!1},v.graphJson=function(t,e,r,n,i){(i&&e&&!t._fullData||i&&!e&&!t._fullLayout)&&v.supplyDefaults(t);var a=i?t._fullData:t.data,o=i?t._fullLayout:t.layout,s=(t._transitionData||{})._frames;function c(t){if(\"function\"==typeof t)return null;if(l.isPlainObject(t)){var e,n,i={};for(e in t)if(\"function\"!=typeof t[e]&&-1===[\"_\",\"[\"].indexOf(e.charAt(0))){if(\"keepdata\"===r){if(\"src\"===e.substr(e.length-3))continue}else if(\"keepstream\"===r){if(\"string\"==typeof(n=t[e+\"src\"])&&n.indexOf(\":\")>0&&!l.isPlainObject(t.stream))continue}else if(\"keepall\"!==r&&\"string\"==typeof(n=t[e+\"src\"])&&n.indexOf(\":\")>0)continue;i[e]=c(t[e])}return i}return Array.isArray(t)?t.map(c):l.isTypedArray(t)?l.simpleMap(t,l.identity):l.isJSDate(t)?l.ms2DateTimeLocal(+t):t}var u={data:(a||[]).map(function(t){var r=c(t);return e&&delete r.fit,r})};return e||(u.layout=c(o)),t.framework&&t.framework.isPolar&&(u=t.framework.getConfig()),s&&(u.frames=c(s)),\"object\"===n?u:JSON.stringify(u)},v.modifyFrames=function(t,e){var r,n,i,a=t._transitionData._frames,o=t._transitionData._frameHash;for(r=0;r<e.length;r++)switch((n=e[r]).type){case\"replace\":i=n.value;var s=(a[n.index]||{}).name,l=i.name;a[n.index]=o[l]=i,l!==s&&(delete o[s],o[l]=i);break;case\"insert\":o[(i=n.value).name]=i,a.splice(n.index,0,i);break;case\"delete\":delete o[(i=a[n.index]).name],a.splice(n.index,1)}return Promise.resolve()},v.computeFrame=function(t,e){var r,n,i,a,o=t._transitionData._frameHash;if(!e)throw new Error(\"computeFrame must be given a string frame name\");var s=o[e.toString()];if(!s)return!1;for(var l=[s],c=[s.name];s.baseframe&&(s=o[s.baseframe.toString()])&&-1===c.indexOf(s.name);)l.push(s),c.push(s.name);for(var u={};s=l.pop();)if(s.layout&&(u.layout=v.extendLayout(u.layout,s.layout)),s.data){if(u.data||(u.data=[]),!(n=s.traces))for(n=[],r=0;r<s.data.length;r++)n[r]=r;for(u.traces||(u.traces=[]),r=0;r<s.data.length;r++)null!=(i=n[r])&&(-1===(a=u.traces.indexOf(i))&&(a=u.data.length,u.traces[a]=i),u.data[a]=v.extendTrace(u.data[a],s.data[r]))}return u},v.recomputeFrameHash=function(t){for(var e=t._transitionData._frameHash={},r=t._transitionData._frames,n=0;n<r.length;n++){var i=r[n];i&&i.name&&(e[i.name]=i)}},v.extendObjectWithContainers=function(t,e,r){var n,i,a,o,s,c,u,h=l.extendDeepNoArrays({},e||{}),f=l.expandObjectPaths(h),p={};if(r&&r.length)for(a=0;a<r.length;a++)void 0===(i=(n=l.nestedProperty(f,r[a])).get())?l.nestedProperty(p,r[a]).set(null):(n.set(null),l.nestedProperty(p,r[a]).set(i));if(t=l.extendDeepNoArrays(t||{},f),r&&r.length)for(a=0;a<r.length;a++)if(c=l.nestedProperty(p,r[a]).get()){for(u=(s=l.nestedProperty(t,r[a])).get(),Array.isArray(u)||(u=[],s.set(u)),o=0;o<c.length;o++){var d=c[o];u[o]=null===d?null:v.extendObjectWithContainers(u[o],d)}s.set(u)}return t},v.dataArrayContainers=[\"transforms\",\"dimensions\"],v.layoutArrayContainers=a.layoutArrayContainers,v.extendTrace=function(t,e){return v.extendObjectWithContainers(t,e,v.dataArrayContainers)},v.extendLayout=function(t,e){return v.extendObjectWithContainers(t,e,v.layoutArrayContainers)},v.transition=function(t,e,r,n,i,a){var o={redraw:i.redraw},s={},c=[];return o.prepareFn=function(){for(var i=Array.isArray(e)?e.length:0,a=n.slice(0,i),o=0;o<a.length;o++){var u=a[o],h=t._fullData[u]._module;if(h){if(h.animatable){var f=h.basePlotModule.name;s[f]||(s[f]=[]),s[f].push(u)}t.data[a[o]]=v.extendTrace(t.data[a[o]],e[o])}}var p=l.expandObjectPaths(l.extendDeepNoArrays({},r)),d=/^[xy]axis[0-9]*$/;for(var g in p)d.test(g)&&delete p[g].range;v.extendLayout(t.layout,p),delete t.calcdata,v.supplyDefaults(t),v.doCalcdata(t);var m=l.expandObjectPaths(r);if(m){var y=t._fullLayout._plots;for(var x in y){var b,_,w,k,T=y[x],A=T.xaxis,M=T.yaxis,S=A.range.slice(),E=M.range.slice();Array.isArray(m[A._name+\".range\"])?b=m[A._name+\".range\"].slice():Array.isArray((m[A._name]||{}).range)&&(b=m[A._name].range.slice()),Array.isArray(m[M._name+\".range\"])?_=m[M._name+\".range\"].slice():Array.isArray((m[M._name]||{}).range)&&(_=m[M._name].range.slice()),S&&b&&(S[0]!==b[0]||S[1]!==b[1])&&(w={xr0:S,xr1:b}),E&&_&&(E[0]!==_[0]||E[1]!==_[1])&&(k={yr0:E,yr1:_}),(w||k)&&c.push(l.extendFlat({plotinfo:T},w,k))}}return Promise.resolve()},o.runFn=function(e){var n,i,o=t._fullLayout._basePlotModules,u=c.length;if(r)for(i=0;i<o.length;i++)o[i].transitionAxes&&o[i].transitionAxes(t,c,a,e);for(var h in u?((n=l.extendFlat({},a)).duration=0,delete s.cartesian):n=a,s){var f=s[h];t._fullData[f[0]]._module.basePlotModule.plot(t,f,n,e)}},S(t,a,o)},v.transitionFromReact=function(t,e,r,n){var i=t._fullLayout,a=i.transition,o={},s=[];return o.prepareFn=function(){var t=i._plots;for(var a in o.redraw=!1,\"some\"===e.anim&&(o.redraw=!0),\"some\"===r.anim&&(o.redraw=!0),t){var c,u,h=t[a],f=h.xaxis,p=h.yaxis,d=n[f._name].range.slice(),g=n[p._name].range.slice(),v=f.range.slice(),m=p.range.slice();f.setScale(),p.setScale(),d[0]===v[0]&&d[1]===v[1]||(c={xr0:d,xr1:v}),g[0]===m[0]&&g[1]===m[1]||(u={yr0:g,yr1:m}),(c||u)&&s.push(l.extendFlat({plotinfo:h},c,u))}return Promise.resolve()},o.runFn=function(r){for(var n,i,o,c=t._fullData,u=t._fullLayout._basePlotModules,h=[],f=0;f<c.length;f++)h.push(f);function p(){for(var e=0;e<u.length;e++)u[e].transitionAxes&&u[e].transitionAxes(t,s,n,r)}function d(){for(var e=0;e<u.length;e++)u[e].plot(t,o,i,r)}s.length&&e.anim?\"traces first\"===a.ordering?(n=l.extendFlat({},a,{duration:0}),o=h,i=a,d(),setTimeout(p,a.duration)):(n=a,o=null,i=l.extendFlat({},a,{duration:0}),p(),d()):s.length?(n=a,p()):e.anim&&(o=h,i=a,d())},S(t,a,o)},v.doCalcdata=function(t,e){var r,n,i,s,c=h.list(t),f=t._fullData,p=t._fullLayout,d=new Array(f.length),g=(t.calcdata||[]).slice();for(t.calcdata=d,p._numBoxes=0,p._numViolins=0,p._violinScaleGroupStats={},t._hmpixcount=0,t._hmlumcount=0,p._piecolormap={},p._sunburstcolormap={},p._funnelareacolormap={},i=0;i<f.length;i++)Array.isArray(e)&&-1===e.indexOf(i)&&(d[i]=g[i]);for(i=0;i<f.length;i++)(r=f[i])._arrayAttrs=o.findArrayAttributes(r),r._extremes={};var v=p._subplots.polar||[];for(i=0;i<v.length;i++)c.push(p[v[i]].radialaxis,p[v[i]].angularaxis);var y=!1;function x(e){if(r=f[e],n=r._module,!0===r.visible&&r.transforms){if(n&&n.calc){var i=n.calc(t,r);i[0]&&i[0].t&&i[0].t._scene&&delete i[0].t._scene.dirty}for(s=0;s<r.transforms.length;s++){var a=r.transforms[s];(n=m[a.type])&&n.calcTransform&&(r._hasCalcTransform=!0,y=!0,n.calcTransform(t,r,a))}}}function b(e,i){if(r=f[e],!!(n=r._module).isContainer===i){var a=[];if(!0===r.visible&&0!==r._length){delete r._indexToPoints;var o=r.transforms||[];for(s=o.length-1;s>=0;s--)if(o[s].enabled){r._indexToPoints=o[s]._indexToPoints;break}n&&n.calc&&(a=n.calc(t,r))}Array.isArray(a)&&a[0]||(a=[{x:u,y:u}]),a[0].t||(a[0].t={}),a[0].trace=r,d[e]=a}}for(C(c,f),i=0;i<f.length;i++)b(i,!0);for(i=0;i<f.length;i++)x(i);for(y&&C(c,f),i=0;i<f.length;i++)b(i,!0);for(i=0;i<f.length;i++)b(i,!1);L(t);var _=function(t,e){var r,n,i,o,s,c=[];function u(t,r,n){var i=r._id.charAt(0);if(\"histogram2dcontour\"===t){var a=r._counterAxes[0],o=h.getFromId(e,a),s=\"x\"===i||\"x\"===a&&\"category\"===o.type,l=\"y\"===i||\"y\"===a&&\"category\"===o.type;return function(t,e){return 0===t||0===e?-1:s&&t===n[e].length-1?-1:l&&e===n.length-1?-1:(\"y\"===i?e:t)-1}}return function(t,e){return\"y\"===i?e:t}}var f={min:function(t){return l.aggNums(Math.min,null,t)},max:function(t){return l.aggNums(Math.max,null,t)},sum:function(t){return l.aggNums(function(t,e){return t+e},null,t)},total:function(t){return l.aggNums(function(t,e){return t+e},null,t)},mean:function(t){return l.mean(t)},median:function(t){return l.median(t)}};for(r=0;r<t.length;r++){var p=t[r];if(\"category\"===p.type){var d=p.categoryorder.match(E);if(d){var g=d[1],v=d[2],m=[];for(n=0;n<p._categories.length;n++)m.push([p._categories[n],[]]);for(n=0;n<p._traceIndices.length;n++){var y=p._traceIndices[n],x=e._fullData[y],b=p._id.charAt(0);if(!0===x.visible){var _=x.type;a.traceIs(x,\"histogram\")&&(delete x._xautoBinFinished,delete x._yautoBinFinished);var w=e.calcdata[y];for(i=0;i<w.length;i++){var k,T,A,M=w[i];if(\"splom\"===_){var S=x._axesDim[p._id];if(\"y\"===b){var C=x._diag[S][0];C&&(p=e._fullLayout[h.id2name(C)])}var L=M.trace.dimensions[S].values;for(o=0;o<L.length;o++)for(k=L[o],T=p._categoriesMap[k],s=0;s<M.trace.dimensions.length;s++)if(s!==S){var P=M.trace.dimensions[s];m[T][1].push(P.values[o])}}else if(\"scattergl\"===_){for(o=0;o<M.t.x.length;o++)\"x\"===b&&(k=M.t.x[o],T=k,A=M.t.y[o]),\"y\"===b&&(k=M.t.y[o],T=k,A=M.t.x[o]),m[T][1].push(A);M.t&&M.t._scene&&delete M.t._scene.dirty}else if(M.hasOwnProperty(\"z\")){A=M.z;var O=u(x.type,p,A);for(o=0;o<A.length;o++)for(s=0;s<A[o].length;s++)(T=O(s,o))+1&&m[T][1].push(A[o][s])}else for(\"x\"===b?(k=M.p+1?M.p:M.x,A=M.s||M.v||M.y):\"y\"===b&&(k=M.p+1?M.p:M.y,A=M.s||M.v||M.x),Array.isArray(A)||(A=[A]),o=0;o<A.length;o++)m[k][1].push(A[o])}}}p._categoriesValue=m;var z=[];for(n=0;n<m.length;n++)z.push([m[n][0],f[g](m[n][1])]);z.sort(function(t,e){return t[1]-e[1]}),p._categoriesAggregatedValue=z,p._initialCategories=z.map(function(t){return t[0]}),\"descending\"===v&&p._initialCategories.reverse(),c=c.concat(p.sortByInitialCategories())}}}return c}(c,t);if(_.length){for(p._numBoxes=0,p._numViolins=0,i=0;i<_.length;i++)b(_[i],!0);for(i=0;i<_.length;i++)b(_[i],!1);L(t)}a.getComponentMethod(\"fx\",\"calc\")(t),a.getComponentMethod(\"errorbars\",\"calc\")(t)};var E=/(total|sum|min|max|mean|median) (ascending|descending)/;function C(t,e){for(var r=0;r<t.length;r++){var n=t[r];n.clearCalc(),\"multicategory\"===n.type&&n.setupMultiCategory(e)}}function L(t){var e,r,n,i=t._fullLayout,a=i._visibleModules,o={};for(r=0;r<a.length;r++){var s=a[r],c=s.crossTraceCalc;if(c){var u=s.basePlotModule.name;o[u]?l.pushUnique(o[u],c):o[u]=[c]}}for(n in o){var h=o[n],f=i._subplots[n];if(Array.isArray(f))for(e=0;e<f.length;e++){var p=f[e],d=\"cartesian\"===n?i._plots[p]:i[p];for(r=0;r<h.length;r++)h[r](t,d,p)}else for(r=0;r<h.length;r++)h[r](t)}}v.rehover=function(t){t._fullLayout._rehover&&t._fullLayout._rehover()},v.redrag=function(t){t._fullLayout._redrag&&t._fullLayout._redrag()},v.generalUpdatePerTraceModule=function(t,e,r,n){var i,a=e.traceHash,o={};for(i=0;i<r.length;i++){var s=r[i],c=s[0].trace;c.visible&&(o[c.type]=o[c.type]||[],o[c.type].push(s))}for(var u in a)if(!o[u]){var h=a[u][0];h[0].trace.visible=!1,o[u]=[h]}for(var f in o){var p=o[f];p[0][0].trace._module.plot(t,e,l.filterVisible(p),n)}e.traceHash=o}},{\"../components/color\":593,\"../constants/numerical\":695,\"../lib\":719,\"../plot_api/plot_schema\":756,\"../plot_api/plot_template\":757,\"../registry\":847,\"./animation_attributes\":762,\"./attributes\":764,\"./cartesian/axis_ids\":770,\"./command\":791,\"./font_attributes\":793,\"./frame_attributes\":794,\"./layout_attributes\":819,d3:163,\"fast-isnumeric\":225}],829:[function(t,e,r){\"use strict\";e.exports={attr:\"subplot\",name:\"polar\",axisNames:[\"angularaxis\",\"radialaxis\"],axisName2dataArray:{angularaxis:\"theta\",radialaxis:\"r\"},layerNames:[\"draglayer\",\"plotbg\",\"backplot\",\"angular-grid\",\"radial-grid\",\"frontplot\",\"angular-line\",\"radial-line\",\"angular-axis\",\"radial-axis\"],radialDragBoxSize:50,angularDragBoxSize:30,cornerLen:25,cornerHalfWidth:2,MINDRAG:8,MINZOOM:20,OFFEDGE:20}},{}],830:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/polygon\").tester,a=n.findIndexOfMin,o=n.isAngleInsideSector,s=n.angleDelta,l=n.angleDist;function c(t,e,r,n){var i,a,o=n[0],s=n[1],l=h(Math.sin(e)-Math.sin(t)),c=h(Math.cos(e)-Math.cos(t)),u=Math.tan(r),f=h(1/u),p=l/c,d=s-p*o;return f?l&&c?a=u*(i=d/(u-p)):c?(i=s*f,a=s):(i=o,a=o*u):l&&c?(i=0,a=d):c?(i=0,a=s):i=a=NaN,[i,a]}function u(t,e,r,i){return n.isFullCircle([e,r])?function(t,e){var r,n=e.length,i=new Array(n+1);for(r=0;r<n;r++){var a=e[r];i[r]=[t*Math.cos(a),t*Math.sin(a)]}return i[r]=i[0].slice(),i}(t,i):function(t,e,r,i){var s,u,h=i.length,f=[];function p(e){return[t*Math.cos(e),t*Math.sin(e)]}function d(t,e,r){return c(t,e,r,p(t))}function g(t){return n.mod(t,h)}function v(t){return o(t,[e,r])}var m=a(i,function(t){return v(t)?l(t,e):1/0}),y=d(i[m],i[g(m-1)],e);for(f.push(y),s=m,u=0;u<h;s++,u++){var x=i[g(s)];if(!v(x))break;f.push(p(x))}var b=a(i,function(t){return v(t)?l(t,r):1/0}),_=d(i[b],i[g(b+1)],r);return f.push(_),f.push([0,0]),f.push(f[0].slice()),f}(t,e,r,i)}function h(t){return Math.abs(t)>1e-10?t:0}function f(t,e,r){e=e||0,r=r||0;for(var n=t.length,i=new Array(n),a=0;a<n;a++){var o=t[a];i[a]=[e+o[0],r-o[1]]}return i}e.exports={isPtInsidePolygon:function(t,e,r,n,a){if(!o(e,n))return!1;var s,l;r[0]<r[1]?(s=r[0],l=r[1]):(s=r[1],l=r[0]);var c=i(u(s,n[0],n[1],a)),h=i(u(l,n[0],n[1],a)),f=[t*Math.cos(e),t*Math.sin(e)];return h.contains(f)&&!c.contains(f)},findPolygonOffset:function(t,e,r,n){for(var i=1/0,a=1/0,o=u(t,e,r,n),s=0;s<o.length;s++){var l=o[s];i=Math.min(i,l[0]),a=Math.min(a,-l[1])}return[i,a]},findEnclosingVertexAngles:function(t,e){var r=a(e,function(e){var r=s(e,t);return r>0?r:1/0}),i=n.mod(r+1,e.length);return[e[r],e[i]]},findIntersectionXY:c,findXYatLength:function(t,e,r,n){var i=-e*r,a=e*e+1,o=2*(e*i-r),s=i*i+r*r-t*t,l=Math.sqrt(o*o-4*a*s),c=(-o+l)/(2*a),u=(-o-l)/(2*a);return[[c,e*c+i+n],[u,e*u+i+n]]},clampTiny:h,pathPolygon:function(t,e,r,n,i,a){return\"M\"+f(u(t,e,r,n),i,a).join(\"L\")},pathPolygonAnnulus:function(t,e,r,n,i,a,o){var s,l;t<e?(s=t,l=e):(s=e,l=t);var c=f(u(s,r,n,i),a,o);return\"M\"+f(u(l,r,n,i),a,o).reverse().join(\"L\")+\"M\"+c.join(\"L\")}}},{\"../../lib\":719,\"../../lib/polygon\":731}],831:[function(t,e,r){\"use strict\";var n=t(\"../get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./polar\"),o=t(\"./constants\"),s=o.attr,l=o.name,c=i(l),u={};u[s]={valType:\"subplotid\",dflt:l,editType:\"calc\"},e.exports={attr:s,name:l,idRoot:l,idRegex:c,attrRegex:c,attributes:u,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[l],o=0;o<i.length;o++){var s=i[o],c=n(r,l,s),u=e[s]._subplot;u||(u=a(t,s),e[s]._subplot=u),u.plot(c,e,t._promises)}},clean:function(t,e,r,n){for(var i=n._subplots[l]||[],a=n._has&&n._has(\"gl\"),o=e._has&&e._has(\"gl\"),s=a&&!o,c=0;c<i.length;c++){var u=i[c],h=n[u]._subplot;if(!e[u]&&h)for(var f in h.framework.remove(),h.layers[\"radial-axis-title\"].remove(),h.clipPaths)h.clipPaths[f].remove();s&&h._scene&&(h._scene.destroy(),h._scene=null)}},toSVG:t(\"../cartesian\").toSVG}},{\"../../lib\":719,\"../cartesian\":778,\"../get_data\":802,\"./constants\":829,\"./layout_attributes\":832,\"./layout_defaults\":833,\"./polar\":840}],832:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../cartesian/layout_attributes\"),a=t(\"../domain\").attributes,o=t(\"../../lib\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=s({color:i.color,showline:o({},i.showline,{dflt:!0}),linecolor:i.linecolor,linewidth:i.linewidth,showgrid:o({},i.showgrid,{dflt:!0}),gridcolor:i.gridcolor,gridwidth:i.gridwidth},\"plot\",\"from-root\"),c=s({tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,showtickprefix:i.showtickprefix,tickprefix:i.tickprefix,showticksuffix:i.showticksuffix,ticksuffix:i.ticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,separatethousands:i.separatethousands,tickfont:i.tickfont,tickangle:i.tickangle,tickformat:i.tickformat,tickformatstops:i.tickformatstops,layer:i.layer},\"plot\",\"from-root\"),u={visible:o({},i.visible,{dflt:!0}),type:o({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autorange:o({},i.autorange,{editType:\"plot\"}),rangemode:{valType:\"enumerated\",values:[\"tozero\",\"nonnegative\",\"normal\"],dflt:\"tozero\",editType:\"calc\"},range:o({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],editType:\"plot\"}),categoryorder:i.categoryorder,categoryarray:i.categoryarray,angle:{valType:\"angle\",editType:\"plot\"},side:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"clockwise\",editType:\"plot\"},title:s(i.title,\"plot\",\"from-root\"),hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}};u.title.text.dflt=\"\",o(u,l,c);var h={visible:o({},i.visible,{dflt:!0}),type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"category\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},categoryorder:i.categoryorder,categoryarray:i.categoryarray,thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\"],dflt:\"degrees\",editType:\"calc\"},period:{valType:\"number\",editType:\"calc\",min:0},direction:{valType:\"enumerated\",values:[\"counterclockwise\",\"clockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"angle\",editType:\"calc\"},hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"};o(h,l,c),e.exports={domain:a({name:\"polar\",editType:\"plot\"}),sector:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],dflt:[0,360],editType:\"plot\"},hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},bgcolor:{valType:\"color\",editType:\"plot\",dflt:n.background},radialaxis:u,angularaxis:h,gridshape:{valType:\"enumerated\",values:[\"circular\",\"linear\"],dflt:\"circular\",editType:\"plot\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"}},{\"../../components/color/attributes\":592,\"../../lib\":719,\"../../plot_api/edit_types\":750,\"../cartesian/layout_attributes\":779,\"../domain\":792}],833:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../subplot_defaults\"),s=t(\"../get_data\").getSubplotData,l=t(\"../cartesian/tick_value_defaults\"),c=t(\"../cartesian/tick_mark_defaults\"),u=t(\"../cartesian/tick_label_defaults\"),h=t(\"../cartesian/category_order_defaults\"),f=t(\"../cartesian/line_grid_defaults\"),p=t(\"../cartesian/axis_autotype\"),d=t(\"./layout_attributes\"),g=t(\"./set_convert\"),v=t(\"./constants\"),m=v.axisNames;function y(t,e,r,o){var p=r(\"bgcolor\");o.bgColor=i.combine(p,o.paper_bgcolor);var y=r(\"sector\");r(\"hole\");var b,_=s(o.fullData,v.name,o.id),w=o.layoutOut;function k(t,e){return r(b+\".\"+t,e)}for(var T=0;T<m.length;T++){b=m[T],n.isPlainObject(t[b])||(t[b]={});var A=t[b],M=a.newContainer(e,b);M._id=M._name=b,M._attr=o.id+\".\"+b,M._traceIndices=_.map(function(t){return t._expandedIndex});var S=v.axisName2dataArray[b],E=x(A,M,k,_,S);h(A,M,k,{axData:_,dataAttr:S});var C,L,P=k(\"visible\");switch(g(M,e,w),k(\"uirevision\",e.uirevision),P&&(L=(C=k(\"color\"))===A.color?C:o.font.color),M._m=1,b){case\"radialaxis\":var O=k(\"autorange\",!M.isValidRange(A.range));A.autorange=O,!O||\"linear\"!==E&&\"-\"!==E||k(\"rangemode\"),\"reversed\"===O&&(M._m=-1),k(\"range\"),M.cleanRange(\"range\",{dfltRange:[0,1]}),P&&(k(\"side\"),k(\"angle\",y[0]),k(\"title.text\"),n.coerceFont(k,\"title.font\",{family:o.font.family,size:Math.round(1.2*o.font.size),color:L}));break;case\"angularaxis\":if(\"date\"===E){n.log(\"Polar plots do not support date angular axes yet.\");for(var z=0;z<_.length;z++)_[z].visible=!1;E=A.type=M.type=\"linear\"}k(\"linear\"===E?\"thetaunit\":\"period\");var I=k(\"direction\");k(\"rotation\",{counterclockwise:0,clockwise:90}[I])}if(P)l(A,M,k,M.type),u(A,M,k,M.type,{tickSuffixDflt:\"degrees\"===M.thetaunit?\"\\xb0\":void 0}),c(A,M,k,{outerTicks:!0}),k(\"showticklabels\")&&(n.coerceFont(k,\"tickfont\",{family:o.font.family,size:o.font.size,color:L}),k(\"tickangle\"),k(\"tickformat\")),f(A,M,k,{dfltColor:C,bgColor:o.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:d[b]}),k(\"layer\");\"category\"!==E&&k(\"hoverformat\"),M._input=A}\"category\"===e.angularaxis.type&&r(\"gridshape\")}function x(t,e,r,n,i){if(\"-\"===r(\"type\")){for(var a,o=0;o<n.length;o++)if(n[o].visible){a=n[o];break}a&&a[i]&&(e.type=p(a[i],\"gregorian\")),\"-\"===e.type?e.type=\"linear\":t.type=e.type}return e.type}e.exports=function(t,e,r){o(t,e,r,{type:v.name,attributes:d,handleDefaults:y,font:e.font,paper_bgcolor:e.paper_bgcolor,fullData:r,layoutOut:e})}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../cartesian/axis_autotype\":768,\"../cartesian/category_order_defaults\":771,\"../cartesian/line_grid_defaults\":781,\"../cartesian/tick_label_defaults\":786,\"../cartesian/tick_mark_defaults\":787,\"../cartesian/tick_value_defaults\":788,\"../get_data\":802,\"../subplot_defaults\":842,\"./constants\":829,\"./layout_attributes\":832,\"./set_convert\":841}],834:[function(t,e,r){\"use strict\";var n=t(\"../../../traces/scatter/attributes\"),i=n.marker,a=t(\"../../../lib/extend\").extendFlat;[\"Area traces are deprecated!\",\"Please switch to the *barpolar* trace type.\"].join(\" \");e.exports={r:a({},n.r,{}),t:a({},n.t,{}),marker:{color:a({},i.color,{}),size:a({},i.size,{}),symbol:a({},i.symbol,{}),opacity:a({},i.opacity,{}),editType:\"calc\"}}},{\"../../../lib/extend\":710,\"../../../traces/scatter/attributes\":1112}],835:[function(t,e,r){\"use strict\";var n=t(\"../../cartesian/layout_attributes\"),i=t(\"../../../lib/extend\").extendFlat,a=t(\"../../../plot_api/edit_types\").overrideAll,o=[\"Legacy polar charts are deprecated!\",\"Please switch to *polar* subplots.\"].join(\" \"),s=i({},n.domain,{});function l(t,e){return i({},e,{showline:{valType:\"boolean\"},showticklabels:{valType:\"boolean\"},tickorientation:{valType:\"enumerated\",values:[\"horizontal\",\"vertical\"]},ticklen:{valType:\"number\",min:0},tickcolor:{valType:\"color\"},ticksuffix:{valType:\"string\"},endpadding:{valType:\"number\",description:o},visible:{valType:\"boolean\"}})}e.exports=a({radialaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},domain:s,orientation:{valType:\"number\"}}),angularaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\",dflt:0},{valType:\"number\",dflt:360}]},domain:s}),layout:{direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"]},orientation:{valType:\"angle\"}}},\"plot\",\"nested\")},{\"../../../lib/extend\":710,\"../../../plot_api/edit_types\":750,\"../../cartesian/layout_attributes\":779}],836:[function(t,e,r){\"use strict\";(e.exports=t(\"./micropolar\")).manager=t(\"./micropolar_manager\")},{\"./micropolar\":837,\"./micropolar_manager\":838}],837:[function(t,e,r){var n=t(\"d3\"),i=t(\"../../../lib\").extendDeepAll,a=t(\"../../../constants/alignment\").MID_SHIFT,o=e.exports={version:\"0.2.2\"};o.Axis=function(){var t,e,r,s,l={data:[],layout:{}},c={},u={},h=n.dispatch(\"hover\"),f={};return f.render=function(c){return function(c){e=c||e;var h=l.data,f=l.layout;(\"string\"==typeof e||e.nodeName)&&(e=n.select(e)),e.datum(h).each(function(e,l){var c=e.slice();u={data:o.util.cloneJson(c),layout:o.util.cloneJson(f)};var h=0;c.forEach(function(t,e){t.color||(t.color=f.defaultColorRange[h],h=(h+1)%f.defaultColorRange.length),t.strokeColor||(t.strokeColor=\"LinePlot\"===t.geometry?t.color:n.rgb(t.color).darker().toString()),u.data[e].color=t.color,u.data[e].strokeColor=t.strokeColor,u.data[e].strokeDash=t.strokeDash,u.data[e].strokeSize=t.strokeSize});var p=c.filter(function(t,e){var r=t.visible;return\"undefined\"==typeof r||!0===r}),d=!1,g=p.map(function(t,e){return d=d||\"undefined\"!=typeof t.groupId,t});if(d){var v=n.nest().key(function(t,e){return\"undefined\"!=typeof t.groupId?t.groupId:\"unstacked\"}).entries(g),m=[],y=v.map(function(t,e){if(\"unstacked\"===t.key)return t.values;var r=t.values[0].r.map(function(t,e){return 0});return t.values.forEach(function(t,e,n){t.yStack=[r],m.push(r),r=o.util.sumArrays(t.r,r)}),t.values});p=n.merge(y)}p.forEach(function(t,e){t.t=Array.isArray(t.t[0])?t.t:[t.t],t.r=Array.isArray(t.r[0])?t.r:[t.r]});var x=Math.min(f.width-f.margin.left-f.margin.right,f.height-f.margin.top-f.margin.bottom)/2;x=Math.max(10,x);var b,_=[f.margin.left+x,f.margin.top+x];b=d?[0,n.max(o.util.sumArrays(o.util.arrayLast(p).r[0],o.util.arrayLast(m)))]:n.extent(o.util.flattenArray(p.map(function(t,e){return t.r}))),f.radialAxis.domain!=o.DATAEXTENT&&(b[0]=0),r=n.scale.linear().domain(f.radialAxis.domain!=o.DATAEXTENT&&f.radialAxis.domain?f.radialAxis.domain:b).range([0,x]),u.layout.radialAxis.domain=r.domain();var w,k=o.util.flattenArray(p.map(function(t,e){return t.t})),T=\"string\"==typeof k[0];T&&(k=o.util.deduplicate(k),w=k.slice(),k=n.range(k.length),p=p.map(function(t,e){var r=t;return t.t=[k],d&&(r.yStack=t.yStack),r}));var A=p.filter(function(t,e){return\"LinePlot\"===t.geometry||\"DotPlot\"===t.geometry}).length===p.length,M=null===f.needsEndSpacing?T||!A:f.needsEndSpacing,S=f.angularAxis.domain&&f.angularAxis.domain!=o.DATAEXTENT&&!T&&f.angularAxis.domain[0]>=0?f.angularAxis.domain:n.extent(k),E=Math.abs(k[1]-k[0]);A&&!T&&(E=0);var C=S.slice();M&&T&&(C[1]+=E);var L=f.angularAxis.ticksCount||4;L>8&&(L=L/(L/8)+L%8),f.angularAxis.ticksStep&&(L=(C[1]-C[0])/L);var P=f.angularAxis.ticksStep||(C[1]-C[0])/(L*(f.minorTicks+1));w&&(P=Math.max(Math.round(P),1)),C[2]||(C[2]=P);var O=n.range.apply(this,C);if(O=O.map(function(t,e){return parseFloat(t.toPrecision(12))}),s=n.scale.linear().domain(C.slice(0,2)).range(\"clockwise\"===f.direction?[0,360]:[360,0]),u.layout.angularAxis.domain=s.domain(),u.layout.angularAxis.endPadding=M?E:0,\"undefined\"==typeof(t=n.select(this).select(\"svg.chart-root\"))||t.empty()){var z=(new DOMParser).parseFromString(\"<svg xmlns='http://www.w3.org/2000/svg' class='chart-root'>' + '<g class='outer-group'>' + '<g class='chart-group'>' + '<circle class='background-circle'></circle>' + '<g class='geometry-group'></g>' + '<g class='radial axis-group'>' + '<circle class='outside-circle'></circle>' + '</g>' + '<g class='angular axis-group'></g>' + '<g class='guides-group'><line></line><circle r='0'></circle></g>' + '</g>' + '<g class='legend-group'></g>' + '<g class='tooltips-group'></g>' + '<g class='title-group'><text></text></g>' + '</g>' + '</svg>\",\"application/xml\"),I=this.appendChild(this.ownerDocument.importNode(z.documentElement,!0));t=n.select(I)}t.select(\".guides-group\").style({\"pointer-events\":\"none\"}),t.select(\".angular.axis-group\").style({\"pointer-events\":\"none\"}),t.select(\".radial.axis-group\").style({\"pointer-events\":\"none\"});var D,R=t.select(\".chart-group\"),F={fill:\"none\",stroke:f.tickColor},B={\"font-size\":f.font.size,\"font-family\":f.font.family,fill:f.font.color,\"text-shadow\":[\"-1px 0px\",\"1px -1px\",\"-1px 1px\",\"1px 1px\"].map(function(t,e){return\" \"+t+\" 0 \"+f.font.outlineColor}).join(\",\")};if(f.showLegend){D=t.select(\".legend-group\").attr({transform:\"translate(\"+[x,f.margin.top]+\")\"}).style({display:\"block\"});var N=p.map(function(t,e){var r=o.util.cloneJson(t);return r.symbol=\"DotPlot\"===t.geometry?t.dotType||\"circle\":\"LinePlot\"!=t.geometry?\"square\":\"line\",r.visibleInLegend=\"undefined\"==typeof t.visibleInLegend||t.visibleInLegend,r.color=\"LinePlot\"===t.geometry?t.strokeColor:t.color,r});o.Legend().config({data:p.map(function(t,e){return t.name||\"Element\"+e}),legendConfig:i({},o.Legend.defaultConfig().legendConfig,{container:D,elements:N,reverseOrder:f.legend.reverseOrder})})();var j=D.node().getBBox();x=Math.min(f.width-j.width-f.margin.left-f.margin.right,f.height-f.margin.top-f.margin.bottom)/2,x=Math.max(10,x),_=[f.margin.left+x,f.margin.top+x],r.range([0,x]),u.layout.radialAxis.domain=r.domain(),D.attr(\"transform\",\"translate(\"+[_[0]+x,_[1]-x]+\")\")}else D=t.select(\".legend-group\").style({display:\"none\"});t.attr({width:f.width,height:f.height}).style({opacity:f.opacity}),R.attr(\"transform\",\"translate(\"+_+\")\").style({cursor:\"crosshair\"});var U=[(f.width-(f.margin.left+f.margin.right+2*x+(j?j.width:0)))/2,(f.height-(f.margin.top+f.margin.bottom+2*x))/2];if(U[0]=Math.max(0,U[0]),U[1]=Math.max(0,U[1]),t.select(\".outer-group\").attr(\"transform\",\"translate(\"+U+\")\"),f.title&&f.title.text){var V=t.select(\"g.title-group text\").style(B).text(f.title.text),q=V.node().getBBox();V.attr({x:_[0]-q.width/2,y:_[1]-x-20})}var H=t.select(\".radial.axis-group\");if(f.radialAxis.gridLinesVisible){var G=H.selectAll(\"circle.grid-circle\").data(r.ticks(5));G.enter().append(\"circle\").attr({class:\"grid-circle\"}).style(F),G.attr(\"r\",r),G.exit().remove()}H.select(\"circle.outside-circle\").attr({r:x}).style(F);var Y=t.select(\"circle.background-circle\").attr({r:x}).style({fill:f.backgroundColor,stroke:f.stroke});function W(t,e){return s(t)%360+f.orientation}if(f.radialAxis.visible){var X=n.svg.axis().scale(r).ticks(5).tickSize(5);H.call(X).attr({transform:\"rotate(\"+f.radialAxis.orientation+\")\"}),H.selectAll(\".domain\").style(F),H.selectAll(\"g>text\").text(function(t,e){return this.textContent+f.radialAxis.ticksSuffix}).style(B).style({\"text-anchor\":\"start\"}).attr({x:0,y:0,dx:0,dy:0,transform:function(t,e){return\"horizontal\"===f.radialAxis.tickOrientation?\"rotate(\"+-f.radialAxis.orientation+\") translate(\"+[0,B[\"font-size\"]]+\")\":\"translate(\"+[0,B[\"font-size\"]]+\")\"}}),H.selectAll(\"g>line\").style({stroke:\"black\"})}var Z=t.select(\".angular.axis-group\").selectAll(\"g.angular-tick\").data(O),J=Z.enter().append(\"g\").classed(\"angular-tick\",!0);Z.attr({transform:function(t,e){return\"rotate(\"+W(t)+\")\"}}).style({display:f.angularAxis.visible?\"block\":\"none\"}),Z.exit().remove(),J.append(\"line\").classed(\"grid-line\",!0).classed(\"major\",function(t,e){return e%(f.minorTicks+1)==0}).classed(\"minor\",function(t,e){return!(e%(f.minorTicks+1)==0)}).style(F),J.selectAll(\".minor\").style({stroke:f.minorTickColor}),Z.select(\"line.grid-line\").attr({x1:f.tickLength?x-f.tickLength:0,x2:x}).style({display:f.angularAxis.gridLinesVisible?\"block\":\"none\"}),J.append(\"text\").classed(\"axis-text\",!0).style(B);var K=Z.select(\"text.axis-text\").attr({x:x+f.labelOffset,dy:a+\"em\",transform:function(t,e){var r=W(t),n=x+f.labelOffset,i=f.angularAxis.tickOrientation;return\"horizontal\"==i?\"rotate(\"+-r+\" \"+n+\" 0)\":\"radial\"==i?r<270&&r>90?\"rotate(180 \"+n+\" 0)\":null:\"rotate(\"+(r<=180&&r>0?-90:90)+\" \"+n+\" 0)\"}}).style({\"text-anchor\":\"middle\",display:f.angularAxis.labelsVisible?\"block\":\"none\"}).text(function(t,e){return e%(f.minorTicks+1)!=0?\"\":w?w[t]+f.angularAxis.ticksSuffix:t+f.angularAxis.ticksSuffix}).style(B);f.angularAxis.rewriteTicks&&K.text(function(t,e){return e%(f.minorTicks+1)!=0?\"\":f.angularAxis.rewriteTicks(this.textContent,e)});var $=n.max(R.selectAll(\".angular-tick text\")[0].map(function(t,e){return t.getCTM().e+t.getBBox().width}));D.attr({transform:\"translate(\"+[x+$,f.margin.top]+\")\"});var Q=t.select(\"g.geometry-group\").selectAll(\"g\").size()>0,tt=t.select(\"g.geometry-group\").selectAll(\"g.geometry\").data(p);if(tt.enter().append(\"g\").attr({class:function(t,e){return\"geometry geometry\"+e}}),tt.exit().remove(),p[0]||Q){var et=[];p.forEach(function(t,e){var n={};n.radialScale=r,n.angularScale=s,n.container=tt.filter(function(t,r){return r==e}),n.geometry=t.geometry,n.orientation=f.orientation,n.direction=f.direction,n.index=e,et.push({data:t,geometryConfig:n})});var rt=n.nest().key(function(t,e){return\"undefined\"!=typeof t.data.groupId||\"unstacked\"}).entries(et),nt=[];rt.forEach(function(t,e){\"unstacked\"===t.key?nt=nt.concat(t.values.map(function(t,e){return[t]})):nt.push(t.values)}),nt.forEach(function(t,e){var r;r=Array.isArray(t)?t[0].geometryConfig.geometry:t.geometryConfig.geometry;var n=t.map(function(t,e){return i(o[r].defaultConfig(),t)});o[r]().config(n)()})}var it,at,ot=t.select(\".guides-group\"),st=t.select(\".tooltips-group\"),lt=o.tooltipPanel().config({container:st,fontSize:8})(),ct=o.tooltipPanel().config({container:st,fontSize:8})(),ut=o.tooltipPanel().config({container:st,hasTick:!0})();if(!T){var ht=ot.select(\"line\").attr({x1:0,y1:0,y2:0}).style({stroke:\"grey\",\"pointer-events\":\"none\"});R.on(\"mousemove.angular-guide\",function(t,e){var r=o.util.getMousePos(Y).angle;ht.attr({x2:-x,transform:\"rotate(\"+r+\")\"}).style({opacity:.5});var n=(r+180+360-f.orientation)%360;it=s.invert(n);var i=o.util.convertToCartesian(x+12,r+180);lt.text(o.util.round(it)).move([i[0]+_[0],i[1]+_[1]])}).on(\"mouseout.angular-guide\",function(t,e){ot.select(\"line\").style({opacity:0})})}var ft=ot.select(\"circle\").style({stroke:\"grey\",fill:\"none\"});R.on(\"mousemove.radial-guide\",function(t,e){var n=o.util.getMousePos(Y).radius;ft.attr({r:n}).style({opacity:.5}),at=r.invert(o.util.getMousePos(Y).radius);var i=o.util.convertToCartesian(n,f.radialAxis.orientation);ct.text(o.util.round(at)).move([i[0]+_[0],i[1]+_[1]])}).on(\"mouseout.radial-guide\",function(t,e){ft.style({opacity:0}),ut.hide(),lt.hide(),ct.hide()}),t.selectAll(\".geometry-group .mark\").on(\"mouseover.tooltip\",function(e,r){var i=n.select(this),a=this.style.fill,s=\"black\",l=this.style.opacity||1;if(i.attr({\"data-opacity\":l}),a&&\"none\"!==a){i.attr({\"data-fill\":a}),s=n.hsl(a).darker().toString(),i.style({fill:s,opacity:1});var c={t:o.util.round(e[0]),r:o.util.round(e[1])};T&&(c.t=w[e[0]]);var u=\"t: \"+c.t+\", r: \"+c.r,h=this.getBoundingClientRect(),f=t.node().getBoundingClientRect(),p=[h.left+h.width/2-U[0]-f.left,h.top+h.height/2-U[1]-f.top];ut.config({color:s}).text(u),ut.move(p)}else a=this.style.stroke||\"black\",i.attr({\"data-stroke\":a}),s=n.hsl(a).darker().toString(),i.style({stroke:s,opacity:1})}).on(\"mousemove.tooltip\",function(t,e){if(0!=n.event.which)return!1;n.select(this).attr(\"data-fill\")&&ut.show()}).on(\"mouseout.tooltip\",function(t,e){ut.hide();var r=n.select(this),i=r.attr(\"data-fill\");i?r.style({fill:i,opacity:r.attr(\"data-opacity\")}):r.style({stroke:r.attr(\"data-stroke\"),opacity:r.attr(\"data-opacity\")})})})}(c),this},f.config=function(t){if(!arguments.length)return l;var e=o.util.cloneJson(t);return e.data.forEach(function(t,e){l.data[e]||(l.data[e]={}),i(l.data[e],o.Axis.defaultConfig().data[0]),i(l.data[e],t)}),i(l.layout,o.Axis.defaultConfig().layout),i(l.layout,e.layout),this},f.getLiveConfig=function(){return u},f.getinputConfig=function(){return c},f.radialScale=function(t){return r},f.angularScale=function(t){return s},f.svg=function(){return t},n.rebind(f,h,\"on\"),f},o.Axis.defaultConfig=function(t,e){return{data:[{t:[1,2,3,4],r:[10,11,12,13],name:\"Line1\",geometry:\"LinePlot\",color:null,strokeDash:\"solid\",strokeColor:null,strokeSize:\"1\",visibleInLegend:!0,opacity:1}],layout:{defaultColorRange:n.scale.category10().range(),title:null,height:450,width:500,margin:{top:40,right:40,bottom:40,left:40},font:{size:12,color:\"gray\",outlineColor:\"white\",family:\"Tahoma, sans-serif\"},direction:\"clockwise\",orientation:0,labelOffset:10,radialAxis:{domain:null,orientation:-45,ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null},angularAxis:{domain:[0,360],ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,labelsVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null,ticksCount:null,ticksStep:null},minorTicks:0,tickLength:null,tickColor:\"silver\",minorTickColor:\"#eee\",backgroundColor:\"none\",needsEndSpacing:null,showLegend:!0,legend:{reverseOrder:!1},opacity:1}}},o.util={},o.DATAEXTENT=\"dataExtent\",o.AREA=\"AreaChart\",o.LINE=\"LinePlot\",o.DOT=\"DotPlot\",o.BAR=\"BarChart\",o.util._override=function(t,e){for(var r in t)r in e&&(e[r]=t[r])},o.util._extend=function(t,e){for(var r in t)e[r]=t[r]},o.util._rndSnd=function(){return 2*Math.random()-1+(2*Math.random()-1)+(2*Math.random()-1)},o.util.dataFromEquation2=function(t,e){var r=e||6;return n.range(0,360+r,r).map(function(e,r){var n=e*Math.PI/180;return[e,t(n)]})},o.util.dataFromEquation=function(t,e,r){var i=e||6,a=[],o=[];n.range(0,360+i,i).forEach(function(e,r){var n=e*Math.PI/180,i=t(n);a.push(e),o.push(i)});var s={t:a,r:o};return r&&(s.name=r),s},o.util.ensureArray=function(t,e){if(\"undefined\"==typeof t)return null;var r=[].concat(t);return n.range(e).map(function(t,e){return r[e]||r[0]})},o.util.fillArrays=function(t,e,r){return e.forEach(function(e,n){t[e]=o.util.ensureArray(t[e],r)}),t},o.util.cloneJson=function(t){return JSON.parse(JSON.stringify(t))},o.util.validateKeys=function(t,e){\"string\"==typeof e&&(e=e.split(\".\"));var r=e.shift();return t[r]&&(!e.length||objHasKeys(t[r],e))},o.util.sumArrays=function(t,e){return n.zip(t,e).map(function(t,e){return n.sum(t)})},o.util.arrayLast=function(t){return t[t.length-1]},o.util.arrayEqual=function(t,e){for(var r=Math.max(t.length,e.length,1);r-- >=0&&t[r]===e[r];);return-2===r},o.util.flattenArray=function(t){for(var e=[];!o.util.arrayEqual(e,t);)e=t,t=[].concat.apply([],t);return t},o.util.deduplicate=function(t){return t.filter(function(t,e,r){return r.indexOf(t)==e})},o.util.convertToCartesian=function(t,e){var r=e*Math.PI/180;return[t*Math.cos(r),t*Math.sin(r)]},o.util.round=function(t,e){var r=e||2,n=Math.pow(10,r);return Math.round(t*n)/n},o.util.getMousePos=function(t){var e=n.mouse(t.node()),r=e[0],i=e[1],a={};return a.x=r,a.y=i,a.pos=e,a.angle=180*(Math.atan2(i,r)+Math.PI)/Math.PI,a.radius=Math.sqrt(r*r+i*i),a},o.util.duplicatesCount=function(t){for(var e,r={},n={},i=0,a=t.length;i<a;i++)(e=t[i])in r?(r[e]++,n[e]=r[e]):r[e]=1;return n},o.util.duplicates=function(t){return Object.keys(o.util.duplicatesCount(t))},o.util.translator=function(t,e,r,n){if(n){var i=r.slice();r=e,e=i}var a=e.reduce(function(t,e){if(\"undefined\"!=typeof t)return t[e]},t);\"undefined\"!=typeof a&&(e.reduce(function(t,r,n){if(\"undefined\"!=typeof t)return n===e.length-1&&delete t[r],t[r]},t),r.reduce(function(t,e,n){return\"undefined\"==typeof t[e]&&(t[e]={}),n===r.length-1&&(t[e]=a),t[e]},t))},o.PolyChart=function(){var t=[o.PolyChart.defaultConfig()],e=n.dispatch(\"hover\"),r={solid:\"none\",dash:[5,2],dot:[2,5]};function a(){var e=t[0].geometryConfig,i=e.container;\"string\"==typeof i&&(i=n.select(i)),i.datum(t).each(function(t,i){var a=!!t[0].data.yStack,o=t.map(function(t,e){return a?n.zip(t.data.t[0],t.data.r[0],t.data.yStack[0]):n.zip(t.data.t[0],t.data.r[0])}),s=e.angularScale,l=e.radialScale.domain()[0],c={bar:function(r,i,a){var o=t[a].data,l=e.radialScale(r[1])-e.radialScale(0),c=e.radialScale(r[2]||0),u=o.barWidth;n.select(this).attr({class:\"mark bar\",d:\"M\"+[[l+c,-u/2],[l+c,u/2],[c,u/2],[c,-u/2]].join(\"L\")+\"Z\",transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0]))+\")\"}})}};c.dot=function(r,i,a){var o=r[2]?[r[0],r[1]+r[2]]:r,s=n.svg.symbol().size(t[a].data.dotSize).type(t[a].data.dotType)(r,i);n.select(this).attr({class:\"mark dot\",d:s,transform:function(t,r){var n,i,a,s=(n=function(t,r){var n=e.radialScale(t[1]),i=(e.angularScale(t[0])+e.orientation)*Math.PI/180;return{r:n,t:i}}(o),i=n.r*Math.cos(n.t),a=n.r*Math.sin(n.t),{x:i,y:a});return\"translate(\"+[s.x,s.y]+\")\"}})};var u=n.svg.line.radial().interpolate(t[0].data.lineInterpolation).radius(function(t){return e.radialScale(t[1])}).angle(function(t){return e.angularScale(t[0])*Math.PI/180});c.line=function(r,i,a){var s=r[2]?o[a].map(function(t,e){return[t[0],t[1]+t[2]]}):o[a];if(n.select(this).each(c.dot).style({opacity:function(e,r){return+t[a].data.dotVisible},fill:d.stroke(r,i,a)}).attr({class:\"mark dot\"}),!(i>0)){var l=n.select(this.parentNode).selectAll(\"path.line\").data([0]);l.enter().insert(\"path\"),l.attr({class:\"line\",d:u(s),transform:function(t,r){return\"rotate(\"+(e.orientation+90)+\")\"},\"pointer-events\":\"none\"}).style({fill:function(t,e){return d.fill(r,i,a)},\"fill-opacity\":0,stroke:function(t,e){return d.stroke(r,i,a)},\"stroke-width\":function(t,e){return d[\"stroke-width\"](r,i,a)},\"stroke-dasharray\":function(t,e){return d[\"stroke-dasharray\"](r,i,a)},opacity:function(t,e){return d.opacity(r,i,a)},display:function(t,e){return d.display(r,i,a)}})}};var h=e.angularScale.range(),f=Math.abs(h[1]-h[0])/o[0].length*Math.PI/180,p=n.svg.arc().startAngle(function(t){return-f/2}).endAngle(function(t){return f/2}).innerRadius(function(t){return e.radialScale(l+(t[2]||0))}).outerRadius(function(t){return e.radialScale(l+(t[2]||0))+e.radialScale(t[1])});c.arc=function(t,r,i){n.select(this).attr({class:\"mark arc\",d:p,transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0])+90)+\")\"}})};var d={fill:function(e,r,n){return t[n].data.color},stroke:function(e,r,n){return t[n].data.strokeColor},\"stroke-width\":function(e,r,n){return t[n].data.strokeSize+\"px\"},\"stroke-dasharray\":function(e,n,i){return r[t[i].data.strokeDash]},opacity:function(e,r,n){return t[n].data.opacity},display:function(e,r,n){return\"undefined\"==typeof t[n].data.visible||t[n].data.visible?\"block\":\"none\"}},g=n.select(this).selectAll(\"g.layer\").data(o);g.enter().append(\"g\").attr({class:\"layer\"});var v=g.selectAll(\"path.mark\").data(function(t,e){return t});v.enter().append(\"path\").attr({class:\"mark\"}),v.style(d).each(c[e.geometryType]),v.exit().remove(),g.exit().remove()})}return a.config=function(e){return arguments.length?(e.forEach(function(e,r){t[r]||(t[r]={}),i(t[r],o.PolyChart.defaultConfig()),i(t[r],e)}),this):t},a.getColorScale=function(){},n.rebind(a,e,\"on\"),a},o.PolyChart.defaultConfig=function(){return{data:{name:\"geom1\",t:[[1,2,3,4]],r:[[1,2,3,4]],dotType:\"circle\",dotSize:64,dotVisible:!1,barWidth:20,color:\"#ffa500\",strokeSize:1,strokeColor:\"silver\",strokeDash:\"solid\",opacity:1,index:0,visible:!0,visibleInLegend:!0},geometryConfig:{geometry:\"LinePlot\",geometryType:\"arc\",direction:\"clockwise\",orientation:0,container:\"body\",radialScale:null,angularScale:null,colorScale:n.scale.category20()}}},o.BarChart=function(){return o.PolyChart()},o.BarChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"bar\"}}},o.AreaChart=function(){return o.PolyChart()},o.AreaChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"arc\"}}},o.DotPlot=function(){return o.PolyChart()},o.DotPlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"dot\",dotType:\"circle\"}}},o.LinePlot=function(){return o.PolyChart()},o.LinePlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"line\"}}},o.Legend=function(){var t=o.Legend.defaultConfig(),e=n.dispatch(\"hover\");function r(){var e=t.legendConfig,a=t.data.map(function(t,r){return[].concat(t).map(function(t,n){var a=i({},e.elements[r]);return a.name=t,a.color=[].concat(e.elements[r].color)[n],a})}),o=n.merge(a);o=o.filter(function(t,r){return e.elements[r]&&(e.elements[r].visibleInLegend||\"undefined\"==typeof e.elements[r].visibleInLegend)}),e.reverseOrder&&(o=o.reverse());var s=e.container;(\"string\"==typeof s||s.nodeName)&&(s=n.select(s));var l=o.map(function(t,e){return t.color}),c=e.fontSize,u=null==e.isContinuous?\"number\"==typeof o[0]:e.isContinuous,h=u?e.height:c*o.length,f=s.classed(\"legend-group\",!0).selectAll(\"svg\").data([0]),p=f.enter().append(\"svg\").attr({width:300,height:h+c,xmlns:\"http://www.w3.org/2000/svg\",\"xmlns:xlink\":\"http://www.w3.org/1999/xlink\",version:\"1.1\"});p.append(\"g\").classed(\"legend-axis\",!0),p.append(\"g\").classed(\"legend-marks\",!0);var d=n.range(o.length),g=n.scale[u?\"linear\":\"ordinal\"]().domain(d).range(l),v=n.scale[u?\"linear\":\"ordinal\"]().domain(d)[u?\"range\":\"rangePoints\"]([0,h]);if(u){var m=f.select(\".legend-marks\").append(\"defs\").append(\"linearGradient\").attr({id:\"grad1\",x1:\"0%\",y1:\"0%\",x2:\"0%\",y2:\"100%\"}).selectAll(\"stop\").data(l);m.enter().append(\"stop\"),m.attr({offset:function(t,e){return e/(l.length-1)*100+\"%\"}}).style({\"stop-color\":function(t,e){return t}}),f.append(\"rect\").classed(\"legend-mark\",!0).attr({height:e.height,width:e.colorBandWidth,fill:\"url(#grad1)\"})}else{var y=f.select(\".legend-marks\").selectAll(\"path.legend-mark\").data(o);y.enter().append(\"path\").classed(\"legend-mark\",!0),y.attr({transform:function(t,e){return\"translate(\"+[c/2,v(e)+c/2]+\")\"},d:function(t,e){var r,i,a,o=t.symbol;return a=3*(i=c),\"line\"===(r=o)?\"M\"+[[-i/2,-i/12],[i/2,-i/12],[i/2,i/12],[-i/2,i/12]]+\"Z\":-1!=n.svg.symbolTypes.indexOf(r)?n.svg.symbol().type(r).size(a)():n.svg.symbol().type(\"square\").size(a)()},fill:function(t,e){return g(e)}}),y.exit().remove()}var x=n.svg.axis().scale(v).orient(\"right\"),b=f.select(\"g.legend-axis\").attr({transform:\"translate(\"+[u?e.colorBandWidth:c,c/2]+\")\"}).call(x);return b.selectAll(\".domain\").style({fill:\"none\",stroke:\"none\"}),b.selectAll(\"line\").style({fill:\"none\",stroke:u?e.textColor:\"none\"}),b.selectAll(\"text\").style({fill:e.textColor,\"font-size\":e.fontSize}).text(function(t,e){return o[e].name}),r}return r.config=function(e){return arguments.length?(i(t,e),this):t},n.rebind(r,e,\"on\"),r},o.Legend.defaultConfig=function(t,e){return{data:[\"a\",\"b\",\"c\"],legendConfig:{elements:[{symbol:\"line\",color:\"red\"},{symbol:\"square\",color:\"yellow\"},{symbol:\"diamond\",color:\"limegreen\"}],height:150,colorBandWidth:30,fontSize:12,container:\"body\",isContinuous:null,textColor:\"grey\",reverseOrder:!1}}},o.tooltipPanel=function(){var t,e,r,a={container:null,hasTick:!1,fontSize:12,color:\"white\",padding:5},s=\"tooltip-\"+o.tooltipPanel.uid++,l=10,c=function(){var n=(t=a.container.selectAll(\"g.\"+s).data([0])).enter().append(\"g\").classed(s,!0).style({\"pointer-events\":\"none\",display:\"none\"});return r=n.append(\"path\").style({fill:\"white\",\"fill-opacity\":.9}).attr({d:\"M0 0\"}),e=n.append(\"text\").attr({dx:a.padding+l,dy:.3*+a.fontSize}),c};return c.text=function(i){var o=n.hsl(a.color).l,s=o>=.5?\"#aaa\":\"white\",u=o>=.5?\"black\":\"white\",h=i||\"\";e.style({fill:u,\"font-size\":a.fontSize+\"px\"}).text(h);var f=a.padding,p=e.node().getBBox(),d={fill:a.color,stroke:s,\"stroke-width\":\"2px\"},g=p.width+2*f+l,v=p.height+2*f;return r.attr({d:\"M\"+[[l,-v/2],[l,-v/4],[a.hasTick?0:l,0],[l,v/4],[l,v/2],[g,v/2],[g,-v/2]].join(\"L\")+\"Z\"}).style(d),t.attr({transform:\"translate(\"+[l,-v/2+2*f]+\")\"}),t.style({display:\"block\"}),c},c.move=function(e){if(t)return t.attr({transform:\"translate(\"+[e[0],e[1]]+\")\"}).style({display:\"block\"}),c},c.hide=function(){if(t)return t.style({display:\"none\"}),c},c.show=function(){if(t)return t.style({display:\"block\"}),c},c.config=function(t){return i(a,t),c},c},o.tooltipPanel.uid=1,o.adapter={},o.adapter.plotly=function(){var t={convert:function(t,e){var r={};if(t.data&&(r.data=t.data.map(function(t,r){var n=i({},t);return[[n,[\"marker\",\"color\"],[\"color\"]],[n,[\"marker\",\"opacity\"],[\"opacity\"]],[n,[\"marker\",\"line\",\"color\"],[\"strokeColor\"]],[n,[\"marker\",\"line\",\"dash\"],[\"strokeDash\"]],[n,[\"marker\",\"line\",\"width\"],[\"strokeSize\"]],[n,[\"marker\",\"symbol\"],[\"dotType\"]],[n,[\"marker\",\"size\"],[\"dotSize\"]],[n,[\"marker\",\"barWidth\"],[\"barWidth\"]],[n,[\"line\",\"interpolation\"],[\"lineInterpolation\"]],[n,[\"showlegend\"],[\"visibleInLegend\"]]].forEach(function(t,r){o.util.translator.apply(null,t.concat(e))}),e||delete n.marker,e&&delete n.groupId,e?(\"LinePlot\"===n.geometry?(n.type=\"scatter\",!0===n.dotVisible?(delete n.dotVisible,n.mode=\"lines+markers\"):n.mode=\"lines\"):\"DotPlot\"===n.geometry?(n.type=\"scatter\",n.mode=\"markers\"):\"AreaChart\"===n.geometry?n.type=\"area\":\"BarChart\"===n.geometry&&(n.type=\"bar\"),delete n.geometry):(\"scatter\"===n.type?\"lines\"===n.mode?n.geometry=\"LinePlot\":\"markers\"===n.mode?n.geometry=\"DotPlot\":\"lines+markers\"===n.mode&&(n.geometry=\"LinePlot\",n.dotVisible=!0):\"area\"===n.type?n.geometry=\"AreaChart\":\"bar\"===n.type&&(n.geometry=\"BarChart\"),delete n.mode,delete n.type),n}),!e&&t.layout&&\"stack\"===t.layout.barmode)){var a=o.util.duplicates(r.data.map(function(t,e){return t.geometry}));r.data.forEach(function(t,e){var n=a.indexOf(t.geometry);-1!=n&&(r.data[e].groupId=n)})}if(t.layout){var s=i({},t.layout);if([[s,[\"plot_bgcolor\"],[\"backgroundColor\"]],[s,[\"showlegend\"],[\"showLegend\"]],[s,[\"radialaxis\"],[\"radialAxis\"]],[s,[\"angularaxis\"],[\"angularAxis\"]],[s.angularaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularaxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularaxis,[\"nticks\"],[\"ticksCount\"]],[s.angularaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularaxis,[\"range\"],[\"domain\"]],[s.angularaxis,[\"endpadding\"],[\"endPadding\"]],[s.radialaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialaxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularAxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularAxis,[\"nticks\"],[\"ticksCount\"]],[s.angularAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularAxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"endpadding\"],[\"endPadding\"]],[s.radialAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialAxis,[\"range\"],[\"domain\"]],[s.font,[\"outlinecolor\"],[\"outlineColor\"]],[s.legend,[\"traceorder\"],[\"reverseOrder\"]],[s,[\"labeloffset\"],[\"labelOffset\"]],[s,[\"defaultcolorrange\"],[\"defaultColorRange\"]]].forEach(function(t,r){o.util.translator.apply(null,t.concat(e))}),e?(\"undefined\"!=typeof s.tickLength&&(s.angularaxis.ticklen=s.tickLength,delete s.tickLength),s.tickColor&&(s.angularaxis.tickcolor=s.tickColor,delete s.tickColor)):(s.angularAxis&&\"undefined\"!=typeof s.angularAxis.ticklen&&(s.tickLength=s.angularAxis.ticklen),s.angularAxis&&\"undefined\"!=typeof s.angularAxis.tickcolor&&(s.tickColor=s.angularAxis.tickcolor)),s.legend&&\"boolean\"!=typeof s.legend.reverseOrder&&(s.legend.reverseOrder=\"normal\"!=s.legend.reverseOrder),s.legend&&\"boolean\"==typeof s.legend.traceorder&&(s.legend.traceorder=s.legend.traceorder?\"reversed\":\"normal\",delete s.legend.reverseOrder),s.margin&&\"undefined\"!=typeof s.margin.t){var l=[\"t\",\"r\",\"b\",\"l\",\"pad\"],c=[\"top\",\"right\",\"bottom\",\"left\",\"pad\"],u={};n.entries(s.margin).forEach(function(t,e){u[c[l.indexOf(t.key)]]=t.value}),s.margin=u}e&&(delete s.needsEndSpacing,delete s.minorTickColor,delete s.minorTicks,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksStep,delete s.angularaxis.rewriteTicks,delete s.angularaxis.nticks,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksStep,delete s.radialaxis.rewriteTicks,delete s.radialaxis.nticks),r.layout=s}return r}};return t}},{\"../../../constants/alignment\":688,\"../../../lib\":719,d3:163}],838:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../../lib\"),a=t(\"../../../components/color\"),o=t(\"./micropolar\"),s=t(\"./undo_manager\"),l=i.extendDeepAll,c=e.exports={};c.framework=function(t){var e,r,i,a,u,h=new s;function f(r,s){return s&&(u=s),n.select(n.select(u).node().parentNode).selectAll(\".svg-container>*:not(.chart-root)\").remove(),e=e?l(e,r):r,i||(i=o.Axis()),a=o.adapter.plotly().convert(e),i.config(a).render(u),t.data=e.data,t.layout=e.layout,c.fillLayout(t),e}return f.isPolar=!0,f.svg=function(){return i.svg()},f.getConfig=function(){return e},f.getLiveConfig=function(){return o.adapter.plotly().convert(i.getLiveConfig(),!0)},f.getLiveScales=function(){return{t:i.angularScale(),r:i.radialScale()}},f.setUndoPoint=function(){var t,n,i=this,a=o.util.cloneJson(e);t=a,n=r,h.add({undo:function(){n&&i(n)},redo:function(){i(t)}}),r=o.util.cloneJson(a)},f.undo=function(){h.undo()},f.redo=function(){h.redo()},f},c.fillLayout=function(t){var e=n.select(t).selectAll(\".plot-container\"),r=e.selectAll(\".svg-container\"),i=t.framework&&t.framework.svg&&t.framework.svg(),o={width:800,height:600,paper_bgcolor:a.background,_container:e,_paperdiv:r,_paper:i};t._fullLayout=l(o,t.layout)}},{\"../../../components/color\":593,\"../../../lib\":719,\"./micropolar\":837,\"./undo_manager\":839,d3:163}],839:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=[],r=-1,n=!1;function i(t,e){return t?(n=!0,t[e](),n=!1,this):this}return{add:function(t){return n?this:(e.splice(r+1,e.length-r),e.push(t),r=e.length-1,this)},setCallback:function(e){t=e},undo:function(){var n=e[r];return n?(i(n,\"undo\"),r-=1,t&&t(n.undo),this):this},redo:function(){var n=e[r+1];return n?(i(n,\"redo\"),r+=1,t&&t(n.redo),this):this},clear:function(){e=[],r=-1},hasUndo:function(){return-1!==r},hasRedo:function(){return r<e.length-1},getCommands:function(){return e},getPreviousCommand:function(){return e[r-1]},getIndex:function(){return r}}}},{}],840:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../plots\"),u=t(\"../../plots/cartesian/axes\"),h=t(\"../cartesian/set_convert\"),f=t(\"./set_convert\"),p=t(\"../cartesian/autorange\").doAutoRange,d=t(\"../cartesian/dragbox\"),g=t(\"../../components/dragelement\"),v=t(\"../../components/fx\"),m=t(\"../../components/titles\"),y=t(\"../cartesian/select\").prepSelect,x=t(\"../cartesian/select\").selectOnClick,b=t(\"../cartesian/select\").clearSelect,_=t(\"../../lib/setcursor\"),w=t(\"../../lib/clear_gl_canvases\"),k=t(\"../../plot_api/subroutines\").redrawReglTraces,T=t(\"../../constants/alignment\").MID_SHIFT,A=t(\"./constants\"),M=t(\"./helpers\"),S=o._,E=o.mod,C=o.deg2rad,L=o.rad2deg;function P(t,e){this.id=e,this.gd=t,this._hasClipOnAxisFalse=null,this.vangles=null,this.radialAxisAngle=null,this.traceHash={},this.layers={},this.clipPaths={},this.clipIds={},this.viewInitial={};var r=t._fullLayout,n=\"clip\"+r._uid+e;this.clipIds.forTraces=n+\"-for-traces\",this.clipPaths.forTraces=r._clips.append(\"clipPath\").attr(\"id\",this.clipIds.forTraces),this.clipPaths.forTraces.append(\"path\"),this.framework=r._polarlayer.append(\"g\").attr(\"class\",e),this.radialTickLayout=null,this.angularTickLayout=null}var O=P.prototype;function z(t){var e=t.ticks+String(t.ticklen)+String(t.showticklabels);return\"side\"in t&&(e+=t.side),e}function I(t,e){return e[o.findIndexOfMin(e,function(e){return o.angleDist(t,e)})]}function D(t,e,r){return e?(t.attr(\"display\",null),t.attr(r)):t&&t.attr(\"display\",\"none\"),t}function R(t,e){return\"translate(\"+t+\",\"+e+\")\"}function F(t){return\"rotate(\"+t+\")\"}e.exports=function(t,e){return new P(t,e)},O.plot=function(t,e){var r=e[this.id];this._hasClipOnAxisFalse=!1;for(var n=0;n<t.length;n++){if(!1===t[n][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(e,r),this.updateLayout(e,r),c.generalUpdatePerTraceModule(this.gd,this,t,r),this.updateFx(e,r)},O.updateLayers=function(t,e){var r=this.layers,i=e.radialaxis,a=e.angularaxis,o=A.layerNames,s=o.indexOf(\"frontplot\"),l=o.slice(0,s),c=\"below traces\"===a.layer,u=\"below traces\"===i.layer;c&&l.push(\"angular-line\"),u&&l.push(\"radial-line\"),c&&l.push(\"angular-axis\"),u&&l.push(\"radial-axis\"),l.push(\"frontplot\"),c||l.push(\"angular-line\"),u||l.push(\"radial-line\"),c||l.push(\"angular-axis\"),u||l.push(\"radial-axis\");var h=this.framework.selectAll(\".polarsublayer\").data(l,String);h.enter().append(\"g\").attr(\"class\",function(t){return\"polarsublayer \"+t}).each(function(t){var e=r[t]=n.select(this);switch(t){case\"frontplot\":e.append(\"g\").classed(\"barlayer\",!0),e.append(\"g\").classed(\"scatterlayer\",!0);break;case\"backplot\":e.append(\"g\").classed(\"maplayer\",!0);break;case\"plotbg\":r.bg=e.append(\"path\");break;case\"radial-grid\":case\"angular-grid\":e.style(\"fill\",\"none\");break;case\"radial-line\":e.append(\"line\").style(\"fill\",\"none\");break;case\"angular-line\":e.append(\"path\").style(\"fill\",\"none\")}}),h.order()},O.updateLayout=function(t,e){var r=this.layers,n=t._size,i=e.radialaxis,a=e.angularaxis,o=e.domain.x,c=e.domain.y;this.xOffset=n.l+n.w*o[0],this.yOffset=n.t+n.h*(1-c[1]);var u=this.xLength=n.w*(o[1]-o[0]),h=this.yLength=n.h*(c[1]-c[0]),f=e.sector;this.sectorInRad=f.map(C);var p,d,g,v,m,y=this.sectorBBox=function(t){var e,r,n,i,a=t[0],o=t[1]-a,s=E(a,360),l=s+o,c=Math.cos(C(s)),u=Math.sin(C(s)),h=Math.cos(C(l)),f=Math.sin(C(l));i=s<=90&&l>=90||s>90&&l>=450?1:u<=0&&f<=0?0:Math.max(u,f);e=s<=180&&l>=180||s>180&&l>=540?-1:c>=0&&h>=0?0:Math.min(c,h);r=s<=270&&l>=270||s>270&&l>=630?-1:u>=0&&f>=0?0:Math.min(u,f);n=l>=360?1:c<=0&&h<=0?0:Math.max(c,h);return[e,r,n,i]}(f),x=y[2]-y[0],b=y[3]-y[1],_=h/u,w=Math.abs(b/x);_>w?(p=u,m=(h-(d=u*w))/n.h/2,g=[o[0],o[1]],v=[c[0]+m,c[1]-m]):(d=h,m=(u-(p=h/w))/n.w/2,g=[o[0]+m,o[1]-m],v=[c[0],c[1]]),this.xLength2=p,this.yLength2=d,this.xDomain2=g,this.yDomain2=v;var k=this.xOffset2=n.l+n.w*g[0],T=this.yOffset2=n.t+n.h*(1-v[1]),A=this.radius=p/x,M=this.innerRadius=e.hole*A,S=this.cx=k-A*y[0],L=this.cy=T+A*y[3],P=this.cxx=S-k,O=this.cyy=L-T;this.radialAxis=this.mockAxis(t,e,i,{_id:\"x\",side:{counterclockwise:\"top\",clockwise:\"bottom\"}[i.side],domain:[M/n.w,A/n.w]}),this.angularAxis=this.mockAxis(t,e,a,{side:\"right\",domain:[0,Math.PI],autorange:!1}),this.doAutoRange(t,e),this.updateAngularAxis(t,e),this.updateRadialAxis(t,e),this.updateRadialAxisTitle(t,e),this.xaxis=this.mockCartesianAxis(t,e,{_id:\"x\",domain:g}),this.yaxis=this.mockCartesianAxis(t,e,{_id:\"y\",domain:v});var z=this.pathSubplot();this.clipPaths.forTraces.select(\"path\").attr(\"d\",z).attr(\"transform\",R(P,O)),r.frontplot.attr(\"transform\",R(k,T)).call(l.setClipUrl,this._hasClipOnAxisFalse?null:this.clipIds.forTraces,this.gd),r.bg.attr(\"d\",z).attr(\"transform\",R(S,L)).call(s.fill,e.bgcolor)},O.mockAxis=function(t,e,r,n){var i=o.extendFlat({anchor:\"free\",position:0},r,n);return f(i,e,t),i},O.mockCartesianAxis=function(t,e,r){var n=this,i=r._id,a=o.extendFlat({type:\"linear\"},r);h(a,t);var s={x:[0,2],y:[1,3]};return a.setRange=function(){var t=n.sectorBBox,r=s[i],o=n.radialAxis._rl,l=(o[1]-o[0])/(1-e.hole);a.range=[t[r[0]]*l,t[r[1]]*l]},a.isPtWithinRange=\"x\"===i?function(t){return n.isPtInside(t)}:function(){return!0},a.setRange(),a.setScale(),a},O.doAutoRange=function(t,e){var r=this.gd,n=this.radialAxis,i=e.radialaxis;n.setScale(),p(r,n);var a=n.range;i.range=a.slice(),i._input.range=a.slice(),n._rl=[n.r2l(a[0],null,\"gregorian\"),n.r2l(a[1],null,\"gregorian\")]},O.updateRadialAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,l=r.innerRadius,c=r.cx,h=r.cy,f=e.radialaxis,p=E(e.sector[0],360),d=r.radialAxis,g=l<a;r.fillViewInitialKey(\"radialaxis.angle\",f.angle),r.fillViewInitialKey(\"radialaxis.range\",d.range.slice()),d.setGeometry(),\"auto\"===d.tickangle&&p>90&&p<=270&&(d.tickangle=180);var v=function(t){return\"translate(\"+(d.l2p(t.x)+l)+\",0)\"},m=z(f);if(r.radialTickLayout!==m&&(i[\"radial-axis\"].selectAll(\".xtick\").remove(),r.radialTickLayout=m),g){d.setScale();var y=u.calcTicks(d),x=u.clipEnds(d,y),b=u.getTickSigns(d)[2];u.drawTicks(n,d,{vals:y,layer:i[\"radial-axis\"],path:u.makeTickPath(d,0,b),transFn:v,crisp:!1}),u.drawGrid(n,d,{vals:x,layer:i[\"radial-grid\"],path:function(t){return r.pathArc(d.r2p(t.x)+l)},transFn:o.noop,crisp:!1}),u.drawLabels(n,d,{vals:y,layer:i[\"radial-axis\"],transFn:v,labelFns:u.makeLabelFns(d,0)})}var _=r.radialAxisAngle=r.vangles?L(I(C(f.angle),r.vangles)):f.angle,w=R(c,h),k=w+F(-_);D(i[\"radial-axis\"],g&&(f.showticklabels||f.ticks),{transform:k}),D(i[\"radial-grid\"],g&&f.showgrid,{transform:w}),D(i[\"radial-line\"].select(\"line\"),g&&f.showline,{x1:l,y1:0,x2:a,y2:0,transform:k}).attr(\"stroke-width\",f.linewidth).call(s.stroke,f.linecolor)},O.updateRadialAxisTitle=function(t,e,r){var n=this.gd,i=this.radius,a=this.cx,o=this.cy,s=e.radialaxis,c=this.id+\"title\",u=void 0!==r?r:this.radialAxisAngle,h=C(u),f=Math.cos(h),p=Math.sin(h),d=0;if(s.title){var g=l.bBox(this.layers[\"radial-axis\"].node()).height,v=s.title.font.size;d=\"counterclockwise\"===s.side?-g-.4*v:g+.8*v}this.layers[\"radial-axis-title\"]=m.draw(n,c,{propContainer:s,propName:this.id+\".radialaxis.title\",placeholder:S(n,\"Click to enter radial axis title\"),attributes:{x:a+i/2*f+d*p,y:o-i/2*p+d*f,\"text-anchor\":\"middle\"},transform:{rotate:-u}})},O.updateAngularAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,l=r.innerRadius,c=r.cx,h=r.cy,f=e.angularaxis,p=r.angularAxis;r.fillViewInitialKey(\"angularaxis.rotation\",f.rotation),p.setGeometry(),p.setScale();var d=function(t){return p.t2g(t.x)};\"linear\"===p.type&&\"radians\"===p.thetaunit&&(p.tick0=L(p.tick0),p.dtick=L(p.dtick));var g=function(t){return R(c+a*Math.cos(t),h-a*Math.sin(t))},v=u.makeLabelFns(p,0).labelStandoff,m={xFn:function(t){var e=d(t);return Math.cos(e)*v},yFn:function(t){var e=d(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(v+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*T)},anchorFn:function(t){var e=d(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},heightFn:function(t,e,r){var n=d(t);return-.5*(1+Math.sin(n))*r}},y=z(f);r.angularTickLayout!==y&&(i[\"angular-axis\"].selectAll(\".\"+p._id+\"tick\").remove(),r.angularTickLayout=y);var x,b=u.calcTicks(p);if(\"linear\"===e.gridshape?(x=b.map(d),o.angleDelta(x[0],x[1])<0&&(x=x.slice().reverse())):x=null,r.vangles=x,\"category\"===p.type&&(b=b.filter(function(t){return o.isAngleInsideSector(d(t),r.sectorInRad)})),p.visible){var _=\"inside\"===p.ticks?-1:1,w=(p.linewidth||1)/2;u.drawTicks(n,p,{vals:b,layer:i[\"angular-axis\"],path:\"M\"+_*w+\",0h\"+_*p.ticklen,transFn:function(t){var e=d(t);return g(e)+F(-L(e))},crisp:!1}),u.drawGrid(n,p,{vals:b,layer:i[\"angular-grid\"],path:function(t){var e=d(t),r=Math.cos(e),n=Math.sin(e);return\"M\"+[c+l*r,h-l*n]+\"L\"+[c+a*r,h-a*n]},transFn:o.noop,crisp:!1}),u.drawLabels(n,p,{vals:b,layer:i[\"angular-axis\"],repositionOnUpdate:!0,transFn:function(t){return g(d(t))},labelFns:m})}D(i[\"angular-line\"].select(\"path\"),f.showline,{d:r.pathSubplot(),transform:R(c,h)}).attr(\"stroke-width\",f.linewidth).call(s.stroke,f.linecolor)},O.updateFx=function(t,e){this.gd._context.staticPlot||(this.updateAngularDrag(t),this.updateRadialDrag(t,e,0),this.updateRadialDrag(t,e,1),this.updateMainDrag(t))},O.updateMainDrag=function(t){var e=this,r=e.gd,o=e.layers,s=t._zoomlayer,l=A.MINZOOM,c=A.OFFEDGE,u=e.radius,h=e.innerRadius,f=e.cx,p=e.cy,m=e.cxx,_=e.cyy,w=e.sectorInRad,k=e.vangles,T=e.radialAxis,S=M.clampTiny,E=M.findXYatLength,C=M.findEnclosingVertexAngles,L=A.cornerHalfWidth,P=A.cornerLen/2,O=d.makeDragger(o,\"path\",\"maindrag\",\"crosshair\");n.select(O).attr(\"d\",e.pathSubplot()).attr(\"transform\",R(f,p));var z,I,D,F,B,N,j,U,V,q={element:O,gd:r,subplot:e.id,plotinfo:{id:e.id,xaxis:e.xaxis,yaxis:e.yaxis},xaxes:[e.xaxis],yaxes:[e.yaxis]};function H(t,e){return Math.sqrt(t*t+e*e)}function G(t,e){return H(t-m,e-_)}function Y(t,e){return Math.atan2(_-e,t-m)}function W(t,e){return[t*Math.cos(e),t*Math.sin(-e)]}function X(t,r){if(0===t)return e.pathSector(2*L);var n=P/t,i=r-n,a=r+n,o=Math.max(0,Math.min(t,u)),s=o-L,l=o+L;return\"M\"+W(s,i)+\"A\"+[s,s]+\" 0,0,0 \"+W(s,a)+\"L\"+W(l,a)+\"A\"+[l,l]+\" 0,0,1 \"+W(l,i)+\"Z\"}function Z(t,r,n){if(0===t)return e.pathSector(2*L);var i,a,o=W(t,r),s=W(t,n),l=S((o[0]+s[0])/2),c=S((o[1]+s[1])/2);if(l&&c){var u=c/l,h=-1/u,f=E(L,u,l,c);i=E(P,h,f[0][0],f[0][1]),a=E(P,h,f[1][0],f[1][1])}else{var p,d;c?(p=P,d=L):(p=L,d=P),i=[[l-p,c-d],[l+p,c-d]],a=[[l-p,c+d],[l+p,c+d]]}return\"M\"+i.join(\"L\")+\"L\"+a.reverse().join(\"L\")+\"Z\"}function J(t,e){return e=Math.max(Math.min(e,u),h),t<c?t=0:u-t<c?t=u:e<c?e=0:u-e<c&&(e=u),Math.abs(e-t)>l?(t<e?(D=t,F=e):(D=e,F=t),!0):(D=null,F=null,!1)}function K(t,e){t=t||B,e=e||\"M0,0Z\",U.attr(\"d\",t),V.attr(\"d\",e),d.transitionZoombox(U,V,N,j),N=!0;var n={};rt(n),r.emit(\"plotly_relayouting\",n)}function $(t,r){var n,i,a=z+t,o=I+r,s=G(z,I),l=Math.min(G(a,o),u),c=Y(z,I);J(s,l)&&(n=B+e.pathSector(F),D&&(n+=e.pathSector(D)),i=X(D,c)+X(F,c)),K(n,i)}function Q(t,e,r,n){var i=M.findIntersectionXY(r,n,r,[t-m,_-e]);return H(i[0],i[1])}function tt(t,r){var n,i,a=z+t,o=I+r,s=Y(z,I),l=Y(a,o),c=C(s,k),h=C(l,k);J(Q(z,I,c[0],c[1]),Math.min(Q(a,o,h[0],h[1]),u))&&(n=B+e.pathSector(F),D&&(n+=e.pathSector(D)),i=[Z(D,c[0],c[1]),Z(F,c[0],c[1])].join(\" \")),K(n,i)}function et(){if(d.removeZoombox(r),null!==D&&null!==F){var t={};rt(t),d.showDoubleClickNotifier(r),a.call(\"_guiRelayout\",r,t)}}function rt(t){var r=T._rl,n=(r[1]-r[0])/(1-h/u)/u,i=[r[0]+(D-h)*n,r[0]+(F-h)*n];t[e.id+\".radialaxis.range\"]=i}function nt(t,n){var i=r._fullLayout.clickmode;if(d.removeZoombox(r),2===t){var o={};for(var s in e.viewInitial)o[e.id+\".\"+s]=e.viewInitial[s];r.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",r,o)}i.indexOf(\"select\")>-1&&1===t&&x(n,r,[e.xaxis],[e.yaxis],e.id,q),i.indexOf(\"event\")>-1&&v.click(r,n,e.id)}q.prepFn=function(t,n,a){var o=r._fullLayout.dragmode,l=O.getBoundingClientRect();if(z=n-l.left,I=a-l.top,k){var c=M.findPolygonOffset(u,w[0],w[1],k);z+=m+c[0],I+=_+c[1]}switch(o){case\"zoom\":q.moveFn=k?tt:$,q.clickFn=nt,q.doneFn=et,function(){D=null,F=null,B=e.pathSubplot(),N=!1;var t=r._fullLayout[e.id];j=i(t.bgcolor).getLuminance(),(U=d.makeZoombox(s,j,f,p,B)).attr(\"fill-rule\",\"evenodd\"),V=d.makeCorners(s,f,p),b(r)}();break;case\"select\":case\"lasso\":y(t,n,a,q,o)}},O.onmousemove=function(t){v.hover(r,t,e.id),r._fullLayout._lasthover=O,r._fullLayout._hoversubplot=e.id},O.onmouseout=function(t){r._dragging||g.unhover(r,t)},g.init(q)},O.updateRadialDrag=function(t,e,r){var i=this,s=i.gd,l=i.layers,c=i.radius,u=i.innerRadius,h=i.cx,f=i.cy,p=i.radialAxis,v=A.radialDragBoxSize,m=v/2;if(p.visible){var y,x,_,T=C(i.radialAxisAngle),M=p._rl,S=M[0],E=M[1],P=M[r],O=.75*(M[1]-M[0])/(1-e.hole)/c;r?(y=h+(c+m)*Math.cos(T),x=f-(c+m)*Math.sin(T),_=\"radialdrag\"):(y=h+(u-m)*Math.cos(T),x=f-(u-m)*Math.sin(T),_=\"radialdrag-inner\");var z,B,N,j=d.makeRectDragger(l,_,\"crosshair\",-m,-m,v,v),U={element:j,gd:s};D(n.select(j),p.visible&&u<c,{transform:R(y,x)}),U.prepFn=function(){z=null,B=null,N=null,U.moveFn=V,U.doneFn=q,b(s)},U.clampFn=function(t,e){return Math.sqrt(t*t+e*e)<A.MINDRAG&&(t=0,e=0),[t,e]},g.init(U)}function V(t,e){if(z)z(t,e);else{var n=[t,-e],a=[Math.cos(T),Math.sin(T)],l=Math.abs(o.dot(n,a)/Math.sqrt(o.dot(n,n)));isNaN(l)||(z=l<.5?H:G)}var c={};!function(t){null!==B?t[i.id+\".radialaxis.angle\"]=B:null!==N&&(t[i.id+\".radialaxis.range[\"+r+\"]\"]=N)}(c),s.emit(\"plotly_relayouting\",c)}function q(){null!==B?a.call(\"_guiRelayout\",s,i.id+\".radialaxis.angle\",B):null!==N&&a.call(\"_guiRelayout\",s,i.id+\".radialaxis.range[\"+r+\"]\",N)}function H(t,e){if(0!==r){var n=y+t,a=x+e;B=Math.atan2(f-a,n-h),i.vangles&&(B=I(B,i.vangles)),B=L(B);var o=R(h,f)+F(-B);l[\"radial-axis\"].attr(\"transform\",o),l[\"radial-line\"].select(\"line\").attr(\"transform\",o);var s=i.gd._fullLayout,c=s[i.id];i.updateRadialAxisTitle(s,c,B)}}function G(t,e){var n=o.dot([t,-e],[Math.cos(T),Math.sin(T)]);if(N=P-O*n,O>0==(r?N>S:N<E)){var l=s._fullLayout,c=l[i.id];p.range[r]=N,p._rl[r]=N,i.updateRadialAxis(l,c),i.xaxis.setRange(),i.xaxis.setScale(),i.yaxis.setRange(),i.yaxis.setScale();var u=!1;for(var h in i.traceHash){var f=i.traceHash[h],d=o.filterVisible(f);f[0][0].trace._module.plot(s,i,d,c),a.traceIs(h,\"gl\")&&d.length&&(u=!0)}u&&(w(s),k(s))}else N=null}},O.updateAngularDrag=function(t){var e=this,r=e.gd,i=e.layers,s=e.radius,c=e.angularAxis,u=e.cx,h=e.cy,f=e.cxx,p=e.cyy,v=A.angularDragBoxSize,m=d.makeDragger(i,\"path\",\"angulardrag\",\"move\"),y={element:m,gd:r};function x(t,e){return Math.atan2(p+v-e,t-f-v)}n.select(m).attr(\"d\",e.pathAnnulus(s,s+v)).attr(\"transform\",R(u,h)).call(_,\"move\");var T,M,S,E,C,P,O=i.frontplot.select(\".scatterlayer\").selectAll(\".trace\"),z=O.selectAll(\".point\"),I=O.selectAll(\".textpoint\");function D(t,s){var d=e.gd._fullLayout,g=d[e.id],v=x(T+t,M+s),m=L(v-P);if(E=S+m,i.frontplot.attr(\"transform\",R(e.xOffset2,e.yOffset2)+F([-m,f,p])),e.vangles){C=e.radialAxisAngle+m;var y=R(u,h)+F(-m),b=R(u,h)+F(-C);i.bg.attr(\"transform\",y),i[\"radial-grid\"].attr(\"transform\",y),i[\"radial-axis\"].attr(\"transform\",b),i[\"radial-line\"].select(\"line\").attr(\"transform\",b),e.updateRadialAxisTitle(d,g,C)}else e.clipPaths.forTraces.select(\"path\").attr(\"transform\",R(f,p)+F(m));z.each(function(){var t=n.select(this),e=l.getTranslate(t);t.attr(\"transform\",R(e.x,e.y)+F([m]))}),I.each(function(){var t=n.select(this),e=t.select(\"text\"),r=l.getTranslate(t);t.attr(\"transform\",F([m,e.attr(\"x\"),e.attr(\"y\")])+R(r.x,r.y))}),c.rotation=o.modHalf(E,360),e.updateAngularAxis(d,g),e._hasClipOnAxisFalse&&!o.isFullCircle(e.sectorInRad)&&O.call(l.hideOutsideRangePoints,e);var _=!1;for(var A in e.traceHash)if(a.traceIs(A,\"gl\")){var D=e.traceHash[A],N=o.filterVisible(D);D[0][0].trace._module.plot(r,e,N,g),N.length&&(_=!0)}_&&(w(r),k(r));var j={};B(j),r.emit(\"plotly_relayouting\",j)}function B(t){t[e.id+\".angularaxis.rotation\"]=E,e.vangles&&(t[e.id+\".radialaxis.angle\"]=C)}function N(){I.select(\"text\").attr(\"transform\",null);var t={};B(t),a.call(\"_guiRelayout\",r,t)}y.prepFn=function(n,i,a){var o=t[e.id];S=o.angularaxis.rotation;var s=m.getBoundingClientRect();T=i-s.left,M=a-s.top,P=x(T,M),y.moveFn=D,y.doneFn=N,b(r)},e.vangles&&!o.isFullCircle(e.sectorInRad)&&(y.prepFn=o.noop,_(n.select(m),null)),g.init(y)},O.isPtInside=function(t){var e=this.sectorInRad,r=this.vangles,n=this.angularAxis.c2g(t.theta),i=this.radialAxis,a=i.c2l(t.r),s=i._rl;return(r?M.isPtInsidePolygon:o.isPtInsideSector)(a,n,s,e,r)},O.pathArc=function(t){var e=this.sectorInRad,r=this.vangles;return(r?M.pathPolygon:o.pathArc)(t,e[0],e[1],r)},O.pathSector=function(t){var e=this.sectorInRad,r=this.vangles;return(r?M.pathPolygon:o.pathSector)(t,e[0],e[1],r)},O.pathAnnulus=function(t,e){var r=this.sectorInRad,n=this.vangles;return(n?M.pathPolygonAnnulus:o.pathAnnulus)(t,e,r[0],r[1],n)},O.pathSubplot=function(){var t=this.innerRadius,e=this.radius;return t?this.pathAnnulus(t,e):this.pathSector(e)},O.fillViewInitialKey=function(t,e){t in this.viewInitial||(this.viewInitial[t]=e)}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../components/titles\":681,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/clear_gl_canvases\":704,\"../../lib/setcursor\":739,\"../../plot_api/subroutines\":758,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../cartesian/autorange\":766,\"../cartesian/dragbox\":775,\"../cartesian/select\":784,\"../cartesian/set_convert\":785,\"../plots\":828,\"./constants\":829,\"./helpers\":830,\"./set_convert\":841,d3:163,tinycolor2:537}],841:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../cartesian/set_convert\"),a=n.deg2rad,o=n.rad2deg;e.exports=function(t,e,r){switch(i(t,r),t._id){case\"x\":case\"radialaxis\":!function(t,e){var r=e._subplot;t.setGeometry=function(){var e=t._rl[0],n=t._rl[1],i=r.innerRadius,a=(r.radius-i)/(n-e),o=i/a,s=e>n?function(t){return t<=0}:function(t){return t>=0};t.c2g=function(r){var n=t.c2l(r)-e;return(s(n)?n:0)+o},t.g2c=function(r){return t.l2c(r+e-o)},t.g2p=function(t){return t*a},t.c2p=function(e){return t.g2p(t.c2g(e))}}}(t,e);break;case\"angularaxis\":!function(t,e){var r=t.type;if(\"linear\"===r){var i=t.d2c,s=t.c2d;t.d2c=function(t,e){return function(t,e){return\"degrees\"===e?a(t):t}(i(t),e)},t.c2d=function(t,e){return s(function(t,e){return\"degrees\"===e?o(t):t}(t,e))}}t.makeCalcdata=function(e,i){var a,o,s=e[i],l=e._length,c=function(r){return t.d2c(r,e.thetaunit)};if(s){if(n.isTypedArray(s)&&\"linear\"===r){if(l===s.length)return s;if(s.subarray)return s.subarray(0,l)}for(a=new Array(l),o=0;o<l;o++)a[o]=c(s[o])}else{var u=i+\"0\",h=\"d\"+i,f=u in e?c(e[u]):0,p=e[h]?c(e[h]):(t.period||2*Math.PI)/l;for(a=new Array(l),o=0;o<l;o++)a[o]=f+o*p}return a},t.setGeometry=function(){var i,s,l,c,u=e.sector,h=u.map(a),f={clockwise:-1,counterclockwise:1}[t.direction],p=a(t.rotation),d=function(t){return f*t+p},g=function(t){return(t-p)/f};switch(r){case\"linear\":s=i=n.identity,c=a,l=o,t.range=n.isFullCircle(h)?[u[0],u[0]+360]:h.map(g).map(o);break;case\"category\":var v=t._categories.length,m=t.period?Math.max(t.period,v):v;0===m&&(m=1),s=c=function(t){return 2*t*Math.PI/m},i=l=function(t){return t*m/Math.PI/2},t.range=[0,m]}t.c2g=function(t){return d(s(t))},t.g2c=function(t){return i(g(t))},t.t2g=function(t){return d(c(t))},t.g2t=function(t){return l(g(t))}}}(t,e)}}},{\"../../lib\":719,\"../cartesian/set_convert\":785}],842:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\"),a=t(\"./domain\").defaults;e.exports=function(t,e,r,o){var s,l,c=o.type,u=o.attributes,h=o.handleDefaults,f=o.partition||\"x\",p=e._subplots[c],d=p.length,g=d&&p[0].replace(/\\d+$/,\"\");function v(t,e){return n.coerce(s,l,u,t,e)}for(var m=0;m<d;m++){var y=p[m];s=t[y]?t[y]:t[y]={},l=i.newContainer(e,y,g),v(\"uirevision\",e.uirevision);var x={};x[f]=[m/d,(m+1)/d],a(l,e,v,x),o.id=y,h(s,l,v,o)}}},{\"../lib\":719,\"../plot_api/plot_template\":757,\"./domain\":792}],843:[function(t,e,r){\"use strict\";var n=t(\"./ternary\"),i=t(\"../../plots/get_data\").getSubplotCalcData,a=t(\"../../lib\").counterRegex;r.name=\"ternary\";var o=r.attr=\"subplot\";r.idRoot=\"ternary\",r.idRegex=r.attrRegex=a(\"ternary\"),(r.attributes={})[o]={valType:\"subplotid\",dflt:\"ternary\",editType:\"calc\"},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t.calcdata,a=e._subplots.ternary,o=0;o<a.length;o++){var s=a[o],l=i(r,\"ternary\",s),c=e[s]._subplot;c||(c=new n({id:s,graphDiv:t,container:e._ternarylayer.node()},e),e[s]._subplot=c),c.plot(l,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.ternary||[],a=0;a<i.length;a++){var o=i[a],s=n[o]._subplot;!e[o]&&s&&(s.plotContainer.remove(),s.clipDef.remove(),s.clipDefRelative.remove(),s.layers[\"a-title\"].remove(),s.layers[\"b-title\"].remove(),s.layers[\"c-title\"].remove())}}},{\"../../lib\":719,\"../../plots/get_data\":802,\"./layout_attributes\":844,\"./layout_defaults\":845,\"./ternary\":846}],844:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"../cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../lib/extend\").extendFlat,l={title:a.title,color:a.color,tickmode:a.tickmode,nticks:s({},a.nticks,{dflt:6,min:1}),tick0:a.tick0,dtick:a.dtick,tickvals:a.tickvals,ticktext:a.ticktext,ticks:a.ticks,ticklen:a.ticklen,tickwidth:a.tickwidth,tickcolor:a.tickcolor,showticklabels:a.showticklabels,showtickprefix:a.showtickprefix,tickprefix:a.tickprefix,showticksuffix:a.showticksuffix,ticksuffix:a.ticksuffix,showexponent:a.showexponent,exponentformat:a.exponentformat,separatethousands:a.separatethousands,tickfont:a.tickfont,tickangle:a.tickangle,tickformat:a.tickformat,tickformatstops:a.tickformatstops,hoverformat:a.hoverformat,showline:s({},a.showline,{dflt:!0}),linecolor:a.linecolor,linewidth:a.linewidth,showgrid:s({},a.showgrid,{dflt:!0}),gridcolor:a.gridcolor,gridwidth:a.gridwidth,layer:a.layer,min:{valType:\"number\",dflt:0,min:0},_deprecated:{title:a._deprecated.title,titlefont:a._deprecated.titlefont}},c=e.exports=o({domain:i({name:\"ternary\"}),bgcolor:{valType:\"color\",dflt:n.background},sum:{valType:\"number\",dflt:1,min:0},aaxis:l,baxis:l,caxis:l},\"plot\",\"from-root\");c.uirevision={valType:\"any\",editType:\"none\"},c.aaxis.uirevision=c.baxis.uirevision=c.caxis.uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":592,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../cartesian/layout_attributes\":779,\"../domain\":792}],845:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../lib\"),o=t(\"../subplot_defaults\"),s=t(\"../cartesian/tick_label_defaults\"),l=t(\"../cartesian/tick_mark_defaults\"),c=t(\"../cartesian/tick_value_defaults\"),u=t(\"../cartesian/line_grid_defaults\"),h=t(\"./layout_attributes\"),f=[\"aaxis\",\"baxis\",\"caxis\"];function p(t,e,r,a){var o,s,l,c=r(\"bgcolor\"),u=r(\"sum\");a.bgColor=n.combine(c,a.paper_bgcolor);for(var h=0;h<f.length;h++)s=t[o=f[h]]||{},(l=i.newContainer(e,o))._name=o,d(s,l,a,e);var p=e.aaxis,g=e.baxis,v=e.caxis;p.min+g.min+v.min>=u&&(p.min=0,g.min=0,v.min=0,t.aaxis&&delete t.aaxis.min,t.baxis&&delete t.baxis.min,t.caxis&&delete t.caxis.min)}function d(t,e,r,n){var i=h[e._name];function o(r,n){return a.coerce(t,e,i,r,n)}o(\"uirevision\",n.uirevision),e.type=\"linear\";var f=o(\"color\"),p=f!==i.color.dflt?f:r.font.color,d=e._name.charAt(0).toUpperCase(),g=\"Component \"+d,v=o(\"title.text\",g);e._hovertitle=v===g?v:d,a.coerceFont(o,\"title.font\",{family:r.font.family,size:Math.round(1.2*r.font.size),color:p}),o(\"min\"),c(t,e,o,\"linear\"),s(t,e,o,\"linear\",{}),l(t,e,o,{outerTicks:!0}),o(\"showticklabels\")&&(a.coerceFont(o,\"tickfont\",{family:r.font.family,size:r.font.size,color:p}),o(\"tickangle\"),o(\"tickformat\")),u(t,e,o,{dfltColor:f,bgColor:r.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:i}),o(\"hoverformat\"),o(\"layer\")}e.exports=function(t,e,r){o(t,e,r,{type:\"ternary\",attributes:h,handleDefaults:p,font:e.font,paper_bgcolor:e.paper_bgcolor})}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../cartesian/line_grid_defaults\":781,\"../cartesian/tick_label_defaults\":786,\"../cartesian/tick_mark_defaults\":787,\"../cartesian/tick_value_defaults\":788,\"../subplot_defaults\":842,\"./layout_attributes\":844}],846:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=o._,l=t(\"../../components/color\"),c=t(\"../../components/drawing\"),u=t(\"../cartesian/set_convert\"),h=t(\"../../lib/extend\").extendFlat,f=t(\"../plots\"),p=t(\"../cartesian/axes\"),d=t(\"../../components/dragelement\"),g=t(\"../../components/fx\"),v=t(\"../../components/titles\"),m=t(\"../cartesian/select\").prepSelect,y=t(\"../cartesian/select\").selectOnClick,x=t(\"../cartesian/select\").clearSelect,b=t(\"../cartesian/constants\");function _(t,e){this.id=t.id,this.graphDiv=t.graphDiv,this.init(e),this.makeFramework(e),this.aTickLayout=null,this.bTickLayout=null,this.cTickLayout=null}e.exports=_;var w=_.prototype;w.init=function(t){this.container=t._ternarylayer,this.defs=t._defs,this.layoutId=t._uid,this.traceHash={},this.layers={}},w.plot=function(t,e){var r=e[this.id],n=e._size;this._hasClipOnAxisFalse=!1;for(var i=0;i<t.length;i++){if(!1===t[i][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(r),this.adjustLayout(r,n),f.generalUpdatePerTraceModule(this.graphDiv,this,t,r),this.layers.plotbg.select(\"path\").call(l.fill,r.bgcolor)},w.makeFramework=function(t){var e=this.graphDiv,r=t[this.id],n=this.clipId=\"clip\"+this.layoutId+this.id,i=this.clipIdRelative=\"clip-relative\"+this.layoutId+this.id;this.clipDef=o.ensureSingleById(t._clips,\"clipPath\",n,function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")}),this.clipDefRelative=o.ensureSingleById(t._clips,\"clipPath\",i,function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")}),this.plotContainer=o.ensureSingle(this.container,\"g\",this.id),this.updateLayers(r),c.setClipUrl(this.layers.backplot,n,e),c.setClipUrl(this.layers.grids,n,e)},w.updateLayers=function(t){var e=this.layers,r=[\"draglayer\",\"plotbg\",\"backplot\",\"grids\"];\"below traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"below traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"below traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\"),r.push(\"frontplot\"),\"above traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"above traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"above traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\");var i=this.plotContainer.selectAll(\"g.toplevel\").data(r,String),a=[\"agrid\",\"bgrid\",\"cgrid\"];i.enter().append(\"g\").attr(\"class\",function(t){return\"toplevel \"+t}).each(function(t){var r=n.select(this);e[t]=r,\"frontplot\"===t?r.append(\"g\").classed(\"scatterlayer\",!0):\"backplot\"===t?r.append(\"g\").classed(\"maplayer\",!0):\"plotbg\"===t?r.append(\"path\").attr(\"d\",\"M0,0Z\"):\"aline\"===t||\"bline\"===t||\"cline\"===t?r.append(\"path\"):\"grids\"===t&&a.forEach(function(t){e[t]=r.append(\"g\").classed(\"grid \"+t,!0)})}),i.order()};var k=Math.sqrt(4/3);w.adjustLayout=function(t,e){var r,n,i,a,o,s,f=this,p=t.domain,d=(p.x[0]+p.x[1])/2,g=(p.y[0]+p.y[1])/2,v=p.x[1]-p.x[0],m=p.y[1]-p.y[0],y=v*e.w,x=m*e.h,b=t.sum,_=t.aaxis.min,w=t.baxis.min,T=t.caxis.min;y>k*x?i=(a=x)*k:a=(i=y)/k,o=v*i/y,s=m*a/x,r=e.l+e.w*d-i/2,n=e.t+e.h*(1-g)-a/2,f.x0=r,f.y0=n,f.w=i,f.h=a,f.sum=b,f.xaxis={type:\"linear\",range:[_+2*T-b,b-_-2*w],domain:[d-o/2,d+o/2],_id:\"x\"},u(f.xaxis,f.graphDiv._fullLayout),f.xaxis.setScale(),f.xaxis.isPtWithinRange=function(t){return t.a>=f.aaxis.range[0]&&t.a<=f.aaxis.range[1]&&t.b>=f.baxis.range[1]&&t.b<=f.baxis.range[0]&&t.c>=f.caxis.range[1]&&t.c<=f.caxis.range[0]},f.yaxis={type:\"linear\",range:[_,b-w-T],domain:[g-s/2,g+s/2],_id:\"y\"},u(f.yaxis,f.graphDiv._fullLayout),f.yaxis.setScale(),f.yaxis.isPtWithinRange=function(){return!0};var A=f.yaxis.domain[0],M=f.aaxis=h({},t.aaxis,{range:[_,b-w-T],side:\"left\",tickangle:(+t.aaxis.tickangle||0)-30,domain:[A,A+s*k],anchor:\"free\",position:0,_id:\"y\",_length:i});u(M,f.graphDiv._fullLayout),M.setScale();var S=f.baxis=h({},t.baxis,{range:[b-_-T,w],side:\"bottom\",domain:f.xaxis.domain,anchor:\"free\",position:0,_id:\"x\",_length:i});u(S,f.graphDiv._fullLayout),S.setScale();var E=f.caxis=h({},t.caxis,{range:[b-_-w,T],side:\"right\",tickangle:(+t.caxis.tickangle||0)+30,domain:[A,A+s*k],anchor:\"free\",position:0,_id:\"y\",_length:i});u(E,f.graphDiv._fullLayout),E.setScale();var C=\"M\"+r+\",\"+(n+a)+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";f.clipDef.select(\"path\").attr(\"d\",C),f.layers.plotbg.select(\"path\").attr(\"d\",C);var L=\"M0,\"+a+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";f.clipDefRelative.select(\"path\").attr(\"d\",L);var P=\"translate(\"+r+\",\"+n+\")\";f.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",P),f.clipDefRelative.select(\"path\").attr(\"transform\",null);var O=\"translate(\"+(r-S._offset)+\",\"+(n+a)+\")\";f.layers.baxis.attr(\"transform\",O),f.layers.bgrid.attr(\"transform\",O);var z=\"translate(\"+(r+i/2)+\",\"+n+\")rotate(30)translate(0,\"+-M._offset+\")\";f.layers.aaxis.attr(\"transform\",z),f.layers.agrid.attr(\"transform\",z);var I=\"translate(\"+(r+i/2)+\",\"+n+\")rotate(-30)translate(0,\"+-E._offset+\")\";f.layers.caxis.attr(\"transform\",I),f.layers.cgrid.attr(\"transform\",I),f.drawAxes(!0),f.layers.aline.select(\"path\").attr(\"d\",M.showline?\"M\"+r+\",\"+(n+a)+\"l\"+i/2+\",-\"+a:\"M0,0\").call(l.stroke,M.linecolor||\"#000\").style(\"stroke-width\",(M.linewidth||0)+\"px\"),f.layers.bline.select(\"path\").attr(\"d\",S.showline?\"M\"+r+\",\"+(n+a)+\"h\"+i:\"M0,0\").call(l.stroke,S.linecolor||\"#000\").style(\"stroke-width\",(S.linewidth||0)+\"px\"),f.layers.cline.select(\"path\").attr(\"d\",E.showline?\"M\"+(r+i/2)+\",\"+n+\"l\"+i/2+\",\"+a:\"M0,0\").call(l.stroke,E.linecolor||\"#000\").style(\"stroke-width\",(E.linewidth||0)+\"px\"),f.graphDiv._context.staticPlot||f.initInteractions(),c.setClipUrl(f.layers.frontplot,f._hasClipOnAxisFalse?null:f.clipId,f.graphDiv)},w.drawAxes=function(t){var e=this.graphDiv,r=this.id.substr(7)+\"title\",n=this.layers,i=this.aaxis,a=this.baxis,o=this.caxis;if(this.drawAx(i),this.drawAx(a),this.drawAx(o),t){var l=Math.max(i.showticklabels?i.tickfont.size/2:0,(o.showticklabels?.75*o.tickfont.size:0)+(\"outside\"===o.ticks?.87*o.ticklen:0)),c=(a.showticklabels?a.tickfont.size:0)+(\"outside\"===a.ticks?a.ticklen:0)+3;n[\"a-title\"]=v.draw(e,\"a\"+r,{propContainer:i,propName:this.id+\".aaxis.title\",placeholder:s(e,\"Click to enter Component A title\"),attributes:{x:this.x0+this.w/2,y:this.y0-i.title.font.size/3-l,\"text-anchor\":\"middle\"}}),n[\"b-title\"]=v.draw(e,\"b\"+r,{propContainer:a,propName:this.id+\".baxis.title\",placeholder:s(e,\"Click to enter Component B title\"),attributes:{x:this.x0-c,y:this.y0+this.h+.83*a.title.font.size+c,\"text-anchor\":\"middle\"}}),n[\"c-title\"]=v.draw(e,\"c\"+r,{propContainer:o,propName:this.id+\".caxis.title\",placeholder:s(e,\"Click to enter Component C title\"),attributes:{x:this.x0+this.w+c,y:this.y0+this.h+.83*o.title.font.size+c,\"text-anchor\":\"middle\"}})}},w.drawAx=function(t){var e,r=this.graphDiv,n=t._name,i=n.charAt(0),a=t._id,s=this.layers[n],l=i+\"tickLayout\",c=(e=t).ticks+String(e.ticklen)+String(e.showticklabels);this[l]!==c&&(s.selectAll(\".\"+a+\"tick\").remove(),this[l]=c),t.setScale();var u=p.calcTicks(t),h=p.clipEnds(t,u),f=p.makeTransFn(t),d=p.getTickSigns(t)[2],g=o.deg2rad(30),v=d*(t.linewidth||1)/2,m=d*t.ticklen,y=this.w,x=this.h,b=\"b\"===i?\"M0,\"+v+\"l\"+Math.sin(g)*m+\",\"+Math.cos(g)*m:\"M\"+v+\",0l\"+Math.cos(g)*m+\",\"+-Math.sin(g)*m,_={a:\"M0,0l\"+x+\",-\"+y/2,b:\"M0,0l-\"+y/2+\",-\"+x,c:\"M0,0l-\"+x+\",\"+y/2}[i];p.drawTicks(r,t,{vals:\"inside\"===t.ticks?h:u,layer:s,path:b,transFn:f,crisp:!1}),p.drawGrid(r,t,{vals:h,layer:this.layers[i+\"grid\"],path:_,transFn:f,crisp:!1}),p.drawLabels(r,t,{vals:u,layer:s,transFn:f,labelFns:p.makeLabelFns(t,0,30)})};var T=b.MINZOOM/2+.87,A=\"m-0.87,.5h\"+T+\"v3h-\"+(T+5.2)+\"l\"+(T/2+2.6)+\",-\"+(.87*T+4.5)+\"l2.6,1.5l-\"+T/2+\",\"+.87*T+\"Z\",M=\"m0.87,.5h-\"+T+\"v3h\"+(T+5.2)+\"l-\"+(T/2+2.6)+\",-\"+(.87*T+4.5)+\"l-2.6,1.5l\"+T/2+\",\"+.87*T+\"Z\",S=\"m0,1l\"+T/2+\",\"+.87*T+\"l2.6,-1.5l-\"+(T/2+2.6)+\",-\"+(.87*T+4.5)+\"l-\"+(T/2+2.6)+\",\"+(.87*T+4.5)+\"l2.6,1.5l\"+T/2+\",-\"+.87*T+\"Z\",E=\"m0.5,0.5h5v-2h-5v-5h-2v5h-5v2h5v5h2Z\",C=!0;function L(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}w.initInteractions=function(){var t,e,r,n,u,h,f,p,v,_,w=this,T=w.layers.plotbg.select(\"path\").node(),P=w.graphDiv,O=P._fullLayout._zoomlayer,z={element:T,gd:P,plotinfo:{id:w.id,xaxis:w.xaxis,yaxis:w.yaxis},subplot:w.id,prepFn:function(a,o,s){z.xaxes=[w.xaxis],z.yaxes=[w.yaxis];var c=P._fullLayout.dragmode;z.minDrag=\"lasso\"===c?1:void 0,\"zoom\"===c?(z.moveFn=N,z.clickFn=D,z.doneFn=j,function(a,o,s){var c=T.getBoundingClientRect();t=o-c.left,e=s-c.top,r={a:w.aaxis.range[0],b:w.baxis.range[1],c:w.caxis.range[1]},u=r,n=w.aaxis.range[1]-r.a,h=i(w.graphDiv._fullLayout[w.id].bgcolor).getLuminance(),f=\"M0,\"+w.h+\"L\"+w.w/2+\", 0L\"+w.w+\",\"+w.h+\"Z\",p=!1,v=O.append(\"path\").attr(\"class\",\"zoombox\").attr(\"transform\",\"translate(\"+w.x0+\", \"+w.y0+\")\").style({fill:h>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"d\",f),_=O.append(\"path\").attr(\"class\",\"zoombox-corners\").attr(\"transform\",\"translate(\"+w.x0+\", \"+w.y0+\")\").style({fill:l.background,stroke:l.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"d\",\"M0,0Z\"),x(P)}(0,o,s)):\"pan\"===c?(z.moveFn=U,z.clickFn=D,z.doneFn=V,r={a:w.aaxis.range[0],b:w.baxis.range[1],c:w.caxis.range[1]},u=r,x(P)):\"select\"!==c&&\"lasso\"!==c||m(a,o,s,z,c)}};function I(t){var e={};return e[w.id+\".aaxis.min\"]=t.a,e[w.id+\".baxis.min\"]=t.b,e[w.id+\".caxis.min\"]=t.c,e}function D(t,e){var r=P._fullLayout.clickmode;L(P),2===t&&(P.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",P,I({a:0,b:0,c:0}))),r.indexOf(\"select\")>-1&&1===t&&y(e,P,[w.xaxis],[w.yaxis],w.id,z),r.indexOf(\"event\")>-1&&g.click(P,e,w.id)}function R(t,e){return 1-e/w.h}function F(t,e){return 1-(t+(w.h-e)/Math.sqrt(3))/w.w}function B(t,e){return(t-(w.h-e)/Math.sqrt(3))/w.w}function N(i,a){var o=t+i,s=e+a,l=Math.max(0,Math.min(1,R(0,e),R(0,s))),c=Math.max(0,Math.min(1,F(t,e),F(o,s))),d=Math.max(0,Math.min(1,B(t,e),B(o,s))),g=(l/2+d)*w.w,m=(1-l/2-c)*w.w,y=(g+m)/2,x=m-g,T=(1-l)*w.h,C=T-x/k;x<b.MINZOOM?(u=r,v.attr(\"d\",f),_.attr(\"d\",\"M0,0Z\")):(u={a:r.a+l*n,b:r.b+c*n,c:r.c+d*n},v.attr(\"d\",f+\"M\"+g+\",\"+T+\"H\"+m+\"L\"+y+\",\"+C+\"L\"+g+\",\"+T+\"Z\"),_.attr(\"d\",\"M\"+t+\",\"+e+E+\"M\"+g+\",\"+T+A+\"M\"+m+\",\"+T+M+\"M\"+y+\",\"+C+S)),p||(v.transition().style(\"fill\",h>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),_.transition().style(\"opacity\",1).duration(200),p=!0),P.emit(\"plotly_relayouting\",I(u))}function j(){L(P),u!==r&&(a.call(\"_guiRelayout\",P,I(u)),C&&P.data&&P._context.showTips&&(o.notifier(s(P,\"Double-click to zoom back out\"),\"long\"),C=!1))}function U(t,e){var n=t/w.xaxis._m,i=e/w.yaxis._m,a=[(u={a:r.a-i,b:r.b+(n+i)/2,c:r.c-(n-i)/2}).a,u.b,u.c].sort(),o=a.indexOf(u.a),s=a.indexOf(u.b),l=a.indexOf(u.c);a[0]<0&&(a[1]+a[0]/2<0?(a[2]+=a[0]+a[1],a[0]=a[1]=0):(a[2]+=a[0]/2,a[1]+=a[0]/2,a[0]=0),u={a:a[o],b:a[s],c:a[l]},e=(r.a-u.a)*w.yaxis._m,t=(r.c-u.c-r.b+u.b)*w.xaxis._m);var h=\"translate(\"+(w.x0+t)+\",\"+(w.y0+e)+\")\";w.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",h);var f=\"translate(\"+-t+\",\"+-e+\")\";w.clipDefRelative.select(\"path\").attr(\"transform\",f),w.aaxis.range=[u.a,w.sum-u.b-u.c],w.baxis.range=[w.sum-u.a-u.c,u.b],w.caxis.range=[w.sum-u.a-u.b,u.c],w.drawAxes(!1),w._hasClipOnAxisFalse&&w.plotContainer.select(\".scatterlayer\").selectAll(\".trace\").call(c.hideOutsideRangePoints,w),P.emit(\"plotly_relayouting\",I(u))}function V(){a.call(\"_guiRelayout\",P,I(u))}T.onmousemove=function(t){g.hover(P,t,w.id),P._fullLayout._lasthover=T,P._fullLayout._hoversubplot=w.id},T.onmouseout=function(t){P._dragging||d.unhover(P,t)},d.init(z)}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../components/titles\":681,\"../../lib\":719,\"../../lib/extend\":710,\"../../registry\":847,\"../cartesian/axes\":767,\"../cartesian/constants\":773,\"../cartesian/select\":784,\"../cartesian/set_convert\":785,\"../plots\":828,d3:163,tinycolor2:537}],847:[function(t,e,r){\"use strict\";var n=t(\"./lib/loggers\"),i=t(\"./lib/noop\"),a=t(\"./lib/push_unique\"),o=t(\"./lib/is_plain_object\"),s=t(\"./lib/dom\").addStyleRule,l=t(\"./lib/extend\"),c=t(\"./plots/attributes\"),u=t(\"./plots/layout_attributes\"),h=l.extendFlat,f=l.extendDeepAll;function p(t){var e=t.name,i=t.categories,a=t.meta;if(r.modules[e])n.log(\"Type \"+e+\" already registered\");else{r.subplotsRegistry[t.basePlotModule.name]||function(t){var e=t.name;if(r.subplotsRegistry[e])return void n.log(\"Plot type \"+e+\" already registered.\");for(var i in m(t),r.subplotsRegistry[e]=t,r.componentsRegistry)b(i,t.name)}(t.basePlotModule);for(var o={},l=0;l<i.length;l++)o[i[l]]=!0,r.allCategories[i[l]]=!0;for(var c in r.modules[e]={_module:t,categories:o},a&&Object.keys(a).length&&(r.modules[e].meta=a),r.allTypes.push(e),r.componentsRegistry)y(c,e);t.layoutAttributes&&h(r.traceLayoutAttributes,t.layoutAttributes);var u=t.basePlotModule,f=u.name;if(\"mapbox\"===f){var p=u.constants.styleRules;for(var d in p)s(\".js-plotly-plot .plotly .mapboxgl-\"+d,p[d])}\"geo\"!==f&&\"mapbox\"!==f||void 0===typeof window||void 0!==window.PlotlyGeoAssets||(window.PlotlyGeoAssets={topojson:{}})}}function d(t){if(\"string\"!=typeof t.name)throw new Error(\"Component module *name* must be a string.\");var e=t.name;for(var n in r.componentsRegistry[e]=t,t.layoutAttributes&&(t.layoutAttributes._isLinkedToArray&&a(r.layoutArrayContainers,e),m(t)),r.modules)y(e,n);for(var i in r.subplotsRegistry)b(e,i);for(var o in r.transformsRegistry)x(e,o);t.schema&&t.schema.layout&&f(u,t.schema.layout)}function g(t){if(\"string\"!=typeof t.name)throw new Error(\"Transform module *name* must be a string.\");var e=\"Transform module \"+t.name,i=\"function\"==typeof t.transform,a=\"function\"==typeof t.calcTransform;if(!i&&!a)throw new Error(e+\" is missing a *transform* or *calcTransform* method.\");for(var s in i&&a&&n.log([e+\" has both a *transform* and *calcTransform* methods.\",\"Please note that all *transform* methods are executed\",\"before all *calcTransform* methods.\"].join(\" \")),o(t.attributes)||n.log(e+\" registered without an *attributes* object.\"),\"function\"!=typeof t.supplyDefaults&&n.log(e+\" registered without a *supplyDefaults* method.\"),r.transformsRegistry[t.name]=t,r.componentsRegistry)x(s,t.name)}function v(t){var e=t.name,n=e.split(\"-\")[0],i=t.dictionary,a=t.format,o=i&&Object.keys(i).length,s=a&&Object.keys(a).length,l=r.localeRegistry,c=l[e];if(c||(l[e]=c={}),n!==e){var u=l[n];u||(l[n]=u={}),o&&u.dictionary===c.dictionary&&(u.dictionary=i),s&&u.format===c.format&&(u.format=a)}o&&(c.dictionary=i),s&&(c.format=a)}function m(t){if(t.layoutAttributes){var e=t.layoutAttributes._arrayAttrRegexps;if(e)for(var n=0;n<e.length;n++)a(r.layoutArrayRegexes,e[n])}}function y(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.traces){var i=n.traces[e];i&&f(r.modules[e]._module.attributes,i)}}function x(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.transforms){var i=n.transforms[e];i&&f(r.transformsRegistry[e].attributes,i)}}function b(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.subplots){var i=r.subplotsRegistry[e],a=i.layoutAttributes,o=\"subplot\"===i.attr?i.name:i.attr;Array.isArray(o)&&(o=o[0]);var s=n.subplots[o];a&&s&&f(a,s)}}function _(t){return\"object\"==typeof t&&(t=t.type),t}r.modules={},r.allCategories={},r.allTypes=[],r.subplotsRegistry={},r.transformsRegistry={},r.componentsRegistry={},r.layoutArrayContainers=[],r.layoutArrayRegexes=[],r.traceLayoutAttributes={},r.localeRegistry={},r.apiMethodRegistry={},r.collectableSubplotTypes=null,r.register=function(t){if(r.collectableSubplotTypes=null,!t)throw new Error(\"No argument passed to Plotly.register.\");t&&!Array.isArray(t)&&(t=[t]);for(var e=0;e<t.length;e++){var n=t[e];if(!n)throw new Error(\"Invalid module was attempted to be registered!\");switch(n.moduleType){case\"trace\":p(n);break;case\"transform\":g(n);break;case\"component\":d(n);break;case\"locale\":v(n);break;case\"apiMethod\":var i=n.name;r.apiMethodRegistry[i]=n.fn;break;default:throw new Error(\"Invalid module was attempted to be registered!\")}}},r.getModule=function(t){var e=r.modules[_(t)];return!!e&&e._module},r.traceIs=function(t,e){if(\"various\"===(t=_(t)))return!1;var i=r.modules[t];return i||(t&&\"area\"!==t&&n.log(\"Unrecognized trace type \"+t+\".\"),i=r.modules[c.type.dflt]),!!i.categories[e]},r.getTransformIndices=function(t,e){for(var r=[],n=t.transforms||[],i=0;i<n.length;i++)n[i].type===e&&r.push(i);return r},r.hasTransform=function(t,e){for(var r=t.transforms||[],n=0;n<r.length;n++)if(r[n].type===e)return!0;return!1},r.getComponentMethod=function(t,e){var n=r.componentsRegistry[t];return n&&n[e]||i},r.call=function(){var t=arguments[0],e=[].slice.call(arguments,1);return r.apiMethodRegistry[t].apply(null,e)}},{\"./lib/dom\":708,\"./lib/extend\":710,\"./lib/is_plain_object\":720,\"./lib/loggers\":723,\"./lib/noop\":728,\"./lib/push_unique\":733,\"./plots/attributes\":764,\"./plots/layout_attributes\":819}],848:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=i.extendFlat,o=i.extendDeep;function s(t){var e;switch(t){case\"themes__thumb\":e={autosize:!0,width:150,height:150,title:{text:\"\"},showlegend:!1,margin:{l:5,r:5,t:5,b:5,pad:0},annotations:[]};break;case\"thumbnail\":e={title:{text:\"\"},hidesources:!0,showlegend:!1,borderwidth:0,bordercolor:\"\",margin:{l:1,r:1,t:1,b:1,pad:0},annotations:[]};break;default:e={}}return e}e.exports=function(t,e){var r;t.framework&&t.framework.isPolar&&(t=t.framework.getConfig());var i,l=t.data,c=t.layout,u=o([],l),h=o({},c,s(e.tileClass)),f=t._context||{};if(e.width&&(h.width=e.width),e.height&&(h.height=e.height),\"thumbnail\"===e.tileClass||\"themes__thumb\"===e.tileClass){h.annotations=[];var p=Object.keys(h);for(r=0;r<p.length;r++)i=p[r],[\"xaxis\",\"yaxis\",\"zaxis\"].indexOf(i.slice(0,5))>-1&&(h[p[r]].title={text:\"\"});for(r=0;r<u.length;r++){var d=u[r];d.showscale=!1,d.marker&&(d.marker.showscale=!1),n.traceIs(d,\"pie-like\")&&(d.textposition=\"none\")}}if(Array.isArray(e.annotations))for(r=0;r<e.annotations.length;r++)h.annotations.push(e.annotations[r]);var g=Object.keys(h).filter(function(t){return t.match(/^scene\\d*$/)});if(g.length){var v={};for(\"thumbnail\"===e.tileClass&&(v={title:{text:\"\"},showaxeslabels:!1,showticklabels:!1,linetickenable:!1}),r=0;r<g.length;r++){var m=h[g[r]];m.xaxis||(m.xaxis={}),m.yaxis||(m.yaxis={}),m.zaxis||(m.zaxis={}),a(m.xaxis,v),a(m.yaxis,v),a(m.zaxis,v),m._scene=null}}var y=document.createElement(\"div\");e.tileClass&&(y.className=e.tileClass);var x={gd:y,td:y,layout:h,data:u,config:{staticPlot:void 0===e.staticPlot||e.staticPlot,plotGlPixelRatio:void 0===e.plotGlPixelRatio?2:e.plotGlPixelRatio,displaylogo:e.displaylogo||!1,showLink:e.showLink||!1,showTips:e.showTips||!1,mapboxAccessToken:f.mapboxAccessToken}};return\"transparent\"!==e.setBackground&&(x.config.setBackground=e.setBackground||\"opaque\"),x.gd.defaultLayout=s(e.tileClass),x}},{\"../lib\":719,\"../registry\":847}],849:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/to_image\"),a=t(\"./filesaver\"),o=t(\"./helpers\");e.exports=function(t,e){var r;return n.isPlainObject(t)||(r=n.getGraphDiv(t)),(e=e||{}).format=e.format||\"png\",e.imageDataOnly=!0,new Promise(function(s,l){r&&r._snapshotInProgress&&l(new Error(\"Snapshotting already in progress.\")),n.isIE()&&\"svg\"!==e.format&&l(new Error(o.MSG_IE_BAD_FORMAT)),r&&(r._snapshotInProgress=!0);var c=i(t,e),u=e.filename||t.fn||\"newplot\";u+=\".\"+e.format,c.then(function(t){return r&&(r._snapshotInProgress=!1),a(t,u,e.format)}).then(function(t){s(t)}).catch(function(t){r&&(r._snapshotInProgress=!1),l(t)})})}},{\"../lib\":719,\"../plot_api/to_image\":760,\"./filesaver\":850,\"./helpers\":851}],850:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"./helpers\");e.exports=function(t,e,r){var a=document.createElement(\"a\"),o=\"download\"in a;return new Promise(function(s,l){var c,u;if(n.isIE9orBelow()&&l(new Error(\"IE < 10 unsupported\")),n.isSafari()){var h=\"svg\"===r?\",\":\";base64,\";return i.octetStream(h+encodeURIComponent(t)),s(e)}return n.isIE()?(c=i.createBlob(t,\"svg\"),window.navigator.msSaveBlob(c,e),c=null,s(e)):o?(c=i.createBlob(t,r),u=i.createObjectURL(c),a.href=u,a.download=e,document.body.appendChild(a),a.click(),document.body.removeChild(a),i.revokeObjectURL(u),c=null,s(e)):void l(new Error(\"download error\"))})}},{\"../lib\":719,\"./helpers\":851}],851:[function(t,e,r){\"use strict\";var n=t(\"../registry\");r.getDelay=function(t){return t._has&&(t._has(\"gl3d\")||t._has(\"gl2d\")||t._has(\"mapbox\"))?500:0},r.getRedrawFunc=function(t){return function(){var e=t._fullLayout||{};!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r||n.getComponentMethod(\"colorbar\",\"draw\")(t)}},r.encodeSVG=function(t){return\"data:image/svg+xml,\"+encodeURIComponent(t)};var i=window.URL||window.webkitURL;r.createObjectURL=function(t){return i.createObjectURL(t)},r.revokeObjectURL=function(t){return i.revokeObjectURL(t)},r.createBlob=function(t,e){if(\"svg\"===e)return new window.Blob([t],{type:\"image/svg+xml;charset=utf-8\"});var r=function(t){for(var e=t.length,r=new ArrayBuffer(e),n=new Uint8Array(r),i=0;i<e;i++)n[i]=t.charCodeAt(i);return r}(window.atob(t));return new window.Blob([r],{type:\"image/\"+e})},r.octetStream=function(t){document.location.href=\"data:application/octet-stream\"+t},r.IMAGE_URL_PREFIX=/^data:image\\/\\w+;base64,/,r.MSG_IE_BAD_FORMAT=\"Sorry IE does not support downloading from canvas. Try {format:'svg'} instead.\"},{\"../registry\":847}],852:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i={getDelay:n.getDelay,getRedrawFunc:n.getRedrawFunc,clone:t(\"./cloneplot\"),toSVG:t(\"./tosvg\"),svgToImg:t(\"./svgtoimg\"),toImage:t(\"./toimage\"),downloadImage:t(\"./download\")};e.exports=i},{\"./cloneplot\":848,\"./download\":849,\"./helpers\":851,\"./svgtoimg\":853,\"./toimage\":854,\"./tosvg\":855}],853:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"events\").EventEmitter,a=t(\"./helpers\");e.exports=function(t){var e=t.emitter||new i,r=new Promise(function(i,o){var s=window.Image,l=t.svg,c=t.format||\"png\";if(n.isIE()&&\"svg\"!==c){var u=new Error(a.MSG_IE_BAD_FORMAT);return o(u),t.promise?r:e.emit(\"error\",u)}var h,f,p=t.canvas,d=t.scale||1,g=t.width||300,v=t.height||150,m=d*g,y=d*v,x=p.getContext(\"2d\"),b=new s;\"svg\"===c||n.isIE9orBelow()||n.isSafari()?f=a.encodeSVG(l):(h=a.createBlob(l,\"svg\"),f=a.createObjectURL(h)),p.width=m,p.height=y,b.onload=function(){var r;switch(h=null,a.revokeObjectURL(f),\"svg\"!==c&&x.drawImage(b,0,0,m,y),c){case\"jpeg\":r=p.toDataURL(\"image/jpeg\");break;case\"png\":r=p.toDataURL(\"image/png\");break;case\"webp\":r=p.toDataURL(\"image/webp\");break;case\"svg\":r=f;break;default:var n=\"Image format is not jpeg, png, svg or webp.\";if(o(new Error(n)),!t.promise)return e.emit(\"error\",n)}i(r),t.promise||e.emit(\"success\",r)},b.onerror=function(r){if(h=null,a.revokeObjectURL(f),o(r),!t.promise)return e.emit(\"error\",r)},b.src=f});return t.promise?r:e}},{\"../lib\":719,\"./helpers\":851,events:104}],854:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i=t(\"../registry\"),a=t(\"../lib\"),o=t(\"./helpers\"),s=t(\"./cloneplot\"),l=t(\"./tosvg\"),c=t(\"./svgtoimg\");e.exports=function(t,e){var r=new n,u=s(t,{format:\"png\"}),h=u.gd;h.style.position=\"absolute\",h.style.left=\"-5000px\",document.body.appendChild(h);var f=o.getRedrawFunc(h);return i.call(\"plot\",h,u.data,u.layout,u.config).then(f).then(function(){var t=o.getDelay(h._fullLayout);setTimeout(function(){var t=l(h),n=document.createElement(\"canvas\");n.id=a.randstr(),(r=c({format:e.format,width:h._fullLayout.width,height:h._fullLayout.height,canvas:n,emitter:r,svg:t})).clean=function(){h&&document.body.removeChild(h)}},t)}).catch(function(t){r.emit(\"error\",t)}),r}},{\"../lib\":719,\"../registry\":847,\"./cloneplot\":848,\"./helpers\":851,\"./svgtoimg\":853,\"./tosvg\":855,events:104}],855:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=t(\"../components/drawing\"),o=t(\"../components/color\"),s=t(\"../constants/xmlns_namespaces\"),l=/\"/g,c=new RegExp('(\"TOBESTRIPPED)|(TOBESTRIPPED\")',\"g\");e.exports=function(t,e,r){var u,h=t._fullLayout,f=h._paper,p=h._toppaper,d=h.width,g=h.height;f.insert(\"rect\",\":first-child\").call(a.setRect,0,0,d,g).call(o.fill,h.paper_bgcolor);var v=h._basePlotModules||[];for(u=0;u<v.length;u++){var m=v[u];m.toSVG&&m.toSVG(t)}if(p){var y=p.node().childNodes,x=Array.prototype.slice.call(y);for(u=0;u<x.length;u++){var b=x[u];b.childNodes.length&&f.node().appendChild(b)}}h._draggers&&h._draggers.remove(),f.node().style.background=\"\",f.selectAll(\"text\").attr({\"data-unformatted\":null,\"data-math\":null}).each(function(){var t=n.select(this);if(\"hidden\"!==this.style.visibility&&\"none\"!==this.style.display){t.style({visibility:null,display:null});var e=this.style.fontFamily;e&&-1!==e.indexOf('\"')&&t.style(\"font-family\",e.replace(l,\"TOBESTRIPPED\"))}else t.remove()}),f.selectAll(\".point, .scatterpts, .legendfill>path, .legendlines>path, .cbfill\").each(function(){var t=n.select(this),e=this.style.fill;e&&-1!==e.indexOf(\"url(\")&&t.style(\"fill\",e.replace(l,\"TOBESTRIPPED\"));var r=this.style.stroke;r&&-1!==r.indexOf(\"url(\")&&t.style(\"stroke\",r.replace(l,\"TOBESTRIPPED\"))}),\"pdf\"!==e&&\"eps\"!==e||f.selectAll(\"#MathJax_SVG_glyphs path\").attr(\"stroke-width\",0),f.node().setAttributeNS(s.xmlns,\"xmlns\",s.svg),f.node().setAttributeNS(s.xmlns,\"xmlns:xlink\",s.xlink),\"svg\"===e&&r&&(f.attr(\"width\",r*d),f.attr(\"height\",r*g),f.attr(\"viewBox\",\"0 0 \"+d+\" \"+g));var _=(new window.XMLSerializer).serializeToString(f.node());return _=function(t){var e=n.select(\"body\").append(\"div\").style({display:\"none\"}).html(\"\"),r=t.replace(/(&[^;]*;)/gi,function(t){return\"&lt;\"===t?\"&#60;\":\"&rt;\"===t?\"&#62;\":-1!==t.indexOf(\"<\")||-1!==t.indexOf(\">\")?\"\":e.html(t).text()});return e.remove(),r}(_),_=(_=_.replace(/&(?!\\w+;|\\#[0-9]+;| \\#x[0-9A-F]+;)/g,\"&amp;\")).replace(c,\"'\"),i.isIE()&&(_=(_=(_=_.replace(/\"/gi,\"'\")).replace(/(\\('#)([^']*)('\\))/gi,'(\"#$2\")')).replace(/(\\\\')/gi,'\"')),_}},{\"../components/color\":593,\"../components/drawing\":614,\"../constants/xmlns_namespaces\":696,\"../lib\":719,d3:163}],856:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\",!0),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":719}],857:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/font_attributes\"),s=t(\"./constants.js\"),l=t(\"../../lib/extend\").extendFlat,c=o({editType:\"calc\",arrayOk:!0,colorEditType:\"style\"}),u=l({},n.marker.line.width,{dflt:0}),h=l({width:u,editType:\"calc\"},a(\"marker.line\")),f=l({line:h,editType:\"calc\"},a(\"marker\"),{opacity:{valType:\"number\",arrayOk:!0,dflt:1,min:0,max:1,editType:\"style\"}});e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,text:n.text,hovertext:n.hovertext,hovertemplate:i({},{keys:s.eventDataKeys}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"none\",arrayOk:!0,editType:\"calc\"},insidetextanchor:{valType:\"enumerated\",values:[\"end\",\"middle\",\"start\"],dflt:\"end\",editType:\"plot\"},textangle:{valType:\"angle\",dflt:\"auto\",editType:\"plot\"},textfont:l({},c,{}),insidetextfont:l({},c,{}),outsidetextfont:l({},c,{}),constraintext:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"both\",\"none\"],dflt:\"both\",editType:\"calc\"},cliponaxis:l({},n.cliponaxis,{}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},base:{valType:\"any\",dflt:null,arrayOk:!0,editType:\"calc\"},offset:{valType:\"number\",dflt:null,arrayOk:!0,editType:\"calc\"},width:{valType:\"number\",dflt:null,min:0,arrayOk:!0,editType:\"calc\"},marker:f,offsetgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},alignmentgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},selected:{marker:{opacity:n.selected.marker.opacity,color:n.selected.marker.color,editType:\"style\"},textfont:n.selected.textfont,editType:\"style\"},unselected:{marker:{opacity:n.unselected.marker.opacity,color:n.unselected.marker.color,editType:\"style\"},textfont:n.unselected.textfont,editType:\"style\"},r:n.r,t:n.t,_deprecated:{bardir:{valType:\"enumerated\",editType:\"calc\",values:[\"v\",\"h\"]}}}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"../scatter/attributes\":1112,\"./constants.js\":859}],858:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),o=t(\"./arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\");e.exports=function(t,e){var r,l,c=n.getFromId(t,e.xaxis||\"x\"),u=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=c.makeCalcdata(e,\"x\"),l=u.makeCalcdata(e,\"y\")):(r=u.makeCalcdata(e,\"y\"),l=c.makeCalcdata(e,\"x\"));for(var h=Math.min(l.length,r.length),f=new Array(h),p=0;p<h;p++)f[p]={p:l[p],s:r[p]},e.ids&&(f[p].id=String(e.ids[p]));return i(e,\"marker\")&&a(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),i(e,\"marker.line\")&&a(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),o(f,e),s(f,e),f}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"../../plots/cartesian/axes\":767,\"../scatter/calc_selection\":1114,\"./arrays_to_calcdata\":856}],859:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[]}},{}],860:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,c=t(\"./sieve.js\");function u(t,e,r,o,u){if(o.length){var b,_,w,k;switch(function(t,e){var r,a;for(r=0;r<e.length;r++){var o,s=e[r],l=s[0].trace,c=\"funnel\"===l.type?l._base:l.base,u=\"h\"===l.orientation?l.xcalendar:l.ycalendar,h=\"category\"===t.type||\"multicategory\"===t.type?function(){return null}:t.d2c;if(i(c)){for(a=0;a<Math.min(c.length,s.length);a++)o=h(c[a],0,u),n(o)?(s[a].b=+o,s[a].hasB=1):s[a].b=0;for(;a<s.length;a++)s[a].b=0}else{o=h(c,0,u);var f=n(o);for(o=f?o:0,a=0;a<s.length;a++)s[a].b=o,f&&(s[a].hasB=1)}}}(r,o),u.mode){case\"overlay\":h(e,r,o,u);break;case\"group\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(k=o[w])[0].trace.offset?_.push(k):b.push(k);_.length&&function(t,e,r,n,i){var o=new c(n,{sepNegVal:!1,overlapNoMerge:!i.norm});(function(t,e,r,n){for(var i=t._fullLayout,a=r.positions,o=r.distinctPositions,s=r.minDiff,c=r.traces,u=c.length,h=a.length!==o.length,f=s*(1-n.gap),v=l(i,e._id)+c[0][0].trace.orientation,m=i._alignmentOpts[v]||{},y=0;y<u;y++){var x,b,_=c[y],w=_[0].trace,k=m[w.alignmentgroup]||{},T=Object.keys(k.offsetGroups||{}).length,A=(x=T?f/T:h?f/u:f)*(1-(n.groupgap||0));b=T?((2*w._offsetIndex+1-T)*x-A)/2:h?((2*y+1-u)*x-A)/2:-A/2;var M=_[0].t;M.barwidth=A,M.poffset=b,M.bargroupwidth=f,M.bardelta=s}r.binWidth=c[0][0].t.barwidth/100,p(r),d(e,r),g(e,r,h)})(t,e,o,i),function(t){for(var e=t.traces,r=0;r<e.length;r++){var n=e[r],i=n[0].trace;if(void 0===i.base)for(var o=new c([n],{sepNegVal:!0,overlapNoMerge:!0}),s=0;s<n.length;s++){var l=n[s];if(l.p!==a){var u=o.put(l.p,l.b+l.s);u&&(l.b=u)}}}}(o),i.norm?(m(o),y(r,o,i)):v(r,o)}(t,e,r,_,u),b.length&&h(e,r,b,u);break;case\"stack\":case\"relative\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(k=o[w])[0].trace.base?_.push(k):b.push(k);_.length&&function(t,e,r,n,i){var o=new c(n,{sepNegVal:\"relative\"===i.mode,overlapNoMerge:!(i.norm||\"stack\"===i.mode||\"relative\"===i.mode)});f(e,o,i),function(t,e,r){var n,i,o,l,c,u,h=x(t),f=e.traces;for(l=0;l<f.length;l++)if(n=f[l],\"funnel\"===(i=n[0].trace).type)for(c=0;c<n.length;c++)(u=n[c]).s!==a&&e.put(u.p,-.5*u.s);for(l=0;l<f.length;l++){n=f[l],i=n[0].trace,o=\"funnel\"===i.type;var p=[];for(c=0;c<n.length;c++)if((u=n[c]).s!==a){var d;d=o?u.s:u.s+u.b;var g=e.put(u.p,d),v=g+d;u.b=g,u[h]=v,r.norm||(p.push(v),u.hasB&&p.push(g))}r.norm||(i._extremes[t._id]=s.findExtremes(t,p,{tozero:!0,padded:!0}))}}(r,o,i);for(var l=0;l<n.length;l++)for(var u=n[l],h=0;h<u.length;h++){var p=u[h];if(p.s!==a){var d=p.b+p.s===o.get(p.p,p.s);d&&(p._outmost=!0)}}i.norm&&y(r,o,i)}(0,e,r,_,u),b.length&&h(e,r,b,u)}!function(t,e){var r,i,a,o=x(e),s={},l=1/0,c=-1/0;for(r=0;r<t.length;r++)for(a=t[r],i=0;i<a.length;i++){var u=a[i].p;n(u)&&(l=Math.min(l,u),c=Math.max(c,u))}var h=1e4/(c-l),f=s.round=function(t){return String(Math.round(h*(t-l)))};for(r=0;r<t.length;r++){(a=t[r])[0].t.extents=s;var p=a[0].t.poffset,d=Array.isArray(p);for(i=0;i<a.length;i++){var g=a[i],v=g[o]-g.w/2;if(n(v)){var m=g[o]+g.w/2,y=f(g.p);s[y]?s[y]=[Math.min(v,s[y][0]),Math.max(m,s[y][1])]:s[y]=[v,m]}g.p0=g.p+(d?p[i]:p),g.p1=g.p0+g.w,g.s0=g.b,g.s1=g.s0+g.s}}}(o,e)}}function h(t,e,r,n){for(var i=0;i<r.length;i++){var a=r[i],o=new c([a],{sepNegVal:!1,overlapNoMerge:!n.norm});f(t,o,n),n.norm?(m(o),y(e,o,n)):v(e,o)}}function f(t,e,r){for(var n=e.minDiff,i=e.traces,a=n*(1-r.gap),o=a*(1-(r.groupgap||0)),s=-o/2,l=0;l<i.length;l++){var c=i[l][0].t;c.barwidth=o,c.poffset=s,c.bargroupwidth=a,c.bardelta=n}e.binWidth=i[0][0].t.barwidth/100,p(e),d(t,e),g(t,e)}function p(t){var e,r,a=t.traces;for(e=0;e<a.length;e++){var o,s=a[e],l=s[0],c=l.trace,u=l.t,h=c._offset||c.offset,f=u.poffset;if(i(h)){for(o=Array.prototype.slice.call(h,0,s.length),r=0;r<o.length;r++)n(o[r])||(o[r]=f);for(r=o.length;r<s.length;r++)o.push(f);u.poffset=o}else void 0!==h&&(u.poffset=h);var p=c._width||c.width,d=u.barwidth;if(i(p)){var g=Array.prototype.slice.call(p,0,s.length);for(r=0;r<g.length;r++)n(g[r])||(g[r]=d);for(r=g.length;r<s.length;r++)g.push(d);if(u.barwidth=g,void 0===h){for(o=[],r=0;r<s.length;r++)o.push(f+(d-g[r])/2);u.poffset=o}}else void 0!==p&&(u.barwidth=p,void 0===h&&(u.poffset=f+(d-p)/2))}}function d(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++)for(var a=r[i],o=a[0].t,s=o.poffset,l=Array.isArray(s),c=o.barwidth,u=Array.isArray(c),h=0;h<a.length;h++){var f=a[h],p=f.w=u?c[h]:c;f[n]=f.p+(l?s[h]:s)+p/2}}function g(t,e,r){var n=e.traces,i=e.minDiff/2;s.minDtick(t,e.minDiff,e.distinctPositions[0],r);for(var a=0;a<n.length;a++){var o,l,c,u,h=n[a],f=h[0],p=f.trace,d=[];for(u=0;u<h.length;u++)l=(o=h[u]).p-i,c=o.p+i,d.push(l,c);if(p.width||p.offset){var g=f.t,v=g.poffset,m=g.barwidth,y=Array.isArray(v),x=Array.isArray(m);for(u=0;u<h.length;u++){o=h[u];var b=y?v[u]:v,_=x?m[u]:m;c=(l=o.p+b)+_,d.push(l,c)}}p._extremes[t._id]=s.findExtremes(t,d,{padded:!1})}}function v(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++){for(var a=r[i],o=a[0].trace,l=[],c=!0,u=0;u<a.length;u++){var h=a[u],f=h.b,p=f+h.s;h[n]=p,l.push(p),h.hasB&&l.push(f),h.hasB&&h.b>0&&h.s>0||(c=!1)}o._extremes[t._id]=s.findExtremes(t,l,{tozero:!c,padded:!0})}}function m(t){for(var e=t.traces,r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++){var o=n[i];o.s!==a&&t.put(o.p,o.b+o.s)}}function y(t,e,r){var i=e.traces,o=x(t),l=\"fraction\"===r.norm?1:100,c=l/1e9,u=t.l2c(t.c2l(0)),h=\"stack\"===r.mode?l:u;function f(e){return n(t.c2l(e))&&(e<u-c||e>h+c||!n(u))}for(var p=0;p<i.length;p++){for(var d=i[p],g=d[0].trace,v=[],m=!0,y=!1,b=0;b<d.length;b++){var _=d[b];if(_.s!==a){var w=Math.abs(l/e.get(_.p,_.s));_.b*=w,_.s*=w;var k=_.b,T=k+_.s;_[o]=T,v.push(T),y=y||f(T),_.hasB&&(v.push(k),y=y||f(k)),_.hasB&&_.b>0&&_.s>0||(m=!1)}}g._extremes[t._id]=s.findExtremes(t,v,{tozero:!m,padded:y})}}function x(t){return t._id.charAt(0)}e.exports={crossTraceCalc:function(t,e){for(var r=e.xaxis,n=e.yaxis,i=t._fullLayout,a=t._fullData,s=t.calcdata,l=[],c=[],h=0;h<a.length;h++){var f=a[h];!0===f.visible&&o.traceIs(f,\"bar\")&&f.xaxis===r._id&&f.yaxis===n._id&&(\"h\"===f.orientation?l.push(s[h]):c.push(s[h]))}var p={mode:i.barmode,norm:i.barnorm,gap:i.bargap,groupgap:i.bargroupgap};u(t,r,n,c,p),u(t,n,r,l,p)},setGroupPositions:u}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"./sieve.js\":869,\"fast-isnumeric\":225}],861:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../registry\"),o=t(\"../scatter/xy_defaults\"),s=t(\"./style_defaults\"),l=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,c=t(\"./attributes\"),u=n.coerceFont;function h(t,e,r,n){var i=e.orientation,a=e[{v:\"x\",h:\"y\"}[i]+\"axis\"],o=l(r,a)+i,s=r._alignmentOpts||{},c=n(\"alignmentgroup\"),u=s[o];u||(u=s[o]={});var h=u[c];h?h.traces.push(e):h=u[c]={traces:[e],alignmentIndex:Object.keys(u).length,offsetGroups:{}};var f=n(\"offsetgroup\"),p=h.offsetGroups,d=p[f];f&&(d||(d=p[f]={offsetIndex:Object.keys(p).length}),e._offsetIndex=d.offsetIndex)}function f(t,e,r,i,a,o){var s=!(!1===(o=o||{}).moduleHasSelected),l=!(!1===o.moduleHasUnselected),c=!(!1===o.moduleHasConstrain),h=!(!1===o.moduleHasCliponaxis),f=!(!1===o.moduleHasTextangle),p=!(!1===o.moduleHasInsideanchor),d=Array.isArray(a)||\"auto\"===a,g=d||\"inside\"===a,v=d||\"outside\"===a;if(g||v){var m=u(i,\"textfont\",r.font),y=n.extendFlat({},m);!(t.textfont&&t.textfont.color)&&delete y.color,u(i,\"insidetextfont\",y),v&&u(i,\"outsidetextfont\",m),s&&i(\"selected.textfont.color\"),l&&i(\"unselected.textfont.color\"),c&&i(\"constraintext\"),h&&i(\"cliponaxis\"),f&&i(\"textangle\")}g&&p&&i(\"insidetextanchor\")}e.exports={supplyDefaults:function(t,e,r,l){function u(r,i){return n.coerce(t,e,c,r,i)}if(o(t,e,l,u)){u(\"orientation\",e.x&&!e.y?\"h\":\"v\"),u(\"base\"),u(\"offset\"),u(\"width\"),u(\"text\"),u(\"hovertext\"),u(\"hovertemplate\");var h=u(\"textposition\");f(t,0,l,u,h,{moduleHasSelected:!0,moduleHasUnselected:!0,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),s(t,e,u,r,l);var p=(e.marker.line||{}).color,d=a.getComponentMethod(\"errorbars\",\"supplyDefaults\");d(t,e,p||i.defaultLine,{axis:\"y\"}),d(t,e,p||i.defaultLine,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,u)}else e.visible=!1},crossTraceDefaults:function(t,e){var r;function i(t){return n.coerce(r._input,r,c,t)}if(\"group\"===e.barmode)for(var a=0;a<t.length;a++)\"bar\"===(r=t[a]).type&&(r._input,h(0,r,e,i))},handleGroupingDefaults:h,handleText:f}},{\"../../components/color\":593,\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../scatter/xy_defaults\":1137,\"./attributes\":857,\"./style_defaults\":871}],862:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../../lib\").isArrayOrTypedArray;r.coerceString=function(t,e,r){if(\"string\"==typeof e){if(e||!t.noBlank)return e}else if((\"number\"==typeof e||!0===e)&&!t.strict)return String(e);return void 0!==r?r:t.dflt},r.coerceNumber=function(t,e,r){if(n(e)){e=+e;var i=t.min,a=t.max;if(!(void 0!==i&&e<i||void 0!==a&&e>a))return e}return void 0!==r?r:t.dflt},r.coerceColor=function(t,e,r){return i(e).isValid()?e:void 0!==r?r:t.dflt},r.coerceEnumerated=function(t,e,r){return t.coerceNumber&&(e=+e),-1!==t.values.indexOf(e)?e:void 0!==r?r:t.dflt},r.getValue=function(t,e){var r;return Array.isArray(t)?e<t.length&&(r=t[e]):r=t,r},r.getLineWidth=function(t,e){return 0<e.mlw?e.mlw:a(t.marker.line.width)?0:t.marker.line.width}},{\"../../lib\":719,\"fast-isnumeric\":225,tinycolor2:537}],863:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../../lib\").fillText,s=t(\"./helpers\").getLineWidth;function l(t,e,r,i){var a,s,l,c,u,h,f,p=t.cd,d=p[0].trace,g=p[0].t,v=\"closest\"===i,m=\"waterfall\"===d.type,y=t.maxHoverDistance,x=t.maxSpikeDistance;function b(t){return t[l]-t.w/2}function _(t){return t[l]+t.w/2}var w=v?b:function(t){return Math.min(b(t),t.p-g.bardelta/2)},k=v?_:function(t){return Math.max(_(t),t.p+g.bardelta/2)};function T(t,e){return n.inbox(t-a,e-a,y+Math.min(1,Math.abs(e-t)/f)-1)}function A(t){return T(w(t),k(t))}function M(t){var e=s,r=t.b,i=t[c];return m&&(i+=Math.abs(t.rawS||0)),n.inbox(r-e,i-e,y+(i-e)/(i-r)-1)}\"h\"===d.orientation?(a=r,s=e,l=\"y\",c=\"x\",u=M,h=A):(a=e,s=r,l=\"x\",c=\"y\",h=M,u=A);var S=t[l+\"a\"],E=t[c+\"a\"];f=Math.abs(S.r2c(S.range[1])-S.r2c(S.range[0]));var C=n.getDistanceFunction(i,u,h,function(t){return(u(t)+h(t))/2});if(n.getClosest(p,C,t),!1!==t.index){v||(w=function(t){return Math.min(b(t),t.p-g.bargroupwidth/2)},k=function(t){return Math.max(_(t),t.p+g.bargroupwidth/2)});var L=p[t.index],P=d.base?L.b+L.s:L.s;t[c+\"0\"]=t[c+\"1\"]=E.c2p(L[c],!0),t[c+\"LabelVal\"]=P;var O=g.extents[g.extents.round(L.p)];return t[l+\"0\"]=S.c2p(v?w(L):O[0],!0),t[l+\"1\"]=S.c2p(v?k(L):O[1],!0),t[l+\"LabelVal\"]=L.p,t.spikeDistance=(M(L)+function(t){return T(b(t),_(t))}(L))/2+x-y,t[l+\"Spike\"]=S.c2p(L.p,!0),o(L,d,t),t.hovertemplate=d.hovertemplate,t}}function c(t,e){var r=e.mcc||t.marker.color,n=e.mlcc||t.marker.line.color,i=s(t,e);return a.opacity(r)?r:a.opacity(n)&&i?n:void 0}e.exports={hoverPoints:function(t,e,r,n){var a=l(t,e,r,n);if(a){var o=a.cd,s=o[0].trace,u=o[a.index];return a.color=c(s,u),i.getComponentMethod(\"errorbars\",\"hoverInfo\")(u,s,a),[a]}},hoverOnBars:l,getTraceColor:c}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"../../registry\":847,\"./helpers\":862}],864:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,colorbar:t(\"../scatter/marker_colorbar\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"bar\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"oriented\",\"errorBarsOK\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../scatter/marker_colorbar\":1129,\"./arrays_to_calcdata\":856,\"./attributes\":857,\"./calc\":858,\"./cross_trace_calc\":860,\"./defaults\":861,\"./hover\":863,\"./layout_attributes\":865,\"./layout_defaults\":866,\"./plot\":867,\"./select\":868,\"./style\":870}],865:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\",\"relative\"],dflt:\"group\",editType:\"calc\"},barnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},bargap:{valType:\"number\",min:0,max:1,editType:\"calc\"},bargroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],866:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\"),o=t(\"./layout_attributes\");e.exports=function(t,e,r){function s(r,n){return a.coerce(t,e,o,r,n)}for(var l=!1,c=!1,u=!1,h={},f=s(\"barmode\"),p=0;p<r.length;p++){var d=r[p];if(n.traceIs(d,\"bar\")&&d.visible){if(l=!0,\"group\"===f){var g=d.xaxis+d.yaxis;h[g]&&(u=!0),h[g]=!0}if(d.visible&&\"histogram\"===d.type)\"category\"!==i.getFromId({_fullLayout:e},d[\"v\"===d.orientation?\"xaxis\":\"yaxis\"]).type&&(c=!0)}}l?(\"overlay\"!==f&&s(\"barnorm\"),s(\"bargap\",c&&!u?0:.2),s(\"bargroupgap\")):delete e.barmode}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./layout_attributes\":865}],867:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../registry\"),u=t(\"../../plots/cartesian/axes\").tickText,h=t(\"./style\"),f=t(\"./helpers\"),p=t(\"./attributes\"),d=p.text,g=p.textposition,v=3;function m(t,e){return t<e?1:-1}function y(t){return\"auto\"===t?0:t}function x(t,e,r,n,i,a){var o=!!a.isHorizontal,s=!!a.constrained,l=a.angle||0,c=a.anchor||0,u=i.width,h=i.height,f=Math.abs(e-t),p=Math.abs(n-r),d=f>2*v&&p>2*v?v:0;f-=2*d,p-=2*d;var g=!1;if(!(\"auto\"===l)||u<=f&&h<=p||!(u>f||h>p)||(u>p||h>f)&&u<h==f<p||(g=!0),g){var x=p;p=f,f=x}var b=y(l),_=Math.abs(Math.sin(Math.PI/180*b)),w=Math.abs(Math.cos(Math.PI/180*b)),k=Math.max(f*w,p*_),T=Math.max(f*_,p*w),A=s?Math.min(k/u,T/h):Math.max(w,_);A=Math.min(1,A);var M=(t+e)/2,S=(r+n)/2;\"middle\"!==c&&(d+=.5*(A*(o!==g?h:u)*_+A*(o!==g?u:h)*w),o?(d*=m(t,e),M=\"start\"===c?t+d:e-d):(d*=m(r,n),S=\"start\"===c?r+d:n-d));return g&&(b+=90),{textX:(i.left+i.right)/2,textY:(i.top+i.bottom)/2,targetX:M,targetY:S,scale:A,rotate:b}}function b(t,e,r,n,i,a){var o,s=!!a.isHorizontal,l=!!a.constrained,c=a.angle||0,u=i.width,h=i.height,f=Math.abs(e-t),p=Math.abs(n-r);o=s?p>2*v?v:0:f>2*v?v:0;var d=1;l&&(d=s?Math.min(1,p/h):Math.min(1,f/u));var g=y(c);o+=.5*(d*(s?h:u)*Math.abs(Math.sin(Math.PI/180*g))+d*(s?u:h)*Math.abs(Math.cos(Math.PI/180*g)));var x=(t+e)/2,b=(r+n)/2;return s?x=e-o*m(e,t):b=n+o*m(r,n),{textX:(i.left+i.right)/2,textY:(i.top+i.bottom)/2,targetX:x,targetY:b,scale:d,rotate:g}}function _(t){var e,r=t.textX,n=t.textY,i=t.targetX,a=t.targetY,o=t.scale,s=t.rotate;return o<1?e=\"scale(\"+o+\") \":(o=1,e=\"\"),\"translate(\"+(i-o*r)+\" \"+(a-o*n)+\")\"+e+(s?\"rotate(\"+s+\" \"+r+\" \"+n+\") \":\"\")}e.exports={plot:function(t,e,r,p,y){var w=e.xaxis,k=e.yaxis,T=t._fullLayout;y||(y={mode:T.barmode,norm:T.barmode,gap:T.bargap,groupgap:T.bargroupgap});var A=a.makeTraceGroups(p,r,\"trace bars\").each(function(r){var c=n.select(this),p=r[0].trace,T=\"waterfall\"===p.type,A=\"funnel\"===p.type,M=\"bar\"===p.type||A,S=0;T&&p.connector.visible&&\"between\"===p.connector.mode&&(S=p.connector.line.width/2);var E=\"h\"===p.orientation,C=a.ensureSingle(c,\"g\",\"points\").selectAll(\"g.point\").data(a.identity);C.enter().append(\"g\").classed(\"point\",!0),C.exit().remove(),C.each(function(c,T){var A,C,L=n.select(this),P=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),n?[i,a]:[a,i]}(c,w,k,E),O=P[0][0],z=P[0][1],I=P[1][0],D=P[1][1],R=!(O!==z&&I!==D&&i(O)&&i(z)&&i(I)&&i(D));if(R&&M&&f.getLineWidth(p,c)&&(E?z-O==0:D-I==0)&&(R=!1),c.isBlank=R,S&&(E?(O-=m(O,z)*S,z+=m(O,z)*S):(I-=m(I,D)*S,D+=m(I,D)*S)),\"waterfall\"===p.type){if(!R){var F=p[c.dir].marker;A=F.line.width,C=F.color}}else A=f.getLineWidth(p,c),C=c.mc||p.marker.color;var B=n.round(A/2%1,2);function N(t){return 0===y.gap&&0===y.groupgap?n.round(Math.round(t)-B,2):t}if(!t._context.staticPlot){var j=s.opacity(C)<1||A>.01?N:function(t,e){return Math.abs(t-e)>=2?N(t):t>e?Math.ceil(t):Math.floor(t)};O=j(O,z),z=j(z,O),I=j(I,D),D=j(D,I)}a.ensureSingle(L,\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"d\",R?\"M0,0Z\":\"M\"+O+\",\"+I+\"V\"+D+\"H\"+z+\"V\"+I+\"Z\").call(l.setClipUrl,e.layerClipId,t),function(t,e,r,n,i,s,c,p,m,y){var w,k=e.xaxis,T=e.yaxis,A=t._fullLayout;function M(e,r,n){var i=a.ensureSingle(e,\"text\").text(r).attr({class:\"bartext bartext-\"+w,transform:\"\",\"text-anchor\":\"middle\",\"data-notex\":1}).call(l.font,n).call(o.convertToTspans,t);return i}var S=n[0].trace,E=\"h\"===S.orientation,C=function(t,e,r,n){var i,o=t[0].trace;return i=o.textinfo?function(t,e,r,n){var i=t[0].trace,o=\"h\"===i.orientation,s=\"waterfall\"===i.type,l=\"funnel\"===i.type;function c(t){var e=o?r:n;return u(e,+t,!0).text}var h,f,p=i.textinfo,d=t[e],g=p.split(\"+\"),v=[],m=function(t){return-1!==g.indexOf(t)};if(m(\"label\")&&v.push((f=t[e].p,u(o?n:r,f,!0).text)),m(\"text\")&&(0===(h=a.castOption(i,d.i,\"text\"))||h)&&v.push(h),s){var y=+d.rawS||d.s,x=d.v,b=x-y;m(\"initial\")&&v.push(c(b)),m(\"delta\")&&v.push(c(y)),m(\"final\")&&v.push(c(x))}if(l){m(\"value\")&&v.push(c(d.s));var _=0;m(\"percent initial\")&&_++,m(\"percent previous\")&&_++,m(\"percent total\")&&_++;var w=_>1;m(\"percent initial\")&&(h=a.formatPercent(d.begR),w&&(h+=\" of initial\"),v.push(h)),m(\"percent previous\")&&(h=a.formatPercent(d.difR),w&&(h+=\" of previous\"),v.push(h)),m(\"percent total\")&&(h=a.formatPercent(d.sumR),w&&(h+=\" of total\"),v.push(h))}return v.join(\"<br>\")}(t,e,r,n):f.getValue(o.text,e),f.coerceString(d,i)}(n,i,k,T);w=function(t,e){var r=f.getValue(t.textposition,e);return f.coerceEnumerated(g,r)}(S,i);var L=\"stack\"===y.mode||\"relative\"===y.mode,P=n[i],O=!L||P._outmost;if(C&&\"none\"!==w&&(!P.isBlank&&s!==c&&p!==m||\"auto\"!==w&&\"inside\"!==w)){var z=A.font,I=h.getBarColor(n[i],S),D=h.getInsideTextFont(S,i,z,I),R=h.getOutsideTextFont(S,i,z),F=r.datum();E?\"log\"===k.type&&F.s0<=0&&(s=k.range[0]<k.range[1]?0:k._length):\"log\"===T.type&&F.s0<=0&&(p=T.range[0]<T.range[1]?T._length:0);var B,N,j,U,V,q,H=Math.abs(c-s)-2*v,G=Math.abs(m-p)-2*v;if(\"outside\"===w&&(O||P.hasB||(w=\"inside\")),\"auto\"===w)if(O){w=\"inside\",B=M(r,C,D),N=l.bBox(B.node()),j=N.width,U=N.height;var Y=j>0&&U>0,W=j<=H&&U<=G,X=j<=G&&U<=H,Z=E?H>=j*(G/U):G>=U*(H/j);Y&&(W||X||Z)?w=\"inside\":(w=\"outside\",B.remove(),B=null)}else w=\"inside\";!B&&(B=M(r,C,\"outside\"===w?R:D),N=l.bBox(B.node()),j=N.width,U=N.height,j<=0||U<=0)?B.remove():(\"outside\"===w?(q=\"both\"===S.constraintext||\"outside\"===S.constraintext,V=_(b(s,c,p,m,N,{isHorizontal:E,constrained:q,angle:S.textangle}))):(q=\"both\"===S.constraintext||\"inside\"===S.constraintext,V=_(x(s,c,p,m,N,{isHorizontal:E,constrained:q,angle:S.textangle,anchor:S.insidetextanchor}))),B.attr(\"transform\",V))}else r.select(\"text\").remove()}(t,e,L,r,T,O,z,I,D,y),e.layerClipId&&l.hideOutsideRangePoint(c,L.select(\"text\"),w,k,p.xcalendar,p.ycalendar)});var L=!1===p.cliponaxis;l.setClipUrl(c,L?null:e.layerClipId,t)});c.getComponentMethod(\"errorbars\",\"plot\")(t,A,e)},getTransform:_,toMoveInsideBar:x,toMoveOutsideBar:b}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./attributes\":857,\"./helpers\":862,\"./style\":870,d3:163,\"fast-isnumeric\":225}],868:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=e.c2p(n?t.s0:t.p0,!0),o=e.c2p(n?t.s1:t.p1,!0),s=r.c2p(n?t.p0:t.s0,!0),l=r.c2p(n?t.p1:t.s1,!0);return i?[(a+o)/2,(s+l)/2]:n?[o,(s+l)/2]:[(a+o)/2,l]}e.exports=function(t,e){var r,i=t.cd,a=t.xaxis,o=t.yaxis,s=i[0].trace,l=\"funnel\"===s.type,c=\"h\"===s.orientation,u=[];if(!1===e)for(r=0;r<i.length;r++)i[r].selected=0;else for(r=0;r<i.length;r++){var h=i[r],f=\"ct\"in h?h.ct:n(h,a,o,c,l);e.contains(f,!1,r,t)?(u.push({pointNumber:r,x:a.c2d(h.x),y:o.c2d(h.y)}),h.selected=1):h.selected=0}return u}},{}],869:[function(t,e,r){\"use strict\";e.exports=a;var n=t(\"../../lib\").distinctVals,i=t(\"../../constants/numerical\").BADNUM;function a(t,e){this.traces=t,this.sepNegVal=e.sepNegVal,this.overlapNoMerge=e.overlapNoMerge;for(var r=1/0,a=[],o=0;o<t.length;o++){for(var s=t[o],l=0;l<s.length;l++){var c=s[l];c.p!==i&&a.push(c.p)}s[0]&&s[0].width1&&(r=Math.min(s[0].width1,r))}this.positions=a;var u=n(a);this.distinctPositions=u.vals,1===u.vals.length&&r!==1/0?this.minDiff=r:this.minDiff=Math.min(u.minDiff,r),this.binWidth=this.minDiff,this.bins={}}a.prototype.put=function(t,e){var r=this.getLabel(t,e),n=this.bins[r]||0;return this.bins[r]=n+e,n},a.prototype.get=function(t,e){var r=this.getLabel(t,e);return this.bins[r]||0},a.prototype.getLabel=function(t,e){return(e<0&&this.sepNegVal?\"v\":\"^\")+(this.overlapNoMerge?t:Math.round(t/this.binWidth))}},{\"../../constants/numerical\":695,\"../../lib\":719}],870:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../lib\"),s=t(\"../../registry\"),l=t(\"./attributes\"),c=l.textfont,u=l.insidetextfont,h=l.outsidetextfont,f=t(\"./helpers\");function p(t,e,r){a.pointStyle(t.selectAll(\"path\"),e,r),d(t,e,r)}function d(t,e,r){t.selectAll(\"text\").each(function(t){var i=n.select(this),o=g(i,t,e,r);a.font(i,o)})}function g(t,e,r,n){var i=n._fullLayout.font,a=r.textfont;if(t.classed(\"bartext-inside\")){var o=b(e,r);a=m(r,e.i,i,o)}else t.classed(\"bartext-outside\")&&(a=y(r,e.i,i));return a}function v(t,e,r){return x(c,t.textfont,e,r)}function m(t,e,r,n){var a=v(t,e,r);return(void 0===t._input.textfont||void 0===t._input.textfont.color||Array.isArray(t.textfont.color)&&void 0===t.textfont.color[e])&&(a={color:i.contrast(n),family:a.family,size:a.size}),x(u,t.insidetextfont,e,a)}function y(t,e,r){var n=v(t,e,r);return x(h,t.outsidetextfont,e,n)}function x(t,e,r,n){e=e||{};var i=f.getValue(e.family,r),a=f.getValue(e.size,r),o=f.getValue(e.color,r);return{family:f.coerceString(t.family,i,n.family),size:f.coerceNumber(t.size,a,n.size),color:f.coerceColor(t.color,o,n.color)}}function b(t,e){return\"waterfall\"===e.type?e[t.dir].marker.color:t.mc||e.marker.color}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.barlayer\").selectAll(\"g.trace\"),r=e.size(),i=t._fullLayout;e.style(\"opacity\",function(t){return t[0].trace.opacity}).each(function(t){(\"stack\"===i.barmode&&r>1||0===i.bargap&&0===i.bargroupgap&&!t[0].trace.marker.line.width)&&n.select(this).attr(\"shape-rendering\",\"crispEdges\")}),e.selectAll(\"g.points\").each(function(e){p(n.select(this),e[0].trace,t)}),s.getComponentMethod(\"errorbars\",\"style\")(e)},styleTextPoints:d,styleOnSelect:function(t,e,r){var i=e[0].trace;i.selectedpoints?function(t,e,r){a.selectedPointStyle(t.selectAll(\"path\"),e),function(t,e,r){t.each(function(t){var i,s=n.select(this);if(t.selected){i=o.extendFlat({},g(s,t,e,r));var l=e.selected.textfont&&e.selected.textfont.color;l&&(i.color=l),a.font(s,i)}else a.selectedTextStyle(s,e)})}(t.selectAll(\"text\"),e,r)}(r,i,t):(p(r,i,t),s.getComponentMethod(\"errorbars\",\"style\")(r))},getInsideTextFont:m,getOutsideTextFont:y,getBarColor:b}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../registry\":847,\"./attributes\":857,\"./helpers\":862,d3:163}],871:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s){r(\"marker.color\",o),i(t,\"marker\")&&a(t,e,s,r,{prefix:\"marker.\",cLetter:\"c\"}),r(\"marker.line.color\",n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,r,{prefix:\"marker.line.\",cLetter:\"c\"}),r(\"marker.line.width\"),r(\"marker.opacity\"),r(\"selected.marker.color\"),r(\"unselected.marker.color\")}},{\"../../components/color\":593,\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604}],872:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../scatterpolar/attributes\"),o=t(\"../bar/attributes\");e.exports={r:a.r,theta:a.theta,r0:a.r0,dr:a.dr,theta0:a.theta0,dtheta:a.dtheta,thetaunit:a.thetaunit,base:i({},o.base,{}),offset:i({},o.offset,{}),width:i({},o.width,{}),text:i({},o.text,{}),hovertext:i({},o.hovertext,{}),marker:o.marker,hoverinfo:a.hoverinfo,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../bar/attributes\":857,\"../scatterpolar/attributes\":1179}],873:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"../bar/arrays_to_calcdata\"),o=t(\"../bar/cross_trace_calc\").setGroupPositions,s=t(\"../scatter/calc_selection\"),l=t(\"../../registry\").traceIs,c=t(\"../../lib\").extendFlat;e.exports={calc:function(t,e){for(var r=t._fullLayout,o=e.subplot,l=r[o].radialaxis,c=r[o].angularaxis,u=l.makeCalcdata(e,\"r\"),h=c.makeCalcdata(e,\"theta\"),f=e._length,p=new Array(f),d=u,g=h,v=0;v<f;v++)p[v]={p:g[v],s:d[v]};function m(t){var r=e[t];void 0!==r&&(e[\"_\"+t]=Array.isArray(r)?c.makeCalcdata(e,t):c.d2c(r,e.thetaunit))}return\"linear\"===c.type&&(m(\"width\"),m(\"offset\")),n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),a(p,e),s(p,e),p},crossTraceCalc:function(t,e,r){for(var n=t.calcdata,i=[],a=0;a<n.length;a++){var s=n[a],u=s[0].trace;!0===u.visible&&l(u,\"bar\")&&u.subplot===r&&i.push(s)}var h=c({},e.radialaxis,{_id:\"x\"}),f=e.angularaxis;o(t,f,h,i,{mode:e.barmode,norm:e.barnorm,gap:e.bargap,groupgap:e.bargroupgap})}}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"../../lib\":719,\"../../registry\":847,\"../bar/arrays_to_calcdata\":856,\"../bar/cross_trace_calc\":860,\"../scatter/calc_selection\":1114}],874:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatterpolar/defaults\").handleRThetaDefaults,a=t(\"../bar/style_defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}i(t,e,s,l)?(l(\"thetaunit\"),l(\"base\"),l(\"offset\"),l(\"width\"),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),a(t,e,l,r,s),n.coerceSelectionMarkerOpacity(e,l)):e.visible=!1}},{\"../../lib\":719,\"../bar/style_defaults\":871,\"../scatterpolar/defaults\":1181,\"./attributes\":872}],875:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../bar/hover\").getTraceColor,o=i.fillText,s=t(\"../scatterpolar/hover\").makeHoverPointText,l=t(\"../../plots/polar/helpers\").isPtInsidePolygon;e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,h=t.subplot,f=h.radialAxis,p=h.angularAxis,d=h.vangles,g=d?l:i.isPtInsideSector,v=t.maxHoverDistance,m=p._period||2*Math.PI,y=Math.abs(f.g2p(Math.sqrt(e*e+r*r))),x=Math.atan2(r,e);f.range[0]>f.range[1]&&(x+=Math.PI);if(n.getClosest(c,function(t){return g(y,x,[t.rp0,t.rp1],[t.thetag0,t.thetag1],d)?v+Math.min(1,Math.abs(t.thetag1-t.thetag0)/m)-1+(t.rp1-y)/(t.rp1-t.rp0)-1:1/0},t),!1!==t.index){var b=c[t.index];t.x0=t.x1=b.ct[0],t.y0=t.y1=b.ct[1];var _=i.extendFlat({},b,{r:b.s,theta:b.p});return o(b,u,t),s(_,u,h,t),t.hovertemplate=u.hovertemplate,t.color=a(u,b),t.xLabelVal=t.yLabelVal=void 0,b.s<0&&(t.idealAlign=\"left\"),[t]}}},{\"../../components/fx\":632,\"../../lib\":719,\"../../plots/polar/helpers\":830,\"../bar/hover\":863,\"../scatterpolar/hover\":1182}],876:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"barpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"bar\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),colorbar:t(\"../scatter/marker_colorbar\"),style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),meta:{}}},{\"../../plots/polar\":831,\"../bar/select\":868,\"../bar/style\":870,\"../scatter/marker_colorbar\":1129,\"./attributes\":872,\"./calc\":873,\"./defaults\":874,\"./hover\":875,\"./layout_attributes\":877,\"./layout_defaults\":878,\"./plot\":879}],877:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},bargap:{valType:\"number\",dflt:.1,min:0,max:1,editType:\"calc\"}}},{}],878:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a,o={};function s(r,o){return n.coerce(t[a]||{},e[a],i,r,o)}for(var l=0;l<r.length;l++){var c=r[l];\"barpolar\"===c.type&&!0===c.visible&&(o[a=c.subplot]||(s(\"barmode\"),s(\"bargap\"),o[a]=1))}}},{\"../../lib\":719,\"./layout_attributes\":877}],879:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../components/drawing\"),s=t(\"../../plots/polar/helpers\");e.exports=function(t,e,r){var l=e.xaxis,c=e.yaxis,u=e.radialAxis,h=e.angularAxis,f=function(t){var e=t.cxx,r=t.cyy;if(t.vangles)return function(n,i,o,l){var c,u;a.angleDelta(o,l)>0?(c=o,u=l):(c=l,u=o);var h=s.findEnclosingVertexAngles(c,t.vangles)[0],f=s.findEnclosingVertexAngles(u,t.vangles)[1],p=[h,(c+u)/2,f];return s.pathPolygonAnnulus(n,i,c,u,p,e,r)};return function(t,n,i,o){return a.pathAnnulus(t,n,i,o,e,r)}}(e),p=e.layers.frontplot.select(\"g.barlayer\");a.makeTraceGroups(p,r,\"trace bars\").each(function(){var r=n.select(this),s=a.ensureSingle(r,\"g\",\"points\").selectAll(\"g.point\").data(a.identity);s.enter().append(\"g\").style(\"vector-effect\",\"non-scaling-stroke\").style(\"stroke-miterlimit\",2).classed(\"point\",!0),s.exit().remove(),s.each(function(t){var e,r=n.select(this),o=t.rp0=u.c2p(t.s0),s=t.rp1=u.c2p(t.s1),p=t.thetag0=h.c2g(t.p0),d=t.thetag1=h.c2g(t.p1);if(i(o)&&i(s)&&i(p)&&i(d)&&o!==s&&p!==d){var g=u.c2g(t.s1),v=(p+d)/2;t.ct=[l.c2p(g*Math.cos(v)),c.c2p(g*Math.sin(v))],e=f(o,s,p,d)}else e=\"M0,0Z\";a.ensureSingle(r,\"path\").attr(\"d\",e)}),o.setClipUrl(r,e._hasClipOnAxisFalse?e.clipIds.forTraces:null,t)})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../plots/polar/helpers\":830,d3:163,\"fast-isnumeric\":225}],880:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../bar/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../lib/extend\").extendFlat,l=n.marker,c=l.line;e.exports={y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},y0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},name:{valType:\"string\",editType:\"calc+clearAxisTypes\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),hovertemplate:o({}),whiskerwidth:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"calc\"},notched:{valType:\"boolean\",editType:\"calc\"},notchwidth:{valType:\"number\",min:0,max:.5,dflt:.25,editType:\"calc\"},boxpoints:{valType:\"enumerated\",values:[\"all\",\"outliers\",\"suspectedoutliers\",!1],dflt:\"outliers\",editType:\"calc\"},boxmean:{valType:\"enumerated\",values:[!0,\"sd\",!1],dflt:!1,editType:\"calc\"},jitter:{valType:\"number\",min:0,max:1,editType:\"calc\"},pointpos:{valType:\"number\",min:-2,max:2,editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},width:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},marker:{outliercolor:{valType:\"color\",dflt:\"rgba(0, 0, 0, 0)\",editType:\"style\"},symbol:s({},l.symbol,{arrayOk:!1,editType:\"plot\"}),opacity:s({},l.opacity,{arrayOk:!1,dflt:1,editType:\"style\"}),size:s({},l.size,{arrayOk:!1,editType:\"calc\"}),color:s({},l.color,{arrayOk:!1,editType:\"style\"}),line:{color:s({},c.color,{arrayOk:!1,dflt:a.defaultLine,editType:\"style\"}),width:s({},c.width,{arrayOk:!1,dflt:0,editType:\"style\"}),outliercolor:{valType:\"color\",editType:\"style\"},outlierwidth:{valType:\"number\",min:0,dflt:1,editType:\"style\"},editType:\"style\"},editType:\"plot\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,offsetgroup:i.offsetgroup,alignmentgroup:i.alignmentgroup,selected:{marker:n.selected.marker,editType:\"style\"},unselected:{marker:n.unselected.marker,editType:\"style\"},hoveron:{valType:\"flaglist\",flags:[\"boxes\",\"points\"],dflt:\"boxes+points\",editType:\"style\"}}},{\"../../components/color/attributes\":592,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../bar/attributes\":857,\"../scatter/attributes\":1112}],881:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=i._,o=t(\"../../plots/cartesian/axes\");function s(t,e,r){var n={text:\"tx\",hovertext:\"htx\"};for(var i in n)Array.isArray(e[i])&&(t[n[i]]=e[i][r])}function l(t,e){return t.v-e.v}function c(t){return t.v}e.exports=function(t,e){var r,u,h,f,p,d=t._fullLayout,g=o.getFromId(t,e.xaxis||\"x\"),v=o.getFromId(t,e.yaxis||\"y\"),m=[],y=\"violin\"===e.type?\"_numViolins\":\"_numBoxes\";\"h\"===e.orientation?(u=g,h=\"x\",f=v,p=\"y\"):(u=v,h=\"y\",f=g,p=\"x\");var x,b=u.makeCalcdata(e,h),_=function(t,e,r,a,o){if(e in t)return r.makeCalcdata(t,e);var s;s=e+\"0\"in t?t[e+\"0\"]:\"name\"in t&&(\"category\"===r.type||n(t.name)&&-1!==[\"linear\",\"log\"].indexOf(r.type)||i.isDateTime(t.name)&&\"date\"===r.type)?t.name:o;var l=\"multicategory\"===r.type?r.r2c_just_indices(s):r.d2c(s,0,t[e+\"calendar\"]);return a.map(function(){return l})}(e,p,f,b,d[y]),w=i.distinctVals(_),k=w.vals,T=w.minDiff/2,A=function(t,e){for(var r=t.length,n=new Array(r+1),i=0;i<r;i++)n[i]=t[i]-e;return n[r]=t[r-1]+e,n}(k,T),M=k.length,S=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=[];return e}(M);for(r=0;r<e._length;r++){var E=b[r];if(n(E)){var C=i.findBin(_[r],A);if(C>=0&&C<M){var L={v:E,i:r};s(L,e,r),S[C].push(L)}}}var P=\"all\"===(e.boxpoints||e.points)?i.identity:function(t){return t.v<x.lf||t.v>x.uf};for(r=0;r<M;r++)if(S[r].length>0){var O=S[r].sort(l),z=O.map(c),I=z.length;(x={}).pos=k[r],x.pts=O,x[p]=x.pos,x[h]=x.pts.map(function(t){return t.v}),x.min=z[0],x.max=z[I-1],x.mean=i.mean(z,I),x.sd=i.stdev(z,I,x.mean),x.q1=i.interp(z,.25),x.med=i.interp(z,.5),x.q3=i.interp(z,.75),x.lf=Math.min(x.q1,z[Math.min(i.findBin(2.5*x.q1-1.5*x.q3,z,!0)+1,I-1)]),x.uf=Math.max(x.q3,z[Math.max(i.findBin(2.5*x.q3-1.5*x.q1,z),0)]),x.lo=4*x.q1-3*x.q3,x.uo=4*x.q3-3*x.q1;var D=1.57*(x.q3-x.q1)/Math.sqrt(I);x.ln=x.med-D,x.un=x.med+D,x.pts2=O.filter(P),m.push(x)}!function(t,e){if(i.isArrayOrTypedArray(e.selectedpoints))for(var r=0;r<t.length;r++){for(var n=t[r].pts||[],a={},o=0;o<n.length;o++)a[n[o].i]=o;i.tagSelected(n,e,a)}}(m,e);var R=o.findExtremes(u,b,{padded:!0});return e._extremes[u._id]=R,m.length>0?(m[0].t={num:d[y],dPos:T,posLetter:p,valLetter:h,labels:{med:a(t,\"median:\"),min:a(t,\"min:\"),q1:a(t,\"q1:\"),q3:a(t,\"q3:\"),max:a(t,\"max:\"),mean:\"sd\"===e.boxmean?a(t,\"mean \\xb1 \\u03c3:\"):a(t,\"mean:\"),lf:a(t,\"lower fence:\"),uf:a(t,\"upper fence:\")}},d[y]++,m):[{t:{empty:!0}}]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"fast-isnumeric\":225}],882:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,o=[\"v\",\"h\"];function s(t,e,r,o){var s,l,c,u=e.calcdata,h=e._fullLayout,f=o._id,p=f.charAt(0),d=[],g=0;for(s=0;s<r.length;s++)for(c=u[r[s]],l=0;l<c.length;l++)d.push(c[l].pos),g+=(c[l].pts2||[]).length;if(d.length){var v=i.distinctVals(d),m=v.minDiff/2;n.minDtick(o,v.minDiff,v.vals[0],!0);var y=h[\"violin\"===t?\"_numViolins\":\"_numBoxes\"],x=\"group\"===h[t+\"mode\"]&&y>1,b=1-h[t+\"gap\"],_=1-h[t+\"groupgap\"];for(s=0;s<r.length;s++){var w,k,T,A,M,S,E=(c=u[r[s]])[0].trace,C=c[0].t,L=E.width,P=E.side;if(L)w=k=A=L/2,T=0;else if(w=m,x){var O=a(h,o._id)+E.orientation,z=(h._alignmentOpts[O]||{})[E.alignmentgroup]||{},I=Object.keys(z.offsetGroups||{}).length,D=I||y;k=w*b*_/D,T=2*w*(((I?E._offsetIndex:C.num)+.5)/D-.5)*b,A=w*b/D}else k=w*b*_,T=0,A=w;C.dPos=w,C.bPos=T,C.bdPos=k,C.wHover=A;var R,F,B,N,j,U,V=T+k,q=Boolean(L);if(\"positive\"===P?(M=w*(L?1:.5),R=V,S=R=T):\"negative\"===P?(M=R=T,S=w*(L?1:.5),F=V):(M=S=w,R=F=V),(E.boxpoints||E.points)&&g>0){var H=E.pointpos,G=E.jitter,Y=E.marker.size/2,W=0;H+G>=0&&((W=V*(H+G))>M?(q=!0,j=Y,B=W):W>R&&(j=Y,B=M)),W<=M&&(B=M);var X=0;H-G<=0&&((X=-V*(H-G))>S?(q=!0,U=Y,N=X):X>F&&(U=Y,N=S)),X<=S&&(N=S)}else B=M,N=S;var Z=new Array(c.length);for(l=0;l<c.length;l++)Z[l]=c[l].pos;E._extremes[f]=n.findExtremes(o,Z,{padded:q,vpadminus:N,vpadplus:B,ppadminus:{x:U,y:j}[p],ppadplus:{x:j,y:U}[p]})}}}e.exports={crossTraceCalc:function(t,e){for(var r=t.calcdata,n=e.xaxis,i=e.yaxis,a=0;a<o.length;a++){for(var l=o[a],c=\"h\"===l?i:n,u=[],h=0;h<r.length;h++){var f=r[h],p=f[0].t,d=f[0].trace;!0!==d.visible||\"box\"!==d.type&&\"candlestick\"!==d.type||p.empty||(d.orientation||\"v\")!==l||d.xaxis!==n._id||d.yaxis!==i._id||u.push(h)}s(\"box\",t,u,c)}},setPositionOffset:s}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_ids\":770}],883:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../bar/defaults\").handleGroupingDefaults,s=t(\"./attributes\");function l(t,e,r,a){var o,s,l=r(\"y\"),c=r(\"x\"),u=c&&c.length;if(l&&l.length)o=\"v\",u?s=Math.min(n.minRowLength(c),n.minRowLength(l)):(r(\"x0\"),s=n.minRowLength(l));else{if(!u)return void(e.visible=!1);o=\"h\",r(\"y0\"),s=n.minRowLength(c)}e._length=s,i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a),r(\"orientation\",o)}function c(t,e,r,i){var a=i.prefix,o=n.coerce2(t,e,s,\"marker.outliercolor\"),l=r(\"marker.line.outliercolor\"),c=r(a+\"points\",o||l?\"suspectedoutliers\":void 0);c?(r(\"jitter\",\"all\"===c?.3:0),r(\"pointpos\",\"all\"===c?-1.5:0),r(\"marker.symbol\"),r(\"marker.opacity\"),r(\"marker.size\"),r(\"marker.color\",e.line.color),r(\"marker.line.color\"),r(\"marker.line.width\"),\"suspectedoutliers\"===c&&(r(\"marker.line.outliercolor\",e.marker.color),r(\"marker.line.outlierwidth\")),r(\"selected.marker.color\"),r(\"unselected.marker.color\"),r(\"selected.marker.size\"),r(\"unselected.marker.size\"),r(\"text\"),r(\"hovertext\")):delete e.marker;var u=r(\"hoveron\");\"all\"!==u&&-1===u.indexOf(\"points\")||r(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,r)}e.exports={supplyDefaults:function(t,e,r,i){function o(r,i){return n.coerce(t,e,s,r,i)}l(t,e,o,i),!1!==e.visible&&(o(\"line.color\",(t.marker||{}).color||r),o(\"line.width\"),o(\"fillcolor\",a.addOpacity(e.line.color,.5)),o(\"whiskerwidth\"),o(\"boxmean\"),o(\"width\"),o(\"notched\",void 0!==t.notchwidth)&&o(\"notchwidth\"),c(t,e,o,{prefix:\"box\"}))},crossTraceDefaults:function(t,e){var r,i;function a(t){return n.coerce(i._input,i,s,t)}for(var l=0;l<t.length;l++){var c=(i=t[l]).type;\"box\"!==c&&\"violin\"!==c||(r=i._input,\"group\"===e[c+\"mode\"]&&o(r,i,e,a))}},handleSampleDefaults:l,handlePointsDefaults:c}},{\"../../components/color\":593,\"../../lib\":719,\"../../registry\":847,\"../bar/defaults\":861,\"./attributes\":880}],884:[function(t,e,r){\"use strict\";e.exports=function(t,e){return e.hoverOnBox&&(t.hoverOnBox=e.hoverOnBox),\"xVal\"in e&&(t.x=e.xVal),\"yVal\"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],885:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=i.fillText;function l(t,e,r,s){var l,c,u,h,f,p,d,g,v,m,y,x,b,_,w=t.cd,k=t.xa,T=t.ya,A=w[0].trace,M=w[0].t,S=\"violin\"===A.type,E=[],C=M.bdPos,L=M.wHover,P=function(t){return t.pos+M.bPos-p};S&&\"both\"!==A.side?(\"positive\"===A.side&&(v=function(t){var e=P(t);return a.inbox(e,e+L,m)},x=C,b=0),\"negative\"===A.side&&(v=function(t){var e=P(t);return a.inbox(e-L,e,m)},x=0,b=C)):(v=function(t){var e=P(t);return a.inbox(e-L,e+L,m)},x=b=C),_=S?function(t){return a.inbox(t.span[0]-f,t.span[1]-f,m)}:function(t){return a.inbox(t.min-f,t.max-f,m)},\"h\"===A.orientation?(f=e,p=r,d=_,g=v,l=\"y\",u=T,c=\"x\",h=k):(f=r,p=e,d=v,g=_,l=\"x\",u=k,c=\"y\",h=T);var O=Math.min(1,C/Math.abs(u.r2c(u.range[1])-u.r2c(u.range[0])));function z(t){return(d(t)+g(t))/2}m=t.maxHoverDistance-O,y=t.maxSpikeDistance-O;var I=a.getDistanceFunction(s,d,g,z);if(a.getClosest(w,I,t),!1===t.index)return[];var D=w[t.index],R=A.line.color,F=(A.marker||{}).color;o.opacity(R)&&A.line.width?t.color=R:o.opacity(F)&&A.boxpoints?t.color=F:t.color=A.fillcolor,t[l+\"0\"]=u.c2p(D.pos+M.bPos-b,!0),t[l+\"1\"]=u.c2p(D.pos+M.bPos+x,!0),t[l+\"LabelVal\"]=D.pos;var B=l+\"Spike\";t.spikeDistance=z(D)*y/m,t[B]=u.c2p(D.pos,!0);var N={},j=[\"med\",\"q1\",\"q3\",\"min\",\"max\"];(A.boxmean||(A.meanline||{}).visible)&&j.push(\"mean\"),(A.boxpoints||A.points)&&j.push(\"lf\",\"uf\");for(var U=0;U<j.length;U++){var V=j[U];if(V in D&&!(D[V]in N)){N[D[V]]=!0;var q=D[V],H=h.c2p(q,!0),G=i.extendFlat({},t);G.attr=V,G[c+\"0\"]=G[c+\"1\"]=H,G[c+\"LabelVal\"]=q,G[c+\"Label\"]=(M.labels?M.labels[V]+\" \":\"\")+n.hoverLabelText(h,q),G.hoverOnBox=!0,\"mean\"===V&&\"sd\"in D&&\"sd\"===A.boxmean&&(G[c+\"err\"]=D.sd),t.name=\"\",t.spikeDistance=void 0,t[B]=void 0,G.hovertemplate=!1,E.push(G)}}return E}function c(t,e,r){for(var n,o,l,c=t.cd,u=t.xa,h=t.ya,f=c[0].trace,p=u.c2p(e),d=h.c2p(r),g=a.quadrature(function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(u.c2p(t.x)-p)-e,1-3/e)},function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(h.c2p(t.y)-d)-e,1-3/e)}),v=!1,m=0;m<c.length;m++){o=c[m];for(var y=0;y<(o.pts||[]).length;y++){var x=g(l=o.pts[y]);x<=t.distance&&(t.distance=x,v=[m,y])}}if(!v)return!1;l=(o=c[v[0]]).pts[v[1]];var b,_=u.c2p(l.x,!0),w=h.c2p(l.y,!0),k=l.mrc||1;return n=i.extendFlat({},t,{index:l.i,color:(f.marker||{}).color,name:f.name,x0:_-k,x1:_+k,y0:w-k,y1:w+k,spikeDistance:t.distance,hovertemplate:f.hovertemplate}),\"h\"===f.orientation?(b=h,n.xLabelVal=l.x,n.yLabelVal=o.pos):(b=u,n.xLabelVal=o.pos,n.yLabelVal=l.y),n[b._id.charAt(0)+\"Spike\"]=b.c2p(o.pos,!0),s(l,f,n),n}e.exports={hoverPoints:function(t,e,r,n){var i,a=t.cd[0].trace.hoveron,o=[];return-1!==a.indexOf(\"boxes\")&&(o=o.concat(l(t,e,r,n))),-1!==a.indexOf(\"points\")&&(i=c(t,e,r)),\"closest\"===n?i?[i]:o:i?(o.push(i),o):o},hoverOnBoxes:l,hoverOnPoints:c}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],886:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\").supplyLayoutDefaults,calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"box\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"boxLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":880,\"./calc\":881,\"./cross_trace_calc\":882,\"./defaults\":883,\"./event_data\":884,\"./hover\":885,\"./layout_attributes\":887,\"./layout_defaults\":888,\"./plot\":889,\"./select\":890,\"./style\":891}],887:[function(t,e,r){\"use strict\";e.exports={boxmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"overlay\",editType:\"calc\"},boxgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"},boxgroupgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"}}},{}],888:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./layout_attributes\");function o(t,e,r,i,a){for(var o=a+\"Layout\",s=!1,l=0;l<r.length;l++){var c=r[l];if(n.traceIs(c,o)){s=!0;break}}s&&(i(a+\"mode\"),i(a+\"gap\"),i(a+\"groupgap\"))}e.exports={supplyLayoutDefaults:function(t,e,r){o(0,0,r,function(r,n){return i.coerce(t,e,a,r,n)},\"box\")},_supply:o}},{\"../../lib\":719,\"../../registry\":847,\"./layout_attributes\":887}],889:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=5,s=.01;function l(t,e,r,a){var o,s,l=e.pos,c=e.val,u=a.bPos,h=a.wdPos||0,f=a.bPosPxOffset||0,p=r.whiskerwidth||0,d=r.notched||!1,g=d?1-2*r.notchwidth:1;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var v=t.selectAll(\"path.box\").data(\"violin\"!==r.type||r.box.visible?i.identity:[]);v.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"box\"),v.exit().remove(),v.each(function(t){if(t.empty)return\"M0,0Z\";var e=t.pos,a=l.c2p(e+u,!0)+f,v=l.c2p(e+u-o,!0)+f,m=l.c2p(e+u+s,!0)+f,y=l.c2p(e+u-h,!0)+f,x=l.c2p(e+u+h,!0)+f,b=l.c2p(e+u-o*g,!0)+f,_=l.c2p(e+u+s*g,!0)+f,w=c.c2p(t.q1,!0),k=c.c2p(t.q3,!0),T=i.constrain(c.c2p(t.med,!0),Math.min(w,k)+1,Math.max(w,k)-1),A=void 0===t.lf||!1===r.boxpoints,M=c.c2p(A?t.min:t.lf,!0),S=c.c2p(A?t.max:t.uf,!0),E=c.c2p(t.ln,!0),C=c.c2p(t.un,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+T+\",\"+b+\"V\"+_+\"M\"+w+\",\"+v+\"V\"+m+(d?\"H\"+E+\"L\"+T+\",\"+_+\"L\"+C+\",\"+m:\"\")+\"H\"+k+\"V\"+v+(d?\"H\"+C+\"L\"+T+\",\"+b+\"L\"+E+\",\"+v:\"\")+\"ZM\"+w+\",\"+a+\"H\"+M+\"M\"+k+\",\"+a+\"H\"+S+(0===p?\"\":\"M\"+M+\",\"+y+\"V\"+x+\"M\"+S+\",\"+y+\"V\"+x)):n.select(this).attr(\"d\",\"M\"+b+\",\"+T+\"H\"+_+\"M\"+v+\",\"+w+\"H\"+m+(d?\"V\"+E+\"L\"+_+\",\"+T+\"L\"+m+\",\"+C:\"\")+\"V\"+k+\"H\"+v+(d?\"V\"+C+\"L\"+b+\",\"+T+\"L\"+v+\",\"+E:\"\")+\"ZM\"+a+\",\"+w+\"V\"+M+\"M\"+a+\",\"+k+\"V\"+S+(0===p?\"\":\"M\"+y+\",\"+M+\"H\"+x+\"M\"+y+\",\"+S+\"H\"+x))})}function c(t,e,r,n){var l=e.x,c=e.y,u=n.bdPos,h=n.bPos,f=r.boxpoints||r.points;i.seedPseudoRandom();var p=t.selectAll(\"g.points\").data(f?function(t){return t.forEach(function(t){t.t=n,t.trace=r}),t}:[]);p.enter().append(\"g\").attr(\"class\",\"points\"),p.exit().remove();var d=p.selectAll(\"path\").data(function(t){var e,n,a=t.pts2,l=Math.max((t.max-t.min)/10,t.q3-t.q1),c=1e-9*l,p=l*s,d=[],g=0;if(r.jitter){if(0===l)for(g=1,d=new Array(a.length),e=0;e<a.length;e++)d[e]=1;else for(e=0;e<a.length;e++){var v=Math.max(0,e-o),m=a[v].v,y=Math.min(a.length-1,e+o),x=a[y].v;\"all\"!==f&&(a[e].v<t.lf?x=Math.min(x,t.lf):m=Math.max(m,t.uf));var b=Math.sqrt(p*(y-v)/(x-m+c))||0;b=i.constrain(Math.abs(b),0,1),d.push(b),g=Math.max(b,g)}n=2*r.jitter/(g||1)}for(e=0;e<a.length;e++){var _=a[e],w=_.v,k=r.jitter?n*d[e]*(i.pseudoRandom()-.5):0,T=t.pos+h+u*(r.pointpos+k);\"h\"===r.orientation?(_.y=T,_.x=w):(_.x=T,_.y=w),\"suspectedoutliers\"===f&&w<t.uo&&w>t.lo&&(_.so=!0)}return a});d.enter().append(\"path\").classed(\"point\",!0),d.exit().remove(),d.call(a.translatePoints,l,c)}function u(t,e,r,a){var o,s,l=e.pos,c=e.val,u=a.bPos,h=a.bPosPxOffset||0,f=r.boxmean||(r.meanline||{}).visible;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var p=t.selectAll(\"path.mean\").data(\"box\"===r.type&&r.boxmean||\"violin\"===r.type&&r.box.visible&&r.meanline.visible?i.identity:[]);p.enter().append(\"path\").attr(\"class\",\"mean\").style({fill:\"none\",\"vector-effect\":\"non-scaling-stroke\"}),p.exit().remove(),p.each(function(t){var e=l.c2p(t.pos+u,!0)+h,i=l.c2p(t.pos+u-o,!0)+h,a=l.c2p(t.pos+u+s,!0)+h,p=c.c2p(t.mean,!0),d=c.c2p(t.mean-t.sd,!0),g=c.c2p(t.mean+t.sd,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+p+\",\"+i+\"V\"+a+(\"sd\"===f?\"m0,0L\"+d+\",\"+e+\"L\"+p+\",\"+i+\"L\"+g+\",\"+e+\"Z\":\"\")):n.select(this).attr(\"d\",\"M\"+i+\",\"+p+\"H\"+a+(\"sd\"===f?\"m0,0L\"+e+\",\"+d+\"L\"+i+\",\"+p+\"L\"+e+\",\"+g+\"Z\":\"\"))})}e.exports={plot:function(t,e,r,a){var o=e.xaxis,s=e.yaxis;i.makeTraceGroups(a,r,\"trace boxes\").each(function(t){var e,r,i=n.select(this),a=t[0],h=a.t,f=a.trace;h.wdPos=h.bdPos*f.whiskerwidth,!0!==f.visible||h.empty?i.remove():(\"h\"===f.orientation?(e=s,r=o):(e=o,r=s),l(i,{pos:e,val:r},f,h),c(i,{x:o,y:s},f,h),u(i,{pos:e,val:r},f,h))})},plotBoxAndWhiskers:l,plotPoints:c,plotBoxMean:u}},{\"../../components/drawing\":614,\"../../lib\":719,d3:163}],890:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i=t.cd,a=t.xaxis,o=t.yaxis,s=[];if(!1===e)for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++)i[r].pts[n].selected=0;else for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++){var l=i[r].pts[n],c=a.c2p(l.x),u=o.c2p(l.y);e.contains([c,u],null,l.i,t)?(s.push({pointNumber:l.i,x:a.c2d(l.x),y:o.c2d(l.y)}),l.selected=1):l.selected=0}return s}},{}],891:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\");e.exports={style:function(t,e,r){var o=r||n.select(t).selectAll(\"g.trace.boxes\");o.style(\"opacity\",function(t){return t[0].trace.opacity}),o.each(function(e){var r=n.select(this),o=e[0].trace,s=o.line.width;function l(t,e,r,n){t.style(\"stroke-width\",e+\"px\").call(i.stroke,r).call(i.fill,n)}var c=r.selectAll(\"path.box\");if(\"candlestick\"===o.type)c.each(function(t){if(!t.empty){var e=n.select(this),r=o[t.dir];l(e,r.line.width,r.line.color,r.fillcolor),e.style(\"opacity\",o.selectedpoints&&!t.selected?.3:1)}});else{l(c,s,o.line.color,o.fillcolor),r.selectAll(\"path.mean\").style({\"stroke-width\":s,\"stroke-dasharray\":2*s+\"px,\"+s+\"px\"}).call(i.stroke,o.line.color);var u=r.selectAll(\"path.point\");a.pointStyle(u,o,t)}})},styleOnSelect:function(t,e,r){var n=e[0].trace,i=r.selectAll(\"path.point\");n.selectedpoints?a.selectedPointStyle(i,n):a.pointStyle(i,n,t)}}},{\"../../components/color\":593,\"../../components/drawing\":614,d3:163}],892:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../ohlc/attributes\"),a=t(\"../box/attributes\");function o(t){return{line:{color:n({},a.line.color,{dflt:t}),width:a.line.width,editType:\"style\"},fillcolor:a.fillcolor,editType:\"style\"}}e.exports={x:i.x,open:i.open,high:i.high,low:i.low,close:i.close,line:{width:n({},a.line.width,{}),editType:\"style\"},increasing:o(i.increasing.line.color.dflt),decreasing:o(i.decreasing.line.color.dflt),text:i.text,hovertext:i.hovertext,whiskerwidth:n({},a.whiskerwidth,{dflt:0}),hoverlabel:i.hoverlabel}},{\"../../lib\":719,\"../box/attributes\":880,\"../ohlc/attributes\":1058}],893:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../ohlc/calc\").calcCommon;function o(t,e,r,n){return{min:r,q1:Math.min(t,n),med:n,q3:Math.max(t,n),max:e}}e.exports=function(t,e){var r=t._fullLayout,s=i.getFromId(t,e.xaxis),l=i.getFromId(t,e.yaxis),c=s.makeCalcdata(e,\"x\"),u=a(t,e,c,l,o);return u.length?(n.extendFlat(u[0].t,{num:r._numBoxes,dPos:n.distinctVals(c).minDiff/2,posLetter:\"x\",valLetter:\"y\"}),r._numBoxes++,u):[{t:{empty:!0}}]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../ohlc/calc\":1059}],894:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../ohlc/ohlc_defaults\"),o=t(\"./attributes\");function s(t,e,r,n){var a=r(n+\".line.color\");r(n+\".line.width\",e.line.width),r(n+\".fillcolor\",i.addOpacity(a,.5))}e.exports=function(t,e,r,i){function l(r,i){return n.coerce(t,e,o,r,i)}a(t,e,l,i)?(l(\"line.width\"),s(t,e,l,\"increasing\"),s(t,e,l,\"decreasing\"),l(\"text\"),l(\"hovertext\"),l(\"whiskerwidth\"),i._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../components/color\":593,\"../../lib\":719,\"../ohlc/ohlc_defaults\":1063,\"./attributes\":892}],895:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"candlestick\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\",\"candlestick\",\"boxLayout\"],meta:{},attributes:t(\"./attributes\"),layoutAttributes:t(\"../box/layout_attributes\"),supplyLayoutDefaults:t(\"../box/layout_defaults\").supplyLayoutDefaults,crossTraceCalc:t(\"../box/cross_trace_calc\").crossTraceCalc,supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"../box/plot\").plot,layerName:\"boxlayer\",style:t(\"../box/style\").style,hoverPoints:t(\"../ohlc/hover\").hoverPoints,selectPoints:t(\"../ohlc/select\")}},{\"../../plots/cartesian\":778,\"../box/cross_trace_calc\":882,\"../box/layout_attributes\":887,\"../box/layout_defaults\":888,\"../box/plot\":889,\"../box/style\":891,\"../ohlc/hover\":1061,\"../ohlc/select\":1065,\"./attributes\":892,\"./calc\":893,\"./defaults\":894}],896:[function(t,e,r){\"use strict\";var n=t(\"./axis_defaults\"),i=t(\"../../plot_api/plot_template\");e.exports=function(t,e,r,a,o){a(\"a\")||(a(\"da\"),a(\"a0\")),a(\"b\")||(a(\"db\"),a(\"b0\")),function(t,e,r,a){[\"aaxis\",\"baxis\"].forEach(function(o){var s=o.charAt(0),l=t[o]||{},c=i.newContainer(e,o),u={tickfont:\"x\",id:s+\"axis\",letter:s,font:e.font,name:o,data:t[s],calendar:e.calendar,dfltColor:a,bgColor:r.paper_bgcolor,fullLayout:r};n(l,c,u),c._categories=c._categories||[],t[o]||\"-\"===l.type||(t[o]={type:l.type})})}(t,e,r,o)}},{\"../../plot_api/plot_template\":757,\"./axis_defaults\":901}],897:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t){return function t(e,r){if(!n(e)||r>=10)return null;var i=1/0;var a=-1/0;var o=e.length;for(var s=0;s<o;s++){var l=e[s];if(n(l)){var c=t(l,r+1);c&&(i=Math.min(c[0],i),a=Math.max(c[1],a))}else i=Math.min(l,i),a=Math.max(l,a)}return[i,a]}(t,0)}},{\"../../lib\":719}],898:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./axis_attributes\"),a=t(\"../../components/color/attributes\"),o=n({editType:\"calc\"});o.family.dflt='\"Open Sans\", verdana, arial, sans-serif',o.size.dflt=12,o.color.dflt=a.defaultLine,e.exports={carpet:{valType:\"string\",editType:\"calc\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},a:{valType:\"data_array\",editType:\"calc\"},a0:{valType:\"number\",dflt:0,editType:\"calc\"},da:{valType:\"number\",dflt:1,editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},b0:{valType:\"number\",dflt:0,editType:\"calc\"},db:{valType:\"number\",dflt:1,editType:\"calc\"},cheaterslope:{valType:\"number\",dflt:1,editType:\"calc\"},aaxis:i,baxis:i,font:o,color:{valType:\"color\",dflt:a.defaultLine,editType:\"plot\"},transforms:void 0}},{\"../../components/color/attributes\":592,\"../../plots/font_attributes\":793,\"./axis_attributes\":900}],899:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,i){var a,o,s,l,c,u,h,f,p,d,g,v,m,y=n(r)?\"a\":\"b\",x=(\"a\"===y?t.aaxis:t.baxis).smoothing,b=\"a\"===y?t.a2i:t.b2j,_=\"a\"===y?r:i,w=\"a\"===y?i:r,k=\"a\"===y?e.a.length:e.b.length,T=\"a\"===y?e.b.length:e.a.length,A=Math.floor(\"a\"===y?t.b2j(w):t.a2i(w)),M=\"a\"===y?function(e){return t.evalxy([],e,A)}:function(e){return t.evalxy([],A,e)};x&&(s=Math.max(0,Math.min(T-2,A)),l=A-s,o=\"a\"===y?function(e,r){return t.dxydi([],e,s,r,l)}:function(e,r){return t.dxydj([],s,e,l,r)});var S=b(_[0]),E=b(_[1]),C=S<E?1:-1,L=1e-8*(E-S),P=C>0?Math.floor:Math.ceil,O=C>0?Math.ceil:Math.floor,z=C>0?Math.min:Math.max,I=C>0?Math.max:Math.min,D=P(S+L),R=O(E-L),F=[[h=M(S)]];for(a=D;a*C<R*C;a+=C)c=[],g=I(S,a),m=(v=z(E,a+C))-g,u=Math.max(0,Math.min(k-2,Math.floor(.5*(g+v)))),f=M(v),x&&(p=o(u,g-u),d=o(u,v-u),c.push([h[0]+p[0]/3*m,h[1]+p[1]/3*m]),c.push([f[0]-d[0]/3*m,f[1]-d[1]/3*m])),c.push(f),F.push(c),h=f;return F}},{\"../../lib\":719}],900:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../plots/cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").TIME_FORMAT_LINK;e.exports={color:{valType:\"color\",editType:\"calc\"},smoothing:{valType:\"number\",dflt:1,min:0,max:1.3,editType:\"calc\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"calc\"},font:n({editType:\"calc\"}),offset:{valType:\"number\",dflt:10,editType:\"calc\"},editType:\"calc\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"date\",\"category\"],dflt:\"-\",editType:\"calc\"},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"calc\"},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"calc\"},range:{valType:\"info_array\",editType:\"calc\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}]},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cheatertype:{valType:\"enumerated\",values:[\"index\",\"value\"],dflt:\"value\",editType:\"calc\"},tickmode:{valType:\"enumerated\",values:[\"linear\",\"array\"],dflt:\"array\",editType:\"calc\"},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},tickvals:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},showticklabels:{valType:\"enumerated\",values:[\"start\",\"end\",\"both\",\"none\"],dflt:\"start\",editType:\"calc\"},tickfont:n({editType:\"calc\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"calc\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"calc\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"calc\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"calc\"},tickformatstops:o(a.tickformatstops,\"calc\",\"from-root\"),categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},labelpadding:{valType:\"integer\",dflt:10,editType:\"calc\"},labelprefix:{valType:\"string\",editType:\"calc\"},labelsuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showline:{valType:\"boolean\",dflt:!1,editType:\"calc\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"calc\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},gridcolor:{valType:\"color\",editType:\"calc\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},showgrid:{valType:\"boolean\",dflt:!0,editType:\"calc\"},minorgridcount:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},minorgridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},minorgridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"calc\"},startline:{valType:\"boolean\",editType:\"calc\"},startlinecolor:{valType:\"color\",editType:\"calc\"},startlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endline:{valType:\"boolean\",editType:\"calc\"},endlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endlinecolor:{valType:\"color\",editType:\"calc\"},tick0:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},dtick:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},arraytick0:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},arraydtick:{valType:\"integer\",min:1,dflt:1,editType:\"calc\"},_deprecated:{title:{valType:\"string\",editType:\"calc\"},titlefont:n({editType:\"calc\"}),titleoffset:{valType:\"number\",dflt:10,editType:\"calc\"}},editType:\"calc\"}},{\"../../components/color/attributes\":592,\"../../constants/docs\":690,\"../../plot_api/edit_types\":750,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/font_attributes\":793}],901:[function(t,e,r){\"use strict\";var n=t(\"./attributes\"),i=t(\"../../components/color\").addOpacity,a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/tick_value_defaults\"),l=t(\"../../plots/cartesian/tick_label_defaults\"),c=t(\"../../plots/cartesian/category_order_defaults\"),u=t(\"../../plots/cartesian/set_convert\"),h=t(\"../../plots/cartesian/axis_autotype\");e.exports=function(t,e,r){var f=r.letter,p=r.font||{},d=n[f+\"axis\"];function g(r,n){return o.coerce(t,e,d,r,n)}function v(r,n){return o.coerce2(t,e,d,r,n)}r.name&&(e._name=r.name,e._id=r.name);var m=g(\"type\");(\"-\"===m&&(r.data&&function(t,e){if(\"-\"!==t.type)return;var r=t._id.charAt(0),n=t[r+\"calendar\"];t.type=h(e,n)}(e,r.data),\"-\"===e.type?e.type=\"linear\":m=t.type=e.type),g(\"smoothing\"),g(\"cheatertype\"),g(\"showticklabels\"),g(\"labelprefix\",f+\" = \"),g(\"labelsuffix\"),g(\"showtickprefix\"),g(\"showticksuffix\"),g(\"separatethousands\"),g(\"tickformat\"),g(\"exponentformat\"),g(\"showexponent\"),g(\"categoryorder\"),g(\"tickmode\"),g(\"tickvals\"),g(\"ticktext\"),g(\"tick0\"),g(\"dtick\"),\"array\"===e.tickmode&&(g(\"arraytick0\"),g(\"arraydtick\")),g(\"labelpadding\"),e._hovertitle=f,\"date\"===m)&&a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",r.calendar);u(e,r.fullLayout),e.c2p=o.identity;var y=g(\"color\",r.dfltColor),x=y===t.color?y:p.color;g(\"title.text\")&&(o.coerceFont(g,\"title.font\",{family:p.family,size:Math.round(1.2*p.size),color:x}),g(\"title.offset\")),g(\"tickangle\"),g(\"autorange\",!e.isValidRange(t.range))&&g(\"rangemode\"),g(\"range\"),e.cleanRange(),g(\"fixedrange\"),s(t,e,g,m),l(t,e,g,m,r),c(t,e,g,{data:r.data,dataAttr:f});var b=v(\"gridcolor\",i(y,.3)),_=v(\"gridwidth\"),w=g(\"showgrid\");w||(delete e.gridcolor,delete e.gridwidth);var k=v(\"startlinecolor\",y),T=v(\"startlinewidth\",_);g(\"startline\",e.showgrid||!!k||!!T)||(delete e.startlinecolor,delete e.startlinewidth);var A=v(\"endlinecolor\",y),M=v(\"endlinewidth\",_);return g(\"endline\",e.showgrid||!!A||!!M)||(delete e.endlinecolor,delete e.endlinewidth),w?(g(\"minorgridcount\"),g(\"minorgridwidth\",_),g(\"minorgridcolor\",i(b,.06)),e.minorgridcount||(delete e.minorgridwidth,delete e.minorgridcolor)):(delete e.gridcolor,delete e.gridWidth),\"none\"===e.showticklabels&&(delete e.tickfont,delete e.tickangle,delete e.showexponent,delete e.exponentformat,delete e.tickformat,delete e.showticksuffix,delete e.showtickprefix),e.showticksuffix||delete e.ticksuffix,e.showtickprefix||delete e.tickprefix,g(\"tickmode\"),e}},{\"../../components/color\":593,\"../../lib\":719,\"../../plots/cartesian/axis_autotype\":768,\"../../plots/cartesian/category_order_defaults\":771,\"../../plots/cartesian/set_convert\":785,\"../../plots/cartesian/tick_label_defaults\":786,\"../../plots/cartesian/tick_value_defaults\":788,\"../../registry\":847,\"./attributes\":898}],902:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\").isArray1D,a=t(\"./cheater_basis\"),o=t(\"./array_minmax\"),s=t(\"./calc_gridlines\"),l=t(\"./calc_labels\"),c=t(\"./calc_clippath\"),u=t(\"../heatmap/clean_2d_array\"),h=t(\"./smooth_fill_2d_array\"),f=t(\"../heatmap/convert_column_xyz\"),p=t(\"./set_convert\");e.exports=function(t,e){var r=n.getFromId(t,e.xaxis),d=n.getFromId(t,e.yaxis),g=e.aaxis,v=e.baxis,m=e.x,y=e.y,x=[];m&&i(m)&&x.push(\"x\"),y&&i(y)&&x.push(\"y\"),x.length&&f(e,g,v,\"a\",\"b\",x);var b=e._a=e._a||e.a,_=e._b=e._b||e.b;m=e._x||e.x,y=e._y||e.y;var w={};if(e._cheater){var k=\"index\"===g.cheatertype?b.length:b,T=\"index\"===v.cheatertype?_.length:_;m=a(k,T,e.cheaterslope)}e._x=m=u(m),e._y=y=u(y),h(m,b,_),h(y,b,_),p(e),e.setScale();var A=o(m),M=o(y),S=.5*(A[1]-A[0]),E=.5*(A[1]+A[0]),C=.5*(M[1]-M[0]),L=.5*(M[1]+M[0]);return A=[E-1.3*S,E+1.3*S],M=[L-1.3*C,L+1.3*C],e._extremes[r._id]=n.findExtremes(r,A,{padded:!0}),e._extremes[d._id]=n.findExtremes(d,M,{padded:!0}),s(e,\"a\",\"b\"),s(e,\"b\",\"a\"),l(e,g),l(e,v),w.clipsegments=c(e._xctrl,e._yctrl,g,v),w.x=m,w.y=y,w.a=b,w.b=_,[w]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../heatmap/clean_2d_array\":1003,\"../heatmap/convert_column_xyz\":1005,\"./array_minmax\":897,\"./calc_clippath\":903,\"./calc_gridlines\":904,\"./calc_labels\":905,\"./cheater_basis\":907,\"./set_convert\":920,\"./smooth_fill_2d_array\":921}],903:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a,o,s=[],l=!!r.smoothing,c=!!n.smoothing,u=t[0].length-1,h=t.length-1;for(i=0,a=[],o=[];i<=u;i++)a[i]=t[0][i],o[i]=e[0][i];for(s.push({x:a,y:o,bicubic:l}),i=0,a=[],o=[];i<=h;i++)a[i]=t[i][u],o[i]=e[i][u];for(s.push({x:a,y:o,bicubic:c}),i=u,a=[],o=[];i>=0;i--)a[u-i]=t[h][i],o[u-i]=e[h][i];for(s.push({x:a,y:o,bicubic:l}),i=h,a=[],o=[];i>=0;i--)a[h-i]=t[i][0],o[h-i]=e[i][0];return s.push({x:a,y:o,bicubic:c}),s}},{}],904:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e,r){var a,o,s,l,c,u,h,f,p,d,g,v,m,y,x=t[\"_\"+e],b=t[e+\"axis\"],_=b._gridlines=[],w=b._minorgridlines=[],k=b._boundarylines=[],T=t[\"_\"+r],A=t[r+\"axis\"];\"array\"===b.tickmode&&(b.tickvals=x.slice());var M=t._xctrl,S=t._yctrl,E=M[0].length,C=M.length,L=t._a.length,P=t._b.length;n.prepTicks(b),\"array\"===b.tickmode&&delete b.tickvals;var O=b.smoothing?3:1;function z(n){var i,a,o,s,l,c,u,h,p,d,g,v,m=[],y=[],x={};if(\"b\"===e)for(a=t.b2j(n),o=Math.floor(Math.max(0,Math.min(P-2,a))),s=a-o,x.length=P,x.crossLength=L,x.xy=function(e){return t.evalxy([],e,a)},x.dxy=function(e,r){return t.dxydi([],e,o,r,s)},i=0;i<L;i++)c=Math.min(L-2,i),u=i-c,h=t.evalxy([],i,a),A.smoothing&&i>0&&(p=t.dxydi([],i-1,o,0,s),m.push(l[0]+p[0]/3),y.push(l[1]+p[1]/3),d=t.dxydi([],i-1,o,1,s),m.push(h[0]-d[0]/3),y.push(h[1]-d[1]/3)),m.push(h[0]),y.push(h[1]),l=h;else for(i=t.a2i(n),c=Math.floor(Math.max(0,Math.min(L-2,i))),u=i-c,x.length=L,x.crossLength=P,x.xy=function(e){return t.evalxy([],i,e)},x.dxy=function(e,r){return t.dxydj([],c,e,u,r)},a=0;a<P;a++)o=Math.min(P-2,a),s=a-o,h=t.evalxy([],i,a),A.smoothing&&a>0&&(g=t.dxydj([],c,a-1,u,0),m.push(l[0]+g[0]/3),y.push(l[1]+g[1]/3),v=t.dxydj([],c,a-1,u,1),m.push(h[0]-v[0]/3),y.push(h[1]-v[1]/3)),m.push(h[0]),y.push(h[1]),l=h;return x.axisLetter=e,x.axis=b,x.crossAxis=A,x.value=n,x.constvar=r,x.index=f,x.x=m,x.y=y,x.smoothing=A.smoothing,x}function I(n){var i,a,o,s,l,c=[],u=[],h={};if(h.length=x.length,h.crossLength=T.length,\"b\"===e)for(o=Math.max(0,Math.min(P-2,n)),l=Math.min(1,Math.max(0,n-o)),h.xy=function(e){return t.evalxy([],e,n)},h.dxy=function(e,r){return t.dxydi([],e,o,r,l)},i=0;i<E;i++)c[i]=M[n*O][i],u[i]=S[n*O][i];else for(a=Math.max(0,Math.min(L-2,n)),s=Math.min(1,Math.max(0,n-a)),h.xy=function(e){return t.evalxy([],n,e)},h.dxy=function(e,r){return t.dxydj([],a,e,s,r)},i=0;i<C;i++)c[i]=M[i][n*O],u[i]=S[i][n*O];return h.axisLetter=e,h.axis=b,h.crossAxis=A,h.value=x[n],h.constvar=r,h.index=n,h.x=c,h.y=u,h.smoothing=A.smoothing,h}if(\"array\"===b.tickmode){for(l=5e-15,u=(c=[Math.floor((x.length-1-b.arraytick0)/b.arraydtick*(1+l)),Math.ceil(-b.arraytick0/b.arraydtick/(1+l))].sort(function(t,e){return t-e}))[0]-1,h=c[1]+1,f=u;f<h;f++)(o=b.arraytick0+b.arraydtick*f)<0||o>x.length-1||_.push(i(I(o),{color:b.gridcolor,width:b.gridwidth}));for(f=u;f<h;f++)if(s=b.arraytick0+b.arraydtick*f,g=Math.min(s+b.arraydtick,x.length-1),!(s<0||s>x.length-1||g<0||g>x.length-1))for(v=x[s],m=x[g],a=0;a<b.minorgridcount;a++)(y=g-s)<=0||(d=v+(m-v)*(a+1)/(b.minorgridcount+1)*(b.arraydtick/y))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&k.push(i(I(0),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&k.push(i(I(x.length-1),{color:b.endlinecolor,width:b.endlinewidth}))}else{for(l=5e-15,u=(c=[Math.floor((x[x.length-1]-b.tick0)/b.dtick*(1+l)),Math.ceil((x[0]-b.tick0)/b.dtick/(1+l))].sort(function(t,e){return t-e}))[0],h=c[1],f=u;f<=h;f++)p=b.tick0+b.dtick*f,_.push(i(z(p),{color:b.gridcolor,width:b.gridwidth}));for(f=u-1;f<h+1;f++)for(p=b.tick0+b.dtick*f,a=0;a<b.minorgridcount;a++)(d=p+b.dtick*(a+1)/(b.minorgridcount+1))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&k.push(i(z(x[0]),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&k.push(i(z(x[x.length-1]),{color:b.endlinecolor,width:b.endlinewidth}))}}},{\"../../lib/extend\":710,\"../../plots/cartesian/axes\":767}],905:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e){var r,a,o,s=e._labels=[],l=e._gridlines;for(r=0;r<l.length;r++)o=l[r],-1!==[\"start\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{prefix:void 0,suffix:void 0,endAnchor:!0,xy:o.xy(0),dxy:o.dxy(0,0),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a)),-1!==[\"end\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{endAnchor:!1,xy:o.xy(o.crossLength-1),dxy:o.dxy(o.crossLength-2,1),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a))}},{\"../../lib/extend\":710,\"../../plots/cartesian/axes\":767}],906:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=t[0]-e[0],a=t[1]-e[1],o=r[0]-e[0],s=r[1]-e[1],l=Math.pow(i*i+a*a,.25),c=Math.pow(o*o+s*s,.25),u=(c*c*i-l*l*o)*n,h=(c*c*a-l*l*s)*n,f=c*(l+c)*3,p=l*(l+c)*3;return[[e[0]+(f&&u/f),e[1]+(f&&h/f)],[e[0]-(p&&u/p),e[1]-(p&&h/p)]]}},{}],907:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i,a,o,s,l,c,u=[],h=n(t)?t.length:t,f=n(e)?e.length:e,p=n(t)?t:null,d=n(e)?e:null;p&&(o=(p.length-1)/(p[p.length-1]-p[0])/(h-1)),d&&(s=(d.length-1)/(d[d.length-1]-d[0])/(f-1));var g=1/0,v=-1/0;for(a=0;a<f;a++)for(u[a]=[],l=d?(d[a]-d[0])*s:a/(f-1),i=0;i<h;i++)c=(p?(p[i]-p[0])*o:i/(h-1))-l*r,g=Math.min(c,g),v=Math.max(c,v),u[a][i]=c;var m=1/(v-g),y=-g*m;for(a=0;a<f;a++)for(i=0;i<h;i++)u[a][i]=m*u[a][i]+y;return u}},{\"../../lib\":719}],908:[function(t,e,r){\"use strict\";var n=t(\"./catmull_rom\"),i=t(\"../../lib\").ensureArray;function a(t,e,r){var n=-.5*r[0]+1.5*e[0],i=-.5*r[1]+1.5*e[1];return[(2*n+t[0])/3,(2*i+t[1])/3]}e.exports=function(t,e,r,o,s,l){var c,u,h,f,p,d,g,v,m,y,x=r[0].length,b=r.length,_=s?3*x-2:x,w=l?3*b-2:b;for(t=i(t,w),e=i(e,w),h=0;h<w;h++)t[h]=i(t[h],_),e[h]=i(e[h],_);for(u=0,f=0;u<b;u++,f+=l?3:1)for(p=t[f],d=e[f],g=r[u],v=o[u],c=0,h=0;c<x;c++,h+=s?3:1)p[h]=g[c],d[h]=v[c];if(s)for(u=0,f=0;u<b;u++,f+=l?3:1){for(c=1,h=3;c<x-1;c++,h+=3)m=n([r[u][c-1],o[u][c-1]],[r[u][c],o[u][c]],[r[u][c+1],o[u][c+1]],s),t[f][h-1]=m[0][0],e[f][h-1]=m[0][1],t[f][h+1]=m[1][0],e[f][h+1]=m[1][1];y=a([t[f][0],e[f][0]],[t[f][2],e[f][2]],[t[f][3],e[f][3]]),t[f][1]=y[0],e[f][1]=y[1],y=a([t[f][_-1],e[f][_-1]],[t[f][_-3],e[f][_-3]],[t[f][_-4],e[f][_-4]]),t[f][_-2]=y[0],e[f][_-2]=y[1]}if(l)for(h=0;h<_;h++){for(f=3;f<w-3;f+=3)m=n([t[f-3][h],e[f-3][h]],[t[f][h],e[f][h]],[t[f+3][h],e[f+3][h]],l),t[f-1][h]=m[0][0],e[f-1][h]=m[0][1],t[f+1][h]=m[1][0],e[f+1][h]=m[1][1];y=a([t[0][h],e[0][h]],[t[2][h],e[2][h]],[t[3][h],e[3][h]]),t[1][h]=y[0],e[1][h]=y[1],y=a([t[w-1][h],e[w-1][h]],[t[w-3][h],e[w-3][h]],[t[w-4][h],e[w-4][h]]),t[w-2][h]=y[0],e[w-2][h]=y[1]}if(s&&l)for(f=1;f<w;f+=(f+1)%3==0?2:1){for(h=3;h<_-3;h+=3)m=n([t[f][h-3],e[f][h-3]],[t[f][h],e[f][h]],[t[f][h+3],e[f][h+3]],s),t[f][h-1]=.5*(t[f][h-1]+m[0][0]),e[f][h-1]=.5*(e[f][h-1]+m[0][1]),t[f][h+1]=.5*(t[f][h+1]+m[1][0]),e[f][h+1]=.5*(e[f][h+1]+m[1][1]);y=a([t[f][0],e[f][0]],[t[f][2],e[f][2]],[t[f][3],e[f][3]]),t[f][1]=.5*(t[f][1]+y[0]),e[f][1]=.5*(e[f][1]+y[1]),y=a([t[f][_-1],e[f][_-1]],[t[f][_-3],e[f][_-3]],[t[f][_-4],e[f][_-4]]),t[f][_-2]=.5*(t[f][_-2]+y[0]),e[f][_-2]=.5*(e[f][_-2]+y[1])}return[t,e]}},{\"../../lib\":719,\"./catmull_rom\":906}],909:[function(t,e,r){\"use strict\";e.exports={RELATIVE_CULL_TOLERANCE:1e-6}},{}],910:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3,n*=3;var f=i*i,p=1-i,d=p*p,g=p*i*2,v=-3*d,m=3*(d-g),y=3*(g-f),x=3*f,b=a*a,_=b*a,w=1-a,k=w*w,T=k*w;for(h=0;h<t.length;h++)o=v*(u=t[h])[n][r]+m*u[n][r+1]+y*u[n][r+2]+x*u[n][r+3],s=v*u[n+1][r]+m*u[n+1][r+1]+y*u[n+1][r+2]+x*u[n+1][r+3],l=v*u[n+2][r]+m*u[n+2][r+1]+y*u[n+2][r+2]+x*u[n+2][r+3],c=v*u[n+3][r]+m*u[n+3][r+1]+y*u[n+3][r+2]+x*u[n+3][r+3],e[h]=T*o+3*(k*a*s+w*b*l)+_*c;return e}:e?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),r*=3;var u=i*i,h=1-i,f=h*h,p=h*i*2,d=-3*f,g=3*(f-p),v=3*(p-u),m=3*u,y=1-a;for(l=0;l<t.length;l++)o=d*(c=t[l])[n][r]+g*c[n][r+1]+v*c[n][r+2]+m*c[n][r+3],s=d*c[n+1][r]+g*c[n+1][r+1]+v*c[n+1][r+2]+m*c[n+1][r+3],e[l]=y*o+a*s;return e}:r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),n*=3;var f=a*a,p=f*a,d=1-a,g=d*d,v=g*d;for(u=0;u<t.length;u++)o=(h=t[u])[n][r+1]-h[n][r],s=h[n+1][r+1]-h[n+1][r],l=h[n+2][r+1]-h[n+2][r],c=h[n+3][r+1]-h[n+3][r],e[u]=v*o+3*(g*a*s+d*f*l)+p*c;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-a;for(l=0;l<t.length;l++)o=(c=t[l])[n][r+1]-c[n][r],s=c[n+1][r+1]-c[n+1][r],e[l]=u*o+a*s;return e}}},{}],911:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3,n*=3;var f=i*i,p=f*i,d=1-i,g=d*d,v=g*d,m=a*a,y=1-a,x=y*y,b=y*a*2,_=-3*x,w=3*(x-b),k=3*(b-m),T=3*m;for(h=0;h<t.length;h++)o=_*(u=t[h])[n][r]+w*u[n+1][r]+k*u[n+2][r]+T*u[n+3][r],s=_*u[n][r+1]+w*u[n+1][r+1]+k*u[n+2][r+1]+T*u[n+3][r+1],l=_*u[n][r+2]+w*u[n+1][r+2]+k*u[n+2][r+2]+T*u[n+3][r+2],c=_*u[n][r+3]+w*u[n+1][r+3]+k*u[n+2][r+3]+T*u[n+3][r+3],e[h]=v*o+3*(g*i*s+d*f*l)+p*c;return e}:e?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3;var f=a*a,p=f*a,d=1-a,g=d*d,v=g*d;for(u=0;u<t.length;u++)o=(h=t[u])[n+1][r]-h[n][r],s=h[n+1][r+1]-h[n][r+1],l=h[n+1][r+2]-h[n][r+2],c=h[n+1][r+3]-h[n][r+3],e[u]=v*o+3*(g*a*s+d*f*l)+p*c;return e}:r?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),n*=3;var u=1-i,h=a*a,f=1-a,p=f*f,d=f*a*2,g=-3*p,v=3*(p-d),m=3*(d-h),y=3*h;for(l=0;l<t.length;l++)o=g*(c=t[l])[n][r]+v*c[n+1][r]+m*c[n+2][r]+y*c[n+3][r],s=g*c[n][r+1]+v*c[n+1][r+1]+m*c[n+2][r+1]+y*c[n+3][r+1],e[l]=u*o+i*s;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-i;for(l=0;l<t.length;l++)o=(c=t[l])[n+1][r]-c[n][r],s=c[n+1][r+1]-c[n][r+1],e[l]=u*o+i*s;return e}}},{}],912:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=e-2,o=r-2;return n&&i?function(e,r,n){var i,s,l,c,u,h;e||(e=[]);var f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));f*=3,p*=3;var v=d*d,m=v*d,y=1-d,x=y*y,b=x*y,_=g*g,w=_*g,k=1-g,T=k*k,A=T*k;for(h=0;h<t.length;h++)i=b*(u=t[h])[p][f]+3*(x*d*u[p][f+1]+y*v*u[p][f+2])+m*u[p][f+3],s=b*u[p+1][f]+3*(x*d*u[p+1][f+1]+y*v*u[p+1][f+2])+m*u[p+1][f+3],l=b*u[p+2][f]+3*(x*d*u[p+2][f+1]+y*v*u[p+2][f+2])+m*u[p+2][f+3],c=b*u[p+3][f]+3*(x*d*u[p+3][f+1]+y*v*u[p+3][f+2])+m*u[p+3][f+3],e[h]=A*i+3*(T*g*s+k*_*l)+w*c;return e}:n?function(e,r,n){e||(e=[]);var i,s,l,c,u,h,f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));f*=3;var v=d*d,m=v*d,y=1-d,x=y*y,b=x*y,_=1-g;for(u=0;u<t.length;u++)i=_*(h=t[u])[p][f]+g*h[p+1][f],s=_*h[p][f+1]+g*h[p+1][f+1],l=_*h[p][f+2]+g*h[p+1][f+1],c=_*h[p][f+3]+g*h[p+1][f+1],e[u]=b*i+3*(x*d*s+y*v*l)+m*c;return e}:i?function(e,r,n){e||(e=[]);var i,s,l,c,u,h,f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));p*=3;var v=g*g,m=v*g,y=1-g,x=y*y,b=x*y,_=1-d;for(u=0;u<t.length;u++)i=_*(h=t[u])[p][f]+d*h[p][f+1],s=_*h[p+1][f]+d*h[p+1][f+1],l=_*h[p+2][f]+d*h[p+2][f+1],c=_*h[p+3][f]+d*h[p+3][f+1],e[u]=b*i+3*(x*g*s+y*v*l)+m*c;return e}:function(e,r,n){e||(e=[]);var i,s,l,c,u=Math.max(0,Math.min(Math.floor(r),a)),h=Math.max(0,Math.min(Math.floor(n),o)),f=Math.max(0,Math.min(1,r-u)),p=Math.max(0,Math.min(1,n-h)),d=1-p,g=1-f;for(l=0;l<t.length;l++)i=g*(c=t[l])[h][u]+f*c[h][u+1],s=g*c[h+1][u]+f*c[h+1][u+1],e[l]=d*i+p*s;return e}}},{}],913:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xy_defaults\"),a=t(\"./ab_defaults\"),o=t(\"./attributes\"),s=t(\"../../components/color/attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,o,r,i)}e._clipPathId=\"clip\"+e.uid+\"carpet\";var u=c(\"color\",s.defaultLine);(n.coerceFont(c,\"font\"),c(\"carpet\"),a(t,e,l,c,u),e.a&&e.b)?(e.a.length<3&&(e.aaxis.smoothing=0),e.b.length<3&&(e.baxis.smoothing=0),i(t,e,c)||(e.visible=!1),e._cheater&&c(\"cheaterslope\")):e.visible=!1}},{\"../../components/color/attributes\":592,\"../../lib\":719,\"./ab_defaults\":896,\"./attributes\":898,\"./xy_defaults\":922}],914:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),plot:t(\"./plot\"),calc:t(\"./calc\"),animatable:!0,isContainer:!0,moduleType:\"trace\",name:\"carpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"carpetAxis\",\"notLegendIsolatable\",\"noMultiCategory\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":898,\"./calc\":902,\"./defaults\":913,\"./plot\":919}],915:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r,n=t._fullData.length,i=0;i<n;i++){var a=t._fullData[i];if(a.index!==e.index&&(\"carpet\"===a.type&&(r||(r=a),a.carpet===e.carpet)))return a}return r}},{}],916:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(0===t.length)return\"\";var n,i=[],a=r?3:1;for(n=0;n<t.length;n+=a)i.push(t[n]+\",\"+e[n]),r&&n<t.length-a&&(i.push(\"C\"),i.push([t[n+1]+\",\"+e[n+1],t[n+2]+\",\"+e[n+2]+\" \"].join(\" \")));return i.join(r?\"\":\"L\")}},{}],917:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i;for(n(t)?t.length>e.length&&(t=t.slice(0,e.length)):t=[],i=0;i<e.length;i++)t[i]=r(e[i]);return t}},{\"../../lib\":719}],918:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i[0]*t.dpdx(e),s=i[1]*t.dpdy(r),l=1,c=1;if(a){var u=Math.sqrt(i[0]*i[0]+i[1]*i[1]),h=Math.sqrt(a[0]*a[0]+a[1]*a[1]),f=(i[0]*a[0]+i[1]*a[1])/u/h;c=Math.max(0,f)}var p=180*Math.atan2(s,o)/Math.PI;return p<-90?(p+=180,l=-l):p>90&&(p-=180,l=-l),{angle:p,flip:l,p:t.c2p(n,e,r),offsetMultplier:c}}},{}],919:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"./map_1d_array\"),o=t(\"./makepath\"),s=t(\"./orient_text\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib\"),u=t(\"../../constants/alignment\");function h(t,e,r,i,s,l){var c=\"const-\"+s+\"-lines\",u=r.selectAll(\".\"+c).data(l);u.enter().append(\"path\").classed(c,!0).style(\"vector-effect\",\"non-scaling-stroke\"),u.each(function(r){var i=r,s=i.x,l=i.y,c=a([],s,t.c2p),u=a([],l,e.c2p),h=\"M\"+o(c,u,i.smoothing);n.select(this).attr(\"d\",h).style(\"stroke-width\",i.width).style(\"stroke\",i.color).style(\"fill\",\"none\")}),u.exit().remove()}function f(t,e,r,a,o,c,u,h){var f=c.selectAll(\"text.\"+h).data(u);f.enter().append(\"text\").classed(h,!0);var p=0,d={};return f.each(function(o,c){var u;if(\"auto\"===o.axis.tickangle)u=s(a,e,r,o.xy,o.dxy);else{var h=(o.axis.tickangle+180)*Math.PI/180;u=s(a,e,r,o.xy,[Math.cos(h),Math.sin(h)])}c||(d={angle:u.angle,flip:u.flip});var f=(o.endAnchor?-1:1)*u.flip,g=n.select(this).attr({\"text-anchor\":f>0?\"start\":\"end\",\"data-notex\":1}).call(i.font,o.font).text(o.text).call(l.convertToTspans,t),v=i.bBox(this);g.attr(\"transform\",\"translate(\"+u.p[0]+\",\"+u.p[1]+\") rotate(\"+u.angle+\")translate(\"+o.axis.labelpadding*f+\",\"+.3*v.height+\")\"),p=Math.max(p,v.width+o.axis.labelpadding)}),f.exit().remove(),d.maxExtent=p,d}e.exports=function(t,e,r,i){var l=e.xaxis,u=e.yaxis,p=t._fullLayout._clips;c.makeTraceGroups(i,r,\"trace\").each(function(e){var r=n.select(this),i=e[0],d=i.trace,v=d.aaxis,m=d.baxis,y=c.ensureSingle(r,\"g\",\"minorlayer\"),x=c.ensureSingle(r,\"g\",\"majorlayer\"),b=c.ensureSingle(r,\"g\",\"boundarylayer\"),_=c.ensureSingle(r,\"g\",\"labellayer\");r.style(\"opacity\",d.opacity),h(l,u,x,v,\"a\",v._gridlines),h(l,u,x,m,\"b\",m._gridlines),h(l,u,y,v,\"a\",v._minorgridlines),h(l,u,y,m,\"b\",m._minorgridlines),h(l,u,b,v,\"a-boundary\",v._boundarylines),h(l,u,b,m,\"b-boundary\",m._boundarylines);var w=f(t,l,u,d,i,_,v._labels,\"a-label\"),k=f(t,l,u,d,i,_,m._labels,\"b-label\");!function(t,e,r,n,i,a,o,l){var u,h,f,p,d=c.aggNums(Math.min,null,r.a),v=c.aggNums(Math.max,null,r.a),m=c.aggNums(Math.min,null,r.b),y=c.aggNums(Math.max,null,r.b);u=.5*(d+v),h=m,f=r.ab2xy(u,h,!0),p=r.dxyda_rough(u,h),void 0===o.angle&&c.extendFlat(o,s(r,i,a,f,r.dxydb_rough(u,h)));g(t,e,r,n,f,p,r.aaxis,i,a,o,\"a-title\"),u=d,h=.5*(m+y),f=r.ab2xy(u,h,!0),p=r.dxydb_rough(u,h),void 0===l.angle&&c.extendFlat(l,s(r,i,a,f,r.dxyda_rough(u,h)));g(t,e,r,n,f,p,r.baxis,i,a,l,\"b-title\")}(t,_,d,i,l,u,w,k),function(t,e,r,n,i){var s,l,u,h,f=r.select(\"#\"+t._clipPathId);f.size()||(f=r.append(\"clipPath\").classed(\"carpetclip\",!0));var p=c.ensureSingle(f,\"path\",\"carpetboundary\"),d=e.clipsegments,g=[];for(h=0;h<d.length;h++)s=d[h],l=a([],s.x,n.c2p),u=a([],s.y,i.c2p),g.push(o(l,u,s.bicubic));var v=\"M\"+g.join(\"L\")+\"Z\";f.attr(\"id\",t._clipPathId),p.attr(\"d\",v)}(d,i,p,l,u)})};var p=u.LINE_SPACING,d=(1-u.MID_SHIFT)/p+1;function g(t,e,r,a,o,c,u,h,f,g,v){var m=[];u.title.text&&m.push(u.title.text);var y=e.selectAll(\"text.\"+v).data(m),x=g.maxExtent;y.enter().append(\"text\").classed(v,!0),y.each(function(){var e=s(r,h,f,o,c);-1===[\"start\",\"both\"].indexOf(u.showticklabels)&&(x=0);var a=u.title.font.size;x+=a+u.title.offset;var v=(g.angle+(g.flip<0?180:0)-e.angle+450)%360,m=v>90&&v<270,y=n.select(this);y.text(u.title.text).call(l.convertToTspans,t),m&&(x=(-l.lineCount(y)+d)*p*a-x),y.attr(\"transform\",\"translate(\"+e.p[0]+\",\"+e.p[1]+\") rotate(\"+e.angle+\") translate(0,\"+x+\")\").classed(\"user-select-none\",!0).attr(\"text-anchor\",\"middle\").call(i.font,u.title.font)}),y.exit().remove()}},{\"../../components/drawing\":614,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"./makepath\":916,\"./map_1d_array\":917,\"./orient_text\":918,d3:163}],920:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/search\").findBin,a=t(\"./compute_control_points\"),o=t(\"./create_spline_evaluator\"),s=t(\"./create_i_derivative_evaluator\"),l=t(\"./create_j_derivative_evaluator\");e.exports=function(t){var e=t._a,r=t._b,c=e.length,u=r.length,h=t.aaxis,f=t.baxis,p=e[0],d=e[c-1],g=r[0],v=r[u-1],m=e[e.length-1]-e[0],y=r[r.length-1]-r[0],x=m*n.RELATIVE_CULL_TOLERANCE,b=y*n.RELATIVE_CULL_TOLERANCE;p-=x,d+=x,g-=b,v+=b,t.isVisible=function(t,e){return t>p&&t<d&&e>g&&e<v},t.isOccluded=function(t,e){return t<p||t>d||e<g||e>v},t.setScale=function(){var e=t._x,r=t._y,n=a(t._xctrl,t._yctrl,e,r,h.smoothing,f.smoothing);t._xctrl=n[0],t._yctrl=n[1],t.evalxy=o([t._xctrl,t._yctrl],c,u,h.smoothing,f.smoothing),t.dxydi=s([t._xctrl,t._yctrl],h.smoothing,f.smoothing),t.dxydj=l([t._xctrl,t._yctrl],h.smoothing,f.smoothing)},t.i2a=function(t){var r=Math.max(0,Math.floor(t[0]),c-2),n=t[0]-r;return(1-n)*e[r]+n*e[r+1]},t.j2b=function(t){var e=Math.max(0,Math.floor(t[1]),c-2),n=t[1]-e;return(1-n)*r[e]+n*r[e+1]},t.ij2ab=function(e){return[t.i2a(e[0]),t.j2b(e[1])]},t.a2i=function(t){var r=Math.max(0,Math.min(i(t,e),c-2)),n=e[r],a=e[r+1];return Math.max(0,Math.min(c-1,r+(t-n)/(a-n)))},t.b2j=function(t){var e=Math.max(0,Math.min(i(t,r),u-2)),n=r[e],a=r[e+1];return Math.max(0,Math.min(u-1,e+(t-n)/(a-n)))},t.ab2ij=function(e){return[t.a2i(e[0]),t.b2j(e[1])]},t.i2c=function(e,r){return t.evalxy([],e,r)},t.ab2xy=function(n,i,a){if(!a&&(n<e[0]||n>e[c-1]|i<r[0]||i>r[u-1]))return[!1,!1];var o=t.a2i(n),s=t.b2j(i),l=t.evalxy([],o,s);if(a){var h,f,p,d,g=0,v=0,m=[];n<e[0]?(h=0,f=0,g=(n-e[0])/(e[1]-e[0])):n>e[c-1]?(h=c-2,f=1,g=(n-e[c-1])/(e[c-1]-e[c-2])):f=o-(h=Math.max(0,Math.min(c-2,Math.floor(o)))),i<r[0]?(p=0,d=0,v=(i-r[0])/(r[1]-r[0])):i>r[u-1]?(p=u-2,d=1,v=(i-r[u-1])/(r[u-1]-r[u-2])):d=s-(p=Math.max(0,Math.min(u-2,Math.floor(s)))),g&&(t.dxydi(m,h,p,f,d),l[0]+=m[0]*g,l[1]+=m[1]*g),v&&(t.dxydj(m,h,p,f,d),l[0]+=m[0]*v,l[1]+=m[1]*v)}return l},t.c2p=function(t,e,r){return[e.c2p(t[0]),r.c2p(t[1])]},t.p2x=function(t,e,r){return[e.p2c(t[0]),r.p2c(t[1])]},t.dadi=function(t){var r=Math.max(0,Math.min(e.length-2,t));return e[r+1]-e[r]},t.dbdj=function(t){var e=Math.max(0,Math.min(r.length-2,t));return r[e+1]-r[e]},t.dxyda=function(e,r,n,i){var a=t.dxydi(null,e,r,n,i),o=t.dadi(e,n);return[a[0]/o,a[1]/o]},t.dxydb=function(e,r,n,i){var a=t.dxydj(null,e,r,n,i),o=t.dbdj(r,i);return[a[0]/o,a[1]/o]},t.dxyda_rough=function(e,r,n){var i=m*(n||.1),a=t.ab2xy(e+i,r,!0),o=t.ab2xy(e-i,r,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dxydb_rough=function(e,r,n){var i=y*(n||.1),a=t.ab2xy(e,r+i,!0),o=t.ab2xy(e,r-i,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dpdx=function(t){return t._m},t.dpdy=function(t){return t._m}}},{\"../../lib/search\":738,\"./compute_control_points\":908,\"./constants\":909,\"./create_i_derivative_evaluator\":910,\"./create_j_derivative_evaluator\":911,\"./create_spline_evaluator\":912}],921:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r){var i,a,o,s=[],l=[],c=t[0].length,u=t.length;function h(e,r){var n,i=0,a=0;return e>0&&void 0!==(n=t[r][e-1])&&(a++,i+=n),e<c-1&&void 0!==(n=t[r][e+1])&&(a++,i+=n),r>0&&void 0!==(n=t[r-1][e])&&(a++,i+=n),r<u-1&&void 0!==(n=t[r+1][e])&&(a++,i+=n),i/Math.max(1,a)}var f,p,d,g,v,m,y,x,b,_,w,k=0;for(i=0;i<c;i++)for(a=0;a<u;a++)void 0===t[a][i]&&(s.push(i),l.push(a),t[a][i]=h(i,a)),k=Math.max(k,Math.abs(t[a][i]));if(!s.length)return t;var T=0,A=0,M=s.length;do{for(T=0,o=0;o<M;o++){i=s[o],a=l[o];var S,E,C,L,P,O,z=0,I=0;0===i?(C=e[P=Math.min(c-1,2)],L=e[1],S=t[a][P],I+=(E=t[a][1])+(E-S)*(e[0]-L)/(L-C),z++):i===c-1&&(C=e[P=Math.max(0,c-3)],L=e[c-2],S=t[a][P],I+=(E=t[a][c-2])+(E-S)*(e[c-1]-L)/(L-C),z++),(0===i||i===c-1)&&a>0&&a<u-1&&(f=r[a+1]-r[a],I+=((p=r[a]-r[a-1])*t[a+1][i]+f*t[a-1][i])/(p+f),z++),0===a?(C=r[O=Math.min(u-1,2)],L=r[1],S=t[O][i],I+=(E=t[1][i])+(E-S)*(r[0]-L)/(L-C),z++):a===u-1&&(C=r[O=Math.max(0,u-3)],L=r[u-2],S=t[O][i],I+=(E=t[u-2][i])+(E-S)*(r[u-1]-L)/(L-C),z++),(0===a||a===u-1)&&i>0&&i<c-1&&(f=e[i+1]-e[i],I+=((p=e[i]-e[i-1])*t[a][i+1]+f*t[a][i-1])/(p+f),z++),z?I/=z:(d=e[i+1]-e[i],g=e[i]-e[i-1],x=(v=r[a+1]-r[a])*(m=r[a]-r[a-1])*(v+m),I=((y=d*g*(d+g))*(m*t[a+1][i]+v*t[a-1][i])+x*(g*t[a][i+1]+d*t[a][i-1]))/(x*(g+d)+y*(m+v))),T+=(_=(b=I-t[a][i])/k)*_,w=z?0:.85,t[a][i]+=b*(1+w)}T=Math.sqrt(T)}while(A++<100&&T>1e-5);return n.log(\"Smoother converged to\",T,\"after\",A,\"iterations\"),t}},{\"../../lib\":719}],922:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArray1D;e.exports=function(t,e,r){var i=r(\"x\"),a=i&&i.length,o=r(\"y\"),s=o&&o.length;if(!a&&!s)return!1;if(e._cheater=!i,a&&!n(i)||s&&!n(o))e._length=null;else{var l=a?i.length:1/0;s&&(l=Math.min(l,o.length)),e.a&&e.a.length&&(l=Math.min(l,e.a.length)),e.b&&e.b.length&&(l=Math.min(l,e.b.length)),e._length=l}return!0}},{\"../../lib\":719}],923:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scattergeo/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/color/attributes\").defaultLine,l=t(\"../../lib/extend\").extendFlat,c=i.marker.line;e.exports=l({locations:{valType:\"data_array\",editType:\"calc\"},locationmode:i.locationmode,z:{valType:\"data_array\",editType:\"calc\"},text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),marker:{line:{color:l({},c.color,{dflt:s}),width:l({},c.width,{dflt:1}),editType:\"calc\"},opacity:{valType:\"number\",arrayOk:!0,min:0,max:1,dflt:1,editType:\"style\"},editType:\"calc\"},selected:{marker:{opacity:i.selected.marker.opacity,editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:i.unselected.marker.opacity,editType:\"plot\"},editType:\"plot\"},hoverinfo:l({},o.hoverinfo,{editType:\"calc\",flags:[\"location\",\"z\",\"text\",\"name\"]}),hovertemplate:n()},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/color/attributes\":592,\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scattergeo/attributes\":1151}],924:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../components/colorscale/calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\");function l(t){return t&&\"string\"==typeof t}e.exports=function(t,e){var r,c=e._length,u=new Array(c);r=e.geojson?function(t){return l(t)||n(t)}:l;for(var h=0;h<c;h++){var f=u[h]={},p=e.locations[h],d=e.z[h];r(p)&&n(d)?(f.loc=p,f.z=d):(f.loc=null,f.z=i),f.index=h}return o(u,e),a(t,e,{vals:e.z,containerStr:\"\",cLetter:\"z\"}),s(u,e),u}},{\"../../components/colorscale/calc\":601,\"../../constants/numerical\":695,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc_selection\":1114,\"fast-isnumeric\":225}],925:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\");l&&l.length&&n.isArrayOrTypedArray(c)&&c.length?(e._length=Math.min(l.length,c.length),s(\"locationmode\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":923}],926:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){t.location=e.location,t.z=e.z;var a=n[i];return a.fIn&&(t.properties=a.fIn.properties),t}},{}],927:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"./attributes\"),a=t(\"../../lib\").fillText;e.exports=function(t,e,r){var o,s,l,c,u=t.cd,h=u[0].trace,f=t.subplot;for(s=0;s<u.length;s++)if(c=!1,(o=u[s])._polygons){for(l=0;l<o._polygons.length;l++)o._polygons[l].contains([e,r])&&(c=!c),o._polygons[l].contains([e+360,r])&&(c=!c);if(c)break}if(c&&o)return t.x0=t.x1=t.xa.c2p(o.ct),t.y0=t.y1=t.ya.c2p(o.ct),t.index=o.index,t.location=o.loc,t.z=o.z,t.zLabel=n.tickText(f.mockAxis,f.mockAxis.c2l(o.z),\"hover\").text,t.hovertemplate=o.hovertemplate,function(t,e,r){if(e.hovertemplate)return;var n=r.hi||e.hoverinfo,o=\"all\"===n?i.hoverinfo.flags:n.split(\"+\"),s=-1!==o.indexOf(\"name\"),l=-1!==o.indexOf(\"location\"),c=-1!==o.indexOf(\"z\"),u=-1!==o.indexOf(\"text\"),h=[];!s&&l?t.nameOverride=r.loc:(s&&(t.nameOverride=e.name),l&&h.push(r.loc));c&&h.push(t.zLabel);u&&a(r,e,h);t.extraText=h.join(\"<br>\")}(t,h,o,f.mockAxis),[t]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./attributes\":923}],928:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"choropleth\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"noOpacity\"],meta:{}}},{\"../../plots/geo\":797,\"../heatmap/colorbar\":1004,\"./attributes\":923,\"./calc\":924,\"./defaults\":925,\"./event_data\":926,\"./hover\":927,\"./plot\":929,\"./select\":930,\"./style\":931}],929:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../lib/polygon\"),o=t(\"../../lib/topojson_utils\").getTopojsonFeatures,s=t(\"../../lib/geo_location_utils\").locationToFeature,l=t(\"./style\").style;function c(t,e){for(var r=t[0].trace,n=t.length,i=o(r,e),a=0;a<n;a++){var l=t[a],c=s(r.locationmode,l.loc,i);c?(l.geojson=c,l.ct=c.properties.ct,l._polygons=u(c)):l.geojson=null}}function u(t){var e,r,n,i,o=t.geometry,s=o.coordinates,l=t.id,c=[];function u(t){for(var e=0;e<t.length-1;e++)if(t[e][0]>0&&t[e+1][0]<0)return e;return null}switch(e=\"RUS\"===l||\"FJI\"===l?function(t){var e;if(null===u(t))e=t;else for(e=new Array(t.length),i=0;i<t.length;i++)e[i]=[t[i][0]<0?t[i][0]+360:t[i][0],t[i][1]];c.push(a.tester(e))}:\"ATA\"===l?function(t){var e=u(t);if(null===e)return c.push(a.tester(t));var r=new Array(t.length+1),n=0;for(i=0;i<t.length;i++)i>e?r[n++]=[t[i][0]+360,t[i][1]]:i===e?(r[n++]=t[i],r[n++]=[t[i][0],-90]):r[n++]=t[i];var o=a.tester(r);o.pts.pop(),c.push(o)}:function(t){c.push(a.tester(t))},o.type){case\"MultiPolygon\":for(r=0;r<s.length;r++)for(n=0;n<s[r].length;n++)e(s[r][n]);break;case\"Polygon\":for(r=0;r<s.length;r++)e(s[r])}return c}e.exports={plot:function(t,e,r){for(var a=0;a<r.length;a++)c(r[a],e.topojson);var o=e.layers.backplot.select(\".choroplethlayer\");i.makeTraceGroups(o,r,\"trace choropleth\").each(function(e){var r=n.select(this).selectAll(\"path.choroplethlocation\").data(i.identity);r.enter().append(\"path\").classed(\"choroplethlocation\",!0),r.exit().remove(),l(t,e)})},feature2polygons:u}},{\"../../lib\":719,\"../../lib/geo_location_utils\":713,\"../../lib/polygon\":731,\"../../lib/topojson_utils\":746,\"./style\":931,d3:163}],930:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)(i=(n=s[r]).ct)&&(a=l.c2p(i),o=c.c2p(i),e.contains([a,o],null,r,t)?(u.push({pointNumber:r,lon:i[0],lat:i[1]}),n.selected=1):n.selected=0);return u}},{}],931:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../components/colorscale\");function s(t,e){var r=e[0].trace,s=e[0].node3.selectAll(\".choroplethlocation\"),l=r.marker||{},c=l.line||{},u=o.makeColorScaleFuncFromTrace(r);s.each(function(t){n.select(this).attr(\"fill\",u(t.z)).call(i.stroke,t.mlc||c.color).call(a.dashLine,\"\",t.mlw||c.width||0).style(\"opacity\",l.opacity)}),a.selectedPointStyle(s,r,t)}e.exports={style:function(t,e){e&&s(t,e)},styleOnSelect:function(t,e){var r=e[0].node3,n=e[0].trace;n.selectedpoints?a.selectedPointStyle(r.selectAll(\".choroplethlocation\"),n,t):s(t,e)}}},{\"../../components/color\":593,\"../../components/colorscale\":605,\"../../components/drawing\":614,d3:163}],932:[function(t,e,r){\"use strict\";var n=t(\"../choropleth/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../lib/extend\").extendFlat;e.exports=o({locations:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},geojson:{valType:\"any\",editType:\"calc\"},below:{valType:\"string\",editType:\"plot\"},text:n.text,hovertext:n.hovertext,marker:{line:{color:o({},n.marker.line.color,{editType:\"plot\"}),width:o({},n.marker.line.width,{editType:\"plot\"}),editType:\"calc\"},opacity:o({},n.marker.opacity,{editType:\"plot\"}),editType:\"calc\"},selected:{marker:{opacity:o({},n.selected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:o({},n.unselected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},hoverinfo:n.hoverinfo,hovertemplate:a({},{keys:[\"properties\"]})},i(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../choropleth/attributes\":923}],933:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"@turf/area\"),a=t(\"@turf/centroid\"),o=t(\"../../lib\"),s=t(\"../../components/colorscale\"),l=t(\"../../components/drawing\"),c=t(\"../../lib/geojson_utils\").makeBlank,u=t(\"../choropleth/plot\").feature2polygons;function h(t){var e,r=t[0].trace,n=r._opts;if(r.selectedpoints){for(var i=l.makeSelectedPointStyleFns(r),a=0;a<t.length;a++){var s=t[a];s.fOut&&(s.fOut.properties.mo2=i.selectedOpacityFn(s))}e={type:\"identity\",property:\"mo2\"}}else e=o.isArrayOrTypedArray(r.marker.opacity)?{type:\"identity\",property:\"mo\"}:r.marker.opacity;return o.extendFlat(n.fill.paint,{\"fill-opacity\":e}),o.extendFlat(n.line.paint,{\"line-opacity\":e}),n}e.exports={convert:function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,l={layout:{visibility:\"none\"},paint:{}},f={layout:{visibility:\"none\"},paint:{}},p=e._opts={fill:l,line:f,geojson:c()};if(!r)return p;var d=\"string\"==typeof e.geojson?(window.PlotlyGeoAssets||{})[e.geojson]:e.geojson;if(!o.isPlainObject(d))return o.error(\"Oops ... something when wrong when fetching \"+e.geojson),p;var g,v={},m=[];for(g=0;g<t.length;g++){var y=t[g];y.loc&&(v[y.loc]=y)}var x,b,_,w=s.makeColorScaleFuncFromTrace(e),k=e.marker,T=k.line||{};function A(t){var e=v[t.id];if(e){var r=t.geometry;if(\"Polygon\"===r.type||\"MultiPolygon\"===r.type){var n={fc:w(e.z)};x&&(n.mo=x(e)),b&&(n.mlc=b(e)),_&&(n.mlw=_(e));var s={type:\"Feature\",geometry:r,properties:n};e._polygons=u(s),e.ct=function(t){var e,r=t.geometry;if(\"MultiPolygon\"===r.type)for(var n=r.coordinates,o=0,s=0;s<n.length;s++){var l={type:\"Polygon\",coordinates:n[s]},c=i.default(l);c>o&&(o=c,e=l)}else e=r;return a.default(e).geometry.coordinates}(s),e.fIn=t,e.fOut=s,m.push(s)}else o.log([\"Location with id\",e.loc,\"does not have a valid GeoJSON geometry,\",\"choroplethmapbox traces only support *Polygon* and *MultiPolygon* geometries.\"].join(\" \"))}delete v[t.id]}switch(o.isArrayOrTypedArray(k.opacity)&&(x=function(t){var e=t.mo;return n(e)?+o.constrain(e,0,1):0}),o.isArrayOrTypedArray(T.color)&&(b=function(t){return t.mlc}),o.isArrayOrTypedArray(T.width)&&(_=function(t){return t.mlw}),d.type){case\"FeatureCollection\":var M=d.features;for(g=0;g<M.length;g++)A(M[g]);break;case\"Feature\":A(d);break;default:return o.warn([\"Invalid GeoJSON type\",(d.type||\"none\")+\",\",\"choroplethmapbox traces only support *FeatureCollection* and *Feature* types.\"].join(\" \")),p}for(var S in v)o.log(\"Location with id \"+S+\" does not have a matching feature\");var E=x?{type:\"identity\",property:\"mo\"}:k.opacity;return o.extendFlat(l.paint,{\"fill-color\":{type:\"identity\",property:\"fc\"},\"fill-opacity\":E}),o.extendFlat(f.paint,{\"line-color\":b?{type:\"identity\",property:\"mlc\"}:T.color,\"line-width\":_?{type:\"identity\",property:\"mlw\"}:T.width,\"line-opacity\":E}),l.layout.visibility=\"visible\",f.layout.visibility=\"visible\",p.geojson={type:\"FeatureCollection\",features:m},h(t),p},convertOnSelect:h}},{\"../../components/colorscale\":605,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/geojson_utils\":714,\"../choropleth/plot\":929,\"@turf/area\":55,\"@turf/centroid\":56,\"fast-isnumeric\":225}],934:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\"),u=s(\"geojson\");n.isArrayOrTypedArray(l)&&l.length&&n.isArrayOrTypedArray(c)&&c.length&&(\"string\"==typeof u&&\"\"!==u||n.isPlainObject(u))?(e._length=Math.min(l.length,c.length),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":932}],935:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../choropleth/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"../choropleth/hover\"),eventData:t(\"../choropleth/event_data\"),selectPoints:t(\"../choropleth/select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.updateOnSelect(e)},getBelow:function(t,e){for(var r=e.getMapLayers(),n=r.length-2;n>=0;n--){var i=r[n].id;if(\"string\"==typeof i&&0===i.indexOf(\"water\"))for(var a=n+1;a<r.length;a++)if(\"string\"==typeof(i=r[a].id)&&-1===i.indexOf(\"plotly-\"))return i}},moduleType:\"trace\",name:\"choroplethmapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"noOpacity\"],meta:{hr_name:\"choropleth_mapbox\"}}},{\"../../plots/mapbox\":822,\"../choropleth/calc\":924,\"../choropleth/event_data\":926,\"../choropleth/hover\":927,\"../choropleth/select\":930,\"../heatmap/colorbar\":1004,\"./attributes\":932,\"./defaults\":934,\"./plot\":936}],936:[function(t,e,r){\"use strict\";var n=t(\"./convert\").convert,i=t(\"./convert\").convertOnSelect,a=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function o(t,e){this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"fill\",a+e+\"-fill\"],[\"line\",a+e+\"-line\"]],this.below=null}var s=o.prototype;s.update=function(t){this._update(n(t))},s.updateOnSelect=function(t){this._update(i(t))},s._update=function(t){var e=this.subplot,r=this.layerList,n=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(t.geojson),n!==this.below&&(this._removeLayers(),this._addLayers(t,n),this.below=n);for(var i=0;i<r.length;i++){var a=r[i],o=a[0],s=a[1],l=t[o];e.setOptions(s,\"setLayoutProperty\",l.layout),\"visible\"===l.layout.visibility&&e.setOptions(s,\"setPaintProperty\",l.paint)}},s._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},s._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},s.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new o(t,r.uid),a=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(a,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":820,\"./convert\":933}],937:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"scaled\",\"absolute\"],editType:\"calc\",dflt:\"scaled\"},sizeref:{valType:\"number\",editType:\"calc\",min:0},anchor:{valType:\"enumerated\",editType:\"calc\",values:[\"tip\",\"tail\",\"cm\",\"center\"],dflt:\"cm\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:i({editType:\"calc\"},{keys:[\"norm\"]})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach(function(t){l[t]=a[t]}),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../mesh3d/attributes\":1053}],938:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){for(var r=e.u,i=e.v,a=e.w,o=Math.min(e.x.length,e.y.length,e.z.length,r.length,i.length,a.length),s=-1/0,l=1/0,c=0;c<o;c++){var u=r[c],h=i[c],f=a[c],p=Math.sqrt(u*u+h*h+f*f);s=Math.max(s,p),l=Math.min(l,p)}e._len=o,e._normMax=s,n(t,e,{vals:[l,s],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],939:[function(t,e,r){\"use strict\";var n=t(\"gl-cone3d\"),i=t(\"gl-cone3d\").createConeMesh,a=t(\"../../lib\").simpleMap,o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\");function c(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var u=c.prototype;u.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index,r=this.data.x[e],n=this.data.y[e],i=this.data.z[e],a=this.data.u[e],o=this.data.v[e],s=this.data.w[e];t.traceCoordinate=[r,n,i,a,o,s,Math.sqrt(a*a+o*o+s*s)];var l=this.data.hovertext||this.data.text;return Array.isArray(l)&&void 0!==l[e]?t.textLabel=l[e]:l&&(t.textLabel=l),!0}};var h={xaxis:0,yaxis:1,zaxis:2},f={tip:1,tail:0,cm:.25,center:.5},p={tip:1,tail:1,cm:.75,center:.5};function d(t,e){var r=t.fullSceneLayout,i=t.dataScale,c={};function u(t,e){var n=r[e],o=i[h[e]];return a(t,function(t){return n.d2l(t)*o})}c.vectors=l(u(e.u,\"xaxis\"),u(e.v,\"yaxis\"),u(e.w,\"zaxis\"),e._len),c.positions=l(u(e.x,\"xaxis\"),u(e.y,\"yaxis\"),u(e.z,\"zaxis\"),e._len);var d=s(e);c.colormap=o(e),c.vertexIntensityBounds=[d.min/e._normMax,d.max/e._normMax],c.coneOffset=f[e.anchor],\"scaled\"===e.sizemode?c.coneSize=e.sizeref||.5:c.coneSize=e.sizeref&&e._normMax?e.sizeref/e._normMax:.5;var g=n(c),v=e.lightposition;return g.lightPosition=[v.x,v.y,v.z],g.ambient=e.lighting.ambient,g.diffuse=e.lighting.diffuse,g.specular=e.lighting.specular,g.roughness=e.lighting.roughness,g.fresnel=e.lighting.fresnel,g.opacity=e.opacity,e._pad=p[e.anchor]*g.vectorScale*g.coneScale*e._normMax,g}u.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),a=i(r,n),o=new c(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../plots/gl3d/zip3\":818,\"gl-cone3d\":242}],940:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),h=s(\"x\"),f=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length&&p&&p.length?(s(\"sizeref\"),s(\"sizemode\"),s(\"anchor\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":937}],941:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"cone\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),eventData:function(t,e){return t.norm=e.traceCoordinate[6],t},meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":937,\"./calc\":938,\"./convert\":939,\"./defaults\":940}],942:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../components/drawing/attributes\").dash,s=t(\"../../plots/font_attributes\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../constants/filter_ops\"),u=c.COMPARISON_OPS2,h=c.INTERVAL_OPS,f=(t(\"../../constants/docs\").FORMAT_LINK,i.line);e.exports=l({z:n.z,x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,xtype:n.xtype,ytype:n.ytype,zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate,connectgaps:n.connectgaps,fillcolor:{valType:\"color\",editType:\"calc\"},autocontour:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"contours.start\":void 0,\"contours.end\":void 0,\"contours.size\":void 0}},ncontours:{valType:\"integer\",dflt:15,min:1,editType:\"calc\"},contours:{type:{valType:\"enumerated\",values:[\"levels\",\"constraint\"],dflt:\"levels\",editType:\"calc\"},start:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},end:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},coloring:{valType:\"enumerated\",values:[\"fill\",\"heatmap\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:{valType:\"boolean\",dflt:!0,editType:\"plot\"},showlabels:{valType:\"boolean\",dflt:!1,editType:\"plot\"},labelfont:s({editType:\"plot\",colorEditType:\"style\"}),labelformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},operation:{valType:\"enumerated\",values:[].concat(u).concat(h),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:l({},f.color,{editType:\"style+colorbars\"}),width:l({},f.width,{editType:\"style+colorbars\"}),dash:o,smoothing:l({},f.smoothing,{}),editType:\"plot\"}},a(\"\",{cLetter:\"z\",autoColorDflt:!1,editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../components/drawing/attributes\":613,\"../../constants/docs\":690,\"../../constants/filter_ops\":691,\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"../heatmap/attributes\":1001,\"../scatter/attributes\":1112}],943:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\"),i=t(\"../heatmap/calc\"),a=t(\"./set_contours\"),o=t(\"./end_plus\");e.exports=function(t,e){var r=i(t,e),s=r[0].z;a(e,s);var l,c=e.contours,u=n.extractOpts(e);if(\"heatmap\"===c.coloring&&u.auto&&!1===e.autocontour){var h=c.start,f=o(c),p=c.size||1,d=Math.floor((f-h)/p)+1;isFinite(p)||(p=1,d=1);var g=h-p/2;l=[g,g+d*p]}else l=s;return n.calc(t,e,{vals:l,cLetter:\"z\"}),r}},{\"../../components/colorscale\":605,\"../heatmap/calc\":1002,\"./end_plus\":953,\"./set_contours\":961}],944:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a,o,s=t[0],l=s.x.length,c=s.y.length,u=s.z,h=n.contours,f=-1/0,p=1/0;for(i=0;i<c;i++)p=Math.min(p,u[i][0]),p=Math.min(p,u[i][l-1]),f=Math.max(f,u[i][0]),f=Math.max(f,u[i][l-1]);for(i=1;i<l-1;i++)p=Math.min(p,u[0][i]),p=Math.min(p,u[c-1][i]),f=Math.max(f,u[0][i]),f=Math.max(f,u[c-1][i]);switch(s.prefixBoundary=!1,e){case\">\":h.value>f&&(s.prefixBoundary=!0);break;case\"<\":h.value<p&&(s.prefixBoundary=!0);break;case\"[]\":a=Math.min.apply(null,h.value),((o=Math.max.apply(null,h.value))<p||a>f)&&(s.prefixBoundary=!0);break;case\"][\":a=Math.min.apply(null,h.value),o=Math.max.apply(null,h.value),a<p&&o>f&&(s.prefixBoundary=!0)}}},{}],945:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\").extractOpts,i=t(\"./make_color_map\"),a=t(\"./end_plus\");e.exports={min:\"zmin\",max:\"zmax\",calc:function(t,e,r){var o=e.contours,s=e.line,l=o.size||1,c=o.coloring,u=i(e,{isColorbar:!0});if(\"heatmap\"===c){var h=n(e);r._fillgradient=e.colorscale,r._zrange=[h.min,h.max]}else\"fill\"===c&&(r._fillcolor=u);r._line={color:\"lines\"===c?u:s.color,width:!1!==o.showlines?s.width:0,dash:s.dash},r._levels={start:o.start,end:a(o),size:l}}}},{\"../../components/colorscale\":605,\"./end_plus\":953,\"./make_color_map\":958}],946:[function(t,e,r){\"use strict\";e.exports={BOTTOMSTART:[1,9,13,104,713],TOPSTART:[4,6,7,104,713],LEFTSTART:[8,12,14,208,1114],RIGHTSTART:[2,3,11,208,1114],NEWDELTA:[null,[-1,0],[0,-1],[-1,0],[1,0],null,[0,-1],[-1,0],[0,1],[0,1],null,[0,1],[1,0],[1,0],[0,-1]],CHOOSESADDLE:{104:[4,1],208:[2,8],713:[7,13],1114:[11,14]},SADDLEREMAINDER:{1:4,2:8,4:1,7:13,8:2,11:14,13:7,14:11},LABELDISTANCE:2,LABELINCREASE:10,LABELMIN:3,LABELMAX:10,LABELOPTIMIZER:{EDGECOST:1,ANGLECOST:1,NEIGHBORCOST:5,SAMELEVELFACTOR:10,SAMELEVELDISTANCE:5,MAXCOST:100,INITIALSEARCHPOINTS:10,ITERATIONS:5}}},{}],947:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./label_defaults\"),a=t(\"../../components/color\"),o=a.addOpacity,s=a.opacity,l=t(\"../../constants/filter_ops\"),c=l.CONSTRAINT_REDUCTION,u=l.COMPARISON_OPS2;e.exports=function(t,e,r,a,l,h){var f,p,d,g=e.contours,v=r(\"contours.operation\");(g._operation=c[v],function(t,e){var r;-1===u.indexOf(e.operation)?(t(\"contours.value\",[0,1]),Array.isArray(e.value)?e.value.length>2?e.value=e.value.slice(2):0===e.length?e.value=[0,1]:e.length<2?(r=parseFloat(e.value[0]),e.value=[r,r+1]):e.value=[parseFloat(e.value[0]),parseFloat(e.value[1])]:n(e.value)&&(r=parseFloat(e.value),e.value=[r,r+1])):(t(\"contours.value\",0),n(e.value)||(Array.isArray(e.value)?e.value=parseFloat(e.value[0]):e.value=0))}(r,g),\"=\"===v?f=g.showlines=!0:(f=r(\"contours.showlines\"),d=r(\"fillcolor\",o((t.line||{}).color||l,.5))),f)&&(p=r(\"line.color\",d&&s(d)?o(e.fillcolor,1):l),r(\"line.width\",2),r(\"line.dash\"));r(\"line.smoothing\"),i(r,a,p,h)}},{\"../../components/color\":593,\"../../constants/filter_ops\":691,\"./label_defaults\":957,\"fast-isnumeric\":225}],948:[function(t,e,r){\"use strict\";var n=t(\"../../constants/filter_ops\"),i=t(\"fast-isnumeric\");function a(t,e){var r,a=Array.isArray(e);function o(t){return i(t)?+t:null}return-1!==n.COMPARISON_OPS2.indexOf(t)?r=o(a?e[0]:e):-1!==n.INTERVAL_OPS.indexOf(t)?r=a?[o(e[0]),o(e[1])]:[o(e),o(e)]:-1!==n.SET_OPS.indexOf(t)&&(r=a?e.map(o):[o(e)]),r}function o(t){return function(e){e=a(t,e);var r=Math.min(e[0],e[1]),n=Math.max(e[0],e[1]);return{start:r,end:n,size:n-r}}}function s(t){return function(e){return{start:e=a(t,e),end:1/0,size:1/0}}}e.exports={\"[]\":o(\"[]\"),\"][\":o(\"][\"),\">\":s(\">\"),\"<\":s(\"<\"),\"=\":s(\"=\")}},{\"../../constants/filter_ops\":691,\"fast-isnumeric\":225}],949:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=n(\"contours.start\"),a=n(\"contours.end\"),o=!1===i||!1===a,s=r(\"contours.size\");!(o?e.autocontour=!0:r(\"autocontour\",!1))&&s||r(\"ncontours\")}},{}],950:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");function i(t){return n.extendFlat({},t,{edgepaths:n.extendDeep([],t.edgepaths),paths:n.extendDeep([],t.paths)})}e.exports=function(t,e){var r,a,o,s=function(t){return t.reverse()},l=function(t){return t};switch(e){case\"=\":case\"<\":return t;case\">\":for(1!==t.length&&n.warn(\"Contour data invalid for the specified inequality operation.\"),a=t[0],r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);return t;case\"][\":var c=s;s=l,l=c;case\"[]\":for(2!==t.length&&n.warn(\"Contour data invalid for the specified inequality range operation.\"),a=i(t[0]),o=i(t[1]),r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);for(;o.edgepaths.length;)a.edgepaths.push(l(o.edgepaths.shift()));for(;o.paths.length;)a.paths.push(l(o.paths.shift()));return[a]}}},{\"../../lib\":719}],951:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"./constraint_defaults\"),o=t(\"./contours_defaults\"),s=t(\"./style_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,l,r,i)}if(i(t,e,u,c)){u(\"text\"),u(\"hovertext\"),u(\"hovertemplate\");var h=\"constraint\"===u(\"contours.type\");u(\"connectgaps\",n.isArray1D(e.z)),h?a(t,e,u,c,r):(o(t,e,u,function(r){return n.coerce2(t,e,l,r)}),s(t,e,u,c))}else e.visible=!1}},{\"../../lib\":719,\"../heatmap/xyz_defaults\":1015,\"./attributes\":942,\"./constraint_defaults\":947,\"./contours_defaults\":949,\"./style_defaults\":963}],952:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constraint_mapping\"),a=t(\"./end_plus\");e.exports=function(t,e,r){for(var o=\"constraint\"===t.type?i[t._operation](t.value):t,s=o.size,l=[],c=a(o),u=r.trace._carpetTrace,h=u?{xaxis:u.aaxis,yaxis:u.baxis,x:r.a,y:r.b}:{xaxis:e.xaxis,yaxis:e.yaxis,x:r.x,y:r.y},f=o.start;f<c;f+=s)if(l.push(n.extendFlat({level:f,crossings:{},starts:[],edgepaths:[],paths:[],z:r.z,smoothing:r.trace.line.smoothing},h)),l.length>1e3){n.warn(\"Too many contours, clipping at 1000\",t);break}return l}},{\"../../lib\":719,\"./constraint_mapping\":948,\"./end_plus\":953}],953:[function(t,e,r){\"use strict\";e.exports=function(t){return t.end+t.size/1e6}},{}],954:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constants\");function a(t,e,r,n){return Math.abs(t[0]-e[0])<r&&Math.abs(t[1]-e[1])<n}function o(t,e,r,o,l){var c,u=e.join(\",\"),h=u,f=t.crossings[h],p=function(t,e,r){var n=0,a=0;t>20&&e?208===t||1114===t?n=0===r[0]?1:-1:a=0===r[1]?1:-1:-1!==i.BOTTOMSTART.indexOf(t)?a=1:-1!==i.LEFTSTART.indexOf(t)?n=1:-1!==i.TOPSTART.indexOf(t)?a=-1:n=-1;return[n,a]}(f,r,e),d=[s(t,e,[-p[0],-p[1]])],g=p.join(\",\"),v=t.z.length,m=t.z[0].length;for(c=0;c<1e4;c++){if(f>20?(f=i.CHOOSESADDLE[f][(p[0]||p[1])<0?0:1],t.crossings[h]=i.SADDLEREMAINDER[f]):delete t.crossings[h],!(p=i.NEWDELTA[f])){n.log(\"Found bad marching index:\",f,e,t.level);break}d.push(s(t,e,p)),e[0]+=p[0],e[1]+=p[1],a(d[d.length-1],d[d.length-2],o,l)&&d.pop(),h=e.join(\",\");var y=p[0]&&(e[0]<0||e[0]>m-2)||p[1]&&(e[1]<0||e[1]>v-2);if(h===u&&p.join(\",\")===g||r&&y)break;f=t.crossings[h]}1e4===c&&n.log(\"Infinite loop in contour?\");var x,b,_,w,k,T,A,M,S,E,C,L,P,O,z,I=a(d[0],d[d.length-1],o,l),D=0,R=.2*t.smoothing,F=[],B=0;for(c=1;c<d.length;c++)L=d[c],P=d[c-1],void 0,void 0,O=L[2]-P[2],z=L[3]-P[3],D+=A=Math.sqrt(O*O+z*z),F.push(A);var N=D/F.length*R;function j(t){return d[t%d.length]}for(c=d.length-2;c>=B;c--)if((x=F[c])<N){for(_=0,b=c-1;b>=B&&x+F[b]<N;b--)x+=F[b];if(I&&c===d.length-2)for(_=0;_<b&&x+F[_]<N;_++)x+=F[_];k=c-b+_+1,T=Math.floor((c+b+_+2)/2),w=I||c!==d.length-2?I||-1!==b?k%2?j(T):[(j(T)[0]+j(T+1)[0])/2,(j(T)[1]+j(T+1)[1])/2]:d[0]:d[d.length-1],d.splice(b+1,c-b+1,w),c=b+1,_&&(B=_),I&&(c===d.length-2?d[_]=d[d.length-1]:0===c&&(d[d.length-1]=d[0]))}for(d.splice(0,B),c=0;c<d.length;c++)d[c].length=2;if(!(d.length<2))if(I)d.pop(),t.paths.push(d);else{r||n.log(\"Unclosed interior contour?\",t.level,u,d.join(\"L\"));var U=!1;for(M=0;M<t.edgepaths.length;M++)if(E=t.edgepaths[M],!U&&a(E[0],d[d.length-1],o,l)){d.pop(),U=!0;var V=!1;for(S=0;S<t.edgepaths.length;S++)if(a((C=t.edgepaths[S])[C.length-1],d[0],o,l)){V=!0,d.shift(),t.edgepaths.splice(M,1),S===M?t.paths.push(d.concat(C)):(S>M&&S--,t.edgepaths[S]=C.concat(d,E));break}V||(t.edgepaths[M]=d.concat(E))}for(M=0;M<t.edgepaths.length&&!U;M++)a((E=t.edgepaths[M])[E.length-1],d[0],o,l)&&(d.shift(),t.edgepaths[M]=E.concat(d),U=!0);U||t.edgepaths.push(d)}}function s(t,e,r){var n=e[0]+Math.max(r[0],0),i=e[1]+Math.max(r[1],0),a=t.z[i][n],o=t.xaxis,s=t.yaxis;if(r[1]){var l=(t.level-a)/(t.z[i][n+1]-a);return[o.c2p((1-l)*t.x[n]+l*t.x[n+1],!0),s.c2p(t.y[i],!0),n+l,i]}var c=(t.level-a)/(t.z[i+1][n]-a);return[o.c2p(t.x[n],!0),s.c2p((1-c)*t.y[i]+c*t.y[i+1],!0),n,i+c]}e.exports=function(t,e,r){var i,a,s,l;for(e=e||.01,r=r||.01,a=0;a<t.length;a++){for(s=t[a],l=0;l<s.starts.length;l++)o(s,s.starts[l],\"edge\",e,r);for(i=0;Object.keys(s.crossings).length&&i<1e4;)i++,o(s,Object.keys(s.crossings)[0].split(\",\").map(Number),void 0,e,r);1e4===i&&n.log(\"Infinite loop in contour?\")}}},{\"../../lib\":719,\"./constants\":946}],955:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../heatmap/hover\");e.exports=function(t,e,r,a,o){var s=i(t,e,r,a,o,!0);return s&&s.forEach(function(t){var e=t.trace;\"constraint\"===e.contours.type&&(e.fillcolor&&n.opacity(e.fillcolor)?t.color=n.addOpacity(e.fillcolor,1):e.contours.showlines&&n.opacity(e.line.color)&&(t.color=n.addOpacity(e.line.color,1)))}),s}},{\"../../components/color\":593,\"../heatmap/hover\":1008}],956:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\").plot,style:t(\"./style\"),colorbar:t(\"./colorbar\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"contour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":942,\"./calc\":943,\"./colorbar\":945,\"./defaults\":951,\"./hover\":955,\"./plot\":960,\"./style\":962}],957:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i){if(i||(i={}),t(\"contours.showlabels\")){var a=e.font;n.coerceFont(t,\"contours.labelfont\",{family:a.family,size:a.size,color:r}),t(\"contours.labelformat\")}!1!==i.hasHover&&t(\"zhoverformat\")}},{\"../../lib\":719}],958:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/colorscale\"),a=t(\"./end_plus\");e.exports=function(t){var e=t.contours,r=e.start,o=a(e),s=e.size||1,l=Math.floor((o-r)/s)+1,c=\"lines\"===e.coloring?0:1,u=i.extractOpts(t);isFinite(s)||(s=1,l=1);var h,f,p=u.reversescale?i.flipScale(u.colorscale):u.colorscale,d=p.length,g=new Array(d),v=new Array(d);if(\"heatmap\"===e.coloring){var m=u.min,y=u.max;for(f=0;f<d;f++)h=p[f],g[f]=h[0]*(y-m)+m,v[f]=h[1];var x=n.extent([m,y,e.start,e.start+s*(l-1)]),b=x[m<y?0:1],_=x[m<y?1:0];b!==m&&(g.splice(0,0,b),v.splice(0,0,v[0])),_!==y&&(g.push(_),v.push(v[v.length-1]))}else for(f=0;f<d;f++)h=p[f],g[f]=(h[0]*(l+c-1)-c/2)*s+r,v[f]=h[1];return i.makeColorScaleFunc({domain:g,range:v},{noNumericCheck:!0})}},{\"../../components/colorscale\":605,\"./end_plus\":953,d3:163}],959:[function(t,e,r){\"use strict\";var n=t(\"./constants\");function i(t,e){var r=(e[0][0]>t?0:1)+(e[0][1]>t?0:2)+(e[1][1]>t?0:4)+(e[1][0]>t?0:8);return 5===r||10===r?t>(e[0][0]+e[0][1]+e[1][0]+e[1][1])/4?5===r?713:1114:5===r?104:208:15===r?0:r}e.exports=function(t){var e,r,a,o,s,l,c,u,h,f=t[0].z,p=f.length,d=f[0].length,g=2===p||2===d;for(r=0;r<p-1;r++)for(o=[],0===r&&(o=o.concat(n.BOTTOMSTART)),r===p-2&&(o=o.concat(n.TOPSTART)),e=0;e<d-1;e++)for(a=o.slice(),0===e&&(a=a.concat(n.LEFTSTART)),e===d-2&&(a=a.concat(n.RIGHTSTART)),s=e+\",\"+r,l=[[f[r][e],f[r][e+1]],[f[r+1][e],f[r+1][e+1]]],h=0;h<t.length;h++)(c=i((u=t[h]).level,l))&&(u.crossings[s]=c,-1!==a.indexOf(c)&&(u.starts.push([e,r]),g&&-1!==a.indexOf(c,a.indexOf(c)+1)&&u.starts.push([e,r])))}},{\"./constants\":946}],960:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../../plots/cartesian/set_convert\"),c=t(\"../heatmap/plot\"),u=t(\"./make_crossings\"),h=t(\"./find_all_paths\"),f=t(\"./empty_pathinfo\"),p=t(\"./convert_to_constraints\"),d=t(\"./close_boundaries\"),g=t(\"./constants\"),v=g.LABELOPTIMIZER;function m(t,e){var r,n,o,s,l,c,u,h=function(t,e){var r=t.prefixBoundary;if(void 0===r){var n=Math.min(t.z[0][0],t.z[0][1]);r=!t.edgepaths.length&&n>t.level}return r?\"M\"+e.join(\"L\")+\"Z\":\"\"}(t,e),f=0,p=t.edgepaths.map(function(t,e){return e}),d=!0;function g(t){return Math.abs(t[1]-e[2][1])<.01}function v(t){return Math.abs(t[0]-e[0][0])<.01}function m(t){return Math.abs(t[0]-e[2][0])<.01}for(;p.length;){for(c=a.smoothopen(t.edgepaths[f],t.smoothing),h+=d?c:c.replace(/^M/,\"L\"),p.splice(p.indexOf(f),1),r=t.edgepaths[f][t.edgepaths[f].length-1],s=-1,o=0;o<4;o++){if(!r){i.log(\"Missing end?\",f,t);break}for(u=r,Math.abs(u[1]-e[0][1])<.01&&!m(r)?n=e[1]:v(r)?n=e[0]:g(r)?n=e[3]:m(r)&&(n=e[2]),l=0;l<t.edgepaths.length;l++){var y=t.edgepaths[l][0];Math.abs(r[0]-n[0])<.01?Math.abs(r[0]-y[0])<.01&&(y[1]-r[1])*(n[1]-y[1])>=0&&(n=y,s=l):Math.abs(r[1]-n[1])<.01?Math.abs(r[1]-y[1])<.01&&(y[0]-r[0])*(n[0]-y[0])>=0&&(n=y,s=l):i.log(\"endpt to newendpt is not vert. or horz.\",r,n,y)}if(r=n,s>=0)break;h+=\"L\"+n}if(s===t.edgepaths.length){i.log(\"unclosed perimeter path\");break}f=s,(d=-1===p.indexOf(f))&&(f=p[0],h+=\"Z\")}for(f=0;f<t.paths.length;f++)h+=a.smoothclosed(t.paths[f],t.smoothing);return h}function y(t,e,r,n){var a=e.width/2,o=e.height/2,s=t.x,l=t.y,c=t.theta,u=Math.cos(c)*a,h=Math.sin(c)*a,f=(s>n.center?n.right-s:s-n.left)/(u+Math.abs(Math.sin(c)*o)),p=(l>n.middle?n.bottom-l:l-n.top)/(Math.abs(h)+Math.cos(c)*o);if(f<1||p<1)return 1/0;var d=v.EDGECOST*(1/(f-1)+1/(p-1));d+=v.ANGLECOST*c*c;for(var g=s-u,m=l-h,y=s+u,x=l+h,b=0;b<r.length;b++){var _=r[b],w=Math.cos(_.theta)*_.width/2,k=Math.sin(_.theta)*_.width/2,T=2*i.segmentDistance(g,m,y,x,_.x-w,_.y-k,_.x+w,_.y+k)/(e.height+_.height),A=_.level===e.level,M=A?v.SAMELEVELDISTANCE:1;if(T<=M)return 1/0;d+=v.NEIGHBORCOST*(A?v.SAMELEVELFACTOR:1)/(T-M)}return d}r.plot=function(t,e,o,s){var l=e.xaxis,v=e.yaxis;i.makeTraceGroups(s,o,\"contour\").each(function(o){var s=n.select(this),y=o[0],x=y.trace,b=y.x,_=y.y,w=x.contours,k=f(w,e,y),T=i.ensureSingle(s,\"g\",\"heatmapcoloring\"),A=[];\"heatmap\"===w.coloring&&(A=[o]),c(t,e,A,T),u(k),h(k);var M=l.c2p(b[0],!0),S=l.c2p(b[b.length-1],!0),E=v.c2p(_[0],!0),C=v.c2p(_[_.length-1],!0),L=[[M,C],[S,C],[S,E],[M,E]],P=k;\"constraint\"===w.type&&(P=p(k,w._operation),d(P,w._operation,L,x)),function(t,e,r){var n=i.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"===r.coloring?[0]:[]);n.enter().append(\"path\"),n.exit().remove(),n.attr(\"d\",\"M\"+e.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(s,L,w),function(t,e,r,a){var o=i.ensureSingle(t,\"g\",\"contourfill\").selectAll(\"path\").data(\"fill\"===a.coloring||\"constraint\"===a.type&&\"=\"!==a._operation?e:[]);o.enter().append(\"path\"),o.exit().remove(),o.each(function(t){var e=m(t,r);e?n.select(this).attr(\"d\",e).style(\"stroke\",\"none\"):n.select(this).remove()})}(s,P,L,w),function(t,e,o,s,l){var c=i.ensureSingle(t,\"g\",\"contourlines\"),u=!1!==l.showlines,h=l.showlabels,f=u&&h,p=r.createLines(c,u||h,e),d=r.createLineClip(c,f,o,s.trace.uid),v=t.selectAll(\"g.contourlabels\").data(h?[0]:[]);if(v.exit().remove(),v.enter().append(\"g\").classed(\"contourlabels\",!0),h){var m=[],y=[];i.clearLocationCache();var x=r.labelFormatter(l,s.t.cb,o._fullLayout),b=a.tester.append(\"text\").attr(\"data-notex\",1).call(a.font,l.labelfont),_=e[0].xaxis,w=e[0].yaxis,k=_._length,T=w._length,A=_.range,M=w.range,S=i.aggNums(Math.min,null,s.x),E=i.aggNums(Math.max,null,s.x),C=i.aggNums(Math.min,null,s.y),L=i.aggNums(Math.max,null,s.y),P=Math.max(_.c2p(S,!0),0),O=Math.min(_.c2p(E,!0),k),z=Math.max(w.c2p(L,!0),0),I=Math.min(w.c2p(C,!0),T),D={};A[0]<A[1]?(D.left=P,D.right=O):(D.left=O,D.right=P),M[0]<M[1]?(D.top=z,D.bottom=I):(D.top=I,D.bottom=z),D.middle=(D.top+D.bottom)/2,D.center=(D.left+D.right)/2,m.push([[D.left,D.top],[D.right,D.top],[D.right,D.bottom],[D.left,D.bottom]]);var R=Math.sqrt(k*k+T*T),F=g.LABELDISTANCE*R/Math.max(1,e.length/g.LABELINCREASE);p.each(function(t){var e=r.calcTextOpts(t.level,x,b,o);n.select(this).selectAll(\"path\").each(function(){var t=i.getVisibleSegment(this,D,e.height/2);if(t&&!(t.len<(e.width+e.height)*g.LABELMIN))for(var n=Math.min(Math.ceil(t.len/F),g.LABELMAX),a=0;a<n;a++){var o=r.findBestTextLocation(this,t,e,y,D);if(!o)break;r.addLabelData(o,e,y,m)}})}),b.remove(),r.drawLabels(v,y,o,d,f?m:null)}h&&!u&&p.remove()}(s,k,t,y,w),function(t,e,r,n,o){var s=r._fullLayout._clips,l=\"clip\"+n.trace.uid,c=s.selectAll(\"#\"+l).data(n.trace.connectgaps?[]:[0]);if(c.enter().append(\"clipPath\").classed(\"contourclip\",!0).attr(\"id\",l),c.exit().remove(),!1===n.trace.connectgaps){var f={level:.9,crossings:{},starts:[],edgepaths:[],paths:[],xaxis:e.xaxis,yaxis:e.yaxis,x:n.x,y:n.y,z:function(t){var e,r,n=t.trace._emptypoints,i=[],a=t.z.length,o=t.z[0].length,s=[];for(e=0;e<o;e++)s.push(1);for(e=0;e<a;e++)i.push(s.slice());for(e=0;e<n.length;e++)r=n[e],i[r[0]][r[1]]=0;return t.zmask=i,i}(n),smoothing:0};u([f]),h([f]);var p=m(f,o),d=i.ensureSingle(c,\"path\",\"\");d.attr(\"d\",p)}else l=null;a.setClipUrl(t,l,r)}(s,e,t,y,L)})},r.createLines=function(t,e,r){var n=r[0].smoothing,i=t.selectAll(\"g.contourlevel\").data(e?r:[]);if(i.exit().remove(),i.enter().append(\"g\").classed(\"contourlevel\",!0),e){var o=i.selectAll(\"path.openline\").data(function(t){return t.pedgepaths||t.edgepaths});o.exit().remove(),o.enter().append(\"path\").classed(\"openline\",!0),o.attr(\"d\",function(t){return a.smoothopen(t,n)}).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\");var s=i.selectAll(\"path.closedline\").data(function(t){return t.ppaths||t.paths});s.exit().remove(),s.enter().append(\"path\").classed(\"closedline\",!0),s.attr(\"d\",function(t){return a.smoothclosed(t,n)}).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\")}return i},r.createLineClip=function(t,e,r,n){var i=e?\"clipline\"+n:null,o=r._fullLayout._clips.selectAll(\"#\"+i).data(e?[0]:[]);return o.exit().remove(),o.enter().append(\"clipPath\").classed(\"contourlineclip\",!0).attr(\"id\",i),a.setClipUrl(t,i,r),o},r.labelFormatter=function(t,e,r){if(t.labelformat)return r._d3locale.numberFormat(t.labelformat);var n;if(e)n=e.axis;else{if(n={type:\"linear\",_id:\"ycontour\",showexponent:\"all\",exponentformat:\"B\"},\"constraint\"===t.type){var i=t.value;Array.isArray(i)?n.range=[i[0],i[i.length-1]]:n.range=[i,i]}else n.range=[t.start,t.end],n.nticks=(t.end-t.start)/t.size;n.range[0]===n.range[1]&&(n.range[1]+=n.range[0]||1),n.nticks||(n.nticks=1e3),l(n,r),s.prepTicks(n),n._tmin=null,n._tmax=null}return function(t){return s.tickText(n,t).text}},r.calcTextOpts=function(t,e,r,n){var i=e(t);r.text(i).call(o.convertToTspans,n);var s=a.bBox(r.node(),!0);return{text:i,width:s.width,height:s.height,level:t,dy:(s.top+s.bottom)/2}},r.findBestTextLocation=function(t,e,r,n,a){var o,s,l,c,u,h=r.width;e.isClosed?(s=e.len/v.INITIALSEARCHPOINTS,o=e.min+s/2,l=e.max):(s=(e.len-h)/(v.INITIALSEARCHPOINTS+1),o=e.min+s+h/2,l=e.max-(s+h)/2);for(var f=1/0,p=0;p<v.ITERATIONS;p++){for(var d=o;d<l;d+=s){var g=i.getTextLocation(t,e.total,d,h),m=y(g,r,n,a);m<f&&(f=m,u=g,c=d)}if(f>2*v.MAXCOST)break;p&&(s/=2),l=(o=c-s/2)+1.5*s}if(f<=v.MAXCOST)return u},r.addLabelData=function(t,e,r,n){var i=e.width/2,a=e.height/2,o=t.x,s=t.y,l=t.theta,c=Math.sin(l),u=Math.cos(l),h=i*u,f=a*c,p=i*c,d=-a*u,g=[[o-h-f,s-p-d],[o+h-f,s+p-d],[o+h+f,s+p+d],[o-h+f,s-p+d]];r.push({text:e.text,x:o,y:s,dy:e.dy,theta:l,level:e.level,width:e.width,height:e.height}),n.push(g)},r.drawLabels=function(t,e,r,a,s){var l=t.selectAll(\"text\").data(e,function(t){return t.text+\",\"+t.x+\",\"+t.y+\",\"+t.theta});if(l.exit().remove(),l.enter().append(\"text\").attr({\"data-notex\":1,\"text-anchor\":\"middle\"}).each(function(t){var e=t.x+Math.sin(t.theta)*t.dy,i=t.y-Math.cos(t.theta)*t.dy;n.select(this).text(t.text).attr({x:e,y:i,transform:\"rotate(\"+180*t.theta/Math.PI+\" \"+e+\" \"+i+\")\"}).call(o.convertToTspans,r)}),s){for(var c=\"\",u=0;u<s.length;u++)c+=\"M\"+s[u].join(\"L\")+\"Z\";i.ensureSingle(a,\"path\",\"\").attr(\"d\",c)}}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/set_convert\":785,\"../heatmap/plot\":1012,\"./close_boundaries\":944,\"./constants\":946,\"./convert_to_constraints\":950,\"./empty_pathinfo\":952,\"./find_all_paths\":954,\"./make_crossings\":959,d3:163}],961:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\");function a(t,e,r){var i={type:\"linear\",range:[t,e]};return n.autoTicks(i,(e-t)/(r||15)),i}e.exports=function(t,e){var r=t.contours;if(t.autocontour){var o=t.zmin,s=t.zmax;(t.zauto||void 0===o)&&(o=i.aggNums(Math.min,null,e)),(t.zauto||void 0===s)&&(s=i.aggNums(Math.max,null,e));var l=a(o,s,t.ncontours);r.size=l.dtick,r.start=n.tickFirst(l),l.range.reverse(),r.end=n.tickFirst(l),r.start===o&&(r.start+=r.size),r.end===s&&(r.end-=r.size),r.start>r.end&&(r.start=r.end=(r.start+r.end)/2),t._input.contours||(t._input.contours={}),i.extendFlat(t._input.contours,{start:r.start,end:r.end,size:r.size}),t._input.autocontour=!0}else if(\"constraint\"!==r.type){var c,u=r.start,h=r.end,f=t._input.contours;if(u>h&&(r.start=f.start=h,h=r.end=f.end=u,u=r.start),!(r.size>0))c=u===h?1:a(u,h,t.ncontours).dtick,f.size=r.size=c}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767}],962:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../heatmap/style\"),o=t(\"./make_color_map\");e.exports=function(t){var e=n.select(t).selectAll(\"g.contour\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.each(function(t){var e=n.select(this),r=t[0].trace,a=r.contours,s=r.line,l=a.size||1,c=a.start,u=\"constraint\"===a.type,h=!u&&\"lines\"===a.coloring,f=!u&&\"fill\"===a.coloring,p=h||f?o(r):null;e.selectAll(\"g.contourlevel\").each(function(t){n.select(this).selectAll(\"path\").call(i.lineGroupStyle,s.width,h?p(t.level):s.color,s.dash)});var d=a.labelfont;if(e.selectAll(\"g.contourlabels text\").each(function(t){i.font(n.select(this),{family:d.family,size:d.size,color:d.color||(h?p(t.level):s.color)})}),u)e.selectAll(\"g.contourfill path\").style(\"fill\",r.fillcolor);else if(f){var g;e.selectAll(\"g.contourfill path\").style(\"fill\",function(t){return void 0===g&&(g=t.level),p(t.level+.5*l)}),void 0===g&&(g=c),e.selectAll(\"g.contourbg path\").style(\"fill\",p(g-.5*l))}}),a(t)}},{\"../../components/drawing\":614,\"../heatmap/style\":1013,\"./make_color_map\":958,d3:163}],963:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/defaults\"),i=t(\"./label_defaults\");e.exports=function(t,e,r,a,o){var s,l=r(\"contours.coloring\"),c=\"\";\"fill\"===l&&(s=r(\"contours.showlines\")),!1!==s&&(\"lines\"!==l&&(c=r(\"line.color\",\"#000\")),r(\"line.width\",.5),r(\"line.dash\")),\"none\"!==l&&(!0!==t.showlegend&&(e.showlegend=!1),e._dfltShowLegend=!1,n(t,e,a,r,{prefix:\"\",cLetter:\"z\"})),r(\"line.smoothing\"),i(r,a,c,o)}},{\"../../components/colorscale/defaults\":603,\"./label_defaults\":957}],964:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../contour/attributes\"),a=i.contours,o=t(\"../scatter/attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../lib/extend\").extendFlat,c=o.line;e.exports=l({carpet:{valType:\"string\",editType:\"calc\"},z:n.z,a:n.x,a0:n.x0,da:n.dx,b:n.y,b0:n.y0,db:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,atype:n.xtype,btype:n.ytype,fillcolor:i.fillcolor,autocontour:i.autocontour,ncontours:i.ncontours,contours:{type:a.type,start:a.start,end:a.end,size:a.size,coloring:{valType:\"enumerated\",values:[\"fill\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:a.showlines,showlabels:a.showlabels,labelfont:a.labelfont,labelformat:a.labelformat,operation:a.operation,value:a.value,editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:l({},c.color,{}),width:c.width,dash:c.dash,smoothing:l({},c.smoothing,{}),editType:\"plot\"},transforms:void 0},s(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../contour/attributes\":942,\"../heatmap/attributes\":1001,\"../scatter/attributes\":1112}],965:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\"),i=t(\"../../lib\"),a=t(\"../heatmap/convert_column_xyz\"),o=t(\"../heatmap/clean_2d_array\"),s=t(\"../heatmap/interp2d\"),l=t(\"../heatmap/find_empties\"),c=t(\"../heatmap/make_bound_array\"),u=t(\"./defaults\"),h=t(\"../carpet/lookup_carpetid\"),f=t(\"../contour/set_contours\");e.exports=function(t,e){var r=e._carpetTrace=h(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){if(!e.a||!e.b){var p=t.data[r.index],d=t.data[e.index];d.a||(d.a=p.a),d.b||(d.b=p.b),u(d,e,e._defaultColor,t._fullLayout)}var g=function(t,e){var r,u,h,f,p,d,g,v=e._carpetTrace,m=v.aaxis,y=v.baxis;m._minDtick=0,y._minDtick=0,i.isArray1D(e.z)&&a(e,m,y,\"a\",\"b\",[\"z\"]);r=e._a=e._a||e.a,f=e._b=e._b||e.b,r=r?m.makeCalcdata(e,\"_a\"):[],f=f?y.makeCalcdata(e,\"_b\"):[],u=e.a0||0,h=e.da||1,p=e.b0||0,d=e.db||1,g=e._z=o(e._z||e.z,e.transpose),e._emptypoints=l(g),s(g,e._emptypoints);var x=i.maxRowLength(g),b=\"scaled\"===e.xtype?\"\":r,_=c(e,b,u,h,x,m),w=\"scaled\"===e.ytype?\"\":f,k=c(e,w,p,d,g.length,y),T={a:_,b:k,z:g};\"levels\"===e.contours.type&&\"none\"!==e.contours.coloring&&n(t,e,{vals:g,containerStr:\"\",cLetter:\"z\"});return[T]}(t,e);return f(e,e._z),g}}},{\"../../components/colorscale/calc\":601,\"../../lib\":719,\"../carpet/lookup_carpetid\":915,\"../contour/set_contours\":961,\"../heatmap/clean_2d_array\":1003,\"../heatmap/convert_column_xyz\":1005,\"../heatmap/find_empties\":1007,\"../heatmap/interp2d\":1010,\"../heatmap/make_bound_array\":1011,\"./defaults\":966}],966:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"./attributes\"),o=t(\"../contour/constraint_defaults\"),s=t(\"../contour/contours_defaults\"),l=t(\"../contour/style_defaults\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,a,r,i)}if(u(\"carpet\"),t.a&&t.b){if(!i(t,e,u,c,\"a\",\"b\"))return void(e.visible=!1);u(\"text\"),\"constraint\"===u(\"contours.type\")?o(t,e,u,c,r,{hasHover:!1}):(s(t,e,u,function(r){return n.coerce2(t,e,a,r)}),l(t,e,u,c,{hasHover:!1}))}else e._defaultColor=r,e._length=null}},{\"../../lib\":719,\"../contour/constraint_defaults\":947,\"../contour/contours_defaults\":949,\"../contour/style_defaults\":963,\"../heatmap/xyz_defaults\":1015,\"./attributes\":964}],967:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../contour/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../contour/style\"),moduleType:\"trace\",name:\"contourcarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"contour\",\"symbols\",\"showLegend\",\"hasLines\",\"carpetDependent\"],meta:{}}},{\"../../plots/cartesian\":778,\"../contour/colorbar\":945,\"../contour/style\":962,\"./attributes\":964,\"./calc\":965,\"./defaults\":966,\"./plot\":970}],968:[function(t,e,r){\"use strict\";var n=t(\"../../components/drawing\"),i=t(\"../carpet/axis_aligned_line\"),a=t(\"../../lib\");e.exports=function(t,e,r,o,s,l,c,u){var h,f,p,d,g,v,m,y=\"\",x=e.edgepaths.map(function(t,e){return e}),b=!0,_=1e-4*Math.abs(r[0][0]-r[2][0]),w=1e-4*Math.abs(r[0][1]-r[2][1]);function k(t){return Math.abs(t[1]-r[0][1])<w}function T(t){return Math.abs(t[1]-r[2][1])<w}function A(t){return Math.abs(t[0]-r[0][0])<_}function M(t){return Math.abs(t[0]-r[2][0])<_}function S(t,e){var r,n,a,o,h=\"\";for(k(t)&&!M(t)||T(t)&&!A(t)?(o=s.aaxis,a=i(s,l,[t[0],e[0]],.5*(t[1]+e[1]))):(o=s.baxis,a=i(s,l,.5*(t[0]+e[0]),[t[1],e[1]])),r=1;r<a.length;r++)for(h+=o.smoothing?\"C\":\"L\",n=0;n<a[r].length;n++){var f=a[r][n];h+=[c.c2p(f[0]),u.c2p(f[1])]+\" \"}return h}for(h=0,f=null;x.length;){var E=e.edgepaths[h][0];for(f&&(y+=S(f,E)),m=n.smoothopen(e.edgepaths[h].map(o),e.smoothing),y+=b?m:m.replace(/^M/,\"L\"),x.splice(x.indexOf(h),1),f=e.edgepaths[h][e.edgepaths[h].length-1],g=-1,d=0;d<4;d++){if(!f){a.log(\"Missing end?\",h,e);break}for(k(f)&&!M(f)?p=r[1]:A(f)?p=r[0]:T(f)?p=r[3]:M(f)&&(p=r[2]),v=0;v<e.edgepaths.length;v++){var C=e.edgepaths[v][0];Math.abs(f[0]-p[0])<_?Math.abs(f[0]-C[0])<_&&(C[1]-f[1])*(p[1]-C[1])>=0&&(p=C,g=v):Math.abs(f[1]-p[1])<w?Math.abs(f[1]-C[1])<w&&(C[0]-f[0])*(p[0]-C[0])>=0&&(p=C,g=v):a.log(\"endpt to newendpt is not vert. or horz.\",f,p,C)}if(g>=0)break;y+=S(f,p),f=p}if(g===e.edgepaths.length){a.log(\"unclosed perimeter path\");break}h=g,(b=-1===x.indexOf(h))&&(h=x[0],y+=S(f,p)+\"Z\",f=null)}for(h=0;h<e.paths.length;h++)y+=n.smoothclosed(e.paths[h].map(o),e.smoothing);return y}},{\"../../components/drawing\":614,\"../../lib\":719,\"../carpet/axis_aligned_line\":899}],969:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i,a,o,s,l,c,u;for(r=0;r<t.length;r++){for(o=(a=t[r]).pedgepaths=[],s=a.ppaths=[],n=0;n<a.edgepaths.length;n++){for(u=a.edgepaths[n],l=[],i=0;i<u.length;i++)l[i]=e(u[i]);o.push(l)}for(n=0;n<a.paths.length;n++){for(u=a.paths[n],c=[],i=0;i<u.length;i++)c[i]=e(u[i]);s.push(c)}}}},{}],970:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../carpet/map_1d_array\"),a=t(\"../carpet/makepath\"),o=t(\"../../components/drawing\"),s=t(\"../../lib\"),l=t(\"../contour/make_crossings\"),c=t(\"../contour/find_all_paths\"),u=t(\"../contour/plot\"),h=t(\"../contour/constants\"),f=t(\"../contour/convert_to_constraints\"),p=t(\"./join_all_paths\"),d=t(\"../contour/empty_pathinfo\"),g=t(\"./map_pathinfo\"),v=t(\"../carpet/lookup_carpetid\"),m=t(\"../contour/close_boundaries\");function y(t,e,r){var n=t.getPointAtLength(e),i=t.getPointAtLength(r),a=i.x-n.x,o=i.y-n.y,s=Math.sqrt(a*a+o*o);return[a/s,o/s]}function x(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]);return[t[0]/e,t[1]/e]}function b(t,e){var r=Math.abs(t[0]*e[0]+t[1]*e[1]);return Math.sqrt(1-r*r)/r}e.exports=function(t,e,r,_){var w=e.xaxis,k=e.yaxis;s.makeTraceGroups(_,r,\"contour\").each(function(r){var _=n.select(this),T=r[0],A=T.trace,M=A._carpetTrace=v(t,A),S=t.calcdata[M.index][0];if(M.visible&&\"legendonly\"!==M.visible){var E=T.a,C=T.b,L=A.contours,P=d(L,e,T),O=\"constraint\"===L.type,z=L._operation,I=O?\"=\"===z?\"lines\":\"fill\":L.coloring,D=[[E[0],C[C.length-1]],[E[E.length-1],C[C.length-1]],[E[E.length-1],C[0]],[E[0],C[0]]];l(P);var R=1e-8*(E[E.length-1]-E[0]),F=1e-8*(C[C.length-1]-C[0]);c(P,R,F);var B,N,j,U,V=P;\"constraint\"===L.type&&(V=f(P,z),m(V,z,D,A)),g(P,G);var q=[];for(U=S.clipsegments.length-1;U>=0;U--)B=S.clipsegments[U],N=i([],B.x,w.c2p),j=i([],B.y,k.c2p),N.reverse(),j.reverse(),q.push(a(N,j,B.bicubic));var H=\"M\"+q.join(\"L\")+\"Z\";!function(t,e,r,n,o,l){var c,u,h,f,p=s.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"!==l||o?[]:[0]);p.enter().append(\"path\"),p.exit().remove();var d=[];for(f=0;f<e.length;f++)c=e[f],u=i([],c.x,r.c2p),h=i([],c.y,n.c2p),d.push(a(u,h,c.bicubic));p.attr(\"d\",\"M\"+d.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(_,S.clipsegments,w,k,O,I),function(t,e,r,i,a,o,l,c,u,h,f){var d=s.ensureSingle(e,\"g\",\"contourfill\").selectAll(\"path\").data(\"fill\"===h?a:[]);d.enter().append(\"path\"),d.exit().remove(),d.each(function(e){var a=p(t,e,o,l,c,u,r,i);e.prefixBoundary&&(a=f+a),a?n.select(this).attr(\"d\",a).style(\"stroke\",\"none\"):n.select(this).remove()})}(A,_,w,k,V,D,G,M,S,I,H),function(t,e,r,i,a,l,c){var f=s.ensureSingle(t,\"g\",\"contourlines\"),p=!1!==a.showlines,d=a.showlabels,g=p&&d,v=u.createLines(f,p||d,e),m=u.createLineClip(f,g,r,i.trace.uid),_=t.selectAll(\"g.contourlabels\").data(d?[0]:[]);if(_.exit().remove(),_.enter().append(\"g\").classed(\"contourlabels\",!0),d){var w=l.xaxis,k=l.yaxis,T=w._length,A=k._length,M=[[[0,0],[T,0],[T,A],[0,A]]],S=[];s.clearLocationCache();var E=u.labelFormatter(a,i.t.cb,r._fullLayout),C=o.tester.append(\"text\").attr(\"data-notex\",1).call(o.font,a.labelfont),L={left:0,right:T,center:T/2,top:0,bottom:A,middle:A/2},P=Math.sqrt(T*T+A*A),O=h.LABELDISTANCE*P/Math.max(1,e.length/h.LABELINCREASE);v.each(function(t){var e=u.calcTextOpts(t.level,E,C,r);n.select(this).selectAll(\"path\").each(function(r){var n=s.getVisibleSegment(this,L,e.height/2);if(n&&(function(t,e,r,n,i,a){for(var o,s=0;s<r.pedgepaths.length;s++)e===r.pedgepaths[s]&&(o=r.edgepaths[s]);if(!o)return;var l=i.a[0],c=i.a[i.a.length-1],u=i.b[0],h=i.b[i.b.length-1];function f(t,e){var r,n=0;return(Math.abs(t[0]-l)<.1||Math.abs(t[0]-c)<.1)&&(r=x(i.dxydb_rough(t[0],t[1],.1)),n=Math.max(n,a*b(e,r)/2)),(Math.abs(t[1]-u)<.1||Math.abs(t[1]-h)<.1)&&(r=x(i.dxyda_rough(t[0],t[1],.1)),n=Math.max(n,a*b(e,r)/2)),n}var p=y(t,0,1),d=y(t,n.total,n.total-1),g=f(o[0],p),v=n.total-f(o[o.length-1],d);n.min<g&&(n.min=g);n.max>v&&(n.max=v);n.len=n.max-n.min}(this,r,t,n,c,e.height),!(n.len<(e.width+e.height)*h.LABELMIN)))for(var i=Math.min(Math.ceil(n.len/O),h.LABELMAX),a=0;a<i;a++){var o=u.findBestTextLocation(this,n,e,S,L);if(!o)break;u.addLabelData(o,e,S,M)}})}),C.remove(),u.drawLabels(_,S,r,m,g?M:null)}d&&!p&&v.remove()}(_,P,t,T,L,e,M),o.setClipUrl(_,M._clipPathId,t)}function G(t){var e=M.ab2xy(t[0],t[1],!0);return[w.c2p(e[0]),k.c2p(e[1])]}})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../carpet/lookup_carpetid\":915,\"../carpet/makepath\":916,\"../carpet/map_1d_array\":917,\"../contour/close_boundaries\":944,\"../contour/constants\":946,\"../contour/convert_to_constraints\":950,\"../contour/empty_pathinfo\":952,\"../contour/find_all_paths\":954,\"../contour/make_crossings\":959,\"../contour/plot\":960,\"./join_all_paths\":968,\"./map_pathinfo\":969,d3:163}],971:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../scattermapbox/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({lon:o.lon,lat:o.lat,z:{valType:\"data_array\",editType:\"calc\"},radius:{valType:\"number\",editType:\"plot\",arrayOk:!0,min:1,dflt:30},below:{valType:\"string\",editType:\"plot\"},text:o.text,hovertext:o.hovertext,hoverinfo:s({},a.hoverinfo,{flags:[\"lon\",\"lat\",\"z\",\"text\",\"name\"]}),hovertemplate:i()},n(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scattermapbox/attributes\":1171}],972:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../components/colorscale/calc\"),s=t(\"../../lib\")._;e.exports=function(t,e){for(var r=e._length,l=new Array(r),c=e.z,u=i(c)&&c.length,h=0;h<r;h++){var f=l[h]={},p=e.lon[h],d=e.lat[h];if(f.lonlat=n(p)&&n(d)?[+p,+d]:[a,a],u){var g=c[h];f.z=n(g)?g:a}}return o(t,e,{vals:u?c:[0,1],containerStr:\"\",cLetter:\"z\"}),r&&(l[0].t={labels:{lat:s(t,\"lat:\")+\" \",lon:s(t,\"lon:\")+\" \"}}),l}},{\"../../components/colorscale/calc\":601,\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],973:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../../components/colorscale\"),s=t(\"../../constants/numerical\").BADNUM,l=t(\"../../lib/geojson_utils\").makeBlank;e.exports=function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,c=e._opts={heatmap:{layout:{visibility:\"none\"},paint:{}},geojson:l()};if(!r)return c;var u,h=[],f=e.z,p=e.radius,d=i.isArrayOrTypedArray(f)&&f.length,g=i.isArrayOrTypedArray(p);for(u=0;u<t.length;u++){var v=t[u],m=v.lonlat;if(m[0]!==s){var y={};if(d){var x=v.z;y.z=x!==s?x:0}g&&(y.r=n(p[u])&&p[u]>0?+p[u]:0),h.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:m},properties:y})}}var b=o.extractOpts(e),_=b.reversescale?o.flipScale(b.colorscale):b.colorscale,w=_[0][1],k=[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,a.opacity(w)<1?w:a.addOpacity(w,0)];for(u=1;u<_.length;u++)k.push(_[u][0],_[u][1]);var T=[\"interpolate\",[\"linear\"],[\"get\",\"z\"],b.min,0,b.max,1];return i.extendFlat(c.heatmap.paint,{\"heatmap-weight\":d?T:1/(b.max-b.min),\"heatmap-color\":k,\"heatmap-radius\":g?{type:\"identity\",property:\"r\"}:e.radius,\"heatmap-opacity\":e.opacity}),c.geojson={type:\"FeatureCollection\",features:h},c.heatmap.layout.visibility=\"visible\",c}},{\"../../components/color\":593,\"../../components/colorscale\":605,\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/geojson_utils\":714,\"fast-isnumeric\":225}],974:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"lon\")||[],c=s(\"lat\")||[],u=Math.min(l.length,c.length);u?(e._length=u,s(\"z\"),s(\"radius\"),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":971}],975:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.z=e.z,t}},{}],976:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../scattermapbox/hover\");e.exports=function(t,e,r){var o=a(t,e,r);if(o){var s=o[0],l=s.cd,c=l[0].trace,u=l[s.index];if(delete s.color,\"z\"in u){var h=s.subplot.mockAxis;s.z=u.z,s.zLabel=i.tickText(h,h.c2l(u.z),\"hover\").text}return s.extraText=function(t,e,r){if(t.hovertemplate)return;var i=(e.hi||t.hoverinfo).split(\"+\"),a=-1!==i.indexOf(\"all\"),o=-1!==i.indexOf(\"lon\"),s=-1!==i.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}a||o&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):o?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(a||-1!==i.indexOf(\"text\"))&&n.fillText(e,t,c);return c.join(\"<br>\")}(c,u,l[0].t.labels),[s]}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scattermapbox/hover\":1175}],977:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),getBelow:function(t,e){for(var r=e.getMapLayers(),n=0;n<r.length;n++){var i=r[n],a=i.id;if(\"symbol\"===i.type&&\"string\"==typeof a&&-1===a.indexOf(\"plotly-\"))return a}},moduleType:\"trace\",name:\"densitymapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\"],meta:{hr_name:\"density_mapbox\"}}},{\"../../plots/mapbox\":822,\"../heatmap/colorbar\":1004,\"./attributes\":971,\"./calc\":972,\"./defaults\":974,\"./event_data\":975,\"./hover\":976,\"./plot\":978}],978:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function a(t,e){this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"heatmap\",i+e+\"-heatmap\"]],this.below=null}var o=a.prototype;o.update=function(t){var e=this.subplot,r=this.layerList,i=n(t),a=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(i.geojson),a!==this.below&&(this._removeLayers(),this._addLayers(i,a),this.below=a);for(var o=0;o<r.length;o++){var s=r[o],l=s[0],c=s[1],u=i[l];e.setOptions(c,\"setLayoutProperty\",u.layout),\"visible\"===u.layout.visibility&&e.setOptions(c,\"setPaintProperty\",u.paint)}},o._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},o._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},o.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new a(t,r.uid),o=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(o,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),i}},{\"../../plots/mapbox/constants\":820,\"./convert\":973}],979:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":719}],980:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"./constants\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../components/color\");e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,hovertext:n.hovertext,hovertemplate:o({},{keys:s.eventDataKeys}),hoverinfo:l({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"percent initial\",\"percent previous\",\"percent total\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"percent initial\",\"percent previous\",\"percent total\",\"value\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},text:n.text,textposition:l({},n.textposition,{dflt:\"auto\"}),insidetextanchor:l({},n.insidetextanchor,{dflt:\"middle\"}),textangle:l({},n.textangle,{dflt:0}),textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:l({},n.orientation,{}),offset:l({},n.offset,{arrayOk:!1}),width:l({},n.width,{arrayOk:!1}),marker:n.marker,connector:{fillcolor:{valType:\"color\",editType:\"style\"},line:{color:l({},i.color,{dflt:c.defaultLine}),width:l({},i.width,{dflt:0,editType:\"plot\"}),dash:i.dash,editType:\"style\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":593,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../bar/attributes\":857,\"../scatter/attributes\":1112,\"./constants\":982}],981:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"./arrays_to_calcdata\"),a=t(\"../scatter/calc_selection\"),o=t(\"../../constants/numerical\").BADNUM;function s(t){return t===o?0:t}e.exports=function(t,e){var r,l,c,u,h=n.getFromId(t,e.xaxis||\"x\"),f=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=h.makeCalcdata(e,\"x\"),l=f.makeCalcdata(e,\"y\")):(r=f.makeCalcdata(e,\"y\"),l=h.makeCalcdata(e,\"x\"));var p,d=Math.min(l.length,r.length),g=new Array(d);for(e._base=[],c=0;c<d;c++){r[c]<0&&(r[c]=o);var v=!1;r[c]!==o&&c+1<d&&r[c+1]!==o&&(v=!0),u=g[c]={p:l[c],s:r[c],cNext:v},e._base[c]=-.5*u.s,e.ids&&(u.id=String(e.ids[c])),0===c&&(g[0].vTotal=0),g[0].vTotal+=s(u.s),u.begR=s(u.s)/s(g[0].s)}for(c=0;c<d;c++)(u=g[c]).s!==o&&(u.sumR=u.s/g[0].vTotal,u.difR=void 0!==p?u.s/p:1,p=u.s);return i(g,e),a(g,e),g}},{\"../../constants/numerical\":695,\"../../plots/cartesian/axes\":767,\"../scatter/calc_selection\":1114,\"./arrays_to_calcdata\":979}],982:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"percentInitial\",\"percentPrevious\",\"percentTotal\"]}},{}],983:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],h=[],f=[];for(i=0;i<o.length;i++){var p=o[i],d=\"h\"===p.orientation;!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"funnel\"===p.type&&(r=s[i],d?f.push(r):h.push(r),u.push(r))}var g={mode:a.funnelmode,norm:a.funnelnorm,gap:a.funnelgap,groupgap:a.funnelgroupgap};for(n(t,l,c,h,g),n(t,c,l,f,g),i=0;i<u.length;i++){r=u[i];for(var v=0;v<r.length;v++)v+1<r.length&&(r[v].nextP0=r[v+1].p0,r[v].nextS0=r[v+1].s0,r[v].nextP1=r[v+1].p1,r[v].nextS1=r[v+1].s1)}}},{\"../bar/cross_trace_calc\":860}],984:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"./attributes\"),l=t(\"../../components/color\");e.exports={supplyDefaults:function(t,e,r,i){function c(r,i){return n.coerce(t,e,s,r,i)}if(o(t,e,i,c)){c(\"orientation\",e.y&&!e.x?\"v\":\"h\"),c(\"offset\"),c(\"width\");var u=c(\"text\");c(\"hovertext\"),c(\"hovertemplate\");var h=c(\"textposition\");a(t,e,i,c,h,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"!==e.textposition&&c(\"textinfo\",Array.isArray(u)?\"text+value\":\"value\");var f=c(\"marker.color\",r);c(\"marker.line.color\",l.defaultLine),c(\"marker.line.width\"),c(\"connector.visible\")&&(c(\"connector.fillcolor\",function(t){var e=n.isArrayOrTypedArray(t)?\"#000\":t;return l.addOpacity(e,.5*l.opacity(e))}(f)),c(\"connector.line.width\")&&(c(\"connector.line.color\"),c(\"connector.line.dash\")))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,s,t)}if(\"group\"===e.funnelmode)for(var l=0;l<t.length;l++)r=(a=t[l])._input,i(r,a,e,o)}}},{\"../../components/color\":593,\"../../lib\":719,\"../bar/defaults\":861,\"../scatter/xy_defaults\":1137,\"./attributes\":980}],985:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"percentInitial\"in e&&(t.percentInitial=e.percentInitial),\"percentPrevious\"in e&&(t.percentPrevious=e.percentPrevious),\"percentTotal\"in e&&(t.percentTotal=e.percentTotal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],986:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\").opacity,i=t(\"../bar/hover\").hoverOnBars,a=t(\"../../lib\").formatPercent;e.exports=function(t,e,r,o){var s=i(t,e,r,o);if(s){var l=s.cd,c=l[0].trace,u=\"h\"===c.orientation,h=l[s.index];s[(u?\"x\":\"y\")+\"LabelVal\"]=h.s,s.percentInitial=h.begR,s.percentInitialLabel=a(h.begR,1),s.percentPrevious=h.difR,s.percentPreviousLabel=a(h.difR,1),s.percentTotal=h.sumR,s.percentTotalLabel=a(h.sumR,1);var f=h.hi||c.hoverinfo,p=[];if(f&&\"none\"!==f&&\"skip\"!==f){var d=\"all\"===f,g=f.split(\"+\"),v=function(t){return d||-1!==g.indexOf(t)};v(\"percent initial\")&&p.push(s.percentInitialLabel+\" of initial\"),v(\"percent previous\")&&p.push(s.percentPreviousLabel+\" of previous\"),v(\"percent total\")&&p.push(s.percentTotalLabel+\" of total\")}return s.extraText=p.join(\"<br>\"),s.color=function(t,e){var r=t.marker,i=e.mc||r.color,a=e.mlc||r.line.color,o=e.mlw||r.line.width;if(n(i))return i;if(n(a)&&o)return a}(c,h),[s]}}},{\"../../components/color\":593,\"../../lib\":719,\"../bar/hover\":863}],987:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"funnel\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../bar/select\":868,\"./attributes\":980,\"./calc\":981,\"./cross_trace_calc\":983,\"./defaults\":984,\"./event_data\":985,\"./hover\":986,\"./layout_attributes\":988,\"./layout_defaults\":989,\"./plot\":990,\"./style\":991}],988:[function(t,e,r){\"use strict\";e.exports={funnelmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},funnelgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},funnelgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],989:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"funnel\"===l.type){a=!0;break}}a&&(o(\"funnelmode\"),o(\"funnelgap\",.2),o(\"funnelgroupgap\"))}},{\"../../lib\":719,\"./layout_attributes\":988}],990:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../bar/plot\").plot;function s(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),i[3]=o.c2p(t.nextS1,!0),a[3]=s.c2p(t.nextP1,!0),n?[i,a]:[a,i]}e.exports=function(t,e,r,l){var c=t._fullLayout;!function(t,e,r,o){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each(function(r){var o=n.select(this),u=r[0].trace,h=i.ensureSingle(o,\"g\",\"regions\");if(u.connector&&u.connector.visible){var f=\"h\"===u.orientation,p=h.selectAll(\"g.region\").data(i.identity);p.enter().append(\"g\").classed(\"region\",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var u=s(r,l,c,f),h=u[0],p=u[1],g=\"\";void 0!==h[3]&&void 0!==p[3]&&(g+=f?\"M\"+h[0]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[2]+\"H\"+h[3]+\"L\"+h[1]+\",\"+p[1]+\"Z\":\"M\"+h[1]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[3]+\"V\"+p[2]+\"L\"+h[1]+\",\"+p[0]+\"Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}})}else h.remove()})}(t,e,r,l),function(t,e,r,o){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each(function(r){var o=n.select(this),u=r[0].trace,h=i.ensureSingle(o,\"g\",\"lines\");if(u.connector&&u.connector.visible&&u.connector.line.width){var f=\"h\"===u.orientation,p=h.selectAll(\"g.line\").data(i.identity);p.enter().append(\"g\").classed(\"line\",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var u=s(r,l,c,f),h=u[0],p=u[1],g=\"\";void 0!==h[3]&&void 0!==p[3]&&(f?(g+=\"M\"+h[0]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[2],g+=\"M\"+h[1]+\",\"+p[1]+\"L\"+h[3]+\",\"+p[2]):(g+=\"M\"+h[1]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[3],g+=\"M\"+h[1]+\",\"+p[0]+\"L\"+h[2]+\",\"+p[2])),\"\"===g&&(g=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}})}else h.remove()})}(t,e,r,l),o(t,e,r,l,{mode:c.funnelmode,norm:c.funnelmode,gap:c.funnelgap,groupgap:c.funnelgroupgap})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../bar/plot\":867,d3:163}],991:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\").styleTextPoints;e.exports={style:function(t,e,r){var l=r||n.select(t).selectAll(\"g.funnellayer\").selectAll(\"g.trace\");l.style(\"opacity\",function(t){return t[0].trace.opacity}),l.each(function(e){var r=n.select(this),l=e[0].trace;r.selectAll(\".point > path\").each(function(t){if(!t.isBlank){var e=l.marker;n.select(this).call(a.fill,t.mc||e.color).call(a.stroke,t.mlc||e.line.color).call(i.dashLine,e.line.dash,t.mlw||e.line.width).style(\"opacity\",l.selectedpoints&&!t.selected?o:1)}}),s(r,l,t),r.selectAll(\".regions\").each(function(){n.select(this).selectAll(\"path\").style(\"stroke-width\",0).call(a.fill,l.connector.fillcolor)}),r.selectAll(\".lines\").each(function(){var t=l.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)})})}}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../constants/interactions\":694,\"../bar/style\":870,d3:163}],992:[function(t,e,r){\"use strict\";var n=t(\"../pie/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../plots/domain\").attributes,o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports={labels:n.labels,label0:n.label0,dlabel:n.dlabel,values:n.values,marker:{colors:n.marker.colors,line:{color:s({},n.marker.line.color,{dflt:null}),width:s({},n.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},text:n.text,hovertext:n.hovertext,scalegroup:s({},n.scalegroup,{}),textinfo:s({},n.textinfo,{flags:[\"label\",\"text\",\"value\",\"percent\"]}),hoverinfo:s({},i.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:o({},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),textposition:s({},n.textposition,{values:[\"inside\",\"none\"],dflt:\"inside\"}),textfont:n.textfont,insidetextfont:n.insidetextfont,title:{text:n.title.text,font:n.title.font,position:s({},n.title.position,{values:[\"top left\",\"top center\",\"top right\"],dflt:\"top center\"}),editType:\"plot\"},domain:a({name:\"funnelarea\",trace:!0,editType:\"calc\"}),aspectratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},baseratio:{valType:\"number\",min:0,max:1,dflt:.333,editType:\"plot\"}}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../pie/attributes\":1086}],993:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData;r.name=\"funnelarea\",r.plot=function(t){var e=n.getModule(\"funnelarea\"),r=i(t.calcdata,e)[0];e.plot(t,r)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"funnelarea\"),a=e._has&&e._has(\"funnelarea\");i&&!a&&n._funnelarealayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],994:[function(t,e,r){\"use strict\";var n=t(\"../pie/calc\");e.exports={calc:function(t,e){return n.calc(t,e)},crossTraceCalc:function(t){n.crossTraceCalc(t,{type:\"funnelarea\"})}}},{\"../pie/calc\":1088}],995:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}var c,u=l(\"values\"),h=n.isArrayOrTypedArray(u),f=l(\"labels\");if(Array.isArray(f)?(c=f.length,h&&(c=Math.min(c,u.length))):h&&(c=u.length,l(\"label0\"),l(\"dlabel\")),c){e._length=c,l(\"marker.line.width\")&&l(\"marker.line.color\",s.paper_bgcolor),l(\"marker.colors\"),l(\"scalegroup\");var p=l(\"text\"),d=l(\"textinfo\",Array.isArray(p)?\"text+percent\":\"percent\");if(l(\"hovertext\"),l(\"hovertemplate\"),d&&\"none\"!==d){var g=l(\"textposition\");o(t,e,s,l,g,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}a(e,s,l),l(\"title.text\")&&(l(\"title.position\"),n.coerceFont(l,\"title.font\",s.font)),l(\"aspectratio\"),l(\"baseratio\")}else e.visible=!1}},{\"../../lib\":719,\"../../plots/domain\":792,\"../bar/defaults\":861,\"./attributes\":992}],996:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"funnelarea\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"funnelarea\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\"),styleOne:t(\"../pie/style_one\"),meta:{}}},{\"../pie/style_one\":1097,\"./attributes\":992,\"./base_plot\":993,\"./calc\":994,\"./defaults\":995,\"./layout_attributes\":997,\"./layout_defaults\":998,\"./plot\":999,\"./style\":1e3}],997:[function(t,e,r){\"use strict\";var n=t(\"../pie/layout_attributes\").hiddenlabels;e.exports={hiddenlabels:n,funnelareacolorway:{valType:\"colorlist\",editType:\"calc\"},extendfunnelareacolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{\"../pie/layout_attributes\":1093}],998:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"funnelareacolorway\",e.colorway),r(\"extendfunnelareacolors\")}},{\"../../lib\":719,\"./layout_attributes\":997}],999:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../lib\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../bar/plot\"),l=s.getTransform,c=s.toMoveInsideBar,u=t(\"../pie/helpers\"),h=t(\"../pie/plot\"),f=h.attachFxHandlers,p=h.determineInsideTextFont,d=h.layoutAreas,g=h.prerenderTitles,v=h.positionTitleOutside;function m(t,e){return\"l\"+(e[0]-t[0])+\",\"+(e[1]-t[1])}e.exports=function(t,e){var r=t._fullLayout;g(e,t),d(e,r._size),a.makeTraceGroups(r._funnelarealayer,e,\"trace\").each(function(e){var s=n.select(this),h=e[0],d=h.trace;!function(t){if(!t.length)return;var e=t[0],r=e.trace,n=r.aspectratio,i=r.baseratio;i>.999&&(i=.999);var a,o=Math.pow(i,2),s=e.vTotal,l=s,c=s*o/(1-o)/s;function u(){var t,e={x:t=Math.sqrt(c),y:-t};return[e.x,e.y]}var h,f,p=[];for(p.push(u()),h=t.length-1;h>-1;h--)if(!(f=t[h]).hidden){var d=f.v/l;c+=d,p.push(u())}var g=1/0,v=-1/0;for(h=0;h<p.length;h++)a=p[h],g=Math.min(g,a[1]),v=Math.max(v,a[1]);for(h=0;h<p.length;h++)p[h][1]-=(v+g)/2;var m=p[p.length-1][0],y=e.r,x=(v-g)/2,b=y/m,_=y/x*n;for(e.r=_*x,h=0;h<p.length;h++)p[h][0]*=b,p[h][1]*=_;var w=[-(a=p[0])[0],a[1]],k=[a[0],a[1]],T=0;for(h=t.length-1;h>-1;h--)if(!(f=t[h]).hidden){var A=p[T+=1][0],M=p[T][1];f.TL=[-A,M],f.TR=[A,M],f.BL=w,f.BR=k,f.pxmid=(S=f.TR,E=f.BR,[.5*(S[0]+E[0]),.5*(S[1]+E[1])]),w=f.TL,k=f.TR}var S,E}(e),s.each(function(){var s=n.select(this).selectAll(\"g.slice\").data(e);s.enter().append(\"g\").classed(\"slice\",!0),s.exit().remove(),s.each(function(r){if(r.hidden)n.select(this).selectAll(\"path,g\").remove();else{r.pointNumber=r.i,r.curveNumber=d.index;var s=h.cx,g=h.cy,v=n.select(this),y=v.selectAll(\"path.surface\").data([r]);y.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),v.call(f,t,e);var x=\"M\"+(s+r.TR[0])+\",\"+(g+r.TR[1])+m(r.TR,r.BR)+m(r.BR,r.BL)+m(r.BL,r.TL)+\"Z\";y.attr(\"d\",x);var b=u.castOption(d.textposition,r.pts),_=v.selectAll(\"g.slicetext\").data(r.text&&\"none\"!==b?[0]:[]);_.enter().append(\"g\").classed(\"slicetext\",!0),_.exit().remove(),_.each(function(){var e=a.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)});e.text(r.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,p(d,r,t._fullLayout.font)).call(o.convertToTspans,t);var u,h,f,v=i.bBox(e.node()),m=Math.min(r.BL[1],r.BR[1]),y=Math.max(r.TL[1],r.TR[1]);h=Math.max(r.TL[0],r.BL[0]),f=Math.min(r.TR[0],r.BR[0]),u=l(c(h,f,m,y,v,{isHorizontal:!0,constrained:!0,angle:0,anchor:\"middle\"})),e.attr(\"transform\",\"translate(\"+s+\",\"+g+\")\"+u)})}});var g=n.select(this).selectAll(\"g.titletext\").data(d.title.text?[0]:[]);g.enter().append(\"g\").classed(\"titletext\",!0),g.exit().remove(),g.each(function(){var e=a.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),s=d.title.text;d._meta&&(s=a.templateString(s,d._meta)),e.text(s).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,d.title.font).call(o.convertToTspans,t);var l=v(h,r._size);e.attr(\"transform\",\"translate(\"+l.x+\",\"+l.y+\")\"+(l.scale<1?\"scale(\"+l.scale+\")\":\"\")+\"translate(\"+l.tx+\",\"+l.ty+\")\")})})})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../bar/plot\":867,\"../pie/helpers\":1091,\"../pie/plot\":1095,d3:163}],1000:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../pie/style_one\");e.exports=function(t){t._fullLayout._funnelarealayer.selectAll(\".trace\").each(function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each(function(t){n.select(this).call(i,t,e)})})}},{\"../pie/style_one\":1097,d3:163}],1001:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../components/colorscale/attributes\"),o=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../lib/extend\").extendFlat);e.exports=o({z:{valType:\"data_array\",editType:\"calc\"},x:o({},n.x,{impliedEdits:{xtype:\"array\"}}),x0:o({},n.x0,{impliedEdits:{xtype:\"scaled\"}}),dx:o({},n.dx,{impliedEdits:{xtype:\"scaled\"}}),y:o({},n.y,{impliedEdits:{ytype:\"array\"}}),y0:o({},n.y0,{impliedEdits:{ytype:\"scaled\"}}),dy:o({},n.dy,{impliedEdits:{ytype:\"scaled\"}}),text:{valType:\"data_array\",editType:\"calc\"},hovertext:{valType:\"data_array\",editType:\"calc\"},transpose:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xtype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},ytype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},zsmooth:{valType:\"enumerated\",values:[\"fast\",\"best\",!1],dflt:!1,editType:\"calc\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xgap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},ygap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},zhoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},hovertemplate:i()},{transforms:void 0},a(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../scatter/attributes\":1112}],1002:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../histogram2d/calc\"),s=t(\"../../components/colorscale/calc\"),l=t(\"./convert_column_xyz\"),c=t(\"./clean_2d_array\"),u=t(\"./interp2d\"),h=t(\"./find_empties\"),f=t(\"./make_bound_array\");e.exports=function(t,e){var r,p,d,g,v,m,y,x,b,_=a.getFromId(t,e.xaxis||\"x\"),w=a.getFromId(t,e.yaxis||\"y\"),k=n.traceIs(e,\"contour\"),T=n.traceIs(e,\"histogram\"),A=n.traceIs(e,\"gl2d\"),M=k?\"best\":e.zsmooth;if(_._minDtick=0,w._minDtick=0,T)r=(b=o(t,e)).x,p=b.x0,d=b.dx,g=b.y,v=b.y0,m=b.dy,y=b.z;else{var S=e.z;i.isArray1D(S)?(l(e,_,w,\"x\",\"y\",[\"z\"]),r=e._x,g=e._y,S=e._z):(r=e._x=e.x?_.makeCalcdata(e,\"x\"):[],g=e._y=e.y?w.makeCalcdata(e,\"y\"):[]),p=e.x0,d=e.dx,v=e.y0,m=e.dy,y=c(S,e,_,w),(k||e.connectgaps)&&(e._emptypoints=h(y),u(y,e._emptypoints))}function E(t){M=e._input.zsmooth=e.zsmooth=!1,i.warn('cannot use zsmooth: \"fast\": '+t)}if(\"fast\"===M)if(\"log\"===_.type||\"log\"===w.type)E(\"log axis found\");else if(!T){if(r.length){var C=(r[r.length-1]-r[0])/(r.length-1),L=Math.abs(C/100);for(x=0;x<r.length-1;x++)if(Math.abs(r[x+1]-r[x]-C)>L){E(\"x scale is not linear\");break}}if(g.length&&\"fast\"===M){var P=(g[g.length-1]-g[0])/(g.length-1),O=Math.abs(P/100);for(x=0;x<g.length-1;x++)if(Math.abs(g[x+1]-g[x]-P)>O){E(\"y scale is not linear\");break}}}var z=i.maxRowLength(y),I=\"scaled\"===e.xtype?\"\":r,D=f(e,I,p,d,z,_),R=\"scaled\"===e.ytype?\"\":g,F=f(e,R,v,m,y.length,w);A||(e._extremes[_._id]=a.findExtremes(_,D),e._extremes[w._id]=a.findExtremes(w,F));var B={x:D,y:F,z:y,text:e._text||e.text,hovertext:e._hovertext||e.hovertext};if(I&&I.length===D.length-1&&(B.xCenter=I),R&&R.length===F.length-1&&(B.yCenter=R),T&&(B.xRanges=b.xRanges,B.yRanges=b.yRanges,B.pts=b.pts),k||s(t,e,{vals:y,cLetter:\"z\"}),k&&e.contours&&\"heatmap\"===e.contours.coloring){var N={type:\"contour\"===e.type?\"heatmap\":\"histogram2d\",xcalendar:e.xcalendar,ycalendar:e.ycalendar};B.xfill=f(N,I,p,d,z,_),B.yfill=f(N,R,v,m,y.length,w)}return[B]}},{\"../../components/colorscale/calc\":601,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../histogram2d/calc\":1033,\"./clean_2d_array\":1003,\"./convert_column_xyz\":1005,\"./find_empties\":1007,\"./interp2d\":1010,\"./make_bound_array\":1011}],1003:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r,o){var s,l,c,u,h,f;function p(t){if(n(t))return+t}if(e&&e.transpose){for(s=0,h=0;h<t.length;h++)s=Math.max(s,t[h].length);if(0===s)return!1;c=function(t){return t.length},u=function(t,e,r){return(t[r]||[])[e]}}else s=t.length,c=function(t,e){return t[e].length},u=function(t,e,r){return(t[e]||[])[r]};var d=function(t,e,r){return e===a||r===a?a:u(t,e,r)};function g(t){if(e&&\"carpet\"!==e.type&&\"contourcarpet\"!==e.type&&t&&\"category\"===t.type&&e[\"_\"+t._id.charAt(0)].length){var r=t._id.charAt(0),n={},o=e[\"_\"+r+\"CategoryMap\"]||e[r];for(h=0;h<o.length;h++)n[o[h]]=h;return function(e){var r=n[t._categories[e]];return r+1?r:a}}return i.identity}var v=g(r),m=g(o);o&&\"category\"===o.type&&(s=o._categories.length);var y=new Array(s);for(h=0;h<s;h++)for(l=r&&\"category\"===r.type?r._categories.length:c(t,h),y[h]=new Array(l),f=0;f<l;f++)y[h][f]=p(d(t,m(h),v(f)));return y}},{\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],1004:[function(t,e,r){\"use strict\";e.exports={min:\"zmin\",max:\"zmax\"}},{}],1005:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r,a,o,s){var l,c,u,h,f=t._length,p=e.makeCalcdata(t,a),d=r.makeCalcdata(t,o),g=t.text,v=void 0!==g&&n.isArray1D(g),m=t.hovertext,y=void 0!==m&&n.isArray1D(m),x=n.distinctVals(p),b=x.vals,_=n.distinctVals(d),w=_.vals,k=[];for(l=0;l<s.length;l++)k[l]=n.init2dArray(w.length,b.length);for(v&&(u=n.init2dArray(w.length,b.length)),y&&(h=n.init2dArray(w.length,b.length)),l=0;l<f;l++)if(p[l]!==i&&d[l]!==i){var T=n.findBin(p[l]+x.minDiff/2,b),A=n.findBin(d[l]+_.minDiff/2,w);for(c=0;c<s.length;c++){var M=t[s[c]];k[c][A][T]=M[l]}v&&(u[A][T]=g[l]),y&&(h[A][T]=m[l])}for(t[\"_\"+a]=b,t[\"_\"+o]=w,c=0;c<s.length;c++)t[\"_\"+s[c]]=k[c];v&&(t._text=u),y&&(t._hovertext=h),e&&\"category\"===e.type&&(t[\"_\"+a+\"CategoryMap\"]=b.map(function(t){return e._categories[t]})),r&&\"category\"===r.type&&(t[\"_\"+o+\"CategoryMap\"]=w.map(function(t){return r._categories[t]}))}},{\"../../constants/numerical\":695,\"../../lib\":719}],1006:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xyz_defaults\"),a=t(\"./style_defaults\"),o=t(\"../../components/colorscale/defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l)?(c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\"),a(t,e,c,l),c(\"connectgaps\",n.isArray1D(e.z)&&!1!==e.zsmooth),o(t,e,l,c,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":1001,\"./style_defaults\":1014,\"./xyz_defaults\":1015}],1007:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").maxRowLength;e.exports=function(t){var e,r,i,a,o,s,l,c,u=[],h={},f=[],p=t[0],d=[],g=[0,0,0],v=n(t);for(r=0;r<t.length;r++)for(e=d,d=p,p=t[r+1]||[],i=0;i<v;i++)void 0===d[i]&&((s=(void 0!==d[i-1]?1:0)+(void 0!==d[i+1]?1:0)+(void 0!==e[i]?1:0)+(void 0!==p[i]?1:0))?(0===r&&s++,0===i&&s++,r===t.length-1&&s++,i===d.length-1&&s++,s<4&&(h[[r,i]]=[r,i,s]),u.push([r,i,s])):f.push([r,i]));for(;f.length;){for(l={},c=!1,o=f.length-1;o>=0;o--)(s=((h[[(r=(a=f[o])[0])-1,i=a[1]]]||g)[2]+(h[[r+1,i]]||g)[2]+(h[[r,i-1]]||g)[2]+(h[[r,i+1]]||g)[2])/20)&&(l[a]=[r,i,s],f.splice(o,1),c=!0);if(!c)throw\"findEmpties iterated with no new neighbors\";for(a in l)h[a]=l[a],u.push(l[a])}return u.sort(function(t,e){return e[2]-t[2]})}},{\"../../lib\":719}],1008:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../components/colorscale\").extractOpts;e.exports=function(t,e,r,s,l,c){var u,h,f,p,d=t.cd[0],g=d.trace,v=t.xa,m=t.ya,y=d.x,x=d.y,b=d.z,_=d.xCenter,w=d.yCenter,k=d.zmask,T=g.zhoverformat,A=y,M=x;if(!1!==t.index){try{f=Math.round(t.index[1]),p=Math.round(t.index[0])}catch(e){return void i.error(\"Error hovering on heatmap, pointNumber must be [row,col], found:\",t.index)}if(f<0||f>=b[0].length||p<0||p>b.length)return}else{if(n.inbox(e-y[0],e-y[y.length-1],0)>0||n.inbox(r-x[0],r-x[x.length-1],0)>0)return;if(c){var S;for(A=[2*y[0]-y[1]],S=1;S<y.length;S++)A.push((y[S]+y[S-1])/2);for(A.push([2*y[y.length-1]-y[y.length-2]]),M=[2*x[0]-x[1]],S=1;S<x.length;S++)M.push((x[S]+x[S-1])/2);M.push([2*x[x.length-1]-x[x.length-2]])}f=Math.max(0,Math.min(A.length-2,i.findBin(e,A))),p=Math.max(0,Math.min(M.length-2,i.findBin(r,M)))}var E=v.c2p(y[f]),C=v.c2p(y[f+1]),L=m.c2p(x[p]),P=m.c2p(x[p+1]);c?(C=E,u=y[f],P=L,h=x[p]):(u=_?_[f]:(y[f]+y[f+1])/2,h=w?w[p]:(x[p]+x[p+1])/2,v&&\"category\"===v.type&&(u=y[f]),m&&\"category\"===m.type&&(h=x[p]),g.zsmooth&&(E=C=v.c2p(u),L=P=m.c2p(h)));var O,z=b[p][f];k&&!k[p][f]&&(z=void 0),Array.isArray(d.hovertext)&&Array.isArray(d.hovertext[p])?O=d.hovertext[p][f]:Array.isArray(d.text)&&Array.isArray(d.text[p])&&(O=d.text[p][f]);var I=o(g),D={type:\"linear\",range:[I.min,I.max],hoverformat:T,_separators:v._separators,_numFormat:v._numFormat},R=a.tickText(D,z,\"hover\").text;return[i.extendFlat(t,{index:[p,f],distance:t.maxHoverDistance,spikeDistance:t.maxSpikeDistance,x0:E,x1:C,y0:L,y1:P,xLabelVal:u,yLabelVal:h,zLabelVal:z,zLabel:R,text:O})]}},{\"../../components/colorscale\":605,\"../../components/fx\":632,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],1009:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:t(\"./colorbar\"),style:t(\"./style\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"heatmap\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":1001,\"./calc\":1002,\"./colorbar\":1004,\"./defaults\":1006,\"./hover\":1008,\"./plot\":1012,\"./style\":1013}],1010:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[-1,0],[1,0],[0,-1],[0,1]];function a(t){return.5-.25*Math.min(1,.5*t)}function o(t,e,r){var n,a,o,s,l,c,u,h,f,p,d,g,v,m=0;for(s=0;s<e.length;s++){for(a=(n=e[s])[0],o=n[1],d=t[a][o],p=0,f=0,l=0;l<4;l++)(u=t[a+(c=i[l])[0]])&&void 0!==(h=u[o+c[1]])&&(0===p?g=v=h:(g=Math.min(g,h),v=Math.max(v,h)),f++,p+=h);if(0===f)throw\"iterateInterp2d order is wrong: no defined neighbors\";t[a][o]=p/f,void 0===d?f<4&&(m=1):(t[a][o]=(1+r)*t[a][o]-r*d,v>g&&(m=Math.max(m,Math.abs(t[a][o]-d)/(v-g))))}return m}e.exports=function(t,e){var r,i=1;for(o(t,e),r=0;r<e.length&&!(e[r][2]<4);r++);for(e=e.slice(r),r=0;r<100&&i>.01;r++)i=o(t,e,a(i));return i>.01&&n.log(\"interp2d didn't converge quickly\",i),t}},{\"../../lib\":719}],1011:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a,o,s){var l,c,u,h=[],f=n.traceIs(t,\"contour\"),p=n.traceIs(t,\"histogram\"),d=n.traceIs(t,\"gl2d\");if(i(e)&&e.length>1&&!p&&\"category\"!==s.type){var g=e.length;if(!(g<=o))return f?e.slice(0,o):e.slice(0,o+1);if(f||d)h=e.slice(0,o);else if(1===o)h=[e[0]-.5,e[0]+.5];else{for(h=[1.5*e[0]-.5*e[1]],u=1;u<g;u++)h.push(.5*(e[u-1]+e[u]));h.push(1.5*e[g-1]-.5*e[g-2])}if(g<o){var v=h[h.length-1],m=v-h[h.length-2];for(u=g;u<o;u++)v+=m,h.push(v)}}else{var y=t[s._id.charAt(0)+\"calendar\"];if(p)l=s.r2c(r,0,y);else if(i(e)&&1===e.length)l=e[0];else if(void 0===r)l=0;else{l=(\"log\"===s.type?s.d2c:s.r2c)(r,0,y)}for(c=a||1,u=f||d?0:-.5;u<o;u++)h.push(l+c*u)}return h}},{\"../../lib\":719,\"../../registry\":847}],1012:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/colorscale\").makeColorScaleFuncFromTrace,l=t(\"../../constants/xmlns_namespaces\");function c(t,e){var r=e.length-2,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=e[n+1],s=o.constrain(n+(t-i)/(a-i)-.5,0,r),l=Math.round(s),c=Math.abs(s-l);return s&&s!==r&&c?{bin0:l,frac:c,bin1:Math.round(l+c/(s-l))}:{bin0:l,bin1:l,frac:0}}function u(t,e){var r=e.length-1,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=(t-i)/(e[n+1]-i)||0;return a<=0?{bin0:n,bin1:n,frac:0}:a<.5?{bin0:n,bin1:n+1,frac:a}:{bin0:n+1,bin1:n,frac:1-a}}function h(t,e,r){t[e]=r[0],t[e+1]=r[1],t[e+2]=r[2],t[e+3]=Math.round(255*r[3])}e.exports=function(t,e,r,f){var p=e.xaxis,d=e.yaxis;o.makeTraceGroups(f,r,\"hm\").each(function(e){var r,f,g,v,m,y,x=n.select(this),b=e[0],_=b.trace,w=b.z,k=b.x,T=b.y,A=b.xCenter,M=b.yCenter,S=a.traceIs(_,\"contour\"),E=S?\"best\":_.zsmooth,C=w.length,L=o.maxRowLength(w),P=!1,O=!1;for(y=0;void 0===r&&y<k.length-1;)r=p.c2p(k[y]),y++;for(y=k.length-1;void 0===f&&y>0;)f=p.c2p(k[y]),y--;for(f<r&&(g=f,f=r,r=g,P=!0),y=0;void 0===v&&y<T.length-1;)v=d.c2p(T[y]),y++;for(y=T.length-1;void 0===m&&y>0;)m=d.c2p(T[y]),y--;if(m<v&&(g=v,v=m,m=g,O=!0),S&&(A=k,M=T,k=b.xfill,T=b.yfill),\"fast\"!==E){var z=\"best\"===E?0:.5;r=Math.max(-z*p._length,r),f=Math.min((1+z)*p._length,f),v=Math.max(-z*d._length,v),m=Math.min((1+z)*d._length,m)}var I=Math.round(f-r),D=Math.round(m-v);if(I<=0||D<=0){x.selectAll(\"image\").data([]).exit().remove()}else{var R,F;\"fast\"===E?(R=L,F=C):(R=I,F=D);var B=document.createElement(\"canvas\");B.width=R,B.height=F;var N,j,U=B.getContext(\"2d\"),V=s(_,{noNumericCheck:!0,returnArray:!0});\"fast\"===E?(N=P?function(t){return L-1-t}:o.identity,j=O?function(t){return C-1-t}:o.identity):(N=function(t){return o.constrain(Math.round(p.c2p(k[t])-r),0,I)},j=function(t){return o.constrain(Math.round(d.c2p(T[t])-v),0,D)});var q,H,G,Y,W,X=j(0),Z=[X,X],J=P?0:1,K=O?0:1,$=0,Q=0,tt=0,et=0;if(E){var rt,nt=0;try{rt=new Uint8Array(I*D*4)}catch(t){rt=new Array(I*D*4)}if(\"best\"===E){var it,at,ot,st=A||k,lt=M||T,ct=new Array(st.length),ut=new Array(lt.length),ht=new Array(I),ft=A?u:c,pt=M?u:c;for(y=0;y<st.length;y++)ct[y]=Math.round(p.c2p(st[y])-r);for(y=0;y<lt.length;y++)ut[y]=Math.round(d.c2p(lt[y])-v);for(y=0;y<I;y++)ht[y]=ft(y,ct);for(H=0;H<D;H++)for(at=w[(it=pt(H,ut)).bin0],ot=w[it.bin1],y=0;y<I;y++,nt+=4)h(rt,nt,W=Tt(at,ot,ht[y],it))}else for(H=0;H<C;H++)for(Y=w[H],Z=j(H),y=0;y<I;y++)W=kt(Y[y],1),h(rt,nt=4*(Z*I+N(y)),W);var dt=U.createImageData(I,D);try{dt.data.set(rt)}catch(t){var gt=dt.data,vt=gt.length;for(H=0;H<vt;H++)gt[H]=rt[H]}U.putImageData(dt,0,0)}else{var mt=_.xgap,yt=_.ygap,xt=Math.floor(mt/2),bt=Math.floor(yt/2);for(H=0;H<C;H++)if(Y=w[H],Z.reverse(),Z[K]=j(H+1),Z[0]!==Z[1]&&void 0!==Z[0]&&void 0!==Z[1])for(q=[G=N(0),G],y=0;y<L;y++)q.reverse(),q[J]=N(y+1),q[0]!==q[1]&&void 0!==q[0]&&void 0!==q[1]&&(W=kt(Y[y],(q[1]-q[0])*(Z[1]-Z[0])),U.fillStyle=\"rgba(\"+W.join(\",\")+\")\",U.fillRect(q[0]+xt,Z[0]+bt,q[1]-q[0]-mt,Z[1]-Z[0]-yt))}Q=Math.round(Q/$),tt=Math.round(tt/$),et=Math.round(et/$);var _t=i(\"rgb(\"+Q+\",\"+tt+\",\"+et+\")\");t._hmpixcount=(t._hmpixcount||0)+$,t._hmlumcount=(t._hmlumcount||0)+$*_t.getLuminance();var wt=x.selectAll(\"image\").data(e);wt.enter().append(\"svg:image\").attr({xmlns:l.svg,preserveAspectRatio:\"none\"}),wt.attr({height:D,width:I,x:r,y:v,\"xlink:href\":B.toDataURL(\"image/png\")})}function kt(t,e){if(void 0!==t){var r=V(t);return r[0]=Math.round(r[0]),r[1]=Math.round(r[1]),r[2]=Math.round(r[2]),$+=e,Q+=r[0]*e,tt+=r[1]*e,et+=r[2]*e,r}return[0,0,0,0]}function Tt(t,e,r,n){var i=t[r.bin0];if(void 0===i)return kt(void 0,1);var a,o=t[r.bin1],s=e[r.bin0],l=e[r.bin1],c=o-i||0,u=s-i||0;return a=void 0===o?void 0===l?0:void 0===s?2*(l-i):2*(2*l-s-i)/3:void 0===l?void 0===s?0:2*(2*i-o-s)/3:void 0===s?2*(2*l-o-i)/3:l+i-o-s,kt(i+r.frac*c+n.frac*(u+r.frac*a))}})}},{\"../../components/colorscale\":605,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../registry\":847,d3:163,tinycolor2:537}],1013:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t){n.select(t).selectAll(\".hm image\").style(\"opacity\",function(t){return t.trace.opacity})}},{d3:163}],1014:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){!1===r(\"zsmooth\")&&(r(\"xgap\"),r(\"ygap\")),r(\"zhoverformat\")}},{}],1015:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\");function o(t,e){var r=e(t);return\"scaled\"===(r?e(t+\"type\",\"array\"):\"scaled\")&&(e(t+\"0\"),e(\"d\"+t)),r}e.exports=function(t,e,r,s,l,c){var u,h,f=r(\"z\");if(l=l||\"x\",c=c||\"y\",void 0===f||!f.length)return 0;if(i.isArray1D(t.z)){u=r(l),h=r(c);var p=i.minRowLength(u),d=i.minRowLength(h);if(0===p||0===d)return 0;e._length=Math.min(p,d,f.length)}else{if(u=o(l,r),h=o(c,r),!function(t){for(var e,r=!0,a=!1,o=!1,s=0;s<t.length;s++){if(e=t[s],!i.isArrayOrTypedArray(e)){r=!1;break}e.length>0&&(a=!0);for(var l=0;l<e.length;l++)if(n(e[l])){o=!0;break}}return r&&a&&o}(f))return 0;r(\"transpose\"),e._length=null}return a.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[l,c],s),!0}},{\"../../lib\":719,\"../../registry\":847,\"fast-isnumeric\":225}],1016:[function(t,e,r){\"use strict\";for(var n=t(\"../heatmap/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=[\"z\",\"x\",\"x0\",\"dx\",\"y\",\"y0\",\"dy\",\"text\",\"transpose\",\"xtype\",\"ytype\"],l={},c=0;c<s.length;c++){var u=s[c];l[u]=n[u]}a(l,i(\"\",{cLetter:\"z\",autoColorDflt:!1})),e.exports=o(l,\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../heatmap/attributes\":1001}],1017:[function(t,e,r){\"use strict\";var n=t(\"gl-heatmap2d\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib/str2rgbarray\");function o(t,e){this.scene=t,this.uid=e,this.type=\"heatmapgl\",this.name=\"\",this.hoverinfo=\"all\",this.xData=[],this.yData=[],this.zData=[],this.textLabels=[],this.idToIndex=[],this.bounds=[0,0,0,0],this.options={z:[],x:[],y:[],shape:[0,0],colorLevels:[0],colorValues:[0,0,0,1]},this.heatmap=n(t.glplot,this.options),this.heatmap._trace=this}var s=o.prototype;s.handlePick=function(t){var e=this.options,r=e.shape,n=t.pointId,i=n%r[0],a=Math.floor(n/r[0]),o=n;return{trace:this,dataCoord:t.dataCoord,traceCoord:[e.x[i],e.y[a],e.z[o]],textLabel:this.textLabels[n],name:this.name,pointIndex:[a,i],hoverinfo:this.hoverinfo}},s.update=function(t,e){var r=e[0];this.index=t.index,this.name=t.name,this.hoverinfo=t.hoverinfo;var n=r.z;this.options.z=[].concat.apply([],n);var o=n[0].length,s=n.length;this.options.shape=[o,s],this.options.x=r.x,this.options.y=r.y;var l=function(t){for(var e=t.colorscale,r=t.zmin,n=t.zmax,i=e.length,o=new Array(i),s=new Array(4*i),l=0;l<i;l++){var c=e[l],u=a(c[1]);o[l]=r+c[0]*(n-r);for(var h=0;h<4;h++)s[4*l+h]=u[h]}return{colorLevels:o,colorValues:s}}(t);this.options.colorLevels=l.colorLevels,this.options.colorValues=l.colorValues,this.textLabels=[].concat.apply([],t.text),this.heatmap.update(this.options);var c=this.scene.xaxis,u=this.scene.yaxis;t._extremes[c._id]=i.findExtremes(c,r.x),t._extremes[u._id]=i.findExtremes(u,r.y)},s.dispose=function(){this.heatmap.dispose()},e.exports=function(t,e,r){var n=new o(t,e.uid);return n.update(e,r),n}},{\"../../lib/str2rgbarray\":742,\"../../plots/cartesian/axes\":767,\"gl-heatmap2d\":251}],1018:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"../heatmap/defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../heatmap/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"heatmapgl\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"2dMap\"],meta:{}}},{\"../../plots/gl2d\":805,\"../heatmap/calc\":1002,\"../heatmap/colorbar\":1004,\"../heatmap/defaults\":1006,\"./attributes\":1016,\"./convert\":1017}],1019:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"./bin_attributes\"),o=t(\"./constants\"),s=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),orientation:n.orientation,histfunc:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"min\",\"max\"],dflt:\"count\",editType:\"calc\"},histnorm:{valType:\"enumerated\",values:[\"\",\"percent\",\"probability\",\"density\",\"probability density\"],dflt:\"\",editType:\"calc\"},cumulative:{enabled:{valType:\"boolean\",dflt:!1,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"increasing\",\"decreasing\"],dflt:\"increasing\",editType:\"calc\"},currentbin:{valType:\"enumerated\",values:[\"include\",\"exclude\",\"half\"],dflt:\"include\",editType:\"calc\"},editType:\"calc\"},nbinsx:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},xbins:a(\"x\",!0),nbinsy:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},ybins:a(\"y\",!0),autobinx:{valType:\"boolean\",dflt:null,editType:\"calc\"},autobiny:{valType:\"boolean\",dflt:null,editType:\"calc\"},bingroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:i({},{keys:o.eventDataKeys}),marker:n.marker,offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,_deprecated:{bardir:n._deprecated.bardir}}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../bar/attributes\":857,\"./bin_attributes\":1021,\"./constants\":1025}],1020:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=t.length,n=0,i=0;i<r;i++)e[i]?(t[i]/=e[i],n+=t[i]):t[i]=null;return n}},{}],1021:[function(t,e,r){\"use strict\";e.exports=function(t,e){return{start:{valType:\"any\",editType:\"calc\"},end:{valType:\"any\",editType:\"calc\"},size:{valType:\"any\",editType:\"calc\"},editType:\"calc\"}}},{}],1022:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports={count:function(t,e,r){return r[t]++,1},sum:function(t,e,r,i){var a=i[e];return n(a)?(a=Number(a),r[t]+=a,a):0},avg:function(t,e,r,i,a){var o=i[e];return n(o)&&(o=Number(o),r[t]+=o,a[t]++),0},min:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]>a){var o=a-r[t];return r[t]=a,o}}return 0},max:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]<a){var o=a-r[t];return r[t]=a,o}}return 0}}},{\"fast-isnumeric\":225}],1023:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.ONEAVGYEAR,a=n.ONEAVGMONTH,o=n.ONEDAY,s=n.ONEHOUR,l=n.ONEMIN,c=n.ONESEC,u=t(\"../../plots/cartesian/axes\").tickIncrement;function h(t,e,r,n){if(t*e<=0)return 1/0;for(var i=Math.abs(e-t),a=\"date\"===r.type,o=f(i,a),s=0;s<10;s++){var l=f(80*o,a);if(o===l)break;if(!p(l,t,e,a,r,n))break;o=l}return o}function f(t,e){return e&&t>c?t>o?t>1.1*i?i:t>1.1*a?a:o:t>s?s:t>l?l:c:Math.pow(10,Math.floor(Math.log(t)/Math.LN10))}function p(t,e,r,n,a,s){if(n&&t>o){var l=d(e,a,s),c=d(r,a,s),u=t===i?0:1;return l[u]!==c[u]}return Math.floor(r/t)-Math.floor(e/t)>.1}function d(t,e,r){var n=e.c2d(t,i,r).split(\"-\");return\"\"===n[0]&&(n.unshift(),n[0]=\"-\"+n[0]),n}e.exports=function(t,e,r,n,a){var s,l,c=-1.1*e,f=-.1*e,p=t-f,d=r[0],g=r[1],v=Math.min(h(d+f,d+p,n,a),h(g+f,g+p,n,a)),m=Math.min(h(d+c,d+f,n,a),h(g+c,g+f,n,a));if(v>m&&m<Math.abs(g-d)/4e3?(s=v,l=!1):(s=Math.min(v,m),l=!0),\"date\"===n.type&&s>o){var y=s===i?1:6,x=s===i?\"M12\":\"M1\";return function(e,r){var o=n.c2d(e,i,a),s=o.indexOf(\"-\",y);s>0&&(o=o.substr(0,s));var c=n.d2c(o,0,a);if(c<e){var h=u(c,x,!1,a);(c+h)/2<e+t&&(c=h)}return r&&l?u(c,x,!0,a):c}}return function(e,r){var n=s*Math.round(e/s);return n+s/10<e&&n+.9*s<e+t&&(n+=s),r&&l&&(n-=s),n}}},{\"../../constants/numerical\":695,\"../../plots/cartesian/axes\":767}],1024:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../bar/arrays_to_calcdata\"),l=t(\"./bin_functions\"),c=t(\"./norm_functions\"),u=t(\"./average\"),h=t(\"./bin_label_vals\");function f(t,e,r,s,l){var c,u,h,p,d,g,v,m=s+\"bins\",y=t._fullLayout,x=e[\"_\"+s+\"bingroup\"],b=y._histogramBinOpts[x],_=\"overlay\"===y.barmode,w=function(t){return r.r2c(t,0,p)},k=function(t){return r.c2r(t,0,p)},T=\"date\"===r.type?function(t){return t||0===t?i.cleanDate(t,null,p):null}:function(t){return n(t)?Number(t):null};function A(t,e,r){e[t+\"Found\"]?(e[t]=T(e[t]),null===e[t]&&(e[t]=r[t])):(g[t]=e[t]=r[t],i.nestedProperty(u[0],m+\".\"+t).set(r[t]))}if(e[\"_\"+s+\"autoBinFinished\"])delete e[\"_\"+s+\"autoBinFinished\"];else{u=b.traces;var M=[],S=!0,E=!1,C=!1;for(c=0;c<u.length;c++)if((h=u[c]).visible){var L=b.dirs[c];d=h[\"_\"+L+\"pos0\"]=r.makeCalcdata(h,L),M=i.concat(M,d),delete h[\"_\"+s+\"autoBinFinished\"],!0===e.visible&&(S?S=!1:(delete h._autoBin,h[\"_\"+s+\"autoBinFinished\"]=1),a.traceIs(h,\"2dMap\")&&(E=!0),\"histogram2dcontour\"===h.type&&(C=!0))}p=u[0][s+\"calendar\"];var P=o.autoBin(M,r,b.nbins,E,p,b.sizeFound&&b.size),O=u[0]._autoBin={};if(g=O[b.dirs[0]]={},C&&(b.size||(P.start=k(o.tickIncrement(w(P.start),P.size,!0,p))),void 0===b.end&&(P.end=k(o.tickIncrement(w(P.end),P.size,!1,p)))),_&&!a.traceIs(e,\"2dMap\")&&0===P._dataSpan&&\"category\"!==r.type&&\"multicategory\"!==r.type){if(l)return[P,d,!0];P=function(t,e,r,n,a){var o,s,l,c=t._fullLayout,u=function(t,e){for(var r=e.xaxis,n=e.yaxis,i=e.orientation,a=[],o=t._fullData,s=0;s<o.length;s++){var l=o[s];\"histogram\"===l.type&&!0===l.visible&&l.orientation===i&&l.xaxis===r&&l.yaxis===n&&a.push(l)}return a}(t,e),h=!1,p=1/0,d=[e];for(o=0;o<u.length;o++)if((s=u[o])===e)h=!0;else if(h){var g=f(t,s,r,n,!0),v=g[0],m=g[2];s[\"_\"+n+\"autoBinFinished\"]=1,s[\"_\"+n+\"pos0\"]=g[1],m?d.push(s):p=Math.min(p,v.size)}else l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]],p=Math.min(p,l.size||s[a].size);var y=new Array(d.length);for(o=0;o<d.length;o++)for(var x=d[o][\"_\"+n+\"pos0\"],b=0;b<x.length;b++)if(void 0!==x[b]){y[o]=x[b];break}isFinite(p)||(p=i.distinctVals(y).minDiff);for(o=0;o<d.length;o++){var _=(s=d[o])[n+\"calendar\"],w={start:r.c2r(y[o]-p/2,0,_),end:r.c2r(y[o]+p/2,0,_),size:p};s._input[a]=s[a]=w,(l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]])&&i.extendFlat(l,w)}return e[a]}(t,e,r,s,m)}(v=h.cumulative||{}).enabled&&\"include\"!==v.currentbin&&(\"decreasing\"===v.direction?P.start=k(o.tickIncrement(w(P.start),P.size,!0,p)):P.end=k(o.tickIncrement(w(P.end),P.size,!1,p))),b.size=P.size,b.sizeFound||(g.size=P.size,i.nestedProperty(u[0],m+\".size\").set(P.size)),A(\"start\",b,P),A(\"end\",b,P)}d=e[\"_\"+s+\"pos0\"],delete e[\"_\"+s+\"pos0\"];var z=e._input[m]||{},I=i.extendFlat({},b),D=b.start,R=r.r2l(z.start),F=void 0!==R;if((b.startFound||F)&&R!==r.r2l(D)){var B=F?R:i.aggNums(Math.min,null,d),N={type:\"category\"===r.type||\"multicategory\"===r.type?\"linear\":r.type,r2l:r.r2l,dtick:b.size,tick0:D,calendar:p,range:[B,o.tickIncrement(B,b.size,!1,p)].map(r.l2r)},j=o.tickFirst(N);j>r.r2l(B)&&(j=o.tickIncrement(j,b.size,!0,p)),I.start=r.l2r(j),F||i.nestedProperty(e,m+\".start\").set(I.start)}var U=b.end,V=r.r2l(z.end),q=void 0!==V;if((b.endFound||q)&&V!==r.r2l(U)){var H=q?V:i.aggNums(Math.max,null,d);I.end=r.l2r(H),q||i.nestedProperty(e,m+\".start\").set(I.end)}var G=\"autobin\"+s;return!1===e._input[G]&&(e._input[m]=i.extendFlat({},e[m]||{}),delete e._input[G],delete e[G]),[I,d]}e.exports={calc:function(t,e){var r,a,p,d,g=[],v=[],m=o.getFromId(t,\"h\"===e.orientation?e.yaxis:e.xaxis),y=\"h\"===e.orientation?\"y\":\"x\",x={x:\"y\",y:\"x\"}[y],b=e[y+\"calendar\"],_=e.cumulative,w=f(t,e,m,y),k=w[0],T=w[1],A=\"string\"==typeof k.size,M=[],S=A?M:k,E=[],C=[],L=[],P=0,O=e.histnorm,z=e.histfunc,I=-1!==O.indexOf(\"density\");_.enabled&&I&&(O=O.replace(/ ?density$/,\"\"),I=!1);var D,R=\"max\"===z||\"min\"===z?null:0,F=l.count,B=c[O],N=!1,j=function(t){return m.r2c(t,0,b)};for(i.isArrayOrTypedArray(e[x])&&\"count\"!==z&&(D=e[x],N=\"avg\"===z,F=l[z]),r=j(k.start),p=j(k.end)+(r-o.tickIncrement(r,k.size,!1,b))/1e6;r<p&&g.length<1e6&&(a=o.tickIncrement(r,k.size,!1,b),g.push((r+a)/2),v.push(R),L.push([]),M.push(r),I&&E.push(1/(a-r)),N&&C.push(0),!(a<=r));)r=a;M.push(r),A||\"date\"!==m.type||(S={start:j(S.start),end:j(S.end),size:S.size});var U,V=v.length,q=!0,H=1/0,G=1/0,Y={};for(r=0;r<T.length;r++){var W=T[r];(d=i.findBin(W,S))>=0&&d<V&&(P+=F(d,r,v,D,C),q&&L[d].length&&W!==T[L[d][0]]&&(q=!1),L[d].push(r),Y[r]=d,H=Math.min(H,W-M[d]),G=Math.min(G,M[d+1]-W))}q||(U=h(H,G,M,m,b)),N&&(P=u(v,C)),B&&B(v,P,E),_.enabled&&function(t,e,r){var n,i,a;function o(e){a=t[e],t[e]/=2}function s(e){i=t[e],t[e]=a+i/2,a+=i}if(\"half\"===r)if(\"increasing\"===e)for(o(0),n=1;n<t.length;n++)s(n);else for(o(t.length-1),n=t.length-2;n>=0;n--)s(n);else if(\"increasing\"===e){for(n=1;n<t.length;n++)t[n]+=t[n-1];\"exclude\"===r&&(t.unshift(0),t.pop())}else{for(n=t.length-2;n>=0;n--)t[n]+=t[n+1];\"exclude\"===r&&(t.push(0),t.shift())}}(v,_.direction,_.currentbin);var X=Math.min(g.length,v.length),Z=[],J=0,K=X-1;for(r=0;r<X;r++)if(v[r]){J=r;break}for(r=X-1;r>=J;r--)if(v[r]){K=r;break}for(r=J;r<=K;r++)if(n(g[r])&&n(v[r])){var $={p:g[r],s:v[r],b:0};_.enabled||($.pts=L[r],q?$.ph0=$.ph1=L[r].length?T[L[r][0]]:g[r]:($.ph0=U(M[r]),$.ph1=U(M[r+1],!0))),Z.push($)}return 1===Z.length&&(Z[0].width1=o.tickIncrement(Z[0].p,k.size,!1,b)-Z[0].p),s(Z,e),i.isArrayOrTypedArray(e.selectedpoints)&&i.tagSelected(Z,e,Y),Z},calcAllAutoBins:f}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../bar/arrays_to_calcdata\":856,\"./average\":1020,\"./bin_functions\":1022,\"./bin_label_vals\":1023,\"./norm_functions\":1031,\"fast-isnumeric\":225}],1025:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"binNumber\"]}},{}],1026:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../../registry\").traceIs,o=t(\"../bar/defaults\").handleGroupingDefaults,s=n.nestedProperty,l=i.getAxisGroup,c=[{aStr:{x:\"xbins.start\",y:\"ybins.start\"},name:\"start\"},{aStr:{x:\"xbins.end\",y:\"ybins.end\"},name:\"end\"},{aStr:{x:\"xbins.size\",y:\"ybins.size\"},name:\"size\"},{aStr:{x:\"nbinsx\",y:\"nbinsy\"},name:\"nbins\"}],u=[\"x\",\"y\"];e.exports=function(t,e){var r,h,f,p,d,g,v,m=e._histogramBinOpts={},y=[],x={},b=[];function _(t,e){return n.coerce(r._input,r,r._module.attributes,t,e)}function w(t){return\"v\"===t.orientation?\"x\":\"y\"}function k(t,r,a){var o=t.uid+\"__\"+a;r||(r=o);var s=function(t,r){return i.getFromTrace({_fullLayout:e},t,r).type}(t,a),l=t[a+\"calendar\"],c=m[r],u=!0;c&&(s===c.axType&&l===c.calendar?(u=!1,c.traces.push(t),c.dirs.push(a)):(r=o,s!==c.axType&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set on a\",\"type:\"+s,\"axis\",\"with bins on\",\"type:\"+c.axType,\"axis.\"].join(\" \")),l!==c.calendar&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set with a\",l,\"calendar\",\"with bins\",c.calendar?\"on a \"+c.calendar+\" calendar\":\"w/o a set calendar\"].join(\" \")))),u&&(m[r]={traces:[t],dirs:[a],axType:s,calendar:t[a+\"calendar\"]||\"\"}),t[\"_\"+a+\"bingroup\"]=r}for(d=0;d<t.length;d++)r=t[d],a(r,\"histogram\")&&(y.push(r),delete r._xautoBinFinished,delete r._yautoBinFinished,a(r,\"2dMap\")||o(r._input,r,e,_));var T=e._alignmentOpts||{};for(d=0;d<y.length;d++){if(r=y[d],f=\"\",!a(r,\"2dMap\")){if(p=w(r),\"group\"===e.barmode&&r.alignmentgroup){var A=r[p+\"axis\"],M=l(e,A)+r.orientation;(T[M]||{})[r.alignmentgroup]&&(f=M)}f||\"overlay\"===e.barmode||(f=l(e,r.xaxis)+l(e,r.yaxis)+w(r))}f?(x[f]||(x[f]=[]),x[f].push(r)):b.push(r)}for(f in x)if(1!==(h=x[f]).length){var S=!1;for(d=0;d<h.length;d++){r=h[d],S=_(\"bingroup\");break}for(f=S||f,d=0;d<h.length;d++){var E=(r=h[d])._input.bingroup;E&&E!==f&&n.warn([\"Trace\",r.index,\"must match\",\"within bingroup\",f+\".\",\"Ignoring its bingroup:\",E,\"setting.\"].join(\" \")),r.bingroup=f,k(r,f,w(r))}}else b.push(h[0]);for(d=0;d<b.length;d++){r=b[d];var C=_(\"bingroup\");if(a(r,\"2dMap\"))for(v=0;v<2;v++){var L=_((p=u[v])+\"bingroup\",C?C+\"__\"+p:null);k(r,L,p)}else k(r,C,w(r))}for(f in m){var P=m[f];for(h=P.traces,g=0;g<c.length;g++){var O,z,I=c[g],D=I.name;if(\"nbins\"!==D||!P.sizeFound){for(d=0;d<h.length;d++){if(r=h[d],p=P.dirs[d],O=I.aStr[p],void 0!==s(r._input,O).get()){P[D]=_(O),P[D+\"Found\"]=!0;break}(z=(r._autoBin||{})[p]||{})[D]&&s(r,O).set(z[D])}if(\"start\"===D||\"end\"===D)for(;d<h.length;d++)(r=h[d])[\"_\"+p+\"bingroup\"]&&_(O,(z=(r._autoBin||{})[p]||{})[D]);\"nbins\"!==D||P.sizeFound||P.nbinsFound||(r=h[0],P[D]=_(O))}}}}},{\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../bar/defaults\":861}],1027:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../bar/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,n){return i.coerce(t,e,s,r,n)}var u=c(\"x\"),h=c(\"y\");c(\"cumulative.enabled\")&&(c(\"cumulative.direction\"),c(\"cumulative.currentbin\")),c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\");var f=c(\"orientation\",h&&!u?\"h\":\"v\"),p=\"v\"===f?\"x\":\"y\",d=\"v\"===f?\"y\":\"x\",g=u&&h?Math.min(i.minRowLength(u)&&i.minRowLength(h)):i.minRowLength(e[p]||[]);if(g){e._length=g,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],l),e[d]&&c(\"histfunc\"),c(\"histnorm\"),c(\"autobin\"+p),o(t,e,c,r,l),i.coerceSelectionMarkerOpacity(e,c);var v=(e.marker.line||{}).color,m=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");m(t,e,v||a.defaultLine,{axis:\"y\"}),m(t,e,v||a.defaultLine,{axis:\"x\",inherit:\"y\"})}else e.visible=!1}},{\"../../components/color\":593,\"../../lib\":719,\"../../registry\":847,\"../bar/style_defaults\":871,\"./attributes\":1019}],1028:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"zLabelVal\"in e&&(t.z=e.zLabelVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),!(r.cumulative||{}).enabled){var a,o=Array.isArray(i)?n[0].pts[i[0]][i[1]]:n[i].pts;if(t.pointNumbers=o,t.binNumber=t.pointNumber,delete t.pointNumber,delete t.pointIndex,r._indexToPoints){a=[];for(var s=0;s<o.length;s++)a=a.concat(r._indexToPoints[o[s]])}else a=o;t.pointIndices=a}return t}},{}],1029:[function(t,e,r){\"use strict\";var n=t(\"../bar/hover\").hoverPoints,i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o){var s=(t=o[0]).cd[t.index],l=t.cd[0].trace;if(!l.cumulative.enabled){var c=\"h\"===l.orientation?\"y\":\"x\";t[c+\"Label\"]=i(t[c+\"a\"],s.ph0,s.ph1)}return l.hovermplate&&(t.hovertemplate=l.hovertemplate),o}}},{\"../../plots/cartesian/axes\":767,\"../bar/hover\":863}],1030:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"../bar/layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),supplyLayoutDefaults:t(\"../bar/layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"../bar/cross_trace_calc\").crossTraceCalc,plot:t(\"../bar/plot\").plot,layerName:\"barlayer\",style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,colorbar:t(\"../scatter/marker_colorbar\"),hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"histogram\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"histogram\",\"oriented\",\"errorBarsOK\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":778,\"../bar/cross_trace_calc\":860,\"../bar/layout_attributes\":865,\"../bar/layout_defaults\":866,\"../bar/plot\":867,\"../bar/select\":868,\"../bar/style\":870,\"../scatter/marker_colorbar\":1129,\"./attributes\":1019,\"./calc\":1024,\"./cross_trace_defaults\":1026,\"./defaults\":1027,\"./event_data\":1028,\"./hover\":1029}],1031:[function(t,e,r){\"use strict\";e.exports={percent:function(t,e){for(var r=t.length,n=100/e,i=0;i<r;i++)t[i]*=n},probability:function(t,e){for(var r=t.length,n=0;n<r;n++)t[n]/=e},density:function(t,e,r,n){var i=t.length;n=n||1;for(var a=0;a<i;a++)t[a]*=r[a]*n},\"probability density\":function(t,e,r,n){var i=t.length;n&&(e/=n);for(var a=0;a<i;a++)t[a]*=r[a]/e}}},{}],1032:[function(t,e,r){\"use strict\";var n=t(\"../histogram/attributes\"),i=t(\"../histogram/bin_attributes\"),a=t(\"../heatmap/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../lib/extend\").extendFlat;e.exports=l({x:n.x,y:n.y,z:{valType:\"data_array\",editType:\"calc\"},marker:{color:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:i(\"x\"),nbinsy:n.nbinsy,ybins:i(\"y\"),autobinx:n.autobinx,autobiny:n.autobiny,bingroup:l({},n.bingroup,{}),xbingroup:l({},n.bingroup,{}),ybingroup:l({},n.bingroup,{}),xgap:a.xgap,ygap:a.ygap,zsmooth:a.zsmooth,zhoverformat:a.zhoverformat,hovertemplate:o({},{keys:\"z\"})},s(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../heatmap/attributes\":1001,\"../histogram/attributes\":1019,\"../histogram/bin_attributes\":1021}],1033:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../histogram/bin_functions\"),o=t(\"../histogram/norm_functions\"),s=t(\"../histogram/average\"),l=t(\"../histogram/bin_label_vals\"),c=t(\"../histogram/calc\").calcAllAutoBins;function u(t,e,r,n){var i,a=new Array(t);if(n)for(i=0;i<t;i++)a[i]=1/(e[i+1]-e[i]);else{var o=1/r;for(i=0;i<t;i++)a[i]=o}return a}function h(t,e){return{start:t(e.start),end:t(e.end),size:e.size}}function f(t,e,r,n,i,a){var o,s=t.length-1,c=new Array(s),u=l(r,n,t,i,a);for(o=0;o<s;o++){var h=(e||[])[o];c[o]=void 0===h?[u(t[o]),u(t[o+1],!0)]:[h,h]}return c}e.exports=function(t,e){var r,l,p,d,g=i.getFromId(t,e.xaxis),v=i.getFromId(t,e.yaxis),m=e.xcalendar,y=e.ycalendar,x=function(t){return g.r2c(t,0,m)},b=function(t){return v.r2c(t,0,y)},_=c(t,e,g,\"x\"),w=_[0],k=_[1],T=c(t,e,v,\"y\"),A=T[0],M=T[1],S=e._length;k.length>S&&k.splice(S,k.length-S),M.length>S&&M.splice(S,M.length-S);var E=[],C=[],L=[],P=\"string\"==typeof w.size,O=\"string\"==typeof A.size,z=[],I=[],D=P?z:w,R=O?I:A,F=0,B=[],N=[],j=e.histnorm,U=e.histfunc,V=-1!==j.indexOf(\"density\"),q=\"max\"===U||\"min\"===U?null:0,H=a.count,G=o[j],Y=!1,W=[],X=[],Z=\"z\"in e?e.z:\"marker\"in e&&Array.isArray(e.marker.color)?e.marker.color:\"\";Z&&\"count\"!==U&&(Y=\"avg\"===U,H=a[U]);var J=w.size,K=x(w.start),$=x(w.end)+(K-i.tickIncrement(K,J,!1,m))/1e6;for(r=K;r<$;r=i.tickIncrement(r,J,!1,m))C.push(q),z.push(r),Y&&L.push(0);z.push(r);var Q,tt=C.length,et=(r-K)/tt,rt=(Q=K+et/2,g.c2r(Q,0,m)),nt=A.size,it=b(A.start),at=b(A.end)+(it-i.tickIncrement(it,nt,!1,y))/1e6;for(r=it;r<at;r=i.tickIncrement(r,nt,!1,y)){E.push(C.slice()),I.push(r);var ot=new Array(tt);for(l=0;l<tt;l++)ot[l]=[];N.push(ot),Y&&B.push(L.slice())}I.push(r);var st=E.length,lt=(r-it)/st,ct=function(t){return v.c2r(t,0,y)}(it+lt/2);V&&(W=u(C.length,D,et,P),X=u(E.length,R,lt,O)),P||\"date\"!==g.type||(D=h(x,D)),O||\"date\"!==v.type||(R=h(b,R));var ut=!0,ht=!0,ft=new Array(tt),pt=new Array(st),dt=1/0,gt=1/0,vt=1/0,mt=1/0;for(r=0;r<S;r++){var yt=k[r],xt=M[r];p=n.findBin(yt,D),d=n.findBin(xt,R),p>=0&&p<tt&&d>=0&&d<st&&(F+=H(p,r,E[d],Z,B[d]),N[d][p].push(r),ut&&(void 0===ft[p]?ft[p]=yt:ft[p]!==yt&&(ut=!1)),ht&&(void 0===pt[d]?pt[d]=xt:pt[d]!==xt&&(ht=!1)),dt=Math.min(dt,yt-z[p]),gt=Math.min(gt,z[p+1]-yt),vt=Math.min(vt,xt-I[d]),mt=Math.min(mt,I[d+1]-xt))}if(Y)for(d=0;d<st;d++)F+=s(E[d],B[d]);if(G)for(d=0;d<st;d++)G(E[d],F,W,X[d]);return{x:k,xRanges:f(z,ut&&ft,dt,gt,g,m),x0:rt,dx:et,y:M,yRanges:f(I,ht&&pt,vt,mt,v,y),y0:ct,dy:lt,z:E,pts:N}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../histogram/average\":1020,\"../histogram/bin_functions\":1022,\"../histogram/bin_label_vals\":1023,\"../histogram/calc\":1024,\"../histogram/norm_functions\":1031}],1034:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./sample_defaults\"),a=t(\"../heatmap/style_defaults\"),o=t(\"../../components/colorscale/defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,l),o(t,e,l,c,{prefix:\"\",cLetter:\"z\"}),c(\"hovertemplate\"))}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../heatmap/style_defaults\":1014,\"./attributes\":1032,\"./sample_defaults\":1037}],1035:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/hover\"),i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a,o,s){var l=n(t,e,r,a,o,s);if(l){var c=(t=l[0]).index,u=c[0],h=c[1],f=t.cd[0],p=f.xRanges[h],d=f.yRanges[u];return t.xLabel=i(t.xa,p[0],p[1]),t.yLabel=i(t.ya,d[0],d[1]),l}}},{\"../../plots/cartesian/axes\":767,\"../heatmap/hover\":1008}],1036:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../heatmap/calc\"),plot:t(\"../heatmap/plot\"),layerName:\"heatmaplayer\",colorbar:t(\"../heatmap/colorbar\"),style:t(\"../heatmap/style\"),hoverPoints:t(\"./hover\"),eventData:t(\"../histogram/event_data\"),moduleType:\"trace\",name:\"histogram2d\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"histogram\"],meta:{}}},{\"../../plots/cartesian\":778,\"../heatmap/calc\":1002,\"../heatmap/colorbar\":1004,\"../heatmap/plot\":1012,\"../heatmap/style\":1013,\"../histogram/cross_trace_defaults\":1026,\"../histogram/event_data\":1028,\"./attributes\":1032,\"./defaults\":1034,\"./hover\":1035}],1037:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"y\"),l=i.minRowLength(o),c=i.minRowLength(s);l&&c?(e._length=Math.min(l,c),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a),(r(\"z\")||r(\"marker.color\"))&&r(\"histfunc\"),r(\"histnorm\"),r(\"autobinx\"),r(\"autobiny\")):e.visible=!1}},{\"../../lib\":719,\"../../registry\":847}],1038:[function(t,e,r){\"use strict\";var n=t(\"../histogram2d/attributes\"),i=t(\"../contour/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat;e.exports=o({x:n.x,y:n.y,z:n.z,marker:n.marker,histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:n.xbins,nbinsy:n.nbinsy,ybins:n.ybins,autobinx:n.autobinx,autobiny:n.autobiny,bingroup:n.bingroup,xbingroup:n.xbingroup,ybingroup:n.ybingroup,autocontour:i.autocontour,ncontours:i.ncontours,contours:i.contours,line:i.line,zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../contour/attributes\":942,\"../histogram2d/attributes\":1032}],1039:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../histogram2d/sample_defaults\"),a=t(\"../contour/contours_defaults\"),o=t(\"../contour/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,function(r){return n.coerce2(t,e,s,r)}),o(t,e,c,l),c(\"hovertemplate\"))}},{\"../../lib\":719,\"../contour/contours_defaults\":949,\"../contour/style_defaults\":963,\"../histogram2d/sample_defaults\":1037,\"./attributes\":1038}],1040:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../contour/calc\"),plot:t(\"../contour/plot\").plot,layerName:\"contourlayer\",style:t(\"../contour/style\"),colorbar:t(\"../contour/colorbar\"),hoverPoints:t(\"../contour/hover\"),moduleType:\"trace\",name:\"histogram2dcontour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"histogram\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":778,\"../contour/calc\":943,\"../contour/colorbar\":945,\"../contour/hover\":955,\"../contour/plot\":960,\"../contour/style\":962,\"../histogram/cross_trace_defaults\":1026,\"./attributes\":1038,\"./defaults\":1039}],1041:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../lib/extend\").extendDeep,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../components/color/attributes\"),l=t(\"../../plots/domain\").attributes,c=t(\"../../plots/cartesian/layout_attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,h=t(\"../../constants/delta.js\"),f=(t(\"../../constants/docs\").FORMAT_LINK,o({editType:\"plot\",colorEditType:\"plot\"})),p={color:{valType:\"color\",editType:\"plot\"},line:{color:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},width:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"calc\"},thickness:{valType:\"number\",min:0,max:1,dflt:1,editType:\"plot\"},editType:\"calc\"},d={valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},g=u(\"steps\",i({},p,{range:d}));e.exports={mode:{valType:\"flaglist\",editType:\"calc\",flags:[\"number\",\"delta\",\"gauge\"],dflt:\"number\"},value:{valType:\"number\",editType:\"calc\",anim:!0},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},domain:l({name:\"indicator\",trace:!0,editType:\"calc\"}),title:{text:{valType:\"string\",editType:\"plot\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},font:n({},f,{}),editType:\"plot\"},number:{valueformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:n({},f,{}),prefix:{valType:\"string\",dflt:\"\",editType:\"plot\"},suffix:{valType:\"string\",dflt:\"\",editType:\"plot\"},editType:\"plot\"},delta:{reference:{valType:\"number\",editType:\"calc\"},position:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],dflt:\"bottom\",editType:\"plot\"},relative:{valType:\"boolean\",editType:\"plot\",dflt:!1},valueformat:{valType:\"string\",editType:\"plot\"},increasing:{symbol:{valType:\"string\",dflt:h.INCREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:h.INCREASING.COLOR,editType:\"plot\"},editType:\"plot\"},decreasing:{symbol:{valType:\"string\",dflt:h.DECREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:h.DECREASING.COLOR,editType:\"plot\"},editType:\"plot\"},font:n({},f,{}),editType:\"calc\"},gauge:{shape:{valType:\"enumerated\",editType:\"plot\",dflt:\"angular\",values:[\"angular\",\"bullet\"]},bar:i({},p,{color:{dflt:\"green\"}}),bgcolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},axis:a({range:d,visible:n({},c.visible,{dflt:!0}),tickmode:c.tickmode,nticks:c.nticks,tick0:c.tick0,dtick:c.dtick,tickvals:c.tickvals,ticktext:c.ticktext,ticks:n({},c.ticks,{dflt:\"outside\"}),ticklen:c.ticklen,tickwidth:c.tickwidth,tickcolor:c.tickcolor,showticklabels:c.showticklabels,tickfont:o({}),tickangle:c.tickangle,tickformat:c.tickformat,tickformatstops:c.tickformatstops,tickprefix:c.tickprefix,showtickprefix:c.showtickprefix,ticksuffix:c.ticksuffix,showticksuffix:c.showticksuffix,separatethousands:c.separatethousands,exponentformat:c.exponentformat,showexponent:c.showexponent,editType:\"plot\"},\"plot\"),steps:g,threshold:{line:{color:n({},p.line.color,{}),width:n({},p.line.width,{dflt:1}),editType:\"plot\"},thickness:n({},p.thickness,{dflt:.85}),value:{valType:\"number\",editType:\"calc\",dflt:!1},editType:\"plot\"},editType:\"plot\"}}},{\"../../components/color/attributes\":592,\"../../constants/delta.js\":689,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1042:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=r.name=\"indicator\";r.plot=function(t,e,r,o){var s=n.getModule(a),l=i(t.calcdata,s)[0];s.plot(t,l,r,o)},r.clean=function(t,e,r,n){var i=n._has&&n._has(a),o=e._has&&e._has(a);i&&!o&&n._indicatorlayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],1043:[function(t,e,r){\"use strict\";e.exports={calc:function(t,e){var r=[],n=e.value;\"number\"!=typeof e._lastValue&&(e._lastValue=e.value);var i=e._lastValue,a=i;return e._hasDelta&&\"number\"==typeof e.delta.reference&&(a=e.delta.reference),r[0]={y:n,lastY:i,delta:n-a,relativeDelta:(n-a)/a},r}}},{}],1044:[function(t,e,r){\"use strict\";e.exports={defaultNumberFontSize:80,bulletNumberDomainSize:.25,bulletPadding:.025,innerRadius:.75,valueThickness:.5,titlePadding:5,horizontalPadding:10}},{}],1045:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../../plot_api/plot_template\"),s=t(\"../../plots/array_container_defaults\"),l=t(\"./constants.js\"),c=t(\"../../plots/cartesian/tick_value_defaults\"),u=t(\"../../plots/cartesian/tick_mark_defaults\"),h=t(\"../../plots/cartesian/tick_label_defaults\");function f(t,e){function r(r,a){return n.coerce(t,e,i.gauge.steps,r,a)}r(\"color\"),r(\"line.color\"),r(\"line.width\"),r(\"range\"),r(\"thickness\")}e.exports={supplyDefaults:function(t,e,r,p){function d(r,a){return n.coerce(t,e,i,r,a)}a(e,p,d),d(\"mode\"),e._hasNumber=-1!==e.mode.indexOf(\"number\"),e._hasDelta=-1!==e.mode.indexOf(\"delta\"),e._hasGauge=-1!==e.mode.indexOf(\"gauge\");var g=d(\"value\");e._range=[0,\"number\"==typeof g?1.5*g:1];var v,m,y,x,b,_,w=new Array(2);function k(t,e){return n.coerce(y,x,i.gauge,t,e)}function T(t,e){return n.coerce(b,_,i.gauge.axis,t,e)}if(e._hasNumber&&(d(\"number.valueformat\"),d(\"number.font.color\",p.font.color),d(\"number.font.family\",p.font.family),d(\"number.font.size\"),void 0===e.number.font.size&&(e.number.font.size=l.defaultNumberFontSize,w[0]=!0),d(\"number.prefix\"),d(\"number.suffix\"),v=e.number.font.size),e._hasDelta&&(d(\"delta.font.color\",p.font.color),d(\"delta.font.family\",p.font.family),d(\"delta.font.size\"),void 0===e.delta.font.size&&(e.delta.font.size=(e._hasNumber?.5:1)*(v||l.defaultNumberFontSize),w[1]=!0),d(\"delta.reference\",e.value),d(\"delta.relative\"),d(\"delta.valueformat\",e.delta.relative?\"2%\":\"\"),d(\"delta.increasing.symbol\"),d(\"delta.increasing.color\"),d(\"delta.decreasing.symbol\"),d(\"delta.decreasing.color\"),d(\"delta.position\"),m=e.delta.font.size),e._scaleNumbers=(!e._hasNumber||w[0])&&(!e._hasDelta||w[1])||!1,d(\"title.font.color\",p.font.color),d(\"title.font.family\",p.font.family),d(\"title.font.size\",.25*(v||m||l.defaultNumberFontSize)),d(\"title.text\"),e._hasGauge){(y=t.gauge)||(y={}),x=o.newContainer(e,\"gauge\"),k(\"shape\"),(e._isBullet=\"bullet\"===e.gauge.shape)||d(\"title.align\",\"center\"),(e._isAngular=\"angular\"===e.gauge.shape)||d(\"align\",\"center\"),k(\"bgcolor\",p.paper_bgcolor),k(\"borderwidth\"),k(\"bordercolor\"),k(\"bar.color\"),k(\"bar.line.color\"),k(\"bar.line.width\"),k(\"bar.thickness\",l.valueThickness*(\"bullet\"===e.gauge.shape?.5:1)),s(y,x,{name:\"steps\",handleItemDefaults:f}),k(\"threshold.value\"),k(\"threshold.thickness\"),k(\"threshold.line.width\"),k(\"threshold.line.color\"),b={},y&&(b=y.axis||{}),_=o.newContainer(x,\"axis\"),T(\"visible\"),e._range=T(\"range\",e._range);var A={outerTicks:!0};c(b,_,T,\"linear\"),h(b,_,T,\"linear\",A),u(b,_,T,A)}else d(\"title.align\",\"center\"),d(\"align\",\"center\"),e._isAngular=e._isBullet=!1;e._length=null}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/tick_label_defaults\":786,\"../../plots/cartesian/tick_mark_defaults\":787,\"../../plots/cartesian/tick_value_defaults\":788,\"../../plots/domain\":792,\"./attributes\":1041,\"./constants.js\":1044}],1046:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"indicator\",basePlotModule:t(\"./base_plot\"),categories:[\"svg\",\"noOpacity\",\"noHover\"],animatable:!0,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\").calc,plot:t(\"./plot\"),meta:{}}},{\"./attributes\":1041,\"./base_plot\":1042,\"./calc\":1043,\"./defaults\":1045,\"./plot\":1047}],1047:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=i.rad2deg,o=t(\"../../constants/alignment\").MID_SHIFT,s=t(\"../../components/drawing\"),l=t(\"./constants\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"../../plots/cartesian/axes\"),h=t(\"../../plots/cartesian/axis_defaults\"),f=t(\"../../plots/cartesian/position_defaults\"),p=t(\"../../plots/cartesian/layout_attributes\"),d=t(\"../../components/color\"),g={left:\"start\",center:\"middle\",right:\"end\"},v={left:0,center:.5,right:1},m=/[yzafpn\\xb5mkMGTPEZY]/;function y(t){return t&&t.duration>0}function x(t){t.each(function(t){d.stroke(n.select(this),t.line.color)}).each(function(t){d.fill(n.select(this),t.color)}).style(\"stroke-width\",function(t){return t.line.width})}function b(t,e,r){var n=t._fullLayout,a=i.extendFlat({type:\"linear\",ticks:\"outside\",range:r,showline:!0},e),o={type:\"linear\",_id:\"x\"+e._id},s={letter:\"x\",font:n.font,noHover:!0,noTickson:!0};function l(t,e){return i.coerce(a,o,p,t,e)}return h(a,o,l,s,n),f(a,o,l,s),o}function _(t,e){return\"translate(\"+t+\",\"+e+\")\"}function w(t,e,r){return[Math.min(e/t.width,r/t.height),t,e+\"x\"+r]}function k(t,e,r,i){var a=document.createElementNS(\"http://www.w3.org/2000/svg\",\"text\"),o=n.select(a);return o.text(t).attr(\"x\",0).attr(\"y\",0).attr(\"text-anchor\",r).attr(\"data-unformatted\",t).call(c.convertToTspans,i).call(s.font,e),s.bBox(o.node())}function T(t,e,r,n,a,o){var s=\"_cache\"+e;t[s]&&t[s].key===a||(t[s]={key:a,value:r});var l=i.aggNums(o,null,[t[s].value,n],2);return t[s].value=l,l}e.exports=function(t,e,r,h){var f,p=t._fullLayout;y(r)&&h&&(f=h()),i.makeTraceGroups(p._indicatorlayer,e,\"trace\").each(function(e){var h,A,M,S,E,C=e[0].trace,L=n.select(this),P=C._hasGauge,O=C._isAngular,z=C._isBullet,I=C.domain,D={w:p._size.w*(I.x[1]-I.x[0]),h:p._size.h*(I.y[1]-I.y[0]),l:p._size.l+p._size.w*I.x[0],r:p._size.r+p._size.w*(1-I.x[1]),t:p._size.t+p._size.h*(1-I.y[1]),b:p._size.b+p._size.h*I.y[0]},R=D.l+D.w/2,F=D.t+D.h/2,B=Math.min(D.w/2,D.h),N=l.innerRadius*B,j=C.align||\"center\";if(A=F,P){if(O&&(h=R,A=F+B/2,M=function(t){return e=t,r=.9*N,n=Math.sqrt(e.width/2*(e.width/2)+e.height*e.height),[r/n,e,r];var e,r,n}),z){var U=l.bulletPadding,V=1-l.bulletNumberDomainSize+U;h=D.l+(V+(1-V)*v[j])*D.w,M=function(t){return w(t,(l.bulletNumberDomainSize-U)*D.w,D.h)}}}else h=D.l+v[j]*D.w,M=function(t){return w(t,D.w,D.h)};!function(t,e,r,a){var o,l,h,f=r[0].trace,p=a.numbersX,x=a.numbersY,w=f.align||\"center\",A=g[w],M=a.transitionOpts,S=a.onComplete,E=i.ensureSingle(e,\"g\",\"numbers\"),C=[];f._hasNumber&&C.push(\"number\");f._hasDelta&&(C.push(\"delta\"),\"left\"===f.delta.position&&C.reverse());var L=E.selectAll(\"text\").data(C);function P(e,r,n,i){if(!e.match(\"s\")||n>=0==i>=0||r(n).slice(-1).match(m)||r(i).slice(-1).match(m))return r;var a=e.slice().replace(\"s\",\"f\").replace(/\\d+/,function(t){return parseInt(t)-1}),o=b(t,{tickformat:a});return function(t){return Math.abs(t)<1?u.tickText(o,t).text:r(t)}}L.enter().append(\"text\"),L.attr(\"text-anchor\",function(){return A}).attr(\"class\",function(t){return t}).attr(\"x\",null).attr(\"y\",null).attr(\"dx\",null).attr(\"dy\",null),L.exit().remove();var O,z=f.mode+f.align;f._hasDelta&&(O=function(){var e=b(t,{tickformat:f.delta.valueformat},f._range);e.setScale(),u.calcTicks(e);var i=function(t){return u.tickText(e,t).text},a=function(t){var e=f.delta.relative?t.relativeDelta:t.delta;return e},o=function(t,e){return 0===t||\"number\"!=typeof t||isNaN(t)?\"-\":(t>0?f.delta.increasing.symbol:f.delta.decreasing.symbol)+e(t)},h=function(t){return t.delta>=0?f.delta.increasing.color:f.delta.decreasing.color};void 0===f._deltaLastValue&&(f._deltaLastValue=a(r[0]));var p=E.select(\"text.delta\");function g(){p.text(o(a(r[0]),i)).call(d.fill,h(r[0])).call(c.convertToTspans,t)}p.call(s.font,f.delta.font).call(d.fill,h({delta:f._deltaLastValue})),y(M)?p.transition().duration(M.duration).ease(M.easing).tween(\"text\",function(){var t=n.select(this),e=a(r[0]),s=f._deltaLastValue,l=P(f.delta.valueformat,i,s,e),c=n.interpolateNumber(s,e);return f._deltaLastValue=e,function(e){t.text(o(c(e),l)),t.call(d.fill,h({delta:c(e)}))}}).each(\"end\",function(){g(),S&&S()}).each(\"interrupt\",function(){g(),S&&S()}):g();return l=k(o(a(r[0]),i),f.delta.font,A,t),p}(),z+=f.delta.position+f.delta.font.size+f.delta.font.family+f.delta.valueformat,z+=f.delta.increasing.symbol+f.delta.decreasing.symbol,h=l);f._hasNumber&&(!function(){var e=b(t,{tickformat:f.number.valueformat},f._range);e.setScale(),u.calcTicks(e);var i=function(t){return u.tickText(e,t).text},a=f.number.suffix,l=f.number.prefix,h=E.select(\"text.number\");function p(){var e=\"number\"==typeof r[0].y?l+i(r[0].y)+a:\"-\";h.text(e).call(s.font,f.number.font).call(c.convertToTspans,t)}y(M)?h.transition().duration(M.duration).ease(M.easing).each(\"end\",function(){p(),S&&S()}).each(\"interrupt\",function(){p(),S&&S()}).attrTween(\"text\",function(){var t=n.select(this),e=n.interpolateNumber(r[0].lastY,r[0].y);f._lastValue=r[0].y;var o=P(f.number.valueformat,i,r[0].lastY,r[0].y);return function(r){t.text(l+o(e(r))+a)}}):p();o=k(l+i(r[0].y)+a,f.number.font,A,t)}(),z+=f.number.font.size+f.number.font.family+f.number.valueformat+f.number.suffix+f.number.prefix,h=o);if(f._hasDelta&&f._hasNumber){var I,D,R=[(o.left+o.right)/2,(o.top+o.bottom)/2],F=[(l.left+l.right)/2,(l.top+l.bottom)/2],B=.75*f.delta.font.size;\"left\"===f.delta.position&&(I=T(f,\"deltaPos\",0,-1*(o.width*v[f.align]+l.width*(1-v[f.align])+B),z,Math.min),D=R[1]-F[1],h={width:o.width+l.width+B,height:Math.max(o.height,l.height),left:l.left+I,right:o.right,top:Math.min(o.top,l.top+D),bottom:Math.max(o.bottom,l.bottom+D)}),\"right\"===f.delta.position&&(I=T(f,\"deltaPos\",0,o.width*(1-v[f.align])+l.width*v[f.align]+B,z,Math.max),D=R[1]-F[1],h={width:o.width+l.width+B,height:Math.max(o.height,l.height),left:o.left,right:l.right+I,top:Math.min(o.top,l.top+D),bottom:Math.max(o.bottom,l.bottom+D)}),\"bottom\"===f.delta.position&&(I=null,D=l.height,h={width:Math.max(o.width,l.width),height:o.height+l.height,left:Math.min(o.left,l.left),right:Math.max(o.right,l.right),top:o.bottom-o.height,bottom:o.bottom+l.height}),\"top\"===f.delta.position&&(I=null,D=o.top,h={width:Math.max(o.width,l.width),height:o.height+l.height,left:Math.min(o.left,l.left),right:Math.max(o.right,l.right),top:o.bottom-o.height-l.height,bottom:o.bottom}),O.attr({dx:I,dy:D})}(f._hasNumber||f._hasDelta)&&E.attr(\"transform\",function(){var t=a.numbersScaler(h);z+=t[2];var e,r=T(f,\"numbersScale\",1,t[0],z,Math.min);f._scaleNumbers||(r=1),e=f._isAngular?x-r*h.bottom:x-r*(h.top+h.bottom)/2,f._numbersTop=r*h.top+e;var n=h[w];\"center\"===w&&(n=(h.left+h.right)/2);var i=p-r*n;return _(i=T(f,\"numbersTranslate\",0,i,z,Math.max),e)+\" scale(\"+r+\")\"})}(t,L,e,{numbersX:h,numbersY:A,numbersScaler:M,transitionOpts:r,onComplete:f}),P&&(S={range:C.gauge.axis.range,color:C.gauge.bgcolor,line:{color:C.gauge.bordercolor,width:0},thickness:1},E={range:C.gauge.axis.range,color:\"rgba(0, 0, 0, 0)\",line:{color:C.gauge.bordercolor,width:C.gauge.borderwidth},thickness:1});var q=L.selectAll(\"g.angular\").data(O?e:[]);q.exit().remove();var H=L.selectAll(\"g.angularaxis\").data(O?e:[]);H.exit().remove(),O&&function(t,e,r,i){var s,l,c,h,f=r[0].trace,p=i.size,d=i.radius,g=i.innerRadius,v=i.gaugeBg,m=i.gaugeOutline,w=[p.l+p.w/2,p.t+p.h/2+d/2],k=i.gauge,T=i.layer,A=i.transitionOpts,M=i.onComplete,S=Math.PI/2;function E(t){var e=f.gauge.axis.range[0],r=f.gauge.axis.range[1],n=(t-e)/(r-e)*Math.PI-S;return n<-S?-S:n>S?S:n}function C(t){return n.svg.arc().innerRadius((g+d)/2-t/2*(d-g)).outerRadius((g+d)/2+t/2*(d-g)).startAngle(-S)}function L(t){t.attr(\"d\",function(t){return C(t.thickness).startAngle(E(t.range[0])).endAngle(E(t.range[1]))()})}k.enter().append(\"g\").classed(\"angular\",!0),k.attr(\"transform\",_(w[0],w[1])),T.enter().append(\"g\").classed(\"angularaxis\",!0).classed(\"crisp\",!0),T.selectAll(\"g.xangularaxistick,path,text\").remove(),(s=b(t,f.gauge.axis)).type=\"linear\",s.range=f.gauge.axis.range,s._id=\"xangularaxis\",s.setScale();var P=function(t){return(s.range[0]-t.x)/(s.range[1]-s.range[0])*Math.PI+Math.PI},O={},z=u.makeLabelFns(s,0).labelStandoff;O.xFn=function(t){var e=P(t);return Math.cos(e)*z},O.yFn=function(t){var e=P(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(z+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*o)},O.anchorFn=function(t){var e=P(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},O.heightFn=function(t,e,r){var n=P(t);return-.5*(1+Math.sin(n))*r};var I=function(t){return _(w[0]+d*Math.cos(t),w[1]-d*Math.sin(t))};c=function(t){return I(P(t))};if(l=u.calcTicks(s),h=u.getTickSigns(s)[2],s.visible){h=\"inside\"===s.ticks?-1:1;var D=(s.linewidth||1)/2;u.drawTicks(t,s,{vals:l,layer:T,path:\"M\"+h*D+\",0h\"+h*s.ticklen,transFn:function(t){var e=P(t);return I(e)+\"rotate(\"+-a(e)+\")\"}}),u.drawLabels(t,s,{vals:l,layer:T,transFn:c,labelFns:O})}var R=[v].concat(f.gauge.steps),F=k.selectAll(\"g.bg-arc\").data(R);F.enter().append(\"g\").classed(\"bg-arc\",!0).append(\"path\"),F.select(\"path\").call(L).call(x),F.exit().remove();var B=C(f.gauge.bar.thickness),N=k.selectAll(\"g.value-arc\").data([f.gauge.bar]);N.enter().append(\"g\").classed(\"value-arc\",!0).append(\"path\");var j=N.select(\"path\");y(A)?(j.transition().duration(A.duration).ease(A.easing).each(\"end\",function(){M&&M()}).each(\"interrupt\",function(){M&&M()}).attrTween(\"d\",(U=B,V=E(r[0].lastY),q=E(r[0].y),function(){var t=n.interpolate(V,q);return function(e){return U.endAngle(t(e))()}})),f._lastValue=r[0].y):j.attr(\"d\",\"number\"==typeof r[0].y?B.endAngle(E(r[0].y)):\"M0,0Z\");var U,V,q;j.call(x),N.exit().remove(),R=[];var H=f.gauge.threshold.value;H&&R.push({range:[H,H],color:f.gauge.threshold.color,line:{color:f.gauge.threshold.line.color,width:f.gauge.threshold.line.width},thickness:f.gauge.threshold.thickness});var G=k.selectAll(\"g.threshold-arc\").data(R);G.enter().append(\"g\").classed(\"threshold-arc\",!0).append(\"path\"),G.select(\"path\").call(L).call(x),G.exit().remove();var Y=k.selectAll(\"g.gauge-outline\").data([m]);Y.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"path\"),Y.select(\"path\").call(L).call(x),Y.exit().remove()}(t,0,e,{radius:B,innerRadius:N,gauge:q,layer:H,size:D,gaugeBg:S,gaugeOutline:E,transitionOpts:r,onComplete:f});var G=L.selectAll(\"g.bullet\").data(z?e:[]);G.exit().remove();var Y=L.selectAll(\"g.bulletaxis\").data(z?e:[]);Y.exit().remove(),z&&function(t,e,r,n){var i,a,o,s,c,h=r[0].trace,f=n.gauge,p=n.layer,g=n.gaugeBg,v=n.gaugeOutline,m=n.size,_=h.domain,w=n.transitionOpts,k=n.onComplete;f.enter().append(\"g\").classed(\"bullet\",!0),f.attr(\"transform\",\"translate(\"+m.l+\", \"+m.t+\")\"),p.enter().append(\"g\").classed(\"bulletaxis\",!0).classed(\"crisp\",!0),p.selectAll(\"g.xbulletaxistick,path,text\").remove();var T=m.h,A=h.gauge.bar.thickness*T,M=_.x[0],S=_.x[0]+(_.x[1]-_.x[0])*(h._hasNumber||h._hasDelta?1-l.bulletNumberDomainSize:1);(i=b(t,h.gauge.axis))._id=\"xbulletaxis\",i.domain=[M,S],i.setScale(),a=u.calcTicks(i),o=u.makeTransFn(i),s=u.getTickSigns(i)[2],c=m.t+m.h,i.visible&&(u.drawTicks(t,i,{vals:\"inside\"===i.ticks?u.clipEnds(i,a):a,layer:p,path:u.makeTickPath(i,c,s),transFn:o}),u.drawLabels(t,i,{vals:a,layer:p,transFn:o,labelFns:u.makeLabelFns(i,c)}));function E(t){t.attr(\"width\",function(t){return Math.max(0,i.c2p(t.range[1])-i.c2p(t.range[0]))}).attr(\"x\",function(t){return i.c2p(t.range[0])}).attr(\"y\",function(t){return.5*(1-t.thickness)*T}).attr(\"height\",function(t){return t.thickness*T})}var C=[g].concat(h.gauge.steps),L=f.selectAll(\"g.bg-bullet\").data(C);L.enter().append(\"g\").classed(\"bg-bullet\",!0).append(\"rect\"),L.select(\"rect\").call(E).call(x),L.exit().remove();var P=f.selectAll(\"g.value-bullet\").data([h.gauge.bar]);P.enter().append(\"g\").classed(\"value-bullet\",!0).append(\"rect\"),P.select(\"rect\").attr(\"height\",A).attr(\"y\",(T-A)/2).call(x),y(w)?P.select(\"rect\").transition().duration(w.duration).ease(w.easing).each(\"end\",function(){k&&k()}).each(\"interrupt\",function(){k&&k()}).attr(\"width\",Math.max(0,i.c2p(Math.min(h.gauge.axis.range[1],r[0].y)))):P.select(\"rect\").attr(\"width\",\"number\"==typeof r[0].y?Math.max(0,i.c2p(Math.min(h.gauge.axis.range[1],r[0].y))):0);P.exit().remove();var O=r.filter(function(){return h.gauge.threshold.value}),z=f.selectAll(\"g.threshold-bullet\").data(O);z.enter().append(\"g\").classed(\"threshold-bullet\",!0).append(\"line\"),z.select(\"line\").attr(\"x1\",i.c2p(h.gauge.threshold.value)).attr(\"x2\",i.c2p(h.gauge.threshold.value)).attr(\"y1\",(1-h.gauge.threshold.thickness)/2*T).attr(\"y2\",(1-(1-h.gauge.threshold.thickness)/2)*T).call(d.stroke,h.gauge.threshold.line.color).style(\"stroke-width\",h.gauge.threshold.line.width),z.exit().remove();var I=f.selectAll(\"g.gauge-outline\").data([v]);I.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"rect\"),I.select(\"rect\").call(E).call(x),I.exit().remove()}(t,0,e,{gauge:G,layer:Y,size:D,gaugeBg:S,gaugeOutline:E,transitionOpts:r,onComplete:f});var W=L.selectAll(\"text.title\").data(e);W.exit().remove(),W.enter().append(\"text\").classed(\"title\",!0),W.attr(\"text-anchor\",function(){return z?g.right:g[C.title.align]}).text(C.title.text).call(s.font,C.title.font).call(c.convertToTspans,t),W.attr(\"transform\",function(){var t,e=D.l+D.w*v[C.title.align],r=l.titlePadding,n=s.bBox(W.node());if(P){if(O)if(C.gauge.axis.visible)t=s.bBox(H.node()).top-r-n.bottom;else t=D.t+D.h/2-B/2-n.bottom-r;z&&(t=A-(n.top+n.bottom)/2,e=D.l-l.bulletPadding*D.w)}else t=C._numbersTop-r-n.bottom;return _(e,t)})})}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_defaults\":769,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/cartesian/position_defaults\":782,\"./constants\":1044,d3:163}],1048:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;var c=e.exports=l(s({x:{valType:\"data_array\"},y:{valType:\"data_array\"},z:{valType:\"data_array\"},value:{valType:\"data_array\"},isomin:{valType:\"number\"},isomax:{valType:\"number\"},surface:{show:{valType:\"boolean\",dflt:!0},count:{valType:\"integer\",dflt:2,min:1},fill:{valType:\"number\",min:0,max:1,dflt:1},pattern:{valType:\"flaglist\",flags:[\"A\",\"B\",\"C\",\"D\",\"E\"],extras:[\"all\",\"odd\",\"even\"],dflt:\"all\"}},spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:.15}},slices:{x:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}}},caps:{x:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}}},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:i()},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:a.opacity,lightposition:a.lightposition,lighting:a.lighting,flatshading:a.flatshading,contour:a.contour,hoverinfo:s({},o.hoverinfo)}),\"calc\",\"nested\");c.flatshading.dflt=!0,c.lighting.facenormalsepsilon.dflt=0,c.x.editType=c.y.editType=c.z.editType=c.value.editType=\"calc+clearAxisTypes\",c.transforms=void 0},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../mesh3d/attributes\":1053}],1049:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e._len=Math.min(e.x.length,e.y.length,e.z.length,e.value.length);for(var r=1/0,i=-1/0,a=e.value.length,o=0;o<a;o++){var s=e.value[o];r=Math.min(r,s),i=Math.max(i,s)}e._minValues=r,e._maxValues=i,e._vMin=void 0===e.isomin||null===e.isomin?r:e.isomin,e._vMax=void 0===e.isomax||null===e.isomin?i:e.isomax,n(t,e,{vals:[e._vMin,e._vMax],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],1050:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib\"),a=t(\"../../lib/gl_format_color\").parseColorScale,o=t(\"../../lib/str2rgbarray\"),s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\");function c(t){return i.distinctVals(t).vals}var u=function(t,e){for(var r=e.length-1;r>0;r--){var n=Math.min(e[r],e[r-1]),i=Math.max(e[r],e[r-1]);if(i>n&&n<t&&t<=i)return{id:r,distRatio:(i-t)/(i-n)}}return{id:0,distRatio:0}};function h(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var f=h.prototype;function p(t){t._i=[],t._j=[],t._k=[];var e,r,n=t.surface.show,i=t.spaceframe.show,a=t.surface.fill,o=t.spaceframe.fill,s=!1,l=!1,h=0,f=c(t.x.slice(0,t._len)),p=c(t.y.slice(0,t._len)),d=c(t.z.slice(0,t._len)),g=f.length,v=p.length,m=d.length;function y(t,e,r){return r+m*e+m*v*t}var x,b,_,w,k,T=t._minValues,A=t._maxValues,M=t._vMin,S=t._vMax;function E(t,e,n){for(var i=w.length,a=r;a<i;a++)if(t===x[a]&&e===b[a]&&n===_[a])return a;return-1}function C(){r=e}function L(){x=[],b=[],_=[],w=[],e=0,C()}function P(t,r,n,i){return x.push(t),b.push(r),_.push(n),w.push(i),++e-1}function O(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=t[i]*(1-r)+r*e[i];return n}function z(t){k=t}function I(t,e){return\"all\"===t||null===t||t.indexOf(e)>-1}function D(t,e){return null===t?e:t}function R(e,r,n){C();var i,a,o,s=[r],l=[n];if(k>=1)s=[r],l=[n];else if(k>0){var c=function(t,e){var r=t[0],n=t[1],i=t[2],a=function(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=(t[i]+e[i]+r[i])/3;return n}(r,n,i),o=Math.sqrt(1-k),s=O(a,r,o),l=O(a,n,o),c=O(a,i,o),u=e[0],h=e[1],f=e[2];return{xyzv:[[r,n,l],[l,s,r],[n,i,c],[c,l,n],[i,r,s],[s,c,i]],abc:[[u,h,-1],[-1,-1,u],[h,f,-1],[-1,-1,h],[f,u,-1],[-1,-1,f]]}}(r,n);s=c.xyzv,l=c.abc}for(var u=0;u<s.length;u++){r=s[u],n=l[u];for(var f=[],p=0;p<3;p++){var d=r[p][0],g=r[p][1],v=r[p][2],m=r[p][3],y=n[p]>-1?n[p]:E(d,g,v);f[p]=y>-1?y:P(d,g,v,D(e,m))}i=f[0],a=f[1],o=f[2],t._i.push(i),t._j.push(a),t._k.push(o),++h}}function F(t,e,r,n){var i=t[3];i<r&&(i=r),i>n&&(i=n);for(var a=(t[3]-i)/(t[3]-e[3]+1e-9),o=[],s=0;s<4;s++)o[s]=(1-a)*t[s]+a*e[s];return o}function B(t,e,r){return t>=e&&t<=r}function N(t){var e=.001*(S-M);return t>=M-e&&t<=S+e}function j(e){for(var r=[],n=0;n<4;n++){var i=e[n];r.push([t.x[i],t.y[i],t.z[i],t.value[i]])}return r}var U=3;function V(t,e,r,n,i,a){a||(a=1),r=[-1,-1,-1];var o=!1,s=[B(e[0][3],n,i),B(e[1][3],n,i),B(e[2][3],n,i)];if(!s[0]&&!s[1]&&!s[2])return!1;var l=function(t,e,r){return N(e[0][3])&&N(e[1][3])&&N(e[2][3])?(R(t,e,r),!0):a<U&&V(t,e,r,M,S,++a)};if(s[0]&&s[1]&&s[2])return l(t,e,r)||o;var c=!1;return[[0,1,2],[2,0,1],[1,2,0]].forEach(function(a){if(s[a[0]]&&s[a[1]]&&!s[a[2]]){var u=e[a[0]],h=e[a[1]],f=e[a[2]],p=F(f,u,n,i),d=F(f,h,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,o=l(t,[u,h,d],[r[a[0]],r[a[1]],-1])||o,c=!0}}),c?o:([[0,1,2],[1,2,0],[2,0,1]].forEach(function(a){if(s[a[0]]&&!s[a[1]]&&!s[a[2]]){var u=e[a[0]],h=e[a[1]],f=e[a[2]],p=F(h,u,n,i),d=F(f,u,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,c=!0}}),o)}function q(t,e,r,n){var i=!1,a=j(e),o=[B(a[0][3],r,n),B(a[1][3],r,n),B(a[2][3],r,n),B(a[3][3],r,n)];if(!(o[0]||o[1]||o[2]||o[3]))return i;if(o[0]&&o[1]&&o[2]&&o[3])return l&&(i=function(t,e,r){var n=function(n,i,a){R(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(3,0,1),n(2,3,0),n(1,2,3)}(t,a,e)||i),i;var s=!1;return[[0,1,2,3],[3,0,1,2],[2,3,0,1],[1,2,3,0]].forEach(function(c){if(o[c[0]]&&o[c[1]]&&o[c[2]]&&!o[c[3]]){var u=a[c[0]],h=a[c[1]],f=a[c[2]],p=a[c[3]];if(l)i=R(t,[u,h,f],[e[c[0]],e[c[1]],e[c[2]]])||i;else{var d=F(p,u,r,n),g=F(p,h,r,n),v=F(p,f,r,n);i=R(null,[d,g,v],[-1,-1,-1])||i}s=!0}}),s?i:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2],[0,2,3,1],[1,3,2,0]].forEach(function(c){if(o[c[0]]&&o[c[1]]&&!o[c[2]]&&!o[c[3]]){var u=a[c[0]],h=a[c[1]],f=a[c[2]],p=a[c[3]],d=F(f,u,r,n),g=F(f,h,r,n),v=F(p,h,r,n),m=F(p,u,r,n);l?(i=R(t,[u,m,d],[e[c[0]],-1,-1])||i,i=R(t,[h,g,v],[e[c[1]],-1,-1])||i):i=function(t,e,r){var n=function(n,i,a){R(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(2,3,0)}(null,[d,g,v,m],[-1,-1,-1,-1])||i,s=!0}}),s?i:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2]].forEach(function(c){if(o[c[0]]&&!o[c[1]]&&!o[c[2]]&&!o[c[3]]){var u=a[c[0]],h=a[c[1]],f=a[c[2]],p=a[c[3]],d=F(h,u,r,n),g=F(f,u,r,n),v=F(p,u,r,n);l?(i=R(t,[u,d,g],[e[c[0]],-1,-1])||i,i=R(t,[u,g,v],[e[c[0]],-1,-1])||i,i=R(t,[u,v,d],[e[c[0]],-1,-1])||i):i=R(null,[d,g,v],[-1,-1,-1])||i,s=!0}}),i))}function H(t,e,r,n,i,a,o,c,u,h,f){var p=!1;return s&&(I(t,\"A\")&&(p=q(null,[e,r,n,a],h,f)||p),I(t,\"B\")&&(p=q(null,[r,n,i,u],h,f)||p),I(t,\"C\")&&(p=q(null,[r,a,o,u],h,f)||p),I(t,\"D\")&&(p=q(null,[n,a,c,u],h,f)||p),I(t,\"E\")&&(p=q(null,[r,n,a,u],h,f)||p)),l&&(p=q(t,[r,n,a,u],h,f)||p),p}function G(t,e,r,n,i,a,o,s){return[!0===s[0]||V(t,j([e,r,n]),[e,r,n],a,o),!0===s[1]||V(t,j([n,i,e]),[n,i,e],a,o)]}function Y(t,e,r,n,i,a,o,s,l){return s?G(t,e,r,i,n,a,o,l):G(t,r,i,n,e,a,o,l)}function W(t,e,r,n,i,a,o){var s,l,c,u,h=!1,f=function(){h=V(t,[s,l,c],[-1,-1,-1],i,a)||h,h=V(t,[c,u,s],[-1,-1,-1],i,a)||h},p=o[0],d=o[1],g=o[2];return p&&(s=O(j([y(e,r-0,n-0)])[0],j([y(e-1,r-0,n-0)])[0],p),l=O(j([y(e,r-0,n-1)])[0],j([y(e-1,r-0,n-1)])[0],p),c=O(j([y(e,r-1,n-1)])[0],j([y(e-1,r-1,n-1)])[0],p),u=O(j([y(e,r-1,n-0)])[0],j([y(e-1,r-1,n-0)])[0],p),f()),d&&(s=O(j([y(e-0,r,n-0)])[0],j([y(e-0,r-1,n-0)])[0],d),l=O(j([y(e-0,r,n-1)])[0],j([y(e-0,r-1,n-1)])[0],d),c=O(j([y(e-1,r,n-1)])[0],j([y(e-1,r-1,n-1)])[0],d),u=O(j([y(e-1,r,n-0)])[0],j([y(e-1,r-1,n-0)])[0],d),f()),g&&(s=O(j([y(e-0,r-0,n)])[0],j([y(e-0,r-0,n-1)])[0],g),l=O(j([y(e-0,r-1,n)])[0],j([y(e-0,r-1,n-1)])[0],g),c=O(j([y(e-1,r-1,n)])[0],j([y(e-1,r-1,n-1)])[0],g),u=O(j([y(e-1,r-0,n)])[0],j([y(e-1,r-0,n-1)])[0],g),f()),h}function X(t,e,r,n,i,a,o,l,c,u,h,f){var p=t;return f?(s&&\"even\"===t&&(p=null),H(p,e,r,n,i,a,o,l,c,u,h)):(s&&\"odd\"===t&&(p=null),H(p,c,l,o,a,i,n,r,e,u,h))}function Z(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<m;c++)for(var u=1;u<v;u++)a.push(Y(t,y(l,u-1,c-1),y(l,u-1,c),y(l,u,c-1),y(l,u,c),r,n,(l+u+c)%2,i&&i[o]?i[o]:[])),o++;return a}function J(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<g;c++)for(var u=1;u<m;u++)a.push(Y(t,y(c-1,l,u-1),y(c,l,u-1),y(c-1,l,u),y(c,l,u),r,n,(c+l+u)%2,i&&i[o]?i[o]:[])),o++;return a}function K(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<v;c++)for(var u=1;u<g;u++)a.push(Y(t,y(u-1,c-1,l),y(u-1,c,l),y(u,c-1,l),y(u,c,l),r,n,(u+c+l)%2,i&&i[o]?i[o]:[])),o++;return a}function $(t,e,r){for(var n=1;n<m;n++)for(var i=1;i<v;i++)for(var a=1;a<g;a++)X(t,y(a-1,i-1,n-1),y(a-1,i-1,n),y(a-1,i,n-1),y(a-1,i,n),y(a,i-1,n-1),y(a,i-1,n),y(a,i,n-1),y(a,i,n),e,r,(a+i+n)%2)}function Q(t,e,r){s=!0,$(t,e,r),s=!1}function tt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<m;u++)for(var h=1;h<v;h++)o.push(W(t,c,h,u,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function et(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<g;u++)for(var h=1;h<m;h++)o.push(W(t,u,c,h,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function rt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<v;u++)for(var h=1;h<g;h++)o.push(W(t,h,u,c,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function nt(t,e){for(var r=[],n=t;n<e;n++)r.push(n);return r}return function(){if(L(),function(){for(var e=0;e<g;e++)for(var r=0;r<v;r++)for(var n=0;n<m;n++){var i=y(e,r,n);P(t.x[i],t.y[i],t.z[i],t.value[i])}}(),i&&o&&(z(o),l=!0,$(null,M,S),l=!1),n&&a){z(a);for(var e=t.surface.pattern,r=t.surface.count,s=0;s<r;s++){var c=1===r?.5:s/(r-1),k=(1-c)*M+c*S,E=Math.abs(k-T)>Math.abs(k-A)?[T,k]:[k,A];Q(e,E[0],E[1])}}var C=[[Math.min(M,A),Math.max(M,A)],[Math.min(T,S),Math.max(T,S)]];[\"x\",\"y\",\"z\"].forEach(function(e){for(var r=[],n=0;n<C.length;n++){var i=0,a=C[n][0],o=C[n][1],s=t.slices[e];if(s.show&&s.fill){z(s.fill);var l=[],c=[],h=[];if(s.locations.length)for(var y=0;y<s.locations.length;y++){var x=u(s.locations[y],\"x\"===e?f:\"y\"===e?p:d);0===x.distRatio?l.push(x.id):x.id>0&&(c.push(x.id),\"x\"===e?h.push([x.distRatio,0,0]):\"y\"===e?h.push([0,x.distRatio,0]):h.push([0,0,x.distRatio]))}else l=nt(1,\"x\"===e?g-1:\"y\"===e?v-1:m-1);c.length>0&&(r[i]=\"x\"===e?tt(null,c,a,o,h,r[i]):\"y\"===e?et(null,c,a,o,h,r[i]):rt(null,c,a,o,h,r[i]),i++),l.length>0&&(r[i]=\"x\"===e?Z(null,l,a,o,r[i]):\"y\"===e?J(null,l,a,o,r[i]):K(null,l,a,o,r[i]),i++)}var b=t.caps[e];b.show&&b.fill&&(z(b.fill),r[i]=\"x\"===e?Z(null,[0,g-1],a,o,r[i]):\"y\"===e?J(null,[0,v-1],a,o,r[i]):K(null,[0,m-1],a,o,r[i]),i++)}}),0===h&&L(),t._x=x,t._y=b,t._z=_,t._intensity=w,t._Xs=f,t._Ys=p,t._Zs=d}(),t}f.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._x[e],n=this.data._y[e],i=this.data._z[e],a=this.data._Ys.length,o=this.data._Zs.length,s=u(r,this.data._Xs).id,l=u(n,this.data._Ys).id,c=u(i,this.data._Zs).id,h=t.index=c+o*l+o*a*s;t.traceCoordinate=[this.data._x[h],this.data._y[h],this.data._z[h],this.data.value[h]];var f=this.data.hovertext||this.data.text;return Array.isArray(f)&&void 0!==f[h]?t.textLabel=f[h]:f&&(t.textLabel=f),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map(function(e){return t.d2l(e,0,n)*r})}this.data=p(t);var i={positions:l(n(r.xaxis,t._x,e.dataScale[0],t.xcalendar),n(r.yaxis,t._y,e.dataScale[1],t.ycalendar),n(r.zaxis,t._z,e.dataScale[2],t.zcalendar)),cells:l(t._i,t._j,t._k),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:o(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},c=s(t);i.vertexIntensity=t._intensity,i.vertexIntensityBounds=[c.min,c.max],i.colormap=a(t),this.mesh.update(i)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports={findNearestOnAxis:u,generateIsoMeshes:p,createIsosurfaceTrace:function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new h(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../../plots/gl3d/zip3\":818,\"gl-mesh3d\":280}],1051:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"../../components/colorscale/defaults\");function s(t,e,r,n,a){var s=a(\"isomin\"),l=a(\"isomax\");null!=l&&null!=s&&s>l&&(e.isomin=null,e.isomax=null);var c=a(\"x\"),u=a(\"y\"),h=a(\"z\"),f=a(\"value\");c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length?(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],n),[\"x\",\"y\",\"z\"].forEach(function(t){var e=\"caps.\"+t;a(e+\".show\")&&a(e+\".fill\");var r=\"slices.\"+t;a(r+\".show\")&&(a(r+\".fill\"),a(r+\".locations\"))}),a(\"spaceframe.show\")&&a(\"spaceframe.fill\"),a(\"surface.show\")&&(a(\"surface.count\"),a(\"surface.fill\"),a(\"surface.pattern\")),a(\"contour.show\")&&(a(\"contour.color\"),a(\"contour.width\")),[\"text\",\"hovertext\",\"hovertemplate\",\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"flatshading\",\"opacity\"].forEach(function(t){a(t)}),o(t,e,n,a,{prefix:\"\",cLetter:\"c\"}),e._length=null):e.visible=!1}e.exports={supplyDefaults:function(t,e,r,i){s(t,e,0,i,function(r,i){return n.coerce(t,e,a,r,i)})},supplyIsoDefaults:s}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../../registry\":847,\"./attributes\":1048}],1052:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\").createIsosurfaceTrace,moduleType:\"trace\",name:\"isosurface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1048,\"./calc\":1049,\"./convert\":1050,\"./defaults\":1051}],1053:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../surface/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},i:{valType:\"data_array\",editType:\"calc\"},j:{valType:\"data_array\",editType:\"calc\"},k:{valType:\"data_array\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:i({editType:\"calc\"}),delaunayaxis:{valType:\"enumerated\",values:[\"x\",\"y\",\"z\"],dflt:\"z\",editType:\"calc\"},alphahull:{valType:\"number\",dflt:-1,editType:\"calc\"},intensity:{valType:\"data_array\",editType:\"calc\"},color:{valType:\"color\",editType:\"calc\"},vertexcolor:{valType:\"data_array\",editType:\"calc\"},facecolor:{valType:\"data_array\",editType:\"calc\"},transforms:void 0},n(\"\",{colorAttr:\"`intensity`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:a.opacity,flatshading:{valType:\"boolean\",dflt:!1,editType:\"calc\"},contour:{show:s({},a.contours.x.show,{}),color:a.contours.x.color,width:a.contours.x.width,editType:\"calc\"},lightposition:{x:s({},a.lightposition.x,{dflt:1e5}),y:s({},a.lightposition.y,{dflt:1e5}),z:s({},a.lightposition.z,{dflt:0}),editType:\"calc\"},lighting:s({vertexnormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-12,editType:\"calc\"},facenormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-6,editType:\"calc\"},editType:\"calc\"},a.lighting),hoverinfo:s({},o.hoverinfo,{editType:\"calc\"})})},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../surface/attributes\":1224}],1054:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.intensity&&n(t,e,{vals:e.intensity,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],1055:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"delaunay-triangulate\"),a=t(\"alpha-shape\"),o=t(\"convex-hull\"),s=t(\"../../lib/gl_format_color\").parseColorScale,l=t(\"../../lib/str2rgbarray\"),c=t(\"../../components/colorscale\").extractOpts,u=t(\"../../plots/gl3d/zip3\");function h(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.color=\"#fff\",this.data=null,this.showContour=!1}var f=h.prototype;function p(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=l(t[n]);return e}function d(t,e,r,n){for(var i=[],a=e.length,o=0;o<a;o++)i[o]=t.d2l(e[o],0,n)*r;return i}function g(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=Math.round(t[n]);return e}function v(t,e){for(var r=t.length,n=0;n<r;n++)if(t[n]<=-.5||t[n]>=e-.5)return!1;return!0}f.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index;t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]];var r=this.data.hovertext||this.data.text;return Array.isArray(r)&&void 0!==r[e]?t.textLabel=r[e]:r&&(t.textLabel=r),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;this.data=t;var n,h=t.x.length,f=u(d(r.xaxis,t.x,e.dataScale[0],t.xcalendar),d(r.yaxis,t.y,e.dataScale[1],t.ycalendar),d(r.zaxis,t.z,e.dataScale[2],t.zcalendar));if(t.i&&t.j&&t.k){if(t.i.length!==t.j.length||t.j.length!==t.k.length||!v(t.i,h)||!v(t.j,h)||!v(t.k,h))return;n=u(g(t.i),g(t.j),g(t.k))}else n=0===t.alphahull?o(f):t.alphahull>0?a(t.alphahull,f):function(t,e){for(var r=[\"x\",\"y\",\"z\"].indexOf(t),n=[],a=e.length,o=0;o<a;o++)n[o]=[e[o][(r+1)%3],e[o][(r+2)%3]];return i(n)}(t.delaunayaxis,f);var m={positions:f,cells:n,lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:l(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading};if(t.intensity){var y=c(t);this.color=\"#fff\",m.vertexIntensity=t.intensity,m.vertexIntensityBounds=[y.min,y.max],m.colormap=s(t)}else t.vertexcolor?(this.color=t.vertexcolor[0],m.vertexColors=p(t.vertexcolor)):t.facecolor?(this.color=t.facecolor[0],m.cellColors=p(t.facecolor)):(this.color=t.color,m.meshColor=l(t.color));this.mesh.update(m)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new h(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":605,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../../plots/gl3d/zip3\":818,\"alpha-shape\":64,\"convex-hull\":130,\"delaunay-triangulate\":165,\"gl-mesh3d\":280}],1056:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,n){return i.coerce(t,e,o,r,n)}function c(t){var e=t.map(function(t){var e=l(t);return e&&i.isArrayOrTypedArray(e)?e:null});return e.every(function(t){return t&&t.length===e[0].length})&&e}c([\"x\",\"y\",\"z\"])?(c([\"i\",\"j\",\"k\"]),(!e.i||e.j&&e.k)&&(!e.j||e.k&&e.i)&&(!e.k||e.i&&e.j)?(n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],s),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"contour.show\",\"contour.color\",\"contour.width\",\"colorscale\",\"reversescale\",\"flatshading\",\"alphahull\",\"delaunayaxis\",\"opacity\"].forEach(function(t){l(t)}),\"intensity\"in t?(l(\"intensity\"),a(t,e,s,l,{prefix:\"\",cLetter:\"c\"})):(e.showscale=!1,\"facecolor\"in t?l(\"facecolor\"):\"vertexcolor\"in t?l(\"vertexcolor\"):l(\"color\",r)),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),e._length=null):e.visible=!1):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../../registry\":847,\"./attributes\":1053}],1057:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"mesh3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1053,\"./calc\":1054,\"./convert\":1055,\"./defaults\":1056}],1058:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../scatter/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../components/fx/attributes\"),s=t(\"../../constants/delta.js\"),l=s.INCREASING.COLOR,c=s.DECREASING.COLOR,u=i.line;function h(t){return{line:{color:n({},u.color,{dflt:t}),width:u.width,dash:a,editType:\"style\"},editType:\"style\"}}e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},open:{valType:\"data_array\",editType:\"calc\"},high:{valType:\"data_array\",editType:\"calc\"},low:{valType:\"data_array\",editType:\"calc\"},close:{valType:\"data_array\",editType:\"calc\"},line:{width:n({},u.width,{}),dash:n({},a,{}),editType:\"style\"},increasing:h(l),decreasing:h(c),text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},tickwidth:{valType:\"number\",min:0,max:.5,dflt:.3,editType:\"calc\"},hoverlabel:n({},o.hoverlabel,{split:{valType:\"boolean\",dflt:!1,editType:\"style\"}})}},{\"../../components/drawing/attributes\":613,\"../../components/fx/attributes\":623,\"../../constants/delta.js\":689,\"../../lib\":719,\"../scatter/attributes\":1112}],1059:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=n._,a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/numerical\").BADNUM;function s(t,e,r,n){return{o:t,h:e,l:r,c:n}}function l(t,e,r,s,l){for(var c=s.makeCalcdata(e,\"open\"),u=s.makeCalcdata(e,\"high\"),h=s.makeCalcdata(e,\"low\"),f=s.makeCalcdata(e,\"close\"),p=Array.isArray(e.text),d=Array.isArray(e.hovertext),g=!0,v=null,m=[],y=0;y<r.length;y++){var x=r[y],b=c[y],_=u[y],w=h[y],k=f[y];if(x!==o&&b!==o&&_!==o&&w!==o&&k!==o){k===b?null!==v&&k!==v&&(g=k>v):g=k>b,v=k;var T=l(b,_,w,k);T.pos=x,T.yc=(b+k)/2,T.i=y,T.dir=g?\"increasing\":\"decreasing\",T.x=T.pos,T.y=[w,_],p&&(T.tx=e.text[y]),d&&(T.htx=e.hovertext[y]),m.push(T)}else m.push({pos:x,empty:!0})}return e._extremes[s._id]=a.findExtremes(s,n.concat(h,u),{padded:!0}),m.length&&(m[0].t={labels:{open:i(t,\"open:\")+\" \",high:i(t,\"high:\")+\" \",low:i(t,\"low:\")+\" \",close:i(t,\"close:\")+\" \"}}),m}e.exports={calc:function(t,e){var r=a.getFromId(t,e.xaxis),i=a.getFromId(t,e.yaxis),o=function(t,e,r){var i=r._minDiff;if(!i){var a,o=t._fullData,s=[];for(i=1/0,a=0;a<o.length;a++){var l=o[a];if(\"ohlc\"===l.type&&!0===l.visible&&l.xaxis===e._id){s.push(l);var c=e.makeCalcdata(l,\"x\");l._xcalc=c;var u=n.distinctVals(c).minDiff;u&&isFinite(u)&&(i=Math.min(i,u))}}for(i===1/0&&(i=1),a=0;a<s.length;a++)s[a]._minDiff=i}return i*r.tickwidth}(t,r,e),c=e._minDiff;e._minDiff=null;var u=e._xcalc;e._xcalc=null;var h=l(t,e,u,i,s);return e._extremes[r._id]=a.findExtremes(r,u,{vpad:c/2}),h.length?(n.extendFlat(h[0].t,{wHover:c/2,tickLen:o}),h):[{t:{empty:!0}}]},calcCommon:l}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],1060:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./ohlc_defaults\"),a=t(\"./attributes\");function o(t,e,r,n){r(n+\".line.color\"),r(n+\".line.width\",e.line.width),r(n+\".line.dash\",e.line.dash)}e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,a,r,i)}i(t,e,l,s)?(l(\"line.width\"),l(\"line.dash\"),o(t,e,l,\"increasing\"),o(t,e,l,\"decreasing\"),l(\"text\"),l(\"hovertext\"),l(\"tickwidth\"),s._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../lib\":719,\"./attributes\":1058,\"./ohlc_defaults\":1063}],1061:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\").fillText,l=t(\"../../constants/delta.js\"),c={increasing:l.INCREASING.SYMBOL,decreasing:l.DECREASING.SYMBOL};function u(t,e,r,n){var i,s,l=t.cd,c=t.xa,u=l[0].trace,h=l[0].t,f=u.type,p=\"ohlc\"===f?\"l\":\"min\",d=\"ohlc\"===f?\"h\":\"max\",g=h.bPos||0,v=function(t){return t.pos+g-e},m=h.bdPos||h.tickLen,y=h.wHover,x=Math.min(1,m/Math.abs(c.r2c(c.range[1])-c.r2c(c.range[0])));function b(t){var e=v(t);return a.inbox(e-y,e+y,i)}function _(t){var e=t[p],n=t[d];return e===n||a.inbox(e-r,n-r,i)}function w(t){return(b(t)+_(t))/2}i=t.maxHoverDistance-x,s=t.maxSpikeDistance-x;var k=a.getDistanceFunction(n,b,_,w);if(a.getClosest(l,k,t),!1===t.index)return null;var T=l[t.index];if(T.empty)return null;var A=u[T.dir],M=A.line.color;return o.opacity(M)&&A.line.width?t.color=M:t.color=A.fillcolor,t.x0=c.c2p(T.pos+g-m,!0),t.x1=c.c2p(T.pos+g+m,!0),t.xLabelVal=T.pos,t.spikeDistance=w(T)*s/i,t.xSpike=c.c2p(T.pos,!0),t}function h(t,e,r,a){var o=t.cd,s=t.ya,l=o[0].trace,c=o[0].t,h=[],f=u(t,e,r,a);if(!f)return[];var p=o[f.index].hi||l.hoverinfo,d=p.split(\"+\");if(!(\"all\"===p||-1!==d.indexOf(\"y\")))return[];for(var g=[\"high\",\"open\",\"close\",\"low\"],v={},m=0;m<g.length;m++){var y,x=g[m],b=l[x][f.index],_=s.c2p(b,!0);b in v?(y=v[b]).yLabel+=\"<br>\"+c.labels[x]+n.hoverLabelText(s,b):((y=i.extendFlat({},f)).y0=y.y1=_,y.yLabelVal=b,y.yLabel=c.labels[x]+n.hoverLabelText(s,b),y.name=\"\",h.push(y),v[b]=y)}return h}function f(t,e,r,i){var a=t.cd,o=t.ya,l=a[0].trace,h=a[0].t,f=u(t,e,r,i);if(!f)return[];var p=a[f.index],d=f.index=p.i,g=p.dir;function v(t){return h.labels[t]+n.hoverLabelText(o,l[t][d])}var m=p.hi||l.hoverinfo,y=m.split(\"+\"),x=\"all\"===m,b=x||-1!==y.indexOf(\"y\"),_=x||-1!==y.indexOf(\"text\"),w=b?[v(\"open\"),v(\"high\"),v(\"low\"),v(\"close\")+\"  \"+c[g]]:[];return _&&s(p,l,w),f.extraText=w.join(\"<br>\"),f.y0=f.y1=o.c2p(p.yc,!0),[f]}e.exports={hoverPoints:function(t,e,r,n){return t.cd[0].trace.hoverlabel.split?h(t,e,r,n):f(t,e,r,n)},hoverSplit:h,hoverOnPoints:f}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../constants/delta.js\":689,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],1062:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"ohlc\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\"],meta:{},attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\").calc,plot:t(\"./plot\"),style:t(\"./style\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\")}},{\"../../plots/cartesian\":778,\"./attributes\":1058,\"./calc\":1059,\"./defaults\":1060,\"./hover\":1061,\"./plot\":1064,\"./select\":1065,\"./style\":1066}],1063:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"open\"),l=r(\"high\"),c=r(\"low\"),u=r(\"close\");if(r(\"hoverlabel.split\"),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\"],a),s&&l&&c&&u){var h=Math.min(s.length,l.length,c.length,u.length);return o&&(h=Math.min(h,i.minRowLength(o))),e._length=h,h}}},{\"../../lib\":719,\"../../registry\":847}],1064:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=e.xaxis,s=e.yaxis;i.makeTraceGroups(a,r,\"trace ohlc\").each(function(t){var e=n.select(this),r=t[0],a=r.t;if(!0!==r.trace.visible||a.empty)e.remove();else{var l=a.tickLen,c=e.selectAll(\"path\").data(i.identity);c.enter().append(\"path\"),c.exit().remove(),c.attr(\"d\",function(t){if(t.empty)return\"M0,0Z\";var e=o.c2p(t.pos,!0),r=o.c2p(t.pos-l,!0),n=o.c2p(t.pos+l,!0);return\"M\"+r+\",\"+s.c2p(t.o,!0)+\"H\"+e+\"M\"+e+\",\"+s.c2p(t.h,!0)+\"V\"+s.c2p(t.l,!0)+\"M\"+n+\",\"+s.c2p(t.c,!0)+\"H\"+e})}})}},{\"../../lib\":719,d3:163}],1065:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n=t.cd,i=t.xaxis,a=t.yaxis,o=[],s=n[0].t.bPos||0;if(!1===e)for(r=0;r<n.length;r++)n[r].selected=0;else for(r=0;r<n.length;r++){var l=n[r];e.contains([i.c2p(l.pos+s),a.c2p(l.yc)],null,l.i,t)?(o.push({pointNumber:l.i,x:i.c2d(l.pos),y:a.c2d(l.yc)}),l.selected=1):l.selected=0}return o}},{}],1066:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\");e.exports=function(t,e,r){var o=r||n.select(t).selectAll(\"g.ohlclayer\").selectAll(\"g.trace\");o.style(\"opacity\",function(t){return t[0].trace.opacity}),o.each(function(t){var e=t[0].trace;n.select(this).selectAll(\"path\").each(function(t){if(!t.empty){var r=e[t.dir].line;n.select(this).style(\"fill\",\"none\").call(a.stroke,r.color).call(i.dashLine,r.dash,r.width).style(\"opacity\",e.selectedpoints&&!t.selected?.3:1)}})})}},{\"../../components/color\":593,\"../../components/drawing\":614,d3:163}],1067:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../plots/attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/fx/hovertemplate_attributes\"),l=t(\"../../plots/domain\").attributes,c=n({editType:\"calc\"},o(\"line\",{editTypeOverride:\"calc\"}),{shape:{valType:\"enumerated\",values:[\"linear\",\"hspline\"],dflt:\"linear\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\"]})});e.exports={domain:l({name:\"parcats\",trace:!0,editType:\"calc\"}),hoverinfo:n({},i.hoverinfo,{flags:[\"count\",\"probability\"],editType:\"plot\",arrayOk:!1}),hoveron:{valType:\"enumerated\",values:[\"category\",\"color\",\"dimension\"],dflt:\"category\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\",\"category\",\"categorycount\",\"colorcount\",\"bandcolorcount\"]}),arrangement:{valType:\"enumerated\",values:[\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"perpendicular\",editType:\"plot\"},bundlecolors:{valType:\"boolean\",dflt:!0,editType:\"plot\"},sortpaths:{valType:\"enumerated\",values:[\"forward\",\"backward\"],dflt:\"forward\",editType:\"plot\"},labelfont:a({editType:\"calc\"}),tickfont:a({editType:\"calc\"}),dimensions:{_isLinkedToArray:\"dimension\",label:{valType:\"string\",editType:\"calc\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",dflt:[],editType:\"calc\"},displayindex:{valType:\"integer\",editType:\"calc\"},editType:\"calc\",visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"}},line:c,counts:{valType:\"number\",min:0,dflt:1,arrayOk:!0,editType:\"calc\"},customdata:void 0,hoverlabel:void 0,ids:void 0,legendgroup:void 0,opacity:void 0,selectedpoints:void 0,showlegend:void 0}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1068:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"parcats\",r.plot=function(t,e,r,a){var o=n(t.calcdata,\"parcats\");if(o.length){var s=o[0];i(t,s,r,a)}},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcats\"),a=e._has&&e._has(\"parcats\");i&&!a&&n._paperdiv.selectAll(\".parcats\").remove()}},{\"../../plots/get_data\":802,\"./plot\":1073}],1069:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),o=t(\"../../lib/filter_unique.js\"),s=t(\"../../components/drawing\"),l=t(\"../../lib\");function c(t,e,r){t.valueInds.push(e),t.count+=r}function u(t,e,r){t.valueInds.push(e),t.count+=r}e.exports=function(t,e){var r=l.filterVisible(e.dimensions);if(0===r.length)return[];var h,f,p,d=r.map(function(t){var e;return\"trace\"===t.categoryorder?e=null:\"array\"===t.categoryorder?e=t.categoryarray:(e=o(t.values).sort(),\"category descending\"===t.categoryorder&&(e=e.reverse())),function(t,e){e=null==e?[]:e.map(function(t){return t});var r={},n={},i=[];e.forEach(function(t,e){r[t]=0,n[t]=e});for(var a=0;a<t.length;a++){var o,s=t[a];void 0===r[s]?(r[s]=1,o=e.push(s)-1,n[s]=o):(r[s]++,o=n[s]),i.push(o)}var l=e.map(function(t){return r[t]});return{uniqueValues:e,uniqueCounts:l,inds:i}}(t.values,e)});h=l.isArrayOrTypedArray(e.counts)?e.counts:[e.counts],function(t){var e;if(function(t){for(var e=new Array(t.length),r=0;r<t.length;r++){if(t[r]<0||t[r]>=t.length)return!1;if(void 0!==e[t[r]])return!1;e[t[r]]=!0}return!0}(t.map(function(t){return t.displayindex})))for(e=0;e<t.length;e++)t[e]._displayindex=t[e].displayindex;else for(e=0;e<t.length;e++)t[e]._displayindex=e}(r),r.forEach(function(t,e){!function(t,e){t._categoryarray=e.uniqueValues,null===t.ticktext||void 0===t.ticktext?t._ticktext=[]:t._ticktext=t.ticktext.slice();for(var r=t._ticktext.length;r<e.uniqueValues.length;r++)t._ticktext.push(e.uniqueValues[r])}(t,d[e])});var g,v=e.line;v?(i(e,\"line\")&&a(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),g=s.tryColorscale(v)):g=l.identity;var m,y,x,b,_=r[0].values.length,w={},k=d.map(function(t){return t.inds});for(p=0,m=0;m<_;m++){var T=[];for(y=0;y<k.length;y++)T.push(k[y][m]);f=h[m%h.length],p+=f;var A=(x=m,b=void 0,b=l.isArrayOrTypedArray(v.color)?v.color[x%v.color.length]:v.color,{color:g(b),rawColor:b}),M=T+\"-\"+A.rawColor;void 0===w[M]&&(w[M]={categoryInds:T,color:A.color,rawColor:A.rawColor,valueInds:[],count:0}),u(w[M],m,f)}var S,E=r.map(function(t,e){return r=e,n=t._index,i=t._displayindex,a=t.label,{dimensionInd:r,containerInd:n,displayInd:i,dimensionLabel:a,count:p,categories:[],dragX:null};var r,n,i,a});for(m=0;m<_;m++)for(f=h[m%h.length],y=0;y<E.length;y++){var C=E[y].containerInd,L=d[y].inds[m],P=E[y].categories;if(void 0===P[L]){var O=e.dimensions[C]._categoryarray[L],z=e.dimensions[C]._ticktext[L];P[L]={dimensionInd:y,categoryInd:S=L,categoryValue:O,displayInd:S,categoryLabel:z,valueInds:[],count:0,dragY:null}}c(P[L],m,f)}return n(function(t,e,r){var n=t.map(function(t){return t.categories.length}).reduce(function(t,e){return Math.max(t,e)});return{dimensions:t,paths:e,trace:void 0,maxCats:n,count:r}}(E,w,p))}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/filter_unique.js\":711,\"../../lib/gup\":717}],1070:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"./attributes\"),c=t(\"../parcoords/merge_length\");function u(t,e){function r(r,i){return n.coerce(t,e,l.dimensions,r,i)}var i=r(\"values\"),a=r(\"visible\");if(i&&i.length||(a=e.visible=!1),a){r(\"label\"),r(\"displayindex\",e._index);var o,s=t.categoryarray,c=Array.isArray(s)&&s.length>0;c&&(o=\"array\");var u=r(\"categoryorder\",o);\"array\"===u?(r(\"categoryarray\"),r(\"ticktext\")):(delete t.categoryarray,delete t.ticktext),c||\"array\"!==u||(e.categoryorder=\"trace\")}}e.exports=function(t,e,r,h){function f(r,i){return n.coerce(t,e,l,r,i)}var p=s(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=function(t,e,r,o,s){s(\"line.shape\"),s(\"line.hovertemplate\");var l=s(\"line.color\",o.colorway[0]);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,h,f);o(e,h,f),Array.isArray(p)&&p.length||(e.visible=!1),c(e,p,\"values\",d),f(\"hoveron\"),f(\"hovertemplate\"),f(\"arrangement\"),f(\"bundlecolors\"),f(\"sortpaths\"),f(\"counts\");var g={family:h.font.family,size:Math.round(h.font.size),color:h.font.color};n.coerceFont(f,\"labelfont\",g);var v={family:h.font.family,size:Math.round(h.font.size/1.2),color:h.font.color};n.coerceFont(f,\"tickfont\",v)}},{\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/domain\":792,\"../parcoords/merge_length\":1083,\"./attributes\":1067}],1071:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcats\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1067,\"./base_plot\":1068,\"./calc\":1069,\"./defaults\":1070,\"./plot\":1073}],1072:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plot_api/plot_api\"),a=t(\"../../components/fx\"),o=t(\"../../lib\"),s=t(\"../../components/drawing\"),l=t(\"tinycolor2\"),c=t(\"../../lib/svg_text_utils\");function u(t,e,r,i){var a=t.map(function(t,e,r){var n,i=r[0],a=e.margin||{l:80,r:80,t:100,b:80},o=i.trace,s=o.domain,l=e.width,c=e.height,u=Math.floor(l*(s.x[1]-s.x[0])),h=Math.floor(c*(s.y[1]-s.y[0])),f=s.x[0]*l+a.l,p=e.height-s.y[1]*e.height+a.t,d=o.line.shape;n=\"all\"===o.hoverinfo?[\"count\",\"probability\"]:(o.hoverinfo||\"\").split(\"+\");var g={trace:o,key:o.uid,model:i,x:f,y:p,width:u,height:h,hoveron:o.hoveron,hoverinfoItems:n,arrangement:o.arrangement,bundlecolors:o.bundlecolors,sortpaths:o.sortpaths,labelfont:o.labelfont,categorylabelfont:o.tickfont,pathShape:d,dragDimension:null,margin:a,paths:[],dimensions:[],graphDiv:t,traceSelection:null,pathSelection:null,dimensionSelection:null};i.dimensions&&(R(g),D(g));return g}.bind(0,e,r)),l=i.selectAll(\"g.parcatslayer\").data([null]);l.enter().append(\"g\").attr(\"class\",\"parcatslayer\").style(\"pointer-events\",\"all\");var u=l.selectAll(\"g.trace.parcats\").data(a,h),v=u.enter().append(\"g\").attr(\"class\",\"trace parcats\");u.attr(\"transform\",function(t){return\"translate(\"+t.x+\", \"+t.y+\")\"}),v.append(\"g\").attr(\"class\",\"paths\");var x=u.select(\"g.paths\").selectAll(\"path.path\").data(function(t){return t.paths},h);x.attr(\"fill\",function(t){return t.model.color});var w=x.enter().append(\"path\").attr(\"class\",\"path\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.model.color}).attr(\"fill-opacity\",0);y(w),x.attr(\"d\",function(t){return t.svgD}),w.empty()||x.sort(p),x.exit().remove(),x.on(\"mouseover\",d).on(\"mouseout\",g).on(\"click\",m),v.append(\"g\").attr(\"class\",\"dimensions\");var k=u.select(\"g.dimensions\").selectAll(\"g.dimension\").data(function(t){return t.dimensions},h);k.enter().append(\"g\").attr(\"class\",\"dimension\"),k.attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),k.exit().remove();var T=k.selectAll(\"g.category\").data(function(t){return t.categories},h),A=T.enter().append(\"g\").attr(\"class\",\"category\");T.attr(\"transform\",function(t){return\"translate(0, \"+t.y+\")\"}),A.append(\"rect\").attr(\"class\",\"catrect\").attr(\"pointer-events\",\"none\"),T.select(\"rect.catrect\").attr(\"fill\",\"none\").attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}),b(A);var P=T.selectAll(\"rect.bandrect\").data(function(t){return t.bands},h);P.each(function(){o.raiseToTop(this)}),P.attr(\"fill\",function(t){return t.color});var O=P.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.color}).attr(\"fill-opacity\",0);P.attr(\"fill\",function(t){return t.color}).attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}).attr(\"y\",function(t){return t.y}).attr(\"cursor\",function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"perpendicular\"===t.parcatsViewModel.arrangement?\"ns-resize\":\"move\"}),_(O),P.exit().remove(),A.append(\"text\").attr(\"class\",\"catlabel\").attr(\"pointer-events\",\"none\");var z=e._fullLayout.paper_bgcolor;T.select(\"text.catlabel\").attr(\"text-anchor\",function(t){return f(t)?\"start\":\"end\"}).attr(\"alignment-baseline\",\"middle\").style(\"text-shadow\",z+\" -1px  1px 2px, \"+z+\" 1px  1px 2px, \"+z+\"  1px -1px 2px, \"+z+\" -1px -1px 2px\").style(\"fill\",\"rgb(0, 0, 0)\").attr(\"x\",function(t){return f(t)?t.width+5:-5}).attr(\"y\",function(t){return t.height/2}).text(function(t){return t.model.categoryLabel}).each(function(t){s.font(n.select(this),t.parcatsViewModel.categorylabelfont),c.convertToTspans(n.select(this),e)}),A.append(\"text\").attr(\"class\",\"dimlabel\"),T.select(\"text.dimlabel\").attr(\"text-anchor\",\"middle\").attr(\"alignment-baseline\",\"baseline\").attr(\"cursor\",function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"ew-resize\"}).attr(\"x\",function(t){return t.width/2}).attr(\"y\",-5).text(function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null}).each(function(t){s.font(n.select(this),t.parcatsViewModel.labelfont)}),T.selectAll(\"rect.bandrect\").on(\"mouseover\",M).on(\"mouseout\",S),T.exit().remove(),k.call(n.behavior.drag().origin(function(t){return{x:t.x,y:0}}).on(\"dragstart\",E).on(\"drag\",C).on(\"dragend\",L)),u.each(function(t){t.traceSelection=n.select(this),t.pathSelection=n.select(this).selectAll(\"g.paths\").selectAll(\"path.path\"),t.dimensionSelection=n.select(this).selectAll(\"g.dimensions\").selectAll(\"g.dimension\")}),u.exit().remove()}function h(t){return t.key}function f(t){var e=t.parcatsViewModel.dimensions.length,r=t.parcatsViewModel.dimensions[e-1].model.dimensionInd;return t.model.dimensionInd===r}function p(t,e){return t.model.rawColor>e.model.rawColor?1:t.model.rawColor<e.model.rawColor?-1:0}function d(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){o.raiseToTop(this),x(n.select(this));var e=v(t);if(t.parcatsViewModel.graphDiv.emit(\"plotly_hover\",{points:e,event:n.event}),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\")){var r,i,s,c=n.mouse(this)[0],u=t.parcatsViewModel.graphDiv,h=t.parcatsViewModel.trace,f=u._fullLayout,p=f._paperdiv.node().getBoundingClientRect(),d=t.parcatsViewModel.graphDiv.getBoundingClientRect();for(s=0;s<t.leftXs.length-1;s++)if(t.leftXs[s]+t.dimWidths[s]-2<=c&&c<=t.leftXs[s+1]+2){var g=t.parcatsViewModel.dimensions[s],m=t.parcatsViewModel.dimensions[s+1];r=(g.x+g.width+m.x)/2,i=(t.topYs[s]+t.topYs[s+1]+t.height)/2;break}var y=t.parcatsViewModel.x+r,b=t.parcatsViewModel.y+i,_=l.mostReadable(t.model.color,[\"black\",\"white\"]),w=t.model.count,k=w/t.parcatsViewModel.model.count,T={countLabel:w,probabilityLabel:k.toFixed(3)},A=[];-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&A.push([\"Count:\",T.countLabel].join(\" \")),-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&A.push([\"P:\",T.probabilityLabel].join(\" \"));var M=A.join(\"<br>\"),S=n.mouse(u)[0];a.loneHover({trace:h,x:y-p.left+d.left,y:b-p.top+d.top,text:M,color:t.model.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:10,fontColor:_,idealAlign:S<y?\"right\":\"left\",hovertemplate:(h.line||{}).hovertemplate,hovertemplateLabels:T,eventData:[{data:h._input,fullData:h,count:w,probability:k}]},{container:f._hoverlayer.node(),outerContainer:f._paper.node(),gd:u})}}}function g(t){if(!t.parcatsViewModel.dragDimension&&(y(n.select(this)),a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()),t.parcatsViewModel.pathSelection.sort(p),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\"))){var e=v(t);t.parcatsViewModel.graphDiv.emit(\"plotly_unhover\",{points:e,event:n.event})}}function v(t){for(var e=[],r=P(t.parcatsViewModel),n=0;n<t.model.valueInds.length;n++){var i=t.model.valueInds[n];e.push({curveNumber:r,pointNumber:i})}return e}function m(t){if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){var e=v(t);t.parcatsViewModel.graphDiv.emit(\"plotly_click\",{points:e,event:n.event})}}function y(t){t.attr(\"fill\",function(t){return t.model.color}).attr(\"fill-opacity\",.6).attr(\"stroke\",\"lightgray\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1)}function x(t){t.attr(\"fill-opacity\",.8).attr(\"stroke\",function(t){return l.mostReadable(t.model.color,[\"black\",\"white\"])}).attr(\"stroke-width\",.3)}function b(t){t.select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",1).attr(\"stroke-opacity\",1)}function _(t){t.attr(\"stroke\",\"black\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1).attr(\"fill-opacity\",1)}function w(t){var e=t.parcatsViewModel.pathSelection,r=t.categoryViewModel.model.dimensionInd,n=t.categoryViewModel.model.categoryInd;return e.filter(function(e){return e.model.categoryInds[r]===n&&e.model.color===t.color})}function k(t,e,r){var i=n.select(t).datum().parcatsViewModel.graphDiv,a=n.select(t.parentNode).selectAll(\"rect.bandrect\"),o=[];a.each(function(t){w(t).each(function(t){Array.prototype.push.apply(o,v(t))})}),i.emit(e,{points:o,event:r})}function T(t,e,r){var i=n.select(t).datum(),a=i.parcatsViewModel.graphDiv,o=w(i),s=[];o.each(function(t){Array.prototype.push.apply(s,v(t))}),a.emit(e,{points:s,event:r})}function A(t,e){var r,i,a=n.select(e.parentNode).select(\"rect.catrect\"),o=a.node().getBoundingClientRect(),s=a.datum(),l=s.parcatsViewModel,c=l.model.dimensions[s.model.dimensionInd],u=l.trace,h=o.top+o.height/2;l.dimensions.length>1&&c.displayInd===l.dimensions.length-1?(r=o.left,i=\"left\"):(r=o.left+o.width,i=\"right\");var f=s.model.count,p=s.model.categoryLabel,d=f/s.parcatsViewModel.model.count,g={countLabel:f,categoryLabel:p,probabilityLabel:d.toFixed(3)},v=[];-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&v.push([\"Count:\",g.countLabel].join(\" \")),-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&v.push([\"P(\"+g.categoryLabel+\"):\",g.probabilityLabel].join(\" \"));var m=v.join(\"<br>\");return{trace:u,x:r-t.left,y:h-t.top,text:m,color:\"lightgray\",borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:12,fontColor:\"black\",idealAlign:i,hovertemplate:u.hovertemplate,hovertemplateLabels:g,eventData:[{data:u._input,fullData:u,count:f,category:p,probability:d}]}}function M(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){if(n.mouse(this)[1]<-1)return;var e,r=t.parcatsViewModel.graphDiv,i=r._fullLayout,s=i._paperdiv.node().getBoundingClientRect(),c=t.parcatsViewModel.hoveron;if(\"color\"===c?(!function(t){var e=n.select(t).datum(),r=w(e);x(r),r.each(function(){o.raiseToTop(this)}),n.select(t.parentNode).selectAll(\"rect.bandrect\").filter(function(t){return t.color===e.color}).each(function(){o.raiseToTop(this),n.select(this).attr(\"stroke\",\"black\").attr(\"stroke-width\",1.5)})}(this),T(this,\"plotly_hover\",n.event)):(!function(t){n.select(t.parentNode).selectAll(\"rect.bandrect\").each(function(t){var e=w(t);x(e),e.each(function(){o.raiseToTop(this)})}),n.select(t.parentNode).select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",2.5)}(this),k(this,\"plotly_hover\",n.event)),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\"))\"category\"===c?e=A(s,this):\"color\"===c?e=function(t,e){var r,i,a=e.getBoundingClientRect(),o=n.select(e).datum(),s=o.categoryViewModel,c=s.parcatsViewModel,u=c.model.dimensions[s.model.dimensionInd],h=c.trace,f=a.y+a.height/2;c.dimensions.length>1&&u.displayInd===c.dimensions.length-1?(r=a.left,i=\"left\"):(r=a.left+a.width,i=\"right\");var p=s.model.categoryLabel,d=o.parcatsViewModel.model.count,g=0;o.categoryViewModel.bands.forEach(function(t){t.color===o.color&&(g+=t.count)});var v=s.model.count,m=0;c.pathSelection.each(function(t){t.model.color===o.color&&(m+=t.model.count)});var y=g/d,x=g/m,b=g/v,_={countLabel:d,categoryLabel:p,probabilityLabel:y.toFixed(3)},w=[];-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&w.push([\"Count:\",_.countLabel].join(\" \")),-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&(w.push(\"P(color \\u2229 \"+p+\"): \"+_.probabilityLabel),w.push(\"P(\"+p+\" | color): \"+x.toFixed(3)),w.push(\"P(color | \"+p+\"): \"+b.toFixed(3)));var k=w.join(\"<br>\"),T=l.mostReadable(o.color,[\"black\",\"white\"]);return{trace:h,x:r-t.left,y:f-t.top,text:k,color:o.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontColor:T,fontSize:10,idealAlign:i,hovertemplate:h.hovertemplate,hovertemplateLabels:_,eventData:[{data:h._input,fullData:h,category:p,count:d,probability:y,categorycount:v,colorcount:m,bandcolorcount:g}]}}(s,this):\"dimension\"===c&&(e=function(t,e){var r=[];return n.select(e.parentNode.parentNode).selectAll(\"g.category\").select(\"rect.catrect\").each(function(){r.push(A(t,this))}),r}(s,this)),e&&a.loneHover(e,{container:i._hoverlayer.node(),outerContainer:i._paper.node(),gd:r})}}function S(t){var e=t.parcatsViewModel;if(!e.dragDimension&&(y(e.pathSelection),b(e.dimensionSelection.selectAll(\"g.category\")),_(e.dimensionSelection.selectAll(\"g.category\").selectAll(\"rect.bandrect\")),a.loneUnhover(e.graphDiv._fullLayout._hoverlayer.node()),e.pathSelection.sort(p),-1===e.hoverinfoItems.indexOf(\"skip\"))){\"color\"===t.parcatsViewModel.hoveron?T(this,\"plotly_unhover\",n.event):k(this,\"plotly_unhover\",n.event)}}function E(t){\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragDimensionDisplayInd=t.model.displayInd,t.initialDragDimensionDisplayInds=t.parcatsViewModel.model.dimensions.map(function(t){return t.displayInd}),t.dragHasMoved=!1,t.dragCategoryDisplayInd=null,n.select(this).selectAll(\"g.category\").select(\"rect.catrect\").each(function(e){var r=n.mouse(this)[0],i=n.mouse(this)[1];-2<=r&&r<=e.width+2&&-2<=i&&i<=e.height+2&&(t.dragCategoryDisplayInd=e.model.displayInd,t.initialDragCategoryDisplayInds=t.model.categories.map(function(t){return t.displayInd}),e.model.dragY=e.y,o.raiseToTop(this.parentNode),n.select(this.parentNode).selectAll(\"rect.bandrect\").each(function(e){e.y<i&&i<=e.y+e.height&&(t.potentialClickBand=this)}))}),t.parcatsViewModel.dragDimension=t,a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()))}function C(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragHasMoved=!0,null!==t.dragDimensionDisplayInd)){var e=t.dragDimensionDisplayInd,r=e-1,i=e+1,a=t.parcatsViewModel.dimensions[e];if(null!==t.dragCategoryDisplayInd){var o=a.categories[t.dragCategoryDisplayInd];o.model.dragY+=n.event.dy;var s=o.model.dragY,l=o.model.displayInd,c=a.categories,u=c[l-1],h=c[l+1];void 0!==u&&s<u.y+u.height/2&&(o.model.displayInd=u.model.displayInd,u.model.displayInd=l),void 0!==h&&s+o.height>h.y+h.height/2&&(o.model.displayInd=h.model.displayInd,h.model.displayInd=l),t.dragCategoryDisplayInd=o.model.displayInd}if(null===t.dragCategoryDisplayInd||\"freeform\"===t.parcatsViewModel.arrangement){a.model.dragX=n.event.x;var f=t.parcatsViewModel.dimensions[r],p=t.parcatsViewModel.dimensions[i];void 0!==f&&a.model.dragX<f.x+f.width&&(a.model.displayInd=f.model.displayInd,f.model.displayInd=e),void 0!==p&&a.model.dragX+a.width>p.x&&(a.model.displayInd=p.model.displayInd,p.model.displayInd=t.dragDimensionDisplayInd),t.dragDimensionDisplayInd=a.model.displayInd}R(t.parcatsViewModel),D(t.parcatsViewModel),z(t.parcatsViewModel),O(t.parcatsViewModel)}}function L(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&null!==t.dragDimensionDisplayInd){n.select(this).selectAll(\"text\").attr(\"font-weight\",\"normal\");var e={},r=P(t.parcatsViewModel),a=t.parcatsViewModel.model.dimensions.map(function(t){return t.displayInd}),o=t.initialDragDimensionDisplayInds.some(function(t,e){return t!==a[e]});o&&a.forEach(function(r,n){var i=t.parcatsViewModel.model.dimensions[n].containerInd;e[\"dimensions[\"+i+\"].displayindex\"]=r});var s=!1;if(null!==t.dragCategoryDisplayInd){var l=t.model.categories.map(function(t){return t.displayInd});if(s=t.initialDragCategoryDisplayInds.some(function(t,e){return t!==l[e]})){var c=t.model.categories.slice().sort(function(t,e){return t.displayInd-e.displayInd}),u=c.map(function(t){return t.categoryValue}),h=c.map(function(t){return t.categoryLabel});e[\"dimensions[\"+t.model.containerInd+\"].categoryarray\"]=[u],e[\"dimensions[\"+t.model.containerInd+\"].ticktext\"]=[h],e[\"dimensions[\"+t.model.containerInd+\"].categoryorder\"]=\"array\"}}if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")&&!t.dragHasMoved&&t.potentialClickBand&&(\"color\"===t.parcatsViewModel.hoveron?T(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent):k(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent)),t.model.dragX=null,null!==t.dragCategoryDisplayInd)t.parcatsViewModel.dimensions[t.dragDimensionDisplayInd].categories[t.dragCategoryDisplayInd].model.dragY=null,t.dragCategoryDisplayInd=null;t.dragDimensionDisplayInd=null,t.parcatsViewModel.dragDimension=null,t.dragHasMoved=null,t.potentialClickBand=null,R(t.parcatsViewModel),D(t.parcatsViewModel),n.transition().duration(300).ease(\"cubic-in-out\").each(function(){z(t.parcatsViewModel,!0),O(t.parcatsViewModel,!0)}).each(\"end\",function(){(o||s)&&i.restyle(t.parcatsViewModel.graphDiv,e,[r])})}}function P(t){for(var e,r=t.graphDiv._fullData,n=0;n<r.length;n++)if(t.key===r[n].uid){e=n;break}return e}function O(t,e){var r;void 0===e&&(e=!1),t.pathSelection.data(function(t){return t.paths},h),(r=t.pathSelection,e?r.transition():r).attr(\"d\",function(t){return t.svgD})}function z(t,e){function r(t){return e?t.transition():t}void 0===e&&(e=!1),t.dimensionSelection.data(function(t){return t.dimensions},h);var i=t.dimensionSelection.selectAll(\"g.category\").data(function(t){return t.categories},h);r(t.dimensionSelection).attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),r(i).attr(\"transform\",function(t){return\"translate(0, \"+t.y+\")\"}),i.select(\".dimlabel\").text(function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null}),i.select(\".catlabel\").attr(\"text-anchor\",function(t){return f(t)?\"start\":\"end\"}).attr(\"x\",function(t){return f(t)?t.width+5:-5}).each(function(t){var e,r;f(t)?(e=t.width+5,r=\"start\"):(e=-5,r=\"end\"),n.select(this).selectAll(\"tspan\").attr(\"x\",e).attr(\"text-anchor\",r)});var a=i.selectAll(\"rect.bandrect\").data(function(t){return t.bands},h),s=a.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"cursor\",\"move\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.color}).attr(\"fill-opacity\",0);a.attr(\"fill\",function(t){return t.color}).attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}).attr(\"y\",function(t){return t.y}),_(s),a.each(function(){o.raiseToTop(this)}),a.exit().remove()}function I(t,e,r,i,a){var o,s,l=[],c=[];for(s=0;s<r.length-1;s++)o=n.interpolateNumber(r[s]+t[s],t[s+1]),l.push(o(a)),c.push(o(1-a));var u=\"M \"+t[0]+\",\"+e[0];for(u+=\"l\"+r[0]+\",0 \",s=1;s<r.length;s++)u+=\"C\"+l[s-1]+\",\"+e[s-1]+\" \"+c[s-1]+\",\"+e[s]+\" \"+t[s]+\",\"+e[s],u+=\"l\"+r[s]+\",0 \";for(u+=\"l0,\"+i+\" \",u+=\"l -\"+r[r.length-1]+\",0 \",s=r.length-2;s>=0;s--)u+=\"C\"+c[s]+\",\"+(e[s+1]+i)+\" \"+l[s]+\",\"+(e[s]+i)+\" \"+(t[s]+r[s])+\",\"+(e[s]+i),u+=\"l-\"+r[s]+\",0 \";return u+=\"Z\"}function D(t){var e=t.dimensions,r=t.model,n=e.map(function(t){return t.categories.map(function(t){return t.y})}),i=t.model.dimensions.map(function(t){return t.categories.map(function(t){return t.displayInd})}),a=t.model.dimensions.map(function(t){return t.displayInd}),o=t.dimensions.map(function(t){return t.model.dimensionInd}),s=e.map(function(t){return t.x}),l=e.map(function(t){return t.width}),c=[];for(var u in r.paths)r.paths.hasOwnProperty(u)&&c.push(r.paths[u]);function h(t){var e=t.categoryInds.map(function(t,e){return i[e][t]});return o.map(function(t){return e[t]})}c.sort(function(e,r){var n=h(e),i=h(r);return\"backward\"===t.sortpaths&&(n.reverse(),i.reverse()),n.push(e.valueInds[0]),i.push(r.valueInds[0]),t.bundlecolors&&(n.unshift(e.rawColor),i.unshift(r.rawColor)),n<i?-1:n>i?1:0});for(var f=new Array(c.length),p=e[0].model.count,d=e[0].categories.map(function(t){return t.height}).reduce(function(t,e){return t+e}),g=0;g<c.length;g++){var v,m=c[g];v=p>0?d*(m.count/p):0;for(var y,x=new Array(n.length),b=0;b<m.categoryInds.length;b++){var _=m.categoryInds[b],w=i[b][_],k=a[b];x[k]=n[k][w],n[k][w]+=v;var T=t.dimensions[k].categories[w],A=T.bands.length,M=T.bands[A-1];if(void 0===M||m.rawColor!==M.rawColor){var S=void 0===M?0:M.y+M.height;T.bands.push({key:S,color:m.color,rawColor:m.rawColor,height:v,width:T.width,count:m.count,y:S,categoryViewModel:T,parcatsViewModel:t})}else{var E=T.bands[A-1];E.height+=v,E.count+=m.count}}y=\"hspline\"===t.pathShape?I(s,x,l,v,.5):I(s,x,l,v,0),f[g]={key:m.valueInds[0],model:m,height:v,leftXs:s,topYs:x,dimWidths:l,svgD:y,parcatsViewModel:t}}t.paths=f}function R(t){var e=t.model.dimensions.map(function(t){return{displayInd:t.displayInd,dimensionInd:t.dimensionInd}});e.sort(function(t,e){return t.displayInd-e.displayInd});var r=[];for(var n in e){var i=e[n].dimensionInd,a=t.model.dimensions[i];r.push(F(t,a))}t.dimensions=r}function F(t,e){var r,n=t.model.dimensions.length,i=e.displayInd;r=40+(n>1?(t.width-80-16)/(n-1):0)*i;var a,o,s,l,c,u=[],h=t.model.maxCats,f=e.categories.length,p=e.count,d=t.height-8*(h-1),g=8*(h-f)/2,v=e.categories.map(function(t){return{displayInd:t.displayInd,categoryInd:t.categoryInd}});for(v.sort(function(t,e){return t.displayInd-e.displayInd}),c=0;c<f;c++)l=v[c].categoryInd,o=e.categories[l],a=p>0?o.count/p*d:0,s={key:o.valueInds[0],model:o,width:16,height:a,y:null!==o.dragY?o.dragY:g,bands:[],parcatsViewModel:t},g=g+a+8,u.push(s);return{key:e.dimensionInd,x:null!==e.dragX?e.dragX:r,y:0,width:16,model:e,categories:u,parcatsViewModel:t,dragCategoryDisplayInd:null,dragDimensionDisplayInd:null,initialDragDimensionDisplayInds:null,initialDragCategoryDisplayInds:null,dragHasMoved:null,potentialClickBand:null}}e.exports=function(t,e,r,n){u(r,t,n,e)}},{\"../../components/drawing\":614,\"../../components/fx\":632,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_api\":754,d3:163,tinycolor2:537}],1073:[function(t,e,r){\"use strict\";var n=t(\"./parcats\");e.exports=function(t,e,r,i){var a=t._fullLayout,o=a._paper,s=a._size;n(t,o,e,{width:s.w,height:s.h,margin:{t:s.t,r:s.r,b:s.b,l:s.l}},r,i)}},{\"./parcats\":1072}],1074:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/cartesian/layout_attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../plots/domain\").attributes,s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/plot_template\").templatedArray;e.exports={domain:o({name:\"parcoords\",trace:!0,editType:\"plot\"}),labelangle:{valType:\"angle\",dflt:0,editType:\"plot\"},labelside:{valType:\"enumerated\",values:[\"top\",\"bottom\"],dflt:\"top\",editType:\"plot\"},labelfont:a({editType:\"plot\"}),tickfont:a({editType:\"plot\"}),rangefont:a({editType:\"plot\"}),dimensions:l(\"dimension\",{label:{valType:\"string\",editType:\"plot\"},tickvals:s({},i.tickvals,{editType:\"plot\"}),ticktext:s({},i.ticktext,{editType:\"plot\"}),tickformat:s({},i.tickformat,{editType:\"plot\"}),visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},constraintrange:{valType:\"info_array\",freeLength:!0,dimensions:\"1-2\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},multiselect:{valType:\"boolean\",dflt:!0,editType:\"plot\"},values:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"}),line:s({editType:\"calc\"},n(\"line\",{colorscaleDflt:\"Viridis\",autoColorDflt:!1,editTypeOverride:\"calc\"}))}},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1075:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\").keyFun,o=t(\"../../lib/gup\").repeat,s=t(\"../../lib\").sorterAsc,l=n.bar.snapRatio;function c(t,e){return t*(1-l)+e*l}var u=n.bar.snapClose;function h(t,e){return t*(1-u)+e*u}function f(t,e,r,n){if(function(t,e){for(var r=0;r<e.length;r++)if(t>=e[r][0]&&t<=e[r][1])return!0;return!1}(r,n))return r;var i=t?-1:1,a=0,o=e.length-1;if(i<0){var s=a;a=o,o=s}for(var l=e[a],u=l,f=a;i*f<i*o;f+=i){var p=f+i,d=e[p];if(i*r<i*h(l,d))return c(l,u);if(i*r<i*d||p===o)return c(d,l);u=l,l=d}}function p(t){t.attr(\"x\",-n.bar.captureWidth/2).attr(\"width\",n.bar.captureWidth)}function d(t){t.attr(\"visibility\",\"visible\").style(\"visibility\",\"visible\").attr(\"fill\",\"yellow\").attr(\"opacity\",0)}function g(t){if(!t.brush.filterSpecified)return\"0,\"+t.height;for(var e,r,n,i=v(t.brush.filter.getConsolidated(),t.height),a=[0],o=i.length?i[0][0]:null,s=0;s<i.length;s++)r=(e=i[s])[1]-e[0],a.push(o),a.push(r),(n=s+1)<i.length&&(o=i[n][0]-e[1]);return a.push(t.height),a}function v(t,e){return t.map(function(t){return t.map(function(t){return Math.max(0,t*e)}).sort(s)})}function m(){i.select(document.body).style(\"cursor\",null)}function y(t){t.attr(\"stroke-dasharray\",g)}function x(t,e){var r=i.select(t).selectAll(\".highlight, .highlight-shadow\");y(e?r.transition().duration(n.bar.snapDuration).each(\"end\",e):r)}function b(t,e){var r,i=t.brush,a=NaN,o={};if(i.filterSpecified){var s=t.height,l=i.filter.getConsolidated(),c=v(l,s),u=NaN,h=NaN,f=NaN;for(r=0;r<=c.length;r++){var p=c[r];if(p&&p[0]<=e&&e<=p[1]){u=r;break}if(h=r?r-1:NaN,p&&p[0]>e){f=r;break}}if(a=u,isNaN(a)&&(a=isNaN(h)||isNaN(f)?isNaN(h)?f:h:e-c[h][1]<c[f][0]-e?h:f),!isNaN(a)){var d=c[a],g=function(t,e){var r=n.bar.handleHeight;if(!(e>t[1]+r||e<t[0]-r))return e>=.9*t[1]+.1*t[0]?\"n\":e<=.9*t[0]+.1*t[1]?\"s\":\"ns\"}(d,e);g&&(o.interval=l[a],o.intervalPix=d,o.region=g)}}if(t.ordinal&&!o.region){var m=t.unitTickvals,y=t.unitToPaddedPx.invert(e);for(r=0;r<m.length;r++){var x=[.25*m[Math.max(r-1,0)]+.75*m[r],.25*m[Math.min(r+1,m.length-1)]+.75*m[r]];if(y>=x[0]&&y<=x[1]){o.clickableOrdinalRange=x;break}}}return o}function _(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.brush.svgBrush;a.wasDragged=!0,a._dragging=!0,a.grabbingBar?a.newExtent=[r-a.grabPoint,r+a.barLength-a.grabPoint].map(e.unitToPaddedPx.invert):a.newExtent=[a.startExtent,e.unitToPaddedPx.invert(r)].sort(s),e.brush.filterSpecified=!0,a.extent=a.stayingIntervals.concat([a.newExtent]),a.brushCallback(e),x(t.parentNode)}function w(t,e){var r=b(e,e.height-i.mouse(t)[1]-2*n.verticalPadding),a=\"crosshair\";r.clickableOrdinalRange?a=\"pointer\":r.region&&(a=r.region+\"-resize\"),i.select(document.body).style(\"cursor\",a)}function k(t){t.on(\"mousemove\",function(t){i.event.preventDefault(),t.parent.inBrushDrag||w(this,t)}).on(\"mouseleave\",function(t){t.parent.inBrushDrag||m()}).call(i.behavior.drag().on(\"dragstart\",function(t){!function(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.unitToPaddedPx.invert(r),o=e.brush,s=b(e,r),l=s.interval,c=o.svgBrush;if(c.wasDragged=!1,c.grabbingBar=\"ns\"===s.region,c.grabbingBar){var u=l.map(e.unitToPaddedPx);c.grabPoint=r-u[0]-n.verticalPadding,c.barLength=u[1]-u[0]}c.clickableOrdinalRange=s.clickableOrdinalRange,c.stayingIntervals=e.multiselect&&o.filterSpecified?o.filter.getConsolidated():[],l&&(c.stayingIntervals=c.stayingIntervals.filter(function(t){return t[0]!==l[0]&&t[1]!==l[1]})),c.startExtent=s.region?l[\"s\"===s.region?1:0]:a,e.parent.inBrushDrag=!0,c.brushStartCallback()}(this,t)}).on(\"drag\",function(t){_(this,t)}).on(\"dragend\",function(t){!function(t,e){var r=e.brush,n=r.filter,a=r.svgBrush;a._dragging||(w(t,e),_(t,e),e.brush.svgBrush.wasDragged=!1),a._dragging=!1,i.event.sourceEvent.stopPropagation();var o=a.grabbingBar;if(a.grabbingBar=!1,a.grabLocation=void 0,e.parent.inBrushDrag=!1,m(),!a.wasDragged)return a.wasDragged=void 0,a.clickableOrdinalRange?r.filterSpecified&&e.multiselect?a.extent.push(a.clickableOrdinalRange):(a.extent=[a.clickableOrdinalRange],r.filterSpecified=!0):o?(a.extent=a.stayingIntervals,0===a.extent.length&&A(r)):A(r),a.brushCallback(e),x(t.parentNode),void a.brushEndCallback(r.filterSpecified?n.getConsolidated():[]);var s=function(){n.set(n.getConsolidated())};if(e.ordinal){var l=e.unitTickvals;l[l.length-1]<l[0]&&l.reverse(),a.newExtent=[f(0,l,a.newExtent[0],a.stayingIntervals),f(1,l,a.newExtent[1],a.stayingIntervals)];var c=a.newExtent[1]>a.newExtent[0];a.extent=a.stayingIntervals.concat(c?[a.newExtent]:[]),a.extent.length||A(r),a.brushCallback(e),c?x(t.parentNode,s):(s(),x(t.parentNode))}else s();a.brushEndCallback(r.filterSpecified?n.getConsolidated():[])}(this,t)}))}function T(t,e){return t[0]-e[0]}function A(t){t.filterSpecified=!1,t.svgBrush.extent=[[-1/0,1/0]]}function M(t){for(var e,r=t.slice(),n=[],i=r.shift();i;){for(e=i.slice();(i=r.shift())&&i[0]<=e[1];)e[1]=Math.max(e[1],i[1]);n.push(e)}return n}e.exports={makeBrush:function(t,e,r,n,i,a){var o,l=function(){var t,e,r=[];return{set:function(n){1===(r=n.map(function(t){return t.slice().sort(s)}).sort(T)).length&&r[0][0]===-1/0&&r[0][1]===1/0&&(r=[[0,-1]]),t=M(r),e=r.reduce(function(t,e){return[Math.min(t[0],e[0]),Math.max(t[1],e[1])]},[1/0,-1/0])},get:function(){return r.slice()},getConsolidated:function(){return t},getBounds:function(){return e}}}();return l.set(r),{filter:l,filterSpecified:e,svgBrush:{extent:[],brushStartCallback:n,brushCallback:(o=i,function(t){var e=t.brush,r=function(t){return t.svgBrush.extent.map(function(t){return t.slice()})}(e).slice();e.filter.set(r),o()}),brushEndCallback:a}}},ensureAxisBrush:function(t){var e=t.selectAll(\".\"+n.cn.axisBrush).data(o,a);e.enter().append(\"g\").classed(n.cn.axisBrush,!0),function(t){var e=t.selectAll(\".background\").data(o);e.enter().append(\"rect\").classed(\"background\",!0).call(p).call(d).style(\"pointer-events\",\"auto\").attr(\"transform\",\"translate(0 \"+n.verticalPadding+\")\"),e.call(k).attr(\"height\",function(t){return t.height-n.verticalPadding});var r=t.selectAll(\".highlight-shadow\").data(o);r.enter().append(\"line\").classed(\"highlight-shadow\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width+n.bar.strokeWidth).attr(\"stroke\",n.bar.strokeColor).attr(\"opacity\",n.bar.strokeOpacity).attr(\"stroke-linecap\",\"butt\"),r.attr(\"y1\",function(t){return t.height}).call(y);var i=t.selectAll(\".highlight\").data(o);i.enter().append(\"line\").classed(\"highlight\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width-n.bar.strokeWidth).attr(\"stroke\",n.bar.fillColor).attr(\"opacity\",n.bar.fillOpacity).attr(\"stroke-linecap\",\"butt\"),i.attr(\"y1\",function(t){return t.height}).call(y)}(e)},cleanRanges:function(t,e){if(Array.isArray(t[0])?(t=t.map(function(t){return t.sort(s)}),t=e.multiselect?M(t.sort(T)):[t[0]]):t=[t.sort(s)],e.tickvals){var r=e.tickvals.slice().sort(s);if(!(t=t.map(function(t){var e=[f(0,r,t[0],[]),f(1,r,t[1],[])];if(e[1]>e[0])return e}).filter(function(t){return t})).length)return}return t.length>1?t:t[0]}}},{\"../../lib\":719,\"../../lib/gup\":717,\"./constants\":1078,d3:163}],1076:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../constants/xmlns_namespaces\");r.name=\"parcoords\",r.plot=function(t){var e=i(t.calcdata,\"parcoords\")[0];e.length&&a(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcoords\"),a=e._has&&e._has(\"parcoords\");i&&!a&&(n._paperdiv.selectAll(\".parcoords\").remove(),n._glimages.selectAll(\"*\").remove())},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter(function(t,e){return e===r.size()-1}).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each(function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})}),window.setTimeout(function(){n.selectAll(\"#filterBarPattern\").attr(\"id\",\"filterBarPattern\")},60)}},{\"../../constants/xmlns_namespaces\":696,\"../../plots/get_data\":802,\"./plot\":1085,d3:163}],1077:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale\"),a=t(\"../../lib/gup\").wrap;e.exports=function(t,e){var r,o;return i.hasColorscale(e,\"line\")&&n(e.line.color)?(r=e.line.color,o=i.extractOpts(e.line).colorscale,i.calc(t,e,{vals:r,containerStr:\"line\",cLetter:\"c\"})):(r=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=.5;return e}(e._length),o=[[0,e.line.color],[1,e.line.color]]),a({lineColor:r,cscale:o})}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gup\":717}],1078:[function(t,e,r){\"use strict\";e.exports={maxDimensionCount:60,overdrag:45,verticalPadding:2,tickDistance:50,canvasPixelRatio:1,blockLineCount:5e3,layers:[\"contextLineLayer\",\"focusLineLayer\",\"pickLineLayer\"],axisTitleOffset:28,axisExtentOffset:10,deselectedLineColor:\"#777\",bar:{width:4,captureWidth:10,fillColor:\"magenta\",fillOpacity:1,snapDuration:150,snapRatio:.25,snapClose:.01,strokeColor:\"white\",strokeOpacity:1,strokeWidth:1,handleHeight:8,handleOpacity:1,handleOverlap:0},cn:{axisExtentText:\"axis-extent-text\",parcoordsLineLayers:\"parcoords-line-layers\",parcoordsLineLayer:\"parcoords-lines\",parcoords:\"parcoords\",parcoordsControlView:\"parcoords-control-view\",yAxis:\"y-axis\",axisOverlays:\"axis-overlays\",axis:\"axis\",axisHeading:\"axis-heading\",axisTitle:\"axis-title\",axisExtent:\"axis-extent\",axisExtentTop:\"axis-extent-top\",axisExtentTopText:\"axis-extent-top-text\",axisExtentBottom:\"axis-extent-bottom\",axisExtentBottomText:\"axis-extent-bottom-text\",axisBrush:\"axis-brush\"},id:{filterBarPattern:\"filter-bar-pattern\"}}},{}],1079:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"../../plots/cartesian/axes\"),c=t(\"./attributes\"),u=t(\"./axisbrush\"),h=t(\"./constants\").maxDimensionCount,f=t(\"./merge_length\");function p(t,e,r,i){function a(r,i){return n.coerce(t,e,c.dimensions,r,i)}var o=a(\"values\"),s=a(\"visible\");if(o&&o.length||(s=e.visible=!1),s){a(\"label\"),a(\"tickvals\"),a(\"ticktext\"),a(\"tickformat\");var h=a(\"range\");e._ax={_id:\"y\",type:\"linear\",showexponent:\"all\",exponentformat:\"B\",range:h},l.setConvert(e._ax,i.layout),a(\"multiselect\");var f=a(\"constraintrange\");f&&(e.constraintrange=u.cleanRanges(f,e))}}e.exports=function(t,e,r,l){function u(r,i){return n.coerce(t,e,c,r,i)}var d=t.dimensions;Array.isArray(d)&&d.length>h&&(n.log(\"parcoords traces support up to \"+h+\" dimensions at the moment\"),d.splice(h));var g=s(t,e,{name:\"dimensions\",layout:l,handleItemDefaults:p}),v=function(t,e,r,o,s){var l=s(\"line.color\",r);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,l,u);o(e,l,u),Array.isArray(g)&&g.length||(e.visible=!1),f(e,g,\"values\",v);var m={family:l.font.family,size:Math.round(l.font.size/1.2),color:l.font.color};n.coerceFont(u,\"labelfont\",m),n.coerceFont(u,\"tickfont\",m),n.coerceFont(u,\"rangefont\",m),u(\"labelangle\"),u(\"labelside\")}},{\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"../../plots/domain\":792,\"./attributes\":1074,\"./axisbrush\":1075,\"./constants\":1078,\"./merge_length\":1083}],1080:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isTypedArray;r.convertTypedArray=function(t){return n(t)?Array.prototype.slice.call(t):t},r.isOrdinal=function(t){return!!t.tickvals},r.isVisible=function(t){return t.visible||!(\"visible\"in t)}},{\"../../lib\":719}],1081:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcoords\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"noOpacity\",\"noHover\"],meta:{}}},{\"./attributes\":1074,\"./base_plot\":1076,\"./calc\":1077,\"./defaults\":1079,\"./plot\":1085}],1082:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nattribute vec4 p01_04, p05_08, p09_12, p13_16,\\n               p17_20, p21_24, p25_28, p29_32,\\n               p33_36, p37_40, p41_44, p45_48,\\n               p49_52, p53_56, p57_60, colors;\\n\\nuniform mat4 dim0A, dim1A, dim0B, dim1B, dim0C, dim1C, dim0D, dim1D,\\n             loA, hiA, loB, hiB, loC, hiC, loD, hiD;\\n\\nuniform vec2 resolution, viewBoxPos, viewBoxSize;\\nuniform sampler2D mask, palette;\\nuniform float maskHeight;\\nuniform float drwLayer; // 0: context, 1: focus, 2: pick\\nuniform vec4 contextColor;\\n\\nbool isPick    = (drwLayer > 1.5);\\nbool isContext = (drwLayer < 0.5);\\n\\nconst vec4 ZEROS = vec4(0.0, 0.0, 0.0, 0.0);\\nconst vec4 UNITS = vec4(1.0, 1.0, 1.0, 1.0);\\n\\nfloat val(mat4 p, mat4 v) {\\n    return dot(matrixCompMult(p, v) * UNITS, UNITS);\\n}\\n\\nfloat axisY(float ratio, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float y1 = val(A, dim0A) + val(B, dim0B) + val(C, dim0C) + val(D, dim0D);\\n    float y2 = val(A, dim1A) + val(B, dim1B) + val(C, dim1C) + val(D, dim1D);\\n    return y1 * (1.0 - ratio) + y2 * ratio;\\n}\\n\\nint iMod(int a, int b) {\\n    return a - b * (a / b);\\n}\\n\\nbool fOutside(float p, float lo, float hi) {\\n    return (lo < hi) && (lo > p || p > hi);\\n}\\n\\nbool vOutside(vec4 p, vec4 lo, vec4 hi) {\\n    return (\\n        fOutside(p[0], lo[0], hi[0]) ||\\n        fOutside(p[1], lo[1], hi[1]) ||\\n        fOutside(p[2], lo[2], hi[2]) ||\\n        fOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool mOutside(mat4 p, mat4 lo, mat4 hi) {\\n    return (\\n        vOutside(p[0], lo[0], hi[0]) ||\\n        vOutside(p[1], lo[1], hi[1]) ||\\n        vOutside(p[2], lo[2], hi[2]) ||\\n        vOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool outsideBoundingBox(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    return mOutside(A, loA, hiA) ||\\n           mOutside(B, loB, hiB) ||\\n           mOutside(C, loC, hiC) ||\\n           mOutside(D, loD, hiD);\\n}\\n\\nbool outsideRasterMask(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    mat4 pnts[4];\\n    pnts[0] = A;\\n    pnts[1] = B;\\n    pnts[2] = C;\\n    pnts[3] = D;\\n\\n    for(int i = 0; i < 4; ++i) {\\n        for(int j = 0; j < 4; ++j) {\\n            for(int k = 0; k < 4; ++k) {\\n                if(0 == iMod(\\n                    int(255.0 * texture2D(mask,\\n                        vec2(\\n                            (float(i * 2 + j / 2) + 0.5) / 8.0,\\n                            (pnts[i][j][k] * (maskHeight - 1.0) + 1.0) / maskHeight\\n                        ))[3]\\n                    ) / int(pow(2.0, float(iMod(j * 4 + k, 8)))),\\n                    2\\n                )) return true;\\n            }\\n        }\\n    }\\n    return false;\\n}\\n\\nvec4 position(bool isContext, float v, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float x = 0.5 * sign(v) + 0.5;\\n    float y = axisY(x, A, B, C, D);\\n    float z = 1.0 - abs(v);\\n\\n    z += isContext ? 0.0 : 2.0 * float(\\n        outsideBoundingBox(A, B, C, D) ||\\n        outsideRasterMask(A, B, C, D)\\n    );\\n\\n    return vec4(\\n        2.0 * (vec2(x, y) * viewBoxSize + viewBoxPos) / resolution - 1.0,\\n        z,\\n        1.0\\n    );\\n}\\n\\nvoid main() {\\n    mat4 A = mat4(p01_04, p05_08, p09_12, p13_16);\\n    mat4 B = mat4(p17_20, p21_24, p25_28, p29_32);\\n    mat4 C = mat4(p33_36, p37_40, p41_44, p45_48);\\n    mat4 D = mat4(p49_52, p53_56, p57_60, ZEROS);\\n\\n    float v = colors[3];\\n\\n    gl_Position = position(isContext, v, A, B, C, D);\\n\\n    fragColor =\\n        isContext ? vec4(contextColor) :\\n        isPick ? vec4(colors.rgb, 1.0) : texture2D(palette, vec2(abs(v), 0.5));\\n}\\n\"]),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n    gl_FragColor = fragColor;\\n}\\n\"]),o=t(\"./constants\").maxDimensionCount,s=t(\"../../lib\"),l=1e-6,c=2048,u=new Uint8Array(4),h=new Uint8Array(4),f={shape:[256,1],format:\"rgba\",type:\"uint8\",mag:\"nearest\",min:\"nearest\"};function p(t,e,r,n,i){var a=t._gl;a.enable(a.SCISSOR_TEST),a.scissor(e,r,n,i),t.clear({color:[0,0,0,0],depth:1})}function d(t,e,r,n,i,a){var o=a.key;r.drawCompleted||(!function(t){t.read({x:0,y:0,width:1,height:1,data:u})}(t),r.drawCompleted=!0),function s(l){var c=Math.min(n,i-l*n);0===l&&(window.cancelAnimationFrame(r.currentRafs[o]),delete r.currentRafs[o],p(t,a.scissorX,a.scissorY,a.scissorWidth,a.viewBoxSize[1])),r.clearOnly||(a.count=2*c,a.offset=2*l*n,e(a),l*n+c<i&&(r.currentRafs[o]=window.requestAnimationFrame(function(){s(l+1)})),r.drawCompleted=!1)}(0)}function g(t,e){return(t>>>8*e)%256/255}function v(t,e,r){for(var n=new Array(8*e),i=0,a=0;a<e;a++)for(var o=0;o<2;o++)for(var s=0;s<4;s++){var l=4*t+s,c=r[64*a+l];63===l&&0===o&&(c*=-1),n[i++]=c}return n}function m(t){var e=\"0\"+t;return e.substr(e.length-2)}function y(t){return t<o?\"p\"+m(t+1)+\"_\"+m(t+4):\"colors\"}function x(t,e,r,n,i,a,o,l,c,u,h,f,p){for(var d=[[],[]],g=0;g<64;g++)d[0][g]=g===i?1:0,d[1][g]=g===a?1:0;var v=t.lines.canvasOverdrag,m=t.domain,y=t.canvasWidth,x=t.canvasHeight,b=t.deselectedLines.color;return s.extendFlat({key:h,resolution:[y,x],viewBoxPos:[o+v,l],viewBoxSize:[c,u],i0:i,i1:a,dim0A:d[0].slice(0,16),dim0B:d[0].slice(16,32),dim0C:d[0].slice(32,48),dim0D:d[0].slice(48,64),dim1A:d[1].slice(0,16),dim1B:d[1].slice(16,32),dim1C:d[1].slice(32,48),dim1D:d[1].slice(48,64),drwLayer:f,contextColor:[b[0]/255,b[1]/255,b[2]/255,b[3]<1?b[3]:Math.max(1/255,Math.pow(1/t.lines.color.length,1/3))],scissorX:(n===e?0:o+v)+(t.pad.l-v)+t.layoutWidth*m.x[0],scissorWidth:(n===r?y-o+v:c+.5)+(n===e?o+v:0),scissorY:l+t.pad.b+t.layoutHeight*m.y[0],scissorHeight:u,viewportX:t.pad.l-v+t.layoutWidth*m.x[0],viewportY:t.pad.b+t.layoutHeight*m.y[0],viewportWidth:y,viewportHeight:x},p)}function b(t){var e=c-1,r=Math.max(0,Math.floor(t[0]*e),0),n=Math.min(e,Math.ceil(t[1]*e),e);return[Math.min(r,n),Math.max(r,n)]}e.exports=function(t,e){var r,n,u,m,_,w=e.context,k=e.pick,T=e.regl,A={currentRafs:{},drawCompleted:!0,clearOnly:!1},M=function(t){for(var e={},r=0;r<=o;r+=4)e[y(r)]=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)});return e}(T),S=T.texture(f),E=[];L(e);var C=T({profile:!1,blend:{enable:w,func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:1,dstAlpha:1},equation:{rgb:\"add\",alpha:\"add\"},color:[0,0,0,0]},depth:{enable:!w,mask:!0,func:\"less\",range:[0,1]},cull:{enable:!0,face:\"back\"},scissor:{enable:!0,box:{x:T.prop(\"scissorX\"),y:T.prop(\"scissorY\"),width:T.prop(\"scissorWidth\"),height:T.prop(\"scissorHeight\")}},viewport:{x:T.prop(\"viewportX\"),y:T.prop(\"viewportY\"),width:T.prop(\"viewportWidth\"),height:T.prop(\"viewportHeight\")},dither:!1,vert:i,frag:a,primitive:\"lines\",lineWidth:1,attributes:M,uniforms:{resolution:T.prop(\"resolution\"),viewBoxPos:T.prop(\"viewBoxPos\"),viewBoxSize:T.prop(\"viewBoxSize\"),dim0A:T.prop(\"dim0A\"),dim1A:T.prop(\"dim1A\"),dim0B:T.prop(\"dim0B\"),dim1B:T.prop(\"dim1B\"),dim0C:T.prop(\"dim0C\"),dim1C:T.prop(\"dim1C\"),dim0D:T.prop(\"dim0D\"),dim1D:T.prop(\"dim1D\"),loA:T.prop(\"loA\"),hiA:T.prop(\"hiA\"),loB:T.prop(\"loB\"),hiB:T.prop(\"hiB\"),loC:T.prop(\"loC\"),hiC:T.prop(\"hiC\"),loD:T.prop(\"loD\"),hiD:T.prop(\"hiD\"),palette:S,contextColor:T.prop(\"contextColor\"),mask:T.prop(\"maskTexture\"),drwLayer:T.prop(\"drwLayer\"),maskHeight:T.prop(\"maskHeight\")},offset:T.prop(\"offset\"),count:T.prop(\"count\")});function L(t){r=t.model,n=t.viewModel,u=n.dimensions.slice(),m=u[0]?u[0].values.length:0;var e=r.lines,i=k?e.color.map(function(t,r){return r/e.color.length}):e.color,a=function(t,e,r){for(var n,i=new Array(t*(o+4)),a=0,s=0;s<t;s++){for(var c=0;c<o;c++)i[a++]=c<e.length?e[c].paddedUnitValues[s]:.5;i[a++]=g(s,2),i[a++]=g(s,1),i[a++]=g(s,0),i[a++]=(n=r[s],Math.max(l,Math.min(1-l,n)))}return i}(m,u,i);!function(t,e,r){for(var n=0;n<=o;n+=4)t[y(n)](v(n/4,e,r))}(M,m,a),w||k||(S=T.texture(s.extendFlat({data:function(t,e){for(var r=new Array(256),n=0;n<256;n++)r[n]=t(n/255).concat(e);return r}(r.unitToColor,255)},f)))}return{render:function(t,e,n){var i,a,o,s=t.length,l=1/0,h=-1/0;for(i=0;i<s;i++)t[i].dim0.canvasX<l&&(l=t[i].dim0.canvasX,a=i),t[i].dim1.canvasX>h&&(h=t[i].dim1.canvasX,o=i);0===s&&p(T,0,0,r.canvasWidth,r.canvasHeight);var f=function(t){var e,r,n,i=[[],[]];for(n=0;n<64;n++){var a=!t&&n<u.length?u[n].brush.filter.getBounds():[-1/0,1/0];i[0][n]=a[0],i[1][n]=a[1]}var o=8*c,s=new Array(o);for(e=0;e<o;e++)s[e]=255;if(!t)for(e=0;e<u.length;e++){var l=e%8,h=(e-l)/8,f=Math.pow(2,l),p=u[e].brush.filter.get();if(!(p.length<2)){var d=b(p[0])[1];for(r=1;r<p.length;r++){var g=b(p[r]);for(n=d+1;n<g[0];n++)s[8*n+h]&=~f;d=Math.max(d,g[1])}}}var v={shape:[8,c],format:\"alpha\",type:\"uint8\",mag:\"nearest\",min:\"nearest\",data:s};return _?_(v):_=T.texture(v),{maskTexture:_,maskHeight:c,loA:i[0].slice(0,16),loB:i[0].slice(16,32),loC:i[0].slice(32,48),loD:i[0].slice(48,64),hiA:i[1].slice(0,16),hiB:i[1].slice(16,32),hiC:i[1].slice(32,48),hiD:i[1].slice(48,64)}}(w);for(i=0;i<s;i++){var g=t[i],v=g.dim0.crossfilterDimensionIndex,y=g.dim1.crossfilterDimensionIndex,M=g.canvasX,S=g.canvasY,L=M+g.panelSizeX;if(e||!E[v]||E[v][0]!==M||E[v][1]!==L){E[v]=[M,L];var P=x(r,a,o,i,v,y,M,S,g.panelSizeX,g.panelSizeY,g.dim0.crossfilterDimensionIndex,w?0:k?2:1,f);A.clearOnly=n;var O=e?r.lines.blockLineCount:m;d(T,C,A,O,m,P)}}},readPixel:function(t,e){return T.read({x:t,y:e,width:1,height:1,data:h}),h},readPixels:function(t,e,r,n){var i=new Uint8Array(4*r*n);return T.read({x:t,y:e,width:r,height:n,data:i}),i},destroy:function(){for(var e in t.style[\"pointer-events\"]=\"none\",S.destroy(),_&&_.destroy(),M)M[e].destroy()},update:L}}},{\"../../lib\":719,\"./constants\":1078,glslify:409}],1083:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a;for(n||(n=1/0),i=0;i<e.length;i++)(a=e[i]).visible&&(n=Math.min(n,a[r].length));for(n===1/0&&(n=0),t._length=n,i=0;i<e.length;i++)(a=e[i]).visible&&(a._length=n);return n}},{}],1084:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"color-rgba\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../components/drawing\"),c=t(\"../../components/colorscale\"),u=t(\"../../lib/gup\"),h=u.keyFun,f=u.repeat,p=u.unwrap,d=t(\"./helpers\"),g=t(\"./constants\"),v=t(\"./axisbrush\"),m=t(\"./lines\");function y(t,e,r){return o.aggNums(t,null,e,r)}function x(t,e){return _(y(Math.min,t,e),y(Math.max,t,e))}function b(t){var e=t.range;return e?_(e[0],e[1]):x(t.values,t._length)}function _(t,e){return!isNaN(t)&&isFinite(t)||(t=0),!isNaN(e)&&isFinite(e)||(e=0),t===e&&(0===t?(t-=1,e+=1):(t*=.9,e*=1.1)),[t,e]}function w(t){return t.dimensions.some(function(t){return t.brush.filterSpecified})}function k(t,e,r){var a=p(e),s=a.trace,l=d.convertTypedArray(a.lineColor),u=s.line,h={color:i(g.deselectedLineColor)},f=c.extractOpts(u),v=f.reversescale?c.flipScale(a.cscale):a.cscale,m=s.domain,y=s.dimensions,x=t.width,_=s.labelangle,w=s.labelside,k=s.labelfont,T=s.tickfont,A=s.rangefont,M=o.extendDeepNoArrays({},u,{color:l.map(n.scale.linear().domain(b({values:l,range:[f.min,f.max],_length:s._length}))),blockLineCount:g.blockLineCount,canvasOverdrag:g.overdrag*g.canvasPixelRatio}),S=Math.floor(x*(m.x[1]-m.x[0])),E=Math.floor(t.height*(m.y[1]-m.y[0])),C=t.margin||{l:80,r:80,t:100,b:80},L=S,P=E;return{key:r,colCount:y.filter(d.isVisible).length,dimensions:y,tickDistance:g.tickDistance,unitToColor:function(t){var e=t.map(function(t){return t[0]}),r=t.map(function(t){var e=i(t[1]);return n.rgb(\"rgb(\"+e[0]+\",\"+e[1]+\",\"+e[2]+\")\")}),a=\"rgb\".split(\"\").map(function(t){return n.scale.linear().clamp(!0).domain(e).range(r.map((i=t,function(t){return t[i]})));var i});return function(t){return a.map(function(e){return e(t)})}}(v),lines:M,deselectedLines:h,labelAngle:_,labelSide:w,labelFont:k,tickFont:T,rangeFont:A,layoutWidth:x,layoutHeight:t.height,domain:m,translateX:m.x[0]*x,translateY:t.height-m.y[1]*t.height,pad:C,canvasWidth:L*g.canvasPixelRatio+2*M.canvasOverdrag,canvasHeight:P*g.canvasPixelRatio,width:L,height:P,canvasPixelRatio:g.canvasPixelRatio}}function T(t,e,r){var i=r.width,a=r.height,s=r.dimensions,l=r.canvasPixelRatio,c=function(t){return i*t/Math.max(1,r.colCount-1)},u=g.verticalPadding/a,h=function(t,e){return n.scale.linear().range([e,t-e])}(a,g.verticalPadding),f={key:r.key,xScale:c,model:r,inBrushDrag:!1},p={};return f.dimensions=s.filter(d.isVisible).map(function(i,s){var m=function(t,e){return n.scale.linear().domain(b(t)).range([e,1-e])}(i,u),y=p[i.label];p[i.label]=(y||0)+1;var x=i.label+(y?\"__\"+y:\"\"),_=i.constraintrange,k=_&&_.length;k&&!Array.isArray(_[0])&&(_=[_]);var T=k?_.map(function(t){return t.map(m)}):[[-1/0,1/0]],A=i.values;A.length>i._length&&(A=A.slice(0,i._length));var M,S=i.tickvals;function E(t,e){return{val:t,text:M[e]}}function C(t,e){return t.val-e.val}if(Array.isArray(S)&&S.length){M=i.ticktext,Array.isArray(M)&&M.length?M.length>S.length?M=M.slice(0,S.length):S.length>M.length&&(S=S.slice(0,M.length)):M=S.map(n.format(i.tickformat));for(var L=1;L<S.length;L++)if(S[L]<S[L-1]){for(var P=S.map(E).sort(C),O=0;O<S.length;O++)S[O]=P[O].val,M[O]=P[O].text;break}}else S=void 0;return A=d.convertTypedArray(A),A=d.convertTypedArray(A),{key:x,label:i.label,tickFormat:i.tickformat,tickvals:S,ticktext:M,ordinal:d.isOrdinal(i),multiselect:i.multiselect,xIndex:s,crossfilterDimensionIndex:s,visibleIndex:i._index,height:a,values:A,paddedUnitValues:A.map(m),unitTickvals:S&&S.map(m),xScale:c,x:c(s),canvasX:c(s)*l,unitToPaddedPx:h,domainScale:function(t,e,r,i,a){var o,s,l=b(r);return i?n.scale.ordinal().domain(i.map((o=n.format(r.tickformat),s=a,s?function(t,e){var r=s[e];return null==r?o(t):r}:o))).range(i.map(function(r){var n=(r-l[0])/(l[1]-l[0]);return t-e+n*(2*e-t)})):n.scale.linear().domain(l).range([t-e,e])}(a,g.verticalPadding,i,S,M),ordinalScale:function(t){if(t.tickvals){var e=b(t);return n.scale.ordinal().domain(t.tickvals).range(t.tickvals.map(function(t){return(t-e[0])/(e[1]-e[0])}))}}(i),parent:f,model:r,brush:v.makeBrush(t,k,T,function(){t.linePickActive(!1)},function(){var e=f;e.focusLayer&&e.focusLayer.render(e.panels,!0);var r=w(e);!t.contextShown()&&r?(e.contextLayer&&e.contextLayer.render(e.panels,!0),t.contextShown(!0)):t.contextShown()&&!r&&(e.contextLayer&&e.contextLayer.render(e.panels,!0,!0),t.contextShown(!1))},function(r){if(f.focusLayer.render(f.panels,!0),f.pickLayer&&f.pickLayer.render(f.panels,!0),t.linePickActive(!0),e&&e.filterChanged){var n=m.invert,a=r.map(function(t){return t.map(n).sort(o.sorterAsc)}).sort(function(t,e){return t[0]-e[0]});e.filterChanged(f.key,i._index,a)}})}}),f}function A(t){t.classed(g.cn.axisExtentText,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"default\").style(\"user-select\",\"none\")}function M(t,e){var r=\"top\"===e?1:-1,n=t*Math.PI/180;return{dir:r,dx:Math.sin(n),dy:Math.cos(n),degrees:t}}function S(t,e){for(var r=e.panels||(e.panels=[]),n=t.data(),i=0;i<n.length-1;i++){var a=r[i]||(r[i]={}),o=n[i],s=n[i+1];a.dim0=o,a.dim1=s,a.canvasX=o.canvasX,a.panelSizeX=s.canvasX-o.canvasX,a.panelSizeY=e.model.canvasHeight,a.y=0,a.canvasY=0}}function E(t,e){return a.tickText(t._ax,e,!1).text}function C(t,e){if(t.ordinal)return\"\";var r=t.domainScale.domain(),n=r[e?r.length-1:0];return E(t.model.dimensions[t.visibleIndex],n)}e.exports=function(t,e,r,i){var c=t._fullLayout,u=c._toppaper,y=c._glcontainer;!function(t){for(var e=0;e<t.length;e++)for(var r=0;r<t[e].length;r++)for(var n=t[e][r].trace,i=n.dimensions,o=0;o<i.length;o++){var s=i[o].values,l=i[o]._ax;l&&(l.range?l.range=_(l.range[0],l.range[1]):l.range=x(s,n._length),l.dtick||(l.dtick=.01*(Math.abs(l.range[1]-l.range[0])||1)),l.tickformat=i[o].tickformat,a.calcTicks(l),l.cleanRange())}}(e);var b,L,P=(b=!0,L=!1,{linePickActive:function(t){return arguments.length?b=!!t:b},contextShown:function(t){return arguments.length?L=!!t:L}}),O=e.filter(function(t){return p(t).trace.visible}).map(k.bind(0,r)).map(T.bind(0,P,i));y.each(function(t,e){return o.extendFlat(t,O[e])});var z=y.selectAll(\".gl-canvas\").each(function(t){t.viewModel=O[0],t.model=t.viewModel?t.viewModel.model:null}),I=null;z.filter(function(t){return t.pick}).style(\"pointer-events\",\"auto\").on(\"mousemove\",function(t){if(P.linePickActive()&&t.lineLayer&&i&&i.hover){var e=n.event,r=this.width,a=this.height,o=n.mouse(this),s=o[0],l=o[1];if(s<0||l<0||s>=r||l>=a)return;var c=t.lineLayer.readPixel(s,a-1-l),u=0!==c[3],h=u?c[2]+256*(c[1]+256*c[0]):null,f={x:s,y:l,clientX:e.clientX,clientY:e.clientY,dataIndex:t.model.key,curveNumber:h};h!==I&&(u?i.hover(f):i.unhover&&i.unhover(f),I=h)}}),z.style(\"opacity\",function(t){return t.pick?0:1}),u.style(\"background\",\"rgba(255, 255, 255, 0)\");var D=u.selectAll(\".\"+g.cn.parcoords).data(O,h);D.exit().remove(),D.enter().append(\"g\").classed(g.cn.parcoords,!0).style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"none\"),D.attr(\"transform\",function(t){return\"translate(\"+t.model.translateX+\",\"+t.model.translateY+\")\"});var R=D.selectAll(\".\"+g.cn.parcoordsControlView).data(f,h);R.enter().append(\"g\").classed(g.cn.parcoordsControlView,!0),R.attr(\"transform\",function(t){return\"translate(\"+t.model.pad.l+\",\"+t.model.pad.t+\")\"});var F=R.selectAll(\".\"+g.cn.yAxis).data(function(t){return t.dimensions},h);F.enter().append(\"g\").classed(g.cn.yAxis,!0),R.each(function(t){S(F,t)}),z.each(function(t){if(t.viewModel){!t.lineLayer||i?t.lineLayer=m(this,t):t.lineLayer.update(t),(t.key||0===t.key)&&(t.viewModel[t.key]=t.lineLayer);var e=!t.context||i;t.lineLayer.render(t.viewModel.panels,e)}}),F.attr(\"transform\",function(t){return\"translate(\"+t.xScale(t.xIndex)+\", 0)\"}),F.call(n.behavior.drag().origin(function(t){return t}).on(\"drag\",function(t){var e=t.parent;P.linePickActive(!1),t.x=Math.max(-g.overdrag,Math.min(t.model.width+g.overdrag,n.event.x)),t.canvasX=t.x*t.model.canvasPixelRatio,F.sort(function(t,e){return t.x-e.x}).each(function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e.xIndex),e.canvasX=e.x*e.model.canvasPixelRatio}),S(F,e),F.filter(function(e){return 0!==Math.abs(t.xIndex-e.xIndex)}).attr(\"transform\",function(t){return\"translate(\"+t.xScale(t.xIndex)+\", 0)\"}),n.select(this).attr(\"transform\",\"translate(\"+t.x+\", 0)\"),F.each(function(r,n,i){i===t.parent.key&&(e.dimensions[n]=r)}),e.contextLayer&&e.contextLayer.render(e.panels,!1,!w(e)),e.focusLayer.render&&e.focusLayer.render(e.panels)}).on(\"dragend\",function(t){var e=t.parent;t.x=t.xScale(t.xIndex),t.canvasX=t.x*t.model.canvasPixelRatio,S(F,e),n.select(this).attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),e.contextLayer&&e.contextLayer.render(e.panels,!1,!w(e)),e.focusLayer&&e.focusLayer.render(e.panels),e.pickLayer&&e.pickLayer.render(e.panels,!0),P.linePickActive(!0),i&&i.axesMoved&&i.axesMoved(e.key,e.dimensions.map(function(t){return t.crossfilterDimensionIndex}))})),F.exit().remove();var B=F.selectAll(\".\"+g.cn.axisOverlays).data(f,h);B.enter().append(\"g\").classed(g.cn.axisOverlays,!0),B.selectAll(\".\"+g.cn.axis).remove();var N=B.selectAll(\".\"+g.cn.axis).data(f,h);N.enter().append(\"g\").classed(g.cn.axis,!0),N.each(function(t){var e=t.model.height/t.model.tickDistance,r=t.domainScale,i=r.domain();n.select(this).call(n.svg.axis().orient(\"left\").tickSize(4).outerTickSize(2).ticks(e,t.tickFormat).tickValues(t.ordinal?i:null).tickFormat(function(e){return d.isOrdinal(t)?e:E(t.model.dimensions[t.visibleIndex],e)}).scale(r)),l.font(N.selectAll(\"text\"),t.model.tickFont)}),N.selectAll(\".domain, .tick>line\").attr(\"fill\",\"none\").attr(\"stroke\",\"black\").attr(\"stroke-opacity\",.25).attr(\"stroke-width\",\"1px\"),N.selectAll(\"text\").style(\"text-shadow\",\"1px 1px 1px #fff, -1px -1px 1px #fff, 1px -1px 1px #fff, -1px 1px 1px #fff\").style(\"cursor\",\"default\").style(\"user-select\",\"none\");var j=B.selectAll(\".\"+g.cn.axisHeading).data(f,h);j.enter().append(\"g\").classed(g.cn.axisHeading,!0);var U=j.selectAll(\".\"+g.cn.axisTitle).data(f,h);U.enter().append(\"text\").classed(g.cn.axisTitle,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"ew-resize\").style(\"user-select\",\"none\").style(\"pointer-events\",\"auto\"),U.text(function(t){return t.label}).each(function(e){var r=n.select(this);l.font(r,e.model.labelFont),s.convertToTspans(r,t)}).attr(\"transform\",function(t){var e=M(t.model.labelAngle,t.model.labelSide),r=g.axisTitleOffset;return(e.dir>0?\"\":\"translate(0,\"+(2*r+t.model.height)+\")\")+\"rotate(\"+e.degrees+\")translate(\"+-r*e.dx+\",\"+-r*e.dy+\")\"}).attr(\"text-anchor\",function(t){var e=M(t.model.labelAngle,t.model.labelSide);return 2*Math.abs(e.dx)>Math.abs(e.dy)?e.dir*e.dx<0?\"start\":\"end\":\"middle\"});var V=B.selectAll(\".\"+g.cn.axisExtent).data(f,h);V.enter().append(\"g\").classed(g.cn.axisExtent,!0);var q=V.selectAll(\".\"+g.cn.axisExtentTop).data(f,h);q.enter().append(\"g\").classed(g.cn.axisExtentTop,!0),q.attr(\"transform\",\"translate(0,\"+-g.axisExtentOffset+\")\");var H=q.selectAll(\".\"+g.cn.axisExtentTopText).data(f,h);H.enter().append(\"text\").classed(g.cn.axisExtentTopText,!0).call(A),H.text(function(t){return C(t,!0)}).each(function(t){l.font(n.select(this),t.model.rangeFont)});var G=V.selectAll(\".\"+g.cn.axisExtentBottom).data(f,h);G.enter().append(\"g\").classed(g.cn.axisExtentBottom,!0),G.attr(\"transform\",function(t){return\"translate(0,\"+(t.model.height+g.axisExtentOffset)+\")\"});var Y=G.selectAll(\".\"+g.cn.axisExtentBottomText).data(f,h);Y.enter().append(\"text\").classed(g.cn.axisExtentBottomText,!0).attr(\"dy\",\"0.75em\").call(A),Y.text(function(t){return C(t,!1)}).each(function(t){l.font(n.select(this),t.model.rangeFont)}),v.ensureAxisBrush(B)}},{\"../../components/colorscale\":605,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/gup\":717,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"./axisbrush\":1075,\"./constants\":1078,\"./helpers\":1080,\"./lines\":1082,\"color-rgba\":122,d3:163}],1085:[function(t,e,r){\"use strict\";var n=t(\"./parcoords\"),i=t(\"../../lib/prepare_regl\"),a=t(\"./helpers\").isVisible;function o(t,e,r){var n=e.indexOf(r),i=t.indexOf(n);return-1===i&&(i+=e.length),i}e.exports=function(t,e){var r=t._fullLayout;if(i(t)){var s={},l={},c={},u={},h=r._size;e.forEach(function(e,r){var n=e[0].trace;c[r]=n.index;var i=u[r]=n._fullInput.index;s[r]=t.data[i].dimensions,l[r]=t.data[i].dimensions.slice()});n(t,e,{width:h.w,height:h.h,margin:{t:h.t,r:h.r,b:h.b,l:h.l}},{filterChanged:function(e,n,i){var a=l[e][n],o=i.map(function(t){return t.slice()}),s=\"dimensions[\"+n+\"].constraintrange\",h=r._tracePreGUI[t._fullData[c[e]]._fullInput.uid];if(void 0===h[s]){var f=a.constraintrange;h[s]=f||null}var p=t._fullData[c[e]].dimensions[n];o.length?(1===o.length&&(o=o[0]),a.constraintrange=o,p.constraintrange=o.slice(),o=[o]):(delete a.constraintrange,delete p.constraintrange,o=null);var d={};d[s]=o,t.emit(\"plotly_restyle\",[d,[u[e]]])},hover:function(e){t.emit(\"plotly_hover\",e)},unhover:function(e){t.emit(\"plotly_unhover\",e)},axesMoved:function(e,r){var n=function(t,e){return function(r,n){return o(t,e,r)-o(t,e,n)}}(r,l[e].filter(a));s[e].sort(n),l[e].filter(function(t){return!a(t)}).sort(function(t){return l[e].indexOf(t)}).forEach(function(t){s[e].splice(s[e].indexOf(t),1),s[e].splice(l[e].indexOf(t),0,t)}),t.emit(\"plotly_restyle\",[{dimensions:[s[e]]},[u[e]]])}})}}},{\"../../lib/prepare_regl\":732,\"./helpers\":1080,\"./parcoords\":1084}],1086:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../plots/domain\").attributes,a=t(\"../../plots/font_attributes\"),o=t(\"../../components/color/attributes\"),s=t(\"../../components/fx/hovertemplate_attributes\"),l=t(\"../../lib/extend\").extendFlat,c=a({editType:\"plot\",arrayOk:!0,colorEditType:\"plot\"});e.exports={labels:{valType:\"data_array\",editType:\"calc\"},label0:{valType:\"number\",dflt:0,editType:\"calc\"},dlabel:{valType:\"number\",dflt:1,editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},marker:{colors:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:o.defaultLine,arrayOk:!0,editType:\"style\"},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0,editType:\"style\"},editType:\"calc\"},editType:\"calc\"},text:{valType:\"data_array\",editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"value\",\"percent\"],extras:[\"none\"],editType:\"calc\"},hoverinfo:l({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:s({},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"auto\",arrayOk:!0,editType:\"plot\"},textfont:l({},c,{}),insidetextfont:l({},c,{}),outsidetextfont:l({},c,{}),title:{text:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:l({},c,{}),position:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"plot\"},editType:\"plot\"},domain:i({name:\"pie\",trace:!0,editType:\"calc\"}),hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},sort:{valType:\"boolean\",dflt:!0,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"number\",min:-360,max:360,dflt:0,editType:\"calc\"},pull:{valType:\"number\",min:0,max:1,dflt:0,arrayOk:!0,editType:\"calc\"},_deprecated:{title:{valType:\"string\",dflt:\"\",editType:\"calc\"},titlefont:l({},c,{}),titleposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"calc\"}}}},{\"../../components/color/attributes\":592,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1087:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData;r.name=\"pie\",r.plot=function(t){var e=n.getModule(\"pie\"),r=i(t.calcdata,e)[0];e.plot(t,r)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"pie\"),a=e._has&&e._has(\"pie\");i&&!a&&n._pielayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],1088:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"tinycolor2\"),o=t(\"../../components/color\"),s=t(\"./helpers\"),l=t(\"../../lib\").isValidTextValue,c={};function u(t){return function(e,r){return!!e&&(!!(e=a(e)).isValid()&&(e=o.addOpacity(e,e.getAlpha()),t[r]||(t[r]=e),e))}}function h(t,e){var r,n=JSON.stringify(t),i=e[n];if(!i){for(i=t.slice(),r=0;r<t.length;r++)i.push(a(t[r]).lighten(20).toHexString());for(r=0;r<t.length;r++)i.push(a(t[r]).darken(20).toHexString());e[n]=i}return i}e.exports={calc:function(t,e){var r,a,o=[],c=t._fullLayout,h=c.hiddenlabels||[],f=e.labels,p=e.marker.colors||[],d=e.values,g=i(d)&&d.length;if(e.dlabel)for(f=new Array(d.length),r=0;r<d.length;r++)f[r]=String(e.label0+r*e.dlabel);var v={},m=u(c[\"_\"+e.type+\"colormap\"]),y=(g?d:f).length,x=0,b=!1;for(r=0;r<y;r++){var _,w,k;if(g){if(_=d[r],!n(_))continue;if((_=+_)<0)continue}else _=1;void 0!==(w=f[r])&&\"\"!==w||(w=r);var T=v[w=String(w)];void 0===T?(v[w]=o.length,(k=-1!==h.indexOf(w))||(x+=_),o.push({v:_,label:w,color:m(p[r],w),i:r,pts:[r],hidden:k})):(b=!0,(a=o[T]).v+=_,a.pts.push(r),a.hidden||(x+=_),!1===a.color&&p[r]&&(a.color=m(p[r],w)))}(\"funnelarea\"===e.type?b:e.sort)&&o.sort(function(t,e){return e.v-t.v}),o[0]&&(o[0].vTotal=x);var A=e.textinfo;if(A&&\"none\"!==A){var M,S=A.split(\"+\"),E=function(t){return-1!==S.indexOf(t)},C=E(\"label\"),L=E(\"text\"),P=E(\"value\"),O=E(\"percent\"),z=c.separators;for(r=0;r<o.length;r++){if(a=o[r],M=C?[a.label]:[],L){var I=s.getFirstFilled(e.text,a.pts);l(I)&&M.push(I)}P&&M.push(s.formatPieValue(a.v,z)),O&&M.push(s.formatPiePercent(a.v/x,z)),a.text=M.join(\"<br>\")}}return o},crossTraceCalc:function(t,e){var r=(e||{}).type;r||(r=\"pie\");var n=t._fullLayout,i=t.calcdata,a=n[r+\"colorway\"],o=n[\"_\"+r+\"colormap\"];n[\"extend\"+r+\"colors\"]&&(a=h(a,c));for(var s=0,l=0;l<i.length;l++){var u=i[l];if(u[0].trace.type===r)for(var f=0;f<u.length;f++){var p=u[f];!1===p.color&&(o[p.label]?p.color=o[p.label]:(o[p.label]=p.color=a[s%a.length],s++))}}},makePullColorFn:u,generateExtendedColors:h}},{\"../../components/color\":593,\"../../lib\":719,\"./helpers\":1091,\"fast-isnumeric\":225,tinycolor2:537}],1089:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}var c,u=l(\"values\"),h=n.isArrayOrTypedArray(u),f=l(\"labels\");if(Array.isArray(f)?(c=f.length,h&&(c=Math.min(c,u.length))):h&&(c=u.length,l(\"label0\"),l(\"dlabel\")),c){e._length=c,l(\"marker.line.width\")&&l(\"marker.line.color\"),l(\"marker.colors\"),l(\"scalegroup\");var p=l(\"text\"),d=l(\"textinfo\",Array.isArray(p)?\"text+percent\":\"percent\");if(l(\"hovertext\"),l(\"hovertemplate\"),d&&\"none\"!==d){var g=l(\"textposition\");o(t,e,s,l,g,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}a(e,s,l);var v=l(\"hole\");if(l(\"title.text\")){var m=l(\"title.position\",v?\"middle center\":\"top center\");v||\"middle center\"!==m||(e.title.position=\"top center\"),n.coerceFont(l,\"title.font\",s.font)}l(\"sort\"),l(\"direction\"),l(\"rotation\"),l(\"pull\")}else e.visible=!1}},{\"../../lib\":719,\"../../plots/domain\":792,\"../bar/defaults\":861,\"./attributes\":1086}],1090:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/helpers\").appendArrayMultiPointValues;e.exports=function(t,e){var r={curveNumber:e.index,pointNumbers:t.pts,data:e._input,fullData:e,label:t.label,color:t.color,value:t.v,percent:t.percent,text:t.text,v:t.v};return 1===t.pts.length&&(r.pointNumber=r.i=t.pts[0]),n(r,e,t.pts),\"funnelarea\"===e.type&&(delete r.v,delete r.i),r}},{\"../../components/fx/helpers\":628}],1091:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");r.formatPiePercent=function(t,e){var r=(100*t).toPrecision(3);return-1!==r.lastIndexOf(\".\")&&(r=r.replace(/[.]?0+$/,\"\")),n.numSeparate(r,e)+\"%\"},r.formatPieValue=function(t,e){var r=t.toPrecision(10);return-1!==r.lastIndexOf(\".\")&&(r=r.replace(/[.]?0+$/,\"\")),n.numSeparate(r,e)},r.getFirstFilled=function(t,e){if(Array.isArray(t))for(var r=0;r<e.length;r++){var n=t[e[r]];if(n||0===n)return n}},r.castOption=function(t,e){return Array.isArray(t)?r.getFirstFilled(t,e):t||void 0}},{\"../../lib\":719}],1092:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),layoutAttributes:t(\"./layout_attributes\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\"),styleOne:t(\"./style_one\"),moduleType:\"trace\",name:\"pie\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"pie\",\"showLegend\"],meta:{}}},{\"./attributes\":1086,\"./base_plot\":1087,\"./calc\":1088,\"./defaults\":1089,\"./layout_attributes\":1093,\"./layout_defaults\":1094,\"./plot\":1095,\"./style\":1096,\"./style_one\":1097}],1093:[function(t,e,r){\"use strict\";e.exports={hiddenlabels:{valType:\"data_array\",editType:\"calc\"},piecolorway:{valType:\"colorlist\",editType:\"calc\"},extendpiecolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1094:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"piecolorway\",e.colorway),r(\"extendpiecolors\")}},{\"../../lib\":719,\"./layout_attributes\":1093}],1095:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/fx\"),a=t(\"../../components/color\"),o=t(\"../../components/drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"./helpers\"),u=t(\"./event_data\");function h(t,e,r){var a=r[0],o=a.trace,l=a.cx,h=a.cy;\"_hasHoverLabel\"in o||(o._hasHoverLabel=!1),\"_hasHoverEvent\"in o||(o._hasHoverEvent=!1),t.on(\"mouseover\",function(t){var r=e._fullLayout,f=e._fullData[o.index];if(!e._dragging&&!1!==r.hovermode){var p=f.hoverinfo;if(Array.isArray(p)&&(p=i.castHoverinfo({hoverinfo:[c.castOption(p,t.pts)],_module:o._module},r,0)),\"all\"===p&&(p=\"label+text+value+percent+name\"),f.hovertemplate||\"none\"!==p&&\"skip\"!==p&&p){var d=t.rInscribed||0,g=l+t.pxmid[0]*(1-d),v=h+t.pxmid[1]*(1-d),m=r.separators,y=[];if(p&&-1!==p.indexOf(\"label\")&&y.push(t.label),t.text=c.castOption(f.hovertext||f.text,t.pts),p&&-1!==p.indexOf(\"text\")){var x=t.text;s.isValidTextValue(x)&&y.push(x)}t.value=t.v,t.valueLabel=c.formatPieValue(t.v,m),p&&-1!==p.indexOf(\"value\")&&y.push(t.valueLabel),t.percent=t.v/a.vTotal,t.percentLabel=c.formatPiePercent(t.percent,m),p&&-1!==p.indexOf(\"percent\")&&y.push(t.percentLabel);var b=f.hoverlabel,_=b.font;i.loneHover({trace:o,x0:g-d*a.r,x1:g+d*a.r,y:v,text:y.join(\"<br>\"),name:f.hovertemplate||-1!==p.indexOf(\"name\")?f.name:void 0,idealAlign:t.pxmid[0]<0?\"left\":\"right\",color:c.castOption(b.bgcolor,t.pts)||t.color,borderColor:c.castOption(b.bordercolor,t.pts),fontFamily:c.castOption(_.family,t.pts),fontSize:c.castOption(_.size,t.pts),fontColor:c.castOption(_.color,t.pts),nameLength:c.castOption(b.namelength,t.pts),textAlign:c.castOption(b.align,t.pts),hovertemplate:c.castOption(f.hovertemplate,t.pts),hovertemplateLabels:t,eventData:[u(t,f)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e}),o._hasHoverLabel=!0}o._hasHoverEvent=!0,e.emit(\"plotly_hover\",{points:[u(t,f)],event:n.event})}}),t.on(\"mouseout\",function(t){var r=e._fullLayout,a=e._fullData[o.index],s=n.select(this).datum();o._hasHoverEvent&&(t.originalEvent=n.event,e.emit(\"plotly_unhover\",{points:[u(s,a)],event:n.event}),o._hasHoverEvent=!1),o._hasHoverLabel&&(i.loneUnhover(r._hoverlayer.node()),o._hasHoverLabel=!1)}),t.on(\"click\",function(t){var r=e._fullLayout,a=e._fullData[o.index];e._dragging||!1===r.hovermode||(e._hoverdata=[u(t,a)],i.click(e,n.event))})}function f(t,e,r){var n=c.castOption(t.insidetextfont.color,e.pts);!n&&t._input.textfont&&(n=c.castOption(t._input.textfont.color,e.pts));var i=c.castOption(t.insidetextfont.family,e.pts)||c.castOption(t.textfont.family,e.pts)||r.family,o=c.castOption(t.insidetextfont.size,e.pts)||c.castOption(t.textfont.size,e.pts)||r.size;return{color:n||a.contrast(e.color),family:i,size:o}}function p(t,e){for(var r,n,i=0;i<t.length;i++)if((n=(r=t[i][0]).trace).title.text){var a=n.title.text;n._meta&&(a=s.templateString(a,n._meta));var c=o.tester.append(\"text\").attr(\"data-notex\",1).text(a).call(o.font,n.title.font).call(l.convertToTspans,e),u=o.bBox(c.node(),!0);r.titleBox={width:u.width,height:u.height},c.remove()}}function d(t,e,r){var n=Math.sqrt(t.width*t.width+t.height*t.height),i=t.width/t.height,a=e.halfangle,o=e.ring,s=e.rInscribed,l=r.r||e.rpx1,c={scale:s*l*2/n,rCenter:1-s,rotate:0};if(c.scale>=1)return c;var u=i+1/(2*Math.tan(a)),h=l*Math.min(1/(Math.sqrt(u*u+.5)+u),o/(Math.sqrt(i*i+o/2)+i)),f={scale:2*h/t.height,rCenter:Math.cos(h/l)-h*i/l,rotate:(180/Math.PI*e.midangle+720)%180-90},p=1/i,d=p+1/(2*Math.tan(a)),g=l*Math.min(1/(Math.sqrt(d*d+.5)+d),o/(Math.sqrt(p*p+o/2)+p)),v={scale:2*g/t.width,rCenter:Math.cos(g/l)-g/i/l,rotate:(180/Math.PI*e.midangle+810)%180-90},m=v.scale>f.scale?v:f;return c.scale<1&&m.scale>c.scale?m:c}function g(t,e){return t.v!==e.vTotal||e.trace.hole?Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2):1}function v(t,e){var r=e.pxmid[0],n=e.pxmid[1],i=t.width/2,a=t.height/2;return r<0&&(i*=-1),n<0&&(a*=-1),{scale:1,rCenter:1,rotate:0,x:i+Math.abs(a)*(i>0?1:-1)/2,y:a/(1+r*r/(n*n)),outside:!0}}function m(t,e){var r,n,i,a=t.trace,o={x:t.cx,y:t.cy},s={tx:0,ty:0};s.ty+=a.title.font.size,i=x(a),-1!==a.title.position.indexOf(\"top\")?(o.y-=(1+i)*t.r,s.ty-=t.titleBox.height):-1!==a.title.position.indexOf(\"bottom\")&&(o.y+=(1+i)*t.r);var l,c,u=(l=t.r,c=t.trace.aspectratio,l/(void 0===c?1:c)),h=e.w*(a.domain.x[1]-a.domain.x[0])/2;return-1!==a.title.position.indexOf(\"left\")?(h+=u,o.x-=(1+i)*u,s.tx+=t.titleBox.width/2):-1!==a.title.position.indexOf(\"center\")?h*=2:-1!==a.title.position.indexOf(\"right\")&&(h+=u,o.x+=(1+i)*u,s.tx-=t.titleBox.width/2),r=h/t.titleBox.width,n=y(t,e)/t.titleBox.height,{x:o.x,y:o.y,scale:Math.min(r,n),tx:s.tx,ty:s.ty}}function y(t,e){var r=t.trace,n=e.h*(r.domain.y[1]-r.domain.y[0]);return Math.min(t.titleBox.height,n/2)}function x(t){var e,r=t.pull;if(!r)return 0;if(Array.isArray(r))for(r=0,e=0;e<t.pull.length;e++)t.pull[e]>r&&(r=t.pull[e]);return r}function b(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n][0],a=i.trace,o=a.domain,s=e.w*(o.x[1]-o.x[0]),l=e.h*(o.y[1]-o.y[0]);a.title.text&&\"middle center\"!==a.title.position&&(l-=y(i,e));var c=s/2,u=l/2;\"funnelarea\"!==a.type||a.scalegroup||(u/=a.aspectratio),i.r=Math.min(c,u)/(1+x(a)),i.cx=e.l+e.w*(a.domain.x[1]+a.domain.x[0])/2,i.cy=e.t+e.h*(1-a.domain.y[0])-l/2,a.title.text&&-1!==a.title.position.indexOf(\"bottom\")&&(i.cy-=y(i,e)),a.scalegroup&&-1===r.indexOf(a.scalegroup)&&r.push(a.scalegroup)}!function(t,e){for(var r,n,i,a=0;a<e.length;a++){var o=1/0,s=e[a];for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var l;if(\"pie\"===i.type)l=r.r*r.r;else if(\"funnelarea\"===i.type){var c,u;i.aspectratio>1?(c=r.r,u=c/i.aspectratio):(u=r.r,c=u*i.aspectratio),c*=(1+i.baseratio)/2,l=c*u}o=Math.min(o,l/r.vTotal)}for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var h=o*r.vTotal;\"funnelarea\"===i.type&&(h/=(1+i.baseratio)/2,h/=i.aspectratio),r.r=Math.sqrt(h)}}}(t,r)}e.exports={plot:function(t,e){var r=t._fullLayout;p(e,t),b(e,r._size);var i=s.makeTraceGroups(r._pielayer,e,\"trace\").each(function(e){var i=n.select(this),u=e[0],p=u.trace;!function(t){var e,r,n,i=t[0],a=i.trace,o=a.rotation*Math.PI/180,s=2*Math.PI/i.vTotal,l=\"px0\",c=\"px1\";if(\"counterclockwise\"===a.direction){for(e=0;e<t.length&&t[e].hidden;e++);if(e===t.length)return;o+=s*t[e].v,s*=-1,l=\"px1\",c=\"px0\"}function u(t){return[i.r*Math.sin(t),-i.r*Math.cos(t)]}for(n=u(o),e=0;e<t.length;e++)(r=t[e]).hidden||(r[l]=n,o+=s*r.v/2,r.pxmid=u(o),r.midangle=o,o+=s*r.v/2,n=u(o),r[c]=n,r.largeArc=r.v>i.vTotal/2?1:0,r.halfangle=Math.PI*Math.min(r.v/i.vTotal,.5),r.ring=1-a.hole,r.rInscribed=g(r,i))}(e),i.attr(\"stroke-linejoin\",\"round\"),i.each(function(){var i=n.select(this).selectAll(\"g.slice\").data(e);i.enter().append(\"g\").classed(\"slice\",!0),i.exit().remove();var g=[[[],[]],[[],[]]],y=!1;i.each(function(r){if(r.hidden)n.select(this).selectAll(\"path,g\").remove();else{r.pointNumber=r.i,r.curveNumber=p.index,g[r.pxmid[1]<0?0:1][r.pxmid[0]<0?0:1].push(r);var i=u.cx,a=u.cy,m=n.select(this),x=m.selectAll(\"path.surface\").data([r]);if(x.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),m.call(h,t,e),p.pull){var b=+c.castOption(p.pull,r.pts)||0;b>0&&(i+=b*r.pxmid[0],a+=b*r.pxmid[1])}r.cxFinal=i,r.cyFinal=a;var _=p.hole;if(r.v===u.vTotal){var w=\"M\"+(i+r.px0[0])+\",\"+(a+r.px0[1])+S(r.px0,r.pxmid,!0,1)+S(r.pxmid,r.px0,!0,1)+\"Z\";_?x.attr(\"d\",\"M\"+(i+_*r.px0[0])+\",\"+(a+_*r.px0[1])+S(r.px0,r.pxmid,!1,_)+S(r.pxmid,r.px0,!1,_)+\"Z\"+w):x.attr(\"d\",w)}else{var k=S(r.px0,r.px1,!0,1);if(_){var T=1-_;x.attr(\"d\",\"M\"+(i+_*r.px1[0])+\",\"+(a+_*r.px1[1])+S(r.px1,r.px0,!1,_)+\"l\"+T*r.px0[0]+\",\"+T*r.px0[1]+k+\"Z\")}else x.attr(\"d\",\"M\"+i+\",\"+a+\"l\"+r.px0[0]+\",\"+r.px0[1]+k+\"Z\")}var A=c.castOption(p.textposition,r.pts),M=m.selectAll(\"g.slicetext\").data(r.text&&\"none\"!==A?[0]:[]);M.enter().append(\"g\").classed(\"slicetext\",!0),M.exit().remove(),M.each(function(){var e=s.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)});e.text(r.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(o.font,\"outside\"===A?function(t,e,r){var n=c.castOption(t.outsidetextfont.color,e.pts)||c.castOption(t.textfont.color,e.pts)||r.color,i=c.castOption(t.outsidetextfont.family,e.pts)||c.castOption(t.textfont.family,e.pts)||r.family,a=c.castOption(t.outsidetextfont.size,e.pts)||c.castOption(t.textfont.size,e.pts)||r.size;return{color:n,family:i,size:a}}(p,r,t._fullLayout.font):f(p,r,t._fullLayout.font)).call(l.convertToTspans,t);var h,g=o.bBox(e.node());\"outside\"===A?h=v(g,r):(h=d(g,r,u),\"auto\"===A&&h.scale<1&&(e.call(o.font,p.outsidetextfont),p.outsidetextfont.family===p.insidetextfont.family&&p.outsidetextfont.size===p.insidetextfont.size||(g=o.bBox(e.node())),h=v(g,r)));var m=i+r.pxmid[0]*h.rCenter+(h.x||0),x=a+r.pxmid[1]*h.rCenter+(h.y||0);h.outside&&(r.yLabelMin=x-g.height/2,r.yLabelMid=x,r.yLabelMax=x+g.height/2,r.labelExtraX=0,r.labelExtraY=0,y=!0),e.attr(\"transform\",\"translate(\"+m+\",\"+x+\")\"+(h.scale<1?\"scale(\"+h.scale+\")\":\"\")+(h.rotate?\"rotate(\"+h.rotate+\")\":\"\")+\"translate(\"+-(g.left+g.right)/2+\",\"+-(g.top+g.bottom)/2+\")\")})}function S(t,e,n,i){var a=i*(e[0]-t[0]),o=i*(e[1]-t[1]);return\"a\"+i*u.r+\",\"+i*u.r+\" 0 \"+r.largeArc+(n?\" 1 \":\" 0 \")+a+\",\"+o}});var x=n.select(this).selectAll(\"g.titletext\").data(p.title.text?[0]:[]);x.enter().append(\"g\").classed(\"titletext\",!0),x.exit().remove(),x.each(function(){var e,i=s.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),a=p.title.text;p._meta&&(a=s.templateString(a,p._meta)),i.text(a).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(o.font,p.title.font).call(l.convertToTspans,t),e=\"middle center\"===p.title.position?function(t){var e=Math.sqrt(t.titleBox.width*t.titleBox.width+t.titleBox.height*t.titleBox.height);return{x:t.cx,y:t.cy,scale:t.trace.hole*t.r*2/e,tx:0,ty:-t.titleBox.height/2+t.trace.title.font.size}}(u):m(u,r._size),i.attr(\"transform\",\"translate(\"+e.x+\",\"+e.y+\")\"+(e.scale<1?\"scale(\"+e.scale+\")\":\"\")+\"translate(\"+e.tx+\",\"+e.ty+\")\")}),y&&function(t,e){var r,n,i,a,o,s,l,u,h,f,p,d,g;function v(t,e){return t.pxmid[1]-e.pxmid[1]}function m(t,e){return e.pxmid[1]-t.pxmid[1]}function y(t,r){r||(r={});var i,u,h,p,d,g,v=r.labelExtraY+(n?r.yLabelMax:r.yLabelMin),m=n?t.yLabelMin:t.yLabelMax,y=n?t.yLabelMax:t.yLabelMin,x=t.cyFinal+o(t.px0[1],t.px1[1]),b=v-m;if(b*l>0&&(t.labelExtraY=b),Array.isArray(e.pull))for(u=0;u<f.length;u++)(h=f[u])===t||(c.castOption(e.pull,t.pts)||0)>=(c.castOption(e.pull,h.pts)||0)||((t.pxmid[1]-h.pxmid[1])*l>0?(p=h.cyFinal+o(h.px0[1],h.px1[1]),(b=p-m-t.labelExtraY)*l>0&&(t.labelExtraY+=b)):(y+t.labelExtraY-x)*l>0&&(i=3*s*Math.abs(u-f.indexOf(t)),d=h.cxFinal+a(h.px0[0],h.px1[0]),(g=d+i-(t.cxFinal+t.pxmid[0])-t.labelExtraX)*s>0&&(t.labelExtraX+=g)))}for(n=0;n<2;n++)for(i=n?v:m,o=n?Math.max:Math.min,l=n?1:-1,r=0;r<2;r++){for(a=r?Math.max:Math.min,s=r?1:-1,(u=t[n][r]).sort(i),h=t[1-n][r],f=h.concat(u),d=[],p=0;p<u.length;p++)void 0!==u[p].yLabelMid&&d.push(u[p]);for(g=!1,p=0;n&&p<h.length;p++)if(void 0!==h[p].yLabelMid){g=h[p];break}for(p=0;p<d.length;p++){var x=p&&d[p-1];g&&!p&&(x=g),y(d[p],x)}}}(g,p),function(t,e){t.each(function(t){var r=n.select(this);if(t.labelExtraX||t.labelExtraY){var i=r.select(\"g.slicetext text\");i.attr(\"transform\",\"translate(\"+t.labelExtraX+\",\"+t.labelExtraY+\")\"+i.attr(\"transform\"));var o=t.cxFinal+t.pxmid[0],l=t.cyFinal+t.pxmid[1],c=\"M\"+o+\",\"+l,u=(t.yLabelMax-t.yLabelMin)*(t.pxmid[0]<0?-1:1)/4;if(t.labelExtraX){var h=t.labelExtraX*t.pxmid[1]/t.pxmid[0],f=t.yLabelMid+t.labelExtraY-(t.cyFinal+t.pxmid[1]);Math.abs(h)>Math.abs(f)?c+=\"l\"+f*t.pxmid[0]/t.pxmid[1]+\",\"+f+\"H\"+(o+t.labelExtraX+u):c+=\"l\"+t.labelExtraX+\",\"+h+\"v\"+(f-h)+\"h\"+u}else c+=\"V\"+(t.yLabelMid+t.labelExtraY)+\"h\"+u;s.ensureSingle(r,\"path\",\"textline\").call(a.stroke,e.outsidetextfont.color).attr({\"stroke-width\":Math.min(2,e.outsidetextfont.size/8),d:c,fill:\"none\"})}else r.select(\"path.textline\").remove()})}(i,p)})});setTimeout(function(){i.selectAll(\"tspan\").each(function(){var t=n.select(this);t.attr(\"dy\")&&t.attr(\"dy\",t.attr(\"dy\"))})},0)},transformInsideText:d,determineInsideTextFont:f,positionTitleOutside:m,prerenderTitles:p,layoutAreas:b,attachFxHandlers:h}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"./event_data\":1090,\"./helpers\":1091,d3:163}],1096:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./style_one\");e.exports=function(t){t._fullLayout._pielayer.selectAll(\".trace\").each(function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each(function(t){n.select(this).call(i,t,e)})})}},{\"./style_one\":1097,d3:163}],1097:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./helpers\").castOption;e.exports=function(t,e,r){var a=r.marker.line,o=i(a.color,e.pts)||n.defaultLine,s=i(a.width,e.pts)||0;t.style(\"stroke-width\",s).call(n.fill,e.color).call(n.stroke,o)}},{\"../../components/color\":593,\"./helpers\":1091}],1098:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\");e.exports={x:n.x,y:n.y,xy:{valType:\"data_array\",editType:\"calc\"},indices:{valType:\"data_array\",editType:\"calc\"},xbounds:{valType:\"data_array\",editType:\"calc\"},ybounds:{valType:\"data_array\",editType:\"calc\"},text:n.text,marker:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,arrayOk:!1,editType:\"calc\"},blend:{valType:\"boolean\",dflt:null,editType:\"calc\"},sizemin:{valType:\"number\",min:.1,max:2,dflt:.5,editType:\"calc\"},sizemax:{valType:\"number\",min:.1,dflt:20,editType:\"calc\"},border:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},arearatio:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},transforms:void 0}},{\"../scatter/attributes\":1112}],1099:[function(t,e,r){\"use strict\";var n=t(\"gl-pointcloud2d\"),i=t(\"../../lib/str2rgbarray\"),a=t(\"../../plots/cartesian/autorange\").findExtremes,o=t(\"../scatter/get_trace_color\");function s(t,e){this.scene=t,this.uid=e,this.type=\"pointcloud\",this.pickXData=[],this.pickYData=[],this.xData=[],this.yData=[],this.textLabels=[],this.color=\"rgb(0, 0, 0)\",this.name=\"\",this.hoverinfo=\"all\",this.idToIndex=new Int32Array(0),this.bounds=[0,0,0,0],this.pointcloudOptions={positions:new Float32Array(0),idToIndex:this.idToIndex,sizemin:.5,sizemax:12,color:[0,0,0,1],areaRatio:1,borderColor:[0,0,0,1]},this.pointcloud=n(t.glplot,this.pointcloudOptions),this.pointcloud._trace=this}var l=s.prototype;l.handlePick=function(t){var e=this.idToIndex[t.pointId];return{trace:this,dataCoord:t.dataCoord,traceCoord:this.pickXYData?[this.pickXYData[2*e],this.pickXYData[2*e+1]]:[this.pickXData[e],this.pickYData[e]],textLabel:Array.isArray(this.textLabels)?this.textLabels[e]:this.textLabels,color:this.color,name:this.name,pointIndex:e,hoverinfo:this.hoverinfo}},l.update=function(t){this.index=t.index,this.textLabels=t.text,this.name=t.name,this.hoverinfo=t.hoverinfo,this.bounds=[1/0,1/0,-1/0,-1/0],this.updateFast(t),this.color=o(t,{})},l.updateFast=function(t){var e,r,n,o,s,l,c=this.xData=this.pickXData=t.x,u=this.yData=this.pickYData=t.y,h=this.pickXYData=t.xy,f=t.xbounds&&t.ybounds,p=t.indices,d=this.bounds;if(h){if(n=h,e=h.length>>>1,f)d[0]=t.xbounds[0],d[2]=t.xbounds[1],d[1]=t.ybounds[0],d[3]=t.ybounds[1];else for(l=0;l<e;l++)o=n[2*l],s=n[2*l+1],o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);if(p)r=p;else for(r=new Int32Array(e),l=0;l<e;l++)r[l]=l}else for(e=c.length,n=new Float32Array(2*e),r=new Int32Array(e),l=0;l<e;l++)o=c[l],s=u[l],r[l]=l,n[2*l]=o,n[2*l+1]=s,o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);this.idToIndex=r,this.pointcloudOptions.idToIndex=r,this.pointcloudOptions.positions=n;var g=i(t.marker.color),v=i(t.marker.border.color),m=t.opacity*t.marker.opacity;g[3]*=m,this.pointcloudOptions.color=g;var y=t.marker.blend;if(null===y){y=c.length<100||u.length<100}this.pointcloudOptions.blend=y,v[3]*=m,this.pointcloudOptions.borderColor=v;var x=t.marker.sizemin,b=Math.max(t.marker.sizemax,t.marker.sizemin);this.pointcloudOptions.sizeMin=x,this.pointcloudOptions.sizeMax=b,this.pointcloudOptions.areaRatio=t.marker.border.arearatio,this.pointcloud.update(this.pointcloudOptions);var _=this.scene.xaxis,w=this.scene.yaxis,k=b/2||.5;t._extremes[_._id]=a(_,[d[0],d[2]],{ppad:k}),t._extremes[w._id]=a(w,[d[1],d[3]],{ppad:k})},l.dispose=function(){this.pointcloud.dispose()},e.exports=function(t,e){var r=new s(t,e.uid);return r.update(e),r}},{\"../../lib/str2rgbarray\":742,\"../../plots/cartesian/autorange\":766,\"../scatter/get_trace_color\":1121,\"gl-pointcloud2d\":292}],1100:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\");e.exports=function(t,e,r){function a(r,a){return n.coerce(t,e,i,r,a)}a(\"x\"),a(\"y\"),a(\"xbounds\"),a(\"ybounds\"),t.xy&&t.xy instanceof Float32Array&&(e.xy=t.xy),t.indices&&t.indices instanceof Int32Array&&(e.indices=t.indices),a(\"text\"),a(\"marker.color\",r),a(\"marker.opacity\"),a(\"marker.blend\"),a(\"marker.sizemin\"),a(\"marker.sizemax\"),a(\"marker.border.color\",r),a(\"marker.border.arearatio\"),e._length=null}},{\"../../lib\":719,\"./attributes\":1098}],1101:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../scatter3d/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"pointcloud\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"showLegend\"],meta:{}}},{\"../../plots/gl2d\":805,\"../scatter3d/calc\":1139,\"./attributes\":1098,\"./convert\":1099,\"./defaults\":1100}],1102:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../components/fx/attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../../components/fx/hovertemplate_attributes\"),c=t(\"../../components/colorscale/attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,h=t(\"../../lib/extend\").extendFlat,f=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=f({hoverinfo:h({},i.hoverinfo,{flags:[],arrayOk:!1}),hoverlabel:o.hoverlabel,domain:s({name:\"sankey\",trace:!0}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\"},valueformat:{valType:\"string\",dflt:\".3s\"},valuesuffix:{valType:\"string\",dflt:\"\"},arrangement:{valType:\"enumerated\",values:[\"snap\",\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"snap\"},textfont:n({}),node:{label:{valType:\"data_array\",dflt:[]},groups:{valType:\"info_array\",impliedEdits:{x:[],y:[]},dimensions:2,freeLength:!0,dflt:[],items:{valType:\"number\",editType:\"calc\"}},x:{valType:\"data_array\",dflt:[]},y:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:.5,arrayOk:!0}},pad:{valType:\"number\",arrayOk:!1,min:0,dflt:20},thickness:{valType:\"number\",arrayOk:!1,min:1,dflt:20},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]})},link:{label:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0}},source:{valType:\"data_array\",dflt:[]},target:{valType:\"data_array\",dflt:[]},value:{valType:\"data_array\",dflt:[]},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]}),colorscales:u(\"concentrationscales\",{editType:\"calc\",label:{valType:\"string\",editType:\"calc\",dflt:\"\"},cmax:{valType:\"number\",editType:\"calc\",dflt:1},cmin:{valType:\"number\",editType:\"calc\",dflt:0},colorscale:h(c().colorscale,{dflt:[[0,\"white\"],[1,\"black\"]]})})}},\"calc\",\"nested\")).transforms=void 0},{\"../../components/color/attributes\":592,\"../../components/colorscale/attributes\":600,\"../../components/fx/attributes\":623,\"../../components/fx/hovertemplate_attributes\":631,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1103:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../components/fx/layout_attributes\"),s=t(\"../../lib/setcursor\"),l=t(\"../../components/dragelement\"),c=t(\"../../plots/cartesian/select\").prepSelect,u=t(\"../../lib\"),h=t(\"../../registry\");function f(t,e){var r=t._fullData[e],n=t._fullLayout,i=n.dragmode,a=\"pan\"===n.dragmode?\"move\":\"crosshair\",o=r._bgRect;if(\"pan\"!==i&&\"zoom\"!==i){s(o,a);var f={_id:\"x\",c2p:u.identity,_offset:r._sankey.translateX,_length:r._sankey.width},p={_id:\"y\",c2p:u.identity,_offset:r._sankey.translateY,_length:r._sankey.height},d={gd:t,element:o.node(),plotinfo:{id:e,xaxis:f,yaxis:p,fillRangeItems:u.noop},subplot:e,xaxes:[f],yaxes:[p],doneFnCompleted:function(r){var n,i=t._fullData[e],a=i.node.groups.slice(),o=[];function s(t){for(var e=i._sankey.graph.nodes,r=0;r<e.length;r++)if(e[r].pointNumber===t)return e[r]}for(var l=0;l<r.length;l++){var c=s(r[l].pointNumber);if(c)if(c.group){for(var u=0;u<c.childrenNodes.length;u++)o.push(c.childrenNodes[u].pointNumber);a[c.pointNumber-i.node._count]=!1}else o.push(c.pointNumber)}n=a.filter(Boolean).concat([o]),h.call(\"_guiRestyle\",t,{\"node.groups\":[n]},e)},prepFn:function(t,e,r){c(t,e,r,d,i)}};l.init(d)}}r.name=\"sankey\",r.baseLayoutAttrOverrides=n({hoverlabel:o.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){var e=i(t.calcdata,\"sankey\")[0];a(t,e),r.updateFx(t)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"sankey\"),a=e._has&&e._has(\"sankey\");i&&!a&&(n._paperdiv.selectAll(\".sankey\").remove(),n._paperdiv.selectAll(\".bgsankey\").remove())},r.updateFx=function(t){for(var e=0;e<t._fullData.length;e++)f(t,e)}},{\"../../components/dragelement\":611,\"../../components/fx/layout_attributes\":633,\"../../lib\":719,\"../../lib/setcursor\":739,\"../../plot_api/edit_types\":750,\"../../plots/cartesian/select\":784,\"../../plots/get_data\":802,\"../../registry\":847,\"./plot\":1108}],1104:[function(t,e,r){\"use strict\";var n=t(\"strongly-connected-components\"),i=t(\"../../lib\"),a=t(\"../../lib/gup\").wrap,o=i.isArrayOrTypedArray,s=i.isIndex,l=t(\"../../components/colorscale\");function c(t){var e,r=t.node,a=t.link,c=[],u=o(a.color),h={},f={},p=a.colorscales.length;for(e=0;e<p;e++){var d=a.colorscales[e],g=l.extractScale(d,{cLetter:\"c\"}),v=l.makeColorScaleFunc(g);f[d.label]=v}var m=0;for(e=0;e<a.value.length;e++)a.source[e]>m&&(m=a.source[e]),a.target[e]>m&&(m=a.target[e]);var y,x=m+1;t.node._count=x;var b=t.node.groups,_={};for(e=0;e<b.length;e++){var w=b[e];for(y=0;y<w.length;y++){var k=w[y],T=x+e;_.hasOwnProperty(k)?i.warn(\"Node \"+k+\" is already part of a group.\"):_[k]=T}}var A={source:[],target:[]};for(e=0;e<a.value.length;e++){var M=a.value[e],S=a.source[e],E=a.target[e];if(M>0&&s(S,x)&&s(E,x)&&(!_.hasOwnProperty(S)||!_.hasOwnProperty(E)||_[S]!==_[E])){_.hasOwnProperty(E)&&(E=_[E]),_.hasOwnProperty(S)&&(S=_[S]),E=+E,h[S=+S]=h[E]=!0;var C=\"\";a.label&&a.label[e]&&(C=a.label[e]);var L=null;C&&f.hasOwnProperty(C)&&(L=f[C]),c.push({pointNumber:e,label:C,color:u?a.color[e]:a.color,concentrationscale:L,source:S,target:E,value:+M}),A.source.push(S),A.target.push(E)}}var P=x+b.length,O=o(r.color),z=[];for(e=0;e<P;e++)if(h[e]){var I=r.label[e];z.push({group:e>x-1,childrenNodes:[],pointNumber:e,label:I,color:O?r.color[e]:r.color})}var D=!1;return function(t,e,r){for(var a=i.init2dArray(t,0),o=0;o<Math.min(e.length,r.length);o++)if(i.isIndex(e[o],t)&&i.isIndex(r[o],t)){if(e[o]===r[o])return!0;a[e[o]].push(r[o])}return n(a).components.some(function(t){return t.length>1})}(P,A.source,A.target)&&(D=!0),{circular:D,links:c,nodes:z,groups:b,groupLookup:_}}e.exports=function(t,e){var r=c(e);return a({circular:r.circular,_nodes:r.nodes,_links:r.links,_groups:r.groups,_groupLookup:r.groupLookup})}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gup\":717,\"strongly-connected-components\":530}],1105:[function(t,e,r){\"use strict\";e.exports={nodeTextOffsetHorizontal:4,nodeTextOffsetVertical:3,nodePadAcross:10,sankeyIterations:50,forceIterations:5,forceTicksPerFrame:10,duration:500,ease:\"linear\",cn:{sankey:\"sankey\",sankeyLinks:\"sankey-links\",sankeyLink:\"sankey-link\",sankeyNodeSet:\"sankey-node-set\",sankeyNode:\"sankey-node\",nodeRect:\"node-rect\",nodeCapture:\"node-capture\",nodeCentered:\"node-entered\",nodeLabelGuide:\"node-label-guide\",nodeLabel:\"node-label\",nodeLabelTextPath:\"node-label-text-path\"}}},{}],1106:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../components/color\"),o=t(\"tinycolor2\"),s=t(\"../../plots/domain\").defaults,l=t(\"../../components/fx/hoverlabel_defaults\"),c=t(\"../../plot_api/plot_template\"),u=t(\"../../plots/array_container_defaults\");function h(t,e){function r(r,a){return n.coerce(t,e,i.link.colorscales,r,a)}r(\"label\"),r(\"cmin\"),r(\"cmax\"),r(\"colorscale\")}e.exports=function(t,e,r,f){function p(r,a){return n.coerce(t,e,i,r,a)}var d=n.extendDeep(f.hoverlabel,t.hoverlabel),g=t.node,v=c.newContainer(e,\"node\");function m(t,e){return n.coerce(g,v,i.node,t,e)}m(\"label\"),m(\"groups\"),m(\"x\"),m(\"y\"),m(\"pad\"),m(\"thickness\"),m(\"line.color\"),m(\"line.width\"),m(\"hoverinfo\",t.hoverinfo),l(g,v,m,d),m(\"hovertemplate\");var y=f.colorway;m(\"color\",v.label.map(function(t,e){return a.addOpacity(function(t){return y[t%y.length]}(e),.8)}));var x=t.link||{},b=c.newContainer(e,\"link\");function _(t,e){return n.coerce(x,b,i.link,t,e)}_(\"label\"),_(\"source\"),_(\"target\"),_(\"value\"),_(\"line.color\"),_(\"line.width\"),_(\"hoverinfo\",t.hoverinfo),l(x,b,_,d),_(\"hovertemplate\");var w,k=o(f.paper_bgcolor).getLuminance()<.333?\"rgba(255, 255, 255, 0.6)\":\"rgba(0, 0, 0, 0.2)\";_(\"color\",n.repeat(k,b.value.length)),u(x,b,{name:\"colorscales\",handleItemDefaults:h}),s(e,f,p),p(\"orientation\"),p(\"valueformat\"),p(\"valuesuffix\"),v.x.length&&v.y.length&&(w=\"freeform\"),p(\"arrangement\",w),n.coerceFont(p,\"textfont\",n.extendFlat({},f.font)),e._length=null}},{\"../../components/color\":593,\"../../components/fx/hoverlabel_defaults\":630,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/array_container_defaults\":763,\"../../plots/domain\":792,\"./attributes\":1102,tinycolor2:537}],1107:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"sankey\",basePlotModule:t(\"./base_plot\"),selectPoints:t(\"./select.js\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1102,\"./base_plot\":1103,\"./calc\":1104,\"./defaults\":1106,\"./plot\":1108,\"./select.js\":1110}],1108:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./render\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\"),l=t(\"./constants\").cn,c=s._;function u(t){return\"\"!==t}function h(t,e){return t.filter(function(t){return t.key===e.traceId})}function f(t,e){n.select(t).select(\"path\").style(\"fill-opacity\",e),n.select(t).select(\"rect\").style(\"fill-opacity\",e)}function p(t){n.select(t).select(\"text.name\").style(\"fill\",\"black\")}function d(t){return function(e){return-1!==t.node.sourceLinks.indexOf(e.link)||-1!==t.node.targetLinks.indexOf(e.link)}}function g(t){return function(e){return-1!==e.node.sourceLinks.indexOf(t.link)||-1!==e.node.targetLinks.indexOf(t.link)}}function v(t,e,r){e&&r&&h(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(y.bind(0,e,r,!1))}function m(t,e,r){e&&r&&h(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(x.bind(0,e,r,!1))}function y(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",function(t){if(!t.link.concentrationscale)return.4}),i&&h(e,t).selectAll(\".\"+l.sankeyLink).filter(function(t){return t.link.label===i}).style(\"fill-opacity\",function(t){if(!t.link.concentrationscale)return.4}),r&&h(e,t).selectAll(\".\"+l.sankeyNode).filter(g(t)).call(v)}function x(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),i&&h(e,t).selectAll(\".\"+l.sankeyLink).filter(function(t){return t.link.label===i}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),r&&h(e,t).selectAll(l.sankeyNode).filter(g(t)).call(m)}function b(t,e){var r=t.hoverlabel||{},n=s.nestedProperty(r,e).get();return!Array.isArray(n)&&n}e.exports=function(t,e){for(var r=t._fullLayout,s=r._paper,h=r._size,d=0;d<t._fullData.length;d++)if(t._fullData[d].type===l.sankey&&!t._fullData[d]._viewInitial){var g=t._fullData[d].node;t._fullData[d]._viewInitial={node:{groups:g.groups.slice(),x:g.x.slice(),y:g.y.slice()}}}var _=c(t,\"source:\")+\" \",w=c(t,\"target:\")+\" \",k=c(t,\"concentration:\")+\" \",T=c(t,\"incoming flow count:\")+\" \",A=c(t,\"outgoing flow count:\")+\" \";i(t,s,e,{width:h.w,height:h.h,margin:{t:h.t,r:h.r,b:h.b,l:h.l}},{linkEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(y.bind(0,r,i,!0)),\"skip\"!==r.link.trace.link.hoverinfo&&(r.link.fullData=r.link.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.link]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var s=i.link.trace.link;if(\"none\"!==s.hoverinfo&&\"skip\"!==s.hoverinfo){for(var l=[],c=0,h=0;h<i.flow.links.length;h++){var d=i.flow.links[h];if(\"closest\"!==t._fullLayout.hovermode||i.link.pointNumber===d.pointNumber){i.link.pointNumber===d.pointNumber&&(c=h),d.fullData=d.trace,s=i.link.trace.link;var g=m(d),v={valueLabel:n.format(i.valueFormat)(d.value)+i.valueSuffix};l.push({x:g[0],y:g[1],name:v.valueLabel,text:[d.label||\"\",_+d.source.label,w+d.target.label,d.concentrationscale?k+n.format(\"%0.2f\")(d.flow.labelConcentration):\"\"].filter(u).join(\"<br>\"),color:b(s,\"bgcolor\")||o.addOpacity(d.color,1),borderColor:b(s,\"bordercolor\"),fontFamily:b(s,\"font.family\"),fontSize:b(s,\"font.size\"),fontColor:b(s,\"font.color\"),nameLength:b(s,\"namelength\"),textAlign:b(s,\"align\"),idealAlign:n.event.x<g[0]?\"right\":\"left\",hovertemplate:s.hovertemplate,hovertemplateLabels:v,eventData:[d]})}}a.loneHover(l,{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t,anchorIndex:c}).each(function(){i.link.concentrationscale||f(this,.65),p(this)})}}function m(t){var e,r;return t.circular?(e=(t.circularPathData.leftInnerExtent+t.circularPathData.rightInnerExtent)/2+i.parent.translateX,r=t.circularPathData.verticalFullExtent+i.parent.translateY):(e=(t.source.x1+t.target.x0)/2+i.parent.translateX,r=(t.y0+t.y1)/2+i.parent.translateY),[e,r]}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(x.bind(0,i,o,!0)),\"skip\"!==i.link.trace.link.hoverinfo&&(i.link.fullData=i.link.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.link]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r){var i=r.link;i.originalEvent=n.event,t._hoverdata=[i],a.click(t,{target:!0})}},nodeEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(v,r,i),\"skip\"!==r.node.trace.node.hoverinfo&&(r.node.fullData=r.node.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.node]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var o=i.node.trace.node;if(\"none\"!==o.hoverinfo&&\"skip\"!==o.hoverinfo){var s=n.select(e).select(\".\"+l.nodeRect),c=t._fullLayout._paperdiv.node().getBoundingClientRect(),h=s.node().getBoundingClientRect(),d=h.left-2-c.left,g=h.right+2-c.left,v=h.top+h.height/4-c.top,m={valueLabel:n.format(i.valueFormat)(i.node.value)+i.valueSuffix};i.node.fullData=i.node.trace;var y=a.loneHover({x0:d,x1:g,y:v,name:n.format(i.valueFormat)(i.node.value)+i.valueSuffix,text:[i.node.label,T+i.node.targetLinks.length,A+i.node.sourceLinks.length].filter(u).join(\"<br>\"),color:b(o,\"bgcolor\")||i.tinyColorHue,borderColor:b(o,\"bordercolor\"),fontFamily:b(o,\"font.family\"),fontSize:b(o,\"font.size\"),fontColor:b(o,\"font.color\"),nameLength:b(o,\"namelength\"),textAlign:b(o,\"align\"),idealAlign:\"left\",hovertemplate:o.hovertemplate,hovertemplateLabels:m,eventData:[i.node]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t});f(y,.85),p(y)}}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(m,i,o),\"skip\"!==i.node.trace.node.hoverinfo&&(i.node.fullData=i.node.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.node]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r,i){var o=r.node;o.originalEvent=n.event,t._hoverdata=[o],n.select(e).call(m,r,i),a.click(t,{target:!0})}}})}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"./constants\":1105,\"./render\":1109,d3:163}],1109:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"tinycolor2\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"@plotly/d3-sankey\"),c=t(\"@plotly/d3-sankey-circular\"),u=t(\"d3-force\"),h=t(\"../../lib\"),f=t(\"../../lib/gup\"),p=f.keyFun,d=f.repeat,g=f.unwrap,v=t(\"d3-interpolate\").interpolateNumber,m=t(\"../../registry\");function y(){var t=.5;return function(e){if(e.link.circular)return r=e.link,n=r.width/2,i=r.circularPathData,\"top\"===r.circularLinkType?\"M \"+i.targetX+\" \"+(i.targetY+n)+\" L\"+i.rightInnerExtent+\" \"+(i.targetY+n)+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightSmallArcRadius+n)+\" 0 0 1 \"+(i.rightFullExtent-n)+\" \"+(i.targetY-i.rightSmallArcRadius)+\"L\"+(i.rightFullExtent-n)+\" \"+i.verticalRightInnerExtent+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightLargeArcRadius+n)+\" 0 0 1 \"+i.rightInnerExtent+\" \"+(i.verticalFullExtent-n)+\"L\"+i.leftInnerExtent+\" \"+(i.verticalFullExtent-n)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftLargeArcRadius+n)+\" 0 0 1 \"+(i.leftFullExtent+n)+\" \"+i.verticalLeftInnerExtent+\"L\"+(i.leftFullExtent+n)+\" \"+(i.sourceY-i.leftSmallArcRadius)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftSmallArcRadius+n)+\" 0 0 1 \"+i.leftInnerExtent+\" \"+(i.sourceY+n)+\"L\"+i.sourceX+\" \"+(i.sourceY+n)+\"L\"+i.sourceX+\" \"+(i.sourceY-n)+\"L\"+i.leftInnerExtent+\" \"+(i.sourceY-n)+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftSmallArcRadius-n)+\" 0 0 0 \"+(i.leftFullExtent-n)+\" \"+(i.sourceY-i.leftSmallArcRadius)+\"L\"+(i.leftFullExtent-n)+\" \"+i.verticalLeftInnerExtent+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftLargeArcRadius-n)+\" 0 0 0 \"+i.leftInnerExtent+\" \"+(i.verticalFullExtent+n)+\"L\"+i.rightInnerExtent+\" \"+(i.verticalFullExtent+n)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightLargeArcRadius-n)+\" 0 0 0 \"+(i.rightFullExtent+n)+\" \"+i.verticalRightInnerExtent+\"L\"+(i.rightFullExtent+n)+\" \"+(i.targetY-i.rightSmallArcRadius)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightSmallArcRadius-n)+\" 0 0 0 \"+i.rightInnerExtent+\" \"+(i.targetY-n)+\"L\"+i.targetX+\" \"+(i.targetY-n)+\"Z\":\"M \"+i.targetX+\" \"+(i.targetY-n)+\" L\"+i.rightInnerExtent+\" \"+(i.targetY-n)+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightSmallArcRadius+n)+\" 0 0 0 \"+(i.rightFullExtent-n)+\" \"+(i.targetY+i.rightSmallArcRadius)+\"L\"+(i.rightFullExtent-n)+\" \"+i.verticalRightInnerExtent+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightLargeArcRadius+n)+\" 0 0 0 \"+i.rightInnerExtent+\" \"+(i.verticalFullExtent+n)+\"L\"+i.leftInnerExtent+\" \"+(i.verticalFullExtent+n)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftLargeArcRadius+n)+\" 0 0 0 \"+(i.leftFullExtent+n)+\" \"+i.verticalLeftInnerExtent+\"L\"+(i.leftFullExtent+n)+\" \"+(i.sourceY+i.leftSmallArcRadius)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftSmallArcRadius+n)+\" 0 0 0 \"+i.leftInnerExtent+\" \"+(i.sourceY-n)+\"L\"+i.sourceX+\" \"+(i.sourceY-n)+\"L\"+i.sourceX+\" \"+(i.sourceY+n)+\"L\"+i.leftInnerExtent+\" \"+(i.sourceY+n)+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftSmallArcRadius-n)+\" 0 0 1 \"+(i.leftFullExtent-n)+\" \"+(i.sourceY+i.leftSmallArcRadius)+\"L\"+(i.leftFullExtent-n)+\" \"+i.verticalLeftInnerExtent+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftLargeArcRadius-n)+\" 0 0 1 \"+i.leftInnerExtent+\" \"+(i.verticalFullExtent-n)+\"L\"+i.rightInnerExtent+\" \"+(i.verticalFullExtent-n)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightLargeArcRadius-n)+\" 0 0 1 \"+(i.rightFullExtent+n)+\" \"+i.verticalRightInnerExtent+\"L\"+(i.rightFullExtent+n)+\" \"+(i.targetY+i.rightSmallArcRadius)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightSmallArcRadius-n)+\" 0 0 1 \"+i.rightInnerExtent+\" \"+(i.targetY+n)+\"L\"+i.targetX+\" \"+(i.targetY+n)+\"Z\";var r,n,i,a=e.link.source.x1,o=e.link.target.x0,s=v(a,o),l=s(t),c=s(1-t),u=e.link.y0-e.link.width/2,h=e.link.y0+e.link.width/2,f=e.link.y1-e.link.width/2,p=e.link.y1+e.link.width/2;return\"M\"+a+\",\"+u+\"C\"+l+\",\"+u+\" \"+c+\",\"+f+\" \"+o+\",\"+f+\"L\"+o+\",\"+p+\"C\"+c+\",\"+p+\" \"+l+\",\"+h+\" \"+a+\",\"+h+\"Z\"}}function x(t){t.attr(\"transform\",function(t){return\"translate(\"+t.node.x0.toFixed(3)+\", \"+t.node.y0.toFixed(3)+\")\"})}function b(t){t.call(x)}function _(t,e){t.call(b),e.attr(\"d\",y())}function w(t){t.attr(\"width\",function(t){return t.node.x1-t.node.x0}).attr(\"height\",function(t){return t.visibleHeight})}function k(t){return t.link.width>1||t.linkLineWidth>0}function T(t){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"+(t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\")}function A(t){return\"translate(\"+(t.horizontal?0:t.labelY)+\" \"+(t.horizontal?t.labelY:0)+\")\"}function M(t){return i.svg.line()([[t.horizontal?t.left?-t.sizeAcross:t.visibleWidth+n.nodeTextOffsetHorizontal:n.nodeTextOffsetHorizontal,0],[t.horizontal?t.left?-n.nodeTextOffsetHorizontal:t.sizeAcross:t.visibleHeight-n.nodeTextOffsetHorizontal,0]])}function S(t){return t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\"}function E(t){return t.horizontal?\"scale(1 1)\":\"scale(-1 1)\"}function C(t){return t.darkBackground&&!t.horizontal?\"rgb(255,255,255)\":\"rgb(0,0,0)\"}function L(t){return t.horizontal&&t.left?\"100%\":\"0%\"}function P(t,e,r){t.on(\".basic\",null).on(\"mouseover.basic\",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.hover(this,t,e),t.interactionState.hovered=[this,t])}).on(\"mousemove.basic\",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.follow(this,t),t.interactionState.hovered=[this,t])}).on(\"mouseout.basic\",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.unhover(this,t,e),t.interactionState.hovered=!1)}).on(\"click.basic\",function(t){t.interactionState.hovered&&(r.unhover(this,t,e),t.interactionState.hovered=!1),t.interactionState.dragInProgress||t.partOfGroup||r.select(this,t,e)})}function O(t,e,r,a){var o=i.behavior.drag().origin(function(t){return{x:t.node.x0+t.visibleWidth/2,y:t.node.y0+t.visibleHeight/2}}).on(\"dragstart\",function(i){if(\"fixed\"!==i.arrangement&&(h.ensureSingle(a._fullLayout._infolayer,\"g\",\"dragcover\",function(t){a._fullLayout._dragCover=t}),h.raiseToTop(this),i.interactionState.dragInProgress=i.node,I(i.node),i.interactionState.hovered&&(r.nodeEvents.unhover.apply(0,i.interactionState.hovered),i.interactionState.hovered=!1),\"snap\"===i.arrangement)){var o=i.traceId+\"|\"+i.key;i.forceLayouts[o]?i.forceLayouts[o].alpha(1):function(t,e,r,i){!function(t){for(var e=0;e<t.length;e++)t[e].y=(t[e].y0+t[e].y1)/2,t[e].x=(t[e].x0+t[e].x1)/2}(r.graph.nodes);var a=r.graph.nodes.filter(function(t){return t.originalX===r.node.originalX}).filter(function(t){return!t.partOfGroup});r.forceLayouts[e]=u.forceSimulation(a).alphaDecay(0).force(\"collide\",u.forceCollide().radius(function(t){return t.dy/2+r.nodePad/2}).strength(1).iterations(n.forceIterations)).force(\"constrain\",function(t,e,r,i){return function(){for(var t=0,a=0;a<r.length;a++){var o=r[a];o===i.interactionState.dragInProgress?(o.x=o.lastDraggedX,o.y=o.lastDraggedY):(o.vx=(o.originalX-o.x)/n.forceTicksPerFrame,o.y=Math.min(i.size-o.dy/2,Math.max(o.dy/2,o.y))),t=Math.max(t,Math.abs(o.vx),Math.abs(o.vy))}!i.interactionState.dragInProgress&&t<.1&&i.forceLayouts[e].alpha()>0&&i.forceLayouts[e].alpha(0)}}(0,e,a,r)).stop()}(0,o,i),function(t,e,r,i,a){window.requestAnimationFrame(function o(){var s;for(s=0;s<n.forceTicksPerFrame;s++)r.forceLayouts[i].tick();var l=r.graph.nodes;if(function(t){for(var e=0;e<t.length;e++)t[e].y0=t[e].y-t[e].dy/2,t[e].y1=t[e].y0+t[e].dy,t[e].x0=t[e].x-t[e].dx/2,t[e].x1=t[e].x0+t[e].dx}(l),r.sankey.update(r.graph),_(t.filter(D(r)),e),r.forceLayouts[i].alpha()>0)window.requestAnimationFrame(o);else{var c=r.node.originalX;r.node.x0=c-r.visibleWidth/2,r.node.x1=c+r.visibleWidth/2,z(r,a)}})}(t,e,i,o,a)}}).on(\"drag\",function(r){if(\"fixed\"!==r.arrangement){var n=i.event.x,a=i.event.y;\"snap\"===r.arrangement?(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2,r.node.y0=a-r.visibleHeight/2,r.node.y1=a+r.visibleHeight/2):(\"freeform\"===r.arrangement&&(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2),a=Math.max(0,Math.min(r.size-r.visibleHeight/2,a)),r.node.y0=a-r.visibleHeight/2,r.node.y1=a+r.visibleHeight/2),I(r.node),\"snap\"!==r.arrangement&&(r.sankey.update(r.graph),_(t.filter(D(r)),e))}}).on(\"dragend\",function(t){if(\"fixed\"!==t.arrangement){t.interactionState.dragInProgress=!1;for(var e=0;e<t.node.childrenNodes.length;e++)t.node.childrenNodes[e].x=t.node.x,t.node.childrenNodes[e].y=t.node.y;\"snap\"!==t.arrangement&&z(t,a)}});t.on(\".drag\",null).call(o)}function z(t,e){for(var r=[],n=[],i=0;i<t.graph.nodes.length;i++){var a=(t.graph.nodes[i].x0+t.graph.nodes[i].x1)/2,o=(t.graph.nodes[i].y0+t.graph.nodes[i].y1)/2;r.push(a/t.figure.width),n.push(o/t.figure.height)}m.call(\"_guiRestyle\",e,{\"node.x\":[r],\"node.y\":[n]},t.trace.index).then(function(){e._fullLayout._dragCover&&e._fullLayout._dragCover.remove()})}function I(t){t.lastDraggedX=t.x0+t.dx/2,t.lastDraggedY=t.y0+t.dy/2}function D(t){return function(e){return e.node.originalX===t.node.originalX}}e.exports=function(t,e,r,u,f){var v=!1;h.ensureSingle(t._fullLayout._infolayer,\"g\",\"first-render\",function(){v=!0});var m=t._fullLayout._dragCover,b=r.filter(function(t){return g(t).trace.visible}).map(function(t,e,r){var i,o=g(e),s=o.trace,u=s.domain,f=\"h\"===s.orientation,p=s.node.pad,d=s.node.thickness,v=t.width*(u.x[1]-u.x[0]),m=t.height*(u.y[1]-u.y[0]),y=o._nodes,x=o._links,b=o.circular;(i=b?c.sankeyCircular().circularLinkGap(0):l.sankey()).iterations(n.sankeyIterations).size(f?[v,m]:[m,v]).nodeWidth(d).nodePadding(p).nodeId(function(t){return t.pointNumber}).nodes(y).links(x);var _,w,k,T=i();for(var A in i.nodePadding()<p&&h.warn(\"node.pad was reduced to \",i.nodePadding(),\" to fit within the figure.\"),o._groupLookup){var M,S=parseInt(o._groupLookup[A]);for(_=0;_<T.nodes.length;_++)if(T.nodes[_].pointNumber===S){M=T.nodes[_];break}if(M){var E={pointNumber:parseInt(A),x0:M.x0,x1:M.x1,y0:M.y0,y1:M.y1,partOfGroup:!0,sourceLinks:[],targetLinks:[]};T.nodes.unshift(E),M.childrenNodes.unshift(E)}}if(function(){for(_=0;_<T.nodes.length;_++){var t,e,r=T.nodes[_],n={};for(w=0;w<r.targetLinks.length;w++)t=(e=r.targetLinks[w]).source.pointNumber+\":\"+e.target.pointNumber,n.hasOwnProperty(t)||(n[t]=[]),n[t].push(e);var i=Object.keys(n);for(w=0;w<i.length;w++){var o=n[t=i[w]],s=0,l={};for(k=0;k<o.length;k++)l[(e=o[k]).label]||(l[e.label]=0),l[e.label]+=e.value,s+=e.value;for(k=0;k<o.length;k++)(e=o[k]).flow={value:s,labelConcentration:l[e.label]/s,concentration:e.value/s,links:o},e.concentrationscale&&(e.color=a(e.concentrationscale(e.flow.labelConcentration)))}var c=0;for(w=0;w<r.sourceLinks.length;w++)c+=r.sourceLinks[w].value;for(w=0;w<r.sourceLinks.length;w++)(e=r.sourceLinks[w]).concentrationOut=e.value/c;var u=0;for(w=0;w<r.targetLinks.length;w++)u+=r.targetLinks[w].value;for(w=0;w<r.targetLinks.length;w++)(e=r.targetLinks[w]).concenrationIn=e.value/u}}(),s.node.x.length&&s.node.y.length){for(_=0;_<Math.min(s.node.x.length,s.node.y.length,T.nodes.length);_++)if(s.node.x[_]&&s.node.y[_]){var C=[s.node.x[_]*v,s.node.y[_]*m];T.nodes[_].x0=C[0]-d/2,T.nodes[_].x1=C[0]+d/2;var L=T.nodes[_].y1-T.nodes[_].y0;T.nodes[_].y0=C[1]-L/2,T.nodes[_].y1=C[1]+L/2}\"snap\"===s.arrangement&&function(t){t.forEach(function(t){var e,r,n,i=0,a=t.length;for(t.sort(function(t,e){return t.y0-e.y0}),n=0;n<a;++n)(e=t[n]).y0>=i||(r=i-e.y0)>1e-6&&(e.y0+=r,e.y1+=r),i=e.y1+p})}(function(t){var e,r,n=t.map(function(t,e){return{x0:t.x0,index:e}}).sort(function(t,e){return t.x0-e.x0}),i=[],a=-1,o=-1/0;for(_=0;_<n.length;_++){var s=t[n[_].index];s.x0>o+d&&(a+=1,e=s.x0),o=s.x0,i[a]||(i[a]=[]),i[a].push(s),r=e-s.x0,s.x0+=r,s.x1+=r}return i}(y=T.nodes)),i.update(T)}return{circular:b,key:r,trace:s,guid:h.randstr(),horizontal:f,width:v,height:m,nodePad:s.node.pad,nodeLineColor:s.node.line.color,nodeLineWidth:s.node.line.width,linkLineColor:s.link.line.color,linkLineWidth:s.link.line.width,valueFormat:s.valueformat,valueSuffix:s.valuesuffix,textFont:s.textfont,translateX:u.x[0]*t.width+t.margin.l,translateY:t.height-u.y[1]*t.height+t.margin.t,dragParallel:f?m:v,dragPerpendicular:f?v:m,arrangement:s.arrangement,sankey:i,graph:T,forceLayouts:{},interactionState:{dragInProgress:!1,hovered:!1}}}.bind(null,u)),_=e.selectAll(\".\"+n.cn.sankey).data(b,p);_.exit().remove(),_.enter().append(\"g\").classed(n.cn.sankey,!0).style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"shape-rendering\",\"geometricPrecision\").style(\"pointer-events\",\"auto\").attr(\"transform\",T),_.each(function(e,r){t._fullData[r]._sankey=e;var n=\"bgsankey-\"+e.trace.uid+\"-\"+r;h.ensureSingle(t._fullLayout._draggers,\"rect\",n),t._fullData[r]._bgRect=i.select(\".\"+n),t._fullData[r]._bgRect.style(\"pointer-events\",\"all\").attr(\"width\",e.width).attr(\"height\",e.height).attr(\"x\",e.translateX).attr(\"y\",e.translateY).classed(\"bgsankey\",!0).style({fill:\"transparent\",\"stroke-width\":0})}),_.transition().ease(n.ease).duration(n.duration).attr(\"transform\",T);var z=_.selectAll(\".\"+n.cn.sankeyLinks).data(d,p);z.enter().append(\"g\").classed(n.cn.sankeyLinks,!0).style(\"fill\",\"none\");var I=z.selectAll(\".\"+n.cn.sankeyLink).data(function(t){return t.graph.links.filter(function(t){return t.value}).map(function(t,e,r){var n=a(e.color),i=e.source.label+\"|\"+e.target.label+\"__\"+r;return e.trace=t.trace,e.curveNumber=t.trace.index,{circular:t.circular,key:i,traceId:t.key,pointNumber:e.pointNumber,link:e,tinyColorHue:o.tinyRGB(n),tinyColorAlpha:n.getAlpha(),linkPath:y,linkLineColor:t.linkLineColor,linkLineWidth:t.linkLineWidth,valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,parent:t,interactionState:t.interactionState,flow:e.flow}}.bind(null,t))},p);I.enter().append(\"path\").classed(n.cn.sankeyLink,!0).call(P,_,f.linkEvents),I.style(\"stroke\",function(t){return k(t)?o.tinyRGB(a(t.linkLineColor)):t.tinyColorHue}).style(\"stroke-opacity\",function(t){return k(t)?o.opacity(t.linkLineColor):t.tinyColorAlpha}).style(\"fill\",function(t){return t.tinyColorHue}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}).style(\"stroke-width\",function(t){return k(t)?t.linkLineWidth:1}).attr(\"d\",y()),I.style(\"opacity\",function(){return t._context.staticPlot||v||m?1:0}).transition().ease(n.ease).duration(n.duration).style(\"opacity\",1),I.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var D=_.selectAll(\".\"+n.cn.sankeyNodeSet).data(d,p);D.enter().append(\"g\").classed(n.cn.sankeyNodeSet,!0),D.style(\"cursor\",function(t){switch(t.arrangement){case\"fixed\":return\"default\";case\"perpendicular\":return\"ns-resize\";default:return\"move\"}});var R=D.selectAll(\".\"+n.cn.sankeyNode).data(function(t){var e=t.graph.nodes;return function(t){var e,r=[];for(e=0;e<t.length;e++)t[e].originalX=(t[e].x0+t[e].x1)/2,t[e].originalY=(t[e].y0+t[e].y1)/2,-1===r.indexOf(t[e].originalX)&&r.push(t[e].originalX);for(r.sort(function(t,e){return t-e}),e=0;e<t.length;e++)t[e].originalLayerIndex=r.indexOf(t[e].originalX),t[e].originalLayer=t[e].originalLayerIndex/(r.length-1)}(e),e.map(function(t,e){var r=a(e.color),i=n.nodePadAcross,s=t.nodePad/2;e.dx=e.x1-e.x0,e.dy=e.y1-e.y0;var l=e.dx,c=Math.max(.5,e.dy),u=\"node_\"+e.pointNumber;return e.group&&(u=h.randstr()),e.trace=t.trace,e.curveNumber=t.trace.index,{index:e.pointNumber,key:u,partOfGroup:e.partOfGroup||!1,group:e.group,traceId:t.key,trace:t.trace,node:e,nodePad:t.nodePad,nodeLineColor:t.nodeLineColor,nodeLineWidth:t.nodeLineWidth,textFont:t.textFont,size:t.horizontal?t.height:t.width,visibleWidth:Math.ceil(l),visibleHeight:c,zoneX:-i,zoneY:-s,zoneWidth:l+2*i,zoneHeight:c+2*s,labelY:t.horizontal?e.dy/2+1:e.dx/2+1,left:1===e.originalLayer,sizeAcross:t.width,forceLayouts:t.forceLayouts,horizontal:t.horizontal,darkBackground:r.getBrightness()<=128,tinyColorHue:o.tinyRGB(r),tinyColorAlpha:r.getAlpha(),valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,graph:t.graph,arrangement:t.arrangement,uniqueNodeLabelPathId:[t.guid,t.key,u].join(\"_\"),interactionState:t.interactionState,figure:t}}.bind(null,t))},p);R.enter().append(\"g\").classed(n.cn.sankeyNode,!0).call(x).style(\"opacity\",function(e){return!t._context.staticPlot&&!v||e.partOfGroup?0:1}),R.call(P,_,f.nodeEvents).call(O,I,f,t),R.transition().ease(n.ease).duration(n.duration).call(x).style(\"opacity\",function(t){return t.partOfGroup?0:1}),R.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var F=R.selectAll(\".\"+n.cn.nodeRect).data(d);F.enter().append(\"rect\").classed(n.cn.nodeRect,!0).call(w),F.style(\"stroke-width\",function(t){return t.nodeLineWidth}).style(\"stroke\",function(t){return o.tinyRGB(a(t.nodeLineColor))}).style(\"stroke-opacity\",function(t){return o.opacity(t.nodeLineColor)}).style(\"fill\",function(t){return t.tinyColorHue}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),F.transition().ease(n.ease).duration(n.duration).call(w);var B=R.selectAll(\".\"+n.cn.nodeCapture).data(d);B.enter().append(\"rect\").classed(n.cn.nodeCapture,!0).style(\"fill-opacity\",0),B.attr(\"x\",function(t){return t.zoneX}).attr(\"y\",function(t){return t.zoneY}).attr(\"width\",function(t){return t.zoneWidth}).attr(\"height\",function(t){return t.zoneHeight});var N=R.selectAll(\".\"+n.cn.nodeCentered).data(d);N.enter().append(\"g\").classed(n.cn.nodeCentered,!0).attr(\"transform\",A),N.transition().ease(n.ease).duration(n.duration).attr(\"transform\",A);var j=N.selectAll(\".\"+n.cn.nodeLabelGuide).data(d);j.enter().append(\"path\").classed(n.cn.nodeLabelGuide,!0).attr(\"id\",function(t){return t.uniqueNodeLabelPathId}).attr(\"d\",M).attr(\"transform\",S),j.transition().ease(n.ease).duration(n.duration).attr(\"d\",M).attr(\"transform\",S);var U=N.selectAll(\".\"+n.cn.nodeLabel).data(d);U.enter().append(\"text\").classed(n.cn.nodeLabel,!0).attr(\"transform\",E).style(\"user-select\",\"none\").style(\"cursor\",\"default\").style(\"fill\",\"black\"),U.style(\"text-shadow\",function(t){return t.horizontal?\"-1px 1px 1px #fff, 1px 1px 1px #fff, 1px -1px 1px #fff, -1px -1px 1px #fff\":\"none\"}).each(function(t){s.font(U,t.textFont)}),U.transition().ease(n.ease).duration(n.duration).attr(\"transform\",E);var V=U.selectAll(\".\"+n.cn.nodeLabelTextPath).data(d);V.enter().append(\"textPath\").classed(n.cn.nodeLabelTextPath,!0).attr(\"alignment-baseline\",\"middle\").attr(\"xlink:href\",function(t){return\"#\"+t.uniqueNodeLabelPathId}).attr(\"startOffset\",L).style(\"fill\",C),V.text(function(t){return t.horizontal||t.node.dy>5?t.node.label:\"\"}).attr(\"text-anchor\",function(t){return t.horizontal&&t.left?\"end\":\"start\"}),V.transition().ease(n.ease).duration(n.duration).attr(\"startOffset\",L).style(\"fill\",C)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/gup\":717,\"../../registry\":847,\"./constants\":1105,\"@plotly/d3-sankey\":54,\"@plotly/d3-sankey-circular\":53,d3:163,\"d3-force\":156,\"d3-interpolate\":158,tinycolor2:537}],1110:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=[],n=t.cd[0].trace,i=n._sankey.graph.nodes,a=0;a<i.length;a++){var o=i[a];if(!o.partOfGroup){var s=[(o.x0+o.x1)/2,(o.y0+o.y1)/2];\"v\"===n.orientation&&s.reverse(),e&&e.contains(s,!1,a,t)&&r.push({pointNumber:o.pointNumber})}}return r}},{}],1111:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\"),n.mergeArray(e.customdata,t,\"data\"),n.mergeArray(e.textposition,t,\"tp\"),e.textfont&&(n.mergeArrayCastPositive(e.textfont.size,t,\"ts\"),n.mergeArray(e.textfont.color,t,\"tc\"),n.mergeArray(e.textfont.family,t,\"tf\"));var i=e.marker;if(i){n.mergeArrayCastPositive(i.size,t,\"ms\"),n.mergeArrayCastPositive(i.opacity,t,\"mo\"),n.mergeArray(i.symbol,t,\"mx\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;i.line&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"));var o=i.gradient;o&&\"none\"!==o.type&&(n.mergeArray(o.type,t,\"mgt\"),n.mergeArray(o.color,t,\"mgc\"))}}},{\"../../lib\":719}],1112:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../components/drawing/attributes\").dash,s=t(\"../../components/drawing\"),l=t(\"./constants\"),c=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},x0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dx:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},y0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dy:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},stackgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc\"},groupnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},stackgaps:{valType:\"enumerated\",values:[\"infer zero\",\"interpolate\"],dflt:\"infer zero\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"],editType:\"calc\"},hoveron:{valType:\"flaglist\",flags:[\"points\",\"fills\"],editType:\"style\"},hovertemplate:n({},{keys:l.eventDataKeys}),line:{color:{valType:\"color\",editType:\"style\",anim:!0},width:{valType:\"number\",min:0,dflt:2,editType:\"style\",anim:!0},shape:{valType:\"enumerated\",values:[\"linear\",\"spline\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},smoothing:{valType:\"number\",min:0,max:1.3,dflt:1,editType:\"plot\"},dash:c({},o,{editType:\"style\"}),simplify:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cliponaxis:{valType:\"boolean\",dflt:!0,editType:\"plot\"},fill:{valType:\"enumerated\",values:[\"none\",\"tozeroy\",\"tozerox\",\"tonexty\",\"tonextx\",\"toself\",\"tonext\"],editType:\"calc\"},fillcolor:{valType:\"color\",editType:\"style\",anim:!0},marker:c({symbol:{valType:\"enumerated\",values:s.symbolList,dflt:\"circle\",arrayOk:!0,editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,arrayOk:!0,editType:\"style\",anim:!0},size:{valType:\"number\",min:0,dflt:6,arrayOk:!0,editType:\"calc\",anim:!0},maxdisplayed:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},sizeref:{valType:\"number\",dflt:1,editType:\"calc\"},sizemin:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"diameter\",\"area\"],dflt:\"diameter\",editType:\"calc\"},line:c({width:{valType:\"number\",min:0,arrayOk:!0,editType:\"style\",anim:!0},editType:\"calc\"},i(\"marker.line\",{anim:!0})),gradient:{type:{valType:\"enumerated\",values:[\"radial\",\"horizontal\",\"vertical\",\"none\"],arrayOk:!0,dflt:\"none\",editType:\"calc\"},color:{valType:\"color\",arrayOk:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},i(\"marker\",{anim:!0})),selected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},unselected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\"],dflt:\"middle center\",arrayOk:!0,editType:\"calc\"},textfont:a({editType:\"calc\",colorEditType:\"style\",arrayOk:!0}),r:{valType:\"data_array\",editType:\"calc\"},t:{valType:\"data_array\",editType:\"calc\"}}},{\"../../components/colorscale/attributes\":600,\"../../components/drawing\":614,\"../../components/drawing/attributes\":613,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"./constants\":1116}],1113:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/numerical\").BADNUM,s=t(\"./subtypes\"),l=t(\"./colorscale_calc\"),c=t(\"./arrays_to_calcdata\"),u=t(\"./calc_selection\");function h(t,e,r,n,i,o,l){var c=e._length,u=t._fullLayout,h=r._id,f=n._id,p=u._firstScatter[d(e)]===e.uid,v=(g(e,u,r,n)||{}).orientation,m=e.fill;r._minDtick=0,n._minDtick=0;var y={padded:!0},x={padded:!0};l&&(y.ppad=x.ppad=l);var b=c<2||i[0]!==i[c-1]||o[0]!==o[c-1];b&&(\"tozerox\"===m||\"tonextx\"===m&&(p||\"h\"===v))?y.tozero=!0:(e.error_y||{}).visible||\"tonexty\"!==m&&\"tozeroy\"!==m&&(s.hasMarkers(e)||s.hasText(e))||(y.padded=!1,y.ppad=0),b&&(\"tozeroy\"===m||\"tonexty\"===m&&(p||\"v\"===v))?x.tozero=!0:\"tonextx\"!==m&&\"tozerox\"!==m||(x.padded=!1),h&&(e._extremes[h]=a.findExtremes(r,i,y)),f&&(e._extremes[f]=a.findExtremes(n,o,x))}function f(t,e){if(s.hasMarkers(t)){var r,n=t.marker,o=1.6*(t.marker.sizeref||1);if(r=\"area\"===t.marker.sizemode?function(t){return Math.max(Math.sqrt((t||0)/o),3)}:function(t){return Math.max((t||0)/o,3)},i.isArrayOrTypedArray(n.size)){var l={type:\"linear\"};a.setConvert(l);for(var c=l.makeCalcdata(t.marker,\"size\"),u=new Array(e),h=0;h<e;h++)u[h]=r(c[h]);return u}return r(n.size)}}function p(t,e){var r=d(e),n=t._firstScatter;n[r]||(n[r]=e.uid)}function d(t){var e=t.stackgroup;return t.xaxis+t.yaxis+t.type+(e?\"-\"+e:\"\")}function g(t,e,r,n){var i=t.stackgroup;if(i){var a=e._scatterStackOpts[r._id+n._id][i],o=\"v\"===a.orientation?n:r;return\"linear\"===o.type||\"log\"===o.type?a:void 0}}e.exports={calc:function(t,e){var r,s,d,v,m,y,x=t._fullLayout,b=a.getFromId(t,e.xaxis||\"x\"),_=a.getFromId(t,e.yaxis||\"y\"),w=b.makeCalcdata(e,\"x\"),k=_.makeCalcdata(e,\"y\"),T=e._length,A=new Array(T),M=e.ids,S=g(e,x,b,_),E=!1;p(x,e);var C,L=\"x\",P=\"y\";for(S?(i.pushUnique(S.traceIndices,e._expandedIndex),(r=\"v\"===S.orientation)?(P=\"s\",C=\"x\"):(L=\"s\",C=\"y\"),m=\"interpolate\"===S.stackgaps):h(t,e,b,_,w,k,f(e,T)),s=0;s<T;s++){var O=A[s]={},z=n(w[s]),I=n(k[s]);z&&I?(O[L]=w[s],O[P]=k[s]):S&&(r?z:I)?(O[C]=r?w[s]:k[s],O.gap=!0,m?(O.s=o,E=!0):O.s=0):O[L]=O[P]=o,M&&(O.id=String(M[s]))}if(c(A,e),l(t,e),u(A,e),S){for(s=0;s<A.length;)A[s][C]===o?A.splice(s,1):s++;if(i.sort(A,function(t,e){return t[C]-e[C]||t.i-e.i}),E){for(s=0;s<A.length-1&&A[s].gap;)s++;for((y=A[s].s)||(y=A[s].s=0),d=0;d<s;d++)A[d].s=y;for(v=A.length-1;v>s&&A[v].gap;)v--;for(y=A[v].s,d=A.length-1;d>v;d--)A[d].s=y;for(;s<v;)if(A[++s].gap){for(d=s+1;A[d].gap;)d++;for(var D=A[s-1][C],R=A[s-1].s,F=(A[d].s-R)/(A[d][C]-D);s<d;)A[s].s=R+(A[s][C]-D)*F,s++}}}return A},calcMarkerSize:f,calcAxisExpansion:h,setFirstScatter:p,getStackOpts:g}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./arrays_to_calcdata\":1111,\"./calc_selection\":1114,\"./colorscale_calc\":1115,\"./subtypes\":1135,\"fast-isnumeric\":225}],1114:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){n.isArrayOrTypedArray(e.selectedpoints)&&n.tagSelected(t,e)}},{\"../../lib\":719}],1115:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"./subtypes\");e.exports=function(t,e){a.hasLines(e)&&n(e,\"line\")&&i(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),a.hasMarkers(e)&&(n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}))}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"./subtypes\":1135}],1116:[function(t,e,r){\"use strict\";e.exports={PTS_LINESONLY:20,minTolerance:.2,toleranceGrowth:10,maxScreensAway:20,eventDataKeys:[]}},{}],1117:[function(t,e,r){\"use strict\";var n=t(\"./calc\");function i(t,e,r,n,i,a,o){i[n]=!0;var s={i:null,gap:!0,s:0};if(s[o]=r,t.splice(e,0,s),e&&r===t[e-1][o]){var l=t[e-1];s.s=l.s,s.i=l.i,s.gap=l.gap}else a&&(s.s=function(t,e,r,n){var i=t[e-1],a=t[e+1];return a?i?i.s+(a.s-i.s)*(r-i[n])/(a[n]-i[n]):a.s:i.s}(t,e,r,o));e||(t[0].t=t[1].t,t[0].trace=t[1].trace,delete t[1].t,delete t[1].trace)}e.exports=function(t,e){var r=e.xaxis,a=e.yaxis,o=r._id+a._id,s=t._fullLayout._scatterStackOpts[o];if(s){var l,c,u,h,f,p,d,g,v,m,y,x,b,_,w,k=t.calcdata;for(var T in s){var A=(m=s[T]).traceIndices;if(A.length){for(y=\"interpolate\"===m.stackgaps,x=m.groupnorm,\"v\"===m.orientation?(b=\"x\",_=\"y\"):(b=\"y\",_=\"x\"),w=new Array(A.length),l=0;l<w.length;l++)w[l]=!1;p=k[A[0]];var M=new Array(p.length);for(l=0;l<p.length;l++)M[l]=p[l][b];for(l=1;l<A.length;l++){for(f=k[A[l]],c=u=0;c<f.length;c++){for(d=f[c][b];d>M[u]&&u<M.length;u++)i(f,c,M[u],l,w,y,b),c++;if(d!==M[u]){for(h=0;h<l;h++)i(k[A[h]],u,d,h,w,y,b);M.splice(u,0,d)}u++}for(;u<M.length;u++)i(f,c,M[u],l,w,y,b),c++}var S=M.length;for(c=0;c<p.length;c++){for(g=p[c][_]=p[c].s,l=1;l<A.length;l++)(f=k[A[l]])[0].trace._rawLength=f[0].trace._length,f[0].trace._length=S,g+=f[c].s,f[c][_]=g;if(x)for(v=(\"fraction\"===x?g:g/100)||1,l=0;l<A.length;l++){var E=k[A[l]][c];E[_]/=v,E.sNorm=E.s/v}}for(l=0;l<A.length;l++){var C=(f=k[A[l]])[0].trace,L=n.calcMarkerSize(C,C._rawLength),P=Array.isArray(L);if(L&&w[l]||P){var O=L;for(L=new Array(S),c=0;c<S;c++)L[c]=f[c].gap?0:P?O[f[c].i]:O}var z=new Array(S),I=new Array(S);for(c=0;c<S;c++)z[c]=f[c].x,I[c]=f[c].y;n.calcAxisExpansion(t,C,r,a,z,I,L),f[0].t.orientation=m.orientation}}}}}},{\"./calc\":1113}],1118:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0;e<t.length;e++){var r=t[e];if(\"scatter\"===r.type){var n=r.fill;if(\"none\"!==n&&\"toself\"!==n&&(r.opacity=void 0,\"tonexty\"===n||\"tonextx\"===n))for(var i=e-1;i>=0;i--){var a=t[i];if(\"scatter\"===a.type&&a.xaxis===r.xaxis&&a.yaxis===r.yaxis){a.opacity=void 0;break}}}}}},{}],1119:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"./constants\"),s=t(\"./subtypes\"),l=t(\"./xy_defaults\"),c=t(\"./stack_defaults\"),u=t(\"./marker_defaults\"),h=t(\"./line_defaults\"),f=t(\"./line_shape_defaults\"),p=t(\"./text_defaults\"),d=t(\"./fillcolor_defaults\");e.exports=function(t,e,r,g){function v(r,i){return n.coerce(t,e,a,r,i)}var m=l(t,e,g,v);if(m||(e.visible=!1),e.visible){var y=c(t,e,g,v),x=!y&&m<o.PTS_LINESONLY?\"lines+markers\":\"lines\";v(\"text\"),v(\"hovertext\"),v(\"mode\",x),s.hasLines(e)&&(h(t,e,r,g,v),f(t,e,v),v(\"connectgaps\"),v(\"line.simplify\")),s.hasMarkers(e)&&u(t,e,r,g,v,{gradient:!0}),s.hasText(e)&&p(t,e,g,v);var b=[];(s.hasMarkers(e)||s.hasText(e))&&(v(\"cliponaxis\"),v(\"marker.maxdisplayed\"),b.push(\"points\")),v(\"fill\",y?y.fillDflt:\"none\"),\"none\"!==e.fill&&(d(t,e,r,v),s.hasLines(e)||f(t,e,v));var _=(e.line||{}).color,w=(e.marker||{}).color;\"tonext\"!==e.fill&&\"toself\"!==e.fill||b.push(\"fills\"),v(\"hoveron\",b.join(\"+\")||\"points\"),\"fills\"!==e.hoveron&&v(\"hovertemplate\");var k=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");k(t,e,_||w||r,{axis:\"y\"}),k(t,e,_||w||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,v)}}},{\"../../lib\":719,\"../../registry\":847,\"./attributes\":1112,\"./constants\":1116,\"./fillcolor_defaults\":1120,\"./line_defaults\":1124,\"./line_shape_defaults\":1126,\"./marker_defaults\":1130,\"./stack_defaults\":1133,\"./subtypes\":1135,\"./text_defaults\":1136,\"./xy_defaults\":1137}],1120:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a){var o=!1;if(e.marker){var s=e.marker.color,l=(e.marker.line||{}).color;s&&!i(s)?o=s:l&&!i(l)&&(o=l)}a(\"fillcolor\",n.addOpacity((e.line||{}).color||o||r,.5))}},{\"../../components/color\":593,\"../../lib\":719}],1121:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./subtypes\");e.exports=function(t,e){var r,a;if(\"lines\"===t.mode)return(r=t.line.color)&&n.opacity(r)?r:t.fillcolor;if(\"none\"===t.mode)return t.fill?t.fillcolor:\"\";var o=e.mcc||(t.marker||{}).color,s=e.mlcc||((t.marker||{}).line||{}).color;return(a=o&&n.opacity(o)?o:s&&n.opacity(s)&&(e.mlw||((t.marker||{}).line||{}).width)?s:\"\")?n.opacity(a)<.3?n.addOpacity(a,.3):a:(r=(t.line||{}).color)&&n.opacity(r)&&i.hasLines(t)&&t.line.width?r:t.fillcolor}},{\"../../components/color\":593,\"./subtypes\":1135}],1122:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/fx\"),a=t(\"../../registry\"),o=t(\"./get_trace_color\"),s=t(\"../../components/color\"),l=n.fillText;e.exports=function(t,e,r,c){var u=t.cd,h=u[0].trace,f=t.xa,p=t.ya,d=f.c2p(e),g=p.c2p(r),v=[d,g],m=h.hoveron||\"\",y=-1!==h.mode.indexOf(\"markers\")?3:.5;if(-1!==m.indexOf(\"points\")){var x=function(t){var e=Math.max(y,t.mrc||0),r=f.c2p(t.x)-d,n=p.c2p(t.y)-g;return Math.max(Math.sqrt(r*r+n*n)-e,1-y/e)},b=i.getDistanceFunction(c,function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(f.c2p(t.x)-d);return n<e?r*n/e:n-e+r},function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(p.c2p(t.y)-g);return n<e?r*n/e:n-e+r},x);if(i.getClosest(u,b,t),!1!==t.index){var _=u[t.index],w=f.c2p(_.x,!0),k=p.c2p(_.y,!0),T=_.mrc||1;t.index=_.i;var A=u[0].t.orientation,M=A&&(_.sNorm||_.s),S=\"h\"===A?M:_.x,E=\"v\"===A?M:_.y;return n.extendFlat(t,{color:o(h,_),x0:w-T,x1:w+T,xLabelVal:S,y0:k-T,y1:k+T,yLabelVal:E,spikeDistance:x(_),hovertemplate:h.hovertemplate}),l(_,h,t),a.getComponentMethod(\"errorbars\",\"hoverInfo\")(_,h,t),[t]}}if(-1!==m.indexOf(\"fills\")&&h._polygons){var C,L,P,O,z,I,D,R,F,B=h._polygons,N=[],j=!1,U=1/0,V=-1/0,q=1/0,H=-1/0;for(C=0;C<B.length;C++)(P=B[C]).contains(v)&&(j=!j,N.push(P),q=Math.min(q,P.ymin),H=Math.max(H,P.ymax));if(j){var G=((q=Math.max(q,0))+(H=Math.min(H,p._length)))/2;for(C=0;C<N.length;C++)for(O=N[C].pts,L=1;L<O.length;L++)(R=O[L-1][1])>G!=(F=O[L][1])>=G&&(I=O[L-1][0],D=O[L][0],F-R&&(z=I+(D-I)*(G-R)/(F-R),U=Math.min(U,z),V=Math.max(V,z)));U=Math.max(U,0),V=Math.min(V,f._length);var Y=s.defaultLine;return s.opacity(h.fillcolor)?Y=h.fillcolor:s.opacity((h.line||{}).color)&&(Y=h.line.color),n.extendFlat(t,{distance:t.maxHoverDistance,x0:U,x1:V,y0:G,y1:G,color:Y,hovertemplate:!1}),delete t.index,h.text&&!Array.isArray(h.text)?t.text=String(h.text):t.text=h.name,[t]}}}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"../../registry\":847,\"./get_trace_color\":1121}],1123:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports={hasLines:n.hasLines,hasMarkers:n.hasMarkers,hasText:n.hasText,isBubble:n.isBubble,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./cross_trace_calc\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\"),colorbar:t(\"./marker_colorbar\"),style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"./select\"),animatable:!0,moduleType:\"trace\",name:\"scatter\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"./arrays_to_calcdata\":1111,\"./attributes\":1112,\"./calc\":1113,\"./cross_trace_calc\":1117,\"./cross_trace_defaults\":1118,\"./defaults\":1119,\"./hover\":1122,\"./marker_colorbar\":1129,\"./plot\":1131,\"./select\":1132,\"./style\":1134,\"./subtypes\":1135}],1124:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s,l){var c=(t.marker||{}).color;(s(\"line.color\",r),i(t,\"line\"))?a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}):s(\"line.color\",!n(c)&&c||r);s(\"line.width\"),(l||{}).noDash||s(\"line.dash\")}},{\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"../../lib\":719}],1125:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.BADNUM,a=n.LOG_CLIP,o=a+.5,s=a-.5,l=t(\"../../lib\"),c=l.segmentsIntersect,u=l.constrain,h=t(\"./constants\");e.exports=function(t,e){var r,n,a,f,p,d,g,v,m,y,x,b,_,w,k,T,A,M,S=e.xaxis,E=e.yaxis,C=\"log\"===S.type,L=\"log\"===E.type,P=S._length,O=E._length,z=e.connectGaps,I=e.baseTolerance,D=e.shape,R=\"linear\"===D,F=e.fill&&\"none\"!==e.fill,B=[],N=h.minTolerance,j=t.length,U=new Array(j),V=0;function q(e){var r=t[e];if(!r)return!1;var n=S.c2p(r.x),a=E.c2p(r.y);if(n===i){if(C&&(n=S.c2p(r.x,!0)),n===i)return!1;L&&a===i&&(n*=Math.abs(S._m*O*(S._m>0?o:s)/(E._m*P*(E._m>0?o:s)))),n*=1e3}if(a===i){if(L&&(a=E.c2p(r.y,!0)),a===i)return!1;a*=1e3}return[n,a]}function H(t,e,r,n){var i=r-t,a=n-e,o=.5-t,s=.5-e,l=i*i+a*a,c=i*o+a*s;if(c>0&&c<l){var u=o*a-s*i;if(u*u<l)return!0}}function G(t,e){var r=t[0]/P,n=t[1]/O,i=Math.max(0,-r,r-1,-n,n-1);return i&&void 0!==A&&H(r,n,A,M)&&(i=0),i&&e&&H(r,n,e[0]/P,e[1]/O)&&(i=0),(1+h.toleranceGrowth*i)*I}function Y(t,e){var r=t[0]-e[0],n=t[1]-e[1];return Math.sqrt(r*r+n*n)}var W,X,Z,J,K,$,Q,tt=h.maxScreensAway,et=-P*tt,rt=P*(1+tt),nt=-O*tt,it=O*(1+tt),at=[[et,nt,rt,nt],[rt,nt,rt,it],[rt,it,et,it],[et,it,et,nt]];function ot(t){if(t[0]<et||t[0]>rt||t[1]<nt||t[1]>it)return[u(t[0],et,rt),u(t[1],nt,it)]}function st(t,e){return t[0]===e[0]&&(t[0]===et||t[0]===rt)||(t[1]===e[1]&&(t[1]===nt||t[1]===it)||void 0)}function lt(t,e,r){return function(n,i){var a=ot(n),o=ot(i),s=[];if(a&&o&&st(a,o))return s;a&&s.push(a),o&&s.push(o);var c=2*l.constrain((n[t]+i[t])/2,e,r)-((a||n)[t]+(o||i)[t]);c&&((a&&o?c>0==a[t]>o[t]?a:o:a||o)[t]+=c);return s}}function ct(t){var e=t[0],r=t[1],n=e===U[V-1][0],i=r===U[V-1][1];if(!n||!i)if(V>1){var a=e===U[V-2][0],o=r===U[V-2][1];n&&(e===et||e===rt)&&a?o?V--:U[V-1]=t:i&&(r===nt||r===it)&&o?a?V--:U[V-1]=t:U[V++]=t}else U[V++]=t}function ut(t){U[V-1][0]!==t[0]&&U[V-1][1]!==t[1]&&ct([Z,J]),ct(t),K=null,Z=J=0}function ht(t){if(A=t[0]/P,M=t[1]/O,W=t[0]<et?et:t[0]>rt?rt:0,X=t[1]<nt?nt:t[1]>it?it:0,W||X){if(V)if(K){var e=Q(K,t);e.length>1&&(ut(e[0]),U[V++]=e[1])}else $=Q(U[V-1],t)[0],U[V++]=$;else U[V++]=[W||t[0],X||t[1]];var r=U[V-1];W&&X&&(r[0]!==W||r[1]!==X)?(K&&(Z!==W&&J!==X?ct(Z&&J?(n=K,a=(i=t)[0]-n[0],o=(i[1]-n[1])/a,(n[1]*i[0]-i[1]*n[0])/a>0?[o>0?et:rt,it]:[o>0?rt:et,nt]):[Z||W,J||X]):Z&&J&&ct([Z,J])),ct([W,X])):Z-W&&J-X&&ct([W||Z,X||J]),K=t,Z=W,J=X}else K&&ut(Q(K,t)[0]),U[V++]=t;var n,i,a,o}for(\"linear\"===D||\"spline\"===D?Q=function(t,e){for(var r=[],n=0,i=0;i<4;i++){var a=at[i],o=c(t[0],t[1],e[0],e[1],a[0],a[1],a[2],a[3]);o&&(!n||Math.abs(o.x-r[0][0])>1||Math.abs(o.y-r[0][1])>1)&&(o=[o.x,o.y],n&&Y(o,t)<Y(r[0],t)?r.unshift(o):r.push(o),n++)}return r}:\"hv\"===D||\"vh\"===D?Q=function(t,e){var r=[],n=ot(t),i=ot(e);return n&&i&&st(n,i)?r:(n&&r.push(n),i&&r.push(i),r)}:\"hvh\"===D?Q=lt(0,et,rt):\"vhv\"===D&&(Q=lt(1,nt,it)),r=0;r<j;r++)if(n=q(r)){for(V=0,K=null,ht(n),r++;r<j;r++){if(!(f=q(r))){if(z)continue;break}if(R&&e.simplify){var ft=q(r+1);if(y=Y(f,n),F&&(0===V||V===j-1)||!(y<G(f,ft)*N)){for(v=[(f[0]-n[0])/y,(f[1]-n[1])/y],p=n,x=y,b=w=k=0,g=!1,a=f,r++;r<t.length;r++){if(d=ft,ft=q(r+1),!d){if(z)continue;break}if(T=(m=[d[0]-n[0],d[1]-n[1]])[0]*v[1]-m[1]*v[0],w=Math.min(w,T),(k=Math.max(k,T))-w>G(d,ft))break;a=d,(_=m[0]*v[0]+m[1]*v[1])>x?(x=_,f=d,g=!1):_<b&&(b=_,p=d,g=!0)}if(g?(ht(f),a!==p&&ht(p)):(p!==n&&ht(p),a!==f&&ht(f)),ht(a),r>=t.length||!d)break;ht(d),n=d}}else ht(f)}K&&ct([Z||K[0],J||K[1]]),B.push(U.slice(0,V))}return B}},{\"../../constants/numerical\":695,\"../../lib\":719,\"./constants\":1116}],1126:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){\"spline\"===r(\"line.shape\")&&r(\"line.smoothing\")}},{}],1127:[function(t,e,r){\"use strict\";var n={tonextx:1,tonexty:1,tonext:1};e.exports=function(t,e,r){var i,a,o,s,l,c={},u=!1,h=-1,f=0,p=-1;for(a=0;a<r.length;a++)(o=(i=r[a][0].trace).stackgroup||\"\")?o in c?l=c[o]:(l=c[o]=f,f++):i.fill in n&&p>=0?l=p:(l=p=f,f++),l<h&&(u=!0),i._groupIndex=h=l;var d=r.slice();u&&d.sort(function(t,e){var r=t[0].trace,n=e[0].trace;return r._groupIndex-n._groupIndex||r.index-n.index});var g={};for(a=0;a<d.length;a++)o=(i=d[a][0].trace).stackgroup||\"\",!0===i.visible?(i._nexttrace=null,i.fill in n&&(s=g[o],i._prevtrace=s||null,s&&(s._nexttrace=i)),i._ownfill=i.fill&&(\"tozero\"===i.fill.substr(0,6)||\"toself\"===i.fill||\"to\"===i.fill.substr(0,2)&&!i._prevtrace),g[o]=i):i._prevtrace=i._nexttrace=i._ownfill=null;return d}},{}],1128:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t){var e=t.marker,r=e.sizeref||1,i=e.sizemin||0,a=\"area\"===e.sizemode?function(t){return Math.sqrt(t/r)}:function(t){return t/r};return function(t){var e=a(t/2);return n(e)&&e>0?Math.max(e,i):0}}},{\"fast-isnumeric\":225}],1129:[function(t,e,r){\"use strict\";e.exports={container:\"marker\",min:\"cmin\",max:\"cmax\"}},{}],1130:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"./subtypes\");e.exports=function(t,e,r,s,l,c){var u=o.isBubble(t),h=(t.line||{}).color;(c=c||{},h&&(r=h),l(\"marker.symbol\"),l(\"marker.opacity\",u?.7:1),l(\"marker.size\"),l(\"marker.color\",r),i(t,\"marker\")&&a(t,e,s,l,{prefix:\"marker.\",cLetter:\"c\"}),c.noSelect||(l(\"selected.marker.color\"),l(\"unselected.marker.color\"),l(\"selected.marker.size\"),l(\"unselected.marker.size\")),c.noLine||(l(\"marker.line.color\",h&&!Array.isArray(h)&&e.marker.color!==h?h:u?n.background:n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,l,{prefix:\"marker.line.\",cLetter:\"c\"}),l(\"marker.line.width\",u?1:0)),u&&(l(\"marker.sizeref\"),l(\"marker.sizemin\"),l(\"marker.sizemode\")),c.gradient)&&(\"none\"!==l(\"marker.gradient.type\")&&l(\"marker.gradient.color\"))}},{\"../../components/color\":593,\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"./subtypes\":1135}],1131:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=a.ensureSingle,s=a.identity,l=t(\"../../components/drawing\"),c=t(\"./subtypes\"),u=t(\"./line_points\"),h=t(\"./link_traces\"),f=t(\"../../lib/polygon\").tester;function p(t,e,r,h,p,d,g){var v;!function(t,e,r,i,o){var s=r.xaxis,l=r.yaxis,u=n.extent(a.simpleMap(s.range,s.r2c)),h=n.extent(a.simpleMap(l.range,l.r2c)),f=i[0].trace;if(!c.hasMarkers(f))return;var p=f.marker.maxdisplayed;if(0===p)return;var d=i.filter(function(t){return t.x>=u[0]&&t.x<=u[1]&&t.y>=h[0]&&t.y<=h[1]}),g=Math.ceil(d.length/p),v=0;o.forEach(function(t,r){var n=t[0].trace;c.hasMarkers(n)&&n.marker.maxdisplayed>0&&r<e&&v++});var m=Math.round(v*g/3+Math.floor(v/3)*g/7.1);i.forEach(function(t){delete t.vis}),d.forEach(function(t,e){0===Math.round((e+m)%g)&&(t.vis=!0)})}(0,e,r,h,p);var m=!!g&&g.duration>0;function y(t){return m?t.transition():t}var x=r.xaxis,b=r.yaxis,_=h[0].trace,w=_.line,k=n.select(d),T=o(k,\"g\",\"errorbars\"),A=o(k,\"g\",\"lines\"),M=o(k,\"g\",\"points\"),S=o(k,\"g\",\"text\");if(i.getComponentMethod(\"errorbars\",\"plot\")(t,T,r,g),!0===_.visible){var E,C;y(k).style(\"opacity\",_.opacity);var L=_.fill.charAt(_.fill.length-1);\"x\"!==L&&\"y\"!==L&&(L=\"\"),h[0][r.isRangePlot?\"nodeRangePlot3\":\"node3\"]=k;var P,O,z=\"\",I=[],D=_._prevtrace;D&&(z=D._prevRevpath||\"\",C=D._nextFill,I=D._polygons);var R,F,B,N,j,U,V,q=\"\",H=\"\",G=[],Y=a.noop;if(E=_._ownFill,c.hasLines(_)||\"none\"!==_.fill){for(C&&C.datum(h),-1!==[\"hv\",\"vh\",\"hvh\",\"vhv\"].indexOf(w.shape)?(R=l.steps(w.shape),F=l.steps(w.shape.split(\"\").reverse().join(\"\"))):R=F=\"spline\"===w.shape?function(t){var e=t[t.length-1];return t.length>1&&t[0][0]===e[0]&&t[0][1]===e[1]?l.smoothclosed(t.slice(1),w.smoothing):l.smoothopen(t,w.smoothing)}:function(t){return\"M\"+t.join(\"L\")},B=function(t){return F(t.reverse())},G=u(h,{xaxis:x,yaxis:b,connectGaps:_.connectgaps,baseTolerance:Math.max(w.width||1,3)/4,shape:w.shape,simplify:w.simplify,fill:_.fill}),V=_._polygons=new Array(G.length),v=0;v<G.length;v++)_._polygons[v]=f(G[v]);G.length&&(N=G[0][0],U=(j=G[G.length-1])[j.length-1]),Y=function(t){return function(e){if(P=R(e),O=B(e),q?L?(q+=\"L\"+P.substr(1),H=O+\"L\"+H.substr(1)):(q+=\"Z\"+P,H=O+\"Z\"+H):(q=P,H=O),c.hasLines(_)&&e.length>1){var r=n.select(this);if(r.datum(h),t)y(r.style(\"opacity\",0).attr(\"d\",P).call(l.lineGroupStyle)).style(\"opacity\",1);else{var i=y(r);i.attr(\"d\",P),l.singleLineStyle(h,i)}}}}}var W=A.selectAll(\".js-line\").data(G);y(W.exit()).style(\"opacity\",0).remove(),W.each(Y(!1)),W.enter().append(\"path\").classed(\"js-line\",!0).style(\"vector-effect\",\"non-scaling-stroke\").call(l.lineGroupStyle).each(Y(!0)),l.setClipUrl(W,r.layerClipId,t),G.length?(E?(E.datum(h),N&&U&&(L?(\"y\"===L?N[1]=U[1]=b.c2p(0,!0):\"x\"===L&&(N[0]=U[0]=x.c2p(0,!0)),y(E).attr(\"d\",\"M\"+U+\"L\"+N+\"L\"+q.substr(1)).call(l.singleFillStyle)):y(E).attr(\"d\",q+\"Z\").call(l.singleFillStyle))):C&&(\"tonext\"===_.fill.substr(0,6)&&q&&z?(\"tonext\"===_.fill?y(C).attr(\"d\",q+\"Z\"+z+\"Z\").call(l.singleFillStyle):y(C).attr(\"d\",q+\"L\"+z.substr(1)+\"Z\").call(l.singleFillStyle),_._polygons=_._polygons.concat(I)):(Z(C),_._polygons=null)),_._prevRevpath=H,_._prevPolygons=V):(E?Z(E):C&&Z(C),_._polygons=_._prevRevpath=_._prevPolygons=null),M.datum(h),S.datum(h),function(e,i,a){var o,u=a[0].trace,h=c.hasMarkers(u),f=c.hasText(u),p=tt(u),d=et,g=et;if(h||f){var v=s,_=u.stackgroup,w=_&&\"infer zero\"===t._fullLayout._scatterStackOpts[x._id+b._id][_].stackgaps;u.marker.maxdisplayed||u._needsCull?v=w?K:J:_&&!w&&(v=$),h&&(d=v),f&&(g=v)}var k,T=(o=e.selectAll(\"path.point\").data(d,p)).enter().append(\"path\").classed(\"point\",!0);m&&T.call(l.pointStyle,u,t).call(l.translatePoints,x,b).style(\"opacity\",0).transition().style(\"opacity\",1),o.order(),h&&(k=l.makePointStyleFns(u)),o.each(function(e){var i=n.select(this),a=y(i);l.translatePoint(e,a,x,b)?(l.singlePointStyle(e,a,u,k,t),r.layerClipId&&l.hideOutsideRangePoint(e,a,x,b,u.xcalendar,u.ycalendar),u.customdata&&i.classed(\"plotly-customdata\",null!==e.data&&void 0!==e.data)):a.remove()}),m?o.exit().transition().style(\"opacity\",0).remove():o.exit().remove(),(o=i.selectAll(\"g\").data(g,p)).enter().append(\"g\").classed(\"textpoint\",!0).append(\"text\"),o.order(),o.each(function(t){var e=n.select(this),i=y(e.select(\"text\"));l.translatePoint(t,i,x,b)?r.layerClipId&&l.hideOutsideRangePoint(t,e,x,b,u.xcalendar,u.ycalendar):e.remove()}),o.selectAll(\"text\").call(l.textPointStyle,u,t).each(function(t){var e=x.c2p(t.x),r=b.c2p(t.y);n.select(this).selectAll(\"tspan.line\").each(function(){y(n.select(this)).attr({x:e,y:r})})}),o.exit().remove()}(M,S,h);var X=!1===_.cliponaxis?null:r.layerClipId;l.setClipUrl(M,X,t),l.setClipUrl(S,X,t)}function Z(t){y(t).attr(\"d\",\"M0,0Z\")}function J(t){return t.filter(function(t){return!t.gap&&t.vis})}function K(t){return t.filter(function(t){return t.vis})}function $(t){return t.filter(function(t){return!t.gap})}function Q(t){return t.id}function tt(t){if(t.ids)return Q}function et(){return!1}}e.exports=function(t,e,r,i,a,c){var u,f,d=!a,g=!!a&&a.duration>0,v=h(t,e,r);((u=i.selectAll(\"g.trace\").data(v,function(t){return t[0].trace.uid})).enter().append(\"g\").attr(\"class\",function(t){return\"trace scatter trace\"+t[0].trace.uid}).style(\"stroke-miterlimit\",2),u.order(),function(t,e,r){e.each(function(e){var i=o(n.select(this),\"g\",\"fills\");l.setClipUrl(i,r.layerClipId,t);var a=e[0].trace,c=[];a._ownfill&&c.push(\"_ownFill\"),a._nexttrace&&c.push(\"_nextFill\");var u=i.selectAll(\"g\").data(c,s);u.enter().append(\"g\"),u.exit().each(function(t){a[t]=null}).remove(),u.order().each(function(t){a[t]=o(n.select(this),\"path\",\"js-fill\")})})}(t,u,e),g)?(c&&(f=c()),n.transition().duration(a.duration).ease(a.easing).each(\"end\",function(){f&&f()}).each(\"interrupt\",function(){f&&f()}).each(function(){i.selectAll(\"g.trace\").each(function(r,n){p(t,n,e,r,v,this,a)})})):u.each(function(r,n){p(t,n,e,r,v,this,a)});d&&u.exit().remove(),i.selectAll(\"path:not([d])\").remove()}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/polygon\":731,\"../../registry\":847,\"./line_points\":1125,\"./link_traces\":1127,\"./subtypes\":1135,d3:163}],1132:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports=function(t,e){var r,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[],h=s[0].trace;if(!n.hasMarkers(h)&&!n.hasText(h))return[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)i=s[r],a=l.c2p(i.x),o=c.c2p(i.y),null!==i.i&&e.contains([a,o],!1,r,t)?(u.push({pointNumber:i.i,x:l.c2d(i.x),y:c.c2d(i.y)}),i.selected=1):i.selected=0;return u}},{\"./subtypes\":1135}],1133:[function(t,e,r){\"use strict\";var n=[\"orientation\",\"groupnorm\",\"stackgaps\"];e.exports=function(t,e,r,i){var a=r._scatterStackOpts,o=i(\"stackgroup\");if(o){var s=e.xaxis+e.yaxis,l=a[s];l||(l=a[s]={});var c=l[o],u=!1;c?c.traces.push(e):(c=l[o]={traceIndices:[],traces:[e]},u=!0);for(var h={orientation:e.x&&!e.y?\"h\":\"v\"},f=0;f<n.length;f++){var p=n[f],d=p+\"Found\";if(!c[d]){var g=void 0!==t[p],v=\"orientation\"===p;if((g||u)&&(c[p]=i(p,h[p]),v&&(c.fillDflt=\"h\"===c[p]?\"tonextx\":\"tonexty\"),g&&(c[d]=!0,!u&&(delete c.traces[0][p],v))))for(var m=0;m<c.traces.length-1;m++){var y=c.traces[m];y._input.fill!==y.fill&&(y.fill=c.fillDflt)}}}return c}}},{}],1134:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../registry\");function o(t,e,r){i.pointStyle(t.selectAll(\"path.point\"),e,r)}function s(t,e,r){i.textPointStyle(t.selectAll(\"text\"),e,r)}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.trace.scatter\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.selectAll(\"g.points\").each(function(e){o(n.select(this),e.trace||e[0].trace,t)}),e.selectAll(\"g.text\").each(function(e){s(n.select(this),e.trace||e[0].trace,t)}),e.selectAll(\"g.trace path.js-line\").call(i.lineGroupStyle),e.selectAll(\"g.trace path.js-fill\").call(i.fillGroupStyle),a.getComponentMethod(\"errorbars\",\"style\")(e)},stylePoints:o,styleText:s,styleOnSelect:function(t,e,r){var n=e[0].trace;n.selectedpoints?(i.selectedPointStyle(r.selectAll(\"path.point\"),n),i.selectedTextStyle(r.selectAll(\"text\"),n)):(o(r,n,t),s(r,n,t))}}},{\"../../components/drawing\":614,\"../../registry\":847,d3:163}],1135:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports={hasLines:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"lines\")},hasMarkers:function(t){return t.visible&&(t.mode&&-1!==t.mode.indexOf(\"markers\")||\"splom\"===t.type)},hasText:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"text\")},isBubble:function(t){return n.isPlainObject(t.marker)&&n.isArrayOrTypedArray(t.marker.size)}}},{\"../../lib\":719}],1136:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i,a){a=a||{},i(\"textposition\"),n.coerceFont(i,\"textfont\",r.font),a.noSelect||(i(\"selected.textfont.color\"),i(\"unselected.textfont.color\"))}},{\"../../lib\":719}],1137:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");e.exports=function(t,e,r,a){var o,s=a(\"x\"),l=a(\"y\");if(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],r),s){var c=n.minRowLength(s);l?o=Math.min(c,n.minRowLength(l)):(o=c,a(\"y0\"),a(\"dy\"))}else{if(!l)return 0;o=n.minRowLength(l),a(\"x0\"),a(\"dx\")}return e._length=o,o}},{\"../../lib\":719,\"../../registry\":847}],1138:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../constants/gl3d_dashes\"),l=t(\"../../constants/gl3d_markers\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../plot_api/edit_types\").overrideAll,h=n.line,f=n.marker,p=f.line,d=c({width:h.width,dash:{valType:\"enumerated\",values:Object.keys(s),dflt:\"solid\"}},i(\"line\"));var g=e.exports=u({x:n.x,y:n.y,z:{valType:\"data_array\"},text:c({},n.text,{}),hovertext:c({},n.hovertext,{}),hovertemplate:a(),mode:c({},n.mode,{dflt:\"lines+markers\"}),surfaceaxis:{valType:\"enumerated\",values:[-1,0,1,2],dflt:-1},surfacecolor:{valType:\"color\"},projection:{x:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},y:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},z:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}}},connectgaps:n.connectgaps,line:d,marker:c({symbol:{valType:\"enumerated\",values:Object.keys(l),dflt:\"circle\",arrayOk:!0},size:c({},f.size,{dflt:8}),sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode,opacity:c({},f.opacity,{arrayOk:!1}),colorbar:f.colorbar,line:c({width:c({},p.width,{arrayOk:!1})},i(\"marker.line\"))},i(\"marker\")),textposition:c({},n.textposition,{dflt:\"top center\"}),textfont:{color:n.textfont.color,size:n.textfont.size,family:c({},n.textfont.family,{arrayOk:!1})},hoverinfo:c({},o.hoverinfo)},\"calc\",\"nested\");g.x.editType=g.y.editType=g.z.editType=\"calc+clearAxisTypes\"},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../constants/gl3d_dashes\":692,\"../../constants/gl3d_markers\":693,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1139:[function(t,e,r){\"use strict\";var n=t(\"../scatter/arrays_to_calcdata\"),i=t(\"../scatter/colorscale_calc\");e.exports=function(t,e){var r=[{x:!1,y:!1,trace:e,t:{}}];return n(r,e),i(t,e),r}},{\"../scatter/arrays_to_calcdata\":1111,\"../scatter/colorscale_calc\":1115}],1140:[function(t,e,r){\"use strict\";var n=t(\"../../registry\");function i(t,e,r,i){if(!e||!e.visible)return null;for(var a=n.getComponentMethod(\"errorbars\",\"makeComputeError\")(e),o=new Array(t.length),s=0;s<t.length;s++){var l=a(+t[s],s);if(\"log\"===i.type){var c=i.c2l(t[s]),u=t[s]-l[0],h=t[s]+l[1];if(o[s]=[(i.c2l(u,!0)-c)*r,(i.c2l(h,!0)-c)*r],u>0){var f=i.c2l(u);i._lowerLogErrorBound||(i._lowerLogErrorBound=f),i._lowerErrorBound=Math.min(i._lowerLogErrorBound,f)}}else o[s]=[-l[0]*r,l[1]*r]}return o}e.exports=function(t,e,r){var n=[i(t.x,t.error_x,e[0],r.xaxis),i(t.y,t.error_y,e[1],r.yaxis),i(t.z,t.error_z,e[2],r.zaxis)],a=function(t){for(var e=0;e<t.length;e++)if(t[e])return t[e].length;return 0}(n);if(0===a)return null;for(var o=new Array(a),s=0;s<a;s++){for(var l=[[0,0,0],[0,0,0]],c=0;c<3;c++)if(n[c])for(var u=0;u<2;u++)l[u][c]=n[c][s][u];o[s]=l}return o}},{\"../../registry\":847}],1141:[function(t,e,r){\"use strict\";var n=t(\"gl-line3d\"),i=t(\"gl-scatter3d\"),a=t(\"gl-error3d\"),o=t(\"gl-mesh3d\"),s=t(\"delaunay-triangulate\"),l=t(\"../../lib\"),c=t(\"../../lib/str2rgbarray\"),u=t(\"../../lib/gl_format_color\").formatColor,h=t(\"../scatter/make_bubble_size_func\"),f=t(\"../../constants/gl3d_dashes\"),p=t(\"../../constants/gl3d_markers\"),d=t(\"./calc_errors\");function g(t,e){this.scene=t,this.uid=e,this.linePlot=null,this.scatterPlot=null,this.errorBars=null,this.textMarkers=null,this.delaunayMesh=null,this.color=null,this.mode=\"\",this.dataPoints=[],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.textLabels=null,this.data=null}var v=g.prototype;function m(t){return null==t?0:t.indexOf(\"left\")>-1?-1:t.indexOf(\"right\")>-1?1:0}function y(t){return null==t?0:t.indexOf(\"top\")>-1?-1:t.indexOf(\"bottom\")>-1?1:0}function x(t,e){return e(4*t)}function b(t){return p[t]}function _(t,e,r,n,i){var a=null;if(l.isArrayOrTypedArray(t)){a=[];for(var o=0;o<e;o++)void 0===t[o]?a[o]=n:a[o]=r(t[o],i)}else a=r(t,l.identity);return a}function w(t,e){var r,n,i,a,o,s,f=[],p=t.fullSceneLayout,g=t.dataScale,v=p.xaxis,w=p.yaxis,k=p.zaxis,T=e.marker,A=e.line,M=e.x||[],S=e.y||[],E=e.z||[],C=M.length,L=e.xcalendar,P=e.ycalendar,O=e.zcalendar;for(o=0;o<C;o++)r=v.d2l(M[o],0,L)*g[0],n=w.d2l(S[o],0,P)*g[1],i=k.d2l(E[o],0,O)*g[2],f[o]=[r,n,i];if(Array.isArray(e.text))s=e.text;else if(void 0!==e.text)for(s=new Array(C),o=0;o<C;o++)s[o]=e.text;if(a={position:f,mode:e.mode,text:s},\"line\"in e&&(a.lineColor=u(A,1,C),a.lineWidth=A.width,a.lineDashes=A.dash),\"marker\"in e){var z=h(e);a.scatterColor=u(T,1,C),a.scatterSize=_(T.size,C,x,20,z),a.scatterMarker=_(T.symbol,C,b,\"\\u25cf\"),a.scatterLineWidth=T.line.width,a.scatterLineColor=u(T.line,1,C),a.scatterAngle=0}\"textposition\"in e&&(a.textOffset=function(t){var e=[0,0];if(Array.isArray(t))for(var r=0;r<t.length;r++)e[r]=[0,0],t[r]&&(e[r][0]=m(t[r]),e[r][1]=y(t[r]));else e[0]=m(t),e[1]=y(t);return e}(e.textposition),a.textColor=u(e.textfont,1,C),a.textSize=_(e.textfont.size,C,l.identity,12),a.textFont=e.textfont.family,a.textAngle=0);var I=[\"x\",\"y\",\"z\"];for(a.project=[!1,!1,!1],a.projectScale=[1,1,1],a.projectOpacity=[1,1,1],o=0;o<3;++o){var D=e.projection[I[o]];(a.project[o]=D.show)&&(a.projectOpacity[o]=D.opacity,a.projectScale[o]=D.scale)}a.errorBounds=d(e,g,p);var R=function(t){for(var e=[0,0,0],r=[[0,0,0],[0,0,0],[0,0,0]],n=[1,1,1],i=0;i<3;i++){var a=t[i];a&&!1!==a.copy_zstyle&&!1!==t[2].visible&&(a=t[2]),a&&a.visible&&(e[i]=a.width/2,r[i]=c(a.color),n[i]=a.thickness)}return{capSize:e,color:r,lineWidth:n}}([e.error_x,e.error_y,e.error_z]);return a.errorColor=R.color,a.errorLineWidth=R.lineWidth,a.errorCapSize=R.capSize,a.delaunayAxis=e.surfaceaxis,a.delaunayColor=c(e.surfacecolor),a}function k(t){if(Array.isArray(t)){var e=t[0];return Array.isArray(e)&&(t=e),\"rgb(\"+t.slice(0,3).map(function(t){return Math.round(255*t)})+\")\"}return null}v.handlePick=function(t){if(t.object&&(t.object===this.linePlot||t.object===this.delaunayMesh||t.object===this.textMarkers||t.object===this.scatterPlot)){var e=t.index=t.data.index;return t.object.highlight&&t.object.highlight(null),this.scatterPlot&&(t.object=this.scatterPlot,this.scatterPlot.highlight(t.data)),t.textLabel=\"\",this.textLabels&&(Array.isArray(this.textLabels)?(this.textLabels[e]||0===this.textLabels[e])&&(t.textLabel=this.textLabels[e]):t.textLabel=this.textLabels),t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]],!0}},v.update=function(t){var e,r,l,c,u=this.scene.glplot.gl,h=f.solid;this.data=t;var p=w(this.scene,t);\"mode\"in p&&(this.mode=p.mode),\"lineDashes\"in p&&p.lineDashes in f&&(h=f[p.lineDashes]),this.color=k(p.scatterColor)||k(p.lineColor),this.dataPoints=p.position,e={gl:this.scene.glplot.gl,position:p.position,color:p.lineColor,lineWidth:p.lineWidth||1,dashes:h[0],dashScale:h[1],opacity:t.opacity,connectGaps:t.connectgaps},-1!==this.mode.indexOf(\"lines\")?this.linePlot?this.linePlot.update(e):(this.linePlot=n(e),this.linePlot._trace=this,this.scene.glplot.add(this.linePlot)):this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose(),this.linePlot=null);var d=t.opacity;if(t.marker&&t.marker.opacity&&(d*=t.marker.opacity),r={gl:this.scene.glplot.gl,position:p.position,color:p.scatterColor,size:p.scatterSize,glyph:p.scatterMarker,opacity:d,orthographic:!0,lineWidth:p.scatterLineWidth,lineColor:p.scatterLineColor,project:p.project,projectScale:p.projectScale,projectOpacity:p.projectOpacity},-1!==this.mode.indexOf(\"markers\")?this.scatterPlot?this.scatterPlot.update(r):(this.scatterPlot=i(r),this.scatterPlot._trace=this,this.scatterPlot.highlightScale=1,this.scene.glplot.add(this.scatterPlot)):this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose(),this.scatterPlot=null),c={gl:this.scene.glplot.gl,position:p.position,glyph:p.text,color:p.textColor,size:p.textSize,angle:p.textAngle,alignment:p.textOffset,font:p.textFont,orthographic:!0,lineWidth:0,project:!1,opacity:t.opacity},this.textLabels=t.hovertext||t.text,-1!==this.mode.indexOf(\"text\")?this.textMarkers?this.textMarkers.update(c):(this.textMarkers=i(c),this.textMarkers._trace=this,this.textMarkers.highlightScale=1,this.scene.glplot.add(this.textMarkers)):this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose(),this.textMarkers=null),l={gl:this.scene.glplot.gl,position:p.position,color:p.errorColor,error:p.errorBounds,lineWidth:p.errorLineWidth,capSize:p.errorCapSize,opacity:t.opacity},this.errorBars?p.errorBounds?this.errorBars.update(l):(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose(),this.errorBars=null):p.errorBounds&&(this.errorBars=a(l),this.errorBars._trace=this,this.scene.glplot.add(this.errorBars)),p.delaunayAxis>=0){var g=function(t,e,r){var n,i=(r+1)%3,a=(r+2)%3,o=[],l=[];for(n=0;n<t.length;++n){var c=t[n];!isNaN(c[i])&&isFinite(c[i])&&!isNaN(c[a])&&isFinite(c[a])&&(o.push([c[i],c[a]]),l.push(n))}var u=s(o);for(n=0;n<u.length;++n)for(var h=u[n],f=0;f<h.length;++f)h[f]=l[h[f]];return{positions:t,cells:u,meshColor:e}}(p.position,p.delaunayColor,p.delaunayAxis);g.opacity=t.opacity,this.delaunayMesh?this.delaunayMesh.update(g):(g.gl=u,this.delaunayMesh=o(g),this.delaunayMesh._trace=this,this.scene.glplot.add(this.delaunayMesh))}else this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose(),this.delaunayMesh=null)},v.dispose=function(){this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose()),this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose()),this.errorBars&&(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose()),this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose()),this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose())},e.exports=function(t,e){var r=new g(t,e.uid);return r.update(e),r}},{\"../../constants/gl3d_dashes\":692,\"../../constants/gl3d_markers\":693,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../scatter/make_bubble_size_func\":1128,\"./calc_errors\":1140,\"delaunay-triangulate\":165,\"gl-error3d\":247,\"gl-line3d\":255,\"gl-mesh3d\":280,\"gl-scatter3d\":297}],1142:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,n){return i.coerce(t,e,c,r,n)}if(function(t,e,r,i){var a=0,o=r(\"x\"),s=r(\"y\"),l=r(\"z\");n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],i),o&&s&&l&&(a=Math.min(o.length,s.length,l.length),e._length=e._xlength=e._ylength=e._zlength=a);return a}(t,e,h,u)){h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),a.hasLines(e)&&(h(\"connectgaps\"),s(t,e,r,u,h)),a.hasMarkers(e)&&o(t,e,r,u,h,{noSelect:!0}),a.hasText(e)&&l(t,e,u,h,{noSelect:!0});var f=(e.line||{}).color,p=(e.marker||{}).color;h(\"surfaceaxis\")>=0&&h(\"surfacecolor\",f||p);for(var d=[\"x\",\"y\",\"z\"],g=0;g<3;++g){var v=\"projection.\"+d[g];h(v+\".show\")&&(h(v+\".opacity\"),h(v+\".scale\"))}var m=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");m(t,e,f||p||r,{axis:\"z\"}),m(t,e,f||p||r,{axis:\"y\",inherit:\"z\"}),m(t,e,f||p||r,{axis:\"x\",inherit:\"z\"})}else e.visible=!1}},{\"../../lib\":719,\"../../registry\":847,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1138}],1143:[function(t,e,r){\"use strict\";e.exports={plot:t(\"./convert\"),attributes:t(\"./attributes\"),markerSymbols:t(\"../../constants/gl3d_markers\"),supplyDefaults:t(\"./defaults\"),colorbar:[{container:\"marker\",min:\"cmin\",max:\"cmax\"},{container:\"line\",min:\"cmin\",max:\"cmax\"}],calc:t(\"./calc\"),moduleType:\"trace\",name:\"scatter3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"symbols\",\"showLegend\"],meta:{}}},{\"../../constants/gl3d_markers\":693,\"../../plots/gl3d\":807,\"./attributes\":1138,\"./calc\":1139,\"./convert\":1141,\"./defaults\":1142}],1144:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=n.marker,c=n.line,u=l.line;e.exports={carpet:{valType:\"string\",editType:\"calc\"},a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},mode:s({},n.mode,{dflt:\"markers\"}),text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),line:{color:c.color,width:c.width,dash:c.dash,shape:s({},c.shape,{values:[\"linear\",\"spline\"]}),smoothing:c.smoothing,editType:\"calc\"},connectgaps:n.connectgaps,fill:s({},n.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:n.fillcolor,marker:s({symbol:l.symbol,opacity:l.opacity,maxdisplayed:l.maxdisplayed,size:l.size,sizeref:l.sizeref,sizemin:l.sizemin,sizemode:l.sizemode,line:s({width:u.width,editType:\"calc\"},o(\"marker.line\")),gradient:l.gradient,editType:\"calc\"},o(\"marker\")),textfont:n.textfont,textposition:n.textposition,selected:n.selected,unselected:n.unselected,hoverinfo:s({},i.hoverinfo,{flags:[\"a\",\"b\",\"text\",\"name\"]}),hoveron:n.hoveron,hovertemplate:a()}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1145:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=t(\"../carpet/lookup_carpetid\");e.exports=function(t,e){var r=e._carpetTrace=l(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){var c;e.xaxis=r.xaxis,e.yaxis=r.yaxis;var u,h,f=e._length,p=new Array(f),d=!1;for(c=0;c<f;c++)if(u=e.a[c],h=e.b[c],n(u)&&n(h)){var g=r.ab2xy(+u,+h,!0),v=r.isVisible(+u,+h);v||(d=!0),p[c]={x:g[0],y:g[1],a:u,b:h,vis:v}}else p[c]={x:!1,y:!1};return e._needsCull=d,p[0].carpet=r,p[0].trace=e,s(e,f),i(t,e),a(p,e),o(p,e),p}}},{\"../carpet/lookup_carpetid\":915,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc\":1113,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1146:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}p(\"carpet\"),e.xaxis=\"x\",e.yaxis=\"y\";var d=p(\"a\"),g=p(\"b\"),v=Math.min(d.length,g.length);if(v){e._length=v,p(\"text\"),p(\"hovertext\"),p(\"mode\",v<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,f,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,f,p,{gradient:!0}),a.hasText(e)&&c(t,e,f,p);var m=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"marker.maxdisplayed\"),m.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||m.push(\"fills\"),\"fills\"!==p(\"hoveron\",m.join(\"+\")||\"points\")&&p(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/line_shape_defaults\":1126,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1144}],1147:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=n[i];return t.a=a.a,t.b=a.b,t.y=a.y,t}},{}],1148:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../lib\").fillText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,h=c-u;return s.x0=Math.max(Math.min(s.x0,h),u),s.x1=Math.max(Math.min(s.x1,h),u),o}var f=s.cd[s.index];s.a=f.a,s.b=f.b,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.trace,d=p._carpet,g=d.ab2ij([f.a,f.b]),v=Math.floor(g[0]),m=g[0]-v,y=Math.floor(g[1]),x=g[1]-y,b=d.evalxy([],v,y,m,x);s.yLabel=b[1].toFixed(3),delete s.text;var _=[];if(!p.hovertemplate){var w=(f.hi||p.hoverinfo).split(\"+\");-1!==w.indexOf(\"all\")&&(w=[\"a\",\"b\",\"text\"]),-1!==w.indexOf(\"a\")&&k(d.aaxis,f.a),-1!==w.indexOf(\"b\")&&k(d.baxis,f.b),_.push(\"y: \"+s.yLabel),-1!==w.indexOf(\"text\")&&i(f,p,_),s.extraText=_.join(\"<br>\")}return o}function k(t,e){var r;r=t.labelprefix&&t.labelprefix.length>0?t.labelprefix.replace(/ = $/,\"\"):t._hovertitle,_.push(r+\": \"+e.toFixed(3)+t.labelsuffix)}}},{\"../../lib\":719,\"../scatter/hover\":1122}],1149:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scattercarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"svg\",\"carpet\",\"symbols\",\"showLegend\",\"carpetDependent\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../scatter/marker_colorbar\":1129,\"../scatter/select\":1132,\"../scatter/style\":1134,\"./attributes\":1144,\"./calc\":1145,\"./defaults\":1146,\"./event_data\":1147,\"./hover\":1148,\"./plot\":1150}],1150:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../components/drawing\");e.exports=function(t,e,r,o){var s,l,c,u=r[0][0].carpet,h={xaxis:i.getFromId(t,u.xaxis||\"x\"),yaxis:i.getFromId(t,u.yaxis||\"y\"),plot:e.plot};for(n(t,h,r,o),s=0;s<r.length;s++)l=r[s][0].trace,c=o.selectAll(\"g.trace\"+l.uid+\" .js-line\"),a.setClipUrl(c,r[s][0].carpet._clipPathId,t)}},{\"../../components/drawing\":614,\"../../plots/cartesian/axes\":767,\"../scatter/plot\":1131}],1151:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/drawing/attributes\").dash,l=t(\"../../lib/extend\").extendFlat,c=t(\"../../plot_api/edit_types\").overrideAll,u=i.marker,h=i.line,f=u.line;e.exports=c({lon:{valType:\"data_array\"},lat:{valType:\"data_array\"},locations:{valType:\"data_array\"},locationmode:{valType:\"enumerated\",values:[\"ISO-3\",\"USA-states\",\"country names\"],dflt:\"ISO-3\"},mode:l({},i.mode,{dflt:\"markers\"}),text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),textfont:i.textfont,textposition:i.textposition,line:{color:h.color,width:h.width,dash:s},connectgaps:i.connectgaps,marker:l({symbol:u.symbol,opacity:u.opacity,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,colorbar:u.colorbar,line:l({width:f.width},o(\"marker.line\")),gradient:u.gradient},o(\"marker\")),fill:{valType:\"enumerated\",values:[\"none\",\"toself\"],dflt:\"none\"},fillcolor:i.fillcolor,selected:i.selected,unselected:i.unselected,hoverinfo:l({},a.hoverinfo,{flags:[\"lon\",\"lat\",\"location\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":600,\"../../components/drawing/attributes\":613,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1152:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../scatter/colorscale_calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\"),l=t(\"../../lib\")._;e.exports=function(t,e){for(var r=Array.isArray(e.locations),c=r?e.locations.length:e._length,u=new Array(c),h=0;h<c;h++){var f=u[h]={};if(r){var p=e.locations[h];f.loc=\"string\"==typeof p?p:null}else{var d=e.lon[h],g=e.lat[h];n(d)&&n(g)?f.lonlat=[+d,+g]:f.lonlat=[i,i]}}return o(u,e),a(t,e),s(u,e),c&&(u[0].t={labels:{lat:l(t,\"lat:\")+\" \",lon:l(t,\"lon:\")+\" \"}}),u}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1153:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,i){return n.coerce(t,e,c,r,i)}!function(t,e,r){var n,i,a=0,o=r(\"locations\");if(o)return r(\"locationmode\"),a=o.length;return n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length),e._length=a,a}(0,e,h)?e.visible=!1:(h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),i.hasLines(e)&&(o(t,e,r,u,h),h(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,u,h,{gradient:!0}),i.hasText(e)&&s(t,e,u,h),h(\"fill\"),\"none\"!==e.fill&&l(t,e,r,h),n.coerceSelectionMarkerOpacity(e,h))}},{\"../../lib\":719,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1151}],1154:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.location=e.loc?e.loc:null,t}},{}],1155:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../scatter/get_trace_color\"),s=t(\"../../lib\").fillText,l=t(\"./attributes\");e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,h=t.xa,f=t.ya,p=t.subplot,d=p.projection.isLonLatOverEdges,g=p.project;if(n.getClosest(c,function(t){var n=t.lonlat;if(n[0]===a)return 1/0;if(d(n))return 1/0;var i=g(n),o=g([e,r]),s=Math.abs(i[0]-o[0]),l=Math.abs(i[1]-o[1]),c=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(s*s+l*l)-c,1-3/c)},t),!1!==t.index){var v=c[t.index],m=v.lonlat,y=[h.c2p(m),f.c2p(m)],x=v.mrc||1;t.x0=y[0]-x,t.x1=y[0]+x,t.y0=y[1]-x,t.y1=y[1]+x,t.loc=v.loc,t.lon=m[0],t.lat=m[1];var b=p.mockAxis;return t.lonLabel=i.tickText(b,b.c2l(t.lon),\"hover\").text,t.latLabel=i.tickText(b,b.c2l(t.lat),\"hover\").text,t.color=o(u,v),t.extraText=function(t,e,r,n){if(t.hovertemplate)return;var i=e.hi||t.hoverinfo,a=\"all\"===i?l.hoverinfo.flags:i.split(\"+\"),o=-1!==a.indexOf(\"location\")&&Array.isArray(t.locations),c=-1!==a.indexOf(\"lon\"),u=-1!==a.indexOf(\"lat\"),h=-1!==a.indexOf(\"text\"),f=[];function p(t){return t+\"\\xb0\"}o?f.push(e.loc):c&&u?f.push(\"(\"+p(r.lonLabel)+\", \"+p(r.latLabel)+\")\"):c?f.push(n.lon+p(r.lonLabel)):u&&f.push(n.lat+p(r.latLabel));h&&s(e,t,f);return f.join(\"<br>\")}(u,v,t,c[0].t.labels),t.hovertemplate=u.hovertemplate,[t]}}},{\"../../components/fx\":632,\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scatter/get_trace_color\":1121,\"./attributes\":1151}],1156:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"scattergeo\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/geo\":797,\"../scatter/marker_colorbar\":1129,\"../scatter/style\":1134,\"./attributes\":1151,\"./calc\":1152,\"./defaults\":1153,\"./event_data\":1154,\"./hover\":1155,\"./plot\":1157,\"./select\":1158,\"./style\":1159}],1157:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../lib/topojson_utils\").getTopojsonFeatures,s=t(\"../../lib/geo_location_utils\").locationToFeature,l=t(\"../../lib/geojson_utils\"),c=t(\"../scatter/subtypes\"),u=t(\"./style\");function h(t,e){var r=t[0].trace;if(Array.isArray(r.locations))for(var n=o(r,e),i=r.locationmode,l=0;l<t.length;l++){var c=t[l],u=s(i,c.loc,n);c.lonlat=u?u.properties.ct:[a,a]}}e.exports=function(t,e,r){for(var o=0;o<r.length;o++)h(r[o],e.topojson);function s(t,e){t.lonlat[0]===a&&n.select(e).remove()}var f=e.layers.frontplot.select(\".scatterlayer\"),p=i.makeTraceGroups(f,r,\"trace scattergeo\");p.selectAll(\"*\").remove(),p.each(function(e){var r=n.select(this),a=e[0].trace;if(c.hasLines(a)||\"none\"!==a.fill){var o=l.calcTraceToLineCoords(e),h=\"none\"!==a.fill?l.makePolygon(o):l.makeLine(o);r.selectAll(\"path.js-line\").data([{geojson:h,trace:a}]).enter().append(\"path\").classed(\"js-line\",!0).style(\"stroke-miterlimit\",2)}c.hasMarkers(a)&&r.selectAll(\"path.point\").data(i.identity).enter().append(\"path\").classed(\"point\",!0).each(function(t){s(t,this)}),c.hasText(a)&&r.selectAll(\"g\").data(i.identity).enter().append(\"g\").append(\"text\").each(function(t){s(t,this)}),u(t,e)})}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/geo_location_utils\":713,\"../../lib/geojson_utils\":714,\"../../lib/topojson_utils\":746,\"../scatter/subtypes\":1135,\"./style\":1159,d3:163}],1158:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,a,o,s,l,c=t.cd,u=t.xaxis,h=t.yaxis,f=[],p=c[0].trace;if(!n.hasMarkers(p)&&!n.hasText(p))return[];if(!1===e)for(l=0;l<c.length;l++)c[l].selected=0;else for(l=0;l<c.length;l++)(a=(r=c[l]).lonlat)[0]!==i&&(o=u.c2p(a),s=h.c2p(a),e.contains([o,s],null,l,t)?(f.push({pointNumber:l,lon:a[0],lat:a[1]}),r.selected=1):r.selected=0);return f}},{\"../../constants/numerical\":695,\"../scatter/subtypes\":1135}],1159:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../scatter/style\"),s=o.stylePoints,l=o.styleText;e.exports=function(t,e){e&&function(t,e){var r=e[0].trace,o=e[0].node3;o.style(\"opacity\",e[0].trace.opacity),s(o,r,t),l(o,r,t),o.selectAll(\"path.js-line\").style(\"fill\",\"none\").each(function(t){var e=n.select(this),r=t.trace,o=r.line||{};e.call(a.stroke,o.color).call(i.dashLine,o.dash||\"\",o.width||0),\"none\"!==r.fill&&e.call(a.fill,r.fillcolor)})}(t,e)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../scatter/style\":1134,d3:163}],1160:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=t(\"./constants\").DASHES,c=i.line,u=i.marker,h=u.line,f=e.exports=s({x:i.x,x0:i.x0,dx:i.dx,y:i.y,y0:i.y0,dy:i.dy,text:i.text,hovertext:i.hovertext,textposition:i.textposition,textfont:i.textfont,mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"]},line:{color:c.color,width:c.width,shape:{valType:\"enumerated\",values:[\"linear\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},dash:{valType:\"enumerated\",values:Object.keys(l),dflt:\"solid\"}},marker:o({},a(\"marker\"),{symbol:u.symbol,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:o({},a(\"marker.line\"),{width:h.width})}),connectgaps:i.connectgaps,fill:o({},i.fill,{dflt:\"none\"}),fillcolor:i.fillcolor,selected:{marker:i.selected.marker,textfont:i.selected.textfont},unselected:{marker:i.unselected.marker,textfont:i.unselected.textfont},opacity:n.opacity},\"calc\",\"nested\");f.x.editType=f.y.editType=f.x0.editType=f.y0.editType=\"calc+clearAxisTypes\",f.hovertemplate=i.hovertemplate},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../scatter/attributes\":1112,\"./constants\":1162}],1161:[function(t,e,r){\"use strict\";var n=t(\"point-cluster\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../plots/cartesian/autorange\").findExtremes,s=t(\"../scatter/calc\"),l=s.calcMarkerSize,c=s.calcAxisExpansion,u=s.setFirstScatter,h=t(\"../scatter/colorscale_calc\"),f=t(\"./convert\"),p=t(\"./scene_update\"),d=t(\"../../constants/numerical\").BADNUM,g=t(\"./constants\").TOO_MANY_POINTS;function v(t,e,r){var n=t._extremes[e._id],i=o(e,r._bnds,{padded:!0});n.min=n.min.concat(i.min),n.max=n.max.concat(i.max)}e.exports=function(t,e){var r,o,s,m=t._fullLayout,y=a.getFromId(t,e.xaxis),x=a.getFromId(t,e.yaxis),b=m._plots[e.xaxis+e.yaxis],_=e._length,w=_>=g,k=2*_,T={},A=y.makeCalcdata(e,\"x\"),M=x.makeCalcdata(e,\"y\"),S=new Array(k);for(r=0;r<_;r++)o=A[r],s=M[r],S[2*r]=o===d?NaN:o,S[2*r+1]=s===d?NaN:s;if(\"log\"===y.type)for(r=0;r<k;r+=2)S[r]=y.c2l(S[r]);if(\"log\"===x.type)for(r=1;r<k;r+=2)S[r]=x.c2l(S[r]);if(w&&\"log\"!==y.type&&\"log\"!==x.type)T.tree=n(S);else{var E=T.ids=new Array(_);for(r=0;r<_;r++)E[r]=r}h(t,e);var C,L=function(t,e,r,n,a,o){var s=f.style(t,r);s.marker&&(s.marker.positions=n);s.line&&n.length>1&&i.extendFlat(s.line,f.linePositions(t,r,n));if(s.errorX||s.errorY){var l=f.errorBarPositions(t,r,n,a,o);s.errorX&&i.extendFlat(s.errorX,l.x),s.errorY&&i.extendFlat(s.errorY,l.y)}s.text&&(i.extendFlat(s.text,{positions:n},f.textPosition(t,r,s.text,s.marker)),i.extendFlat(s.textSel,{positions:n},f.textPosition(t,r,s.text,s.markerSel)),i.extendFlat(s.textUnsel,{positions:n},f.textPosition(t,r,s.text,s.markerUnsel)));return s}(t,0,e,S,A,M),P=p(t,b);return u(m,e),w?L.marker&&(C=2*(L.marker.sizeAvg||Math.max(L.marker.size,3))):C=l(e,_),c(t,e,y,x,A,M,C),L.errorX&&v(e,y,L.errorX),L.errorY&&v(e,x,L.errorY),L.fill&&!P.fill2d&&(P.fill2d=!0),L.marker&&!P.scatter2d&&(P.scatter2d=!0),L.line&&!P.line2d&&(P.line2d=!0),!L.errorX&&!L.errorY||P.error2d||(P.error2d=!0),L.text&&!P.glText&&(P.glText=!0),L.marker&&(L.marker.snap=T.tree||g),P.lineOptions.push(L.line),P.errorXOptions.push(L.errorX),P.errorYOptions.push(L.errorY),P.fillOptions.push(L.fill),P.markerOptions.push(L.marker),P.markerSelectedOptions.push(L.markerSel),P.markerUnselectedOptions.push(L.markerUnsel),P.textOptions.push(L.text),P.textSelectedOptions.push(L.textSel),P.textUnselectedOptions.push(L.textUnsel),P.selectBatch.push([]),P.unselectBatch.push([]),T._scene=P,T.index=P.count,T.x=A,T.y=M,T.positions=S,P.count++,[{x:!1,y:!1,t:T,trace:e}]}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/autorange\":766,\"../../plots/cartesian/axis_ids\":770,\"../scatter/calc\":1113,\"../scatter/colorscale_calc\":1115,\"./constants\":1162,\"./convert\":1163,\"./scene_update\":1169,\"point-cluster\":469}],1162:[function(t,e,r){\"use strict\";e.exports={TOO_MANY_POINTS:1e5,SYMBOL_SDF_SIZE:200,SYMBOL_SIZE:20,SYMBOL_STROKE:1,DOT_RE:/-dot/,OPEN_RE:/-open/,DASHES:{solid:[1],dot:[1,1],dash:[4,1],longdash:[8,1],dashdot:[4,1,1,1],longdashdot:[8,1,1,1]}}},{}],1163:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"svg-path-sdf\"),a=t(\"color-normalize\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../components/drawing\"),c=t(\"../../plots/cartesian/axis_ids\"),u=t(\"../../lib/gl_format_color\").formatColor,h=t(\"../scatter/subtypes\"),f=t(\"../scatter/make_bubble_size_func\"),p=t(\"./constants\"),d=t(\"../../constants/interactions\").DESELECTDIM,g={start:1,left:1,end:-1,right:-1,middle:0,center:0,bottom:1,top:-1};function v(t){var e,r=t._length,i=t.textfont,a=t.textposition,o=Array.isArray(a)?a:[a],s=i.color,l=i.size,c=i.family,u={};for(u.text=t.text,u.opacity=t.opacity,u.font={},u.align=[],u.baseline=[],e=0;e<o.length;e++){var h=o[e].split(/\\s+/);switch(h[1]){case\"left\":u.align.push(\"right\");break;case\"right\":u.align.push(\"left\");break;default:u.align.push(h[1])}switch(h[0]){case\"top\":u.baseline.push(\"bottom\");break;case\"bottom\":u.baseline.push(\"top\");break;default:u.baseline.push(h[0])}}if(Array.isArray(s))for(u.color=new Array(r),e=0;e<r;e++)u.color[e]=s[e];else u.color=s;if(Array.isArray(l)||Array.isArray(c))for(u.font=new Array(r),e=0;e<r;e++){var f=u.font[e]={};f.size=Array.isArray(l)?n(l[e])?l[e]:0:l,f.family=Array.isArray(c)?c[e]:c}else u.font={size:l,family:c};return u}function m(t){var e,r,n=t._length,i=t.marker,o={},l=Array.isArray(i.symbol),c=s.isArrayOrTypedArray(i.color),h=s.isArrayOrTypedArray(i.line.color),d=s.isArrayOrTypedArray(i.opacity),g=s.isArrayOrTypedArray(i.size),v=s.isArrayOrTypedArray(i.line.width);if(l||(r=p.OPEN_RE.test(i.symbol)),l||c||h||d){o.colors=new Array(n),o.borderColors=new Array(n);var m=u(i,i.opacity,n),y=u(i.line,i.opacity,n);if(!Array.isArray(y[0])){var x=y;for(y=Array(n),e=0;e<n;e++)y[e]=x}if(!Array.isArray(m[0])){var b=m;for(m=Array(n),e=0;e<n;e++)m[e]=b}for(o.colors=m,o.borderColors=y,e=0;e<n;e++){if(l){var _=i.symbol[e];r=p.OPEN_RE.test(_)}r&&(y[e]=m[e].slice(),m[e]=m[e].slice(),m[e][3]=0)}o.opacity=t.opacity}else r?(o.color=a(i.color,\"uint8\"),o.color[3]=0,o.borderColor=a(i.color,\"uint8\")):(o.color=a(i.color,\"uint8\"),o.borderColor=a(i.line.color,\"uint8\")),o.opacity=t.opacity*i.opacity;if(l)for(o.markers=new Array(n),e=0;e<n;e++)o.markers[e]=M(i.symbol[e]);else o.marker=M(i.symbol);var w,k=f(t);if(g||v){var T,A=o.sizes=new Array(n),S=o.borderSizes=new Array(n),E=0;if(g){for(e=0;e<n;e++)A[e]=k(i.size[e]),E+=A[e];T=E/n}else for(w=k(i.size),e=0;e<n;e++)A[e]=w;if(v)for(e=0;e<n;e++)S[e]=i.line.width[e]/2;else for(w=i.line.width/2,e=0;e<n;e++)S[e]=w;o.sizeAvg=T}else o.size=k(i&&i.size||10),o.borderSizes=k(i.line.width);return o}function y(t,e){var r=t.marker,n={};return e?(e.marker&&e.marker.symbol?n=m(s.extendFlat({},r,e.marker)):e.marker&&(e.marker.size&&(n.size=e.marker.size/2),e.marker.color&&(n.colors=e.marker.color),void 0!==e.marker.opacity&&(n.opacity=e.marker.opacity)),n):n}function x(t,e){var r={};if(!e)return r;if(e.textfont){var n={opacity:1,text:t.text,textposition:t.textposition,textfont:s.extendFlat({},t.textfont)};e.textfont&&s.extendFlat(n.textfont,e.textfont),r=v(n)}return r}function b(t,e){var r={capSize:2*e.width,lineWidth:e.thickness,color:e.color};return e.copy_ystyle&&(r=t.error_y),r}var _=p.SYMBOL_SDF_SIZE,w=p.SYMBOL_SIZE,k=p.SYMBOL_STROKE,T={},A=l.symbolFuncs[0](.05*w);function M(t){if(\"circle\"===t)return null;var e,r,n=l.symbolNumber(t),a=l.symbolFuncs[n%100],o=!!l.symbolNoDot[n%100],s=!!l.symbolNoFill[n%100],c=p.DOT_RE.test(t);return T[t]?T[t]:(e=c&&!o?a(1.1*w)+A:a(w),r=i(e,{w:_,h:_,viewBox:[-w,-w,w,w],stroke:s?k:-k}),T[t]=r,r||null)}e.exports={style:function(t,e){var r,n={marker:void 0,markerSel:void 0,markerUnsel:void 0,line:void 0,fill:void 0,errorX:void 0,errorY:void 0,text:void 0,textSel:void 0,textUnsel:void 0};if(!0!==e.visible)return n;if(h.hasText(e)&&(n.text=v(e),n.textSel=x(e,e.selected),n.textUnsel=x(e,e.unselected)),h.hasMarkers(e)&&(n.marker=m(e),n.markerSel=y(e,e.selected),n.markerUnsel=y(e,e.unselected),!e.unselected&&Array.isArray(e.marker.opacity))){var i=e.marker.opacity;for(n.markerUnsel.opacity=new Array(i.length),r=0;r<i.length;r++)n.markerUnsel.opacity[r]=d*i[r]}if(h.hasLines(e)){n.line={overlay:!0,thickness:e.line.width,color:e.line.color,opacity:e.opacity};var a=(p.DASHES[e.line.dash]||[1]).slice();for(r=0;r<a.length;++r)a[r]*=e.line.width;n.line.dashes=a}return e.error_x&&e.error_x.visible&&(n.errorX=b(e,e.error_x)),e.error_y&&e.error_y.visible&&(n.errorY=b(e,e.error_y)),e.fill&&\"none\"!==e.fill&&(n.fill={closed:!0,fill:e.fillcolor,thickness:0}),n},markerStyle:m,markerSelection:y,linePositions:function(t,e,r){var n,i,a=r.length,o=a/2;if(h.hasLines(e)&&o)if(\"hv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i+2],r[2*i+1]));n.push(r[a-2],r[a-1])}else if(\"hvh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var s=(r[2*i]+r[2*i+2])/2;n.push(r[2*i],r[2*i+1],s,r[2*i+1],s,r[2*i+3])}n.push(r[a-2],r[a-1])}else if(\"vhv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var l=(r[2*i+1]+r[2*i+3])/2;n.push(r[2*i],r[2*i+1],r[2*i],l,r[2*i+2],l)}n.push(r[a-2],r[a-1])}else if(\"vh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+3]));n.push(r[a-2],r[a-1])}else n=r;var c=!1;for(i=0;i<n.length;i++)if(isNaN(n[i])){c=!0;break}var u=c||n.length>p.TOO_MANY_POINTS?\"rect\":h.hasMarkers(e)?\"rect\":\"round\";if(c&&e.connectgaps){var f=n[0],d=n[1];for(i=0;i<n.length;i+=2)isNaN(n[i])||isNaN(n[i+1])?(n[i]=f,n[i+1]=d):(f=n[i],d=n[i+1])}return{join:u,positions:n}},errorBarPositions:function(t,e,r,i,a){var s=o.getComponentMethod(\"errorbars\",\"makeComputeError\"),l=c.getFromId(t,e.xaxis),u=c.getFromId(t,e.yaxis),h=r.length/2,f={};function p(t,i){var a=i._id.charAt(0),o=e[\"error_\"+a];if(o&&o.visible&&(\"linear\"===i.type||\"log\"===i.type)){for(var l=s(o),c={x:0,y:1}[a],u={x:[0,1,2,3],y:[2,3,0,1]}[a],p=new Float64Array(4*h),d=1/0,g=-1/0,v=0,m=0;v<h;v++,m+=4){var y=t[v];if(n(y)){var x=r[2*v+c],b=l(y,v),_=b[0],w=b[1];if(n(_)&&n(w)){var k=y-_,T=y+w;p[m+u[0]]=x-i.c2l(k),p[m+u[1]]=i.c2l(T)-x,p[m+u[2]]=0,p[m+u[3]]=0,d=Math.min(d,y-_),g=Math.max(g,y+w)}}}f[a]={positions:r,errors:p,_bnds:[d,g]}}}return p(i,l),p(a,u),f},textPosition:function(t,e,r,n){var i,a=e._length,o={};if(h.hasMarkers(e)){var s=r.font,l=r.align,c=r.baseline;for(o.offset=new Array(a),i=0;i<a;i++){var u=n.sizes?n.sizes[i]:n.size,f=Array.isArray(s)?s[i].size:s.size,p=Array.isArray(l)?l.length>1?l[i]:l[0]:l,d=Array.isArray(c)?c.length>1?c[i]:c[0]:c,v=g[p],m=g[d],y=u?u/.8+1:0,x=-m*y-.5*m;o.offset[i]=[v*y/f,x/f]}}return o}}},{\"../../components/drawing\":614,\"../../constants/interactions\":694,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../scatter/make_bubble_size_func\":1128,\"../scatter/subtypes\":1135,\"./constants\":1162,\"color-normalize\":120,\"fast-isnumeric\":225,\"svg-path-sdf\":535}],1164:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"../scatter/constants\"),s=t(\"../scatter/subtypes\"),l=t(\"../scatter/xy_defaults\"),c=t(\"../scatter/marker_defaults\"),u=t(\"../scatter/line_defaults\"),h=t(\"../scatter/fillcolor_defaults\"),f=t(\"../scatter/text_defaults\");e.exports=function(t,e,r,p){function d(r,i){return n.coerce(t,e,a,r,i)}var g=!!t.marker&&/-open/.test(t.marker.symbol),v=s.isBubble(t),m=l(t,e,p,d);if(m){var y=m<o.PTS_LINESONLY?\"lines+markers\":\"lines\";d(\"text\"),d(\"hovertext\"),d(\"hovertemplate\"),d(\"mode\",y),s.hasLines(e)&&(d(\"connectgaps\"),u(t,e,r,p,d),d(\"line.shape\")),s.hasMarkers(e)&&(c(t,e,r,p,d),d(\"marker.line.width\",g||v?1:0)),s.hasText(e)&&f(t,e,p,d);var x=(e.line||{}).color,b=(e.marker||{}).color;d(\"fill\"),\"none\"!==e.fill&&h(t,e,r,d);var _=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");_(t,e,x||b||r,{axis:\"y\"}),_(t,e,x||b||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}},{\"../../lib\":719,\"../../registry\":847,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"../scatter/xy_defaults\":1137,\"./attributes\":1160}],1165:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../constants/interactions\").DESELECTDIM;e.exports={styleTextSelection:function(t){var e,r,o=t[0],s=o.trace,l=o.t,c=l._scene,u=l.index,h=c.selectBatch[u],f=c.unselectBatch[u],p=c.textOptions[u],d=c.textSelectedOptions[u]||{},g=c.textUnselectedOptions[u]||{},v=n.extendFlat({},p);if(h.length||f.length){var m=d.color,y=g.color,x=p.color,b=Array.isArray(x);for(v.color=new Array(s._length),e=0;e<h.length;e++)r=h[e],v.color[r]=m||(b?x[r]:x);for(e=0;e<f.length;e++){r=f[e];var _=b?x[r]:x;v.color[r]=y||(m?_:i.addOpacity(_,a))}}c.glText[u].update(v)}}},{\"../../components/color\":593,\"../../constants/interactions\":694,\"../../lib\":719}],1166:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\");function o(t,e,r,o){var s=t.xa,l=t.ya,c=t.distance,u=t.dxy,h=t.index,f={pointNumber:h,x:e[h],y:r[h]};f.tx=Array.isArray(o.text)?o.text[h]:o.text,f.htx=Array.isArray(o.hovertext)?o.hovertext[h]:o.hovertext,f.data=Array.isArray(o.customdata)?o.customdata[h]:o.customdata,f.tp=Array.isArray(o.textposition)?o.textposition[h]:o.textposition;var p=o.textfont;p&&(f.ts=Array.isArray(p.size)?p.size[h]:p.size,f.tc=Array.isArray(p.color)?p.color[h]:p.color,f.tf=Array.isArray(p.family)?p.family[h]:p.family);var d=o.marker;d&&(f.ms=i.isArrayOrTypedArray(d.size)?d.size[h]:d.size,f.mo=i.isArrayOrTypedArray(d.opacity)?d.opacity[h]:d.opacity,f.mx=Array.isArray(d.symbol)?d.symbol[h]:d.symbol,f.mc=i.isArrayOrTypedArray(d.color)?d.color[h]:d.color);var g=d&&d.line;g&&(f.mlc=Array.isArray(g.color)?g.color[h]:g.color,f.mlw=i.isArrayOrTypedArray(g.width)?g.width[h]:g.width);var v=d&&d.gradient;v&&\"none\"!==v.type&&(f.mgt=Array.isArray(v.type)?v.type[h]:v.type,f.mgc=Array.isArray(v.color)?v.color[h]:v.color);var m=s.c2p(f.x,!0),y=l.c2p(f.y,!0),x=f.mrc||1,b=o.hoverlabel;b&&(f.hbg=Array.isArray(b.bgcolor)?b.bgcolor[h]:b.bgcolor,f.hbc=Array.isArray(b.bordercolor)?b.bordercolor[h]:b.bordercolor,f.hts=Array.isArray(b.font.size)?b.font.size[h]:b.font.size,f.htc=Array.isArray(b.font.color)?b.font.color[h]:b.font.color,f.htf=Array.isArray(b.font.family)?b.font.family[h]:b.font.family,f.hnl=Array.isArray(b.namelength)?b.namelength[h]:b.namelength);var _=o.hoverinfo;_&&(f.hi=Array.isArray(_)?_[h]:_);var w=o.hovertemplate;w&&(f.ht=Array.isArray(w)?w[h]:w);var k={};return k[t.index]=f,i.extendFlat(t,{color:a(o,f),x0:m-x,x1:m+x,xLabelVal:f.x,y0:y-x,y1:y+x,yLabelVal:f.y,cd:k,distance:c,spikeDistance:u,hovertemplate:f.ht}),f.htx?t.text=f.htx:f.tx?t.text=f.tx:o.text&&(t.text=o.text),i.fillText(f,o,t),n.getComponentMethod(\"errorbars\",\"hoverInfo\")(f,o,t),t}e.exports={hoverPoints:function(t,e,r,n){var i,a,s,l,c,u,h,f,p,d=t.cd,g=d[0].t,v=d[0].trace,m=t.xa,y=t.ya,x=g.x,b=g.y,_=m.c2p(e),w=y.c2p(r),k=t.distance;if(g.tree){var T=m.p2c(_-k),A=m.p2c(_+k),M=y.p2c(w-k),S=y.p2c(w+k);i=\"x\"===n?g.tree.range(Math.min(T,A),Math.min(y._rl[0],y._rl[1]),Math.max(T,A),Math.max(y._rl[0],y._rl[1])):g.tree.range(Math.min(T,A),Math.min(M,S),Math.max(T,A),Math.max(M,S))}else{if(!g.ids)return[t];i=g.ids}var E=k;if(\"x\"===n)for(c=0;c<i.length;c++)s=x[i[c]],(u=Math.abs(m.c2p(s)-_))<E&&(E=u,h=y.c2p(b[i[c]])-w,p=Math.sqrt(u*u+h*h),a=i[c]);else for(c=i.length-1;c>-1;c--)s=x[i[c]],l=b[i[c]],u=m.c2p(s)-_,h=y.c2p(l)-w,(f=Math.sqrt(u*u+h*h))<E&&(E=p=f,a=i[c]);return t.index=a,t.distance=E,t.dxy=p,void 0===a?[t]:(o(t,x,b,v),[t])},calcHover:o}},{\"../../lib\":719,\"../../registry\":847,\"../scatter/get_trace_color\":1121}],1167:[function(t,e,r){\"use strict\";var n=t(\"./hover\");e.exports={moduleType:\"trace\",name:\"scattergl\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../scatter/cross_trace_defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:n.hoverPoints,selectPoints:t(\"./select\"),meta:{}}},{\"../../plots/cartesian\":778,\"../scatter/cross_trace_defaults\":1118,\"../scatter/marker_colorbar\":1129,\"./attributes\":1160,\"./calc\":1161,\"./defaults\":1164,\"./hover\":1166,\"./plot\":1168,\"./select\":1170}],1168:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"regl-line2d\"),a=t(\"regl-error2d\"),o=t(\"gl-text\"),s=t(\"../../lib\"),l=t(\"../../lib/prepare_regl\"),c=t(\"../scatter/subtypes\"),u=t(\"../scatter/link_traces\"),h=t(\"./edit_style\").styleTextSelection;e.exports=function(t,e,r){if(r.length){var f,p,d=t._fullLayout,g=e._scene,v=e.xaxis,m=e.yaxis;if(g)if(l(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])){var y=g.count,x=d._glcanvas.data()[0].regl;if(u(t,e,r),g.dirty){if(!0===g.error2d&&(g.error2d=a(x)),!0===g.line2d&&(g.line2d=i(x)),!0===g.scatter2d&&(g.scatter2d=n(x)),!0===g.fill2d&&(g.fill2d=i(x)),!0===g.glText)for(g.glText=new Array(y),f=0;f<y;f++)g.glText[f]=new o(x);if(g.glText){if(y>g.glText.length){var b=y-g.glText.length;for(f=0;f<b;f++)g.glText.push(new o(x))}else if(y<g.glText.length){var _=g.glText.length-y;g.glText.splice(y,_).forEach(function(t){t.destroy()})}for(f=0;f<y;f++)g.glText[f].update(g.textOptions[f])}if(g.line2d&&(g.line2d.update(g.lineOptions),g.lineOptions=g.lineOptions.map(function(t){if(t&&t.positions){for(var e=t.positions,r=0;r<e.length&&(isNaN(e[r])||isNaN(e[r+1]));)r+=2;for(var n=e.length-2;n>r&&(isNaN(e[n])||isNaN(e[n+1]));)n-=2;t.positions=e.slice(r,n+2)}return t}),g.line2d.update(g.lineOptions)),g.error2d){var w=(g.errorXOptions||[]).concat(g.errorYOptions||[]);g.error2d.update(w)}g.scatter2d&&g.scatter2d.update(g.markerOptions),g.fillOrder=s.repeat(null,y),g.fill2d&&(g.fillOptions=g.fillOptions.map(function(t,e){var n=r[e];if(t&&n&&n[0]&&n[0].trace){var i,a,o=n[0],s=o.trace,l=o.t,c=g.lineOptions[e],u=[];s._ownfill&&u.push(e),s._nexttrace&&u.push(e+1),u.length&&(g.fillOrder[e]=u);var h,f,p=[],d=c&&c.positions||l.positions;if(\"tozeroy\"===s.fill){for(h=0;h<d.length&&isNaN(d[h+1]);)h+=2;for(f=d.length-2;f>h&&isNaN(d[f+1]);)f-=2;0!==d[h+1]&&(p=[d[h],0]),p=p.concat(d.slice(h,f+2)),0!==d[f+1]&&(p=p.concat([d[f],0]))}else if(\"tozerox\"===s.fill){for(h=0;h<d.length&&isNaN(d[h]);)h+=2;for(f=d.length-2;f>h&&isNaN(d[f]);)f-=2;0!==d[h]&&(p=[0,d[h+1]]),p=p.concat(d.slice(h,f+2)),0!==d[f]&&(p=p.concat([0,d[f+1]]))}else if(\"toself\"===s.fill||\"tonext\"===s.fill){for(p=[],i=0,a=0;a<d.length;a+=2)(isNaN(d[a])||isNaN(d[a+1]))&&((p=p.concat(d.slice(i,a))).push(d[i],d[i+1]),i=a+2);p=p.concat(d.slice(i)),i&&p.push(d[i],d[i+1])}else{var v=s._nexttrace;if(v){var m=g.lineOptions[e+1];if(m){var y=m.positions;if(\"tonexty\"===s.fill){for(p=d.slice(),e=Math.floor(y.length/2);e--;){var x=y[2*e],b=y[2*e+1];isNaN(x)||isNaN(b)||p.push(x,b)}t.fill=v.fillcolor}}}}if(s._prevtrace&&\"tonext\"===s._prevtrace.fill){var _=g.lineOptions[e-1].positions,w=p.length/2,k=[i=w];for(a=0;a<_.length;a+=2)(isNaN(_[a])||isNaN(_[a+1]))&&(k.push(a/2+w+1),i=a+2);p=p.concat(_),t.hole=k}return t.fillmode=s.fill,t.opacity=s.opacity,t.positions=p,t}}),g.fill2d.update(g.fillOptions))}var k=d.dragmode,T=\"lasso\"===k||\"select\"===k,A=d.clickmode.indexOf(\"select\")>-1;for(f=0;f<y;f++){var M=r[f][0],S=M.trace,E=M.t,C=E.index,L=S._length,P=E.x,O=E.y;if(S.selectedpoints||T||A){if(T||(T=!0),S.selectedpoints){var z=g.selectBatch[C]=s.selIndices2selPoints(S),I={};for(p=0;p<z.length;p++)I[z[p]]=1;var D=[];for(p=0;p<L;p++)I[p]||D.push(p);g.unselectBatch[C]=D}var R=E.xpx=new Array(L),F=E.ypx=new Array(L);for(p=0;p<L;p++)R[p]=v.c2p(P[p]),F[p]=m.c2p(O[p])}else E.xpx=E.ypx=null}if(T){if(g.select2d||(g.select2d=n(d._glcanvas.data()[1].regl)),g.scatter2d){var B=new Array(y);for(f=0;f<y;f++)B[f]=g.selectBatch[f].length||g.unselectBatch[f].length?g.markerUnselectedOptions[f]:{};g.scatter2d.update(B)}g.select2d&&(g.select2d.update(g.markerOptions),g.select2d.update(g.markerSelectedOptions)),g.glText&&r.forEach(function(t){var e=((t||[])[0]||{}).trace||{};c.hasText(e)&&h(t)})}else g.scatter2d&&g.scatter2d.update(g.markerOptions);var N={viewport:function(t,e,r){var n=t._size,i=t.width,a=t.height;return[n.l+e.domain[0]*n.w,n.b+r.domain[0]*n.h,i-n.r-(1-e.domain[1])*n.w,a-n.t-(1-r.domain[1])*n.h]}(d,v,m),range:[(v._rl||v.range)[0],(m._rl||m.range)[0],(v._rl||v.range)[1],(m._rl||m.range)[1]]},j=s.repeat(N,g.count);g.fill2d&&g.fill2d.update(j),g.line2d&&g.line2d.update(j),g.error2d&&g.error2d.update(j.concat(j)),g.scatter2d&&g.scatter2d.update(j),g.select2d&&g.select2d.update(j),g.glText&&g.glText.forEach(function(t){t.update(N)})}else g.init()}}},{\"../../lib\":719,\"../../lib/prepare_regl\":732,\"../scatter/link_traces\":1127,\"../scatter/subtypes\":1135,\"./edit_style\":1165,\"gl-text\":317,\"regl-error2d\":490,\"regl-line2d\":491,\"regl-scatter2d\":497}],1169:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=e._scene,i={count:0,dirty:!0,lineOptions:[],fillOptions:[],markerOptions:[],markerSelectedOptions:[],markerUnselectedOptions:[],errorXOptions:[],errorYOptions:[],textOptions:[],textSelectedOptions:[],textUnselectedOptions:[],selectBatch:[],unselectBatch:[]},a={fill2d:!1,scatter2d:!1,error2d:!1,line2d:!1,glText:!1,select2d:!1};return e._scene||((r=e._scene={}).init=function(){n.extendFlat(r,a,i)},r.init(),r.update=function(t){var e=n.repeat(t,r.count);if(r.fill2d&&r.fill2d.update(e),r.scatter2d&&r.scatter2d.update(e),r.line2d&&r.line2d.update(e),r.error2d&&r.error2d.update(e.concat(e)),r.select2d&&r.select2d.update(e),r.glText)for(var i=0;i<r.count;i++)r.glText[i].update(t)},r.draw=function(){for(var t=r.count,e=r.fill2d,i=r.error2d,a=r.line2d,o=r.scatter2d,s=r.glText,l=r.select2d,c=r.selectBatch,u=r.unselectBatch,h=0;h<t;h++){if(e&&r.fillOrder[h]&&e.draw(r.fillOrder[h]),a&&r.lineOptions[h]&&a.draw(h),i&&(r.errorXOptions[h]&&i.draw(h),r.errorYOptions[h]&&i.draw(h+t)),o&&r.markerOptions[h])if(u[h].length){var f=n.repeat([],r.count);f[h]=u[h],o.draw(f)}else c[h].length||o.draw(h);s[h]&&r.textOptions[h]&&s[h].render()}l&&l.draw(c),r.dirty=!1},r.destroy=function(){r.fill2d&&r.fill2d.destroy&&r.fill2d.destroy(),r.scatter2d&&r.scatter2d.destroy&&r.scatter2d.destroy(),r.error2d&&r.error2d.destroy&&r.error2d.destroy(),r.line2d&&r.line2d.destroy&&r.line2d.destroy(),r.select2d&&r.select2d.destroy&&r.select2d.destroy(),r.glText&&r.glText.forEach(function(t){t.destroy&&t.destroy()}),r.lineOptions=null,r.fillOptions=null,r.markerOptions=null,r.markerSelectedOptions=null,r.markerUnselectedOptions=null,r.errorXOptions=null,r.errorYOptions=null,r.textOptions=null,r.textSelectedOptions=null,r.textUnselectedOptions=null,r.selectBatch=null,r.unselectBatch=null,e._scene=null}),r.dirty||n.extendFlat(r,i),r}},{\"../../lib\":719}],1170:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"./edit_style\").styleTextSelection;e.exports=function(t,e){var r=t.cd,a=[],o=r[0].trace,s=r[0].t,l=o._length,c=s.x,u=s.y,h=s._scene,f=s.index;if(!h)return a;var p=n.hasText(o),d=n.hasMarkers(o),g=!d&&!p;if(!0!==o.visible||g)return a;var v=[],m=[];if(!1!==e&&!e.degenerate)for(var y=0;y<l;y++)e.contains([s.xpx[y],s.ypx[y]],!1,y,t)?(v.push(y),a.push({pointNumber:y,x:c[y],y:u[y]})):m.push(y);if(d){var x=h.scatter2d;if(v.length||m.length){if(!h.selectBatch[f].length&&!h.unselectBatch[f].length){var b=new Array(h.count);b[f]=h.markerUnselectedOptions[f],x.update.apply(x,b)}}else{var _=new Array(h.count);_[f]=h.markerOptions[f],x.update.apply(x,_)}}return h.selectBatch[f]=v,h.unselectBatch[f]=m,p&&i(r),a}},{\"../scatter/subtypes\":1135,\"./edit_style\":1165}],1171:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scattergeo/attributes\"),a=t(\"../scatter/attributes\"),o=t(\"../../plots/mapbox/layout_attributes\"),s=t(\"../../plots/attributes\"),l=t(\"../../components/colorscale/attributes\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../plot_api/edit_types\").overrideAll,h=i.line,f=i.marker;e.exports=u({lon:i.lon,lat:i.lat,mode:c({},a.mode,{dflt:\"markers\"}),text:c({},a.text,{}),hovertext:c({},a.hovertext,{}),line:{color:h.color,width:h.width},connectgaps:a.connectgaps,marker:c({symbol:{valType:\"string\",dflt:\"circle\",arrayOk:!0},opacity:f.opacity,size:f.size,sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode},l(\"marker\")),fill:i.fill,fillcolor:a.fillcolor,textfont:o.layers.symbol.textfont,textposition:o.layers.symbol.textposition,below:{valType:\"string\"},selected:{marker:a.selected.marker},unselected:{marker:a.unselected.marker},hoverinfo:c({},s.hoverinfo,{flags:[\"lon\",\"lat\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../../plots/mapbox/layout_attributes\":824,\"../scatter/attributes\":1112,\"../scattergeo/attributes\":1151}],1172:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../lib/geojson_utils\"),s=t(\"../../components/colorscale\"),l=t(\"../../components/drawing\"),c=t(\"../scatter/make_bubble_size_func\"),u=t(\"../scatter/subtypes\"),h=t(\"../../plots/mapbox/convert_text_opts\");function f(){return{geojson:o.makeBlank(),layout:{visibility:\"none\"},paint:{}}}function p(t){return i.isArrayOrTypedArray(t)?function(t){return t}:t?function(){return t}:d}function d(){return\"\"}function g(t){return t[0]===a}e.exports=function(t){var e,r=t[0].trace,a=!0===r.visible&&0!==r._length,v=\"none\"!==r.fill,m=u.hasLines(r),y=u.hasMarkers(r),x=u.hasText(r),b=y&&\"circle\"===r.marker.symbol,_=y&&\"circle\"!==r.marker.symbol,w=f(),k=f(),T=f(),A=f(),M={fill:w,line:k,circle:T,symbol:A};if(!a)return M;if((v||m)&&(e=o.calcTraceToLineCoords(t)),v&&(w.geojson=o.makePolygon(e),w.layout.visibility=\"visible\",i.extendFlat(w.paint,{\"fill-color\":r.fillcolor})),m&&(k.geojson=o.makeLine(e),k.layout.visibility=\"visible\",i.extendFlat(k.paint,{\"line-width\":r.line.width,\"line-color\":r.line.color,\"line-opacity\":r.opacity})),b){var S=function(t){var e,r,a,o,u=t[0].trace,h=u.marker,f=u.selectedpoints,p=i.isArrayOrTypedArray(h.color),d=i.isArrayOrTypedArray(h.size),v=i.isArrayOrTypedArray(h.opacity);function m(t){return u.opacity*t}p&&(r=s.hasColorscale(u,\"marker\")?s.makeColorScaleFuncFromTrace(h):i.identity);d&&(a=c(u));v&&(o=function(t){var e=n(t)?+i.constrain(t,0,1):0;return m(e)});var y,x=[];for(e=0;e<t.length;e++){var b=t[e],_=b.lonlat;if(!g(_)){var w={};r&&(w.mcc=b.mcc=r(b.mc)),a&&(w.mrc=b.mrc=a(b.ms)),o&&(w.mo=o(b.mo)),f&&(w.selected=b.selected||0),x.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:_},properties:w})}}if(f)for(y=l.makeSelectedPointStyleFns(u),e=0;e<x.length;e++){var k=x[e].properties;y.selectedOpacityFn&&(k.mo=m(y.selectedOpacityFn(k))),y.selectedColorFn&&(k.mcc=y.selectedColorFn(k)),y.selectedSizeFn&&(k.mrc=y.selectedSizeFn(k))}return{geojson:{type:\"FeatureCollection\",features:x},mcc:p||y&&y.selectedColorFn?{type:\"identity\",property:\"mcc\"}:h.color,mrc:d||y&&y.selectedSizeFn?{type:\"identity\",property:\"mrc\"}:(T=h.size,T/2),mo:v||y&&y.selectedOpacityFn?{type:\"identity\",property:\"mo\"}:m(h.opacity)};var T}(t);T.geojson=S.geojson,T.layout.visibility=\"visible\",i.extendFlat(T.paint,{\"circle-color\":S.mcc,\"circle-radius\":S.mrc,\"circle-opacity\":S.mo})}if((_||x)&&(A.geojson=function(t){for(var e=t[0].trace,r=(e.marker||{}).symbol,n=e.text,i=\"circle\"!==r?p(r):d,a=u.hasText(e)?p(n):d,o=[],s=0;s<t.length;s++){var l=t[s];g(l.lonlat)||o.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:l.lonlat},properties:{symbol:i(l.mx),text:a(l.tx)}})}return{type:\"FeatureCollection\",features:o}}(t),i.extendFlat(A.layout,{visibility:\"visible\",\"icon-image\":\"{symbol}-15\",\"text-field\":\"{text}\"}),_&&(i.extendFlat(A.layout,{\"icon-size\":r.marker.size/10}),i.extendFlat(A.paint,{\"icon-opacity\":r.opacity*r.marker.opacity,\"icon-color\":r.marker.color})),x)){var E=(r.marker||{}).size,C=h(r.textposition,E);i.extendFlat(A.layout,{\"text-size\":r.textfont.size,\"text-anchor\":C.anchor,\"text-offset\":C.offset}),i.extendFlat(A.paint,{\"text-color\":r.textfont.color,\"text-opacity\":r.opacity})}return M}},{\"../../components/colorscale\":605,\"../../components/drawing\":614,\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/geojson_utils\":714,\"../../plots/mapbox/convert_text_opts\":821,\"../scatter/make_bubble_size_func\":1128,\"../scatter/subtypes\":1135,\"fast-isnumeric\":225}],1173:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,i){return n.coerce(t,e,c,r,i)}if(function(t,e,r){var n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length);return e._length=a,a}(0,e,h)){if(h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),h(\"below\"),i.hasLines(e)&&(o(t,e,r,u,h,{noDash:!0}),h(\"connectgaps\")),i.hasMarkers(e)){a(t,e,r,u,h,{noLine:!0});var f=e.marker;\"circle\"!==f.symbol&&(n.isArrayOrTypedArray(f.size)&&(f.size=f.size[0]),n.isArrayOrTypedArray(f.color)&&(f.color=f.color[0]))}i.hasText(e)&&s(t,e,u,h,{noSelect:!0}),h(\"fill\"),\"none\"!==e.fill&&l(t,e,r,h),n.coerceSelectionMarkerOpacity(e,h)}else e.visible=!1}},{\"../../lib\":719,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1171}],1174:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t}},{}],1175:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\"),o=i.fillText,s=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,h=t.ya,f=t.subplot,p=360*(e>=0?Math.floor((e+180)/360):Math.ceil((e-180)/360)),d=e-p;if(n.getClosest(l,function(t){var e=t.lonlat;if(e[0]===s)return 1/0;var n=i.modHalf(e[0],360),a=e[1],o=f.project([n,a]),l=o.x-u.c2p([d,a]),c=o.y-h.c2p([n,r]),p=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(l*l+c*c)-p,1-3/p)},t),!1!==t.index){var g=l[t.index],v=g.lonlat,m=[i.modHalf(v[0],360)+p,v[1]],y=u.c2p(m),x=h.c2p(m),b=g.mrc||1;return t.x0=y-b,t.x1=y+b,t.y0=x-b,t.y1=x+b,t.color=a(c,g),t.extraText=function(t,e,r){if(t.hovertemplate)return;var n=(e.hi||t.hoverinfo).split(\"+\"),i=-1!==n.indexOf(\"all\"),a=-1!==n.indexOf(\"lon\"),s=-1!==n.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}i||a&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):a?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(i||-1!==n.indexOf(\"text\"))&&o(e,t,c);return c.join(\"<br>\")}(c,g,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},{\"../../components/fx\":632,\"../../constants/numerical\":695,\"../../lib\":719,\"../scatter/get_trace_color\":1121}],1176:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"../scattergeo/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.update(e)},moduleType:\"trace\",name:\"scattermapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"symbols\",\"showLegend\",\"scatterlike\"],meta:{}}},{\"../../plots/mapbox\":822,\"../scatter/marker_colorbar\":1129,\"../scattergeo/calc\":1152,\"./attributes\":1171,\"./defaults\":1173,\"./event_data\":1174,\"./hover\":1175,\"./plot\":1177,\"./select\":1178}],1177:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix,a=[\"fill\",\"line\",\"circle\",\"symbol\"];function o(t,e){this.subplot=t,this.uid=e,this.sourceIds={fill:\"source-\"+e+\"-fill\",line:\"source-\"+e+\"-line\",circle:\"source-\"+e+\"-circle\",symbol:\"source-\"+e+\"-symbol\"},this.layerIds={fill:i+e+\"-fill\",line:i+e+\"-line\",circle:i+e+\"-circle\",symbol:i+e+\"-symbol\"},this.below=null}var s=o.prototype;s.addSource=function(t,e){this.subplot.map.addSource(this.sourceIds[t],{type:\"geojson\",data:e.geojson})},s.setSourceData=function(t,e){this.subplot.map.getSource(this.sourceIds[t]).setData(e.geojson)},s.addLayer=function(t,e,r){this.subplot.addLayer({type:t,id:this.layerIds[t],source:this.sourceIds[t],layout:e.layout,paint:e.paint},r)},s.update=function(t){var e,r,i,o=this.subplot,s=o.map,l=n(t),c=o.belowLookup[\"trace-\"+this.uid];if(c!==this.below){for(e=a.length-1;e>=0;e--)r=a[e],s.removeLayer(this.layerIds[r]);for(e=0;e<a.length;e++)i=l[r=a[e]],this.addLayer(r,i,c);this.below=c}for(e=0;e<a.length;e++)i=l[r=a[e]],o.setOptions(this.layerIds[r],\"setLayoutProperty\",i.layout),\"visible\"===i.layout.visibility&&(this.setSourceData(r,i),o.setOptions(this.layerIds[r],\"setPaintProperty\",i.paint));t[0].trace._glTrace=this},s.dispose=function(){for(var t=this.subplot.map,e=a.length-1;e>=0;e--){var r=a[e];t.removeLayer(this.layerIds[r]),t.removeSource(this.sourceIds[r])}},e.exports=function(t,e){for(var r=e[0].trace,i=new o(t,r.uid),s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid],c=0;c<a.length;c++){var u=a[c],h=s[u];i.addSource(u,h),i.addLayer(u,h,l)}return e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":820,\"./convert\":1172}],1178:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,o=t.cd,s=t.xaxis,l=t.yaxis,c=[],u=o[0].trace;if(!i.hasMarkers(u))return[];if(!1===e)for(r=0;r<o.length;r++)o[r].selected=0;else for(r=0;r<o.length;r++){var h=o[r],f=h.lonlat;if(f[0]!==a){var p=[n.modHalf(f[0],360),f[1]],d=[s.c2p(p),l.c2p(p)];e.contains(d,null,r,t)?(c.push({pointNumber:r,lon:f[0],lat:f[1]}),h.selected=1):h.selected=0}}return c}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../scatter/subtypes\":1135}],1179:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../scatter/attributes\"),o=t(\"../../plots/attributes\"),s=a.line;e.exports={mode:a.mode,r:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},theta:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},r0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dr:{valType:\"number\",dflt:1,editType:\"calc\"},theta0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dtheta:{valType:\"number\",editType:\"calc\"},thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\",\"gradians\"],dflt:\"degrees\",editType:\"calc+clearAxisTypes\"},text:a.text,hovertext:a.hovertext,line:{color:s.color,width:s.width,dash:s.dash,shape:i({},s.shape,{values:[\"linear\",\"spline\"]}),smoothing:s.smoothing,editType:\"calc\"},connectgaps:a.connectgaps,marker:a.marker,cliponaxis:i({},a.cliponaxis,{dflt:!1}),textposition:a.textposition,textfont:a.textfont,fill:i({},a.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:a.fillcolor,hoverinfo:i({},o.hoverinfo,{flags:[\"r\",\"theta\",\"text\",\"name\"]}),hoveron:a.hoveron,hovertemplate:n(),selected:a.selected,unselected:a.unselected}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1180:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../plots/cartesian/axes\"),o=t(\"../scatter/colorscale_calc\"),s=t(\"../scatter/arrays_to_calcdata\"),l=t(\"../scatter/calc_selection\"),c=t(\"../scatter/calc\").calcMarkerSize;e.exports=function(t,e){for(var r=t._fullLayout,u=e.subplot,h=r[u].radialaxis,f=r[u].angularaxis,p=h.makeCalcdata(e,\"r\"),d=f.makeCalcdata(e,\"theta\"),g=e._length,v=new Array(g),m=0;m<g;m++){var y=p[m],x=d[m],b=v[m]={};n(y)&&n(x)?(b.r=y,b.theta=x):b.r=i}var _=c(e,g);return e._extremes.x=a.findExtremes(h,p,{ppad:_}),o(t,e),s(v,e),l(v,e),v}},{\"../../constants/numerical\":695,\"../../plots/cartesian/axes\":767,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc\":1113,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1181:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/line_shape_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,h=t(\"./attributes\");function f(t,e,r,n){var i,a=n(\"r\"),o=n(\"theta\");if(a)o?i=Math.min(a.length,o.length):(i=a.length,n(\"theta0\"),n(\"dtheta\"));else{if(!o)return 0;i=e.theta.length,n(\"r0\"),n(\"dr\")}return e._length=i,i}e.exports={handleRThetaDefaults:f,supplyDefaults:function(t,e,r,p){function d(r,i){return n.coerce(t,e,h,r,i)}var g=f(0,e,0,d);if(g){d(\"thetaunit\"),d(\"mode\",g<u?\"lines+markers\":\"lines\"),d(\"text\"),d(\"hovertext\"),\"fills\"!==e.hoveron&&d(\"hovertemplate\"),i.hasLines(e)&&(o(t,e,r,p,d),s(t,e,d),d(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,p,d,{gradient:!0}),i.hasText(e)&&l(t,e,p,d);var v=[];(i.hasMarkers(e)||i.hasText(e))&&(d(\"cliponaxis\"),d(\"marker.maxdisplayed\"),v.push(\"points\")),d(\"fill\"),\"none\"!==e.fill&&(c(t,e,r,d),i.hasLines(e)||s(t,e,d)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||v.push(\"fills\"),d(\"hoveron\",v.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/line_shape_defaults\":1126,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1179}],1182:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\");function o(t,e,r,n){var o=r.radialAxis,s=r.angularAxis;o._hovertitle=\"r\",s._hovertitle=\"\\u03b8\";var l=o.c2l(t.r);n.rLabel=i.tickText(o,l,\"hover\").text;var c=\"degrees\"===s.thetaunit?a.rad2deg(t.theta):t.theta;n.thetaLabel=i.tickText(s,c,\"hover\").text;var u=t.hi||e.hoverinfo,h=[];function f(t,e){h.push(t._hovertitle+\": \"+e)}if(!e.hovertemplate){var p=u.split(\"+\");-1!==p.indexOf(\"all\")&&(p=[\"r\",\"theta\",\"text\"]),-1!==p.indexOf(\"r\")&&f(o,n.rLabel),-1!==p.indexOf(\"theta\")&&f(s,n.thetaLabel),-1!==p.indexOf(\"text\")&&n.text&&(h.push(n.text),delete n.text),n.extraText=h.join(\"<br>\")}}e.exports={hoverPoints:function(t,e,r,i){var a=n(t,e,r,i);if(a&&!1!==a[0].index){var s=a[0];if(void 0===s.index)return a;var l=t.subplot,c=s.cd[s.index],u=s.trace;if(l.isPtInside(c))return s.xLabelVal=void 0,s.yLabelVal=void 0,o(c,u,l,s),s.hovertemplate=u.hovertemplate,a}},makeHoverPointText:o}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scatter/hover\":1122}],1183:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scatter/select\"),meta:{}}},{\"../../plots/polar\":831,\"../scatter/marker_colorbar\":1129,\"../scatter/select\":1132,\"../scatter/style\":1134,\"./attributes\":1179,\"./calc\":1180,\"./defaults\":1181,\"./hover\":1182,\"./plot\":1184}],1184:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){for(var a=e.layers.frontplot.select(\"g.scatterlayer\"),o={xaxis:e.xaxis,yaxis:e.yaxis,plot:e.framework,layerClipId:e._hasClipOnAxisFalse?e.clipIds.forTraces:null},s=e.radialAxis,l=e.angularAxis,c=0;c<r.length;c++)for(var u=r[c],h=0;h<u.length;h++){var f=u[h],p=f.r;if(p===i)f.x=f.y=i;else{var d=s.c2g(p),g=l.c2g(f.theta);f.x=d*Math.cos(g),f.y=d*Math.sin(g)}}n(t,o,r,a)}},{\"../../constants/numerical\":695,\"../scatter/plot\":1131}],1185:[function(t,e,r){\"use strict\";var n=t(\"../scatterpolar/attributes\"),i=t(\"../scattergl/attributes\");e.exports={mode:n.mode,r:n.r,theta:n.theta,r0:n.r0,dr:n.dr,theta0:n.theta0,dtheta:n.dtheta,thetaunit:n.thetaunit,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,line:i.line,connectgaps:i.connectgaps,marker:i.marker,fill:i.fill,fillcolor:i.fillcolor,textposition:i.textposition,textfont:i.textfont,hoverinfo:n.hoverinfo,selected:n.selected,unselected:n.unselected}},{\"../scattergl/attributes\":1160,\"../scatterpolar/attributes\":1179}],1186:[function(t,e,r){\"use strict\";var n=t(\"../scatter/colorscale_calc\"),i=t(\"../scatter/calc\").calcMarkerSize,a=t(\"../scattergl/convert\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r=t._fullLayout,l=e.subplot,c=r[l].radialaxis,u=r[l].angularaxis,h=c.makeCalcdata(e,\"r\"),f=u.makeCalcdata(e,\"theta\"),p=e._length,d={};p<h.length&&(h=h.slice(0,p)),p<f.length&&(f=f.slice(0,p)),d.r=h,d.theta=f,n(t,e);var g,v=d.opts=a.style(t,e);return p<s?g=i(e,p):v.marker&&(g=2*(v.marker.sizeAvg||Math.max(v.marker.size,3))),e._extremes.x=o.findExtremes(c,h,{ppad:g}),[{x:!1,y:!1,t:d,trace:e}]}},{\"../../plots/cartesian/axes\":767,\"../scatter/calc\":1113,\"../scatter/colorscale_calc\":1115,\"../scattergl/constants\":1162,\"../scattergl/convert\":1163}],1187:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatterpolar/defaults\").handleRThetaDefaults,o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}var d=a(t,e,f,p);d?(p(\"thetaunit\"),p(\"mode\",d<u?\"lines+markers\":\"lines\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),i.hasLines(e)&&(s(t,e,r,f,p),p(\"connectgaps\")),i.hasMarkers(e)&&o(t,e,r,f,p),i.hasText(e)&&l(t,e,f,p),p(\"fill\"),\"none\"!==e.fill&&c(t,e,r,p),n.coerceSelectionMarkerOpacity(e,p)):e.visible=!1}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"../scatterpolar/defaults\":1181,\"./attributes\":1185}],1188:[function(t,e,r){\"use strict\";var n=t(\"../scattergl/hover\"),i=t(\"../scatterpolar/hover\").makeHoverPointText;e.exports={hoverPoints:function(t,e,r,a){var o=t.cd[0].t,s=o.r,l=o.theta,c=n.hoverPoints(t,e,r,a);if(c&&!1!==c[0].index){var u=c[0];if(void 0===u.index)return c;var h=t.subplot,f=u.cd[u.index],p=u.trace;if(f.r=s[u.index],f.theta=l[u.index],h.isPtInside(f))return u.xLabelVal=void 0,u.yLabelVal=void 0,i(f,p,h,u),c}}}},{\"../scattergl/hover\":1166,\"../scatterpolar/hover\":1182}],1189:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolargl\",basePlotModule:t(\"../../plots/polar\"),categories:[\"gl\",\"regl\",\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scattergl/select\"),meta:{}}},{\"../../plots/polar\":831,\"../scatter/marker_colorbar\":1129,\"../scattergl/select\":1170,\"./attributes\":1185,\"./calc\":1186,\"./defaults\":1187,\"./hover\":1188,\"./plot\":1190}],1190:[function(t,e,r){\"use strict\";var n=t(\"point-cluster\"),i=t(\"fast-isnumeric\"),a=t(\"../scattergl/plot\"),o=t(\"../scattergl/scene_update\"),s=t(\"../scattergl/convert\"),l=t(\"../../lib\"),c=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e,r){if(r.length){var u=e.radialAxis,h=e.angularAxis,f=o(t,e);return r.forEach(function(r){if(r&&r[0]&&r[0].trace){var a,o=r[0],p=o.trace,d=o.t,g=p._length,v=d.r,m=d.theta,y=d.opts,x=v.slice(),b=m.slice();for(a=0;a<v.length;a++)e.isPtInside({r:v[a],theta:m[a]})||(x[a]=NaN,b[a]=NaN);var _=new Array(2*g),w=Array(g),k=Array(g);for(a=0;a<g;a++){var T,A,M=x[a];if(i(M)){var S=u.c2g(M),E=h.c2g(b[a],p.thetaunit);T=S*Math.cos(E),A=S*Math.sin(E)}else T=A=NaN;w[a]=_[2*a]=T,k[a]=_[2*a+1]=A}d.tree=n(_),y.marker&&g>=c&&(y.marker.cluster=d.tree),y.marker&&(y.markerSel.positions=y.markerUnsel.positions=y.marker.positions=_),y.line&&_.length>1&&l.extendFlat(y.line,s.linePositions(t,p,_)),y.text&&(l.extendFlat(y.text,{positions:_},s.textPosition(t,p,y.text,y.marker)),l.extendFlat(y.textSel,{positions:_},s.textPosition(t,p,y.text,y.markerSel)),l.extendFlat(y.textUnsel,{positions:_},s.textPosition(t,p,y.text,y.markerUnsel))),y.fill&&!f.fill2d&&(f.fill2d=!0),y.marker&&!f.scatter2d&&(f.scatter2d=!0),y.line&&!f.line2d&&(f.line2d=!0),y.text&&!f.glText&&(f.glText=!0),f.lineOptions.push(y.line),f.fillOptions.push(y.fill),f.markerOptions.push(y.marker),f.markerSelectedOptions.push(y.markerSel),f.markerUnselectedOptions.push(y.markerUnsel),f.textOptions.push(y.text),f.textSelectedOptions.push(y.textSel),f.textUnselectedOptions.push(y.textUnsel),f.selectBatch.push([]),f.unselectBatch.push([]),d.x=w,d.y=k,d.rawx=w,d.rawy=k,d.r=v,d.theta=m,d.positions=_,d._scene=f,d.index=f.count,f.count++}}),a(t,e,r)}}},{\"../../lib\":719,\"../scattergl/constants\":1162,\"../scattergl/convert\":1163,\"../scattergl/plot\":1168,\"../scattergl/scene_update\":1169,\"fast-isnumeric\":225,\"point-cluster\":469}],1191:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/drawing/attributes\").dash,l=t(\"../../lib/extend\").extendFlat,c=i.marker,u=i.line,h=c.line;e.exports={a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},c:{valType:\"data_array\",editType:\"calc\"},sum:{valType:\"number\",dflt:0,min:0,editType:\"calc\"},mode:l({},i.mode,{dflt:\"markers\"}),text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),line:{color:u.color,width:u.width,dash:s,shape:l({},u.shape,{values:[\"linear\",\"spline\"]}),smoothing:u.smoothing,editType:\"calc\"},connectgaps:i.connectgaps,cliponaxis:i.cliponaxis,fill:l({},i.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:i.fillcolor,marker:l({symbol:c.symbol,opacity:c.opacity,maxdisplayed:c.maxdisplayed,size:c.size,sizeref:c.sizeref,sizemin:c.sizemin,sizemode:c.sizemode,line:l({width:h.width,editType:\"calc\"},o(\"marker.line\")),gradient:c.gradient,editType:\"calc\"},o(\"marker\")),textfont:i.textfont,textposition:i.textposition,selected:i.selected,unselected:i.unselected,hoverinfo:l({},a.hoverinfo,{flags:[\"a\",\"b\",\"c\",\"text\",\"name\"]}),hoveron:i.hoveron,hovertemplate:n()}},{\"../../components/colorscale/attributes\":600,\"../../components/drawing/attributes\":613,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1192:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=[\"a\",\"b\",\"c\"],c={a:[\"b\",\"c\"],b:[\"a\",\"c\"],c:[\"a\",\"b\"]};e.exports=function(t,e){var r,u,h,f,p,d,g=t._fullLayout[e.subplot].sum,v=e.sum||g,m={a:e.a,b:e.b,c:e.c};for(r=0;r<l.length;r++)if(!m[h=l[r]]){for(p=m[c[h][0]],d=m[c[h][1]],f=new Array(p.length),u=0;u<p.length;u++)f[u]=v-p[u]-d[u];m[h]=f}var y,x,b,_,w,k,T=e._length,A=new Array(T);for(r=0;r<T;r++)y=m.a[r],x=m.b[r],b=m.c[r],n(y)&&n(x)&&n(b)?(1!==(_=g/((y=+y)+(x=+x)+(b=+b)))&&(y*=_,x*=_,b*=_),k=y,w=b-x,A[r]={x:w,y:k,a:y,b:x,c:b}):A[r]={x:!1,y:!1};return s(e,T),i(t,e),a(A,e),o(A,e),A}},{\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc\":1113,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1193:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}var d,g=p(\"a\"),v=p(\"b\"),m=p(\"c\");if(g?(d=g.length,v?(d=Math.min(d,v.length),m&&(d=Math.min(d,m.length))):d=m?Math.min(d,m.length):0):v&&m&&(d=Math.min(v.length,m.length)),d){e._length=d,p(\"sum\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),p(\"mode\",d<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,f,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,f,p,{gradient:!0}),a.hasText(e)&&c(t,e,f,p);var y=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"cliponaxis\"),p(\"marker.maxdisplayed\"),y.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||y.push(\"fills\"),p(\"hoveron\",y.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/line_shape_defaults\":1126,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1191}],1194:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),n[i]){var a=n[i];t.a=a.a,t.b=a.b,t.c=a.c}else t.a=e.a,t.b=e.b,t.c=e.c;return t}},{}],1195:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,h=c-u;return s.x0=Math.max(Math.min(s.x0,h),u),s.x1=Math.max(Math.min(s.x1,h),u),o}var f=s.cd[s.index];s.a=f.a,s.b=f.b,s.c=f.c,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.subplot;s.aLabel=i.tickText(p.aaxis,f.a,\"hover\").text,s.bLabel=i.tickText(p.baxis,f.b,\"hover\").text,s.cLabel=i.tickText(p.caxis,f.c,\"hover\").text;var d=s.trace,g=f.hi||d.hoverinfo,v=[];if(!d.hovertemplate){var m=g.split(\"+\");-1!==m.indexOf(\"all\")&&(m=[\"a\",\"b\",\"c\"]),-1!==m.indexOf(\"a\")&&y(p.aaxis,s.aLabel),-1!==m.indexOf(\"b\")&&y(p.baxis,s.bLabel),-1!==m.indexOf(\"c\")&&y(p.caxis,s.cLabel)}return s.extraText=v.join(\"<br>\"),s.hovertemplate=d.hovertemplate,o}function y(t,e){v.push(t._hovertitle+\": \"+e)}}},{\"../../plots/cartesian/axes\":767,\"../scatter/hover\":1122}],1196:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scatterternary\",basePlotModule:t(\"../../plots/ternary\"),categories:[\"ternary\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/ternary\":843,\"../scatter/marker_colorbar\":1129,\"../scatter/select\":1132,\"../scatter/style\":1134,\"./attributes\":1191,\"./calc\":1192,\"./defaults\":1193,\"./event_data\":1194,\"./hover\":1195,\"./plot\":1197}],1197:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\");e.exports=function(t,e,r){var i=e.plotContainer;i.select(\".scatterlayer\").selectAll(\"*\").remove();var a={xaxis:e.xaxis,yaxis:e.yaxis,plot:i,layerClipId:e._hasClipOnAxisFalse?e.clipIdRelative:null},o=e.layers.frontplot.select(\"g.scatterlayer\");n(t,a,r,o)}},{\"../scatter/plot\":1131}],1198:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../scattergl/attributes\"),s=t(\"../../plots/cartesian/constants\").idRegex,l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"../../lib/extend\").extendFlat,u=n.marker,h=u.line,f=c(i(\"marker.line\",{editTypeOverride:\"calc\"}),{width:c({},h.width,{editType:\"calc\"}),editType:\"calc\"}),p=c(i(\"marker\"),{symbol:u.symbol,size:c({},u.size,{editType:\"markerSize\"}),sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:f,editType:\"calc\"});function d(t){return{valType:\"info_array\",freeLength:!0,editType:\"calc\",items:{valType:\"subplotid\",regex:s[t],editType:\"plot\"}}}p.color.editType=p.cmin.editType=p.cmax.editType=\"style\",e.exports={dimensions:l(\"dimension\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},label:{valType:\"string\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},axis:{type:{valType:\"enumerated\",values:[\"linear\",\"log\",\"date\",\"category\"],editType:\"calc+clearAxisTypes\"},matches:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc+clearAxisTypes\"},editType:\"calc+clearAxisTypes\"}),text:c({},o.text,{}),hovertext:c({},o.hovertext,{}),hovertemplate:a(),marker:p,xaxes:d(\"x\"),yaxes:d(\"y\"),diagonal:{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},showupperhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},showlowerhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},selected:{marker:o.selected.marker,editType:\"calc\"},unselected:{marker:o.unselected.marker,editType:\"calc\"},opacity:o.opacity}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773,\"../scatter/attributes\":1112,\"../scattergl/attributes\":1160}],1199:[function(t,e,r){\"use strict\";var n=t(\"regl-line2d\"),i=t(\"../../registry\"),a=t(\"../../lib/prepare_regl\"),o=t(\"../../plots/get_data\").getModuleCalcData,s=t(\"../../plots/cartesian\"),l=t(\"../../plots/cartesian/axis_ids\").getFromId,c=t(\"../../plots/cartesian/axes\").shouldShowZeroLine,u=\"splom\";function h(t,e,r){for(var n=r.matrixOptions.data.length,i=e._visibleDims,a=r.viewOpts.ranges=new Array(n),o=0;o<i.length;o++){var s=i[o],c=a[o]=new Array(4),u=l(t,e._diag[s][0]);u&&(c[0]=u.r2l(u.range[0]),c[2]=u.r2l(u.range[1]));var h=l(t,e._diag[s][1]);h&&(c[1]=h.r2l(h.range[0]),c[3]=h.r2l(h.range[1]))}r.selectBatch.length||r.unselectBatch.length?r.matrix.update({ranges:a},{ranges:a}):r.matrix.update({ranges:a})}function f(t){var e=t._fullLayout,r=e._glcanvas.data()[0].regl,i=e._splomGrid;i||(i=e._splomGrid=n(r)),i.update(function(t){var e,r=t._fullLayout,n=r._size,i=[0,0,r.width,r.height],a={};function o(t,e,r,n,o,s){var l=e[t+\"color\"],c=e[t+\"width\"],u=String(l+c);u in a?a[u].data.push(NaN,NaN,r,n,o,s):a[u]={data:[r,n,o,s],join:\"rect\",thickness:c,color:l,viewport:i,range:i,overlay:!1}}for(e in r._splomSubplots){var s,l,u=r._plots[e],h=u.xaxis,f=u.yaxis,p=h._vals,d=f._vals,g=n.b+f.domain[0]*n.h,v=-f._m,m=-v*f.r2l(f.range[0],f.calendar);if(h.showgrid)for(e=0;e<p.length;e++)s=h._offset+h.l2p(p[e].x),o(\"grid\",h,s,g,s,g+f._length);if(f.showgrid)for(e=0;e<d.length;e++)l=g+m+v*d[e].x,o(\"grid\",f,h._offset,l,h._offset+h._length,l);c(t,h,f)&&(s=h._offset+h.l2p(0),o(\"zeroline\",h,s,g,s,g+f._length)),c(t,f,h)&&(l=g+m+0,o(\"zeroline\",f,h._offset,l,h._offset+h._length,l))}var y=[];for(e in a)y.push(a[e]);return y}(t))}e.exports={name:u,attr:s.attr,attrRegex:s.attrRegex,layoutAttributes:s.layoutAttributes,supplyLayoutDefaults:s.supplyLayoutDefaults,drawFramework:s.drawFramework,plot:function(t){var e=t._fullLayout,r=i.getModule(u),n=o(t.calcdata,r)[0];a(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])&&(e._hasOnlyLargeSploms&&f(t),r.plot(t,{},n))},drag:function(t){var e=t.calcdata,r=t._fullLayout;r._hasOnlyLargeSploms&&f(t);for(var n=0;n<e.length;n++){var i=e[n][0].trace,a=r._splomScenes[i.uid];\"splom\"===i.type&&a&&a.matrix&&h(t,i,a)}},updateGrid:f,clean:function(t,e,r,n){var i,a={};if(n._splomScenes){for(i=0;i<t.length;i++){var o=t[i];\"splom\"===o.type&&(a[o.uid]=1)}for(i=0;i<r.length;i++){var l=r[i];if(!a[l.uid]){var c=n._splomScenes[l.uid];c&&c.destroy&&c.destroy(),n._splomScenes[l.uid]=null,delete n._splomScenes[l.uid]}}}0===Object.keys(n._splomScenes||{}).length&&delete n._splomScenes,n._splomGrid&&!e._hasOnlyLargeSploms&&n._hasOnlyLargeSploms&&(n._splomGrid.destroy(),n._splomGrid=null,delete n._splomGrid),s.clean(t,e,r,n)},updateFx:s.updateFx,toSVG:s.toSVG}},{\"../../lib/prepare_regl\":732,\"../../plots/cartesian\":778,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_ids\":770,\"../../plots/get_data\":802,\"../../registry\":847,\"regl-line2d\":491}],1200:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../scatter/calc\").calcMarkerSize,o=t(\"../scatter/calc\").calcAxisExpansion,s=t(\"../scatter/colorscale_calc\"),l=t(\"../scattergl/convert\").markerSelection,c=t(\"../scattergl/convert\").markerStyle,u=t(\"./scene_update\"),h=t(\"../../constants/numerical\").BADNUM,f=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r,p,d,g,v,m,y=e.dimensions,x=e._length,b={},_=b.cdata=[],w=b.data=[],k=e._visibleDims=[];function T(t,r){for(var i=t.makeCalcdata({v:r.values,vcalendar:e.calendar},\"v\"),a=0;a<i.length;a++)i[a]=i[a]===h?NaN:i[a];_.push(i),w.push(\"log\"===t.type?n.simpleMap(i,t.c2l):i)}for(r=0;r<y.length;r++)if((d=y[r]).visible){if(g=i.getFromId(t,e._diag[r][0]),v=i.getFromId(t,e._diag[r][1]),g&&v&&g.type!==v.type){n.log(\"Skipping splom dimension \"+r+\" with conflicting axis types\");continue}g?(T(g,d),v&&\"category\"===v.type&&(v._categories=g._categories.slice())):T(v,d),k.push(r)}for(s(t,e),n.extendFlat(b,c(e)),m=_.length*x>f?2*(b.sizeAvg||Math.max(b.size,3)):a(e,x),p=0;p<k.length;p++)d=y[r=k[p]],g=i.getFromId(t,e._diag[r][0])||{},v=i.getFromId(t,e._diag[r][1])||{},o(t,e,g,v,_[p],_[p],m);var A=u(t,e);return A.matrix||(A.matrix=!0),A.matrixOptions=b,A.selectedOptions=l(e,e.selected),A.unselectedOptions=l(e,e.unselected),[{x:!1,y:!1,t:{},trace:e}]}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../scatter/calc\":1113,\"../scatter/colorscale_calc\":1115,\"../scattergl/constants\":1162,\"../scattergl/convert\":1163,\"./scene_update\":1207}],1201:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"../scatter/subtypes\"),s=t(\"../scatter/marker_defaults\"),l=t(\"../parcoords/merge_length\"),c=/-open/;function u(t,e){function r(r,i){return n.coerce(t,e,a.dimensions,r,i)}r(\"label\");var i=r(\"values\");i&&i.length?r(\"visible\"):e.visible=!1,r(\"axis.type\"),r(\"axis.matches\")}e.exports=function(t,e,r,h){function f(r,i){return n.coerce(t,e,a,r,i)}var p=i(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=f(\"diagonal.visible\"),g=f(\"showupperhalf\"),v=f(\"showlowerhalf\");if(l(e,p,\"values\")&&(d||g||v)){f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),s(t,e,r,h,f);var m=c.test(e.marker.symbol),y=o.isBubble(e);f(\"marker.line.width\",m||y?1:0),function(t,e,r,n){var i,a,o=e.dimensions,s=o.length,l=e.showupperhalf,c=e.showlowerhalf,u=e.diagonal.visible,h=new Array(s),f=new Array(s);for(i=0;i<s;i++){var p=i?i+1:\"\";h[i]=\"x\"+p,f[i]=\"y\"+p}var d=n(\"xaxes\",h),g=n(\"yaxes\",f),v=e._diag=new Array(s);e._xaxes={},e._yaxes={};var m=[],y=[];function x(t,n,i,a){if(t){var o=t.charAt(0),s=r._splomAxes[o];if(e[\"_\"+o+\"axes\"][t]=1,a.push(t),!(t in s)){var l=s[t]={};i&&(l.label=i.label||\"\",i.visible&&i.axis&&(i.axis.type&&(l.type=i.axis.type),i.axis.matches&&(l.matches=n)))}}}var b=!u&&!c,_=!u&&!l;for(e._axesDim={},i=0;i<s;i++){var w=o[i],k=0===i,T=i===s-1,A=k&&b||T&&_?void 0:d[i],M=k&&_||T&&b?void 0:g[i];x(A,M,w,m),x(M,A,w,y),v[i]=[A,M],e._axesDim[A]=i,e._axesDim[M]=i}for(i=0;i<m.length;i++)for(a=0;a<y.length;a++){var S=m[i]+y[a];i>a&&l?r._splomSubplots[S]=1:i<a&&c?r._splomSubplots[S]=1:i!==a||!u&&c&&l||(r._splomSubplots[S]=1)}(!c||!u&&l&&c)&&(r._splomGridDflt.xside=\"bottom\",r._splomGridDflt.yside=\"left\")}(0,e,h,f),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../parcoords/merge_length\":1083,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"./attributes\":1198}],1202:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scattergl/convert\").markerStyle;e.exports=function(t,e){var r=e.trace,o=t._fullLayout._splomScenes[r.uid];if(o){i(t,r),n.extendFlat(o.matrixOptions,a(r));var s=n.extendFlat({},o.matrixOptions,o.viewOpts);o.matrix.update(s,null)}}},{\"../../lib\":719,\"../scatter/colorscale_calc\":1115,\"../scattergl/convert\":1163}],1203:[function(t,e,r){\"use strict\";r.getDimIndex=function(t,e){for(var r=e._id,n={x:0,y:1}[r.charAt(0)],i=t._visibleDims,a=0;a<i.length;a++){var o=i[a];if(t._diag[o][n]===r)return a}return!1}},{}],1204:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i=t(\"../scattergl/hover\").calcHover;e.exports={hoverPoints:function(t,e,r){var a=t.cd[0].trace,o=t.scene.matrixOptions.cdata,s=t.xa,l=t.ya,c=s.c2p(e),u=l.c2p(r),h=t.distance,f=n.getDimIndex(a,s),p=n.getDimIndex(a,l);if(!1===f||!1===p)return[t];for(var d,g,v=o[f],m=o[p],y=h,x=0;x<v.length;x++){var b=v[x],_=m[x],w=s.c2p(b)-c,k=l.c2p(_)-u,T=Math.sqrt(w*w+k*k);T<y&&(y=g=T,d=x)}return t.index=d,t.distance=y,t.dxy=g,void 0===d?[t]:(i(t,v,m,a),[t])}}},{\"../scattergl/hover\":1166,\"./helpers\":1203}],1205:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../components/grid\");e.exports={moduleType:\"trace\",name:\"splom\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\"),editStyle:t(\"./edit_style\"),meta:{}},n.register(i)},{\"../../components/grid\":636,\"../../registry\":847,\"../scatter/marker_colorbar\":1129,\"./attributes\":1198,\"./base_plot\":1199,\"./calc\":1200,\"./defaults\":1201,\"./edit_style\":1202,\"./hover\":1204,\"./plot\":1206,\"./select\":1208}],1206:[function(t,e,r){\"use strict\";var n=t(\"regl-splom\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\");function o(t,e){var r,o,s,l,c,u=t._fullLayout,h=u._size,f=e.trace,p=e.t,d=u._splomScenes[f.uid],g=d.matrixOptions,v=g.cdata,m=u._glcanvas.data()[0].regl,y=u.dragmode;if(0!==v.length){g.lower=f.showupperhalf,g.upper=f.showlowerhalf,g.diagonal=f.diagonal.visible;var x=f._visibleDims,b=v.length,_=d.viewOpts={};for(_.ranges=new Array(b),_.domains=new Array(b),c=0;c<x.length;c++){s=x[c];var w=_.ranges[c]=new Array(4),k=_.domains[c]=new Array(4);(r=a.getFromId(t,f._diag[s][0]))&&(w[0]=r._rl[0],w[2]=r._rl[1],k[0]=r.domain[0],k[2]=r.domain[1]),(o=a.getFromId(t,f._diag[s][1]))&&(w[1]=o._rl[0],w[3]=o._rl[1],k[1]=o.domain[0],k[3]=o.domain[1])}_.viewport=[h.l,h.b,h.w+h.l,h.h+h.b],!0===d.matrix&&(d.matrix=n(m));var T=u.clickmode.indexOf(\"select\")>-1,A=!0;if(\"lasso\"===y||\"select\"===y||!!f.selectedpoints||T){var M=f._length;if(f.selectedpoints){d.selectBatch=f.selectedpoints;var S=f.selectedpoints,E={};for(s=0;s<S.length;s++)E[S[s]]=!0;var C=[];for(s=0;s<M;s++)E[s]||C.push(s);d.unselectBatch=C}var L=p.xpx=new Array(b),P=p.ypx=new Array(b);for(c=0;c<x.length;c++){if(s=x[c],r=a.getFromId(t,f._diag[s][0]))for(L[c]=new Array(M),l=0;l<M;l++)L[c][l]=r.c2p(v[c][l]);if(o=a.getFromId(t,f._diag[s][1]))for(P[c]=new Array(M),l=0;l<M;l++)P[c][l]=o.c2p(v[c][l])}if(d.selectBatch.length||d.unselectBatch.length){var O=i.extendFlat({},g,d.unselectedOptions,_),z=i.extendFlat({},g,d.selectedOptions,_);d.matrix.update(O,z),A=!1}}else p.xpx=p.ypx=null;if(A){var I=i.extendFlat({},g,_);d.matrix.update(I,null)}}}e.exports=function(t,e,r){if(r.length)for(var n=0;n<r.length;n++)o(t,r[n][0])}},{\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"regl-splom\":501}],1207:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t._fullLayout,i=e.uid,a=r._splomScenes;a||(a=r._splomScenes={});var o={dirty:!0},s=a[e.uid];return s||((s=a[i]=n.extendFlat({},o,{matrix:!1,selectBatch:[],unselectBatch:[]})).draw=function(){s.matrix&&s.matrix.draw&&(s.selectBatch.length||s.unselectBatch.length?s.matrix.draw(s.unselectBatch,s.selectBatch):s.matrix.draw()),s.dirty=!1},s.destroy=function(){s.matrix&&s.matrix.destroy&&s.matrix.destroy(),s.matrixOptions=null,s.selectBatch=null,s.unselectBatch=null,s=null}),s.dirty||n.extendFlat(s,o),s}},{\"../../lib\":719}],1208:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"./helpers\");e.exports=function(t,e){var r=t.cd,o=r[0].trace,s=r[0].t,l=t.scene,c=l.matrixOptions.cdata,u=t.xaxis,h=t.yaxis,f=[];if(!l)return f;var p=!i.hasMarkers(o)&&!i.hasText(o);if(!0!==o.visible||p)return f;var d=a.getDimIndex(o,u),g=a.getDimIndex(o,h);if(!1===d||!1===g)return f;var v=s.xpx[d],m=s.ypx[g],y=c[d],x=c[g],b=[],_=[];if(!1!==e&&!e.degenerate)for(var w=0;w<y.length;w++)e.contains([v[w],m[w]],null,w,t)?(b.push(w),f.push({pointNumber:w,x:y[w],y:x[w]})):_.push(w);var k=l.matrixOptions;return b.length||_.length?l.selectBatch.length||l.unselectBatch.length||l.matrix.update(l.unselectedOptions,n.extendFlat({},k,l.selectedOptions,l.viewOpts)):l.matrix.update(k,null),l.selectBatch=b,l.unselectBatch=_,f}},{\"../../lib\":719,\"../scatter/subtypes\":1135,\"./helpers\":1203}],1209:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},starts:{x:{valType:\"data_array\",editType:\"calc\"},y:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},maxdisplayed:{valType:\"integer\",min:0,dflt:1e3,editType:\"calc\"},sizeref:{valType:\"number\",editType:\"calc\",min:0,dflt:1},text:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:i({editType:\"calc\"},{keys:[\"tubex\",\"tubey\",\"tubez\",\"tubeu\",\"tubev\",\"tubew\",\"norm\",\"divergence\"]})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach(function(t){l[t]=a[t]}),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"divergence\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../mesh3d/attributes\":1053}],1210:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){var r,i,a,o,s=e.u,l=e.v,c=e.w,u=e.x,h=e.y,f=e.z,p=Math.min(u.length,h.length,f.length,s.length,l.length,c.length),d=0;e.starts&&(i=e.starts.x||[],a=e.starts.y||[],o=e.starts.z||[],d=Math.min(i.length,a.length,o.length));var g=0,v=1/0;for(r=0;r<p;r++){var m=s[r],y=l[r],x=c[r],b=Math.sqrt(m*m+y*y+x*x);g=Math.max(g,b),v=Math.min(v,b)}n(t,e,{vals:[v,g],containerStr:\"\",cLetter:\"c\"});var _=-1/0,w=1/0,k=-1/0,T=1/0,A=-1/0,M=1/0;for(r=0;r<p;r++){var S=u[r];_=Math.max(_,S),w=Math.min(w,S);var E=h[r];k=Math.max(k,E),T=Math.min(T,E);var C=f[r];A=Math.max(A,C),M=Math.min(M,C)}for(r=0;r<d;r++){var L=i[r];_=Math.max(_,L),w=Math.min(w,L);var P=a[r];k=Math.max(k,P),T=Math.min(T,P);var O=o[r];A=Math.max(A,O),M=Math.min(M,O)}e._len=p,e._slen=d,e._normMax=g,e._xbnds=[w,_],e._ybnds=[T,k],e._zbnds=[M,A]}},{\"../../components/colorscale/calc\":601}],1211:[function(t,e,r){\"use strict\";var n=t(\"gl-streamtube3d\"),i=n.createTubeMesh,a=t(\"../../lib\"),o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\"),c={xaxis:0,yaxis:1,zaxis:2};function u(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var h=u.prototype;function f(t){return a.distinctVals(t).vals}function p(t){var e=t.length;return e>2?t.slice(1,e-1):2===e?[(t[0]+t[1])/2]:t}function d(t){var e=t.length;return 1===e?[.5,.5]:[t[1]-t[0],t[e-1]-t[e-2]]}function g(t,e){var r=t.fullSceneLayout,i=t.dataScale,u=e._len,h={};function g(t,e){var n=r[e],o=i[c[e]];return a.simpleMap(t,function(t){return n.d2l(t)*o})}h.vectors=l(g(e.u,\"xaxis\"),g(e.v,\"yaxis\"),g(e.w,\"zaxis\"),u);var v=f(e.x.slice(0,u)),m=f(e.y.slice(0,u)),y=f(e.z.slice(0,u));if(v.length*m.length*y.length>u)return{positions:[],cells:[]};var x=g(v,\"xaxis\"),b=g(m,\"yaxis\"),_=g(y,\"zaxis\");if(h.meshgrid=[x,b,_],e.starts){var w=e._slen;h.startingPositions=l(g(e.starts.x.slice(0,w),\"xaxis\"),g(e.starts.y.slice(0,w),\"yaxis\"),g(e.starts.z.slice(0,w),\"zaxis\"))}else{for(var k=b[0],T=p(x),A=p(_),M=new Array(T.length*A.length),S=0,E=0;E<T.length;E++)for(var C=0;C<A.length;C++)M[S++]=[T[E],k,A[C]];h.startingPositions=M}h.colormap=o(e),h.tubeSize=e.sizeref,h.maxLength=e.maxdisplayed;var L=g(e._xbnds,\"xaxis\"),P=g(e._ybnds,\"yaxis\"),O=g(e._zbnds,\"zaxis\"),z=d(x),I=d(b),D=d(_),R=[[L[0]-z[0],P[0]-I[0],O[0]-D[0]],[L[1]+z[1],P[1]+I[1],O[1]+D[1]]],F=n(h,R),B=s(e);F.vertexIntensityBounds=[B.min/e._normMax,B.max/e._normMax];var N=e.lightposition;return F.lightPosition=[N.x,N.y,N.z],F.ambient=e.lighting.ambient,F.diffuse=e.lighting.diffuse,F.specular=e.lighting.specular,F.roughness=e.lighting.roughness,F.fresnel=e.lighting.fresnel,F.opacity=e.opacity,e._pad=F.tubeScale*e.sizeref*2,F}h.handlePick=function(t){var e=this.scene.fullSceneLayout,r=this.scene.dataScale;function n(t,n){var i=e[n],a=r[c[n]];return i.l2c(t)/a}if(t.object===this.mesh){var i=t.data.position,a=t.data.velocity;return t.traceCoordinate=[n(i[0],\"xaxis\"),n(i[1],\"yaxis\"),n(i[2],\"zaxis\"),n(a[0],\"xaxis\"),n(a[1],\"yaxis\"),n(a[2],\"zaxis\"),t.data.intensity*this.data._normMax,t.data.divergence],t.textLabel=this.data.hovertext||this.data.text,!0}},h.update=function(t){this.data=t;var e=g(this.scene,t);this.mesh.update(e)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=g(t,e),a=i(r,n),o=new u(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../plots/gl3d/zip3\":818,\"gl-streamtube3d\":313}],1212:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),h=s(\"x\"),f=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length&&p&&p.length?(s(\"starts.x\"),s(\"starts.y\"),s(\"starts.z\"),s(\"maxdisplayed\"),s(\"sizeref\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":1209}],1213:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"streamtube\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),eventData:function(t,e){return t.tubex=t.x,t.tubey=t.y,t.tubez=t.z,t.tubeu=e.traceCoordinate[3],t.tubev=e.traceCoordinate[4],t.tubew=e.traceCoordinate[5],t.norm=e.traceCoordinate[6],t.divergence=e.traceCoordinate[7],delete t.x,delete t.y,delete t.z,t},meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1209,\"./calc\":1210,\"./convert\":1211,\"./defaults\":1212}],1214:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../plots/domain\").attributes,o=t(\"../pie/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports={labels:{valType:\"data_array\",editType:\"calc\"},parents:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},branchvalues:{valType:\"enumerated\",values:[\"remainder\",\"total\"],dflt:\"remainder\",editType:\"calc\"},level:{valType:\"any\",editType:\"plot\",anim:!0},maxdepth:{valType:\"integer\",editType:\"plot\",dflt:-1},marker:{colors:{valType:\"data_array\",editType:\"calc\"},line:{color:s({},o.marker.line.color,{dflt:null}),width:s({},o.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},leaf:{opacity:{valType:\"number\",editType:\"style\",min:0,max:1,dflt:.7},editType:\"plot\"},text:o.text,textinfo:s({},o.textinfo,{editType:\"plot\",flags:[\"label\",\"text\",\"value\"]}),textfont:o.textfont,hovertext:o.hovertext,hoverinfo:s({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"name\"]}),hovertemplate:i(),insidetextfont:o.insidetextfont,outsidetextfont:o.outsidetextfont,domain:a({name:\"sunburst\",trace:!0,editType:\"calc\"})}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../pie/attributes\":1086}],1215:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=r.name=\"sunburst\";r.plot=function(t,e,r,o){var s=n.getModule(a),l=i(t.calcdata,s)[0];s.plot(t,l,r,o)},r.clean=function(t,e,r,n){var i=n._has&&n._has(a),o=e._has&&e._has(a);i&&!o&&n._sunburstlayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],1216:[function(t,e,r){\"use strict\";var n=t(\"d3-hierarchy\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../pie/calc\").makePullColorFn,s=t(\"../pie/calc\").generateExtendedColors,l=a.isArrayOrTypedArray,c={};r.calc=function(t,e){var r,s,c,u,h,f,p=t._fullLayout,d=e.ids,g=l(d),v=e.labels,m=e.parents,y=e.values,x=l(y),b=[],_={},w={},k=function(t){return t||\"number\"==typeof t},T=function(t){return!x||i(y[t])&&y[t]>=0};g?(r=Math.min(d.length,m.length),s=function(t){return k(d[t])&&T(t)},c=function(t){return String(d[t])}):(r=Math.min(v.length,m.length),s=function(t){return k(v[t])&&T(t)},c=function(t){return String(v[t])}),x&&(r=Math.min(r,y.length));for(var A=0;A<r;A++)if(s(A)){var M=c(A),S=k(m[A])?String(m[A]):\"\",E={i:A,id:M,pid:S,label:k(v[A])?String(v[A]):\"\"};x&&(E.v=+y[A]),b.push(E),h=M,_[u=S]?_[u].push(h):_[u]=[h],w[h]=1}if(_[\"\"]){if(_[\"\"].length>1){for(var C=a.randstr(),L=0;L<b.length;L++)\"\"===b[L].pid&&(b[L].pid=C);b.unshift({hasMultipleRoots:!0,id:C,pid:\"\"})}}else{var P,O=[];for(P in _)w[P]||O.push(P);if(1!==O.length)return a.warn(\"Multiple implied roots, cannot build sunburst hierarchy.\");P=O[0],b.unshift({id:P,pid:\"\",label:P})}try{f=n.stratify().id(function(t){return t.id}).parentId(function(t){return t.pid})(b)}catch(t){return a.warn(\"Failed to build sunburst hierarchy. Error: \"+t.message)}var z=n.hierarchy(f),I=!1;if(x)switch(e.branchvalues){case\"remainder\":z.sum(function(t){return t.data.v});break;case\"total\":z.each(function(t){var e=t.data.data.v;if(t.children&&e<t.children.reduce(function(t,e){return t+e.data.data.v},0))return I=!0,a.warn([\"Total value for node\",t.data.data.id,\"is smaller than the sum of its children.\"].join(\" \"));t.value=e})}else z.count();if(!I){z.sort(function(t,e){return e.value-t.value});var D=e.marker.colors||[],R=o(p._sunburstcolormap);return z.each(function(t){var e=t.data.data,r=e.id;e.color=R(D[e.i],r)}),b[0].hierarchy=z,b}},r.crossTraceCalc=function(t){var e=t._fullLayout,r=t.calcdata,n=e.sunburstcolorway,i=e._sunburstcolormap;e.extendsunburstcolors&&(n=s(n,c));var a=0;function o(t){var e=t.data.data,r=e.id;!1===e.color&&(i[r]?e.color=i[r]:t.parent?t.parent.parent?e.color=t.parent.data.data.color:(i[r]=e.color=n[a%n.length],a++):e.color=\"rgba(0,0,0,0)\")}for(var l=0;l<r.length;l++){var u=r[l][0];\"sunburst\"===u.trace.type&&u.hierarchy&&u.hierarchy.each(o)}}},{\"../../lib\":719,\"../pie/calc\":1088,\"d3-hierarchy\":157,\"fast-isnumeric\":225}],1217:[function(t,e,r){\"use strict\";e.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:\"linear\"}},{}],1218:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}var c=l(\"labels\"),u=l(\"parents\");if(c&&c.length&&u&&u.length){var h=l(\"values\");h&&h.length&&l(\"branchvalues\"),l(\"level\"),l(\"maxdepth\"),l(\"marker.line.width\")&&l(\"marker.line.color\",s.paper_bgcolor),l(\"marker.colors\"),l(\"leaf.opacity\");var f=l(\"text\");l(\"textinfo\",Array.isArray(f)?\"text+label\":\"label\"),l(\"hovertext\"),l(\"hovertemplate\");o(t,e,s,l,\"auto\",{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),a(e,s,l),e._length=null}else e.visible=!1}},{\"../../lib\":719,\"../../plots/domain\":792,\"../bar/defaults\":861,\"./attributes\":1214}],1219:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"sunburst\",basePlotModule:t(\"./base_plot\"),categories:[],animatable:!0,attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\").style,meta:{}}},{\"./attributes\":1214,\"./base_plot\":1215,\"./calc\":1216,\"./defaults\":1218,\"./layout_attributes\":1220,\"./layout_defaults\":1221,\"./plot\":1222,\"./style\":1223}],1220:[function(t,e,r){\"use strict\";e.exports={sunburstcolorway:{valType:\"colorlist\",editType:\"calc\"},extendsunburstcolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1221:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"sunburstcolorway\",e.colorway),r(\"extendsunburstcolors\")}},{\"../../lib\":719,\"./layout_attributes\":1220}],1222:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"d3-hierarchy\"),a=t(\"../../registry\"),o=t(\"../../components/fx\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../lib\"),u=t(\"../../lib/events\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"../../lib/setcursor\"),p=t(\"../../components/fx/helpers\").appendArrayPointValue,d=t(\"../pie/plot\").transformInsideText,g=t(\"../pie/helpers\").formatPieValue,v=t(\"./style\").styleOne,m=t(\"./constants\");function y(t,e,r,a){var o=t._fullLayout,u=a&&a.duration>0,f=n.select(r).selectAll(\"g.slice\"),p=e[0],m=p.trace,y=x(p.hierarchy,m.level),w=m.maxdepth>=0?m.maxdepth:1/0,M=o._size,S=m.domain,E=M.w*(S.x[1]-S.x[0]),C=M.h*(S.y[1]-S.y[0]),L=.5*Math.min(E,C),P=p.cx=M.l+M.w*(S.x[1]+S.x[0])/2,O=p.cy=M.t+M.h*(1-S.y[0])-C/2;if(!y)return f.remove();var z=null,I={};u&&f.each(function(t){I[k(t)]={rpx0:t.rpx0,rpx1:t.rpx1,x0:t.x0,x1:t.x1,transform:t.transform},!z&&_(t)&&(z=t)});var D=function(t){return i.partition().size([2*Math.PI,t.height+1])(t)}(y).descendants(),R=y.height+1,F=0,B=w;p.hasMultipleRoots&&b(y)&&(D=D.slice(1),R-=1,F=1,B+=1),D=D.filter(function(t){return t.y1<=B});var N=Math.min(R,w),j=function(t){return(t-F)/N*L},U=function(t,e){return[t*Math.cos(e),-t*Math.sin(e)]},V=function(t){return c.pathAnnulus(t.rpx0,t.rpx1,t.x0,t.x1,P,O)},q=function(t){return P+t.pxmid[0]*t.transform.rCenter+(t.transform.x||0)},H=function(t){return O+t.pxmid[1]*t.transform.rCenter+(t.transform.y||0)};(f=f.data(D,function(t){return k(t)})).enter().append(\"g\").classed(\"slice\",!0),u?f.exit().transition().each(function(){var t=n.select(this);t.select(\"path.surface\").transition().attrTween(\"d\",function(t){var e=function(t){var e,r=k(t),i=I[r],a=I[k(y)];if(a){var o=t.x1>a.x1?2*Math.PI:0;e=t.rpx1<a.rpx1?{rpx0:0,rpx1:0}:{x0:o,x1:o}}else{var s,l=k(t.parent);f.each(function(t){if(k(t)===l)return s=t});var c,u=s.children;u.forEach(function(t,e){if(k(t)===r)return c=e});var h=u.length,p=n.interpolate(s.x0,s.x1);e={rpx0:L,rpx1:L,x0:p(c/h),x1:p((c+1)/h)}}return n.interpolate(i,e)}(t);return function(t){return V(e(t))}}),t.select(\"g.slicetext\").attr(\"opacity\",0)}).remove():f.exit().remove(),f.order();var G=null;if(u&&z){var Y=k(z);f.each(function(t){null===G&&k(t)===Y&&(G=t.x1)})}var W=f;function X(t){var e=t.parent,r=I[k(e)],i={};if(r){var a=e.children,o=a.indexOf(t),s=a.length,l=n.interpolate(r.x0,r.x1);i.x0=l(o/s),i.x1=l(o/s)}else i.x0=i.x1=0;return i}u&&(W=W.transition().each(\"end\",function(){T(n.select(this),t,{isTransitioning:!1})})),W.each(function(r){var i=n.select(this),a=c.ensureSingle(i,\"path\",\"surface\",function(t){t.style(\"pointer-events\",\"all\")});r.rpx0=j(r.y0),r.rpx1=j(r.y1),r.xmid=(r.x0+r.x1)/2,r.pxmid=U(r.rpx1,r.xmid),r.midangle=-(r.xmid-Math.PI/2),r.halfangle=.5*Math.min(c.angleDelta(r.x0,r.x1)||Math.PI,Math.PI),r.ring=1-r.rpx0/r.rpx1,r.rInscribed=function(t){return 0===t.rpx0&&c.isFullCircle([t.x0,t.x1])?1:Math.max(0,Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2))}(r),u?a.transition().attrTween(\"d\",function(t){var e=function(t){var e,r=I[k(t)],i={x0:t.x0,x1:t.x1,rpx0:t.rpx0,rpx1:t.rpx1};if(r)e=r;else if(z)if(t.parent)if(G){var a=t.x1>G?2*Math.PI:0;e={x0:a,x1:a}}else e={rpx0:L,rpx1:L},c.extendFlat(e,X(t));else e={rpx0:0,rpx1:0};else e={x0:0,x1:0};return n.interpolate(e,i)}(t);return function(t){return V(e(t))}}):a.attr(\"d\",V),i.call(A,t,e).call(T,t,{isTransitioning:t._transitioning}),a.call(v,r,m);var f=c.ensureSingle(i,\"g\",\"slicetext\"),y=c.ensureSingle(f,\"text\",\"\",function(t){t.attr(\"data-notex\",1)});y.text(function(t,e,r){var n=e.textinfo;if(!n||\"none\"===n)return\"\";var i=t.data.data,a=r.separators,o=n.split(\"+\"),s=function(t){return-1!==o.indexOf(t)},l=[];s(\"label\")&&i.label&&l.push(i.label);i.hasOwnProperty(\"v\")&&s(\"value\")&&l.push(g(i.v,a));if(s(\"text\")){var u=c.castOption(e,i.i,\"text\");c.isValidTextValue(u)&&l.push(u)}return l.join(\"<br>\")}(r,m,o)).classed(\"slicetext\",!0).attr(\"text-anchor\",\"middle\").call(l.font,b(r)?function(t,e,r){var n=e.data.data.i,i=c.castOption(t,n,\"outsidetextfont.color\")||c.castOption(t,n,\"textfont.color\")||r.color,a=c.castOption(t,n,\"outsidetextfont.family\")||c.castOption(t,n,\"textfont.family\")||r.family,o=c.castOption(t,n,\"outsidetextfont.size\")||c.castOption(t,n,\"textfont.size\")||r.size;return{color:i,family:a,size:o}}(m,r,o.font):function(t,e,r){var n=e.data.data,i=n.i,a=c.castOption(t,i,\"insidetextfont.color\");!a&&t._input.textfont&&(a=c.castOption(t._input,i,\"textfont.color\"));var o=c.castOption(t,i,\"insidetextfont.family\")||c.castOption(t,i,\"textfont.family\")||r.family,l=c.castOption(t,i,\"insidetextfont.size\")||c.castOption(t,i,\"textfont.size\")||r.size;return{color:a||s.contrast(n.color),family:o,size:l}}(m,r,o.font)).call(h.convertToTspans,t);var x=l.bBox(y.node());r.transform=d(x,r,p),r.translateX=q(r),r.translateY=H(r);var _=function(t,e){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"+(t.transform.scale<1?\"scale(\"+t.transform.scale+\")\":\"\")+(t.transform.rotate?\"rotate(\"+t.transform.rotate+\")\":\"\")+\"translate(\"+-(e.left+e.right)/2+\",\"+-(e.top+e.bottom)/2+\")\"};u?y.transition().attrTween(\"transform\",function(t){var e=function(t){var e,r=I[k(t)],i=t.transform;if(r)e=r;else if(e={rpx1:t.rpx1,transform:{scale:0,rotate:i.rotate,rCenter:i.rCenter,x:i.x,y:i.y}},z)if(t.parent)if(G){var a=t.x1>G?2*Math.PI:0;e.x0=e.x1=a}else c.extendFlat(e,X(t));else e.x0=e.x1=0;else e.x0=e.x1=0;var o=n.interpolate(e.rpx1,t.rpx1),s=n.interpolate(e.x0,t.x0),l=n.interpolate(e.x1,t.x1),u=n.interpolate(e.transform.scale,i.scale),h=n.interpolate(e.transform.rotate,i.rotate),f=0===i.rCenter?3:0===e.transform.rCenter?1/3:1,p=n.interpolate(e.transform.rCenter,i.rCenter);return function(t){var e=o(t),r=s(t),n=l(t),a=function(t){return p(Math.pow(t,f))}(t),c={pxmid:U(e,(r+n)/2),transform:{rCenter:a,x:i.x,y:i.y}},d={rpx1:o(t),translateX:q(c),translateY:H(c),transform:{scale:u(t),rotate:h(t),rCenter:a}};return d}}(t);return function(t){return _(e(t),x)}}):y.attr(\"transform\",_(r,x))})}function x(t,e){var r;return e&&t.eachAfter(function(t){if(k(t)===e)return r=t.copy()}),r||t}function b(t){return\"\"===t.data.data.pid}function _(t){return!t.parent}function w(t){return!t.children}function k(t){return t.data.data.id}function T(t,e,r){var n=t.datum(),i=(r||{}).isTransitioning;f(t,i||w(n)||b(n)?null:\"pointer\")}function A(t,e,r){var i=r[0],s=i.trace;\"_hasHoverLabel\"in s||(s._hasHoverLabel=!1),\"_hasHoverEvent\"in s||(s._hasHoverEvent=!1),t.on(\"mouseover\",function(t){var r=e._fullLayout;if(!e._dragging&&!1!==r.hovermode){var a=e._fullData[s.index],l=t.data.data,u=l.i,h=function(t){return c.castOption(a,u,t)},f=h(\"hovertemplate\"),p=o.castHoverinfo(a,r,u),d=r.separators;if(f||p&&\"none\"!==p&&\"skip\"!==p){var v=t.rInscribed,m=i.cx+t.pxmid[0]*(1-v),y=i.cy+t.pxmid[1]*(1-v),x={},b=[],_=[],w=function(t){return-1!==b.indexOf(t)};if(p&&(b=\"all\"===p?a._module.attributes.hoverinfo.flags:p.split(\"+\")),x.label=l.label,w(\"label\")&&x.label&&_.push(x.label),l.hasOwnProperty(\"v\")&&(x.value=l.v,x.valueLabel=g(x.value,d),w(\"value\")&&_.push(x.valueLabel)),x.text=h(\"hovertext\")||h(\"text\"),w(\"text\")){var k=x.text;c.isValidTextValue(k)&&_.push(k)}o.loneHover({trace:a,x0:m-v*t.rpx1,x1:m+v*t.rpx1,y:y,idealAlign:t.pxmid[0]<0?\"left\":\"right\",text:_.join(\"<br>\"),name:f||w(\"name\")?a.name:void 0,color:h(\"hoverlabel.bgcolor\")||l.color,borderColor:h(\"hoverlabel.bordercolor\"),fontFamily:h(\"hoverlabel.font.family\"),fontSize:h(\"hoverlabel.font.size\"),fontColor:h(\"hoverlabel.font.color\"),nameLength:h(\"hoverlabel.namelength\"),textAlign:h(\"hoverlabel.align\"),hovertemplate:f,hovertemplateLabels:x,eventData:[M(t,a)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e}),s._hasHoverLabel=!0}s._hasHoverEvent=!0,e.emit(\"plotly_hover\",{points:[M(t,a)],event:n.event})}}),t.on(\"mouseout\",function(t){var r=e._fullLayout,i=e._fullData[s.index],a=n.select(this).datum();s._hasHoverEvent&&(t.originalEvent=n.event,e.emit(\"plotly_unhover\",{points:[M(a,i)],event:n.event}),s._hasHoverEvent=!1),s._hasHoverLabel&&(o.loneUnhover(r._hoverlayer.node()),s._hasHoverLabel=!1)}),t.on(\"click\",function(t){var r=e._fullLayout,l=e._fullData[s.index];if(!1===u.triggerHandler(e,\"plotly_sunburstclick\",{points:[M(t,l)],event:n.event})||w(t)||b(t))r.hovermode&&(e._hoverdata=[M(t,l)],o.click(e,n.event));else if(!e._dragging&&!e._transitioning){a.call(\"_storeDirectGUIEdit\",l,r._tracePreGUI[l.uid],{level:l.level});var c=i.hierarchy,h=k(t),f=_(t)?function(t,e){var r;return t.eachAfter(function(t){for(var n=t.children||[],i=0;i<n.length;i++)if(k(n[i])===e)return r=t.copy()}),r||t}(c,h):x(c,h),p={data:[{level:k(f)}],traces:[s.index]},d={frame:{redraw:!1,duration:m.CLICK_TRANSITION_TIME},transition:{duration:m.CLICK_TRANSITION_TIME,easing:m.CLICK_TRANSITION_EASING},mode:\"immediate\",fromcurrent:!0};o.loneUnhover(r._hoverlayer.node()),a.call(\"animate\",e,p,d)}})}function M(t,e){var r=t.data.data,n={curveNumber:e.index,pointNumber:r.i,data:e._input,fullData:e};return p(n,e,r.i),n}e.exports=function(t,e,r,i){var a,o,s=t._fullLayout._sunburstlayer,l=!r,c=r&&r.duration>0;((a=s.selectAll(\"g.trace.sunburst\").data(e,function(t){return t[0].trace.uid})).enter().append(\"g\").classed(\"trace\",!0).classed(\"sunburst\",!0).attr(\"stroke-linejoin\",\"round\"),a.order(),c)?(i&&(o=i()),n.transition().duration(r.duration).ease(r.easing).each(\"end\",function(){o&&o()}).each(\"interrupt\",function(){o&&o()}).each(function(){s.selectAll(\"g.trace\").each(function(e){y(t,e,this,r)})})):a.each(function(e){y(t,e,this,r)});l&&a.exit().remove()}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../components/fx/helpers\":628,\"../../lib\":719,\"../../lib/events\":709,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../registry\":847,\"../pie/helpers\":1091,\"../pie/plot\":1095,\"./constants\":1217,\"./style\":1223,d3:163,\"d3-hierarchy\":157}],1223:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../lib\");function o(t,e,r){var n=e.data.data,o=!e.children,s=n.i,l=a.castOption(r,s,\"marker.line.color\")||i.defaultLine,c=a.castOption(r,s,\"marker.line.width\")||0;t.style(\"stroke-width\",c).call(i.fill,n.color).call(i.stroke,l).style(\"opacity\",o?r.leaf.opacity:null)}e.exports={style:function(t){t._fullLayout._sunburstlayer.selectAll(\".trace\").each(function(t){var e=n.select(this),r=t[0].trace;e.style(\"opacity\",r.opacity),e.selectAll(\"path.surface\").each(function(t){n.select(this).call(o,t,r)})})},styleOne:o}},{\"../../components/color\":593,\"../../lib\":719,d3:163}],1224:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;function c(t){return{show:{valType:\"boolean\",dflt:!1},start:{valType:\"number\",dflt:null,editType:\"plot\"},end:{valType:\"number\",dflt:null,editType:\"plot\"},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\"},project:{x:{valType:\"boolean\",dflt:!1},y:{valType:\"boolean\",dflt:!1},z:{valType:\"boolean\",dflt:!1}},color:{valType:\"color\",dflt:n.defaultLine},usecolormap:{valType:\"boolean\",dflt:!1},width:{valType:\"number\",min:1,max:16,dflt:2},highlight:{valType:\"boolean\",dflt:!0},highlightcolor:{valType:\"color\",dflt:n.defaultLine},highlightwidth:{valType:\"number\",min:1,max:16,dflt:2}}}var u=e.exports=l(s({z:{valType:\"data_array\"},x:{valType:\"data_array\"},y:{valType:\"data_array\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:a(),connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},surfacecolor:{valType:\"data_array\"}},i(\"\",{colorAttr:\"z or surfacecolor\",showScaleDflt:!0,autoColorDflt:!1,editTypeOverride:\"calc\"}),{contours:{x:c(),y:c(),z:c()},hidesurface:{valType:\"boolean\",dflt:!1},lightposition:{x:{valType:\"number\",min:-1e5,max:1e5,dflt:10},y:{valType:\"number\",min:-1e5,max:1e5,dflt:1e4},z:{valType:\"number\",min:-1e5,max:1e5,dflt:0}},lighting:{ambient:{valType:\"number\",min:0,max:1,dflt:.8},diffuse:{valType:\"number\",min:0,max:1,dflt:.8},specular:{valType:\"number\",min:0,max:2,dflt:.05},roughness:{valType:\"number\",min:0,max:1,dflt:.5},fresnel:{valType:\"number\",min:0,max:5,dflt:.2}},opacity:{valType:\"number\",min:0,max:1,dflt:1},_deprecated:{zauto:s({},i.zauto,{}),zmin:s({},i.zmin,{}),zmax:s({},i.zmax,{})},hoverinfo:s({},o.hoverinfo)}),\"calc\",\"nested\");u.x.editType=u.y.editType=u.z.editType=\"calc+clearAxisTypes\",u.transforms=void 0},{\"../../components/color\":593,\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764}],1225:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.surfacecolor?n(t,e,{vals:e.surfacecolor,containerStr:\"\",cLetter:\"c\"}):n(t,e,{vals:e.z,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],1226:[function(t,e,r){\"use strict\";var n=t(\"gl-surface3d\"),i=t(\"ndarray\"),a=t(\"ndarray-homography\"),o=t(\"ndarray-fill\"),s=t(\"../../lib\").isArrayOrTypedArray,l=t(\"../../lib/gl_format_color\").parseColorScale,c=t(\"../../lib/str2rgbarray\"),u=t(\"../../components/colorscale\").extractOpts,h=t(\"../heatmap/interp2d\"),f=t(\"../heatmap/find_empties\");function p(t,e,r){this.scene=t,this.uid=r,this.surface=e,this.data=null,this.showContour=[!1,!1,!1],this.contourStart=[null,null,null],this.contourEnd=[null,null,null],this.contourSize=[0,0,0],this.minValues=[1/0,1/0,1/0],this.maxValues=[-1/0,-1/0,-1/0],this.dataScaleX=1,this.dataScaleY=1,this.refineData=!0,this.objectOffset=[0,0,0]}var d=p.prototype;d.getXat=function(t,e,r,n){var i=s(this.data.x)?s(this.data.x[0])?this.data.x[e][t]:this.data.x[t]:t;return void 0===r?i:n.d2l(i,0,r)},d.getYat=function(t,e,r,n){var i=s(this.data.y)?s(this.data.y[0])?this.data.y[e][t]:this.data.y[e]:e;return void 0===r?i:n.d2l(i,0,r)},d.getZat=function(t,e,r,n){var i=this.data.z[e][t];return null===i&&this.data.connectgaps&&this.data._interpolatedZ&&(i=this.data._interpolatedZ[e][t]),void 0===r?i:n.d2l(i,0,r)},d.handlePick=function(t){if(t.object===this.surface){var e=(t.data.index[0]-1)/this.dataScaleX-1,r=(t.data.index[1]-1)/this.dataScaleY-1,n=Math.max(Math.min(Math.round(e),this.data.z[0].length-1),0),i=Math.max(Math.min(Math.round(r),this.data._ylength-1),0);t.index=[n,i],t.traceCoordinate=[this.getXat(n,i),this.getYat(n,i),this.getZat(n,i)],t.dataCoordinate=[this.getXat(n,i,this.data.xcalendar,this.scene.fullSceneLayout.xaxis),this.getYat(n,i,this.data.ycalendar,this.scene.fullSceneLayout.yaxis),this.getZat(n,i,this.data.zcalendar,this.scene.fullSceneLayout.zaxis)];for(var a=0;a<3;a++){var o=t.dataCoordinate[a];null!=o&&(t.dataCoordinate[a]*=this.scene.dataScale[a])}var s=this.data.hovertext||this.data.text;return Array.isArray(s)&&s[i]&&void 0!==s[i][n]?t.textLabel=s[i][n]:t.textLabel=s||\"\",t.data.dataCoordinate=t.dataCoordinate.slice(),this.surface.highlight(t.data),this.scene.glplot.spikes.position=t.dataCoordinate,!0}};var g=[2,3,5,7,11,13,17,19,23,29,31,37,41,43,47,53,59,61,67,71,73,79,83,89,97,101,103,107,109,113,127,131,137,139,149,151,157,163,167,173,179,181,191,193,197,199,211,223,227,229,233,239,241,251,257,263,269,271,277,281,283,293,307,311,313,317,331,337,347,349,353,359,367,373,379,383,389,397,401,409,419,421,431,433,439,443,449,457,461,463,467,479,487,491,499,503,509,521,523,541,547,557,563,569,571,577,587,593,599,601,607,613,617,619,631,641,643,647,653,659,661,673,677,683,691,701,709,719,727,733,739,743,751,757,761,769,773,787,797,809,811,821,823,827,829,839,853,857,859,863,877,881,883,887,907,911,919,929,937,941,947,953,967,971,977,983,991,997,1009,1013,1019,1021,1031,1033,1039,1049,1051,1061,1063,1069,1087,1091,1093,1097,1103,1109,1117,1123,1129,1151,1153,1163,1171,1181,1187,1193,1201,1213,1217,1223,1229,1231,1237,1249,1259,1277,1279,1283,1289,1291,1297,1301,1303,1307,1319,1321,1327,1361,1367,1373,1381,1399,1409,1423,1427,1429,1433,1439,1447,1451,1453,1459,1471,1481,1483,1487,1489,1493,1499,1511,1523,1531,1543,1549,1553,1559,1567,1571,1579,1583,1597,1601,1607,1609,1613,1619,1621,1627,1637,1657,1663,1667,1669,1693,1697,1699,1709,1721,1723,1733,1741,1747,1753,1759,1777,1783,1787,1789,1801,1811,1823,1831,1847,1861,1867,1871,1873,1877,1879,1889,1901,1907,1913,1931,1933,1949,1951,1973,1979,1987,1993,1997,1999,2003,2011,2017,2027,2029,2039,2053,2063,2069,2081,2083,2087,2089,2099,2111,2113,2129,2131,2137,2141,2143,2153,2161,2179,2203,2207,2213,2221,2237,2239,2243,2251,2267,2269,2273,2281,2287,2293,2297,2309,2311,2333,2339,2341,2347,2351,2357,2371,2377,2381,2383,2389,2393,2399,2411,2417,2423,2437,2441,2447,2459,2467,2473,2477,2503,2521,2531,2539,2543,2549,2551,2557,2579,2591,2593,2609,2617,2621,2633,2647,2657,2659,2663,2671,2677,2683,2687,2689,2693,2699,2707,2711,2713,2719,2729,2731,2741,2749,2753,2767,2777,2789,2791,2797,2801,2803,2819,2833,2837,2843,2851,2857,2861,2879,2887,2897,2903,2909,2917,2927,2939,2953,2957,2963,2969,2971,2999];function v(t,e){if(t<e)return 0;for(var r=0;0===Math.floor(t%e);)t/=e,r++;return r}function m(t){for(var e=[],r=0;r<g.length;r++){var n=g[r];e.push(v(t,n))}return e}function y(t){for(var e=m(t),r=t,n=0;n<g.length;n++)if(e[n]>0){r=g[n];break}return r}function x(t,e){if(!(t<1||e<1)){for(var r=m(t),n=m(e),i=1,a=0;a<g.length;a++)i*=Math.pow(g[a],Math.max(r[a],n[a]));return i}}d.calcXnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getXat(e-1,0),i=this.getXat(e,0);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r},d.calcYnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getYat(0,e-1),i=this.getYat(0,e);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r};var b=[1,2,4,6,12,24,36,48,60,120,180,240,360,720,840,1260],_=b[9],w=b[13];function k(t,e){for(var r=!1,n=0;n<t.length;n++)if(e===t[n]){r=!0;break}!1===r&&t.push(e)}d.estimateScale=function(t,e){for(var r=1+function(t){if(0!==t.length){for(var e=1,r=0;r<t.length;r++)e=x(e,t[r]);return e}}(0===e?this.calcXnums(t):this.calcYnums(t));r<_;)r*=2;for(;r>w;)r--,r/=y(r),++r<_&&(r=w);var n=Math.round(r/t);return n>1?n:1},d.refineCoords=function(t){for(var e=this.dataScaleX,r=this.dataScaleY,n=t[0].shape[0],o=t[0].shape[1],s=0|Math.floor(t[0].shape[0]*e+1),l=0|Math.floor(t[0].shape[1]*r+1),c=1+n+1,u=1+o+1,h=i(new Float32Array(c*u),[c,u]),f=0;f<t.length;++f){this.surface.padField(h,t[f]);var p=i(new Float32Array(s*l),[s,l]);a(p,h,[e,0,0,0,r,0,0,0,1]),t[f]=p}},d.setContourLevels=function(){var t,e,r,n=[[],[],[]],i=[!1,!1,!1],a=!1;for(t=0;t<3;++t)if(this.showContour[t]&&(a=!0,this.contourSize[t]>0&&null!==this.contourStart[t]&&null!==this.contourEnd[t]&&this.contourEnd[t]>this.contourStart[t]))for(i[t]=!0,e=this.contourStart[t];e<this.contourEnd[t];e+=this.contourSize[t])r=e*this.scene.dataScale[t],k(n[t],r);if(a){var o=[[],[],[]];for(t=0;t<3;++t)this.showContour[t]&&(o[t]=i[t]?n[t]:this.scene.contourLevels[t]);this.surface.update({levels:o})}},d.update=function(t){var e,r,n,a,s=this.scene,p=s.fullSceneLayout,d=this.surface,g=t.opacity,v=l(t,g),m=s.dataScale,y=t.z[0].length,x=t._ylength,b=s.contourLevels;this.data=t;var _=[];for(e=0;e<3;e++)for(_[e]=[],r=0;r<y;r++)_[e][r]=[];for(r=0;r<y;r++)for(n=0;n<x;n++)_[0][r][n]=this.getXat(r,n,t.xcalendar,p.xaxis),_[1][r][n]=this.getYat(r,n,t.ycalendar,p.yaxis),_[2][r][n]=this.getZat(r,n,t.zcalendar,p.zaxis);if(t.connectgaps)for(t._emptypoints=f(_[2]),h(_[2],t._emptypoints),t._interpolatedZ=[],r=0;r<y;r++)for(t._interpolatedZ[r]=[],n=0;n<x;n++)t._interpolatedZ[r][n]=_[2][r][n];for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null==(a=_[e][r][n])?_[e][r][n]=NaN:a=_[e][r][n]*=m[e];for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null!=(a=_[e][r][n])&&(this.minValues[e]>a&&(this.minValues[e]=a),this.maxValues[e]<a&&(this.maxValues[e]=a));for(e=0;e<3;e++)this.objectOffset[e]=.5*(this.minValues[e]+this.maxValues[e]);for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null!=(a=_[e][r][n])&&(_[e][r][n]-=this.objectOffset[e]);var k=[i(new Float32Array(y*x),[y,x]),i(new Float32Array(y*x),[y,x]),i(new Float32Array(y*x),[y,x])];o(k[0],function(t,e){return _[0][t][e]}),o(k[1],function(t,e){return _[1][t][e]}),o(k[2],function(t,e){return _[2][t][e]}),_=[];var T={colormap:v,levels:[[],[],[]],showContour:[!0,!0,!0],showSurface:!t.hidesurface,contourProject:[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],contourWidth:[1,1,1],contourColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],contourTint:[1,1,1],dynamicColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],dynamicWidth:[1,1,1],dynamicTint:[1,1,1],opacity:t.opacity},A=u(t);if(T.intensityBounds=[A.min,A.max],t.surfacecolor){var M=i(new Float32Array(y*x),[y,x]);o(M,function(e,r){return t.surfacecolor[r][e]}),k.push(M)}else T.intensityBounds[0]*=m[2],T.intensityBounds[1]*=m[2];(w<k[0].shape[0]||w<k[0].shape[1])&&(this.refineData=!1),!0===this.refineData&&(this.dataScaleX=this.estimateScale(k[0].shape[0],0),this.dataScaleY=this.estimateScale(k[0].shape[1],1),1===this.dataScaleX&&1===this.dataScaleY||this.refineCoords(k)),t.surfacecolor&&(T.intensity=k.pop());var S=[!0,!0,!0],E=[\"x\",\"y\",\"z\"];for(e=0;e<3;++e){var C=t.contours[E[e]];S[e]=C.highlight,T.showContour[e]=C.show||C.highlight,T.showContour[e]&&(T.contourProject[e]=[C.project.x,C.project.y,C.project.z],C.show?(this.showContour[e]=!0,T.levels[e]=b[e],d.highlightColor[e]=T.contourColor[e]=c(C.color),C.usecolormap?d.highlightTint[e]=T.contourTint[e]=0:d.highlightTint[e]=T.contourTint[e]=1,T.contourWidth[e]=C.width,this.contourStart[e]=C.start,this.contourEnd[e]=C.end,this.contourSize[e]=C.size):(this.showContour[e]=!1,this.contourStart[e]=null,this.contourEnd[e]=null,this.contourSize[e]=0),C.highlight&&(T.dynamicColor[e]=c(C.highlightcolor),T.dynamicWidth[e]=C.highlightwidth))}(function(t){var e=t[0].rgb,r=t[t.length-1].rgb;return e[0]===r[0]&&e[1]===r[1]&&e[2]===r[2]&&e[3]===r[3]})(v)&&(T.vertexColor=!0),T.objectOffset=this.objectOffset,T.coords=k,d.update(T),d.visible=t.visible,d.enableDynamic=S,d.enableHighlight=S,d.snapToData=!0,\"lighting\"in t&&(d.ambientLight=t.lighting.ambient,d.diffuseLight=t.lighting.diffuse,d.specularLight=t.lighting.specular,d.roughness=t.lighting.roughness,d.fresnel=t.lighting.fresnel),\"lightposition\"in t&&(d.lightPosition=[t.lightposition.x,t.lightposition.y,t.lightposition.z]),g&&g<1&&(d.supportsTransparency=!0)},d.dispose=function(){this.scene.glplot.remove(this.surface),this.surface.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new p(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../heatmap/find_empties\":1007,\"../heatmap/interp2d\":1010,\"gl-surface3d\":316,ndarray:450,\"ndarray-fill\":440,\"ndarray-homography\":442}],1227:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");function s(t,e,r){e in t&&!(r in t)&&(t[r]=t[e])}e.exports=function(t,e,r,l){var c,u;function h(r,n){return i.coerce(t,e,o,r,n)}var f=h(\"x\"),p=h(\"y\"),d=h(\"z\");if(!d||!d.length||f&&f.length<1||p&&p.length<1)e.visible=!1;else{e._xlength=Array.isArray(f)&&i.isArrayOrTypedArray(f[0])?d.length:d[0].length,e._ylength=d.length,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],l),h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"hidesurface\",\"connectgaps\",\"opacity\"].forEach(function(t){h(t)});var g=h(\"surfacecolor\"),v=[\"x\",\"y\",\"z\"];for(c=0;c<3;++c){var m=\"contours.\"+v[c],y=h(m+\".show\"),x=h(m+\".highlight\");if(y||x)for(u=0;u<3;++u)h(m+\".project.\"+v[u]);y&&(h(m+\".color\"),h(m+\".width\"),h(m+\".usecolormap\")),x&&(h(m+\".highlightcolor\"),h(m+\".highlightwidth\")),h(m+\".start\"),h(m+\".end\"),h(m+\".size\")}g||(s(t,\"zmin\",\"cmin\"),s(t,\"zmax\",\"cmax\"),s(t,\"zauto\",\"cauto\")),a(t,e,l,h,{prefix:\"\",cLetter:\"c\"}),e._length=null}}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../../registry\":847,\"./attributes\":1224}],1228:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"surface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"2dMap\",\"noOpacity\"],meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1224,\"./calc\":1225,\"./convert\":1226,\"./defaults\":1227}],1229:[function(t,e,r){\"use strict\";var n=t(\"../../components/annotations/attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../plots/domain\").attributes;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=a({domain:s({name:\"table\",trace:!0}),columnwidth:{valType:\"number\",arrayOk:!0,dflt:null},columnorder:{valType:\"data_array\"},header:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:28},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))},cells:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:20},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))}},\"calc\",\"from-root\")).transforms=void 0},{\"../../components/annotations/attributes\":576,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1230:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"table\",r.plot=function(t){var e=n(t.calcdata,\"table\")[0];e.length&&i(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"table\"),a=e._has&&e._has(\"table\");i&&!a&&n._paperdiv.selectAll(\".table\").remove()}},{\"../../plots/get_data\":802,\"./plot\":1237}],1231:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap;e.exports=function(){return n({})}},{\"../../lib/gup\":717}],1232:[function(t,e,r){\"use strict\";e.exports={cellPad:8,columnExtentOffset:10,columnTitleOffset:28,emptyHeaderHeight:16,latexCheck:/^\\$.*\\$$/,goldenRatio:1.618,lineBreaker:\"<br>\",maxDimensionCount:60,overdrag:45,releaseTransitionDuration:120,releaseTransitionEase:\"cubic-out\",scrollbarCaptureWidth:18,scrollbarHideDelay:1e3,scrollbarHideDuration:1e3,scrollbarOffset:5,scrollbarWidth:8,transitionDuration:100,transitionEase:\"cubic-out\",uplift:5,wrapSpacer:\" \",wrapSplitCharacter:\" \",cn:{table:\"table\",tableControlView:\"table-control-view\",scrollBackground:\"scroll-background\",yColumn:\"y-column\",columnBlock:\"column-block\",scrollAreaClip:\"scroll-area-clip\",scrollAreaClipRect:\"scroll-area-clip-rect\",columnBoundary:\"column-boundary\",columnBoundaryClippath:\"column-boundary-clippath\",columnBoundaryRect:\"column-boundary-rect\",columnCells:\"column-cells\",columnCell:\"column-cell\",cellRect:\"cell-rect\",cellText:\"cell-text\",cellTextHolder:\"cell-text-holder\",scrollbarKit:\"scrollbar-kit\",scrollbar:\"scrollbar\",scrollbarSlider:\"scrollbar-slider\",scrollbarGlyph:\"scrollbar-glyph\",scrollbarCaptureZone:\"scrollbar-capture-zone\"}}},{}],1233:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"fast-isnumeric\");function o(t){if(Array.isArray(t)){for(var e=0,r=0;r<t.length;r++)e=Math.max(e,o(t[r]));return e}return t}function s(t,e){return t+e}function l(t){var e,r=t.slice(),n=1/0,i=0;for(e=0;e<r.length;e++)Array.isArray(r[e])||(r[e]=[r[e]]),n=Math.min(n,r[e].length),i=Math.max(i,r[e].length);if(n!==i)for(e=0;e<r.length;e++){var a=i-r[e].length;a&&(r[e]=r[e].concat(c(a)))}return r}function c(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=\"\";return e}function u(t){return t.calcdata.columns.reduce(function(e,r){return r.xIndex<t.xIndex?e+r.columnWidth:e},0)}function h(t,e){return Object.keys(t).map(function(r){return i({},t[r],{auxiliaryBlocks:e})})}function f(t,e){for(var r,n={},i=0,a=0,o={firstRowIndex:null,lastRowIndex:null,rows:[]},s=0,l=0,c=0;c<t.length;c++)r=t[c],o.rows.push({rowIndex:c,rowHeight:r}),((a+=r)>=e||c===t.length-1)&&(n[i]=o,o.key=l++,o.firstRowIndex=s,o.lastRowIndex=c,o={firstRowIndex:null,lastRowIndex:null,rows:[]},i+=a,s=c+1,a=0);return n}e.exports=function(t,e){var r=l(e.cells.values),p=function(t){return t.slice(e.header.values.length,t.length)},d=l(e.header.values);d.length&&!d[0].length&&(d[0]=[\"\"],d=l(d));var g=d.concat(p(r).map(function(){return c((d[0]||[\"\"]).length)})),v=e.domain,m=Math.floor(t._fullLayout._size.w*(v.x[1]-v.x[0])),y=Math.floor(t._fullLayout._size.h*(v.y[1]-v.y[0])),x=e.header.values.length?g[0].map(function(){return e.header.height}):[n.emptyHeaderHeight],b=r.length?r[0].map(function(){return e.cells.height}):[],_=x.reduce(s,0),w=f(b,y-_+n.uplift),k=h(f(x,_),[]),T=h(w,k),A={},M=e._fullInput.columnorder.concat(p(r.map(function(t,e){return e}))),S=g.map(function(t,r){var n=Array.isArray(e.columnwidth)?e.columnwidth[Math.min(r,e.columnwidth.length-1)]:e.columnwidth;return a(n)?Number(n):1}),E=S.reduce(s,0);S=S.map(function(t){return t/E*m});var C=Math.max(o(e.header.line.width),o(e.cells.line.width)),L={key:e.uid+t._context.staticPlot,translateX:v.x[0]*t._fullLayout._size.w,translateY:t._fullLayout._size.h*(1-v.y[1]),size:t._fullLayout._size,width:m,maxLineWidth:C,height:y,columnOrder:M,groupHeight:y,rowBlocks:T,headerRowBlocks:k,scrollY:0,cells:i({},e.cells,{values:r}),headerCells:i({},e.header,{values:g}),gdColumns:g.map(function(t){return t[0]}),gdColumnsOriginalOrder:g.map(function(t){return t[0]}),prevPages:[0,0],scrollbarState:{scrollbarScrollInProgress:!1},columns:g.map(function(t,e){var r=A[t];return A[t]=(r||0)+1,{key:t+\"__\"+A[t],label:t,specIndex:e,xIndex:M[e],xScale:u,x:void 0,calcdata:void 0,columnWidth:S[e]}})};return L.columns.forEach(function(t){t.calcdata=L,t.x=u(t)}),L}},{\"../../lib/extend\":710,\"./constants\":1232,\"fast-isnumeric\":225}],1234:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat;r.splitToPanels=function(t){var e=[0,0],r=n({},t,{key:\"header\",type:\"header\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!0,values:t.calcdata.headerCells.values[t.specIndex],rowBlocks:t.calcdata.headerRowBlocks,calcdata:n({},t.calcdata,{cells:t.calcdata.headerCells})});return[n({},t,{key:\"cells1\",type:\"cells\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),n({},t,{key:\"cells2\",type:\"cells\",page:1,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),r]},r.splitToCells=function(t){var e=function(t){var e=t.rowBlocks[t.page],r=e?e.rows[0].rowIndex:0,n=e?r+e.rows.length:0;return[r,n]}(t);return(t.values||[]).slice(e[0],e[1]).map(function(r,n){return{keyWithinBlock:n+(\"string\"==typeof r&&r.match(/[<$&> ]/)?\"_keybuster_\"+Math.random():\"\"),key:e[0]+n,column:t,calcdata:t.calcdata,page:t.page,rowBlocks:t.rowBlocks,value:r}})}},{\"../../lib/extend\":710}],1235:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults;e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}a(e,o,s),s(\"columnwidth\"),s(\"header.values\"),s(\"header.format\"),s(\"header.align\"),s(\"header.prefix\"),s(\"header.suffix\"),s(\"header.height\"),s(\"header.line.width\"),s(\"header.line.color\"),s(\"header.fill.color\"),n.coerceFont(s,\"header.font\",n.extendFlat({},o.font)),function(t,e){for(var r=t.columnorder||[],n=t.header.values.length,i=r.slice(0,n),a=i.slice().sort(function(t,e){return t-e}),o=i.map(function(t){return a.indexOf(t)}),s=o.length;s<n;s++)o.push(s);e(\"columnorder\",o)}(e,s),s(\"cells.values\"),s(\"cells.format\"),s(\"cells.align\"),s(\"cells.prefix\"),s(\"cells.suffix\"),s(\"cells.height\"),s(\"cells.line.width\"),s(\"cells.line.color\"),s(\"cells.fill.color\"),n.coerceFont(s,\"cells.font\",n.extendFlat({},o.font)),e._length=null}},{\"../../lib\":719,\"../../plots/domain\":792,\"./attributes\":1229}],1236:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"table\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1229,\"./base_plot\":1230,\"./calc\":1231,\"./defaults\":1235,\"./plot\":1237}],1237:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\"),o=t(\"../../components/drawing\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../lib\").raiseToTop,c=t(\"../../lib\").cancelTransition,u=t(\"./data_preparation_helper\"),h=t(\"./data_split_helpers\"),f=t(\"../../components/color\");function p(t){return Math.ceil(t.calcdata.maxLineWidth/2)}function d(t,e){return\"clip\"+t._fullLayout._uid+\"_scrollAreaBottomClip_\"+e.key}function g(t,e){return\"clip\"+t._fullLayout._uid+\"_columnBoundaryClippath_\"+e.calcdata.key+\"_\"+e.specIndex}function v(t){return[].concat.apply([],t.map(function(t){return t})).map(function(t){return t.__data__})}function m(t,e,r){var o=t.selectAll(\".\"+n.cn.scrollbarKit).data(a.repeat,a.keyFun);o.enter().append(\"g\").classed(n.cn.scrollbarKit,!0).style(\"shape-rendering\",\"geometricPrecision\"),o.each(function(t){var e=t.scrollbarState;e.totalHeight=function(t){var e=t.rowBlocks;return z(e,e.length-1)+(e.length?I(e[e.length-1],1/0):1)}(t),e.scrollableAreaHeight=t.groupHeight-A(t),e.currentlyVisibleHeight=Math.min(e.totalHeight,e.scrollableAreaHeight),e.ratio=e.currentlyVisibleHeight/e.totalHeight,e.barLength=Math.max(e.ratio*e.currentlyVisibleHeight,n.goldenRatio*n.scrollbarWidth),e.barWiggleRoom=e.currentlyVisibleHeight-e.barLength,e.wiggleRoom=Math.max(0,e.totalHeight-e.scrollableAreaHeight),e.topY=0===e.barWiggleRoom?0:t.scrollY/e.wiggleRoom*e.barWiggleRoom,e.bottomY=e.topY+e.barLength,e.dragMultiplier=e.wiggleRoom/e.barWiggleRoom}).attr(\"transform\",function(t){return\"translate(\"+(t.width+n.scrollbarWidth/2+n.scrollbarOffset)+\" \"+A(t)+\")\"});var s=o.selectAll(\".\"+n.cn.scrollbar).data(a.repeat,a.keyFun);s.enter().append(\"g\").classed(n.cn.scrollbar,!0);var l=s.selectAll(\".\"+n.cn.scrollbarSlider).data(a.repeat,a.keyFun);l.enter().append(\"g\").classed(n.cn.scrollbarSlider,!0),l.attr(\"transform\",function(t){return\"translate(0 \"+(t.scrollbarState.topY||0)+\")\"});var c=l.selectAll(\".\"+n.cn.scrollbarGlyph).data(a.repeat,a.keyFun);c.enter().append(\"line\").classed(n.cn.scrollbarGlyph,!0).attr(\"stroke\",\"black\").attr(\"stroke-width\",n.scrollbarWidth).attr(\"stroke-linecap\",\"round\").attr(\"y1\",n.scrollbarWidth/2),c.attr(\"y2\",function(t){return t.scrollbarState.barLength-n.scrollbarWidth/2}).attr(\"stroke-opacity\",function(t){return t.columnDragInProgress||!t.scrollbarState.barWiggleRoom||r?0:.4}),c.transition().delay(0).duration(0),c.transition().delay(n.scrollbarHideDelay).duration(n.scrollbarHideDuration).attr(\"stroke-opacity\",0);var u=s.selectAll(\".\"+n.cn.scrollbarCaptureZone).data(a.repeat,a.keyFun);u.enter().append(\"line\").classed(n.cn.scrollbarCaptureZone,!0).attr(\"stroke\",\"white\").attr(\"stroke-opacity\",.01).attr(\"stroke-width\",n.scrollbarCaptureWidth).attr(\"stroke-linecap\",\"butt\").attr(\"y1\",0).on(\"mousedown\",function(r){var n=i.event.y,a=this.getBoundingClientRect(),o=r.scrollbarState,s=n-a.top,l=i.scale.linear().domain([0,o.scrollableAreaHeight]).range([0,o.totalHeight]).clamp(!0);o.topY<=s&&s<=o.bottomY||S(e,t,null,l(s-o.barLength/2))(r)}).call(i.behavior.drag().origin(function(t){return i.event.stopPropagation(),t.scrollbarState.scrollbarScrollInProgress=!0,t}).on(\"drag\",S(e,t)).on(\"dragend\",function(){})),u.attr(\"y2\",function(t){return t.scrollbarState.scrollableAreaHeight}),e._context.staticPlot&&(c.remove(),u.remove())}function y(t,e,r,s){var l=function(t){var e=t.selectAll(\".\"+n.cn.columnCell).data(h.splitToCells,function(t){return t.keyWithinBlock});return e.enter().append(\"g\").classed(n.cn.columnCell,!0),e.exit().remove(),e}(function(t){var e=t.selectAll(\".\"+n.cn.columnCells).data(a.repeat,a.keyFun);return e.enter().append(\"g\").classed(n.cn.columnCells,!0),e.exit().remove(),e}(r));!function(t){t.each(function(t,e){var r=t.calcdata.cells.font,n=t.column.specIndex,i={size:_(r.size,n,e),color:_(r.color,n,e),family:_(r.family,n,e)};t.rowNumber=t.key,t.align=_(t.calcdata.cells.align,n,e),t.cellBorderWidth=_(t.calcdata.cells.line.width,n,e),t.font=i})}(l),function(t){t.attr(\"width\",function(t){return t.column.columnWidth}).attr(\"stroke-width\",function(t){return t.cellBorderWidth}).each(function(t){var e=i.select(this);f.stroke(e,_(t.calcdata.cells.line.color,t.column.specIndex,t.rowNumber)),f.fill(e,_(t.calcdata.cells.fill.color,t.column.specIndex,t.rowNumber))})}(function(t){var e=t.selectAll(\".\"+n.cn.cellRect).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"rect\").classed(n.cn.cellRect,!0),e}(l));var c=function(t){var e=t.selectAll(\".\"+n.cn.cellText).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"text\").classed(n.cn.cellText,!0).style(\"cursor\",function(){return\"auto\"}).on(\"mousedown\",function(){i.event.stopPropagation()}),e}(function(t){var e=t.selectAll(\".\"+n.cn.cellTextHolder).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"g\").classed(n.cn.cellTextHolder,!0).style(\"shape-rendering\",\"geometricPrecision\"),e}(l));!function(t){t.each(function(t){o.font(i.select(this),t.font)})}(c),x(c,e,s,t),O(l)}function x(t,e,r,a){t.text(function(t){var e=t.column.specIndex,r=t.rowNumber,a=t.value,o=\"string\"==typeof a,s=o&&a.match(/<br>/i),l=!o||s;t.mayHaveMarkup=o&&a.match(/[<&>]/);var c,u=\"string\"==typeof(c=a)&&c.match(n.latexCheck);t.latex=u;var h,f,p=u?\"\":_(t.calcdata.cells.prefix,e,r)||\"\",d=u?\"\":_(t.calcdata.cells.suffix,e,r)||\"\",g=u?null:_(t.calcdata.cells.format,e,r)||null,v=p+(g?i.format(g)(t.value):t.value)+d;if(t.wrappingNeeded=!t.wrapped&&!l&&!u&&(h=b(v)),t.cellHeightMayIncrease=s||u||t.mayHaveMarkup||(void 0===h?b(v):h),t.needsConvertToTspans=t.mayHaveMarkup||t.wrappingNeeded||t.latex,t.wrappingNeeded){var m=(\" \"===n.wrapSplitCharacter?v.replace(/<a href=/gi,\"<a_href=\"):v).split(n.wrapSplitCharacter),y=\" \"===n.wrapSplitCharacter?m.map(function(t){return t.replace(/<a_href=/gi,\"<a href=\")}):m;t.fragments=y.map(function(t){return{text:t,width:null}}),t.fragments.push({fragment:n.wrapSpacer,width:null}),f=y.join(n.lineBreaker)+n.lineBreaker+n.wrapSpacer}else delete t.fragments,f=v;return f}).attr(\"dy\",function(t){return t.needsConvertToTspans?0:\"0.75em\"}).each(function(t){var o=i.select(this),l=t.wrappingNeeded?C:L;t.needsConvertToTspans?s.convertToTspans(o,a,l(r,this,e,a,t)):i.select(this.parentNode).attr(\"transform\",function(t){return\"translate(\"+P(t)+\" \"+n.cellPad+\")\"}).attr(\"text-anchor\",function(t){return{left:\"start\",center:\"middle\",right:\"end\"}[t.align]})})}function b(t){return-1!==t.indexOf(n.wrapSplitCharacter)}function _(t,e,r){if(Array.isArray(t)){var n=t[Math.min(e,t.length-1)];return Array.isArray(n)?n[Math.min(r,n.length-1)]:n}return t}function w(t,e,r){t.transition().ease(n.releaseTransitionEase).duration(n.releaseTransitionDuration).attr(\"transform\",\"translate(\"+e.x+\" \"+r+\")\")}function k(t){return\"cells\"===t.type}function T(t){return\"header\"===t.type}function A(t){return(t.rowBlocks.length?t.rowBlocks[0].auxiliaryBlocks:[]).reduce(function(t,e){return t+I(e,1/0)},0)}function M(t,e,r){var n=v(e)[0];if(void 0!==n){var i=n.rowBlocks,a=n.calcdata,o=z(i,i.length),s=n.calcdata.groupHeight-A(n),l=a.scrollY=Math.max(0,Math.min(o-s,a.scrollY)),c=function(t,e,r){for(var n=[],i=0,a=0;a<t.length;a++){for(var o=t[a],s=o.rows,l=0,c=0;c<s.length;c++)l+=s[c].rowHeight;o.allRowsHeight=l,e<i+l&&e+r>i&&n.push(a),i+=l}return n}(i,l,s);1===c.length&&(c[0]===i.length-1?c.unshift(c[0]-1):c.push(c[0]+1)),c[0]%2&&c.reverse(),e.each(function(t,e){t.page=c[e],t.scrollY=l}),e.attr(\"transform\",function(t){return\"translate(0 \"+(z(t.rowBlocks,t.page)-t.scrollY)+\")\"}),t&&(E(t,r,e,c,n.prevPages,n,0),E(t,r,e,c,n.prevPages,n,1),m(r,t))}}function S(t,e,r,a){return function(o){var s=o.calcdata?o.calcdata:o,l=e.filter(function(t){return s.key===t.key}),c=r||s.scrollbarState.dragMultiplier,u=s.scrollY;s.scrollY=void 0===a?s.scrollY+c*i.event.dy:a;var h=l.selectAll(\".\"+n.cn.yColumn).selectAll(\".\"+n.cn.columnBlock).filter(k);return M(t,h,l),s.scrollY===u}}function E(t,e,r,n,i,a,o){n[o]!==i[o]&&(clearTimeout(a.currentRepaint[o]),a.currentRepaint[o]=setTimeout(function(){var a=r.filter(function(t,e){return e===o&&n[e]!==i[e]});y(t,e,a,r),i[o]=n[o]}))}function C(t,e,r,a){return function(){var o=i.select(e.parentNode);o.each(function(t){var e=t.fragments;o.selectAll(\"tspan.line\").each(function(t,r){e[r].width=this.getComputedTextLength()});var r,i,a=e[e.length-1].width,s=e.slice(0,-1),l=[],c=0,u=t.column.columnWidth-2*n.cellPad;for(t.value=\"\";s.length;)c+(i=(r=s.shift()).width+a)>u&&(t.value+=l.join(n.wrapSpacer)+n.lineBreaker,l=[],c=0),l.push(r.text),c+=i;c&&(t.value+=l.join(n.wrapSpacer)),t.wrapped=!0}),o.selectAll(\"tspan.line\").remove(),x(o.select(\".\"+n.cn.cellText),r,t,a),i.select(e.parentNode.parentNode).call(O)}}function L(t,e,r,a,o){return function(){if(!o.settledY){var s=i.select(e.parentNode),l=R(o),c=o.key-l.firstRowIndex,u=l.rows[c].rowHeight,h=o.cellHeightMayIncrease?e.parentNode.getBoundingClientRect().height+2*n.cellPad:u,f=Math.max(h,u);f-l.rows[c].rowHeight&&(l.rows[c].rowHeight=f,t.selectAll(\".\"+n.cn.columnCell).call(O),M(null,t.filter(k),0),m(r,a,!0)),s.attr(\"transform\",function(){var t=this.parentNode.getBoundingClientRect(),e=i.select(this.parentNode).select(\".\"+n.cn.cellRect).node().getBoundingClientRect(),r=this.transform.baseVal.consolidate(),a=e.top-t.top+(r?r.matrix.f:n.cellPad);return\"translate(\"+P(o,i.select(this.parentNode).select(\".\"+n.cn.cellTextHolder).node().getBoundingClientRect().width)+\" \"+a+\")\"}),o.settledY=!0}}}function P(t,e){switch(t.align){case\"left\":return n.cellPad;case\"right\":return t.column.columnWidth-(e||0)-n.cellPad;case\"center\":return(t.column.columnWidth-(e||0))/2;default:return n.cellPad}}function O(t){t.attr(\"transform\",function(t){var e=t.rowBlocks[0].auxiliaryBlocks.reduce(function(t,e){return t+I(e,1/0)},0);return\"translate(0 \"+(I(R(t),t.key)+e)+\")\"}).selectAll(\".\"+n.cn.cellRect).attr(\"height\",function(t){return(e=R(t),r=t.key,e.rows[r-e.firstRowIndex]).rowHeight;var e,r})}function z(t,e){for(var r=0,n=e-1;n>=0;n--)r+=D(t[n]);return r}function I(t,e){for(var r=0,n=0;n<t.rows.length&&t.rows[n].rowIndex<e;n++)r+=t.rows[n].rowHeight;return r}function D(t){var e=t.allRowsHeight;if(void 0!==e)return e;for(var r=0,n=0;n<t.rows.length;n++)r+=t.rows[n].rowHeight;return t.allRowsHeight=r,r}function R(t){return t.rowBlocks[t.page]}e.exports=function(t,e){var r=!t._context.staticPlot,s=t._fullLayout._paper.selectAll(\".\"+n.cn.table).data(e.map(function(e){var r=a.unwrap(e).trace;return u(t,r)}),a.keyFun);s.exit().remove(),s.enter().append(\"g\").classed(n.cn.table,!0).attr(\"overflow\",\"visible\").style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"overflow\",\"visible\").style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"all\"),s.attr(\"width\",function(t){return t.width+t.size.l+t.size.r}).attr(\"height\",function(t){return t.height+t.size.t+t.size.b}).attr(\"transform\",function(t){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"});var f=s.selectAll(\".\"+n.cn.tableControlView).data(a.repeat,a.keyFun),x=f.enter().append(\"g\").classed(n.cn.tableControlView,!0).style(\"box-sizing\",\"content-box\");r&&x.on(\"mousemove\",function(e){f.filter(function(t){return e===t}).call(m,t)}).on(\"mousewheel\",function(e){if(!e.scrollbarState.wheeling){e.scrollbarState.wheeling=!0;var r=e.scrollY+i.event.deltaY;S(t,f,null,r)(e)||(i.event.stopPropagation(),i.event.preventDefault()),e.scrollbarState.wheeling=!1}}).call(m,t,!0),f.attr(\"transform\",function(t){return\"translate(\"+t.size.l+\" \"+t.size.t+\")\"});var b=f.selectAll(\".\"+n.cn.scrollBackground).data(a.repeat,a.keyFun);b.enter().append(\"rect\").classed(n.cn.scrollBackground,!0).attr(\"fill\",\"none\"),b.attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}),f.each(function(e){o.setClipUrl(i.select(this),d(t,e),t)});var _=f.selectAll(\".\"+n.cn.yColumn).data(function(t){return t.columns},a.keyFun);_.enter().append(\"g\").classed(n.cn.yColumn,!0),_.exit().remove(),_.attr(\"transform\",function(t){return\"translate(\"+t.x+\" 0)\"}),r&&_.call(i.behavior.drag().origin(function(e){return w(i.select(this),e,-n.uplift),l(this),e.calcdata.columnDragInProgress=!0,m(f.filter(function(t){return e.calcdata.key===t.key}),t),e}).on(\"drag\",function(t){var e=i.select(this),r=function(e){return(t===e?i.event.x:e.x)+e.columnWidth/2};t.x=Math.max(-n.overdrag,Math.min(t.calcdata.width+n.overdrag-t.columnWidth,i.event.x)),v(_).filter(function(e){return e.calcdata.key===t.calcdata.key}).sort(function(t,e){return r(t)-r(e)}).forEach(function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e)}),_.filter(function(e){return t!==e}).transition().ease(n.transitionEase).duration(n.transitionDuration).attr(\"transform\",function(t){return\"translate(\"+t.x+\" 0)\"}),e.call(c).attr(\"transform\",\"translate(\"+t.x+\" -\"+n.uplift+\" )\")}).on(\"dragend\",function(e){var r=i.select(this),n=e.calcdata;e.x=e.xScale(e),e.calcdata.columnDragInProgress=!1,w(r,e,0),function(t,e,r){var n=e.gdColumnsOriginalOrder;e.gdColumns.sort(function(t,e){return r[n.indexOf(t)]-r[n.indexOf(e)]}),e.columnorder=r,t.emit(\"plotly_restyle\")}(t,n,n.columns.map(function(t){return t.xIndex}))})),_.each(function(e){o.setClipUrl(i.select(this),g(t,e),t)});var A=_.selectAll(\".\"+n.cn.columnBlock).data(h.splitToPanels,a.keyFun);A.enter().append(\"g\").classed(n.cn.columnBlock,!0).attr(\"id\",function(t){return t.key}),A.style(\"cursor\",function(t){return t.dragHandle?\"ew-resize\":t.calcdata.scrollbarState.barWiggleRoom?\"ns-resize\":\"default\"});var E=A.filter(T),C=A.filter(k);r&&C.call(i.behavior.drag().origin(function(t){return i.event.stopPropagation(),t}).on(\"drag\",S(t,f,-1)).on(\"dragend\",function(){})),y(t,f,E,A),y(t,f,C,A);var L=f.selectAll(\".\"+n.cn.scrollAreaClip).data(a.repeat,a.keyFun);L.enter().append(\"clipPath\").classed(n.cn.scrollAreaClip,!0).attr(\"id\",function(e){return d(t,e)});var P=L.selectAll(\".\"+n.cn.scrollAreaClipRect).data(a.repeat,a.keyFun);P.enter().append(\"rect\").classed(n.cn.scrollAreaClipRect,!0).attr(\"x\",-n.overdrag).attr(\"y\",-n.uplift).attr(\"fill\",\"none\"),P.attr(\"width\",function(t){return t.width+2*n.overdrag}).attr(\"height\",function(t){return t.height+n.uplift}),_.selectAll(\".\"+n.cn.columnBoundary).data(a.repeat,a.keyFun).enter().append(\"g\").classed(n.cn.columnBoundary,!0);var O=_.selectAll(\".\"+n.cn.columnBoundaryClippath).data(a.repeat,a.keyFun);O.enter().append(\"clipPath\").classed(n.cn.columnBoundaryClippath,!0),O.attr(\"id\",function(e){return g(t,e)});var z=O.selectAll(\".\"+n.cn.columnBoundaryRect).data(a.repeat,a.keyFun);z.enter().append(\"rect\").classed(n.cn.columnBoundaryRect,!0).attr(\"fill\",\"none\"),z.attr(\"width\",function(t){return t.columnWidth+2*p(t)}).attr(\"height\",function(t){return t.calcdata.height+2*p(t)+n.uplift}).attr(\"x\",function(t){return-p(t)}).attr(\"y\",function(t){return-p(t)}),M(null,C,f)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/gup\":717,\"../../lib/svg_text_utils\":743,\"./constants\":1232,\"./data_preparation_helper\":1233,\"./data_split_helpers\":1234,d3:163}],1238:[function(t,e,r){\"use strict\";var n=t(\"../box/attributes\"),i=t(\"../../lib/extend\").extendFlat;e.exports={y:n.y,x:n.x,x0:n.x0,y0:n.y0,name:i({},n.name,{}),orientation:i({},n.orientation,{}),bandwidth:{valType:\"number\",min:0,editType:\"calc\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},scalemode:{valType:\"enumerated\",values:[\"width\",\"count\"],dflt:\"width\",editType:\"calc\"},spanmode:{valType:\"enumerated\",values:[\"soft\",\"hard\",\"manual\"],dflt:\"soft\",editType:\"calc\"},span:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}],editType:\"calc\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,points:i({},n.boxpoints,{}),jitter:i({},n.jitter,{}),pointpos:i({},n.pointpos,{}),width:i({},n.width,{}),marker:n.marker,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,box:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},width:{valType:\"number\",min:0,max:1,dflt:.25,editType:\"plot\"},fillcolor:{valType:\"color\",editType:\"style\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},editType:\"plot\"},meanline:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"plot\"},side:{valType:\"enumerated\",values:[\"both\",\"positive\",\"negative\"],dflt:\"both\",editType:\"calc\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,hoveron:{valType:\"flaglist\",flags:[\"violins\",\"points\",\"kde\"],dflt:\"violins+points+kde\",extras:[\"all\"],editType:\"style\"}}},{\"../../lib/extend\":710,\"../box/attributes\":880}],1239:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/calc\"),o=t(\"./helpers\"),s=t(\"../../constants/numerical\").BADNUM;function l(t,e,r){var i=e.max-e.min;if(!i)return t.bandwidth?t.bandwidth:0;if(t.bandwidth)return Math.max(t.bandwidth,i/1e4);var a=r.length,o=n.stdev(r,a-1,e.mean);return Math.max(function(t,e,r){return 1.059*Math.min(e,r/1.349)*Math.pow(t,-.2)}(a,o,e.q3-e.q1),i/100)}function c(t,e,r,n){var a,o=t.spanmode,l=t.span||[],c=[e.min,e.max],u=[e.min-2*n,e.max+2*n];function h(n){var i=l[n],a=\"multicategory\"===r.type?r.r2c(i):r.d2c(i,0,t[e.valLetter+\"calendar\"]);return a===s?u[n]:a}var f={type:\"linear\",range:a=\"soft\"===o?u:\"hard\"===o?c:[h(0),h(1)]};return i.setConvert(f),f.cleanRange(),a}e.exports=function(t,e){var r=a(t,e);if(r[0].t.empty)return r;for(var s=t._fullLayout,u=i.getFromId(t,e[\"h\"===e.orientation?\"xaxis\":\"yaxis\"]),h=1/0,f=-1/0,p=0,d=0,g=0;g<r.length;g++){var v=r[g],m=v.pts.map(o.extractVal),y=v.bandwidth=l(e,v,m),x=v.span=c(e,v,u,y);if(v.min===v.max&&0===y)x=v.span=[v.min,v.max],v.density=[{v:1,t:x[0]}],v.bandwidth=y,p=Math.max(p,1);else{var b=x[1]-x[0],_=Math.ceil(b/(y/3)),w=b/_;if(!isFinite(w)||!isFinite(_))return n.error(\"Something went wrong with computing the violin span\"),r[0].t.empty=!0,r;var k=o.makeKDE(v,e,m);v.density=new Array(_);for(var T=0,A=x[0];A<x[1]+w/2;T++,A+=w){var M=k(A);v.density[T]={v:M,t:A},p=Math.max(p,M)}}d=Math.max(d,m.length),h=Math.min(h,x[0]),f=Math.max(f,x[1])}var S=i.findExtremes(u,[h,f],{padded:!0});if(e._extremes[u._id]=S,e.width)r[0].t.maxKDE=p;else{var E=s._violinScaleGroupStats,C=e.scalegroup,L=E[C];L?(L.maxKDE=Math.max(L.maxKDE,p),L.maxCount=Math.max(L.maxCount,d)):E[C]={maxKDE:p,maxCount:d}}return r[0].t.labels.kde=n._(t,\"kde:\"),r}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../box/calc\":881,\"./helpers\":1242}],1240:[function(t,e,r){\"use strict\";var n=t(\"../box/cross_trace_calc\").setPositionOffset,i=[\"v\",\"h\"];e.exports=function(t,e){for(var r=t.calcdata,a=e.xaxis,o=e.yaxis,s=0;s<i.length;s++){for(var l=i[s],c=\"h\"===l?o:a,u=[],h=0;h<r.length;h++){var f=r[h],p=f[0].t,d=f[0].trace;!0!==d.visible||\"violin\"!==d.type||p.empty||d.orientation!==l||d.xaxis!==a._id||d.yaxis!==o._id||u.push(h)}n(\"violin\",t,u,c)}}},{\"../box/cross_trace_calc\":882}],1241:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../box/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}function c(r,i){return n.coerce2(t,e,o,r,i)}if(a.handleSampleDefaults(t,e,l,s),!1!==e.visible){l(\"bandwidth\"),l(\"side\"),l(\"width\")||(l(\"scalegroup\",e.name),l(\"scalemode\"));var u,h=l(\"span\");Array.isArray(h)&&(u=\"manual\"),l(\"spanmode\",u);var f=l(\"line.color\",(t.marker||{}).color||r),p=l(\"line.width\"),d=l(\"fillcolor\",i.addOpacity(e.line.color,.5));a.handlePointsDefaults(t,e,l,{prefix:\"\"});var g=c(\"box.width\"),v=c(\"box.fillcolor\",d),m=c(\"box.line.color\",f),y=c(\"box.line.width\",p);l(\"box.visible\",Boolean(g||v||m||y))||(e.box={visible:!1});var x=c(\"meanline.color\",f),b=c(\"meanline.width\",p);l(\"meanline.visible\",Boolean(x||b))||(e.meanline={visible:!1})}}},{\"../../components/color\":593,\"../../lib\":719,\"../box/defaults\":883,\"./attributes\":1238}],1242:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=function(t){return 1/Math.sqrt(2*Math.PI)*Math.exp(-.5*t*t)};r.makeKDE=function(t,e,r){var n=r.length,a=i,o=t.bandwidth,s=1/(n*o);return function(t){for(var e=0,i=0;i<n;i++)e+=a((t-r[i])/o);return s*e}},r.getPositionOnKdePath=function(t,e,r){var i,a;\"h\"===e.orientation?(i=\"y\",a=\"x\"):(i=\"x\",a=\"y\");var o=n.findPointOnPath(t.path,r,a,{pathLength:t.pathLength}),s=t.posCenterPx,l=o[i];return[l,\"both\"===e.side?2*s-l:s]},r.getKdeValue=function(t,e,n){var i=t.pts.map(r.extractVal);return r.makeKDE(t,e,i)(n)/t.posDensityScale},r.extractVal=function(t){return t.v}},{\"../../lib\":719}],1243:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/hover\"),o=t(\"./helpers\");e.exports=function(t,e,r,s,l){var c,u,h=t.cd,f=h[0].trace,p=f.hoveron,d=-1!==p.indexOf(\"violins\"),g=-1!==p.indexOf(\"kde\"),v=[];if(d||g){var m=a.hoverOnBoxes(t,e,r,s);if(g&&m.length>0){var y,x,b,_,w,k=t.xa,T=t.ya;\"h\"===f.orientation?(w=e,y=\"y\",b=T,x=\"x\",_=k):(w=r,y=\"x\",b=k,x=\"y\",_=T);var A=h[t.index];if(w>=A.span[0]&&w<=A.span[1]){var M=n.extendFlat({},t),S=_.c2p(w,!0),E=o.getKdeValue(A,f,w),C=o.getPositionOnKdePath(A,f,S),L=b._offset,P=b._length;M[y+\"0\"]=C[0],M[y+\"1\"]=C[1],M[x+\"0\"]=M[x+\"1\"]=S,M[x+\"Label\"]=x+\": \"+i.hoverLabelText(_,w)+\", \"+h[0].t.labels.kde+\" \"+E.toFixed(3),M.spikeDistance=m[0].spikeDistance;var O=y+\"Spike\";M[O]=m[0][O],m[0].spikeDistance=void 0,m[0][O]=void 0,M.hovertemplate=!1,v.push(M),(u={stroke:t.color})[y+\"1\"]=n.constrain(L+C[0],L,L+P),u[y+\"2\"]=n.constrain(L+C[1],L,L+P),u[x+\"1\"]=u[x+\"2\"]=_._offset+S}}d&&(v=v.concat(m))}-1!==p.indexOf(\"points\")&&(c=a.hoverOnPoints(t,e,r));var z=l.selectAll(\".violinline-\"+f.uid).data(u?[0]:[]);return z.enter().append(\"line\").classed(\"violinline-\"+f.uid,!0).attr(\"stroke-width\",1.5),z.exit().remove(),z.attr(u),\"closest\"===s?c?[c]:v:c?(v.push(c),v):v}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../box/hover\":885,\"./helpers\":1242}],1244:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../box/defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../box/select\"),moduleType:\"trace\",name:\"violin\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"violinLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../box/defaults\":883,\"../box/select\":890,\"../scatter/style\":1134,\"./attributes\":1238,\"./calc\":1239,\"./cross_trace_calc\":1240,\"./defaults\":1241,\"./hover\":1243,\"./layout_attributes\":1245,\"./layout_defaults\":1246,\"./plot\":1247,\"./style\":1248}],1245:[function(t,e,r){\"use strict\";var n=t(\"../box/layout_attributes\"),i=t(\"../../lib\").extendFlat;e.exports={violinmode:i({},n.boxmode,{}),violingap:i({},n.boxgap,{}),violingroupgap:i({},n.boxgroupgap,{})}},{\"../../lib\":719,\"../box/layout_attributes\":887}],1246:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"../box/layout_defaults\");e.exports=function(t,e,r){a._supply(t,e,r,function(r,a){return n.coerce(t,e,i,r,a)},\"violin\")}},{\"../../lib\":719,\"../box/layout_defaults\":888,\"./layout_attributes\":1245}],1247:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../box/plot\"),s=t(\"../scatter/line_points\"),l=t(\"./helpers\");e.exports=function(t,e,r,c){var u=t._fullLayout,h=e.xaxis,f=e.yaxis;function p(t){var e=s(t,{xaxis:h,yaxis:f,connectGaps:!0,baseTolerance:.75,shape:\"spline\",simplify:!0});return a.smoothopen(e[0],1)}i.makeTraceGroups(c,r,\"trace violins\").each(function(t){var r=n.select(this),a=t[0],s=a.t,c=a.trace;if(!0!==c.visible||s.empty)r.remove();else{var d=s.bPos,g=s.bdPos,v=e[s.valLetter+\"axis\"],m=e[s.posLetter+\"axis\"],y=\"both\"===c.side,x=y||\"positive\"===c.side,b=y||\"negative\"===c.side,_=r.selectAll(\"path.violin\").data(i.identity);_.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"violin\"),_.exit().remove(),_.each(function(t){var e,r,i,a,o,l,h,f,_=n.select(this),w=t.density,k=w.length,T=t.pos+d,A=m.c2p(T);if(c.width)e=s.maxKDE/g;else{var M=u._violinScaleGroupStats[c.scalegroup];e=\"count\"===c.scalemode?M.maxKDE/g*(M.maxCount/t.pts.length):M.maxKDE/g}if(x){for(h=new Array(k),o=0;o<k;o++)(f=h[o]={})[s.posLetter]=T+w[o].v/e,f[s.valLetter]=w[o].t;r=p(h)}if(b){for(h=new Array(k),l=0,o=k-1;l<k;l++,o--)(f=h[l]={})[s.posLetter]=T-w[o].v/e,f[s.valLetter]=w[o].t;i=p(h)}if(y)a=r+\"L\"+i.substr(1)+\"Z\";else{var S=[A,v.c2p(w[0].t)],E=[A,v.c2p(w[k-1].t)];\"h\"===c.orientation&&(S.reverse(),E.reverse()),a=x?\"M\"+S+\"L\"+r.substr(1)+\"L\"+E:\"M\"+E+\"L\"+i.substr(1)+\"L\"+S}_.attr(\"d\",a),t.posCenterPx=A,t.posDensityScale=e*g,t.path=_.node(),t.pathLength=t.path.getTotalLength()/(y?2:1)});var w,k,T,A=c.box,M=A.width,S=(A.line||{}).width;y?(w=g*M,k=0):x?(w=[0,g*M/2],k=-S):(w=[g*M/2,0],k=S),o.plotBoxAndWhiskers(r,{pos:m,val:v},c,{bPos:d,bdPos:w,bPosPxOffset:k}),o.plotBoxMean(r,{pos:m,val:v},c,{bPos:d,bdPos:w,bPosPxOffset:k}),!c.box.visible&&c.meanline.visible&&(T=i.identity);var E=r.selectAll(\"path.meanline\").data(T||[]);E.enter().append(\"path\").attr(\"class\",\"meanline\").style(\"fill\",\"none\").style(\"vector-effect\",\"non-scaling-stroke\"),E.exit().remove(),E.each(function(t){var e=v.c2p(t.mean,!0),r=l.getPositionOnKdePath(t,c,e);n.select(this).attr(\"d\",\"h\"===c.orientation?\"M\"+e+\",\"+r[0]+\"V\"+r[1]:\"M\"+r[0]+\",\"+e+\"H\"+r[1])}),o.plotPoints(r,{x:h,y:f},c,s)}})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../box/plot\":889,\"../scatter/line_points\":1125,\"./helpers\":1242,d3:163}],1248:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../scatter/style\").stylePoints;e.exports=function(t){var e=n.select(t).selectAll(\"g.trace.violins\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.each(function(e){var r=e[0].trace,o=n.select(this),s=r.box||{},l=s.line||{},c=r.meanline||{},u=c.width;o.selectAll(\"path.violin\").style(\"stroke-width\",r.line.width+\"px\").call(i.stroke,r.line.color).call(i.fill,r.fillcolor),o.selectAll(\"path.box\").style(\"stroke-width\",l.width+\"px\").call(i.stroke,l.color).call(i.fill,s.fillcolor);var h={\"stroke-width\":u+\"px\",\"stroke-dasharray\":2*u+\"px,\"+u+\"px\"};o.selectAll(\"path.mean\").style(h).call(i.stroke,c.color),o.selectAll(\"path.meanline\").style(h).call(i.stroke,c.color),a(o,r,t)})}},{\"../../components/color\":593,\"../scatter/style\":1134,d3:163}],1249:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../isosurface/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=e.exports=s(o({x:i.x,y:i.y,z:i.z,value:i.value,isomin:i.isomin,isomax:i.isomax,surface:i.surface,spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:1}},slices:i.slices,caps:i.caps,text:i.text,hovertext:i.hovertext,hovertemplate:i.hovertemplate},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{colorbar:i.colorbar,opacity:i.opacity,opacityscale:{valType:\"any\",editType:\"calc\"},lightposition:i.lightposition,lighting:i.lighting,flatshading:i.flatshading,contour:i.contour,hoverinfo:o({},a.hoverinfo)}),\"calc\",\"nested\");l.x.editType=l.y.editType=l.z.editType=l.value.editType=\"calc+clearAxisTypes\",l.transforms=void 0},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../isosurface/attributes\":1048}],1250:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib/gl_format_color\").parseColorScale,a=t(\"../../lib/str2rgbarray\"),o=t(\"../../components/colorscale\").extractOpts,s=t(\"../../plots/gl3d/zip3\"),l=t(\"../isosurface/convert\").findNearestOnAxis,c=t(\"../isosurface/convert\").generateIsoMeshes;function u(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var h=u.prototype;h.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._x[e],n=this.data._y[e],i=this.data._z[e],a=this.data._Ys.length,o=this.data._Zs.length,s=l(r,this.data._Xs).id,c=l(n,this.data._Ys).id,u=l(i,this.data._Zs).id,h=t.index=u+o*c+o*a*s;t.traceCoordinate=[this.data._x[h],this.data._y[h],this.data._z[h],this.data.value[h]];var f=this.data.hovertext||this.data.text;return Array.isArray(f)&&void 0!==f[h]?t.textLabel=f[h]:f&&(t.textLabel=f),!0}},h.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map(function(e){return t.d2l(e,0,n)*r})}this.data=c(t);var l={positions:s(n(r.xaxis,t._x,e.dataScale[0],t.xcalendar),n(r.yaxis,t._y,e.dataScale[1],t.ycalendar),n(r.zaxis,t._z,e.dataScale[2],t.zcalendar)),cells:s(t._i,t._j,t._k),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,opacityscale:t.opacityscale,contourEnable:t.contour.show,contourColor:a(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},u=o(t);l.vertexIntensity=t._intensity,l.vertexIntensityBounds=[u.min,u.max],l.colormap=i(t),this.mesh.update(l)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new u(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":605,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../../plots/gl3d/zip3\":818,\"../isosurface/convert\":1050,\"gl-mesh3d\":280}],1251:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../isosurface/defaults\").supplyIsoDefaults;e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}a(t,e,r,o,s);var l=s(\"opacityscale\");\"max\"===l?e.opacityscale=[[0,.1],[1,1]]:\"min\"===l?e.opacityscale=[[0,1],[1,.1]]:\"extremes\"===l?e.opacityscale=function(t,e){for(var r=[],n=0;n<32;n++){var i=n/31,a=e+(1-e)*(1-Math.pow(Math.sin(t*i*Math.PI),2));r.push([i,Math.max(1,Math.min(0,a))])}return r}(1,.1):function(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var n=t[r];if(2!==n.length||+n[0]<e)return!1;e=+n[0]}return!0}(l)||(e.opacityscale=void 0)}},{\"../../lib\":719,\"../isosurface/defaults\":1051,\"./attributes\":1249}],1252:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../isosurface/calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"volume\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],meta:{}}},{\"../../plots/gl3d\":807,\"../isosurface/calc\":1049,\"./attributes\":1249,\"./convert\":1250,\"./defaults\":1251}],1253:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"./constants\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../components/color\");function u(t){return{marker:{color:l({},n.marker.color,{arrayOk:!1,editType:\"style\"}),line:{color:l({},n.marker.line.color,{arrayOk:!1,editType:\"style\"}),width:l({},n.marker.line.width,{arrayOk:!1,editType:\"style\"}),editType:\"style\"},editType:\"style\"},editType:\"style\"}}e.exports={measure:{valType:\"data_array\",dflt:[],editType:\"calc\"},base:{valType:\"number\",dflt:null,arrayOk:!1,editType:\"calc\"},x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,hovertext:n.hovertext,hovertemplate:o({},{keys:s.eventDataKeys}),hoverinfo:l({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"initial\",\"delta\",\"final\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"initial\",\"delta\",\"final\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},text:n.text,textposition:n.textposition,insidetextanchor:n.insidetextanchor,textangle:n.textangle,textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:n.orientation,offset:n.offset,width:n.width,increasing:u(),decreasing:u(),totals:u(),connector:{line:{color:l({},i.color,{dflt:c.defaultLine}),width:l({},i.width,{editType:\"plot\"}),dash:i.dash,editType:\"plot\"},mode:{valType:\"enumerated\",values:[\"spanning\",\"between\"],dflt:\"between\",editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":593,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../bar/attributes\":857,\"../scatter/attributes\":1112,\"./constants\":1255}],1254:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\").mergeArray,a=t(\"../scatter/calc_selection\"),o=t(\"../../constants/numerical\").BADNUM;function s(t){return\"a\"===t||\"absolute\"===t}function l(t){return\"t\"===t||\"total\"===t}e.exports=function(t,e){var r,c,u=n.getFromId(t,e.xaxis||\"x\"),h=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=u.makeCalcdata(e,\"x\"),c=h.makeCalcdata(e,\"y\")):(r=h.makeCalcdata(e,\"y\"),c=u.makeCalcdata(e,\"x\"));for(var f,p=Math.min(c.length,r.length),d=new Array(p),g=0,v=!1,m=0;m<p;m++){var y=r[m]||0,x=!1;(r[m]!==o||l(e.measure[m])||s(e.measure[m]))&&m+1<p&&(r[m+1]!==o||l(e.measure[m+1])||s(e.measure[m+1]))&&(x=!0);var b=d[m]={i:m,p:c[m],s:y,rawS:y,cNext:x};s(e.measure[m])?(g=b.s,b.isSum=!0,b.dir=\"totals\",b.s=g):l(e.measure[m])?(b.isSum=!0,b.dir=\"totals\",b.s=g):(b.isSum=!1,b.dir=b.rawS<0?\"decreasing\":\"increasing\",f=b.s,b.s=g+f,g+=f),\"totals\"===b.dir&&(v=!0),e.ids&&(b.id=String(e.ids[m])),b.v=(e.base||0)+g}return d.length&&(d[0].hasTotals=v),i(e.text,d,\"tx\"),i(e.hovertext,d,\"htx\"),a(d,e),d}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scatter/calc_selection\":1114}],1255:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"initial\",\"delta\",\"final\"]}},{}],1256:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],h=[],f=[];for(i=0;i<o.length;i++){var p=o[i];!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"waterfall\"===p.type&&(r=s[i],\"h\"===p.orientation?f.push(r):h.push(r),u.push(r))}var d={mode:a.waterfallmode,norm:a.waterfallnorm,gap:a.waterfallgap,groupgap:a.waterfallgroupgap};for(n(t,l,c,h,d),n(t,c,l,f,d),i=0;i<u.length;i++){r=u[i];for(var g=0;g<r.length;g++){var v=r[g];!1===v.isSum&&(v.s0+=0===g?0:r[g-1].s),g+1<r.length&&(r[g].nextP0=r[g+1].p0,r[g].nextS0=r[g+1].s0)}}}},{\"../bar/cross_trace_calc\":860}],1257:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"./attributes\"),l=t(\"../../components/color\"),c=t(\"../../constants/delta.js\"),u=c.INCREASING.COLOR,h=c.DECREASING.COLOR,f=\"#4499FF\";function p(t,e,r){t(e+\".marker.color\",r),t(e+\".marker.line.color\",l.defaultLine),t(e+\".marker.line.width\")}e.exports={supplyDefaults:function(t,e,r,i){function l(r,i){return n.coerce(t,e,s,r,i)}if(o(t,e,i,l)){l(\"measure\"),l(\"orientation\",e.x&&!e.y?\"h\":\"v\"),l(\"base\"),l(\"offset\"),l(\"width\"),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\");var c=l(\"textposition\");a(t,e,i,l,c,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"!==e.textposition&&l(\"textinfo\"),p(l,\"increasing\",u),p(l,\"decreasing\",h),p(l,\"totals\",f),l(\"connector.visible\")&&(l(\"connector.mode\"),l(\"connector.line.width\")&&(l(\"connector.line.color\"),l(\"connector.line.dash\")))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,s,t)}if(\"group\"===e.waterfallmode)for(var l=0;l<t.length;l++)r=(a=t[l])._input,i(r,a,e,o)}}},{\"../../components/color\":593,\"../../constants/delta.js\":689,\"../../lib\":719,\"../bar/defaults\":861,\"../scatter/xy_defaults\":1137,\"./attributes\":1253}],1258:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"initial\"in e&&(t.initial=e.initial),\"delta\"in e&&(t.delta=e.delta),\"final\"in e&&(t.final=e.final),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],1259:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\").hoverLabelText,i=t(\"../../components/color\").opacity,a=t(\"../bar/hover\").hoverOnBars,o=t(\"../../constants/delta.js\"),s=o.INCREASING.SYMBOL,l=o.DECREASING.SYMBOL;e.exports=function(t,e,r,o){var c=a(t,e,r,o);if(c){var u=c.cd,h=u[0].trace,f=\"h\"===h.orientation,p=f?t.xa:t.ya,d=u[c.index],g=d.isSum?d.b+d.s:d.rawS;if(!d.isSum){c.initial=d.b+d.s-g,c.delta=g,c.final=c.initial+c.delta;var v=w(Math.abs(c.delta));c.deltaLabel=g<0?\"(\"+v+\")\":v,c.finalLabel=w(c.final),c.initialLabel=w(c.initial)}var m=d.hi||h.hoverinfo,y=[];if(m&&\"none\"!==m&&\"skip\"!==m){var x=\"all\"===m,b=m.split(\"+\"),_=function(t){return x||-1!==b.indexOf(t)};d.isSum||(!_(\"final\")||_(f?\"x\":\"y\")||y.push(c.finalLabel),_(\"delta\")&&(g<0?y.push(c.deltaLabel+\" \"+l):y.push(c.deltaLabel+\" \"+s)),_(\"initial\")&&y.push(\"Initial: \"+c.initialLabel))}return y.length&&(c.extraText=y.join(\"<br>\")),c.color=function(t,e){var r=t[e.dir].marker,n=r.color,a=r.line.color,o=r.line.width;if(i(n))return n;if(i(a)&&o)return a}(h,d),[c]}function w(t){return n(p,t)}}},{\"../../components/color\":593,\"../../constants/delta.js\":689,\"../../plots/cartesian/axes\":767,\"../bar/hover\":863}],1260:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"waterfall\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../bar/select\":868,\"./attributes\":1253,\"./calc\":1254,\"./cross_trace_calc\":1256,\"./defaults\":1257,\"./event_data\":1258,\"./hover\":1259,\"./layout_attributes\":1261,\"./layout_defaults\":1262,\"./plot\":1263,\"./style\":1264}],1261:[function(t,e,r){\"use strict\";e.exports={waterfallmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"group\",editType:\"calc\"},waterfallgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},waterfallgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],1262:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"waterfall\"===l.type){a=!0;break}}a&&(o(\"waterfallmode\"),o(\"waterfallgap\",.2),o(\"waterfallgroupgap\"))}},{\"../../lib\":719,\"./layout_attributes\":1261}],1263:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../bar/plot\").plot;e.exports=function(t,e,r,s){var l=t._fullLayout;o(t,e,r,s,{mode:l.waterfallmode,norm:l.waterfallmode,gap:l.waterfallgap,groupgap:l.waterfallgroupgap}),function(t,e,r,o){var s=e.xaxis,l=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each(function(r){var o=n.select(this),c=r[0].trace,u=i.ensureSingle(o,\"g\",\"lines\");if(c.connector&&c.connector.visible){var h=\"h\"===c.orientation,f=c.connector.mode,p=u.selectAll(\"g.line\").data(i.identity);p.enter().append(\"g\").classed(\"line\",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var c=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),n?[i,a]:[a,i]}(r,s,l,h),u=c[0],p=c[1],g=\"\";\"spanning\"===f&&!r.isSum&&o>0&&(g+=h?\"M\"+u[0]+\",\"+p[1]+\"V\"+p[0]:\"M\"+u[1]+\",\"+p[0]+\"H\"+u[0]),\"between\"!==f&&(r.isSum||o<d-1)&&(g+=h?\"M\"+u[1]+\",\"+p[0]+\"V\"+p[1]:\"M\"+u[0]+\",\"+p[1]+\"H\"+u[1]),void 0!==u[2]&&void 0!==p[2]&&(g+=h?\"M\"+u[1]+\",\"+p[1]+\"V\"+p[2]:\"M\"+u[1]+\",\"+p[1]+\"H\"+u[2]),\"\"===g&&(g=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}})}else u.remove()})}(t,e,r,s)}},{\"../../components/drawing\":614,\"../../lib\":719,\"../bar/plot\":867,d3:163}],1264:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\").styleTextPoints;e.exports={style:function(t,e,r){var l=r||n.select(t).selectAll(\"g.waterfalllayer\").selectAll(\"g.trace\");l.style(\"opacity\",function(t){return t[0].trace.opacity}),l.each(function(e){var r=n.select(this),l=e[0].trace;r.selectAll(\".point > path\").each(function(t){if(!t.isBlank){var e=l[t.dir].marker;n.select(this).call(a.fill,e.color).call(a.stroke,e.line.color).call(i.dashLine,e.line.dash,e.line.width).style(\"opacity\",l.selectedpoints&&!t.selected?o:1)}}),s(r,l,t),r.selectAll(\".lines\").each(function(){var t=l.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)})})}}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../constants/interactions\":694,\"../bar/style\":870,d3:163}],1265:[function(t,e,r){\"use strict\";var n=t(\"../plots/cartesian/axes\"),i=t(\"../lib\"),a=t(\"../plot_api/plot_schema\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/numerical\").BADNUM;r.moduleType=\"transform\",r.name=\"aggregate\";var l=r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},aggregations:{_isLinkedToArray:\"aggregation\",target:{valType:\"string\",editType:\"calc\"},func:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"median\",\"mode\",\"rms\",\"stddev\",\"min\",\"max\",\"first\",\"last\",\"change\",\"range\"],dflt:\"first\",editType:\"calc\"},funcmode:{valType:\"enumerated\",values:[\"sample\",\"population\"],dflt:\"sample\",editType:\"calc\"},enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},c=l.aggregations;function u(t,e,r,a){if(a.enabled){for(var o=a.target,l=i.nestedProperty(e,o),c=l.get(),u=function(t,e){var r=t.func,n=e.d2c,i=e.c2d;switch(r){case\"count\":return h;case\"first\":return f;case\"last\":return p;case\"sum\":return function(t,e){for(var r=0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r+=o)}return i(r)};case\"avg\":return function(t,e){for(var r=0,a=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l,a++)}return a?i(r/a):s};case\"min\":return function(t,e){for(var r=1/0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r=Math.min(r,o))}return r===1/0?s:i(r)};case\"max\":return function(t,e){for(var r=-1/0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r=Math.max(r,o))}return r===-1/0?s:i(r)};case\"range\":return function(t,e){for(var r=1/0,a=-1/0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r=Math.min(r,l),a=Math.max(a,l))}return a===-1/0||r===1/0?s:i(a-r)};case\"change\":return function(t,e){var r=n(t[e[0]]),a=n(t[e[e.length-1]]);return r===s||a===s?s:i(a-r)};case\"median\":return function(t,e){for(var r=[],a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&r.push(o)}if(!r.length)return s;r.sort();var l=(r.length-1)/2;return i((r[Math.floor(l)]+r[Math.ceil(l)])/2)};case\"mode\":return function(t,e){for(var r={},a=0,o=s,l=0;l<e.length;l++){var c=n(t[e[l]]);if(c!==s){var u=r[c]=(r[c]||0)+1;u>a&&(a=u,o=c)}}return a?i(o):s};case\"rms\":return function(t,e){for(var r=0,a=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l*l,a++)}return a?i(Math.sqrt(r/a)):s};case\"stddev\":return function(e,r){var i,a=0,o=0,l=1,c=s;for(i=0;i<r.length&&c===s;i++)c=n(e[r[i]]);if(c===s)return s;for(;i<r.length;i++){var u=n(e[r[i]]);if(u!==s){var h=u-c;a+=h,o+=h*h,l++}}var f=\"sample\"===t.funcmode?l-1:l;return f?Math.sqrt((o-a*a/l)/f):0}}}(a,n.getDataConversions(t,e,o,c)),d=new Array(r.length),g=0;g<r.length;g++)d[g]=u(c,r[g]);l.set(d),\"count\"===a.func&&i.pushUnique(e._arrayAttrs,o)}}function h(t,e){return e.length}function f(t,e){return t[e[0]]}function p(t,e){return t[e[e.length-1]]}r.supplyDefaults=function(t,e){var r,n={};function o(e,r){return i.coerce(t,n,l,e,r)}if(!o(\"enabled\"))return n;var s=a.findArrayAttributes(e),u={};for(r=0;r<s.length;r++)u[s[r]]=1;var h=o(\"groups\");if(!Array.isArray(h)){if(!u[h])return n.enabled=!1,n;u[h]=0}var f,p=t.aggregations||[],d=n.aggregations=new Array(p.length);function g(t,e){return i.coerce(p[r],f,c,t,e)}for(r=0;r<p.length;r++){f={_index:r};var v=g(\"target\"),m=g(\"func\");g(\"enabled\")&&v&&(u[v]||\"count\"===m&&void 0===u[v])?(\"stddev\"===m&&g(\"funcmode\"),u[v]=0,d[r]=f):d[r]={enabled:!1,_index:r}}for(r=0;r<s.length;r++)u[s[r]]&&d.push({target:s[r],func:c.func.dflt,enabled:!0,_index:-1});return n},r.calcTransform=function(t,e,r){if(r.enabled){var n=r.groups,a=i.getTargetArray(e,{target:n});if(a){var s,l,c,h,f={},p={},d=[],g=o(e.transforms,r),v=a.length;for(e._length&&(v=Math.min(v,e._length)),s=0;s<v;s++)void 0===(c=f[l=a[s]])?(f[l]=d.length,h=[s],d.push(h),p[f[l]]=g(s)):(d[c].push(s),p[f[l]]=(p[f[l]]||[]).concat(g(s)));r._indexToPoints=p;var m=r.aggregations;for(s=0;s<m.length;s++)u(t,e,d,m[s]);\"string\"==typeof n&&u(t,e,d,{target:n,func:\"first\",enabled:!0}),e._length=d.length}}}},{\"../constants/numerical\":695,\"../lib\":719,\"../plot_api/plot_schema\":756,\"../plots/cartesian/axes\":767,\"./helpers\":1268}],1266:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../registry\"),a=t(\"../plots/cartesian/axes\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/filter_ops\"),l=s.COMPARISON_OPS,c=s.INTERVAL_OPS,u=s.SET_OPS;r.moduleType=\"transform\",r.name=\"filter\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},operation:{valType:\"enumerated\",values:[].concat(l).concat(c).concat(u),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},preservegaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function a(i,a){return n.coerce(t,e,r.attributes,i,a)}if(a(\"enabled\")){var o=a(\"target\");if(n.isArrayOrTypedArray(o)&&0===o.length)return e.enabled=!1,e;a(\"preservegaps\"),a(\"operation\"),a(\"value\");var s=i.getComponentMethod(\"calendars\",\"handleDefaults\");s(t,e,\"valuecalendar\",null),s(t,e,\"targetcalendar\",null)}return e},r.calcTransform=function(t,e,r){if(r.enabled){var i=n.getTargetArray(e,r);if(i){var s=r.target,h=i.length;e._length&&(h=Math.min(h,e._length));var f=r.targetcalendar,p=e._arrayAttrs,d=r.preservegaps;if(\"string\"==typeof s){var g=n.nestedProperty(e,s+\"calendar\").get();g&&(f=g)}var v,m,y=function(t,e,r){var n=t.operation,i=t.value,a=Array.isArray(i);function o(t){return-1!==t.indexOf(n)}var s,h=function(r){return e(r,0,t.valuecalendar)},f=function(t){return e(t,0,r)};o(l)?s=h(a?i[0]:i):o(c)?s=a?[h(i[0]),h(i[1])]:[h(i),h(i)]:o(u)&&(s=a?i.map(h):[h(i)]);switch(n){case\"=\":return function(t){return f(t)===s};case\"!=\":return function(t){return f(t)!==s};case\"<\":return function(t){return f(t)<s};case\"<=\":return function(t){return f(t)<=s};case\">\":return function(t){return f(t)>s};case\">=\":return function(t){return f(t)>=s};case\"[]\":return function(t){var e=f(t);return e>=s[0]&&e<=s[1]};case\"()\":return function(t){var e=f(t);return e>s[0]&&e<s[1]};case\"[)\":return function(t){var e=f(t);return e>=s[0]&&e<s[1]};case\"(]\":return function(t){var e=f(t);return e>s[0]&&e<=s[1]};case\"][\":return function(t){var e=f(t);return e<=s[0]||e>=s[1]};case\")(\":return function(t){var e=f(t);return e<s[0]||e>s[1]};case\"](\":return function(t){var e=f(t);return e<=s[0]||e>s[1]};case\")[\":return function(t){var e=f(t);return e<s[0]||e>=s[1]};case\"{}\":return function(t){return-1!==s.indexOf(f(t))};case\"}{\":return function(t){return-1===s.indexOf(f(t))}}}(r,a.getDataToCoordFunc(t,e,s,i),f),x={},b={},_=0;d?(v=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set(new Array(h))},m=function(t,e){var r=x[t.astr][e];t.get()[e]=r}):(v=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set([])},m=function(t,e){var r=x[t.astr][e];t.get().push(r)}),T(v);for(var w=o(e.transforms,r),k=0;k<h;k++){y(i[k])?(T(m,k),b[_++]=w(k)):d&&_++}r._indexToPoints=b,e._length=_}}function T(t,r){for(var i=0;i<p.length;i++){t(n.nestedProperty(e,p[i]),r)}}}},{\"../constants/filter_ops\":691,\"../lib\":719,\"../plots/cartesian/axes\":767,\"../registry\":847,\"./helpers\":1268}],1267:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_schema\"),a=t(\"../plots/plots\"),o=t(\"./helpers\").pointsAccessorFunction;function s(t,e){var r,s,l,c,u,h,f,p,d,g,v=e.transform,m=e.transformIndex,y=t.transforms[m].groups,x=o(t.transforms,v);if(!Array.isArray(y)||0===y.length)return[t];var b=n.filterUnique(y),_=new Array(b.length),w=y.length,k=i.findArrayAttributes(t),T=v.styles||[],A={};for(r=0;r<T.length;r++)A[T[r].target]=T[r].value;v.styles&&(g=n.keyedContainer(v,\"styles\",\"target\",\"value.name\"));var M={},S={};for(r=0;r<b.length;r++){M[h=b[r]]=r,S[h]=0,(f=_[r]=n.extendDeepNoArrays({},t))._group=h,f.transforms[m]._indexToPoints={};var E=null;for(g&&(E=g.get(h)),f.name=E||\"\"===E?E:n.templateString(v.nameformat,{trace:t.name,group:h}),p=f.transforms,f.transforms=[],s=0;s<p.length;s++)f.transforms[s]=n.extendDeepNoArrays({},p[s]);for(s=0;s<k.length;s++)n.nestedProperty(f,k[s]).set([])}for(l=0;l<k.length;l++){for(c=k[l],s=0,d=[];s<b.length;s++)d[s]=n.nestedProperty(_[s],c).get();for(u=n.nestedProperty(t,c).get(),s=0;s<w;s++)d[M[y[s]]].push(u[s])}for(s=0;s<w;s++){(f=_[M[y[s]]]).transforms[m]._indexToPoints[S[y[s]]]=x(s),S[y[s]]++}for(r=0;r<b.length;r++)h=b[r],f=_[r],a.clearExpandedTraceDefaultColors(f),f=n.extendDeepNoArrays(f,A[h]||{});return _}r.moduleType=\"transform\",r.name=\"groupby\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"data_array\",dflt:[],editType:\"calc\"},nameformat:{valType:\"string\",editType:\"calc\"},styles:{_isLinkedToArray:\"style\",target:{valType:\"string\",editType:\"calc\"},value:{valType:\"any\",dflt:{},editType:\"calc\",_compareAsJSON:!0},editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t,e,i){var a,o={};function s(e,i){return n.coerce(t,o,r.attributes,e,i)}if(!s(\"enabled\"))return o;s(\"groups\"),s(\"nameformat\",i._dataLength>1?\"%{group} (%{trace})\":\"%{group}\");var l=t.styles,c=o.styles=[];if(l)for(a=0;a<l.length;a++){var u=c[a]={};n.coerce(l[a],c[a],r.attributes.styles,\"target\");var h=n.coerce(l[a],c[a],r.attributes.styles,\"value\");n.isPlainObject(h)?u.value=n.extendDeep({},h):h&&delete u.value}return o},r.transform=function(t,e){var r,n,i,a=[];for(n=0;n<t.length;n++)for(r=s(t[n],e),i=0;i<r.length;i++)a.push(r[i]);return a}},{\"../lib\":719,\"../plot_api/plot_schema\":756,\"../plots/plots\":828,\"./helpers\":1268}],1268:[function(t,e,r){\"use strict\";r.pointsAccessorFunction=function(t,e){for(var r,n,i=0;i<t.length&&(r=t[i])!==e;i++)r._indexToPoints&&!1!==r.enabled&&(n=r._indexToPoints);return n?function(t){return n[t]}:function(t){return[t]}}},{}],1269:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/cartesian/axes\"),a=t(\"./helpers\").pointsAccessorFunction;r.moduleType=\"transform\",r.name=\"sort\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},order:{valType:\"enumerated\",values:[\"ascending\",\"descending\"],dflt:\"ascending\",editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function i(i,a){return n.coerce(t,e,r.attributes,i,a)}return i(\"enabled\")&&(i(\"target\"),i(\"order\")),e},r.calcTransform=function(t,e,r){if(r.enabled){var o=n.getTargetArray(e,r);if(o){var s=r.target,l=o.length;e._length&&(l=Math.min(l,e._length));var c,u,h=e._arrayAttrs,f=function(t,e,r,n){var i,a=new Array(n),o=new Array(n);for(i=0;i<n;i++)a[i]={v:e[i],i:i};for(a.sort(function(t,e){switch(t.order){case\"ascending\":return function(t,r){return e(t.v)-e(r.v)};case\"descending\":return function(t,r){return e(r.v)-e(t.v)}}}(t,r)),i=0;i<n;i++)o[i]=a[i].i;return o}(r,o,i.getDataToCoordFunc(t,e,s,o),l),p=a(e.transforms,r),d={};for(c=0;c<h.length;c++){var g=n.nestedProperty(e,h[c]),v=g.get(),m=new Array(l);for(u=0;u<l;u++)m[u]=v[f[u]];g.set(m)}for(u=0;u<l;u++)d[u]=p(f[u]);r._indexToPoints=d,e._length=l}}}},{\"../lib\":719,\"../plots/cartesian/axes\":767,\"./helpers\":1268}]},{},[25])(25)});</script>    \n",
       "            <div id=\"c5b7937a-b3d6-4087-aac6-b88109b5a110\" class=\"plotly-graph-div\" style=\"height:500px; width:500px;\"></div>\n",
       "            <script type=\"text/javascript\">\n",
       "                \n",
       "                    window.PLOTLYENV=window.PLOTLYENV || {};\n",
       "                    \n",
       "                if (document.getElementById(\"c5b7937a-b3d6-4087-aac6-b88109b5a110\")) {\n",
       "                    Plotly.newPlot(\n",
       "                        'c5b7937a-b3d6-4087-aac6-b88109b5a110',\n",
       "                        [{\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha = 0.8\", \"showscale\": false, \"type\": \"surface\", \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.10000000000000002, 0.17411011265922485, 0.24082246852806927, 0.30314331330207966, 0.36238983183884776, 0.4192962712629476, 0.47432763938033673, 0.5278031643091579, 0.5799546134795289, 0.6309573444801934, 0.6809483127522303, 0.7300372102718471, 0.7783137122039473, 0.8258523872989461, 0.8727161387290322, 0.9189586839976283, 0.9646263856416865, 1.0097596309015797, 1.0543938903738734, 1.0985605433061179, 1.142287530066645, 1.1855998744839988, 1.228520106741704, 1.271068609258575, 1.313263902201884, 1.3551228811604874, 1.396661016523824, 1.4378925219250929, 1.4788304974808697, 1.519487052336355, 1.5598734100953937, 1.6000000000000005, 1.6398765361701582, 1.679512086781349, 1.7189151347155787, 1.7580936309501134, 1.797055041730823, 1.8358063904019344, 1.8743542946219982, 1.9127049995800744, 1.9508644077311328, 1.9888381054913127, 2.026631387268768, 2.0642492771517187, 2.1016965485301045, 2.13897774188921, 2.1760971809815493, 2.2130589875561473, 2.249867094801228, 2.2865252596366323, 2.323037073975402, 2.3594059750594583, 2.395635254961836, 2.4317280693371046, 2.4676874454922784, 2.503516289842348, 2.539217394807506, 2.5747934452029178, 2.61024702416647, 2.6455806186651625, 2.680796624616603, 2.715897351658382, 2.750885027594806, 2.785761802547598, 2.820529752834578, 2.855190884598056, 2.889747137202636, 2.924200386420304, 2.9585524474190423, 2.99280507756976, 3.026959979085028, 3.061018801501899, 3.094983144020095, 3.128854557705816, 3.1626345475706255, 3.1963245745340574, 3.229926057277886, 3.26344037399938, 3.296868864070247, 3.3302128296074938, 3.3634735369618975, 3.3966522181293946, 3.4297500720902443, 3.462768266080517, 3.4957079368000623, 3.5285701915608625, 3.5613561093793575, 3.5940667420160914, 3.626703114965799, 3.659266228400805, 3.69175705807045, 3.7241765561590467, 3.7565256521046995, 3.788805253381191, 3.821016246244965, 3.8531594964491087, 3.885235849926139, 3.917246133441246, 3.9491911552175707, 3.9810717055349736, 4.012888557303689], [0.0, 0.11486983549970352, 0.2, 0.2766323734445184, 0.3482202253184497, 0.4162766037009366, 0.4816449370561385, 0.5448593790858196, 0.6062866266041593, 0.6661929104768761, 0.7247796636776956, 0.7822042066964935, 0.8385925425258952, 0.89404768088031, 0.9486552787606736, 1.0024875929374035, 1.0556063286183157, 1.1080647423733407, 1.1599092269590578, 1.2111805273913923, 1.2619146889603867, 1.3121438067211815, 1.3618966255044607, 1.4111990256949771, 1.4600744205436942, 1.508544084136291, 1.5566274244078944, 1.6043422121694033, 1.6517047745978921, 1.698730159775722, 1.7454322774580646, 1.791824020180194, 1.8379173679952565, 1.8837234794968964, 1.929252771283373, 1.9745149876272918, 2.01951926180316, 2.0642741702753247, 2.108787780747747, 2.153067694913917, 2.197121086612236, 2.240954735983017, 2.28457506013329, 2.3279881407409926, 2.3711997489679977, 2.414215367999477, 2.457040213483408, 2.4996792521071907, 2.54213721851715, 2.5844186307601285, 2.626527804403768, 2.66846886547267, 2.7102457623209752, 2.751862276547563, 2.793322033047648, 2.8346285092838155, 2.8757850438501857, 2.916794844395239, 2.95766099496174, 2.9983864627959296, 3.03897410467271, 3.0794266727786956, 3.119746820190787, 3.1599371059841266, 3.200000000000001, 3.239937887301273, 3.279753072340316, 3.3194477828620594, 3.3590241735626973, 3.3984843295227054, 3.437830269431157, 3.4770639486168307, 3.516187261900227, 3.555202046279435, 3.5941100834616466, 3.632913102251169, 3.671612780803869, 3.7102107487571665, 3.7487085892439964, 3.787107840798436, 3.825409999160149, 3.8636165189841907, 3.9017288154622656, 3.939748265861026, 3.977676210982625, 4.015513956552311, 4.053262774537536, 4.090923904402708, 4.128498554303437, 4.165987902223836, 4.203393097060209, 4.24071525965422, 4.27795548377842, 4.315114837076832, 4.3521943619630985, 4.389195076478536, 4.4261179751122945, 4.462964029585662, 4.499734189602456, 4.536429383567264, 4.573050519273265, 4.609598484561173], [0.0, 0.12457309396155174, 0.21689435423953973, 0.30000000000000004, 0.37763500451796084, 0.4514402257237171, 0.5223303379776745, 0.590884615890877, 0.6575007318068904, 0.7224674055842076, 0.7860030855966228, 0.8482783814744369, 0.9094299399062389, 0.9695694720194644, 1.028789870413634, 1.0871694955165432, 1.1447752648842044, 1.2016649337633383, 1.2578888137888427, 1.3134910917803058, 1.3685108578372633, 1.42298291814101, 1.4769384456489911, 1.5304055069078983, 1.5834094929274731, 1.6359734748530934, 1.6881185000425407, 1.7398638404385867, 1.7912272024038713, 1.8422249051589266, 1.89287203344058, 1.9431825688393956, 1.993169503384828, 2.0428449382566907, 2.0922201699617475, 2.141305765888571, 2.190111630815541, 2.238647065676141, 2.2869208196675728, 2.3349411366118416, 2.3827157963341836, 2.4302521517053735, 2.4775571618968377, 2.524637422316621, 2.571499191626862, 2.6181484161870965, 2.6645907522203225, 2.7108315859588235, 2.7568760519928843, 2.802729050016767, 2.848395260141756, 2.8938791569250593, 2.9391850222452844, 2.984316957139667, 3.0292788927047387, 3.074074600150511, 3.118707700088062, 3.16318167112162, 3.2074998578085054, 3.251665478043504, 3.2956816299183536, 3.3395512981017474, 3.3832773597806907, 3.4268625901999354, 3.470309667832636, 3.5136211792121412, 3.5567996234519956, 3.5998474164786907, 3.642766894999424, 3.685560320225111, 3.728229881367068, 3.770777698924158, 3.813205827775725, 3.8555162600943405, 3.8977109280911595, 3.939791706605651, 3.9817604155504793, 4.023618822221423, 4.065368643481462, 4.107011547827371, 4.148549157346593, 4.189983049571472, 4.231314759237462, 4.2725457799513675, 4.3136775657752775, 4.354711532731363, 4.395649060232419, 4.4364914924426095, 4.4772401395725865, 4.517896279112868, 4.558461157009065, 4.598935988782319, 4.639321960598091, 4.67962023028618, 4.7198319283147585, 4.759958158720896, 4.800000000000001, 4.839958505956381, 4.879834706517015, 4.9196296085104745, 4.959344196412832, 4.998979433062281], [0.0, 0.13195079107728944, 0.229739670999407, 0.3177671523146437, 0.4000000000000001, 0.4781762498950185, 0.5532647468890367, 0.6258790724605869, 0.6964404506368994, 0.7652547003754746, 0.8325532074018732, 0.8985166855040227, 0.963289874112277, 1.026991100316126, 1.0897187581716392, 1.1515558489121325, 1.2125732532083187, 1.2728321467944699, 1.3323858209537522, 1.3912810794189336, 1.4495593273553913, 1.5072574323001684, 1.564408413392987, 1.6210419993892387, 1.6771850850517904, 1.732862107887866, 1.7880953617606197, 1.8429052599712976, 1.8973105575213471, 1.9513285401182223, 2.004975185874807, 2.058265304425163, 2.1112126572366314, 2.163830062167376, 2.2161294847466815, 2.268122118204461, 2.3198184539181157, 2.3712283436581343, 2.4223610547827845, 2.4732253193448748, 2.5238293779207734, 2.5741810188465064, 2.624287613442363, 2.6741561477217837, 2.723793251008921, 2.773205221829561, 2.8223980513899543, 2.8713774449157485, 2.9201488410873884, 2.9687174297778487, 3.017088168272582, 3.06526579612926, 3.113254848815789, 3.161059670248582, 3.2086844243388066, 3.2561331056420166, 3.3034095491957842, 3.3505174396206434, 3.397460319551444, 3.4442415974590626, 3.4908645549161292, 3.53733235335488, 3.5836480403603876, 3.6298145555380574, 3.675834735990513, 3.7217113214355413, 3.7674469589937924, 3.813044207672202, 3.8585055425667454, 3.903833358805933, 3.9490299752545837, 3.9940976379956483, 4.039038523606319, 4.083854742243279, 4.128548340550649, 4.173121304403093, 4.217575561495494, 4.261912983789674, 4.306135389827834, 4.3502445469215365, 4.394242173224472, 4.438129939696511, 4.481909471966034, 4.525582352096982, 4.56915012026658, 4.612614276359275, 4.655976281481985, 4.6992375594054385, 4.742399497935995, 4.785463450222069, 4.828430735998954, 4.871302642775626, 4.914080426966816, 4.956765314973456, 4.999358504214381, 5.04186116411198, 5.0842744370343, 5.1265994391959895, 5.168837261520257, 5.210988970463929, 5.253055608807536, 5.295038196412244], [0.0, 0.13797296614612148, 0.24022488679628623, 0.332269902974487, 0.4182558210365093, 0.49999999999999994, 0.5785155024015763, 0.654443913303929, 0.7282256812104322, 0.8001805825189799, 0.8705505632961241, 0.93952458502622, 1.007253992982465, 1.0738625146497733, 1.1394530347449108, 1.204112342640346, 1.267914553968891, 1.330923636497959, 1.3931953137010376, 1.4547785254123173, 1.515716566510398, 1.5760479871502193, 1.6358073134502662, 1.6950256309730263, 1.7537310619463105, 1.811949159194239, 1.869703234061905, 1.9270146315044916, 1.9839029624933204, 2.0403863016478, 2.096481356314738, 2.1522036120332677, 2.207567458337944, 2.2625862980882414, 2.3172726429148485, 2.3716381969016833, 2.4256939302479177, 2.4794501443544372, 2.5329165295375953, 2.586102216377183, 2.639015821545789, 2.691665488835609, 2.744058925990692, 2.7962034378630087, 2.8481059563360973, 2.899773067397644, 2.951211035689873, 3.0024258268223765, 3.0534231276945416, 3.1042083650428243, 3.1547867224009662, 3.205163155637932, 3.2553424072183534, 3.305329019313044, 3.3551273458722166, 3.4047415637611507, 3.454175683046819, 3.5034335565141874, 3.552518888482376, 3.6014352429833463, 3.650186051359235, 3.698774619328632, 3.7472041335670285, 3.795477667842105, 3.8435981887405806, 3.8915685610197355, 3.9393915526136216, 3.9870698393211073, 4.03460600920044, 4.082002566692723, 4.129261936494729, 4.17638646719963, 4.223378434722628, 4.270240045527012, 4.316973439664824, 4.363580693645161, 4.4100638231420355, 4.456424785552773, 4.502665482417024, 4.548787761705661, 4.59479341998814, 4.640684204486193, 4.686461815021153, 4.732127905861649, 4.777684087477908, 4.823131928208431, 4.868472955844402, 4.913708659136809, 4.958840489230872, 5.003869861032094, 5.048798154507899, 5.0936267159285915, 5.138356859051114, 5.182989866248785, 5.227526989590102, 5.271969451869366, 5.316318447591793, 5.3605751439155656, 5.404740681553142, 5.4488161756339615, 5.49280271653059, 5.5367013706502], [0.0, 0.14309690811052556, 0.24914618792310347, 0.34460950649911054, 0.43378870847907947, 0.518568644668324, 0.6000000000000001, 0.6787481862669054, 0.7552700090359217, 0.829897120333555, 0.9028804514474343, 0.9744159813792331, 1.0446606759553492, 1.1137428575641026, 1.1817692317817543, 1.2488298111028098, 1.3150014636137808, 1.3803505326715677, 1.4449348111684155, 1.508805056431297, 1.5720061711932456, 1.634578137257459, 1.696556762948874, 1.7579742882635063, 1.818859879812478, 1.8792400393825317, 1.9391389440389288, 1.9985787314306283, 2.0575797408272685, 2.1161607180906277, 2.174338991033087, 2.2321306202847264, 2.2895505297684093, 2.34661262008948, 2.4033298675266765, 2.4597144108218676, 2.5157776275776857, 2.571530201761122, 2.626982183560612, 2.68214304264093, 2.737021715674527, 2.791626648891967, 2.8459658362820206, 2.9000468539790574, 2.9538768912979823, 3.00746277881221, 3.0608110138157967, 3.113927783464904, 3.1668189858549467, 3.2194902492566633, 3.271946949706187, 3.324194227120022, 3.3762370000850823, 3.428079979456092, 3.4797276808771733, 3.5311844363310607, 3.582454404807743, 3.6335415821741774, 3.684449810317854, 3.7351827856292203, 3.78574406688116, 3.8361370825576904, 3.886365137678791, 3.936431420163544, 3.9863390067696565, 4.036090868643729, 4.085689876513381, 4.135138805549398, 4.184440339923495, 4.233597077084931, 4.282611531777142, 4.331486139813685, 4.380223261631082, 4.42882518563469, 4.477294131352282, 4.525632252408872, 4.573841639335146, 4.621924322220857, 4.669882273223683, 4.717717408943129, 4.765431592668367, 4.8130266365082095, 4.860504303410747, 4.907866309079661, 4.9551143237936754, 5.002249974135133, 5.049274844633242, 5.096190479327166, 5.142998383253725, 5.189700023864177, 5.236296832374194, 5.282790205050913, 5.329181504440646, 5.375472060540582, 5.421663171917647, 5.46775610677741, 5.5137521039857695, 5.559652374046003, 5.605458100033535, 5.651170438490689, 5.696790520283513, 5.742319451422653], [0.0, 0.1475773161594552, 0.25694703142468783, 0.35539933576267324, 0.4473707658880579, 0.5348051878625344, 0.6187861838865271, 0.7, 0.7789177444921346, 0.8558814535160307, 0.9311499150948377, 1.0049252443928347, 1.0773693218845504, 1.1486144877716113, 1.218770788614574, 1.2879310552267333, 1.3561745624579484, 1.423569730895957, 1.490176162946172, 1.5560462051630304, 1.6212261661978982, 1.6857572796964846, 1.749676475153355, 1.8130170020086807, 1.8758089400891171, 1.9380796209604725, 1.9998539786793306, 2.061154844031224, 2.1220031931145575, 2.182418358729787, 2.242418211228409, 2.3020193141037537, 2.361237058551284, 2.4200857804085567, 2.478578862245574, 2.5367288228719342, 2.594547396126494, 2.652045600494526, 2.7092338008389447, 2.7661217633226323, 2.8227187044279924, 2.8790333348396566, 2.935073898840633, 2.9908482097763818, 3.0463636820614597, 3.1016273601366295, 3.1566459447282145, 3.2114258167141325, 3.265973058860973, 3.320293475662357, 3.3743926114797564, 3.428275767162036, 3.481948015298573, 3.5354142142423988, 3.5886790210238346, 3.641746903261323, 3.6946221501641046, 3.7473088827109544, 3.799811063080038, 3.8521325033969216, 3.904276873860757, 3.956247710302447, 4.008048421223161, 4.059682294356702, 4.111152502795006, 4.162462110712185, 4.2136140787192184, 4.2646112688783395, 4.315456449403502, 4.366152299070899, 4.416701411361353, 4.46710629835449, 4.517369394392824, 4.5674930595323815, 4.617479582795036, 4.667331185236456, 4.7170500228424865, 4.766638189265612, 4.816097718412371, 4.865430586891587, 4.914638716332589, 4.963723975581869, 5.012688182785964, 5.0615331073677625, 5.1102604719029285, 5.158871953902596, 5.207369187508068, 5.255753765102846, 5.304027238846918, 5.352191122137887, 5.400246891003228, 5.448195985427629, 5.496039810619147, 5.543779738217587, 5.591417107448407, 5.6389532262250786, 5.686389372202773, 5.733726793785993, 5.7809667110926215, 5.828110316876675, 5.875158777411963, 5.922113233338664], [0.0, 0.1515716566510398, 0.2639015821545789, 0.3650186051359235, 0.459479341998814, 0.5492802716530588, 0.6355343046292874, 0.7189462609625462, 0.8, 0.8790468154750565, 0.956352499790037, 1.0321246385758591, 1.1065294937780734, 1.179702987529729, 1.2517581449211739, 1.3227903093325808, 1.3928809012737988, 1.4621001932101518, 1.5305094007509492, 1.598162287267028, 1.6651064148037462, 1.7313841330402582, 1.7970333710080455, 1.862088278079523, 1.9265797482245537, 1.9905358527674863, 2.053982200632252, 2.1169422405444127, 2.1794375163432784, 2.2414878840925674, 2.3031116978242654, 2.3643259693406558, 2.4251465064166373, 2.4855880329047966, 2.5456642935889393, 2.605388146113855, 2.6647716419075045, 2.723826097682443, 2.7825621588378673, 2.840989855868474, 2.8991186547107826, 2.9569575018135734, 3.014514864600337, 3.0717987678932213, 3.1288168267859735, 3.1855762763848037, 3.2420839987784773, 3.2983465475503095, 3.354370170103581, 3.4101608280368407, 3.465724215775732, 3.5210657776423573, 3.57619072352124, 3.6311040432620154, 3.6858105199425952, 3.740314742102371, 3.794621115042694, 3.8487338712811106, 3.9026570802364446, 3.956394657213585, 4.009950371749614, 4.063327855376541, 4.116530608850325, 4.1695620088908605, 4.222425314473262, 4.275123672706847, 4.327660124334751, 4.380037608884031, 4.432258969493362, 4.484326957442925, 4.536244236408922, 4.588013386463144, 4.639636907836231, 4.691117224461695, 4.7424566873162695, 4.793657577570913, 4.84472210956557, 4.895652433619704, 4.946450638689749, 4.99711875488359, 5.047658755841547, 5.098072560992471, 5.148362037693013, 5.1985290032574145, 5.248575226884725, 5.298502431489737, 5.348312295443567, 5.398006454229308, 5.447586502017842, 5.497053993168526, 5.546410443659122, 5.59565733244907, 5.6447961027799085, 5.693828163416368, 5.742754889831497, 5.791577625338867, 5.840297682174777, 5.888916342533155, 5.937434859555697, 5.985854458279608, 6.034176336545164, 6.082401665865211], [0.0, 0.15518455739153597, 0.27019200770412266, 0.3737192818846552, 0.47043160900986947, 0.5623730565710473, 0.6506830627186192, 0.7360832477580963, 0.8190690044316878, 0.9, 0.9791483623609768, 1.0567266252096805, 1.1329050135538825, 1.2078226894013284, 1.2815953719373026, 1.3543206771711513, 1.4260819663728028, 1.4969511870400218, 1.5669910139330236, 1.636256491940092, 1.7047963168076516, 1.7726538476726315, 1.8398679176525994, 1.9064734901131382, 1.972502195420671, 2.037982774014807, 2.102941445240332, 2.167402216752623, 2.2313871459154493, 2.294916562086737, 2.3580092567898685, 2.420682647324795, 2.482952918264576, 2.544835144423311, 2.606343398208985, 2.667490843744494, 2.728289819718717, 2.7887519125922595, 2.8488880215107746, 2.9087084160583934, 2.968222787804118, 3.0274402964465676, 3.0863696112409023, 3.145018948290982, 3.2033961042058743, 3.26150848654963, 3.3193631414542404, 3.376966778715908, 3.434325794652614, 3.4914462929650933, 3.548334103812776, 3.604994801290015, 3.661433719465473, 3.7176559671281186, 3.773666441366528, 3.829469840093692, 3.88507067361685, 3.940473275340918, 3.9956818116844275, 4.050700291278474, 4.10553257351179, 4.16018237647851, 4.214653284379506, 4.268948754423031, 4.3230721232659635, 4.377026613032922, 4.4308153369469725, 4.484441304602492, 4.537907426907933, 4.591216520723695, 4.644371313218046, 4.697374445962029, 4.75022847878242, 4.802935893390228, 4.855499096800671, 4.90792042455928, 4.960202143787571, 5.012346456060575, 5.064355500127623, 5.1162313544867715, 5.167976039822534, 5.21959152131576, 5.271079710833889, 5.322442469009131, 5.373681607211614, 5.42479888942397, 5.475796034023396, 5.526674715476781, 5.577436565954067, 5.628083176864722, 5.67861610032174, 5.729036850537416, 5.779346905154763, 5.829547706518187, 5.879640662886863, 5.92962714959393, 5.979508510154484, 6.029286057325158, 6.078961074117854, 6.128534814770072, 6.1780085056741205, 6.227383346267322], [0.0, 0.15848931924611134, 0.27594593229224296, 0.38167789096181765, 0.4804497735925725, 0.5743491774985174, 0.664539805948974, 0.7517586466500455, 0.8365116420730186, 0.9191661188401216, 1.0, 1.079230345298891, 1.1570310048031527, 1.233544104071174, 1.3088878266078583, 1.3831618672225916, 1.4564513624208644, 1.5288297918718774, 1.60036116503796, 1.6711016990261411, 1.7411011265922482, 1.810403730235845, 1.87904917005244, 1.9470731539765267, 2.01450798596493, 2.081383018504683, 2.1477250292995467, 2.213558537264427, 2.2789060694898216, 2.343788388261312, 2.4082246852806923, 2.4722327487612916, 2.535829107937782, 2.5990291586527943, 2.661847272995918, 2.724296895429098, 2.7863906274020755, 2.8481403021171032, 2.9095570508246347, 2.970651361806657, 3.0314331330207964, 3.091911719227754, 3.1520959743004386, 3.211994289310292, 3.2716146269005324, 3.3309645523843803, 3.390051261946053, 3.4488816082714764, 3.5074621238926214, 3.5657990424927277, 3.623898318388478, 3.681765644378398, 3.7394064681238106, 3.796826007208857, 3.854029263008983, 3.9110210334824664, 3.967805924986641, 4.024388363209259, 4.080772603295601, 4.136962739243317, 4.192962712629476, 4.248776320727584, 4.304407224066535, 4.359858953478209, 4.415134916675888, 4.470238404401549, 4.525172596176483, 4.5799405656864485, 4.634545285829697, 4.688989633453605, 4.743276393803367, 4.797408264704094, 4.851387860495835, 4.905217715739342, 4.958900288708875, 5.012437964687017, 5.065833059075191, 5.119087820332485, 5.172204432754366, 5.2251850191019376, 5.278031643091578, 5.330746311754014, 5.383330977671218, 5.435787541098841, 5.488117851981384, 5.540323711866702, 5.5924068757260175, 5.644369053685139, 5.6962119126721955, 5.747937077986809, 5.799546134795289, 5.851040629556123, 5.902422071379746, 5.953691933326282, 6.004851653644753, 6.0559026369569615, 6.106846255389083, 6.157683849653805, 6.2084167300856485, 6.2590461776319675, 6.309573444801933, 6.359999756575714], [0.0, 0.16153942662021778, 0.281256477677527, 0.38902323483289747, 0.48969597014570987, 0.585402456482446, 0.6773287924381185, 0.7662261489562102, 0.8526102053083794, 0.9368553572723312, 1.0192448764914566, 1.1, 1.1792979235873753, 1.2572835080007883, 1.3340772111720975, 1.409780646524983, 1.4844805890064676, 1.558251932392911, 1.6311599180008391, 1.7032618448285624, 1.7746084027326519, 1.8452447264239062, 1.9152112392514733, 1.9845443363446358, 2.053276943345878, 2.1214389776272204, 2.1890577322260265, 2.25615819792069, 2.322763335332784, 2.388894306315511, 2.454570671912596, 2.519810562669337, 2.584630825923485, 2.6490471538087617, 2.7130741950038453, 2.7767256527076896, 2.8400143708833805, 2.902952410461687, 2.9655511169126014, 3.0278211803638033, 3.0897726892578907, 3.151415178386779, 3.212757672015068, 3.273808722699332, 3.3345764463228758, 3.3950685537924374, 3.4552923797819113, 3.515254908856317, 3.5749627992653967, 3.6344224046588542, 3.6936397939434613, 3.7526207694749485, 3.8113708837542073, 3.8698954547771414, 3.9281995801700504, 3.9862881502273253, 4.044165859955078, 4.101837220212876, 4.159306568035744, 4.216578076209812, 4.273655762167313, 4.330543496259812, 4.387245009462629, 4.443763900558069, 4.500103642840433, 4.556267590381623, 4.612258983892423, 4.668080956211296, 4.723736537449552, 4.7792286598191405, 4.834560162166954, 4.889733794237418, 4.944752220683229, 4.999618024842451, 5.054333712298526, 5.108901714238506, 5.163324390623431, 5.2176040331837035, 5.271742868251288, 5.325743059439564, 5.379606710180875, 5.433335866131007, 5.486932517449133, 5.540398600961086, 5.593736002213324, 5.646946557424266, 5.700032055339337, 5.752994238995509, 5.8058348074007355, 5.85855541713333, 5.9111576838659285, 5.963643183818425, 6.016013455143897, 6.068269999251328, 6.120414282068665, 6.172447735249484, 6.22437175732636, 6.276187714813829, 6.32789694326364, 6.379500748274818, 6.431000406460921, 6.482397166376708], [0.0, 0.16437518295172257, 0.2861938162210511, 0.39585237323186834, 0.498292375846207, 0.5956789490835458, 0.6892190129982211, 0.7796769250220154, 0.867577416958159, 0.9533014569439311, 1.0371372893366482, 1.1193100348931466, 1.2000000000000002, 1.2793545883735817, 1.357496372533811, 1.4345287496850556, 1.5105400180718433, 1.585606386199111, 1.6597942406671102, 1.7331618863338394, 1.8057609028948687, 1.8776372173817608, 1.9488319627584663, 2.019382173055373, 2.0893213519106983, 2.1586799418832774, 2.2274857151282053, 2.295764101126424, 2.3635384635635086, 2.4308303357800485, 2.49765962220562, 2.5640447716595767, 2.6300029272275616, 2.6955500565120682, 2.7607010653431354, 2.8254698974735803, 2.889869622336831, 2.9539125125881944, 3.017610112862594, 3.0809733009483784, 3.1440123423864916, 3.2067369393480885, 3.269156274514918, 3.33127905058007, 3.3931135258977476, 3.4546675467363976, 3.5159485765270126, 3.5769637224456985, 3.637719759624956, 3.6982231532501233, 3.7584800787650634, 3.8184964403834094, 3.878277888077858, 3.937829833199483, 3.9971574628612565, 4.056265753204621, 4.115159481654537, 4.173843238256802, 4.232321436181256, 4.290598321465528, 4.348677982066174, 4.406564356277144, 4.464261240569453, 4.521772296900505, 4.579101059536819, 4.636250941429606, 4.69322524017896, 4.750027143618998, 4.806659735053353, 4.863125998167716, 4.919428821643735, 4.975571003496437, 5.0315552551553715, 5.087384205308006, 5.143060403522245, 5.198586323663599, 5.253964367121224, 5.309196865855884, 5.36428608528186, 5.419234226993845, 5.474043431349054, 5.528715779913893, 5.583253297783934, 5.637657955785175, 5.69193167256404, 5.746076316572989, 5.800093707958116, 5.853985620354667, 5.9077537825959645, 5.961399880340854, 6.014925557624421, 6.068332418336433, 6.121622027631594, 6.174795913275489, 6.227855566929809, 6.2808024453802025, 6.333637971709894, 6.386363536422004, 6.4389804985133265, 6.491490186502127, 6.5438938994123745, 6.596192907716678], [0.0, 0.16702776523348103, 0.2908122302201994, 0.40224038736253726, 0.5063335016631935, 0.6052916375537973, 0.7003411915978159, 0.7922588559417013, 0.8815778301771843, 0.9686852302633299, 1.0538739520617835, 1.1373727491851455, 1.2193648376899149, 1.3000000000000003, 1.379402786632782, 1.4576782633510283, 1.5349161533002453, 1.6111938947898092, 1.686578945724755, 1.7611305518498404, 1.8349011252209961, 1.907937334011045, 1.9802809749615793, 2.051969679734644, 2.123037492628885, 2.1935153474658144, 2.263431464569923, 2.3328116837869626, 2.4016797458308234, 2.4700575315334667, 2.537965266529508, 2.605421697353629, 2.672444243735697, 2.7390491309532323, 2.8052515053770892, 2.8710655357755104, 2.9365045024881375, 3.0015808762185934, 3.0663063879017853, 3.1306920908649003, 3.194748416307661, 3.2584852229686962, 3.321911841714041, 3.385037115675317, 3.4478694364748015, 3.5104167769990364, 3.572686721119123, 3.6346864907022605, 3.6964229702137334, 3.7579027291699343, 3.8191320426701165, 3.8801169102063615, 3.9408630729270357, 4.00137602950816, 4.06166105076904, 4.121723193152928, 4.1815673111798315, 4.241198068966794, 4.300619950900587, 4.359837271538695, 4.418854184806522, 4.477674692551703, 4.53630265251029, 4.594741785734032, 4.652995683523192, 4.7110678139050215, 4.768961527694191, 4.826680064168058, 4.8842265563866505, 4.941604036184485, 4.9988154388589185, 5.0558636075775665, 5.112751297525306, 5.1694811798096945, 5.226055845141942, 5.2824778073092284, 5.338749506452806, 5.394873312165137, 5.450851526418319, 5.506686386334985, 5.56238006681207, 5.617934683006979, 5.67335229269499, 5.72863489850604, 5.783784450048447, 5.838802845926572, 5.893691935658869, 5.948453521502387, 6.003089360189257, 6.057601164580419, 6.111990605241352, 6.166259311944377, 6.220408875101671, 6.274440847132929, 6.328356743771332, 6.382158045311209, 6.435846197800597, 6.489422614181672, 6.542888675381858, 6.596245731358201, 6.649495102097495, 6.702638078574429], [0.0, 0.16952182030724353, 0.29515463231891037, 0.4082466323576216, 0.5138940628493757, 0.6143298395415735, 0.7107986715253464, 0.8040888484979244, 0.8947415317761157, 0.9831496177263357, 1.0696103757250688, 1.1543559751290424, 1.237572367773054, 1.3194115726290119, 1.4, 1.4794442844885438, 1.5578354889842692, 1.6352522081037575, 1.7117629070320612, 1.7874277161701517, 1.8622998301896752, 1.9364266141116284, 2.009850488785669, 2.0826096477890275, 2.1547386437691007, 2.2262688724505715, 2.2972289755432227, 2.3676451787328374, 2.4375415772291475, 2.506940378588235, 2.5758621104534667, 2.6443257992823845, 2.712349124915897, 2.779948554907025, 2.847139461791914, 2.9139362259065558, 2.980352325892344, 3.046400418665186, 3.1120924103260608, 3.1774395192502056, 3.2424523323957963, 3.3071408557119413, 3.3715145593929687, 3.4355824186159567, 3.4993529503067093, 3.5628342464027427, 3.6260340040173613, 3.6889595528545334, 3.7516178801782343, 3.814015653600737, 3.876159241920945, 3.9380547342152283, 3.9997079573586616, 4.061124492133378, 4.122309688062448, 4.183268677091828, 4.244006386229115, 4.30452754923585, 4.364836717459575, 4.424938269882654, 4.484836422456818, 4.544535236785207, 4.604038628207507, 4.663350373338132, 4.722474117102567, 4.781413379312573, 4.8401715608171125, 4.898751949262366, 4.957157724491148, 5.015391963609264, 5.0734576457438685, 5.1313576565166965, 5.189094792252988, 5.246671763945221, 5.304091200989053, 5.361355654707479, 5.41846760167789, 5.475429446875452, 5.532243526645264, 5.588912111514624, 5.645437408855985, 5.701821565410236, 5.758066669679313, 5.814174754196379, 5.870147797681265, 5.925987727088251, 5.9816964195527635, 6.037275704243113, 6.092727364122919, 6.1480531376295255, 6.203254720273259, 6.258333766162168, 6.313291889456429, 6.368130665756436, 6.422851633428265, 6.47745629486997, 6.531946117721946, 6.586322536024394, 6.640586951324713, 6.6947407337374845, 6.748785222959513, 6.802721729242296], [0.0, 0.17187719275874785, 0.2992555739477689, 0.41391889843836444, 0.5210342169394704, 0.6228654698077586, 0.7206746603888587, 0.8152610310457598, 0.9071732621064218, 0.9968097089234609, 1.0844717711976986, 1.1703948440965921, 1.2547674631095278, 1.3377437593925443, 1.4194518996205303, 1.4999999999999998, 1.579480388667856, 1.6579727522511036, 1.735546507204729, 1.8122626193943627, 1.8881750225898037, 1.9633317399117873, 2.0377757816143354, 2.111545871944413, 2.184677043631296, 2.257201128618586, 2.3291471665701082, 2.40054174755694, 2.4714093015728125, 2.541772344730344, 2.6116516898883724, 2.681066627862113, 2.750035084139966, 2.8185737550786603, 2.8866982268036474, 2.954423079454385, 3.0217619789473953, 3.0887277580564834, 3.155332488308544, 3.2215875439493202, 3.2875036590344515, 3.3530909785378435, 3.418359104234732, 3.4833171360052253, 3.547973709111118, 3.612337027921038, 3.6764148964936294, 3.740214746373335, 3.8037436619066725, 3.867008403347146, 3.930015427983114, 3.9927709094938773, 4.055280755714359, 4.117550624967275, 4.179585941103113, 4.241391907372184, 4.302973519238985, 4.364335576236952, 4.425482692951023, 4.486419309206083, 4.547149699531195, 4.607677981962285, 4.668008126239605, 4.728143961450658, 4.7880891831643035, 4.8478473600973215, 4.907421940350798, 4.966816257250172, 5.026033534819676, 5.085076892919079, 5.143949352068169, 5.202653837982126, 5.261193185838932, 5.319570144298173, 5.377787379288892, 5.435847477582716, 5.493752950167129, 5.551506235432536, 5.609109702185715, 5.666565652501158, 5.723876324421022, 5.781043894513474, 5.838070480298543, 5.894958142549842, 5.951708887479961, 6.00832466881669, 6.064807389776782, 6.1211589049434005, 6.177381022053046, 6.233475503697279, 6.2894440689442135, 6.345288394884426, 6.401010118105582, 6.456610836099803, 6.512092108607554, 6.567455458901529, 6.622702375013832, 6.677834310909525, 6.732852687609407, 6.787758894264725, 6.842554289186317, 6.897240200830597], [0.0, 0.1741101126592248, 0.30314331330207955, 0.4192962712629475, 0.5278031643091576, 0.6309573444801931, 0.7300372102718469, 0.8258523872989457, 0.9189586839976279, 1.0097596309015795, 1.0985605433061176, 1.1855998744839986, 1.2710686092585746, 1.3551228811604872, 1.4378925219250922, 1.5194870523363544, 1.6, 1.6795120867813484, 1.758093630950113, 1.835806390401934, 1.9127049995800738, 1.988838105491312, 2.064249277151718, 2.1389777418892093, 2.2130589875561464, 2.2865252596366314, 2.3594059750594574, 2.431728069337104, 2.5035162898423473, 2.574793445202917, 2.6455806186651616, 2.715897351658381, 2.785761802547597, 2.8551908845980556, 2.9242003864203037, 2.992805077569759, 3.061018801501898, 3.128854557705815, 3.196324574534056, 3.263440373999379, 3.3302128296074924, 3.3966522181293937, 3.462768266080516, 3.5285701915608616, 3.59406674201609, 3.6592662284008037, 3.724176556159046, 3.78880525338119, 3.8531594964491074, 3.917246133441245, 3.9810717055349722, 4.044642466614131, 4.107964401264504, 4.171043241318159, 4.2338844810888245, 4.296493391424152, 4.358875032686557, 4.421034266761981, 4.482975768185135, 4.5447040344603025, 4.60622339564853, 4.667538023284663, 4.728651938681311, 4.789569020671063, 4.850293012833274, 4.9108275302472375, 4.971176065809591, 5.031341996150233, 5.091328587177878, 5.151138999283546, 5.210776292227709, 5.270243429734589, 5.329543283815008, 5.388678638837405, 5.447652195364886, 5.506466573774779, 5.565124317675735, 5.623627897136184, 5.681979711736947, 5.7401820934596115, 5.798237309421564, 5.856147564467572, 5.913915003627146, 5.971541714446167, 6.029029729200673, 6.0863810270000505, 6.143597535786442, 6.200681134236584, 6.257633653571947, 6.3144568792825675, 6.371152552769607, 6.427722372911343, 6.484167997556955, 6.54049104495217, 6.596693095100619, 6.65277569106439, 6.708740340207161, 6.764588515382989, 6.820321656073681, 6.875941169477453, 6.931448431551464, 6.986844788010592], [0.0, 0.17623403478323169, 0.30684127650498216, 0.4244111529515947, 0.534241692207828, 0.6386542222937697, 0.7389427365423364, 0.8359267369720242, 0.9301688121755985, 1.0220774152464698, 1.1119615859385787, 1.2000626863515946, 1.286574031081021, 1.371653658288166, 1.4554329834905735, 1.538022863486599, 1.619517966799908, 1.7, 1.7795401391501218, 1.8582008955137614, 1.9360375700049626, 2.0130994030621694, 2.0894304951880813, 2.165070552234169, 2.240055494959496, 2.3144179622020933, 2.3881877297399043, 2.4613920616644327, 2.534056007234955, 2.606202653315474, 2.6778533403411533, 2.749027848121898, 2.8197445565317074, 2.890020585156171, 2.959871915206822, 3.029313496408886, 3.0983593410904033, 3.167022607317717, 3.235315672613735, 3.3032501995451287, 3.3708371942605595, 3.438087058894571, 3.5050096386137253, 3.57161426396713, 3.6379097891081678, 3.7039046263745234, 3.7696067776466133, 3.835023862847947, 3.900163145903135, 3.965031558428479, 4.0296357213954, 4.093981964977177, 4.158076346763932, 4.2219246685088025, 4.28553249154916, 4.348905151030302, 4.4120477690446345, 4.474965266786929, 4.5376623758152785, 4.600143648497806, 4.662413467716798, 4.724476055894524, 4.7863354833985, 4.847995676378142, 4.9094604240797155, 4.970733385681888, 5.0318180966901975, 5.092717974925135, 5.1534363261353535, 5.213976349264626, 5.274341141398614, 5.334533702415209, 5.394556939360117, 5.454413670567531, 5.514106629543997, 5.573638468632117, 5.633011762469332, 5.6922290112557725, 5.751292643844092, 5.810205020663093, 5.868968436486114, 5.9275851230542225, 5.986057251563567, 6.044386935025434, 6.102576230507046, 6.160627141260412, 6.218541618746115, 6.276321564558362, 6.3339688322572, 6.391485229113373, 6.448872517770924, 6.506132417832287, 6.563266607370293, 6.620276724371216, 6.677164368112717, 6.733931100480284, 6.790578447225516, 6.847107899169417, 6.903520913353643, 6.959818914142442, 7.016003294277899, 7.072075415890906], [0.0, 0.17826024579660033, 0.31036911478307194, 0.42929072433157667, 0.5403840154082454, 0.6459970049778166, 0.7474385637693104, 0.8455376158406002, 0.9408632180197389, 1.0338285194973316, 1.1247461131420948, 1.2138601360599284, 1.3013661254372384, 1.3874239364434007, 1.4721664955161928, 1.5557059340049721, 1.6381380088633757, 1.7195453660637319, 1.8000000000000003, 1.879565140644803, 1.9582967247219536, 2.0362445588007163, 2.113453250419361, 2.1899629619384178, 2.265810027107765, 2.3410274600231027, 2.415645378802657, 2.489691361000665, 2.5631907438746055, 2.6361668797244855, 2.708641354342303, 2.7806341749518597, 2.852163932745606, 2.923247944137699, 2.9939023740800437, 3.0641423441789537, 3.1339820278660473, 3.2034347344895635, 3.2725129838801843, 3.341228572692308, 3.4095926336153037, 3.4776156883799083, 3.545307695345263, 3.612678092336356, 3.6797358353051988, 3.7464894333084295, 3.8129469802262768, 3.8791161835906, 3.9450043908413424, 4.010618613289499, 4.075965548029614, 4.141051598014704, 4.205882890480665, 4.270465293884981, 4.334804433505246, 4.398905705826383, 4.462774291830899, 4.526415169293891, 4.589833124173475, 4.653032761177594, 4.716018513579737, 4.778794652348521, 4.84136529464959, 4.903734411772377, 4.965905836529152, 5.027883270169162, 5.089670288846621, 5.15127034967764, 5.21268679641797, 5.273922864790519, 5.334981687488989, 5.395866298881692, 5.456579639437434, 5.51712455989357, 5.577503825184519, 5.637720118147595, 5.69777604302155, 5.757674128752001, 5.817416832116787, 5.877006540683206, 5.936445575608237, 5.995736194291885, 6.054880592893135, 6.113880908717146, 6.1727392224818045, 6.231457560471057, 6.290037896581964, 6.348482154271884, 6.4067922084117495, 6.4649698870509935, 6.523016973099261, 6.580935205929725, 6.638726282908482, 6.69639186085418, 6.753933557431816, 6.811352952484305, 6.868651589305228, 6.925830975855968, 6.982892585930188, 7.039837860268441, 7.0966682076255525, 7.153385005793204], [0.0, 0.18019831273171422, 0.3137434853072099, 0.43395802496644426, 0.5462591357293617, 0.6530203624849001, 0.7555648061628231, 0.8547304029835368, 0.9510923966296996, 1.045068428099846, 1.136974488810138, 1.2270573701545953, 1.315514735223545, 1.402508177151083, 1.4881720675672823, 1.5726197569270821, 1.6559480432652913, 1.7382404710912376, 1.8195698175306316, 1.9000000000000001, 1.979587563373977, 2.058382855724867, 2.136430969569487, 2.213772503918405, 2.2904441875464174, 2.366479393482464, 2.441908567292591, 2.516759586357539, 2.591058063404511, 2.6648276046225425, 2.738090030486971, 2.810865565742552, 2.883173003707428, 2.955029849061904, 3.026452442505194, 3.097456070047545, 3.1680550592158347, 3.2382628640591458, 3.308092140525272, 3.3775548135232643, 3.446662136778435, 3.5154247464150505, 3.5838527090607353, 3.651955565149652, 3.7197423680040034, 3.7872217191919213, 3.854401800591277, 3.921290403531149, 3.987894955333734, 4.054222543537849, 4.120279938049658, 4.186073611435858, 4.251609757548393, 4.316894308647328, 4.3819329511689515, 4.446731140269425, 4.511294113259523, 4.575626902033315, 4.639734344582432, 4.703621095677759, 4.767291636791868, 4.8307502853278645, 4.894001203213715, 4.957048404915191, 5.0198957649153595, 5.082547024703898, 5.145005799315402, 5.207275583452164, 5.269359757223655, 5.33126159153195, 5.392984253129778, 5.454530809375469, 5.515904232706962, 5.577107404855171, 5.6381431208152195, 5.69901409259255, 5.759722952739514, 5.820272257696731, 5.880664490952426, 5.940902066031817, 6.00098732932778, 6.060922562783049, 6.120709986433513, 6.180351760821372, 6.239849989286327, 6.2992067201423305, 6.35842394874689, 6.417503619469424, 6.4764476275646885, 6.5352578209568915, 6.593936001939686, 6.652483928796921, 6.710903317348663, 6.769195842426692, 6.827363139283455, 6.885406804938109, 6.943328399463109, 7.001129447214578, 7.058811438009439, 7.1163758282521545, 7.1738240420137, 7.231157472065275], [0.0, 0.182056420302608, 0.31697863849222263, 0.43843276548657756, 0.5518918645844859, 0.659753955386447, 0.7633557819236352, 0.8635439207617045, 0.9608995471851449, 1.0558446086806568, 1.1486983549970349, 1.239710122307718, 1.3290796118979478, 1.416970083162849, 1.503517293300091, 1.588835761573218, 1.673023284146037, 1.7561642669936848, 1.8383322376802431, 1.9195917727040783, 1.9999999999999998, 2.079607786802411, 2.1584606905977815, 2.2365997290317248, 2.314062009606305, 2.3908812494750924, 2.4670882081423477, 2.5427110504452903, 2.6177756532157166, 2.6923058660569206, 2.766323734445183, 2.8398496916718936, 2.9129027248417283, 2.9855005191337924, 3.0576595837437544, 3.1293953623029336, 3.20072233007592, 3.2716540798426745, 3.342203398052282, 3.412382332577008, 3.4822022531844965, 3.551673905672975, 3.6208074604716898, 3.6896125563906024, 3.7580983401048798, 3.826273501877372, 3.8941463079530534, 3.961724630000973, 4.02901597192986, 4.096027494361398, 4.162766037009366, 4.229238139182064, 4.295450058599093, 4.361407788690774, 4.427117074528853, 4.492583427520112, 4.557812138979643, 4.622808292687686, 4.687576776522624, 4.7521222932528255, 4.816449370561384, 4.88056237037013, 4.944465497522582, 5.008162807879513, 5.071658215875563, 5.134955501580629, 5.198058317305588, 5.2609701937882125, 5.3236945459918354, 5.386234678546306, 5.448593790858195, 5.510774981914772, 5.57278125480415, 5.634615520972095, 5.6962806042342065, 5.757779244560662, 5.819114101649269, 5.880287758301282, 5.941302723613313, 6.002161435997546, 6.062866266041592, 6.123419519218347, 6.183823438455507, 6.244080206573615, 6.304191948600876, 6.364160733972347, 6.423988578620584, 6.48367744696429, 6.543229253801065, 6.602645866109911, 6.6619291047687605, 6.721080746191934, 6.780102523892106, 6.838996129971017, 6.897763216542952, 6.9564053970946675, 7.014924247785242, 7.073321308689135, 7.1315980849854546, 7.18975604809632, 7.247796636776956, 7.305721258160065], [0.0, 0.1838416287252544, 0.32008686688809423, 0.4427319484783656, 0.557303604546244, 0.6662233691872481, 0.7708410942740636, 0.8720116577308621, 0.9703219337293861, 1.0661980072880195, 1.1599622586540013, 1.2518664689408392, 1.3421122976641735, 1.4308646051077254, 1.518260479676778, 1.6044155635876032, 1.6894286119734032, 1.7733848584772296, 1.856358551659581, 1.9384149012429017, 2.0196115953469707, 2.1, 2.1796261194159547, 2.258531373451182, 2.3367532334764034, 2.4143257472687747, 2.491279975954033, 2.567644360548092, 2.643445031625726, 2.7187060726546126, 2.793449745284513, 2.867696683171538, 2.9414660596040707, 3.014775733178504, 3.087642374976339, 3.1600815800660196, 3.2321079656536513, 3.3037352578072445, 3.374976368357218, 3.4458434633148345, 3.5163480239373786, 3.5865009013942015, 3.6563123658437213, 3.72579215061212, 3.794949492065009, 3.8637931656802, 3.932331518759791, 4.0005725001608266, 4.068523687373846, 4.136192311236139, 4.203585278530336, 4.270709192687871, 4.337570372790277, 4.404174871038239, 4.470528488838516, 4.536636791641628, 4.602505122648233, 4.668138615489092, 4.7335422059721335, 4.798720642980122, 4.863678498593695, 4.928420177506806, 4.992949925794818, 5.057271839089454, 5.121389870209509, 5.1853078362914795, 5.249029425460064, 5.312558203074737, 5.375897617585269, 5.439051006026042, 5.502021599176359, 5.564812526411534, 5.627426820267352, 5.6898674207386275, 5.752137179330726, 5.814238862881417, 5.8761751571689675, 5.937948670321058, 5.999561936037992, 6.061017416642534, 6.122317505967796, 6.183464532093673, 6.244460759941559, 6.305308393736291, 6.366009579343672, 6.4265664064912205, 6.486980910879318, 6.547255076189362, 6.607390835995068, 6.667390075582659, 6.727254633685226, 6.78698630413625, 6.846586837446879, 6.906057942311262, 6.965401287043982, 7.024618500953319, 7.083711175653851, 7.142680866321693, 7.201529092895438, 7.26025734122567, 7.318867064175758, 7.377359682676464], [0.0, 0.18556007362580842, 0.32307885324043556, 0.4468703499081746, 0.5625129553550541, 0.6724508387726091, 0.7780464696657949, 0.8801627168617118, 0.9793919402914197, 1.0761642077688864, 1.1708049129648923, 1.2635681904967386, 1.354657584876237, 1.4442394974054071, 1.5324522979124207, 1.6194127095699042, 1.705220410616759, 1.7899614314106878, 1.8737107145446625, 1.9565340792837849, 2.038489752982913, 2.119629581810095, 2.2, 2.2796428145777656, 2.3585958471747506, 2.43689346382698, 2.5145670160015765, 2.5916452105645718, 2.6681544223441955, 2.7441189599264106, 2.8195612930499663, 2.8945022482424205, 2.9689611780129352, 3.0429561078897023, 3.116503864785822, 3.1896201895433913, 3.2623198360016787, 3.334616658532017, 3.406523689657125, 3.4780532091090817, 3.549216805465304, 3.620025431325581, 3.6904894528478125, 3.7606186943396676, 3.8304224785029466, 3.8999096628435357, 3.969088672689272, 4.037967531198504, 4.106553886691757, 4.174855037595995, 4.242877955254442, 4.310629304823581, 4.378115464452053, 4.445342542913005, 4.51231639584138, 4.579042640710302, 4.645526670665568, 4.711773667324142, 4.7777886126310225, 4.843576299858774, 4.909141343825192, 4.974488190396754, 5.039621125338674, 5.104544282566262, 5.169261651846971, 5.233777085997675, 5.298094307617522, 5.362216915392902, 5.426148390007691, 5.489892099688931, 5.553451305415379, 5.6168291658139315, 5.680028741766762, 5.743053000750048, 5.805904820923375, 5.868586994987305, 5.931102233825204, 5.993453169944015, 6.055642360727606, 6.117672291515103, 6.179545378515782, 6.24126397157108, 6.302830356773558, 6.364246758951874, 6.425515344030136, 6.486638221269423, 6.547617445398665, 6.608455018641561, 6.669152892645752, 6.729712970320024, 6.790137107584876, 6.850427115041505, 6.9105847595638235, 6.970611765817859, 7.030509817712635, 7.090280559786257, 7.149925598530794, 7.209446503659246, 7.268844809317709, 7.328122015245637, 7.3872795878869235, 7.446318961454366], [0.0, 0.1872171230554857, 0.32596394386926575, 0.4508608972494537, 0.567536189899231, 0.6784558174143034, 0.7849944161374158, 0.8880225603048655, 0.9881378996154234, 1.085774342383936, 1.1812601880431084, 1.2748518406295968, 1.3667546623054787, 1.4571365403345828, 1.546137080186134, 1.6338740473694155, 1.7204480102489117, 1.8059457674324801, 1.8904429307496289, 1.9740059072307774, 2.056693444200427, 2.1385578508123393, 2.219645975958392, 2.3000000000000003, 2.379658082315277, 2.458654895828574, 2.537022071975273, 2.614788573973405, 2.6919810121781276, 2.768623912250811, 2.844739944584726, 2.9203501216880943, 2.9954739688877723, 3.0701296726797214, 3.1443342102411935, 3.2181034629798324, 3.2914523164865304, 3.3643947488520047, 3.4369439089792597, 3.5091121862582475, 3.5809112727522554, 3.652352218867667, 3.723445483332061, 3.7942009781840658, 3.8646281093771067, 3.9347358135145014, 4.004532591162172, 4.0740265371251825, 4.1432253680234785, 4.212136447458896, 4.280766809028678, 4.349123177409083, 4.4172119877055485, 4.4850394032424985, 4.552611331945634, 4.6199334414520505, 4.687011173068279, 4.753849754683067, 4.820454212730127, 4.886829383285893, 4.952979922378437, 5.018910315575773, 5.08462488691495, 5.150127807227099, 5.215423101908254, 5.280514658180898, 5.345406231886953, 5.410101453849034, 5.47460383583349, 5.538916776145592, 5.603043564884602, 5.66698738888392, 5.730751336359364, 5.794338401286642, 5.8577514875272705, 5.920993412720601, 5.9840669119581555, 6.0469746412551375, 6.109719180832822, 6.1723030382243875, 6.234728651215834, 6.296998390632654, 6.359114562982193, 6.421079412960802, 6.48289512583427, 6.544563829699353, 6.606087597633688, 6.667468449740809, 6.728708355096551, 6.789809233602654, 6.850772957752966, 6.911601354317333, 6.972296205947832, 7.0328592527117415, 7.093292193555372, 7.153596687702536, 7.21377435599126, 7.273826782152065, 7.333755514030953, 7.393562064760037, 7.453247913878535, 7.512814508406752], [0.0, 0.1888175022589804, 0.32875036590344514, 0.45471496995311944, 0.5723876324421022, 0.6842554289186316, 0.7917047464637366, 0.8956136012019356, 0.9965847516924139, 1.0950558154077703, 1.1913578981670916, 1.2857495958134313, 1.378438025996442, 1.469592511122642, 1.5593538500440307, 1.6478408149591766, 1.7351548339163179, 1.821383447499712, 1.9066029138878622, 1.9908802077752392, 2.0742745786732963, 2.1568387828876388, 2.238620069786293, 2.319660980299045, 2.4, 2.4796720982064158, 2.558709176747163, 2.6371404464251693, 2.714992745067622, 2.792290807987432, 2.8690574993701112, 2.9453140113441036, 3.0210800361436867, 3.0963739157275776, 3.1712127723982215, 3.2456126233215428, 3.3195884813342205, 3.3931544440152175, 3.4663237726676783, 3.539108962589187, 3.6115218057897374, 3.6835734471373756, 3.755274434763521, 3.8266347654374107, 3.8976639255169316, 3.9683709279977424, 4.038764346110746, 4.1088523438574445, 4.178642703821397, 4.248142852550364, 4.317359883766555, 4.386300579630456, 4.4549714302564105, 4.523378651654494, 4.591528202252848, 4.659425798136957, 4.727076927127017, 4.794486861801085, 4.861660671560098, 4.928603233820492, 4.995319244411239, 5.061813227244124, 5.1280895433191525, 5.1941523991207745, 5.260005854455123, 5.325653829773643, 5.391100113024136, 5.456348366066408, 5.521402130686271, 5.586264834238569, 5.650939794947161, 5.715430226887304, 5.779739244673662, 5.843869867875204, 5.90782502517639, 5.971607558302459, 6.035220225725188, 6.098665706164067, 6.161946601896756, 6.225065441891458, 6.288024684772983, 6.350826721633238, 6.413473878696176, 6.475968419846378, 6.538312549029835, 6.600508412534814, 6.66255810116014, 6.724463652277703, 6.786227051795495, 6.8478502360270594, 6.909335093472795, 6.970683466518239, 7.031897153054025, 7.092977908021967, 7.153927444891397, 7.214747437069593, 7.275439519249912, 7.336005288701002, 7.396446306500246, 7.456764098714389, 7.516960157530127, 7.5770359423372575], [0.0, 0.19036539387158782, 0.3314454017339986, 0.4584426407447396, 0.5770799623628854, 0.6898648307306072, 0.7981949982785914, 0.9029556789481826, 1.004754572603832, 1.10403288422675, 1.201124433981431, 1.2962899376327148, 1.3897382107431533, 1.4816399637936206, 1.5721371498795493, 1.6613495148724347, 1.749379318309245, 1.8363148184160578, 1.9222328985220836, 2.0072010823681814, 2.0912791051825463, 2.174520155757401, 2.256971870802515, 2.3386771399904953, 2.4196747643931995, 2.4999999999999996, 2.5796850101651705, 2.6587592451564994, 2.7372497628128096, 2.815181501222619, 2.8925775120078816, 2.969459161026264, 3.0458463019454056, 3.1217574270880726, 3.197209799122238, 3.272219566519645, 3.346801865189483, 3.4209709082801076, 3.494740065808421, 3.568121935506188, 3.6411284060521605, 3.7137707136779894, 3.786059492986762, 3.8580048226994132, 3.929616266941273, 4.0009029125949, 4.071873403172989, 4.142535969604045, 4.212898458271833, 4.282968356605607, 4.352752816480621, 4.422258675656282, 4.491492477451715, 4.560460488834715, 4.629168717079537, 4.697622925131099, 4.765828645797748, 4.833791194881179, 4.901515683340359, 4.969007028575899, 5.036269964912325, 5.103309053347627, 5.170128690632501, 5.236733117735389, 5.30312642774398, 5.369312573248866, 5.435295373250761, 5.501078519628731, 5.566665583203505, 5.63206001942676, 5.697265173724553, 5.762284286520544, 5.827120497962446, 5.8917768523731056, 5.956256302445803, 6.0205617132017295, 6.084695865726111, 6.148661460698094, 6.212461121728337, 6.276097398517068, 6.339572769844454, 6.402889646404142, 6.466050373490045, 6.52905723354566, 6.5919124485845275, 6.654618182489794, 6.717176543200276, 6.779589584789869, 6.841859309446676, 6.903987669357787, 6.965976568505188, 7.027827864377954, 7.0895433696055035, 7.151124853516343, 7.212574043626514, 7.273892627061587, 7.335082251915835, 7.396144528552026, 7.4570810308449715, 7.517893297371836, 7.578582832551991, 7.639151107739044], [0.0, 0.1918645191625306, 0.33405553046696207, 0.4620528712767166, 0.5816244604403988, 0.6952975083515085, 0.8044807747250744, 0.9100664445520651, 1.012667003326387, 1.112727130513411, 1.2105832751075947, 1.3064982060074317, 1.4006823831956317, 1.4933078614961455, 1.5845177118834026, 1.674432623226261, 1.7631556603543683, 1.8507757765263197, 1.9373704605266595, 2.023007767844932, 2.1077479041235665, 2.191644477015916, 2.2747454983702906, 2.3570941956149776, 2.4387296753798298, 2.51968747129473, 2.6, 2.679696943683947, 2.758805573265564, 2.83735102322053, 2.915356526702057, 2.9928436178236955, 3.0698323066004902, 3.1463412309820358, 3.2223877895796185, 3.2979882580340094, 3.37315789144951, 3.447911014902857, 3.5222611036996807, 3.5962208547787387, 3.6698022504419923, 3.743016615406288, 3.8158746680220896, 3.8883865663801442, 3.9605619499231577, 4.032409977092787, 4.103939359469287, 4.1751583927996325, 4.24607498525777, 4.316696683236372, 4.387030694931628, 4.457083911950225, 4.526862929139846, 4.59637406282059, 4.665623367573924, 4.734616651727894, 4.803359491661647, 4.871857245038758, 4.9401150630669335, 5.008137901871261, 5.075930533059015, 5.143497553545995, 5.210843394707257, 5.2779723309088205, 5.344888487471394, 5.411595848112175, 5.478098261906464, 5.54439944980683, 5.610503010754178, 5.676412427411826, 5.742131071551021, 5.807662209113725, 5.873009004976275, 5.938174527435527, 6.003161752437187, 6.067973567564454, 6.132612775803571, 6.197082099101498, 6.2613841817298, 6.325521593467563, 6.389496832615321, 6.453312328850905, 6.5169704459373925, 6.580473484292494, 6.6438236834280815, 6.707023224267858, 6.770074231350633, 6.832978774926111, 6.895738872949602, 6.9583564929816495, 7.020833553998073, 7.083171928115654, 7.145373442238246, 7.207439879627798, 7.269372981404521, 7.331174447980078, 7.392845940427467, 7.454389081791044, 7.515805458339868, 7.577096620767379, 7.638264085340233, 7.699309334998933], [0.0, 0.19331820449317627, 0.33658654363385987, 0.46555367217460797, 0.5860312103167044, 0.7005655161767013, 0.8105760231123681, 0.916961675864935, 1.0203396005006329, 1.1211578456539657, 1.2197554094669347, 1.31639705173919, 1.4112948270296084, 1.5046220937568582, 1.5965230068903544, 1.6871191697131422, 1.7765144279383365, 1.8647984087899303, 1.9520491881558577, 2.038335337156521, 2.1237175175898693, 2.208249743274289, 2.291980389825818, 2.3749530121907143, 2.4572070132950636, 2.538778195993704, 2.619699222535653, 2.7, 2.77970800592724, 2.8588485652275235, 2.937445087082931, 3.015519268762895, 3.0930912718908212, 3.170179875629042, 3.2468026104115797, 3.322975875193618, 3.398715040661648, 3.4740345404281263, 3.548947951896009, 3.623468068203986, 3.6976069624394143, 3.771376045122263, 3.844786115811908, 3.917847409563131, 3.9905696388530716, 4.062962031513455, 4.135033365128907, 4.206791998300155, 4.278245899118409, 4.349402671152521, 4.420269577212474, 4.4908535611200655, 4.561161267689663, 4.631199061097746, 4.700973041799071, 4.7704890621292, 4.83975274071741, 4.908769475820277, 4.9775444576742744, 5.046082679955184, 5.114388950422955, 5.182467900822491, 5.250323996103709, 5.317961543017895, 5.385384698141759, 5.4525974753756286, 5.5196037529577975, 5.586407280033098, 5.653011682810254, 5.719420470339415, 5.785637039938471, 5.851664682294199, 5.917506586262014, 5.983165843386104, 6.048645452159795, 6.113948322044421, 6.179077277263395, 6.244035060386849, 6.308824335720997, 6.373447692515177, 6.437907647998606, 6.50220665025787, 6.56634708096539, 6.630331257968279, 6.694161437746347, 6.757839817747337, 6.821368538606889, 6.8847496862602116, 6.947985293951906, 7.011077344149977, 7.074027770369606, 7.1368384589119005, 7.199511250522475, 7.2620479419743855, 7.324450287579656, 7.3867200006333285, 7.448858754793728, 7.5108681854024075, 7.572749890746988, 7.634505433269934, 7.69613634072608, 7.757644107291616], [0.0, 0.19472943612303362, 0.3390436406144871, 0.46895223502227934, 0.5903092646378209, 0.705679676106998, 0.8164932647152433, 0.923655537541026, 1.0277881256987516, 1.1293423485982057, 1.2286596790831472, 1.3260068097117295, 1.421597343050693, 1.5156059030429971, 1.6081776969958492, 1.699435215901756, 1.7894830635522319, 1.8784115214540555, 1.9662992354526716, 2.053215277240761, 2.139220751450138, 2.224370066202506, 2.3087119502580853, 2.3922902765162104, 2.4751447355461083, 2.557311391565076, 2.6388231452580238, 2.7197101220270716, 2.8000000000000007, 2.8797182889599506, 2.9588885689770885, 3.0375326957118953, 3.1156709779685388, 3.1933223319980844, 3.2705044162075154, 3.3472337492651296, 3.4235258140641234, 3.499395149582978, 3.574855432340304, 3.6499195488652814, 3.724599660379351, 3.798907260699794, 3.8728532282232573, 3.946447872720885, 4.019700977571339, 4.092621837969932, 4.165219295578056, 4.2375017700146005, 4.309477287538202, 4.381153507224108, 4.452537744901144, 4.523636995081319, 4.594457951086446, 4.665007023551781, 4.735290357465676, 4.805313847886006, 4.875083154458296, 4.94460371484664, 5.013880757176472, 5.082919311577632, 5.151724220906934, 5.220300150721229, 5.28865159856477, 5.356782902628323, 5.424698249831795, 5.492401683377167, 5.55989710981405, 5.627188305656199, 5.694278923583828, 5.761172498263311, 5.827872451813112, 5.89438209894217, 5.960704651784689, 6.026843224453268, 6.092800837330373, 6.158580421116533, 6.224184820652122, 6.289616798528159, 6.354879038500411, 6.419974148719855, 6.484904664791594, 6.5496730526733575, 6.614281711423883, 6.6787329758106715, 6.743029118785938, 6.807172353838894, 6.871164837231914, 6.935008670127631, 6.99870590061342, 7.062258525629396, 7.125668492805486, 7.188937702212882, 7.252068008034724, 7.315061220160592, 7.377919105709068, 7.440643390482325, 7.50323576035647, 7.565697862611122, 7.628031307201475, 7.690237667975892, 7.752318483841891, 7.814275259883211], [0.0, 0.1961009057454548, 0.34143150791917165, 0.47225504202210655, 0.59446678309216, 0.7106497425654109, 0.8222437857035593, 0.9301607970258747, 1.0350267857634294, 1.1372962499459074, 1.2373130673931283, 1.3353458089655157, 1.4316095816219423, 1.5262802391730128, 1.6195040116136943, 1.7114042526343916, 1.8020863027458605, 1.8916410793029905, 1.980147782049959, 2.067675969147903, 2.154287175585486, 2.240036192678075, 2.3249720923800967, 2.409139056585509, 2.492577055402221, 2.5753224070459977, 2.6574082439196185, 2.7388649035968946, 2.8197202591412687, 2.9000000000000004, 2.9797278723165044, 3.058925885679579, 3.1376144919272773, 3.21581274053687, 3.2935384142826134, 3.3708081481729533, 3.4476375341463252, 3.524041213578504, 3.600032959311133, 3.675625748632568, 3.7508318284151225, 3.825662773426453, 3.900129538679207, 3.9742425065557283, 4.048011529338523, 4.121445967688496, 4.194554725538416, 4.267346281806126, 4.339828719278796, 4.412009750974157, 4.483896744246047, 4.555496742868473, 4.6268164873039765, 4.697862433337595, 4.768640769236523, 4.839157431577234, 4.909418119865849, 4.97942831006366, 5.049193267117521, 5.1187180565842265, 5.188007555428589, 5.257066462066737, 5.325899305718905, 5.3945104551295175, 5.462904126706747, 5.531084392128644, 5.59905518545845, 5.666820309807719, 5.7343834435823045, 5.801748146343061, 5.8689178643102595, 5.935895935538167, 6.002685594783888, 6.069289978092559, 6.1357121271190485, 6.201954993204661, 6.26802144122584, 6.3339142532303905, 6.39963613187564, 6.46518970368164, 6.530577522111633, 6.595802070490965, 6.660865764774822, 6.725770956174357, 6.790519933650073, 6.855114926280672, 6.91955810551498, 6.983851587314009, 7.047997434189712, 7.111997657146554, 7.17585421753152, 7.239569028797907, 7.303143958187776, 7.366580828337667, 7.429881418811888, 7.493047467567353, 7.556080672353706, 7.618982692052276, 7.681755147957089, 7.744399625001044, 7.8069176729301075, 7.8693108074282465], [0.0, 0.19743504858348196, 0.3437543855174957, 0.475467957738334, 0.5985111478955378, 0.7154845405526276, 0.8278377968767289, 0.9364890052554508, 1.0420684338789408, 1.1450336728854527, 1.2457309396155172, 1.3444306321107664, 1.4413493207777173, 1.536664055821765, 1.6305220620915195, 1.7230475324955523, 1.8143465242128436, 1.9045105731407495, 1.9936194178469218, 2.081743089720922, 2.168943542395397, 2.2552759399501365, 2.340789688193184, 2.4255292696033273, 2.5095349262190556, 2.59284322334162, 2.6754875187850886, 2.7574983565203643, 2.8389037992410606, 2.919729711168703, 3.0, 3.0797368250626564, 3.158960777335712, 3.2376910358966726, 3.3159455045022073, 3.393740931334526, 3.471093014409458, 3.548016494713162, 3.624525238788725, 3.7006323122135223, 3.776350045179608, 3.851690091201819, 3.9266634798235747, 4.001280664062185, 4.07555156322867, 4.149485601667775, 4.223091743888826, 4.296378526494702, 4.369354087262593, 4.442026191684577, 4.514402257237172, 4.586489375615632, 4.658294333140217, 4.729823629516922, 4.80108349511388, 4.872079906896164, 4.942818603145624, 5.013305097078423, 5.083544689460688, 5.153542480311961, 5.223303379776745, 5.2928321182361335, 5.362133255724225, 5.431211190707535, 5.500070168279932, 5.568714287820511, 5.63714751015732, 5.705373664275803, 5.773396453607294, 5.84121946192958, 5.90884615890877, 5.976279905309079, 6.043523957894791, 6.1105814740466515, 6.177455516112967, 6.244149055514048, 6.310664976617088, 6.377006080397137, 6.44317508789864, 6.5091746435107805, 6.575007318068903, 6.640675611793281, 6.706181957075687, 6.771528721123381, 6.836718208469463, 6.901752663357837, 6.966634272010451, 7.031365164783936, 7.095947418222236, 7.160383057011378, 7.224674055842076, 7.288822341185516, 7.352829792987259, 7.416698246283874, 7.48042949274667, 7.5440252821564835, 7.607487323813345, 7.670817287884529, 7.734016806694291, 7.797087475958382, 7.860030855966228, 7.922848472713525], [0.0, 0.19873407546644578, 0.34601612268689763, 0.4785963063447307, 0.6024490610292391, 0.7201920818893416, 0.8332845681596994, 0.9426506488043291, 1.0489247388724505, 1.1525674392235408, 1.2539272451403496, 1.3532763337525067, 1.4508327003947878, 1.546774560177088, 1.6412501066161314, 1.7343843497496063, 1.8262840445613033, 1.9170413292103972, 2.0067364669056498, 2.0954399498092067, 2.183214139178577, 2.270114562046446, 2.3561909492871167, 2.4414880760525177, 2.526046449154239, 2.609902874475482, 2.693090929308557, 2.775641358588885, 2.857582409648994, 2.938940116884447, 3.019738545293004, 3.1000000000000005, 3.179745207463133, 3.258993472948939, 3.337762818012124, 3.4160701010298156, 3.4939311233031747, 3.571360722806902, 3.6483728573192145, 3.724980678382649, 3.801196597315946, 3.8770323443084194, 3.9524990214725353, 4.02760715060139, 4.102366716270257, 4.176787204831504, 4.25087763977658, 4.32464661387507, 4.398102318446794, 4.471252570077002, 4.5441048350456095, 4.616666251707789, 4.688943651034494, 4.760943575496635, 4.832672296455146, 4.904135830200632, 4.975339952770055, 5.046290213653867, 5.1169919484946655, 5.1874502908676465, 5.257670183223686, 5.32765638706749, 5.3974134924359705, 5.466945926735418, 5.536257962990363, 5.605353727551826, 5.674237207308181, 5.742912256437743, 5.811382602738626, 5.879651853568137, 5.947723501421107, 6.015600929173949, 6.083287415018877, 6.150786137110671, 6.218100177946404, 6.285232528496892, 6.352186092107065, 6.41896368818103, 6.485568055666387, 6.552001856351118, 6.618267677985415, 6.68436803723979, 6.750305382509975, 6.816082096578304, 6.88170049914059, 6.94716284920677, 7.012471347383075, 7.077628138042849, 7.142635311392688, 7.207494905440071, 7.27220890786822, 7.336779257823566, 7.401207847620801, 7.465496524370147, 7.5296470915312375, 7.593661310397621, 7.657540901515693, 7.7212875460416175, 7.7849028870395545, 7.848388530724288, 7.911746047651194, 7.974976973856279], [0.0, 0.19999999999999998, 0.34822022531844965, 0.4816449370561384, 0.6062866266041592, 0.7247796636776954, 0.8385925425258951, 0.9486552787606733, 1.0556063286183155, 1.1599092269590576, 1.2619146889603865, 1.3618966255044604, 1.460074420543694, 1.5566274244078944, 1.651704774597892, 1.7454322774580642, 1.8379173679952563, 1.9292527712833727, 2.019519261803159, 2.1087877807477464, 2.1971210866122353, 2.28457506013329, 2.3711997489679972, 2.4570402134834075, 2.5421372185171496, 2.6265278044037674, 2.7102457623209744, 2.7933220330476476, 2.8757850438501853, 2.957660994961739, 3.0389741046727097, 3.1197468201907865, 3.2000000000000006, 3.279753072340316, 3.359024173562697, 3.4378302694311564, 3.5161872619002263, 3.5941100834616457, 3.6716127808038683, 3.748708589243996, 3.8254099991601485, 3.9017288154622647, 3.9776762109826245, 4.053262774537535, 4.1284985543034365, 4.203393097060208, 4.2779554837784195, 4.352194361963098, 4.426117975112294, 4.499734189602455, 4.573050519273264, 4.646074147950803, 4.718811950118916, 4.791270509923671, 4.863456138674208, 4.935374890984556, 5.0070325796846955, 5.078434789615011, 5.149586890405835, 5.220494048332939, 5.291161237330323, 5.361593249233205, 5.431794703316763, 5.501770055189611, 5.571523605095195, 5.641059505669155, 5.710381769196111, 5.7794942744052715, 5.848400772840607, 5.917104894838083, 5.985610155139519, 6.053919958170054, 6.122037603003797, 6.189966288040189, 6.2577091154116316, 6.325269095141249, 6.392649149068114, 6.459852114555771, 6.526880747998758, 6.593737728140493, 6.660425659214986, 6.726947073923794, 6.793304436258788, 6.859500144180488, 6.925536532161033, 6.991415873600124, 7.057140383121724, 7.122712218758713, 7.188133484032182, 7.253406229931597, 7.318532456801609, 7.383514116140899, 7.448353112318093, 7.513051304209397, 7.577610506762381, 7.642032492489928, 7.706318992898216, 7.770471699852276, 7.834492266882491, 7.8983823104351405, 7.962143411069946, 8.025777114607376], [0.0, 0.20123466170855583, 0.3503698962101765, 0.4846182798606534, 0.6100294210155475, 0.7292539521671095, 0.8437694330325811, 0.9545116204971992, 1.0621229121845868, 1.1670697044986924, 1.2697048776900042, 1.3703040335770693, 1.4690879104371297, 1.5662369657849158, 1.661901257793066, 1.7562073694473386, 1.8492633989840235, 1.9411626438975167, 2.0319863773143556, 2.1218059783695447, 2.210684592985739, 2.298678446868631, 2.3858378966349374, 2.4722082808232564, 2.5578306159251385, 2.64274217093654, 2.7269769456385418, 2.810566071816994, 2.893538152228582, 2.975919548848581, 3.0577346294743704, 3.1390059798871786, 3.219754587336894, 3.3000000000000007, 3.3797604661887535, 3.4590530564020607, 3.5378937707621265, 3.616297633943568, 3.694278779349382, 3.7718505240023656, 3.8490254353875963, 3.925815391290366, 4.002231633516293, 4.078284816249716, 4.153985049697569, 4.229341939574949, 4.304364622912058, 4.37906180059764, 4.453441767019403, 4.527512437115363, 4.601281371110454, 4.674755797178733, 4.747942632242354, 4.820848501093349, 4.893479754002518, 4.9658424829608885, 5.037942536682837, 5.109785534485688, 5.181376879148161, 5.252721768839041, 5.323825208197957, 5.394692018641604, 5.465326847961371, 5.535734179271719, 5.605918339362826, 5.675883506505828, 5.74563371775442, 5.815172875782401, 5.884504755293181, 5.953633009033908, 6.022561173443988, 6.0912926739651265, 6.159830830037635, 6.228178859805663, 6.296339884552029, 6.364316932881662, 6.432112944671045, 6.499730774799648, 6.56717319667808, 6.634442905586468, 6.701542521835563, 6.768474593762072, 6.835241600568844, 6.901845955019752, 6.968290005998352, 7.034576040938742, 7.100706288136442, 7.166682918946535, 7.232508049875794, 7.2981837445750815, 7.363712015737789, 7.429094826909802, 7.4943340942160015, 7.5594316880080115, 7.624389434437631, 7.689209116960012, 7.753892477770456, 7.818441219178398, 7.882857004921974, 7.947141461426285, 8.011296179008337, 8.075322713031424], [0.0, 0.20243974584998847, 0.35246806956646337, 0.4875203932378918, 0.6136825530099643, 0.733621054560764, 0.8488223059031893, 0.9602276676578034, 1.068483384415656, 1.1740586455732411, 1.2773084445875396, 1.3785100337053997, 1.4778854730846729, 1.5756163009012814, 1.6718534739440487, 1.7667243332348854, 1.860337624351197, 1.9527872034949596, 2.0441548304929396, 2.134512311930675, 2.2239231718771575, 2.312443972743027, 2.4001253727031893, 2.4870129818039124, 2.573148062162042, 2.6585681059571344, 2.743307316576332, 2.8273970122366947, 2.9108659669811474, 2.993740700652393, 3.0760457269731982, 3.1578037669786627, 3.239035933599816, 3.319761892076462, 3.4, 3.4797674300952037, 3.5590802783002435, 3.6379536592642823, 3.716401791027523, 3.794438070361117, 3.8720751400099256, 3.949324948888788, 4.026198806124339, 4.102707429702988, 4.178860990376163, 4.2546691513823225, 4.330141104468338, 4.405285602627812, 4.480110989918992, 4.554625228678124, 4.628835924404187, 4.702750348556812, 4.77637545947981, 4.849717921637463, 4.922784123328865, 4.99558019302664, 5.06811201446991, 5.140385240627013, 5.212405306630949, 5.284177441779488, 5.355706680682307, 5.4269978736289195, 5.498055696243795, 5.56888465848831, 5.639489113063415, 5.709873263261627, 5.780041170312342, 5.849996760260334, 5.919743830413644, 5.989286055393722, 6.058626992817772, 6.1277700886405935, 6.196718682180807, 6.265476010854263, 6.3340452146354345, 6.402429340265906, 6.47063134522747, 6.538654101495904, 6.606500399090257, 6.674172949431209, 6.741674388521119, 6.809007279957283, 6.876174117789142, 6.943177329229287, 7.0100192772274506, 7.076702262915921, 7.143228527934261, 7.209600256640607, 7.2758195782163355, 7.341888568670378, 7.407809252749048, 7.47358360575683, 7.539213555293227, 7.604700982910375, 7.670047725695894, 7.735255577785076, 7.80032629180627, 7.865261580263114, 7.930063116856958, 7.9947325377526735, 8.059271442790802, 8.123681396648855], [0.0, 0.2036168004640398, 0.3545174406810487, 0.49035500521537373, 0.6172507153663745, 0.737886580797276, 0.853757652010635, 0.9658107630228504, 1.074695915914266, 1.1808850281106056, 1.2847351571234393, 1.3865251672399543, 1.4864784097524693, 1.584777478362572, 1.6815742075740039, 1.776996678813366, 1.8711542699424164, 1.9641413828755114, 2.0560402528192943, 2.146923103867596, 2.2368538294402893, 2.325889320821409, 2.41408053072999, 2.5014733344048636, 2.5881092338750777, 2.6740259393126724, 2.7592578529750966, 2.8438364751743443, 2.9277907472555653, 3.0111473432569893, 3.0939309194326357, 3.1761643289255503, 3.257868807424637, 3.339064134510198, 3.4197687745110095, 3.5, 3.579774000502684, 3.6591059785500164, 3.738010234850798, 3.8165002440696343, 3.894588722460673, 3.972287688413872, 4.049608516811035, 4.126561987956648, 4.203158331738398, 4.2794072675801536, 4.355318040672776, 4.430899454902796, 4.506159902843699, 4.581107393127504, 4.655749575474188, 4.730093763622162, 4.804146956373449, 4.877915856941832, 4.951406890770179, 5.024626221964173, 5.097579768473025, 5.170273216133388, 5.24271203168, 5.314901474815577, 5.3868466094227525, 5.458552313992302, 5.530023291334388, 5.601264077632861, 5.672279050896781, 5.743072438858056, 5.813648326359475, 5.884010662273193, 5.954163265986111, 6.024109833485196, 6.093853943072869, 6.163399060739901, 6.232748545220863, 6.301905652755062, 6.370873541573865, 6.439655276133667, 6.5082538311120794, 6.57667209518354, 6.64491287458923, 6.7129788965149695, 6.780872812289743, 6.848597200416488, 6.916154569445911, 6.983547360703253, 7.050777950877256, 7.1178486544797845, 7.1847617261840675, 7.251519363048856, 7.31812370663532, 7.384576845023026, 7.450880814730861, 7.517037602548413, 7.583049147282915, 7.648917341426494, 7.714644032748236, 7.780231025815152, 7.845680083445981, 7.910992928101446, 7.976171243214375, 8.041216674462868, 8.106130830989493, 8.170915286569336], [0.0, 0.20476725110792193, 0.35652049159320065, 0.49312554885516774, 0.6207382295661439, 0.7420556969510294, 0.8585814486631533, 0.9712676684042124, 1.0807680308164909, 1.1875571196956047, 1.2919940099556333, 1.3943591414885168, 1.4948771275386208, 1.5937315934760452, 1.6910752316812006, 1.7870368472506373, 1.8817264360394779, 1.9752389333401832, 2.067657038994663, 2.159053385168456, 2.2494922262841897, 2.339030775066046, 2.4277202721198567, 2.5156068518830947, 2.602732250874477, 2.6891343923314253, 2.7748478728868013, 2.8599043708317935, 2.9443329910323857, 3.0281605582371833, 3.1114118680099447, 3.1941099026157387, 3.2762760177267514, 3.3579301046794394, 3.4390907321274637, 3.519775270235123, 3.6000000000000005, 3.6797802098485253, 3.759130281289606, 3.8380637651207454, 3.9165934494439076, 3.9947314205538818, 4.072489117601433, 4.149877381800598, 4.226906500838722, 4.303586249055167, 4.379925923876836, 4.4559343789328985, 4.53162005421553, 4.606991003606137, 4.682054920046205, 4.756819158597333, 4.831290757605314, 4.905476458157607, 4.97938272200133, 5.0530157480698366, 5.126381487749211, 5.199485659001518, 5.272333759448972, 5.344931078512014, 5.417282708684606, 5.489393556021374, 5.561268349903719, 5.632911652145283, 5.704327865491211, 5.775521241560429, 5.846495888275398, 5.917255776819706, 5.9878047481600865, 6.058146519166119, 6.128284688357907, 6.198222741309339, 6.267964055732095, 6.337511906263484, 6.406869468979128, 6.476039825649832, 6.5450259677603695, 6.61383080030641, 6.682457145384616, 6.750907745589615, 6.8191852672306075, 6.8872923033792715, 6.955231376759817, 7.023004942491163, 7.090615390690525, 7.1580650489469395, 7.225356184672712, 7.292491007340146, 7.3594716706103975, 7.426300274360844, 7.492978866616859, 7.559509445393548, 7.6258939604525535, 7.6921343149787305, 7.7582323671812, 7.824189931822919, 7.890008781682685, 7.95569064895326, 8.021237226578998, 8.086650169536204, 8.15193109605923, 8.217081588815109], [0.0, 0.2058924136478517, 0.3584795133590718, 0.4958351930587798, 0.624149084569721, 0.7461331715873947, 0.8632992132387264, 0.9766046253190532, 1.0867066743058615, 1.194082551755071, 1.2990933056386602, 1.402020916819889, 1.503091232756148, 1.602488887808901, 1.700367413378204, 1.796856322323538, 1.892066214909251, 1.9860925480817022, 2.079018476104901, 2.170917030246251, 2.261852817995919, 2.351883366452645, 2.4410601977810056, 2.529429699919658, 2.617033838722661, 2.7039107458094214, 2.7900952079156363, 2.875619077399522, 2.9605116190535385, 3.0447998050238954, 3.1285085671219166, 3.2116610138964576, 3.294278618365628, 3.3763813811655243, 3.4579879729815204, 3.539115859424126, 3.6197814109523425, 3.7, 3.779786087100046, 3.859153297509397, 3.9381144895985467, 4.016681816074496, 4.0948667789442705, 4.1726802789926065, 4.250132660436004, 4.3272337513222245, 4.40399290016601, 4.480419009245771, 4.556520564930062, 4.632305665355047, 4.70778204573367, 4.782957101542385, 4.857837909801549, 4.932431248639789, 5.006743615310469, 5.080781242809066, 5.154550115223557, 5.228055981935274, 5.301304370774963, 5.374300600227567, 5.447049790769469, 5.519556875413262, 5.591826609527525, 5.6638635799923165, 5.735672213745151, 5.807256785766898, 5.878621426552385, 5.949770129106204, 6.02070675550057, 6.091435043028654, 6.161958609983839, 6.232280961092671, 6.302405492626802, 6.37233549721714, 6.442074168391319, 6.511624604853974, 6.580989814527597, 6.650172718370332, 6.719176153985801, 6.788002879038742, 6.856655574489287, 6.925136847657618, 6.993449235129903, 7.0615952055155375, 7.12957716206504, 7.197397445157167, 7.265058334663284, 7.3325620521963835, 7.399910763251638, 7.467106579244906, 7.534151559455127, 7.601047712876172, 7.667796999983302, 7.734401334419066, 7.800862584603137, 7.867182575270299, 7.933363088940478, 7.999405867324552, 8.065312612669327, 8.131084989044933, 8.196724623577651, 8.262233107631019], [0.0, 0.2069935054081614, 0.36039662546342843, 0.4984868694167167, 0.6274869706144198, 0.7501234161659722, 0.8679160499328884, 0.9818274078731414, 1.0925182714587234, 1.20046838421763, 1.3060407249698003, 1.4095187825835713, 1.511129612325646, 1.6110588359633389, 1.7094608059670735, 1.806465727817976, 1.902184793259399, 1.9967139697317757, 2.090136856199692, 2.1825268744943664, 2.2739489776202757, 2.364461000325254, 2.4541147403091905, 2.5429568335887387, 2.6310294704470896, 2.7183709864276873, 2.8050163543021656, 2.890997596771923, 2.9763441351345645, 3.0610830857806035, 3.1452395138541647, 3.2288366514862794, 3.3118960865305827, 3.3944379265845455, 3.4764809421824747, 3.5580426923391952, 3.6391396350612633, 3.7197872249927273, 3.8, 3.8797916582064906, 3.959175126747954, 4.038162623322838, 4.116765711449734, 4.194995350209672, 4.272861939138974, 4.350375358844802, 4.42754500783681, 4.50437983600189, 4.580888375092835, 4.657078766553822, 4.732958786964928, 4.808535871352867, 4.883817134585182, 4.958809391039248, 5.033519172715078, 5.107952745941578, 5.182116126809022, 5.256015095445849, 5.329655209245085, 5.403041815134392, 5.476180060973941, 5.549074906157575, 5.621731131485103, 5.694153348366755, 5.766346007414856, 5.838313406472442, 5.910059698123807, 5.981588896727726, 6.0529048850103875, 6.124011420251625, 6.194912140095089, 6.2656105680102465, 6.3361101184316695, 6.4064141015989176, 6.4765257281182915, 6.546448113265981, 6.616184281050544, 6.685737168051113, 6.755109627046528, 6.824304430449234, 6.89332427355687, 6.962171777633301, 7.030849492830101, 7.099359900958538, 7.16770541812147, 7.235888397213762, 7.303911130299304, 7.371775850872044, 7.439484736008007, 7.507039908414688, 7.574443438383843, 7.6416973456532356, 7.708803601182554, 7.7757641288483095, 7.842580807062297, 7.909255470317795, 7.975789910667468, 8.042185879136685, 8.108445087075697, 8.174569207453912, 8.240559876099317, 8.306418692885899], [0.0, 0.20807165492618435, 0.3622737928038931, 0.5010832957004431, 0.6307553087857051, 0.754030520391307, 0.8724366906605981, 0.9869413690309702, 1.0982087787308326, 1.2067211620876115, 1.312843388538244, 1.4168604235354951, 1.5190005049895803, 1.6194502215001725, 1.7183647295003182, 1.8158749126613918, 1.9120925418817496, 2.007114084459294, 2.1010235747934476, 2.193894817141496, 2.2857931028231215, 2.376776567825104, 2.4668972796416204, 2.5562021171983895, 2.6447334905315523, 2.7325299348596466, 2.819626605114016, 2.9060556907899895, 2.991846766429388, 3.0770270896615703, 3.1616218561853504, 3.2456544191389916, 3.32914647881895, 3.4121182475554357, 3.4945885936512453, 3.576575167579355, 3.6580945130697446, 3.739162165263756, 3.819792737749953, 3.9000000000000004, 3.9797969464821277, 4.059195858532072, 4.1382083598983455, 4.216845466743613, 4.295117632771378, 4.373034790053085, 4.450606386051606, 4.527841417270354, 4.604748459900735, 4.681335697792578, 4.757610948031173, 4.8335816843694275, 4.909255058733491, 4.984637920994207, 5.059736837174265, 5.1345581062414665, 5.209107775621583, 5.283391655549521, 5.357415332364628, 5.431184180844652, 5.504703375662989, 5.577977902045055, 5.651012565692007, 5.723812002033134, 5.7963806848622905, 5.868722934408322, 5.940842924884737, 6.0127446915595595, 6.084432137382604, 6.15590903920393, 6.227179053614274, 6.2982457224354995, 6.369112477886654, 6.4397826474490625, 6.510259458451836, 6.580546042397442, 6.6506454390453325, 6.7205606002701535, 6.790294393709768, 6.859849606217057, 6.929228947128423, 6.998435051360887, 7.06747048234878, 7.136337734830171, 7.205039237492469, 7.273577355485863, 7.3419543928127196, 7.4101725946004, 7.478234149264477, 7.546141190568815, 7.613895799588523, 7.681500006581401, 7.748955792773107, 7.816265092060886, 7.883429792640455, 7.950451738560265, 8.017332731207091, 8.08407453072672, 8.150678857383168, 8.217147392859696, 8.283481781504692, 8.349683631525268], [0.0, 0.20912791051825463, 0.36411284060521604, 0.5036269964912325, 0.6339572769844454, 0.7578582832551989, 0.8768655309731552, 0.99195148124666, 1.1037837291689718, 1.2128469651239586, 1.3195079107728942, 1.4240529781680489, 1.5267115638472706, 1.6276712036091765, 1.7270878415234092, 1.8250930256796172, 1.92179909437029, 2.01730300460022, 2.1116892173613135, 2.2050319115710173, 2.2973967099940698, 2.388842043738954, 2.479420244615436, 2.5691784295255564, 2.658159223795896, 2.7464013582652944, 2.833940166325698, 2.920808000879288, 3.0070345866001826, 3.092647319488453, 3.177671523146437, 3.2621306692623415, 3.3460465682920746, 3.4294395351717815, 3.5123285339873695, 3.5947313048127305, 3.6766644753604867, 3.7581436596346185, 3.839183545408157, 3.9197979720521547, 4.0, 4.079801972932441, 4.159215573604822, 4.23825187410229, 4.316921381195563, 4.3952340773752825, 4.4731994580634495, 4.550826565433355, 4.628124019212611, 4.705100044795565, 4.781762498950185, 4.858118893369158, 4.934176416284696, 5.009941952340348, 5.085422100890581, 5.160623192879295, 5.235551306431433, 5.310212281276997, 5.384611732113843, 5.458755061004259, 5.532647468890367, 5.606293966304599, 5.679699383343787, 5.752868378968529, 5.8258054496834575, 5.898514937648644, 5.971001038267585, 6.043267807292953, 6.11531916748751, 6.187158914874126, 6.258790724605868, 6.330218156484315, 6.40144466015184, 6.472473579981408, 6.54330815968535, 6.6139515466629035, 6.6844067961045655, 6.754676874869886, 6.824764665154016, 6.894672967957023, 6.964404506368994, 7.03396192868285, 7.103347811345951, 7.172564661760659, 7.2416149209433796, 7.310500966050759, 7.379225112781206, 7.4477896176592555, 7.51619668020976, 7.584448445028429, 7.652547003754746, 7.72049439695292, 7.788292615906108, 7.855943604328796, 7.923449260001947, 7.990811436335141, 8.05803194385972, 8.125112551656684, 8.192054988722797, 8.258860945278226, 8.325532074018732, 8.392069991315337], [0.0, 0.21016324782757845, 0.3659154675608827, 0.5061203213571382, 0.6370958328077823, 0.7616102403894224, 0.881206661706144, 0.9968623722655995, 1.1092482722488564, 1.2188514516144568, 1.3260404475662164, 1.4311030901071837, 1.5342699114571616, 1.6357293758552072, 1.7356381994090566, 1.834128581468369, 1.9313134164829886, 2.02729014146635, 2.122143635554528, 2.215948444905289, 2.3087705171644286, 2.4006685727174877, 2.491695202455265, 2.581897756543198, 2.6713190713346533, 2.759998069414672, 2.8479702591015363, 2.93526815346814, 3.02192162434765, 3.107958203370531, 3.19340333950962, 3.2782806206552806, 3.3626119652412556, 3.446417788777598, 3.52971714923642, 3.612527874518055, 3.6948666746545586, 3.7767492409507426, 3.8581903338949393, 3.9392038613732896, 4.019802948477954, 4.1000000000000005, 4.179806756533023, 4.259234344977151, 4.338293324119362, 4.416993725870985, 4.495345092663361, 4.5733565114352, 4.651036644588124, 4.7283937582382425, 4.805435748050316, 4.88217016290545, 4.958604226622902, 5.034744857930283, 5.110598688853727, 5.186172081679976, 5.261471144625171, 5.3365017463302795, 5.411269529290053, 5.485779922310969, 5.5600381520836475, 5.6340492539463485, 5.707818081908444, 5.78134931799582, 5.8546474809741245, 5.927716934500319, 6.000561894748241, 6.073186437549529, 6.14559450508751, 6.217789912178168, 6.2897763521692855, 6.361557402486082, 6.4331365298492065, 6.504517095188731, 6.575702358275757, 6.6466954820914665, 6.717499536951802, 6.788117504404456, 6.858552280913568, 6.928806681346223, 6.998883442273808, 7.0687852251002505, 7.138514619028219, 7.20807414387357, 7.277466252737537, 7.346693334545443, 7.4157577164601145, 7.484661666177543, 7.553407394111852, 7.621997055476079, 7.690432752264866, 7.7587165351447185, 7.826850405257113, 7.894836315939355, 7.962676174367823, 8.03037184312784, 8.097925141714212, 8.165337847966194, 8.232611699440358, 8.29974839472471, 8.366749594697069, 8.433616923730687], [0.0, 0.21117857649667537, 0.3676832574505088, 0.5085654609217306, 0.6401737337761886, 0.7652896882459743, 0.8854638969567312, 1.0016783567736787, 1.114607209092488, 1.2247398970728647, 1.3324467383744965, 1.4380169535482887, 1.541682188548127, 1.6436318181107263, 1.7440233154617242, 1.8429895186247205, 1.9406438674587725, 2.0370842697094433, 2.132396014576039, 2.226654008359461, 2.3199245173080025, 2.4122665454937735, 2.5037329378816784, 2.5943712733925666, 2.684224595328347, 2.773332014314629, 2.861729210215451, 2.9494488531790073, 3.0365209593535565, 3.122973193378803, 3.208831127175207, 3.294118462589599, 3.3788572239468064, 3.4630679253871275, 3.546769716954459, 3.629980512678268, 3.7127171033191626, 3.794995255988887, 3.8768298024858034, 3.958234717887036, 4.039223190693941, 4.119807685626903, 4.2, 4.279811314469007, 4.3592522388319095, 4.438332853465632, 4.517062746902364, 4.595451049981117, 4.673506466952808, 4.751237303868337, 4.828651494537549, 4.905756624311273, 4.982559951908067, 5.059068429480904, 5.135288721096184, 5.211227219777765, 5.286890063251452, 5.362283148510456, 5.437412145309226, 5.51228250868158, 5.586899490569026, 5.661268150636263, 5.735393366343075, 5.8092798423348855, 5.882932119208141, 5.956354581701257, 6.029551466357007, 6.102526868697955, 6.175284749952678, 6.247828943367082, 6.320163160132039, 6.392290994955823, 6.464215931307303, 6.535941346353684, 6.60747051561449, 6.678806617351715, 6.7499527367144365, 6.82091186965463, 6.891686926629668, 6.962280736105658, 7.032696047874757, 7.102935536198513, 7.173001802788403, 7.242897379633875, 7.312624731687443, 7.382186259415671, 7.45158430122424, 7.520821135764707, 7.589898984130019, 7.658820011945358, 7.727586331360401, 7.796200002948717, 7.864663037519582, 7.9329773978471545, 8.001145000321653, 8.069167716526815, 8.137047374747691, 8.204785761412525, 8.272384622472279, 8.339845664721075, 8.407170557060672, 8.474360931711901], [0.0, 0.21217474608418974, 0.36941768944160697, 0.5109644611131087, 0.6431935552698873, 0.7688997055389974, 0.8896407988926345, 1.0064034644623605, 1.1198650236972743, 1.2305172285537345, 1.3387321435503965, 1.444800353546619, 1.5489545972143937, 1.6513851426071562, 1.7522502057817577, 1.8516832513840689, 1.9497982543905792, 2.046693584396345, 2.142454932926078, 2.2371575596279754, 2.3308680433408506, 2.4236456664702666, 2.5155435232608965, 2.606609417072427, 2.696886594250223, 2.7864143499121687, 2.87522853223102, 2.963361965466287, 3.050844807358118, 3.1377048530455953, 3.2239677950768004, 3.309657447104693, 3.3947959373470367, 3.479403876713239, 3.563500505581603, 3.6471038224854864, 3.7302306973907147, 3.8128969717855035, 3.895117547432633, 3.97690646533233, 4.058276976198625, 4.139241603550363, 4.219812200351802, 4.3, 4.379815662341381, 4.459269315303929, 4.538370592650766, 4.617128668292812, 4.695552287540595, 4.773649795626241, 4.851429163784884, 4.9288980131489, 5.006063636677607, 5.082933019318606, 5.159512856573971, 5.235809571624669, 5.31182933114933, 5.387578059958403, 5.463061454551651, 5.538284995695325, 5.613253960105343, 5.6879734313138055, 5.762448309788405, 5.836683322367271, 5.910683031065713, 5.984451841305789, 6.0579940096148555, 6.1313136508348345, 6.204414744880175, 6.277301143078933, 6.349976574128376, 6.4224446496937, 6.494708869675962, 6.566772627173108, 6.638639213155913, 6.710311820878837, 6.781793550044194, 6.853087410736435, 6.924196327142115, 6.995123141069756, 7.065870615282809, 7.1364414366578215, 7.2068382191790405, 7.27706350677979, 7.347119776040236, 7.4170094387504, 7.4867348443466675, 7.556298282229429, 7.625701983968952, 7.694948125406084, 7.764038828653914, 7.83297616400613, 7.901762151757379, 7.970398763940598, 8.038887925985984, 8.107231518305891, 8.175431377809739, 8.243489299352696, 8.311407037121704, 8.37918630596216, 8.446828782648351, 8.514336107100606], [0.0, 0.21315255132709482, 0.37112014725161685, 0.5133192358364695, 0.6461577064808712, 0.7724431723144726, 0.8937406998163491, 1.0110414649887693, 1.1250259107101082, 1.236188055170807, 1.3449016775452185, 1.4514587018501839, 1.5560929393315899, 1.6589955348913357, 1.7603254337234238, 1.8602167155442402, 1.9587838805828395, 2.0561257517695952, 2.152328415537773, 2.247467478368922, 2.3416098259297846, 2.434815013828309, 2.5271363809934773, 2.6186219510862903, 2.709315169752474, 2.7992555132010786, 2.888478994810814, 2.977018590111468, 3.0649045958248413, 3.1521649351836425, 3.238825419139809, 3.3249099710912877, 3.410440821233518, 3.495438675461081, 3.5799228628213755, 3.6639114647938245, 3.747421429089325, 3.8304686702014377, 3.9130681585675697, 3.9952339998957607, 4.076979505965826, 4.1583172580111265, 4.23925916362019, 4.319816507959073, 4.4, 4.479819814345411, 4.559285629155531, 4.63840666061916, 4.717191694349501, 4.795649114037603, 4.87378692765396, 4.95161279145286, 5.029134032003154, 5.106357666442506, 5.1832904211291435, 5.259938748845204, 5.336308844688391, 5.412406660773589, 5.488237919852822, 5.5638081279503995, 5.6391225860999326, 5.714186401260929, 5.789004496484841, 5.863581620393385, 5.9379223560258705, 6.012031129106704, 6.085912215779404, 6.159569749849101, 6.233007729571644, 6.306230024023893, 6.379240379086783, 6.452042423069832, 6.5246396720033575, 6.597035534622366, 6.669233317064035, 6.741236227298909, 6.813047379314251, 6.884669797066455, 6.9561064182181624, 7.0273600976743404, 7.098433610930609, 7.16932965724596, 7.240050862651162, 7.310599782803229, 7.380978905695624, 7.45119065423308, 7.521237388679335, 7.591121408985461, 7.660844957005893, 7.730410218608821, 7.799819325687072, 7.869074358075261, 7.938177345378544, 8.007130268717951, 8.075935062397008, 8.14459361549393, 8.213107773383514, 8.2814793391925, 8.34971007519199, 8.417801704130222, 8.485755910508884, 8.55357434180586], [0.0, 0.21411273683383236, 0.3727919273191351, 0.5156315782762436, 0.6490684446398417, 0.7759227869576797, 0.8977667218433067, 1.0155958902365496, 1.1300938001979068, 1.2417566953150931, 1.3509600385206133, 1.4579970688576045, 1.5631026508184112, 1.6664687903528688, 1.768255148653314, 1.8685964094232759, 1.9676075886794906, 2.065387954518693, 2.162023981166576, 2.257591615688218, 2.352158045049347, 2.4457830931372793, 2.538520339156171, 2.6304180230985805, 2.721519786319265, 2.8118652828552366, 2.901490688314201, 2.990429126770383, 3.078711031422829, 3.166364451289668, 3.253415313593096, 3.3398876494984764, 3.4258037893413182, 3.5111845322897763, 3.596049294462555, 3.6804162387904813, 3.764302389328584, 3.847723732260233, 3.9306953054599707, 4.013231278177633, 4.095345022158439, 4.177049175310262, 4.258355698861591, 4.339275928814622, 4.4198206223821455, 4.5, 4.579823783425494, 4.659301230363469, 4.738441166003568, 4.817252011802742, 4.895741811804884, 4.973918256753311, 5.051788706220774, 5.129360208954943, 5.2066395216141865, 5.283633126048402, 5.36034724526227, 5.436787858183089, 5.512960713342088, 5.5888713415664935, 5.664525067769412, 5.739927021915607, 5.815082149233333, 5.889995219735362, 5.964670837106163, 6.039113447006641, 6.113327344843005, 6.1873166830418835, 6.261085477870014, 6.334637615833239, 6.407976859686512, 6.481106854083752, 6.55403113089389, 6.626753114207216, 6.6992761250540225, 6.771603385855757, 6.843738024627217, 6.915683078946777, 6.987441499710326, 7.0590161546832855, 7.1304098318640134, 7.20162524267082, 7.272665024963919, 7.34353174591276, 7.4142279047184365, 7.484755935200107, 7.555118208253763, 7.625317034191033, 7.695354664965206, 7.765233296291122, 7.834955069665118, 7.9045220742908135, 7.9739363489161, 8.04319988358634, 8.112314621318484, 8.18128245970046, 8.2501052524199, 8.318784810726063, 8.387322904828528, 8.45572126523598, 8.523981584038259, 8.592105516134618], [0.0, 0.2150560012811139, 0.3744342461109714, 0.5179031710029347, 0.6519278877385316, 0.779341081401979, 0.9017217944989074, 1.0200700542224543, 1.135072379798462, 1.2472272009944148, 1.3569116348286068, 1.4644202121961598, 1.5699888322748314, 1.6738103468884058, 1.776045120609731, 1.8768284304855951, 1.9762757992308468, 2.074486932263548, 2.171548684767872, 2.2675373383904236, 2.362520376086217, 2.4565578852941288, 2.549703681259193, 2.6420062164931806, 2.7335093246109574, 2.8242528343436897, 2.9142730806691652, 3.0036033335882935, 3.092274160372268, 3.1803137336079623, 3.267748094738831, 3.3546013807985045, 3.4408960204978234, 3.5266529046347816, 3.6118915348649603, 3.696630154135195, 3.7808858614992578, 3.8646747135669606, 3.948011814461555, 4.030911395854898, 4.113386888400854, 4.19545098568306, 4.277115701624679, 4.358392422168177, 4.4392919519167835, 4.519824556332027, 4.6000000000000005, 4.679827581409963, 4.759316164630554, 4.838474208219088, 4.917309791657148, 4.9958306395692915, 5.074044143950546, 5.151957384601541, 5.22957714794681, 5.3069099443917604, 5.383962024356255, 5.460739393107497, 5.537247824501623, 5.613492873731681, 5.689479889169452, 5.7652140233795395, 5.840700243376188, 5.915943340186256, 5.990947937775544, 6.065718501390128, 6.140259345359442, 6.214574640403453, 6.288668420482387, 6.362544589223921, 6.436206925959665, 6.509659091399902, 6.582904632973061, 6.655946989854114, 6.72878949770401, 6.8014353931404345, 6.87388781795852, 6.946149823118562, 7.018224372516494, 7.090114346551555, 7.16182254550451, 7.233351692738705, 7.304704437735334, 7.3758833589734, 7.446890966664122, 7.517729705348742, 7.5884019563681315, 7.658910040211898, 7.729256218754214, 7.799442697383046, 7.869471627029003, 7.9393451060996, 8.009065182324344, 8.078633854515655, 8.148053074250365, 8.217324747476141, 8.286450736046957, 8.355432859191453, 8.42427289491779, 8.492972581358336, 8.561533618057355, 8.629957667204694], [0.0, 0.2159830011764466, 0.37604824667308606, 0.5201355950341274, 0.6547380259355499, 0.7827004347638213, 0.9056086704946488, 1.024467070943044, 1.1399651145791705, 1.2526033796543472, 1.362760608751532, 1.4707326023426428, 1.5767562764499412, 1.6810253141858964, 1.7837007713755948, 1.8849185081781648, 1.9847945452696554, 2.0834290178487977, 2.1809091554894415, 2.2773115686505836, 2.3727040311728307, 2.467146889502245, 2.5606941908547243, 2.653394596596817, 2.745292129288391, 2.8364267893425428, 2.926835068359152, 3.0165503797496216, 3.1056034225455105, 3.194022490771758, 3.281833738123583, 3.369061405677411, 3.4557280188231463, 3.541854558408664, 3.6274606101515228, 3.712564495634866, 3.797183387618016, 3.881333411922876, 3.9650297377790915, 4.048286658204208, 4.131117661744985, 4.21353549670081, 4.295552228780919, 4.377179293006938, 4.458427540555386, 4.539307281137113, 4.6198283214285025, 4.7, 4.77983121912885, 4.85933047383302, 4.938505878420735, 5.017365190813583, 5.09591583486982, 5.17416492090759, 5.252119264604341, 5.329785404428612, 5.40716961774273, 5.484277935699632, 5.561116157043687, 5.637689860913628, 5.71400441873542, 5.790065005283817, 5.865876608983404, 5.941444041512782, 6.016771946769378, 6.091864809246732, 6.166726961871214, 6.241362593340701, 6.315775755003821, 6.3899703673148585, 6.463950225896247, 6.537719007237782, 6.611280274059097, 6.684637480359745, 6.757793976179055, 6.830753012086169, 6.903517743418944, 6.976091234288851, 7.048476461367713, 7.120676317470742, 7.192693614949327, 7.264531088905884, 7.336191400242209, 7.40767713855185, 7.478990824866301, 7.550134914264015, 7.621111798350641, 7.691923807618269, 7.76257321369089, 7.833062231462806, 7.903393021136223, 7.97356769016385, 8.04358829510194, 8.11345684337881, 8.183175294983567, 8.252745564079477, 8.32216952054604, 8.391448991453696, 8.460585762474714, 8.529581579233689, 8.598438148600783, 8.667157139930715], [0.0, 0.21689435423953968, 0.3776350045179607, 0.5223303379776745, 0.6575007318068903, 0.7860030855966226, 0.9094299399062388, 1.0287898704136338, 1.1447752648842044, 1.2578888137888424, 1.3685108578372631, 1.476938445648991, 1.583409492927473, 1.6881185000425407, 1.7912272024038711, 1.8928720334405795, 1.9931695033848278, 2.0922201699617475, 2.1901116308155406, 2.2869208196675723, 2.3827157963341827, 2.4775571618968373, 2.571499191626862, 2.664590752220322, 2.756876051992884, 2.8483952601417557, 2.9391850222452836, 3.0292788927047383, 3.1187077000880614, 3.2074998578085046, 3.295681629918353, 3.38327735978069, 3.4703096678326357, 3.5567996234519956, 3.6427668949994234, 3.728229881367067, 3.8132058277757244, 3.8977109280911586, 3.981760415550478, 4.065368643481462, 4.148549157346593, 4.231314759237461, 4.313677565775277, 4.395649060232418, 4.477240139572585, 4.558461157009064, 4.63932196059809, 4.719831928314758, 4.8, 4.8798347065170145, 4.9593441964128315, 5.038536260344046, 5.117418353494326, 5.195997616184223, 5.274280892850339, 5.352274749550669, 5.429985490135243, 5.507419171205803, 5.584581615974864, 5.661478427122665, 5.738114998740222, 5.814496527437557, 5.890628022688206, 5.966514316473936, 6.042160072287373, 6.117569793544642, 6.192747831455153, 6.2676983923912415, 6.342425544796442, 6.416933225667628, 6.4912252466430855, 6.565305299725775, 6.63917696266844, 6.712843704044987, 6.786308888030435, 6.859575778909894, 6.932647545335357, 7.005527264347495, 7.078217925178373, 7.150722432849609, 7.223043611579475, 7.295184208011312, 7.36714689427475, 7.4389342708902815, 7.5105488695270415, 7.581993155622831, 7.65326953087482, 7.724380335608751, 7.795327851033863, 7.86611430139034, 7.936741855995485, 8.00721263119453, 8.077528692221492, 8.147692054975144, 8.217704687714889, 8.287568512680915, 8.357285407642792, 8.426857207380388, 8.496285705100727, 8.565572653794167, 8.63471976753311, 8.703728722716216], [0.0, 0.21779064244827795, 0.3791955329279463, 0.524488801367084, 0.6602177695795953, 0.7892511429290606, 0.9131880429452478, 1.0330412131161864, 1.1495059024112548, 1.2630868786054932, 1.3741660541180072, 1.4830417050837914, 1.5899527303625414, 1.6950944340720178, 1.798629219972815, 1.9006940852877636, 2.001406021712675, 2.100866002514632, 2.1991619873239103, 2.29637122778065, 2.392562064949687, 2.4877953503387125, 2.582125583504678, 2.6756018330790265, 2.768268490062642, 2.860165889646807, 2.9513308288430395, 3.0417970007118855, 3.131595361216405, 3.220754441184651, 3.309300613201749, 3.3972583212266185, 3.484650279172448, 3.5714976434835544, 3.6578201637975787, 3.7436363150377407, 3.8289634136885087, 3.9138177205347287, 3.9982145317629145, 4.0821682600141385, 4.165692506725776, 4.2488001268924265, 4.331503287205689, 4.4138135183910965, 4.495741762442661, 4.5772984153569976, 4.658493365886178, 4.739336030758581, 4.819835386757888, 4.8999999999999995, 4.9798380527047765, 5.059357367722705, 5.13856543104505, 5.217469412498823, 5.296076184804385, 5.374392341153132, 5.452424211444942, 5.5301778773096935, 5.607659186023583, 5.684873763419211, 5.761827025877983, 5.838524191484249, 5.914970290412556, 5.991170174612215, 6.067128526847141, 6.1428498691432525, 6.218338570690776, 6.2935988552443405, 6.368634808059807, 6.4434503824031815, 6.518049405663863, 6.5924355851015415, 6.666612513253563, 6.740583673027277, 6.814352442499722, 6.887922099445253, 6.961295825609909, 7.034476710749841, 7.107467756449733, 7.180271879735834, 7.252891916497135, 7.325330624727134, 7.397590687597691, 7.469674716375619, 7.541585253191852, 7.613324773672297, 7.684895689438834, 7.756300350488298, 7.827541047456737, 7.898620013775722, 7.969539427726983, 8.040301414401279, 8.11090804756694, 8.181361351453187, 8.251663302453, 8.321815830749982, 8.391820821873344, 8.46168011818495, 8.531395520302016, 8.600968788458916, 8.670401643811235, 8.739695769685136], [0.0, 0.21867241478865557, 0.38073078774317565, 0.5266123072839791, 0.6628908034679973, 0.7924465962305566, 0.9168852814894792, 1.0372237030430083, 1.1541599247257708, 1.2682007579738996, 1.3797296614612147, 1.4890461189579087, 1.5963899965571828, 1.7019573891075983, 1.8059113578963655, 1.9083894548090878, 2.009509145207664, 2.1093718111712048, 2.2080657684535, 2.3056685814645985, 2.402248867962862, 2.497867725826423, 2.5925798752654297, 2.686434583576253, 2.7794764214863066, 2.871745887492587, 2.963279927587241, 3.0541123712444294, 3.1442742997590987, 3.233794359472506, 3.3226990297448697, 3.411012853501745, 3.49875863661849, 3.5859576211958455, 3.6726296368321156, 3.7587932332502274, 3.844465797044167, 3.9296636548340724, 4.014402164736364, 4.098695797744795, 4.182558210365093, 4.266002309638071, 4.349040311514802, 4.431683793405444, 4.51394374160503, 4.595830594200607, 4.6773542799809915, 4.758524253800214, 4.8393495287864, 4.919838705737215, 5.0, 5.079841266097739, 5.159370020330342, 5.238593461553411, 5.317518490312999, 5.396151726494454, 5.47449952562562, 5.552567993959163, 5.630363002445239, 5.707890199693841, 5.785155024015763, 5.8621627146218955, 5.938918322052528, 6.015426717901136, 6.091692603890811, 6.16772052035587, 6.243514854176144, 6.319079846207048, 6.394419598244476, 6.469538079560088, 6.54443913303929, 6.619126480951413, 6.693603730378966, 6.767874378330595, 6.841941816560216, 6.915809336112957, 6.989480131616843, 7.062957305337567, 7.1362438710123755, 7.209342757477727, 7.282256812104321, 7.354988804051985, 7.427541427355979, 7.499917303855392, 7.572118985973524, 7.644148959359385, 7.716009645398827, 7.787703403603154, 7.859232533882547, 7.930599278711104, 8.0018058251898, 8.072854307013282, 8.143746806345979, 8.214485355612636, 8.28507193920809, 8.355508495130707, 8.425796916543666, 8.495939053268033, 8.565936713211213, 8.635791663734263, 8.705505632961241, 8.775080311033618], [0.0, 0.21954018974274897, 0.3822416716933762, 0.5287021043496951, 0.6655214052158416, 0.7955913244274352, 0.9205238295149465, 1.0413397994978932, 1.1587400683925582, 1.273233458854784, 1.3852049512676265, 1.494955217866294, 1.6027250766234842, 1.7087114005663788, 1.813077898071128, 1.9159626668813095, 2.017483638505862, 2.1177425973463797, 2.2168282096270095, 2.314818347562754, 2.411781901213225, 2.507780210916073, 2.6028682140319646, 2.6970953733685588, 2.7905064365267958, 2.8831420627170448, 2.9750393445471404, 3.0662322457394096, 3.1567519709311465, 3.2466272801431395, 3.335884757815737, 3.4245490442701154, 3.512643035883984, 3.6001880590547843, 3.6872040220721756, 3.77370954827141, 3.8597220932430636, 3.945258048397485, 4.030332832797917, 4.114960974864498, 4.199156185297141, 4.282931422356684, 4.366298950471721, 4.449270392995958, 4.531856779822206, 4.614068590459797, 4.695915793098738, 4.777407880113504, 4.858553900399724, 4.939362488886288, 5.019841893522146, 5.1000000000000005, 5.17984435444729, 5.259382184287402, 5.3386204174503655, 5.4175657000917425, 5.49622441296052, 5.574602686541286, 5.652706415082348, 5.7305412696095255, 5.808112710014888, 5.8854259963005, 5.9624861990491045, 6.039298209186509, 6.11586674709402, 6.19219637112372, 6.268291485564244, 6.344156348100323, 6.419795076805333, 6.495211656702508, 6.570409945927276, 6.645393681520344, 6.720166484878488, 6.794731866887814, 6.869093232761997, 6.94325388660628, 7.0172170357261825, 7.09098579469836, 7.164563189219714, 7.237952159749431, 7.31115556495766, 7.384176184993299, 7.457016724582563, 7.529679815968992, 7.602168021704864, 7.674483837303192, 7.7466296937587975, 7.818607959946423, 7.890420944903163, 7.962070900002102, 8.03356002102346, 8.104890450129192, 8.176064277746544, 8.247083544365694, 8.317950242256307, 8.38866631710746, 8.459233669595124, 8.529654156881149, 8.599929594047408, 8.670061755468513, 8.740052376126373, 8.809903152869579], [0.0, 0.22039445754429599, 0.38372903832506117, 0.5307593731572211, 0.6681110609339241, 0.7986871040769149, 0.9241057425534331, 1.0453918277949574, 1.1632489208807975, 1.278187824381326, 1.390595016703017, 1.500772340047314, 1.6089615494501486, 1.7153602840047624, 1.8201328891041304, 1.923417999853376, 2.025334006652774, 2.1259830899641434, 2.225454261026822, 2.3238256950696967, 2.4211665502151893, 2.5175384054865195, 2.612996412014863, 2.7075902250759842, 2.8013647663912633, 2.8943608533828953, 2.986615722992291, 3.078163471100332, 3.1690354237668052, 3.2592604529225766, 3.3488652464525224, 3.437874540557454, 3.5263113207087367, 3.6141969962884106, 3.701551553052639, 3.7883936868032038, 3.8747409210533195, 3.960609710995069, 4.046015535689864, 4.130972980090368, 4.215495808247134, 4.299597028843772, 4.383288954031831, 4.46658325239344, 4.54949099674058, 4.632022707360115, 4.714188391229955, 4.7959975776610015, 4.8774593507596595, 4.958582379054777, 5.03937494258946, 5.119844957740972, 5.2, 5.2798473249130495, 5.359393887367894, 5.438646359381401, 5.517611146531127, 5.596294403156407, 5.67470204644106, 5.752839769477819, 5.830713053404113, 5.908327178689558, 5.985687235647391, 6.0627981342348285, 6.1396646132009804, 6.2162912486352395, 6.292682461964071, 6.368842527439572, 6.444775579159236, 6.52048561765269, 6.595976516068019, 6.671252025987381, 6.74631578289902, 6.8211713113504855, 6.895822029805714, 6.970271255226779, 7.044522207399361, 7.118578013019463, 7.192441709557476, 7.266116248914413, 7.3396045008839845, 7.412909256433119, 7.486033230812576, 7.558979066508394, 7.631749336044178, 7.704346544643398, 7.7767731327602885, 7.849031478487278, 7.921123899846316, 7.993052656970958, 8.064819954185573, 8.136427941987629, 8.207878718938574, 8.279174333468479, 8.350316785599265, 8.42130802859101, 8.49214997051554, 8.56284447576123, 8.633393366472742, 8.703798423929081, 8.774061389863258, 8.84418396772659], [0.0, 0.22123568222761164, 0.38519369556889926, 0.5327852312054493, 0.6706611773112421, 0.8017356167921694, 0.9276329662835192, 1.0493819889772134, 1.1676889313782872, 1.283066545741944, 1.3959027856259774, 1.5065006453348073, 1.6151028026603444, 1.7219076510654525, 1.8270801632338407, 1.930759503427644, 2.0330645139320347, 2.134097765221937, 2.233948608284123, 2.332695516734894, 2.430407912666647, 2.5271476101438766, 2.622969970804382, 2.7179248394533913, 2.8120573092742234, 2.905408353485292, 2.998015351157871, 3.0899125283135778, 3.181131330580789, 3.2717007400917852, 3.361647546596561, 3.450996580711654, 3.539770915641787, 3.627992042486576, 3.7156800232859135, 3.8028536252016796, 3.889530438632672, 3.975726981578877, 4.061458792183811, 4.146740511069515, 4.231585954822614, 4.316008181779626, 4.4000195510864115, 4.483631775862968, 4.566855971185146, 4.649702697494743, 4.732181999965356, 4.8143034442803545, 4.896076149219317, 4.977508816398042, 5.058609757463771, 5.139386919009827, 5.219847905441824, 5.300000000000001, 5.379850184118272, 5.459405155279963, 5.538671343512109, 5.6176549266445726, 5.696361844446501, 5.77479781174062, 5.85296833058534, 5.930878701605326, 6.008534034543057, 6.085939258096591, 6.16309912910239, 6.2400182411163465, 6.316701032441088, 6.393151793643128, 6.469374674599416, 6.545373691109218, 6.621152731104059, 6.696715560485531, 6.772065828618187, 6.847207073502441, 6.922142726650183, 6.996876117684011, 7.071410478679226, 7.145748948266129, 7.219894575508848, 7.29385032357552, 7.3676190732135876, 7.441203626042833, 7.514606707677869, 7.587830970690853, 7.6608789974244695, 7.733753302664384, 7.806456336179817, 7.8789904851401475, 7.951358076414994, 8.023561378764628, 8.095602604927114, 8.167483913608164, 8.239207411379239, 8.310775154489068, 8.382189150593467, 8.453451360407925, 8.52456369928719, 8.595528038735837, 8.66634620785348, 8.73701999471809, 8.807551147710713, 8.877941376784577], [0.0, 0.22206430349229198, 0.3866364089863525, 0.5347807373898009, 0.6731730872677196, 0.8047384559998254, 0.9311073443492157, 1.053312368661375, 1.1720624206334085, 1.2878721729947298, 1.4011310323534025, 1.5121431278557542, 1.621152046224736, 1.728356923990697, 1.8339233517298699, 1.9379910149334496, 2.0406792010012653, 2.142090864578081, 2.242315691307931, 2.341432448724022, 2.439510818933869, 2.5366128475218006, 2.6327941034783797, 2.7281046182987265, 2.8225896540592164, 2.9162903374403073, 3.0092441875137155, 3.1014855584919943, 3.1930460137807084, 3.2839546440624896, 3.3742383394262845, 3.4639220234897987, 3.553028855876672, 3.641580408179785, 3.72959681757986, 3.8170969215297412, 3.904098376311715, 3.990617761792669, 4.076670674313042, 4.1622718093302025, 4.247435035179738, 4.332173459107167, 4.416499486548577, 4.500424874494563, 4.583960779651635, 4.667117802014916, 4.749906024381429, 4.832335048262077, 4.914414026590126, 4.99615169357261, 5.077556391987407, 5.158636098191195, 5.239398445071306, 5.319850743146793, 5.3999999999999995, 5.479852938199159, 5.55941601185448, 5.638695421934409, 5.717697130455047, 5.796426873643549, 5.874890174165861, 5.9530923524997315, 6.031038537525788, 6.1087336764021485, 6.186182543781641, 6.263389750424969, 6.340359751258082, 6.41709685291748, 6.4936052208231585, 6.569888885815253, 6.645951750387235, 6.721797594545593, 6.797430081323294, 6.872852761972063, 6.948069080856253, 7.023082380069307, 7.097895903792018, 7.172512802410184, 7.24693613640797, 7.321168880051831, 7.395213924878828, 7.469074083001995, 7.542752090244525, 7.616250609113583, 7.689572231623814, 7.762719481979827, 7.835694819126261, 7.9085006391734565, 7.981139277706143, 8.053613011982058, 8.12592406302691, 8.198074597631672, 8.270066730257811, 8.341902524855579, 8.413583996600309, 8.4851131135512, 8.556491798236816, 8.62772192917131, 8.69880534230504, 8.769743832413097, 8.840539154424947, 8.911193024698319], [0.0, 0.22288073840335182, 0.388057904729788, 0.5367468960965402, 0.6756480551080614, 0.8076971331010888, 0.9345306254885786, 1.0571849451020823, 1.1763715899285072, 1.2926071249274789, 1.406282388387635, 1.5177026276073364, 1.6271123248731227, 1.7347113488546961, 1.8406658989335996, 1.945116174164487, 2.048181900515638, 2.1499664111517545, 2.2505597214524005, 2.3500408885451165, 2.448479850728549, 2.545938881701948, 2.642473754759149, 2.7381346853395554, 2.8329671019287264, 2.9270122824122304, 3.02030788380327, 3.112888386620058, 3.2047854703132237, 3.2960283325193234, 3.3866439621905924, 3.4766573745781573, 3.56609181445363, 3.654968932719357, 3.7433089405918127, 3.8311307447810505, 3.9184520664839115, 4.00528954652432, 4.091658838583751, 4.177574692148446, 4.263051026541897, 4.3481009971993245, 4.43273705516627, 4.516971000658722, 4.600814031401602, 4.6842767863616555, 4.7673693854060115, 4.850101465346199, 4.932482212766883, 5.014520393987015, 5.096224382457283, 5.177602183859993, 5.258661459145323, 5.339409545709959, 5.419853476900109, 5.499999999999999, 5.579855592848823, 5.659426479213322, 5.738718643029364, 5.817737841613744, 5.896489617936876, 5.974979312037616, 6.053212071653277, 6.1311928621305505, 6.20892647567661, 6.28641754000394, 6.363670526417339, 6.440689757386955, 6.517479413647241, 6.594043540857998, 6.670386055860487, 6.7465107525586525, 6.822421307452862, 6.8981212848512605, 6.97361414178165, 7.048903232624914, 7.123991813489299, 7.198883046343219, 7.273580002922923, 7.348085668429963, 7.422402945032338, 7.496534655182011, 7.570483544760622, 7.644252286064227, 7.717843480637198, 7.7912596619645536, 7.864503298031416, 7.937576793757593, 8.010482493314754, 8.083222682333133, 8.155799590004197, 8.228215391085277, 8.3004722078118, 8.37257211172228, 8.444517125400983, 8.516309224142812, 8.587950337544646, 8.659442351027119, 8.730787107290597, 8.80198640770878, 8.87304201366326, 8.943955647822072], [0.0, 0.22368538294402893, 0.38945887224606723, 0.5386846609422752, 0.6780872812289742, 0.810613083098949, 0.9379044700445586, 1.0610015965572785, 1.1806185292756417, 1.2972736980632469, 1.411359352213996, 1.5231818410307298, 1.6329865294304864, 1.7409740076492863, 1.847311075082052, 1.952138436930378, 2.055576251397503, 2.157728224701751, 2.2586846971964114, 2.358525011421243, 2.457319358166294, 2.5551302359514643, 2.6520136194234585, 2.748019905309573, 2.8431946861013855, 2.9375793887059807, 3.031211806085994, 3.124126543241282, 3.2163553939916985, 3.307927661383171, 3.398870431803512, 3.489208810813963, 3.5789661271044633, 3.6681641097414945, 3.7568230429081106, 3.844961901571412, 3.932598470905343, 4.019749451810569, 4.106430554481521, 4.192656581653068, 4.278441502900276, 4.3637985211521455, 4.448740132405011, 4.533278179476028, 4.61742390051617, 4.701187972901002, 4.784580553032421, 4.867611312512795, 4.9502894710922165, 5.032623826737823, 5.114622783130152, 5.196294374853641, 5.277646290516048, 5.358685894003545, 5.439420244054143, 5.519856112311127, 5.6000000000000005, 5.679858153356563, 5.759436577919901, 5.838741051791886, 5.917777137954177, 5.996550195724248, 6.07506539142379, 6.153327708325396, 6.231341955937077, 6.309112778678297, 6.386644663996167, 6.463941949965828, 6.54100883241503, 6.617849371609223, 6.694467498530258, 6.770867020778841, 6.847051628128246, 6.923024897754495, 6.998790299165956, 7.074351198853509, 7.149710864680608, 7.224872470031013, 7.299839097730561, 7.374613743757987, 7.449199320758702, 7.523598661374294, 7.597814521399588, 7.67184958277817, 7.745706456446514, 7.81938768503603, 7.892895745441769, 7.9662330512657835, 8.039401955142678, 8.112404750954273, 8.185243675939864, 8.257920912708101, 8.330438591156112, 8.402798790301075, 8.475003540029201, 8.547054822766608, 8.618954575076403, 8.69070468918598, 8.762307014448217, 8.833763358740141, 8.905075489802288, 8.976245136521872], [0.0, 0.22447861343640918, 0.3908399667499978, 0.5405949381951426, 0.6804919064256981, 0.8134876697463803, 0.9412304559216297, 1.0647641080266308, 1.1848052249146899, 1.3018740748993325, 1.4163642982643256, 1.5285833306848295, 1.638777407188085, 1.7471478293408649, 1.8538619880401574, 1.9590610874547003, 2.0628657118913485, 2.165379935330207, 2.266694418488469, 2.3668887852694827, 2.4660334753730564, 2.5641912089506103, 2.6614181591454877, 2.7577649014012704, 2.8532771898890985, 2.947996598423669, 3.041961053988581, 3.1352052842995373, 3.2277611959232635, 3.319658195819808, 3.410923466430414, 3.5015822023453715, 3.5916578149825473, 3.681172110463786, 3.7701454449036724, 3.858596860558115, 3.9465442056706346, 4.034004240366436, 4.120992730551254, 4.207524531453249, 4.293613662186226, 4.379273372499262, 4.464516202701847, 4.549354037607993, 4.633798155221276, 4.717859270781246, 4.801547576706313, 4.8848727788961686, 4.967844129795874, 5.050470458571817, 5.132760198705566, 5.214721413273713, 5.296361818149261, 5.377688803332114, 5.458709452591894, 5.539430561585411, 5.619858654592737, 5.7, 5.779860624643058, 5.859446327114023, 5.938762690121931, 6.017815091989409, 6.096608717358892, 6.175148567174601, 6.253439467999966, 6.331486080724439, 6.409292908708461, 6.486864305410805, 6.564204481538417, 6.641317511755213, 6.718207340983047, 6.79487779032509, 6.871332562639252, 6.947575247786891, 7.023609327579908, 7.099438180447391, 7.175065085841256, 7.2504932283986765, 7.325725701877772, 7.400765512881582, 7.475615584384308, 7.550278759072616, 7.6247578025139005, 7.699055406162424, 7.773174190213531, 7.847116706315286, 7.920885440146271, 7.994482813867628, 8.067911188456847, 8.141172865930285, 8.21427009146091, 8.287205055397317, 8.35997989518964, 8.432596697227655, 8.505057498595926, 8.577364288750626, 8.649519011122283, 8.721523564648482, 8.793379805240258, 8.865089547185711, 8.936654564494114, 9.008076592183643], [0.0, 0.22526078784323253, 0.3922018114909096, 0.5424785899098494, 0.6828630158383433, 0.8163221902639539, 0.9445100840442131, 1.0684741774263533, 1.18893356618432, 1.3064103314571607, 1.421299485130822, 1.533909534110873, 1.6444875714071185, 1.7532356000025209, 1.8603215940517497, 1.965887249736056, 2.070053571526859, 2.172924996040161, 2.2745924998918152, 2.3751359844270965, 2.4746261347862566, 2.5731258896631264, 2.6706916179310314, 2.767374071258883, 2.8632191632438846, 2.958268612560742, 3.052560478346025, 3.146129609320866, 3.2390080232273886, 3.3312252294914018, 3.422808505268784, 3.5137831329379807, 3.6041726054917214, 3.69399880503321, 3.783282158605981, 3.8720417748168736, 3.9602955640999182, 4.048060344979382, 4.135351938295806, 4.222185251038977, 4.308574351170972, 4.394532534608361, 4.48007238535615, 4.565205829639859, 4.6499441847601934, 4.734298203292939, 4.818278113171019, 4.901893654113411, 4.985154110804443, 5.068068343174892, 5.150644814091995, 5.232891614727366, 5.314816487839238, 5.396426849177264, 5.477729807193789, 5.558732181224445, 5.639440518282538, 5.719861108595792, 5.800000000000002, 5.8798630112919215, 5.959455744633009, 6.0387835970861445, 6.117851771359158, 6.196665285821584, 6.2752289838545545, 6.353547542587949, 6.43162548107374, 6.509467167939915, 6.587076828565227, 6.6644585518113715, 6.741616296345907, 6.8185538965862795, 6.895275068292651, 6.971783413834914, 7.048082427157009, 7.124175498459842, 7.200065918622267, 7.275756883378023, 7.351251497265136, 7.426552777362868, 7.501663656830246, 7.576586988259009, 7.651325546852907, 7.72588203344432, 7.800259077358414, 7.874459239134229, 7.9484850131114575, 8.022338829891034, 8.096023058677046, 8.169540009507013, 8.242891935376994, 8.316081034267638, 8.389109451076834, 8.461979279464174, 8.534692563612253, 8.607251299909317, 8.679657438557593, 8.75191288511133, 8.824019501948314, 8.895979109678356, 8.967793488492095, 9.039464379453216], [0.0, 0.22603224696268157, 0.39354499983290214, 0.5443364368049916, 0.6852016425738122, 0.8191178796696308, 0.9477447833663809, 1.0721334212564202, 1.1930053518281234, 1.310884444211514, 1.426167063104648, 1.5391627719683343, 1.650119510041132, 1.7592399721132406, 1.866692707606755, 1.9726198979751843, 2.0771429620985273, 2.1803666942608055, 2.2823823826489202, 2.383270202249299, 2.4831010802802607, 2.5819381709841545, 2.6798380362829146, 2.776851601656607, 2.873024937944464, 2.968399906696711, 3.0630146973924783, 3.1569042781006282, 3.2501007762156555, 3.3426338022254116, 3.43453072670288, 3.5258169186120223, 3.6165159514029055, 3.7066497821191997, 3.7962389077617047, 3.8853025023792265, 3.973858537744335, 4.061923889980334, 4.14951443410999, 4.236645128175622, 4.32333008831839, 4.4095826559898885, 4.49541545829204, 4.58084046229456, 4.665869024056941, 4.75051193297972, 4.834779452023808, 4.918681354264166, 5.002226956182731, 5.085425148053219, 5.168284421725968, 5.250812896082731, 5.3330183403986595, 5.414908195820402, 5.496489595144892, 5.577769381062194, 5.6587541230074185, 5.739450132750671, 5.819863478839995, 5.9, 5.979865317578078, 6.059464847120631, 6.138803809153401, 6.217887239232522, 6.296719997326436, 6.375306776582964, 6.4536521115306495, 6.531760385758882, 6.60963583911723, 6.687282574470668, 6.764704564044153, 6.841905655387003, 6.918889576984887, 6.995659943544867, 7.072220260976727, 7.148573931091922, 7.2247242560397, 7.300674442498353, 7.376427605638136, 7.451986772871014, 7.527354887401315, 7.602534811590156, 7.677529330145633, 7.75234115314977, 7.826972918932479, 7.9014271968019765, 7.975706489640414, 8.049813236372895, 8.123749814317414, 8.19751854142276, 8.27112167840091, 8.344561430760026, 8.417839950743705, 8.490959339181776, 8.563921647257626, 8.636728878196603, 8.709382988879865, 8.781885891387688, 8.85423945447601, 8.926445504989756, 8.99850582921625, 9.070422174181862], [0.0, 0.22679331552660542, 0.3948700971669639, 0.546169260907824, 0.6875087710349914, 0.8218759147586127, 0.950935915476668, 1.075743379809746, 1.1970222957910757, 1.3152982964597326, 1.4309690811052553, 1.5443452555132613, 1.6556755937534577, 1.7651634731055335, 1.8729780105109017, 1.979261866159341, 2.0841368677578815, 2.1877081624412393, 2.2900673457709058, 2.391294862688868, 2.4914618792310343, 2.590631762285114, 2.688861264221533, 2.786201481990502, 2.882698641555435, 2.9783947454177286, 3.07332811164353, 3.1675338260419705, 3.261044124183039, 3.353888716255457, 3.446095064991105, 3.537688624773265, 3.628693048425687, 3.719130366923154, 3.809021146281499, 3.8983846251100758, 3.987238835693844, 4.075600710979356, 4.163486179441844, 4.250910249488547, 4.337887084790794, 4.424430071721909, 4.510551879900273, 4.5962645166896765, 4.681579376386368, 4.766507284719655, 4.8510585392066545, 4.935242945829049, 5.019069852438111, 5.1025481792418175, 5.18568644668324, 5.268492800981055, 5.350975037570177, 5.433140622652194, 5.514996713040729, 5.596550174465731, 5.677807598482121, 5.758775318112236, 5.839459422337407, 5.919865769541689, 6.0, 6.079867547493319, 6.159473650125313, 6.238823360407233, 6.317921554671424, 6.396772941867908, 6.475382071793344, 6.5537533427970205, 6.6318910090044145, 6.709799187095173, 6.787481862669053, 6.864942896230375, 6.9421860288189166, 7.019214887312746, 7.096032989426325, 7.172643748425276, 7.249050477577452, 7.325256394358281, 7.401264624427044, 7.477078205389246, 7.552700090359216, 7.628133151335871, 7.703380182403638, 7.778443902769603, 7.853326959647148, 7.9280319309955525, 8.00256132812437, 8.076917598170763, 8.15110312645734, 8.225120238737611, 8.29897120333555, 8.37265823318544, 8.446183487777652, 8.51954907501568, 8.592757052989406, 8.665809431669196, 8.738708174525186, 8.811455200075777, 8.884052383369154, 8.956501557401378, 9.028804514474343, 9.100963007496798], [0.0, 0.22754430321145303, 0.396177642671109, 0.5479778079888158, 0.6897853399853291, 0.8245974177668624, 0.9540847788368779, 1.0793055219673207, 1.2009860325552735, 1.3196536841846696, 1.435707493058943, 1.5494590934822081, 1.6611580832974042, 1.7710085132336653, 1.8791800602345368, 1.9858158568848736, 2.0910381343035414, 2.1949523878021986, 2.297650516245539, 2.3992132309553615, 2.499711933621858, 2.599210200961464, 2.6977649732704765, 2.7954275166980085, 2.8922442102769303, 2.988257195592814, 3.0835049175955973, 3.1780225782751317, 3.271842519944041, 3.364994551171309, 3.457506225627005, 3.5494030819822937, 3.640708851383249, 3.7314456377564973, 3.821634075218754, 3.911293466084772, 4.000441902350369, 4.089096373032687, 4.177272859351408, 4.264986419411571, 4.352251263785105, 4.439080823172045, 4.525487809144069, 4.611484268825321, 4.697081634242333, 4.782290766971983, 4.867121998629874, 4.951585167668537, 5.035689652893072, 5.119444404049213, 5.202857969794041, 5.285938523321054, 5.368693885878432, 5.4511315483908245, 5.533258691370433, 5.615082203281909, 5.696608697506991, 5.777844528038749, 5.858795804021144, 5.939468403237281, 6.01986798463889, 6.1, 6.17986970476937, 6.259482168188787, 6.338842282737745, 6.417954772959157, 6.496824203715567, 6.575454987920649, 6.653851393786697, 6.732017551625049, 6.809957460233096, 6.887674992898569, 6.965173903049065, 7.042457829572446, 7.119530301831489, 7.196394744394268, 7.27305448149996, 7.349512741278121, 7.425772659738124, 7.5018372845439885, 7.577709578588784, 7.653392423381563, 7.728888622258893, 7.804200903432053, 7.879331922880224, 7.954284267099161, 8.029060455714196, 8.10366294396577, 8.178094125075084, 8.252356332496989, 8.326451842066627, 8.400382874046041, 8.474151595076389, 8.54776012004113, 8.621210513845156, 8.694504793114522, 8.767644927821054, 8.840632842836005, 8.913470419416468, 8.986159496628153, 9.058701872707863, 9.131099306368807], [0.0, 0.2282855055701629, 0.39746815093289156, 0.5497627898058493, 0.6920322453737954, 0.8272834597481766, 0.9571926126894614, 1.0828212496184206, 1.2048981220584782, 1.3239523214592264, 1.4403841637786834, 1.5545062984379228, 1.6665691363193988, 1.7767773928266832, 1.8853012976086583, 1.992284449489975, 2.097849477744901, 2.2021022213253127, 2.3051348784470815, 2.4070284233409054, 2.507854490280699, 2.607676863077567, 2.706552667505013, 2.804533336706403, 2.9016654007895757, 2.9979911386120195, 3.093549120354176, 3.1883746626727874, 3.2825002132322627, 3.3759556776999577, 3.468768699499213, 3.560964900490809, 3.6525680891226067, 3.74360044132252, 3.8340826584207943, 3.9240341056075043, 4.0134729338112995, 4.10241618738931, 4.190879899618413, 4.278879177653889, 4.366428278357154, 4.453540676177379, 4.540229124092892, 4.626505708470112, 4.7123818985742325, 4.797868591362612, 4.882976152105036, 4.9677144513017915, 5.052092898308478, 5.136120472023718, 5.219805748950964, 5.303156928907065, 5.386181858617115, 5.468888053406687, 5.55128271717777, 5.633372760833485, 5.715164819297988, 5.796665267261833, 5.877880233768894, 5.958815615748557, 6.039477090586008, 6.119870127813873, 6.2, 6.279871792898716, 6.359490414926266, 6.438860606015281, 6.517986945897877, 6.5968738618623455, 6.675525636024247, 6.753946412148987, 6.832140202059631, 6.910110891660751, 6.987862246606349, 7.065397917637595, 7.142721445613805, 7.219836266258234, 7.296745714638429, 7.37345302939925, 7.449961356765297, 7.526273754328048, 7.602393194631892, 7.678322568572106, 7.754064688616839, 7.829622291864239, 7.90499804294507, 7.980194536780331, 8.05521430120278, 8.130059799450548, 8.204733432540515, 8.27923754152852, 8.353574409663008, 8.427746264438298, 8.50175527955316, 8.57560357678007, 8.649293227750142, 8.722826255658378, 8.796204636893588, 8.869430302597099, 8.942505140154005, 9.015430994620585, 9.088209670091219, 9.16084293100794], [0.0, 0.22901720489235822, 0.39874211344709265, 0.5515248861757632, 0.6942503429425072, 0.8299350636914463, 0.9602606006642828, 1.0862919017407517, 1.208760054234254, 1.3281958454350968, 1.4450008743915868, 1.5594887926268315, 1.671910813638732, 1.7824723089834331, 1.8913440539288588, 1.9986701075617448, 2.104573492206967, 2.2091603860507703, 2.3125232828221907, 2.4147434162900403, 2.5158926503299757, 2.6160349731925865, 2.7152276937505615, 2.813522410000466, 2.9109658011881585, 3.007600281683067, 3.1034645452905414, 3.198594021864059, 3.2930212630690865, 3.3867762704264437, 3.4798867759620045, 3.572378483659582, 3.6642752782777324, 3.7555994068225176, 3.8463716369759626, 3.9366113959973315, 4.026336892992521, 4.1155652269491325, 4.204312482533804, 4.292593815323177, 4.380423527874679, 4.467815137825698, 4.554781439030334, 4.641334556594155, 4.7274859965435745, 4.81324669076281, 4.898627037744348, 4.983636939625345, 5.06828583592021, 5.152582734306675, 5.236536238777552, 5.3201545754316895, 5.403445616144461, 5.486416900329515, 5.569075654978743, 5.651428813146051, 5.733483031021815, 5.815244703728706, 5.896719979955375, 5.977914775532007, 6.058834786040912, 6.139485498545628, 6.219872202513606, 6.300000000000001, 6.379873815153484, 6.45949840309909, 6.538878358247865, 6.618018122078417, 6.696921990431319, 6.775594120353546, 6.854038536526837, 6.932259137310841, 7.010259700429211, 7.088043888324451, 7.165615253205017, 7.242977241806325, 7.320133199885459, 7.397086376467763, 7.4738399278621, 7.55039692146012, 7.626760339333793, 7.702933081644277, 7.778917969874225, 7.854717749894718, 7.930335094877177, 8.005772608059827, 8.081032825377617, 8.15611821796384, 8.231031194531095, 8.305774103638761, 8.38034923585354, 8.454758825809298, 8.529005054171934, 8.603090049514615, 8.677015890108434, 8.750784605633125, 8.824398178812212, 8.8978585469767, 8.971167603561119, 9.044327199535513, 9.11733914477673, 9.190205209382187], [0.0, 0.22973967099940698, 0.39999999999999997, 0.5532647468890367, 0.6964404506368993, 0.832553207401873, 0.9632898741122768, 1.0897187581716392, 1.2125732532083187, 1.332385820953752, 1.449559327355391, 1.5644084133929868, 1.6771850850517902, 1.7880953617606197, 1.8973105575213467, 2.0049751858748066, 2.111212657236631, 2.216129484746681, 2.3198184539181153, 2.4223610547827845, 2.523829377920773, 2.6242876134423625, 2.723793251008921, 2.822398051389954, 2.920148841087388, 3.0170881682725814, 3.1132548488157883, 3.208684424338806, 3.303409549195784, 3.3974603195514437, 3.490864554916129, 3.583648040360387, 3.6758347359905126, 3.7674469589937924, 3.858505542566745, 3.949029975254583, 4.039038523606319, 4.1285483405506485, 4.217575561495493, 4.306135389827834, 4.394242173224471, 4.481909471966033, 4.56915012026658, 4.655976281481984, 4.7423994979359945, 4.828430735998953, 4.914080426966815, 4.99935850421438, 5.084274437034299, 5.168837261520256, 5.253055608807535, 5.336937730945339, 5.42049152464195, 5.503724553095125, 5.586644066095295, 5.66925701856763, 5.751570087700371, 5.833589688790477, 5.915321989923479, 5.996772925591858, 6.077948209345419, 6.15885334555739, 6.239493640381573, 6.319874211968252, 6.400000000000001, 6.4798757746025455, 6.559506144680631, 6.638895565724117, 6.718048347125394, 6.79696865904541, 6.875660538862313, 6.95412789723366, 7.032374523800453, 7.110404092558868, 7.1882201669232915, 7.265826204502337, 7.3432255616077375, 7.420421497514332, 7.497417178487991, 7.574215681596871, 7.650819998320297, 7.7272330379683805, 7.80345763092453, 7.879496531722051, 7.955352421965249, 8.031027913104621, 8.10652554907507, 8.181847808805415, 8.256997108606873, 8.331975804447671, 8.406786194120418, 8.481430519308438, 8.555910967556839, 8.630229674153663, 8.704388723926195, 8.778390152957073, 8.852235950224587, 8.925928059171325, 8.99946837920491, 9.072858767134527, 9.146101038546528, 9.219196969122343], [0.0, 0.23045316198021404, 0.40124225995049656, 0.5549829934817413, 0.6986033508362294, 0.8351388261674051, 0.9662815151905982, 1.0931030430980928, 1.2163390811820787, 1.3365237448137028, 1.4540611511009969, 1.5692669181884318, 1.6823938347036151, 1.7936485598995793, 1.9032029398195045, 2.011201936812686, 2.117769344564297, 2.2230120070067194, 2.3270229978124286, 2.4298840600927822, 2.5316675083159668, 2.6324377319442718, 2.732252399181824, 2.831163431548957, 2.929217800974317, 3.0264581877689865, 3.122923528351721, 3.2186494747241516, 3.3136687826534184, 3.4080116417723936, 3.5017059579890795, 3.5947775964534254, 3.687250591683425, 3.7791473301757375, 3.870488709827494, 3.9612942797085062, 4.051582363097291, 4.1413701661935365, 4.23067387451609, 4.319508738668332, 4.407889150885921, 4.49582871356297, 4.583340300772114, 4.670436113644351, 4.757127730349847, 4.843426151316649, 4.929341840236665, 5.01488476133428, 5.100064413310452, 5.1848898603218085, 5.269369760308917, 5.353512390948957, 5.437325673474621, 5.520817194572312, 5.603994226547769, 5.686863745925725, 5.769432450631431, 5.851706775885512, 5.933692908929412, 6.0153968026860705, 6.096824188449574, 6.177980587687809, 6.258871323033633, 6.339501528532512, 6.419876159207946, 6.5, 6.579877674127063, 6.659513650916188, 6.738912253143227, 6.8180776639201905, 6.897013933163908, 6.975724983677071, 7.054214616869976, 7.13248651814895, 7.210544261995093, 7.288391316755141, 7.3660310491643575, 7.443466728619746, 7.520701531220492, 7.597738543591047, 7.674580766501226, 7.7512311182964355, 7.827692438150266, 7.903967489150638, 7.9800589612299815, 8.055969473949045, 8.131701579143302, 8.207257763440257, 8.282640450655343, 8.3578520040736, 8.432894728623776, 8.507770872951077, 8.582482631394363, 8.657032145873133, 8.731421507689413, 8.805652759249202, 8.879727895707862, 8.95364886654363, 9.027417577063025, 9.101035889841834, 9.174505626104981, 9.247828567048543], [0.0, 0.2311579248730029, 0.40246932341711167, 0.5566802208774253, 0.7007397924203531, 0.8376928152294452, 0.9692365597213068, 1.0964459282906869, 1.220058842031095, 1.3406110497245236, 1.4585079043342193, 1.5740659892157813, 1.6875388660651622, 1.7991338261326801, 1.9090232409943984, 2.017352516317828, 2.1242458243691735, 2.2298103358267727, 2.334139408997385, 2.43731503697597, 2.5394097553800083, 2.640488150585136, 2.7406080671541386, 2.839821585391723, 2.938175820874259, 3.0357135844360967, 3.1324739315698316, 3.2284926233066593, 3.323802515586132, 3.4184338903658835, 3.512414738894677, 3.605771005422258, 3.698526797968047, 3.790704571490216, 3.882325287795033, 3.9734085557365133, 4.063972754628711, 4.154035143290646, 4.243611956739089, 4.332718492216221, 4.4213691859714785, 4.509577681997285, 4.5973568937372615, 4.684719059635434, 4.771675793269874, 4.858238128709713, 4.944416561646514, 5.030221086776863, 5.115661231850277, 5.200746088743034, 5.28548434187308, 5.369884294232064, 5.4539538912770835, 5.537700742895852, 5.621132143633988, 5.704255091351564, 5.787076304457164, 5.869602237851356, 5.951839097697163, 6.033792855122521, 6.115469258948741, 6.196873847529244, 6.278011959774357, 6.358888745430286, 6.439509174673788, 6.5198780470780475, 6.6000000000000005, 6.679879516434621, 6.759520932377507, 6.838928443733297, 6.9181061128041215, 6.997057874389232, 7.075787541524253, 7.154298810886074, 7.232595267887136, 7.310680391480941, 7.388557558698765, 7.466230048935959, 7.54370104800473, 7.620973651968924, 7.698050870775193, 7.774935631693716, 7.851630782580732, 7.928139094974129, 8.004463267032586, 8.080605926327888, 8.156569632499432, 8.232356879779234, 8.307970099395138, 8.383411661859498, 8.458683879149898, 8.533789006788272, 8.608729245824115, 8.683506744727262, 8.75812360119528, 8.83258186388017, 8.906883534038807, 8.981030567111238, 9.055024874230726, 9.128868323669106, 9.202562742220909, 9.27610991652939], [0.0, 0.23185419629780504, 0.4036816023792486, 0.5583569989102893, 0.7028504926870738, 0.8402160320749276, 0.9721559998433715, 1.0997485361036305, 1.2237337846433811, 1.3446491079750031, 1.4629010800265252, 1.5788072377351472, 1.6926219065507078, 1.804553002106073, 1.9147734151782072, 2.0234289894114346, 2.1306442710915867, 2.236526753706097, 2.3411700767665398, 2.444656480339503, 2.5470587185272, 2.648441572246068, 2.7488630602926603, 2.8483754198429136, 2.9470259083901564, 3.0448574657193697, 3.1419092649623073, 3.2382171748660658, 3.3338141503356633, 3.428730564541102, 3.5229944930436634, 3.6166319582398385, 3.709667140764881, 3.802122563213604, 3.8940192505313895, 3.9853768706361365, 4.0762138582022835, 4.1665475240341845, 4.25639415205015, 4.345769085569226, 4.434686804324316, 4.523160993404951, 4.611204605151374, 4.698829914871057, 4.7860485711233665, 4.872871641213181, 4.959309652446166, 5.045372629623962, 5.1310701291946454, 5.216411270420161, 5.301404763876813, 5.386058937565714, 5.470381760876497, 5.554380866618636, 5.638063571309674, 5.721436893887957, 5.804507572998602, 5.887282082985005, 5.969766648703789, 6.05196725926854, 6.133889680816609, 6.2155394683835095, 6.2969219769609115, 6.378042371806588, 6.4589056380679795, 6.539516589775077, 6.619879878253012, 6.7, 6.779881304072105, 6.85952799901246, 6.9389441593592665, 7.018133731763798, 7.097100540746931, 7.175848294120328, 7.254380588096061, 7.332700912106595, 7.4108126533551735, 7.488719101115023, 7.5664234507943435, 7.643928807782644, 7.721238191092844, 7.798354536812363, 7.875280701375474, 7.952019464668224, 8.02857353297642, 8.104945541786366, 8.181138058447356, 8.257153584704286, 8.332994559108114, 8.408663359311413, 8.484162304255689, 8.559493656256732, 8.63465962299383, 8.70966235940823, 8.784503969515974, 8.859186508139821, 8.933711982564631, 9.008082354120441, 9.082299539697043, 9.156365413193699, 9.230281806907431, 9.30405051286305], [0.0, 0.2325422030438996, 0.40487949169997695, 0.560013873739874, 0.7049361391329267, 0.8427092985651397, 0.9750407864757836, 1.1030119422611584, 1.2273651060199287, 1.3486392348400291, 1.4672421091215282, 1.5834922080643, 1.6976446118063788, 1.8099078529518153, 1.920455335315607, 2.0294333353201464, 2.136966768831312, 2.2431634483139202, 2.3481172911464827, 2.4519107814356844, 2.554616889175079, 2.6563005875127237, 2.7570200674107994, 2.856827721054425, 2.955770946169346, 3.053892809960544, 3.1512326018025627, 3.247826296879823, 3.343706947888098, 3.4389050181270746, 3.5334486664697713, 3.627363992531831, 3.7206752487023946, 3.8134050244100766, 3.905574406989919, 3.997203122722621, 4.088309660985879, 4.178911383952325, 4.26902462386135, 4.358664769561939, 4.447846343754316, 4.5365830721373, 4.624887945486054, 4.712773275533936, 4.8002507454063785, 4.887331455249505, 4.974025963607825, 5.060344325030689, 5.146296124324085, 5.231890507810555, 5.31713621191427, 5.4020415893489435, 5.486614633152665, 5.570862998784594, 5.654794024473389, 5.738414749985473, 5.821731933962295, 5.904752069959288, 5.987481401304787, 6.069925934884539, 6.1520914539463964, 6.233983530009947, 6.315607533957325, 6.396968646373747, 6.478071867199633, 6.558922024750183, 6.639523784152924, 6.719881655249029, 6.8, 6.879883039437449, 6.959534860190408, 7.038959420621485, 7.118160556600488, 7.197141986941677, 7.275907318528565, 7.354460051148198, 7.432803582055047, 7.510941210282962, 7.588876140722234, 7.666611487977339, 7.744150280019851, 7.821495461649767, 7.898649897777576, 7.9756163765383885, 8.052397612248678, 8.128996248215314, 8.205414859405979, 8.281655954989267, 8.357721980752327, 8.4336153214032, 8.509338302764647, 8.58489319386568, 8.660282208936678, 8.735507509313482, 8.810571205255624, 8.885475357683356, 8.960221979837986, 9.03481303886962, 9.109250457356248, 9.183536114757768, 9.257671848808375, 9.331659456850558], [0.0, 0.23322216261602416, 0.4060633700770402, 0.5616513691664572, 0.7069973911089797, 0.8451734029151339, 0.9778918316077974, 1.1062371784483573, 1.230953954157625, 1.352582691748361, 1.471532363981344, 1.5881223812980791, 1.7026085696976931, 1.815200071539104, 1.9260707976746652, 2.03536745224291, 2.143215316367024, 2.2497225177583298, 2.3549832484122475, 2.459080233621178, 2.5620866567448726, 2.6640676809145964, 2.76508166724445, 2.86518116111569, 2.9644136988462697, 3.0628224735708214, 3.1604468895470634, 3.2573230271518083, 3.35348403572779, 3.4489604676501924, 3.5437805641293254, 3.6379705010967998, 3.731554601856387, 3.82455552188879, 3.9169944101889773, 4.008891050717817, 4.100263986916437, 4.191130631724921, 4.2815073651385624, 4.371409621003749, 4.460851964485465, 4.549848161416838, 4.638411240558402, 4.726553549643351, 4.814286805958883, 4.901622142108247, 4.988570147509414, 5.075140906111505, 5.161344030746735, 5.2471886944817365, 5.332683659286214, 5.417837302297441, 5.502657639925359, 5.587152350013897, 5.671328792248886, 5.755194026981213, 5.838754832614775, 5.922017721692333, 6.004988955797878, 6.087674559381455, 6.170080332601281, 6.2522118632682195, 6.334074537969004, 6.415673552437018, 6.497013921232644, 6.578100486789203, 6.658937927875176, 6.739530767518634, 6.819883380435567, 6.8999999999999995, 6.979884724790373, 7.059541524743653, 7.138974246945831, 7.218186621085082, 7.297182264591541, 7.375964687485722, 7.45453729695576, 7.532903401681967, 7.6110662159258196, 7.6890288633989785, 7.7667943809268865, 7.844365721920215, 7.921745759666527, 7.998937290453514, 8.075943036534381, 8.152765648945103, 8.22940771018263, 8.305871736752435, 8.382160181593209, 8.458275436385948, 8.534219833754179, 8.609995649361613, 8.6856051039131, 8.761050365064282, 8.836333549245147, 8.911456723402132, 8.986421906663317, 9.061231071930806, 9.13588614740426, 9.210389018039164, 9.284741526943302, 9.358945476714633], [0.0, 0.23389428374280202, 0.4072336009280796, 0.5632699878554623, 0.7090348813620975, 0.8476091015362176, 0.9807100104307473, 1.1094252347227793, 1.2345014307327489, 1.35648068923128, 1.475773161594552, 1.5926991787705242, 1.7075153040212698, 1.8204312824314357, 1.9316215260457008, 2.041233161788108, 2.1493918318285314, 2.2562059754907016, 2.361770056221211, 2.4661670377178355, 2.5694703142468787, 2.6717452367327237, 2.7730503344799082, 2.873438304299815, 2.9729568195049385, 3.0716491977078677, 3.1695549567251438, 3.2667102809133355, 3.3631484151480078, 3.4588999998529957, 3.5539933576267324, 3.648454739837041, 3.742308539884833, 3.8355774785414627, 3.9282827657510224, 4.0204442424896225, 4.1120805056385885, 4.20320901832022, 4.293846207735192, 4.384007552208571, 4.473707658880579, 4.562960333255989, 4.651778641642818, 4.740174967359096, 4.828161061459979, 4.915748088631679, 5.002946668809727, 5.0897669150041, 5.176218467750156, 5.262310526550319, 5.348051878625344, 5.433450925254512, 5.518515705950193, 5.603253920683034, 5.687672950348688, 5.771779875645212, 5.855581494511131, 5.939084338257652, 6.022294686513979, 6.105218581091968, 6.18786183886527, 6.270230063748215, 6.3523286578511, 6.434162831880852, 6.515737614849274, 6.597057863145059, 6.6781282690203945, 6.758953368538231, 6.839537549022018, 6.919885056045906, 6.999999999999999, 7.079886362262195, 7.159548001005368, 7.238988656666255, 7.318211957100034, 7.39722142244272, 7.476020469701596, 7.554612417092235, 7.633000488139268, 7.711187815556555, 7.789177444921346, 7.866972338155718, 7.944575376827744, 8.021989365283712, 8.099217033622068, 8.176261040518787, 8.253123975913295, 8.329808363563368, 8.406316663476796, 8.482651274227145, 8.558814535160307, 8.634808728498218, 8.710636081345552, 8.786298767604908, 8.861798909805591, 8.937138580850759, 9.012319805687397, 9.087344562903308, 9.162214786255008, 9.236932366130224, 9.311499150948377, 9.385916948502322], [0.0, 0.23455876685050028, 0.40839053321549457, 0.5648702124783733, 0.7110492174711066, 0.8500171207528029, 0.9834961633244984, 1.1125770617616058, 1.2380085936014802, 1.360334389670168, 1.4799657665654045, 1.5972239652809193, 1.712366277963438, 1.8256030455739303, 1.9371091756538252, 2.047032213108119, 2.155498157050422, 2.2626157548756907, 2.3684797383969083, 2.473173307007973, 2.576770063484986, 2.67933554441136, 2.7809284453707463, 2.8816016128837902, 2.981402855700717, 3.0803756144974983, 3.1785595193590095, 3.2759908574399432, 3.3727029680630567, 3.4687265787002466, 3.5640900924131698, 3.658819835148602, 3.7529402696080054, 3.8464741811114207, 3.9394428398594354, 4.031866143195476, 4.123762740833771, 4.215150145508561, 4.306044831089458, 4.396462319874751, 4.486417260502889, 4.575923497699461, 4.664994134893274, 4.7536415905828076, 4.8418776492074365, 4.929713507171739, 5.017159814582007, 5.104226713178821, 5.190923870885865, 5.277260513340935, 5.363245452728884, 5.448887114196646, 5.534193560096487, 5.61917251227432, 5.703831372594591, 5.788177241871299, 5.872216937355607, 5.9559570089138845, 6.039403754015475, 6.122563231636751, 6.20544127517684, 6.288043504470538, 6.370375336975295, 6.4524419982014205, 6.534248531447914, 6.615799806900249, 6.69710053014109, 6.778155250120137, 6.858968366625029, 6.9395441372914, 7.019886684186787, 7.100000000000001, 7.179887953864816, 7.259554296844377, 7.339002667100436, 7.4182365947695565, 7.497259506566584, 7.576074730133992, 7.654685498154299, 7.733094952241267, 7.811306146624488, 7.8893220516407325, 7.967145557044472, 8.04477947514902, 8.12222654380891, 8.19948942925329, 8.276570728779493, 8.353472973315174, 8.430198629856894, 8.50675010379246, 8.583129741113739, 8.659339830526354, 8.735382605462089, 8.811260245999495, 8.886974880697894, 8.962528588349464, 9.037923399653975, 9.113161298820303, 9.188244225098689, 9.26317407424736, 9.337952699937013, 9.412581915096363], [0.0, 0.23521580450493468, 0.4095345022158438, 0.5664525067769411, 0.7130409831864013, 0.8523981584038256, 0.9862510977103354, 1.1156935729577244, 1.2414764591322878, 1.364144909859358, 1.4841113939020587, 1.6016980521029371, 1.7171628973263064, 1.8307168597327363, 1.9425353368084246, 2.0527662867558947, 2.1615360616329813, 2.2689537134539663, 2.3751142393912095, 2.480101071893785, 2.583988019911266, 2.686840803605807, 2.7887182829770336, 2.8896734525773806, 2.9897542550772416, 3.0890042528370594, 3.18746318695209, 3.285167446223311, 3.382150463362401, 3.4784430519139553, 3.574073694501275, 3.6690687908144386, 3.7634528720789557, 3.857248787440293, 3.950477866680366, 4.0431600628783295, 4.135314077989326, 4.226957473803645, 4.318106770336912, 4.408777533367926, 4.498984452568379, 4.588741411445213, 4.6780615501320915, 4.7669573219137495, 4.855440544239713, 4.943522444877529, 5.0312137037661895, 5.118524491054955, 5.205464501748954, 5.292042987328508, 5.3782687846628505, 5.464150342499136, 5.549695745773603, 5.634912737962325, 5.719808741663586, 5.804390877581933, 5.888665982064771, 5.972640623325718, 6.056321116474367, 6.1397135374592775, 6.222823736019889, 6.305657347733075, 6.388219805231477, 6.470516348662916, 6.552552035453502, 6.634331749430897, 6.715860209358878, 6.797141976929498, 6.878181464254927, 6.958982940897133, 7.039550540470245, 7.11988826684725, 7.2, 7.279889501498987, 7.3595604196970505, 7.439016294619247, 7.518260562579212, 7.597296560540696, 7.67612753024149, 7.754756622095532, 7.833186898887814, 7.911421339275508, 7.9894628411077635, 8.067314224575645, 8.144978235202863, 8.222457546687119, 8.299754763601197, 8.376872423962295, 8.453813001677444, 8.53057890887233, 8.607172498110334, 8.683596064508118, 8.759851847753671, 8.83594203403231, 8.911868757865797, 8.987634103869349, 9.06324010843106, 9.138688761317903, 9.213982007212273, 9.289121747182731, 9.36410984009241, 9.438948103948338], [0.0, 0.23586558182407352, 0.41066583023823056, 0.5680173165568269, 0.7150107396807243, 0.8547528853379799, 0.9889755897809969, 1.1187756463768244, 1.2449060043836657, 1.3679133233990475, 1.4882112116199318, 1.6061226997942597, 1.721906513539927, 1.8357741657063853, 1.94790153831066, 2.05843699828582, 2.1675072467338548, 2.2752216369222946, 2.3816754284506283, 2.48695228424782, 2.5911262171586777, 2.694263128895531, 2.796422042057169, 2.8976560975920487, 2.9980133706108973, 3.097537543814005, 3.1962684680803317, 3.294242632733937, 3.391493562843464, 3.488052157075094, 3.583946976734608, 3.679204494440516, 3.7738493091851772, 3.8679043332342067, 3.9613909552924667, 4.0543291835589566, 4.1467377716524645, 4.238634329877253, 4.330035423885045, 4.420956662454685, 4.511412775837685, 4.601417685893802, 4.690984569055965, 4.780125913010771, 4.868853567853132, 4.957178792367002, 5.045112295994414, 5.132664276979392, 5.219844457109257, 5.306662113421295, 5.39312610719635, 5.479244910521015, 5.565026630665946, 5.65047903249836, 5.735609559121271, 5.8204253509099795, 5.904933263097113, 5.9891398820408055, 6.073051540295969, 6.156674330595808, 6.240014118839508, 6.323076556172074, 6.405867090233646, 6.488390975647813, 6.57065328381169, 6.652658912044379, 6.734412592145116, 6.815918898407505, 6.897182255132056, 6.97820694367529, 7.0589971090703285, 7.139556766250754, 7.219889805906735, 7.3, 7.379891006961865, 7.45956637659661, 7.539029554710596, 7.618283887485843, 7.697332625615357, 7.7761789282160105, 7.854825866533656, 7.933276427453924, 8.011533516831195, 8.089599962647235, 8.167478518010192, 8.245171864003783, 8.322682612395853, 8.400013308214808, 8.477166432201777, 8.55414440314588, 8.63094958010939, 8.707584264549165, 8.784050702340279, 8.86035108570732, 8.93648755506861, 9.01246220079806, 9.088277064909231, 9.163934142665774, 9.239435384122217, 9.314782695598772, 9.389977941093631, 9.465022943636015], [0.0, 0.23650827686365633, 0.4117848272957034, 0.5695650706162576, 0.7169590267181437, 0.8570819468111606, 0.9916703861175595, 1.121824126586492, 1.2482981691394417, 1.371640662931712, 1.4922663431747893, 1.6104991208224413, 1.7265984264774528, 1.8407763493271128, 1.9532092506381065, 2.06404590161907, 2.173413348611723, 2.281421242853321, 2.388165103510142, 2.4937288214789173, 2.5981866112773204, 2.7016045541890423, 2.804041833639778, 2.905551735378355, 3.006182465512296, 3.105977825770088, 3.204977775617802, 3.3032189038069224, 3.4007348267564086, 3.4975565273262412, 3.5937126446470766, 3.6892297234709703, 3.784132429818502, 3.8784437383874546, 3.972185096163404, 4.065376565864411, 4.158036952209803, 4.250183913489029, 4.341834060492502, 4.433003044530428, 4.523705635991838, 4.613955794671276, 4.70376673290529, 4.793150972407376, 4.88212039556201, 4.9706862918314885, 5.058859399839316, 5.146649945618062, 5.234067677445322, 5.321121897636788, 5.407821491618843, 5.494174954563124, 5.580190415831273, 5.6658756614484975, 5.751238154799044, 5.836285055714566, 5.921023238107077, 6.005459306281457, 6.089599610047792, 6.173450258740984, 6.257017134243833, 6.340305903099789, 6.423322027792915, 6.506070777264791, 6.588557236731256, 6.670786316855804, 6.752762762331048, 6.834491159914792, 6.915975945963041, 6.997221413498307, 7.078231718848252, 7.15901088788649, 7.239562821904685, 7.319891303142541, 7.4, 7.4798924719539785, 7.559572174200093, 7.6390424620381605, 7.718306595018794, 7.79736774086694, 7.876228979197093, 7.954893305033658, 8.033363632148992, 8.111642796230647, 8.18973355788854, 8.2676386055119, 8.345360557985213, 8.422901967271669, 8.50026532087201, 8.57745304416616, 8.654467502644449, 8.731311004034833, 8.80798580033202, 8.884494089734053, 8.960838018491541, 9.037019682674329, 9.113041129860123, 9.188904360749342, 9.264611330710094, 9.340163951256999, 9.41556409146734, 9.490813579337791], [0.0, 0.23714406097793114, 0.41289179173333673, 0.5710961816147635, 0.7188863637476046, 0.8593859637937392, 0.994336205201996, 1.124839826367287, 1.2516538578127592, 1.3753279222342187, 1.4962778697388446, 1.614828482021342, 1.731239887088656, 1.845724744268528, 1.9584598889239124, 2.069594492191822, 2.179255941941329, 2.2875541841753337, 2.3945849948357742, 2.500432490335798, 2.6051710846973517, 2.708867036844548, 2.811579689300609, 2.913362471057691, 3.014263717811496, 3.114327349038793, 3.213593431625123, 3.3120986526802496, 3.4098767189911534, 3.506958696706276, 3.603373301944294, 3.6991471508151537, 3.7943049756468987, 3.8888698128981445, 3.9828631672084853, 4.076305155228798, 4.16921463222946, 4.261609303969128, 4.35350582589152, 4.444919891380862, 4.535866310532109, 4.626359080666672, 4.716411449638648, 4.806035972822538, 4.895244564545173, 4.984048544617305, 5.072458680530122, 5.160485225805925, 5.248137954927735, 5.33542619521783, 5.4223588559884925, 5.508944455248174, 5.595191144211952, 5.681106729835511, 5.766698695566251, 5.851974220482959, 5.936940196976177, 6.0216032471045455, 6.10596973774778, 6.190045794663965, 6.273837315547639, 6.357349982175116, 6.440589271714769, 6.523560467272203, 6.6062686677333895, 6.688718796962721, 6.770915612407545, 6.852863713155838, 6.934567547489464, 7.016031419971487, 7.09725949810265, 7.178255818578969, 7.2590242931796, 7.339568714311704, 7.419892760236658, 7.499999999999999, 7.579893898085642, 7.659577818813156, 7.739055030495512, 7.818328709373171, 7.89740194333928, 7.976277735469499, 8.054959007369021, 8.133448602348325, 8.211749288438428, 8.289863761255518, 8.367794646724192, 8.445544503667858, 8.523115826274182, 8.600511046443023, 8.677732536023646, 8.754782608947664, 8.831663523263625, 8.908377483078793, 8.984926640413349, 9.061313096971814, 9.137538905836218, 9.213606073085282, 9.289516559343557, 9.365272281264218, 9.440875112949021, 9.51632688730868], [0.0, 0.23777309915742487, 0.4139870108163228, 0.5726110468866042, 0.7207932509268569, 0.8616655341946087, 0.9969737388334334, 1.1278235283148805, 1.2549739412288397, 1.37897605817674, 1.5002468323319447, 1.619111906891172, 1.7358320998657768, 1.8506206346745255, 1.963654815746283, 2.075084209903031, 2.1850365429174468, 2.29362205243049, 2.40093676843526, 2.507065030468499, 2.6120814499396006, 2.716052461528263, 2.819037565167143, 2.921090331571853, 3.0222592246512923, 3.122588280381152, 3.2221176719266778, 3.3208841837122898, 3.4189216119341475, 3.516261105145427, 3.612931455635953, 3.708959350116424, 3.8043695865187983, 3.899185262407214, 3.9934279394635515, 4.087117787699255, 4.180273712399384, 4.272913466288132, 4.365053748988733, 4.456710295513014, 4.547897955240552, 4.638630762621455, 4.728922000650508, 4.818784258006061, 4.908229480618381, 4.99726901832466, 5.085913667177477, 5.174173707897185, 5.26205894089418, 5.349578718231996, 5.436741972855375, 5.5235572453672726, 5.610032708604332, 5.6961761902306325, 5.781995193543846, 5.8674969166656785, 5.95268827026913, 6.0375758939782305, 6.122166171561209, 6.206465245025071, 6.290479027708329, 6.374213216458533, 6.457673302972559, 6.540864584369751, 6.623792173061165, 6.70646100597203, 6.788875853169091, 6.871041325939669, 6.95296188436495, 7.034641844426098, 7.1160853846783905, 7.197296552525409, 7.278279270122527, 7.359037339936485, 7.439574449985456, 7.519894178782077, 7.600000000000001, 7.67989528688285, 7.759583316412981, 7.839067273256013, 7.918350253495909, 7.997435268174157, 8.076325246645675, 8.155023039762986, 8.233531422899468, 8.311853098821581, 8.389990700419345, 8.467946793303586, 8.545723878277949, 8.623324393693045, 8.700750717689607, 8.778005170337082, 8.85509001567362, 8.932007463653006, 9.00875967200378, 9.085348748005352, 9.16177675018567, 9.238045689944695, 9.314157533107645, 9.390114201411725, 9.465917573929858, 9.541569488434655], [0.0, 0.23839555034548993, 0.4150707612811116, 0.574110049203085, 0.7226801700820455, 0.8639212340083166, 0.9995836534554222, 1.1307759863415245, 1.2582592582957273, 1.3825859925585817, 1.5041742338188455, 1.6233504777540073, 1.7403762251544312, 1.8554652576230126, 1.9687953437426893, 2.0805164418769855, 2.1907566121638173, 2.299626380828306, 2.4072220292544086, 2.5136281177660167, 2.618919453093024, 2.7231626438302823, 2.8264173456715667, 2.928737269571885, 3.0301710063107445, 3.1307627071428374, 3.2305526504002033, 3.329577716802884, 3.427871791019969, 3.525466103146466, 3.622389520845716, 3.718668800689874, 3.8143288055278397, 3.9093926933894054, 4.003882082401419, 4.0978171953771225, 4.191216987092529, 4.284099256745569, 4.376480747676364, 4.468377236088438, 4.559803610234619, 4.650773941304916, 4.74130154706683, 4.8313990491538155, 4.921078424768637, 5.010351053460509, 5.0992277595443145, 5.187718850653655, 5.275834152854804, 5.363583042693472, 5.4509744764993915, 5.538017017233425, 5.624718859127368, 5.711087850336849, 5.797131513801947, 5.882857066487878, 5.9682714371586565, 6.053381282819765, 6.138193003951096, 6.222712758638428, 6.30694647570043, 6.390899866898068, 6.474578438304585, 6.557987500906319, 6.641132180497786, 6.724017426928278, 6.806648022751797, 6.889028591327263, 6.971163604411627, 7.053057389284586, 7.134714135440196, 7.216137900877478, 7.297332618019372, 7.378302099286852, 7.459050042352724, 7.539580035097587, 7.6198955602886045, 7.699999999999999, 7.779896639792735, 7.859588672669367, 7.939079202818896, 8.01837124916523, 8.09746774873186, 8.176371559834376, 8.255085465111627, 8.333612174405479, 8.411954327498426, 8.490114496717647, 8.56809518941348, 8.645898850319742, 8.723527863802751, 8.800984556005517, 8.878271196893072, 8.955390002204501, 9.032343135316923, 9.109132709026264, 9.18576078724936, 9.262229386651692, 9.338540478204683, 9.414695988676339, 9.490697802058682, 9.566547760935318], [0.0, 0.2390115677352187, 0.41614330985236875, 0.5755935574875919, 0.7245475856077863, 0.8661536183910526, 1.0021665914008862, 1.1336979270843972, 1.2615106175714101, 1.3861586138301498, 1.5080610407826143, 1.6275452377756257, 1.7448733813211965, 1.8602598054368322, 1.9738827380619408, 2.0858925250545255, 2.196417557461665, 2.305568647109771, 2.4134423241752234, 2.5201233674869576, 2.625686777076488, 2.730199333656196, 2.8337208470709903, 2.9363051670657283, 3.0380010099791606, 3.138852641153431, 3.238900443000345, 3.338181391540233, 3.4367294590006368, 3.5345759561755603, 3.6317498253227845, 3.728277892153817, 3.8241850837634996, 3.9194946180222954, 4.014228168918588, 4.10840601152165, 4.202047149586895, 4.295169428305628, 4.387789634282992, 4.4799235844884375, 4.571586205646243, 4.662791605306569, 4.753553135650208, 4.843883450925093, 4.933794559283241, 5.023297869678784, 5.11240423439678, 5.201123987705899, 5.289466981063105, 5.377442615243233, 5.465059869719294, 5.55232732957896, 5.639253210228033, 5.7258453801018865, 5.812111381579979, 5.898058450276264, 5.983693532858777, 6.069023303534797, 6.154054179323142, 6.238792334222171, 6.323243712370701, 6.407414040288967, 6.491308838277983, 6.574933431047747, 6.658292957637901, 6.741392380688213, 6.824236495110871, 6.90682993621162, 6.9891771873024915, 7.071282586844934, 7.153150335158711, 7.234784500728772, 7.31618902613949, 7.39736773366319, 7.478324330527513, 7.559062413884191, 7.639585475499908, 7.719896906188212, 7.800000000000001, 7.879897958188592, 7.959593892964256, 8.03909083105184, 8.118391717064146, 8.197499416702685, 8.276416719796691, 8.355146343190295, 8.433690933487226, 8.51205306966159, 8.590235265542757, 8.668239972181766, 8.746069580106171, 8.82372642146977, 8.901212772103214, 8.978530853471089, 9.055682834540708, 9.132670833567493, 9.209496919801472, 9.286163115119212, 9.362671395585158, 9.439023692946108, 9.515221896062348, 9.591267852278746], [0.0, 0.23962129904817694, 0.4172049137282789, 0.5770619274868465, 0.7263959453121281, 0.8683632226707508, 1.0047231720608427, 1.1365900512277147, 1.2647287987349876, 1.3896947787094804, 1.5119081852833198, 1.6316971928635369, 1.7493246467884707, 1.8650054278531873, 1.9789182186661156, 2.091213748625597, 2.2020207363111477, 2.311450276236086, 2.4195991448304417, 2.5265523371984857, 2.63238504470083, 2.7371642184110296, 2.840949820752113, 2.9437958388425205, 3.045751113298993, 3.1468600223869334, 3.2471630515358427, 3.34669727109386, 3.4454967399534993, 3.5435928487842774, 3.6410146136772257, 3.737788928777678, 3.8339407847708316, 3.9294934587571797, 4.0244686800166125, 4.118886775341189, 4.212766796965923, 4.306126635606156, 4.398983120690561, 4.491352109538525, 4.583248566953201, 4.674686636473863, 4.765679704343434, 4.85624045709151, 4.94638093350355, 5.036112571638534, 5.125446251466285, 5.214392333618745, 5.302960694684472, 5.391160759420179, 5.479001530205998, 5.566491614030617, 5.653639247257779, 5.740452318395656, 5.826938389064722, 5.91310471333737, 5.998958255602957, 6.084505707095021, 6.16975350120254, 6.254707827674075, 6.339374645812257, 6.423759696745982, 6.507868514858848, 6.591706438444473, 6.675278619652464, 6.758590033782549, 6.841645487978996, 6.92444962937246, 7.007006952712142, 7.089321807527139, 7.171398404852457, 7.253240823551967, 7.334853016267786, 7.41623881502306, 7.497401936502767, 7.578345987035164, 7.659074467294621, 7.739590776744833, 7.819898217839997, 7.8999999999999995, 7.979899243374526, 8.059598982409762, 8.139102169230371, 8.218411676848428, 8.297530302210166, 8.376460769090533, 8.455205730844883, 8.533767773026428, 8.612149415877447, 8.690353116701745, 8.768381272125238, 8.846236220251171, 8.923920242715965, 9.00143556665128, 9.078784366557581, 9.155968766094071, 9.232990839789545, 9.30985261467849, 9.386556071866396, 9.463103148028047, 9.539495736842316, 9.615735690366744], [0.0, 0.24022488679628623, 0.41825582103650927, 0.5785155024015763, 0.7282256812104321, 0.870550563296124, 1.007253992982465, 1.1394530347449106, 1.2679145539688907, 1.3931953137010376, 1.515716566510398, 1.6358073134502662, 1.7537310619463105, 1.869703234061905, 1.9839029624933202, 2.0964813563147375, 2.2075674583379437, 2.3172726429148485, 2.4256939302479172, 2.5329165295375953, 2.6390158215457884, 2.744058925990692, 2.8481059563360973, 2.9512110356898726, 3.053423127694541, 3.1547867224009662, 3.255342407218353, 3.355127345872216, 3.454175683046819, 3.5525188884823753, 3.650186051359235, 3.7472041335670285, 3.84359818874058, 3.9393915526136216, 4.034606009200439, 4.1292619364947285, 4.223378434722628, 4.316973439664824, 4.410063823142035, 4.502665482417024, 4.59479341998814, 4.686461815021153, 4.777684087477908, 4.8684729558444015, 4.958840489230871, 5.048798154507898, 5.138356859051113, 5.2275269895901015, 5.316318447591792, 5.404740681553142, 5.492802716530589, 5.580513181193169, 5.6678803326513965, 5.754912079283992, 5.841616001758576, 5.927999372419992, 6.014069173200365, 6.099832112187939, 6.185294638976906, 6.270462958907331, 6.355343046292874, 6.439940656723896, 6.524261338524682, 6.608310443435609, 6.692093136584149, 6.775614405802435, 6.858879070343562, 6.941891789043954, 7.024657067974739, 7.107179267621149, 7.189462609625461, 7.271511183125896, 7.353328950720973, 7.434919754086413, 7.516287319269238, 7.597435261681772, 7.678367090816315, 7.759086214699551, 7.839595944104309, 7.919899496534757, 8.0, 8.079900496589762, 8.159603945864882, 8.239113228074334, 8.318431147209644, 8.397560433906742, 8.476503748204582, 8.555263682169183, 8.633842762391128, 8.712243452363976, 8.790468154750565, 8.868519213543644, 8.9463989161269, 9.024109495241966, 9.10165313086671, 9.179031952009671, 9.256248038425221, 9.333303422253795, 9.41020008959113, 9.486939981990357, 9.563524997900371, 9.639956994043908], [0.0, 0.24082246852806916, 0.4192962712629475, 0.5799546134795288, 0.7300372102718469, 0.8727161387290319, 1.0097596309015795, 1.1422875300666446, 1.2710686092585746, 1.3966610165238236, 1.5194870523363544, 1.6398765361701577, 1.7580936309501127, 1.8743542946219975, 1.988838105491312, 2.1016965485301036, 2.2130589875561464, 2.323037073975401, 2.431728069337104, 2.5392173948075047, 2.645580618665161, 2.750885027594805, 2.855190884598055, 2.9585524474190414, 3.061018801501898, 3.1626345475706246, 3.2634403739993787, 3.3634735369618967, 3.4627682660805164, 3.5613561093793558, 3.6592662284008037, 3.756525652104698, 3.8531594964491074, 3.9491911552175694, 4.044642466614131, 4.139533859324641, 4.2338844810888245, 4.327712312304291, 4.42103426676198, 4.513866281270574, 4.60622339564853, 4.6981198243336095, 4.789569020671062, 4.880583734785299, 4.971176065809592, 5.061357509139426, 5.151138999283546, 5.240530948809491, 5.329543283815008, 5.41818547630107, 5.506466573774779, 5.594395226369791, 5.681979711736947, 5.769227957927796, 5.856147564467572, 5.942745821791755, 6.029029729200673, 6.115006011469563, 6.200681134236584, 6.286061318278158, 6.371152552769607, 6.4559606076188585, 6.540491044952169, 6.624749229822867, 6.708740340207161, 6.792469376344878, 6.875941169477452, 6.959160390030597, 7.042131555284714, 7.124859036572142, 7.20734706603689, 7.289599742989289, 7.37162103988519, 7.453414807956838, 7.534984782520146, 7.616334587981111, 7.697467742562219, 7.778387662767941, 7.859097667606958, 7.93960098258728, 8.019900743499226, 8.1, 8.179901719012623, 8.259608787950958, 8.339124017781717, 8.418450145933544, 8.497589839062487, 8.57654569568257, 8.655320248669502, 8.733915967645014, 8.81233526124879, 8.89058047930448, 8.96865391488585, 9.046557806288684, 9.12429433891375, 9.20186564706569, 9.279273815672461, 9.356520881929635, 9.43360883687355, 9.510539626887125, 9.587315155141827, 9.663937282979164], [0.0, 0.24141417706037357, 0.4203264956551569, 0.5813795805735155, 0.7318309351217656, 0.8748604302842259, 1.0122406427142765, 1.1450941671799362, 1.2741916656155645, 1.400092657455275, 1.523220480778845, 1.6439057654372955, 1.7624133234122883, 1.8789596432652034, 1.9937247445311994, 2.106860484385761, 2.2184965444977127, 2.3287448506041026, 2.437702903228914, 2.5454563334209435, 2.652080895132433, 2.757644040373658, 2.8622061802143675, 2.965821705711707, 3.0685398229143237, 3.1704052421316264, 3.2714587517104143, 3.3717376993640373, 3.4712763988181137, 3.57010647561127, 3.668257162936739, 3.76575555616538, 3.8626268329659776, 3.9588944446013463, 4.0545802829327, 4.149704826839825, 4.244287271109057, 4.338345640316419, 4.431896889810578, 4.524956995557466, 4.617541034328858, 4.709663255487844, 4.801337145434976, 4.892575485622127, 4.983390404910531, 5.073793426940226, 5.163795513086397, 5.253407101500595, 5.3426381426693075, 5.431498131866518, 5.519996138829345, 5.608140834945098, 5.695940518203074, 5.7834031361342975, 5.870536306936281, 5.957347338957337, 6.043843248695301, 6.130030777448397, 6.215916406741064, 6.301506372634372, 6.38680667901924, 6.471823109980443, 6.556561241310561, 6.64102645124503, 6.725223930482512, 6.809158691548584, 6.892835577555196, 6.976259270403447, 7.059434298472841, 7.142365043836221, 7.22505574903611, 7.307510523454974, 7.389733349309118, 7.471728087293388, 7.553498481901486, 7.635048166444693, 7.71638066778988, 7.797499410835977, 7.878407722746579, 7.959108836954871, 8.03960589695591, 8.119901959900004, 8.200000000000001, 8.279902911764232, 8.359613513066046, 8.439134548060034, 8.518468689954302, 8.597618543647512, 8.676586648238725, 8.755375479417618, 8.833987451741972, 8.912424920809034, 8.990690185326724, 9.06878548909039, 9.146713022870403, 9.224474926215459, 9.30207328917625, 9.379510153953797, 9.456787516476487, 9.533907327909558, 9.610871496100634, 9.687681886964597], [0.0, 0.24200014069659623, 0.4213467176023263, 0.5827907126669437, 0.7336072447033563, 0.8769839029201699, 1.0146975663919149, 1.1478735546632584, 1.2772844002292487, 1.4034909805968605, 1.526917661377575, 1.6478958749314954, 1.7666910759953756, 1.8835202785944531, 1.998563939209648, 2.1119742836061595, 2.223881308217849, 2.3343972104493718, 2.4436197274792533, 2.5516346982010876, 2.6585180604380967, 2.7643374299209547, 2.869153364349945, 2.973020386800897, 3.07598782275602, 3.1781004910461683, 3.2793992790201476, 3.3799216250421646, 3.4797019261245596, 3.578771884567878, 3.6771608045205415, 3.7748958471196454, 3.87200225114554, 3.968503524782251, 4.064421613027203, 4.159777044466786, 4.254589060477171, 4.348875729383868, 4.442654047689786, 4.535940030137929, 4.62874879009461, 4.72109461150916, 4.812991013516495, 4.904450808591797, 4.995486155035628, 5.086108604458359, 5.176329144840764, 5.266158239670013, 5.355605863584544, 5.444681534905392, 5.533394345383861, 5.621752987454564, 5.709765779247786, 5.797440687584904, 5.8847853491544155, 5.971807090043554, 6.058512943780688, 6.144909668026609, 6.231003760037797, 6.316801471011572, 6.402308819411573, 6.487531603361781, 6.572475412188414, 6.657145637181029, 6.741547481637221, 6.825685970249036, 6.909565957883685, 6.99319213780624, 7.076569049387546, 7.159701085336672, 7.2425924984936945, 7.325247408215426, 7.407669806383858, 7.489863563064566, 7.571832431839938, 7.653580054840072, 7.735109967492298, 7.816425603008506, 7.897530296628024, 7.97842728963227, 8.05911973314623, 8.139610691740574, 8.21990314684719, 8.3, 8.379904075911936, 8.459618125398231, 8.539144828155441, 8.618486795404868, 8.697646572408512, 8.776626640865071, 8.855429421192976, 8.93405727470701, 9.012512505694545, 9.0907973633971, 9.168914043902511, 9.246864691952613, 9.3246514026711, 9.40227622321585, 9.47974115435979, 9.557048152004054, 9.634199128627017, 9.711195954672537], [0.0, 0.24258048343234653, 0.42235715299335075, 0.5841883083691009, 0.7353665149010177, 0.8790870059843445, 1.0171309218434612, 1.150626280662058, 1.2803474675523772, 1.406856705066838, 1.5305793764919489, 1.651847708998767, 1.7709277939134624, 1.8880371656845774, 2.003356713547358, 2.117039028320994, 2.2292144181849762, 2.339995349605574, 2.44947979414573, 2.5577537965500676, 2.664893476748993, 2.770966612623078, 2.876033907096578, 2.9801500139976045, 3.0833643770962547, 3.185721922703828, 3.2872636362214527, 3.388027045794617, 3.488046630923449, 3.5873541699340685, 3.685979037249442, 3.7839484591420347, 3.881287734917545, 3.978020429135188, 4.074168539418887, 4.169752643584821, 4.264792029152079, 4.359304807775986, 4.453308016718923, 4.546817709128992, 4.639849034616006, 4.732416311383766, 4.824533090987547, 4.916212216628247, 5.007465875763357, 5.098305647705268, 5.188742546785134, 5.278787061582706, 5.368449190656695, 5.457738475154107, 5.546664028629259, 5.635234564362167, 5.7234584204309025, 5.811343582762148, 5.898897706358015, 5.986128134874491, 6.073041918707113, 6.159645831722282, 6.245946386757607, 6.331949850001461, 6.417662254350414, 6.503089411832983, 6.588236925179198, 6.673110198607518, 6.757714447893614, 6.842054709779287, 6.926135850774255, 7.009962575398548, 7.093539433908918, 7.176870829548632, 7.259961025356537, 7.342814150568115, 7.425434206638325, 7.507825072913584, 7.589990511977776, 7.671934174695227, 7.753659604971609, 7.835170244252025, 7.916469435774072, 7.997560428592116, 8.078446381387883, 8.159130366081214, 8.239615371253805, 8.319904305397767, 8.4, 8.479905212472497, 8.559622628938016, 8.639154866879851, 8.71850447766382, 8.797673948940005, 8.876665706931265, 8.955482118615071, 9.03412549380473, 9.112598087135687, 9.190902099962234, 9.269039682169534, 9.347012933905615, 9.424823907237664, 9.502474607736676, 9.579966995994253, 9.6573029890751, 9.734484461908604], [0.0, 0.2431553251494122, 0.423358010554546, 0.5855726563822676, 0.7371091091283731, 0.8811701739161584, 1.0195412117287816, 1.153352913808789, 1.283381500324819, 1.4101905261251653, 1.5342063825249108, 1.6557620839721219, 1.7751243523482076, 1.8925112375919682, 2.008104057590935, 2.1220557647579734, 2.234496976063192, 2.3455404244840654, 2.4552843137462403, 2.563814892494128, 2.67120846103914, 2.7775329578747403, 2.88284922977259, 2.9872120600736958, 3.0906710097147996, 3.193271111468849, 3.2950534478598654, 3.39605563596359, 3.496312236986042, 3.5958551045582787, 3.694713682711683, 3.792915262236678, 3.890485202390596, 3.987447123573466, 4.083823075536866, 4.179633684860121, 4.274898284767855, 4.3696350298344875, 4.463860997695511, 4.557592279540091, 4.650844060877993, 4.74363069384279, 4.83596576210281, 4.927862139293415, 5.0193320417526515, 5.110387076232349, 5.201038283164263, 5.291296175982878, 5.381170776940439, 5.470671649793559, 5.559807929692894, 5.648588350566279, 5.737021270250485, 5.825114693596401, 5.9128762937461605, 6.000313431757973, 6.087433174734662, 6.174242312594624, 6.260747373608907, 6.346954638814835, 6.432870155405105, 6.518499749180967, 6.603849036149213, 6.688923433334647, 6.773728168872738, 6.8582682914408295, 6.94254867908078, 7.0265740474609, 7.110348957620658, 7.1938778232376634, 7.277164917452867, 7.360214379286778, 7.443030219676582, 7.525616327161562, 7.60797647324178, 7.690114317432995, 7.772033412038852, 7.853737206659632, 7.935229052455385, 8.01651220617974, 8.09758983399954, 8.178465015114137, 8.259140745187251, 8.339619939603233, 8.419905436558743, 8.5, 8.579906322415052, 8.659627027489831, 8.739164672636113, 8.818521751398949, 8.89770069575061, 8.976703878277576, 9.05553361426671, 9.134192163696257, 9.212681733137044, 9.291004477568809, 9.369162502116284, 9.44715786370943, 9.524992572671838, 9.602668594241111, 9.680187850024815, 9.75755221939534], [0.0, 0.24372478179882237, 0.4243494921683795, 0.5869440359425744, 0.7388353788832142, 0.883233826910351, 1.0219289222262173, 1.1560540040912306, 1.2863871105397746, 1.4134931162351854, 1.5377994110779951, 1.6596397894181358, 1.7792815977852692, 1.8969433967793847, 2.0128069289247215, 2.1270255048404416, 2.239730047394549, 2.3510335535790667, 2.4610344571074694, 2.5698192086138367, 2.677464287100793, 2.784037790170088, 2.889600707093238, 2.9942079495108773, 3.0979091944287878, 3.200749580084241, 3.302770285214313, 3.4040090149919044, 3.5045004115635163, 3.604276403159689, 3.7033665027681386, 3.8017980650928473, 3.899596508781159, 3.9967855095508042, 4.09338716879269, 4.189422161392477, 4.284909865852157, 4.379868479263185, 4.474315119255952, 4.568265914704321, 4.661736086681702, 4.754740020933592, 4.847291332940534, 4.939402926487251, 5.031087046521794, 5.1223553269783775, 5.213218834144855, 5.303688106077605, 5.393773188500447, 5.483483667567795, 5.572828699824338, 5.661817039652296, 5.750457064462042, 5.838756797851396, 5.926723930932574, 6.014365842002989, 6.101689614716236, 6.188702054892335, 6.2754097060911915, 6.361818864059982, 6.447935590153601, 6.53376572381701, 6.619314894209386, 6.704588531041915, 6.789591874694074, 6.874329985666939, 6.958807753426478, 7.043029904684841, 7.127001011163206, 7.210725496875779, 7.294207644970974, 7.377451604162663, 7.46046139478143, 7.543240914473309, 7.625793943571009, 7.708124150160679, 7.790235094865268, 7.872130235363833, 7.95381293066466, 8.035286445148522, 8.11655395239725, 8.197618538821517, 8.278483207100725, 8.3591508794469, 8.439624400703604, 8.519906541290068, 8.6, 8.679907406663867, 8.759631324682763, 8.839174253441488, 8.91853863060786, 8.997726834324828, 9.076741185301534, 9.155583948808967, 9.234257336585626, 9.312763508658094, 9.391104575081192, 9.469282597602103, 9.547299591252482, 9.625157525872416, 9.70285832756977, 9.780403880118326], [0.0, 0.2442889655737394, 0.4253317931744926, 0.5883027172363644, 0.7405456642716103, 0.8852783715435348, 1.024294523757515, 1.1587300836725614, 1.2893648903563055, 1.4167651260663197, 1.5413591700421996, 1.663481589314255, 1.7834003492764796, 1.9013345164615936, 2.017466254098627, 2.1319492276962326, 2.2449146631878545, 2.356475819135426, 2.4667313571106777, 2.5757679278670427, 2.6836621874437663, 2.7904823910776244, 2.896289669220513, 3.0011390606247073, 3.1050803572902876, 3.208158801942306, 3.310415668640008, 3.411888749837723, 3.5126127678729624, 3.6126197248850005, 3.7119392021793853, 3.8105986177818503, 3.908623449179831, 4.0060374268965475, 4.102862703484081, 4.1991200016871355, 4.294828744865827, 4.390007172234958, 4.484672441049489, 4.578840717519038, 4.6725272579513595, 4.765746481392641, 4.858512034841082, 4.950836851951596, 5.042733206017325, 5.1342127579031756, 5.225286599513679, 5.315965293299129, 5.406258908237581, 5.496177052673861, 5.585728904348587, 5.674923237908972, 5.76376845015775, 5.852272583266082, 5.940443346149876, 6.02828813418612, 6.115814047425931, 6.20302790744371, 6.289936272946653, 6.3765454542555835, 6.462861526756459, 6.54889034341162, 6.634637546410843, 6.720108578034226, 6.805308690791883, 6.8902429568991375, 6.974916277140289, 7.059333389169066, 7.14349887528945, 7.227417169756527, 7.311092565633515, 7.3945292212378915, 7.477731166206663, 7.560702307208286, 7.643446433326336, 7.725967221137992, 7.808268239508474, 7.890352954120812, 7.972224731758856, 8.053886844359898, 8.135342472852102, 8.216594710790684, 8.29764656780577, 8.378500972873837, 8.459160777423806, 8.539628758287979, 8.619907620507345, 8.700000000000001, 8.779908466100906, 8.859635523980534, 8.939183616949514, 9.018555128655814, 9.097752385180646, 9.176777657038738, 9.255633161088406, 9.33432106235635, 9.412843475781832, 9.491202467884644, 9.569400058360921, 9.647438221610612, 9.72531888820021, 9.803043946264134], [0.0, 0.2448479850728549, 0.4263051026541897, 0.5896489617936876, 0.7422402945032338, 0.8873042013663259, 1.026638471672939, 1.1613816676663917, 1.2923154129617425, 1.4200071854416902, 1.5448863446289454, 1.667288223161438, 1.7874813996326984, 1.9056854418771034, 2.022082929977539, 2.136827881083656, 2.2500518214202163, 2.361868268724776, 2.4723761103416146, 2.5816621953117154, 2.689803355090437, 2.7968680011066622, 2.9029174037003678, 3.008006727571948, 3.1121858786631797, 3.21550020323046, 3.3179910697826713, 3.419696357256636, 3.520650867446848, 3.6208866757247855, 3.7204334310884812, 3.8193186143058018, 3.9175677611656794, 4.0152046564951585, 4.1122515035391904, 4.208729072463443, 4.304656831075546, 4.400053060328072, 4.494934956737844, 4.589318723508485, 4.683219651859569, 4.776652193833162, 4.869630027656619, 4.962166116581624, 5.0542727619869545, 5.145961651421697, 5.237243902172581, 5.32813010086052, 5.418630339504949, 5.508754248437984, 5.598511026402158, 5.687909468124177, 5.7769579896216285, 5.865664651469005, 5.954037180222937, 6.0420829881836475, 6.129809191649683, 6.217222627805617, 6.304329870367286, 6.391137244095757, 6.477650838279618, 6.563876519274857, 6.649819942182575, 6.73548656173673, 6.820881642467036, 6.906010268195838, 6.990877350922161, 7.075487639141161, 7.159845725642751, 7.243956054829159, 7.327822929587649, 7.4114505177514, 7.494842858178651, 7.578003866477697, 7.660937340402876, 7.743646964944676, 7.82613631713514, 7.9084088705880085, 7.990467999791521, 8.072316984170318, 8.153959011931654, 8.23539718370989, 8.316634516022255, 8.397673944547751, 8.47851832724038, 8.55917044728682, 8.639633015918148, 8.719908675084374, 8.8, 8.879909501568223, 8.959639628690823, 9.039192770470402, 9.118571258311064, 9.197777367923278, 9.27681332123832, 9.355681288237232, 9.434383388699004, 9.512921693872359, 9.591298228075207, 9.669514970225622, 9.747573855307921, 9.825476775777238], [0.0, 0.245401945454913, 0.42726960369947853, 0.5909830228604275, 0.7439195883597856, 0.8893116974633202, 1.0289612068991827, 1.1640092548697103, 1.2952392333872642, 1.423219904234285, 1.5483815983450515, 1.6710604070363786, 1.7915255165518866, 1.909996991490839, 2.0266578250174563, 2.1416623827400425, 2.2551424884570457, 2.36721191673611, 2.4779697786508255, 2.587503119735228, 2.6958889452732753, 2.8031958214724213, 2.9094851572947396, 3.014812242248915, 3.119227095187249, 3.2227751649605287, 3.3254979136725047, 3.427433305959828, 3.528616222354889, 3.6290788107986223, 3.728850787368927, 3.827959695007989, 3.926431127278609, 4.024288922820208, 4.121555335111837, 4.218251181310968, 4.314395973270496, 4.410008033303038, 4.505104596831962, 4.599701903720095, 4.693815279782888, 4.787459209759666, 4.880647402824316, 4.973392851557447, 5.065707885169296, 5.1576042176516355, 5.249092991443688, 5.3401848171182404, 5.430889809527586, 5.521217620792144, 5.611177470466296, 5.700778173174522, 5.79002816397537, 5.87893552168011, 5.9675079903264505, 6.055752998984697, 6.143677680053781, 6.231288886187178, 6.318593205973539, 6.40559697848349, 6.492306306782431, 6.578727070498784, 6.664864937528129, 6.750725374945573, 6.836313659191657, 6.921634885590703, 7.006693977254969, 7.091495693422923, 7.17604463727551, 7.2603452632702705, 7.344401884029609, 7.428218676816285, 7.511799689626321, 7.595148846926945, 7.678269955064786, 7.7611667073675, 7.843842688960047, 7.926301381315099, 8.008546166555567, 8.090580331525677, 8.172407071645896, 8.25402949456567, 8.335450623626988, 8.41667340115074, 8.497700691556947, 8.578535284329153, 8.659179896832507, 8.739637176994341, 8.819909705855498, 8.9, 8.979910513870195, 9.059643641973945, 9.139201720990082, 9.218587031777789, 9.297801801295389, 9.376848204433433, 9.455728365766841, 9.534444361230468, 9.612998219722174, 9.691391924637271, 9.76962741533791, 9.847706588560843], [0.0, 0.2459509485849363, 0.4282254736676647, 0.5923051457504459, 0.7455838546382703, 0.8913012289830016, 1.0312631565524872, 1.166613328456474, 1.2981368892796834, 1.4264038732150022, 1.5518455739153596, 1.6747988345872291, 1.7955334436866137, 1.9142699581322393, 2.0311917804730997, 2.146453621657883, 2.2601876003958137, 2.3725077457863133, 2.4835133906301867, 2.5932917751961546, 2.7019200770412266, 2.809467015766353, 2.915994137715209, 3.0215568560878925, 3.1262053016368223, 3.2299850248890833, 3.3329375807057375, 3.4351010186563586, 3.5365102973066285, 3.637197636517531, 3.737192818846552, 3.836523448853814, 3.9352151773589816, 4.0332918963323, 4.130775909037386, 4.227688079203, 4.324047962333153, 4.419873921730382, 4.515183231376437, 4.609992167465296, 4.704316090098694, 4.79816951642062, 4.8915661862745585, 4.984519121307588, 5.077040678312342, 5.169142597486657, 5.260836046197162, 5.352131658754177, 5.443039572638531, 5.533569461563967, 5.623730565710474, 5.7135317194222495, 5.802981376628403, 5.892087634213792, 5.980858253540766, 6.069300680299641, 6.157422062845658, 6.245229269162768, 6.332728902579338, 6.419927316347503, 6.506830627186192, 6.593444727877488, 6.679775298996953, 6.7658278198504105, 6.851607578682637, 6.937119682217003, 7.022369064579552, 7.107360495655923, 7.19209858892511, 7.276587808809982, 7.360832477580963, 7.444836781846014, 7.528604778657169, 7.612140401261309, 7.695447464520467, 7.77852967002486, 7.861390610919942, 7.944033776466992, 8.026462556355266, 8.108680244782185, 8.190690044316877, 8.272495069561094, 8.354098350620525, 8.435502836398491, 8.516711397723181, 8.597726830318658, 8.678551857629245, 8.75918913350611, 8.839641244764291, 8.919910713617815, 9.0, 9.079911503775609, 9.159647566850987, 9.23921047518797, 9.318602460726938, 9.397825703224015, 9.476882332007136, 9.555774427655349, 9.634504023605484, 9.713073107690018, 9.79148362360977, 9.869737472344786], [0.0, 0.2464950931726869, 0.42917288442242635, 0.5936155681790287, 0.7472333925707313, 0.893273153639511, 1.0335447345192046, 1.1691943566343672, 1.3010089016322481, 1.4295596648556608, 1.5552788941563633, 1.6785041779764494, 1.7995059016548731, 1.9185051100729176, 2.0356856115413957, 2.151202459293203, 2.2651880643384508, 2.3777567080557964, 2.489007943011028, 2.5990292024841968, 2.7078978347807903, 2.8156827115377605, 2.922445515264591, 3.028241781758155, 3.133121752680699, 3.237131079335797, 3.3403114085209418, 3.4427008739869955, 3.5443345116423544, 3.6452446126315783, 3.745461025403411, 3.845011415590608, 3.9439214907629907, 4.0422151957496615, 4.139914883158223, 4.237041462876581, 4.333614533673556, 4.429652499478859, 4.525172672491387, 4.620191364914752, 4.714723970833544, 4.808785039509641, 4.902388341184711, 4.995546926315065, 5.088273179031643, 5.180578865506424, 5.272475177812841, 5.3639727737886815, 5.455081813343045, 5.545811991591909, 5.636172569158337, 5.726172399931725, 5.815819956544752, 5.905123353795911, 5.994090370218875, 6.082728467976888, 6.171044811240289, 6.259046283187834, 6.346739501757166, 6.434130834256425, 6.521226410937237, 6.60803213761894, 6.694553707444863, 6.780796611843309, 6.8667661507588225, 6.952467442212947, 7.03790543124804, 7.123084898302689, 7.208010467062798, 7.292686611828375, 7.377117664432483, 7.461307820745581, 7.545261146795569, 7.628981584531286, 7.7124729572548105, 7.795738974745796, 7.878783238099211, 7.961609244296016, 8.04422039052485, 8.126619978271258, 8.208811217189762, 8.290797228772895, 8.372581049830186, 8.454165635789142, 8.535553863829403, 8.616748535860323, 8.697752381351604, 8.778568060025822, 8.859198164421116, 8.939645222331682, 9.019911699133228, 9.1, 9.179912472019604, 9.259651406211361, 9.33921903945362, 9.418617556325028, 9.497849090864461, 9.576915728254068, 9.655819506429472, 9.73456241762106, 9.813146409829907, 9.891573388241817], [0.0, 0.24703447490385583, 0.43011200256222787, 0.5949145205788192, 0.748868492221943, 0.8952278181880636, 1.0358063420058694, 1.1717527932670695, 1.3038557754770632, 1.4326878340898408, 1.5586821628039582, 1.682177088774138, 1.803443588997815, 1.9227031920477287, 2.0401401084449087, 2.15590973071047, 2.2701447595969246, 2.3829597265539832, 2.49445440198883, 2.604716410503435, 2.7138232696572135, 2.821844001792361, 2.92884042439232, 3.034868194777657, 3.1399776645496633, 3.24421458490631, 3.347620693776812, 3.450234208356483, 3.5520902412194624, 3.653221154169945, 3.753656860971191, 3.8534250877940246, 3.952551598461694, 4.051060390199489, 4.148973864527096, 4.246312977087535, 4.343097369535745, 4.439345486073005, 4.535074676780848, 4.630301289557323, 4.7250407521724345, 4.8193076457248205, 4.9131157705882575, 5.006478205776128, 5.099407362518386, 5.191915032733805, 5.284012432986362, 5.375710244435378, 5.467018649221916, 5.557947363676848, 5.64850566868738, 5.738702437517031, 5.828546161338331, 5.9180449727066184, 6.007206667176587, 6.0960387232402224, 6.184548320744537, 6.272742357930089, 6.3606274672159255, 6.44821002984316, 6.535496189477663, 6.6224918648619155, 6.70920276159701, 6.795634383127617, 6.881792040995648, 6.967680864421921, 7.053305809269563, 7.138671666437737, 7.223783069729921, 7.308644503236805, 7.393260308270391, 7.477634689882562, 7.561771722998516, 7.645675358192889, 7.729349427133923, 7.812797647719029, 7.896023628923111, 7.979030875379238, 8.061822791709796, 8.14440268662465, 8.226773776801709, 8.30893919056397, 8.390901971366121, 8.47266508110275, 8.554231403249357, 8.635603745846446, 8.716784844336356, 8.797777364261684, 8.878583903833569, 8.959206996377544, 9.039649112664057, 9.119912663130371, 9.200000000000001, 9.279913419305489, 9.359655162819928, 9.43922741990227, 9.51863232926111, 9.597871980641395, 9.676948416438178, 9.755863633241242, 9.834619583314298, 9.913218176012082], [0.0, 0.2475691865644366, 0.4310429896368671, 0.5962022263993374, 0.7504894348664402, 0.8971655588756651, 1.038048368060693, 1.1742890784641937, 1.3066780005415386, 1.435788919034192, 1.5620559652981847, 1.6858181988049523, 1.8073471830877172, 1.9268649262227822, 2.0445560374589813, 2.160576245668025, 2.2750585388361797, 2.388117696319048, 2.499853704479098, 2.6103543775837155, 2.7196974009808113, 2.827951946412987, 2.935179965169017, 3.041437235040984, 3.146774216617351, 3.2512367601255816, 3.3548666938375753, 3.4577023176706225, 3.5597788202008154, 3.6611286332802, 3.761781735421049, 3.861765912808104, 3.9611069850309866, 4.059829001257519, 4.15795441149598, 4.2555042167483474, 4.352498101184364, 4.448954548928195, 4.544890947616014, 4.640323680531264, 4.7352682088377005, 4.829739145195079, 4.923750319848394, 5.017314840120845, 5.110445144106771, 5.203153049248819, 5.295449796389471, 5.387346089807656, 5.47885213368391, 5.56997766538032, 5.660731985872782, 5.751123987631192, 5.841162180207414, 5.930854713759883, 6.020209400716949, 6.109233735757958, 6.1979349142708635, 6.2863198494276205, 6.374395188003295, 6.462167325051341, 6.549642417535731, 6.636826397010196, 6.723724981425732, 6.810343686139338, 6.8966878341898745, 6.982762565900479, 7.068572847861349, 7.154123481341659, 7.239419110174858, 7.324464228157553, 7.4092631859986104, 7.493820197851843, 7.5781393474627174, 7.662224593956974, 7.746079777296589, 7.829708623426446, 7.913114749133154, 7.99630166663564, 8.079272787925671, 8.16203142887489, 8.244580813123779, 8.326924075766655, 8.409064266845835, 8.491004354666995, 8.57274722894698, 8.654295703804364, 8.73565252060241, 8.816820350653341, 8.897801797792185, 8.978599400827912, 9.059215635879012, 9.139652918600188, 9.2199136063064, 9.3, 9.379914346306455, 9.459658839323628, 9.539235622389398, 9.618646789772015, 9.697894388287336, 9.776980418846817, 9.855906837939877, 9.934675559054098], [0.0, 0.2480993181587069, 0.4319660023528932, 0.5974789023911062, 0.7520964933461722, 0.8990867018686657, 1.040271190068255, 1.1768036391409054, 1.3094760518710997, 1.438863441672675, 1.565400869527643, 1.689428120951502, 1.8112173409892975, 1.9309910131137131, 2.0489341418860882, 2.165202789647723, 2.2799302291583414, 2.393231485556002, 2.5052067593086944, 2.6159440527246427, 2.725521217503064, 2.83400757350728, 2.9414652046852856, 3.047950008268785, 3.1535125528998824, 3.258198786987301, 3.362050628371793, 3.4651064589840717, 3.5674015427511896, 3.6689683809730504, 3.76983701635633, 3.8700352945856404, 3.9695890905393107, 4.068522504882782, 4.1668580356975955, 4.264616728956168, 4.361818310978884, 4.458481305470837, 4.554623137301167, 4.650260224835617, 4.745408062345661, 4.840081293781835, 4.93429377900449, 5.0280586534041545, 5.1213883817094485, 5.214294806668264, 5.306789193193635, 5.398882268486065, 5.490584258576782, 5.5819049216789525, 5.672853578685086, 5.7634391411069466, 5.853670136718305, 5.943554733129913, 6.033100759499243, 6.122315726554354, 6.211206845091021, 6.299781043084702, 6.3880449815435165, 6.476005069214947, 6.563667476247166, 6.65103814689542, 6.738122811354822, 6.8249269967926685, 6.911456037646293, 6.997715085246048, 7.083709116817327, 7.169442943910491, 7.2549212203030455, 7.340148449414378, 7.425128991269732, 7.509867069046889, 7.594366775236032, 7.678632077440764, 7.762666823845753, 7.846474748374424, 7.930059475558184, 8.013424525136838, 8.096573316408413, 8.179509172344986, 8.26223532348997, 8.344754911651009, 8.427070993401621, 8.509186543403652, 8.591104457561839, 8.672827556020755, 8.754358586013877, 8.835700224573635, 8.916855081110773, 8.99782569987073, 9.078614562274225, 9.159224089148722, 9.239656642857005, 9.319914529328676, 9.4, 9.479915253667173, 9.559662438257702, 9.639243652524389, 9.71866094766604, 9.79791632887875, 9.87701175684147, 9.95594914913922], [0.0, 0.24862495702121018, 0.43288119276857834, 0.5987447588753295, 0.753689932409968, 0.900991563658571, 1.0424751742190401, 1.1792968895490827, 1.3122503904202307, 1.4419119085060041, 1.5687174265360495, 1.6930074499168883, 1.8150547002772213, 1.9350821324572491, 2.0532751429806426, 2.169790124832221, 2.2847606331317816, 2.3983019367168956, 2.5105144483465827, 2.621486356776308, 2.7312956786468083, 2.8400118806868395, 2.9476971783793635, 3.054407587383486, 3.1601937834792255, 3.265101812424501, 3.3691736808698463, 3.472447852064354, 3.5749596646474564, 3.6767416887783604, 3.7778240308141156, 3.8782345954349573, 3.9779993123393633, 4.077142333253965, 4.175686203926158, 4.273652014917683, 4.371059534342352, 4.4679273251507485, 4.564272849129439, 4.66011255942915, 4.755461983148497, 4.850335795263614, 4.9447478849992255, 5.038711415575328, 5.132238878129101, 5.2253421404992295, 5.318032491465299, 5.410320680955142, 5.5022169566654995, 5.593731097483901, 5.684872444050691, 5.7756499267581205, 5.8660720914474425, 5.956147123033822, 6.04588286726208, 6.135286850772975, 6.224366299639533, 6.313128156515254, 6.40157909652069, 6.489725541981302, 6.577573676117725, 6.6651294557790814, 6.752398623300836, 6.83938671756049, 6.926099084297254, 7.0125408857554135, 7.098717109705426, 7.184632577891704, 7.270291953951542, 7.355699750845554, 7.44086033783641, 7.525777947049382, 7.610456679645258, 7.6949005116336595, 7.77911329935226, 7.863098784635411, 7.946860599693678, 8.03040227172401, 8.113727227268777, 8.19683879634031, 8.279740216326458, 8.362434635691294, 8.444925117484187, 8.527214642669295, 8.609306113286788, 8.691202355456186, 8.772906122231428, 8.85442009631667, 8.935746892651116, 9.016889060870607, 9.09784908765316, 9.178629398955149, 9.259232362144415, 9.339660288036043, 9.419915432836339, 9.5, 9.579916142005272, 9.65966596205151, 9.739251515683314, 9.818674812345117, 9.897937816869886, 9.977042450905357], [0.0, 0.24914618792310342, 0.43378870847907935, 0.6, 0.7552700090359216, 0.9028804514474341, 1.044660675955349, 1.1817692317817539, 1.3150014636137806, 1.444934811168415, 1.5720061711932454, 1.6965567629488736, 1.8188598798124775, 1.9391389440389286, 2.0575797408272676, 2.1743389910330864, 2.289550529768409, 2.403329867526676, 2.5157776275776853, 2.626982183560611, 2.7370217156745262, 2.84596583628202, 2.953876891297982, 3.0608110138157962, 3.166818985854946, 3.2719469497061864, 3.376237000085081, 3.479727680877173, 3.5824544048077422, 3.6844498103178527, 3.7857440668811595, 3.8863651376787907, 3.9863390067696556, 4.085689876513381, 4.184440339923495, 4.282611531777142, 4.380223261631081, 4.477294131352281, 4.573841639335145, 4.669882273223683, 4.765431592668366, 4.860504303410746, 4.955114323793675, 5.049274844633241, 5.142998383253724, 5.236296832374192, 5.329181504440644, 5.421663171917646, 5.513752103985768, 5.605458100033533, 5.696790520283511, 5.787758313850118, 5.878370044490568, 5.968633914279333, 6.0585577854094765, 6.148149200301021, 6.237415400176123, 6.326363342243239, 6.41499971561701, 6.503330956087007, 6.591363259836706, 6.679102596203494, 6.76655471956138, 6.853725180399869, 6.9406193356652714, 7.027242358424282, 7.11359924690399, 7.19969483295738, 7.285533789998847, 7.371120640450221, 7.456459762734135, 7.541555397848314, 7.626411655551449, 7.71103252018868, 7.795421856182318, 7.879583413211301, 7.963520831100957, 8.047237644442845, 8.130737286962923, 8.214023095654742, 8.297098314693185, 8.379966099142942, 8.462629518474921, 8.545091559902735, 8.627355131550553, 8.709423065462724, 8.791298120464836, 8.872982984885217, 8.954480279145171, 9.035792558225735, 9.116922314018128, 9.197871977564636, 9.27864392119618, 9.359240460572359, 9.439663856629515, 9.51991631744179, 9.600000000000001, 9.67991701191276, 9.759669413034029, 9.839259217020947, 9.918688392825663, 9.997958866124561], [0.0, 0.24966309317320867, 0.4346886927923791, 0.6012448239832546, 0.756836972737723, 0.9047536635140567, 1.0468280403950025, 1.1842210562524111, 1.3177297058803163, 1.4479326270137185, 1.5752676228327882, 1.7000766205279931, 1.8226334804800948, 1.9431620884796, 2.0618486151753355, 2.1788501065726926, 2.2943006754522908, 2.408316071957959, 2.520997128123259, 2.632432400936743, 2.74270023279846, 2.851870380496232, 2.960005319294431, 3.0671612987461425, 3.1733892062286433, 3.278735279764405, 3.3832417014031773, 3.486947094997758, 3.589886946744444, 3.692093962799489, 3.793598375229356, 3.8944282052305694, 3.9946094907713396, 4.094166484424089, 4.1931218260762195, 4.29149669435334, 4.389310939911229, 4.486583203210269, 4.5833310189489005, 4.679570908978158, 4.775318465230222, 4.870588423956743, 4.965394732377053, 5.059750608674315, 5.153668596142581, 5.2471606121748255, 5.340237992687053, 5.432911532493532, 5.525191522080372, 5.617087781166951, 5.708609689395556, 5.799766214447388, 5.890565937846947, 5.9810170786856025, 6.071127515468164, 6.16090480626296, 6.2503562073155585, 6.339488690268585, 6.42830895811463, 6.516823459995639, 6.605038404950354, 6.692959774700782, 6.780593335559572, 6.867944649531866, 6.955019084678066, 7.041821824797464, 7.128357878487005, 7.214632087624347, 7.300649135319851, 7.3864135533780475, 7.47192972930551, 7.5572019128987895, 7.642234222443121, 7.727030650549993, 7.8115950696592575, 7.895931237229336, 7.980042800637128, 8.063933301807433, 8.14760618159018, 8.231064783902207, 8.314312359649104, 8.3973520704414, 8.480186992118249, 8.562820118090858, 8.645254362516903, 8.727492563316389, 8.809537485038664, 8.891391821589544, 8.973058198826939, 9.054539177032725, 9.13583725326806, 9.216954863618934, 9.297894385338154, 9.378658138889639, 9.459248389900507, 9.539667351026006, 9.619917183732076, 9.700000000000001, 9.779917863957332, 9.859672793438959, 9.939266761482028, 10.018701697758138], [0.0, 0.2501757527140843, 0.4355812848965559, 0.602479423344736, 0.7583910658558927, 0.9066114895621418, 1.048977602734168, 1.1866527421507047, 1.3204355391591907, 1.4509058196724696, 1.5785022858581215, 1.7035675670217492, 1.8263760858904956, 1.9471521879831568, 2.0660824262323727, 2.183324169122648, 2.2990118048225097, 2.4132613211577545, 2.5261737572109864, 2.637837851814154, 2.7483321082360144, 2.8577264265033513, 2.966083410167583, 3.0734594242849296, 3.1799054607250827, 3.285467852455919, 3.3901888681440355, 3.494107210952658, 3.59725843994563, 3.6996753284382033, 3.801388170575528, 3.902425045093006, 4.00281204342535, 4.102573467945346, 4.201732005029264, 4.300308876791014, 4.3983239746478215, 4.495795977336488, 4.5927424555613, 4.689179965099349, 4.785124129899374, 4.880589716472524, 4.975590700677425, 5.070140327839528, 5.164251167009356, 5.257935160051119, 5.351203666158054, 5.44406750231056, 5.536536980125285, 5.6286219394854715, 5.720331779293614, 5.811675485645201, 5.90266165768608, 5.993298531384745, 6.083594001423771, 6.173555641391266, 6.26319072243281, 6.3525062305066395, 6.441508882369303, 6.530205140405451, 6.618601226403498, 6.706703134368351, 6.794516642453237, 6.8820473240843505, 6.969300558344896, 7.056281539678606, 7.142995286967108, 7.229446652030397, 7.315640327595157, 7.401580854771551, 7.4872726300754815, 7.572719912030056, 7.657926827377017, 7.7428973769263045, 7.827635441069458, 7.912144784980486, 7.99642906352583, 8.080491825903296, 8.164336520028275, 8.24796649668402, 8.331385013451552, 8.414595238433462, 8.497600253784853, 8.580403059063617, 8.663006574411378, 8.745413643575542, 8.827627036782195, 8.909649453468834, 8.991483524885323, 9.07313181657083, 9.154596830713997, 9.235881008403082, 9.316986731772358, 9.397916326050595, 9.478672061517162, 9.55925615537079, 9.639670773515777, 9.719918032270169, 9.8, 9.879918698683598, 9.959676105409553, 10.039274153811862], [0.0, 0.25068424421341, 0.4364666200188944, 0.6037039851256675, 0.7599325238348079, 0.9084542110514628, 1.0511096886305296, 1.1890646578759059, 1.3231193733828746, 1.4538548395819602, 1.5817106503191742, 1.7070301313068958, 1.8300882630466422, 1.9511098470477999, 2.0702818154187663, 2.1877618565013286, 2.3036846316129527, 2.418166364328995, 2.531308299097743, 2.643199355116115, 2.753918195213672, 2.8635348614915976, 2.9721120847453495, 3.0797063445952175, 3.1863687365537596, 3.2921456877623276, 3.3970795528001534, 3.501209113496077, 3.604570001189059, 3.707195055807329, 3.8091146330700125, 3.910356868783582, 4.01094790741456, 4.110912100731207, 4.210272181220694, 4.309049414131666, 4.407263731311389, 4.504933849461893, 4.6020773750005715, 4.698710897354748, 4.794850072229416, 4.8905096961492065, 4.985703773379198, 5.080445576166456, 5.174747699108564, 5.268622108342015, 5.362080186148029, 5.4551327714929165, 5.54779019695207, 5.640062322408661, 5.731958565868801, 5.82348793169255, 5.914659036503839, 6.0054801330110745, 6.095959131943067, 6.186103622281521, 6.275920889950893, 6.365417935108635, 6.454601488163354, 6.543478024634739, 6.632053778957217, 6.720334757318736, 6.808326749616831, 6.896035340605893, 6.983465920302312, 7.070623693707722, 7.15751368990481, 7.244140770575079, 7.330509637983353, 7.416624842469768, 7.502490789486311, 7.588111746211694, 7.6734918477754155, 7.758635103119209, 7.8435454005216565, 7.928226512809619, 8.012682102278193, 8.09691572533906, 8.180930836915625, 8.264730794601732, 8.348318862599559, 8.43169821545098, 8.514871941575699, 8.597843046628313, 8.680614456685744, 8.763189021275423, 8.84556951625402, 8.927758646545744, 9.009759048748565, 9.09157329361621, 9.17320388842311, 9.254653279219125, 9.335923852980306, 9.417017939661536, 9.49793781415661, 9.578685698170798, 9.659263762010681, 9.739674126295796, 9.819918863596213, 9.9, 9.979919516614258, 10.059679351003163], [0.0, 0.25118864315095796, 0.4373448295773112, 0.6049186910982999, 0.7614615754863514, 0.91028210151304, 1.0532246145679582, 1.1914571614494367, 1.3257816069359947, 1.4567801244906113, 1.5848931924611134, 1.710464827361669, 1.8337705629789585, 1.955035653142947, 2.074447406086017, 2.192163827432888, 2.308319849451542, 2.423031929569479, 2.5364015159477993, 2.6485177066967314, 2.7594593229224293, 2.869296547656997, 2.9780922379158175, 3.0859029869611865, 3.192779993114366, 3.2987697769322355, 3.4039147782151966, 3.5082538568245702, 3.611822715792731, 3.714654261124758, 3.8167789096181766, 3.918224853691197, 4.019018290415328, 4.119183620556749, 4.2187436223424095, 4.317719603808523, 4.416131536907, 4.513998175999536, 4.611337162929197, 4.708165120502707, 4.804497735925725, 4.900349835494804, 4.995735451652846, 5.090667883351854, 5.185159750530859, 5.279223043403284, 5.372869167152506, 5.466108982553799, 5.558952842972614, 5.651410628131081, 5.743491774985175, 5.8352053060125275, 5.9265598551744825, 6.017563691784628, 6.10822474248886, 6.1985506115385895, 6.288548599518198, 6.378225720670078, 6.467588718945013, 6.556644082892013, 6.64539805948974, 6.733856667011125, 6.82202570700349, 6.909910775458248, 6.99751727323698, 7.084850415814245, 7.17191524239169, 7.258716624432953, 7.345259273664231, 7.431547749581351, 7.517586466500455, 7.603379700186202, 7.688931594088335, 7.774246165214936, 7.859327309668147, 7.944178807866091, 8.028804329472727, 8.113207438055554, 8.19739159548959, 8.281360166124454, 8.365116420730187, 8.448663540236126, 8.532004619276142, 8.615142669552487, 8.698080623029604, 8.780821334968424, 8.863367586810888, 8.945722088923754, 9.02788748321006, 9.109866345596117, 9.191661188401216, 9.273274462596886, 9.354708559961983, 9.43596581513947, 9.517048507600428, 9.597958863520393, 9.6786990575728, 9.759271214644057, 9.83967741147443, 9.919919678228657, 10.0, 10.079920318251189], [0.0, 0.2516890229014065, 0.43821604132454106, 0.6061237179653446, 0.7629784432409537, 0.912095426849246, 1.0553226882037436, 1.1938306009076765, 1.3284226270924242, 1.459682099938255, 1.58805037524686, 1.713872154829702, 1.8374235213498982, 1.9589301773537797, 2.0785798042006562, 2.196530722269984, 2.3129181326212542, 2.4278587246707137, 2.5414541486690347, 2.653793680214129, 2.7649562974275503, 2.875012323149349, 2.984024739609078, 3.0920502528055103, 3.1991401630494036, 3.3053410835688037, 3.4106955387062183, 3.515242465733664, 3.619017638805658, 3.7220540294776097, 3.824382115138755, 3.9260301443679455, 4.027024366422505, 4.1273892306761, 4.227147560730999, 4.3263207070700345, 4.4249286814302, 4.522990275532771, 4.620523166364208, 4.717544009844657, 4.81406852442944, 4.910111565949799, 5.005687194801928, 5.100808736429981, 5.195488835912506, 5.2897395073480045, 5.383572178639521, 5.476997732197512, 5.570026542011826, 5.662668507485471, 5.754933084373287, 5.846829313126112, 5.938365844904553, 6.029550965495062, 6.120392617333795, 6.210898419820193, 6.30107568808175, 6.390931450333561, 6.480472463960685, 6.569705230437627, 6.658636009187331, 6.747270830471414, 6.835615507394157, 6.923675647094453, 7.011456661192658, 7.098963775552805, 7.186202039414871, 7.27317633394668, 7.359891380260416, 7.446351746934635, 7.532561857079009, 7.618525994975724, 7.704248312328472, 7.789732834147407, 7.874983464295892, 7.960003990722824, 8.044798090402306, 8.129369334000634, 8.213721190289045, 8.297857030319102, 8.381780131376381, 8.465493680726777, 8.549000779168823, 8.63230444440422, 8.715407614238028, 8.798313149618993, 8.881023837529822, 8.96354239373645, 9.045871465404714, 9.128013633592293, 9.209971415623135, 9.291747267351225, 9.373343585319954, 9.454762708823006, 9.536006921872278, 9.617078455077952, 9.697979487445515, 9.778712148094254, 9.859278517901398, 9.93968063107587, 10.019920476665334, 10.100000000000001]]}, {\"colorscale\": [[0.0, \"#440154\"], [0.1111111111111111, \"#482878\"], [0.2222222222222222, \"#3e4989\"], [0.3333333333333333, \"#31688e\"], [0.4444444444444444, \"#26828e\"], [0.5555555555555556, \"#1f9e89\"], [0.6666666666666666, \"#35b779\"], [0.7777777777777778, \"#6ece58\"], [0.8888888888888888, \"#b5de2b\"], [1.0, \"#fde725\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha = 0.5\", \"showscale\": false, \"type\": \"surface\", \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.1, 0.1414213562373095, 0.17320508075688776, 0.2, 0.223606797749979, 0.24494897427831783, 0.2645751311064591, 0.282842712474619, 0.3, 0.31622776601683794, 0.33166247903554, 0.3464101615137755, 0.36055512754639896, 0.37416573867739417, 0.38729833462074165, 0.4, 0.41231056256176607, 0.4242640687119285, 0.43588989435406744, 0.447213595499958, 0.45825756949558405, 0.469041575982343, 0.479583152331272, 0.48989794855663565, 0.5, 0.5099019513592785, 0.5196152422706632, 0.5291502622129182, 0.5385164807134505, 0.5477225575051661, 0.5567764362830022, 0.565685424949238, 0.574456264653803, 0.5830951894845301, 0.5916079783099616, 0.6, 0.608276253029822, 0.6164414002968976, 0.6244997998398399, 0.6324555320336759, 0.6403124237432849, 0.6480740698407861, 0.6557438524302001, 0.66332495807108, 0.6708203932499369, 0.6782329983125268, 0.6855654600401044, 0.692820323027551, 0.7000000000000001, 0.7071067811865476, 0.7141428428542851, 0.7211102550927979, 0.7280109889280519, 0.7348469228349535, 0.7416198487095663, 0.7483314773547883, 0.754983443527075, 0.7615773105863909, 0.7681145747868608, 0.7745966692414833, 0.7810249675906654, 0.787400787401181, 0.7937253933193772, 0.8, 0.8062257748298549, 0.812403840463596, 0.8185352771872451, 0.8246211251235321, 0.8306623862918076, 0.8366600265340756, 0.8426149773176359, 0.848528137423857, 0.8544003745317531, 0.8602325267042626, 0.8660254037844387, 0.8717797887081349, 0.8774964387392122, 0.8831760866327848, 0.8888194417315589, 0.894427190999916, 0.9, 0.9055385138137417, 0.9110433579144299, 0.9165151389911681, 0.9219544457292888, 0.9273618495495705, 0.9327379053088816, 0.938083151964686, 0.9433981132056604, 0.9486832980505138, 0.9539392014169457, 0.959166304662544, 0.9643650760992956, 0.9695359714832659, 0.9746794344808963, 0.9797958971132713, 0.9848857801796106, 0.9899494936611666, 0.9949874371066201, 1.0, 1.0049875621120892], [0.0, 0.1414213562373095, 0.19999999999999998, 0.24494897427831783, 0.282842712474619, 0.31622776601683794, 0.34641016151377546, 0.3741657386773941, 0.39999999999999997, 0.4242640687119285, 0.4472135954999579, 0.469041575982343, 0.48989794855663565, 0.5099019513592785, 0.529150262212918, 0.5477225575051661, 0.565685424949238, 0.58309518948453, 0.6, 0.6164414002968976, 0.6324555320336759, 0.6480740698407861, 0.6633249580710799, 0.6782329983125268, 0.6928203230275509, 0.7071067811865476, 0.7211102550927979, 0.7348469228349535, 0.7483314773547882, 0.7615773105863909, 0.7745966692414833, 0.7874007874011811, 0.7999999999999999, 0.812403840463596, 0.8246211251235321, 0.8366600265340756, 0.848528137423857, 0.8602325267042626, 0.8717797887081348, 0.8831760866327847, 0.8944271909999159, 0.9055385138137417, 0.9165151389911681, 0.9273618495495702, 0.938083151964686, 0.9486832980505137, 0.9591663046625439, 0.9695359714832658, 0.9797958971132713, 0.9899494936611665, 1.0, 1.0099504938362078, 1.019803902718557, 1.0295630140987002, 1.0392304845413265, 1.0488088481701516, 1.058300524425836, 1.0677078252031311, 1.0770329614269007, 1.0862780491200215, 1.0954451150103321, 1.104536101718726, 1.1135528725660042, 1.1224972160321824, 1.131370849898476, 1.1401754250991378, 1.1489125293076057, 1.1575836902790224, 1.16619037896906, 1.174734012447073, 1.1832159566199232, 1.1916375287812984, 1.2, 1.2083045973594573, 1.2165525060596438, 1.224744871391589, 1.2328828005937953, 1.2409673645990857, 1.2489995996796797, 1.2569805089976536, 1.2649110640673518, 1.2727922061357855, 1.2806248474865698, 1.2884098726725124, 1.2961481396815722, 1.3038404810405297, 1.3114877048604001, 1.3190905958272918, 1.3266499161421599, 1.3341664064126333, 1.3416407864998738, 1.349073756323204, 1.3564659966250536, 1.3638181696985856, 1.3711309200802089, 1.378404875209022, 1.3856406460551018, 1.392838827718412, 1.4, 1.407124727947029, 1.4142135623730951, 1.4212670403551897], [0.0, 0.17320508075688776, 0.24494897427831783, 0.3000000000000001, 0.3464101615137755, 0.38729833462074176, 0.42426406871192857, 0.45825756949558405, 0.48989794855663565, 0.5196152422706632, 0.5477225575051662, 0.574456264653803, 0.6000000000000002, 0.6244997998398399, 0.6480740698407861, 0.6708203932499369, 0.692820323027551, 0.7141428428542851, 0.7348469228349536, 0.7549834435270751, 0.7745966692414835, 0.7937253933193773, 0.8124038404635961, 0.8306623862918077, 0.8485281374238571, 0.8660254037844388, 0.8831760866327849, 0.9000000000000001, 0.9165151389911681, 0.9327379053088817, 0.9486832980505139, 0.9643650760992957, 0.9797958971132713, 0.9949874371066202, 1.009950493836208, 1.02469507659596, 1.0392304845413265, 1.053565375285274, 1.0677078252031313, 1.081665382639197, 1.0954451150103324, 1.1090536506409419, 1.1224972160321827, 1.1357816691600549, 1.148912529307606, 1.161895003862225, 1.1747340124470733, 1.187434208703792, 1.2000000000000004, 1.2124355652982142, 1.2247448713915892, 1.2369316876852985, 1.2489995996796799, 1.2609520212918495, 1.2727922061357857, 1.2845232578665131, 1.2961481396815722, 1.3076696830622023, 1.3190905958272923, 1.3304134695650072, 1.3416407864998738, 1.3527749258468684, 1.3638181696985856, 1.3747727084867523, 1.385640646055102, 1.3964240043768943, 1.4071247279470291, 1.4177446878757827, 1.4282856857085702, 1.4387494569938162, 1.4491376746189442, 1.4594519519326425, 1.4696938456699071, 1.4798648586948744, 1.489966442575134, 1.5000000000000002, 1.5099668870541503, 1.5198684153570665, 1.5297058540778359, 1.5394804318340656, 1.549193338482967, 1.5588457268119897, 1.5684387141358125, 1.5779733838059502, 1.5874507866387546, 1.5968719422671316, 1.6062378404209012, 1.6155494421403516, 1.6248076809271923, 1.6340134638368193, 1.6431676725154984, 1.6522711641858308, 1.6613247725836153, 1.670329308849007, 1.6792855623746668, 1.6881943016134133, 1.6970562748477143, 1.7058722109231985, 1.7146428199482249, 1.7233687939614089, 1.7320508075688776, 1.7406895185529214], [0.0, 0.2, 0.282842712474619, 0.3464101615137755, 0.4, 0.447213595499958, 0.48989794855663565, 0.5291502622129182, 0.565685424949238, 0.6, 0.6324555320336759, 0.66332495807108, 0.692820323027551, 0.7211102550927979, 0.7483314773547883, 0.7745966692414833, 0.8, 0.8246211251235321, 0.848528137423857, 0.8717797887081349, 0.894427190999916, 0.9165151389911681, 0.938083151964686, 0.959166304662544, 0.9797958971132713, 1.0, 1.019803902718557, 1.0392304845413265, 1.0583005244258363, 1.077032961426901, 1.0954451150103321, 1.1135528725660044, 1.131370849898476, 1.148912529307606, 1.1661903789690602, 1.1832159566199232, 1.2, 1.216552506059644, 1.2328828005937953, 1.2489995996796799, 1.2649110640673518, 1.2806248474865698, 1.2961481396815722, 1.3114877048604001, 1.32664991614216, 1.3416407864998738, 1.3564659966250536, 1.3711309200802089, 1.385640646055102, 1.4000000000000001, 1.4142135623730951, 1.4282856857085702, 1.4422205101855958, 1.4560219778561039, 1.469693845669907, 1.4832396974191326, 1.4966629547095767, 1.50996688705415, 1.5231546211727818, 1.5362291495737217, 1.5491933384829666, 1.5620499351813308, 1.574801574802362, 1.5874507866387544, 1.6, 1.6124515496597098, 1.624807680927192, 1.6370705543744901, 1.6492422502470643, 1.661324772583615, 1.6733200530681511, 1.6852299546352718, 1.697056274847714, 1.7088007490635062, 1.7204650534085253, 1.7320508075688774, 1.7435595774162698, 1.7549928774784245, 1.7663521732655696, 1.7776388834631178, 1.788854381999832, 1.8, 1.8110770276274835, 1.8220867158288598, 1.8330302779823362, 1.8439088914585775, 1.854723699099141, 1.8654758106177631, 1.876166303929372, 1.8867962264113207, 1.8973665961010275, 1.9078784028338913, 1.918332609325088, 1.9287301521985911, 1.9390719429665317, 1.9493588689617927, 1.9595917942265426, 1.9697715603592212, 1.9798989873223332, 1.9899748742132402, 2.0, 2.0099751242241783], [0.0, 0.223606797749979, 0.31622776601683794, 0.38729833462074176, 0.447213595499958, 0.5000000000000001, 0.5477225575051662, 0.5916079783099617, 0.6324555320336759, 0.6708203932499369, 0.7071067811865476, 0.7416198487095664, 0.7745966692414835, 0.806225774829855, 0.8366600265340756, 0.8660254037844386, 0.894427190999916, 0.9219544457292888, 0.9486832980505139, 0.9746794344808966, 1.0000000000000002, 1.02469507659596, 1.0488088481701516, 1.072380529476361, 1.0954451150103324, 1.118033988749895, 1.140175425099138, 1.1618950038622253, 1.1832159566199234, 1.2041594578792296, 1.2247448713915892, 1.2449899597988734, 1.2649110640673518, 1.2845232578665131, 1.30384048104053, 1.3228756555322954, 1.3416407864998738, 1.3601470508735445, 1.3784048752090223, 1.3964240043768943, 1.4142135623730951, 1.4317821063276355, 1.4491376746189442, 1.466287829861518, 1.4832396974191329, 1.5, 1.5165750888103102, 1.5329709716755893, 1.549193338482967, 1.565247584249853, 1.5811388300841898, 1.5968719422671316, 1.61245154965971, 1.627882059609971, 1.6431676725154984, 1.6583123951777001, 1.6733200530681511, 1.6881943016134133, 1.7029386365926404, 1.7175564037317668, 1.7320508075688772, 1.746424919657298, 1.760681686165901, 1.7748239349298849, 1.788854381999832, 1.8027756377319946, 1.8165902124584952, 1.8303005217723127, 1.8439088914585775, 1.8574175621006712, 1.8708286933869709, 1.8841443681416774, 1.8973665961010278, 1.91049731745428, 1.9235384061671346, 1.9364916731037085, 1.9493588689617931, 1.9621416870348585, 1.9748417658131503, 1.9874606914351793, 2.0000000000000004, 2.012461179749811, 2.024845673131659, 2.0371548787463363, 2.04939015319192, 2.0615528128088303, 2.0736441353327724, 2.0856653614614213, 2.0976176963403033, 2.1095023109728985, 2.121320343559643, 2.1330729007701543, 2.144761058952722, 2.1563858652847827, 2.1679483388678804, 2.179449471770337, 2.1908902300206647, 2.2022715545545246, 2.2135943621178655, 2.224859546128699, 2.23606797749979, 2.2472205054244236], [0.0, 0.24494897427831783, 0.34641016151377546, 0.42426406871192857, 0.48989794855663565, 0.5477225575051662, 0.6000000000000001, 0.6480740698407861, 0.6928203230275509, 0.7348469228349535, 0.7745966692414834, 0.8124038404635961, 0.8485281374238571, 0.8831760866327848, 0.916515138991168, 0.9486832980505138, 0.9797958971132713, 1.0099504938362078, 1.0392304845413265, 1.0677078252031313, 1.0954451150103324, 1.1224972160321824, 1.148912529307606, 1.174734012447073, 1.2000000000000002, 1.2247448713915892, 1.2489995996796799, 1.2727922061357857, 1.2961481396815722, 1.319090595827292, 1.3416407864998738, 1.3638181696985856, 1.3856406460551018, 1.4071247279470291, 1.4282856857085702, 1.449137674618944, 1.469693845669907, 1.489966442575134, 1.50996688705415, 1.5297058540778357, 1.5491933384829668, 1.5684387141358125, 1.5874507866387546, 1.606237840420901, 1.6248076809271923, 1.6431676725154982, 1.661324772583615, 1.6792855623746665, 1.6970562748477143, 1.7146428199482247, 1.7320508075688774, 1.7492855684535904, 1.7663521732655696, 1.7832554500127011, 1.8, 1.8165902124584952, 1.833030277982336, 1.849324200890693, 1.8654758106177631, 1.8814887722226779, 1.8973665961010275, 1.9131126469708992, 1.928730152198591, 1.9442222095223582, 1.9595917942265426, 1.9748417658131499, 1.98997487421324, 2.004993765576342, 2.0199009876724157, 2.0346989949375804, 2.04939015319192, 2.0639767440550294, 2.078460969082653, 2.092844953645635, 2.1071307505705477, 2.121320343559643, 2.1354156504062627, 2.149418526020468, 2.1633307652783937, 2.177154105707724, 2.1908902300206647, 2.2045407685048604, 2.2181073012818837, 2.2315913604421396, 2.244994432064365, 2.2583179581272432, 2.2715633383201097, 2.2847319317591728, 2.297825058615212, 2.3108440016582685, 2.32379000772445, 2.3366642891095846, 2.349468024894146, 2.3622023622035435, 2.374868417407584, 2.3874672772626644, 2.4000000000000004, 2.412467616362964, 2.4248711305964283, 2.4372115213907883, 2.4494897427831783, 2.4617067250182347], [0.0, 0.2645751311064591, 0.3741657386773941, 0.45825756949558405, 0.5291502622129182, 0.5916079783099617, 0.6480740698407861, 0.7000000000000001, 0.7483314773547882, 0.7937253933193772, 0.8366600265340756, 0.8774964387392122, 0.9165151389911681, 0.9539392014169458, 0.9899494936611666, 1.0246950765959597, 1.0583005244258363, 1.0908712114635715, 1.1224972160321824, 1.1532562594670797, 1.1832159566199234, 1.2124355652982142, 1.2409673645990857, 1.2688577540449522, 1.2961481396815722, 1.3228756555322954, 1.3490737563232043, 1.374772708486752, 1.4000000000000001, 1.4247806848775009, 1.4491376746189437, 1.4730919862656235, 1.4966629547095764, 1.5198684153570665, 1.5427248620541514, 1.5652475842498528, 1.5874507866387544, 1.6093476939431082, 1.6309506430300091, 1.6522711641858308, 1.6733200530681511, 1.6941074346097418, 1.7146428199482249, 1.7349351572897471, 1.7549928774784245, 1.7748239349298847, 1.7944358444926363, 1.8138357147217055, 1.8330302779823362, 1.8520259177452134, 1.8708286933869709, 1.8894443627691186, 1.9078784028338915, 1.9261360284258224, 1.9442222095223582, 1.9621416870348585, 1.9798989873223332, 1.997498435543818, 2.0149441679609885, 2.0322401432901573, 2.0493901531919194, 2.0663978319771825, 2.083266665599966, 2.1, 2.1166010488516727, 2.133072900770154, 2.149418526020468, 2.1656407827707715, 2.181742422927143, 2.1977260975835913, 2.2135943621178655, 2.2293496809607953, 2.244994432064365, 2.260530911091463, 2.2759613353482084, 2.29128784747792, 2.3065125189341593, 2.32163735324878, 2.336664289109585, 2.3515952032609695, 2.366431913239847, 2.3811761799581315, 2.395829710142188, 2.41039415863879, 2.4248711305964283, 2.4392621835300936, 2.4535688292770597, 2.4677925358506134, 2.4819347291981715, 2.495996794869737, 2.5099800796022267, 2.5238858928247927, 2.5377155080899043, 2.551470164434615, 2.5651510676761324, 2.578759391645525, 2.5922962793631443, 2.6057628441590768, 2.619160170741759, 2.632489316217637, 2.6457513110645907, 2.6589471600616665], [0.0, 0.282842712474619, 0.39999999999999997, 0.48989794855663565, 0.565685424949238, 0.6324555320336759, 0.6928203230275509, 0.7483314773547882, 0.7999999999999999, 0.848528137423857, 0.8944271909999159, 0.938083151964686, 0.9797958971132713, 1.019803902718557, 1.058300524425836, 1.0954451150103321, 1.131370849898476, 1.16619037896906, 1.2, 1.2328828005937953, 1.2649110640673518, 1.2961481396815722, 1.3266499161421599, 1.3564659966250536, 1.3856406460551018, 1.4142135623730951, 1.4422205101855958, 1.469693845669907, 1.4966629547095764, 1.5231546211727818, 1.5491933384829666, 1.5748015748023623, 1.5999999999999999, 1.624807680927192, 1.6492422502470643, 1.6733200530681511, 1.697056274847714, 1.7204650534085253, 1.7435595774162695, 1.7663521732655694, 1.7888543819998317, 1.8110770276274835, 1.8330302779823362, 1.8547236990991405, 1.876166303929372, 1.8973665961010273, 1.9183326093250879, 1.9390719429665315, 1.9595917942265426, 1.979898987322333, 2.0, 2.0199009876724157, 2.039607805437114, 2.0591260281974004, 2.078460969082653, 2.0976176963403033, 2.116601048851672, 2.1354156504062622, 2.1540659228538015, 2.172556098240043, 2.1908902300206643, 2.209072203437452, 2.2271057451320084, 2.244994432064365, 2.262741699796952, 2.2803508501982757, 2.2978250586152114, 2.315167380558045, 2.33238075793812, 2.349468024894146, 2.3664319132398464, 2.3832750575625967, 2.4, 2.4166091947189146, 2.4331050121192876, 2.449489742783178, 2.4657656011875906, 2.4819347291981715, 2.4979991993593593, 2.513961017995307, 2.5298221281347035, 2.545584412271571, 2.5612496949731396, 2.576819745345025, 2.5922962793631443, 2.6076809620810595, 2.6229754097208002, 2.6381811916545836, 2.6532998322843198, 2.6683328128252666, 2.6832815729997477, 2.698147512646408, 2.7129319932501073, 2.727636339397171, 2.7422618401604177, 2.756809750418044, 2.7712812921102037, 2.785677655436824, 2.8, 2.814249455894058, 2.8284271247461903, 2.8425340807103794], [0.0, 0.3, 0.4242640687119285, 0.5196152422706632, 0.6, 0.6708203932499369, 0.7348469228349535, 0.7937253933193772, 0.848528137423857, 0.8999999999999999, 0.9486832980505138, 0.99498743710662, 1.0392304845413265, 1.0816653826391969, 1.1224972160321824, 1.1618950038622249, 1.2, 1.236931687685298, 1.2727922061357855, 1.307669683062202, 1.3416407864998738, 1.374772708486752, 1.407124727947029, 1.438749456993816, 1.469693845669907, 1.5, 1.5297058540778354, 1.5588457268119895, 1.5874507866387544, 1.6155494421403513, 1.6431676725154982, 1.6703293088490065, 1.697056274847714, 1.7233687939614086, 1.7492855684535902, 1.7748239349298847, 1.7999999999999998, 1.8248287590894658, 1.849324200890693, 1.8734993995195195, 1.8973665961010275, 1.9209372712298547, 1.9442222095223582, 1.9672315572906, 1.98997487421324, 2.0124611797498106, 2.0346989949375804, 2.056696380120313, 2.078460969082653, 2.1, 2.1213203435596424, 2.142428528562855, 2.1633307652783937, 2.1840329667841556, 2.2045407685048604, 2.224859546128699, 2.244994432064365, 2.264950330581225, 2.2847319317591723, 2.3043437243605824, 2.3237900077244498, 2.3430749027719964, 2.362202362203543, 2.3811761799581315, 2.4, 2.4186773244895647, 2.437211521390788, 2.455605831561735, 2.473863375370596, 2.4919871588754225, 2.5099800796022267, 2.5278449319529073, 2.545584412271571, 2.563201123595259, 2.580697580112788, 2.598076211353316, 2.615339366124404, 2.6324893162176366, 2.6495282598983545, 2.6664583251946765, 2.6832815729997477, 2.7, 2.716615541441225, 2.7331300737432893, 2.749545416973504, 2.765863337187866, 2.7820855486487113, 2.7982137159266447, 2.814249455894058, 2.830194339616981, 2.846049894151541, 2.8618176042508368, 2.877498913987632, 2.8930952282978866, 2.9086079144497976, 2.9240383034426887, 2.939387691339814, 2.9546573405388314, 2.9698484809834995, 2.98496231131986, 3.0, 3.0149626863362675], [0.0, 0.31622776601683794, 0.4472135954999579, 0.5477225575051662, 0.6324555320336759, 0.7071067811865476, 0.7745966692414834, 0.8366600265340756, 0.8944271909999159, 0.9486832980505138, 1.0, 1.0488088481701516, 1.0954451150103324, 1.140175425099138, 1.1832159566199232, 1.224744871391589, 1.2649110640673518, 1.3038404810405297, 1.3416407864998738, 1.3784048752090223, 1.4142135623730951, 1.449137674618944, 1.4832396974191326, 1.5165750888103102, 1.5491933384829668, 1.5811388300841898, 1.61245154965971, 1.6431676725154984, 1.6733200530681511, 1.7029386365926402, 1.7320508075688772, 1.760681686165901, 1.7888543819998317, 1.8165902124584952, 1.8439088914585775, 1.8708286933869707, 1.8973665961010275, 1.9235384061671346, 1.949358868961793, 1.97484176581315, 2.0, 2.024845673131659, 2.04939015319192, 2.073644135332772, 2.0976176963403033, 2.1213203435596424, 2.1447610589527217, 2.16794833886788, 2.1908902300206647, 2.2135943621178655, 2.23606797749979, 2.2583179581272432, 2.280350850198276, 2.302172886644268, 2.32379000772445, 2.345207879911715, 2.3664319132398464, 2.3874672772626644, 2.4083189157584592, 2.4289915602982237, 2.449489742783178, 2.4698178070456938, 2.4899799195977463, 2.5099800796022267, 2.5298221281347035, 2.5495097567963922, 2.569046515733026, 2.588435821108957, 2.6076809620810595, 2.6267851073127395, 2.6457513110645907, 2.6645825188948455, 2.6832815729997477, 2.701851217221259, 2.7202941017470885, 2.7386127875258306, 2.7568097504180447, 2.7748873851023217, 2.7928480087537886, 2.8106938645110393, 2.8284271247461903, 2.8460498941515415, 2.863564212655271, 2.8809720581775866, 2.898275349237888, 2.9154759474226504, 2.932575659723036, 2.9495762407505253, 2.9664793948382653, 2.9832867780352594, 3.0, 3.0166206257996713, 3.0331501776206204, 3.0495901363953815, 3.0659419433511785, 3.082207001484488, 3.0983866769659336, 3.1144823004794877, 3.1304951684997055, 3.146426544510455, 3.1622776601683795, 3.178049716414141], [0.0, 0.33166247903554, 0.469041575982343, 0.574456264653803, 0.66332495807108, 0.7416198487095664, 0.8124038404635961, 0.8774964387392122, 0.938083151964686, 0.99498743710662, 1.0488088481701516, 1.1, 1.148912529307606, 1.1958260743101399, 1.2409673645990857, 1.284523257866513, 1.32664991614216, 1.3674794331177345, 1.407124727947029, 1.4456832294800963, 1.4832396974191329, 1.5198684153570665, 1.5556349186104048, 1.5905973720586868, 1.6248076809271923, 1.6583123951777001, 1.6911534525287766, 1.7233687939614089, 1.7549928774784245, 1.7860571099491753, 1.816590212458495, 1.846618531261939, 1.876166303929372, 1.9052558883257653, 1.9339079605813718, 1.9621416870348585, 1.98997487421324, 2.017424100183202, 2.0445048300260877, 2.0712315177207983, 2.0976176963403033, 2.1236760581595306, 2.149418526020468, 2.1748563170931545, 2.2, 2.224859546128699, 2.249444375840399, 2.273763400180415, 2.297825058615212, 2.32163735324878, 2.345207879911715, 2.368543856465403, 2.3916521486202797, 2.4145392935299275, 2.4372115213907883, 2.459674775249769, 2.4819347291981715, 2.503996805109783, 2.525866188063018, 2.5475478405713994, 2.569046515733026, 2.5903667693977237, 2.6115129714401193, 2.632489316217637, 2.65329983228432, 2.6739483914241875, 2.6944387170614963, 2.714774392099646, 2.734958866235469, 2.7549954627911823, 2.774887385102322, 2.7946377224964243, 2.814249455894058, 2.833725463060951, 2.8530685235374214, 2.8722813232690148, 2.8913664589601926, 2.91032644217105, 2.9291637031753623, 2.9478805945967355, 2.9664793948382657, 2.9849623113198605, 3.003331483536242, 3.0215889859476257, 3.039736830714133, 3.0577769702841313, 3.07571129984594, 3.093541659651604, 3.1112698372208096, 3.1288975694324033, 3.146426544510455, 3.1638584039112754, 3.1811947441173736, 3.1984371183438958, 3.2155870381627056, 3.2326459750489227, 3.2496153618543846, 3.2664965942122155, 3.283291031876401, 3.3000000000000007, 3.3166247903554003, 3.333166662499792], [0.0, 0.3464101615137755, 0.48989794855663565, 0.6000000000000002, 0.692820323027551, 0.7745966692414835, 0.8485281374238571, 0.9165151389911681, 0.9797958971132713, 1.0392304845413265, 1.0954451150103324, 1.148912529307606, 1.2000000000000004, 1.2489995996796799, 1.2961481396815722, 1.3416407864998738, 1.385640646055102, 1.4282856857085702, 1.4696938456699071, 1.5099668870541503, 1.549193338482967, 1.5874507866387546, 1.6248076809271923, 1.6613247725836153, 1.6970562748477143, 1.7320508075688776, 1.7663521732655698, 1.8000000000000003, 1.8330302779823362, 1.8654758106177634, 1.8973665961010278, 1.9287301521985913, 1.9595917942265426, 1.9899748742132404, 2.019900987672416, 2.04939015319192, 2.078460969082653, 2.107130750570548, 2.1354156504062627, 2.163330765278394, 2.1908902300206647, 2.2181073012818837, 2.2449944320643653, 2.2715633383201097, 2.297825058615212, 2.32379000772445, 2.3494680248941466, 2.374868417407584, 2.400000000000001, 2.4248711305964283, 2.4494897427831783, 2.473863375370597, 2.4979991993593598, 2.521904042583699, 2.5455844122715714, 2.5690465157330262, 2.5922962793631443, 2.6153393661244047, 2.6381811916545845, 2.6608269391300143, 2.6832815729997477, 2.705549851693737, 2.727636339397171, 2.7495454169735045, 2.771281292110204, 2.7928480087537886, 2.8142494558940583, 2.8354893757515653, 2.8565713714171403, 2.8774989139876324, 2.8982753492378883, 2.918903903865285, 2.9393876913398143, 2.9597297173897488, 2.979932885150268, 3.0000000000000004, 3.0199337741083006, 3.039736830714133, 3.0594117081556718, 3.078960863668131, 3.098386676965934, 3.1176914536239795, 3.136877428271625, 3.1559467676119004, 3.174901573277509, 3.193743884534263, 3.2124756808418025, 3.231098884280703, 3.2496153618543846, 3.2680269276736387, 3.286335345030997, 3.3045423283716615, 3.3226495451672307, 3.340658617698014, 3.3585711247493335, 3.3763886032268267, 3.3941125496954285, 3.411744421846397, 3.4292856398964497, 3.4467375879228177, 3.4641016151377553, 3.481379037105843], [0.0, 0.36055512754639896, 0.5099019513592785, 0.6244997998398399, 0.7211102550927979, 0.806225774829855, 0.8831760866327848, 0.9539392014169458, 1.019803902718557, 1.0816653826391969, 1.140175425099138, 1.1958260743101399, 1.2489995996796799, 1.3000000000000003, 1.3490737563232043, 1.396424004376894, 1.4422205101855958, 1.4866068747318506, 1.5297058540778357, 1.5716233645501714, 1.61245154965971, 1.6522711641858308, 1.6911534525287764, 1.7291616465790585, 1.7663521732655696, 1.8027756377319948, 1.8384776310850237, 1.8734993995195197, 1.9078784028338915, 1.94164878389476, 1.9748417658131499, 2.0074859899884734, 2.039607805437114, 2.0712315177207983, 2.102379604162864, 2.1330729007701543, 2.1633307652783937, 2.193171219946131, 2.222611077089287, 2.2516660498395407, 2.280350850198276, 2.3086792761230397, 2.336664289109585, 2.364318083507378, 2.3916521486202797, 2.4186773244895647, 2.445403852127497, 2.471841418861655, 2.4979991993593598, 2.5238858928247927, 2.5495097567963927, 2.574878637916747, 2.6000000000000005, 2.624880949681338, 2.6495282598983545, 2.673948391424188, 2.6981475126464085, 2.72213151776324, 2.7459060435491964, 2.7694764848252458, 2.792848008753788, 2.816025568065745, 2.839013913315678, 2.861817604250837, 2.8844410203711917, 2.9068883707497264, 2.9291637031753623, 2.951270912674741, 2.973213749463701, 2.994995826374388, 3.0166206257996717, 3.0380915061926625, 3.0594117081556713, 3.0805843601498726, 3.1016124838541645, 3.122498999199199, 3.1432467291003428, 3.1638584039112754, 3.1843366656181322, 3.204684071792413, 3.22490309931942, 3.2449961479175906, 3.264965543462902, 3.2848135411313684, 3.3045423283716615, 3.3241540277189325, 3.343650699460098, 3.363034344160048, 3.3823069050575527, 3.4014702703389896, 3.420526275297414, 3.439476704383968, 3.458323293158117, 3.4770677301427426, 3.4957116585897072, 3.5142566781611158, 3.532704346531139, 3.5510561809129415, 3.5693136595149495, 3.58747822293042, 3.6055512754639896, 3.6235341863986883], [0.0, 0.37416573867739417, 0.529150262212918, 0.6480740698407861, 0.7483314773547883, 0.8366600265340756, 0.916515138991168, 0.9899494936611666, 1.058300524425836, 1.1224972160321824, 1.1832159566199232, 1.2409673645990857, 1.2961481396815722, 1.3490737563232043, 1.4, 1.4491376746189437, 1.4966629547095767, 1.5427248620541512, 1.5874507866387544, 1.6309506430300091, 1.6733200530681511, 1.7146428199482247, 1.7549928774784245, 1.7944358444926363, 1.833030277982336, 1.8708286933869707, 1.9078784028338913, 1.9442222095223582, 1.9798989873223332, 2.0149441679609885, 2.0493901531919194, 2.083266665599966, 2.116601048851672, 2.149418526020468, 2.181742422927143, 2.2135943621178655, 2.244994432064365, 2.2759613353482084, 2.3065125189341593, 2.3366642891095846, 2.3664319132398464, 2.395829710142188, 2.4248711305964283, 2.453568829277059, 2.4819347291981715, 2.5099800796022262, 2.5377155080899043, 2.565151067676132, 2.5922962793631443, 2.619160170741759, 2.6457513110645907, 2.672077843177478, 2.6981475126464085, 2.7239676943752476, 2.749545416973504, 2.7748873851023217, 2.8, 2.824889378365107, 2.8495613697550017, 2.8740215726399825, 2.8982753492378874, 2.9223278392404914, 2.9461839725312466, 2.9698484809834995, 2.9933259094191533, 3.016620625799671, 3.0397368307141326, 3.062678566222711, 3.0854497241083023, 3.1080540535840107, 3.1304951684997055, 3.152776554086889, 3.1749015732775088, 3.196873472629156, 3.218695387886216, 3.24037034920393, 3.2619012860600183, 3.283291031876401, 3.3045423283716615, 3.3256578296631782, 3.3466401061363023, 3.3674916480965473, 3.3882148692194836, 3.408812109811862, 3.4292856398964493, 3.449637662132068, 3.4698703145794947, 3.4899856733230297, 3.509985754956849, 3.529872518944558, 3.5496478698597693, 3.5693136595149495, 3.5888716889852725, 3.6083237105337433, 3.627671429443411, 3.6469165057620936, 3.666060555964672, 3.685105154537656, 3.704051835490427, 3.722902093797257, 3.7416573867739413, 3.7603191353926335], [0.0, 0.38729833462074165, 0.5477225575051661, 0.6708203932499369, 0.7745966692414833, 0.8660254037844386, 0.9486832980505138, 1.0246950765959597, 1.0954451150103321, 1.1618950038622249, 1.224744871391589, 1.284523257866513, 1.3416407864998738, 1.396424004376894, 1.4491376746189437, 1.4999999999999998, 1.5491933384829666, 1.5968719422671311, 1.6431676725154982, 1.6881943016134133, 1.7320508075688772, 1.7748239349298847, 1.816590212458495, 1.857417562100671, 1.8973665961010275, 1.9364916731037083, 1.9748417658131499, 2.0124611797498106, 2.0493901531919194, 2.085665361461421, 2.1213203435596424, 2.1563858652847823, 2.1908902300206643, 2.224859546128699, 2.258317958127243, 2.29128784747792, 2.3237900077244498, 2.355843797877949, 2.3874672772626644, 2.4186773244895647, 2.449489742783178, 2.479919353527449, 2.5099800796022267, 2.5396850198400585, 2.569046515733026, 2.5980762113533156, 2.626785107312739, 2.6551836094703507, 2.6832815729997477, 2.7110883423451915, 2.7386127875258306, 2.765863337187866, 2.792848008753788, 2.819574435974337, 2.846049894151541, 2.8722813232690143, 2.8982753492378874, 2.924038303442689, 2.9495762407505253, 2.974894956128703, 2.9999999999999996, 3.0248966924508345, 3.049590136395381, 3.074085229787879, 3.098386676965933, 3.1224989991991987, 3.1464265445104544, 3.1701734968294715, 3.1937438845342623, 3.217141588429082, 3.24037034920393, 3.2634337744161437, 3.2863353450309964, 3.309078421554859, 3.3316662497915357, 3.3541019662496843, 3.3763886032268267, 3.3985290935932855, 3.420526275297414, 3.442382895611701, 3.4641016151377544, 3.485685011586675, 3.5071355833500366, 3.5284557528754696, 3.5496478698597693, 3.5707142142714248, 3.591656999213594, 3.6124783736376886, 3.63318042491699, 3.6537651812890215, 3.674234614174767, 3.694590640382233, 3.714835124201342, 3.7349698793966195, 3.7549966711037173, 3.7749172176353745, 3.794733192202055, 3.8144462245521304, 3.8340579025361623, 3.853569773599539, 3.8729833462074166, 3.892300091205713], [0.0, 0.4, 0.565685424949238, 0.692820323027551, 0.8, 0.894427190999916, 0.9797958971132713, 1.0583005244258363, 1.131370849898476, 1.2, 1.2649110640673518, 1.32664991614216, 1.385640646055102, 1.4422205101855958, 1.4966629547095767, 1.5491933384829666, 1.6, 1.6492422502470643, 1.697056274847714, 1.7435595774162698, 1.788854381999832, 1.8330302779823362, 1.876166303929372, 1.918332609325088, 1.9595917942265426, 2.0, 2.039607805437114, 2.078460969082653, 2.1166010488516727, 2.154065922853802, 2.1908902300206643, 2.227105745132009, 2.262741699796952, 2.297825058615212, 2.3323807579381204, 2.3664319132398464, 2.4, 2.433105012119288, 2.4657656011875906, 2.4979991993593598, 2.5298221281347035, 2.5612496949731396, 2.5922962793631443, 2.6229754097208002, 2.65329983228432, 2.6832815729997477, 2.7129319932501073, 2.7422618401604177, 2.771281292110204, 2.8000000000000003, 2.8284271247461903, 2.8565713714171403, 2.8844410203711917, 2.9120439557122078, 2.939387691339814, 2.9664793948382653, 2.9933259094191533, 3.0199337741083, 3.0463092423455636, 3.0724582991474434, 3.098386676965933, 3.1240998703626617, 3.149603149604724, 3.1749015732775088, 3.2, 3.2249030993194197, 3.249615361854384, 3.2741411087489802, 3.2984845004941286, 3.32264954516723, 3.3466401061363023, 3.3704599092705436, 3.394112549695428, 3.4176014981270124, 3.4409301068170506, 3.464101615137755, 3.4871191548325395, 3.509985754956849, 3.532704346531139, 3.5552777669262356, 3.577708763999664, 3.6, 3.622154055254967, 3.6441734316577197, 3.6660605559646724, 3.687817782917155, 3.709447398198282, 3.7309516212355263, 3.752332607858744, 3.7735924528226414, 3.794733192202055, 3.8157568056677826, 3.836665218650176, 3.8574603043971822, 3.8781438859330635, 3.8987177379235853, 3.9191835884530852, 3.9395431207184424, 3.9597979746446663, 3.9799497484264803, 4.0, 4.019950248448357], [0.0, 0.41231056256176607, 0.58309518948453, 0.7141428428542851, 0.8246211251235321, 0.9219544457292888, 1.0099504938362078, 1.0908712114635715, 1.16619037896906, 1.236931687685298, 1.3038404810405297, 1.3674794331177345, 1.4282856857085702, 1.4866068747318506, 1.5427248620541512, 1.5968719422671311, 1.6492422502470643, 1.7, 1.7492855684535902, 1.797220075561143, 1.8439088914585775, 1.8894443627691184, 1.9339079605813716, 1.977371993328519, 2.0199009876724157, 2.0615528128088303, 2.102379604162864, 2.142428528562855, 2.181742422927143, 2.220360331117452, 2.258317958127243, 2.2956480566497994, 2.33238075793812, 2.3685438564654024, 2.4041630560342617, 2.4392621835300936, 2.473863375370596, 2.5079872407968904, 2.541653005427767, 2.574878637916747, 2.6076809620810595, 2.6400757564888173, 2.672077843177478, 2.7037011669191546, 2.734958866235469, 2.765863337187866, 2.7964262908219126, 2.826658805020514, 2.8565713714171403, 2.8861739379323623, 2.9154759474226504, 2.944486372867092, 2.973213749463701, 3.001666203960727, 3.0298514815086235, 3.0577769702841313, 3.0854497241083023, 3.1128764832546763, 3.1400636936215167, 3.167017524422623, 3.1937438845342623, 3.2202484376209237, 3.246536616149585, 3.2726136343907144, 3.2984845004941286, 3.324154027718932, 3.3496268448888453, 3.374907406137241, 3.4, 3.424908757908742, 3.4496376621320683, 3.4741905532080417, 3.4985711369071804, 3.522782990761707, 3.5468295701936396, 3.570714214271425, 3.594440151122286, 3.6180105030251086, 3.6414282912066254, 3.664696440361739, 3.687817782917155, 3.710795063055895, 3.733630940518894, 3.7563279941985894, 3.778888725538237, 3.8013155617496426, 3.8236108588610325, 3.845776904605882, 3.867815921162743, 3.8897300677553446, 3.9115214431215892, 3.9331920878594273, 3.954743986657038, 3.976179070414209, 3.9974992182613374, 4.018706259482023, 4.039801975344831, 4.060788100849391, 4.08166632639171, 4.102438299353203, 4.123105625617661, 4.1436698710201325], [0.0, 0.4242640687119285, 0.6, 0.7348469228349536, 0.848528137423857, 0.9486832980505139, 1.0392304845413265, 1.1224972160321824, 1.2, 1.2727922061357855, 1.3416407864998738, 1.407124727947029, 1.4696938456699071, 1.5297058540778357, 1.5874507866387544, 1.6431676725154982, 1.697056274847714, 1.7492855684535902, 1.8, 1.8493242008906932, 1.8973665961010278, 1.9442222095223582, 1.98997487421324, 2.0346989949375804, 2.078460969082653, 2.121320343559643, 2.1633307652783937, 2.2045407685048604, 2.244994432064365, 2.2847319317591728, 2.32379000772445, 2.3622023622035435, 2.4, 2.4372115213907883, 2.4738633753705965, 2.5099800796022267, 2.545584412271571, 2.5806975801127883, 2.615339366124404, 2.6495282598983545, 2.6832815729997477, 2.716615541441225, 2.749545416973504, 2.782085548648711, 2.814249455894058, 2.846049894151541, 2.877498913987632, 2.9086079144497976, 2.9393876913398143, 2.9698484809834995, 3.0, 3.029851481508624, 3.0594117081556713, 3.0886890422961004, 3.1176914536239795, 3.146426544510455, 3.1749015732775088, 3.2031234756093934, 3.2310988842807027, 3.2588341473600644, 3.2863353450309964, 3.3136083051561784, 3.340658617698013, 3.3674916480965473, 3.394112549695428, 3.420526275297414, 3.4467375879228173, 3.4727510708370675, 3.4985711369071804, 3.5242020373412193, 3.5496478698597698, 3.5749125863438955, 3.6, 3.6249137920783716, 3.6496575181789317, 3.6742346141747673, 3.6986484017813863, 3.722902093797257, 3.7469987990390394, 3.7709415269929605, 3.7947331922020555, 3.8183766184073566, 3.84187454245971, 3.8652296180175374, 3.8884444190447165, 3.9115214431215897, 3.9344631145812006, 3.957271787481876, 3.97994974842648, 4.0024992192379, 4.024922359499621, 4.047221268969612, 4.069397989875161, 4.091454509095757, 4.113392760240627, 4.135214625627066, 4.156921938165306, 4.178516483155236, 4.2, 4.221374183841087, 4.242640687119286, 4.263801121065569], [0.0, 0.43588989435406744, 0.6164414002968976, 0.7549834435270751, 0.8717797887081349, 0.9746794344808966, 1.0677078252031313, 1.1532562594670797, 1.2328828005937953, 1.307669683062202, 1.3784048752090223, 1.4456832294800963, 1.5099668870541503, 1.5716233645501714, 1.6309506430300091, 1.6881943016134133, 1.7435595774162698, 1.797220075561143, 1.8493242008906932, 1.9000000000000004, 1.9493588689617931, 1.9974984355438181, 2.0445048300260877, 2.0904544960366875, 2.1354156504062627, 2.179449471770337, 2.2226110770892875, 2.2649503305812253, 2.3065125189341593, 2.3473389188611007, 2.3874672772626644, 2.4269322199023198, 2.4657656011875906, 2.503996805109783, 2.5416530054277673, 2.5787593916455256, 2.615339366124404, 2.651414716712571, 2.687005768508881, 2.7221315177632404, 2.7568097504180447, 2.791057147390573, 2.8248893783651075, 2.8583211855912904, 2.8913664589601926, 2.924038303442689, 2.956349099818897, 2.9883105594967874, 3.0199337741083006, 3.051229260478472, 3.082207001484489, 3.1128764832546767, 3.1432467291003428, 3.1733263305244868, 3.203123475609394, 3.232645975048923, 3.2619012860600183, 3.290896534380867, 3.319638534539567, 3.3481338085566414, 3.3763886032268267, 3.4044089061098406, 3.432200460346103, 3.4597687784012394, 3.4871191548325395, 3.5142566781611158, 3.541186241925155, 3.567912554982255, 3.594440151122286, 3.6207733980463352, 3.6469165057620945, 3.672873534441392, 3.6986484017813863, 3.7242448899072147, 3.749666651850535, 3.7749172176353754, 3.8000000000000007, 3.824918299781056, 3.8496753109840323, 3.874274125562104, 3.8987177379235862, 3.9230090491866068, 3.947150871198111, 3.9711459303329564, 3.9949968710876362, 4.018706259482024, 4.042276586281548, 4.065710270051225, 4.0890096600521755, 4.112177038990418, 4.135214625627067, 4.158124577258358, 4.180908992073375, 4.203569911396741, 4.226109321823088, 4.2485291572496005, 4.270831300812525, 4.293017586733137, 4.315089802078284, 4.337049688440289, 4.358898943540674, 4.380639222761903], [0.0, 0.447213595499958, 0.6324555320336759, 0.7745966692414835, 0.894427190999916, 1.0000000000000002, 1.0954451150103324, 1.1832159566199234, 1.2649110640673518, 1.3416407864998738, 1.4142135623730951, 1.4832396974191329, 1.549193338482967, 1.61245154965971, 1.6733200530681511, 1.7320508075688772, 1.788854381999832, 1.8439088914585775, 1.8973665961010278, 1.9493588689617931, 2.0000000000000004, 2.04939015319192, 2.0976176963403033, 2.144761058952722, 2.1908902300206647, 2.23606797749979, 2.280350850198276, 2.3237900077244507, 2.366431913239847, 2.4083189157584592, 2.4494897427831783, 2.489979919597747, 2.5298221281347035, 2.5690465157330262, 2.60768096208106, 2.6457513110645907, 2.6832815729997477, 2.720294101747089, 2.7568097504180447, 2.7928480087537886, 2.8284271247461903, 2.863564212655271, 2.8982753492378883, 2.932575659723036, 2.9664793948382657, 3.0, 3.0331501776206204, 3.0659419433511785, 3.098386676965934, 3.130495168499706, 3.1622776601683795, 3.193743884534263, 3.22490309931942, 3.255764119219942, 3.286335345030997, 3.3166247903554003, 3.3466401061363023, 3.3763886032268267, 3.405877273185281, 3.4351128074635335, 3.4641016151377544, 3.492849839314596, 3.521363372331802, 3.5496478698597698, 3.577708763999664, 3.605551275463989, 3.6331804249169903, 3.6606010435446255, 3.687817782917155, 3.7148351242013424, 3.7416573867739418, 3.768288736283355, 3.7947331922020555, 3.82099463490856, 3.847076812334269, 3.872983346207417, 3.8987177379235862, 3.924283374069717, 3.9496835316263006, 3.9749213828703587, 4.000000000000001, 4.024922359499622, 4.049691346263318, 4.0743097574926725, 4.09878030638384, 4.123105625617661, 4.147288270665545, 4.171330722922843, 4.1952353926806065, 4.219004621945797, 4.242640687119286, 4.266145801540309, 4.289522117905444, 4.312771730569565, 4.335896677735761, 4.358898943540674, 4.3817804600413295, 4.404543109109049, 4.427188724235731, 4.449719092257398, 4.47213595499958, 4.494441010848847], [0.0, 0.45825756949558405, 0.6480740698407861, 0.7937253933193773, 0.9165151389911681, 1.02469507659596, 1.1224972160321824, 1.2124355652982142, 1.2961481396815722, 1.374772708486752, 1.449137674618944, 1.5198684153570665, 1.5874507866387546, 1.6522711641858308, 1.7146428199482247, 1.7748239349298847, 1.8330302779823362, 1.8894443627691184, 1.9442222095223582, 1.9974984355438181, 2.04939015319192, 2.1, 2.149418526020468, 2.1977260975835913, 2.244994432064365, 2.2912878474779204, 2.336664289109585, 2.381176179958132, 2.4248711305964283, 2.4677925358506134, 2.5099800796022267, 2.551470164434615, 2.5922962793631443, 2.632489316217637, 2.672077843177478, 2.711088342345192, 2.749545416973504, 2.787471972953271, 2.824889378365107, 2.861817604250837, 2.898275349237888, 2.934280150224242, 2.9698484809835, 3.004995840263344, 3.039736830714133, 3.0740852297878796, 3.108054053584011, 3.1416556144810017, 3.174901573277509, 3.2078029864690882, 3.2403703492039306, 3.272613634390715, 3.3045423283716615, 3.336165463522456, 3.3674916480965478, 3.398529093593286, 3.4292856398964493, 3.459768778401239, 3.48998567332303, 3.5199431813596083, 3.5496478698597693, 3.5791060336346563, 3.608323710533743, 3.6373066958946425, 3.6660605559646724, 3.6945906403822333, 3.722902093797257, 3.7509998667022106, 3.778888725538237, 3.8065732621348563, 3.834057902536163, 3.861346915261565, 3.8884444190447165, 3.915354390090379, 3.9420806688854046, 3.968626966596886, 3.9949968710876362, 4.02119385257662, 4.047221268969613, 4.07308237088326, 4.09878030638384, 4.124318125460256, 4.149698784249287, 4.174925149029621, 4.2, 4.224926034855522, 4.249705872175156, 4.274342054632503, 4.298837052040936, 4.323193264243457, 4.347413023856832, 4.371498598878879, 4.3954521951671826, 4.419275958796871, 4.442971978304612, 4.466542286825459, 4.48998886412873, 4.513313638558704, 4.536518488885503, 4.559605246071199, 4.582575694955841, 4.605431575867782], [0.0, 0.469041575982343, 0.6633249580710799, 0.8124038404635961, 0.938083151964686, 1.0488088481701516, 1.148912529307606, 1.2409673645990857, 1.3266499161421599, 1.407124727947029, 1.4832396974191326, 1.5556349186104048, 1.6248076809271923, 1.6911534525287764, 1.7549928774784245, 1.816590212458495, 1.876166303929372, 1.9339079605813716, 1.98997487421324, 2.0445048300260877, 2.0976176963403033, 2.149418526020468, 2.2, 2.249444375840399, 2.297825058615212, 2.345207879911715, 2.3916521486202797, 2.4372115213907883, 2.4819347291981715, 2.5258661880630178, 2.569046515733026, 2.6115129714401193, 2.6532998322843198, 2.6944387170614963, 2.734958866235469, 2.7748873851023217, 2.814249455894058, 2.8530685235374214, 2.891366458960192, 2.9291637031753623, 2.9664793948382653, 3.0033314835362415, 3.039736830714133, 3.0757112998459397, 3.1112698372208096, 3.1464265445104544, 3.1811947441173736, 3.2155870381627056, 3.2496153618543846, 3.283291031876401, 3.3166247903554003, 3.3496268448888458, 3.3823069050575527, 3.414674215792775, 3.4467375879228173, 3.4785054261852175, 3.509985754956849, 3.5411862419251547, 3.5721142198983507, 3.602776706930364, 3.63318042491699, 3.6633318168028404, 3.6932370625238775, 3.722902093797257, 3.752332607858744, 3.7815340802378072, 3.81051177665153, 3.8392707640904935, 3.867815921162743, 3.8961519477556315, 3.924283374069717, 3.952214569073901, 3.97994974842648, 4.007492981902776, 4.034848200366403, 4.06201920231798, 4.0890096600521755, 4.115823125451336, 4.1424630354415966, 4.168932717135166, 4.1952353926806065, 4.221374183841087, 4.247352116319061, 4.273172123844299, 4.298837052040936, 4.324349662087931, 4.349712634186309, 4.374928570845472, 4.4, 4.424929377967517, 4.449719092257398, 4.474371464239419, 4.498888751680798, 4.523273151159457, 4.54752680036083, 4.571651780264984, 4.595650117230424, 4.61952378498044, 4.64327470649756, 4.666904755831214, 4.69041575982343, 4.713809499757071], [0.0, 0.479583152331272, 0.6782329983125268, 0.8306623862918077, 0.959166304662544, 1.072380529476361, 1.174734012447073, 1.2688577540449522, 1.3564659966250536, 1.438749456993816, 1.5165750888103102, 1.5905973720586868, 1.6613247725836153, 1.7291616465790585, 1.7944358444926363, 1.857417562100671, 1.918332609325088, 1.977371993328519, 2.0346989949375804, 2.0904544960366875, 2.144761058952722, 2.1977260975835913, 2.249444375840399, 2.3000000000000003, 2.349468024894146, 2.39791576165636, 2.4454038521274972, 2.491987158875423, 2.5377155080899043, 2.582634314028992, 2.6267851073127395, 2.670205984563738, 2.7129319932501073, 2.754995462791183, 2.7964262908219126, 2.8372521918222215, 2.877498913987632, 2.917190429162965, 2.956349099818897, 2.994995826374388, 3.0331501776206204, 3.0708305065568178, 3.108054053584011, 3.1448370387032774, 3.1811947441173736, 3.2171415884290826, 3.252691193458119, 3.2878564445547194, 3.3226495451672307, 3.357082066318904, 3.3911649915626345, 3.4249087579087423, 3.458323293158117, 3.491418050019219, 3.5242020373412197, 3.5566838487557484, 3.5888716889852725, 3.620773398046335, 3.6523964735499352, 3.6837480912787726, 3.714835124201342, 3.745664160065609, 3.7762415176998414, 3.8065732621348563, 3.836665218650176, 3.866522985836241, 3.8961519477556315, 3.9255572852781047, 3.954743986657038, 3.9837168574084183, 4.012480529547776, 4.041039470235351, 4.069397989875161, 4.097560249709576, 4.125530268947254, 4.153311931459037, 4.180908992073375, 4.2083250825001635, 4.235563716909475, 4.262628297189424, 4.289522117905444, 4.316248370981448, 4.342810150121694, 4.369210454990696, 4.3954521951671826, 4.421538193886829, 4.447471191587417, 4.473253849269009, 4.498888751680798, 4.524378410345448, 4.549725266430931, 4.57493169347915, 4.6000000000000005, 4.624932431938872, 4.649731175025068, 4.674398357008098, 4.698936049788292, 4.723346271447818, 4.747630988187688, 4.77179211617606, 4.79583152331272, 4.819751030914357], [0.0, 0.48989794855663565, 0.6928203230275509, 0.8485281374238571, 0.9797958971132713, 1.0954451150103324, 1.2000000000000002, 1.2961481396815722, 1.3856406460551018, 1.469693845669907, 1.5491933384829668, 1.6248076809271923, 1.6970562748477143, 1.7663521732655696, 1.833030277982336, 1.8973665961010275, 1.9595917942265426, 2.0199009876724157, 2.078460969082653, 2.1354156504062627, 2.1908902300206647, 2.244994432064365, 2.297825058615212, 2.349468024894146, 2.4000000000000004, 2.4494897427831783, 2.4979991993593598, 2.5455844122715714, 2.5922962793631443, 2.638181191654584, 2.6832815729997477, 2.727636339397171, 2.7712812921102037, 2.8142494558940583, 2.8565713714171403, 2.898275349237888, 2.939387691339814, 2.979932885150268, 3.0199337741083, 3.0594117081556713, 3.0983866769659336, 3.136877428271625, 3.174901573277509, 3.212475680841802, 3.2496153618543846, 3.2863353450309964, 3.32264954516723, 3.358571124749333, 3.3941125496954285, 3.4292856398964493, 3.464101615137755, 3.498571136907181, 3.532704346531139, 3.5665109000254023, 3.6, 3.6331804249169903, 3.666060555964672, 3.698648401781386, 3.7309516212355263, 3.7629775444453557, 3.794733192202055, 3.8262252939417984, 3.857460304397182, 3.8884444190447165, 3.9191835884530852, 3.9496835316262997, 3.97994974842648, 4.009987531152684, 4.039801975344831, 4.069397989875161, 4.09878030638384, 4.127953488110059, 4.156921938165306, 4.18568990729127, 4.214261501141095, 4.242640687119286, 4.270831300812525, 4.298837052040936, 4.3266615305567875, 4.354308211415448, 4.3817804600413295, 4.409081537009721, 4.436214602563767, 4.463182720884279, 4.48998886412873, 4.5166359162544865, 4.543126676640219, 4.5694638635183455, 4.595650117230424, 4.621688003316537, 4.6475800154489, 4.673328578219169, 4.698936049788292, 4.724404724407087, 4.749736834815168, 4.774934554525329, 4.800000000000001, 4.824935232725928, 4.849742261192857, 4.874423042781577, 4.898979485566357, 4.9234134500364695], [0.0, 0.5, 0.7071067811865476, 0.8660254037844388, 1.0, 1.118033988749895, 1.2247448713915892, 1.3228756555322954, 1.4142135623730951, 1.5, 1.5811388300841898, 1.6583123951777001, 1.7320508075688776, 1.8027756377319948, 1.8708286933869707, 1.9364916731037083, 2.0, 2.0615528128088303, 2.121320343559643, 2.179449471770337, 2.23606797749979, 2.2912878474779204, 2.345207879911715, 2.39791576165636, 2.4494897427831783, 2.5000000000000004, 2.5495097567963927, 2.5980762113533165, 2.6457513110645907, 2.6925824035672523, 2.7386127875258306, 2.783882181415011, 2.8284271247461903, 2.8722813232690148, 2.9154759474226504, 2.958039891549808, 3.0, 3.04138126514911, 3.0822070014844885, 3.1224989991991996, 3.1622776601683795, 3.2015621187164247, 3.2403703492039306, 3.278719262151, 3.3166247903554003, 3.3541019662496843, 3.3911649915626345, 3.4278273002005224, 3.4641016151377553, 3.5, 3.535533905932738, 3.5707142142714257, 3.6055512754639896, 3.64005494464026, 3.6742346141747677, 3.708099243547832, 3.7416573867739413, 3.774917217635375, 3.8078865529319548, 3.840572873934304, 3.8729833462074166, 3.9051248379533274, 3.9370039370059056, 3.968626966596886, 4.0, 4.031128874149275, 4.06201920231798, 4.092676385936225, 4.123105625617661, 4.153311931459037, 4.183300132670378, 4.2130748865881795, 4.242640687119286, 4.272001872658766, 4.301162633521313, 4.330127018922194, 4.358898943540674, 4.387482193696061, 4.415880433163924, 4.444097208657795, 4.47213595499958, 4.500000000000001, 4.527692569068709, 4.55521678957215, 4.582575694955841, 4.609772228646444, 4.636809247747852, 4.663689526544408, 4.69041575982343, 4.716990566028302, 4.743416490252569, 4.769696007084729, 4.79583152331272, 4.821825380496478, 4.847679857416329, 4.873397172404482, 4.898979485566357, 4.924428900898053, 4.949747468305833, 4.974937185533101, 5.000000000000001, 5.024937810560446], [0.0, 0.5099019513592785, 0.7211102550927979, 0.8831760866327849, 1.019803902718557, 1.140175425099138, 1.2489995996796799, 1.3490737563232043, 1.4422205101855958, 1.5297058540778354, 1.61245154965971, 1.6911534525287766, 1.7663521732655698, 1.8384776310850237, 1.9078784028338913, 1.9748417658131499, 2.039607805437114, 2.102379604162864, 2.1633307652783937, 2.2226110770892875, 2.280350850198276, 2.336664289109585, 2.3916521486202797, 2.4454038521274972, 2.4979991993593598, 2.5495097567963927, 2.6000000000000005, 2.6495282598983545, 2.6981475126464085, 2.7459060435491964, 2.792848008753788, 2.839013913315678, 2.8844410203711917, 2.9291637031753623, 2.973213749463701, 3.0166206257996713, 3.059411708155671, 3.101612483854165, 3.1432467291003428, 3.1843366656181322, 3.22490309931942, 3.264965543462902, 3.304542328371662, 3.3436506994600976, 3.382306905057553, 3.420526275297414, 3.458323293158117, 3.4957116585897072, 3.5327043465311396, 3.5693136595149495, 3.6055512754639896, 3.6414282912066254, 3.6769552621700474, 3.712142238654118, 3.7469987990390394, 3.7815340802378077, 3.8157568056677826, 3.849675310984032, 3.8832975677895205, 3.916631205513228, 3.9496835316262997, 3.9824615503479754, 4.014971979976946, 4.047221268969613, 4.079215610874228, 4.110960958218893, 4.142463035441596, 4.173727350941841, 4.204759208325728, 4.235563716909475, 4.266145801540309, 4.296510211788167, 4.3266615305567875, 4.356604182158393, 4.386342439892262, 4.415880433163924, 4.445222154178575, 4.474371464239419, 4.503332099679082, 4.532107677449864, 4.560701700396552, 4.589117562233507, 4.617358552246079, 4.645427859734774, 4.67332857821917, 4.701063709417264, 4.7286361670147565, 4.756048780237647, 4.7833042972405595, 4.810405388322278, 4.83735464897913, 4.864154602806124, 4.8908077042549944, 4.917316341257699, 4.943682837723311, 4.969909455915671, 4.9959983987187195, 5.021951811795889, 5.047771785649585, 5.073460357586329, 5.099019513592785, 5.1244511901275835], [0.0, 0.5196152422706632, 0.7348469228349535, 0.9000000000000001, 1.0392304845413265, 1.1618950038622253, 1.2727922061357857, 1.374772708486752, 1.469693845669907, 1.5588457268119895, 1.6431676725154984, 1.7233687939614089, 1.8000000000000003, 1.8734993995195197, 1.9442222095223582, 2.0124611797498106, 2.078460969082653, 2.142428528562855, 2.2045407685048604, 2.2649503305812253, 2.3237900077244507, 2.381176179958132, 2.4372115213907883, 2.491987158875423, 2.5455844122715714, 2.5980762113533165, 2.6495282598983545, 2.7, 2.749545416973504, 2.7982137159266447, 2.8460498941515415, 2.8930952282978866, 2.939387691339814, 2.9849623113198605, 3.0298514815086235, 3.0740852297878796, 3.117691453623979, 3.160696125855822, 3.203123475609394, 3.244996147917591, 3.286335345030997, 3.3271609519228256, 3.3674916480965478, 3.407345007480164, 3.4467375879228177, 3.4856850115866753, 3.5242020373412197, 3.5623026261113755, 3.6000000000000005, 3.6373066958946425, 3.6742346141747677, 3.7107950630558952, 3.7469987990390394, 3.782856063875548, 3.818376618407357, 3.853569773599539, 3.8884444190447165, 3.9230090491866063, 3.957271787481876, 3.9912404086950213, 4.024922359499621, 4.058324777540605, 4.091454509095756, 4.124318125460256, 4.156921938165306, 4.189272013130682, 4.221374183841087, 4.253234063627348, 4.28485705712571, 4.316248370981448, 4.3474130238568325, 4.378355855797928, 4.409081537009721, 4.439594576084623, 4.469899327725402, 4.5, 4.529900661162451, 4.559605246071199, 4.589117562233508, 4.618441295502196, 4.647580015448901, 4.676537180435969, 4.705316142407438, 4.73392015141785, 4.762352359916264, 4.790615826801394, 4.818713521262704, 4.846648326421054, 4.874423042781577, 4.902040391510457, 4.929503017546495, 4.956813492557492, 4.983974317750846, 5.0109879265470205, 5.037856687124, 5.06458290484024, 5.091168824543143, 5.117616632769595, 5.143928459844674, 5.170106381884226, 5.196152422706633, 5.222068555658764], [0.0, 0.5291502622129182, 0.7483314773547882, 0.9165151389911681, 1.0583005244258363, 1.1832159566199234, 1.2961481396815722, 1.4000000000000001, 1.4966629547095764, 1.5874507866387544, 1.6733200530681511, 1.7549928774784245, 1.8330302779823362, 1.9078784028338915, 1.9798989873223332, 2.0493901531919194, 2.1166010488516727, 2.181742422927143, 2.244994432064365, 2.3065125189341593, 2.366431913239847, 2.4248711305964283, 2.4819347291981715, 2.5377155080899043, 2.5922962793631443, 2.6457513110645907, 2.6981475126464085, 2.749545416973504, 2.8000000000000003, 2.8495613697550017, 2.8982753492378874, 2.946183972531247, 2.993325909419153, 3.039736830714133, 3.0854497241083028, 3.1304951684997055, 3.1749015732775088, 3.2186953878862163, 3.2619012860600183, 3.3045423283716615, 3.3466401061363023, 3.3882148692194836, 3.4292856398964497, 3.4698703145794942, 3.509985754956849, 3.5496478698597693, 3.5888716889852725, 3.627671429443411, 3.6660605559646724, 3.704051835490427, 3.7416573867739418, 3.7788887255382373, 3.815756805667783, 3.852272056851645, 3.8884444190447165, 3.924283374069717, 3.9597979746446663, 3.994996871087636, 4.029888335921977, 4.064480286580315, 4.098780306383839, 4.132795663954365, 4.166533331199932, 4.2, 4.233202097703345, 4.266145801540308, 4.298837052040936, 4.331281565541543, 4.363484845854286, 4.3954521951671826, 4.427188724235731, 4.458699361921591, 4.48998886412873, 4.521061822182926, 4.551922670696417, 4.58257569495584, 4.613025037868319, 4.64327470649756, 4.67332857821917, 4.703190406521939, 4.732863826479694, 4.762352359916263, 4.791659420284376, 4.82078831727758, 4.849742261192857, 4.878524367060187, 4.907137658554119, 4.935585071701227, 4.963869458396343, 4.991993589739474, 5.019960159204453, 5.047771785649585, 5.075431016179809, 5.10294032886923, 5.130302135352265, 5.15751878329105, 5.184592558726289, 5.2115256883181535, 5.238320341483518, 5.264978632435274, 5.291502622129181, 5.317894320123333], [0.0, 0.5385164807134505, 0.7615773105863909, 0.9327379053088817, 1.077032961426901, 1.2041594578792296, 1.319090595827292, 1.4247806848775009, 1.5231546211727818, 1.6155494421403513, 1.7029386365926402, 1.7860571099491753, 1.8654758106177634, 1.94164878389476, 2.0149441679609885, 2.085665361461421, 2.154065922853802, 2.220360331117452, 2.2847319317591728, 2.3473389188611007, 2.4083189157584592, 2.4677925358506134, 2.5258661880630178, 2.582634314028992, 2.638181191654584, 2.6925824035672523, 2.7459060435491964, 2.7982137159266447, 2.8495613697550017, 2.9000000000000004, 2.9495762407505253, 2.99833287011299, 3.0463092423455636, 3.0935416596516045, 3.1400636936215167, 3.1859064644147983, 3.2310988842807027, 3.2756678708318403, 3.3196385345395667, 3.363034344160048, 3.4058772731852804, 3.448187929913334, 3.48998567332303, 3.531288716601915, 3.5721142198983507, 3.6124783736376886, 3.6523964735499352, 3.691882988394947, 3.7309516212355267, 3.769615364994153, 3.8078865529319548, 3.845776904605883, 3.88329756778952, 3.9204591567825324, 3.957271787481876, 3.993745109543172, 4.029888335921977, 4.065710270051224, 4.101219330881976, 4.136423575989287, 4.171330722922842, 4.205948168962618, 4.240283009422838, 4.274342054632503, 4.308131845707604, 4.341658669218482, 4.374928570845472, 4.407947368106838, 4.440720662234904, 4.473253849269009, 4.505552130427525, 4.537620521815371, 4.5694638635183455, 4.601086828130937, 4.632493928760188, 4.663689526544408, 4.694677837722201, 4.725462940284264, 4.756048780237647, 4.786439177509728, 4.8166378315169185, 4.846648326421054, 4.876474136094644, 4.906118628814432, 4.935585071701227, 4.964876634922565, 4.993996395673509, 5.022947341949744, 5.0517323761260355, 5.0803543183522155, 5.10881590977792, 5.137119815616529, 5.165268628057984, 5.193264869039514, 5.221110992882646, 5.2488093888042835, 5.276362383309168, 5.3037722424704485, 5.331041174104736, 5.358171329847527, 5.385164807134505, 5.412023651093924], [0.0, 0.5477225575051661, 0.7745966692414833, 0.9486832980505139, 1.0954451150103321, 1.2247448713915892, 1.3416407864998738, 1.4491376746189437, 1.5491933384829666, 1.6431676725154982, 1.7320508075688772, 1.816590212458495, 1.8973665961010278, 1.9748417658131499, 2.0493901531919194, 2.1213203435596424, 2.1908902300206643, 2.258317958127243, 2.32379000772445, 2.3874672772626644, 2.4494897427831783, 2.5099800796022267, 2.569046515733026, 2.6267851073127395, 2.6832815729997477, 2.7386127875258306, 2.792848008753788, 2.8460498941515415, 2.8982753492378874, 2.9495762407505253, 2.9999999999999996, 3.049590136395381, 3.098386676965933, 3.146426544510455, 3.1937438845342623, 3.2403703492039297, 3.2863353450309964, 3.331666249791536, 3.376388603226826, 3.420526275297414, 3.4641016151377544, 3.5071355833500366, 3.5496478698597698, 3.5916569992135936, 3.63318042491699, 3.674234614174767, 3.714835124201342, 3.7549966711037173, 3.7947331922020555, 3.8340579025361627, 3.872983346207417, 3.9115214431215892, 3.9496835316262997, 3.9874804074753776, 4.024922359499621, 4.06201920231798, 4.098780306383839, 4.135214625627066, 4.171330722922842, 4.207136793592525, 4.242640687119285, 4.277849927241487, 4.3127717305695645, 4.347413023856832, 4.381780460041329, 4.415880433163923, 4.449719092257397, 4.483302354291978, 4.516635916254486, 4.54972526643093, 4.58257569495584, 4.61519230368573, 4.6475800154489, 4.679743582719036, 4.711687595755898, 4.743416490252569, 4.774934554525329, 4.806245936279166, 4.83735464897913, 4.868264577855234, 4.898979485566357, 4.929503017546495, 4.959838707054898, 4.9899899799498595, 5.019960159204453, 5.049752469181039, 5.079370039680118, 5.10881590977792, 5.138093031466052, 5.167204273105525, 5.196152422706632, 5.224940191045253, 5.253570214625479, 5.282045058497703, 5.310367218940701, 5.338539126015655, 5.366563145999495, 5.394441583704471, 5.422176684690383, 5.449770637375485, 5.477225575051661, 5.504543577809154], [0.0, 0.5567764362830022, 0.7874007874011811, 0.9643650760992957, 1.1135528725660044, 1.2449899597988734, 1.3638181696985856, 1.4730919862656235, 1.5748015748023623, 1.6703293088490065, 1.760681686165901, 1.846618531261939, 1.9287301521985913, 2.0074859899884734, 2.083266665599966, 2.1563858652847823, 2.227105745132009, 2.2956480566497994, 2.3622023622035435, 2.4269322199023198, 2.489979919597747, 2.551470164434615, 2.6115129714401193, 2.670205984563738, 2.727636339397171, 2.783882181415011, 2.839013913315678, 2.8930952282978866, 2.946183972531247, 2.99833287011299, 3.049590136395381, 3.1, 3.1496031496047245, 3.1984371183438953, 3.2465366161495854, 3.2939338184001206, 3.340658617698013, 3.38673884437522, 3.432200460346103, 3.477067730142742, 3.521363372331802, 3.5651086939951777, 3.6083237105337433, 3.6510272527057364, 3.693237062523878, 3.7349698793966195, 3.7762415176998414, 3.817066936798463, 3.8574603043971827, 3.8974350539810154, 3.9370039370059056, 3.9761790704142093, 4.014971979976947, 4.053393639902249, 4.091454509095757, 4.129164564412516, 4.166533331199932, 4.20356991139674, 4.240283009422838, 4.276680956068619, 4.3127717305695645, 4.34856298103178, 4.384062043356595, 4.419275958796871, 4.454211490264018, 4.488875137492688, 4.523273151159456, 4.557411546042337, 4.591296113299599, 4.624932431938872, 4.658325879540847, 4.69148164229596, 4.724404724407087, 4.757099956906519, 4.789572005931219, 4.8218253804964775, 4.8538644398046396, 4.8856934001224435, 4.917316341257699, 4.948737212663449, 4.979959839195494, 5.01098792654702, 5.041825066382213, 5.072474741188959, 5.10294032886923, 5.13322510708424, 5.163332257370235, 5.193264869039514, 5.223025942880239, 5.252618394667558, 5.282045058497703, 5.3113086899558, 5.340411969127476, 5.36935750346352, 5.398147830506312, 5.426785420486054, 5.455272678794342, 5.483611948342078, 5.511805511808268, 5.539855593785817, 5.567764362830022, 5.595533933415113], [0.0, 0.565685424949238, 0.7999999999999999, 0.9797958971132713, 1.131370849898476, 1.2649110640673518, 1.3856406460551018, 1.4966629547095764, 1.5999999999999999, 1.697056274847714, 1.7888543819998317, 1.876166303929372, 1.9595917942265426, 2.039607805437114, 2.116601048851672, 2.1908902300206643, 2.262741699796952, 2.33238075793812, 2.4, 2.4657656011875906, 2.5298221281347035, 2.5922962793631443, 2.6532998322843198, 2.7129319932501073, 2.7712812921102037, 2.8284271247461903, 2.8844410203711917, 2.939387691339814, 2.993325909419153, 3.0463092423455636, 3.098386676965933, 3.1496031496047245, 3.1999999999999997, 3.249615361854384, 3.2984845004941286, 3.3466401061363023, 3.394112549695428, 3.4409301068170506, 3.487119154832539, 3.5327043465311387, 3.5777087639996634, 3.622154055254967, 3.6660605559646724, 3.709447398198281, 3.752332607858744, 3.7947331922020546, 3.8366652186501757, 3.878143885933063, 3.9191835884530852, 3.959797974644666, 4.0, 4.039801975344831, 4.079215610874228, 4.118252056394801, 4.156921938165306, 4.1952353926806065, 4.233202097703344, 4.2708313008125245, 4.308131845707603, 4.345112196480086, 4.381780460041329, 4.418144406874904, 4.454211490264017, 4.48998886412873, 4.525483399593904, 4.560701700396551, 4.595650117230423, 4.63033476111609, 4.66476151587624, 4.698936049788292, 4.732863826479693, 4.766550115125193, 4.8, 4.833218389437829, 4.866210024238575, 4.898979485566356, 4.931531202375181, 4.963869458396343, 4.995998398718719, 5.027922035990614, 5.059644256269407, 5.091168824543142, 5.122499389946279, 5.15363949069005, 5.184592558726289, 5.215361924162119, 5.2459508194416005, 5.276362383309167, 5.3065996645686395, 5.336665625650533, 5.366563145999495, 5.396295025292816, 5.4258639865002145, 5.455272678794342, 5.4845236803208355, 5.513619500836088, 5.542562584220407, 5.571355310873648, 5.6, 5.628498911788116, 5.656854249492381, 5.685068161420759], [0.0, 0.574456264653803, 0.812403840463596, 0.9949874371066202, 1.148912529307606, 1.2845232578665131, 1.4071247279470291, 1.5198684153570665, 1.624807680927192, 1.7233687939614086, 1.8165902124584952, 1.9052558883257653, 1.9899748742132404, 2.0712315177207983, 2.149418526020468, 2.224859546128699, 2.297825058615212, 2.3685438564654024, 2.4372115213907883, 2.503996805109783, 2.5690465157330262, 2.632489316217637, 2.6944387170614963, 2.754995462791183, 2.8142494558940583, 2.8722813232690148, 2.9291637031753623, 2.9849623113198605, 3.039736830714133, 3.0935416596516045, 3.146426544510455, 3.1984371183438953, 3.249615361854384, 3.3000000000000007, 3.3496268448888458, 3.398529093593286, 3.4467375879228173, 3.49428104193123, 3.541186241925155, 3.58747822293042, 3.6331804249169903, 3.678314831549905, 3.7229020937972575, 3.7669616403674726, 3.8105117766515306, 3.853569773599539, 3.896151947755632, 3.9382737335030438, 3.9799497484264807, 4.02119385257662, 4.06201920231798, 4.102438299353204, 4.1424630354415966, 4.182104733265298, 4.221374183841087, 4.260281680828159, 4.298837052040936, 4.337049688440288, 4.374928570845472, 4.412482294582042, 4.449719092257398, 4.486646854834912, 4.523273151159457, 4.559605246071199, 4.595650117230424, 4.631414470763764, 4.666904755831214, 4.702127178203499, 4.737087712930805, 4.77179211617606, 4.806245936279167, 4.8404545241123795, 4.874423042781577, 4.908156476723211, 4.941659640242335, 4.974937185533101, 5.007993610219566, 5.040833264451424, 5.07346035758633, 5.105878964487898, 5.1380930314660525, 5.170106381884226, 5.201922721455982, 5.23354564325181, 5.264978632435274, 5.296225070746145, 5.327288240746882, 5.358171329847526, 5.388877434122993, 5.419409561935692, 5.449770637375486, 5.479963503528103, 5.509990925582366, 5.539855593785817, 5.569560126257729, 5.599107071667768, 5.628498911788117, 5.657738063926256, 5.686826883245173, 5.715767664977296, 5.7445626465380295, 5.773214009544425], [0.0, 0.5830951894845301, 0.8246211251235321, 1.009950493836208, 1.1661903789690602, 1.30384048104053, 1.4282856857085702, 1.5427248620541514, 1.6492422502470643, 1.7492855684535902, 1.8439088914585775, 1.9339079605813718, 2.019900987672416, 2.102379604162864, 2.181742422927143, 2.258317958127243, 2.3323807579381204, 2.4041630560342617, 2.4738633753705965, 2.5416530054277673, 2.60768096208106, 2.672077843177478, 2.734958866235469, 2.7964262908219126, 2.8565713714171403, 2.9154759474226504, 2.973213749463701, 3.0298514815086235, 3.0854497241083028, 3.1400636936215167, 3.1937438845342623, 3.2465366161495854, 3.2984845004941286, 3.3496268448888458, 3.4000000000000004, 3.449637662132068, 3.4985711369071804, 3.54682957019364, 3.594440151122286, 3.6414282912066254, 3.687817782917155, 3.733630940518894, 3.7788887255382373, 3.823610858861032, 3.8678159211627436, 3.911521443121589, 3.954743986657038, 3.997499218261337, 4.039801975344832, 4.08166632639171, 4.123105625617661, 4.164132562731403, 4.204759208325728, 4.244997055358225, 4.28485705712571, 4.324349662087931, 4.363484845854286, 4.402272140611028, 4.440720662234904, 4.4788391353117385, 4.516635916254486, 4.5541190146942805, 4.591296113299598, 4.628174586162454, 4.664761515876241, 4.701063709417263, 4.737087712930805, 4.77283982551269, 4.8083261120685235, 4.843552415324934, 4.878524367060187, 4.913247398615299, 4.947726750741193, 4.98196748283246, 5.015974481593781, 5.049752469181039, 5.083306010855535, 5.1166395221864125, 5.149757275833494, 5.182663407939976, 5.21536192416212, 5.247856705360771, 5.280151512977635, 5.31224999411737, 5.344155686354956, 5.375872022286245, 5.40740233383831, 5.4387498563548595, 5.469917732470938, 5.500909015790026, 5.531726674375733, 5.562373594069352, 5.592852581643825, 5.62316636780382, 5.653317610041029, 5.683308895353129, 5.713142742834281, 5.742821606144492, 5.772347875864725, 5.801723881744115, 5.830951894845301, 5.860034129593445], [0.0, 0.5916079783099616, 0.8366600265340756, 1.02469507659596, 1.1832159566199232, 1.3228756555322954, 1.449137674618944, 1.5652475842498528, 1.6733200530681511, 1.7748239349298847, 1.8708286933869707, 1.9621416870348585, 2.04939015319192, 2.1330729007701543, 2.2135943621178655, 2.29128784747792, 2.3664319132398464, 2.4392621835300936, 2.5099800796022267, 2.5787593916455256, 2.6457513110645907, 2.711088342345192, 2.7748873851023217, 2.8372521918222215, 2.898275349237888, 2.958039891549808, 3.0166206257996713, 3.0740852297878796, 3.1304951684997055, 3.1859064644147983, 3.2403703492039297, 3.2939338184001206, 3.3466401061363023, 3.398529093593286, 3.449637662132068, 3.5, 3.5496478698597693, 3.5986108430893164, 3.646916505762094, 3.6945906403822333, 3.7416573867739413, 3.7881393849751626, 3.834057902536163, 3.879432948254164, 3.924283374069717, 3.9686269665968856, 4.012480529547776, 4.05585995813465, 4.09878030638384, 4.141255848169731, 4.183300132670378, 4.224926034855522, 4.266145801540309, 4.306971093471606, 4.347413023856832, 4.387482193696061, 4.427188724235731, 4.466542286825459, 4.505552130427525, 4.544227107000705, 4.58257569495584, 4.620606020859168, 4.658325879540846, 4.695742752749559, 4.732863826479693, 4.769696007084728, 4.806245936279166, 4.8425200051213, 4.878524367060187, 4.914264950122246, 4.949747468305833, 4.984977432245807, 5.019960159204453, 5.054700782440045, 5.089204259999788, 5.123475382979799, 5.157518783291051, 5.191338940966964, 5.2249401910452535, 5.2583267300539625, 5.291502622129181, 5.324471804789654, 5.35723809439155, 5.389805191284746, 5.422176684690384, 5.454356057317858, 5.486346689738081, 5.518151864528558, 5.549774770204643, 5.58121850495033, 5.612486080160912, 5.643580423808984, 5.674504383644443, 5.705260730238365, 5.735852159879995, 5.766281297335397, 5.796550698475776, 5.826662852782887, 5.856620185738529, 5.886425061104576, 5.916079783099616, 5.9455865984779], [0.0, 0.6, 0.848528137423857, 1.0392304845413265, 1.2, 1.3416407864998738, 1.469693845669907, 1.5874507866387544, 1.697056274847714, 1.7999999999999998, 1.8973665961010275, 1.98997487421324, 2.078460969082653, 2.1633307652783937, 2.244994432064365, 2.3237900077244498, 2.4, 2.473863375370596, 2.545584412271571, 2.615339366124404, 2.6832815729997477, 2.749545416973504, 2.814249455894058, 2.877498913987632, 2.939387691339814, 3.0, 3.059411708155671, 3.117691453623979, 3.1749015732775088, 3.2310988842807027, 3.2863353450309964, 3.340658617698013, 3.394112549695428, 3.4467375879228173, 3.4985711369071804, 3.5496478698597693, 3.5999999999999996, 3.6496575181789317, 3.698648401781386, 3.746998799039039, 3.794733192202055, 3.8418745424597094, 3.8884444190447165, 3.9344631145812, 3.97994974842648, 4.024922359499621, 4.069397989875161, 4.113392760240626, 4.156921938165306, 4.2, 4.242640687119285, 4.28485705712571, 4.3266615305567875, 4.368065933568311, 4.409081537009721, 4.449719092257398, 4.48998886412873, 4.52990066116245, 4.569463863518345, 4.608687448721165, 4.6475800154488995, 4.686149805543993, 4.724404724407086, 4.762352359916263, 4.8, 4.8373546489791295, 4.874423042781576, 4.91121166312347, 4.947726750741192, 4.983974317750845, 5.019960159204453, 5.0556898639058145, 5.091168824543142, 5.126402247190518, 5.161395160225576, 5.196152422706632, 5.230678732248808, 5.264978632435273, 5.299056519796709, 5.332916650389353, 5.366563145999495, 5.4, 5.43323108288245, 5.466260147486579, 5.499090833947008, 5.531726674375732, 5.5641710972974225, 5.596427431853289, 5.628498911788116, 5.660388679233962, 5.692099788303082, 5.7236352085016735, 5.754997827975264, 5.786190456595773, 5.817215828899595, 5.848076606885377, 5.878775382679628, 5.909314681077663, 5.939696961966999, 5.96992462263972, 6.0, 6.029925372672535], [0.0, 0.608276253029822, 0.8602325267042626, 1.053565375285274, 1.216552506059644, 1.3601470508735445, 1.489966442575134, 1.6093476939431082, 1.7204650534085253, 1.8248287590894658, 1.9235384061671346, 2.017424100183202, 2.107130750570548, 2.193171219946131, 2.2759613353482084, 2.355843797877949, 2.433105012119288, 2.5079872407968904, 2.5806975801127883, 2.651414716712571, 2.720294101747089, 2.787471972953271, 2.8530685235374214, 2.917190429162965, 2.979932885150268, 3.04138126514911, 3.101612483854165, 3.160696125855822, 3.2186953878862163, 3.2756678708318403, 3.331666249791536, 3.38673884437522, 3.4409301068170506, 3.49428104193123, 3.54682957019364, 3.5986108430893164, 3.6496575181789317, 3.7, 3.7496666518505353, 3.7986839826445165, 3.847076812334269, 3.89486841883009, 3.942080668885405, 3.988734135035826, 4.034848200366404, 4.080441152620633, 4.125530268947254, 4.170131892398609, 4.214261501141096, 4.257933771208754, 4.301162633521314, 4.343961325794695, 4.386342439892262, 4.428317965096906, 4.469899327725402, 4.511097427455985, 4.551922670696417, 4.592385001282014, 4.632493928760188, 4.672258554489466, 4.711687595755898, 4.750789408087881, 4.789572005931219, 4.828043081829325, 4.866210024238576, 4.904079934095691, 4.941659640242335, 4.978955713801841, 5.015974481593781, 5.052722038663912, 5.089204259999789, 5.1254268114957995, 5.1613951602255765, 5.197114584074513, 5.232590180780452, 5.26782687642637, 5.302829433425142, 5.3376024580330075, 5.372150407425318, 5.406477596365309, 5.440588203494178, 5.474486277268398, 5.508175741568166, 5.541660400998964, 5.574943945906542, 5.608029957123981, 5.640921910468182, 5.673623181001714, 5.706137047074843, 5.7384666941614295, 5.770615218501404, 5.8025856305616035, 5.83438085832593, 5.866003750424986, 5.897457079114693, 5.928743543112655, 5.959865770300536, 5.990826320300065, 6.021627686929839, 6.052272300549605, 6.08276253029822, 6.113100686231171], [0.0, 0.6164414002968976, 0.8717797887081348, 1.0677078252031313, 1.2328828005937953, 1.3784048752090223, 1.50996688705415, 1.6309506430300091, 1.7435595774162695, 1.849324200890693, 1.949358868961793, 2.0445048300260877, 2.1354156504062627, 2.222611077089287, 2.3065125189341593, 2.3874672772626644, 2.4657656011875906, 2.541653005427767, 2.615339366124404, 2.687005768508881, 2.7568097504180447, 2.824889378365107, 2.891366458960192, 2.956349099818897, 3.0199337741083, 3.0822070014844885, 3.1432467291003428, 3.203123475609394, 3.2619012860600183, 3.3196385345395667, 3.376388603226826, 3.432200460346103, 3.487119154832539, 3.541186241925155, 3.594440151122286, 3.646916505762094, 3.698648401781386, 3.7496666518505353, 3.8000000000000003, 3.8496753109840323, 3.898717737923586, 3.9471508711981107, 3.9949968710876362, 4.042276586281547, 4.0890096600521755, 4.135214625627066, 4.180908992073375, 4.226109321823088, 4.270831300812525, 4.315089802078284, 4.358898943540674, 4.402272140611029, 4.445222154178574, 4.487761134463376, 4.529900661162451, 4.571651780264984, 4.613025037868319, 4.654030511288038, 4.694677837722201, 4.734976240700686, 4.774934554525329, 4.814561246884289, 4.853864439804639, 4.892851929090027, 4.931531202375181, 4.969909455915671, 5.007993610219566, 5.045790324617146, 5.083306010855534, 5.120546845796843, 5.157518783291051, 5.194227565288221, 5.230678732248808, 5.266877632905477, 5.302829433425141, 5.338539126015656, 5.374011537017762, 5.409251334519409, 5.444263035526481, 5.47905101272109, 5.513619500836089, 5.547972602672079, 5.582114294781146, 5.616048432839589, 5.649778756730214, 5.68330889535313, 5.716642371182581, 5.749782604586021, 5.782732917920384, 5.815496539419485, 5.848076606885378, 5.880476171195663, 5.912698199637794, 5.944745579080741, 5.976621118993575, 6.008327554319921, 6.0398675482166, 6.071243694664217, 6.102458520956943, 6.133514490078262, 6.164414002968977, 6.1951594006934165], [0.0, 0.6244997998398399, 0.8831760866327847, 1.081665382639197, 1.2489995996796799, 1.3964240043768943, 1.5297058540778357, 1.6522711641858308, 1.7663521732655694, 1.8734993995195195, 1.97484176581315, 2.0712315177207983, 2.163330765278394, 2.2516660498395407, 2.3366642891095846, 2.4186773244895647, 2.4979991993593598, 2.574878637916747, 2.6495282598983545, 2.7221315177632404, 2.7928480087537886, 2.861817604250837, 2.9291637031753623, 2.994995826374388, 3.0594117081556713, 3.1224989991991996, 3.1843366656181322, 3.244996147917591, 3.3045423283716615, 3.363034344160048, 3.420526275297414, 3.477067730142742, 3.5327043465311387, 3.58747822293042, 3.6414282912066254, 3.6945906403822333, 3.746998799039039, 3.7986839826445165, 3.8496753109840323, 3.900000000000001, 3.9496835316263, 3.9987498046264416, 4.047221268969613, 4.095119045888654, 4.1424630354415966, 4.189272013130682, 4.235563716909475, 4.281354925721529, 4.326661530556788, 4.371498598878879, 4.415880433163924, 4.459820624195553, 4.503332099679081, 4.546427168667723, 4.589117562233507, 4.631414470763765, 4.673328578219169, 4.7148700936505135, 4.756048780237647, 4.796873982084583, 4.8373546489791295, 4.87749935930288, 4.917316341257699, 4.956813492557492, 4.9959983987187195, 5.034878350069642, 5.073460357586329, 5.111751167652823, 5.149757275833494, 5.187484939737176, 5.2249401910452535, 5.262128846769148, 5.299056519796709, 5.335728628781641, 5.372150407425317, 5.408326913195984, 5.444263035526481, 5.479963503528103, 5.515432893255072, 5.550675634551168, 5.585696017507577, 5.620498198558559, 5.655086206239478, 5.68946394662977, 5.723635208501674, 5.757603668193913, 5.791372894228104, 5.8249463516842805, 5.858327406350725, 5.8915193286621745, 5.92452529743945, 5.957348403442593, 5.989991652748776, 6.02245796996542, 6.054750201288242, 6.08687111741328, 6.118823416311343, 6.150609725872713, 6.182232606429493, 6.213694553162394, 6.244997998398399, 6.276145313805283], [0.0, 0.6324555320336759, 0.8944271909999159, 1.0954451150103324, 1.2649110640673518, 1.4142135623730951, 1.5491933384829668, 1.6733200530681511, 1.7888543819998317, 1.8973665961010275, 2.0, 2.0976176963403033, 2.1908902300206647, 2.280350850198276, 2.3664319132398464, 2.449489742783178, 2.5298221281347035, 2.6076809620810595, 2.6832815729997477, 2.7568097504180447, 2.8284271247461903, 2.898275349237888, 2.9664793948382653, 3.0331501776206204, 3.0983866769659336, 3.1622776601683795, 3.22490309931942, 3.286335345030997, 3.3466401061363023, 3.4058772731852804, 3.4641016151377544, 3.521363372331802, 3.5777087639996634, 3.6331804249169903, 3.687817782917155, 3.7416573867739413, 3.794733192202055, 3.847076812334269, 3.898717737923586, 3.9496835316263, 4.0, 4.049691346263318, 4.09878030638384, 4.147288270665544, 4.1952353926806065, 4.242640687119285, 4.2895221179054435, 4.33589667773576, 4.3817804600413295, 4.427188724235731, 4.47213595499958, 4.5166359162544865, 4.560701700396552, 4.604345773288536, 4.6475800154489, 4.69041575982343, 4.732863826479693, 4.774934554525329, 4.8166378315169185, 4.857983120596447, 4.898979485566356, 4.9396356140913875, 4.979959839195493, 5.019960159204453, 5.059644256269407, 5.0990195135927845, 5.138093031466052, 5.176871642217914, 5.215361924162119, 5.253570214625479, 5.291502622129181, 5.329165037789691, 5.366563145999495, 5.403702434442518, 5.440588203494177, 5.477225575051661, 5.513619500836089, 5.549774770204643, 5.585696017507577, 5.621387729022079, 5.656854249492381, 5.692099788303083, 5.727128425310542, 5.761944116355173, 5.796550698475776, 5.830951894845301, 5.865151319446072, 5.8991524815010505, 5.932958789676531, 5.966573556070519, 6.0, 6.0332412515993425, 6.066300355241241, 6.099180272790763, 6.131883886702357, 6.164414002968976, 6.196773353931867, 6.228964600958975, 6.260990336999411, 6.29285308902091, 6.324555320336759, 6.356099432828282], [0.0, 0.6403124237432849, 0.9055385138137417, 1.1090536506409419, 1.2806248474865698, 1.4317821063276355, 1.5684387141358125, 1.6941074346097418, 1.8110770276274835, 1.9209372712298547, 2.024845673131659, 2.1236760581595306, 2.2181073012818837, 2.3086792761230397, 2.395829710142188, 2.479919353527449, 2.5612496949731396, 2.6400757564888173, 2.716615541441225, 2.791057147390573, 2.863564212655271, 2.934280150224242, 3.0033314835362415, 3.0708305065568178, 3.136877428271625, 3.2015621187164247, 3.264965543462902, 3.3271609519228256, 3.3882148692194836, 3.448187929913334, 3.5071355833500366, 3.5651086939951777, 3.622154055254967, 3.678314831549905, 3.733630940518894, 3.7881393849751626, 3.8418745424597094, 3.89486841883009, 3.9471508711981107, 3.9987498046264416, 4.049691346263318, 4.1000000000000005, 4.149698784249287, 4.198809355043403, 4.247352116319061, 4.295346318982906, 4.342810150121693, 4.389760813529594, 4.436214602563767, 4.4821869662029945, 4.527692569068709, 4.572745346069471, 4.617358552246079, 4.661544808322667, 4.705316142407437, 4.748684028233507, 4.791659420284376, 4.8342527861087286, 4.876474136094644, 4.9183330509431755, 4.959838707054898, 5.000999900019996, 5.041825066382213, 5.082322303829225, 5.122499389946279, 5.162363799656123, 5.201922721455982, 5.241183072551464, 5.280151512977635, 5.3188344587888805, 5.35723809439155, 5.395368384086485, 5.43323108288245, 5.470831746635972, 5.508175741568165, 5.545268253204709, 5.582114294781146, 5.61871871515206, 5.655086206239478, 5.691221310052879, 5.727128425310542, 5.762811813689565, 5.798275605729691, 5.833523806414096, 5.868560300448484, 5.903388857258177, 5.93801313572141, 5.9724366886556455, 6.006662967072483, 6.040695324215583, 6.074537019394977, 6.1081912216301815, 6.1416610131136355, 6.174949392505174, 6.208059278067504, 6.24099351065197, 6.27375485654325, 6.306346010171025, 6.338769596696192, 6.3710281744785915, 6.403124237432849, 6.435060217278469], [0.0, 0.6480740698407861, 0.9165151389911681, 1.1224972160321827, 1.2961481396815722, 1.4491376746189442, 1.5874507866387546, 1.7146428199482249, 1.8330302779823362, 1.9442222095223582, 2.04939015319192, 2.149418526020468, 2.2449944320643653, 2.336664289109585, 2.4248711305964283, 2.5099800796022267, 2.5922962793631443, 2.672077843177478, 2.749545416973504, 2.8248893783651075, 2.8982753492378883, 2.9698484809835, 3.039736830714133, 3.108054053584011, 3.174901573277509, 3.2403703492039306, 3.304542328371662, 3.3674916480965478, 3.4292856398964497, 3.48998567332303, 3.5496478698597698, 3.6083237105337433, 3.6660605559646724, 3.7229020937972575, 3.7788887255382373, 3.834057902536163, 3.8884444190447165, 3.942080668885405, 3.9949968710876362, 4.047221268969613, 4.09878030638384, 4.149698784249287, 4.200000000000001, 4.249705872175156, 4.298837052040936, 4.347413023856832, 4.3954521951671826, 4.442971978304612, 4.489988864128731, 4.536518488885503, 4.582575694955841, 4.628174586162455, 4.67332857821917, 4.718050444834181, 4.762352359916264, 4.806245936279167, 4.849742261192857, 4.892851929090027, 4.935585071701227, 4.9779513858614575, 5.019960159204453, 5.061620293937506, 5.10294032886923, 5.143928459844674, 5.184592558726289, 5.224940191045253, 5.264978632435274, 5.304714883949938, 5.344155686354956, 5.383307533477909, 5.422176684690385, 5.46076917659042, 5.499090833947008, 5.537147279962851, 5.574943945906542, 5.612486080160912, 5.649778756730215, 5.686826883245173, 5.723635208501675, 5.760208329565868, 5.796550698475777, 5.832666628567075, 5.868560300448485, 5.904235767650205, 5.939696961967, 5.974947698515863, 6.009991680526689, 6.044832503882966, 6.079473661428266, 6.113918547053109, 6.148170459575759, 6.182232606429493, 6.216108107168022, 6.249799996799899, 6.283311228962004, 6.316644678941503, 6.349803146555018, 6.38278935889318, 6.4156059729381765, 6.448255578061405, 6.480740698407861, 6.5130637951735135], [0.0, 0.6557438524302001, 0.9273618495495702, 1.1357816691600549, 1.3114877048604001, 1.466287829861518, 1.606237840420901, 1.7349351572897471, 1.8547236990991405, 1.9672315572906, 2.073644135332772, 2.1748563170931545, 2.2715633383201097, 2.364318083507378, 2.453568829277059, 2.5396850198400585, 2.6229754097208002, 2.7037011669191546, 2.782085548648711, 2.8583211855912904, 2.932575659723036, 3.004995840263344, 3.0757112998459397, 3.1448370387032774, 3.212475680841802, 3.278719262151, 3.3436506994600976, 3.407345007480164, 3.4698703145794942, 3.531288716601915, 3.5916569992135936, 3.6510272527057364, 3.709447398198281, 3.7669616403674726, 3.823610858861032, 3.879432948254164, 3.9344631145812, 3.988734135035826, 4.042276586281547, 4.095119045888654, 4.147288270665544, 4.198809355043403, 4.249705872175156, 4.299999999999999, 4.349712634186309, 4.398863489584553, 4.447471191587417, 4.495553358597804, 4.543126676640219, 4.5902069670114, 4.636809247747852, 4.682947789587239, 4.728636167014756, 4.773887304912004, 4.818713521262703, 4.863126566315131, 4.907137658554118, 4.950757517794625, 4.993996395673509, 5.03686410378521, 5.079370039680117, 5.121523210920751, 5.163332257370234, 5.204805471869242, 5.2459508194416005, 5.28677595515452, 5.3272882407468805, 5.367494760127856, 5.407402333838309, 5.447017532558529, 5.486346689738081, 5.525395913416522, 5.564171097297422, 5.602677931132575, 5.6409219104681805, 5.678908345800274, 5.716642371182581, 5.754128952326321, 5.791372894228104, 5.8283788483591215, 5.865151319446072, 5.9016946718718, 5.938013135721409, 5.974110812497538, 6.009991680526688, 6.0456596000767355, 6.081118318204308, 6.1163714733492105, 6.151422599691879, 6.186275131288617, 6.220932405998315, 6.255397669213365, 6.289674077406555, 6.323764701504951, 6.357672530100933, 6.3914004725099165, 6.424951361683604, 6.458327956987009, 6.491532946846992, 6.524568951279464, 6.557438524302, 6.590144156238162], [0.0, 0.66332495807108, 0.938083151964686, 1.148912529307606, 1.32664991614216, 1.4832396974191329, 1.6248076809271923, 1.7549928774784245, 1.876166303929372, 1.98997487421324, 2.0976176963403033, 2.2, 2.297825058615212, 2.3916521486202797, 2.4819347291981715, 2.569046515733026, 2.65329983228432, 2.734958866235469, 2.814249455894058, 2.8913664589601926, 2.9664793948382657, 3.039736830714133, 3.1112698372208096, 3.1811947441173736, 3.2496153618543846, 3.3166247903554003, 3.382306905057553, 3.4467375879228177, 3.509985754956849, 3.5721142198983507, 3.63318042491699, 3.693237062523878, 3.752332607858744, 3.8105117766515306, 3.8678159211627436, 3.924283374069717, 3.97994974842648, 4.034848200366404, 4.0890096600521755, 4.1424630354415966, 4.1952353926806065, 4.247352116319061, 4.298837052040936, 4.349712634186309, 4.4, 4.449719092257398, 4.498888751680798, 4.54752680036083, 4.595650117230424, 4.64327470649756, 4.69041575982343, 4.737087712930806, 4.7833042972405595, 4.829078587059855, 4.874423042781577, 4.919349550499538, 4.963869458396343, 5.007993610219566, 5.051732376126036, 5.095095681142799, 5.138093031466052, 5.180733538795447, 5.223025942880239, 5.264978632435274, 5.30659966456864, 5.347896782848375, 5.388877434122993, 5.429548784199292, 5.469917732470938, 5.509990925582365, 5.549774770204644, 5.589275444992849, 5.628498911788116, 5.667450926121902, 5.706137047074843, 5.7445626465380295, 5.782732917920385, 5.8206528843421, 5.858327406350725, 5.895761189193471, 5.9329587896765315, 5.969924622639721, 6.006662967072484, 6.043177971895251, 6.079473661428266, 6.115553940568263, 6.15142259969188, 6.187083319303208, 6.222539674441619, 6.2577951388648065, 6.29285308902091, 6.327716807822551, 6.362389488234747, 6.3968742366877915, 6.431174076325411, 6.465291950097845, 6.499230723708769, 6.532993188424431, 6.566582063752802, 6.600000000000001, 6.6332495807108005, 6.666333324999584], [0.0, 0.6708203932499369, 0.9486832980505137, 1.161895003862225, 1.3416407864998738, 1.5, 1.6431676725154982, 1.7748239349298847, 1.8973665961010273, 2.0124611797498106, 2.1213203435596424, 2.224859546128699, 2.32379000772445, 2.4186773244895647, 2.5099800796022262, 2.5980762113533156, 2.6832815729997477, 2.765863337187866, 2.846049894151541, 2.924038303442689, 3.0, 3.0740852297878796, 3.1464265445104544, 3.2171415884290826, 3.2863353450309964, 3.3541019662496843, 3.420526275297414, 3.4856850115866753, 3.5496478698597693, 3.6124783736376886, 3.674234614174767, 3.7349698793966195, 3.7947331922020546, 3.853569773599539, 3.911521443121589, 3.9686269665968856, 4.024922359499621, 4.080441152620633, 4.135214625627066, 4.189272013130682, 4.242640687119285, 4.295346318982906, 4.347413023856832, 4.398863489584553, 4.449719092257398, 4.499999999999999, 4.54972526643093, 4.598912915026768, 4.6475800154489, 4.695742752749558, 4.743416490252569, 4.790615826801393, 4.8373546489791295, 4.883646178829912, 4.9295030175464944, 4.9749371855331, 5.0199601592044525, 5.064582904840239, 5.10881590977792, 5.1526692111953, 5.196152422706631, 5.239274758971893, 5.282045058497702, 5.324471804789654, 5.366563145999495, 5.4083269131959835, 5.449770637375485, 5.490901565316937, 5.531726674375732, 5.572252686302012, 5.612486080160912, 5.652433104425031, 5.692099788303082, 5.731491952362839, 5.770615218501403, 5.809475019311125, 5.848076606885378, 5.886425061104575, 5.92452529743945, 5.962382074305537, 6.0, 6.037383539249432, 6.074537019394977, 6.111464636239008, 6.148170459575759, 6.18465843842649, 6.220932405998316, 6.256996084384263, 6.292853089020909, 6.328506932918695, 6.363961030678928, 6.399218702310462, 6.434283176858165, 6.469157595854347, 6.5038450166036395, 6.53834841531101, 6.572670690061993, 6.606814663663572, 6.640783086353596, 6.674578638386096, 6.7082039324993685, 6.74166151627327], [0.0, 0.6782329983125268, 0.9591663046625439, 1.1747340124470733, 1.3564659966250536, 1.5165750888103102, 1.661324772583615, 1.7944358444926363, 1.9183326093250879, 2.0346989949375804, 2.1447610589527217, 2.249444375840399, 2.3494680248941466, 2.445403852127497, 2.5377155080899043, 2.626785107312739, 2.7129319932501073, 2.7964262908219126, 2.877498913987632, 2.956349099818897, 3.0331501776206204, 3.108054053584011, 3.1811947441173736, 3.252691193458119, 3.32264954516723, 3.3911649915626345, 3.458323293158117, 3.5242020373412197, 3.5888716889852725, 3.6523964735499352, 3.714835124201342, 3.7762415176998414, 3.8366652186501757, 3.896151947755632, 3.954743986657038, 4.012480529547776, 4.069397989875161, 4.125530268947254, 4.180908992073375, 4.235563716909475, 4.2895221179054435, 4.342810150121693, 4.3954521951671826, 4.447471191587417, 4.498888751680798, 4.54972526643093, 4.6000000000000005, 4.649731175025068, 4.698936049788293, 4.747630988187688, 4.79583152331272, 4.843552415324934, 4.890807704254994, 4.937610758251404, 4.983974317750845, 5.029910535983717, 5.075431016179809, 5.120546845796843, 5.165268628057984, 5.209606511052442, 5.253570214625478, 5.297169055259611, 5.340411969127476, 5.383307533477908, 5.4258639865002145, 5.468089245796926, 5.509990925582365, 5.551576352712804, 5.592852581643825, 5.63382640840131, 5.674504383644443, 5.71489282489182, 5.754997827975264, 5.794825277780168, 5.834380858325929, 5.873670062235366, 5.912698199637794, 5.951470406546605, 5.989991652748776, 6.028266749240615, 6.066300355241241, 6.104096984812742, 6.1416610131136355, 6.178996682310163, 6.216108107168022, 6.252999280345393, 6.289674077406556, 6.326136261573884, 6.362389488234747, 6.398437309218556, 6.434283176858165, 6.469930447848725, 6.505382386916238, 6.540642170307134, 6.57571288910944, 6.6105975524153635, 6.64529909033446, 6.679820356865895, 6.714164132637808, 6.748333127521196, 6.782329983125269, 6.81615727518079], [0.0, 0.6855654600401044, 0.9695359714832658, 1.187434208703792, 1.3711309200802089, 1.5329709716755893, 1.6792855623746665, 1.8138357147217055, 1.9390719429665315, 2.056696380120313, 2.16794833886788, 2.273763400180415, 2.374868417407584, 2.471841418861655, 2.565151067676132, 2.6551836094703507, 2.7422618401604177, 2.826658805020514, 2.9086079144497976, 2.9883105594967874, 3.0659419433511785, 3.1416556144810017, 3.2155870381627056, 3.2878564445547194, 3.358571124749333, 3.4278273002005224, 3.4957116585897072, 3.5623026261113755, 3.627671429443411, 3.691882988394947, 3.7549966711037173, 3.817066936798463, 3.878143885933063, 3.9382737335030438, 3.997499218261337, 4.05585995813465, 4.113392760240626, 4.170131892398609, 4.226109321823088, 4.281354925721529, 4.33589667773576, 4.389760813529594, 4.442971978304612, 4.495553358597804, 4.54752680036083, 4.598912915026768, 4.649731175025068, 4.7, 4.749736834815168, 4.798958220280731, 4.847679857416329, 4.89591666595746, 4.94368283772331, 4.990991885387113, 5.037856687124, 5.084289527554465, 5.130302135352264, 5.175905717843014, 5.221110992882646, 5.265928218272634, 5.310367218940701, 5.354437412091022, 5.3981478305063115, 5.441507144165117, 5.4845236803208355, 5.527205442174191, 5.569560126257728, 5.61159513863928, 5.653317610041028, 5.69473440996154, 5.735852159879995, 5.776677245614472, 5.817215828899595, 5.857473858242988, 5.897457079114692, 5.937171043518958, 5.976621118993575, 6.015812497078014, 6.054750201288242, 6.09343909463285, 6.131883886702357, 6.17008914036094, 6.208059278067503, 6.245798587850876, 6.2833112289620034, 6.320601237224193, 6.357672530100934, 6.394528911499267, 6.431174076325411, 6.4676116148080505, 6.5038450166036395, 6.539877674696982, 6.575712889109439, 6.611353870426239, 6.646803743153547, 6.682065548915245, 6.717142249498666, 6.7520367297579185, 6.786751800382861, 6.821290200541244, 6.855654600401045, 6.889847603539574], [0.0, 0.692820323027551, 0.9797958971132713, 1.2000000000000004, 1.385640646055102, 1.549193338482967, 1.6970562748477143, 1.8330302779823362, 1.9595917942265426, 2.078460969082653, 2.1908902300206647, 2.297825058615212, 2.400000000000001, 2.4979991993593598, 2.5922962793631443, 2.6832815729997477, 2.771281292110204, 2.8565713714171403, 2.9393876913398143, 3.0199337741083006, 3.098386676965934, 3.174901573277509, 3.2496153618543846, 3.3226495451672307, 3.3941125496954285, 3.4641016151377553, 3.5327043465311396, 3.6000000000000005, 3.6660605559646724, 3.7309516212355267, 3.7947331922020555, 3.8574603043971827, 3.9191835884530852, 3.9799497484264807, 4.039801975344832, 4.09878030638384, 4.156921938165306, 4.214261501141096, 4.270831300812525, 4.326661530556788, 4.3817804600413295, 4.436214602563767, 4.489988864128731, 4.543126676640219, 4.595650117230424, 4.6475800154489, 4.698936049788293, 4.749736834815168, 4.800000000000002, 4.849742261192857, 4.898979485566357, 4.947726750741194, 4.9959983987187195, 5.043808085167398, 5.091168824543143, 5.1380930314660525, 5.184592558726289, 5.230678732248809, 5.276362383309169, 5.321653878260029, 5.366563145999495, 5.411099703387474, 5.455272678794342, 5.499090833947009, 5.542562584220408, 5.585696017507577, 5.628498911788117, 5.670978751503131, 5.713142742834281, 5.754997827975265, 5.796550698475777, 5.83780780773057, 5.8787753826796285, 5.9194594347794975, 5.959865770300536, 6.000000000000001, 6.039867548216601, 6.079473661428266, 6.1188234163113435, 6.157921727336262, 6.196773353931868, 6.235382907247959, 6.27375485654325, 6.311893535223801, 6.349803146555018, 6.387487769068526, 6.424951361683605, 6.462197768561406, 6.499230723708769, 6.536053855347277, 6.572670690061994, 6.609084656743323, 6.645299090334461, 6.681317235396028, 6.717142249498667, 6.752777206453653, 6.788225099390857, 6.823488843692794, 6.8585712797928995, 6.893475175845635, 6.9282032302755105, 6.962758074211686], [0.0, 0.7000000000000001, 0.9899494936611665, 1.2124355652982142, 1.4000000000000001, 1.565247584249853, 1.7146428199482247, 1.8520259177452134, 1.979898987322333, 2.1, 2.2135943621178655, 2.32163735324878, 2.4248711305964283, 2.5238858928247927, 2.619160170741759, 2.7110883423451915, 2.8000000000000003, 2.8861739379323623, 2.9698484809834995, 3.051229260478472, 3.130495168499706, 3.2078029864690882, 3.283291031876401, 3.357082066318904, 3.4292856398964493, 3.5, 3.5693136595149495, 3.6373066958946425, 3.704051835490427, 3.769615364994153, 3.8340579025361627, 3.8974350539810154, 3.959797974644666, 4.02119385257662, 4.08166632639171, 4.141255848169731, 4.2, 4.257933771208754, 4.315089802078284, 4.371498598878879, 4.427188724235731, 4.4821869662029945, 4.536518488885503, 4.5902069670114, 4.64327470649756, 4.695742752749558, 4.747630988187688, 4.798958220280731, 4.849742261192857, 4.9, 4.949747468305833, 4.998999899979996, 5.047771785649585, 5.096076922496363, 5.143928459844674, 5.191338940966964, 5.238320341483518, 5.2848841046895245, 5.331041174104736, 5.376802023508025, 5.422176684690383, 5.467174773134658, 5.511805511808268, 5.55607775323564, 5.6000000000000005, 5.643580423808984, 5.686826883245172, 5.729746940310715, 5.772347875864725, 5.814636704042653, 5.856620185738529, 5.898304841223451, 5.939696961966999, 5.980802621722272, 6.021627686929839, 6.06217782649107, 6.102458520956944, 6.142475071174486, 6.182232606429493, 6.221736092120913, 6.260990336999412, 6.300000000000001, 6.338769596696192, 6.377303505401009, 6.4156059729381765, 6.4536811201050215, 6.491532946846993, 6.529165337162171, 6.566582063752802, 6.603786792439623, 6.640783086353597, 6.67757440991862, 6.714164132637808, 6.750555532695069, 6.786751800382861, 6.822756041366274, 6.858571279792899, 6.894200461257274, 6.929646455628165, 6.96491205974634, 7.0, 7.034912934784624], [0.0, 0.7071067811865476, 1.0, 1.2247448713915892, 1.4142135623730951, 1.5811388300841898, 1.7320508075688774, 1.8708286933869709, 2.0, 2.1213203435596424, 2.23606797749979, 2.345207879911715, 2.4494897427831783, 2.5495097567963927, 2.6457513110645907, 2.7386127875258306, 2.8284271247461903, 2.9154759474226504, 3.0, 3.082207001484489, 3.1622776601683795, 3.2403703492039306, 3.3166247903554003, 3.3911649915626345, 3.464101615137755, 3.535533905932738, 3.6055512754639896, 3.6742346141747677, 3.7416573867739418, 3.8078865529319548, 3.872983346207417, 3.9370039370059056, 4.0, 4.06201920231798, 4.123105625617661, 4.183300132670378, 4.242640687119285, 4.301162633521314, 4.358898943540674, 4.415880433163924, 4.47213595499958, 4.527692569068709, 4.582575694955841, 4.636809247747852, 4.69041575982343, 4.743416490252569, 4.79583152331272, 4.847679857416329, 4.898979485566357, 4.949747468305833, 5.000000000000001, 5.04975246918104, 5.099019513592785, 5.147815070493501, 5.196152422706632, 5.244044240850759, 5.291502622129181, 5.338539126015656, 5.385164807134505, 5.431390245600108, 5.477225575051661, 5.522680508593631, 5.5677643628300215, 5.612486080160912, 5.656854249492381, 5.70087712549569, 5.744562646538029, 5.787918451395113, 5.830951894845301, 5.873670062235366, 5.916079783099617, 5.958187643906493, 6.0, 6.041522986797286, 6.082762530298219, 6.123724356957946, 6.164414002968978, 6.2048368229954285, 6.244997998398399, 6.284902544988268, 6.324555320336759, 6.3639610306789285, 6.403124237432849, 6.442049363362563, 6.480740698407861, 6.519202405202649, 6.557438524302001, 6.59545297913646, 6.6332495807108005, 6.670832032063167, 6.708203932499369, 6.745368781616021, 6.782329983125269, 6.8190908484929285, 6.855654600401045, 6.892024376045111, 6.92820323027551, 6.9641941385920605, 7.0, 7.035623639735145, 7.071067811865476, 7.1063352017759485], [0.0, 0.7141428428542851, 1.0099504938362078, 1.2369316876852985, 1.4282856857085702, 1.5968719422671316, 1.7492855684535904, 1.8894443627691186, 2.0199009876724157, 2.142428528562855, 2.2583179581272432, 2.368543856465403, 2.473863375370597, 2.574878637916747, 2.672077843177478, 2.765863337187866, 2.8565713714171403, 2.944486372867092, 3.029851481508624, 3.1128764832546767, 3.193743884534263, 3.272613634390715, 3.3496268448888458, 3.4249087579087423, 3.498571136907181, 3.5707142142714257, 3.6414282912066254, 3.7107950630558952, 3.7788887255382373, 3.845776904605883, 3.9115214431215892, 3.9761790704142093, 4.039801975344831, 4.102438299353204, 4.164132562731403, 4.224926034855522, 4.28485705712571, 4.343961325794695, 4.402272140611029, 4.459820624195553, 4.5166359162544865, 4.572745346069471, 4.628174586162455, 4.682947789587239, 4.737087712930806, 4.790615826801393, 4.843552415324934, 4.89591666595746, 4.947726750741194, 4.998999899979996, 5.04975246918104, 5.100000000000001, 5.149757275833494, 5.199038372622384, 5.247856705360771, 5.296225070746145, 5.344155686354956, 5.391660226683429, 5.43874985635486, 5.485435260760991, 5.531726674375732, 5.577633906953737, 5.62316636780382, 5.668333088307356, 5.713142742834281, 5.757603668193913, 5.801723881744115, 5.845511098270194, 5.888972745734184, 5.932115979985557, 5.974947698515863, 6.017474553332154, 6.059702963017248, 6.101639124038721, 6.143289021363068, 6.184658438426491, 6.225752966509353, 6.266578013557321, 6.307138812488593, 6.347440429023341, 6.387487769068526, 6.427285585688566, 6.466838485689898, 6.506150935845249, 6.54522726878143, 6.584071688552609, 6.62268827591938, 6.661080993352356, 6.6992536897776915, 6.73721010508059, 6.77495387438173, 6.81248853210044, 6.8498175158174845, 6.886944169949399, 6.923871749245506, 6.960603422117942, 6.997142273814362, 7.033491309442276, 7.069653456853455, 7.105631569396208, 7.141428428542851, 7.177046746399247], [0.0, 0.7211102550927979, 1.019803902718557, 1.2489995996796799, 1.4422205101855958, 1.61245154965971, 1.7663521732655696, 1.9078784028338915, 2.039607805437114, 2.1633307652783937, 2.280350850198276, 2.3916521486202797, 2.4979991993593598, 2.6000000000000005, 2.6981475126464085, 2.792848008753788, 2.8844410203711917, 2.973213749463701, 3.0594117081556713, 3.1432467291003428, 3.22490309931942, 3.3045423283716615, 3.3823069050575527, 3.458323293158117, 3.532704346531139, 3.6055512754639896, 3.6769552621700474, 3.7469987990390394, 3.815756805667783, 3.88329756778952, 3.9496835316262997, 4.014971979976947, 4.079215610874228, 4.1424630354415966, 4.204759208325728, 4.266145801540309, 4.3266615305567875, 4.386342439892262, 4.445222154178574, 4.503332099679081, 4.560701700396552, 4.617358552246079, 4.67332857821917, 4.728636167014756, 4.7833042972405595, 4.8373546489791295, 4.890807704254994, 4.94368283772331, 4.9959983987187195, 5.047771785649585, 5.099019513592785, 5.149757275833494, 5.200000000000001, 5.249761899362676, 5.299056519796709, 5.347896782848376, 5.396295025292817, 5.44426303552648, 5.491812087098393, 5.5389529696504916, 5.585696017507576, 5.63205113613149, 5.678027826631356, 5.723635208501674, 5.768882040742383, 5.813776741499453, 5.858327406350725, 5.902541825349482, 5.946427498927402, 5.989991652748776, 6.033241251599343, 6.076183012385325, 6.118823416311343, 6.161168720299745, 6.203224967708329, 6.244997998398398, 6.2864934582006855, 6.327716807822551, 6.3686733312362644, 6.409368143584826, 6.44980619863884, 6.489992295835181, 6.529931086925804, 6.569627082262737, 6.609084656743323, 6.648308055437865, 6.687301398920196, 6.726068688320096, 6.764613810115105, 6.802940540677979, 6.841052550594828, 6.878953408767936, 6.916646586316234, 6.954135460285485, 6.9914233171794145, 7.0285133563222315, 7.065408693062278, 7.102112361825883, 7.138627319029899, 7.17495644586084, 7.211102550927979, 7.247068372797377], [0.0, 0.7280109889280519, 1.0295630140987002, 1.2609520212918495, 1.4560219778561039, 1.627882059609971, 1.7832554500127011, 1.9261360284258224, 2.0591260281974004, 2.1840329667841556, 2.302172886644268, 2.4145392935299275, 2.521904042583699, 2.624880949681338, 2.7239676943752476, 2.819574435974337, 2.9120439557122078, 3.001666203960727, 3.0886890422961004, 3.1733263305244868, 3.255764119219942, 3.336165463522456, 3.414674215792775, 3.491418050019219, 3.5665109000254023, 3.64005494464026, 3.712142238654118, 3.782856063875548, 3.852272056851645, 3.9204591567825324, 3.9874804074753776, 4.053393639902249, 4.118252056394801, 4.182104733265298, 4.244997055358225, 4.306971093471606, 4.368065933568311, 4.428317965096906, 4.487761134463376, 4.546427168667723, 4.604345773288536, 4.661544808322667, 4.718050444834181, 4.773887304912004, 4.829078587059855, 4.883646178829912, 4.937610758251404, 4.990991885387113, 5.043808085167398, 5.096076922496363, 5.147815070493501, 5.199038372622384, 5.249761899362676, 5.300000000000001, 5.349766350038103, 5.399073994677236, 5.447935388750495, 5.496362433464519, 5.5443665102516455, 5.591958512006326, 5.639148871948674, 5.6859475903318, 5.732364259186606, 5.7784080852774675, 5.8240879114244155, 5.869412236331676, 5.914389233048499, 5.959026766175833, 6.003332407921454, 6.047313453096343, 6.090976933136425, 6.134329629226001, 6.177378084592201, 6.220128616033596, 6.262587324740471, 6.304760106459247, 6.3466526610489735, 6.388270501473776, 6.429618962271405, 6.470703207534712, 6.511528238439884, 6.552098900352467, 6.592419889539805, 6.632495759516172, 6.672330927044912, 6.711929677819935, 6.751296171847301, 6.790434448545985, 6.82934843158555, 6.868041933477111, 6.906518659932804, 6.944782214007867, 6.982836100038438, 7.020683727387242, 7.058328414008519, 7.095773389842717, 7.1330218000508046, 7.170076708097342, 7.206941098690901, 7.243617880589783, 7.28010988928052, 7.31641988953614], [0.0, 0.7348469228349535, 1.0392304845413265, 1.2727922061357857, 1.469693845669907, 1.6431676725154984, 1.8, 1.9442222095223582, 2.078460969082653, 2.2045407685048604, 2.32379000772445, 2.4372115213907883, 2.5455844122715714, 2.6495282598983545, 2.749545416973504, 2.846049894151541, 2.939387691339814, 3.0298514815086235, 3.1176914536239795, 3.203123475609394, 3.286335345030997, 3.3674916480965478, 3.4467375879228173, 3.5242020373412197, 3.6, 3.6742346141747677, 3.7469987990390394, 3.818376618407357, 3.8884444190447165, 3.957271787481876, 4.024922359499621, 4.091454509095757, 4.156921938165306, 4.221374183841087, 4.28485705712571, 4.347413023856832, 4.409081537009721, 4.469899327725402, 4.529900661162451, 4.589117562233507, 4.6475800154489, 4.705316142407437, 4.762352359916264, 4.818713521262703, 4.874423042781577, 4.9295030175464944, 4.983974317750845, 5.037856687124, 5.091168824543143, 5.143928459844674, 5.196152422706632, 5.247856705360771, 5.299056519796709, 5.349766350038103, 5.4, 5.449770637375486, 5.499090833947008, 5.547972602672079, 5.596427431853289, 5.644466316668034, 5.692099788303082, 5.739337940912697, 5.786190456595773, 5.8326666285670745, 5.878775382679628, 5.924525297439449, 5.96992462263972, 6.014981296729027, 6.059702963017247, 6.104096984812742, 6.148170459575759, 6.191930232165088, 6.235382907247959, 6.278534860936905, 6.321392251711643, 6.363961030678928, 6.406246951218788, 6.448255578061404, 6.489992295835182, 6.5314623171231725, 6.572670690061994, 6.613622305514581, 6.654321903845651, 6.694774081326419, 6.7349832961930955, 6.77495387438173, 6.814690014960329, 6.854195795277518, 6.8934751758456345, 6.932532004974806, 6.971370023173351, 7.009992867328754, 7.0484040746824395, 7.0866070866106305, 7.124605252222751, 7.162401831787993, 7.2, 7.237402849088892, 7.274613391789285, 7.3116345641723655, 7.348469228349535, 7.385120175054704], [0.0, 0.7416198487095663, 1.0488088481701516, 1.2845232578665131, 1.4832396974191326, 1.6583123951777001, 1.8165902124584952, 1.9621416870348585, 2.0976176963403033, 2.224859546128699, 2.345207879911715, 2.459674775249769, 2.5690465157330262, 2.673948391424188, 2.7748873851023217, 2.8722813232690143, 2.9664793948382653, 3.0577769702841313, 3.146426544510455, 3.232645975048923, 3.3166247903554003, 3.398529093593286, 3.4785054261852175, 3.5566838487557484, 3.6331804249169903, 3.708099243547832, 3.7815340802378077, 3.853569773599539, 3.924283374069717, 3.993745109543172, 4.06201920231798, 4.129164564412516, 4.1952353926806065, 4.260281680828159, 4.324349662087931, 4.387482193696061, 4.449719092257398, 4.511097427455985, 4.571651780264984, 4.631414470763765, 4.69041575982343, 4.748684028233507, 4.806245936279167, 4.863126566315131, 4.919349550499538, 4.9749371855331, 5.029910535983717, 5.084289527554465, 5.1380930314660525, 5.191338940966964, 5.244044240850759, 5.296225070746145, 5.347896782848376, 5.399073994677236, 5.449770637375486, 5.5, 5.549774770204643, 5.599107071667768, 5.648008498577176, 5.6964901474504455, 5.744562646538029, 5.792236183029832, 5.839520528262573, 5.886425061104576, 5.932958789676531, 5.979130371550699, 6.024948132556827, 6.070420084310475, 6.115553940568263, 6.1603571325045765, 6.2048368229954285, 6.248999919987198, 6.29285308902091, 6.336402764976356, 6.3796551630946325, 6.422616289332565, 6.465291950097846, 6.507687761409578, 6.549809157525127, 6.591661399070799, 6.6332495807108005, 6.674578638386097, 6.715653356152327, 6.756478372643548, 6.797058187186572, 6.837397165588672, 6.87749954561976, 6.917369442208505, 6.957010852370435, 6.996427659884722, 7.035623639735144, 7.074602462329597, 7.113367697511497, 7.15192281837549, 7.1902712048990205, 7.2284161474004796, 7.266360849833981, 7.30410843293006, 7.341661937191061, 7.379024325749307, 7.416198487095664, 7.4531872376856345], [0.0, 0.7483314773547883, 1.058300524425836, 1.2961481396815722, 1.4966629547095767, 1.6733200530681511, 1.833030277982336, 1.9798989873223332, 2.116601048851672, 2.244994432064365, 2.3664319132398464, 2.4819347291981715, 2.5922962793631443, 2.6981475126464085, 2.8, 2.8982753492378874, 2.9933259094191533, 3.0854497241083023, 3.1749015732775088, 3.2619012860600183, 3.3466401061363023, 3.4292856398964493, 3.509985754956849, 3.5888716889852725, 3.666060555964672, 3.7416573867739413, 3.8157568056677826, 3.8884444190447165, 3.9597979746446663, 4.029888335921977, 4.098780306383839, 4.166533331199932, 4.233202097703344, 4.298837052040936, 4.363484845854286, 4.427188724235731, 4.48998886412873, 4.551922670696417, 4.613025037868319, 4.673328578219169, 4.732863826479693, 4.791659420284376, 4.849742261192857, 4.907137658554118, 4.963869458396343, 5.0199601592044525, 5.075431016179809, 5.130302135352264, 5.184592558726289, 5.238320341483518, 5.291502622129181, 5.344155686354956, 5.396295025292817, 5.447935388750495, 5.499090833947008, 5.549774770204643, 5.6, 5.649778756730214, 5.6991227395100035, 5.748043145279965, 5.796550698475775, 5.844655678480983, 5.892367945062493, 5.939696961966999, 5.986651818838307, 6.033241251599342, 6.079473661428265, 6.125357132445422, 6.170899448216605, 6.216108107168021, 6.260990336999411, 6.305553108173778, 6.3498031465550175, 6.393746945258312, 6.437390775772432, 6.48074069840786, 6.523802572120037, 6.566582063752802, 6.609084656743323, 6.6513156593263565, 6.6932802122726045, 6.734983296193095, 6.776429738438967, 6.817624219623724, 6.858571279792899, 6.899275324264136, 6.939740629158989, 6.979971346646059, 7.019971509913698, 7.059745037889116, 7.099295739719539, 7.138627319029899, 7.177743377970545, 7.216647421067487, 7.255342858886822, 7.293833011524187, 7.332121111929344, 7.370210309075312, 7.408103670980854, 7.445804187594514, 7.483314773547883, 7.520638270785267], [0.0, 0.754983443527075, 1.0677078252031311, 1.3076696830622023, 1.50996688705415, 1.6881943016134133, 1.849324200890693, 1.997498435543818, 2.1354156504062622, 2.264950330581225, 2.3874672772626644, 2.503996805109783, 2.6153393661244047, 2.72213151776324, 2.824889378365107, 2.924038303442689, 3.0199337741083, 3.1128764832546763, 3.2031234756093934, 3.290896534380867, 3.3763886032268267, 3.459768778401239, 3.5411862419251547, 3.620773398046335, 3.698648401781386, 3.774917217635375, 3.849675310984032, 3.9230090491866063, 3.994996871087636, 4.065710270051224, 4.135214625627066, 4.20356991139674, 4.2708313008125245, 4.337049688440288, 4.402272140611028, 4.466542286825459, 4.52990066116245, 4.592385001282014, 4.654030511288038, 4.7148700936505135, 4.774934554525329, 4.8342527861087286, 4.892851929090027, 4.950757517794625, 5.007993610219566, 5.064582904840239, 5.120546845796843, 5.175905717843014, 5.230678732248809, 5.2848841046895245, 5.338539126015656, 5.391660226683429, 5.44426303552648, 5.496362433464519, 5.547972602672079, 5.599107071667768, 5.649778756730214, 5.7, 5.749782604586021, 5.799137866959191, 5.848076606885378, 5.8966091951222275, 5.944745579080739, 5.9924953066314535, 6.0398675482166, 6.08687111741328, 6.133514490078261, 6.17980582219215, 6.2257529665093525, 6.271363488110062, 6.316644678941503, 6.361603571427569, 6.406246951218787, 6.450581369148055, 6.494613152451807, 6.5383484153110105, 6.581793068761734, 6.624952830020755, 6.667833231267862, 6.710439627923047, 6.752777206453653, 6.794850991743675, 6.836665854054885, 6.878226515607057, 6.919537556802478, 6.960603422117942, 7.001428425685718, 7.042016756583302, 7.0823724838503095, 7.122499561249548, 7.162401831787993, 7.202083032012336, 7.24154679609267, 7.280796659706959, 7.31983606373804, 7.358668357794092, 7.397296803562772, 7.4357245780085215, 7.473954776421918, 7.5119904153293495, 7.54983443527075, 7.587489703452652], [0.0, 0.7615773105863909, 1.0770329614269007, 1.3190905958272923, 1.5231546211727818, 1.7029386365926404, 1.8654758106177631, 2.0149441679609885, 2.1540659228538015, 2.2847319317591723, 2.4083189157584592, 2.525866188063018, 2.6381811916545845, 2.7459060435491964, 2.8495613697550017, 2.9495762407505253, 3.0463092423455636, 3.1400636936215167, 3.2310988842807027, 3.319638534539567, 3.405877273185281, 3.48998567332303, 3.5721142198983507, 3.6523964735499352, 3.7309516212355263, 3.8078865529319548, 3.8832975677895205, 3.957271787481876, 4.029888335921977, 4.101219330881976, 4.171330722922842, 4.240283009422838, 4.308131845707603, 4.374928570845472, 4.440720662234904, 4.505552130427525, 4.569463863518345, 4.632493928760188, 4.694677837722201, 4.756048780237647, 4.8166378315169185, 4.876474136094644, 4.935585071701227, 4.993996395673509, 5.051732376126036, 5.10881590977792, 5.165268628057984, 5.221110992882646, 5.276362383309169, 5.331041174104736, 5.385164807134505, 5.43874985635486, 5.491812087098393, 5.5443665102516455, 5.596427431853289, 5.648008498577176, 5.6991227395100035, 5.749782604586021, 5.800000000000001, 5.849786320883866, 5.8991524815010505, 5.948108943185221, 5.99666574022598, 6.044832503882966, 6.092618484691127, 6.1400325732035, 6.187083319303208, 6.23377895020348, 6.280127387243033, 6.326136261573885, 6.3718129288295975, 6.417164482853779, 6.462197768561405, 6.5069193939989765, 6.55133574166368, 6.59545297913646, 6.639277069079134, 6.682813778641449, 6.726068688320096, 6.76904720030818, 6.811754546370562, 6.854195795277518, 6.8963758598266685, 6.938299503480662, 6.97997134664606, 7.021395872616784, 7.062577433203831, 7.103520254071217, 7.144228439796701, 7.184705978674423, 7.224956747275378, 7.264984514780469, 7.3047929470998705, 7.3443856107914165, 7.383765976789894, 7.4229374239582535, 7.4619032424710525, 7.5006666370396715, 7.539230729988306, 7.577598564189055, 7.6157731058639095, 7.653757247260983], [0.0, 0.7681145747868608, 1.0862780491200215, 1.3304134695650072, 1.5362291495737217, 1.7175564037317668, 1.8814887722226779, 2.0322401432901573, 2.172556098240043, 2.3043437243605824, 2.4289915602982237, 2.5475478405713994, 2.6608269391300143, 2.7694764848252458, 2.8740215726399825, 2.974894956128703, 3.0724582991474434, 3.167017524422623, 3.2588341473600644, 3.3481338085566414, 3.4351128074635335, 3.5199431813596083, 3.602776706930364, 3.6837480912787726, 3.7629775444453557, 3.840572873934304, 3.916631205513228, 3.9912404086950213, 4.064480286580315, 4.136423575989287, 4.207136793592525, 4.276680956068619, 4.345112196480086, 4.412482294582042, 4.4788391353117385, 4.544227107000705, 4.608687448721165, 4.672258554489466, 4.734976240700686, 4.796873982084583, 4.857983120596447, 4.9183330509431755, 4.9779513858614575, 5.03686410378521, 5.095095681142799, 5.1526692111953, 5.209606511052442, 5.265928218272634, 5.321653878260029, 5.376802023508025, 5.431390245600108, 5.485435260760991, 5.5389529696504916, 5.591958512006326, 5.644466316668034, 5.6964901474504455, 5.748043145279965, 5.799137866959191, 5.849786320883866, 5.8999999999999995, 5.949789912257406, 5.999166608788257, 6.048140210014975, 6.096720429870472, 6.144916598294887, 6.192737682156413, 6.240192304729077, 6.287288763847259, 6.334035048845246, 6.380438856379708, 6.4265076052238514, 6.472248450113762, 6.517668294720129, 6.562773803811921, 6.607571414672716, 6.652067347825035, 6.696267617113283, 6.740178039191546, 6.783804242458652, 6.827151675479314, 6.870225614927067, 6.913031173081747, 6.955573304911681, 6.997856814768361, 7.0398863627192165, 7.0816664705420855, 7.123201527403251, 7.164495795239188, 7.205553413860728, 7.246378405796926, 7.286974680894671, 7.327346040688948, 7.367496182557545, 7.407428703673091, 7.447147104764348, 7.486654793697916, 7.525955088890711, 7.565051222562872, 7.603946343840151, 7.642643521714199, 7.681145747868608, 7.719455939378112], [0.0, 0.7745966692414833, 1.0954451150103321, 1.3416407864998738, 1.5491933384829666, 1.7320508075688772, 1.8973665961010275, 2.0493901531919194, 2.1908902300206643, 2.3237900077244498, 2.449489742783178, 2.569046515733026, 2.6832815729997477, 2.792848008753788, 2.8982753492378874, 2.9999999999999996, 3.098386676965933, 3.1937438845342623, 3.2863353450309964, 3.3763886032268267, 3.4641016151377544, 3.5496478698597693, 3.63318042491699, 3.714835124201342, 3.794733192202055, 3.8729833462074166, 3.9496835316262997, 4.024922359499621, 4.098780306383839, 4.171330722922842, 4.242640687119285, 4.3127717305695645, 4.381780460041329, 4.449719092257398, 4.516635916254486, 4.58257569495584, 4.6475800154488995, 4.711687595755898, 4.774934554525329, 4.8373546489791295, 4.898979485566356, 4.959838707054898, 5.019960159204453, 5.079370039680117, 5.138093031466052, 5.196152422706631, 5.253570214625478, 5.310367218940701, 5.366563145999495, 5.422176684690383, 5.477225575051661, 5.531726674375732, 5.585696017507576, 5.639148871948674, 5.692099788303082, 5.744562646538029, 5.796550698475775, 5.848076606885378, 5.8991524815010505, 5.949789912257406, 5.999999999999999, 6.049793384901669, 6.099180272790762, 6.148170459575758, 6.196773353931866, 6.244997998398397, 6.292853089020909, 6.340346993658943, 6.387487769068525, 6.434283176858164, 6.48074069840786, 6.526867548832287, 6.572670690061993, 6.618156843109718, 6.663332499583071, 6.7082039324993685, 6.752777206453653, 6.797058187186571, 6.841052550594828, 6.884765791223402, 6.928203230275509, 6.97137002317335, 7.014271166700073, 7.056911505750939, 7.099295739719539, 7.1414284285428495, 7.183313998427188, 7.224956747275377, 7.26636084983398, 7.307530362578043, 7.348469228349534, 7.389181280764466, 7.429670248402684, 7.469939758793239, 7.5099933422074345, 7.549834435270749, 7.58946638440411, 7.628892449104261, 7.668115805072325, 7.707139547199078, 7.745966692414833, 7.784600182411426], [0.0, 0.7810249675906654, 1.104536101718726, 1.3527749258468684, 1.5620499351813308, 1.746424919657298, 1.9131126469708992, 2.0663978319771825, 2.209072203437452, 2.3430749027719964, 2.4698178070456938, 2.5903667693977237, 2.705549851693737, 2.816025568065745, 2.9223278392404914, 3.0248966924508345, 3.1240998703626617, 3.2202484376209237, 3.3136083051561784, 3.4044089061098406, 3.492849839314596, 3.5791060336346563, 3.6633318168028404, 3.745664160065609, 3.8262252939417984, 3.9051248379533274, 3.9824615503479754, 4.058324777540605, 4.132795663954365, 4.205948168962618, 4.277849927241487, 4.34856298103178, 4.418144406874904, 4.486646854834912, 4.5541190146942805, 4.620606020859168, 4.686149805543993, 4.750789408087881, 4.814561246884289, 4.87749935930288, 4.9396356140913875, 5.000999900019996, 5.061620293937506, 5.121523210920751, 5.180733538795447, 5.239274758971893, 5.297169055259611, 5.354437412091022, 5.411099703387474, 5.467174773134658, 5.522680508593631, 5.577633906953737, 5.63205113613149, 5.6859475903318, 5.739337940912697, 5.792236183029832, 5.844655678480983, 5.8966091951222275, 5.948108943185221, 5.999166608788257, 6.049793384901669, 6.1, 6.149796744608719, 6.199193495931548, 6.248199740725323, 6.296824596572465, 6.345076831686122, 6.392964883369843, 6.440496875241847, 6.487680633323437, 6.534523701081817, 6.5810333535091585, 6.627216610312357, 6.673080248281149, 6.71863081289633, 6.7638746292343415, 6.808817812219681, 6.853466276272176, 6.897825744392215, 6.941901756723442, 6.985699678629192, 7.029224708315989, 7.07248188403477, 7.115476090888086, 7.158212067269313, 7.200694410957877, 7.242927584892728, 7.284915922644544, 7.326663633605681, 7.368174807915458, 7.409453421137082, 7.450503338701353, 7.491328320131218, 7.531932023060219, 7.572318007057021, 7.6124897372673015, 7.652450587883597, 7.692203845452876, 7.731752712031082, 7.771100308193172, 7.810249675906655, 7.849203781276163], [0.0, 0.787400787401181, 1.1135528725660042, 1.3638181696985856, 1.574801574802362, 1.760681686165901, 1.928730152198591, 2.083266665599966, 2.2271057451320084, 2.362202362203543, 2.4899799195977463, 2.6115129714401193, 2.727636339397171, 2.839013913315678, 2.9461839725312466, 3.049590136395381, 3.149603149604724, 3.246536616149585, 3.340658617698013, 3.432200460346103, 3.521363372331802, 3.608323710533743, 3.6932370625238775, 3.7762415176998414, 3.857460304397182, 3.9370039370059056, 4.014971979976946, 4.091454509095756, 4.166533331199932, 4.240283009422838, 4.3127717305695645, 4.384062043356595, 4.454211490264017, 4.523273151159457, 4.591296113299598, 4.658325879540846, 4.724404724407086, 4.789572005931219, 4.853864439804639, 4.917316341257699, 4.979959839195493, 5.041825066382213, 5.10294032886923, 5.163332257370234, 5.223025942880239, 5.282045058497702, 5.340411969127476, 5.3981478305063115, 5.455272678794342, 5.511805511808268, 5.5677643628300215, 5.62316636780382, 5.678027826631356, 5.732364259186606, 5.786190456595773, 5.839520528262573, 5.892367945062493, 5.944745579080739, 5.99666574022598, 6.048140210014975, 6.099180272790762, 6.149796744608719, 6.199999999999999, 6.249799996799897, 6.299206299209448, 6.348228099241551, 6.39687423668779, 6.445153217728807, 6.49307323229917, 6.540642170307133, 6.587867636800241, 6.6347569661593475, 6.681317235396026, 6.727555276621664, 6.773477688750439, 6.819090848492928, 6.864400920692206, 6.90941386804988, 6.954135460285484, 6.998571282769077, 7.042726744663604, 7.08660708661063, 7.130217387990355, 7.173562573784381, 7.216647421067486, 7.259476565152615, 7.302054505411474, 7.344385610791416, 7.386474125047755, 7.428324171709255, 7.469939758793239, 7.511324783285569, 7.552483035399683, 7.593418202627852, 7.634133873596926, 7.674633541739956, 7.714920608794364, 7.754998388136519, 7.79487010796203, 7.834538914320357, 7.874007874011811, 7.913279977354524], [0.0, 0.7937253933193772, 1.1224972160321824, 1.3747727084867523, 1.5874507866387544, 1.7748239349298849, 1.9442222095223582, 2.1, 2.244994432064365, 2.3811761799581315, 2.5099800796022267, 2.632489316217637, 2.7495454169735045, 2.861817604250837, 2.9698484809834995, 3.074085229787879, 3.1749015732775088, 3.2726136343907144, 3.3674916480965473, 3.4597687784012394, 3.5496478698597698, 3.6373066958946425, 3.722902093797257, 3.8065732621348563, 3.8884444190447165, 3.968626966596886, 4.047221268969613, 4.124318125460256, 4.2, 4.274342054632503, 4.347413023856832, 4.419275958796871, 4.48998886412873, 4.559605246071199, 4.628174586162454, 4.695742752749559, 4.762352359916263, 4.828043081829325, 4.892851929090027, 4.956813492557492, 5.019960159204453, 5.082322303829225, 5.143928459844674, 5.204805471869242, 5.264978632435274, 5.324471804789654, 5.383307533477908, 5.441507144165117, 5.499090833947009, 5.55607775323564, 5.612486080160912, 5.668333088307356, 5.723635208501674, 5.7784080852774675, 5.8326666285670745, 5.886425061104576, 5.939696961966999, 5.9924953066314535, 6.044832503882966, 6.096720429870472, 6.148170459575758, 6.199193495931548, 6.249799996799897, 6.3, 6.3498031465550175, 6.3992187023104625, 6.448255578061403, 6.496922348312315, 6.545227268781429, 6.593178292750774, 6.640783086353597, 6.688049042882386, 6.734983296193095, 6.7815927332743895, 6.827884006044625, 6.87386354243376, 6.919537556802479, 6.96491205974634, 7.009992867328754, 7.0547856097829085, 7.0992957397195395, 7.143528539874395, 7.187489130426565, 7.23118247591637, 7.274613391789285, 7.317786550590281, 7.3607064878311785, 7.40337760755184, 7.445804187594514, 7.487990384609211, 7.52994023880668, 7.571657678474378, 7.6131465242697125, 7.654410493303845, 7.695453203028396, 7.736278174936576, 7.776888838089433, 7.817288532477231, 7.857480512225277, 7.897467948652911, 7.937253933193772, 7.976841480185], [0.0, 0.8, 1.131370849898476, 1.385640646055102, 1.6, 1.788854381999832, 1.9595917942265426, 2.1166010488516727, 2.262741699796952, 2.4, 2.5298221281347035, 2.65329983228432, 2.771281292110204, 2.8844410203711917, 2.9933259094191533, 3.098386676965933, 3.2, 3.2984845004941286, 3.394112549695428, 3.4871191548325395, 3.577708763999664, 3.6660605559646724, 3.752332607858744, 3.836665218650176, 3.9191835884530852, 4.0, 4.079215610874228, 4.156921938165306, 4.233202097703345, 4.308131845707604, 4.381780460041329, 4.454211490264018, 4.525483399593904, 4.595650117230424, 4.664761515876241, 4.732863826479693, 4.8, 4.866210024238576, 4.931531202375181, 4.9959983987187195, 5.059644256269407, 5.122499389946279, 5.184592558726289, 5.2459508194416005, 5.30659966456864, 5.366563145999495, 5.4258639865002145, 5.4845236803208355, 5.542562584220408, 5.6000000000000005, 5.656854249492381, 5.713142742834281, 5.768882040742383, 5.8240879114244155, 5.878775382679628, 5.932958789676531, 5.986651818838307, 6.0398675482166, 6.092618484691127, 6.144916598294887, 6.196773353931866, 6.248199740725323, 6.299206299209448, 6.3498031465550175, 6.4, 6.449806198638839, 6.499230723708768, 6.5482822174979605, 6.596969000988257, 6.64529909033446, 6.6932802122726045, 6.740919818541087, 6.788225099390856, 6.835202996254025, 6.881860213634101, 6.92820323027551, 6.974238309665079, 7.019971509913698, 7.065408693062278, 7.110555533852471, 7.155417527999328, 7.2, 7.244308110509934, 7.288346863315439, 7.332121111929345, 7.37563556583431, 7.418894796396564, 7.4619032424710525, 7.504665215717488, 7.547184905645283, 7.58946638440411, 7.631513611335565, 7.673330437300352, 7.7149206087943645, 7.756287771866127, 7.797435475847171, 7.8383671769061705, 7.879086241436885, 7.919595949289333, 7.959899496852961, 8.0, 8.039900496896713], [0.0, 0.8062257748298549, 1.1401754250991378, 1.3964240043768943, 1.6124515496597098, 1.8027756377319946, 1.9748417658131499, 2.133072900770154, 2.2803508501982757, 2.4186773244895647, 2.5495097567963922, 2.6739483914241875, 2.7928480087537886, 2.9068883707497264, 3.016620625799671, 3.1224989991991987, 3.2249030993194197, 3.324154027718932, 3.420526275297414, 3.5142566781611158, 3.605551275463989, 3.6945906403822333, 3.7815340802378072, 3.866522985836241, 3.9496835316262997, 4.031128874149275, 4.110960958218893, 4.189272013130682, 4.266145801540308, 4.341658669218482, 4.415880433163923, 4.488875137492688, 4.560701700396551, 4.631414470763764, 4.701063709417263, 4.769696007084728, 4.8373546489791295, 4.904079934095691, 4.969909455915671, 5.034878350069642, 5.0990195135927845, 5.162363799656123, 5.224940191045253, 5.28677595515452, 5.347896782848375, 5.4083269131959835, 5.468089245796926, 5.527205442174191, 5.585696017507577, 5.643580423808984, 5.70087712549569, 5.757603668193913, 5.813776741499453, 5.869412236331676, 5.924525297439449, 5.979130371550699, 6.033241251599342, 6.08687111741328, 6.1400325732035, 6.192737682156413, 6.244997998398397, 6.296824596572465, 6.348228099241551, 6.3992187023104625, 6.449806198638839, 6.499999999999999, 6.549809157525125, 6.599242380758566, 6.648308055437864, 6.697014260101287, 6.745368781616021, 6.793379129711516, 6.841052550594828, 6.888396039717809, 6.93541635375988, 6.98212002188447, 7.0285133563222315, 7.074602462329597, 7.12039324756716, 7.165891430938652, 7.211102550927978, 7.256031973468694, 7.300684899377592, 7.345066371381541, 7.389181280764467, 7.433034373659253, 7.476630257007497, 7.519973404208288, 7.5630681604756145, 7.6059187479225665, 7.648529270389177, 7.6909037180295, 7.733045971672482, 7.774959806970066, 7.816648898345122, 7.858116822750854, 7.899367063252599, 7.940403012442127, 7.981227975693965, 8.021845174272563, 8.06225774829855, 8.10246875958186], [0.0, 0.812403840463596, 1.1489125293076057, 1.4071247279470291, 1.624807680927192, 1.8165902124584952, 1.98997487421324, 2.149418526020468, 2.2978250586152114, 2.437211521390788, 2.569046515733026, 2.6944387170614963, 2.8142494558940583, 2.9291637031753623, 3.0397368307141326, 3.1464265445104544, 3.249615361854384, 3.3496268448888453, 3.4467375879228173, 3.541186241925155, 3.6331804249169903, 3.722902093797257, 3.81051177665153, 3.8961519477556315, 3.97994974842648, 4.06201920231798, 4.142463035441596, 4.221374183841087, 4.298837052040936, 4.374928570845472, 4.449719092257397, 4.523273151159456, 4.595650117230423, 4.666904755831214, 4.737087712930805, 4.806245936279166, 4.874423042781576, 4.941659640242335, 5.007993610219566, 5.073460357586329, 5.138093031466052, 5.201922721455982, 5.264978632435274, 5.3272882407468805, 5.388877434122993, 5.449770637375485, 5.509990925582365, 5.569560126257728, 5.628498911788117, 5.686826883245172, 5.744562646538029, 5.801723881744115, 5.858327406350725, 5.914389233048499, 5.96992462263972, 6.024948132556827, 6.079473661428265, 6.133514490078261, 6.187083319303208, 6.240192304729077, 6.292853089020909, 6.345076831686122, 6.39687423668779, 6.448255578061403, 6.499230723708768, 6.549809157525125, 6.6, 6.649812027418519, 6.699253689777691, 6.748333127521196, 6.797058187186572, 6.8454364360499325, 6.8934751758456345, 6.941181455631311, 6.988562083862459, 7.035623639735144, 7.08237248385031, 7.128814768248646, 7.17495644586084, 7.2208032794142785, 7.266360849833981, 7.311634564172365, 7.356629663099809, 7.401351227985333, 7.445804187594514, 7.489993324429602, 7.533923280734945, 7.577598564189054, 7.62102355330306, 7.664202502543888, 7.707139547199077, 7.749838707999025, 7.792303895511263, 7.834538914320357, 7.8765474670060875, 7.918333157931661, 7.95989949685296, 8.001249902359007, 8.04238770515324, 8.083316151184489, 8.12403840463596, 8.16455755078008], [0.0, 0.8185352771872451, 1.1575836902790224, 1.4177446878757827, 1.6370705543744901, 1.8303005217723127, 2.004993765576342, 2.1656407827707715, 2.315167380558045, 2.455605831561735, 2.588435821108957, 2.714774392099646, 2.8354893757515653, 2.951270912674741, 3.062678566222711, 3.1701734968294715, 3.2741411087489802, 3.374907406137241, 3.4727510708370675, 3.567912554982255, 3.6606010435446255, 3.7509998667022106, 3.8392707640904935, 3.9255572852781047, 4.009987531152684, 4.092676385936225, 4.173727350941841, 4.253234063627348, 4.331281565541543, 4.407947368106838, 4.483302354291978, 4.557411546042337, 4.63033476111609, 4.702127178203499, 4.77283982551269, 4.8425200051213, 4.91121166312347, 4.978955713801841, 5.045790324617146, 5.111751167652823, 5.176871642217914, 5.241183072551464, 5.304714883949938, 5.367494760127856, 5.429548784199292, 5.490901565316937, 5.551576352712804, 5.61159513863928, 5.670978751503131, 5.729746940310715, 5.787918451395113, 5.845511098270194, 5.902541825349482, 5.959026766175833, 6.014981296729027, 6.070420084310475, 6.125357132445422, 6.17980582219215, 6.23377895020348, 6.287288763847259, 6.340346993658943, 6.392964883369843, 6.445153217728807, 6.496922348312315, 6.5482822174979605, 6.599242380758566, 6.649812027418519, 6.7, 6.749814812274482, 6.79926466612383, 6.848357467305573, 6.897100840208152, 6.945502141674135, 6.993568473962345, 7.041306696913577, 7.088723439378913, 7.13582510996451, 7.182617907142214, 7.229107828771128, 7.275300681071539, 7.321202087089251, 7.366817494685205, 7.4121521840825695, 7.457211275000863, 7.501999733404421, 7.546522377890362, 7.590783885739338, 7.634788798650556, 7.678541528180987, 7.722046360907191, 7.76530746332687, 7.808328886515987, 7.851114570556209, 7.893668348746355, 7.935993951610599, 7.978095010715276, 8.019975062305368, 8.061637550770936, 8.103085831953157, 8.144323176298936, 8.18535277187245, 8.226177727231525], [0.0, 0.8246211251235321, 1.16619037896906, 1.4282856857085702, 1.6492422502470643, 1.8439088914585775, 2.0199009876724157, 2.181742422927143, 2.33238075793812, 2.473863375370596, 2.6076809620810595, 2.734958866235469, 2.8565713714171403, 2.973213749463701, 3.0854497241083023, 3.1937438845342623, 3.2984845004941286, 3.4, 3.4985711369071804, 3.594440151122286, 3.687817782917155, 3.778888725538237, 3.867815921162743, 3.954743986657038, 4.039801975344831, 4.123105625617661, 4.204759208325728, 4.28485705712571, 4.363484845854286, 4.440720662234904, 4.516635916254486, 4.591296113299599, 4.66476151587624, 4.737087712930805, 4.8083261120685235, 4.878524367060187, 4.947726750741192, 5.015974481593781, 5.083306010855534, 5.149757275833494, 5.215361924162119, 5.280151512977635, 5.344155686354956, 5.407402333838309, 5.469917732470938, 5.531726674375732, 5.592852581643825, 5.653317610041028, 5.713142742834281, 5.772347875864725, 5.830951894845301, 5.888972745734184, 5.946427498927402, 6.003332407921454, 6.059702963017247, 6.115553940568263, 6.170899448216605, 6.2257529665093525, 6.280127387243033, 6.334035048845246, 6.387487769068525, 6.440496875241847, 6.49307323229917, 6.545227268781429, 6.596969000988257, 6.648308055437864, 6.699253689777691, 6.749814812274482, 6.8, 6.849817515817484, 6.899275324264137, 6.948381106416083, 6.997142273814361, 7.045565981523414, 7.093659140387279, 7.14142842854285, 7.188880302244572, 7.236021006050217, 7.282856582413251, 7.329392880723478, 7.37563556583431, 7.42159012611179, 7.467261881037788, 7.512655988397179, 7.557777451076474, 7.602631123499285, 7.647221717722065, 7.691553809211764, 7.735631842325486, 7.779460135510689, 7.8230428862431785, 7.866384175718855, 7.909487973314076, 7.952358140828418, 7.994998436522675, 8.037412518964047, 8.079603950689663, 8.121576201698781, 8.16333265278342, 8.204876598706406, 8.246211251235321, 8.287339742040265], [0.0, 0.8306623862918076, 1.174734012447073, 1.4387494569938162, 1.661324772583615, 1.8574175621006712, 2.0346989949375804, 2.1977260975835913, 2.349468024894146, 2.4919871588754225, 2.6267851073127395, 2.7549954627911823, 2.8774989139876324, 2.994995826374388, 3.1080540535840107, 3.217141588429082, 3.32264954516723, 3.424908757908742, 3.5242020373412193, 3.6207733980463352, 3.7148351242013424, 3.8065732621348563, 3.8961519477556315, 3.9837168574084183, 4.069397989875161, 4.153311931459037, 4.235563716909475, 4.316248370981448, 4.3954521951671826, 4.473253849269009, 4.54972526643093, 4.624932431938872, 4.698936049788292, 4.77179211617606, 4.843552415324934, 4.914264950122246, 4.983974317750845, 5.052722038663912, 5.120546845796843, 5.187484939737176, 5.253570214625479, 5.3188344587888805, 5.383307533477909, 5.447017532558529, 5.509990925582365, 5.572252686302012, 5.63382640840131, 5.69473440996154, 5.754997827975265, 5.814636704042653, 5.873670062235366, 5.932115979985557, 5.989991652748776, 6.047313453096343, 6.104096984812742, 6.1603571325045765, 6.216108107168021, 6.271363488110062, 6.326136261573885, 6.380438856379708, 6.434283176858164, 6.487680633323437, 6.540642170307133, 6.593178292750774, 6.64529909033446, 6.697014260101287, 6.748333127521196, 6.79926466612383, 6.849817515817484, 6.9, 6.949820141557622, 6.999285677838847, 7.048404074682439, 7.097182539571601, 7.145628033979938, 7.19374728496908, 7.2415467960926705, 7.289032857656769, 7.336211556382492, 7.383088784512889, 7.429670248402685, 7.475961476626268, 7.521967827636597, 7.567694497005016, 7.6131465242697125, 7.658328799418317, 7.703246069028303, 7.747902942086975, 7.792303895511263, 7.836453279386026, 7.880355321938218, 7.924014134263013, 7.967433714816837, 8.010617953691215, 8.053570636680355, 8.096295449154509, 8.138795979750322, 8.18107572388864, 8.223138087129511, 8.264986388373547, 8.306623862918075, 8.34805366537614], [0.0, 0.8366600265340756, 1.1832159566199232, 1.4491376746189442, 1.6733200530681511, 1.8708286933869709, 2.04939015319192, 2.2135943621178655, 2.3664319132398464, 2.5099800796022267, 2.6457513110645907, 2.774887385102322, 2.8982753492378883, 3.0166206257996717, 3.1304951684997055, 3.24037034920393, 3.3466401061363023, 3.4496376621320683, 3.5496478698597698, 3.6469165057620945, 3.7416573867739418, 3.834057902536163, 3.924283374069717, 4.012480529547776, 4.09878030638384, 4.183300132670378, 4.266145801540309, 4.3474130238568325, 4.427188724235731, 4.505552130427525, 4.58257569495584, 4.658325879540847, 4.732863826479693, 4.806245936279167, 4.878524367060187, 4.949747468305833, 5.019960159204453, 5.089204259999789, 5.157518783291051, 5.2249401910452535, 5.291502622129181, 5.35723809439155, 5.422176684690385, 5.486346689738081, 5.549774770204644, 5.612486080160912, 5.674504383644443, 5.735852159879995, 5.796550698475777, 5.856620185738529, 5.916079783099617, 5.974947698515863, 6.033241251599343, 6.090976933136425, 6.148170459575759, 6.2048368229954285, 6.260990336999411, 6.316644678941503, 6.3718129288295975, 6.4265076052238514, 6.48074069840786, 6.534523701081817, 6.587867636800241, 6.640783086353597, 6.6932802122726045, 6.745368781616021, 6.797058187186572, 6.848357467305573, 6.899275324264137, 6.949820141557622, 7.000000000000001, 7.049822692805827, 7.0992957397195395, 7.148426400264607, 7.197221686178633, 7.24568837309472, 7.293833011524189, 7.341661937191062, 7.3891812807644675, 7.436396977031284, 7.4833147735478835, 7.529940238806681, 7.576278769950325, 7.622335600063802, 7.668115805072326, 7.713624310270757, 7.75886589650833, 7.803845206050669, 7.848566748139434, 7.893034904268446, 7.937253933193772, 7.981227975693966, 8.024961059095553, 8.068457101577724, 8.1117199162693, 8.154753215150045, 8.19756061276768, 8.240145629781066, 8.282511696339462, 8.324662155306966, 8.366600265340756, 8.408329203831164], [0.0, 0.8426149773176359, 1.1916375287812984, 1.4594519519326425, 1.6852299546352718, 1.8841443681416774, 2.0639767440550294, 2.2293496809607953, 2.3832750575625967, 2.5278449319529073, 2.6645825188948455, 2.7946377224964243, 2.918903903865285, 3.0380915061926625, 3.152776554086889, 3.2634337744161437, 3.3704599092705436, 3.4741905532080417, 3.5749125863438955, 3.672873534441392, 3.768288736283355, 3.861346915261565, 3.952214569073901, 4.041039470235351, 4.127953488110059, 4.2130748865881795, 4.296510211788167, 4.378355855797928, 4.458699361921591, 4.537620521815371, 4.61519230368573, 4.69148164229596, 4.766550115125193, 4.8404545241123795, 4.913247398615299, 4.984977432245807, 5.0556898639058145, 5.1254268114957995, 5.194227565288221, 5.262128846769148, 5.329165037789691, 5.395368384086485, 5.46076917659042, 5.525395913416522, 5.589275444992849, 5.652433104425031, 5.71489282489182, 5.776677245614472, 5.83780780773057, 5.898304841223451, 5.958187643906493, 6.017474553332154, 6.076183012385325, 6.134329629226001, 6.191930232165088, 6.248999919987198, 6.305553108173778, 6.361603571427569, 6.417164482853779, 6.472248450113762, 6.526867548832287, 6.5810333535091585, 6.6347569661593475, 6.688049042882386, 6.740919818541087, 6.793379129711516, 6.8454364360499325, 6.897100840208152, 6.948381106416083, 6.999285677838847, 7.049822692805827, 7.1, 7.149825172687791, 7.199305522062527, 7.248448109768049, 7.297259759663212, 7.345747068882784, 7.3939164182454755, 7.441773982055624, 7.489325737341113, 7.53657747256671, 7.583534795858723, 7.630203142774117, 7.676587783644501, 7.72269383052313, 7.768526243760782, 7.814089838234521, 7.859389289251424, 7.904429138147802, 7.949213797602879, 7.993747556684537, 8.038034585643434, 8.082078940470701, 8.125884567233282, 8.16945530620004, 8.212794895770866, 8.255906976220118, 8.298795093265047, 8.341462701469089, 8.383913167489272, 8.426149773176359, 8.468175718535841], [0.0, 0.848528137423857, 1.2, 1.4696938456699071, 1.697056274847714, 1.8973665961010278, 2.078460969082653, 2.244994432064365, 2.4, 2.545584412271571, 2.6832815729997477, 2.814249455894058, 2.9393876913398143, 3.0594117081556713, 3.1749015732775088, 3.2863353450309964, 3.394112549695428, 3.4985711369071804, 3.6, 3.6986484017813863, 3.7947331922020555, 3.8884444190447165, 3.97994974842648, 4.069397989875161, 4.156921938165306, 4.242640687119286, 4.3266615305567875, 4.409081537009721, 4.48998886412873, 4.5694638635183455, 4.6475800154489, 4.724404724407087, 4.8, 4.874423042781577, 4.947726750741193, 5.019960159204453, 5.091168824543142, 5.1613951602255765, 5.230678732248808, 5.299056519796709, 5.366563145999495, 5.43323108288245, 5.499090833947008, 5.564171097297422, 5.628498911788116, 5.692099788303082, 5.754997827975264, 5.817215828899595, 5.8787753826796285, 5.939696961966999, 6.0, 6.059702963017248, 6.118823416311343, 6.177378084592201, 6.235382907247959, 6.29285308902091, 6.3498031465550175, 6.406246951218787, 6.462197768561405, 6.517668294720129, 6.572670690061993, 6.627216610312357, 6.681317235396026, 6.734983296193095, 6.788225099390856, 6.841052550594828, 6.8934751758456345, 6.945502141674135, 6.997142273814361, 7.048404074682439, 7.0992957397195395, 7.149825172687791, 7.2, 7.249827584156743, 7.299315036357863, 7.3484692283495345, 7.397296803562773, 7.445804187594514, 7.493997598078079, 7.541883053985921, 7.589466384404111, 7.636753236814713, 7.68374908491942, 7.730459236035075, 7.776888838089433, 7.823042886243179, 7.868926229162401, 7.914543574963752, 7.95989949685296, 8.0049984384758, 8.049844718999243, 8.094442537939225, 8.138795979750322, 8.182909018191515, 8.226785520481254, 8.270429251254132, 8.313843876330612, 8.357032966310472, 8.4, 8.442748367682174, 8.485281374238571, 8.527602242131138], [0.0, 0.8544003745317531, 1.2083045973594573, 1.4798648586948744, 1.7088007490635062, 1.91049731745428, 2.092844953645635, 2.260530911091463, 2.4166091947189146, 2.563201123595259, 2.701851217221259, 2.833725463060951, 2.9597297173897488, 3.0805843601498726, 3.196873472629156, 3.309078421554859, 3.4176014981270124, 3.522782990761707, 3.6249137920783716, 3.7242448899072147, 3.82099463490856, 3.915354390090379, 4.007492981902776, 4.097560249709576, 4.18568990729127, 4.272001872658766, 4.356604182158393, 4.439594576084623, 4.521061822182926, 4.601086828130937, 4.679743582719036, 4.757099956906519, 4.833218389437829, 4.908156476723211, 4.98196748283246, 5.054700782440045, 5.126402247190518, 5.197114584074513, 5.266877632905477, 5.335728628781641, 5.403702434442518, 5.470831746635972, 5.537147279962851, 5.602677931132575, 5.667450926121902, 5.731491952362839, 5.794825277780168, 5.857473858242988, 5.9194594347794975, 5.980802621722272, 6.041522986797286, 6.101639124038721, 6.161168720299745, 6.220128616033596, 6.278534860936905, 6.336402764976356, 6.393746945258312, 6.450581369148055, 6.5069193939989765, 6.562773803811921, 6.618156843109718, 6.673080248281149, 6.727555276621664, 6.7815927332743895, 6.835202996254025, 6.888396039717809, 6.941181455631311, 6.993568473962345, 7.045565981523414, 7.097182539571601, 7.148426400264607, 7.199305522062527, 7.249827584156743, 7.3, 7.349829930005183, 7.399324293474371, 7.448489779814429, 7.4973328590906245, 7.545859791965394, 7.594076639065476, 7.64198926981712, 7.689603370785778, 7.736924453553881, 7.783957862167549, 7.830708780180758, 7.877182237323192, 7.923383115816122, 7.969316156358713, 8.014985963805552, 8.060397012554654, 8.105553651663778, 8.150460109711599, 8.195120499419152, 8.239538822045807, 8.283718971573094, 8.327664738688751, 8.37137981458254, 8.414867794564572, 8.4581321815162, 8.501176389182852, 8.544003745317532, 8.586617494683225], [0.0, 0.8602325267042626, 1.2165525060596438, 1.489966442575134, 1.7204650534085253, 1.9235384061671346, 2.1071307505705477, 2.2759613353482084, 2.4331050121192876, 2.580697580112788, 2.7202941017470885, 2.8530685235374214, 2.979932885150268, 3.1016124838541645, 3.218695387886216, 3.3316662497915357, 3.4409301068170506, 3.5468295701936396, 3.6496575181789317, 3.749666651850535, 3.847076812334269, 3.9420806688854046, 4.034848200366403, 4.125530268947254, 4.214261501141095, 4.301162633521313, 4.386342439892262, 4.469899327725402, 4.551922670696417, 4.632493928760188, 4.711687595755898, 4.789572005931219, 4.866210024238575, 4.941659640242335, 5.015974481593781, 5.089204259999788, 5.161395160225576, 5.232590180780452, 5.302829433425141, 5.372150407425317, 5.440588203494177, 5.508175741568165, 5.574943945906542, 5.6409219104681805, 5.706137047074843, 5.770615218501403, 5.834380858325929, 5.897457079114692, 5.959865770300536, 6.021627686929839, 6.082762530298219, 6.143289021363068, 6.203224967708329, 6.262587324740471, 6.321392251711643, 6.3796551630946325, 6.437390775772432, 6.494613152451807, 6.55133574166368, 6.607571414672716, 6.663332499583071, 6.71863081289633, 6.773477688750439, 6.827884006044625, 6.881860213634101, 6.93541635375988, 6.988562083862459, 7.041306696913577, 7.093659140387279, 7.145628033979938, 7.197221686178633, 7.248448109768049, 7.299315036357863, 7.349829930005183, 7.3999999999999995, 7.44983221287567, 7.49933330370107, 7.548509786706248, 7.597367965289032, 7.645913941446111, 7.694153624668538, 7.742092740338364, 7.789736837660179, 7.837091297158659, 7.884161337770809, 7.930952023559341, 7.977468270071652, 8.023714850367003, 8.069696400732806, 8.115417426109392, 8.160882305241266, 8.206095295571457, 8.251060537894508, 8.295782060782456, 8.340263784797218, 8.384509526501832, 8.42852300228219, 8.472307831990054, 8.515867542417507, 8.559205570612264, 8.602325267042627, 8.645229898620395], [0.0, 0.8660254037844387, 1.224744871391589, 1.5000000000000002, 1.7320508075688774, 1.9364916731037085, 2.121320343559643, 2.29128784747792, 2.449489742783178, 2.598076211353316, 2.7386127875258306, 2.8722813232690148, 3.0000000000000004, 3.122498999199199, 3.24037034920393, 3.3541019662496843, 3.464101615137755, 3.570714214271425, 3.6742346141747673, 3.7749172176353754, 3.872983346207417, 3.968626966596886, 4.06201920231798, 4.153311931459037, 4.242640687119286, 4.330127018922194, 4.415880433163924, 4.5, 4.58257569495584, 4.663689526544408, 4.743416490252569, 4.8218253804964775, 4.898979485566356, 4.974937185533101, 5.049752469181039, 5.123475382979799, 5.196152422706632, 5.26782687642637, 5.338539126015656, 5.408326913195984, 5.477225575051661, 5.545268253204709, 5.612486080160912, 5.678908345800274, 5.7445626465380295, 5.809475019311125, 5.873670062235366, 5.937171043518958, 6.000000000000001, 6.06217782649107, 6.123724356957946, 6.184658438426491, 6.244997998398398, 6.304760106459247, 6.363961030678928, 6.422616289332565, 6.48074069840786, 6.5383484153110105, 6.59545297913646, 6.652067347825035, 6.7082039324993685, 6.7638746292343415, 6.819090848492928, 6.87386354243376, 6.92820323027551, 6.98212002188447, 7.035623639735144, 7.088723439378913, 7.14142842854285, 7.19374728496908, 7.24568837309472, 7.297259759663212, 7.3484692283495345, 7.399324293474371, 7.44983221287567, 7.5, 7.549834435270751, 7.599342076785332, 7.6485292703891785, 7.697402159170327, 7.745966692414834, 7.794228634059948, 7.842193570679062, 7.88986691902975, 7.937253933193772, 7.984359711335657, 8.031189202104505, 8.077747210701757, 8.12403840463596, 8.170067319184096, 8.215838362577491, 8.261355820929154, 8.306623862918075, 8.351646544245034, 8.396427811873334, 8.440971508067065, 8.485281374238571, 8.529361054615991, 8.573214099741124, 8.616843969807043, 8.660254037844387, 8.703447592764606], [0.0, 0.8717797887081349, 1.2328828005937953, 1.5099668870541503, 1.7435595774162698, 1.9493588689617931, 2.1354156504062627, 2.3065125189341593, 2.4657656011875906, 2.615339366124404, 2.7568097504180447, 2.8913664589601926, 3.0199337741083006, 3.1432467291003428, 3.2619012860600183, 3.3763886032268267, 3.4871191548325395, 3.594440151122286, 3.6986484017813863, 3.8000000000000007, 3.8987177379235862, 3.9949968710876362, 4.0890096600521755, 4.180908992073375, 4.270831300812525, 4.358898943540674, 4.445222154178575, 4.529900661162451, 4.613025037868319, 4.694677837722201, 4.774934554525329, 4.8538644398046396, 4.931531202375181, 5.007993610219566, 5.083306010855535, 5.157518783291051, 5.230678732248808, 5.302829433425142, 5.374011537017762, 5.444263035526481, 5.513619500836089, 5.582114294781146, 5.649778756730215, 5.716642371182581, 5.782732917920385, 5.848076606885378, 5.912698199637794, 5.976621118993575, 6.039867548216601, 6.102458520956944, 6.164414002968978, 6.225752966509353, 6.2864934582006855, 6.3466526610489735, 6.406246951218788, 6.465291950097846, 6.523802572120037, 6.581793068761734, 6.639277069079134, 6.696267617113283, 6.752777206453653, 6.808817812219681, 6.864400920692206, 6.919537556802479, 6.974238309665079, 7.0285133563222315, 7.08237248385031, 7.13582510996451, 7.188880302244572, 7.2415467960926705, 7.293833011524189, 7.345747068882784, 7.397296803562773, 7.448489779814429, 7.49933330370107, 7.549834435270751, 7.600000000000001, 7.649836599562112, 7.6993506219680645, 7.748548251124208, 7.7974354758471724, 7.8460180983732135, 7.894301742396222, 7.942291860665913, 7.9899937421752725, 8.037412518964048, 8.084553172563096, 8.13142054010245, 8.178019320104351, 8.224354077980836, 8.270429251254134, 8.316249154516717, 8.36181798414675, 8.407139822793482, 8.452218643646177, 8.497058314499201, 8.54166260162505, 8.586035173466273, 8.630179604156568, 8.674099376880578, 8.717797887081348, 8.761278445523805], [0.0, 0.8774964387392122, 1.2409673645990857, 1.5198684153570665, 1.7549928774784245, 1.9621416870348585, 2.149418526020468, 2.32163735324878, 2.4819347291981715, 2.6324893162176366, 2.7748873851023217, 2.91032644217105, 3.039736830714133, 3.1638584039112754, 3.283291031876401, 3.3985290935932855, 3.509985754956849, 3.6180105030251086, 3.722902093797257, 3.824918299781056, 3.924283374069717, 4.02119385257662, 4.115823125451336, 4.2083250825001635, 4.298837052040936, 4.387482193696061, 4.474371464239419, 4.559605246071199, 4.64327470649756, 4.725462940284264, 4.806245936279166, 4.8856934001224435, 4.963869458396343, 5.040833264451424, 5.1166395221864125, 5.191338940966964, 5.264978632435273, 5.3376024580330075, 5.409251334519409, 5.479963503528103, 5.549774770204643, 5.61871871515206, 5.686826883245173, 5.754128952326321, 5.8206528843421, 5.886425061104575, 5.951470406546605, 6.015812497078014, 6.079473661428266, 6.142475071174486, 6.2048368229954285, 6.266578013557321, 6.327716807822551, 6.388270501473776, 6.448255578061404, 6.507687761409578, 6.566582063752802, 6.624952830020755, 6.682813778641449, 6.740178039191546, 6.797058187186571, 6.853466276272176, 6.90941386804988, 6.96491205974634, 7.019971509913698, 7.074602462329597, 7.128814768248646, 7.182617907142214, 7.236021006050217, 7.289032857656769, 7.341661937191062, 7.3939164182454755, 7.445804187594514, 7.4973328590906245, 7.548509786706248, 7.599342076785332, 7.649836599562112, 7.7, 7.749838707999026, 7.799358948016177, 7.848566748139434, 7.897467948652911, 7.9460682101275735, 7.994373021069257, 8.04238770515324, 8.090117428072352, 8.137567204023572, 8.184741901856162, 8.231646250902672, 8.278284846512591, 8.324662155306966, 8.370782520170978, 8.416650165000327, 8.462269199216012, 8.507643622061282, 8.55277732669336, 8.597674104081872, 8.64233764672499, 8.6867715521936, 8.73097932651315, 8.774964387392123, 8.81873006730561], [0.0, 0.8831760866327848, 1.2489995996796797, 1.5297058540778359, 1.7663521732655696, 1.9748417658131503, 2.1633307652783937, 2.336664289109585, 2.4979991993593593, 2.6495282598983545, 2.7928480087537886, 2.9291637031753623, 3.0594117081556718, 3.1843366656181322, 3.3045423283716615, 3.420526275297414, 3.532704346531139, 3.6414282912066254, 3.7469987990390394, 3.8496753109840323, 3.9496835316263006, 4.047221268969613, 4.1424630354415966, 4.235563716909475, 4.3266615305567875, 4.415880433163924, 4.503332099679082, 4.589117562233508, 4.67332857821917, 4.756048780237647, 4.83735464897913, 4.917316341257699, 4.995998398718719, 5.07346035758633, 5.149757275833494, 5.2249401910452535, 5.299056519796709, 5.372150407425318, 5.444263035526481, 5.515432893255072, 5.585696017507577, 5.655086206239478, 5.723635208501675, 5.791372894228104, 5.858327406350725, 5.92452529743945, 5.989991652748776, 6.054750201288242, 6.1188234163113435, 6.182232606429493, 6.244997998398399, 6.307138812488593, 6.3686733312362644, 6.429618962271405, 6.489992295835182, 6.549809157525127, 6.609084656743323, 6.667833231267862, 6.726068688320096, 6.783804242458652, 6.841052550594828, 6.897825744392215, 6.954135460285484, 7.009992867328754, 7.065408693062278, 7.12039324756716, 7.17495644586084, 7.229107828771128, 7.282856582413251, 7.336211556382492, 7.3891812807644675, 7.441773982055624, 7.493997598078079, 7.545859791965394, 7.597367965289032, 7.6485292703891785, 7.6993506219680645, 7.749838707999026, 7.800000000000002, 7.849840762716147, 7.899367063252601, 7.9485847796950635, 7.997499609252884, 8.046117075956577, 8.094442537939226, 8.142481194328914, 8.19023809177731, 8.23771813064759, 8.284926070883193, 8.33186653757728, 8.378544026261366, 8.424962907930219, 8.47112743381895, 8.517041739947036, 8.56270985144306, 8.608135686662937, 8.653323061113575, 8.698275691193055, 8.742997197757758, 8.787491109526087, 8.831760866327848, 8.875809822207776], [0.0, 0.8888194417315589, 1.2569805089976536, 1.5394804318340656, 1.7776388834631178, 1.9874606914351793, 2.177154105707724, 2.3515952032609695, 2.513961017995307, 2.6664583251946765, 2.8106938645110393, 2.9478805945967355, 3.078960863668131, 3.204684071792413, 3.3256578296631782, 3.442382895611701, 3.5552777669262356, 3.664696440361739, 3.7709415269929605, 3.874274125562104, 3.9749213828703587, 4.07308237088326, 4.168932717135166, 4.262628297189424, 4.354308211415448, 4.444097208657795, 4.532107677449864, 4.618441295502196, 4.703190406521939, 4.786439177509728, 4.868264577855234, 4.948737212663449, 5.027922035990614, 5.105878964487898, 5.182663407939976, 5.2583267300539625, 5.332916650389353, 5.406477596365309, 5.47905101272109, 5.550675634551168, 5.621387729022079, 5.691221310052879, 5.760208329565868, 5.8283788483591215, 5.895761189193471, 5.962382074305537, 6.028266749240615, 6.09343909463285, 6.157921727336262, 6.221736092120913, 6.284902544988268, 6.347440429023341, 6.409368143584826, 6.470703207534712, 6.5314623171231725, 6.591661399070799, 6.6513156593263565, 6.710439627923047, 6.76904720030818, 6.827151675479314, 6.884765791223402, 6.941901756723442, 6.998571282769077, 7.0547856097829085, 7.110555533852471, 7.165891430938652, 7.2208032794142785, 7.275300681071539, 7.329392880723478, 7.383088784512889, 7.436396977031284, 7.489325737341113, 7.541883053985921, 7.594076639065476, 7.645913941446111, 7.697402159170327, 7.748548251124208, 7.799358948016177, 7.849840762716147, 7.9, 7.949842765740717, 7.999374975584031, 8.048602363143555, 8.097530487747484, 8.14616474176652, 8.194510357550353, 8.242572413997951, 8.290355842785038, 8.337865434270332, 8.385105843100611, 8.432081593533118, 8.478797084492587, 8.525256594378847, 8.571464285639882, 8.61742420912421, 8.663140308225419, 8.708616422830897, 8.753856293085923, 8.798863562983575, 8.843641783790206, 8.88819441731559, 8.932524839036274], [0.0, 0.894427190999916, 1.2649110640673518, 1.549193338482967, 1.788854381999832, 2.0000000000000004, 2.1908902300206647, 2.366431913239847, 2.5298221281347035, 2.6832815729997477, 2.8284271247461903, 2.9664793948382657, 3.098386676965934, 3.22490309931942, 3.3466401061363023, 3.4641016151377544, 3.577708763999664, 3.687817782917155, 3.7947331922020555, 3.8987177379235862, 4.000000000000001, 4.09878030638384, 4.1952353926806065, 4.289522117905444, 4.3817804600413295, 4.47213595499958, 4.560701700396552, 4.647580015448901, 4.732863826479694, 4.8166378315169185, 4.898979485566357, 4.979959839195494, 5.059644256269407, 5.1380930314660525, 5.21536192416212, 5.291502622129181, 5.366563145999495, 5.440588203494178, 5.513619500836089, 5.585696017507577, 5.656854249492381, 5.727128425310542, 5.796550698475777, 5.865151319446072, 5.9329587896765315, 6.0, 6.066300355241241, 6.131883886702357, 6.196773353931868, 6.260990336999412, 6.324555320336759, 6.387487769068526, 6.44980619863884, 6.511528238439884, 6.572670690061994, 6.6332495807108005, 6.6932802122726045, 6.752777206453653, 6.811754546370562, 6.870225614927067, 6.928203230275509, 6.985699678629192, 7.042726744663604, 7.0992957397195395, 7.155417527999328, 7.211102550927978, 7.266360849833981, 7.321202087089251, 7.37563556583431, 7.429670248402685, 7.4833147735478835, 7.53657747256671, 7.589466384404111, 7.64198926981712, 7.694153624668538, 7.745966692414834, 7.7974354758471724, 7.848566748139434, 7.899367063252601, 7.949842765740717, 8.000000000000002, 8.049844718999244, 8.099382692526635, 8.148619514985345, 8.19756061276768, 8.246211251235321, 8.29457654133109, 8.342661445845685, 8.390470785361213, 8.438009243891594, 8.485281374238571, 8.532291603080617, 8.579044235810889, 8.62554346113913, 8.671793355471522, 8.717797887081348, 8.763560920082659, 8.809086218218098, 8.854377448471462, 8.899438184514796, 8.94427190999916, 8.988882021697695], [0.0, 0.9, 1.2727922061357855, 1.5588457268119897, 1.8, 2.012461179749811, 2.2045407685048604, 2.3811761799581315, 2.545584412271571, 2.7, 2.8460498941515415, 2.9849623113198605, 3.1176914536239795, 3.2449961479175906, 3.3674916480965473, 3.485685011586675, 3.6, 3.710795063055895, 3.8183766184073566, 3.9230090491866068, 4.024922359499622, 4.124318125460256, 4.221374183841087, 4.316248370981448, 4.409081537009721, 4.500000000000001, 4.589117562233507, 4.676537180435969, 4.762352359916263, 4.846648326421054, 4.929503017546495, 5.01098792654702, 5.091168824543142, 5.170106381884226, 5.247856705360771, 5.324471804789654, 5.4, 5.474486277268398, 5.547972602672079, 5.620498198558559, 5.692099788303083, 5.762811813689565, 5.832666628567075, 5.9016946718718, 5.969924622639721, 6.037383539249432, 6.104096984812742, 6.17008914036094, 6.235382907247959, 6.300000000000001, 6.3639610306789285, 6.427285585688566, 6.489992295835181, 6.552098900352467, 6.613622305514581, 6.674578638386097, 6.734983296193095, 6.794850991743675, 6.854195795277518, 6.913031173081747, 6.97137002317335, 7.029224708315989, 7.08660708661063, 7.143528539874395, 7.2, 7.256031973468694, 7.311634564172365, 7.366817494685205, 7.42159012611179, 7.475961476626268, 7.529940238806681, 7.583534795858723, 7.636753236814713, 7.689603370785778, 7.742092740338364, 7.794228634059948, 7.8460180983732135, 7.897467948652911, 7.9485847796950635, 7.999374975584031, 8.049844718999244, 8.100000000000001, 8.149846624323676, 8.19939022122987, 8.248636250920512, 8.2975900115636, 8.346256645946134, 8.394641147779934, 8.442748367682174, 8.490583018850943, 8.538149682454625, 8.58545281275251, 8.632496741962896, 8.67928568489366, 8.725823743349393, 8.772114910328067, 8.818163074019441, 8.863972021616496, 8.909545442950499, 8.95488693395958, 9.000000000000002, 9.044888059008803], [0.0, 0.9055385138137417, 1.2806248474865698, 1.5684387141358125, 1.8110770276274835, 2.024845673131659, 2.2181073012818837, 2.395829710142188, 2.5612496949731396, 2.716615541441225, 2.863564212655271, 3.003331483536242, 3.136877428271625, 3.264965543462902, 3.3882148692194836, 3.5071355833500366, 3.622154055254967, 3.733630940518894, 3.84187454245971, 3.947150871198111, 4.049691346263318, 4.149698784249287, 4.247352116319061, 4.342810150121694, 4.436214602563767, 4.527692569068709, 4.617358552246079, 4.705316142407438, 4.791659420284376, 4.876474136094644, 4.959838707054898, 5.041825066382213, 5.122499389946279, 5.201922721455982, 5.280151512977635, 5.35723809439155, 5.43323108288245, 5.508175741568166, 5.582114294781146, 5.655086206239478, 5.727128425310542, 5.798275605729691, 5.868560300448485, 5.938013135721409, 6.006662967072484, 6.074537019394977, 6.1416610131136355, 6.208059278067503, 6.27375485654325, 6.338769596696192, 6.403124237432849, 6.466838485689898, 6.529931086925804, 6.592419889539805, 6.654321903845651, 6.715653356152327, 6.776429738438967, 6.836665854054885, 6.8963758598266685, 6.955573304911681, 7.014271166700073, 7.07248188403477, 7.130217387990355, 7.187489130426565, 7.244308110509934, 7.300684899377592, 7.356629663099809, 7.4121521840825695, 7.467261881037788, 7.521967827636597, 7.576278769950325, 7.630203142774117, 7.68374908491942, 7.736924453553881, 7.789736837660179, 7.842193570679062, 7.894301742396222, 7.9460682101275735, 7.997499609252884, 8.048602363143555, 8.099382692526635, 8.149846624323676, 8.200000000000001, 8.249848483457136, 8.299397568498573, 8.348652585896723, 8.397618710086808, 8.446300965511472, 8.494704232638123, 8.542833253669418, 8.590692637965812, 8.638286867197687, 8.685620300243388, 8.732697177848321, 8.77952162705919, 8.826097665446492, 8.872429205127535, 8.918520056601322, 8.964373932405989, 9.009994450608726, 9.055385138137417, 9.100549433962767], [0.0, 0.9110433579144299, 1.2884098726725124, 1.5779733838059502, 1.8220867158288598, 2.0371548787463363, 2.2315913604421396, 2.41039415863879, 2.576819745345025, 2.7331300737432893, 2.8809720581775866, 3.0215889859476257, 3.1559467676119004, 3.2848135411313684, 3.408812109811862, 3.5284557528754696, 3.6441734316577197, 3.7563279941985894, 3.8652296180175374, 3.9711459303329564, 4.0743097574926725, 4.174925149029621, 4.273172123844299, 4.369210454990696, 4.463182720884279, 4.55521678957215, 4.645427859734774, 4.73392015141785, 4.82078831727758, 4.906118628814432, 4.9899899799498595, 5.072474741188959, 5.15363949069005, 5.23354564325181, 5.31224999411737, 5.389805191284746, 5.466260147486579, 5.541660400998964, 5.616048432839589, 5.68946394662977, 5.761944116355173, 5.833523806414096, 5.904235767650205, 5.974110812497538, 6.043177971895251, 6.111464636239008, 6.178996682310163, 6.245798587850876, 6.311893535223801, 6.377303505401009, 6.442049363362563, 6.506150935845249, 6.569627082262737, 6.632495759516172, 6.694774081326419, 6.756478372643548, 6.817624219623724, 6.878226515607057, 6.938299503480662, 6.997856814768361, 7.056911505750939, 7.115476090888086, 7.173562573784381, 7.23118247591637, 7.288346863315439, 7.345066371381541, 7.401351227985333, 7.457211275000863, 7.512655988397179, 7.567694497005016, 7.622335600063802, 7.676587783644501, 7.730459236035075, 7.783957862167549, 7.837091297158659, 7.88986691902975, 7.942291860665913, 7.994373021069257, 8.046117075956577, 8.097530487747484, 8.148619514985345, 8.19939022122987, 8.249848483457136, 8.299999999999999, 8.349850298059241, 8.399404740813482, 8.44866853415377, 8.49764673306675, 8.546344247688598, 8.594765849050223, 8.64291617453276, 8.690799733051039, 8.738420909981391, 8.78578397184907, 8.832893070789435, 8.879752248796134, 8.926365441768558, 8.972736483370054, 9.018869108707587, 9.064766957842878, 9.1104335791443, 9.155872432488342], [0.0, 0.9165151389911681, 1.2961481396815722, 1.5874507866387546, 1.8330302779823362, 2.04939015319192, 2.244994432064365, 2.4248711305964283, 2.5922962793631443, 2.749545416973504, 2.898275349237888, 3.039736830714133, 3.174901573277509, 3.3045423283716615, 3.4292856398964493, 3.5496478698597693, 3.6660605559646724, 3.778888725538237, 3.8884444190447165, 3.9949968710876362, 4.09878030638384, 4.2, 4.298837052040936, 4.3954521951671826, 4.48998886412873, 4.582575694955841, 4.67332857821917, 4.762352359916264, 4.849742261192857, 4.935585071701227, 5.019960159204453, 5.10294032886923, 5.184592558726289, 5.264978632435274, 5.344155686354956, 5.422176684690384, 5.499090833947008, 5.574943945906542, 5.649778756730214, 5.723635208501674, 5.796550698475776, 5.868560300448484, 5.939696961967, 6.009991680526688, 6.079473661428266, 6.148170459575759, 6.216108107168022, 6.2833112289620034, 6.349803146555018, 6.4156059729381765, 6.480740698407861, 6.54522726878143, 6.609084656743323, 6.672330927044912, 6.7349832961930955, 6.797058187186572, 6.858571279792899, 6.919537556802478, 6.97997134664606, 7.0398863627192165, 7.099295739719539, 7.158212067269313, 7.216647421067486, 7.274613391789285, 7.332121111929345, 7.389181280764467, 7.445804187594514, 7.501999733404421, 7.557777451076474, 7.6131465242697125, 7.668115805072326, 7.72269383052313, 7.776888838089433, 7.830708780180758, 7.884161337770809, 7.937253933193772, 7.9899937421752725, 8.04238770515324, 8.094442537939226, 8.14616474176652, 8.19756061276768, 8.248636250920512, 8.299397568498573, 8.349850298059241, 8.4, 8.449852069711044, 8.499411744350311, 8.548684109265006, 8.597674104081872, 8.646386528486914, 8.694826047713663, 8.742997197757758, 8.790904390334365, 8.838551917593742, 8.885943956609225, 8.933084573650918, 8.97997772825746, 9.026627277117408, 9.073036977771006, 9.119210492142399, 9.165151389911681, 9.210863151735564], [0.0, 0.9219544457292888, 1.3038404810405297, 1.5968719422671316, 1.8439088914585775, 2.0615528128088303, 2.2583179581272432, 2.4392621835300936, 2.6076809620810595, 2.765863337187866, 2.9154759474226504, 3.0577769702841313, 3.193743884534263, 3.3241540277189325, 3.449637662132068, 3.5707142142714248, 3.687817782917155, 3.8013155617496426, 3.9115214431215897, 4.018706259482024, 4.123105625617661, 4.224926034855522, 4.324349662087931, 4.421538193886829, 4.5166359162544865, 4.609772228646444, 4.701063709417264, 4.790615826801394, 4.878524367060187, 4.964876634922565, 5.049752469181039, 5.13322510708424, 5.215361924162119, 5.296225070746145, 5.375872022286245, 5.454356057317858, 5.531726674375732, 5.608029957123981, 5.68330889535313, 5.757603668193913, 5.830951894845301, 5.903388857258177, 5.974947698515863, 6.0456596000767355, 6.115553940568263, 6.18465843842649, 6.252999280345393, 6.320601237224193, 6.387487769068526, 6.4536811201050215, 6.519202405202649, 6.584071688552609, 6.648308055437865, 6.711929677819935, 6.77495387438173, 6.837397165588672, 6.899275324264136, 6.960603422117942, 7.021395872616784, 7.0816664705420855, 7.1414284285428495, 7.200694410957877, 7.259476565152615, 7.317786550590281, 7.37563556583431, 7.433034373659253, 7.489993324429602, 7.546522377890362, 7.602631123499285, 7.658328799418317, 7.713624310270757, 7.768526243760782, 7.823042886243179, 7.877182237323192, 7.930952023559341, 7.984359711335657, 8.037412518964048, 8.090117428072352, 8.142481194328914, 8.194510357550353, 8.246211251235321, 8.2975900115636, 8.348652585896723, 8.399404740813482, 8.449852069711044, 8.5, 8.549853799919623, 8.599418584997478, 8.648699324175862, 8.697700845625814, 8.746427842267952, 8.794884877018005, 8.843076387773658, 8.891006692158093, 8.938679992034618, 8.986100377805714, 9.033271832508973, 9.080198235721511, 9.126883367283709, 9.173330910852394, 9.219544457292889, 9.265527507918803], [0.0, 0.9273618495495705, 1.3114877048604001, 1.6062378404209012, 1.854723699099141, 2.0736441353327724, 2.2715633383201097, 2.4535688292770597, 2.6229754097208002, 2.7820855486487113, 2.932575659723036, 3.07571129984594, 3.2124756808418025, 3.343650699460098, 3.4698703145794947, 3.591656999213594, 3.709447398198282, 3.8236108588610325, 3.9344631145812006, 4.042276586281548, 4.147288270665545, 4.249705872175156, 4.349712634186309, 4.447471191587417, 4.543126676640219, 4.636809247747852, 4.7286361670147565, 4.818713521262704, 4.907137658554119, 4.993996395673509, 5.079370039680118, 5.163332257370235, 5.2459508194416005, 5.327288240746882, 5.40740233383831, 5.486346689738081, 5.5641710972974225, 5.640921910468182, 5.716642371182581, 5.791372894228104, 5.865151319446072, 5.93801313572141, 6.009991680526689, 6.081118318204308, 6.15142259969188, 6.220932405998316, 6.289674077406556, 6.357672530100934, 6.424951361683605, 6.491532946846993, 6.557438524302001, 6.62268827591938, 6.687301398920196, 6.751296171847301, 6.814690014960329, 6.87749954561976, 6.939740629158989, 7.001428425685718, 7.062577433203831, 7.123201527403251, 7.183313998427188, 7.242927584892728, 7.302054505411474, 7.3607064878311785, 7.418894796396564, 7.476630257007497, 7.533923280734945, 7.590783885739338, 7.647221717722065, 7.703246069028303, 7.75886589650833, 7.814089838234521, 7.868926229162401, 7.923383115816122, 7.977468270071652, 8.031189202104505, 8.084553172563096, 8.137567204023572, 8.19023809177731, 8.242572413997951, 8.29457654133109, 8.346256645946134, 8.397618710086808, 8.44866853415377, 8.499411744350311, 8.549853799919623, 8.600000000000001, 8.649855490122365, 8.699425268372618, 8.748714191239761, 8.79772697916911, 8.84646822183859, 8.894942383174834, 8.943153806124549, 8.99110671719561, 9.038805230781334, 9.086253353280439, 9.133454987024352, 9.180413934022802, 9.22713389953782, 9.273618495495704, 9.319871243745807], [0.0, 0.9327379053088816, 1.3190905958272918, 1.6155494421403516, 1.8654758106177631, 2.0856653614614213, 2.2847319317591728, 2.4677925358506134, 2.6381811916545836, 2.7982137159266447, 2.9495762407505253, 3.093541659651604, 3.231098884280703, 3.363034344160048, 3.4899856733230297, 3.6124783736376886, 3.7309516212355263, 3.845776904605882, 3.957271787481876, 4.065710270051225, 4.171330722922843, 4.274342054632503, 4.374928570845472, 4.473253849269009, 4.5694638635183455, 4.663689526544408, 4.756048780237647, 4.846648326421054, 4.935585071701227, 5.022947341949744, 5.10881590977792, 5.193264869039514, 5.276362383309167, 5.358171329847526, 5.4387498563548595, 5.518151864528558, 5.596427431853289, 5.673623181001714, 5.749782604586021, 5.8249463516842805, 5.8991524815010505, 5.9724366886556455, 6.044832503882966, 6.1163714733492105, 6.187083319303208, 6.256996084384263, 6.326136261573884, 6.394528911499267, 6.462197768561406, 6.529165337162171, 6.59545297913646, 6.661080993352356, 6.726068688320096, 6.790434448545985, 6.854195795277518, 6.917369442208505, 6.979971346646059, 7.042016756583302, 7.103520254071217, 7.164495795239188, 7.224956747275377, 7.284915922644544, 7.344385610791416, 7.40337760755184, 7.4619032424710525, 7.519973404208288, 7.577598564189054, 7.634788798650556, 7.691553809211764, 7.747902942086975, 7.803845206050669, 7.859389289251424, 7.914543574963752, 7.969316156358713, 8.023714850367003, 8.077747210701757, 8.13142054010245, 8.184741901856162, 8.23771813064759, 8.290355842785038, 8.342661445845685, 8.394641147779934, 8.446300965511472, 8.49764673306675, 8.548684109265006, 8.599418584997478, 8.649855490122365, 8.700000000000001, 8.749857141690944, 8.799431799837988, 8.848728722251575, 8.897752525216692, 8.946507698538017, 8.994998610338971, 9.043229511629129, 9.091204540653564, 9.138927727036691, 9.186402995732335, 9.233634170791044, 9.280624978954814, 9.327379053088816, 9.373899935459095], [0.0, 0.938083151964686, 1.3266499161421599, 1.6248076809271923, 1.876166303929372, 2.0976176963403033, 2.297825058615212, 2.4819347291981715, 2.6532998322843198, 2.814249455894058, 2.9664793948382653, 3.1112698372208096, 3.2496153618543846, 3.3823069050575527, 3.509985754956849, 3.63318042491699, 3.752332607858744, 3.867815921162743, 3.97994974842648, 4.0890096600521755, 4.1952353926806065, 4.298837052040936, 4.4, 4.498888751680798, 4.595650117230424, 4.69041575982343, 4.7833042972405595, 4.874423042781577, 4.963869458396343, 5.0517323761260355, 5.138093031466052, 5.223025942880239, 5.3065996645686395, 5.388877434122993, 5.469917732470938, 5.549774770204643, 5.628498911788116, 5.706137047074843, 5.782732917920384, 5.858327406350725, 5.932958789676531, 6.006662967072483, 6.079473661428266, 6.151422599691879, 6.222539674441619, 6.292853089020909, 6.362389488234747, 6.431174076325411, 6.499230723708769, 6.566582063752802, 6.6332495807108005, 6.6992536897776915, 6.764613810115105, 6.82934843158555, 6.8934751758456345, 6.957010852370435, 7.019971509913698, 7.0823724838503095, 7.144228439796701, 7.205553413860728, 7.26636084983398, 7.326663633605681, 7.386474125047755, 7.445804187594514, 7.504665215717488, 7.5630681604756145, 7.62102355330306, 7.678541528180987, 7.735631842325486, 7.792303895511263, 7.848566748139434, 7.904429138147802, 7.95989949685296, 8.014985963805552, 8.069696400732806, 8.12403840463596, 8.178019320104351, 8.231646250902672, 8.284926070883193, 8.337865434270332, 8.390470785361213, 8.442748367682174, 8.494704232638123, 8.546344247688598, 8.597674104081872, 8.648699324175862, 8.699425268372618, 8.749857141690944, 8.8, 8.849858755935035, 8.899438184514796, 8.948742928478838, 8.997777503361595, 9.046546302318914, 9.09505360072166, 9.143303560529969, 9.191300234460847, 9.23904756996088, 9.28654941299512, 9.333809511662428, 9.38083151964686, 9.427618999514142], [0.0, 0.9433981132056604, 1.3341664064126333, 1.6340134638368193, 1.8867962264113207, 2.1095023109728985, 2.3108440016582685, 2.495996794869737, 2.6683328128252666, 2.830194339616981, 2.9832867780352594, 3.1288975694324033, 3.2680269276736387, 3.4014702703389896, 3.529872518944558, 3.6537651812890215, 3.7735924528226414, 3.8897300677553446, 4.0024992192379, 4.112177038990418, 4.219004621945797, 4.323193264243457, 4.424929377967517, 4.524378410345448, 4.621688003316537, 4.716990566028302, 4.810405388322278, 4.902040391510457, 4.991993589739474, 5.0803543183522155, 5.167204273105525, 5.252618394667558, 5.336665625650533, 5.419409561935692, 5.500909015790026, 5.58121850495033, 5.660388679233962, 5.7384666941614295, 5.815496539419485, 5.8915193286621745, 5.966573556070519, 6.040695324215583, 6.113918547053109, 6.186275131288617, 6.2577951388648065, 6.328506932918695, 6.398437309218556, 6.4676116148080505, 6.536053855347277, 6.603786792439623, 6.670832032063167, 6.73721010508059, 6.802940540677979, 6.868041933477111, 6.932532004974806, 6.996427659884722, 7.059745037889116, 7.122499561249548, 7.184705978674423, 7.246378405796926, 7.307530362578043, 7.368174807915458, 7.428324171709255, 7.487990384609211, 7.547184905645283, 7.6059187479225665, 7.664202502543888, 7.722046360907191, 7.779460135510689, 7.836453279386026, 7.893034904268446, 7.949213797602879, 8.0049984384758, 8.060397012554654, 8.115417426109392, 8.170067319184096, 8.224354077980836, 8.278284846512591, 8.33186653757728, 8.385105843100611, 8.438009243891594, 8.490583018850943, 8.542833253669418, 8.594765849050223, 8.646386528486914, 8.697700845625814, 8.748714191239761, 8.799431799837988, 8.849858755935035, 8.899999999999999, 8.949860334105779, 8.99944442729661, 9.048756820690896, 9.097801932335084, 9.1465840618233, 9.195107394696377, 9.243376006633074, 9.291393867445294, 9.339164844888433, 9.38669270829721, 9.433981132056603, 9.481033698917013], [0.0, 0.9486832980505138, 1.3416407864998738, 1.6431676725154984, 1.8973665961010275, 2.121320343559643, 2.32379000772445, 2.5099800796022267, 2.6832815729997477, 2.846049894151541, 3.0, 3.146426544510455, 3.286335345030997, 3.420526275297414, 3.5496478698597693, 3.674234614174767, 3.794733192202055, 3.9115214431215892, 4.024922359499621, 4.135214625627067, 4.242640687119286, 4.347413023856832, 4.449719092257398, 4.549725266430931, 4.6475800154489, 4.743416490252569, 4.83735464897913, 4.929503017546495, 5.019960159204453, 5.10881590977792, 5.196152422706632, 5.282045058497703, 5.366563145999495, 5.449770637375486, 5.531726674375733, 5.612486080160912, 5.692099788303082, 5.770615218501404, 5.848076606885378, 5.92452529743945, 6.0, 6.074537019394977, 6.148170459575759, 6.220932405998315, 6.29285308902091, 6.363961030678928, 6.434283176858165, 6.5038450166036395, 6.572670690061994, 6.640783086353597, 6.708203932499369, 6.77495387438173, 6.841052550594828, 6.906518659932804, 6.971370023173351, 7.035623639735144, 7.099295739719539, 7.162401831787993, 7.224956747275378, 7.286974680894671, 7.348469228349534, 7.409453421137082, 7.469939758793239, 7.52994023880668, 7.58946638440411, 7.648529270389177, 7.707139547199077, 7.76530746332687, 7.8230428862431785, 7.880355321938218, 7.937253933193772, 7.993747556684537, 8.049844718999243, 8.105553651663778, 8.160882305241266, 8.215838362577491, 8.270429251254134, 8.324662155306966, 8.378544026261366, 8.432081593533118, 8.485281374238571, 8.538149682454625, 8.590692637965812, 8.64291617453276, 8.694826047713663, 8.746427842267952, 8.79772697916911, 8.848728722251575, 8.899438184514796, 8.949860334105779, 9.0, 9.049861877399014, 9.099450532861862, 9.148770409186145, 9.197825830053535, 9.246621004453464, 9.2951600308978, 9.343446901438464, 9.391485505499116, 9.439279633531365, 9.486832980505138, 9.534149149242424], [0.0, 0.9539392014169457, 1.349073756323204, 1.6522711641858308, 1.9078784028338913, 2.1330729007701543, 2.3366642891095846, 2.5238858928247927, 2.698147512646408, 2.8618176042508368, 3.0166206257996713, 3.1638584039112754, 3.3045423283716615, 3.439476704383968, 3.5693136595149495, 3.694590640382233, 3.8157568056677826, 3.9331920878594273, 4.047221268969612, 4.158124577258358, 4.266145801540309, 4.371498598878879, 4.474371464239419, 4.57493169347915, 4.673328578219169, 4.769696007084729, 4.864154602806124, 4.956813492557492, 5.047771785649585, 5.137119815616529, 5.224940191045253, 5.3113086899558, 5.396295025292816, 5.479963503528103, 5.562373594069352, 5.643580423808984, 5.7236352085016735, 5.8025856305616035, 5.880476171195663, 5.957348403442593, 6.0332412515993425, 6.1081912216301815, 6.182232606429493, 6.255397669213365, 6.327716807822551, 6.399218702310462, 6.469930447848725, 6.539877674696982, 6.609084656743323, 6.67757440991862, 6.745368781616021, 6.81248853210044, 6.878953408767936, 6.944782214007867, 7.009992867328754, 7.074602462329597, 7.138627319029899, 7.202083032012336, 7.264984514780469, 7.327346040688948, 7.389181280764466, 7.450503338701353, 7.511324783285569, 7.571657678474378, 7.631513611335565, 7.6909037180295, 7.749838707999025, 7.808328886515987, 7.866384175718855, 7.924014134263013, 7.981227975693966, 8.038034585643434, 8.094442537939225, 8.150460109711599, 8.206095295571457, 8.261355820929154, 8.316249154516717, 8.370782520170978, 8.424962907930219, 8.478797084492587, 8.532291603080617, 8.58545281275251, 8.638286867197687, 8.690799733051039, 8.742997197757758, 8.794884877018005, 8.84646822183859, 8.897752525216692, 8.948742928478838, 8.99944442729661, 9.049861877399014, 9.1, 9.1498633869583, 9.199456505685541, 9.248783703817493, 9.297849213662264, 9.346657156438338, 9.395211546314432, 9.443516294262428, 9.491575211733826, 9.539392014169458, 9.586970324351693], [0.0, 0.959166304662544, 1.3564659966250536, 1.6613247725836153, 1.918332609325088, 2.144761058952722, 2.349468024894146, 2.5377155080899043, 2.7129319932501073, 2.877498913987632, 3.0331501776206204, 3.1811947441173736, 3.3226495451672307, 3.458323293158117, 3.5888716889852725, 3.714835124201342, 3.836665218650176, 3.954743986657038, 4.069397989875161, 4.180908992073375, 4.289522117905444, 4.3954521951671826, 4.498888751680798, 4.6000000000000005, 4.698936049788292, 4.79583152331272, 4.8908077042549944, 4.983974317750846, 5.075431016179809, 5.165268628057984, 5.253570214625479, 5.340411969127476, 5.4258639865002145, 5.509990925582366, 5.592852581643825, 5.674504383644443, 5.754997827975264, 5.83438085832593, 5.912698199637794, 5.989991652748776, 6.066300355241241, 6.1416610131136355, 6.216108107168022, 6.289674077406555, 6.362389488234747, 6.434283176858165, 6.505382386916238, 6.575712889109439, 6.645299090334461, 6.714164132637808, 6.782329983125269, 6.8498175158174845, 6.916646586316234, 6.982836100038438, 7.0484040746824395, 7.113367697511497, 7.177743377970545, 7.24154679609267, 7.3047929470998705, 7.367496182557545, 7.429670248402684, 7.491328320131218, 7.552483035399683, 7.6131465242697125, 7.673330437300352, 7.733045971672482, 7.792303895511263, 7.851114570556209, 7.909487973314076, 7.967433714816837, 8.024961059095553, 8.082078940470701, 8.138795979750322, 8.195120499419152, 8.251060537894508, 8.306623862918075, 8.36181798414675, 8.416650165000327, 8.47112743381895, 8.525256594378847, 8.579044235810889, 8.632496741962896, 8.685620300243388, 8.738420909981391, 8.790904390334365, 8.843076387773658, 8.894942383174834, 8.946507698538017, 8.997777503361595, 9.048756820690896, 9.099450532861862, 9.1498633869583, 9.200000000000001, 9.249864863877743, 9.299462350050137, 9.348796714016196, 9.397872099576585, 9.446692542895637, 9.495261976375376, 9.54358423235212, 9.59166304662544, 9.639502061828715], [0.0, 0.9643650760992956, 1.3638181696985856, 1.670329308849007, 1.9287301521985911, 2.1563858652847827, 2.3622023622035435, 2.551470164434615, 2.727636339397171, 2.8930952282978866, 3.0495901363953815, 3.1984371183438958, 3.340658617698014, 3.4770677301427426, 3.6083237105337433, 3.7349698793966195, 3.8574603043971822, 3.976179070414209, 4.091454509095757, 4.203569911396741, 4.312771730569565, 4.419275958796871, 4.523273151159457, 4.624932431938872, 4.724404724407087, 4.821825380496478, 4.917316341257699, 5.0109879265470205, 5.10294032886923, 5.193264869039514, 5.282045058497703, 5.36935750346352, 5.455272678794342, 5.539855593785817, 5.62316636780382, 5.705260730238365, 5.786190456595773, 5.866003750424986, 5.944745579080741, 6.02245796996542, 6.099180272790763, 6.174949392505174, 6.249799996799899, 6.323764701504951, 6.3968742366877915, 6.469157595854347, 6.540642170307134, 6.611353870426239, 6.681317235396028, 6.750555532695069, 6.8190908484929285, 6.886944169949399, 6.954135460285485, 7.020683727387242, 7.0866070866106305, 7.15192281837549, 7.216647421067487, 7.280796659706959, 7.3443856107914165, 7.407428703673091, 7.469939758793239, 7.531932023060219, 7.593418202627852, 7.654410493303845, 7.7149206087943645, 7.774959806970066, 7.834538914320357, 7.893668348746355, 7.952358140828418, 8.010617953691215, 8.068457101577724, 8.125884567233282, 8.182909018191515, 8.239538822045807, 8.295782060782456, 8.351646544245034, 8.407139822793482, 8.462269199216012, 8.517041739947036, 8.571464285639882, 8.62554346113913, 8.67928568489366, 8.732697177848321, 8.78578397184907, 8.838551917593742, 8.891006692158093, 8.943153806124549, 8.994998610338971, 9.046546302318914, 9.097801932335084, 9.148770409186145, 9.199456505685541, 9.249864863877743, 9.3, 9.349866309204641, 9.39946807005588, 9.448809448814174, 9.497894503520243, 9.5467271878901, 9.595311355031686, 9.643650760992957, 9.691749068150704], [0.0, 0.9695359714832659, 1.3711309200802089, 1.6792855623746668, 1.9390719429665317, 2.1679483388678804, 2.374868417407584, 2.5651510676761324, 2.7422618401604177, 2.9086079144497976, 3.0659419433511785, 3.2155870381627056, 3.3585711247493335, 3.4957116585897072, 3.627671429443411, 3.7549966711037173, 3.8781438859330635, 3.9974992182613374, 4.113392760240627, 4.226109321823088, 4.335896677735761, 4.442971978304612, 4.54752680036083, 4.649731175025068, 4.749736834815168, 4.847679857416329, 4.943682837723311, 5.037856687124, 5.130302135352265, 5.221110992882646, 5.310367218940701, 5.398147830506312, 5.4845236803208355, 5.569560126257729, 5.653317610041029, 5.735852159879995, 5.817215828899595, 5.897457079114693, 5.976621118993575, 6.054750201288242, 6.131883886702357, 6.208059278067504, 6.283311228962004, 6.357672530100933, 6.431174076325411, 6.5038450166036395, 6.57571288910944, 6.646803743153547, 6.717142249498667, 6.786751800382861, 6.855654600401045, 6.923871749245506, 6.9914233171794145, 7.058328414008519, 7.124605252222751, 7.1902712048990205, 7.255342858886822, 7.31983606373804, 7.383765976789894, 7.447147104764348, 7.5099933422074345, 7.572318007057021, 7.634133873596926, 7.695453203028396, 7.756287771866127, 7.816648898345122, 7.8765474670060875, 7.935993951610599, 7.994998436522675, 8.053570636680355, 8.1117199162693, 8.16945530620004, 8.226785520481254, 8.283718971573094, 8.340263784797218, 8.396427811873334, 8.452218643646177, 8.507643622061282, 8.56270985144306, 8.61742420912421, 8.671793355471522, 8.725823743349393, 8.77952162705919, 8.832893070789435, 8.885943956609225, 8.938679992034618, 8.99110671719561, 9.043229511629129, 9.09505360072166, 9.1465840618233, 9.197825830053535, 9.248783703817493, 9.299462350050137, 9.349866309204641, 9.4, 9.44986772394196, 9.499473669630335, 9.548821916864929, 9.597916440561463, 9.646761114488118, 9.695359714832659, 9.743715923609434], [0.0, 0.9746794344808963, 1.378404875209022, 1.6881943016134133, 1.9493588689617927, 2.179449471770337, 2.3874672772626644, 2.578759391645525, 2.756809750418044, 2.9240383034426887, 3.082207001484488, 3.2326459750489227, 3.3763886032268267, 3.5142566781611158, 3.6469165057620936, 3.7749172176353745, 3.8987177379235853, 4.018706259482023, 4.135214625627066, 4.2485291572496005, 4.358898943540674, 4.466542286825459, 4.571651780264984, 4.674398357008098, 4.774934554525329, 4.873397172404482, 4.969909455915671, 5.06458290484024, 5.15751878329105, 5.2488093888042835, 5.338539126015655, 5.426785420486054, 5.513619500836088, 5.599107071667768, 5.683308895353129, 5.766281297335397, 5.848076606885377, 5.928743543112655, 6.008327554319921, 6.08687111741328, 6.164414002968976, 6.24099351065197, 6.316644678941503, 6.3914004725099165, 6.465291950097845, 6.53834841531101, 6.6105975524153635, 6.682065548915245, 6.752777206453653, 6.822756041366274, 6.892024376045111, 6.960603422117942, 7.0285133563222315, 7.095773389842717, 7.162401831787993, 7.2284161474004796, 7.293833011524187, 7.358668357794092, 7.4229374239582535, 7.486654793697916, 7.549834435270749, 7.6124897372673015, 7.674633541739956, 7.736278174936576, 7.797435475847171, 7.858116822750854, 7.918333157931661, 7.978095010715276, 8.037412518964047, 8.096295449154509, 8.154753215150045, 8.212794895770866, 8.270429251254132, 8.327664738688751, 8.384509526501832, 8.440971508067065, 8.497058314499201, 8.55277732669336, 8.608135686662937, 8.663140308225419, 8.717797887081348, 8.772114910328067, 8.826097665446492, 8.879752248796134, 8.933084573650918, 8.986100377805714, 9.038805230781334, 9.091204540653564, 9.143303560529969, 9.195107394696377, 9.246621004453464, 9.297849213662264, 9.348796714016196, 9.39946807005588, 9.44986772394196, 9.499999999999998, 9.549869109050658, 9.599479152537391, 9.648834126463154, 9.697937925146768, 9.746794344808963, 9.795407086997457], [0.0, 0.9797958971132713, 1.3856406460551018, 1.6970562748477143, 1.9595917942265426, 2.1908902300206647, 2.4000000000000004, 2.5922962793631443, 2.7712812921102037, 2.939387691339814, 3.0983866769659336, 3.2496153618543846, 3.3941125496954285, 3.532704346531139, 3.666060555964672, 3.794733192202055, 3.9191835884530852, 4.039801975344831, 4.156921938165306, 4.270831300812525, 4.3817804600413295, 4.48998886412873, 4.595650117230424, 4.698936049788292, 4.800000000000001, 4.898979485566357, 4.9959983987187195, 5.091168824543143, 5.184592558726289, 5.276362383309168, 5.366563145999495, 5.455272678794342, 5.542562584220407, 5.628498911788117, 5.713142742834281, 5.796550698475776, 5.878775382679628, 5.959865770300536, 6.0398675482166, 6.118823416311343, 6.196773353931867, 6.27375485654325, 6.349803146555018, 6.424951361683604, 6.499230723708769, 6.572670690061993, 6.64529909033446, 6.717142249498666, 6.788225099390857, 6.858571279792899, 6.92820323027551, 6.997142273814362, 7.065408693062278, 7.1330218000508046, 7.2, 7.266360849833981, 7.332121111929344, 7.397296803562772, 7.4619032424710525, 7.525955088890711, 7.58946638440411, 7.652450587883597, 7.714920608794364, 7.776888838089433, 7.8383671769061705, 7.899367063252599, 7.95989949685296, 8.019975062305368, 8.079603950689663, 8.138795979750322, 8.19756061276768, 8.255906976220118, 8.313843876330612, 8.37137981458254, 8.42852300228219, 8.485281374238571, 8.54166260162505, 8.597674104081872, 8.653323061113575, 8.708616422830897, 8.763560920082659, 8.818163074019441, 8.872429205127535, 8.926365441768558, 8.97997772825746, 9.033271832508973, 9.086253353280439, 9.138927727036691, 9.191300234460847, 9.243376006633074, 9.2951600308978, 9.346657156438338, 9.397872099576585, 9.448809448814174, 9.499473669630335, 9.549869109050658, 9.600000000000001, 9.649870465451857, 9.699484522385713, 9.748846085563153, 9.797958971132713, 9.846826900072939], [0.0, 0.9848857801796106, 1.392838827718412, 1.7058722109231985, 1.9697715603592212, 2.2022715545545246, 2.412467616362964, 2.6057628441590768, 2.785677655436824, 2.9546573405388314, 3.1144823004794877, 3.2664965942122155, 3.411744421846397, 3.5510561809129415, 3.685105154537656, 3.8144462245521304, 3.9395431207184424, 4.060788100849391, 4.178516483155236, 4.293017586733137, 4.404543109109049, 4.513313638558704, 4.61952378498044, 4.723346271447818, 4.824935232725928, 4.924428900898053, 5.021951811795889, 5.117616632769595, 5.2115256883181535, 5.3037722424704485, 5.394441583704471, 5.483611948342078, 5.571355310873648, 5.657738063926256, 5.742821606144492, 5.826662852782887, 5.909314681077663, 5.990826320300065, 6.071243694664217, 6.150609725872713, 6.228964600958975, 6.306346010171025, 6.38278935889318, 6.458327956987009, 6.532993188424431, 6.606814663663572, 6.679820356865895, 6.7520367297579185, 6.823488843692794, 6.894200461257274, 6.9641941385920605, 7.033491309442276, 7.102112361825883, 7.170076708097342, 7.237402849088892, 7.30410843293006, 7.370210309075312, 7.4357245780085215, 7.5006666370396715, 7.565051222562872, 7.628892449104261, 7.692203845452876, 7.754998388136519, 7.817288532477231, 7.879086241436885, 7.940403012442127, 8.001249902359007, 8.061637550770936, 8.121576201698781, 8.18107572388864, 8.240145629781066, 8.298795093265047, 8.357032966310472, 8.414867794564572, 8.472307831990054, 8.529361054615991, 8.586035173466273, 8.64233764672499, 8.698275691193055, 8.753856293085923, 8.809086218218098, 8.863972021616496, 8.918520056601322, 8.972736483370054, 9.026627277117408, 9.080198235721511, 9.133454987024352, 9.186402995732335, 9.23904756996088, 9.291393867445294, 9.343446901438464, 9.395211546314432, 9.446692542895637, 9.497894503520243, 9.548821916864929, 9.599479152537391, 9.649870465451857, 9.700000000000003, 9.749871794028884, 9.799489782636646, 9.848857801796106, 9.897979591815698], [0.0, 0.9899494936611666, 1.4, 1.7146428199482249, 1.9798989873223332, 2.2135943621178655, 2.4248711305964283, 2.619160170741759, 2.8, 2.9698484809834995, 3.1304951684997055, 3.283291031876401, 3.4292856398964497, 3.5693136595149495, 3.704051835490427, 3.8340579025361623, 3.9597979746446663, 4.08166632639171, 4.2, 4.315089802078284, 4.427188724235731, 4.536518488885503, 4.64327470649756, 4.747630988187688, 4.849742261192857, 4.949747468305833, 5.047771785649585, 5.143928459844674, 5.238320341483518, 5.331041174104736, 5.422176684690383, 5.511805511808268, 5.6, 5.686826883245173, 5.772347875864725, 5.856620185738529, 5.939696961966999, 6.021627686929839, 6.102458520956943, 6.182232606429493, 6.260990336999411, 6.338769596696192, 6.4156059729381765, 6.491532946846992, 6.566582063752802, 6.640783086353596, 6.714164132637808, 6.786751800382861, 6.8585712797928995, 6.929646455628165, 7.0, 7.069653456853455, 7.138627319029899, 7.206941098690901, 7.274613391789285, 7.341661937191061, 7.408103670980854, 7.473954776421918, 7.539230729988306, 7.603946343840151, 7.668115805072325, 7.731752712031082, 7.79487010796203, 7.857480512225277, 7.919595949289333, 7.981227975693965, 8.04238770515324, 8.103085831953157, 8.16333265278342, 8.223138087129511, 8.282511696339462, 8.341462701469089, 8.4, 8.4581321815162, 8.515867542417507, 8.573214099741124, 8.630179604156568, 8.6867715521936, 8.742997197757758, 8.798863562983575, 8.854377448471462, 8.909545442950499, 8.964373932405989, 9.018869108707587, 9.073036977771006, 9.126883367283709, 9.180413934022802, 9.233634170791044, 9.28654941299512, 9.339164844888433, 9.391485505499116, 9.443516294262428, 9.495261976375376, 9.5467271878901, 9.597916440561463, 9.648834126463154, 9.699484522385713, 9.749871794028884, 9.8, 9.849873095629203, 9.899494936611665, 9.948869282486328], [0.0, 0.9949874371066201, 1.407124727947029, 1.7233687939614089, 1.9899748742132402, 2.224859546128699, 2.4372115213907883, 2.632489316217637, 2.814249455894058, 2.98496231131986, 3.146426544510455, 3.3000000000000007, 3.4467375879228177, 3.58747822293042, 3.722902093797257, 3.853569773599539, 3.9799497484264803, 4.102438299353203, 4.221374183841087, 4.337049688440289, 4.449719092257398, 4.559605246071199, 4.666904755831214, 4.77179211617606, 4.874423042781577, 4.974937185533101, 5.073460357586329, 5.170106381884226, 5.264978632435274, 5.358171329847527, 5.449770637375485, 5.539855593785817, 5.628498911788116, 5.715767664977296, 5.801723881744115, 5.886425061104576, 5.96992462263972, 6.052272300549605, 6.133514490078262, 6.213694553162394, 6.29285308902091, 6.3710281744785915, 6.448255578061405, 6.524568951279464, 6.600000000000001, 6.674578638386096, 6.748333127521196, 6.821290200541244, 6.893475175845635, 6.96491205974634, 7.035623639735145, 7.105631569396208, 7.17495644586084, 7.243617880589783, 7.3116345641723655, 7.379024325749307, 7.445804187594514, 7.5119904153293495, 7.577598564189055, 7.642643521714199, 7.707139547199078, 7.771100308193172, 7.834538914320357, 7.897467948652911, 7.959899496852961, 8.021845174272563, 8.083316151184489, 8.144323176298936, 8.204876598706406, 8.264986388373547, 8.324662155306966, 8.383913167489272, 8.442748367682174, 8.501176389182852, 8.559205570612264, 8.616843969807043, 8.674099376880578, 8.73097932651315, 8.787491109526087, 8.843641783790206, 8.899438184514796, 8.95488693395958, 9.009994450608726, 9.064766957842878, 9.119210492142399, 9.173330910852394, 9.22713389953782, 9.280624978954814, 9.333809511662428, 9.38669270829721, 9.439279633531365, 9.491575211733826, 9.54358423235212, 9.595311355031686, 9.646761114488118, 9.697937925146768, 9.748846085563153, 9.799489782636646, 9.849873095629203, 9.900000000000002, 9.949874371066201, 9.999499987499377], [0.0, 1.0, 1.4142135623730951, 1.7320508075688776, 2.0, 2.23606797749979, 2.4494897427831783, 2.6457513110645907, 2.8284271247461903, 3.0, 3.1622776601683795, 3.3166247903554003, 3.4641016151377553, 3.6055512754639896, 3.7416573867739413, 3.8729833462074166, 4.0, 4.123105625617661, 4.242640687119286, 4.358898943540674, 4.47213595499958, 4.582575694955841, 4.69041575982343, 4.79583152331272, 4.898979485566357, 5.000000000000001, 5.099019513592785, 5.196152422706633, 5.291502622129181, 5.385164807134505, 5.477225575051661, 5.567764362830022, 5.656854249492381, 5.7445626465380295, 5.830951894845301, 5.916079783099616, 6.0, 6.08276253029822, 6.164414002968977, 6.244997998398399, 6.324555320336759, 6.403124237432849, 6.480740698407861, 6.557438524302, 6.6332495807108005, 6.7082039324993685, 6.782329983125269, 6.855654600401045, 6.9282032302755105, 7.0, 7.071067811865476, 7.141428428542851, 7.211102550927979, 7.28010988928052, 7.348469228349535, 7.416198487095664, 7.483314773547883, 7.54983443527075, 7.6157731058639095, 7.681145747868608, 7.745966692414833, 7.810249675906655, 7.874007874011811, 7.937253933193772, 8.0, 8.06225774829855, 8.12403840463596, 8.18535277187245, 8.246211251235321, 8.306623862918075, 8.366600265340756, 8.426149773176359, 8.485281374238571, 8.544003745317532, 8.602325267042627, 8.660254037844387, 8.717797887081348, 8.774964387392123, 8.831760866327848, 8.88819441731559, 8.94427190999916, 9.000000000000002, 9.055385138137417, 9.1104335791443, 9.165151389911681, 9.219544457292889, 9.273618495495704, 9.327379053088816, 9.38083151964686, 9.433981132056603, 9.486832980505138, 9.539392014169458, 9.59166304662544, 9.643650760992957, 9.695359714832659, 9.746794344808963, 9.797958971132713, 9.848857801796106, 9.899494936611665, 9.949874371066201, 10.000000000000002, 10.049875621120892], [0.0, 1.0049875621120892, 1.4212670403551897, 1.7406895185529214, 2.0099751242241783, 2.2472205054244236, 2.4617067250182347, 2.6589471600616665, 2.8425340807103794, 3.0149626863362675, 3.178049716414141, 3.333166662499792, 3.481379037105843, 3.6235341863986883, 3.7603191353926335, 3.892300091205713, 4.019950248448357, 4.1436698710201325, 4.263801121065569, 4.380639222761903, 4.494441010848847, 4.605431575867782, 4.713809499757071, 4.819751030914357, 4.9234134500364695, 5.024937810560446, 5.1244511901275835, 5.222068555658764, 5.317894320123333, 5.412023651093924, 5.504543577809154, 5.595533933415113, 5.685068161420759, 5.773214009544425, 5.860034129593445, 5.9455865984779, 6.029925372672535, 6.113100686231171, 6.1951594006934165, 6.276145313805283, 6.356099432828282, 6.435060217278469, 6.5130637951735135, 6.590144156238162, 6.666333324999584, 6.74166151627327, 6.81615727518079, 6.889847603539574, 6.962758074211686, 7.034912934784624, 7.1063352017759485, 7.177046746399247, 7.247068372797377, 7.31641988953614, 7.385120175054704, 7.4531872376856345, 7.520638270785267, 7.587489703452652, 7.653757247260983, 7.719455939378112, 7.784600182411426, 7.849203781276163, 7.913279977354524, 7.976841480185, 8.039900496896713, 8.10246875958186, 8.16455755078008, 8.226177727231525, 8.287339742040265, 8.34805366537614, 8.408329203831164, 8.468175718535841, 8.527602242131138, 8.586617494683225, 8.645229898620395, 8.703447592764606, 8.761278445523805, 8.81873006730561, 8.875809822207776, 8.932524839036274, 8.988882021697695, 9.044888059008803, 9.100549433962767, 9.155872432488342, 9.210863151735564, 9.265527507918803, 9.319871243745807, 9.373899935459095, 9.427618999514142, 9.481033698917013, 9.534149149242424, 9.586970324351693, 9.639502061828715, 9.691749068150704, 9.743715923609434, 9.795407086997457, 9.846826900072939, 9.897979591815698, 9.948869282486328, 9.999499987499377, 10.049875621120892, 10.100000000000001]]}],\n",
       "                        {\"autosize\": false, \"height\": 500, \"margin\": {\"b\": 65, \"l\": 65, \"r\": 50, \"t\": 90}, \"scene\": {\"xaxis\": {\"title\": {\"text\": \"K\"}}, \"yaxis\": {\"title\": {\"text\": \"L\"}}, \"zaxis\": {\"title\": {\"text\": \"Y\"}}}, \"template\": {\"data\": {\"bar\": [{\"error_x\": {\"color\": \"#2a3f5f\"}, \"error_y\": {\"color\": \"#2a3f5f\"}, \"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"bar\"}], \"barpolar\": [{\"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"barpolar\"}], \"carpet\": [{\"aaxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"baxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"type\": \"carpet\"}], \"choropleth\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"choropleth\"}], \"contour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"contour\"}], \"contourcarpet\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"contourcarpet\"}], \"heatmap\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmap\"}], \"heatmapgl\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmapgl\"}], \"histogram\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"histogram\"}], \"histogram2d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2d\"}], \"histogram2dcontour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2dcontour\"}], \"mesh3d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"mesh3d\"}], \"parcoords\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"parcoords\"}], \"scatter\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter\"}], \"scatter3d\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter3d\"}], \"scattercarpet\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattercarpet\"}], \"scattergeo\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergeo\"}], \"scattergl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergl\"}], \"scattermapbox\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattermapbox\"}], \"scatterpolar\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolar\"}], \"scatterpolargl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolargl\"}], \"scatterternary\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterternary\"}], \"surface\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"surface\"}], \"table\": [{\"cells\": {\"fill\": {\"color\": \"#EBF0F8\"}, \"line\": {\"color\": \"white\"}}, \"header\": {\"fill\": {\"color\": \"#C8D4E3\"}, \"line\": {\"color\": \"white\"}}, \"type\": \"table\"}]}, \"layout\": {\"annotationdefaults\": {\"arrowcolor\": \"#2a3f5f\", \"arrowhead\": 0, \"arrowwidth\": 1}, \"colorscale\": {\"diverging\": [[0, \"#8e0152\"], [0.1, \"#c51b7d\"], [0.2, \"#de77ae\"], [0.3, \"#f1b6da\"], [0.4, \"#fde0ef\"], [0.5, \"#f7f7f7\"], [0.6, \"#e6f5d0\"], [0.7, \"#b8e186\"], [0.8, \"#7fbc41\"], [0.9, \"#4d9221\"], [1, \"#276419\"]], \"sequential\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"sequentialminus\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]]}, \"colorway\": [\"#636efa\", \"#EF553B\", \"#00cc96\", \"#ab63fa\", \"#FFA15A\", \"#19d3f3\", \"#FF6692\", \"#B6E880\", \"#FF97FF\", \"#FECB52\"], \"font\": {\"color\": \"#2a3f5f\"}, \"geo\": {\"bgcolor\": \"white\", \"lakecolor\": \"white\", \"landcolor\": \"#E5ECF6\", \"showlakes\": true, \"showland\": true, \"subunitcolor\": \"white\"}, \"hoverlabel\": {\"align\": \"left\"}, \"hovermode\": \"closest\", \"mapbox\": {\"style\": \"light\"}, \"paper_bgcolor\": \"white\", \"plot_bgcolor\": \"#E5ECF6\", \"polar\": {\"angularaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"radialaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"scene\": {\"xaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"yaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"zaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}}, \"shapedefaults\": {\"line\": {\"color\": \"#2a3f5f\"}}, \"ternary\": {\"aaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"baxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"caxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"title\": {\"x\": 0.05}, \"xaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}, \"yaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}}}, \"title\": {\"text\": \"Cobb-Douglas Production Function\"}, \"width\": 500},\n",
       "                        {\"responsive\": true}\n",
       "                    )\n",
       "                };\n",
       "                \n",
       "            </script>\n",
       "        </div>\n",
       "</body>\n",
       "</html>"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "change_alpha(0.8, filename=\"fig2.html\")\n",
    "display(HTML(\"fig2.html\"))"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "\n",
    "The next plot has $\\alpha = 0.2$ (the purple-yellow surface) with $\\alpha=0.5$ for reference (the blue-yellow surface). What is the difference between the plot above and the one below?"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {
    "tags": [
     "remove_input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<html>\n",
       "<head><meta charset=\"utf-8\" /></head>\n",
       "<body>\n",
       "    <div>\n",
       "            <script src=\"https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.5/MathJax.js?config=TeX-AMS-MML_SVG\"></script><script type=\"text/javascript\">if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}</script>\n",
       "                <script type=\"text/javascript\">window.PlotlyConfig = {MathJaxConfig: 'local'};</script>\n",
       "        <script type=\"text/javascript\">/**\n",
       "* plotly.js v1.49.1\n",
       "* Copyright 2012-2019, Plotly, Inc.\n",
       "* All rights reserved.\n",
       "* Licensed under the MIT license\n",
       "*/\n",
       "!function(t){if(\"object\"==typeof exports&&\"undefined\"!=typeof module)module.exports=t();else if(\"function\"==typeof define&&define.amd)define([],t);else{(\"undefined\"!=typeof window?window:\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:this).Plotly=t()}}(function(){return function(){return function t(e,r,n){function i(o,s){if(!r[o]){if(!e[o]){var l=\"function\"==typeof require&&require;if(!s&&l)return l(o,!0);if(a)return a(o,!0);var c=new Error(\"Cannot find module '\"+o+\"'\");throw c.code=\"MODULE_NOT_FOUND\",c}var u=r[o]={exports:{}};e[o][0].call(u.exports,function(t){return i(e[o][1][t]||t)},u,u.exports,t,e,r,n)}return r[o].exports}for(var a=\"function\"==typeof require&&require,o=0;o<n.length;o++)i(n[o]);return i}}()({1:[function(t,e,r){\"use strict\";var n=t(\"../src/lib\"),i={\"X,X div\":\"direction:ltr;font-family:'Open Sans', verdana, arial, sans-serif;margin:0;padding:0;\",\"X input,X button\":\"font-family:'Open Sans', verdana, arial, sans-serif;\",\"X input:focus,X button:focus\":\"outline:none;\",\"X a\":\"text-decoration:none;\",\"X a:hover\":\"text-decoration:none;\",\"X .crisp\":\"shape-rendering:crispEdges;\",\"X .user-select-none\":\"-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;\",\"X svg\":\"overflow:hidden;\",\"X svg a\":\"fill:#447adb;\",\"X svg a:hover\":\"fill:#3c6dc5;\",\"X .main-svg\":\"position:absolute;top:0;left:0;pointer-events:none;\",\"X .main-svg .draglayer\":\"pointer-events:all;\",\"X .cursor-default\":\"cursor:default;\",\"X .cursor-pointer\":\"cursor:pointer;\",\"X .cursor-crosshair\":\"cursor:crosshair;\",\"X .cursor-move\":\"cursor:move;\",\"X .cursor-col-resize\":\"cursor:col-resize;\",\"X .cursor-row-resize\":\"cursor:row-resize;\",\"X .cursor-ns-resize\":\"cursor:ns-resize;\",\"X .cursor-ew-resize\":\"cursor:ew-resize;\",\"X .cursor-sw-resize\":\"cursor:sw-resize;\",\"X .cursor-s-resize\":\"cursor:s-resize;\",\"X .cursor-se-resize\":\"cursor:se-resize;\",\"X .cursor-w-resize\":\"cursor:w-resize;\",\"X .cursor-e-resize\":\"cursor:e-resize;\",\"X .cursor-nw-resize\":\"cursor:nw-resize;\",\"X .cursor-n-resize\":\"cursor:n-resize;\",\"X .cursor-ne-resize\":\"cursor:ne-resize;\",\"X .cursor-grab\":\"cursor:-webkit-grab;cursor:grab;\",\"X .modebar\":\"position:absolute;top:2px;right:2px;\",\"X .ease-bg\":\"-webkit-transition:background-color 0.3s ease 0s;-moz-transition:background-color 0.3s ease 0s;-ms-transition:background-color 0.3s ease 0s;-o-transition:background-color 0.3s ease 0s;transition:background-color 0.3s ease 0s;\",\"X .modebar--hover>:not(.watermark)\":\"opacity:0;-webkit-transition:opacity 0.3s ease 0s;-moz-transition:opacity 0.3s ease 0s;-ms-transition:opacity 0.3s ease 0s;-o-transition:opacity 0.3s ease 0s;transition:opacity 0.3s ease 0s;\",\"X:hover .modebar--hover .modebar-group\":\"opacity:1;\",\"X .modebar-group\":\"float:left;display:inline-block;box-sizing:border-box;padding-left:8px;position:relative;vertical-align:middle;white-space:nowrap;\",\"X .modebar-btn\":\"position:relative;font-size:16px;padding:3px 4px;height:22px;cursor:pointer;line-height:normal;box-sizing:border-box;\",\"X .modebar-btn svg\":\"position:relative;top:2px;\",\"X .modebar.vertical\":\"display:flex;flex-direction:column;flex-wrap:wrap;align-content:flex-end;max-height:100%;\",\"X .modebar.vertical svg\":\"top:-1px;\",\"X .modebar.vertical .modebar-group\":\"display:block;float:none;padding-left:0px;padding-bottom:8px;\",\"X .modebar.vertical .modebar-group .modebar-btn\":\"display:block;text-align:center;\",\"X [data-title]:before,X [data-title]:after\":\"position:absolute;-webkit-transform:translate3d(0, 0, 0);-moz-transform:translate3d(0, 0, 0);-ms-transform:translate3d(0, 0, 0);-o-transform:translate3d(0, 0, 0);transform:translate3d(0, 0, 0);display:none;opacity:0;z-index:1001;pointer-events:none;top:110%;right:50%;\",\"X [data-title]:hover:before,X [data-title]:hover:after\":\"display:block;opacity:1;\",\"X [data-title]:before\":\"content:'';position:absolute;background:transparent;border:6px solid transparent;z-index:1002;margin-top:-12px;border-bottom-color:#69738a;margin-right:-6px;\",\"X [data-title]:after\":\"content:attr(data-title);background:#69738a;color:white;padding:8px 10px;font-size:12px;line-height:12px;white-space:nowrap;margin-right:-18px;border-radius:2px;\",\"X .vertical [data-title]:before,X .vertical [data-title]:after\":\"top:0%;right:200%;\",\"X .vertical [data-title]:before\":\"border:6px solid transparent;border-left-color:#69738a;margin-top:8px;margin-right:-30px;\",\"X .select-outline\":\"fill:none;stroke-width:1;shape-rendering:crispEdges;\",\"X .select-outline-1\":\"stroke:white;\",\"X .select-outline-2\":\"stroke:black;stroke-dasharray:2px 2px;\",Y:\"font-family:'Open Sans';position:fixed;top:50px;right:20px;z-index:10000;font-size:10pt;max-width:180px;\",\"Y p\":\"margin:0;\",\"Y .notifier-note\":\"min-width:180px;max-width:250px;border:1px solid #fff;z-index:3000;margin:0;background-color:#8c97af;background-color:rgba(140,151,175,0.9);color:#fff;padding:10px;overflow-wrap:break-word;word-wrap:break-word;-ms-hyphens:auto;-webkit-hyphens:auto;hyphens:auto;\",\"Y .notifier-close\":\"color:#fff;opacity:0.8;float:right;padding:0 5px;background:none;border:none;font-size:20px;font-weight:bold;line-height:20px;\",\"Y .notifier-close:hover\":\"color:#444;text-decoration:none;cursor:pointer;\"};for(var a in i){var o=a.replace(/^,/,\" ,\").replace(/X/g,\".js-plotly-plot .plotly\").replace(/Y/g,\".plotly-notifier\");n.addStyleRule(o,i[a])}},{\"../src/lib\":719}],2:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/aggregate\")},{\"../src/transforms/aggregate\":1265}],3:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/bar\")},{\"../src/traces/bar\":864}],4:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/barpolar\")},{\"../src/traces/barpolar\":876}],5:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/box\")},{\"../src/traces/box\":886}],6:[function(t,e,r){\"use strict\";e.exports=t(\"../src/components/calendars\")},{\"../src/components/calendars\":591}],7:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/candlestick\")},{\"../src/traces/candlestick\":895}],8:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/carpet\")},{\"../src/traces/carpet\":914}],9:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choropleth\")},{\"../src/traces/choropleth\":928}],10:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choroplethmapbox\")},{\"../src/traces/choroplethmapbox\":935}],11:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/cone\")},{\"../src/traces/cone\":941}],12:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contour\")},{\"../src/traces/contour\":956}],13:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contourcarpet\")},{\"../src/traces/contourcarpet\":967}],14:[function(t,e,r){\"use strict\";e.exports=t(\"../src/core\")},{\"../src/core\":697}],15:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/densitymapbox\")},{\"../src/traces/densitymapbox\":977}],16:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/filter\")},{\"../src/transforms/filter\":1266}],17:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnel\")},{\"../src/traces/funnel\":987}],18:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnelarea\")},{\"../src/traces/funnelarea\":996}],19:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/groupby\")},{\"../src/transforms/groupby\":1267}],20:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmap\")},{\"../src/traces/heatmap\":1009}],21:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmapgl\")},{\"../src/traces/heatmapgl\":1018}],22:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram\")},{\"../src/traces/histogram\":1030}],23:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2d\")},{\"../src/traces/histogram2d\":1036}],24:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2dcontour\")},{\"../src/traces/histogram2dcontour\":1040}],25:[function(t,e,r){\"use strict\";var n=t(\"./core\");n.register([t(\"./bar\"),t(\"./box\"),t(\"./heatmap\"),t(\"./histogram\"),t(\"./histogram2d\"),t(\"./histogram2dcontour\"),t(\"./contour\"),t(\"./scatterternary\"),t(\"./violin\"),t(\"./funnel\"),t(\"./waterfall\"),t(\"./pie\"),t(\"./sunburst\"),t(\"./funnelarea\"),t(\"./scatter3d\"),t(\"./surface\"),t(\"./isosurface\"),t(\"./volume\"),t(\"./mesh3d\"),t(\"./cone\"),t(\"./streamtube\"),t(\"./scattergeo\"),t(\"./choropleth\"),t(\"./scattergl\"),t(\"./splom\"),t(\"./pointcloud\"),t(\"./heatmapgl\"),t(\"./parcoords\"),t(\"./parcats\"),t(\"./scattermapbox\"),t(\"./choroplethmapbox\"),t(\"./densitymapbox\"),t(\"./sankey\"),t(\"./indicator\"),t(\"./table\"),t(\"./carpet\"),t(\"./scattercarpet\"),t(\"./contourcarpet\"),t(\"./ohlc\"),t(\"./candlestick\"),t(\"./scatterpolar\"),t(\"./scatterpolargl\"),t(\"./barpolar\")]),n.register([t(\"./aggregate\"),t(\"./filter\"),t(\"./groupby\"),t(\"./sort\")]),n.register([t(\"./calendars\")]),e.exports=n},{\"./aggregate\":2,\"./bar\":3,\"./barpolar\":4,\"./box\":5,\"./calendars\":6,\"./candlestick\":7,\"./carpet\":8,\"./choropleth\":9,\"./choroplethmapbox\":10,\"./cone\":11,\"./contour\":12,\"./contourcarpet\":13,\"./core\":14,\"./densitymapbox\":15,\"./filter\":16,\"./funnel\":17,\"./funnelarea\":18,\"./groupby\":19,\"./heatmap\":20,\"./heatmapgl\":21,\"./histogram\":22,\"./histogram2d\":23,\"./histogram2dcontour\":24,\"./indicator\":26,\"./isosurface\":27,\"./mesh3d\":28,\"./ohlc\":29,\"./parcats\":30,\"./parcoords\":31,\"./pie\":32,\"./pointcloud\":33,\"./sankey\":34,\"./scatter3d\":35,\"./scattercarpet\":36,\"./scattergeo\":37,\"./scattergl\":38,\"./scattermapbox\":39,\"./scatterpolar\":40,\"./scatterpolargl\":41,\"./scatterternary\":42,\"./sort\":43,\"./splom\":44,\"./streamtube\":45,\"./sunburst\":46,\"./surface\":47,\"./table\":48,\"./violin\":49,\"./volume\":50,\"./waterfall\":51}],26:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/indicator\")},{\"../src/traces/indicator\":1046}],27:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/isosurface\")},{\"../src/traces/isosurface\":1052}],28:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/mesh3d\")},{\"../src/traces/mesh3d\":1057}],29:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/ohlc\")},{\"../src/traces/ohlc\":1062}],30:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcats\")},{\"../src/traces/parcats\":1071}],31:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcoords\")},{\"../src/traces/parcoords\":1081}],32:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pie\")},{\"../src/traces/pie\":1092}],33:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pointcloud\")},{\"../src/traces/pointcloud\":1101}],34:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sankey\")},{\"../src/traces/sankey\":1107}],35:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatter3d\")},{\"../src/traces/scatter3d\":1143}],36:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattercarpet\")},{\"../src/traces/scattercarpet\":1149}],37:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergeo\")},{\"../src/traces/scattergeo\":1156}],38:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergl\")},{\"../src/traces/scattergl\":1167}],39:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattermapbox\")},{\"../src/traces/scattermapbox\":1176}],40:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolar\")},{\"../src/traces/scatterpolar\":1183}],41:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolargl\")},{\"../src/traces/scatterpolargl\":1189}],42:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterternary\")},{\"../src/traces/scatterternary\":1196}],43:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/sort\")},{\"../src/transforms/sort\":1269}],44:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/splom\")},{\"../src/traces/splom\":1205}],45:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/streamtube\")},{\"../src/traces/streamtube\":1213}],46:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sunburst\")},{\"../src/traces/sunburst\":1219}],47:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/surface\")},{\"../src/traces/surface\":1228}],48:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/table\")},{\"../src/traces/table\":1236}],49:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/violin\")},{\"../src/traces/violin\":1244}],50:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/volume\")},{\"../src/traces/volume\":1252}],51:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/waterfall\")},{\"../src/traces/waterfall\":1260}],52:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).eye||[0,0,1],r=t.center||[0,0,0],s=t.up||[0,1,0],l=t.distanceLimits||[0,1/0],c=t.mode||\"turntable\",u=n(),h=i(),f=a();return u.setDistanceLimits(l[0],l[1]),u.lookAt(0,e,r,s),h.setDistanceLimits(l[0],l[1]),h.lookAt(0,e,r,s),f.setDistanceLimits(l[0],l[1]),f.lookAt(0,e,r,s),new o({turntable:u,orbit:h,matrix:f},c)};var n=t(\"turntable-camera-controller\"),i=t(\"orbit-camera-controller\"),a=t(\"matrix-camera-controller\");function o(t,e){this._controllerNames=Object.keys(t),this._controllerList=this._controllerNames.map(function(e){return t[e]}),this._mode=e,this._active=t[e],this._active||(this._mode=\"turntable\",this._active=t.turntable),this.modes=this._controllerNames,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}var s=o.prototype;[[\"flush\",1],[\"idle\",1],[\"lookAt\",4],[\"rotate\",4],[\"pan\",4],[\"translate\",4],[\"setMatrix\",2],[\"setDistanceLimits\",2],[\"setDistance\",2]].forEach(function(t){for(var e=t[0],r=[],n=0;n<t[1];++n)r.push(\"a\"+n);var i=\"var cc=this._controllerList;for(var i=0;i<cc.length;++i){cc[i].\"+t[0]+\"(\"+r.join()+\")}\";s[e]=Function.apply(null,r.concat(i))}),s.recalcMatrix=function(t){this._active.recalcMatrix(t)},s.getDistance=function(t){return this._active.getDistance(t)},s.getDistanceLimits=function(t){return this._active.getDistanceLimits(t)},s.lastT=function(){return this._active.lastT()},s.setMode=function(t){if(t!==this._mode){var e=this._controllerNames.indexOf(t);if(!(e<0)){var r=this._active,n=this._controllerList[e],i=Math.max(r.lastT(),n.lastT());r.recalcMatrix(i),n.setMatrix(i,r.computedMatrix),this._active=n,this._mode=t,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}}},s.getMode=function(){return this._mode}},{\"matrix-camera-controller\":433,\"orbit-camera-controller\":456,\"turntable-camera-controller\":542}],53:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n,i){\"use strict\";function a(t){return t.target.depth}function o(t,e){return t.sourceLinks.length?t.depth:e-1}function s(t){return function(){return t}}i=i&&i.hasOwnProperty(\"default\")?i.default:i;var l=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&\"function\"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?\"symbol\":typeof t};function c(t,e){return h(t.source,e.source)||t.index-e.index}function u(t,e){return h(t.target,e.target)||t.index-e.index}function h(t,e){return t.partOfCycle===e.partOfCycle?t.y0-e.y0:\"top\"===t.circularLinkType||\"bottom\"===e.circularLinkType?-1:1}function f(t){return t.value}function p(t){return(t.y0+t.y1)/2}function d(t){return p(t.source)}function g(t){return p(t.target)}function v(t){return t.index}function m(t){return t.nodes}function y(t){return t.links}function x(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function b(t,e){return e(t)}var _=25,w=10,k=.3;function T(t,e){var r=0,n=0;t.links.forEach(function(i){i.circular&&(i.source.circularLinkType||i.target.circularLinkType?i.circularLinkType=i.source.circularLinkType?i.source.circularLinkType:i.target.circularLinkType:i.circularLinkType=r<n?\"top\":\"bottom\",\"top\"==i.circularLinkType?r+=1:n+=1,t.nodes.forEach(function(t){b(t,e)!=b(i.source,e)&&b(t,e)!=b(i.target,e)||(t.circularLinkType=i.circularLinkType)}))}),t.links.forEach(function(t){t.circular&&(t.source.circularLinkType==t.target.circularLinkType&&(t.circularLinkType=t.source.circularLinkType),Y(t,e)&&(t.circularLinkType=t.source.circularLinkType))})}function A(t){var e=Math.abs(t.y1-t.y0),r=Math.abs(t.target.x0-t.source.x1);return Math.atan(r/e)}function M(t,e){var r=0;t.sourceLinks.forEach(function(t){r=t.circular&&!Y(t,e)?r+1:r});var n=0;return t.targetLinks.forEach(function(t){n=t.circular&&!Y(t,e)?n+1:n}),r+n}function S(t){var e=t.source.sourceLinks,r=0;e.forEach(function(t){r=t.circular?r+1:r});var n=t.target.targetLinks,i=0;return n.forEach(function(t){i=t.circular?i+1:i}),!(r>1||i>1)}function E(t,e,r){return t.sort(L),t.forEach(function(n,i){var a,o,s=0;if(Y(n,r)&&S(n))n.circularPathData.verticalBuffer=s+n.width/2;else{for(var l=0;l<i;l++)if(a=t[i],o=t[l],!(a.source.column<o.target.column||a.target.column>o.source.column)){var c=t[l].circularPathData.verticalBuffer+t[l].width/2+e;s=c>s?c:s}n.circularPathData.verticalBuffer=s+n.width/2}}),t}function C(t,r,i,a){var o=e.min(t.links,function(t){return t.source.y0});t.links.forEach(function(t){t.circular&&(t.circularPathData={})}),E(t.links.filter(function(t){return\"top\"==t.circularLinkType}),r,a),E(t.links.filter(function(t){return\"bottom\"==t.circularLinkType}),r,a),t.links.forEach(function(e){if(e.circular){if(e.circularPathData.arcRadius=e.width+w,e.circularPathData.leftNodeBuffer=5,e.circularPathData.rightNodeBuffer=5,e.circularPathData.sourceWidth=e.source.x1-e.source.x0,e.circularPathData.sourceX=e.source.x0+e.circularPathData.sourceWidth,e.circularPathData.targetX=e.target.x0,e.circularPathData.sourceY=e.y0,e.circularPathData.targetY=e.y1,Y(e,a)&&S(e))e.circularPathData.leftSmallArcRadius=w+e.width/2,e.circularPathData.leftLargeArcRadius=w+e.width/2,e.circularPathData.rightSmallArcRadius=w+e.width/2,e.circularPathData.rightLargeArcRadius=w+e.width/2,\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=e.source.y1+_+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=e.source.y0-_-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius);else{var s=e.source.column,l=e.circularLinkType,c=t.links.filter(function(t){return t.source.column==s&&t.circularLinkType==l});\"bottom\"==e.circularLinkType?c.sort(O):c.sort(P);var u=0;c.forEach(function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.leftSmallArcRadius=w+e.width/2+u,e.circularPathData.leftLargeArcRadius=w+e.width/2+n*r+u),u+=t.width}),s=e.target.column,c=t.links.filter(function(t){return t.target.column==s&&t.circularLinkType==l}),\"bottom\"==e.circularLinkType?c.sort(I):c.sort(z),u=0,c.forEach(function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.rightSmallArcRadius=w+e.width/2+u,e.circularPathData.rightLargeArcRadius=w+e.width/2+n*r+u),u+=t.width}),\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=Math.max(i,e.source.y1,e.target.y1)+_+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=o-_-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius)}e.circularPathData.leftInnerExtent=e.circularPathData.sourceX+e.circularPathData.leftNodeBuffer,e.circularPathData.rightInnerExtent=e.circularPathData.targetX-e.circularPathData.rightNodeBuffer,e.circularPathData.leftFullExtent=e.circularPathData.sourceX+e.circularPathData.leftLargeArcRadius+e.circularPathData.leftNodeBuffer,e.circularPathData.rightFullExtent=e.circularPathData.targetX-e.circularPathData.rightLargeArcRadius-e.circularPathData.rightNodeBuffer}if(e.circular)e.path=function(t){var e=\"\";e=\"top\"==t.circularLinkType?\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 0 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY-t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 0 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 0 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY-t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 0 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY:\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 1 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY+t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 1 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 1 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY+t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 1 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY;return e}(e);else{var h=n.linkHorizontal().source(function(t){return[t.source.x0+(t.source.x1-t.source.x0),t.y0]}).target(function(t){return[t.target.x0,t.y1]});e.path=h(e)}})}function L(t,e){return D(t)==D(e)?\"bottom\"==t.circularLinkType?O(t,e):P(t,e):D(e)-D(t)}function P(t,e){return t.y0-e.y0}function O(t,e){return e.y0-t.y0}function z(t,e){return t.y1-e.y1}function I(t,e){return e.y1-t.y1}function D(t){return t.target.column-t.source.column}function R(t){return t.target.x0-t.source.x1}function F(t,e){var r=A(t),n=R(e)/Math.tan(r);return\"up\"==G(t)?t.y1+n:t.y1-n}function B(t,e){var r=A(t),n=R(e)/Math.tan(r);return\"up\"==G(t)?t.y1-n:t.y1+n}function N(t,e,r,n){t.links.forEach(function(i){if(!i.circular&&i.target.column-i.source.column>1){var a=i.source.column+1,o=i.target.column-1,s=1,l=o-a+1;for(s=1;a<=o;a++,s++)t.nodes.forEach(function(o){if(o.column==a){var c,u=s/(l+1),h=Math.pow(1-u,3),f=3*u*Math.pow(1-u,2),p=3*Math.pow(u,2)*(1-u),d=Math.pow(u,3),g=h*i.y0+f*i.y0+p*i.y1+d*i.y1,v=g-i.width/2,m=g+i.width/2;v>o.y0&&v<o.y1?(c=o.y1-v+10,c=\"bottom\"==o.circularLinkType?c:-c,o=U(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&j(o,t)&&U(t,c,e,r)})):m>o.y0&&m<o.y1?(c=m-o.y0+10,o=U(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&U(t,c,e,r)})):v<o.y0&&m>o.y1&&(c=m-o.y0+10,o=U(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&U(t,c,e,r)}))}})}})}function j(t,e){return t.y0>e.y0&&t.y0<e.y1||(t.y1>e.y0&&t.y1<e.y1||t.y0<e.y0&&t.y1>e.y1)}function U(t,e,r,n){return t.y0+e>=r&&t.y1+e<=n&&(t.y0=t.y0+e,t.y1=t.y1+e,t.targetLinks.forEach(function(t){t.y1=t.y1+e}),t.sourceLinks.forEach(function(t){t.y0=t.y0+e})),t}function V(t,e,r,n){t.nodes.forEach(function(i){n&&i.y+(i.y1-i.y0)>e&&(i.y=i.y-(i.y+(i.y1-i.y0)-e));var a=t.links.filter(function(t){return b(t.source,r)==b(i,r)}),o=a.length;o>1&&a.sort(function(t,e){if(!t.circular&&!e.circular){if(t.target.column==e.target.column)return t.y1-e.y1;if(!H(t,e))return t.y1-e.y1;if(t.target.column>e.target.column){var r=B(e,t);return t.y1-r}if(e.target.column>t.target.column)return B(t,e)-e.y1}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.target.column===e.target.column?t.target.y1-e.target.y1:e.target.column-t.target.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.target.column===e.target.column?e.target.y1-t.target.y1:t.target.column-e.target.column:\"top\"==t.circularLinkType?-1:1:void 0});var s=i.y0;a.forEach(function(t){t.y0=s+t.width/2,s+=t.width}),a.forEach(function(t,e){if(\"bottom\"==t.circularLinkType){for(var r=e+1,n=0;r<o;r++)n+=a[r].width;t.y0=i.y1-n-t.width/2}})})}function q(t,e,r){t.nodes.forEach(function(e){var n=t.links.filter(function(t){return b(t.target,r)==b(e,r)}),i=n.length;i>1&&n.sort(function(t,e){if(!t.circular&&!e.circular){if(t.source.column==e.source.column)return t.y0-e.y0;if(!H(t,e))return t.y0-e.y0;if(e.source.column<t.source.column){var r=F(e,t);return t.y0-r}if(t.source.column<e.source.column)return F(t,e)-e.y0}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:t.source.column-e.source.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:e.source.column-t.source.column:\"top\"==t.circularLinkType?-1:1:void 0});var a=e.y0;n.forEach(function(t){t.y1=a+t.width/2,a+=t.width}),n.forEach(function(t,r){if(\"bottom\"==t.circularLinkType){for(var a=r+1,o=0;a<i;a++)o+=n[a].width;t.y1=e.y1-o-t.width/2}})})}function H(t,e){return G(t)==G(e)}function G(t){return t.y0-t.y1>0?\"up\":\"down\"}function Y(t,e){return b(t.source,e)==b(t.target,e)}t.sankeyCircular=function(){var t,n,a=0,b=0,A=1,S=1,E=24,L=v,P=o,O=m,z=y,I=32,D=2,R=null;function F(){var o={nodes:O.apply(null,arguments),links:z.apply(null,arguments)};!function(t){t.nodes.forEach(function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]});var e=r.map(t.nodes,L);t.links.forEach(function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!==(\"undefined\"==typeof n?\"undefined\":l(n))&&(n=t.source=x(e,n)),\"object\"!==(\"undefined\"==typeof i?\"undefined\":l(i))&&(i=t.target=x(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)})}(o),function(t,e,r){var n=0;if(null===r){for(var a=[],o=0;o<t.links.length;o++){var s=t.links[o],l=s.source.index,c=s.target.index;a[l]||(a[l]=[]),a[c]||(a[c]=[]),-1===a[l].indexOf(c)&&a[l].push(c)}var u=i(a);u.sort(function(t,e){return t.length-e.length});var h={};for(o=0;o<u.length;o++){var f=u[o],p=f.slice(-2);h[p[0]]||(h[p[0]]={}),h[p[0]][p[1]]=!0}t.links.forEach(function(t){var e=t.target.index,r=t.source.index;e===r||h[r]&&h[r][e]?(t.circular=!0,t.circularLinkID=n,n+=1):t.circular=!1})}else t.links.forEach(function(t){t.source[r]<t.target[r]?t.circular=!1:(t.circular=!0,t.circularLinkID=n,n+=1)})}(o,0,R),function(t){t.nodes.forEach(function(t){t.partOfCycle=!1,t.value=Math.max(e.sum(t.sourceLinks,f),e.sum(t.targetLinks,f)),t.sourceLinks.forEach(function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)}),t.targetLinks.forEach(function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)})})}(o),function(t){var e,r,n;for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach(function(t){t.depth=n,t.sourceLinks.forEach(function(t){r.indexOf(t.target)<0&&!t.circular&&r.push(t.target)})});for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach(function(t){t.height=n,t.targetLinks.forEach(function(t){r.indexOf(t.source)<0&&!t.circular&&r.push(t.source)})});t.nodes.forEach(function(t){t.column=Math.floor(P.call(null,t,n))})}(o),T(o,L),function(i,o,s){var l=r.nest().key(function(t){return t.column}).sortKeys(e.ascending).entries(i.nodes).map(function(t){return t.values});(function(r){if(n){var o=1/0;l.forEach(function(t){var e=S*n/(t.length+1);o=e<o?e:o}),t=o}var s=e.min(l,function(r){return(S-b-(r.length-1)*t)/e.sum(r,f)});s*=k,i.links.forEach(function(t){t.width=t.value*s});var c=function(t){var r=0,n=0,i=0,a=0,o=e.max(t.nodes,function(t){return t.column});return t.links.forEach(function(t){t.circular&&(\"top\"==t.circularLinkType?r+=t.width:n+=t.width,0==t.target.column&&(a+=t.width),t.source.column==o&&(i+=t.width))}),{top:r=r>0?r+_+w:r,bottom:n=n>0?n+_+w:n,left:a=a>0?a+_+w:a,right:i=i>0?i+_+w:i}}(i),u=function(t,r){var n=e.max(t.nodes,function(t){return t.column}),i=A-a,o=S-b,s=i+r.right+r.left,l=o+r.top+r.bottom,c=i/s,u=o/l;return a=a*c+r.left,A=0==r.right?A:A*c,b=b*u+r.top,S*=u,t.nodes.forEach(function(t){t.x0=a+t.column*((A-a-E)/n),t.x1=t.x0+E}),u}(i,c);s*=u,i.links.forEach(function(t){t.width=t.value*s}),l.forEach(function(t){var e=t.length;t.forEach(function(t,n){t.depth==l.length-1&&1==e?(t.y0=S/2-t.value*s,t.y1=t.y0+t.value*s):0==t.depth&&1==e?(t.y0=S/2-t.value*s,t.y1=t.y0+t.value*s):t.partOfCycle?0==M(t,r)?(t.y0=S/2+n,t.y1=t.y0+t.value*s):\"top\"==t.circularLinkType?(t.y0=b+n,t.y1=t.y0+t.value*s):(t.y0=S-t.value*s-n,t.y1=t.y0+t.value*s):0==c.top||0==c.bottom?(t.y0=(S-b)/e*n,t.y1=t.y0+t.value*s):(t.y0=(S-b)/2-e/2+n,t.y1=t.y0+t.value*s)})})})(s),m();for(var c=1,u=o;u>0;--u)v(c*=.99,s),m();function v(t,r){var n=l.length;l.forEach(function(i){var a=i.length,o=i[0].depth;i.forEach(function(i){var s;if(i.sourceLinks.length||i.targetLinks.length)if(i.partOfCycle&&M(i,r)>0);else if(0==o&&1==a)s=i.y1-i.y0,i.y0=S/2-s/2,i.y1=S/2+s/2;else if(o==n-1&&1==a)s=i.y1-i.y0,i.y0=S/2-s/2,i.y1=S/2+s/2;else{var l=e.mean(i.sourceLinks,g),c=e.mean(i.targetLinks,d),u=((l&&c?(l+c)/2:l||c)-p(i))*t;i.y0+=u,i.y1+=u}})})}function m(){l.forEach(function(e){var r,n,i,a=b,o=e.length;for(e.sort(h),i=0;i<o;++i)r=e[i],(n=a-r.y0)>0&&(r.y0+=n,r.y1+=n),a=r.y1+t;if((n=a-t-S)>0)for(a=r.y0-=n,r.y1-=n,i=o-2;i>=0;--i)r=e[i],(n=r.y1+t-a)>0&&(r.y0-=n,r.y1-=n),a=r.y0})}}(o,I,L),B(o);for(var s=0;s<4;s++)V(o,S,L),q(o,0,L),N(o,b,S,L),V(o,S,L),q(o,0,L);return function(t,r,n){var i=t.nodes,a=t.links,o=!1,s=!1;if(a.forEach(function(t){\"top\"==t.circularLinkType?o=!0:\"bottom\"==t.circularLinkType&&(s=!0)}),0==o||0==s){var l=e.min(i,function(t){return t.y0}),c=e.max(i,function(t){return t.y1}),u=c-l,h=n-r,f=h/u;i.forEach(function(t){var e=(t.y1-t.y0)*f;t.y0=(t.y0-l)*f,t.y1=t.y0+e}),a.forEach(function(t){t.y0=(t.y0-l)*f,t.y1=(t.y1-l)*f,t.width=t.width*f})}}(o,b,S),C(o,D,S,L),o}function B(t){t.nodes.forEach(function(t){t.sourceLinks.sort(u),t.targetLinks.sort(c)}),t.nodes.forEach(function(t){var e=t.y0,r=e,n=t.y1,i=n;t.sourceLinks.forEach(function(t){t.circular?(t.y0=n-t.width/2,n-=t.width):(t.y0=e+t.width/2,e+=t.width)}),t.targetLinks.forEach(function(t){t.circular?(t.y1=i-t.width/2,i-=t.width):(t.y1=r+t.width/2,r+=t.width)})})}return F.nodeId=function(t){return arguments.length?(L=\"function\"==typeof t?t:s(t),F):L},F.nodeAlign=function(t){return arguments.length?(P=\"function\"==typeof t?t:s(t),F):P},F.nodeWidth=function(t){return arguments.length?(E=+t,F):E},F.nodePadding=function(e){return arguments.length?(t=+e,F):t},F.nodes=function(t){return arguments.length?(O=\"function\"==typeof t?t:s(t),F):O},F.links=function(t){return arguments.length?(z=\"function\"==typeof t?t:s(t),F):z},F.size=function(t){return arguments.length?(a=b=0,A=+t[0],S=+t[1],F):[A-a,S-b]},F.extent=function(t){return arguments.length?(a=+t[0][0],A=+t[1][0],b=+t[0][1],S=+t[1][1],F):[[a,b],[A,S]]},F.iterations=function(t){return arguments.length?(I=+t,F):I},F.circularLinkGap=function(t){return arguments.length?(D=+t,F):D},F.nodePaddingRatio=function(t){return arguments.length?(n=+t,F):n},F.sortNodes=function(t){return arguments.length?(R=t,F):R},F.update=function(t){return T(t,L),B(t),t.links.forEach(function(t){t.circular&&(t.circularLinkType=t.y0+t.y1<S?\"top\":\"bottom\",t.source.circularLinkType=t.circularLinkType,t.target.circularLinkType=t.circularLinkType)}),V(t,S,L,!1),q(t,0,L),C(t,D,S,L),t},F},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,a)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=o,Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\"),t(\"elementary-circuits-directed-graph\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,null)},{\"d3-array\":152,\"d3-collection\":153,\"d3-shape\":161,\"elementary-circuits-directed-graph\":172}],54:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n){\"use strict\";function i(t){return t.target.depth}function a(t,e){return t.sourceLinks.length?t.depth:e-1}function o(t){return function(){return t}}function s(t,e){return c(t.source,e.source)||t.index-e.index}function l(t,e){return c(t.target,e.target)||t.index-e.index}function c(t,e){return t.y0-e.y0}function u(t){return t.value}function h(t){return(t.y0+t.y1)/2}function f(t){return h(t.source)*t.value}function p(t){return h(t.target)*t.value}function d(t){return t.index}function g(t){return t.nodes}function v(t){return t.links}function m(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function y(t){return[t.source.x1,t.y0]}function x(t){return[t.target.x0,t.y1]}t.sankey=function(){var t=0,n=0,i=1,y=1,x=24,b=8,_=d,w=a,k=g,T=v,A=32,M=2/3;function S(){var a={nodes:k.apply(null,arguments),links:T.apply(null,arguments)};return function(t){t.nodes.forEach(function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]});var e=r.map(t.nodes,_);t.links.forEach(function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!=typeof n&&(n=t.source=m(e,n)),\"object\"!=typeof i&&(i=t.target=m(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)})}(a),function(t){t.nodes.forEach(function(t){t.value=Math.max(e.sum(t.sourceLinks,u),e.sum(t.targetLinks,u))})}(a),function(e){var r,n,a;for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach(function(t){t.depth=a,t.sourceLinks.forEach(function(t){n.indexOf(t.target)<0&&n.push(t.target)})});for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach(function(t){t.height=a,t.targetLinks.forEach(function(t){n.indexOf(t.source)<0&&n.push(t.source)})});var o=(i-t-x)/(a-1);e.nodes.forEach(function(e){e.x1=(e.x0=t+Math.max(0,Math.min(a-1,Math.floor(w.call(null,e,a))))*o)+x})}(a),function(t){var i=r.nest().key(function(t){return t.x0}).sortKeys(e.ascending).entries(t.nodes).map(function(t){return t.values});(function(){var r=e.max(i,function(t){return t.length}),a=M*(y-n)/(r-1);b>a&&(b=a);var o=e.min(i,function(t){return(y-n-(t.length-1)*b)/e.sum(t,u)});i.forEach(function(t){t.forEach(function(t,e){t.y1=(t.y0=e)+t.value*o})}),t.links.forEach(function(t){t.width=t.value*o})})(),d();for(var a=1,o=A;o>0;--o)l(a*=.99),d(),s(a),d();function s(t){i.forEach(function(r){r.forEach(function(r){if(r.targetLinks.length){var n=(e.sum(r.targetLinks,f)/e.sum(r.targetLinks,u)-h(r))*t;r.y0+=n,r.y1+=n}})})}function l(t){i.slice().reverse().forEach(function(r){r.forEach(function(r){if(r.sourceLinks.length){var n=(e.sum(r.sourceLinks,p)/e.sum(r.sourceLinks,u)-h(r))*t;r.y0+=n,r.y1+=n}})})}function d(){i.forEach(function(t){var e,r,i,a=n,o=t.length;for(t.sort(c),i=0;i<o;++i)e=t[i],(r=a-e.y0)>0&&(e.y0+=r,e.y1+=r),a=e.y1+b;if((r=a-b-y)>0)for(a=e.y0-=r,e.y1-=r,i=o-2;i>=0;--i)e=t[i],(r=e.y1+b-a)>0&&(e.y0-=r,e.y1-=r),a=e.y0})}}(a),E(a),a}function E(t){t.nodes.forEach(function(t){t.sourceLinks.sort(l),t.targetLinks.sort(s)}),t.nodes.forEach(function(t){var e=t.y0,r=e;t.sourceLinks.forEach(function(t){t.y0=e+t.width/2,e+=t.width}),t.targetLinks.forEach(function(t){t.y1=r+t.width/2,r+=t.width})})}return S.update=function(t){return E(t),t},S.nodeId=function(t){return arguments.length?(_=\"function\"==typeof t?t:o(t),S):_},S.nodeAlign=function(t){return arguments.length?(w=\"function\"==typeof t?t:o(t),S):w},S.nodeWidth=function(t){return arguments.length?(x=+t,S):x},S.nodePadding=function(t){return arguments.length?(b=+t,S):b},S.nodes=function(t){return arguments.length?(k=\"function\"==typeof t?t:o(t),S):k},S.links=function(t){return arguments.length?(T=\"function\"==typeof t?t:o(t),S):T},S.size=function(e){return arguments.length?(t=n=0,i=+e[0],y=+e[1],S):[i-t,y-n]},S.extent=function(e){return arguments.length?(t=+e[0][0],i=+e[1][0],n=+e[0][1],y=+e[1][1],S):[[t,n],[i,y]]},S.iterations=function(t){return arguments.length?(A=+t,S):A},S},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,i)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=a,t.sankeyLinkHorizontal=function(){return n.linkHorizontal().source(y).target(x)},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3)},{\"d3-array\":152,\"d3-collection\":153,\"d3-shape\":161}],55:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\"),i=6378137;function a(t){var e=0;if(t&&t.length>0){e+=Math.abs(o(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(o(t[r]))}return e}function o(t){var e,r,n,a,o,l,c=0,u=t.length;if(u>2){for(l=0;l<u;l++)l===u-2?(n=u-2,a=u-1,o=0):l===u-1?(n=u-1,a=0,o=1):(n=l,a=l+1,o=l+2),e=t[n],r=t[a],c+=(s(t[o][0])-s(e[0]))*Math.sin(s(r[1]));c=c*i*i/2}return c}function s(t){return t*Math.PI/180}r.default=function(t){return n.geomReduce(t,function(t,e){return t+function(t){var e,r=0;switch(t.type){case\"Polygon\":return a(t.coordinates);case\"MultiPolygon\":for(e=0;e<t.coordinates.length;e++)r+=a(t.coordinates[e]);return r;case\"Point\":case\"MultiPoint\":case\"LineString\":case\"MultiLineString\":return 0}return 0}(e)},0)}},{\"@turf/meta\":58}],56:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\"),i=t(\"@turf/helpers\");r.default=function(t,e){void 0===e&&(e={});var r=0,a=0,o=0;return n.coordEach(t,function(t){r+=t[0],a+=t[1],o++}),i.point([r/o,a/o],e.properties)}},{\"@turf/helpers\":57,\"@turf/meta\":58}],57:[function(t,e,r){\"use strict\";function n(t,e,r){void 0===r&&(r={});var n={type:\"Feature\"};return(0===r.id||r.id)&&(n.id=r.id),r.bbox&&(n.bbox=r.bbox),n.properties=e||{},n.geometry=t,n}function i(t,e,r){return void 0===r&&(r={}),n({type:\"Point\",coordinates:t},e,r)}function a(t,e,r){void 0===r&&(r={});for(var i=0,a=t;i<a.length;i++){var o=a[i];if(o.length<4)throw new Error(\"Each LinearRing of a Polygon must have 4 or more Positions.\");for(var s=0;s<o[o.length-1].length;s++)if(o[o.length-1][s]!==o[0][s])throw new Error(\"First and last Position are not equivalent.\")}return n({type:\"Polygon\",coordinates:t},e,r)}function o(t,e,r){if(void 0===r&&(r={}),t.length<2)throw new Error(\"coordinates must be an array of two or more positions\");return n({type:\"LineString\",coordinates:t},e,r)}function s(t,e){void 0===e&&(e={});var r={type:\"FeatureCollection\"};return e.id&&(r.id=e.id),e.bbox&&(r.bbox=e.bbox),r.features=t,r}function l(t,e,r){return void 0===r&&(r={}),n({type:\"MultiLineString\",coordinates:t},e,r)}function c(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPoint\",coordinates:t},e,r)}function u(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPolygon\",coordinates:t},e,r)}function h(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t*n}function f(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t/n}function p(t){return 180*(t%(2*Math.PI))/Math.PI}function d(t){return!isNaN(t)&&null!==t&&!Array.isArray(t)&&!/^\\s*$/.test(t)}Object.defineProperty(r,\"__esModule\",{value:!0}),r.earthRadius=6371008.8,r.factors={centimeters:100*r.earthRadius,centimetres:100*r.earthRadius,degrees:r.earthRadius/111325,feet:3.28084*r.earthRadius,inches:39.37*r.earthRadius,kilometers:r.earthRadius/1e3,kilometres:r.earthRadius/1e3,meters:r.earthRadius,metres:r.earthRadius,miles:r.earthRadius/1609.344,millimeters:1e3*r.earthRadius,millimetres:1e3*r.earthRadius,nauticalmiles:r.earthRadius/1852,radians:1,yards:r.earthRadius/1.0936},r.unitsFactors={centimeters:100,centimetres:100,degrees:1/111325,feet:3.28084,inches:39.37,kilometers:.001,kilometres:.001,meters:1,metres:1,miles:1/1609.344,millimeters:1e3,millimetres:1e3,nauticalmiles:1/1852,radians:1/r.earthRadius,yards:1/1.0936},r.areaFactors={acres:247105e-9,centimeters:1e4,centimetres:1e4,feet:10.763910417,inches:1550.003100006,kilometers:1e-6,kilometres:1e-6,meters:1,metres:1,miles:3.86e-7,millimeters:1e6,millimetres:1e6,yards:1.195990046},r.feature=n,r.geometry=function(t,e,r){switch(void 0===r&&(r={}),t){case\"Point\":return i(e).geometry;case\"LineString\":return o(e).geometry;case\"Polygon\":return a(e).geometry;case\"MultiPoint\":return c(e).geometry;case\"MultiLineString\":return l(e).geometry;case\"MultiPolygon\":return u(e).geometry;default:throw new Error(t+\" is invalid\")}},r.point=i,r.points=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return i(t,e)}),r)},r.polygon=a,r.polygons=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return a(t,e)}),r)},r.lineString=o,r.lineStrings=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return o(t,e)}),r)},r.featureCollection=s,r.multiLineString=l,r.multiPoint=c,r.multiPolygon=u,r.geometryCollection=function(t,e,r){return void 0===r&&(r={}),n({type:\"GeometryCollection\",geometries:t},e,r)},r.round=function(t,e){if(void 0===e&&(e=0),e&&!(e>=0))throw new Error(\"precision must be a positive number\");var r=Math.pow(10,e||0);return Math.round(t*r)/r},r.radiansToLength=h,r.lengthToRadians=f,r.lengthToDegrees=function(t,e){return p(f(t,e))},r.bearingToAzimuth=function(t){var e=t%360;return e<0&&(e+=360),e},r.radiansToDegrees=p,r.degreesToRadians=function(t){return t%360*Math.PI/180},r.convertLength=function(t,e,r){if(void 0===e&&(e=\"kilometers\"),void 0===r&&(r=\"kilometers\"),!(t>=0))throw new Error(\"length must be a positive number\");return h(f(t,e),r)},r.convertArea=function(t,e,n){if(void 0===e&&(e=\"meters\"),void 0===n&&(n=\"kilometers\"),!(t>=0))throw new Error(\"area must be a positive number\");var i=r.areaFactors[e];if(!i)throw new Error(\"invalid original units\");var a=r.areaFactors[n];if(!a)throw new Error(\"invalid final units\");return t/i*a},r.isNumber=d,r.isObject=function(t){return!!t&&t.constructor===Object},r.validateBBox=function(t){if(!t)throw new Error(\"bbox is required\");if(!Array.isArray(t))throw new Error(\"bbox must be an Array\");if(4!==t.length&&6!==t.length)throw new Error(\"bbox must be an Array of 4 or 6 numbers\");t.forEach(function(t){if(!d(t))throw new Error(\"bbox must only contain numbers\")})},r.validateId=function(t){if(!t)throw new Error(\"id is required\");if(-1===[\"string\",\"number\"].indexOf(typeof t))throw new Error(\"id must be a number or a string\")},r.radians2degrees=function(){throw new Error(\"method has been renamed to `radiansToDegrees`\")},r.degrees2radians=function(){throw new Error(\"method has been renamed to `degreesToRadians`\")},r.distanceToDegrees=function(){throw new Error(\"method has been renamed to `lengthToDegrees`\")},r.distanceToRadians=function(){throw new Error(\"method has been renamed to `lengthToRadians`\")},r.radiansToDistance=function(){throw new Error(\"method has been renamed to `radiansToLength`\")},r.bearingToAngle=function(){throw new Error(\"method has been renamed to `bearingToAzimuth`\")},r.convertDistance=function(){throw new Error(\"method has been renamed to `convertLength`\")}},{}],58:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/helpers\");function i(t,e,r){if(null!==t)for(var n,a,o,s,l,c,u,h,f=0,p=0,d=t.type,g=\"FeatureCollection\"===d,v=\"Feature\"===d,m=g?t.features.length:1,y=0;y<m;y++){l=(h=!!(u=g?t.features[y].geometry:v?t.geometry:t)&&\"GeometryCollection\"===u.type)?u.geometries.length:1;for(var x=0;x<l;x++){var b=0,_=0;if(null!==(s=h?u.geometries[x]:u)){c=s.coordinates;var w=s.type;switch(f=!r||\"Polygon\"!==w&&\"MultiPolygon\"!==w?0:1,w){case null:break;case\"Point\":if(!1===e(c,p,y,b,_))return!1;p++,b++;break;case\"LineString\":case\"MultiPoint\":for(n=0;n<c.length;n++){if(!1===e(c[n],p,y,b,_))return!1;p++,\"MultiPoint\"===w&&b++}\"LineString\"===w&&b++;break;case\"Polygon\":case\"MultiLineString\":for(n=0;n<c.length;n++){for(a=0;a<c[n].length-f;a++){if(!1===e(c[n][a],p,y,b,_))return!1;p++}\"MultiLineString\"===w&&b++,\"Polygon\"===w&&_++}\"Polygon\"===w&&b++;break;case\"MultiPolygon\":for(n=0;n<c.length;n++){for(_=0,a=0;a<c[n].length;a++){for(o=0;o<c[n][a].length-f;o++){if(!1===e(c[n][a][o],p,y,b,_))return!1;p++}_++}b++}break;case\"GeometryCollection\":for(n=0;n<s.geometries.length;n++)if(!1===i(s.geometries[n],e,r))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}}}}}function a(t,e){var r;switch(t.type){case\"FeatureCollection\":for(r=0;r<t.features.length&&!1!==e(t.features[r].properties,r);r++);break;case\"Feature\":e(t.properties,0)}}function o(t,e){if(\"Feature\"===t.type)e(t,0);else if(\"FeatureCollection\"===t.type)for(var r=0;r<t.features.length&&!1!==e(t.features[r],r);r++);}function s(t,e){var r,n,i,a,o,s,l,c,u,h,f=0,p=\"FeatureCollection\"===t.type,d=\"Feature\"===t.type,g=p?t.features.length:1;for(r=0;r<g;r++){for(s=p?t.features[r].geometry:d?t.geometry:t,c=p?t.features[r].properties:d?t.properties:{},u=p?t.features[r].bbox:d?t.bbox:void 0,h=p?t.features[r].id:d?t.id:void 0,o=(l=!!s&&\"GeometryCollection\"===s.type)?s.geometries.length:1,i=0;i<o;i++)if(null!==(a=l?s.geometries[i]:s))switch(a.type){case\"Point\":case\"LineString\":case\"MultiPoint\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":if(!1===e(a,f,c,u,h))return!1;break;case\"GeometryCollection\":for(n=0;n<a.geometries.length;n++)if(!1===e(a.geometries[n],f,c,u,h))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}else if(!1===e(null,f,c,u,h))return!1;f++}}function l(t,e){s(t,function(t,r,i,a,o){var s,l=null===t?null:t.type;switch(l){case null:case\"Point\":case\"LineString\":case\"Polygon\":return!1!==e(n.feature(t,i,{bbox:a,id:o}),r,0)&&void 0}switch(l){case\"MultiPoint\":s=\"Point\";break;case\"MultiLineString\":s=\"LineString\";break;case\"MultiPolygon\":s=\"Polygon\"}for(var c=0;c<t.coordinates.length;c++){var u={type:s,coordinates:t.coordinates[c]};if(!1===e(n.feature(u,i),r,c))return!1}})}function c(t,e){l(t,function(t,r,a){var o=0;if(t.geometry){var s=t.geometry.type;if(\"Point\"!==s&&\"MultiPoint\"!==s){var l,c=0,u=0,h=0;return!1!==i(t,function(i,s,f,p,d){if(void 0===l||r>c||p>u||d>h)return l=i,c=r,u=p,h=d,void(o=0);var g=n.lineString([l,i],t.properties);if(!1===e(g,r,a,d,o))return!1;o++,l=i})&&void 0}}})}function u(t,e){if(!t)throw new Error(\"geojson is required\");l(t,function(t,r,i){if(null!==t.geometry){var a=t.geometry.type,o=t.geometry.coordinates;switch(a){case\"LineString\":if(!1===e(t,r,i,0,0))return!1;break;case\"Polygon\":for(var s=0;s<o.length;s++)if(!1===e(n.lineString(o[s],t.properties),r,i,s))return!1}}})}r.coordEach=i,r.coordReduce=function(t,e,r,n){var a=r;return i(t,function(t,n,i,o,s){a=0===n&&void 0===r?t:e(a,t,n,i,o,s)},n),a},r.propEach=a,r.propReduce=function(t,e,r){var n=r;return a(t,function(t,i){n=0===i&&void 0===r?t:e(n,t,i)}),n},r.featureEach=o,r.featureReduce=function(t,e,r){var n=r;return o(t,function(t,i){n=0===i&&void 0===r?t:e(n,t,i)}),n},r.coordAll=function(t){var e=[];return i(t,function(t){e.push(t)}),e},r.geomEach=s,r.geomReduce=function(t,e,r){var n=r;return s(t,function(t,i,a,o,s){n=0===i&&void 0===r?t:e(n,t,i,a,o,s)}),n},r.flattenEach=l,r.flattenReduce=function(t,e,r){var n=r;return l(t,function(t,i,a){n=0===i&&0===a&&void 0===r?t:e(n,t,i,a)}),n},r.segmentEach=c,r.segmentReduce=function(t,e,r){var n=r,i=!1;return c(t,function(t,a,o,s,l){n=!1===i&&void 0===r?t:e(n,t,a,o,s,l),i=!0}),n},r.lineEach=u,r.lineReduce=function(t,e,r){var n=r;return u(t,function(t,i,a,o){n=0===i&&void 0===r?t:e(n,t,i,a,o)}),n},r.findSegment=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.segmentIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":case\"MultiPoint\":return null;case\"LineString\":return s<0&&(s=c.length+s-1),n.lineString([c[s],c[s+1]],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s-1),n.lineString([c[o][s],c[o][s+1]],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s-1),n.lineString([c[a][s],c[a][s+1]],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s-1),n.lineString([c[a][o][s],c[a][o][s+1]],l,e)}throw new Error(\"geojson is invalid\")},r.findPoint=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.coordIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":return n.point(c,l,e);case\"MultiPoint\":return a<0&&(a=c.length+a),n.point(c[a],l,e);case\"LineString\":return s<0&&(s=c.length+s),n.point(c[s],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s),n.point(c[o][s],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s),n.point(c[a][s],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s),n.point(c[a][o][s],l,e)}throw new Error(\"geojson is invalid\")}},{\"@turf/helpers\":57}],59:[function(t,e,r){\"use strict\";var n=\"undefined\"==typeof WeakMap?t(\"weak-map\"):WeakMap,i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=new n;e.exports=function(t){var e=o.get(t),r=e&&(e._triangleBuffer.handle||e._triangleBuffer.buffer);if(!r||!t.isBuffer(r)){var n=i(t,new Float32Array([-1,-1,-1,4,4,-1]));(e=a(t,[{buffer:n,type:t.FLOAT,size:2}]))._triangleBuffer=n,o.set(t,e)}e.bind(),t.drawArrays(t.TRIANGLES,0,3),e.unbind()}},{\"gl-buffer\":241,\"gl-vao\":327,\"weak-map\":552}],60:[function(t,e,r){e.exports=function(t){var e=0,r=0,n=0,i=0;return t.map(function(t){var a=(t=t.slice())[0],o=a.toUpperCase();if(a!=o)switch(t[0]=o,a){case\"a\":t[6]+=n,t[7]+=i;break;case\"v\":t[1]+=i;break;case\"h\":t[1]+=n;break;default:for(var s=1;s<t.length;)t[s++]+=n,t[s++]+=i}switch(o){case\"Z\":n=e,i=r;break;case\"H\":n=t[1];break;case\"V\":i=t[1];break;case\"M\":n=e=t[1],i=r=t[2];break;default:n=t[t.length-2],i=t[t.length-1]}return t})}},{}],61:[function(t,e,r){var n=t(\"pad-left\");e.exports=function(t,e,r){e=\"number\"==typeof e?e:1,r=r||\": \";var i=t.split(/\\r?\\n/),a=String(i.length+e-1).length;return i.map(function(t,i){var o=i+e,s=String(o).length,l=n(o,a-s);return l+r+t}).join(\"\\n\")}},{\"pad-left\":457}],62:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[0];for(var r=t[0].length,n=[t[0]],a=[0],o=1;o<e;++o)if(n.push(t[o]),i(n,r)){if(a.push(o),a.length===r+1)return a}else n.pop();return a};var n=t(\"robust-orientation\");function i(t,e){for(var r=new Array(e+1),i=0;i<t.length;++i)r[i]=t[i];for(i=0;i<=t.length;++i){for(var a=t.length;a<=e;++a){for(var o=new Array(e),s=0;s<e;++s)o[s]=Math.pow(a+1-i,s);r[a]=o}if(n.apply(void 0,r))return!0}return!1}},{\"robust-orientation\":510}],63:[function(t,e,r){\"use strict\";e.exports=function(t,e){return n(e).filter(function(r){for(var n=new Array(r.length),a=0;a<r.length;++a)n[a]=e[r[a]];return i(n)*t<1})};var n=t(\"delaunay-triangulate\"),i=t(\"circumradius\")},{circumradius:114,\"delaunay-triangulate\":165}],64:[function(t,e,r){e.exports=function(t,e){return i(n(t,e))};var n=t(\"alpha-complex\"),i=t(\"simplicial-complex-boundary\")},{\"alpha-complex\":63,\"simplicial-complex-boundary\":517}],65:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(!t||null==t.length)throw Error(\"Argument should be an array\");e=null==e?1:Math.floor(e);for(var r=Array(2*e),n=0;n<e;n++){for(var i=-1/0,a=1/0,o=n,s=t.length;o<s;o+=e)t[o]>i&&(i=t[o]),t[o]<a&&(a=t[o]);r[n]=a,r[e+n]=i}return r}},{}],66:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\");e.exports=function(t,e,r){if(!t||null==t.length)throw Error(\"Argument should be an array\");null==e&&(e=1);null==r&&(r=n(t,e));for(var i=0;i<e;i++){var a=r[e+i],o=r[i],s=i,l=t.length;if(a===1/0&&o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:t[s]===o?0:.5;else if(a===1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:0;else if(o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===o?0:1;else{var c=a-o;for(s=i;s<l;s+=e)t[s]=0===c?.5:(t[s]-o)/c}}return t}},{\"array-bounds\":65}],67:[function(t,e,r){e.exports=function(t,e){var r=\"number\"==typeof t,n=\"number\"==typeof e;r&&!n?(e=t,t=0):r||n||(t=0,e=0);var i=(e|=0)-(t|=0);if(i<0)throw new Error(\"array length must be positive\");for(var a=new Array(i),o=0,s=t;o<i;o++,s++)a[o]=s;return a}},{}],68:[function(t,e,r){(function(r){\"use strict\";var n=t(\"object-assign\");function i(t,e){if(t===e)return 0;for(var r=t.length,n=e.length,i=0,a=Math.min(r,n);i<a;++i)if(t[i]!==e[i]){r=t[i],n=e[i];break}return r<n?-1:n<r?1:0}function a(t){return r.Buffer&&\"function\"==typeof r.Buffer.isBuffer?r.Buffer.isBuffer(t):!(null==t||!t._isBuffer)}var o=t(\"util/\"),s=Object.prototype.hasOwnProperty,l=Array.prototype.slice,c=\"foo\"===function(){}.name;function u(t){return Object.prototype.toString.call(t)}function h(t){return!a(t)&&(\"function\"==typeof r.ArrayBuffer&&(\"function\"==typeof ArrayBuffer.isView?ArrayBuffer.isView(t):!!t&&(t instanceof DataView||!!(t.buffer&&t.buffer instanceof ArrayBuffer))))}var f=e.exports=y,p=/\\s*function\\s+([^\\(\\s]*)\\s*/;function d(t){if(o.isFunction(t)){if(c)return t.name;var e=t.toString().match(p);return e&&e[1]}}function g(t,e){return\"string\"==typeof t?t.length<e?t:t.slice(0,e):t}function v(t){if(c||!o.isFunction(t))return o.inspect(t);var e=d(t);return\"[Function\"+(e?\": \"+e:\"\")+\"]\"}function m(t,e,r,n,i){throw new f.AssertionError({message:r,actual:t,expected:e,operator:n,stackStartFunction:i})}function y(t,e){t||m(t,!0,e,\"==\",f.ok)}function x(t,e,r,n){if(t===e)return!0;if(a(t)&&a(e))return 0===i(t,e);if(o.isDate(t)&&o.isDate(e))return t.getTime()===e.getTime();if(o.isRegExp(t)&&o.isRegExp(e))return t.source===e.source&&t.global===e.global&&t.multiline===e.multiline&&t.lastIndex===e.lastIndex&&t.ignoreCase===e.ignoreCase;if(null!==t&&\"object\"==typeof t||null!==e&&\"object\"==typeof e){if(h(t)&&h(e)&&u(t)===u(e)&&!(t instanceof Float32Array||t instanceof Float64Array))return 0===i(new Uint8Array(t.buffer),new Uint8Array(e.buffer));if(a(t)!==a(e))return!1;var s=(n=n||{actual:[],expected:[]}).actual.indexOf(t);return-1!==s&&s===n.expected.indexOf(e)||(n.actual.push(t),n.expected.push(e),function(t,e,r,n){if(null==t||null==e)return!1;if(o.isPrimitive(t)||o.isPrimitive(e))return t===e;if(r&&Object.getPrototypeOf(t)!==Object.getPrototypeOf(e))return!1;var i=b(t),a=b(e);if(i&&!a||!i&&a)return!1;if(i)return t=l.call(t),e=l.call(e),x(t,e,r);var s,c,u=k(t),h=k(e);if(u.length!==h.length)return!1;for(u.sort(),h.sort(),c=u.length-1;c>=0;c--)if(u[c]!==h[c])return!1;for(c=u.length-1;c>=0;c--)if(s=u[c],!x(t[s],e[s],r,n))return!1;return!0}(t,e,r,n))}return r?t===e:t==e}function b(t){return\"[object Arguments]\"==Object.prototype.toString.call(t)}function _(t,e){if(!t||!e)return!1;if(\"[object RegExp]\"==Object.prototype.toString.call(e))return e.test(t);try{if(t instanceof e)return!0}catch(t){}return!Error.isPrototypeOf(e)&&!0===e.call({},t)}function w(t,e,r,n){var i;if(\"function\"!=typeof e)throw new TypeError('\"block\" argument must be a function');\"string\"==typeof r&&(n=r,r=null),i=function(t){var e;try{t()}catch(t){e=t}return e}(e),n=(r&&r.name?\" (\"+r.name+\").\":\".\")+(n?\" \"+n:\".\"),t&&!i&&m(i,r,\"Missing expected exception\"+n);var a=\"string\"==typeof n,s=!t&&i&&!r;if((!t&&o.isError(i)&&a&&_(i,r)||s)&&m(i,r,\"Got unwanted exception\"+n),t&&i&&r&&!_(i,r)||!t&&i)throw i}f.AssertionError=function(t){var e;this.name=\"AssertionError\",this.actual=t.actual,this.expected=t.expected,this.operator=t.operator,t.message?(this.message=t.message,this.generatedMessage=!1):(this.message=g(v((e=this).actual),128)+\" \"+e.operator+\" \"+g(v(e.expected),128),this.generatedMessage=!0);var r=t.stackStartFunction||m;if(Error.captureStackTrace)Error.captureStackTrace(this,r);else{var n=new Error;if(n.stack){var i=n.stack,a=d(r),o=i.indexOf(\"\\n\"+a);if(o>=0){var s=i.indexOf(\"\\n\",o+1);i=i.substring(s+1)}this.stack=i}}},o.inherits(f.AssertionError,Error),f.fail=m,f.ok=y,f.equal=function(t,e,r){t!=e&&m(t,e,r,\"==\",f.equal)},f.notEqual=function(t,e,r){t==e&&m(t,e,r,\"!=\",f.notEqual)},f.deepEqual=function(t,e,r){x(t,e,!1)||m(t,e,r,\"deepEqual\",f.deepEqual)},f.deepStrictEqual=function(t,e,r){x(t,e,!0)||m(t,e,r,\"deepStrictEqual\",f.deepStrictEqual)},f.notDeepEqual=function(t,e,r){x(t,e,!1)&&m(t,e,r,\"notDeepEqual\",f.notDeepEqual)},f.notDeepStrictEqual=function t(e,r,n){x(e,r,!0)&&m(e,r,n,\"notDeepStrictEqual\",t)},f.strictEqual=function(t,e,r){t!==e&&m(t,e,r,\"===\",f.strictEqual)},f.notStrictEqual=function(t,e,r){t===e&&m(t,e,r,\"!==\",f.notStrictEqual)},f.throws=function(t,e,r){w(!0,t,e,r)},f.doesNotThrow=function(t,e,r){w(!1,t,e,r)},f.ifError=function(t){if(t)throw t},f.strict=n(function t(e,r){e||m(e,!0,r,\"==\",t)},f,{equal:f.strictEqual,deepEqual:f.deepStrictEqual,notEqual:f.notStrictEqual,notDeepEqual:f.notDeepStrictEqual}),f.strict.strict=f.strict;var k=Object.keys||function(t){var e=[];for(var r in t)s.call(t,r)&&e.push(r);return e}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"object-assign\":454,\"util/\":71}],69:[function(t,e,r){\"function\"==typeof Object.create?e.exports=function(t,e){t.super_=e,t.prototype=Object.create(e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}})}:e.exports=function(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}},{}],70:[function(t,e,r){e.exports=function(t){return t&&\"object\"==typeof t&&\"function\"==typeof t.copy&&\"function\"==typeof t.fill&&\"function\"==typeof t.readUInt8}},{}],71:[function(t,e,r){(function(e,n){var i=/%[sdj%]/g;r.format=function(t){if(!m(t)){for(var e=[],r=0;r<arguments.length;r++)e.push(s(arguments[r]));return e.join(\" \")}r=1;for(var n=arguments,a=n.length,o=String(t).replace(i,function(t){if(\"%%\"===t)return\"%\";if(r>=a)return t;switch(t){case\"%s\":return String(n[r++]);case\"%d\":return Number(n[r++]);case\"%j\":try{return JSON.stringify(n[r++])}catch(t){return\"[Circular]\"}default:return t}}),l=n[r];r<a;l=n[++r])g(l)||!b(l)?o+=\" \"+l:o+=\" \"+s(l);return o},r.deprecate=function(t,i){if(y(n.process))return function(){return r.deprecate(t,i).apply(this,arguments)};if(!0===e.noDeprecation)return t;var a=!1;return function(){if(!a){if(e.throwDeprecation)throw new Error(i);e.traceDeprecation?console.trace(i):console.error(i),a=!0}return t.apply(this,arguments)}};var a,o={};function s(t,e){var n={seen:[],stylize:c};return arguments.length>=3&&(n.depth=arguments[2]),arguments.length>=4&&(n.colors=arguments[3]),d(e)?n.showHidden=e:e&&r._extend(n,e),y(n.showHidden)&&(n.showHidden=!1),y(n.depth)&&(n.depth=2),y(n.colors)&&(n.colors=!1),y(n.customInspect)&&(n.customInspect=!0),n.colors&&(n.stylize=l),u(n,t,n.depth)}function l(t,e){var r=s.styles[e];return r?\"\\x1b[\"+s.colors[r][0]+\"m\"+t+\"\\x1b[\"+s.colors[r][1]+\"m\":t}function c(t,e){return t}function u(t,e,n){if(t.customInspect&&e&&k(e.inspect)&&e.inspect!==r.inspect&&(!e.constructor||e.constructor.prototype!==e)){var i=e.inspect(n,t);return m(i)||(i=u(t,i,n)),i}var a=function(t,e){if(y(e))return t.stylize(\"undefined\",\"undefined\");if(m(e)){var r=\"'\"+JSON.stringify(e).replace(/^\"|\"$/g,\"\").replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"')+\"'\";return t.stylize(r,\"string\")}if(v(e))return t.stylize(\"\"+e,\"number\");if(d(e))return t.stylize(\"\"+e,\"boolean\");if(g(e))return t.stylize(\"null\",\"null\")}(t,e);if(a)return a;var o=Object.keys(e),s=function(t){var e={};return t.forEach(function(t,r){e[t]=!0}),e}(o);if(t.showHidden&&(o=Object.getOwnPropertyNames(e)),w(e)&&(o.indexOf(\"message\")>=0||o.indexOf(\"description\")>=0))return h(e);if(0===o.length){if(k(e)){var l=e.name?\": \"+e.name:\"\";return t.stylize(\"[Function\"+l+\"]\",\"special\")}if(x(e))return t.stylize(RegExp.prototype.toString.call(e),\"regexp\");if(_(e))return t.stylize(Date.prototype.toString.call(e),\"date\");if(w(e))return h(e)}var c,b=\"\",T=!1,A=[\"{\",\"}\"];(p(e)&&(T=!0,A=[\"[\",\"]\"]),k(e))&&(b=\" [Function\"+(e.name?\": \"+e.name:\"\")+\"]\");return x(e)&&(b=\" \"+RegExp.prototype.toString.call(e)),_(e)&&(b=\" \"+Date.prototype.toUTCString.call(e)),w(e)&&(b=\" \"+h(e)),0!==o.length||T&&0!=e.length?n<0?x(e)?t.stylize(RegExp.prototype.toString.call(e),\"regexp\"):t.stylize(\"[Object]\",\"special\"):(t.seen.push(e),c=T?function(t,e,r,n,i){for(var a=[],o=0,s=e.length;o<s;++o)S(e,String(o))?a.push(f(t,e,r,n,String(o),!0)):a.push(\"\");return i.forEach(function(i){i.match(/^\\d+$/)||a.push(f(t,e,r,n,i,!0))}),a}(t,e,n,s,o):o.map(function(r){return f(t,e,n,s,r,T)}),t.seen.pop(),function(t,e,r){if(t.reduce(function(t,e){return 0,e.indexOf(\"\\n\")>=0&&0,t+e.replace(/\\u001b\\[\\d\\d?m/g,\"\").length+1},0)>60)return r[0]+(\"\"===e?\"\":e+\"\\n \")+\" \"+t.join(\",\\n  \")+\" \"+r[1];return r[0]+e+\" \"+t.join(\", \")+\" \"+r[1]}(c,b,A)):A[0]+b+A[1]}function h(t){return\"[\"+Error.prototype.toString.call(t)+\"]\"}function f(t,e,r,n,i,a){var o,s,l;if((l=Object.getOwnPropertyDescriptor(e,i)||{value:e[i]}).get?s=l.set?t.stylize(\"[Getter/Setter]\",\"special\"):t.stylize(\"[Getter]\",\"special\"):l.set&&(s=t.stylize(\"[Setter]\",\"special\")),S(n,i)||(o=\"[\"+i+\"]\"),s||(t.seen.indexOf(l.value)<0?(s=g(r)?u(t,l.value,null):u(t,l.value,r-1)).indexOf(\"\\n\")>-1&&(s=a?s.split(\"\\n\").map(function(t){return\"  \"+t}).join(\"\\n\").substr(2):\"\\n\"+s.split(\"\\n\").map(function(t){return\"   \"+t}).join(\"\\n\")):s=t.stylize(\"[Circular]\",\"special\")),y(o)){if(a&&i.match(/^\\d+$/))return s;(o=JSON.stringify(\"\"+i)).match(/^\"([a-zA-Z_][a-zA-Z_0-9]*)\"$/)?(o=o.substr(1,o.length-2),o=t.stylize(o,\"name\")):(o=o.replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"').replace(/(^\"|\"$)/g,\"'\"),o=t.stylize(o,\"string\"))}return o+\": \"+s}function p(t){return Array.isArray(t)}function d(t){return\"boolean\"==typeof t}function g(t){return null===t}function v(t){return\"number\"==typeof t}function m(t){return\"string\"==typeof t}function y(t){return void 0===t}function x(t){return b(t)&&\"[object RegExp]\"===T(t)}function b(t){return\"object\"==typeof t&&null!==t}function _(t){return b(t)&&\"[object Date]\"===T(t)}function w(t){return b(t)&&(\"[object Error]\"===T(t)||t instanceof Error)}function k(t){return\"function\"==typeof t}function T(t){return Object.prototype.toString.call(t)}function A(t){return t<10?\"0\"+t.toString(10):t.toString(10)}r.debuglog=function(t){if(y(a)&&(a=e.env.NODE_DEBUG||\"\"),t=t.toUpperCase(),!o[t])if(new RegExp(\"\\\\b\"+t+\"\\\\b\",\"i\").test(a)){var n=e.pid;o[t]=function(){var e=r.format.apply(r,arguments);console.error(\"%s %d: %s\",t,n,e)}}else o[t]=function(){};return o[t]},r.inspect=s,s.colors={bold:[1,22],italic:[3,23],underline:[4,24],inverse:[7,27],white:[37,39],grey:[90,39],black:[30,39],blue:[34,39],cyan:[36,39],green:[32,39],magenta:[35,39],red:[31,39],yellow:[33,39]},s.styles={special:\"cyan\",number:\"yellow\",boolean:\"yellow\",undefined:\"grey\",null:\"bold\",string:\"green\",date:\"magenta\",regexp:\"red\"},r.isArray=p,r.isBoolean=d,r.isNull=g,r.isNullOrUndefined=function(t){return null==t},r.isNumber=v,r.isString=m,r.isSymbol=function(t){return\"symbol\"==typeof t},r.isUndefined=y,r.isRegExp=x,r.isObject=b,r.isDate=_,r.isError=w,r.isFunction=k,r.isPrimitive=function(t){return null===t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||\"symbol\"==typeof t||\"undefined\"==typeof t},r.isBuffer=t(\"./support/isBuffer\");var M=[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"];function S(t,e){return Object.prototype.hasOwnProperty.call(t,e)}r.log=function(){var t,e;console.log(\"%s - %s\",(t=new Date,e=[A(t.getHours()),A(t.getMinutes()),A(t.getSeconds())].join(\":\"),[t.getDate(),M[t.getMonth()],e].join(\" \")),r.format.apply(r,arguments))},r.inherits=t(\"inherits\"),r._extend=function(t,e){if(!e||!b(e))return t;for(var r=Object.keys(e),n=r.length;n--;)t[r[n]]=e[r[n]];return t}}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./support/isBuffer\":70,_process:482,inherits:69}],72:[function(t,e,r){e.exports=function(t){return atob(t)}},{}],73:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=e.length,a=new Array(r+1),o=0;o<r;++o){for(var s=new Array(r+1),l=0;l<=r;++l)s[l]=t[l][o];a[o]=s}a[r]=new Array(r+1);for(var o=0;o<=r;++o)a[r][o]=1;for(var c=new Array(r+1),o=0;o<r;++o)c[o]=e[o];c[r]=1;var u=n(a,c),h=i(u[r+1]);0===h&&(h=1);for(var f=new Array(r+1),o=0;o<=r;++o)f[o]=i(u[o])/h;return f};var n=t(\"robust-linear-solve\");function i(t){for(var e=0,r=0;r<t.length;++r)e+=t[r];return e}},{\"robust-linear-solve\":509}],74:[function(t,e,r){\"use strict\";r.byteLength=function(t){var e=c(t),r=e[0],n=e[1];return 3*(r+n)/4-n},r.toByteArray=function(t){for(var e,r=c(t),n=r[0],o=r[1],s=new a(function(t,e,r){return 3*(e+r)/4-r}(0,n,o)),l=0,u=o>0?n-4:n,h=0;h<u;h+=4)e=i[t.charCodeAt(h)]<<18|i[t.charCodeAt(h+1)]<<12|i[t.charCodeAt(h+2)]<<6|i[t.charCodeAt(h+3)],s[l++]=e>>16&255,s[l++]=e>>8&255,s[l++]=255&e;2===o&&(e=i[t.charCodeAt(h)]<<2|i[t.charCodeAt(h+1)]>>4,s[l++]=255&e);1===o&&(e=i[t.charCodeAt(h)]<<10|i[t.charCodeAt(h+1)]<<4|i[t.charCodeAt(h+2)]>>2,s[l++]=e>>8&255,s[l++]=255&e);return s},r.fromByteArray=function(t){for(var e,r=t.length,i=r%3,a=[],o=0,s=r-i;o<s;o+=16383)a.push(u(t,o,o+16383>s?s:o+16383));1===i?(e=t[r-1],a.push(n[e>>2]+n[e<<4&63]+\"==\")):2===i&&(e=(t[r-2]<<8)+t[r-1],a.push(n[e>>10]+n[e>>4&63]+n[e<<2&63]+\"=\"));return a.join(\"\")};for(var n=[],i=[],a=\"undefined\"!=typeof Uint8Array?Uint8Array:Array,o=\"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/\",s=0,l=o.length;s<l;++s)n[s]=o[s],i[o.charCodeAt(s)]=s;function c(t){var e=t.length;if(e%4>0)throw new Error(\"Invalid string. Length must be a multiple of 4\");var r=t.indexOf(\"=\");return-1===r&&(r=e),[r,r===e?0:4-r%4]}function u(t,e,r){for(var i,a,o=[],s=e;s<r;s+=3)i=(t[s]<<16&16711680)+(t[s+1]<<8&65280)+(255&t[s+2]),o.push(n[(a=i)>>18&63]+n[a>>12&63]+n[a>>6&63]+n[63&a]);return o.join(\"\")}i[\"-\".charCodeAt(0)]=62,i[\"_\".charCodeAt(0)]=63},{}],75:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).add(e[0].mul(t[1])),t[1].mul(e[1]))}},{\"./lib/rationalize\":85}],76:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t[0].mul(e[1]).cmp(e[0].mul(t[1]))}},{}],77:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]),t[1].mul(e[0]))}},{\"./lib/rationalize\":85}],78:[function(t,e,r){\"use strict\";var n=t(\"./is-rat\"),i=t(\"./lib/is-bn\"),a=t(\"./lib/num-to-bn\"),o=t(\"./lib/str-to-bn\"),s=t(\"./lib/rationalize\"),l=t(\"./div\");e.exports=function t(e,r){if(n(e))return r?l(e,t(r)):[e[0].clone(),e[1].clone()];var c=0;var u,h;if(i(e))u=e.clone();else if(\"string\"==typeof e)u=o(e);else{if(0===e)return[a(0),a(1)];if(e===Math.floor(e))u=a(e);else{for(;e!==Math.floor(e);)e*=Math.pow(2,256),c-=256;u=a(e)}}if(n(r))u.mul(r[1]),h=r[0].clone();else if(i(r))h=r.clone();else if(\"string\"==typeof r)h=o(r);else if(r)if(r===Math.floor(r))h=a(r);else{for(;r!==Math.floor(r);)r*=Math.pow(2,256),c+=256;h=a(r)}else h=a(1);c>0?u=u.ushln(c):c<0&&(h=h.ushln(-c));return s(u,h)}},{\"./div\":77,\"./is-rat\":79,\"./lib/is-bn\":83,\"./lib/num-to-bn\":84,\"./lib/rationalize\":85,\"./lib/str-to-bn\":86}],79:[function(t,e,r){\"use strict\";var n=t(\"./lib/is-bn\");e.exports=function(t){return Array.isArray(t)&&2===t.length&&n(t[0])&&n(t[1])}},{\"./lib/is-bn\":83}],80:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return t.cmp(new n(0))}},{\"bn.js\":94}],81:[function(t,e,r){\"use strict\";var n=t(\"./bn-sign\");e.exports=function(t){var e=t.length,r=t.words,i=0;if(1===e)i=r[0];else if(2===e)i=r[0]+67108864*r[1];else for(var a=0;a<e;a++){var o=r[a];i+=o*Math.pow(67108864,a)}return n(t)*i}},{\"./bn-sign\":80}],82:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=t(\"bit-twiddle\").countTrailingZeros;e.exports=function(t){var e=i(n.lo(t));if(e<32)return e;var r=i(n.hi(t));if(r>20)return 52;return r+32}},{\"bit-twiddle\":92,\"double-bits\":167}],83:[function(t,e,r){\"use strict\";t(\"bn.js\");e.exports=function(t){return t&&\"object\"==typeof t&&Boolean(t.words)}},{\"bn.js\":94}],84:[function(t,e,r){\"use strict\";var n=t(\"bn.js\"),i=t(\"double-bits\");e.exports=function(t){var e=i.exponent(t);return e<52?new n(t):new n(t*Math.pow(2,52-e)).ushln(e-52)}},{\"bn.js\":94,\"double-bits\":167}],85:[function(t,e,r){\"use strict\";var n=t(\"./num-to-bn\"),i=t(\"./bn-sign\");e.exports=function(t,e){var r=i(t),a=i(e);if(0===r)return[n(0),n(1)];if(0===a)return[n(0),n(0)];a<0&&(t=t.neg(),e=e.neg());var o=t.gcd(e);if(o.cmpn(1))return[t.div(o),e.div(o)];return[t,e]}},{\"./bn-sign\":80,\"./num-to-bn\":84}],86:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return new n(t)}},{\"bn.js\":94}],87:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[0]),t[1].mul(e[1]))}},{\"./lib/rationalize\":85}],88:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-sign\");e.exports=function(t){return n(t[0])*n(t[1])}},{\"./lib/bn-sign\":80}],89:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).sub(t[1].mul(e[0])),t[1].mul(e[1]))}},{\"./lib/rationalize\":85}],90:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-to-num\"),i=t(\"./lib/ctz\");e.exports=function(t){var e=t[0],r=t[1];if(0===e.cmpn(0))return 0;var a=e.abs().divmod(r.abs()),o=a.div,s=n(o),l=a.mod,c=e.negative!==r.negative?-1:1;if(0===l.cmpn(0))return c*s;if(s){var u=i(s)+4,h=n(l.ushln(u).divRound(r));return c*(s+h*Math.pow(2,-u))}var f=r.bitLength()-l.bitLength()+53,h=n(l.ushln(f).divRound(r));return f<1023?c*h*Math.pow(2,-f):(h*=Math.pow(2,-1023),c*h*Math.pow(2,1023-f))}},{\"./lib/bn-to-num\":81,\"./lib/ctz\":82}],91:[function(t,e,r){\"use strict\";function n(t,e,r,n,i,a){var o=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",a?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a\",i?\".get(m)\":\"[m]\"];return a?e.indexOf(\"c\")<0?o.push(\";if(x===y){return m}else if(x<=y){\"):o.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):o.push(\";if(\",e,\"){i=m;\"),r?o.push(\"l=m+1}else{h=m-1}\"):o.push(\"h=m-1}else{l=m+1}\"),o.push(\"}\"),a?o.push(\"return -1};\"):o.push(\"return i};\"),o.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],!1,i),n(\"B\",\"x\"+t+\"y\",e,[\"y\"],!0,i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!1,i),n(\"Q\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!0,i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(a.shape){if(typeof(c)==='function'){return Q(a,(l===undefined)?0:l|0,(h===undefined)?a.shape[0]-1:h|0,y,c)}else{return B(a,(c===undefined)?0:c|0,(l===undefined)?a.shape[0]-1:l|0,y)}}else{if(typeof(c)==='function'){return P(a,(l===undefined)?0:l|0,(h===undefined)?a.length-1:h|0,y,c)}else{return A(a,(c===undefined)?0:c|0,(l===undefined)?a.length-1:l|0,y)}}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],92:[function(t,e,r){\"use strict\";function n(t){var e=32;return(t&=-t)&&e--,65535&t&&(e-=16),16711935&t&&(e-=8),252645135&t&&(e-=4),858993459&t&&(e-=2),1431655765&t&&(e-=1),e}r.INT_BITS=32,r.INT_MAX=2147483647,r.INT_MIN=-1<<31,r.sign=function(t){return(t>0)-(t<0)},r.abs=function(t){var e=t>>31;return(t^e)-e},r.min=function(t,e){return e^(t^e)&-(t<e)},r.max=function(t,e){return t^(t^e)&-(t<e)},r.isPow2=function(t){return!(t&t-1||!t)},r.log2=function(t){var e,r;return e=(t>65535)<<4,e|=r=((t>>>=e)>255)<<3,e|=r=((t>>>=r)>15)<<2,(e|=r=((t>>>=r)>3)<<1)|(t>>>=r)>>1},r.log10=function(t){return t>=1e9?9:t>=1e8?8:t>=1e7?7:t>=1e6?6:t>=1e5?5:t>=1e4?4:t>=1e3?3:t>=100?2:t>=10?1:0},r.popCount=function(t){return 16843009*((t=(858993459&(t-=t>>>1&1431655765))+(t>>>2&858993459))+(t>>>4)&252645135)>>>24},r.countTrailingZeros=n,r.nextPow2=function(t){return t+=0===t,--t,t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)+1},r.prevPow2=function(t){return t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)-(t>>>1)},r.parity=function(t){return t^=t>>>16,t^=t>>>8,t^=t>>>4,27030>>>(t&=15)&1};var i=new Array(256);!function(t){for(var e=0;e<256;++e){var r=e,n=e,i=7;for(r>>>=1;r;r>>>=1)n<<=1,n|=1&r,--i;t[e]=n<<i&255}}(i),r.reverse=function(t){return i[255&t]<<24|i[t>>>8&255]<<16|i[t>>>16&255]<<8|i[t>>>24&255]},r.interleave2=function(t,e){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t&=65535)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e&=65535)|e<<8))|e<<4))|e<<2))|e<<1))<<1},r.deinterleave2=function(t,e){return(t=65535&((t=16711935&((t=252645135&((t=858993459&((t=t>>>e&1431655765)|t>>>1))|t>>>2))|t>>>4))|t>>>16))<<16>>16},r.interleave3=function(t,e,r){return t=1227133513&((t=3272356035&((t=251719695&((t=4278190335&((t&=1023)|t<<16))|t<<8))|t<<4))|t<<2),(t|=(e=1227133513&((e=3272356035&((e=251719695&((e=4278190335&((e&=1023)|e<<16))|e<<8))|e<<4))|e<<2))<<1)|(r=1227133513&((r=3272356035&((r=251719695&((r=4278190335&((r&=1023)|r<<16))|r<<8))|r<<4))|r<<2))<<2},r.deinterleave3=function(t,e){return(t=1023&((t=4278190335&((t=251719695&((t=3272356035&((t=t>>>e&1227133513)|t>>>2))|t>>>4))|t>>>8))|t>>>16))<<22>>22},r.nextCombination=function(t){var e=t|t-1;return e+1|(~e&-~e)-1>>>n(t)+1}},{}],93:[function(t,e,r){\"use strict\";var n=t(\"clamp\");e.exports=function(t,e){e||(e={});var r,o,s,l,c,u,h,f,p,d,g,v=null==e.cutoff?.25:e.cutoff,m=null==e.radius?8:e.radius,y=e.channel||0;if(ArrayBuffer.isView(t)||Array.isArray(t)){if(!e.width||!e.height)throw Error(\"For raw data width and height should be provided by options\");r=e.width,o=e.height,l=t,u=e.stride?e.stride:Math.floor(t.length/r/o)}else window.HTMLCanvasElement&&t instanceof window.HTMLCanvasElement?(h=(f=t).getContext(\"2d\"),r=f.width,o=f.height,p=h.getImageData(0,0,r,o),l=p.data,u=4):window.CanvasRenderingContext2D&&t instanceof window.CanvasRenderingContext2D?(f=t.canvas,h=t,r=f.width,o=f.height,p=h.getImageData(0,0,r,o),l=p.data,u=4):window.ImageData&&t instanceof window.ImageData&&(p=t,r=t.width,o=t.height,l=p.data,u=4);if(s=Math.max(r,o),window.Uint8ClampedArray&&l instanceof window.Uint8ClampedArray||window.Uint8Array&&l instanceof window.Uint8Array)for(c=l,l=Array(r*o),d=0,g=c.length;d<g;d++)l[d]=c[d*u+y]/255;else if(1!==u)throw Error(\"Raw data can have only 1 value per pixel\");var x=Array(r*o),b=Array(r*o),_=Array(s),w=Array(s),k=Array(s+1),T=Array(s);for(d=0,g=r*o;d<g;d++){var A=l[d];x[d]=1===A?0:0===A?i:Math.pow(Math.max(0,.5-A),2),b[d]=1===A?i:0===A?0:Math.pow(Math.max(0,A-.5),2)}a(x,r,o,_,w,T,k),a(b,r,o,_,w,T,k);var M=window.Float32Array?new Float32Array(r*o):new Array(r*o);for(d=0,g=r*o;d<g;d++)M[d]=n(1-((x[d]-b[d])/m+v),0,1);return M};var i=1e20;function a(t,e,r,n,i,a,s){for(var l=0;l<e;l++){for(var c=0;c<r;c++)n[c]=t[c*e+l];for(o(n,i,a,s,r),c=0;c<r;c++)t[c*e+l]=i[c]}for(c=0;c<r;c++){for(l=0;l<e;l++)n[l]=t[c*e+l];for(o(n,i,a,s,e),l=0;l<e;l++)t[c*e+l]=Math.sqrt(i[l])}}function o(t,e,r,n,a){r[0]=0,n[0]=-i,n[1]=+i;for(var o=1,s=0;o<a;o++){for(var l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);l<=n[s];)s--,l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);r[++s]=o,n[s]=l,n[s+1]=+i}for(o=0,s=0;o<a;o++){for(;n[s+1]<o;)s++;e[o]=(o-r[s])*(o-r[s])+t[r[s]]}}},{clamp:115}],94:[function(t,e,r){!function(e,r){\"use strict\";function n(t,e){if(!t)throw new Error(e||\"Assertion failed\")}function i(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}function a(t,e,r){if(a.isBN(t))return t;this.negative=0,this.words=null,this.length=0,this.red=null,null!==t&&(\"le\"!==e&&\"be\"!==e||(r=e,e=10),this._init(t||0,e||10,r||\"be\"))}var o;\"object\"==typeof e?e.exports=a:r.BN=a,a.BN=a,a.wordSize=26;try{o=t(\"buffer\").Buffer}catch(t){}function s(t,e,r){for(var n=0,i=Math.min(t.length,r),a=e;a<i;a++){var o=t.charCodeAt(a)-48;n<<=4,n|=o>=49&&o<=54?o-49+10:o>=17&&o<=22?o-17+10:15&o}return n}function l(t,e,r,n){for(var i=0,a=Math.min(t.length,r),o=e;o<a;o++){var s=t.charCodeAt(o)-48;i*=n,i+=s>=49?s-49+10:s>=17?s-17+10:s}return i}a.isBN=function(t){return t instanceof a||null!==t&&\"object\"==typeof t&&t.constructor.wordSize===a.wordSize&&Array.isArray(t.words)},a.max=function(t,e){return t.cmp(e)>0?t:e},a.min=function(t,e){return t.cmp(e)<0?t:e},a.prototype._init=function(t,e,r){if(\"number\"==typeof t)return this._initNumber(t,e,r);if(\"object\"==typeof t)return this._initArray(t,e,r);\"hex\"===e&&(e=16),n(e===(0|e)&&e>=2&&e<=36);var i=0;\"-\"===(t=t.toString().replace(/\\s+/g,\"\"))[0]&&i++,16===e?this._parseHex(t,i):this._parseBase(t,e,i),\"-\"===t[0]&&(this.negative=1),this.strip(),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initNumber=function(t,e,r){t<0&&(this.negative=1,t=-t),t<67108864?(this.words=[67108863&t],this.length=1):t<4503599627370496?(this.words=[67108863&t,t/67108864&67108863],this.length=2):(n(t<9007199254740992),this.words=[67108863&t,t/67108864&67108863,1],this.length=3),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initArray=function(t,e,r){if(n(\"number\"==typeof t.length),t.length<=0)return this.words=[0],this.length=1,this;this.length=Math.ceil(t.length/3),this.words=new Array(this.length);for(var i=0;i<this.length;i++)this.words[i]=0;var a,o,s=0;if(\"be\"===r)for(i=t.length-1,a=0;i>=0;i-=3)o=t[i]|t[i-1]<<8|t[i-2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);else if(\"le\"===r)for(i=0,a=0;i<t.length;i+=3)o=t[i]|t[i+1]<<8|t[i+2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);return this.strip()},a.prototype._parseHex=function(t,e){this.length=Math.ceil((t.length-e)/6),this.words=new Array(this.length);for(var r=0;r<this.length;r++)this.words[r]=0;var n,i,a=0;for(r=t.length-6,n=0;r>=e;r-=6)i=s(t,r,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303,(a+=24)>=26&&(a-=26,n++);r+6!==e&&(i=s(t,e,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303),this.strip()},a.prototype._parseBase=function(t,e,r){this.words=[0],this.length=1;for(var n=0,i=1;i<=67108863;i*=e)n++;n--,i=i/e|0;for(var a=t.length-r,o=a%n,s=Math.min(a,a-o)+r,c=0,u=r;u<s;u+=n)c=l(t,u,u+n,e),this.imuln(i),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c);if(0!==o){var h=1;for(c=l(t,u,t.length,e),u=0;u<o;u++)h*=e;this.imuln(h),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c)}},a.prototype.copy=function(t){t.words=new Array(this.length);for(var e=0;e<this.length;e++)t.words[e]=this.words[e];t.length=this.length,t.negative=this.negative,t.red=this.red},a.prototype.clone=function(){var t=new a(null);return this.copy(t),t},a.prototype._expand=function(t){for(;this.length<t;)this.words[this.length++]=0;return this},a.prototype.strip=function(){for(;this.length>1&&0===this.words[this.length-1];)this.length--;return this._normSign()},a.prototype._normSign=function(){return 1===this.length&&0===this.words[0]&&(this.negative=0),this},a.prototype.inspect=function(){return(this.red?\"<BN-R: \":\"<BN: \")+this.toString(16)+\">\"};var c=[\"\",\"0\",\"00\",\"000\",\"0000\",\"00000\",\"000000\",\"0000000\",\"00000000\",\"000000000\",\"0000000000\",\"00000000000\",\"000000000000\",\"0000000000000\",\"00000000000000\",\"000000000000000\",\"0000000000000000\",\"00000000000000000\",\"000000000000000000\",\"0000000000000000000\",\"00000000000000000000\",\"000000000000000000000\",\"0000000000000000000000\",\"00000000000000000000000\",\"000000000000000000000000\",\"0000000000000000000000000\"],u=[0,0,25,16,12,11,10,9,8,8,7,7,7,7,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5],h=[0,0,33554432,43046721,16777216,48828125,60466176,40353607,16777216,43046721,1e7,19487171,35831808,62748517,7529536,11390625,16777216,24137569,34012224,47045881,64e6,4084101,5153632,6436343,7962624,9765625,11881376,14348907,17210368,20511149,243e5,28629151,33554432,39135393,45435424,52521875,60466176];function f(t,e,r){r.negative=e.negative^t.negative;var n=t.length+e.length|0;r.length=n,n=n-1|0;var i=0|t.words[0],a=0|e.words[0],o=i*a,s=67108863&o,l=o/67108864|0;r.words[0]=s;for(var c=1;c<n;c++){for(var u=l>>>26,h=67108863&l,f=Math.min(c,e.length-1),p=Math.max(0,c-t.length+1);p<=f;p++){var d=c-p|0;u+=(o=(i=0|t.words[d])*(a=0|e.words[p])+h)/67108864|0,h=67108863&o}r.words[c]=0|h,l=0|u}return 0!==l?r.words[c]=0|l:r.length--,r.strip()}a.prototype.toString=function(t,e){var r;if(e=0|e||1,16===(t=t||10)||\"hex\"===t){r=\"\";for(var i=0,a=0,o=0;o<this.length;o++){var s=this.words[o],l=(16777215&(s<<i|a)).toString(16);r=0!==(a=s>>>24-i&16777215)||o!==this.length-1?c[6-l.length]+l+r:l+r,(i+=2)>=26&&(i-=26,o--)}for(0!==a&&(r=a.toString(16)+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}if(t===(0|t)&&t>=2&&t<=36){var f=u[t],p=h[t];r=\"\";var d=this.clone();for(d.negative=0;!d.isZero();){var g=d.modn(p).toString(t);r=(d=d.idivn(p)).isZero()?g+r:c[f-g.length]+g+r}for(this.isZero()&&(r=\"0\"+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}n(!1,\"Base should be between 2 and 36\")},a.prototype.toNumber=function(){var t=this.words[0];return 2===this.length?t+=67108864*this.words[1]:3===this.length&&1===this.words[2]?t+=4503599627370496+67108864*this.words[1]:this.length>2&&n(!1,\"Number can only safely store up to 53 bits\"),0!==this.negative?-t:t},a.prototype.toJSON=function(){return this.toString(16)},a.prototype.toBuffer=function(t,e){return n(\"undefined\"!=typeof o),this.toArrayLike(o,t,e)},a.prototype.toArray=function(t,e){return this.toArrayLike(Array,t,e)},a.prototype.toArrayLike=function(t,e,r){var i=this.byteLength(),a=r||Math.max(1,i);n(i<=a,\"byte array longer than desired length\"),n(a>0,\"Requested array length <= 0\"),this.strip();var o,s,l=\"le\"===e,c=new t(a),u=this.clone();if(l){for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[s]=o;for(;s<a;s++)c[s]=0}else{for(s=0;s<a-i;s++)c[s]=0;for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[a-s-1]=o}return c},Math.clz32?a.prototype._countBits=function(t){return 32-Math.clz32(t)}:a.prototype._countBits=function(t){var e=t,r=0;return e>=4096&&(r+=13,e>>>=13),e>=64&&(r+=7,e>>>=7),e>=8&&(r+=4,e>>>=4),e>=2&&(r+=2,e>>>=2),r+e},a.prototype._zeroBits=function(t){if(0===t)return 26;var e=t,r=0;return 0==(8191&e)&&(r+=13,e>>>=13),0==(127&e)&&(r+=7,e>>>=7),0==(15&e)&&(r+=4,e>>>=4),0==(3&e)&&(r+=2,e>>>=2),0==(1&e)&&r++,r},a.prototype.bitLength=function(){var t=this.words[this.length-1],e=this._countBits(t);return 26*(this.length-1)+e},a.prototype.zeroBits=function(){if(this.isZero())return 0;for(var t=0,e=0;e<this.length;e++){var r=this._zeroBits(this.words[e]);if(t+=r,26!==r)break}return t},a.prototype.byteLength=function(){return Math.ceil(this.bitLength()/8)},a.prototype.toTwos=function(t){return 0!==this.negative?this.abs().inotn(t).iaddn(1):this.clone()},a.prototype.fromTwos=function(t){return this.testn(t-1)?this.notn(t).iaddn(1).ineg():this.clone()},a.prototype.isNeg=function(){return 0!==this.negative},a.prototype.neg=function(){return this.clone().ineg()},a.prototype.ineg=function(){return this.isZero()||(this.negative^=1),this},a.prototype.iuor=function(t){for(;this.length<t.length;)this.words[this.length++]=0;for(var e=0;e<t.length;e++)this.words[e]=this.words[e]|t.words[e];return this.strip()},a.prototype.ior=function(t){return n(0==(this.negative|t.negative)),this.iuor(t)},a.prototype.or=function(t){return this.length>t.length?this.clone().ior(t):t.clone().ior(this)},a.prototype.uor=function(t){return this.length>t.length?this.clone().iuor(t):t.clone().iuor(this)},a.prototype.iuand=function(t){var e;e=this.length>t.length?t:this;for(var r=0;r<e.length;r++)this.words[r]=this.words[r]&t.words[r];return this.length=e.length,this.strip()},a.prototype.iand=function(t){return n(0==(this.negative|t.negative)),this.iuand(t)},a.prototype.and=function(t){return this.length>t.length?this.clone().iand(t):t.clone().iand(this)},a.prototype.uand=function(t){return this.length>t.length?this.clone().iuand(t):t.clone().iuand(this)},a.prototype.iuxor=function(t){var e,r;this.length>t.length?(e=this,r=t):(e=t,r=this);for(var n=0;n<r.length;n++)this.words[n]=e.words[n]^r.words[n];if(this!==e)for(;n<e.length;n++)this.words[n]=e.words[n];return this.length=e.length,this.strip()},a.prototype.ixor=function(t){return n(0==(this.negative|t.negative)),this.iuxor(t)},a.prototype.xor=function(t){return this.length>t.length?this.clone().ixor(t):t.clone().ixor(this)},a.prototype.uxor=function(t){return this.length>t.length?this.clone().iuxor(t):t.clone().iuxor(this)},a.prototype.inotn=function(t){n(\"number\"==typeof t&&t>=0);var e=0|Math.ceil(t/26),r=t%26;this._expand(e),r>0&&e--;for(var i=0;i<e;i++)this.words[i]=67108863&~this.words[i];return r>0&&(this.words[i]=~this.words[i]&67108863>>26-r),this.strip()},a.prototype.notn=function(t){return this.clone().inotn(t)},a.prototype.setn=function(t,e){n(\"number\"==typeof t&&t>=0);var r=t/26|0,i=t%26;return this._expand(r+1),this.words[r]=e?this.words[r]|1<<i:this.words[r]&~(1<<i),this.strip()},a.prototype.iadd=function(t){var e,r,n;if(0!==this.negative&&0===t.negative)return this.negative=0,e=this.isub(t),this.negative^=1,this._normSign();if(0===this.negative&&0!==t.negative)return t.negative=0,e=this.isub(t),t.negative=1,e._normSign();this.length>t.length?(r=this,n=t):(r=t,n=this);for(var i=0,a=0;a<n.length;a++)e=(0|r.words[a])+(0|n.words[a])+i,this.words[a]=67108863&e,i=e>>>26;for(;0!==i&&a<r.length;a++)e=(0|r.words[a])+i,this.words[a]=67108863&e,i=e>>>26;if(this.length=r.length,0!==i)this.words[this.length]=i,this.length++;else if(r!==this)for(;a<r.length;a++)this.words[a]=r.words[a];return this},a.prototype.add=function(t){var e;return 0!==t.negative&&0===this.negative?(t.negative=0,e=this.sub(t),t.negative^=1,e):0===t.negative&&0!==this.negative?(this.negative=0,e=t.sub(this),this.negative=1,e):this.length>t.length?this.clone().iadd(t):t.clone().iadd(this)},a.prototype.isub=function(t){if(0!==t.negative){t.negative=0;var e=this.iadd(t);return t.negative=1,e._normSign()}if(0!==this.negative)return this.negative=0,this.iadd(t),this.negative=1,this._normSign();var r,n,i=this.cmp(t);if(0===i)return this.negative=0,this.length=1,this.words[0]=0,this;i>0?(r=this,n=t):(r=t,n=this);for(var a=0,o=0;o<n.length;o++)a=(e=(0|r.words[o])-(0|n.words[o])+a)>>26,this.words[o]=67108863&e;for(;0!==a&&o<r.length;o++)a=(e=(0|r.words[o])+a)>>26,this.words[o]=67108863&e;if(0===a&&o<r.length&&r!==this)for(;o<r.length;o++)this.words[o]=r.words[o];return this.length=Math.max(this.length,o),r!==this&&(this.negative=1),this.strip()},a.prototype.sub=function(t){return this.clone().isub(t)};var p=function(t,e,r){var n,i,a,o=t.words,s=e.words,l=r.words,c=0,u=0|o[0],h=8191&u,f=u>>>13,p=0|o[1],d=8191&p,g=p>>>13,v=0|o[2],m=8191&v,y=v>>>13,x=0|o[3],b=8191&x,_=x>>>13,w=0|o[4],k=8191&w,T=w>>>13,A=0|o[5],M=8191&A,S=A>>>13,E=0|o[6],C=8191&E,L=E>>>13,P=0|o[7],O=8191&P,z=P>>>13,I=0|o[8],D=8191&I,R=I>>>13,F=0|o[9],B=8191&F,N=F>>>13,j=0|s[0],U=8191&j,V=j>>>13,q=0|s[1],H=8191&q,G=q>>>13,Y=0|s[2],W=8191&Y,X=Y>>>13,Z=0|s[3],J=8191&Z,K=Z>>>13,$=0|s[4],Q=8191&$,tt=$>>>13,et=0|s[5],rt=8191&et,nt=et>>>13,it=0|s[6],at=8191&it,ot=it>>>13,st=0|s[7],lt=8191&st,ct=st>>>13,ut=0|s[8],ht=8191&ut,ft=ut>>>13,pt=0|s[9],dt=8191&pt,gt=pt>>>13;r.negative=t.negative^e.negative,r.length=19;var vt=(c+(n=Math.imul(h,U))|0)+((8191&(i=(i=Math.imul(h,V))+Math.imul(f,U)|0))<<13)|0;c=((a=Math.imul(f,V))+(i>>>13)|0)+(vt>>>26)|0,vt&=67108863,n=Math.imul(d,U),i=(i=Math.imul(d,V))+Math.imul(g,U)|0,a=Math.imul(g,V);var mt=(c+(n=n+Math.imul(h,H)|0)|0)+((8191&(i=(i=i+Math.imul(h,G)|0)+Math.imul(f,H)|0))<<13)|0;c=((a=a+Math.imul(f,G)|0)+(i>>>13)|0)+(mt>>>26)|0,mt&=67108863,n=Math.imul(m,U),i=(i=Math.imul(m,V))+Math.imul(y,U)|0,a=Math.imul(y,V),n=n+Math.imul(d,H)|0,i=(i=i+Math.imul(d,G)|0)+Math.imul(g,H)|0,a=a+Math.imul(g,G)|0;var yt=(c+(n=n+Math.imul(h,W)|0)|0)+((8191&(i=(i=i+Math.imul(h,X)|0)+Math.imul(f,W)|0))<<13)|0;c=((a=a+Math.imul(f,X)|0)+(i>>>13)|0)+(yt>>>26)|0,yt&=67108863,n=Math.imul(b,U),i=(i=Math.imul(b,V))+Math.imul(_,U)|0,a=Math.imul(_,V),n=n+Math.imul(m,H)|0,i=(i=i+Math.imul(m,G)|0)+Math.imul(y,H)|0,a=a+Math.imul(y,G)|0,n=n+Math.imul(d,W)|0,i=(i=i+Math.imul(d,X)|0)+Math.imul(g,W)|0,a=a+Math.imul(g,X)|0;var xt=(c+(n=n+Math.imul(h,J)|0)|0)+((8191&(i=(i=i+Math.imul(h,K)|0)+Math.imul(f,J)|0))<<13)|0;c=((a=a+Math.imul(f,K)|0)+(i>>>13)|0)+(xt>>>26)|0,xt&=67108863,n=Math.imul(k,U),i=(i=Math.imul(k,V))+Math.imul(T,U)|0,a=Math.imul(T,V),n=n+Math.imul(b,H)|0,i=(i=i+Math.imul(b,G)|0)+Math.imul(_,H)|0,a=a+Math.imul(_,G)|0,n=n+Math.imul(m,W)|0,i=(i=i+Math.imul(m,X)|0)+Math.imul(y,W)|0,a=a+Math.imul(y,X)|0,n=n+Math.imul(d,J)|0,i=(i=i+Math.imul(d,K)|0)+Math.imul(g,J)|0,a=a+Math.imul(g,K)|0;var bt=(c+(n=n+Math.imul(h,Q)|0)|0)+((8191&(i=(i=i+Math.imul(h,tt)|0)+Math.imul(f,Q)|0))<<13)|0;c=((a=a+Math.imul(f,tt)|0)+(i>>>13)|0)+(bt>>>26)|0,bt&=67108863,n=Math.imul(M,U),i=(i=Math.imul(M,V))+Math.imul(S,U)|0,a=Math.imul(S,V),n=n+Math.imul(k,H)|0,i=(i=i+Math.imul(k,G)|0)+Math.imul(T,H)|0,a=a+Math.imul(T,G)|0,n=n+Math.imul(b,W)|0,i=(i=i+Math.imul(b,X)|0)+Math.imul(_,W)|0,a=a+Math.imul(_,X)|0,n=n+Math.imul(m,J)|0,i=(i=i+Math.imul(m,K)|0)+Math.imul(y,J)|0,a=a+Math.imul(y,K)|0,n=n+Math.imul(d,Q)|0,i=(i=i+Math.imul(d,tt)|0)+Math.imul(g,Q)|0,a=a+Math.imul(g,tt)|0;var _t=(c+(n=n+Math.imul(h,rt)|0)|0)+((8191&(i=(i=i+Math.imul(h,nt)|0)+Math.imul(f,rt)|0))<<13)|0;c=((a=a+Math.imul(f,nt)|0)+(i>>>13)|0)+(_t>>>26)|0,_t&=67108863,n=Math.imul(C,U),i=(i=Math.imul(C,V))+Math.imul(L,U)|0,a=Math.imul(L,V),n=n+Math.imul(M,H)|0,i=(i=i+Math.imul(M,G)|0)+Math.imul(S,H)|0,a=a+Math.imul(S,G)|0,n=n+Math.imul(k,W)|0,i=(i=i+Math.imul(k,X)|0)+Math.imul(T,W)|0,a=a+Math.imul(T,X)|0,n=n+Math.imul(b,J)|0,i=(i=i+Math.imul(b,K)|0)+Math.imul(_,J)|0,a=a+Math.imul(_,K)|0,n=n+Math.imul(m,Q)|0,i=(i=i+Math.imul(m,tt)|0)+Math.imul(y,Q)|0,a=a+Math.imul(y,tt)|0,n=n+Math.imul(d,rt)|0,i=(i=i+Math.imul(d,nt)|0)+Math.imul(g,rt)|0,a=a+Math.imul(g,nt)|0;var wt=(c+(n=n+Math.imul(h,at)|0)|0)+((8191&(i=(i=i+Math.imul(h,ot)|0)+Math.imul(f,at)|0))<<13)|0;c=((a=a+Math.imul(f,ot)|0)+(i>>>13)|0)+(wt>>>26)|0,wt&=67108863,n=Math.imul(O,U),i=(i=Math.imul(O,V))+Math.imul(z,U)|0,a=Math.imul(z,V),n=n+Math.imul(C,H)|0,i=(i=i+Math.imul(C,G)|0)+Math.imul(L,H)|0,a=a+Math.imul(L,G)|0,n=n+Math.imul(M,W)|0,i=(i=i+Math.imul(M,X)|0)+Math.imul(S,W)|0,a=a+Math.imul(S,X)|0,n=n+Math.imul(k,J)|0,i=(i=i+Math.imul(k,K)|0)+Math.imul(T,J)|0,a=a+Math.imul(T,K)|0,n=n+Math.imul(b,Q)|0,i=(i=i+Math.imul(b,tt)|0)+Math.imul(_,Q)|0,a=a+Math.imul(_,tt)|0,n=n+Math.imul(m,rt)|0,i=(i=i+Math.imul(m,nt)|0)+Math.imul(y,rt)|0,a=a+Math.imul(y,nt)|0,n=n+Math.imul(d,at)|0,i=(i=i+Math.imul(d,ot)|0)+Math.imul(g,at)|0,a=a+Math.imul(g,ot)|0;var kt=(c+(n=n+Math.imul(h,lt)|0)|0)+((8191&(i=(i=i+Math.imul(h,ct)|0)+Math.imul(f,lt)|0))<<13)|0;c=((a=a+Math.imul(f,ct)|0)+(i>>>13)|0)+(kt>>>26)|0,kt&=67108863,n=Math.imul(D,U),i=(i=Math.imul(D,V))+Math.imul(R,U)|0,a=Math.imul(R,V),n=n+Math.imul(O,H)|0,i=(i=i+Math.imul(O,G)|0)+Math.imul(z,H)|0,a=a+Math.imul(z,G)|0,n=n+Math.imul(C,W)|0,i=(i=i+Math.imul(C,X)|0)+Math.imul(L,W)|0,a=a+Math.imul(L,X)|0,n=n+Math.imul(M,J)|0,i=(i=i+Math.imul(M,K)|0)+Math.imul(S,J)|0,a=a+Math.imul(S,K)|0,n=n+Math.imul(k,Q)|0,i=(i=i+Math.imul(k,tt)|0)+Math.imul(T,Q)|0,a=a+Math.imul(T,tt)|0,n=n+Math.imul(b,rt)|0,i=(i=i+Math.imul(b,nt)|0)+Math.imul(_,rt)|0,a=a+Math.imul(_,nt)|0,n=n+Math.imul(m,at)|0,i=(i=i+Math.imul(m,ot)|0)+Math.imul(y,at)|0,a=a+Math.imul(y,ot)|0,n=n+Math.imul(d,lt)|0,i=(i=i+Math.imul(d,ct)|0)+Math.imul(g,lt)|0,a=a+Math.imul(g,ct)|0;var Tt=(c+(n=n+Math.imul(h,ht)|0)|0)+((8191&(i=(i=i+Math.imul(h,ft)|0)+Math.imul(f,ht)|0))<<13)|0;c=((a=a+Math.imul(f,ft)|0)+(i>>>13)|0)+(Tt>>>26)|0,Tt&=67108863,n=Math.imul(B,U),i=(i=Math.imul(B,V))+Math.imul(N,U)|0,a=Math.imul(N,V),n=n+Math.imul(D,H)|0,i=(i=i+Math.imul(D,G)|0)+Math.imul(R,H)|0,a=a+Math.imul(R,G)|0,n=n+Math.imul(O,W)|0,i=(i=i+Math.imul(O,X)|0)+Math.imul(z,W)|0,a=a+Math.imul(z,X)|0,n=n+Math.imul(C,J)|0,i=(i=i+Math.imul(C,K)|0)+Math.imul(L,J)|0,a=a+Math.imul(L,K)|0,n=n+Math.imul(M,Q)|0,i=(i=i+Math.imul(M,tt)|0)+Math.imul(S,Q)|0,a=a+Math.imul(S,tt)|0,n=n+Math.imul(k,rt)|0,i=(i=i+Math.imul(k,nt)|0)+Math.imul(T,rt)|0,a=a+Math.imul(T,nt)|0,n=n+Math.imul(b,at)|0,i=(i=i+Math.imul(b,ot)|0)+Math.imul(_,at)|0,a=a+Math.imul(_,ot)|0,n=n+Math.imul(m,lt)|0,i=(i=i+Math.imul(m,ct)|0)+Math.imul(y,lt)|0,a=a+Math.imul(y,ct)|0,n=n+Math.imul(d,ht)|0,i=(i=i+Math.imul(d,ft)|0)+Math.imul(g,ht)|0,a=a+Math.imul(g,ft)|0;var At=(c+(n=n+Math.imul(h,dt)|0)|0)+((8191&(i=(i=i+Math.imul(h,gt)|0)+Math.imul(f,dt)|0))<<13)|0;c=((a=a+Math.imul(f,gt)|0)+(i>>>13)|0)+(At>>>26)|0,At&=67108863,n=Math.imul(B,H),i=(i=Math.imul(B,G))+Math.imul(N,H)|0,a=Math.imul(N,G),n=n+Math.imul(D,W)|0,i=(i=i+Math.imul(D,X)|0)+Math.imul(R,W)|0,a=a+Math.imul(R,X)|0,n=n+Math.imul(O,J)|0,i=(i=i+Math.imul(O,K)|0)+Math.imul(z,J)|0,a=a+Math.imul(z,K)|0,n=n+Math.imul(C,Q)|0,i=(i=i+Math.imul(C,tt)|0)+Math.imul(L,Q)|0,a=a+Math.imul(L,tt)|0,n=n+Math.imul(M,rt)|0,i=(i=i+Math.imul(M,nt)|0)+Math.imul(S,rt)|0,a=a+Math.imul(S,nt)|0,n=n+Math.imul(k,at)|0,i=(i=i+Math.imul(k,ot)|0)+Math.imul(T,at)|0,a=a+Math.imul(T,ot)|0,n=n+Math.imul(b,lt)|0,i=(i=i+Math.imul(b,ct)|0)+Math.imul(_,lt)|0,a=a+Math.imul(_,ct)|0,n=n+Math.imul(m,ht)|0,i=(i=i+Math.imul(m,ft)|0)+Math.imul(y,ht)|0,a=a+Math.imul(y,ft)|0;var Mt=(c+(n=n+Math.imul(d,dt)|0)|0)+((8191&(i=(i=i+Math.imul(d,gt)|0)+Math.imul(g,dt)|0))<<13)|0;c=((a=a+Math.imul(g,gt)|0)+(i>>>13)|0)+(Mt>>>26)|0,Mt&=67108863,n=Math.imul(B,W),i=(i=Math.imul(B,X))+Math.imul(N,W)|0,a=Math.imul(N,X),n=n+Math.imul(D,J)|0,i=(i=i+Math.imul(D,K)|0)+Math.imul(R,J)|0,a=a+Math.imul(R,K)|0,n=n+Math.imul(O,Q)|0,i=(i=i+Math.imul(O,tt)|0)+Math.imul(z,Q)|0,a=a+Math.imul(z,tt)|0,n=n+Math.imul(C,rt)|0,i=(i=i+Math.imul(C,nt)|0)+Math.imul(L,rt)|0,a=a+Math.imul(L,nt)|0,n=n+Math.imul(M,at)|0,i=(i=i+Math.imul(M,ot)|0)+Math.imul(S,at)|0,a=a+Math.imul(S,ot)|0,n=n+Math.imul(k,lt)|0,i=(i=i+Math.imul(k,ct)|0)+Math.imul(T,lt)|0,a=a+Math.imul(T,ct)|0,n=n+Math.imul(b,ht)|0,i=(i=i+Math.imul(b,ft)|0)+Math.imul(_,ht)|0,a=a+Math.imul(_,ft)|0;var St=(c+(n=n+Math.imul(m,dt)|0)|0)+((8191&(i=(i=i+Math.imul(m,gt)|0)+Math.imul(y,dt)|0))<<13)|0;c=((a=a+Math.imul(y,gt)|0)+(i>>>13)|0)+(St>>>26)|0,St&=67108863,n=Math.imul(B,J),i=(i=Math.imul(B,K))+Math.imul(N,J)|0,a=Math.imul(N,K),n=n+Math.imul(D,Q)|0,i=(i=i+Math.imul(D,tt)|0)+Math.imul(R,Q)|0,a=a+Math.imul(R,tt)|0,n=n+Math.imul(O,rt)|0,i=(i=i+Math.imul(O,nt)|0)+Math.imul(z,rt)|0,a=a+Math.imul(z,nt)|0,n=n+Math.imul(C,at)|0,i=(i=i+Math.imul(C,ot)|0)+Math.imul(L,at)|0,a=a+Math.imul(L,ot)|0,n=n+Math.imul(M,lt)|0,i=(i=i+Math.imul(M,ct)|0)+Math.imul(S,lt)|0,a=a+Math.imul(S,ct)|0,n=n+Math.imul(k,ht)|0,i=(i=i+Math.imul(k,ft)|0)+Math.imul(T,ht)|0,a=a+Math.imul(T,ft)|0;var Et=(c+(n=n+Math.imul(b,dt)|0)|0)+((8191&(i=(i=i+Math.imul(b,gt)|0)+Math.imul(_,dt)|0))<<13)|0;c=((a=a+Math.imul(_,gt)|0)+(i>>>13)|0)+(Et>>>26)|0,Et&=67108863,n=Math.imul(B,Q),i=(i=Math.imul(B,tt))+Math.imul(N,Q)|0,a=Math.imul(N,tt),n=n+Math.imul(D,rt)|0,i=(i=i+Math.imul(D,nt)|0)+Math.imul(R,rt)|0,a=a+Math.imul(R,nt)|0,n=n+Math.imul(O,at)|0,i=(i=i+Math.imul(O,ot)|0)+Math.imul(z,at)|0,a=a+Math.imul(z,ot)|0,n=n+Math.imul(C,lt)|0,i=(i=i+Math.imul(C,ct)|0)+Math.imul(L,lt)|0,a=a+Math.imul(L,ct)|0,n=n+Math.imul(M,ht)|0,i=(i=i+Math.imul(M,ft)|0)+Math.imul(S,ht)|0,a=a+Math.imul(S,ft)|0;var Ct=(c+(n=n+Math.imul(k,dt)|0)|0)+((8191&(i=(i=i+Math.imul(k,gt)|0)+Math.imul(T,dt)|0))<<13)|0;c=((a=a+Math.imul(T,gt)|0)+(i>>>13)|0)+(Ct>>>26)|0,Ct&=67108863,n=Math.imul(B,rt),i=(i=Math.imul(B,nt))+Math.imul(N,rt)|0,a=Math.imul(N,nt),n=n+Math.imul(D,at)|0,i=(i=i+Math.imul(D,ot)|0)+Math.imul(R,at)|0,a=a+Math.imul(R,ot)|0,n=n+Math.imul(O,lt)|0,i=(i=i+Math.imul(O,ct)|0)+Math.imul(z,lt)|0,a=a+Math.imul(z,ct)|0,n=n+Math.imul(C,ht)|0,i=(i=i+Math.imul(C,ft)|0)+Math.imul(L,ht)|0,a=a+Math.imul(L,ft)|0;var Lt=(c+(n=n+Math.imul(M,dt)|0)|0)+((8191&(i=(i=i+Math.imul(M,gt)|0)+Math.imul(S,dt)|0))<<13)|0;c=((a=a+Math.imul(S,gt)|0)+(i>>>13)|0)+(Lt>>>26)|0,Lt&=67108863,n=Math.imul(B,at),i=(i=Math.imul(B,ot))+Math.imul(N,at)|0,a=Math.imul(N,ot),n=n+Math.imul(D,lt)|0,i=(i=i+Math.imul(D,ct)|0)+Math.imul(R,lt)|0,a=a+Math.imul(R,ct)|0,n=n+Math.imul(O,ht)|0,i=(i=i+Math.imul(O,ft)|0)+Math.imul(z,ht)|0,a=a+Math.imul(z,ft)|0;var Pt=(c+(n=n+Math.imul(C,dt)|0)|0)+((8191&(i=(i=i+Math.imul(C,gt)|0)+Math.imul(L,dt)|0))<<13)|0;c=((a=a+Math.imul(L,gt)|0)+(i>>>13)|0)+(Pt>>>26)|0,Pt&=67108863,n=Math.imul(B,lt),i=(i=Math.imul(B,ct))+Math.imul(N,lt)|0,a=Math.imul(N,ct),n=n+Math.imul(D,ht)|0,i=(i=i+Math.imul(D,ft)|0)+Math.imul(R,ht)|0,a=a+Math.imul(R,ft)|0;var Ot=(c+(n=n+Math.imul(O,dt)|0)|0)+((8191&(i=(i=i+Math.imul(O,gt)|0)+Math.imul(z,dt)|0))<<13)|0;c=((a=a+Math.imul(z,gt)|0)+(i>>>13)|0)+(Ot>>>26)|0,Ot&=67108863,n=Math.imul(B,ht),i=(i=Math.imul(B,ft))+Math.imul(N,ht)|0,a=Math.imul(N,ft);var zt=(c+(n=n+Math.imul(D,dt)|0)|0)+((8191&(i=(i=i+Math.imul(D,gt)|0)+Math.imul(R,dt)|0))<<13)|0;c=((a=a+Math.imul(R,gt)|0)+(i>>>13)|0)+(zt>>>26)|0,zt&=67108863;var It=(c+(n=Math.imul(B,dt))|0)+((8191&(i=(i=Math.imul(B,gt))+Math.imul(N,dt)|0))<<13)|0;return c=((a=Math.imul(N,gt))+(i>>>13)|0)+(It>>>26)|0,It&=67108863,l[0]=vt,l[1]=mt,l[2]=yt,l[3]=xt,l[4]=bt,l[5]=_t,l[6]=wt,l[7]=kt,l[8]=Tt,l[9]=At,l[10]=Mt,l[11]=St,l[12]=Et,l[13]=Ct,l[14]=Lt,l[15]=Pt,l[16]=Ot,l[17]=zt,l[18]=It,0!==c&&(l[19]=c,r.length++),r};function d(t,e,r){return(new g).mulp(t,e,r)}function g(t,e){this.x=t,this.y=e}Math.imul||(p=f),a.prototype.mulTo=function(t,e){var r=this.length+t.length;return 10===this.length&&10===t.length?p(this,t,e):r<63?f(this,t,e):r<1024?function(t,e,r){r.negative=e.negative^t.negative,r.length=t.length+e.length;for(var n=0,i=0,a=0;a<r.length-1;a++){var o=i;i=0;for(var s=67108863&n,l=Math.min(a,e.length-1),c=Math.max(0,a-t.length+1);c<=l;c++){var u=a-c,h=(0|t.words[u])*(0|e.words[c]),f=67108863&h;s=67108863&(f=f+s|0),i+=(o=(o=o+(h/67108864|0)|0)+(f>>>26)|0)>>>26,o&=67108863}r.words[a]=s,n=o,o=i}return 0!==n?r.words[a]=n:r.length--,r.strip()}(this,t,e):d(this,t,e)},g.prototype.makeRBT=function(t){for(var e=new Array(t),r=a.prototype._countBits(t)-1,n=0;n<t;n++)e[n]=this.revBin(n,r,t);return e},g.prototype.revBin=function(t,e,r){if(0===t||t===r-1)return t;for(var n=0,i=0;i<e;i++)n|=(1&t)<<e-i-1,t>>=1;return n},g.prototype.permute=function(t,e,r,n,i,a){for(var o=0;o<a;o++)n[o]=e[t[o]],i[o]=r[t[o]]},g.prototype.transform=function(t,e,r,n,i,a){this.permute(a,t,e,r,n,i);for(var o=1;o<i;o<<=1)for(var s=o<<1,l=Math.cos(2*Math.PI/s),c=Math.sin(2*Math.PI/s),u=0;u<i;u+=s)for(var h=l,f=c,p=0;p<o;p++){var d=r[u+p],g=n[u+p],v=r[u+p+o],m=n[u+p+o],y=h*v-f*m;m=h*m+f*v,v=y,r[u+p]=d+v,n[u+p]=g+m,r[u+p+o]=d-v,n[u+p+o]=g-m,p!==s&&(y=l*h-c*f,f=l*f+c*h,h=y)}},g.prototype.guessLen13b=function(t,e){var r=1|Math.max(e,t),n=1&r,i=0;for(r=r/2|0;r;r>>>=1)i++;return 1<<i+1+n},g.prototype.conjugate=function(t,e,r){if(!(r<=1))for(var n=0;n<r/2;n++){var i=t[n];t[n]=t[r-n-1],t[r-n-1]=i,i=e[n],e[n]=-e[r-n-1],e[r-n-1]=-i}},g.prototype.normalize13b=function(t,e){for(var r=0,n=0;n<e/2;n++){var i=8192*Math.round(t[2*n+1]/e)+Math.round(t[2*n]/e)+r;t[n]=67108863&i,r=i<67108864?0:i/67108864|0}return t},g.prototype.convert13b=function(t,e,r,i){for(var a=0,o=0;o<e;o++)a+=0|t[o],r[2*o]=8191&a,a>>>=13,r[2*o+1]=8191&a,a>>>=13;for(o=2*e;o<i;++o)r[o]=0;n(0===a),n(0==(-8192&a))},g.prototype.stub=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=0;return e},g.prototype.mulp=function(t,e,r){var n=2*this.guessLen13b(t.length,e.length),i=this.makeRBT(n),a=this.stub(n),o=new Array(n),s=new Array(n),l=new Array(n),c=new Array(n),u=new Array(n),h=new Array(n),f=r.words;f.length=n,this.convert13b(t.words,t.length,o,n),this.convert13b(e.words,e.length,c,n),this.transform(o,a,s,l,n,i),this.transform(c,a,u,h,n,i);for(var p=0;p<n;p++){var d=s[p]*u[p]-l[p]*h[p];l[p]=s[p]*h[p]+l[p]*u[p],s[p]=d}return this.conjugate(s,l,n),this.transform(s,l,f,a,n,i),this.conjugate(f,a,n),this.normalize13b(f,n),r.negative=t.negative^e.negative,r.length=t.length+e.length,r.strip()},a.prototype.mul=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),this.mulTo(t,e)},a.prototype.mulf=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),d(this,t,e)},a.prototype.imul=function(t){return this.clone().mulTo(t,this)},a.prototype.imuln=function(t){n(\"number\"==typeof t),n(t<67108864);for(var e=0,r=0;r<this.length;r++){var i=(0|this.words[r])*t,a=(67108863&i)+(67108863&e);e>>=26,e+=i/67108864|0,e+=a>>>26,this.words[r]=67108863&a}return 0!==e&&(this.words[r]=e,this.length++),this},a.prototype.muln=function(t){return this.clone().imuln(t)},a.prototype.sqr=function(){return this.mul(this)},a.prototype.isqr=function(){return this.imul(this.clone())},a.prototype.pow=function(t){var e=function(t){for(var e=new Array(t.bitLength()),r=0;r<e.length;r++){var n=r/26|0,i=r%26;e[r]=(t.words[n]&1<<i)>>>i}return e}(t);if(0===e.length)return new a(1);for(var r=this,n=0;n<e.length&&0===e[n];n++,r=r.sqr());if(++n<e.length)for(var i=r.sqr();n<e.length;n++,i=i.sqr())0!==e[n]&&(r=r.mul(i));return r},a.prototype.iushln=function(t){n(\"number\"==typeof t&&t>=0);var e,r=t%26,i=(t-r)/26,a=67108863>>>26-r<<26-r;if(0!==r){var o=0;for(e=0;e<this.length;e++){var s=this.words[e]&a,l=(0|this.words[e])-s<<r;this.words[e]=l|o,o=s>>>26-r}o&&(this.words[e]=o,this.length++)}if(0!==i){for(e=this.length-1;e>=0;e--)this.words[e+i]=this.words[e];for(e=0;e<i;e++)this.words[e]=0;this.length+=i}return this.strip()},a.prototype.ishln=function(t){return n(0===this.negative),this.iushln(t)},a.prototype.iushrn=function(t,e,r){var i;n(\"number\"==typeof t&&t>=0),i=e?(e-e%26)/26:0;var a=t%26,o=Math.min((t-a)/26,this.length),s=67108863^67108863>>>a<<a,l=r;if(i-=o,i=Math.max(0,i),l){for(var c=0;c<o;c++)l.words[c]=this.words[c];l.length=o}if(0===o);else if(this.length>o)for(this.length-=o,c=0;c<this.length;c++)this.words[c]=this.words[c+o];else this.words[0]=0,this.length=1;var u=0;for(c=this.length-1;c>=0&&(0!==u||c>=i);c--){var h=0|this.words[c];this.words[c]=u<<26-a|h>>>a,u=h&s}return l&&0!==u&&(l.words[l.length++]=u),0===this.length&&(this.words[0]=0,this.length=1),this.strip()},a.prototype.ishrn=function(t,e,r){return n(0===this.negative),this.iushrn(t,e,r)},a.prototype.shln=function(t){return this.clone().ishln(t)},a.prototype.ushln=function(t){return this.clone().iushln(t)},a.prototype.shrn=function(t){return this.clone().ishrn(t)},a.prototype.ushrn=function(t){return this.clone().iushrn(t)},a.prototype.testn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26,i=1<<e;return!(this.length<=r)&&!!(this.words[r]&i)},a.prototype.imaskn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26;if(n(0===this.negative,\"imaskn works only with positive numbers\"),this.length<=r)return this;if(0!==e&&r++,this.length=Math.min(r,this.length),0!==e){var i=67108863^67108863>>>e<<e;this.words[this.length-1]&=i}return this.strip()},a.prototype.maskn=function(t){return this.clone().imaskn(t)},a.prototype.iaddn=function(t){return n(\"number\"==typeof t),n(t<67108864),t<0?this.isubn(-t):0!==this.negative?1===this.length&&(0|this.words[0])<t?(this.words[0]=t-(0|this.words[0]),this.negative=0,this):(this.negative=0,this.isubn(t),this.negative=1,this):this._iaddn(t)},a.prototype._iaddn=function(t){this.words[0]+=t;for(var e=0;e<this.length&&this.words[e]>=67108864;e++)this.words[e]-=67108864,e===this.length-1?this.words[e+1]=1:this.words[e+1]++;return this.length=Math.max(this.length,e+1),this},a.prototype.isubn=function(t){if(n(\"number\"==typeof t),n(t<67108864),t<0)return this.iaddn(-t);if(0!==this.negative)return this.negative=0,this.iaddn(t),this.negative=1,this;if(this.words[0]-=t,1===this.length&&this.words[0]<0)this.words[0]=-this.words[0],this.negative=1;else for(var e=0;e<this.length&&this.words[e]<0;e++)this.words[e]+=67108864,this.words[e+1]-=1;return this.strip()},a.prototype.addn=function(t){return this.clone().iaddn(t)},a.prototype.subn=function(t){return this.clone().isubn(t)},a.prototype.iabs=function(){return this.negative=0,this},a.prototype.abs=function(){return this.clone().iabs()},a.prototype._ishlnsubmul=function(t,e,r){var i,a,o=t.length+r;this._expand(o);var s=0;for(i=0;i<t.length;i++){a=(0|this.words[i+r])+s;var l=(0|t.words[i])*e;s=((a-=67108863&l)>>26)-(l/67108864|0),this.words[i+r]=67108863&a}for(;i<this.length-r;i++)s=(a=(0|this.words[i+r])+s)>>26,this.words[i+r]=67108863&a;if(0===s)return this.strip();for(n(-1===s),s=0,i=0;i<this.length;i++)s=(a=-(0|this.words[i])+s)>>26,this.words[i]=67108863&a;return this.negative=1,this.strip()},a.prototype._wordDiv=function(t,e){var r=(this.length,t.length),n=this.clone(),i=t,o=0|i.words[i.length-1];0!==(r=26-this._countBits(o))&&(i=i.ushln(r),n.iushln(r),o=0|i.words[i.length-1]);var s,l=n.length-i.length;if(\"mod\"!==e){(s=new a(null)).length=l+1,s.words=new Array(s.length);for(var c=0;c<s.length;c++)s.words[c]=0}var u=n.clone()._ishlnsubmul(i,1,l);0===u.negative&&(n=u,s&&(s.words[l]=1));for(var h=l-1;h>=0;h--){var f=67108864*(0|n.words[i.length+h])+(0|n.words[i.length+h-1]);for(f=Math.min(f/o|0,67108863),n._ishlnsubmul(i,f,h);0!==n.negative;)f--,n.negative=0,n._ishlnsubmul(i,1,h),n.isZero()||(n.negative^=1);s&&(s.words[h]=f)}return s&&s.strip(),n.strip(),\"div\"!==e&&0!==r&&n.iushrn(r),{div:s||null,mod:n}},a.prototype.divmod=function(t,e,r){return n(!t.isZero()),this.isZero()?{div:new a(0),mod:new a(0)}:0!==this.negative&&0===t.negative?(s=this.neg().divmod(t,e),\"mod\"!==e&&(i=s.div.neg()),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.iadd(t)),{div:i,mod:o}):0===this.negative&&0!==t.negative?(s=this.divmod(t.neg(),e),\"mod\"!==e&&(i=s.div.neg()),{div:i,mod:s.mod}):0!=(this.negative&t.negative)?(s=this.neg().divmod(t.neg(),e),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.isub(t)),{div:s.div,mod:o}):t.length>this.length||this.cmp(t)<0?{div:new a(0),mod:this}:1===t.length?\"div\"===e?{div:this.divn(t.words[0]),mod:null}:\"mod\"===e?{div:null,mod:new a(this.modn(t.words[0]))}:{div:this.divn(t.words[0]),mod:new a(this.modn(t.words[0]))}:this._wordDiv(t,e);var i,o,s},a.prototype.div=function(t){return this.divmod(t,\"div\",!1).div},a.prototype.mod=function(t){return this.divmod(t,\"mod\",!1).mod},a.prototype.umod=function(t){return this.divmod(t,\"mod\",!0).mod},a.prototype.divRound=function(t){var e=this.divmod(t);if(e.mod.isZero())return e.div;var r=0!==e.div.negative?e.mod.isub(t):e.mod,n=t.ushrn(1),i=t.andln(1),a=r.cmp(n);return a<0||1===i&&0===a?e.div:0!==e.div.negative?e.div.isubn(1):e.div.iaddn(1)},a.prototype.modn=function(t){n(t<=67108863);for(var e=(1<<26)%t,r=0,i=this.length-1;i>=0;i--)r=(e*r+(0|this.words[i]))%t;return r},a.prototype.idivn=function(t){n(t<=67108863);for(var e=0,r=this.length-1;r>=0;r--){var i=(0|this.words[r])+67108864*e;this.words[r]=i/t|0,e=i%t}return this.strip()},a.prototype.divn=function(t){return this.clone().idivn(t)},a.prototype.egcd=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i=new a(1),o=new a(0),s=new a(0),l=new a(1),c=0;e.isEven()&&r.isEven();)e.iushrn(1),r.iushrn(1),++c;for(var u=r.clone(),h=e.clone();!e.isZero();){for(var f=0,p=1;0==(e.words[0]&p)&&f<26;++f,p<<=1);if(f>0)for(e.iushrn(f);f-- >0;)(i.isOdd()||o.isOdd())&&(i.iadd(u),o.isub(h)),i.iushrn(1),o.iushrn(1);for(var d=0,g=1;0==(r.words[0]&g)&&d<26;++d,g<<=1);if(d>0)for(r.iushrn(d);d-- >0;)(s.isOdd()||l.isOdd())&&(s.iadd(u),l.isub(h)),s.iushrn(1),l.iushrn(1);e.cmp(r)>=0?(e.isub(r),i.isub(s),o.isub(l)):(r.isub(e),s.isub(i),l.isub(o))}return{a:s,b:l,gcd:r.iushln(c)}},a.prototype._invmp=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i,o=new a(1),s=new a(0),l=r.clone();e.cmpn(1)>0&&r.cmpn(1)>0;){for(var c=0,u=1;0==(e.words[0]&u)&&c<26;++c,u<<=1);if(c>0)for(e.iushrn(c);c-- >0;)o.isOdd()&&o.iadd(l),o.iushrn(1);for(var h=0,f=1;0==(r.words[0]&f)&&h<26;++h,f<<=1);if(h>0)for(r.iushrn(h);h-- >0;)s.isOdd()&&s.iadd(l),s.iushrn(1);e.cmp(r)>=0?(e.isub(r),o.isub(s)):(r.isub(e),s.isub(o))}return(i=0===e.cmpn(1)?o:s).cmpn(0)<0&&i.iadd(t),i},a.prototype.gcd=function(t){if(this.isZero())return t.abs();if(t.isZero())return this.abs();var e=this.clone(),r=t.clone();e.negative=0,r.negative=0;for(var n=0;e.isEven()&&r.isEven();n++)e.iushrn(1),r.iushrn(1);for(;;){for(;e.isEven();)e.iushrn(1);for(;r.isEven();)r.iushrn(1);var i=e.cmp(r);if(i<0){var a=e;e=r,r=a}else if(0===i||0===r.cmpn(1))break;e.isub(r)}return r.iushln(n)},a.prototype.invm=function(t){return this.egcd(t).a.umod(t)},a.prototype.isEven=function(){return 0==(1&this.words[0])},a.prototype.isOdd=function(){return 1==(1&this.words[0])},a.prototype.andln=function(t){return this.words[0]&t},a.prototype.bincn=function(t){n(\"number\"==typeof t);var e=t%26,r=(t-e)/26,i=1<<e;if(this.length<=r)return this._expand(r+1),this.words[r]|=i,this;for(var a=i,o=r;0!==a&&o<this.length;o++){var s=0|this.words[o];a=(s+=a)>>>26,s&=67108863,this.words[o]=s}return 0!==a&&(this.words[o]=a,this.length++),this},a.prototype.isZero=function(){return 1===this.length&&0===this.words[0]},a.prototype.cmpn=function(t){var e,r=t<0;if(0!==this.negative&&!r)return-1;if(0===this.negative&&r)return 1;if(this.strip(),this.length>1)e=1;else{r&&(t=-t),n(t<=67108863,\"Number is too big\");var i=0|this.words[0];e=i===t?0:i<t?-1:1}return 0!==this.negative?0|-e:e},a.prototype.cmp=function(t){if(0!==this.negative&&0===t.negative)return-1;if(0===this.negative&&0!==t.negative)return 1;var e=this.ucmp(t);return 0!==this.negative?0|-e:e},a.prototype.ucmp=function(t){if(this.length>t.length)return 1;if(this.length<t.length)return-1;for(var e=0,r=this.length-1;r>=0;r--){var n=0|this.words[r],i=0|t.words[r];if(n!==i){n<i?e=-1:n>i&&(e=1);break}}return e},a.prototype.gtn=function(t){return 1===this.cmpn(t)},a.prototype.gt=function(t){return 1===this.cmp(t)},a.prototype.gten=function(t){return this.cmpn(t)>=0},a.prototype.gte=function(t){return this.cmp(t)>=0},a.prototype.ltn=function(t){return-1===this.cmpn(t)},a.prototype.lt=function(t){return-1===this.cmp(t)},a.prototype.lten=function(t){return this.cmpn(t)<=0},a.prototype.lte=function(t){return this.cmp(t)<=0},a.prototype.eqn=function(t){return 0===this.cmpn(t)},a.prototype.eq=function(t){return 0===this.cmp(t)},a.red=function(t){return new w(t)},a.prototype.toRed=function(t){return n(!this.red,\"Already a number in reduction context\"),n(0===this.negative,\"red works only with positives\"),t.convertTo(this)._forceRed(t)},a.prototype.fromRed=function(){return n(this.red,\"fromRed works only with numbers in reduction context\"),this.red.convertFrom(this)},a.prototype._forceRed=function(t){return this.red=t,this},a.prototype.forceRed=function(t){return n(!this.red,\"Already a number in reduction context\"),this._forceRed(t)},a.prototype.redAdd=function(t){return n(this.red,\"redAdd works only with red numbers\"),this.red.add(this,t)},a.prototype.redIAdd=function(t){return n(this.red,\"redIAdd works only with red numbers\"),this.red.iadd(this,t)},a.prototype.redSub=function(t){return n(this.red,\"redSub works only with red numbers\"),this.red.sub(this,t)},a.prototype.redISub=function(t){return n(this.red,\"redISub works only with red numbers\"),this.red.isub(this,t)},a.prototype.redShl=function(t){return n(this.red,\"redShl works only with red numbers\"),this.red.shl(this,t)},a.prototype.redMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.mul(this,t)},a.prototype.redIMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.imul(this,t)},a.prototype.redSqr=function(){return n(this.red,\"redSqr works only with red numbers\"),this.red._verify1(this),this.red.sqr(this)},a.prototype.redISqr=function(){return n(this.red,\"redISqr works only with red numbers\"),this.red._verify1(this),this.red.isqr(this)},a.prototype.redSqrt=function(){return n(this.red,\"redSqrt works only with red numbers\"),this.red._verify1(this),this.red.sqrt(this)},a.prototype.redInvm=function(){return n(this.red,\"redInvm works only with red numbers\"),this.red._verify1(this),this.red.invm(this)},a.prototype.redNeg=function(){return n(this.red,\"redNeg works only with red numbers\"),this.red._verify1(this),this.red.neg(this)},a.prototype.redPow=function(t){return n(this.red&&!t.red,\"redPow(normalNum)\"),this.red._verify1(this),this.red.pow(this,t)};var v={k256:null,p224:null,p192:null,p25519:null};function m(t,e){this.name=t,this.p=new a(e,16),this.n=this.p.bitLength(),this.k=new a(1).iushln(this.n).isub(this.p),this.tmp=this._tmp()}function y(){m.call(this,\"k256\",\"ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffe fffffc2f\")}function x(){m.call(this,\"p224\",\"ffffffff ffffffff ffffffff ffffffff 00000000 00000000 00000001\")}function b(){m.call(this,\"p192\",\"ffffffff ffffffff ffffffff fffffffe ffffffff ffffffff\")}function _(){m.call(this,\"25519\",\"7fffffffffffffff ffffffffffffffff ffffffffffffffff ffffffffffffffed\")}function w(t){if(\"string\"==typeof t){var e=a._prime(t);this.m=e.p,this.prime=e}else n(t.gtn(1),\"modulus must be greater than 1\"),this.m=t,this.prime=null}function k(t){w.call(this,t),this.shift=this.m.bitLength(),this.shift%26!=0&&(this.shift+=26-this.shift%26),this.r=new a(1).iushln(this.shift),this.r2=this.imod(this.r.sqr()),this.rinv=this.r._invmp(this.m),this.minv=this.rinv.mul(this.r).isubn(1).div(this.m),this.minv=this.minv.umod(this.r),this.minv=this.r.sub(this.minv)}m.prototype._tmp=function(){var t=new a(null);return t.words=new Array(Math.ceil(this.n/13)),t},m.prototype.ireduce=function(t){var e,r=t;do{this.split(r,this.tmp),e=(r=(r=this.imulK(r)).iadd(this.tmp)).bitLength()}while(e>this.n);var n=e<this.n?-1:r.ucmp(this.p);return 0===n?(r.words[0]=0,r.length=1):n>0?r.isub(this.p):r.strip(),r},m.prototype.split=function(t,e){t.iushrn(this.n,0,e)},m.prototype.imulK=function(t){return t.imul(this.k)},i(y,m),y.prototype.split=function(t,e){for(var r=Math.min(t.length,9),n=0;n<r;n++)e.words[n]=t.words[n];if(e.length=r,t.length<=9)return t.words[0]=0,void(t.length=1);var i=t.words[9];for(e.words[e.length++]=4194303&i,n=10;n<t.length;n++){var a=0|t.words[n];t.words[n-10]=(4194303&a)<<4|i>>>22,i=a}i>>>=22,t.words[n-10]=i,0===i&&t.length>10?t.length-=10:t.length-=9},y.prototype.imulK=function(t){t.words[t.length]=0,t.words[t.length+1]=0,t.length+=2;for(var e=0,r=0;r<t.length;r++){var n=0|t.words[r];e+=977*n,t.words[r]=67108863&e,e=64*n+(e/67108864|0)}return 0===t.words[t.length-1]&&(t.length--,0===t.words[t.length-1]&&t.length--),t},i(x,m),i(b,m),i(_,m),_.prototype.imulK=function(t){for(var e=0,r=0;r<t.length;r++){var n=19*(0|t.words[r])+e,i=67108863&n;n>>>=26,t.words[r]=i,e=n}return 0!==e&&(t.words[t.length++]=e),t},a._prime=function(t){if(v[t])return v[t];var e;if(\"k256\"===t)e=new y;else if(\"p224\"===t)e=new x;else if(\"p192\"===t)e=new b;else{if(\"p25519\"!==t)throw new Error(\"Unknown prime \"+t);e=new _}return v[t]=e,e},w.prototype._verify1=function(t){n(0===t.negative,\"red works only with positives\"),n(t.red,\"red works only with red numbers\")},w.prototype._verify2=function(t,e){n(0==(t.negative|e.negative),\"red works only with positives\"),n(t.red&&t.red===e.red,\"red works only with red numbers\")},w.prototype.imod=function(t){return this.prime?this.prime.ireduce(t)._forceRed(this):t.umod(this.m)._forceRed(this)},w.prototype.neg=function(t){return t.isZero()?t.clone():this.m.sub(t)._forceRed(this)},w.prototype.add=function(t,e){this._verify2(t,e);var r=t.add(e);return r.cmp(this.m)>=0&&r.isub(this.m),r._forceRed(this)},w.prototype.iadd=function(t,e){this._verify2(t,e);var r=t.iadd(e);return r.cmp(this.m)>=0&&r.isub(this.m),r},w.prototype.sub=function(t,e){this._verify2(t,e);var r=t.sub(e);return r.cmpn(0)<0&&r.iadd(this.m),r._forceRed(this)},w.prototype.isub=function(t,e){this._verify2(t,e);var r=t.isub(e);return r.cmpn(0)<0&&r.iadd(this.m),r},w.prototype.shl=function(t,e){return this._verify1(t),this.imod(t.ushln(e))},w.prototype.imul=function(t,e){return this._verify2(t,e),this.imod(t.imul(e))},w.prototype.mul=function(t,e){return this._verify2(t,e),this.imod(t.mul(e))},w.prototype.isqr=function(t){return this.imul(t,t.clone())},w.prototype.sqr=function(t){return this.mul(t,t)},w.prototype.sqrt=function(t){if(t.isZero())return t.clone();var e=this.m.andln(3);if(n(e%2==1),3===e){var r=this.m.add(new a(1)).iushrn(2);return this.pow(t,r)}for(var i=this.m.subn(1),o=0;!i.isZero()&&0===i.andln(1);)o++,i.iushrn(1);n(!i.isZero());var s=new a(1).toRed(this),l=s.redNeg(),c=this.m.subn(1).iushrn(1),u=this.m.bitLength();for(u=new a(2*u*u).toRed(this);0!==this.pow(u,c).cmp(l);)u.redIAdd(l);for(var h=this.pow(u,i),f=this.pow(t,i.addn(1).iushrn(1)),p=this.pow(t,i),d=o;0!==p.cmp(s);){for(var g=p,v=0;0!==g.cmp(s);v++)g=g.redSqr();n(v<d);var m=this.pow(h,new a(1).iushln(d-v-1));f=f.redMul(m),h=m.redSqr(),p=p.redMul(h),d=v}return f},w.prototype.invm=function(t){var e=t._invmp(this.m);return 0!==e.negative?(e.negative=0,this.imod(e).redNeg()):this.imod(e)},w.prototype.pow=function(t,e){if(e.isZero())return new a(1).toRed(this);if(0===e.cmpn(1))return t.clone();var r=new Array(16);r[0]=new a(1).toRed(this),r[1]=t;for(var n=2;n<r.length;n++)r[n]=this.mul(r[n-1],t);var i=r[0],o=0,s=0,l=e.bitLength()%26;for(0===l&&(l=26),n=e.length-1;n>=0;n--){for(var c=e.words[n],u=l-1;u>=0;u--){var h=c>>u&1;i!==r[0]&&(i=this.sqr(i)),0!==h||0!==o?(o<<=1,o|=h,(4===++s||0===n&&0===u)&&(i=this.mul(i,r[o]),s=0,o=0)):s=0}l=26}return i},w.prototype.convertTo=function(t){var e=t.umod(this.m);return e===t?e.clone():e},w.prototype.convertFrom=function(t){var e=t.clone();return e.red=null,e},a.mont=function(t){return new k(t)},i(k,w),k.prototype.convertTo=function(t){return this.imod(t.ushln(this.shift))},k.prototype.convertFrom=function(t){var e=this.imod(t.mul(this.rinv));return e.red=null,e},k.prototype.imul=function(t,e){if(t.isZero()||e.isZero())return t.words[0]=0,t.length=1,t;var r=t.imul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),a=i;return i.cmp(this.m)>=0?a=i.isub(this.m):i.cmpn(0)<0&&(a=i.iadd(this.m)),a._forceRed(this)},k.prototype.mul=function(t,e){if(t.isZero()||e.isZero())return new a(0)._forceRed(this);var r=t.mul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),o=i;return i.cmp(this.m)>=0?o=i.isub(this.m):i.cmpn(0)<0&&(o=i.iadd(this.m)),o._forceRed(this)},k.prototype.invm=function(t){return this.imod(t._invmp(this.m).mul(this.r2))._forceRed(this)}}(\"undefined\"==typeof e||e,this)},{buffer:103}],95:[function(t,e,r){\"use strict\";e.exports=function(t){var e,r,n,i=t.length,a=0;for(e=0;e<i;++e)a+=t[e].length;var o=new Array(a),s=0;for(e=0;e<i;++e){var l=t[e],c=l.length;for(r=0;r<c;++r){var u=o[s++]=new Array(c-1),h=0;for(n=0;n<c;++n)n!==r&&(u[h++]=l[n]);if(1&r){var f=u[1];u[1]=u[0],u[0]=f}}}return o}},{}],96:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 1:return n=[],c(i=t,i,u,!0),n;case 2:return\"function\"==typeof e?c(t,t,e,!0):function(t,e){return n=[],c(t,e,u,!1),n}(t,e);case 3:return c(t,e,r,!1);default:throw new Error(\"box-intersect: Invalid arguments\")}var i};var n,i=t(\"typedarray-pool\"),a=t(\"./lib/sweep\"),o=t(\"./lib/intersect\");function s(t,e){for(var r=0;r<t;++r)if(!(e[r]<=e[r+t]))return!0;return!1}function l(t,e,r,n){for(var i=0,a=0,o=0,l=t.length;o<l;++o){var c=t[o];if(!s(e,c)){for(var u=0;u<2*e;++u)r[i++]=c[u];n[a++]=o}}return a}function c(t,e,r,n){var s=t.length,c=e.length;if(!(s<=0||c<=0)){var u=t[0].length>>>1;if(!(u<=0)){var h,f=i.mallocDouble(2*u*s),p=i.mallocInt32(s);if((s=l(t,u,f,p))>0){if(1===u&&n)a.init(s),h=a.sweepComplete(u,r,0,s,f,p,0,s,f,p);else{var d=i.mallocDouble(2*u*c),g=i.mallocInt32(c);(c=l(e,u,d,g))>0&&(a.init(s+c),h=1===u?a.sweepBipartite(u,r,0,s,f,p,0,c,d,g):o(u,r,n,s,f,p,c,d,g),i.free(d),i.free(g))}i.free(f),i.free(p)}return h}}}function u(t,e){n.push([t,e])}},{\"./lib/intersect\":98,\"./lib/sweep\":102,\"typedarray-pool\":545}],97:[function(t,e,r){\"use strict\";var n=\"d\",i=\"ax\",a=\"vv\",o=\"fp\",s=\"es\",l=\"rs\",c=\"re\",u=\"rb\",h=\"ri\",f=\"rp\",p=\"bs\",d=\"be\",g=\"bb\",v=\"bi\",m=\"bp\",y=\"rv\",x=\"Q\",b=[n,i,a,l,c,u,h,p,d,g,v];function _(t){var e=\"bruteForce\"+(t?\"Full\":\"Partial\"),r=[],_=b.slice();t||_.splice(3,0,o);var w=[\"function \"+e+\"(\"+_.join()+\"){\"];function k(e,o){var _=function(t,e,r){var o=\"bruteForce\"+(t?\"Red\":\"Blue\")+(e?\"Flip\":\"\")+(r?\"Full\":\"\"),_=[\"function \",o,\"(\",b.join(),\"){\",\"var \",s,\"=2*\",n,\";\"],w=\"for(var i=\"+l+\",\"+f+\"=\"+s+\"*\"+l+\";i<\"+c+\";++i,\"+f+\"+=\"+s+\"){var x0=\"+u+\"[\"+i+\"+\"+f+\"],x1=\"+u+\"[\"+i+\"+\"+f+\"+\"+n+\"],xi=\"+h+\"[i];\",k=\"for(var j=\"+p+\",\"+m+\"=\"+s+\"*\"+p+\";j<\"+d+\";++j,\"+m+\"+=\"+s+\"){var y0=\"+g+\"[\"+i+\"+\"+m+\"],\"+(r?\"y1=\"+g+\"[\"+i+\"+\"+m+\"+\"+n+\"],\":\"\")+\"yi=\"+v+\"[j];\";return t?_.push(w,x,\":\",k):_.push(k,x,\":\",w),r?_.push(\"if(y1<x0||x1<y0)continue;\"):e?_.push(\"if(y0<=x0||x1<y0)continue;\"):_.push(\"if(y0<x0||x1<y0)continue;\"),_.push(\"for(var k=\"+i+\"+1;k<\"+n+\";++k){var r0=\"+u+\"[k+\"+f+\"],r1=\"+u+\"[k+\"+n+\"+\"+f+\"],b0=\"+g+\"[k+\"+m+\"],b1=\"+g+\"[k+\"+n+\"+\"+m+\"];if(r1<b0||b1<r0)continue \"+x+\";}var \"+y+\"=\"+a+\"(\"),e?_.push(\"yi,xi\"):_.push(\"xi,yi\"),_.push(\");if(\"+y+\"!==void 0)return \"+y+\";}}}\"),{name:o,code:_.join(\"\")}}(e,o,t);r.push(_.code),w.push(\"return \"+_.name+\"(\"+b.join()+\");\")}w.push(\"if(\"+c+\"-\"+l+\">\"+d+\"-\"+p+\"){\"),t?(k(!0,!1),w.push(\"}else{\"),k(!1,!1)):(w.push(\"if(\"+o+\"){\"),k(!0,!0),w.push(\"}else{\"),k(!0,!1),w.push(\"}}else{if(\"+o+\"){\"),k(!1,!0),w.push(\"}else{\"),k(!1,!1),w.push(\"}\")),w.push(\"}}return \"+e);var T=r.join(\"\")+w.join(\"\");return new Function(T)()}r.partial=_(!1),r.full=_(!0)},{}],98:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,u,S,E,C,L){!function(t,e){var r=8*i.log2(e+1)*(t+1)|0,a=i.nextPow2(b*r);w.length<a&&(n.free(w),w=n.mallocInt32(a));var o=i.nextPow2(_*r);k<o&&(n.free(k),k=n.mallocDouble(o))}(t,a+E);var P,O=0,z=2*t;T(O++,0,0,a,0,E,r?16:0,-1/0,1/0),r||T(O++,0,0,E,0,a,1,-1/0,1/0);for(;O>0;){var I=(O-=1)*b,D=w[I],R=w[I+1],F=w[I+2],B=w[I+3],N=w[I+4],j=w[I+5],U=O*_,V=k[U],q=k[U+1],H=1&j,G=!!(16&j),Y=u,W=S,X=C,Z=L;if(H&&(Y=C,W=L,X=u,Z=S),!(2&j&&(F=v(t,D,R,F,Y,W,q),R>=F)||4&j&&(R=m(t,D,R,F,Y,W,V))>=F)){var J=F-R,K=N-B;if(G){if(t*J*(J+K)<p){if(void 0!==(P=l.scanComplete(t,D,e,R,F,Y,W,B,N,X,Z)))return P;continue}}else{if(t*Math.min(J,K)<h){if(void 0!==(P=o(t,D,e,H,R,F,Y,W,B,N,X,Z)))return P;continue}if(t*J*K<f){if(void 0!==(P=l.scanBipartite(t,D,e,H,R,F,Y,W,B,N,X,Z)))return P;continue}}var $=d(t,D,R,F,Y,W,V,q);if(R<$)if(t*($-R)<h){if(void 0!==(P=s(t,D+1,e,R,$,Y,W,B,N,X,Z)))return P}else if(D===t-2){if(void 0!==(P=H?l.sweepBipartite(t,e,B,N,X,Z,R,$,Y,W):l.sweepBipartite(t,e,R,$,Y,W,B,N,X,Z)))return P}else T(O++,D+1,R,$,B,N,H,-1/0,1/0),T(O++,D+1,B,N,R,$,1^H,-1/0,1/0);if($<F){var Q=c(t,D,B,N,X,Z),tt=X[z*Q+D],et=g(t,D,Q,N,X,Z,tt);if(et<N&&T(O++,D,$,F,et,N,(4|H)+(G?16:0),tt,q),B<Q&&T(O++,D,$,F,B,Q,(2|H)+(G?16:0),V,tt),Q+1===et){if(void 0!==(P=G?M(t,D,e,$,F,Y,W,Q,X,Z[Q]):A(t,D,e,H,$,F,Y,W,Q,X,Z[Q])))return P}else if(Q<et){var rt;if(G){if(rt=y(t,D,$,F,Y,W,tt),$<rt){var nt=g(t,D,$,rt,Y,W,tt);if(D===t-2){if($<nt&&void 0!==(P=l.sweepComplete(t,e,$,nt,Y,W,Q,et,X,Z)))return P;if(nt<rt&&void 0!==(P=l.sweepBipartite(t,e,nt,rt,Y,W,Q,et,X,Z)))return P}else $<nt&&T(O++,D+1,$,nt,Q,et,16,-1/0,1/0),nt<rt&&(T(O++,D+1,nt,rt,Q,et,0,-1/0,1/0),T(O++,D+1,Q,et,nt,rt,1,-1/0,1/0))}}else rt=H?x(t,D,$,F,Y,W,tt):y(t,D,$,F,Y,W,tt),$<rt&&(D===t-2?P=H?l.sweepBipartite(t,e,Q,et,X,Z,$,rt,Y,W):l.sweepBipartite(t,e,$,rt,Y,W,Q,et,X,Z):(T(O++,D+1,$,rt,Q,et,H,-1/0,1/0),T(O++,D+1,Q,et,$,rt,1^H,-1/0,1/0)))}}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./brute\"),o=a.partial,s=a.full,l=t(\"./sweep\"),c=t(\"./median\"),u=t(\"./partition\"),h=128,f=1<<22,p=1<<22,d=u(\"!(lo>=p0)&&!(p1>=hi)\",[\"p0\",\"p1\"]),g=u(\"lo===p0\",[\"p0\"]),v=u(\"lo<p0\",[\"p0\"]),m=u(\"hi<=p0\",[\"p0\"]),y=u(\"lo<=p0&&p0<=hi\",[\"p0\"]),x=u(\"lo<p0&&p0<=hi\",[\"p0\"]),b=6,_=2,w=n.mallocInt32(1024),k=n.mallocDouble(1024);function T(t,e,r,n,i,a,o,s,l){var c=b*t;w[c]=e,w[c+1]=r,w[c+2]=n,w[c+3]=i,w[c+4]=a,w[c+5]=o;var u=_*t;k[u]=s,k[u+1]=l}function A(t,e,r,n,i,a,o,s,l,c,u){var h=2*t,f=l*h,p=c[f+e];t:for(var d=i,g=i*h;d<a;++d,g+=h){var v=o[g+e],m=o[g+e+t];if(!(p<v||m<p)&&(!n||p!==v)){for(var y,x=s[d],b=e+1;b<t;++b){v=o[g+b],m=o[g+b+t];var _=c[f+b],w=c[f+b+t];if(m<_||w<v)continue t}if(void 0!==(y=n?r(u,x):r(x,u)))return y}}}function M(t,e,r,n,i,a,o,s,l,c){var u=2*t,h=s*u,f=l[h+e];t:for(var p=n,d=n*u;p<i;++p,d+=u){var g=o[p];if(g!==c){var v=a[d+e],m=a[d+e+t];if(!(f<v||m<f)){for(var y=e+1;y<t;++y){v=a[d+y],m=a[d+y+t];var x=l[h+y],b=l[h+y+t];if(m<x||b<v)continue t}var _=r(g,c);if(void 0!==_)return _}}}}},{\"./brute\":97,\"./median\":99,\"./partition\":100,\"./sweep\":102,\"bit-twiddle\":92,\"typedarray-pool\":545}],99:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,o,s,l){if(o<=r+1)return r;var c=r,u=o,h=o+r>>>1,f=2*t,p=h,d=s[f*h+e];for(;c<u;){if(u-c<i){a(t,e,c,u,s,l),d=s[f*h+e];break}var g=u-c,v=Math.random()*g+c|0,m=s[f*v+e],y=Math.random()*g+c|0,x=s[f*y+e],b=Math.random()*g+c|0,_=s[f*b+e];m<=x?_>=x?(p=y,d=x):m>=_?(p=v,d=m):(p=b,d=_):x>=_?(p=y,d=x):_>=m?(p=v,d=m):(p=b,d=_);for(var w=f*(u-1),k=f*p,T=0;T<f;++T,++w,++k){var A=s[w];s[w]=s[k],s[k]=A}var M=l[u-1];l[u-1]=l[p],l[p]=M,p=n(t,e,c,u-1,s,l,d);for(var w=f*(u-1),k=f*p,T=0;T<f;++T,++w,++k){var A=s[w];s[w]=s[k],s[k]=A}var M=l[u-1];if(l[u-1]=l[p],l[p]=M,h<p){for(u=p-1;c<u&&s[f*(u-1)+e]===d;)u-=1;u+=1}else{if(!(p<h))break;for(c=p+1;c<u&&s[f*c+e]===d;)c+=1}}return n(t,e,r,h,s,l,s[f*h+e])};var n=t(\"./partition\")(\"lo<p0\",[\"p0\"]),i=8;function a(t,e,r,n,i,a){for(var o=2*t,s=o*(r+1)+e,l=r+1;l<n;++l,s+=o)for(var c=i[s],u=l,h=o*(l-1);u>r&&i[h+e]>c;--u,h-=o){for(var f=h,p=h+o,d=0;d<o;++d,++f,++p){var g=i[f];i[f]=i[p],i[p]=g}var v=a[u];a[u]=a[u-1],a[u-1]=v}}},{\"./partition\":100}],100:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=\"abcdef\".split(\"\").concat(e),i=[];t.indexOf(\"lo\")>=0&&i.push(\"lo=e[k+n]\");t.indexOf(\"hi\")>=0&&i.push(\"hi=e[k+o]\");return r.push(n.replace(\"_\",i.join()).replace(\"$\",t)),Function.apply(void 0,r)};var n=\"for(var j=2*a,k=j*c,l=k,m=c,n=b,o=a+b,p=c;d>p;++p,k+=j){var _;if($)if(m===p)m+=1,l+=j;else{for(var s=0;j>s;++s){var t=e[k+s];e[k+s]=e[l],e[l++]=t}var u=f[p];f[p]=f[m],f[m++]=u}}return m\"},{}],101:[function(t,e,r){\"use strict\";e.exports=function(t,e){e<=4*n?i(0,e-1,t):function t(e,r,h){var f=(r-e+1)/6|0,p=e+f,d=r-f,g=e+r>>1,v=g-f,m=g+f,y=p,x=v,b=g,_=m,w=d,k=e+1,T=r-1,A=0;c(y,x,h)&&(A=y,y=x,x=A);c(_,w,h)&&(A=_,_=w,w=A);c(y,b,h)&&(A=y,y=b,b=A);c(x,b,h)&&(A=x,x=b,b=A);c(y,_,h)&&(A=y,y=_,_=A);c(b,_,h)&&(A=b,b=_,_=A);c(x,w,h)&&(A=x,x=w,w=A);c(x,b,h)&&(A=x,x=b,b=A);c(_,w,h)&&(A=_,_=w,w=A);var M=h[2*x];var S=h[2*x+1];var E=h[2*_];var C=h[2*_+1];var L=2*y;var P=2*b;var O=2*w;var z=2*p;var I=2*g;var D=2*d;for(var R=0;R<2;++R){var F=h[L+R],B=h[P+R],N=h[O+R];h[z+R]=F,h[I+R]=B,h[D+R]=N}o(v,e,h);o(m,r,h);for(var j=k;j<=T;++j)if(u(j,M,S,h))j!==k&&a(j,k,h),++k;else if(!u(j,E,C,h))for(;;){if(u(T,E,C,h)){u(T,M,S,h)?(s(j,k,T,h),++k,--T):(a(j,T,h),--T);break}if(--T<j)break}l(e,k-1,M,S,h);l(r,T+1,E,C,h);k-2-e<=n?i(e,k-2,h):t(e,k-2,h);r-(T+2)<=n?i(T+2,r,h):t(T+2,r,h);T-k<=n?i(k,T,h):t(k,T,h)}(0,e-1,t)};var n=32;function i(t,e,r){for(var n=2*(t+1),i=t+1;i<=e;++i){for(var a=r[n++],o=r[n++],s=i,l=n-2;s-- >t;){var c=r[l-2],u=r[l-1];if(c<a)break;if(c===a&&u<o)break;r[l]=c,r[l+1]=u,l-=2}r[l]=a,r[l+1]=o}}function a(t,e,r){e*=2;var n=r[t*=2],i=r[t+1];r[t]=r[e],r[t+1]=r[e+1],r[e]=n,r[e+1]=i}function o(t,e,r){e*=2,r[t*=2]=r[e],r[t+1]=r[e+1]}function s(t,e,r,n){e*=2,r*=2;var i=n[t*=2],a=n[t+1];n[t]=n[e],n[t+1]=n[e+1],n[e]=n[r],n[e+1]=n[r+1],n[r]=i,n[r+1]=a}function l(t,e,r,n,i){e*=2,i[t*=2]=i[e],i[e]=r,i[t+1]=i[e+1],i[e+1]=n}function c(t,e,r){e*=2;var n=r[t*=2],i=r[e];return!(n<i)&&(n!==i||r[t+1]>r[e+1])}function u(t,e,r,n){var i=n[t*=2];return i<e||i===e&&n[t+1]<r}},{}],102:[function(t,e,r){\"use strict\";e.exports={init:function(t){var e=i.nextPow2(t);s.length<e&&(n.free(s),s=n.mallocInt32(e));l.length<e&&(n.free(l),l=n.mallocInt32(e));c.length<e&&(n.free(c),c=n.mallocInt32(e));u.length<e&&(n.free(u),u=n.mallocInt32(e));h.length<e&&(n.free(h),h=n.mallocInt32(e));f.length<e&&(n.free(f),f=n.mallocInt32(e));var r=8*e;p.length<r&&(n.free(p),p=n.mallocDouble(r))},sweepBipartite:function(t,e,r,n,i,h,f,v,m,y){for(var x=0,b=2*t,_=t-1,w=b-1,k=r;k<n;++k){var T=h[k],A=b*k;p[x++]=i[A+_],p[x++]=-(T+1),p[x++]=i[A+w],p[x++]=T}for(var k=f;k<v;++k){var T=y[k]+o,M=b*k;p[x++]=m[M+_],p[x++]=-T,p[x++]=m[M+w],p[x++]=T}var S=x>>>1;a(p,S);for(var E=0,C=0,k=0;k<S;++k){var L=0|p[2*k+1];if(L>=o)d(c,u,C--,L=L-o|0);else if(L>=0)d(s,l,E--,L);else if(L<=-o){L=-L-o|0;for(var P=0;P<E;++P){var O=e(s[P],L);if(void 0!==O)return O}g(c,u,C++,L)}else{L=-L-1|0;for(var P=0;P<C;++P){var O=e(L,c[P]);if(void 0!==O)return O}g(s,l,E++,L)}}},sweepComplete:function(t,e,r,n,i,o,v,m,y,x){for(var b=0,_=2*t,w=t-1,k=_-1,T=r;T<n;++T){var A=o[T]+1<<1,M=_*T;p[b++]=i[M+w],p[b++]=-A,p[b++]=i[M+k],p[b++]=A}for(var T=v;T<m;++T){var A=x[T]+1<<1,S=_*T;p[b++]=y[S+w],p[b++]=1|-A,p[b++]=y[S+k],p[b++]=1|A}var E=b>>>1;a(p,E);for(var C=0,L=0,P=0,T=0;T<E;++T){var O=0|p[2*T+1],z=1&O;if(T<E-1&&O>>1==p[2*T+3]>>1&&(z=2,T+=1),O<0){for(var I=-(O>>1)-1,D=0;D<P;++D){var R=e(h[D],I);if(void 0!==R)return R}if(0!==z)for(var D=0;D<C;++D){var R=e(s[D],I);if(void 0!==R)return R}if(1!==z)for(var D=0;D<L;++D){var R=e(c[D],I);if(void 0!==R)return R}0===z?g(s,l,C++,I):1===z?g(c,u,L++,I):2===z&&g(h,f,P++,I)}else{var I=(O>>1)-1;0===z?d(s,l,C--,I):1===z?d(c,u,L--,I):2===z&&d(h,f,P--,I)}}},scanBipartite:function(t,e,r,n,i,c,u,h,f,v,m,y){var x=0,b=2*t,_=e,w=e+t,k=1,T=1;n?T=o:k=o;for(var A=i;A<c;++A){var M=A+k,S=b*A;p[x++]=u[S+_],p[x++]=-M,p[x++]=u[S+w],p[x++]=M}for(var A=f;A<v;++A){var M=A+T,E=b*A;p[x++]=m[E+_],p[x++]=-M}var C=x>>>1;a(p,C);for(var L=0,A=0;A<C;++A){var P=0|p[2*A+1];if(P<0){var M=-P,O=!1;if(M>=o?(O=!n,M-=o):(O=!!n,M-=1),O)g(s,l,L++,M);else{var z=y[M],I=b*M,D=m[I+e+1],R=m[I+e+1+t];t:for(var F=0;F<L;++F){var B=s[F],N=b*B;if(!(R<u[N+e+1]||u[N+e+1+t]<D)){for(var j=e+2;j<t;++j)if(m[I+j+t]<u[N+j]||u[N+j+t]<m[I+j])continue t;var U,V=h[B];if(void 0!==(U=n?r(z,V):r(V,z)))return U}}}}else d(s,l,L--,P-k)}},scanComplete:function(t,e,r,n,i,l,c,u,h,f,d){for(var g=0,v=2*t,m=e,y=e+t,x=n;x<i;++x){var b=x+o,_=v*x;p[g++]=l[_+m],p[g++]=-b,p[g++]=l[_+y],p[g++]=b}for(var x=u;x<h;++x){var b=x+1,w=v*x;p[g++]=f[w+m],p[g++]=-b}var k=g>>>1;a(p,k);for(var T=0,x=0;x<k;++x){var A=0|p[2*x+1];if(A<0){var b=-A;if(b>=o)s[T++]=b-o;else{var M=d[b-=1],S=v*b,E=f[S+e+1],C=f[S+e+1+t];t:for(var L=0;L<T;++L){var P=s[L],O=c[P];if(O===M)break;var z=v*P;if(!(C<l[z+e+1]||l[z+e+1+t]<E)){for(var I=e+2;I<t;++I)if(f[S+I+t]<l[z+I]||l[z+I+t]<f[S+I])continue t;var D=r(O,M);if(void 0!==D)return D}}}}else{for(var b=A-o,L=T-1;L>=0;--L)if(s[L]===b){for(var I=L+1;I<T;++I)s[I-1]=s[I];break}--T}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./sort\"),o=1<<28,s=n.mallocInt32(1024),l=n.mallocInt32(1024),c=n.mallocInt32(1024),u=n.mallocInt32(1024),h=n.mallocInt32(1024),f=n.mallocInt32(1024),p=n.mallocDouble(8192);function d(t,e,r,n){var i=e[n],a=t[r-1];t[i]=a,e[a]=i}function g(t,e,r,n){t[r]=n,e[n]=r}},{\"./sort\":101,\"bit-twiddle\":92,\"typedarray-pool\":545}],103:[function(t,e,r){},{}],104:[function(t,e,r){var n=Object.create||function(t){var e=function(){};return e.prototype=t,new e},i=Object.keys||function(t){var e=[];for(var r in t)Object.prototype.hasOwnProperty.call(t,r)&&e.push(r);return r},a=Function.prototype.bind||function(t){var e=this;return function(){return e.apply(t,arguments)}};function o(){this._events&&Object.prototype.hasOwnProperty.call(this,\"_events\")||(this._events=n(null),this._eventsCount=0),this._maxListeners=this._maxListeners||void 0}e.exports=o,o.EventEmitter=o,o.prototype._events=void 0,o.prototype._maxListeners=void 0;var s,l=10;try{var c={};Object.defineProperty&&Object.defineProperty(c,\"x\",{value:0}),s=0===c.x}catch(t){s=!1}function u(t){return void 0===t._maxListeners?o.defaultMaxListeners:t._maxListeners}function h(t,e,r,i){var a,o,s;if(\"function\"!=typeof r)throw new TypeError('\"listener\" argument must be a function');if((o=t._events)?(o.newListener&&(t.emit(\"newListener\",e,r.listener?r.listener:r),o=t._events),s=o[e]):(o=t._events=n(null),t._eventsCount=0),s){if(\"function\"==typeof s?s=o[e]=i?[r,s]:[s,r]:i?s.unshift(r):s.push(r),!s.warned&&(a=u(t))&&a>0&&s.length>a){s.warned=!0;var l=new Error(\"Possible EventEmitter memory leak detected. \"+s.length+' \"'+String(e)+'\" listeners added. Use emitter.setMaxListeners() to increase limit.');l.name=\"MaxListenersExceededWarning\",l.emitter=t,l.type=e,l.count=s.length,\"object\"==typeof console&&console.warn&&console.warn(\"%s: %s\",l.name,l.message)}}else s=o[e]=r,++t._eventsCount;return t}function f(){if(!this.fired)switch(this.target.removeListener(this.type,this.wrapFn),this.fired=!0,arguments.length){case 0:return this.listener.call(this.target);case 1:return this.listener.call(this.target,arguments[0]);case 2:return this.listener.call(this.target,arguments[0],arguments[1]);case 3:return this.listener.call(this.target,arguments[0],arguments[1],arguments[2]);default:for(var t=new Array(arguments.length),e=0;e<t.length;++e)t[e]=arguments[e];this.listener.apply(this.target,t)}}function p(t,e,r){var n={fired:!1,wrapFn:void 0,target:t,type:e,listener:r},i=a.call(f,n);return i.listener=r,n.wrapFn=i,i}function d(t,e,r){var n=t._events;if(!n)return[];var i=n[e];return i?\"function\"==typeof i?r?[i.listener||i]:[i]:r?function(t){for(var e=new Array(t.length),r=0;r<e.length;++r)e[r]=t[r].listener||t[r];return e}(i):v(i,i.length):[]}function g(t){var e=this._events;if(e){var r=e[t];if(\"function\"==typeof r)return 1;if(r)return r.length}return 0}function v(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t[n];return r}s?Object.defineProperty(o,\"defaultMaxListeners\",{enumerable:!0,get:function(){return l},set:function(t){if(\"number\"!=typeof t||t<0||t!=t)throw new TypeError('\"defaultMaxListeners\" must be a positive number');l=t}}):o.defaultMaxListeners=l,o.prototype.setMaxListeners=function(t){if(\"number\"!=typeof t||t<0||isNaN(t))throw new TypeError('\"n\" argument must be a positive number');return this._maxListeners=t,this},o.prototype.getMaxListeners=function(){return u(this)},o.prototype.emit=function(t){var e,r,n,i,a,o,s=\"error\"===t;if(o=this._events)s=s&&null==o.error;else if(!s)return!1;if(s){if(arguments.length>1&&(e=arguments[1]),e instanceof Error)throw e;var l=new Error('Unhandled \"error\" event. ('+e+\")\");throw l.context=e,l}if(!(r=o[t]))return!1;var c=\"function\"==typeof r;switch(n=arguments.length){case 1:!function(t,e,r){if(e)t.call(r);else for(var n=t.length,i=v(t,n),a=0;a<n;++a)i[a].call(r)}(r,c,this);break;case 2:!function(t,e,r,n){if(e)t.call(r,n);else for(var i=t.length,a=v(t,i),o=0;o<i;++o)a[o].call(r,n)}(r,c,this,arguments[1]);break;case 3:!function(t,e,r,n,i){if(e)t.call(r,n,i);else for(var a=t.length,o=v(t,a),s=0;s<a;++s)o[s].call(r,n,i)}(r,c,this,arguments[1],arguments[2]);break;case 4:!function(t,e,r,n,i,a){if(e)t.call(r,n,i,a);else for(var o=t.length,s=v(t,o),l=0;l<o;++l)s[l].call(r,n,i,a)}(r,c,this,arguments[1],arguments[2],arguments[3]);break;default:for(i=new Array(n-1),a=1;a<n;a++)i[a-1]=arguments[a];!function(t,e,r,n){if(e)t.apply(r,n);else for(var i=t.length,a=v(t,i),o=0;o<i;++o)a[o].apply(r,n)}(r,c,this,i)}return!0},o.prototype.addListener=function(t,e){return h(this,t,e,!1)},o.prototype.on=o.prototype.addListener,o.prototype.prependListener=function(t,e){return h(this,t,e,!0)},o.prototype.once=function(t,e){if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');return this.on(t,p(this,t,e)),this},o.prototype.prependOnceListener=function(t,e){if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');return this.prependListener(t,p(this,t,e)),this},o.prototype.removeListener=function(t,e){var r,i,a,o,s;if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');if(!(i=this._events))return this;if(!(r=i[t]))return this;if(r===e||r.listener===e)0==--this._eventsCount?this._events=n(null):(delete i[t],i.removeListener&&this.emit(\"removeListener\",t,r.listener||e));else if(\"function\"!=typeof r){for(a=-1,o=r.length-1;o>=0;o--)if(r[o]===e||r[o].listener===e){s=r[o].listener,a=o;break}if(a<0)return this;0===a?r.shift():function(t,e){for(var r=e,n=r+1,i=t.length;n<i;r+=1,n+=1)t[r]=t[n];t.pop()}(r,a),1===r.length&&(i[t]=r[0]),i.removeListener&&this.emit(\"removeListener\",t,s||e)}return this},o.prototype.removeAllListeners=function(t){var e,r,a;if(!(r=this._events))return this;if(!r.removeListener)return 0===arguments.length?(this._events=n(null),this._eventsCount=0):r[t]&&(0==--this._eventsCount?this._events=n(null):delete r[t]),this;if(0===arguments.length){var o,s=i(r);for(a=0;a<s.length;++a)\"removeListener\"!==(o=s[a])&&this.removeAllListeners(o);return this.removeAllListeners(\"removeListener\"),this._events=n(null),this._eventsCount=0,this}if(\"function\"==typeof(e=r[t]))this.removeListener(t,e);else if(e)for(a=e.length-1;a>=0;a--)this.removeListener(t,e[a]);return this},o.prototype.listeners=function(t){return d(this,t,!0)},o.prototype.rawListeners=function(t){return d(this,t,!1)},o.listenerCount=function(t,e){return\"function\"==typeof t.listenerCount?t.listenerCount(e):g.call(t,e)},o.prototype.listenerCount=g,o.prototype.eventNames=function(){return this._eventsCount>0?Reflect.ownKeys(this._events):[]}},{}],105:[function(t,e,r){(function(e){\"use strict\";var n=t(\"base64-js\"),i=t(\"ieee754\");r.Buffer=e,r.SlowBuffer=function(t){+t!=t&&(t=0);return e.alloc(+t)},r.INSPECT_MAX_BYTES=50;var a=2147483647;function o(t){if(t>a)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"');var r=new Uint8Array(t);return r.__proto__=e.prototype,r}function e(t,e,r){if(\"number\"==typeof t){if(\"string\"==typeof e)throw new TypeError('The \"string\" argument must be of type string. Received type number');return c(t)}return s(t,e,r)}function s(t,r,n){if(\"string\"==typeof t)return function(t,r){\"string\"==typeof r&&\"\"!==r||(r=\"utf8\");if(!e.isEncoding(r))throw new TypeError(\"Unknown encoding: \"+r);var n=0|f(t,r),i=o(n),a=i.write(t,r);a!==n&&(i=i.slice(0,a));return i}(t,r);if(ArrayBuffer.isView(t))return u(t);if(null==t)throw TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t);if(N(t,ArrayBuffer)||t&&N(t.buffer,ArrayBuffer))return function(t,r,n){if(r<0||t.byteLength<r)throw new RangeError('\"offset\" is outside of buffer bounds');if(t.byteLength<r+(n||0))throw new RangeError('\"length\" is outside of buffer bounds');var i;i=void 0===r&&void 0===n?new Uint8Array(t):void 0===n?new Uint8Array(t,r):new Uint8Array(t,r,n);return i.__proto__=e.prototype,i}(t,r,n);if(\"number\"==typeof t)throw new TypeError('The \"value\" argument must not be of type number. Received type number');var i=t.valueOf&&t.valueOf();if(null!=i&&i!==t)return e.from(i,r,n);var a=function(t){if(e.isBuffer(t)){var r=0|h(t.length),n=o(r);return 0===n.length?n:(t.copy(n,0,0,r),n)}if(void 0!==t.length)return\"number\"!=typeof t.length||j(t.length)?o(0):u(t);if(\"Buffer\"===t.type&&Array.isArray(t.data))return u(t.data)}(t);if(a)return a;if(\"undefined\"!=typeof Symbol&&null!=Symbol.toPrimitive&&\"function\"==typeof t[Symbol.toPrimitive])return e.from(t[Symbol.toPrimitive](\"string\"),r,n);throw new TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t)}function l(t){if(\"number\"!=typeof t)throw new TypeError('\"size\" argument must be of type number');if(t<0)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"')}function c(t){return l(t),o(t<0?0:0|h(t))}function u(t){for(var e=t.length<0?0:0|h(t.length),r=o(e),n=0;n<e;n+=1)r[n]=255&t[n];return r}function h(t){if(t>=a)throw new RangeError(\"Attempt to allocate Buffer larger than maximum size: 0x\"+a.toString(16)+\" bytes\");return 0|t}function f(t,r){if(e.isBuffer(t))return t.length;if(ArrayBuffer.isView(t)||N(t,ArrayBuffer))return t.byteLength;if(\"string\"!=typeof t)throw new TypeError('The \"string\" argument must be one of type string, Buffer, or ArrayBuffer. Received type '+typeof t);var n=t.length,i=arguments.length>2&&!0===arguments[2];if(!i&&0===n)return 0;for(var a=!1;;)switch(r){case\"ascii\":case\"latin1\":case\"binary\":return n;case\"utf8\":case\"utf-8\":return R(t).length;case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return 2*n;case\"hex\":return n>>>1;case\"base64\":return F(t).length;default:if(a)return i?-1:R(t).length;r=(\"\"+r).toLowerCase(),a=!0}}function p(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function d(t,r,n,i,a){if(0===t.length)return-1;if(\"string\"==typeof n?(i=n,n=0):n>2147483647?n=2147483647:n<-2147483648&&(n=-2147483648),j(n=+n)&&(n=a?0:t.length-1),n<0&&(n=t.length+n),n>=t.length){if(a)return-1;n=t.length-1}else if(n<0){if(!a)return-1;n=0}if(\"string\"==typeof r&&(r=e.from(r,i)),e.isBuffer(r))return 0===r.length?-1:g(t,r,n,i,a);if(\"number\"==typeof r)return r&=255,\"function\"==typeof Uint8Array.prototype.indexOf?a?Uint8Array.prototype.indexOf.call(t,r,n):Uint8Array.prototype.lastIndexOf.call(t,r,n):g(t,[r],n,i,a);throw new TypeError(\"val must be string, number or Buffer\")}function g(t,e,r,n,i){var a,o=1,s=t.length,l=e.length;if(void 0!==n&&(\"ucs2\"===(n=String(n).toLowerCase())||\"ucs-2\"===n||\"utf16le\"===n||\"utf-16le\"===n)){if(t.length<2||e.length<2)return-1;o=2,s/=2,l/=2,r/=2}function c(t,e){return 1===o?t[e]:t.readUInt16BE(e*o)}if(i){var u=-1;for(a=r;a<s;a++)if(c(t,a)===c(e,-1===u?0:a-u)){if(-1===u&&(u=a),a-u+1===l)return u*o}else-1!==u&&(a-=a-u),u=-1}else for(r+l>s&&(r=s-l),a=r;a>=0;a--){for(var h=!0,f=0;f<l;f++)if(c(t,a+f)!==c(e,f)){h=!1;break}if(h)return a}return-1}function v(t,e,r,n){r=Number(r)||0;var i=t.length-r;n?(n=Number(n))>i&&(n=i):n=i;var a=e.length;n>a/2&&(n=a/2);for(var o=0;o<n;++o){var s=parseInt(e.substr(2*o,2),16);if(j(s))return o;t[r+o]=s}return o}function m(t,e,r,n){return B(R(e,t.length-r),t,r,n)}function y(t,e,r,n){return B(function(t){for(var e=[],r=0;r<t.length;++r)e.push(255&t.charCodeAt(r));return e}(e),t,r,n)}function x(t,e,r,n){return y(t,e,r,n)}function b(t,e,r,n){return B(F(e),t,r,n)}function _(t,e,r,n){return B(function(t,e){for(var r,n,i,a=[],o=0;o<t.length&&!((e-=2)<0);++o)r=t.charCodeAt(o),n=r>>8,i=r%256,a.push(i),a.push(n);return a}(e,t.length-r),t,r,n)}function w(t,e,r){return 0===e&&r===t.length?n.fromByteArray(t):n.fromByteArray(t.slice(e,r))}function k(t,e,r){r=Math.min(t.length,r);for(var n=[],i=e;i<r;){var a,o,s,l,c=t[i],u=null,h=c>239?4:c>223?3:c>191?2:1;if(i+h<=r)switch(h){case 1:c<128&&(u=c);break;case 2:128==(192&(a=t[i+1]))&&(l=(31&c)<<6|63&a)>127&&(u=l);break;case 3:a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&(l=(15&c)<<12|(63&a)<<6|63&o)>2047&&(l<55296||l>57343)&&(u=l);break;case 4:a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&(l=(15&c)<<18|(63&a)<<12|(63&o)<<6|63&s)>65535&&l<1114112&&(u=l)}null===u?(u=65533,h=1):u>65535&&(u-=65536,n.push(u>>>10&1023|55296),u=56320|1023&u),n.push(u),i+=h}return function(t){var e=t.length;if(e<=T)return String.fromCharCode.apply(String,t);var r=\"\",n=0;for(;n<e;)r+=String.fromCharCode.apply(String,t.slice(n,n+=T));return r}(n)}r.kMaxLength=a,e.TYPED_ARRAY_SUPPORT=function(){try{var t=new Uint8Array(1);return t.__proto__={__proto__:Uint8Array.prototype,foo:function(){return 42}},42===t.foo()}catch(t){return!1}}(),e.TYPED_ARRAY_SUPPORT||\"undefined\"==typeof console||\"function\"!=typeof console.error||console.error(\"This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support.\"),Object.defineProperty(e.prototype,\"parent\",{enumerable:!0,get:function(){if(e.isBuffer(this))return this.buffer}}),Object.defineProperty(e.prototype,\"offset\",{enumerable:!0,get:function(){if(e.isBuffer(this))return this.byteOffset}}),\"undefined\"!=typeof Symbol&&null!=Symbol.species&&e[Symbol.species]===e&&Object.defineProperty(e,Symbol.species,{value:null,configurable:!0,enumerable:!1,writable:!1}),e.poolSize=8192,e.from=function(t,e,r){return s(t,e,r)},e.prototype.__proto__=Uint8Array.prototype,e.__proto__=Uint8Array,e.alloc=function(t,e,r){return function(t,e,r){return l(t),t<=0?o(t):void 0!==e?\"string\"==typeof r?o(t).fill(e,r):o(t).fill(e):o(t)}(t,e,r)},e.allocUnsafe=function(t){return c(t)},e.allocUnsafeSlow=function(t){return c(t)},e.isBuffer=function(t){return null!=t&&!0===t._isBuffer&&t!==e.prototype},e.compare=function(t,r){if(N(t,Uint8Array)&&(t=e.from(t,t.offset,t.byteLength)),N(r,Uint8Array)&&(r=e.from(r,r.offset,r.byteLength)),!e.isBuffer(t)||!e.isBuffer(r))throw new TypeError('The \"buf1\", \"buf2\" arguments must be one of type Buffer or Uint8Array');if(t===r)return 0;for(var n=t.length,i=r.length,a=0,o=Math.min(n,i);a<o;++a)if(t[a]!==r[a]){n=t[a],i=r[a];break}return n<i?-1:i<n?1:0},e.isEncoding=function(t){switch(String(t).toLowerCase()){case\"hex\":case\"utf8\":case\"utf-8\":case\"ascii\":case\"latin1\":case\"binary\":case\"base64\":case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return!0;default:return!1}},e.concat=function(t,r){if(!Array.isArray(t))throw new TypeError('\"list\" argument must be an Array of Buffers');if(0===t.length)return e.alloc(0);var n;if(void 0===r)for(r=0,n=0;n<t.length;++n)r+=t[n].length;var i=e.allocUnsafe(r),a=0;for(n=0;n<t.length;++n){var o=t[n];if(N(o,Uint8Array)&&(o=e.from(o)),!e.isBuffer(o))throw new TypeError('\"list\" argument must be an Array of Buffers');o.copy(i,a),a+=o.length}return i},e.byteLength=f,e.prototype._isBuffer=!0,e.prototype.swap16=function(){var t=this.length;if(t%2!=0)throw new RangeError(\"Buffer size must be a multiple of 16-bits\");for(var e=0;e<t;e+=2)p(this,e,e+1);return this},e.prototype.swap32=function(){var t=this.length;if(t%4!=0)throw new RangeError(\"Buffer size must be a multiple of 32-bits\");for(var e=0;e<t;e+=4)p(this,e,e+3),p(this,e+1,e+2);return this},e.prototype.swap64=function(){var t=this.length;if(t%8!=0)throw new RangeError(\"Buffer size must be a multiple of 64-bits\");for(var e=0;e<t;e+=8)p(this,e,e+7),p(this,e+1,e+6),p(this,e+2,e+5),p(this,e+3,e+4);return this},e.prototype.toString=function(){var t=this.length;return 0===t?\"\":0===arguments.length?k(this,0,t):function(t,e,r){var n=!1;if((void 0===e||e<0)&&(e=0),e>this.length)return\"\";if((void 0===r||r>this.length)&&(r=this.length),r<=0)return\"\";if((r>>>=0)<=(e>>>=0))return\"\";for(t||(t=\"utf8\");;)switch(t){case\"hex\":return S(this,e,r);case\"utf8\":case\"utf-8\":return k(this,e,r);case\"ascii\":return A(this,e,r);case\"latin1\":case\"binary\":return M(this,e,r);case\"base64\":return w(this,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return E(this,e,r);default:if(n)throw new TypeError(\"Unknown encoding: \"+t);t=(t+\"\").toLowerCase(),n=!0}}.apply(this,arguments)},e.prototype.toLocaleString=e.prototype.toString,e.prototype.equals=function(t){if(!e.isBuffer(t))throw new TypeError(\"Argument must be a Buffer\");return this===t||0===e.compare(this,t)},e.prototype.inspect=function(){var t=\"\",e=r.INSPECT_MAX_BYTES;return t=this.toString(\"hex\",0,e).replace(/(.{2})/g,\"$1 \").trim(),this.length>e&&(t+=\" ... \"),\"<Buffer \"+t+\">\"},e.prototype.compare=function(t,r,n,i,a){if(N(t,Uint8Array)&&(t=e.from(t,t.offset,t.byteLength)),!e.isBuffer(t))throw new TypeError('The \"target\" argument must be one of type Buffer or Uint8Array. Received type '+typeof t);if(void 0===r&&(r=0),void 0===n&&(n=t?t.length:0),void 0===i&&(i=0),void 0===a&&(a=this.length),r<0||n>t.length||i<0||a>this.length)throw new RangeError(\"out of range index\");if(i>=a&&r>=n)return 0;if(i>=a)return-1;if(r>=n)return 1;if(this===t)return 0;for(var o=(a>>>=0)-(i>>>=0),s=(n>>>=0)-(r>>>=0),l=Math.min(o,s),c=this.slice(i,a),u=t.slice(r,n),h=0;h<l;++h)if(c[h]!==u[h]){o=c[h],s=u[h];break}return o<s?-1:s<o?1:0},e.prototype.includes=function(t,e,r){return-1!==this.indexOf(t,e,r)},e.prototype.indexOf=function(t,e,r){return d(this,t,e,r,!0)},e.prototype.lastIndexOf=function(t,e,r){return d(this,t,e,r,!1)},e.prototype.write=function(t,e,r,n){if(void 0===e)n=\"utf8\",r=this.length,e=0;else if(void 0===r&&\"string\"==typeof e)n=e,r=this.length,e=0;else{if(!isFinite(e))throw new Error(\"Buffer.write(string, encoding, offset[, length]) is no longer supported\");e>>>=0,isFinite(r)?(r>>>=0,void 0===n&&(n=\"utf8\")):(n=r,r=void 0)}var i=this.length-e;if((void 0===r||r>i)&&(r=i),t.length>0&&(r<0||e<0)||e>this.length)throw new RangeError(\"Attempt to write outside buffer bounds\");n||(n=\"utf8\");for(var a=!1;;)switch(n){case\"hex\":return v(this,t,e,r);case\"utf8\":case\"utf-8\":return m(this,t,e,r);case\"ascii\":return y(this,t,e,r);case\"latin1\":case\"binary\":return x(this,t,e,r);case\"base64\":return b(this,t,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return _(this,t,e,r);default:if(a)throw new TypeError(\"Unknown encoding: \"+n);n=(\"\"+n).toLowerCase(),a=!0}},e.prototype.toJSON=function(){return{type:\"Buffer\",data:Array.prototype.slice.call(this._arr||this,0)}};var T=4096;function A(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(127&t[i]);return n}function M(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(t[i]);return n}function S(t,e,r){var n=t.length;(!e||e<0)&&(e=0),(!r||r<0||r>n)&&(r=n);for(var i=\"\",a=e;a<r;++a)i+=D(t[a]);return i}function E(t,e,r){for(var n=t.slice(e,r),i=\"\",a=0;a<n.length;a+=2)i+=String.fromCharCode(n[a]+256*n[a+1]);return i}function C(t,e,r){if(t%1!=0||t<0)throw new RangeError(\"offset is not uint\");if(t+e>r)throw new RangeError(\"Trying to access beyond buffer length\")}function L(t,r,n,i,a,o){if(!e.isBuffer(t))throw new TypeError('\"buffer\" argument must be a Buffer instance');if(r>a||r<o)throw new RangeError('\"value\" argument is out of bounds');if(n+i>t.length)throw new RangeError(\"Index out of range\")}function P(t,e,r,n,i,a){if(r+n>t.length)throw new RangeError(\"Index out of range\");if(r<0)throw new RangeError(\"Index out of range\")}function O(t,e,r,n,a){return e=+e,r>>>=0,a||P(t,0,r,4),i.write(t,e,r,n,23,4),r+4}function z(t,e,r,n,a){return e=+e,r>>>=0,a||P(t,0,r,8),i.write(t,e,r,n,52,8),r+8}e.prototype.slice=function(t,r){var n=this.length;(t=~~t)<0?(t+=n)<0&&(t=0):t>n&&(t=n),(r=void 0===r?n:~~r)<0?(r+=n)<0&&(r=0):r>n&&(r=n),r<t&&(r=t);var i=this.subarray(t,r);return i.__proto__=e.prototype,i},e.prototype.readUIntLE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n},e.prototype.readUIntBE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t+--e],i=1;e>0&&(i*=256);)n+=this[t+--e]*i;return n},e.prototype.readUInt8=function(t,e){return t>>>=0,e||C(t,1,this.length),this[t]},e.prototype.readUInt16LE=function(t,e){return t>>>=0,e||C(t,2,this.length),this[t]|this[t+1]<<8},e.prototype.readUInt16BE=function(t,e){return t>>>=0,e||C(t,2,this.length),this[t]<<8|this[t+1]},e.prototype.readUInt32LE=function(t,e){return t>>>=0,e||C(t,4,this.length),(this[t]|this[t+1]<<8|this[t+2]<<16)+16777216*this[t+3]},e.prototype.readUInt32BE=function(t,e){return t>>>=0,e||C(t,4,this.length),16777216*this[t]+(this[t+1]<<16|this[t+2]<<8|this[t+3])},e.prototype.readIntLE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n>=(i*=128)&&(n-=Math.pow(2,8*e)),n},e.prototype.readIntBE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=e,i=1,a=this[t+--n];n>0&&(i*=256);)a+=this[t+--n]*i;return a>=(i*=128)&&(a-=Math.pow(2,8*e)),a},e.prototype.readInt8=function(t,e){return t>>>=0,e||C(t,1,this.length),128&this[t]?-1*(255-this[t]+1):this[t]},e.prototype.readInt16LE=function(t,e){t>>>=0,e||C(t,2,this.length);var r=this[t]|this[t+1]<<8;return 32768&r?4294901760|r:r},e.prototype.readInt16BE=function(t,e){t>>>=0,e||C(t,2,this.length);var r=this[t+1]|this[t]<<8;return 32768&r?4294901760|r:r},e.prototype.readInt32LE=function(t,e){return t>>>=0,e||C(t,4,this.length),this[t]|this[t+1]<<8|this[t+2]<<16|this[t+3]<<24},e.prototype.readInt32BE=function(t,e){return t>>>=0,e||C(t,4,this.length),this[t]<<24|this[t+1]<<16|this[t+2]<<8|this[t+3]},e.prototype.readFloatLE=function(t,e){return t>>>=0,e||C(t,4,this.length),i.read(this,t,!0,23,4)},e.prototype.readFloatBE=function(t,e){return t>>>=0,e||C(t,4,this.length),i.read(this,t,!1,23,4)},e.prototype.readDoubleLE=function(t,e){return t>>>=0,e||C(t,8,this.length),i.read(this,t,!0,52,8)},e.prototype.readDoubleBE=function(t,e){return t>>>=0,e||C(t,8,this.length),i.read(this,t,!1,52,8)},e.prototype.writeUIntLE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||L(this,t,e,r,Math.pow(2,8*r)-1,0);var i=1,a=0;for(this[e]=255&t;++a<r&&(i*=256);)this[e+a]=t/i&255;return e+r},e.prototype.writeUIntBE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||L(this,t,e,r,Math.pow(2,8*r)-1,0);var i=r-1,a=1;for(this[e+i]=255&t;--i>=0&&(a*=256);)this[e+i]=t/a&255;return e+r},e.prototype.writeUInt8=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,1,255,0),this[e]=255&t,e+1},e.prototype.writeUInt16LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,65535,0),this[e]=255&t,this[e+1]=t>>>8,e+2},e.prototype.writeUInt16BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,65535,0),this[e]=t>>>8,this[e+1]=255&t,e+2},e.prototype.writeUInt32LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,4294967295,0),this[e+3]=t>>>24,this[e+2]=t>>>16,this[e+1]=t>>>8,this[e]=255&t,e+4},e.prototype.writeUInt32BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,4294967295,0),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},e.prototype.writeIntLE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);L(this,t,e,r,i-1,-i)}var a=0,o=1,s=0;for(this[e]=255&t;++a<r&&(o*=256);)t<0&&0===s&&0!==this[e+a-1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},e.prototype.writeIntBE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);L(this,t,e,r,i-1,-i)}var a=r-1,o=1,s=0;for(this[e+a]=255&t;--a>=0&&(o*=256);)t<0&&0===s&&0!==this[e+a+1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},e.prototype.writeInt8=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,1,127,-128),t<0&&(t=255+t+1),this[e]=255&t,e+1},e.prototype.writeInt16LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,32767,-32768),this[e]=255&t,this[e+1]=t>>>8,e+2},e.prototype.writeInt16BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,32767,-32768),this[e]=t>>>8,this[e+1]=255&t,e+2},e.prototype.writeInt32LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,2147483647,-2147483648),this[e]=255&t,this[e+1]=t>>>8,this[e+2]=t>>>16,this[e+3]=t>>>24,e+4},e.prototype.writeInt32BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,2147483647,-2147483648),t<0&&(t=4294967295+t+1),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},e.prototype.writeFloatLE=function(t,e,r){return O(this,t,e,!0,r)},e.prototype.writeFloatBE=function(t,e,r){return O(this,t,e,!1,r)},e.prototype.writeDoubleLE=function(t,e,r){return z(this,t,e,!0,r)},e.prototype.writeDoubleBE=function(t,e,r){return z(this,t,e,!1,r)},e.prototype.copy=function(t,r,n,i){if(!e.isBuffer(t))throw new TypeError(\"argument should be a Buffer\");if(n||(n=0),i||0===i||(i=this.length),r>=t.length&&(r=t.length),r||(r=0),i>0&&i<n&&(i=n),i===n)return 0;if(0===t.length||0===this.length)return 0;if(r<0)throw new RangeError(\"targetStart out of bounds\");if(n<0||n>=this.length)throw new RangeError(\"Index out of range\");if(i<0)throw new RangeError(\"sourceEnd out of bounds\");i>this.length&&(i=this.length),t.length-r<i-n&&(i=t.length-r+n);var a=i-n;if(this===t&&\"function\"==typeof Uint8Array.prototype.copyWithin)this.copyWithin(r,n,i);else if(this===t&&n<r&&r<i)for(var o=a-1;o>=0;--o)t[o+r]=this[o+n];else Uint8Array.prototype.set.call(t,this.subarray(n,i),r);return a},e.prototype.fill=function(t,r,n,i){if(\"string\"==typeof t){if(\"string\"==typeof r?(i=r,r=0,n=this.length):\"string\"==typeof n&&(i=n,n=this.length),void 0!==i&&\"string\"!=typeof i)throw new TypeError(\"encoding must be a string\");if(\"string\"==typeof i&&!e.isEncoding(i))throw new TypeError(\"Unknown encoding: \"+i);if(1===t.length){var a=t.charCodeAt(0);(\"utf8\"===i&&a<128||\"latin1\"===i)&&(t=a)}}else\"number\"==typeof t&&(t&=255);if(r<0||this.length<r||this.length<n)throw new RangeError(\"Out of range index\");if(n<=r)return this;var o;if(r>>>=0,n=void 0===n?this.length:n>>>0,t||(t=0),\"number\"==typeof t)for(o=r;o<n;++o)this[o]=t;else{var s=e.isBuffer(t)?t:e.from(t,i),l=s.length;if(0===l)throw new TypeError('The value \"'+t+'\" is invalid for argument \"value\"');for(o=0;o<n-r;++o)this[o+r]=s[o%l]}return this};var I=/[^+\\/0-9A-Za-z-_]/g;function D(t){return t<16?\"0\"+t.toString(16):t.toString(16)}function R(t,e){var r;e=e||1/0;for(var n=t.length,i=null,a=[],o=0;o<n;++o){if((r=t.charCodeAt(o))>55295&&r<57344){if(!i){if(r>56319){(e-=3)>-1&&a.push(239,191,189);continue}if(o+1===n){(e-=3)>-1&&a.push(239,191,189);continue}i=r;continue}if(r<56320){(e-=3)>-1&&a.push(239,191,189),i=r;continue}r=65536+(i-55296<<10|r-56320)}else i&&(e-=3)>-1&&a.push(239,191,189);if(i=null,r<128){if((e-=1)<0)break;a.push(r)}else if(r<2048){if((e-=2)<0)break;a.push(r>>6|192,63&r|128)}else if(r<65536){if((e-=3)<0)break;a.push(r>>12|224,r>>6&63|128,63&r|128)}else{if(!(r<1114112))throw new Error(\"Invalid code point\");if((e-=4)<0)break;a.push(r>>18|240,r>>12&63|128,r>>6&63|128,63&r|128)}}return a}function F(t){return n.toByteArray(function(t){if((t=(t=t.split(\"=\")[0]).trim().replace(I,\"\")).length<2)return\"\";for(;t.length%4!=0;)t+=\"=\";return t}(t))}function B(t,e,r,n){for(var i=0;i<n&&!(i+r>=e.length||i>=t.length);++i)e[i+r]=t[i];return i}function N(t,e){return t instanceof e||null!=t&&null!=t.constructor&&null!=t.constructor.name&&t.constructor.name===e.name}function j(t){return t!=t}}).call(this,t(\"buffer\").Buffer)},{\"base64-js\":74,buffer:105,ieee754:412}],106:[function(t,e,r){\"use strict\";var n=t(\"./lib/monotone\"),i=t(\"./lib/triangulation\"),a=t(\"./lib/delaunay\"),o=t(\"./lib/filter\");function s(t){return[Math.min(t[0],t[1]),Math.max(t[0],t[1])]}function l(t,e){return t[0]-e[0]||t[1]-e[1]}function c(t,e,r){return e in t?t[e]:r}e.exports=function(t,e,r){Array.isArray(e)?(r=r||{},e=e||[]):(r=e||{},e=[]);var u=!!c(r,\"delaunay\",!0),h=!!c(r,\"interior\",!0),f=!!c(r,\"exterior\",!0),p=!!c(r,\"infinity\",!1);if(!h&&!f||0===t.length)return[];var d=n(t,e);if(u||h!==f||p){for(var g=i(t.length,function(t){return t.map(s).sort(l)}(e)),v=0;v<d.length;++v){var m=d[v];g.addTriangle(m[0],m[1],m[2])}return u&&a(t,g),f?h?p?o(g,0,p):g.cells():o(g,1,p):o(g,-1)}return d}},{\"./lib/delaunay\":107,\"./lib/filter\":108,\"./lib/monotone\":109,\"./lib/triangulation\":110}],107:[function(t,e,r){\"use strict\";var n=t(\"robust-in-sphere\")[4];t(\"binary-search-bounds\");function i(t,e,r,i,a,o){var s=e.opposite(i,a);if(!(s<0)){if(a<i){var l=i;i=a,a=l,l=o,o=s,s=l}e.isConstraint(i,a)||n(t[i],t[a],t[o],t[s])<0&&r.push(i,a)}}e.exports=function(t,e){for(var r=[],a=t.length,o=e.stars,s=0;s<a;++s)for(var l=o[s],c=1;c<l.length;c+=2){var u=l[c];if(!(u<s)&&!e.isConstraint(s,u)){for(var h=l[c-1],f=-1,p=1;p<l.length;p+=2)if(l[p-1]===u){f=l[p];break}f<0||n(t[s],t[u],t[h],t[f])<0&&r.push(s,u)}}for(;r.length>0;){for(var u=r.pop(),s=r.pop(),h=-1,f=-1,l=o[s],d=1;d<l.length;d+=2){var g=l[d-1],v=l[d];g===u?f=v:v===u&&(h=g)}h<0||f<0||(n(t[s],t[u],t[h],t[f])>=0||(e.flip(s,u),i(t,e,r,h,s,f),i(t,e,r,s,f,h),i(t,e,r,f,u,h),i(t,e,r,u,h,f)))}}},{\"binary-search-bounds\":111,\"robust-in-sphere\":508}],108:[function(t,e,r){\"use strict\";var n,i=t(\"binary-search-bounds\");function a(t,e,r,n,i,a,o){this.cells=t,this.neighbor=e,this.flags=n,this.constraint=r,this.active=i,this.next=a,this.boundary=o}function o(t,e){return t[0]-e[0]||t[1]-e[1]||t[2]-e[2]}e.exports=function(t,e,r){var n=function(t,e){for(var r=t.cells(),n=r.length,i=0;i<n;++i){var s=r[i],l=s[0],c=s[1],u=s[2];c<u?c<l&&(s[0]=c,s[1]=u,s[2]=l):u<l&&(s[0]=u,s[1]=l,s[2]=c)}r.sort(o);for(var h=new Array(n),i=0;i<h.length;++i)h[i]=0;var f=[],p=[],d=new Array(3*n),g=new Array(3*n),v=null;e&&(v=[]);for(var m=new a(r,d,g,h,f,p,v),i=0;i<n;++i)for(var s=r[i],y=0;y<3;++y){var l=s[y],c=s[(y+1)%3],x=d[3*i+y]=m.locate(c,l,t.opposite(c,l)),b=g[3*i+y]=t.isConstraint(l,c);x<0&&(b?p.push(i):(f.push(i),h[i]=1),e&&v.push([c,l,-1]))}return m}(t,r);if(0===e)return r?n.cells.concat(n.boundary):n.cells;var i=1,s=n.active,l=n.next,c=n.flags,u=n.cells,h=n.constraint,f=n.neighbor;for(;s.length>0||l.length>0;){for(;s.length>0;){var p=s.pop();if(c[p]!==-i){c[p]=i;u[p];for(var d=0;d<3;++d){var g=f[3*p+d];g>=0&&0===c[g]&&(h[3*p+d]?l.push(g):(s.push(g),c[g]=i))}}}var v=l;l=s,s=v,l.length=0,i=-i}var m=function(t,e,r){for(var n=0,i=0;i<t.length;++i)e[i]===r&&(t[n++]=t[i]);return t.length=n,t}(u,c,e);if(r)return m.concat(n.boundary);return m},a.prototype.locate=(n=[0,0,0],function(t,e,r){var a=t,s=e,l=r;return e<r?e<t&&(a=e,s=r,l=t):r<t&&(a=r,s=t,l=e),a<0?-1:(n[0]=a,n[1]=s,n[2]=l,i.eq(this.cells,n,o))})},{\"binary-search-bounds\":111}],109:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"robust-orientation\")[3],a=0,o=1,s=2;function l(t,e,r,n,i){this.a=t,this.b=e,this.idx=r,this.lowerIds=n,this.upperIds=i}function c(t,e,r,n){this.a=t,this.b=e,this.type=r,this.idx=n}function u(t,e){var r=t.a[0]-e.a[0]||t.a[1]-e.a[1]||t.type-e.type;return r||(t.type!==a&&(r=i(t.a,t.b,e.b))?r:t.idx-e.idx)}function h(t,e){return i(t.a,t.b,e)}function f(t,e,r,a,o){for(var s=n.lt(e,a,h),l=n.gt(e,a,h),c=s;c<l;++c){for(var u=e[c],f=u.lowerIds,p=f.length;p>1&&i(r[f[p-2]],r[f[p-1]],a)>0;)t.push([f[p-1],f[p-2],o]),p-=1;f.length=p,f.push(o);var d=u.upperIds;for(p=d.length;p>1&&i(r[d[p-2]],r[d[p-1]],a)<0;)t.push([d[p-2],d[p-1],o]),p-=1;d.length=p,d.push(o)}}function p(t,e){var r;return(r=t.a[0]<e.a[0]?i(t.a,t.b,e.a):i(e.b,e.a,t.a))?r:(r=e.b[0]<t.b[0]?i(t.a,t.b,e.b):i(e.b,e.a,t.b))||t.idx-e.idx}function d(t,e,r){var i=n.le(t,r,p),a=t[i],o=a.upperIds,s=o[o.length-1];a.upperIds=[s],t.splice(i+1,0,new l(r.a,r.b,r.idx,[s],o))}function g(t,e,r){var i=r.a;r.a=r.b,r.b=i;var a=n.eq(t,r,p),o=t[a];t[a-1].upperIds=o.upperIds,t.splice(a,1)}e.exports=function(t,e){for(var r=t.length,n=e.length,i=[],h=0;h<r;++h)i.push(new c(t[h],null,a,h));for(var h=0;h<n;++h){var p=e[h],v=t[p[0]],m=t[p[1]];v[0]<m[0]?i.push(new c(v,m,s,h),new c(m,v,o,h)):v[0]>m[0]&&i.push(new c(m,v,s,h),new c(v,m,o,h))}i.sort(u);for(var y=i[0].a[0]-(1+Math.abs(i[0].a[0]))*Math.pow(2,-52),x=[new l([y,1],[y,0],-1,[],[],[],[])],b=[],h=0,_=i.length;h<_;++h){var w=i[h],k=w.type;k===a?f(b,x,t,w.a,w.idx):k===s?d(x,t,w):g(x,t,w)}return b}},{\"binary-search-bounds\":111,\"robust-orientation\":510}],110:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\");function i(t,e){this.stars=t,this.edges=e}e.exports=function(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=[];return new i(r,e)};var a=i.prototype;function o(t,e,r){for(var n=1,i=t.length;n<i;n+=2)if(t[n-1]===e&&t[n]===r)return t[n-1]=t[i-2],t[n]=t[i-1],void(t.length=i-2)}a.isConstraint=function(){var t=[0,0];function e(t,e){return t[0]-e[0]||t[1]-e[1]}return function(r,i){return t[0]=Math.min(r,i),t[1]=Math.max(r,i),n.eq(this.edges,t,e)>=0}}(),a.removeTriangle=function(t,e,r){var n=this.stars;o(n[t],e,r),o(n[e],r,t),o(n[r],t,e)},a.addTriangle=function(t,e,r){var n=this.stars;n[t].push(e,r),n[e].push(r,t),n[r].push(t,e)},a.opposite=function(t,e){for(var r=this.stars[e],n=1,i=r.length;n<i;n+=2)if(r[n]===t)return r[n-1];return-1},a.flip=function(t,e){var r=this.opposite(t,e),n=this.opposite(e,t);this.removeTriangle(t,e,r),this.removeTriangle(e,t,n),this.addTriangle(t,n,r),this.addTriangle(e,r,n)},a.edges=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2)e.push([i[a],i[a+1]]);return e},a.cells=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2){var s=i[a],l=i[a+1];r<Math.min(s,l)&&e.push([r,s,l])}return e}},{\"binary-search-bounds\":111}],111:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",i?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a[m]\"];return i?e.indexOf(\"c\")<0?a.push(\";if(x===y){return m}else if(x<=y){\"):a.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):a.push(\";if(\",e,\"){i=m;\"),r?a.push(\"l=m+1}else{h=m-1}\"):a.push(\"h=m-1}else{l=m+1}\"),a.push(\"}\"),i?a.push(\"return -1};\"):a.push(\"return i};\"),a.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(typeof(c)==='function'){return P(a,(l===void 0)?0:l|0,(h===void 0)?a.length-1:h|0,y,c)}else{return A(a,(c===void 0)?0:c|0,(l===void 0)?a.length-1:l|0,y)}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],112:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1,r=1;r<t.length;++r)for(var n=0;n<r;++n)if(t[r]<t[n])e=-e;else if(t[n]===t[r])return 0;return e}},{}],113:[function(t,e,r){\"use strict\";var n=t(\"dup\"),i=t(\"robust-linear-solve\");function a(t,e){for(var r=0,n=t.length,i=0;i<n;++i)r+=t[i]*e[i];return r}function o(t){var e=t.length;if(0===e)return[];t[0].length;var r=n([t.length+1,t.length+1],1),o=n([t.length+1],1);r[e][e]=0;for(var s=0;s<e;++s){for(var l=0;l<=s;++l)r[l][s]=r[s][l]=2*a(t[s],t[l]);o[s]=a(t[s],t[s])}var c=i(r,o),u=0,h=c[e+1];for(s=0;s<h.length;++s)u+=h[s];var f=new Array(e);for(s=0;s<e;++s){h=c[s];var p=0;for(l=0;l<h.length;++l)p+=h[l];f[s]=p/u}return f}function s(t){if(0===t.length)return[];for(var e=t[0].length,r=n([e]),i=o(t),a=0;a<t.length;++a)for(var s=0;s<e;++s)r[s]+=t[a][s]*i[a];return r}s.barycenetric=o,e.exports=s},{dup:170,\"robust-linear-solve\":509}],114:[function(t,e,r){e.exports=function(t){for(var e=n(t),r=0,i=0;i<t.length;++i)for(var a=t[i],o=0;o<e.length;++o)r+=Math.pow(a[o]-e[o],2);return Math.sqrt(r/t.length)};var n=t(\"circumcenter\")},{circumcenter:113}],115:[function(t,e,r){e.exports=function(t,e,r){return e<r?t<e?e:t>r?r:t:t<r?r:t>e?e:t}},{}],116:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n;if(r){n=e;for(var i=new Array(e.length),a=0;a<e.length;++a){var o=e[a];i[a]=[o[0],o[1],r[a]]}e=i}var s=function(t,e,r){var n=d(t,[],p(t));return m(e,n,r),!!n}(t,e,!!r);for(;y(t,e,!!r);)s=!0;if(r&&s){n.length=0,r.length=0;for(var a=0;a<e.length;++a){var o=e[a];n.push([o[0],o[1]]),r.push(o[2])}}return s};var n=t(\"union-find\"),i=t(\"box-intersect\"),a=t(\"robust-segment-intersect\"),o=t(\"big-rat\"),s=t(\"big-rat/cmp\"),l=t(\"big-rat/to-float\"),c=t(\"rat-vec\"),u=t(\"nextafter\"),h=t(\"./lib/rat-seg-intersect\");function f(t){var e=l(t);return[u(e,-1/0),u(e,1/0)]}function p(t){for(var e=new Array(t.length),r=0;r<t.length;++r){var n=t[r];e[r]=[u(n[0],-1/0),u(n[1],-1/0),u(n[0],1/0),u(n[1],1/0)]}return e}function d(t,e,r){for(var a=e.length,o=new n(a),s=[],l=0;l<e.length;++l){var c=e[l],h=f(c[0]),p=f(c[1]);s.push([u(h[0],-1/0),u(p[0],-1/0),u(h[1],1/0),u(p[1],1/0)])}i(s,function(t,e){o.link(t,e)});var d=!0,g=new Array(a);for(l=0;l<a;++l){(m=o.find(l))!==l&&(d=!1,t[m]=[Math.min(t[l][0],t[m][0]),Math.min(t[l][1],t[m][1])])}if(d)return null;var v=0;for(l=0;l<a;++l){var m;(m=o.find(l))===l?(g[l]=v,t[v++]=t[l]):g[l]=-1}t.length=v;for(l=0;l<a;++l)g[l]<0&&(g[l]=g[o.find(l)]);return g}function g(t,e){return t[0]-e[0]||t[1]-e[1]}function v(t,e){var r=t[0]-e[0]||t[1]-e[1];return r||(t[2]<e[2]?-1:t[2]>e[2]?1:0)}function m(t,e,r){if(0!==t.length){if(e)for(var n=0;n<t.length;++n){var i=e[(o=t[n])[0]],a=e[o[1]];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}else for(n=0;n<t.length;++n){var o;i=(o=t[n])[0],a=o[1];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}r?t.sort(v):t.sort(g);var s=1;for(n=1;n<t.length;++n){var l=t[n-1],c=t[n];(c[0]!==l[0]||c[1]!==l[1]||r&&c[2]!==l[2])&&(t[s++]=c)}t.length=s}}function y(t,e,r){var n=function(t,e){for(var r=new Array(e.length),n=0;n<e.length;++n){var i=e[n],a=t[i[0]],o=t[i[1]];r[n]=[u(Math.min(a[0],o[0]),-1/0),u(Math.min(a[1],o[1]),-1/0),u(Math.max(a[0],o[0]),1/0),u(Math.max(a[1],o[1]),1/0)]}return r}(t,e),f=function(t,e,r){var n=[];return i(r,function(r,i){var o=e[r],s=e[i];if(o[0]!==s[0]&&o[0]!==s[1]&&o[1]!==s[0]&&o[1]!==s[1]){var l=t[o[0]],c=t[o[1]],u=t[s[0]],h=t[s[1]];a(l,c,u,h)&&n.push([r,i])}}),n}(t,e,n),g=p(t),v=function(t,e,r,n){var o=[];return i(r,n,function(r,n){var i=e[r];if(i[0]!==n&&i[1]!==n){var s=t[n],l=t[i[0]],c=t[i[1]];a(l,c,s,s)&&o.push([r,n])}}),o}(t,e,n,g),y=d(t,function(t,e,r,n,i){var a,u,f=t.map(function(t){return[o(t[0]),o(t[1])]});for(a=0;a<r.length;++a){var p=r[a];u=p[0];var d=p[1],g=e[u],v=e[d],m=h(c(t[g[0]]),c(t[g[1]]),c(t[v[0]]),c(t[v[1]]));if(m){var y=t.length;t.push([l(m[0]),l(m[1])]),f.push(m),n.push([u,y],[d,y])}}for(n.sort(function(t,e){if(t[0]!==e[0])return t[0]-e[0];var r=f[t[1]],n=f[e[1]];return s(r[0],n[0])||s(r[1],n[1])}),a=n.length-1;a>=0;--a){var x=e[u=(S=n[a])[0]],b=x[0],_=x[1],w=t[b],k=t[_];if((w[0]-k[0]||w[1]-k[1])<0){var T=b;b=_,_=T}x[0]=b;var A,M=x[1]=S[1];for(i&&(A=x[2]);a>0&&n[a-1][0]===u;){var S,E=(S=n[--a])[1];i?e.push([M,E,A]):e.push([M,E]),M=E}i?e.push([M,_,A]):e.push([M,_])}return f}(t,e,f,v,r));return m(e,y,r),!!y||(f.length>0||v.length>0)}},{\"./lib/rat-seg-intersect\":117,\"big-rat\":78,\"big-rat/cmp\":76,\"big-rat/to-float\":90,\"box-intersect\":96,nextafter:451,\"rat-vec\":486,\"robust-segment-intersect\":513,\"union-find\":546}],117:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var a=s(e,t),h=s(n,r),f=u(a,h);if(0===o(f))return null;var p=s(t,r),d=u(h,p),g=i(d,f),v=c(a,g);return l(t,v)};var n=t(\"big-rat/mul\"),i=t(\"big-rat/div\"),a=t(\"big-rat/sub\"),o=t(\"big-rat/sign\"),s=t(\"rat-vec/sub\"),l=t(\"rat-vec/add\"),c=t(\"rat-vec/muls\");function u(t,e){return a(n(t[0],e[1]),n(t[1],e[0]))}},{\"big-rat/div\":77,\"big-rat/mul\":87,\"big-rat/sign\":88,\"big-rat/sub\":89,\"rat-vec/add\":485,\"rat-vec/muls\":487,\"rat-vec/sub\":488}],118:[function(t,e,r){\"use strict\";var n=t(\"clamp\");function i(t,e){null==e&&(e=!0);var r=t[0],i=t[1],a=t[2],o=t[3];return null==o&&(o=e?1:255),e&&(r*=255,i*=255,a*=255,o*=255),16777216*(r=255&n(r,0,255))+((i=255&n(i,0,255))<<16)+((a=255&n(a,0,255))<<8)+(o=255&n(o,0,255))}e.exports=i,e.exports.to=i,e.exports.from=function(t,e){var r=(t=+t)>>>24,n=(16711680&t)>>>16,i=(65280&t)>>>8,a=255&t;return!1===e?[r,n,i,a]:[r/255,n/255,i/255,a/255]}},{clamp:115}],119:[function(t,e,r){\"use strict\";e.exports={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]}},{}],120:[function(t,e,r){\"use strict\";var n=t(\"color-rgba\"),i=t(\"clamp\"),a=t(\"dtype\");e.exports=function(t,e){\"float\"!==e&&e||(e=\"array\"),\"uint\"===e&&(e=\"uint8\"),\"uint_clamped\"===e&&(e=\"uint8_clamped\");var r=new(a(e))(4),o=\"uint8\"!==e&&\"uint8_clamped\"!==e;return t.length&&\"string\"!=typeof t||((t=n(t))[0]/=255,t[1]/=255,t[2]/=255),function(t){return t instanceof Uint8Array||t instanceof Uint8ClampedArray||!!(Array.isArray(t)&&(t[0]>1||0===t[0])&&(t[1]>1||0===t[1])&&(t[2]>1||0===t[2])&&(!t[3]||t[3]>1))}(t)?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:255,o&&(r[0]/=255,r[1]/=255,r[2]/=255,r[3]/=255),r):(o?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:1):(r[0]=i(Math.floor(255*t[0]),0,255),r[1]=i(Math.floor(255*t[1]),0,255),r[2]=i(Math.floor(255*t[2]),0,255),r[3]=null==t[3]?255:i(Math.floor(255*t[3]),0,255)),r)}},{clamp:115,\"color-rgba\":122,dtype:169}],121:[function(t,e,r){(function(r){\"use strict\";var n=t(\"color-name\"),i=t(\"is-plain-obj\"),a=t(\"defined\");e.exports=function(t){var e,s,l=[],c=1;if(\"string\"==typeof t)if(n[t])l=n[t].slice(),s=\"rgb\";else if(\"transparent\"===t)c=0,s=\"rgb\",l=[0,0,0];else if(/^#[A-Fa-f0-9]+$/.test(t)){var u=t.slice(1),h=u.length,f=h<=4;c=1,f?(l=[parseInt(u[0]+u[0],16),parseInt(u[1]+u[1],16),parseInt(u[2]+u[2],16)],4===h&&(c=parseInt(u[3]+u[3],16)/255)):(l=[parseInt(u[0]+u[1],16),parseInt(u[2]+u[3],16),parseInt(u[4]+u[5],16)],8===h&&(c=parseInt(u[6]+u[7],16)/255)),l[0]||(l[0]=0),l[1]||(l[1]=0),l[2]||(l[2]=0),s=\"rgb\"}else if(e=/^((?:rgb|hs[lvb]|hwb|cmyk?|xy[zy]|gray|lab|lchu?v?|[ly]uv|lms)a?)\\s*\\(([^\\)]*)\\)/.exec(t)){var p=e[1],d=\"rgb\"===p,u=p.replace(/a$/,\"\");s=u;var h=\"cmyk\"===u?4:\"gray\"===u?1:3;l=e[2].trim().split(/\\s*,\\s*/).map(function(t,e){if(/%$/.test(t))return e===h?parseFloat(t)/100:\"rgb\"===u?255*parseFloat(t)/100:parseFloat(t);if(\"h\"===u[e]){if(/deg$/.test(t))return parseFloat(t);if(void 0!==o[t])return o[t]}return parseFloat(t)}),p===u&&l.push(1),c=d?1:void 0===l[h]?1:l[h],l=l.slice(0,h)}else t.length>10&&/[0-9](?:\\s|\\/)/.test(t)&&(l=t.match(/([0-9]+)/g).map(function(t){return parseFloat(t)}),s=t.match(/([a-z])/gi).join(\"\").toLowerCase());else if(isNaN(t))if(i(t)){var g=a(t.r,t.red,t.R,null);null!==g?(s=\"rgb\",l=[g,a(t.g,t.green,t.G),a(t.b,t.blue,t.B)]):(s=\"hsl\",l=[a(t.h,t.hue,t.H),a(t.s,t.saturation,t.S),a(t.l,t.lightness,t.L,t.b,t.brightness)]),c=a(t.a,t.alpha,t.opacity,1),null!=t.opacity&&(c/=100)}else(Array.isArray(t)||r.ArrayBuffer&&ArrayBuffer.isView&&ArrayBuffer.isView(t))&&(l=[t[0],t[1],t[2]],s=\"rgb\",c=4===t.length?t[3]:1);else s=\"rgb\",l=[t>>>16,(65280&t)>>>8,255&t];return{space:s,values:l,alpha:c}};var o={red:0,orange:60,yellow:120,green:180,blue:240,purple:300}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"color-name\":119,defined:164,\"is-plain-obj\":422}],122:[function(t,e,r){\"use strict\";var n=t(\"color-parse\"),i=t(\"color-space/hsl\"),a=t(\"clamp\");e.exports=function(t){var e,r=n(t);return r.space?((e=Array(3))[0]=a(r.values[0],0,255),e[1]=a(r.values[1],0,255),e[2]=a(r.values[2],0,255),\"h\"===r.space[0]&&(e=i.rgb(e)),e.push(a(r.alpha,0,1)),e):[]}},{clamp:115,\"color-parse\":121,\"color-space/hsl\":123}],123:[function(t,e,r){\"use strict\";var n=t(\"./rgb\");e.exports={name:\"hsl\",min:[0,0,0],max:[360,100,100],channel:[\"hue\",\"saturation\",\"lightness\"],alias:[\"HSL\"],rgb:function(t){var e,r,n,i,a,o=t[0]/360,s=t[1]/100,l=t[2]/100;if(0===s)return[a=255*l,a,a];e=2*l-(r=l<.5?l*(1+s):l+s-l*s),i=[0,0,0];for(var c=0;c<3;c++)(n=o+1/3*-(c-1))<0?n++:n>1&&n--,a=6*n<1?e+6*(r-e)*n:2*n<1?r:3*n<2?e+(r-e)*(2/3-n)*6:e,i[c]=255*a;return i}},n.hsl=function(t){var e,r,n=t[0]/255,i=t[1]/255,a=t[2]/255,o=Math.min(n,i,a),s=Math.max(n,i,a),l=s-o;return s===o?e=0:n===s?e=(i-a)/l:i===s?e=2+(a-n)/l:a===s&&(e=4+(n-i)/l),(e=Math.min(60*e,360))<0&&(e+=360),r=(o+s)/2,[e,100*(s===o?0:r<=.5?l/(s+o):l/(2-s-o)),100*r]}},{\"./rgb\":124}],124:[function(t,e,r){\"use strict\";e.exports={name:\"rgb\",min:[0,0,0],max:[255,255,255],channel:[\"red\",\"green\",\"blue\"],alias:[\"RGB\"]}},{}],125:[function(t,e,r){e.exports={jet:[{index:0,rgb:[0,0,131]},{index:.125,rgb:[0,60,170]},{index:.375,rgb:[5,255,255]},{index:.625,rgb:[255,255,0]},{index:.875,rgb:[250,0,0]},{index:1,rgb:[128,0,0]}],hsv:[{index:0,rgb:[255,0,0]},{index:.169,rgb:[253,255,2]},{index:.173,rgb:[247,255,2]},{index:.337,rgb:[0,252,4]},{index:.341,rgb:[0,252,10]},{index:.506,rgb:[1,249,255]},{index:.671,rgb:[2,0,253]},{index:.675,rgb:[8,0,253]},{index:.839,rgb:[255,0,251]},{index:.843,rgb:[255,0,245]},{index:1,rgb:[255,0,6]}],hot:[{index:0,rgb:[0,0,0]},{index:.3,rgb:[230,0,0]},{index:.6,rgb:[255,210,0]},{index:1,rgb:[255,255,255]}],cool:[{index:0,rgb:[0,255,255]},{index:1,rgb:[255,0,255]}],spring:[{index:0,rgb:[255,0,255]},{index:1,rgb:[255,255,0]}],summer:[{index:0,rgb:[0,128,102]},{index:1,rgb:[255,255,102]}],autumn:[{index:0,rgb:[255,0,0]},{index:1,rgb:[255,255,0]}],winter:[{index:0,rgb:[0,0,255]},{index:1,rgb:[0,255,128]}],bone:[{index:0,rgb:[0,0,0]},{index:.376,rgb:[84,84,116]},{index:.753,rgb:[169,200,200]},{index:1,rgb:[255,255,255]}],copper:[{index:0,rgb:[0,0,0]},{index:.804,rgb:[255,160,102]},{index:1,rgb:[255,199,127]}],greys:[{index:0,rgb:[0,0,0]},{index:1,rgb:[255,255,255]}],yignbu:[{index:0,rgb:[8,29,88]},{index:.125,rgb:[37,52,148]},{index:.25,rgb:[34,94,168]},{index:.375,rgb:[29,145,192]},{index:.5,rgb:[65,182,196]},{index:.625,rgb:[127,205,187]},{index:.75,rgb:[199,233,180]},{index:.875,rgb:[237,248,217]},{index:1,rgb:[255,255,217]}],greens:[{index:0,rgb:[0,68,27]},{index:.125,rgb:[0,109,44]},{index:.25,rgb:[35,139,69]},{index:.375,rgb:[65,171,93]},{index:.5,rgb:[116,196,118]},{index:.625,rgb:[161,217,155]},{index:.75,rgb:[199,233,192]},{index:.875,rgb:[229,245,224]},{index:1,rgb:[247,252,245]}],yiorrd:[{index:0,rgb:[128,0,38]},{index:.125,rgb:[189,0,38]},{index:.25,rgb:[227,26,28]},{index:.375,rgb:[252,78,42]},{index:.5,rgb:[253,141,60]},{index:.625,rgb:[254,178,76]},{index:.75,rgb:[254,217,118]},{index:.875,rgb:[255,237,160]},{index:1,rgb:[255,255,204]}],bluered:[{index:0,rgb:[0,0,255]},{index:1,rgb:[255,0,0]}],rdbu:[{index:0,rgb:[5,10,172]},{index:.35,rgb:[106,137,247]},{index:.5,rgb:[190,190,190]},{index:.6,rgb:[220,170,132]},{index:.7,rgb:[230,145,90]},{index:1,rgb:[178,10,28]}],picnic:[{index:0,rgb:[0,0,255]},{index:.1,rgb:[51,153,255]},{index:.2,rgb:[102,204,255]},{index:.3,rgb:[153,204,255]},{index:.4,rgb:[204,204,255]},{index:.5,rgb:[255,255,255]},{index:.6,rgb:[255,204,255]},{index:.7,rgb:[255,153,255]},{index:.8,rgb:[255,102,204]},{index:.9,rgb:[255,102,102]},{index:1,rgb:[255,0,0]}],rainbow:[{index:0,rgb:[150,0,90]},{index:.125,rgb:[0,0,200]},{index:.25,rgb:[0,25,255]},{index:.375,rgb:[0,152,255]},{index:.5,rgb:[44,255,150]},{index:.625,rgb:[151,255,0]},{index:.75,rgb:[255,234,0]},{index:.875,rgb:[255,111,0]},{index:1,rgb:[255,0,0]}],portland:[{index:0,rgb:[12,51,131]},{index:.25,rgb:[10,136,186]},{index:.5,rgb:[242,211,56]},{index:.75,rgb:[242,143,56]},{index:1,rgb:[217,30,30]}],blackbody:[{index:0,rgb:[0,0,0]},{index:.2,rgb:[230,0,0]},{index:.4,rgb:[230,210,0]},{index:.7,rgb:[255,255,255]},{index:1,rgb:[160,200,255]}],earth:[{index:0,rgb:[0,0,130]},{index:.1,rgb:[0,180,180]},{index:.2,rgb:[40,210,40]},{index:.4,rgb:[230,230,50]},{index:.6,rgb:[120,70,20]},{index:1,rgb:[255,255,255]}],electric:[{index:0,rgb:[0,0,0]},{index:.15,rgb:[30,0,100]},{index:.4,rgb:[120,0,100]},{index:.6,rgb:[160,90,0]},{index:.8,rgb:[230,200,0]},{index:1,rgb:[255,250,220]}],alpha:[{index:0,rgb:[255,255,255,0]},{index:1,rgb:[255,255,255,1]}],viridis:[{index:0,rgb:[68,1,84]},{index:.13,rgb:[71,44,122]},{index:.25,rgb:[59,81,139]},{index:.38,rgb:[44,113,142]},{index:.5,rgb:[33,144,141]},{index:.63,rgb:[39,173,129]},{index:.75,rgb:[92,200,99]},{index:.88,rgb:[170,220,50]},{index:1,rgb:[253,231,37]}],inferno:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[31,12,72]},{index:.25,rgb:[85,15,109]},{index:.38,rgb:[136,34,106]},{index:.5,rgb:[186,54,85]},{index:.63,rgb:[227,89,51]},{index:.75,rgb:[249,140,10]},{index:.88,rgb:[249,201,50]},{index:1,rgb:[252,255,164]}],magma:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[28,16,68]},{index:.25,rgb:[79,18,123]},{index:.38,rgb:[129,37,129]},{index:.5,rgb:[181,54,122]},{index:.63,rgb:[229,80,100]},{index:.75,rgb:[251,135,97]},{index:.88,rgb:[254,194,135]},{index:1,rgb:[252,253,191]}],plasma:[{index:0,rgb:[13,8,135]},{index:.13,rgb:[75,3,161]},{index:.25,rgb:[125,3,168]},{index:.38,rgb:[168,34,150]},{index:.5,rgb:[203,70,121]},{index:.63,rgb:[229,107,93]},{index:.75,rgb:[248,148,65]},{index:.88,rgb:[253,195,40]},{index:1,rgb:[240,249,33]}],warm:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[172,0,187]},{index:.25,rgb:[219,0,170]},{index:.38,rgb:[255,0,130]},{index:.5,rgb:[255,63,74]},{index:.63,rgb:[255,123,0]},{index:.75,rgb:[234,176,0]},{index:.88,rgb:[190,228,0]},{index:1,rgb:[147,255,0]}],cool:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[116,0,218]},{index:.25,rgb:[98,74,237]},{index:.38,rgb:[68,146,231]},{index:.5,rgb:[0,204,197]},{index:.63,rgb:[0,247,146]},{index:.75,rgb:[0,255,88]},{index:.88,rgb:[40,255,8]},{index:1,rgb:[147,255,0]}],\"rainbow-soft\":[{index:0,rgb:[125,0,179]},{index:.1,rgb:[199,0,180]},{index:.2,rgb:[255,0,121]},{index:.3,rgb:[255,108,0]},{index:.4,rgb:[222,194,0]},{index:.5,rgb:[150,255,0]},{index:.6,rgb:[0,255,55]},{index:.7,rgb:[0,246,150]},{index:.8,rgb:[50,167,222]},{index:.9,rgb:[103,51,235]},{index:1,rgb:[124,0,186]}],bathymetry:[{index:0,rgb:[40,26,44]},{index:.13,rgb:[59,49,90]},{index:.25,rgb:[64,76,139]},{index:.38,rgb:[63,110,151]},{index:.5,rgb:[72,142,158]},{index:.63,rgb:[85,174,163]},{index:.75,rgb:[120,206,163]},{index:.88,rgb:[187,230,172]},{index:1,rgb:[253,254,204]}],cdom:[{index:0,rgb:[47,15,62]},{index:.13,rgb:[87,23,86]},{index:.25,rgb:[130,28,99]},{index:.38,rgb:[171,41,96]},{index:.5,rgb:[206,67,86]},{index:.63,rgb:[230,106,84]},{index:.75,rgb:[242,149,103]},{index:.88,rgb:[249,193,135]},{index:1,rgb:[254,237,176]}],chlorophyll:[{index:0,rgb:[18,36,20]},{index:.13,rgb:[25,63,41]},{index:.25,rgb:[24,91,59]},{index:.38,rgb:[13,119,72]},{index:.5,rgb:[18,148,80]},{index:.63,rgb:[80,173,89]},{index:.75,rgb:[132,196,122]},{index:.88,rgb:[175,221,162]},{index:1,rgb:[215,249,208]}],density:[{index:0,rgb:[54,14,36]},{index:.13,rgb:[89,23,80]},{index:.25,rgb:[110,45,132]},{index:.38,rgb:[120,77,178]},{index:.5,rgb:[120,113,213]},{index:.63,rgb:[115,151,228]},{index:.75,rgb:[134,185,227]},{index:.88,rgb:[177,214,227]},{index:1,rgb:[230,241,241]}],\"freesurface-blue\":[{index:0,rgb:[30,4,110]},{index:.13,rgb:[47,14,176]},{index:.25,rgb:[41,45,236]},{index:.38,rgb:[25,99,212]},{index:.5,rgb:[68,131,200]},{index:.63,rgb:[114,156,197]},{index:.75,rgb:[157,181,203]},{index:.88,rgb:[200,208,216]},{index:1,rgb:[241,237,236]}],\"freesurface-red\":[{index:0,rgb:[60,9,18]},{index:.13,rgb:[100,17,27]},{index:.25,rgb:[142,20,29]},{index:.38,rgb:[177,43,27]},{index:.5,rgb:[192,87,63]},{index:.63,rgb:[205,125,105]},{index:.75,rgb:[216,162,148]},{index:.88,rgb:[227,199,193]},{index:1,rgb:[241,237,236]}],oxygen:[{index:0,rgb:[64,5,5]},{index:.13,rgb:[106,6,15]},{index:.25,rgb:[144,26,7]},{index:.38,rgb:[168,64,3]},{index:.5,rgb:[188,100,4]},{index:.63,rgb:[206,136,11]},{index:.75,rgb:[220,174,25]},{index:.88,rgb:[231,215,44]},{index:1,rgb:[248,254,105]}],par:[{index:0,rgb:[51,20,24]},{index:.13,rgb:[90,32,35]},{index:.25,rgb:[129,44,34]},{index:.38,rgb:[159,68,25]},{index:.5,rgb:[182,99,19]},{index:.63,rgb:[199,134,22]},{index:.75,rgb:[212,171,35]},{index:.88,rgb:[221,210,54]},{index:1,rgb:[225,253,75]}],phase:[{index:0,rgb:[145,105,18]},{index:.13,rgb:[184,71,38]},{index:.25,rgb:[186,58,115]},{index:.38,rgb:[160,71,185]},{index:.5,rgb:[110,97,218]},{index:.63,rgb:[50,123,164]},{index:.75,rgb:[31,131,110]},{index:.88,rgb:[77,129,34]},{index:1,rgb:[145,105,18]}],salinity:[{index:0,rgb:[42,24,108]},{index:.13,rgb:[33,50,162]},{index:.25,rgb:[15,90,145]},{index:.38,rgb:[40,118,137]},{index:.5,rgb:[59,146,135]},{index:.63,rgb:[79,175,126]},{index:.75,rgb:[120,203,104]},{index:.88,rgb:[193,221,100]},{index:1,rgb:[253,239,154]}],temperature:[{index:0,rgb:[4,35,51]},{index:.13,rgb:[23,51,122]},{index:.25,rgb:[85,59,157]},{index:.38,rgb:[129,79,143]},{index:.5,rgb:[175,95,130]},{index:.63,rgb:[222,112,101]},{index:.75,rgb:[249,146,66]},{index:.88,rgb:[249,196,65]},{index:1,rgb:[232,250,91]}],turbidity:[{index:0,rgb:[34,31,27]},{index:.13,rgb:[65,50,41]},{index:.25,rgb:[98,69,52]},{index:.38,rgb:[131,89,57]},{index:.5,rgb:[161,112,59]},{index:.63,rgb:[185,140,66]},{index:.75,rgb:[202,174,88]},{index:.88,rgb:[216,209,126]},{index:1,rgb:[233,246,171]}],\"velocity-blue\":[{index:0,rgb:[17,32,64]},{index:.13,rgb:[35,52,116]},{index:.25,rgb:[29,81,156]},{index:.38,rgb:[31,113,162]},{index:.5,rgb:[50,144,169]},{index:.63,rgb:[87,173,176]},{index:.75,rgb:[149,196,189]},{index:.88,rgb:[203,221,211]},{index:1,rgb:[254,251,230]}],\"velocity-green\":[{index:0,rgb:[23,35,19]},{index:.13,rgb:[24,64,38]},{index:.25,rgb:[11,95,45]},{index:.38,rgb:[39,123,35]},{index:.5,rgb:[95,146,12]},{index:.63,rgb:[152,165,18]},{index:.75,rgb:[201,186,69]},{index:.88,rgb:[233,216,137]},{index:1,rgb:[255,253,205]}],cubehelix:[{index:0,rgb:[0,0,0]},{index:.07,rgb:[22,5,59]},{index:.13,rgb:[60,4,105]},{index:.2,rgb:[109,1,135]},{index:.27,rgb:[161,0,147]},{index:.33,rgb:[210,2,142]},{index:.4,rgb:[251,11,123]},{index:.47,rgb:[255,29,97]},{index:.53,rgb:[255,54,69]},{index:.6,rgb:[255,85,46]},{index:.67,rgb:[255,120,34]},{index:.73,rgb:[255,157,37]},{index:.8,rgb:[241,191,57]},{index:.87,rgb:[224,220,93]},{index:.93,rgb:[218,241,142]},{index:1,rgb:[227,253,198]}]}},{}],126:[function(t,e,r){\"use strict\";var n=t(\"./colorScale\"),i=t(\"lerp\");function a(t){return[t[0]/255,t[1]/255,t[2]/255,t[3]]}function o(t){for(var e,r=\"#\",n=0;n<3;++n)r+=(\"00\"+(e=(e=t[n]).toString(16))).substr(e.length);return r}function s(t){return\"rgba(\"+t.join(\",\")+\")\"}e.exports=function(t){var e,r,l,c,u,h,f,p,d,g;t||(t={});p=(t.nshades||72)-1,f=t.format||\"hex\",(h=t.colormap)||(h=\"jet\");if(\"string\"==typeof h){if(h=h.toLowerCase(),!n[h])throw Error(h+\" not a supported colorscale\");u=n[h]}else{if(!Array.isArray(h))throw Error(\"unsupported colormap option\",h);u=h.slice()}if(u.length>p+1)throw new Error(h+\" map requires nshades to be at least size \"+u.length);d=Array.isArray(t.alpha)?2!==t.alpha.length?[1,1]:t.alpha.slice():\"number\"==typeof t.alpha?[t.alpha,t.alpha]:[1,1];e=u.map(function(t){return Math.round(t.index*p)}),d[0]=Math.min(Math.max(d[0],0),1),d[1]=Math.min(Math.max(d[1],0),1);var v=u.map(function(t,e){var r=u[e].index,n=u[e].rgb.slice();return 4===n.length&&n[3]>=0&&n[3]<=1?n:(n[3]=d[0]+(d[1]-d[0])*r,n)}),m=[];for(g=0;g<e.length-1;++g){c=e[g+1]-e[g],r=v[g],l=v[g+1];for(var y=0;y<c;y++){var x=y/c;m.push([Math.round(i(r[0],l[0],x)),Math.round(i(r[1],l[1],x)),Math.round(i(r[2],l[2],x)),i(r[3],l[3],x)])}}m.push(u[u.length-1].rgb.concat(d[1])),\"hex\"===f?m=m.map(o):\"rgbaString\"===f?m=m.map(s):\"float\"===f&&(m=m.map(a));return m}},{\"./colorScale\":125,lerp:425}],127:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a){var o=n(e,r,a);if(0===o){var s=i(n(t,e,r)),c=i(n(t,e,a));if(s===c){if(0===s){var u=l(t,e,r),h=l(t,e,a);return u===h?0:u?1:-1}return 0}return 0===c?s>0?-1:l(t,e,a)?-1:1:0===s?c>0?1:l(t,e,r)?1:-1:i(c-s)}var f=n(t,e,r);if(f>0)return o>0&&n(t,e,a)>0?1:-1;if(f<0)return o>0||n(t,e,a)>0?1:-1;var p=n(t,e,a);return p>0?1:l(t,e,r)?1:-1};var n=t(\"robust-orientation\"),i=t(\"signum\"),a=t(\"two-sum\"),o=t(\"robust-product\"),s=t(\"robust-sum\");function l(t,e,r){var n=a(t[0],-e[0]),i=a(t[1],-e[1]),l=a(r[0],-e[0]),c=a(r[1],-e[1]),u=s(o(n,l),o(i,c));return u[u.length-1]>=0}},{\"robust-orientation\":510,\"robust-product\":511,\"robust-sum\":515,signum:516,\"two-sum\":544}],128:[function(t,e,r){e.exports=function(t,e){var r=t.length,a=t.length-e.length;if(a)return a;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return t[0]+t[1]-e[0]-e[1]||n(t[0],t[1])-n(e[0],e[1]);case 3:var o=t[0]+t[1],s=e[0]+e[1];if(a=o+t[2]-(s+e[2]))return a;var l=n(t[0],t[1]),c=n(e[0],e[1]);return n(l,t[2])-n(c,e[2])||n(l+t[2],o)-n(c+e[2],s);case 4:var u=t[0],h=t[1],f=t[2],p=t[3],d=e[0],g=e[1],v=e[2],m=e[3];return u+h+f+p-(d+g+v+m)||n(u,h,f,p)-n(d,g,v,m,d)||n(u+h,u+f,u+p,h+f,h+p,f+p)-n(d+g,d+v,d+m,g+v,g+m,v+m)||n(u+h+f,u+h+p,u+f+p,h+f+p)-n(d+g+v,d+g+m,d+v+m,g+v+m);default:for(var y=t.slice().sort(i),x=e.slice().sort(i),b=0;b<r;++b)if(a=y[b]-x[b])return a;return 0}};var n=Math.min;function i(t,e){return t-e}},{}],129:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"cell-orientation\");e.exports=function(t,e){return n(t,e)||i(t)-i(e)}},{\"cell-orientation\":112,\"compare-cell\":128}],130:[function(t,e,r){\"use strict\";var n=t(\"./lib/ch1d\"),i=t(\"./lib/ch2d\"),a=t(\"./lib/chnd\");e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[[0]];var r=t[0].length;if(0===r)return[];if(1===r)return n(t);if(2===r)return i(t);return a(t,r)}},{\"./lib/ch1d\":131,\"./lib/ch2d\":132,\"./lib/chnd\":133}],131:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0,r=0,n=1;n<t.length;++n)t[n][0]<t[e][0]&&(e=n),t[n][0]>t[r][0]&&(r=n);return e<r?[[e],[r]]:e>r?[[r],[e]]:[[e]]}},{}],132:[function(t,e,r){\"use strict\";e.exports=function(t){var e=n(t),r=e.length;if(r<=2)return[];for(var i=new Array(r),a=e[r-1],o=0;o<r;++o){var s=e[o];i[o]=[a,s],a=s}return i};var n=t(\"monotone-convex-hull-2d\")},{\"monotone-convex-hull-2d\":434}],133:[function(t,e,r){\"use strict\";e.exports=function(t,e){try{return n(t,!0)}catch(s){var r=i(t);if(r.length<=e)return[];var a=function(t,e){for(var r=t.length,n=new Array(r),i=0;i<e.length;++i)n[i]=t[e[i]];for(var a=e.length,i=0;i<r;++i)e.indexOf(i)<0&&(n[a++]=t[i]);return n}(t,r),o=n(a,!0);return function(t,e){for(var r=t.length,n=e.length,i=0;i<r;++i)for(var a=t[i],o=0;o<a.length;++o){var s=a[o];if(s<n)a[o]=e[s];else{s-=n;for(var l=0;l<n;++l)s>=e[l]&&(s+=1);a[o]=s}}return t}(o,r)}};var n=t(\"incremental-convex-hull\"),i=t(\"affine-hull\")},{\"affine-hull\":62,\"incremental-convex-hull\":413}],134:[function(t,e,r){e.exports={AFG:\"afghan\",ALA:\"\\\\b\\\\wland\",ALB:\"albania\",DZA:\"algeria\",ASM:\"^(?=.*americ).*samoa\",AND:\"andorra\",AGO:\"angola\",AIA:\"anguill?a\",ATA:\"antarctica\",ATG:\"antigua\",ARG:\"argentin\",ARM:\"armenia\",ABW:\"^(?!.*bonaire).*\\\\baruba\",AUS:\"australia\",AUT:\"^(?!.*hungary).*austria|\\\\baustri.*\\\\bemp\",AZE:\"azerbaijan\",BHS:\"bahamas\",BHR:\"bahrain\",BGD:\"bangladesh|^(?=.*east).*paki?stan\",BRB:\"barbados\",BLR:\"belarus|byelo\",BEL:\"^(?!.*luxem).*belgium\",BLZ:\"belize|^(?=.*british).*honduras\",BEN:\"benin|dahome\",BMU:\"bermuda\",BTN:\"bhutan\",BOL:\"bolivia\",BES:\"^(?=.*bonaire).*eustatius|^(?=.*carib).*netherlands|\\\\bbes.?islands\",BIH:\"herzegovina|bosnia\",BWA:\"botswana|bechuana\",BVT:\"bouvet\",BRA:\"brazil\",IOT:\"british.?indian.?ocean\",BRN:\"brunei\",BGR:\"bulgaria\",BFA:\"burkina|\\\\bfaso|upper.?volta\",BDI:\"burundi\",CPV:\"verde\",KHM:\"cambodia|kampuchea|khmer\",CMR:\"cameroon\",CAN:\"canada\",CYM:\"cayman\",CAF:\"\\\\bcentral.african.republic\",TCD:\"\\\\bchad\",CHL:\"\\\\bchile\",CHN:\"^(?!.*\\\\bmac)(?!.*\\\\bhong)(?!.*\\\\btai)(?!.*\\\\brep).*china|^(?=.*peo)(?=.*rep).*china\",CXR:\"christmas\",CCK:\"\\\\bcocos|keeling\",COL:\"colombia\",COM:\"comoro\",COG:\"^(?!.*\\\\bdem)(?!.*\\\\bd[\\\\.]?r)(?!.*kinshasa)(?!.*zaire)(?!.*belg)(?!.*l.opoldville)(?!.*free).*\\\\bcongo\",COK:\"\\\\bcook\",CRI:\"costa.?rica\",CIV:\"ivoire|ivory\",HRV:\"croatia\",CUB:\"\\\\bcuba\",CUW:\"^(?!.*bonaire).*\\\\bcura(c|\\xe7)ao\",CYP:\"cyprus\",CSK:\"czechoslovakia\",CZE:\"^(?=.*rep).*czech|czechia|bohemia\",COD:\"\\\\bdem.*congo|congo.*\\\\bdem|congo.*\\\\bd[\\\\.]?r|\\\\bd[\\\\.]?r.*congo|belgian.?congo|congo.?free.?state|kinshasa|zaire|l.opoldville|drc|droc|rdc\",DNK:\"denmark\",DJI:\"djibouti\",DMA:\"dominica(?!n)\",DOM:\"dominican.rep\",ECU:\"ecuador\",EGY:\"egypt\",SLV:\"el.?salvador\",GNQ:\"guine.*eq|eq.*guine|^(?=.*span).*guinea\",ERI:\"eritrea\",EST:\"estonia\",ETH:\"ethiopia|abyssinia\",FLK:\"falkland|malvinas\",FRO:\"faroe|faeroe\",FJI:\"fiji\",FIN:\"finland\",FRA:\"^(?!.*\\\\bdep)(?!.*martinique).*france|french.?republic|\\\\bgaul\",GUF:\"^(?=.*french).*guiana\",PYF:\"french.?polynesia|tahiti\",ATF:\"french.?southern\",GAB:\"gabon\",GMB:\"gambia\",GEO:\"^(?!.*south).*georgia\",DDR:\"german.?democratic.?republic|democratic.?republic.*germany|east.germany\",DEU:\"^(?!.*east).*germany|^(?=.*\\\\bfed.*\\\\brep).*german\",GHA:\"ghana|gold.?coast\",GIB:\"gibraltar\",GRC:\"greece|hellenic|hellas\",GRL:\"greenland\",GRD:\"grenada\",GLP:\"guadeloupe\",GUM:\"\\\\bguam\",GTM:\"guatemala\",GGY:\"guernsey\",GIN:\"^(?!.*eq)(?!.*span)(?!.*bissau)(?!.*portu)(?!.*new).*guinea\",GNB:\"bissau|^(?=.*portu).*guinea\",GUY:\"guyana|british.?guiana\",HTI:\"haiti\",HMD:\"heard.*mcdonald\",VAT:\"holy.?see|vatican|papal.?st\",HND:\"^(?!.*brit).*honduras\",HKG:\"hong.?kong\",HUN:\"^(?!.*austr).*hungary\",ISL:\"iceland\",IND:\"india(?!.*ocea)\",IDN:\"indonesia\",IRN:\"\\\\biran|persia\",IRQ:\"\\\\biraq|mesopotamia\",IRL:\"(^ireland)|(^republic.*ireland)\",IMN:\"^(?=.*isle).*\\\\bman\",ISR:\"israel\",ITA:\"italy\",JAM:\"jamaica\",JPN:\"japan\",JEY:\"jersey\",JOR:\"jordan\",KAZ:\"kazak\",KEN:\"kenya|british.?east.?africa|east.?africa.?prot\",KIR:\"kiribati\",PRK:\"^(?=.*democrat|people|north|d.*p.*.r).*\\\\bkorea|dprk|korea.*(d.*p.*r)\",KWT:\"kuwait\",KGZ:\"kyrgyz|kirghiz\",LAO:\"\\\\blaos?\\\\b\",LVA:\"latvia\",LBN:\"lebanon\",LSO:\"lesotho|basuto\",LBR:\"liberia\",LBY:\"libya\",LIE:\"liechtenstein\",LTU:\"lithuania\",LUX:\"^(?!.*belg).*luxem\",MAC:\"maca(o|u)\",MDG:\"madagascar|malagasy\",MWI:\"malawi|nyasa\",MYS:\"malaysia\",MDV:\"maldive\",MLI:\"\\\\bmali\\\\b\",MLT:\"\\\\bmalta\",MHL:\"marshall\",MTQ:\"martinique\",MRT:\"mauritania\",MUS:\"mauritius\",MYT:\"\\\\bmayotte\",MEX:\"\\\\bmexic\",FSM:\"fed.*micronesia|micronesia.*fed\",MCO:\"monaco\",MNG:\"mongolia\",MNE:\"^(?!.*serbia).*montenegro\",MSR:\"montserrat\",MAR:\"morocco|\\\\bmaroc\",MOZ:\"mozambique\",MMR:\"myanmar|burma\",NAM:\"namibia\",NRU:\"nauru\",NPL:\"nepal\",NLD:\"^(?!.*\\\\bant)(?!.*\\\\bcarib).*netherlands\",ANT:\"^(?=.*\\\\bant).*(nether|dutch)\",NCL:\"new.?caledonia\",NZL:\"new.?zealand\",NIC:\"nicaragua\",NER:\"\\\\bniger(?!ia)\",NGA:\"nigeria\",NIU:\"niue\",NFK:\"norfolk\",MNP:\"mariana\",NOR:\"norway\",OMN:\"\\\\boman|trucial\",PAK:\"^(?!.*east).*paki?stan\",PLW:\"palau\",PSE:\"palestin|\\\\bgaza|west.?bank\",PAN:\"panama\",PNG:\"papua|new.?guinea\",PRY:\"paraguay\",PER:\"peru\",PHL:\"philippines\",PCN:\"pitcairn\",POL:\"poland\",PRT:\"portugal\",PRI:\"puerto.?rico\",QAT:\"qatar\",KOR:\"^(?!.*d.*p.*r)(?!.*democrat)(?!.*people)(?!.*north).*\\\\bkorea(?!.*d.*p.*r)\",MDA:\"moldov|b(a|e)ssarabia\",REU:\"r(e|\\xe9)union\",ROU:\"r(o|u|ou)mania\",RUS:\"\\\\brussia|soviet.?union|u\\\\.?s\\\\.?s\\\\.?r|socialist.?republics\",RWA:\"rwanda\",BLM:\"barth(e|\\xe9)lemy\",SHN:\"helena\",KNA:\"kitts|\\\\bnevis\",LCA:\"\\\\blucia\",MAF:\"^(?=.*collectivity).*martin|^(?=.*france).*martin(?!ique)|^(?=.*french).*martin(?!ique)\",SPM:\"miquelon\",VCT:\"vincent\",WSM:\"^(?!.*amer).*samoa\",SMR:\"san.?marino\",STP:\"\\\\bs(a|\\xe3)o.?tom(e|\\xe9)\",SAU:\"\\\\bsa\\\\w*.?arabia\",SEN:\"senegal\",SRB:\"^(?!.*monte).*serbia\",SYC:\"seychell\",SLE:\"sierra\",SGP:\"singapore\",SXM:\"^(?!.*martin)(?!.*saba).*maarten\",SVK:\"^(?!.*cze).*slovak\",SVN:\"slovenia\",SLB:\"solomon\",SOM:\"somali\",ZAF:\"south.africa|s\\\\\\\\..?africa\",SGS:\"south.?georgia|sandwich\",SSD:\"\\\\bs\\\\w*.?sudan\",ESP:\"spain\",LKA:\"sri.?lanka|ceylon\",SDN:\"^(?!.*\\\\bs(?!u)).*sudan\",SUR:\"surinam|dutch.?guiana\",SJM:\"svalbard\",SWZ:\"swaziland\",SWE:\"sweden\",CHE:\"switz|swiss\",SYR:\"syria\",TWN:\"taiwan|taipei|formosa|^(?!.*peo)(?=.*rep).*china\",TJK:\"tajik\",THA:\"thailand|\\\\bsiam\",MKD:\"macedonia|fyrom\",TLS:\"^(?=.*leste).*timor|^(?=.*east).*timor\",TGO:\"togo\",TKL:\"tokelau\",TON:\"tonga\",TTO:\"trinidad|tobago\",TUN:\"tunisia\",TUR:\"turkey\",TKM:\"turkmen\",TCA:\"turks\",TUV:\"tuvalu\",UGA:\"uganda\",UKR:\"ukrain\",ARE:\"emirates|^u\\\\.?a\\\\.?e\\\\.?$|united.?arab.?em\",GBR:\"united.?kingdom|britain|^u\\\\.?k\\\\.?$\",TZA:\"tanzania\",USA:\"united.?states\\\\b(?!.*islands)|\\\\bu\\\\.?s\\\\.?a\\\\.?\\\\b|^\\\\s*u\\\\.?s\\\\.?\\\\b(?!.*islands)\",UMI:\"minor.?outlying.?is\",URY:\"uruguay\",UZB:\"uzbek\",VUT:\"vanuatu|new.?hebrides\",VEN:\"venezuela\",VNM:\"^(?!.*republic).*viet.?nam|^(?=.*socialist).*viet.?nam\",VGB:\"^(?=.*\\\\bu\\\\.?\\\\s?k).*virgin|^(?=.*brit).*virgin|^(?=.*kingdom).*virgin\",VIR:\"^(?=.*\\\\bu\\\\.?\\\\s?s).*virgin|^(?=.*states).*virgin\",WLF:\"futuna|wallis\",ESH:\"western.sahara\",YEM:\"^(?!.*arab)(?!.*north)(?!.*sana)(?!.*peo)(?!.*dem)(?!.*south)(?!.*aden)(?!.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YMD:\"^(?=.*peo).*yemen|^(?!.*rep)(?=.*dem).*yemen|^(?=.*south).*yemen|^(?=.*aden).*yemen|^(?=.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YUG:\"yugoslavia\",ZMB:\"zambia|northern.?rhodesia\",EAZ:\"zanzibar\",ZWE:\"zimbabwe|^(?!.*northern).*rhodesia\"}},{}],135:[function(t,e,r){e.exports=[\"xx-small\",\"x-small\",\"small\",\"medium\",\"large\",\"x-large\",\"xx-large\",\"larger\",\"smaller\"]},{}],136:[function(t,e,r){e.exports=[\"normal\",\"condensed\",\"semi-condensed\",\"extra-condensed\",\"ultra-condensed\",\"expanded\",\"semi-expanded\",\"extra-expanded\",\"ultra-expanded\"]},{}],137:[function(t,e,r){e.exports=[\"normal\",\"italic\",\"oblique\"]},{}],138:[function(t,e,r){e.exports=[\"normal\",\"bold\",\"bolder\",\"lighter\",\"100\",\"200\",\"300\",\"400\",\"500\",\"600\",\"700\",\"800\",\"900\"]},{}],139:[function(t,e,r){\"use strict\";e.exports={parse:t(\"./parse\"),stringify:t(\"./stringify\")}},{\"./parse\":141,\"./stringify\":142}],140:[function(t,e,r){\"use strict\";var n=t(\"css-font-size-keywords\");e.exports={isSize:function(t){return/^[\\d\\.]/.test(t)||-1!==t.indexOf(\"/\")||-1!==n.indexOf(t)}}},{\"css-font-size-keywords\":135}],141:[function(t,e,r){\"use strict\";var n=t(\"unquote\"),i=t(\"css-global-keywords\"),a=t(\"css-system-font-keywords\"),o=t(\"css-font-weight-keywords\"),s=t(\"css-font-style-keywords\"),l=t(\"css-font-stretch-keywords\"),c=t(\"string-split-by\"),u=t(\"./lib/util\").isSize;e.exports=f;var h=f.cache={};function f(t){if(\"string\"!=typeof t)throw new Error(\"Font argument must be a string.\");if(h[t])return h[t];if(\"\"===t)throw new Error(\"Cannot parse an empty string.\");if(-1!==a.indexOf(t))return h[t]={system:t};for(var e,r={style:\"normal\",variant:\"normal\",weight:\"normal\",stretch:\"normal\",lineHeight:\"normal\",size:\"1rem\",family:[\"serif\"]},f=c(t,/\\s+/);e=f.shift();){if(-1!==i.indexOf(e))return[\"style\",\"variant\",\"weight\",\"stretch\"].forEach(function(t){r[t]=e}),h[t]=r;if(-1===s.indexOf(e))if(\"normal\"!==e&&\"small-caps\"!==e)if(-1===l.indexOf(e)){if(-1===o.indexOf(e)){if(u(e)){var d=c(e,\"/\");if(r.size=d[0],null!=d[1]?r.lineHeight=p(d[1]):\"/\"===f[0]&&(f.shift(),r.lineHeight=p(f.shift())),!f.length)throw new Error(\"Missing required font-family.\");return r.family=c(f.join(\" \"),/\\s*,\\s*/).map(n),h[t]=r}throw new Error(\"Unknown or unsupported font token: \"+e)}r.weight=e}else r.stretch=e;else r.variant=e;else r.style=e}throw new Error(\"Missing required font-size.\")}function p(t){var e=parseFloat(t);return e.toString()===t?e:t}},{\"./lib/util\":140,\"css-font-stretch-keywords\":136,\"css-font-style-keywords\":137,\"css-font-weight-keywords\":138,\"css-global-keywords\":143,\"css-system-font-keywords\":144,\"string-split-by\":529,unquote:548}],142:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\"),i=t(\"./lib/util\").isSize,a=g(t(\"css-global-keywords\")),o=g(t(\"css-system-font-keywords\")),s=g(t(\"css-font-weight-keywords\")),l=g(t(\"css-font-style-keywords\")),c=g(t(\"css-font-stretch-keywords\")),u={normal:1,\"small-caps\":1},h={serif:1,\"sans-serif\":1,monospace:1,cursive:1,fantasy:1,\"system-ui\":1},f=\"1rem\",p=\"serif\";function d(t,e){if(t&&!e[t]&&!a[t])throw Error(\"Unknown keyword `\"+t+\"`\");return t}function g(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=1;return e}e.exports=function(t){if((t=n(t,{style:\"style fontstyle fontStyle font-style slope distinction\",variant:\"variant font-variant fontVariant fontvariant var capitalization\",weight:\"weight w font-weight fontWeight fontweight\",stretch:\"stretch font-stretch fontStretch fontstretch width\",size:\"size s font-size fontSize fontsize height em emSize\",lineHeight:\"lh line-height lineHeight lineheight leading\",family:\"font family fontFamily font-family fontfamily type typeface face\",system:\"system reserved default global\"})).system)return t.system&&d(t.system,o),t.system;if(d(t.style,l),d(t.variant,u),d(t.weight,s),d(t.stretch,c),null==t.size&&(t.size=f),\"number\"==typeof t.size&&(t.size+=\"px\"),!i)throw Error(\"Bad size value `\"+t.size+\"`\");t.family||(t.family=p),Array.isArray(t.family)&&(t.family.length||(t.family=[p]),t.family=t.family.map(function(t){return h[t]?t:'\"'+t+'\"'}).join(\", \"));var e=[];return e.push(t.style),t.variant!==t.style&&e.push(t.variant),t.weight!==t.variant&&t.weight!==t.style&&e.push(t.weight),t.stretch!==t.weight&&t.stretch!==t.variant&&t.stretch!==t.style&&e.push(t.stretch),e.push(t.size+(null==t.lineHeight||\"normal\"===t.lineHeight||t.lineHeight+\"\"==\"1\"?\"\":\"/\"+t.lineHeight)),e.push(t.family),e.filter(Boolean).join(\" \")}},{\"./lib/util\":140,\"css-font-stretch-keywords\":136,\"css-font-style-keywords\":137,\"css-font-weight-keywords\":138,\"css-global-keywords\":143,\"css-system-font-keywords\":144,\"pick-by-alias\":465}],143:[function(t,e,r){e.exports=[\"inherit\",\"initial\",\"unset\"]},{}],144:[function(t,e,r){e.exports=[\"caption\",\"icon\",\"menu\",\"message-box\",\"small-caption\",\"status-bar\"]},{}],145:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i-1,s=i*i,l=o*o,c=(1+2*i)*l,u=i*l,h=s*(3-2*i),f=s*o;if(t.length){a||(a=new Array(t.length));for(var p=t.length-1;p>=0;--p)a[p]=c*t[p]+u*e[p]+h*r[p]+f*n[p];return a}return c*t+u*e+h*r+f*n},e.exports.derivative=function(t,e,r,n,i,a){var o=6*i*i-6*i,s=3*i*i-4*i+1,l=-6*i*i+6*i,c=3*i*i-2*i;if(t.length){a||(a=new Array(t.length));for(var u=t.length-1;u>=0;--u)a[u]=o*t[u]+s*e[u]+l*r[u]+c*n[u];return a}return o*t+s*e+l*r[u]+c*n}},{}],146:[function(t,e,r){\"use strict\";var n=t(\"./lib/thunk.js\");function i(){this.argTypes=[],this.shimArgs=[],this.arrayArgs=[],this.arrayBlockIndices=[],this.scalarArgs=[],this.offsetArgs=[],this.offsetArgIndex=[],this.indexArgs=[],this.shapeArgs=[],this.funcName=\"\",this.pre=null,this.body=null,this.post=null,this.debug=!1}e.exports=function(t){var e=new i;e.pre=t.pre,e.body=t.body,e.post=t.post;var r=t.args.slice(0);e.argTypes=r;for(var a=0;a<r.length;++a){var o=r[a];if(\"array\"===o||\"object\"==typeof o&&o.blockIndices){if(e.argTypes[a]=\"array\",e.arrayArgs.push(a),e.arrayBlockIndices.push(o.blockIndices?o.blockIndices:0),e.shimArgs.push(\"array\"+a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array args\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array args\")}else if(\"scalar\"===o)e.scalarArgs.push(a),e.shimArgs.push(\"scalar\"+a);else if(\"index\"===o){if(e.indexArgs.push(a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array index\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array index\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array index\")}else if(\"shape\"===o){if(e.shapeArgs.push(a),a<e.pre.args.length&&e.pre.args[a].lvalue)throw new Error(\"cwise: pre() block may not write to array shape\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array shape\");if(a<e.post.args.length&&e.post.args[a].lvalue)throw new Error(\"cwise: post() block may not write to array shape\")}else{if(\"object\"!=typeof o||!o.offset)throw new Error(\"cwise: Unknown argument type \"+r[a]);e.argTypes[a]=\"offset\",e.offsetArgs.push({array:o.array,offset:o.offset}),e.offsetArgIndex.push(a)}}if(e.arrayArgs.length<=0)throw new Error(\"cwise: No array arguments specified\");if(e.pre.args.length>r.length)throw new Error(\"cwise: Too many arguments in pre() block\");if(e.body.args.length>r.length)throw new Error(\"cwise: Too many arguments in body() block\");if(e.post.args.length>r.length)throw new Error(\"cwise: Too many arguments in post() block\");return e.debug=!!t.printCode||!!t.debug,e.funcName=t.funcName||\"cwise\",e.blockSize=t.blockSize||64,n(e)}},{\"./lib/thunk.js\":148}],147:[function(t,e,r){\"use strict\";var n=t(\"uniq\");function i(t,e,r){var n,i,a=t.length,o=e.arrayArgs.length,s=e.indexArgs.length>0,l=[],c=[],u=0,h=0;for(n=0;n<a;++n)c.push([\"i\",n,\"=0\"].join(\"\"));for(i=0;i<o;++i)for(n=0;n<a;++n)h=u,u=t[n],0===n?c.push([\"d\",i,\"s\",n,\"=t\",i,\"p\",u].join(\"\")):c.push([\"d\",i,\"s\",n,\"=(t\",i,\"p\",u,\"-s\",h,\"*t\",i,\"p\",h,\")\"].join(\"\"));for(c.length>0&&l.push(\"var \"+c.join(\",\")),n=a-1;n>=0;--n)u=t[n],l.push([\"for(i\",n,\"=0;i\",n,\"<s\",u,\";++i\",n,\"){\"].join(\"\"));for(l.push(r),n=0;n<a;++n){for(h=u,u=t[n],i=0;i<o;++i)l.push([\"p\",i,\"+=d\",i,\"s\",n].join(\"\"));s&&(n>0&&l.push([\"index[\",h,\"]-=s\",h].join(\"\")),l.push([\"++index[\",u,\"]\"].join(\"\"))),l.push(\"}\")}return l.join(\"\\n\")}function a(t,e,r){for(var n=t.body,i=[],a=[],o=0;o<t.args.length;++o){var s=t.args[o];if(!(s.count<=0)){var l=new RegExp(s.name,\"g\"),c=\"\",u=e.arrayArgs.indexOf(o);switch(e.argTypes[o]){case\"offset\":var h=e.offsetArgIndex.indexOf(o);u=e.offsetArgs[h].array,c=\"+q\"+h;case\"array\":c=\"p\"+u+c;var f=\"l\"+o,p=\"a\"+u;if(0===e.arrayBlockIndices[u])1===s.count?\"generic\"===r[u]?s.lvalue?(i.push([\"var \",f,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,f),a.push([p,\".set(\",c,\",\",f,\")\"].join(\"\"))):n=n.replace(l,[p,\".get(\",c,\")\"].join(\"\")):n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\")):\"generic\"===r[u]?(i.push([\"var \",f,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,f),s.lvalue&&a.push([p,\".set(\",c,\",\",f,\")\"].join(\"\"))):(i.push([\"var \",f,\"=\",p,\"[\",c,\"]\"].join(\"\")),n=n.replace(l,f),s.lvalue&&a.push([p,\"[\",c,\"]=\",f].join(\"\")));else{for(var d=[s.name],g=[c],v=0;v<Math.abs(e.arrayBlockIndices[u]);v++)d.push(\"\\\\s*\\\\[([^\\\\]]+)\\\\]\"),g.push(\"$\"+(v+1)+\"*t\"+u+\"b\"+v);if(l=new RegExp(d.join(\"\"),\"g\"),c=g.join(\"+\"),\"generic\"===r[u])throw new Error(\"cwise: Generic arrays not supported in combination with blocks!\");n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\"))}break;case\"scalar\":n=n.replace(l,\"Y\"+e.scalarArgs.indexOf(o));break;case\"index\":n=n.replace(l,\"index\");break;case\"shape\":n=n.replace(l,\"shape\")}}}return[i.join(\"\\n\"),n,a.join(\"\\n\")].join(\"\\n\").trim()}e.exports=function(t,e){for(var r=e[1].length-Math.abs(t.arrayBlockIndices[0])|0,o=new Array(t.arrayArgs.length),s=new Array(t.arrayArgs.length),l=0;l<t.arrayArgs.length;++l)s[l]=e[2*l],o[l]=e[2*l+1];var c=[],u=[],h=[],f=[],p=[];for(l=0;l<t.arrayArgs.length;++l){t.arrayBlockIndices[l]<0?(h.push(0),f.push(r),c.push(r),u.push(r+t.arrayBlockIndices[l])):(h.push(t.arrayBlockIndices[l]),f.push(t.arrayBlockIndices[l]+r),c.push(0),u.push(t.arrayBlockIndices[l]));for(var d=[],g=0;g<o[l].length;g++)h[l]<=o[l][g]&&o[l][g]<f[l]&&d.push(o[l][g]-h[l]);p.push(d)}var v=[\"SS\"],m=[\"'use strict'\"],y=[];for(g=0;g<r;++g)y.push([\"s\",g,\"=SS[\",g,\"]\"].join(\"\"));for(l=0;l<t.arrayArgs.length;++l){for(v.push(\"a\"+l),v.push(\"t\"+l),v.push(\"p\"+l),g=0;g<r;++g)y.push([\"t\",l,\"p\",g,\"=t\",l,\"[\",h[l]+g,\"]\"].join(\"\"));for(g=0;g<Math.abs(t.arrayBlockIndices[l]);++g)y.push([\"t\",l,\"b\",g,\"=t\",l,\"[\",c[l]+g,\"]\"].join(\"\"))}for(l=0;l<t.scalarArgs.length;++l)v.push(\"Y\"+l);if(t.shapeArgs.length>0&&y.push(\"shape=SS.slice(0)\"),t.indexArgs.length>0){var x=new Array(r);for(l=0;l<r;++l)x[l]=\"0\";y.push([\"index=[\",x.join(\",\"),\"]\"].join(\"\"))}for(l=0;l<t.offsetArgs.length;++l){var b=t.offsetArgs[l],_=[];for(g=0;g<b.offset.length;++g)0!==b.offset[g]&&(1===b.offset[g]?_.push([\"t\",b.array,\"p\",g].join(\"\")):_.push([b.offset[g],\"*t\",b.array,\"p\",g].join(\"\")));0===_.length?y.push(\"q\"+l+\"=0\"):y.push([\"q\",l,\"=\",_.join(\"+\")].join(\"\"))}var w=n([].concat(t.pre.thisVars).concat(t.body.thisVars).concat(t.post.thisVars));for((y=y.concat(w)).length>0&&m.push(\"var \"+y.join(\",\")),l=0;l<t.arrayArgs.length;++l)m.push(\"p\"+l+\"|=0\");t.pre.body.length>3&&m.push(a(t.pre,t,s));var k=a(t.body,t,s),T=function(t){for(var e=0,r=t[0].length;e<r;){for(var n=1;n<t.length;++n)if(t[n][e]!==t[0][e])return e;++e}return e}(p);T<r?m.push(function(t,e,r,n){for(var a=e.length,o=r.arrayArgs.length,s=r.blockSize,l=r.indexArgs.length>0,c=[],u=0;u<o;++u)c.push([\"var offset\",u,\"=p\",u].join(\"\"));for(u=t;u<a;++u)c.push([\"for(var j\"+u+\"=SS[\",e[u],\"]|0;j\",u,\">0;){\"].join(\"\")),c.push([\"if(j\",u,\"<\",s,\"){\"].join(\"\")),c.push([\"s\",e[u],\"=j\",u].join(\"\")),c.push([\"j\",u,\"=0\"].join(\"\")),c.push([\"}else{s\",e[u],\"=\",s].join(\"\")),c.push([\"j\",u,\"-=\",s,\"}\"].join(\"\")),l&&c.push([\"index[\",e[u],\"]=j\",u].join(\"\"));for(u=0;u<o;++u){for(var h=[\"offset\"+u],f=t;f<a;++f)h.push([\"j\",f,\"*t\",u,\"p\",e[f]].join(\"\"));c.push([\"p\",u,\"=(\",h.join(\"+\"),\")\"].join(\"\"))}for(c.push(i(e,r,n)),u=t;u<a;++u)c.push(\"}\");return c.join(\"\\n\")}(T,p[0],t,k)):m.push(i(p[0],t,k)),t.post.body.length>3&&m.push(a(t.post,t,s)),t.debug&&console.log(\"-----Generated cwise routine for \",e,\":\\n\"+m.join(\"\\n\")+\"\\n----------\");var A=[t.funcName||\"unnamed\",\"_cwise_loop_\",o[0].join(\"s\"),\"m\",T,function(t){for(var e=new Array(t.length),r=!0,n=0;n<t.length;++n){var i=t[n],a=i.match(/\\d+/);a=a?a[0]:\"\",0===i.charAt(0)?e[n]=\"u\"+i.charAt(1)+a:e[n]=i.charAt(0)+a,n>0&&(r=r&&e[n]===e[n-1])}return r?e[0]:e.join(\"\")}(s)].join(\"\");return new Function([\"function \",A,\"(\",v.join(\",\"),\"){\",m.join(\"\\n\"),\"} return \",A].join(\"\"))()}},{uniq:547}],148:[function(t,e,r){\"use strict\";var n=t(\"./compile.js\");e.exports=function(t){var e=[\"'use strict'\",\"var CACHED={}\"],r=[],i=t.funcName+\"_cwise_thunk\";e.push([\"return function \",i,\"(\",t.shimArgs.join(\",\"),\"){\"].join(\"\"));for(var a=[],o=[],s=[[\"array\",t.arrayArgs[0],\".shape.slice(\",Math.max(0,t.arrayBlockIndices[0]),t.arrayBlockIndices[0]<0?\",\"+t.arrayBlockIndices[0]+\")\":\")\"].join(\"\")],l=[],c=[],u=0;u<t.arrayArgs.length;++u){var h=t.arrayArgs[u];r.push([\"t\",h,\"=array\",h,\".dtype,\",\"r\",h,\"=array\",h,\".order\"].join(\"\")),a.push(\"t\"+h),a.push(\"r\"+h),o.push(\"t\"+h),o.push(\"r\"+h+\".join()\"),s.push(\"array\"+h+\".data\"),s.push(\"array\"+h+\".stride\"),s.push(\"array\"+h+\".offset|0\"),u>0&&(l.push(\"array\"+t.arrayArgs[0]+\".shape.length===array\"+h+\".shape.length+\"+(Math.abs(t.arrayBlockIndices[0])-Math.abs(t.arrayBlockIndices[u]))),c.push(\"array\"+t.arrayArgs[0]+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[0])+\"]===array\"+h+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[u])+\"]\"))}for(t.arrayArgs.length>1&&(e.push(\"if (!(\"+l.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same dimensionality!')\"),e.push(\"for(var shapeIndex=array\"+t.arrayArgs[0]+\".shape.length-\"+Math.abs(t.arrayBlockIndices[0])+\"; shapeIndex--\\x3e0;) {\"),e.push(\"if (!(\"+c.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same shape!')\"),e.push(\"}\")),u=0;u<t.scalarArgs.length;++u)s.push(\"scalar\"+t.scalarArgs[u]);return r.push([\"type=[\",o.join(\",\"),\"].join()\"].join(\"\")),r.push(\"proc=CACHED[type]\"),e.push(\"var \"+r.join(\",\")),e.push([\"if(!proc){\",\"CACHED[type]=proc=compile([\",a.join(\",\"),\"])}\",\"return proc(\",s.join(\",\"),\")}\"].join(\"\")),t.debug&&console.log(\"-----Generated thunk:\\n\"+e.join(\"\\n\")+\"\\n----------\"),new Function(\"compile\",e.join(\"\\n\"))(n.bind(void 0,t))}},{\"./compile.js\":147}],149:[function(t,e,r){e.exports=t(\"cwise-compiler\")},{\"cwise-compiler\":146}],150:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/copy\"),a=t(\"es5-ext/object/normalize-options\"),o=t(\"es5-ext/object/valid-callable\"),s=t(\"es5-ext/object/map\"),l=t(\"es5-ext/object/valid-callable\"),c=t(\"es5-ext/object/valid-value\"),u=Function.prototype.bind,h=Object.defineProperty,f=Object.prototype.hasOwnProperty;n=function(t,e,r){var n,a=c(e)&&l(e.value);return delete(n=i(e)).writable,delete n.value,n.get=function(){return!r.overwriteDefinition&&f.call(this,t)?a:(e.value=u.call(a,r.resolveContext?r.resolveContext(this):this),h(this,t,e),this[t])},n},e.exports=function(t){var e=a(arguments[1]);return null!=e.resolveContext&&o(e.resolveContext),s(t,function(t,r){return n(r,t,e)})}},{\"es5-ext/object/copy\":189,\"es5-ext/object/map\":198,\"es5-ext/object/normalize-options\":199,\"es5-ext/object/valid-callable\":203,\"es5-ext/object/valid-value\":205}],151:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/object/assign\"),i=t(\"es5-ext/object/normalize-options\"),a=t(\"es5-ext/object/is-callable\"),o=t(\"es5-ext/string/#/contains\");(e.exports=function(t,e){var r,a,s,l,c;return arguments.length<2||\"string\"!=typeof t?(l=e,e=t,t=null):l=arguments[2],null==t?(r=s=!0,a=!1):(r=o.call(t,\"c\"),a=o.call(t,\"e\"),s=o.call(t,\"w\")),c={value:e,configurable:r,enumerable:a,writable:s},l?n(i(l),c):c}).gs=function(t,e,r){var s,l,c,u;return\"string\"!=typeof t?(c=r,r=e,e=t,t=null):c=arguments[3],null==e?e=void 0:a(e)?null==r?r=void 0:a(r)||(c=r,r=void 0):(c=e,e=r=void 0),null==t?(s=!0,l=!1):(s=o.call(t,\"c\"),l=o.call(t,\"e\")),u={get:e,set:r,configurable:s,enumerable:l},c?n(i(c),u):u}},{\"es5-ext/object/assign\":186,\"es5-ext/object/is-callable\":192,\"es5-ext/object/normalize-options\":199,\"es5-ext/string/#/contains\":206}],152:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function r(t){var r;return 1===t.length&&(r=t,t=function(t,n){return e(r(t),n)}),{left:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}var n=r(e),i=n.right,a=n.left;function o(t,e){return[t,e]}function s(t){return null===t?NaN:+t}function l(t,e){var r,n,i=t.length,a=0,o=-1,l=0,c=0;if(null==e)for(;++o<i;)isNaN(r=s(t[o]))||(c+=(n=r-l)*(r-(l+=n/++a)));else for(;++o<i;)isNaN(r=s(e(t[o],o,t)))||(c+=(n=r-l)*(r-(l+=n/++a)));if(a>1)return c/(a-1)}function c(t,e){var r=l(t,e);return r?Math.sqrt(r):r}function u(t,e){var r,n,i,a=t.length,o=-1;if(null==e){for(;++o<a;)if(null!=(r=t[o])&&r>=r)for(n=i=r;++o<a;)null!=(r=t[o])&&(n>r&&(n=r),i<r&&(i=r))}else for(;++o<a;)if(null!=(r=e(t[o],o,t))&&r>=r)for(n=i=r;++o<a;)null!=(r=e(t[o],o,t))&&(n>r&&(n=r),i<r&&(i=r));return[n,i]}var h=Array.prototype,f=h.slice,p=h.map;function d(t){return function(){return t}}function g(t){return t}function v(t,e,r){t=+t,e=+e,r=(i=arguments.length)<2?(e=t,t=0,1):i<3?1:+r;for(var n=-1,i=0|Math.max(0,Math.ceil((e-t)/r)),a=new Array(i);++n<i;)a[n]=t+n*r;return a}var m=Math.sqrt(50),y=Math.sqrt(10),x=Math.sqrt(2);function b(t,e,r){var n=(e-t)/Math.max(0,r),i=Math.floor(Math.log(n)/Math.LN10),a=n/Math.pow(10,i);return i>=0?(a>=m?10:a>=y?5:a>=x?2:1)*Math.pow(10,i):-Math.pow(10,-i)/(a>=m?10:a>=y?5:a>=x?2:1)}function _(t,e,r){var n=Math.abs(e-t)/Math.max(0,r),i=Math.pow(10,Math.floor(Math.log(n)/Math.LN10)),a=n/i;return a>=m?i*=10:a>=y?i*=5:a>=x&&(i*=2),e<t?-i:i}function w(t){return Math.ceil(Math.log(t.length)/Math.LN2)+1}function k(t,e,r){if(null==r&&(r=s),n=t.length){if((e=+e)<=0||n<2)return+r(t[0],0,t);if(e>=1)return+r(t[n-1],n-1,t);var n,i=(n-1)*e,a=Math.floor(i),o=+r(t[a],a,t);return o+(+r(t[a+1],a+1,t)-o)*(i-a)}}function T(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&n>r&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&n>r&&(n=r);return n}function A(t){if(!(i=t.length))return[];for(var e=-1,r=T(t,M),n=new Array(r);++e<r;)for(var i,a=-1,o=n[e]=new Array(i);++a<i;)o[a]=t[a][e];return n}function M(t){return t.length}t.bisect=i,t.bisectRight=i,t.bisectLeft=a,t.ascending=e,t.bisector=r,t.cross=function(t,e,r){var n,i,a,s,l=t.length,c=e.length,u=new Array(l*c);for(null==r&&(r=o),n=a=0;n<l;++n)for(s=t[n],i=0;i<c;++i,++a)u[a]=r(s,e[i]);return u},t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.deviation=c,t.extent=u,t.histogram=function(){var t=g,e=u,r=w;function n(n){var a,o,s=n.length,l=new Array(s);for(a=0;a<s;++a)l[a]=t(n[a],a,n);var c=e(l),u=c[0],h=c[1],f=r(l,u,h);Array.isArray(f)||(f=_(u,h,f),f=v(Math.ceil(u/f)*f,h,f));for(var p=f.length;f[0]<=u;)f.shift(),--p;for(;f[p-1]>h;)f.pop(),--p;var d,g=new Array(p+1);for(a=0;a<=p;++a)(d=g[a]=[]).x0=a>0?f[a-1]:u,d.x1=a<p?f[a]:h;for(a=0;a<s;++a)u<=(o=l[a])&&o<=h&&g[i(f,o,0,p)].push(n[a]);return g}return n.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:d(e),n):t},n.domain=function(t){return arguments.length?(e=\"function\"==typeof t?t:d([t[0],t[1]]),n):e},n.thresholds=function(t){return arguments.length?(r=\"function\"==typeof t?t:Array.isArray(t)?d(f.call(t)):d(t),n):r},n},t.thresholdFreedmanDiaconis=function(t,r,n){return t=p.call(t,s).sort(e),Math.ceil((n-r)/(2*(k(t,.75)-k(t,.25))*Math.pow(t.length,-1/3)))},t.thresholdScott=function(t,e,r){return Math.ceil((r-e)/(3.5*c(t)*Math.pow(t.length,-1/3)))},t.thresholdSturges=w,t.max=function(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&r>n&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&r>n&&(n=r);return n},t.mean=function(t,e){var r,n=t.length,i=n,a=-1,o=0;if(null==e)for(;++a<n;)isNaN(r=s(t[a]))?--i:o+=r;else for(;++a<n;)isNaN(r=s(e(t[a],a,t)))?--i:o+=r;if(i)return o/i},t.median=function(t,r){var n,i=t.length,a=-1,o=[];if(null==r)for(;++a<i;)isNaN(n=s(t[a]))||o.push(n);else for(;++a<i;)isNaN(n=s(r(t[a],a,t)))||o.push(n);return k(o.sort(e),.5)},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r},t.min=T,t.pairs=function(t,e){null==e&&(e=o);for(var r=0,n=t.length-1,i=t[0],a=new Array(n<0?0:n);r<n;)a[r]=e(i,i=t[++r]);return a},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.quantile=k,t.range=v,t.scan=function(t,r){if(n=t.length){var n,i,a=0,o=0,s=t[o];for(null==r&&(r=e);++a<n;)(r(i=t[a],s)<0||0!==r(s,s))&&(s=i,o=a);return 0===r(s,s)?o:void 0}},t.shuffle=function(t,e,r){for(var n,i,a=(null==r?t.length:r)-(e=null==e?0:+e);a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.sum=function(t,e){var r,n=t.length,i=-1,a=0;if(null==e)for(;++i<n;)(r=+t[i])&&(a+=r);else for(;++i<n;)(r=+e(t[i],i,t))&&(a+=r);return a},t.ticks=function(t,e,r){var n,i,a,o,s=-1;if(r=+r,(t=+t)==(e=+e)&&r>0)return[t];if((n=e<t)&&(i=t,t=e,e=i),0===(o=b(t,e,r))||!isFinite(o))return[];if(o>0)for(t=Math.ceil(t/o),e=Math.floor(e/o),a=new Array(i=Math.ceil(e-t+1));++s<i;)a[s]=(t+s)*o;else for(t=Math.floor(t*o),e=Math.ceil(e*o),a=new Array(i=Math.ceil(t-e+1));++s<i;)a[s]=(t-s)/o;return n&&a.reverse(),a},t.tickIncrement=b,t.tickStep=_,t.transpose=A,t.variance=l,t.zip=function(){return A(arguments)},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],153:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(){}function r(t,r){var n=new e;if(t instanceof e)t.each(function(t,e){n.set(e,t)});else if(Array.isArray(t)){var i,a=-1,o=t.length;if(null==r)for(;++a<o;)n.set(a,t[a]);else for(;++a<o;)n.set(r(i=t[a],a,t),i)}else if(t)for(var s in t)n.set(s,t[s]);return n}e.prototype=r.prototype={constructor:e,has:function(t){return\"$\"+t in this},get:function(t){return this[\"$\"+t]},set:function(t,e){return this[\"$\"+t]=e,this},remove:function(t){var e=\"$\"+t;return e in this&&delete this[e]},clear:function(){for(var t in this)\"$\"===t[0]&&delete this[t]},keys:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(e.slice(1));return t},values:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(this[e]);return t},entries:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push({key:e.slice(1),value:this[e]});return t},size:function(){var t=0;for(var e in this)\"$\"===e[0]&&++t;return t},empty:function(){for(var t in this)if(\"$\"===t[0])return!1;return!0},each:function(t){for(var e in this)\"$\"===e[0]&&t(this[e],e.slice(1),this)}};function n(){return{}}function i(t,e,r){t[e]=r}function a(){return r()}function o(t,e,r){t.set(e,r)}function s(){}var l=r.prototype;function c(t,e){var r=new s;if(t instanceof s)t.each(function(t){r.add(t)});else if(t){var n=-1,i=t.length;if(null==e)for(;++n<i;)r.add(t[n]);else for(;++n<i;)r.add(e(t[n],n,t))}return r}s.prototype=c.prototype={constructor:s,has:l.has,add:function(t){return this[\"$\"+(t+=\"\")]=t,this},remove:l.remove,clear:l.clear,values:l.keys,size:l.size,empty:l.empty,each:l.each};t.nest=function(){var t,e,s,l=[],c=[];function u(n,i,a,o){if(i>=l.length)return null!=t&&n.sort(t),null!=e?e(n):n;for(var s,c,h,f=-1,p=n.length,d=l[i++],g=r(),v=a();++f<p;)(h=g.get(s=d(c=n[f])+\"\"))?h.push(c):g.set(s,[c]);return g.each(function(t,e){o(v,e,u(t,i,a,o))}),v}return s={object:function(t){return u(t,0,n,i)},map:function(t){return u(t,0,a,o)},entries:function(t){return function t(r,n){if(++n>l.length)return r;var i,a=c[n-1];return null!=e&&n>=l.length?i=r.entries():(i=[],r.each(function(e,r){i.push({key:r,values:t(e,n)})})),null!=a?i.sort(function(t,e){return a(t.key,e.key)}):i}(u(t,0,a,o),0)},key:function(t){return l.push(t),s},sortKeys:function(t){return c[l.length-1]=t,s},sortValues:function(e){return t=e,s},rollup:function(t){return e=t,s}}},t.set=c,t.map=r,t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],154:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e,r){t.prototype=e.prototype=r,r.constructor=t}function r(t,e){var r=Object.create(t.prototype);for(var n in e)r[n]=e[n];return r}function n(){}var i=\"\\\\s*([+-]?\\\\d+)\\\\s*\",a=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)\\\\s*\",o=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)%\\\\s*\",s=/^#([0-9a-f]{3})$/,l=/^#([0-9a-f]{6})$/,c=new RegExp(\"^rgb\\\\(\"+[i,i,i]+\"\\\\)$\"),u=new RegExp(\"^rgb\\\\(\"+[o,o,o]+\"\\\\)$\"),h=new RegExp(\"^rgba\\\\(\"+[i,i,i,a]+\"\\\\)$\"),f=new RegExp(\"^rgba\\\\(\"+[o,o,o,a]+\"\\\\)$\"),p=new RegExp(\"^hsl\\\\(\"+[a,o,o]+\"\\\\)$\"),d=new RegExp(\"^hsla\\\\(\"+[a,o,o,a]+\"\\\\)$\"),g={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};function v(t){var e;return t=(t+\"\").trim().toLowerCase(),(e=s.exec(t))?new _((e=parseInt(e[1],16))>>8&15|e>>4&240,e>>4&15|240&e,(15&e)<<4|15&e,1):(e=l.exec(t))?m(parseInt(e[1],16)):(e=c.exec(t))?new _(e[1],e[2],e[3],1):(e=u.exec(t))?new _(255*e[1]/100,255*e[2]/100,255*e[3]/100,1):(e=h.exec(t))?y(e[1],e[2],e[3],e[4]):(e=f.exec(t))?y(255*e[1]/100,255*e[2]/100,255*e[3]/100,e[4]):(e=p.exec(t))?k(e[1],e[2]/100,e[3]/100,1):(e=d.exec(t))?k(e[1],e[2]/100,e[3]/100,e[4]):g.hasOwnProperty(t)?m(g[t]):\"transparent\"===t?new _(NaN,NaN,NaN,0):null}function m(t){return new _(t>>16&255,t>>8&255,255&t,1)}function y(t,e,r,n){return n<=0&&(t=e=r=NaN),new _(t,e,r,n)}function x(t){return t instanceof n||(t=v(t)),t?new _((t=t.rgb()).r,t.g,t.b,t.opacity):new _}function b(t,e,r,n){return 1===arguments.length?x(t):new _(t,e,r,null==n?1:n)}function _(t,e,r,n){this.r=+t,this.g=+e,this.b=+r,this.opacity=+n}function w(t){return((t=Math.max(0,Math.min(255,Math.round(t)||0)))<16?\"0\":\"\")+t.toString(16)}function k(t,e,r,n){return n<=0?t=e=r=NaN:r<=0||r>=1?t=e=NaN:e<=0&&(t=NaN),new A(t,e,r,n)}function T(t,e,r,i){return 1===arguments.length?function(t){if(t instanceof A)return new A(t.h,t.s,t.l,t.opacity);if(t instanceof n||(t=v(t)),!t)return new A;if(t instanceof A)return t;var e=(t=t.rgb()).r/255,r=t.g/255,i=t.b/255,a=Math.min(e,r,i),o=Math.max(e,r,i),s=NaN,l=o-a,c=(o+a)/2;return l?(s=e===o?(r-i)/l+6*(r<i):r===o?(i-e)/l+2:(e-r)/l+4,l/=c<.5?o+a:2-o-a,s*=60):l=c>0&&c<1?0:s,new A(s,l,c,t.opacity)}(t):new A(t,e,r,null==i?1:i)}function A(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}function M(t,e,r){return 255*(t<60?e+(r-e)*t/60:t<180?r:t<240?e+(r-e)*(240-t)/60:e)}e(n,v,{displayable:function(){return this.rgb().displayable()},hex:function(){return this.rgb().hex()},toString:function(){return this.rgb()+\"\"}}),e(_,b,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new _(this.r*t,this.g*t,this.b*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new _(this.r*t,this.g*t,this.b*t,this.opacity)},rgb:function(){return this},displayable:function(){return 0<=this.r&&this.r<=255&&0<=this.g&&this.g<=255&&0<=this.b&&this.b<=255&&0<=this.opacity&&this.opacity<=1},hex:function(){return\"#\"+w(this.r)+w(this.g)+w(this.b)},toString:function(){var t=this.opacity;return(1===(t=isNaN(t)?1:Math.max(0,Math.min(1,t)))?\"rgb(\":\"rgba(\")+Math.max(0,Math.min(255,Math.round(this.r)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.g)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.b)||0))+(1===t?\")\":\", \"+t+\")\")}})),e(A,T,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new A(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new A(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=this.h%360+360*(this.h<0),e=isNaN(t)||isNaN(this.s)?0:this.s,r=this.l,n=r+(r<.5?r:1-r)*e,i=2*r-n;return new _(M(t>=240?t-240:t+120,i,n),M(t,i,n),M(t<120?t+240:t-120,i,n),this.opacity)},displayable:function(){return(0<=this.s&&this.s<=1||isNaN(this.s))&&0<=this.l&&this.l<=1&&0<=this.opacity&&this.opacity<=1}}));var S=Math.PI/180,E=180/Math.PI,C=.96422,L=1,P=.82521,O=4/29,z=6/29,I=3*z*z,D=z*z*z;function R(t){if(t instanceof B)return new B(t.l,t.a,t.b,t.opacity);if(t instanceof G){if(isNaN(t.h))return new B(t.l,0,0,t.opacity);var e=t.h*S;return new B(t.l,Math.cos(e)*t.c,Math.sin(e)*t.c,t.opacity)}t instanceof _||(t=x(t));var r,n,i=V(t.r),a=V(t.g),o=V(t.b),s=N((.2225045*i+.7168786*a+.0606169*o)/L);return i===a&&a===o?r=n=s:(r=N((.4360747*i+.3850649*a+.1430804*o)/C),n=N((.0139322*i+.0971045*a+.7141733*o)/P)),new B(116*s-16,500*(r-s),200*(s-n),t.opacity)}function F(t,e,r,n){return 1===arguments.length?R(t):new B(t,e,r,null==n?1:n)}function B(t,e,r,n){this.l=+t,this.a=+e,this.b=+r,this.opacity=+n}function N(t){return t>D?Math.pow(t,1/3):t/I+O}function j(t){return t>z?t*t*t:I*(t-O)}function U(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function V(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function q(t){if(t instanceof G)return new G(t.h,t.c,t.l,t.opacity);if(t instanceof B||(t=R(t)),0===t.a&&0===t.b)return new G(NaN,0,t.l,t.opacity);var e=Math.atan2(t.b,t.a)*E;return new G(e<0?e+360:e,Math.sqrt(t.a*t.a+t.b*t.b),t.l,t.opacity)}function H(t,e,r,n){return 1===arguments.length?q(t):new G(t,e,r,null==n?1:n)}function G(t,e,r,n){this.h=+t,this.c=+e,this.l=+r,this.opacity=+n}e(B,F,r(n,{brighter:function(t){return new B(this.l+18*(null==t?1:t),this.a,this.b,this.opacity)},darker:function(t){return new B(this.l-18*(null==t?1:t),this.a,this.b,this.opacity)},rgb:function(){var t=(this.l+16)/116,e=isNaN(this.a)?t:t+this.a/500,r=isNaN(this.b)?t:t-this.b/200;return new _(U(3.1338561*(e=C*j(e))-1.6168667*(t=L*j(t))-.4906146*(r=P*j(r))),U(-.9787684*e+1.9161415*t+.033454*r),U(.0719453*e-.2289914*t+1.4052427*r),this.opacity)}})),e(G,H,r(n,{brighter:function(t){return new G(this.h,this.c,this.l+18*(null==t?1:t),this.opacity)},darker:function(t){return new G(this.h,this.c,this.l-18*(null==t?1:t),this.opacity)},rgb:function(){return R(this).rgb()}}));var Y=-.14861,W=1.78277,X=-.29227,Z=-.90649,J=1.97294,K=J*Z,$=J*W,Q=W*X-Z*Y;function tt(t,e,r,n){return 1===arguments.length?function(t){if(t instanceof et)return new et(t.h,t.s,t.l,t.opacity);t instanceof _||(t=x(t));var e=t.r/255,r=t.g/255,n=t.b/255,i=(Q*n+K*e-$*r)/(Q+K-$),a=n-i,o=(J*(r-i)-X*a)/Z,s=Math.sqrt(o*o+a*a)/(J*i*(1-i)),l=s?Math.atan2(o,a)*E-120:NaN;return new et(l<0?l+360:l,s,i,t.opacity)}(t):new et(t,e,r,null==n?1:n)}function et(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}e(et,tt,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new et(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new et(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=isNaN(this.h)?0:(this.h+120)*S,e=+this.l,r=isNaN(this.s)?0:this.s*e*(1-e),n=Math.cos(t),i=Math.sin(t);return new _(255*(e+r*(Y*n+W*i)),255*(e+r*(X*n+Z*i)),255*(e+r*(J*n)),this.opacity)}})),t.color=v,t.rgb=b,t.hsl=T,t.lab=F,t.hcl=H,t.lch=function(t,e,r,n){return 1===arguments.length?q(t):new G(r,e,t,null==n?1:n)},t.gray=function(t,e){return new B(t,0,0,null==e?1:e)},t.cubehelix=tt,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],155:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e={value:function(){}};function r(){for(var t,e=0,r=arguments.length,i={};e<r;++e){if(!(t=arguments[e]+\"\")||t in i)throw new Error(\"illegal type: \"+t);i[t]=[]}return new n(i)}function n(t){this._=t}function i(t,e){for(var r,n=0,i=t.length;n<i;++n)if((r=t[n]).name===e)return r.value}function a(t,r,n){for(var i=0,a=t.length;i<a;++i)if(t[i].name===r){t[i]=e,t=t.slice(0,i).concat(t.slice(i+1));break}return null!=n&&t.push({name:r,value:n}),t}n.prototype=r.prototype={constructor:n,on:function(t,e){var r,n,o=this._,s=(n=o,(t+\"\").trim().split(/^|\\s+/).map(function(t){var e=\"\",r=t.indexOf(\".\");if(r>=0&&(e=t.slice(r+1),t=t.slice(0,r)),t&&!n.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);return{type:t,name:e}})),l=-1,c=s.length;if(!(arguments.length<2)){if(null!=e&&\"function\"!=typeof e)throw new Error(\"invalid callback: \"+e);for(;++l<c;)if(r=(t=s[l]).type)o[r]=a(o[r],t.name,e);else if(null==e)for(r in o)o[r]=a(o[r],t.name,null);return this}for(;++l<c;)if((r=(t=s[l]).type)&&(r=i(o[r],t.name)))return r},copy:function(){var t={},e=this._;for(var r in e)t[r]=e[r].slice();return new n(t)},call:function(t,e){if((r=arguments.length-2)>0)for(var r,n,i=new Array(r),a=0;a<r;++a)i[a]=arguments[a+2];if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(a=0,r=(n=this._[t]).length;a<r;++a)n[a].value.apply(e,i)},apply:function(t,e,r){if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(var n=this._[t],i=0,a=n.length;i<a;++i)n[i].value.apply(e,r)}},t.dispatch=r,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],156:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n,i){\"use strict\";var a=function(t){return function(){return t}},o=function(){return 1e-6*(Math.random()-.5)};function s(t){return t.x+t.vx}function l(t){return t.y+t.vy}function c(t){return t.index}function u(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function h(t){return t.x}function f(t){return t.y}var p=10,d=Math.PI*(3-Math.sqrt(5));t.forceCenter=function(t,e){var r;function n(){var n,i,a=r.length,o=0,s=0;for(n=0;n<a;++n)o+=(i=r[n]).x,s+=i.y;for(o=o/a-t,s=s/a-e,n=0;n<a;++n)(i=r[n]).x-=o,i.y-=s}return null==t&&(t=0),null==e&&(e=0),n.initialize=function(t){r=t},n.x=function(e){return arguments.length?(t=+e,n):t},n.y=function(t){return arguments.length?(e=+t,n):e},n},t.forceCollide=function(t){var r,n,i=1,c=1;function u(){for(var t,a,u,f,p,d,g,v=r.length,m=0;m<c;++m)for(a=e.quadtree(r,s,l).visitAfter(h),t=0;t<v;++t)u=r[t],d=n[u.index],g=d*d,f=u.x+u.vx,p=u.y+u.vy,a.visit(y);function y(t,e,r,n,a){var s=t.data,l=t.r,c=d+l;if(!s)return e>f+c||n<f-c||r>p+c||a<p-c;if(s.index>u.index){var h=f-s.x-s.vx,v=p-s.y-s.vy,m=h*h+v*v;m<c*c&&(0===h&&(m+=(h=o())*h),0===v&&(m+=(v=o())*v),m=(c-(m=Math.sqrt(m)))/m*i,u.vx+=(h*=m)*(c=(l*=l)/(g+l)),u.vy+=(v*=m)*c,s.vx-=h*(c=1-c),s.vy-=v*c)}}}function h(t){if(t.data)return t.r=n[t.data.index];for(var e=t.r=0;e<4;++e)t[e]&&t[e].r>t.r&&(t.r=t[e].r)}function f(){if(r){var e,i,a=r.length;for(n=new Array(a),e=0;e<a;++e)i=r[e],n[i.index]=+t(i,e,r)}}return\"function\"!=typeof t&&(t=a(null==t?1:+t)),u.initialize=function(t){r=t,f()},u.iterations=function(t){return arguments.length?(c=+t,u):c},u.strength=function(t){return arguments.length?(i=+t,u):i},u.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),f(),u):t},u},t.forceLink=function(t){var e,n,i,s,l,h=c,f=function(t){return 1/Math.min(s[t.source.index],s[t.target.index])},p=a(30),d=1;function g(r){for(var i=0,a=t.length;i<d;++i)for(var s,c,u,h,f,p,g,v=0;v<a;++v)c=(s=t[v]).source,h=(u=s.target).x+u.vx-c.x-c.vx||o(),f=u.y+u.vy-c.y-c.vy||o(),h*=p=((p=Math.sqrt(h*h+f*f))-n[v])/p*r*e[v],f*=p,u.vx-=h*(g=l[v]),u.vy-=f*g,c.vx+=h*(g=1-g),c.vy+=f*g}function v(){if(i){var a,o,c=i.length,f=t.length,p=r.map(i,h);for(a=0,s=new Array(c);a<f;++a)(o=t[a]).index=a,\"object\"!=typeof o.source&&(o.source=u(p,o.source)),\"object\"!=typeof o.target&&(o.target=u(p,o.target)),s[o.source.index]=(s[o.source.index]||0)+1,s[o.target.index]=(s[o.target.index]||0)+1;for(a=0,l=new Array(f);a<f;++a)o=t[a],l[a]=s[o.source.index]/(s[o.source.index]+s[o.target.index]);e=new Array(f),m(),n=new Array(f),y()}}function m(){if(i)for(var r=0,n=t.length;r<n;++r)e[r]=+f(t[r],r,t)}function y(){if(i)for(var e=0,r=t.length;e<r;++e)n[e]=+p(t[e],e,t)}return null==t&&(t=[]),g.initialize=function(t){i=t,v()},g.links=function(e){return arguments.length?(t=e,v(),g):t},g.id=function(t){return arguments.length?(h=t,g):h},g.iterations=function(t){return arguments.length?(d=+t,g):d},g.strength=function(t){return arguments.length?(f=\"function\"==typeof t?t:a(+t),m(),g):f},g.distance=function(t){return arguments.length?(p=\"function\"==typeof t?t:a(+t),y(),g):p},g},t.forceManyBody=function(){var t,r,n,i,s=a(-30),l=1,c=1/0,u=.81;function p(i){var a,o=t.length,s=e.quadtree(t,h,f).visitAfter(g);for(n=i,a=0;a<o;++a)r=t[a],s.visit(v)}function d(){if(t){var e,r,n=t.length;for(i=new Array(n),e=0;e<n;++e)r=t[e],i[r.index]=+s(r,e,t)}}function g(t){var e,r,n,a,o,s=0,l=0;if(t.length){for(n=a=o=0;o<4;++o)(e=t[o])&&(r=Math.abs(e.value))&&(s+=e.value,l+=r,n+=r*e.x,a+=r*e.y);t.x=n/l,t.y=a/l}else{(e=t).x=e.data.x,e.y=e.data.y;do{s+=i[e.data.index]}while(e=e.next)}t.value=s}function v(t,e,a,s){if(!t.value)return!0;var h=t.x-r.x,f=t.y-r.y,p=s-e,d=h*h+f*f;if(p*p/u<d)return d<c&&(0===h&&(d+=(h=o())*h),0===f&&(d+=(f=o())*f),d<l&&(d=Math.sqrt(l*d)),r.vx+=h*t.value*n/d,r.vy+=f*t.value*n/d),!0;if(!(t.length||d>=c)){(t.data!==r||t.next)&&(0===h&&(d+=(h=o())*h),0===f&&(d+=(f=o())*f),d<l&&(d=Math.sqrt(l*d)));do{t.data!==r&&(p=i[t.data.index]*n/d,r.vx+=h*p,r.vy+=f*p)}while(t=t.next)}}return p.initialize=function(e){t=e,d()},p.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),d(),p):s},p.distanceMin=function(t){return arguments.length?(l=t*t,p):Math.sqrt(l)},p.distanceMax=function(t){return arguments.length?(c=t*t,p):Math.sqrt(c)},p.theta=function(t){return arguments.length?(u=t*t,p):Math.sqrt(u)},p},t.forceRadial=function(t,e,r){var n,i,o,s=a(.1);function l(t){for(var a=0,s=n.length;a<s;++a){var l=n[a],c=l.x-e||1e-6,u=l.y-r||1e-6,h=Math.sqrt(c*c+u*u),f=(o[a]-h)*i[a]*t/h;l.vx+=c*f,l.vy+=u*f}}function c(){if(n){var e,r=n.length;for(i=new Array(r),o=new Array(r),e=0;e<r;++e)o[e]=+t(n[e],e,n),i[e]=isNaN(o[e])?0:+s(n[e],e,n)}}return\"function\"!=typeof t&&(t=a(+t)),null==e&&(e=0),null==r&&(r=0),l.initialize=function(t){n=t,c()},l.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),c(),l):s},l.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),c(),l):t},l.x=function(t){return arguments.length?(e=+t,l):e},l.y=function(t){return arguments.length?(r=+t,l):r},l},t.forceSimulation=function(t){var e,a=1,o=.001,s=1-Math.pow(o,1/300),l=0,c=.6,u=r.map(),h=i.timer(g),f=n.dispatch(\"tick\",\"end\");function g(){v(),f.call(\"tick\",e),a<o&&(h.stop(),f.call(\"end\",e))}function v(){var e,r,n=t.length;for(a+=(l-a)*s,u.each(function(t){t(a)}),e=0;e<n;++e)null==(r=t[e]).fx?r.x+=r.vx*=c:(r.x=r.fx,r.vx=0),null==r.fy?r.y+=r.vy*=c:(r.y=r.fy,r.vy=0)}function m(){for(var e,r=0,n=t.length;r<n;++r){if((e=t[r]).index=r,isNaN(e.x)||isNaN(e.y)){var i=p*Math.sqrt(r),a=r*d;e.x=i*Math.cos(a),e.y=i*Math.sin(a)}(isNaN(e.vx)||isNaN(e.vy))&&(e.vx=e.vy=0)}}function y(e){return e.initialize&&e.initialize(t),e}return null==t&&(t=[]),m(),e={tick:v,restart:function(){return h.restart(g),e},stop:function(){return h.stop(),e},nodes:function(r){return arguments.length?(t=r,m(),u.each(y),e):t},alpha:function(t){return arguments.length?(a=+t,e):a},alphaMin:function(t){return arguments.length?(o=+t,e):o},alphaDecay:function(t){return arguments.length?(s=+t,e):+s},alphaTarget:function(t){return arguments.length?(l=+t,e):l},velocityDecay:function(t){return arguments.length?(c=1-t,e):1-c},force:function(t,r){return arguments.length>1?(null==r?u.remove(t):u.set(t,y(r)),e):u.get(t)},find:function(e,r,n){var i,a,o,s,l,c=0,u=t.length;for(null==n?n=1/0:n*=n,c=0;c<u;++c)(o=(i=e-(s=t[c]).x)*i+(a=r-s.y)*a)<n&&(l=s,n=o);return l},on:function(t,r){return arguments.length>1?(f.on(t,r),e):f.on(t)}}},t.forceX=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vx+=(n[a]-i.x)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},t.forceY=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vy+=(n[a]-i.y)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.y=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-quadtree\"),t(\"d3-collection\"),t(\"d3-dispatch\"),t(\"d3-timer\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,n.d3)},{\"d3-collection\":153,\"d3-dispatch\":155,\"d3-quadtree\":160,\"d3-timer\":162}],157:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e){return t.parent===e.parent?1:2}function r(t,e){return t+e.x}function n(t,e){return Math.max(t,e.y)}function i(t){var e=0,r=t.children,n=r&&r.length;if(n)for(;--n>=0;)e+=r[n].value;else e=1;t.value=e}function a(t,e){var r,n,i,a,s,u=new c(t),h=+t.value&&(u.value=t.value),f=[u];for(null==e&&(e=o);r=f.pop();)if(h&&(r.value=+r.data.value),(i=e(r.data))&&(s=i.length))for(r.children=new Array(s),a=s-1;a>=0;--a)f.push(n=r.children[a]=new c(i[a])),n.parent=r,n.depth=r.depth+1;return u.eachBefore(l)}function o(t){return t.children}function s(t){t.data=t.data.data}function l(t){var e=0;do{t.height=e}while((t=t.parent)&&t.height<++e)}function c(t){this.data=t,this.depth=this.height=0,this.parent=null}c.prototype=a.prototype={constructor:c,count:function(){return this.eachAfter(i)},each:function(t){var e,r,n,i,a=this,o=[a];do{for(e=o.reverse(),o=[];a=e.pop();)if(t(a),r=a.children)for(n=0,i=r.length;n<i;++n)o.push(r[n])}while(o.length);return this},eachAfter:function(t){for(var e,r,n,i=this,a=[i],o=[];i=a.pop();)if(o.push(i),e=i.children)for(r=0,n=e.length;r<n;++r)a.push(e[r]);for(;i=o.pop();)t(i);return this},eachBefore:function(t){for(var e,r,n=this,i=[n];n=i.pop();)if(t(n),e=n.children)for(r=e.length-1;r>=0;--r)i.push(e[r]);return this},sum:function(t){return this.eachAfter(function(e){for(var r=+t(e.data)||0,n=e.children,i=n&&n.length;--i>=0;)r+=n[i].value;e.value=r})},sort:function(t){return this.eachBefore(function(e){e.children&&e.children.sort(t)})},path:function(t){for(var e=this,r=function(t,e){if(t===e)return t;var r=t.ancestors(),n=e.ancestors(),i=null;for(t=r.pop(),e=n.pop();t===e;)i=t,t=r.pop(),e=n.pop();return i}(e,t),n=[e];e!==r;)e=e.parent,n.push(e);for(var i=n.length;t!==r;)n.splice(i,0,t),t=t.parent;return n},ancestors:function(){for(var t=this,e=[t];t=t.parent;)e.push(t);return e},descendants:function(){var t=[];return this.each(function(e){t.push(e)}),t},leaves:function(){var t=[];return this.eachBefore(function(e){e.children||t.push(e)}),t},links:function(){var t=this,e=[];return t.each(function(r){r!==t&&e.push({source:r.parent,target:r})}),e},copy:function(){return a(this).eachBefore(s)}};var u=Array.prototype.slice;function h(t){for(var e,r,n=0,i=(t=function(t){for(var e,r,n=t.length;n;)r=Math.random()*n--|0,e=t[n],t[n]=t[r],t[r]=e;return t}(u.call(t))).length,a=[];n<i;)e=t[n],r&&d(r,e)?++n:(r=v(a=f(a,e)),n=0);return r}function f(t,e){var r,n;if(g(e,t))return[e];for(r=0;r<t.length;++r)if(p(e,t[r])&&g(m(t[r],e),t))return[t[r],e];for(r=0;r<t.length-1;++r)for(n=r+1;n<t.length;++n)if(p(m(t[r],t[n]),e)&&p(m(t[r],e),t[n])&&p(m(t[n],e),t[r])&&g(y(t[r],t[n],e),t))return[t[r],t[n],e];throw new Error}function p(t,e){var r=t.r-e.r,n=e.x-t.x,i=e.y-t.y;return r<0||r*r<n*n+i*i}function d(t,e){var r=t.r-e.r+1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function g(t,e){for(var r=0;r<e.length;++r)if(!d(t,e[r]))return!1;return!0}function v(t){switch(t.length){case 1:return{x:(e=t[0]).x,y:e.y,r:e.r};case 2:return m(t[0],t[1]);case 3:return y(t[0],t[1],t[2])}var e}function m(t,e){var r=t.x,n=t.y,i=t.r,a=e.x,o=e.y,s=e.r,l=a-r,c=o-n,u=s-i,h=Math.sqrt(l*l+c*c);return{x:(r+a+l/h*u)/2,y:(n+o+c/h*u)/2,r:(h+i+s)/2}}function y(t,e,r){var n=t.x,i=t.y,a=t.r,o=e.x,s=e.y,l=e.r,c=r.x,u=r.y,h=r.r,f=n-o,p=n-c,d=i-s,g=i-u,v=l-a,m=h-a,y=n*n+i*i-a*a,x=y-o*o-s*s+l*l,b=y-c*c-u*u+h*h,_=p*d-f*g,w=(d*b-g*x)/(2*_)-n,k=(g*v-d*m)/_,T=(p*x-f*b)/(2*_)-i,A=(f*m-p*v)/_,M=k*k+A*A-1,S=2*(a+w*k+T*A),E=w*w+T*T-a*a,C=-(M?(S+Math.sqrt(S*S-4*M*E))/(2*M):E/S);return{x:n+w+k*C,y:i+T+A*C,r:C}}function x(t,e,r){var n,i,a,o,s=t.x-e.x,l=t.y-e.y,c=s*s+l*l;c?(i=e.r+r.r,i*=i,o=t.r+r.r,i>(o*=o)?(n=(c+o-i)/(2*c),a=Math.sqrt(Math.max(0,o/c-n*n)),r.x=t.x-n*s-a*l,r.y=t.y-n*l+a*s):(n=(c+i-o)/(2*c),a=Math.sqrt(Math.max(0,i/c-n*n)),r.x=e.x+n*s-a*l,r.y=e.y+n*l+a*s)):(r.x=e.x+r.r,r.y=e.y)}function b(t,e){var r=t.r+e.r-1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function _(t){var e=t._,r=t.next._,n=e.r+r.r,i=(e.x*r.r+r.x*e.r)/n,a=(e.y*r.r+r.y*e.r)/n;return i*i+a*a}function w(t){this._=t,this.next=null,this.previous=null}function k(t){if(!(i=t.length))return 0;var e,r,n,i,a,o,s,l,c,u,f;if((e=t[0]).x=0,e.y=0,!(i>1))return e.r;if(r=t[1],e.x=-r.r,r.x=e.r,r.y=0,!(i>2))return e.r+r.r;x(r,e,n=t[2]),e=new w(e),r=new w(r),n=new w(n),e.next=n.previous=r,r.next=e.previous=n,n.next=r.previous=e;t:for(s=3;s<i;++s){x(e._,r._,n=t[s]),n=new w(n),l=r.next,c=e.previous,u=r._.r,f=e._.r;do{if(u<=f){if(b(l._,n._)){r=l,e.next=r,r.previous=e,--s;continue t}u+=l._.r,l=l.next}else{if(b(c._,n._)){(e=c).next=r,r.previous=e,--s;continue t}f+=c._.r,c=c.previous}}while(l!==c.next);for(n.previous=e,n.next=r,e.next=r.previous=r=n,a=_(e);(n=n.next)!==r;)(o=_(n))<a&&(e=n,a=o);r=e.next}for(e=[r._],n=r;(n=n.next)!==r;)e.push(n._);for(n=h(e),s=0;s<i;++s)(e=t[s]).x-=n.x,e.y-=n.y;return n.r}function T(t){if(\"function\"!=typeof t)throw new Error;return t}function A(){return 0}function M(t){return function(){return t}}function S(t){return Math.sqrt(t.value)}function E(t){return function(e){e.children||(e.r=Math.max(0,+t(e)||0))}}function C(t,e){return function(r){if(n=r.children){var n,i,a,o=n.length,s=t(r)*e||0;if(s)for(i=0;i<o;++i)n[i].r+=s;if(a=k(n),s)for(i=0;i<o;++i)n[i].r-=s;r.r=a+s}}}function L(t){return function(e){var r=e.parent;e.r*=t,r&&(e.x=r.x+t*e.x,e.y=r.y+t*e.y)}}function P(t){t.x0=Math.round(t.x0),t.y0=Math.round(t.y0),t.x1=Math.round(t.x1),t.y1=Math.round(t.y1)}function O(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(n-e)/t.value;++s<l;)(a=o[s]).y0=r,a.y1=i,a.x0=e,a.x1=e+=a.value*c}var z=\"$\",I={depth:-1},D={};function R(t){return t.id}function F(t){return t.parentId}function B(t,e){return t.parent===e.parent?1:2}function N(t){var e=t.children;return e?e[0]:t.t}function j(t){var e=t.children;return e?e[e.length-1]:t.t}function U(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function V(t,e,r){return t.a.parent===e.parent?t.a:r}function q(t,e){this._=t,this.parent=null,this.children=null,this.A=null,this.a=this,this.z=0,this.m=0,this.c=0,this.s=0,this.t=null,this.i=e}function H(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(i-r)/t.value;++s<l;)(a=o[s]).x0=e,a.x1=n,a.y0=r,a.y1=r+=a.value*c}q.prototype=Object.create(c.prototype);var G=(1+Math.sqrt(5))/2;function Y(t,e,r,n,i,a){for(var o,s,l,c,u,h,f,p,d,g,v,m=[],y=e.children,x=0,b=0,_=y.length,w=e.value;x<_;){l=i-r,c=a-n;do{u=y[b++].value}while(!u&&b<_);for(h=f=u,v=u*u*(g=Math.max(c/l,l/c)/(w*t)),d=Math.max(f/v,v/h);b<_;++b){if(u+=s=y[b].value,s<h&&(h=s),s>f&&(f=s),v=u*u*g,(p=Math.max(f/v,v/h))>d){u-=s;break}d=p}m.push(o={value:u,dice:l<c,children:y.slice(x,b)}),o.dice?O(o,r,n,i,w?n+=c*u/w:a):H(o,r,n,w?r+=l*u/w:i,a),w-=u,x=b}return m}var W=function t(e){function r(t,r,n,i,a){Y(e,t,r,n,i,a)}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);var X=function t(e){function r(t,r,n,i,a){if((o=t._squarify)&&o.ratio===e)for(var o,s,l,c,u,h=-1,f=o.length,p=t.value;++h<f;){for(l=(s=o[h]).children,c=s.value=0,u=l.length;c<u;++c)s.value+=l[c].value;s.dice?O(s,r,n,i,n+=(a-n)*s.value/p):H(s,r,n,r+=(i-r)*s.value/p,a),p-=s.value}else t._squarify=o=Y(e,t,r,n,i,a),o.ratio=e}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);t.cluster=function(){var t=e,i=1,a=1,o=!1;function s(e){var s,l=0;e.eachAfter(function(e){var i=e.children;i?(e.x=function(t){return t.reduce(r,0)/t.length}(i),e.y=function(t){return 1+t.reduce(n,0)}(i)):(e.x=s?l+=t(e,s):0,e.y=0,s=e)});var c=function(t){for(var e;e=t.children;)t=e[0];return t}(e),u=function(t){for(var e;e=t.children;)t=e[e.length-1];return t}(e),h=c.x-t(c,u)/2,f=u.x+t(u,c)/2;return e.eachAfter(o?function(t){t.x=(t.x-e.x)*i,t.y=(e.y-t.y)*a}:function(t){t.x=(t.x-h)/(f-h)*i,t.y=(1-(e.y?t.y/e.y:1))*a})}return s.separation=function(e){return arguments.length?(t=e,s):t},s.size=function(t){return arguments.length?(o=!1,i=+t[0],a=+t[1],s):o?null:[i,a]},s.nodeSize=function(t){return arguments.length?(o=!0,i=+t[0],a=+t[1],s):o?[i,a]:null},s},t.hierarchy=a,t.pack=function(){var t=null,e=1,r=1,n=A;function i(i){return i.x=e/2,i.y=r/2,t?i.eachBefore(E(t)).eachAfter(C(n,.5)).eachBefore(L(1)):i.eachBefore(E(S)).eachAfter(C(A,1)).eachAfter(C(n,i.r/Math.min(e,r))).eachBefore(L(Math.min(e,r)/(2*i.r))),i}return i.radius=function(e){return arguments.length?(t=null==(r=e)?null:T(r),i):t;var r},i.size=function(t){return arguments.length?(e=+t[0],r=+t[1],i):[e,r]},i.padding=function(t){return arguments.length?(n=\"function\"==typeof t?t:M(+t),i):n},i},t.packSiblings=function(t){return k(t),t},t.packEnclose=h,t.partition=function(){var t=1,e=1,r=0,n=!1;function i(i){var a=i.height+1;return i.x0=i.y0=r,i.x1=t,i.y1=e/a,i.eachBefore(function(t,e){return function(n){n.children&&O(n,n.x0,t*(n.depth+1)/e,n.x1,t*(n.depth+2)/e);var i=n.x0,a=n.y0,o=n.x1-r,s=n.y1-r;o<i&&(i=o=(i+o)/2),s<a&&(a=s=(a+s)/2),n.x0=i,n.y0=a,n.x1=o,n.y1=s}}(e,a)),n&&i.eachBefore(P),i}return i.round=function(t){return arguments.length?(n=!!t,i):n},i.size=function(r){return arguments.length?(t=+r[0],e=+r[1],i):[t,e]},i.padding=function(t){return arguments.length?(r=+t,i):r},i},t.stratify=function(){var t=R,e=F;function r(r){var n,i,a,o,s,u,h,f=r.length,p=new Array(f),d={};for(i=0;i<f;++i)n=r[i],s=p[i]=new c(n),null!=(u=t(n,i,r))&&(u+=\"\")&&(d[h=z+(s.id=u)]=h in d?D:s);for(i=0;i<f;++i)if(s=p[i],null!=(u=e(r[i],i,r))&&(u+=\"\")){if(!(o=d[z+u]))throw new Error(\"missing: \"+u);if(o===D)throw new Error(\"ambiguous: \"+u);o.children?o.children.push(s):o.children=[s],s.parent=o}else{if(a)throw new Error(\"multiple roots\");a=s}if(!a)throw new Error(\"no root\");if(a.parent=I,a.eachBefore(function(t){t.depth=t.parent.depth+1,--f}).eachBefore(l),a.parent=null,f>0)throw new Error(\"cycle\");return a}return r.id=function(e){return arguments.length?(t=T(e),r):t},r.parentId=function(t){return arguments.length?(e=T(t),r):e},r},t.tree=function(){var t=B,e=1,r=1,n=null;function i(i){var l=function(t){for(var e,r,n,i,a,o=new q(t,0),s=[o];e=s.pop();)if(n=e._.children)for(e.children=new Array(a=n.length),i=a-1;i>=0;--i)s.push(r=e.children[i]=new q(n[i],i)),r.parent=e;return(o.parent=new q(null,0)).children=[o],o}(i);if(l.eachAfter(a),l.parent.m=-l.z,l.eachBefore(o),n)i.eachBefore(s);else{var c=i,u=i,h=i;i.eachBefore(function(t){t.x<c.x&&(c=t),t.x>u.x&&(u=t),t.depth>h.depth&&(h=t)});var f=c===u?1:t(c,u)/2,p=f-c.x,d=e/(u.x+f+p),g=r/(h.depth||1);i.eachBefore(function(t){t.x=(t.x+p)*d,t.y=t.depth*g})}return i}function a(e){var r=e.children,n=e.parent.children,i=e.i?n[e.i-1]:null;if(r){!function(t){for(var e,r=0,n=0,i=t.children,a=i.length;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(e);var a=(r[0].z+r[r.length-1].z)/2;i?(e.z=i.z+t(e._,i._),e.m=e.z-a):e.z=a}else i&&(e.z=i.z+t(e._,i._));e.parent.A=function(e,r,n){if(r){for(var i,a=e,o=e,s=r,l=a.parent.children[0],c=a.m,u=o.m,h=s.m,f=l.m;s=j(s),a=N(a),s&&a;)l=N(l),(o=j(o)).a=e,(i=s.z+h-a.z-c+t(s._,a._))>0&&(U(V(s,e,n),e,i),c+=i,u+=i),h+=s.m,c+=a.m,f+=l.m,u+=o.m;s&&!j(o)&&(o.t=s,o.m+=h-u),a&&!N(l)&&(l.t=a,l.m+=c-f,n=e)}return n}(e,i,e.parent.A||n[0])}function o(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function s(t){t.x*=e,t.y=t.depth*r}return i.separation=function(e){return arguments.length?(t=e,i):t},i.size=function(t){return arguments.length?(n=!1,e=+t[0],r=+t[1],i):n?null:[e,r]},i.nodeSize=function(t){return arguments.length?(n=!0,e=+t[0],r=+t[1],i):n?[e,r]:null},i},t.treemap=function(){var t=W,e=!1,r=1,n=1,i=[0],a=A,o=A,s=A,l=A,c=A;function u(t){return t.x0=t.y0=0,t.x1=r,t.y1=n,t.eachBefore(h),i=[0],e&&t.eachBefore(P),t}function h(e){var r=i[e.depth],n=e.x0+r,u=e.y0+r,h=e.x1-r,f=e.y1-r;h<n&&(n=h=(n+h)/2),f<u&&(u=f=(u+f)/2),e.x0=n,e.y0=u,e.x1=h,e.y1=f,e.children&&(r=i[e.depth+1]=a(e)/2,n+=c(e)-r,u+=o(e)-r,(h-=s(e)-r)<n&&(n=h=(n+h)/2),(f-=l(e)-r)<u&&(u=f=(u+f)/2),t(e,n,u,h,f))}return u.round=function(t){return arguments.length?(e=!!t,u):e},u.size=function(t){return arguments.length?(r=+t[0],n=+t[1],u):[r,n]},u.tile=function(e){return arguments.length?(t=T(e),u):t},u.padding=function(t){return arguments.length?u.paddingInner(t).paddingOuter(t):u.paddingInner()},u.paddingInner=function(t){return arguments.length?(a=\"function\"==typeof t?t:M(+t),u):a},u.paddingOuter=function(t){return arguments.length?u.paddingTop(t).paddingRight(t).paddingBottom(t).paddingLeft(t):u.paddingTop()},u.paddingTop=function(t){return arguments.length?(o=\"function\"==typeof t?t:M(+t),u):o},u.paddingRight=function(t){return arguments.length?(s=\"function\"==typeof t?t:M(+t),u):s},u.paddingBottom=function(t){return arguments.length?(l=\"function\"==typeof t?t:M(+t),u):l},u.paddingLeft=function(t){return arguments.length?(c=\"function\"==typeof t?t:M(+t),u):c},u},t.treemapBinary=function(t,e,r,n,i){var a,o,s=t.children,l=s.length,c=new Array(l+1);for(c[0]=o=a=0;a<l;++a)c[a+1]=o+=s[a].value;!function t(e,r,n,i,a,o,l){if(e>=r-1){var u=s[e];return u.x0=i,u.y0=a,u.x1=o,void(u.y1=l)}for(var h=c[e],f=n/2+h,p=e+1,d=r-1;p<d;){var g=p+d>>>1;c[g]<f?p=g+1:d=g}f-c[p-1]<c[p]-f&&e+1<p&&--p;var v=c[p]-h,m=n-v;if(o-i>l-a){var y=(i*m+o*v)/n;t(e,p,v,i,a,y,l),t(p,r,m,y,a,o,l)}else{var x=(a*m+l*v)/n;t(e,p,v,i,a,o,x),t(p,r,m,i,x,o,l)}}(0,l,t.value,e,r,n,i)},t.treemapDice=O,t.treemapSlice=H,t.treemapSliceDice=function(t,e,r,n,i){(1&t.depth?H:O)(t,e,r,n,i)},t.treemapSquarify=W,t.treemapResquarify=X,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],158:[function(t,e,r){var n,i;n=this,i=function(t,e){\"use strict\";function r(t,e,r,n,i){var a=t*t,o=a*t;return((1-3*t+3*a-o)*e+(4-6*a+3*o)*r+(1+3*t+3*a-3*o)*n+o*i)/6}function n(t){var e=t.length-1;return function(n){var i=n<=0?n=0:n>=1?(n=1,e-1):Math.floor(n*e),a=t[i],o=t[i+1],s=i>0?t[i-1]:2*a-o,l=i<e-1?t[i+2]:2*o-a;return r((n-i/e)*e,s,a,o,l)}}function i(t){var e=t.length;return function(n){var i=Math.floor(((n%=1)<0?++n:n)*e),a=t[(i+e-1)%e],o=t[i%e],s=t[(i+1)%e],l=t[(i+2)%e];return r((n-i/e)*e,a,o,s,l)}}function a(t){return function(){return t}}function o(t,e){return function(r){return t+r*e}}function s(t,e){var r=e-t;return r?o(t,r>180||r<-180?r-360*Math.round(r/360):r):a(isNaN(t)?e:t)}function l(t){return 1==(t=+t)?c:function(e,r){return r-e?function(t,e,r){return t=Math.pow(t,r),e=Math.pow(e,r)-t,r=1/r,function(n){return Math.pow(t+n*e,r)}}(e,r,t):a(isNaN(e)?r:e)}}function c(t,e){var r=e-t;return r?o(t,r):a(isNaN(t)?e:t)}var u=function t(r){var n=l(r);function i(t,r){var i=n((t=e.rgb(t)).r,(r=e.rgb(r)).r),a=n(t.g,r.g),o=n(t.b,r.b),s=c(t.opacity,r.opacity);return function(e){return t.r=i(e),t.g=a(e),t.b=o(e),t.opacity=s(e),t+\"\"}}return i.gamma=t,i}(1);function h(t){return function(r){var n,i,a=r.length,o=new Array(a),s=new Array(a),l=new Array(a);for(n=0;n<a;++n)i=e.rgb(r[n]),o[n]=i.r||0,s[n]=i.g||0,l[n]=i.b||0;return o=t(o),s=t(s),l=t(l),i.opacity=1,function(t){return i.r=o(t),i.g=s(t),i.b=l(t),i+\"\"}}}var f=h(n),p=h(i);function d(t,e){var r,n=e?e.length:0,i=t?Math.min(n,t.length):0,a=new Array(i),o=new Array(n);for(r=0;r<i;++r)a[r]=_(t[r],e[r]);for(;r<n;++r)o[r]=e[r];return function(t){for(r=0;r<i;++r)o[r]=a[r](t);return o}}function g(t,e){var r=new Date;return e-=t=+t,function(n){return r.setTime(t+e*n),r}}function v(t,e){return e-=t=+t,function(r){return t+e*r}}function m(t,e){var r,n={},i={};for(r in null!==t&&\"object\"==typeof t||(t={}),null!==e&&\"object\"==typeof e||(e={}),e)r in t?n[r]=_(t[r],e[r]):i[r]=e[r];return function(t){for(r in n)i[r]=n[r](t);return i}}var y=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,x=new RegExp(y.source,\"g\");function b(t,e){var r,n,i,a=y.lastIndex=x.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=y.exec(t))&&(n=x.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:v(r,n)})),a=x.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?function(t){return function(e){return t(e)+\"\"}}(l[0].x):function(t){return function(){return t}}(e):(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}function _(t,r){var n,i=typeof r;return null==r||\"boolean\"===i?a(r):(\"number\"===i?v:\"string\"===i?(n=e.color(r))?(r=n,u):b:r instanceof e.color?u:r instanceof Date?g:Array.isArray(r)?d:\"function\"!=typeof r.valueOf&&\"function\"!=typeof r.toString||isNaN(r)?m:v)(t,r)}var w,k,T,A,M=180/Math.PI,S={translateX:0,translateY:0,rotate:0,skewX:0,scaleX:1,scaleY:1};function E(t,e,r,n,i,a){var o,s,l;return(o=Math.sqrt(t*t+e*e))&&(t/=o,e/=o),(l=t*r+e*n)&&(r-=t*l,n-=e*l),(s=Math.sqrt(r*r+n*n))&&(r/=s,n/=s,l/=s),t*n<e*r&&(t=-t,e=-e,l=-l,o=-o),{translateX:i,translateY:a,rotate:Math.atan2(e,t)*M,skewX:Math.atan(l)*M,scaleX:o,scaleY:s}}function C(t,e,r,n){function i(t){return t.length?t.pop()+\" \":\"\"}return function(a,o){var s=[],l=[];return a=t(a),o=t(o),function(t,n,i,a,o,s){if(t!==i||n!==a){var l=o.push(\"translate(\",null,e,null,r);s.push({i:l-4,x:v(t,i)},{i:l-2,x:v(n,a)})}else(i||a)&&o.push(\"translate(\"+i+e+a+r)}(a.translateX,a.translateY,o.translateX,o.translateY,s,l),function(t,e,r,a){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),a.push({i:r.push(i(r)+\"rotate(\",null,n)-2,x:v(t,e)})):e&&r.push(i(r)+\"rotate(\"+e+n)}(a.rotate,o.rotate,s,l),function(t,e,r,a){t!==e?a.push({i:r.push(i(r)+\"skewX(\",null,n)-2,x:v(t,e)}):e&&r.push(i(r)+\"skewX(\"+e+n)}(a.skewX,o.skewX,s,l),function(t,e,r,n,a,o){if(t!==r||e!==n){var s=a.push(i(a)+\"scale(\",null,\",\",null,\")\");o.push({i:s-4,x:v(t,r)},{i:s-2,x:v(e,n)})}else 1===r&&1===n||a.push(i(a)+\"scale(\"+r+\",\"+n+\")\")}(a.scaleX,a.scaleY,o.scaleX,o.scaleY,s,l),a=o=null,function(t){for(var e,r=-1,n=l.length;++r<n;)s[(e=l[r]).i]=e.x(t);return s.join(\"\")}}}var L=C(function(t){return\"none\"===t?S:(w||(w=document.createElement(\"DIV\"),k=document.documentElement,T=document.defaultView),w.style.transform=t,t=T.getComputedStyle(k.appendChild(w),null).getPropertyValue(\"transform\"),k.removeChild(w),E(+(t=t.slice(7,-1).split(\",\"))[0],+t[1],+t[2],+t[3],+t[4],+t[5]))},\"px, \",\"px)\",\"deg)\"),P=C(function(t){return null==t?S:(A||(A=document.createElementNS(\"http://www.w3.org/2000/svg\",\"g\")),A.setAttribute(\"transform\",t),(t=A.transform.baseVal.consolidate())?E((t=t.matrix).a,t.b,t.c,t.d,t.e,t.f):S)},\", \",\")\",\")\"),O=Math.SQRT2,z=2,I=4,D=1e-12;function R(t){return((t=Math.exp(t))+1/t)/2}function F(t){return function(r,n){var i=t((r=e.hsl(r)).h,(n=e.hsl(n)).h),a=c(r.s,n.s),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.s=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var B=F(s),N=F(c);function j(t){return function(r,n){var i=t((r=e.hcl(r)).h,(n=e.hcl(n)).h),a=c(r.c,n.c),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.c=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var U=j(s),V=j(c);function q(t){return function r(n){function i(r,i){var a=t((r=e.cubehelix(r)).h,(i=e.cubehelix(i)).h),o=c(r.s,i.s),s=c(r.l,i.l),l=c(r.opacity,i.opacity);return function(t){return r.h=a(t),r.s=o(t),r.l=s(Math.pow(t,n)),r.opacity=l(t),r+\"\"}}return n=+n,i.gamma=r,i}(1)}var H=q(s),G=q(c);t.interpolate=_,t.interpolateArray=d,t.interpolateBasis=n,t.interpolateBasisClosed=i,t.interpolateDate=g,t.interpolateDiscrete=function(t){var e=t.length;return function(r){return t[Math.max(0,Math.min(e-1,Math.floor(r*e)))]}},t.interpolateHue=function(t,e){var r=s(+t,+e);return function(t){var e=r(t);return e-360*Math.floor(e/360)}},t.interpolateNumber=v,t.interpolateObject=m,t.interpolateRound=function(t,e){return e-=t=+t,function(r){return Math.round(t+e*r)}},t.interpolateString=b,t.interpolateTransformCss=L,t.interpolateTransformSvg=P,t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,h=l-a,f=u*u+h*h;if(f<D)n=Math.log(c/o)/O,r=function(t){return[i+t*u,a+t*h,o*Math.exp(O*t*n)]};else{var p=Math.sqrt(f),d=(c*c-o*o+I*f)/(2*o*z*p),g=(c*c-o*o-I*f)/(2*c*z*p),v=Math.log(Math.sqrt(d*d+1)-d),m=Math.log(Math.sqrt(g*g+1)-g);n=(m-v)/O,r=function(t){var e,r=t*n,s=R(v),l=o/(z*p)*(s*(e=O*r+v,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(v));return[i+l*u,a+l*h,o*s/R(O*r+v)]}}return r.duration=1e3*n,r},t.interpolateRgb=u,t.interpolateRgbBasis=f,t.interpolateRgbBasisClosed=p,t.interpolateHsl=B,t.interpolateHslLong=N,t.interpolateLab=function(t,r){var n=c((t=e.lab(t)).l,(r=e.lab(r)).l),i=c(t.a,r.a),a=c(t.b,r.b),o=c(t.opacity,r.opacity);return function(e){return t.l=n(e),t.a=i(e),t.b=a(e),t.opacity=o(e),t+\"\"}},t.interpolateHcl=U,t.interpolateHclLong=V,t.interpolateCubehelix=H,t.interpolateCubehelixLong=G,t.piecewise=function(t,e){for(var r=0,n=e.length-1,i=e[0],a=new Array(n<0?0:n);r<n;)a[r]=t(i,i=e[++r]);return function(t){var e=Math.max(0,Math.min(n-1,Math.floor(t*=n)));return a[e](t-e)}},t.quantize=function(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t(n/(e-1));return r},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-color\")):i(n.d3=n.d3||{},n.d3)},{\"d3-color\":154}],159:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e=Math.PI,r=2*e,n=r-1e-6;function i(){this._x0=this._y0=this._x1=this._y1=null,this._=\"\"}function a(){return new i}i.prototype=a.prototype={constructor:i,moveTo:function(t,e){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)},closePath:function(){null!==this._x1&&(this._x1=this._x0,this._y1=this._y0,this._+=\"Z\")},lineTo:function(t,e){this._+=\"L\"+(this._x1=+t)+\",\"+(this._y1=+e)},quadraticCurveTo:function(t,e,r,n){this._+=\"Q\"+ +t+\",\"+ +e+\",\"+(this._x1=+r)+\",\"+(this._y1=+n)},bezierCurveTo:function(t,e,r,n,i,a){this._+=\"C\"+ +t+\",\"+ +e+\",\"+ +r+\",\"+ +n+\",\"+(this._x1=+i)+\",\"+(this._y1=+a)},arcTo:function(t,r,n,i,a){t=+t,r=+r,n=+n,i=+i,a=+a;var o=this._x1,s=this._y1,l=n-t,c=i-r,u=o-t,h=s-r,f=u*u+h*h;if(a<0)throw new Error(\"negative radius: \"+a);if(null===this._x1)this._+=\"M\"+(this._x1=t)+\",\"+(this._y1=r);else if(f>1e-6)if(Math.abs(h*l-c*u)>1e-6&&a){var p=n-o,d=i-s,g=l*l+c*c,v=p*p+d*d,m=Math.sqrt(g),y=Math.sqrt(f),x=a*Math.tan((e-Math.acos((g+f-v)/(2*m*y)))/2),b=x/y,_=x/m;Math.abs(b-1)>1e-6&&(this._+=\"L\"+(t+b*u)+\",\"+(r+b*h)),this._+=\"A\"+a+\",\"+a+\",0,0,\"+ +(h*p>u*d)+\",\"+(this._x1=t+_*l)+\",\"+(this._y1=r+_*c)}else this._+=\"L\"+(this._x1=t)+\",\"+(this._y1=r);else;},arc:function(t,i,a,o,s,l){t=+t,i=+i;var c=(a=+a)*Math.cos(o),u=a*Math.sin(o),h=t+c,f=i+u,p=1^l,d=l?o-s:s-o;if(a<0)throw new Error(\"negative radius: \"+a);null===this._x1?this._+=\"M\"+h+\",\"+f:(Math.abs(this._x1-h)>1e-6||Math.abs(this._y1-f)>1e-6)&&(this._+=\"L\"+h+\",\"+f),a&&(d<0&&(d=d%r+r),d>n?this._+=\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(t-c)+\",\"+(i-u)+\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(this._x1=h)+\",\"+(this._y1=f):d>1e-6&&(this._+=\"A\"+a+\",\"+a+\",0,\"+ +(d>=e)+\",\"+p+\",\"+(this._x1=t+a*Math.cos(s))+\",\"+(this._y1=i+a*Math.sin(s))))},rect:function(t,e,r,n){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)+\"h\"+ +r+\"v\"+ +n+\"h\"+-r+\"Z\"},toString:function(){return this._}},t.path=a,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],160:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e,r,n){if(isNaN(e)||isNaN(r))return t;var i,a,o,s,l,c,u,h,f,p=t._root,d={data:n},g=t._x0,v=t._y0,m=t._x1,y=t._y1;if(!p)return t._root=d,t;for(;p.length;)if((c=e>=(a=(g+m)/2))?g=a:m=a,(u=r>=(o=(v+y)/2))?v=o:y=o,i=p,!(p=p[h=u<<1|c]))return i[h]=d,t;if(s=+t._x.call(null,p.data),l=+t._y.call(null,p.data),e===s&&r===l)return d.next=p,i?i[h]=d:t._root=d,t;do{i=i?i[h]=new Array(4):t._root=new Array(4),(c=e>=(a=(g+m)/2))?g=a:m=a,(u=r>=(o=(v+y)/2))?v=o:y=o}while((h=u<<1|c)==(f=(l>=o)<<1|s>=a));return i[f]=p,i[h]=d,t}var r=function(t,e,r,n,i){this.node=t,this.x0=e,this.y0=r,this.x1=n,this.y1=i};function n(t){return t[0]}function i(t){return t[1]}function a(t,e,r){var a=new o(null==e?n:e,null==r?i:r,NaN,NaN,NaN,NaN);return null==t?a:a.addAll(t)}function o(t,e,r,n,i,a){this._x=t,this._y=e,this._x0=r,this._y0=n,this._x1=i,this._y1=a,this._root=void 0}function s(t){for(var e={data:t.data},r=e;t=t.next;)r=r.next={data:t.data};return e}var l=a.prototype=o.prototype;l.copy=function(){var t,e,r=new o(this._x,this._y,this._x0,this._y0,this._x1,this._y1),n=this._root;if(!n)return r;if(!n.length)return r._root=s(n),r;for(t=[{source:n,target:r._root=new Array(4)}];n=t.pop();)for(var i=0;i<4;++i)(e=n.source[i])&&(e.length?t.push({source:e,target:n.target[i]=new Array(4)}):n.target[i]=s(e));return r},l.add=function(t){var r=+this._x.call(null,t),n=+this._y.call(null,t);return e(this.cover(r,n),r,n,t)},l.addAll=function(t){var r,n,i,a,o=t.length,s=new Array(o),l=new Array(o),c=1/0,u=1/0,h=-1/0,f=-1/0;for(n=0;n<o;++n)isNaN(i=+this._x.call(null,r=t[n]))||isNaN(a=+this._y.call(null,r))||(s[n]=i,l[n]=a,i<c&&(c=i),i>h&&(h=i),a<u&&(u=a),a>f&&(f=a));for(h<c&&(c=this._x0,h=this._x1),f<u&&(u=this._y0,f=this._y1),this.cover(c,u).cover(h,f),n=0;n<o;++n)e(this,s[n],l[n],t[n]);return this},l.cover=function(t,e){if(isNaN(t=+t)||isNaN(e=+e))return this;var r=this._x0,n=this._y0,i=this._x1,a=this._y1;if(isNaN(r))i=(r=Math.floor(t))+1,a=(n=Math.floor(e))+1;else{if(!(r>t||t>i||n>e||e>a))return this;var o,s,l=i-r,c=this._root;switch(s=(e<(n+a)/2)<<1|t<(r+i)/2){case 0:do{(o=new Array(4))[s]=c,c=o}while(a=n+(l*=2),t>(i=r+l)||e>a);break;case 1:do{(o=new Array(4))[s]=c,c=o}while(a=n+(l*=2),(r=i-l)>t||e>a);break;case 2:do{(o=new Array(4))[s]=c,c=o}while(n=a-(l*=2),t>(i=r+l)||n>e);break;case 3:do{(o=new Array(4))[s]=c,c=o}while(n=a-(l*=2),(r=i-l)>t||n>e)}this._root&&this._root.length&&(this._root=c)}return this._x0=r,this._y0=n,this._x1=i,this._y1=a,this},l.data=function(){var t=[];return this.visit(function(e){if(!e.length)do{t.push(e.data)}while(e=e.next)}),t},l.extent=function(t){return arguments.length?this.cover(+t[0][0],+t[0][1]).cover(+t[1][0],+t[1][1]):isNaN(this._x0)?void 0:[[this._x0,this._y0],[this._x1,this._y1]]},l.find=function(t,e,n){var i,a,o,s,l,c,u,h=this._x0,f=this._y0,p=this._x1,d=this._y1,g=[],v=this._root;for(v&&g.push(new r(v,h,f,p,d)),null==n?n=1/0:(h=t-n,f=e-n,p=t+n,d=e+n,n*=n);c=g.pop();)if(!(!(v=c.node)||(a=c.x0)>p||(o=c.y0)>d||(s=c.x1)<h||(l=c.y1)<f))if(v.length){var m=(a+s)/2,y=(o+l)/2;g.push(new r(v[3],m,y,s,l),new r(v[2],a,y,m,l),new r(v[1],m,o,s,y),new r(v[0],a,o,m,y)),(u=(e>=y)<<1|t>=m)&&(c=g[g.length-1],g[g.length-1]=g[g.length-1-u],g[g.length-1-u]=c)}else{var x=t-+this._x.call(null,v.data),b=e-+this._y.call(null,v.data),_=x*x+b*b;if(_<n){var w=Math.sqrt(n=_);h=t-w,f=e-w,p=t+w,d=e+w,i=v.data}}return i},l.remove=function(t){if(isNaN(a=+this._x.call(null,t))||isNaN(o=+this._y.call(null,t)))return this;var e,r,n,i,a,o,s,l,c,u,h,f,p=this._root,d=this._x0,g=this._y0,v=this._x1,m=this._y1;if(!p)return this;if(p.length)for(;;){if((c=a>=(s=(d+v)/2))?d=s:v=s,(u=o>=(l=(g+m)/2))?g=l:m=l,e=p,!(p=p[h=u<<1|c]))return this;if(!p.length)break;(e[h+1&3]||e[h+2&3]||e[h+3&3])&&(r=e,f=h)}for(;p.data!==t;)if(n=p,!(p=p.next))return this;return(i=p.next)&&delete p.next,n?(i?n.next=i:delete n.next,this):e?(i?e[h]=i:delete e[h],(p=e[0]||e[1]||e[2]||e[3])&&p===(e[3]||e[2]||e[1]||e[0])&&!p.length&&(r?r[f]=p:this._root=p),this):(this._root=i,this)},l.removeAll=function(t){for(var e=0,r=t.length;e<r;++e)this.remove(t[e]);return this},l.root=function(){return this._root},l.size=function(){var t=0;return this.visit(function(e){if(!e.length)do{++t}while(e=e.next)}),t},l.visit=function(t){var e,n,i,a,o,s,l=[],c=this._root;for(c&&l.push(new r(c,this._x0,this._y0,this._x1,this._y1));e=l.pop();)if(!t(c=e.node,i=e.x0,a=e.y0,o=e.x1,s=e.y1)&&c.length){var u=(i+o)/2,h=(a+s)/2;(n=c[3])&&l.push(new r(n,u,h,o,s)),(n=c[2])&&l.push(new r(n,i,h,u,s)),(n=c[1])&&l.push(new r(n,u,a,o,h)),(n=c[0])&&l.push(new r(n,i,a,u,h))}return this},l.visitAfter=function(t){var e,n=[],i=[];for(this._root&&n.push(new r(this._root,this._x0,this._y0,this._x1,this._y1));e=n.pop();){var a=e.node;if(a.length){var o,s=e.x0,l=e.y0,c=e.x1,u=e.y1,h=(s+c)/2,f=(l+u)/2;(o=a[0])&&n.push(new r(o,s,l,h,f)),(o=a[1])&&n.push(new r(o,h,l,c,f)),(o=a[2])&&n.push(new r(o,s,f,h,u)),(o=a[3])&&n.push(new r(o,h,f,c,u))}i.push(e)}for(;e=i.pop();)t(e.node,e.x0,e.y0,e.x1,e.y1);return this},l.x=function(t){return arguments.length?(this._x=t,this):this._x},l.y=function(t){return arguments.length?(this._y=t,this):this._y},t.quadtree=a,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],161:[function(t,e,r){var n,i;n=this,i=function(t,e){\"use strict\";function r(t){return function(){return t}}var n=Math.abs,i=Math.atan2,a=Math.cos,o=Math.max,s=Math.min,l=Math.sin,c=Math.sqrt,u=1e-12,h=Math.PI,f=h/2,p=2*h;function d(t){return t>=1?f:t<=-1?-f:Math.asin(t)}function g(t){return t.innerRadius}function v(t){return t.outerRadius}function m(t){return t.startAngle}function y(t){return t.endAngle}function x(t){return t&&t.padAngle}function b(t,e,r,n,i,a,s){var l=t-r,u=e-n,h=(s?a:-a)/c(l*l+u*u),f=h*u,p=-h*l,d=t+f,g=e+p,v=r+f,m=n+p,y=(d+v)/2,x=(g+m)/2,b=v-d,_=m-g,w=b*b+_*_,k=i-a,T=d*m-v*g,A=(_<0?-1:1)*c(o(0,k*k*w-T*T)),M=(T*_-b*A)/w,S=(-T*b-_*A)/w,E=(T*_+b*A)/w,C=(-T*b+_*A)/w,L=M-y,P=S-x,O=E-y,z=C-x;return L*L+P*P>O*O+z*z&&(M=E,S=C),{cx:M,cy:S,x01:-f,y01:-p,x11:M*(i/k-1),y11:S*(i/k-1)}}function _(t){this._context=t}function w(t){return new _(t)}function k(t){return t[0]}function T(t){return t[1]}function A(){var t=k,n=T,i=r(!0),a=null,o=w,s=null;function l(r){var l,c,u,h=r.length,f=!1;for(null==a&&(s=o(u=e.path())),l=0;l<=h;++l)!(l<h&&i(c=r[l],l,r))===f&&((f=!f)?s.lineStart():s.lineEnd()),f&&s.point(+t(c,l,r),+n(c,l,r));if(u)return s=null,u+\"\"||null}return l.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),l):t},l.y=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),l):n},l.defined=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(!!t),l):i},l.curve=function(t){return arguments.length?(o=t,null!=a&&(s=o(a)),l):o},l.context=function(t){return arguments.length?(null==t?a=s=null:s=o(a=t),l):a},l}function M(){var t=k,n=null,i=r(0),a=T,o=r(!0),s=null,l=w,c=null;function u(r){var u,h,f,p,d,g=r.length,v=!1,m=new Array(g),y=new Array(g);for(null==s&&(c=l(d=e.path())),u=0;u<=g;++u){if(!(u<g&&o(p=r[u],u,r))===v)if(v=!v)h=u,c.areaStart(),c.lineStart();else{for(c.lineEnd(),c.lineStart(),f=u-1;f>=h;--f)c.point(m[f],y[f]);c.lineEnd(),c.areaEnd()}v&&(m[u]=+t(p,u,r),y[u]=+i(p,u,r),c.point(n?+n(p,u,r):m[u],a?+a(p,u,r):y[u]))}if(d)return c=null,d+\"\"||null}function h(){return A().defined(o).curve(l).context(s)}return u.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),n=null,u):t},u.x0=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),u):t},u.x1=function(t){return arguments.length?(n=null==t?null:\"function\"==typeof t?t:r(+t),u):n},u.y=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a=null,u):i},u.y0=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),u):i},u.y1=function(t){return arguments.length?(a=null==t?null:\"function\"==typeof t?t:r(+t),u):a},u.lineX0=u.lineY0=function(){return h().x(t).y(i)},u.lineY1=function(){return h().x(t).y(a)},u.lineX1=function(){return h().x(n).y(i)},u.defined=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(!!t),u):o},u.curve=function(t){return arguments.length?(l=t,null!=s&&(c=l(s)),u):l},u.context=function(t){return arguments.length?(null==t?s=c=null:c=l(s=t),u):s},u}function S(t,e){return e<t?-1:e>t?1:e>=t?0:NaN}function E(t){return t}_.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._point=0},lineEnd:function(){(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:this._context.lineTo(t,e)}}};var C=P(w);function L(t){this._curve=t}function P(t){function e(e){return new L(t(e))}return e._curve=t,e}function O(t){var e=t.curve;return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function z(){return O(A().curve(C))}function I(){var t=M().curve(C),e=t.curve,r=t.lineX0,n=t.lineX1,i=t.lineY0,a=t.lineY1;return t.angle=t.x,delete t.x,t.startAngle=t.x0,delete t.x0,t.endAngle=t.x1,delete t.x1,t.radius=t.y,delete t.y,t.innerRadius=t.y0,delete t.y0,t.outerRadius=t.y1,delete t.y1,t.lineStartAngle=function(){return O(r())},delete t.lineX0,t.lineEndAngle=function(){return O(n())},delete t.lineX1,t.lineInnerRadius=function(){return O(i())},delete t.lineY0,t.lineOuterRadius=function(){return O(a())},delete t.lineY1,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function D(t,e){return[(e=+e)*Math.cos(t-=Math.PI/2),e*Math.sin(t)]}L.prototype={areaStart:function(){this._curve.areaStart()},areaEnd:function(){this._curve.areaEnd()},lineStart:function(){this._curve.lineStart()},lineEnd:function(){this._curve.lineEnd()},point:function(t,e){this._curve.point(e*Math.sin(t),e*-Math.cos(t))}};var R=Array.prototype.slice;function F(t){return t.source}function B(t){return t.target}function N(t){var n=F,i=B,a=k,o=T,s=null;function l(){var r,l=R.call(arguments),c=n.apply(this,l),u=i.apply(this,l);if(s||(s=r=e.path()),t(s,+a.apply(this,(l[0]=c,l)),+o.apply(this,l),+a.apply(this,(l[0]=u,l)),+o.apply(this,l)),r)return s=null,r+\"\"||null}return l.source=function(t){return arguments.length?(n=t,l):n},l.target=function(t){return arguments.length?(i=t,l):i},l.x=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),l):a},l.y=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),l):o},l.context=function(t){return arguments.length?(s=null==t?null:t,l):s},l}function j(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e=(e+n)/2,r,e,i,n,i)}function U(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e,r=(r+i)/2,n,r,n,i)}function V(t,e,r,n,i){var a=D(e,r),o=D(e,r=(r+i)/2),s=D(n,r),l=D(n,i);t.moveTo(a[0],a[1]),t.bezierCurveTo(o[0],o[1],s[0],s[1],l[0],l[1])}var q={draw:function(t,e){var r=Math.sqrt(e/h);t.moveTo(r,0),t.arc(0,0,r,0,p)}},H={draw:function(t,e){var r=Math.sqrt(e/5)/2;t.moveTo(-3*r,-r),t.lineTo(-r,-r),t.lineTo(-r,-3*r),t.lineTo(r,-3*r),t.lineTo(r,-r),t.lineTo(3*r,-r),t.lineTo(3*r,r),t.lineTo(r,r),t.lineTo(r,3*r),t.lineTo(-r,3*r),t.lineTo(-r,r),t.lineTo(-3*r,r),t.closePath()}},G=Math.sqrt(1/3),Y=2*G,W={draw:function(t,e){var r=Math.sqrt(e/Y),n=r*G;t.moveTo(0,-r),t.lineTo(n,0),t.lineTo(0,r),t.lineTo(-n,0),t.closePath()}},X=Math.sin(h/10)/Math.sin(7*h/10),Z=Math.sin(p/10)*X,J=-Math.cos(p/10)*X,K={draw:function(t,e){var r=Math.sqrt(.8908130915292852*e),n=Z*r,i=J*r;t.moveTo(0,-r),t.lineTo(n,i);for(var a=1;a<5;++a){var o=p*a/5,s=Math.cos(o),l=Math.sin(o);t.lineTo(l*r,-s*r),t.lineTo(s*n-l*i,l*n+s*i)}t.closePath()}},$={draw:function(t,e){var r=Math.sqrt(e),n=-r/2;t.rect(n,n,r,r)}},Q=Math.sqrt(3),tt={draw:function(t,e){var r=-Math.sqrt(e/(3*Q));t.moveTo(0,2*r),t.lineTo(-Q*r,-r),t.lineTo(Q*r,-r),t.closePath()}},et=-.5,rt=Math.sqrt(3)/2,nt=1/Math.sqrt(12),it=3*(nt/2+1),at={draw:function(t,e){var r=Math.sqrt(e/it),n=r/2,i=r*nt,a=n,o=r*nt+r,s=-a,l=o;t.moveTo(n,i),t.lineTo(a,o),t.lineTo(s,l),t.lineTo(et*n-rt*i,rt*n+et*i),t.lineTo(et*a-rt*o,rt*a+et*o),t.lineTo(et*s-rt*l,rt*s+et*l),t.lineTo(et*n+rt*i,et*i-rt*n),t.lineTo(et*a+rt*o,et*o-rt*a),t.lineTo(et*s+rt*l,et*l-rt*s),t.closePath()}},ot=[q,H,W,$,K,tt,at];function st(){}function lt(t,e,r){t._context.bezierCurveTo((2*t._x0+t._x1)/3,(2*t._y0+t._y1)/3,(t._x0+2*t._x1)/3,(t._y0+2*t._y1)/3,(t._x0+4*t._x1+e)/6,(t._y0+4*t._y1+r)/6)}function ct(t){this._context=t}function ut(t){this._context=t}function ht(t){this._context=t}function ft(t,e){this._basis=new ct(t),this._beta=e}ct.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){switch(this._point){case 3:lt(this,this._x1,this._y1);case 2:this._context.lineTo(this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,this._context.lineTo((5*this._x0+this._x1)/6,(5*this._y0+this._y1)/6);default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ut.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._y0=this._y1=this._y2=this._y3=this._y4=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x2,this._y2),this._context.closePath();break;case 2:this._context.moveTo((this._x2+2*this._x3)/3,(this._y2+2*this._y3)/3),this._context.lineTo((this._x3+2*this._x2)/3,(this._y3+2*this._y2)/3),this._context.closePath();break;case 3:this.point(this._x2,this._y2),this.point(this._x3,this._y3),this.point(this._x4,this._y4)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x2=t,this._y2=e;break;case 1:this._point=2,this._x3=t,this._y3=e;break;case 2:this._point=3,this._x4=t,this._y4=e,this._context.moveTo((this._x0+4*this._x1+t)/6,(this._y0+4*this._y1+e)/6);break;default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ht.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3;var r=(this._x0+4*this._x1+t)/6,n=(this._y0+4*this._y1+e)/6;this._line?this._context.lineTo(r,n):this._context.moveTo(r,n);break;case 3:this._point=4;default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ft.prototype={lineStart:function(){this._x=[],this._y=[],this._basis.lineStart()},lineEnd:function(){var t=this._x,e=this._y,r=t.length-1;if(r>0)for(var n,i=t[0],a=e[0],o=t[r]-i,s=e[r]-a,l=-1;++l<=r;)n=l/r,this._basis.point(this._beta*t[l]+(1-this._beta)*(i+n*o),this._beta*e[l]+(1-this._beta)*(a+n*s));this._x=this._y=null,this._basis.lineEnd()},point:function(t,e){this._x.push(+t),this._y.push(+e)}};var pt=function t(e){function r(t){return 1===e?new ct(t):new ft(t,e)}return r.beta=function(e){return t(+e)},r}(.85);function dt(t,e,r){t._context.bezierCurveTo(t._x1+t._k*(t._x2-t._x0),t._y1+t._k*(t._y2-t._y0),t._x2+t._k*(t._x1-e),t._y2+t._k*(t._y1-r),t._x2,t._y2)}function gt(t,e){this._context=t,this._k=(1-e)/6}gt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:dt(this,this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2,this._x1=t,this._y1=e;break;case 2:this._point=3;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var vt=function t(e){function r(t){return new gt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function mt(t,e){this._context=t,this._k=(1-e)/6}mt.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var yt=function t(e){function r(t){return new mt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function xt(t,e){this._context=t,this._k=(1-e)/6}xt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var bt=function t(e){function r(t){return new xt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function _t(t,e,r){var n=t._x1,i=t._y1,a=t._x2,o=t._y2;if(t._l01_a>u){var s=2*t._l01_2a+3*t._l01_a*t._l12_a+t._l12_2a,l=3*t._l01_a*(t._l01_a+t._l12_a);n=(n*s-t._x0*t._l12_2a+t._x2*t._l01_2a)/l,i=(i*s-t._y0*t._l12_2a+t._y2*t._l01_2a)/l}if(t._l23_a>u){var c=2*t._l23_2a+3*t._l23_a*t._l12_a+t._l12_2a,h=3*t._l23_a*(t._l23_a+t._l12_a);a=(a*c+t._x1*t._l23_2a-e*t._l12_2a)/h,o=(o*c+t._y1*t._l23_2a-r*t._l12_2a)/h}t._context.bezierCurveTo(n,i,a,o,t._x2,t._y2)}function wt(t,e){this._context=t,this._alpha=e}wt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:this.point(this._x2,this._y2)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var kt=function t(e){function r(t){return e?new wt(t,e):new gt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Tt(t,e){this._context=t,this._alpha=e}Tt.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var At=function t(e){function r(t){return e?new Tt(t,e):new mt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Mt(t,e){this._context=t,this._alpha=e}Mt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var St=function t(e){function r(t){return e?new Mt(t,e):new xt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Et(t){this._context=t}function Ct(t){return t<0?-1:1}function Lt(t,e,r){var n=t._x1-t._x0,i=e-t._x1,a=(t._y1-t._y0)/(n||i<0&&-0),o=(r-t._y1)/(i||n<0&&-0),s=(a*i+o*n)/(n+i);return(Ct(a)+Ct(o))*Math.min(Math.abs(a),Math.abs(o),.5*Math.abs(s))||0}function Pt(t,e){var r=t._x1-t._x0;return r?(3*(t._y1-t._y0)/r-e)/2:e}function Ot(t,e,r){var n=t._x0,i=t._y0,a=t._x1,o=t._y1,s=(a-n)/3;t._context.bezierCurveTo(n+s,i+s*e,a-s,o-s*r,a,o)}function zt(t){this._context=t}function It(t){this._context=new Dt(t)}function Dt(t){this._context=t}function Rt(t){this._context=t}function Ft(t){var e,r,n=t.length-1,i=new Array(n),a=new Array(n),o=new Array(n);for(i[0]=0,a[0]=2,o[0]=t[0]+2*t[1],e=1;e<n-1;++e)i[e]=1,a[e]=4,o[e]=4*t[e]+2*t[e+1];for(i[n-1]=2,a[n-1]=7,o[n-1]=8*t[n-1]+t[n],e=1;e<n;++e)r=i[e]/a[e-1],a[e]-=r,o[e]-=r*o[e-1];for(i[n-1]=o[n-1]/a[n-1],e=n-2;e>=0;--e)i[e]=(o[e]-i[e+1])/a[e];for(a[n-1]=(t[n]+i[n-1])/2,e=0;e<n-1;++e)a[e]=2*t[e+1]-i[e+1];return[i,a]}function Bt(t,e){this._context=t,this._t=e}function Nt(t,e){if((i=t.length)>1)for(var r,n,i,a=1,o=t[e[0]],s=o.length;a<i;++a)for(n=o,o=t[e[a]],r=0;r<s;++r)o[r][1]+=o[r][0]=isNaN(n[r][1])?n[r][0]:n[r][1]}function jt(t){for(var e=t.length,r=new Array(e);--e>=0;)r[e]=e;return r}function Ut(t,e){return t[e]}function Vt(t){var e=t.map(qt);return jt(t).sort(function(t,r){return e[t]-e[r]})}function qt(t){for(var e,r=-1,n=0,i=t.length,a=-1/0;++r<i;)(e=+t[r][1])>a&&(a=e,n=r);return n}function Ht(t){var e=t.map(Gt);return jt(t).sort(function(t,r){return e[t]-e[r]})}function Gt(t){for(var e,r=0,n=-1,i=t.length;++n<i;)(e=+t[n][1])&&(r+=e);return r}Et.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._point=0},lineEnd:function(){this._point&&this._context.closePath()},point:function(t,e){t=+t,e=+e,this._point?this._context.lineTo(t,e):(this._point=1,this._context.moveTo(t,e))}},zt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=this._t0=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x1,this._y1);break;case 3:Ot(this,this._t0,Pt(this,this._t0))}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){var r=NaN;if(e=+e,(t=+t)!==this._x1||e!==this._y1){switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,Ot(this,Pt(this,r=Lt(this,t,e)),r);break;default:Ot(this,this._t0,r=Lt(this,t,e))}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e,this._t0=r}}},(It.prototype=Object.create(zt.prototype)).point=function(t,e){zt.prototype.point.call(this,e,t)},Dt.prototype={moveTo:function(t,e){this._context.moveTo(e,t)},closePath:function(){this._context.closePath()},lineTo:function(t,e){this._context.lineTo(e,t)},bezierCurveTo:function(t,e,r,n,i,a){this._context.bezierCurveTo(e,t,n,r,a,i)}},Rt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=[],this._y=[]},lineEnd:function(){var t=this._x,e=this._y,r=t.length;if(r)if(this._line?this._context.lineTo(t[0],e[0]):this._context.moveTo(t[0],e[0]),2===r)this._context.lineTo(t[1],e[1]);else for(var n=Ft(t),i=Ft(e),a=0,o=1;o<r;++a,++o)this._context.bezierCurveTo(n[0][a],i[0][a],n[1][a],i[1][a],t[o],e[o]);(this._line||0!==this._line&&1===r)&&this._context.closePath(),this._line=1-this._line,this._x=this._y=null},point:function(t,e){this._x.push(+t),this._y.push(+e)}},Bt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=this._y=NaN,this._point=0},lineEnd:function(){0<this._t&&this._t<1&&2===this._point&&this._context.lineTo(this._x,this._y),(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line>=0&&(this._t=1-this._t,this._line=1-this._line)},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:if(this._t<=0)this._context.lineTo(this._x,e),this._context.lineTo(t,e);else{var r=this._x*(1-this._t)+t*this._t;this._context.lineTo(r,this._y),this._context.lineTo(r,e)}}this._x=t,this._y=e}},t.arc=function(){var t=g,o=v,_=r(0),w=null,k=m,T=y,A=x,M=null;function S(){var r,g,v,m=+t.apply(this,arguments),y=+o.apply(this,arguments),x=k.apply(this,arguments)-f,S=T.apply(this,arguments)-f,E=n(S-x),C=S>x;if(M||(M=r=e.path()),y<m&&(g=y,y=m,m=g),y>u)if(E>p-u)M.moveTo(y*a(x),y*l(x)),M.arc(0,0,y,x,S,!C),m>u&&(M.moveTo(m*a(S),m*l(S)),M.arc(0,0,m,S,x,C));else{var L,P,O=x,z=S,I=x,D=S,R=E,F=E,B=A.apply(this,arguments)/2,N=B>u&&(w?+w.apply(this,arguments):c(m*m+y*y)),j=s(n(y-m)/2,+_.apply(this,arguments)),U=j,V=j;if(N>u){var q=d(N/m*l(B)),H=d(N/y*l(B));(R-=2*q)>u?(I+=q*=C?1:-1,D-=q):(R=0,I=D=(x+S)/2),(F-=2*H)>u?(O+=H*=C?1:-1,z-=H):(F=0,O=z=(x+S)/2)}var G=y*a(O),Y=y*l(O),W=m*a(D),X=m*l(D);if(j>u){var Z,J=y*a(z),K=y*l(z),$=m*a(I),Q=m*l(I);if(E<h&&(Z=function(t,e,r,n,i,a,o,s){var l=r-t,c=n-e,h=o-i,f=s-a,p=f*l-h*c;if(!(p*p<u))return[t+(p=(h*(e-a)-f*(t-i))/p)*l,e+p*c]}(G,Y,$,Q,J,K,W,X))){var tt=G-Z[0],et=Y-Z[1],rt=J-Z[0],nt=K-Z[1],it=1/l(((v=(tt*rt+et*nt)/(c(tt*tt+et*et)*c(rt*rt+nt*nt)))>1?0:v<-1?h:Math.acos(v))/2),at=c(Z[0]*Z[0]+Z[1]*Z[1]);U=s(j,(m-at)/(it-1)),V=s(j,(y-at)/(it+1))}}F>u?V>u?(L=b($,Q,G,Y,y,V,C),P=b(J,K,W,X,y,V,C),M.moveTo(L.cx+L.x01,L.cy+L.y01),V<j?M.arc(L.cx,L.cy,V,i(L.y01,L.x01),i(P.y01,P.x01),!C):(M.arc(L.cx,L.cy,V,i(L.y01,L.x01),i(L.y11,L.x11),!C),M.arc(0,0,y,i(L.cy+L.y11,L.cx+L.x11),i(P.cy+P.y11,P.cx+P.x11),!C),M.arc(P.cx,P.cy,V,i(P.y11,P.x11),i(P.y01,P.x01),!C))):(M.moveTo(G,Y),M.arc(0,0,y,O,z,!C)):M.moveTo(G,Y),m>u&&R>u?U>u?(L=b(W,X,J,K,m,-U,C),P=b(G,Y,$,Q,m,-U,C),M.lineTo(L.cx+L.x01,L.cy+L.y01),U<j?M.arc(L.cx,L.cy,U,i(L.y01,L.x01),i(P.y01,P.x01),!C):(M.arc(L.cx,L.cy,U,i(L.y01,L.x01),i(L.y11,L.x11),!C),M.arc(0,0,m,i(L.cy+L.y11,L.cx+L.x11),i(P.cy+P.y11,P.cx+P.x11),C),M.arc(P.cx,P.cy,U,i(P.y11,P.x11),i(P.y01,P.x01),!C))):M.arc(0,0,m,D,I,C):M.lineTo(W,X)}else M.moveTo(0,0);if(M.closePath(),r)return M=null,r+\"\"||null}return S.centroid=function(){var e=(+t.apply(this,arguments)+ +o.apply(this,arguments))/2,r=(+k.apply(this,arguments)+ +T.apply(this,arguments))/2-h/2;return[a(r)*e,l(r)*e]},S.innerRadius=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),S):t},S.outerRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),S):o},S.cornerRadius=function(t){return arguments.length?(_=\"function\"==typeof t?t:r(+t),S):_},S.padRadius=function(t){return arguments.length?(w=null==t?null:\"function\"==typeof t?t:r(+t),S):w},S.startAngle=function(t){return arguments.length?(k=\"function\"==typeof t?t:r(+t),S):k},S.endAngle=function(t){return arguments.length?(T=\"function\"==typeof t?t:r(+t),S):T},S.padAngle=function(t){return arguments.length?(A=\"function\"==typeof t?t:r(+t),S):A},S.context=function(t){return arguments.length?(M=null==t?null:t,S):M},S},t.area=M,t.line=A,t.pie=function(){var t=E,e=S,n=null,i=r(0),a=r(p),o=r(0);function s(r){var s,l,c,u,h,f=r.length,d=0,g=new Array(f),v=new Array(f),m=+i.apply(this,arguments),y=Math.min(p,Math.max(-p,a.apply(this,arguments)-m)),x=Math.min(Math.abs(y)/f,o.apply(this,arguments)),b=x*(y<0?-1:1);for(s=0;s<f;++s)(h=v[g[s]=s]=+t(r[s],s,r))>0&&(d+=h);for(null!=e?g.sort(function(t,r){return e(v[t],v[r])}):null!=n&&g.sort(function(t,e){return n(r[t],r[e])}),s=0,c=d?(y-f*b)/d:0;s<f;++s,m=u)l=g[s],u=m+((h=v[l])>0?h*c:0)+b,v[l]={data:r[l],index:s,value:h,startAngle:m,endAngle:u,padAngle:x};return v}return s.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),s):t},s.sortValues=function(t){return arguments.length?(e=t,n=null,s):e},s.sort=function(t){return arguments.length?(n=t,e=null,s):n},s.startAngle=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),s):i},s.endAngle=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),s):a},s.padAngle=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),s):o},s},t.areaRadial=I,t.radialArea=I,t.lineRadial=z,t.radialLine=z,t.pointRadial=D,t.linkHorizontal=function(){return N(j)},t.linkVertical=function(){return N(U)},t.linkRadial=function(){var t=N(V);return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t},t.symbol=function(){var t=r(q),n=r(64),i=null;function a(){var r;if(i||(i=r=e.path()),t.apply(this,arguments).draw(i,+n.apply(this,arguments)),r)return i=null,r+\"\"||null}return a.type=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(e),a):t},a.size=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),a):n},a.context=function(t){return arguments.length?(i=null==t?null:t,a):i},a},t.symbols=ot,t.symbolCircle=q,t.symbolCross=H,t.symbolDiamond=W,t.symbolSquare=$,t.symbolStar=K,t.symbolTriangle=tt,t.symbolWye=at,t.curveBasisClosed=function(t){return new ut(t)},t.curveBasisOpen=function(t){return new ht(t)},t.curveBasis=function(t){return new ct(t)},t.curveBundle=pt,t.curveCardinalClosed=yt,t.curveCardinalOpen=bt,t.curveCardinal=vt,t.curveCatmullRomClosed=At,t.curveCatmullRomOpen=St,t.curveCatmullRom=kt,t.curveLinearClosed=function(t){return new Et(t)},t.curveLinear=w,t.curveMonotoneX=function(t){return new zt(t)},t.curveMonotoneY=function(t){return new It(t)},t.curveNatural=function(t){return new Rt(t)},t.curveStep=function(t){return new Bt(t,.5)},t.curveStepAfter=function(t){return new Bt(t,1)},t.curveStepBefore=function(t){return new Bt(t,0)},t.stack=function(){var t=r([]),e=jt,n=Nt,i=Ut;function a(r){var a,o,s=t.apply(this,arguments),l=r.length,c=s.length,u=new Array(c);for(a=0;a<c;++a){for(var h,f=s[a],p=u[a]=new Array(l),d=0;d<l;++d)p[d]=h=[0,+i(r[d],f,d,r)],h.data=r[d];p.key=f}for(a=0,o=e(u);a<c;++a)u[o[a]].index=a;return n(u,o),u}return a.keys=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(R.call(e)),a):t},a.value=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a):i},a.order=function(t){return arguments.length?(e=null==t?jt:\"function\"==typeof t?t:r(R.call(t)),a):e},a.offset=function(t){return arguments.length?(n=null==t?Nt:t,a):n},a},t.stackOffsetExpand=function(t,e){if((n=t.length)>0){for(var r,n,i,a=0,o=t[0].length;a<o;++a){for(i=r=0;r<n;++r)i+=t[r][a][1]||0;if(i)for(r=0;r<n;++r)t[r][a][1]/=i}Nt(t,e)}},t.stackOffsetDiverging=function(t,e){if((s=t.length)>1)for(var r,n,i,a,o,s,l=0,c=t[e[0]].length;l<c;++l)for(a=o=0,r=0;r<s;++r)(i=(n=t[e[r]][l])[1]-n[0])>=0?(n[0]=a,n[1]=a+=i):i<0?(n[1]=o,n[0]=o+=i):n[0]=a},t.stackOffsetNone=Nt,t.stackOffsetSilhouette=function(t,e){if((r=t.length)>0){for(var r,n=0,i=t[e[0]],a=i.length;n<a;++n){for(var o=0,s=0;o<r;++o)s+=t[o][n][1]||0;i[n][1]+=i[n][0]=-s/2}Nt(t,e)}},t.stackOffsetWiggle=function(t,e){if((i=t.length)>0&&(n=(r=t[e[0]]).length)>0){for(var r,n,i,a=0,o=1;o<n;++o){for(var s=0,l=0,c=0;s<i;++s){for(var u=t[e[s]],h=u[o][1]||0,f=(h-(u[o-1][1]||0))/2,p=0;p<s;++p){var d=t[e[p]];f+=(d[o][1]||0)-(d[o-1][1]||0)}l+=h,c+=f*h}r[o-1][1]+=r[o-1][0]=a,l&&(a-=c/l)}r[o-1][1]+=r[o-1][0]=a,Nt(t,e)}},t.stackOrderAppearance=Vt,t.stackOrderAscending=Ht,t.stackOrderDescending=function(t){return Ht(t).reverse()},t.stackOrderInsideOut=function(t){var e,r,n=t.length,i=t.map(Gt),a=Vt(t),o=0,s=0,l=[],c=[];for(e=0;e<n;++e)r=a[e],o<s?(o+=i[r],l.push(r)):(s+=i[r],c.push(r));return c.reverse().concat(l)},t.stackOrderNone=jt,t.stackOrderReverse=function(t){return jt(t).reverse()},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-path\")):i(n.d3=n.d3||{},n.d3)},{\"d3-path\":159}],162:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e,r,n=0,i=0,a=0,o=1e3,s=0,l=0,c=0,u=\"object\"==typeof performance&&performance.now?performance:Date,h=\"object\"==typeof window&&window.requestAnimationFrame?window.requestAnimationFrame.bind(window):function(t){setTimeout(t,17)};function f(){return l||(h(p),l=u.now()+c)}function p(){l=0}function d(){this._call=this._time=this._next=null}function g(t,e,r){var n=new d;return n.restart(t,e,r),n}function v(){f(),++n;for(var t,r=e;r;)(t=l-r._time)>=0&&r._call.call(null,t),r=r._next;--n}function m(){l=(s=u.now())+c,n=i=0;try{v()}finally{n=0,function(){var t,n,i=e,a=1/0;for(;i;)i._call?(a>i._time&&(a=i._time),t=i,i=i._next):(n=i._next,i._next=null,i=t?t._next=n:e=n);r=t,x(a)}(),l=0}}function y(){var t=u.now(),e=t-s;e>o&&(c-=e,s=t)}function x(t){n||(i&&(i=clearTimeout(i)),t-l>24?(t<1/0&&(i=setTimeout(m,t-u.now()-c)),a&&(a=clearInterval(a))):(a||(s=u.now(),a=setInterval(y,o)),n=1,h(m)))}d.prototype=g.prototype={constructor:d,restart:function(t,n,i){if(\"function\"!=typeof t)throw new TypeError(\"callback is not a function\");i=(null==i?f():+i)+(null==n?0:+n),this._next||r===this||(r?r._next=this:e=this,r=this),this._call=t,this._time=i,x()},stop:function(){this._call&&(this._call=null,this._time=1/0,x())}};t.now=f,t.timer=g,t.timerFlush=v,t.timeout=function(t,e,r){var n=new d;return e=null==e?0:+e,n.restart(function(r){n.stop(),t(r+e)},e,r),n},t.interval=function(t,e,r){var n=new d,i=e;return null==e?(n.restart(t,e,r),n):(e=+e,r=null==r?f():+r,n.restart(function a(o){o+=i,n.restart(a,i+=e,r),t(o)},e,r),n)},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],163:[function(t,e,r){!function(){var t={version:\"3.5.17\"},r=[].slice,n=function(t){return r.call(t)},i=this.document;function a(t){return t&&(t.ownerDocument||t.document||t).documentElement}function o(t){return t&&(t.ownerDocument&&t.ownerDocument.defaultView||t.document&&t||t.defaultView)}if(i)try{n(i.documentElement.childNodes)[0].nodeType}catch(t){n=function(t){for(var e=t.length,r=new Array(e);e--;)r[e]=t[e];return r}}if(Date.now||(Date.now=function(){return+new Date}),i)try{i.createElement(\"DIV\").style.setProperty(\"opacity\",0,\"\")}catch(t){var s=this.Element.prototype,l=s.setAttribute,c=s.setAttributeNS,u=this.CSSStyleDeclaration.prototype,h=u.setProperty;s.setAttribute=function(t,e){l.call(this,t,e+\"\")},s.setAttributeNS=function(t,e,r){c.call(this,t,e,r+\"\")},u.setProperty=function(t,e,r){h.call(this,t,e+\"\",r)}}function f(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function p(t){return null===t?NaN:+t}function d(t){return!isNaN(t)}function g(t){return{left:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}t.ascending=f,t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.min=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&r>n&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&r>n&&(r=n)}return r},t.max=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&n>r&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&n>r&&(r=n)}return r},t.extent=function(t,e){var r,n,i,a=-1,o=t.length;if(1===arguments.length){for(;++a<o;)if(null!=(n=t[a])&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=t[a])&&(r>n&&(r=n),i<n&&(i=n))}else{for(;++a<o;)if(null!=(n=e.call(t,t[a],a))&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=e.call(t,t[a],a))&&(r>n&&(r=n),i<n&&(i=n))}return[r,i]},t.sum=function(t,e){var r,n=0,i=t.length,a=-1;if(1===arguments.length)for(;++a<i;)d(r=+t[a])&&(n+=r);else for(;++a<i;)d(r=+e.call(t,t[a],a))&&(n+=r);return n},t.mean=function(t,e){var r,n=0,i=t.length,a=-1,o=i;if(1===arguments.length)for(;++a<i;)d(r=p(t[a]))?n+=r:--o;else for(;++a<i;)d(r=p(e.call(t,t[a],a)))?n+=r:--o;if(o)return n/o},t.quantile=function(t,e){var r=(t.length-1)*e+1,n=Math.floor(r),i=+t[n-1],a=r-n;return a?i+a*(t[n]-i):i},t.median=function(e,r){var n,i=[],a=e.length,o=-1;if(1===arguments.length)for(;++o<a;)d(n=p(e[o]))&&i.push(n);else for(;++o<a;)d(n=p(r.call(e,e[o],o)))&&i.push(n);if(i.length)return t.quantile(i.sort(f),.5)},t.variance=function(t,e){var r,n,i=t.length,a=0,o=0,s=-1,l=0;if(1===arguments.length)for(;++s<i;)d(r=p(t[s]))&&(o+=(n=r-a)*(r-(a+=n/++l)));else for(;++s<i;)d(r=p(e.call(t,t[s],s)))&&(o+=(n=r-a)*(r-(a+=n/++l)));if(l>1)return o/(l-1)},t.deviation=function(){var e=t.variance.apply(this,arguments);return e?Math.sqrt(e):e};var v=g(f);function m(t){return t.length}t.bisectLeft=v.left,t.bisect=t.bisectRight=v.right,t.bisector=function(t){return g(1===t.length?function(e,r){return f(t(e),r)}:t)},t.shuffle=function(t,e,r){(a=arguments.length)<3&&(r=t.length,a<2&&(e=0));for(var n,i,a=r-e;a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.pairs=function(t){for(var e=0,r=t.length-1,n=t[0],i=new Array(r<0?0:r);e<r;)i[e]=[n,n=t[++e]];return i},t.transpose=function(e){if(!(a=e.length))return[];for(var r=-1,n=t.min(e,m),i=new Array(n);++r<n;)for(var a,o=-1,s=i[r]=new Array(a);++o<a;)s[o]=e[o][r];return i},t.zip=function(){return t.transpose(arguments)},t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r};var y=Math.abs;function x(t,e){for(var r in e)Object.defineProperty(t.prototype,r,{value:e[r],enumerable:!1})}function b(){this._=Object.create(null)}t.range=function(t,e,r){if(arguments.length<3&&(r=1,arguments.length<2&&(e=t,t=0)),(e-t)/r==1/0)throw new Error(\"infinite range\");var n,i=[],a=function(t){var e=1;for(;t*e%1;)e*=10;return e}(y(r)),o=-1;if(t*=a,e*=a,(r*=a)<0)for(;(n=t+r*++o)>e;)i.push(n/a);else for(;(n=t+r*++o)<e;)i.push(n/a);return i},t.map=function(t,e){var r=new b;if(t instanceof b)t.forEach(function(t,e){r.set(t,e)});else if(Array.isArray(t)){var n,i=-1,a=t.length;if(1===arguments.length)for(;++i<a;)r.set(i,t[i]);else for(;++i<a;)r.set(e.call(t,n=t[i],i),n)}else for(var o in t)r.set(o,t[o]);return r};var _=\"__proto__\",w=\"\\0\";function k(t){return(t+=\"\")===_||t[0]===w?w+t:t}function T(t){return(t+=\"\")[0]===w?t.slice(1):t}function A(t){return k(t)in this._}function M(t){return(t=k(t))in this._&&delete this._[t]}function S(){var t=[];for(var e in this._)t.push(T(e));return t}function E(){var t=0;for(var e in this._)++t;return t}function C(){for(var t in this._)return!1;return!0}function L(){this._=Object.create(null)}function P(t){return t}function O(t,e,r){return function(){var n=r.apply(e,arguments);return n===e?t:n}}function z(t,e){if(e in t)return e;e=e.charAt(0).toUpperCase()+e.slice(1);for(var r=0,n=I.length;r<n;++r){var i=I[r]+e;if(i in t)return i}}x(b,{has:A,get:function(t){return this._[k(t)]},set:function(t,e){return this._[k(t)]=e},remove:M,keys:S,values:function(){var t=[];for(var e in this._)t.push(this._[e]);return t},entries:function(){var t=[];for(var e in this._)t.push({key:T(e),value:this._[e]});return t},size:E,empty:C,forEach:function(t){for(var e in this._)t.call(this,T(e),this._[e])}}),t.nest=function(){var e,r,n={},i=[],a=[];function o(t,a,s){if(s>=i.length)return r?r.call(n,a):e?a.sort(e):a;for(var l,c,u,h,f=-1,p=a.length,d=i[s++],g=new b;++f<p;)(h=g.get(l=d(c=a[f])))?h.push(c):g.set(l,[c]);return t?(c=t(),u=function(e,r){c.set(e,o(t,r,s))}):(c={},u=function(e,r){c[e]=o(t,r,s)}),g.forEach(u),c}return n.map=function(t,e){return o(e,t,0)},n.entries=function(e){return function t(e,r){if(r>=i.length)return e;var n=[],o=a[r++];return e.forEach(function(e,i){n.push({key:e,values:t(i,r)})}),o?n.sort(function(t,e){return o(t.key,e.key)}):n}(o(t.map,e,0),0)},n.key=function(t){return i.push(t),n},n.sortKeys=function(t){return a[i.length-1]=t,n},n.sortValues=function(t){return e=t,n},n.rollup=function(t){return r=t,n},n},t.set=function(t){var e=new L;if(t)for(var r=0,n=t.length;r<n;++r)e.add(t[r]);return e},x(L,{has:A,add:function(t){return this._[k(t+=\"\")]=!0,t},remove:M,values:S,size:E,empty:C,forEach:function(t){for(var e in this._)t.call(this,T(e))}}),t.behavior={},t.rebind=function(t,e){for(var r,n=1,i=arguments.length;++n<i;)t[r=arguments[n]]=O(t,e,e[r]);return t};var I=[\"webkit\",\"ms\",\"moz\",\"Moz\",\"o\",\"O\"];function D(){}function R(){}function F(t){var e=[],r=new b;function n(){for(var r,n=e,i=-1,a=n.length;++i<a;)(r=n[i].on)&&r.apply(this,arguments);return t}return n.on=function(n,i){var a,o=r.get(n);return arguments.length<2?o&&o.on:(o&&(o.on=null,e=e.slice(0,a=e.indexOf(o)).concat(e.slice(a+1)),r.remove(n)),i&&e.push(r.set(n,{on:i})),t)},n}function B(){t.event.preventDefault()}function N(){for(var e,r=t.event;e=r.sourceEvent;)r=e;return r}function j(e){for(var r=new R,n=0,i=arguments.length;++n<i;)r[arguments[n]]=F(r);return r.of=function(n,i){return function(a){try{var o=a.sourceEvent=t.event;a.target=e,t.event=a,r[a.type].apply(n,i)}finally{t.event=o}}},r}t.dispatch=function(){for(var t=new R,e=-1,r=arguments.length;++e<r;)t[arguments[e]]=F(t);return t},R.prototype.on=function(t,e){var r=t.indexOf(\".\"),n=\"\";if(r>=0&&(n=t.slice(r+1),t=t.slice(0,r)),t)return arguments.length<2?this[t].on(n):this[t].on(n,e);if(2===arguments.length){if(null==e)for(t in this)this.hasOwnProperty(t)&&this[t].on(n,null);return this}},t.event=null,t.requote=function(t){return t.replace(U,\"\\\\$&\")};var U=/[\\\\\\^\\$\\*\\+\\?\\|\\[\\]\\(\\)\\.\\{\\}]/g,V={}.__proto__?function(t,e){t.__proto__=e}:function(t,e){for(var r in e)t[r]=e[r]};function q(t){return V(t,W),t}var H=function(t,e){return e.querySelector(t)},G=function(t,e){return e.querySelectorAll(t)},Y=function(t,e){var r=t.matches||t[z(t,\"matchesSelector\")];return(Y=function(t,e){return r.call(t,e)})(t,e)};\"function\"==typeof Sizzle&&(H=function(t,e){return Sizzle(t,e)[0]||null},G=Sizzle,Y=Sizzle.matchesSelector),t.selection=function(){return t.select(i.documentElement)};var W=t.selection.prototype=[];function X(t){return\"function\"==typeof t?t:function(){return H(t,this)}}function Z(t){return\"function\"==typeof t?t:function(){return G(t,this)}}W.select=function(t){var e,r,n,i,a=[];t=X(t);for(var o=-1,s=this.length;++o<s;){a.push(e=[]),e.parentNode=(n=this[o]).parentNode;for(var l=-1,c=n.length;++l<c;)(i=n[l])?(e.push(r=t.call(i,i.__data__,l,o)),r&&\"__data__\"in i&&(r.__data__=i.__data__)):e.push(null)}return q(a)},W.selectAll=function(t){var e,r,i=[];t=Z(t);for(var a=-1,o=this.length;++a<o;)for(var s=this[a],l=-1,c=s.length;++l<c;)(r=s[l])&&(i.push(e=n(t.call(r,r.__data__,l,a))),e.parentNode=r);return q(i)};var J=\"http://www.w3.org/1999/xhtml\",K={svg:\"http://www.w3.org/2000/svg\",xhtml:J,xlink:\"http://www.w3.org/1999/xlink\",xml:\"http://www.w3.org/XML/1998/namespace\",xmlns:\"http://www.w3.org/2000/xmlns/\"};function $(e,r){return e=t.ns.qualify(e),null==r?e.local?function(){this.removeAttributeNS(e.space,e.local)}:function(){this.removeAttribute(e)}:\"function\"==typeof r?e.local?function(){var t=r.apply(this,arguments);null==t?this.removeAttributeNS(e.space,e.local):this.setAttributeNS(e.space,e.local,t)}:function(){var t=r.apply(this,arguments);null==t?this.removeAttribute(e):this.setAttribute(e,t)}:e.local?function(){this.setAttributeNS(e.space,e.local,r)}:function(){this.setAttribute(e,r)}}function Q(t){return t.trim().replace(/\\s+/g,\" \")}function tt(e){return new RegExp(\"(?:^|\\\\s+)\"+t.requote(e)+\"(?:\\\\s+|$)\",\"g\")}function et(t){return(t+\"\").trim().split(/^|\\s+/)}function rt(t,e){var r=(t=et(t).map(nt)).length;return\"function\"==typeof e?function(){for(var n=-1,i=e.apply(this,arguments);++n<r;)t[n](this,i)}:function(){for(var n=-1;++n<r;)t[n](this,e)}}function nt(t){var e=tt(t);return function(r,n){if(i=r.classList)return n?i.add(t):i.remove(t);var i=r.getAttribute(\"class\")||\"\";n?(e.lastIndex=0,e.test(i)||r.setAttribute(\"class\",Q(i+\" \"+t))):r.setAttribute(\"class\",Q(i.replace(e,\" \")))}}function it(t,e,r){return null==e?function(){this.style.removeProperty(t)}:\"function\"==typeof e?function(){var n=e.apply(this,arguments);null==n?this.style.removeProperty(t):this.style.setProperty(t,n,r)}:function(){this.style.setProperty(t,e,r)}}function at(t,e){return null==e?function(){delete this[t]}:\"function\"==typeof e?function(){var r=e.apply(this,arguments);null==r?delete this[t]:this[t]=r}:function(){this[t]=e}}function ot(e){return\"function\"==typeof e?e:(e=t.ns.qualify(e)).local?function(){return this.ownerDocument.createElementNS(e.space,e.local)}:function(){var t=this.ownerDocument,r=this.namespaceURI;return r===J&&t.documentElement.namespaceURI===J?t.createElement(e):t.createElementNS(r,e)}}function st(){var t=this.parentNode;t&&t.removeChild(this)}function lt(t){return{__data__:t}}function ct(t){return function(){return Y(this,t)}}function ut(t,e){for(var r=0,n=t.length;r<n;r++)for(var i,a=t[r],o=0,s=a.length;o<s;o++)(i=a[o])&&e(i,o,r);return t}function ht(t){return V(t,ft),t}t.ns={prefix:K,qualify:function(t){var e=t.indexOf(\":\"),r=t;return e>=0&&\"xmlns\"!==(r=t.slice(0,e))&&(t=t.slice(e+1)),K.hasOwnProperty(r)?{space:K[r],local:t}:t}},W.attr=function(e,r){if(arguments.length<2){if(\"string\"==typeof e){var n=this.node();return(e=t.ns.qualify(e)).local?n.getAttributeNS(e.space,e.local):n.getAttribute(e)}for(r in e)this.each($(r,e[r]));return this}return this.each($(e,r))},W.classed=function(t,e){if(arguments.length<2){if(\"string\"==typeof t){var r=this.node(),n=(t=et(t)).length,i=-1;if(e=r.classList){for(;++i<n;)if(!e.contains(t[i]))return!1}else for(e=r.getAttribute(\"class\");++i<n;)if(!tt(t[i]).test(e))return!1;return!0}for(e in t)this.each(rt(e,t[e]));return this}return this.each(rt(t,e))},W.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.each(it(r,t[r],e));return this}if(n<2){var i=this.node();return o(i).getComputedStyle(i,null).getPropertyValue(t)}r=\"\"}return this.each(it(t,e,r))},W.property=function(t,e){if(arguments.length<2){if(\"string\"==typeof t)return this.node()[t];for(e in t)this.each(at(e,t[e]));return this}return this.each(at(t,e))},W.text=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.textContent=null==e?\"\":e}:null==t?function(){this.textContent=\"\"}:function(){this.textContent=t}):this.node().textContent},W.html=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.innerHTML=null==e?\"\":e}:null==t?function(){this.innerHTML=\"\"}:function(){this.innerHTML=t}):this.node().innerHTML},W.append=function(t){return t=ot(t),this.select(function(){return this.appendChild(t.apply(this,arguments))})},W.insert=function(t,e){return t=ot(t),e=X(e),this.select(function(){return this.insertBefore(t.apply(this,arguments),e.apply(this,arguments)||null)})},W.remove=function(){return this.each(st)},W.data=function(t,e){var r,n,i=-1,a=this.length;if(!arguments.length){for(t=new Array(a=(r=this[0]).length);++i<a;)(n=r[i])&&(t[i]=n.__data__);return t}function o(t,r){var n,i,a,o=t.length,u=r.length,h=Math.min(o,u),f=new Array(u),p=new Array(u),d=new Array(o);if(e){var g,v=new b,m=new Array(o);for(n=-1;++n<o;)(i=t[n])&&(v.has(g=e.call(i,i.__data__,n))?d[n]=i:v.set(g,i),m[n]=g);for(n=-1;++n<u;)(i=v.get(g=e.call(r,a=r[n],n)))?!0!==i&&(f[n]=i,i.__data__=a):p[n]=lt(a),v.set(g,!0);for(n=-1;++n<o;)n in m&&!0!==v.get(m[n])&&(d[n]=t[n])}else{for(n=-1;++n<h;)i=t[n],a=r[n],i?(i.__data__=a,f[n]=i):p[n]=lt(a);for(;n<u;++n)p[n]=lt(r[n]);for(;n<o;++n)d[n]=t[n]}p.update=f,p.parentNode=f.parentNode=d.parentNode=t.parentNode,s.push(p),l.push(f),c.push(d)}var s=ht([]),l=q([]),c=q([]);if(\"function\"==typeof t)for(;++i<a;)o(r=this[i],t.call(r,r.parentNode.__data__,i));else for(;++i<a;)o(r=this[i],t);return l.enter=function(){return s},l.exit=function(){return c},l},W.datum=function(t){return arguments.length?this.property(\"__data__\",t):this.property(\"__data__\")},W.filter=function(t){var e,r,n,i=[];\"function\"!=typeof t&&(t=ct(t));for(var a=0,o=this.length;a<o;a++){i.push(e=[]),e.parentNode=(r=this[a]).parentNode;for(var s=0,l=r.length;s<l;s++)(n=r[s])&&t.call(n,n.__data__,s,a)&&e.push(n)}return q(i)},W.order=function(){for(var t=-1,e=this.length;++t<e;)for(var r,n=this[t],i=n.length-1,a=n[i];--i>=0;)(r=n[i])&&(a&&a!==r.nextSibling&&a.parentNode.insertBefore(r,a),a=r);return this},W.sort=function(t){t=function(t){arguments.length||(t=f);return function(e,r){return e&&r?t(e.__data__,r.__data__):!e-!r}}.apply(this,arguments);for(var e=-1,r=this.length;++e<r;)this[e].sort(t);return this.order()},W.each=function(t){return ut(this,function(e,r,n){t.call(e,e.__data__,r,n)})},W.call=function(t){var e=n(arguments);return t.apply(e[0]=this,e),this},W.empty=function(){return!this.node()},W.node=function(){for(var t=0,e=this.length;t<e;t++)for(var r=this[t],n=0,i=r.length;n<i;n++){var a=r[n];if(a)return a}return null},W.size=function(){var t=0;return ut(this,function(){++t}),t};var ft=[];function pt(e,r,i){var a=\"__on\"+e,o=e.indexOf(\".\"),s=gt;o>0&&(e=e.slice(0,o));var l=dt.get(e);function c(){var t=this[a];t&&(this.removeEventListener(e,t,t.$),delete this[a])}return l&&(e=l,s=vt),o?r?function(){var t=s(r,n(arguments));c.call(this),this.addEventListener(e,this[a]=t,t.$=i),t._=r}:c:r?D:function(){var r,n=new RegExp(\"^__on([^.]+)\"+t.requote(e)+\"$\");for(var i in this)if(r=i.match(n)){var a=this[i];this.removeEventListener(r[1],a,a.$),delete this[i]}}}t.selection.enter=ht,t.selection.enter.prototype=ft,ft.append=W.append,ft.empty=W.empty,ft.node=W.node,ft.call=W.call,ft.size=W.size,ft.select=function(t){for(var e,r,n,i,a,o=[],s=-1,l=this.length;++s<l;){n=(i=this[s]).update,o.push(e=[]),e.parentNode=i.parentNode;for(var c=-1,u=i.length;++c<u;)(a=i[c])?(e.push(n[c]=r=t.call(i.parentNode,a.__data__,c,s)),r.__data__=a.__data__):e.push(null)}return q(o)},ft.insert=function(t,e){var r,n,i;return arguments.length<2&&(r=this,e=function(t,e,a){var o,s=r[a].update,l=s.length;for(a!=i&&(i=a,n=0),e>=n&&(n=e+1);!(o=s[n])&&++n<l;);return o}),W.insert.call(this,t,e)},t.select=function(t){var e;return\"string\"==typeof t?(e=[H(t,i)]).parentNode=i.documentElement:(e=[t]).parentNode=a(t),q([e])},t.selectAll=function(t){var e;return\"string\"==typeof t?(e=n(G(t,i))).parentNode=i.documentElement:(e=n(t)).parentNode=null,q([e])},W.on=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=!1),t)this.each(pt(r,t[r],e));return this}if(n<2)return(n=this.node()[\"__on\"+t])&&n._;r=!1}return this.each(pt(t,e,r))};var dt=t.map({mouseenter:\"mouseover\",mouseleave:\"mouseout\"});function gt(e,r){return function(n){var i=t.event;t.event=n,r[0]=this.__data__;try{e.apply(this,r)}finally{t.event=i}}}function vt(t,e){var r=gt(t,e);return function(t){var e=t.relatedTarget;e&&(e===this||8&e.compareDocumentPosition(this))||r.call(this,t)}}i&&dt.forEach(function(t){\"on\"+t in i&&dt.remove(t)});var mt,yt=0;function xt(e){var r=\".dragsuppress-\"+ ++yt,n=\"click\"+r,i=t.select(o(e)).on(\"touchmove\"+r,B).on(\"dragstart\"+r,B).on(\"selectstart\"+r,B);if(null==mt&&(mt=!(\"onselectstart\"in e)&&z(e.style,\"userSelect\")),mt){var s=a(e).style,l=s[mt];s[mt]=\"none\"}return function(t){if(i.on(r,null),mt&&(s[mt]=l),t){var e=function(){i.on(n,null)};i.on(n,function(){B(),e()},!0),setTimeout(e,0)}}}t.mouse=function(t){return _t(t,N())};var bt=this.navigator&&/WebKit/.test(this.navigator.userAgent)?-1:0;function _t(e,r){r.changedTouches&&(r=r.changedTouches[0]);var n=e.ownerSVGElement||e;if(n.createSVGPoint){var i=n.createSVGPoint();if(bt<0){var a=o(e);if(a.scrollX||a.scrollY){var s=(n=t.select(\"body\").append(\"svg\").style({position:\"absolute\",top:0,left:0,margin:0,padding:0,border:\"none\"},\"important\"))[0][0].getScreenCTM();bt=!(s.f||s.e),n.remove()}}return bt?(i.x=r.pageX,i.y=r.pageY):(i.x=r.clientX,i.y=r.clientY),[(i=i.matrixTransform(e.getScreenCTM().inverse())).x,i.y]}var l=e.getBoundingClientRect();return[r.clientX-l.left-e.clientLeft,r.clientY-l.top-e.clientTop]}function wt(){return t.event.changedTouches[0].identifier}t.touch=function(t,e,r){if(arguments.length<3&&(r=e,e=N().changedTouches),e)for(var n,i=0,a=e.length;i<a;++i)if((n=e[i]).identifier===r)return _t(t,n)},t.behavior.drag=function(){var e=j(a,\"drag\",\"dragstart\",\"dragend\"),r=null,n=s(D,t.mouse,o,\"mousemove\",\"mouseup\"),i=s(wt,t.touch,P,\"touchmove\",\"touchend\");function a(){this.on(\"mousedown.drag\",n).on(\"touchstart.drag\",i)}function s(n,i,a,o,s){return function(){var l,c=t.event.target.correspondingElement||t.event.target,u=this.parentNode,h=e.of(this,arguments),f=0,p=n(),d=\".drag\"+(null==p?\"\":\"-\"+p),g=t.select(a(c)).on(o+d,function(){var t,e,r=i(u,p);if(!r)return;t=r[0]-m[0],e=r[1]-m[1],f|=t|e,m=r,h({type:\"drag\",x:r[0]+l[0],y:r[1]+l[1],dx:t,dy:e})}).on(s+d,function(){if(!i(u,p))return;g.on(o+d,null).on(s+d,null),v(f),h({type:\"dragend\"})}),v=xt(c),m=i(u,p);l=r?[(l=r.apply(this,arguments)).x-m[0],l.y-m[1]]:[0,0],h({type:\"dragstart\"})}}return a.origin=function(t){return arguments.length?(r=t,a):r},t.rebind(a,e,\"on\")},t.touches=function(t,e){return arguments.length<2&&(e=N().touches),e?n(e).map(function(e){var r=_t(t,e);return r.identifier=e.identifier,r}):[]};var kt=1e-6,Tt=kt*kt,At=Math.PI,Mt=2*At,St=Mt-kt,Et=At/2,Ct=At/180,Lt=180/At;function Pt(t){return t>0?1:t<0?-1:0}function Ot(t,e,r){return(e[0]-t[0])*(r[1]-t[1])-(e[1]-t[1])*(r[0]-t[0])}function zt(t){return t>1?0:t<-1?At:Math.acos(t)}function It(t){return t>1?Et:t<-1?-Et:Math.asin(t)}function Dt(t){return((t=Math.exp(t))+1/t)/2}function Rt(t){return(t=Math.sin(t/2))*t}var Ft=Math.SQRT2;t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,h=l-a,f=u*u+h*h;if(f<Tt)n=Math.log(c/o)/Ft,r=function(t){return[i+t*u,a+t*h,o*Math.exp(Ft*t*n)]};else{var p=Math.sqrt(f),d=(c*c-o*o+4*f)/(2*o*2*p),g=(c*c-o*o-4*f)/(2*c*2*p),v=Math.log(Math.sqrt(d*d+1)-d),m=Math.log(Math.sqrt(g*g+1)-g);n=(m-v)/Ft,r=function(t){var e,r=t*n,s=Dt(v),l=o/(2*p)*(s*(e=Ft*r+v,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(v));return[i+l*u,a+l*h,o*s/Dt(Ft*r+v)]}}return r.duration=1e3*n,r},t.behavior.zoom=function(){var e,r,n,a,s,l,c,u,h,f={x:0,y:0,k:1},p=[960,500],d=jt,g=250,v=0,m=\"mousedown.zoom\",y=\"mousemove.zoom\",x=\"mouseup.zoom\",b=\"touchstart.zoom\",_=j(w,\"zoomstart\",\"zoom\",\"zoomend\");function w(t){t.on(m,P).on(Nt+\".zoom\",z).on(\"dblclick.zoom\",I).on(b,O)}function k(t){return[(t[0]-f.x)/f.k,(t[1]-f.y)/f.k]}function T(t){f.k=Math.max(d[0],Math.min(d[1],t))}function A(t,e){e=function(t){return[t[0]*f.k+f.x,t[1]*f.k+f.y]}(e),f.x+=t[0]-e[0],f.y+=t[1]-e[1]}function M(e,n,i,a){e.__chart__={x:f.x,y:f.y,k:f.k},T(Math.pow(2,a)),A(r=n,i),e=t.select(e),g>0&&(e=e.transition().duration(g)),e.call(w.event)}function S(){c&&c.domain(l.range().map(function(t){return(t-f.x)/f.k}).map(l.invert)),h&&h.domain(u.range().map(function(t){return(t-f.y)/f.k}).map(u.invert))}function E(t){v++||t({type:\"zoomstart\"})}function C(t){S(),t({type:\"zoom\",scale:f.k,translate:[f.x,f.y]})}function L(t){--v||(t({type:\"zoomend\"}),r=null)}function P(){var e=this,r=_.of(e,arguments),n=0,i=t.select(o(e)).on(y,function(){n=1,A(t.mouse(e),a),C(r)}).on(x,function(){i.on(y,null).on(x,null),s(n),L(r)}),a=k(t.mouse(e)),s=xt(e);hs.call(e),E(r)}function O(){var e,r=this,n=_.of(r,arguments),i={},a=0,o=\".zoom-\"+t.event.changedTouches[0].identifier,l=\"touchmove\"+o,c=\"touchend\"+o,u=[],h=t.select(r),p=xt(r);function d(){var n=t.touches(r);return e=f.k,n.forEach(function(t){t.identifier in i&&(i[t.identifier]=k(t))}),n}function g(){var e=t.event.target;t.select(e).on(l,v).on(c,y),u.push(e);for(var n=t.event.changedTouches,o=0,h=n.length;o<h;++o)i[n[o].identifier]=null;var p=d(),g=Date.now();if(1===p.length){if(g-s<500){var m=p[0];M(r,m,i[m.identifier],Math.floor(Math.log(f.k)/Math.LN2)+1),B()}s=g}else if(p.length>1){m=p[0];var x=p[1],b=m[0]-x[0],_=m[1]-x[1];a=b*b+_*_}}function v(){var o,l,c,u,h=t.touches(r);hs.call(r);for(var f=0,p=h.length;f<p;++f,u=null)if(c=h[f],u=i[c.identifier]){if(l)break;o=c,l=u}if(u){var d=(d=c[0]-o[0])*d+(d=c[1]-o[1])*d,g=a&&Math.sqrt(d/a);o=[(o[0]+c[0])/2,(o[1]+c[1])/2],l=[(l[0]+u[0])/2,(l[1]+u[1])/2],T(g*e)}s=null,A(o,l),C(n)}function y(){if(t.event.touches.length){for(var e=t.event.changedTouches,r=0,a=e.length;r<a;++r)delete i[e[r].identifier];for(var s in i)return void d()}t.selectAll(u).on(o,null),h.on(m,P).on(b,O),p(),L(n)}g(),E(n),h.on(m,null).on(b,g)}function z(){var i=_.of(this,arguments);a?clearTimeout(a):(hs.call(this),e=k(r=n||t.mouse(this)),E(i)),a=setTimeout(function(){a=null,L(i)},50),B(),T(Math.pow(2,.002*Bt())*f.k),A(r,e),C(i)}function I(){var e=t.mouse(this),r=Math.log(f.k)/Math.LN2;M(this,e,k(e),t.event.shiftKey?Math.ceil(r)-1:Math.floor(r)+1)}return Nt||(Nt=\"onwheel\"in i?(Bt=function(){return-t.event.deltaY*(t.event.deltaMode?120:1)},\"wheel\"):\"onmousewheel\"in i?(Bt=function(){return t.event.wheelDelta},\"mousewheel\"):(Bt=function(){return-t.event.detail},\"MozMousePixelScroll\")),w.event=function(e){e.each(function(){var e=_.of(this,arguments),n=f;ds?t.select(this).transition().each(\"start.zoom\",function(){f=this.__chart__||{x:0,y:0,k:1},E(e)}).tween(\"zoom:zoom\",function(){var i=p[0],a=p[1],o=r?r[0]:i/2,s=r?r[1]:a/2,l=t.interpolateZoom([(o-f.x)/f.k,(s-f.y)/f.k,i/f.k],[(o-n.x)/n.k,(s-n.y)/n.k,i/n.k]);return function(t){var r=l(t),n=i/r[2];this.__chart__=f={x:o-r[0]*n,y:s-r[1]*n,k:n},C(e)}}).each(\"interrupt.zoom\",function(){L(e)}).each(\"end.zoom\",function(){L(e)}):(this.__chart__=f,E(e),C(e),L(e))})},w.translate=function(t){return arguments.length?(f={x:+t[0],y:+t[1],k:f.k},S(),w):[f.x,f.y]},w.scale=function(t){return arguments.length?(f={x:f.x,y:f.y,k:null},T(+t),S(),w):f.k},w.scaleExtent=function(t){return arguments.length?(d=null==t?jt:[+t[0],+t[1]],w):d},w.center=function(t){return arguments.length?(n=t&&[+t[0],+t[1]],w):n},w.size=function(t){return arguments.length?(p=t&&[+t[0],+t[1]],w):p},w.duration=function(t){return arguments.length?(g=+t,w):g},w.x=function(t){return arguments.length?(c=t,l=t.copy(),f={x:0,y:0,k:1},w):c},w.y=function(t){return arguments.length?(h=t,u=t.copy(),f={x:0,y:0,k:1},w):h},t.rebind(w,_,\"on\")};var Bt,Nt,jt=[0,1/0];function Ut(){}function Vt(t,e,r){return this instanceof Vt?(this.h=+t,this.s=+e,void(this.l=+r)):arguments.length<2?t instanceof Vt?new Vt(t.h,t.s,t.l):ue(\"\"+t,he,Vt):new Vt(t,e,r)}t.color=Ut,Ut.prototype.toString=function(){return this.rgb()+\"\"},t.hsl=Vt;var qt=Vt.prototype=new Ut;function Ht(t,e,r){var n,i;function a(t){return Math.round(255*function(t){return t>360?t-=360:t<0&&(t+=360),t<60?n+(i-n)*t/60:t<180?i:t<240?n+(i-n)*(240-t)/60:n}(t))}return t=isNaN(t)?0:(t%=360)<0?t+360:t,e=isNaN(e)?0:e<0?0:e>1?1:e,n=2*(r=r<0?0:r>1?1:r)-(i=r<=.5?r*(1+e):r+e-r*e),new ae(a(t+120),a(t),a(t-120))}function Gt(e,r,n){return this instanceof Gt?(this.h=+e,this.c=+r,void(this.l=+n)):arguments.length<2?e instanceof Gt?new Gt(e.h,e.c,e.l):ee(e instanceof Xt?e.l:(e=fe((e=t.rgb(e)).r,e.g,e.b)).l,e.a,e.b):new Gt(e,r,n)}qt.brighter=function(t){return t=Math.pow(.7,arguments.length?t:1),new Vt(this.h,this.s,this.l/t)},qt.darker=function(t){return t=Math.pow(.7,arguments.length?t:1),new Vt(this.h,this.s,t*this.l)},qt.rgb=function(){return Ht(this.h,this.s,this.l)},t.hcl=Gt;var Yt=Gt.prototype=new Ut;function Wt(t,e,r){return isNaN(t)&&(t=0),isNaN(e)&&(e=0),new Xt(r,Math.cos(t*=Ct)*e,Math.sin(t)*e)}function Xt(t,e,r){return this instanceof Xt?(this.l=+t,this.a=+e,void(this.b=+r)):arguments.length<2?t instanceof Xt?new Xt(t.l,t.a,t.b):t instanceof Gt?Wt(t.h,t.c,t.l):fe((t=ae(t)).r,t.g,t.b):new Xt(t,e,r)}Yt.brighter=function(t){return new Gt(this.h,this.c,Math.min(100,this.l+Zt*(arguments.length?t:1)))},Yt.darker=function(t){return new Gt(this.h,this.c,Math.max(0,this.l-Zt*(arguments.length?t:1)))},Yt.rgb=function(){return Wt(this.h,this.c,this.l).rgb()},t.lab=Xt;var Zt=18,Jt=.95047,Kt=1,$t=1.08883,Qt=Xt.prototype=new Ut;function te(t,e,r){var n=(t+16)/116,i=n+e/500,a=n-r/200;return new ae(ie(3.2404542*(i=re(i)*Jt)-1.5371385*(n=re(n)*Kt)-.4985314*(a=re(a)*$t)),ie(-.969266*i+1.8760108*n+.041556*a),ie(.0556434*i-.2040259*n+1.0572252*a))}function ee(t,e,r){return t>0?new Gt(Math.atan2(r,e)*Lt,Math.sqrt(e*e+r*r),t):new Gt(NaN,NaN,t)}function re(t){return t>.206893034?t*t*t:(t-4/29)/7.787037}function ne(t){return t>.008856?Math.pow(t,1/3):7.787037*t+4/29}function ie(t){return Math.round(255*(t<=.00304?12.92*t:1.055*Math.pow(t,1/2.4)-.055))}function ae(t,e,r){return this instanceof ae?(this.r=~~t,this.g=~~e,void(this.b=~~r)):arguments.length<2?t instanceof ae?new ae(t.r,t.g,t.b):ue(\"\"+t,ae,Ht):new ae(t,e,r)}function oe(t){return new ae(t>>16,t>>8&255,255&t)}function se(t){return oe(t)+\"\"}Qt.brighter=function(t){return new Xt(Math.min(100,this.l+Zt*(arguments.length?t:1)),this.a,this.b)},Qt.darker=function(t){return new Xt(Math.max(0,this.l-Zt*(arguments.length?t:1)),this.a,this.b)},Qt.rgb=function(){return te(this.l,this.a,this.b)},t.rgb=ae;var le=ae.prototype=new Ut;function ce(t){return t<16?\"0\"+Math.max(0,t).toString(16):Math.min(255,t).toString(16)}function ue(t,e,r){var n,i,a,o=0,s=0,l=0;if(n=/([a-z]+)\\((.*)\\)/.exec(t=t.toLowerCase()))switch(i=n[2].split(\",\"),n[1]){case\"hsl\":return r(parseFloat(i[0]),parseFloat(i[1])/100,parseFloat(i[2])/100);case\"rgb\":return e(de(i[0]),de(i[1]),de(i[2]))}return(a=ge.get(t))?e(a.r,a.g,a.b):(null==t||\"#\"!==t.charAt(0)||isNaN(a=parseInt(t.slice(1),16))||(4===t.length?(o=(3840&a)>>4,o|=o>>4,s=240&a,s|=s>>4,l=15&a,l|=l<<4):7===t.length&&(o=(16711680&a)>>16,s=(65280&a)>>8,l=255&a)),e(o,s,l))}function he(t,e,r){var n,i,a=Math.min(t/=255,e/=255,r/=255),o=Math.max(t,e,r),s=o-a,l=(o+a)/2;return s?(i=l<.5?s/(o+a):s/(2-o-a),n=t==o?(e-r)/s+(e<r?6:0):e==o?(r-t)/s+2:(t-e)/s+4,n*=60):(n=NaN,i=l>0&&l<1?0:n),new Vt(n,i,l)}function fe(t,e,r){var n=ne((.4124564*(t=pe(t))+.3575761*(e=pe(e))+.1804375*(r=pe(r)))/Jt),i=ne((.2126729*t+.7151522*e+.072175*r)/Kt);return Xt(116*i-16,500*(n-i),200*(i-ne((.0193339*t+.119192*e+.9503041*r)/$t)))}function pe(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function de(t){var e=parseFloat(t);return\"%\"===t.charAt(t.length-1)?Math.round(2.55*e):e}le.brighter=function(t){t=Math.pow(.7,arguments.length?t:1);var e=this.r,r=this.g,n=this.b,i=30;return e||r||n?(e&&e<i&&(e=i),r&&r<i&&(r=i),n&&n<i&&(n=i),new ae(Math.min(255,e/t),Math.min(255,r/t),Math.min(255,n/t))):new ae(i,i,i)},le.darker=function(t){return new ae((t=Math.pow(.7,arguments.length?t:1))*this.r,t*this.g,t*this.b)},le.hsl=function(){return he(this.r,this.g,this.b)},le.toString=function(){return\"#\"+ce(this.r)+ce(this.g)+ce(this.b)};var ge=t.map({aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074});function ve(t){return\"function\"==typeof t?t:function(){return t}}function me(t){return function(e,r,n){return 2===arguments.length&&\"function\"==typeof r&&(n=r,r=null),ye(e,r,t,n)}}function ye(e,r,i,a){var o={},s=t.dispatch(\"beforesend\",\"progress\",\"load\",\"error\"),l={},c=new XMLHttpRequest,u=null;function h(){var t,e=c.status;if(!e&&function(t){var e=t.responseType;return e&&\"text\"!==e?t.response:t.responseText}(c)||e>=200&&e<300||304===e){try{t=i.call(o,c)}catch(t){return void s.error.call(o,t)}s.load.call(o,t)}else s.error.call(o,c)}return!this.XDomainRequest||\"withCredentials\"in c||!/^(http(s)?:)?\\/\\//.test(e)||(c=new XDomainRequest),\"onload\"in c?c.onload=c.onerror=h:c.onreadystatechange=function(){c.readyState>3&&h()},c.onprogress=function(e){var r=t.event;t.event=e;try{s.progress.call(o,c)}finally{t.event=r}},o.header=function(t,e){return t=(t+\"\").toLowerCase(),arguments.length<2?l[t]:(null==e?delete l[t]:l[t]=e+\"\",o)},o.mimeType=function(t){return arguments.length?(r=null==t?null:t+\"\",o):r},o.responseType=function(t){return arguments.length?(u=t,o):u},o.response=function(t){return i=t,o},[\"get\",\"post\"].forEach(function(t){o[t]=function(){return o.send.apply(o,[t].concat(n(arguments)))}}),o.send=function(t,n,i){if(2===arguments.length&&\"function\"==typeof n&&(i=n,n=null),c.open(t,e,!0),null==r||\"accept\"in l||(l.accept=r+\",*/*\"),c.setRequestHeader)for(var a in l)c.setRequestHeader(a,l[a]);return null!=r&&c.overrideMimeType&&c.overrideMimeType(r),null!=u&&(c.responseType=u),null!=i&&o.on(\"error\",i).on(\"load\",function(t){i(null,t)}),s.beforesend.call(o,c),c.send(null==n?null:n),o},o.abort=function(){return c.abort(),o},t.rebind(o,s,\"on\"),null==a?o:o.get(function(t){return 1===t.length?function(e,r){t(null==e?r:null)}:t}(a))}ge.forEach(function(t,e){ge.set(t,oe(e))}),t.functor=ve,t.xhr=me(P),t.dsv=function(t,e){var r=new RegExp('[\"'+t+\"\\n]\"),n=t.charCodeAt(0);function i(t,r,n){arguments.length<3&&(n=r,r=null);var i=ye(t,e,null==r?a:o(r),n);return i.row=function(t){return arguments.length?i.response(null==(r=t)?a:o(t)):r},i}function a(t){return i.parse(t.responseText)}function o(t){return function(e){return i.parse(e.responseText,t)}}function s(e){return e.map(l).join(t)}function l(t){return r.test(t)?'\"'+t.replace(/\\\"/g,'\"\"')+'\"':t}return i.parse=function(t,e){var r;return i.parseRows(t,function(t,n){if(r)return r(t,n-1);var i=new Function(\"d\",\"return {\"+t.map(function(t,e){return JSON.stringify(t)+\": d[\"+e+\"]\"}).join(\",\")+\"}\");r=e?function(t,r){return e(i(t),r)}:i})},i.parseRows=function(t,e){var r,i,a={},o={},s=[],l=t.length,c=0,u=0;function h(){if(c>=l)return o;if(i)return i=!1,a;var e=c;if(34===t.charCodeAt(e)){for(var r=e;r++<l;)if(34===t.charCodeAt(r)){if(34!==t.charCodeAt(r+1))break;++r}return c=r+2,13===(s=t.charCodeAt(r+1))?(i=!0,10===t.charCodeAt(r+2)&&++c):10===s&&(i=!0),t.slice(e+1,r).replace(/\"\"/g,'\"')}for(;c<l;){var s,u=1;if(10===(s=t.charCodeAt(c++)))i=!0;else if(13===s)i=!0,10===t.charCodeAt(c)&&(++c,++u);else if(s!==n)continue;return t.slice(e,c-u)}return t.slice(e)}for(;(r=h())!==o;){for(var f=[];r!==a&&r!==o;)f.push(r),r=h();e&&null==(f=e(f,u++))||s.push(f)}return s},i.format=function(e){if(Array.isArray(e[0]))return i.formatRows(e);var r=new L,n=[];return e.forEach(function(t){for(var e in t)r.has(e)||n.push(r.add(e))}),[n.map(l).join(t)].concat(e.map(function(e){return n.map(function(t){return l(e[t])}).join(t)})).join(\"\\n\")},i.formatRows=function(t){return t.map(s).join(\"\\n\")},i},t.csv=t.dsv(\",\",\"text/csv\"),t.tsv=t.dsv(\"\\t\",\"text/tab-separated-values\");var xe,be,_e,we,ke=this[z(this,\"requestAnimationFrame\")]||function(t){setTimeout(t,17)};function Te(t,e,r){var n=arguments.length;n<2&&(e=0),n<3&&(r=Date.now());var i={c:t,t:r+e,n:null};return be?be.n=i:xe=i,be=i,_e||(we=clearTimeout(we),_e=1,ke(Ae)),i}function Ae(){var t=Me(),e=Se()-t;e>24?(isFinite(e)&&(clearTimeout(we),we=setTimeout(Ae,e)),_e=0):(_e=1,ke(Ae))}function Me(){for(var t=Date.now(),e=xe;e;)t>=e.t&&e.c(t-e.t)&&(e.c=null),e=e.n;return t}function Se(){for(var t,e=xe,r=1/0;e;)e.c?(e.t<r&&(r=e.t),e=(t=e).n):e=t?t.n=e.n:xe=e.n;return be=t,r}function Ee(t,e){return e-(t?Math.ceil(Math.log(t)/Math.LN10):1)}t.timer=function(){Te.apply(this,arguments)},t.timer.flush=function(){Me(),Se()},t.round=function(t,e){return e?Math.round(t*(e=Math.pow(10,e)))/e:Math.round(t)};var Ce=[\"y\",\"z\",\"a\",\"f\",\"p\",\"n\",\"\\xb5\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\",\"P\",\"E\",\"Z\",\"Y\"].map(function(t,e){var r=Math.pow(10,3*y(8-e));return{scale:e>8?function(t){return t/r}:function(t){return t*r},symbol:t}});t.formatPrefix=function(e,r){var n=0;return(e=+e)&&(e<0&&(e*=-1),r&&(e=t.round(e,Ee(e,r))),n=1+Math.floor(1e-12+Math.log(e)/Math.LN10),n=Math.max(-24,Math.min(24,3*Math.floor((n-1)/3)))),Ce[8+n/3]};var Le=/(?:([^{])?([<>=^]))?([+\\- ])?([$#])?(0)?(\\d+)?(,)?(\\.-?\\d+)?([a-z%])?/i,Pe=t.map({b:function(t){return t.toString(2)},c:function(t){return String.fromCharCode(t)},o:function(t){return t.toString(8)},x:function(t){return t.toString(16)},X:function(t){return t.toString(16).toUpperCase()},g:function(t,e){return t.toPrecision(e)},e:function(t,e){return t.toExponential(e)},f:function(t,e){return t.toFixed(e)},r:function(e,r){return(e=t.round(e,Ee(e,r))).toFixed(Math.max(0,Math.min(20,Ee(e*(1+1e-15),r))))}});function Oe(t){return t+\"\"}var ze=t.time={},Ie=Date;function De(){this._=new Date(arguments.length>1?Date.UTC.apply(this,arguments):arguments[0])}De.prototype={getDate:function(){return this._.getUTCDate()},getDay:function(){return this._.getUTCDay()},getFullYear:function(){return this._.getUTCFullYear()},getHours:function(){return this._.getUTCHours()},getMilliseconds:function(){return this._.getUTCMilliseconds()},getMinutes:function(){return this._.getUTCMinutes()},getMonth:function(){return this._.getUTCMonth()},getSeconds:function(){return this._.getUTCSeconds()},getTime:function(){return this._.getTime()},getTimezoneOffset:function(){return 0},valueOf:function(){return this._.valueOf()},setDate:function(){Re.setUTCDate.apply(this._,arguments)},setDay:function(){Re.setUTCDay.apply(this._,arguments)},setFullYear:function(){Re.setUTCFullYear.apply(this._,arguments)},setHours:function(){Re.setUTCHours.apply(this._,arguments)},setMilliseconds:function(){Re.setUTCMilliseconds.apply(this._,arguments)},setMinutes:function(){Re.setUTCMinutes.apply(this._,arguments)},setMonth:function(){Re.setUTCMonth.apply(this._,arguments)},setSeconds:function(){Re.setUTCSeconds.apply(this._,arguments)},setTime:function(){Re.setTime.apply(this._,arguments)}};var Re=Date.prototype;function Fe(t,e,r){function n(e){var r=t(e),n=a(r,1);return e-r<n-e?r:n}function i(r){return e(r=t(new Ie(r-1)),1),r}function a(t,r){return e(t=new Ie(+t),r),t}function o(t,n,a){var o=i(t),s=[];if(a>1)for(;o<n;)r(o)%a||s.push(new Date(+o)),e(o,1);else for(;o<n;)s.push(new Date(+o)),e(o,1);return s}t.floor=t,t.round=n,t.ceil=i,t.offset=a,t.range=o;var s=t.utc=Be(t);return s.floor=s,s.round=Be(n),s.ceil=Be(i),s.offset=Be(a),s.range=function(t,e,r){try{Ie=De;var n=new De;return n._=t,o(n,e,r)}finally{Ie=Date}},t}function Be(t){return function(e,r){try{Ie=De;var n=new De;return n._=e,t(n,r)._}finally{Ie=Date}}}ze.year=Fe(function(t){return(t=ze.day(t)).setMonth(0,1),t},function(t,e){t.setFullYear(t.getFullYear()+e)},function(t){return t.getFullYear()}),ze.years=ze.year.range,ze.years.utc=ze.year.utc.range,ze.day=Fe(function(t){var e=new Ie(2e3,0);return e.setFullYear(t.getFullYear(),t.getMonth(),t.getDate()),e},function(t,e){t.setDate(t.getDate()+e)},function(t){return t.getDate()-1}),ze.days=ze.day.range,ze.days.utc=ze.day.utc.range,ze.dayOfYear=function(t){var e=ze.year(t);return Math.floor((t-e-6e4*(t.getTimezoneOffset()-e.getTimezoneOffset()))/864e5)},[\"sunday\",\"monday\",\"tuesday\",\"wednesday\",\"thursday\",\"friday\",\"saturday\"].forEach(function(t,e){e=7-e;var r=ze[t]=Fe(function(t){return(t=ze.day(t)).setDate(t.getDate()-(t.getDay()+e)%7),t},function(t,e){t.setDate(t.getDate()+7*Math.floor(e))},function(t){var r=ze.year(t).getDay();return Math.floor((ze.dayOfYear(t)+(r+e)%7)/7)-(r!==e)});ze[t+\"s\"]=r.range,ze[t+\"s\"].utc=r.utc.range,ze[t+\"OfYear\"]=function(t){var r=ze.year(t).getDay();return Math.floor((ze.dayOfYear(t)+(r+e)%7)/7)}}),ze.week=ze.sunday,ze.weeks=ze.sunday.range,ze.weeks.utc=ze.sunday.utc.range,ze.weekOfYear=ze.sundayOfYear;var Ne={\"-\":\"\",_:\" \",0:\"0\"},je=/^\\s*\\d+/,Ue=/^%/;function Ve(t,e,r){var n=t<0?\"-\":\"\",i=(n?-t:t)+\"\",a=i.length;return n+(a<r?new Array(r-a+1).join(e)+i:i)}function qe(e){return new RegExp(\"^(?:\"+e.map(t.requote).join(\"|\")+\")\",\"i\")}function He(t){for(var e=new b,r=-1,n=t.length;++r<n;)e.set(t[r].toLowerCase(),r);return e}function Ge(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+1));return n?(t.w=+n[0],r+n[0].length):-1}function Ye(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.U=+n[0],r+n[0].length):-1}function We(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.W=+n[0],r+n[0].length):-1}function Xe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+4));return n?(t.y=+n[0],r+n[0].length):-1}function Ze(t,e,r){je.lastIndex=0;var n,i=je.exec(e.slice(r,r+2));return i?(t.y=(n=+i[0])+(n>68?1900:2e3),r+i[0].length):-1}function Je(t,e,r){return/^[+-]\\d{4}$/.test(e=e.slice(r,r+5))?(t.Z=-e,r+5):-1}function Ke(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.m=n[0]-1,r+n[0].length):-1}function $e(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.d=+n[0],r+n[0].length):-1}function Qe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.j=+n[0],r+n[0].length):-1}function tr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.H=+n[0],r+n[0].length):-1}function er(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.M=+n[0],r+n[0].length):-1}function rr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.S=+n[0],r+n[0].length):-1}function nr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.L=+n[0],r+n[0].length):-1}function ir(t){var e=t.getTimezoneOffset(),r=e>0?\"-\":\"+\",n=y(e)/60|0,i=y(e)%60;return r+Ve(n,\"0\",2)+Ve(i,\"0\",2)}function ar(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r,r+1));return n?r+n[0].length:-1}function or(t){for(var e=t.length,r=-1;++r<e;)t[r][0]=this(t[r][0]);return function(e){for(var r=0,n=t[r];!n[1](e);)n=t[++r];return n[0](e)}}t.locale=function(e){return{numberFormat:function(e){var r=e.decimal,n=e.thousands,i=e.grouping,a=e.currency,o=i&&n?function(t,e){for(var r=t.length,a=[],o=0,s=i[0],l=0;r>0&&s>0&&(l+s+1>e&&(s=Math.max(1,e-l)),a.push(t.substring(r-=s,r+s)),!((l+=s+1)>e));)s=i[o=(o+1)%i.length];return a.reverse().join(n)}:P;return function(e){var n=Le.exec(e),i=n[1]||\" \",s=n[2]||\">\",l=n[3]||\"-\",c=n[4]||\"\",u=n[5],h=+n[6],f=n[7],p=n[8],d=n[9],g=1,v=\"\",m=\"\",y=!1,x=!0;switch(p&&(p=+p.substring(1)),(u||\"0\"===i&&\"=\"===s)&&(u=i=\"0\",s=\"=\"),d){case\"n\":f=!0,d=\"g\";break;case\"%\":g=100,m=\"%\",d=\"f\";break;case\"p\":g=100,m=\"%\",d=\"r\";break;case\"b\":case\"o\":case\"x\":case\"X\":\"#\"===c&&(v=\"0\"+d.toLowerCase());case\"c\":x=!1;case\"d\":y=!0,p=0;break;case\"s\":g=-1,d=\"r\"}\"$\"===c&&(v=a[0],m=a[1]),\"r\"!=d||p||(d=\"g\"),null!=p&&(\"g\"==d?p=Math.max(1,Math.min(21,p)):\"e\"!=d&&\"f\"!=d||(p=Math.max(0,Math.min(20,p)))),d=Pe.get(d)||Oe;var b=u&&f;return function(e){var n=m;if(y&&e%1)return\"\";var a=e<0||0===e&&1/e<0?(e=-e,\"-\"):\"-\"===l?\"\":l;if(g<0){var c=t.formatPrefix(e,p);e=c.scale(e),n=c.symbol+m}else e*=g;var _,w,k=(e=d(e,p)).lastIndexOf(\".\");if(k<0){var T=x?e.lastIndexOf(\"e\"):-1;T<0?(_=e,w=\"\"):(_=e.substring(0,T),w=e.substring(T))}else _=e.substring(0,k),w=r+e.substring(k+1);!u&&f&&(_=o(_,1/0));var A=v.length+_.length+w.length+(b?0:a.length),M=A<h?new Array(A=h-A+1).join(i):\"\";return b&&(_=o(M+_,M.length?h-w.length:1/0)),a+=v,e=_+w,(\"<\"===s?a+e+M:\">\"===s?M+a+e:\"^\"===s?M.substring(0,A>>=1)+a+e+M.substring(A):a+(b?e:M+e))+n}}}(e),timeFormat:function(e){var r=e.dateTime,n=e.date,i=e.time,a=e.periods,o=e.days,s=e.shortDays,l=e.months,c=e.shortMonths;function u(t){var e=t.length;function r(r){for(var n,i,a,o=[],s=-1,l=0;++s<e;)37===t.charCodeAt(s)&&(o.push(t.slice(l,s)),null!=(i=Ne[n=t.charAt(++s)])&&(n=t.charAt(++s)),(a=_[n])&&(n=a(r,null==i?\"e\"===n?\" \":\"0\":i)),o.push(n),l=s+1);return o.push(t.slice(l,s)),o.join(\"\")}return r.parse=function(e){var r={y:1900,m:0,d:1,H:0,M:0,S:0,L:0,Z:null};if(h(r,t,e,0)!=e.length)return null;\"p\"in r&&(r.H=r.H%12+12*r.p);var n=null!=r.Z&&Ie!==De,i=new(n?De:Ie);return\"j\"in r?i.setFullYear(r.y,0,r.j):\"W\"in r||\"U\"in r?(\"w\"in r||(r.w=\"W\"in r?1:0),i.setFullYear(r.y,0,1),i.setFullYear(r.y,0,\"W\"in r?(r.w+6)%7+7*r.W-(i.getDay()+5)%7:r.w+7*r.U-(i.getDay()+6)%7)):i.setFullYear(r.y,r.m,r.d),i.setHours(r.H+(r.Z/100|0),r.M+r.Z%100,r.S,r.L),n?i._:i},r.toString=function(){return t},r}function h(t,e,r,n){for(var i,a,o,s=0,l=e.length,c=r.length;s<l;){if(n>=c)return-1;if(37===(i=e.charCodeAt(s++))){if(o=e.charAt(s++),!(a=w[o in Ne?e.charAt(s++):o])||(n=a(t,r,n))<0)return-1}else if(i!=r.charCodeAt(n++))return-1}return n}u.utc=function(t){var e=u(t);function r(t){try{var r=new(Ie=De);return r._=t,e(r)}finally{Ie=Date}}return r.parse=function(t){try{Ie=De;var r=e.parse(t);return r&&r._}finally{Ie=Date}},r.toString=e.toString,r},u.multi=u.utc.multi=or;var f=t.map(),p=qe(o),d=He(o),g=qe(s),v=He(s),m=qe(l),y=He(l),x=qe(c),b=He(c);a.forEach(function(t,e){f.set(t.toLowerCase(),e)});var _={a:function(t){return s[t.getDay()]},A:function(t){return o[t.getDay()]},b:function(t){return c[t.getMonth()]},B:function(t){return l[t.getMonth()]},c:u(r),d:function(t,e){return Ve(t.getDate(),e,2)},e:function(t,e){return Ve(t.getDate(),e,2)},H:function(t,e){return Ve(t.getHours(),e,2)},I:function(t,e){return Ve(t.getHours()%12||12,e,2)},j:function(t,e){return Ve(1+ze.dayOfYear(t),e,3)},L:function(t,e){return Ve(t.getMilliseconds(),e,3)},m:function(t,e){return Ve(t.getMonth()+1,e,2)},M:function(t,e){return Ve(t.getMinutes(),e,2)},p:function(t){return a[+(t.getHours()>=12)]},S:function(t,e){return Ve(t.getSeconds(),e,2)},U:function(t,e){return Ve(ze.sundayOfYear(t),e,2)},w:function(t){return t.getDay()},W:function(t,e){return Ve(ze.mondayOfYear(t),e,2)},x:u(n),X:u(i),y:function(t,e){return Ve(t.getFullYear()%100,e,2)},Y:function(t,e){return Ve(t.getFullYear()%1e4,e,4)},Z:ir,\"%\":function(){return\"%\"}},w={a:function(t,e,r){g.lastIndex=0;var n=g.exec(e.slice(r));return n?(t.w=v.get(n[0].toLowerCase()),r+n[0].length):-1},A:function(t,e,r){p.lastIndex=0;var n=p.exec(e.slice(r));return n?(t.w=d.get(n[0].toLowerCase()),r+n[0].length):-1},b:function(t,e,r){x.lastIndex=0;var n=x.exec(e.slice(r));return n?(t.m=b.get(n[0].toLowerCase()),r+n[0].length):-1},B:function(t,e,r){m.lastIndex=0;var n=m.exec(e.slice(r));return n?(t.m=y.get(n[0].toLowerCase()),r+n[0].length):-1},c:function(t,e,r){return h(t,_.c.toString(),e,r)},d:$e,e:$e,H:tr,I:tr,j:Qe,L:nr,m:Ke,M:er,p:function(t,e,r){var n=f.get(e.slice(r,r+=2).toLowerCase());return null==n?-1:(t.p=n,r)},S:rr,U:Ye,w:Ge,W:We,x:function(t,e,r){return h(t,_.x.toString(),e,r)},X:function(t,e,r){return h(t,_.X.toString(),e,r)},y:Ze,Y:Xe,Z:Je,\"%\":ar};return u}(e)}};var sr=t.locale({decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],dateTime:\"%a %b %e %X %Y\",date:\"%m/%d/%Y\",time:\"%H:%M:%S\",periods:[\"AM\",\"PM\"],days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"]});function lr(){}t.format=sr.numberFormat,t.geo={},lr.prototype={s:0,t:0,add:function(t){ur(t,this.t,cr),ur(cr.s,this.s,this),this.s?this.t+=cr.t:this.s=cr.t},reset:function(){this.s=this.t=0},valueOf:function(){return this.s}};var cr=new lr;function ur(t,e,r){var n=r.s=t+e,i=n-t,a=n-i;r.t=t-a+(e-i)}function hr(t,e){t&&pr.hasOwnProperty(t.type)&&pr[t.type](t,e)}t.geo.stream=function(t,e){t&&fr.hasOwnProperty(t.type)?fr[t.type](t,e):hr(t,e)};var fr={Feature:function(t,e){hr(t.geometry,e)},FeatureCollection:function(t,e){for(var r=t.features,n=-1,i=r.length;++n<i;)hr(r[n].geometry,e)}},pr={Sphere:function(t,e){e.sphere()},Point:function(t,e){t=t.coordinates,e.point(t[0],t[1],t[2])},MultiPoint:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)t=r[n],e.point(t[0],t[1],t[2])},LineString:function(t,e){dr(t.coordinates,e,0)},MultiLineString:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)dr(r[n],e,0)},Polygon:function(t,e){gr(t.coordinates,e)},MultiPolygon:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)gr(r[n],e)},GeometryCollection:function(t,e){for(var r=t.geometries,n=-1,i=r.length;++n<i;)hr(r[n],e)}};function dr(t,e,r){var n,i=-1,a=t.length-r;for(e.lineStart();++i<a;)n=t[i],e.point(n[0],n[1],n[2]);e.lineEnd()}function gr(t,e){var r=-1,n=t.length;for(e.polygonStart();++r<n;)dr(t[r],e,1);e.polygonEnd()}t.geo.area=function(e){return vr=0,t.geo.stream(e,Cr),vr};var vr,mr,yr,xr,br,_r,wr,kr,Tr,Ar,Mr,Sr,Er=new lr,Cr={sphere:function(){vr+=4*At},point:D,lineStart:D,lineEnd:D,polygonStart:function(){Er.reset(),Cr.lineStart=Lr},polygonEnd:function(){var t=2*Er;vr+=t<0?4*At+t:t,Cr.lineStart=Cr.lineEnd=Cr.point=D}};function Lr(){var t,e,r,n,i;function a(t,e){e=e*Ct/2+At/4;var a=(t*=Ct)-r,o=a>=0?1:-1,s=o*a,l=Math.cos(e),c=Math.sin(e),u=i*c,h=n*l+u*Math.cos(s),f=u*o*Math.sin(s);Er.add(Math.atan2(f,h)),r=t,n=l,i=c}Cr.point=function(o,s){Cr.point=a,r=(t=o)*Ct,n=Math.cos(s=(e=s)*Ct/2+At/4),i=Math.sin(s)},Cr.lineEnd=function(){a(t,e)}}function Pr(t){var e=t[0],r=t[1],n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}function Or(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}function zr(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}function Ir(t,e){t[0]+=e[0],t[1]+=e[1],t[2]+=e[2]}function Dr(t,e){return[t[0]*e,t[1]*e,t[2]*e]}function Rr(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]+t[2]*t[2]);t[0]/=e,t[1]/=e,t[2]/=e}function Fr(t){return[Math.atan2(t[1],t[0]),It(t[2])]}function Br(t,e){return y(t[0]-e[0])<kt&&y(t[1]-e[1])<kt}t.geo.bounds=function(){var e,r,n,i,a,o,s,l,c,u,h,f={point:p,lineStart:g,lineEnd:v,polygonStart:function(){f.point=m,f.lineStart=x,f.lineEnd=b,c=0,Cr.polygonStart()},polygonEnd:function(){Cr.polygonEnd(),f.point=p,f.lineStart=g,f.lineEnd=v,Er<0?(e=-(n=180),r=-(i=90)):c>kt?i=90:c<-kt&&(r=-90),h[0]=e,h[1]=n}};function p(t,a){u.push(h=[e=t,n=t]),a<r&&(r=a),a>i&&(i=a)}function d(t,o){var s=Pr([t*Ct,o*Ct]);if(l){var c=zr(l,s),u=zr([c[1],-c[0],0],c);Rr(u),u=Fr(u);var h=t-a,f=h>0?1:-1,d=u[0]*Lt*f,g=y(h)>180;if(g^(f*a<d&&d<f*t))(v=u[1]*Lt)>i&&(i=v);else if(g^(f*a<(d=(d+360)%360-180)&&d<f*t)){var v;(v=-u[1]*Lt)<r&&(r=v)}else o<r&&(r=o),o>i&&(i=o);g?t<a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t):n>=e?(t<e&&(e=t),t>n&&(n=t)):t>a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t)}else p(t,o);l=s,a=t}function g(){f.point=d}function v(){h[0]=e,h[1]=n,f.point=p,l=null}function m(t,e){if(l){var r=t-a;c+=y(r)>180?r+(r>0?360:-360):r}else o=t,s=e;Cr.point(t,e),d(t,e)}function x(){Cr.lineStart()}function b(){m(o,s),Cr.lineEnd(),y(c)>kt&&(e=-(n=180)),h[0]=e,h[1]=n,l=null}function _(t,e){return(e-=t)<0?e+360:e}function w(t,e){return t[0]-e[0]}function k(t,e){return e[0]<=e[1]?e[0]<=t&&t<=e[1]:t<e[0]||e[1]<t}return function(a){if(i=n=-(e=r=1/0),u=[],t.geo.stream(a,f),c=u.length){u.sort(w);for(var o=1,s=[g=u[0]];o<c;++o)k((p=u[o])[0],g)||k(p[1],g)?(_(g[0],p[1])>_(g[0],g[1])&&(g[1]=p[1]),_(p[0],g[1])>_(g[0],g[1])&&(g[0]=p[0])):s.push(g=p);for(var l,c,p,d=-1/0,g=(o=0,s[c=s.length-1]);o<=c;g=p,++o)p=s[o],(l=_(g[1],p[0]))>d&&(d=l,e=p[0],n=g[1])}return u=h=null,e===1/0||r===1/0?[[NaN,NaN],[NaN,NaN]]:[[e,r],[n,i]]}}(),t.geo.centroid=function(e){mr=yr=xr=br=_r=wr=kr=Tr=Ar=Mr=Sr=0,t.geo.stream(e,Nr);var r=Ar,n=Mr,i=Sr,a=r*r+n*n+i*i;return a<Tt&&(r=wr,n=kr,i=Tr,yr<kt&&(r=xr,n=br,i=_r),(a=r*r+n*n+i*i)<Tt)?[NaN,NaN]:[Math.atan2(n,r)*Lt,It(i/Math.sqrt(a))*Lt]};var Nr={sphere:D,point:jr,lineStart:Vr,lineEnd:qr,polygonStart:function(){Nr.lineStart=Hr},polygonEnd:function(){Nr.lineStart=Vr}};function jr(t,e){t*=Ct;var r=Math.cos(e*=Ct);Ur(r*Math.cos(t),r*Math.sin(t),Math.sin(e))}function Ur(t,e,r){xr+=(t-xr)/++mr,br+=(e-br)/mr,_r+=(r-_r)/mr}function Vr(){var t,e,r;function n(n,i){n*=Ct;var a=Math.cos(i*=Ct),o=a*Math.cos(n),s=a*Math.sin(n),l=Math.sin(i),c=Math.atan2(Math.sqrt((c=e*l-r*s)*c+(c=r*o-t*l)*c+(c=t*s-e*o)*c),t*o+e*s+r*l);yr+=c,wr+=c*(t+(t=o)),kr+=c*(e+(e=s)),Tr+=c*(r+(r=l)),Ur(t,e,r)}Nr.point=function(i,a){i*=Ct;var o=Math.cos(a*=Ct);t=o*Math.cos(i),e=o*Math.sin(i),r=Math.sin(a),Nr.point=n,Ur(t,e,r)}}function qr(){Nr.point=jr}function Hr(){var t,e,r,n,i;function a(t,e){t*=Ct;var a=Math.cos(e*=Ct),o=a*Math.cos(t),s=a*Math.sin(t),l=Math.sin(e),c=n*l-i*s,u=i*o-r*l,h=r*s-n*o,f=Math.sqrt(c*c+u*u+h*h),p=r*o+n*s+i*l,d=f&&-zt(p)/f,g=Math.atan2(f,p);Ar+=d*c,Mr+=d*u,Sr+=d*h,yr+=g,wr+=g*(r+(r=o)),kr+=g*(n+(n=s)),Tr+=g*(i+(i=l)),Ur(r,n,i)}Nr.point=function(o,s){t=o,e=s,Nr.point=a,o*=Ct;var l=Math.cos(s*=Ct);r=l*Math.cos(o),n=l*Math.sin(o),i=Math.sin(s),Ur(r,n,i)},Nr.lineEnd=function(){a(t,e),Nr.lineEnd=qr,Nr.point=jr}}function Gr(t,e){function r(r,n){return r=t(r,n),e(r[0],r[1])}return t.invert&&e.invert&&(r.invert=function(r,n){return(r=e.invert(r,n))&&t.invert(r[0],r[1])}),r}function Yr(){return!0}function Wr(t,e,r,n,i){var a=[],o=[];if(t.forEach(function(t){if(!((e=t.length-1)<=0)){var e,r=t[0],n=t[e];if(Br(r,n)){i.lineStart();for(var s=0;s<e;++s)i.point((r=t[s])[0],r[1]);i.lineEnd()}else{var l=new Zr(r,t,null,!0),c=new Zr(r,null,l,!1);l.o=c,a.push(l),o.push(c),l=new Zr(n,t,null,!1),c=new Zr(n,null,l,!0),l.o=c,a.push(l),o.push(c)}}}),o.sort(e),Xr(a),Xr(o),a.length){for(var s=0,l=r,c=o.length;s<c;++s)o[s].e=l=!l;for(var u,h,f=a[0];;){for(var p=f,d=!0;p.v;)if((p=p.n)===f)return;u=p.z,i.lineStart();do{if(p.v=p.o.v=!0,p.e){if(d)for(s=0,c=u.length;s<c;++s)i.point((h=u[s])[0],h[1]);else n(p.x,p.n.x,1,i);p=p.n}else{if(d)for(s=(u=p.p.z).length-1;s>=0;--s)i.point((h=u[s])[0],h[1]);else n(p.x,p.p.x,-1,i);p=p.p}u=(p=p.o).z,d=!d}while(!p.v);i.lineEnd()}}}function Xr(t){if(e=t.length){for(var e,r,n=0,i=t[0];++n<e;)i.n=r=t[n],r.p=i,i=r;i.n=r=t[0],r.p=i}}function Zr(t,e,r,n){this.x=t,this.z=e,this.o=r,this.e=n,this.v=!1,this.n=this.p=null}function Jr(e,r,n,i){return function(a,o){var s,l=r(o),c=a.invert(i[0],i[1]),u={point:h,lineStart:p,lineEnd:d,polygonStart:function(){u.point=b,u.lineStart=_,u.lineEnd=w,s=[],g=[]},polygonEnd:function(){u.point=h,u.lineStart=p,u.lineEnd=d,s=t.merge(s);var e=function(t,e){var r=t[0],n=t[1],i=[Math.sin(r),-Math.cos(r),0],a=0,o=0;Er.reset();for(var s=0,l=e.length;s<l;++s){var c=e[s],u=c.length;if(u)for(var h=c[0],f=h[0],p=h[1]/2+At/4,d=Math.sin(p),g=Math.cos(p),v=1;;){v===u&&(v=0);var m=(t=c[v])[0],y=t[1]/2+At/4,x=Math.sin(y),b=Math.cos(y),_=m-f,w=_>=0?1:-1,k=w*_,T=k>At,A=d*x;if(Er.add(Math.atan2(A*w*Math.sin(k),g*b+A*Math.cos(k))),a+=T?_+w*Mt:_,T^f>=r^m>=r){var M=zr(Pr(h),Pr(t));Rr(M);var S=zr(i,M);Rr(S);var E=(T^_>=0?-1:1)*It(S[2]);(n>E||n===E&&(M[0]||M[1]))&&(o+=T^_>=0?1:-1)}if(!v++)break;f=m,d=x,g=b,h=t}}return(a<-kt||a<kt&&Er<-kt)^1&o}(c,g);s.length?(x||(o.polygonStart(),x=!0),Wr(s,Qr,e,n,o)):e&&(x||(o.polygonStart(),x=!0),o.lineStart(),n(null,null,1,o),o.lineEnd()),x&&(o.polygonEnd(),x=!1),s=g=null},sphere:function(){o.polygonStart(),o.lineStart(),n(null,null,1,o),o.lineEnd(),o.polygonEnd()}};function h(t,r){var n=a(t,r);e(t=n[0],r=n[1])&&o.point(t,r)}function f(t,e){var r=a(t,e);l.point(r[0],r[1])}function p(){u.point=f,l.lineStart()}function d(){u.point=h,l.lineEnd()}var g,v,m=$r(),y=r(m),x=!1;function b(t,e){v.push([t,e]);var r=a(t,e);y.point(r[0],r[1])}function _(){y.lineStart(),v=[]}function w(){b(v[0][0],v[0][1]),y.lineEnd();var t,e=y.clean(),r=m.buffer(),n=r.length;if(v.pop(),g.push(v),v=null,n)if(1&e){var i,a=-1;if((n=(t=r[0]).length-1)>0){for(x||(o.polygonStart(),x=!0),o.lineStart();++a<n;)o.point((i=t[a])[0],i[1]);o.lineEnd()}}else n>1&&2&e&&r.push(r.pop().concat(r.shift())),s.push(r.filter(Kr))}return u}}function Kr(t){return t.length>1}function $r(){var t,e=[];return{lineStart:function(){e.push(t=[])},point:function(e,r){t.push([e,r])},lineEnd:D,buffer:function(){var r=e;return e=[],t=null,r},rejoin:function(){e.length>1&&e.push(e.pop().concat(e.shift()))}}}function Qr(t,e){return((t=t.x)[0]<0?t[1]-Et-kt:Et-t[1])-((e=e.x)[0]<0?e[1]-Et-kt:Et-e[1])}var tn=Jr(Yr,function(t){var e,r=NaN,n=NaN,i=NaN;return{lineStart:function(){t.lineStart(),e=1},point:function(a,o){var s=a>0?At:-At,l=y(a-r);y(l-At)<kt?(t.point(r,n=(n+o)/2>0?Et:-Et),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),t.point(a,n),e=0):i!==s&&l>=At&&(y(r-i)<kt&&(r-=i*kt),y(a-s)<kt&&(a-=s*kt),n=function(t,e,r,n){var i,a,o=Math.sin(t-r);return y(o)>kt?Math.atan((Math.sin(e)*(a=Math.cos(n))*Math.sin(r)-Math.sin(n)*(i=Math.cos(e))*Math.sin(t))/(i*a*o)):(e+n)/2}(r,n,a,o),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),e=0),t.point(r=a,n=o),i=s},lineEnd:function(){t.lineEnd(),r=n=NaN},clean:function(){return 2-e}}},function(t,e,r,n){var i;if(null==t)i=r*Et,n.point(-At,i),n.point(0,i),n.point(At,i),n.point(At,0),n.point(At,-i),n.point(0,-i),n.point(-At,-i),n.point(-At,0),n.point(-At,i);else if(y(t[0]-e[0])>kt){var a=t[0]<e[0]?At:-At;i=r*a/2,n.point(-a,i),n.point(0,i),n.point(a,i)}else n.point(e[0],e[1])},[-At,-At/2]);function en(t,e,r,n){return function(i){var a,o=i.a,s=i.b,l=o.x,c=o.y,u=0,h=1,f=s.x-l,p=s.y-c;if(a=t-l,f||!(a>0)){if(a/=f,f<0){if(a<u)return;a<h&&(h=a)}else if(f>0){if(a>h)return;a>u&&(u=a)}if(a=r-l,f||!(a<0)){if(a/=f,f<0){if(a>h)return;a>u&&(u=a)}else if(f>0){if(a<u)return;a<h&&(h=a)}if(a=e-c,p||!(a>0)){if(a/=p,p<0){if(a<u)return;a<h&&(h=a)}else if(p>0){if(a>h)return;a>u&&(u=a)}if(a=n-c,p||!(a<0)){if(a/=p,p<0){if(a>h)return;a>u&&(u=a)}else if(p>0){if(a<u)return;a<h&&(h=a)}return u>0&&(i.a={x:l+u*f,y:c+u*p}),h<1&&(i.b={x:l+h*f,y:c+h*p}),i}}}}}}var rn=1e9;function nn(e,r,n,i){return function(l){var c,u,h,f,p,d,g,v,m,y,x,b=l,_=$r(),w=en(e,r,n,i),k={point:M,lineStart:function(){k.point=S,u&&u.push(h=[]);y=!0,m=!1,g=v=NaN},lineEnd:function(){c&&(S(f,p),d&&m&&_.rejoin(),c.push(_.buffer()));k.point=M,m&&l.lineEnd()},polygonStart:function(){l=_,c=[],u=[],x=!0},polygonEnd:function(){l=b,c=t.merge(c);var r=function(t){for(var e=0,r=u.length,n=t[1],i=0;i<r;++i)for(var a,o=1,s=u[i],l=s.length,c=s[0];o<l;++o)a=s[o],c[1]<=n?a[1]>n&&Ot(c,a,t)>0&&++e:a[1]<=n&&Ot(c,a,t)<0&&--e,c=a;return 0!==e}([e,i]),n=x&&r,a=c.length;(n||a)&&(l.polygonStart(),n&&(l.lineStart(),T(null,null,1,l),l.lineEnd()),a&&Wr(c,o,r,T,l),l.polygonEnd()),c=u=h=null}};function T(t,o,l,c){var u=0,h=0;if(null==t||(u=a(t,l))!==(h=a(o,l))||s(t,o)<0^l>0)do{c.point(0===u||3===u?e:n,u>1?i:r)}while((u=(u+l+4)%4)!==h);else c.point(o[0],o[1])}function A(t,a){return e<=t&&t<=n&&r<=a&&a<=i}function M(t,e){A(t,e)&&l.point(t,e)}function S(t,e){var r=A(t=Math.max(-rn,Math.min(rn,t)),e=Math.max(-rn,Math.min(rn,e)));if(u&&h.push([t,e]),y)f=t,p=e,d=r,y=!1,r&&(l.lineStart(),l.point(t,e));else if(r&&m)l.point(t,e);else{var n={a:{x:g,y:v},b:{x:t,y:e}};w(n)?(m||(l.lineStart(),l.point(n.a.x,n.a.y)),l.point(n.b.x,n.b.y),r||l.lineEnd(),x=!1):r&&(l.lineStart(),l.point(t,e),x=!1)}g=t,v=e,m=r}return k};function a(t,i){return y(t[0]-e)<kt?i>0?0:3:y(t[0]-n)<kt?i>0?2:1:y(t[1]-r)<kt?i>0?1:0:i>0?3:2}function o(t,e){return s(t.x,e.x)}function s(t,e){var r=a(t,1),n=a(e,1);return r!==n?r-n:0===r?e[1]-t[1]:1===r?t[0]-e[0]:2===r?t[1]-e[1]:e[0]-t[0]}}function an(t){var e=0,r=At/3,n=Cn(t),i=n(e,r);return i.parallels=function(t){return arguments.length?n(e=t[0]*At/180,r=t[1]*At/180):[e/At*180,r/At*180]},i}function on(t,e){var r=Math.sin(t),n=(r+Math.sin(e))/2,i=1+r*(2*n-r),a=Math.sqrt(i)/n;function o(t,e){var r=Math.sqrt(i-2*n*Math.sin(e))/n;return[r*Math.sin(t*=n),a-r*Math.cos(t)]}return o.invert=function(t,e){var r=a-e;return[Math.atan2(t,r)/n,It((i-(t*t+r*r)*n*n)/(2*n))]},o}t.geo.clipExtent=function(){var t,e,r,n,i,a,o={stream:function(t){return i&&(i.valid=!1),(i=a(t)).valid=!0,i},extent:function(s){return arguments.length?(a=nn(t=+s[0][0],e=+s[0][1],r=+s[1][0],n=+s[1][1]),i&&(i.valid=!1,i=null),o):[[t,e],[r,n]]}};return o.extent([[0,0],[960,500]])},(t.geo.conicEqualArea=function(){return an(on)}).raw=on,t.geo.albers=function(){return t.geo.conicEqualArea().rotate([96,0]).center([-.6,38.7]).parallels([29.5,45.5]).scale(1070)},t.geo.albersUsa=function(){var e,r,n,i,a=t.geo.albers(),o=t.geo.conicEqualArea().rotate([154,0]).center([-2,58.5]).parallels([55,65]),s=t.geo.conicEqualArea().rotate([157,0]).center([-3,19.9]).parallels([8,18]),l={point:function(t,r){e=[t,r]}};function c(t){var a=t[0],o=t[1];return e=null,r(a,o),e||(n(a,o),e)||i(a,o),e}return c.invert=function(t){var e=a.scale(),r=a.translate(),n=(t[0]-r[0])/e,i=(t[1]-r[1])/e;return(i>=.12&&i<.234&&n>=-.425&&n<-.214?o:i>=.166&&i<.234&&n>=-.214&&n<-.115?s:a).invert(t)},c.stream=function(t){var e=a.stream(t),r=o.stream(t),n=s.stream(t);return{point:function(t,i){e.point(t,i),r.point(t,i),n.point(t,i)},sphere:function(){e.sphere(),r.sphere(),n.sphere()},lineStart:function(){e.lineStart(),r.lineStart(),n.lineStart()},lineEnd:function(){e.lineEnd(),r.lineEnd(),n.lineEnd()},polygonStart:function(){e.polygonStart(),r.polygonStart(),n.polygonStart()},polygonEnd:function(){e.polygonEnd(),r.polygonEnd(),n.polygonEnd()}}},c.precision=function(t){return arguments.length?(a.precision(t),o.precision(t),s.precision(t),c):a.precision()},c.scale=function(t){return arguments.length?(a.scale(t),o.scale(.35*t),s.scale(t),c.translate(a.translate())):a.scale()},c.translate=function(t){if(!arguments.length)return a.translate();var e=a.scale(),u=+t[0],h=+t[1];return r=a.translate(t).clipExtent([[u-.455*e,h-.238*e],[u+.455*e,h+.238*e]]).stream(l).point,n=o.translate([u-.307*e,h+.201*e]).clipExtent([[u-.425*e+kt,h+.12*e+kt],[u-.214*e-kt,h+.234*e-kt]]).stream(l).point,i=s.translate([u-.205*e,h+.212*e]).clipExtent([[u-.214*e+kt,h+.166*e+kt],[u-.115*e-kt,h+.234*e-kt]]).stream(l).point,c},c.scale(1070)};var sn,ln,cn,un,hn,fn,pn={point:D,lineStart:D,lineEnd:D,polygonStart:function(){ln=0,pn.lineStart=dn},polygonEnd:function(){pn.lineStart=pn.lineEnd=pn.point=D,sn+=y(ln/2)}};function dn(){var t,e,r,n;function i(t,e){ln+=n*t-r*e,r=t,n=e}pn.point=function(a,o){pn.point=i,t=r=a,e=n=o},pn.lineEnd=function(){i(t,e)}}var gn={point:function(t,e){t<cn&&(cn=t);t>hn&&(hn=t);e<un&&(un=e);e>fn&&(fn=e)},lineStart:D,lineEnd:D,polygonStart:D,polygonEnd:D};function vn(){var t=mn(4.5),e=[],r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(e){return t=mn(e),r},result:function(){if(e.length){var t=e.join(\"\");return e=[],t}}};function n(r,n){e.push(\"M\",r,\",\",n,t)}function i(t,n){e.push(\"M\",t,\",\",n),r.point=a}function a(t,r){e.push(\"L\",t,\",\",r)}function o(){r.point=n}function s(){e.push(\"Z\")}return r}function mn(t){return\"m0,\"+t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+-2*t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+2*t+\"z\"}var yn,xn={point:bn,lineStart:_n,lineEnd:wn,polygonStart:function(){xn.lineStart=kn},polygonEnd:function(){xn.point=bn,xn.lineStart=_n,xn.lineEnd=wn}};function bn(t,e){xr+=t,br+=e,++_r}function _n(){var t,e;function r(r,n){var i=r-t,a=n-e,o=Math.sqrt(i*i+a*a);wr+=o*(t+r)/2,kr+=o*(e+n)/2,Tr+=o,bn(t=r,e=n)}xn.point=function(n,i){xn.point=r,bn(t=n,e=i)}}function wn(){xn.point=bn}function kn(){var t,e,r,n;function i(t,e){var i=t-r,a=e-n,o=Math.sqrt(i*i+a*a);wr+=o*(r+t)/2,kr+=o*(n+e)/2,Tr+=o,Ar+=(o=n*t-r*e)*(r+t),Mr+=o*(n+e),Sr+=3*o,bn(r=t,n=e)}xn.point=function(a,o){xn.point=i,bn(t=r=a,e=n=o)},xn.lineEnd=function(){i(t,e)}}function Tn(t){var e=4.5,r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(t){return e=t,r},result:D};function n(r,n){t.moveTo(r+e,n),t.arc(r,n,e,0,Mt)}function i(e,n){t.moveTo(e,n),r.point=a}function a(e,r){t.lineTo(e,r)}function o(){r.point=n}function s(){t.closePath()}return r}function An(t){var e=.5,r=Math.cos(30*Ct),n=16;function i(e){return(n?function(e){var r,i,o,s,l,c,u,h,f,p,d,g,v={point:m,lineStart:y,lineEnd:b,polygonStart:function(){e.polygonStart(),v.lineStart=_},polygonEnd:function(){e.polygonEnd(),v.lineStart=y}};function m(r,n){r=t(r,n),e.point(r[0],r[1])}function y(){h=NaN,v.point=x,e.lineStart()}function x(r,i){var o=Pr([r,i]),s=t(r,i);a(h,f,u,p,d,g,h=s[0],f=s[1],u=r,p=o[0],d=o[1],g=o[2],n,e),e.point(h,f)}function b(){v.point=m,e.lineEnd()}function _(){y(),v.point=w,v.lineEnd=k}function w(t,e){x(r=t,e),i=h,o=f,s=p,l=d,c=g,v.point=x}function k(){a(h,f,u,p,d,g,i,o,r,s,l,c,n,e),v.lineEnd=b,b()}return v}:function(e){return Sn(e,function(r,n){r=t(r,n),e.point(r[0],r[1])})})(e)}function a(n,i,o,s,l,c,u,h,f,p,d,g,v,m){var x=u-n,b=h-i,_=x*x+b*b;if(_>4*e&&v--){var w=s+p,k=l+d,T=c+g,A=Math.sqrt(w*w+k*k+T*T),M=Math.asin(T/=A),S=y(y(T)-1)<kt||y(o-f)<kt?(o+f)/2:Math.atan2(k,w),E=t(S,M),C=E[0],L=E[1],P=C-n,O=L-i,z=b*P-x*O;(z*z/_>e||y((x*P+b*O)/_-.5)>.3||s*p+l*d+c*g<r)&&(a(n,i,o,s,l,c,C,L,S,w/=A,k/=A,T,v,m),m.point(C,L),a(C,L,S,w,k,T,u,h,f,p,d,g,v,m))}}return i.precision=function(t){return arguments.length?(n=(e=t*t)>0&&16,i):Math.sqrt(e)},i}function Mn(t){this.stream=t}function Sn(t,e){return{point:e,sphere:function(){t.sphere()},lineStart:function(){t.lineStart()},lineEnd:function(){t.lineEnd()},polygonStart:function(){t.polygonStart()},polygonEnd:function(){t.polygonEnd()}}}function En(t){return Cn(function(){return t})()}function Cn(e){var r,n,i,a,o,s,l=An(function(t,e){return[(t=r(t,e))[0]*c+a,o-t[1]*c]}),c=150,u=480,h=250,f=0,p=0,d=0,g=0,v=0,m=tn,x=P,b=null,_=null;function w(t){return[(t=i(t[0]*Ct,t[1]*Ct))[0]*c+a,o-t[1]*c]}function k(t){return(t=i.invert((t[0]-a)/c,(o-t[1])/c))&&[t[0]*Lt,t[1]*Lt]}function T(){i=Gr(n=zn(d,g,v),r);var t=r(f,p);return a=u-t[0]*c,o=h+t[1]*c,A()}function A(){return s&&(s.valid=!1,s=null),w}return w.stream=function(t){return s&&(s.valid=!1),(s=Ln(m(n,l(x(t))))).valid=!0,s},w.clipAngle=function(t){return arguments.length?(m=null==t?(b=t,tn):function(t){var e=Math.cos(t),r=e>0,n=y(e)>kt;return Jr(i,function(t){var e,s,l,c,u;return{lineStart:function(){c=l=!1,u=1},point:function(h,f){var p,d=[h,f],g=i(h,f),v=r?g?0:o(h,f):g?o(h+(h<0?At:-At),f):0;if(!e&&(c=l=g)&&t.lineStart(),g!==l&&(p=a(e,d),(Br(e,p)||Br(d,p))&&(d[0]+=kt,d[1]+=kt,g=i(d[0],d[1]))),g!==l)u=0,g?(t.lineStart(),p=a(d,e),t.point(p[0],p[1])):(p=a(e,d),t.point(p[0],p[1]),t.lineEnd()),e=p;else if(n&&e&&r^g){var m;v&s||!(m=a(d,e,!0))||(u=0,r?(t.lineStart(),t.point(m[0][0],m[0][1]),t.point(m[1][0],m[1][1]),t.lineEnd()):(t.point(m[1][0],m[1][1]),t.lineEnd(),t.lineStart(),t.point(m[0][0],m[0][1])))}!g||e&&Br(e,d)||t.point(d[0],d[1]),e=d,l=g,s=v},lineEnd:function(){l&&t.lineEnd(),e=null},clean:function(){return u|(c&&l)<<1}}},Fn(t,6*Ct),r?[0,-t]:[-At,t-At]);function i(t,r){return Math.cos(t)*Math.cos(r)>e}function a(t,r,n){var i=[1,0,0],a=zr(Pr(t),Pr(r)),o=Or(a,a),s=a[0],l=o-s*s;if(!l)return!n&&t;var c=e*o/l,u=-e*s/l,h=zr(i,a),f=Dr(i,c);Ir(f,Dr(a,u));var p=h,d=Or(f,p),g=Or(p,p),v=d*d-g*(Or(f,f)-1);if(!(v<0)){var m=Math.sqrt(v),x=Dr(p,(-d-m)/g);if(Ir(x,f),x=Fr(x),!n)return x;var b,_=t[0],w=r[0],k=t[1],T=r[1];w<_&&(b=_,_=w,w=b);var A=w-_,M=y(A-At)<kt;if(!M&&T<k&&(b=k,k=T,T=b),M||A<kt?M?k+T>0^x[1]<(y(x[0]-_)<kt?k:T):k<=x[1]&&x[1]<=T:A>At^(_<=x[0]&&x[0]<=w)){var S=Dr(p,(-d+m)/g);return Ir(S,f),[x,Fr(S)]}}}function o(e,n){var i=r?t:At-t,a=0;return e<-i?a|=1:e>i&&(a|=2),n<-i?a|=4:n>i&&(a|=8),a}}((b=+t)*Ct),A()):b},w.clipExtent=function(t){return arguments.length?(_=t,x=t?nn(t[0][0],t[0][1],t[1][0],t[1][1]):P,A()):_},w.scale=function(t){return arguments.length?(c=+t,T()):c},w.translate=function(t){return arguments.length?(u=+t[0],h=+t[1],T()):[u,h]},w.center=function(t){return arguments.length?(f=t[0]%360*Ct,p=t[1]%360*Ct,T()):[f*Lt,p*Lt]},w.rotate=function(t){return arguments.length?(d=t[0]%360*Ct,g=t[1]%360*Ct,v=t.length>2?t[2]%360*Ct:0,T()):[d*Lt,g*Lt,v*Lt]},t.rebind(w,l,\"precision\"),function(){return r=e.apply(this,arguments),w.invert=r.invert&&k,T()}}function Ln(t){return Sn(t,function(e,r){t.point(e*Ct,r*Ct)})}function Pn(t,e){return[t,e]}function On(t,e){return[t>At?t-Mt:t<-At?t+Mt:t,e]}function zn(t,e,r){return t?e||r?Gr(Dn(t),Rn(e,r)):Dn(t):e||r?Rn(e,r):On}function In(t){return function(e,r){return[(e+=t)>At?e-Mt:e<-At?e+Mt:e,r]}}function Dn(t){var e=In(t);return e.invert=In(-t),e}function Rn(t,e){var r=Math.cos(t),n=Math.sin(t),i=Math.cos(e),a=Math.sin(e);function o(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*r+s*n;return[Math.atan2(l*i-u*a,s*r-c*n),It(u*i+l*a)]}return o.invert=function(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*i-l*a;return[Math.atan2(l*i+c*a,s*r+u*n),It(u*r-s*n)]},o}function Fn(t,e){var r=Math.cos(t),n=Math.sin(t);return function(i,a,o,s){var l=o*e;null!=i?(i=Bn(r,i),a=Bn(r,a),(o>0?i<a:i>a)&&(i+=o*Mt)):(i=t+o*Mt,a=t-.5*l);for(var c,u=i;o>0?u>a:u<a;u-=l)s.point((c=Fr([r,-n*Math.cos(u),-n*Math.sin(u)]))[0],c[1])}}function Bn(t,e){var r=Pr(e);r[0]-=t,Rr(r);var n=zt(-r[1]);return((-r[2]<0?-n:n)+2*Math.PI-kt)%(2*Math.PI)}function Nn(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map(function(e){return[t,e]})}}function jn(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map(function(e){return[e,t]})}}function Un(t){return t.source}function Vn(t){return t.target}t.geo.path=function(){var e,r,n,i,a,o=4.5;function s(e){return e&&(\"function\"==typeof o&&i.pointRadius(+o.apply(this,arguments)),a&&a.valid||(a=n(i)),t.geo.stream(e,a)),i.result()}function l(){return a=null,s}return s.area=function(e){return sn=0,t.geo.stream(e,n(pn)),sn},s.centroid=function(e){return xr=br=_r=wr=kr=Tr=Ar=Mr=Sr=0,t.geo.stream(e,n(xn)),Sr?[Ar/Sr,Mr/Sr]:Tr?[wr/Tr,kr/Tr]:_r?[xr/_r,br/_r]:[NaN,NaN]},s.bounds=function(e){return hn=fn=-(cn=un=1/0),t.geo.stream(e,n(gn)),[[cn,un],[hn,fn]]},s.projection=function(t){return arguments.length?(n=(e=t)?t.stream||(r=t,i=An(function(t,e){return r([t*Lt,e*Lt])}),function(t){return Ln(i(t))}):P,l()):e;var r,i},s.context=function(t){return arguments.length?(i=null==(r=t)?new vn:new Tn(t),\"function\"!=typeof o&&i.pointRadius(o),l()):r},s.pointRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:(i.pointRadius(+t),+t),s):o},s.projection(t.geo.albersUsa()).context(null)},t.geo.transform=function(t){return{stream:function(e){var r=new Mn(e);for(var n in t)r[n]=t[n];return r}}},Mn.prototype={point:function(t,e){this.stream.point(t,e)},sphere:function(){this.stream.sphere()},lineStart:function(){this.stream.lineStart()},lineEnd:function(){this.stream.lineEnd()},polygonStart:function(){this.stream.polygonStart()},polygonEnd:function(){this.stream.polygonEnd()}},t.geo.projection=En,t.geo.projectionMutator=Cn,(t.geo.equirectangular=function(){return En(Pn)}).raw=Pn.invert=Pn,t.geo.rotation=function(t){function e(e){return(e=t(e[0]*Ct,e[1]*Ct))[0]*=Lt,e[1]*=Lt,e}return t=zn(t[0]%360*Ct,t[1]*Ct,t.length>2?t[2]*Ct:0),e.invert=function(e){return(e=t.invert(e[0]*Ct,e[1]*Ct))[0]*=Lt,e[1]*=Lt,e},e},On.invert=Pn,t.geo.circle=function(){var t,e,r=[0,0],n=6;function i(){var t=\"function\"==typeof r?r.apply(this,arguments):r,n=zn(-t[0]*Ct,-t[1]*Ct,0).invert,i=[];return e(null,null,1,{point:function(t,e){i.push(t=n(t,e)),t[0]*=Lt,t[1]*=Lt}}),{type:\"Polygon\",coordinates:[i]}}return i.origin=function(t){return arguments.length?(r=t,i):r},i.angle=function(r){return arguments.length?(e=Fn((t=+r)*Ct,n*Ct),i):t},i.precision=function(r){return arguments.length?(e=Fn(t*Ct,(n=+r)*Ct),i):n},i.angle(90)},t.geo.distance=function(t,e){var r,n=(e[0]-t[0])*Ct,i=t[1]*Ct,a=e[1]*Ct,o=Math.sin(n),s=Math.cos(n),l=Math.sin(i),c=Math.cos(i),u=Math.sin(a),h=Math.cos(a);return Math.atan2(Math.sqrt((r=h*o)*r+(r=c*u-l*h*s)*r),l*u+c*h*s)},t.geo.graticule=function(){var e,r,n,i,a,o,s,l,c,u,h,f,p=10,d=p,g=90,v=360,m=2.5;function x(){return{type:\"MultiLineString\",coordinates:b()}}function b(){return t.range(Math.ceil(i/g)*g,n,g).map(h).concat(t.range(Math.ceil(l/v)*v,s,v).map(f)).concat(t.range(Math.ceil(r/p)*p,e,p).filter(function(t){return y(t%g)>kt}).map(c)).concat(t.range(Math.ceil(o/d)*d,a,d).filter(function(t){return y(t%v)>kt}).map(u))}return x.lines=function(){return b().map(function(t){return{type:\"LineString\",coordinates:t}})},x.outline=function(){return{type:\"Polygon\",coordinates:[h(i).concat(f(s).slice(1),h(n).reverse().slice(1),f(l).reverse().slice(1))]}},x.extent=function(t){return arguments.length?x.majorExtent(t).minorExtent(t):x.minorExtent()},x.majorExtent=function(t){return arguments.length?(i=+t[0][0],n=+t[1][0],l=+t[0][1],s=+t[1][1],i>n&&(t=i,i=n,n=t),l>s&&(t=l,l=s,s=t),x.precision(m)):[[i,l],[n,s]]},x.minorExtent=function(t){return arguments.length?(r=+t[0][0],e=+t[1][0],o=+t[0][1],a=+t[1][1],r>e&&(t=r,r=e,e=t),o>a&&(t=o,o=a,a=t),x.precision(m)):[[r,o],[e,a]]},x.step=function(t){return arguments.length?x.majorStep(t).minorStep(t):x.minorStep()},x.majorStep=function(t){return arguments.length?(g=+t[0],v=+t[1],x):[g,v]},x.minorStep=function(t){return arguments.length?(p=+t[0],d=+t[1],x):[p,d]},x.precision=function(t){return arguments.length?(m=+t,c=Nn(o,a,90),u=jn(r,e,m),h=Nn(l,s,90),f=jn(i,n,m),x):m},x.majorExtent([[-180,-90+kt],[180,90-kt]]).minorExtent([[-180,-80-kt],[180,80+kt]])},t.geo.greatArc=function(){var e,r,n=Un,i=Vn;function a(){return{type:\"LineString\",coordinates:[e||n.apply(this,arguments),r||i.apply(this,arguments)]}}return a.distance=function(){return t.geo.distance(e||n.apply(this,arguments),r||i.apply(this,arguments))},a.source=function(t){return arguments.length?(n=t,e=\"function\"==typeof t?null:t,a):n},a.target=function(t){return arguments.length?(i=t,r=\"function\"==typeof t?null:t,a):i},a.precision=function(){return arguments.length?a:0},a},t.geo.interpolate=function(t,e){return r=t[0]*Ct,n=t[1]*Ct,i=e[0]*Ct,a=e[1]*Ct,o=Math.cos(n),s=Math.sin(n),l=Math.cos(a),c=Math.sin(a),u=o*Math.cos(r),h=o*Math.sin(r),f=l*Math.cos(i),p=l*Math.sin(i),d=2*Math.asin(Math.sqrt(Rt(a-n)+o*l*Rt(i-r))),g=1/Math.sin(d),(v=d?function(t){var e=Math.sin(t*=d)*g,r=Math.sin(d-t)*g,n=r*u+e*f,i=r*h+e*p,a=r*s+e*c;return[Math.atan2(i,n)*Lt,Math.atan2(a,Math.sqrt(n*n+i*i))*Lt]}:function(){return[r*Lt,n*Lt]}).distance=d,v;var r,n,i,a,o,s,l,c,u,h,f,p,d,g,v},t.geo.length=function(e){return yn=0,t.geo.stream(e,qn),yn};var qn={sphere:D,point:D,lineStart:function(){var t,e,r;function n(n,i){var a=Math.sin(i*=Ct),o=Math.cos(i),s=y((n*=Ct)-t),l=Math.cos(s);yn+=Math.atan2(Math.sqrt((s=o*Math.sin(s))*s+(s=r*a-e*o*l)*s),e*a+r*o*l),t=n,e=a,r=o}qn.point=function(i,a){t=i*Ct,e=Math.sin(a*=Ct),r=Math.cos(a),qn.point=n},qn.lineEnd=function(){qn.point=qn.lineEnd=D}},lineEnd:D,polygonStart:D,polygonEnd:D};function Hn(t,e){function r(e,r){var n=Math.cos(e),i=Math.cos(r),a=t(n*i);return[a*i*Math.sin(e),a*Math.sin(r)]}return r.invert=function(t,r){var n=Math.sqrt(t*t+r*r),i=e(n),a=Math.sin(i),o=Math.cos(i);return[Math.atan2(t*a,n*o),Math.asin(n&&r*a/n)]},r}var Gn=Hn(function(t){return Math.sqrt(2/(1+t))},function(t){return 2*Math.asin(t/2)});(t.geo.azimuthalEqualArea=function(){return En(Gn)}).raw=Gn;var Yn=Hn(function(t){var e=Math.acos(t);return e&&e/Math.sin(e)},P);function Wn(t,e){var r=Math.cos(t),n=function(t){return Math.tan(At/4+t/2)},i=t===e?Math.sin(t):Math.log(r/Math.cos(e))/Math.log(n(e)/n(t)),a=r*Math.pow(n(t),i)/i;if(!i)return Jn;function o(t,e){a>0?e<-Et+kt&&(e=-Et+kt):e>Et-kt&&(e=Et-kt);var r=a/Math.pow(n(e),i);return[r*Math.sin(i*t),a-r*Math.cos(i*t)]}return o.invert=function(t,e){var r=a-e,n=Pt(i)*Math.sqrt(t*t+r*r);return[Math.atan2(t,r)/i,2*Math.atan(Math.pow(a/n,1/i))-Et]},o}function Xn(t,e){var r=Math.cos(t),n=t===e?Math.sin(t):(r-Math.cos(e))/(e-t),i=r/n+t;if(y(n)<kt)return Pn;function a(t,e){var r=i-e;return[r*Math.sin(n*t),i-r*Math.cos(n*t)]}return a.invert=function(t,e){var r=i-e;return[Math.atan2(t,r)/n,i-Pt(n)*Math.sqrt(t*t+r*r)]},a}(t.geo.azimuthalEquidistant=function(){return En(Yn)}).raw=Yn,(t.geo.conicConformal=function(){return an(Wn)}).raw=Wn,(t.geo.conicEquidistant=function(){return an(Xn)}).raw=Xn;var Zn=Hn(function(t){return 1/t},Math.atan);function Jn(t,e){return[t,Math.log(Math.tan(At/4+e/2))]}function Kn(t){var e,r=En(t),n=r.scale,i=r.translate,a=r.clipExtent;return r.scale=function(){var t=n.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.translate=function(){var t=i.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.clipExtent=function(t){var o=a.apply(r,arguments);if(o===r){if(e=null==t){var s=At*n(),l=i();a([[l[0]-s,l[1]-s],[l[0]+s,l[1]+s]])}}else e&&(o=null);return o},r.clipExtent(null)}(t.geo.gnomonic=function(){return En(Zn)}).raw=Zn,Jn.invert=function(t,e){return[t,2*Math.atan(Math.exp(e))-Et]},(t.geo.mercator=function(){return Kn(Jn)}).raw=Jn;var $n=Hn(function(){return 1},Math.asin);(t.geo.orthographic=function(){return En($n)}).raw=$n;var Qn=Hn(function(t){return 1/(1+t)},function(t){return 2*Math.atan(t)});function ti(t,e){return[Math.log(Math.tan(At/4+e/2)),-t]}function ei(t){return t[0]}function ri(t){return t[1]}function ni(t){for(var e=t.length,r=[0,1],n=2,i=2;i<e;i++){for(;n>1&&Ot(t[r[n-2]],t[r[n-1]],t[i])<=0;)--n;r[n++]=i}return r.slice(0,n)}function ii(t,e){return t[0]-e[0]||t[1]-e[1]}(t.geo.stereographic=function(){return En(Qn)}).raw=Qn,ti.invert=function(t,e){return[-e,2*Math.atan(Math.exp(t))-Et]},(t.geo.transverseMercator=function(){var t=Kn(ti),e=t.center,r=t.rotate;return t.center=function(t){return t?e([-t[1],t[0]]):[(t=e())[1],-t[0]]},t.rotate=function(t){return t?r([t[0],t[1],t.length>2?t[2]+90:90]):[(t=r())[0],t[1],t[2]-90]},r([0,0,90])}).raw=ti,t.geom={},t.geom.hull=function(t){var e=ei,r=ri;if(arguments.length)return n(t);function n(t){if(t.length<3)return[];var n,i=ve(e),a=ve(r),o=t.length,s=[],l=[];for(n=0;n<o;n++)s.push([+i.call(this,t[n],n),+a.call(this,t[n],n),n]);for(s.sort(ii),n=0;n<o;n++)l.push([s[n][0],-s[n][1]]);var c=ni(s),u=ni(l),h=u[0]===c[0],f=u[u.length-1]===c[c.length-1],p=[];for(n=c.length-1;n>=0;--n)p.push(t[s[c[n]][2]]);for(n=+h;n<u.length-f;++n)p.push(t[s[u[n]][2]]);return p}return n.x=function(t){return arguments.length?(e=t,n):e},n.y=function(t){return arguments.length?(r=t,n):r},n},t.geom.polygon=function(t){return V(t,ai),t};var ai=t.geom.polygon.prototype=[];function oi(t,e,r){return(r[0]-e[0])*(t[1]-e[1])<(r[1]-e[1])*(t[0]-e[0])}function si(t,e,r,n){var i=t[0],a=r[0],o=e[0]-i,s=n[0]-a,l=t[1],c=r[1],u=e[1]-l,h=n[1]-c,f=(s*(l-c)-h*(i-a))/(h*o-s*u);return[i+f*o,l+f*u]}function li(t){var e=t[0],r=t[t.length-1];return!(e[0]-r[0]||e[1]-r[1])}ai.area=function(){for(var t,e=-1,r=this.length,n=this[r-1],i=0;++e<r;)t=n,n=this[e],i+=t[1]*n[0]-t[0]*n[1];return.5*i},ai.centroid=function(t){var e,r,n=-1,i=this.length,a=0,o=0,s=this[i-1];for(arguments.length||(t=-1/(6*this.area()));++n<i;)e=s,s=this[n],r=e[0]*s[1]-s[0]*e[1],a+=(e[0]+s[0])*r,o+=(e[1]+s[1])*r;return[a*t,o*t]},ai.clip=function(t){for(var e,r,n,i,a,o,s=li(t),l=-1,c=this.length-li(this),u=this[c-1];++l<c;){for(e=t.slice(),t.length=0,i=this[l],a=e[(n=e.length-s)-1],r=-1;++r<n;)oi(o=e[r],u,i)?(oi(a,u,i)||t.push(si(a,o,u,i)),t.push(o)):oi(a,u,i)&&t.push(si(a,o,u,i)),a=o;s&&t.push(t[0]),u=i}return t};var ci,ui,hi,fi,pi,di=[],gi=[];function vi(){Ii(this),this.edge=this.site=this.circle=null}function mi(t){var e=di.pop()||new vi;return e.site=t,e}function yi(t){Si(t),hi.remove(t),di.push(t),Ii(t)}function xi(t){var e=t.circle,r=e.x,n=e.cy,i={x:r,y:n},a=t.P,o=t.N,s=[t];yi(t);for(var l=a;l.circle&&y(r-l.circle.x)<kt&&y(n-l.circle.cy)<kt;)a=l.P,s.unshift(l),yi(l),l=a;s.unshift(l),Si(l);for(var c=o;c.circle&&y(r-c.circle.x)<kt&&y(n-c.circle.cy)<kt;)o=c.N,s.push(c),yi(c),c=o;s.push(c),Si(c);var u,h=s.length;for(u=1;u<h;++u)c=s[u],l=s[u-1],Pi(c.edge,l.site,c.site,i);l=s[0],(c=s[h-1]).edge=Li(l.site,c.site,null,i),Mi(l),Mi(c)}function bi(t){for(var e,r,n,i,a=t.x,o=t.y,s=hi._;s;)if((n=_i(s,o)-a)>kt)s=s.L;else{if(!((i=a-wi(s,o))>kt)){n>-kt?(e=s.P,r=s):i>-kt?(e=s,r=s.N):e=r=s;break}if(!s.R){e=s;break}s=s.R}var l=mi(t);if(hi.insert(e,l),e||r){if(e===r)return Si(e),r=mi(e.site),hi.insert(l,r),l.edge=r.edge=Li(e.site,l.site),Mi(e),void Mi(r);if(r){Si(e),Si(r);var c=e.site,u=c.x,h=c.y,f=t.x-u,p=t.y-h,d=r.site,g=d.x-u,v=d.y-h,m=2*(f*v-p*g),y=f*f+p*p,x=g*g+v*v,b={x:(v*y-p*x)/m+u,y:(f*x-g*y)/m+h};Pi(r.edge,c,d,b),l.edge=Li(c,t,null,b),r.edge=Li(t,d,null,b),Mi(e),Mi(r)}else l.edge=Li(e.site,l.site)}}function _i(t,e){var r=t.site,n=r.x,i=r.y,a=i-e;if(!a)return n;var o=t.P;if(!o)return-1/0;var s=(r=o.site).x,l=r.y,c=l-e;if(!c)return s;var u=s-n,h=1/a-1/c,f=u/c;return h?(-f+Math.sqrt(f*f-2*h*(u*u/(-2*c)-l+c/2+i-a/2)))/h+n:(n+s)/2}function wi(t,e){var r=t.N;if(r)return _i(r,e);var n=t.site;return n.y===e?n.x:1/0}function ki(t){this.site=t,this.edges=[]}function Ti(t,e){return e.angle-t.angle}function Ai(){Ii(this),this.x=this.y=this.arc=this.site=this.cy=null}function Mi(t){var e=t.P,r=t.N;if(e&&r){var n=e.site,i=t.site,a=r.site;if(n!==a){var o=i.x,s=i.y,l=n.x-o,c=n.y-s,u=a.x-o,h=2*(l*(v=a.y-s)-c*u);if(!(h>=-Tt)){var f=l*l+c*c,p=u*u+v*v,d=(v*f-c*p)/h,g=(l*p-u*f)/h,v=g+s,m=gi.pop()||new Ai;m.arc=t,m.site=i,m.x=d+o,m.y=v+Math.sqrt(d*d+g*g),m.cy=v,t.circle=m;for(var y=null,x=pi._;x;)if(m.y<x.y||m.y===x.y&&m.x<=x.x){if(!x.L){y=x.P;break}x=x.L}else{if(!x.R){y=x;break}x=x.R}pi.insert(y,m),y||(fi=m)}}}}function Si(t){var e=t.circle;e&&(e.P||(fi=e.N),pi.remove(e),gi.push(e),Ii(e),t.circle=null)}function Ei(t,e){var r=t.b;if(r)return!0;var n,i,a=t.a,o=e[0][0],s=e[1][0],l=e[0][1],c=e[1][1],u=t.l,h=t.r,f=u.x,p=u.y,d=h.x,g=h.y,v=(f+d)/2,m=(p+g)/2;if(g===p){if(v<o||v>=s)return;if(f>d){if(a){if(a.y>=c)return}else a={x:v,y:l};r={x:v,y:c}}else{if(a){if(a.y<l)return}else a={x:v,y:c};r={x:v,y:l}}}else if(i=m-(n=(f-d)/(g-p))*v,n<-1||n>1)if(f>d){if(a){if(a.y>=c)return}else a={x:(l-i)/n,y:l};r={x:(c-i)/n,y:c}}else{if(a){if(a.y<l)return}else a={x:(c-i)/n,y:c};r={x:(l-i)/n,y:l}}else if(p<g){if(a){if(a.x>=s)return}else a={x:o,y:n*o+i};r={x:s,y:n*s+i}}else{if(a){if(a.x<o)return}else a={x:s,y:n*s+i};r={x:o,y:n*o+i}}return t.a=a,t.b=r,!0}function Ci(t,e){this.l=t,this.r=e,this.a=this.b=null}function Li(t,e,r,n){var i=new Ci(t,e);return ci.push(i),r&&Pi(i,t,e,r),n&&Pi(i,e,t,n),ui[t.i].edges.push(new Oi(i,t,e)),ui[e.i].edges.push(new Oi(i,e,t)),i}function Pi(t,e,r,n){t.a||t.b?t.l===r?t.b=n:t.a=n:(t.a=n,t.l=e,t.r=r)}function Oi(t,e,r){var n=t.a,i=t.b;this.edge=t,this.site=e,this.angle=r?Math.atan2(r.y-e.y,r.x-e.x):t.l===e?Math.atan2(i.x-n.x,n.y-i.y):Math.atan2(n.x-i.x,i.y-n.y)}function zi(){this._=null}function Ii(t){t.U=t.C=t.L=t.R=t.P=t.N=null}function Di(t,e){var r=e,n=e.R,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.R=n.L,r.R&&(r.R.U=r),n.L=r}function Ri(t,e){var r=e,n=e.L,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.L=n.R,r.L&&(r.L.U=r),n.R=r}function Fi(t){for(;t.L;)t=t.L;return t}function Bi(t,e){var r,n,i,a=t.sort(Ni).pop();for(ci=[],ui=new Array(t.length),hi=new zi,pi=new zi;;)if(i=fi,a&&(!i||a.y<i.y||a.y===i.y&&a.x<i.x))a.x===r&&a.y===n||(ui[a.i]=new ki(a),bi(a),r=a.x,n=a.y),a=t.pop();else{if(!i)break;xi(i.arc)}e&&(function(t){for(var e,r=ci,n=en(t[0][0],t[0][1],t[1][0],t[1][1]),i=r.length;i--;)(!Ei(e=r[i],t)||!n(e)||y(e.a.x-e.b.x)<kt&&y(e.a.y-e.b.y)<kt)&&(e.a=e.b=null,r.splice(i,1))}(e),function(t){for(var e,r,n,i,a,o,s,l,c,u,h=t[0][0],f=t[1][0],p=t[0][1],d=t[1][1],g=ui,v=g.length;v--;)if((a=g[v])&&a.prepare())for(l=(s=a.edges).length,o=0;o<l;)n=(u=s[o].end()).x,i=u.y,e=(c=s[++o%l].start()).x,r=c.y,(y(n-e)>kt||y(i-r)>kt)&&(s.splice(o,0,new Oi((m=a.site,x=u,b=y(n-h)<kt&&d-i>kt?{x:h,y:y(e-h)<kt?r:d}:y(i-d)<kt&&f-n>kt?{x:y(r-d)<kt?e:f,y:d}:y(n-f)<kt&&i-p>kt?{x:f,y:y(e-f)<kt?r:p}:y(i-p)<kt&&n-h>kt?{x:y(r-p)<kt?e:h,y:p}:null,_=void 0,_=new Ci(m,null),_.a=x,_.b=b,ci.push(_),_),a.site,null)),++l);var m,x,b,_}(e));var o={cells:ui,edges:ci};return hi=pi=ci=ui=null,o}function Ni(t,e){return e.y-t.y||e.x-t.x}ki.prototype.prepare=function(){for(var t,e=this.edges,r=e.length;r--;)(t=e[r].edge).b&&t.a||e.splice(r,1);return e.sort(Ti),e.length},Oi.prototype={start:function(){return this.edge.l===this.site?this.edge.a:this.edge.b},end:function(){return this.edge.l===this.site?this.edge.b:this.edge.a}},zi.prototype={insert:function(t,e){var r,n,i;if(t){if(e.P=t,e.N=t.N,t.N&&(t.N.P=e),t.N=e,t.R){for(t=t.R;t.L;)t=t.L;t.L=e}else t.R=e;r=t}else this._?(t=Fi(this._),e.P=null,e.N=t,t.P=t.L=e,r=t):(e.P=e.N=null,this._=e,r=null);for(e.L=e.R=null,e.U=r,e.C=!0,t=e;r&&r.C;)r===(n=r.U).L?(i=n.R)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.R&&(Di(this,r),r=(t=r).U),r.C=!1,n.C=!0,Ri(this,n)):(i=n.L)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.L&&(Ri(this,r),r=(t=r).U),r.C=!1,n.C=!0,Di(this,n)),r=t.U;this._.C=!1},remove:function(t){t.N&&(t.N.P=t.P),t.P&&(t.P.N=t.N),t.N=t.P=null;var e,r,n,i=t.U,a=t.L,o=t.R;if(r=a?o?Fi(o):a:o,i?i.L===t?i.L=r:i.R=r:this._=r,a&&o?(n=r.C,r.C=t.C,r.L=a,a.U=r,r!==o?(i=r.U,r.U=t.U,t=r.R,i.L=t,r.R=o,o.U=r):(r.U=i,i=r,t=r.R)):(n=t.C,t=r),t&&(t.U=i),!n)if(t&&t.C)t.C=!1;else{do{if(t===this._)break;if(t===i.L){if((e=i.R).C&&(e.C=!1,i.C=!0,Di(this,i),e=i.R),e.L&&e.L.C||e.R&&e.R.C){e.R&&e.R.C||(e.L.C=!1,e.C=!0,Ri(this,e),e=i.R),e.C=i.C,i.C=e.R.C=!1,Di(this,i),t=this._;break}}else if((e=i.L).C&&(e.C=!1,i.C=!0,Ri(this,i),e=i.L),e.L&&e.L.C||e.R&&e.R.C){e.L&&e.L.C||(e.R.C=!1,e.C=!0,Di(this,e),e=i.L),e.C=i.C,i.C=e.L.C=!1,Ri(this,i),t=this._;break}e.C=!0,t=i,i=i.U}while(!t.C);t&&(t.C=!1)}}},t.geom.voronoi=function(t){var e=ei,r=ri,n=e,i=r,a=ji;if(t)return o(t);function o(t){var e=new Array(t.length),r=a[0][0],n=a[0][1],i=a[1][0],o=a[1][1];return Bi(s(t),a).cells.forEach(function(a,s){var l=a.edges,c=a.site;(e[s]=l.length?l.map(function(t){var e=t.start();return[e.x,e.y]}):c.x>=r&&c.x<=i&&c.y>=n&&c.y<=o?[[r,o],[i,o],[i,n],[r,n]]:[]).point=t[s]}),e}function s(t){return t.map(function(t,e){return{x:Math.round(n(t,e)/kt)*kt,y:Math.round(i(t,e)/kt)*kt,i:e}})}return o.links=function(t){return Bi(s(t)).edges.filter(function(t){return t.l&&t.r}).map(function(e){return{source:t[e.l.i],target:t[e.r.i]}})},o.triangles=function(t){var e=[];return Bi(s(t)).cells.forEach(function(r,n){for(var i,a,o,s,l=r.site,c=r.edges.sort(Ti),u=-1,h=c.length,f=c[h-1].edge,p=f.l===l?f.r:f.l;++u<h;)f,i=p,p=(f=c[u].edge).l===l?f.r:f.l,n<i.i&&n<p.i&&(o=i,s=p,((a=l).x-s.x)*(o.y-a.y)-(a.x-o.x)*(s.y-a.y)<0)&&e.push([t[n],t[i.i],t[p.i]])}),e},o.x=function(t){return arguments.length?(n=ve(e=t),o):e},o.y=function(t){return arguments.length?(i=ve(r=t),o):r},o.clipExtent=function(t){return arguments.length?(a=null==t?ji:t,o):a===ji?null:a},o.size=function(t){return arguments.length?o.clipExtent(t&&[[0,0],t]):a===ji?null:a&&a[1]},o};var ji=[[-1e6,-1e6],[1e6,1e6]];function Ui(t){return t.x}function Vi(t){return t.y}function qi(e,r){e=t.rgb(e),r=t.rgb(r);var n=e.r,i=e.g,a=e.b,o=r.r-n,s=r.g-i,l=r.b-a;return function(t){return\"#\"+ce(Math.round(n+o*t))+ce(Math.round(i+s*t))+ce(Math.round(a+l*t))}}function Hi(t,e){var r,n={},i={};for(r in t)r in e?n[r]=Zi(t[r],e[r]):i[r]=t[r];for(r in e)r in t||(i[r]=e[r]);return function(t){for(r in n)i[r]=n[r](t);return i}}function Gi(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function Yi(t,e){var r,n,i,a=Wi.lastIndex=Xi.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=Wi.exec(t))&&(n=Xi.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:Gi(r,n)})),a=Xi.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?(e=l[0].x,function(t){return e(t)+\"\"}):function(){return e}:(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}t.geom.delaunay=function(e){return t.geom.voronoi().triangles(e)},t.geom.quadtree=function(t,e,r,n,i){var a,o=ei,s=ri;if(a=arguments.length)return o=Ui,s=Vi,3===a&&(i=r,n=e,r=e=0),l(t);function l(t){var l,c,u,h,f,p,d,g,v,m=ve(o),x=ve(s);if(null!=e)p=e,d=r,g=n,v=i;else if(g=v=-(p=d=1/0),c=[],u=[],f=t.length,a)for(h=0;h<f;++h)(l=t[h]).x<p&&(p=l.x),l.y<d&&(d=l.y),l.x>g&&(g=l.x),l.y>v&&(v=l.y),c.push(l.x),u.push(l.y);else for(h=0;h<f;++h){var b=+m(l=t[h],h),_=+x(l,h);b<p&&(p=b),_<d&&(d=_),b>g&&(g=b),_>v&&(v=_),c.push(b),u.push(_)}var w=g-p,k=v-d;function T(t,e,r,n,i,a,o,s){if(!isNaN(r)&&!isNaN(n))if(t.leaf){var l=t.x,c=t.y;if(null!=l)if(y(l-r)+y(c-n)<.01)A(t,e,r,n,i,a,o,s);else{var u=t.point;t.x=t.y=t.point=null,A(t,u,l,c,i,a,o,s),A(t,e,r,n,i,a,o,s)}else t.x=r,t.y=n,t.point=e}else A(t,e,r,n,i,a,o,s)}function A(t,e,r,n,i,a,o,s){var l=.5*(i+o),c=.5*(a+s),u=r>=l,h=n>=c,f=h<<1|u;t.leaf=!1,u?i=l:o=l,h?a=c:s=c,T(t=t.nodes[f]||(t.nodes[f]={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){T(M,t,+m(t,++h),+x(t,h),p,d,g,v)}}),e,r,n,i,a,o,s)}w>k?v=d+w:g=p+k;var M={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){T(M,t,+m(t,++h),+x(t,h),p,d,g,v)}};if(M.visit=function(t){!function t(e,r,n,i,a,o){if(!e(r,n,i,a,o)){var s=.5*(n+a),l=.5*(i+o),c=r.nodes;c[0]&&t(e,c[0],n,i,s,l),c[1]&&t(e,c[1],s,i,a,l),c[2]&&t(e,c[2],n,l,s,o),c[3]&&t(e,c[3],s,l,a,o)}}(t,M,p,d,g,v)},M.find=function(t){return function(t,e,r,n,i,a,o){var s,l=1/0;return function t(c,u,h,f,p){if(!(u>a||h>o||f<n||p<i)){if(d=c.point){var d,g=e-c.x,v=r-c.y,m=g*g+v*v;if(m<l){var y=Math.sqrt(l=m);n=e-y,i=r-y,a=e+y,o=r+y,s=d}}for(var x=c.nodes,b=.5*(u+f),_=.5*(h+p),w=(r>=_)<<1|e>=b,k=w+4;w<k;++w)if(c=x[3&w])switch(3&w){case 0:t(c,u,h,b,_);break;case 1:t(c,b,h,f,_);break;case 2:t(c,u,_,b,p);break;case 3:t(c,b,_,f,p)}}}(t,n,i,a,o),s}(M,t[0],t[1],p,d,g,v)},h=-1,null==e){for(;++h<f;)T(M,t[h],c[h],u[h],p,d,g,v);--h}else t.forEach(M.add);return c=u=t=l=null,M}return l.x=function(t){return arguments.length?(o=t,l):o},l.y=function(t){return arguments.length?(s=t,l):s},l.extent=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=+t[0][0],r=+t[0][1],n=+t[1][0],i=+t[1][1]),l):null==e?null:[[e,r],[n,i]]},l.size=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=r=0,n=+t[0],i=+t[1]),l):null==e?null:[n-e,i-r]},l},t.interpolateRgb=qi,t.interpolateObject=Hi,t.interpolateNumber=Gi,t.interpolateString=Yi;var Wi=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,Xi=new RegExp(Wi.source,\"g\");function Zi(e,r){for(var n,i=t.interpolators.length;--i>=0&&!(n=t.interpolators[i](e,r)););return n}function Ji(t,e){var r,n=[],i=[],a=t.length,o=e.length,s=Math.min(t.length,e.length);for(r=0;r<s;++r)n.push(Zi(t[r],e[r]));for(;r<a;++r)i[r]=t[r];for(;r<o;++r)i[r]=e[r];return function(t){for(r=0;r<s;++r)i[r]=n[r](t);return i}}t.interpolate=Zi,t.interpolators=[function(t,e){var r=typeof e;return(\"string\"===r?ge.has(e.toLowerCase())||/^(#|rgb\\(|hsl\\()/i.test(e)?qi:Yi:e instanceof Ut?qi:Array.isArray(e)?Ji:\"object\"===r&&isNaN(e)?Hi:Gi)(t,e)}],t.interpolateArray=Ji;var Ki=function(){return P},$i=t.map({linear:Ki,poly:function(t){return function(e){return Math.pow(e,t)}},quad:function(){return ra},cubic:function(){return na},sin:function(){return aa},exp:function(){return oa},circle:function(){return sa},elastic:function(t,e){var r;arguments.length<2&&(e=.45);arguments.length?r=e/Mt*Math.asin(1/t):(t=1,r=e/4);return function(n){return 1+t*Math.pow(2,-10*n)*Math.sin((n-r)*Mt/e)}},back:function(t){t||(t=1.70158);return function(e){return e*e*((t+1)*e-t)}},bounce:function(){return la}}),Qi=t.map({in:P,out:ta,\"in-out\":ea,\"out-in\":function(t){return ea(ta(t))}});function ta(t){return function(e){return 1-t(1-e)}}function ea(t){return function(e){return.5*(e<.5?t(2*e):2-t(2-2*e))}}function ra(t){return t*t}function na(t){return t*t*t}function ia(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}function aa(t){return 1-Math.cos(t*Et)}function oa(t){return Math.pow(2,10*(t-1))}function sa(t){return 1-Math.sqrt(1-t*t)}function la(t){return t<1/2.75?7.5625*t*t:t<2/2.75?7.5625*(t-=1.5/2.75)*t+.75:t<2.5/2.75?7.5625*(t-=2.25/2.75)*t+.9375:7.5625*(t-=2.625/2.75)*t+.984375}function ca(t,e){return e-=t,function(r){return Math.round(t+e*r)}}function ua(t){var e,r,n,i=[t.a,t.b],a=[t.c,t.d],o=fa(i),s=ha(i,a),l=fa(((e=a)[0]+=(n=-s)*(r=i)[0],e[1]+=n*r[1],e))||0;i[0]*a[1]<a[0]*i[1]&&(i[0]*=-1,i[1]*=-1,o*=-1,s*=-1),this.rotate=(o?Math.atan2(i[1],i[0]):Math.atan2(-a[0],a[1]))*Lt,this.translate=[t.e,t.f],this.scale=[o,l],this.skew=l?Math.atan2(s,l)*Lt:0}function ha(t,e){return t[0]*e[0]+t[1]*e[1]}function fa(t){var e=Math.sqrt(ha(t,t));return e&&(t[0]/=e,t[1]/=e),e}t.ease=function(t){var e,n=t.indexOf(\"-\"),i=n>=0?t.slice(0,n):t,a=n>=0?t.slice(n+1):\"in\";return i=$i.get(i)||Ki,a=Qi.get(a)||P,e=a(i.apply(null,r.call(arguments,1))),function(t){return t<=0?0:t>=1?1:e(t)}},t.interpolateHcl=function(e,r){e=t.hcl(e),r=t.hcl(r);var n=e.h,i=e.c,a=e.l,o=r.h-n,s=r.c-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.c:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Wt(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateHsl=function(e,r){e=t.hsl(e),r=t.hsl(r);var n=e.h,i=e.s,a=e.l,o=r.h-n,s=r.s-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.s:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Ht(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateLab=function(e,r){e=t.lab(e),r=t.lab(r);var n=e.l,i=e.a,a=e.b,o=r.l-n,s=r.a-i,l=r.b-a;return function(t){return te(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateRound=ca,t.transform=function(e){var r=i.createElementNS(t.ns.prefix.svg,\"g\");return(t.transform=function(t){if(null!=t){r.setAttribute(\"transform\",t);var e=r.transform.baseVal.consolidate()}return new ua(e?e.matrix:pa)})(e)},ua.prototype.toString=function(){return\"translate(\"+this.translate+\")rotate(\"+this.rotate+\")skewX(\"+this.skew+\")scale(\"+this.scale+\")\"};var pa={a:1,b:0,c:0,d:1,e:0,f:0};function da(t){return t.length?t.pop()+\",\":\"\"}function ga(e,r){var n=[],i=[];return e=t.transform(e),r=t.transform(r),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(\"translate(\",null,\",\",null,\")\");n.push({i:i-4,x:Gi(t[0],e[0])},{i:i-2,x:Gi(t[1],e[1])})}else(e[0]||e[1])&&r.push(\"translate(\"+e+\")\")}(e.translate,r.translate,n,i),function(t,e,r,n){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),n.push({i:r.push(da(r)+\"rotate(\",null,\")\")-2,x:Gi(t,e)})):e&&r.push(da(r)+\"rotate(\"+e+\")\")}(e.rotate,r.rotate,n,i),function(t,e,r,n){t!==e?n.push({i:r.push(da(r)+\"skewX(\",null,\")\")-2,x:Gi(t,e)}):e&&r.push(da(r)+\"skewX(\"+e+\")\")}(e.skew,r.skew,n,i),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(da(r)+\"scale(\",null,\",\",null,\")\");n.push({i:i-4,x:Gi(t[0],e[0])},{i:i-2,x:Gi(t[1],e[1])})}else 1===e[0]&&1===e[1]||r.push(da(r)+\"scale(\"+e+\")\")}(e.scale,r.scale,n,i),e=r=null,function(t){for(var e,r=-1,a=i.length;++r<a;)n[(e=i[r]).i]=e.x(t);return n.join(\"\")}}function va(t,e){return e=(e-=t=+t)||1/e,function(r){return(r-t)/e}}function ma(t,e){return e=(e-=t=+t)||1/e,function(r){return Math.max(0,Math.min(1,(r-t)/e))}}function ya(t){for(var e=t.source,r=t.target,n=function(t,e){if(t===e)return t;var r=xa(t),n=xa(e),i=r.pop(),a=n.pop(),o=null;for(;i===a;)o=i,i=r.pop(),a=n.pop();return o}(e,r),i=[e];e!==n;)e=e.parent,i.push(e);for(var a=i.length;r!==n;)i.splice(a,0,r),r=r.parent;return i}function xa(t){for(var e=[],r=t.parent;null!=r;)e.push(t),t=r,r=r.parent;return e.push(t),e}function ba(t){t.fixed|=2}function _a(t){t.fixed&=-7}function wa(t){t.fixed|=4,t.px=t.x,t.py=t.y}function ka(t){t.fixed&=-5}t.interpolateTransform=ga,t.layout={},t.layout.bundle=function(){return function(t){for(var e=[],r=-1,n=t.length;++r<n;)e.push(ya(t[r]));return e}},t.layout.chord=function(){var e,r,n,i,a,o,s,l={},c=0;function u(){var l,u,f,p,d,g={},v=[],m=t.range(i),y=[];for(e=[],r=[],l=0,p=-1;++p<i;){for(u=0,d=-1;++d<i;)u+=n[p][d];v.push(u),y.push(t.range(i)),l+=u}for(a&&m.sort(function(t,e){return a(v[t],v[e])}),o&&y.forEach(function(t,e){t.sort(function(t,r){return o(n[e][t],n[e][r])})}),l=(Mt-c*i)/l,u=0,p=-1;++p<i;){for(f=u,d=-1;++d<i;){var x=m[p],b=y[x][d],_=n[x][b],w=u,k=u+=_*l;g[x+\"-\"+b]={index:x,subindex:b,startAngle:w,endAngle:k,value:_}}r[x]={index:x,startAngle:f,endAngle:u,value:v[x]},u+=c}for(p=-1;++p<i;)for(d=p-1;++d<i;){var T=g[p+\"-\"+d],A=g[d+\"-\"+p];(T.value||A.value)&&e.push(T.value<A.value?{source:A,target:T}:{source:T,target:A})}s&&h()}function h(){e.sort(function(t,e){return s((t.source.value+t.target.value)/2,(e.source.value+e.target.value)/2)})}return l.matrix=function(t){return arguments.length?(i=(n=t)&&n.length,e=r=null,l):n},l.padding=function(t){return arguments.length?(c=t,e=r=null,l):c},l.sortGroups=function(t){return arguments.length?(a=t,e=r=null,l):a},l.sortSubgroups=function(t){return arguments.length?(o=t,e=null,l):o},l.sortChords=function(t){return arguments.length?(s=t,e&&h(),l):s},l.chords=function(){return e||u(),e},l.groups=function(){return r||u(),r},l},t.layout.force=function(){var e,r,n,i,a,o,s={},l=t.dispatch(\"start\",\"tick\",\"end\"),c=[1,1],u=.9,h=Ta,f=Aa,p=-30,d=Ma,g=.1,v=.64,m=[],y=[];function x(t){return function(e,r,n,i){if(e.point!==t){var a=e.cx-t.x,o=e.cy-t.y,s=i-r,l=a*a+o*o;if(s*s/v<l){if(l<d){var c=e.charge/l;t.px-=a*c,t.py-=o*c}return!0}if(e.point&&l&&l<d){c=e.pointCharge/l;t.px-=a*c,t.py-=o*c}}return!e.charge}}function b(e){e.px=t.event.x,e.py=t.event.y,s.resume()}return s.tick=function(){if((n*=.99)<.005)return e=null,l.end({type:\"end\",alpha:n=0}),!0;var r,s,h,f,d,v,b,_,w,k=m.length,T=y.length;for(s=0;s<T;++s)f=(h=y[s]).source,(v=(_=(d=h.target).x-f.x)*_+(w=d.y-f.y)*w)&&(_*=v=n*a[s]*((v=Math.sqrt(v))-i[s])/v,w*=v,d.x-=_*(b=f.weight+d.weight?f.weight/(f.weight+d.weight):.5),d.y-=w*b,f.x+=_*(b=1-b),f.y+=w*b);if((b=n*g)&&(_=c[0]/2,w=c[1]/2,s=-1,b))for(;++s<k;)(h=m[s]).x+=(_-h.x)*b,h.y+=(w-h.y)*b;if(p)for(!function t(e,r,n){var i=0,a=0;e.charge=0;if(!e.leaf)for(var o,s=e.nodes,l=s.length,c=-1;++c<l;)null!=(o=s[c])&&(t(o,r,n),e.charge+=o.charge,i+=o.charge*o.cx,a+=o.charge*o.cy);if(e.point){e.leaf||(e.point.x+=Math.random()-.5,e.point.y+=Math.random()-.5);var u=r*n[e.point.index];e.charge+=e.pointCharge=u,i+=u*e.point.x,a+=u*e.point.y}e.cx=i/e.charge;e.cy=a/e.charge}(r=t.geom.quadtree(m),n,o),s=-1;++s<k;)(h=m[s]).fixed||r.visit(x(h));for(s=-1;++s<k;)(h=m[s]).fixed?(h.x=h.px,h.y=h.py):(h.x-=(h.px-(h.px=h.x))*u,h.y-=(h.py-(h.py=h.y))*u);l.tick({type:\"tick\",alpha:n})},s.nodes=function(t){return arguments.length?(m=t,s):m},s.links=function(t){return arguments.length?(y=t,s):y},s.size=function(t){return arguments.length?(c=t,s):c},s.linkDistance=function(t){return arguments.length?(h=\"function\"==typeof t?t:+t,s):h},s.distance=s.linkDistance,s.linkStrength=function(t){return arguments.length?(f=\"function\"==typeof t?t:+t,s):f},s.friction=function(t){return arguments.length?(u=+t,s):u},s.charge=function(t){return arguments.length?(p=\"function\"==typeof t?t:+t,s):p},s.chargeDistance=function(t){return arguments.length?(d=t*t,s):Math.sqrt(d)},s.gravity=function(t){return arguments.length?(g=+t,s):g},s.theta=function(t){return arguments.length?(v=t*t,s):Math.sqrt(v)},s.alpha=function(t){return arguments.length?(t=+t,n?t>0?n=t:(e.c=null,e.t=NaN,e=null,l.end({type:\"end\",alpha:n=0})):t>0&&(l.start({type:\"start\",alpha:n=t}),e=Te(s.tick)),s):n},s.start=function(){var t,e,r,n=m.length,l=y.length,u=c[0],d=c[1];for(t=0;t<n;++t)(r=m[t]).index=t,r.weight=0;for(t=0;t<l;++t)\"number\"==typeof(r=y[t]).source&&(r.source=m[r.source]),\"number\"==typeof r.target&&(r.target=m[r.target]),++r.source.weight,++r.target.weight;for(t=0;t<n;++t)r=m[t],isNaN(r.x)&&(r.x=g(\"x\",u)),isNaN(r.y)&&(r.y=g(\"y\",d)),isNaN(r.px)&&(r.px=r.x),isNaN(r.py)&&(r.py=r.y);if(i=[],\"function\"==typeof h)for(t=0;t<l;++t)i[t]=+h.call(this,y[t],t);else for(t=0;t<l;++t)i[t]=h;if(a=[],\"function\"==typeof f)for(t=0;t<l;++t)a[t]=+f.call(this,y[t],t);else for(t=0;t<l;++t)a[t]=f;if(o=[],\"function\"==typeof p)for(t=0;t<n;++t)o[t]=+p.call(this,m[t],t);else for(t=0;t<n;++t)o[t]=p;function g(r,i){if(!e){for(e=new Array(n),c=0;c<n;++c)e[c]=[];for(c=0;c<l;++c){var a=y[c];e[a.source.index].push(a.target),e[a.target.index].push(a.source)}}for(var o,s=e[t],c=-1,u=s.length;++c<u;)if(!isNaN(o=s[c][r]))return o;return Math.random()*i}return s.resume()},s.resume=function(){return s.alpha(.1)},s.stop=function(){return s.alpha(0)},s.drag=function(){if(r||(r=t.behavior.drag().origin(P).on(\"dragstart.force\",ba).on(\"drag.force\",b).on(\"dragend.force\",_a)),!arguments.length)return r;this.on(\"mouseover.force\",wa).on(\"mouseout.force\",ka).call(r)},t.rebind(s,l,\"on\")};var Ta=20,Aa=1,Ma=1/0;function Sa(e,r){return t.rebind(e,r,\"sort\",\"children\",\"value\"),e.nodes=e,e.links=za,e}function Ea(t,e){for(var r=[t];null!=(t=r.pop());)if(e(t),(i=t.children)&&(n=i.length))for(var n,i;--n>=0;)r.push(i[n])}function Ca(t,e){for(var r=[t],n=[];null!=(t=r.pop());)if(n.push(t),(a=t.children)&&(i=a.length))for(var i,a,o=-1;++o<i;)r.push(a[o]);for(;null!=(t=n.pop());)e(t)}function La(t){return t.children}function Pa(t){return t.value}function Oa(t,e){return e.value-t.value}function za(e){return t.merge(e.map(function(t){return(t.children||[]).map(function(e){return{source:t,target:e}})}))}t.layout.hierarchy=function(){var t=Oa,e=La,r=Pa;function n(i){var a,o=[i],s=[];for(i.depth=0;null!=(a=o.pop());)if(s.push(a),(c=e.call(n,a,a.depth))&&(l=c.length)){for(var l,c,u;--l>=0;)o.push(u=c[l]),u.parent=a,u.depth=a.depth+1;r&&(a.value=0),a.children=c}else r&&(a.value=+r.call(n,a,a.depth)||0),delete a.children;return Ca(i,function(e){var n,i;t&&(n=e.children)&&n.sort(t),r&&(i=e.parent)&&(i.value+=e.value)}),s}return n.sort=function(e){return arguments.length?(t=e,n):t},n.children=function(t){return arguments.length?(e=t,n):e},n.value=function(t){return arguments.length?(r=t,n):r},n.revalue=function(t){return r&&(Ea(t,function(t){t.children&&(t.value=0)}),Ca(t,function(t){var e;t.children||(t.value=+r.call(n,t,t.depth)||0),(e=t.parent)&&(e.value+=t.value)})),t},n},t.layout.partition=function(){var e=t.layout.hierarchy(),r=[1,1];function n(t,n){var i=e.call(this,t,n);return function t(e,r,n,i){var a=e.children;if(e.x=r,e.y=e.depth*i,e.dx=n,e.dy=i,a&&(o=a.length)){var o,s,l,c=-1;for(n=e.value?n/e.value:0;++c<o;)t(s=a[c],r,l=s.value*n,i),r+=l}}(i[0],0,r[0],r[1]/function t(e){var r=e.children,n=0;if(r&&(i=r.length))for(var i,a=-1;++a<i;)n=Math.max(n,t(r[a]));return 1+n}(i[0])),i}return n.size=function(t){return arguments.length?(r=t,n):r},Sa(n,e)},t.layout.pie=function(){var e=Number,r=Ia,n=0,i=Mt,a=0;function o(s){var l,c=s.length,u=s.map(function(t,r){return+e.call(o,t,r)}),h=+(\"function\"==typeof n?n.apply(this,arguments):n),f=(\"function\"==typeof i?i.apply(this,arguments):i)-h,p=Math.min(Math.abs(f)/c,+(\"function\"==typeof a?a.apply(this,arguments):a)),d=p*(f<0?-1:1),g=t.sum(u),v=g?(f-c*d)/g:0,m=t.range(c),y=[];return null!=r&&m.sort(r===Ia?function(t,e){return u[e]-u[t]}:function(t,e){return r(s[t],s[e])}),m.forEach(function(t){y[t]={data:s[t],value:l=u[t],startAngle:h,endAngle:h+=l*v+d,padAngle:p}}),y}return o.value=function(t){return arguments.length?(e=t,o):e},o.sort=function(t){return arguments.length?(r=t,o):r},o.startAngle=function(t){return arguments.length?(n=t,o):n},o.endAngle=function(t){return arguments.length?(i=t,o):i},o.padAngle=function(t){return arguments.length?(a=t,o):a},o};var Ia={};function Da(t){return t.x}function Ra(t){return t.y}function Fa(t,e,r){t.y0=e,t.y=r}t.layout.stack=function(){var e=P,r=ja,n=Ua,i=Fa,a=Da,o=Ra;function s(l,c){if(!(p=l.length))return l;var u=l.map(function(t,r){return e.call(s,t,r)}),h=u.map(function(t){return t.map(function(t,e){return[a.call(s,t,e),o.call(s,t,e)]})}),f=r.call(s,h,c);u=t.permute(u,f),h=t.permute(h,f);var p,d,g,v,m=n.call(s,h,c),y=u[0].length;for(g=0;g<y;++g)for(i.call(s,u[0][g],v=m[g],h[0][g][1]),d=1;d<p;++d)i.call(s,u[d][g],v+=h[d-1][g][1],h[d][g][1]);return l}return s.values=function(t){return arguments.length?(e=t,s):e},s.order=function(t){return arguments.length?(r=\"function\"==typeof t?t:Ba.get(t)||ja,s):r},s.offset=function(t){return arguments.length?(n=\"function\"==typeof t?t:Na.get(t)||Ua,s):n},s.x=function(t){return arguments.length?(a=t,s):a},s.y=function(t){return arguments.length?(o=t,s):o},s.out=function(t){return arguments.length?(i=t,s):i},s};var Ba=t.map({\"inside-out\":function(e){var r,n,i=e.length,a=e.map(Va),o=e.map(qa),s=t.range(i).sort(function(t,e){return a[t]-a[e]}),l=0,c=0,u=[],h=[];for(r=0;r<i;++r)n=s[r],l<c?(l+=o[n],u.push(n)):(c+=o[n],h.push(n));return h.reverse().concat(u)},reverse:function(e){return t.range(e.length).reverse()},default:ja}),Na=t.map({silhouette:function(t){var e,r,n,i=t.length,a=t[0].length,o=[],s=0,l=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];n>s&&(s=n),o.push(n)}for(r=0;r<a;++r)l[r]=(s-o[r])/2;return l},wiggle:function(t){var e,r,n,i,a,o,s,l,c,u=t.length,h=t[0],f=h.length,p=[];for(p[0]=l=c=0,r=1;r<f;++r){for(e=0,i=0;e<u;++e)i+=t[e][r][1];for(e=0,a=0,s=h[r][0]-h[r-1][0];e<u;++e){for(n=0,o=(t[e][r][1]-t[e][r-1][1])/(2*s);n<e;++n)o+=(t[n][r][1]-t[n][r-1][1])/s;a+=o*t[e][r][1]}p[r]=l-=i?a/i*s:0,l<c&&(c=l)}for(r=0;r<f;++r)p[r]-=c;return p},expand:function(t){var e,r,n,i=t.length,a=t[0].length,o=1/i,s=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];if(n)for(e=0;e<i;e++)t[e][r][1]/=n;else for(e=0;e<i;e++)t[e][r][1]=o}for(r=0;r<a;++r)s[r]=0;return s},zero:Ua});function ja(e){return t.range(e.length)}function Ua(t){for(var e=-1,r=t[0].length,n=[];++e<r;)n[e]=0;return n}function Va(t){for(var e,r=1,n=0,i=t[0][1],a=t.length;r<a;++r)(e=t[r][1])>i&&(n=r,i=e);return n}function qa(t){return t.reduce(Ha,0)}function Ha(t,e){return t+e[1]}function Ga(t,e){return Ya(t,Math.ceil(Math.log(e.length)/Math.LN2+1))}function Ya(t,e){for(var r=-1,n=+t[0],i=(t[1]-n)/e,a=[];++r<=e;)a[r]=i*r+n;return a}function Wa(e){return[t.min(e),t.max(e)]}function Xa(t,e){return t.value-e.value}function Za(t,e){var r=t._pack_next;t._pack_next=e,e._pack_prev=t,e._pack_next=r,r._pack_prev=e}function Ja(t,e){t._pack_next=e,e._pack_prev=t}function Ka(t,e){var r=e.x-t.x,n=e.y-t.y,i=t.r+e.r;return.999*i*i>r*r+n*n}function $a(t){if((e=t.children)&&(l=e.length)){var e,r,n,i,a,o,s,l,c=1/0,u=-1/0,h=1/0,f=-1/0;if(e.forEach(Qa),(r=e[0]).x=-r.r,r.y=0,x(r),l>1&&((n=e[1]).x=n.r,n.y=0,x(n),l>2))for(eo(r,n,i=e[2]),x(i),Za(r,i),r._pack_prev=i,Za(i,n),n=r._pack_next,a=3;a<l;a++){eo(r,n,i=e[a]);var p=0,d=1,g=1;for(o=n._pack_next;o!==n;o=o._pack_next,d++)if(Ka(o,i)){p=1;break}if(1==p)for(s=r._pack_prev;s!==o._pack_prev&&!Ka(s,i);s=s._pack_prev,g++);p?(d<g||d==g&&n.r<r.r?Ja(r,n=o):Ja(r=s,n),a--):(Za(r,i),n=i,x(i))}var v=(c+u)/2,m=(h+f)/2,y=0;for(a=0;a<l;a++)(i=e[a]).x-=v,i.y-=m,y=Math.max(y,i.r+Math.sqrt(i.x*i.x+i.y*i.y));t.r=y,e.forEach(to)}function x(t){c=Math.min(t.x-t.r,c),u=Math.max(t.x+t.r,u),h=Math.min(t.y-t.r,h),f=Math.max(t.y+t.r,f)}}function Qa(t){t._pack_next=t._pack_prev=t}function to(t){delete t._pack_next,delete t._pack_prev}function eo(t,e,r){var n=t.r+r.r,i=e.x-t.x,a=e.y-t.y;if(n&&(i||a)){var o=e.r+r.r,s=i*i+a*a,l=.5+((n*=n)-(o*=o))/(2*s),c=Math.sqrt(Math.max(0,2*o*(n+s)-(n-=s)*n-o*o))/(2*s);r.x=t.x+l*i+c*a,r.y=t.y+l*a-c*i}else r.x=t.x+n,r.y=t.y}function ro(t,e){return t.parent==e.parent?1:2}function no(t){var e=t.children;return e.length?e[0]:t.t}function io(t){var e,r=t.children;return(e=r.length)?r[e-1]:t.t}function ao(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function oo(t,e,r){return t.a.parent===e.parent?t.a:r}function so(t){return{x:t.x,y:t.y,dx:t.dx,dy:t.dy}}function lo(t,e){var r=t.x+e[3],n=t.y+e[0],i=t.dx-e[1]-e[3],a=t.dy-e[0]-e[2];return i<0&&(r+=i/2,i=0),a<0&&(n+=a/2,a=0),{x:r,y:n,dx:i,dy:a}}function co(t){var e=t[0],r=t[t.length-1];return e<r?[e,r]:[r,e]}function uo(t){return t.rangeExtent?t.rangeExtent():co(t.range())}function ho(t,e,r,n){var i=r(t[0],t[1]),a=n(e[0],e[1]);return function(t){return a(i(t))}}function fo(t,e){var r,n=0,i=t.length-1,a=t[n],o=t[i];return o<a&&(r=n,n=i,i=r,r=a,a=o,o=r),t[n]=e.floor(a),t[i]=e.ceil(o),t}function po(t){return t?{floor:function(e){return Math.floor(e/t)*t},ceil:function(e){return Math.ceil(e/t)*t}}:go}t.layout.histogram=function(){var e=!0,r=Number,n=Wa,i=Ga;function a(a,o){for(var s,l,c=[],u=a.map(r,this),h=n.call(this,u,o),f=i.call(this,h,u,o),p=(o=-1,u.length),d=f.length-1,g=e?1:1/p;++o<d;)(s=c[o]=[]).dx=f[o+1]-(s.x=f[o]),s.y=0;if(d>0)for(o=-1;++o<p;)(l=u[o])>=h[0]&&l<=h[1]&&((s=c[t.bisect(f,l,1,d)-1]).y+=g,s.push(a[o]));return c}return a.value=function(t){return arguments.length?(r=t,a):r},a.range=function(t){return arguments.length?(n=ve(t),a):n},a.bins=function(t){return arguments.length?(i=\"number\"==typeof t?function(e){return Ya(e,t)}:ve(t),a):i},a.frequency=function(t){return arguments.length?(e=!!t,a):e},a},t.layout.pack=function(){var e,r=t.layout.hierarchy().sort(Xa),n=0,i=[1,1];function a(t,a){var o=r.call(this,t,a),s=o[0],l=i[0],c=i[1],u=null==e?Math.sqrt:\"function\"==typeof e?e:function(){return e};if(s.x=s.y=0,Ca(s,function(t){t.r=+u(t.value)}),Ca(s,$a),n){var h=n*(e?1:Math.max(2*s.r/l,2*s.r/c))/2;Ca(s,function(t){t.r+=h}),Ca(s,$a),Ca(s,function(t){t.r-=h})}return function t(e,r,n,i){var a=e.children;e.x=r+=i*e.x;e.y=n+=i*e.y;e.r*=i;if(a)for(var o=-1,s=a.length;++o<s;)t(a[o],r,n,i)}(s,l/2,c/2,e?1:1/Math.max(2*s.r/l,2*s.r/c)),o}return a.size=function(t){return arguments.length?(i=t,a):i},a.radius=function(t){return arguments.length?(e=null==t||\"function\"==typeof t?t:+t,a):e},a.padding=function(t){return arguments.length?(n=+t,a):n},Sa(a,r)},t.layout.tree=function(){var e=t.layout.hierarchy().sort(null).value(null),r=ro,n=[1,1],i=null;function a(t,a){var c=e.call(this,t,a),u=c[0],h=function(t){var e,r={A:null,children:[t]},n=[r];for(;null!=(e=n.pop());)for(var i,a=e.children,o=0,s=a.length;o<s;++o)n.push((a[o]=i={_:a[o],parent:e,children:(i=a[o].children)&&i.slice()||[],A:null,a:null,z:0,m:0,c:0,s:0,t:null,i:o}).a=i);return r.children[0]}(u);if(Ca(h,o),h.parent.m=-h.z,Ea(h,s),i)Ea(u,l);else{var f=u,p=u,d=u;Ea(u,function(t){t.x<f.x&&(f=t),t.x>p.x&&(p=t),t.depth>d.depth&&(d=t)});var g=r(f,p)/2-f.x,v=n[0]/(p.x+r(p,f)/2+g),m=n[1]/(d.depth||1);Ea(u,function(t){t.x=(t.x+g)*v,t.y=t.depth*m})}return c}function o(t){var e=t.children,n=t.parent.children,i=t.i?n[t.i-1]:null;if(e.length){!function(t){var e,r=0,n=0,i=t.children,a=i.length;for(;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(t);var a=(e[0].z+e[e.length-1].z)/2;i?(t.z=i.z+r(t._,i._),t.m=t.z-a):t.z=a}else i&&(t.z=i.z+r(t._,i._));t.parent.A=function(t,e,n){if(e){for(var i,a=t,o=t,s=e,l=a.parent.children[0],c=a.m,u=o.m,h=s.m,f=l.m;s=io(s),a=no(a),s&&a;)l=no(l),(o=io(o)).a=t,(i=s.z+h-a.z-c+r(s._,a._))>0&&(ao(oo(s,t,n),t,i),c+=i,u+=i),h+=s.m,c+=a.m,f+=l.m,u+=o.m;s&&!io(o)&&(o.t=s,o.m+=h-u),a&&!no(l)&&(l.t=a,l.m+=c-f,n=t)}return n}(t,i,t.parent.A||n[0])}function s(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function l(t){t.x*=n[0],t.y=t.depth*n[1]}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t)?l:null,a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null==(n=t)?null:l,a):i?n:null},Sa(a,e)},t.layout.cluster=function(){var e=t.layout.hierarchy().sort(null).value(null),r=ro,n=[1,1],i=!1;function a(a,o){var s,l=e.call(this,a,o),c=l[0],u=0;Ca(c,function(e){var n=e.children;n&&n.length?(e.x=function(t){return t.reduce(function(t,e){return t+e.x},0)/t.length}(n),e.y=function(e){return 1+t.max(e,function(t){return t.y})}(n)):(e.x=s?u+=r(e,s):0,e.y=0,s=e)});var h=function t(e){var r=e.children;return r&&r.length?t(r[0]):e}(c),f=function t(e){var r,n=e.children;return n&&(r=n.length)?t(n[r-1]):e}(c),p=h.x-r(h,f)/2,d=f.x+r(f,h)/2;return Ca(c,i?function(t){t.x=(t.x-c.x)*n[0],t.y=(c.y-t.y)*n[1]}:function(t){t.x=(t.x-p)/(d-p)*n[0],t.y=(1-(c.y?t.y/c.y:1))*n[1]}),l}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t),a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null!=(n=t),a):i?n:null},Sa(a,e)},t.layout.treemap=function(){var e,r=t.layout.hierarchy(),n=Math.round,i=[1,1],a=null,o=so,s=!1,l=\"squarify\",c=.5*(1+Math.sqrt(5));function u(t,e){for(var r,n,i=-1,a=t.length;++i<a;)n=(r=t[i]).value*(e<0?0:e),r.area=isNaN(n)||n<=0?0:n}function h(t){var e=t.children;if(e&&e.length){var r,n,i,a=o(t),s=[],c=e.slice(),f=1/0,g=\"slice\"===l?a.dx:\"dice\"===l?a.dy:\"slice-dice\"===l?1&t.depth?a.dy:a.dx:Math.min(a.dx,a.dy);for(u(c,a.dx*a.dy/t.value),s.area=0;(i=c.length)>0;)s.push(r=c[i-1]),s.area+=r.area,\"squarify\"!==l||(n=p(s,g))<=f?(c.pop(),f=n):(s.area-=s.pop().area,d(s,g,a,!1),g=Math.min(a.dx,a.dy),s.length=s.area=0,f=1/0);s.length&&(d(s,g,a,!0),s.length=s.area=0),e.forEach(h)}}function f(t){var e=t.children;if(e&&e.length){var r,n=o(t),i=e.slice(),a=[];for(u(i,n.dx*n.dy/t.value),a.area=0;r=i.pop();)a.push(r),a.area+=r.area,null!=r.z&&(d(a,r.z?n.dx:n.dy,n,!i.length),a.length=a.area=0);e.forEach(f)}}function p(t,e){for(var r,n=t.area,i=0,a=1/0,o=-1,s=t.length;++o<s;)(r=t[o].area)&&(r<a&&(a=r),r>i&&(i=r));return e*=e,(n*=n)?Math.max(e*i*c/n,n/(e*a*c)):1/0}function d(t,e,r,i){var a,o=-1,s=t.length,l=r.x,c=r.y,u=e?n(t.area/e):0;if(e==r.dx){for((i||u>r.dy)&&(u=r.dy);++o<s;)(a=t[o]).x=l,a.y=c,a.dy=u,l+=a.dx=Math.min(r.x+r.dx-l,u?n(a.area/u):0);a.z=!0,a.dx+=r.x+r.dx-l,r.y+=u,r.dy-=u}else{for((i||u>r.dx)&&(u=r.dx);++o<s;)(a=t[o]).x=l,a.y=c,a.dx=u,c+=a.dy=Math.min(r.y+r.dy-c,u?n(a.area/u):0);a.z=!1,a.dy+=r.y+r.dy-c,r.x+=u,r.dx-=u}}function g(t){var n=e||r(t),a=n[0];return a.x=a.y=0,a.value?(a.dx=i[0],a.dy=i[1]):a.dx=a.dy=0,e&&r.revalue(a),u([a],a.dx*a.dy/a.value),(e?f:h)(a),s&&(e=n),n}return g.size=function(t){return arguments.length?(i=t,g):i},g.padding=function(t){if(!arguments.length)return a;function e(e){return lo(e,t)}var r;return o=null==(a=t)?so:\"function\"==(r=typeof t)?function(e){var r=t.call(g,e,e.depth);return null==r?so(e):lo(e,\"number\"==typeof r?[r,r,r,r]:r)}:\"number\"===r?(t=[t,t,t,t],e):e,g},g.round=function(t){return arguments.length?(n=t?Math.round:Number,g):n!=Number},g.sticky=function(t){return arguments.length?(s=t,e=null,g):s},g.ratio=function(t){return arguments.length?(c=t,g):c},g.mode=function(t){return arguments.length?(l=t+\"\",g):l},Sa(g,r)},t.random={normal:function(t,e){var r=arguments.length;return r<2&&(e=1),r<1&&(t=0),function(){var r,n,i;do{i=(r=2*Math.random()-1)*r+(n=2*Math.random()-1)*n}while(!i||i>1);return t+e*r*Math.sqrt(-2*Math.log(i)/i)}},logNormal:function(){var e=t.random.normal.apply(t,arguments);return function(){return Math.exp(e())}},bates:function(e){var r=t.random.irwinHall(e);return function(){return r()/e}},irwinHall:function(t){return function(){for(var e=0,r=0;r<t;r++)e+=Math.random();return e}}},t.scale={};var go={floor:P,ceil:P};function vo(e,r,n,i){var a=[],o=[],s=0,l=Math.min(e.length,r.length)-1;for(e[l]<e[0]&&(e=e.slice().reverse(),r=r.slice().reverse());++s<=l;)a.push(n(e[s-1],e[s])),o.push(i(r[s-1],r[s]));return function(r){var n=t.bisect(e,r,1,l)-1;return o[n](a[n](r))}}function mo(e,r){return t.rebind(e,r,\"range\",\"rangeRound\",\"interpolate\",\"clamp\")}function yo(t,e){return fo(t,po(xo(t,e)[2])),fo(t,po(xo(t,e)[2])),t}function xo(t,e){null==e&&(e=10);var r=co(t),n=r[1]-r[0],i=Math.pow(10,Math.floor(Math.log(n/e)/Math.LN10)),a=e/n*i;return a<=.15?i*=10:a<=.35?i*=5:a<=.75&&(i*=2),r[0]=Math.ceil(r[0]/i)*i,r[1]=Math.floor(r[1]/i)*i+.5*i,r[2]=i,r}function bo(e,r){return t.range.apply(t,xo(e,r))}function _o(e,r,n){var i=xo(e,r);if(n){var a=Le.exec(n);if(a.shift(),\"s\"===a[8]){var o=t.formatPrefix(Math.max(y(i[0]),y(i[1])));return a[7]||(a[7]=\".\"+ko(o.scale(i[2]))),a[8]=\"f\",n=t.format(a.join(\"\")),function(t){return n(o.scale(t))+o.symbol}}a[7]||(a[7]=\".\"+function(t,e){var r=ko(e[2]);return t in wo?Math.abs(r-ko(Math.max(y(e[0]),y(e[1]))))+ +(\"e\"!==t):r-2*(\"%\"===t)}(a[8],i)),n=a.join(\"\")}else n=\",.\"+ko(i[2])+\"f\";return t.format(n)}t.scale.linear=function(){return function t(e,r,n,i){var a,o;function s(){var t=Math.min(e.length,r.length)>2?vo:ho,s=i?ma:va;return a=t(e,r,s,n),o=t(r,e,s,Zi),l}function l(t){return a(t)}l.invert=function(t){return o(t)};l.domain=function(t){return arguments.length?(e=t.map(Number),s()):e};l.range=function(t){return arguments.length?(r=t,s()):r};l.rangeRound=function(t){return l.range(t).interpolate(ca)};l.clamp=function(t){return arguments.length?(i=t,s()):i};l.interpolate=function(t){return arguments.length?(n=t,s()):n};l.ticks=function(t){return bo(e,t)};l.tickFormat=function(t,r){return _o(e,t,r)};l.nice=function(t){return yo(e,t),s()};l.copy=function(){return t(e,r,n,i)};return s()}([0,1],[0,1],Zi,!1)};var wo={s:1,g:1,p:1,r:1,e:1};function ko(t){return-Math.floor(Math.log(t)/Math.LN10+.01)}t.scale.log=function(){return function e(r,n,i,a){function o(t){return(i?Math.log(t<0?0:t):-Math.log(t>0?0:-t))/Math.log(n)}function s(t){return i?Math.pow(n,t):-Math.pow(n,-t)}function l(t){return r(o(t))}l.invert=function(t){return s(r.invert(t))};l.domain=function(t){return arguments.length?(i=t[0]>=0,r.domain((a=t.map(Number)).map(o)),l):a};l.base=function(t){return arguments.length?(n=+t,r.domain(a.map(o)),l):n};l.nice=function(){var t=fo(a.map(o),i?Math:Ao);return r.domain(t),a=t.map(s),l};l.ticks=function(){var t=co(a),e=[],r=t[0],l=t[1],c=Math.floor(o(r)),u=Math.ceil(o(l)),h=n%1?2:n;if(isFinite(u-c)){if(i){for(;c<u;c++)for(var f=1;f<h;f++)e.push(s(c)*f);e.push(s(c))}else for(e.push(s(c));c++<u;)for(var f=h-1;f>0;f--)e.push(s(c)*f);for(c=0;e[c]<r;c++);for(u=e.length;e[u-1]>l;u--);e=e.slice(c,u)}return e};l.tickFormat=function(e,r){if(!arguments.length)return To;arguments.length<2?r=To:\"function\"!=typeof r&&(r=t.format(r));var i=Math.max(1,n*e/l.ticks().length);return function(t){var e=t/s(Math.round(o(t)));return e*n<n-.5&&(e*=n),e<=i?r(t):\"\"}};l.copy=function(){return e(r.copy(),n,i,a)};return mo(l,r)}(t.scale.linear().domain([0,1]),10,!0,[1,10])};var To=t.format(\".0e\"),Ao={floor:function(t){return-Math.ceil(-t)},ceil:function(t){return-Math.floor(-t)}};function Mo(t){return function(e){return e<0?-Math.pow(-e,t):Math.pow(e,t)}}t.scale.pow=function(){return function t(e,r,n){var i=Mo(r),a=Mo(1/r);function o(t){return e(i(t))}o.invert=function(t){return a(e.invert(t))};o.domain=function(t){return arguments.length?(e.domain((n=t.map(Number)).map(i)),o):n};o.ticks=function(t){return bo(n,t)};o.tickFormat=function(t,e){return _o(n,t,e)};o.nice=function(t){return o.domain(yo(n,t))};o.exponent=function(t){return arguments.length?(i=Mo(r=t),a=Mo(1/r),e.domain(n.map(i)),o):r};o.copy=function(){return t(e.copy(),r,n)};return mo(o,e)}(t.scale.linear(),1,[0,1])},t.scale.sqrt=function(){return t.scale.pow().exponent(.5)},t.scale.ordinal=function(){return function e(r,n){var i,a,o;function s(t){return a[((i.get(t)||(\"range\"===n.t?i.set(t,r.push(t)):NaN))-1)%a.length]}function l(e,n){return t.range(r.length).map(function(t){return e+n*t})}s.domain=function(t){if(!arguments.length)return r;r=[],i=new b;for(var e,a=-1,o=t.length;++a<o;)i.has(e=t[a])||i.set(e,r.push(e));return s[n.t].apply(s,n.a)};s.range=function(t){return arguments.length?(a=t,o=0,n={t:\"range\",a:arguments},s):a};s.rangePoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=(i+c)/2,0):(c-i)/(r.length-1+e);return a=l(i+u*e/2,u),o=0,n={t:\"rangePoints\",a:arguments},s};s.rangeRoundPoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=c=Math.round((i+c)/2),0):(c-i)/(r.length-1+e)|0;return a=l(i+Math.round(u*e/2+(c-i-(r.length-1+e)*u)/2),u),o=0,n={t:\"rangeRoundPoints\",a:arguments},s};s.rangeBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],h=t[1-c],f=(h-u)/(r.length-e+2*i);return a=l(u+f*i,f),c&&a.reverse(),o=f*(1-e),n={t:\"rangeBands\",a:arguments},s};s.rangeRoundBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],h=t[1-c],f=Math.floor((h-u)/(r.length-e+2*i));return a=l(u+Math.round((h-u-(r.length-e)*f)/2),f),c&&a.reverse(),o=Math.round(f*(1-e)),n={t:\"rangeRoundBands\",a:arguments},s};s.rangeBand=function(){return o};s.rangeExtent=function(){return co(n.a[0])};s.copy=function(){return e(r,n)};return s.domain(r)}([],{t:\"range\",a:[[]]})},t.scale.category10=function(){return t.scale.ordinal().range(So)},t.scale.category20=function(){return t.scale.ordinal().range(Eo)},t.scale.category20b=function(){return t.scale.ordinal().range(Co)},t.scale.category20c=function(){return t.scale.ordinal().range(Lo)};var So=[2062260,16744206,2924588,14034728,9725885,9197131,14907330,8355711,12369186,1556175].map(se),Eo=[2062260,11454440,16744206,16759672,2924588,10018698,14034728,16750742,9725885,12955861,9197131,12885140,14907330,16234194,8355711,13092807,12369186,14408589,1556175,10410725].map(se),Co=[3750777,5395619,7040719,10264286,6519097,9216594,11915115,13556636,9202993,12426809,15186514,15190932,8666169,11356490,14049643,15177372,8077683,10834324,13528509,14589654].map(se),Lo=[3244733,7057110,10406625,13032431,15095053,16616764,16625259,16634018,3253076,7652470,10607003,13101504,7695281,10394312,12369372,14342891,6513507,9868950,12434877,14277081].map(se);function Po(){return 0}t.scale.quantile=function(){return function e(r,n){var i;function a(){var e=0,a=n.length;for(i=[];++e<a;)i[e-1]=t.quantile(r,e/a);return o}function o(e){if(!isNaN(e=+e))return n[t.bisect(i,e)]}o.domain=function(t){return arguments.length?(r=t.map(p).filter(d).sort(f),a()):r};o.range=function(t){return arguments.length?(n=t,a()):n};o.quantiles=function(){return i};o.invertExtent=function(t){return(t=n.indexOf(t))<0?[NaN,NaN]:[t>0?i[t-1]:r[0],t<i.length?i[t]:r[r.length-1]]};o.copy=function(){return e(r,n)};return a()}([],[])},t.scale.quantize=function(){return function t(e,r,n){var i,a;function o(t){return n[Math.max(0,Math.min(a,Math.floor(i*(t-e))))]}function s(){return i=n.length/(r-e),a=n.length-1,o}o.domain=function(t){return arguments.length?(e=+t[0],r=+t[t.length-1],s()):[e,r]};o.range=function(t){return arguments.length?(n=t,s()):n};o.invertExtent=function(t){return[t=(t=n.indexOf(t))<0?NaN:t/i+e,t+1/i]};o.copy=function(){return t(e,r,n)};return s()}(0,1,[0,1])},t.scale.threshold=function(){return function e(r,n){function i(e){if(e<=e)return n[t.bisect(r,e)]}i.domain=function(t){return arguments.length?(r=t,i):r};i.range=function(t){return arguments.length?(n=t,i):n};i.invertExtent=function(t){return t=n.indexOf(t),[r[t-1],r[t]]};i.copy=function(){return e(r,n)};return i}([.5],[0,1])},t.scale.identity=function(){return function t(e){function r(t){return+t}r.invert=r;r.domain=r.range=function(t){return arguments.length?(e=t.map(r),r):e};r.ticks=function(t){return bo(e,t)};r.tickFormat=function(t,r){return _o(e,t,r)};r.copy=function(){return t(e)};return r}([0,1])},t.svg={},t.svg.arc=function(){var t=zo,e=Io,r=Po,n=Oo,i=Do,a=Ro,o=Fo;function s(){var s=Math.max(0,+t.apply(this,arguments)),c=Math.max(0,+e.apply(this,arguments)),u=i.apply(this,arguments)-Et,h=a.apply(this,arguments)-Et,f=Math.abs(h-u),p=u>h?0:1;if(c<s&&(d=c,c=s,s=d),f>=St)return l(c,p)+(s?l(s,1-p):\"\")+\"Z\";var d,g,v,m,y,x,b,_,w,k,T,A,M=0,S=0,E=[];if((m=(+o.apply(this,arguments)||0)/2)&&(v=n===Oo?Math.sqrt(s*s+c*c):+n.apply(this,arguments),p||(S*=-1),c&&(S=It(v/c*Math.sin(m))),s&&(M=It(v/s*Math.sin(m)))),c){y=c*Math.cos(u+S),x=c*Math.sin(u+S),b=c*Math.cos(h-S),_=c*Math.sin(h-S);var C=Math.abs(h-u-2*S)<=At?0:1;if(S&&Bo(y,x,b,_)===p^C){var L=(u+h)/2;y=c*Math.cos(L),x=c*Math.sin(L),b=_=null}}else y=x=0;if(s){w=s*Math.cos(h-M),k=s*Math.sin(h-M),T=s*Math.cos(u+M),A=s*Math.sin(u+M);var P=Math.abs(u-h+2*M)<=At?0:1;if(M&&Bo(w,k,T,A)===1-p^P){var O=(u+h)/2;w=s*Math.cos(O),k=s*Math.sin(O),T=A=null}}else w=k=0;if(f>kt&&(d=Math.min(Math.abs(c-s)/2,+r.apply(this,arguments)))>.001){g=s<c^p?0:1;var z=d,I=d;if(f<At){var D=null==T?[w,k]:null==b?[y,x]:si([y,x],[T,A],[b,_],[w,k]),R=y-D[0],F=x-D[1],B=b-D[0],N=_-D[1],j=1/Math.sin(Math.acos((R*B+F*N)/(Math.sqrt(R*R+F*F)*Math.sqrt(B*B+N*N)))/2),U=Math.sqrt(D[0]*D[0]+D[1]*D[1]);I=Math.min(d,(s-U)/(j-1)),z=Math.min(d,(c-U)/(j+1))}if(null!=b){var V=No(null==T?[w,k]:[T,A],[y,x],c,z,p),q=No([b,_],[w,k],c,z,p);d===z?E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 0,\",g,\" \",V[1],\"A\",c,\",\",c,\" 0 \",1-p^Bo(V[1][0],V[1][1],q[1][0],q[1][1]),\",\",p,\" \",q[1],\"A\",z,\",\",z,\" 0 0,\",g,\" \",q[0]):E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 1,\",g,\" \",q[0])}else E.push(\"M\",y,\",\",x);if(null!=T){var H=No([y,x],[T,A],s,-I,p),G=No([w,k],null==b?[y,x]:[b,_],s,-I,p);d===I?E.push(\"L\",G[0],\"A\",I,\",\",I,\" 0 0,\",g,\" \",G[1],\"A\",s,\",\",s,\" 0 \",p^Bo(G[1][0],G[1][1],H[1][0],H[1][1]),\",\",1-p,\" \",H[1],\"A\",I,\",\",I,\" 0 0,\",g,\" \",H[0]):E.push(\"L\",G[0],\"A\",I,\",\",I,\" 0 0,\",g,\" \",H[0])}else E.push(\"L\",w,\",\",k)}else E.push(\"M\",y,\",\",x),null!=b&&E.push(\"A\",c,\",\",c,\" 0 \",C,\",\",p,\" \",b,\",\",_),E.push(\"L\",w,\",\",k),null!=T&&E.push(\"A\",s,\",\",s,\" 0 \",P,\",\",1-p,\" \",T,\",\",A);return E.push(\"Z\"),E.join(\"\")}function l(t,e){return\"M0,\"+t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+-t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+t}return s.innerRadius=function(e){return arguments.length?(t=ve(e),s):t},s.outerRadius=function(t){return arguments.length?(e=ve(t),s):e},s.cornerRadius=function(t){return arguments.length?(r=ve(t),s):r},s.padRadius=function(t){return arguments.length?(n=t==Oo?Oo:ve(t),s):n},s.startAngle=function(t){return arguments.length?(i=ve(t),s):i},s.endAngle=function(t){return arguments.length?(a=ve(t),s):a},s.padAngle=function(t){return arguments.length?(o=ve(t),s):o},s.centroid=function(){var r=(+t.apply(this,arguments)+ +e.apply(this,arguments))/2,n=(+i.apply(this,arguments)+ +a.apply(this,arguments))/2-Et;return[Math.cos(n)*r,Math.sin(n)*r]},s};var Oo=\"auto\";function zo(t){return t.innerRadius}function Io(t){return t.outerRadius}function Do(t){return t.startAngle}function Ro(t){return t.endAngle}function Fo(t){return t&&t.padAngle}function Bo(t,e,r,n){return(t-r)*e-(e-n)*t>0?0:1}function No(t,e,r,n,i){var a=t[0]-e[0],o=t[1]-e[1],s=(i?n:-n)/Math.sqrt(a*a+o*o),l=s*o,c=-s*a,u=t[0]+l,h=t[1]+c,f=e[0]+l,p=e[1]+c,d=(u+f)/2,g=(h+p)/2,v=f-u,m=p-h,y=v*v+m*m,x=r-n,b=u*p-f*h,_=(m<0?-1:1)*Math.sqrt(Math.max(0,x*x*y-b*b)),w=(b*m-v*_)/y,k=(-b*v-m*_)/y,T=(b*m+v*_)/y,A=(-b*v+m*_)/y,M=w-d,S=k-g,E=T-d,C=A-g;return M*M+S*S>E*E+C*C&&(w=T,k=A),[[w-l,k-c],[w*r/x,k*r/x]]}function jo(t){var e=ei,r=ri,n=Yr,i=Vo,a=i.key,o=.7;function s(a){var s,l=[],c=[],u=-1,h=a.length,f=ve(e),p=ve(r);function d(){l.push(\"M\",i(t(c),o))}for(;++u<h;)n.call(this,s=a[u],u)?c.push([+f.call(this,s,u),+p.call(this,s,u)]):c.length&&(d(),c=[]);return c.length&&d(),l.length?l.join(\"\"):null}return s.x=function(t){return arguments.length?(e=t,s):e},s.y=function(t){return arguments.length?(r=t,s):r},s.defined=function(t){return arguments.length?(n=t,s):n},s.interpolate=function(t){return arguments.length?(a=\"function\"==typeof t?i=t:(i=Uo.get(t)||Vo).key,s):a},s.tension=function(t){return arguments.length?(o=t,s):o},s}t.svg.line=function(){return jo(P)};var Uo=t.map({linear:Vo,\"linear-closed\":qo,step:function(t){var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];for(;++e<r;)i.push(\"H\",(n[0]+(n=t[e])[0])/2,\"V\",n[1]);r>1&&i.push(\"H\",n[0]);return i.join(\"\")},\"step-before\":Ho,\"step-after\":Go,basis:Xo,\"basis-open\":function(t){if(t.length<4)return Vo(t);var e,r=[],n=-1,i=t.length,a=[0],o=[0];for(;++n<3;)e=t[n],a.push(e[0]),o.push(e[1]);r.push(Zo($o,a)+\",\"+Zo($o,o)),--n;for(;++n<i;)e=t[n],a.shift(),a.push(e[0]),o.shift(),o.push(e[1]),Qo(r,a,o);return r.join(\"\")},\"basis-closed\":function(t){var e,r,n=-1,i=t.length,a=i+4,o=[],s=[];for(;++n<4;)r=t[n%i],o.push(r[0]),s.push(r[1]);e=[Zo($o,o),\",\",Zo($o,s)],--n;for(;++n<a;)r=t[n%i],o.shift(),o.push(r[0]),s.shift(),s.push(r[1]),Qo(e,o,s);return e.join(\"\")},bundle:function(t,e){var r=t.length-1;if(r)for(var n,i,a=t[0][0],o=t[0][1],s=t[r][0]-a,l=t[r][1]-o,c=-1;++c<=r;)n=t[c],i=c/r,n[0]=e*n[0]+(1-e)*(a+i*s),n[1]=e*n[1]+(1-e)*(o+i*l);return Xo(t)},cardinal:function(t,e){return t.length<3?Vo(t):t[0]+Yo(t,Wo(t,e))},\"cardinal-open\":function(t,e){return t.length<4?Vo(t):t[1]+Yo(t.slice(1,-1),Wo(t,e))},\"cardinal-closed\":function(t,e){return t.length<3?qo(t):t[0]+Yo((t.push(t[0]),t),Wo([t[t.length-2]].concat(t,[t[1]]),e))},monotone:function(t){return t.length<3?Vo(t):t[0]+Yo(t,function(t){var e,r,n,i,a=[],o=function(t){var e=0,r=t.length-1,n=[],i=t[0],a=t[1],o=n[0]=ts(i,a);for(;++e<r;)n[e]=(o+(o=ts(i=a,a=t[e+1])))/2;return n[e]=o,n}(t),s=-1,l=t.length-1;for(;++s<l;)e=ts(t[s],t[s+1]),y(e)<kt?o[s]=o[s+1]=0:(r=o[s]/e,n=o[s+1]/e,(i=r*r+n*n)>9&&(i=3*e/Math.sqrt(i),o[s]=i*r,o[s+1]=i*n));s=-1;for(;++s<=l;)i=(t[Math.min(l,s+1)][0]-t[Math.max(0,s-1)][0])/(6*(1+o[s]*o[s])),a.push([i||0,o[s]*i||0]);return a}(t))}});function Vo(t){return t.length>1?t.join(\"L\"):t+\"Z\"}function qo(t){return t.join(\"L\")+\"Z\"}function Ho(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"V\",(n=t[e])[1],\"H\",n[0]);return i.join(\"\")}function Go(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"H\",(n=t[e])[0],\"V\",n[1]);return i.join(\"\")}function Yo(t,e){if(e.length<1||t.length!=e.length&&t.length!=e.length+2)return Vo(t);var r=t.length!=e.length,n=\"\",i=t[0],a=t[1],o=e[0],s=o,l=1;if(r&&(n+=\"Q\"+(a[0]-2*o[0]/3)+\",\"+(a[1]-2*o[1]/3)+\",\"+a[0]+\",\"+a[1],i=t[1],l=2),e.length>1){s=e[1],a=t[l],l++,n+=\"C\"+(i[0]+o[0])+\",\"+(i[1]+o[1])+\",\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1];for(var c=2;c<e.length;c++,l++)a=t[l],s=e[c],n+=\"S\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1]}if(r){var u=t[l];n+=\"Q\"+(a[0]+2*s[0]/3)+\",\"+(a[1]+2*s[1]/3)+\",\"+u[0]+\",\"+u[1]}return n}function Wo(t,e){for(var r,n=[],i=(1-e)/2,a=t[0],o=t[1],s=1,l=t.length;++s<l;)r=a,a=o,o=t[s],n.push([i*(o[0]-r[0]),i*(o[1]-r[1])]);return n}function Xo(t){if(t.length<3)return Vo(t);var e=1,r=t.length,n=t[0],i=n[0],a=n[1],o=[i,i,i,(n=t[1])[0]],s=[a,a,a,n[1]],l=[i,\",\",a,\"L\",Zo($o,o),\",\",Zo($o,s)];for(t.push(t[r-1]);++e<=r;)n=t[e],o.shift(),o.push(n[0]),s.shift(),s.push(n[1]),Qo(l,o,s);return t.pop(),l.push(\"L\",n),l.join(\"\")}function Zo(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}Uo.forEach(function(t,e){e.key=t,e.closed=/-closed$/.test(t)});var Jo=[0,2/3,1/3,0],Ko=[0,1/3,2/3,0],$o=[0,1/6,2/3,1/6];function Qo(t,e,r){t.push(\"C\",Zo(Jo,e),\",\",Zo(Jo,r),\",\",Zo(Ko,e),\",\",Zo(Ko,r),\",\",Zo($o,e),\",\",Zo($o,r))}function ts(t,e){return(e[1]-t[1])/(e[0]-t[0])}function es(t){for(var e,r,n,i=-1,a=t.length;++i<a;)r=(e=t[i])[0],n=e[1]-Et,e[0]=r*Math.cos(n),e[1]=r*Math.sin(n);return t}function rs(t){var e=ei,r=ei,n=0,i=ri,a=Yr,o=Vo,s=o.key,l=o,c=\"L\",u=.7;function h(s){var h,f,p,d=[],g=[],v=[],m=-1,y=s.length,x=ve(e),b=ve(n),_=e===r?function(){return f}:ve(r),w=n===i?function(){return p}:ve(i);function k(){d.push(\"M\",o(t(v),u),c,l(t(g.reverse()),u),\"Z\")}for(;++m<y;)a.call(this,h=s[m],m)?(g.push([f=+x.call(this,h,m),p=+b.call(this,h,m)]),v.push([+_.call(this,h,m),+w.call(this,h,m)])):g.length&&(k(),g=[],v=[]);return g.length&&k(),d.length?d.join(\"\"):null}return h.x=function(t){return arguments.length?(e=r=t,h):r},h.x0=function(t){return arguments.length?(e=t,h):e},h.x1=function(t){return arguments.length?(r=t,h):r},h.y=function(t){return arguments.length?(n=i=t,h):i},h.y0=function(t){return arguments.length?(n=t,h):n},h.y1=function(t){return arguments.length?(i=t,h):i},h.defined=function(t){return arguments.length?(a=t,h):a},h.interpolate=function(t){return arguments.length?(s=\"function\"==typeof t?o=t:(o=Uo.get(t)||Vo).key,l=o.reverse||o,c=o.closed?\"M\":\"L\",h):s},h.tension=function(t){return arguments.length?(u=t,h):u},h}function ns(t){return t.radius}function is(t){return[t.x,t.y]}function as(){return 64}function os(){return\"circle\"}function ss(t){var e=Math.sqrt(t/At);return\"M0,\"+e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+-e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+e+\"Z\"}t.svg.line.radial=function(){var t=jo(es);return t.radius=t.x,delete t.x,t.angle=t.y,delete t.y,t},Ho.reverse=Go,Go.reverse=Ho,t.svg.area=function(){return rs(P)},t.svg.area.radial=function(){var t=rs(es);return t.radius=t.x,delete t.x,t.innerRadius=t.x0,delete t.x0,t.outerRadius=t.x1,delete t.x1,t.angle=t.y,delete t.y,t.startAngle=t.y0,delete t.y0,t.endAngle=t.y1,delete t.y1,t},t.svg.chord=function(){var t=Un,e=Vn,r=ns,n=Do,i=Ro;function a(r,n){var i,a,c=o(this,t,r,n),u=o(this,e,r,n);return\"M\"+c.p0+s(c.r,c.p1,c.a1-c.a0)+(a=u,(i=c).a0==a.a0&&i.a1==a.a1?l(c.r,c.p1,c.r,c.p0):l(c.r,c.p1,u.r,u.p0)+s(u.r,u.p1,u.a1-u.a0)+l(u.r,u.p1,c.r,c.p0))+\"Z\"}function o(t,e,a,o){var s=e.call(t,a,o),l=r.call(t,s,o),c=n.call(t,s,o)-Et,u=i.call(t,s,o)-Et;return{r:l,a0:c,a1:u,p0:[l*Math.cos(c),l*Math.sin(c)],p1:[l*Math.cos(u),l*Math.sin(u)]}}function s(t,e,r){return\"A\"+t+\",\"+t+\" 0 \"+ +(r>At)+\",1 \"+e}function l(t,e,r,n){return\"Q 0,0 \"+n}return a.radius=function(t){return arguments.length?(r=ve(t),a):r},a.source=function(e){return arguments.length?(t=ve(e),a):t},a.target=function(t){return arguments.length?(e=ve(t),a):e},a.startAngle=function(t){return arguments.length?(n=ve(t),a):n},a.endAngle=function(t){return arguments.length?(i=ve(t),a):i},a},t.svg.diagonal=function(){var t=Un,e=Vn,r=is;function n(n,i){var a=t.call(this,n,i),o=e.call(this,n,i),s=(a.y+o.y)/2,l=[a,{x:a.x,y:s},{x:o.x,y:s},o];return\"M\"+(l=l.map(r))[0]+\"C\"+l[1]+\" \"+l[2]+\" \"+l[3]}return n.source=function(e){return arguments.length?(t=ve(e),n):t},n.target=function(t){return arguments.length?(e=ve(t),n):e},n.projection=function(t){return arguments.length?(r=t,n):r},n},t.svg.diagonal.radial=function(){var e=t.svg.diagonal(),r=is,n=e.projection;return e.projection=function(t){return arguments.length?n(function(t){return function(){var e=t.apply(this,arguments),r=e[0],n=e[1]-Et;return[r*Math.cos(n),r*Math.sin(n)]}}(r=t)):r},e},t.svg.symbol=function(){var t=os,e=as;function r(r,n){return(ls.get(t.call(this,r,n))||ss)(e.call(this,r,n))}return r.type=function(e){return arguments.length?(t=ve(e),r):t},r.size=function(t){return arguments.length?(e=ve(t),r):e},r};var ls=t.map({circle:ss,cross:function(t){var e=Math.sqrt(t/5)/2;return\"M\"+-3*e+\",\"+-e+\"H\"+-e+\"V\"+-3*e+\"H\"+e+\"V\"+-e+\"H\"+3*e+\"V\"+e+\"H\"+e+\"V\"+3*e+\"H\"+-e+\"V\"+e+\"H\"+-3*e+\"Z\"},diamond:function(t){var e=Math.sqrt(t/(2*us)),r=e*us;return\"M0,\"+-e+\"L\"+r+\",0 0,\"+e+\" \"+-r+\",0Z\"},square:function(t){var e=Math.sqrt(t)/2;return\"M\"+-e+\",\"+-e+\"L\"+e+\",\"+-e+\" \"+e+\",\"+e+\" \"+-e+\",\"+e+\"Z\"},\"triangle-down\":function(t){var e=Math.sqrt(t/cs),r=e*cs/2;return\"M0,\"+r+\"L\"+e+\",\"+-r+\" \"+-e+\",\"+-r+\"Z\"},\"triangle-up\":function(t){var e=Math.sqrt(t/cs),r=e*cs/2;return\"M0,\"+-r+\"L\"+e+\",\"+r+\" \"+-e+\",\"+r+\"Z\"}});t.svg.symbolTypes=ls.keys();var cs=Math.sqrt(3),us=Math.tan(30*Ct);W.transition=function(t){for(var e,r,n=ds||++ms,i=bs(t),a=[],o=gs||{time:Date.now(),ease:ia,delay:0,duration:250},s=-1,l=this.length;++s<l;){a.push(e=[]);for(var c=this[s],u=-1,h=c.length;++u<h;)(r=c[u])&&_s(r,u,i,n,o),e.push(r)}return ps(a,i,n)},W.interrupt=function(t){return this.each(null==t?hs:fs(bs(t)))};var hs=fs(bs());function fs(t){return function(){var e,r,n;(e=this[t])&&(n=e[r=e.active])&&(n.timer.c=null,n.timer.t=NaN,--e.count?delete e[r]:delete this[t],e.active+=.5,n.event&&n.event.interrupt.call(this,this.__data__,n.index))}}function ps(t,e,r){return V(t,vs),t.namespace=e,t.id=r,t}var ds,gs,vs=[],ms=0;function ys(t,e,r,n){var i=t.id,a=t.namespace;return ut(t,\"function\"==typeof r?function(t,o,s){t[a][i].tween.set(e,n(r.call(t,t.__data__,o,s)))}:(r=n(r),function(t){t[a][i].tween.set(e,r)}))}function xs(t){return null==t&&(t=\"\"),function(){this.textContent=t}}function bs(t){return null==t?\"__transition__\":\"__transition_\"+t+\"__\"}function _s(t,e,r,n,i){var a,o,s,l,c,u=t[r]||(t[r]={active:0,count:0}),h=u[n];function f(r){var i=u.active,f=u[i];for(var d in f&&(f.timer.c=null,f.timer.t=NaN,--u.count,delete u[i],f.event&&f.event.interrupt.call(t,t.__data__,f.index)),u)if(+d<n){var g=u[d];g.timer.c=null,g.timer.t=NaN,--u.count,delete u[d]}o.c=p,Te(function(){return o.c&&p(r||1)&&(o.c=null,o.t=NaN),1},0,a),u.active=n,h.event&&h.event.start.call(t,t.__data__,e),c=[],h.tween.forEach(function(r,n){(n=n.call(t,t.__data__,e))&&c.push(n)}),l=h.ease,s=h.duration}function p(i){for(var a=i/s,o=l(a),f=c.length;f>0;)c[--f].call(t,o);if(a>=1)return h.event&&h.event.end.call(t,t.__data__,e),--u.count?delete u[n]:delete t[r],1}h||(a=i.time,o=Te(function(t){var e=h.delay;if(o.t=e+a,e<=t)return f(t-e);o.c=f},0,a),h=u[n]={tween:new b,time:a,timer:o,delay:i.delay,duration:i.duration,ease:i.ease,index:e},i=null,++u.count)}vs.call=W.call,vs.empty=W.empty,vs.node=W.node,vs.size=W.size,t.transition=function(e,r){return e&&e.transition?ds?e.transition(r):e:t.selection().transition(e)},t.transition.prototype=vs,vs.select=function(t){var e,r,n,i=this.id,a=this.namespace,o=[];t=X(t);for(var s=-1,l=this.length;++s<l;){o.push(e=[]);for(var c=this[s],u=-1,h=c.length;++u<h;)(n=c[u])&&(r=t.call(n,n.__data__,u,s))?(\"__data__\"in n&&(r.__data__=n.__data__),_s(r,u,a,i,n[a][i]),e.push(r)):e.push(null)}return ps(o,a,i)},vs.selectAll=function(t){var e,r,n,i,a,o=this.id,s=this.namespace,l=[];t=Z(t);for(var c=-1,u=this.length;++c<u;)for(var h=this[c],f=-1,p=h.length;++f<p;)if(n=h[f]){a=n[s][o],r=t.call(n,n.__data__,f,c),l.push(e=[]);for(var d=-1,g=r.length;++d<g;)(i=r[d])&&_s(i,d,s,o,a),e.push(i)}return ps(l,s,o)},vs.filter=function(t){var e,r,n=[];\"function\"!=typeof t&&(t=ct(t));for(var i=0,a=this.length;i<a;i++){n.push(e=[]);for(var o,s=0,l=(o=this[i]).length;s<l;s++)(r=o[s])&&t.call(r,r.__data__,s,i)&&e.push(r)}return ps(n,this.namespace,this.id)},vs.tween=function(t,e){var r=this.id,n=this.namespace;return arguments.length<2?this.node()[n][r].tween.get(t):ut(this,null==e?function(e){e[n][r].tween.remove(t)}:function(i){i[n][r].tween.set(t,e)})},vs.attr=function(e,r){if(arguments.length<2){for(r in e)this.attr(r,e[r]);return this}var n=\"transform\"==e?ga:Zi,i=t.ns.qualify(e);function a(){this.removeAttribute(i)}function o(){this.removeAttributeNS(i.space,i.local)}return ys(this,\"attr.\"+e,r,i.local?function(t){return null==t?o:(t+=\"\",function(){var e,r=this.getAttributeNS(i.space,i.local);return r!==t&&(e=n(r,t),function(t){this.setAttributeNS(i.space,i.local,e(t))})})}:function(t){return null==t?a:(t+=\"\",function(){var e,r=this.getAttribute(i);return r!==t&&(e=n(r,t),function(t){this.setAttribute(i,e(t))})})})},vs.attrTween=function(e,r){var n=t.ns.qualify(e);return this.tween(\"attr.\"+e,n.local?function(t,e){var i=r.call(this,t,e,this.getAttributeNS(n.space,n.local));return i&&function(t){this.setAttributeNS(n.space,n.local,i(t))}}:function(t,e){var i=r.call(this,t,e,this.getAttribute(n));return i&&function(t){this.setAttribute(n,i(t))}})},vs.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.style(r,t[r],e);return this}r=\"\"}function i(){this.style.removeProperty(t)}return ys(this,\"style.\"+t,e,function(e){return null==e?i:(e+=\"\",function(){var n,i=o(this).getComputedStyle(this,null).getPropertyValue(t);return i!==e&&(n=Zi(i,e),function(e){this.style.setProperty(t,n(e),r)})})})},vs.styleTween=function(t,e,r){return arguments.length<3&&(r=\"\"),this.tween(\"style.\"+t,function(n,i){var a=e.call(this,n,i,o(this).getComputedStyle(this,null).getPropertyValue(t));return a&&function(e){this.style.setProperty(t,a(e),r)}})},vs.text=function(t){return ys(this,\"text\",t,xs)},vs.remove=function(){var t=this.namespace;return this.each(\"end.transition\",function(){var e;this[t].count<2&&(e=this.parentNode)&&e.removeChild(this)})},vs.ease=function(e){var r=this.id,n=this.namespace;return arguments.length<1?this.node()[n][r].ease:(\"function\"!=typeof e&&(e=t.ease.apply(t,arguments)),ut(this,function(t){t[n][r].ease=e}))},vs.delay=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].delay:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].delay=+t.call(n,n.__data__,i,a)}:(t=+t,function(n){n[r][e].delay=t}))},vs.duration=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].duration:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].duration=Math.max(1,t.call(n,n.__data__,i,a))}:(t=Math.max(1,t),function(n){n[r][e].duration=t}))},vs.each=function(e,r){var n=this.id,i=this.namespace;if(arguments.length<2){var a=gs,o=ds;try{ds=n,ut(this,function(t,r,a){gs=t[i][n],e.call(t,t.__data__,r,a)})}finally{gs=a,ds=o}}else ut(this,function(a){var o=a[i][n];(o.event||(o.event=t.dispatch(\"start\",\"end\",\"interrupt\"))).on(e,r)});return this},vs.transition=function(){for(var t,e,r,n=this.id,i=++ms,a=this.namespace,o=[],s=0,l=this.length;s<l;s++){o.push(t=[]);for(var c,u=0,h=(c=this[s]).length;u<h;u++)(e=c[u])&&_s(e,u,a,i,{time:(r=e[a][n]).time,ease:r.ease,delay:r.delay+r.duration,duration:r.duration}),t.push(e)}return ps(o,a,i)},t.svg.axis=function(){var e,r=t.scale.linear(),i=ws,a=6,o=6,s=3,l=[10],c=null;function u(n){n.each(function(){var n,u=t.select(this),h=this.__chart__||r,f=this.__chart__=r.copy(),p=null==c?f.ticks?f.ticks.apply(f,l):f.domain():c,d=null==e?f.tickFormat?f.tickFormat.apply(f,l):P:e,g=u.selectAll(\".tick\").data(p,f),v=g.enter().insert(\"g\",\".domain\").attr(\"class\",\"tick\").style(\"opacity\",kt),m=t.transition(g.exit()).style(\"opacity\",kt).remove(),y=t.transition(g.order()).style(\"opacity\",1),x=Math.max(a,0)+s,b=uo(f),_=u.selectAll(\".domain\").data([0]),w=(_.enter().append(\"path\").attr(\"class\",\"domain\"),t.transition(_));v.append(\"line\"),v.append(\"text\");var k,T,A,M,S=v.select(\"line\"),E=y.select(\"line\"),C=g.select(\"text\").text(d),L=v.select(\"text\"),O=y.select(\"text\"),z=\"top\"===i||\"left\"===i?-1:1;if(\"bottom\"===i||\"top\"===i?(n=Ts,k=\"x\",A=\"y\",T=\"x2\",M=\"y2\",C.attr(\"dy\",z<0?\"0em\":\".71em\").style(\"text-anchor\",\"middle\"),w.attr(\"d\",\"M\"+b[0]+\",\"+z*o+\"V0H\"+b[1]+\"V\"+z*o)):(n=As,k=\"y\",A=\"x\",T=\"y2\",M=\"x2\",C.attr(\"dy\",\".32em\").style(\"text-anchor\",z<0?\"end\":\"start\"),w.attr(\"d\",\"M\"+z*o+\",\"+b[0]+\"H0V\"+b[1]+\"H\"+z*o)),S.attr(M,z*a),L.attr(A,z*x),E.attr(T,0).attr(M,z*a),O.attr(k,0).attr(A,z*x),f.rangeBand){var I=f,D=I.rangeBand()/2;h=f=function(t){return I(t)+D}}else h.rangeBand?h=f:m.call(n,f,h);v.call(n,h,f),y.call(n,f,f)})}return u.scale=function(t){return arguments.length?(r=t,u):r},u.orient=function(t){return arguments.length?(i=t in ks?t+\"\":ws,u):i},u.ticks=function(){return arguments.length?(l=n(arguments),u):l},u.tickValues=function(t){return arguments.length?(c=t,u):c},u.tickFormat=function(t){return arguments.length?(e=t,u):e},u.tickSize=function(t){var e=arguments.length;return e?(a=+t,o=+arguments[e-1],u):a},u.innerTickSize=function(t){return arguments.length?(a=+t,u):a},u.outerTickSize=function(t){return arguments.length?(o=+t,u):o},u.tickPadding=function(t){return arguments.length?(s=+t,u):s},u.tickSubdivide=function(){return arguments.length&&u},u};var ws=\"bottom\",ks={top:1,right:1,bottom:1,left:1};function Ts(t,e,r){t.attr(\"transform\",function(t){var n=e(t);return\"translate(\"+(isFinite(n)?n:r(t))+\",0)\"})}function As(t,e,r){t.attr(\"transform\",function(t){var n=e(t);return\"translate(0,\"+(isFinite(n)?n:r(t))+\")\"})}t.svg.brush=function(){var e,r,n=j(f,\"brushstart\",\"brush\",\"brushend\"),i=null,a=null,s=[0,0],l=[0,0],c=!0,u=!0,h=Ss[0];function f(e){e.each(function(){var e=t.select(this).style(\"pointer-events\",\"all\").style(\"-webkit-tap-highlight-color\",\"rgba(0,0,0,0)\").on(\"mousedown.brush\",v).on(\"touchstart.brush\",v),r=e.selectAll(\".background\").data([0]);r.enter().append(\"rect\").attr(\"class\",\"background\").style(\"visibility\",\"hidden\").style(\"cursor\",\"crosshair\"),e.selectAll(\".extent\").data([0]).enter().append(\"rect\").attr(\"class\",\"extent\").style(\"cursor\",\"move\");var n=e.selectAll(\".resize\").data(h,P);n.exit().remove(),n.enter().append(\"g\").attr(\"class\",function(t){return\"resize \"+t}).style(\"cursor\",function(t){return Ms[t]}).append(\"rect\").attr(\"x\",function(t){return/[ew]$/.test(t)?-3:null}).attr(\"y\",function(t){return/^[ns]/.test(t)?-3:null}).attr(\"width\",6).attr(\"height\",6).style(\"visibility\",\"hidden\"),n.style(\"display\",f.empty()?\"none\":null);var o,s=t.transition(e),l=t.transition(r);i&&(o=uo(i),l.attr(\"x\",o[0]).attr(\"width\",o[1]-o[0]),d(s)),a&&(o=uo(a),l.attr(\"y\",o[0]).attr(\"height\",o[1]-o[0]),g(s)),p(s)})}function p(t){t.selectAll(\".resize\").attr(\"transform\",function(t){return\"translate(\"+s[+/e$/.test(t)]+\",\"+l[+/^s/.test(t)]+\")\"})}function d(t){t.select(\".extent\").attr(\"x\",s[0]),t.selectAll(\".extent,.n>rect,.s>rect\").attr(\"width\",s[1]-s[0])}function g(t){t.select(\".extent\").attr(\"y\",l[0]),t.selectAll(\".extent,.e>rect,.w>rect\").attr(\"height\",l[1]-l[0])}function v(){var h,v,m=this,y=t.select(t.event.target),x=n.of(m,arguments),b=t.select(m),_=y.datum(),w=!/^(n|s)$/.test(_)&&i,k=!/^(e|w)$/.test(_)&&a,T=y.classed(\"extent\"),A=xt(m),M=t.mouse(m),S=t.select(o(m)).on(\"keydown.brush\",function(){32==t.event.keyCode&&(T||(h=null,M[0]-=s[1],M[1]-=l[1],T=2),B())}).on(\"keyup.brush\",function(){32==t.event.keyCode&&2==T&&(M[0]+=s[1],M[1]+=l[1],T=0,B())});if(t.event.changedTouches?S.on(\"touchmove.brush\",L).on(\"touchend.brush\",O):S.on(\"mousemove.brush\",L).on(\"mouseup.brush\",O),b.interrupt().selectAll(\"*\").interrupt(),T)M[0]=s[0]-M[0],M[1]=l[0]-M[1];else if(_){var E=+/w$/.test(_),C=+/^n/.test(_);v=[s[1-E]-M[0],l[1-C]-M[1]],M[0]=s[E],M[1]=l[C]}else t.event.altKey&&(h=M.slice());function L(){var e=t.mouse(m),r=!1;v&&(e[0]+=v[0],e[1]+=v[1]),T||(t.event.altKey?(h||(h=[(s[0]+s[1])/2,(l[0]+l[1])/2]),M[0]=s[+(e[0]<h[0])],M[1]=l[+(e[1]<h[1])]):h=null),w&&P(e,i,0)&&(d(b),r=!0),k&&P(e,a,1)&&(g(b),r=!0),r&&(p(b),x({type:\"brush\",mode:T?\"move\":\"resize\"}))}function P(t,n,i){var a,o,f=uo(n),p=f[0],d=f[1],g=M[i],v=i?l:s,m=v[1]-v[0];if(T&&(p-=g,d-=m+g),a=(i?u:c)?Math.max(p,Math.min(d,t[i])):t[i],T?o=(a+=g)+m:(h&&(g=Math.max(p,Math.min(d,2*h[i]-a))),g<a?(o=a,a=g):o=g),v[0]!=a||v[1]!=o)return i?r=null:e=null,v[0]=a,v[1]=o,!0}function O(){L(),b.style(\"pointer-events\",\"all\").selectAll(\".resize\").style(\"display\",f.empty()?\"none\":null),t.select(\"body\").style(\"cursor\",null),S.on(\"mousemove.brush\",null).on(\"mouseup.brush\",null).on(\"touchmove.brush\",null).on(\"touchend.brush\",null).on(\"keydown.brush\",null).on(\"keyup.brush\",null),A(),x({type:\"brushend\"})}b.style(\"pointer-events\",\"none\").selectAll(\".resize\").style(\"display\",null),t.select(\"body\").style(\"cursor\",y.style(\"cursor\")),x({type:\"brushstart\"}),L()}return f.event=function(i){i.each(function(){var i=n.of(this,arguments),a={x:s,y:l,i:e,j:r},o=this.__chart__||a;this.__chart__=a,ds?t.select(this).transition().each(\"start.brush\",function(){e=o.i,r=o.j,s=o.x,l=o.y,i({type:\"brushstart\"})}).tween(\"brush:brush\",function(){var t=Ji(s,a.x),n=Ji(l,a.y);return e=r=null,function(e){s=a.x=t(e),l=a.y=n(e),i({type:\"brush\",mode:\"resize\"})}}).each(\"end.brush\",function(){e=a.i,r=a.j,i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"})}):(i({type:\"brushstart\"}),i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"}))})},f.x=function(t){return arguments.length?(h=Ss[!(i=t)<<1|!a],f):i},f.y=function(t){return arguments.length?(h=Ss[!i<<1|!(a=t)],f):a},f.clamp=function(t){return arguments.length?(i&&a?(c=!!t[0],u=!!t[1]):i?c=!!t:a&&(u=!!t),f):i&&a?[c,u]:i?c:a?u:null},f.extent=function(t){var n,o,c,u,h;return arguments.length?(i&&(n=t[0],o=t[1],a&&(n=n[0],o=o[0]),e=[n,o],i.invert&&(n=i(n),o=i(o)),o<n&&(h=n,n=o,o=h),n==s[0]&&o==s[1]||(s=[n,o])),a&&(c=t[0],u=t[1],i&&(c=c[1],u=u[1]),r=[c,u],a.invert&&(c=a(c),u=a(u)),u<c&&(h=c,c=u,u=h),c==l[0]&&u==l[1]||(l=[c,u])),f):(i&&(e?(n=e[0],o=e[1]):(n=s[0],o=s[1],i.invert&&(n=i.invert(n),o=i.invert(o)),o<n&&(h=n,n=o,o=h))),a&&(r?(c=r[0],u=r[1]):(c=l[0],u=l[1],a.invert&&(c=a.invert(c),u=a.invert(u)),u<c&&(h=c,c=u,u=h))),i&&a?[[n,c],[o,u]]:i?[n,o]:a&&[c,u])},f.clear=function(){return f.empty()||(s=[0,0],l=[0,0],e=r=null),f},f.empty=function(){return!!i&&s[0]==s[1]||!!a&&l[0]==l[1]},t.rebind(f,n,\"on\")};var Ms={n:\"ns-resize\",e:\"ew-resize\",s:\"ns-resize\",w:\"ew-resize\",nw:\"nwse-resize\",ne:\"nesw-resize\",se:\"nwse-resize\",sw:\"nesw-resize\"},Ss=[[\"n\",\"e\",\"s\",\"w\",\"nw\",\"ne\",\"se\",\"sw\"],[\"e\",\"w\"],[\"n\",\"s\"],[]],Es=ze.format=sr.timeFormat,Cs=Es.utc,Ls=Cs(\"%Y-%m-%dT%H:%M:%S.%LZ\");function Ps(t){return t.toISOString()}function Os(e,r,n){function i(t){return e(t)}function a(e,n){var i=(e[1]-e[0])/n,a=t.bisect(Is,i);return a==Is.length?[r.year,xo(e.map(function(t){return t/31536e6}),n)[2]]:a?r[i/Is[a-1]<Is[a]/i?a-1:a]:[Fs,xo(e,n)[2]]}return i.invert=function(t){return zs(e.invert(t))},i.domain=function(t){return arguments.length?(e.domain(t),i):e.domain().map(zs)},i.nice=function(t,e){var r=i.domain(),n=co(r),o=null==t?a(n,10):\"number\"==typeof t&&a(n,t);function s(r){return!isNaN(r)&&!t.range(r,zs(+r+1),e).length}return o&&(t=o[0],e=o[1]),i.domain(fo(r,e>1?{floor:function(e){for(;s(e=t.floor(e));)e=zs(e-1);return e},ceil:function(e){for(;s(e=t.ceil(e));)e=zs(+e+1);return e}}:t))},i.ticks=function(t,e){var r=co(i.domain()),n=null==t?a(r,10):\"number\"==typeof t?a(r,t):!t.range&&[{range:t},e];return n&&(t=n[0],e=n[1]),t.range(r[0],zs(+r[1]+1),e<1?1:e)},i.tickFormat=function(){return n},i.copy=function(){return Os(e.copy(),r,n)},mo(i,e)}function zs(t){return new Date(t)}Es.iso=Date.prototype.toISOString&&+new Date(\"2000-01-01T00:00:00.000Z\")?Ps:Ls,Ps.parse=function(t){var e=new Date(t);return isNaN(e)?null:e},Ps.toString=Ls.toString,ze.second=Fe(function(t){return new Ie(1e3*Math.floor(t/1e3))},function(t,e){t.setTime(t.getTime()+1e3*Math.floor(e))},function(t){return t.getSeconds()}),ze.seconds=ze.second.range,ze.seconds.utc=ze.second.utc.range,ze.minute=Fe(function(t){return new Ie(6e4*Math.floor(t/6e4))},function(t,e){t.setTime(t.getTime()+6e4*Math.floor(e))},function(t){return t.getMinutes()}),ze.minutes=ze.minute.range,ze.minutes.utc=ze.minute.utc.range,ze.hour=Fe(function(t){var e=t.getTimezoneOffset()/60;return new Ie(36e5*(Math.floor(t/36e5-e)+e))},function(t,e){t.setTime(t.getTime()+36e5*Math.floor(e))},function(t){return t.getHours()}),ze.hours=ze.hour.range,ze.hours.utc=ze.hour.utc.range,ze.month=Fe(function(t){return(t=ze.day(t)).setDate(1),t},function(t,e){t.setMonth(t.getMonth()+e)},function(t){return t.getMonth()}),ze.months=ze.month.range,ze.months.utc=ze.month.utc.range;var Is=[1e3,5e3,15e3,3e4,6e4,3e5,9e5,18e5,36e5,108e5,216e5,432e5,864e5,1728e5,6048e5,2592e6,7776e6,31536e6],Ds=[[ze.second,1],[ze.second,5],[ze.second,15],[ze.second,30],[ze.minute,1],[ze.minute,5],[ze.minute,15],[ze.minute,30],[ze.hour,1],[ze.hour,3],[ze.hour,6],[ze.hour,12],[ze.day,1],[ze.day,2],[ze.week,1],[ze.month,1],[ze.month,3],[ze.year,1]],Rs=Es.multi([[\".%L\",function(t){return t.getMilliseconds()}],[\":%S\",function(t){return t.getSeconds()}],[\"%I:%M\",function(t){return t.getMinutes()}],[\"%I %p\",function(t){return t.getHours()}],[\"%a %d\",function(t){return t.getDay()&&1!=t.getDate()}],[\"%b %d\",function(t){return 1!=t.getDate()}],[\"%B\",function(t){return t.getMonth()}],[\"%Y\",Yr]]),Fs={range:function(e,r,n){return t.range(Math.ceil(e/n)*n,+r,n).map(zs)},floor:P,ceil:P};Ds.year=ze.year,ze.scale=function(){return Os(t.scale.linear(),Ds,Rs)};var Bs=Ds.map(function(t){return[t[0].utc,t[1]]}),Ns=Cs.multi([[\".%L\",function(t){return t.getUTCMilliseconds()}],[\":%S\",function(t){return t.getUTCSeconds()}],[\"%I:%M\",function(t){return t.getUTCMinutes()}],[\"%I %p\",function(t){return t.getUTCHours()}],[\"%a %d\",function(t){return t.getUTCDay()&&1!=t.getUTCDate()}],[\"%b %d\",function(t){return 1!=t.getUTCDate()}],[\"%B\",function(t){return t.getUTCMonth()}],[\"%Y\",Yr]]);function js(t){return JSON.parse(t.responseText)}function Us(t){var e=i.createRange();return e.selectNode(i.body),e.createContextualFragment(t.responseText)}Bs.year=ze.year.utc,ze.scale.utc=function(){return Os(t.scale.linear(),Bs,Ns)},t.text=me(function(t){return t.responseText}),t.json=function(t,e){return ye(t,\"application/json\",js,e)},t.html=function(t,e){return ye(t,\"text/html\",Us,e)},t.xml=me(function(t){return t.responseXML}),\"object\"==typeof e&&e.exports?e.exports=t:this.d3=t}()},{}],164:[function(t,e,r){e.exports=function(){for(var t=0;t<arguments.length;t++)if(void 0!==arguments[t])return arguments[t]}},{}],165:[function(t,e,r){\"use strict\";var n=t(\"incremental-convex-hull\"),i=t(\"uniq\");function a(t,e){this.point=t,this.index=e}function o(t,e){for(var r=t.point,n=e.point,i=r.length,a=0;a<i;++a){var o=n[a]-r[a];if(o)return o}return 0}e.exports=function(t,e){var r=t.length;if(0===r)return[];var s=t[0].length;if(s<1)return[];if(1===s)return function(t,e,r){if(1===t)return r?[[-1,0]]:[];var n=e.map(function(t,e){return[t[0],e]});n.sort(function(t,e){return t[0]-e[0]});for(var i=new Array(t-1),a=1;a<t;++a){var o=n[a-1],s=n[a];i[a-1]=[o[1],s[1]]}r&&i.push([-1,i[0][1]],[i[t-1][1],-1]);return i}(r,t,e);for(var l=new Array(r),c=1,u=0;u<r;++u){for(var h=t[u],f=new Array(s+1),p=0,d=0;d<s;++d){var g=h[d];f[d]=g,p+=g*g}f[s]=p,l[u]=new a(f,u),c=Math.max(p,c)}i(l,o),r=l.length;for(var v=new Array(r+s+1),m=new Array(r+s+1),y=(s+1)*(s+1)*c,x=new Array(s+1),u=0;u<=s;++u)x[u]=0;x[s]=y,v[0]=x.slice(),m[0]=-1;for(var u=0;u<=s;++u){var f=x.slice();f[u]=1,v[u+1]=f,m[u+1]=-1}for(var u=0;u<r;++u){var b=l[u];v[u+s+1]=b.point,m[u+s+1]=b.index}var _=n(v,!1);_=e?_.filter(function(t){for(var e=0,r=0;r<=s;++r){var n=m[t[r]];if(n<0&&++e>=2)return!1;t[r]=n}return!0}):_.filter(function(t){for(var e=0;e<=s;++e){var r=m[t[e]];if(r<0)return!1;t[e]=r}return!0});if(1&s)for(var u=0;u<_.length;++u){var b=_[u],f=b[0];b[0]=b[1],b[1]=f}return _}},{\"incremental-convex-hull\":413,uniq:547}],166:[function(t,e,r){\"use strict\";e.exports=a;var n=(a.canvas=document.createElement(\"canvas\")).getContext(\"2d\"),i=o([32,126]);function a(t,e){Array.isArray(t)&&(t=t.join(\", \"));var r,a={},s=16,l=.05;e&&(2===e.length&&\"number\"==typeof e[0]?r=o(e):Array.isArray(e)?r=e:(e.o?r=o(e.o):e.pairs&&(r=e.pairs),e.fontSize&&(s=e.fontSize),null!=e.threshold&&(l=e.threshold))),r||(r=i),n.font=s+\"px \"+t;for(var c=0;c<r.length;c++){var u=r[c],h=n.measureText(u[0]).width+n.measureText(u[1]).width,f=n.measureText(u).width;if(Math.abs(h-f)>s*l){var p=(f-h)/s;a[u]=1e3*p}}return a}function o(t){for(var e=[],r=t[0];r<=t[1];r++)for(var n=String.fromCharCode(r),i=t[0];i<t[1];i++){var a=n+String.fromCharCode(i);e.push(a)}return e}a.createPairs=o,a.ascii=i},{}],167:[function(t,e,r){(function(t){var r=!1;if(\"undefined\"!=typeof Float64Array){var n=new Float64Array(1),i=new Uint32Array(n.buffer);if(n[0]=1,r=!0,1072693248===i[1]){e.exports=function(t){return n[0]=t,[i[0],i[1]]},e.exports.pack=function(t,e){return i[0]=t,i[1]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[0]},e.exports.hi=function(t){return n[0]=t,i[1]}}else if(1072693248===i[0]){e.exports=function(t){return n[0]=t,[i[1],i[0]]},e.exports.pack=function(t,e){return i[1]=t,i[0]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[1]},e.exports.hi=function(t){return n[0]=t,i[0]}}else r=!1}if(!r){var a=new t(8);e.exports=function(t){return a.writeDoubleLE(t,0,!0),[a.readUInt32LE(0,!0),a.readUInt32LE(4,!0)]},e.exports.pack=function(t,e){return a.writeUInt32LE(t,0,!0),a.writeUInt32LE(e,4,!0),a.readDoubleLE(0,!0)},e.exports.lo=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(0,!0)},e.exports.hi=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(4,!0)}}e.exports.sign=function(t){return e.exports.hi(t)>>>31},e.exports.exponent=function(t){return(e.exports.hi(t)<<1>>>21)-1023},e.exports.fraction=function(t){var r=e.exports.lo(t),n=e.exports.hi(t),i=1048575&n;return 2146435072&n&&(i+=1<<20),[r,i]},e.exports.denormalized=function(t){return!(2146435072&e.exports.hi(t))}}).call(this,t(\"buffer\").Buffer)},{buffer:105}],168:[function(t,e,r){var n=t(\"abs-svg-path\"),i=t(\"normalize-svg-path\"),a={M:\"moveTo\",C:\"bezierCurveTo\"};e.exports=function(t,e){t.beginPath(),i(n(e)).forEach(function(e){var r=e[0],n=e.slice(1);t[a[r]].apply(t,n)}),t.closePath()}},{\"abs-svg-path\":60,\"normalize-svg-path\":452}],169:[function(t,e,r){e.exports=function(t){switch(t){case\"int8\":return Int8Array;case\"int16\":return Int16Array;case\"int32\":return Int32Array;case\"uint8\":return Uint8Array;case\"uint16\":return Uint16Array;case\"uint32\":return Uint32Array;case\"float32\":return Float32Array;case\"float64\":return Float64Array;case\"array\":return Array;case\"uint8_clamped\":return Uint8ClampedArray}}},{}],170:[function(t,e,r){\"use strict\";e.exports=function(t,e){switch(\"undefined\"==typeof e&&(e=0),typeof t){case\"number\":if(t>0)return function(t,e){var r,n;for(r=new Array(t),n=0;n<t;++n)r[n]=e;return r}(0|t,e);break;case\"object\":if(\"number\"==typeof t.length)return function t(e,r,n){var i=0|e[n];if(i<=0)return[];var a,o=new Array(i);if(n===e.length-1)for(a=0;a<i;++a)o[a]=r;else for(a=0;a<i;++a)o[a]=t(e,r,n+1);return o}(t,e,0)}return[]}},{}],171:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(\"number\"!=typeof e){e=0;for(var i=0;i<r;++i){var a=t[i];e=Math.max(e,a[0],a[1])}e=1+(0|e)}e|=0;for(var o=new Array(e),i=0;i<e;++i)o[i]=[];for(var i=0;i<r;++i){var a=t[i];o[a[0]].push(a[1]),o[a[1]].push(a[0])}for(var s=0;s<e;++s)n(o[s],function(t,e){return t-e});return o};var n=t(\"uniq\")},{uniq:547}],172:[function(t,e,r){var n=t(\"strongly-connected-components\");e.exports=function(t){var e,r=[],i=[],a=[],o={},s=[];function l(t){var r,n,u=!1;for(i.push(t),a[t]=!0,r=0;r<s[t].length;r++)(n=s[t][r])===e?(c(e,i),u=!0):a[n]||(u=l(n));if(u)!function t(e){a[e]=!1,o.hasOwnProperty(e)&&Object.keys(o[e]).forEach(function(r){delete o[e][r],a[r]&&t(r)})}(t);else for(r=0;r<s[t].length;r++){n=s[t][r];var h=o[n];h||(h={},o[n]=h),h[n]=!0}return i.pop(),u}function c(t,e){var n=[].concat(e).concat(t);r.push(n)}function u(e){!function(e){for(var r=0;r<t.length;r++)r<e&&(t[r]=[]),t[r]=t[r].filter(function(t){return t>=e})}(e);for(var r,i=n(t).components.filter(function(t){return t.length>1}),a=1/0,o=0;o<i.length;o++)for(var s=0;s<i[o].length;s++)i[o][s]<a&&(a=i[o][s],r=o);var l=i[r];return!!l&&{leastVertex:a,adjList:t.map(function(t,e){return-1===l.indexOf(e)?[]:t.filter(function(t){return-1!==l.indexOf(t)})})}}e=0;for(var h=t.length;e<h;){var f=u(e);if(e=f.leastVertex,s=f.adjList){for(var p=0;p<s.length;p++)for(var d=0;d<s[p].length;d++){var g=s[p][d];a[+g]=!1,o[g]={}}l(e),e+=1}else e=h}return r}},{\"strongly-connected-components\":530}],173:[function(t,e,r){\"use strict\";var n=t(\"../../object/valid-value\");e.exports=function(){return n(this).length=0,this}},{\"../../object/valid-value\":205}],174:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Array.from:t(\"./shim\")},{\"./is-implemented\":175,\"./shim\":176}],175:[function(t,e,r){\"use strict\";e.exports=function(){var t,e,r=Array.from;return\"function\"==typeof r&&(e=r(t=[\"raz\",\"dwa\"]),Boolean(e&&e!==t&&\"dwa\"===e[1]))}},{}],176:[function(t,e,r){\"use strict\";var n=t(\"es6-symbol\").iterator,i=t(\"../../function/is-arguments\"),a=t(\"../../function/is-function\"),o=t(\"../../number/to-pos-integer\"),s=t(\"../../object/valid-callable\"),l=t(\"../../object/valid-value\"),c=t(\"../../object/is-value\"),u=t(\"../../string/is-string\"),h=Array.isArray,f=Function.prototype.call,p={configurable:!0,enumerable:!0,writable:!0,value:null},d=Object.defineProperty;e.exports=function(t){var e,r,g,v,m,y,x,b,_,w,k=arguments[1],T=arguments[2];if(t=Object(l(t)),c(k)&&s(k),this&&this!==Array&&a(this))e=this;else{if(!k){if(i(t))return 1!==(m=t.length)?Array.apply(null,t):((v=new Array(1))[0]=t[0],v);if(h(t)){for(v=new Array(m=t.length),r=0;r<m;++r)v[r]=t[r];return v}}v=[]}if(!h(t))if(void 0!==(_=t[n])){for(x=s(_).call(t),e&&(v=new e),b=x.next(),r=0;!b.done;)w=k?f.call(k,T,b.value,r):b.value,e?(p.value=w,d(v,r,p)):v[r]=w,b=x.next(),++r;m=r}else if(u(t)){for(m=t.length,e&&(v=new e),r=0,g=0;r<m;++r)w=t[r],r+1<m&&(y=w.charCodeAt(0))>=55296&&y<=56319&&(w+=t[++r]),w=k?f.call(k,T,w,g):w,e?(p.value=w,d(v,g,p)):v[g]=w,++g;m=g}if(void 0===m)for(m=o(t.length),e&&(v=new e(m)),r=0;r<m;++r)w=k?f.call(k,T,t[r],r):t[r],e?(p.value=w,d(v,r,p)):v[r]=w;return e&&(p.value=null,v.length=m),v}},{\"../../function/is-arguments\":177,\"../../function/is-function\":178,\"../../number/to-pos-integer\":184,\"../../object/is-value\":194,\"../../object/valid-callable\":203,\"../../object/valid-value\":205,\"../../string/is-string\":209,\"es6-symbol\":219}],177:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(function(){return arguments}());e.exports=function(t){return n.call(t)===i}},{}],178:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(t(\"./noop\"));e.exports=function(t){return\"function\"==typeof t&&n.call(t)===i}},{\"./noop\":179}],179:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],180:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Math.sign:t(\"./shim\")},{\"./is-implemented\":181,\"./shim\":182}],181:[function(t,e,r){\"use strict\";e.exports=function(){var t=Math.sign;return\"function\"==typeof t&&(1===t(10)&&-1===t(-20))}},{}],182:[function(t,e,r){\"use strict\";e.exports=function(t){return t=Number(t),isNaN(t)||0===t?t:t>0?1:-1}},{}],183:[function(t,e,r){\"use strict\";var n=t(\"../math/sign\"),i=Math.abs,a=Math.floor;e.exports=function(t){return isNaN(t)?0:0!==(t=Number(t))&&isFinite(t)?n(t)*a(i(t)):t}},{\"../math/sign\":180}],184:[function(t,e,r){\"use strict\";var n=t(\"./to-integer\"),i=Math.max;e.exports=function(t){return i(0,n(t))}},{\"./to-integer\":183}],185:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./valid-value\"),a=Function.prototype.bind,o=Function.prototype.call,s=Object.keys,l=Object.prototype.propertyIsEnumerable;e.exports=function(t,e){return function(r,c){var u,h=arguments[2],f=arguments[3];return r=Object(i(r)),n(c),u=s(r),f&&u.sort(\"function\"==typeof f?a.call(f,r):void 0),\"function\"!=typeof t&&(t=u[t]),o.call(t,u,function(t,n){return l.call(r,t)?o.call(c,h,r[t],t,r,n):e})}}},{\"./valid-callable\":203,\"./valid-value\":205}],186:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.assign:t(\"./shim\")},{\"./is-implemented\":187,\"./shim\":188}],187:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=Object.assign;return\"function\"==typeof e&&(e(t={foo:\"raz\"},{bar:\"dwa\"},{trzy:\"trzy\"}),t.foo+t.bar+t.trzy===\"razdwatrzy\")}},{}],188:[function(t,e,r){\"use strict\";var n=t(\"../keys\"),i=t(\"../valid-value\"),a=Math.max;e.exports=function(t,e){var r,o,s,l=a(arguments.length,2);for(t=Object(i(t)),s=function(n){try{t[n]=e[n]}catch(t){r||(r=t)}},o=1;o<l;++o)e=arguments[o],n(e).forEach(s);if(void 0!==r)throw r;return t}},{\"../keys\":195,\"../valid-value\":205}],189:[function(t,e,r){\"use strict\";var n=t(\"../array/from\"),i=t(\"./assign\"),a=t(\"./valid-value\");e.exports=function(t){var e=Object(a(t)),r=arguments[1],o=Object(arguments[2]);if(e!==t&&!r)return e;var s={};return r?n(r,function(e){(o.ensure||e in t)&&(s[e]=t[e])}):i(s,t),s}},{\"../array/from\":174,\"./assign\":186,\"./valid-value\":205}],190:[function(t,e,r){\"use strict\";var n,i,a,o,s=Object.create;t(\"./set-prototype-of/is-implemented\")()||(n=t(\"./set-prototype-of/shim\")),e.exports=n?1!==n.level?s:(i={},a={},o={configurable:!1,enumerable:!1,writable:!0,value:void 0},Object.getOwnPropertyNames(Object.prototype).forEach(function(t){a[t]=\"__proto__\"!==t?o:{configurable:!0,enumerable:!1,writable:!0,value:void 0}}),Object.defineProperties(i,a),Object.defineProperty(n,\"nullPolyfill\",{configurable:!1,enumerable:!1,writable:!1,value:i}),function(t,e){return s(null===t?i:t,e)}):s},{\"./set-prototype-of/is-implemented\":201,\"./set-prototype-of/shim\":202}],191:[function(t,e,r){\"use strict\";e.exports=t(\"./_iterate\")(\"forEach\")},{\"./_iterate\":185}],192:[function(t,e,r){\"use strict\";e.exports=function(t){return\"function\"==typeof t}},{}],193:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i={function:!0,object:!0};e.exports=function(t){return n(t)&&i[typeof t]||!1}},{\"./is-value\":194}],194:[function(t,e,r){\"use strict\";var n=t(\"../function/noop\")();e.exports=function(t){return t!==n&&null!==t}},{\"../function/noop\":179}],195:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.keys:t(\"./shim\")},{\"./is-implemented\":196,\"./shim\":197}],196:[function(t,e,r){\"use strict\";e.exports=function(){try{return Object.keys(\"primitive\"),!0}catch(t){return!1}}},{}],197:[function(t,e,r){\"use strict\";var n=t(\"../is-value\"),i=Object.keys;e.exports=function(t){return i(n(t)?Object(t):t)}},{\"../is-value\":194}],198:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./for-each\"),a=Function.prototype.call;e.exports=function(t,e){var r={},o=arguments[2];return n(e),i(t,function(t,n,i,s){r[n]=a.call(e,o,t,n,i,s)}),r}},{\"./for-each\":191,\"./valid-callable\":203}],199:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i=Array.prototype.forEach,a=Object.create;e.exports=function(t){var e=a(null);return i.call(arguments,function(t){n(t)&&function(t,e){var r;for(r in t)e[r]=t[r]}(Object(t),e)}),e}},{\"./is-value\":194}],200:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.setPrototypeOf:t(\"./shim\")},{\"./is-implemented\":201,\"./shim\":202}],201:[function(t,e,r){\"use strict\";var n=Object.create,i=Object.getPrototypeOf,a={};e.exports=function(){var t=Object.setPrototypeOf,e=arguments[0]||n;return\"function\"==typeof t&&i(t(e(null),a))===a}},{}],202:[function(t,e,r){\"use strict\";var n,i,a,o,s=t(\"../is-object\"),l=t(\"../valid-value\"),c=Object.prototype.isPrototypeOf,u=Object.defineProperty,h={configurable:!0,enumerable:!1,writable:!0,value:void 0};n=function(t,e){if(l(t),null===e||s(e))return t;throw new TypeError(\"Prototype must be null or an object\")},e.exports=(i=function(){var t,e=Object.create(null),r={},n=Object.getOwnPropertyDescriptor(Object.prototype,\"__proto__\");if(n){try{(t=n.set).call(e,r)}catch(t){}if(Object.getPrototypeOf(e)===r)return{set:t,level:2}}return e.__proto__=r,Object.getPrototypeOf(e)===r?{level:2}:((e={}).__proto__=r,Object.getPrototypeOf(e)===r&&{level:1})}())?(2===i.level?i.set?(o=i.set,a=function(t,e){return o.call(n(t,e),e),t}):a=function(t,e){return n(t,e).__proto__=e,t}:a=function t(e,r){var i;return n(e,r),(i=c.call(t.nullPolyfill,e))&&delete t.nullPolyfill.__proto__,null===r&&(r=t.nullPolyfill),e.__proto__=r,i&&u(t.nullPolyfill,\"__proto__\",h),e},Object.defineProperty(a,\"level\",{configurable:!1,enumerable:!1,writable:!1,value:i.level})):null,t(\"../create\")},{\"../create\":190,\"../is-object\":193,\"../valid-value\":205}],203:[function(t,e,r){\"use strict\";e.exports=function(t){if(\"function\"!=typeof t)throw new TypeError(t+\" is not a function\");return t}},{}],204:[function(t,e,r){\"use strict\";var n=t(\"./is-object\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not an Object\");return t}},{\"./is-object\":193}],205:[function(t,e,r){\"use strict\";var n=t(\"./is-value\");e.exports=function(t){if(!n(t))throw new TypeError(\"Cannot use null or undefined\");return t}},{\"./is-value\":194}],206:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?String.prototype.contains:t(\"./shim\")},{\"./is-implemented\":207,\"./shim\":208}],207:[function(t,e,r){\"use strict\";var n=\"razdwatrzy\";e.exports=function(){return\"function\"==typeof n.contains&&(!0===n.contains(\"dwa\")&&!1===n.contains(\"foo\"))}},{}],208:[function(t,e,r){\"use strict\";var n=String.prototype.indexOf;e.exports=function(t){return n.call(this,t,arguments[1])>-1}},{}],209:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(\"\");e.exports=function(t){return\"string\"==typeof t||t&&\"object\"==typeof t&&(t instanceof String||n.call(t)===i)||!1}},{}],210:[function(t,e,r){\"use strict\";var n=Object.create(null),i=Math.random;e.exports=function(){var t;do{t=i().toString(36).slice(2)}while(n[t]);return t}},{}],211:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"es5-ext/string/#/contains\"),o=t(\"d\"),s=t(\"es6-symbol\"),l=t(\"./\"),c=Object.defineProperty;n=e.exports=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");l.call(this,t),e=e?a.call(e,\"key+value\")?\"key+value\":a.call(e,\"key\")?\"key\":\"value\":\"value\",c(this,\"__kind__\",o(\"\",e))},i&&i(n,l),delete n.prototype.constructor,n.prototype=Object.create(l.prototype,{_resolve:o(function(t){return\"value\"===this.__kind__?this.__list__[t]:\"key+value\"===this.__kind__?[t,this.__list__[t]]:t})}),c(n.prototype,s.toStringTag,o(\"c\",\"Array Iterator\"))},{\"./\":214,d:151,\"es5-ext/object/set-prototype-of\":200,\"es5-ext/string/#/contains\":206,\"es6-symbol\":219}],212:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/valid-callable\"),a=t(\"es5-ext/string/is-string\"),o=t(\"./get\"),s=Array.isArray,l=Function.prototype.call,c=Array.prototype.some;e.exports=function(t,e){var r,u,h,f,p,d,g,v,m=arguments[2];if(s(t)||n(t)?r=\"array\":a(t)?r=\"string\":t=o(t),i(e),h=function(){f=!0},\"array\"!==r)if(\"string\"!==r)for(u=t.next();!u.done;){if(l.call(e,m,u.value,h),f)return;u=t.next()}else for(d=t.length,p=0;p<d&&(g=t[p],p+1<d&&(v=g.charCodeAt(0))>=55296&&v<=56319&&(g+=t[++p]),l.call(e,m,g,h),!f);++p);else c.call(t,function(t){return l.call(e,m,t,h),f})}},{\"./get\":213,\"es5-ext/function/is-arguments\":177,\"es5-ext/object/valid-callable\":203,\"es5-ext/string/is-string\":209}],213:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/string/is-string\"),a=t(\"./array\"),o=t(\"./string\"),s=t(\"./valid-iterable\"),l=t(\"es6-symbol\").iterator;e.exports=function(t){return\"function\"==typeof s(t)[l]?t[l]():n(t)?new a(t):i(t)?new o(t):new a(t)}},{\"./array\":211,\"./string\":216,\"./valid-iterable\":217,\"es5-ext/function/is-arguments\":177,\"es5-ext/string/is-string\":209,\"es6-symbol\":219}],214:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/array/#/clear\"),a=t(\"es5-ext/object/assign\"),o=t(\"es5-ext/object/valid-callable\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"d\"),c=t(\"d/auto-bind\"),u=t(\"es6-symbol\"),h=Object.defineProperty,f=Object.defineProperties;e.exports=n=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");f(this,{__list__:l(\"w\",s(t)),__context__:l(\"w\",e),__nextIndex__:l(\"w\",0)}),e&&(o(e.on),e.on(\"_add\",this._onAdd),e.on(\"_delete\",this._onDelete),e.on(\"_clear\",this._onClear))},delete n.prototype.constructor,f(n.prototype,a({_next:l(function(){var t;if(this.__list__)return this.__redo__&&void 0!==(t=this.__redo__.shift())?t:this.__nextIndex__<this.__list__.length?this.__nextIndex__++:void this._unBind()}),next:l(function(){return this._createResult(this._next())}),_createResult:l(function(t){return void 0===t?{done:!0,value:void 0}:{done:!1,value:this._resolve(t)}}),_resolve:l(function(t){return this.__list__[t]}),_unBind:l(function(){this.__list__=null,delete this.__redo__,this.__context__&&(this.__context__.off(\"_add\",this._onAdd),this.__context__.off(\"_delete\",this._onDelete),this.__context__.off(\"_clear\",this._onClear),this.__context__=null)}),toString:l(function(){return\"[object \"+(this[u.toStringTag]||\"Object\")+\"]\"})},c({_onAdd:l(function(t){t>=this.__nextIndex__||(++this.__nextIndex__,this.__redo__?(this.__redo__.forEach(function(e,r){e>=t&&(this.__redo__[r]=++e)},this),this.__redo__.push(t)):h(this,\"__redo__\",l(\"c\",[t])))}),_onDelete:l(function(t){var e;t>=this.__nextIndex__||(--this.__nextIndex__,this.__redo__&&(-1!==(e=this.__redo__.indexOf(t))&&this.__redo__.splice(e,1),this.__redo__.forEach(function(e,r){e>t&&(this.__redo__[r]=--e)},this)))}),_onClear:l(function(){this.__redo__&&i.call(this.__redo__),this.__nextIndex__=0})}))),h(n.prototype,u.iterator,l(function(){return this}))},{d:151,\"d/auto-bind\":150,\"es5-ext/array/#/clear\":173,\"es5-ext/object/assign\":186,\"es5-ext/object/valid-callable\":203,\"es5-ext/object/valid-value\":205,\"es6-symbol\":219}],215:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/string/is-string\"),o=t(\"es6-symbol\").iterator,s=Array.isArray;e.exports=function(t){return!!i(t)&&(!!s(t)||(!!a(t)||(!!n(t)||\"function\"==typeof t[o])))}},{\"es5-ext/function/is-arguments\":177,\"es5-ext/object/is-value\":194,\"es5-ext/string/is-string\":209,\"es6-symbol\":219}],216:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"d\"),o=t(\"es6-symbol\"),s=t(\"./\"),l=Object.defineProperty;n=e.exports=function(t){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");t=String(t),s.call(this,t),l(this,\"__length__\",a(\"\",t.length))},i&&i(n,s),delete n.prototype.constructor,n.prototype=Object.create(s.prototype,{_next:a(function(){if(this.__list__)return this.__nextIndex__<this.__length__?this.__nextIndex__++:void this._unBind()}),_resolve:a(function(t){var e,r=this.__list__[t];return this.__nextIndex__===this.__length__?r:(e=r.charCodeAt(0))>=55296&&e<=56319?r+this.__list__[this.__nextIndex__++]:r})}),l(n.prototype,o.toStringTag,a(\"c\",\"String Iterator\"))},{\"./\":214,d:151,\"es5-ext/object/set-prototype-of\":200,\"es6-symbol\":219}],217:[function(t,e,r){\"use strict\";var n=t(\"./is-iterable\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not iterable\");return t}},{\"./is-iterable\":215}],218:[function(t,e,r){(function(n,i){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():t.ES6Promise=n()}(this,function(){\"use strict\";function e(t){return\"function\"==typeof t}var r=Array.isArray?Array.isArray:function(t){return\"[object Array]\"===Object.prototype.toString.call(t)},a=0,o=void 0,s=void 0,l=function(t,e){g[a]=t,g[a+1]=e,2===(a+=2)&&(s?s(v):_())};var c=\"undefined\"!=typeof window?window:void 0,u=c||{},h=u.MutationObserver||u.WebKitMutationObserver,f=\"undefined\"==typeof self&&\"undefined\"!=typeof n&&\"[object process]\"==={}.toString.call(n),p=\"undefined\"!=typeof Uint8ClampedArray&&\"undefined\"!=typeof importScripts&&\"undefined\"!=typeof MessageChannel;function d(){var t=setTimeout;return function(){return t(v,1)}}var g=new Array(1e3);function v(){for(var t=0;t<a;t+=2){(0,g[t])(g[t+1]),g[t]=void 0,g[t+1]=void 0}a=0}var m,y,x,b,_=void 0;function w(t,e){var r=arguments,n=this,i=new this.constructor(A);void 0===i[T]&&V(i);var a,o=n._state;return o?(a=r[o-1],l(function(){return j(o,i,a,n._result)})):R(n,i,t,e),i}function k(t){if(t&&\"object\"==typeof t&&t.constructor===this)return t;var e=new this(A);return O(e,t),e}f?_=function(){return n.nextTick(v)}:h?(y=0,x=new h(v),b=document.createTextNode(\"\"),x.observe(b,{characterData:!0}),_=function(){b.data=y=++y%2}):p?((m=new MessageChannel).port1.onmessage=v,_=function(){return m.port2.postMessage(0)}):_=void 0===c&&\"function\"==typeof t?function(){try{var e=t(\"vertx\");return o=e.runOnLoop||e.runOnContext,function(){o(v)}}catch(t){return d()}}():d();var T=Math.random().toString(36).substring(16);function A(){}var M=void 0,S=1,E=2,C=new B;function L(t){try{return t.then}catch(t){return C.error=t,C}}function P(t,r,n){r.constructor===t.constructor&&n===w&&r.constructor.resolve===k?function(t,e){e._state===S?I(t,e._result):e._state===E?D(t,e._result):R(e,void 0,function(e){return O(t,e)},function(e){return D(t,e)})}(t,r):n===C?D(t,C.error):void 0===n?I(t,r):e(n)?function(t,e,r){l(function(t){var n=!1,i=function(t,e,r,n){try{t.call(e,r,n)}catch(t){return t}}(r,e,function(r){n||(n=!0,e!==r?O(t,r):I(t,r))},function(e){n||(n=!0,D(t,e))},t._label);!n&&i&&(n=!0,D(t,i))},t)}(t,r,n):I(t,r)}function O(t,e){var r;t===e?D(t,new TypeError(\"You cannot resolve a promise with itself\")):\"function\"==typeof(r=e)||\"object\"==typeof r&&null!==r?P(t,e,L(e)):I(t,e)}function z(t){t._onerror&&t._onerror(t._result),F(t)}function I(t,e){t._state===M&&(t._result=e,t._state=S,0!==t._subscribers.length&&l(F,t))}function D(t,e){t._state===M&&(t._state=E,t._result=e,l(z,t))}function R(t,e,r,n){var i=t._subscribers,a=i.length;t._onerror=null,i[a]=e,i[a+S]=r,i[a+E]=n,0===a&&t._state&&l(F,t)}function F(t){var e=t._subscribers,r=t._state;if(0!==e.length){for(var n=void 0,i=void 0,a=t._result,o=0;o<e.length;o+=3)n=e[o],i=e[o+r],n?j(r,n,i,a):i(a);t._subscribers.length=0}}function B(){this.error=null}var N=new B;function j(t,r,n,i){var a=e(n),o=void 0,s=void 0,l=void 0,c=void 0;if(a){if((o=function(t,e){try{return t(e)}catch(t){return N.error=t,N}}(n,i))===N?(c=!0,s=o.error,o=null):l=!0,r===o)return void D(r,new TypeError(\"A promises callback cannot return that same promise.\"))}else o=i,l=!0;r._state!==M||(a&&l?O(r,o):c?D(r,s):t===S?I(r,o):t===E&&D(r,o))}var U=0;function V(t){t[T]=U++,t._state=void 0,t._result=void 0,t._subscribers=[]}function q(t,e){this._instanceConstructor=t,this.promise=new t(A),this.promise[T]||V(this.promise),r(e)?(this._input=e,this.length=e.length,this._remaining=e.length,this._result=new Array(this.length),0===this.length?I(this.promise,this._result):(this.length=this.length||0,this._enumerate(),0===this._remaining&&I(this.promise,this._result))):D(this.promise,new Error(\"Array Methods must be provided an Array\"))}function H(t){this[T]=U++,this._result=this._state=void 0,this._subscribers=[],A!==t&&(\"function\"!=typeof t&&function(){throw new TypeError(\"You must pass a resolver function as the first argument to the promise constructor\")}(),this instanceof H?function(t,e){try{e(function(e){O(t,e)},function(e){D(t,e)})}catch(e){D(t,e)}}(this,t):function(){throw new TypeError(\"Failed to construct 'Promise': Please use the 'new' operator, this object constructor cannot be called as a function.\")}())}function G(){var t=void 0;if(\"undefined\"!=typeof i)t=i;else if(\"undefined\"!=typeof self)t=self;else try{t=Function(\"return this\")()}catch(t){throw new Error(\"polyfill failed because global object is unavailable in this environment\")}var e=t.Promise;if(e){var r=null;try{r=Object.prototype.toString.call(e.resolve())}catch(t){}if(\"[object Promise]\"===r&&!e.cast)return}t.Promise=H}return q.prototype._enumerate=function(){for(var t=this.length,e=this._input,r=0;this._state===M&&r<t;r++)this._eachEntry(e[r],r)},q.prototype._eachEntry=function(t,e){var r=this._instanceConstructor,n=r.resolve;if(n===k){var i=L(t);if(i===w&&t._state!==M)this._settledAt(t._state,e,t._result);else if(\"function\"!=typeof i)this._remaining--,this._result[e]=t;else if(r===H){var a=new r(A);P(a,t,i),this._willSettleAt(a,e)}else this._willSettleAt(new r(function(e){return e(t)}),e)}else this._willSettleAt(n(t),e)},q.prototype._settledAt=function(t,e,r){var n=this.promise;n._state===M&&(this._remaining--,t===E?D(n,r):this._result[e]=r),0===this._remaining&&I(n,this._result)},q.prototype._willSettleAt=function(t,e){var r=this;R(t,void 0,function(t){return r._settledAt(S,e,t)},function(t){return r._settledAt(E,e,t)})},H.all=function(t){return new q(this,t).promise},H.race=function(t){var e=this;return r(t)?new e(function(r,n){for(var i=t.length,a=0;a<i;a++)e.resolve(t[a]).then(r,n)}):new e(function(t,e){return e(new TypeError(\"You must pass an array to race.\"))})},H.resolve=k,H.reject=function(t){var e=new this(A);return D(e,t),e},H._setScheduler=function(t){s=t},H._setAsap=function(t){l=t},H._asap=l,H.prototype={constructor:H,then:w,catch:function(t){return this.then(null,t)}},G(),H.polyfill=G,H.Promise=H,H})}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{_process:482}],219:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Symbol:t(\"./polyfill\")},{\"./is-implemented\":220,\"./polyfill\":222}],220:[function(t,e,r){\"use strict\";var n={object:!0,symbol:!0};e.exports=function(){var t;if(\"function\"!=typeof Symbol)return!1;t=Symbol(\"test symbol\");try{String(t)}catch(t){return!1}return!!n[typeof Symbol.iterator]&&(!!n[typeof Symbol.toPrimitive]&&!!n[typeof Symbol.toStringTag])}},{}],221:[function(t,e,r){\"use strict\";e.exports=function(t){return!!t&&(\"symbol\"==typeof t||!!t.constructor&&(\"Symbol\"===t.constructor.name&&\"Symbol\"===t[t.constructor.toStringTag]))}},{}],222:[function(t,e,r){\"use strict\";var n,i,a,o,s=t(\"d\"),l=t(\"./validate-symbol\"),c=Object.create,u=Object.defineProperties,h=Object.defineProperty,f=Object.prototype,p=c(null);if(\"function\"==typeof Symbol){n=Symbol;try{String(n()),o=!0}catch(t){}}var d,g=(d=c(null),function(t){for(var e,r,n=0;d[t+(n||\"\")];)++n;return d[t+=n||\"\"]=!0,h(f,e=\"@@\"+t,s.gs(null,function(t){r||(r=!0,h(this,e,s(t)),r=!1)})),e});a=function(t){if(this instanceof a)throw new TypeError(\"Symbol is not a constructor\");return i(t)},e.exports=i=function t(e){var r;if(this instanceof t)throw new TypeError(\"Symbol is not a constructor\");return o?n(e):(r=c(a.prototype),e=void 0===e?\"\":String(e),u(r,{__description__:s(\"\",e),__name__:s(\"\",g(e))}))},u(i,{for:s(function(t){return p[t]?p[t]:p[t]=i(String(t))}),keyFor:s(function(t){var e;for(e in l(t),p)if(p[e]===t)return e}),hasInstance:s(\"\",n&&n.hasInstance||i(\"hasInstance\")),isConcatSpreadable:s(\"\",n&&n.isConcatSpreadable||i(\"isConcatSpreadable\")),iterator:s(\"\",n&&n.iterator||i(\"iterator\")),match:s(\"\",n&&n.match||i(\"match\")),replace:s(\"\",n&&n.replace||i(\"replace\")),search:s(\"\",n&&n.search||i(\"search\")),species:s(\"\",n&&n.species||i(\"species\")),split:s(\"\",n&&n.split||i(\"split\")),toPrimitive:s(\"\",n&&n.toPrimitive||i(\"toPrimitive\")),toStringTag:s(\"\",n&&n.toStringTag||i(\"toStringTag\")),unscopables:s(\"\",n&&n.unscopables||i(\"unscopables\"))}),u(a.prototype,{constructor:s(i),toString:s(\"\",function(){return this.__name__})}),u(i.prototype,{toString:s(function(){return\"Symbol (\"+l(this).__description__+\")\"}),valueOf:s(function(){return l(this)})}),h(i.prototype,i.toPrimitive,s(\"\",function(){var t=l(this);return\"symbol\"==typeof t?t:t.toString()})),h(i.prototype,i.toStringTag,s(\"c\",\"Symbol\")),h(a.prototype,i.toStringTag,s(\"c\",i.prototype[i.toStringTag])),h(a.prototype,i.toPrimitive,s(\"c\",i.prototype[i.toPrimitive]))},{\"./validate-symbol\":223,d:151}],223:[function(t,e,r){\"use strict\";var n=t(\"./is-symbol\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not a symbol\");return t}},{\"./is-symbol\":221}],224:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=e||0,i=r||1;return[[t[12]+t[0],t[13]+t[1],t[14]+t[2],t[15]+t[3]],[t[12]-t[0],t[13]-t[1],t[14]-t[2],t[15]-t[3]],[t[12]+t[4],t[13]+t[5],t[14]+t[6],t[15]+t[7]],[t[12]-t[4],t[13]-t[5],t[14]-t[6],t[15]-t[7]],[n*t[12]+t[8],n*t[13]+t[9],n*t[14]+t[10],n*t[15]+t[11]],[i*t[12]-t[8],i*t[13]-t[9],i*t[14]-t[10],i*t[15]-t[11]]]}},{}],225:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\");e.exports=function(t){var e=typeof t;if(\"string\"===e){var r=t;if(0===(t=+t)&&n(r))return!1}else if(\"number\"!==e)return!1;return t-t<1}},{\"is-string-blank\":423}],226:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 0:return new o([0],[0],0);case 1:if(\"number\"==typeof t){var n=l(t);return new o(n,n,0)}return new o(t,l(t.length),0);case 2:if(\"number\"==typeof e){var n=l(t.length);return new o(t,n,+e)}r=0;case 3:if(t.length!==e.length)throw new Error(\"state and velocity lengths must match\");return new o(t,e,r)}};var n=t(\"cubic-hermite\"),i=t(\"binary-search-bounds\");function a(t,e,r){return Math.min(e,Math.max(t,r))}function o(t,e,r){this.dimension=t.length,this.bounds=[new Array(this.dimension),new Array(this.dimension)];for(var n=0;n<this.dimension;++n)this.bounds[0][n]=-1/0,this.bounds[1][n]=1/0;this._state=t.slice().reverse(),this._velocity=e.slice().reverse(),this._time=[r],this._scratch=[t.slice(),t.slice(),t.slice(),t.slice(),t.slice()]}var s=o.prototype;function l(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=0;return e}s.flush=function(t){var e=i.gt(this._time,t)-1;e<=0||(this._time.splice(0,e),this._state.splice(0,e*this.dimension),this._velocity.splice(0,e*this.dimension))},s.curve=function(t){var e=this._time,r=e.length,o=i.le(e,t),s=this._scratch[0],l=this._state,c=this._velocity,u=this.dimension,h=this.bounds;if(o<0)for(var f=u-1,p=0;p<u;++p,--f)s[p]=l[f];else if(o>=r-1){f=l.length-1;var d=t-e[r-1];for(p=0;p<u;++p,--f)s[p]=l[f]+d*c[f]}else{f=u*(o+1)-1;var g=e[o],v=e[o+1]-g||1,m=this._scratch[1],y=this._scratch[2],x=this._scratch[3],b=this._scratch[4],_=!0;for(p=0;p<u;++p,--f)m[p]=l[f],x[p]=c[f]*v,y[p]=l[f+u],b[p]=c[f+u]*v,_=_&&m[p]===y[p]&&x[p]===b[p]&&0===x[p];if(_)for(p=0;p<u;++p)s[p]=m[p];else n(m,x,y,b,(t-g)/v,s)}var w=h[0],k=h[1];for(p=0;p<u;++p)s[p]=a(w[p],k[p],s[p]);return s},s.dcurve=function(t){var e=this._time,r=e.length,a=i.le(e,t),o=this._scratch[0],s=this._state,l=this._velocity,c=this.dimension;if(a>=r-1)for(var u=s.length-1,h=(e[r-1],0);h<c;++h,--u)o[h]=l[u];else{u=c*(a+1)-1;var f=e[a],p=e[a+1]-f||1,d=this._scratch[1],g=this._scratch[2],v=this._scratch[3],m=this._scratch[4],y=!0;for(h=0;h<c;++h,--u)d[h]=s[u],v[h]=l[u]*p,g[h]=s[u+c],m[h]=l[u+c]*p,y=y&&d[h]===g[h]&&v[h]===m[h]&&0===v[h];if(y)for(h=0;h<c;++h)o[h]=0;else{n.derivative(d,v,g,m,(t-f)/p,o);for(h=0;h<c;++h)o[h]/=p}}return o},s.lastT=function(){var t=this._time;return t[t.length-1]},s.stable=function(){for(var t=this._velocity,e=t.length,r=this.dimension-1;r>=0;--r)if(t[--e])return!1;return!0},s.jump=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1];this._time.push(e,t);for(var u=0;u<2;++u)for(var h=0;h<r;++h)n.push(n[o++]),i.push(0);this._time.push(t);for(h=r;h>0;--h)n.push(a(l[h-1],c[h-1],arguments[h])),i.push(0)}},s.push=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=t-e,l=this.bounds,c=l[0],u=l[1],h=s>1e-6?1/s:0;this._time.push(t);for(var f=r;f>0;--f){var p=a(c[f-1],u[f-1],arguments[f]);n.push(p),i.push((p-n[o++])*h)}}},s.set=function(t){var e=this.dimension;if(!(t<this.lastT()||arguments.length!==e+1)){var r=this._state,n=this._velocity,i=this.bounds,o=i[0],s=i[1];this._time.push(t);for(var l=e;l>0;--l)r.push(a(o[l-1],s[l-1],arguments[l])),n.push(0)}},s.move=function(t){var e=this.lastT(),r=this.dimension;if(!(t<=e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1],u=t-e,h=u>1e-6?1/u:0;this._time.push(t);for(var f=r;f>0;--f){var p=arguments[f];n.push(a(l[f-1],c[f-1],n[o++]+p)),i.push(p*h)}}},s.idle=function(t){var e=this.lastT();if(!(t<e)){var r=this.dimension,n=this._state,i=this._velocity,o=n.length-r,s=this.bounds,l=s[0],c=s[1],u=t-e;this._time.push(t);for(var h=r-1;h>=0;--h)n.push(a(l[h],c[h],n[o]+u*i[o])),i.push(0),o+=1}}},{\"binary-search-bounds\":91,\"cubic-hermite\":145}],227:[function(t,e,r){var n=t(\"dtype\");e.exports=function(t,e,r){if(!t)throw new TypeError(\"must specify data as first parameter\");if(r=0|+(r||0),Array.isArray(t)&&t[0]&&\"number\"==typeof t[0][0]){var i,a,o,s,l=t[0].length,c=t.length*l;e&&\"string\"!=typeof e||(e=new(n(e||\"float32\"))(c+r));var u=e.length-r;if(c!==u)throw new Error(\"source length \"+c+\" (\"+l+\"x\"+t.length+\") does not match destination length \"+u);for(i=0,o=r;i<t.length;i++)for(a=0;a<l;a++)e[o++]=null===t[i][a]?NaN:t[i][a]}else if(e&&\"string\"!=typeof e)e.set(t,r);else{var h=n(e||\"float32\");if(Array.isArray(t)||\"array\"===e)for(e=new h(t.length+r),i=0,o=r,s=e.length;o<s;o++,i++)e[o]=null===t[i]?NaN:t[i];else 0===r?e=new h(t):(e=new h(t.length+r)).set(t,r)}return e}},{dtype:169}],228:[function(t,e,r){\"use strict\";var n=t(\"css-font/stringify\"),i=[32,126];e.exports=function(t){var e=(t=t||{}).shape?t.shape:t.canvas?[t.canvas.width,t.canvas.height]:[512,512],r=t.canvas||document.createElement(\"canvas\"),a=t.font,o=\"number\"==typeof t.step?[t.step,t.step]:t.step||[32,32],s=t.chars||i;a&&\"string\"!=typeof a&&(a=n(a));if(Array.isArray(s)){if(2===s.length&&\"number\"==typeof s[0]&&\"number\"==typeof s[1]){for(var l=[],c=s[0],u=0;c<=s[1];c++)l[u++]=String.fromCharCode(c);s=l}}else s=String(s).split(\"\");e=e.slice(),r.width=e[0],r.height=e[1];var h=r.getContext(\"2d\");h.fillStyle=\"#000\",h.fillRect(0,0,r.width,r.height),h.font=a,h.textAlign=\"center\",h.textBaseline=\"middle\",h.fillStyle=\"#fff\";for(var f=o[0]/2,p=o[1]/2,c=0;c<s.length;c++)h.fillText(s[c],f,p),(f+=o[0])>e[0]-o[0]/2&&(f=o[0]/2,p+=o[1]);return r}},{\"css-font/stringify\":142}],229:[function(t,e,r){\"use strict\";function n(t,e){e||(e={}),(\"string\"==typeof t||Array.isArray(t))&&(e.family=t);var r=Array.isArray(e.family)?e.family.join(\", \"):e.family;if(!r)throw Error(\"`family` must be defined\");var s=e.size||e.fontSize||e.em||48,l=e.weight||e.fontWeight||\"\",c=(t=[e.style||e.fontStyle||\"\",l,s].join(\" \")+\"px \"+r,e.origin||\"top\");if(n.cache[r]&&s<=n.cache[r].em)return i(n.cache[r],c);var u=e.canvas||n.canvas,h=u.getContext(\"2d\"),f={upper:void 0!==e.upper?e.upper:\"H\",lower:void 0!==e.lower?e.lower:\"x\",descent:void 0!==e.descent?e.descent:\"p\",ascent:void 0!==e.ascent?e.ascent:\"h\",tittle:void 0!==e.tittle?e.tittle:\"i\",overshoot:void 0!==e.overshoot?e.overshoot:\"O\"},p=Math.ceil(1.5*s);u.height=p,u.width=.5*p,h.font=t;var d={top:0};h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillStyle=\"black\",h.fillText(\"H\",0,0);var g=a(h.getImageData(0,0,p,p));h.clearRect(0,0,p,p),h.textBaseline=\"bottom\",h.fillText(\"H\",0,p);var v=a(h.getImageData(0,0,p,p));d.lineHeight=d.bottom=p-v+g,h.clearRect(0,0,p,p),h.textBaseline=\"alphabetic\",h.fillText(\"H\",0,p);var m=p-a(h.getImageData(0,0,p,p))-1+g;d.baseline=d.alphabetic=m,h.clearRect(0,0,p,p),h.textBaseline=\"middle\",h.fillText(\"H\",0,.5*p);var y=a(h.getImageData(0,0,p,p));d.median=d.middle=p-y-1+g-.5*p,h.clearRect(0,0,p,p),h.textBaseline=\"hanging\",h.fillText(\"H\",0,.5*p);var x=a(h.getImageData(0,0,p,p));d.hanging=p-x-1+g-.5*p,h.clearRect(0,0,p,p),h.textBaseline=\"ideographic\",h.fillText(\"H\",0,p);var b=a(h.getImageData(0,0,p,p));if(d.ideographic=p-b-1+g,f.upper&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.upper,0,0),d.upper=a(h.getImageData(0,0,p,p)),d.capHeight=d.baseline-d.upper),f.lower&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.lower,0,0),d.lower=a(h.getImageData(0,0,p,p)),d.xHeight=d.baseline-d.lower),f.tittle&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.tittle,0,0),d.tittle=a(h.getImageData(0,0,p,p))),f.ascent&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.ascent,0,0),d.ascent=a(h.getImageData(0,0,p,p))),f.descent&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.descent,0,0),d.descent=o(h.getImageData(0,0,p,p))),f.overshoot){h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.overshoot,0,0);var _=o(h.getImageData(0,0,p,p));d.overshoot=_-m}for(var w in d)d[w]/=s;return d.em=s,n.cache[r]=d,i(d,c)}function i(t,e){var r={};for(var n in\"string\"==typeof e&&(e=t[e]),t)\"em\"!==n&&(r[n]=t[n]-e);return r}function a(t){for(var e=t.height,r=t.data,n=3;n<r.length;n+=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}function o(t){for(var e=t.height,r=t.data,n=r.length-1;n>0;n-=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}e.exports=n,n.canvas=document.createElement(\"canvas\"),n.cache={}},{}],230:[function(t,e,r){\"use strict\";e.exports=function(t){return new c(t||d,null)};var n=0,i=1;function a(t,e,r,n,i,a){this._color=t,this.key=e,this.value=r,this.left=n,this.right=i,this._count=a}function o(t){return new a(t._color,t.key,t.value,t.left,t.right,t._count)}function s(t,e){return new a(t,e.key,e.value,e.left,e.right,e._count)}function l(t){t._count=1+(t.left?t.left._count:0)+(t.right?t.right._count:0)}function c(t,e){this._compare=t,this.root=e}var u=c.prototype;function h(t,e){this.tree=t,this._stack=e}Object.defineProperty(u,\"keys\",{get:function(){var t=[];return this.forEach(function(e,r){t.push(e)}),t}}),Object.defineProperty(u,\"values\",{get:function(){var t=[];return this.forEach(function(e,r){t.push(r)}),t}}),Object.defineProperty(u,\"length\",{get:function(){return this.root?this.root._count:0}}),u.insert=function(t,e){for(var r=this._compare,o=this.root,u=[],h=[];o;){var f=r(t,o.key);u.push(o),h.push(f),o=f<=0?o.left:o.right}u.push(new a(n,t,e,null,null,1));for(var p=u.length-2;p>=0;--p){o=u[p];h[p]<=0?u[p]=new a(o._color,o.key,o.value,u[p+1],o.right,o._count+1):u[p]=new a(o._color,o.key,o.value,o.left,u[p+1],o._count+1)}for(p=u.length-1;p>1;--p){var d=u[p-1];o=u[p];if(d._color===i||o._color===i)break;var g=u[p-2];if(g.left===d)if(d.left===o){if(!(v=g.right)||v._color!==n){if(g._color=n,g.left=d.right,d._color=i,d.right=g,u[p-2]=d,u[p-1]=o,l(g),l(d),p>=3)(m=u[p-3]).left===g?m.left=d:m.right=d;break}d._color=i,g.right=s(i,v),g._color=n,p-=1}else{if(!(v=g.right)||v._color!==n){if(d.right=o.left,g._color=n,g.left=o.right,o._color=i,o.left=d,o.right=g,u[p-2]=o,u[p-1]=d,l(g),l(d),l(o),p>=3)(m=u[p-3]).left===g?m.left=o:m.right=o;break}d._color=i,g.right=s(i,v),g._color=n,p-=1}else if(d.right===o){if(!(v=g.left)||v._color!==n){if(g._color=n,g.right=d.left,d._color=i,d.left=g,u[p-2]=d,u[p-1]=o,l(g),l(d),p>=3)(m=u[p-3]).right===g?m.right=d:m.left=d;break}d._color=i,g.left=s(i,v),g._color=n,p-=1}else{var v;if(!(v=g.left)||v._color!==n){var m;if(d.left=o.right,g._color=n,g.right=o.left,o._color=i,o.right=d,o.left=g,u[p-2]=o,u[p-1]=d,l(g),l(d),l(o),p>=3)(m=u[p-3]).right===g?m.right=o:m.left=o;break}d._color=i,g.left=s(i,v),g._color=n,p-=1}}return u[0]._color=i,new c(r,u[0])},u.forEach=function(t,e,r){if(this.root)switch(arguments.length){case 1:return function t(e,r){var n;if(r.left&&(n=t(e,r.left)))return n;return(n=e(r.key,r.value))||(r.right?t(e,r.right):void 0)}(t,this.root);case 2:return function t(e,r,n,i){if(r(e,i.key)<=0){var a;if(i.left&&(a=t(e,r,n,i.left)))return a;if(a=n(i.key,i.value))return a}if(i.right)return t(e,r,n,i.right)}(e,this._compare,t,this.root);case 3:if(this._compare(e,r)>=0)return;return function t(e,r,n,i,a){var o,s=n(e,a.key),l=n(r,a.key);if(s<=0){if(a.left&&(o=t(e,r,n,i,a.left)))return o;if(l>0&&(o=i(a.key,a.value)))return o}if(l>0&&a.right)return t(e,r,n,i,a.right)}(e,r,this._compare,t,this.root)}},Object.defineProperty(u,\"begin\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.left;return new h(this,t)}}),Object.defineProperty(u,\"end\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.right;return new h(this,t)}}),u.at=function(t){if(t<0)return new h(this,[]);for(var e=this.root,r=[];;){if(r.push(e),e.left){if(t<e.left._count){e=e.left;continue}t-=e.left._count}if(!t)return new h(this,r);if(t-=1,!e.right)break;if(t>=e.right._count)break;e=e.right}return new h(this,[])},u.ge=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<=0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},u.gt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},u.lt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},u.le=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>=0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},u.find=function(t){for(var e=this._compare,r=this.root,n=[];r;){var i=e(t,r.key);if(n.push(r),0===i)return new h(this,n);r=i<=0?r.left:r.right}return new h(this,[])},u.remove=function(t){var e=this.find(t);return e?e.remove():this},u.get=function(t){for(var e=this._compare,r=this.root;r;){var n=e(t,r.key);if(0===n)return r.value;r=n<=0?r.left:r.right}};var f=h.prototype;function p(t,e){t.key=e.key,t.value=e.value,t.left=e.left,t.right=e.right,t._color=e._color,t._count=e._count}function d(t,e){return t<e?-1:t>e?1:0}Object.defineProperty(f,\"valid\",{get:function(){return this._stack.length>0}}),Object.defineProperty(f,\"node\",{get:function(){return this._stack.length>0?this._stack[this._stack.length-1]:null},enumerable:!0}),f.clone=function(){return new h(this.tree,this._stack.slice())},f.remove=function(){var t=this._stack;if(0===t.length)return this.tree;var e=new Array(t.length),r=t[t.length-1];e[e.length-1]=new a(r._color,r.key,r.value,r.left,r.right,r._count);for(var u=t.length-2;u>=0;--u){(r=t[u]).left===t[u+1]?e[u]=new a(r._color,r.key,r.value,e[u+1],r.right,r._count):e[u]=new a(r._color,r.key,r.value,r.left,e[u+1],r._count)}if((r=e[e.length-1]).left&&r.right){var h=e.length;for(r=r.left;r.right;)e.push(r),r=r.right;var f=e[h-1];e.push(new a(r._color,f.key,f.value,r.left,r.right,r._count)),e[h-1].key=r.key,e[h-1].value=r.value;for(u=e.length-2;u>=h;--u)r=e[u],e[u]=new a(r._color,r.key,r.value,r.left,e[u+1],r._count);e[h-1].left=e[h]}if((r=e[e.length-1])._color===n){var d=e[e.length-2];d.left===r?d.left=null:d.right===r&&(d.right=null),e.pop();for(u=0;u<e.length;++u)e[u]._count--;return new c(this.tree._compare,e[0])}if(r.left||r.right){r.left?p(r,r.left):r.right&&p(r,r.right),r._color=i;for(u=0;u<e.length-1;++u)e[u]._count--;return new c(this.tree._compare,e[0])}if(1===e.length)return new c(this.tree._compare,null);for(u=0;u<e.length;++u)e[u]._count--;var g=e[e.length-2];return function(t){for(var e,r,a,c,u=t.length-1;u>=0;--u){if(e=t[u],0===u)return void(e._color=i);if((r=t[u-1]).left===e){if((a=r.right).right&&a.right._color===n)return c=(a=r.right=o(a)).right=o(a.right),r.right=a.left,a.left=r,a.right=c,a._color=r._color,e._color=i,r._color=i,c._color=i,l(r),l(a),u>1&&((h=t[u-2]).left===r?h.left=a:h.right=a),void(t[u-1]=a);if(a.left&&a.left._color===n)return c=(a=r.right=o(a)).left=o(a.left),r.right=c.left,a.left=c.right,c.left=r,c.right=a,c._color=r._color,r._color=i,a._color=i,e._color=i,l(r),l(a),l(c),u>1&&((h=t[u-2]).left===r?h.left=c:h.right=c),void(t[u-1]=c);if(a._color===i){if(r._color===n)return r._color=i,void(r.right=s(n,a));r.right=s(n,a);continue}a=o(a),r.right=a.left,a.left=r,a._color=r._color,r._color=n,l(r),l(a),u>1&&((h=t[u-2]).left===r?h.left=a:h.right=a),t[u-1]=a,t[u]=r,u+1<t.length?t[u+1]=e:t.push(e),u+=2}else{if((a=r.left).left&&a.left._color===n)return c=(a=r.left=o(a)).left=o(a.left),r.left=a.right,a.right=r,a.left=c,a._color=r._color,e._color=i,r._color=i,c._color=i,l(r),l(a),u>1&&((h=t[u-2]).right===r?h.right=a:h.left=a),void(t[u-1]=a);if(a.right&&a.right._color===n)return c=(a=r.left=o(a)).right=o(a.right),r.left=c.right,a.right=c.left,c.right=r,c.left=a,c._color=r._color,r._color=i,a._color=i,e._color=i,l(r),l(a),l(c),u>1&&((h=t[u-2]).right===r?h.right=c:h.left=c),void(t[u-1]=c);if(a._color===i){if(r._color===n)return r._color=i,void(r.left=s(n,a));r.left=s(n,a);continue}var h;a=o(a),r.left=a.right,a.right=r,a._color=r._color,r._color=n,l(r),l(a),u>1&&((h=t[u-2]).right===r?h.right=a:h.left=a),t[u-1]=a,t[u]=r,u+1<t.length?t[u+1]=e:t.push(e),u+=2}}}(e),g.left===r?g.left=null:g.right=null,new c(this.tree._compare,e[0])},Object.defineProperty(f,\"key\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].key},enumerable:!0}),Object.defineProperty(f,\"value\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].value},enumerable:!0}),Object.defineProperty(f,\"index\",{get:function(){var t=0,e=this._stack;if(0===e.length){var r=this.tree.root;return r?r._count:0}e[e.length-1].left&&(t=e[e.length-1].left._count);for(var n=e.length-2;n>=0;--n)e[n+1]===e[n].right&&(++t,e[n].left&&(t+=e[n].left._count));return t},enumerable:!0}),f.next=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.right)for(e=e.right;e;)t.push(e),e=e.left;else for(t.pop();t.length>0&&t[t.length-1].right===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(f,\"hasNext\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].right)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].left===t[e])return!0;return!1}}),f.update=function(t){var e=this._stack;if(0===e.length)throw new Error(\"Can't update empty node!\");var r=new Array(e.length),n=e[e.length-1];r[r.length-1]=new a(n._color,n.key,t,n.left,n.right,n._count);for(var i=e.length-2;i>=0;--i)(n=e[i]).left===e[i+1]?r[i]=new a(n._color,n.key,n.value,r[i+1],n.right,n._count):r[i]=new a(n._color,n.key,n.value,n.left,r[i+1],n._count);return new c(this.tree._compare,r[0])},f.prev=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.left)for(e=e.left;e;)t.push(e),e=e.right;else for(t.pop();t.length>0&&t[t.length-1].left===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(f,\"hasPrev\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].left)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].right===t[e])return!0;return!1}})},{}],231:[function(t,e,r){var n=[.9999999999998099,676.5203681218851,-1259.1392167224028,771.3234287776531,-176.6150291621406,12.507343278686905,-.13857109526572012,9984369578019572e-21,1.5056327351493116e-7],i=607/128,a=[.9999999999999971,57.15623566586292,-59.59796035547549,14.136097974741746,-.4919138160976202,3399464998481189e-20,4652362892704858e-20,-9837447530487956e-20,.0001580887032249125,-.00021026444172410488,.00021743961811521265,-.0001643181065367639,8441822398385275e-20,-26190838401581408e-21,36899182659531625e-22];function o(t){if(t<0)return Number(\"0/0\");for(var e=a[0],r=a.length-1;r>0;--r)e+=a[r]/(t+r);var n=t+i+.5;return.5*Math.log(2*Math.PI)+(t+.5)*Math.log(n)-n+Math.log(e)-Math.log(t)}e.exports=function t(e){if(e<.5)return Math.PI/(Math.sin(Math.PI*e)*t(1-e));if(e>100)return Math.exp(o(e));e-=1;for(var r=n[0],i=1;i<9;i++)r+=n[i]/(e+i);var a=e+7+.5;return Math.sqrt(2*Math.PI)*Math.pow(a,e+.5)*Math.exp(-a)*r},e.exports.log=o},{}],232:[function(t,e,r){e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"must specify type string\");if(e=e||{},\"undefined\"==typeof document&&!e.canvas)return null;var r=e.canvas||document.createElement(\"canvas\");\"number\"==typeof e.width&&(r.width=e.width);\"number\"==typeof e.height&&(r.height=e.height);var n,i=e;try{var a=[t];0===t.indexOf(\"webgl\")&&a.push(\"experimental-\"+t);for(var o=0;o<a.length;o++)if(n=r.getContext(a[o],i))return n}catch(t){n=null}return n||null}},{}],233:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=new u(t);return r.update(e),r};var n=t(\"./lib/text.js\"),i=t(\"./lib/lines.js\"),a=t(\"./lib/background.js\"),o=t(\"./lib/cube.js\"),s=t(\"./lib/ticks.js\"),l=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]);function c(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function u(t){this.gl=t,this.pixelRatio=1,this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.autoTicks=!0,this.tickSpacing=[1,1,1],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickAlign=[\"auto\",\"auto\",\"auto\"],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[10,10,10],this.lastCubeProps={cubeEdges:[0,0,0],axis:[0,0,0]},this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=\"sans-serif\",this.labelSize=[20,20,20],this.labelAngle=[0,0,0],this.labelAlign=[\"auto\",\"auto\",\"auto\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[10,10,10],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[0,0,0],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!1,!1,!1],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._firstInit=!0,this._text=null,this._lines=null,this._background=a(t)}var h=u.prototype;function f(){this.primalOffset=[0,0,0],this.primalMinor=[0,0,0],this.mirrorOffset=[0,0,0],this.mirrorMinor=[0,0,0]}h.update=function(t){function e(e,r,n){if(n in t){var i,a=t[n],o=this[n];(e?Array.isArray(a)&&Array.isArray(a[0]):Array.isArray(a))?this[n]=i=[r(a[0]),r(a[1]),r(a[2])]:this[n]=i=[r(a),r(a),r(a)];for(var s=0;s<3;++s)if(i[s]!==o[s])return!0}return!1}t=t||{};var r,a=e.bind(this,!1,Number),o=e.bind(this,!1,Boolean),l=e.bind(this,!1,String),c=e.bind(this,!0,function(t){if(Array.isArray(t)){if(3===t.length)return[+t[0],+t[1],+t[2],1];if(4===t.length)return[+t[0],+t[1],+t[2],+t[3]]}return[0,0,0,1]}),u=!1,h=!1;if(\"bounds\"in t)for(var f=t.bounds,p=0;p<2;++p)for(var d=0;d<3;++d)f[p][d]!==this.bounds[p][d]&&(h=!0),this.bounds[p][d]=f[p][d];if(\"ticks\"in t){r=t.ticks,u=!0,this.autoTicks=!1;for(p=0;p<3;++p)this.tickSpacing[p]=0}else a(\"tickSpacing\")&&(this.autoTicks=!0,h=!0);if(this._firstInit&&(\"ticks\"in t||\"tickSpacing\"in t||(this.autoTicks=!0),h=!0,u=!0,this._firstInit=!1),h&&this.autoTicks&&(r=s.create(this.bounds,this.tickSpacing),u=!0),u){for(p=0;p<3;++p)r[p].sort(function(t,e){return t.x-e.x});s.equal(r,this.ticks)?u=!1:this.ticks=r}o(\"tickEnable\"),l(\"tickFont\")&&(u=!0),a(\"tickSize\"),a(\"tickAngle\"),a(\"tickPad\"),c(\"tickColor\");var g=l(\"labels\");l(\"labelFont\")&&(g=!0),o(\"labelEnable\"),a(\"labelSize\"),a(\"labelPad\"),c(\"labelColor\"),o(\"lineEnable\"),o(\"lineMirror\"),a(\"lineWidth\"),c(\"lineColor\"),o(\"lineTickEnable\"),o(\"lineTickMirror\"),a(\"lineTickLength\"),a(\"lineTickWidth\"),c(\"lineTickColor\"),o(\"gridEnable\"),a(\"gridWidth\"),c(\"gridColor\"),o(\"zeroEnable\"),c(\"zeroLineColor\"),a(\"zeroLineWidth\"),o(\"backgroundEnable\"),c(\"backgroundColor\"),this._text?this._text&&(g||u)&&this._text.update(this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont):this._text=n(this.gl,this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont),this._lines&&u&&(this._lines.dispose(),this._lines=null),this._lines||(this._lines=i(this.gl,this.bounds,this.ticks))};var p=[new f,new f,new f];function d(t,e,r,n,i){for(var a=t.primalOffset,o=t.primalMinor,s=t.mirrorOffset,l=t.mirrorMinor,c=n[e],u=0;u<3;++u)if(e!==u){var h=a,f=s,p=o,d=l;c&1<<u&&(h=s,f=a,p=l,d=o),h[u]=r[0][u],f[u]=r[1][u],i[u]>0?(p[u]=-1,d[u]=0):(p[u]=0,d[u]=1)}}var g=[0,0,0],v={model:l,view:l,projection:l,_ortho:!1};h.isOpaque=function(){return!0},h.isTransparent=function(){return!1},h.drawTransparent=function(t){};var m=[0,0,0],y=[0,0,0],x=[0,0,0];h.draw=function(t){t=t||v;for(var e=this.gl,r=t.model||l,n=t.view||l,i=t.projection||l,a=this.bounds,s=t._ortho||!1,u=o(r,n,i,a,s),h=u.cubeEdges,f=u.axis,b=n[12],_=n[13],w=n[14],k=n[15],T=(s?2:1)*this.pixelRatio*(i[3]*b+i[7]*_+i[11]*w+i[15]*k)/e.drawingBufferHeight,A=0;A<3;++A)this.lastCubeProps.cubeEdges[A]=h[A],this.lastCubeProps.axis[A]=f[A];var M=p;for(A=0;A<3;++A)d(p[A],A,this.bounds,h,f);e=this.gl;var S,E=g;for(A=0;A<3;++A)this.backgroundEnable[A]?E[A]=f[A]:E[A]=0;this._background.draw(r,n,i,a,E,this.backgroundColor),this._lines.bind(r,n,i,this);for(A=0;A<3;++A){var C=[0,0,0];f[A]>0?C[A]=a[1][A]:C[A]=a[0][A];for(var L=0;L<2;++L){var P=(A+1+L)%3,O=(A+1+(1^L))%3;this.gridEnable[P]&&this._lines.drawGrid(P,O,this.bounds,C,this.gridColor[P],this.gridWidth[P]*this.pixelRatio)}for(L=0;L<2;++L){P=(A+1+L)%3,O=(A+1+(1^L))%3;this.zeroEnable[O]&&Math.min(a[0][O],a[1][O])<=0&&Math.max(a[0][O],a[1][O])>=0&&this._lines.drawZero(P,O,this.bounds,C,this.zeroLineColor[O],this.zeroLineWidth[O]*this.pixelRatio)}}for(A=0;A<3;++A){this.lineEnable[A]&&this._lines.drawAxisLine(A,this.bounds,M[A].primalOffset,this.lineColor[A],this.lineWidth[A]*this.pixelRatio),this.lineMirror[A]&&this._lines.drawAxisLine(A,this.bounds,M[A].mirrorOffset,this.lineColor[A],this.lineWidth[A]*this.pixelRatio);var z=c(m,M[A].primalMinor),I=c(y,M[A].mirrorMinor),D=this.lineTickLength;for(L=0;L<3;++L){var R=T/r[5*L];z[L]*=D[L]*R,I[L]*=D[L]*R}this.lineTickEnable[A]&&this._lines.drawAxisTicks(A,M[A].primalOffset,z,this.lineTickColor[A],this.lineTickWidth[A]*this.pixelRatio),this.lineTickMirror[A]&&this._lines.drawAxisTicks(A,M[A].mirrorOffset,I,this.lineTickColor[A],this.lineTickWidth[A]*this.pixelRatio)}this._lines.unbind(),this._text.bind(r,n,i,this.pixelRatio);var F,B;function N(t){(B=[0,0,0])[t]=1}function j(t,e,r){var n=(t+1)%3,i=(t+2)%3,a=e[n],o=e[i],s=r[n],l=r[i];a>0&&l>0?N(n):a>0&&l<0?N(n):a<0&&l>0?N(n):a<0&&l<0?N(n):o>0&&s>0?N(i):o>0&&s<0?N(i):o<0&&s>0?N(i):o<0&&s<0&&N(i)}for(A=0;A<3;++A){var U=M[A].primalMinor,V=M[A].mirrorMinor,q=c(x,M[A].primalOffset);for(L=0;L<3;++L)this.lineTickEnable[A]&&(q[L]+=T*U[L]*Math.max(this.lineTickLength[L],0)/r[5*L]);var H=[0,0,0];if(H[A]=1,this.tickEnable[A]){-3600===this.tickAngle[A]?(this.tickAngle[A]=0,this.tickAlign[A]=\"auto\"):this.tickAlign[A]=-1,F=1,\"auto\"===(S=[this.tickAlign[A],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]),B=[0,0,0],j(A,U,V);for(L=0;L<3;++L)q[L]+=T*U[L]*this.tickPad[L]/r[5*L];this._text.drawTicks(A,this.tickSize[A],this.tickAngle[A],q,this.tickColor[A],H,B,S)}if(this.labelEnable[A]){F=0,B=[0,0,0],this.labels[A].length>4&&(N(A),F=1),\"auto\"===(S=[this.labelAlign[A],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]);for(L=0;L<3;++L)q[L]+=T*U[L]*this.labelPad[L]/r[5*L];q[A]+=.5*(a[0][A]+a[1][A]),this._text.drawLabel(A,this.labelSize[A],this.labelAngle[A],q,this.labelColor[A],[0,0,0],B,S)}}this._text.unbind()},h.dispose=function(){this._text.dispose(),this._lines.dispose(),this._background.dispose(),this._lines=null,this._text=null,this._background=null,this.gl=null}},{\"./lib/background.js\":234,\"./lib/cube.js\":235,\"./lib/lines.js\":236,\"./lib/text.js\":238,\"./lib/ticks.js\":239}],234:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=[],r=[],s=0,l=0;l<3;++l)for(var c=(l+1)%3,u=(l+2)%3,h=[0,0,0],f=[0,0,0],p=-1;p<=1;p+=2){r.push(s,s+2,s+1,s+1,s+2,s+3),h[l]=p,f[l]=p;for(var d=-1;d<=1;d+=2){h[c]=d;for(var g=-1;g<=1;g+=2)h[u]=g,e.push(h[0],h[1],h[2],f[0],f[1],f[2]),s+=1}var v=c;c=u,u=v}var m=n(t,new Float32Array(e)),y=n(t,new Uint16Array(r),t.ELEMENT_ARRAY_BUFFER),x=i(t,[{buffer:m,type:t.FLOAT,size:3,offset:0,stride:24},{buffer:m,type:t.FLOAT,size:3,offset:12,stride:24}],y),b=a(t);return b.attributes.position.location=0,b.attributes.normal.location=1,new o(t,m,x,b)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").bg;function o(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n}var s=o.prototype;s.draw=function(t,e,r,n,i,a){for(var o=!1,s=0;s<3;++s)o=o||i[s];if(o){var l=this.gl;l.enable(l.POLYGON_OFFSET_FILL),l.polygonOffset(1,2),this.shader.bind(),this.shader.uniforms={model:t,view:e,projection:r,bounds:n,enable:i,colors:a},this.vao.bind(),this.vao.draw(this.gl.TRIANGLES,36),this.vao.unbind(),l.disable(l.POLYGON_OFFSET_FILL)}},s.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders\":237,\"gl-buffer\":241,\"gl-vao\":327}],235:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,p){i(s,e,t),i(s,r,s);for(var y=0,x=0;x<2;++x){u[2]=a[x][2];for(var b=0;b<2;++b){u[1]=a[b][1];for(var _=0;_<2;++_)u[0]=a[_][0],f(l[y],u,s),y+=1}}for(var w=-1,x=0;x<8;++x){for(var k=l[x][3],T=0;T<3;++T)c[x][T]=l[x][T]/k;p&&(c[x][2]*=-1),k<0&&(w<0?w=x:c[x][2]<c[w][2]&&(w=x))}if(w<0){w=0;for(var A=0;A<3;++A){for(var M=(A+2)%3,S=(A+1)%3,E=-1,C=-1,L=0;L<2;++L){var P=L<<A,O=P+(L<<M)+(1-L<<S),z=P+(1-L<<M)+(L<<S);o(c[P],c[O],c[z],h)<0||(L?E=1:C=1)}if(E<0||C<0)C>E&&(w|=1<<A);else{for(var L=0;L<2;++L){var P=L<<A,O=P+(L<<M)+(1-L<<S),z=P+(1-L<<M)+(L<<S),I=d([l[P],l[O],l[z],l[P+(1<<M)+(1<<S)]]);L?E=I:C=I}C>E&&(w|=1<<A)}}}for(var D=7^w,R=-1,x=0;x<8;++x)x!==w&&x!==D&&(R<0?R=x:c[R][1]>c[x][1]&&(R=x));for(var F=-1,x=0;x<3;++x){var B=R^1<<x;if(B!==w&&B!==D){F<0&&(F=B);var S=c[B];S[0]<c[F][0]&&(F=B)}}for(var N=-1,x=0;x<3;++x){var B=R^1<<x;if(B!==w&&B!==D&&B!==F){N<0&&(N=B);var S=c[B];S[0]>c[N][0]&&(N=B)}}var j=g;j[0]=j[1]=j[2]=0,j[n.log2(F^R)]=R&F,j[n.log2(R^N)]=R&N;var U=7^N;U===w||U===D?(U=7^F,j[n.log2(N^U)]=U&N):j[n.log2(F^U)]=U&F;for(var V=v,q=w,A=0;A<3;++A)V[A]=q&1<<A?-1:1;return m};var n=t(\"bit-twiddle\"),i=t(\"gl-mat4/multiply\"),a=t(\"split-polygon\"),o=t(\"robust-orientation\"),s=new Array(16),l=new Array(8),c=new Array(8),u=new Array(3),h=[0,0,0];function f(t,e,r){for(var n=0;n<4;++n){t[n]=r[12+n];for(var i=0;i<3;++i)t[n]+=e[i]*r[4*i+n]}}!function(){for(var t=0;t<8;++t)l[t]=[1,1,1,1],c[t]=[1,1,1]}();var p=[[0,0,1,0,0],[0,0,-1,1,0],[0,-1,0,1,0],[0,1,0,1,0],[-1,0,0,1,0],[1,0,0,1,0]];function d(t){for(var e=0;e<p.length;++e)if((t=a.positive(t,p[e])).length<3)return 0;var r=t[0],n=r[0]/r[3],i=r[1]/r[3],o=0;for(e=1;e+1<t.length;++e){var s=t[e],l=t[e+1],c=s[0]/s[3]-n,u=s[1]/s[3]-i,h=l[0]/l[3]-n,f=l[1]/l[3]-i;o+=Math.abs(c*f-u*h)}return o}var g=[1,1,1],v=[0,0,0],m={cubeEdges:g,axis:v}},{\"bit-twiddle\":92,\"gl-mat4/multiply\":267,\"robust-orientation\":510,\"split-polygon\":527}],236:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var o=[],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[0,0,0];o.push(0,0,1,0,1,1,0,0,-1,0,0,-1,0,1,1,0,1,-1);for(var h=0;h<3;++h){for(var f=o.length/3|0,d=0;d<r[h].length;++d){var g=+r[h][d].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var v=o.length/3|0;s[h]=f,l[h]=v-f;for(var f=o.length/3|0,m=0;m<r[h].length;++m){var g=+r[h][m].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var v=o.length/3|0;c[h]=f,u[h]=v-f}var y=n(t,new Float32Array(o)),x=i(t,[{buffer:y,type:t.FLOAT,size:3,stride:0,offset:0}]),b=a(t);return b.attributes.position.location=0,new p(t,y,x,b,l,s,u,c)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").line,o=[0,0,0],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[1,1];function h(t){return t[0]=t[1]=t[2]=0,t}function f(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function p(t,e,r,n,i,a,o,s){this.gl=t,this.vertBuffer=e,this.vao=r,this.shader=n,this.tickCount=i,this.tickOffset=a,this.gridCount=o,this.gridOffset=s}var d=p.prototype;d.bind=function(t,e,r){this.shader.bind(),this.shader.uniforms.model=t,this.shader.uniforms.view=e,this.shader.uniforms.projection=r,u[0]=this.gl.drawingBufferWidth,u[1]=this.gl.drawingBufferHeight,this.shader.uniforms.screenShape=u,this.vao.bind()},d.unbind=function(){this.vao.unbind()},d.drawAxisLine=function(t,e,r,n,i){var a=h(s);this.shader.uniforms.majorAxis=s,a[t]=e[1][t]-e[0][t],this.shader.uniforms.minorAxis=a;var o,u=f(c,r);u[t]+=e[0][t],this.shader.uniforms.offset=u,this.shader.uniforms.lineWidth=i,this.shader.uniforms.color=n,(o=h(l))[(t+2)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6),(o=h(l))[(t+1)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6)},d.drawAxisTicks=function(t,e,r,n,i){if(this.tickCount[t]){var a=h(o);a[t]=1,this.shader.uniforms.majorAxis=a,this.shader.uniforms.offset=e,this.shader.uniforms.minorAxis=r,this.shader.uniforms.color=n,this.shader.uniforms.lineWidth=i;var s=h(l);s[t]=1,this.shader.uniforms.screenAxis=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t])}},d.drawGrid=function(t,e,r,n,i,a){if(this.gridCount[t]){var u=h(s);u[e]=r[1][e]-r[0][e],this.shader.uniforms.minorAxis=u;var p=f(c,n);p[e]+=r[0][e],this.shader.uniforms.offset=p;var d=h(o);d[t]=1,this.shader.uniforms.majorAxis=d;var g=h(l);g[t]=1,this.shader.uniforms.screenAxis=g,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,this.gridCount[t],this.gridOffset[t])}},d.drawZero=function(t,e,r,n,i,a){var o=h(s);this.shader.uniforms.majorAxis=o,o[t]=r[1][t]-r[0][t],this.shader.uniforms.minorAxis=o;var u=f(c,n);u[t]+=r[0][t],this.shader.uniforms.offset=u;var p=h(l);p[e]=1,this.shader.uniforms.screenAxis=p,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,6)},d.dispose=function(){this.vao.dispose(),this.vertBuffer.dispose(),this.shader.dispose()}},{\"./shaders\":237,\"gl-buffer\":241,\"gl-vao\":327}],237:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, majorAxis, minorAxis, screenAxis;\\nuniform float lineWidth;\\nuniform vec2 screenShape;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nvoid main() {\\n  vec3 major = position.x * majorAxis;\\n  vec3 minor = position.y * minorAxis;\\n\\n  vec3 vPosition = major + minor + offset;\\n  vec3 pPosition = project(vPosition);\\n  vec3 offset = project(vPosition + screenAxis * position.z);\\n\\n  vec2 screen = normalize((offset - pPosition).xy * screenShape) / screenShape;\\n\\n  gl_Position = vec4(pPosition + vec3(0.5 * screen * lineWidth, 0), 1.0);\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.line=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"}])};var s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, axis, alignDir, alignOpt;\\nuniform float scale, angle, pixelScale;\\nuniform vec2 resolution;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nfloat computeViewAngle(vec3 a, vec3 b) {\\n  vec3 A = project(a);\\n  vec3 B = project(b);\\n\\n  return atan(\\n    (B.y - A.y) * resolution.y,\\n    (B.x - A.x) * resolution.x\\n  );\\n}\\n\\nconst float PI = 3.141592;\\nconst float TWO_PI = 2.0 * PI;\\nconst float HALF_PI = 0.5 * PI;\\nconst float ONE_AND_HALF_PI = 1.5 * PI;\\n\\nint option = int(floor(alignOpt.x + 0.001));\\nfloat hv_ratio =       alignOpt.y;\\nbool enableAlign =    (alignOpt.z != 0.0);\\n\\nfloat mod_angle(float a) {\\n  return mod(a, PI);\\n}\\n\\nfloat positive_angle(float a) {\\n  return mod_angle((a < 0.0) ?\\n    a + TWO_PI :\\n    a\\n  );\\n}\\n\\nfloat look_upwards(float a) {\\n  float b = positive_angle(a);\\n  return ((b > HALF_PI) && (b <= ONE_AND_HALF_PI)) ?\\n    b - PI :\\n    b;\\n}\\n\\nfloat look_horizontal_or_vertical(float a, float ratio) {\\n  // ratio controls the ratio between being horizontal to (vertical + horizontal)\\n  // if ratio is set to 0.5 then it is 50%, 50%.\\n  // when using a higher ratio e.g. 0.75 the result would\\n  // likely be more horizontal than vertical.\\n\\n  float b = positive_angle(a);\\n\\n  return\\n    (b < (      ratio) * HALF_PI) ? 0.0 :\\n    (b < (2.0 - ratio) * HALF_PI) ? -HALF_PI :\\n    (b < (2.0 + ratio) * HALF_PI) ? 0.0 :\\n    (b < (4.0 - ratio) * HALF_PI) ? HALF_PI :\\n                                    0.0;\\n}\\n\\nfloat roundTo(float a, float b) {\\n  return float(b * floor((a + 0.5 * b) / b));\\n}\\n\\nfloat look_round_n_directions(float a, int n) {\\n  float b = positive_angle(a);\\n  float div = TWO_PI / float(n);\\n  float c = roundTo(b, div);\\n  return look_upwards(c);\\n}\\n\\nfloat applyAlignOption(float rawAngle, float delta) {\\n  return\\n    (option >  2) ? look_round_n_directions(rawAngle + delta, option) :       // option 3-n: round to n directions\\n    (option == 2) ? look_horizontal_or_vertical(rawAngle + delta, hv_ratio) : // horizontal or vertical\\n    (option == 1) ? rawAngle + delta :       // use free angle, and flip to align with one direction of the axis\\n    (option == 0) ? look_upwards(rawAngle) : // use free angle, and stay upwards\\n    (option ==-1) ? 0.0 :                    // useful for backward compatibility, all texts remains horizontal\\n                    rawAngle;                // otherwise return back raw input angle\\n}\\n\\nbool isAxisTitle = (axis.x == 0.0) &&\\n                   (axis.y == 0.0) &&\\n                   (axis.z == 0.0);\\n\\nvoid main() {\\n  //Compute world offset\\n  float axisDistance = position.z;\\n  vec3 dataPosition = axisDistance * axis + offset;\\n\\n  float beta = angle; // i.e. user defined attributes for each tick\\n\\n  float axisAngle;\\n  float clipAngle;\\n  float flip;\\n\\n  if (enableAlign) {\\n    axisAngle = (isAxisTitle) ? HALF_PI :\\n                      computeViewAngle(dataPosition, dataPosition + axis);\\n    clipAngle = computeViewAngle(dataPosition, dataPosition + alignDir);\\n\\n    axisAngle += (sin(axisAngle) < 0.0) ? PI : 0.0;\\n    clipAngle += (sin(clipAngle) < 0.0) ? PI : 0.0;\\n\\n    flip = (dot(vec2(cos(axisAngle), sin(axisAngle)),\\n                vec2(sin(clipAngle),-cos(clipAngle))) > 0.0) ? 1.0 : 0.0;\\n\\n    beta += applyAlignOption(clipAngle, flip * PI);\\n  }\\n\\n  //Compute plane offset\\n  vec2 planeCoord = position.xy * pixelScale;\\n\\n  mat2 planeXform = scale * mat2(\\n     cos(beta), sin(beta),\\n    -sin(beta), cos(beta)\\n  );\\n\\n  vec2 viewOffset = 2.0 * planeXform * planeCoord / resolution;\\n\\n  //Compute clip position\\n  vec3 clipPosition = project(dataPosition);\\n\\n  //Apply text offset in clip coordinates\\n  clipPosition += vec3(viewOffset, 0.0);\\n\\n  //Done\\n  gl_Position = vec4(clipPosition, 1.0);\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.text=function(t){return i(t,s,l,null,[{name:\"position\",type:\"vec3\"}])};var c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec3 normal;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 enable;\\nuniform vec3 bounds[2];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n\\n  vec3 signAxis = sign(bounds[1] - bounds[0]);\\n\\n  vec3 realNormal = signAxis * normal;\\n\\n  if(dot(realNormal, enable) > 0.0) {\\n    vec3 minRange = min(bounds[0], bounds[1]);\\n    vec3 maxRange = max(bounds[0], bounds[1]);\\n    vec3 nPosition = mix(minRange, maxRange, 0.5 * (position + 1.0));\\n    gl_Position = projection * view * model * vec4(nPosition, 1.0);\\n  } else {\\n    gl_Position = vec4(0,0,0,0);\\n  }\\n\\n  colorChannel = abs(realNormal);\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 colors[3];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n  gl_FragColor = colorChannel.x * colors[0] +\\n                 colorChannel.y * colors[1] +\\n                 colorChannel.z * colors[2];\\n}\"]);r.bg=function(t){return i(t,c,u,null,[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}])}},{\"gl-shader\":301,glslify:409}],238:[function(t,e,r){(function(r){\"use strict\";e.exports=function(t,e,r,a,s,l){var u=n(t),h=i(t,[{buffer:u,size:3}]),f=o(t);f.attributes.position.location=0;var p=new c(t,f,u,h);return p.update(e,r,a,s,l),p};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"vectorize-text\"),o=t(\"./shaders\").text,s=window||r.global||{},l=s.__TEXT_CACHE||{};s.__TEXT_CACHE={};function c(t,e,r,n){this.gl=t,this.shader=e,this.buffer=r,this.vao=n,this.tickOffset=this.tickCount=this.labelOffset=this.labelCount=null}var u=c.prototype,h=[0,0];u.bind=function(t,e,r,n){this.vao.bind(),this.shader.bind();var i=this.shader.uniforms;i.model=t,i.view=e,i.projection=r,i.pixelScale=n,h[0]=this.gl.drawingBufferWidth,h[1]=this.gl.drawingBufferHeight,this.shader.uniforms.resolution=h},u.unbind=function(){this.vao.unbind()},u.update=function(t,e,r,n,i){var o=[];function s(t,e,r,n,i,s){var c=l[r];c||(c=l[r]={});var u=c[e];u||(u=c[e]=function(t,e){try{return a(t,e)}catch(e){return console.warn('error vectorizing text:\"'+t+'\" error:',e),{cells:[],positions:[]}}}(e,{triangles:!0,font:r,textAlign:\"center\",textBaseline:\"middle\",lineSpacing:i,styletags:s}));for(var h=(n||12)/12,f=u.positions,p=u.cells,d=0,g=p.length;d<g;++d)for(var v=p[d],m=2;m>=0;--m){var y=f[v[m]];o.push(h*y[0],-h*y[1],t)}}for(var c=[0,0,0],u=[0,0,0],h=[0,0,0],f=[0,0,0],p={breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},d=0;d<3;++d){h[d]=o.length/3|0,s(.5*(t[0][d]+t[1][d]),e[d],r[d],12,1.25,p),f[d]=(o.length/3|0)-h[d],c[d]=o.length/3|0;for(var g=0;g<n[d].length;++g)n[d][g].text&&s(n[d][g].x,n[d][g].text,n[d][g].font||i,n[d][g].fontSize||12,1.25,p);u[d]=(o.length/3|0)-c[d]}this.buffer.update(o),this.tickOffset=c,this.tickCount=u,this.labelOffset=h,this.labelCount=f},u.drawTicks=function(t,e,r,n,i,a,o,s){this.tickCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t]))},u.drawLabel=function(t,e,r,n,i,a,o,s){this.labelCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.labelCount[t],this.labelOffset[t]))},u.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()}}).call(this,t(\"_process\"))},{\"./shaders\":237,_process:482,\"gl-buffer\":241,\"gl-vao\":327,\"vectorize-text\":550}],239:[function(t,e,r){\"use strict\";function n(t,e){var r=t+\"\",n=r.indexOf(\".\"),i=0;n>=0&&(i=r.length-n-1);var a=Math.pow(10,i),o=Math.round(t*e*a),s=o+\"\";if(s.indexOf(\"e\")>=0)return s;var l=o/a,c=o%a;o<0?(l=0|-Math.ceil(l),c=0|-c):(l=0|Math.floor(l),c|=0);var u=\"\"+l;if(o<0&&(u=\"-\"+u),i){for(var h=\"\"+c;h.length<i;)h=\"0\"+h;return u+\".\"+h}return u}r.create=function(t,e){for(var r=[],i=0;i<3;++i){for(var a=[],o=(t[0][i],t[1][i],0);o*e[i]<=t[1][i];++o)a.push({x:o*e[i],text:n(e[i],o)});for(var o=-1;o*e[i]>=t[0][i];--o)a.push({x:o*e[i],text:n(e[i],o)});r.push(a)}return r},r.equal=function(t,e){for(var r=0;r<3;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;++n){var i=t[r][n],a=e[r][n];if(i.x!==a.x||i.text!==a.text||i.font!==a.font||i.fontColor!==a.fontColor||i.fontSize!==a.fontSize||i.dx!==a.dx||i.dy!==a.dy)return!1}}return!0}},{}],240:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,l,h){var f=e.model||c,p=e.view||c,m=e.projection||c,y=e._ortho||!1,x=t.bounds,b=(h=h||a(f,p,m,x,y)).axis;o(u,p,f),o(u,m,u);for(var _=g,w=0;w<3;++w)_[w].lo=1/0,_[w].hi=-1/0,_[w].pixelsPerDataUnit=1/0;var k=n(s(u,u));s(u,u);for(var T=0;T<3;++T){var A=(T+1)%3,M=(T+2)%3,S=v;t:for(var w=0;w<2;++w){var E=[];if(b[T]<0!=!!w){S[T]=x[w][T];for(var C=0;C<2;++C){S[A]=x[C^w][A];for(var L=0;L<2;++L)S[M]=x[L^C^w][M],E.push(S.slice())}for(var P=y?5:4,C=P;C===P;++C){if(0===E.length)continue t;E=i.positive(E,k[C])}for(var C=0;C<E.length;++C)for(var M=E[C],O=d(v,u,M,r,l),L=0;L<3;++L)_[L].lo=Math.min(_[L].lo,M[L]),_[L].hi=Math.max(_[L].hi,M[L]),L!==T&&(_[L].pixelsPerDataUnit=Math.min(_[L].pixelsPerDataUnit,Math.abs(O[L])))}}}return _};var n=t(\"extract-frustum-planes\"),i=t(\"split-polygon\"),a=t(\"./lib/cube.js\"),o=t(\"gl-mat4/multiply\"),s=t(\"gl-mat4/transpose\"),l=t(\"gl-vec4/transformMat4\"),c=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]),u=new Float32Array(16);function h(t,e,r){this.lo=t,this.hi=e,this.pixelsPerDataUnit=r}var f=[0,0,0,1],p=[0,0,0,1];function d(t,e,r,n,i){for(var a=0;a<3;++a){for(var o=f,s=p,c=0;c<3;++c)s[c]=o[c]=r[c];s[3]=o[3]=1,s[a]+=1,l(s,s,e),s[3]<0&&(t[a]=1/0),o[a]-=1,l(o,o,e),o[3]<0&&(t[a]=1/0);var u=(o[0]/o[3]-s[0]/s[3])*n,h=(o[1]/o[3]-s[1]/s[3])*i;t[a]=.25*Math.sqrt(u*u+h*h)}return t}var g=[new h(1/0,-1/0,1/0),new h(1/0,-1/0,1/0),new h(1/0,-1/0,1/0)],v=[0,0,0]},{\"./lib/cube.js\":235,\"extract-frustum-planes\":224,\"gl-mat4/multiply\":267,\"gl-mat4/transpose\":276,\"gl-vec4/transformMat4\":398,\"split-polygon\":527}],241:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"ndarray-ops\"),a=t(\"ndarray\"),o=[\"uint8\",\"uint8_clamped\",\"uint16\",\"uint32\",\"int8\",\"int16\",\"int32\",\"float32\"];function s(t,e,r,n,i){this.gl=t,this.type=e,this.handle=r,this.length=n,this.usage=i}var l=s.prototype;function c(t,e,r,n,i,a){var o=i.length*i.BYTES_PER_ELEMENT;if(a<0)return t.bufferData(e,i,n),o;if(o+a>r)throw new Error(\"gl-buffer: If resizing buffer, must not specify offset\");return t.bufferSubData(e,a,i),r}function u(t,e){for(var r=n.malloc(t.length,e),i=t.length,a=0;a<i;++a)r[a]=t[a];return r}l.bind=function(){this.gl.bindBuffer(this.type,this.handle)},l.unbind=function(){this.gl.bindBuffer(this.type,null)},l.dispose=function(){this.gl.deleteBuffer(this.handle)},l.update=function(t,e){if(\"number\"!=typeof e&&(e=-1),this.bind(),\"object\"==typeof t&&\"undefined\"!=typeof t.shape){var r=t.dtype;if(o.indexOf(r)<0&&(r=\"float32\"),this.type===this.gl.ELEMENT_ARRAY_BUFFER)r=gl.getExtension(\"OES_element_index_uint\")&&\"uint16\"!==r?\"uint32\":\"uint16\";if(r===t.dtype&&function(t,e){for(var r=1,n=e.length-1;n>=0;--n){if(e[n]!==r)return!1;r*=t[n]}return!0}(t.shape,t.stride))0===t.offset&&t.data.length===t.shape[0]?this.length=c(this.gl,this.type,this.length,this.usage,t.data,e):this.length=c(this.gl,this.type,this.length,this.usage,t.data.subarray(t.offset,t.shape[0]),e);else{var s=n.malloc(t.size,r),l=a(s,t.shape);i.assign(l,t),this.length=c(this.gl,this.type,this.length,this.usage,e<0?s:s.subarray(0,t.size),e),n.free(s)}}else if(Array.isArray(t)){var h;h=this.type===this.gl.ELEMENT_ARRAY_BUFFER?u(t,\"uint16\"):u(t,\"float32\"),this.length=c(this.gl,this.type,this.length,this.usage,e<0?h:h.subarray(0,t.length),e),n.free(h)}else if(\"object\"==typeof t&&\"number\"==typeof t.length)this.length=c(this.gl,this.type,this.length,this.usage,t,e);else{if(\"number\"!=typeof t&&void 0!==t)throw new Error(\"gl-buffer: Invalid data type\");if(e>=0)throw new Error(\"gl-buffer: Cannot specify offset when resizing buffer\");(t|=0)<=0&&(t=1),this.gl.bufferData(this.type,0|t,this.usage),this.length=t}},e.exports=function(t,e,r,n){if(r=r||t.ARRAY_BUFFER,n=n||t.DYNAMIC_DRAW,r!==t.ARRAY_BUFFER&&r!==t.ELEMENT_ARRAY_BUFFER)throw new Error(\"gl-buffer: Invalid type for webgl buffer, must be either gl.ARRAY_BUFFER or gl.ELEMENT_ARRAY_BUFFER\");if(n!==t.DYNAMIC_DRAW&&n!==t.STATIC_DRAW&&n!==t.STREAM_DRAW)throw new Error(\"gl-buffer: Invalid usage for buffer, must be either gl.DYNAMIC_DRAW, gl.STATIC_DRAW or gl.STREAM_DRAW\");var i=t.createBuffer(),a=new s(t,r,i,0,n);return a.update(e),a}},{ndarray:450,\"ndarray-ops\":444,\"typedarray-pool\":545}],242:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\"),i=function(t,e){for(var r=0;r<t.length;r++)if(t[r]>=e)return r-1;return r},a=n.create(),o=n.create(),s=function(t,e,r){return t<e?e:t>r?r:t},l=function(t,e,r,l){var c=t[0],u=t[1],h=t[2],f=r[0].length,p=r[1].length,d=r[2].length,g=i(r[0],c),v=i(r[1],u),m=i(r[2],h),y=g+1,x=v+1,b=m+1;if(l&&(g=s(g,0,f-1),y=s(y,0,f-1),v=s(v,0,p-1),x=s(x,0,p-1),m=s(m,0,d-1),b=s(b,0,d-1)),g<0||v<0||m<0||y>=f||x>=p||b>=d)return n.create();var _=(c-r[0][g])/(r[0][y]-r[0][g]),w=(u-r[1][v])/(r[1][x]-r[1][v]),k=(h-r[2][m])/(r[2][b]-r[2][m]);(_<0||_>1||isNaN(_))&&(_=0),(w<0||w>1||isNaN(w))&&(w=0),(k<0||k>1||isNaN(k))&&(k=0);var T=m*f*p,A=b*f*p,M=v*f,S=x*f,E=g,C=y,L=e[M+T+E],P=e[M+T+C],O=e[S+T+E],z=e[S+T+C],I=e[M+A+E],D=e[M+A+C],R=e[S+A+E],F=e[S+A+C],B=n.create();return n.lerp(B,L,P,_),n.lerp(a,O,z,_),n.lerp(B,B,a,w),n.lerp(a,I,D,_),n.lerp(o,R,F,_),n.lerp(a,a,o,w),n.lerp(B,B,a,k),B};e.exports=function(t,e){var r;r=t.positions?t.positions:function(t){for(var e=t[0],r=t[1],n=t[2],i=[],a=0;a<n.length;a++)for(var o=0;o<r.length;o++)for(var s=0;s<e.length;s++)i.push([n[a],r[o],e[s]]);return i}(t.meshgrid);var i=t.meshgrid,a=t.vectors,o={positions:[],vertexIntensity:[],vertexIntensityBounds:t.vertexIntensityBounds,vertexNormals:[],vectors:[],cells:[],coneOffset:t.coneOffset,colormap:t.colormap};if(0===t.positions.length)return e&&(e[0]=[0,0,0],e[1]=[0,0,0]),o;for(var s=0,c=1/0,u=-1/0,h=1/0,f=-1/0,p=1/0,d=-1/0,g=null,v=null,m=[],y=1/0,x=0;x<r.length;x++){var b,_=r[x];c=Math.min(_[0],c),u=Math.max(_[0],u),h=Math.min(_[1],h),f=Math.max(_[1],f),p=Math.min(_[2],p),d=Math.max(_[2],d),b=i?l(_,a,i,!0):a[x],n.length(b)>s&&(s=n.length(b)),x&&(y=Math.min(y,2*n.distance(g,_)/(n.length(v)+n.length(b)))),g=_,v=b,m.push(b)}var w=[c,h,p],k=[u,f,d];e&&(e[0]=w,e[1]=k),0===s&&(s=1);var T=1/s;isFinite(y)&&!isNaN(y)||(y=1),o.vectorScale=y;var A=function(t,e,r){var i=n.create();return void 0!==t&&n.set(i,t,e,r),i}(0,1,0),M=t.coneSize||.5;t.absoluteConeSize&&(M=t.absoluteConeSize*T),o.coneScale=M;x=0;for(var S=0;x<r.length;x++)for(var E=(_=r[x])[0],C=_[1],L=_[2],P=m[x],O=n.length(P)*T,z=0;z<8;z++){o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vertexIntensity.push(O,O,O),o.vertexIntensity.push(O,O,O),o.vertexNormals.push(A,A,A),o.vertexNormals.push(A,A,A);var I=o.positions.length;o.cells.push([I-6,I-5,I-4],[I-3,I-2,I-1])}return o},e.exports.createConeMesh=t(\"./lib/conemesh\")},{\"./lib/conemesh\":243,\"gl-vec3\":346}],243:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./shaders\"),g=d.meshShader,v=d.pickShader,m=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function y(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,y,x,b,_,w,k,T){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=i,this.triangleVectors=a,this.triangleColors=s,this.triangleNormals=c,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=u,this.triangleCount=0,this.lineWidth=1,this.edgePositions=h,this.edgeColors=p,this.edgeUVs=d,this.edgeIds=f,this.edgeVAO=g,this.edgeCount=0,this.pointPositions=v,this.pointColors=x,this.pointUVs=b,this.pointSizes=_,this.pointIds=y,this.pointVAO=w,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=k,this.contourVAO=T,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.coneScale=2,this.vectorScale=1,this.coneOffset=.25,this._model=m,this._view=m,this._projection=m,this._resolution=[1,1]}var x=y.prototype;function b(t){var e=n(t,v.vertex,v.fragment,null,v.attributes);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.vector.location=5,e}x.isOpaque=function(){return this.opacity>=1},x.isTransparent=function(){return this.opacity<1},x.pickSlots=1,x.setPickBase=function(t){this.pickId=t},x.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=i[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},x.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),void 0!==t.vectorScale&&(this.vectorScale=t.vectorScale),void 0!==t.coneScale&&(this.coneScale=t.coneScale),void 0!==t.coneOffset&&(this.coneOffset=t.coneOffset),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=h({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return u(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,i=t.vectors;if(n&&r&&i){var a=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[],w=[],k=[];this.cells=r,this.positions=n;var T=t.vertexNormals,A=t.cellNormals,M=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,S=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!A&&(A=s.faceNormals(r,n,S)),A||T||(T=s.vertexNormals(r,n,M));var E=t.vertexColors,C=t.cellColors,L=t.meshColor||[1,1,1,1],P=t.vertexUVs,O=t.vertexIntensity,z=t.cellUVs,I=t.cellIntensity,D=1/0,R=-1/0;if(!P&&!z)if(O)if(t.vertexIntensityBounds)D=+t.vertexIntensityBounds[0],R=+t.vertexIntensityBounds[1];else for(var F=0;F<O.length;++F){var B=O[F];D=Math.min(D,B),R=Math.max(R,B)}else if(I)for(F=0;F<I.length;++F){B=I[F];D=Math.min(D,B),R=Math.max(R,B)}else for(F=0;F<n.length;++F){B=n[F][2];D=Math.min(D,B),R=Math.max(R,B)}this.intensity=O||(I?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,I):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var N=t.pointSizes,j=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(F=0;F<n.length;++F)for(var U=n[F],V=0;V<3;++V)!isNaN(U[V])&&isFinite(U[V])&&(this.bounds[0][V]=Math.min(this.bounds[0][V],U[V]),this.bounds[1][V]=Math.max(this.bounds[1][V],U[V]));var q=0,H=0,G=0;t:for(F=0;F<r.length;++F){var Y=r[F];switch(Y.length){case 1:for(U=n[X=Y[0]],V=0;V<3;++V)if(isNaN(U[V])||!isFinite(U[V]))continue t;x.push(U[0],U[1],U[2],U[3]),3===(Z=E?E[X]:C?C[F]:L).length?b.push(Z[0],Z[1],Z[2],1):b.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],_.push(J[0],J[1]),N?w.push(N[X]):w.push(j),k.push(F),G+=1;break;case 2:for(V=0;V<2;++V){U=n[X=Y[V]];for(var W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t}for(V=0;V<2;++V){U=n[X=Y[V]];g.push(U[0],U[1],U[2]),3===(Z=E?E[X]:C?C[F]:L).length?v.push(Z[0],Z[1],Z[2],1):v.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],m.push(J[0],J[1]),y.push(F)}H+=1;break;case 3:for(V=0;V<3;++V)for(U=n[X=Y[V]],W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t;for(V=0;V<3;++V){var X;U=n[X=Y[2-V]];a.push(U[0],U[1],U[2],U[3]);var Z,J,K,$=i[X];l.push($[0],$[1],$[2]),3===(Z=E?E[X]:C?C[F]:L).length?c.push(Z[0],Z[1],Z[2],1):c.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],p.push(J[0],J[1]),K=T?T[X]:A[F],f.push(K[0],K[1],K[2]),d.push(F)}q+=1}}this.pointCount=G,this.edgeCount=H,this.triangleCount=q,this.pointPositions.update(x),this.pointColors.update(b),this.pointUVs.update(_),this.pointSizes.update(w),this.pointIds.update(new Uint32Array(k)),this.edgePositions.update(g),this.edgeColors.update(v),this.edgeUVs.update(m),this.edgeIds.update(new Uint32Array(y)),this.trianglePositions.update(a),this.triangleVectors.update(l),this.triangleColors.update(c),this.triangleUVs.update(p),this.triangleNormals.update(f),this.triangleIds.update(new Uint32Array(d))}},x.drawTransparent=x.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:m.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var f=u[12+o],p=0;p<3;++p)f+=u[4*p+o]*this.lightPosition[p];s.lightPosition[o]=f/h}if(this.triangleCount>0){var d=this.triShader;d.bind(),d.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},x.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:i,clipBounds:a,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind())},x.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3);return{index:Math.floor(r[1]/48),position:n,dataCoordinate:n}},x.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose()},e.exports=function(t,e){1===arguments.length&&(t=(e=t).gl);var r=e.triShader||function(t){var e=n(t,g.vertex,g.fragment,null,g.attributes);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.vector.location=5,e}(t),s=b(t),l=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));l.generateMipmap(),l.minFilter=t.LINEAR_MIPMAP_LINEAR,l.magFilter=t.LINEAR;var c=i(t),h=i(t),f=i(t),p=i(t),d=i(t),v=i(t),m=a(t,[{buffer:c,type:t.FLOAT,size:4},{buffer:v,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:f,type:t.FLOAT,size:4},{buffer:p,type:t.FLOAT,size:2},{buffer:d,type:t.FLOAT,size:3},{buffer:h,type:t.FLOAT,size:3}]),x=i(t),_=i(t),w=i(t),k=i(t),T=a(t,[{buffer:x,type:t.FLOAT,size:3},{buffer:k,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:_,type:t.FLOAT,size:4},{buffer:w,type:t.FLOAT,size:2}]),A=i(t),M=i(t),S=i(t),E=i(t),C=i(t),L=a(t,[{buffer:A,type:t.FLOAT,size:3},{buffer:C,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:M,type:t.FLOAT,size:4},{buffer:S,type:t.FLOAT,size:2},{buffer:E,type:t.FLOAT,size:1}]),P=i(t),O=new y(t,l,r,s,c,h,v,f,p,d,m,x,k,_,w,T,A,C,M,S,E,L,P,a(t,[{buffer:P,type:t.FLOAT,size:3}]));return O.update(e),O}},{\"./shaders\":244,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-shader\":301,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,normals:453,\"simplicial-complex-contour\":518,\"typedarray-pool\":545}],244:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\nuniform float vectorScale;\\nuniform float coneScale;\\n\\nuniform float coneOffset;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * conePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal,0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(conePosition, 1.0);\\n  vec4 t_position  = view * conePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = conePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular\\n            , opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nuniform float vectorScale;\\nuniform float coneScale;\\nuniform float coneOffset;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n  gl_Position = projection * view * conePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec3\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec3\"}]}},{glslify:409}],245:[function(t,e,r){e.exports={0:\"NONE\",1:\"ONE\",2:\"LINE_LOOP\",3:\"LINE_STRIP\",4:\"TRIANGLES\",5:\"TRIANGLE_STRIP\",6:\"TRIANGLE_FAN\",256:\"DEPTH_BUFFER_BIT\",512:\"NEVER\",513:\"LESS\",514:\"EQUAL\",515:\"LEQUAL\",516:\"GREATER\",517:\"NOTEQUAL\",518:\"GEQUAL\",519:\"ALWAYS\",768:\"SRC_COLOR\",769:\"ONE_MINUS_SRC_COLOR\",770:\"SRC_ALPHA\",771:\"ONE_MINUS_SRC_ALPHA\",772:\"DST_ALPHA\",773:\"ONE_MINUS_DST_ALPHA\",774:\"DST_COLOR\",775:\"ONE_MINUS_DST_COLOR\",776:\"SRC_ALPHA_SATURATE\",1024:\"STENCIL_BUFFER_BIT\",1028:\"FRONT\",1029:\"BACK\",1032:\"FRONT_AND_BACK\",1280:\"INVALID_ENUM\",1281:\"INVALID_VALUE\",1282:\"INVALID_OPERATION\",1285:\"OUT_OF_MEMORY\",1286:\"INVALID_FRAMEBUFFER_OPERATION\",2304:\"CW\",2305:\"CCW\",2849:\"LINE_WIDTH\",2884:\"CULL_FACE\",2885:\"CULL_FACE_MODE\",2886:\"FRONT_FACE\",2928:\"DEPTH_RANGE\",2929:\"DEPTH_TEST\",2930:\"DEPTH_WRITEMASK\",2931:\"DEPTH_CLEAR_VALUE\",2932:\"DEPTH_FUNC\",2960:\"STENCIL_TEST\",2961:\"STENCIL_CLEAR_VALUE\",2962:\"STENCIL_FUNC\",2963:\"STENCIL_VALUE_MASK\",2964:\"STENCIL_FAIL\",2965:\"STENCIL_PASS_DEPTH_FAIL\",2966:\"STENCIL_PASS_DEPTH_PASS\",2967:\"STENCIL_REF\",2968:\"STENCIL_WRITEMASK\",2978:\"VIEWPORT\",3024:\"DITHER\",3042:\"BLEND\",3088:\"SCISSOR_BOX\",3089:\"SCISSOR_TEST\",3106:\"COLOR_CLEAR_VALUE\",3107:\"COLOR_WRITEMASK\",3317:\"UNPACK_ALIGNMENT\",3333:\"PACK_ALIGNMENT\",3379:\"MAX_TEXTURE_SIZE\",3386:\"MAX_VIEWPORT_DIMS\",3408:\"SUBPIXEL_BITS\",3410:\"RED_BITS\",3411:\"GREEN_BITS\",3412:\"BLUE_BITS\",3413:\"ALPHA_BITS\",3414:\"DEPTH_BITS\",3415:\"STENCIL_BITS\",3553:\"TEXTURE_2D\",4352:\"DONT_CARE\",4353:\"FASTEST\",4354:\"NICEST\",5120:\"BYTE\",5121:\"UNSIGNED_BYTE\",5122:\"SHORT\",5123:\"UNSIGNED_SHORT\",5124:\"INT\",5125:\"UNSIGNED_INT\",5126:\"FLOAT\",5386:\"INVERT\",5890:\"TEXTURE\",6401:\"STENCIL_INDEX\",6402:\"DEPTH_COMPONENT\",6406:\"ALPHA\",6407:\"RGB\",6408:\"RGBA\",6409:\"LUMINANCE\",6410:\"LUMINANCE_ALPHA\",7680:\"KEEP\",7681:\"REPLACE\",7682:\"INCR\",7683:\"DECR\",7936:\"VENDOR\",7937:\"RENDERER\",7938:\"VERSION\",9728:\"NEAREST\",9729:\"LINEAR\",9984:\"NEAREST_MIPMAP_NEAREST\",9985:\"LINEAR_MIPMAP_NEAREST\",9986:\"NEAREST_MIPMAP_LINEAR\",9987:\"LINEAR_MIPMAP_LINEAR\",10240:\"TEXTURE_MAG_FILTER\",10241:\"TEXTURE_MIN_FILTER\",10242:\"TEXTURE_WRAP_S\",10243:\"TEXTURE_WRAP_T\",10497:\"REPEAT\",10752:\"POLYGON_OFFSET_UNITS\",16384:\"COLOR_BUFFER_BIT\",32769:\"CONSTANT_COLOR\",32770:\"ONE_MINUS_CONSTANT_COLOR\",32771:\"CONSTANT_ALPHA\",32772:\"ONE_MINUS_CONSTANT_ALPHA\",32773:\"BLEND_COLOR\",32774:\"FUNC_ADD\",32777:\"BLEND_EQUATION_RGB\",32778:\"FUNC_SUBTRACT\",32779:\"FUNC_REVERSE_SUBTRACT\",32819:\"UNSIGNED_SHORT_4_4_4_4\",32820:\"UNSIGNED_SHORT_5_5_5_1\",32823:\"POLYGON_OFFSET_FILL\",32824:\"POLYGON_OFFSET_FACTOR\",32854:\"RGBA4\",32855:\"RGB5_A1\",32873:\"TEXTURE_BINDING_2D\",32926:\"SAMPLE_ALPHA_TO_COVERAGE\",32928:\"SAMPLE_COVERAGE\",32936:\"SAMPLE_BUFFERS\",32937:\"SAMPLES\",32938:\"SAMPLE_COVERAGE_VALUE\",32939:\"SAMPLE_COVERAGE_INVERT\",32968:\"BLEND_DST_RGB\",32969:\"BLEND_SRC_RGB\",32970:\"BLEND_DST_ALPHA\",32971:\"BLEND_SRC_ALPHA\",33071:\"CLAMP_TO_EDGE\",33170:\"GENERATE_MIPMAP_HINT\",33189:\"DEPTH_COMPONENT16\",33306:\"DEPTH_STENCIL_ATTACHMENT\",33635:\"UNSIGNED_SHORT_5_6_5\",33648:\"MIRRORED_REPEAT\",33901:\"ALIASED_POINT_SIZE_RANGE\",33902:\"ALIASED_LINE_WIDTH_RANGE\",33984:\"TEXTURE0\",33985:\"TEXTURE1\",33986:\"TEXTURE2\",33987:\"TEXTURE3\",33988:\"TEXTURE4\",33989:\"TEXTURE5\",33990:\"TEXTURE6\",33991:\"TEXTURE7\",33992:\"TEXTURE8\",33993:\"TEXTURE9\",33994:\"TEXTURE10\",33995:\"TEXTURE11\",33996:\"TEXTURE12\",33997:\"TEXTURE13\",33998:\"TEXTURE14\",33999:\"TEXTURE15\",34000:\"TEXTURE16\",34001:\"TEXTURE17\",34002:\"TEXTURE18\",34003:\"TEXTURE19\",34004:\"TEXTURE20\",34005:\"TEXTURE21\",34006:\"TEXTURE22\",34007:\"TEXTURE23\",34008:\"TEXTURE24\",34009:\"TEXTURE25\",34010:\"TEXTURE26\",34011:\"TEXTURE27\",34012:\"TEXTURE28\",34013:\"TEXTURE29\",34014:\"TEXTURE30\",34015:\"TEXTURE31\",34016:\"ACTIVE_TEXTURE\",34024:\"MAX_RENDERBUFFER_SIZE\",34041:\"DEPTH_STENCIL\",34055:\"INCR_WRAP\",34056:\"DECR_WRAP\",34067:\"TEXTURE_CUBE_MAP\",34068:\"TEXTURE_BINDING_CUBE_MAP\",34069:\"TEXTURE_CUBE_MAP_POSITIVE_X\",34070:\"TEXTURE_CUBE_MAP_NEGATIVE_X\",34071:\"TEXTURE_CUBE_MAP_POSITIVE_Y\",34072:\"TEXTURE_CUBE_MAP_NEGATIVE_Y\",34073:\"TEXTURE_CUBE_MAP_POSITIVE_Z\",34074:\"TEXTURE_CUBE_MAP_NEGATIVE_Z\",34076:\"MAX_CUBE_MAP_TEXTURE_SIZE\",34338:\"VERTEX_ATTRIB_ARRAY_ENABLED\",34339:\"VERTEX_ATTRIB_ARRAY_SIZE\",34340:\"VERTEX_ATTRIB_ARRAY_STRIDE\",34341:\"VERTEX_ATTRIB_ARRAY_TYPE\",34342:\"CURRENT_VERTEX_ATTRIB\",34373:\"VERTEX_ATTRIB_ARRAY_POINTER\",34466:\"NUM_COMPRESSED_TEXTURE_FORMATS\",34467:\"COMPRESSED_TEXTURE_FORMATS\",34660:\"BUFFER_SIZE\",34661:\"BUFFER_USAGE\",34816:\"STENCIL_BACK_FUNC\",34817:\"STENCIL_BACK_FAIL\",34818:\"STENCIL_BACK_PASS_DEPTH_FAIL\",34819:\"STENCIL_BACK_PASS_DEPTH_PASS\",34877:\"BLEND_EQUATION_ALPHA\",34921:\"MAX_VERTEX_ATTRIBS\",34922:\"VERTEX_ATTRIB_ARRAY_NORMALIZED\",34930:\"MAX_TEXTURE_IMAGE_UNITS\",34962:\"ARRAY_BUFFER\",34963:\"ELEMENT_ARRAY_BUFFER\",34964:\"ARRAY_BUFFER_BINDING\",34965:\"ELEMENT_ARRAY_BUFFER_BINDING\",34975:\"VERTEX_ATTRIB_ARRAY_BUFFER_BINDING\",35040:\"STREAM_DRAW\",35044:\"STATIC_DRAW\",35048:\"DYNAMIC_DRAW\",35632:\"FRAGMENT_SHADER\",35633:\"VERTEX_SHADER\",35660:\"MAX_VERTEX_TEXTURE_IMAGE_UNITS\",35661:\"MAX_COMBINED_TEXTURE_IMAGE_UNITS\",35663:\"SHADER_TYPE\",35664:\"FLOAT_VEC2\",35665:\"FLOAT_VEC3\",35666:\"FLOAT_VEC4\",35667:\"INT_VEC2\",35668:\"INT_VEC3\",35669:\"INT_VEC4\",35670:\"BOOL\",35671:\"BOOL_VEC2\",35672:\"BOOL_VEC3\",35673:\"BOOL_VEC4\",35674:\"FLOAT_MAT2\",35675:\"FLOAT_MAT3\",35676:\"FLOAT_MAT4\",35678:\"SAMPLER_2D\",35680:\"SAMPLER_CUBE\",35712:\"DELETE_STATUS\",35713:\"COMPILE_STATUS\",35714:\"LINK_STATUS\",35715:\"VALIDATE_STATUS\",35716:\"INFO_LOG_LENGTH\",35717:\"ATTACHED_SHADERS\",35718:\"ACTIVE_UNIFORMS\",35719:\"ACTIVE_UNIFORM_MAX_LENGTH\",35720:\"SHADER_SOURCE_LENGTH\",35721:\"ACTIVE_ATTRIBUTES\",35722:\"ACTIVE_ATTRIBUTE_MAX_LENGTH\",35724:\"SHADING_LANGUAGE_VERSION\",35725:\"CURRENT_PROGRAM\",36003:\"STENCIL_BACK_REF\",36004:\"STENCIL_BACK_VALUE_MASK\",36005:\"STENCIL_BACK_WRITEMASK\",36006:\"FRAMEBUFFER_BINDING\",36007:\"RENDERBUFFER_BINDING\",36048:\"FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE\",36049:\"FRAMEBUFFER_ATTACHMENT_OBJECT_NAME\",36050:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL\",36051:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE\",36053:\"FRAMEBUFFER_COMPLETE\",36054:\"FRAMEBUFFER_INCOMPLETE_ATTACHMENT\",36055:\"FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT\",36057:\"FRAMEBUFFER_INCOMPLETE_DIMENSIONS\",36061:\"FRAMEBUFFER_UNSUPPORTED\",36064:\"COLOR_ATTACHMENT0\",36096:\"DEPTH_ATTACHMENT\",36128:\"STENCIL_ATTACHMENT\",36160:\"FRAMEBUFFER\",36161:\"RENDERBUFFER\",36162:\"RENDERBUFFER_WIDTH\",36163:\"RENDERBUFFER_HEIGHT\",36164:\"RENDERBUFFER_INTERNAL_FORMAT\",36168:\"STENCIL_INDEX8\",36176:\"RENDERBUFFER_RED_SIZE\",36177:\"RENDERBUFFER_GREEN_SIZE\",36178:\"RENDERBUFFER_BLUE_SIZE\",36179:\"RENDERBUFFER_ALPHA_SIZE\",36180:\"RENDERBUFFER_DEPTH_SIZE\",36181:\"RENDERBUFFER_STENCIL_SIZE\",36194:\"RGB565\",36336:\"LOW_FLOAT\",36337:\"MEDIUM_FLOAT\",36338:\"HIGH_FLOAT\",36339:\"LOW_INT\",36340:\"MEDIUM_INT\",36341:\"HIGH_INT\",36346:\"SHADER_COMPILER\",36347:\"MAX_VERTEX_UNIFORM_VECTORS\",36348:\"MAX_VARYING_VECTORS\",36349:\"MAX_FRAGMENT_UNIFORM_VECTORS\",37440:\"UNPACK_FLIP_Y_WEBGL\",37441:\"UNPACK_PREMULTIPLY_ALPHA_WEBGL\",37442:\"CONTEXT_LOST_WEBGL\",37443:\"UNPACK_COLORSPACE_CONVERSION_WEBGL\",37444:\"BROWSER_DEFAULT_WEBGL\"}},{}],246:[function(t,e,r){var n=t(\"./1.0/numbers\");e.exports=function(t){return n[t]}},{\"./1.0/numbers\":245}],247:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),o=i(e,[{buffer:r,type:e.FLOAT,size:3,offset:0,stride:40},{buffer:r,type:e.FLOAT,size:4,offset:12,stride:40},{buffer:r,type:e.FLOAT,size:3,offset:28,stride:40}]),l=a(e);l.attributes.position.location=0,l.attributes.color.location=1,l.attributes.offset.location=2;var c=new s(e,r,o,l);return c.update(t),c};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\"),o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.shader=n,this.buffer=e,this.vao=r,this.pixelRatio=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lineWidth=[1,1,1],this.capSize=[10,10,10],this.lineCount=[0,0,0],this.lineOffset=[0,0,0],this.opacity=1,this.hasAlpha=!1}var l=s.prototype;function c(t,e){for(var r=0;r<3;++r)t[0][r]=Math.min(t[0][r],e[r]),t[1][r]=Math.max(t[1][r],e[r])}l.isOpaque=function(){return!this.hasAlpha},l.isTransparent=function(){return this.hasAlpha},l.drawTransparent=l.draw=function(t){var e=this.gl,r=this.shader.uniforms;this.shader.bind();var n=r.view=t.view||o,i=r.projection=t.projection||o;r.model=t.model||o,r.clipBounds=this.clipBounds,r.opacity=this.opacity;var a=n[12],s=n[13],l=n[14],c=n[15],u=(t._ortho||!1?2:1)*this.pixelRatio*(i[3]*a+i[7]*s+i[11]*l+i[15]*c)/e.drawingBufferHeight;this.vao.bind();for(var h=0;h<3;++h)e.lineWidth(this.lineWidth[h]*this.pixelRatio),r.capSize=this.capSize[h]*u,this.lineCount[h]&&e.drawArrays(e.LINES,this.lineOffset[h],this.lineCount[h]);this.vao.unbind()};var u=function(){for(var t=new Array(3),e=0;e<3;++e){for(var r=[],n=1;n<=2;++n)for(var i=-1;i<=1;i+=2){var a=[0,0,0];a[(n+e)%3]=i,r.push(a)}t[e]=r}return t}();function h(t,e,r,n){for(var i=u[n],a=0;a<i.length;++a){var o=i[a];t.push(e[0],e[1],e[2],r[0],r[1],r[2],r[3],o[0],o[1],o[2])}return i.length}l.update=function(t){\"lineWidth\"in(t=t||{})&&(this.lineWidth=t.lineWidth,Array.isArray(this.lineWidth)||(this.lineWidth=[this.lineWidth,this.lineWidth,this.lineWidth])),\"capSize\"in t&&(this.capSize=t.capSize,Array.isArray(this.capSize)||(this.capSize=[this.capSize,this.capSize,this.capSize])),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var e=t.color||[[0,0,0],[0,0,0],[0,0,0]],r=t.position,n=t.error;if(Array.isArray(e[0])||(e=[e,e,e]),r&&n){var i=[],a=r.length,o=0;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.lineCount=[0,0,0];for(var s=0;s<3;++s){this.lineOffset[s]=o;t:for(var l=0;l<a;++l){for(var u=r[l],f=0;f<3;++f)if(isNaN(u[f])||!isFinite(u[f]))continue t;var p=n[l],d=e[s];if(Array.isArray(d[0])&&(d=e[l]),3===d.length?d=[d[0],d[1],d[2],1]:4===d.length&&(d=[d[0],d[1],d[2],d[3]],!this.hasAlpha&&d[3]<1&&(this.hasAlpha=!0)),!isNaN(p[0][s])&&!isNaN(p[1][s])){var g;if(p[0][s]<0)(g=u.slice())[s]+=p[0][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+h(i,g,d,s);if(p[1][s]>0)(g=u.slice())[s]+=p[1][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+h(i,g,d,s)}}this.lineCount[s]=o-this.lineOffset[s]}this.buffer.update(i)}},l.dispose=function(){this.shader.dispose(),this.buffer.dispose(),this.vao.dispose()}},{\"./shaders/index\":248,\"gl-buffer\":241,\"gl-vao\":327}],248:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, offset;\\nattribute vec4 color;\\nuniform mat4 model, view, projection;\\nuniform float capSize;\\nvarying vec4 fragColor;\\nvarying vec3 fragPosition;\\n\\nvoid main() {\\n  vec4 worldPosition  = model * vec4(position, 1.0);\\n  worldPosition       = (worldPosition / worldPosition.w) + vec4(capSize * offset, 0.0);\\n  gl_Position         = projection * view * worldPosition;\\n  fragColor           = color;\\n  fragPosition        = position;\\n}\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float opacity;\\nvarying vec3 fragPosition;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], fragPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  gl_FragColor = opacity * fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"offset\",type:\"vec3\"}])}},{\"gl-shader\":301,glslify:409}],249:[function(t,e,r){\"use strict\";var n=t(\"gl-texture2d\");e.exports=function(t,e,r,n){i||(i=t.FRAMEBUFFER_UNSUPPORTED,a=t.FRAMEBUFFER_INCOMPLETE_ATTACHMENT,o=t.FRAMEBUFFER_INCOMPLETE_DIMENSIONS,s=t.FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT);var c=t.getExtension(\"WEBGL_draw_buffers\");!l&&c&&function(t,e){var r=t.getParameter(e.MAX_COLOR_ATTACHMENTS_WEBGL);l=new Array(r+1);for(var n=0;n<=r;++n){for(var i=new Array(r),a=0;a<n;++a)i[a]=t.COLOR_ATTACHMENT0+a;for(var a=n;a<r;++a)i[a]=t.NONE;l[n]=i}}(t,c);Array.isArray(e)&&(n=r,r=0|e[1],e=0|e[0]);if(\"number\"!=typeof e)throw new Error(\"gl-fbo: Missing shape parameter\");var u=t.getParameter(t.MAX_RENDERBUFFER_SIZE);if(e<0||e>u||r<0||r>u)throw new Error(\"gl-fbo: Parameters are too large for FBO\");var h=1;if(\"color\"in(n=n||{})){if((h=Math.max(0|n.color,0))<0)throw new Error(\"gl-fbo: Must specify a nonnegative number of colors\");if(h>1){if(!c)throw new Error(\"gl-fbo: Multiple draw buffer extension not supported\");if(h>t.getParameter(c.MAX_COLOR_ATTACHMENTS_WEBGL))throw new Error(\"gl-fbo: Context does not support \"+h+\" draw buffers\")}}var f=t.UNSIGNED_BYTE,p=t.getExtension(\"OES_texture_float\");if(n.float&&h>0){if(!p)throw new Error(\"gl-fbo: Context does not support floating point textures\");f=t.FLOAT}else n.preferFloat&&h>0&&p&&(f=t.FLOAT);var g=!0;\"depth\"in n&&(g=!!n.depth);var v=!1;\"stencil\"in n&&(v=!!n.stencil);return new d(t,e,r,f,h,g,v,c)};var i,a,o,s,l=null;function c(t){return[t.getParameter(t.FRAMEBUFFER_BINDING),t.getParameter(t.RENDERBUFFER_BINDING),t.getParameter(t.TEXTURE_BINDING_2D)]}function u(t,e){t.bindFramebuffer(t.FRAMEBUFFER,e[0]),t.bindRenderbuffer(t.RENDERBUFFER,e[1]),t.bindTexture(t.TEXTURE_2D,e[2])}function h(t){switch(t){case i:throw new Error(\"gl-fbo: Framebuffer unsupported\");case a:throw new Error(\"gl-fbo: Framebuffer incomplete attachment\");case o:throw new Error(\"gl-fbo: Framebuffer incomplete dimensions\");case s:throw new Error(\"gl-fbo: Framebuffer incomplete missing attachment\");default:throw new Error(\"gl-fbo: Framebuffer failed for unspecified reason\")}}function f(t,e,r,i,a,o){if(!i)return null;var s=n(t,e,r,a,i);return s.magFilter=t.NEAREST,s.minFilter=t.NEAREST,s.mipSamples=1,s.bind(),t.framebufferTexture2D(t.FRAMEBUFFER,o,t.TEXTURE_2D,s.handle,0),s}function p(t,e,r,n,i){var a=t.createRenderbuffer();return t.bindRenderbuffer(t.RENDERBUFFER,a),t.renderbufferStorage(t.RENDERBUFFER,n,e,r),t.framebufferRenderbuffer(t.FRAMEBUFFER,i,t.RENDERBUFFER,a),a}function d(t,e,r,n,i,a,o,s){this.gl=t,this._shape=[0|e,0|r],this._destroyed=!1,this._ext=s,this.color=new Array(i);for(var d=0;d<i;++d)this.color[d]=null;this._color_rb=null,this.depth=null,this._depth_rb=null,this._colorType=n,this._useDepth=a,this._useStencil=o;var g=this,v=[0|e,0|r];Object.defineProperties(v,{0:{get:function(){return g._shape[0]},set:function(t){return g.width=t}},1:{get:function(){return g._shape[1]},set:function(t){return g.height=t}}}),this._shapeVector=v,function(t){var e=c(t.gl),r=t.gl,n=t.handle=r.createFramebuffer(),i=t._shape[0],a=t._shape[1],o=t.color.length,s=t._ext,d=t._useStencil,g=t._useDepth,v=t._colorType;r.bindFramebuffer(r.FRAMEBUFFER,n);for(var m=0;m<o;++m)t.color[m]=f(r,i,a,v,r.RGBA,r.COLOR_ATTACHMENT0+m);0===o?(t._color_rb=p(r,i,a,r.RGBA4,r.COLOR_ATTACHMENT0),s&&s.drawBuffersWEBGL(l[0])):o>1&&s.drawBuffersWEBGL(l[o]);var y=r.getExtension(\"WEBGL_depth_texture\");y?d?t.depth=f(r,i,a,y.UNSIGNED_INT_24_8_WEBGL,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g&&(t.depth=f(r,i,a,r.UNSIGNED_SHORT,r.DEPTH_COMPONENT,r.DEPTH_ATTACHMENT)):g&&d?t._depth_rb=p(r,i,a,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g?t._depth_rb=p(r,i,a,r.DEPTH_COMPONENT16,r.DEPTH_ATTACHMENT):d&&(t._depth_rb=p(r,i,a,r.STENCIL_INDEX,r.STENCIL_ATTACHMENT));var x=r.checkFramebufferStatus(r.FRAMEBUFFER);if(x!==r.FRAMEBUFFER_COMPLETE){for(t._destroyed=!0,r.bindFramebuffer(r.FRAMEBUFFER,null),r.deleteFramebuffer(t.handle),t.handle=null,t.depth&&(t.depth.dispose(),t.depth=null),t._depth_rb&&(r.deleteRenderbuffer(t._depth_rb),t._depth_rb=null),m=0;m<t.color.length;++m)t.color[m].dispose(),t.color[m]=null;t._color_rb&&(r.deleteRenderbuffer(t._color_rb),t._color_rb=null),u(r,e),h(x)}u(r,e)}(this)}var g=d.prototype;function v(t,e,r){if(t._destroyed)throw new Error(\"gl-fbo: Can't resize destroyed FBO\");if(t._shape[0]!==e||t._shape[1]!==r){var n=t.gl,i=n.getParameter(n.MAX_RENDERBUFFER_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-fbo: Can't resize FBO, invalid dimensions\");t._shape[0]=e,t._shape[1]=r;for(var a=c(n),o=0;o<t.color.length;++o)t.color[o].shape=t._shape;t._color_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._color_rb),n.renderbufferStorage(n.RENDERBUFFER,n.RGBA4,t._shape[0],t._shape[1])),t.depth&&(t.depth.shape=t._shape),t._depth_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._depth_rb),t._useDepth&&t._useStencil?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_STENCIL,t._shape[0],t._shape[1]):t._useDepth?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_COMPONENT16,t._shape[0],t._shape[1]):t._useStencil&&n.renderbufferStorage(n.RENDERBUFFER,n.STENCIL_INDEX,t._shape[0],t._shape[1])),n.bindFramebuffer(n.FRAMEBUFFER,t.handle);var s=n.checkFramebufferStatus(n.FRAMEBUFFER);s!==n.FRAMEBUFFER_COMPLETE&&(t.dispose(),u(n,a),h(s)),u(n,a)}}Object.defineProperties(g,{shape:{get:function(){return this._destroyed?[0,0]:this._shapeVector},set:function(t){if(Array.isArray(t)||(t=[0|t,0|t]),2!==t.length)throw new Error(\"gl-fbo: Shape vector must be length 2\");var e=0|t[0],r=0|t[1];return v(this,e,r),[e,r]},enumerable:!1},width:{get:function(){return this._destroyed?0:this._shape[0]},set:function(t){return v(this,t|=0,this._shape[1]),t},enumerable:!1},height:{get:function(){return this._destroyed?0:this._shape[1]},set:function(t){return t|=0,v(this,this._shape[0],t),t},enumerable:!1}}),g.bind=function(){if(!this._destroyed){var t=this.gl;t.bindFramebuffer(t.FRAMEBUFFER,this.handle),t.viewport(0,0,this._shape[0],this._shape[1])}},g.dispose=function(){if(!this._destroyed){this._destroyed=!0;var t=this.gl;t.deleteFramebuffer(this.handle),this.handle=null,this.depth&&(this.depth.dispose(),this.depth=null),this._depth_rb&&(t.deleteRenderbuffer(this._depth_rb),this._depth_rb=null);for(var e=0;e<this.color.length;++e)this.color[e].dispose(),this.color[e]=null;this._color_rb&&(t.deleteRenderbuffer(this._color_rb),this._color_rb=null)}}},{\"gl-texture2d\":322}],250:[function(t,e,r){var n=t(\"sprintf-js\").sprintf,i=t(\"gl-constants/lookup\"),a=t(\"glsl-shader-name\"),o=t(\"add-line-numbers\");e.exports=function(t,e,r){\"use strict\";var s=a(e)||\"of unknown name (see npm glsl-shader-name)\",l=\"unknown type\";void 0!==r&&(l=r===i.FRAGMENT_SHADER?\"fragment\":\"vertex\");for(var c=n(\"Error compiling %s shader %s:\\n\",l,s),u=n(\"%s%s\",c,t),h=t.split(\"\\n\"),f={},p=0;p<h.length;p++){var d=h[p];if(\"\"!==d&&\"\\0\"!==d){var g=parseInt(d.split(\":\")[2]);if(isNaN(g))throw new Error(n(\"Could not parse error: %s\",d));f[g]=d}}for(var v=o(e).split(\"\\n\"),p=0;p<v.length;p++)if(f[p+3]||f[p+2]||f[p+1]){var m=v[p];if(c+=m+\"\\n\",f[p+1]){var y=f[p+1];y=y.substr(y.split(\":\",3).join(\":\").length+1).trim(),c+=n(\"^^^ %s\\n\\n\",y)}}return{long:c.trim(),short:u.trim()}}},{\"add-line-numbers\":61,\"gl-constants/lookup\":246,\"glsl-shader-name\":401,\"sprintf-js\":528}],251:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.gl,n=o(r,l.vertex,l.fragment),i=o(r,l.pickVertex,l.pickFragment),a=s(r),u=s(r),h=s(r),f=s(r),p=new c(t,n,i,a,u,h,f);return p.update(e),t.addObject(p),p};var n=t(\"binary-search-bounds\"),i=t(\"iota-array\"),a=t(\"typedarray-pool\"),o=t(\"gl-shader\"),s=t(\"gl-buffer\"),l=t(\"./lib/shaders\");function c(t,e,r,n,i,a,o){this.plot=t,this.shader=e,this.pickShader=r,this.positionBuffer=n,this.weightBuffer=i,this.colorBuffer=a,this.idBuffer=o,this.xData=[],this.yData=[],this.shape=[0,0],this.bounds=[1/0,1/0,-1/0,-1/0],this.pickOffset=0}var u,h=c.prototype,f=[0,0,1,0,0,1,1,0,1,1,0,1];h.draw=(u=[1,0,0,0,1,0,0,0,1],function(){var t=this.plot,e=this.shader,r=this.bounds,n=this.numVertices;if(!(n<=0)){var i=t.gl,a=t.dataBox,o=r[2]-r[0],s=r[3]-r[1],l=a[2]-a[0],c=a[3]-a[1];u[0]=2*o/l,u[4]=2*s/c,u[6]=2*(r[0]-a[0])/l-1,u[7]=2*(r[1]-a[1])/c-1,e.bind();var h=e.uniforms;h.viewTransform=u,h.shape=this.shape;var f=e.attributes;this.positionBuffer.bind(),f.position.pointer(),this.weightBuffer.bind(),f.weight.pointer(i.UNSIGNED_BYTE,!1),this.colorBuffer.bind(),f.color.pointer(i.UNSIGNED_BYTE,!0),i.drawArrays(i.TRIANGLES,0,n)}}),h.drawPick=function(){var t=[1,0,0,0,1,0,0,0,1],e=[0,0,0,0];return function(r){var n=this.plot,i=this.pickShader,a=this.bounds,o=this.numVertices;if(!(o<=0)){var s=n.gl,l=n.dataBox,c=a[2]-a[0],u=a[3]-a[1],h=l[2]-l[0],f=l[3]-l[1];t[0]=2*c/h,t[4]=2*u/f,t[6]=2*(a[0]-l[0])/h-1,t[7]=2*(a[1]-l[1])/f-1;for(var p=0;p<4;++p)e[p]=r>>8*p&255;this.pickOffset=r,i.bind();var d=i.uniforms;d.viewTransform=t,d.pickOffset=e,d.shape=this.shape;var g=i.attributes;return this.positionBuffer.bind(),g.position.pointer(),this.weightBuffer.bind(),g.weight.pointer(s.UNSIGNED_BYTE,!1),this.idBuffer.bind(),g.pickId.pointer(s.UNSIGNED_BYTE,!1),s.drawArrays(s.TRIANGLES,0,o),r+this.shape[0]*this.shape[1]}}}(),h.pick=function(t,e,r){var n=this.pickOffset,i=this.shape[0]*this.shape[1];if(r<n||r>=n+i)return null;var a=r-n,o=this.xData,s=this.yData;return{object:this,pointId:a,dataCoord:[o[a%this.shape[0]],s[a/this.shape[0]|0]]}},h.update=function(t){var e=(t=t||{}).shape||[0,0],r=t.x||i(e[0]),o=t.y||i(e[1]),s=t.z||new Float32Array(e[0]*e[1]);this.xData=r,this.yData=o;var l=t.colorLevels||[0],c=t.colorValues||[0,0,0,1],u=l.length,h=this.bounds,p=h[0]=r[0],d=h[1]=o[0],g=1/((h[2]=r[r.length-1])-p),v=1/((h[3]=o[o.length-1])-d),m=e[0],y=e[1];this.shape=[m,y];var x=(m-1)*(y-1)*(f.length>>>1);this.numVertices=x;for(var b=a.mallocUint8(4*x),_=a.mallocFloat32(2*x),w=a.mallocUint8(2*x),k=a.mallocUint32(x),T=0,A=0;A<y-1;++A)for(var M=v*(o[A]-d),S=v*(o[A+1]-d),E=0;E<m-1;++E)for(var C=g*(r[E]-p),L=g*(r[E+1]-p),P=0;P<f.length;P+=2){var O,z,I,D,R=f[P],F=f[P+1],B=s[(A+F)*m+(E+R)],N=n.le(l,B);if(N<0)O=c[0],z=c[1],I=c[2],D=c[3];else if(N===u-1)O=c[4*u-4],z=c[4*u-3],I=c[4*u-2],D=c[4*u-1];else{var j=(B-l[N])/(l[N+1]-l[N]),U=1-j,V=4*N,q=4*(N+1);O=U*c[V]+j*c[q],z=U*c[V+1]+j*c[q+1],I=U*c[V+2]+j*c[q+2],D=U*c[V+3]+j*c[q+3]}b[4*T]=255*O,b[4*T+1]=255*z,b[4*T+2]=255*I,b[4*T+3]=255*D,_[2*T]=.5*C+.5*L,_[2*T+1]=.5*M+.5*S,w[2*T]=R,w[2*T+1]=F,k[T]=A*m+E,T+=1}this.positionBuffer.update(_),this.weightBuffer.update(w),this.colorBuffer.update(b),this.idBuffer.update(k),a.free(_),a.free(b),a.free(w),a.free(k)},h.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.positionBuffer.dispose(),this.weightBuffer.dispose(),this.colorBuffer.dispose(),this.idBuffer.dispose(),this.plot.removeObject(this)}},{\"./lib/shaders\":252,\"binary-search-bounds\":253,\"gl-buffer\":241,\"gl-shader\":301,\"iota-array\":416,\"typedarray-pool\":545}],252:[function(t,e,r){\"use strict\";var n=t(\"glslify\");e.exports={fragment:n([\"precision lowp float;\\n#define GLSLIFY 1\\nvarying vec4 fragColor;\\nvoid main() {\\n  gl_FragColor = vec4(fragColor.rgb * fragColor.a, fragColor.a);\\n}\\n\"]),vertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 color;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  fragColor = color;\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"]),pickFragment:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nuniform vec2 shape;\\nuniform vec4 pickOffset;\\n\\nvoid main() {\\n  vec2 d = step(.5, vWeight);\\n  vec4 id = fragId + pickOffset;\\n  id.x += d.x + d.y*shape.x;\\n\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  gl_FragColor = id/255.;\\n}\\n\"]),pickVertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nvoid main() {\\n  vWeight = weight;\\n\\n  fragId = pickId;\\n\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"])}},{glslify:409}],253:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],254:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, nextPosition;\\nattribute float arcLength, lineWidth;\\nattribute vec4 color;\\n\\nuniform vec2 screenShape;\\nuniform float pixelRatio;\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 fragColor;\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  vec4 startPoint = project(position);\\n  vec4 endPoint   = project(nextPosition);\\n\\n  vec2 A = startPoint.xy / startPoint.w;\\n  vec2 B =   endPoint.xy /   endPoint.w;\\n\\n  float clipAngle = atan(\\n    (B.y - A.y) * screenShape.y,\\n    (B.x - A.x) * screenShape.x\\n  );\\n\\n  vec2 offset = 0.5 * pixelRatio * lineWidth * vec2(\\n    sin(clipAngle),\\n    -cos(clipAngle)\\n  ) / screenShape;\\n\\n  gl_Position = vec4(startPoint.xy + startPoint.w * offset, startPoint.zw);\\n\\n  worldPosition = position;\\n  pixelArcLength = arcLength;\\n  fragColor = color;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3      clipBounds[2];\\nuniform sampler2D dashTexture;\\nuniform float     dashScale;\\nuniform float     opacity;\\n\\nvarying vec3    worldPosition;\\nvarying float   pixelArcLength;\\nvarying vec4    fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], worldPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  float dashWeight = texture2D(dashTexture, vec2(dashScale * pixelArcLength, 0)).r;\\n  if(dashWeight < 0.5) {\\n    discard;\\n  }\\n  gl_FragColor = fragColor * opacity;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\n#define FLOAT_MAX  1.70141184e38\\n#define FLOAT_MIN  1.17549435e-38\\n\\nlowp vec4 encode_float_1540259130(highp float v) {\\n  highp float av = abs(v);\\n\\n  //Handle special cases\\n  if(av < FLOAT_MIN) {\\n    return vec4(0.0, 0.0, 0.0, 0.0);\\n  } else if(v > FLOAT_MAX) {\\n    return vec4(127.0, 128.0, 0.0, 0.0) / 255.0;\\n  } else if(v < -FLOAT_MAX) {\\n    return vec4(255.0, 128.0, 0.0, 0.0) / 255.0;\\n  }\\n\\n  highp vec4 c = vec4(0,0,0,0);\\n\\n  //Compute exponent and mantissa\\n  highp float e = floor(log2(av));\\n  highp float m = av * pow(2.0, -e) - 1.0;\\n  \\n  //Unpack mantissa\\n  c[1] = floor(128.0 * m);\\n  m -= c[1] / 128.0;\\n  c[2] = floor(32768.0 * m);\\n  m -= c[2] / 32768.0;\\n  c[3] = floor(8388608.0 * m);\\n  \\n  //Unpack exponent\\n  highp float ebias = e + 127.0;\\n  c[0] = floor(ebias / 2.0);\\n  ebias -= c[0] * 2.0;\\n  c[1] += floor(ebias) * 128.0; \\n\\n  //Unpack sign bit\\n  c[0] += 128.0 * step(0.0, -v);\\n\\n  //Scale back to range\\n  return c / 255.0;\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform float pickId;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], worldPosition)) discard;\\n\\n  gl_FragColor = vec4(pickId/255.0, encode_float_1540259130(pixelArcLength).xyz);\\n}\"]),l=[{name:\"position\",type:\"vec3\"},{name:\"nextPosition\",type:\"vec3\"},{name:\"arcLength\",type:\"float\"},{name:\"lineWidth\",type:\"float\"},{name:\"color\",type:\"vec4\"}];r.createShader=function(t){return i(t,a,o,null,l)},r.createPickShader=function(t){return i(t,a,s,null,l)}},{\"gl-shader\":301,glslify:409}],255:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl||t.scene&&t.scene.gl,r=u(e);r.attributes.position.location=0,r.attributes.nextPosition.location=1,r.attributes.arcLength.location=2,r.attributes.lineWidth.location=3,r.attributes.color.location=4;var o=h(e);o.attributes.position.location=0,o.attributes.nextPosition.location=1,o.attributes.arcLength.location=2,o.attributes.lineWidth.location=3,o.attributes.color.location=4;for(var s=n(e),c=i(e,[{buffer:s,size:3,offset:0,stride:48},{buffer:s,size:3,offset:12,stride:48},{buffer:s,size:1,offset:24,stride:48},{buffer:s,size:1,offset:28,stride:48},{buffer:s,size:4,offset:32,stride:48}]),f=l(new Array(1024),[256,1,4]),p=0;p<1024;++p)f.data[p]=255;var d=a(e,f);d.wrap=e.REPEAT;var g=new v(e,r,o,s,c,d);return g.update(t),g};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"gl-texture2d\"),o=t(\"glsl-read-float\"),s=t(\"binary-search-bounds\"),l=t(\"ndarray\"),c=t(\"./lib/shaders\"),u=c.createShader,h=c.createPickShader,f=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function p(t,e){for(var r=0,n=0;n<3;++n){var i=t[n]-e[n];r+=i*i}return Math.sqrt(r)}function d(t){for(var e=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],r=0;r<3;++r)e[0][r]=Math.max(t[0][r],e[0][r]),e[1][r]=Math.min(t[1][r],e[1][r]);return e}function g(t,e,r,n){this.arcLength=t,this.position=e,this.index=r,this.dataCoordinate=n}function v(t,e,r,n,i,a){this.gl=t,this.shader=e,this.pickShader=r,this.buffer=n,this.vao=i,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.points=[],this.arcLength=[],this.vertexCount=0,this.bounds=[[0,0,0],[0,0,0]],this.pickId=0,this.lineWidth=1,this.texture=a,this.dashScale=1,this.opacity=1,this.hasAlpha=!1,this.dirty=!0,this.pixelRatio=1}var m=v.prototype;m.isTransparent=function(){return this.hasAlpha},m.isOpaque=function(){return!this.hasAlpha},m.pickSlots=1,m.setPickBase=function(t){this.pickId=t},m.drawTransparent=m.draw=function(t){if(this.vertexCount){var e=this.gl,r=this.shader,n=this.vao;r.bind(),r.uniforms={model:t.model||f,view:t.view||f,projection:t.projection||f,clipBounds:d(this.clipBounds),dashTexture:this.texture.bind(),dashScale:this.dashScale/this.arcLength[this.arcLength.length-1],opacity:this.opacity,screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},m.drawPick=function(t){if(this.vertexCount){var e=this.gl,r=this.pickShader,n=this.vao;r.bind(),r.uniforms={model:t.model||f,view:t.view||f,projection:t.projection||f,pickId:this.pickId,clipBounds:d(this.clipBounds),screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},m.update=function(t){var e,r;this.dirty=!0;var n=!!t.connectGaps;\"dashScale\"in t&&(this.dashScale=t.dashScale),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var i=[],a=[],o=[],c=0,u=0,h=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],f=t.position||t.positions;if(f){var d=t.color||t.colors||[0,0,0,1],g=t.lineWidth||1,v=!1;t:for(e=1;e<f.length;++e){var m,y,x,b=f[e-1],_=f[e];for(a.push(c),o.push(b.slice()),r=0;r<3;++r){if(isNaN(b[r])||isNaN(_[r])||!isFinite(b[r])||!isFinite(_[r])){if(!n&&i.length>0){for(var w=0;w<24;++w)i.push(i[i.length-12]);u+=2,v=!0}continue t}h[0][r]=Math.min(h[0][r],b[r],_[r]),h[1][r]=Math.max(h[1][r],b[r],_[r])}Array.isArray(d[0])?(m=d.length>e-1?d[e-1]:d.length>0?d[d.length-1]:[0,0,0,1],y=d.length>e?d[e]:d.length>0?d[d.length-1]:[0,0,0,1]):m=y=d,3===m.length&&(m=[m[0],m[1],m[2],1]),3===y.length&&(y=[y[0],y[1],y[2],1]),!this.hasAlpha&&m[3]<1&&(this.hasAlpha=!0),x=Array.isArray(g)?g.length>e-1?g[e-1]:g.length>0?g[g.length-1]:[0,0,0,1]:g;var k=c;if(c+=p(b,_),v){for(r=0;r<2;++r)i.push(b[0],b[1],b[2],_[0],_[1],_[2],k,x,m[0],m[1],m[2],m[3]);u+=2,v=!1}i.push(b[0],b[1],b[2],_[0],_[1],_[2],k,x,m[0],m[1],m[2],m[3],b[0],b[1],b[2],_[0],_[1],_[2],k,-x,m[0],m[1],m[2],m[3],_[0],_[1],_[2],b[0],b[1],b[2],c,-x,y[0],y[1],y[2],y[3],_[0],_[1],_[2],b[0],b[1],b[2],c,x,y[0],y[1],y[2],y[3]),u+=4}}if(this.buffer.update(i),a.push(c),o.push(f[f.length-1].slice()),this.bounds=h,this.vertexCount=u,this.points=o,this.arcLength=a,\"dashes\"in t){var T=t.dashes.slice();for(T.unshift(0),e=1;e<T.length;++e)T[e]=T[e-1]+T[e];var A=l(new Array(1024),[256,1,4]);for(e=0;e<256;++e){for(r=0;r<4;++r)A.set(e,0,r,0);1&s.le(T,T[T.length-1]*e/255)?A.set(e,0,0,0):A.set(e,0,0,255)}this.texture.setPixels(A)}},m.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()},m.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=o(t.value[0],t.value[1],t.value[2],0),r=s.le(this.arcLength,e);if(r<0)return null;if(r===this.arcLength.length-1)return new g(this.arcLength[this.arcLength.length-1],this.points[this.points.length-1].slice(),r);for(var n=this.points[r],i=this.points[Math.min(r+1,this.points.length-1)],a=(e-this.arcLength[r])/(this.arcLength[r+1]-this.arcLength[r]),l=1-a,c=[0,0,0],u=0;u<3;++u)c[u]=l*n[u]+a*i[u];var h=Math.min(a<.5?r:r+1,this.points.length-1);return new g(e,c,h,this.points[h])}},{\"./lib/shaders\":254,\"binary-search-bounds\":256,\"gl-buffer\":241,\"gl-texture2d\":322,\"gl-vao\":327,\"glsl-read-float\":400,ndarray:450}],256:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],257:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r*a-i*n;return o?(o=1/o,t[0]=a*o,t[1]=-n*o,t[2]=-i*o,t[3]=r*o,t):null}},{}],258:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=u*o-s*c,f=-u*a+s*l,p=c*a-o*l,d=r*h+n*f+i*p;return d?(d=1/d,t[0]=h*d,t[1]=(-u*n+i*c)*d,t[2]=(s*n-i*o)*d,t[3]=f*d,t[4]=(u*r-i*l)*d,t[5]=(-s*r+i*a)*d,t[6]=p*d,t[7]=(-c*r+n*l)*d,t[8]=(o*r-n*a)*d,t):null}},{}],259:[function(t,e,r){e.exports=function(t){var e=new Float32Array(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e}},{}],260:[function(t,e,r){e.exports=function(){var t=new Float32Array(16);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],261:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3],a=t[4],o=t[5],s=t[6],l=t[7],c=t[8],u=t[9],h=t[10],f=t[11],p=t[12],d=t[13],g=t[14],v=t[15];return(e*o-r*a)*(h*v-f*g)-(e*s-n*a)*(u*v-f*d)+(e*l-i*a)*(u*g-h*d)+(r*s-n*o)*(c*v-f*p)-(r*l-i*o)*(c*g-h*p)+(n*l-i*s)*(c*d-u*p)}},{}],262:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r+r,s=n+n,l=i+i,c=r*o,u=n*o,h=n*s,f=i*o,p=i*s,d=i*l,g=a*o,v=a*s,m=a*l;return t[0]=1-h-d,t[1]=u+m,t[2]=f-v,t[3]=0,t[4]=u-m,t[5]=1-c-d,t[6]=p+g,t[7]=0,t[8]=f+v,t[9]=p-g,t[10]=1-c-h,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],263:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=n+n,l=i+i,c=a+a,u=n*s,h=n*l,f=n*c,p=i*l,d=i*c,g=a*c,v=o*s,m=o*l,y=o*c;return t[0]=1-(p+g),t[1]=h+y,t[2]=f-m,t[3]=0,t[4]=h-y,t[5]=1-(u+g),t[6]=d+v,t[7]=0,t[8]=f+m,t[9]=d-v,t[10]=1-(u+p),t[11]=0,t[12]=r[0],t[13]=r[1],t[14]=r[2],t[15]=1,t}},{}],264:[function(t,e,r){e.exports=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],265:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],g=e[13],v=e[14],m=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,k=i*c-a*l,T=u*g-h*d,A=u*v-f*d,M=u*m-p*d,S=h*v-f*g,E=h*m-p*g,C=f*m-p*v,L=y*C-x*E+b*S+_*M-w*A+k*T;if(!L)return null;return L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(i*E-n*C-a*S)*L,t[2]=(g*k-v*w+m*_)*L,t[3]=(f*w-h*k-p*_)*L,t[4]=(l*M-o*C-c*A)*L,t[5]=(r*C-i*M+a*A)*L,t[6]=(v*b-d*k-m*x)*L,t[7]=(u*k-f*b+p*x)*L,t[8]=(o*E-s*M+c*T)*L,t[9]=(n*M-r*E-a*T)*L,t[10]=(d*w-g*b+m*y)*L,t[11]=(h*b-u*w-p*y)*L,t[12]=(s*A-o*S-l*T)*L,t[13]=(r*S-n*A+i*T)*L,t[14]=(g*x-d*_-v*y)*L,t[15]=(u*_-h*x+f*y)*L,t}},{}],266:[function(t,e,r){var n=t(\"./identity\");e.exports=function(t,e,r,i){var a,o,s,l,c,u,h,f,p,d,g=e[0],v=e[1],m=e[2],y=i[0],x=i[1],b=i[2],_=r[0],w=r[1],k=r[2];if(Math.abs(g-_)<1e-6&&Math.abs(v-w)<1e-6&&Math.abs(m-k)<1e-6)return n(t);h=g-_,f=v-w,p=m-k,d=1/Math.sqrt(h*h+f*f+p*p),a=x*(p*=d)-b*(f*=d),o=b*(h*=d)-y*p,s=y*f-x*h,(d=Math.sqrt(a*a+o*o+s*s))?(a*=d=1/d,o*=d,s*=d):(a=0,o=0,s=0);l=f*s-p*o,c=p*a-h*s,u=h*o-f*a,(d=Math.sqrt(l*l+c*c+u*u))?(l*=d=1/d,c*=d,u*=d):(l=0,c=0,u=0);return t[0]=a,t[1]=l,t[2]=h,t[3]=0,t[4]=o,t[5]=c,t[6]=f,t[7]=0,t[8]=s,t[9]=u,t[10]=p,t[11]=0,t[12]=-(a*g+o*v+s*m),t[13]=-(l*g+c*v+u*m),t[14]=-(h*g+f*v+p*m),t[15]=1,t}},{\"./identity\":264}],267:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],g=e[12],v=e[13],m=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*h+w*g,t[1]=x*i+b*l+_*f+w*v,t[2]=x*a+b*c+_*p+w*m,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*h+w*g,t[5]=x*i+b*l+_*f+w*v,t[6]=x*a+b*c+_*p+w*m,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*h+w*g,t[9]=x*i+b*l+_*f+w*v,t[10]=x*a+b*c+_*p+w*m,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*h+w*g,t[13]=x*i+b*l+_*f+w*v,t[14]=x*a+b*c+_*p+w*m,t[15]=x*o+b*u+_*d+w*y,t}},{}],268:[function(t,e,r){e.exports=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t}},{}],269:[function(t,e,r){e.exports=function(t,e,r,n,i){var a=1/Math.tan(e/2),o=1/(n-i);return t[0]=a/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=a,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=(i+n)*o,t[11]=-1,t[12]=0,t[13]=0,t[14]=2*i*n*o,t[15]=0,t}},{}],270:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_,w,k,T,A,M,S,E=n[0],C=n[1],L=n[2],P=Math.sqrt(E*E+C*C+L*L);if(Math.abs(P)<1e-6)return null;E*=P=1/P,C*=P,L*=P,i=Math.sin(r),a=Math.cos(r),o=1-a,s=e[0],l=e[1],c=e[2],u=e[3],h=e[4],f=e[5],p=e[6],d=e[7],g=e[8],v=e[9],m=e[10],y=e[11],x=E*E*o+a,b=C*E*o+L*i,_=L*E*o-C*i,w=E*C*o-L*i,k=C*C*o+a,T=L*C*o+E*i,A=E*L*o+C*i,M=C*L*o-E*i,S=L*L*o+a,t[0]=s*x+h*b+g*_,t[1]=l*x+f*b+v*_,t[2]=c*x+p*b+m*_,t[3]=u*x+d*b+y*_,t[4]=s*w+h*k+g*T,t[5]=l*w+f*k+v*T,t[6]=c*w+p*k+m*T,t[7]=u*w+d*k+y*T,t[8]=s*A+h*M+g*S,t[9]=l*A+f*M+v*S,t[10]=c*A+p*M+m*S,t[11]=u*A+d*M+y*S,e!==t&&(t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t}},{}],271:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+h*n,t[7]=l*i+f*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=h*i-s*n,t[11]=f*i-l*n,t}},{}],272:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[8],u=e[9],h=e[10],f=e[11];e!==t&&(t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i-c*n,t[1]=o*i-u*n,t[2]=s*i-h*n,t[3]=l*i-f*n,t[8]=a*n+c*i,t[9]=o*n+u*i,t[10]=s*n+h*i,t[11]=l*n+f*i,t}},{}],273:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+h*n,t[3]=l*i+f*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=h*i-s*n,t[7]=f*i-l*n,t}},{}],274:[function(t,e,r){e.exports=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},{}],275:[function(t,e,r){e.exports=function(t,e,r){var n,i,a,o,s,l,c,u,h,f,p,d,g=r[0],v=r[1],m=r[2];e===t?(t[12]=e[0]*g+e[4]*v+e[8]*m+e[12],t[13]=e[1]*g+e[5]*v+e[9]*m+e[13],t[14]=e[2]*g+e[6]*v+e[10]*m+e[14],t[15]=e[3]*g+e[7]*v+e[11]*m+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*g+s*v+h*m+e[12],t[13]=i*g+l*v+f*m+e[13],t[14]=a*g+c*v+p*m+e[14],t[15]=o*g+u*v+d*m+e[15]);return t}},{}],276:[function(t,e,r){e.exports=function(t,e){if(t===e){var r=e[1],n=e[2],i=e[3],a=e[6],o=e[7],s=e[11];t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=r,t[6]=e[9],t[7]=e[13],t[8]=n,t[9]=a,t[11]=e[14],t[12]=i,t[13]=o,t[14]=s}else t[0]=e[0],t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=e[1],t[5]=e[5],t[6]=e[9],t[7]=e[13],t[8]=e[2],t[9]=e[6],t[10]=e[10],t[11]=e[14],t[12]=e[3],t[13]=e[7],t[14]=e[11],t[15]=e[15];return t}},{}],277:[function(t,e,r){\"use strict\";e.exports=function(t,e){switch(e.length){case 0:break;case 1:t[0]=1/e[0];break;case 4:n(t,e);break;case 9:i(t,e);break;case 16:a(t,e);break;default:throw new Error(\"currently supports matrices up to 4x4\")}return t};var n=t(\"gl-mat2/invert\"),i=t(\"gl-mat3/invert\"),a=t(\"gl-mat4/invert\")},{\"gl-mat2/invert\":257,\"gl-mat3/invert\":258,\"gl-mat4/invert\":265}],278:[function(t,e,r){\"use strict\";var n=t(\"barycentric\"),i=t(\"polytope-closest-point/lib/closest_point_2d.js\");function a(t,e){for(var r=[0,0,0,0],n=0;n<4;++n)for(var i=0;i<4;++i)r[i]+=t[4*n+i]*e[n];return r}function o(t,e,r,n,i){for(var o=a(n,a(r,a(e,[t[0],t[1],t[2],1]))),s=0;s<3;++s)o[s]/=o[3];return[.5*i[0]*(1+o[0]),.5*i[1]*(1-o[1])]}e.exports=function(t,e,r,a,s,l){if(1===t.length)return[0,t[0].slice()];for(var c=new Array(t.length),u=0;u<t.length;++u)c[u]=o(t[u],r,a,s,l);for(var h=0,f=1/0,u=0;u<c.length;++u){for(var p=0,d=0;d<2;++d)p+=Math.pow(c[u][d]-e[d],2);p<f&&(f=p,h=u)}for(var g=function(t,e){if(2===t.length){for(var r=0,a=0,o=0;o<2;++o)r+=Math.pow(e[o]-t[0][o],2),a+=Math.pow(e[o]-t[1][o],2);return r=Math.sqrt(r),a=Math.sqrt(a),r+a<1e-6?[1,0]:[a/(r+a),r/(a+r)]}if(3===t.length){var s=[0,0];return i(t[0],t[1],t[2],e,s),n(t,s)}return[]}(c,e),v=0,u=0;u<3;++u){if(g[u]<-.001||g[u]>1.0001)return null;v+=g[u]}if(Math.abs(v-1)>.001)return null;return[h,function(t,e){for(var r=[0,0,0],n=0;n<t.length;++n)for(var i=t[n],a=e[n],o=0;o<3;++o)r[o]+=a*i[o];return r}(t,g),g]}},{barycentric:73,\"polytope-closest-point/lib/closest_point_2d.js\":481}],279:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, normal;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  gl_Position      = project(position);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * vec4(position , 1.0);\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal  = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  f_color          = color;\\n  f_data           = position;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\n//#pragma glslify: beckmann = require(glsl-specular-beckmann) // used in gl-surface3d\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (f_color.a == 0.0 ||\\n    outOfRange(clipBounds[0], clipBounds[1], f_data)\\n  ) discard;\\n\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  //float specular = max(0.0, beckmann(L, V, N, roughness)); // used in gl-surface3d\\n\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = vec4(f_color.rgb, 1.0) * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * f_color.a;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_color = color;\\n  f_data  = position;\\n  f_uv    = uv;\\n}\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_data)) discard;\\n\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\nattribute float pointSize;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0 ,0.0 ,0.0);\\n  } else {\\n    gl_Position = projection * view * model * vec4(position, 1.0);\\n  }\\n  gl_PointSize = pointSize;\\n  f_color = color;\\n  f_uv = uv;\\n}\"]),c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  vec2 pointR = gl_PointCoord.xy - vec2(0.5, 0.5);\\n  if(dot(pointR, pointR) > 0.25) {\\n    discard;\\n  }\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_id        = id;\\n  f_position  = position;\\n}\"]),h=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]),f=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3  position;\\nattribute float pointSize;\\nattribute vec4  id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0, 0.0, 0.0);\\n  } else {\\n    gl_Position  = projection * view * model * vec4(position, 1.0);\\n    gl_PointSize = pointSize;\\n  }\\n  f_id         = id;\\n  f_position   = position;\\n}\"]),p=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n}\"]),d=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec3 contourColor;\\n\\nvoid main() {\\n  gl_FragColor = vec4(contourColor, 1.0);\\n}\\n\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.wireShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.pointShader={vertex:l,fragment:c,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"pointSize\",type:\"float\"}]},r.pickShader={vertex:u,fragment:h,attributes:[{name:\"position\",type:\"vec3\"},{name:\"id\",type:\"vec4\"}]},r.pointPickShader={vertex:f,fragment:h,attributes:[{name:\"position\",type:\"vec3\"},{name:\"pointSize\",type:\"float\"},{name:\"id\",type:\"vec4\"}]},r.contourShader={vertex:p,fragment:d,attributes:[{name:\"position\",type:\"vec3\"}]}},{glslify:409}],280:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./lib/shaders\"),g=t(\"./lib/closest-point\"),v=d.meshShader,m=d.wireShader,y=d.pointShader,x=d.pickShader,b=d.pointPickShader,_=d.contourShader,w=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function k(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_,k,T,A,M,S){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.lineShader=n,this.pointShader=i,this.pickShader=a,this.pointPickShader=o,this.contourShader=s,this.trianglePositions=l,this.triangleColors=u,this.triangleNormals=f,this.triangleUVs=h,this.triangleIds=c,this.triangleVAO=p,this.triangleCount=0,this.lineWidth=1,this.edgePositions=d,this.edgeColors=v,this.edgeUVs=m,this.edgeIds=g,this.edgeVAO=y,this.edgeCount=0,this.pointPositions=x,this.pointColors=_,this.pointUVs=k,this.pointSizes=T,this.pointIds=b,this.pointVAO=A,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=M,this.contourVAO=S,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.hasAlpha=!1,this.opacityscale=!1,this._model=w,this._view=w,this._projection=w,this._resolution=[1,1]}var T=k.prototype;function A(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}function M(t){var e=n(t,y.vertex,y.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.pointSize.location=4,e}function S(t){var e=n(t,x.vertex,x.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e}function E(t){var e=n(t,b.vertex,b.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.pointSize.location=4,e}function C(t){var e=n(t,_.vertex,_.fragment);return e.attributes.position.location=0,e}T.isOpaque=function(){return!this.hasAlpha},T.isTransparent=function(){return this.hasAlpha},T.pickSlots=1,T.setPickBase=function(t){this.pickId=t},T.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=i[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},T.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=t.opacity,this.opacity<1&&(this.hasAlpha=!0)),\"opacityscale\"in t&&(this.opacityscale=t.opacityscale,this.hasAlpha=!0),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t,e){for(var r=h({colormap:t,nshades:256,format:\"rgba\"}),n=new Uint8Array(1024),i=0;i<256;++i){for(var a=r[i],o=0;o<3;++o)n[4*i+o]=a[o];n[4*i+3]=e?255*A(i/255,e):255*a[3]}return u(n,[256,256,4],[4,0,1])}(t.colormap,this.opacityscale)),this.texture.generateMipmap());var r=t.cells,n=t.positions;if(n&&r){var i=[],a=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[];this.cells=r,this.positions=n;var w=t.vertexNormals,k=t.cellNormals,T=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,M=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!k&&(k=s.faceNormals(r,n,M)),k||w||(w=s.vertexNormals(r,n,T));var S=t.vertexColors,E=t.cellColors,C=t.meshColor||[1,1,1,1],L=t.vertexUVs,P=t.vertexIntensity,O=t.cellUVs,z=t.cellIntensity,I=1/0,D=-1/0;if(!L&&!O)if(P)if(t.vertexIntensityBounds)I=+t.vertexIntensityBounds[0],D=+t.vertexIntensityBounds[1];else for(var R=0;R<P.length;++R){var F=P[R];I=Math.min(I,F),D=Math.max(D,F)}else if(z)for(R=0;R<z.length;++R){F=z[R];I=Math.min(I,F),D=Math.max(D,F)}else for(R=0;R<n.length;++R){F=n[R][2];I=Math.min(I,F),D=Math.max(D,F)}this.intensity=P||(z?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,z):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var B=t.pointSizes,N=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(R=0;R<n.length;++R)for(var j=n[R],U=0;U<3;++U)!isNaN(j[U])&&isFinite(j[U])&&(this.bounds[0][U]=Math.min(this.bounds[0][U],j[U]),this.bounds[1][U]=Math.max(this.bounds[1][U],j[U]));var V=0,q=0,H=0;t:for(R=0;R<r.length;++R){var G=r[R];switch(G.length){case 1:for(j=n[W=G[0]],U=0;U<3;++U)if(isNaN(j[U])||!isFinite(j[U]))continue t;m.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?y.push(X[0],X[1],X[2],this.opacity):(y.push(X[0],X[1],X[2],X[3]*this.opacity),!this.hasAlpha&&X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],x.push(Z[0],Z[1]),B?b.push(B[W]):b.push(N),_.push(R),H+=1;break;case 2:for(U=0;U<2;++U){j=n[W=G[U]];for(var Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t}for(U=0;U<2;++U){j=n[W=G[U]];p.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?d.push(X[0],X[1],X[2],this.opacity):(d.push(X[0],X[1],X[2],X[3]*this.opacity),!this.hasAlpha&&X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],g.push(Z[0],Z[1]),v.push(R)}q+=1;break;case 3:for(U=0;U<3;++U)for(j=n[W=G[U]],Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t;for(U=0;U<3;++U){var W,X,Z,J;j=n[W=G[2-U]];i.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?a.push(X[0],X[1],X[2],this.opacity):(a.push(X[0],X[1],X[2],X[3]*this.opacity),!this.hasAlpha&&X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],c.push(Z[0],Z[1]),J=w?w[W]:k[R],l.push(J[0],J[1],J[2]),f.push(R)}V+=1}}this.pointCount=H,this.edgeCount=q,this.triangleCount=V,this.pointPositions.update(m),this.pointColors.update(y),this.pointUVs.update(x),this.pointSizes.update(b),this.pointIds.update(new Uint32Array(_)),this.edgePositions.update(p),this.edgeColors.update(d),this.edgeUVs.update(g),this.edgeIds.update(new Uint32Array(v)),this.trianglePositions.update(i),this.triangleColors.update(a),this.triangleUVs.update(c),this.triangleNormals.update(l),this.triangleIds.update(new Uint32Array(f))}},T.drawTransparent=T.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:w.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h,f=u[15];for(o=0;o<3;++o)f+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];s.lightPosition[o]=p/f}this.triangleCount>0&&((h=this.triShader).bind(),h.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind());this.edgeCount>0&&this.lineWidth>0&&((h=this.lineShader).bind(),h.uniforms=s,this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind());this.pointCount>0&&((h=this.pointShader).bind(),h.uniforms=s,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind());this.contourEnable&&this.contourCount>0&&this.contourLineWidth>0&&((h=this.contourShader).bind(),h.uniforms=s,this.contourVAO.bind(),e.drawArrays(e.LINES,0,this.contourCount),this.contourVAO.unbind())},T.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s,l={model:r,view:n,projection:i,clipBounds:a,pickId:this.pickId/255};((s=this.pickShader).bind(),s.uniforms=l,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind()),this.pointCount>0)&&((s=this.pointPickShader).bind(),s.uniforms=l,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind())},T.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;for(var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions,i=new Array(r.length),a=0;a<r.length;++a)i[a]=n[r[a]];var o=g(i,[t.coord[0],this._resolution[1]-t.coord[1]],this._model,this._view,this._projection,this._resolution);if(!o)return null;var s=o[2],l=0;for(a=0;a<r.length;++a)l+=s[a]*this.intensity[r[a]];return{position:o[1],index:r[o[0]],cell:r,cellId:e,intensity:l,dataCoordinate:this.positions[r[o[0]]]}},T.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.lineShader.dispose(),this.pointShader.dispose(),this.pickShader.dispose(),this.pointPickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose(),this.contourShader.dispose()},e.exports=function(t,e){if(1===arguments.length&&(t=(e=t).gl),!(t.getExtension(\"OES_standard_derivatives\")||t.getExtension(\"MOZ_OES_standard_derivatives\")||t.getExtension(\"WEBKIT_OES_standard_derivatives\")))throw new Error(\"derivatives not supported\");var r=function(t){var e=n(t,v.vertex,v.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.normal.location=4,e}(t),s=function(t){var e=n(t,m.vertex,m.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e}(t),l=M(t),c=S(t),h=E(t),f=C(t),p=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));p.generateMipmap(),p.minFilter=t.LINEAR_MIPMAP_LINEAR,p.magFilter=t.LINEAR;var d=i(t),g=i(t),y=i(t),x=i(t),b=i(t),_=a(t,[{buffer:d,type:t.FLOAT,size:3},{buffer:b,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:g,type:t.FLOAT,size:4},{buffer:y,type:t.FLOAT,size:2},{buffer:x,type:t.FLOAT,size:3}]),w=i(t),T=i(t),A=i(t),L=i(t),P=a(t,[{buffer:w,type:t.FLOAT,size:3},{buffer:L,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:T,type:t.FLOAT,size:4},{buffer:A,type:t.FLOAT,size:2}]),O=i(t),z=i(t),I=i(t),D=i(t),R=i(t),F=a(t,[{buffer:O,type:t.FLOAT,size:3},{buffer:R,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:z,type:t.FLOAT,size:4},{buffer:I,type:t.FLOAT,size:2},{buffer:D,type:t.FLOAT,size:1}]),B=i(t),N=new k(t,p,r,s,l,c,h,f,d,b,g,y,x,_,w,L,T,A,P,O,R,z,I,D,F,B,a(t,[{buffer:B,type:t.FLOAT,size:3}]));return N.update(e),N}},{\"./lib/closest-point\":278,\"./lib/shaders\":279,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-shader\":301,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,normals:453,\"simplicial-complex-contour\":518,\"typedarray-pool\":545}],281:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[0,0,0,1,1,0,1,1]),s=i(e,a.boxVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawBox=(s=[0,0],l=[0,0],function(t,e,r,n,i){var a=this.plot,o=this.shader,c=a.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,o.uniforms.lo=s,o.uniforms.hi=l,o.uniforms.color=i,c.drawArrays(c.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":284,\"gl-buffer\":241,\"gl-shader\":301}],282:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,o.gridVert,o.gridFrag),l=i(e,o.tickVert,o.gridFrag);return new s(t,r,a,l)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"binary-search-bounds\"),o=t(\"./shaders\");function s(t,e,r,n){this.plot=t,this.vbo=e,this.shader=r,this.tickShader=n,this.ticks=[[],[]]}function l(t,e){return t-e}var c,u,h,f,p,d=s.prototype;d.draw=(c=[0,0],u=[0,0],h=[0,0],function(){for(var t=this.plot,e=this.vbo,r=this.shader,n=this.ticks,i=t.gl,a=t._tickBounds,o=t.dataBox,s=t.viewBox,l=t.gridLineWidth,f=t.gridLineColor,p=t.gridLineEnable,d=t.pixelRatio,g=0;g<2;++g){var v=a[g],m=a[g+2]-v,y=.5*(o[g+2]+o[g]),x=o[g+2]-o[g];u[g]=2*m/x,c[g]=2*(v-y)/x}r.bind(),e.bind(),r.attributes.dataCoord.pointer(),r.uniforms.dataShift=c,r.uniforms.dataScale=u;var b=0;for(g=0;g<2;++g){h[0]=h[1]=0,h[g]=1,r.uniforms.dataAxis=h,r.uniforms.lineWidth=l[g]/(s[g+2]-s[g])*d,r.uniforms.color=f[g];var _=6*n[g].length;p[g]&&_&&i.drawArrays(i.TRIANGLES,b,_),b+=_}}),d.drawTickMarks=function(){var t=[0,0],e=[0,0],r=[1,0],n=[0,1],i=[0,0],o=[0,0];return function(){for(var s=this.plot,c=this.vbo,u=this.tickShader,h=this.ticks,f=s.gl,p=s._tickBounds,d=s.dataBox,g=s.viewBox,v=s.pixelRatio,m=s.screenBox,y=m[2]-m[0],x=m[3]-m[1],b=g[2]-g[0],_=g[3]-g[1],w=0;w<2;++w){var k=p[w],T=p[w+2]-k,A=.5*(d[w+2]+d[w]),M=d[w+2]-d[w];e[w]=2*T/M,t[w]=2*(k-A)/M}e[0]*=b/y,t[0]*=b/y,e[1]*=_/x,t[1]*=_/x,u.bind(),c.bind(),u.attributes.dataCoord.pointer();var S=u.uniforms;S.dataShift=t,S.dataScale=e;var E=s.tickMarkLength,C=s.tickMarkWidth,L=s.tickMarkColor,P=6*h[0].length,O=Math.min(a.ge(h[0],(d[0]-p[0])/(p[2]-p[0]),l),h[0].length),z=Math.min(a.gt(h[0],(d[2]-p[0])/(p[2]-p[0]),l),h[0].length),I=0+6*O,D=6*Math.max(0,z-O),R=Math.min(a.ge(h[1],(d[1]-p[1])/(p[3]-p[1]),l),h[1].length),F=Math.min(a.gt(h[1],(d[3]-p[1])/(p[3]-p[1]),l),h[1].length),B=P+6*R,N=6*Math.max(0,F-R);i[0]=2*(g[0]-E[1])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=E[1]*v/y,o[1]=C[1]*v/x,N&&(S.color=L[1],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,f.drawArrays(f.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[1]-E[0])/x-1,o[0]=C[0]*v/y,o[1]=E[0]*v/x,D&&(S.color=L[0],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,f.drawArrays(f.TRIANGLES,I,D)),i[0]=2*(g[2]+E[3])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=E[3]*v/y,o[1]=C[3]*v/x,N&&(S.color=L[3],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,f.drawArrays(f.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[3]+E[2])/x-1,o[0]=C[2]*v/y,o[1]=E[2]*v/x,D&&(S.color=L[2],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,f.drawArrays(f.TRIANGLES,I,D))}}(),d.update=(f=[1,1,-1,-1,1,-1],p=[1,-1,1,1,-1,-1],function(t){for(var e=t.ticks,r=t.bounds,n=new Float32Array(18*(e[0].length+e[1].length)),i=(this.plot.zeroLineEnable,0),a=[[],[]],o=0;o<2;++o)for(var s=a[o],l=e[o],c=r[o],u=r[o+2],h=0;h<l.length;++h){var d=(l[h].x-c)/(u-c);s.push(d);for(var g=0;g<6;++g)n[i++]=d,n[i++]=f[g],n[i++]=p[g]}this.ticks=a,this.vbo.update(n)}),d.dispose=function(){this.vbo.dispose(),this.shader.dispose(),this.tickShader.dispose()}},{\"./shaders\":284,\"binary-search-bounds\":286,\"gl-buffer\":241,\"gl-shader\":301}],283:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[-1,-1,-1,1,1,-1,1,1]),s=i(e,a.lineVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawLine=(s=[0,0],l=[0,0],function(t,e,r,n,i,a){var o=this.plot,c=this.shader,u=o.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,c.uniforms.start=s,c.uniforms.end=l,c.uniforms.width=i*o.pixelRatio,c.uniforms.color=a,u.drawArrays(u.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":284,\"gl-buffer\":241,\"gl-shader\":301}],284:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision lowp float;\\n#define GLSLIFY 1\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = vec4(color.xyz * color.w, color.w);\\n}\\n\"]);e.exports={lineVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 start, end;\\nuniform float width;\\n\\nvec2 perp(vec2 v) {\\n  return vec2(v.y, -v.x);\\n}\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  vec2 delta = normalize(perp(start - end));\\n  vec2 offset = mix(start, end, 0.5 * (coord.y+1.0));\\n  gl_Position = vec4(screen(offset + 0.5 * width * delta * coord.x), 0, 1);\\n}\\n\"]),lineFrag:i,textVert:n([\"#define GLSLIFY 1\\nattribute vec3 textCoordinate;\\n\\nuniform vec2 dataScale, dataShift, dataAxis, screenOffset, textScale;\\nuniform float angle;\\n\\nvoid main() {\\n  float dataOffset  = textCoordinate.z;\\n  vec2 glyphOffset  = textCoordinate.xy;\\n  mat2 glyphMatrix = mat2(cos(angle), sin(angle), -sin(angle), cos(angle));\\n  vec2 screenCoordinate = dataAxis * (dataScale * dataOffset + dataShift) +\\n    glyphMatrix * glyphOffset * textScale + screenOffset;\\n  gl_Position = vec4(screenCoordinate, 0, 1);\\n}\\n\"]),textFrag:i,gridVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale;\\nuniform float lineWidth;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  pos += 10.0 * dataCoord.y * vec2(dataAxis.y, -dataAxis.x) + dataCoord.z * lineWidth;\\n  gl_Position = vec4(pos, 0, 1);\\n}\\n\"]),gridFrag:i,boxVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 lo, hi;\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  gl_Position = vec4(screen(mix(lo, hi, coord)), 0, 1);\\n}\\n\"]),tickVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale, screenOffset, tickScale;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  gl_Position = vec4(pos + tickScale*dataCoord.yz + screenOffset, 0, 1);\\n}\\n\"])}},{glslify:409}],285:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,s.textVert,s.textFrag);return new l(t,r,a)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"text-cache\"),o=t(\"binary-search-bounds\"),s=t(\"./shaders\");function l(t,e,r){this.plot=t,this.vbo=e,this.shader=r,this.tickOffset=[[],[]],this.tickX=[[],[]],this.labelOffset=[0,0],this.labelCount=[0,0]}var c,u,h,f,p,d,g=l.prototype;g.drawTicks=(c=[0,0],u=[0,0],h=[0,0],function(t){var e=this.plot,r=this.shader,n=this.tickX[t],i=this.tickOffset[t],a=e.gl,s=e.viewBox,l=e.dataBox,f=e.screenBox,p=e.pixelRatio,d=e.tickEnable,g=e.tickPad,v=e.tickColor,m=e.tickAngle,y=e.labelEnable,x=e.labelPad,b=e.labelColor,_=e.labelAngle,w=this.labelOffset[t],k=this.labelCount[t],T=o.lt(n,l[t]),A=o.le(n,l[t+2]);c[0]=c[1]=0,c[t]=1,u[t]=(s[2+t]+s[t])/(f[2+t]-f[t])-1;var M=2/f[2+(1^t)]-f[1^t];u[1^t]=M*s[1^t]-1,d[t]&&(u[1^t]-=M*p*g[t],T<A&&i[A]>i[T]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=v[t],r.uniforms.angle=m[t],a.drawArrays(a.TRIANGLES,i[T],i[A]-i[T]))),y[t]&&k&&(u[1^t]-=M*p*x[t],r.uniforms.dataAxis=h,r.uniforms.screenOffset=u,r.uniforms.color=b[t],r.uniforms.angle=_[t],a.drawArrays(a.TRIANGLES,w,k)),u[1^t]=M*s[2+(1^t)]-1,d[t+2]&&(u[1^t]+=M*p*g[t+2],T<A&&i[A]>i[T]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=v[t+2],r.uniforms.angle=m[t+2],a.drawArrays(a.TRIANGLES,i[T],i[A]-i[T]))),y[t+2]&&k&&(u[1^t]+=M*p*x[t+2],r.uniforms.dataAxis=h,r.uniforms.screenOffset=u,r.uniforms.color=b[t+2],r.uniforms.angle=_[t+2],a.drawArrays(a.TRIANGLES,w,k))}),g.drawTitle=function(){var t=[0,0],e=[0,0];return function(){var r=this.plot,n=this.shader,i=r.gl,a=r.screenBox,o=r.titleCenter,s=r.titleAngle,l=r.titleColor,c=r.pixelRatio;if(this.titleCount){for(var u=0;u<2;++u)e[u]=2*(o[u]*c-a[u])/(a[2+u]-a[u])-1;n.bind(),n.uniforms.dataAxis=t,n.uniforms.screenOffset=e,n.uniforms.angle=s,n.uniforms.color=l,i.drawArrays(i.TRIANGLES,this.titleOffset,this.titleCount)}}}(),g.bind=(f=[0,0],p=[0,0],d=[0,0],function(){var t=this.plot,e=this.shader,r=t._tickBounds,n=t.dataBox,i=t.screenBox,a=t.viewBox;e.bind();for(var o=0;o<2;++o){var s=r[o],l=r[o+2]-s,c=.5*(n[o+2]+n[o]),u=n[o+2]-n[o],h=a[o],g=a[o+2]-h,v=i[o],m=i[o+2]-v;p[o]=2*l/u*g/m,f[o]=2*(s-c)/u*g/m}d[1]=2*t.pixelRatio/(i[3]-i[1]),d[0]=d[1]*(i[3]-i[1])/(i[2]-i[0]),e.uniforms.dataScale=p,e.uniforms.dataShift=f,e.uniforms.textScale=d,this.vbo.bind(),e.attributes.textCoordinate.pointer()}),g.update=function(t){var e,r,n,i,o,s=[],l=t.ticks,c=t.bounds;for(o=0;o<2;++o){var u=[Math.floor(s.length/3)],h=[-1/0],f=l[o];for(e=0;e<f.length;++e){var p=f[e],d=p.x,g=p.text,v=p.font||\"sans-serif\";i=p.fontSize||12;for(var m=1/(c[o+2]-c[o]),y=c[o],x=g.split(\"\\n\"),b=0;b<x.length;b++)for(n=a(v,x[b]).data,r=0;r<n.length;r+=2)s.push(n[r]*i,-n[r+1]*i-b*i*1.2,(d-y)*m);u.push(Math.floor(s.length/3)),h.push(d)}this.tickOffset[o]=u,this.tickX[o]=h}for(o=0;o<2;++o){for(this.labelOffset[o]=Math.floor(s.length/3),n=a(t.labelFont[o],t.labels[o],{textAlign:\"center\"}).data,i=t.labelSize[o],e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.labelCount[o]=Math.floor(s.length/3)-this.labelOffset[o]}for(this.titleOffset=Math.floor(s.length/3),n=a(t.titleFont,t.title).data,i=t.titleSize,e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.titleCount=Math.floor(s.length/3)-this.titleOffset,this.vbo.update(s)},g.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":284,\"binary-search-bounds\":286,\"gl-buffer\":241,\"gl-shader\":301,\"text-cache\":536}],286:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],287:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[e.drawingBufferWidth,e.drawingBufferHeight]),c=new l(e,r);return c.grid=i(c),c.text=a(c),c.line=o(c),c.box=s(c),c.update(t),c};var n=t(\"gl-select-static\"),i=t(\"./lib/grid\"),a=t(\"./lib/text\"),o=t(\"./lib/line\"),s=t(\"./lib/box\");function l(t,e){this.gl=t,this.pickBuffer=e,this.screenBox=[0,0,t.drawingBufferWidth,t.drawingBufferHeight],this.viewBox=[0,0,0,0],this.dataBox=[-10,-10,10,10],this.gridLineEnable=[!0,!0],this.gridLineWidth=[1,1],this.gridLineColor=[[0,0,0,1],[0,0,0,1]],this.pixelRatio=1,this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickEnable=[!0,!0,!0,!0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[15,15,15,15],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelEnable=[!0,!0,!0,!0],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.titleCenter=[0,0],this.titleEnable=!0,this.titleAngle=0,this.titleColor=[0,0,0,1],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[4,4],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderLineEnable=[!0,!0,!0,!0],this.borderLineWidth=[2,2,2,2],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.grid=null,this.text=null,this.line=null,this.box=null,this.objects=[],this.overlays=[],this._tickBounds=[1/0,1/0,-1/0,-1/0],this.static=!1,this.dirty=!1,this.pickDirty=!1,this.pickDelay=120,this.pickRadius=10,this._pickTimeout=null,this._drawPick=this.drawPick.bind(this),this._depthCounter=0}var c=l.prototype;function u(t){for(var e=t.slice(),r=0;r<e.length;++r)e[r]=e[r].slice();return e}function h(t,e){return t.x-e.x}c.setDirty=function(){this.dirty=this.pickDirty=!0},c.setOverlayDirty=function(){this.dirty=!0},c.nextDepthValue=function(){return this._depthCounter++/65536},c.draw=function(){var t=this.gl,e=this.screenBox,r=this.viewBox,n=this.dataBox,i=this.pixelRatio,a=this.grid,o=this.line,s=this.text,l=this.objects;if(this._depthCounter=0,this.pickDirty&&(this._pickTimeout&&clearTimeout(this._pickTimeout),this.pickDirty=!1,this._pickTimeout=setTimeout(this._drawPick,this.pickDelay)),this.dirty){if(this.dirty=!1,t.bindFramebuffer(t.FRAMEBUFFER,null),t.enable(t.SCISSOR_TEST),t.disable(t.DEPTH_TEST),t.depthFunc(t.LESS),t.depthMask(!1),t.enable(t.BLEND),t.blendEquation(t.FUNC_ADD,t.FUNC_ADD),t.blendFunc(t.ONE,t.ONE_MINUS_SRC_ALPHA),this.borderColor){t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]);var c=this.borderColor;t.clearColor(c[0]*c[3],c[1]*c[3],c[2]*c[3],c[3]),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT)}t.scissor(r[0],r[1],r[2]-r[0],r[3]-r[1]),t.viewport(r[0],r[1],r[2]-r[0],r[3]-r[1]);var u=this.backgroundColor;t.clearColor(u[0]*u[3],u[1]*u[3],u[2]*u[3],u[3]),t.clear(t.COLOR_BUFFER_BIT),a.draw();var h=this.zeroLineEnable,f=this.zeroLineColor,p=this.zeroLineWidth;if(h[0]||h[1]){o.bind();for(var d=0;d<2;++d)if(h[d]&&n[d]<=0&&n[d+2]>=0){var g=e[d]-n[d]*(e[d+2]-e[d])/(n[d+2]-n[d]);0===d?o.drawLine(g,e[1],g,e[3],p[d],f[d]):o.drawLine(e[0],g,e[2],g,p[d],f[d])}}for(d=0;d<l.length;++d)l[d].draw();t.viewport(e[0],e[1],e[2]-e[0],e[3]-e[1]),t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]),this.grid.drawTickMarks(),o.bind();var v=this.borderLineEnable,m=this.borderLineWidth,y=this.borderLineColor;for(v[1]&&o.drawLine(r[0],r[1]-.5*m[1]*i,r[0],r[3]+.5*m[3]*i,m[1],y[1]),v[0]&&o.drawLine(r[0]-.5*m[0]*i,r[1],r[2]+.5*m[2]*i,r[1],m[0],y[0]),v[3]&&o.drawLine(r[2],r[1]-.5*m[1]*i,r[2],r[3]+.5*m[3]*i,m[3],y[3]),v[2]&&o.drawLine(r[0]-.5*m[0]*i,r[3],r[2]+.5*m[2]*i,r[3],m[2],y[2]),s.bind(),d=0;d<2;++d)s.drawTicks(d);this.titleEnable&&s.drawTitle();var x=this.overlays;for(d=0;d<x.length;++d)x[d].draw();t.disable(t.SCISSOR_TEST),t.disable(t.BLEND),t.depthMask(!0)}},c.drawPick=function(){if(!this.static){var t=this.pickBuffer;this.gl;this._pickTimeout=null,t.begin();for(var e=1,r=this.objects,n=0;n<r.length;++n)e=r[n].drawPick(e);t.end()}},c.pick=function(t,e){if(!this.static){var r=this.pixelRatio,n=this.pickPixelRatio,i=this.viewBox,a=0|Math.round((t-i[0]/r)*n),o=0|Math.round((e-i[1]/r)*n),s=this.pickBuffer.query(a,o,this.pickRadius);if(!s)return null;for(var l=s.id+(s.value[0]<<8)+(s.value[1]<<16)+(s.value[2]<<24),c=this.objects,u=0;u<c.length;++u){var h=c[u].pick(a,o,l);if(h)return h}return null}},c.setScreenBox=function(t){var e=this.screenBox,r=this.pixelRatio;e[0]=0|Math.round(t[0]*r),e[1]=0|Math.round(t[1]*r),e[2]=0|Math.round(t[2]*r),e[3]=0|Math.round(t[3]*r),this.setDirty()},c.setDataBox=function(t){var e=this.dataBox;(e[0]!==t[0]||e[1]!==t[1]||e[2]!==t[2]||e[3]!==t[3])&&(e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],this.setDirty())},c.setViewBox=function(t){var e=this.pixelRatio,r=this.viewBox;r[0]=0|Math.round(t[0]*e),r[1]=0|Math.round(t[1]*e),r[2]=0|Math.round(t[2]*e),r[3]=0|Math.round(t[3]*e);var n=this.pickPixelRatio;this.pickBuffer.shape=[0|Math.round((t[2]-t[0])*n),0|Math.round((t[3]-t[1])*n)],this.setDirty()},c.update=function(t){t=t||{};var e=this.gl;this.pixelRatio=t.pixelRatio||1;var r=this.pixelRatio;this.pickPixelRatio=Math.max(r,1),this.setScreenBox(t.screenBox||[0,0,e.drawingBufferWidth/r,e.drawingBufferHeight/r]);this.screenBox;this.setViewBox(t.viewBox||[.125*(this.screenBox[2]-this.screenBox[0])/r,.125*(this.screenBox[3]-this.screenBox[1])/r,.875*(this.screenBox[2]-this.screenBox[0])/r,.875*(this.screenBox[3]-this.screenBox[1])/r]);var n=this.viewBox,i=(n[2]-n[0])/(n[3]-n[1]);this.setDataBox(t.dataBox||[-10,-10/i,10,10/i]),this.borderColor=!1!==t.borderColor&&(t.borderColor||[0,0,0,0]).slice(),this.backgroundColor=(t.backgroundColor||[0,0,0,0]).slice(),this.gridLineEnable=(t.gridLineEnable||[!0,!0]).slice(),this.gridLineWidth=(t.gridLineWidth||[1,1]).slice(),this.gridLineColor=u(t.gridLineColor||[[.5,.5,.5,1],[.5,.5,.5,1]]),this.zeroLineEnable=(t.zeroLineEnable||[!0,!0]).slice(),this.zeroLineWidth=(t.zeroLineWidth||[4,4]).slice(),this.zeroLineColor=u(t.zeroLineColor||[[0,0,0,1],[0,0,0,1]]),this.tickMarkLength=(t.tickMarkLength||[0,0,0,0]).slice(),this.tickMarkWidth=(t.tickMarkWidth||[0,0,0,0]).slice(),this.tickMarkColor=u(t.tickMarkColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.titleCenter=(t.titleCenter||[.5*(n[0]+n[2])/r,(n[3]+120)/r]).slice(),this.titleEnable=!(\"titleEnable\"in t&&!t.titleEnable),this.titleAngle=t.titleAngle||0,this.titleColor=(t.titleColor||[0,0,0,1]).slice(),this.labelPad=(t.labelPad||[15,15,15,15]).slice(),this.labelAngle=(t.labelAngle||[0,Math.PI/2,0,3*Math.PI/2]).slice(),this.labelEnable=(t.labelEnable||[!0,!0,!0,!0]).slice(),this.labelColor=u(t.labelColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.tickPad=(t.tickPad||[15,15,15,15]).slice(),this.tickAngle=(t.tickAngle||[0,0,0,0]).slice(),this.tickEnable=(t.tickEnable||[!0,!0,!0,!0]).slice(),this.tickColor=u(t.tickColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.borderLineEnable=(t.borderLineEnable||[!0,!0,!0,!0]).slice(),this.borderLineWidth=(t.borderLineWidth||[2,2,2,2]).slice(),this.borderLineColor=u(t.borderLineColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]);var a=t.ticks||[[],[]],o=this._tickBounds;o[0]=o[1]=1/0,o[2]=o[3]=-1/0;for(var s=0;s<2;++s){var l=a[s].slice(0);0!==l.length&&(l.sort(h),o[s]=Math.min(o[s],l[0].x),o[s+2]=Math.max(o[s+2],l[l.length-1].x))}this.grid.update({bounds:o,ticks:a}),this.text.update({bounds:o,ticks:a,labels:t.labels||[\"x\",\"y\"],labelSize:t.labelSize||[12,12],labelFont:t.labelFont||[\"sans-serif\",\"sans-serif\"],title:t.title||\"\",titleSize:t.titleSize||18,titleFont:t.titleFont||\"sans-serif\"}),this.static=!!t.static,this.setDirty()},c.dispose=function(){this.box.dispose(),this.grid.dispose(),this.text.dispose(),this.line.dispose();for(var t=this.objects.length-1;t>=0;--t)this.objects[t].dispose();this.objects.length=0;for(t=this.overlays.length-1;t>=0;--t)this.overlays[t].dispose();this.overlays.length=0,this.gl=null},c.addObject=function(t){this.objects.indexOf(t)<0&&(this.objects.push(t),this.setDirty())},c.removeObject=function(t){for(var e=this.objects,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setDirty();break}},c.addOverlay=function(t){this.overlays.indexOf(t)<0&&(this.overlays.push(t),this.setOverlayDirty())},c.removeOverlay=function(t){for(var e=this.overlays,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setOverlayDirty();break}}},{\"./lib/box\":281,\"./lib/grid\":282,\"./lib/line\":283,\"./lib/text\":285,\"gl-select-static\":300}],288:[function(t,e,r){\"use strict\";e.exports=function(t,e){t=t||document.body,e=e||{};var r=[.01,1/0];\"distanceLimits\"in e&&(r[0]=e.distanceLimits[0],r[1]=e.distanceLimits[1]);\"zoomMin\"in e&&(r[0]=e.zoomMin);\"zoomMax\"in e&&(r[1]=e.zoomMax);var c=i({center:e.center||[0,0,0],up:e.up||[0,1,0],eye:e.eye||[0,0,10],mode:e.mode||\"orbit\",distanceLimits:r}),u=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],h=0,f=t.clientWidth,p=t.clientHeight,d={keyBindingMode:\"rotate\",enableWheel:!0,view:c,element:t,delay:e.delay||16,rotateSpeed:e.rotateSpeed||1,zoomSpeed:e.zoomSpeed||1,translateSpeed:e.translateSpeed||1,flipX:!!e.flipX,flipY:!!e.flipY,modes:c.modes,_ortho:e._ortho||e.projection&&\"orthographic\"===e.projection.type||!1,tick:function(){var e=n(),r=this.delay,i=e-2*r;c.idle(e-r),c.recalcMatrix(i),c.flush(e-(100+2*r));for(var a=!0,o=c.computedMatrix,s=0;s<16;++s)a=a&&u[s]===o[s],u[s]=o[s];var l=t.clientWidth===f&&t.clientHeight===p;return f=t.clientWidth,p=t.clientHeight,a?!l:(h=Math.exp(c.computedRadius[0]),!0)},lookAt:function(t,e,r){c.lookAt(c.lastT(),t,e,r)},rotate:function(t,e,r){c.rotate(c.lastT(),t,e,r)},pan:function(t,e,r){c.pan(c.lastT(),t,e,r)},translate:function(t,e,r){c.translate(c.lastT(),t,e,r)}};return Object.defineProperties(d,{matrix:{get:function(){return c.computedMatrix},set:function(t){return c.setMatrix(c.lastT(),t),c.computedMatrix},enumerable:!0},mode:{get:function(){return c.getMode()},set:function(t){var e=c.computedUp.slice(),r=c.computedEye.slice(),i=c.computedCenter.slice();if(c.setMode(t),\"turntable\"===t){var a=n();c._active.lookAt(a,r,i,e),c._active.lookAt(a+500,r,i,[0,0,1]),c._active.flush(a)}return c.getMode()},enumerable:!0},center:{get:function(){return c.computedCenter},set:function(t){return c.lookAt(c.lastT(),null,t),c.computedCenter},enumerable:!0},eye:{get:function(){return c.computedEye},set:function(t){return c.lookAt(c.lastT(),t),c.computedEye},enumerable:!0},up:{get:function(){return c.computedUp},set:function(t){return c.lookAt(c.lastT(),null,null,t),c.computedUp},enumerable:!0},distance:{get:function(){return h},set:function(t){return c.setDistance(c.lastT(),t),t},enumerable:!0},distanceLimits:{get:function(){return c.getDistanceLimits(r)},set:function(t){return c.setDistanceLimits(t),t},enumerable:!0}}),t.addEventListener(\"contextmenu\",function(t){return t.preventDefault(),!1}),d._lastX=-1,d._lastY=-1,d._lastMods={shift:!1,control:!1,alt:!1,meta:!1},d.enableMouseListeners=function(){function e(e,r,i,a){var o=d.keyBindingMode;if(!1!==o){var s=\"rotate\"===o,l=\"pan\"===o,u=\"zoom\"===o,f=!!a.control,p=!!a.alt,g=!!a.shift,v=!!(1&e),m=!!(2&e),y=!!(4&e),x=1/t.clientHeight,b=x*(r-d._lastX),_=x*(i-d._lastY),w=d.flipX?1:-1,k=d.flipY?1:-1,T=Math.PI*d.rotateSpeed,A=n();if(-1!==d._lastX&&-1!==d._lastY&&((s&&v&&!f&&!p&&!g||v&&!f&&!p&&g)&&c.rotate(A,w*T*b,-k*T*_,0),(l&&v&&!f&&!p&&!g||m||v&&f&&!p&&!g)&&c.pan(A,-d.translateSpeed*b*h,d.translateSpeed*_*h,0),u&&v&&!f&&!p&&!g||y||v&&!f&&p&&!g)){var M=-d.zoomSpeed*_/window.innerHeight*(A-c.lastT())*100;c.pan(A,0,0,h*(Math.exp(M)-1))}return d._lastX=r,d._lastY=i,d._lastMods=a,!0}}d.mouseListener=a(t,e),t.addEventListener(\"touchstart\",function(r){var n=s(r.changedTouches[0],t);e(0,n[0],n[1],d._lastMods),e(1,n[0],n[1],d._lastMods),r.preventDefault()},!!l&&{passive:!1}),t.addEventListener(\"touchmove\",function(r){var n=s(r.changedTouches[0],t);e(1,n[0],n[1],d._lastMods),r.preventDefault()},!!l&&{passive:!1}),t.addEventListener(\"touchend\",function(t){e(0,d._lastX,d._lastY,d._lastMods),t.preventDefault()},!!l&&{passive:!1}),d.wheelListener=o(t,function(t,e){if(!1!==d.keyBindingMode&&d.enableWheel){var r=d.flipX?1:-1,i=d.flipY?1:-1,a=n();if(Math.abs(t)>Math.abs(e))c.rotate(a,0,0,-t*r*Math.PI*d.rotateSpeed/window.innerWidth);else if(!d._ortho){var o=-d.zoomSpeed*i*e/window.innerHeight*(a-c.lastT())/20;c.pan(a,0,0,h*(Math.exp(o)-1))}}},!0)},d.enableMouseListeners(),d};var n=t(\"right-now\"),i=t(\"3d-view\"),a=t(\"mouse-change\"),o=t(\"mouse-wheel\"),s=t(\"mouse-event-offset\"),l=t(\"has-passive-events\")},{\"3d-view\":52,\"has-passive-events\":411,\"mouse-change\":435,\"mouse-event-offset\":436,\"mouse-wheel\":438,\"right-now\":504}],289:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\nattribute vec2 position;\\nvarying vec2 uv;\\nvoid main() {\\n  uv = position;\\n  gl_Position = vec4(position, 0, 1);\\n}\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D accumBuffer;\\nvarying vec2 uv;\\n\\nvoid main() {\\n  vec4 accum = texture2D(accumBuffer, 0.5 * (uv + 1.0));\\n  gl_FragColor = min(vec4(1,1,1,1), accum);\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec2\"}])}},{\"gl-shader\":301,glslify:409}],290:[function(t,e,r){\"use strict\";var n=t(\"./camera.js\"),i=t(\"gl-axes3d\"),a=t(\"gl-axes3d/properties\"),o=t(\"gl-spikes3d\"),s=t(\"gl-select-static\"),l=t(\"gl-fbo\"),c=t(\"a-big-triangle\"),u=t(\"mouse-change\"),h=t(\"mouse-wheel\"),f=t(\"gl-mat4/perspective\"),p=t(\"gl-mat4/ortho\"),d=t(\"./lib/shader\"),g=t(\"is-mobile\")({tablet:!0});function v(){this.mouse=[-1,-1],this.screen=null,this.distance=1/0,this.index=null,this.dataCoordinate=null,this.dataPosition=null,this.object=null,this.data=null}function m(t){var e=Math.round(Math.log(Math.abs(t))/Math.log(10));if(e<0){var r=Math.round(Math.pow(10,-e));return Math.ceil(t*r)/r}if(e>0){r=Math.round(Math.pow(10,e));return Math.ceil(t/r)*r}return Math.ceil(t)}function y(t){return\"boolean\"!=typeof t||t}e.exports={createScene:function(t){(t=t||{}).camera=t.camera||{};var e=t.canvas;if(!e)if(e=document.createElement(\"canvas\"),t.container){var r=t.container;r.appendChild(e)}else document.body.appendChild(e);var x=t.gl;x||(x=function(t,e){var r=null;try{(r=t.getContext(\"webgl\",e))||(r=t.getContext(\"experimental-webgl\",e))}catch(t){return null}return r}(e,t.glOptions||{premultipliedAlpha:!0,antialias:!0,preserveDrawingBuffer:g}));if(!x)throw new Error(\"webgl not supported\");var b=t.bounds||[[-10,-10,-10],[10,10,10]],_=new v,w=l(x,[x.drawingBufferWidth,x.drawingBufferHeight],{preferFloat:!g}),k=d(x),T=t.cameraObject&&!0===t.cameraObject._ortho||t.camera.projection&&\"orthographic\"===t.camera.projection.type||!1,A={eye:t.camera.eye||[2,0,0],center:t.camera.center||[0,0,0],up:t.camera.up||[0,1,0],zoomMin:t.camera.zoomMax||.1,zoomMax:t.camera.zoomMin||100,mode:t.camera.mode||\"turntable\",_ortho:T},M=t.axes||{},S=i(x,M);S.enable=!M.disable;var E=t.spikes||{},C=o(x,E),L=[],P=[],O=[],z=[],I=!0,D=!0,R=new Array(16),F=new Array(16),B={view:null,projection:R,model:F,_ortho:!1},D=!0,N=[x.drawingBufferWidth,x.drawingBufferHeight],j=t.cameraObject||n(e,A),U={gl:x,contextLost:!1,pixelRatio:t.pixelRatio||1,canvas:e,selection:_,camera:j,axes:S,axesPixels:null,spikes:C,bounds:b,objects:L,shape:N,aspect:t.aspectRatio||[1,1,1],pickRadius:t.pickRadius||10,zNear:t.zNear||.01,zFar:t.zFar||1e3,fovy:t.fovy||Math.PI/4,clearColor:t.clearColor||[0,0,0,0],autoResize:y(t.autoResize),autoBounds:y(t.autoBounds),autoScale:!!t.autoScale,autoCenter:y(t.autoCenter),clipToBounds:y(t.clipToBounds),snapToData:!!t.snapToData,onselect:t.onselect||null,onrender:t.onrender||null,onclick:t.onclick||null,cameraParams:B,oncontextloss:null,mouseListener:null,_stopped:!1},V=[x.drawingBufferWidth/U.pixelRatio|0,x.drawingBufferHeight/U.pixelRatio|0];function q(){if(!U._stopped&&U.autoResize){var t=e.parentNode,r=1,n=1;t&&t!==document.body?(r=t.clientWidth,n=t.clientHeight):(r=window.innerWidth,n=window.innerHeight);var i=0|Math.ceil(r*U.pixelRatio),a=0|Math.ceil(n*U.pixelRatio);if(i!==e.width||a!==e.height){e.width=i,e.height=a;var o=e.style;o.position=o.position||\"absolute\",o.left=\"0px\",o.top=\"0px\",o.width=r+\"px\",o.height=n+\"px\",I=!0}}}U.autoResize&&q();function H(){for(var t=L.length,e=z.length,r=0;r<e;++r)O[r]=0;t:for(var r=0;r<t;++r){var n=L[r],i=n.pickSlots;if(i){for(var a=0;a<e;++a)if(O[a]+i<255){P[r]=a,n.setPickBase(O[a]+1),O[a]+=i;continue t}var o=s(x,N);P[r]=e,z.push(o),O.push(i),n.setPickBase(1),e+=1}else P[r]=-1}for(;e>0&&0===O[e-1];)O.pop(),z.pop().dispose()}function G(){if(U.contextLost)return!0;x.isContextLost()&&(U.contextLost=!0,U.mouseListener.enabled=!1,U.selection.object=null,U.oncontextloss&&U.oncontextloss())}window.addEventListener(\"resize\",q),U.update=function(t){U._stopped||(t=t||{},I=!0,D=!0)},U.add=function(t){U._stopped||(t.axes=S,L.push(t),P.push(-1),I=!0,D=!0,H())},U.remove=function(t){if(!U._stopped){var e=L.indexOf(t);e<0||(L.splice(e,1),P.pop(),I=!0,D=!0,H())}},U.dispose=function(){if(!U._stopped&&(U._stopped=!0,window.removeEventListener(\"resize\",q),e.removeEventListener(\"webglcontextlost\",G),U.mouseListener.enabled=!1,!U.contextLost)){S.dispose(),C.dispose();for(var t=0;t<L.length;++t)L[t].dispose();w.dispose();for(var t=0;t<z.length;++t)z[t].dispose();k.dispose(),x=null,S=null,C=null,L=[]}},U.wheelListener=h(e,function(t,e){if(!1!==j.keyBindingMode&&j.enableWheel&&j._ortho){var r=t>e?1.1:1/1.1;U.aspect[0]*=r,U.aspect[1]*=r,U.aspect[2]*=r,U.redraw()}},!0),U._mouseRotating=!1,U._prevButtons=0,U.enableMouseListeners=function(){U.mouseListener=u(e,function(t,e,r){if(!U._stopped){var n=z.length,i=L.length,a=_.object;_.distance=1/0,_.mouse[0]=e,_.mouse[1]=r,_.object=null,_.screen=null,_.dataCoordinate=_.dataPosition=null;var o=!1;if(t&&U._prevButtons)U._mouseRotating=!0;else{U._mouseRotating&&(D=!0),U._mouseRotating=!1;for(var s=0;s<n;++s){var l=z[s].query(e,V[1]-r-1,U.pickRadius);if(l){if(l.distance>_.distance)continue;for(var c=0;c<i;++c){var u=L[c];if(P[c]===s){var h=u.pick(l);h&&(_.buttons=t,_.screen=l.coord,_.distance=l.distance,_.object=u,_.index=h.distance,_.dataPosition=h.position,_.dataCoordinate=h.dataCoordinate,_.data=h,o=!0)}}}}}a&&a!==_.object&&(a.highlight&&a.highlight(null),I=!0),_.object&&(_.object.highlight&&_.object.highlight(_.data),I=!0),(o=o||_.object!==a)&&U.onselect&&U.onselect(_),1&t&&!(1&U._prevButtons)&&U.onclick&&U.onclick(_),U._prevButtons=t}})},e.addEventListener(\"webglcontextlost\",G);var Y=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],W=[Y[0].slice(),Y[1].slice()];function X(){if(!G()){q();var t=U.camera.tick();B.view=U.camera.matrix,I=I||t,D=D||t,S.pixelRatio=U.pixelRatio,C.pixelRatio=U.pixelRatio;var e=L.length,r=Y[0],n=Y[1];r[0]=r[1]=r[2]=1/0,n[0]=n[1]=n[2]=-1/0;for(var i=0;i<e;++i){var o=L[i];o.pixelRatio=U.pixelRatio,o.axes=U.axes,I=I||!!o.dirty,D=D||!!o.dirty;var s=o.bounds;if(s)for(var l=s[0],u=s[1],h=0;h<3;++h)r[h]=Math.min(r[h],l[h]),n[h]=Math.max(n[h],u[h])}var d=U.bounds;if(U.autoBounds)for(var h=0;h<3;++h){if(n[h]<r[h])r[h]=-1,n[h]=1;else{r[h]===n[h]&&(r[h]-=1,n[h]+=1);var g=.05*(n[h]-r[h]);r[h]=r[h]-g,n[h]=n[h]+g}d[0][h]=r[h],d[1][h]=n[h]}for(var v=!1,h=0;h<3;++h)v=v||W[0][h]!==d[0][h]||W[1][h]!==d[1][h],W[0][h]=d[0][h],W[1][h]=d[1][h];if(D=D||v,I=I||v){if(v){for(var y=[0,0,0],i=0;i<3;++i)y[i]=m((d[1][i]-d[0][i])/10);S.autoTicks?S.update({bounds:d,tickSpacing:y}):S.update({bounds:d})}var b=x.drawingBufferWidth,A=x.drawingBufferHeight;N[0]=b,N[1]=A,V[0]=0|Math.max(b/U.pixelRatio,1),V[1]=0|Math.max(A/U.pixelRatio,1),T?(p(R,-b/A,b/A,-1,1,U.zNear,U.zFar),B._ortho=!0):(f(R,U.fovy,b/A,U.zNear,U.zFar),B._ortho=!1);for(var i=0;i<16;++i)F[i]=0;F[15]=1;for(var M=0,i=0;i<3;++i)M=Math.max(M,d[1][i]-d[0][i]);for(var i=0;i<3;++i)U.autoScale?F[5*i]=U.aspect[i]/(d[1][i]-d[0][i]):F[5*i]=1/M,U.autoCenter&&(F[12+i]=.5*-F[5*i]*(d[0][i]+d[1][i]));for(var i=0;i<e;++i){var o=L[i];o.axesBounds=d,U.clipToBounds&&(o.clipBounds=d)}_.object&&(U.snapToData?C.position=_.dataCoordinate:C.position=_.dataPosition,C.bounds=d),D&&(D=!1,function(){if(G())return;x.colorMask(!0,!0,!0,!0),x.depthMask(!0),x.disable(x.BLEND),x.enable(x.DEPTH_TEST);for(var t=L.length,e=z.length,r=0;r<e;++r){var n=z[r];n.shape=V,n.begin();for(var i=0;i<t;++i)if(P[i]===r){var a=L[i];a.drawPick&&(a.pixelRatio=1,a.drawPick(B))}n.end()}}()),U.axesPixels=a(U.axes,B,b,A),U.onrender&&U.onrender(),x.bindFramebuffer(x.FRAMEBUFFER,null),x.viewport(0,0,b,A);var E=U.clearColor;x.clearColor(E[0],E[1],E[2],E[3]),x.clear(x.COLOR_BUFFER_BIT|x.DEPTH_BUFFER_BIT),x.depthMask(!0),x.colorMask(!0,!0,!0,!0),x.enable(x.DEPTH_TEST),x.depthFunc(x.LEQUAL),x.disable(x.BLEND),x.disable(x.CULL_FACE);var O=!1;S.enable&&(O=O||S.isTransparent(),S.draw(B)),C.axes=S,_.object&&C.draw(B),x.disable(x.CULL_FACE);for(var i=0;i<e;++i){var o=L[i];o.axes=S,o.pixelRatio=U.pixelRatio,o.isOpaque&&o.isOpaque()&&o.draw(B),o.isTransparent&&o.isTransparent()&&(O=!0)}if(O){w.shape=N,w.bind(),x.clear(x.DEPTH_BUFFER_BIT),x.colorMask(!1,!1,!1,!1),x.depthMask(!0),x.depthFunc(x.LESS),S.enable&&S.isTransparent()&&S.drawTransparent(B);for(var i=0;i<e;++i){var o=L[i];o.isOpaque&&o.isOpaque()&&o.draw(B)}x.enable(x.BLEND),x.blendEquation(x.FUNC_ADD),x.blendFunc(x.ONE,x.ONE_MINUS_SRC_ALPHA),x.colorMask(!0,!0,!0,!0),x.depthMask(!1),x.clearColor(0,0,0,0),x.clear(x.COLOR_BUFFER_BIT),S.isTransparent()&&S.drawTransparent(B);for(var i=0;i<e;++i){var o=L[i];o.isTransparent&&o.isTransparent()&&o.drawTransparent(B)}x.bindFramebuffer(x.FRAMEBUFFER,null),x.blendFunc(x.ONE,x.ONE_MINUS_SRC_ALPHA),x.disable(x.DEPTH_TEST),k.bind(),w.color[0].bind(0),k.uniforms.accumBuffer=0,c(x),x.disable(x.BLEND)}I=!1;for(var i=0;i<e;++i)L[i].dirty=!1}}}return U.enableMouseListeners(),function t(){U._stopped||U.contextLost||(X(),requestAnimationFrame(t))}(),U.redraw=function(){U._stopped||(I=!0,X())},U},createCamera:n}},{\"./camera.js\":288,\"./lib/shader\":289,\"a-big-triangle\":59,\"gl-axes3d\":233,\"gl-axes3d/properties\":240,\"gl-fbo\":249,\"gl-mat4/ortho\":268,\"gl-mat4/perspective\":269,\"gl-select-static\":300,\"gl-spikes3d\":310,\"is-mobile\":420,\"mouse-change\":435,\"mouse-wheel\":438}],291:[function(t,e,r){var n=t(\"glslify\");r.pointVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform float pointCloud;\\n\\nhighp float rand(vec2 co) {\\n  highp float a = 12.9898;\\n  highp float b = 78.233;\\n  highp float c = 43758.5453;\\n  highp float d = dot(co.xy, vec2(a, b));\\n  highp float e = mod(d, 3.14);\\n  return fract(sin(e) * c);\\n}\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n    // if we don't jitter the point size a bit, overall point cloud\\n    // saturation 'jumps' on zooming, which is disturbing and confusing\\n  gl_PointSize = pointSize * ((19.5 + rand(position)) / 20.0);\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    // get the same square surface as circle would be\\n    gl_PointSize *= 0.886;\\n  }\\n}\"]),r.pointFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color, borderColor;\\nuniform float centerFraction;\\nuniform float pointCloud;\\n\\nvoid main() {\\n  float radius;\\n  vec4 baseColor;\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    if(centerFraction == 1.0) {\\n      gl_FragColor = color;\\n    } else {\\n      gl_FragColor = mix(borderColor, color, centerFraction);\\n    }\\n  } else {\\n    radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n    if(radius > 1.0) {\\n      discard;\\n    }\\n    baseColor = mix(borderColor, color, step(radius, centerFraction));\\n    gl_FragColor = vec4(baseColor.rgb * baseColor.a, baseColor.a);\\n  }\\n}\\n\"]),r.pickVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform vec4 pickOffset;\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n  gl_PointSize = pointSize;\\n\\n  vec4 id = pickId + pickOffset;\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  fragId = id;\\n}\\n\"]),r.pickFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  float radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n  if(radius > 1.0) {\\n    discard;\\n  }\\n  gl_FragColor = fragId / 255.0;\\n}\\n\"])},{glslify:409}],292:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"typedarray-pool\"),o=t(\"./lib/shader\");function s(t,e,r,n,i){this.plot=t,this.offsetBuffer=e,this.pickBuffer=r,this.shader=n,this.pickShader=i,this.sizeMin=.5,this.sizeMinCap=2,this.sizeMax=20,this.areaRatio=1,this.pointCount=0,this.color=[1,0,0,1],this.borderColor=[0,0,0,1],this.blend=!1,this.pickOffset=0,this.points=null}e.exports=function(t,e){var r=t.gl,a=i(r),l=i(r),c=n(r,o.pointVertex,o.pointFragment),u=n(r,o.pickVertex,o.pickFragment),h=new s(t,a,l,c,u);return h.update(e),t.addObject(h),h};var l,c,u=s.prototype;u.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.offsetBuffer.dispose(),this.pickBuffer.dispose(),this.plot.removeObject(this)},u.update=function(t){var e;function r(e,r){return e in t?t[e]:r}t=t||{},this.sizeMin=r(\"sizeMin\",.5),this.sizeMax=r(\"sizeMax\",20),this.color=r(\"color\",[1,0,0,1]).slice(),this.areaRatio=r(\"areaRatio\",1),this.borderColor=r(\"borderColor\",[0,0,0,1]).slice(),this.blend=r(\"blend\",!1);var n=t.positions.length>>>1,i=t.positions instanceof Float32Array,o=t.idToIndex instanceof Int32Array&&t.idToIndex.length>=n,s=t.positions,l=i?s:a.mallocFloat32(s.length),c=o?t.idToIndex:a.mallocInt32(n);if(i||l.set(s),!o)for(l.set(s),e=0;e<n;e++)c[e]=e;this.points=s,this.offsetBuffer.update(l),this.pickBuffer.update(c),i||a.free(l),o||a.free(c),this.pointCount=n,this.pickOffset=0},u.unifiedDraw=(l=[1,0,0,0,1,0,0,0,1],c=[0,0,0,0],function(t){var e=void 0!==t,r=e?this.pickShader:this.shader,n=this.plot.gl,i=this.plot.dataBox;if(0===this.pointCount)return t;var a=i[2]-i[0],o=i[3]-i[1],s=function(t,e){var r,n=0,i=t.length>>>1;for(r=0;r<i;r++){var a=t[2*r],o=t[2*r+1];a>=e[0]&&a<=e[2]&&o>=e[1]&&o<=e[3]&&n++}return n}(this.points,i),u=this.plot.pickPixelRatio*Math.max(Math.min(this.sizeMinCap,this.sizeMin),Math.min(this.sizeMax,this.sizeMax/Math.pow(s,.33333)));l[0]=2/a,l[4]=2/o,l[6]=-2*i[0]/a-1,l[7]=-2*i[1]/o-1,this.offsetBuffer.bind(),r.bind(),r.attributes.position.pointer(),r.uniforms.matrix=l,r.uniforms.color=this.color,r.uniforms.borderColor=this.borderColor,r.uniforms.pointCloud=u<5,r.uniforms.pointSize=u,r.uniforms.centerFraction=Math.min(1,Math.max(0,Math.sqrt(1-this.areaRatio))),e&&(c[0]=255&t,c[1]=t>>8&255,c[2]=t>>16&255,c[3]=t>>24&255,this.pickBuffer.bind(),r.attributes.pickId.pointer(n.UNSIGNED_BYTE),r.uniforms.pickOffset=c,this.pickOffset=t);var h=n.getParameter(n.BLEND),f=n.getParameter(n.DITHER);return h&&!this.blend&&n.disable(n.BLEND),f&&n.disable(n.DITHER),n.drawArrays(n.POINTS,0,this.pointCount),h&&!this.blend&&n.enable(n.BLEND),f&&n.enable(n.DITHER),t+this.pointCount}),u.draw=u.unifiedDraw,u.drawPick=u.unifiedDraw,u.pick=function(t,e,r){var n=this.pickOffset,i=this.pointCount;if(r<n||r>=n+i)return null;var a=r-n,o=this.points;return{object:this,pointId:a,dataCoord:[o[2*a],o[2*a+1]]}}},{\"./lib/shader\":291,\"gl-buffer\":241,\"gl-shader\":301,\"typedarray-pool\":545}],293:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c=e[0],u=e[1],h=e[2],f=e[3],p=r[0],d=r[1],g=r[2],v=r[3];(a=c*p+u*d+h*g+f*v)<0&&(a=-a,p=-p,d=-d,g=-g,v=-v);1-a>1e-6?(i=Math.acos(a),o=Math.sin(i),s=Math.sin((1-n)*i)/o,l=Math.sin(n*i)/o):(s=1-n,l=n);return t[0]=s*c+l*p,t[1]=s*u+l*d,t[2]=s*h+l*g,t[3]=s*f+l*v,t}},{}],294:[function(t,e,r){\"use strict\";e.exports=function(t){return t||0===t?t.toString():\"\"}},{}],295:[function(t,e,r){\"use strict\";var n=t(\"vectorize-text\");e.exports=function(t,e,r){var a=i[e];a||(a=i[e]={});if(t in a)return a[t];var o={textAlign:\"center\",textBaseline:\"middle\",lineHeight:1,font:e,lineSpacing:1.25,styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},triangles:!0},s=n(t,o);o.triangles=!1;var l,c,u=n(t,o);if(r&&1!==r){for(l=0;l<s.positions.length;++l)for(c=0;c<s.positions[l].length;++c)s.positions[l][c]/=r;for(l=0;l<u.positions.length;++l)for(c=0;c<u.positions[l].length;++c)u.positions[l][c]/=r}var h=[[1/0,1/0],[-1/0,-1/0]],f=u.positions.length;for(l=0;l<f;++l){var p=u.positions[l];for(c=0;c<2;++c)h[0][c]=Math.min(h[0][c],p[c]),h[1][c]=Math.max(h[1][c],p[c])}return a[t]=[s,u,h]};var i={}},{\"vectorize-text\":550}],296:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform vec4 highlightId;\\nuniform float highlightScale;\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = 1.0;\\n    if(distance(highlightId, id) < 0.0001) {\\n      scale = highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1);\\n    vec4 viewPosition = view * worldPosition;\\n    viewPosition = viewPosition / viewPosition.w;\\n    vec4 clipPosition = projection * (viewPosition + scale * vec4(glyph.x, -glyph.y, 0, 0));\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float highlightScale, pixelRatio;\\nuniform vec4 highlightId;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = pixelRatio;\\n    if(distance(highlightId.bgr, id.bgr) < 0.001) {\\n      scale *= highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1.0);\\n    vec4 viewPosition = view * worldPosition;\\n    vec4 clipPosition = projection * viewPosition;\\n    clipPosition /= clipPosition.w;\\n\\n    gl_Position = clipPosition + vec4(screenSize * scale * vec2(glyph.x, -glyph.y), 0.0, 0.0);\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform float highlightScale;\\nuniform vec4 highlightId;\\nuniform vec3 axes[2];\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float scale, pixelRatio;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float lscale = pixelRatio * scale;\\n    if(distance(highlightId, id) < 0.0001) {\\n      lscale *= highlightScale;\\n    }\\n\\n    vec4 clipCenter   = projection * view * model * vec4(position, 1);\\n    vec3 dataPosition = position + 0.5*lscale*(axes[0] * glyph.x + axes[1] * glyph.y) * clipCenter.w * screenSize.y;\\n    vec4 clipPosition = projection * view * model * vec4(dataPosition, 1);\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = dataPosition;\\n  }\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float opacity;\\n\\nvarying vec4 interpColor;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (\\n    outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate) ||\\n    interpColor.a * opacity == 0.\\n  ) discard;\\n  gl_FragColor = interpColor * opacity;\\n}\\n\"]),c=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float pickGroup;\\n\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate)) discard;\\n\\n  gl_FragColor = vec4(pickGroup, pickId.bgr);\\n}\"]),u=[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"glyph\",type:\"vec2\"},{name:\"id\",type:\"vec4\"}],h={vertex:a,fragment:l,attributes:u},f={vertex:o,fragment:l,attributes:u},p={vertex:s,fragment:l,attributes:u},d={vertex:a,fragment:c,attributes:u},g={vertex:o,fragment:c,attributes:u},v={vertex:s,fragment:c,attributes:u};function m(t,e){var r=n(t,e),i=r.attributes;return i.position.location=0,i.color.location=1,i.glyph.location=2,i.id.location=3,r}r.createPerspective=function(t){return m(t,h)},r.createOrtho=function(t){return m(t,f)},r.createProject=function(t){return m(t,p)},r.createPickPerspective=function(t){return m(t,d)},r.createPickOrtho=function(t){return m(t,g)},r.createPickProject=function(t){return m(t,v)}},{\"gl-shader\":301,glslify:409}],297:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"typedarray-pool\"),s=t(\"gl-mat4/multiply\"),l=t(\"./lib/shaders\"),c=t(\"./lib/glyphs\"),u=t(\"./lib/get-simple-string\"),h=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function f(t,e){var r=t[0],n=t[1],i=t[2],a=t[3];return t[0]=e[0]*r+e[4]*n+e[8]*i+e[12]*a,t[1]=e[1]*r+e[5]*n+e[9]*i+e[13]*a,t[2]=e[2]*r+e[6]*n+e[10]*i+e[14]*a,t[3]=e[3]*r+e[7]*n+e[11]*i+e[15]*a,t}function p(t,e,r,n){return f(n,n),f(n,n),f(n,n)}function d(t,e){this.index=t,this.dataCoordinate=this.position=e}function g(t){return!0===t?1:t>1?1:t}function v(t,e,r,n,i,a,o,s,l,c,u,h){this.gl=t,this.pixelRatio=1,this.shader=e,this.orthoShader=r,this.projectShader=n,this.pointBuffer=i,this.colorBuffer=a,this.glyphBuffer=o,this.idBuffer=s,this.vao=l,this.vertexCount=0,this.lineVertexCount=0,this.opacity=1,this.hasAlpha=!1,this.lineWidth=0,this.projectScale=[2/3,2/3,2/3],this.projectOpacity=[1,1,1],this.projectHasAlpha=!1,this.pickId=0,this.pickPerspectiveShader=c,this.pickOrthoShader=u,this.pickProjectShader=h,this.points=[],this._selectResult=new d(0,[0,0,0]),this.useOrtho=!0,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.axesProject=[!0,!0,!0],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.highlightId=[1,1,1,1],this.highlightScale=2,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.dirty=!0}e.exports=function(t){var e=t.gl,r=l.createPerspective(e),n=l.createOrtho(e),o=l.createProject(e),s=l.createPickPerspective(e),c=l.createPickOrtho(e),u=l.createPickProject(e),h=i(e),f=i(e),p=i(e),d=i(e),g=a(e,[{buffer:h,size:3,type:e.FLOAT},{buffer:f,size:4,type:e.FLOAT},{buffer:p,size:2,type:e.FLOAT},{buffer:d,size:4,type:e.UNSIGNED_BYTE,normalized:!0}]),m=new v(e,r,n,o,h,f,p,d,g,s,c,u);return m.update(t),m};var m=v.prototype;m.pickSlots=1,m.setPickBase=function(t){this.pickId=t},m.isTransparent=function(){if(this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&this.projectHasAlpha)return!0;return!1},m.isOpaque=function(){if(!this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&!this.projectHasAlpha)return!0;return!1};var y=[0,0],x=[0,0,0],b=[0,0,0],_=[0,0,0,1],w=[0,0,0,1],k=h.slice(),T=[0,0,0],A=[[0,0,0],[0,0,0]];function M(t){return t[0]=t[1]=t[2]=0,t}function S(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=1,t}function E(t,e,r,n){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[r]=n,t}function C(t,e,r,n){var i,a=e.axesProject,o=e.gl,l=t.uniforms,c=r.model||h,u=r.view||h,f=r.projection||h,d=e.axesBounds,g=function(t){for(var e=A,r=0;r<2;++r)for(var n=0;n<3;++n)e[r][n]=Math.max(Math.min(t[r][n],1e8),-1e8);return e}(e.clipBounds);i=e.axes&&e.axes.lastCubeProps?e.axes.lastCubeProps.axis:[1,1,1],y[0]=2/o.drawingBufferWidth,y[1]=2/o.drawingBufferHeight,t.bind(),l.view=u,l.projection=f,l.screenSize=y,l.highlightId=e.highlightId,l.highlightScale=e.highlightScale,l.clipBounds=g,l.pickGroup=e.pickId/255,l.pixelRatio=n;for(var v=0;v<3;++v)if(a[v]){l.scale=e.projectScale[v],l.opacity=e.projectOpacity[v];for(var m=k,C=0;C<16;++C)m[C]=0;for(C=0;C<4;++C)m[5*C]=1;m[5*v]=0,i[v]<0?m[12+v]=d[0][v]:m[12+v]=d[1][v],s(m,c,m),l.model=m;var L=(v+1)%3,P=(v+2)%3,O=M(x),z=M(b);O[L]=1,z[P]=1;var I=p(0,0,0,S(_,O)),D=p(0,0,0,S(w,z));if(Math.abs(I[1])>Math.abs(D[1])){var R=I;I=D,D=R,R=O,O=z,z=R;var F=L;L=P,P=F}I[0]<0&&(O[L]=-1),D[1]>0&&(z[P]=-1);var B=0,N=0;for(C=0;C<4;++C)B+=Math.pow(c[4*L+C],2),N+=Math.pow(c[4*P+C],2);O[L]/=Math.sqrt(B),z[P]/=Math.sqrt(N),l.axes[0]=O,l.axes[1]=z,l.fragClipBounds[0]=E(T,g[0],v,-1e8),l.fragClipBounds[1]=E(T,g[1],v,1e8),e.vao.bind(),e.vao.draw(o.TRIANGLES,e.vertexCount),e.lineWidth>0&&(o.lineWidth(e.lineWidth*n),e.vao.draw(o.LINES,e.lineVertexCount,e.vertexCount)),e.vao.unbind()}}var L=[[-1e8,-1e8,-1e8],[1e8,1e8,1e8]];function P(t,e,r,n,i,a,o){var s=r.gl;if((a===r.projectHasAlpha||o)&&C(e,r,n,i),a===r.hasAlpha||o){t.bind();var l=t.uniforms;l.model=n.model||h,l.view=n.view||h,l.projection=n.projection||h,y[0]=2/s.drawingBufferWidth,y[1]=2/s.drawingBufferHeight,l.screenSize=y,l.highlightId=r.highlightId,l.highlightScale=r.highlightScale,l.fragClipBounds=L,l.clipBounds=r.axes.bounds,l.opacity=r.opacity,l.pickGroup=r.pickId/255,l.pixelRatio=i,r.vao.bind(),r.vao.draw(s.TRIANGLES,r.vertexCount),r.lineWidth>0&&(s.lineWidth(r.lineWidth*i),r.vao.draw(s.LINES,r.lineVertexCount,r.vertexCount)),r.vao.unbind()}}function O(t,e,r,i){var a;a=Array.isArray(t)?e<t.length?t[e]:void 0:t,a=u(a);var o=!0;n(a)&&(a=\"\\u25bc\",o=!1);var s=c(a,r,i);return{mesh:s[0],lines:s[1],bounds:s[2],visible:o}}m.draw=function(t){P(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!1,!1)},m.drawTransparent=function(t){P(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!0,!1)},m.drawPick=function(t){P(this.useOrtho?this.pickOrthoShader:this.pickPerspectiveShader,this.pickProjectShader,this,t,1,!0,!0)},m.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[2]+(t.value[1]<<8)+(t.value[0]<<16);if(e>=this.pointCount||e<0)return null;var r=this.points[e],n=this._selectResult;n.index=e;for(var i=0;i<3;++i)n.position[i]=n.dataCoordinate[i]=r[i];return n},m.highlight=function(t){if(t){var e=t.index,r=255&e,n=e>>8&255,i=e>>16&255;this.highlightId=[r/255,n/255,i/255,0]}else this.highlightId=[1,1,1,1]},m.update=function(t){if(\"perspective\"in(t=t||{})&&(this.useOrtho=!t.perspective),\"orthographic\"in t&&(this.useOrtho=!!t.orthographic),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"project\"in t)if(Array.isArray(t.project))this.axesProject=t.project;else{var e=!!t.project;this.axesProject=[e,e,e]}if(\"projectScale\"in t)if(Array.isArray(t.projectScale))this.projectScale=t.projectScale.slice();else{var r=+t.projectScale;this.projectScale=[r,r,r]}if(this.projectHasAlpha=!1,\"projectOpacity\"in t){if(Array.isArray(t.projectOpacity))this.projectOpacity=t.projectOpacity.slice();else{r=+t.projectOpacity;this.projectOpacity=[r,r,r]}for(var n=0;n<3;++n)this.projectOpacity[n]=g(this.projectOpacity[n]),this.projectOpacity[n]<1&&(this.projectHasAlpha=!0)}this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=g(t.opacity),this.opacity<1&&(this.hasAlpha=!0)),this.dirty=!0;var i,a,s=t.position,l=t.font||\"normal\",c=t.alignment||[0,0];if(2===c.length)i=c[0],a=c[1];else{i=[],a=[];for(n=0;n<c.length;++n)i[n]=c[n][0],a[n]=c[n][1]}var u=[1/0,1/0,1/0],h=[-1/0,-1/0,-1/0],f=t.glyph,p=t.color,d=t.size,v=t.angle,m=t.lineColor,y=-1,x=0,b=0,_=0;if(s.length){_=s.length;t:for(n=0;n<_;++n){for(var w=s[n],k=0;k<3;++k)if(isNaN(w[k])||!isFinite(w[k]))continue t;var T=(N=O(f,n,l,this.pixelRatio)).mesh,A=N.lines,M=N.bounds;x+=3*T.cells.length,b+=2*A.edges.length}}var S=x+b,E=o.mallocFloat(3*S),C=o.mallocFloat(4*S),L=o.mallocFloat(2*S),P=o.mallocUint32(S);if(S>0){var z=0,I=x,D=[0,0,0,1],R=[0,0,0,1],F=Array.isArray(p)&&Array.isArray(p[0]),B=Array.isArray(m)&&Array.isArray(m[0]);t:for(n=0;n<_;++n){y+=1;for(w=s[n],k=0;k<3;++k){if(isNaN(w[k])||!isFinite(w[k]))continue t;h[k]=Math.max(h[k],w[k]),u[k]=Math.min(u[k],w[k])}T=(N=O(f,n,l,this.pixelRatio)).mesh,A=N.lines,M=N.bounds;var N,j=N.visible;if(j)if(Array.isArray(p)){if(3===(U=F?n<p.length?p[n]:[0,0,0,0]:p).length){for(k=0;k<3;++k)D[k]=U[k];D[3]=1}else if(4===U.length){for(k=0;k<4;++k)D[k]=U[k];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else D[0]=D[1]=D[2]=0,D[3]=1;else D=[1,1,1,0];if(j)if(Array.isArray(m)){var U;if(3===(U=B?n<m.length?m[n]:[0,0,0,0]:m).length){for(k=0;k<3;++k)R[k]=U[k];R[k]=1}else if(4===U.length){for(k=0;k<4;++k)R[k]=U[k];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else R[0]=R[1]=R[2]=0,R[3]=1;else R=[1,1,1,0];var V=.5;j?Array.isArray(d)?V=n<d.length?+d[n]:12:d?V=+d:this.useOrtho&&(V=12):V=0;var q=0;Array.isArray(v)?q=n<v.length?+v[n]:0:v&&(q=+v);var H=Math.cos(q),G=Math.sin(q);for(w=s[n],k=0;k<3;++k)h[k]=Math.max(h[k],w[k]),u[k]=Math.min(u[k],w[k]);var Y=i,W=a;Y=0;Array.isArray(i)?Y=n<i.length?i[n]:0:i&&(Y=i);W=0;Array.isArray(a)?W=n<a.length?a[n]:0:a&&(W=a);var X=[Y*=Y>0?1-M[0][0]:Y<0?1+M[1][0]:1,W*=W>0?1-M[0][1]:W<0?1+M[1][1]:1],Z=T.cells||[],J=T.positions||[];for(k=0;k<Z.length;++k)for(var K=Z[k],$=0;$<3;++$){for(var Q=0;Q<3;++Q)E[3*z+Q]=w[Q];for(Q=0;Q<4;++Q)C[4*z+Q]=D[Q];P[z]=y;var tt=J[K[$]];L[2*z]=V*(H*tt[0]-G*tt[1]+X[0]),L[2*z+1]=V*(G*tt[0]+H*tt[1]+X[1]),z+=1}for(Z=A.edges,J=A.positions,k=0;k<Z.length;++k)for(K=Z[k],$=0;$<2;++$){for(Q=0;Q<3;++Q)E[3*I+Q]=w[Q];for(Q=0;Q<4;++Q)C[4*I+Q]=R[Q];P[I]=y;tt=J[K[$]];L[2*I]=V*(H*tt[0]-G*tt[1]+X[0]),L[2*I+1]=V*(G*tt[0]+H*tt[1]+X[1]),I+=1}}}this.bounds=[u,h],this.points=s,this.pointCount=s.length,this.vertexCount=x,this.lineVertexCount=b,this.pointBuffer.update(E),this.colorBuffer.update(C),this.glyphBuffer.update(L),this.idBuffer.update(P),o.free(E),o.free(C),o.free(L),o.free(P)},m.dispose=function(){this.shader.dispose(),this.orthoShader.dispose(),this.pickPerspectiveShader.dispose(),this.pickOrthoShader.dispose(),this.vao.dispose(),this.pointBuffer.dispose(),this.colorBuffer.dispose(),this.glyphBuffer.dispose(),this.idBuffer.dispose()}},{\"./lib/get-simple-string\":294,\"./lib/glyphs\":295,\"./lib/shaders\":296,\"gl-buffer\":241,\"gl-mat4/multiply\":267,\"gl-vao\":327,\"is-string-blank\":423,\"typedarray-pool\":545}],298:[function(t,e,r){\"use strict\";var n=t(\"glslify\");r.boxVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 vertex;\\n\\nuniform vec2 cornerA, cornerB;\\n\\nvoid main() {\\n  gl_Position = vec4(mix(cornerA, cornerB, vertex), 0, 1);\\n}\\n\"]),r.boxFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\n\\nvoid main() {\\n  gl_FragColor = color;\\n}\\n\"])},{glslify:409}],299:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"./lib/shaders\");function o(t,e,r){this.plot=t,this.boxBuffer=e,this.boxShader=r,this.enabled=!0,this.selectBox=[1/0,1/0,-1/0,-1/0],this.borderColor=[0,0,0,1],this.innerFill=!1,this.innerColor=[0,0,0,.25],this.outerFill=!0,this.outerColor=[0,0,0,.5],this.borderWidth=10}e.exports=function(t,e){var r=t.gl,s=i(r,[0,0,0,1,1,0,1,1]),l=n(r,a.boxVertex,a.boxFragment),c=new o(t,s,l);return c.update(e),t.addOverlay(c),c};var s=o.prototype;s.draw=function(){if(this.enabled){var t=this.plot,e=this.selectBox,r=this.borderWidth,n=(this.innerFill,this.innerColor),i=(this.outerFill,this.outerColor),a=this.borderColor,o=t.box,s=t.screenBox,l=t.dataBox,c=t.viewBox,u=t.pixelRatio,h=(e[0]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],f=(e[1]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1],p=(e[2]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],d=(e[3]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1];if(h=Math.max(h,c[0]),f=Math.max(f,c[1]),p=Math.min(p,c[2]),d=Math.min(d,c[3]),!(p<h||d<f)){o.bind();var g=s[2]-s[0],v=s[3]-s[1];if(this.outerFill&&(o.drawBox(0,0,g,f,i),o.drawBox(0,f,h,d,i),o.drawBox(0,d,g,v,i),o.drawBox(p,f,g,d,i)),this.innerFill&&o.drawBox(h,f,p,d,n),r>0){var m=r*u;o.drawBox(h-m,f-m,p+m,f+m,a),o.drawBox(h-m,d-m,p+m,d+m,a),o.drawBox(h-m,f-m,h+m,d+m,a),o.drawBox(p-m,f-m,p+m,d+m,a)}}}},s.update=function(t){t=t||{},this.innerFill=!!t.innerFill,this.outerFill=!!t.outerFill,this.innerColor=(t.innerColor||[0,0,0,.5]).slice(),this.outerColor=(t.outerColor||[0,0,0,.5]).slice(),this.borderColor=(t.borderColor||[0,0,0,1]).slice(),this.borderWidth=t.borderWidth||0,this.selectBox=(t.selectBox||this.selectBox).slice()},s.dispose=function(){this.boxBuffer.dispose(),this.boxShader.dispose(),this.plot.removeOverlay(this)}},{\"./lib/shaders\":298,\"gl-buffer\":241,\"gl-shader\":301}],300:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=n(t,e),a=i.mallocUint8(e[0]*e[1]*4);return new c(t,r,a)};var n=t(\"gl-fbo\"),i=t(\"typedarray-pool\"),a=t(\"ndarray\"),o=t(\"bit-twiddle\").nextPow2,s=t(\"cwise/lib/wrapper\")({args:[\"array\",{offset:[0,0,1],array:0},{offset:[0,0,2],array:0},{offset:[0,0,3],array:0},\"scalar\",\"scalar\",\"index\"],pre:{body:\"{this_closestD2=1e8,this_closestX=-1,this_closestY=-1}\",args:[],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[]},body:{body:\"{if(_inline_16_arg0_<255||_inline_16_arg1_<255||_inline_16_arg2_<255||_inline_16_arg3_<255){var _inline_16_l=_inline_16_arg4_-_inline_16_arg6_[0],_inline_16_a=_inline_16_arg5_-_inline_16_arg6_[1],_inline_16_f=_inline_16_l*_inline_16_l+_inline_16_a*_inline_16_a;_inline_16_f<this_closestD2&&(this_closestD2=_inline_16_f,this_closestX=_inline_16_arg6_[0],this_closestY=_inline_16_arg6_[1])}}\",args:[{name:\"_inline_16_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg4_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg5_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg6_\",lvalue:!1,rvalue:!0,count:4}],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[\"_inline_16_a\",\"_inline_16_f\",\"_inline_16_l\"]},post:{body:\"{return[this_closestX,this_closestY,this_closestD2]}\",args:[],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[]},debug:!1,funcName:\"cwise\",blockSize:64});function l(t,e,r,n,i){this.coord=[t,e],this.id=r,this.value=n,this.distance=i}function c(t,e,r){this.gl=t,this.fbo=e,this.buffer=r,this._readTimeout=null;var n=this;this._readCallback=function(){n.gl&&(e.bind(),t.readPixels(0,0,e.shape[0],e.shape[1],t.RGBA,t.UNSIGNED_BYTE,n.buffer),n._readTimeout=null)}}var u=c.prototype;Object.defineProperty(u,\"shape\",{get:function(){return this.gl?this.fbo.shape.slice():[0,0]},set:function(t){if(this.gl){this.fbo.shape=t;var e=this.fbo.shape[0],r=this.fbo.shape[1];if(r*e*4>this.buffer.length){i.free(this.buffer);for(var n=this.buffer=i.mallocUint8(o(r*e*4)),a=0;a<r*e*4;++a)n[a]=255}return t}}}),u.begin=function(){var t=this.gl;this.shape;t&&(this.fbo.bind(),t.clearColor(1,1,1,1),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT))},u.end=function(){var t=this.gl;t&&(t.bindFramebuffer(t.FRAMEBUFFER,null),this._readTimeout||clearTimeout(this._readTimeout),this._readTimeout=setTimeout(this._readCallback,1))},u.query=function(t,e,r){if(!this.gl)return null;var n=this.fbo.shape.slice();t|=0,e|=0,\"number\"!=typeof r&&(r=1);var i=0|Math.min(Math.max(t-r,0),n[0]),o=0|Math.min(Math.max(t+r,0),n[0]),c=0|Math.min(Math.max(e-r,0),n[1]),u=0|Math.min(Math.max(e+r,0),n[1]);if(o<=i||u<=c)return null;var h=[o-i,u-c],f=a(this.buffer,[h[0],h[1],4],[4,4*n[0],1],4*(i+n[0]*c)),p=s(f.hi(h[0],h[1],1),r,r),d=p[0],g=p[1];return d<0||Math.pow(this.radius,2)<p[2]?null:new l(d+i|0,g+c|0,f.get(d,g,0),[f.get(d,g,1),f.get(d,g,2),f.get(d,g,3)],Math.sqrt(p[2]))},u.dispose=function(){this.gl&&(this.fbo.dispose(),i.free(this.buffer),this.gl=null,this._readTimeout&&clearTimeout(this._readTimeout))}},{\"bit-twiddle\":92,\"cwise/lib/wrapper\":149,\"gl-fbo\":249,ndarray:450,\"typedarray-pool\":545}],301:[function(t,e,r){\"use strict\";var n=t(\"./lib/create-uniforms\"),i=t(\"./lib/create-attributes\"),a=t(\"./lib/reflect\"),o=t(\"./lib/shader-cache\"),s=t(\"./lib/runtime-reflect\"),l=t(\"./lib/GLError\");function c(t){this.gl=t,this.gl.lastAttribCount=0,this._vref=this._fref=this._relink=this.vertShader=this.fragShader=this.program=this.attributes=this.uniforms=this.types=null}var u=c.prototype;function h(t,e){return t.name<e.name?-1:1}u.bind=function(){var t;this.program||this._relink();var e=this.gl.getProgramParameter(this.program,this.gl.ACTIVE_ATTRIBUTES),r=this.gl.lastAttribCount;if(e>r)for(t=r;t<e;t++)this.gl.enableVertexAttribArray(t);else if(r>e)for(t=e;t<r;t++)this.gl.disableVertexAttribArray(t);this.gl.lastAttribCount=e,this.gl.useProgram(this.program)},u.dispose=function(){for(var t=this.gl.lastAttribCount,e=0;e<t;e++)this.gl.disableVertexAttribArray(e);this.gl.lastAttribCount=0,this._fref&&this._fref.dispose(),this._vref&&this._vref.dispose(),this.attributes=this.types=this.vertShader=this.fragShader=this.program=this._relink=this._fref=this._vref=null},u.update=function(t,e,r,c){if(!e||1===arguments.length){var u=t;t=u.vertex,e=u.fragment,r=u.uniforms,c=u.attributes}var f=this,p=f.gl,d=f._vref;f._vref=o.shader(p,p.VERTEX_SHADER,t),d&&d.dispose(),f.vertShader=f._vref.shader;var g=this._fref;if(f._fref=o.shader(p,p.FRAGMENT_SHADER,e),g&&g.dispose(),f.fragShader=f._fref.shader,!r||!c){var v=p.createProgram();if(p.attachShader(v,f.fragShader),p.attachShader(v,f.vertShader),p.linkProgram(v),!p.getProgramParameter(v,p.LINK_STATUS)){var m=p.getProgramInfoLog(v);throw new l(m,\"Error linking program:\"+m)}r=r||s.uniforms(p,v),c=c||s.attributes(p,v),p.deleteProgram(v)}(c=c.slice()).sort(h);var y,x=[],b=[],_=[];for(y=0;y<c.length;++y){var w=c[y];if(w.type.indexOf(\"mat\")>=0){for(var k=0|w.type.charAt(w.type.length-1),T=new Array(k),A=0;A<k;++A)T[A]=_.length,b.push(w.name+\"[\"+A+\"]\"),\"number\"==typeof w.location?_.push(w.location+A):Array.isArray(w.location)&&w.location.length===k&&\"number\"==typeof w.location[A]?_.push(0|w.location[A]):_.push(-1);x.push({name:w.name,type:w.type,locations:T})}else x.push({name:w.name,type:w.type,locations:[_.length]}),b.push(w.name),\"number\"==typeof w.location?_.push(0|w.location):_.push(-1)}var M=0;for(y=0;y<_.length;++y)if(_[y]<0){for(;_.indexOf(M)>=0;)M+=1;_[y]=M}var S=new Array(r.length);function E(){f.program=o.program(p,f._vref,f._fref,b,_);for(var t=0;t<r.length;++t)S[t]=p.getUniformLocation(f.program,r[t].name)}E(),f._relink=E,f.types={uniforms:a(r),attributes:a(c)},f.attributes=i(p,f,x,_),Object.defineProperty(f,\"uniforms\",n(p,f,r,S))},e.exports=function(t,e,r,n,i){var a=new c(t);return a.update(e,r,n,i),a}},{\"./lib/GLError\":302,\"./lib/create-attributes\":303,\"./lib/create-uniforms\":304,\"./lib/reflect\":305,\"./lib/runtime-reflect\":306,\"./lib/shader-cache\":307}],302:[function(t,e,r){function n(t,e,r){this.shortMessage=e||\"\",this.longMessage=r||\"\",this.rawError=t||\"\",this.message=\"gl-shader: \"+(e||t||\"\")+(r?\"\\n\"+r:\"\"),this.stack=(new Error).stack}n.prototype=new Error,n.prototype.name=\"GLError\",n.prototype.constructor=n,e.exports=n},{}],303:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){for(var a={},l=0,c=r.length;l<c;++l){var u=r[l],h=u.name,f=u.type,p=u.locations;switch(f){case\"bool\":case\"int\":case\"float\":o(t,e,p[0],i,1,a,h);break;default:if(f.indexOf(\"vec\")>=0){var d=f.charCodeAt(f.length-1)-48;if(d<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+h+\": \"+f);o(t,e,p[0],i,d,a,h)}else{if(!(f.indexOf(\"mat\")>=0))throw new n(\"\",\"Unknown data type for attribute \"+h+\": \"+f);var d=f.charCodeAt(f.length-1)-48;if(d<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+h+\": \"+f);s(t,e,p,i,d,a,h)}}}return a};var n=t(\"./GLError\");function i(t,e,r,n,i,a){this._gl=t,this._wrapper=e,this._index=r,this._locations=n,this._dimension=i,this._constFunc=a}var a=i.prototype;function o(t,e,r,n,a,o,s){for(var l=[\"gl\",\"v\"],c=[],u=0;u<a;++u)l.push(\"x\"+u),c.push(\"x\"+u);l.push(\"if(x0.length===void 0){return gl.vertexAttrib\"+a+\"f(v,\"+c.join()+\")}else{return gl.vertexAttrib\"+a+\"fv(v,x0)}\");var h=Function.apply(null,l),f=new i(t,e,r,n,a,h);Object.defineProperty(o,s,{set:function(e){return t.disableVertexAttribArray(n[r]),h(t,n[r],e),e},get:function(){return f},enumerable:!0})}function s(t,e,r,n,i,a,s){for(var l=new Array(i),c=new Array(i),u=0;u<i;++u)o(t,e,r[u],n,i,l,u),c[u]=l[u];Object.defineProperty(l,\"location\",{set:function(t){if(Array.isArray(t))for(var e=0;e<i;++e)c[e].location=t[e];else for(e=0;e<i;++e)c[e].location=t+e;return t},get:function(){for(var t=new Array(i),e=0;e<i;++e)t[e]=n[r[e]];return t},enumerable:!0}),l.pointer=function(e,a,o,s){e=e||t.FLOAT,a=!!a,o=o||i*i,s=s||0;for(var l=0;l<i;++l){var c=n[r[l]];t.vertexAttribPointer(c,i,e,a,o,s+l*i),t.enableVertexAttribArray(c)}};var h=new Array(i),f=t[\"vertexAttrib\"+i+\"fv\"];Object.defineProperty(a,s,{set:function(e){for(var a=0;a<i;++a){var o=n[r[a]];if(t.disableVertexAttribArray(o),Array.isArray(e[0]))f.call(t,o,e[a]);else{for(var s=0;s<i;++s)h[s]=e[i*a+s];f.call(t,o,h)}}return e},get:function(){return l},enumerable:!0})}a.pointer=function(t,e,r,n){var i=this._gl,a=this._locations[this._index];i.vertexAttribPointer(a,this._dimension,t||i.FLOAT,!!e,r||0,n||0),i.enableVertexAttribArray(a)},a.set=function(t,e,r,n){return this._constFunc(this._locations[this._index],t,e,r,n)},Object.defineProperty(a,\"location\",{get:function(){return this._locations[this._index]},set:function(t){return t!==this._locations[this._index]&&(this._locations[this._index]=0|t,this._wrapper.program=null),0|t}})},{\"./GLError\":302}],304:[function(t,e,r){\"use strict\";var n=t(\"./reflect\"),i=t(\"./GLError\");function a(t){return new Function(\"y\",\"return function(){return y}\")(t)}function o(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}e.exports=function(t,e,r,s){function l(t,e,r){switch(r){case\"bool\":case\"int\":case\"sampler2D\":case\"samplerCube\":return\"gl.uniform1i(locations[\"+e+\"],obj\"+t+\")\";case\"float\":return\"gl.uniform1f(locations[\"+e+\"],obj\"+t+\")\";default:var n=r.indexOf(\"vec\");if(!(0<=n&&n<=1&&r.length===4+n)){if(0===r.indexOf(\"mat\")&&4===r.length){var a=r.charCodeAt(r.length-1)-48;if(a<2||a>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+r);return\"gl.uniformMatrix\"+a+\"fv(locations[\"+e+\"],false,obj\"+t+\")\"}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+r)}var a=r.charCodeAt(r.length-1)-48;if(a<2||a>4)throw new i(\"\",\"Invalid data type\");switch(r.charAt(0)){case\"b\":case\"i\":return\"gl.uniform\"+a+\"iv(locations[\"+e+\"],obj\"+t+\")\";case\"v\":return\"gl.uniform\"+a+\"fv(locations[\"+e+\"],obj\"+t+\")\";default:throw new i(\"\",\"Unrecognized data type for vector \"+name+\": \"+r)}}}function c(e){for(var n=[\"return function updateProperty(obj){\"],i=function t(e,r){if(\"object\"!=typeof r)return[[e,r]];var n=[];for(var i in r){var a=r[i],o=e;parseInt(i)+\"\"===i?o+=\"[\"+i+\"]\":o+=\".\"+i,\"object\"==typeof a?n.push.apply(n,t(o,a)):n.push([o,a])}return n}(\"\",e),a=0;a<i.length;++a){var o=i[a],c=o[0],u=o[1];s[u]&&n.push(l(c,u,r[u].type))}n.push(\"return obj}\");var h=new Function(\"gl\",\"locations\",n.join(\"\\n\"));return h(t,s)}function u(n,l,u){if(\"object\"==typeof u){var f=h(u);Object.defineProperty(n,l,{get:a(f),set:c(u),enumerable:!0,configurable:!1})}else s[u]?Object.defineProperty(n,l,{get:(p=u,new Function(\"gl\",\"wrapper\",\"locations\",\"return function(){return gl.getUniform(wrapper.program,locations[\"+p+\"])}\")(t,e,s)),set:c(u),enumerable:!0,configurable:!1}):n[l]=function(t){switch(t){case\"bool\":return!1;case\"int\":case\"sampler2D\":case\"samplerCube\":case\"float\":return 0;default:var e=t.indexOf(\"vec\");if(0<=e&&e<=1&&t.length===4+e){var r=t.charCodeAt(t.length-1)-48;if(r<2||r>4)throw new i(\"\",\"Invalid data type\");return\"b\"===t.charAt(0)?o(r,!1):o(r,0)}if(0===t.indexOf(\"mat\")&&4===t.length){var r=t.charCodeAt(t.length-1)-48;if(r<2||r>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+t);return o(r*r,0)}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+t)}}(r[u].type);var p}function h(t){var e;if(Array.isArray(t)){e=new Array(t.length);for(var r=0;r<t.length;++r)u(e,r,t[r])}else for(var n in e={},t)u(e,n,t[n]);return e}var f=n(r,!0);return{get:a(h(f)),set:c(f),enumerable:!0,configurable:!0}}},{\"./GLError\":302,\"./reflect\":305}],305:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r={},n=0;n<t.length;++n)for(var i=t[n].name,a=i.split(\".\"),o=r,s=0;s<a.length;++s){var l=a[s].split(\"[\");if(l.length>1){l[0]in o||(o[l[0]]=[]),o=o[l[0]];for(var c=1;c<l.length;++c){var u=parseInt(l[c]);c<l.length-1||s<a.length-1?(u in o||(c<l.length-1?o[u]=[]:o[u]={}),o=o[u]):o[u]=e?n:t[n].type}}else s<a.length-1?(l[0]in o||(o[l[0]]={}),o=o[l[0]]):o[l[0]]=e?n:t[n].type}return r}},{}],306:[function(t,e,r){\"use strict\";r.uniforms=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_UNIFORMS),n=[],i=0;i<r;++i){var o=t.getActiveUniform(e,i);if(o){var s=a(t,o.type);if(o.size>1)for(var l=0;l<o.size;++l)n.push({name:o.name.replace(\"[0]\",\"[\"+l+\"]\"),type:s});else n.push({name:o.name,type:s})}}return n},r.attributes=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_ATTRIBUTES),n=[],i=0;i<r;++i){var o=t.getActiveAttrib(e,i);o&&n.push({name:o.name,type:a(t,o.type)})}return n};var n={FLOAT:\"float\",FLOAT_VEC2:\"vec2\",FLOAT_VEC3:\"vec3\",FLOAT_VEC4:\"vec4\",INT:\"int\",INT_VEC2:\"ivec2\",INT_VEC3:\"ivec3\",INT_VEC4:\"ivec4\",BOOL:\"bool\",BOOL_VEC2:\"bvec2\",BOOL_VEC3:\"bvec3\",BOOL_VEC4:\"bvec4\",FLOAT_MAT2:\"mat2\",FLOAT_MAT3:\"mat3\",FLOAT_MAT4:\"mat4\",SAMPLER_2D:\"sampler2D\",SAMPLER_CUBE:\"samplerCube\"},i=null;function a(t,e){if(!i){var r=Object.keys(n);i={};for(var a=0;a<r.length;++a){var o=r[a];i[t[o]]=n[o]}}return i[e]}},{}],307:[function(t,e,r){\"use strict\";r.shader=function(t,e,r){return u(t).getShaderReference(e,r)},r.program=function(t,e,r,n,i){return u(t).getProgram(e,r,n,i)};var n=t(\"./GLError\"),i=t(\"gl-format-compiler-error\"),a=new(\"undefined\"==typeof WeakMap?t(\"weakmap-shim\"):WeakMap),o=0;function s(t,e,r,n,i,a,o){this.id=t,this.src=e,this.type=r,this.shader=n,this.count=a,this.programs=[],this.cache=o}function l(t){this.gl=t,this.shaders=[{},{}],this.programs={}}s.prototype.dispose=function(){if(0==--this.count){for(var t=this.cache,e=t.gl,r=this.programs,n=0,i=r.length;n<i;++n){var a=t.programs[r[n]];a&&(delete t.programs[n],e.deleteProgram(a))}e.deleteShader(this.shader),delete t.shaders[this.type===e.FRAGMENT_SHADER|0][this.src]}};var c=l.prototype;function u(t){var e=a.get(t);return e||(e=new l(t),a.set(t,e)),e}c.getShaderReference=function(t,e){var r=this.gl,a=this.shaders[t===r.FRAGMENT_SHADER|0],l=a[e];if(l&&r.isShader(l.shader))l.count+=1;else{var c=function(t,e,r){var a=t.createShader(e);if(t.shaderSource(a,r),t.compileShader(a),!t.getShaderParameter(a,t.COMPILE_STATUS)){var o=t.getShaderInfoLog(a);try{var s=i(o,r,e)}catch(t){throw console.warn(\"Failed to format compiler error: \"+t),new n(o,\"Error compiling shader:\\n\"+o)}throw new n(o,s.short,s.long)}return a}(r,t,e);l=a[e]=new s(o++,e,t,c,[],1,this)}return l},c.getProgram=function(t,e,r,i){var a=[t.id,e.id,r.join(\":\"),i.join(\":\")].join(\"@\"),o=this.programs[a];return o&&this.gl.isProgram(o)||(this.programs[a]=o=function(t,e,r,i,a){var o=t.createProgram();t.attachShader(o,e),t.attachShader(o,r);for(var s=0;s<i.length;++s)t.bindAttribLocation(o,a[s],i[s]);if(t.linkProgram(o),!t.getProgramParameter(o,t.LINK_STATUS)){var l=t.getProgramInfoLog(o);throw new n(l,\"Error linking program: \"+l)}return o}(this.gl,t.shader,e.shader,r,i),t.programs.push(a),e.programs.push(a)),o}},{\"./GLError\":302,\"gl-format-compiler-error\":250,\"weakmap-shim\":555}],308:[function(t,e,r){\"use strict\";function n(t){this.plot=t,this.enable=[!0,!0,!1,!1],this.width=[1,1,1,1],this.color=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.center=[1/0,1/0]}e.exports=function(t,e){var r=new n(t);return r.update(e),t.addOverlay(r),r};var i=n.prototype;i.update=function(t){t=t||{},this.enable=(t.enable||[!0,!0,!1,!1]).slice(),this.width=(t.width||[1,1,1,1]).slice(),this.color=(t.color||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]).map(function(t){return t.slice()}),this.center=(t.center||[1/0,1/0]).slice(),this.plot.setOverlayDirty()},i.draw=function(){var t=this.enable,e=this.width,r=this.color,n=this.center,i=this.plot,a=i.line,o=i.dataBox,s=i.viewBox;if(a.bind(),o[0]<=n[0]&&n[0]<=o[2]&&o[1]<=n[1]&&n[1]<=o[3]){var l=s[0]+(n[0]-o[0])/(o[2]-o[0])*(s[2]-s[0]),c=s[1]+(n[1]-o[1])/(o[3]-o[1])*(s[3]-s[1]);t[0]&&a.drawLine(l,c,s[0],c,e[0],r[0]),t[1]&&a.drawLine(l,c,l,s[1],e[1],r[1]),t[2]&&a.drawLine(l,c,s[2],c,e[2],r[2]),t[3]&&a.drawLine(l,c,l,s[3],e[3],r[3])}},i.dispose=function(){this.plot.removeOverlay(this)}},{}],309:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, color;\\nattribute float weight;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 coordinates[3];\\nuniform vec4 colors[3];\\nuniform vec2 screenShape;\\nuniform float lineWidth;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vertexPosition = mix(coordinates[0],\\n    mix(coordinates[2], coordinates[1], 0.5 * (position + 1.0)), abs(position));\\n\\n  vec4 clipPos = projection * view * model * vec4(vertexPosition, 1.0);\\n  vec2 clipOffset = (projection * view * model * vec4(color, 0.0)).xy;\\n  vec2 delta = weight * clipOffset * screenShape;\\n  vec2 lineOffset = normalize(vec2(delta.y, -delta.x)) / screenShape;\\n\\n  gl_Position   = vec4(clipPos.xy + clipPos.w * 0.5 * lineWidth * lineOffset, clipPos.z, clipPos.w);\\n  fragColor     = color.x * colors[0] + color.y * colors[1] + color.z * colors[2];\\n}\\n\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  gl_FragColor = fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec3\"},{name:\"weight\",type:\"float\"}])}},{\"gl-shader\":301,glslify:409}],310:[function(t,e,r){\"use strict\";var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\");e.exports=function(t,e){var r=[];function o(t,e,n,i,a,o){var s=[t,e,n,0,0,0,1];s[i+3]=1,s[i]=a,r.push.apply(r,s),s[6]=-1,r.push.apply(r,s),s[i]=o,r.push.apply(r,s),r.push.apply(r,s),s[6]=1,r.push.apply(r,s),s[i]=a,r.push.apply(r,s)}o(0,0,0,0,0,1),o(0,0,0,1,0,1),o(0,0,0,2,0,1),o(1,0,0,1,-1,1),o(1,0,0,2,-1,1),o(0,1,0,0,-1,1),o(0,1,0,2,-1,1),o(0,0,1,0,-1,1),o(0,0,1,1,-1,1);var l=n(t,r),c=i(t,[{type:t.FLOAT,buffer:l,size:3,offset:0,stride:28},{type:t.FLOAT,buffer:l,size:3,offset:12,stride:28},{type:t.FLOAT,buffer:l,size:1,offset:24,stride:28}]),u=a(t);u.attributes.position.location=0,u.attributes.color.location=1,u.attributes.weight.location=2;var h=new s(t,l,c,u);return h.update(e),h};var o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n,this.pixelRatio=1,this.bounds=[[-1e3,-1e3,-1e3],[1e3,1e3,1e3]],this.position=[0,0,0],this.lineWidth=[2,2,2],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.enabled=[!0,!0,!0],this.drawSides=[!0,!0,!0],this.axes=null}var l=s.prototype,c=[0,0,0],u=[0,0,0],h=[0,0];l.isTransparent=function(){return!1},l.drawTransparent=function(t){},l.draw=function(t){var e=this.gl,r=this.vao,n=this.shader;r.bind(),n.bind();var i,a=t.model||o,s=t.view||o,l=t.projection||o;this.axes&&(i=this.axes.lastCubeProps.axis);for(var f=c,p=u,d=0;d<3;++d)i&&i[d]<0?(f[d]=this.bounds[0][d],p[d]=this.bounds[1][d]):(f[d]=this.bounds[1][d],p[d]=this.bounds[0][d]);h[0]=e.drawingBufferWidth,h[1]=e.drawingBufferHeight,n.uniforms.model=a,n.uniforms.view=s,n.uniforms.projection=l,n.uniforms.coordinates=[this.position,f,p],n.uniforms.colors=this.colors,n.uniforms.screenShape=h;for(d=0;d<3;++d)n.uniforms.lineWidth=this.lineWidth[d]*this.pixelRatio,this.enabled[d]&&(r.draw(e.TRIANGLES,6,6*d),this.drawSides[d]&&r.draw(e.TRIANGLES,12,18+12*d));r.unbind()},l.update=function(t){t&&(\"bounds\"in t&&(this.bounds=t.bounds),\"position\"in t&&(this.position=t.position),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"colors\"in t&&(this.colors=t.colors),\"enabled\"in t&&(this.enabled=t.enabled),\"drawSides\"in t&&(this.drawSides=t.drawSides))},l.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders/index\":309,\"gl-buffer\":241,\"gl-vao\":327}],311:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\nuniform float vectorScale;\\nuniform float tubeScale;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * tubePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal,0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(tubePosition, 1.0);\\n  vec4 t_position  = view * tubePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = tubePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular\\n            , opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform float tubeScale;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  gl_Position = projection * view * tubePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec4\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec4\"}]}},{glslify:409}],312:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./shaders\"),g=d.meshShader,v=d.pickShader,m=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function y(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,y,x,b,_,w,k,T){this.gl=t,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=i,this.triangleVectors=a,this.triangleColors=s,this.triangleNormals=c,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=u,this.triangleCount=0,this.lineWidth=1,this.edgePositions=h,this.edgeColors=p,this.edgeUVs=d,this.edgeIds=f,this.edgeVAO=g,this.edgeCount=0,this.pointPositions=v,this.pointColors=x,this.pointUVs=b,this.pointSizes=_,this.pointIds=y,this.pointVAO=w,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=k,this.contourVAO=T,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!1,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.tubeScale=1,this._model=m,this._view=m,this._projection=m,this._resolution=[1,1],this.pixelRatio=1}var x=y.prototype;function b(t){var e=n(t,v.vertex,v.fragment,null,v.attributes);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.vector.location=5,e}x.isOpaque=function(){return this.opacity>=1},x.isTransparent=function(){return this.opacity<1},x.pickSlots=1,x.setPickBase=function(t){this.pickId=t},x.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=i[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},x.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=h({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return u(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,i=t.vectors;if(n&&r&&i){void 0!==t.tubeScale&&(this.tubeScale=t.tubeScale);var a=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[],w=[],k=[];this.cells=r,this.positions=n,this.vectors=i;var T=t.vertexNormals,A=t.cellNormals,M=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,S=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!A&&(A=s.faceNormals(r,n,S)),A||T||(T=s.vertexNormals(r,n,M));var E=t.vertexColors,C=t.cellColors,L=t.meshColor||[1,1,1,1],P=t.vertexUVs,O=t.vertexIntensity,z=t.cellUVs,I=t.cellIntensity,D=1/0,R=-1/0;if(!P&&!z)if(O)if(t.vertexIntensityBounds)D=+t.vertexIntensityBounds[0],R=+t.vertexIntensityBounds[1];else for(var F=0;F<O.length;++F){var B=O[F];D=Math.min(D,B),R=Math.max(R,B)}else if(I)for(F=0;F<I.length;++F){B=I[F];D=Math.min(D,B),R=Math.max(R,B)}else for(F=0;F<n.length;++F){B=n[F][2];D=Math.min(D,B),R=Math.max(R,B)}this.intensity=O||(I?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,I):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var N=t.pointSizes,j=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(F=0;F<n.length;++F)for(var U=n[F],V=0;V<3;++V)!isNaN(U[V])&&isFinite(U[V])&&(this.bounds[0][V]=Math.min(this.bounds[0][V],U[V]),this.bounds[1][V]=Math.max(this.bounds[1][V],U[V]));var q=0,H=0,G=0;t:for(F=0;F<r.length;++F){var Y=r[F];switch(Y.length){case 1:for(U=n[X=Y[0]],V=0;V<3;++V)if(isNaN(U[V])||!isFinite(U[V]))continue t;x.push(U[0],U[1],U[2],U[3]),3===(Z=E?E[X]:C?C[F]:L).length?b.push(Z[0],Z[1],Z[2],1):b.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],_.push(J[0],J[1]),N?w.push(N[X]):w.push(j),k.push(F),G+=1;break;case 2:for(V=0;V<2;++V){U=n[X=Y[V]];for(var W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t}for(V=0;V<2;++V){U=n[X=Y[V]];g.push(U[0],U[1],U[2]),3===(Z=E?E[X]:C?C[F]:L).length?v.push(Z[0],Z[1],Z[2],1):v.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],m.push(J[0],J[1]),y.push(F)}H+=1;break;case 3:for(V=0;V<3;++V)for(U=n[X=Y[V]],W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t;for(V=0;V<3;++V){var X;U=n[X=Y[2-V]];a.push(U[0],U[1],U[2],U[3]);var Z,J,K,$=i[X];l.push($[0],$[1],$[2],$[3]),3===(Z=E?E[X]:C?C[F]:L).length?c.push(Z[0],Z[1],Z[2],1):c.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],p.push(J[0],J[1]),K=T?T[X]:A[F],f.push(K[0],K[1],K[2]),d.push(F)}q+=1}}this.pointCount=G,this.edgeCount=H,this.triangleCount=q,this.pointPositions.update(x),this.pointColors.update(b),this.pointUVs.update(_),this.pointSizes.update(w),this.pointIds.update(new Uint32Array(k)),this.edgePositions.update(g),this.edgeColors.update(v),this.edgeUVs.update(m),this.edgeIds.update(new Uint32Array(y)),this.trianglePositions.update(a),this.triangleVectors.update(l),this.triangleColors.update(c),this.triangleUVs.update(p),this.triangleNormals.update(f),this.triangleIds.update(new Uint32Array(d))}},x.drawTransparent=x.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:m.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,tubeScale:this.tubeScale,contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var f=u[12+o],p=0;p<3;++p)f+=u[4*p+o]*this.lightPosition[p];s.lightPosition[o]=f/h}if(this.triangleCount>0){var d=this.triShader;d.bind(),d.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},x.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:i,clipBounds:a,tubeScale:this.tubeScale,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind())},x.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3);return{index:e,position:n,intensity:this.intensity[r[1]],velocity:this.vectors[r[1]].slice(0,3),divergence:this.vectors[r[1]][3],dataCoordinate:n}},x.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose()},e.exports=function(t,e){1===arguments.length&&(t=(e=t).gl);var r=e.triShader||function(t){var e=n(t,g.vertex,g.fragment,null,g.attributes);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.vector.location=5,e}(t),s=b(t),l=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));l.generateMipmap(),l.minFilter=t.LINEAR_MIPMAP_LINEAR,l.magFilter=t.LINEAR;var c=i(t),h=i(t),f=i(t),p=i(t),d=i(t),v=i(t),m=a(t,[{buffer:c,type:t.FLOAT,size:4},{buffer:v,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:f,type:t.FLOAT,size:4},{buffer:p,type:t.FLOAT,size:2},{buffer:d,type:t.FLOAT,size:3},{buffer:h,type:t.FLOAT,size:4}]),x=i(t),_=i(t),w=i(t),k=i(t),T=a(t,[{buffer:x,type:t.FLOAT,size:3},{buffer:k,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:_,type:t.FLOAT,size:4},{buffer:w,type:t.FLOAT,size:2}]),A=i(t),M=i(t),S=i(t),E=i(t),C=i(t),L=a(t,[{buffer:A,type:t.FLOAT,size:3},{buffer:C,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:M,type:t.FLOAT,size:4},{buffer:S,type:t.FLOAT,size:2},{buffer:E,type:t.FLOAT,size:1}]),P=i(t),O=new y(t,l,r,s,c,h,v,f,p,d,m,x,k,_,w,T,A,C,M,S,E,L,P,a(t,[{buffer:P,type:t.FLOAT,size:3}]));return O.update(e),O}},{\"./shaders\":311,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-shader\":301,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,normals:453,\"simplicial-complex-contour\":518,\"typedarray-pool\":545}],313:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\"),i=t(\"gl-vec4\"),a=function(t,e,r,a){for(var o=0,s=0;s<t.length;s++)for(var l=t[s].velocities,c=0;c<l.length;c++){var u=n.length(l[c]);u>o&&(o=u)}var h=t.map(function(t){return function(t,e,r,a){var o,s,l,c=t.points,u=t.velocities,h=t.divergences;n.set(n.create(),0,1,0),n.create(),n.create();n.create();for(var f=[],p=[],d=[],g=[],v=[],m=[],y=0,x=0,b=i.create(),_=i.create(),w=0;w<c.length;w++){o=c[w],s=u[w],l=h[w],0===e&&(l=.05*r),x=n.length(s)/a,b=i.create(),n.copy(b,s),b[3]=l;for(var k=0;k<8;k++)v[k]=[o[0],o[1],o[2],k];if(g.length>0)for(k=0;k<8;k++){var T=(k+1)%8;f.push(g[k],v[k],v[T],v[T],g[T],g[k]),d.push(_,b,b,b,_,_),m.push(y,x,x,x,y,y),p.push([f.length-6,f.length-5,f.length-4],[f.length-3,f.length-2,f.length-1])}var A=g;g=v,v=A,A=_,_=b,b=A,A=y,y=x,x=A}return{positions:f,cells:p,vectors:d,vertexIntensity:m}}(t,r,a,o)}),f=[],p=[],d=[],g=[];for(s=0;s<h.length;s++){var v=h[s],m=f.length;f=f.concat(v.positions),d=d.concat(v.vectors),g=g.concat(v.vertexIntensity);for(c=0;c<v.cells.length;c++){var y=v.cells[c],x=[];p.push(x);for(var b=0;b<y.length;b++)x.push(y[b]+m)}}return{positions:f,cells:p,vectors:d,vertexIntensity:g,colormap:e}},o=function(t,e){var r=n.create(),i=1e-4;n.add(r,t,[i,0,0]);var a=this.getVelocity(r);n.subtract(a,a,e),n.scale(a,a,1e4),n.add(r,t,[0,i,0]);var o=this.getVelocity(r);n.subtract(o,o,e),n.scale(o,o,1e4),n.add(r,t,[0,0,i]);var s=this.getVelocity(r);return n.subtract(s,s,e),n.scale(s,s,1e4),n.add(r,a,o),n.add(r,r,s),r},s=function(t){return f(t,this.vectors,this.meshgrid,this.clampBorders)},l=function(t,e){for(var r=0;r<t.length;r++){var n=t[r];if(n===e)return r;if(n>e)return r-1}return r},c=n.create(),u=n.create(),h=function(t,e,r){return t<e?e:t>r?r:t},f=function(t,e,r,i){var a=t[0],o=t[1],s=t[2],f=r[0].length,p=r[1].length,d=r[2].length,g=l(r[0],a),v=l(r[1],o),m=l(r[2],s),y=g+1,x=v+1,b=m+1;if(r[0][g]===a&&(y=g),r[1][v]===o&&(x=v),r[2][m]===s&&(b=m),i&&(g=h(g,0,f-1),y=h(y,0,f-1),v=h(v,0,p-1),x=h(x,0,p-1),m=h(m,0,d-1),b=h(b,0,d-1)),g<0||v<0||m<0||y>=f||x>=p||b>=d)return n.create();var _=(a-r[0][g])/(r[0][y]-r[0][g]),w=(o-r[1][v])/(r[1][x]-r[1][v]),k=(s-r[2][m])/(r[2][b]-r[2][m]);(_<0||_>1||isNaN(_))&&(_=0),(w<0||w>1||isNaN(w))&&(w=0),(k<0||k>1||isNaN(k))&&(k=0);var T=m*f*p,A=b*f*p,M=v*f,S=x*f,E=g,C=y,L=e[M+T+E],P=e[M+T+C],O=e[S+T+E],z=e[S+T+C],I=e[M+A+E],D=e[M+A+C],R=e[S+A+E],F=e[S+A+C],B=n.create();return n.lerp(B,L,P,_),n.lerp(c,O,z,_),n.lerp(B,B,c,w),n.lerp(c,I,D,_),n.lerp(u,R,F,_),n.lerp(c,c,u,w),n.lerp(B,B,c,k),B},p=function(t){var e=1/0;t.sort(function(t,e){return t-e});for(var r=1;r<t.length;r++){var n=Math.abs(t[r]-t[r-1]);n<e&&(e=n)}return e};e.exports=function(t,e){var r=t.startingPositions,i=t.maxLength||1e3,l=t.tubeSize||1,c=t.absoluteTubeSize;t.getDivergence||(t.getDivergence=o),t.getVelocity||(t.getVelocity=s),void 0===t.clampBorders&&(t.clampBorders=!0);var u=[],h=e[0][0],f=e[0][1],d=e[0][2],g=e[1][0],v=e[1][1],m=e[1][2],y=function(t,e){var r=e[0],n=e[1],i=e[2];return r>=h&&r<=g&&n>=f&&n<=v&&i>=d&&i<=m},x=10*n.distance(e[0],e[1])/i,b=x*x,_=1,w=0;n.create();r.length>=2&&(_=function(t){for(var e=[],r=[],n=[],i={},a={},o={},s=0;s<t.length;s++){var l=t[s],c=l[0],u=l[1],h=l[2];i[c]||(e.push(c),i[c]=!0),a[u]||(r.push(u),a[u]=!0),o[h]||(n.push(h),o[h]=!0)}var f=p(e),d=p(r),g=p(n),v=Math.min(f,d,g);return isFinite(v)?v:1}(r));for(var k=0;k<r.length;k++){var T=n.create();n.copy(T,r[k]);var A=[T],M=[],S=t.getVelocity(T),E=T;M.push(S);var C=[],L=t.getDivergence(T,S);(I=n.length(L))>w&&!isNaN(I)&&isFinite(I)&&(w=I),C.push(I),u.push({points:A,velocities:M,divergences:C});for(var P=0;P<100*i&&A.length<i&&y(0,T);){P++;var O=n.clone(S),z=n.squaredLength(O);if(0===z)break;if(z>b&&n.scale(O,O,x/Math.sqrt(z)),n.add(O,O,T),S=t.getVelocity(O),n.squaredDistance(E,O)-b>-1e-4*b){A.push(O),E=O,M.push(S);L=t.getDivergence(O,S);(I=n.length(L))>w&&!isNaN(I)&&isFinite(I)&&(w=I),C.push(I)}T=O}}for(k=0;k<C.length;k++){var I=C[k];!isNaN(I)&&isFinite(I)||(C[k]=w)}var D=a(u,t.colormap,w,_);return c?D.tubeScale=c:(0===w&&(w=1),D.tubeScale=.5*l*_/w),D},e.exports.createTubeMesh=t(\"./lib/tubemesh\")},{\"./lib/tubemesh\":312,\"gl-vec3\":346,\"gl-vec4\":382}],314:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute vec3 f;\\nattribute vec3 normal;\\n\\nuniform vec3 objectOffset;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 lightPosition, eyePosition;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 localCoordinate = vec3(uv.zw, f.x);\\n  worldCoordinate = objectOffset + localCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n  vec4 clipPosition = projection * view * worldPosition;\\n  gl_Position = clipPosition;\\n  kill = f.y;\\n  value = f.z;\\n  planeCoordinate = uv.xy;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * worldPosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  lightDirection = lightPosition - cameraCoordinate.xyz;\\n  eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  surfaceNormal  = normalize((vec4(normal,0) * inverseModel).xyz);\\n}\\n\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat beckmannSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness) {\\n  return beckmannDistribution(dot(surfaceNormal, normalize(lightDirection + viewDirection)), roughness);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 lowerBound, upperBound;\\nuniform float contourTint;\\nuniform vec4 contourColor;\\nuniform sampler2D colormap;\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform float vertexColor;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec3 N = normalize(surfaceNormal);\\n  vec3 V = normalize(eyeDirection);\\n  vec3 L = normalize(lightDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = max(beckmannSpecular(L, V, N, roughness), 0.);\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  //decide how to interpolate color \\u2014 in vertex or in fragment\\n  vec4 surfaceColor =\\n    step(vertexColor, .5) * texture2D(colormap, vec2(value, value)) +\\n    step(.5, vertexColor) * vColor;\\n\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = mix(litColor, contourColor, contourTint) * opacity;\\n}\\n\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute float f;\\n\\nuniform vec3 objectOffset;\\nuniform mat3 permutation;\\nuniform mat4 model, view, projection;\\nuniform float height, zOffset;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 dataCoordinate = permutation * vec3(uv.xy, height);\\n  worldCoordinate = objectOffset + dataCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n\\n  vec4 clipPosition = projection * view * worldPosition;\\n  clipPosition.z += zOffset;\\n\\n  gl_Position = clipPosition;\\n  value = f + objectOffset.z;\\n  kill = -1.0;\\n  planeCoordinate = uv.zw;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Don't do lighting for contours\\n  surfaceNormal   = vec3(1,0,0);\\n  eyeDirection    = vec3(0,1,0);\\n  lightDirection  = vec3(0,0,1);\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec2 shape;\\nuniform vec3 clipBounds[2];\\nuniform float pickId;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 surfaceNormal;\\n\\nvec2 splitFloat(float v) {\\n  float vh = 255.0 * v;\\n  float upper = floor(vh);\\n  float lower = fract(vh);\\n  return vec2(upper / 255.0, floor(lower * 16.0) / 16.0);\\n}\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec2 ux = splitFloat(planeCoordinate.x / shape.x);\\n  vec2 uy = splitFloat(planeCoordinate.y / shape.y);\\n  gl_FragColor = vec4(pickId, ux.x, uy.x, ux.y + (uy.y/16.0));\\n}\\n\"]);r.createShader=function(t){var e=n(t,a,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createPickShader=function(t){var e=n(t,a,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createContourShader=function(t){var e=n(t,s,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e},r.createPickContourShader=function(t){var e=n(t,s,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e}},{\"gl-shader\":301,glslify:409}],315:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],316:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=y(e),n=b(e),s=x(e),l=_(e),c=i(e),u=a(e,[{buffer:c,size:4,stride:w,offset:0},{buffer:c,size:3,stride:w,offset:16},{buffer:c,size:3,stride:w,offset:28}]),h=i(e),f=a(e,[{buffer:h,size:4,stride:20,offset:0},{buffer:h,size:1,stride:20,offset:16}]),p=i(e),d=a(e,[{buffer:p,size:2,type:e.FLOAT}]),g=o(e,1,S,e.RGBA,e.UNSIGNED_BYTE);g.minFilter=e.LINEAR,g.magFilter=e.LINEAR;var v=new E(e,[0,0],[[0,0,0],[0,0,0]],r,n,c,u,g,s,l,h,f,p,d,[0,0,0]),m={levels:[[],[],[]]};for(var k in t)m[k]=t[k];return m.colormap=m.colormap||\"jet\",v.update(m),v};var n=t(\"bit-twiddle\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"typedarray-pool\"),l=t(\"colormap\"),c=t(\"ndarray-ops\"),u=t(\"ndarray-pack\"),h=t(\"ndarray\"),f=t(\"surface-nets\"),p=t(\"gl-mat4/multiply\"),d=t(\"gl-mat4/invert\"),g=t(\"binary-search-bounds\"),v=t(\"ndarray-gradient\"),m=t(\"./lib/shaders\"),y=m.createShader,x=m.createContourShader,b=m.createPickShader,_=m.createPickContourShader,w=40,k=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1],T=[[0,0],[0,1],[1,0],[1,1],[1,0],[0,1]],A=[[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0]];function M(t,e,r,n,i){this.position=t,this.index=e,this.uv=r,this.level=n,this.dataCoordinate=i}!function(){for(var t=0;t<3;++t){var e=A[t],r=(t+2)%3;e[(t+1)%3+0]=1,e[r+3]=1,e[t+6]=1}}();var S=256;function E(t,e,r,n,i,a,o,l,c,u,f,p,d,g,v){this.gl=t,this.shape=e,this.bounds=r,this.objectOffset=v,this.intensityBounds=[],this._shader=n,this._pickShader=i,this._coordinateBuffer=a,this._vao=o,this._colorMap=l,this._contourShader=c,this._contourPickShader=u,this._contourBuffer=f,this._contourVAO=p,this._contourOffsets=[[],[],[]],this._contourCounts=[[],[],[]],this._vertexCount=0,this._pickResult=new M([0,0,0],[0,0],[0,0],[0,0,0],[0,0,0]),this._dynamicBuffer=d,this._dynamicVAO=g,this._dynamicOffsets=[0,0,0],this._dynamicCounts=[0,0,0],this.contourWidth=[1,1,1],this.contourLevels=[[1],[1],[1]],this.contourTint=[0,0,0],this.contourColor=[[.5,.5,.5,1],[.5,.5,.5,1],[.5,.5,.5,1]],this.showContour=!0,this.showSurface=!0,this.enableHighlight=[!0,!0,!0],this.highlightColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.highlightTint=[1,1,1],this.highlightLevel=[-1,-1,-1],this.enableDynamic=[!0,!0,!0],this.dynamicLevel=[NaN,NaN,NaN],this.dynamicColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.dynamicTint=[1,1,1],this.dynamicWidth=[1,1,1],this.axesBounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.surfaceProject=[!1,!1,!1],this.contourProject=[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],this.colorBounds=[!1,!1],this._field=[h(s.mallocFloat(1024),[0,0]),h(s.mallocFloat(1024),[0,0]),h(s.mallocFloat(1024),[0,0])],this.pickId=1,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.snapToData=!1,this.pixelRatio=1,this.opacity=1,this.lightPosition=[10,1e4,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.vertexColor=0,this.dirty=!0}var C=E.prototype;C.isTransparent=function(){return this.opacity<1},C.isOpaque=function(){if(this.opacity>=1)return!0;for(var t=0;t<3;++t)if(this._contourCounts[t].length>0||this._dynamicCounts[t]>0)return!0;return!1},C.pickSlots=1,C.setPickBase=function(t){this.pickId=t};var L=[0,0,0],P={showSurface:!1,showContour:!1,projections:[k.slice(),k.slice(),k.slice()],clipBounds:[[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]]]};function O(t,e){var r,n,i,a=e.axes&&e.axes.lastCubeProps.axis||L,o=e.showSurface,s=e.showContour;for(r=0;r<3;++r)for(o=o||e.surfaceProject[r],n=0;n<3;++n)s=s||e.contourProject[r][n];for(r=0;r<3;++r){var l=P.projections[r];for(n=0;n<16;++n)l[n]=0;for(n=0;n<4;++n)l[5*n]=1;l[5*r]=0,l[12+r]=e.axesBounds[+(a[r]>0)][r],p(l,t.model,l);var c=P.clipBounds[r];for(i=0;i<2;++i)for(n=0;n<3;++n)c[i][n]=t.clipBounds[i][n];c[0][r]=-1e8,c[1][r]=1e8}return P.showSurface=o,P.showContour=s,P}var z={model:k,view:k,projection:k,inverseModel:k.slice(),lowerBound:[0,0,0],upperBound:[0,0,0],colorMap:0,clipBounds:[[0,0,0],[0,0,0]],height:0,contourTint:0,contourColor:[0,0,0,1],permutation:[1,0,0,0,1,0,0,0,1],zOffset:-1e-4,objectOffset:[0,0,0],kambient:1,kdiffuse:1,kspecular:1,lightPosition:[1e3,1e3,1e3],eyePosition:[0,0,0],roughness:1,fresnel:1,opacity:1,vertexColor:0},I=k.slice(),D=[1,0,0,0,1,0,0,0,1];function R(t,e){t=t||{};var r=this.gl;r.disable(r.CULL_FACE),this._colorMap.bind(0);var n=z;n.model=t.model||k,n.view=t.view||k,n.projection=t.projection||k,n.lowerBound=[this.bounds[0][0],this.bounds[0][1],this.colorBounds[0]||this.bounds[0][2]],n.upperBound=[this.bounds[1][0],this.bounds[1][1],this.colorBounds[1]||this.bounds[1][2]],n.objectOffset=this.objectOffset,n.contourColor=this.contourColor[0],n.inverseModel=d(n.inverseModel,n.model);for(var i=0;i<2;++i)for(var a=n.clipBounds[i],o=0;o<3;++o)a[o]=Math.min(Math.max(this.clipBounds[i][o],-1e8),1e8);n.kambient=this.ambientLight,n.kdiffuse=this.diffuseLight,n.kspecular=this.specularLight,n.roughness=this.roughness,n.fresnel=this.fresnel,n.opacity=this.opacity,n.height=0,n.permutation=D,n.vertexColor=this.vertexColor;var s=I;for(p(s,n.view,n.model),p(s,n.projection,s),d(s,s),i=0;i<3;++i)n.eyePosition[i]=s[12+i]/s[15];var l=s[15];for(i=0;i<3;++i)l+=this.lightPosition[i]*s[4*i+3];for(i=0;i<3;++i){var c=s[12+i];for(o=0;o<3;++o)c+=s[4*o+i]*this.lightPosition[o];n.lightPosition[i]=c/l}var u=O(n,this);if(u.showSurface&&e===this.opacity<1){for(this._shader.bind(),this._shader.uniforms=n,this._vao.bind(),this.showSurface&&this._vertexCount&&this._vao.draw(r.TRIANGLES,this._vertexCount),i=0;i<3;++i)this.surfaceProject[i]&&this.vertexCount&&(this._shader.uniforms.model=u.projections[i],this._shader.uniforms.clipBounds=u.clipBounds[i],this._vao.draw(r.TRIANGLES,this._vertexCount));this._vao.unbind()}if(u.showContour&&!e){var h=this._contourShader;n.kambient=1,n.kdiffuse=0,n.kspecular=0,n.opacity=1,h.bind(),h.uniforms=n;var f=this._contourVAO;for(f.bind(),i=0;i<3;++i)for(h.uniforms.permutation=A[i],r.lineWidth(this.contourWidth[i]*this.pixelRatio),o=0;o<this.contourLevels[i].length;++o)o===this.highlightLevel[i]?(h.uniforms.contourColor=this.highlightColor[i],h.uniforms.contourTint=this.highlightTint[i]):0!==o&&o-1!==this.highlightLevel[i]||(h.uniforms.contourColor=this.contourColor[i],h.uniforms.contourTint=this.contourTint[i]),this._contourCounts[i][o]&&(h.uniforms.height=this.contourLevels[i][o],f.draw(r.LINES,this._contourCounts[i][o],this._contourOffsets[i][o]));for(i=0;i<3;++i)for(h.uniforms.model=u.projections[i],h.uniforms.clipBounds=u.clipBounds[i],o=0;o<3;++o)if(this.contourProject[i][o]){h.uniforms.permutation=A[o],r.lineWidth(this.contourWidth[o]*this.pixelRatio);for(var g=0;g<this.contourLevels[o].length;++g)g===this.highlightLevel[o]?(h.uniforms.contourColor=this.highlightColor[o],h.uniforms.contourTint=this.highlightTint[o]):0!==g&&g-1!==this.highlightLevel[o]||(h.uniforms.contourColor=this.contourColor[o],h.uniforms.contourTint=this.contourTint[o]),this._contourCounts[o][g]&&(h.uniforms.height=this.contourLevels[o][g],f.draw(r.LINES,this._contourCounts[o][g],this._contourOffsets[o][g]))}for(f.unbind(),(f=this._dynamicVAO).bind(),i=0;i<3;++i)if(0!==this._dynamicCounts[i])for(h.uniforms.model=n.model,h.uniforms.clipBounds=n.clipBounds,h.uniforms.permutation=A[i],r.lineWidth(this.dynamicWidth[i]*this.pixelRatio),h.uniforms.contourColor=this.dynamicColor[i],h.uniforms.contourTint=this.dynamicTint[i],h.uniforms.height=this.dynamicLevel[i],f.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]),o=0;o<3;++o)this.contourProject[o][i]&&(h.uniforms.model=u.projections[o],h.uniforms.clipBounds=u.clipBounds[o],f.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]));f.unbind()}}C.draw=function(t){return R.call(this,t,!1)},C.drawTransparent=function(t){return R.call(this,t,!0)};var F={model:k,view:k,projection:k,inverseModel:k,clipBounds:[[0,0,0],[0,0,0]],height:0,shape:[0,0],pickId:0,lowerBound:[0,0,0],upperBound:[0,0,0],zOffset:0,objectOffset:[0,0,0],permutation:[1,0,0,0,1,0,0,0,1],lightPosition:[0,0,0],eyePosition:[0,0,0]};function B(t,e){return Array.isArray(t)?[e(t[0]),e(t[1]),e(t[2])]:[e(t),e(t),e(t)]}function N(t){return Array.isArray(t)?3===t.length?[t[0],t[1],t[2],1]:[t[0],t[1],t[2],t[3]]:[0,0,0,1]}function j(t){if(Array.isArray(t)){if(Array.isArray(t))return[N(t[0]),N(t[1]),N(t[2])];var e=N(t);return[e.slice(),e.slice(),e.slice()]}}C.drawPick=function(t){t=t||{};var e=this.gl;e.disable(e.CULL_FACE);var r=F;r.model=t.model||k,r.view=t.view||k,r.projection=t.projection||k,r.shape=this._field[2].shape,r.pickId=this.pickId/255,r.lowerBound=this.bounds[0],r.upperBound=this.bounds[1],r.objectOffset=this.objectOffset,r.permutation=D;for(var n=0;n<2;++n)for(var i=r.clipBounds[n],a=0;a<3;++a)i[a]=Math.min(Math.max(this.clipBounds[n][a],-1e8),1e8);var o=O(r,this);if(o.showSurface){for(this._pickShader.bind(),this._pickShader.uniforms=r,this._vao.bind(),this._vao.draw(e.TRIANGLES,this._vertexCount),n=0;n<3;++n)this.surfaceProject[n]&&(this._pickShader.uniforms.model=o.projections[n],this._pickShader.uniforms.clipBounds=o.clipBounds[n],this._vao.draw(e.TRIANGLES,this._vertexCount));this._vao.unbind()}if(o.showContour){var s=this._contourPickShader;s.bind(),s.uniforms=r;var l=this._contourVAO;for(l.bind(),a=0;a<3;++a)for(e.lineWidth(this.contourWidth[a]*this.pixelRatio),s.uniforms.permutation=A[a],n=0;n<this.contourLevels[a].length;++n)this._contourCounts[a][n]&&(s.uniforms.height=this.contourLevels[a][n],l.draw(e.LINES,this._contourCounts[a][n],this._contourOffsets[a][n]));for(n=0;n<3;++n)for(s.uniforms.model=o.projections[n],s.uniforms.clipBounds=o.clipBounds[n],a=0;a<3;++a)if(this.contourProject[n][a]){s.uniforms.permutation=A[a],e.lineWidth(this.contourWidth[a]*this.pixelRatio);for(var c=0;c<this.contourLevels[a].length;++c)this._contourCounts[a][c]&&(s.uniforms.height=this.contourLevels[a][c],l.draw(e.LINES,this._contourCounts[a][c],this._contourOffsets[a][c]))}l.unbind()}},C.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=this._field[2].shape,r=this._pickResult,n=e[0]*(t.value[0]+(t.value[2]>>4)/16)/255,i=Math.floor(n),a=n-i,o=e[1]*(t.value[1]+(15&t.value[2])/16)/255,s=Math.floor(o),l=o-s;i+=1,s+=1;var c=r.position;c[0]=c[1]=c[2]=0;for(var u=0;u<2;++u)for(var h=u?a:1-a,f=0;f<2;++f)for(var p=i+u,d=s+f,v=h*(f?l:1-l),m=0;m<3;++m)c[m]+=this._field[m].get(p,d)*v;for(var y=this._pickResult.level,x=0;x<3;++x)if(y[x]=g.le(this.contourLevels[x],c[x]),y[x]<0)this.contourLevels[x].length>0&&(y[x]=0);else if(y[x]<this.contourLevels[x].length-1){var b=this.contourLevels[x][y[x]],_=this.contourLevels[x][y[x]+1];Math.abs(b-c[x])>Math.abs(_-c[x])&&(y[x]+=1)}for(r.index[0]=a<.5?i:i+1,r.index[1]=l<.5?s:s+1,r.uv[0]=n/e[0],r.uv[1]=o/e[1],m=0;m<3;++m)r.dataCoordinate[m]=this._field[m].get(r.index[0],r.index[1]);return r},C.padField=function(t,e){var r=e.shape.slice(),n=t.shape.slice();c.assign(t.lo(1,1).hi(r[0],r[1]),e),c.assign(t.lo(1).hi(r[0],1),e.hi(r[0],1)),c.assign(t.lo(1,n[1]-1).hi(r[0],1),e.lo(0,r[1]-1).hi(r[0],1)),c.assign(t.lo(0,1).hi(1,r[1]),e.hi(1)),c.assign(t.lo(n[0]-1,1).hi(1,r[1]),e.lo(r[0]-1)),t.set(0,0,e.get(0,0)),t.set(0,n[1]-1,e.get(0,r[1]-1)),t.set(n[0]-1,0,e.get(r[0]-1,0)),t.set(n[0]-1,n[1]-1,e.get(r[0]-1,r[1]-1))},C.update=function(t){t=t||{},this.objectOffset=t.objectOffset||this.objectOffset,this.dirty=!0,\"contourWidth\"in t&&(this.contourWidth=B(t.contourWidth,Number)),\"showContour\"in t&&(this.showContour=B(t.showContour,Boolean)),\"showSurface\"in t&&(this.showSurface=!!t.showSurface),\"contourTint\"in t&&(this.contourTint=B(t.contourTint,Boolean)),\"contourColor\"in t&&(this.contourColor=j(t.contourColor)),\"contourProject\"in t&&(this.contourProject=B(t.contourProject,function(t){return B(t,Boolean)})),\"surfaceProject\"in t&&(this.surfaceProject=t.surfaceProject),\"dynamicColor\"in t&&(this.dynamicColor=j(t.dynamicColor)),\"dynamicTint\"in t&&(this.dynamicTint=B(t.dynamicTint,Number)),\"dynamicWidth\"in t&&(this.dynamicWidth=B(t.dynamicWidth,Number)),\"opacity\"in t&&(this.opacity=t.opacity),\"colorBounds\"in t&&(this.colorBounds=t.colorBounds),\"vertexColor\"in t&&(this.vertexColor=t.vertexColor?1:0);var e=t.field||t.coords&&t.coords[2]||null,r=!1;if(e||(e=this._field[2].shape[0]||this._field[2].shape[2]?this._field[2].lo(1,1).hi(this._field[2].shape[0]-2,this._field[2].shape[1]-2):this._field[2].hi(0,0)),\"field\"in t||\"coords\"in t){var i=(e.shape[0]+2)*(e.shape[1]+2);i>this._field[2].data.length&&(s.freeFloat(this._field[2].data),this._field[2].data=s.mallocFloat(n.nextPow2(i))),this._field[2]=h(this._field[2].data,[e.shape[0]+2,e.shape[1]+2]),this.padField(this._field[2],e),this.shape=e.shape.slice();for(var a=this.shape,o=0;o<2;++o)this._field[2].size>this._field[o].data.length&&(s.freeFloat(this._field[o].data),this._field[o].data=s.mallocFloat(this._field[2].size)),this._field[o]=h(this._field[o].data,[a[0]+2,a[1]+2]);if(t.coords){var p=t.coords;if(!Array.isArray(p)||3!==p.length)throw new Error(\"gl-surface: invalid coordinates for x/y\");for(o=0;o<2;++o){var d=p[o];for(b=0;b<2;++b)if(d.shape[b]!==a[b])throw new Error(\"gl-surface: coords have incorrect shape\");this.padField(this._field[o],d)}}else if(t.ticks){var g=t.ticks;if(!Array.isArray(g)||2!==g.length)throw new Error(\"gl-surface: invalid ticks\");for(o=0;o<2;++o){var m=g[o];if((Array.isArray(m)||m.length)&&(m=h(m)),m.shape[0]!==a[o])throw new Error(\"gl-surface: invalid tick length\");var y=h(m.data,a);y.stride[o]=m.stride[0],y.stride[1^o]=0,this.padField(this._field[o],y)}}else{for(o=0;o<2;++o){var x=[0,0];x[o]=1,this._field[o]=h(this._field[o].data,[a[0]+2,a[1]+2],x,0)}this._field[0].set(0,0,0);for(var b=0;b<a[0];++b)this._field[0].set(b+1,0,b);for(this._field[0].set(a[0]+1,0,a[0]-1),this._field[1].set(0,0,0),b=0;b<a[1];++b)this._field[1].set(0,b+1,b);this._field[1].set(0,a[1]+1,a[1]-1)}var _=this._field,w=h(s.mallocFloat(3*_[2].size*2),[3,a[0]+2,a[1]+2,2]);for(o=0;o<3;++o)v(w.pick(o),_[o],\"mirror\");var k=h(s.mallocFloat(3*_[2].size),[a[0]+2,a[1]+2,3]);for(o=0;o<a[0]+2;++o)for(b=0;b<a[1]+2;++b){var A=w.get(0,o,b,0),M=w.get(0,o,b,1),E=w.get(1,o,b,0),C=w.get(1,o,b,1),L=w.get(2,o,b,0),P=w.get(2,o,b,1),O=E*P-C*L,z=L*M-P*A,I=A*C-M*E,D=Math.sqrt(O*O+z*z+I*I);D<1e-8?(D=Math.max(Math.abs(O),Math.abs(z),Math.abs(I)))<1e-8?(I=1,z=O=0,D=1):D=1/D:D=1/Math.sqrt(D),k.set(o,b,0,O*D),k.set(o,b,1,z*D),k.set(o,b,2,I*D)}s.free(w.data);var R=[1/0,1/0,1/0],F=[-1/0,-1/0,-1/0],N=1/0,U=-1/0,V=(a[0]-1)*(a[1]-1)*6,q=s.mallocFloat(n.nextPow2(10*V)),H=0,G=0;for(o=0;o<a[0]-1;++o)t:for(b=0;b<a[1]-1;++b){for(var Y=0;Y<2;++Y)for(var W=0;W<2;++W)for(var X=0;X<3;++X){var Z=this._field[X].get(1+o+Y,1+b+W);if(isNaN(Z)||!isFinite(Z))continue t}for(X=0;X<6;++X){var J=o+T[X][0],K=b+T[X][1],$=this._field[0].get(J+1,K+1),Q=this._field[1].get(J+1,K+1);Z=this._field[2].get(J+1,K+1),O=k.get(J+1,K+1,0),z=k.get(J+1,K+1,1),I=k.get(J+1,K+1,2),t.intensity&&(tt=t.intensity.get(J,K));var tt=t.intensity?t.intensity.get(J,K):Z+this.objectOffset[2];q[H++]=J,q[H++]=K,q[H++]=$,q[H++]=Q,q[H++]=Z,q[H++]=0,q[H++]=tt,q[H++]=O,q[H++]=z,q[H++]=I,R[0]=Math.min(R[0],$+this.objectOffset[0]),R[1]=Math.min(R[1],Q+this.objectOffset[1]),R[2]=Math.min(R[2],Z+this.objectOffset[2]),N=Math.min(N,tt),F[0]=Math.max(F[0],$+this.objectOffset[0]),F[1]=Math.max(F[1],Q+this.objectOffset[1]),F[2]=Math.max(F[2],Z+this.objectOffset[2]),U=Math.max(U,tt),G+=1}}for(t.intensityBounds&&(N=+t.intensityBounds[0],U=+t.intensityBounds[1]),o=6;o<H;o+=10)q[o]=(q[o]-N)/(U-N);this._vertexCount=G,this._coordinateBuffer.update(q.subarray(0,H)),s.freeFloat(q),s.free(k.data),this.bounds=[R,F],this.intensity=t.intensity||this._field[2],this.intensityBounds[0]===N&&this.intensityBounds[1]===U||(r=!0),this.intensityBounds=[N,U]}if(\"levels\"in t){var et=t.levels;for(et=Array.isArray(et[0])?et.slice():[[],[],et],o=0;o<3;++o)et[o]=et[o].slice(),et[o].sort(function(t,e){return t-e});for(o=0;o<3;++o)for(b=0;b<et[o].length;++b)et[o][b]-=this.objectOffset[o];t:for(o=0;o<3;++o){if(et[o].length!==this.contourLevels[o].length){r=!0;break}for(b=0;b<et[o].length;++b)if(et[o][b]!==this.contourLevels[o][b]){r=!0;break t}}this.contourLevels=et}if(r){_=this._field,a=this.shape;for(var rt=[],nt=0;nt<3;++nt){var it=this.contourLevels[nt],at=[],ot=[],st=[0,0,0];for(o=0;o<it.length;++o){var lt=f(this._field[nt],it[o]);at.push(rt.length/5|0),G=0;t:for(b=0;b<lt.cells.length;++b){var ct=lt.cells[b];for(X=0;X<2;++X){var ut=lt.positions[ct[X]],ht=ut[0],ft=0|Math.floor(ht),pt=ht-ft,dt=ut[1],gt=0|Math.floor(dt),vt=dt-gt,mt=!1;e:for(var yt=0;yt<3;++yt){st[yt]=0;var xt=(nt+yt+1)%3;for(Y=0;Y<2;++Y){var bt=Y?pt:1-pt;for(J=0|Math.min(Math.max(ft+Y,0),a[0]),W=0;W<2;++W){var _t=W?vt:1-vt;if(K=0|Math.min(Math.max(gt+W,0),a[1]),Z=yt<2?this._field[xt].get(J,K):(this.intensity.get(J,K)-this.intensityBounds[0])/(this.intensityBounds[1]-this.intensityBounds[0]),!isFinite(Z)||isNaN(Z)){mt=!0;break e}var wt=bt*_t;st[yt]+=wt*Z}}}if(mt){if(X>0){for(var kt=0;kt<5;++kt)rt.pop();G-=1}continue t}rt.push(st[0],st[1],ut[0],ut[1],st[2]),G+=1}}ot.push(G)}this._contourOffsets[nt]=at,this._contourCounts[nt]=ot}var Tt=s.mallocFloat(rt.length);for(o=0;o<rt.length;++o)Tt[o]=rt[o];this._contourBuffer.update(Tt),s.freeFloat(Tt)}t.colormap&&this._colorMap.setPixels(function(t){var e=u([l({colormap:t,nshades:S,format:\"rgba\"}).map(function(t){return[t[0],t[1],t[2],255*t[3]]})]);return c.divseq(e,255),e}(t.colormap))},C.dispose=function(){this._shader.dispose(),this._vao.dispose(),this._coordinateBuffer.dispose(),this._colorMap.dispose(),this._contourBuffer.dispose(),this._contourVAO.dispose(),this._contourShader.dispose(),this._contourPickShader.dispose(),this._dynamicBuffer.dispose(),this._dynamicVAO.dispose();for(var t=0;t<3;++t)s.freeFloat(this._field[t].data)},C.highlight=function(t){var e,r;if(!t)return this._dynamicCounts=[0,0,0],this.dyanamicLevel=[NaN,NaN,NaN],void(this.highlightLevel=[-1,-1,-1]);for(e=0;e<3;++e)this.enableHighlight[e]?this.highlightLevel[e]=t.level[e]:this.highlightLevel[e]=-1;for(r=this.snapToData?t.dataCoordinate:t.position,e=0;e<3;++e)r[e]-=this.objectOffset[e];if(this.enableDynamic[0]&&r[0]!==this.dynamicLevel[0]||this.enableDynamic[1]&&r[1]!==this.dynamicLevel[1]||this.enableDynamic[2]&&r[2]!==this.dynamicLevel[2]){for(var n=0,i=this.shape,a=s.mallocFloat(12*i[0]*i[1]),o=0;o<3;++o)if(this.enableDynamic[o]){this.dynamicLevel[o]=r[o];var l=(o+1)%3,c=(o+2)%3,u=this._field[o],h=this._field[l],p=this._field[c],d=f(u,r[o]),g=d.cells,v=d.positions;for(this._dynamicOffsets[o]=n,e=0;e<g.length;++e)for(var m=g[e],y=0;y<2;++y){var x=v[m[y]],b=+x[0],_=0|b,w=0|Math.min(_+1,i[0]),k=b-_,T=1-k,A=+x[1],M=0|A,S=0|Math.min(M+1,i[1]),E=A-M,C=1-E,L=T*C,P=T*E,O=k*C,z=k*E,I=L*h.get(_,M)+P*h.get(_,S)+O*h.get(w,M)+z*h.get(w,S),D=L*p.get(_,M)+P*p.get(_,S)+O*p.get(w,M)+z*p.get(w,S);if(isNaN(I)||isNaN(D)){y&&(n-=1);break}a[2*n+0]=I,a[2*n+1]=D,n+=1}this._dynamicCounts[o]=n-this._dynamicOffsets[o]}else this.dynamicLevel[o]=NaN,this._dynamicCounts[o]=0;this._dynamicBuffer.update(a.subarray(0,2*n)),s.freeFloat(a)}}},{\"./lib/shaders\":314,\"binary-search-bounds\":315,\"bit-twiddle\":92,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,\"ndarray-gradient\":441,\"ndarray-ops\":444,\"ndarray-pack\":445,\"surface-nets\":531,\"typedarray-pool\":545}],317:[function(t,e,r){\"use strict\";var n=t(\"css-font\"),i=t(\"pick-by-alias\"),a=t(\"regl\"),o=t(\"gl-util/context\"),s=t(\"es6-weak-map\"),l=t(\"color-normalize\"),c=t(\"font-atlas\"),u=t(\"typedarray-pool\"),h=t(\"parse-rect\"),f=t(\"is-plain-obj\"),p=t(\"parse-unit\"),d=t(\"to-px\"),g=t(\"detect-kerning\"),v=t(\"object-assign\"),m=t(\"font-measure\"),y=t(\"flatten-vertex-data\"),x=t(\"bit-twiddle\").nextPow2,b=new s,_=!1;if(document.body){var w=document.body.appendChild(document.createElement(\"div\"));w.style.font=\"italic small-caps bold condensed 16px/2 cursive\",getComputedStyle(w).fontStretch&&(_=!0),document.body.removeChild(w)}var k=function(t){!function(t){return\"function\"==typeof t&&t._gl&&t.prop&&t.texture&&t.buffer}(t)?this.gl=o(t):(t={regl:t},this.gl=t.regl._gl),this.shader=b.get(this.gl),this.shader?this.regl=this.shader.regl:this.regl=t.regl||a({gl:this.gl}),this.charBuffer=this.regl.buffer({type:\"uint8\",usage:\"stream\"}),this.sizeBuffer=this.regl.buffer({type:\"float\",usage:\"stream\"}),this.shader||(this.shader=this.createShader(),b.set(this.gl,this.shader)),this.batch=[],this.fontSize=[],this.font=[],this.fontAtlas=[],this.draw=this.shader.draw.bind(this),this.render=function(){this.regl._refresh(),this.draw(this.batch)},this.canvas=this.gl.canvas,this.update(f(t)?t:{})};k.prototype.createShader=function(){var t=this.regl,e=t({blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},stencil:{enable:!1},depth:{enable:!1},count:t.prop(\"count\"),offset:t.prop(\"offset\"),attributes:{charOffset:{offset:4,stride:8,buffer:t.this(\"sizeBuffer\")},width:{offset:0,stride:8,buffer:t.this(\"sizeBuffer\")},char:t.this(\"charBuffer\"),position:t.this(\"position\")},uniforms:{atlasSize:function(t,e){return[e.atlas.width,e.atlas.height]},atlasDim:function(t,e){return[e.atlas.cols,e.atlas.rows]},atlas:function(t,e){return e.atlas.texture},charStep:function(t,e){return e.atlas.step},em:function(t,e){return e.atlas.em},color:t.prop(\"color\"),opacity:t.prop(\"opacity\"),viewport:t.this(\"viewportArray\"),scale:t.this(\"scale\"),align:t.prop(\"align\"),baseline:t.prop(\"baseline\"),translate:t.this(\"translate\"),positionOffset:t.prop(\"positionOffset\")},primitive:\"points\",viewport:t.this(\"viewport\"),vert:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tattribute float width, charOffset, char;\\n\\t\\t\\tattribute vec2 position;\\n\\t\\t\\tuniform float fontSize, charStep, em, align, baseline;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tuniform vec4 color;\\n\\t\\t\\tuniform vec2 atlasSize, atlasDim, scale, translate, positionOffset;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\t\"+(k.normalViewport?\"\":\"vec2 positionOffset = vec2(positionOffset.x,- positionOffset.y);\")+\"\\n\\n\\t\\t\\t\\tvec2 offset = floor(em * (vec2(align + charOffset, baseline)\\n\\t\\t\\t\\t\\t+ positionOffset))\\n\\t\\t\\t\\t\\t/ (viewport.zw * scale.xy);\\n\\n\\t\\t\\t\\tvec2 position = (position + translate) * scale;\\n\\t\\t\\t\\tposition += offset * scale;\\n\\n\\t\\t\\t\\t\"+(k.normalViewport?\"position.y = 1. - position.y;\":\"\")+\"\\n\\n\\t\\t\\t\\tcharCoord = position * viewport.zw + viewport.xy;\\n\\n\\t\\t\\t\\tgl_Position = vec4(position * 2. - 1., 0, 1);\\n\\n\\t\\t\\t\\tgl_PointSize = charStep;\\n\\n\\t\\t\\t\\tcharId.x = mod(char, atlasDim.x);\\n\\t\\t\\t\\tcharId.y = floor(char / atlasDim.x);\\n\\n\\t\\t\\t\\tcharWidth = width * em;\\n\\n\\t\\t\\t\\tfontColor = color / 255.;\\n\\t\\t\\t}\",frag:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tuniform sampler2D atlas;\\n\\t\\t\\tuniform float fontSize, charStep, opacity;\\n\\t\\t\\tuniform vec2 atlasSize;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\n\\t\\t\\tfloat lightness(vec4 color) {\\n\\t\\t\\t\\treturn color.r * 0.299 + color.g * 0.587 + color.b * 0.114;\\n\\t\\t\\t}\\n\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\tvec2 uv = gl_FragCoord.xy - charCoord + charStep * .5;\\n\\t\\t\\t\\tfloat halfCharStep = floor(charStep * .5 + .5);\\n\\n\\t\\t\\t\\t// invert y and shift by 1px (FF expecially needs that)\\n\\t\\t\\t\\tuv.y = charStep - uv.y;\\n\\n\\t\\t\\t\\t// ignore points outside of character bounding box\\n\\t\\t\\t\\tfloat halfCharWidth = ceil(charWidth * .5);\\n\\t\\t\\t\\tif (floor(uv.x) > halfCharStep + halfCharWidth ||\\n\\t\\t\\t\\t\\tfloor(uv.x) < halfCharStep - halfCharWidth) return;\\n\\n\\t\\t\\t\\tuv += charId * charStep;\\n\\t\\t\\t\\tuv = uv / atlasSize;\\n\\n\\t\\t\\t\\tvec4 color = fontColor;\\n\\t\\t\\t\\tvec4 mask = texture2D(atlas, uv);\\n\\n\\t\\t\\t\\tfloat maskY = lightness(mask);\\n\\t\\t\\t\\t// float colorY = lightness(color);\\n\\t\\t\\t\\tcolor.a *= maskY;\\n\\t\\t\\t\\tcolor.a *= opacity;\\n\\n\\t\\t\\t\\t// color.a += .1;\\n\\n\\t\\t\\t\\t// antialiasing, see yiq color space y-channel formula\\n\\t\\t\\t\\t// color.rgb += (1. - color.rgb) * (1. - mask.rgb);\\n\\n\\t\\t\\t\\tgl_FragColor = color;\\n\\t\\t\\t}\"});return{regl:t,draw:e,atlas:{}}},k.prototype.update=function(t){var e=this;if(\"string\"==typeof t)t={text:t};else if(!t)return;null!=(t=i(t,{position:\"position positions coord coords coordinates\",font:\"font fontFace fontface typeface cssFont css-font family fontFamily\",fontSize:\"fontSize fontsize size font-size\",text:\"text texts chars characters value values symbols\",align:\"align alignment textAlign textbaseline\",baseline:\"baseline textBaseline textbaseline\",direction:\"dir direction textDirection\",color:\"color colour fill fill-color fillColor textColor textcolor\",kerning:\"kerning kern\",range:\"range dataBox\",viewport:\"vp viewport viewBox viewbox viewPort\",opacity:\"opacity alpha transparency visible visibility opaque\",offset:\"offset positionOffset padding shift indent indentation\"},!0)).opacity&&(Array.isArray(t.opacity)?this.opacity=t.opacity.map(function(t){return parseFloat(t)}):this.opacity=parseFloat(t.opacity)),null!=t.viewport&&(this.viewport=h(t.viewport),k.normalViewport&&(this.viewport.y=this.canvas.height-this.viewport.y-this.viewport.height),this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null==this.viewport&&(this.viewport={x:0,y:0,width:this.gl.drawingBufferWidth,height:this.gl.drawingBufferHeight},this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null!=t.kerning&&(this.kerning=t.kerning),null!=t.offset&&(\"number\"==typeof t.offset&&(t.offset=[t.offset,0]),this.positionOffset=y(t.offset)),t.direction&&(this.direction=t.direction),t.range&&(this.range=t.range,this.scale=[1/(t.range[2]-t.range[0]),1/(t.range[3]-t.range[1])],this.translate=[-t.range[0],-t.range[1]]),t.scale&&(this.scale=t.scale),t.translate&&(this.translate=t.translate),this.scale||(this.scale=[1/this.viewport.width,1/this.viewport.height]),this.translate||(this.translate=[0,0]),this.font.length||t.font||(t.font=k.baseFontSize+\"px sans-serif\");var r,a=!1,o=!1;if(t.font&&(Array.isArray(t.font)?t.font:[t.font]).forEach(function(t,r){if(\"string\"==typeof t)try{t=n.parse(t)}catch(e){t=n.parse(k.baseFontSize+\"px \"+t)}else t=n.parse(n.stringify(t));var i=n.stringify({size:k.baseFontSize,family:t.family,stretch:_?t.stretch:void 0,variant:t.variant,weight:t.weight,style:t.style}),s=p(t.size),l=Math.round(s[0]*d(s[1]));if(l!==e.fontSize[r]&&(o=!0,e.fontSize[r]=l),!(e.font[r]&&i==e.font[r].baseString||(a=!0,e.font[r]=k.fonts[i],e.font[r]))){var c=t.family.join(\", \"),u=[t.style];t.style!=t.variant&&u.push(t.variant),t.variant!=t.weight&&u.push(t.weight),_&&t.weight!=t.stretch&&u.push(t.stretch),e.font[r]={baseString:i,family:c,weight:t.weight,stretch:t.stretch,style:t.style,variant:t.variant,width:{},kerning:{},metrics:m(c,{origin:\"top\",fontSize:k.baseFontSize,fontStyle:u.join(\" \")})},k.fonts[i]=e.font[r]}}),(a||o)&&this.font.forEach(function(r,i){var a=n.stringify({size:e.fontSize[i],family:r.family,stretch:_?r.stretch:void 0,variant:r.variant,weight:r.weight,style:r.style});if(e.fontAtlas[i]=e.shader.atlas[a],!e.fontAtlas[i]){var o=r.metrics;e.shader.atlas[a]=e.fontAtlas[i]={fontString:a,step:2*Math.ceil(e.fontSize[i]*o.bottom*.5),em:e.fontSize[i],cols:0,rows:0,height:0,width:0,chars:[],ids:{},texture:e.regl.texture()}}null==t.text&&(t.text=e.text)}),\"string\"==typeof t.text&&t.position&&t.position.length>2){for(var s=Array(.5*t.position.length),f=0;f<s.length;f++)s[f]=t.text;t.text=s}if(null!=t.text||a){if(this.textOffsets=[0],Array.isArray(t.text)){this.count=t.text[0].length,this.counts=[this.count];for(var b=1;b<t.text.length;b++)this.textOffsets[b]=this.textOffsets[b-1]+t.text[b-1].length,this.count+=t.text[b].length,this.counts.push(t.text[b].length);this.text=t.text.join(\"\")}else this.text=t.text,this.count=this.text.length,this.counts=[this.count];r=[],this.font.forEach(function(t,n){k.atlasContext.font=t.baseString;for(var i=e.fontAtlas[n],a=0;a<e.text.length;a++){var o=e.text.charAt(a);if(null==i.ids[o]&&(i.ids[o]=i.chars.length,i.chars.push(o),r.push(o)),null==t.width[o]&&(t.width[o]=k.atlasContext.measureText(o).width/k.baseFontSize,e.kerning)){var s=[];for(var l in t.width)s.push(l+o,o+l);v(t.kerning,g(t.family,{pairs:s}))}}})}if(t.position)if(t.position.length>2){for(var w=!t.position[0].length,T=u.mallocFloat(2*this.count),A=0,M=0;A<this.counts.length;A++){var S=this.counts[A];if(w)for(var E=0;E<S;E++)T[M++]=t.position[2*A],T[M++]=t.position[2*A+1];else for(var C=0;C<S;C++)T[M++]=t.position[A][0],T[M++]=t.position[A][1]}this.position.call?this.position({type:\"float\",data:T}):this.position=this.regl.buffer({type:\"float\",data:T}),u.freeFloat(T)}else this.position.destroy&&this.position.destroy(),this.position={constant:t.position};if(t.text||a){var L=u.mallocUint8(this.count),P=u.mallocFloat(2*this.count);this.textWidth=[];for(var O=0,z=0;O<this.counts.length;O++){for(var I=this.counts[O],D=this.font[O]||this.font[0],R=this.fontAtlas[O]||this.fontAtlas[0],F=0;F<I;F++){var B=this.text.charAt(z),N=this.text.charAt(z-1);if(L[z]=R.ids[B],P[2*z]=D.width[B],F){var j=P[2*z-2],U=P[2*z],V=P[2*z-1]+.5*j+.5*U;if(this.kerning){var q=D.kerning[N+B];q&&(V+=.001*q)}P[2*z+1]=V}else P[2*z+1]=.5*P[2*z];z++}this.textWidth.push(P.length?.5*P[2*z-2]+P[2*z-1]:0)}t.align||(t.align=this.align),this.charBuffer({data:L,type:\"uint8\",usage:\"stream\"}),this.sizeBuffer({data:P,type:\"float\",usage:\"stream\"}),u.freeUint8(L),u.freeFloat(P),r.length&&this.font.forEach(function(t,r){var n=e.fontAtlas[r],i=n.step,a=Math.floor(k.maxAtlasSize/i),o=Math.min(a,n.chars.length),s=Math.ceil(n.chars.length/o),l=x(o*i),u=x(s*i);n.width=l,n.height=u,n.rows=s,n.cols=o,n.em&&n.texture({data:c({canvas:k.atlasCanvas,font:n.fontString,chars:n.chars,shape:[l,u],step:[i,i]})})})}if(t.align&&(this.align=t.align,this.alignOffset=this.textWidth.map(function(t,r){var n=Array.isArray(e.align)?e.align.length>1?e.align[r]:e.align[0]:e.align;if(\"number\"==typeof n)return n;switch(n){case\"right\":case\"end\":return-t;case\"center\":case\"centre\":case\"middle\":return.5*-t}return 0})),null==this.baseline&&null==t.baseline&&(t.baseline=0),null!=t.baseline&&(this.baseline=t.baseline,Array.isArray(this.baseline)||(this.baseline=[this.baseline]),this.baselineOffset=this.baseline.map(function(t,r){var n=(e.font[r]||e.font[0]).metrics,i=0;return i+=.5*n.bottom,i+=\"number\"==typeof t?t-n.baseline:-n[t],k.normalViewport||(i*=-1),i})),null!=t.color)if(t.color||(t.color=\"transparent\"),\"string\"!=typeof t.color&&isNaN(t.color)){var H;if(\"number\"==typeof t.color[0]&&t.color.length>this.counts.length){var G=t.color.length;H=u.mallocUint8(G);for(var Y=(t.color.subarray||t.color.slice).bind(t.color),W=0;W<G;W+=4)H.set(l(Y(W,W+4),\"uint8\"),W)}else{var X=t.color.length;H=u.mallocUint8(4*X);for(var Z=0;Z<X;Z++)H.set(l(t.color[Z]||0,\"uint8\"),4*Z)}this.color=H}else this.color=l(t.color,\"uint8\");if(t.position||t.text||t.color||t.baseline||t.align||t.font||t.offset||t.opacity)if(this.color.length>4||this.baselineOffset.length>1||this.align&&this.align.length>1||this.fontAtlas.length>1||this.positionOffset.length>2){var J=Math.max(.5*this.position.length||0,.25*this.color.length||0,this.baselineOffset.length||0,this.alignOffset.length||0,this.font.length||0,this.opacity.length||0,.5*this.positionOffset.length||0);this.batch=Array(J);for(var K=0;K<this.batch.length;K++)this.batch[K]={count:this.counts.length>1?this.counts[K]:this.counts[0],offset:this.textOffsets.length>1?this.textOffsets[K]:this.textOffsets[0],color:this.color?this.color.length<=4?this.color:this.color.subarray(4*K,4*K+4):[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[K]:this.opacity,baseline:null!=this.baselineOffset[K]?this.baselineOffset[K]:this.baselineOffset[0],align:this.align?null!=this.alignOffset[K]?this.alignOffset[K]:this.alignOffset[0]:0,atlas:this.fontAtlas[K]||this.fontAtlas[0],positionOffset:this.positionOffset.length>2?this.positionOffset.subarray(2*K,2*K+2):this.positionOffset}}else this.count?this.batch=[{count:this.count,offset:0,color:this.color||[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[0]:this.opacity,baseline:this.baselineOffset[0],align:this.alignOffset?this.alignOffset[0]:0,atlas:this.fontAtlas[0],positionOffset:this.positionOffset}]:this.batch=[]},k.prototype.destroy=function(){},k.prototype.kerning=!0,k.prototype.position={constant:new Float32Array(2)},k.prototype.translate=null,k.prototype.scale=null,k.prototype.font=null,k.prototype.text=\"\",k.prototype.positionOffset=[0,0],k.prototype.opacity=1,k.prototype.color=new Uint8Array([0,0,0,255]),k.prototype.alignOffset=[0,0],k.normalViewport=!1,k.maxAtlasSize=1024,k.atlasCanvas=document.createElement(\"canvas\"),k.atlasContext=k.atlasCanvas.getContext(\"2d\",{alpha:!1}),k.baseFontSize=64,k.fonts={},e.exports=k},{\"bit-twiddle\":92,\"color-normalize\":120,\"css-font\":139,\"detect-kerning\":166,\"es6-weak-map\":318,\"flatten-vertex-data\":227,\"font-atlas\":228,\"font-measure\":229,\"gl-util/context\":323,\"is-plain-obj\":422,\"object-assign\":454,\"parse-rect\":459,\"parse-unit\":461,\"pick-by-alias\":465,regl:502,\"to-px\":539,\"typedarray-pool\":545}],318:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?WeakMap:t(\"./polyfill\")},{\"./is-implemented\":319,\"./polyfill\":321}],319:[function(t,e,r){\"use strict\";e.exports=function(){var t,e;if(\"function\"!=typeof WeakMap)return!1;try{t=new WeakMap([[e={},\"one\"],[{},\"two\"],[{},\"three\"]])}catch(t){return!1}return\"[object WeakMap]\"===String(t)&&(\"function\"==typeof t.set&&(t.set({},1)===t&&(\"function\"==typeof t.delete&&(\"function\"==typeof t.has&&\"one\"===t.get(e)))))}},{}],320:[function(t,e,r){\"use strict\";e.exports=\"function\"==typeof WeakMap&&\"[object WeakMap]\"===Object.prototype.toString.call(new WeakMap)},{}],321:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/object/set-prototype-of\"),o=t(\"es5-ext/object/valid-object\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"es5-ext/string/random-uniq\"),c=t(\"d\"),u=t(\"es6-iterator/get\"),h=t(\"es6-iterator/for-of\"),f=t(\"es6-symbol\").toStringTag,p=t(\"./is-native-implemented\"),d=Array.isArray,g=Object.defineProperty,v=Object.prototype.hasOwnProperty,m=Object.getPrototypeOf;e.exports=n=function(){var t,e=arguments[0];if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");return t=p&&a&&WeakMap!==n?a(new WeakMap,m(this)):this,i(e)&&(d(e)||(e=u(e))),g(t,\"__weakMapData__\",c(\"c\",\"$weakMap$\"+l())),e?(h(e,function(e){s(e),t.set(e[0],e[1])}),t):t},p&&(a&&a(n,WeakMap),n.prototype=Object.create(WeakMap.prototype,{constructor:c(n)})),Object.defineProperties(n.prototype,{delete:c(function(t){return!!v.call(o(t),this.__weakMapData__)&&(delete t[this.__weakMapData__],!0)}),get:c(function(t){if(v.call(o(t),this.__weakMapData__))return t[this.__weakMapData__]}),has:c(function(t){return v.call(o(t),this.__weakMapData__)}),set:c(function(t,e){return g(o(t),this.__weakMapData__,c(\"c\",e)),this}),toString:c(function(){return\"[object WeakMap]\"})}),g(n.prototype,f,c(\"c\",\"WeakMap\"))},{\"./is-native-implemented\":320,d:151,\"es5-ext/object/is-value\":194,\"es5-ext/object/set-prototype-of\":200,\"es5-ext/object/valid-object\":204,\"es5-ext/object/valid-value\":205,\"es5-ext/string/random-uniq\":210,\"es6-iterator/for-of\":212,\"es6-iterator/get\":213,\"es6-symbol\":219}],322:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"ndarray-ops\"),a=t(\"typedarray-pool\");e.exports=function(t){if(arguments.length<=1)throw new Error(\"gl-texture2d: Missing arguments for texture2d constructor\");o||function(t){o=[t.LINEAR,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_NEAREST],s=[t.NEAREST,t.LINEAR,t.NEAREST_MIPMAP_NEAREST,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_LINEAR],l=[t.REPEAT,t.CLAMP_TO_EDGE,t.MIRRORED_REPEAT]}(t);if(\"number\"==typeof arguments[1])return v(t,arguments[1],arguments[2],arguments[3]||t.RGBA,arguments[4]||t.UNSIGNED_BYTE);if(Array.isArray(arguments[1]))return v(t,0|arguments[1][0],0|arguments[1][1],arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(\"object\"==typeof arguments[1]){var e=arguments[1],r=c(e)?e:e.raw;if(r)return function(t,e,r,n,i,a){var o=g(t);return t.texImage2D(t.TEXTURE_2D,0,i,i,a,e),new f(t,o,r,n,i,a)}(t,r,0|e.width,0|e.height,arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(e.shape&&e.data&&e.stride)return function(t,e){var r=e.dtype,o=e.shape.slice(),s=t.getParameter(t.MAX_TEXTURE_SIZE);if(o[0]<0||o[0]>s||o[1]<0||o[1]>s)throw new Error(\"gl-texture2d: Invalid texture size\");var l=d(o,e.stride.slice()),c=0;\"float32\"===r?c=t.FLOAT:\"float64\"===r?(c=t.FLOAT,l=!1,r=\"float32\"):\"uint8\"===r?c=t.UNSIGNED_BYTE:(c=t.UNSIGNED_BYTE,l=!1,r=\"uint8\");var h,p,v=0;if(2===o.length)v=t.LUMINANCE,o=[o[0],o[1],1],e=n(e.data,o,[e.stride[0],e.stride[1],1],e.offset);else{if(3!==o.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===o[2])v=t.ALPHA;else if(2===o[2])v=t.LUMINANCE_ALPHA;else if(3===o[2])v=t.RGB;else{if(4!==o[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");v=t.RGBA}}c!==t.FLOAT||t.getExtension(\"OES_texture_float\")||(c=t.UNSIGNED_BYTE,l=!1);var m=e.size;if(l)h=0===e.offset&&e.data.length===m?e.data:e.data.subarray(e.offset,e.offset+m);else{var y=[o[2],o[2]*o[0],1];p=a.malloc(m,r);var x=n(p,o,y,0);\"float32\"!==r&&\"float64\"!==r||c!==t.UNSIGNED_BYTE?i.assign(x,e):u(x,e),h=p.subarray(0,m)}var b=g(t);t.texImage2D(t.TEXTURE_2D,0,v,o[0],o[1],0,v,c,h),l||a.free(p);return new f(t,b,o[0],o[1],v,c)}(t,e)}throw new Error(\"gl-texture2d: Invalid arguments for texture2d constructor\")};var o=null,s=null,l=null;function c(t){return\"undefined\"!=typeof HTMLCanvasElement&&t instanceof HTMLCanvasElement||\"undefined\"!=typeof HTMLImageElement&&t instanceof HTMLImageElement||\"undefined\"!=typeof HTMLVideoElement&&t instanceof HTMLVideoElement||\"undefined\"!=typeof ImageData&&t instanceof ImageData}var u=function(t,e){i.muls(t,e,255)};function h(t,e,r){var n=t.gl,i=n.getParameter(n.MAX_TEXTURE_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-texture2d: Invalid texture size\");return t._shape=[e,r],t.bind(),n.texImage2D(n.TEXTURE_2D,0,t.format,e,r,0,t.format,t.type,null),t._mipLevels=[0],t}function f(t,e,r,n,i,a){this.gl=t,this.handle=e,this.format=i,this.type=a,this._shape=[r,n],this._mipLevels=[0],this._magFilter=t.NEAREST,this._minFilter=t.NEAREST,this._wrapS=t.CLAMP_TO_EDGE,this._wrapT=t.CLAMP_TO_EDGE,this._anisoSamples=1;var o=this,s=[this._wrapS,this._wrapT];Object.defineProperties(s,[{get:function(){return o._wrapS},set:function(t){return o.wrapS=t}},{get:function(){return o._wrapT},set:function(t){return o.wrapT=t}}]),this._wrapVector=s;var l=[this._shape[0],this._shape[1]];Object.defineProperties(l,[{get:function(){return o._shape[0]},set:function(t){return o.width=t}},{get:function(){return o._shape[1]},set:function(t){return o.height=t}}]),this._shapeVector=l}var p=f.prototype;function d(t,e){return 3===t.length?1===e[2]&&e[1]===t[0]*t[2]&&e[0]===t[2]:1===e[0]&&e[1]===t[0]}function g(t){var e=t.createTexture();return t.bindTexture(t.TEXTURE_2D,e),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MIN_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MAG_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_S,t.CLAMP_TO_EDGE),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_T,t.CLAMP_TO_EDGE),e}function v(t,e,r,n,i){var a=t.getParameter(t.MAX_TEXTURE_SIZE);if(e<0||e>a||r<0||r>a)throw new Error(\"gl-texture2d: Invalid texture shape\");if(i===t.FLOAT&&!t.getExtension(\"OES_texture_float\"))throw new Error(\"gl-texture2d: Floating point textures not supported on this platform\");var o=g(t);return t.texImage2D(t.TEXTURE_2D,0,n,e,r,0,n,i,null),new f(t,o,e,r,n,i)}Object.defineProperties(p,{minFilter:{get:function(){return this._minFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,t),this._minFilter=t}},magFilter:{get:function(){return this._magFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,t),this._magFilter=t}},mipSamples:{get:function(){return this._anisoSamples},set:function(t){var e=this._anisoSamples;if(this._anisoSamples=0|Math.max(t,1),e!==this._anisoSamples){var r=this.gl.getExtension(\"EXT_texture_filter_anisotropic\");r&&this.gl.texParameterf(this.gl.TEXTURE_2D,r.TEXTURE_MAX_ANISOTROPY_EXT,this._anisoSamples)}return this._anisoSamples}},wrapS:{get:function(){return this._wrapS},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_S,t),this._wrapS=t}},wrapT:{get:function(){return this._wrapT},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_T,t),this._wrapT=t}},wrap:{get:function(){return this._wrapVector},set:function(t){if(Array.isArray(t)||(t=[t,t]),2!==t.length)throw new Error(\"gl-texture2d: Must specify wrap mode for rows and columns\");for(var e=0;e<2;++e)if(l.indexOf(t[e])<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);this._wrapS=t[0],this._wrapT=t[1];var r=this.gl;return this.bind(),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_S,this._wrapS),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_T,this._wrapT),t}},shape:{get:function(){return this._shapeVector},set:function(t){if(Array.isArray(t)){if(2!==t.length)throw new Error(\"gl-texture2d: Invalid texture shape\")}else t=[0|t,0|t];return h(this,0|t[0],0|t[1]),[0|t[0],0|t[1]]}},width:{get:function(){return this._shape[0]},set:function(t){return h(this,t|=0,this._shape[1]),t}},height:{get:function(){return this._shape[1]},set:function(t){return t|=0,h(this,this._shape[0],t),t}}}),p.bind=function(t){var e=this.gl;return void 0!==t&&e.activeTexture(e.TEXTURE0+(0|t)),e.bindTexture(e.TEXTURE_2D,this.handle),void 0!==t?0|t:e.getParameter(e.ACTIVE_TEXTURE)-e.TEXTURE0},p.dispose=function(){this.gl.deleteTexture(this.handle)},p.generateMipmap=function(){this.bind(),this.gl.generateMipmap(this.gl.TEXTURE_2D);for(var t=Math.min(this._shape[0],this._shape[1]),e=0;t>0;++e,t>>>=1)this._mipLevels.indexOf(e)<0&&this._mipLevels.push(e)},p.setPixels=function(t,e,r,o){var s=this.gl;this.bind(),Array.isArray(e)?(o=r,r=0|e[1],e=0|e[0]):(e=e||0,r=r||0),o=o||0;var l=c(t)?t:t.raw;if(l){this._mipLevels.indexOf(o)<0?(s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,this.type,l),this._mipLevels.push(o)):s.texSubImage2D(s.TEXTURE_2D,o,e,r,this.format,this.type,l)}else{if(!(t.shape&&t.stride&&t.data))throw new Error(\"gl-texture2d: Unsupported data type\");if(t.shape.length<2||e+t.shape[1]>this._shape[1]>>>o||r+t.shape[0]>this._shape[0]>>>o||e<0||r<0)throw new Error(\"gl-texture2d: Texture dimensions are out of bounds\");!function(t,e,r,o,s,l,c,h){var f=h.dtype,p=h.shape.slice();if(p.length<2||p.length>3)throw new Error(\"gl-texture2d: Invalid ndarray, must be 2d or 3d\");var g=0,v=0,m=d(p,h.stride.slice());\"float32\"===f?g=t.FLOAT:\"float64\"===f?(g=t.FLOAT,m=!1,f=\"float32\"):\"uint8\"===f?g=t.UNSIGNED_BYTE:(g=t.UNSIGNED_BYTE,m=!1,f=\"uint8\");if(2===p.length)v=t.LUMINANCE,p=[p[0],p[1],1],h=n(h.data,p,[h.stride[0],h.stride[1],1],h.offset);else{if(3!==p.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===p[2])v=t.ALPHA;else if(2===p[2])v=t.LUMINANCE_ALPHA;else if(3===p[2])v=t.RGB;else{if(4!==p[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");v=t.RGBA}p[2]}v!==t.LUMINANCE&&v!==t.ALPHA||s!==t.LUMINANCE&&s!==t.ALPHA||(v=s);if(v!==s)throw new Error(\"gl-texture2d: Incompatible texture format for setPixels\");var y=h.size,x=c.indexOf(o)<0;x&&c.push(o);if(g===l&&m)0===h.offset&&h.data.length===y?x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,h.data):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,h.data):x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,h.data.subarray(h.offset,h.offset+y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,h.data.subarray(h.offset,h.offset+y));else{var b;b=l===t.FLOAT?a.mallocFloat32(y):a.mallocUint8(y);var _=n(b,p,[p[2],p[2]*p[0],1]);g===t.FLOAT&&l===t.UNSIGNED_BYTE?u(_,h):i.assign(_,h),x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,b.subarray(0,y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,b.subarray(0,y)),l===t.FLOAT?a.freeFloat32(b):a.freeUint8(b)}}(s,e,r,o,this.format,this.type,this._mipLevels,t)}}},{ndarray:450,\"ndarray-ops\":444,\"typedarray-pool\":545}],323:[function(t,e,r){(function(r){\"use strict\";var n=t(\"pick-by-alias\");function i(t){if(t.container)if(t.container==document.body)document.body.style.width||(t.canvas.width=t.width||t.pixelRatio*r.innerWidth),document.body.style.height||(t.canvas.height=t.height||t.pixelRatio*r.innerHeight);else{var e=t.container.getBoundingClientRect();t.canvas.width=t.width||e.right-e.left,t.canvas.height=t.height||e.bottom-e.top}}function a(t){return\"function\"==typeof t.getContext&&\"width\"in t&&\"height\"in t}function o(){var t=document.createElement(\"canvas\");return t.style.position=\"absolute\",t.style.top=0,t.style.left=0,t}e.exports=function(t){var e;if(t?\"string\"==typeof t&&(t={container:t}):t={},a(t)?t={container:t}:t=\"string\"==typeof(e=t).nodeName&&\"function\"==typeof e.appendChild&&\"function\"==typeof e.getBoundingClientRect?{container:t}:function(t){return\"function\"==typeof t.drawArrays||\"function\"==typeof t.drawElements}(t)?{gl:t}:n(t,{container:\"container target element el canvas holder parent parentNode wrapper use ref root node\",gl:\"gl context webgl glContext\",attrs:\"attributes attrs contextAttributes\",pixelRatio:\"pixelRatio pxRatio px ratio pxratio pixelratio\",width:\"w width\",height:\"h height\"},!0),t.pixelRatio||(t.pixelRatio=r.pixelRatio||1),t.gl)return t.gl;if(t.canvas&&(t.container=t.canvas.parentNode),t.container){if(\"string\"==typeof t.container){var s=document.querySelector(t.container);if(!s)throw Error(\"Element \"+t.container+\" is not found\");t.container=s}a(t.container)?(t.canvas=t.container,t.container=t.canvas.parentNode):t.canvas||(t.canvas=o(),t.container.appendChild(t.canvas),i(t))}else if(!t.canvas){if(\"undefined\"==typeof document)throw Error(\"Not DOM environment. Use headless-gl.\");t.container=document.body||document.documentElement,t.canvas=o(),t.container.appendChild(t.canvas),i(t)}if(!t.gl)try{t.gl=t.canvas.getContext(\"webgl\",t.attrs)}catch(e){try{t.gl=t.canvas.getContext(\"experimental-webgl\",t.attrs)}catch(e){t.gl=t.canvas.getContext(\"webgl-experimental\",t.attrs)}}return t.gl}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"pick-by-alias\":465}],324:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){e?e.bind():t.bindBuffer(t.ELEMENT_ARRAY_BUFFER,null);var n=0|t.getParameter(t.MAX_VERTEX_ATTRIBS);if(r){if(r.length>n)throw new Error(\"gl-vao: Too many vertex attributes\");for(var i=0;i<r.length;++i){var a=r[i];if(a.buffer){var o=a.buffer,s=a.size||4,l=a.type||t.FLOAT,c=!!a.normalized,u=a.stride||0,h=a.offset||0;o.bind(),t.enableVertexAttribArray(i),t.vertexAttribPointer(i,s,l,c,u,h)}else{if(\"number\"==typeof a)t.vertexAttrib1f(i,a);else if(1===a.length)t.vertexAttrib1f(i,a[0]);else if(2===a.length)t.vertexAttrib2f(i,a[0],a[1]);else if(3===a.length)t.vertexAttrib3f(i,a[0],a[1],a[2]);else{if(4!==a.length)throw new Error(\"gl-vao: Invalid vertex attribute\");t.vertexAttrib4f(i,a[0],a[1],a[2],a[3])}t.disableVertexAttribArray(i)}}for(;i<n;++i)t.disableVertexAttribArray(i)}else for(t.bindBuffer(t.ARRAY_BUFFER,null),i=0;i<n;++i)t.disableVertexAttribArray(i)}},{}],325:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t){this.gl=t,this._elements=null,this._attributes=null,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(){n(this.gl,this._elements,this._attributes)},i.prototype.update=function(t,e,r){this._elements=e,this._attributes=t,this._elementsType=r||this.gl.UNSIGNED_SHORT},i.prototype.dispose=function(){},i.prototype.unbind=function(){},i.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._elements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t){return new i(t)}},{\"./do-bind.js\":324}],326:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t,e,r,n,i,a){this.location=t,this.dimension=e,this.a=r,this.b=n,this.c=i,this.d=a}function a(t,e,r){this.gl=t,this._ext=e,this.handle=r,this._attribs=[],this._useElements=!1,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(t){switch(this.dimension){case 1:t.vertexAttrib1f(this.location,this.a);break;case 2:t.vertexAttrib2f(this.location,this.a,this.b);break;case 3:t.vertexAttrib3f(this.location,this.a,this.b,this.c);break;case 4:t.vertexAttrib4f(this.location,this.a,this.b,this.c,this.d)}},a.prototype.bind=function(){this._ext.bindVertexArrayOES(this.handle);for(var t=0;t<this._attribs.length;++t)this._attribs[t].bind(this.gl)},a.prototype.unbind=function(){this._ext.bindVertexArrayOES(null)},a.prototype.dispose=function(){this._ext.deleteVertexArrayOES(this.handle)},a.prototype.update=function(t,e,r){if(this.bind(),n(this.gl,e,t),this.unbind(),this._attribs.length=0,t)for(var a=0;a<t.length;++a){var o=t[a];\"number\"==typeof o?this._attribs.push(new i(a,1,o)):Array.isArray(o)&&this._attribs.push(new i(a,o.length,o[0],o[1],o[2],o[3]))}this._useElements=!!e,this._elementsType=r||this.gl.UNSIGNED_SHORT},a.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._useElements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t,e){return new a(t,e,e.createVertexArrayOES())}},{\"./do-bind.js\":324}],327:[function(t,e,r){\"use strict\";var n=t(\"./lib/vao-native.js\"),i=t(\"./lib/vao-emulated.js\");function a(t){this.bindVertexArrayOES=t.bindVertexArray.bind(t),this.createVertexArrayOES=t.createVertexArray.bind(t),this.deleteVertexArrayOES=t.deleteVertexArray.bind(t)}e.exports=function(t,e,r,o){var s,l=t.createVertexArray?new a(t):t.getExtension(\"OES_vertex_array_object\");return(s=l?n(t,l):i(t)).update(e,r,o),s}},{\"./lib/vao-emulated.js\":325,\"./lib/vao-native.js\":326}],328:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t}},{}],329:[function(t,e,r){e.exports=function(t,e){var r=n(t[0],t[1],t[2]),o=n(e[0],e[1],e[2]);i(r,r),i(o,o);var s=a(r,o);return s>1?0:Math.acos(s)};var n=t(\"./fromValues\"),i=t(\"./normalize\"),a=t(\"./dot\")},{\"./dot\":339,\"./fromValues\":345,\"./normalize\":356}],330:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.ceil(e[0]),t[1]=Math.ceil(e[1]),t[2]=Math.ceil(e[2]),t}},{}],331:[function(t,e,r){e.exports=function(t){var e=new Float32Array(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e}},{}],332:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}},{}],333:[function(t,e,r){e.exports=function(){var t=new Float32Array(3);return t[0]=0,t[1]=0,t[2]=0,t}},{}],334:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2];return t[0]=i*l-a*s,t[1]=a*o-n*l,t[2]=n*s-i*o,t}},{}],335:[function(t,e,r){e.exports=t(\"./distance\")},{\"./distance\":336}],336:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return Math.sqrt(r*r+n*n+i*i)}},{}],337:[function(t,e,r){e.exports=t(\"./divide\")},{\"./divide\":338}],338:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t}},{}],339:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}},{}],340:[function(t,e,r){e.exports=1e-6},{}],341:[function(t,e,r){e.exports=function(t,e){var r=t[0],i=t[1],a=t[2],o=e[0],s=e[1],l=e[2];return Math.abs(r-o)<=n*Math.max(1,Math.abs(r),Math.abs(o))&&Math.abs(i-s)<=n*Math.max(1,Math.abs(i),Math.abs(s))&&Math.abs(a-l)<=n*Math.max(1,Math.abs(a),Math.abs(l))};var n=t(\"./epsilon\")},{\"./epsilon\":340}],342:[function(t,e,r){e.exports=function(t,e){return t[0]===e[0]&&t[1]===e[1]&&t[2]===e[2]}},{}],343:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.floor(e[0]),t[1]=Math.floor(e[1]),t[2]=Math.floor(e[2]),t}},{}],344:[function(t,e,r){e.exports=function(t,e,r,i,a,o){var s,l;e||(e=3);r||(r=0);l=i?Math.min(i*e+r,t.length):t.length;for(s=r;s<l;s+=e)n[0]=t[s],n[1]=t[s+1],n[2]=t[s+2],a(n,n,o),t[s]=n[0],t[s+1]=n[1],t[s+2]=n[2];return t};var n=t(\"./create\")()},{\"./create\":333}],345:[function(t,e,r){e.exports=function(t,e,r){var n=new Float32Array(3);return n[0]=t,n[1]=e,n[2]=r,n}},{}],346:[function(t,e,r){e.exports={EPSILON:t(\"./epsilon\"),create:t(\"./create\"),clone:t(\"./clone\"),angle:t(\"./angle\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),equals:t(\"./equals\"),exactEquals:t(\"./exactEquals\"),add:t(\"./add\"),subtract:t(\"./subtract\"),sub:t(\"./sub\"),multiply:t(\"./multiply\"),mul:t(\"./mul\"),divide:t(\"./divide\"),div:t(\"./div\"),min:t(\"./min\"),max:t(\"./max\"),floor:t(\"./floor\"),ceil:t(\"./ceil\"),round:t(\"./round\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),dist:t(\"./dist\"),squaredDistance:t(\"./squaredDistance\"),sqrDist:t(\"./sqrDist\"),length:t(\"./length\"),len:t(\"./len\"),squaredLength:t(\"./squaredLength\"),sqrLen:t(\"./sqrLen\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),cross:t(\"./cross\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformMat3:t(\"./transformMat3\"),transformQuat:t(\"./transformQuat\"),rotateX:t(\"./rotateX\"),rotateY:t(\"./rotateY\"),rotateZ:t(\"./rotateZ\"),forEach:t(\"./forEach\")}},{\"./add\":328,\"./angle\":329,\"./ceil\":330,\"./clone\":331,\"./copy\":332,\"./create\":333,\"./cross\":334,\"./dist\":335,\"./distance\":336,\"./div\":337,\"./divide\":338,\"./dot\":339,\"./epsilon\":340,\"./equals\":341,\"./exactEquals\":342,\"./floor\":343,\"./forEach\":344,\"./fromValues\":345,\"./inverse\":347,\"./len\":348,\"./length\":349,\"./lerp\":350,\"./max\":351,\"./min\":352,\"./mul\":353,\"./multiply\":354,\"./negate\":355,\"./normalize\":356,\"./random\":357,\"./rotateX\":358,\"./rotateY\":359,\"./rotateZ\":360,\"./round\":361,\"./scale\":362,\"./scaleAndAdd\":363,\"./set\":364,\"./sqrDist\":365,\"./sqrLen\":366,\"./squaredDistance\":367,\"./squaredLength\":368,\"./sub\":369,\"./subtract\":370,\"./transformMat3\":371,\"./transformMat4\":372,\"./transformQuat\":373}],347:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t}},{}],348:[function(t,e,r){e.exports=t(\"./length\")},{\"./length\":349}],349:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return Math.sqrt(e*e+r*r+n*n)}},{}],350:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t}},{}],351:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t}},{}],352:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t}},{}],353:[function(t,e,r){e.exports=t(\"./multiply\")},{\"./multiply\":354}],354:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t}},{}],355:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t}},{}],356:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=r*r+n*n+i*i;a>0&&(a=1/Math.sqrt(a),t[0]=e[0]*a,t[1]=e[1]*a,t[2]=e[2]*a);return t}},{}],357:[function(t,e,r){e.exports=function(t,e){e=e||1;var r=2*Math.random()*Math.PI,n=2*Math.random()-1,i=Math.sqrt(1-n*n)*e;return t[0]=Math.cos(r)*i,t[1]=Math.sin(r)*i,t[2]=n*e,t}},{}],358:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[1],a=r[2],o=e[1]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=e[0],t[1]=i+o*c-s*l,t[2]=a+o*l+s*c,t}},{}],359:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[2],o=e[0]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+s*l+o*c,t[1]=e[1],t[2]=a+s*c-o*l,t}},{}],360:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[1],o=e[0]-i,s=e[1]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+o*c-s*l,t[1]=a+o*l+s*c,t[2]=e[2],t}},{}],361:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.round(e[0]),t[1]=Math.round(e[1]),t[2]=Math.round(e[2]),t}},{}],362:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t}},{}],363:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t}},{}],364:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e,t[1]=r,t[2]=n,t}},{}],365:[function(t,e,r){e.exports=t(\"./squaredDistance\")},{\"./squaredDistance\":367}],366:[function(t,e,r){e.exports=t(\"./squaredLength\")},{\"./squaredLength\":368}],367:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return r*r+n*n+i*i}},{}],368:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return e*e+r*r+n*n}},{}],369:[function(t,e,r){e.exports=t(\"./subtract\")},{\"./subtract\":370}],370:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t}},{}],371:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t}},{}],372:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[3]*n+r[7]*i+r[11]*a+r[15];return o=o||1,t[0]=(r[0]*n+r[4]*i+r[8]*a+r[12])/o,t[1]=(r[1]*n+r[5]*i+r[9]*a+r[13])/o,t[2]=(r[2]*n+r[6]*i+r[10]*a+r[14])/o,t}},{}],373:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,h=c*i+l*n-o*a,f=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+h*-l-f*-s,t[1]=h*c+p*-s+f*-o-u*-l,t[2]=f*c+p*-l+u*-s-h*-o,t}},{}],374:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t[3]=e[3]+r[3],t}},{}],375:[function(t,e,r){e.exports=function(t){var e=new Float32Array(4);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e}},{}],376:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t}},{}],377:[function(t,e,r){e.exports=function(){var t=new Float32Array(4);return t[0]=0,t[1]=0,t[2]=0,t[3]=0,t}},{}],378:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return Math.sqrt(r*r+n*n+i*i+a*a)}},{}],379:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t[3]=e[3]/r[3],t}},{}],380:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}},{}],381:[function(t,e,r){e.exports=function(t,e,r,n){var i=new Float32Array(4);return i[0]=t,i[1]=e,i[2]=r,i[3]=n,i}},{}],382:[function(t,e,r){e.exports={create:t(\"./create\"),clone:t(\"./clone\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),add:t(\"./add\"),subtract:t(\"./subtract\"),multiply:t(\"./multiply\"),divide:t(\"./divide\"),min:t(\"./min\"),max:t(\"./max\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),squaredDistance:t(\"./squaredDistance\"),length:t(\"./length\"),squaredLength:t(\"./squaredLength\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformQuat:t(\"./transformQuat\")}},{\"./add\":374,\"./clone\":375,\"./copy\":376,\"./create\":377,\"./distance\":378,\"./divide\":379,\"./dot\":380,\"./fromValues\":381,\"./inverse\":383,\"./length\":384,\"./lerp\":385,\"./max\":386,\"./min\":387,\"./multiply\":388,\"./negate\":389,\"./normalize\":390,\"./random\":391,\"./scale\":392,\"./scaleAndAdd\":393,\"./set\":394,\"./squaredDistance\":395,\"./squaredLength\":396,\"./subtract\":397,\"./transformMat4\":398,\"./transformQuat\":399}],383:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t[3]=1/e[3],t}},{}],384:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return Math.sqrt(e*e+r*r+n*n+i*i)}},{}],385:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2],s=e[3];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t[3]=s+n*(r[3]-s),t}},{}],386:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t[3]=Math.max(e[3],r[3]),t}},{}],387:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t[3]=Math.min(e[3],r[3]),t}},{}],388:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t[3]=e[3]*r[3],t}},{}],389:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t[3]=-e[3],t}},{}],390:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r*r+n*n+i*i+a*a;o>0&&(o=1/Math.sqrt(o),t[0]=r*o,t[1]=n*o,t[2]=i*o,t[3]=a*o);return t}},{}],391:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"./scale\");e.exports=function(t,e){return e=e||1,t[0]=Math.random(),t[1]=Math.random(),t[2]=Math.random(),t[3]=Math.random(),n(t,t),i(t,t,e),t}},{\"./normalize\":390,\"./scale\":392}],392:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t}},{}],393:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t[3]=e[3]+r[3]*n,t}},{}],394:[function(t,e,r){e.exports=function(t,e,r,n,i){return t[0]=e,t[1]=r,t[2]=n,t[3]=i,t}},{}],395:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return r*r+n*n+i*i+a*a}},{}],396:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return e*e+r*r+n*n+i*i}},{}],397:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t[3]=e[3]-r[3],t}},{}],398:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}},{}],399:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,h=c*i+l*n-o*a,f=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+h*-l-f*-s,t[1]=h*c+p*-s+f*-o-u*-l,t[2]=f*c+p*-l+u*-s-h*-o,t[3]=e[3],t}},{}],400:[function(t,e,r){e.exports=function(t,e,r,a){return n[0]=a,n[1]=r,n[2]=e,n[3]=t,i[0]};var n=new Uint8Array(4),i=new Float32Array(n.buffer)},{}],401:[function(t,e,r){var n=t(\"glsl-tokenizer\"),i=t(\"atob-lite\");e.exports=function(t){for(var e=Array.isArray(t)?t:n(t),r=0;r<e.length;r++){var a=e[r];if(\"preprocessor\"===a.type){var o=a.data.match(/\\#define\\s+SHADER_NAME(_B64)?\\s+(.+)$/);if(o&&o[2]){var s=o[1],l=o[2];return(s?i(l):l).trim()}}}}},{\"atob-lite\":72,\"glsl-tokenizer\":408}],402:[function(t,e,r){e.exports=function(t){var e,r,k,T=0,A=0,M=l,S=[],E=[],C=1,L=0,P=0,O=!1,z=!1,I=\"\",D=a,R=n;\"300 es\"===(t=t||{}).version&&(D=s,R=o);return function(t){return E=[],null!==t?function(t){var r;T=0,k=(I+=t).length;for(;e=I[T],T<k;){switch(r=T,M){case u:T=U();break;case h:case f:T=j();break;case p:T=V();break;case d:T=G();break;case _:T=H();break;case g:T=Y();break;case c:T=W();break;case x:T=N();break;case l:T=B()}if(r!==T)switch(I[r]){case\"\\n\":L=0,++C;break;default:++L}}return A+=T,I=I.slice(T),E}(t.replace?t.replace(/\\r\\n/g,\"\\n\"):t):function(t){S.length&&F(S.join(\"\"));return M=b,F(\"(eof)\"),E}()};function F(t){t.length&&E.push({type:w[M],data:t,position:P,line:C,column:L})}function B(){return S=S.length?[]:S,\"/\"===r&&\"*\"===e?(P=A+T-1,M=u,r=e,T+1):\"/\"===r&&\"/\"===e?(P=A+T-1,M=h,r=e,T+1):\"#\"===e?(M=f,P=A+T,T):/\\s/.test(e)?(M=x,P=A+T,T):(O=/\\d/.test(e),z=/[^\\w_]/.test(e),P=A+T,M=O?d:z?p:c,T)}function N(){return/[^\\s]/g.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function j(){return\"\\r\"!==e&&\"\\n\"!==e||\"\\\\\"===r?(S.push(e),r=e,T+1):(F(S.join(\"\")),M=l,T)}function U(){return\"/\"===e&&\"*\"===r?(S.push(e),F(S.join(\"\")),M=l,T+1):(S.push(e),r=e,T+1)}function V(){if(\".\"===r&&/\\d/.test(e))return M=g,T;if(\"/\"===r&&\"*\"===e)return M=u,T;if(\"/\"===r&&\"/\"===e)return M=h,T;if(\".\"===e&&S.length){for(;q(S););return M=g,T}if(\";\"===e||\")\"===e||\"(\"===e){if(S.length)for(;q(S););return F(e),M=l,T+1}var t=2===S.length&&\"=\"!==e;if(/[\\w_\\d\\s]/.test(e)||t){for(;q(S););return M=l,T}return S.push(e),r=e,T+1}function q(t){for(var e,r,n=0;;){if(e=i.indexOf(t.slice(0,t.length+n).join(\"\")),r=i[e],-1===e){if(n--+t.length>0)continue;r=t.slice(0,1).join(\"\")}return F(r),P+=r.length,(S=S.slice(r.length)).length}}function H(){return/[^a-fA-F0-9]/.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function G(){return\".\"===e?(S.push(e),M=g,r=e,T+1):/[eE]/.test(e)?(S.push(e),M=g,r=e,T+1):\"x\"===e&&1===S.length&&\"0\"===S[0]?(M=_,S.push(e),r=e,T+1):/[^\\d]/.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function Y(){return\"f\"===e&&(S.push(e),r=e,T+=1),/[eE]/.test(e)?(S.push(e),r=e,T+1):\"-\"===e&&/[eE]/.test(r)?(S.push(e),r=e,T+1):/[^\\d]/.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function W(){if(/[^\\d\\w_]/.test(e)){var t=S.join(\"\");return M=R.indexOf(t)>-1?y:D.indexOf(t)>-1?m:v,F(S.join(\"\")),M=l,T}return S.push(e),r=e,T+1}};var n=t(\"./lib/literals\"),i=t(\"./lib/operators\"),a=t(\"./lib/builtins\"),o=t(\"./lib/literals-300es\"),s=t(\"./lib/builtins-300es\"),l=999,c=9999,u=0,h=1,f=2,p=3,d=4,g=5,v=6,m=7,y=8,x=9,b=10,_=11,w=[\"block-comment\",\"line-comment\",\"preprocessor\",\"operator\",\"integer\",\"float\",\"ident\",\"builtin\",\"keyword\",\"whitespace\",\"eof\",\"integer\"]},{\"./lib/builtins\":404,\"./lib/builtins-300es\":403,\"./lib/literals\":406,\"./lib/literals-300es\":405,\"./lib/operators\":407}],403:[function(t,e,r){var n=t(\"./builtins\");n=n.slice().filter(function(t){return!/^(gl\\_|texture)/.test(t)}),e.exports=n.concat([\"gl_VertexID\",\"gl_InstanceID\",\"gl_Position\",\"gl_PointSize\",\"gl_FragCoord\",\"gl_FrontFacing\",\"gl_FragDepth\",\"gl_PointCoord\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexUniformVectors\",\"gl_MaxVertexOutputVectors\",\"gl_MaxFragmentInputVectors\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxTextureImageUnits\",\"gl_MaxFragmentUniformVectors\",\"gl_MaxDrawBuffers\",\"gl_MinProgramTexelOffset\",\"gl_MaxProgramTexelOffset\",\"gl_DepthRangeParameters\",\"gl_DepthRange\",\"trunc\",\"round\",\"roundEven\",\"isnan\",\"isinf\",\"floatBitsToInt\",\"floatBitsToUint\",\"intBitsToFloat\",\"uintBitsToFloat\",\"packSnorm2x16\",\"unpackSnorm2x16\",\"packUnorm2x16\",\"unpackUnorm2x16\",\"packHalf2x16\",\"unpackHalf2x16\",\"outerProduct\",\"transpose\",\"determinant\",\"inverse\",\"texture\",\"textureSize\",\"textureProj\",\"textureLod\",\"textureOffset\",\"texelFetch\",\"texelFetchOffset\",\"textureProjOffset\",\"textureLodOffset\",\"textureProjLod\",\"textureProjLodOffset\",\"textureGrad\",\"textureGradOffset\",\"textureProjGrad\",\"textureProjGradOffset\"])},{\"./builtins\":404}],404:[function(t,e,r){e.exports=[\"abs\",\"acos\",\"all\",\"any\",\"asin\",\"atan\",\"ceil\",\"clamp\",\"cos\",\"cross\",\"dFdx\",\"dFdy\",\"degrees\",\"distance\",\"dot\",\"equal\",\"exp\",\"exp2\",\"faceforward\",\"floor\",\"fract\",\"gl_BackColor\",\"gl_BackLightModelProduct\",\"gl_BackLightProduct\",\"gl_BackMaterial\",\"gl_BackSecondaryColor\",\"gl_ClipPlane\",\"gl_ClipVertex\",\"gl_Color\",\"gl_DepthRange\",\"gl_DepthRangeParameters\",\"gl_EyePlaneQ\",\"gl_EyePlaneR\",\"gl_EyePlaneS\",\"gl_EyePlaneT\",\"gl_Fog\",\"gl_FogCoord\",\"gl_FogFragCoord\",\"gl_FogParameters\",\"gl_FragColor\",\"gl_FragCoord\",\"gl_FragData\",\"gl_FragDepth\",\"gl_FragDepthEXT\",\"gl_FrontColor\",\"gl_FrontFacing\",\"gl_FrontLightModelProduct\",\"gl_FrontLightProduct\",\"gl_FrontMaterial\",\"gl_FrontSecondaryColor\",\"gl_LightModel\",\"gl_LightModelParameters\",\"gl_LightModelProducts\",\"gl_LightProducts\",\"gl_LightSource\",\"gl_LightSourceParameters\",\"gl_MaterialParameters\",\"gl_MaxClipPlanes\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxDrawBuffers\",\"gl_MaxFragmentUniformComponents\",\"gl_MaxLights\",\"gl_MaxTextureCoords\",\"gl_MaxTextureImageUnits\",\"gl_MaxTextureUnits\",\"gl_MaxVaryingFloats\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxVertexUniformComponents\",\"gl_ModelViewMatrix\",\"gl_ModelViewMatrixInverse\",\"gl_ModelViewMatrixInverseTranspose\",\"gl_ModelViewMatrixTranspose\",\"gl_ModelViewProjectionMatrix\",\"gl_ModelViewProjectionMatrixInverse\",\"gl_ModelViewProjectionMatrixInverseTranspose\",\"gl_ModelViewProjectionMatrixTranspose\",\"gl_MultiTexCoord0\",\"gl_MultiTexCoord1\",\"gl_MultiTexCoord2\",\"gl_MultiTexCoord3\",\"gl_MultiTexCoord4\",\"gl_MultiTexCoord5\",\"gl_MultiTexCoord6\",\"gl_MultiTexCoord7\",\"gl_Normal\",\"gl_NormalMatrix\",\"gl_NormalScale\",\"gl_ObjectPlaneQ\",\"gl_ObjectPlaneR\",\"gl_ObjectPlaneS\",\"gl_ObjectPlaneT\",\"gl_Point\",\"gl_PointCoord\",\"gl_PointParameters\",\"gl_PointSize\",\"gl_Position\",\"gl_ProjectionMatrix\",\"gl_ProjectionMatrixInverse\",\"gl_ProjectionMatrixInverseTranspose\",\"gl_ProjectionMatrixTranspose\",\"gl_SecondaryColor\",\"gl_TexCoord\",\"gl_TextureEnvColor\",\"gl_TextureMatrix\",\"gl_TextureMatrixInverse\",\"gl_TextureMatrixInverseTranspose\",\"gl_TextureMatrixTranspose\",\"gl_Vertex\",\"greaterThan\",\"greaterThanEqual\",\"inversesqrt\",\"length\",\"lessThan\",\"lessThanEqual\",\"log\",\"log2\",\"matrixCompMult\",\"max\",\"min\",\"mix\",\"mod\",\"normalize\",\"not\",\"notEqual\",\"pow\",\"radians\",\"reflect\",\"refract\",\"sign\",\"sin\",\"smoothstep\",\"sqrt\",\"step\",\"tan\",\"texture2D\",\"texture2DLod\",\"texture2DProj\",\"texture2DProjLod\",\"textureCube\",\"textureCubeLod\",\"texture2DLodEXT\",\"texture2DProjLodEXT\",\"textureCubeLodEXT\",\"texture2DGradEXT\",\"texture2DProjGradEXT\",\"textureCubeGradEXT\"]},{}],405:[function(t,e,r){var n=t(\"./literals\");e.exports=n.slice().concat([\"layout\",\"centroid\",\"smooth\",\"case\",\"mat2x2\",\"mat2x3\",\"mat2x4\",\"mat3x2\",\"mat3x3\",\"mat3x4\",\"mat4x2\",\"mat4x3\",\"mat4x4\",\"uint\",\"uvec2\",\"uvec3\",\"uvec4\",\"samplerCubeShadow\",\"sampler2DArray\",\"sampler2DArrayShadow\",\"isampler2D\",\"isampler3D\",\"isamplerCube\",\"isampler2DArray\",\"usampler2D\",\"usampler3D\",\"usamplerCube\",\"usampler2DArray\",\"coherent\",\"restrict\",\"readonly\",\"writeonly\",\"resource\",\"atomic_uint\",\"noperspective\",\"patch\",\"sample\",\"subroutine\",\"common\",\"partition\",\"active\",\"filter\",\"image1D\",\"image2D\",\"image3D\",\"imageCube\",\"iimage1D\",\"iimage2D\",\"iimage3D\",\"iimageCube\",\"uimage1D\",\"uimage2D\",\"uimage3D\",\"uimageCube\",\"image1DArray\",\"image2DArray\",\"iimage1DArray\",\"iimage2DArray\",\"uimage1DArray\",\"uimage2DArray\",\"image1DShadow\",\"image2DShadow\",\"image1DArrayShadow\",\"image2DArrayShadow\",\"imageBuffer\",\"iimageBuffer\",\"uimageBuffer\",\"sampler1DArray\",\"sampler1DArrayShadow\",\"isampler1D\",\"isampler1DArray\",\"usampler1D\",\"usampler1DArray\",\"isampler2DRect\",\"usampler2DRect\",\"samplerBuffer\",\"isamplerBuffer\",\"usamplerBuffer\",\"sampler2DMS\",\"isampler2DMS\",\"usampler2DMS\",\"sampler2DMSArray\",\"isampler2DMSArray\",\"usampler2DMSArray\"])},{\"./literals\":406}],406:[function(t,e,r){e.exports=[\"precision\",\"highp\",\"mediump\",\"lowp\",\"attribute\",\"const\",\"uniform\",\"varying\",\"break\",\"continue\",\"do\",\"for\",\"while\",\"if\",\"else\",\"in\",\"out\",\"inout\",\"float\",\"int\",\"void\",\"bool\",\"true\",\"false\",\"discard\",\"return\",\"mat2\",\"mat3\",\"mat4\",\"vec2\",\"vec3\",\"vec4\",\"ivec2\",\"ivec3\",\"ivec4\",\"bvec2\",\"bvec3\",\"bvec4\",\"sampler1D\",\"sampler2D\",\"sampler3D\",\"samplerCube\",\"sampler1DShadow\",\"sampler2DShadow\",\"struct\",\"asm\",\"class\",\"union\",\"enum\",\"typedef\",\"template\",\"this\",\"packed\",\"goto\",\"switch\",\"default\",\"inline\",\"noinline\",\"volatile\",\"public\",\"static\",\"extern\",\"external\",\"interface\",\"long\",\"short\",\"double\",\"half\",\"fixed\",\"unsigned\",\"input\",\"output\",\"hvec2\",\"hvec3\",\"hvec4\",\"dvec2\",\"dvec3\",\"dvec4\",\"fvec2\",\"fvec3\",\"fvec4\",\"sampler2DRect\",\"sampler3DRect\",\"sampler2DRectShadow\",\"sizeof\",\"cast\",\"namespace\",\"using\"]},{}],407:[function(t,e,r){e.exports=[\"<<=\",\">>=\",\"++\",\"--\",\"<<\",\">>\",\"<=\",\">=\",\"==\",\"!=\",\"&&\",\"||\",\"+=\",\"-=\",\"*=\",\"/=\",\"%=\",\"&=\",\"^^\",\"^=\",\"|=\",\"(\",\")\",\"[\",\"]\",\".\",\"!\",\"~\",\"*\",\"/\",\"%\",\"+\",\"-\",\"<\",\">\",\"&\",\"^\",\"|\",\"?\",\":\",\"=\",\",\",\";\",\"{\",\"}\"]},{}],408:[function(t,e,r){var n=t(\"./index\");e.exports=function(t,e){var r=n(e),i=[];return i=(i=i.concat(r(t))).concat(r(null))}},{\"./index\":402}],409:[function(t,e,r){e.exports=function(t){\"string\"==typeof t&&(t=[t]);for(var e=[].slice.call(arguments,1),r=[],n=0;n<t.length-1;n++)r.push(t[n],e[n]||\"\");return r.push(t[n]),r.join(\"\")}},{}],410:[function(t,e,r){(function(r){\"use strict\";var n,i=t(\"is-browser\");n=\"function\"==typeof r.matchMedia?!r.matchMedia(\"(hover: none)\").matches:i,e.exports=n}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"is-browser\":417}],411:[function(t,e,r){\"use strict\";var n=t(\"is-browser\");e.exports=n&&function(){var t=!1;try{var e=Object.defineProperty({},\"passive\",{get:function(){t=!0}});window.addEventListener(\"test\",null,e),window.removeEventListener(\"test\",null,e)}catch(e){t=!1}return t}()},{\"is-browser\":417}],412:[function(t,e,r){r.read=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?i-1:0,f=r?-1:1,p=t[e+h];for(h+=f,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+h],h+=f,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},r.write=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,h=u>>1,f=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,i),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g}},{}],413:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(0===r)throw new Error(\"Must have at least d+1 points\");var i=t[0].length;if(r<=i)throw new Error(\"Must input at least d+1 points\");var o=t.slice(0,i+1),s=n.apply(void 0,o);if(0===s)throw new Error(\"Input not in general position\");for(var l=new Array(i+1),u=0;u<=i;++u)l[u]=u;s<0&&(l[0]=1,l[1]=0);for(var h=new a(l,new Array(i+1),!1),f=h.adjacent,p=new Array(i+2),u=0;u<=i;++u){for(var d=l.slice(),g=0;g<=i;++g)g===u&&(d[g]=-1);var v=d[0];d[0]=d[1],d[1]=v;var m=new a(d,new Array(i+1),!0);f[u]=m,p[u]=m}p[i+1]=h;for(var u=0;u<=i;++u)for(var d=f[u].vertices,y=f[u].adjacent,g=0;g<=i;++g){var x=d[g];if(x<0)y[g]=h;else for(var b=0;b<=i;++b)f[b].vertices.indexOf(x)<0&&(y[g]=f[b])}for(var _=new c(i,o,p),w=!!e,u=i+1;u<r;++u)_.insert(t[u],w);return _.boundary()};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\").compareCells;function a(t,e,r){this.vertices=t,this.adjacent=e,this.boundary=r,this.lastVisited=-1}function o(t,e,r){this.vertices=t,this.cell=e,this.index=r}function s(t,e){return i(t.vertices,e.vertices)}a.prototype.flip=function(){var t=this.vertices[0];this.vertices[0]=this.vertices[1],this.vertices[1]=t;var e=this.adjacent[0];this.adjacent[0]=this.adjacent[1],this.adjacent[1]=e};var l=[];function c(t,e,r){this.dimension=t,this.vertices=e,this.simplices=r,this.interior=r.filter(function(t){return!t.boundary}),this.tuple=new Array(t+1);for(var i=0;i<=t;++i)this.tuple[i]=this.vertices[i];var a=l[t];a||(a=l[t]=function(t){for(var e=[\"function orient(){var tuple=this.tuple;return test(\"],r=0;r<=t;++r)r>0&&e.push(\",\"),e.push(\"tuple[\",r,\"]\");e.push(\")}return orient\");var i=new Function(\"test\",e.join(\"\")),a=n[t+1];return a||(a=n),i(a)}(t)),this.orient=a}var u=c.prototype;u.handleBoundaryDegeneracy=function(t,e){var r=this.dimension,n=this.vertices.length-1,i=this.tuple,a=this.vertices,o=[t];for(t.lastVisited=-n;o.length>0;){(t=o.pop()).vertices;for(var s=t.adjacent,l=0;l<=r;++l){var c=s[l];if(c.boundary&&!(c.lastVisited<=-n)){for(var u=c.vertices,h=0;h<=r;++h){var f=u[h];i[h]=f<0?e:a[f]}var p=this.orient();if(p>0)return c;c.lastVisited=-n,0===p&&o.push(c)}}}return null},u.walk=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,a=this.tuple,o=e?this.interior.length*Math.random()|0:this.interior.length-1,s=this.interior[o];t:for(;!s.boundary;){for(var l=s.vertices,c=s.adjacent,u=0;u<=n;++u)a[u]=i[l[u]];s.lastVisited=r;for(u=0;u<=n;++u){var h=c[u];if(!(h.lastVisited>=r)){var f=a[u];a[u]=t;var p=this.orient();if(a[u]=f,p<0){s=h;continue t}h.boundary?h.lastVisited=-r:h.lastVisited=r}}return}return s},u.addPeaks=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,l=this.tuple,c=this.interior,u=this.simplices,h=[e];e.lastVisited=r,e.vertices[e.vertices.indexOf(-1)]=r,e.boundary=!1,c.push(e);for(var f=[];h.length>0;){var p=(e=h.pop()).vertices,d=e.adjacent,g=p.indexOf(r);if(!(g<0))for(var v=0;v<=n;++v)if(v!==g){var m=d[v];if(m.boundary&&!(m.lastVisited>=r)){var y=m.vertices;if(m.lastVisited!==-r){for(var x=0,b=0;b<=n;++b)y[b]<0?(x=b,l[b]=t):l[b]=i[y[b]];if(this.orient()>0){y[x]=r,m.boundary=!1,c.push(m),h.push(m),m.lastVisited=r;continue}m.lastVisited=-r}var _=m.adjacent,w=p.slice(),k=d.slice(),T=new a(w,k,!0);u.push(T);var A=_.indexOf(e);if(!(A<0)){_[A]=T,k[g]=m,w[v]=-1,k[v]=e,d[v]=T,T.flip();for(b=0;b<=n;++b){var M=w[b];if(!(M<0||M===r)){for(var S=new Array(n-1),E=0,C=0;C<=n;++C){var L=w[C];L<0||C===b||(S[E++]=L)}f.push(new o(S,T,b))}}}}}}f.sort(s);for(v=0;v+1<f.length;v+=2){var P=f[v],O=f[v+1],z=P.index,I=O.index;z<0||I<0||(P.cell.adjacent[P.index]=O.cell,O.cell.adjacent[O.index]=P.cell)}},u.insert=function(t,e){var r=this.vertices;r.push(t);var n=this.walk(t,e);if(n){for(var i=this.dimension,a=this.tuple,o=0;o<=i;++o){var s=n.vertices[o];a[o]=s<0?t:r[s]}var l=this.orient(a);l<0||(0!==l||(n=this.handleBoundaryDegeneracy(n,t)))&&this.addPeaks(t,n)}},u.boundary=function(){for(var t=this.dimension,e=[],r=this.simplices,n=r.length,i=0;i<n;++i){var a=r[i];if(a.boundary){for(var o=new Array(t),s=a.vertices,l=0,c=0,u=0;u<=t;++u)s[u]>=0?o[l++]=s[u]:c=1&u;if(c===(1&t)){var h=o[0];o[0]=o[1],o[1]=h}e.push(o)}}return e}},{\"robust-orientation\":510,\"simplicial-complex\":520}],414:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=0,a=1;function o(t,e,r,n,i){this.mid=t,this.left=e,this.right=r,this.leftPoints=n,this.rightPoints=i,this.count=(e?e.count:0)+(r?r.count:0)+n.length}e.exports=function(t){if(!t||0===t.length)return new x(null);return new x(y(t))};var s=o.prototype;function l(t,e){t.mid=e.mid,t.left=e.left,t.right=e.right,t.leftPoints=e.leftPoints,t.rightPoints=e.rightPoints,t.count=e.count}function c(t,e){var r=y(e);t.mid=r.mid,t.left=r.left,t.right=r.right,t.leftPoints=r.leftPoints,t.rightPoints=r.rightPoints,t.count=r.count}function u(t,e){var r=t.intervals([]);r.push(e),c(t,r)}function h(t,e){var r=t.intervals([]),n=r.indexOf(e);return n<0?i:(r.splice(n,1),c(t,r),a)}function f(t,e,r){for(var n=0;n<t.length&&t[n][0]<=e;++n){var i=r(t[n]);if(i)return i}}function p(t,e,r){for(var n=t.length-1;n>=0&&t[n][1]>=e;--n){var i=r(t[n]);if(i)return i}}function d(t,e){for(var r=0;r<t.length;++r){var n=e(t[r]);if(n)return n}}function g(t,e){return t-e}function v(t,e){var r=t[0]-e[0];return r||t[1]-e[1]}function m(t,e){var r=t[1]-e[1];return r||t[0]-e[0]}function y(t){if(0===t.length)return null;for(var e=[],r=0;r<t.length;++r)e.push(t[r][0],t[r][1]);e.sort(g);var n=e[e.length>>1],i=[],a=[],s=[];for(r=0;r<t.length;++r){var l=t[r];l[1]<n?i.push(l):n<l[0]?a.push(l):s.push(l)}var c=s,u=s.slice();return c.sort(v),u.sort(m),new o(n,y(i),y(a),c,u)}function x(t){this.root=t}s.intervals=function(t){return t.push.apply(t,this.leftPoints),this.left&&this.left.intervals(t),this.right&&this.right.intervals(t),t},s.insert=function(t){var e=this.count-this.leftPoints.length;if(this.count+=1,t[1]<this.mid)this.left?4*(this.left.count+1)>3*(e+1)?u(this,t):this.left.insert(t):this.left=y([t]);else if(t[0]>this.mid)this.right?4*(this.right.count+1)>3*(e+1)?u(this,t):this.right.insert(t):this.right=y([t]);else{var r=n.ge(this.leftPoints,t,v),i=n.ge(this.rightPoints,t,m);this.leftPoints.splice(r,0,t),this.rightPoints.splice(i,0,t)}},s.remove=function(t){var e=this.count-this.leftPoints;if(t[1]<this.mid)return this.left?4*(this.right?this.right.count:0)>3*(e-1)?h(this,t):2===(c=this.left.remove(t))?(this.left=null,this.count-=1,a):(c===a&&(this.count-=1),c):i;if(t[0]>this.mid)return this.right?4*(this.left?this.left.count:0)>3*(e-1)?h(this,t):2===(c=this.right.remove(t))?(this.right=null,this.count-=1,a):(c===a&&(this.count-=1),c):i;if(1===this.count)return this.leftPoints[0]===t?2:i;if(1===this.leftPoints.length&&this.leftPoints[0]===t){if(this.left&&this.right){for(var r=this,o=this.left;o.right;)r=o,o=o.right;if(r===this)o.right=this.right;else{var s=this.left,c=this.right;r.count-=o.count,r.right=o.left,o.left=s,o.right=c}l(this,o),this.count=(this.left?this.left.count:0)+(this.right?this.right.count:0)+this.leftPoints.length}else this.left?l(this,this.left):l(this,this.right);return a}for(s=n.ge(this.leftPoints,t,v);s<this.leftPoints.length&&this.leftPoints[s][0]===t[0];++s)if(this.leftPoints[s]===t){this.count-=1,this.leftPoints.splice(s,1);for(c=n.ge(this.rightPoints,t,m);c<this.rightPoints.length&&this.rightPoints[c][1]===t[1];++c)if(this.rightPoints[c]===t)return this.rightPoints.splice(c,1),a}return i},s.queryPoint=function(t,e){if(t<this.mid){if(this.left)if(r=this.left.queryPoint(t,e))return r;return f(this.leftPoints,t,e)}if(t>this.mid){var r;if(this.right)if(r=this.right.queryPoint(t,e))return r;return p(this.rightPoints,t,e)}return d(this.leftPoints,e)},s.queryInterval=function(t,e,r){var n;if(t<this.mid&&this.left&&(n=this.left.queryInterval(t,e,r)))return n;if(e>this.mid&&this.right&&(n=this.right.queryInterval(t,e,r)))return n;return e<this.mid?f(this.leftPoints,e,r):t>this.mid?p(this.rightPoints,t,r):d(this.leftPoints,r)};var b=x.prototype;b.insert=function(t){this.root?this.root.insert(t):this.root=new o(t[0],null,null,[t],[t])},b.remove=function(t){if(this.root){var e=this.root.remove(t);return 2===e&&(this.root=null),e!==i}return!1},b.queryPoint=function(t,e){if(this.root)return this.root.queryPoint(t,e)},b.queryInterval=function(t,e,r){if(t<=e&&this.root)return this.root.queryInterval(t,e,r)},Object.defineProperty(b,\"count\",{get:function(){return this.root?this.root.count:0}}),Object.defineProperty(b,\"intervals\",{get:function(){return this.root?this.root.intervals([]):[]}})},{\"binary-search-bounds\":91}],415:[function(t,e,r){\"use strict\";e.exports=function(t,e){e=e||new Array(t.length);for(var r=0;r<t.length;++r)e[t[r]]=r;return e}},{}],416:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=r;return e}},{}],417:[function(t,e,r){e.exports=!0},{}],418:[function(t,e,r){function n(t){return!!t.constructor&&\"function\"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}e.exports=function(t){return null!=t&&(n(t)||function(t){return\"function\"==typeof t.readFloatLE&&\"function\"==typeof t.slice&&n(t.slice(0,0))}(t)||!!t._isBuffer)}},{}],419:[function(t,e,r){\"use strict\";e.exports=\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion))},{}],420:[function(t,e,r){\"use strict\";e.exports=a,e.exports.isMobile=a;var n=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i,i=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino|android|ipad|playbook|silk/i;function a(t){t||(t={});var e=t.ua;return e||\"undefined\"==typeof navigator||(e=navigator.userAgent),e&&e.headers&&\"string\"==typeof e.headers[\"user-agent\"]&&(e=e.headers[\"user-agent\"]),\"string\"==typeof e&&(t.tablet?i.test(e):n.test(e))}},{}],421:[function(t,e,r){\"use strict\";e.exports=function(t){var e=typeof t;return null!==t&&(\"object\"===e||\"function\"===e)}},{}],422:[function(t,e,r){\"use strict\";var n=Object.prototype.toString;e.exports=function(t){var e;return\"[object Object]\"===n.call(t)&&(null===(e=Object.getPrototypeOf(t))||e===Object.getPrototypeOf({}))}},{}],423:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=t.length,n=0;n<r;n++)if(((e=t.charCodeAt(n))<9||e>13)&&32!==e&&133!==e&&160!==e&&5760!==e&&6158!==e&&(e<8192||e>8205)&&8232!==e&&8233!==e&&8239!==e&&8287!==e&&8288!==e&&12288!==e&&65279!==e)return!1;return!0}},{}],424:[function(t,e,r){\"use strict\";e.exports=function(t){return\"string\"==typeof t&&(t=t.trim(),!!(/^[mzlhvcsqta]\\s*[-+.0-9][^mlhvzcsqta]+/i.test(t)&&/[\\dz]$/i.test(t)&&t.length>4))}},{}],425:[function(t,e,r){e.exports=function(t,e,r){return t*(1-r)+e*r}},{}],426:[function(t,e,r){var n,i;n=this,i=function(){\"use strict\";var t,e,r;function n(n,i){if(t)if(e){var a=\"var sharedChunk = {}; (\"+t+\")(sharedChunk); (\"+e+\")(sharedChunk);\",o={};t(o),(r=i(o)).workerUrl=window.URL.createObjectURL(new Blob([a],{type:\"text/javascript\"}))}else e=i;else t=i}return n(0,function(t){function e(t,e){return t(e={exports:{}},e.exports),e.exports}var r=n;function n(t,e,r,n){this.cx=3*t,this.bx=3*(r-t)-this.cx,this.ax=1-this.cx-this.bx,this.cy=3*e,this.by=3*(n-e)-this.cy,this.ay=1-this.cy-this.by,this.p1x=t,this.p1y=n,this.p2x=r,this.p2y=n}n.prototype.sampleCurveX=function(t){return((this.ax*t+this.bx)*t+this.cx)*t},n.prototype.sampleCurveY=function(t){return((this.ay*t+this.by)*t+this.cy)*t},n.prototype.sampleCurveDerivativeX=function(t){return(3*this.ax*t+2*this.bx)*t+this.cx},n.prototype.solveCurveX=function(t,e){var r,n,i,a,o;for(void 0===e&&(e=1e-6),i=t,o=0;o<8;o++){if(a=this.sampleCurveX(i)-t,Math.abs(a)<e)return i;var s=this.sampleCurveDerivativeX(i);if(Math.abs(s)<1e-6)break;i-=a/s}if((i=t)<(r=0))return r;if(i>(n=1))return n;for(;r<n;){if(a=this.sampleCurveX(i),Math.abs(a-t)<e)return i;t>a?r=i:n=i,i=.5*(n-r)+r}return i},n.prototype.solve=function(t,e){return this.sampleCurveY(this.solveCurveX(t,e))};var i=a;function a(t,e){this.x=t,this.y=e}function o(t,e){if(Array.isArray(t)){if(!Array.isArray(e)||t.length!==e.length)return!1;for(var r=0;r<t.length;r++)if(!o(t[r],e[r]))return!1;return!0}if(\"object\"==typeof t&&null!==t&&null!==e){if(\"object\"!=typeof e)return!1;if(Object.keys(t).length!==Object.keys(e).length)return!1;for(var n in t)if(!o(t[n],e[n]))return!1;return!0}return t===e}function s(t,e,n,i){var a=new r(t,e,n,i);return function(t){return a.solve(t)}}a.prototype={clone:function(){return new a(this.x,this.y)},add:function(t){return this.clone()._add(t)},sub:function(t){return this.clone()._sub(t)},multByPoint:function(t){return this.clone()._multByPoint(t)},divByPoint:function(t){return this.clone()._divByPoint(t)},mult:function(t){return this.clone()._mult(t)},div:function(t){return this.clone()._div(t)},rotate:function(t){return this.clone()._rotate(t)},rotateAround:function(t,e){return this.clone()._rotateAround(t,e)},matMult:function(t){return this.clone()._matMult(t)},unit:function(){return this.clone()._unit()},perp:function(){return this.clone()._perp()},round:function(){return this.clone()._round()},mag:function(){return Math.sqrt(this.x*this.x+this.y*this.y)},equals:function(t){return this.x===t.x&&this.y===t.y},dist:function(t){return Math.sqrt(this.distSqr(t))},distSqr:function(t){var e=t.x-this.x,r=t.y-this.y;return e*e+r*r},angle:function(){return Math.atan2(this.y,this.x)},angleTo:function(t){return Math.atan2(this.y-t.y,this.x-t.x)},angleWith:function(t){return this.angleWithSep(t.x,t.y)},angleWithSep:function(t,e){return Math.atan2(this.x*e-this.y*t,this.x*t+this.y*e)},_matMult:function(t){var e=t[0]*this.x+t[1]*this.y,r=t[2]*this.x+t[3]*this.y;return this.x=e,this.y=r,this},_add:function(t){return this.x+=t.x,this.y+=t.y,this},_sub:function(t){return this.x-=t.x,this.y-=t.y,this},_mult:function(t){return this.x*=t,this.y*=t,this},_div:function(t){return this.x/=t,this.y/=t,this},_multByPoint:function(t){return this.x*=t.x,this.y*=t.y,this},_divByPoint:function(t){return this.x/=t.x,this.y/=t.y,this},_unit:function(){return this._div(this.mag()),this},_perp:function(){var t=this.y;return this.y=this.x,this.x=-t,this},_rotate:function(t){var e=Math.cos(t),r=Math.sin(t),n=e*this.x-r*this.y,i=r*this.x+e*this.y;return this.x=n,this.y=i,this},_rotateAround:function(t,e){var r=Math.cos(t),n=Math.sin(t),i=e.x+r*(this.x-e.x)-n*(this.y-e.y),a=e.y+n*(this.x-e.x)+r*(this.y-e.y);return this.x=i,this.y=a,this},_round:function(){return this.x=Math.round(this.x),this.y=Math.round(this.y),this}},a.convert=function(t){return t instanceof a?t:Array.isArray(t)?new a(t[0],t[1]):t};var l=s(.25,.1,.25,1);function c(t,e,r){return Math.min(r,Math.max(e,t))}function u(t,e,r){var n=r-e,i=((t-e)%n+n)%n+e;return i===e?r:i}function h(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}var f=1;function p(){return f++}function d(){return function t(e){return e?(e^16*Math.random()>>e/4).toString(16):([1e7]+-[1e3]+-4e3+-8e3+-1e11).replace(/[018]/g,t)}()}function g(t){return!!t&&/^[0-9a-f]{8}-[0-9a-f]{4}-[4][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$/i.test(t)}function v(t,e){t.forEach(function(t){e[t]&&(e[t]=e[t].bind(e))})}function m(t,e){return-1!==t.indexOf(e,t.length-e.length)}function y(t,e,r){var n={};for(var i in t)n[i]=e.call(r||this,t[i],i,t);return n}function x(t,e,r){var n={};for(var i in t)e.call(r||this,t[i],i,t)&&(n[i]=t[i]);return n}function b(t){return Array.isArray(t)?t.map(b):\"object\"==typeof t&&t?y(t,b):t}var _={};function w(t){_[t]||(\"undefined\"!=typeof console&&console.warn(t),_[t]=!0)}function k(t,e,r){return(r.y-t.y)*(e.x-t.x)>(e.y-t.y)*(r.x-t.x)}function T(t){for(var e=0,r=0,n=t.length,i=n-1,a=void 0,o=void 0;r<n;i=r++)a=t[r],e+=((o=t[i]).x-a.x)*(a.y+o.y);return e}function A(t){var e={};if(t.replace(/(?:^|(?:\\s*\\,\\s*))([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)(?:\\=(?:([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)|(?:\\\"((?:[^\"\\\\]|\\\\.)*)\\\")))?/g,function(t,r,n,i){var a=n||i;return e[r]=!a||a.toLowerCase(),\"\"}),e[\"max-age\"]){var r=parseInt(e[\"max-age\"],10);isNaN(r)?delete e[\"max-age\"]:e[\"max-age\"]=r}return e}function M(t){try{var e=self[t];return e.setItem(\"_mapbox_test_\",1),e.removeItem(\"_mapbox_test_\"),!0}catch(t){return!1}}var S,E,C,L=self.performance&&self.performance.now?self.performance.now.bind(self.performance):Date.now.bind(Date),P=self.requestAnimationFrame||self.mozRequestAnimationFrame||self.webkitRequestAnimationFrame||self.msRequestAnimationFrame,O=self.cancelAnimationFrame||self.mozCancelAnimationFrame||self.webkitCancelAnimationFrame||self.msCancelAnimationFrame,z={now:L,frame:function(t){var e=P(t);return{cancel:function(){return O(e)}}},getImageData:function(t){var e=self.document.createElement(\"canvas\"),r=e.getContext(\"2d\");if(!r)throw new Error(\"failed to create canvas 2d context\");return e.width=t.width,e.height=t.height,r.drawImage(t,0,0,t.width,t.height),r.getImageData(0,0,t.width,t.height)},resolveURL:function(t){return S||(S=self.document.createElement(\"a\")),S.href=t,S.href},hardwareConcurrency:self.navigator.hardwareConcurrency||4,get devicePixelRatio(){return self.devicePixelRatio}},I={API_URL:\"https://api.mapbox.com\",get EVENTS_URL(){return this.API_URL?0===this.API_URL.indexOf(\"https://api.mapbox.cn\")?\"https://events.mapbox.cn/events/v2\":0===this.API_URL.indexOf(\"https://api.mapbox.com\")?\"https://events.mapbox.com/events/v2\":null:null},FEEDBACK_URL:\"https://apps.mapbox.com/feedback\",REQUIRE_ACCESS_TOKEN:!0,ACCESS_TOKEN:null,MAX_PARALLEL_IMAGE_REQUESTS:16},D={supported:!1,testSupport:function(t){!R&&C&&(F?B(t):E=t)}},R=!1,F=!1;function B(t){var e=t.createTexture();t.bindTexture(t.TEXTURE_2D,e);try{if(t.texImage2D(t.TEXTURE_2D,0,t.RGBA,t.RGBA,t.UNSIGNED_BYTE,C),t.isContextLost())return;D.supported=!0}catch(t){}t.deleteTexture(e),R=!0}self.document&&((C=self.document.createElement(\"img\")).onload=function(){E&&B(E),E=null,F=!0},C.onerror=function(){R=!0,E=null},C.src=\"data:image/webp;base64,UklGRh4AAABXRUJQVlA4TBEAAAAvAQAAAAfQ//73v/+BiOh/AAA=\");var N=\"01\",j=function(t){this._transformRequestFn=t,this._createSkuToken()};j.prototype._createSkuToken=function(){var t=function(){for(var t=\"\",e=0;e<10;e++)t+=\"0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ\"[Math.floor(62*Math.random())];return{token:[\"1\",N,t].join(\"\"),tokenExpiresAt:Date.now()+432e5}}();this._skuToken=t.token,this._skuTokenExpiresAt=t.tokenExpiresAt},j.prototype._isSkuTokenExpired=function(){return Date.now()>this._skuTokenExpiresAt},j.prototype.transformRequest=function(t,e){return this._transformRequestFn&&this._transformRequestFn(t,e)||{url:t}},j.prototype.normalizeStyleURL=function(t,e){return Y(t,e)},j.prototype.normalizeGlyphsURL=function(t,e){return W(t,e)},j.prototype.normalizeSourceURL=function(t,e){return X(t,e)},j.prototype.normalizeSpriteURL=function(t,e,r,n){return Z(t,e,r,n)},j.prototype.normalizeTileURL=function(t,e,r){return this._isSkuTokenExpired()&&this._createSkuToken(),K(t,e,r,this._skuToken)},j.prototype.canonicalizeTileURL=function(t){return Q(t)},j.prototype.canonicalizeTileset=function(t,e){return tt(t,e)};var U=\"See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\";function V(t,e){var r=rt(I.API_URL);if(t.protocol=r.protocol,t.authority=r.authority,\"/\"!==r.path&&(t.path=\"\"+r.path+t.path),!I.REQUIRE_ACCESS_TOKEN)return nt(t);if(!(e=e||I.ACCESS_TOKEN))throw new Error(\"An API access token is required to use Mapbox GL. \"+U);if(\"s\"===e[0])throw new Error(\"Use a public access token (pk.*) with Mapbox GL, not a secret access token (sk.*). \"+U);return t.params.push(\"access_token=\"+e),nt(t)}function q(t){return 0===t.indexOf(\"mapbox:\")}var H=/^((https?:)?\\/\\/)?([^\\/]+\\.)?mapbox\\.c(n|om)(\\/|\\?|$)/i;function G(t){return H.test(t)}var Y=function(t,e){if(!q(t))return t;var r=rt(t);return r.path=\"/styles/v1\"+r.path,V(r,e)},W=function(t,e){if(!q(t))return t;var r=rt(t);return r.path=\"/fonts/v1\"+r.path,V(r,e)},X=function(t,e){if(!q(t))return t;var r=rt(t);return r.path=\"/v4/\"+r.authority+\".json\",r.params.push(\"secure\"),V(r,e)},Z=function(t,e,r,n){var i=rt(t);return q(t)?(i.path=\"/styles/v1\"+i.path+\"/sprite\"+e+r,V(i,n)):(i.path+=\"\"+e+r,nt(i))},J=/(\\.(png|jpg)\\d*)(?=$)/,K=function(t,e,r,n){if(!e||!q(e))return t;var i=rt(t),a=z.devicePixelRatio>=2||512===r?\"@2x\":\"\",o=D.supported?\".webp\":\"$1\";return i.path=i.path.replace(J,\"\"+a+o),i.path=\"/v4\"+i.path,I.REQUIRE_ACCESS_TOKEN&&I.ACCESS_TOKEN&&n&&i.params.push(\"sku=\"+n),V(i)},$=/\\.[\\w]+$/,Q=function(t){var e=rt(t);if(!e.path.match(/(^\\/v4\\/)/)||!e.path.match($))return t;var r=\"mapbox://tiles/\";r+=e.path.replace(\"/v4/\",\"\");var n=e.params.filter(function(t){return!t.match(/^access_token=/)});return n.length&&(r+=\"?\"+n.join(\"&\")),r},tt=function(t,e){if(!q(e))return t.tiles||[];for(var r=[],n=0,i=t.tiles;n<i.length;n+=1){var a=i[n],o=Q(a);r.push(o)}return r},et=/^(\\w+):\\/\\/([^\\/?]*)(\\/[^?]+)?\\??(.+)?/;function rt(t){var e=t.match(et);if(!e)throw new Error(\"Unable to parse URL object\");return{protocol:e[1],authority:e[2],path:e[3]||\"/\",params:e[4]?e[4].split(\"&\"):[]}}function nt(t){var e=t.params.length?\"?\"+t.params.join(\"&\"):\"\";return t.protocol+\"://\"+t.authority+t.path+e}function it(t){if(!t)return null;var e,r=t.split(\".\");if(!r||3!==r.length)return null;try{return JSON.parse((e=r[1],decodeURIComponent(self.atob(e).split(\"\").map(function(t){return\"%\"+(\"00\"+t.charCodeAt(0).toString(16)).slice(-2)}).join(\"\"))))}catch(t){return null}}var at=function(t){this.type=t,this.anonId=null,this.eventData={},this.queue=[],this.pendingRequest=null};at.prototype.getStorageKey=function(t){var e,r=it(I.ACCESS_TOKEN),n=\"\";return r&&r.u?(e=r.u,n=self.btoa(encodeURIComponent(e).replace(/%([0-9A-F]{2})/g,function(t,e){return String.fromCharCode(Number(\"0x\"+e))}))):n=I.ACCESS_TOKEN||\"\",t?\"mapbox.eventData.\"+t+\":\"+n:\"mapbox.eventData:\"+n},at.prototype.fetchEventData=function(){var t=M(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{var n=self.localStorage.getItem(e);n&&(this.eventData=JSON.parse(n));var i=self.localStorage.getItem(r);i&&(this.anonId=i)}catch(t){w(\"Unable to read from LocalStorage\")}},at.prototype.saveEventData=function(){var t=M(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{self.localStorage.setItem(r,this.anonId),Object.keys(this.eventData).length>=1&&self.localStorage.setItem(e,JSON.stringify(this.eventData))}catch(t){w(\"Unable to write to LocalStorage\")}},at.prototype.processRequests=function(){},at.prototype.postEvent=function(t,e,r){var n=this;if(I.EVENTS_URL){var i=rt(I.EVENTS_URL);i.params.push(\"access_token=\"+(I.ACCESS_TOKEN||\"\"));var a={event:this.type,created:new Date(t).toISOString(),sdkIdentifier:\"mapbox-gl-js\",sdkVersion:\"1.1.1\",skuId:N,userId:this.anonId},o=e?h(a,e):a,s={url:nt(i),headers:{\"Content-Type\":\"text/plain\"},body:JSON.stringify([o])};this.pendingRequest=St(s,function(t){n.pendingRequest=null,r(t),n.saveEventData(),n.processRequests()})}},at.prototype.queueRequest=function(t){this.queue.push(t),this.processRequests()};var ot,st=function(t){function e(){t.call(this,\"map.load\"),this.success={},this.skuToken=\"\"}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.postMapLoadEvent=function(t,e,r){this.skuToken=r,I.EVENTS_URL&&I.ACCESS_TOKEN&&Array.isArray(t)&&t.some(function(t){return q(t)||G(t)})&&this.queueRequest({id:e,timestamp:Date.now()})},e.prototype.processRequests=function(){var t=this;if(!this.pendingRequest&&0!==this.queue.length){var e=this.queue.shift(),r=e.id,n=e.timestamp;r&&this.success[r]||(this.anonId||this.fetchEventData(),g(this.anonId)||(this.anonId=d()),this.postEvent(n,{skuToken:this.skuToken},function(e){e||r&&(t.success[r]=!0)}))}},e}(at),lt=new(function(t){function e(){t.call(this,\"appUserTurnstile\")}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.postTurnstileEvent=function(t){I.EVENTS_URL&&I.ACCESS_TOKEN&&Array.isArray(t)&&t.some(function(t){return q(t)||G(t)})&&this.queueRequest(Date.now())},e.prototype.processRequests=function(){var t=this;if(!this.pendingRequest&&0!==this.queue.length){this.anonId&&this.eventData.lastSuccess&&this.eventData.tokenU||this.fetchEventData();var e=it(I.ACCESS_TOKEN),r=e?e.u:I.ACCESS_TOKEN,n=r!==this.eventData.tokenU;g(this.anonId)||(this.anonId=d(),n=!0);var i=this.queue.shift();if(this.eventData.lastSuccess){var a=new Date(this.eventData.lastSuccess),o=new Date(i),s=(i-this.eventData.lastSuccess)/864e5;n=n||s>=1||s<-1||a.getDate()!==o.getDate()}else n=!0;if(!n)return this.processRequests();this.postEvent(i,{\"enabled.telemetry\":!1},function(e){e||(t.eventData.lastSuccess=i,t.eventData.tokenU=r)})}},e}(at)),ct=lt.postTurnstileEvent.bind(lt),ut=new st,ht=ut.postMapLoadEvent.bind(ut),ft=\"mapbox-tiles\",pt=500,dt=50,gt=42e4;function vt(t){var e=t.indexOf(\"?\");return e<0?t:t.slice(0,e)}var mt=1/0,yt={Unknown:\"Unknown\",Style:\"Style\",Source:\"Source\",Tile:\"Tile\",Glyphs:\"Glyphs\",SpriteImage:\"SpriteImage\",SpriteJSON:\"SpriteJSON\",Image:\"Image\"};\"function\"==typeof Object.freeze&&Object.freeze(yt);var xt=function(t){function e(e,r,n){401===r&&G(n)&&(e+=\": you may have provided an invalid Mapbox access token. See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\"),t.call(this,e),this.status=r,this.url=n,this.name=this.constructor.name,this.message=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.toString=function(){return this.name+\": \"+this.message+\" (\"+this.status+\"): \"+this.url},e}(Error);function bt(){return\"undefined\"!=typeof WorkerGlobalScope&&\"undefined\"!=typeof self&&self instanceof WorkerGlobalScope}var _t=bt()?function(){return self.worker&&self.worker.referrer}:function(){var t=self.location.origin;if(t&&\"null\"!==t&&\"file://\"!==t)return t+self.location.pathname};function wt(t,e){var r,n=new self.AbortController,i=new self.Request(t.url,{method:t.method||\"GET\",body:t.body,credentials:t.credentials,headers:t.headers,referrer:_t(),signal:n.signal}),a=!1,o=!1,s=(r=i.url).indexOf(\"sku=\")>0&&G(r);\"json\"===t.type&&i.headers.set(\"Accept\",\"application/json\");var l=function(r,n,a){if(!o){if(r&&\"SecurityError\"!==r.message&&w(r),n&&a)return c(n);var l=Date.now();self.fetch(i).then(function(r){if(r.ok){var n=s?r.clone():null;return c(r,n,l)}return e(new xt(r.statusText,r.status,t.url))}).catch(function(t){20!==t.code&&e(new Error(t.message))})}},c=function(r,n,s){(\"arrayBuffer\"===t.type?r.arrayBuffer():\"json\"===t.type?r.json():r.text()).then(function(t){o||(n&&s&&function(t,e,r){if(self.caches){var n={status:e.status,statusText:e.statusText,headers:new self.Headers};e.headers.forEach(function(t,e){return n.headers.set(e,t)});var i=A(e.headers.get(\"Cache-Control\")||\"\");i[\"no-store\"]||(i[\"max-age\"]&&n.headers.set(\"Expires\",new Date(r+1e3*i[\"max-age\"]).toUTCString()),new Date(n.headers.get(\"Expires\")).getTime()-r<gt||function(t,e){if(void 0===ot)try{new Response(new ReadableStream),ot=!0}catch(t){ot=!1}ot?e(t.body):t.blob().then(e)}(e,function(e){var r=new self.Response(e,n);self.caches.open(ft).then(function(e){return e.put(vt(t.url),r)})}))}}(i,n,s),a=!0,e(null,t,r.headers.get(\"Cache-Control\"),r.headers.get(\"Expires\")))}).catch(function(t){return e(new Error(t.message))})};return s?function(t,e){if(!self.caches)return e(null);var r=vt(t.url);self.caches.open(ft).catch(e).then(function(t){t.match(r).catch(e).then(function(n){var i=function(t){if(!t)return!1;var e=new Date(t.headers.get(\"Expires\")),r=A(t.headers.get(\"Cache-Control\")||\"\");return e>Date.now()&&!r[\"no-cache\"]}(n);t.delete(r),i&&t.put(r,n.clone()),e(null,n,i)})})}(i,l):l(null,null),{cancel:function(){o=!0,a||n.abort()}}}var kt,Tt,At=function(t,e){if(!/^file:/.test(t.url)){if(self.fetch&&self.Request&&self.AbortController&&self.Request.prototype.hasOwnProperty(\"signal\"))return wt(t,e);if(bt()&&self.worker&&self.worker.actor)return self.worker.actor.send(\"getResource\",t,e)}return function(t,e){var r=new self.XMLHttpRequest;for(var n in r.open(t.method||\"GET\",t.url,!0),\"arrayBuffer\"===t.type&&(r.responseType=\"arraybuffer\"),t.headers)r.setRequestHeader(n,t.headers[n]);return\"json\"===t.type&&r.setRequestHeader(\"Accept\",\"application/json\"),r.withCredentials=\"include\"===t.credentials,r.onerror=function(){e(new Error(r.statusText))},r.onload=function(){if((r.status>=200&&r.status<300||0===r.status)&&null!==r.response){var n=r.response;if(\"json\"===t.type)try{n=JSON.parse(r.response)}catch(t){return e(t)}e(null,n,r.getResponseHeader(\"Cache-Control\"),r.getResponseHeader(\"Expires\"))}else e(new xt(r.statusText,r.status,t.url))},r.send(t.body),{cancel:function(){return r.abort()}}}(t,e)},Mt=function(t,e){return At(h(t,{type:\"arrayBuffer\"}),e)},St=function(t,e){return At(h(t,{method:\"POST\"}),e)};kt=[],Tt=0;var Et=function(t,e){if(Tt>=I.MAX_PARALLEL_IMAGE_REQUESTS){var r={requestParameters:t,callback:e,cancelled:!1,cancel:function(){this.cancelled=!0}};return kt.push(r),r}Tt++;var n=!1,i=function(){if(!n)for(n=!0,Tt--;kt.length&&Tt<I.MAX_PARALLEL_IMAGE_REQUESTS;){var t=kt.shift(),e=t.requestParameters,r=t.callback;t.cancelled||(t.cancel=Et(e,r).cancel)}},a=Mt(t,function(t,r,n,a){if(i(),t)e(t);else if(r){var o=new self.Image,s=self.URL||self.webkitURL;o.onload=function(){e(null,o),s.revokeObjectURL(o.src)},o.onerror=function(){return e(new Error(\"Could not load image. Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.\"))};var l=new self.Blob([new Uint8Array(r)],{type:\"image/png\"});o.cacheControl=n,o.expires=a,o.src=r.byteLength?s.createObjectURL(l):\"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAC0lEQVQYV2NgAAIAAAUAAarVyFEAAAAASUVORK5CYII=\"}});return{cancel:function(){a.cancel(),i()}}};function Ct(t,e,r){r[t]&&-1!==r[t].indexOf(e)||(r[t]=r[t]||[],r[t].push(e))}function Lt(t,e,r){if(r&&r[t]){var n=r[t].indexOf(e);-1!==n&&r[t].splice(n,1)}}var Pt=function(t,e){void 0===e&&(e={}),h(this,e),this.type=t},Ot=function(t){function e(e,r){void 0===r&&(r={}),t.call(this,\"error\",h({error:e},r))}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Pt),zt=function(){};zt.prototype.on=function(t,e){return this._listeners=this._listeners||{},Ct(t,e,this._listeners),this},zt.prototype.off=function(t,e){return Lt(t,e,this._listeners),Lt(t,e,this._oneTimeListeners),this},zt.prototype.once=function(t,e){return this._oneTimeListeners=this._oneTimeListeners||{},Ct(t,e,this._oneTimeListeners),this},zt.prototype.fire=function(t,e){\"string\"==typeof t&&(t=new Pt(t,e||{}));var r=t.type;if(this.listens(r)){t.target=this;for(var n=0,i=this._listeners&&this._listeners[r]?this._listeners[r].slice():[];n<i.length;n+=1)i[n].call(this,t);for(var a=0,o=this._oneTimeListeners&&this._oneTimeListeners[r]?this._oneTimeListeners[r].slice():[];a<o.length;a+=1){var s=o[a];Lt(r,s,this._oneTimeListeners),s.call(this,t)}var l=this._eventedParent;l&&(h(t,\"function\"==typeof this._eventedParentData?this._eventedParentData():this._eventedParentData),l.fire(t))}else t instanceof Ot&&console.error(t.error);return this},zt.prototype.listens=function(t){return this._listeners&&this._listeners[t]&&this._listeners[t].length>0||this._oneTimeListeners&&this._oneTimeListeners[t]&&this._oneTimeListeners[t].length>0||this._eventedParent&&this._eventedParent.listens(t)},zt.prototype.setEventedParent=function(t,e){return this._eventedParent=t,this._eventedParentData=e,this};var It={$version:8,$root:{version:{required:!0,type:\"enum\",values:[8]},name:{type:\"string\"},metadata:{type:\"*\"},center:{type:\"array\",value:\"number\"},zoom:{type:\"number\"},bearing:{type:\"number\",default:0,period:360,units:\"degrees\"},pitch:{type:\"number\",default:0,units:\"degrees\"},light:{type:\"light\"},sources:{required:!0,type:\"sources\"},sprite:{type:\"string\"},glyphs:{type:\"string\"},transition:{type:\"transition\"},layers:{required:!0,type:\"array\",value:\"layer\"}},sources:{\"*\":{type:\"source\"}},source:[\"source_vector\",\"source_raster\",\"source_raster_dem\",\"source_geojson\",\"source_video\",\"source_image\"],source_vector:{type:{required:!0,type:\"enum\",values:{vector:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},attribution:{type:\"string\"},\"*\":{type:\"*\"}},source_raster:{type:{required:!0,type:\"enum\",values:{raster:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},attribution:{type:\"string\"},\"*\":{type:\"*\"}},source_raster_dem:{type:{required:!0,type:\"enum\",values:{\"raster-dem\":{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},attribution:{type:\"string\"},encoding:{type:\"enum\",values:{terrarium:{},mapbox:{}},default:\"mapbox\"},\"*\":{type:\"*\"}},source_geojson:{type:{required:!0,type:\"enum\",values:{geojson:{}}},data:{type:\"*\"},maxzoom:{type:\"number\",default:18},attribution:{type:\"string\"},buffer:{type:\"number\",default:128,maximum:512,minimum:0},tolerance:{type:\"number\",default:.375},cluster:{type:\"boolean\",default:!1},clusterRadius:{type:\"number\",default:50,minimum:0},clusterMaxZoom:{type:\"number\"},clusterProperties:{type:\"*\"},lineMetrics:{type:\"boolean\",default:!1},generateId:{type:\"boolean\",default:!1}},source_video:{type:{required:!0,type:\"enum\",values:{video:{}}},urls:{required:!0,type:\"array\",value:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},source_image:{type:{required:!0,type:\"enum\",values:{image:{}}},url:{required:!0,type:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},layer:{id:{type:\"string\",required:!0},type:{type:\"enum\",values:{fill:{},line:{},symbol:{},circle:{},heatmap:{},\"fill-extrusion\":{},raster:{},hillshade:{},background:{}},required:!0},metadata:{type:\"*\"},source:{type:\"string\"},\"source-layer\":{type:\"string\"},minzoom:{type:\"number\",minimum:0,maximum:24},maxzoom:{type:\"number\",minimum:0,maximum:24},filter:{type:\"filter\"},layout:{type:\"layout\"},paint:{type:\"paint\"}},layout:[\"layout_fill\",\"layout_line\",\"layout_circle\",\"layout_heatmap\",\"layout_fill-extrusion\",\"layout_symbol\",\"layout_raster\",\"layout_hillshade\",\"layout_background\"],layout_background:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_fill:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_circle:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_heatmap:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},\"layout_fill-extrusion\":{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_line:{\"line-cap\":{type:\"enum\",values:{butt:{},round:{},square:{}},default:\"butt\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-join\":{type:\"enum\",values:{bevel:{},round:{},miter:{}},default:\"miter\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"line-miter-limit\":{type:\"number\",default:2,requires:[{\"line-join\":\"miter\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-round-limit\":{type:\"number\",default:1.05,requires:[{\"line-join\":\"round\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_symbol:{\"symbol-placement\":{type:\"enum\",values:{point:{},line:{},\"line-center\":{}},default:\"point\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-spacing\":{type:\"number\",default:250,minimum:1,units:\"pixels\",requires:[{\"symbol-placement\":\"line\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-avoid-edges\":{type:\"boolean\",default:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"symbol-z-order\":{type:\"enum\",values:{auto:{},\"viewport-y\":{},source:{}},default:\"auto\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-optional\":{type:\"boolean\",default:!1,requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-size\":{type:\"number\",default:1,minimum:0,units:\"factor of the original icon size\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-text-fit\":{type:\"enum\",values:{none:{},width:{},height:{},both:{}},default:\"none\",requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-text-fit-padding\":{type:\"array\",value:\"number\",length:4,default:[0,0,0,0],units:\"pixels\",requires:[\"icon-image\",\"text-field\",{\"icon-text-fit\":[\"both\",\"width\",\"height\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-image\":{type:\"string\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-keep-upright\":{type:\"boolean\",default:!1,requires:[\"icon-image\",{\"icon-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-offset\":{type:\"array\",value:\"number\",length:2,default:[0,0],requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-anchor\":{type:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-field\":{type:\"formatted\",default:\"\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-font\":{type:\"array\",value:\"string\",default:[\"Open Sans Regular\",\"Arial Unicode MS Regular\"],requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-size\":{type:\"number\",default:16,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-width\":{type:\"number\",default:10,minimum:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-line-height\":{type:\"number\",default:1.2,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-letter-spacing\":{type:\"number\",default:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-justify\":{type:\"enum\",values:{auto:{},left:{},center:{},right:{}},default:\"center\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-radial-offset\":{type:\"number\",units:\"ems\",default:0,requires:[{\"!\":\"text-offset\"}],\"property-type\":\"data-driven\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]}},\"text-variable-anchor\":{type:\"array\",value:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},requires:[{\"!\":\"text-anchor\"},{\"!\":\"text-offset\"},{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-anchor\":{type:\"enum\",requires:[\"text-field\"],values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-angle\":{type:\"number\",default:45,units:\"degrees\",requires:[\"text-field\",{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-keep-upright\":{type:\"boolean\",default:!0,requires:[\"text-field\",{\"text-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-transform\":{type:\"enum\",values:{none:{},uppercase:{},lowercase:{}},default:\"none\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-offset\":{type:\"array\",value:\"number\",units:\"ems\",length:2,default:[0,0],requires:[\"text-field\",{\"!\":\"text-radial-offset\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-optional\":{type:\"boolean\",default:!1,requires:[\"text-field\",\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_raster:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_hillshade:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},filter:{type:\"array\",value:\"*\"},filter_operator:{type:\"enum\",values:{\"==\":{},\"!=\":{},\">\":{},\">=\":{},\"<\":{},\"<=\":{},in:{},\"!in\":{},all:{},any:{},none:{},has:{},\"!has\":{}}},geometry_type:{type:\"enum\",values:{Point:{},LineString:{},Polygon:{}}},function:{expression:{type:\"expression\"},stops:{type:\"array\",value:\"function_stop\"},base:{type:\"number\",default:1,minimum:0},property:{type:\"string\",default:\"$zoom\"},type:{type:\"enum\",values:{identity:{},exponential:{},interval:{},categorical:{}},default:\"exponential\"},colorSpace:{type:\"enum\",values:{rgb:{},lab:{},hcl:{}},default:\"rgb\"},default:{type:\"*\",required:!1}},function_stop:{type:\"array\",minimum:0,maximum:22,value:[\"number\",\"color\"],length:2},expression:{type:\"array\",value:\"*\",minimum:1},expression_name:{type:\"enum\",values:{let:{group:\"Variable binding\"},var:{group:\"Variable binding\"},literal:{group:\"Types\"},array:{group:\"Types\"},at:{group:\"Lookup\"},case:{group:\"Decision\"},match:{group:\"Decision\"},coalesce:{group:\"Decision\"},step:{group:\"Ramps, scales, curves\"},interpolate:{group:\"Ramps, scales, curves\"},\"interpolate-hcl\":{group:\"Ramps, scales, curves\"},\"interpolate-lab\":{group:\"Ramps, scales, curves\"},ln2:{group:\"Math\"},pi:{group:\"Math\"},e:{group:\"Math\"},typeof:{group:\"Types\"},string:{group:\"Types\"},number:{group:\"Types\"},boolean:{group:\"Types\"},object:{group:\"Types\"},collator:{group:\"Types\"},format:{group:\"Types\"},\"number-format\":{group:\"Types\"},\"to-string\":{group:\"Types\"},\"to-number\":{group:\"Types\"},\"to-boolean\":{group:\"Types\"},\"to-rgba\":{group:\"Color\"},\"to-color\":{group:\"Types\"},rgb:{group:\"Color\"},rgba:{group:\"Color\"},get:{group:\"Lookup\"},has:{group:\"Lookup\"},length:{group:\"Lookup\"},properties:{group:\"Feature data\"},\"feature-state\":{group:\"Feature data\"},\"geometry-type\":{group:\"Feature data\"},id:{group:\"Feature data\"},zoom:{group:\"Zoom\"},\"heatmap-density\":{group:\"Heatmap\"},\"line-progress\":{group:\"Feature data\"},accumulated:{group:\"Feature data\"},\"+\":{group:\"Math\"},\"*\":{group:\"Math\"},\"-\":{group:\"Math\"},\"/\":{group:\"Math\"},\"%\":{group:\"Math\"},\"^\":{group:\"Math\"},sqrt:{group:\"Math\"},log10:{group:\"Math\"},ln:{group:\"Math\"},log2:{group:\"Math\"},sin:{group:\"Math\"},cos:{group:\"Math\"},tan:{group:\"Math\"},asin:{group:\"Math\"},acos:{group:\"Math\"},atan:{group:\"Math\"},min:{group:\"Math\"},max:{group:\"Math\"},round:{group:\"Math\"},abs:{group:\"Math\"},ceil:{group:\"Math\"},floor:{group:\"Math\"},\"==\":{group:\"Decision\"},\"!=\":{group:\"Decision\"},\">\":{group:\"Decision\"},\"<\":{group:\"Decision\"},\">=\":{group:\"Decision\"},\"<=\":{group:\"Decision\"},all:{group:\"Decision\"},any:{group:\"Decision\"},\"!\":{group:\"Decision\"},\"is-supported-script\":{group:\"String\"},upcase:{group:\"String\"},downcase:{group:\"String\"},concat:{group:\"String\"},\"resolved-locale\":{group:\"String\"}}},light:{anchor:{type:\"enum\",default:\"viewport\",values:{map:{},viewport:{}},\"property-type\":\"data-constant\",transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]}},position:{type:\"array\",default:[1.15,210,30],length:3,value:\"number\",\"property-type\":\"data-constant\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]}},color:{type:\"color\",\"property-type\":\"data-constant\",default:\"#ffffff\",expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0},intensity:{type:\"number\",\"property-type\":\"data-constant\",default:.5,minimum:0,maximum:1,expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0}},paint:[\"paint_fill\",\"paint_line\",\"paint_circle\",\"paint_heatmap\",\"paint_fill-extrusion\",\"paint_symbol\",\"paint_raster\",\"paint_hillshade\",\"paint_background\"],paint_fill:{\"fill-antialias\":{type:\"boolean\",default:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-outline-color\":{type:\"color\",transition:!0,requires:[{\"!\":\"fill-pattern\"},{\"fill-antialias\":!0}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"}},\"paint_fill-extrusion\":{\"fill-extrusion-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-extrusion-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-extrusion-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"fill-extrusion-height\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-base\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,requires:[\"fill-extrusion-height\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-vertical-gradient\":{type:\"boolean\",default:!0,transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_line:{\"line-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"line-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-width\":{type:\"number\",default:1,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-gap-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-offset\":{type:\"number\",default:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-dasharray\":{type:\"array\",value:\"number\",minimum:0,transition:!0,units:\"line widths\",requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"line-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"line-gradient\":{type:\"color\",transition:!1,requires:[{\"!\":\"line-dasharray\"},{\"!\":\"line-pattern\"},{source:\"geojson\",has:{lineMetrics:!0}}],expression:{interpolated:!0,parameters:[\"line-progress\"]},\"property-type\":\"color-ramp\"}},paint_circle:{\"circle-radius\":{type:\"number\",default:5,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-blur\":{type:\"number\",default:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"circle-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-scale\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-stroke-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"}},paint_heatmap:{\"heatmap-radius\":{type:\"number\",default:30,minimum:1,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-weight\":{type:\"number\",default:1,minimum:0,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-intensity\":{type:\"number\",default:1,minimum:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"heatmap-color\":{type:\"color\",default:[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,\"rgba(0, 0, 255, 0)\",.1,\"royalblue\",.3,\"cyan\",.5,\"lime\",.7,\"yellow\",1,\"red\"],transition:!1,expression:{interpolated:!0,parameters:[\"heatmap-density\"]},\"property-type\":\"color-ramp\"},\"heatmap-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_symbol:{\"icon-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"icon-image\",\"icon-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"text-field\",\"text-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_raster:{\"raster-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-hue-rotate\":{type:\"number\",default:0,period:360,transition:!0,units:\"degrees\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-min\":{type:\"number\",default:0,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-max\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-saturation\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-contrast\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-resampling\":{type:\"enum\",values:{linear:{},nearest:{}},default:\"linear\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-fade-duration\":{type:\"number\",default:300,minimum:0,transition:!1,units:\"milliseconds\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_hillshade:{\"hillshade-illumination-direction\":{type:\"number\",default:335,minimum:0,maximum:359,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-illumination-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-exaggeration\":{type:\"number\",default:.5,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-shadow-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-highlight-color\":{type:\"color\",default:\"#FFFFFF\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-accent-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_background:{\"background-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"background-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"background-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"background-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},transition:{duration:{type:\"number\",default:300,minimum:0,units:\"milliseconds\"},delay:{type:\"number\",default:0,minimum:0,units:\"milliseconds\"}},\"property-type\":{\"data-driven\":{type:\"property-type\"},\"cross-faded\":{type:\"property-type\"},\"cross-faded-data-driven\":{type:\"property-type\"},\"color-ramp\":{type:\"property-type\"},\"data-constant\":{type:\"property-type\"},constant:{type:\"property-type\"}}},Dt=function(t,e,r,n){this.message=(t?t+\": \":\"\")+r,n&&(this.identifier=n),null!=e&&e.__line__&&(this.line=e.__line__)};function Rt(t){var e=t.key,r=t.value;return r?[new Dt(e,r,\"constants have been deprecated as of v8\")]:[]}function Ft(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}function Bt(t){return t instanceof Number||t instanceof String||t instanceof Boolean}function Nt(t){return Bt(t)?t.valueOf():t}function jt(t){if(Array.isArray(t))return t.map(jt);if(t instanceof Object&&!Bt(t)){var e={};for(var r in t)e[r]=jt(t[r]);return e}return Nt(t)}var Ut=function(t){function e(e,r){t.call(this,r),this.message=r,this.key=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Error),Vt=function(t,e){void 0===e&&(e=[]),this.parent=t,this.bindings={};for(var r=0,n=e;r<n.length;r+=1){var i=n[r],a=i[0],o=i[1];this.bindings[a]=o}};Vt.prototype.concat=function(t){return new Vt(this,t)},Vt.prototype.get=function(t){if(this.bindings[t])return this.bindings[t];if(this.parent)return this.parent.get(t);throw new Error(t+\" not found in scope.\")},Vt.prototype.has=function(t){return!!this.bindings[t]||!!this.parent&&this.parent.has(t)};var qt={kind:\"null\"},Ht={kind:\"number\"},Gt={kind:\"string\"},Yt={kind:\"boolean\"},Wt={kind:\"color\"},Xt={kind:\"object\"},Zt={kind:\"value\"},Jt={kind:\"collator\"},Kt={kind:\"formatted\"};function $t(t,e){return{kind:\"array\",itemType:t,N:e}}function Qt(t){if(\"array\"===t.kind){var e=Qt(t.itemType);return\"number\"==typeof t.N?\"array<\"+e+\", \"+t.N+\">\":\"value\"===t.itemType.kind?\"array\":\"array<\"+e+\">\"}return t.kind}var te=[qt,Ht,Gt,Yt,Wt,Kt,Xt,$t(Zt)];function ee(t,e){if(\"error\"===e.kind)return null;if(\"array\"===t.kind){if(\"array\"===e.kind&&(0===e.N&&\"value\"===e.itemType.kind||!ee(t.itemType,e.itemType))&&(\"number\"!=typeof t.N||t.N===e.N))return null}else{if(t.kind===e.kind)return null;if(\"value\"===t.kind)for(var r=0,n=te;r<n.length;r+=1)if(!ee(n[r],e))return null}return\"Expected \"+Qt(t)+\" but found \"+Qt(e)+\" instead.\"}var re=e(function(t,e){var r={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],rebeccapurple:[102,51,153,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function n(t){return(t=Math.round(t))<0?0:t>255?255:t}function i(t){return t<0?0:t>1?1:t}function a(t){return\"%\"===t[t.length-1]?n(parseFloat(t)/100*255):n(parseInt(t))}function o(t){return\"%\"===t[t.length-1]?i(parseFloat(t)/100):i(parseFloat(t))}function s(t,e,r){return r<0?r+=1:r>1&&(r-=1),6*r<1?t+(e-t)*r*6:2*r<1?e:3*r<2?t+(e-t)*(2/3-r)*6:t}try{e.parseCSSColor=function(t){var e,i=t.replace(/ /g,\"\").toLowerCase();if(i in r)return r[i].slice();if(\"#\"===i[0])return 4===i.length?(e=parseInt(i.substr(1),16))>=0&&e<=4095?[(3840&e)>>4|(3840&e)>>8,240&e|(240&e)>>4,15&e|(15&e)<<4,1]:null:7===i.length&&(e=parseInt(i.substr(1),16))>=0&&e<=16777215?[(16711680&e)>>16,(65280&e)>>8,255&e,1]:null;var l=i.indexOf(\"(\"),c=i.indexOf(\")\");if(-1!==l&&c+1===i.length){var u=i.substr(0,l),h=i.substr(l+1,c-(l+1)).split(\",\"),f=1;switch(u){case\"rgba\":if(4!==h.length)return null;f=o(h.pop());case\"rgb\":return 3!==h.length?null:[a(h[0]),a(h[1]),a(h[2]),f];case\"hsla\":if(4!==h.length)return null;f=o(h.pop());case\"hsl\":if(3!==h.length)return null;var p=(parseFloat(h[0])%360+360)%360/360,d=o(h[1]),g=o(h[2]),v=g<=.5?g*(d+1):g+d-g*d,m=2*g-v;return[n(255*s(m,v,p+1/3)),n(255*s(m,v,p)),n(255*s(m,v,p-1/3)),f];default:return null}}return null}}catch(t){}}).parseCSSColor,ne=function(t,e,r,n){void 0===n&&(n=1),this.r=t,this.g=e,this.b=r,this.a=n};ne.parse=function(t){if(t){if(t instanceof ne)return t;if(\"string\"==typeof t){var e=re(t);if(e)return new ne(e[0]/255*e[3],e[1]/255*e[3],e[2]/255*e[3],e[3])}}},ne.prototype.toString=function(){var t=this.toArray(),e=t[0],r=t[1],n=t[2],i=t[3];return\"rgba(\"+Math.round(e)+\",\"+Math.round(r)+\",\"+Math.round(n)+\",\"+i+\")\"},ne.prototype.toArray=function(){var t=this.r,e=this.g,r=this.b,n=this.a;return 0===n?[0,0,0,0]:[255*t/n,255*e/n,255*r/n,n]},ne.black=new ne(0,0,0,1),ne.white=new ne(1,1,1,1),ne.transparent=new ne(0,0,0,0),ne.red=new ne(1,0,0,1);var ie=function(t,e,r){this.sensitivity=t?e?\"variant\":\"case\":e?\"accent\":\"base\",this.locale=r,this.collator=new Intl.Collator(this.locale?this.locale:[],{sensitivity:this.sensitivity,usage:\"search\"})};ie.prototype.compare=function(t,e){return this.collator.compare(t,e)},ie.prototype.resolvedLocale=function(){return new Intl.Collator(this.locale?this.locale:[]).resolvedOptions().locale};var ae=function(t,e,r){this.text=t,this.scale=e,this.fontStack=r},oe=function(t){this.sections=t};function se(t,e,r,n){return\"number\"==typeof t&&t>=0&&t<=255&&\"number\"==typeof e&&e>=0&&e<=255&&\"number\"==typeof r&&r>=0&&r<=255?void 0===n||\"number\"==typeof n&&n>=0&&n<=1?null:\"Invalid rgba value [\"+[t,e,r,n].join(\", \")+\"]: 'a' must be between 0 and 1.\":\"Invalid rgba value [\"+(\"number\"==typeof n?[t,e,r,n]:[t,e,r]).join(\", \")+\"]: 'r', 'g', and 'b' must be between 0 and 255.\"}function le(t){if(null===t)return qt;if(\"string\"==typeof t)return Gt;if(\"boolean\"==typeof t)return Yt;if(\"number\"==typeof t)return Ht;if(t instanceof ne)return Wt;if(t instanceof ie)return Jt;if(t instanceof oe)return Kt;if(Array.isArray(t)){for(var e,r=t.length,n=0,i=t;n<i.length;n+=1){var a=le(i[n]);if(e){if(e===a)continue;e=Zt;break}e=a}return $t(e||Zt,r)}return Xt}function ce(t){var e=typeof t;return null===t?\"\":\"string\"===e||\"number\"===e||\"boolean\"===e?String(t):t instanceof ne||t instanceof oe?t.toString():JSON.stringify(t)}oe.fromString=function(t){return new oe([new ae(t,null,null)])},oe.prototype.toString=function(){return this.sections.map(function(t){return t.text}).join(\"\")},oe.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.text);var i={};n.fontStack&&(i[\"text-font\"]=[\"literal\",n.fontStack.split(\",\")]),n.scale&&(i[\"font-scale\"]=n.scale),t.push(i)}return t};var ue=function(t,e){this.type=t,this.value=e};ue.parse=function(t,e){if(2!==t.length)return e.error(\"'literal' expression requires exactly one argument, but found \"+(t.length-1)+\" instead.\");if(!function t(e){if(null===e)return!0;if(\"string\"==typeof e)return!0;if(\"boolean\"==typeof e)return!0;if(\"number\"==typeof e)return!0;if(e instanceof ne)return!0;if(e instanceof ie)return!0;if(e instanceof oe)return!0;if(Array.isArray(e)){for(var r=0,n=e;r<n.length;r+=1)if(!t(n[r]))return!1;return!0}if(\"object\"==typeof e){for(var i in e)if(!t(e[i]))return!1;return!0}return!1}(t[1]))return e.error(\"invalid value\");var r=t[1],n=le(r),i=e.expectedType;return\"array\"!==n.kind||0!==n.N||!i||\"array\"!==i.kind||\"number\"==typeof i.N&&0!==i.N||(n=i),new ue(n,r)},ue.prototype.evaluate=function(){return this.value},ue.prototype.eachChild=function(){},ue.prototype.possibleOutputs=function(){return[this.value]},ue.prototype.serialize=function(){return\"array\"===this.type.kind||\"object\"===this.type.kind?[\"literal\",this.value]:this.value instanceof ne?[\"rgba\"].concat(this.value.toArray()):this.value instanceof oe?this.value.serialize():this.value};var he=function(t){this.name=\"ExpressionEvaluationError\",this.message=t};he.prototype.toJSON=function(){return this.message};var fe={string:Gt,number:Ht,boolean:Yt,object:Xt},pe=function(t,e){this.type=t,this.args=e};pe.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r,n=1,i=t[0];if(\"array\"===i){var a,o;if(t.length>2){var s=t[1];if(\"string\"!=typeof s||!(s in fe)||\"object\"===s)return e.error('The item type argument of \"array\" must be one of string, number, boolean',1);a=fe[s],n++}else a=Zt;if(t.length>3){if(null!==t[2]&&(\"number\"!=typeof t[2]||t[2]<0||t[2]!==Math.floor(t[2])))return e.error('The length argument to \"array\" must be a positive integer literal',2);o=t[2],n++}r=$t(a,o)}else r=fe[i];for(var l=[];n<t.length;n++){var c=e.parse(t[n],n,Zt);if(!c)return null;l.push(c)}return new pe(r,l)},pe.prototype.evaluate=function(t){for(var e=0;e<this.args.length;e++){var r=this.args[e].evaluate(t);if(!ee(this.type,le(r)))return r;if(e===this.args.length-1)throw new he(\"Expected value to be of type \"+Qt(this.type)+\", but found \"+Qt(le(r))+\" instead.\")}return null},pe.prototype.eachChild=function(t){this.args.forEach(t)},pe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},pe.prototype.serialize=function(){var t=this.type,e=[t.kind];if(\"array\"===t.kind){var r=t.itemType;if(\"string\"===r.kind||\"number\"===r.kind||\"boolean\"===r.kind){e.push(r.kind);var n=t.N;(\"number\"==typeof n||this.args.length>1)&&e.push(n)}}return e.concat(this.args.map(function(t){return t.serialize()}))};var de=function(t){this.type=Kt,this.sections=t};de.parse=function(t,e){if(t.length<3)return e.error(\"Expected at least two arguments.\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");for(var r=[],n=1;n<t.length-1;n+=2){var i=e.parse(t[n],1,Zt);if(!i)return null;var a=i.type.kind;if(\"string\"!==a&&\"value\"!==a&&\"null\"!==a)return e.error(\"Formatted text type must be 'string', 'value', or 'null'.\");var o=t[n+1];if(\"object\"!=typeof o||Array.isArray(o))return e.error(\"Format options argument must be an object.\");var s=null;if(o[\"font-scale\"]&&!(s=e.parse(o[\"font-scale\"],1,Ht)))return null;var l=null;if(o[\"text-font\"]&&!(l=e.parse(o[\"text-font\"],1,$t(Gt))))return null;r.push({text:i,scale:s,font:l})}return new de(r)},de.prototype.evaluate=function(t){return new oe(this.sections.map(function(e){return new ae(ce(e.text.evaluate(t)),e.scale?e.scale.evaluate(t):null,e.font?e.font.evaluate(t).join(\",\"):null)}))},de.prototype.eachChild=function(t){for(var e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t(n.text),n.scale&&t(n.scale),n.font&&t(n.font)}},de.prototype.possibleOutputs=function(){return[void 0]},de.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.text.serialize());var i={};n.scale&&(i[\"font-scale\"]=n.scale.serialize()),n.font&&(i[\"text-font\"]=n.font.serialize()),t.push(i)}return t};var ge={\"to-boolean\":Yt,\"to-color\":Wt,\"to-number\":Ht,\"to-string\":Gt},ve=function(t,e){this.type=t,this.args=e};ve.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r=t[0];if((\"to-boolean\"===r||\"to-string\"===r)&&2!==t.length)return e.error(\"Expected one argument.\");for(var n=ge[r],i=[],a=1;a<t.length;a++){var o=e.parse(t[a],a,Zt);if(!o)return null;i.push(o)}return new ve(n,i)},ve.prototype.evaluate=function(t){if(\"boolean\"===this.type.kind)return Boolean(this.args[0].evaluate(t));if(\"color\"===this.type.kind){for(var e,r,n=0,i=this.args;n<i.length;n+=1){if(r=null,(e=i[n].evaluate(t))instanceof ne)return e;if(\"string\"==typeof e){var a=t.parseColor(e);if(a)return a}else if(Array.isArray(e)&&!(r=e.length<3||e.length>4?\"Invalid rbga value \"+JSON.stringify(e)+\": expected an array containing either three or four numeric values.\":se(e[0],e[1],e[2],e[3])))return new ne(e[0]/255,e[1]/255,e[2]/255,e[3])}throw new he(r||\"Could not parse color from value '\"+(\"string\"==typeof e?e:String(JSON.stringify(e)))+\"'\")}if(\"number\"===this.type.kind){for(var o=null,s=0,l=this.args;s<l.length;s+=1){if(null===(o=l[s].evaluate(t)))return 0;var c=Number(o);if(!isNaN(c))return c}throw new he(\"Could not convert \"+JSON.stringify(o)+\" to number.\")}return\"formatted\"===this.type.kind?oe.fromString(ce(this.args[0].evaluate(t))):ce(this.args[0].evaluate(t))},ve.prototype.eachChild=function(t){this.args.forEach(t)},ve.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},ve.prototype.serialize=function(){if(\"formatted\"===this.type.kind)return new de([{text:this.args[0],scale:null,font:null}]).serialize();var t=[\"to-\"+this.type.kind];return this.eachChild(function(e){t.push(e.serialize())}),t};var me=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],ye=function(){this.globals=null,this.feature=null,this.featureState=null,this._parseColorCache={}};ye.prototype.id=function(){return this.feature&&\"id\"in this.feature?this.feature.id:null},ye.prototype.geometryType=function(){return this.feature?\"number\"==typeof this.feature.type?me[this.feature.type]:this.feature.type:null},ye.prototype.properties=function(){return this.feature&&this.feature.properties||{}},ye.prototype.parseColor=function(t){var e=this._parseColorCache[t];return e||(e=this._parseColorCache[t]=ne.parse(t)),e};var xe=function(t,e,r,n){this.name=t,this.type=e,this._evaluate=r,this.args=n};xe.prototype.evaluate=function(t){return this._evaluate(t,this.args)},xe.prototype.eachChild=function(t){this.args.forEach(t)},xe.prototype.possibleOutputs=function(){return[void 0]},xe.prototype.serialize=function(){return[this.name].concat(this.args.map(function(t){return t.serialize()}))},xe.parse=function(t,e){var r,n=t[0],i=xe.definitions[n];if(!i)return e.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0);for(var a=Array.isArray(i)?i[0]:i.type,o=Array.isArray(i)?[[i[1],i[2]]]:i.overloads,s=o.filter(function(e){var r=e[0];return!Array.isArray(r)||r.length===t.length-1}),l=null,c=0,u=s;c<u.length;c+=1){var h=u[c],f=h[0],p=h[1];l=new Ae(e.registry,e.path,null,e.scope);for(var d=[],g=!1,v=1;v<t.length;v++){var m=t[v],y=Array.isArray(f)?f[v-1]:f.type,x=l.parse(m,1+d.length,y);if(!x){g=!0;break}d.push(x)}if(!g)if(Array.isArray(f)&&f.length!==d.length)l.error(\"Expected \"+f.length+\" arguments, but found \"+d.length+\" instead.\");else{for(var b=0;b<d.length;b++){var _=Array.isArray(f)?f[b]:f.type,w=d[b];l.concat(b+1).checkSubtype(_,w.type)}if(0===l.errors.length)return new xe(n,a,p,d)}}if(1===s.length)(r=e.errors).push.apply(r,l.errors);else{for(var k=(s.length?s:o).map(function(t){var e;return e=t[0],Array.isArray(e)?\"(\"+e.map(Qt).join(\", \")+\")\":\"(\"+Qt(e.type)+\"...)\"}).join(\" | \"),T=[],A=1;A<t.length;A++){var M=e.parse(t[A],1+T.length);if(!M)return null;T.push(Qt(M.type))}e.error(\"Expected arguments of type \"+k+\", but found (\"+T.join(\", \")+\") instead.\")}return null},xe.register=function(t,e){for(var r in xe.definitions=e,e)t[r]=xe};var be=function(t,e,r){this.type=Jt,this.locale=r,this.caseSensitive=t,this.diacriticSensitive=e};function _e(t){if(t instanceof xe){if(\"get\"===t.name&&1===t.args.length)return!1;if(\"feature-state\"===t.name)return!1;if(\"has\"===t.name&&1===t.args.length)return!1;if(\"properties\"===t.name||\"geometry-type\"===t.name||\"id\"===t.name)return!1;if(/^filter-/.test(t.name))return!1}var e=!0;return t.eachChild(function(t){e&&!_e(t)&&(e=!1)}),e}function we(t){if(t instanceof xe&&\"feature-state\"===t.name)return!1;var e=!0;return t.eachChild(function(t){e&&!we(t)&&(e=!1)}),e}function ke(t,e){if(t instanceof xe&&e.indexOf(t.name)>=0)return!1;var r=!0;return t.eachChild(function(t){r&&!ke(t,e)&&(r=!1)}),r}be.parse=function(t,e){if(2!==t.length)return e.error(\"Expected one argument.\");var r=t[1];if(\"object\"!=typeof r||Array.isArray(r))return e.error(\"Collator options argument must be an object.\");var n=e.parse(void 0!==r[\"case-sensitive\"]&&r[\"case-sensitive\"],1,Yt);if(!n)return null;var i=e.parse(void 0!==r[\"diacritic-sensitive\"]&&r[\"diacritic-sensitive\"],1,Yt);if(!i)return null;var a=null;return r.locale&&!(a=e.parse(r.locale,1,Gt))?null:new be(n,i,a)},be.prototype.evaluate=function(t){return new ie(this.caseSensitive.evaluate(t),this.diacriticSensitive.evaluate(t),this.locale?this.locale.evaluate(t):null)},be.prototype.eachChild=function(t){t(this.caseSensitive),t(this.diacriticSensitive),this.locale&&t(this.locale)},be.prototype.possibleOutputs=function(){return[void 0]},be.prototype.serialize=function(){var t={};return t[\"case-sensitive\"]=this.caseSensitive.serialize(),t[\"diacritic-sensitive\"]=this.diacriticSensitive.serialize(),this.locale&&(t.locale=this.locale.serialize()),[\"collator\",t]};var Te=function(t,e){this.type=e.type,this.name=t,this.boundExpression=e};Te.parse=function(t,e){if(2!==t.length||\"string\"!=typeof t[1])return e.error(\"'var' expression requires exactly one string literal argument.\");var r=t[1];return e.scope.has(r)?new Te(r,e.scope.get(r)):e.error('Unknown variable \"'+r+'\". Make sure \"'+r+'\" has been bound in an enclosing \"let\" expression before using it.',1)},Te.prototype.evaluate=function(t){return this.boundExpression.evaluate(t)},Te.prototype.eachChild=function(){},Te.prototype.possibleOutputs=function(){return[void 0]},Te.prototype.serialize=function(){return[\"var\",this.name]};var Ae=function(t,e,r,n,i){void 0===e&&(e=[]),void 0===n&&(n=new Vt),void 0===i&&(i=[]),this.registry=t,this.path=e,this.key=e.map(function(t){return\"[\"+t+\"]\"}).join(\"\"),this.scope=n,this.errors=i,this.expectedType=r};function Me(t,e){for(var r,n,i=t.length-1,a=0,o=i,s=0;a<=o;)if(r=t[s=Math.floor((a+o)/2)],n=t[s+1],r<=e){if(s===i||e<n)return s;a=s+1}else{if(!(r>e))throw new he(\"Input is not a number.\");o=s-1}return 0}Ae.prototype.parse=function(t,e,r,n,i){return void 0===i&&(i={}),e?this.concat(e,r,n)._parse(t,i):this._parse(t,i)},Ae.prototype._parse=function(t,e){function r(t,e,r){return\"assert\"===r?new pe(e,[t]):\"coerce\"===r?new ve(e,[t]):t}if(null!==t&&\"string\"!=typeof t&&\"boolean\"!=typeof t&&\"number\"!=typeof t||(t=[\"literal\",t]),Array.isArray(t)){if(0===t.length)return this.error('Expected an array with at least one element. If you wanted a literal array, use [\"literal\", []].');var n=t[0];if(\"string\"!=typeof n)return this.error(\"Expression name must be a string, but found \"+typeof n+' instead. If you wanted a literal array, use [\"literal\", [...]].',0),null;var i=this.registry[n];if(i){var a=i.parse(t,this);if(!a)return null;if(this.expectedType){var o=this.expectedType,s=a.type;if(\"string\"!==o.kind&&\"number\"!==o.kind&&\"boolean\"!==o.kind&&\"object\"!==o.kind&&\"array\"!==o.kind||\"value\"!==s.kind)if(\"color\"!==o.kind&&\"formatted\"!==o.kind||\"value\"!==s.kind&&\"string\"!==s.kind){if(this.checkSubtype(o,s))return null}else a=r(a,o,e.typeAnnotation||\"coerce\");else a=r(a,o,e.typeAnnotation||\"assert\")}if(!(a instanceof ue)&&function t(e){if(e instanceof Te)return t(e.boundExpression);if(e instanceof xe&&\"error\"===e.name)return!1;if(e instanceof be)return!1;var r=e instanceof ve||e instanceof pe,n=!0;return e.eachChild(function(e){n=r?n&&t(e):n&&e instanceof ue}),!!n&&(_e(e)&&ke(e,[\"zoom\",\"heatmap-density\",\"line-progress\",\"accumulated\",\"is-supported-script\"]))}(a)){var l=new ye;try{a=new ue(a.type,a.evaluate(l))}catch(t){return this.error(t.message),null}}return a}return this.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0)}return void 0===t?this.error(\"'undefined' value invalid. Use null instead.\"):\"object\"==typeof t?this.error('Bare objects invalid. Use [\"literal\", {...}] instead.'):this.error(\"Expected an array, but found \"+typeof t+\" instead.\")},Ae.prototype.concat=function(t,e,r){var n=\"number\"==typeof t?this.path.concat(t):this.path,i=r?this.scope.concat(r):this.scope;return new Ae(this.registry,n,e||null,i,this.errors)},Ae.prototype.error=function(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];var n=\"\"+this.key+e.map(function(t){return\"[\"+t+\"]\"}).join(\"\");this.errors.push(new Ut(n,t))},Ae.prototype.checkSubtype=function(t,e){var r=ee(t,e);return r&&this.error(r),r};var Se=function(t,e,r){this.type=t,this.input=e,this.labels=[],this.outputs=[];for(var n=0,i=r;n<i.length;n+=1){var a=i[n],o=a[0],s=a[1];this.labels.push(o),this.outputs.push(s)}};function Ee(t,e,r){return t*(1-r)+e*r}Se.parse=function(t,e){if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");var r=e.parse(t[1],1,Ht);if(!r)return null;var n=[],i=null;e.expectedType&&\"value\"!==e.expectedType.kind&&(i=e.expectedType);for(var a=1;a<t.length;a+=2){var o=1===a?-1/0:t[a],s=t[a+1],l=a,c=a+1;if(\"number\"!=typeof o)return e.error('Input/output pairs for \"step\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',l);if(n.length&&n[n.length-1][0]>=o)return e.error('Input/output pairs for \"step\" expressions must be arranged with input values in strictly ascending order.',l);var u=e.parse(s,c,i);if(!u)return null;i=i||u.type,n.push([o,u])}return new Se(i,r,n)},Se.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;return n>=e[i-1]?r[i-1].evaluate(t):r[Me(e,n)].evaluate(t)},Se.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},Se.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()}))},Se.prototype.serialize=function(){for(var t=[\"step\",this.input.serialize()],e=0;e<this.labels.length;e++)e>0&&t.push(this.labels[e]),t.push(this.outputs[e].serialize());return t};var Ce=Object.freeze({number:Ee,color:function(t,e,r){return new ne(Ee(t.r,e.r,r),Ee(t.g,e.g,r),Ee(t.b,e.b,r),Ee(t.a,e.a,r))},array:function(t,e,r){return t.map(function(t,n){return Ee(t,e[n],r)})}}),Le=.95047,Pe=1,Oe=1.08883,ze=4/29,Ie=6/29,De=3*Ie*Ie,Re=Ie*Ie*Ie,Fe=Math.PI/180,Be=180/Math.PI;function Ne(t){return t>Re?Math.pow(t,1/3):t/De+ze}function je(t){return t>Ie?t*t*t:De*(t-ze)}function Ue(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function Ve(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function qe(t){var e=Ve(t.r),r=Ve(t.g),n=Ve(t.b),i=Ne((.4124564*e+.3575761*r+.1804375*n)/Le),a=Ne((.2126729*e+.7151522*r+.072175*n)/Pe);return{l:116*a-16,a:500*(i-a),b:200*(a-Ne((.0193339*e+.119192*r+.9503041*n)/Oe)),alpha:t.a}}function He(t){var e=(t.l+16)/116,r=isNaN(t.a)?e:e+t.a/500,n=isNaN(t.b)?e:e-t.b/200;return e=Pe*je(e),r=Le*je(r),n=Oe*je(n),new ne(Ue(3.2404542*r-1.5371385*e-.4985314*n),Ue(-.969266*r+1.8760108*e+.041556*n),Ue(.0556434*r-.2040259*e+1.0572252*n),t.alpha)}var Ge={forward:qe,reverse:He,interpolate:function(t,e,r){return{l:Ee(t.l,e.l,r),a:Ee(t.a,e.a,r),b:Ee(t.b,e.b,r),alpha:Ee(t.alpha,e.alpha,r)}}},Ye={forward:function(t){var e=qe(t),r=e.l,n=e.a,i=e.b,a=Math.atan2(i,n)*Be;return{h:a<0?a+360:a,c:Math.sqrt(n*n+i*i),l:r,alpha:t.a}},reverse:function(t){var e=t.h*Fe,r=t.c;return He({l:t.l,a:Math.cos(e)*r,b:Math.sin(e)*r,alpha:t.alpha})},interpolate:function(t,e,r){return{h:function(t,e,r){var n=e-t;return t+r*(n>180||n<-180?n-360*Math.round(n/360):n)}(t.h,e.h,r),c:Ee(t.c,e.c,r),l:Ee(t.l,e.l,r),alpha:Ee(t.alpha,e.alpha,r)}}},We=Object.freeze({lab:Ge,hcl:Ye}),Xe=function(t,e,r,n,i){this.type=t,this.operator=e,this.interpolation=r,this.input=n,this.labels=[],this.outputs=[];for(var a=0,o=i;a<o.length;a+=1){var s=o[a],l=s[0],c=s[1];this.labels.push(l),this.outputs.push(c)}};function Ze(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}Xe.interpolationFactor=function(t,e,n,i){var a=0;if(\"exponential\"===t.name)a=Ze(e,t.base,n,i);else if(\"linear\"===t.name)a=Ze(e,1,n,i);else if(\"cubic-bezier\"===t.name){var o=t.controlPoints;a=new r(o[0],o[1],o[2],o[3]).solve(Ze(e,1,n,i))}return a},Xe.parse=function(t,e){var r=t[0],n=t[1],i=t[2],a=t.slice(3);if(!Array.isArray(n)||0===n.length)return e.error(\"Expected an interpolation type expression.\",1);if(\"linear\"===n[0])n={name:\"linear\"};else if(\"exponential\"===n[0]){var o=n[1];if(\"number\"!=typeof o)return e.error(\"Exponential interpolation requires a numeric base.\",1,1);n={name:\"exponential\",base:o}}else{if(\"cubic-bezier\"!==n[0])return e.error(\"Unknown interpolation type \"+String(n[0]),1,0);var s=n.slice(1);if(4!==s.length||s.some(function(t){return\"number\"!=typeof t||t<0||t>1}))return e.error(\"Cubic bezier interpolation requires four numeric arguments with values between 0 and 1.\",1);n={name:\"cubic-bezier\",controlPoints:s}}if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");if(!(i=e.parse(i,2,Ht)))return null;var l=[],c=null;\"interpolate-hcl\"===r||\"interpolate-lab\"===r?c=Wt:e.expectedType&&\"value\"!==e.expectedType.kind&&(c=e.expectedType);for(var u=0;u<a.length;u+=2){var h=a[u],f=a[u+1],p=u+3,d=u+4;if(\"number\"!=typeof h)return e.error('Input/output pairs for \"interpolate\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',p);if(l.length&&l[l.length-1][0]>=h)return e.error('Input/output pairs for \"interpolate\" expressions must be arranged with input values in strictly ascending order.',p);var g=e.parse(f,d,c);if(!g)return null;c=c||g.type,l.push([h,g])}return\"number\"===c.kind||\"color\"===c.kind||\"array\"===c.kind&&\"number\"===c.itemType.kind&&\"number\"==typeof c.N?new Xe(c,r,n,i,l):e.error(\"Type \"+Qt(c)+\" is not interpolatable.\")},Xe.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;if(n>=e[i-1])return r[i-1].evaluate(t);var a=Me(e,n),o=e[a],s=e[a+1],l=Xe.interpolationFactor(this.interpolation,n,o,s),c=r[a].evaluate(t),u=r[a+1].evaluate(t);return\"interpolate\"===this.operator?Ce[this.type.kind.toLowerCase()](c,u,l):\"interpolate-hcl\"===this.operator?Ye.reverse(Ye.interpolate(Ye.forward(c),Ye.forward(u),l)):Ge.reverse(Ge.interpolate(Ge.forward(c),Ge.forward(u),l))},Xe.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},Xe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()}))},Xe.prototype.serialize=function(){var t;t=\"linear\"===this.interpolation.name?[\"linear\"]:\"exponential\"===this.interpolation.name?1===this.interpolation.base?[\"linear\"]:[\"exponential\",this.interpolation.base]:[\"cubic-bezier\"].concat(this.interpolation.controlPoints);for(var e=[this.operator,t,this.input.serialize()],r=0;r<this.labels.length;r++)e.push(this.labels[r],this.outputs[r].serialize());return e};var Je=function(t,e){this.type=t,this.args=e};Je.parse=function(t,e){if(t.length<2)return e.error(\"Expectected at least one argument.\");var r=null,n=e.expectedType;n&&\"value\"!==n.kind&&(r=n);for(var i=[],a=0,o=t.slice(1);a<o.length;a+=1){var s=o[a],l=e.parse(s,1+i.length,r,void 0,{typeAnnotation:\"omit\"});if(!l)return null;r=r||l.type,i.push(l)}var c=n&&i.some(function(t){return ee(n,t.type)});return new Je(c?Zt:r,i)},Je.prototype.evaluate=function(t){for(var e=null,r=0,n=this.args;r<n.length&&null===(e=n[r].evaluate(t));r+=1);return e},Je.prototype.eachChild=function(t){this.args.forEach(t)},Je.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},Je.prototype.serialize=function(){var t=[\"coalesce\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var Ke=function(t,e){this.type=e.type,this.bindings=[].concat(t),this.result=e};Ke.prototype.evaluate=function(t){return this.result.evaluate(t)},Ke.prototype.eachChild=function(t){for(var e=0,r=this.bindings;e<r.length;e+=1)t(r[e][1]);t(this.result)},Ke.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found \"+(t.length-1)+\" instead.\");for(var r=[],n=1;n<t.length-1;n+=2){var i=t[n];if(\"string\"!=typeof i)return e.error(\"Expected string, but found \"+typeof i+\" instead.\",n);if(/[^a-zA-Z0-9_]/.test(i))return e.error(\"Variable names must contain only alphanumeric characters or '_'.\",n);var a=e.parse(t[n+1],n+1);if(!a)return null;r.push([i,a])}var o=e.parse(t[t.length-1],t.length-1,e.expectedType,r);return o?new Ke(r,o):null},Ke.prototype.possibleOutputs=function(){return this.result.possibleOutputs()},Ke.prototype.serialize=function(){for(var t=[\"let\"],e=0,r=this.bindings;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];t.push(i,a.serialize())}return t.push(this.result.serialize()),t};var $e=function(t,e,r){this.type=t,this.index=e,this.input=r};$e.parse=function(t,e){if(3!==t.length)return e.error(\"Expected 2 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,Ht),n=e.parse(t[2],2,$t(e.expectedType||Zt));if(!r||!n)return null;var i=n.type;return new $e(i.itemType,r,n)},$e.prototype.evaluate=function(t){var e=this.index.evaluate(t),r=this.input.evaluate(t);if(e<0)throw new he(\"Array index out of bounds: \"+e+\" < 0.\");if(e>=r.length)throw new he(\"Array index out of bounds: \"+e+\" > \"+(r.length-1)+\".\");if(e!==Math.floor(e))throw new he(\"Array index must be an integer, but found \"+e+\" instead.\");return r[e]},$e.prototype.eachChild=function(t){t(this.index),t(this.input)},$e.prototype.possibleOutputs=function(){return[void 0]},$e.prototype.serialize=function(){return[\"at\",this.index.serialize(),this.input.serialize()]};var Qe=function(t,e,r,n,i,a){this.inputType=t,this.type=e,this.input=r,this.cases=n,this.outputs=i,this.otherwise=a};Qe.parse=function(t,e){if(t.length<5)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=1)return e.error(\"Expected an even number of arguments.\");var r,n;e.expectedType&&\"value\"!==e.expectedType.kind&&(n=e.expectedType);for(var i={},a=[],o=2;o<t.length-1;o+=2){var s=t[o],l=t[o+1];Array.isArray(s)||(s=[s]);var c=e.concat(o);if(0===s.length)return c.error(\"Expected at least one branch label.\");for(var u=0,h=s;u<h.length;u+=1){var f=h[u];if(\"number\"!=typeof f&&\"string\"!=typeof f)return c.error(\"Branch labels must be numbers or strings.\");if(\"number\"==typeof f&&Math.abs(f)>Number.MAX_SAFE_INTEGER)return c.error(\"Branch labels must be integers no larger than \"+Number.MAX_SAFE_INTEGER+\".\");if(\"number\"==typeof f&&Math.floor(f)!==f)return c.error(\"Numeric branch labels must be integer values.\");if(r){if(c.checkSubtype(r,le(f)))return null}else r=le(f);if(void 0!==i[String(f)])return c.error(\"Branch labels must be unique.\");i[String(f)]=a.length}var p=e.parse(l,o,n);if(!p)return null;n=n||p.type,a.push(p)}var d=e.parse(t[1],1,Zt);if(!d)return null;var g=e.parse(t[t.length-1],t.length-1,n);return g?\"value\"!==d.type.kind&&e.concat(1).checkSubtype(r,d.type)?null:new Qe(r,n,d,i,a,g):null},Qe.prototype.evaluate=function(t){var e=this.input.evaluate(t);return(le(e)===this.inputType&&this.outputs[this.cases[e]]||this.otherwise).evaluate(t)},Qe.prototype.eachChild=function(t){t(this.input),this.outputs.forEach(t),t(this.otherwise)},Qe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()})).concat(this.otherwise.possibleOutputs())},Qe.prototype.serialize=function(){for(var t=this,e=[\"match\",this.input.serialize()],r=[],n={},i=0,a=Object.keys(this.cases).sort();i<a.length;i+=1){var o=a[i];void 0===(h=n[this.cases[o]])?(n[this.cases[o]]=r.length,r.push([this.cases[o],[o]])):r[h][1].push(o)}for(var s=function(e){return\"number\"===t.inputType.kind?Number(e):e},l=0,c=r;l<c.length;l+=1){var u=c[l],h=u[0],f=u[1];1===f.length?e.push(s(f[0])):e.push(f.map(s)),e.push(this.outputs[outputIndex$1].serialize())}return e.push(this.otherwise.serialize()),e};var tr=function(t,e,r){this.type=t,this.branches=e,this.otherwise=r};function er(t,e){return\"==\"===t||\"!=\"===t?\"boolean\"===e.kind||\"string\"===e.kind||\"number\"===e.kind||\"null\"===e.kind||\"value\"===e.kind:\"string\"===e.kind||\"number\"===e.kind||\"value\"===e.kind}function rr(t,e,r,n){return 0===n.compare(e,r)}function nr(t,e,r){var n=\"==\"!==t&&\"!=\"!==t;return function(){function i(t,e,r){this.type=Yt,this.lhs=t,this.rhs=e,this.collator=r,this.hasUntypedArgument=\"value\"===t.type.kind||\"value\"===e.type.kind}return i.parse=function(t,e){if(3!==t.length&&4!==t.length)return e.error(\"Expected two or three arguments.\");var r=t[0],a=e.parse(t[1],1,Zt);if(!a)return null;if(!er(r,a.type))return e.concat(1).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Qt(a.type)+\"'.\");var o=e.parse(t[2],2,Zt);if(!o)return null;if(!er(r,o.type))return e.concat(2).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Qt(o.type)+\"'.\");if(a.type.kind!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot compare types '\"+Qt(a.type)+\"' and '\"+Qt(o.type)+\"'.\");n&&(\"value\"===a.type.kind&&\"value\"!==o.type.kind?a=new pe(o.type,[a]):\"value\"!==a.type.kind&&\"value\"===o.type.kind&&(o=new pe(a.type,[o])));var s=null;if(4===t.length){if(\"string\"!==a.type.kind&&\"string\"!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot use collator to compare non-string types.\");if(!(s=e.parse(t[3],3,Jt)))return null}return new i(a,o,s)},i.prototype.evaluate=function(i){var a=this.lhs.evaluate(i),o=this.rhs.evaluate(i);if(n&&this.hasUntypedArgument){var s=le(a),l=le(o);if(s.kind!==l.kind||\"string\"!==s.kind&&\"number\"!==s.kind)throw new he('Expected arguments for \"'+t+'\" to be (string, string) or (number, number), but found ('+s.kind+\", \"+l.kind+\") instead.\")}if(this.collator&&!n&&this.hasUntypedArgument){var c=le(a),u=le(o);if(\"string\"!==c.kind||\"string\"!==u.kind)return e(i,a,o)}return this.collator?r(i,a,o,this.collator.evaluate(i)):e(i,a,o)},i.prototype.eachChild=function(t){t(this.lhs),t(this.rhs),this.collator&&t(this.collator)},i.prototype.possibleOutputs=function(){return[!0,!1]},i.prototype.serialize=function(){var e=[t];return this.eachChild(function(t){e.push(t.serialize())}),e},i}()}tr.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=0)return e.error(\"Expected an odd number of arguments.\");var r;e.expectedType&&\"value\"!==e.expectedType.kind&&(r=e.expectedType);for(var n=[],i=1;i<t.length-1;i+=2){var a=e.parse(t[i],i,Yt);if(!a)return null;var o=e.parse(t[i+1],i+1,r);if(!o)return null;n.push([a,o]),r=r||o.type}var s=e.parse(t[t.length-1],t.length-1,r);return s?new tr(r,n,s):null},tr.prototype.evaluate=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];if(i.evaluate(t))return a.evaluate(t)}return this.otherwise.evaluate(t)},tr.prototype.eachChild=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];t(i),t(a)}t(this.otherwise)},tr.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.branches.map(function(t){return t[0],t[1].possibleOutputs()})).concat(this.otherwise.possibleOutputs())},tr.prototype.serialize=function(){var t=[\"case\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var ir=nr(\"==\",function(t,e,r){return e===r},rr),ar=nr(\"!=\",function(t,e,r){return e!==r},function(t,e,r,n){return!rr(0,e,r,n)}),or=nr(\"<\",function(t,e,r){return e<r},function(t,e,r,n){return n.compare(e,r)<0}),sr=nr(\">\",function(t,e,r){return e>r},function(t,e,r,n){return n.compare(e,r)>0}),lr=nr(\"<=\",function(t,e,r){return e<=r},function(t,e,r,n){return n.compare(e,r)<=0}),cr=nr(\">=\",function(t,e,r){return e>=r},function(t,e,r,n){return n.compare(e,r)>=0}),ur=function(t,e,r,n,i){this.type=Gt,this.number=t,this.locale=e,this.currency=r,this.minFractionDigits=n,this.maxFractionDigits=i};ur.parse=function(t,e){if(3!==t.length)return e.error(\"Expected two arguments.\");var r=e.parse(t[1],1,Ht);if(!r)return null;var n=t[2];if(\"object\"!=typeof n||Array.isArray(n))return e.error(\"NumberFormat options argument must be an object.\");var i=null;if(n.locale&&!(i=e.parse(n.locale,1,Gt)))return null;var a=null;if(n.currency&&!(a=e.parse(n.currency,1,Gt)))return null;var o=null;if(n[\"min-fraction-digits\"]&&!(o=e.parse(n[\"min-fraction-digits\"],1,Ht)))return null;var s=null;return n[\"max-fraction-digits\"]&&!(s=e.parse(n[\"max-fraction-digits\"],1,Ht))?null:new ur(r,i,a,o,s)},ur.prototype.evaluate=function(t){return new Intl.NumberFormat(this.locale?this.locale.evaluate(t):[],{style:this.currency?\"currency\":\"decimal\",currency:this.currency?this.currency.evaluate(t):void 0,minimumFractionDigits:this.minFractionDigits?this.minFractionDigits.evaluate(t):void 0,maximumFractionDigits:this.maxFractionDigits?this.maxFractionDigits.evaluate(t):void 0}).format(this.number.evaluate(t))},ur.prototype.eachChild=function(t){t(this.number),this.locale&&t(this.locale),this.currency&&t(this.currency),this.minFractionDigits&&t(this.minFractionDigits),this.maxFractionDigits&&t(this.maxFractionDigits)},ur.prototype.possibleOutputs=function(){return[void 0]},ur.prototype.serialize=function(){var t={};return this.locale&&(t.locale=this.locale.serialize()),this.currency&&(t.currency=this.currency.serialize()),this.minFractionDigits&&(t[\"min-fraction-digits\"]=this.minFractionDigits.serialize()),this.maxFractionDigits&&(t[\"max-fraction-digits\"]=this.maxFractionDigits.serialize()),[\"number-format\",this.number.serialize(),t]};var hr=function(t){this.type=Ht,this.input=t};hr.parse=function(t,e){if(2!==t.length)return e.error(\"Expected 1 argument, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1);return r?\"array\"!==r.type.kind&&\"string\"!==r.type.kind&&\"value\"!==r.type.kind?e.error(\"Expected argument of type string or array, but found \"+Qt(r.type)+\" instead.\"):new hr(r):null},hr.prototype.evaluate=function(t){var e=this.input.evaluate(t);if(\"string\"==typeof e)return e.length;if(Array.isArray(e))return e.length;throw new he(\"Expected value to be of type string or array, but found \"+Qt(le(e))+\" instead.\")},hr.prototype.eachChild=function(t){t(this.input)},hr.prototype.possibleOutputs=function(){return[void 0]},hr.prototype.serialize=function(){var t=[\"length\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var fr={\"==\":ir,\"!=\":ar,\">\":sr,\"<\":or,\">=\":cr,\"<=\":lr,array:pe,at:$e,boolean:pe,case:tr,coalesce:Je,collator:be,format:de,interpolate:Xe,\"interpolate-hcl\":Xe,\"interpolate-lab\":Xe,length:hr,let:Ke,literal:ue,match:Qe,number:pe,\"number-format\":ur,object:pe,step:Se,string:pe,\"to-boolean\":ve,\"to-color\":ve,\"to-number\":ve,\"to-string\":ve,var:Te};function pr(t,e){var r=e[0],n=e[1],i=e[2],a=e[3];r=r.evaluate(t),n=n.evaluate(t),i=i.evaluate(t);var o=a?a.evaluate(t):1,s=se(r,n,i,o);if(s)throw new he(s);return new ne(r/255*o,n/255*o,i/255*o,o)}function dr(t,e){return t in e}function gr(t,e){var r=e[t];return void 0===r?null:r}function vr(t){return{type:t}}function mr(t){return{result:\"success\",value:t}}function yr(t){return{result:\"error\",value:t}}function xr(t){return\"data-driven\"===t[\"property-type\"]||\"cross-faded-data-driven\"===t[\"property-type\"]}function br(t){return!!t.expression&&t.expression.parameters.indexOf(\"zoom\")>-1}function _r(t){return!!t.expression&&t.expression.interpolated}function wr(t){return t instanceof Number?\"number\":t instanceof String?\"string\":t instanceof Boolean?\"boolean\":Array.isArray(t)?\"array\":null===t?\"null\":typeof t}function kr(t){return\"object\"==typeof t&&null!==t&&!Array.isArray(t)}function Tr(t){return t}function Ar(t,e,r){return void 0!==t?t:void 0!==e?e:void 0!==r?r:void 0}function Mr(t,e,r,n,i){return Ar(typeof r===i?n[r]:void 0,t.default,e.default)}function Sr(t,e,r){if(\"number\"!==wr(r))return Ar(t.default,e.default);var n=t.stops.length;if(1===n)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[n-1][0])return t.stops[n-1][1];var i=Me(t.stops.map(function(t){return t[0]}),r);return t.stops[i][1]}function Er(t,e,r){var n=void 0!==t.base?t.base:1;if(\"number\"!==wr(r))return Ar(t.default,e.default);var i=t.stops.length;if(1===i)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[i-1][0])return t.stops[i-1][1];var a=Me(t.stops.map(function(t){return t[0]}),r),o=function(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}(r,n,t.stops[a][0],t.stops[a+1][0]),s=t.stops[a][1],l=t.stops[a+1][1],c=Ce[e.type]||Tr;if(t.colorSpace&&\"rgb\"!==t.colorSpace){var u=We[t.colorSpace];c=function(t,e){return u.reverse(u.interpolate(u.forward(t),u.forward(e),o))}}return\"function\"==typeof s.evaluate?{evaluate:function(){for(var t=[],e=arguments.length;e--;)t[e]=arguments[e];var r=s.evaluate.apply(void 0,t),n=l.evaluate.apply(void 0,t);if(void 0!==r&&void 0!==n)return c(r,n,o)}}:c(s,l,o)}function Cr(t,e,r){return\"color\"===e.type?r=ne.parse(r):\"formatted\"===e.type?r=oe.fromString(r.toString()):wr(r)===e.type||\"enum\"===e.type&&e.values[r]||(r=void 0),Ar(r,t.default,e.default)}xe.register(fr,{error:[{kind:\"error\"},[Gt],function(t,e){var r=e[0];throw new he(r.evaluate(t))}],typeof:[Gt,[Zt],function(t,e){return Qt(le(e[0].evaluate(t)))}],\"to-rgba\":[$t(Ht,4),[Wt],function(t,e){return e[0].evaluate(t).toArray()}],rgb:[Wt,[Ht,Ht,Ht],pr],rgba:[Wt,[Ht,Ht,Ht,Ht],pr],has:{type:Yt,overloads:[[[Gt],function(t,e){return dr(e[0].evaluate(t),t.properties())}],[[Gt,Xt],function(t,e){var r=e[0],n=e[1];return dr(r.evaluate(t),n.evaluate(t))}]]},get:{type:Zt,overloads:[[[Gt],function(t,e){return gr(e[0].evaluate(t),t.properties())}],[[Gt,Xt],function(t,e){var r=e[0],n=e[1];return gr(r.evaluate(t),n.evaluate(t))}]]},\"feature-state\":[Zt,[Gt],function(t,e){return gr(e[0].evaluate(t),t.featureState||{})}],properties:[Xt,[],function(t){return t.properties()}],\"geometry-type\":[Gt,[],function(t){return t.geometryType()}],id:[Zt,[],function(t){return t.id()}],zoom:[Ht,[],function(t){return t.globals.zoom}],\"heatmap-density\":[Ht,[],function(t){return t.globals.heatmapDensity||0}],\"line-progress\":[Ht,[],function(t){return t.globals.lineProgress||0}],accumulated:[Zt,[],function(t){return void 0===t.globals.accumulated?null:t.globals.accumulated}],\"+\":[Ht,vr(Ht),function(t,e){for(var r=0,n=0,i=e;n<i.length;n+=1)r+=i[n].evaluate(t);return r}],\"*\":[Ht,vr(Ht),function(t,e){for(var r=1,n=0,i=e;n<i.length;n+=1)r*=i[n].evaluate(t);return r}],\"-\":{type:Ht,overloads:[[[Ht,Ht],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)-n.evaluate(t)}],[[Ht],function(t,e){return-e[0].evaluate(t)}]]},\"/\":[Ht,[Ht,Ht],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)/n.evaluate(t)}],\"%\":[Ht,[Ht,Ht],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)%n.evaluate(t)}],ln2:[Ht,[],function(){return Math.LN2}],pi:[Ht,[],function(){return Math.PI}],e:[Ht,[],function(){return Math.E}],\"^\":[Ht,[Ht,Ht],function(t,e){var r=e[0],n=e[1];return Math.pow(r.evaluate(t),n.evaluate(t))}],sqrt:[Ht,[Ht],function(t,e){var r=e[0];return Math.sqrt(r.evaluate(t))}],log10:[Ht,[Ht],function(t,e){var r=e[0];return Math.log(r.evaluate(t))/Math.LN10}],ln:[Ht,[Ht],function(t,e){var r=e[0];return Math.log(r.evaluate(t))}],log2:[Ht,[Ht],function(t,e){var r=e[0];return Math.log(r.evaluate(t))/Math.LN2}],sin:[Ht,[Ht],function(t,e){var r=e[0];return Math.sin(r.evaluate(t))}],cos:[Ht,[Ht],function(t,e){var r=e[0];return Math.cos(r.evaluate(t))}],tan:[Ht,[Ht],function(t,e){var r=e[0];return Math.tan(r.evaluate(t))}],asin:[Ht,[Ht],function(t,e){var r=e[0];return Math.asin(r.evaluate(t))}],acos:[Ht,[Ht],function(t,e){var r=e[0];return Math.acos(r.evaluate(t))}],atan:[Ht,[Ht],function(t,e){var r=e[0];return Math.atan(r.evaluate(t))}],min:[Ht,vr(Ht),function(t,e){return Math.min.apply(Math,e.map(function(e){return e.evaluate(t)}))}],max:[Ht,vr(Ht),function(t,e){return Math.max.apply(Math,e.map(function(e){return e.evaluate(t)}))}],abs:[Ht,[Ht],function(t,e){var r=e[0];return Math.abs(r.evaluate(t))}],round:[Ht,[Ht],function(t,e){var r=e[0].evaluate(t);return r<0?-Math.round(-r):Math.round(r)}],floor:[Ht,[Ht],function(t,e){var r=e[0];return Math.floor(r.evaluate(t))}],ceil:[Ht,[Ht],function(t,e){var r=e[0];return Math.ceil(r.evaluate(t))}],\"filter-==\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1];return t.properties()[r.value]===n.value}],\"filter-id-==\":[Yt,[Zt],function(t,e){var r=e[0];return t.id()===r.value}],\"filter-type-==\":[Yt,[Gt],function(t,e){var r=e[0];return t.geometryType()===r.value}],\"filter-<\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<a}],\"filter-id-<\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<i}],\"filter->\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>a}],\"filter-id->\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>i}],\"filter-<=\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<=a}],\"filter-id-<=\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<=i}],\"filter->=\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>=a}],\"filter-id->=\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>=i}],\"filter-has\":[Yt,[Zt],function(t,e){return e[0].value in t.properties()}],\"filter-has-id\":[Yt,[],function(t){return null!==t.id()}],\"filter-type-in\":[Yt,[$t(Gt)],function(t,e){return e[0].value.indexOf(t.geometryType())>=0}],\"filter-id-in\":[Yt,[$t(Zt)],function(t,e){return e[0].value.indexOf(t.id())>=0}],\"filter-in-small\":[Yt,[Gt,$t(Zt)],function(t,e){var r=e[0];return e[1].value.indexOf(t.properties()[r.value])>=0}],\"filter-in-large\":[Yt,[Gt,$t(Zt)],function(t,e){var r=e[0],n=e[1];return function(t,e,r,n){for(;r<=n;){var i=r+n>>1;if(e[i]===t)return!0;e[i]>t?n=i-1:r=i+1}return!1}(t.properties()[r.value],n.value,0,n.value.length-1)}],all:{type:Yt,overloads:[[[Yt,Yt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)&&n.evaluate(t)}],[vr(Yt),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(!n[r].evaluate(t))return!1;return!0}]]},any:{type:Yt,overloads:[[[Yt,Yt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)||n.evaluate(t)}],[vr(Yt),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(n[r].evaluate(t))return!0;return!1}]]},\"!\":[Yt,[Yt],function(t,e){return!e[0].evaluate(t)}],\"is-supported-script\":[Yt,[Gt],function(t,e){var r=e[0],n=t.globals&&t.globals.isSupportedScript;return!n||n(r.evaluate(t))}],upcase:[Gt,[Gt],function(t,e){return e[0].evaluate(t).toUpperCase()}],downcase:[Gt,[Gt],function(t,e){return e[0].evaluate(t).toLowerCase()}],concat:[Gt,vr(Zt),function(t,e){return e.map(function(e){return ce(e.evaluate(t))}).join(\"\")}],\"resolved-locale\":[Gt,[Jt],function(t,e){return e[0].evaluate(t).resolvedLocale()}]});var Lr=function(t,e){var r;this.expression=t,this._warningHistory={},this._evaluator=new ye,this._defaultValue=e?\"color\"===(r=e).type&&kr(r.default)?new ne(0,0,0,0):\"color\"===r.type?ne.parse(r.default)||null:void 0===r.default?null:r.default:null,this._enumValues=e&&\"enum\"===e.type?e.values:null};function Pr(t){return Array.isArray(t)&&t.length>0&&\"string\"==typeof t[0]&&t[0]in fr}function Or(t,e){var r=new Ae(fr,[],e?function(t){var e={color:Wt,string:Gt,number:Ht,enum:Gt,boolean:Yt,formatted:Kt};return\"array\"===t.type?$t(e[t.value]||Zt,t.length):e[t.type]}(e):void 0),n=r.parse(t,void 0,void 0,void 0,e&&\"string\"===e.type?{typeAnnotation:\"coerce\"}:void 0);return n?mr(new Lr(n,e)):yr(r.errors)}Lr.prototype.evaluateWithoutErrorHandling=function(t,e,r){return this._evaluator.globals=t,this._evaluator.feature=e,this._evaluator.featureState=r,this.expression.evaluate(this._evaluator)},Lr.prototype.evaluate=function(t,e,r){this._evaluator.globals=t,this._evaluator.feature=e||null,this._evaluator.featureState=r||null;try{var n=this.expression.evaluate(this._evaluator);if(null==n)return this._defaultValue;if(this._enumValues&&!(n in this._enumValues))throw new he(\"Expected value to be one of \"+Object.keys(this._enumValues).map(function(t){return JSON.stringify(t)}).join(\", \")+\", but found \"+JSON.stringify(n)+\" instead.\");return n}catch(t){return this._warningHistory[t.message]||(this._warningHistory[t.message]=!0,\"undefined\"!=typeof console&&console.warn(t.message)),this._defaultValue}};var zr=function(t,e){this.kind=t,this._styleExpression=e,this.isStateDependent=\"constant\"!==t&&!we(e.expression)};zr.prototype.evaluateWithoutErrorHandling=function(t,e,r){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r)},zr.prototype.evaluate=function(t,e,r){return this._styleExpression.evaluate(t,e,r)};var Ir=function(t,e,r){this.kind=t,this.zoomStops=r.labels,this._styleExpression=e,this.isStateDependent=\"camera\"!==t&&!we(e.expression),r instanceof Xe&&(this.interpolationType=r.interpolation)};function Dr(t,e){if(\"error\"===(t=Or(t,e)).result)return t;var r=t.value.expression,n=_e(r);if(!n&&!xr(e))return yr([new Ut(\"\",\"data expressions not supported\")]);var i=ke(r,[\"zoom\"]);if(!i&&!br(e))return yr([new Ut(\"\",\"zoom expressions not supported\")]);var a=function t(e){var r=null;if(e instanceof Ke)r=t(e.result);else if(e instanceof Je)for(var n=0,i=e.args;n<i.length;n+=1){var a=i[n];if(r=t(a))break}else(e instanceof Se||e instanceof Xe)&&e.input instanceof xe&&\"zoom\"===e.input.name&&(r=e);return r instanceof Ut?r:(e.eachChild(function(e){var n=t(e);n instanceof Ut?r=n:!r&&n?r=new Ut(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.'):r&&n&&r!==n&&(r=new Ut(\"\",'Only one zoom-based \"step\" or \"interpolate\" subexpression may be used in an expression.'))}),r)}(r);return a||i?a instanceof Ut?yr([a]):a instanceof Xe&&!_r(e)?yr([new Ut(\"\",'\"interpolate\" expressions cannot be used with this property')]):mr(a?new Ir(n?\"camera\":\"composite\",t.value,a):new zr(n?\"constant\":\"source\",t.value)):yr([new Ut(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.')])}Ir.prototype.evaluateWithoutErrorHandling=function(t,e,r){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r)},Ir.prototype.evaluate=function(t,e,r){return this._styleExpression.evaluate(t,e,r)},Ir.prototype.interpolationFactor=function(t,e,r){return this.interpolationType?Xe.interpolationFactor(this.interpolationType,t,e,r):0};var Rr=function(t,e){this._parameters=t,this._specification=e,Ft(this,function t(e,r){var n,i,a,o=\"color\"===r.type,s=e.stops&&\"object\"==typeof e.stops[0][0],l=s||void 0!==e.property,c=s||!l,u=e.type||(_r(r)?\"exponential\":\"interval\");if(o&&((e=Ft({},e)).stops&&(e.stops=e.stops.map(function(t){return[t[0],ne.parse(t[1])]})),e.default?e.default=ne.parse(e.default):e.default=ne.parse(r.default)),e.colorSpace&&\"rgb\"!==e.colorSpace&&!We[e.colorSpace])throw new Error(\"Unknown color space: \"+e.colorSpace);if(\"exponential\"===u)n=Er;else if(\"interval\"===u)n=Sr;else if(\"categorical\"===u){n=Mr,i=Object.create(null);for(var h=0,f=e.stops;h<f.length;h+=1){var p=f[h];i[p[0]]=p[1]}a=typeof e.stops[0][0]}else{if(\"identity\"!==u)throw new Error('Unknown function type \"'+u+'\"');n=Cr}if(s){for(var d={},g=[],v=0;v<e.stops.length;v++){var m=e.stops[v],y=m[0].zoom;void 0===d[y]&&(d[y]={zoom:y,type:e.type,property:e.property,default:e.default,stops:[]},g.push(y)),d[y].stops.push([m[0].value,m[1]])}for(var x=[],b=0,_=g;b<_.length;b+=1){var w=_[b];x.push([d[w].zoom,t(d[w],r)])}var k={name:\"linear\"};return{kind:\"composite\",interpolationType:k,interpolationFactor:Xe.interpolationFactor.bind(void 0,k),zoomStops:x.map(function(t){return t[0]}),evaluate:function(t,n){var i=t.zoom;return Er({stops:x,base:e.base},r,i).evaluate(i,n)}}}if(c){var T=\"exponential\"===u?{name:\"exponential\",base:void 0!==e.base?e.base:1}:null;return{kind:\"camera\",interpolationType:T,interpolationFactor:Xe.interpolationFactor.bind(void 0,T),zoomStops:e.stops.map(function(t){return t[0]}),evaluate:function(t){var o=t.zoom;return n(e,r,o,i,a)}}}return{kind:\"source\",evaluate:function(t,o){var s=o&&o.properties?o.properties[e.property]:void 0;return void 0===s?Ar(e.default,r.default):n(e,r,s,i,a)}}}(this._parameters,this._specification))};function Fr(t){var e=t.key,r=t.value,n=t.valueSpec||{},i=t.objectElementValidators||{},a=t.style,o=t.styleSpec,s=[],l=wr(r);if(\"object\"!==l)return[new Dt(e,r,\"object expected, \"+l+\" found\")];for(var c in r){var u=c.split(\".\")[0],h=n[u]||n[\"*\"],f=void 0;if(i[u])f=i[u];else if(n[u])f=ln;else if(i[\"*\"])f=i[\"*\"];else{if(!n[\"*\"]){s.push(new Dt(e,r[c],'unknown property \"'+c+'\"'));continue}f=ln}s=s.concat(f({key:(e?e+\".\":e)+c,value:r[c],valueSpec:h,style:a,styleSpec:o,object:r,objectKey:c},r))}for(var p in n)i[p]||n[p].required&&void 0===n[p].default&&void 0===r[p]&&s.push(new Dt(e,r,'missing required property \"'+p+'\"'));return s}function Br(t){var e=t.value,r=t.valueSpec,n=t.style,i=t.styleSpec,a=t.key,o=t.arrayElementValidator||ln;if(\"array\"!==wr(e))return[new Dt(a,e,\"array expected, \"+wr(e)+\" found\")];if(r.length&&e.length!==r.length)return[new Dt(a,e,\"array length \"+r.length+\" expected, length \"+e.length+\" found\")];if(r[\"min-length\"]&&e.length<r[\"min-length\"])return[new Dt(a,e,\"array length at least \"+r[\"min-length\"]+\" expected, length \"+e.length+\" found\")];var s={type:r.value,values:r.values};i.$version<7&&(s.function=r.function),\"object\"===wr(r.value)&&(s=r.value);for(var l=[],c=0;c<e.length;c++)l=l.concat(o({array:e,arrayIndex:c,value:e[c],valueSpec:s,style:n,styleSpec:i,key:a+\"[\"+c+\"]\"}));return l}function Nr(t){var e=t.key,r=t.value,n=t.valueSpec,i=wr(r);return\"number\"!==i?[new Dt(e,r,\"number expected, \"+i+\" found\")]:\"minimum\"in n&&r<n.minimum?[new Dt(e,r,r+\" is less than the minimum value \"+n.minimum)]:\"maximum\"in n&&r>n.maximum?[new Dt(e,r,r+\" is greater than the maximum value \"+n.maximum)]:[]}function jr(t){var e,r,n,i=t.valueSpec,a=Nt(t.value.type),o={},s=\"categorical\"!==a&&void 0===t.value.property,l=!s,c=\"array\"===wr(t.value.stops)&&\"array\"===wr(t.value.stops[0])&&\"object\"===wr(t.value.stops[0][0]),u=Fr({key:t.key,value:t.value,valueSpec:t.styleSpec.function,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{stops:function(t){if(\"identity\"===a)return[new Dt(t.key,t.value,'identity function may not have a \"stops\" property')];var e=[],r=t.value;return e=e.concat(Br({key:t.key,value:r,valueSpec:t.valueSpec,style:t.style,styleSpec:t.styleSpec,arrayElementValidator:h})),\"array\"===wr(r)&&0===r.length&&e.push(new Dt(t.key,r,\"array must have at least one stop\")),e},default:function(t){return ln({key:t.key,value:t.value,valueSpec:i,style:t.style,styleSpec:t.styleSpec})}}});return\"identity\"===a&&s&&u.push(new Dt(t.key,t.value,'missing required property \"property\"')),\"identity\"===a||t.value.stops||u.push(new Dt(t.key,t.value,'missing required property \"stops\"')),\"exponential\"===a&&t.valueSpec.expression&&!_r(t.valueSpec)&&u.push(new Dt(t.key,t.value,\"exponential functions not supported\")),t.styleSpec.$version>=8&&(l&&!xr(t.valueSpec)?u.push(new Dt(t.key,t.value,\"property functions not supported\")):s&&!br(t.valueSpec)&&u.push(new Dt(t.key,t.value,\"zoom functions not supported\"))),\"categorical\"!==a&&!c||void 0!==t.value.property||u.push(new Dt(t.key,t.value,'\"property\" property is required')),u;function h(t){var e=[],a=t.value,s=t.key;if(\"array\"!==wr(a))return[new Dt(s,a,\"array expected, \"+wr(a)+\" found\")];if(2!==a.length)return[new Dt(s,a,\"array length 2 expected, length \"+a.length+\" found\")];if(c){if(\"object\"!==wr(a[0]))return[new Dt(s,a,\"object expected, \"+wr(a[0])+\" found\")];if(void 0===a[0].zoom)return[new Dt(s,a,\"object stop key must have zoom\")];if(void 0===a[0].value)return[new Dt(s,a,\"object stop key must have value\")];if(n&&n>Nt(a[0].zoom))return[new Dt(s,a[0].zoom,\"stop zoom values must appear in ascending order\")];Nt(a[0].zoom)!==n&&(n=Nt(a[0].zoom),r=void 0,o={}),e=e.concat(Fr({key:s+\"[0]\",value:a[0],valueSpec:{zoom:{}},style:t.style,styleSpec:t.styleSpec,objectElementValidators:{zoom:Nr,value:f}}))}else e=e.concat(f({key:s+\"[0]\",value:a[0],valueSpec:{},style:t.style,styleSpec:t.styleSpec},a));return Pr(jt(a[1]))?e.concat([new Dt(s+\"[1]\",a[1],\"expressions are not allowed in function stops.\")]):e.concat(ln({key:s+\"[1]\",value:a[1],valueSpec:i,style:t.style,styleSpec:t.styleSpec}))}function f(t,n){var s=wr(t.value),l=Nt(t.value),c=null!==t.value?t.value:n;if(e){if(s!==e)return[new Dt(t.key,c,s+\" stop domain type must match previous stop domain type \"+e)]}else e=s;if(\"number\"!==s&&\"string\"!==s&&\"boolean\"!==s)return[new Dt(t.key,c,\"stop domain value must be a number, string, or boolean\")];if(\"number\"!==s&&\"categorical\"!==a){var u=\"number expected, \"+s+\" found\";return xr(i)&&void 0===a&&(u+='\\nIf you intended to use a categorical function, specify `\"type\": \"categorical\"`.'),[new Dt(t.key,c,u)]}return\"categorical\"!==a||\"number\"!==s||isFinite(l)&&Math.floor(l)===l?\"categorical\"!==a&&\"number\"===s&&void 0!==r&&l<r?[new Dt(t.key,c,\"stop domain values must appear in ascending order\")]:(r=l,\"categorical\"===a&&l in o?[new Dt(t.key,c,\"stop domain values must be unique\")]:(o[l]=!0,[])):[new Dt(t.key,c,\"integer expected, found \"+l)]}}function Ur(t){var e=(\"property\"===t.expressionContext?Dr:Or)(jt(t.value),t.valueSpec);if(\"error\"===e.result)return e.value.map(function(e){return new Dt(\"\"+t.key+e.key,t.value,e.message)});var r=e.value.expression||e.value._styleExpression.expression;if(\"property\"===t.expressionContext&&\"text-font\"===t.propertyKey&&-1!==r.possibleOutputs().indexOf(void 0))return[new Dt(t.key,t.value,'Invalid data expression for \"'+t.propertyKey+'\". Output values must be contained as literals within the expression.')];if(\"property\"===t.expressionContext&&\"layout\"===t.propertyType&&!we(r))return[new Dt(t.key,t.value,'\"feature-state\" data expressions are not supported with layout properties.')];if(\"filter\"===t.expressionContext&&!we(r))return[new Dt(t.key,t.value,'\"feature-state\" data expressions are not supported with filters.')];if(t.expressionContext&&0===t.expressionContext.indexOf(\"cluster\")){if(!ke(r,[\"zoom\",\"feature-state\"]))return[new Dt(t.key,t.value,'\"zoom\" and \"feature-state\" expressions are not supported with cluster properties.')];if(\"cluster-initial\"===t.expressionContext&&!_e(r))return[new Dt(t.key,t.value,\"Feature data expressions are not supported with initial expression part of cluster properties.\")]}return[]}function Vr(t){var e=t.key,r=t.value,n=t.valueSpec,i=[];return Array.isArray(n.values)?-1===n.values.indexOf(Nt(r))&&i.push(new Dt(e,r,\"expected one of [\"+n.values.join(\", \")+\"], \"+JSON.stringify(r)+\" found\")):-1===Object.keys(n.values).indexOf(Nt(r))&&i.push(new Dt(e,r,\"expected one of [\"+Object.keys(n.values).join(\", \")+\"], \"+JSON.stringify(r)+\" found\")),i}function qr(t){if(!0===t||!1===t)return!0;if(!Array.isArray(t)||0===t.length)return!1;switch(t[0]){case\"has\":return t.length>=2&&\"$id\"!==t[1]&&\"$type\"!==t[1];case\"in\":case\"!in\":case\"!has\":case\"none\":return!1;case\"==\":case\"!=\":case\">\":case\">=\":case\"<\":case\"<=\":return 3!==t.length||Array.isArray(t[1])||Array.isArray(t[2]);case\"any\":case\"all\":for(var e=0,r=t.slice(1);e<r.length;e+=1){var n=r[e];if(!qr(n)&&\"boolean\"!=typeof n)return!1}return!0;default:return!0}}Rr.deserialize=function(t){return new Rr(t._parameters,t._specification)},Rr.serialize=function(t){return{_parameters:t._parameters,_specification:t._specification}};var Hr={type:\"boolean\",default:!1,transition:!1,\"property-type\":\"data-driven\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]}};function Gr(t){if(null==t)return function(){return!0};qr(t)||(t=Wr(t));var e=Or(t,Hr);if(\"error\"===e.result)throw new Error(e.value.map(function(t){return t.key+\": \"+t.message}).join(\", \"));return function(t,r){return e.value.evaluate(t,r)}}function Yr(t,e){return t<e?-1:t>e?1:0}function Wr(t){if(!t)return!0;var e,r=t[0];return t.length<=1?\"any\"!==r:\"==\"===r?Xr(t[1],t[2],\"==\"):\"!=\"===r?Kr(Xr(t[1],t[2],\"==\")):\"<\"===r||\">\"===r||\"<=\"===r||\">=\"===r?Xr(t[1],t[2],r):\"any\"===r?(e=t.slice(1),[\"any\"].concat(e.map(Wr))):\"all\"===r?[\"all\"].concat(t.slice(1).map(Wr)):\"none\"===r?[\"all\"].concat(t.slice(1).map(Wr).map(Kr)):\"in\"===r?Zr(t[1],t.slice(2)):\"!in\"===r?Kr(Zr(t[1],t.slice(2))):\"has\"===r?Jr(t[1]):\"!has\"!==r||Kr(Jr(t[1]))}function Xr(t,e,r){switch(t){case\"$type\":return[\"filter-type-\"+r,e];case\"$id\":return[\"filter-id-\"+r,e];default:return[\"filter-\"+r,t,e]}}function Zr(t,e){if(0===e.length)return!1;switch(t){case\"$type\":return[\"filter-type-in\",[\"literal\",e]];case\"$id\":return[\"filter-id-in\",[\"literal\",e]];default:return e.length>200&&!e.some(function(t){return typeof t!=typeof e[0]})?[\"filter-in-large\",t,[\"literal\",e.sort(Yr)]]:[\"filter-in-small\",t,[\"literal\",e]]}}function Jr(t){switch(t){case\"$type\":return!0;case\"$id\":return[\"filter-has-id\"];default:return[\"filter-has\",t]}}function Kr(t){return[\"!\",t]}function $r(t){return qr(jt(t.value))?Ur(Ft({},t,{expressionContext:\"filter\",valueSpec:{value:\"boolean\"}})):function t(e){var r=e.value,n=e.key;if(\"array\"!==wr(r))return[new Dt(n,r,\"array expected, \"+wr(r)+\" found\")];var i,a=e.styleSpec,o=[];if(r.length<1)return[new Dt(n,r,\"filter array must have at least 1 element\")];switch(o=o.concat(Vr({key:n+\"[0]\",value:r[0],valueSpec:a.filter_operator,style:e.style,styleSpec:e.styleSpec})),Nt(r[0])){case\"<\":case\"<=\":case\">\":case\">=\":r.length>=2&&\"$type\"===Nt(r[1])&&o.push(new Dt(n,r,'\"$type\" cannot be use with operator \"'+r[0]+'\"'));case\"==\":case\"!=\":3!==r.length&&o.push(new Dt(n,r,'filter array for operator \"'+r[0]+'\" must have 3 elements'));case\"in\":case\"!in\":r.length>=2&&\"string\"!==(i=wr(r[1]))&&o.push(new Dt(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"));for(var s=2;s<r.length;s++)i=wr(r[s]),\"$type\"===Nt(r[1])?o=o.concat(Vr({key:n+\"[\"+s+\"]\",value:r[s],valueSpec:a.geometry_type,style:e.style,styleSpec:e.styleSpec})):\"string\"!==i&&\"number\"!==i&&\"boolean\"!==i&&o.push(new Dt(n+\"[\"+s+\"]\",r[s],\"string, number, or boolean expected, \"+i+\" found\"));break;case\"any\":case\"all\":case\"none\":for(var l=1;l<r.length;l++)o=o.concat(t({key:n+\"[\"+l+\"]\",value:r[l],style:e.style,styleSpec:e.styleSpec}));break;case\"has\":case\"!has\":i=wr(r[1]),2!==r.length?o.push(new Dt(n,r,'filter array for \"'+r[0]+'\" operator must have 2 elements')):\"string\"!==i&&o.push(new Dt(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"))}return o}(t)}function Qr(t,e){var r=t.key,n=t.style,i=t.styleSpec,a=t.value,o=t.objectKey,s=i[e+\"_\"+t.layerType];if(!s)return[];var l=o.match(/^(.*)-transition$/);if(\"paint\"===e&&l&&s[l[1]]&&s[l[1]].transition)return ln({key:r,value:a,valueSpec:i.transition,style:n,styleSpec:i});var c,u=t.valueSpec||s[o];if(!u)return[new Dt(r,a,'unknown property \"'+o+'\"')];if(\"string\"===wr(a)&&xr(u)&&!u.tokens&&(c=/^{([^}]+)}$/.exec(a)))return[new Dt(r,a,'\"'+o+'\" does not support interpolation syntax\\nUse an identity property function instead: `{ \"type\": \"identity\", \"property\": '+JSON.stringify(c[1])+\" }`.\")];var h=[];return\"symbol\"===t.layerType&&(\"text-field\"===o&&n&&!n.glyphs&&h.push(new Dt(r,a,'use of \"text-field\" requires a style \"glyphs\" property')),\"text-font\"===o&&kr(jt(a))&&\"identity\"===Nt(a.type)&&h.push(new Dt(r,a,'\"text-font\" does not support identity functions'))),h.concat(ln({key:t.key,value:a,valueSpec:u,style:n,styleSpec:i,expressionContext:\"property\",propertyType:e,propertyKey:o}))}function tn(t){return Qr(t,\"paint\")}function en(t){return Qr(t,\"layout\")}function rn(t){var e=[],r=t.value,n=t.key,i=t.style,a=t.styleSpec;r.type||r.ref||e.push(new Dt(n,r,'either \"type\" or \"ref\" is required'));var o,s=Nt(r.type),l=Nt(r.ref);if(r.id)for(var c=Nt(r.id),u=0;u<t.arrayIndex;u++){var h=i.layers[u];Nt(h.id)===c&&e.push(new Dt(n,r.id,'duplicate layer id \"'+r.id+'\", previously used at line '+h.id.__line__))}if(\"ref\"in r)[\"type\",\"source\",\"source-layer\",\"filter\",\"layout\"].forEach(function(t){t in r&&e.push(new Dt(n,r[t],'\"'+t+'\" is prohibited for ref layers'))}),i.layers.forEach(function(t){Nt(t.id)===l&&(o=t)}),o?o.ref?e.push(new Dt(n,r.ref,\"ref cannot reference another ref layer\")):s=Nt(o.type):e.push(new Dt(n,r.ref,'ref layer \"'+l+'\" not found'));else if(\"background\"!==s)if(r.source){var f=i.sources&&i.sources[r.source],p=f&&Nt(f.type);f?\"vector\"===p&&\"raster\"===s?e.push(new Dt(n,r.source,'layer \"'+r.id+'\" requires a raster source')):\"raster\"===p&&\"raster\"!==s?e.push(new Dt(n,r.source,'layer \"'+r.id+'\" requires a vector source')):\"vector\"!==p||r[\"source-layer\"]?\"raster-dem\"===p&&\"hillshade\"!==s?e.push(new Dt(n,r.source,\"raster-dem source can only be used with layer type 'hillshade'.\")):\"line\"!==s||!r.paint||!r.paint[\"line-gradient\"]||\"geojson\"===p&&f.lineMetrics||e.push(new Dt(n,r,'layer \"'+r.id+'\" specifies a line-gradient, which requires a GeoJSON source with `lineMetrics` enabled.')):e.push(new Dt(n,r,'layer \"'+r.id+'\" must specify a \"source-layer\"')):e.push(new Dt(n,r.source,'source \"'+r.source+'\" not found'))}else e.push(new Dt(n,r,'missing required property \"source\"'));return e=e.concat(Fr({key:n,value:r,valueSpec:a.layer,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(){return[]},type:function(){return ln({key:n+\".type\",value:r.type,valueSpec:a.layer.type,style:t.style,styleSpec:t.styleSpec,object:r,objectKey:\"type\"})},filter:$r,layout:function(t){return Fr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return en(Ft({layerType:s},t))}}})},paint:function(t){return Fr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return tn(Ft({layerType:s},t))}}})}}}))}function nn(t){var e=t.value,r=t.key,n=t.styleSpec,i=t.style;if(!e.type)return[new Dt(r,e,'\"type\" is required')];var a,o=Nt(e.type);switch(o){case\"vector\":case\"raster\":case\"raster-dem\":if(a=Fr({key:r,value:e,valueSpec:n[\"source_\"+o.replace(\"-\",\"_\")],style:t.style,styleSpec:n}),\"url\"in e)for(var s in e)[\"type\",\"url\",\"tileSize\"].indexOf(s)<0&&a.push(new Dt(r+\".\"+s,e[s],'a source with a \"url\" property may not include a \"'+s+'\" property'));return a;case\"geojson\":if(a=Fr({key:r,value:e,valueSpec:n.source_geojson,style:i,styleSpec:n}),e.cluster)for(var l in e.clusterProperties){var c=e.clusterProperties[l],u=c[0],h=c[1],f=\"string\"==typeof u?[u,[\"accumulated\"],[\"get\",l]]:u;a.push.apply(a,Ur({key:r+\".\"+l+\".map\",value:h,expressionContext:\"cluster-map\"})),a.push.apply(a,Ur({key:r+\".\"+l+\".reduce\",value:f,expressionContext:\"cluster-reduce\"}))}return a;case\"video\":return Fr({key:r,value:e,valueSpec:n.source_video,style:i,styleSpec:n});case\"image\":return Fr({key:r,value:e,valueSpec:n.source_image,style:i,styleSpec:n});case\"canvas\":return[new Dt(r,null,\"Please use runtime APIs to add canvas sources, rather than including them in stylesheets.\",\"source.canvas\")];default:return Vr({key:r+\".type\",value:e.type,valueSpec:{values:[\"vector\",\"raster\",\"raster-dem\",\"geojson\",\"video\",\"image\"]},style:i,styleSpec:n})}}function an(t){var e=t.value,r=t.styleSpec,n=r.light,i=t.style,a=[],o=wr(e);if(void 0===e)return a;if(\"object\"!==o)return a.concat([new Dt(\"light\",e,\"object expected, \"+o+\" found\")]);for(var s in e){var l=s.match(/^(.*)-transition$/);a=l&&n[l[1]]&&n[l[1]].transition?a.concat(ln({key:s,value:e[s],valueSpec:r.transition,style:i,styleSpec:r})):n[s]?a.concat(ln({key:s,value:e[s],valueSpec:n[s],style:i,styleSpec:r})):a.concat([new Dt(s,e[s],'unknown property \"'+s+'\"')])}return a}function on(t){var e=t.value,r=t.key,n=wr(e);return\"string\"!==n?[new Dt(r,e,\"string expected, \"+n+\" found\")]:[]}var sn={\"*\":function(){return[]},array:Br,boolean:function(t){var e=t.value,r=t.key,n=wr(e);return\"boolean\"!==n?[new Dt(r,e,\"boolean expected, \"+n+\" found\")]:[]},number:Nr,color:function(t){var e=t.key,r=t.value,n=wr(r);return\"string\"!==n?[new Dt(e,r,\"color expected, \"+n+\" found\")]:null===re(r)?[new Dt(e,r,'color expected, \"'+r+'\" found')]:[]},constants:Rt,enum:Vr,filter:$r,function:jr,layer:rn,object:Fr,source:nn,light:an,string:on,formatted:function(t){return 0===on(t).length?[]:Ur(t)}};function ln(t){var e=t.value,r=t.valueSpec,n=t.styleSpec;return r.expression&&kr(Nt(e))?jr(t):r.expression&&Pr(jt(e))?Ur(t):r.type&&sn[r.type]?sn[r.type](t):Fr(Ft({},t,{valueSpec:r.type?n[r.type]:r}))}function cn(t){var e=t.value,r=t.key,n=on(t);return n.length?n:(-1===e.indexOf(\"{fontstack}\")&&n.push(new Dt(r,e,'\"glyphs\" url must include a \"{fontstack}\" token')),-1===e.indexOf(\"{range}\")&&n.push(new Dt(r,e,'\"glyphs\" url must include a \"{range}\" token')),n)}function un(t,e){e=e||It;var r=[];return r=r.concat(ln({key:\"\",value:t,valueSpec:e.$root,styleSpec:e,style:t,objectElementValidators:{glyphs:cn,\"*\":function(){return[]}}})),t.constants&&(r=r.concat(Rt({key:\"constants\",value:t.constants,style:t,styleSpec:e}))),hn(r)}function hn(t){return[].concat(t).sort(function(t,e){return t.line-e.line})}function fn(t){return function(){for(var e=[],r=arguments.length;r--;)e[r]=arguments[r];return hn(t.apply(this,e))}}un.source=fn(nn),un.light=fn(an),un.layer=fn(rn),un.filter=fn($r),un.paintProperty=fn(tn),un.layoutProperty=fn(en);var pn=un,dn=pn.light,gn=pn.paintProperty,vn=pn.layoutProperty;function mn(t,e){var r=!1;if(e&&e.length)for(var n=0,i=e;n<i.length;n+=1){var a=i[n];t.fire(new Ot(new Error(a.message))),r=!0}return r}var yn=bn,xn=3;function bn(t,e,r){var n=this.cells=[];if(t instanceof ArrayBuffer){this.arrayBuffer=t;var i=new Int32Array(this.arrayBuffer);t=i[0],e=i[1],r=i[2],this.d=e+2*r;for(var a=0;a<this.d*this.d;a++){var o=i[xn+a],s=i[xn+a+1];n.push(o===s?null:i.subarray(o,s))}var l=i[xn+n.length],c=i[xn+n.length+1];this.keys=i.subarray(l,c),this.bboxes=i.subarray(c),this.insert=this._insertReadonly}else{this.d=e+2*r;for(var u=0;u<this.d*this.d;u++)n.push([]);this.keys=[],this.bboxes=[]}this.n=e,this.extent=t,this.padding=r,this.scale=e/t,this.uid=0;var h=r/e*t;this.min=-h,this.max=t+h}bn.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertCell,this.uid++),this.keys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},bn.prototype._insertReadonly=function(){throw\"Cannot insert into a GridIndex created from an ArrayBuffer.\"},bn.prototype._insertCell=function(t,e,r,n,i,a){this.cells[i].push(a)},bn.prototype.query=function(t,e,r,n,i){var a=this.min,o=this.max;if(t<=a&&e<=a&&o<=r&&o<=n&&!i)return Array.prototype.slice.call(this.keys);var s=[];return this._forEachCell(t,e,r,n,this._queryCell,s,{},i),s},bn.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=this.cells[i];if(null!==l)for(var c=this.keys,u=this.bboxes,h=0;h<l.length;h++){var f=l[h];if(void 0===o[f]){var p=4*f;(s?s(u[p+0],u[p+1],u[p+2],u[p+3]):t<=u[p+2]&&e<=u[p+3]&&r>=u[p+0]&&n>=u[p+1])?(o[f]=!0,a.push(c[f])):o[f]=!1}}},bn.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToCellCoord(t),c=this._convertToCellCoord(e),u=this._convertToCellCoord(r),h=this._convertToCellCoord(n),f=l;f<=u;f++)for(var p=c;p<=h;p++){var d=this.d*p+f;if((!s||s(this._convertFromCellCoord(f),this._convertFromCellCoord(p),this._convertFromCellCoord(f+1),this._convertFromCellCoord(p+1)))&&i.call(this,t,e,r,n,d,a,o,s))return}},bn.prototype._convertFromCellCoord=function(t){return(t-this.padding)/this.scale},bn.prototype._convertToCellCoord=function(t){return Math.max(0,Math.min(this.d-1,Math.floor(t*this.scale)+this.padding))},bn.prototype.toArrayBuffer=function(){if(this.arrayBuffer)return this.arrayBuffer;for(var t=this.cells,e=xn+this.cells.length+1+1,r=0,n=0;n<this.cells.length;n++)r+=this.cells[n].length;var i=new Int32Array(e+r+this.keys.length+this.bboxes.length);i[0]=this.extent,i[1]=this.n,i[2]=this.padding;for(var a=e,o=0;o<t.length;o++){var s=t[o];i[xn+o]=a,i.set(s,a),a+=s.length}return i[xn+t.length]=a,i.set(this.keys,a),a+=this.keys.length,i[xn+t.length+1]=a,i.set(this.bboxes,a),a+=this.bboxes.length,i.buffer};var _n=self.ImageData,wn={};function kn(t,e,r){void 0===r&&(r={}),Object.defineProperty(e,\"_classRegistryKey\",{value:t,writeable:!1}),wn[t]={klass:e,omit:r.omit||[],shallow:r.shallow||[]}}for(var Tn in kn(\"Object\",Object),yn.serialize=function(t,e){var r=t.toArrayBuffer();return e&&e.push(r),{buffer:r}},yn.deserialize=function(t){return new yn(t.buffer)},kn(\"Grid\",yn),kn(\"Color\",ne),kn(\"Error\",Error),kn(\"StylePropertyFunction\",Rr),kn(\"StyleExpression\",Lr,{omit:[\"_evaluator\"]}),kn(\"ZoomDependentExpression\",Ir),kn(\"ZoomConstantExpression\",zr),kn(\"CompoundExpression\",xe,{omit:[\"_evaluate\"]}),fr)fr[Tn]._classRegistryKey||kn(\"Expression_\"+Tn,fr[Tn]);function An(t,e){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp)return t;if(t instanceof ArrayBuffer)return e&&e.push(t),t;if(ArrayBuffer.isView(t)){var r=t;return e&&e.push(r.buffer),r}if(t instanceof _n)return e&&e.push(t.data.buffer),t;if(Array.isArray(t)){for(var n=[],i=0,a=t;i<a.length;i+=1){var o=a[i];n.push(An(o,e))}return n}if(\"object\"==typeof t){var s=t.constructor,l=s._classRegistryKey;if(!l)throw new Error(\"can't serialize object of unregistered class\");var c=s.serialize?s.serialize(t,e):{};if(!s.serialize){for(var u in t)if(t.hasOwnProperty(u)&&!(wn[l].omit.indexOf(u)>=0)){var h=t[u];c[u]=wn[l].shallow.indexOf(u)>=0?h:An(h,e)}t instanceof Error&&(c.message=t.message)}if(c.$name)throw new Error(\"$name property is reserved for worker serialization logic.\");return\"Object\"!==l&&(c.$name=l),c}throw new Error(\"can't serialize object of type \"+typeof t)}function Mn(t){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp||t instanceof ArrayBuffer||ArrayBuffer.isView(t)||t instanceof _n)return t;if(Array.isArray(t))return t.map(Mn);if(\"object\"==typeof t){var e=t.$name||\"Object\",r=wn[e].klass;if(!r)throw new Error(\"can't deserialize unregistered class \"+e);if(r.deserialize)return r.deserialize(t);for(var n=Object.create(r.prototype),i=0,a=Object.keys(t);i<a.length;i+=1){var o=a[i];if(\"$name\"!==o){var s=t[o];n[o]=wn[e].shallow.indexOf(o)>=0?s:Mn(s)}}return n}throw new Error(\"can't deserialize object of type \"+typeof t)}var Sn=function(){this.first=!0};Sn.prototype.update=function(t,e){var r=Math.floor(t);return this.first?(this.first=!1,this.lastIntegerZoom=r,this.lastIntegerZoomTime=0,this.lastZoom=t,this.lastFloorZoom=r,!0):(this.lastFloorZoom>r?(this.lastIntegerZoom=r+1,this.lastIntegerZoomTime=e):this.lastFloorZoom<r&&(this.lastIntegerZoom=r,this.lastIntegerZoomTime=e),t!==this.lastZoom&&(this.lastZoom=t,this.lastFloorZoom=r,!0))};var En={\"Latin-1 Supplement\":function(t){return t>=128&&t<=255},Arabic:function(t){return t>=1536&&t<=1791},\"Arabic Supplement\":function(t){return t>=1872&&t<=1919},\"Arabic Extended-A\":function(t){return t>=2208&&t<=2303},\"Hangul Jamo\":function(t){return t>=4352&&t<=4607},\"Unified Canadian Aboriginal Syllabics\":function(t){return t>=5120&&t<=5759},Khmer:function(t){return t>=6016&&t<=6143},\"Unified Canadian Aboriginal Syllabics Extended\":function(t){return t>=6320&&t<=6399},\"General Punctuation\":function(t){return t>=8192&&t<=8303},\"Letterlike Symbols\":function(t){return t>=8448&&t<=8527},\"Number Forms\":function(t){return t>=8528&&t<=8591},\"Miscellaneous Technical\":function(t){return t>=8960&&t<=9215},\"Control Pictures\":function(t){return t>=9216&&t<=9279},\"Optical Character Recognition\":function(t){return t>=9280&&t<=9311},\"Enclosed Alphanumerics\":function(t){return t>=9312&&t<=9471},\"Geometric Shapes\":function(t){return t>=9632&&t<=9727},\"Miscellaneous Symbols\":function(t){return t>=9728&&t<=9983},\"Miscellaneous Symbols and Arrows\":function(t){return t>=11008&&t<=11263},\"CJK Radicals Supplement\":function(t){return t>=11904&&t<=12031},\"Kangxi Radicals\":function(t){return t>=12032&&t<=12255},\"Ideographic Description Characters\":function(t){return t>=12272&&t<=12287},\"CJK Symbols and Punctuation\":function(t){return t>=12288&&t<=12351},Hiragana:function(t){return t>=12352&&t<=12447},Katakana:function(t){return t>=12448&&t<=12543},Bopomofo:function(t){return t>=12544&&t<=12591},\"Hangul Compatibility Jamo\":function(t){return t>=12592&&t<=12687},Kanbun:function(t){return t>=12688&&t<=12703},\"Bopomofo Extended\":function(t){return t>=12704&&t<=12735},\"CJK Strokes\":function(t){return t>=12736&&t<=12783},\"Katakana Phonetic Extensions\":function(t){return t>=12784&&t<=12799},\"Enclosed CJK Letters and Months\":function(t){return t>=12800&&t<=13055},\"CJK Compatibility\":function(t){return t>=13056&&t<=13311},\"CJK Unified Ideographs Extension A\":function(t){return t>=13312&&t<=19903},\"Yijing Hexagram Symbols\":function(t){return t>=19904&&t<=19967},\"CJK Unified Ideographs\":function(t){return t>=19968&&t<=40959},\"Yi Syllables\":function(t){return t>=40960&&t<=42127},\"Yi Radicals\":function(t){return t>=42128&&t<=42191},\"Hangul Jamo Extended-A\":function(t){return t>=43360&&t<=43391},\"Hangul Syllables\":function(t){return t>=44032&&t<=55215},\"Hangul Jamo Extended-B\":function(t){return t>=55216&&t<=55295},\"Private Use Area\":function(t){return t>=57344&&t<=63743},\"CJK Compatibility Ideographs\":function(t){return t>=63744&&t<=64255},\"Arabic Presentation Forms-A\":function(t){return t>=64336&&t<=65023},\"Vertical Forms\":function(t){return t>=65040&&t<=65055},\"CJK Compatibility Forms\":function(t){return t>=65072&&t<=65103},\"Small Form Variants\":function(t){return t>=65104&&t<=65135},\"Arabic Presentation Forms-B\":function(t){return t>=65136&&t<=65279},\"Halfwidth and Fullwidth Forms\":function(t){return t>=65280&&t<=65519}};function Cn(t){for(var e=0,r=t;e<r.length;e+=1)if(On(r[e].charCodeAt(0)))return!0;return!1}function Ln(t){for(var e=0,r=t;e<r.length;e+=1)if(!Pn(r[e].charCodeAt(0)))return!1;return!0}function Pn(t){return!(En.Arabic(t)||En[\"Arabic Supplement\"](t)||En[\"Arabic Extended-A\"](t)||En[\"Arabic Presentation Forms-A\"](t)||En[\"Arabic Presentation Forms-B\"](t))}function On(t){return!!(746===t||747===t||!(t<4352)&&(En[\"Bopomofo Extended\"](t)||En.Bopomofo(t)||En[\"CJK Compatibility Forms\"](t)&&!(t>=65097&&t<=65103)||En[\"CJK Compatibility Ideographs\"](t)||En[\"CJK Compatibility\"](t)||En[\"CJK Radicals Supplement\"](t)||En[\"CJK Strokes\"](t)||!(!En[\"CJK Symbols and Punctuation\"](t)||t>=12296&&t<=12305||t>=12308&&t<=12319||12336===t)||En[\"CJK Unified Ideographs Extension A\"](t)||En[\"CJK Unified Ideographs\"](t)||En[\"Enclosed CJK Letters and Months\"](t)||En[\"Hangul Compatibility Jamo\"](t)||En[\"Hangul Jamo Extended-A\"](t)||En[\"Hangul Jamo Extended-B\"](t)||En[\"Hangul Jamo\"](t)||En[\"Hangul Syllables\"](t)||En.Hiragana(t)||En[\"Ideographic Description Characters\"](t)||En.Kanbun(t)||En[\"Kangxi Radicals\"](t)||En[\"Katakana Phonetic Extensions\"](t)||En.Katakana(t)&&12540!==t||!(!En[\"Halfwidth and Fullwidth Forms\"](t)||65288===t||65289===t||65293===t||t>=65306&&t<=65310||65339===t||65341===t||65343===t||t>=65371&&t<=65503||65507===t||t>=65512&&t<=65519)||!(!En[\"Small Form Variants\"](t)||t>=65112&&t<=65118||t>=65123&&t<=65126)||En[\"Unified Canadian Aboriginal Syllabics\"](t)||En[\"Unified Canadian Aboriginal Syllabics Extended\"](t)||En[\"Vertical Forms\"](t)||En[\"Yijing Hexagram Symbols\"](t)||En[\"Yi Syllables\"](t)||En[\"Yi Radicals\"](t)))}function zn(t){return!(On(t)||function(t){return!!(En[\"Latin-1 Supplement\"](t)&&(167===t||169===t||174===t||177===t||188===t||189===t||190===t||215===t||247===t)||En[\"General Punctuation\"](t)&&(8214===t||8224===t||8225===t||8240===t||8241===t||8251===t||8252===t||8258===t||8263===t||8264===t||8265===t||8273===t)||En[\"Letterlike Symbols\"](t)||En[\"Number Forms\"](t)||En[\"Miscellaneous Technical\"](t)&&(t>=8960&&t<=8967||t>=8972&&t<=8991||t>=8996&&t<=9e3||9003===t||t>=9085&&t<=9114||t>=9150&&t<=9165||9167===t||t>=9169&&t<=9179||t>=9186&&t<=9215)||En[\"Control Pictures\"](t)&&9251!==t||En[\"Optical Character Recognition\"](t)||En[\"Enclosed Alphanumerics\"](t)||En[\"Geometric Shapes\"](t)||En[\"Miscellaneous Symbols\"](t)&&!(t>=9754&&t<=9759)||En[\"Miscellaneous Symbols and Arrows\"](t)&&(t>=11026&&t<=11055||t>=11088&&t<=11097||t>=11192&&t<=11243)||En[\"CJK Symbols and Punctuation\"](t)||En.Katakana(t)||En[\"Private Use Area\"](t)||En[\"CJK Compatibility Forms\"](t)||En[\"Small Form Variants\"](t)||En[\"Halfwidth and Fullwidth Forms\"](t)||8734===t||8756===t||8757===t||t>=9984&&t<=10087||t>=10102&&t<=10131||65532===t||65533===t)}(t))}function In(t,e){return!(!e&&(t>=1424&&t<=2303||En[\"Arabic Presentation Forms-A\"](t)||En[\"Arabic Presentation Forms-B\"](t))||t>=2304&&t<=3583||t>=3840&&t<=4255||En.Khmer(t))}var Dn,Rn=!1,Fn=null,Bn=!1,Nn=new zt,jn={applyArabicShaping:null,processBidirectionalText:null,processStyledBidirectionalText:null,isLoaded:function(){return Bn||null!=jn.applyArabicShaping}},Un=function(t,e){this.zoom=t,e?(this.now=e.now,this.fadeDuration=e.fadeDuration,this.zoomHistory=e.zoomHistory,this.transition=e.transition):(this.now=0,this.fadeDuration=0,this.zoomHistory=new Sn,this.transition={})};Un.prototype.isSupportedScript=function(t){return function(t,e){for(var r=0,n=t;r<n.length;r+=1)if(!In(n[r].charCodeAt(0),e))return!1;return!0}(t,jn.isLoaded())},Un.prototype.crossFadingFactor=function(){return 0===this.fadeDuration?1:Math.min((this.now-this.zoomHistory.lastIntegerZoomTime)/this.fadeDuration,1)},Un.prototype.getCrossfadeParameters=function(){var t=this.zoom,e=t-Math.floor(t),r=this.crossFadingFactor();return t>this.zoomHistory.lastIntegerZoom?{fromScale:2,toScale:1,t:e+(1-e)*r}:{fromScale:.5,toScale:1,t:1-(1-r)*e}};var Vn=function(t,e){this.property=t,this.value=e,this.expression=function(t,e){if(kr(t))return new Rr(t,e);if(Pr(t)){var r=Dr(t,e);if(\"error\"===r.result)throw new Error(r.value.map(function(t){return t.key+\": \"+t.message}).join(\", \"));return r.value}var n=t;return\"string\"==typeof t&&\"color\"===e.type&&(n=ne.parse(t)),{kind:\"constant\",evaluate:function(){return n}}}(void 0===e?t.specification.default:e,t.specification)};Vn.prototype.isDataDriven=function(){return\"source\"===this.expression.kind||\"composite\"===this.expression.kind},Vn.prototype.possiblyEvaluate=function(t){return this.property.possiblyEvaluate(this,t)};var qn=function(t){this.property=t,this.value=new Vn(t,void 0)};qn.prototype.transitioned=function(t,e){return new Gn(this.property,this.value,e,h({},t.transition,this.transition),t.now)},qn.prototype.untransitioned=function(){return new Gn(this.property,this.value,null,{},0)};var Hn=function(t){this._properties=t,this._values=Object.create(t.defaultTransitionablePropertyValues)};Hn.prototype.getValue=function(t){return b(this._values[t].value.value)},Hn.prototype.setValue=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new qn(this._values[t].property)),this._values[t].value=new Vn(this._values[t].property,null===e?void 0:b(e))},Hn.prototype.getTransition=function(t){return b(this._values[t].transition)},Hn.prototype.setTransition=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new qn(this._values[t].property)),this._values[t].transition=b(e)||void 0},Hn.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i);var a=this.getTransition(n);void 0!==a&&(t[n+\"-transition\"]=a)}return t},Hn.prototype.transitioned=function(t,e){for(var r=new Yn(this._properties),n=0,i=Object.keys(this._values);n<i.length;n+=1){var a=i[n];r._values[a]=this._values[a].transitioned(t,e._values[a])}return r},Hn.prototype.untransitioned=function(){for(var t=new Yn(this._properties),e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e];t._values[n]=this._values[n].untransitioned()}return t};var Gn=function(t,e,r,n,i){this.property=t,this.value=e,this.begin=i+n.delay||0,this.end=this.begin+n.duration||0,t.specification.transition&&(n.delay||n.duration)&&(this.prior=r)};Gn.prototype.possiblyEvaluate=function(t){var e=t.now||0,r=this.value.possiblyEvaluate(t),n=this.prior;if(n){if(e>this.end)return this.prior=null,r;if(this.value.isDataDriven())return this.prior=null,r;if(e<this.begin)return n.possiblyEvaluate(t);var i=(e-this.begin)/(this.end-this.begin);return this.property.interpolate(n.possiblyEvaluate(t),r,function(t){if(i<=0)return 0;if(i>=1)return 1;var e=i*i,r=e*i;return 4*(i<.5?r:3*(i-e)+r-.75)}())}return r};var Yn=function(t){this._properties=t,this._values=Object.create(t.defaultTransitioningPropertyValues)};Yn.prototype.possiblyEvaluate=function(t){for(var e=new Zn(this._properties),r=0,n=Object.keys(this._values);r<n.length;r+=1){var i=n[r];e._values[i]=this._values[i].possiblyEvaluate(t)}return e},Yn.prototype.hasTransition=function(){for(var t=0,e=Object.keys(this._values);t<e.length;t+=1){var r=e[t];if(this._values[r].prior)return!0}return!1};var Wn=function(t){this._properties=t,this._values=Object.create(t.defaultPropertyValues)};Wn.prototype.getValue=function(t){return b(this._values[t].value)},Wn.prototype.setValue=function(t,e){this._values[t]=new Vn(this._values[t].property,null===e?void 0:b(e))},Wn.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i)}return t},Wn.prototype.possiblyEvaluate=function(t){for(var e=new Zn(this._properties),r=0,n=Object.keys(this._values);r<n.length;r+=1){var i=n[r];e._values[i]=this._values[i].possiblyEvaluate(t)}return e};var Xn=function(t,e,r){this.property=t,this.value=e,this.parameters=r};Xn.prototype.isConstant=function(){return\"constant\"===this.value.kind},Xn.prototype.constantOr=function(t){return\"constant\"===this.value.kind?this.value.value:t},Xn.prototype.evaluate=function(t,e){return this.property.evaluate(this.value,this.parameters,t,e)};var Zn=function(t){this._properties=t,this._values=Object.create(t.defaultPossiblyEvaluatedValues)};Zn.prototype.get=function(t){return this._values[t]};var Jn=function(t){this.specification=t};Jn.prototype.possiblyEvaluate=function(t,e){return t.expression.evaluate(e)},Jn.prototype.interpolate=function(t,e,r){var n=Ce[this.specification.type];return n?n(t,e,r):t};var Kn=function(t){this.specification=t};Kn.prototype.possiblyEvaluate=function(t,e){return\"constant\"===t.expression.kind||\"camera\"===t.expression.kind?new Xn(this,{kind:\"constant\",value:t.expression.evaluate(e)},e):new Xn(this,t.expression,e)},Kn.prototype.interpolate=function(t,e,r){if(\"constant\"!==t.value.kind||\"constant\"!==e.value.kind)return t;if(void 0===t.value.value||void 0===e.value.value)return new Xn(this,{kind:\"constant\",value:void 0},t.parameters);var n=Ce[this.specification.type];return n?new Xn(this,{kind:\"constant\",value:n(t.value.value,e.value.value,r)},t.parameters):t},Kn.prototype.evaluate=function(t,e,r,n){return\"constant\"===t.kind?t.value:t.evaluate(e,r,n)};var $n=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(t,e){if(void 0===t.value)return new Xn(this,{kind:\"constant\",value:void 0},e);if(\"constant\"===t.expression.kind){var r=t.expression.evaluate(e),n=this._calculate(r,r,r,e);return new Xn(this,{kind:\"constant\",value:n},e)}if(\"camera\"===t.expression.kind){var i=this._calculate(t.expression.evaluate({zoom:e.zoom-1}),t.expression.evaluate({zoom:e.zoom}),t.expression.evaluate({zoom:e.zoom+1}),e);return new Xn(this,{kind:\"constant\",value:i},e)}return new Xn(this,t.expression,e)},e.prototype.evaluate=function(t,e,r,n){if(\"source\"===t.kind){var i=t.evaluate(e,r,n);return this._calculate(i,i,i,e)}return\"composite\"===t.kind?this._calculate(t.evaluate({zoom:Math.floor(e.zoom)-1},r,n),t.evaluate({zoom:Math.floor(e.zoom)},r,n),t.evaluate({zoom:Math.floor(e.zoom)+1},r,n),e):t.value},e.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},e.prototype.interpolate=function(t){return t},e}(Kn),Qn=function(t){this.specification=t};Qn.prototype.possiblyEvaluate=function(t,e){if(void 0!==t.value){if(\"constant\"===t.expression.kind){var r=t.expression.evaluate(e);return this._calculate(r,r,r,e)}return this._calculate(t.expression.evaluate(new Un(Math.floor(e.zoom-1),e)),t.expression.evaluate(new Un(Math.floor(e.zoom),e)),t.expression.evaluate(new Un(Math.floor(e.zoom+1),e)),e)}},Qn.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},Qn.prototype.interpolate=function(t){return t};var ti=function(t){this.specification=t};ti.prototype.possiblyEvaluate=function(t,e){return!!t.expression.evaluate(e)},ti.prototype.interpolate=function(){return!1};var ei=function(t){for(var e in this.properties=t,this.defaultPropertyValues={},this.defaultTransitionablePropertyValues={},this.defaultTransitioningPropertyValues={},this.defaultPossiblyEvaluatedValues={},t){var r=t[e],n=this.defaultPropertyValues[e]=new Vn(r,void 0),i=this.defaultTransitionablePropertyValues[e]=new qn(r);this.defaultTransitioningPropertyValues[e]=i.untransitioned(),this.defaultPossiblyEvaluatedValues[e]=n.possiblyEvaluate({})}};kn(\"DataDrivenProperty\",Kn),kn(\"DataConstantProperty\",Jn),kn(\"CrossFadedDataDrivenProperty\",$n),kn(\"CrossFadedProperty\",Qn),kn(\"ColorRampProperty\",ti);var ri=function(t){function e(e,r){if(t.call(this),this.id=e.id,this.type=e.type,this._featureFilter=function(){return!0},\"custom\"!==e.type&&(e=e,this.metadata=e.metadata,this.minzoom=e.minzoom,this.maxzoom=e.maxzoom,\"background\"!==e.type&&(this.source=e.source,this.sourceLayer=e[\"source-layer\"],this.filter=e.filter),r.layout&&(this._unevaluatedLayout=new Wn(r.layout)),r.paint)){for(var n in this._transitionablePaint=new Hn(r.paint),e.paint)this.setPaintProperty(n,e.paint[n],{validate:!1});for(var i in e.layout)this.setLayoutProperty(i,e.layout[i],{validate:!1});this._transitioningPaint=this._transitionablePaint.untransitioned()}}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getCrossfadeParameters=function(){return this._crossfadeParameters},e.prototype.getLayoutProperty=function(t){return\"visibility\"===t?this.visibility:this._unevaluatedLayout.getValue(t)},e.prototype.setLayoutProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e){var n=\"layers.\"+this.id+\".layout.\"+t;if(this._validate(vn,n,t,e,r))return}\"visibility\"!==t?this._unevaluatedLayout.setValue(t,e):this.visibility=e},e.prototype.getPaintProperty=function(t){return m(t,\"-transition\")?this._transitionablePaint.getTransition(t.slice(0,-\"-transition\".length)):this._transitionablePaint.getValue(t)},e.prototype.setPaintProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e){var n=\"layers.\"+this.id+\".paint.\"+t;if(this._validate(gn,n,t,e,r))return!1}if(m(t,\"-transition\"))return this._transitionablePaint.setTransition(t.slice(0,-\"-transition\".length),e||void 0),!1;var i=this._transitionablePaint._values[t],a=\"cross-faded-data-driven\"===i.property.specification[\"property-type\"],o=i.value.isDataDriven();return this._transitionablePaint.setValue(t,e),this._handleSpecialPaintPropertyUpdate(t),this._transitionablePaint._values[t].value.isDataDriven()||o||a},e.prototype._handleSpecialPaintPropertyUpdate=function(t){},e.prototype.isHidden=function(t){return!!(this.minzoom&&t<this.minzoom)||!!(this.maxzoom&&t>=this.maxzoom)||\"none\"===this.visibility},e.prototype.updateTransitions=function(t){this._transitioningPaint=this._transitionablePaint.transitioned(t,this._transitioningPaint)},e.prototype.hasTransition=function(){return this._transitioningPaint.hasTransition()},e.prototype.recalculate=function(t){t.getCrossfadeParameters&&(this._crossfadeParameters=t.getCrossfadeParameters()),this._unevaluatedLayout&&(this.layout=this._unevaluatedLayout.possiblyEvaluate(t)),this.paint=this._transitioningPaint.possiblyEvaluate(t)},e.prototype.serialize=function(){var t={id:this.id,type:this.type,source:this.source,\"source-layer\":this.sourceLayer,metadata:this.metadata,minzoom:this.minzoom,maxzoom:this.maxzoom,filter:this.filter,layout:this._unevaluatedLayout&&this._unevaluatedLayout.serialize(),paint:this._transitionablePaint&&this._transitionablePaint.serialize()};return this.visibility&&(t.layout=t.layout||{},t.layout.visibility=this.visibility),x(t,function(t,e){return!(void 0===t||\"layout\"===e&&!Object.keys(t).length||\"paint\"===e&&!Object.keys(t).length)})},e.prototype._validate=function(t,e,r,n,i){return void 0===i&&(i={}),(!i||!1!==i.validate)&&mn(this,t.call(pn,{key:e,layerType:this.type,objectKey:r,value:n,styleSpec:It,style:{glyphs:!0,sprite:!0}}))},e.prototype.is3D=function(){return!1},e.prototype.isTileClipped=function(){return!1},e.prototype.hasOffscreenPass=function(){return!1},e.prototype.resize=function(){},e.prototype.isStateDependent=function(){for(var t in this.paint._values){var e=this.paint.get(t);if(e instanceof Xn&&xr(e.property.specification)&&(\"source\"===e.value.kind||\"composite\"===e.value.kind)&&e.value.isStateDependent)return!0}return!1},e}(zt),ni={Int8:Int8Array,Uint8:Uint8Array,Int16:Int16Array,Uint16:Uint16Array,Int32:Int32Array,Uint32:Uint32Array,Float32:Float32Array},ii=function(t,e){this._structArray=t,this._pos1=e*this.size,this._pos2=this._pos1/2,this._pos4=this._pos1/4,this._pos8=this._pos1/8},ai=function(){this.isTransferred=!1,this.capacity=-1,this.resize(0)};function oi(t,e){void 0===e&&(e=1);var r=0,n=0;return{members:t.map(function(t){var i,a=(i=t.type,ni[i].BYTES_PER_ELEMENT),o=r=si(r,Math.max(e,a)),s=t.components||1;return n=Math.max(n,a),r+=a*s,{name:t.name,type:t.type,components:s,offset:o}}),size:si(r,Math.max(n,e)),alignment:e}}function si(t,e){return Math.ceil(t/e)*e}ai.serialize=function(t,e){return t._trim(),e&&(t.isTransferred=!0,e.push(t.arrayBuffer)),{length:t.length,arrayBuffer:t.arrayBuffer}},ai.deserialize=function(t){var e=Object.create(this.prototype);return e.arrayBuffer=t.arrayBuffer,e.length=t.length,e.capacity=t.arrayBuffer.byteLength/e.bytesPerElement,e._refreshViews(),e},ai.prototype._trim=function(){this.length!==this.capacity&&(this.capacity=this.length,this.arrayBuffer=this.arrayBuffer.slice(0,this.length*this.bytesPerElement),this._refreshViews())},ai.prototype.clear=function(){this.length=0},ai.prototype.resize=function(t){this.reserve(t),this.length=t},ai.prototype.reserve=function(t){if(t>this.capacity){this.capacity=Math.max(t,Math.floor(5*this.capacity),128),this.arrayBuffer=new ArrayBuffer(this.capacity*this.bytesPerElement);var e=this.uint8;this._refreshViews(),e&&this.uint8.set(e)}},ai.prototype._refreshViews=function(){throw new Error(\"_refreshViews() must be implemented by each concrete StructArray layout\")};var li=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.int16[n+0]=e,this.int16[n+1]=r,t},e}(ai);li.prototype.bytesPerElement=4,kn(\"StructArrayLayout2i4\",li);var ci=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.int16[a+0]=e,this.int16[a+1]=r,this.int16[a+2]=n,this.int16[a+3]=i,t},e}(ai);ci.prototype.bytesPerElement=8,kn(\"StructArrayLayout4i8\",ci);var ui=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(ai);ui.prototype.bytesPerElement=12,kn(\"StructArrayLayout2i4i12\",ui);var hi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=4*t,l=8*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.uint8[l+4]=n,this.uint8[l+5]=i,this.uint8[l+6]=a,this.uint8[l+7]=o,t},e}(ai);hi.prototype.bytesPerElement=8,kn(\"StructArrayLayout2i4ub8\",hi);var fi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s){var l=this.length;return this.resize(l+1),this.emplace(l,t,e,r,n,i,a,o,s)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l){var c=8*t;return this.uint16[c+0]=e,this.uint16[c+1]=r,this.uint16[c+2]=n,this.uint16[c+3]=i,this.uint16[c+4]=a,this.uint16[c+5]=o,this.uint16[c+6]=s,this.uint16[c+7]=l,t},e}(ai);fi.prototype.bytesPerElement=16,kn(\"StructArrayLayout8ui16\",fi);var pi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s){var l=this.length;return this.resize(l+1),this.emplace(l,t,e,r,n,i,a,o,s)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l){var c=8*t;return this.int16[c+0]=e,this.int16[c+1]=r,this.int16[c+2]=n,this.int16[c+3]=i,this.uint16[c+4]=a,this.uint16[c+5]=o,this.uint16[c+6]=s,this.uint16[c+7]=l,t},e}(ai);pi.prototype.bytesPerElement=16,kn(\"StructArrayLayout4i4ui16\",pi);var di=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.float32[i+0]=e,this.float32[i+1]=r,this.float32[i+2]=n,t},e}(ai);di.prototype.bytesPerElement=12,kn(\"StructArrayLayout3f12\",di);var gi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.uint32[r+0]=e,t},e}(ai);gi.prototype.bytesPerElement=4,kn(\"StructArrayLayout1ul4\",gi);var vi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u){var h=this.length;return this.resize(h+1),this.emplace(h,t,e,r,n,i,a,o,s,l,c,u)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h){var f=12*t,p=6*t;return this.int16[f+0]=e,this.int16[f+1]=r,this.int16[f+2]=n,this.int16[f+3]=i,this.int16[f+4]=a,this.int16[f+5]=o,this.uint32[p+3]=s,this.uint16[f+8]=l,this.uint16[f+9]=c,this.int16[f+10]=u,this.int16[f+11]=h,t},e}(ai);vi.prototype.bytesPerElement=24,kn(\"StructArrayLayout6i1ul2ui2i24\",vi);var mi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(ai);mi.prototype.bytesPerElement=12,kn(\"StructArrayLayout2i2i2i12\",mi);var yi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=12*t,o=3*t;return this.uint8[a+0]=e,this.uint8[a+1]=r,this.float32[o+1]=n,this.float32[o+2]=i,t},e}(ai);yi.prototype.bytesPerElement=12,kn(\"StructArrayLayout2ub2f12\",yi);var xi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d){var g=this.length;return this.resize(g+1),this.emplace(g,t,e,r,n,i,a,o,s,l,c,u,h,f,p,d)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g){var v=22*t,m=11*t,y=44*t;return this.int16[v+0]=e,this.int16[v+1]=r,this.uint16[v+2]=n,this.uint16[v+3]=i,this.uint32[m+2]=a,this.uint32[m+3]=o,this.uint32[m+4]=s,this.uint16[v+10]=l,this.uint16[v+11]=c,this.uint16[v+12]=u,this.float32[m+7]=h,this.float32[m+8]=f,this.uint8[y+36]=p,this.uint8[y+37]=d,this.uint32[m+10]=g,t},e}(ai);xi.prototype.bytesPerElement=44,kn(\"StructArrayLayout2i2ui3ul3ui2f2ub1ul44\",xi);var bi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m){var y=this.length;return this.resize(y+1),this.emplace(y,t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m,y){var x=22*t,b=11*t;return this.int16[x+0]=e,this.int16[x+1]=r,this.int16[x+2]=n,this.int16[x+3]=i,this.int16[x+4]=a,this.int16[x+5]=o,this.uint16[x+6]=s,this.uint16[x+7]=l,this.uint16[x+8]=c,this.uint16[x+9]=u,this.uint16[x+10]=h,this.uint16[x+11]=f,this.uint16[x+12]=p,this.uint16[x+13]=d,this.uint16[x+14]=g,this.uint32[b+8]=v,this.float32[b+9]=m,this.float32[b+10]=y,t},e}(ai);bi.prototype.bytesPerElement=44,kn(\"StructArrayLayout6i9ui1ul2f44\",bi);var _i=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.float32[r+0]=e,t},e}(ai);_i.prototype.bytesPerElement=4,kn(\"StructArrayLayout1f4\",_i);var wi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.int16[i+0]=e,this.int16[i+1]=r,this.int16[i+2]=n,t},e}(ai);wi.prototype.bytesPerElement=6,kn(\"StructArrayLayout3i6\",wi);var ki=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=2*t,a=4*t;return this.uint32[i+0]=e,this.uint16[a+2]=r,this.uint16[a+3]=n,t},e}(ai);ki.prototype.bytesPerElement=8,kn(\"StructArrayLayout1ul2ui8\",ki);var Ti=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.uint16[i+0]=e,this.uint16[i+1]=r,this.uint16[i+2]=n,t},e}(ai);Ti.prototype.bytesPerElement=6,kn(\"StructArrayLayout3ui6\",Ti);var Ai=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.uint16[n+0]=e,this.uint16[n+1]=r,t},e}(ai);Ai.prototype.bytesPerElement=4,kn(\"StructArrayLayout2ui4\",Ai);var Mi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.uint16[r+0]=e,t},e}(ai);Mi.prototype.bytesPerElement=2,kn(\"StructArrayLayout1ui2\",Mi);var Si=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.float32[n+0]=e,this.float32[n+1]=r,t},e}(ai);Si.prototype.bytesPerElement=8,kn(\"StructArrayLayout2f8\",Si);var Ei=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.float32[a+0]=e,this.float32[a+1]=r,this.float32[a+2]=n,this.float32[a+3]=i,t},e}(ai);Ei.prototype.bytesPerElement=16,kn(\"StructArrayLayout4f16\",Ei);var Ci=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorPointX:{configurable:!0},anchorPointY:{configurable:!0},x1:{configurable:!0},y1:{configurable:!0},x2:{configurable:!0},y2:{configurable:!0},featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0},radius:{configurable:!0},signedDistanceFromAnchor:{configurable:!0},anchorPoint:{configurable:!0}};return r.anchorPointX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorPointX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorPointY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorPointY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.x1.get=function(){return this._structArray.int16[this._pos2+2]},r.x1.set=function(t){this._structArray.int16[this._pos2+2]=t},r.y1.get=function(){return this._structArray.int16[this._pos2+3]},r.y1.set=function(t){this._structArray.int16[this._pos2+3]=t},r.x2.get=function(){return this._structArray.int16[this._pos2+4]},r.x2.set=function(t){this._structArray.int16[this._pos2+4]=t},r.y2.get=function(){return this._structArray.int16[this._pos2+5]},r.y2.set=function(t){this._structArray.int16[this._pos2+5]=t},r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.featureIndex.set=function(t){this._structArray.uint32[this._pos4+3]=t},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.sourceLayerIndex.set=function(t){this._structArray.uint16[this._pos2+8]=t},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.bucketIndex.set=function(t){this._structArray.uint16[this._pos2+9]=t},r.radius.get=function(){return this._structArray.int16[this._pos2+10]},r.radius.set=function(t){this._structArray.int16[this._pos2+10]=t},r.signedDistanceFromAnchor.get=function(){return this._structArray.int16[this._pos2+11]},r.signedDistanceFromAnchor.set=function(t){this._structArray.int16[this._pos2+11]=t},r.anchorPoint.get=function(){return new i(this.anchorPointX,this.anchorPointY)},Object.defineProperties(e.prototype,r),e}(ii);Ci.prototype.size=24;var Li=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Ci(this,t)},e}(vi);kn(\"CollisionBoxArray\",Li);var Pi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},glyphStartIndex:{configurable:!0},numGlyphs:{configurable:!0},vertexStartIndex:{configurable:!0},lineStartIndex:{configurable:!0},lineLength:{configurable:!0},segment:{configurable:!0},lowerSize:{configurable:!0},upperSize:{configurable:!0},lineOffsetX:{configurable:!0},lineOffsetY:{configurable:!0},writingMode:{configurable:!0},hidden:{configurable:!0},crossTileID:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.glyphStartIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.glyphStartIndex.set=function(t){this._structArray.uint16[this._pos2+2]=t},r.numGlyphs.get=function(){return this._structArray.uint16[this._pos2+3]},r.numGlyphs.set=function(t){this._structArray.uint16[this._pos2+3]=t},r.vertexStartIndex.get=function(){return this._structArray.uint32[this._pos4+2]},r.vertexStartIndex.set=function(t){this._structArray.uint32[this._pos4+2]=t},r.lineStartIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.lineStartIndex.set=function(t){this._structArray.uint32[this._pos4+3]=t},r.lineLength.get=function(){return this._structArray.uint32[this._pos4+4]},r.lineLength.set=function(t){this._structArray.uint32[this._pos4+4]=t},r.segment.get=function(){return this._structArray.uint16[this._pos2+10]},r.segment.set=function(t){this._structArray.uint16[this._pos2+10]=t},r.lowerSize.get=function(){return this._structArray.uint16[this._pos2+11]},r.lowerSize.set=function(t){this._structArray.uint16[this._pos2+11]=t},r.upperSize.get=function(){return this._structArray.uint16[this._pos2+12]},r.upperSize.set=function(t){this._structArray.uint16[this._pos2+12]=t},r.lineOffsetX.get=function(){return this._structArray.float32[this._pos4+7]},r.lineOffsetX.set=function(t){this._structArray.float32[this._pos4+7]=t},r.lineOffsetY.get=function(){return this._structArray.float32[this._pos4+8]},r.lineOffsetY.set=function(t){this._structArray.float32[this._pos4+8]=t},r.writingMode.get=function(){return this._structArray.uint8[this._pos1+36]},r.writingMode.set=function(t){this._structArray.uint8[this._pos1+36]=t},r.hidden.get=function(){return this._structArray.uint8[this._pos1+37]},r.hidden.set=function(t){this._structArray.uint8[this._pos1+37]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+10]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+10]=t},Object.defineProperties(e.prototype,r),e}(ii);Pi.prototype.size=44;var Oi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Pi(this,t)},e}(xi);kn(\"PlacedSymbolArray\",Oi);var zi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},rightJustifiedTextSymbolIndex:{configurable:!0},centerJustifiedTextSymbolIndex:{configurable:!0},leftJustifiedTextSymbolIndex:{configurable:!0},verticalPlacedTextSymbolIndex:{configurable:!0},key:{configurable:!0},textBoxStartIndex:{configurable:!0},textBoxEndIndex:{configurable:!0},iconBoxStartIndex:{configurable:!0},iconBoxEndIndex:{configurable:!0},featureIndex:{configurable:!0},numHorizontalGlyphVertices:{configurable:!0},numVerticalGlyphVertices:{configurable:!0},numIconVertices:{configurable:!0},crossTileID:{configurable:!0},textBoxScale:{configurable:!0},radialTextOffset:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.rightJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+2]},r.rightJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+2]=t},r.centerJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+3]},r.centerJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+3]=t},r.leftJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+4]},r.leftJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+4]=t},r.verticalPlacedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+5]},r.verticalPlacedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+5]=t},r.key.get=function(){return this._structArray.uint16[this._pos2+6]},r.key.set=function(t){this._structArray.uint16[this._pos2+6]=t},r.textBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+7]},r.textBoxStartIndex.set=function(t){this._structArray.uint16[this._pos2+7]=t},r.textBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.textBoxEndIndex.set=function(t){this._structArray.uint16[this._pos2+8]=t},r.iconBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.iconBoxStartIndex.set=function(t){this._structArray.uint16[this._pos2+9]=t},r.iconBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+10]},r.iconBoxEndIndex.set=function(t){this._structArray.uint16[this._pos2+10]=t},r.featureIndex.get=function(){return this._structArray.uint16[this._pos2+11]},r.featureIndex.set=function(t){this._structArray.uint16[this._pos2+11]=t},r.numHorizontalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+12]},r.numHorizontalGlyphVertices.set=function(t){this._structArray.uint16[this._pos2+12]=t},r.numVerticalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+13]},r.numVerticalGlyphVertices.set=function(t){this._structArray.uint16[this._pos2+13]=t},r.numIconVertices.get=function(){return this._structArray.uint16[this._pos2+14]},r.numIconVertices.set=function(t){this._structArray.uint16[this._pos2+14]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+8]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+8]=t},r.textBoxScale.get=function(){return this._structArray.float32[this._pos4+9]},r.textBoxScale.set=function(t){this._structArray.float32[this._pos4+9]=t},r.radialTextOffset.get=function(){return this._structArray.float32[this._pos4+10]},r.radialTextOffset.set=function(t){this._structArray.float32[this._pos4+10]=t},Object.defineProperties(e.prototype,r),e}(ii);zi.prototype.size=44;var Ii=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new zi(this,t)},e}(bi);kn(\"SymbolInstanceArray\",Ii);var Di=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={offsetX:{configurable:!0}};return r.offsetX.get=function(){return this._structArray.float32[this._pos4+0]},r.offsetX.set=function(t){this._structArray.float32[this._pos4+0]=t},Object.defineProperties(e.prototype,r),e}(ii);Di.prototype.size=4;var Ri=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getoffsetX=function(t){return this.float32[1*t+0]},e.prototype.get=function(t){return new Di(this,t)},e}(_i);kn(\"GlyphOffsetArray\",Ri);var Fi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={x:{configurable:!0},y:{configurable:!0},tileUnitDistanceFromAnchor:{configurable:!0}};return r.x.get=function(){return this._structArray.int16[this._pos2+0]},r.x.set=function(t){this._structArray.int16[this._pos2+0]=t},r.y.get=function(){return this._structArray.int16[this._pos2+1]},r.y.set=function(t){this._structArray.int16[this._pos2+1]=t},r.tileUnitDistanceFromAnchor.get=function(){return this._structArray.int16[this._pos2+2]},r.tileUnitDistanceFromAnchor.set=function(t){this._structArray.int16[this._pos2+2]=t},Object.defineProperties(e.prototype,r),e}(ii);Fi.prototype.size=6;var Bi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getx=function(t){return this.int16[3*t+0]},e.prototype.gety=function(t){return this.int16[3*t+1]},e.prototype.gettileUnitDistanceFromAnchor=function(t){return this.int16[3*t+2]},e.prototype.get=function(t){return new Fi(this,t)},e}(wi);kn(\"SymbolLineVertexArray\",Bi);var Ni=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0}};return r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+0]},r.featureIndex.set=function(t){this._structArray.uint32[this._pos4+0]=t},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.sourceLayerIndex.set=function(t){this._structArray.uint16[this._pos2+2]=t},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+3]},r.bucketIndex.set=function(t){this._structArray.uint16[this._pos2+3]=t},Object.defineProperties(e.prototype,r),e}(ii);Ni.prototype.size=8;var ji=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Ni(this,t)},e}(ki);kn(\"FeatureIndexArray\",ji);var Ui=oi([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,Vi=function(t){void 0===t&&(t=[]),this.segments=t};function qi(t,e){return 256*(t=c(Math.floor(t),0,255))+c(Math.floor(e),0,255)}Vi.prototype.prepareSegment=function(t,e,r,n){var i=this.segments[this.segments.length-1];return t>Vi.MAX_VERTEX_ARRAY_LENGTH&&w(\"Max vertices per segment is \"+Vi.MAX_VERTEX_ARRAY_LENGTH+\": bucket requested \"+t),(!i||i.vertexLength+t>Vi.MAX_VERTEX_ARRAY_LENGTH||i.sortKey!==n)&&(i={vertexOffset:e.length,primitiveOffset:r.length,vertexLength:0,primitiveLength:0},void 0!==n&&(i.sortKey=n),this.segments.push(i)),i},Vi.prototype.get=function(){return this.segments},Vi.prototype.destroy=function(){for(var t=0,e=this.segments;t<e.length;t+=1){var r=e[t];for(var n in r.vaos)r.vaos[n].destroy()}},Vi.simpleSegment=function(t,e,r,n){return new Vi([{vertexOffset:t,primitiveOffset:e,vertexLength:r,primitiveLength:n,vaos:{},sortKey:0}])},Vi.MAX_VERTEX_ARRAY_LENGTH=Math.pow(2,16)-1,kn(\"SegmentVector\",Vi);var Hi=function(){this.ids=[],this.positions=[],this.indexed=!1};function Gi(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}Hi.prototype.add=function(t,e,r,n){this.ids.push(t),this.positions.push(e,r,n)},Hi.prototype.getPositions=function(t){for(var e=0,r=this.ids.length-1;e<r;){var n=e+r>>1;this.ids[n]>=t?r=n:e=n+1}for(var i=[];this.ids[e]===t;){var a=this.positions[3*e],o=this.positions[3*e+1],s=this.positions[3*e+2];i.push({index:a,start:o,end:s}),e++}return i},Hi.serialize=function(t,e){var r=new Float64Array(t.ids),n=new Uint32Array(t.positions);return function t(e,r,n,i){if(!(n>=i)){for(var a=e[n+i>>1],o=n-1,s=i+1;;){do{o++}while(e[o]<a);do{s--}while(e[s]>a);if(o>=s)break;Gi(e,o,s),Gi(r,3*o,3*s),Gi(r,3*o+1,3*s+1),Gi(r,3*o+2,3*s+2)}t(e,r,n,s),t(e,r,s+1,i)}}(r,n,0,r.length-1),e.push(r.buffer,n.buffer),{ids:r,positions:n}},Hi.deserialize=function(t){var e=new Hi;return e.ids=t.ids,e.positions=t.positions,e.indexed=!0,e},kn(\"FeaturePositionMap\",Hi);var Yi=function(t,e){this.gl=t.gl,this.location=e},Wi=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1i(this.location,t))},e}(Yi),Xi=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1f(this.location,t))},e}(Yi),Zi=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]||(this.current=t,this.gl.uniform2f(this.location,t[0],t[1]))},e}(Yi),Ji=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]||(this.current=t,this.gl.uniform3f(this.location,t[0],t[1],t[2]))},e}(Yi),Ki=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]&&t[3]===this.current[3]||(this.current=t,this.gl.uniform4f(this.location,t[0],t[1],t[2],t[3]))},e}(Yi),$i=function(t){function e(e,r){t.call(this,e,r),this.current=ne.transparent}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t.r===this.current.r&&t.g===this.current.g&&t.b===this.current.b&&t.a===this.current.a||(this.current=t,this.gl.uniform4f(this.location,t.r,t.g,t.b,t.a))},e}(Yi),Qi=new Float32Array(16),ta=function(t){function e(e,r){t.call(this,e,r),this.current=Qi}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(t[12]!==this.current[12]||t[0]!==this.current[0])return this.current=t,void this.gl.uniformMatrix4fv(this.location,!1,t);for(var e=1;e<16;e++)if(t[e]!==this.current[e]){this.current=t,this.gl.uniformMatrix4fv(this.location,!1,t);break}},e}(Yi);function ea(t){return[qi(255*t.r,255*t.g),qi(255*t.b,255*t.a)]}var ra=function(t,e,r){this.value=t,this.names=e,this.uniformNames=this.names.map(function(t){return\"u_\"+t}),this.type=r,this.maxValue=-1/0};ra.prototype.defines=function(){return this.names.map(function(t){return\"#define HAS_UNIFORM_u_\"+t})},ra.prototype.setConstantPatternPositions=function(){},ra.prototype.populatePaintArray=function(){},ra.prototype.updatePaintArray=function(){},ra.prototype.upload=function(){},ra.prototype.destroy=function(){},ra.prototype.setUniforms=function(t,e,r,n){e.set(n.constantOr(this.value))},ra.prototype.getBinding=function(t,e){return\"color\"===this.type?new $i(t,e):new Xi(t,e)},ra.serialize=function(t){var e=t.value,r=t.names,n=t.type;return{value:An(e),names:r,type:n}},ra.deserialize=function(t){var e=t.value,r=t.names,n=t.type;return new ra(Mn(e),r,n)};var na=function(t,e,r){this.value=t,this.names=e,this.uniformNames=this.names.map(function(t){return\"u_\"+t}),this.type=r,this.maxValue=-1/0,this.patternPositions={patternTo:null,patternFrom:null}};na.prototype.defines=function(){return this.names.map(function(t){return\"#define HAS_UNIFORM_u_\"+t})},na.prototype.populatePaintArray=function(){},na.prototype.updatePaintArray=function(){},na.prototype.upload=function(){},na.prototype.destroy=function(){},na.prototype.setConstantPatternPositions=function(t,e){this.patternPositions.patternTo=t.tlbr,this.patternPositions.patternFrom=e.tlbr},na.prototype.setUniforms=function(t,e,r,n,i){var a=this.patternPositions;\"u_pattern_to\"===i&&a.patternTo&&e.set(a.patternTo),\"u_pattern_from\"===i&&a.patternFrom&&e.set(a.patternFrom)},na.prototype.getBinding=function(t,e){return new Ki(t,e)};var ia=function(t,e,r,n){this.expression=t,this.names=e,this.type=r,this.uniformNames=this.names.map(function(t){return\"a_\"+t}),this.maxValue=-1/0,this.paintVertexAttributes=e.map(function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?2:1,offset:0}}),this.paintVertexArray=new n};ia.prototype.defines=function(){return[]},ia.prototype.setConstantPatternPositions=function(){},ia.prototype.populatePaintArray=function(t,e){var r=this.paintVertexArray,n=r.length;r.reserve(t);var i=this.expression.evaluate(new Un(0),e,{});if(\"color\"===this.type)for(var a=ea(i),o=n;o<t;o++)r.emplaceBack(a[0],a[1]);else{for(var s=n;s<t;s++)r.emplaceBack(i);this.maxValue=Math.max(this.maxValue,i)}},ia.prototype.updatePaintArray=function(t,e,r,n){var i=this.paintVertexArray,a=this.expression.evaluate({zoom:0},r,n);if(\"color\"===this.type)for(var o=ea(a),s=t;s<e;s++)i.emplace(s,o[0],o[1]);else{for(var l=t;l<e;l++)i.emplace(l,a);this.maxValue=Math.max(this.maxValue,a)}},ia.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},ia.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},ia.prototype.setUniforms=function(t,e){e.set(0)},ia.prototype.getBinding=function(t,e){return new Xi(t,e)};var aa=function(t,e,r,n,i,a){this.expression=t,this.names=e,this.uniformNames=this.names.map(function(t){return\"u_\"+t+\"_t\"}),this.type=r,this.useIntegerZoom=n,this.zoom=i,this.maxValue=-1/0;var o=a;this.paintVertexAttributes=e.map(function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?4:2,offset:0}}),this.paintVertexArray=new o};aa.prototype.defines=function(){return[]},aa.prototype.setConstantPatternPositions=function(){},aa.prototype.populatePaintArray=function(t,e){var r=this.paintVertexArray,n=r.length;r.reserve(t);var i=this.expression.evaluate(new Un(this.zoom),e,{}),a=this.expression.evaluate(new Un(this.zoom+1),e,{});if(\"color\"===this.type)for(var o=ea(i),s=ea(a),l=n;l<t;l++)r.emplaceBack(o[0],o[1],s[0],s[1]);else{for(var c=n;c<t;c++)r.emplaceBack(i,a);this.maxValue=Math.max(this.maxValue,i,a)}},aa.prototype.updatePaintArray=function(t,e,r,n){var i=this.paintVertexArray,a=this.expression.evaluate({zoom:this.zoom},r,n),o=this.expression.evaluate({zoom:this.zoom+1},r,n);if(\"color\"===this.type)for(var s=ea(a),l=ea(o),c=t;c<e;c++)i.emplace(c,s[0],s[1],l[0],l[1]);else{for(var u=t;u<e;u++)i.emplace(u,a,o);this.maxValue=Math.max(this.maxValue,a,o)}},aa.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},aa.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},aa.prototype.interpolationFactor=function(t){return this.useIntegerZoom?this.expression.interpolationFactor(Math.floor(t),this.zoom,this.zoom+1):this.expression.interpolationFactor(t,this.zoom,this.zoom+1)},aa.prototype.setUniforms=function(t,e,r){e.set(this.interpolationFactor(r.zoom))},aa.prototype.getBinding=function(t,e){return new Xi(t,e)};var oa=function(t,e,r,n,i,a,o){this.expression=t,this.names=e,this.type=r,this.uniformNames=this.names.map(function(t){return\"u_\"+t+\"_t\"}),this.useIntegerZoom=n,this.zoom=i,this.maxValue=-1/0,this.layerId=o,this.paintVertexAttributes=e.map(function(t){return{name:\"a_\"+t,type:\"Uint16\",components:4,offset:0}}),this.zoomInPaintVertexArray=new a,this.zoomOutPaintVertexArray=new a};oa.prototype.defines=function(){return[]},oa.prototype.setConstantPatternPositions=function(){},oa.prototype.populatePaintArray=function(t,e,r){var n=this.zoomInPaintVertexArray,i=this.zoomOutPaintVertexArray,a=this.layerId,o=n.length;if(n.reserve(t),i.reserve(t),r&&e.patterns&&e.patterns[a]){var s=e.patterns[a],l=s.min,c=s.mid,u=s.max,h=r[l],f=r[c],p=r[u];if(!h||!f||!p)return;for(var d=o;d<t;d++)n.emplaceBack(f.tl[0],f.tl[1],f.br[0],f.br[1],h.tl[0],h.tl[1],h.br[0],h.br[1]),i.emplaceBack(f.tl[0],f.tl[1],f.br[0],f.br[1],p.tl[0],p.tl[1],p.br[0],p.br[1])}},oa.prototype.updatePaintArray=function(t,e,r,n,i){var a=this.zoomInPaintVertexArray,o=this.zoomOutPaintVertexArray,s=this.layerId;if(i&&r.patterns&&r.patterns[s]){var l=r.patterns[s],c=l.min,u=l.mid,h=l.max,f=i[c],p=i[u],d=i[h];if(!f||!p||!d)return;for(var g=t;g<e;g++)a.emplace(g,p.tl[0],p.tl[1],p.br[0],p.br[1],f.tl[0],f.tl[1],f.br[0],f.br[1]),o.emplace(g,p.tl[0],p.tl[1],p.br[0],p.br[1],d.tl[0],d.tl[1],d.br[0],d.br[1])}},oa.prototype.upload=function(t){this.zoomInPaintVertexArray&&this.zoomInPaintVertexArray.arrayBuffer&&this.zoomOutPaintVertexArray&&this.zoomOutPaintVertexArray.arrayBuffer&&(this.zoomInPaintVertexBuffer=t.createVertexBuffer(this.zoomInPaintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent),this.zoomOutPaintVertexBuffer=t.createVertexBuffer(this.zoomOutPaintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},oa.prototype.destroy=function(){this.zoomOutPaintVertexBuffer&&this.zoomOutPaintVertexBuffer.destroy(),this.zoomInPaintVertexBuffer&&this.zoomInPaintVertexBuffer.destroy()},oa.prototype.setUniforms=function(t,e){e.set(0)},oa.prototype.getBinding=function(t,e){return new Xi(t,e)};var sa=function(){this.binders={},this.cacheKey=\"\",this._buffers=[],this._featureMap=new Hi,this._bufferOffset=0};sa.createDynamic=function(t,e,r){var n=new sa,i=[];for(var a in t.paint._values)if(r(a)){var o=t.paint.get(a);if(o instanceof Xn&&xr(o.property.specification)){var s=ca(a,t.type),l=o.property.specification.type,c=o.property.useIntegerZoom;if(\"cross-faded\"===o.property.specification[\"property-type\"]||\"cross-faded-data-driven\"===o.property.specification[\"property-type\"])if(\"constant\"===o.value.kind)n.binders[a]=new na(o.value.value,s,l),i.push(\"/u_\"+a);else{var u=ua(a,l,\"source\");n.binders[a]=new oa(o.value,s,l,c,e,u,t.id),i.push(\"/a_\"+a)}else if(\"constant\"===o.value.kind)n.binders[a]=new ra(o.value.value,s,l),i.push(\"/u_\"+a);else if(\"source\"===o.value.kind){var h=ua(a,l,\"source\");n.binders[a]=new ia(o.value,s,l,h),i.push(\"/a_\"+a)}else{var f=ua(a,l,\"composite\");n.binders[a]=new aa(o.value,s,l,c,e,f),i.push(\"/z_\"+a)}}}return n.cacheKey=i.sort().join(\"\"),n},sa.prototype.populatePaintArrays=function(t,e,r,n){for(var i in this.binders)this.binders[i].populatePaintArray(t,e,n);void 0!==e.id&&this._featureMap.add(+e.id,r,this._bufferOffset,t),this._bufferOffset=t},sa.prototype.setConstantPatternPositions=function(t,e){for(var r in this.binders)this.binders[r].setConstantPatternPositions(t,e)},sa.prototype.updatePaintArrays=function(t,e,r,n){var i=!1;for(var a in t)for(var o=0,s=this._featureMap.getPositions(+a);o<s.length;o+=1){var l=s[o],c=e.feature(l.index);for(var u in this.binders){var h=this.binders[u];if(!(h instanceof ra||h instanceof na)&&!0===h.expression.isStateDependent){var f=r.paint.get(u);h.expression=f.value,h.updatePaintArray(l.start,l.end,c,t[a],n),i=!0}}}return i},sa.prototype.defines=function(){var t=[];for(var e in this.binders)t.push.apply(t,this.binders[e].defines());return t},sa.prototype.getPaintVertexBuffers=function(){return this._buffers},sa.prototype.getUniforms=function(t,e){var r=[];for(var n in this.binders)for(var i=this.binders[n],a=0,o=i.uniformNames;a<o.length;a+=1){var s=o[a];if(e[s]){var l=i.getBinding(t,e[s]);r.push({name:s,property:n,binding:l})}}return r},sa.prototype.setUniforms=function(t,e,r,n){for(var i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.name,l=o.property,c=o.binding;this.binders[l].setUniforms(t,c,n,r.get(l),s)}},sa.prototype.updatePatternPaintBuffers=function(t){var e=[];for(var r in this.binders){var n=this.binders[r];if(n instanceof oa){var i=2===t.fromScale?n.zoomInPaintVertexBuffer:n.zoomOutPaintVertexBuffer;i&&e.push(i)}else(n instanceof ia||n instanceof aa)&&n.paintVertexBuffer&&e.push(n.paintVertexBuffer)}this._buffers=e},sa.prototype.upload=function(t){for(var e in this.binders)this.binders[e].upload(t);var r=[];for(var n in this.binders){var i=this.binders[n];(i instanceof ia||i instanceof aa)&&i.paintVertexBuffer&&r.push(i.paintVertexBuffer)}this._buffers=r},sa.prototype.destroy=function(){for(var t in this.binders)this.binders[t].destroy()};var la=function(t,e,r,n){void 0===n&&(n=function(){return!0}),this.programConfigurations={};for(var i=0,a=e;i<a.length;i+=1){var o=a[i];this.programConfigurations[o.id]=sa.createDynamic(o,r,n),this.programConfigurations[o.id].layoutAttributes=t}this.needsUpload=!1};function ca(t,e){return{\"text-opacity\":[\"opacity\"],\"icon-opacity\":[\"opacity\"],\"text-color\":[\"fill_color\"],\"icon-color\":[\"fill_color\"],\"text-halo-color\":[\"halo_color\"],\"icon-halo-color\":[\"halo_color\"],\"text-halo-blur\":[\"halo_blur\"],\"icon-halo-blur\":[\"halo_blur\"],\"text-halo-width\":[\"halo_width\"],\"icon-halo-width\":[\"halo_width\"],\"line-gap-width\":[\"gapwidth\"],\"line-pattern\":[\"pattern_to\",\"pattern_from\"],\"fill-pattern\":[\"pattern_to\",\"pattern_from\"],\"fill-extrusion-pattern\":[\"pattern_to\",\"pattern_from\"]}[t]||[t.replace(e+\"-\",\"\").replace(/-/g,\"_\")]}function ua(t,e,r){var n={color:{source:Si,composite:Ei},number:{source:_i,composite:Si}},i=function(t){return{\"line-pattern\":{source:fi,composite:fi},\"fill-pattern\":{source:fi,composite:fi},\"fill-extrusion-pattern\":{source:fi,composite:fi}}[t]}(t);return i&&i[r]||n[e][r]}la.prototype.populatePaintArrays=function(t,e,r,n){for(var i in this.programConfigurations)this.programConfigurations[i].populatePaintArrays(t,e,r,n);this.needsUpload=!0},la.prototype.updatePaintArrays=function(t,e,r,n){for(var i=0,a=r;i<a.length;i+=1){var o=a[i];this.needsUpload=this.programConfigurations[o.id].updatePaintArrays(t,e,o,n)||this.needsUpload}},la.prototype.get=function(t){return this.programConfigurations[t]},la.prototype.upload=function(t){if(this.needsUpload){for(var e in this.programConfigurations)this.programConfigurations[e].upload(t);this.needsUpload=!1}},la.prototype.destroy=function(){for(var t in this.programConfigurations)this.programConfigurations[t].destroy()},kn(\"ConstantBinder\",ra),kn(\"CrossFadedConstantBinder\",na),kn(\"SourceExpressionBinder\",ia),kn(\"CrossFadedCompositeBinder\",oa),kn(\"CompositeExpressionBinder\",aa),kn(\"ProgramConfiguration\",sa,{omit:[\"_buffers\"]}),kn(\"ProgramConfigurationSet\",la);var ha=8192,fa=(16,{min:-1*Math.pow(2,15),max:Math.pow(2,15)-1});function pa(t){for(var e=ha/t.extent,r=t.loadGeometry(),n=0;n<r.length;n++)for(var i=r[n],a=0;a<i.length;a++){var o=i[a];o.x=Math.round(o.x*e),o.y=Math.round(o.y*e),(o.x<fa.min||o.x>fa.max||o.y<fa.min||o.y>fa.max)&&w(\"Geometry exceeds allowed extent, reduce your vector tile buffer size\")}return r}function da(t,e,r,n,i){t.emplaceBack(2*e+(n+1)/2,2*r+(i+1)/2)}var ga=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new li,this.indexArray=new Ti,this.segments=new Vi,this.programConfigurations=new la(Ui,t.layers,t.zoom),this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function va(t,e){for(var r=0;r<t.length;r++)if(Aa(e,t[r]))return!0;for(var n=0;n<e.length;n++)if(Aa(t,e[n]))return!0;return!!ba(t,e)}function ma(t,e,r){return!!Aa(t,e)||!!wa(e,t,r)}function ya(t,e){if(1===t.length)return Ta(e,t[0]);for(var r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++)if(Aa(t,n[i]))return!0;for(var a=0;a<t.length;a++)if(Ta(e,t[a]))return!0;for(var o=0;o<e.length;o++)if(ba(t,e[o]))return!0;return!1}function xa(t,e,r){if(t.length>1){if(ba(t,e))return!0;for(var n=0;n<e.length;n++)if(wa(e[n],t,r))return!0}for(var i=0;i<t.length;i++)if(wa(t[i],e,r))return!0;return!1}function ba(t,e){if(0===t.length||0===e.length)return!1;for(var r=0;r<t.length-1;r++)for(var n=t[r],i=t[r+1],a=0;a<e.length-1;a++)if(_a(n,i,e[a],e[a+1]))return!0;return!1}function _a(t,e,r,n){return k(t,r,n)!==k(e,r,n)&&k(t,e,r)!==k(t,e,n)}function wa(t,e,r){var n=r*r;if(1===e.length)return t.distSqr(e[0])<n;for(var i=1;i<e.length;i++)if(ka(t,e[i-1],e[i])<n)return!0;return!1}function ka(t,e,r){var n=e.distSqr(r);if(0===n)return t.distSqr(e);var i=((t.x-e.x)*(r.x-e.x)+(t.y-e.y)*(r.y-e.y))/n;return i<0?t.distSqr(e):i>1?t.distSqr(r):t.distSqr(r.sub(e)._mult(i)._add(e))}function Ta(t,e){for(var r,n,i,a=!1,o=0;o<t.length;o++)for(var s=0,l=(r=t[o]).length-1;s<r.length;l=s++)n=r[s],i=r[l],n.y>e.y!=i.y>e.y&&e.x<(i.x-n.x)*(e.y-n.y)/(i.y-n.y)+n.x&&(a=!a);return a}function Aa(t,e){for(var r=!1,n=0,i=t.length-1;n<t.length;i=n++){var a=t[n],o=t[i];a.y>e.y!=o.y>e.y&&e.x<(o.x-a.x)*(e.y-a.y)/(o.y-a.y)+a.x&&(r=!r)}return r}function Ma(t,e,r){var n=r[0],i=r[2];if(t.x<n.x&&e.x<n.x||t.x>i.x&&e.x>i.x||t.y<n.y&&e.y<n.y||t.y>i.y&&e.y>i.y)return!1;var a=k(t,e,r[0]);return a!==k(t,e,r[1])||a!==k(t,e,r[2])||a!==k(t,e,r[3])}function Sa(t,e,r){var n=e.paint.get(t).value;return\"constant\"===n.kind?n.value:r.programConfigurations.get(e.id).binders[t].maxValue}function Ea(t){return Math.sqrt(t[0]*t[0]+t[1]*t[1])}function Ca(t,e,r,n,a){if(!e[0]&&!e[1])return t;var o=i.convert(e)._mult(a);\"viewport\"===r&&o._rotate(-n);for(var s=[],l=0;l<t.length;l++){var c=t[l];s.push(c.sub(o))}return s}ga.prototype.populate=function(t,e){for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a);this.addFeature(a,l,o),e.featureIndex.insert(a,l,o,s,this.index)}}},ga.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},ga.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},ga.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},ga.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ui),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},ga.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},ga.prototype.addFeature=function(t,e,r){for(var n=0,i=e;n<i.length;n+=1)for(var a=0,o=i[n];a<o.length;a+=1){var s=o[a],l=s.x,c=s.y;if(!(l<0||l>=ha||c<0||c>=ha)){var u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),h=u.vertexLength;da(this.layoutVertexArray,l,c,-1,-1),da(this.layoutVertexArray,l,c,1,-1),da(this.layoutVertexArray,l,c,1,1),da(this.layoutVertexArray,l,c,-1,1),this.indexArray.emplaceBack(h,h+1,h+2),this.indexArray.emplaceBack(h,h+3,h+2),u.vertexLength+=4,u.primitiveLength+=2}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,{})},kn(\"CircleBucket\",ga,{omit:[\"layers\"]});var La={paint:new ei({\"circle-radius\":new Kn(It.paint_circle[\"circle-radius\"]),\"circle-color\":new Kn(It.paint_circle[\"circle-color\"]),\"circle-blur\":new Kn(It.paint_circle[\"circle-blur\"]),\"circle-opacity\":new Kn(It.paint_circle[\"circle-opacity\"]),\"circle-translate\":new Jn(It.paint_circle[\"circle-translate\"]),\"circle-translate-anchor\":new Jn(It.paint_circle[\"circle-translate-anchor\"]),\"circle-pitch-scale\":new Jn(It.paint_circle[\"circle-pitch-scale\"]),\"circle-pitch-alignment\":new Jn(It.paint_circle[\"circle-pitch-alignment\"]),\"circle-stroke-width\":new Kn(It.paint_circle[\"circle-stroke-width\"]),\"circle-stroke-color\":new Kn(It.paint_circle[\"circle-stroke-color\"]),\"circle-stroke-opacity\":new Kn(It.paint_circle[\"circle-stroke-opacity\"])})},Pa=\"undefined\"!=typeof Float32Array?Float32Array:Array;function Oa(){var t=new Pa(9);return Pa!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[5]=0,t[6]=0,t[7]=0),t[0]=1,t[4]=1,t[8]=1,t}function za(){var t=new Pa(3);return Pa!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0),t}function Ia(t,e,r){var n=new Pa(3);return n[0]=t,n[1]=e,n[2]=r,n}Math.PI;function Da(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}function Ra(){var t=new Pa(4);return Pa!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0),t[3]=1,t}za(),function(){var t;t=new Pa(4),Pa!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0,t[3]=0)}();za(),Ia(1,0,0),Ia(0,1,0),Ra(),Ra(),Oa(),function(){var t;t=new Pa(2),Pa!=Float32Array&&(t[0]=0,t[1]=0)}();var Fa=function(t){function e(e){t.call(this,e,La)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new ga(t)},e.prototype.queryRadius=function(t){var e=t;return Sa(\"circle-radius\",this,e)+Sa(\"circle-stroke-width\",this,e)+Ea(this.paint.get(\"circle-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o,s){for(var l=Ca(t,this.paint.get(\"circle-translate\"),this.paint.get(\"circle-translate-anchor\"),a.angle,o),c=this.paint.get(\"circle-radius\").evaluate(e,r)+this.paint.get(\"circle-stroke-width\").evaluate(e,r),u=\"map\"===this.paint.get(\"circle-pitch-alignment\"),h=u?l:function(t,e){return l.map(function(t){return Ba(t,e)})}(0,s),f=u?c*o:c,p=0,d=n;p<d.length;p+=1)for(var g=0,v=d[p];g<v.length;g+=1){var m=v[g],y=u?m:Ba(m,s),x=f,b=Da([],[m.x,m.y,0,1],s);if(\"viewport\"===this.paint.get(\"circle-pitch-scale\")&&\"map\"===this.paint.get(\"circle-pitch-alignment\")?x*=b[3]/a.cameraToCenterDistance:\"map\"===this.paint.get(\"circle-pitch-scale\")&&\"viewport\"===this.paint.get(\"circle-pitch-alignment\")&&(x*=a.cameraToCenterDistance/b[3]),ma(h,y,x))return!0}return!1},e}(ri);function Ba(t,e){var r=Da([],[t.x,t.y,0,1],e);return new i(r[0]/r[3],r[1]/r[3])}var Na=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ga);function ja(t,e,r,n){var i=e.width,a=e.height;if(n){if(n instanceof Uint8ClampedArray)n=new Uint8Array(n.buffer);else if(n.length!==i*a*r)throw new RangeError(\"mismatched image size\")}else n=new Uint8Array(i*a*r);return t.width=i,t.height=a,t.data=n,t}function Ua(t,e,r){var n=e.width,i=e.height;if(n!==t.width||i!==t.height){var a=ja({},{width:n,height:i},r);Va(t,a,{x:0,y:0},{x:0,y:0},{width:Math.min(t.width,n),height:Math.min(t.height,i)},r),t.width=n,t.height=i,t.data=a.data}}function Va(t,e,r,n,i,a){if(0===i.width||0===i.height)return e;if(i.width>t.width||i.height>t.height||r.x>t.width-i.width||r.y>t.height-i.height)throw new RangeError(\"out of range source coordinates for image copy\");if(i.width>e.width||i.height>e.height||n.x>e.width-i.width||n.y>e.height-i.height)throw new RangeError(\"out of range destination coordinates for image copy\");for(var o=t.data,s=e.data,l=0;l<i.height;l++)for(var c=((r.y+l)*t.width+r.x)*a,u=((n.y+l)*e.width+n.x)*a,h=0;h<i.width*a;h++)s[u+h]=o[c+h];return e}kn(\"HeatmapBucket\",Na,{omit:[\"layers\"]});var qa=function(t,e){ja(this,t,1,e)};qa.prototype.resize=function(t){Ua(this,t,1)},qa.prototype.clone=function(){return new qa({width:this.width,height:this.height},new Uint8Array(this.data))},qa.copy=function(t,e,r,n,i){Va(t,e,r,n,i,1)};var Ha=function(t,e){ja(this,t,4,e)};Ha.prototype.resize=function(t){Ua(this,t,4)},Ha.prototype.replace=function(t,e){e?this.data.set(t):t instanceof Uint8ClampedArray?this.data=new Uint8Array(t.buffer):this.data=t},Ha.prototype.clone=function(){return new Ha({width:this.width,height:this.height},new Uint8Array(this.data))},Ha.copy=function(t,e,r,n,i){Va(t,e,r,n,i,4)},kn(\"AlphaImage\",qa),kn(\"RGBAImage\",Ha);var Ga={paint:new ei({\"heatmap-radius\":new Kn(It.paint_heatmap[\"heatmap-radius\"]),\"heatmap-weight\":new Kn(It.paint_heatmap[\"heatmap-weight\"]),\"heatmap-intensity\":new Jn(It.paint_heatmap[\"heatmap-intensity\"]),\"heatmap-color\":new ti(It.paint_heatmap[\"heatmap-color\"]),\"heatmap-opacity\":new Jn(It.paint_heatmap[\"heatmap-opacity\"])})};function Ya(t,e){for(var r=new Uint8Array(1024),n={},i=0,a=0;i<256;i++,a+=4){n[e]=i/255;var o=t.evaluate(n);r[a+0]=Math.floor(255*o.r/o.a),r[a+1]=Math.floor(255*o.g/o.a),r[a+2]=Math.floor(255*o.b/o.a),r[a+3]=Math.floor(255*o.a)}return new Ha({width:256,height:1},r)}var Wa=function(t){function e(e){t.call(this,e,Ga),this._updateColorRamp()}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new Na(t)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"heatmap-color\"===t&&this._updateColorRamp()},e.prototype._updateColorRamp=function(){var t=this._transitionablePaint._values[\"heatmap-color\"].value.expression;this.colorRamp=Ya(t,\"heatmapDensity\"),this.colorRampTexture=null},e.prototype.resize=function(){this.heatmapFbo&&(this.heatmapFbo.destroy(),this.heatmapFbo=null)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"heatmap-opacity\")&&\"none\"!==this.visibility},e}(ri),Xa={paint:new ei({\"hillshade-illumination-direction\":new Jn(It.paint_hillshade[\"hillshade-illumination-direction\"]),\"hillshade-illumination-anchor\":new Jn(It.paint_hillshade[\"hillshade-illumination-anchor\"]),\"hillshade-exaggeration\":new Jn(It.paint_hillshade[\"hillshade-exaggeration\"]),\"hillshade-shadow-color\":new Jn(It.paint_hillshade[\"hillshade-shadow-color\"]),\"hillshade-highlight-color\":new Jn(It.paint_hillshade[\"hillshade-highlight-color\"]),\"hillshade-accent-color\":new Jn(It.paint_hillshade[\"hillshade-accent-color\"])})},Za=function(t){function e(e){t.call(this,e,Xa)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"hillshade-exaggeration\")&&\"none\"!==this.visibility},e}(ri),Ja=oi([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,Ka=Qa,$a=Qa;function Qa(t,e,r){r=r||2;var n,i,a,o,s,l,c,u=e&&e.length,h=u?e[0]*r:t.length,f=to(t,0,h,r,!0),p=[];if(!f||f.next===f.prev)return p;if(u&&(f=function(t,e,r,n){var i,a,o,s=[];for(i=0,a=e.length;i<a;i++)(o=to(t,e[i]*n,i<a-1?e[i+1]*n:t.length,n,!1))===o.next&&(o.steiner=!0),s.push(uo(o));for(s.sort(so),i=0;i<s.length;i++)lo(s[i],r),r=eo(r,r.next);return r}(t,e,f,r)),t.length>80*r){n=a=t[0],i=o=t[1];for(var d=r;d<h;d+=r)(s=t[d])<n&&(n=s),(l=t[d+1])<i&&(i=l),s>a&&(a=s),l>o&&(o=l);c=0!==(c=Math.max(a-n,o-i))?1/c:0}return ro(f,p,r,n,i,c),p}function to(t,e,r,n,i){var a,o;if(i===wo(t,e,r,n)>0)for(a=e;a<r;a+=n)o=xo(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=xo(a,t[a],t[a+1],o);return o&&go(o,o.next)&&(bo(o),o=o.next),o}function eo(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!go(n,n.next)&&0!==po(n.prev,n,n.next))n=n.next;else{if(bo(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function ro(t,e,r,n,i,a,o){if(t){!o&&a&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=co(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,a);for(var s,l,c=t;t.prev!==t.next;)if(s=t.prev,l=t.next,a?io(t,n,i,a):no(t))e.push(s.i/r),e.push(t.i/r),e.push(l.i/r),bo(t),t=l.next,c=l.next;else if((t=l)===c){o?1===o?ro(t=ao(t,e,r),e,r,n,i,a,2):2===o&&oo(t,e,r,n,i,a):ro(eo(t),e,r,n,i,a,1);break}}}function no(t){var e=t.prev,r=t,n=t.next;if(po(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(ho(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&po(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function io(t,e,r,n){var i=t.prev,a=t,o=t.next;if(po(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,h=co(s,l,e,r,n),f=co(c,u,e,r,n),p=t.prevZ,d=t.nextZ;p&&p.z>=h&&d&&d.z<=f;){if(p!==t.prev&&p!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&po(p.prev,p,p.next)>=0)return!1;if(p=p.prevZ,d!==t.prev&&d!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&po(d.prev,d,d.next)>=0)return!1;d=d.nextZ}for(;p&&p.z>=h;){if(p!==t.prev&&p!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&po(p.prev,p,p.next)>=0)return!1;p=p.prevZ}for(;d&&d.z<=f;){if(d!==t.prev&&d!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&po(d.prev,d,d.next)>=0)return!1;d=d.nextZ}return!0}function ao(t,e,r){var n=t;do{var i=n.prev,a=n.next.next;!go(i,a)&&vo(i,n,n.next,a)&&mo(i,a)&&mo(a,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(a.i/r),bo(n),bo(n.next),n=t=a),n=n.next}while(n!==t);return n}function oo(t,e,r,n,i,a){var o=t;do{for(var s=o.next.next;s!==o.prev;){if(o.i!==s.i&&fo(o,s)){var l=yo(o,s);return o=eo(o,o.next),l=eo(l,l.next),ro(o,e,r,n,i,a),void ro(l,e,r,n,i,a)}s=s.next}o=o.next}while(o!==t)}function so(t,e){return t.x-e.x}function lo(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r.prev;var l,c=r,u=r.x,h=r.y,f=1/0;for(n=r.next;n!==c;)i>=n.x&&n.x>=u&&i!==n.x&&ho(a<h?i:o,a,u,h,a<h?o:i,a,n.x,n.y)&&((l=Math.abs(a-n.y)/(i-n.x))<f||l===f&&n.x>r.x)&&mo(n,t)&&(r=n,f=l),n=n.next;return r}(t,e)){var r=yo(e,t);eo(r,r.next)}}function co(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function uo(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function ho(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function fo(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&vo(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&mo(t,e)&&mo(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)}function po(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function go(t,e){return t.x===e.x&&t.y===e.y}function vo(t,e,r,n){return!!(go(t,e)&&go(r,n)||go(t,n)&&go(r,e))||po(t,e,r)>0!=po(t,e,n)>0&&po(r,n,t)>0!=po(r,n,e)>0}function mo(t,e){return po(t.prev,t,t.next)<0?po(t,e,t.next)>=0&&po(t,t.prev,e)>=0:po(t,e,t.prev)<0||po(t,t.next,e)<0}function yo(t,e){var r=new _o(t.i,t.x,t.y),n=new _o(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function xo(t,e,r,n){var i=new _o(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function bo(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function _o(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function wo(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}function ko(t,e,r,n,i){!function t(e,r,n,i,a){for(;i>n;){if(i-n>600){var o=i-n+1,s=r-n+1,l=Math.log(o),c=.5*Math.exp(2*l/3),u=.5*Math.sqrt(l*c*(o-c)/o)*(s-o/2<0?-1:1);t(e,r,Math.max(n,Math.floor(r-s*c/o+u)),Math.min(i,Math.floor(r+(o-s)*c/o+u)),a)}var h=e[r],f=n,p=i;for(To(e,n,r),a(e[i],h)>0&&To(e,n,i);f<p;){for(To(e,f,p),f++,p--;a(e[f],h)<0;)f++;for(;a(e[p],h)>0;)p--}0===a(e[n],h)?To(e,n,p):To(e,++p,i),p<=r&&(n=p+1),r<=p&&(i=p-1)}}(t,e,r||0,n||t.length-1,i||Ao)}function To(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function Ao(t,e){return t<e?-1:t>e?1:0}function Mo(t,e){var r=t.length;if(r<=1)return[t];for(var n,i,a=[],o=0;o<r;o++){var s=T(t[o]);0!==s&&(t[o].area=Math.abs(s),void 0===i&&(i=s<0),i===s<0?(n&&a.push(n),n=[t[o]]):n.push(t[o]))}if(n&&a.push(n),e>1)for(var l=0;l<a.length;l++)a[l].length<=e||(ko(a[l],e,1,a[l].length-1,So),a[l]=a[l].slice(0,e));return a}function So(t,e){return e.area-t.area}function Eo(t,e,r){for(var n=r.patternDependencies,i=!1,a=0,o=e;a<o.length;a+=1){var s=o[a].paint.get(t+\"-pattern\");s.isConstant()||(i=!0);var l=s.constantOr(null);l&&(i=!0,n[l.to]=!0,n[l.from]=!0)}return i}function Co(t,e,r,n,i){for(var a=i.patternDependencies,o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.paint.get(t+\"-pattern\").value;if(\"constant\"!==c.kind){var u=c.evaluate({zoom:n-1},r,{}),h=c.evaluate({zoom:n},r,{}),f=c.evaluate({zoom:n+1},r,{});a[u]=!0,a[h]=!0,a[f]=!0,r.patterns[l.id]={min:u,mid:h,max:f}}}return r}Qa.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(wo(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(wo(t,c,u,r))}var h=0;for(s=0;s<n.length;s+=3){var f=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;h+=Math.abs((t[f]-t[d])*(t[p+1]-t[f+1])-(t[f]-t[p])*(t[d+1]-t[f+1]))}return 0===o&&0===h?0:Math.abs((h-o)/o)},Qa.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r},Ka.default=$a;var Lo=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new li,this.indexArray=new Ti,this.indexArray2=new Ai,this.programConfigurations=new la(Ja,t.layers,t.zoom),this.segments=new Vi,this.segments2=new Vi,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};Lo.prototype.populate=function(t,e){this.features=[],this.hasPattern=Eo(\"fill\",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a),c={sourceLayerIndex:s,index:o,geometry:l,properties:a.properties,type:a.type,patterns:{}};void 0!==a.id&&(c.id=a.id),this.hasPattern?this.features.push(Co(\"fill\",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(a,l,o,s,this.index)}}},Lo.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Lo.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var i=n[r],a=i.geometry;this.addFeature(i,a,i.index,e)}},Lo.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Lo.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Lo.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ja),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.indexBuffer2=t.createIndexBuffer(this.indexArray2)),this.programConfigurations.upload(t),this.uploaded=!0},Lo.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.indexBuffer2.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.segments2.destroy())},Lo.prototype.addFeature=function(t,e,r,n){for(var i=0,a=Mo(e,500);i<a.length;i+=1){for(var o=a[i],s=0,l=0,c=o;l<c.length;l+=1)s+=c[l].length;for(var u=this.segments.prepareSegment(s,this.layoutVertexArray,this.indexArray),h=u.vertexLength,f=[],p=[],d=0,g=o;d<g.length;d+=1){var v=g[d];if(0!==v.length){v!==o[0]&&p.push(f.length/2);var m=this.segments2.prepareSegment(v.length,this.layoutVertexArray,this.indexArray2),y=m.vertexLength;this.layoutVertexArray.emplaceBack(v[0].x,v[0].y),this.indexArray2.emplaceBack(y+v.length-1,y),f.push(v[0].x),f.push(v[0].y);for(var x=1;x<v.length;x++)this.layoutVertexArray.emplaceBack(v[x].x,v[x].y),this.indexArray2.emplaceBack(y+x-1,y+x),f.push(v[x].x),f.push(v[x].y);m.vertexLength+=v.length,m.primitiveLength+=v.length}}for(var b=Ka(f,p),_=0;_<b.length;_+=3)this.indexArray.emplaceBack(h+b[_],h+b[_+1],h+b[_+2]);u.vertexLength+=s,u.primitiveLength+=b.length/3}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,n)},kn(\"FillBucket\",Lo,{omit:[\"layers\",\"features\"]});var Po={paint:new ei({\"fill-antialias\":new Jn(It.paint_fill[\"fill-antialias\"]),\"fill-opacity\":new Kn(It.paint_fill[\"fill-opacity\"]),\"fill-color\":new Kn(It.paint_fill[\"fill-color\"]),\"fill-outline-color\":new Kn(It.paint_fill[\"fill-outline-color\"]),\"fill-translate\":new Jn(It.paint_fill[\"fill-translate\"]),\"fill-translate-anchor\":new Jn(It.paint_fill[\"fill-translate-anchor\"]),\"fill-pattern\":new $n(It.paint_fill[\"fill-pattern\"])})},Oo=function(t){function e(e){t.call(this,e,Po)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e);var r=this.paint._values[\"fill-outline-color\"];\"constant\"===r.value.kind&&void 0===r.value.value&&(this.paint._values[\"fill-outline-color\"]=this.paint._values[\"fill-color\"])},e.prototype.createBucket=function(t){return new Lo(t)},e.prototype.queryRadius=function(){return Ea(this.paint.get(\"fill-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o){return ya(Ca(t,this.paint.get(\"fill-translate\"),this.paint.get(\"fill-translate-anchor\"),a.angle,o),n)},e.prototype.isTileClipped=function(){return!0},e}(ri),zo=oi([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_normal_ed\",components:4,type:\"Int16\"}],4).members,Io=Do;function Do(t,e,r,n,i){this.properties={},this.extent=r,this.type=0,this._pbf=t,this._geometry=-1,this._keys=n,this._values=i,t.readFields(Ro,this,e)}function Ro(t,e,r){1==t?e.id=r.readVarint():2==t?function(t,e){for(var r=t.readVarint()+t.pos;t.pos<r;){var n=e._keys[t.readVarint()],i=e._values[t.readVarint()];e.properties[n]=i}}(r,e):3==t?e.type=r.readVarint():4==t&&(e._geometry=r.pos)}function Fo(t){for(var e,r,n=0,i=0,a=t.length,o=a-1;i<a;o=i++)e=t[i],n+=((r=t[o]).x-e.x)*(e.y+r.y);return n}Do.types=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],Do.prototype.loadGeometry=function(){var t=this._pbf;t.pos=this._geometry;for(var e,r=t.readVarint()+t.pos,n=1,a=0,o=0,s=0,l=[];t.pos<r;){if(a<=0){var c=t.readVarint();n=7&c,a=c>>3}if(a--,1===n||2===n)o+=t.readSVarint(),s+=t.readSVarint(),1===n&&(e&&l.push(e),e=[]),e.push(new i(o,s));else{if(7!==n)throw new Error(\"unknown command \"+n);e&&e.push(e[0].clone())}}return e&&l.push(e),l},Do.prototype.bbox=function(){var t=this._pbf;t.pos=this._geometry;for(var e=t.readVarint()+t.pos,r=1,n=0,i=0,a=0,o=1/0,s=-1/0,l=1/0,c=-1/0;t.pos<e;){if(n<=0){var u=t.readVarint();r=7&u,n=u>>3}if(n--,1===r||2===r)(i+=t.readSVarint())<o&&(o=i),i>s&&(s=i),(a+=t.readSVarint())<l&&(l=a),a>c&&(c=a);else if(7!==r)throw new Error(\"unknown command \"+r)}return[o,l,s,c]},Do.prototype.toGeoJSON=function(t,e,r){var n,i,a=this.extent*Math.pow(2,r),o=this.extent*t,s=this.extent*e,l=this.loadGeometry(),c=Do.types[this.type];function u(t){for(var e=0;e<t.length;e++){var r=t[e],n=180-360*(r.y+s)/a;t[e]=[360*(r.x+o)/a-180,360/Math.PI*Math.atan(Math.exp(n*Math.PI/180))-90]}}switch(this.type){case 1:var h=[];for(n=0;n<l.length;n++)h[n]=l[n][0];u(l=h);break;case 2:for(n=0;n<l.length;n++)u(l[n]);break;case 3:for(l=function(t){var e=t.length;if(e<=1)return[t];for(var r,n,i=[],a=0;a<e;a++){var o=Fo(t[a]);0!==o&&(void 0===n&&(n=o<0),n===o<0?(r&&i.push(r),r=[t[a]]):r.push(t[a]))}return r&&i.push(r),i}(l),n=0;n<l.length;n++)for(i=0;i<l[n].length;i++)u(l[n][i])}1===l.length?l=l[0]:c=\"Multi\"+c;var f={type:\"Feature\",geometry:{type:c,coordinates:l},properties:this.properties};return\"id\"in this&&(f.id=this.id),f};var Bo=No;function No(t,e){this.version=1,this.name=null,this.extent=4096,this.length=0,this._pbf=t,this._keys=[],this._values=[],this._features=[],t.readFields(jo,this,e),this.length=this._features.length}function jo(t,e,r){15===t?e.version=r.readVarint():1===t?e.name=r.readString():5===t?e.extent=r.readVarint():2===t?e._features.push(r.pos):3===t?e._keys.push(r.readString()):4===t&&e._values.push(function(t){for(var e=null,r=t.readVarint()+t.pos;t.pos<r;){var n=t.readVarint()>>3;e=1===n?t.readString():2===n?t.readFloat():3===n?t.readDouble():4===n?t.readVarint64():5===n?t.readVarint():6===n?t.readSVarint():7===n?t.readBoolean():null}return e}(r))}function Uo(t,e,r){if(3===t){var n=new Bo(r,r.readVarint()+r.pos);n.length&&(e[n.name]=n)}}No.prototype.feature=function(t){if(t<0||t>=this._features.length)throw new Error(\"feature index out of bounds\");this._pbf.pos=this._features[t];var e=this._pbf.readVarint()+this._pbf.pos;return new Io(this._pbf,e,this.extent,this._keys,this._values)};var Vo={VectorTile:function(t,e){this.layers=t.readFields(Uo,{},e)},VectorTileFeature:Io,VectorTileLayer:Bo},qo=Vo.VectorTileFeature.types,Ho=Math.pow(2,13);function Go(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,2*Math.floor(n*Ho)+o,i*Ho*2,a*Ho*2,Math.round(s))}var Yo=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new ui,this.indexArray=new Ti,this.programConfigurations=new la(zo,t.layers,t.zoom),this.segments=new Vi,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function Wo(t,e){return t.x===e.x&&(t.x<0||t.x>ha)||t.y===e.y&&(t.y<0||t.y>ha)}function Xo(t){return t.every(function(t){return t.x<0})||t.every(function(t){return t.x>ha})||t.every(function(t){return t.y<0})||t.every(function(t){return t.y>ha})}Yo.prototype.populate=function(t,e){this.features=[],this.hasPattern=Eo(\"fill-extrusion\",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a),c={sourceLayerIndex:s,index:o,geometry:l,properties:a.properties,type:a.type,patterns:{}};void 0!==a.id&&(c.id=a.id),this.hasPattern?this.features.push(Co(\"fill-extrusion\",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(a,l,o,s,this.index,!0)}}},Yo.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var i=n[r],a=i.geometry;this.addFeature(i,a,i.index,e)}},Yo.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Yo.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Yo.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Yo.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,zo),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Yo.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Yo.prototype.addFeature=function(t,e,r,n){for(var i=0,a=Mo(e,500);i<a.length;i+=1){for(var o=a[i],s=0,l=0,c=o;l<c.length;l+=1)s+=c[l].length;for(var u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),h=0,f=o;h<f.length;h+=1){var p=f[h];if(0!==p.length&&!Xo(p))for(var d=0,g=0;g<p.length;g++){var v=p[g];if(g>=1){var m=p[g-1];if(!Wo(v,m)){u.vertexLength+4>Vi.MAX_VERTEX_ARRAY_LENGTH&&(u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray));var y=v.sub(m)._perp()._unit(),x=m.dist(v);d+x>32768&&(d=0),Go(this.layoutVertexArray,v.x,v.y,y.x,y.y,0,0,d),Go(this.layoutVertexArray,v.x,v.y,y.x,y.y,0,1,d),d+=x,Go(this.layoutVertexArray,m.x,m.y,y.x,y.y,0,0,d),Go(this.layoutVertexArray,m.x,m.y,y.x,y.y,0,1,d);var b=u.vertexLength;this.indexArray.emplaceBack(b,b+2,b+1),this.indexArray.emplaceBack(b+1,b+2,b+3),u.vertexLength+=4,u.primitiveLength+=2}}}}if(u.vertexLength+s>Vi.MAX_VERTEX_ARRAY_LENGTH&&(u=this.segments.prepareSegment(s,this.layoutVertexArray,this.indexArray)),\"Polygon\"===qo[t.type]){for(var _=[],w=[],k=u.vertexLength,T=0,A=o;T<A.length;T+=1){var M=A[T];if(0!==M.length){M!==o[0]&&w.push(_.length/2);for(var S=0;S<M.length;S++){var E=M[S];Go(this.layoutVertexArray,E.x,E.y,0,0,1,1,0),_.push(E.x),_.push(E.y)}}}for(var C=Ka(_,w),L=0;L<C.length;L+=3)this.indexArray.emplaceBack(k+C[L],k+C[L+2],k+C[L+1]);u.primitiveLength+=C.length/3,u.vertexLength+=s}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,n)},kn(\"FillExtrusionBucket\",Yo,{omit:[\"layers\",\"features\"]});var Zo={paint:new ei({\"fill-extrusion-opacity\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-opacity\"]),\"fill-extrusion-color\":new Kn(It[\"paint_fill-extrusion\"][\"fill-extrusion-color\"]),\"fill-extrusion-translate\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-translate\"]),\"fill-extrusion-translate-anchor\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-translate-anchor\"]),\"fill-extrusion-pattern\":new $n(It[\"paint_fill-extrusion\"][\"fill-extrusion-pattern\"]),\"fill-extrusion-height\":new Kn(It[\"paint_fill-extrusion\"][\"fill-extrusion-height\"]),\"fill-extrusion-base\":new Kn(It[\"paint_fill-extrusion\"][\"fill-extrusion-base\"]),\"fill-extrusion-vertical-gradient\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-vertical-gradient\"])})},Jo=function(t){function e(e){t.call(this,e,Zo)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new Yo(t)},e.prototype.queryRadius=function(){return Ea(this.paint.get(\"fill-extrusion-translate\"))},e.prototype.is3D=function(){return!0},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s,l){var c=Ca(t,this.paint.get(\"fill-extrusion-translate\"),this.paint.get(\"fill-extrusion-translate-anchor\"),o.angle,s),u=this.paint.get(\"fill-extrusion-height\").evaluate(e,r),h=this.paint.get(\"fill-extrusion-base\").evaluate(e,r),f=function(t,e,r,n){for(var a=[],o=0,s=t;o<s.length;o+=1){var l=s[o],c=[l.x,l.y,0,1];Da(c,c,e),a.push(new i(c[0]/c[3],c[1]/c[3]))}return a}(c,l),p=function(t,e,r,n){for(var a=[],o=[],s=n[8]*e,l=n[9]*e,c=n[10]*e,u=n[11]*e,h=n[8]*r,f=n[9]*r,p=n[10]*r,d=n[11]*r,g=0,v=t;g<v.length;g+=1){for(var m=[],y=[],x=0,b=v[g];x<b.length;x+=1){var _=b[x],w=_.x,k=_.y,T=n[0]*w+n[4]*k+n[12],A=n[1]*w+n[5]*k+n[13],M=n[2]*w+n[6]*k+n[14],S=n[3]*w+n[7]*k+n[15],E=M+c,C=S+u,L=T+h,P=A+f,O=M+p,z=S+d,I=new i((T+s)/C,(A+l)/C);I.z=E/C,m.push(I);var D=new i(L/z,P/z);D.z=O/z,y.push(D)}a.push(m),o.push(y)}return[a,o]}(n,h,u,l);return function(t,e,r){var n=1/0;ya(r,e)&&(n=$o(r,e[0]));for(var i=0;i<e.length;i++)for(var a=e[i],o=t[i],s=0;s<a.length-1;s++){var l=a[s],c=a[s+1],u=o[s],h=[l,c,o[s+1],u,l];va(r,h)&&(n=Math.min(n,$o(r,h)))}return n!==1/0&&n}(p[0],p[1],f)},e}(ri);function Ko(t,e){return t.x*e.x+t.y*e.y}function $o(t,e){if(1===t.length){var r=e[0],n=e[1],i=e[3],a=t[0],o=n.sub(r),s=i.sub(r),l=a.sub(r),c=Ko(o,o),u=Ko(o,s),h=Ko(s,s),f=Ko(l,o),p=Ko(l,s),d=c*h-u*u,g=(h*f-u*p)/d,v=(c*p-u*f)/d,m=1-g-v;return r.z*m+n.z*g+i.z*v}for(var y=1/0,x=0,b=e;x<b.length;x+=1){var _=b[x];y=Math.min(y,_.z)}return y}var Qo=oi([{name:\"a_pos_normal\",components:2,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint8\"}],4).members,ts=Vo.VectorTileFeature.types,es=63,rs=Math.cos(Math.PI/180*37.5),ns=.5,is=Math.pow(2,14)/ns;function as(t,e,r,n,i,a,o){t.emplaceBack((e.x<<1)+(n?1:0),(e.y<<1)+(i?1:0),Math.round(es*r.x)+128,Math.round(es*r.y)+128,1+(0===a?0:a<0?-1:1)|(o*ns&63)<<2,o*ns>>6)}var os=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.features=[],this.hasPattern=!1,this.layoutVertexArray=new hi,this.indexArray=new Ti,this.programConfigurations=new la(Qo,t.layers,t.zoom),this.segments=new Vi,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function ss(t,e){return(t/e.tileTotal*(e.end-e.start)+e.start)*(is-1)}os.prototype.populate=function(t,e){this.features=[],this.hasPattern=Eo(\"line\",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a),c={sourceLayerIndex:s,index:o,geometry:l,properties:a.properties,type:a.type,patterns:{}};void 0!==a.id&&(c.id=a.id),this.hasPattern?this.features.push(Co(\"line\",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(a,l,o,s,this.index)}}},os.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},os.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var i=n[r],a=i.geometry;this.addFeature(i,a,i.index,e)}},os.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},os.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},os.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Qo),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},os.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},os.prototype.addFeature=function(t,e,r,n){for(var i=this.layers[0].layout,a=i.get(\"line-join\").evaluate(t,{}),o=i.get(\"line-cap\"),s=i.get(\"line-miter-limit\"),l=i.get(\"line-round-limit\"),c=0,u=e;c<u.length;c+=1){var h=u[c];this.addLine(h,t,a,o,s,l,r,n)}},os.prototype.addLine=function(t,e,r,n,i,a,o,s){var l=null;e.properties&&e.properties.hasOwnProperty(\"mapbox_clip_start\")&&e.properties.hasOwnProperty(\"mapbox_clip_end\")&&(l={start:e.properties.mapbox_clip_start,end:e.properties.mapbox_clip_end,tileTotal:void 0});for(var c=\"Polygon\"===ts[e.type],u=t.length;u>=2&&t[u-1].equals(t[u-2]);)u--;for(var h=0;h<u-1&&t[h].equals(t[h+1]);)h++;if(!(u<(c?3:2))){l&&(l.tileTotal=function(t,e,r){for(var n,i,a=0,o=h;o<r-1;o++)n=t[o],i=t[o+1],a+=n.dist(i);return a}(t,0,u)),\"bevel\"===r&&(i=1.05);var f=ha/(512*this.overscaling)*15,p=t[h],d=this.segments.prepareSegment(10*u,this.layoutVertexArray,this.indexArray);this.distance=0;var g,v,m,y=n,x=c?\"butt\":n,b=!0,_=void 0,w=void 0,k=void 0,T=void 0;this.e1=this.e2=this.e3=-1,c&&(g=t[u-2],T=p.sub(g)._unit()._perp());for(var A=h;A<u;A++)if(!(w=c&&A===u-1?t[h+1]:t[A+1])||!t[A].equals(w)){T&&(k=T),g&&(_=g),g=t[A],T=w?w.sub(g)._unit()._perp():k;var M=(k=k||T).add(T);0===M.x&&0===M.y||M._unit();var S=M.x*T.x+M.y*T.y,E=0!==S?1/S:1/0,C=S<rs&&_&&w;if(C&&A>h){var L=g.dist(_);if(L>2*f){var P=g.sub(g.sub(_)._mult(f/L)._round());this.distance+=P.dist(_),this.addCurrentVertex(P,this.distance,k.mult(1),0,0,!1,d,l),_=P}}var O=_&&w,z=O?r:w?y:x;if(O&&\"round\"===z&&(E<a?z=\"miter\":E<=2&&(z=\"fakeround\")),\"miter\"===z&&E>i&&(z=\"bevel\"),\"bevel\"===z&&(E>2&&(z=\"flipbevel\"),E<i&&(z=\"miter\")),_&&(this.distance+=g.dist(_)),\"miter\"===z)M._mult(E),this.addCurrentVertex(g,this.distance,M,0,0,!1,d,l);else if(\"flipbevel\"===z){if(E>100)M=T.clone().mult(-1);else{var I=k.x*T.y-k.y*T.x>0?-1:1,D=E*k.add(T).mag()/k.sub(T).mag();M._perp()._mult(D*I)}this.addCurrentVertex(g,this.distance,M,0,0,!1,d,l),this.addCurrentVertex(g,this.distance,M.mult(-1),0,0,!1,d,l)}else if(\"bevel\"===z||\"fakeround\"===z){var R=k.x*T.y-k.y*T.x>0,F=-Math.sqrt(E*E-1);if(R?(m=0,v=F):(v=0,m=F),b||this.addCurrentVertex(g,this.distance,k,v,m,!1,d,l),\"fakeround\"===z){for(var B=Math.floor(8*(.5-(S-.5))),N=void 0,j=0;j<B;j++)N=T.mult((j+1)/(B+1))._add(k)._unit(),this.addPieSliceVertex(g,this.distance,N,R,d,l);this.addPieSliceVertex(g,this.distance,M,R,d,l);for(var U=B-1;U>=0;U--)N=k.mult((U+1)/(B+1))._add(T)._unit(),this.addPieSliceVertex(g,this.distance,N,R,d,l)}w&&this.addCurrentVertex(g,this.distance,T,-v,-m,!1,d,l)}else\"butt\"===z?(b||this.addCurrentVertex(g,this.distance,k,0,0,!1,d,l),w&&this.addCurrentVertex(g,this.distance,T,0,0,!1,d,l)):\"square\"===z?(b||(this.addCurrentVertex(g,this.distance,k,1,1,!1,d,l),this.e1=this.e2=-1),w&&this.addCurrentVertex(g,this.distance,T,-1,-1,!1,d,l)):\"round\"===z&&(b||(this.addCurrentVertex(g,this.distance,k,0,0,!1,d,l),this.addCurrentVertex(g,this.distance,k,1,1,!0,d,l),this.e1=this.e2=-1),w&&(this.addCurrentVertex(g,this.distance,T,-1,-1,!0,d,l),this.addCurrentVertex(g,this.distance,T,0,0,!1,d,l)));if(C&&A<u-1){var V=g.dist(w);if(V>2*f){var q=g.add(w.sub(g)._mult(f/V)._round());this.distance+=q.dist(g),this.addCurrentVertex(q,this.distance,T.mult(1),0,0,!1,d,l),g=q}}b=!1}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,e,o,s)}},os.prototype.addCurrentVertex=function(t,e,r,n,i,a,o,s){var l,c=this.layoutVertexArray,u=this.indexArray;s&&(e=ss(e,s)),l=r.clone(),n&&l._sub(r.perp()._mult(n)),as(c,t,l,a,!1,n,e),this.e3=o.vertexLength++,this.e1>=0&&this.e2>=0&&(u.emplaceBack(this.e1,this.e2,this.e3),o.primitiveLength++),this.e1=this.e2,this.e2=this.e3,l=r.mult(-1),i&&l._sub(r.perp()._mult(i)),as(c,t,l,a,!0,-i,e),this.e3=o.vertexLength++,this.e1>=0&&this.e2>=0&&(u.emplaceBack(this.e1,this.e2,this.e3),o.primitiveLength++),this.e1=this.e2,this.e2=this.e3,e>is/2&&!s&&(this.distance=0,this.addCurrentVertex(t,this.distance,r,n,i,a,o))},os.prototype.addPieSliceVertex=function(t,e,r,n,i,a){r=r.mult(n?-1:1);var o=this.layoutVertexArray,s=this.indexArray;a&&(e=ss(e,a)),as(o,t,r,!1,n,0,e),this.e3=i.vertexLength++,this.e1>=0&&this.e2>=0&&(s.emplaceBack(this.e1,this.e2,this.e3),i.primitiveLength++),n?this.e2=this.e3:this.e1=this.e3},kn(\"LineBucket\",os,{omit:[\"layers\",\"features\"]});var ls=new ei({\"line-cap\":new Jn(It.layout_line[\"line-cap\"]),\"line-join\":new Kn(It.layout_line[\"line-join\"]),\"line-miter-limit\":new Jn(It.layout_line[\"line-miter-limit\"]),\"line-round-limit\":new Jn(It.layout_line[\"line-round-limit\"])}),cs={paint:new ei({\"line-opacity\":new Kn(It.paint_line[\"line-opacity\"]),\"line-color\":new Kn(It.paint_line[\"line-color\"]),\"line-translate\":new Jn(It.paint_line[\"line-translate\"]),\"line-translate-anchor\":new Jn(It.paint_line[\"line-translate-anchor\"]),\"line-width\":new Kn(It.paint_line[\"line-width\"]),\"line-gap-width\":new Kn(It.paint_line[\"line-gap-width\"]),\"line-offset\":new Kn(It.paint_line[\"line-offset\"]),\"line-blur\":new Kn(It.paint_line[\"line-blur\"]),\"line-dasharray\":new Qn(It.paint_line[\"line-dasharray\"]),\"line-pattern\":new $n(It.paint_line[\"line-pattern\"]),\"line-gradient\":new ti(It.paint_line[\"line-gradient\"])}),layout:ls},us=new(function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(e,r){return r=new Un(Math.floor(r.zoom),{now:r.now,fadeDuration:r.fadeDuration,zoomHistory:r.zoomHistory,transition:r.transition}),t.prototype.possiblyEvaluate.call(this,e,r)},e.prototype.evaluate=function(e,r,n,i){return r=h({},r,{zoom:Math.floor(r.zoom)}),t.prototype.evaluate.call(this,e,r,n,i)},e}(Kn))(cs.paint.properties[\"line-width\"].specification);us.useIntegerZoom=!0;var hs=function(t){function e(e){t.call(this,e,cs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"line-gradient\"===t&&this._updateGradient()},e.prototype._updateGradient=function(){var t=this._transitionablePaint._values[\"line-gradient\"].value.expression;this.gradient=Ya(t,\"lineProgress\"),this.gradientTexture=null},e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e),this.paint._values[\"line-floorwidth\"]=us.possiblyEvaluate(this._transitioningPaint._values[\"line-width\"].value,e)},e.prototype.createBucket=function(t){return new os(t)},e.prototype.queryRadius=function(t){var e=t,r=fs(Sa(\"line-width\",this,e),Sa(\"line-gap-width\",this,e)),n=Sa(\"line-offset\",this,e);return r/2+Math.abs(n)+Ea(this.paint.get(\"line-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s){var l=Ca(t,this.paint.get(\"line-translate\"),this.paint.get(\"line-translate-anchor\"),o.angle,s),c=s/2*fs(this.paint.get(\"line-width\").evaluate(e,r),this.paint.get(\"line-gap-width\").evaluate(e,r)),u=this.paint.get(\"line-offset\").evaluate(e,r);return u&&(n=function(t,e){for(var r=[],n=new i(0,0),a=0;a<t.length;a++){for(var o=t[a],s=[],l=0;l<o.length;l++){var c=o[l-1],u=o[l],h=o[l+1],f=0===l?n:u.sub(c)._unit()._perp(),p=l===o.length-1?n:h.sub(u)._unit()._perp(),d=f._add(p)._unit(),g=d.x*p.x+d.y*p.y;d._mult(1/g),s.push(d._mult(e)._add(u))}r.push(s)}return r}(n,u*s)),function(t,e,r){for(var n=0;n<e.length;n++){var i=e[n];if(t.length>=3)for(var a=0;a<i.length;a++)if(Aa(t,i[a]))return!0;if(xa(t,i,r))return!0}return!1}(l,n,c)},e.prototype.isTileClipped=function(){return!0},e}(ri);function fs(t,e){return e>0?e+2*t:t}var ps=oi([{name:\"a_pos_offset\",components:4,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint16\"}]),ds=oi([{name:\"a_projected_pos\",components:3,type:\"Float32\"}],4),gs=(oi([{name:\"a_fade_opacity\",components:1,type:\"Uint32\"}],4),oi([{name:\"a_placed\",components:2,type:\"Uint8\"},{name:\"a_shift\",components:2,type:\"Float32\"}])),vs=(oi([{type:\"Int16\",name:\"anchorPointX\"},{type:\"Int16\",name:\"anchorPointY\"},{type:\"Int16\",name:\"x1\"},{type:\"Int16\",name:\"y1\"},{type:\"Int16\",name:\"x2\"},{type:\"Int16\",name:\"y2\"},{type:\"Uint32\",name:\"featureIndex\"},{type:\"Uint16\",name:\"sourceLayerIndex\"},{type:\"Uint16\",name:\"bucketIndex\"},{type:\"Int16\",name:\"radius\"},{type:\"Int16\",name:\"signedDistanceFromAnchor\"}]),oi([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4)),ms=oi([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4);function ys(t,e,r){return t.sections.forEach(function(t){t.text=function(t,e,r){var n=e.layout.get(\"text-transform\").evaluate(r,{});return\"uppercase\"===n?t=t.toLocaleUpperCase():\"lowercase\"===n&&(t=t.toLocaleLowerCase()),jn.applyArabicShaping&&(t=jn.applyArabicShaping(t)),t}(t.text,e,r)}),t}oi([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Uint16\",name:\"glyphStartIndex\"},{type:\"Uint16\",name:\"numGlyphs\"},{type:\"Uint32\",name:\"vertexStartIndex\"},{type:\"Uint32\",name:\"lineStartIndex\"},{type:\"Uint32\",name:\"lineLength\"},{type:\"Uint16\",name:\"segment\"},{type:\"Uint16\",name:\"lowerSize\"},{type:\"Uint16\",name:\"upperSize\"},{type:\"Float32\",name:\"lineOffsetX\"},{type:\"Float32\",name:\"lineOffsetY\"},{type:\"Uint8\",name:\"writingMode\"},{type:\"Uint8\",name:\"hidden\"},{type:\"Uint32\",name:\"crossTileID\"}]),oi([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Int16\",name:\"rightJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"centerJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"leftJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"verticalPlacedTextSymbolIndex\"},{type:\"Uint16\",name:\"key\"},{type:\"Uint16\",name:\"textBoxStartIndex\"},{type:\"Uint16\",name:\"textBoxEndIndex\"},{type:\"Uint16\",name:\"iconBoxStartIndex\"},{type:\"Uint16\",name:\"iconBoxEndIndex\"},{type:\"Uint16\",name:\"featureIndex\"},{type:\"Uint16\",name:\"numHorizontalGlyphVertices\"},{type:\"Uint16\",name:\"numVerticalGlyphVertices\"},{type:\"Uint16\",name:\"numIconVertices\"},{type:\"Uint32\",name:\"crossTileID\"},{type:\"Float32\",name:\"textBoxScale\"},{type:\"Float32\",name:\"radialTextOffset\"}]),oi([{type:\"Float32\",name:\"offsetX\"}]),oi([{type:\"Int16\",name:\"x\"},{type:\"Int16\",name:\"y\"},{type:\"Int16\",name:\"tileUnitDistanceFromAnchor\"}]);var xs={\"!\":\"\\ufe15\",\"#\":\"\\uff03\",$:\"\\uff04\",\"%\":\"\\uff05\",\"&\":\"\\uff06\",\"(\":\"\\ufe35\",\")\":\"\\ufe36\",\"*\":\"\\uff0a\",\"+\":\"\\uff0b\",\",\":\"\\ufe10\",\"-\":\"\\ufe32\",\".\":\"\\u30fb\",\"/\":\"\\uff0f\",\":\":\"\\ufe13\",\";\":\"\\ufe14\",\"<\":\"\\ufe3f\",\"=\":\"\\uff1d\",\">\":\"\\ufe40\",\"?\":\"\\ufe16\",\"@\":\"\\uff20\",\"[\":\"\\ufe47\",\"\\\\\":\"\\uff3c\",\"]\":\"\\ufe48\",\"^\":\"\\uff3e\",_:\"\\ufe33\",\"`\":\"\\uff40\",\"{\":\"\\ufe37\",\"|\":\"\\u2015\",\"}\":\"\\ufe38\",\"~\":\"\\uff5e\",\"\\xa2\":\"\\uffe0\",\"\\xa3\":\"\\uffe1\",\"\\xa5\":\"\\uffe5\",\"\\xa6\":\"\\uffe4\",\"\\xac\":\"\\uffe2\",\"\\xaf\":\"\\uffe3\",\"\\u2013\":\"\\ufe32\",\"\\u2014\":\"\\ufe31\",\"\\u2018\":\"\\ufe43\",\"\\u2019\":\"\\ufe44\",\"\\u201c\":\"\\ufe41\",\"\\u201d\":\"\\ufe42\",\"\\u2026\":\"\\ufe19\",\"\\u2027\":\"\\u30fb\",\"\\u20a9\":\"\\uffe6\",\"\\u3001\":\"\\ufe11\",\"\\u3002\":\"\\ufe12\",\"\\u3008\":\"\\ufe3f\",\"\\u3009\":\"\\ufe40\",\"\\u300a\":\"\\ufe3d\",\"\\u300b\":\"\\ufe3e\",\"\\u300c\":\"\\ufe41\",\"\\u300d\":\"\\ufe42\",\"\\u300e\":\"\\ufe43\",\"\\u300f\":\"\\ufe44\",\"\\u3010\":\"\\ufe3b\",\"\\u3011\":\"\\ufe3c\",\"\\u3014\":\"\\ufe39\",\"\\u3015\":\"\\ufe3a\",\"\\u3016\":\"\\ufe17\",\"\\u3017\":\"\\ufe18\",\"\\uff01\":\"\\ufe15\",\"\\uff08\":\"\\ufe35\",\"\\uff09\":\"\\ufe36\",\"\\uff0c\":\"\\ufe10\",\"\\uff0d\":\"\\ufe32\",\"\\uff0e\":\"\\u30fb\",\"\\uff1a\":\"\\ufe13\",\"\\uff1b\":\"\\ufe14\",\"\\uff1c\":\"\\ufe3f\",\"\\uff1e\":\"\\ufe40\",\"\\uff1f\":\"\\ufe16\",\"\\uff3b\":\"\\ufe47\",\"\\uff3d\":\"\\ufe48\",\"\\uff3f\":\"\\ufe33\",\"\\uff5b\":\"\\ufe37\",\"\\uff5c\":\"\\u2015\",\"\\uff5d\":\"\\ufe38\",\"\\uff5f\":\"\\ufe35\",\"\\uff60\":\"\\ufe36\",\"\\uff61\":\"\\ufe12\",\"\\uff62\":\"\\ufe41\",\"\\uff63\":\"\\ufe42\"},bs=function(t){function e(e,r,n,i){t.call(this,e,r),this.angle=n,void 0!==i&&(this.segment=i)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.clone=function(){return new e(this.x,this.y,this.angle,this.segment)},e}(i);kn(\"Anchor\",bs);var _s=256;function ws(t,e){var r=e.expression;if(\"constant\"===r.kind)return{kind:\"constant\",layoutSize:r.evaluate(new Un(t+1))};if(\"source\"===r.kind)return{kind:\"source\"};for(var n=r.zoomStops,i=r.interpolationType,a=0;a<n.length&&n[a]<=t;)a++;for(var o=a=Math.max(0,a-1);o<n.length&&n[o]<t+1;)o++;o=Math.min(n.length-1,o);var s=n[a],l=n[o];return\"composite\"===r.kind?{kind:\"composite\",minZoom:s,maxZoom:l,interpolationType:i}:{kind:\"camera\",minZoom:s,maxZoom:l,minSize:r.evaluate(new Un(s)),maxSize:r.evaluate(new Un(l)),interpolationType:i}}function ks(t,e,r){var n=e.uSize,i=e.uSizeT,a=r.lowerSize,o=r.upperSize;return\"source\"===t.kind?a/_s:\"composite\"===t.kind?Ee(a/_s,o/_s,i):n}function Ts(t,e){var r=0,n=0;if(\"constant\"===t.kind)n=t.layoutSize;else if(\"source\"!==t.kind){var i=t.interpolationType,a=t.minZoom,o=t.maxZoom,s=i?c(Xe.interpolationFactor(i,e,a,o),0,1):0;\"camera\"===t.kind?n=Ee(t.minSize,t.maxSize,s):r=s}return{uSizeT:r,uSize:n}}var As=Object.freeze({getSizeData:ws,evaluateSizeForFeature:ks,evaluateSizeForZoom:Ts,SIZE_PACK_FACTOR:_s}),Ms=Vo.VectorTileFeature.types,Ss=[{name:\"a_fade_opacity\",components:1,type:\"Uint8\",offset:0}];function Es(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,Math.round(32*n),Math.round(32*i),a,o,s?s[0]:0,s?s[1]:0)}function Cs(t,e,r){t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r)}var Ls=function(t){this.layoutVertexArray=new pi,this.indexArray=new Ti,this.programConfigurations=t,this.segments=new Vi,this.dynamicLayoutVertexArray=new di,this.opacityVertexArray=new gi,this.placedSymbolArray=new Oi};Ls.prototype.upload=function(t,e,r,n){r&&(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,ps.members),this.indexBuffer=t.createIndexBuffer(this.indexArray,e),this.dynamicLayoutVertexBuffer=t.createVertexBuffer(this.dynamicLayoutVertexArray,ds.members,!0),this.opacityVertexBuffer=t.createVertexBuffer(this.opacityVertexArray,Ss,!0),this.opacityVertexBuffer.itemSize=1),(r||n)&&this.programConfigurations.upload(t)},Ls.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.dynamicLayoutVertexBuffer.destroy(),this.opacityVertexBuffer.destroy())},kn(\"SymbolBuffers\",Ls);var Ps=function(t,e,r){this.layoutVertexArray=new t,this.layoutAttributes=e,this.indexArray=new r,this.segments=new Vi,this.collisionVertexArray=new yi};Ps.prototype.upload=function(t){this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,this.layoutAttributes),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.collisionVertexBuffer=t.createVertexBuffer(this.collisionVertexArray,gs.members,!0)},Ps.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.segments.destroy(),this.collisionVertexBuffer.destroy())},kn(\"CollisionBuffers\",Ps);var Os=function(t){this.collisionBoxArray=t.collisionBoxArray,this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.pixelRatio=t.pixelRatio,this.sourceLayerIndex=t.sourceLayerIndex,this.hasPattern=!1;var e=this.layers[0]._unevaluatedLayout._values;this.textSizeData=ws(this.zoom,e[\"text-size\"]),this.iconSizeData=ws(this.zoom,e[\"icon-size\"]);var r=this.layers[0].layout,n=r.get(\"symbol-sort-key\"),i=r.get(\"symbol-z-order\");this.sortFeaturesByKey=\"viewport-y\"!==i&&void 0!==n.constantOr(1);var a=\"viewport-y\"===i||\"auto\"===i&&!this.sortFeaturesByKey;this.sortFeaturesByY=a&&(r.get(\"text-allow-overlap\")||r.get(\"icon-allow-overlap\")||r.get(\"text-ignore-placement\")||r.get(\"icon-ignore-placement\")),this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id}),this.sourceID=t.sourceID};Os.prototype.createArrays=function(){this.text=new Ls(new la(ps.members,this.layers,this.zoom,function(t){return/^text/.test(t)})),this.icon=new Ls(new la(ps.members,this.layers,this.zoom,function(t){return/^icon/.test(t)})),this.collisionBox=new Ps(mi,vs.members,Ai),this.collisionCircle=new Ps(mi,ms.members,Ti),this.glyphOffsetArray=new Ri,this.lineVertexArray=new Bi,this.symbolInstances=new Ii},Os.prototype.calculateGlyphDependencies=function(t,e,r,n){for(var i=0;i<t.length;i++)if(e[t.charCodeAt(i)]=!0,r&&n){var a=xs[t.charAt(i)];a&&(e[a.charCodeAt(0)]=!0)}},Os.prototype.populate=function(t,e){var r=this.layers[0],n=r.layout,i=n.get(\"text-font\"),a=n.get(\"text-field\"),o=n.get(\"icon-image\"),s=(\"constant\"!==a.value.kind||a.value.value.toString().length>0)&&(\"constant\"!==i.value.kind||i.value.value.length>0),l=\"constant\"!==o.value.kind||o.value.value&&o.value.value.length>0,c=n.get(\"symbol-sort-key\");if(this.features=[],s||l){for(var u=e.iconDependencies,h=e.glyphDependencies,f=new Un(this.zoom),p=0,d=t;p<d.length;p+=1){var g=d[p],v=g.feature,m=g.index,y=g.sourceLayerIndex;if(r._featureFilter(f,v)){var x=void 0;if(s){var b=r.getValueAndResolveTokens(\"text-field\",v);x=ys(b instanceof oe?b:oe.fromString(b),r,v)}var _=void 0;if(l&&(_=r.getValueAndResolveTokens(\"icon-image\",v)),x||_){var w=this.sortFeaturesByKey?c.evaluate(v,{}):void 0,k={text:x,icon:_,index:m,sourceLayerIndex:y,geometry:pa(v),properties:v.properties,type:Ms[v.type],sortKey:w};if(void 0!==v.id&&(k.id=v.id),this.features.push(k),_&&(u[_]=!0),x)for(var T=i.evaluate(v,{}).join(\",\"),A=\"map\"===n.get(\"text-rotation-alignment\")&&\"point\"!==n.get(\"symbol-placement\"),M=0,S=x.sections;M<S.length;M+=1){var E=S[M],C=Cn(x.toString()),L=E.fontStack||T,P=h[L]=h[L]||{};this.calculateGlyphDependencies(E.text,P,A,C)}}}}\"line\"===n.get(\"symbol-placement\")&&(this.features=function(t){var e={},r={},n=[],i=0;function a(e){n.push(t[e]),i++}function o(t,e,i){var a=r[t];return delete r[t],r[e]=a,n[a].geometry[0].pop(),n[a].geometry[0]=n[a].geometry[0].concat(i[0]),a}function s(t,r,i){var a=e[r];return delete e[r],e[t]=a,n[a].geometry[0].shift(),n[a].geometry[0]=i[0].concat(n[a].geometry[0]),a}function l(t,e,r){var n=r?e[0][e[0].length-1]:e[0][0];return t+\":\"+n.x+\":\"+n.y}for(var c=0;c<t.length;c++){var u=t[c],h=u.geometry,f=u.text?u.text.toString():null;if(f){var p=l(f,h),d=l(f,h,!0);if(p in r&&d in e&&r[p]!==e[d]){var g=s(p,d,h),v=o(p,d,n[g].geometry);delete e[p],delete r[d],r[l(f,n[v].geometry,!0)]=v,n[g].geometry=null}else p in r?o(p,d,h):d in e?s(p,d,h):(a(c),e[p]=i-1,r[d]=i-1)}else a(c)}return n.filter(function(t){return t.geometry})}(this.features)),this.sortFeaturesByKey&&this.features.sort(function(t,e){return t.sortKey-e.sortKey})}},Os.prototype.update=function(t,e,r){this.stateDependentLayers.length&&(this.text.programConfigurations.updatePaintArrays(t,e,this.layers,r),this.icon.programConfigurations.updatePaintArrays(t,e,this.layers,r))},Os.prototype.isEmpty=function(){return 0===this.symbolInstances.length},Os.prototype.uploadPending=function(){return!this.uploaded||this.text.programConfigurations.needsUpload||this.icon.programConfigurations.needsUpload},Os.prototype.upload=function(t){this.uploaded||(this.collisionBox.upload(t),this.collisionCircle.upload(t)),this.text.upload(t,this.sortFeaturesByY,!this.uploaded,this.text.programConfigurations.needsUpload),this.icon.upload(t,this.sortFeaturesByY,!this.uploaded,this.icon.programConfigurations.needsUpload),this.uploaded=!0},Os.prototype.destroy=function(){this.text.destroy(),this.icon.destroy(),this.collisionBox.destroy(),this.collisionCircle.destroy()},Os.prototype.addToLineVertexArray=function(t,e){var r=this.lineVertexArray.length;if(void 0!==t.segment){for(var n=t.dist(e[t.segment+1]),i=t.dist(e[t.segment]),a={},o=t.segment+1;o<e.length;o++)a[o]={x:e[o].x,y:e[o].y,tileUnitDistanceFromAnchor:n},o<e.length-1&&(n+=e[o+1].dist(e[o]));for(var s=t.segment||0;s>=0;s--)a[s]={x:e[s].x,y:e[s].y,tileUnitDistanceFromAnchor:i},s>0&&(i+=e[s-1].dist(e[s]));for(var l=0;l<e.length;l++){var c=a[l];this.lineVertexArray.emplaceBack(c.x,c.y,c.tileUnitDistanceFromAnchor)}}return{lineStartIndex:r,lineLength:this.lineVertexArray.length-r}},Os.prototype.addSymbols=function(t,e,r,n,i,a,o,s,l,c){for(var u=t.indexArray,h=t.layoutVertexArray,f=t.dynamicLayoutVertexArray,p=t.segments.prepareSegment(4*e.length,t.layoutVertexArray,t.indexArray,a.sortKey),d=this.glyphOffsetArray.length,g=p.vertexLength,v=0,m=e;v<m.length;v+=1){var y=m[v],x=y.tl,b=y.tr,_=y.bl,w=y.br,k=y.tex,T=p.vertexLength,A=y.glyphOffset[1];Es(h,s.x,s.y,x.x,A+x.y,k.x,k.y,r),Es(h,s.x,s.y,b.x,A+b.y,k.x+k.w,k.y,r),Es(h,s.x,s.y,_.x,A+_.y,k.x,k.y+k.h,r),Es(h,s.x,s.y,w.x,A+w.y,k.x+k.w,k.y+k.h,r),Cs(f,s,0),u.emplaceBack(T,T+1,T+2),u.emplaceBack(T+1,T+2,T+3),p.vertexLength+=4,p.primitiveLength+=2,this.glyphOffsetArray.emplaceBack(y.glyphOffset[0])}t.placedSymbolArray.emplaceBack(s.x,s.y,d,this.glyphOffsetArray.length-d,g,l,c,s.segment,r?r[0]:0,r?r[1]:0,n[0],n[1],o,!1,0),t.programConfigurations.populatePaintArrays(t.layoutVertexArray.length,a,a.index,{})},Os.prototype._addCollisionDebugVertex=function(t,e,r,n,i,a){return e.emplaceBack(0,0),t.emplaceBack(r.x,r.y,n,i,Math.round(a.x),Math.round(a.y))},Os.prototype.addCollisionDebugVertices=function(t,e,r,n,a,o,s,l){var c=a.segments.prepareSegment(4,a.layoutVertexArray,a.indexArray),u=c.vertexLength,h=a.layoutVertexArray,f=a.collisionVertexArray,p=s.anchorX,d=s.anchorY;if(this._addCollisionDebugVertex(h,f,o,p,d,new i(t,e)),this._addCollisionDebugVertex(h,f,o,p,d,new i(r,e)),this._addCollisionDebugVertex(h,f,o,p,d,new i(r,n)),this._addCollisionDebugVertex(h,f,o,p,d,new i(t,n)),c.vertexLength+=4,l){var g=a.indexArray;g.emplaceBack(u,u+1,u+2),g.emplaceBack(u,u+2,u+3),c.primitiveLength+=2}else{var v=a.indexArray;v.emplaceBack(u,u+1),v.emplaceBack(u+1,u+2),v.emplaceBack(u+2,u+3),v.emplaceBack(u+3,u),c.primitiveLength+=4}},Os.prototype.addDebugCollisionBoxes=function(t,e,r){for(var n=t;n<e;n++){var i=this.collisionBoxArray.get(n),a=i.x1,o=i.y1,s=i.x2,l=i.y2,c=i.radius>0;this.addCollisionDebugVertices(a,o,s,l,c?this.collisionCircle:this.collisionBox,i.anchorPoint,r,c)}},Os.prototype.generateCollisionDebugBuffers=function(){for(var t=0;t<this.symbolInstances.length;t++){var e=this.symbolInstances.get(t);this.addDebugCollisionBoxes(e.textBoxStartIndex,e.textBoxEndIndex,e),this.addDebugCollisionBoxes(e.iconBoxStartIndex,e.iconBoxEndIndex,e)}},Os.prototype._deserializeCollisionBoxesForSymbol=function(t,e,r,n,i){for(var a={},o=e;o<r;o++){var s=t.get(o);if(0===s.radius){a.textBox={x1:s.x1,y1:s.y1,x2:s.x2,y2:s.y2,anchorPointX:s.anchorPointX,anchorPointY:s.anchorPointY},a.textFeatureIndex=s.featureIndex;break}a.textCircles||(a.textCircles=[],a.textFeatureIndex=s.featureIndex),a.textCircles.push(s.anchorPointX,s.anchorPointY,s.radius,s.signedDistanceFromAnchor,1)}for(var l=n;l<i;l++){var c=t.get(l);if(0===c.radius){a.iconBox={x1:c.x1,y1:c.y1,x2:c.x2,y2:c.y2,anchorPointX:c.anchorPointX,anchorPointY:c.anchorPointY},a.iconFeatureIndex=c.featureIndex;break}}return a},Os.prototype.deserializeCollisionBoxes=function(t){this.collisionArrays=[];for(var e=0;e<this.symbolInstances.length;e++){var r=this.symbolInstances.get(e);this.collisionArrays.push(this._deserializeCollisionBoxesForSymbol(t,r.textBoxStartIndex,r.textBoxEndIndex,r.iconBoxStartIndex,r.iconBoxEndIndex))}},Os.prototype.hasTextData=function(){return this.text.segments.get().length>0},Os.prototype.hasIconData=function(){return this.icon.segments.get().length>0},Os.prototype.hasCollisionBoxData=function(){return this.collisionBox.segments.get().length>0},Os.prototype.hasCollisionCircleData=function(){return this.collisionCircle.segments.get().length>0},Os.prototype.addIndicesForPlacedTextSymbol=function(t){for(var e=this.text.placedSymbolArray.get(t),r=e.vertexStartIndex+4*e.numGlyphs,n=e.vertexStartIndex;n<r;n+=4)this.text.indexArray.emplaceBack(n,n+1,n+2),this.text.indexArray.emplaceBack(n+1,n+2,n+3)},Os.prototype.getSortedSymbolIndexes=function(t){if(this.sortedAngle===t&&void 0!==this.symbolInstanceIndexes)return this.symbolInstanceIndexes;for(var e=Math.sin(t),r=Math.cos(t),n=[],i=[],a=[],o=0;o<this.symbolInstances.length;++o){a.push(o);var s=this.symbolInstances.get(o);n.push(0|Math.round(e*s.anchorX+r*s.anchorY)),i.push(s.featureIndex)}return a.sort(function(t,e){return n[t]-n[e]||i[e]-i[t]}),a},Os.prototype.sortFeatures=function(t){var e=this;if(this.sortFeaturesByY&&this.sortedAngle!==t&&!(this.text.segments.get().length>1||this.icon.segments.get().length>1)){this.symbolInstanceIndexes=this.getSortedSymbolIndexes(t),this.sortedAngle=t,this.text.indexArray.clear(),this.icon.indexArray.clear(),this.featureSortOrder=[];for(var r=0,n=this.symbolInstanceIndexes;r<n.length;r+=1){var i=n[r],a=this.symbolInstances.get(i);this.featureSortOrder.push(a.featureIndex),[a.rightJustifiedTextSymbolIndex,a.centerJustifiedTextSymbolIndex,a.leftJustifiedTextSymbolIndex].forEach(function(t,r,n){t>=0&&n.indexOf(t)===r&&e.addIndicesForPlacedTextSymbol(t)}),a.verticalPlacedTextSymbolIndex>=0&&this.addIndicesForPlacedTextSymbol(a.verticalPlacedTextSymbolIndex);var o=this.icon.placedSymbolArray.get(i);if(o.numGlyphs){var s=o.vertexStartIndex;this.icon.indexArray.emplaceBack(s,s+1,s+2),this.icon.indexArray.emplaceBack(s+1,s+2,s+3)}}this.text.indexBuffer&&this.text.indexBuffer.updateData(this.text.indexArray),this.icon.indexBuffer&&this.icon.indexBuffer.updateData(this.icon.indexArray)}},kn(\"SymbolBucket\",Os,{omit:[\"layers\",\"collisionBoxArray\",\"features\",\"compareText\"]}),Os.MAX_GLYPHS=65535,Os.addDynamicAttributes=Cs;var zs=new ei({\"symbol-placement\":new Jn(It.layout_symbol[\"symbol-placement\"]),\"symbol-spacing\":new Jn(It.layout_symbol[\"symbol-spacing\"]),\"symbol-avoid-edges\":new Jn(It.layout_symbol[\"symbol-avoid-edges\"]),\"symbol-sort-key\":new Kn(It.layout_symbol[\"symbol-sort-key\"]),\"symbol-z-order\":new Jn(It.layout_symbol[\"symbol-z-order\"]),\"icon-allow-overlap\":new Jn(It.layout_symbol[\"icon-allow-overlap\"]),\"icon-ignore-placement\":new Jn(It.layout_symbol[\"icon-ignore-placement\"]),\"icon-optional\":new Jn(It.layout_symbol[\"icon-optional\"]),\"icon-rotation-alignment\":new Jn(It.layout_symbol[\"icon-rotation-alignment\"]),\"icon-size\":new Kn(It.layout_symbol[\"icon-size\"]),\"icon-text-fit\":new Jn(It.layout_symbol[\"icon-text-fit\"]),\"icon-text-fit-padding\":new Jn(It.layout_symbol[\"icon-text-fit-padding\"]),\"icon-image\":new Kn(It.layout_symbol[\"icon-image\"]),\"icon-rotate\":new Kn(It.layout_symbol[\"icon-rotate\"]),\"icon-padding\":new Jn(It.layout_symbol[\"icon-padding\"]),\"icon-keep-upright\":new Jn(It.layout_symbol[\"icon-keep-upright\"]),\"icon-offset\":new Kn(It.layout_symbol[\"icon-offset\"]),\"icon-anchor\":new Kn(It.layout_symbol[\"icon-anchor\"]),\"icon-pitch-alignment\":new Jn(It.layout_symbol[\"icon-pitch-alignment\"]),\"text-pitch-alignment\":new Jn(It.layout_symbol[\"text-pitch-alignment\"]),\"text-rotation-alignment\":new Jn(It.layout_symbol[\"text-rotation-alignment\"]),\"text-field\":new Kn(It.layout_symbol[\"text-field\"]),\"text-font\":new Kn(It.layout_symbol[\"text-font\"]),\"text-size\":new Kn(It.layout_symbol[\"text-size\"]),\"text-max-width\":new Kn(It.layout_symbol[\"text-max-width\"]),\"text-line-height\":new Jn(It.layout_symbol[\"text-line-height\"]),\"text-letter-spacing\":new Kn(It.layout_symbol[\"text-letter-spacing\"]),\"text-justify\":new Kn(It.layout_symbol[\"text-justify\"]),\"text-radial-offset\":new Kn(It.layout_symbol[\"text-radial-offset\"]),\"text-variable-anchor\":new Jn(It.layout_symbol[\"text-variable-anchor\"]),\"text-anchor\":new Kn(It.layout_symbol[\"text-anchor\"]),\"text-max-angle\":new Jn(It.layout_symbol[\"text-max-angle\"]),\"text-rotate\":new Kn(It.layout_symbol[\"text-rotate\"]),\"text-padding\":new Jn(It.layout_symbol[\"text-padding\"]),\"text-keep-upright\":new Jn(It.layout_symbol[\"text-keep-upright\"]),\"text-transform\":new Kn(It.layout_symbol[\"text-transform\"]),\"text-offset\":new Kn(It.layout_symbol[\"text-offset\"]),\"text-allow-overlap\":new Jn(It.layout_symbol[\"text-allow-overlap\"]),\"text-ignore-placement\":new Jn(It.layout_symbol[\"text-ignore-placement\"]),\"text-optional\":new Jn(It.layout_symbol[\"text-optional\"])}),Is={paint:new ei({\"icon-opacity\":new Kn(It.paint_symbol[\"icon-opacity\"]),\"icon-color\":new Kn(It.paint_symbol[\"icon-color\"]),\"icon-halo-color\":new Kn(It.paint_symbol[\"icon-halo-color\"]),\"icon-halo-width\":new Kn(It.paint_symbol[\"icon-halo-width\"]),\"icon-halo-blur\":new Kn(It.paint_symbol[\"icon-halo-blur\"]),\"icon-translate\":new Jn(It.paint_symbol[\"icon-translate\"]),\"icon-translate-anchor\":new Jn(It.paint_symbol[\"icon-translate-anchor\"]),\"text-opacity\":new Kn(It.paint_symbol[\"text-opacity\"]),\"text-color\":new Kn(It.paint_symbol[\"text-color\"]),\"text-halo-color\":new Kn(It.paint_symbol[\"text-halo-color\"]),\"text-halo-width\":new Kn(It.paint_symbol[\"text-halo-width\"]),\"text-halo-blur\":new Kn(It.paint_symbol[\"text-halo-blur\"]),\"text-translate\":new Jn(It.paint_symbol[\"text-translate\"]),\"text-translate-anchor\":new Jn(It.paint_symbol[\"text-translate-anchor\"])}),layout:zs},Ds=function(t){function e(e){t.call(this,e,Is)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e),\"auto\"===this.layout.get(\"icon-rotation-alignment\")&&(\"point\"!==this.layout.get(\"symbol-placement\")?this.layout._values[\"icon-rotation-alignment\"]=\"map\":this.layout._values[\"icon-rotation-alignment\"]=\"viewport\"),\"auto\"===this.layout.get(\"text-rotation-alignment\")&&(\"point\"!==this.layout.get(\"symbol-placement\")?this.layout._values[\"text-rotation-alignment\"]=\"map\":this.layout._values[\"text-rotation-alignment\"]=\"viewport\"),\"auto\"===this.layout.get(\"text-pitch-alignment\")&&(this.layout._values[\"text-pitch-alignment\"]=this.layout.get(\"text-rotation-alignment\")),\"auto\"===this.layout.get(\"icon-pitch-alignment\")&&(this.layout._values[\"icon-pitch-alignment\"]=this.layout.get(\"icon-rotation-alignment\"))},e.prototype.getValueAndResolveTokens=function(t,e){var r,n=this.layout.get(t).evaluate(e,{}),i=this._unevaluatedLayout._values[t];return i.isDataDriven()||Pr(i.value)?n:(r=e.properties,n.replace(/{([^{}]+)}/g,function(t,e){return e in r?String(r[e]):\"\"}))},e.prototype.createBucket=function(t){return new Os(t)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e}(ri),Rs={paint:new ei({\"background-color\":new Jn(It.paint_background[\"background-color\"]),\"background-pattern\":new Qn(It.paint_background[\"background-pattern\"]),\"background-opacity\":new Jn(It.paint_background[\"background-opacity\"])})},Fs=function(t){function e(e){t.call(this,e,Rs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ri),Bs={paint:new ei({\"raster-opacity\":new Jn(It.paint_raster[\"raster-opacity\"]),\"raster-hue-rotate\":new Jn(It.paint_raster[\"raster-hue-rotate\"]),\"raster-brightness-min\":new Jn(It.paint_raster[\"raster-brightness-min\"]),\"raster-brightness-max\":new Jn(It.paint_raster[\"raster-brightness-max\"]),\"raster-saturation\":new Jn(It.paint_raster[\"raster-saturation\"]),\"raster-contrast\":new Jn(It.paint_raster[\"raster-contrast\"]),\"raster-resampling\":new Jn(It.paint_raster[\"raster-resampling\"]),\"raster-fade-duration\":new Jn(It.paint_raster[\"raster-fade-duration\"])})},Ns=function(t){function e(e){t.call(this,e,Bs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ri),js=function(t){function e(e){t.call(this,e,{}),this.implementation=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.is3D=function(){return\"3d\"===this.implementation.renderingMode},e.prototype.hasOffscreenPass=function(){return void 0!==this.implementation.prerender},e.prototype.recalculate=function(){},e.prototype.updateTransitions=function(){},e.prototype.hasTransition=function(){},e.prototype.serialize=function(){},e.prototype.onAdd=function(t){this.implementation.onAdd&&this.implementation.onAdd(t,t.painter.context.gl)},e.prototype.onRemove=function(t){this.implementation.onRemove&&this.implementation.onRemove(t,t.painter.context.gl)},e}(ri),Us={circle:Fa,heatmap:Wa,hillshade:Za,fill:Oo,\"fill-extrusion\":Jo,line:hs,symbol:Ds,background:Fs,raster:Ns};function Vs(t){for(var e=0,r=0,n=0,i=t;n<i.length;n+=1){var a=i[n];e+=a.w*a.h,r=Math.max(r,a.w)}t.sort(function(t,e){return e.h-t.h});for(var o=[{x:0,y:0,w:Math.max(Math.ceil(Math.sqrt(e/.95)),r),h:1/0}],s=0,l=0,c=0,u=t;c<u.length;c+=1)for(var h=u[c],f=o.length-1;f>=0;f--){var p=o[f];if(!(h.w>p.w||h.h>p.h)){if(h.x=p.x,h.y=p.y,l=Math.max(l,h.y+h.h),s=Math.max(s,h.x+h.w),h.w===p.w&&h.h===p.h){var d=o.pop();f<o.length&&(o[f]=d)}else h.h===p.h?(p.x+=h.w,p.w-=h.w):h.w===p.w?(p.y+=h.h,p.h-=h.h):(o.push({x:p.x+h.w,y:p.y,w:p.w-h.w,h:h.h}),p.y+=h.h,p.h-=h.h);break}}return{w:s,h:l,fill:e/(s*l)||0}}var qs=function(t,e){var r=e.pixelRatio,n=e.version;this.paddedRect=t,this.pixelRatio=r,this.version=n},Hs={tl:{configurable:!0},br:{configurable:!0},tlbr:{configurable:!0},displaySize:{configurable:!0}};Hs.tl.get=function(){return[this.paddedRect.x+1,this.paddedRect.y+1]},Hs.br.get=function(){return[this.paddedRect.x+this.paddedRect.w-1,this.paddedRect.y+this.paddedRect.h-1]},Hs.tlbr.get=function(){return this.tl.concat(this.br)},Hs.displaySize.get=function(){return[(this.paddedRect.w-2)/this.pixelRatio,(this.paddedRect.h-2)/this.pixelRatio]},Object.defineProperties(qs.prototype,Hs);var Gs=function(t,e){var r={},n={};this.haveRenderCallbacks=[];var i=[];this.addImages(t,r,i),this.addImages(e,n,i);var a=Vs(i),o=a.w,s=a.h,l=new Ha({width:o||1,height:s||1});for(var c in t){var u=t[c],h=r[c].paddedRect;Ha.copy(u.data,l,{x:0,y:0},{x:h.x+1,y:h.y+1},u.data)}for(var f in e){var p=e[f],d=n[f].paddedRect,g=d.x+1,v=d.y+1,m=p.data.width,y=p.data.height;Ha.copy(p.data,l,{x:0,y:0},{x:g,y:v},p.data),Ha.copy(p.data,l,{x:0,y:y-1},{x:g,y:v-1},{width:m,height:1}),Ha.copy(p.data,l,{x:0,y:0},{x:g,y:v+y},{width:m,height:1}),Ha.copy(p.data,l,{x:m-1,y:0},{x:g-1,y:v},{width:1,height:y}),Ha.copy(p.data,l,{x:0,y:0},{x:g+m,y:v},{width:1,height:y})}this.image=l,this.iconPositions=r,this.patternPositions=n};Gs.prototype.addImages=function(t,e,r){for(var n in t){var i=t[n],a={x:0,y:0,w:i.data.width+2,h:i.data.height+2};r.push(a),e[n]=new qs(a,i),i.hasRenderCallback&&this.haveRenderCallbacks.push(n)}},Gs.prototype.patchUpdatedImages=function(t,e){for(var r in t.dispatchRenderCallbacks(this.haveRenderCallbacks),t.updatedImages)this.patchUpdatedImage(this.iconPositions[r],t.getImage(r),e),this.patchUpdatedImage(this.patternPositions[r],t.getImage(r),e)},Gs.prototype.patchUpdatedImage=function(t,e,r){if(t&&e&&t.version!==e.version){t.version=e.version;var n=t.tl,i=n[0],a=n[1];r.update(e.data,void 0,{x:i,y:a})}},kn(\"ImagePosition\",qs),kn(\"ImageAtlas\",Gs);var Ys=self.HTMLImageElement,Ws=self.HTMLCanvasElement,Xs=self.HTMLVideoElement,Zs=self.ImageData,Js=function(t,e,r,n){this.context=t,this.format=r,this.texture=t.gl.createTexture(),this.update(e,n)};Js.prototype.update=function(t,e,r){var n=t.width,i=t.height,a=!(this.size&&this.size[0]===n&&this.size[1]===i||r),o=this.context,s=o.gl;if(this.useMipmap=Boolean(e&&e.useMipmap),s.bindTexture(s.TEXTURE_2D,this.texture),o.pixelStoreUnpackFlipY.set(!1),o.pixelStoreUnpack.set(1),o.pixelStoreUnpackPremultiplyAlpha.set(this.format===s.RGBA&&(!e||!1!==e.premultiply)),a)this.size=[n,i],t instanceof Ys||t instanceof Ws||t instanceof Xs||t instanceof Zs?s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,s.UNSIGNED_BYTE,t):s.texImage2D(s.TEXTURE_2D,0,this.format,n,i,0,this.format,s.UNSIGNED_BYTE,t.data);else{var l=r||{x:0,y:0},c=l.x,u=l.y;t instanceof Ys||t instanceof Ws||t instanceof Xs||t instanceof Zs?s.texSubImage2D(s.TEXTURE_2D,0,c,u,s.RGBA,s.UNSIGNED_BYTE,t):s.texSubImage2D(s.TEXTURE_2D,0,c,u,n,i,s.RGBA,s.UNSIGNED_BYTE,t.data)}this.useMipmap&&this.isSizePowerOfTwo()&&s.generateMipmap(s.TEXTURE_2D)},Js.prototype.bind=function(t,e,r){var n=this.context.gl;n.bindTexture(n.TEXTURE_2D,this.texture),r!==n.LINEAR_MIPMAP_NEAREST||this.isSizePowerOfTwo()||(r=n.LINEAR),t!==this.filter&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,t),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,r||t),this.filter=t),e!==this.wrap&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,e),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,e),this.wrap=e)},Js.prototype.isSizePowerOfTwo=function(){return this.size[0]===this.size[1]&&Math.log(this.size[0])/Math.LN2%1==0},Js.prototype.destroy=function(){this.context.gl.deleteTexture(this.texture),this.texture=null};var Ks=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?i-1:0,f=r?-1:1,p=t[e+h];for(h+=f,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+h],h+=f,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},$s=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,h=u>>1,f=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,i),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g},Qs=tl;function tl(t){this.buf=ArrayBuffer.isView&&ArrayBuffer.isView(t)?t:new Uint8Array(t||0),this.pos=0,this.type=0,this.length=this.buf.length}function el(t){return t.type===tl.Bytes?t.readVarint()+t.pos:t.pos+1}function rl(t,e,r){return r?4294967296*e+(t>>>0):4294967296*(e>>>0)+(t>>>0)}function nl(t,e,r){var n=e<=16383?1:e<=2097151?2:e<=268435455?3:Math.floor(Math.log(e)/(7*Math.LN2));r.realloc(n);for(var i=r.pos-1;i>=t;i--)r.buf[i+n]=r.buf[i]}function il(t,e){for(var r=0;r<t.length;r++)e.writeVarint(t[r])}function al(t,e){for(var r=0;r<t.length;r++)e.writeSVarint(t[r])}function ol(t,e){for(var r=0;r<t.length;r++)e.writeFloat(t[r])}function sl(t,e){for(var r=0;r<t.length;r++)e.writeDouble(t[r])}function ll(t,e){for(var r=0;r<t.length;r++)e.writeBoolean(t[r])}function cl(t,e){for(var r=0;r<t.length;r++)e.writeFixed32(t[r])}function ul(t,e){for(var r=0;r<t.length;r++)e.writeSFixed32(t[r])}function hl(t,e){for(var r=0;r<t.length;r++)e.writeFixed64(t[r])}function fl(t,e){for(var r=0;r<t.length;r++)e.writeSFixed64(t[r])}function pl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+16777216*t[e+3]}function dl(t,e,r){t[r]=e,t[r+1]=e>>>8,t[r+2]=e>>>16,t[r+3]=e>>>24}function gl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+(t[e+3]<<24)}tl.Varint=0,tl.Fixed64=1,tl.Bytes=2,tl.Fixed32=5,tl.prototype={destroy:function(){this.buf=null},readFields:function(t,e,r){for(r=r||this.length;this.pos<r;){var n=this.readVarint(),i=n>>3,a=this.pos;this.type=7&n,t(i,e,this),this.pos===a&&this.skip(n)}return e},readMessage:function(t,e){return this.readFields(t,e,this.readVarint()+this.pos)},readFixed32:function(){var t=pl(this.buf,this.pos);return this.pos+=4,t},readSFixed32:function(){var t=gl(this.buf,this.pos);return this.pos+=4,t},readFixed64:function(){var t=pl(this.buf,this.pos)+4294967296*pl(this.buf,this.pos+4);return this.pos+=8,t},readSFixed64:function(){var t=pl(this.buf,this.pos)+4294967296*gl(this.buf,this.pos+4);return this.pos+=8,t},readFloat:function(){var t=Ks(this.buf,this.pos,!0,23,4);return this.pos+=4,t},readDouble:function(){var t=Ks(this.buf,this.pos,!0,52,8);return this.pos+=8,t},readVarint:function(t){var e,r,n=this.buf;return e=127&(r=n[this.pos++]),r<128?e:(e|=(127&(r=n[this.pos++]))<<7,r<128?e:(e|=(127&(r=n[this.pos++]))<<14,r<128?e:(e|=(127&(r=n[this.pos++]))<<21,r<128?e:function(t,e,r){var n,i,a=r.buf;if(n=(112&(i=a[r.pos++]))>>4,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<3,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<10,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<17,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<24,i<128)return rl(t,n,e);if(n|=(1&(i=a[r.pos++]))<<31,i<128)return rl(t,n,e);throw new Error(\"Expected varint not more than 10 bytes\")}(e|=(15&(r=n[this.pos]))<<28,t,this))))},readVarint64:function(){return this.readVarint(!0)},readSVarint:function(){var t=this.readVarint();return t%2==1?(t+1)/-2:t/2},readBoolean:function(){return Boolean(this.readVarint())},readString:function(){var t=this.readVarint()+this.pos,e=function(t,e,r){for(var n=\"\",i=e;i<r;){var a,o,s,l=t[i],c=null,u=l>239?4:l>223?3:l>191?2:1;if(i+u>r)break;1===u?l<128&&(c=l):2===u?128==(192&(a=t[i+1]))&&(c=(31&l)<<6|63&a)<=127&&(c=null):3===u?(a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&((c=(15&l)<<12|(63&a)<<6|63&o)<=2047||c>=55296&&c<=57343)&&(c=null)):4===u&&(a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&((c=(15&l)<<18|(63&a)<<12|(63&o)<<6|63&s)<=65535||c>=1114112)&&(c=null)),null===c?(c=65533,u=1):c>65535&&(c-=65536,n+=String.fromCharCode(c>>>10&1023|55296),c=56320|1023&c),n+=String.fromCharCode(c),i+=u}return n}(this.buf,this.pos,t);return this.pos=t,e},readBytes:function(){var t=this.readVarint()+this.pos,e=this.buf.subarray(this.pos,t);return this.pos=t,e},readPackedVarint:function(t,e){if(this.type!==tl.Bytes)return t.push(this.readVarint(e));var r=el(this);for(t=t||[];this.pos<r;)t.push(this.readVarint(e));return t},readPackedSVarint:function(t){if(this.type!==tl.Bytes)return t.push(this.readSVarint());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSVarint());return t},readPackedBoolean:function(t){if(this.type!==tl.Bytes)return t.push(this.readBoolean());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readBoolean());return t},readPackedFloat:function(t){if(this.type!==tl.Bytes)return t.push(this.readFloat());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFloat());return t},readPackedDouble:function(t){if(this.type!==tl.Bytes)return t.push(this.readDouble());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readDouble());return t},readPackedFixed32:function(t){if(this.type!==tl.Bytes)return t.push(this.readFixed32());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFixed32());return t},readPackedSFixed32:function(t){if(this.type!==tl.Bytes)return t.push(this.readSFixed32());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed32());return t},readPackedFixed64:function(t){if(this.type!==tl.Bytes)return t.push(this.readFixed64());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFixed64());return t},readPackedSFixed64:function(t){if(this.type!==tl.Bytes)return t.push(this.readSFixed64());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed64());return t},skip:function(t){var e=7&t;if(e===tl.Varint)for(;this.buf[this.pos++]>127;);else if(e===tl.Bytes)this.pos=this.readVarint()+this.pos;else if(e===tl.Fixed32)this.pos+=4;else{if(e!==tl.Fixed64)throw new Error(\"Unimplemented type: \"+e);this.pos+=8}},writeTag:function(t,e){this.writeVarint(t<<3|e)},realloc:function(t){for(var e=this.length||16;e<this.pos+t;)e*=2;if(e!==this.length){var r=new Uint8Array(e);r.set(this.buf),this.buf=r,this.length=e}},finish:function(){return this.length=this.pos,this.pos=0,this.buf.subarray(0,this.length)},writeFixed32:function(t){this.realloc(4),dl(this.buf,t,this.pos),this.pos+=4},writeSFixed32:function(t){this.realloc(4),dl(this.buf,t,this.pos),this.pos+=4},writeFixed64:function(t){this.realloc(8),dl(this.buf,-1&t,this.pos),dl(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeSFixed64:function(t){this.realloc(8),dl(this.buf,-1&t,this.pos),dl(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeVarint:function(t){(t=+t||0)>268435455||t<0?function(t,e){var r,n;if(t>=0?(r=t%4294967296|0,n=t/4294967296|0):(n=~(-t/4294967296),4294967295^(r=~(-t%4294967296))?r=r+1|0:(r=0,n=n+1|0)),t>=0x10000000000000000||t<-0x10000000000000000)throw new Error(\"Given varint doesn't fit into 10 bytes\");e.realloc(10),function(t,e,r){r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos]=127&t}(r,0,e),function(t,e){var r=(7&t)<<4;e.buf[e.pos++]|=r|((t>>>=3)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t)))))}(n,e)}(t,this):(this.realloc(4),this.buf[this.pos++]=127&t|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=t>>>7&127))))},writeSVarint:function(t){this.writeVarint(t<0?2*-t-1:2*t)},writeBoolean:function(t){this.writeVarint(Boolean(t))},writeString:function(t){t=String(t),this.realloc(4*t.length),this.pos++;var e=this.pos;this.pos=function(t,e,r){for(var n,i,a=0;a<e.length;a++){if((n=e.charCodeAt(a))>55295&&n<57344){if(!i){n>56319||a+1===e.length?(t[r++]=239,t[r++]=191,t[r++]=189):i=n;continue}if(n<56320){t[r++]=239,t[r++]=191,t[r++]=189,i=n;continue}n=i-55296<<10|n-56320|65536,i=null}else i&&(t[r++]=239,t[r++]=191,t[r++]=189,i=null);n<128?t[r++]=n:(n<2048?t[r++]=n>>6|192:(n<65536?t[r++]=n>>12|224:(t[r++]=n>>18|240,t[r++]=n>>12&63|128),t[r++]=n>>6&63|128),t[r++]=63&n|128)}return r}(this.buf,t,this.pos);var r=this.pos-e;r>=128&&nl(e,r,this),this.pos=e-1,this.writeVarint(r),this.pos+=r},writeFloat:function(t){this.realloc(4),$s(this.buf,t,this.pos,!0,23,4),this.pos+=4},writeDouble:function(t){this.realloc(8),$s(this.buf,t,this.pos,!0,52,8),this.pos+=8},writeBytes:function(t){var e=t.length;this.writeVarint(e),this.realloc(e);for(var r=0;r<e;r++)this.buf[this.pos++]=t[r]},writeRawMessage:function(t,e){this.pos++;var r=this.pos;t(e,this);var n=this.pos-r;n>=128&&nl(r,n,this),this.pos=r-1,this.writeVarint(n),this.pos+=n},writeMessage:function(t,e,r){this.writeTag(t,tl.Bytes),this.writeRawMessage(e,r)},writePackedVarint:function(t,e){e.length&&this.writeMessage(t,il,e)},writePackedSVarint:function(t,e){e.length&&this.writeMessage(t,al,e)},writePackedBoolean:function(t,e){e.length&&this.writeMessage(t,ll,e)},writePackedFloat:function(t,e){e.length&&this.writeMessage(t,ol,e)},writePackedDouble:function(t,e){e.length&&this.writeMessage(t,sl,e)},writePackedFixed32:function(t,e){e.length&&this.writeMessage(t,cl,e)},writePackedSFixed32:function(t,e){e.length&&this.writeMessage(t,ul,e)},writePackedFixed64:function(t,e){e.length&&this.writeMessage(t,hl,e)},writePackedSFixed64:function(t,e){e.length&&this.writeMessage(t,fl,e)},writeBytesField:function(t,e){this.writeTag(t,tl.Bytes),this.writeBytes(e)},writeFixed32Field:function(t,e){this.writeTag(t,tl.Fixed32),this.writeFixed32(e)},writeSFixed32Field:function(t,e){this.writeTag(t,tl.Fixed32),this.writeSFixed32(e)},writeFixed64Field:function(t,e){this.writeTag(t,tl.Fixed64),this.writeFixed64(e)},writeSFixed64Field:function(t,e){this.writeTag(t,tl.Fixed64),this.writeSFixed64(e)},writeVarintField:function(t,e){this.writeTag(t,tl.Varint),this.writeVarint(e)},writeSVarintField:function(t,e){this.writeTag(t,tl.Varint),this.writeSVarint(e)},writeStringField:function(t,e){this.writeTag(t,tl.Bytes),this.writeString(e)},writeFloatField:function(t,e){this.writeTag(t,tl.Fixed32),this.writeFloat(e)},writeDoubleField:function(t,e){this.writeTag(t,tl.Fixed64),this.writeDouble(e)},writeBooleanField:function(t,e){this.writeVarintField(t,Boolean(e))}};var vl=3;function ml(t,e,r){1===t&&r.readMessage(yl,e)}function yl(t,e,r){if(3===t){var n=r.readMessage(xl,{}),i=n.id,a=n.bitmap,o=n.width,s=n.height,l=n.left,c=n.top,u=n.advance;e.push({id:i,bitmap:new qa({width:o+2*vl,height:s+2*vl},a),metrics:{width:o,height:s,left:l,top:c,advance:u}})}}function xl(t,e,r){1===t?e.id=r.readVarint():2===t?e.bitmap=r.readBytes():3===t?e.width=r.readVarint():4===t?e.height=r.readVarint():5===t?e.left=r.readSVarint():6===t?e.top=r.readSVarint():7===t&&(e.advance=r.readVarint())}var bl=vl,_l=function(t,e,r){this.target=t,this.parent=e,this.mapId=r,this.callbacks={},this.callbackID=0,v([\"receive\"],this),this.target.addEventListener(\"message\",this.receive,!1)};function wl(t,e,r){var n=2*Math.PI*6378137/256/Math.pow(2,r);return[t*n-2*Math.PI*6378137/2,e*n-2*Math.PI*6378137/2]}_l.prototype.send=function(t,e,r,n){var i=this,a=r?this.mapId+\":\"+this.callbackID++:null;r&&(this.callbacks[a]=r);var o=[];if(this.target.postMessage({targetMapId:n,sourceMapId:this.mapId,type:t,id:String(a),data:An(e,o)},o),r)return{cancel:function(){i.callbacks[a]=null,i.target.postMessage({targetMapId:n,sourceMapId:i.mapId,type:\"<cancel>\",id:String(a)})}}},_l.prototype.receive=function(t){var e,r=this,n=t.data,i=n.id;if(!n.targetMapId||this.mapId===n.targetMapId){var a=function(t,e){delete r.callbacks[i];var n=[];r.target.postMessage({sourceMapId:r.mapId,type:\"<response>\",id:String(i),error:t?An(t):null,data:An(e,n)},n)};if(\"<response>\"===n.type||\"<cancel>\"===n.type)e=this.callbacks[n.id],delete this.callbacks[n.id],e&&n.error?e(Mn(n.error)):e&&e(null,Mn(n.data));else if(void 0!==n.id&&this.parent[n.type]){this.callbacks[n.id]=null;var o=this.parent[n.type](n.sourceMapId,Mn(n.data),a);o&&null===this.callbacks[n.id]&&(this.callbacks[n.id]=o.cancel)}else if(void 0!==n.id&&this.parent.getWorkerSource){var s=n.type.split(\".\"),l=Mn(n.data);this.parent.getWorkerSource(n.sourceMapId,s[0],l.source)[s[1]](l,a)}else this.parent[n.type](Mn(n.data))}},_l.prototype.remove=function(){this.target.removeEventListener(\"message\",this.receive,!1)};var kl=function(t,e){t&&(e?this.setSouthWest(t).setNorthEast(e):4===t.length?this.setSouthWest([t[0],t[1]]).setNorthEast([t[2],t[3]]):this.setSouthWest(t[0]).setNorthEast(t[1]))};kl.prototype.setNorthEast=function(t){return this._ne=t instanceof Tl?new Tl(t.lng,t.lat):Tl.convert(t),this},kl.prototype.setSouthWest=function(t){return this._sw=t instanceof Tl?new Tl(t.lng,t.lat):Tl.convert(t),this},kl.prototype.extend=function(t){var e,r,n=this._sw,i=this._ne;if(t instanceof Tl)e=t,r=t;else{if(!(t instanceof kl))return Array.isArray(t)?t.every(Array.isArray)?this.extend(kl.convert(t)):this.extend(Tl.convert(t)):this;if(e=t._sw,r=t._ne,!e||!r)return this}return n||i?(n.lng=Math.min(e.lng,n.lng),n.lat=Math.min(e.lat,n.lat),i.lng=Math.max(r.lng,i.lng),i.lat=Math.max(r.lat,i.lat)):(this._sw=new Tl(e.lng,e.lat),this._ne=new Tl(r.lng,r.lat)),this},kl.prototype.getCenter=function(){return new Tl((this._sw.lng+this._ne.lng)/2,(this._sw.lat+this._ne.lat)/2)},kl.prototype.getSouthWest=function(){return this._sw},kl.prototype.getNorthEast=function(){return this._ne},kl.prototype.getNorthWest=function(){return new Tl(this.getWest(),this.getNorth())},kl.prototype.getSouthEast=function(){return new Tl(this.getEast(),this.getSouth())},kl.prototype.getWest=function(){return this._sw.lng},kl.prototype.getSouth=function(){return this._sw.lat},kl.prototype.getEast=function(){return this._ne.lng},kl.prototype.getNorth=function(){return this._ne.lat},kl.prototype.toArray=function(){return[this._sw.toArray(),this._ne.toArray()]},kl.prototype.toString=function(){return\"LngLatBounds(\"+this._sw.toString()+\", \"+this._ne.toString()+\")\"},kl.prototype.isEmpty=function(){return!(this._sw&&this._ne)},kl.convert=function(t){return!t||t instanceof kl?t:new kl(t)};var Tl=function(t,e){if(isNaN(t)||isNaN(e))throw new Error(\"Invalid LngLat object: (\"+t+\", \"+e+\")\");if(this.lng=+t,this.lat=+e,this.lat>90||this.lat<-90)throw new Error(\"Invalid LngLat latitude value: must be between -90 and 90\")};function Al(t){return 2*Math.PI*6378137*Math.cos(t*Math.PI/180)}function Ml(t){return(180+t)/360}function Sl(t){return(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+t*Math.PI/360)))/360}function El(t,e){return t/Al(e)}function Cl(t){var e=180-360*t;return 360/Math.PI*Math.atan(Math.exp(e*Math.PI/180))-90}Tl.prototype.wrap=function(){return new Tl(u(this.lng,-180,180),this.lat)},Tl.prototype.toArray=function(){return[this.lng,this.lat]},Tl.prototype.toString=function(){return\"LngLat(\"+this.lng+\", \"+this.lat+\")\"},Tl.prototype.toBounds=function(t){void 0===t&&(t=0);var e=360*t/40075017,r=e/Math.cos(Math.PI/180*this.lat);return new kl(new Tl(this.lng-r,this.lat-e),new Tl(this.lng+r,this.lat+e))},Tl.convert=function(t){if(t instanceof Tl)return t;if(Array.isArray(t)&&(2===t.length||3===t.length))return new Tl(Number(t[0]),Number(t[1]));if(!Array.isArray(t)&&\"object\"==typeof t&&null!==t)return new Tl(Number(\"lng\"in t?t.lng:t.lon),Number(t.lat));throw new Error(\"`LngLatLike` argument must be specified as a LngLat instance, an object {lng: <lng>, lat: <lat>}, an object {lon: <lng>, lat: <lat>}, or an array of [<lng>, <lat>]\")};var Ll=function(t,e,r){void 0===r&&(r=0),this.x=+t,this.y=+e,this.z=+r};Ll.fromLngLat=function(t,e){void 0===e&&(e=0);var r=Tl.convert(t);return new Ll(Ml(r.lng),Sl(r.lat),El(e,r.lat))},Ll.prototype.toLngLat=function(){return new Tl(360*this.x-180,Cl(this.y))},Ll.prototype.toAltitude=function(){return this.z*Al(Cl(this.y))};var Pl=function(t,e,r){this.z=t,this.x=e,this.y=r,this.key=Il(0,t,e,r)};Pl.prototype.equals=function(t){return this.z===t.z&&this.x===t.x&&this.y===t.y},Pl.prototype.url=function(t,e){var r,n,i,a,o,s=(r=this.x,n=this.y,i=this.z,a=wl(256*r,256*(n=Math.pow(2,i)-n-1),i),o=wl(256*(r+1),256*(n+1),i),a[0]+\",\"+a[1]+\",\"+o[0]+\",\"+o[1]),l=function(t,e,r){for(var n,i=\"\",a=t;a>0;a--)i+=(e&(n=1<<a-1)?1:0)+(r&n?2:0);return i}(this.z,this.x,this.y);return t[(this.x+this.y)%t.length].replace(\"{prefix}\",(this.x%16).toString(16)+(this.y%16).toString(16)).replace(\"{z}\",String(this.z)).replace(\"{x}\",String(this.x)).replace(\"{y}\",String(\"tms\"===e?Math.pow(2,this.z)-this.y-1:this.y)).replace(\"{quadkey}\",l).replace(\"{bbox-epsg-3857}\",s)},Pl.prototype.getTilePoint=function(t){var e=Math.pow(2,this.z);return new i((t.x*e-this.x)*ha,(t.y*e-this.y)*ha)};var Ol=function(t,e){this.wrap=t,this.canonical=e,this.key=Il(t,e.z,e.x,e.y)},zl=function(t,e,r,n,i){this.overscaledZ=t,this.wrap=e,this.canonical=new Pl(r,+n,+i),this.key=Il(e,t,n,i)};function Il(t,e,r,n){(t*=2)<0&&(t=-1*t-1);var i=1<<e;return 32*(i*i*t+i*n+r)+e}zl.prototype.equals=function(t){return this.overscaledZ===t.overscaledZ&&this.wrap===t.wrap&&this.canonical.equals(t.canonical)},zl.prototype.scaledTo=function(t){var e=this.canonical.z-t;return t>this.canonical.z?new zl(t,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y):new zl(t,this.wrap,t,this.canonical.x>>e,this.canonical.y>>e)},zl.prototype.isChildOf=function(t){if(t.wrap!==this.wrap)return!1;var e=this.canonical.z-t.canonical.z;return 0===t.overscaledZ||t.overscaledZ<this.overscaledZ&&t.canonical.x===this.canonical.x>>e&&t.canonical.y===this.canonical.y>>e},zl.prototype.children=function(t){if(this.overscaledZ>=t)return[new zl(this.overscaledZ+1,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y)];var e=this.canonical.z+1,r=2*this.canonical.x,n=2*this.canonical.y;return[new zl(e,this.wrap,e,r,n),new zl(e,this.wrap,e,r+1,n),new zl(e,this.wrap,e,r,n+1),new zl(e,this.wrap,e,r+1,n+1)]},zl.prototype.isLessThan=function(t){return this.wrap<t.wrap||!(this.wrap>t.wrap)&&(this.overscaledZ<t.overscaledZ||!(this.overscaledZ>t.overscaledZ)&&(this.canonical.x<t.canonical.x||!(this.canonical.x>t.canonical.x)&&this.canonical.y<t.canonical.y))},zl.prototype.wrapped=function(){return new zl(this.overscaledZ,0,this.canonical.z,this.canonical.x,this.canonical.y)},zl.prototype.unwrapTo=function(t){return new zl(this.overscaledZ,t,this.canonical.z,this.canonical.x,this.canonical.y)},zl.prototype.overscaleFactor=function(){return Math.pow(2,this.overscaledZ-this.canonical.z)},zl.prototype.toUnwrapped=function(){return new Ol(this.wrap,this.canonical)},zl.prototype.toString=function(){return this.overscaledZ+\"/\"+this.canonical.x+\"/\"+this.canonical.y},zl.prototype.getTilePoint=function(t){return this.canonical.getTilePoint(new Ll(t.x-this.wrap,t.y))},kn(\"CanonicalTileID\",Pl),kn(\"OverscaledTileID\",zl,{omit:[\"posMatrix\"]});var Dl=function(t,e,r){if(this.uid=t,e.height!==e.width)throw new RangeError(\"DEM tiles must be square\");if(r&&\"mapbox\"!==r&&\"terrarium\"!==r)return w('\"'+r+'\" is not a valid encoding type. Valid types include \"mapbox\" and \"terrarium\".');var n=this.dim=e.height;this.stride=this.dim+2,this.data=new Int32Array(this.stride*this.stride);for(var i=e.data,a=\"terrarium\"===r?this._unpackTerrarium:this._unpackMapbox,o=0;o<n;o++)for(var s=0;s<n;s++){var l=4*(o*n+s);this.set(s,o,a(i[l],i[l+1],i[l+2]))}for(var c=0;c<n;c++)this.set(-1,c,this.get(0,c)),this.set(n,c,this.get(n-1,c)),this.set(c,-1,this.get(c,0)),this.set(c,n,this.get(c,n-1));this.set(-1,-1,this.get(0,0)),this.set(n,-1,this.get(n-1,0)),this.set(-1,n,this.get(0,n-1)),this.set(n,n,this.get(n-1,n-1))};Dl.prototype.set=function(t,e,r){this.data[this._idx(t,e)]=r+65536},Dl.prototype.get=function(t,e){return this.data[this._idx(t,e)]-65536},Dl.prototype._idx=function(t,e){if(t<-1||t>=this.dim+1||e<-1||e>=this.dim+1)throw new RangeError(\"out of range source coordinates for DEM data\");return(e+1)*this.stride+(t+1)},Dl.prototype._unpackMapbox=function(t,e,r){return(256*t*256+256*e+r)/10-1e4},Dl.prototype._unpackTerrarium=function(t,e,r){return 256*t+e+r/256-32768},Dl.prototype.getPixels=function(){return new Ha({width:this.stride,height:this.stride},new Uint8Array(this.data.buffer))},Dl.prototype.backfillBorder=function(t,e,r){if(this.dim!==t.dim)throw new Error(\"dem dimension mismatch\");var n=e*this.dim,i=e*this.dim+this.dim,a=r*this.dim,o=r*this.dim+this.dim;switch(e){case-1:n=i-1;break;case 1:i=n+1}switch(r){case-1:a=o-1;break;case 1:o=a+1}for(var s=-e*this.dim,l=-r*this.dim,c=a;c<o;c++)for(var u=n;u<i;u++)this.set(u,c,t.get(u+s,c+l))},kn(\"DEMData\",Dl);var Rl=oi([{name:\"a_pos\",type:\"Int16\",components:2},{name:\"a_texture_pos\",type:\"Int16\",components:2}]),Fl=function(t){this._stringToNumber={},this._numberToString=[];for(var e=0;e<t.length;e++){var r=t[e];this._stringToNumber[r]=e,this._numberToString[e]=r}};Fl.prototype.encode=function(t){return this._stringToNumber[t]},Fl.prototype.decode=function(t){return this._numberToString[t]};var Bl=function(t,e,r,n){this.type=\"Feature\",this._vectorTileFeature=t,t._z=e,t._x=r,t._y=n,this.properties=t.properties,null!=t.id&&(this.id=t.id)},Nl={geometry:{configurable:!0}};Nl.geometry.get=function(){return void 0===this._geometry&&(this._geometry=this._vectorTileFeature.toGeoJSON(this._vectorTileFeature._x,this._vectorTileFeature._y,this._vectorTileFeature._z).geometry),this._geometry},Nl.geometry.set=function(t){this._geometry=t},Bl.prototype.toJSON=function(){var t={geometry:this.geometry};for(var e in this)\"_geometry\"!==e&&\"_vectorTileFeature\"!==e&&(t[e]=this[e]);return t},Object.defineProperties(Bl.prototype,Nl);var jl=function(){this.state={},this.stateChanges={},this.deletedStates={}};jl.prototype.updateState=function(t,e,r){var n=String(e);if(this.stateChanges[t]=this.stateChanges[t]||{},this.stateChanges[t][n]=this.stateChanges[t][n]||{},h(this.stateChanges[t][n],r),null===this.deletedStates[t])for(var i in this.deletedStates[t]={},this.state[t])i!==n&&(this.deletedStates[t][i]=null);else if(this.deletedStates[t]&&null===this.deletedStates[t][n])for(var a in this.deletedStates[t][n]={},this.state[t][n])r[a]||(this.deletedStates[t][n][a]=null);else for(var o in r)this.deletedStates[t]&&this.deletedStates[t][n]&&null===this.deletedStates[t][n][o]&&delete this.deletedStates[t][n][o]},jl.prototype.removeFeatureState=function(t,e,r){if(null!==this.deletedStates[t]){var n=String(e);if(this.deletedStates[t]=this.deletedStates[t]||{},r&&void 0!==e&&e>=0)null!==this.deletedStates[t][n]&&(this.deletedStates[t][n]=this.deletedStates[t][n]||{},this.deletedStates[t][n][r]=null);else if(void 0!==e&&e>=0)if(this.stateChanges[t]&&this.stateChanges[t][n])for(r in this.deletedStates[t][n]={},this.stateChanges[t][n])this.deletedStates[t][n][r]=null;else this.deletedStates[t][n]=null;else this.deletedStates[t]=null}},jl.prototype.getState=function(t,e){var r=String(e),n=this.state[t]||{},i=this.stateChanges[t]||{},a=h({},n[r],i[r]);if(null===this.deletedStates[t])return{};if(this.deletedStates[t]){var o=this.deletedStates[t][e];if(null===o)return{};for(var s in o)delete a[s]}return a},jl.prototype.initializeTileState=function(t,e){t.setFeatureState(this.state,e)},jl.prototype.coalesceChanges=function(t,e){var r={};for(var n in this.stateChanges){this.state[n]=this.state[n]||{};var i={};for(var a in this.stateChanges[n])this.state[n][a]||(this.state[n][a]={}),h(this.state[n][a],this.stateChanges[n][a]),i[a]=this.state[n][a];r[n]=i}for(var o in this.deletedStates){this.state[o]=this.state[o]||{};var s={};if(null===this.deletedStates[o])for(var l in this.state[o])s[l]={},this.state[o][l]={};else for(var c in this.deletedStates[o]){if(null===this.deletedStates[o][c])this.state[o][c]={};else for(var u=0,f=Object.keys(this.deletedStates[o][c]);u<f.length;u+=1){var p=f[u];delete this.state[o][c][p]}s[c]=this.state[o][c]}r[o]=r[o]||{},h(r[o],s)}if(this.stateChanges={},this.deletedStates={},0!==Object.keys(r).length)for(var d in t)t[d].setFeatureState(r,e)};var Ul=function(t,e,r){this.tileID=t,this.x=t.canonical.x,this.y=t.canonical.y,this.z=t.canonical.z,this.grid=e||new yn(ha,16,0),this.grid3D=new yn(ha,16,0),this.featureIndexArray=r||new ji};function Vl(t){for(var e=1/0,r=1/0,n=-1/0,i=-1/0,a=0,o=t;a<o.length;a+=1){var s=o[a];e=Math.min(e,s.x),r=Math.min(r,s.y),n=Math.max(n,s.x),i=Math.max(i,s.y)}return{minX:e,minY:r,maxX:n,maxY:i}}function ql(t,e){return e-t}Ul.prototype.insert=function(t,e,r,n,i,a){var o=this.featureIndexArray.length;this.featureIndexArray.emplaceBack(r,n,i);for(var s=a?this.grid3D:this.grid,l=0;l<e.length;l++){for(var c=e[l],u=[1/0,1/0,-1/0,-1/0],h=0;h<c.length;h++){var f=c[h];u[0]=Math.min(u[0],f.x),u[1]=Math.min(u[1],f.y),u[2]=Math.max(u[2],f.x),u[3]=Math.max(u[3],f.y)}u[0]<ha&&u[1]<ha&&u[2]>=0&&u[3]>=0&&s.insert(o,u[0],u[1],u[2],u[3])}},Ul.prototype.loadVTLayers=function(){return this.vtLayers||(this.vtLayers=new Vo.VectorTile(new Qs(this.rawTileData)).layers,this.sourceLayerCoder=new Fl(this.vtLayers?Object.keys(this.vtLayers).sort():[\"_geojsonTileLayer\"])),this.vtLayers},Ul.prototype.query=function(t,e,r){var n=this;this.loadVTLayers();for(var a=t.params||{},o=ha/t.tileSize/t.scale,s=Gr(a.filter),l=t.queryGeometry,c=t.queryPadding*o,u=Vl(l),h=this.grid.query(u.minX-c,u.minY-c,u.maxX+c,u.maxY+c),f=Vl(t.cameraQueryGeometry),p=0,d=this.grid3D.query(f.minX-c,f.minY-c,f.maxX+c,f.maxY+c,function(e,r,n,a){return function(t,e,r,n,a){for(var o=0,s=t;o<s.length;o+=1){var l=s[o];if(e<=l.x&&r<=l.y&&n>=l.x&&a>=l.y)return!0}var c=[new i(e,r),new i(e,a),new i(n,a),new i(n,r)];if(t.length>2)for(var u=0,h=c;u<h.length;u+=1)if(Aa(t,h[u]))return!0;for(var f=0;f<t.length-1;f++)if(Ma(t[f],t[f+1],c))return!0;return!1}(t.cameraQueryGeometry,e-c,r-c,n+c,a+c)});p<d.length;p+=1){var g=d[p];h.push(g)}h.sort(ql);for(var v,m={},y=function(i){var c=h[i];if(c!==v){v=c;var u=n.featureIndexArray.get(c),f=null;n.loadMatchingFeature(m,u.bucketIndex,u.sourceLayerIndex,u.featureIndex,s,a.layers,e,function(e,i){f||(f=pa(e));var a={};return e.id&&(a=r.getState(i.sourceLayer||\"_geojsonTileLayer\",e.id)),i.queryIntersectsFeature(l,e,a,f,n.z,t.transform,o,t.pixelPosMatrix)})}},x=0;x<h.length;x++)y(x);return m},Ul.prototype.loadMatchingFeature=function(t,e,r,n,i,a,o,s){var l=this.bucketLayerIDs[e];if(!a||function(t,e){for(var r=0;r<t.length;r++)if(e.indexOf(t[r])>=0)return!0;return!1}(a,l)){var c=this.sourceLayerCoder.decode(r),u=this.vtLayers[c].feature(n);if(i(new Un(this.tileID.overscaledZ),u))for(var h=0;h<l.length;h++){var f=l[h];if(!(a&&a.indexOf(f)<0)){var p=o[f];if(p){var d=!s||s(u,p);if(d){var g=new Bl(u,this.z,this.x,this.y);g.layer=p.serialize();var v=t[f];void 0===v&&(v=t[f]=[]),v.push({featureIndex:n,feature:g,intersectionZ:d})}}}}}},Ul.prototype.lookupSymbolFeatures=function(t,e,r,n,i,a){var o={};this.loadVTLayers();for(var s=Gr(n),l=0,c=t;l<c.length;l+=1){var u=c[l];this.loadMatchingFeature(o,e,r,u,s,i,a)}return o},Ul.prototype.hasLayer=function(t){for(var e=0,r=this.bucketLayerIDs;e<r.length;e+=1)for(var n=0,i=r[e];n<i.length;n+=1)if(t===i[n])return!0;return!1},kn(\"FeatureIndex\",Ul,{omit:[\"rawTileData\",\"sourceLayerCoder\"]});var Hl=function(t,e){this.tileID=t,this.uid=p(),this.uses=0,this.tileSize=e,this.buckets={},this.expirationTime=null,this.queryPadding=0,this.hasSymbolBuckets=!1,this.expiredRequestCount=0,this.state=\"loading\"};Hl.prototype.registerFadeDuration=function(t){var e=t+this.timeAdded;e<z.now()||this.fadeEndTime&&e<this.fadeEndTime||(this.fadeEndTime=e)},Hl.prototype.wasRequested=function(){return\"errored\"===this.state||\"loaded\"===this.state||\"reloading\"===this.state},Hl.prototype.loadVectorData=function(t,e,r){if(this.hasData()&&this.unloadVectorData(),this.state=\"loaded\",t){for(var n in t.featureIndex&&(this.latestFeatureIndex=t.featureIndex,t.rawTileData?(this.latestRawTileData=t.rawTileData,this.latestFeatureIndex.rawTileData=t.rawTileData):this.latestRawTileData&&(this.latestFeatureIndex.rawTileData=this.latestRawTileData)),this.collisionBoxArray=t.collisionBoxArray,this.buckets=function(t,e){var r={};if(!e)return r;for(var n=function(){var t=a[i],n=t.layerIds.map(function(t){return e.getLayer(t)}).filter(Boolean);if(0!==n.length){t.layers=n,t.stateDependentLayerIds&&(t.stateDependentLayers=t.stateDependentLayerIds.map(function(t){return n.filter(function(e){return e.id===t})[0]}));for(var o=0,s=n;o<s.length;o+=1){var l=s[o];r[l.id]=t}}},i=0,a=t;i<a.length;i+=1)n();return r}(t.buckets,e.style),this.hasSymbolBuckets=!1,this.buckets){var i=this.buckets[n];if(i instanceof Os){if(this.hasSymbolBuckets=!0,!r)break;i.justReloaded=!0}}for(var a in this.queryPadding=0,this.buckets){var o=this.buckets[a];this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(a).queryRadius(o))}t.imageAtlas&&(this.imageAtlas=t.imageAtlas),t.glyphAtlasImage&&(this.glyphAtlasImage=t.glyphAtlasImage)}else this.collisionBoxArray=new Li},Hl.prototype.unloadVectorData=function(){for(var t in this.buckets)this.buckets[t].destroy();this.buckets={},this.imageAtlasTexture&&this.imageAtlasTexture.destroy(),this.imageAtlas&&(this.imageAtlas=null),this.glyphAtlasTexture&&this.glyphAtlasTexture.destroy(),this.latestFeatureIndex=null,this.state=\"unloaded\"},Hl.prototype.unloadDEMData=function(){this.dem=null,this.neighboringTiles=null,this.state=\"unloaded\"},Hl.prototype.getBucket=function(t){return this.buckets[t.id]},Hl.prototype.upload=function(t){for(var e in this.buckets){var r=this.buckets[e];r.uploadPending()&&r.upload(t)}var n=t.gl;this.imageAtlas&&!this.imageAtlas.uploaded&&(this.imageAtlasTexture=new Js(t,this.imageAtlas.image,n.RGBA),this.imageAtlas.uploaded=!0),this.glyphAtlasImage&&(this.glyphAtlasTexture=new Js(t,this.glyphAtlasImage,n.ALPHA),this.glyphAtlasImage=null)},Hl.prototype.prepare=function(t){this.imageAtlas&&this.imageAtlas.patchUpdatedImages(t,this.imageAtlasTexture)},Hl.prototype.queryRenderedFeatures=function(t,e,r,n,i,a,o,s,l){return this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData?this.latestFeatureIndex.query({queryGeometry:r,cameraQueryGeometry:n,scale:i,tileSize:this.tileSize,pixelPosMatrix:l,transform:o,params:a,queryPadding:this.queryPadding*s},t,e):{}},Hl.prototype.querySourceFeatures=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData){var r=this.latestFeatureIndex.loadVTLayers(),n=e?e.sourceLayer:\"\",i=r._geojsonTileLayer||r[n];if(i)for(var a=Gr(e&&e.filter),o=this.tileID.canonical,s=o.z,l=o.x,c=o.y,u={z:s,x:l,y:c},h=0;h<i.length;h++){var f=i.feature(h);if(a(new Un(this.tileID.overscaledZ),f)){var p=new Bl(f,s,l,c);p.tile=u,t.push(p)}}}},Hl.prototype.clearMask=function(){this.segments&&(this.segments.destroy(),delete this.segments),this.maskedBoundsBuffer&&(this.maskedBoundsBuffer.destroy(),delete this.maskedBoundsBuffer),this.maskedIndexBuffer&&(this.maskedIndexBuffer.destroy(),delete this.maskedIndexBuffer)},Hl.prototype.setMask=function(t,e){if(!o(this.mask,t)&&(this.mask=t,this.clearMask(),!o(t,{0:!0}))){var r=new ci,n=new Ti;this.segments=new Vi,this.segments.prepareSegment(0,r,n);for(var a=Object.keys(t),s=0;s<a.length;s++){var l=t[+a[s]],c=ha>>l.z,u=new i(l.x*c,l.y*c),h=new i(u.x+c,u.y+c),f=this.segments.prepareSegment(4,r,n);r.emplaceBack(u.x,u.y,u.x,u.y),r.emplaceBack(h.x,u.y,h.x,u.y),r.emplaceBack(u.x,h.y,u.x,h.y),r.emplaceBack(h.x,h.y,h.x,h.y);var p=f.vertexLength;n.emplaceBack(p,p+1,p+2),n.emplaceBack(p+1,p+2,p+3),f.vertexLength+=4,f.primitiveLength+=2}this.maskedBoundsBuffer=e.createVertexBuffer(r,Rl.members),this.maskedIndexBuffer=e.createIndexBuffer(n)}},Hl.prototype.hasData=function(){return\"loaded\"===this.state||\"reloading\"===this.state||\"expired\"===this.state},Hl.prototype.patternsLoaded=function(){return this.imageAtlas&&!!Object.keys(this.imageAtlas.patternPositions).length},Hl.prototype.setExpiryData=function(t){var e=this.expirationTime;if(t.cacheControl){var r=A(t.cacheControl);r[\"max-age\"]&&(this.expirationTime=Date.now()+1e3*r[\"max-age\"])}else t.expires&&(this.expirationTime=new Date(t.expires).getTime());if(this.expirationTime){var n=Date.now(),i=!1;if(this.expirationTime>n)i=!1;else if(e)if(this.expirationTime<e)i=!0;else{var a=this.expirationTime-e;a?this.expirationTime=n+Math.max(a,3e4):i=!0}else i=!0;i?(this.expiredRequestCount++,this.state=\"expired\"):this.expiredRequestCount=0}},Hl.prototype.getExpiryTimeout=function(){if(this.expirationTime)return this.expiredRequestCount?1e3*(1<<Math.min(this.expiredRequestCount-1,31)):Math.min(this.expirationTime-(new Date).getTime(),Math.pow(2,31)-1)},Hl.prototype.setFeatureState=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData&&0!==Object.keys(t).length){var r=this.latestFeatureIndex.loadVTLayers();for(var n in this.buckets){var i=this.buckets[n],a=i.layers[0].sourceLayer||\"_geojsonTileLayer\",o=r[a],s=t[a];o&&s&&0!==Object.keys(s).length&&(i.update(s,o,this.imageAtlas&&this.imageAtlas.patternPositions||{}),e&&e.style&&(this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(n).queryRadius(i))))}}},Hl.prototype.holdingForFade=function(){return void 0!==this.symbolFadeHoldUntil},Hl.prototype.symbolFadeFinished=function(){return!this.symbolFadeHoldUntil||this.symbolFadeHoldUntil<z.now()},Hl.prototype.clearFadeHold=function(){this.symbolFadeHoldUntil=void 0},Hl.prototype.setHoldDuration=function(t){this.symbolFadeHoldUntil=z.now()+t};var Gl=24,Yl={horizontal:1,vertical:2,horizontalOnly:3},Wl=function(){this.text=\"\",this.sectionIndex=[],this.sections=[]};function Xl(t,e,r,n,i,a,o,s,l,c){var u,h=Wl.fromFeature(t,r);c===Yl.vertical&&h.verticalizePunctuation();var f=jn.processBidirectionalText,p=jn.processStyledBidirectionalText;if(f&&1===h.sections.length){u=[];for(var d=0,g=f(h.toString(),tc(h,s,n,e));d<g.length;d+=1){var v=g[d],m=new Wl;m.text=v,m.sections=h.sections;for(var y=0;y<v.length;y++)m.sectionIndex.push(0);u.push(m)}}else if(p){u=[];for(var x=0,b=p(h.text,h.sectionIndex,tc(h,s,n,e));x<b.length;x+=1){var _=b[x],w=new Wl;w.text=_[0],w.sectionIndex=_[1],w.sections=h.sections,u.push(w)}}else u=function(t,e){for(var r=[],n=t.text,i=0,a=0,o=e;a<o.length;a+=1){var s=o[a];r.push(t.substring(i,s)),i=s}return i<n.length&&r.push(t.substring(i,n.length)),r}(h,tc(h,s,n,e));var k=[],T={positionedGlyphs:k,text:h.toString(),top:l[1],bottom:l[1],left:l[0],right:l[0],writingMode:c,lineCount:u.length};return function(t,e,r,n,i,a,o,s){for(var l=0,c=-17,u=0,h=t.positionedGlyphs,f=\"right\"===a?1:\"left\"===a?0:.5,p=0,d=r;p<d.length;p+=1){var g=d[p];g.trim();var v=g.getMaxScale();if(g.length()){for(var m=h.length,y=0;y<g.length();y++){var x=g.getSection(y),b=g.getCharCode(y),_=24*(v-x.scale),w=e[x.fontStack],k=w&&w[b];k&&(On(b)&&o!==Yl.horizontal?(h.push({glyph:b,x:l,y:_,vertical:!0,scale:x.scale,fontStack:x.fontStack}),l+=Gl*x.scale+s):(h.push({glyph:b,x:l,y:c+_,vertical:!1,scale:x.scale,fontStack:x.fontStack}),l+=k.metrics.advance*x.scale+s))}if(h.length!==m){var T=l-s;u=Math.max(T,u),rc(h,e,m,h.length-1,f)}l=0,c+=n*v}else c+=n}var A=ec(i),M=A.horizontalAlign,S=A.verticalAlign;!function(t,e,r,n,i,a,o){for(var s=(e-r)*i,l=(-n*o+.5)*a,c=0;c<t.length;c++)t[c].x+=s,t[c].y+=l}(h,f,M,S,u,n,r.length);var E=c- -17;t.top+=-S*E,t.bottom=t.top+E,t.left+=-M*u,t.right=t.left+u}(T,e,u,i,a,o,c,s),!!k.length&&T}Wl.fromFeature=function(t,e){for(var r=new Wl,n=0;n<t.sections.length;n++){var i=t.sections[n];r.sections.push({scale:i.scale||1,fontStack:i.fontStack||e}),r.text+=i.text;for(var a=0;a<i.text.length;a++)r.sectionIndex.push(n)}return r},Wl.prototype.length=function(){return this.text.length},Wl.prototype.getSection=function(t){return this.sections[this.sectionIndex[t]]},Wl.prototype.getCharCode=function(t){return this.text.charCodeAt(t)},Wl.prototype.verticalizePunctuation=function(){this.text=function(t){for(var e=\"\",r=0;r<t.length;r++){var n=t.charCodeAt(r+1)||null,i=t.charCodeAt(r-1)||null;n&&zn(n)&&!xs[t[r+1]]||i&&zn(i)&&!xs[t[r-1]]||!xs[t[r]]?e+=t[r]:e+=xs[t[r]]}return e}(this.text)},Wl.prototype.trim=function(){for(var t=0,e=0;e<this.text.length&&Zl[this.text.charCodeAt(e)];e++)t++;for(var r=this.text.length,n=this.text.length-1;n>=0&&n>=t&&Zl[this.text.charCodeAt(n)];n--)r--;this.text=this.text.substring(t,r),this.sectionIndex=this.sectionIndex.slice(t,r)},Wl.prototype.substring=function(t,e){var r=new Wl;return r.text=this.text.substring(t,e),r.sectionIndex=this.sectionIndex.slice(t,e),r.sections=this.sections,r},Wl.prototype.toString=function(){return this.text},Wl.prototype.getMaxScale=function(){var t=this;return this.sectionIndex.reduce(function(e,r){return Math.max(e,t.sections[r].scale)},0)};var Zl={9:!0,10:!0,11:!0,12:!0,13:!0,32:!0},Jl={};function Kl(t,e,r,n){var i=Math.pow(t-e,2);return n?t<e?i/2:2*i:i+Math.abs(r)*r}function $l(t,e,r){var n=0;return 10===t&&(n-=1e4),r&&(n+=150),40!==t&&65288!==t||(n+=50),41!==e&&65289!==e||(n+=50),n}function Ql(t,e,r,n,i,a){for(var o=null,s=Kl(e,r,i,a),l=0,c=n;l<c.length;l+=1){var u=c[l],h=Kl(e-u.x,r,i,a)+u.badness;h<=s&&(o=u,s=h)}return{index:t,x:e,priorBreak:o,badness:s}}function tc(t,e,r,n){if(!r)return[];if(!t)return[];for(var i,a=[],o=function(t,e,r,n){for(var i=0,a=0;a<t.length();a++){var o=t.getSection(a),s=n[o.fontStack],l=s&&s[t.getCharCode(a)];l&&(i+=l.metrics.advance*o.scale+e)}return i/Math.max(1,Math.ceil(i/r))}(t,e,r,n),s=t.text.indexOf(\"\\u200b\")>=0,l=0,c=0;c<t.length();c++){var u=t.getSection(c),h=t.getCharCode(c),f=n[u.fontStack],p=f&&f[h];if(p&&!Zl[h]&&(l+=p.metrics.advance*u.scale+e),c<t.length()-1){var d=!((i=h)<11904||!(En[\"Bopomofo Extended\"](i)||En.Bopomofo(i)||En[\"CJK Compatibility Forms\"](i)||En[\"CJK Compatibility Ideographs\"](i)||En[\"CJK Compatibility\"](i)||En[\"CJK Radicals Supplement\"](i)||En[\"CJK Strokes\"](i)||En[\"CJK Symbols and Punctuation\"](i)||En[\"CJK Unified Ideographs Extension A\"](i)||En[\"CJK Unified Ideographs\"](i)||En[\"Enclosed CJK Letters and Months\"](i)||En[\"Halfwidth and Fullwidth Forms\"](i)||En.Hiragana(i)||En[\"Ideographic Description Characters\"](i)||En[\"Kangxi Radicals\"](i)||En[\"Katakana Phonetic Extensions\"](i)||En.Katakana(i)||En[\"Vertical Forms\"](i)||En[\"Yi Radicals\"](i)||En[\"Yi Syllables\"](i)));(Jl[h]||d)&&a.push(Ql(c+1,l,o,a,$l(h,t.getCharCode(c+1),d&&s),!1))}}return function t(e){return e?t(e.priorBreak).concat(e.index):[]}(Ql(t.length(),l,o,a,0,!0))}function ec(t){var e=.5,r=.5;switch(t){case\"right\":case\"top-right\":case\"bottom-right\":e=1;break;case\"left\":case\"top-left\":case\"bottom-left\":e=0}switch(t){case\"bottom\":case\"bottom-right\":case\"bottom-left\":r=1;break;case\"top\":case\"top-right\":case\"top-left\":r=0}return{horizontalAlign:e,verticalAlign:r}}function rc(t,e,r,n,i){if(i){var a=t[n],o=e[a.fontStack],s=o&&o[a.glyph];if(s)for(var l=s.metrics.advance*a.scale,c=(t[n].x+l)*i,u=r;u<=n;u++)t[u].x-=c}}function nc(t,e,r){var n=ec(r),i=n.horizontalAlign,a=n.verticalAlign,o=e[0],s=e[1],l=o-t.displaySize[0]*i,c=l+t.displaySize[0],u=s-t.displaySize[1]*a;return{image:t,top:u,bottom:u+t.displaySize[1],left:l,right:c}}function ic(t,e,r,n,i){if(void 0===e.segment)return!0;for(var a=e,o=e.segment+1,s=0;s>-r/2;){if(--o<0)return!1;s-=t[o].dist(a),a=t[o]}s+=t[o].dist(t[o+1]),o++;for(var l=[],c=0;s<r/2;){var u=t[o-1],h=t[o],f=t[o+1];if(!f)return!1;var p=u.angleTo(h)-h.angleTo(f);for(p=Math.abs((p+3*Math.PI)%(2*Math.PI)-Math.PI),l.push({distance:s,angleDelta:p}),c+=p;s-l[0].distance>n;)c-=l.shift().angleDelta;if(c>i)return!1;o++,s+=h.dist(f)}return!0}function ac(t){for(var e=0,r=0;r<t.length-1;r++)e+=t[r].dist(t[r+1]);return e}function oc(t,e,r){return t?.6*e*r:0}function sc(t,e){return Math.max(t?t.right-t.left:0,e?e.right-e.left:0)}function lc(t,e,r,n,i,a){for(var o=oc(r,i,a),s=sc(r,n)*a,l=0,c=ac(t)/2,u=0;u<t.length-1;u++){var h=t[u],f=t[u+1],p=h.dist(f);if(l+p>c){var d=(c-l)/p,g=Ee(h.x,f.x,d),v=Ee(h.y,f.y,d),m=new bs(g,v,f.angleTo(h),u);return m._round(),!o||ic(t,m,s,o,e)?m:void 0}l+=p}}function cc(t,e,r,n,i,a,o,s,l){var c=oc(n,a,o),u=sc(n,i),h=u*o,f=0===t[0].x||t[0].x===l||0===t[0].y||t[0].y===l;return e-h<e/4&&(e=h+e/4),function t(e,r,n,i,a,o,s,l,c){for(var u=o/2,h=ac(e),f=0,p=r-n,d=[],g=0;g<e.length-1;g++){for(var v=e[g],m=e[g+1],y=v.dist(m),x=m.angleTo(v);p+n<f+y;){var b=((p+=n)-f)/y,_=Ee(v.x,m.x,b),w=Ee(v.y,m.y,b);if(_>=0&&_<c&&w>=0&&w<c&&p-u>=0&&p+u<=h){var k=new bs(_,w,x,g);k._round(),i&&!ic(e,k,o,i,a)||d.push(k)}}f+=y}return l||d.length||s||(d=t(e,f/2,n,i,a,o,s,!0,c)),d}(t,f?e/2*s%e:(u/2+2*a)*o*s%e,e,c,r,h,f,!1,l)}Jl[10]=!0,Jl[32]=!0,Jl[38]=!0,Jl[40]=!0,Jl[41]=!0,Jl[43]=!0,Jl[45]=!0,Jl[47]=!0,Jl[173]=!0,Jl[183]=!0,Jl[8203]=!0,Jl[8208]=!0,Jl[8211]=!0,Jl[8231]=!0;var uc=function(t,e,r,n,a,o,s,l,c,u,h,f){var p=s.top*l-c,d=s.bottom*l+c,g=s.left*l-c,v=s.right*l+c;if(this.boxStartIndex=t.length,u){var m=d-p,y=v-g;m>0&&(m=Math.max(10*l,m),this._addLineCollisionCircles(t,e,r,r.segment,y,m,n,a,o,h))}else{if(f){var x=new i(g,p),b=new i(v,p),_=new i(g,d),w=new i(v,d),k=f*Math.PI/180;x._rotate(k),b._rotate(k),_._rotate(k),w._rotate(k),g=Math.min(x.x,b.x,_.x,w.x),v=Math.max(x.x,b.x,_.x,w.x),p=Math.min(x.y,b.y,_.y,w.y),d=Math.max(x.y,b.y,_.y,w.y)}t.emplaceBack(r.x,r.y,g,p,v,d,n,a,o,0,0)}this.boxEndIndex=t.length};uc.prototype._addLineCollisionCircles=function(t,e,r,n,i,a,o,s,l,c){var u=a/2,h=Math.floor(i/u)||1,f=1+.4*Math.log(c)/Math.LN2,p=Math.floor(h*f/2),d=-a/2,g=r,v=n+1,m=d,y=-i/2,x=y-i/4;do{if(--v<0){if(m>y)return;v=0;break}m-=e[v].dist(g),g=e[v]}while(m>x);for(var b=e[v].dist(e[v+1]),_=-p;_<h+p;_++){var w=_*u,k=y+w;if(w<0&&(k+=w),w>i&&(k+=w-i),!(k<m)){for(;m+b<k;){if(m+=b,++v+1>=e.length)return;b=e[v].dist(e[v+1])}var T=k-m,A=e[v],M=e[v+1].sub(A)._unit()._mult(T)._add(A)._round(),S=Math.abs(k-d)<u?0:.8*(k-d);t.emplaceBack(M.x,M.y,-a/2,-a/2,a/2,a/2,o,s,l,a/2,S)}}};var hc=function(t,e){if(void 0===t&&(t=[]),void 0===e&&(e=fc),this.data=t,this.length=this.data.length,this.compare=e,this.length>0)for(var r=(this.length>>1)-1;r>=0;r--)this._down(r)};function fc(t,e){return t<e?-1:t>e?1:0}function pc(t,e,r){void 0===e&&(e=1),void 0===r&&(r=!1);for(var n=1/0,a=1/0,o=-1/0,s=-1/0,l=t[0],c=0;c<l.length;c++){var u=l[c];(!c||u.x<n)&&(n=u.x),(!c||u.y<a)&&(a=u.y),(!c||u.x>o)&&(o=u.x),(!c||u.y>s)&&(s=u.y)}var h=o-n,f=s-a,p=Math.min(h,f),d=p/2,g=new hc([],dc);if(0===p)return new i(n,a);for(var v=n;v<o;v+=p)for(var m=a;m<s;m+=p)g.push(new gc(v+d,m+d,d,t));for(var y=function(t){for(var e=0,r=0,n=0,i=t[0],a=0,o=i.length,s=o-1;a<o;s=a++){var l=i[a],c=i[s],u=l.x*c.y-c.x*l.y;r+=(l.x+c.x)*u,n+=(l.y+c.y)*u,e+=3*u}return new gc(r/e,n/e,0,t)}(t),x=g.length;g.length;){var b=g.pop();(b.d>y.d||!y.d)&&(y=b,r&&console.log(\"found best %d after %d probes\",Math.round(1e4*b.d)/1e4,x)),b.max-y.d<=e||(d=b.h/2,g.push(new gc(b.p.x-d,b.p.y-d,d,t)),g.push(new gc(b.p.x+d,b.p.y-d,d,t)),g.push(new gc(b.p.x-d,b.p.y+d,d,t)),g.push(new gc(b.p.x+d,b.p.y+d,d,t)),x+=4)}return r&&(console.log(\"num probes: \"+x),console.log(\"best distance: \"+y.d)),y.p}function dc(t,e){return e.max-t.max}function gc(t,e,r,n){this.p=new i(t,e),this.h=r,this.d=function(t,e){for(var r=!1,n=1/0,i=0;i<e.length;i++)for(var a=e[i],o=0,s=a.length,l=s-1;o<s;l=o++){var c=a[o],u=a[l];c.y>t.y!=u.y>t.y&&t.x<(u.x-c.x)*(t.y-c.y)/(u.y-c.y)+c.x&&(r=!r),n=Math.min(n,ka(t,c,u))}return(r?1:-1)*Math.sqrt(n)}(this.p,n),this.max=this.d+this.h*Math.SQRT2}hc.prototype.push=function(t){this.data.push(t),this.length++,this._up(this.length-1)},hc.prototype.pop=function(){if(0!==this.length){var t=this.data[0];return this.length--,this.length>0&&(this.data[0]=this.data[this.length],this._down(0)),this.data.pop(),t}},hc.prototype.peek=function(){return this.data[0]},hc.prototype._up=function(t){for(var e=this.data,r=this.compare,n=e[t];t>0;){var i=t-1>>1,a=e[i];if(r(n,a)>=0)break;e[t]=a,t=i}e[t]=n},hc.prototype._down=function(t){for(var e=this.data,r=this.compare,n=this.length>>1,i=e[t];t<n;){var a=1+(t<<1),o=e[a],s=a+1;if(s<this.length&&r(e[s],o)<0&&(a=s,o=e[s]),r(o,i)>=0)break;e[t]=o,t=a}e[t]=i};var vc=e(function(t){t.exports=function(t,e){var r,n,i,a,o,s,l,c;for(r=3&t.length,n=t.length-r,i=e,o=3432918353,s=461845907,c=0;c<n;)l=255&t.charCodeAt(c)|(255&t.charCodeAt(++c))<<8|(255&t.charCodeAt(++c))<<16|(255&t.charCodeAt(++c))<<24,++c,i=27492+(65535&(a=5*(65535&(i=(i^=l=(65535&(l=(l=(65535&l)*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295)<<13|i>>>19))+((5*(i>>>16)&65535)<<16)&4294967295))+((58964+(a>>>16)&65535)<<16);switch(l=0,r){case 3:l^=(255&t.charCodeAt(c+2))<<16;case 2:l^=(255&t.charCodeAt(c+1))<<8;case 1:i^=l=(65535&(l=(l=(65535&(l^=255&t.charCodeAt(c)))*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295}return i^=t.length,i=2246822507*(65535&(i^=i>>>16))+((2246822507*(i>>>16)&65535)<<16)&4294967295,i=3266489909*(65535&(i^=i>>>13))+((3266489909*(i>>>16)&65535)<<16)&4294967295,(i^=i>>>16)>>>0}}),mc=e(function(t){t.exports=function(t,e){for(var r,n=t.length,i=e^n,a=0;n>=4;)r=1540483477*(65535&(r=255&t.charCodeAt(a)|(255&t.charCodeAt(++a))<<8|(255&t.charCodeAt(++a))<<16|(255&t.charCodeAt(++a))<<24))+((1540483477*(r>>>16)&65535)<<16),i=1540483477*(65535&i)+((1540483477*(i>>>16)&65535)<<16)^(r=1540483477*(65535&(r^=r>>>24))+((1540483477*(r>>>16)&65535)<<16)),n-=4,++a;switch(n){case 3:i^=(255&t.charCodeAt(a+2))<<16;case 2:i^=(255&t.charCodeAt(a+1))<<8;case 1:i=1540483477*(65535&(i^=255&t.charCodeAt(a)))+((1540483477*(i>>>16)&65535)<<16)}return i=1540483477*(65535&(i^=i>>>13))+((1540483477*(i>>>16)&65535)<<16),(i^=i>>>15)>>>0}}),yc=vc,xc=vc,bc=mc;yc.murmur3=xc,yc.murmur2=bc;var _c=7;function wc(t,e){var r=0,n=0,i=e/Math.sqrt(2);switch(t){case\"top-right\":case\"top-left\":n=i-_c;break;case\"bottom-right\":case\"bottom-left\":n=-i+_c;break;case\"bottom\":n=-e+_c;break;case\"top\":n=e-_c}switch(t){case\"top-right\":case\"bottom-right\":r=-i;break;case\"top-left\":case\"bottom-left\":r=i;break;case\"left\":r=e;break;case\"right\":r=-e}return[r,n]}function kc(t){switch(t){case\"right\":case\"top-right\":case\"bottom-right\":return\"right\";case\"left\":case\"top-left\":case\"bottom-left\":return\"left\"}return\"center\"}function Tc(t,e,r,n,a,o,s){var l=o.layoutTextSize.evaluate(e,{}),c=o.layoutIconSize.evaluate(e,{}),u=o.textMaxSize.evaluate(e,{});void 0===u&&(u=l);var h=t.layers[0].layout,f=h.get(\"icon-offset\").evaluate(e,{}),p=Sc(r.horizontal),d=l/24,g=t.tilePixelRatio*d,v=t.tilePixelRatio*u/24,m=t.tilePixelRatio*c,y=t.tilePixelRatio*h.get(\"symbol-spacing\"),x=h.get(\"text-padding\")*t.tilePixelRatio,b=h.get(\"icon-padding\")*t.tilePixelRatio,_=h.get(\"text-max-angle\")/180*Math.PI,k=\"map\"===h.get(\"text-rotation-alignment\")&&\"point\"!==h.get(\"symbol-placement\"),T=\"map\"===h.get(\"icon-rotation-alignment\")&&\"point\"!==h.get(\"symbol-placement\"),A=h.get(\"symbol-placement\"),M=y/2,S=function(l,c){c.x<0||c.x>=ha||c.y<0||c.y>=ha||function(t,e,r,n,a,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_){var k,T,A=t.addToLineVertexArray(e,r),M=0,S=0,E=0,C={},L=yc(\"\"),P=(o.layout.get(\"text-radial-offset\").evaluate(x,{})||0)*Gl;for(var O in n.horizontal){var z=n.horizontal[O];if(!k){L=yc(z.text);var I=o.layout.get(\"text-rotate\").evaluate(x,{});k=new uc(s,r,e,l,c,u,z,h,f,p,t.overscaling,I)}var D=1===z.lineCount;if(S+=Mc(t,e,z,o,p,x,d,A,n.vertical?Yl.horizontal:Yl.horizontalOnly,D?Object.keys(n.horizontal):[O],C,b,_),D)break}n.vertical&&(E+=Mc(t,e,n.vertical,o,p,x,d,A,Yl.vertical,[\"vertical\"],C,b,_));var R=k?k.boxStartIndex:t.collisionBoxArray.length,F=k?k.boxEndIndex:t.collisionBoxArray.length;if(a){var B=function(t,e,r,n,a,o){var s,l,c,u,h=e.image,f=r.layout,p=e.top-1/h.pixelRatio,d=e.left-1/h.pixelRatio,g=e.bottom+1/h.pixelRatio,v=e.right+1/h.pixelRatio;if(\"none\"!==f.get(\"icon-text-fit\")&&a){var m=v-d,y=g-p,x=f.get(\"text-size\").evaluate(o,{})/24,b=a.left*x,_=a.right*x,w=a.top*x,k=_-b,T=a.bottom*x-w,A=f.get(\"icon-text-fit-padding\")[0],M=f.get(\"icon-text-fit-padding\")[1],S=f.get(\"icon-text-fit-padding\")[2],E=f.get(\"icon-text-fit-padding\")[3],C=\"width\"===f.get(\"icon-text-fit\")?.5*(T-y):0,L=\"height\"===f.get(\"icon-text-fit\")?.5*(k-m):0,P=\"width\"===f.get(\"icon-text-fit\")||\"both\"===f.get(\"icon-text-fit\")?k:m,O=\"height\"===f.get(\"icon-text-fit\")||\"both\"===f.get(\"icon-text-fit\")?T:y;s=new i(b+L-E,w+C-A),l=new i(b+L+M+P,w+C-A),c=new i(b+L+M+P,w+C+S+O),u=new i(b+L-E,w+C+S+O)}else s=new i(d,p),l=new i(v,p),c=new i(v,g),u=new i(d,g);var z=r.layout.get(\"icon-rotate\").evaluate(o,{})*Math.PI/180;if(z){var I=Math.sin(z),D=Math.cos(z),R=[D,-I,I,D];s._matMult(R),l._matMult(R),u._matMult(R),c._matMult(R)}return[{tl:s,tr:l,bl:u,br:c,tex:h.paddedRect,writingMode:void 0,glyphOffset:[0,0]}]}(0,a,o,0,Sc(n.horizontal),x),N=o.layout.get(\"icon-rotate\").evaluate(x,{});T=new uc(s,r,e,l,c,u,a,g,v,!1,t.overscaling,N),M=4*B.length;var j=t.iconSizeData,U=null;\"source\"===j.kind?(U=[_s*o.layout.get(\"icon-size\").evaluate(x,{})])[0]>Ac&&w(t.layerIds[0]+': Value for \"icon-size\" is >= 256. Reduce your \"icon-size\".'):\"composite\"===j.kind&&((U=[_s*_.compositeIconSizes[0].evaluate(x,{}),_s*_.compositeIconSizes[1].evaluate(x,{})])[0]>Ac||U[1]>Ac)&&w(t.layerIds[0]+': Value for \"icon-size\" is >= 256. Reduce your \"icon-size\".'),t.addSymbols(t.icon,B,U,y,m,x,!1,e,A.lineStartIndex,A.lineLength)}var V=T?T.boxStartIndex:t.collisionBoxArray.length,q=T?T.boxEndIndex:t.collisionBoxArray.length;t.glyphOffsetArray.length>=Os.MAX_GLYPHS&&w(\"Too many glyphs being rendered in a tile. See https://github.com/mapbox/mapbox-gl-js/issues/2907\"),t.symbolInstances.emplaceBack(e.x,e.y,C.right>=0?C.right:-1,C.center>=0?C.center:-1,C.left>=0?C.left:-1,C.vertical||-1,L,R,F,V,q,l,S,E,M,0,h,P)}(t,c,l,r,n,t.layers[0],t.collisionBoxArray,e.index,e.sourceLayerIndex,t.index,g,x,k,s,m,b,T,f,e,a,o)};if(\"line\"===A)for(var E=0,C=function(t,e,r,n,a){for(var o=[],s=0;s<t.length;s++)for(var l=t[s],c=void 0,u=0;u<l.length-1;u++){var h=l[u],f=l[u+1];h.x<0&&f.x<0||(h.x<0?h=new i(0,h.y+(f.y-h.y)*((0-h.x)/(f.x-h.x)))._round():f.x<0&&(f=new i(0,h.y+(f.y-h.y)*((0-h.x)/(f.x-h.x)))._round()),h.y<0&&f.y<0||(h.y<0?h=new i(h.x+(f.x-h.x)*((0-h.y)/(f.y-h.y)),0)._round():f.y<0&&(f=new i(h.x+(f.x-h.x)*((0-h.y)/(f.y-h.y)),0)._round()),h.x>=n&&f.x>=n||(h.x>=n?h=new i(n,h.y+(f.y-h.y)*((n-h.x)/(f.x-h.x)))._round():f.x>=n&&(f=new i(n,h.y+(f.y-h.y)*((n-h.x)/(f.x-h.x)))._round()),h.y>=a&&f.y>=a||(h.y>=a?h=new i(h.x+(f.x-h.x)*((a-h.y)/(f.y-h.y)),a)._round():f.y>=a&&(f=new i(h.x+(f.x-h.x)*((a-h.y)/(f.y-h.y)),a)._round()),c&&h.equals(c[c.length-1])||(c=[h],o.push(c)),c.push(f)))))}return o}(e.geometry,0,0,ha,ha);E<C.length;E+=1)for(var L=C[E],P=0,O=cc(L,y,_,r.vertical||p,n,24,v,t.overscaling,ha);P<O.length;P+=1){var z=O[P];p&&Ec(t,p.text,M,z)||S(L,z)}else if(\"line-center\"===A)for(var I=0,D=e.geometry;I<D.length;I+=1){var R=D[I];if(R.length>1){var F=lc(R,_,r.vertical||p,n,24,v);F&&S(R,F)}}else if(\"Polygon\"===e.type)for(var B=0,N=Mo(e.geometry,0);B<N.length;B+=1){var j=N[B],U=pc(j,16);S(j[0],new bs(U.x,U.y,0))}else if(\"LineString\"===e.type)for(var V=0,q=e.geometry;V<q.length;V+=1){var H=q[V];S(H,new bs(H[0].x,H[0].y,0))}else if(\"Point\"===e.type)for(var G=0,Y=e.geometry;G<Y.length;G+=1)for(var W=0,X=Y[G];W<X.length;W+=1){var Z=X[W];S([Z],new bs(Z.x,Z.y,0))}}var Ac=65535;function Mc(t,e,r,n,a,o,s,l,c,u,h,f,p){var d=function(t,e,r,n,a,o,s){for(var l=n.layout.get(\"text-rotate\").evaluate(o,{})*Math.PI/180,c=e.positionedGlyphs,u=[],h=0;h<c.length;h++){var f=c[h],p=s[f.fontStack],d=p&&p[f.glyph];if(d){var g=d.rect;if(g){var v=bl+1,m=d.metrics.advance*f.scale/2,y=a?[f.x+m,f.y]:[0,0],x=a?[0,0]:[f.x+m+r[0],f.y+r[1]],b=(d.metrics.left-v)*f.scale-m+x[0],_=(-d.metrics.top-v)*f.scale+x[1],w=b+g.w*f.scale,k=_+g.h*f.scale,T=new i(b,_),A=new i(w,_),M=new i(b,k),S=new i(w,k);if(a&&f.vertical){var E=new i(-m,m),C=-Math.PI/2,L=new i(5,0);T._rotateAround(C,E)._add(L),A._rotateAround(C,E)._add(L),M._rotateAround(C,E)._add(L),S._rotateAround(C,E)._add(L)}if(l){var P=Math.sin(l),O=Math.cos(l),z=[O,-P,P,O];T._matMult(z),A._matMult(z),M._matMult(z),S._matMult(z)}u.push({tl:T,tr:A,bl:M,br:S,tex:g,writingMode:e.writingMode,glyphOffset:y})}}}return u}(0,r,s,n,a,o,f),g=t.textSizeData,v=null;\"source\"===g.kind?(v=[_s*n.layout.get(\"text-size\").evaluate(o,{})])[0]>Ac&&w(t.layerIds[0]+': Value for \"text-size\" is >= 256. Reduce your \"text-size\".'):\"composite\"===g.kind&&((v=[_s*p.compositeTextSizes[0].evaluate(o,{}),_s*p.compositeTextSizes[1].evaluate(o,{})])[0]>Ac||v[1]>Ac)&&w(t.layerIds[0]+': Value for \"text-size\" is >= 256. Reduce your \"text-size\".'),t.addSymbols(t.text,d,v,s,a,o,c,e,l.lineStartIndex,l.lineLength);for(var m=0,y=u;m<y.length;m+=1)h[y[m]]=t.text.placedSymbolArray.length-1;return 4*d.length}function Sc(t){for(var e in t)return t[e];return null}function Ec(t,e,r,n){var i=t.compareText;if(e in i){for(var a=i[e],o=a.length-1;o>=0;o--)if(n.dist(a[o])<r)return!0}else i[e]=[];return i[e].push(n),!1}t.Actor=_l,t.AlphaImage=qa,t.CanonicalTileID=Pl,t.CollisionBoxArray=Li,t.Color=ne,t.DEMData=Dl,t.DataConstantProperty=Jn,t.DictionaryCoder=Fl,t.EXTENT=ha,t.ErrorEvent=Ot,t.EvaluationParameters=Un,t.Event=Pt,t.Evented=zt,t.FeatureIndex=Ul,t.FillBucket=Lo,t.FillExtrusionBucket=Yo,t.ImageAtlas=Gs,t.ImagePosition=qs,t.LineBucket=os,t.LngLat=Tl,t.LngLatBounds=kl,t.MercatorCoordinate=Ll,t.ONE_EM=Gl,t.OverscaledTileID=zl,t.Point=i,t.Point$1=i,t.ProgramConfiguration=sa,t.Properties=ei,t.Protobuf=Qs,t.RGBAImage=Ha,t.RequestManager=j,t.ResourceType=yt,t.SegmentVector=Vi,t.SourceFeatureState=jl,t.StructArrayLayout1ui2=Mi,t.StructArrayLayout2i4=li,t.StructArrayLayout2ui4=Ai,t.StructArrayLayout3ui6=Ti,t.StructArrayLayout4i8=ci,t.SymbolBucket=Os,t.Texture=Js,t.Tile=Hl,t.Transitionable=Hn,t.Uniform1f=Xi,t.Uniform1i=Wi,t.Uniform2f=Zi,t.Uniform3f=Ji,t.Uniform4f=Ki,t.UniformColor=$i,t.UniformMatrix4f=ta,t.UnwrappedTileID=Ol,t.ValidationError=Dt,t.WritingMode=Yl,t.ZoomHistory=Sn,t.addDynamicAttributes=Cs,t.asyncAll=function(t,e,r){if(!t.length)return r(null,[]);var n=t.length,i=new Array(t.length),a=null;t.forEach(function(t,o){e(t,function(t,e){t&&(a=t),i[o]=e,0==--n&&r(a,i)})})},t.bezier=s,t.bindAll=v,t.browser=z,t.cacheEntryPossiblyAdded=function(t){++mt>dt&&(t.send(\"enforceCacheSizeLimit\",pt),mt=0)},t.clamp=c,t.clearTileCache=function(t){var e=self.caches.delete(ft);t&&e.catch(t).then(function(){return t()})},t.clone=function(t){var e=new Pa(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e},t.clone$1=b,t.config=I,t.create=function(){var t=new Pa(16);return Pa!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=0,t[12]=0,t[13]=0,t[14]=0),t[0]=1,t[5]=1,t[10]=1,t[15]=1,t},t.create$1=Oa,t.create$2=function(){var t=new Pa(4);return Pa!=Float32Array&&(t[1]=0,t[2]=0),t[0]=1,t[3]=1,t},t.createCommonjsModule=e,t.createExpression=Or,t.createLayout=oi,t.createStyleLayer=function(t){return\"custom\"===t.type?new js(t):new Us[t.type](t)},t.deepEqual=o,t.ease=l,t.emitValidationErrors=mn,t.endsWith=m,t.enforceCacheSizeLimit=function(t){self.caches&&self.caches.open(ft).then(function(e){e.keys().then(function(r){for(var n=0;n<r.length-t;n++)e.delete(r[n])})})},t.evaluateRadialOffset=wc,t.evaluateSizeForFeature=ks,t.evaluateSizeForZoom=Ts,t.evented=Nn,t.extend=h,t.featureFilter=Gr,t.filterObject=x,t.fromRotation=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=r,t[2]=0,t[3]=-r,t[4]=n,t[5]=0,t[6]=0,t[7]=0,t[8]=1,t},t.getAnchorAlignment=ec,t.getAnchorJustification=kc,t.getArrayBuffer=Mt,t.getImage=Et,t.getJSON=function(t,e){return At(h(t,{type:\"json\"}),e)},t.getReferrer=_t,t.getVideo=function(t,e){var r,n,i=self.document.createElement(\"video\");i.muted=!0,i.onloadstart=function(){e(null,i)};for(var a=0;a<t.length;a++){var o=self.document.createElement(\"source\");r=t[a],n=void 0,(n=self.document.createElement(\"a\")).href=r,(n.protocol!==self.document.location.protocol||n.host!==self.document.location.host)&&(i.crossOrigin=\"Anonymous\"),o.src=t[a],i.appendChild(o)}return{cancel:function(){}}},t.identity=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t},t.invert=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],g=e[13],v=e[14],m=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,k=i*c-a*l,T=u*g-h*d,A=u*v-f*d,M=u*m-p*d,S=h*v-f*g,E=h*m-p*g,C=f*m-p*v,L=y*C-x*E+b*S+_*M-w*A+k*T;return L?(L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(i*E-n*C-a*S)*L,t[2]=(g*k-v*w+m*_)*L,t[3]=(f*w-h*k-p*_)*L,t[4]=(l*M-o*C-c*A)*L,t[5]=(r*C-i*M+a*A)*L,t[6]=(v*b-d*k-m*x)*L,t[7]=(u*k-f*b+p*x)*L,t[8]=(o*E-s*M+c*T)*L,t[9]=(n*M-r*E-a*T)*L,t[10]=(d*w-g*b+m*y)*L,t[11]=(h*b-u*w-p*y)*L,t[12]=(s*A-o*S-l*T)*L,t[13]=(r*S-n*A+i*T)*L,t[14]=(g*x-d*_-v*y)*L,t[15]=(u*_-h*x+f*y)*L,t):null},t.isChar=En,t.isMapboxURL=q,t.keysDifference=function(t,e){var r=[];for(var n in t)n in e||r.push(n);return r},t.makeRequest=At,t.mapObject=y,t.mercatorXfromLng=Ml,t.mercatorYfromLat=Sl,t.mercatorZfromAltitude=El,t.multiply=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],g=e[12],v=e[13],m=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*h+w*g,t[1]=x*i+b*l+_*f+w*v,t[2]=x*a+b*c+_*p+w*m,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*h+w*g,t[5]=x*i+b*l+_*f+w*v,t[6]=x*a+b*c+_*p+w*m,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*h+w*g,t[9]=x*i+b*l+_*f+w*v,t[10]=x*a+b*c+_*p+w*m,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*h+w*g,t[13]=x*i+b*l+_*f+w*v,t[14]=x*a+b*c+_*p+w*m,t[15]=x*o+b*u+_*d+w*y,t},t.mvt=Vo,t.number=Ee,t.ortho=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t},t.parseGlyphPBF=function(t){return new Qs(t).readFields(ml,[])},t.pbf=Qs,t.performSymbolLayout=function(t,e,r,n,i,a){t.createArrays();var o=512*t.overscaling;t.tilePixelRatio=ha/o,t.compareText={},t.iconsNeedLinear=!1;var s=t.layers[0].layout,l=t.layers[0]._unevaluatedLayout._values,c={};if(\"composite\"===t.textSizeData.kind){var u=t.textSizeData,h=u.minZoom,f=u.maxZoom;c.compositeTextSizes=[l[\"text-size\"].possiblyEvaluate(new Un(h)),l[\"text-size\"].possiblyEvaluate(new Un(f))]}if(\"composite\"===t.iconSizeData.kind){var p=t.iconSizeData,d=p.minZoom,g=p.maxZoom;c.compositeIconSizes=[l[\"icon-size\"].possiblyEvaluate(new Un(d)),l[\"icon-size\"].possiblyEvaluate(new Un(g))]}c.layoutTextSize=l[\"text-size\"].possiblyEvaluate(new Un(t.zoom+1)),c.layoutIconSize=l[\"icon-size\"].possiblyEvaluate(new Un(t.zoom+1)),c.textMaxSize=l[\"text-size\"].possiblyEvaluate(new Un(18));for(var v=s.get(\"text-line-height\")*Gl,m=\"map\"===s.get(\"text-rotation-alignment\")&&\"point\"!==s.get(\"symbol-placement\"),y=s.get(\"text-keep-upright\"),x=0,b=t.features;x<b.length;x+=1){var _=b[x],k=s.get(\"text-font\").evaluate(_,{}).join(\",\"),T=r,A={horizontal:{},vertical:void 0},M=_.text,S=[0,0];if(M){var E=M.toString(),C=s.get(\"text-letter-spacing\").evaluate(_,{})*Gl,L=Ln(E)?C:0,P=s.get(\"text-anchor\").evaluate(_,{}),O=s.get(\"text-variable-anchor\"),z=s.get(\"text-radial-offset\").evaluate(_,{});O||(S=z?wc(P,z*Gl):s.get(\"text-offset\").evaluate(_,{}).map(function(t){return t*Gl}));var I=m?\"center\":s.get(\"text-justify\").evaluate(_,{}),D=\"point\"===s.get(\"symbol-placement\")?s.get(\"text-max-width\").evaluate(_,{})*Gl:0;if(!m&&O)for(var R=\"auto\"===I?O.map(function(t){return kc(t)}):[I],F=!1,B=0;B<R.length;B++){var N=R[B];if(!A.horizontal[N])if(F)A.horizontal[N]=A.horizontal[0];else{var j=Xl(M,e,k,D,v,\"center\",N,L,S,Yl.horizontal);j&&(A.horizontal[N]=j,F=1===j.lineCount)}}else{\"auto\"===I&&(I=kc(P));var U=Xl(M,e,k,D,v,P,I,L,S,Yl.horizontal);U&&(A.horizontal[I]=U),Cn(E)&&m&&y&&(A.vertical=Xl(M,e,k,D,v,P,I,L,S,Yl.vertical))}}var V=void 0;if(_.icon){var q=n[_.icon];q&&(V=nc(i[_.icon],s.get(\"icon-offset\").evaluate(_,{}),s.get(\"icon-anchor\").evaluate(_,{})),void 0===t.sdfIcons?t.sdfIcons=q.sdf:t.sdfIcons!==q.sdf&&w(\"Style sheet warning: Cannot mix SDF and non-SDF icons in one buffer\"),q.pixelRatio!==t.pixelRatio?t.iconsNeedLinear=!0:0!==s.get(\"icon-rotate\").constantOr(1)&&(t.iconsNeedLinear=!0))}(Object.keys(A.horizontal).length||V)&&Tc(t,_,A,V,T,c,S)}a&&t.generateCollisionDebugBuffers()},t.perspective=function(t,e,r,n,i){var a,o=1/Math.tan(e/2);return t[0]=o/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=o,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=-1,t[12]=0,t[13]=0,t[15]=0,null!=i&&i!==1/0?(a=1/(n-i),t[10]=(i+n)*a,t[14]=2*i*n*a):(t[10]=-1,t[14]=-2*n),t},t.pick=function(t,e){for(var r={},n=0;n<e.length;n++){var i=e[n];i in t&&(r[i]=t[i])}return r},t.plugin=jn,t.polygonIntersectsPolygon=va,t.postMapLoadEvent=ht,t.postTurnstileEvent=ct,t.potpack=Vs,t.rasterBoundsAttributes=Rl,t.refProperties=[\"type\",\"source\",\"source-layer\",\"minzoom\",\"maxzoom\",\"filter\",\"layout\"],t.register=kn,t.registerForPluginAvailability=function(t){return Fn?t({pluginURL:Fn,completionCallback:Dn}):Nn.once(\"pluginAvailable\",t),t},t.rotate=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=Math.sin(r),l=Math.cos(r);return t[0]=n*l+a*s,t[1]=i*l+o*s,t[2]=n*-s+a*l,t[3]=i*-s+o*l,t},t.rotateX=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];return e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+h*n,t[7]=l*i+f*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=h*i-s*n,t[11]=f*i-l*n,t},t.rotateZ=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];return e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+h*n,t[3]=l*i+f*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=h*i-s*n,t[7]=f*i-l*n,t},t.scale=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t},t.setCacheLimits=function(t,e){pt=t,dt=e},t.setRTLTextPlugin=function(t,e){if(Rn)throw new Error(\"setRTLTextPlugin cannot be called multiple times.\");Rn=!0,Fn=z.resolveURL(t),Dn=function(t){t?(Rn=!1,Fn=null,e&&e(t)):Bn=!0},Nn.fire(new Pt(\"pluginAvailable\",{pluginURL:Fn,completionCallback:Dn}))},t.sphericalToCartesian=function(t){var e=t[0],r=t[1],n=t[2];return r+=90,r*=Math.PI/180,n*=Math.PI/180,{x:e*Math.cos(r)*Math.sin(n),y:e*Math.sin(r)*Math.sin(n),z:e*Math.cos(n)}},t.styleSpec=It,t.symbolSize=As,t.transformMat3=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t},t.transformMat4=Da,t.translate=function(t,e,r){var n,i,a,o,s,l,c,u,h,f,p,d,g=r[0],v=r[1],m=r[2];return e===t?(t[12]=e[0]*g+e[4]*v+e[8]*m+e[12],t[13]=e[1]*g+e[5]*v+e[9]*m+e[13],t[14]=e[2]*g+e[6]*v+e[10]*m+e[14],t[15]=e[3]*g+e[7]*v+e[11]*m+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*g+s*v+h*m+e[12],t[13]=i*g+l*v+f*m+e[13],t[14]=a*g+c*v+p*m+e[14],t[15]=o*g+u*v+d*m+e[15]),t},t.uniqueId=p,t.validateCustomStyleLayer=function(t){var e=[],r=t.id;return void 0===r&&e.push({message:\"layers.\"+r+': missing required property \"id\"'}),void 0===t.render&&e.push({message:\"layers.\"+r+': missing required method \"render\"'}),t.renderingMode&&\"2d\"!==t.renderingMode&&\"3d\"!==t.renderingMode&&e.push({message:\"layers.\"+r+': property \"renderingMode\" must be either \"2d\" or \"3d\"'}),e},t.validateLight=dn,t.validateStyle=pn,t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.vectorTile=Vo,t.version=\"1.1.1\",t.warnOnce=w,t.webpSupported=D,t.window=self,t.wrap=u}),n(0,function(t){function e(t){var r=typeof t;if(\"number\"===r||\"boolean\"===r||\"string\"===r||null==t)return JSON.stringify(t);if(Array.isArray(t)){for(var n=\"[\",i=0,a=t;i<a.length;i+=1)n+=e(a[i])+\",\";return n+\"]\"}for(var o=Object.keys(t).sort(),s=\"{\",l=0;l<o.length;l++)s+=JSON.stringify(o[l])+\":\"+e(t[o[l]])+\",\";return s+\"}\"}function r(r){for(var n=\"\",i=0,a=t.refProperties;i<a.length;i+=1)n+=\"/\"+e(r[a[i]]);return n}var n=function(t){this.keyCache={},t&&this.replace(t)};n.prototype.replace=function(t){this._layerConfigs={},this._layers={},this.update(t,[])},n.prototype.update=function(e,n){for(var i=this,a=0,o=e;a<o.length;a+=1){var s=o[a];this._layerConfigs[s.id]=s;var l=this._layers[s.id]=t.createStyleLayer(s);l._featureFilter=t.featureFilter(l.filter),this.keyCache[s.id]&&delete this.keyCache[s.id]}for(var c=0,u=n;c<u.length;c+=1){var h=u[c];delete this.keyCache[h],delete this._layerConfigs[h],delete this._layers[h]}this.familiesBySource={};for(var f=0,p=function(t,e){for(var n={},i=0;i<t.length;i++){var a=e&&e[t[i].id]||r(t[i]);e&&(e[t[i].id]=a);var o=n[a];o||(o=n[a]=[]),o.push(t[i])}var s=[];for(var l in n)s.push(n[l]);return s}(t.values(this._layerConfigs),this.keyCache);f<p.length;f+=1){var d=p[f].map(function(t){return i._layers[t.id]}),g=d[0];if(\"none\"!==g.visibility){var v=g.source||\"\",m=this.familiesBySource[v];m||(m=this.familiesBySource[v]={});var y=g.sourceLayer||\"_geojsonTileLayer\",x=m[y];x||(x=m[y]=[]),x.push(d)}}};var i=function(e){var r={},n=[];for(var i in e){var a=e[i],o=r[i]={};for(var s in a){var l=a[+s];if(l&&0!==l.bitmap.width&&0!==l.bitmap.height){var c={x:0,y:0,w:l.bitmap.width+2,h:l.bitmap.height+2};n.push(c),o[s]={rect:c,metrics:l.metrics}}}}var u=t.potpack(n),h=u.w,f=u.h,p=new t.AlphaImage({width:h||1,height:f||1});for(var d in e){var g=e[d];for(var v in g){var m=g[+v];if(m&&0!==m.bitmap.width&&0!==m.bitmap.height){var y=r[d][v].rect;t.AlphaImage.copy(m.bitmap,p,{x:0,y:0},{x:y.x+1,y:y.y+1},m.bitmap)}}}this.image=p,this.positions=r};t.register(\"GlyphAtlas\",i);var a=function(e){this.tileID=new t.OverscaledTileID(e.tileID.overscaledZ,e.tileID.wrap,e.tileID.canonical.z,e.tileID.canonical.x,e.tileID.canonical.y),this.uid=e.uid,this.zoom=e.zoom,this.pixelRatio=e.pixelRatio,this.tileSize=e.tileSize,this.source=e.source,this.overscaling=this.tileID.overscaleFactor(),this.showCollisionBoxes=e.showCollisionBoxes,this.collectResourceTiming=!!e.collectResourceTiming,this.returnDependencies=!!e.returnDependencies};function o(e,r){for(var n=new t.EvaluationParameters(r),i=0,a=e;i<a.length;i+=1)a[i].recalculate(n)}a.prototype.parse=function(e,r,n,a){var s=this;this.status=\"parsing\",this.data=e,this.collisionBoxArray=new t.CollisionBoxArray;var l=new t.DictionaryCoder(Object.keys(e.layers).sort()),c=new t.FeatureIndex(this.tileID);c.bucketLayerIDs=[];var u,h,f,p,d={},g={featureIndex:c,iconDependencies:{},patternDependencies:{},glyphDependencies:{}},v=r.familiesBySource[this.source];for(var m in v){var y=e.layers[m];if(y){1===y.version&&t.warnOnce('Vector tile source \"'+this.source+'\" layer \"'+m+'\" does not use vector tile spec v2 and therefore may have some rendering errors.');for(var x=l.encode(m),b=[],_=0;_<y.length;_++){var w=y.feature(_);b.push({feature:w,index:_,sourceLayerIndex:x})}for(var k=0,T=v[m];k<T.length;k+=1){var A=T[k],M=A[0];M.minzoom&&this.zoom<Math.floor(M.minzoom)||M.maxzoom&&this.zoom>=M.maxzoom||\"none\"!==M.visibility&&(o(A,this.zoom),(d[M.id]=M.createBucket({index:c.bucketLayerIDs.length,layers:A,zoom:this.zoom,pixelRatio:this.pixelRatio,overscaling:this.overscaling,collisionBoxArray:this.collisionBoxArray,sourceLayerIndex:x,sourceID:this.source})).populate(b,g),c.bucketLayerIDs.push(A.map(function(t){return t.id})))}}}var S=t.mapObject(g.glyphDependencies,function(t){return Object.keys(t).map(Number)});Object.keys(S).length?n.send(\"getGlyphs\",{uid:this.uid,stacks:S},function(t,e){u||(u=t,h=e,L.call(s))}):h={};var E=Object.keys(g.iconDependencies);E.length?n.send(\"getImages\",{icons:E},function(t,e){u||(u=t,f=e,L.call(s))}):f={};var C=Object.keys(g.patternDependencies);function L(){if(u)return a(u);if(h&&f&&p){var e=new i(h),r=new t.ImageAtlas(f,p);for(var n in d){var s=d[n];s instanceof t.SymbolBucket?(o(s.layers,this.zoom),t.performSymbolLayout(s,h,e.positions,f,r.iconPositions,this.showCollisionBoxes)):s.hasPattern&&(s instanceof t.LineBucket||s instanceof t.FillBucket||s instanceof t.FillExtrusionBucket)&&(o(s.layers,this.zoom),s.addFeatures(g,r.patternPositions))}this.status=\"done\",a(null,{buckets:t.values(d).filter(function(t){return!t.isEmpty()}),featureIndex:c,collisionBoxArray:this.collisionBoxArray,glyphAtlasImage:e.image,imageAtlas:r,glyphMap:this.returnDependencies?h:null,iconMap:this.returnDependencies?f:null,glyphPositions:this.returnDependencies?e.positions:null})}}C.length?n.send(\"getImages\",{icons:C},function(t,e){u||(u=t,p=e,L.call(s))}):p={},L.call(this)};var s=\"undefined\"!=typeof performance,l={getEntriesByName:function(t){return!!(s&&performance&&performance.getEntriesByName)&&performance.getEntriesByName(t)},mark:function(t){return!!(s&&performance&&performance.mark)&&performance.mark(t)},measure:function(t,e,r){return!!(s&&performance&&performance.measure)&&performance.measure(t,e,r)},clearMarks:function(t){return!!(s&&performance&&performance.clearMarks)&&performance.clearMarks(t)},clearMeasures:function(t){return!!(s&&performance&&performance.clearMeasures)&&performance.clearMeasures(t)}},c=function(t){this._marks={start:[t.url,\"start\"].join(\"#\"),end:[t.url,\"end\"].join(\"#\"),measure:t.url.toString()},l.mark(this._marks.start)};function u(e,r){var n=t.getArrayBuffer(e.request,function(e,n,i,a){e?r(e):n&&r(null,{vectorTile:new t.vectorTile.VectorTile(new t.pbf(n)),rawData:n,cacheControl:i,expires:a})});return function(){n.cancel(),r()}}c.prototype.finish=function(){l.mark(this._marks.end);var t=l.getEntriesByName(this._marks.measure);return 0===t.length&&(l.measure(this._marks.measure,this._marks.start,this._marks.end),t=l.getEntriesByName(this._marks.measure),l.clearMarks(this._marks.start),l.clearMarks(this._marks.end),l.clearMeasures(this._marks.measure)),t},l.Performance=c;var h=function(t,e,r){this.actor=t,this.layerIndex=e,this.loadVectorData=r||u,this.loading={},this.loaded={}};h.prototype.loadTile=function(e,r){var n=this,i=e.uid;this.loading||(this.loading={});var o=!!(e&&e.request&&e.request.collectResourceTiming)&&new l.Performance(e.request),s=this.loading[i]=new a(e);s.abort=this.loadVectorData(e,function(e,a){if(delete n.loading[i],e||!a)return s.status=\"done\",n.loaded[i]=s,r(e);var l=a.rawData,c={};a.expires&&(c.expires=a.expires),a.cacheControl&&(c.cacheControl=a.cacheControl);var u={};if(o){var h=o.finish();h&&(u.resourceTiming=JSON.parse(JSON.stringify(h)))}s.vectorTile=a.vectorTile,s.parse(a.vectorTile,n.layerIndex,n.actor,function(e,n){if(e||!n)return r(e);r(null,t.extend({rawTileData:l.slice(0)},n,c,u))}),n.loaded=n.loaded||{},n.loaded[i]=s})},h.prototype.reloadTile=function(t,e){var r=this.loaded,n=t.uid,i=this;if(r&&r[n]){var a=r[n];a.showCollisionBoxes=t.showCollisionBoxes;var o=function(t,r){var n=a.reloadCallback;n&&(delete a.reloadCallback,a.parse(a.vectorTile,i.layerIndex,i.actor,n)),e(t,r)};\"parsing\"===a.status?a.reloadCallback=o:\"done\"===a.status&&(a.vectorTile?a.parse(a.vectorTile,this.layerIndex,this.actor,o):o())}},h.prototype.abortTile=function(t,e){var r=this.loading,n=t.uid;r&&r[n]&&r[n].abort&&(r[n].abort(),delete r[n]),e()},h.prototype.removeTile=function(t,e){var r=this.loaded,n=t.uid;r&&r[n]&&delete r[n],e()};var f=function(){this.loaded={}};f.prototype.loadTile=function(e,r){var n=e.uid,i=e.encoding,a=e.rawImageData,o=new t.DEMData(n,a,i);this.loaded=this.loaded||{},this.loaded[n]=o,r(null,o)},f.prototype.removeTile=function(t){var e=this.loaded,r=t.uid;e&&e[r]&&delete e[r]};var p={RADIUS:6378137,FLATTENING:1/298.257223563,POLAR_RADIUS:6356752.3142};function d(t){var e=0;if(t&&t.length>0){e+=Math.abs(g(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(g(t[r]))}return e}function g(t){var e,r,n,i,a,o,s=0,l=t.length;if(l>2){for(o=0;o<l;o++)o===l-2?(n=l-2,i=l-1,a=0):o===l-1?(n=l-1,i=0,a=1):(n=o,i=o+1,a=o+2),e=t[n],r=t[i],s+=(v(t[a][0])-v(e[0]))*Math.sin(v(r[1]));s=s*p.RADIUS*p.RADIUS/2}return s}function v(t){return t*Math.PI/180}var m={geometry:function t(e){var r,n=0;switch(e.type){case\"Polygon\":return d(e.coordinates);case\"MultiPolygon\":for(r=0;r<e.coordinates.length;r++)n+=d(e.coordinates[r]);return n;case\"Point\":case\"MultiPoint\":case\"LineString\":case\"MultiLineString\":return 0;case\"GeometryCollection\":for(r=0;r<e.geometries.length;r++)n+=t(e.geometries[r]);return n}},ring:g};function y(t,e){return function(r){return t(r,e)}}function x(t,e){e=!!e,t[0]=b(t[0],e);for(var r=1;r<t.length;r++)t[r]=b(t[r],!e);return t}function b(t,e){return function(t){return m.ring(t)>=0}(t)===e?t:t.reverse()}var _=t.vectorTile.VectorTileFeature.prototype.toGeoJSON,w=function(e){this._feature=e,this.extent=t.EXTENT,this.type=e.type,this.properties=e.tags,\"id\"in e&&!isNaN(e.id)&&(this.id=parseInt(e.id,10))};w.prototype.loadGeometry=function(){if(1===this._feature.type){for(var e=[],r=0,n=this._feature.geometry;r<n.length;r+=1){var i=n[r];e.push([new t.Point$1(i[0],i[1])])}return e}for(var a=[],o=0,s=this._feature.geometry;o<s.length;o+=1){for(var l=[],c=0,u=s[o];c<u.length;c+=1){var h=u[c];l.push(new t.Point$1(h[0],h[1]))}a.push(l)}return a},w.prototype.toGeoJSON=function(t,e,r){return _.call(this,t,e,r)};var k=function(e){this.layers={_geojsonTileLayer:this},this.name=\"_geojsonTileLayer\",this.extent=t.EXTENT,this.length=e.length,this._features=e};k.prototype.feature=function(t){return new w(this._features[t])};var T=t.vectorTile.VectorTileFeature,A=M;function M(t,e){this.options=e||{},this.features=t,this.length=t.length}function S(t,e){this.id=\"number\"==typeof t.id?t.id:void 0,this.type=t.type,this.rawGeometry=1===t.type?[t.geometry]:t.geometry,this.properties=t.tags,this.extent=e||4096}M.prototype.feature=function(t){return new S(this.features[t],this.options.extent)},S.prototype.loadGeometry=function(){var e=this.rawGeometry;this.geometry=[];for(var r=0;r<e.length;r++){for(var n=e[r],i=[],a=0;a<n.length;a++)i.push(new t.Point$1(n[a][0],n[a][1]));this.geometry.push(i)}return this.geometry},S.prototype.bbox=function(){this.geometry||this.loadGeometry();for(var t=this.geometry,e=1/0,r=-1/0,n=1/0,i=-1/0,a=0;a<t.length;a++)for(var o=t[a],s=0;s<o.length;s++){var l=o[s];e=Math.min(e,l.x),r=Math.max(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.y)}return[e,n,r,i]},S.prototype.toGeoJSON=T.prototype.toGeoJSON;var E=P,C=P,L=A;function P(e){var r=new t.pbf;return function(t,e){for(var r in t.layers)e.writeMessage(3,O,t.layers[r])}(e,r),r.finish()}function O(t,e){var r;e.writeVarintField(15,t.version||1),e.writeStringField(1,t.name||\"\"),e.writeVarintField(5,t.extent||4096);var n={keys:[],values:[],keycache:{},valuecache:{}};for(r=0;r<t.length;r++)n.feature=t.feature(r),e.writeMessage(2,z,n);var i=n.keys;for(r=0;r<i.length;r++)e.writeStringField(3,i[r]);var a=n.values;for(r=0;r<a.length;r++)e.writeMessage(4,B,a[r])}function z(t,e){var r=t.feature;void 0!==r.id&&e.writeVarintField(1,r.id),e.writeMessage(2,I,t),e.writeVarintField(3,r.type),e.writeMessage(4,F,r)}function I(t,e){var r=t.feature,n=t.keys,i=t.values,a=t.keycache,o=t.valuecache;for(var s in r.properties){var l=a[s];void 0===l&&(n.push(s),l=n.length-1,a[s]=l),e.writeVarint(l);var c=r.properties[s],u=typeof c;\"string\"!==u&&\"boolean\"!==u&&\"number\"!==u&&(c=JSON.stringify(c));var h=u+\":\"+c,f=o[h];void 0===f&&(i.push(c),f=i.length-1,o[h]=f),e.writeVarint(f)}}function D(t,e){return(e<<3)+(7&t)}function R(t){return t<<1^t>>31}function F(t,e){for(var r=t.loadGeometry(),n=t.type,i=0,a=0,o=r.length,s=0;s<o;s++){var l=r[s],c=1;1===n&&(c=l.length),e.writeVarint(D(1,c));for(var u=3===n?l.length-1:l.length,h=0;h<u;h++){1===h&&1!==n&&e.writeVarint(D(2,u-1));var f=l[h].x-i,p=l[h].y-a;e.writeVarint(R(f)),e.writeVarint(R(p)),i+=f,a+=p}3===n&&e.writeVarint(D(7,1))}}function B(t,e){var r=typeof t;\"string\"===r?e.writeStringField(1,t):\"boolean\"===r?e.writeBooleanField(7,t):\"number\"===r&&(t%1!=0?e.writeDoubleField(3,t):t<0?e.writeSVarintField(6,t):e.writeVarintField(5,t))}function N(t,e,r,n){j(t,r,n),j(e,2*r,2*n),j(e,2*r+1,2*n+1)}function j(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function U(t,e,r,n){var i=t-r,a=e-n;return i*i+a*a}E.fromVectorTileJs=C,E.fromGeojsonVt=function(t,e){e=e||{};var r={};for(var n in t)r[n]=new A(t[n].features,e),r[n].name=n,r[n].version=e.version,r[n].extent=e.extent;return P({layers:r})},E.GeoJSONWrapper=L;var V=function(t){return t[0]},q=function(t){return t[1]},H=function(t,e,r,n,i){void 0===e&&(e=V),void 0===r&&(r=q),void 0===n&&(n=64),void 0===i&&(i=Float64Array),this.nodeSize=n,this.points=t;for(var a=t.length<65536?Uint16Array:Uint32Array,o=this.ids=new a(t.length),s=this.coords=new i(2*t.length),l=0;l<t.length;l++)o[l]=l,s[2*l]=e(t[l]),s[2*l+1]=r(t[l]);!function t(e,r,n,i,a,o){if(!(a-i<=n)){var s=i+a>>1;!function t(e,r,n,i,a,o){for(;a>i;){if(a-i>600){var s=a-i+1,l=n-i+1,c=Math.log(s),u=.5*Math.exp(2*c/3),h=.5*Math.sqrt(c*u*(s-u)/s)*(l-s/2<0?-1:1);t(e,r,n,Math.max(i,Math.floor(n-l*u/s+h)),Math.min(a,Math.floor(n+(s-l)*u/s+h)),o)}var f=r[2*n+o],p=i,d=a;for(N(e,r,i,n),r[2*a+o]>f&&N(e,r,i,a);p<d;){for(N(e,r,p,d),p++,d--;r[2*p+o]<f;)p++;for(;r[2*d+o]>f;)d--}r[2*i+o]===f?N(e,r,i,d):N(e,r,++d,a),d<=n&&(i=d+1),n<=d&&(a=d-1)}}(e,r,s,i,a,o%2),t(e,r,n,i,s-1,o+1),t(e,r,n,s+1,a,o+1)}}(o,s,n,0,o.length-1,0)};H.prototype.range=function(t,e,r,n){return function(t,e,r,n,i,a,o){for(var s,l,c=[0,t.length-1,0],u=[];c.length;){var h=c.pop(),f=c.pop(),p=c.pop();if(f-p<=o)for(var d=p;d<=f;d++)s=e[2*d],l=e[2*d+1],s>=r&&s<=i&&l>=n&&l<=a&&u.push(t[d]);else{var g=Math.floor((p+f)/2);s=e[2*g],l=e[2*g+1],s>=r&&s<=i&&l>=n&&l<=a&&u.push(t[g]);var v=(h+1)%2;(0===h?r<=s:n<=l)&&(c.push(p),c.push(g-1),c.push(v)),(0===h?i>=s:a>=l)&&(c.push(g+1),c.push(f),c.push(v))}}return u}(this.ids,this.coords,t,e,r,n,this.nodeSize)},H.prototype.within=function(t,e,r){return function(t,e,r,n,i,a){for(var o=[0,t.length-1,0],s=[],l=i*i;o.length;){var c=o.pop(),u=o.pop(),h=o.pop();if(u-h<=a)for(var f=h;f<=u;f++)U(e[2*f],e[2*f+1],r,n)<=l&&s.push(t[f]);else{var p=Math.floor((h+u)/2),d=e[2*p],g=e[2*p+1];U(d,g,r,n)<=l&&s.push(t[p]);var v=(c+1)%2;(0===c?r-i<=d:n-i<=g)&&(o.push(h),o.push(p-1),o.push(v)),(0===c?r+i>=d:n+i>=g)&&(o.push(p+1),o.push(u),o.push(v))}}return s}(this.ids,this.coords,t,e,r,this.nodeSize)};var G={minZoom:0,maxZoom:16,radius:40,extent:512,nodeSize:64,log:!1,reduce:null,map:function(t){return t}},Y=function(t){this.options=Q(Object.create(G),t),this.trees=new Array(this.options.maxZoom+1)};function W(t,e,r,n,i){return{x:t,y:e,zoom:1/0,id:r,parentId:-1,numPoints:n,properties:i}}function X(t,e){var r=t.geometry.coordinates,n=r[0],i=r[1];return{x:K(n),y:$(i),zoom:1/0,index:e,parentId:-1}}function Z(t){return{type:\"Feature\",id:t.id,properties:J(t),geometry:{type:\"Point\",coordinates:[(n=t.x,360*(n-.5)),(e=t.y,r=(180-360*e)*Math.PI/180,360*Math.atan(Math.exp(r))/Math.PI-90)]}};var e,r,n}function J(t){var e=t.numPoints,r=e>=1e4?Math.round(e/1e3)+\"k\":e>=1e3?Math.round(e/100)/10+\"k\":e;return Q(Q({},t.properties),{cluster:!0,cluster_id:t.id,point_count:e,point_count_abbreviated:r})}function K(t){return t/360+.5}function $(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function Q(t,e){for(var r in e)t[r]=e[r];return t}function tt(t){return t.x}function et(t){return t.y}function rt(t,e,r,n,i,a){var o=i-r,s=a-n;if(0!==o||0!==s){var l=((t-r)*o+(e-n)*s)/(o*o+s*s);l>1?(r=i,n=a):l>0&&(r+=o*l,n+=s*l)}return(o=t-r)*o+(s=e-n)*s}function nt(t,e,r,n){var i={id:void 0===t?null:t,type:e,geometry:r,tags:n,minX:1/0,minY:1/0,maxX:-1/0,maxY:-1/0};return function(t){var e=t.geometry,r=t.type;if(\"Point\"===r||\"MultiPoint\"===r||\"LineString\"===r)it(t,e);else if(\"Polygon\"===r||\"MultiLineString\"===r)for(var n=0;n<e.length;n++)it(t,e[n]);else if(\"MultiPolygon\"===r)for(n=0;n<e.length;n++)for(var i=0;i<e[n].length;i++)it(t,e[n][i])}(i),i}function it(t,e){for(var r=0;r<e.length;r+=3)t.minX=Math.min(t.minX,e[r]),t.minY=Math.min(t.minY,e[r+1]),t.maxX=Math.max(t.maxX,e[r]),t.maxY=Math.max(t.maxY,e[r+1])}function at(t,e,r,n){if(e.geometry){var i=e.geometry.coordinates,a=e.geometry.type,o=Math.pow(r.tolerance/((1<<r.maxZoom)*r.extent),2),s=[],l=e.id;if(r.promoteId?l=e.properties[r.promoteId]:r.generateId&&(l=n||0),\"Point\"===a)ot(i,s);else if(\"MultiPoint\"===a)for(var c=0;c<i.length;c++)ot(i[c],s);else if(\"LineString\"===a)st(i,s,o,!1);else if(\"MultiLineString\"===a){if(r.lineMetrics){for(c=0;c<i.length;c++)s=[],st(i[c],s,o,!1),t.push(nt(l,\"LineString\",s,e.properties));return}lt(i,s,o,!1)}else if(\"Polygon\"===a)lt(i,s,o,!0);else{if(\"MultiPolygon\"!==a){if(\"GeometryCollection\"===a){for(c=0;c<e.geometry.geometries.length;c++)at(t,{id:l,geometry:e.geometry.geometries[c],properties:e.properties},r,n);return}throw new Error(\"Input data is not a valid GeoJSON object.\")}for(c=0;c<i.length;c++){var u=[];lt(i[c],u,o,!0),s.push(u)}}t.push(nt(l,a,s,e.properties))}}function ot(t,e){e.push(ct(t[0])),e.push(ut(t[1])),e.push(0)}function st(t,e,r,n){for(var i,a,o=0,s=0;s<t.length;s++){var l=ct(t[s][0]),c=ut(t[s][1]);e.push(l),e.push(c),e.push(0),s>0&&(o+=n?(i*c-l*a)/2:Math.sqrt(Math.pow(l-i,2)+Math.pow(c-a,2))),i=l,a=c}var u=e.length-3;e[2]=1,function t(e,r,n,i){for(var a,o=i,s=n-r>>1,l=n-r,c=e[r],u=e[r+1],h=e[n],f=e[n+1],p=r+3;p<n;p+=3){var d=rt(e[p],e[p+1],c,u,h,f);if(d>o)a=p,o=d;else if(d===o){var g=Math.abs(p-s);g<l&&(a=p,l=g)}}o>i&&(a-r>3&&t(e,r,a,i),e[a+2]=o,n-a>3&&t(e,a,n,i))}(e,0,u,r),e[u+2]=1,e.size=Math.abs(o),e.start=0,e.end=e.size}function lt(t,e,r,n){for(var i=0;i<t.length;i++){var a=[];st(t[i],a,r,n),e.push(a)}}function ct(t){return t/360+.5}function ut(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function ht(t,e,r,n,i,a,o,s){if(n/=e,a>=(r/=e)&&o<n)return t;if(o<r||a>=n)return null;for(var l=[],c=0;c<t.length;c++){var u=t[c],h=u.geometry,f=u.type,p=0===i?u.minX:u.minY,d=0===i?u.maxX:u.maxY;if(p>=r&&d<n)l.push(u);else if(!(d<r||p>=n)){var g=[];if(\"Point\"===f||\"MultiPoint\"===f)ft(h,g,r,n,i);else if(\"LineString\"===f)pt(h,g,r,n,i,!1,s.lineMetrics);else if(\"MultiLineString\"===f)gt(h,g,r,n,i,!1);else if(\"Polygon\"===f)gt(h,g,r,n,i,!0);else if(\"MultiPolygon\"===f)for(var v=0;v<h.length;v++){var m=[];gt(h[v],m,r,n,i,!0),m.length&&g.push(m)}if(g.length){if(s.lineMetrics&&\"LineString\"===f){for(v=0;v<g.length;v++)l.push(nt(u.id,f,g[v],u.tags));continue}\"LineString\"!==f&&\"MultiLineString\"!==f||(1===g.length?(f=\"LineString\",g=g[0]):f=\"MultiLineString\"),\"Point\"!==f&&\"MultiPoint\"!==f||(f=3===g.length?\"Point\":\"MultiPoint\"),l.push(nt(u.id,f,g,u.tags))}}}return l.length?l:null}function ft(t,e,r,n,i){for(var a=0;a<t.length;a+=3){var o=t[a+i];o>=r&&o<=n&&(e.push(t[a]),e.push(t[a+1]),e.push(t[a+2]))}}function pt(t,e,r,n,i,a,o){for(var s,l,c=dt(t),u=0===i?mt:yt,h=t.start,f=0;f<t.length-3;f+=3){var p=t[f],d=t[f+1],g=t[f+2],v=t[f+3],m=t[f+4],y=0===i?p:d,x=0===i?v:m,b=!1;o&&(s=Math.sqrt(Math.pow(p-v,2)+Math.pow(d-m,2))),y<r?x>r&&(l=u(c,p,d,v,m,r),o&&(c.start=h+s*l)):y>n?x<n&&(l=u(c,p,d,v,m,n),o&&(c.start=h+s*l)):vt(c,p,d,g),x<r&&y>=r&&(l=u(c,p,d,v,m,r),b=!0),x>n&&y<=n&&(l=u(c,p,d,v,m,n),b=!0),!a&&b&&(o&&(c.end=h+s*l),e.push(c),c=dt(t)),o&&(h+=s)}var _=t.length-3;p=t[_],d=t[_+1],g=t[_+2],(y=0===i?p:d)>=r&&y<=n&&vt(c,p,d,g),_=c.length-3,a&&_>=3&&(c[_]!==c[0]||c[_+1]!==c[1])&&vt(c,c[0],c[1],c[2]),c.length&&e.push(c)}function dt(t){var e=[];return e.size=t.size,e.start=t.start,e.end=t.end,e}function gt(t,e,r,n,i,a){for(var o=0;o<t.length;o++)pt(t[o],e,r,n,i,a,!1)}function vt(t,e,r,n){t.push(e),t.push(r),t.push(n)}function mt(t,e,r,n,i,a){var o=(a-e)/(n-e);return t.push(a),t.push(r+(i-r)*o),t.push(1),o}function yt(t,e,r,n,i,a){var o=(a-r)/(i-r);return t.push(e+(n-e)*o),t.push(a),t.push(1),o}function xt(t,e){for(var r=[],n=0;n<t.length;n++){var i,a=t[n],o=a.type;if(\"Point\"===o||\"MultiPoint\"===o||\"LineString\"===o)i=bt(a.geometry,e);else if(\"MultiLineString\"===o||\"Polygon\"===o){i=[];for(var s=0;s<a.geometry.length;s++)i.push(bt(a.geometry[s],e))}else if(\"MultiPolygon\"===o)for(i=[],s=0;s<a.geometry.length;s++){for(var l=[],c=0;c<a.geometry[s].length;c++)l.push(bt(a.geometry[s][c],e));i.push(l)}r.push(nt(a.id,o,i,a.tags))}return r}function bt(t,e){var r=[];r.size=t.size,void 0!==t.start&&(r.start=t.start,r.end=t.end);for(var n=0;n<t.length;n+=3)r.push(t[n]+e,t[n+1],t[n+2]);return r}function _t(t,e){if(t.transformed)return t;var r,n,i,a=1<<t.z,o=t.x,s=t.y;for(r=0;r<t.features.length;r++){var l=t.features[r],c=l.geometry,u=l.type;if(l.geometry=[],1===u)for(n=0;n<c.length;n+=2)l.geometry.push(wt(c[n],c[n+1],e,a,o,s));else for(n=0;n<c.length;n++){var h=[];for(i=0;i<c[n].length;i+=2)h.push(wt(c[n][i],c[n][i+1],e,a,o,s));l.geometry.push(h)}}return t.transformed=!0,t}function wt(t,e,r,n,i,a){return[Math.round(r*(t*n-i)),Math.round(r*(e*n-a))]}function kt(t,e,r,n,i){for(var a=e===i.maxZoom?0:i.tolerance/((1<<e)*i.extent),o={features:[],numPoints:0,numSimplified:0,numFeatures:0,source:null,x:r,y:n,z:e,transformed:!1,minX:2,minY:1,maxX:-1,maxY:0},s=0;s<t.length;s++){o.numFeatures++,Tt(o,t[s],a,i);var l=t[s].minX,c=t[s].minY,u=t[s].maxX,h=t[s].maxY;l<o.minX&&(o.minX=l),c<o.minY&&(o.minY=c),u>o.maxX&&(o.maxX=u),h>o.maxY&&(o.maxY=h)}return o}function Tt(t,e,r,n){var i=e.geometry,a=e.type,o=[];if(\"Point\"===a||\"MultiPoint\"===a)for(var s=0;s<i.length;s+=3)o.push(i[s]),o.push(i[s+1]),t.numPoints++,t.numSimplified++;else if(\"LineString\"===a)At(o,i,t,r,!1,!1);else if(\"MultiLineString\"===a||\"Polygon\"===a)for(s=0;s<i.length;s++)At(o,i[s],t,r,\"Polygon\"===a,0===s);else if(\"MultiPolygon\"===a)for(var l=0;l<i.length;l++){var c=i[l];for(s=0;s<c.length;s++)At(o,c[s],t,r,!0,0===s)}if(o.length){var u=e.tags||null;if(\"LineString\"===a&&n.lineMetrics){for(var h in u={},e.tags)u[h]=e.tags[h];u.mapbox_clip_start=i.start/i.size,u.mapbox_clip_end=i.end/i.size}var f={geometry:o,type:\"Polygon\"===a||\"MultiPolygon\"===a?3:\"LineString\"===a||\"MultiLineString\"===a?2:1,tags:u};null!==e.id&&(f.id=e.id),t.features.push(f)}}function At(t,e,r,n,i,a){var o=n*n;if(n>0&&e.size<(i?o:n))r.numPoints+=e.length/3;else{for(var s=[],l=0;l<e.length;l+=3)(0===n||e[l+2]>o)&&(r.numSimplified++,s.push(e[l]),s.push(e[l+1])),r.numPoints++;i&&function(t,e){for(var r=0,n=0,i=t.length,a=i-2;n<i;a=n,n+=2)r+=(t[n]-t[a])*(t[n+1]+t[a+1]);if(r>0===e)for(n=0,i=t.length;n<i/2;n+=2){var o=t[n],s=t[n+1];t[n]=t[i-2-n],t[n+1]=t[i-1-n],t[i-2-n]=o,t[i-1-n]=s}}(s,a),t.push(s)}}function Mt(t,e){var r=(e=this.options=function(t,e){for(var r in e)t[r]=e[r];return t}(Object.create(this.options),e)).debug;if(r&&console.time(\"preprocess data\"),e.maxZoom<0||e.maxZoom>24)throw new Error(\"maxZoom should be in the 0-24 range\");if(e.promoteId&&e.generateId)throw new Error(\"promoteId and generateId cannot be used together.\");var n=function(t,e){var r=[];if(\"FeatureCollection\"===t.type)for(var n=0;n<t.features.length;n++)at(r,t.features[n],e,n);else\"Feature\"===t.type?at(r,t,e):at(r,{geometry:t},e);return r}(t,e);this.tiles={},this.tileCoords=[],r&&(console.timeEnd(\"preprocess data\"),console.log(\"index: maxZoom: %d, maxPoints: %d\",e.indexMaxZoom,e.indexMaxPoints),console.time(\"generate tiles\"),this.stats={},this.total=0),(n=function(t,e){var r=e.buffer/e.extent,n=t,i=ht(t,1,-1-r,r,0,-1,2,e),a=ht(t,1,1-r,2+r,0,-1,2,e);return(i||a)&&(n=ht(t,1,-r,1+r,0,-1,2,e)||[],i&&(n=xt(i,1).concat(n)),a&&(n=n.concat(xt(a,-1)))),n}(n,e)).length&&this.splitTile(n,0,0,0),r&&(n.length&&console.log(\"features: %d, points: %d\",this.tiles[0].numFeatures,this.tiles[0].numPoints),console.timeEnd(\"generate tiles\"),console.log(\"tiles generated:\",this.total,JSON.stringify(this.stats)))}function St(t,e,r){return 32*((1<<t)*r+e)+t}function Et(t,e){var r=t.tileID.canonical;if(!this._geoJSONIndex)return e(null,null);var n=this._geoJSONIndex.getTile(r.z,r.x,r.y);if(!n)return e(null,null);var i=new k(n.features),a=E(i);0===a.byteOffset&&a.byteLength===a.buffer.byteLength||(a=new Uint8Array(a)),e(null,{vectorTile:i,rawData:a.buffer})}Y.prototype.load=function(t){var e=this.options,r=e.log,n=e.minZoom,i=e.maxZoom,a=e.nodeSize;r&&console.time(\"total time\");var o=\"prepare \"+t.length+\" points\";r&&console.time(o),this.points=t;for(var s=[],l=0;l<t.length;l++)t[l].geometry&&s.push(X(t[l],l));this.trees[i+1]=new H(s,tt,et,a,Float32Array),r&&console.timeEnd(o);for(var c=i;c>=n;c--){var u=+Date.now();s=this._cluster(s,c),this.trees[c]=new H(s,tt,et,a,Float32Array),r&&console.log(\"z%d: %d clusters in %dms\",c,s.length,+Date.now()-u)}return r&&console.timeEnd(\"total time\"),this},Y.prototype.getClusters=function(t,e){var r=((t[0]+180)%360+360)%360-180,n=Math.max(-90,Math.min(90,t[1])),i=180===t[2]?180:((t[2]+180)%360+360)%360-180,a=Math.max(-90,Math.min(90,t[3]));if(t[2]-t[0]>=360)r=-180,i=180;else if(r>i){var o=this.getClusters([r,n,180,a],e),s=this.getClusters([-180,n,i,a],e);return o.concat(s)}for(var l=this.trees[this._limitZoom(e)],c=[],u=0,h=l.range(K(r),$(a),K(i),$(n));u<h.length;u+=1){var f=h[u],p=l.points[f];c.push(p.numPoints?Z(p):this.points[p.index])}return c},Y.prototype.getChildren=function(t){var e=t>>5,r=t%32,n=\"No cluster with the specified id.\",i=this.trees[r];if(!i)throw new Error(n);var a=i.points[e];if(!a)throw new Error(n);for(var o=this.options.radius/(this.options.extent*Math.pow(2,r-1)),s=[],l=0,c=i.within(a.x,a.y,o);l<c.length;l+=1){var u=c[l],h=i.points[u];h.parentId===t&&s.push(h.numPoints?Z(h):this.points[h.index])}if(0===s.length)throw new Error(n);return s},Y.prototype.getLeaves=function(t,e,r){e=e||10,r=r||0;var n=[];return this._appendLeaves(n,t,e,r,0),n},Y.prototype.getTile=function(t,e,r){var n=this.trees[this._limitZoom(t)],i=Math.pow(2,t),a=this.options,o=a.extent,s=a.radius/o,l=(r-s)/i,c=(r+1+s)/i,u={features:[]};return this._addTileFeatures(n.range((e-s)/i,l,(e+1+s)/i,c),n.points,e,r,i,u),0===e&&this._addTileFeatures(n.range(1-s/i,l,1,c),n.points,i,r,i,u),e===i-1&&this._addTileFeatures(n.range(0,l,s/i,c),n.points,-1,r,i,u),u.features.length?u:null},Y.prototype.getClusterExpansionZoom=function(t){for(var e=t%32-1;e<=this.options.maxZoom;){var r=this.getChildren(t);if(e++,1!==r.length)break;t=r[0].properties.cluster_id}return e},Y.prototype._appendLeaves=function(t,e,r,n,i){for(var a=0,o=this.getChildren(e);a<o.length;a+=1){var s=o[a],l=s.properties;if(l&&l.cluster?i+l.point_count<=n?i+=l.point_count:i=this._appendLeaves(t,l.cluster_id,r,n,i):i<n?i++:t.push(s),t.length===r)break}return i},Y.prototype._addTileFeatures=function(t,e,r,n,i,a){for(var o=0,s=t;o<s.length;o+=1){var l=e[s[o]],c={type:1,geometry:[[Math.round(this.options.extent*(l.x*i-r)),Math.round(this.options.extent*(l.y*i-n))]],tags:l.numPoints?J(l):this.points[l.index].properties},u=l.numPoints?l.id:this.points[l.index].id;void 0!==u&&(c.id=u),a.features.push(c)}},Y.prototype._limitZoom=function(t){return Math.max(this.options.minZoom,Math.min(t,this.options.maxZoom+1))},Y.prototype._cluster=function(t,e){for(var r=[],n=this.options,i=n.radius,a=n.extent,o=n.reduce,s=i/(a*Math.pow(2,e)),l=0;l<t.length;l++){var c=t[l];if(!(c.zoom<=e)){c.zoom=e;for(var u=this.trees[e+1],h=u.within(c.x,c.y,s),f=c.numPoints||1,p=c.x*f,d=c.y*f,g=o?this._map(c,!0):null,v=(l<<5)+(e+1),m=0,y=h;m<y.length;m+=1){var x=y[m],b=u.points[x];if(!(b.zoom<=e)){b.zoom=e;var _=b.numPoints||1;p+=b.x*_,d+=b.y*_,f+=_,b.parentId=v,o&&o(g,this._map(b))}}1===f?r.push(c):(c.parentId=v,r.push(W(p/f,d/f,v,f,g)))}}return r},Y.prototype._map=function(t,e){if(t.numPoints)return e?Q({},t.properties):t.properties;var r=this.points[t.index].properties,n=this.options.map(r);return e&&n===r?Q({},n):n},Mt.prototype.options={maxZoom:14,indexMaxZoom:5,indexMaxPoints:1e5,tolerance:3,extent:4096,buffer:64,lineMetrics:!1,promoteId:null,generateId:!1,debug:0},Mt.prototype.splitTile=function(t,e,r,n,i,a,o){for(var s=[t,e,r,n],l=this.options,c=l.debug;s.length;){n=s.pop(),r=s.pop(),e=s.pop(),t=s.pop();var u=1<<e,h=St(e,r,n),f=this.tiles[h];if(!f&&(c>1&&console.time(\"creation\"),f=this.tiles[h]=kt(t,e,r,n,l),this.tileCoords.push({z:e,x:r,y:n}),c)){c>1&&(console.log(\"tile z%d-%d-%d (features: %d, points: %d, simplified: %d)\",e,r,n,f.numFeatures,f.numPoints,f.numSimplified),console.timeEnd(\"creation\"));var p=\"z\"+e;this.stats[p]=(this.stats[p]||0)+1,this.total++}if(f.source=t,i){if(e===l.maxZoom||e===i)continue;var d=1<<i-e;if(r!==Math.floor(a/d)||n!==Math.floor(o/d))continue}else if(e===l.indexMaxZoom||f.numPoints<=l.indexMaxPoints)continue;if(f.source=null,0!==t.length){c>1&&console.time(\"clipping\");var g,v,m,y,x,b,_=.5*l.buffer/l.extent,w=.5-_,k=.5+_,T=1+_;g=v=m=y=null,x=ht(t,u,r-_,r+k,0,f.minX,f.maxX,l),b=ht(t,u,r+w,r+T,0,f.minX,f.maxX,l),t=null,x&&(g=ht(x,u,n-_,n+k,1,f.minY,f.maxY,l),v=ht(x,u,n+w,n+T,1,f.minY,f.maxY,l),x=null),b&&(m=ht(b,u,n-_,n+k,1,f.minY,f.maxY,l),y=ht(b,u,n+w,n+T,1,f.minY,f.maxY,l),b=null),c>1&&console.timeEnd(\"clipping\"),s.push(g||[],e+1,2*r,2*n),s.push(v||[],e+1,2*r,2*n+1),s.push(m||[],e+1,2*r+1,2*n),s.push(y||[],e+1,2*r+1,2*n+1)}}},Mt.prototype.getTile=function(t,e,r){var n=this.options,i=n.extent,a=n.debug;if(t<0||t>24)return null;var o=1<<t,s=St(t,e=(e%o+o)%o,r);if(this.tiles[s])return _t(this.tiles[s],i);a>1&&console.log(\"drilling down to z%d-%d-%d\",t,e,r);for(var l,c=t,u=e,h=r;!l&&c>0;)c--,u=Math.floor(u/2),h=Math.floor(h/2),l=this.tiles[St(c,u,h)];return l&&l.source?(a>1&&console.log(\"found parent tile z%d-%d-%d\",c,u,h),a>1&&console.time(\"drilling down\"),this.splitTile(l.source,c,u,h,t,e,r),a>1&&console.timeEnd(\"drilling down\"),this.tiles[s]?_t(this.tiles[s],i):null):null};var Ct=function(e){function r(t,r,n){e.call(this,t,r,Et),n&&(this.loadGeoJSON=n)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadData=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),this._pendingCallback=e,this._pendingLoadDataParams=t,this._state&&\"Idle\"!==this._state?this._state=\"NeedsLoadData\":(this._state=\"Coalescing\",this._loadData())},r.prototype._loadData=function(){var e=this;if(this._pendingCallback&&this._pendingLoadDataParams){var r=this._pendingCallback,n=this._pendingLoadDataParams;delete this._pendingCallback,delete this._pendingLoadDataParams;var i=!!(n&&n.request&&n.request.collectResourceTiming)&&new l.Performance(n.request);this.loadGeoJSON(n,function(a,o){if(a||!o)return r(a);if(\"object\"!=typeof o)return r(new Error(\"Input data given to '\"+n.source+\"' is not a valid GeoJSON object.\"));!function t(e,r){switch(e&&e.type||null){case\"FeatureCollection\":return e.features=e.features.map(y(t,r)),e;case\"GeometryCollection\":return e.geometries=e.geometries.map(y(t,r)),e;case\"Feature\":return e.geometry=t(e.geometry,r),e;case\"Polygon\":case\"MultiPolygon\":return function(t,e){return\"Polygon\"===t.type?t.coordinates=x(t.coordinates,e):\"MultiPolygon\"===t.type&&(t.coordinates=t.coordinates.map(y(x,e))),t}(e,r);default:return e}}(o,!0);try{e._geoJSONIndex=n.cluster?new Y(function(e){var r=e.superclusterOptions,n=e.clusterProperties;if(!n||!r)return r;for(var i={},a={},o={accumulated:null,zoom:0},s={properties:null},l=Object.keys(n),c=0,u=l;c<u.length;c+=1){var h=u[c],f=n[h],p=f[0],d=f[1],g=t.createExpression(d),v=t.createExpression(\"string\"==typeof p?[p,[\"accumulated\"],[\"get\",h]]:p);i[h]=g.value,a[h]=v.value}return r.map=function(t){s.properties=t;for(var e={},r=0,n=l;r<n.length;r+=1){var a=n[r];e[a]=i[a].evaluate(o,s)}return e},r.reduce=function(t,e){s.properties=e;for(var r=0,n=l;r<n.length;r+=1){var i=n[r];o.accumulated=t[i],t[i]=a[i].evaluate(o,s)}},r}(n)).load(o.features):new Mt(o,n.geojsonVtOptions)}catch(a){return r(a)}e.loaded={};var s={};if(i){var l=i.finish();l&&(s.resourceTiming={},s.resourceTiming[n.source]=JSON.parse(JSON.stringify(l)))}r(null,s)})}},r.prototype.coalesce=function(){\"Coalescing\"===this._state?this._state=\"Idle\":\"NeedsLoadData\"===this._state&&(this._state=\"Coalescing\",this._loadData())},r.prototype.reloadTile=function(t,r){var n=this.loaded,i=t.uid;return n&&n[i]?e.prototype.reloadTile.call(this,t,r):this.loadTile(t,r)},r.prototype.loadGeoJSON=function(e,r){if(e.request)t.getJSON(e.request,r);else{if(\"string\"!=typeof e.data)return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"));try{return r(null,JSON.parse(e.data))}catch(t){return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"))}}},r.prototype.removeSource=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),e()},r.prototype.getClusterExpansionZoom=function(t,e){e(null,this._geoJSONIndex.getClusterExpansionZoom(t.clusterId))},r.prototype.getClusterChildren=function(t,e){e(null,this._geoJSONIndex.getChildren(t.clusterId))},r.prototype.getClusterLeaves=function(t,e){e(null,this._geoJSONIndex.getLeaves(t.clusterId,t.limit,t.offset))},r}(h),Lt=function(e){var r=this;this.self=e,this.actor=new t.Actor(e,this),this.layerIndexes={},this.workerSourceTypes={vector:h,geojson:Ct},this.workerSources={},this.demWorkerSources={},this.self.registerWorkerSource=function(t,e){if(r.workerSourceTypes[t])throw new Error('Worker source with name \"'+t+'\" already registered.');r.workerSourceTypes[t]=e},this.self.registerRTLTextPlugin=function(e){if(t.plugin.isLoaded())throw new Error(\"RTL text plugin already registered.\");t.plugin.applyArabicShaping=e.applyArabicShaping,t.plugin.processBidirectionalText=e.processBidirectionalText,t.plugin.processStyledBidirectionalText=e.processStyledBidirectionalText}};return Lt.prototype.setReferrer=function(t,e){this.referrer=e},Lt.prototype.setLayers=function(t,e,r){this.getLayerIndex(t).replace(e),r()},Lt.prototype.updateLayers=function(t,e,r){this.getLayerIndex(t).update(e.layers,e.removedIds),r()},Lt.prototype.loadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).loadTile(e,r)},Lt.prototype.loadDEMTile=function(t,e,r){this.getDEMWorkerSource(t,e.source).loadTile(e,r)},Lt.prototype.reloadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).reloadTile(e,r)},Lt.prototype.abortTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).abortTile(e,r)},Lt.prototype.removeTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).removeTile(e,r)},Lt.prototype.removeDEMTile=function(t,e){this.getDEMWorkerSource(t,e.source).removeTile(e)},Lt.prototype.removeSource=function(t,e,r){if(this.workerSources[t]&&this.workerSources[t][e.type]&&this.workerSources[t][e.type][e.source]){var n=this.workerSources[t][e.type][e.source];delete this.workerSources[t][e.type][e.source],void 0!==n.removeSource?n.removeSource(e,r):r()}},Lt.prototype.loadWorkerSource=function(t,e,r){try{this.self.importScripts(e.url),r()}catch(t){r(t.toString())}},Lt.prototype.loadRTLTextPlugin=function(e,r,n){try{t.plugin.isLoaded()||(this.self.importScripts(r),n(t.plugin.isLoaded()?null:new Error(\"RTL Text Plugin failed to import scripts from \"+r)))}catch(t){n(t.toString())}},Lt.prototype.getLayerIndex=function(t){var e=this.layerIndexes[t];return e||(e=this.layerIndexes[t]=new n),e},Lt.prototype.getWorkerSource=function(t,e,r){var n=this;if(this.workerSources[t]||(this.workerSources[t]={}),this.workerSources[t][e]||(this.workerSources[t][e]={}),!this.workerSources[t][e][r]){var i={send:function(e,r,i){n.actor.send(e,r,i,t)}};this.workerSources[t][e][r]=new this.workerSourceTypes[e](i,this.getLayerIndex(t))}return this.workerSources[t][e][r]},Lt.prototype.getDEMWorkerSource=function(t,e){return this.demWorkerSources[t]||(this.demWorkerSources[t]={}),this.demWorkerSources[t][e]||(this.demWorkerSources[t][e]=new f),this.demWorkerSources[t][e]},Lt.prototype.enforceCacheSizeLimit=function(e,r){t.enforceCacheSizeLimit(r)},\"undefined\"!=typeof WorkerGlobalScope&&void 0!==t.window&&t.window instanceof WorkerGlobalScope&&(t.window.worker=new Lt(t.window)),Lt}),n(0,function(t){var e=t.createCommonjsModule(function(t){function e(t){return!!(\"undefined\"!=typeof window&&\"undefined\"!=typeof document&&Array.prototype&&Array.prototype.every&&Array.prototype.filter&&Array.prototype.forEach&&Array.prototype.indexOf&&Array.prototype.lastIndexOf&&Array.prototype.map&&Array.prototype.some&&Array.prototype.reduce&&Array.prototype.reduceRight&&Array.isArray&&Function.prototype&&Function.prototype.bind&&Object.keys&&Object.create&&Object.getPrototypeOf&&Object.getOwnPropertyNames&&Object.isSealed&&Object.isFrozen&&Object.isExtensible&&Object.getOwnPropertyDescriptor&&Object.defineProperty&&Object.defineProperties&&Object.seal&&Object.freeze&&Object.preventExtensions&&\"JSON\"in window&&\"parse\"in JSON&&\"stringify\"in JSON&&function(){if(!(\"Worker\"in window&&\"Blob\"in window&&\"URL\"in window))return!1;var t,e,r=new Blob([\"\"],{type:\"text/javascript\"}),n=URL.createObjectURL(r);try{e=new Worker(n),t=!0}catch(e){t=!1}return e&&e.terminate(),URL.revokeObjectURL(n),t}()&&\"Uint8ClampedArray\"in window&&ArrayBuffer.isView&&function(t){return void 0===r[t]&&(r[t]=function(t){var r=document.createElement(\"canvas\"),n=Object.create(e.webGLContextAttributes);return n.failIfMajorPerformanceCaveat=t,r.probablySupportsContext?r.probablySupportsContext(\"webgl\",n)||r.probablySupportsContext(\"experimental-webgl\",n):r.supportsContext?r.supportsContext(\"webgl\",n)||r.supportsContext(\"experimental-webgl\",n):r.getContext(\"webgl\",n)||r.getContext(\"experimental-webgl\",n)}(t)),r[t]}(t&&t.failIfMajorPerformanceCaveat))}t.exports?t.exports=e:window&&(window.mapboxgl=window.mapboxgl||{},window.mapboxgl.supported=e);var r={};e.webGLContextAttributes={antialias:!1,alpha:!0,stencil:!0,depth:!0}}),r={create:function(e,r,n){var i=t.window.document.createElement(e);return void 0!==r&&(i.className=r),n&&n.appendChild(i),i},createNS:function(e,r){return t.window.document.createElementNS(e,r)}},n=t.window.document.documentElement.style;function i(t){if(!n)return t[0];for(var e=0;e<t.length;e++)if(t[e]in n)return t[e];return t[0]}var a,o=i([\"userSelect\",\"MozUserSelect\",\"WebkitUserSelect\",\"msUserSelect\"]);r.disableDrag=function(){n&&o&&(a=n[o],n[o]=\"none\")},r.enableDrag=function(){n&&o&&(n[o]=a)};var s=i([\"transform\",\"WebkitTransform\"]);r.setTransform=function(t,e){t.style[s]=e};var l=!1;try{var c=Object.defineProperty({},\"passive\",{get:function(){l=!0}});t.window.addEventListener(\"test\",c,c),t.window.removeEventListener(\"test\",c,c)}catch(t){l=!1}r.addEventListener=function(t,e,r,n){void 0===n&&(n={}),\"passive\"in n&&l?t.addEventListener(e,r,n):t.addEventListener(e,r,n.capture)},r.removeEventListener=function(t,e,r,n){void 0===n&&(n={}),\"passive\"in n&&l?t.removeEventListener(e,r,n):t.removeEventListener(e,r,n.capture)};var u=function(e){e.preventDefault(),e.stopPropagation(),t.window.removeEventListener(\"click\",u,!0)};function h(t){var e=t.userImage;return!!(e&&e.render&&e.render())&&(t.data.replace(new Uint8Array(e.data.buffer)),!0)}r.suppressClick=function(){t.window.addEventListener(\"click\",u,!0),t.window.setTimeout(function(){t.window.removeEventListener(\"click\",u,!0)},0)},r.mousePos=function(e,r){var n=e.getBoundingClientRect(),i=t.window.TouchEvent&&r instanceof t.window.TouchEvent?r.touches[0]:r;return new t.Point(i.clientX-n.left-e.clientLeft,i.clientY-n.top-e.clientTop)},r.touchPos=function(e,r){for(var n=e.getBoundingClientRect(),i=[],a=\"touchend\"===r.type?r.changedTouches:r.touches,o=0;o<a.length;o++)i.push(new t.Point(a[o].clientX-n.left-e.clientLeft,a[o].clientY-n.top-e.clientTop));return i},r.mouseButton=function(e){return void 0!==t.window.InstallTrigger&&2===e.button&&e.ctrlKey&&t.window.navigator.platform.toUpperCase().indexOf(\"MAC\")>=0?0:e.button},r.remove=function(t){t.parentNode&&t.parentNode.removeChild(t)};var f=function(e){function r(){e.call(this),this.images={},this.updatedImages={},this.callbackDispatchedThisFrame={},this.loaded=!1,this.requestors=[],this.patterns={},this.atlasImage=new t.RGBAImage({width:1,height:1}),this.dirty=!0}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.isLoaded=function(){return this.loaded},r.prototype.setLoaded=function(t){if(this.loaded!==t&&(this.loaded=t,t)){for(var e=0,r=this.requestors;e<r.length;e+=1){var n=r[e],i=n.ids,a=n.callback;this._notify(i,a)}this.requestors=[]}},r.prototype.getImage=function(t){return this.images[t]},r.prototype.addImage=function(t,e){this.images[t]=e},r.prototype.updateImage=function(t,e){var r=this.images[t];e.version=r.version+1,this.images[t]=e,this.updatedImages[t]=!0},r.prototype.removeImage=function(t){var e=this.images[t];delete this.images[t],delete this.patterns[t],e.userImage&&e.userImage.onRemove&&e.userImage.onRemove()},r.prototype.listImages=function(){return Object.keys(this.images)},r.prototype.getImages=function(t,e){var r=!0;if(!this.isLoaded())for(var n=0,i=t;n<i.length;n+=1){var a=i[n];this.images[a]||(r=!1)}this.isLoaded()||r?this._notify(t,e):this.requestors.push({ids:t,callback:e})},r.prototype._notify=function(e,r){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i];this.images[o]||this.fire(new t.Event(\"styleimagemissing\",{id:o}));var s=this.images[o];s?n[o]={data:s.data.clone(),pixelRatio:s.pixelRatio,sdf:s.sdf,version:s.version,hasRenderCallback:Boolean(s.userImage&&s.userImage.render)}:t.warnOnce('Image \"'+o+'\" could not be loaded. Please make sure you have added the image with map.addImage() or a \"sprite\" property in your style. You can provide missing images by listening for the \"styleimagemissing\" map event.')}r(null,n)},r.prototype.getPixelSize=function(){var t=this.atlasImage;return{width:t.width,height:t.height}},r.prototype.getPattern=function(e){var r=this.patterns[e],n=this.getImage(e);if(!n)return null;if(r&&r.position.version===n.version)return r.position;if(r)r.position.version=n.version;else{var i={w:n.data.width+2,h:n.data.height+2,x:0,y:0},a=new t.ImagePosition(i,n);this.patterns[e]={bin:i,position:a}}return this._updatePatternAtlas(),this.patterns[e].position},r.prototype.bind=function(e){var r=e.gl;this.atlasTexture?this.dirty&&(this.atlasTexture.update(this.atlasImage),this.dirty=!1):this.atlasTexture=new t.Texture(e,this.atlasImage,r.RGBA),this.atlasTexture.bind(r.LINEAR,r.CLAMP_TO_EDGE)},r.prototype._updatePatternAtlas=function(){var e=[];for(var r in this.patterns)e.push(this.patterns[r].bin);var n=t.potpack(e),i=n.w,a=n.h,o=this.atlasImage;for(var s in o.resize({width:i||1,height:a||1}),this.patterns){var l=this.patterns[s].bin,c=l.x+1,u=l.y+1,h=this.images[s].data,f=h.width,p=h.height;t.RGBAImage.copy(h,o,{x:0,y:0},{x:c,y:u},{width:f,height:p}),t.RGBAImage.copy(h,o,{x:0,y:p-1},{x:c,y:u-1},{width:f,height:1}),t.RGBAImage.copy(h,o,{x:0,y:0},{x:c,y:u+p},{width:f,height:1}),t.RGBAImage.copy(h,o,{x:f-1,y:0},{x:c-1,y:u},{width:1,height:p}),t.RGBAImage.copy(h,o,{x:0,y:0},{x:c+f,y:u},{width:1,height:p})}this.dirty=!0},r.prototype.beginFrame=function(){this.callbackDispatchedThisFrame={}},r.prototype.dispatchRenderCallbacks=function(t){for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!this.callbackDispatchedThisFrame[n]){this.callbackDispatchedThisFrame[n]=!0;var i=this.images[n];h(i)&&this.updateImage(n,i)}}},r}(t.Evented),p=g,d=1e20;function g(t,e,r,n,i,a){this.fontSize=t||24,this.buffer=void 0===e?3:e,this.cutoff=n||.25,this.fontFamily=i||\"sans-serif\",this.fontWeight=a||\"normal\",this.radius=r||8;var o=this.size=this.fontSize+2*this.buffer;this.canvas=document.createElement(\"canvas\"),this.canvas.width=this.canvas.height=o,this.ctx=this.canvas.getContext(\"2d\"),this.ctx.font=this.fontWeight+\" \"+this.fontSize+\"px \"+this.fontFamily,this.ctx.textBaseline=\"middle\",this.ctx.fillStyle=\"black\",this.gridOuter=new Float64Array(o*o),this.gridInner=new Float64Array(o*o),this.f=new Float64Array(o),this.d=new Float64Array(o),this.z=new Float64Array(o+1),this.v=new Int16Array(o),this.middle=Math.round(o/2*(navigator.userAgent.indexOf(\"Gecko/\")>=0?1.2:1))}function v(t,e,r,n,i,a,o){for(var s=0;s<e;s++){for(var l=0;l<r;l++)n[l]=t[l*e+s];for(m(n,i,a,o,r),l=0;l<r;l++)t[l*e+s]=i[l]}for(l=0;l<r;l++){for(s=0;s<e;s++)n[s]=t[l*e+s];for(m(n,i,a,o,e),s=0;s<e;s++)t[l*e+s]=Math.sqrt(i[s])}}function m(t,e,r,n,i){r[0]=0,n[0]=-d,n[1]=+d;for(var a=1,o=0;a<i;a++){for(var s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);s<=n[o];)o--,s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);r[++o]=a,n[o]=s,n[o+1]=+d}for(a=0,o=0;a<i;a++){for(;n[o+1]<a;)o++;e[a]=(a-r[o])*(a-r[o])+t[r[o]]}}g.prototype.draw=function(t){this.ctx.clearRect(0,0,this.size,this.size),this.ctx.fillText(t,this.buffer,this.middle);for(var e=this.ctx.getImageData(0,0,this.size,this.size),r=new Uint8ClampedArray(this.size*this.size),n=0;n<this.size*this.size;n++){var i=e.data[4*n+3]/255;this.gridOuter[n]=1===i?0:0===i?d:Math.pow(Math.max(0,.5-i),2),this.gridInner[n]=1===i?d:0===i?0:Math.pow(Math.max(0,i-.5),2)}for(v(this.gridOuter,this.size,this.size,this.f,this.d,this.v,this.z),v(this.gridInner,this.size,this.size,this.f,this.d,this.v,this.z),n=0;n<this.size*this.size;n++){var a=this.gridOuter[n]-this.gridInner[n];r[n]=Math.max(0,Math.min(255,Math.round(255-255*(a/this.radius+this.cutoff))))}return r};var y=function(t,e){this.requestManager=t,this.localIdeographFontFamily=e,this.entries={}};y.prototype.setURL=function(t){this.url=t},y.prototype.getGlyphs=function(e,r){var n=this,i=[];for(var a in e)for(var o=0,s=e[a];o<s.length;o+=1){var l=s[o];i.push({stack:a,id:l})}t.asyncAll(i,function(t,e){var r=t.stack,i=t.id,a=n.entries[r];a||(a=n.entries[r]={glyphs:{},requests:{}});var o=a.glyphs[i];if(void 0===o)if(o=n._tinySDF(a,r,i))e(null,{stack:r,id:i,glyph:o});else{var s=Math.floor(i/256);if(256*s>65535)e(new Error(\"glyphs > 65535 not supported\"));else{var l=a.requests[s];l||(l=a.requests[s]=[],y.loadGlyphRange(r,s,n.url,n.requestManager,function(t,e){if(e)for(var r in e)a.glyphs[+r]=e[+r];for(var n=0,i=l;n<i.length;n+=1)(0,i[n])(t,e);delete a.requests[s]})),l.push(function(t,n){t?e(t):n&&e(null,{stack:r,id:i,glyph:n[i]||null})})}}else e(null,{stack:r,id:i,glyph:o})},function(t,e){if(t)r(t);else if(e){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.stack,l=o.id,c=o.glyph;(n[s]||(n[s]={}))[l]=c&&{id:c.id,bitmap:c.bitmap.clone(),metrics:c.metrics}}r(null,n)}})},y.prototype._tinySDF=function(e,r,n){var i=this.localIdeographFontFamily;if(i&&(t.isChar[\"CJK Unified Ideographs\"](n)||t.isChar[\"Hangul Syllables\"](n)||t.isChar.Hiragana(n)||t.isChar.Katakana(n))){var a=e.tinySDF;if(!a){var o=\"400\";/bold/i.test(r)?o=\"900\":/medium/i.test(r)?o=\"500\":/light/i.test(r)&&(o=\"200\"),a=e.tinySDF=new y.TinySDF(24,3,8,.25,i,o)}return{id:n,bitmap:new t.AlphaImage({width:30,height:30},a.draw(String.fromCharCode(n))),metrics:{width:24,height:24,left:0,top:-8,advance:24}}}},y.loadGlyphRange=function(e,r,n,i,a){var o=256*r,s=o+255,l=i.transformRequest(i.normalizeGlyphsURL(n).replace(\"{fontstack}\",e).replace(\"{range}\",o+\"-\"+s),t.ResourceType.Glyphs);t.getArrayBuffer(l,function(e,r){if(e)a(e);else if(r){for(var n={},i=0,o=t.parseGlyphPBF(r);i<o.length;i+=1){var s=o[i];n[s.id]=s}a(null,n)}})},y.TinySDF=p;var x=function(){this.specification=t.styleSpec.light.position};x.prototype.possiblyEvaluate=function(e,r){return t.sphericalToCartesian(e.expression.evaluate(r))},x.prototype.interpolate=function(e,r,n){return{x:t.number(e.x,r.x,n),y:t.number(e.y,r.y,n),z:t.number(e.z,r.z,n)}};var b=new t.Properties({anchor:new t.DataConstantProperty(t.styleSpec.light.anchor),position:new x,color:new t.DataConstantProperty(t.styleSpec.light.color),intensity:new t.DataConstantProperty(t.styleSpec.light.intensity)}),_=function(e){function r(r){e.call(this),this._transitionable=new t.Transitionable(b),this.setLight(r),this._transitioning=this._transitionable.untransitioned()}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getLight=function(){return this._transitionable.serialize()},r.prototype.setLight=function(e,r){if(void 0===r&&(r={}),!this._validate(t.validateLight,e,r))for(var n in e){var i=e[n];t.endsWith(n,\"-transition\")?this._transitionable.setTransition(n.slice(0,-\"-transition\".length),i):this._transitionable.setValue(n,i)}},r.prototype.updateTransitions=function(t){this._transitioning=this._transitionable.transitioned(t,this._transitioning)},r.prototype.hasTransition=function(){return this._transitioning.hasTransition()},r.prototype.recalculate=function(t){this.properties=this._transitioning.possiblyEvaluate(t)},r.prototype._validate=function(e,r,n){return(!n||!1!==n.validate)&&t.emitValidationErrors(this,e.call(t.validateStyle,t.extend({value:r,style:{glyphs:!0,sprite:!0},styleSpec:t.styleSpec})))},r}(t.Evented),w=function(t,e){this.width=t,this.height=e,this.nextRow=0,this.bytes=4,this.data=new Uint8Array(this.width*this.height*this.bytes),this.positions={}};w.prototype.getDash=function(t,e){var r=t.join(\",\")+String(e);return this.positions[r]||(this.positions[r]=this.addDash(t,e)),this.positions[r]},w.prototype.addDash=function(e,r){var n=r?7:0,i=2*n+1;if(this.nextRow+i>this.height)return t.warnOnce(\"LineAtlas out of space\"),null;for(var a=0,o=0;o<e.length;o++)a+=e[o];for(var s=this.width/a,l=s/2,c=e.length%2==1,u=-n;u<=n;u++)for(var h=this.nextRow+n+u,f=this.width*h,p=c?-e[e.length-1]:0,d=e[0],g=1,v=0;v<this.width;v++){for(;d<v/s;)p=d,d+=e[g],c&&g===e.length-1&&(d+=e[0]),g++;var m=Math.abs(v-p*s),y=Math.abs(v-d*s),x=Math.min(m,y),b=g%2==1,_=void 0;if(r){var w=n?u/n*(l+1):0;if(b){var k=l-Math.abs(w);_=Math.sqrt(x*x+k*k)}else _=l-Math.sqrt(x*x+w*w)}else _=(b?1:-1)*x;this.data[3+4*(f+v)]=Math.max(0,Math.min(255,_+128))}var T={y:(this.nextRow+n+.5)/this.height,height:2*n/this.height,width:a};return this.nextRow+=i,this.dirty=!0,T},w.prototype.bind=function(t){var e=t.gl;this.texture?(e.bindTexture(e.TEXTURE_2D,this.texture),this.dirty&&(this.dirty=!1,e.texSubImage2D(e.TEXTURE_2D,0,0,0,this.width,this.height,e.RGBA,e.UNSIGNED_BYTE,this.data))):(this.texture=e.createTexture(),e.bindTexture(e.TEXTURE_2D,this.texture),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_S,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_T,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,e.LINEAR),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,e.LINEAR),e.texImage2D(e.TEXTURE_2D,0,e.RGBA,this.width,this.height,0,e.RGBA,e.UNSIGNED_BYTE,this.data))};var k=function e(r,n){this.workerPool=r,this.actors=[],this.currentActor=0,this.id=t.uniqueId();for(var i=this.workerPool.acquire(this.id),a=0;a<i.length;a++){var o=i[a],s=new e.Actor(o,n,this.id);s.name=\"Worker \"+a,this.actors.push(s)}};function T(e,r,n){var i=function(i,a){if(i)return n(i);if(a){var o=t.pick(a,[\"tiles\",\"minzoom\",\"maxzoom\",\"attribution\",\"mapbox_logo\",\"bounds\"]);a.vector_layers&&(o.vectorLayers=a.vector_layers,o.vectorLayerIds=o.vectorLayers.map(function(t){return t.id})),e.url&&(o.tiles=r.canonicalizeTileset(o,e.url)),n(null,o)}};return e.url?t.getJSON(r.transformRequest(r.normalizeSourceURL(e.url),t.ResourceType.Source),i):t.browser.frame(function(){return i(null,e)})}k.prototype.broadcast=function(e,r,n){n=n||function(){},t.asyncAll(this.actors,function(t,n){t.send(e,r,n)},n)},k.prototype.send=function(t,e,r,n){return(\"number\"!=typeof n||isNaN(n))&&(n=this.currentActor=(this.currentActor+1)%this.actors.length),this.actors[n].send(t,e,r),n},k.prototype.remove=function(){this.actors.forEach(function(t){t.remove()}),this.actors=[],this.workerPool.release(this.id)},k.Actor=t.Actor;var A=function(e,r,n){this.bounds=t.LngLatBounds.convert(this.validateBounds(e)),this.minzoom=r||0,this.maxzoom=n||24};A.prototype.validateBounds=function(t){return Array.isArray(t)&&4===t.length?[Math.max(-180,t[0]),Math.max(-90,t[1]),Math.min(180,t[2]),Math.min(90,t[3])]:[-180,-90,180,90]},A.prototype.contains=function(e){var r=Math.pow(2,e.z),n=Math.floor(t.mercatorXfromLng(this.bounds.getWest())*r),i=Math.floor(t.mercatorYfromLat(this.bounds.getNorth())*r),a=Math.ceil(t.mercatorXfromLng(this.bounds.getEast())*r),o=Math.ceil(t.mercatorYfromLat(this.bounds.getSouth())*r);return e.x>=n&&e.x<a&&e.y>=i&&e.y<o};var M=function(e){function r(r,n,i,a){if(e.call(this),this.id=r,this.dispatcher=i,this.type=\"vector\",this.minzoom=0,this.maxzoom=22,this.scheme=\"xyz\",this.tileSize=512,this.reparseOverscaled=!0,this.isTileClipped=!0,t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"])),this._options=t.extend({type:\"vector\"},n),this._collectResourceTiming=n.collectResourceTiming,512!==this.tileSize)throw new Error(\"vector tile sources must have a tileSize of 512\");this.setEventedParent(a)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=T(this._options,this.map._requestManager,function(r,n){e._tileJSONRequest=null,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))})},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,null),i={request:this.map._requestManager.transformRequest(n,t.ResourceType.Tile),uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,tileSize:this.tileSize*e.tileID.overscaleFactor(),type:this.type,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes};function a(n,i){return e.aborted?r(null):n&&404!==n.status?r(n):(i&&i.resourceTiming&&(e.resourceTiming=i.resourceTiming),this.map._refreshExpiredTiles&&i&&e.setExpiryData(i),e.loadVectorData(i,this.map.painter),t.cacheEntryPossiblyAdded(this.dispatcher),r(null),void(e.reloadCallback&&(this.loadTile(e,e.reloadCallback),e.reloadCallback=null)))}i.request.collectResourceTiming=this._collectResourceTiming,void 0===e.workerID||\"expired\"===e.state?e.workerID=this.dispatcher.send(\"loadTile\",i,a.bind(this)):\"loading\"===e.state?e.reloadCallback=r:this.dispatcher.send(\"reloadTile\",i,a.bind(this),e.workerID)},r.prototype.abortTile=function(t){this.dispatcher.send(\"abortTile\",{uid:t.uid,type:this.type,source:this.id},void 0,t.workerID)},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.dispatcher.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},void 0,t.workerID)},r.prototype.hasTransition=function(){return!1},r}(t.Evented),S=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.dispatcher=i,this.setEventedParent(a),this.type=\"raster\",this.minzoom=0,this.maxzoom=22,this.roundZoom=!0,this.scheme=\"xyz\",this.tileSize=512,this._loaded=!1,this._options=t.extend({},n),t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"]))}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=T(this._options,this.map._requestManager,function(r,n){e._tileJSONRequest=null,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))})},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.loadTile=function(e,r){var n=this,i=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(i,t.ResourceType.Tile),function(i,a){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(i)e.state=\"errored\",r(i);else if(a){n.map._refreshExpiredTiles&&e.setExpiryData(a),delete a.cacheControl,delete a.expires;var o=n.map.painter.context,s=o.gl;e.texture=n.map.painter.getTileTexture(a.width),e.texture?e.texture.update(a,{useMipmap:!0}):(e.texture=new t.Texture(o,a,s.RGBA,{useMipmap:!0}),e.texture.bind(s.LINEAR,s.CLAMP_TO_EDGE,s.LINEAR_MIPMAP_NEAREST),o.extTextureFilterAnisotropic&&s.texParameterf(s.TEXTURE_2D,o.extTextureFilterAnisotropic.TEXTURE_MAX_ANISOTROPY_EXT,o.extTextureFilterAnisotropicMax)),e.state=\"loaded\",t.cacheEntryPossiblyAdded(n.dispatcher),r(null)}})},r.prototype.abortTile=function(t,e){t.request&&(t.request.cancel(),delete t.request),e()},r.prototype.unloadTile=function(t,e){t.texture&&this.map.painter.saveTileTexture(t.texture),e()},r.prototype.hasTransition=function(){return!1},r}(t.Evented),E=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),this.type=\"raster-dem\",this.maxzoom=22,this._options=t.extend({},n),this.encoding=n.encoding||\"mapbox\"}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.serialize=function(){return{type:\"raster-dem\",url:this.url,tileSize:this.tileSize,tiles:this.tiles,bounds:this.bounds,encoding:this.encoding}},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(n,t.ResourceType.Tile),function(n,i){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(n)e.state=\"errored\",r(n);else if(i){this.map._refreshExpiredTiles&&e.setExpiryData(i),delete i.cacheControl,delete i.expires;var a=t.browser.getImageData(i),o={uid:e.uid,coord:e.tileID,source:this.id,rawImageData:a,encoding:this.encoding};e.workerID&&\"expired\"!==e.state||(e.workerID=this.dispatcher.send(\"loadDEMTile\",o,function(t,n){t&&(e.state=\"errored\",r(t)),n&&(e.dem=n,e.needsHillshadePrepare=!0,e.state=\"loaded\",r(null))}.bind(this)))}}.bind(this)),e.neighboringTiles=this._getNeighboringTiles(e.tileID)},r.prototype._getNeighboringTiles=function(e){var r=e.canonical,n=Math.pow(2,r.z),i=(r.x-1+n)%n,a=0===r.x?e.wrap-1:e.wrap,o=(r.x+1+n)%n,s=r.x+1===n?e.wrap+1:e.wrap,l={};return l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y).key]={backfilled:!1},r.y>0&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y-1).key]={backfilled:!1}),r.y+1<n&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y+1).key]={backfilled:!1}),l},r.prototype.unloadTile=function(t){t.demTexture&&this.map.painter.saveTileTexture(t.demTexture),t.fbo&&(t.fbo.destroy(),delete t.fbo),t.dem&&delete t.dem,delete t.neighboringTiles,t.state=\"unloaded\",this.dispatcher.send(\"removeDEMTile\",{uid:t.uid,source:this.id},void 0,t.workerID)},r}(S),C=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.type=\"geojson\",this.minzoom=0,this.maxzoom=18,this.tileSize=512,this.isTileClipped=!0,this.reparseOverscaled=!0,this._removed=!1,this.dispatcher=i,this.setEventedParent(a),this._data=n.data,this._options=t.extend({},n),this._collectResourceTiming=n.collectResourceTiming,this._resourceTiming=[],void 0!==n.maxzoom&&(this.maxzoom=n.maxzoom),n.type&&(this.type=n.type),n.attribution&&(this.attribution=n.attribution);var o=t.EXTENT/this.tileSize;this.workerOptions=t.extend({source:this.id,cluster:n.cluster||!1,geojsonVtOptions:{buffer:(void 0!==n.buffer?n.buffer:128)*o,tolerance:(void 0!==n.tolerance?n.tolerance:.375)*o,extent:t.EXTENT,maxZoom:this.maxzoom,lineMetrics:n.lineMetrics||!1,generateId:n.generateId||!1},superclusterOptions:{maxZoom:void 0!==n.clusterMaxZoom?Math.min(n.clusterMaxZoom,this.maxzoom-1):this.maxzoom-1,extent:t.EXTENT,radius:(n.clusterRadius||50)*o,log:!1},clusterProperties:n.clusterProperties},n.workerOptions)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData(function(r){if(r)e.fire(new t.ErrorEvent(r));else{var n={dataType:\"source\",sourceDataType:\"metadata\"};e._collectResourceTiming&&e._resourceTiming&&e._resourceTiming.length>0&&(n.resourceTiming=e._resourceTiming,e._resourceTiming=[]),e.fire(new t.Event(\"data\",n))}})},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setData=function(e){var r=this;return this._data=e,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData(function(e){if(e)r.fire(new t.ErrorEvent(e));else{var n={dataType:\"source\",sourceDataType:\"content\"};r._collectResourceTiming&&r._resourceTiming&&r._resourceTiming.length>0&&(n.resourceTiming=r._resourceTiming,r._resourceTiming=[]),r.fire(new t.Event(\"data\",n))}}),this},r.prototype.getClusterExpansionZoom=function(t,e){return this.dispatcher.send(\"geojson.getClusterExpansionZoom\",{clusterId:t,source:this.id},e,this.workerID),this},r.prototype.getClusterChildren=function(t,e){return this.dispatcher.send(\"geojson.getClusterChildren\",{clusterId:t,source:this.id},e,this.workerID),this},r.prototype.getClusterLeaves=function(t,e,r,n){return this.dispatcher.send(\"geojson.getClusterLeaves\",{source:this.id,clusterId:t,limit:e,offset:r},n,this.workerID),this},r.prototype._updateWorkerData=function(e){var r=this,n=t.extend({},this.workerOptions),i=this._data;\"string\"==typeof i?(n.request=this.map._requestManager.transformRequest(t.browser.resolveURL(i),t.ResourceType.Source),n.request.collectResourceTiming=this._collectResourceTiming):n.data=JSON.stringify(i),this.workerID=this.dispatcher.send(this.type+\".loadData\",n,function(t,i){r._removed||i&&i.abandoned||(r._loaded=!0,i&&i.resourceTiming&&i.resourceTiming[r.id]&&(r._resourceTiming=i.resourceTiming[r.id].slice(0)),r.dispatcher.send(r.type+\".coalesce\",{source:n.source},null,r.workerID),e(t))},this.workerID)},r.prototype.loadTile=function(e,r){var n=this,i=void 0===e.workerID?\"loadTile\":\"reloadTile\",a={type:this.type,uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,maxZoom:this.maxzoom,tileSize:this.tileSize,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes};e.workerID=this.dispatcher.send(i,a,function(t,a){return e.unloadVectorData(),e.aborted?r(null):t?r(t):(e.loadVectorData(a,n.map.painter,\"reloadTile\"===i),r(null))},this.workerID)},r.prototype.abortTile=function(t){t.aborted=!0},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.dispatcher.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},null,t.workerID)},r.prototype.onRemove=function(){this._removed=!0,this.dispatcher.send(\"removeSource\",{type:this.type,source:this.id},null,this.workerID)},r.prototype.serialize=function(){return t.extend({},this._options,{type:this.type,data:this._data})},r.prototype.hasTransition=function(){return!1},r}(t.Evented),L=function(e){function r(t,r,n,i){e.call(this),this.id=t,this.dispatcher=n,this.coordinates=r.coordinates,this.type=\"image\",this.minzoom=0,this.maxzoom=22,this.tileSize=512,this.tiles={},this.setEventedParent(i),this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(e,r){var n=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this.url=this.options.url,t.getImage(this.map._requestManager.transformRequest(this.url,t.ResourceType.Image),function(i,a){i?n.fire(new t.ErrorEvent(i)):a&&(n.image=a,e&&(n.coordinates=e),r&&r(),n._finishLoading())})},r.prototype.updateImage=function(t){var e=this;return this.image&&t.url?(this.options.url=t.url,this.load(t.coordinates,function(){e.texture=null}),this):this},r.prototype._finishLoading=function(){this.map&&(this.setCoordinates(this.coordinates),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setCoordinates=function(e){var r=this;this.coordinates=e;var n=e.map(t.MercatorCoordinate.fromLngLat);this.tileID=function(e){for(var r=1/0,n=1/0,i=-1/0,a=-1/0,o=0,s=e;o<s.length;o+=1){var l=s[o];r=Math.min(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.x),a=Math.max(a,l.y)}var c=i-r,u=a-n,h=Math.max(c,u),f=Math.max(0,Math.floor(-Math.log(h)/Math.LN2)),p=Math.pow(2,f);return new t.CanonicalTileID(f,Math.floor((r+i)/2*p),Math.floor((n+a)/2*p))}(n),this.minzoom=this.maxzoom=this.tileID.z;var i=n.map(function(t){return r.tileID.getTilePoint(t)._round()});return this._boundsArray=new t.StructArrayLayout4i8,this._boundsArray.emplaceBack(i[0].x,i[0].y,0,0),this._boundsArray.emplaceBack(i[1].x,i[1].y,t.EXTENT,0),this._boundsArray.emplaceBack(i[3].x,i[3].y,0,t.EXTENT),this._boundsArray.emplaceBack(i[2].x,i[2].y,t.EXTENT,t.EXTENT),this.boundsBuffer&&(this.boundsBuffer.destroy(),delete this.boundsBuffer),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})),this},r.prototype.prepare=function(){if(0!==Object.keys(this.tiles).length&&this.image){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture||(this.texture=new t.Texture(e,this.image,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.loadTile=function(t,e){this.tileID&&this.tileID.equals(t.tileID.canonical)?(this.tiles[String(t.tileID.wrap)]=t,t.buckets={},e(null)):(t.state=\"errored\",e(null))},r.prototype.serialize=function(){return{type:\"image\",url:this.options.url,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return!1},r}(t.Evented),P=function(e){function r(t,r,n,i){e.call(this,t,r,n,i),this.roundZoom=!0,this.type=\"video\",this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this,r=this.options;this.urls=[];for(var n=0,i=r.urls;n<i.length;n+=1){var a=i[n];this.urls.push(this.map._requestManager.transformRequest(a,t.ResourceType.Source).url)}t.getVideo(this.urls,function(r,n){r?e.fire(new t.ErrorEvent(r)):n&&(e.video=n,e.video.loop=!0,e.video.addEventListener(\"playing\",function(){e.map.triggerRepaint()}),e.map&&e.video.play(),e._finishLoading())})},r.prototype.getVideo=function(){return this.video},r.prototype.onAdd=function(t){this.map||(this.map=t,this.load(),this.video&&(this.video.play(),this.setCoordinates(this.coordinates)))},r.prototype.prepare=function(){if(!(0===Object.keys(this.tiles).length||this.video.readyState<2)){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?this.video.paused||(this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE),r.texSubImage2D(r.TEXTURE_2D,0,0,0,r.RGBA,r.UNSIGNED_BYTE,this.video)):(this.texture=new t.Texture(e,this.video,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"video\",urls:this.urls,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this.video&&!this.video.paused},r}(L),O=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),n.coordinates?Array.isArray(n.coordinates)&&4===n.coordinates.length&&!n.coordinates.some(function(t){return!Array.isArray(t)||2!==t.length||t.some(function(t){return\"number\"!=typeof t})})||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"coordinates\" property must be an array of 4 longitude/latitude array pairs'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"coordinates\"'))),n.animate&&\"boolean\"!=typeof n.animate&&this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'optional \"animate\" property must be a boolean value'))),n.canvas?\"string\"==typeof n.canvas||n.canvas instanceof t.window.HTMLCanvasElement||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"canvas\" must be either a string representing the ID of the canvas element from which to read, or an HTMLCanvasElement instance'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"canvas\"'))),this.options=n,this.animate=void 0===n.animate||n.animate}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){this.canvas||(this.canvas=this.options.canvas instanceof t.window.HTMLCanvasElement?this.options.canvas:t.window.document.getElementById(this.options.canvas)),this.width=this.canvas.width,this.height=this.canvas.height,this._hasInvalidDimensions()?this.fire(new t.ErrorEvent(new Error(\"Canvas dimensions cannot be less than or equal to zero.\"))):(this.play=function(){this._playing=!0,this.map.triggerRepaint()},this.pause=function(){this._playing&&(this.prepare(),this._playing=!1)},this._finishLoading())},r.prototype.getCanvas=function(){return this.canvas},r.prototype.onAdd=function(t){this.map=t,this.load(),this.canvas&&this.animate&&this.play()},r.prototype.onRemove=function(){this.pause()},r.prototype.prepare=function(){var e=!1;if(this.canvas.width!==this.width&&(this.width=this.canvas.width,e=!0),this.canvas.height!==this.height&&(this.height=this.canvas.height,e=!0),!this._hasInvalidDimensions()&&0!==Object.keys(this.tiles).length){var r=this.map.painter.context,n=r.gl;for(var i in this.boundsBuffer||(this.boundsBuffer=r.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?(e||this._playing)&&this.texture.update(this.canvas,{premultiply:!0}):this.texture=new t.Texture(r,this.canvas,n.RGBA,{premultiply:!0}),this.tiles){var a=this.tiles[i];\"loaded\"!==a.state&&(a.state=\"loaded\",a.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"canvas\",coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this._playing},r.prototype._hasInvalidDimensions=function(){for(var t=0,e=[this.canvas.width,this.canvas.height];t<e.length;t+=1){var r=e[t];if(isNaN(r)||r<=0)return!0}return!1},r}(L),z={vector:M,raster:S,\"raster-dem\":E,geojson:C,video:P,image:L,canvas:O},I=function(e,r,n,i){var a=new z[r.type](e,r,n,i);if(a.id!==e)throw new Error(\"Expected Source id to be \"+e+\" instead of \"+a.id);return t.bindAll([\"load\",\"abort\",\"unload\",\"serialize\",\"prepare\"],a),a};function D(e,r){var n=t.identity([]);return t.translate(n,n,[1,1,0]),t.scale(n,n,[.5*e.width,.5*e.height,1]),t.multiply(n,n,e.calculatePosMatrix(r.toUnwrapped()))}function R(t,e,r,n,i){var a=function(t,e,r){if(t)for(var n=0,i=t;n<i.length;n+=1){var a=e[i[n]];if(a&&a.source===r&&\"fill-extrusion\"===a.type)return!0}else for(var o in e){var s=e[o];if(s.source===r&&\"fill-extrusion\"===s.type)return!0}return!1}(n&&n.layers,e,t.id),o=i.maxPitchScaleFactor(),s=t.tilesIn(r,o,a);s.sort(F);for(var l=[],c=0,u=s;c<u.length;c+=1){var h=u[c];l.push({wrappedTileID:h.tileID.wrapped().key,queryResults:h.tile.queryRenderedFeatures(e,t._state,h.queryGeometry,h.cameraQueryGeometry,h.scale,n,i,o,D(t.transform,h.tileID))})}var f=function(t){for(var e={},r={},n=0,i=t;n<i.length;n+=1){var a=i[n],o=a.queryResults,s=a.wrappedTileID,l=r[s]=r[s]||{};for(var c in o)for(var u=o[c],h=l[c]=l[c]||{},f=e[c]=e[c]||[],p=0,d=u;p<d.length;p+=1){var g=d[p];h[g.featureIndex]||(h[g.featureIndex]=!0,f.push(g))}}return e}(l);for(var p in f)f[p].forEach(function(e){var r=e.feature,n=t.getFeatureState(r.layer[\"source-layer\"],r.id);r.source=r.layer.source,r.layer[\"source-layer\"]&&(r.sourceLayer=r.layer[\"source-layer\"]),r.state=n});return f}function F(t,e){var r=t.tileID,n=e.tileID;return r.overscaledZ-n.overscaledZ||r.canonical.y-n.canonical.y||r.wrap-n.wrap||r.canonical.x-n.canonical.x}var B=function(t,e){this.max=t,this.onRemove=e,this.reset()};B.prototype.reset=function(){for(var t in this.data)for(var e=0,r=this.data[t];e<r.length;e+=1){var n=r[e];n.timeout&&clearTimeout(n.timeout),this.onRemove(n.value)}return this.data={},this.order=[],this},B.prototype.add=function(t,e,r){var n=this,i=t.wrapped().key;void 0===this.data[i]&&(this.data[i]=[]);var a={value:e,timeout:void 0};if(void 0!==r&&(a.timeout=setTimeout(function(){n.remove(t,a)},r)),this.data[i].push(a),this.order.push(i),this.order.length>this.max){var o=this._getAndRemoveByKey(this.order[0]);o&&this.onRemove(o)}return this},B.prototype.has=function(t){return t.wrapped().key in this.data},B.prototype.getAndRemove=function(t){return this.has(t)?this._getAndRemoveByKey(t.wrapped().key):null},B.prototype._getAndRemoveByKey=function(t){var e=this.data[t].shift();return e.timeout&&clearTimeout(e.timeout),0===this.data[t].length&&delete this.data[t],this.order.splice(this.order.indexOf(t),1),e.value},B.prototype.get=function(t){return this.has(t)?this.data[t.wrapped().key][0].value:null},B.prototype.remove=function(t,e){if(!this.has(t))return this;var r=t.wrapped().key,n=void 0===e?0:this.data[r].indexOf(e),i=this.data[r][n];return this.data[r].splice(n,1),i.timeout&&clearTimeout(i.timeout),0===this.data[r].length&&delete this.data[r],this.onRemove(i.value),this.order.splice(this.order.indexOf(r),1),this},B.prototype.setMaxSize=function(t){for(this.max=t;this.order.length>this.max;){var e=this._getAndRemoveByKey(this.order[0]);e&&this.onRemove(e)}return this};var N=function(t,e,r){this.context=t;var n=t.gl;this.buffer=n.createBuffer(),this.dynamicDraw=Boolean(r),this.context.unbindVAO(),t.bindElementBuffer.set(this.buffer),n.bufferData(n.ELEMENT_ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?n.DYNAMIC_DRAW:n.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};N.prototype.bind=function(){this.context.bindElementBuffer.set(this.buffer)},N.prototype.updateData=function(t){var e=this.context.gl;this.context.unbindVAO(),this.bind(),e.bufferSubData(e.ELEMENT_ARRAY_BUFFER,0,t.arrayBuffer)},N.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var j={Int8:\"BYTE\",Uint8:\"UNSIGNED_BYTE\",Int16:\"SHORT\",Uint16:\"UNSIGNED_SHORT\",Int32:\"INT\",Uint32:\"UNSIGNED_INT\",Float32:\"FLOAT\"},U=function(t,e,r,n){this.length=e.length,this.attributes=r,this.itemSize=e.bytesPerElement,this.dynamicDraw=n,this.context=t;var i=t.gl;this.buffer=i.createBuffer(),t.bindVertexBuffer.set(this.buffer),i.bufferData(i.ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?i.DYNAMIC_DRAW:i.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};U.prototype.bind=function(){this.context.bindVertexBuffer.set(this.buffer)},U.prototype.updateData=function(t){var e=this.context.gl;this.bind(),e.bufferSubData(e.ARRAY_BUFFER,0,t.arrayBuffer)},U.prototype.enableAttributes=function(t,e){for(var r=0;r<this.attributes.length;r++){var n=this.attributes[r],i=e.attributes[n.name];void 0!==i&&t.enableVertexAttribArray(i)}},U.prototype.setVertexAttribPointers=function(t,e,r){for(var n=0;n<this.attributes.length;n++){var i=this.attributes[n],a=e.attributes[i.name];void 0!==a&&t.vertexAttribPointer(a,i.components,t[j[i.type]],!1,this.itemSize,i.offset+this.itemSize*(r||0))}},U.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var V=function(t){this.gl=t.gl,this.default=this.getDefault(),this.current=this.default,this.dirty=!1};V.prototype.get=function(){return this.current},V.prototype.set=function(t){},V.prototype.getDefault=function(){return this.default},V.prototype.setDefault=function(){this.set(this.default)};var q=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.clearColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(V),H=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 1},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearDepth(t),this.current=t,this.dirty=!1)},e}(V),G=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearStencil(t),this.current=t,this.dirty=!1)},e}(V),Y=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return[!0,!0,!0,!0]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.colorMask(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(V),W=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthMask(t),this.current=t,this.dirty=!1)},e}(V),X=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 255},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.stencilMask(t),this.current=t,this.dirty=!1)},e}(V),Z=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return{func:this.gl.ALWAYS,ref:0,mask:255}},e.prototype.set=function(t){var e=this.current;(t.func!==e.func||t.ref!==e.ref||t.mask!==e.mask||this.dirty)&&(this.gl.stencilFunc(t.func,t.ref,t.mask),this.current=t,this.dirty=!1)},e}(V),J=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.KEEP,t.KEEP,t.KEEP]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||this.dirty)&&(this.gl.stencilOp(t[0],t[1],t[2]),this.current=t,this.dirty=!1)},e}(V),K=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.STENCIL_TEST):e.disable(e.STENCIL_TEST),this.current=t,this.dirty=!1}},e}(V),$=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return[0,1]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.depthRange(t[0],t[1]),this.current=t,this.dirty=!1)},e}(V),Q=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.DEPTH_TEST):e.disable(e.DEPTH_TEST),this.current=t,this.dirty=!1}},e}(V),tt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.LESS},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthFunc(t),this.current=t,this.dirty=!1)},e}(V),et=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.BLEND):e.disable(e.BLEND),this.current=t,this.dirty=!1}},e}(V),rt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.ONE,t.ZERO]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.blendFunc(t[0],t[1]),this.current=t,this.dirty=!1)},e}(V),nt=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.blendColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(V),it=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.FUNC_ADD},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.blendEquation(t),this.current=t,this.dirty=!1)},e}(V),at=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.CULL_FACE):e.disable(e.CULL_FACE),this.current=t,this.dirty=!1}},e}(V),ot=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.BACK},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.cullFace(t),this.current=t,this.dirty=!1)},e}(V),st=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.CCW},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.frontFace(t),this.current=t,this.dirty=!1)},e}(V),lt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.useProgram(t),this.current=t,this.dirty=!1)},e}(V),ct=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.TEXTURE0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.activeTexture(t),this.current=t,this.dirty=!1)},e}(V),ut=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[0,0,t.drawingBufferWidth,t.drawingBufferHeight]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.viewport(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(V),ht=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindFramebuffer(e.FRAMEBUFFER,t),this.current=t,this.dirty=!1}},e}(V),ft=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindRenderbuffer(e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(V),pt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindTexture(e.TEXTURE_2D,t),this.current=t,this.dirty=!1}},e}(V),dt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindBuffer(e.ARRAY_BUFFER,t),this.current=t,this.dirty=!1}},e}(V),gt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){var e=this.gl;e.bindBuffer(e.ELEMENT_ARRAY_BUFFER,t),this.current=t,this.dirty=!1},e}(V),vt=function(t){function e(e){t.call(this,e),this.vao=e.extVertexArrayObject}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){this.vao&&(t!==this.current||this.dirty)&&(this.vao.bindVertexArrayOES(t),this.current=t,this.dirty=!1)},e}(V),mt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 4},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_ALIGNMENT,t),this.current=t,this.dirty=!1}},e}(V),yt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_PREMULTIPLY_ALPHA_WEBGL,t),this.current=t,this.dirty=!1}},e}(V),xt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_FLIP_Y_WEBGL,t),this.current=t,this.dirty=!1}},e}(V),bt=function(t){function e(e,r){t.call(this,e),this.context=e,this.parent=r}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e}(V),_t=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.setDirty=function(){this.dirty=!0},e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferTexture2D(e.FRAMEBUFFER,e.COLOR_ATTACHMENT0,e.TEXTURE_2D,t,0),this.current=t,this.dirty=!1}},e}(bt),wt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferRenderbuffer(e.FRAMEBUFFER,e.DEPTH_ATTACHMENT,e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(bt),kt=function(t,e,r){this.context=t,this.width=e,this.height=r;var n=t.gl,i=this.framebuffer=n.createFramebuffer();this.colorAttachment=new _t(t,i),this.depthAttachment=new wt(t,i)};kt.prototype.destroy=function(){var t=this.context.gl,e=this.colorAttachment.get();e&&t.deleteTexture(e);var r=this.depthAttachment.get();r&&t.deleteRenderbuffer(r),t.deleteFramebuffer(this.framebuffer)};var Tt=function(t,e,r){this.func=t,this.mask=e,this.range=r};Tt.ReadOnly=!1,Tt.ReadWrite=!0,Tt.disabled=new Tt(519,Tt.ReadOnly,[0,1]);var At=function(t,e,r,n,i,a){this.test=t,this.ref=e,this.mask=r,this.fail=n,this.depthFail=i,this.pass=a};At.disabled=new At({func:519,mask:0},0,0,7680,7680,7680);var Mt=function(t,e,r){this.blendFunction=t,this.blendColor=e,this.mask=r};Mt.disabled=new Mt(Mt.Replace=[1,0],t.Color.transparent,[!1,!1,!1,!1]),Mt.unblended=new Mt(Mt.Replace,t.Color.transparent,[!0,!0,!0,!0]),Mt.alphaBlended=new Mt([1,771],t.Color.transparent,[!0,!0,!0,!0]);var St=function(t,e,r){this.enable=t,this.mode=e,this.frontFace=r};St.disabled=new St(!1,1029,2305),St.backCCW=new St(!0,1029,2305);var Et=function(t){this.gl=t,this.extVertexArrayObject=this.gl.getExtension(\"OES_vertex_array_object\"),this.clearColor=new q(this),this.clearDepth=new H(this),this.clearStencil=new G(this),this.colorMask=new Y(this),this.depthMask=new W(this),this.stencilMask=new X(this),this.stencilFunc=new Z(this),this.stencilOp=new J(this),this.stencilTest=new K(this),this.depthRange=new $(this),this.depthTest=new Q(this),this.depthFunc=new tt(this),this.blend=new et(this),this.blendFunc=new rt(this),this.blendColor=new nt(this),this.blendEquation=new it(this),this.cullFace=new at(this),this.cullFaceSide=new ot(this),this.frontFace=new st(this),this.program=new lt(this),this.activeTexture=new ct(this),this.viewport=new ut(this),this.bindFramebuffer=new ht(this),this.bindRenderbuffer=new ft(this),this.bindTexture=new pt(this),this.bindVertexBuffer=new dt(this),this.bindElementBuffer=new gt(this),this.bindVertexArrayOES=this.extVertexArrayObject&&new vt(this),this.pixelStoreUnpack=new mt(this),this.pixelStoreUnpackPremultiplyAlpha=new yt(this),this.pixelStoreUnpackFlipY=new xt(this),this.extTextureFilterAnisotropic=t.getExtension(\"EXT_texture_filter_anisotropic\")||t.getExtension(\"MOZ_EXT_texture_filter_anisotropic\")||t.getExtension(\"WEBKIT_EXT_texture_filter_anisotropic\"),this.extTextureFilterAnisotropic&&(this.extTextureFilterAnisotropicMax=t.getParameter(this.extTextureFilterAnisotropic.MAX_TEXTURE_MAX_ANISOTROPY_EXT)),this.extTextureHalfFloat=t.getExtension(\"OES_texture_half_float\"),this.extTextureHalfFloat&&t.getExtension(\"OES_texture_half_float_linear\")};Et.prototype.setDefault=function(){this.unbindVAO(),this.clearColor.setDefault(),this.clearDepth.setDefault(),this.clearStencil.setDefault(),this.colorMask.setDefault(),this.depthMask.setDefault(),this.stencilMask.setDefault(),this.stencilFunc.setDefault(),this.stencilOp.setDefault(),this.stencilTest.setDefault(),this.depthRange.setDefault(),this.depthTest.setDefault(),this.depthFunc.setDefault(),this.blend.setDefault(),this.blendFunc.setDefault(),this.blendColor.setDefault(),this.blendEquation.setDefault(),this.cullFace.setDefault(),this.cullFaceSide.setDefault(),this.frontFace.setDefault(),this.program.setDefault(),this.activeTexture.setDefault(),this.bindFramebuffer.setDefault(),this.pixelStoreUnpack.setDefault(),this.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.pixelStoreUnpackFlipY.setDefault()},Et.prototype.setDirty=function(){this.clearColor.dirty=!0,this.clearDepth.dirty=!0,this.clearStencil.dirty=!0,this.colorMask.dirty=!0,this.depthMask.dirty=!0,this.stencilMask.dirty=!0,this.stencilFunc.dirty=!0,this.stencilOp.dirty=!0,this.stencilTest.dirty=!0,this.depthRange.dirty=!0,this.depthTest.dirty=!0,this.depthFunc.dirty=!0,this.blend.dirty=!0,this.blendFunc.dirty=!0,this.blendColor.dirty=!0,this.blendEquation.dirty=!0,this.cullFace.dirty=!0,this.cullFaceSide.dirty=!0,this.frontFace.dirty=!0,this.program.dirty=!0,this.activeTexture.dirty=!0,this.viewport.dirty=!0,this.bindFramebuffer.dirty=!0,this.bindRenderbuffer.dirty=!0,this.bindTexture.dirty=!0,this.bindVertexBuffer.dirty=!0,this.bindElementBuffer.dirty=!0,this.extVertexArrayObject&&(this.bindVertexArrayOES.dirty=!0),this.pixelStoreUnpack.dirty=!0,this.pixelStoreUnpackPremultiplyAlpha.dirty=!0,this.pixelStoreUnpackFlipY.dirty=!0},Et.prototype.createIndexBuffer=function(t,e){return new N(this,t,e)},Et.prototype.createVertexBuffer=function(t,e,r){return new U(this,t,e,r)},Et.prototype.createRenderbuffer=function(t,e,r){var n=this.gl,i=n.createRenderbuffer();return this.bindRenderbuffer.set(i),n.renderbufferStorage(n.RENDERBUFFER,t,e,r),this.bindRenderbuffer.set(null),i},Et.prototype.createFramebuffer=function(t,e){return new kt(this,t,e)},Et.prototype.clear=function(t){var e=t.color,r=t.depth,n=this.gl,i=0;e&&(i|=n.COLOR_BUFFER_BIT,this.clearColor.set(e),this.colorMask.set([!0,!0,!0,!0])),void 0!==r&&(i|=n.DEPTH_BUFFER_BIT,this.depthRange.set([0,1]),this.clearDepth.set(r),this.depthMask.set(!0)),n.clear(i)},Et.prototype.setCullFace=function(t){!1===t.enable?this.cullFace.set(!1):(this.cullFace.set(!0),this.cullFaceSide.set(t.mode),this.frontFace.set(t.frontFace))},Et.prototype.setDepthMode=function(t){t.func!==this.gl.ALWAYS||t.mask?(this.depthTest.set(!0),this.depthFunc.set(t.func),this.depthMask.set(t.mask),this.depthRange.set(t.range)):this.depthTest.set(!1)},Et.prototype.setStencilMode=function(t){t.test.func!==this.gl.ALWAYS||t.mask?(this.stencilTest.set(!0),this.stencilMask.set(t.mask),this.stencilOp.set([t.fail,t.depthFail,t.pass]),this.stencilFunc.set({func:t.test.func,ref:t.ref,mask:t.test.mask})):this.stencilTest.set(!1)},Et.prototype.setColorMode=function(e){t.deepEqual(e.blendFunction,Mt.Replace)?this.blend.set(!1):(this.blend.set(!0),this.blendFunc.set(e.blendFunction),this.blendColor.set(e.blendColor)),this.colorMask.set(e.mask)},Et.prototype.unbindVAO=function(){this.extVertexArrayObject&&this.bindVertexArrayOES.set(null)};var Ct=function(e){function r(r,n,i){var a=this;e.call(this),this.id=r,this.dispatcher=i,this.on(\"data\",function(t){\"source\"===t.dataType&&\"metadata\"===t.sourceDataType&&(a._sourceLoaded=!0),a._sourceLoaded&&!a._paused&&\"source\"===t.dataType&&\"content\"===t.sourceDataType&&(a.reload(),a.transform&&a.update(a.transform))}),this.on(\"error\",function(){a._sourceErrored=!0}),this._source=I(r,n,i,this),this._tiles={},this._cache=new B(0,this._unloadTile.bind(this)),this._timers={},this._cacheTimers={},this._maxTileCacheSize=null,this._coveredTiles={},this._state=new t.SourceFeatureState}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.onAdd=function(t){this.map=t,this._maxTileCacheSize=t?t._maxTileCacheSize:null,this._source&&this._source.onAdd&&this._source.onAdd(t)},r.prototype.onRemove=function(t){this._source&&this._source.onRemove&&this._source.onRemove(t)},r.prototype.loaded=function(){if(this._sourceErrored)return!0;if(!this._sourceLoaded)return!1;for(var t in this._tiles){var e=this._tiles[t];if(\"loaded\"!==e.state&&\"errored\"!==e.state)return!1}return!0},r.prototype.getSource=function(){return this._source},r.prototype.pause=function(){this._paused=!0},r.prototype.resume=function(){if(this._paused){var t=this._shouldReloadOnResume;this._paused=!1,this._shouldReloadOnResume=!1,t&&this.reload(),this.transform&&this.update(this.transform)}},r.prototype._loadTile=function(t,e){return this._source.loadTile(t,e)},r.prototype._unloadTile=function(t){if(this._source.unloadTile)return this._source.unloadTile(t,function(){})},r.prototype._abortTile=function(t){if(this._source.abortTile)return this._source.abortTile(t,function(){})},r.prototype.serialize=function(){return this._source.serialize()},r.prototype.prepare=function(t){for(var e in this._source.prepare&&this._source.prepare(),this._state.coalesceChanges(this._tiles,this.map?this.map.painter:null),this._tiles){var r=this._tiles[e];r.upload(t),r.prepare(this.map.style.imageManager)}},r.prototype.getIds=function(){return Object.keys(this._tiles).map(Number).sort(Lt)},r.prototype.getRenderableIds=function(e){var r=this,n=[];for(var i in this._tiles)this._isIdRenderable(+i,e)&&n.push(+i);return e?n.sort(function(e,n){var i=r._tiles[e].tileID,a=r._tiles[n].tileID,o=new t.Point(i.canonical.x,i.canonical.y)._rotate(r.transform.angle),s=new t.Point(a.canonical.x,a.canonical.y)._rotate(r.transform.angle);return i.overscaledZ-a.overscaledZ||s.y-o.y||s.x-o.x}):n.sort(Lt)},r.prototype.hasRenderableParent=function(t){var e=this.findLoadedParent(t,0);return!!e&&this._isIdRenderable(e.tileID.key)},r.prototype._isIdRenderable=function(t,e){return this._tiles[t]&&this._tiles[t].hasData()&&!this._coveredTiles[t]&&(e||!this._tiles[t].holdingForFade())},r.prototype.reload=function(){if(this._paused)this._shouldReloadOnResume=!0;else for(var t in this._cache.reset(),this._tiles)\"errored\"!==this._tiles[t].state&&this._reloadTile(t,\"reloading\")},r.prototype._reloadTile=function(t,e){var r=this._tiles[t];r&&(\"loading\"!==r.state&&(r.state=e),this._loadTile(r,this._tileLoaded.bind(this,r,t,e)))},r.prototype._tileLoaded=function(e,r,n,i){if(i)return e.state=\"errored\",void(404!==i.status?this._source.fire(new t.ErrorEvent(i,{tile:e})):this.update(this.transform));e.timeAdded=t.browser.now(),\"expired\"===n&&(e.refreshedUponExpiration=!0),this._setTileReloadTimer(r,e),\"raster-dem\"===this.getSource().type&&e.dem&&this._backfillDEM(e),this._state.initializeTileState(e,this.map?this.map.painter:null),this._source.fire(new t.Event(\"data\",{dataType:\"source\",tile:e,coord:e.tileID}))},r.prototype._backfillDEM=function(t){for(var e=this.getRenderableIds(),r=0;r<e.length;r++){var n=e[r];if(t.neighboringTiles&&t.neighboringTiles[n]){var i=this.getTileByID(n);a(t,i),a(i,t)}}function a(t,e){t.needsHillshadePrepare=!0;var r=e.tileID.canonical.x-t.tileID.canonical.x,n=e.tileID.canonical.y-t.tileID.canonical.y,i=Math.pow(2,t.tileID.canonical.z),a=e.tileID.key;0===r&&0===n||Math.abs(n)>1||(Math.abs(r)>1&&(1===Math.abs(r+i)?r+=i:1===Math.abs(r-i)&&(r-=i)),e.dem&&t.dem&&(t.dem.backfillBorder(e.dem,r,n),t.neighboringTiles&&t.neighboringTiles[a]&&(t.neighboringTiles[a].backfilled=!0)))}},r.prototype.getTile=function(t){return this.getTileByID(t.key)},r.prototype.getTileByID=function(t){return this._tiles[t]},r.prototype.getZoom=function(t){return t.zoom+t.scaleZoom(t.tileSize/this._source.tileSize)},r.prototype._retainLoadedChildren=function(t,e,r,n){for(var i in this._tiles){var a=this._tiles[i];if(!(n[i]||!a.hasData()||a.tileID.overscaledZ<=e||a.tileID.overscaledZ>r)){for(var o=a.tileID;a&&a.tileID.overscaledZ>e+1;){var s=a.tileID.scaledTo(a.tileID.overscaledZ-1);(a=this._tiles[s.key])&&a.hasData()&&(o=s)}for(var l=o;l.overscaledZ>e;)if(t[(l=l.scaledTo(l.overscaledZ-1)).key]){n[o.key]=o;break}}}},r.prototype.findLoadedParent=function(t,e){for(var r=t.overscaledZ-1;r>=e;r--){var n=t.scaledTo(r);if(!n)return;var i=String(n.key),a=this._tiles[i];if(a&&a.hasData())return a;if(this._cache.has(n))return this._cache.get(n)}},r.prototype.updateCacheSize=function(t){var e=(Math.ceil(t.width/this._source.tileSize)+1)*(Math.ceil(t.height/this._source.tileSize)+1),r=Math.floor(5*e),n=\"number\"==typeof this._maxTileCacheSize?Math.min(this._maxTileCacheSize,r):r;this._cache.setMaxSize(n)},r.prototype.handleWrapJump=function(t){var e=(t-(void 0===this._prevLng?t:this._prevLng))/360,r=Math.round(e);if(this._prevLng=t,r){var n={};for(var i in this._tiles){var a=this._tiles[i];a.tileID=a.tileID.unwrapTo(a.tileID.wrap+r),n[a.tileID.key]=a}for(var o in this._tiles=n,this._timers)clearTimeout(this._timers[o]),delete this._timers[o];for(var s in this._tiles){var l=this._tiles[s];this._setTileReloadTimer(s,l)}}},r.prototype.update=function(e){var n=this;if(this.transform=e,this._sourceLoaded&&!this._paused){var i;this.updateCacheSize(e),this.handleWrapJump(this.transform.center.lng),this._coveredTiles={},this.used?this._source.tileID?i=e.getVisibleUnwrappedCoordinates(this._source.tileID).map(function(e){return new t.OverscaledTileID(e.canonical.z,e.wrap,e.canonical.z,e.canonical.x,e.canonical.y)}):(i=e.coveringTiles({tileSize:this._source.tileSize,minzoom:this._source.minzoom,maxzoom:this._source.maxzoom,roundZoom:this._source.roundZoom,reparseOverscaled:this._source.reparseOverscaled}),this._source.hasTile&&(i=i.filter(function(t){return n._source.hasTile(t)}))):i=[];var a=(this._source.roundZoom?Math.round:Math.floor)(this.getZoom(e)),o=Math.max(a-r.maxOverzooming,this._source.minzoom),s=Math.max(a+r.maxUnderzooming,this._source.minzoom),l=this._updateRetainedTiles(i,a);if(Pt(this._source.type)){for(var c={},u={},h=0,f=Object.keys(l);h<f.length;h+=1){var p=f[h],d=l[p],g=this._tiles[p];if(g&&!(g.fadeEndTime&&g.fadeEndTime<=t.browser.now())){var v=this.findLoadedParent(d,o);v&&(this._addTile(v.tileID),c[v.tileID.key]=v.tileID),u[p]=d}}for(var m in this._retainLoadedChildren(u,a,s,l),c)l[m]||(this._coveredTiles[m]=!0,l[m]=c[m])}for(var y in l)this._tiles[y].clearFadeHold();for(var x=0,b=t.keysDifference(this._tiles,l);x<b.length;x+=1){var _=b[x],w=this._tiles[_];w.hasSymbolBuckets&&!w.holdingForFade()?w.setHoldDuration(this.map._fadeDuration):w.hasSymbolBuckets&&!w.symbolFadeFinished()||this._removeTile(_)}}},r.prototype.releaseSymbolFadeTiles=function(){for(var t in this._tiles)this._tiles[t].holdingForFade()&&this._removeTile(t)},r.prototype._updateRetainedTiles=function(t,e){for(var n={},i={},a=Math.max(e-r.maxOverzooming,this._source.minzoom),o=Math.max(e+r.maxUnderzooming,this._source.minzoom),s={},l=0,c=t;l<c.length;l+=1){var u=c[l],h=this._addTile(u);n[u.key]=u,h.hasData()||e<this._source.maxzoom&&(s[u.key]=u)}this._retainLoadedChildren(s,e,o,n);for(var f=0,p=t;f<p.length;f+=1){var d=p[f],g=this._tiles[d.key];if(!g.hasData()){if(e+1>this._source.maxzoom){var v=d.children(this._source.maxzoom)[0],m=this.getTile(v);if(m&&m.hasData()){n[v.key]=v;continue}}else{var y=d.children(this._source.maxzoom);if(n[y[0].key]&&n[y[1].key]&&n[y[2].key]&&n[y[3].key])continue}for(var x=g.wasRequested(),b=d.overscaledZ-1;b>=a;--b){var _=d.scaledTo(b);if(i[_.key])break;if(i[_.key]=!0,!(g=this.getTile(_))&&x&&(g=this._addTile(_)),g&&(n[_.key]=_,x=g.wasRequested(),g.hasData()))break}}}return n},r.prototype._addTile=function(e){var r=this._tiles[e.key];if(r)return r;(r=this._cache.getAndRemove(e))&&(this._setTileReloadTimer(e.key,r),r.tileID=e,this._state.initializeTileState(r,this.map?this.map.painter:null),this._cacheTimers[e.key]&&(clearTimeout(this._cacheTimers[e.key]),delete this._cacheTimers[e.key],this._setTileReloadTimer(e.key,r)));var n=Boolean(r);return n||(r=new t.Tile(e,this._source.tileSize*e.overscaleFactor()),this._loadTile(r,this._tileLoaded.bind(this,r,e.key,r.state))),r?(r.uses++,this._tiles[e.key]=r,n||this._source.fire(new t.Event(\"dataloading\",{tile:r,coord:r.tileID,dataType:\"source\"})),r):null},r.prototype._setTileReloadTimer=function(t,e){var r=this;t in this._timers&&(clearTimeout(this._timers[t]),delete this._timers[t]);var n=e.getExpiryTimeout();n&&(this._timers[t]=setTimeout(function(){r._reloadTile(t,\"expired\"),delete r._timers[t]},n))},r.prototype._removeTile=function(t){var e=this._tiles[t];e&&(e.uses--,delete this._tiles[t],this._timers[t]&&(clearTimeout(this._timers[t]),delete this._timers[t]),e.uses>0||(e.hasData()?this._cache.add(e.tileID,e,e.getExpiryTimeout()):(e.aborted=!0,this._abortTile(e),this._unloadTile(e))))},r.prototype.clearTiles=function(){for(var t in this._shouldReloadOnResume=!1,this._paused=!1,this._tiles)this._removeTile(t);this._cache.reset()},r.prototype.tilesIn=function(e,r,n){var i=this,a=[],o=this.transform;if(!o)return a;for(var s=n?o.getCameraQueryGeometry(e):e,l=e.map(function(t){return o.pointCoordinate(t)}),c=s.map(function(t){return o.pointCoordinate(t)}),u=this.getIds(),h=1/0,f=1/0,p=-1/0,d=-1/0,g=0,v=c;g<v.length;g+=1){var m=v[g];h=Math.min(h,m.x),f=Math.min(f,m.y),p=Math.max(p,m.x),d=Math.max(d,m.y)}for(var y=function(e){var n=i._tiles[u[e]];if(!n.holdingForFade()){var s=n.tileID,g=Math.pow(2,o.zoom-n.tileID.overscaledZ),v=r*n.queryPadding*t.EXTENT/n.tileSize/g,m=[s.getTilePoint(new t.MercatorCoordinate(h,f)),s.getTilePoint(new t.MercatorCoordinate(p,d))];if(m[0].x-v<t.EXTENT&&m[0].y-v<t.EXTENT&&m[1].x+v>=0&&m[1].y+v>=0){var y=l.map(function(t){return s.getTilePoint(t)}),x=c.map(function(t){return s.getTilePoint(t)});a.push({tile:n,tileID:s,queryGeometry:y,cameraQueryGeometry:x,scale:g})}}},x=0;x<u.length;x++)y(x);return a},r.prototype.getVisibleCoordinates=function(t){for(var e=this,r=this.getRenderableIds(t).map(function(t){return e._tiles[t].tileID}),n=0,i=r;n<i.length;n+=1){var a=i[n];a.posMatrix=this.transform.calculatePosMatrix(a.toUnwrapped())}return r},r.prototype.hasTransition=function(){if(this._source.hasTransition())return!0;if(Pt(this._source.type))for(var e in this._tiles){var r=this._tiles[e];if(void 0!==r.fadeEndTime&&r.fadeEndTime>=t.browser.now())return!0}return!1},r.prototype.setFeatureState=function(t,e,r){t=t||\"_geojsonTileLayer\",this._state.updateState(t,e,r)},r.prototype.removeFeatureState=function(t,e,r){t=t||\"_geojsonTileLayer\",this._state.removeFeatureState(t,e,r)},r.prototype.getFeatureState=function(t,e){return t=t||\"_geojsonTileLayer\",this._state.getState(t,e)},r}(t.Evented);function Lt(t,e){return t%32-e%32||e-t}function Pt(t){return\"raster\"===t||\"image\"===t||\"video\"===t}function Ot(){return new t.window.Worker(Jn.workerUrl)}Ct.maxOverzooming=10,Ct.maxUnderzooming=3;var zt=function(){this.active={}};zt.prototype.acquire=function(t){if(!this.workers)for(this.workers=[];this.workers.length<zt.workerCount;)this.workers.push(new Ot);return this.active[t]=!0,this.workers.slice()},zt.prototype.release=function(t){delete this.active[t],0===Object.keys(this.active).length&&(this.workers.forEach(function(t){t.terminate()}),this.workers=null)};var It,Dt=Math.floor(t.browser.hardwareConcurrency/2);function Rt(e,r){var n={};for(var i in e)\"ref\"!==i&&(n[i]=e[i]);return t.refProperties.forEach(function(t){t in r&&(n[t]=r[t])}),n}function Ft(t){t=t.slice();for(var e=Object.create(null),r=0;r<t.length;r++)e[t[r].id]=t[r];for(var n=0;n<t.length;n++)\"ref\"in t[n]&&(t[n]=Rt(t[n],e[t[n].ref]));return t}zt.workerCount=Math.max(Math.min(Dt,6),1);var Bt={setStyle:\"setStyle\",addLayer:\"addLayer\",removeLayer:\"removeLayer\",setPaintProperty:\"setPaintProperty\",setLayoutProperty:\"setLayoutProperty\",setFilter:\"setFilter\",addSource:\"addSource\",removeSource:\"removeSource\",setGeoJSONSourceData:\"setGeoJSONSourceData\",setLayerZoomRange:\"setLayerZoomRange\",setLayerProperty:\"setLayerProperty\",setCenter:\"setCenter\",setZoom:\"setZoom\",setBearing:\"setBearing\",setPitch:\"setPitch\",setSprite:\"setSprite\",setGlyphs:\"setGlyphs\",setTransition:\"setTransition\",setLight:\"setLight\"};function Nt(t,e,r){r.push({command:Bt.addSource,args:[t,e[t]]})}function jt(t,e,r){e.push({command:Bt.removeSource,args:[t]}),r[t]=!0}function Ut(t,e,r,n){jt(t,r,n),Nt(t,e,r)}function Vt(e,r,n){var i;for(i in e[n])if(e[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;for(i in r[n])if(r[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;return!0}function qt(e,r,n,i,a,o){var s;for(s in r=r||{},e=e||{})e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}));for(s in r)r.hasOwnProperty(s)&&!e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}))}function Ht(t){return t.id}function Gt(t,e){return t[e.id]=e,t}var Yt=function(t,e,r){var n=this.boxCells=[],i=this.circleCells=[];this.xCellCount=Math.ceil(t/r),this.yCellCount=Math.ceil(e/r);for(var a=0;a<this.xCellCount*this.yCellCount;a++)n.push([]),i.push([]);this.circleKeys=[],this.boxKeys=[],this.bboxes=[],this.circles=[],this.width=t,this.height=e,this.xScale=this.xCellCount/t,this.yScale=this.yCellCount/e,this.boxUid=0,this.circleUid=0};function Wt(e,r,n,i,a){var o=t.create();return r?(t.scale(o,o,[1/a,1/a,1]),n||t.rotateZ(o,o,i.angle)):t.multiply(o,i.labelPlaneMatrix,e),o}function Xt(e,r,n,i,a){if(r){var o=t.clone(e);return t.scale(o,o,[a,a,1]),n||t.rotateZ(o,o,-i.angle),o}return i.glCoordMatrix}function Zt(e,r){var n=[e.x,e.y,0,1];ae(n,n,r);var i=n[3];return{point:new t.Point(n[0]/i,n[1]/i),signedDistanceFromCamera:i}}function Jt(t,e){var r=t[0]/t[3],n=t[1]/t[3];return r>=-e[0]&&r<=e[0]&&n>=-e[1]&&n<=e[1]}function Kt(e,r,n,i,a,o,s,l){var c=i?e.textSizeData:e.iconSizeData,u=t.evaluateSizeForZoom(c,n.transform.zoom),h=[256/n.width*2+1,256/n.height*2+1],f=i?e.text.dynamicLayoutVertexArray:e.icon.dynamicLayoutVertexArray;f.clear();for(var p=e.lineVertexArray,d=i?e.text.placedSymbolArray:e.icon.placedSymbolArray,g=n.transform.width/n.transform.height,v=!1,m=0;m<d.length;m++){var y=d.get(m);if(y.hidden||y.writingMode===t.WritingMode.vertical&&!v)ie(y.numGlyphs,f);else{v=!1;var x=[y.anchorX,y.anchorY,0,1];if(t.transformMat4(x,x,r),Jt(x,h)){var b=.5+x[3]/n.transform.cameraToCenterDistance*.5,_=t.evaluateSizeForFeature(c,u,y),w=s?_*b:_/b,k=new t.Point(y.anchorX,y.anchorY),T=Zt(k,a).point,A={},M=te(y,w,!1,l,r,a,o,e.glyphOffsetArray,p,f,T,k,A,g);v=M.useVertical,(M.notEnoughRoom||v||M.needsFlipping&&te(y,w,!0,l,r,a,o,e.glyphOffsetArray,p,f,T,k,A,g).notEnoughRoom)&&ie(y.numGlyphs,f)}else ie(y.numGlyphs,f)}}i?e.text.dynamicLayoutVertexBuffer.updateData(f):e.icon.dynamicLayoutVertexBuffer.updateData(f)}function $t(t,e,r,n,i,a,o,s,l,c,u,h){var f=s.glyphStartIndex+s.numGlyphs,p=s.lineStartIndex,d=s.lineStartIndex+s.lineLength,g=e.getoffsetX(s.glyphStartIndex),v=e.getoffsetX(f-1),m=re(t*g,r,n,i,a,o,s.segment,p,d,l,c,u,h);if(!m)return null;var y=re(t*v,r,n,i,a,o,s.segment,p,d,l,c,u,h);return y?{first:m,last:y}:null}function Qt(e,r,n,i){return e===t.WritingMode.horizontal&&Math.abs(n.y-r.y)>Math.abs(n.x-r.x)*i?{useVertical:!0}:(e===t.WritingMode.vertical?r.y<n.y:r.x>n.x)?{needsFlipping:!0}:null}function te(e,r,n,i,a,o,s,l,c,u,h,f,p,d){var g,v=r/24,m=e.lineOffsetX*v,y=e.lineOffsetY*v;if(e.numGlyphs>1){var x=e.glyphStartIndex+e.numGlyphs,b=e.lineStartIndex,_=e.lineStartIndex+e.lineLength,w=$t(v,l,m,y,n,h,f,e,c,o,p,!1);if(!w)return{notEnoughRoom:!0};var k=Zt(w.first.point,s).point,T=Zt(w.last.point,s).point;if(i&&!n){var A=Qt(e.writingMode,k,T,d);if(A)return A}g=[w.first];for(var M=e.glyphStartIndex+1;M<x-1;M++)g.push(re(v*l.getoffsetX(M),m,y,n,h,f,e.segment,b,_,c,o,p,!1));g.push(w.last)}else{if(i&&!n){var S=Zt(f,a).point,E=e.lineStartIndex+e.segment+1,C=new t.Point(c.getx(E),c.gety(E)),L=Zt(C,a),P=L.signedDistanceFromCamera>0?L.point:ee(f,C,S,1,a),O=Qt(e.writingMode,S,P,d);if(O)return O}var z=re(v*l.getoffsetX(e.glyphStartIndex),m,y,n,h,f,e.segment,e.lineStartIndex,e.lineStartIndex+e.lineLength,c,o,p,!1);if(!z)return{notEnoughRoom:!0};g=[z]}for(var I=0,D=g;I<D.length;I+=1){var R=D[I];t.addDynamicAttributes(u,R.point,R.angle)}return{}}function ee(t,e,r,n,i){var a=Zt(t.add(t.sub(e)._unit()),i).point,o=r.sub(a);return r.add(o._mult(n/o.mag()))}function re(e,r,n,i,a,o,s,l,c,u,h,f,p){var d=i?e-r:e+r,g=d>0?1:-1,v=0;i&&(g*=-1,v=Math.PI),g<0&&(v+=Math.PI);for(var m=g>0?l+s:l+s+1,y=m,x=a,b=a,_=0,w=0,k=Math.abs(d);_+w<=k;){if((m+=g)<l||m>=c)return null;if(b=x,void 0===(x=f[m])){var T=new t.Point(u.getx(m),u.gety(m)),A=Zt(T,h);if(A.signedDistanceFromCamera>0)x=f[m]=A.point;else{var M=m-g;x=ee(0===_?o:new t.Point(u.getx(M),u.gety(M)),T,b,k-_+1,h)}}_+=w,w=b.dist(x)}var S=(k-_)/w,E=x.sub(b),C=E.mult(S)._add(b);return C._add(E._unit()._perp()._mult(n*g)),{point:C,angle:v+Math.atan2(x.y-b.y,x.x-b.x),tileDistance:p?{prevTileDistance:m-g===y?0:u.gettileUnitDistanceFromAnchor(m-g),lastSegmentViewportDistance:k-_}:null}}Yt.prototype.keysLength=function(){return this.boxKeys.length+this.circleKeys.length},Yt.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertBoxCell,this.boxUid++),this.boxKeys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},Yt.prototype.insertCircle=function(t,e,r,n){this._forEachCell(e-n,r-n,e+n,r+n,this._insertCircleCell,this.circleUid++),this.circleKeys.push(t),this.circles.push(e),this.circles.push(r),this.circles.push(n)},Yt.prototype._insertBoxCell=function(t,e,r,n,i,a){this.boxCells[i].push(a)},Yt.prototype._insertCircleCell=function(t,e,r,n,i,a){this.circleCells[i].push(a)},Yt.prototype._query=function(t,e,r,n,i,a){if(r<0||t>this.width||n<0||e>this.height)return!i&&[];var o=[];if(t<=0&&e<=0&&this.width<=r&&this.height<=n){if(i)return!0;for(var s=0;s<this.boxKeys.length;s++)o.push({key:this.boxKeys[s],x1:this.bboxes[4*s],y1:this.bboxes[4*s+1],x2:this.bboxes[4*s+2],y2:this.bboxes[4*s+3]});for(var l=0;l<this.circleKeys.length;l++){var c=this.circles[3*l],u=this.circles[3*l+1],h=this.circles[3*l+2];o.push({key:this.circleKeys[l],x1:c-h,y1:u-h,x2:c+h,y2:u+h})}return a?o.filter(a):o}var f={hitTest:i,seenUids:{box:{},circle:{}}};return this._forEachCell(t,e,r,n,this._queryCell,o,f,a),i?o.length>0:o},Yt.prototype._queryCircle=function(t,e,r,n,i){var a=t-r,o=t+r,s=e-r,l=e+r;if(o<0||a>this.width||l<0||s>this.height)return!n&&[];var c=[],u={hitTest:n,circle:{x:t,y:e,radius:r},seenUids:{box:{},circle:{}}};return this._forEachCell(a,s,o,l,this._queryCellCircle,c,u,i),n?c.length>0:c},Yt.prototype.query=function(t,e,r,n,i){return this._query(t,e,r,n,!1,i)},Yt.prototype.hitTest=function(t,e,r,n,i){return this._query(t,e,r,n,!0,i)},Yt.prototype.hitTestCircle=function(t,e,r,n){return this._queryCircle(t,e,r,!0,n)},Yt.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=o.seenUids,c=this.boxCells[i];if(null!==c)for(var u=this.bboxes,h=0,f=c;h<f.length;h+=1){var p=f[h];if(!l.box[p]){l.box[p]=!0;var d=4*p;if(t<=u[d+2]&&e<=u[d+3]&&r>=u[d+0]&&n>=u[d+1]&&(!s||s(this.boxKeys[p]))){if(o.hitTest)return a.push(!0),!0;a.push({key:this.boxKeys[p],x1:u[d],y1:u[d+1],x2:u[d+2],y2:u[d+3]})}}}var g=this.circleCells[i];if(null!==g)for(var v=this.circles,m=0,y=g;m<y.length;m+=1){var x=y[m];if(!l.circle[x]){l.circle[x]=!0;var b=3*x;if(this._circleAndRectCollide(v[b],v[b+1],v[b+2],t,e,r,n)&&(!s||s(this.circleKeys[x]))){if(o.hitTest)return a.push(!0),!0;var _=v[b],w=v[b+1],k=v[b+2];a.push({key:this.circleKeys[x],x1:_-k,y1:w-k,x2:_+k,y2:w+k})}}}},Yt.prototype._queryCellCircle=function(t,e,r,n,i,a,o,s){var l=o.circle,c=o.seenUids,u=this.boxCells[i];if(null!==u)for(var h=this.bboxes,f=0,p=u;f<p.length;f+=1){var d=p[f];if(!c.box[d]){c.box[d]=!0;var g=4*d;if(this._circleAndRectCollide(l.x,l.y,l.radius,h[g+0],h[g+1],h[g+2],h[g+3])&&(!s||s(this.boxKeys[d])))return a.push(!0),!0}}var v=this.circleCells[i];if(null!==v)for(var m=this.circles,y=0,x=v;y<x.length;y+=1){var b=x[y];if(!c.circle[b]){c.circle[b]=!0;var _=3*b;if(this._circlesCollide(m[_],m[_+1],m[_+2],l.x,l.y,l.radius)&&(!s||s(this.circleKeys[b])))return a.push(!0),!0}}},Yt.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToXCellCoord(t),c=this._convertToYCellCoord(e),u=this._convertToXCellCoord(r),h=this._convertToYCellCoord(n),f=l;f<=u;f++)for(var p=c;p<=h;p++){var d=this.xCellCount*p+f;if(i.call(this,t,e,r,n,d,a,o,s))return}},Yt.prototype._convertToXCellCoord=function(t){return Math.max(0,Math.min(this.xCellCount-1,Math.floor(t*this.xScale)))},Yt.prototype._convertToYCellCoord=function(t){return Math.max(0,Math.min(this.yCellCount-1,Math.floor(t*this.yScale)))},Yt.prototype._circlesCollide=function(t,e,r,n,i,a){var o=n-t,s=i-e,l=r+a;return l*l>o*o+s*s},Yt.prototype._circleAndRectCollide=function(t,e,r,n,i,a,o){var s=(a-n)/2,l=Math.abs(t-(n+s));if(l>s+r)return!1;var c=(o-i)/2,u=Math.abs(e-(i+c));if(u>c+r)return!1;if(l<=s||u<=c)return!0;var h=l-s,f=u-c;return h*h+f*f<=r*r};var ne=new Float32Array([-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0]);function ie(t,e){for(var r=0;r<t;r++){var n=e.length;e.resize(n+4),e.float32.set(ne,3*n)}}function ae(t,e,r){var n=e[0],i=e[1];return t[0]=r[0]*n+r[4]*i+r[12],t[1]=r[1]*n+r[5]*i+r[13],t[3]=r[3]*n+r[7]*i+r[15],t}var oe=function(t,e,r){void 0===e&&(e=new Yt(t.width+200,t.height+200,25)),void 0===r&&(r=new Yt(t.width+200,t.height+200,25)),this.transform=t,this.grid=e,this.ignoredGrid=r,this.pitchfactor=Math.cos(t._pitch)*t.cameraToCenterDistance,this.screenRightBoundary=t.width+100,this.screenBottomBoundary=t.height+100,this.gridRightBoundary=t.width+200,this.gridBottomBoundary=t.height+200};function se(t,e,r){t[e+4]=r?1:0}function le(e,r,n){return r*(t.EXTENT/(e.tileSize*Math.pow(2,n-e.tileID.overscaledZ)))}oe.prototype.placeCollisionBox=function(t,e,r,n,i){var a=this.projectAndGetPerspectiveRatio(n,t.anchorPointX,t.anchorPointY),o=r*a.perspectiveRatio,s=t.x1*o+a.point.x,l=t.y1*o+a.point.y,c=t.x2*o+a.point.x,u=t.y2*o+a.point.y;return!this.isInsideGrid(s,l,c,u)||!e&&this.grid.hitTest(s,l,c,u,i)?{box:[],offscreen:!1}:{box:[s,l,c,u],offscreen:this.isOffscreen(s,l,c,u)}},oe.prototype.approximateTileDistance=function(t,e,r,n,i){var a=i?1:n/this.pitchfactor,o=t.lastSegmentViewportDistance*r;return t.prevTileDistance+o+(a-1)*o*Math.abs(Math.sin(e))},oe.prototype.placeCollisionCircles=function(e,r,n,i,a,o,s,l,c,u,h,f,p){var d=[],g=this.projectAnchor(c,a.anchorX,a.anchorY),v=l/24,m=a.lineOffsetX*l,y=a.lineOffsetY*l,x=new t.Point(a.anchorX,a.anchorY),b=$t(v,s,m,y,!1,Zt(x,u).point,x,a,o,u,{},!0),_=!1,w=!1,k=!0,T=g.perspectiveRatio*i,A=1/(i*n),M=0,S=0;b&&(M=this.approximateTileDistance(b.first.tileDistance,b.first.angle,A,g.cameraDistance,f),S=this.approximateTileDistance(b.last.tileDistance,b.last.angle,A,g.cameraDistance,f));for(var E=0;E<e.length;E+=5){var C=e[E],L=e[E+1],P=e[E+2],O=e[E+3];if(!b||O<-M||O>S)se(e,E,!1);else{var z=this.projectPoint(c,C,L),I=P*T;if(d.length>0){var D=z.x-d[d.length-4],R=z.y-d[d.length-3];if(I*I*2>D*D+R*R&&E+8<e.length){var F=e[E+8];if(F>-M&&F<S){se(e,E,!1);continue}}}var B=E/5;d.push(z.x,z.y,I,B),se(e,E,!0);var N=z.x-I,j=z.y-I,U=z.x+I,V=z.y+I;if(k=k&&this.isOffscreen(N,j,U,V),w=w||this.isInsideGrid(N,j,U,V),!r&&this.grid.hitTestCircle(z.x,z.y,I,p)){if(!h)return{circles:[],offscreen:!1};_=!0}}}return{circles:_||!w?[]:d,offscreen:k}},oe.prototype.queryRenderedSymbols=function(e){if(0===e.length||0===this.grid.keysLength()&&0===this.ignoredGrid.keysLength())return{};for(var r=[],n=1/0,i=1/0,a=-1/0,o=-1/0,s=0,l=e;s<l.length;s+=1){var c=l[s],u=new t.Point(c.x+100,c.y+100);n=Math.min(n,u.x),i=Math.min(i,u.y),a=Math.max(a,u.x),o=Math.max(o,u.y),r.push(u)}for(var h={},f={},p=0,d=this.grid.query(n,i,a,o).concat(this.ignoredGrid.query(n,i,a,o));p<d.length;p+=1){var g=d[p],v=g.key;if(void 0===h[v.bucketInstanceId]&&(h[v.bucketInstanceId]={}),!h[v.bucketInstanceId][v.featureIndex]){var m=[new t.Point(g.x1,g.y1),new t.Point(g.x2,g.y1),new t.Point(g.x2,g.y2),new t.Point(g.x1,g.y2)];t.polygonIntersectsPolygon(r,m)&&(h[v.bucketInstanceId][v.featureIndex]=!0,void 0===f[v.bucketInstanceId]&&(f[v.bucketInstanceId]=[]),f[v.bucketInstanceId].push(v.featureIndex))}}return f},oe.prototype.insertCollisionBox=function(t,e,r,n,i){var a={bucketInstanceId:r,featureIndex:n,collisionGroupID:i};(e?this.ignoredGrid:this.grid).insert(a,t[0],t[1],t[2],t[3])},oe.prototype.insertCollisionCircles=function(t,e,r,n,i){for(var a=e?this.ignoredGrid:this.grid,o={bucketInstanceId:r,featureIndex:n,collisionGroupID:i},s=0;s<t.length;s+=4)a.insertCircle(o,t[s],t[s+1],t[s+2])},oe.prototype.projectAnchor=function(t,e,r){var n=[e,r,0,1];return ae(n,n,t),{perspectiveRatio:.5+this.transform.cameraToCenterDistance/n[3]*.5,cameraDistance:n[3]}},oe.prototype.projectPoint=function(e,r,n){var i=[r,n,0,1];return ae(i,i,e),new t.Point((i[0]/i[3]+1)/2*this.transform.width+100,(-i[1]/i[3]+1)/2*this.transform.height+100)},oe.prototype.projectAndGetPerspectiveRatio=function(e,r,n){var i=[r,n,0,1];return ae(i,i,e),{point:new t.Point((i[0]/i[3]+1)/2*this.transform.width+100,(-i[1]/i[3]+1)/2*this.transform.height+100),perspectiveRatio:.5+this.transform.cameraToCenterDistance/i[3]*.5}},oe.prototype.isOffscreen=function(t,e,r,n){return r<100||t>=this.screenRightBoundary||n<100||e>this.screenBottomBoundary},oe.prototype.isInsideGrid=function(t,e,r,n){return r>=0&&t<this.gridRightBoundary&&n>=0&&e<this.gridBottomBoundary};var ce=function(t,e,r,n){this.opacity=t?Math.max(0,Math.min(1,t.opacity+(t.placed?e:-e))):n&&r?1:0,this.placed=r};ce.prototype.isHidden=function(){return 0===this.opacity&&!this.placed};var ue=function(t,e,r,n,i){this.text=new ce(t?t.text:null,e,r,i),this.icon=new ce(t?t.icon:null,e,n,i)};ue.prototype.isHidden=function(){return this.text.isHidden()&&this.icon.isHidden()};var he=function(t,e,r){this.text=t,this.icon=e,this.skipFade=r},fe=function(t,e,r,n,i){this.bucketInstanceId=t,this.featureIndex=e,this.sourceLayerIndex=r,this.bucketIndex=n,this.tileID=i},pe=function(t){this.crossSourceCollisions=t,this.maxGroupID=0,this.collisionGroups={}};function de(e,r,n,i,a){var o=t.getAnchorAlignment(e),s=-(o.horizontalAlign-.5)*r,l=-(o.verticalAlign-.5)*n,c=t.evaluateRadialOffset(e,i);return new t.Point(s+c[0]*a,l+c[1]*a)}pe.prototype.get=function(t){if(this.crossSourceCollisions)return{ID:0,predicate:null};if(!this.collisionGroups[t]){var e=++this.maxGroupID;this.collisionGroups[t]={ID:e,predicate:function(t){return t.collisionGroupID===e}}}return this.collisionGroups[t]};var ge=function(t,e,r,n){this.transform=t.clone(),this.collisionIndex=new oe(this.transform),this.placements={},this.opacities={},this.variableOffsets={},this.stale=!1,this.commitTime=0,this.fadeDuration=e,this.retainedQueryData={},this.collisionGroups=new pe(r),this.prevPlacement=n,n&&(n.prevPlacement=void 0)};function ve(t,e,r,n,i){t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0)}ge.prototype.placeLayerTile=function(e,r,n,i){var a=r.getBucket(e),o=r.latestFeatureIndex;if(a&&o&&e.id===a.layerIds[0]){var s=r.collisionBoxArray,l=a.layers[0].layout,c=Math.pow(2,this.transform.zoom-r.tileID.overscaledZ),u=r.tileSize/t.EXTENT,h=this.transform.calculatePosMatrix(r.tileID.toUnwrapped()),f=Wt(h,\"map\"===l.get(\"text-pitch-alignment\"),\"map\"===l.get(\"text-rotation-alignment\"),this.transform,le(r,1,this.transform.zoom)),p=Wt(h,\"map\"===l.get(\"icon-pitch-alignment\"),\"map\"===l.get(\"icon-rotation-alignment\"),this.transform,le(r,1,this.transform.zoom));this.retainedQueryData[a.bucketInstanceId]=new fe(a.bucketInstanceId,o,a.sourceLayerIndex,a.index,r.tileID),this.placeLayerBucket(a,h,f,p,c,u,n,r.holdingForFade(),i,s)}},ge.prototype.attemptAnchorPlacement=function(e,r,n,i,a,o,s,l,c,u,h,f,p,d){var g,v=de(e,n,i,a,o),m=this.collisionIndex.placeCollisionBox(function(e,r,n,i,a,o){var s=e.x1,l=e.x2,c=e.y1,u=e.y2,h=e.anchorPointX,f=e.anchorPointY,p=new t.Point(r,n);return i&&p._rotate(a?o:-o),{x1:s+p.x,y1:c+p.y,x2:l+p.x,y2:u+p.y,anchorPointX:h,anchorPointY:f}}(r,v.x,v.y,s,l,this.transform.angle),f,c,u,h.predicate);if(m.box.length>0)return this.prevPlacement&&this.prevPlacement.variableOffsets[p.crossTileID]&&this.prevPlacement.placements[p.crossTileID]&&this.prevPlacement.placements[p.crossTileID].text&&(g=this.prevPlacement.variableOffsets[p.crossTileID].anchor),this.variableOffsets[p.crossTileID]={radialOffset:a,width:n,height:i,anchor:e,textBoxScale:o,prevAnchor:g},this.markUsedJustification(d,e,p),m},ge.prototype.placeLayerBucket=function(e,r,n,i,a,o,s,l,c,u){var h=this,f=e.layers[0].layout,p=t.evaluateSizeForZoom(e.textSizeData,this.transform.zoom),d=f.get(\"text-optional\"),g=f.get(\"icon-optional\"),v=f.get(\"text-allow-overlap\"),m=f.get(\"icon-allow-overlap\"),y=v&&(m||!e.hasIconData()||g),x=m&&(v||!e.hasTextData()||d),b=this.collisionGroups.get(e.sourceID),_=\"map\"===f.get(\"text-rotation-alignment\"),w=\"map\"===f.get(\"text-pitch-alignment\"),k=\"viewport-y\"===f.get(\"symbol-z-order\");!e.collisionArrays&&u&&e.deserializeCollisionBoxes(u);var T=function(i,u){if(!c[i.crossTileID])if(l)h.placements[i.crossTileID]=new he(!1,!1,!1);else{var m=!1,k=!1,T=!0,A=null,M=null,S=null,E=0,C=0;u.textFeatureIndex&&(E=u.textFeatureIndex);var L=u.textBox;if(L)if(f.get(\"text-variable-anchor\")){var P=L.x2-L.x1,O=L.y2-L.y1,z=i.textBoxScale,I=f.get(\"text-variable-anchor\");if(h.prevPlacement&&h.prevPlacement.variableOffsets[i.crossTileID]){var D=h.prevPlacement.variableOffsets[i.crossTileID];I[0]!==D.anchor&&(I=I.filter(function(t){return t!==D.anchor})).unshift(D.anchor)}for(var R=0,F=I;R<F.length;R+=1){var B=F[R];if(A=h.attemptAnchorPlacement(B,L,P,O,i.radialTextOffset,z,_,w,o,r,b,v,i,e)){m=!0;break}}if(!h.variableOffsets[i.crossTileID]&&h.prevPlacement){var N=h.prevPlacement.variableOffsets[i.crossTileID];N&&(h.variableOffsets[i.crossTileID]=N,h.markUsedJustification(e,N.anchor,i))}}else m=(A=h.collisionIndex.placeCollisionBox(L,f.get(\"text-allow-overlap\"),o,r,b.predicate)).box.length>0;T=A&&A.offscreen;var j=u.textCircles;if(j){var U=e.text.placedSymbolArray.get(i.centerJustifiedTextSymbolIndex),V=t.evaluateSizeForFeature(e.textSizeData,p,U);M=h.collisionIndex.placeCollisionCircles(j,f.get(\"text-allow-overlap\"),a,o,U,e.lineVertexArray,e.glyphOffsetArray,V,r,n,s,w,b.predicate),m=f.get(\"text-allow-overlap\")||M.circles.length>0,T=T&&M.offscreen}u.iconFeatureIndex&&(C=u.iconFeatureIndex),u.iconBox&&(k=(S=h.collisionIndex.placeCollisionBox(u.iconBox,f.get(\"icon-allow-overlap\"),o,r,b.predicate)).box.length>0,T=T&&S.offscreen);var q=d||0===i.numHorizontalGlyphVertices&&0===i.numVerticalGlyphVertices,H=g||0===i.numIconVertices;q||H?H?q||(k=k&&m):m=k&&m:k=m=k&&m,m&&A&&h.collisionIndex.insertCollisionBox(A.box,f.get(\"text-ignore-placement\"),e.bucketInstanceId,E,b.ID),k&&S&&h.collisionIndex.insertCollisionBox(S.box,f.get(\"icon-ignore-placement\"),e.bucketInstanceId,C,b.ID),m&&M&&h.collisionIndex.insertCollisionCircles(M.circles,f.get(\"text-ignore-placement\"),e.bucketInstanceId,E,b.ID),h.placements[i.crossTileID]=new he(m||y,k||x,T||e.justReloaded),c[i.crossTileID]=!0}};if(k)for(var A=e.getSortedSymbolIndexes(this.transform.angle),M=A.length-1;M>=0;--M){var S=A[M];T(e.symbolInstances.get(S),e.collisionArrays[S])}else for(var E=0;E<e.symbolInstances.length;++E)T(e.symbolInstances.get(E),e.collisionArrays[E]);e.justReloaded=!1},ge.prototype.markUsedJustification=function(e,r,n){var i={left:n.leftJustifiedTextSymbolIndex,center:n.centerJustifiedTextSymbolIndex,right:n.rightJustifiedTextSymbolIndex},a=i[t.getAnchorJustification(r)];for(var o in i){var s=i[o];s>=0&&(e.text.placedSymbolArray.get(s).crossTileID=a>=0&&s!==a?0:n.crossTileID)}},ge.prototype.commit=function(t){this.commitTime=t;var e=this.prevPlacement,r=!1,n=e&&0!==this.fadeDuration?(this.commitTime-e.commitTime)/this.fadeDuration:1,i=e?e.opacities:{},a=e?e.variableOffsets:{};for(var o in this.placements){var s=this.placements[o],l=i[o];l?(this.opacities[o]=new ue(l,n,s.text,s.icon),r=r||s.text!==l.text.placed||s.icon!==l.icon.placed):(this.opacities[o]=new ue(null,n,s.text,s.icon,s.skipFade),r=r||s.text||s.icon)}for(var c in i){var u=i[c];if(!this.opacities[c]){var h=new ue(u,n,!1,!1);h.isHidden()||(this.opacities[c]=h,r=r||u.text.placed||u.icon.placed)}}for(var f in a)this.variableOffsets[f]||!this.opacities[f]||this.opacities[f].isHidden()||(this.variableOffsets[f]=a[f]);r?this.lastPlacementChangeTime=t:\"number\"!=typeof this.lastPlacementChangeTime&&(this.lastPlacementChangeTime=e?e.lastPlacementChangeTime:t)},ge.prototype.updateLayerOpacities=function(t,e){for(var r={},n=0,i=e;n<i.length;n+=1){var a=i[n],o=a.getBucket(t);o&&a.latestFeatureIndex&&t.id===o.layerIds[0]&&this.updateBucketOpacities(o,r,a.collisionBoxArray)}},ge.prototype.updateBucketOpacities=function(e,r,n){e.hasTextData()&&e.text.opacityVertexArray.clear(),e.hasIconData()&&e.icon.opacityVertexArray.clear(),e.hasCollisionBoxData()&&e.collisionBox.collisionVertexArray.clear(),e.hasCollisionCircleData()&&e.collisionCircle.collisionVertexArray.clear();var i=e.layers[0].layout,a=new ue(null,0,!1,!1,!0),o=i.get(\"text-allow-overlap\"),s=i.get(\"icon-allow-overlap\"),l=i.get(\"text-variable-anchor\"),c=\"map\"===i.get(\"text-rotation-alignment\"),u=\"map\"===i.get(\"text-pitch-alignment\"),h=new ue(null,0,o&&(s||!e.hasIconData()||i.get(\"icon-optional\")),s&&(o||!e.hasTextData()||i.get(\"text-optional\")),!0);!e.collisionArrays&&n&&(e.hasCollisionBoxData()||e.hasCollisionCircleData())&&e.deserializeCollisionBoxes(n);for(var f=0;f<e.symbolInstances.length;f++){var p=e.symbolInstances.get(f),d=p.numHorizontalGlyphVertices,g=p.numVerticalGlyphVertices,v=p.crossTileID,m=r[v],y=this.opacities[v];m?y=a:y||(y=h,this.opacities[v]=y),r[v]=!0;var x=d>0||g>0,b=p.numIconVertices>0;if(x){for(var _=Te(y.text),w=(d+g)/4,k=0;k<w;k++)e.text.opacityVertexArray.emplaceBack(_);var T=y.text.isHidden()?1:0;[p.rightJustifiedTextSymbolIndex,p.centerJustifiedTextSymbolIndex,p.leftJustifiedTextSymbolIndex,p.verticalPlacedTextSymbolIndex].forEach(function(t){t>=0&&(e.text.placedSymbolArray.get(t).hidden=T)});var A=this.variableOffsets[p.crossTileID];A&&this.markUsedJustification(e,A.anchor,p)}if(b){for(var M=Te(y.icon),S=0;S<p.numIconVertices/4;S++)e.icon.opacityVertexArray.emplaceBack(M);e.icon.placedSymbolArray.get(f).hidden=y.icon.isHidden()}if(e.hasCollisionBoxData()||e.hasCollisionCircleData()){var E=e.collisionArrays[f];if(E){if(E.textBox){var C=new t.Point(0,0),L=!0;if(l){var P=this.variableOffsets[v];P?(C=de(P.anchor,P.width,P.height,P.radialOffset,P.textBoxScale),c&&C._rotate(u?this.transform.angle:-this.transform.angle)):L=!1}ve(e.collisionBox.collisionVertexArray,y.text.placed,!L,C.x,C.y)}E.iconBox&&ve(e.collisionBox.collisionVertexArray,y.icon.placed,!1);var O=E.textCircles;if(O&&e.hasCollisionCircleData())for(var z=0;z<O.length;z+=5){var I=m||0===O[z+4];ve(e.collisionCircle.collisionVertexArray,y.text.placed,I)}}}}e.sortFeatures(this.transform.angle),this.retainedQueryData[e.bucketInstanceId]&&(this.retainedQueryData[e.bucketInstanceId].featureSortOrder=e.featureSortOrder),e.hasTextData()&&e.text.opacityVertexBuffer&&e.text.opacityVertexBuffer.updateData(e.text.opacityVertexArray),e.hasIconData()&&e.icon.opacityVertexBuffer&&e.icon.opacityVertexBuffer.updateData(e.icon.opacityVertexArray),e.hasCollisionBoxData()&&e.collisionBox.collisionVertexBuffer&&e.collisionBox.collisionVertexBuffer.updateData(e.collisionBox.collisionVertexArray),e.hasCollisionCircleData()&&e.collisionCircle.collisionVertexBuffer&&e.collisionCircle.collisionVertexBuffer.updateData(e.collisionCircle.collisionVertexArray)},ge.prototype.symbolFadeChange=function(t){return 0===this.fadeDuration?1:(t-this.commitTime)/this.fadeDuration},ge.prototype.hasTransitions=function(t){return this.stale||t-this.lastPlacementChangeTime<this.fadeDuration},ge.prototype.stillRecent=function(t){return this.commitTime+this.fadeDuration>t},ge.prototype.setStale=function(){this.stale=!0};var me=Math.pow(2,25),ye=Math.pow(2,24),xe=Math.pow(2,17),be=Math.pow(2,16),_e=Math.pow(2,9),we=Math.pow(2,8),ke=Math.pow(2,1);function Te(t){if(0===t.opacity&&!t.placed)return 0;if(1===t.opacity&&t.placed)return 4294967295;var e=t.placed?1:0,r=Math.floor(127*t.opacity);return r*me+e*ye+r*xe+e*be+r*_e+e*we+r*ke+e}var Ae=function(){this._currentTileIndex=0,this._seenCrossTileIDs={}};Ae.prototype.continuePlacement=function(t,e,r,n,i){for(;this._currentTileIndex<t.length;){var a=t[this._currentTileIndex];if(e.placeLayerTile(n,a,r,this._seenCrossTileIDs),this._currentTileIndex++,i())return!0}};var Me=function(t,e,r,n,i,a,o){this.placement=new ge(t,i,a,o),this._currentPlacementIndex=e.length-1,this._forceFullPlacement=r,this._showCollisionBoxes=n,this._done=!1};Me.prototype.isDone=function(){return this._done},Me.prototype.continuePlacement=function(e,r,n){for(var i=this,a=t.browser.now(),o=function(){var e=t.browser.now()-a;return!i._forceFullPlacement&&e>2};this._currentPlacementIndex>=0;){var s=r[e[this._currentPlacementIndex]],l=this.placement.collisionIndex.transform.zoom;if(\"symbol\"===s.type&&(!s.minzoom||s.minzoom<=l)&&(!s.maxzoom||s.maxzoom>l)){if(this._inProgressLayer||(this._inProgressLayer=new Ae),this._inProgressLayer.continuePlacement(n[s.source],this.placement,this._showCollisionBoxes,s,o))return;delete this._inProgressLayer}this._currentPlacementIndex--}this._done=!0},Me.prototype.commit=function(t){return this.placement.commit(t),this.placement};var Se=512/t.EXTENT/2,Ee=function(t,e,r){this.tileID=t,this.indexedSymbolInstances={},this.bucketInstanceId=r;for(var n=0;n<e.length;n++){var i=e.get(n),a=i.key;this.indexedSymbolInstances[a]||(this.indexedSymbolInstances[a]=[]),this.indexedSymbolInstances[a].push({crossTileID:i.crossTileID,coord:this.getScaledCoordinates(i,t)})}};Ee.prototype.getScaledCoordinates=function(e,r){var n=r.canonical.z-this.tileID.canonical.z,i=Se/Math.pow(2,n);return{x:Math.floor((r.canonical.x*t.EXTENT+e.anchorX)*i),y:Math.floor((r.canonical.y*t.EXTENT+e.anchorY)*i)}},Ee.prototype.findMatches=function(t,e,r){for(var n=this.tileID.canonical.z<e.canonical.z?1:Math.pow(2,this.tileID.canonical.z-e.canonical.z),i=0;i<t.length;i++){var a=t.get(i);if(!a.crossTileID){var o=this.indexedSymbolInstances[a.key];if(o)for(var s=this.getScaledCoordinates(a,e),l=0,c=o;l<c.length;l+=1){var u=c[l];if(Math.abs(u.coord.x-s.x)<=n&&Math.abs(u.coord.y-s.y)<=n&&!r[u.crossTileID]){r[u.crossTileID]=!0,a.crossTileID=u.crossTileID;break}}}}};var Ce=function(){this.maxCrossTileID=0};Ce.prototype.generate=function(){return++this.maxCrossTileID};var Le=function(){this.indexes={},this.usedCrossTileIDs={},this.lng=0};Le.prototype.handleWrapJump=function(t){var e=Math.round((t-this.lng)/360);if(0!==e)for(var r in this.indexes){var n=this.indexes[r],i={};for(var a in n){var o=n[a];o.tileID=o.tileID.unwrapTo(o.tileID.wrap+e),i[o.tileID.key]=o}this.indexes[r]=i}this.lng=t},Le.prototype.addBucket=function(t,e,r){if(this.indexes[t.overscaledZ]&&this.indexes[t.overscaledZ][t.key]){if(this.indexes[t.overscaledZ][t.key].bucketInstanceId===e.bucketInstanceId)return!1;this.removeBucketCrossTileIDs(t.overscaledZ,this.indexes[t.overscaledZ][t.key])}for(var n=0;n<e.symbolInstances.length;n++)e.symbolInstances.get(n).crossTileID=0;this.usedCrossTileIDs[t.overscaledZ]||(this.usedCrossTileIDs[t.overscaledZ]={});var i=this.usedCrossTileIDs[t.overscaledZ];for(var a in this.indexes){var o=this.indexes[a];if(Number(a)>t.overscaledZ)for(var s in o){var l=o[s];l.tileID.isChildOf(t)&&l.findMatches(e.symbolInstances,t,i)}else{var c=o[t.scaledTo(Number(a)).key];c&&c.findMatches(e.symbolInstances,t,i)}}for(var u=0;u<e.symbolInstances.length;u++){var h=e.symbolInstances.get(u);h.crossTileID||(h.crossTileID=r.generate(),i[h.crossTileID]=!0)}return void 0===this.indexes[t.overscaledZ]&&(this.indexes[t.overscaledZ]={}),this.indexes[t.overscaledZ][t.key]=new Ee(t,e.symbolInstances,e.bucketInstanceId),!0},Le.prototype.removeBucketCrossTileIDs=function(t,e){for(var r in e.indexedSymbolInstances)for(var n=0,i=e.indexedSymbolInstances[r];n<i.length;n+=1){var a=i[n];delete this.usedCrossTileIDs[t][a.crossTileID]}},Le.prototype.removeStaleBuckets=function(t){var e=!1;for(var r in this.indexes){var n=this.indexes[r];for(var i in n)t[n[i].bucketInstanceId]||(this.removeBucketCrossTileIDs(r,n[i]),delete n[i],e=!0)}return e};var Pe=function(){this.layerIndexes={},this.crossTileIDs=new Ce,this.maxBucketInstanceId=0,this.bucketsInCurrentPlacement={}};Pe.prototype.addLayer=function(t,e,r){var n=this.layerIndexes[t.id];void 0===n&&(n=this.layerIndexes[t.id]=new Le);var i=!1,a={};n.handleWrapJump(r);for(var o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.getBucket(t);c&&t.id===c.layerIds[0]&&(c.bucketInstanceId||(c.bucketInstanceId=++this.maxBucketInstanceId),n.addBucket(l.tileID,c,this.crossTileIDs)&&(i=!0),a[c.bucketInstanceId]=!0)}return n.removeStaleBuckets(a)&&(i=!0),i},Pe.prototype.pruneUnusedLayers=function(t){var e={};for(var r in t.forEach(function(t){e[t]=!0}),this.layerIndexes)e[r]||delete this.layerIndexes[r]};var Oe=function(e,r){return t.emitValidationErrors(e,r&&r.filter(function(t){return\"source.canvas\"!==t.identifier}))},ze=t.pick(Bt,[\"addLayer\",\"removeLayer\",\"setPaintProperty\",\"setLayoutProperty\",\"setFilter\",\"addSource\",\"removeSource\",\"setLayerZoomRange\",\"setLight\",\"setTransition\",\"setGeoJSONSourceData\"]),Ie=t.pick(Bt,[\"setCenter\",\"setZoom\",\"setBearing\",\"setPitch\"]),De=function(e){function r(n,i){var a=this;void 0===i&&(i={}),e.call(this),this.map=n,this.dispatcher=new k((It||(It=new zt),It),this),this.imageManager=new f,this.imageManager.setEventedParent(this),this.glyphManager=new y(n._requestManager,i.localIdeographFontFamily),this.lineAtlas=new w(256,512),this.crossTileSymbolIndex=new Pe,this._layers={},this._order=[],this.sourceCaches={},this.zoomHistory=new t.ZoomHistory,this._loaded=!1,this._resetUpdates(),this.dispatcher.broadcast(\"setReferrer\",t.getReferrer());var o=this;this._rtlTextPluginCallback=r.registerForPluginAvailability(function(t){for(var e in o.dispatcher.broadcast(\"loadRTLTextPlugin\",t.pluginURL,t.completionCallback),o.sourceCaches)o.sourceCaches[e].reload()}),this.on(\"data\",function(t){if(\"source\"===t.dataType&&\"metadata\"===t.sourceDataType){var e=a.sourceCaches[t.sourceId];if(e){var r=e.getSource();if(r&&r.vectorLayerIds)for(var n in a._layers){var i=a._layers[n];i.source===r.id&&a._validateLayer(i)}}}})}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadURL=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"}));var i=\"boolean\"==typeof r.validate?r.validate:!t.isMapboxURL(e);e=this.map._requestManager.normalizeStyleURL(e,r.accessToken);var a=this.map._requestManager.transformRequest(e,t.ResourceType.Style);this._request=t.getJSON(a,function(e,r){n._request=null,e?n.fire(new t.ErrorEvent(e)):r&&n._load(r,i)})},r.prototype.loadJSON=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"})),this._request=t.browser.frame(function(){n._request=null,n._load(e,!1!==r.validate)})},r.prototype._load=function(e,r){var n=this;if(!r||!Oe(this,t.validateStyle(e))){for(var i in this._loaded=!0,this.stylesheet=e,e.sources)this.addSource(i,e.sources[i],{validate:!1});e.sprite?this._spriteRequest=function(e,r,n){var i,a,o,s=t.browser.devicePixelRatio>1?\"@2x\":\"\",l=t.getJSON(r.transformRequest(r.normalizeSpriteURL(e,s,\".json\"),t.ResourceType.SpriteJSON),function(t,e){l=null,o||(o=t,i=e,u())}),c=t.getImage(r.transformRequest(r.normalizeSpriteURL(e,s,\".png\"),t.ResourceType.SpriteImage),function(t,e){c=null,o||(o=t,a=e,u())});function u(){if(o)n(o);else if(i&&a){var e=t.browser.getImageData(a),r={};for(var s in i){var l=i[s],c=l.width,u=l.height,h=l.x,f=l.y,p=l.sdf,d=l.pixelRatio,g=new t.RGBAImage({width:c,height:u});t.RGBAImage.copy(e,g,{x:h,y:f},{x:0,y:0},{width:c,height:u}),r[s]={data:g,pixelRatio:d,sdf:p}}n(null,r)}}return{cancel:function(){l&&(l.cancel(),l=null),c&&(c.cancel(),c=null)}}}(e.sprite,this.map._requestManager,function(e,r){if(n._spriteRequest=null,e)n.fire(new t.ErrorEvent(e));else if(r)for(var i in r)n.imageManager.addImage(i,r[i]);n.imageManager.setLoaded(!0),n.fire(new t.Event(\"data\",{dataType:\"style\"}))}):this.imageManager.setLoaded(!0),this.glyphManager.setURL(e.glyphs);var a=Ft(this.stylesheet.layers);this._order=a.map(function(t){return t.id}),this._layers={};for(var o=0,s=a;o<s.length;o+=1){var l=s[o];(l=t.createStyleLayer(l)).setEventedParent(this,{layer:{id:l.id}}),this._layers[l.id]=l}this.dispatcher.broadcast(\"setLayers\",this._serializeLayers(this._order)),this.light=new _(this.stylesheet.light),this.fire(new t.Event(\"data\",{dataType:\"style\"})),this.fire(new t.Event(\"style.load\"))}},r.prototype._validateLayer=function(e){var r=this.sourceCaches[e.source];if(r){var n=e.sourceLayer;if(n){var i=r.getSource();(\"geojson\"===i.type||i.vectorLayerIds&&-1===i.vectorLayerIds.indexOf(n))&&this.fire(new t.ErrorEvent(new Error('Source layer \"'+n+'\" does not exist on source \"'+i.id+'\" as specified by style layer \"'+e.id+'\"')))}}},r.prototype.loaded=function(){if(!this._loaded)return!1;if(Object.keys(this._updatedSources).length)return!1;for(var t in this.sourceCaches)if(!this.sourceCaches[t].loaded())return!1;return!!this.imageManager.isLoaded()},r.prototype._serializeLayers=function(t){for(var e=[],r=0,n=t;r<n.length;r+=1){var i=n[r],a=this._layers[i];\"custom\"!==a.type&&e.push(a.serialize())}return e},r.prototype.hasTransitions=function(){if(this.light&&this.light.hasTransition())return!0;for(var t in this.sourceCaches)if(this.sourceCaches[t].hasTransition())return!0;for(var e in this._layers)if(this._layers[e].hasTransition())return!0;return!1},r.prototype._checkLoaded=function(){if(!this._loaded)throw new Error(\"Style is not done loading\")},r.prototype.update=function(e){if(this._loaded){var r=this._changed;if(this._changed){var n=Object.keys(this._updatedLayers),i=Object.keys(this._removedLayers);for(var a in(n.length||i.length)&&this._updateWorkerLayers(n,i),this._updatedSources){var o=this._updatedSources[a];\"reload\"===o?this._reloadSource(a):\"clear\"===o&&this._clearSource(a)}for(var s in this._updatedPaintProps)this._layers[s].updateTransitions(e);this.light.updateTransitions(e),this._resetUpdates()}for(var l in this.sourceCaches)this.sourceCaches[l].used=!1;for(var c=0,u=this._order;c<u.length;c+=1){var h=u[c],f=this._layers[h];f.recalculate(e),!f.isHidden(e.zoom)&&f.source&&(this.sourceCaches[f.source].used=!0)}this.light.recalculate(e),this.z=e.zoom,r&&this.fire(new t.Event(\"data\",{dataType:\"style\"}))}},r.prototype._updateWorkerLayers=function(t,e){this.dispatcher.broadcast(\"updateLayers\",{layers:this._serializeLayers(t),removedIds:e})},r.prototype._resetUpdates=function(){this._changed=!1,this._updatedLayers={},this._removedLayers={},this._updatedSources={},this._updatedPaintProps={}},r.prototype.setState=function(e){var r=this;if(this._checkLoaded(),Oe(this,t.validateStyle(e)))return!1;(e=t.clone$1(e)).layers=Ft(e.layers);var n=function(e,r){if(!e)return[{command:Bt.setStyle,args:[r]}];var n=[];try{if(!t.deepEqual(e.version,r.version))return[{command:Bt.setStyle,args:[r]}];t.deepEqual(e.center,r.center)||n.push({command:Bt.setCenter,args:[r.center]}),t.deepEqual(e.zoom,r.zoom)||n.push({command:Bt.setZoom,args:[r.zoom]}),t.deepEqual(e.bearing,r.bearing)||n.push({command:Bt.setBearing,args:[r.bearing]}),t.deepEqual(e.pitch,r.pitch)||n.push({command:Bt.setPitch,args:[r.pitch]}),t.deepEqual(e.sprite,r.sprite)||n.push({command:Bt.setSprite,args:[r.sprite]}),t.deepEqual(e.glyphs,r.glyphs)||n.push({command:Bt.setGlyphs,args:[r.glyphs]}),t.deepEqual(e.transition,r.transition)||n.push({command:Bt.setTransition,args:[r.transition]}),t.deepEqual(e.light,r.light)||n.push({command:Bt.setLight,args:[r.light]});var i={},a=[];!function(e,r,n,i){var a;for(a in r=r||{},e=e||{})e.hasOwnProperty(a)&&(r.hasOwnProperty(a)||jt(a,n,i));for(a in r)r.hasOwnProperty(a)&&(e.hasOwnProperty(a)?t.deepEqual(e[a],r[a])||(\"geojson\"===e[a].type&&\"geojson\"===r[a].type&&Vt(e,r,a)?n.push({command:Bt.setGeoJSONSourceData,args:[a,r[a].data]}):Ut(a,r,n,i)):Nt(a,r,n))}(e.sources,r.sources,a,i);var o=[];e.layers&&e.layers.forEach(function(t){i[t.source]?n.push({command:Bt.removeLayer,args:[t.id]}):o.push(t)}),n=n.concat(a),function(e,r,n){r=r||[];var i,a,o,s,l,c,u,h=(e=e||[]).map(Ht),f=r.map(Ht),p=e.reduce(Gt,{}),d=r.reduce(Gt,{}),g=h.slice(),v=Object.create(null);for(i=0,a=0;i<h.length;i++)o=h[i],d.hasOwnProperty(o)?a++:(n.push({command:Bt.removeLayer,args:[o]}),g.splice(g.indexOf(o,a),1));for(i=0,a=0;i<f.length;i++)o=f[f.length-1-i],g[g.length-1-i]!==o&&(p.hasOwnProperty(o)?(n.push({command:Bt.removeLayer,args:[o]}),g.splice(g.lastIndexOf(o,g.length-a),1)):a++,c=g[g.length-i],n.push({command:Bt.addLayer,args:[d[o],c]}),g.splice(g.length-i,0,o),v[o]=!0);for(i=0;i<f.length;i++)if(s=p[o=f[i]],l=d[o],!v[o]&&!t.deepEqual(s,l))if(t.deepEqual(s.source,l.source)&&t.deepEqual(s[\"source-layer\"],l[\"source-layer\"])&&t.deepEqual(s.type,l.type)){for(u in qt(s.layout,l.layout,n,o,null,Bt.setLayoutProperty),qt(s.paint,l.paint,n,o,null,Bt.setPaintProperty),t.deepEqual(s.filter,l.filter)||n.push({command:Bt.setFilter,args:[o,l.filter]}),t.deepEqual(s.minzoom,l.minzoom)&&t.deepEqual(s.maxzoom,l.maxzoom)||n.push({command:Bt.setLayerZoomRange,args:[o,l.minzoom,l.maxzoom]}),s)s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?qt(s[u],l[u],n,o,u.slice(6),Bt.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Bt.setLayerProperty,args:[o,u,l[u]]}));for(u in l)l.hasOwnProperty(u)&&!s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?qt(s[u],l[u],n,o,u.slice(6),Bt.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Bt.setLayerProperty,args:[o,u,l[u]]}))}else n.push({command:Bt.removeLayer,args:[o]}),c=g[g.lastIndexOf(o)+1],n.push({command:Bt.addLayer,args:[l,c]})}(o,r.layers,n)}catch(t){console.warn(\"Unable to compute style diff:\",t),n=[{command:Bt.setStyle,args:[r]}]}return n}(this.serialize(),e).filter(function(t){return!(t.command in Ie)});if(0===n.length)return!1;var i=n.filter(function(t){return!(t.command in ze)});if(i.length>0)throw new Error(\"Unimplemented: \"+i.map(function(t){return t.command}).join(\", \")+\".\");return n.forEach(function(t){\"setTransition\"!==t.command&&r[t.command].apply(r,t.args)}),this.stylesheet=e,!0},r.prototype.addImage=function(e,r){if(this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"An image with this name already exists.\")));this.imageManager.addImage(e,r),this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.updateImage=function(t,e){this.imageManager.updateImage(t,e)},r.prototype.getImage=function(t){return this.imageManager.getImage(t)},r.prototype.removeImage=function(e){if(!this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"No image with this name exists.\")));this.imageManager.removeImage(e),this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.listImages=function(){return this._checkLoaded(),this.imageManager.listImages()},r.prototype.addSource=function(e,r,n){var i=this;if(void 0===n&&(n={}),this._checkLoaded(),void 0!==this.sourceCaches[e])throw new Error(\"There is already a source with this ID\");if(!r.type)throw new Error(\"The type property must be defined, but the only the following properties were given: \"+Object.keys(r).join(\", \")+\".\");if(!([\"vector\",\"raster\",\"geojson\",\"video\",\"image\"].indexOf(r.type)>=0&&this._validate(t.validateStyle.source,\"sources.\"+e,r,null,n))){this.map&&this.map._collectResourceTiming&&(r.collectResourceTiming=!0);var a=this.sourceCaches[e]=new Ct(e,r,this.dispatcher);a.style=this,a.setEventedParent(this,function(){return{isSourceLoaded:i.loaded(),source:a.serialize(),sourceId:e}}),a.onAdd(this.map),this._changed=!0}},r.prototype.removeSource=function(e){if(this._checkLoaded(),void 0===this.sourceCaches[e])throw new Error(\"There is no source with this ID\");for(var r in this._layers)if(this._layers[r].source===e)return this.fire(new t.ErrorEvent(new Error('Source \"'+e+'\" cannot be removed while layer \"'+r+'\" is using it.')));var n=this.sourceCaches[e];delete this.sourceCaches[e],delete this._updatedSources[e],n.fire(new t.Event(\"data\",{sourceDataType:\"metadata\",dataType:\"source\",sourceId:e})),n.setEventedParent(null),n.clearTiles(),n.onRemove&&n.onRemove(this.map),this._changed=!0},r.prototype.setGeoJSONSourceData=function(t,e){this._checkLoaded(),this.sourceCaches[t].getSource().setData(e),this._changed=!0},r.prototype.getSource=function(t){return this.sourceCaches[t]&&this.sourceCaches[t].getSource()},r.prototype.addLayer=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=e.id;if(this.getLayer(i))this.fire(new t.ErrorEvent(new Error('Layer with id \"'+i+'\" already exists on this map')));else{var a;if(\"custom\"===e.type){if(Oe(this,t.validateCustomStyleLayer(e)))return;a=t.createStyleLayer(e)}else{if(\"object\"==typeof e.source&&(this.addSource(i,e.source),e=t.clone$1(e),e=t.extend(e,{source:i})),this._validate(t.validateStyle.layer,\"layers.\"+i,e,{arrayIndex:-1},n))return;a=t.createStyleLayer(e),this._validateLayer(a),a.setEventedParent(this,{layer:{id:i}})}var o=r?this._order.indexOf(r):this._order.length;if(r&&-1===o)this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.')));else{if(this._order.splice(o,0,i),this._layerOrderChanged=!0,this._layers[i]=a,this._removedLayers[i]&&a.source&&\"custom\"!==a.type){var s=this._removedLayers[i];delete this._removedLayers[i],s.type!==a.type?this._updatedSources[a.source]=\"clear\":(this._updatedSources[a.source]=\"reload\",this.sourceCaches[a.source].pause())}this._updateLayer(a),a.onAdd&&a.onAdd(this.map)}}},r.prototype.moveLayer=function(e,r){if(this._checkLoaded(),this._changed=!0,this._layers[e]){if(e!==r){var n=this._order.indexOf(e);this._order.splice(n,1);var i=r?this._order.indexOf(r):this._order.length;r&&-1===i?this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.'))):(this._order.splice(i,0,e),this._layerOrderChanged=!0)}}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be moved.\")))},r.prototype.removeLayer=function(e){this._checkLoaded();var r=this._layers[e];if(r){r.setEventedParent(null);var n=this._order.indexOf(e);this._order.splice(n,1),this._layerOrderChanged=!0,this._changed=!0,this._removedLayers[e]=r,delete this._layers[e],delete this._updatedLayers[e],delete this._updatedPaintProps[e],r.onRemove&&r.onRemove(this.map)}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be removed.\")))},r.prototype.getLayer=function(t){return this._layers[t]},r.prototype.setLayerZoomRange=function(e,r,n){this._checkLoaded();var i=this.getLayer(e);i?i.minzoom===r&&i.maxzoom===n||(null!=r&&(i.minzoom=r),null!=n&&(i.maxzoom=n),this._updateLayer(i)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot have zoom extent.\")))},r.prototype.setFilter=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=this.getLayer(e);if(i){if(!t.deepEqual(i.filter,r))return null==r?(i.filter=void 0,void this._updateLayer(i)):void(this._validate(t.validateStyle.filter,\"layers.\"+i.id+\".filter\",r,null,n)||(i.filter=t.clone$1(r),this._updateLayer(i)))}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be filtered.\")))},r.prototype.getFilter=function(e){return t.clone$1(this.getLayer(e).filter)},r.prototype.setLayoutProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getLayoutProperty(r),n)||(a.setLayoutProperty(r,n,i),this._updateLayer(a)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getLayoutProperty=function(e,r){var n=this.getLayer(e);if(n)return n.getLayoutProperty(r);this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style.\")))},r.prototype.setPaintProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getPaintProperty(r),n)||(a.setPaintProperty(r,n,i)&&this._updateLayer(a),this._changed=!0,this._updatedPaintProps[e]=!0):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getPaintProperty=function(t,e){return this.getLayer(t).getPaintProperty(e)},r.prototype.setFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=e.sourceLayer,a=this.sourceCaches[n],o=parseInt(e.id,10);if(void 0!==a){var s=a.getSource().type;\"geojson\"===s&&i?this.fire(new t.ErrorEvent(new Error(\"GeoJSON sources cannot have a sourceLayer parameter.\"))):\"vector\"!==s||i?isNaN(o)||o<0?this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided and non-negative.\"))):a.setFeatureState(i,o,r):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.removeFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=this.sourceCaches[n];if(void 0!==i){var a=i.getSource().type,o=\"vector\"===a?e.sourceLayer:void 0,s=parseInt(e.id,10);\"vector\"!==a||o?void 0!==e.id&&isNaN(s)||s<0?this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be non-negative.\"))):r&&\"string\"!=typeof e.id&&\"number\"!=typeof e.id?this.fire(new t.ErrorEvent(new Error(\"A feature id is requred to remove its specific state property.\"))):i.removeFeatureState(o,s,r):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.getFeatureState=function(e){this._checkLoaded();var r=e.source,n=e.sourceLayer,i=this.sourceCaches[r],a=parseInt(e.id,10);if(void 0!==i)if(\"vector\"!==i.getSource().type||n){if(!(isNaN(a)||a<0))return i.getFeatureState(n,a);this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided and non-negative.\")))}else this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")));else this.fire(new t.ErrorEvent(new Error(\"The source '\"+r+\"' does not exist in the map's style.\")))},r.prototype.getTransition=function(){return t.extend({duration:300,delay:0},this.stylesheet&&this.stylesheet.transition)},r.prototype.serialize=function(){return t.filterObject({version:this.stylesheet.version,name:this.stylesheet.name,metadata:this.stylesheet.metadata,light:this.stylesheet.light,center:this.stylesheet.center,zoom:this.stylesheet.zoom,bearing:this.stylesheet.bearing,pitch:this.stylesheet.pitch,sprite:this.stylesheet.sprite,glyphs:this.stylesheet.glyphs,transition:this.stylesheet.transition,sources:t.mapObject(this.sourceCaches,function(t){return t.serialize()}),layers:this._serializeLayers(this._order)},function(t){return void 0!==t})},r.prototype._updateLayer=function(t){this._updatedLayers[t.id]=!0,t.source&&!this._updatedSources[t.source]&&(this._updatedSources[t.source]=\"reload\",this.sourceCaches[t.source].pause()),this._changed=!0},r.prototype._flattenAndSortRenderedFeatures=function(t){for(var e=this,r=function(t){return\"fill-extrusion\"===e._layers[t].type},n={},i=[],a=this._order.length-1;a>=0;a--){var o=this._order[a];if(r(o)){n[o]=a;for(var s=0,l=t;s<l.length;s+=1){var c=l[s][o];if(c)for(var u=0,h=c;u<h.length;u+=1){var f=h[u];i.push(f)}}}}i.sort(function(t,e){return e.intersectionZ-t.intersectionZ});for(var p=[],d=this._order.length-1;d>=0;d--){var g=this._order[d];if(r(g))for(var v=i.length-1;v>=0;v--){var m=i[v].feature;if(n[m.layer.id]<d)break;p.push(m),i.pop()}else for(var y=0,x=t;y<x.length;y+=1){var b=x[y][g];if(b)for(var _=0,w=b;_<w.length;_+=1){var k=w[_];p.push(k.feature)}}}return p},r.prototype.queryRenderedFeatures=function(e,r,n){r&&r.filter&&this._validate(t.validateStyle.filter,\"queryRenderedFeatures.filter\",r.filter,null,r);var i={};if(r&&r.layers){if(!Array.isArray(r.layers))return this.fire(new t.ErrorEvent(new Error(\"parameters.layers must be an Array.\"))),[];for(var a=0,o=r.layers;a<o.length;a+=1){var s=o[a],l=this._layers[s];if(!l)return this.fire(new t.ErrorEvent(new Error(\"The layer '\"+s+\"' does not exist in the map's style and cannot be queried for features.\"))),[];i[l.source]=!0}}var c=[];for(var u in this.sourceCaches)r.layers&&!i[u]||c.push(R(this.sourceCaches[u],this._layers,e,r,n));return this.placement&&c.push(function(t,e,r,n,i,a){for(var o={},s=i.queryRenderedSymbols(r),l=[],c=0,u=Object.keys(s).map(Number);c<u.length;c+=1){var h=u[c];l.push(a[h])}l.sort(F);for(var f=function(){var e=d[p],r=e.featureIndex.lookupSymbolFeatures(s[e.bucketInstanceId],e.bucketIndex,e.sourceLayerIndex,n.filter,n.layers,t);for(var i in r){var a=o[i]=o[i]||[],l=r[i];l.sort(function(t,r){var n=e.featureSortOrder;if(n){var i=n.indexOf(t.featureIndex);return n.indexOf(r.featureIndex)-i}return r.featureIndex-t.featureIndex});for(var c=0,u=l;c<u.length;c+=1){var h=u[c];a.push(h)}}},p=0,d=l;p<d.length;p+=1)f();var g=function(r){o[r].forEach(function(n){var i=n.feature,a=t[r],o=e[a.source].getFeatureState(i.layer[\"source-layer\"],i.id);i.source=i.layer.source,i.layer[\"source-layer\"]&&(i.sourceLayer=i.layer[\"source-layer\"]),i.state=o})};for(var v in o)g(v);return o}(this._layers,this.sourceCaches,e,r,this.placement.collisionIndex,this.placement.retainedQueryData)),this._flattenAndSortRenderedFeatures(c)},r.prototype.querySourceFeatures=function(e,r){r&&r.filter&&this._validate(t.validateStyle.filter,\"querySourceFeatures.filter\",r.filter,null,r);var n=this.sourceCaches[e];return n?function(t,e){for(var r=t.getRenderableIds().map(function(e){return t.getTileByID(e)}),n=[],i={},a=0;a<r.length;a++){var o=r[a],s=o.tileID.canonical.key;i[s]||(i[s]=!0,o.querySourceFeatures(n,e))}return n}(n,r):[]},r.prototype.addSourceType=function(t,e,n){return r.getSourceType(t)?n(new Error('A source type called \"'+t+'\" already exists.')):(r.setSourceType(t,e),e.workerSourceURL?void this.dispatcher.broadcast(\"loadWorkerSource\",{name:t,url:e.workerSourceURL},n):n(null,null))},r.prototype.getLight=function(){return this.light.getLight()},r.prototype.setLight=function(e,r){void 0===r&&(r={}),this._checkLoaded();var n=this.light.getLight(),i=!1;for(var a in e)if(!t.deepEqual(e[a],n[a])){i=!0;break}if(i){var o={now:t.browser.now(),transition:t.extend({duration:300,delay:0},this.stylesheet.transition)};this.light.setLight(e,r),this.light.updateTransitions(o)}},r.prototype._validate=function(e,r,n,i,a){return void 0===a&&(a={}),(!a||!1!==a.validate)&&Oe(this,e.call(t.validateStyle,t.extend({key:r,style:this.serialize(),value:n,styleSpec:t.styleSpec},i)))},r.prototype._remove=function(){for(var e in this._request&&(this._request.cancel(),this._request=null),this._spriteRequest&&(this._spriteRequest.cancel(),this._spriteRequest=null),t.evented.off(\"pluginAvailable\",this._rtlTextPluginCallback),this.sourceCaches)this.sourceCaches[e].clearTiles();this.dispatcher.remove()},r.prototype._clearSource=function(t){this.sourceCaches[t].clearTiles()},r.prototype._reloadSource=function(t){this.sourceCaches[t].resume(),this.sourceCaches[t].reload()},r.prototype._updateSources=function(t){for(var e in this.sourceCaches)this.sourceCaches[e].update(t)},r.prototype._generateCollisionBoxes=function(){for(var t in this.sourceCaches)this._reloadSource(t)},r.prototype._updatePlacement=function(e,r,n,i){for(var a=!1,o=!1,s={},l=0,c=this._order;l<c.length;l+=1){var u=c[l],h=this._layers[u];if(\"symbol\"===h.type){if(!s[h.source]){var f=this.sourceCaches[h.source];s[h.source]=f.getRenderableIds(!0).map(function(t){return f.getTileByID(t)}).sort(function(t,e){return e.tileID.overscaledZ-t.tileID.overscaledZ||(t.tileID.isLessThan(e.tileID)?-1:1)})}var p=this.crossTileSymbolIndex.addLayer(h,s[h.source],e.center.lng);a=a||p}}this.crossTileSymbolIndex.pruneUnusedLayers(this._order);var d=this._layerOrderChanged||0===n;if((d||!this.pauseablePlacement||this.pauseablePlacement.isDone()&&!this.placement.stillRecent(t.browser.now()))&&(this.pauseablePlacement=new Me(e,this._order,d,r,n,i,this.placement),this._layerOrderChanged=!1),this.pauseablePlacement.isDone()?this.placement.setStale():(this.pauseablePlacement.continuePlacement(this._order,this._layers,s),this.pauseablePlacement.isDone()&&(this.placement=this.pauseablePlacement.commit(t.browser.now()),o=!0),a&&this.pauseablePlacement.placement.setStale()),o||a)for(var g=0,v=this._order;g<v.length;g+=1){var m=v[g],y=this._layers[m];\"symbol\"===y.type&&this.placement.updateLayerOpacities(y,s[y.source])}return!this.pauseablePlacement.isDone()||this.placement.hasTransitions(t.browser.now())},r.prototype._releaseSymbolFadeTiles=function(){for(var t in this.sourceCaches)this.sourceCaches[t].releaseSymbolFadeTiles()},r.prototype.getImages=function(t,e,r){this.imageManager.getImages(e.icons,r)},r.prototype.getGlyphs=function(t,e,r){this.glyphManager.getGlyphs(e.stacks,r)},r.prototype.getResource=function(e,r,n){return t.makeRequest(r,n)},r}(t.Evented);De.getSourceType=function(t){return z[t]},De.setSourceType=function(t,e){z[t]=e},De.registerForPluginAvailability=t.registerForPluginAvailability;var Re=t.createLayout([{name:\"a_pos\",type:\"Int16\",components:2}]),Fe=lr(\"#ifdef GL_ES\\nprecision mediump float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\",\"#ifdef GL_ES\\nprecision highp float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\\nvec2 unpack_float(const float packedValue) {int packedIntValue=int(packedValue);int v0=packedIntValue/256;return vec2(v0,packedIntValue-v0*256);}vec2 unpack_opacity(const float packedOpacity) {int intOpacity=int(packedOpacity)/2;return vec2(float(intOpacity)/127.0,mod(packedOpacity,2.0));}vec4 decode_color(const vec2 encodedColor) {return vec4(unpack_float(encodedColor[0])/255.0,unpack_float(encodedColor[1])/255.0\\n);}float unpack_mix_vec2(const vec2 packedValue,const float t) {return mix(packedValue[0],packedValue[1],t);}vec4 unpack_mix_color(const vec4 packedColors,const float t) {vec4 minColor=decode_color(vec2(packedColors[0],packedColors[1]));vec4 maxColor=decode_color(vec2(packedColors[2],packedColors[3]));return mix(minColor,maxColor,t);}vec2 get_pattern_pos(const vec2 pixel_coord_upper,const vec2 pixel_coord_lower,const vec2 pattern_size,const float tile_units_to_pixels,const vec2 pos) {vec2 offset=mod(mod(mod(pixel_coord_upper,pattern_size)*256.0,pattern_size)*256.0+pixel_coord_lower,pattern_size);return (tile_units_to_pixels*pos+offset)/pattern_size;}\"),Be=lr(\"uniform vec4 u_color;uniform float u_opacity;void main() {gl_FragColor=u_color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),Ne=lr(\"uniform vec2 u_pattern_tl_a;uniform vec2 u_pattern_br_a;uniform vec2 u_pattern_tl_b;uniform vec2 u_pattern_br_b;uniform vec2 u_texsize;uniform float u_mix;uniform float u_opacity;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(u_pattern_tl_a/u_texsize,u_pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(u_pattern_tl_b/u_texsize,u_pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_mix)*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pattern_size_a;uniform vec2 u_pattern_size_b;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_scale_a;uniform float u_scale_b;uniform float u_tile_units_to_pixels;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_a*u_pattern_size_a,u_tile_units_to_pixels,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_b*u_pattern_size_b,u_tile_units_to_pixels,a_pos);}\"),je=lr(\"varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=v_data.xy;float extrude_length=length(extrude);lowp float antialiasblur=v_data.z;float antialiased_blur=-max(blur,antialiasblur);float opacity_t=smoothstep(0.0,antialiased_blur,extrude_length-1.0);float color_t=stroke_width < 0.01 ? 0.0 : smoothstep(antialiased_blur,0.0,extrude_length-radius/(radius+stroke_width));gl_FragColor=opacity_t*mix(color*opacity,stroke_color*stroke_opacity,color_t);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform bool u_scale_with_map;uniform bool u_pitch_with_map;uniform vec2 u_extrude_scale;uniform lowp float u_device_pixel_ratio;uniform highp float u_camera_to_center_distance;attribute vec2 a_pos;varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main(void) {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=vec2(mod(a_pos,2.0)*2.0-1.0);vec2 circle_center=floor(a_pos*0.5);if (u_pitch_with_map) {vec2 corner_position=circle_center;if (u_scale_with_map) {corner_position+=extrude*(radius+stroke_width)*u_extrude_scale;} else {vec4 projected_center=u_matrix*vec4(circle_center,0,1);corner_position+=extrude*(radius+stroke_width)*u_extrude_scale*(projected_center.w/u_camera_to_center_distance);}gl_Position=u_matrix*vec4(corner_position,0,1);} else {gl_Position=u_matrix*vec4(circle_center,0,1);if (u_scale_with_map) {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*u_camera_to_center_distance;} else {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*gl_Position.w;}}lowp float antialiasblur=1.0/u_device_pixel_ratio/(radius+stroke_width);v_data=vec3(extrude.x,extrude.y,antialiasblur);}\"),Ue=lr(\"void main() {gl_FragColor=vec4(1.0);}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),Ve=lr(\"uniform highp float u_intensity;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main() {\\n#pragma mapbox: initialize highp float weight\\nfloat d=-0.5*3.0*3.0*dot(v_extrude,v_extrude);float val=weight*u_intensity*GAUSS_COEF*exp(d);gl_FragColor=vec4(val,1.0,1.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform float u_extrude_scale;uniform float u_opacity;uniform float u_intensity;attribute vec2 a_pos;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#pragma mapbox: define mediump float radius\\nconst highp float ZERO=1.0/255.0/16.0;\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main(void) {\\n#pragma mapbox: initialize highp float weight\\n#pragma mapbox: initialize mediump float radius\\nvec2 unscaled_extrude=vec2(mod(a_pos,2.0)*2.0-1.0);float S=sqrt(-2.0*log(ZERO/weight/u_intensity/GAUSS_COEF))/3.0;v_extrude=S*unscaled_extrude;vec2 extrude=v_extrude*radius*u_extrude_scale;vec4 pos=vec4(floor(a_pos*0.5)+extrude,0,1);gl_Position=u_matrix*pos;}\"),qe=lr(\"uniform sampler2D u_image;uniform sampler2D u_color_ramp;uniform float u_opacity;varying vec2 v_pos;void main() {float t=texture2D(u_image,v_pos).r;vec4 color=texture2D(u_color_ramp,vec2(t,0.5));gl_FragColor=color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(0.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;attribute vec2 a_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos*u_world,0,1);v_pos.x=a_pos.x;v_pos.y=1.0-a_pos.y;}\"),He=lr(\"varying float v_placed;varying float v_notUsed;void main() {float alpha=0.5;gl_FragColor=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {gl_FragColor=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {gl_FragColor*=.1;}}\",\"attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;attribute vec2 a_shift;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);gl_Position.xy+=(a_extrude+a_shift)*u_extrude_scale*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;}\"),Ge=lr(\"uniform float u_overscale_factor;varying float v_placed;varying float v_notUsed;varying float v_radius;varying vec2 v_extrude;varying vec2 v_extrude_scale;void main() {float alpha=0.5;vec4 color=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {color=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {color*=.2;}float extrude_scale_length=length(v_extrude_scale);float extrude_length=length(v_extrude)*extrude_scale_length;float stroke_width=15.0*extrude_scale_length/u_overscale_factor;float radius=v_radius*extrude_scale_length;float distance_to_edge=abs(extrude_length-radius);float opacity_t=smoothstep(-stroke_width,0.0,-distance_to_edge);gl_FragColor=opacity_t*color;}\",\"attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;varying float v_radius;varying vec2 v_extrude;varying vec2 v_extrude_scale;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);highp float padding_factor=1.2;gl_Position.xy+=a_extrude*u_extrude_scale*padding_factor*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;v_radius=abs(a_extrude.y);v_extrude=a_extrude*padding_factor;v_extrude_scale=u_extrude_scale*u_camera_to_center_distance*collision_perspective_ratio;}\"),Ye=lr(\"uniform highp vec4 u_color;void main() {gl_FragColor=u_color;}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),We=lr(\"#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_FragColor=color*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);}\"),Xe=lr(\"varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=outline_color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;uniform vec2 u_world;varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),Ze=lr(\"uniform vec2 u_texsize;uniform sampler2D u_image;uniform float u_fade;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);float dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=mix(color1,color2,u_fade)*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec4 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;gl_Position=u_matrix*vec4(a_pos,0,1);vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,a_pos);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),Je=lr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_fade)*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec4 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileZoomRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileZoomRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileZoomRatio,a_pos);}\"),Ke=lr(\"varying vec4 v_color;void main() {gl_FragColor=v_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;uniform float u_vertical_gradient;uniform lowp float u_opacity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec4 v_color;\\n#pragma mapbox: define highp float base\\n#pragma mapbox: define highp float height\\n#pragma mapbox: define highp vec4 color\\nvoid main() {\\n#pragma mapbox: initialize highp float base\\n#pragma mapbox: initialize highp float height\\n#pragma mapbox: initialize highp vec4 color\\nvec3 normal=a_normal_ed.xyz;base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);gl_Position=u_matrix*vec4(a_pos,t > 0.0 ? height : base,1);float colorvalue=color.r*0.2126+color.g*0.7152+color.b*0.0722;v_color=vec4(0.0,0.0,0.0,1.0);vec4 ambientlight=vec4(0.03,0.03,0.03,1.0);color+=ambientlight;float directional=clamp(dot(normal/16384.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((1.0-colorvalue+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_color.r+=clamp(color.r*directional*u_lightcolor.r,mix(0.0,0.3,1.0-u_lightcolor.r),1.0);v_color.g+=clamp(color.g*directional*u_lightcolor.g,mix(0.0,0.3,1.0-u_lightcolor.g),1.0);v_color.b+=clamp(color.b*directional*u_lightcolor.b,mix(0.0,0.3,1.0-u_lightcolor.b),1.0);v_color*=u_opacity;}\"),$e=lr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);vec4 mixedColor=mix(color1,color2,u_fade);gl_FragColor=mixedColor*v_lighting;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_height_factor;uniform vec4 u_scale;uniform float u_vertical_gradient;uniform lowp float u_opacity;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec3 normal=a_normal_ed.xyz;float edgedistance=a_normal_ed.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);float z=t > 0.0 ? height : base;gl_Position=u_matrix*vec4(a_pos,z,1);vec2 pos=normal.x==1.0 && normal.y==0.0 && normal.z==16384.0\\n? a_pos\\n: vec2(edgedistance,z*u_height_factor);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,pos);v_lighting=vec4(0.0,0.0,0.0,1.0);float directional=clamp(dot(normal/16383.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((0.5+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_lighting.rgb+=clamp(directional*u_lightcolor,mix(vec3(0.0),vec3(0.3),1.0-u_lightcolor),vec3(1.0));v_lighting*=u_opacity;}\"),Qe=lr(\"#ifdef GL_ES\\nprecision highp float;\\n#endif\\nuniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_dimension;uniform float u_zoom;uniform float u_maxzoom;float getElevation(vec2 coord,float bias) {vec4 data=texture2D(u_image,coord)*255.0;return (data.r+data.g*256.0+data.b*256.0*256.0)/4.0;}void main() {vec2 epsilon=1.0/u_dimension;float a=getElevation(v_pos+vec2(-epsilon.x,-epsilon.y),0.0);float b=getElevation(v_pos+vec2(0,-epsilon.y),0.0);float c=getElevation(v_pos+vec2(epsilon.x,-epsilon.y),0.0);float d=getElevation(v_pos+vec2(-epsilon.x,0),0.0);float e=getElevation(v_pos,0.0);float f=getElevation(v_pos+vec2(epsilon.x,0),0.0);float g=getElevation(v_pos+vec2(-epsilon.x,epsilon.y),0.0);float h=getElevation(v_pos+vec2(0,epsilon.y),0.0);float i=getElevation(v_pos+vec2(epsilon.x,epsilon.y),0.0);float exaggeration=u_zoom < 2.0 ? 0.4 : u_zoom < 4.5 ? 0.35 : 0.3;vec2 deriv=vec2((c+f+f+i)-(a+d+d+g),(g+h+h+i)-(a+b+b+c))/ pow(2.0,(u_zoom-u_maxzoom)*exaggeration+19.2562-u_zoom);gl_FragColor=clamp(vec4(deriv.x/2.0+0.5,deriv.y/2.0+0.5,1.0,1.0),0.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_dimension;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);highp vec2 epsilon=1.0/u_dimension;float scale=(u_dimension.x-2.0)/u_dimension.x;v_pos=(a_texture_pos/8192.0)*scale+epsilon;}\"),tr=lr(\"uniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_latrange;uniform vec2 u_light;uniform vec4 u_shadow;uniform vec4 u_highlight;uniform vec4 u_accent;\\n#define PI 3.141592653589793\\nvoid main() {vec4 pixel=texture2D(u_image,v_pos);vec2 deriv=((pixel.rg*2.0)-1.0);float scaleFactor=cos(radians((u_latrange[0]-u_latrange[1])*(1.0-v_pos.y)+u_latrange[1]));float slope=atan(1.25*length(deriv)/scaleFactor);float aspect=deriv.x !=0.0 ? atan(deriv.y,-deriv.x) : PI/2.0*(deriv.y > 0.0 ? 1.0 :-1.0);float intensity=u_light.x;float azimuth=u_light.y+PI;float base=1.875-intensity*1.75;float maxValue=0.5*PI;float scaledSlope=intensity !=0.5 ? ((pow(base,slope)-1.0)/(pow(base,maxValue)-1.0))*maxValue : slope;float accent=cos(scaledSlope);vec4 accent_color=(1.0-accent)*u_accent*clamp(intensity*2.0,0.0,1.0);float shade=abs(mod((aspect+azimuth)/PI+0.5,2.0)-1.0);vec4 shade_color=mix(u_shadow,u_highlight,shade)*sin(scaledSlope)*clamp(intensity*2.0,0.0,1.0);gl_FragColor=accent_color*(1.0-shade_color.a)+shade_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos=a_texture_pos/8192.0;}\"),er=lr(\"uniform lowp float u_device_pixel_ratio;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform vec2 u_units_to_pixels;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_linesofar;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),rr=lr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);vec4 color=texture2D(u_image,vec2(v_lineprogress,0.5));gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define MAX_LINE_DISTANCE 32767.0\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_lineprogress=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0/MAX_LINE_DISTANCE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),nr=lr(\"uniform lowp float u_device_pixel_ratio;uniform vec2 u_texsize;uniform float u_fade;uniform mediump vec4 u_scale;uniform sampler2D u_image;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileZoomRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);vec2 pattern_size_a=vec2(display_size_a.x*fromScale/tileZoomRatio,display_size_a.y);vec2 pattern_size_b=vec2(display_size_b.x*toScale/tileZoomRatio,display_size_b.y);float dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float x_a=mod(v_linesofar/pattern_size_a.x,1.0);float x_b=mod(v_linesofar/pattern_size_b.x,1.0);float y_a=0.5+(v_normal.y*clamp(v_width2.s,0.0,(pattern_size_a.y+2.0)/2.0)/pattern_size_a.y);float y_b=0.5+(v_normal.y*clamp(v_width2.s,0.0,(pattern_size_b.y+2.0)/2.0)/pattern_size_b.y);vec2 pos_a=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,vec2(x_a,y_a));vec2 pos_b=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,vec2(x_b,y_b));vec4 color=mix(texture2D(u_image,pos_a),texture2D(u_image,pos_b),u_fade);gl_FragColor=color*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform vec2 u_units_to_pixels;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_linesofar=a_linesofar;v_width2=vec2(outset,inset);}\"),ir=lr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;uniform float u_sdfgamma;uniform float u_mix;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float sdfdist_a=texture2D(u_image,v_tex_a).a;float sdfdist_b=texture2D(u_image,v_tex_b).a;float sdfdist=mix(sdfdist_a,sdfdist_b,u_mix);alpha*=smoothstep(0.5-u_sdfgamma/floorwidth,0.5+u_sdfgamma/floorwidth,sdfdist);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_patternscale_a;uniform float u_tex_y_a;uniform vec2 u_patternscale_b;uniform float u_tex_y_b;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_tex_a=vec2(a_linesofar*u_patternscale_a.x/floorwidth,normal.y*u_patternscale_a.y+u_tex_y_a);v_tex_b=vec2(a_linesofar*u_patternscale_b.x/floorwidth,normal.y*u_patternscale_b.y+u_tex_y_b);v_width2=vec2(outset,inset);}\"),ar=lr(\"uniform float u_fade_t;uniform float u_opacity;uniform sampler2D u_image0;uniform sampler2D u_image1;varying vec2 v_pos0;varying vec2 v_pos1;uniform float u_brightness_low;uniform float u_brightness_high;uniform float u_saturation_factor;uniform float u_contrast_factor;uniform vec3 u_spin_weights;void main() {vec4 color0=texture2D(u_image0,v_pos0);vec4 color1=texture2D(u_image1,v_pos1);if (color0.a > 0.0) {color0.rgb=color0.rgb/color0.a;}if (color1.a > 0.0) {color1.rgb=color1.rgb/color1.a;}vec4 color=mix(color0,color1,u_fade_t);color.a*=u_opacity;vec3 rgb=color.rgb;rgb=vec3(dot(rgb,u_spin_weights.xyz),dot(rgb,u_spin_weights.zxy),dot(rgb,u_spin_weights.yzx));float average=(color.r+color.g+color.b)/3.0;rgb+=(average-rgb)*u_saturation_factor;rgb=(rgb-0.5)*u_contrast_factor+0.5;vec3 u_high_vec=vec3(u_brightness_low,u_brightness_low,u_brightness_low);vec3 u_low_vec=vec3(u_brightness_high,u_brightness_high,u_brightness_high);gl_FragColor=vec4(mix(u_high_vec,u_low_vec,rgb)*color.a,color.a);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_tl_parent;uniform float u_scale_parent;uniform float u_buffer_scale;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos0;varying vec2 v_pos1;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos0=(((a_texture_pos/8192.0)-0.5)/u_buffer_scale )+0.5;v_pos1=(v_pos0*u_scale_parent)+u_tl_parent;}\"),or=lr(\"uniform sampler2D u_texture;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nlowp float alpha=opacity*v_fade_opacity;gl_FragColor=texture2D(u_texture,v_tex)*alpha;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform highp float u_camera_to_center_distance;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform float u_fade_change;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform vec2 u_texsize;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size[0],a_size[1],u_size_t)/256.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size[0]/256.0;} else if (!u_is_size_zoom_constant && u_is_size_feature_constant) {size=u_size;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);v_tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;v_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));}\"),sr=lr(\"#define SDF_PX 8.0\\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;uniform bool u_is_text;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nfloat EDGE_GAMMA=0.105/u_device_pixel_ratio;vec2 tex=v_data0.xy;float gamma_scale=v_data1.x;float size=v_data1.y;float fade_opacity=v_data1[2];float fontScale=u_is_text ? size/24.0 : size;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size[0],a_size[1],u_size_t)/256.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size[0]/256.0;} else if (!u_is_size_zoom_constant && u_is_size_feature_constant) {size=u_size;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);float gamma_scale=gl_Position.w;vec2 tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));v_data0=vec2(tex.x,tex.y);v_data1=vec3(gamma_scale,size,interpolated_fade_opacity);}\");function lr(t,e){var r=/#pragma mapbox: ([\\w]+) ([\\w]+) ([\\w]+) ([\\w]+)/g,n={};return{fragmentSource:t=t.replace(r,function(t,e,r,i,a){return n[a]=!0,\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"\\n#ifdef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"}),vertexSource:e=e.replace(r,function(t,e,r,i,a){var o=\"float\"===i?\"vec2\":\"vec4\",s=a.match(/color/)?\"color\":o;return n[a]?\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"})}}var cr=Object.freeze({prelude:Fe,background:Be,backgroundPattern:Ne,circle:je,clippingMask:Ue,heatmap:Ve,heatmapTexture:qe,collisionBox:He,collisionCircle:Ge,debug:Ye,fill:We,fillOutline:Xe,fillOutlinePattern:Ze,fillPattern:Je,fillExtrusion:Ke,fillExtrusionPattern:$e,hillshadePrepare:Qe,hillshade:tr,line:er,lineGradient:rr,linePattern:nr,lineSDF:ir,raster:ar,symbolIcon:or,symbolSDF:sr}),ur=function(){this.boundProgram=null,this.boundLayoutVertexBuffer=null,this.boundPaintVertexBuffers=[],this.boundIndexBuffer=null,this.boundVertexOffset=null,this.boundDynamicVertexBuffer=null,this.vao=null};ur.prototype.bind=function(t,e,r,n,i,a,o,s){this.context=t;for(var l=this.boundPaintVertexBuffers.length!==n.length,c=0;!l&&c<n.length;c++)this.boundPaintVertexBuffers[c]!==n[c]&&(l=!0);var u=!this.vao||this.boundProgram!==e||this.boundLayoutVertexBuffer!==r||l||this.boundIndexBuffer!==i||this.boundVertexOffset!==a||this.boundDynamicVertexBuffer!==o||this.boundDynamicVertexBuffer2!==s;!t.extVertexArrayObject||u?this.freshBind(e,r,n,i,a,o,s):(t.bindVertexArrayOES.set(this.vao),o&&o.bind(),i&&i.dynamicDraw&&i.bind(),s&&s.bind())},ur.prototype.freshBind=function(t,e,r,n,i,a,o){var s,l=t.numAttributes,c=this.context,u=c.gl;if(c.extVertexArrayObject)this.vao&&this.destroy(),this.vao=c.extVertexArrayObject.createVertexArrayOES(),c.bindVertexArrayOES.set(this.vao),s=0,this.boundProgram=t,this.boundLayoutVertexBuffer=e,this.boundPaintVertexBuffers=r,this.boundIndexBuffer=n,this.boundVertexOffset=i,this.boundDynamicVertexBuffer=a,this.boundDynamicVertexBuffer2=o;else{s=c.currentNumAttributes||0;for(var h=l;h<s;h++)u.disableVertexAttribArray(h)}e.enableAttributes(u,t);for(var f=0,p=r;f<p.length;f+=1)p[f].enableAttributes(u,t);a&&a.enableAttributes(u,t),o&&o.enableAttributes(u,t),e.bind(),e.setVertexAttribPointers(u,t,i);for(var d=0,g=r;d<g.length;d+=1){var v=g[d];v.bind(),v.setVertexAttribPointers(u,t,i)}a&&(a.bind(),a.setVertexAttribPointers(u,t,i)),n&&n.bind(),o&&(o.bind(),o.setVertexAttribPointers(u,t,i)),c.currentNumAttributes=l},ur.prototype.destroy=function(){this.vao&&(this.context.extVertexArrayObject.deleteVertexArrayOES(this.vao),this.vao=null)};var hr=function(t,e,r,n,i){var a=t.gl;this.program=a.createProgram();var o=r.defines();i&&o.push(\"#define OVERDRAW_INSPECTOR;\");var s=o.concat(Fe.fragmentSource,e.fragmentSource).join(\"\\n\"),l=o.concat(Fe.vertexSource,e.vertexSource).join(\"\\n\"),c=a.createShader(a.FRAGMENT_SHADER);a.shaderSource(c,s),a.compileShader(c),a.attachShader(this.program,c);var u=a.createShader(a.VERTEX_SHADER);a.shaderSource(u,l),a.compileShader(u),a.attachShader(this.program,u);for(var h=r.layoutAttributes||[],f=0;f<h.length;f++)a.bindAttribLocation(this.program,f,h[f].name);a.linkProgram(this.program),this.numAttributes=a.getProgramParameter(this.program,a.ACTIVE_ATTRIBUTES),this.attributes={};for(var p={},d=0;d<this.numAttributes;d++){var g=a.getActiveAttrib(this.program,d);g&&(this.attributes[g.name]=a.getAttribLocation(this.program,g.name))}for(var v=a.getProgramParameter(this.program,a.ACTIVE_UNIFORMS),m=0;m<v;m++){var y=a.getActiveUniform(this.program,m);y&&(p[y.name]=a.getUniformLocation(this.program,y.name))}this.fixedUniforms=n(t,p),this.binderUniforms=r.getUniforms(t,p)};function fr(e,r,n){var i=1/le(n,1,r.transform.tileZoom),a=Math.pow(2,n.tileID.overscaledZ),o=n.tileSize*Math.pow(2,r.transform.tileZoom)/a,s=o*(n.tileID.canonical.x+n.tileID.wrap*a),l=o*n.tileID.canonical.y;return{u_image:0,u_texsize:n.imageAtlasTexture.size,u_scale:[t.browser.devicePixelRatio,i,e.fromScale,e.toScale],u_fade:e.t,u_pixel_coord_upper:[s>>16,l>>16],u_pixel_coord_lower:[65535&s,65535&l]}}hr.prototype.draw=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g){var v,m=t.gl;for(var y in t.program.set(this.program),t.setDepthMode(r),t.setStencilMode(n),t.setColorMode(i),t.setCullFace(a),this.fixedUniforms)this.fixedUniforms[y].set(o[y]);p&&p.setUniforms(t,this.binderUniforms,h,{zoom:f});for(var x=(v={},v[m.LINES]=2,v[m.TRIANGLES]=3,v[m.LINE_STRIP]=1,v)[e],b=0,_=u.get();b<_.length;b+=1){var w=_[b],k=w.vaos||(w.vaos={});(k[s]||(k[s]=new ur)).bind(t,this,l,p?p.getPaintVertexBuffers():[],c,w.vertexOffset,d,g),m.drawElements(e,w.primitiveLength*x,m.UNSIGNED_SHORT,w.primitiveOffset*x*2)}};var pr=function(e,r,n,i){var a=r.style.light,o=a.properties.get(\"position\"),s=[o.x,o.y,o.z],l=t.create$1();\"viewport\"===a.properties.get(\"anchor\")&&t.fromRotation(l,-r.transform.angle),t.transformMat3(s,s,l);var c=a.properties.get(\"color\");return{u_matrix:e,u_lightpos:s,u_lightintensity:a.properties.get(\"intensity\"),u_lightcolor:[c.r,c.g,c.b],u_vertical_gradient:+n,u_opacity:i}},dr=function(e,r,n,i,a,o,s){return t.extend(pr(e,r,n,i),fr(o,r,s),{u_height_factor:-Math.pow(2,a.overscaledZ)/s.tileSize/8})},gr=function(t){return{u_matrix:t}},vr=function(e,r,n,i){return t.extend(gr(e),fr(n,r,i))},mr=function(t,e){return{u_matrix:t,u_world:e}},yr=function(e,r,n,i,a){return t.extend(vr(e,r,n,i),{u_world:a})},xr=function(e,r,n,i){var a,o,s=e.transform;if(\"map\"===i.paint.get(\"circle-pitch-alignment\")){var l=le(n,1,s.zoom);a=!0,o=[l,l]}else a=!1,o=s.pixelsToGLUnits;return{u_camera_to_center_distance:s.cameraToCenterDistance,u_scale_with_map:+(\"map\"===i.paint.get(\"circle-pitch-scale\")),u_matrix:e.translatePosMatrix(r.posMatrix,n,i.paint.get(\"circle-translate\"),i.paint.get(\"circle-translate-anchor\")),u_pitch_with_map:+a,u_device_pixel_ratio:t.browser.devicePixelRatio,u_extrude_scale:o}},br=function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pixels_to_tile_units:new t.Uniform1f(e,r.u_pixels_to_tile_units),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_overscale_factor:new t.Uniform1f(e,r.u_overscale_factor)}},_r=function(t,e,r){var n=le(r,1,e.zoom),i=Math.pow(2,e.zoom-r.tileID.overscaledZ),a=r.tileID.overscaleFactor();return{u_matrix:t,u_camera_to_center_distance:e.cameraToCenterDistance,u_pixels_to_tile_units:n,u_extrude_scale:[e.pixelsToGLUnits[0]/(n*i),e.pixelsToGLUnits[1]/(n*i)],u_overscale_factor:a}},wr=function(t,e){return{u_matrix:t,u_color:e}},kr=function(t){return{u_matrix:t}},Tr=function(t,e,r,n){return{u_matrix:t,u_extrude_scale:le(e,1,r),u_intensity:n}},Ar=function(t,e,r){var n=r.paint.get(\"hillshade-shadow-color\"),i=r.paint.get(\"hillshade-highlight-color\"),a=r.paint.get(\"hillshade-accent-color\"),o=r.paint.get(\"hillshade-illumination-direction\")*(Math.PI/180);\"viewport\"===r.paint.get(\"hillshade-illumination-anchor\")&&(o-=t.transform.angle);var s=!t.options.moving;return{u_matrix:t.transform.calculatePosMatrix(e.tileID.toUnwrapped(),s),u_image:0,u_latrange:Sr(t,e.tileID),u_light:[r.paint.get(\"hillshade-exaggeration\"),o],u_shadow:n,u_highlight:i,u_accent:a}},Mr=function(e,r){var n=e.dem.stride,i=t.create();return t.ortho(i,0,t.EXTENT,-t.EXTENT,0,0,1),t.translate(i,i,[0,-t.EXTENT,0]),{u_matrix:i,u_image:1,u_dimension:[n,n],u_zoom:e.tileID.overscaledZ,u_maxzoom:r}};function Sr(e,r){var n=Math.pow(2,r.canonical.z),i=r.canonical.y;return[new t.MercatorCoordinate(0,i/n).toLngLat().lat,new t.MercatorCoordinate(0,(i+1)/n).toLngLat().lat]}var Er=function(e,r,n){var i=e.transform;return{u_matrix:zr(e,r,n),u_ratio:1/le(r,1,i.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_units_to_pixels:[1/i.pixelsToGLUnits[0],1/i.pixelsToGLUnits[1]]}},Cr=function(e,r,n){return t.extend(Er(e,r,n),{u_image:0})},Lr=function(e,r,n,i){var a=e.transform,o=Or(r,a);return{u_matrix:zr(e,r,n),u_texsize:r.imageAtlasTexture.size,u_ratio:1/le(r,1,a.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_image:0,u_scale:[t.browser.devicePixelRatio,o,i.fromScale,i.toScale],u_fade:i.t,u_units_to_pixels:[1/a.pixelsToGLUnits[0],1/a.pixelsToGLUnits[1]]}},Pr=function(e,r,n,i,a){var o=e.transform,s=e.lineAtlas,l=Or(r,o),c=\"round\"===n.layout.get(\"line-cap\"),u=s.getDash(i.from,c),h=s.getDash(i.to,c),f=u.width*a.fromScale,p=h.width*a.toScale;return t.extend(Er(e,r,n),{u_patternscale_a:[l/f,-u.height/2],u_patternscale_b:[l/p,-h.height/2],u_sdfgamma:s.width/(256*Math.min(f,p)*t.browser.devicePixelRatio)/2,u_image:0,u_tex_y_a:u.y,u_tex_y_b:h.y,u_mix:a.t})};function Or(t,e){return 1/le(t,1,e.tileZoom)}function zr(t,e,r){return t.translatePosMatrix(e.tileID.posMatrix,e,r.paint.get(\"line-translate\"),r.paint.get(\"line-translate-anchor\"))}var Ir=function(t,e,r,n,i){return{u_matrix:t,u_tl_parent:e,u_scale_parent:r,u_buffer_scale:1,u_fade_t:n.mix,u_opacity:n.opacity*i.paint.get(\"raster-opacity\"),u_image0:0,u_image1:1,u_brightness_low:i.paint.get(\"raster-brightness-min\"),u_brightness_high:i.paint.get(\"raster-brightness-max\"),u_saturation_factor:(o=i.paint.get(\"raster-saturation\"),o>0?1-1/(1.001-o):-o),u_contrast_factor:(a=i.paint.get(\"raster-contrast\"),a>0?1/(1-a):1+a),u_spin_weights:function(t){t*=Math.PI/180;var e=Math.sin(t),r=Math.cos(t);return[(2*r+1)/3,(-Math.sqrt(3)*e-r+1)/3,(Math.sqrt(3)*e-r+1)/3]}(i.paint.get(\"raster-hue-rotate\"))};var a,o};var Dr=function(t,e,r,n,i,a,o,s,l,c){var u=i.transform;return{u_is_size_zoom_constant:+(\"constant\"===t||\"source\"===t),u_is_size_feature_constant:+(\"constant\"===t||\"camera\"===t),u_size_t:e?e.uSizeT:0,u_size:e?e.uSize:0,u_camera_to_center_distance:u.cameraToCenterDistance,u_pitch:u.pitch/360*2*Math.PI,u_rotate_symbol:+r,u_aspect_ratio:u.width/u.height,u_fade_change:i.options.fadeDuration?i.symbolFadeChange:1,u_matrix:a,u_label_plane_matrix:o,u_coord_matrix:s,u_is_text:+l,u_pitch_with_map:+n,u_texsize:c,u_texture:0}},Rr=function(e,r,n,i,a,o,s,l,c,u,h){var f=a.transform;return t.extend(Dr(e,r,n,i,a,o,s,l,c,u),{u_gamma_scale:i?Math.cos(f._pitch)*f.cameraToCenterDistance:1,u_device_pixel_ratio:t.browser.devicePixelRatio,u_is_halo:+h})},Fr=function(t,e,r){return{u_matrix:t,u_opacity:e,u_color:r}},Br=function(e,r,n,i,a,o){return t.extend(function(t,e,r,n){var i=r.imageManager.getPattern(t.from),a=r.imageManager.getPattern(t.to),o=r.imageManager.getPixelSize(),s=o.width,l=o.height,c=Math.pow(2,n.tileID.overscaledZ),u=n.tileSize*Math.pow(2,r.transform.tileZoom)/c,h=u*(n.tileID.canonical.x+n.tileID.wrap*c),f=u*n.tileID.canonical.y;return{u_image:0,u_pattern_tl_a:i.tl,u_pattern_br_a:i.br,u_pattern_tl_b:a.tl,u_pattern_br_b:a.br,u_texsize:[s,l],u_mix:e.t,u_pattern_size_a:i.displaySize,u_pattern_size_b:a.displaySize,u_scale_a:e.fromScale,u_scale_b:e.toScale,u_tile_units_to_pixels:1/le(n,1,r.transform.tileZoom),u_pixel_coord_upper:[h>>16,f>>16],u_pixel_coord_lower:[65535&h,65535&f]}}(i,o,n,a),{u_matrix:e,u_opacity:r})},Nr={fillExtrusion:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fillExtrusionPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_height_factor:new t.Uniform1f(e,r.u_height_factor),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fill:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},fillPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},fillOutline:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world)}},fillOutlinePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},circle:function(e,r){return{u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_scale_with_map:new t.Uniform1i(e,r.u_scale_with_map),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},collisionBox:br,collisionCircle:br,debug:function(e,r){return{u_color:new t.UniformColor(e,r.u_color),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},clippingMask:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmap:function(e,r){return{u_extrude_scale:new t.Uniform1f(e,r.u_extrude_scale),u_intensity:new t.Uniform1f(e,r.u_intensity),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmapTexture:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_color_ramp:new t.Uniform1i(e,r.u_color_ramp),u_opacity:new t.Uniform1f(e,r.u_opacity)}},hillshade:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_latrange:new t.Uniform2f(e,r.u_latrange),u_light:new t.Uniform2f(e,r.u_light),u_shadow:new t.UniformColor(e,r.u_shadow),u_highlight:new t.UniformColor(e,r.u_highlight),u_accent:new t.UniformColor(e,r.u_accent)}},hillshadePrepare:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_dimension:new t.Uniform2f(e,r.u_dimension),u_zoom:new t.Uniform1f(e,r.u_zoom),u_maxzoom:new t.Uniform1f(e,r.u_maxzoom)}},line:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels)}},lineGradient:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_image:new t.Uniform1i(e,r.u_image)}},linePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_texsize:new t.Uniform2f(e,r.u_texsize),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_image:new t.Uniform1i(e,r.u_image),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},lineSDF:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_patternscale_a:new t.Uniform2f(e,r.u_patternscale_a),u_patternscale_b:new t.Uniform2f(e,r.u_patternscale_b),u_sdfgamma:new t.Uniform1f(e,r.u_sdfgamma),u_image:new t.Uniform1i(e,r.u_image),u_tex_y_a:new t.Uniform1f(e,r.u_tex_y_a),u_tex_y_b:new t.Uniform1f(e,r.u_tex_y_b),u_mix:new t.Uniform1f(e,r.u_mix)}},raster:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_tl_parent:new t.Uniform2f(e,r.u_tl_parent),u_scale_parent:new t.Uniform1f(e,r.u_scale_parent),u_buffer_scale:new t.Uniform1f(e,r.u_buffer_scale),u_fade_t:new t.Uniform1f(e,r.u_fade_t),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image0:new t.Uniform1i(e,r.u_image0),u_image1:new t.Uniform1i(e,r.u_image1),u_brightness_low:new t.Uniform1f(e,r.u_brightness_low),u_brightness_high:new t.Uniform1f(e,r.u_brightness_high),u_saturation_factor:new t.Uniform1f(e,r.u_saturation_factor),u_contrast_factor:new t.Uniform1f(e,r.u_contrast_factor),u_spin_weights:new t.Uniform3f(e,r.u_spin_weights)}},symbolIcon:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1f(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture)}},symbolSDF:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1f(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture),u_gamma_scale:new t.Uniform1f(e,r.u_gamma_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_is_halo:new t.Uniform1f(e,r.u_is_halo)}},background:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_color:new t.UniformColor(e,r.u_color)}},backgroundPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image:new t.Uniform1i(e,r.u_image),u_pattern_tl_a:new t.Uniform2f(e,r.u_pattern_tl_a),u_pattern_br_a:new t.Uniform2f(e,r.u_pattern_br_a),u_pattern_tl_b:new t.Uniform2f(e,r.u_pattern_tl_b),u_pattern_br_b:new t.Uniform2f(e,r.u_pattern_br_b),u_texsize:new t.Uniform2f(e,r.u_texsize),u_mix:new t.Uniform1f(e,r.u_mix),u_pattern_size_a:new t.Uniform2f(e,r.u_pattern_size_a),u_pattern_size_b:new t.Uniform2f(e,r.u_pattern_size_b),u_scale_a:new t.Uniform1f(e,r.u_scale_a),u_scale_b:new t.Uniform1f(e,r.u_scale_b),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_tile_units_to_pixels:new t.Uniform1f(e,r.u_tile_units_to_pixels)}}};function jr(e,r){for(var n=e.sort(function(t,e){return t.tileID.isLessThan(e.tileID)?-1:e.tileID.isLessThan(t.tileID)?1:0}),i=0;i<n.length;i++){var a={},o=n[i],s=n.slice(i+1);Ur(o.tileID.wrapped(),o.tileID,s,new t.OverscaledTileID(0,o.tileID.wrap+1,0,0,0),a),o.setMask(a,r)}}function Ur(e,r,n,i,a){for(var o=0;o<n.length;o++){var s=n[o];if(i.isLessThan(s.tileID))break;if(r.key===s.tileID.key)return;if(s.tileID.isChildOf(r)){for(var l=r.children(1/0),c=0;c<l.length;c++)Ur(e,l[c],n.slice(o),i,a);return}}var u=r.overscaledZ-e.overscaledZ,h=new t.CanonicalTileID(u,r.canonical.x-(e.canonical.x<<u),r.canonical.y-(e.canonical.y<<u));a[h.key]=a[h.key]||h}function Vr(t,e,r,n,i){for(var a=t.context,o=a.gl,s=i?t.useProgram(\"collisionCircle\"):t.useProgram(\"collisionBox\"),l=0;l<n.length;l++){var c=n[l],u=e.getTile(c),h=u.getBucket(r);if(h){var f=i?h.collisionCircle:h.collisionBox;f&&s.draw(a,i?o.TRIANGLES:o.LINES,Tt.disabled,At.disabled,t.colorModeForRenderPass(),St.disabled,_r(c.posMatrix,t.transform,u),r.id,f.layoutVertexBuffer,f.indexBuffer,f.segments,null,t.transform.zoom,null,null,f.collisionVertexBuffer)}}}var qr=t.identity(new Float32Array(16));function Hr(e,r,n,i,a,o){var s=t.getAnchorAlignment(e),l=-(s.horizontalAlign-.5)*r,c=-(s.verticalAlign-.5)*n,u=t.evaluateRadialOffset(e,i);return new t.Point((l/a+u[0])*o,(c/a+u[1])*o)}function Gr(e,r,n,i,a,o,s,l,c,u){var h=e.text.placedSymbolArray,f=e.text.dynamicLayoutVertexArray;f.clear();for(var p=0;p<h.length;p++){var d=h.get(p),g=!d.hidden&&d.crossTileID?i[d.crossTileID]:null;if(g){var v=new t.Point(d.anchorX,d.anchorY),m=Zt(v,n?l:s),y=.5+o.cameraToCenterDistance/m.signedDistanceFromCamera*.5,x=a.evaluateSizeForFeature(e.textSizeData,u,d)*y/t.ONE_EM;n&&(x*=e.tilePixelRatio/c);for(var b=g.width,_=g.height,w=g.radialOffset,k=g.textBoxScale,T=Hr(g.anchor,b,_,w,k,x),A=n?Zt(v.add(T),s).point:m.point.add(r?T.rotate(-o.angle):T),M=0;M<d.numGlyphs;M++)t.addDynamicAttributes(f,A,0)}else ie(d.numGlyphs,f)}e.text.dynamicLayoutVertexBuffer.updateData(f)}function Yr(e,r,n,i,a,o,s,l,c,u,h,f,p){for(var d,g,v=e.context,m=v.gl,y=e.transform,x=\"map\"===l,b=\"map\"===c,_=x&&\"point\"!==n.layout.get(\"symbol-placement\"),w=x&&!b&&!_,k=void 0!==n.layout.get(\"symbol-sort-key\").constantOr(1),T=e.depthModeForSublayer(0,Tt.ReadOnly),A=n.layout.get(\"text-variable-anchor\"),M=[],S=0,E=i;S<E.length;S+=1){var C=E[S],L=r.getTile(C),P=L.getBucket(n);if(P){var O=a?P.text:P.icon;if(O&&O.segments.get().length){var z=O.programConfigurations.get(n.id),I=a||P.sdfIcons,D=a?P.textSizeData:P.iconSizeData;d||(d=e.useProgram(I?\"symbolSDF\":\"symbolIcon\",z),g=t.evaluateSizeForZoom(D,y.zoom)),v.activeTexture.set(m.TEXTURE0);var R=void 0,F=void 0,B=void 0;if(a)F=L.glyphAtlasTexture,B=m.LINEAR,R=L.glyphAtlasTexture.size;else{var N=1!==n.layout.get(\"icon-size\").constantOr(0)||P.iconsNeedLinear,j=b||0!==y.pitch;F=L.imageAtlasTexture,B=I||e.options.rotating||e.options.zooming||N||j?m.LINEAR:m.NEAREST,R=L.imageAtlasTexture.size}var U=le(L,1,e.transform.zoom),V=Wt(C.posMatrix,b,x,e.transform,U),q=Xt(C.posMatrix,b,x,e.transform,U);if(_)Kt(P,C.posMatrix,e,a,V,q,b,u);else if(a&&g&&A){var H=Math.pow(2,y.zoom-L.tileID.overscaledZ);Gr(P,x,b,p,t.symbolSize,y,V,C.posMatrix,H,g)}var G=e.translatePosMatrix(C.posMatrix,L,o,s),Y=_||a&&A?qr:V,W=e.translatePosMatrix(q,L,o,s,!0),X=I&&0!==n.paint.get(a?\"text-halo-width\":\"icon-halo-width\").constantOr(1),Z={program:d,buffers:O,uniformValues:I?Rr(D.kind,g,w,b,e,G,Y,W,a,R,!0):Dr(D.kind,g,w,b,e,G,Y,W,a,R),atlasTexture:F,atlasInterpolation:B,isSDF:I,hasHalo:X};if(k)for(var J=0,K=O.segments.get();J<K.length;J+=1){var $=K[J];M.push({segments:new t.SegmentVector([$]),sortKey:$.sortKey,state:Z})}else M.push({segments:O.segments,sortKey:0,state:Z})}}}k&&M.sort(function(t,e){return t.sortKey-e.sortKey});for(var Q=0,tt=M;Q<tt.length;Q+=1){var et=tt[Q],rt=et.state;if(rt.atlasTexture.bind(rt.atlasInterpolation,m.CLAMP_TO_EDGE),rt.isSDF){var nt=rt.uniformValues;rt.hasHalo&&(nt.u_is_halo=1,Wr(rt.buffers,et.segments,n,e,rt.program,T,h,f,nt)),nt.u_is_halo=0}Wr(rt.buffers,et.segments,n,e,rt.program,T,h,f,rt.uniformValues)}}function Wr(t,e,r,n,i,a,o,s,l){var c=n.context,u=c.gl;i.draw(c,u.TRIANGLES,a,o,s,St.disabled,l,r.id,t.layoutVertexBuffer,t.indexBuffer,e,r.paint,n.transform.zoom,t.programConfigurations.get(r.id),t.dynamicLayoutVertexBuffer,t.opacityVertexBuffer)}function Xr(t,e,r,n,i,a,o){var s,l,c,u,h,f=t.context.gl,p=r.paint.get(\"fill-pattern\"),d=p&&p.constantOr(1),g=r.getCrossfadeParameters();o?(l=d&&!r.getPaintProperty(\"fill-outline-color\")?\"fillOutlinePattern\":\"fillOutline\",s=f.LINES):(l=d?\"fillPattern\":\"fill\",s=f.TRIANGLES);for(var v=0,m=n;v<m.length;v+=1){var y=m[v],x=e.getTile(y);if(!d||x.patternsLoaded()){var b=x.getBucket(r);if(b){var _=b.programConfigurations.get(r.id),w=t.useProgram(l,_);d&&(t.context.activeTexture.set(f.TEXTURE0),x.imageAtlasTexture.bind(f.LINEAR,f.CLAMP_TO_EDGE),_.updatePatternPaintBuffers(g));var k=p.constantOr(null);if(k&&x.imageAtlas){var T=x.imageAtlas.patternPositions[k.to],A=x.imageAtlas.patternPositions[k.from];T&&A&&_.setConstantPatternPositions(T,A)}var M=t.translatePosMatrix(y.posMatrix,x,r.paint.get(\"fill-translate\"),r.paint.get(\"fill-translate-anchor\"));if(o){u=b.indexBuffer2,h=b.segments2;var S=[f.drawingBufferWidth,f.drawingBufferHeight];c=\"fillOutlinePattern\"===l&&d?yr(M,t,g,x,S):mr(M,S)}else u=b.indexBuffer,h=b.segments,c=d?vr(M,t,g,x):gr(M);w.draw(t.context,s,i,t.stencilModeForClipping(y),a,St.disabled,c,r.id,b.layoutVertexBuffer,u,h,r.paint,t.transform.zoom,_)}}}}function Zr(t,e,r,n,i,a,o){for(var s=t.context,l=s.gl,c=r.paint.get(\"fill-extrusion-pattern\"),u=c.constantOr(1),h=r.getCrossfadeParameters(),f=r.paint.get(\"fill-extrusion-opacity\"),p=0,d=n;p<d.length;p+=1){var g=d[p],v=e.getTile(g),m=v.getBucket(r);if(m){var y=m.programConfigurations.get(r.id),x=t.useProgram(u?\"fillExtrusionPattern\":\"fillExtrusion\",y);u&&(t.context.activeTexture.set(l.TEXTURE0),v.imageAtlasTexture.bind(l.LINEAR,l.CLAMP_TO_EDGE),y.updatePatternPaintBuffers(h));var b=c.constantOr(null);if(b&&v.imageAtlas){var _=v.imageAtlas.patternPositions[b.to],w=v.imageAtlas.patternPositions[b.from];_&&w&&y.setConstantPatternPositions(_,w)}var k=t.translatePosMatrix(g.posMatrix,v,r.paint.get(\"fill-extrusion-translate\"),r.paint.get(\"fill-extrusion-translate-anchor\")),T=r.paint.get(\"fill-extrusion-vertical-gradient\"),A=u?dr(k,t,T,f,g,h,v):pr(k,t,T,f);x.draw(s,s.gl.TRIANGLES,i,a,o,St.backCCW,A,r.id,m.layoutVertexBuffer,m.indexBuffer,m.segments,r.paint,t.transform.zoom,y)}}}function Jr(t,e,r,n,i,a){var o=t.context,s=o.gl,l=e.fbo;if(l){var c=t.useProgram(\"hillshade\");o.activeTexture.set(s.TEXTURE0),s.bindTexture(s.TEXTURE_2D,l.colorAttachment.get());var u=Ar(t,e,r);e.maskedBoundsBuffer&&e.maskedIndexBuffer&&e.segments?c.draw(o,s.TRIANGLES,n,i,a,St.disabled,u,r.id,e.maskedBoundsBuffer,e.maskedIndexBuffer,e.segments):c.draw(o,s.TRIANGLES,n,i,a,St.disabled,u,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}}function Kr(e,r,n,i,a,o,s){var l=e.context,c=l.gl;if(r.dem&&r.dem.data){var u=r.dem.dim,h=r.dem.stride,f=r.dem.getPixels();if(l.activeTexture.set(c.TEXTURE1),l.pixelStoreUnpackPremultiplyAlpha.set(!1),r.demTexture=r.demTexture||e.getTileTexture(h),r.demTexture){var p=r.demTexture;p.update(f,{premultiply:!1}),p.bind(c.NEAREST,c.CLAMP_TO_EDGE)}else r.demTexture=new t.Texture(l,f,c.RGBA,{premultiply:!1}),r.demTexture.bind(c.NEAREST,c.CLAMP_TO_EDGE);l.activeTexture.set(c.TEXTURE0);var d=r.fbo;if(!d){var g=new t.Texture(l,{width:u,height:u,data:null},c.RGBA);g.bind(c.LINEAR,c.CLAMP_TO_EDGE),(d=r.fbo=l.createFramebuffer(u,u)).colorAttachment.set(g.texture)}l.bindFramebuffer.set(d.framebuffer),l.viewport.set([0,0,u,u]),e.useProgram(\"hillshadePrepare\").draw(l,c.TRIANGLES,a,o,s,St.disabled,Mr(r,i),n.id,e.rasterBoundsBuffer,e.quadTriangleIndexBuffer,e.rasterBoundsSegments),r.needsHillshadePrepare=!1}}function $r(e,r,n,i,a){var o=i.paint.get(\"raster-fade-duration\");if(o>0){var s=t.browser.now(),l=(s-e.timeAdded)/o,c=r?(s-r.timeAdded)/o:-1,u=n.getSource(),h=a.coveringZoomLevel({tileSize:u.tileSize,roundZoom:u.roundZoom}),f=!r||Math.abs(r.tileID.overscaledZ-h)>Math.abs(e.tileID.overscaledZ-h),p=f&&e.refreshedUponExpiration?1:t.clamp(f?l:1-c,0,1);return e.refreshedUponExpiration&&l>=1&&(e.refreshedUponExpiration=!1),r?{opacity:1,mix:1-p}:{opacity:p,mix:0}}return{opacity:1,mix:0}}function Qr(e,r,n){var i=e.context,a=i.gl,o=n.posMatrix,s=e.useProgram(\"debug\"),l=Tt.disabled,c=At.disabled,u=e.colorModeForRenderPass(),h=\"$debug\";s.draw(i,a.LINE_STRIP,l,c,u,St.disabled,wr(o,t.Color.red),h,e.debugBuffer,e.tileBorderIndexBuffer,e.debugSegments);for(var f=r.getTileByID(n.key).latestRawTileData,p=f&&f.byteLength||0,d=Math.floor(p/1024),g=function(t,e,r,n){n=n||1;var i,a,o,s,l,c,u,h,f=[];for(i=0,a=t.length;i<a;i++)if(l=tn[t[i]]){for(h=null,o=0,s=l[1].length;o<s;o+=2)-1===l[1][o]&&-1===l[1][o+1]?h=null:(c=e+l[1][o]*n,u=200-l[1][o+1]*n,h&&f.push(h.x,h.y,c,u),h={x:c,y:u});e+=l[0]*n}return f}(n.toString()+\" \"+d+\"kb\",50,0,5),v=new t.StructArrayLayout2i4,m=new t.StructArrayLayout2ui4,y=0;y<g.length;y+=2)v.emplaceBack(g[y],g[y+1]),m.emplaceBack(y,y+1);for(var x=i.createVertexBuffer(v,Re.members),b=i.createIndexBuffer(m),_=t.SegmentVector.simpleSegment(0,0,v.length/2,v.length/2),w=r.getTile(n).tileSize,k=t.EXTENT/(Math.pow(2,e.transform.zoom-n.overscaledZ)*w),T=[[-1,-1],[-1,1],[1,-1],[1,1]],A=0;A<T.length;A++){var M=T[A];s.draw(i,a.LINES,l,c,u,St.disabled,wr(t.translate([],o,[k*M[0],k*M[1],0]),t.Color.white),h,x,b,_)}s.draw(i,a.LINES,l,c,u,St.disabled,wr(o,t.Color.black),h,x,b,_)}var tn={\" \":[16,[]],\"!\":[10,[5,21,5,7,-1,-1,5,2,4,1,5,0,6,1,5,2]],'\"':[16,[4,21,4,14,-1,-1,12,21,12,14]],\"#\":[21,[11,25,4,-7,-1,-1,17,25,10,-7,-1,-1,4,12,18,12,-1,-1,3,6,17,6]],$:[20,[8,25,8,-4,-1,-1,12,25,12,-4,-1,-1,17,18,15,20,12,21,8,21,5,20,3,18,3,16,4,14,5,13,7,12,13,10,15,9,16,8,17,6,17,3,15,1,12,0,8,0,5,1,3,3]],\"%\":[24,[21,21,3,0,-1,-1,8,21,10,19,10,17,9,15,7,14,5,14,3,16,3,18,4,20,6,21,8,21,10,20,13,19,16,19,19,20,21,21,-1,-1,17,7,15,6,14,4,14,2,16,0,18,0,20,1,21,3,21,5,19,7,17,7]],\"&\":[26,[23,12,23,13,22,14,21,14,20,13,19,11,17,6,15,3,13,1,11,0,7,0,5,1,4,2,3,4,3,6,4,8,5,9,12,13,13,14,14,16,14,18,13,20,11,21,9,20,8,18,8,16,9,13,11,10,16,3,18,1,20,0,22,0,23,1,23,2]],\"'\":[10,[5,19,4,20,5,21,6,20,6,18,5,16,4,15]],\"(\":[14,[11,25,9,23,7,20,5,16,4,11,4,7,5,2,7,-2,9,-5,11,-7]],\")\":[14,[3,25,5,23,7,20,9,16,10,11,10,7,9,2,7,-2,5,-5,3,-7]],\"*\":[16,[8,21,8,9,-1,-1,3,18,13,12,-1,-1,13,18,3,12]],\"+\":[26,[13,18,13,0,-1,-1,4,9,22,9]],\",\":[10,[6,1,5,0,4,1,5,2,6,1,6,-1,5,-3,4,-4]],\"-\":[26,[4,9,22,9]],\".\":[10,[5,2,4,1,5,0,6,1,5,2]],\"/\":[22,[20,25,2,-7]],0:[20,[9,21,6,20,4,17,3,12,3,9,4,4,6,1,9,0,11,0,14,1,16,4,17,9,17,12,16,17,14,20,11,21,9,21]],1:[20,[6,17,8,18,11,21,11,0]],2:[20,[4,16,4,17,5,19,6,20,8,21,12,21,14,20,15,19,16,17,16,15,15,13,13,10,3,0,17,0]],3:[20,[5,21,16,21,10,13,13,13,15,12,16,11,17,8,17,6,16,3,14,1,11,0,8,0,5,1,4,2,3,4]],4:[20,[13,21,3,7,18,7,-1,-1,13,21,13,0]],5:[20,[15,21,5,21,4,12,5,13,8,14,11,14,14,13,16,11,17,8,17,6,16,3,14,1,11,0,8,0,5,1,4,2,3,4]],6:[20,[16,18,15,20,12,21,10,21,7,20,5,17,4,12,4,7,5,3,7,1,10,0,11,0,14,1,16,3,17,6,17,7,16,10,14,12,11,13,10,13,7,12,5,10,4,7]],7:[20,[17,21,7,0,-1,-1,3,21,17,21]],8:[20,[8,21,5,20,4,18,4,16,5,14,7,13,11,12,14,11,16,9,17,7,17,4,16,2,15,1,12,0,8,0,5,1,4,2,3,4,3,7,4,9,6,11,9,12,13,13,15,14,16,16,16,18,15,20,12,21,8,21]],9:[20,[16,14,15,11,13,9,10,8,9,8,6,9,4,11,3,14,3,15,4,18,6,20,9,21,10,21,13,20,15,18,16,14,16,9,15,4,13,1,10,0,8,0,5,1,4,3]],\":\":[10,[5,14,4,13,5,12,6,13,5,14,-1,-1,5,2,4,1,5,0,6,1,5,2]],\";\":[10,[5,14,4,13,5,12,6,13,5,14,-1,-1,6,1,5,0,4,1,5,2,6,1,6,-1,5,-3,4,-4]],\"<\":[24,[20,18,4,9,20,0]],\"=\":[26,[4,12,22,12,-1,-1,4,6,22,6]],\">\":[24,[4,18,20,9,4,0]],\"?\":[18,[3,16,3,17,4,19,5,20,7,21,11,21,13,20,14,19,15,17,15,15,14,13,13,12,9,10,9,7,-1,-1,9,2,8,1,9,0,10,1,9,2]],\"@\":[27,[18,13,17,15,15,16,12,16,10,15,9,14,8,11,8,8,9,6,11,5,14,5,16,6,17,8,-1,-1,12,16,10,14,9,11,9,8,10,6,11,5,-1,-1,18,16,17,8,17,6,19,5,21,5,23,7,24,10,24,12,23,15,22,17,20,19,18,20,15,21,12,21,9,20,7,19,5,17,4,15,3,12,3,9,4,6,5,4,7,2,9,1,12,0,15,0,18,1,20,2,21,3,-1,-1,19,16,18,8,18,6,19,5]],A:[18,[9,21,1,0,-1,-1,9,21,17,0,-1,-1,4,7,14,7]],B:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,15,17,13,16,12,13,11,-1,-1,4,11,13,11,16,10,17,9,18,7,18,4,17,2,16,1,13,0,4,0]],C:[21,[18,16,17,18,15,20,13,21,9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5]],D:[21,[4,21,4,0,-1,-1,4,21,11,21,14,20,16,18,17,16,18,13,18,8,17,5,16,3,14,1,11,0,4,0]],E:[19,[4,21,4,0,-1,-1,4,21,17,21,-1,-1,4,11,12,11,-1,-1,4,0,17,0]],F:[18,[4,21,4,0,-1,-1,4,21,17,21,-1,-1,4,11,12,11]],G:[21,[18,16,17,18,15,20,13,21,9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,18,8,-1,-1,13,8,18,8]],H:[22,[4,21,4,0,-1,-1,18,21,18,0,-1,-1,4,11,18,11]],I:[8,[4,21,4,0]],J:[16,[12,21,12,5,11,2,10,1,8,0,6,0,4,1,3,2,2,5,2,7]],K:[21,[4,21,4,0,-1,-1,18,21,4,7,-1,-1,9,12,18,0]],L:[17,[4,21,4,0,-1,-1,4,0,16,0]],M:[24,[4,21,4,0,-1,-1,4,21,12,0,-1,-1,20,21,12,0,-1,-1,20,21,20,0]],N:[22,[4,21,4,0,-1,-1,4,21,18,0,-1,-1,18,21,18,0]],O:[22,[9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,19,8,19,13,18,16,17,18,15,20,13,21,9,21]],P:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,14,17,12,16,11,13,10,4,10]],Q:[22,[9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,19,8,19,13,18,16,17,18,15,20,13,21,9,21,-1,-1,12,4,18,-2]],R:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,15,17,13,16,12,13,11,4,11,-1,-1,11,11,18,0]],S:[20,[17,18,15,20,12,21,8,21,5,20,3,18,3,16,4,14,5,13,7,12,13,10,15,9,16,8,17,6,17,3,15,1,12,0,8,0,5,1,3,3]],T:[16,[8,21,8,0,-1,-1,1,21,15,21]],U:[22,[4,21,4,6,5,3,7,1,10,0,12,0,15,1,17,3,18,6,18,21]],V:[18,[1,21,9,0,-1,-1,17,21,9,0]],W:[24,[2,21,7,0,-1,-1,12,21,7,0,-1,-1,12,21,17,0,-1,-1,22,21,17,0]],X:[20,[3,21,17,0,-1,-1,17,21,3,0]],Y:[18,[1,21,9,11,9,0,-1,-1,17,21,9,11]],Z:[20,[17,21,3,0,-1,-1,3,21,17,21,-1,-1,3,0,17,0]],\"[\":[14,[4,25,4,-7,-1,-1,5,25,5,-7,-1,-1,4,25,11,25,-1,-1,4,-7,11,-7]],\"\\\\\":[14,[0,21,14,-3]],\"]\":[14,[9,25,9,-7,-1,-1,10,25,10,-7,-1,-1,3,25,10,25,-1,-1,3,-7,10,-7]],\"^\":[16,[6,15,8,18,10,15,-1,-1,3,12,8,17,13,12,-1,-1,8,17,8,0]],_:[16,[0,-2,16,-2]],\"`\":[10,[6,21,5,20,4,18,4,16,5,15,6,16,5,17]],a:[19,[15,14,15,0,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],b:[19,[4,21,4,0,-1,-1,4,11,6,13,8,14,11,14,13,13,15,11,16,8,16,6,15,3,13,1,11,0,8,0,6,1,4,3]],c:[18,[15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],d:[19,[15,21,15,0,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],e:[18,[3,8,15,8,15,10,14,12,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],f:[12,[10,21,8,21,6,20,5,17,5,0,-1,-1,2,14,9,14]],g:[19,[15,14,15,-2,14,-5,13,-6,11,-7,8,-7,6,-6,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],h:[19,[4,21,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0]],i:[8,[3,21,4,20,5,21,4,22,3,21,-1,-1,4,14,4,0]],j:[10,[5,21,6,20,7,21,6,22,5,21,-1,-1,6,14,6,-3,5,-6,3,-7,1,-7]],k:[17,[4,21,4,0,-1,-1,14,14,4,4,-1,-1,8,8,15,0]],l:[8,[4,21,4,0]],m:[30,[4,14,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0,-1,-1,15,10,18,13,20,14,23,14,25,13,26,10,26,0]],n:[19,[4,14,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0]],o:[19,[8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3,16,6,16,8,15,11,13,13,11,14,8,14]],p:[19,[4,14,4,-7,-1,-1,4,11,6,13,8,14,11,14,13,13,15,11,16,8,16,6,15,3,13,1,11,0,8,0,6,1,4,3]],q:[19,[15,14,15,-7,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],r:[13,[4,14,4,0,-1,-1,4,8,5,11,7,13,9,14,12,14]],s:[17,[14,11,13,13,10,14,7,14,4,13,3,11,4,9,6,8,11,7,13,6,14,4,14,3,13,1,10,0,7,0,4,1,3,3]],t:[12,[5,21,5,4,6,1,8,0,10,0,-1,-1,2,14,9,14]],u:[19,[4,14,4,4,5,1,7,0,10,0,12,1,15,4,-1,-1,15,14,15,0]],v:[16,[2,14,8,0,-1,-1,14,14,8,0]],w:[22,[3,14,7,0,-1,-1,11,14,7,0,-1,-1,11,14,15,0,-1,-1,19,14,15,0]],x:[17,[3,14,14,0,-1,-1,14,14,3,0]],y:[16,[2,14,8,0,-1,-1,14,14,8,0,6,-4,4,-6,2,-7,1,-7]],z:[17,[14,14,3,0,-1,-1,3,14,14,14,-1,-1,3,0,14,0]],\"{\":[14,[9,25,7,24,6,23,5,21,5,19,6,17,7,16,8,14,8,12,6,10,-1,-1,7,24,6,22,6,20,7,18,8,17,9,15,9,13,8,11,4,9,8,7,9,5,9,3,8,1,7,0,6,-2,6,-4,7,-6,-1,-1,6,8,8,6,8,4,7,2,6,1,5,-1,5,-3,6,-5,7,-6,9,-7]],\"|\":[8,[4,25,4,-7]],\"}\":[14,[5,25,7,24,8,23,9,21,9,19,8,17,7,16,6,14,6,12,8,10,-1,-1,7,24,8,22,8,20,7,18,6,17,5,15,5,13,6,11,10,9,6,7,5,5,5,3,6,1,7,0,8,-2,8,-4,7,-6,-1,-1,8,8,6,6,6,4,7,2,8,1,9,-1,9,-3,8,-5,7,-6,5,-7]],\"~\":[24,[3,6,3,8,4,11,6,12,8,12,10,11,14,8,16,7,18,7,20,8,21,10,-1,-1,3,8,4,10,6,11,8,11,10,10,14,7,16,6,18,6,20,7,21,10,21,12]]},en={symbol:function(t,e,r,n,i){if(\"translucent\"===t.renderPass){var a=At.disabled,o=t.colorModeForRenderPass();0!==r.paint.get(\"icon-opacity\").constantOr(1)&&Yr(t,e,r,n,!1,r.paint.get(\"icon-translate\"),r.paint.get(\"icon-translate-anchor\"),r.layout.get(\"icon-rotation-alignment\"),r.layout.get(\"icon-pitch-alignment\"),r.layout.get(\"icon-keep-upright\"),a,o,i),0!==r.paint.get(\"text-opacity\").constantOr(1)&&Yr(t,e,r,n,!0,r.paint.get(\"text-translate\"),r.paint.get(\"text-translate-anchor\"),r.layout.get(\"text-rotation-alignment\"),r.layout.get(\"text-pitch-alignment\"),r.layout.get(\"text-keep-upright\"),a,o,i),e.map.showCollisionBoxes&&function(t,e,r,n){Vr(t,e,r,n,!1),Vr(t,e,r,n,!0)}(t,e,r,n)}},circle:function(t,e,r,n){if(\"translucent\"===t.renderPass){var i=r.paint.get(\"circle-opacity\"),a=r.paint.get(\"circle-stroke-width\"),o=r.paint.get(\"circle-stroke-opacity\");if(0!==i.constantOr(1)||0!==a.constantOr(1)&&0!==o.constantOr(1))for(var s=t.context,l=s.gl,c=t.depthModeForSublayer(0,Tt.ReadOnly),u=At.disabled,h=t.colorModeForRenderPass(),f=0;f<n.length;f++){var p=n[f],d=e.getTile(p),g=d.getBucket(r);if(g){var v=g.programConfigurations.get(r.id);t.useProgram(\"circle\",v).draw(s,l.TRIANGLES,c,u,h,St.disabled,xr(t,p,d,r),r.id,g.layoutVertexBuffer,g.indexBuffer,g.segments,r.paint,t.transform.zoom,v)}}}},heatmap:function(e,r,n,i){if(0!==n.paint.get(\"heatmap-opacity\"))if(\"offscreen\"===e.renderPass){var a=e.context,o=a.gl,s=e.depthModeForSublayer(0,Tt.ReadOnly),l=At.disabled,c=new Mt([o.ONE,o.ONE],t.Color.transparent,[!0,!0,!0,!0]);!function(t,e,r){var n=t.gl;t.activeTexture.set(n.TEXTURE1),t.viewport.set([0,0,e.width/4,e.height/4]);var i=r.heatmapFbo;if(i)n.bindTexture(n.TEXTURE_2D,i.colorAttachment.get()),t.bindFramebuffer.set(i.framebuffer);else{var a=n.createTexture();n.bindTexture(n.TEXTURE_2D,a),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,n.LINEAR),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,n.LINEAR),i=r.heatmapFbo=t.createFramebuffer(e.width/4,e.height/4),function t(e,r,n,i){var a=e.gl;a.texImage2D(a.TEXTURE_2D,0,a.RGBA,r.width/4,r.height/4,0,a.RGBA,e.extTextureHalfFloat?e.extTextureHalfFloat.HALF_FLOAT_OES:a.UNSIGNED_BYTE,null),i.colorAttachment.set(n),e.extTextureHalfFloat&&a.checkFramebufferStatus(a.FRAMEBUFFER)!==a.FRAMEBUFFER_COMPLETE&&(e.extTextureHalfFloat=null,i.colorAttachment.setDirty(),t(e,r,n,i))}(t,e,a,i)}}(a,e,n),a.clear({color:t.Color.transparent});for(var u=0;u<i.length;u++){var h=i[u];if(!r.hasRenderableParent(h)){var f=r.getTile(h),p=f.getBucket(n);if(p){var d=p.programConfigurations.get(n.id),g=e.useProgram(\"heatmap\",d),v=e.transform.zoom;g.draw(a,o.TRIANGLES,s,l,c,St.disabled,Tr(h.posMatrix,f,v,n.paint.get(\"heatmap-intensity\")),n.id,p.layoutVertexBuffer,p.indexBuffer,p.segments,n.paint,e.transform.zoom,d)}}}a.viewport.set([0,0,e.width,e.height])}else\"translucent\"===e.renderPass&&(e.context.setColorMode(e.colorModeForRenderPass()),function(e,r){var n=e.context,i=n.gl,a=r.heatmapFbo;if(a){n.activeTexture.set(i.TEXTURE0),i.bindTexture(i.TEXTURE_2D,a.colorAttachment.get()),n.activeTexture.set(i.TEXTURE1);var o=r.colorRampTexture;o||(o=r.colorRampTexture=new t.Texture(n,r.colorRamp,i.RGBA)),o.bind(i.LINEAR,i.CLAMP_TO_EDGE),e.useProgram(\"heatmapTexture\").draw(n,i.TRIANGLES,Tt.disabled,At.disabled,e.colorModeForRenderPass(),St.disabled,function(e,r,n,i){var a=t.create();t.ortho(a,0,e.width,e.height,0,0,1);var o=e.context.gl;return{u_matrix:a,u_world:[o.drawingBufferWidth,o.drawingBufferHeight],u_image:n,u_color_ramp:i,u_opacity:r.paint.get(\"heatmap-opacity\")}}(e,r,0,1),r.id,e.viewportBuffer,e.quadTriangleIndexBuffer,e.viewportSegments,r.paint,e.transform.zoom)}}(e,n))},line:function(e,r,n,i){if(\"translucent\"===e.renderPass){var a=n.paint.get(\"line-opacity\"),o=n.paint.get(\"line-width\");if(0!==a.constantOr(1)&&0!==o.constantOr(1)){var s=e.depthModeForSublayer(0,Tt.ReadOnly),l=e.colorModeForRenderPass(),c=n.paint.get(\"line-dasharray\"),u=n.paint.get(\"line-pattern\"),h=u.constantOr(1),f=n.paint.get(\"line-gradient\"),p=n.getCrossfadeParameters(),d=c?\"lineSDF\":h?\"linePattern\":f?\"lineGradient\":\"line\",g=e.context,v=g.gl,m=!0;if(f){g.activeTexture.set(v.TEXTURE0);var y=n.gradientTexture;if(!n.gradient)return;y||(y=n.gradientTexture=new t.Texture(g,n.gradient,v.RGBA)),y.bind(v.LINEAR,v.CLAMP_TO_EDGE)}for(var x=0,b=i;x<b.length;x+=1){var _=b[x],w=r.getTile(_);if(!h||w.patternsLoaded()){var k=w.getBucket(n);if(k){var T=k.programConfigurations.get(n.id),A=e.context.program.get(),M=e.useProgram(d,T),S=m||M.program!==A,E=u.constantOr(null);if(E&&w.imageAtlas){var C=w.imageAtlas.patternPositions[E.to],L=w.imageAtlas.patternPositions[E.from];C&&L&&T.setConstantPatternPositions(C,L)}var P=c?Pr(e,w,n,c,p):h?Lr(e,w,n,p):f?Cr(e,w,n):Er(e,w,n);c&&(S||e.lineAtlas.dirty)?(g.activeTexture.set(v.TEXTURE0),e.lineAtlas.bind(g)):h&&(g.activeTexture.set(v.TEXTURE0),w.imageAtlasTexture.bind(v.LINEAR,v.CLAMP_TO_EDGE),T.updatePatternPaintBuffers(p)),M.draw(g,v.TRIANGLES,s,e.stencilModeForClipping(_),l,St.disabled,P,n.id,k.layoutVertexBuffer,k.indexBuffer,k.segments,n.paint,e.transform.zoom,T),m=!1}}}}}},fill:function(e,r,n,i){var a=n.paint.get(\"fill-color\"),o=n.paint.get(\"fill-opacity\");if(0!==o.constantOr(1)){var s=e.colorModeForRenderPass(),l=n.paint.get(\"fill-pattern\"),c=e.opaquePassEnabledForLayer()&&!l.constantOr(1)&&1===a.constantOr(t.Color.transparent).a&&1===o.constantOr(0)?\"opaque\":\"translucent\";if(e.renderPass===c){var u=e.depthModeForSublayer(1,\"opaque\"===e.renderPass?Tt.ReadWrite:Tt.ReadOnly);Xr(e,r,n,i,u,s,!1)}if(\"translucent\"===e.renderPass&&n.paint.get(\"fill-antialias\")){var h=e.depthModeForSublayer(n.getPaintProperty(\"fill-outline-color\")?2:0,Tt.ReadOnly);Xr(e,r,n,i,h,s,!0)}}},\"fill-extrusion\":function(t,e,r,n){var i=r.paint.get(\"fill-extrusion-opacity\");if(0!==i&&\"translucent\"===t.renderPass){var a=new Tt(t.context.gl.LEQUAL,Tt.ReadWrite,t.depthRangeFor3D);if(1!==i||r.paint.get(\"fill-extrusion-pattern\").constantOr(1))Zr(t,e,r,n,a,At.disabled,Mt.disabled),Zr(t,e,r,n,a,t.stencilModeFor3D(),t.colorModeForRenderPass());else{var o=t.colorModeForRenderPass();Zr(t,e,r,n,a,At.disabled,o)}}},hillshade:function(t,e,r,n){if(\"offscreen\"===t.renderPass||\"translucent\"===t.renderPass){for(var i=t.context,a=e.getSource().maxzoom,o=t.depthModeForSublayer(0,Tt.ReadOnly),s=At.disabled,l=t.colorModeForRenderPass(),c=0,u=n;c<u.length;c+=1){var h=u[c],f=e.getTile(h);f.needsHillshadePrepare&&\"offscreen\"===t.renderPass?Kr(t,f,r,a,o,s,l):\"translucent\"===t.renderPass&&Jr(t,f,r,o,s,l)}i.viewport.set([0,0,t.width,t.height])}},raster:function(t,e,r,n){if(\"translucent\"===t.renderPass&&0!==r.paint.get(\"raster-opacity\"))for(var i=t.context,a=i.gl,o=e.getSource(),s=t.useProgram(\"raster\"),l=At.disabled,c=t.colorModeForRenderPass(),u=n.length&&n[0].overscaledZ,h=!t.options.moving,f=0,p=n;f<p.length;f+=1){var d=p[f],g=t.depthModeForSublayer(d.overscaledZ-u,1===r.paint.get(\"raster-opacity\")?Tt.ReadWrite:Tt.ReadOnly,a.LESS),v=e.getTile(d),m=t.transform.calculatePosMatrix(d.toUnwrapped(),h);v.registerFadeDuration(r.paint.get(\"raster-fade-duration\"));var y=e.findLoadedParent(d,0),x=$r(v,y,e,r,t.transform),b=void 0,_=void 0,w=\"nearest\"===r.paint.get(\"raster-resampling\")?a.NEAREST:a.LINEAR;i.activeTexture.set(a.TEXTURE0),v.texture.bind(w,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),i.activeTexture.set(a.TEXTURE1),y?(y.texture.bind(w,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),b=Math.pow(2,y.tileID.overscaledZ-v.tileID.overscaledZ),_=[v.tileID.canonical.x*b%1,v.tileID.canonical.y*b%1]):v.texture.bind(w,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST);var k=Ir(m,_||[0,0],b||1,x,r);o instanceof L?s.draw(i,a.TRIANGLES,g,l,c,St.disabled,k,r.id,o.boundsBuffer,t.quadTriangleIndexBuffer,o.boundsSegments):v.maskedBoundsBuffer&&v.maskedIndexBuffer&&v.segments?s.draw(i,a.TRIANGLES,g,l,c,St.disabled,k,r.id,v.maskedBoundsBuffer,v.maskedIndexBuffer,v.segments,r.paint,t.transform.zoom):s.draw(i,a.TRIANGLES,g,l,c,St.disabled,k,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}},background:function(t,e,r){var n=r.paint.get(\"background-color\"),i=r.paint.get(\"background-opacity\");if(0!==i){var a=t.context,o=a.gl,s=t.transform,l=s.tileSize,c=r.paint.get(\"background-pattern\");if(!t.isPatternMissing(c)){var u=c||1!==n.a||1!==i?\"translucent\":\"opaque\";if(t.renderPass===u){var h=At.disabled,f=t.depthModeForSublayer(0,\"opaque\"===u?Tt.ReadWrite:Tt.ReadOnly),p=t.colorModeForRenderPass(),d=t.useProgram(c?\"backgroundPattern\":\"background\"),g=s.coveringTiles({tileSize:l});c&&(a.activeTexture.set(o.TEXTURE0),t.imageManager.bind(t.context));for(var v=r.getCrossfadeParameters(),m=0,y=g;m<y.length;m+=1){var x=y[m],b=t.transform.calculatePosMatrix(x.toUnwrapped()),_=c?Br(b,i,t,c,{tileID:x,tileSize:l},v):Fr(b,i,n);d.draw(a,o.TRIANGLES,f,h,p,St.disabled,_,r.id,t.tileExtentBuffer,t.quadTriangleIndexBuffer,t.tileExtentSegments)}}}}},debug:function(t,e,r){for(var n=0;n<r.length;n++)Qr(t,e,r[n])},custom:function(t,e,r){var n=t.context,i=r.implementation;if(\"offscreen\"===t.renderPass){var a=i.prerender;a&&(t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),a.call(i,n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState())}else if(\"translucent\"===t.renderPass){t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),n.setStencilMode(At.disabled);var o=\"3d\"===i.renderingMode?new Tt(t.context.gl.LEQUAL,Tt.ReadWrite,t.depthRangeFor3D):t.depthModeForSublayer(0,Tt.ReadOnly);n.setDepthMode(o),i.render(n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState(),n.bindFramebuffer.set(null)}}},rn=function(e,r){this.context=new Et(e),this.transform=r,this._tileTextures={},this.setup(),this.numSublayers=Ct.maxUnderzooming+Ct.maxOverzooming+1,this.depthEpsilon=1/Math.pow(2,16),this.depthRboNeedsClear=!0,this.emptyProgramConfiguration=new t.ProgramConfiguration,this.crossTileSymbolIndex=new Pe};function nn(t,e){if(t.y>e.y){var r=t;t=e,e=r}return{x0:t.x,y0:t.y,x1:e.x,y1:e.y,dx:e.x-t.x,dy:e.y-t.y}}function an(t,e,r,n,i){var a=Math.max(r,Math.floor(e.y0)),o=Math.min(n,Math.ceil(e.y1));if(t.x0===e.x0&&t.y0===e.y0?t.x0+e.dy/t.dy*t.dx<e.x1:t.x1-e.dy/t.dy*t.dx<e.x0){var s=t;t=e,e=s}for(var l=t.dx/t.dy,c=e.dx/e.dy,u=t.dx>0,h=e.dx<0,f=a;f<o;f++){var p=l*Math.max(0,Math.min(t.dy,f+u-t.y0))+t.x0,d=c*Math.max(0,Math.min(e.dy,f+h-e.y0))+e.x0;i(Math.floor(d),Math.ceil(p),f)}}function on(t,e,r,n,i,a){var o,s=nn(t,e),l=nn(e,r),c=nn(r,t);s.dy>l.dy&&(o=s,s=l,l=o),s.dy>c.dy&&(o=s,s=c,c=o),l.dy>c.dy&&(o=l,l=c,c=o),s.dy&&an(c,s,n,i,a),l.dy&&an(c,l,n,i,a)}rn.prototype.resize=function(e,r){var n=this.context.gl;if(this.width=e*t.browser.devicePixelRatio,this.height=r*t.browser.devicePixelRatio,this.context.viewport.set([0,0,this.width,this.height]),this.style)for(var i=0,a=this.style._order;i<a.length;i+=1){var o=a[i];this.style._layers[o].resize()}this.depthRbo&&(n.deleteRenderbuffer(this.depthRbo),this.depthRbo=null)},rn.prototype.setup=function(){var e=this.context,r=new t.StructArrayLayout2i4;r.emplaceBack(0,0),r.emplaceBack(t.EXTENT,0),r.emplaceBack(0,t.EXTENT),r.emplaceBack(t.EXTENT,t.EXTENT),this.tileExtentBuffer=e.createVertexBuffer(r,Re.members),this.tileExtentSegments=t.SegmentVector.simpleSegment(0,0,4,2);var n=new t.StructArrayLayout2i4;n.emplaceBack(0,0),n.emplaceBack(t.EXTENT,0),n.emplaceBack(0,t.EXTENT),n.emplaceBack(t.EXTENT,t.EXTENT),this.debugBuffer=e.createVertexBuffer(n,Re.members),this.debugSegments=t.SegmentVector.simpleSegment(0,0,4,5);var i=new t.StructArrayLayout4i8;i.emplaceBack(0,0,0,0),i.emplaceBack(t.EXTENT,0,t.EXTENT,0),i.emplaceBack(0,t.EXTENT,0,t.EXTENT),i.emplaceBack(t.EXTENT,t.EXTENT,t.EXTENT,t.EXTENT),this.rasterBoundsBuffer=e.createVertexBuffer(i,t.rasterBoundsAttributes.members),this.rasterBoundsSegments=t.SegmentVector.simpleSegment(0,0,4,2);var a=new t.StructArrayLayout2i4;a.emplaceBack(0,0),a.emplaceBack(1,0),a.emplaceBack(0,1),a.emplaceBack(1,1),this.viewportBuffer=e.createVertexBuffer(a,Re.members),this.viewportSegments=t.SegmentVector.simpleSegment(0,0,4,2);var o=new t.StructArrayLayout1ui2;o.emplaceBack(0),o.emplaceBack(1),o.emplaceBack(3),o.emplaceBack(2),o.emplaceBack(0),this.tileBorderIndexBuffer=e.createIndexBuffer(o);var s=new t.StructArrayLayout3ui6;s.emplaceBack(0,1,2),s.emplaceBack(2,1,3),this.quadTriangleIndexBuffer=e.createIndexBuffer(s);var l=this.context.gl;this.stencilClearMode=new At({func:l.ALWAYS,mask:0},0,255,l.ZERO,l.ZERO,l.ZERO)},rn.prototype.clearStencil=function(){var e=this.context,r=e.gl;this.nextStencilID=1,this.currentStencilSource=void 0;var n=t.create();t.ortho(n,0,this.width,this.height,0,0,1),t.scale(n,n,[r.drawingBufferWidth,r.drawingBufferHeight,0]),this.useProgram(\"clippingMask\").draw(e,r.TRIANGLES,Tt.disabled,this.stencilClearMode,Mt.disabled,St.disabled,kr(n),\"$clipping\",this.viewportBuffer,this.quadTriangleIndexBuffer,this.viewportSegments)},rn.prototype._renderTileClippingMasks=function(t,e){if(this.currentStencilSource!==t.source&&t.isTileClipped()&&e&&e.length){this.currentStencilSource=t.source;var r=this.context,n=r.gl;this.nextStencilID+e.length>256&&this.clearStencil(),r.setColorMode(Mt.disabled),r.setDepthMode(Tt.disabled);var i=this.useProgram(\"clippingMask\");this._tileClippingMaskIDs={};for(var a=0,o=e;a<o.length;a+=1){var s=o[a],l=this._tileClippingMaskIDs[s.key]=this.nextStencilID++;i.draw(r,n.TRIANGLES,Tt.disabled,new At({func:n.ALWAYS,mask:0},l,255,n.KEEP,n.KEEP,n.REPLACE),Mt.disabled,St.disabled,kr(s.posMatrix),\"$clipping\",this.tileExtentBuffer,this.quadTriangleIndexBuffer,this.tileExtentSegments)}}},rn.prototype.stencilModeFor3D=function(){this.nextStencilID+1>256&&this.clearStencil();var t=this.nextStencilID++,e=this.context.gl;return new At({func:e.NOTEQUAL,mask:255},t,255,e.KEEP,e.KEEP,e.REPLACE)},rn.prototype.stencilModeForClipping=function(t){var e=this.context.gl;return new At({func:e.EQUAL,mask:255},this._tileClippingMaskIDs[t.key],0,e.KEEP,e.KEEP,e.REPLACE)},rn.prototype.colorModeForRenderPass=function(){var e=this.context.gl;return this._showOverdrawInspector?new Mt([e.CONSTANT_COLOR,e.ONE],new t.Color(1/8,1/8,1/8,0),[!0,!0,!0,!0]):\"opaque\"===this.renderPass?Mt.unblended:Mt.alphaBlended},rn.prototype.depthModeForSublayer=function(t,e,r){if(!this.opaquePassEnabledForLayer())return Tt.disabled;var n=1-((1+this.currentLayer)*this.numSublayers+t)*this.depthEpsilon;return new Tt(r||this.context.gl.LEQUAL,e,[n,n])},rn.prototype.opaquePassEnabledForLayer=function(){return this.currentLayer<this.opaquePassCutoff},rn.prototype.render=function(e,r){this.style=e,this.options=r,this.lineAtlas=e.lineAtlas,this.imageManager=e.imageManager,this.glyphManager=e.glyphManager,this.symbolFadeChange=e.placement.symbolFadeChange(t.browser.now()),this.imageManager.beginFrame();var n=this.style._order,i=this.style.sourceCaches;for(var a in i){var o=i[a];o.used&&o.prepare(this.context)}var s={},l={},c={};for(var u in i){var h=i[u];s[u]=h.getVisibleCoordinates(),l[u]=s[u].slice().reverse(),c[u]=h.getVisibleCoordinates(!0).reverse()}for(var f in i){var p=i[f],d=p.getSource();if(\"raster\"===d.type||\"raster-dem\"===d.type){for(var g=[],v=0,m=s[f];v<m.length;v+=1){var y=m[v];g.push(p.getTile(y))}jr(g,this.context)}}this.opaquePassCutoff=1/0;for(var x=0;x<n.length;x++){var b=n[x];if(this.style._layers[b].is3D()){this.opaquePassCutoff=x;break}}this.renderPass=\"offscreen\",this.depthRboNeedsClear=!0;for(var _=0,w=n;_<w.length;_+=1){var k=w[_],T=this.style._layers[k];if(T.hasOffscreenPass()&&!T.isHidden(this.transform.zoom)){var A=l[T.source];(\"custom\"===T.type||A.length)&&this.renderLayer(this,i[T.source],T,A)}}for(this.context.bindFramebuffer.set(null),this.context.clear({color:r.showOverdrawInspector?t.Color.black:t.Color.transparent,depth:1}),this.clearStencil(),this._showOverdrawInspector=r.showOverdrawInspector,this.depthRangeFor3D=[0,1-(e._order.length+2)*this.numSublayers*this.depthEpsilon],this.renderPass=\"opaque\",this.currentLayer=n.length-1;this.currentLayer>=0;this.currentLayer--){var M=this.style._layers[n[this.currentLayer]],S=i[M.source],E=s[M.source];this._renderTileClippingMasks(M,E),this.renderLayer(this,S,M,E)}for(this.renderPass=\"translucent\",this.currentLayer=0;this.currentLayer<n.length;this.currentLayer++){var C=this.style._layers[n[this.currentLayer]],L=i[C.source],P=(\"symbol\"===C.type?c:l)[C.source];this._renderTileClippingMasks(C,s[C.source]),this.renderLayer(this,L,C,P)}if(this.options.showTileBoundaries)for(var O in i){en.debug(this,i[O],s[O]);break}this.context.setDefault()},rn.prototype.setupOffscreenDepthRenderbuffer=function(){var t=this.context;this.depthRbo||(this.depthRbo=t.createRenderbuffer(t.gl.DEPTH_COMPONENT16,this.width,this.height))},rn.prototype.renderLayer=function(t,e,r,n){r.isHidden(this.transform.zoom)||(\"background\"===r.type||\"custom\"===r.type||n.length)&&(this.id=r.id,en[r.type](t,e,r,n,this.style.placement.variableOffsets))},rn.prototype.translatePosMatrix=function(e,r,n,i,a){if(!n[0]&&!n[1])return e;var o=a?\"map\"===i?this.transform.angle:0:\"viewport\"===i?-this.transform.angle:0;if(o){var s=Math.sin(o),l=Math.cos(o);n=[n[0]*l-n[1]*s,n[0]*s+n[1]*l]}var c=[a?n[0]:le(r,n[0],this.transform.zoom),a?n[1]:le(r,n[1],this.transform.zoom),0],u=new Float32Array(16);return t.translate(u,e,c),u},rn.prototype.saveTileTexture=function(t){var e=this._tileTextures[t.size[0]];e?e.push(t):this._tileTextures[t.size[0]]=[t]},rn.prototype.getTileTexture=function(t){var e=this._tileTextures[t];return e&&e.length>0?e.pop():null},rn.prototype.isPatternMissing=function(t){if(!t)return!1;var e=this.imageManager.getPattern(t.from),r=this.imageManager.getPattern(t.to);return!e||!r},rn.prototype.useProgram=function(t,e){void 0===e&&(e=this.emptyProgramConfiguration),this.cache=this.cache||{};var r=\"\"+t+(e.cacheKey||\"\")+(this._showOverdrawInspector?\"/overdraw\":\"\");return this.cache[r]||(this.cache[r]=new hr(this.context,cr[t],e,Nr[t],this._showOverdrawInspector)),this.cache[r]},rn.prototype.setCustomLayerDefaults=function(){this.context.unbindVAO(),this.context.cullFace.setDefault(),this.context.activeTexture.setDefault(),this.context.pixelStoreUnpack.setDefault(),this.context.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.context.pixelStoreUnpackFlipY.setDefault()},rn.prototype.setBaseState=function(){var t=this.context.gl;this.context.cullFace.set(!1),this.context.viewport.set([0,0,this.width,this.height]),this.context.blendEquation.set(t.FUNC_ADD)};var sn=function(e,r,n){this.tileSize=512,this.maxValidLatitude=85.051129,this._renderWorldCopies=void 0===n||n,this._minZoom=e||0,this._maxZoom=r||22,this.setMaxBounds(),this.width=0,this.height=0,this._center=new t.LngLat(0,0),this.zoom=0,this.angle=0,this._fov=.6435011087932844,this._pitch=0,this._unmodified=!0,this._posMatrixCache={},this._alignedPosMatrixCache={}},ln={minZoom:{configurable:!0},maxZoom:{configurable:!0},renderWorldCopies:{configurable:!0},worldSize:{configurable:!0},centerPoint:{configurable:!0},size:{configurable:!0},bearing:{configurable:!0},pitch:{configurable:!0},fov:{configurable:!0},zoom:{configurable:!0},center:{configurable:!0},unmodified:{configurable:!0},point:{configurable:!0}};sn.prototype.clone=function(){var t=new sn(this._minZoom,this._maxZoom,this._renderWorldCopies);return t.tileSize=this.tileSize,t.latRange=this.latRange,t.width=this.width,t.height=this.height,t._center=this._center,t.zoom=this.zoom,t.angle=this.angle,t._fov=this._fov,t._pitch=this._pitch,t._unmodified=this._unmodified,t._calcMatrices(),t},ln.minZoom.get=function(){return this._minZoom},ln.minZoom.set=function(t){this._minZoom!==t&&(this._minZoom=t,this.zoom=Math.max(this.zoom,t))},ln.maxZoom.get=function(){return this._maxZoom},ln.maxZoom.set=function(t){this._maxZoom!==t&&(this._maxZoom=t,this.zoom=Math.min(this.zoom,t))},ln.renderWorldCopies.get=function(){return this._renderWorldCopies},ln.renderWorldCopies.set=function(t){void 0===t?t=!0:null===t&&(t=!1),this._renderWorldCopies=t},ln.worldSize.get=function(){return this.tileSize*this.scale},ln.centerPoint.get=function(){return this.size._div(2)},ln.size.get=function(){return new t.Point(this.width,this.height)},ln.bearing.get=function(){return-this.angle/Math.PI*180},ln.bearing.set=function(e){var r=-t.wrap(e,-180,180)*Math.PI/180;this.angle!==r&&(this._unmodified=!1,this.angle=r,this._calcMatrices(),this.rotationMatrix=t.create$2(),t.rotate(this.rotationMatrix,this.rotationMatrix,this.angle))},ln.pitch.get=function(){return this._pitch/Math.PI*180},ln.pitch.set=function(e){var r=t.clamp(e,0,60)/180*Math.PI;this._pitch!==r&&(this._unmodified=!1,this._pitch=r,this._calcMatrices())},ln.fov.get=function(){return this._fov/Math.PI*180},ln.fov.set=function(t){t=Math.max(.01,Math.min(60,t)),this._fov!==t&&(this._unmodified=!1,this._fov=t/180*Math.PI,this._calcMatrices())},ln.zoom.get=function(){return this._zoom},ln.zoom.set=function(t){var e=Math.min(Math.max(t,this.minZoom),this.maxZoom);this._zoom!==e&&(this._unmodified=!1,this._zoom=e,this.scale=this.zoomScale(e),this.tileZoom=Math.floor(e),this.zoomFraction=e-this.tileZoom,this._constrain(),this._calcMatrices())},ln.center.get=function(){return this._center},ln.center.set=function(t){t.lat===this._center.lat&&t.lng===this._center.lng||(this._unmodified=!1,this._center=t,this._constrain(),this._calcMatrices())},sn.prototype.coveringZoomLevel=function(t){return(t.roundZoom?Math.round:Math.floor)(this.zoom+this.scaleZoom(this.tileSize/t.tileSize))},sn.prototype.getVisibleUnwrappedCoordinates=function(e){var r=[new t.UnwrappedTileID(0,e)];if(this._renderWorldCopies)for(var n=this.pointCoordinate(new t.Point(0,0)),i=this.pointCoordinate(new t.Point(this.width,0)),a=this.pointCoordinate(new t.Point(this.width,this.height)),o=this.pointCoordinate(new t.Point(0,this.height)),s=Math.floor(Math.min(n.x,i.x,a.x,o.x)),l=Math.floor(Math.max(n.x,i.x,a.x,o.x)),c=s-1;c<=l+1;c++)0!==c&&r.push(new t.UnwrappedTileID(c,e));return r},sn.prototype.coveringTiles=function(e){var r=this.coveringZoomLevel(e),n=r;if(void 0!==e.minzoom&&r<e.minzoom)return[];void 0!==e.maxzoom&&r>e.maxzoom&&(r=e.maxzoom);var i=t.MercatorCoordinate.fromLngLat(this.center),a=Math.pow(2,r),o=new t.Point(a*i.x-.5,a*i.y-.5);return function(e,r,n,i){void 0===i&&(i=!0);var a=1<<e,o={};function s(r,s,l){var c,u,h,f;if(l>=0&&l<=a)for(c=r;c<s;c++)u=Math.floor(c/a),h=(c%a+a)%a,0!==u&&!0!==i||(f=new t.OverscaledTileID(n,u,e,h,l),o[f.key]=f)}var l=r.map(function(e){return new t.Point(e.x,e.y)._mult(a)});return on(l[0],l[1],l[2],0,a,s),on(l[2],l[3],l[0],0,a,s),Object.keys(o).map(function(t){return o[t]})}(r,[this.pointCoordinate(new t.Point(0,0)),this.pointCoordinate(new t.Point(this.width,0)),this.pointCoordinate(new t.Point(this.width,this.height)),this.pointCoordinate(new t.Point(0,this.height))],e.reparseOverscaled?n:r,this._renderWorldCopies).sort(function(t,e){return o.dist(t.canonical)-o.dist(e.canonical)})},sn.prototype.resize=function(t,e){this.width=t,this.height=e,this.pixelsToGLUnits=[2/t,-2/e],this._constrain(),this._calcMatrices()},ln.unmodified.get=function(){return this._unmodified},sn.prototype.zoomScale=function(t){return Math.pow(2,t)},sn.prototype.scaleZoom=function(t){return Math.log(t)/Math.LN2},sn.prototype.project=function(e){var r=t.clamp(e.lat,-this.maxValidLatitude,this.maxValidLatitude);return new t.Point(t.mercatorXfromLng(e.lng)*this.worldSize,t.mercatorYfromLat(r)*this.worldSize)},sn.prototype.unproject=function(e){return new t.MercatorCoordinate(e.x/this.worldSize,e.y/this.worldSize).toLngLat()},ln.point.get=function(){return this.project(this.center)},sn.prototype.setLocationAtPoint=function(e,r){var n=this.pointCoordinate(r),i=this.pointCoordinate(this.centerPoint),a=this.locationCoordinate(e),o=new t.MercatorCoordinate(a.x-(n.x-i.x),a.y-(n.y-i.y));this.center=this.coordinateLocation(o),this._renderWorldCopies&&(this.center=this.center.wrap())},sn.prototype.locationPoint=function(t){return this.coordinatePoint(this.locationCoordinate(t))},sn.prototype.pointLocation=function(t){return this.coordinateLocation(this.pointCoordinate(t))},sn.prototype.locationCoordinate=function(e){return t.MercatorCoordinate.fromLngLat(e)},sn.prototype.coordinateLocation=function(t){return t.toLngLat()},sn.prototype.pointCoordinate=function(e){var r=[e.x,e.y,0,1],n=[e.x,e.y,1,1];t.transformMat4(r,r,this.pixelMatrixInverse),t.transformMat4(n,n,this.pixelMatrixInverse);var i=r[3],a=n[3],o=r[0]/i,s=n[0]/a,l=r[1]/i,c=n[1]/a,u=r[2]/i,h=n[2]/a,f=u===h?0:(0-u)/(h-u);return new t.MercatorCoordinate(t.number(o,s,f)/this.worldSize,t.number(l,c,f)/this.worldSize)},sn.prototype.coordinatePoint=function(e){var r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix),new t.Point(r[0]/r[3],r[1]/r[3])},sn.prototype.getBounds=function(){return(new t.LngLatBounds).extend(this.pointLocation(new t.Point(0,0))).extend(this.pointLocation(new t.Point(this.width,0))).extend(this.pointLocation(new t.Point(this.width,this.height))).extend(this.pointLocation(new t.Point(0,this.height)))},sn.prototype.getMaxBounds=function(){return this.latRange&&2===this.latRange.length&&this.lngRange&&2===this.lngRange.length?new t.LngLatBounds([this.lngRange[0],this.latRange[0]],[this.lngRange[1],this.latRange[1]]):null},sn.prototype.setMaxBounds=function(t){t?(this.lngRange=[t.getWest(),t.getEast()],this.latRange=[t.getSouth(),t.getNorth()],this._constrain()):(this.lngRange=null,this.latRange=[-this.maxValidLatitude,this.maxValidLatitude])},sn.prototype.calculatePosMatrix=function(e,r){void 0===r&&(r=!1);var n=e.key,i=r?this._alignedPosMatrixCache:this._posMatrixCache;if(i[n])return i[n];var a=e.canonical,o=this.worldSize/this.zoomScale(a.z),s=a.x+Math.pow(2,a.z)*e.wrap,l=t.identity(new Float64Array(16));return t.translate(l,l,[s*o,a.y*o,0]),t.scale(l,l,[o/t.EXTENT,o/t.EXTENT,1]),t.multiply(l,r?this.alignedProjMatrix:this.projMatrix,l),i[n]=new Float32Array(l),i[n]},sn.prototype.customLayerMatrix=function(){return this.mercatorMatrix.slice()},sn.prototype._constrain=function(){if(this.center&&this.width&&this.height&&!this._constraining){this._constraining=!0;var e,r,n,i,a=-90,o=90,s=-180,l=180,c=this.size,u=this._unmodified;if(this.latRange){var h=this.latRange;a=t.mercatorYfromLat(h[1])*this.worldSize,e=(o=t.mercatorYfromLat(h[0])*this.worldSize)-a<c.y?c.y/(o-a):0}if(this.lngRange){var f=this.lngRange;s=t.mercatorXfromLng(f[0])*this.worldSize,r=(l=t.mercatorXfromLng(f[1])*this.worldSize)-s<c.x?c.x/(l-s):0}var p=this.point,d=Math.max(r||0,e||0);if(d)return this.center=this.unproject(new t.Point(r?(l+s)/2:p.x,e?(o+a)/2:p.y)),this.zoom+=this.scaleZoom(d),this._unmodified=u,void(this._constraining=!1);if(this.latRange){var g=p.y,v=c.y/2;g-v<a&&(i=a+v),g+v>o&&(i=o-v)}if(this.lngRange){var m=p.x,y=c.x/2;m-y<s&&(n=s+y),m+y>l&&(n=l-y)}void 0===n&&void 0===i||(this.center=this.unproject(new t.Point(void 0!==n?n:p.x,void 0!==i?i:p.y))),this._unmodified=u,this._constraining=!1}},sn.prototype._calcMatrices=function(){if(this.height){this.cameraToCenterDistance=.5/Math.tan(this._fov/2)*this.height;var e=this._fov/2,r=Math.PI/2+this._pitch,n=Math.sin(e)*this.cameraToCenterDistance/Math.sin(Math.PI-r-e),i=this.point,a=i.x,o=i.y,s=1.01*(Math.cos(Math.PI/2-this._pitch)*n+this.cameraToCenterDistance),l=new Float64Array(16);t.perspective(l,this._fov,this.width/this.height,1,s),t.scale(l,l,[1,-1,1]),t.translate(l,l,[0,0,-this.cameraToCenterDistance]),t.rotateX(l,l,this._pitch),t.rotateZ(l,l,this.angle),t.translate(l,l,[-a,-o,0]),this.mercatorMatrix=t.scale([],l,[this.worldSize,this.worldSize,this.worldSize]),t.scale(l,l,[1,1,t.mercatorZfromAltitude(1,this.center.lat)*this.worldSize,1]),this.projMatrix=l;var c=this.width%2/2,u=this.height%2/2,h=Math.cos(this.angle),f=Math.sin(this.angle),p=a-Math.round(a)+h*c+f*u,d=o-Math.round(o)+h*u+f*c,g=new Float64Array(l);if(t.translate(g,g,[p>.5?p-1:p,d>.5?d-1:d,0]),this.alignedProjMatrix=g,l=t.create(),t.scale(l,l,[this.width/2,-this.height/2,1]),t.translate(l,l,[1,-1,0]),this.labelPlaneMatrix=l,l=t.create(),t.scale(l,l,[1,-1,1]),t.translate(l,l,[-1,-1,0]),t.scale(l,l,[2/this.width,2/this.height,1]),this.glCoordMatrix=l,this.pixelMatrix=t.multiply(new Float64Array(16),this.labelPlaneMatrix,this.projMatrix),!(l=t.invert(new Float64Array(16),this.pixelMatrix)))throw new Error(\"failed to invert matrix\");this.pixelMatrixInverse=l,this._posMatrixCache={},this._alignedPosMatrixCache={}}},sn.prototype.maxPitchScaleFactor=function(){if(!this.pixelMatrixInverse)return 1;var e=this.pointCoordinate(new t.Point(0,0)),r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix)[3]/this.cameraToCenterDistance},sn.prototype.getCameraPoint=function(){var e=this._pitch,r=Math.tan(e)*(this.cameraToCenterDistance||1);return this.centerPoint.add(new t.Point(0,r))},sn.prototype.getCameraQueryGeometry=function(e){var r=this.getCameraPoint();if(1===e.length)return[e[0],r];for(var n=r.x,i=r.y,a=r.x,o=r.y,s=0,l=e;s<l.length;s+=1){var c=l[s];n=Math.min(n,c.x),i=Math.min(i,c.y),a=Math.max(a,c.x),o=Math.max(o,c.y)}return[new t.Point(n,i),new t.Point(a,i),new t.Point(a,o),new t.Point(n,o),new t.Point(n,i)]},Object.defineProperties(sn.prototype,ln);var cn=function(){var e,r,n,i;t.bindAll([\"_onHashChange\",\"_updateHash\"],this),this._updateHash=(e=this._updateHashUnthrottled.bind(this),300,r=!1,n=null,i=function(){n=null,r&&(e(),n=setTimeout(i,300),r=!1)},function(){return r=!0,n||i(),n})};cn.prototype.addTo=function(e){return this._map=e,t.window.addEventListener(\"hashchange\",this._onHashChange,!1),this._map.on(\"moveend\",this._updateHash),this},cn.prototype.remove=function(){return t.window.removeEventListener(\"hashchange\",this._onHashChange,!1),this._map.off(\"moveend\",this._updateHash),clearTimeout(this._updateHash()),delete this._map,this},cn.prototype.getHashString=function(t){var e=this._map.getCenter(),r=Math.round(100*this._map.getZoom())/100,n=Math.ceil((r*Math.LN2+Math.log(512/360/.5))/Math.LN10),i=Math.pow(10,n),a=Math.round(e.lng*i)/i,o=Math.round(e.lat*i)/i,s=this._map.getBearing(),l=this._map.getPitch(),c=\"\";return c+=t?\"#/\"+a+\"/\"+o+\"/\"+r:\"#\"+r+\"/\"+o+\"/\"+a,(s||l)&&(c+=\"/\"+Math.round(10*s)/10),l&&(c+=\"/\"+Math.round(l)),c},cn.prototype._onHashChange=function(){var e=t.window.location.hash.replace(\"#\",\"\").split(\"/\");return e.length>=3&&(this._map.jumpTo({center:[+e[2],+e[1]],zoom:+e[0],bearing:+(e[3]||0),pitch:+(e[4]||0)}),!0)},cn.prototype._updateHashUnthrottled=function(){var e=this.getHashString();try{t.window.history.replaceState(t.window.history.state,\"\",e)}catch(t){}};var un=function(e){function n(n,i,a,o){void 0===o&&(o={});var s=r.mousePos(i.getCanvasContainer(),a),l=i.unproject(s);e.call(this,n,t.extend({point:s,lngLat:l,originalEvent:a},o)),this._defaultPrevented=!1,this.target=i}e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),hn=function(e){function n(n,i,a){var o=r.touchPos(i.getCanvasContainer(),a),s=o.map(function(t){return i.unproject(t)}),l=o.reduce(function(t,e,r,n){return t.add(e.div(n.length))},new t.Point(0,0)),c=i.unproject(l);e.call(this,n,{points:o,point:l,lngLats:s,lngLat:c,originalEvent:a}),this._defaultPrevented=!1}e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),fn=function(t){function e(e,r,n){t.call(this,e,{originalEvent:n}),this._defaultPrevented=!1}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={defaultPrevented:{configurable:!0}};return e.prototype.preventDefault=function(){this._defaultPrevented=!0},r.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(e.prototype,r),e}(t.Event),pn=function(e){this._map=e,this._el=e.getCanvasContainer(),this._delta=0,this._defaultZoomRate=.01,this._wheelZoomRate=1/450,t.bindAll([\"_onWheel\",\"_onTimeout\",\"_onScrollFrame\",\"_onScrollFinished\"],this)};pn.prototype.setZoomRate=function(t){this._defaultZoomRate=t},pn.prototype.setWheelZoomRate=function(t){this._wheelZoomRate=t},pn.prototype.isEnabled=function(){return!!this._enabled},pn.prototype.isActive=function(){return!!this._active},pn.prototype.isZooming=function(){return!!this._zooming},pn.prototype.enable=function(t){this.isEnabled()||(this._enabled=!0,this._aroundCenter=t&&\"center\"===t.around)},pn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},pn.prototype.onWheel=function(e){if(this.isEnabled()){var r=e.deltaMode===t.window.WheelEvent.DOM_DELTA_LINE?40*e.deltaY:e.deltaY,n=t.browser.now(),i=n-(this._lastWheelEventTime||0);this._lastWheelEventTime=n,0!==r&&r%4.000244140625==0?this._type=\"wheel\":0!==r&&Math.abs(r)<4?this._type=\"trackpad\":i>400?(this._type=null,this._lastValue=r,this._timeout=setTimeout(this._onTimeout,40,e)):this._type||(this._type=Math.abs(i*r)<200?\"trackpad\":\"wheel\",this._timeout&&(clearTimeout(this._timeout),this._timeout=null,r+=this._lastValue)),e.shiftKey&&r&&(r/=4),this._type&&(this._lastWheelEvent=e,this._delta-=r,this.isActive()||this._start(e)),e.preventDefault()}},pn.prototype._onTimeout=function(t){this._type=\"wheel\",this._delta-=this._lastValue,this.isActive()||this._start(t)},pn.prototype._start=function(e){if(this._delta){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),this._active=!0,this.isZooming()||(this._zooming=!0,this._map.fire(new t.Event(\"movestart\",{originalEvent:e})),this._map.fire(new t.Event(\"zoomstart\",{originalEvent:e}))),this._finishTimeout&&clearTimeout(this._finishTimeout);var n=r.mousePos(this._el,e);this._around=t.LngLat.convert(this._aroundCenter?this._map.getCenter():this._map.unproject(n)),this._aroundPoint=this._map.transform.locationPoint(this._around),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onScrollFrame))}},pn.prototype._onScrollFrame=function(){var e=this;if(this._frameId=null,this.isActive()){var r=this._map.transform;if(0!==this._delta){var n=\"wheel\"===this._type&&Math.abs(this._delta)>4.000244140625?this._wheelZoomRate:this._defaultZoomRate,i=2/(1+Math.exp(-Math.abs(this._delta*n)));this._delta<0&&0!==i&&(i=1/i);var a=\"number\"==typeof this._targetZoom?r.zoomScale(this._targetZoom):r.scale;this._targetZoom=Math.min(r.maxZoom,Math.max(r.minZoom,r.scaleZoom(a*i))),\"wheel\"===this._type&&(this._startZoom=r.zoom,this._easing=this._smoothOutEasing(200)),this._delta=0}var o=\"number\"==typeof this._targetZoom?this._targetZoom:r.zoom,s=this._startZoom,l=this._easing,c=!1;if(\"wheel\"===this._type&&s&&l){var u=Math.min((t.browser.now()-this._lastWheelEventTime)/200,1),h=l(u);r.zoom=t.number(s,o,h),u<1?this._frameId||(this._frameId=this._map._requestRenderFrame(this._onScrollFrame)):c=!0}else r.zoom=o,c=!0;r.setLocationAtPoint(this._around,this._aroundPoint),this._map.fire(new t.Event(\"move\",{originalEvent:this._lastWheelEvent})),this._map.fire(new t.Event(\"zoom\",{originalEvent:this._lastWheelEvent})),c&&(this._active=!1,this._finishTimeout=setTimeout(function(){e._zooming=!1,e._map.fire(new t.Event(\"zoomend\",{originalEvent:e._lastWheelEvent})),e._map.fire(new t.Event(\"moveend\",{originalEvent:e._lastWheelEvent})),delete e._targetZoom},200))}},pn.prototype._smoothOutEasing=function(e){var r=t.ease;if(this._prevEase){var n=this._prevEase,i=(t.browser.now()-n.start)/n.duration,a=n.easing(i+.01)-n.easing(i),o=.27/Math.sqrt(a*a+1e-4)*.01,s=Math.sqrt(.0729-o*o);r=t.bezier(o,s,.25,1)}return this._prevEase={start:t.browser.now(),duration:e,easing:r},r};var dn=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._container=e.getContainer(),this._clickTolerance=r.clickTolerance||1,t.bindAll([\"_onMouseMove\",\"_onMouseUp\",\"_onKeyDown\"],this)};dn.prototype.isEnabled=function(){return!!this._enabled},dn.prototype.isActive=function(){return!!this._active},dn.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},dn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},dn.prototype.onMouseDown=function(e){this.isEnabled()&&e.shiftKey&&0===e.button&&(t.window.document.addEventListener(\"mousemove\",this._onMouseMove,!1),t.window.document.addEventListener(\"keydown\",this._onKeyDown,!1),t.window.document.addEventListener(\"mouseup\",this._onMouseUp,!1),r.disableDrag(),this._startPos=this._lastPos=r.mousePos(this._el,e),this._active=!0)},dn.prototype._onMouseMove=function(t){var e=r.mousePos(this._el,t);if(!(this._lastPos.equals(e)||!this._box&&e.dist(this._startPos)<this._clickTolerance)){var n=this._startPos;this._lastPos=e,this._box||(this._box=r.create(\"div\",\"mapboxgl-boxzoom\",this._container),this._container.classList.add(\"mapboxgl-crosshair\"),this._fireEvent(\"boxzoomstart\",t));var i=Math.min(n.x,e.x),a=Math.max(n.x,e.x),o=Math.min(n.y,e.y),s=Math.max(n.y,e.y);r.setTransform(this._box,\"translate(\"+i+\"px,\"+o+\"px)\"),this._box.style.width=a-i+\"px\",this._box.style.height=s-o+\"px\"}},dn.prototype._onMouseUp=function(e){if(0===e.button){var n=this._startPos,i=r.mousePos(this._el,e);this._finish(),r.suppressClick(),n.x===i.x&&n.y===i.y?this._fireEvent(\"boxzoomcancel\",e):this._map.fitScreenCoordinates(n,i,this._map.getBearing(),{linear:!0}).fire(new t.Event(\"boxzoomend\",{originalEvent:e}))}},dn.prototype._onKeyDown=function(t){27===t.keyCode&&(this._finish(),this._fireEvent(\"boxzoomcancel\",t))},dn.prototype._finish=function(){this._active=!1,t.window.document.removeEventListener(\"mousemove\",this._onMouseMove,!1),t.window.document.removeEventListener(\"keydown\",this._onKeyDown,!1),t.window.document.removeEventListener(\"mouseup\",this._onMouseUp,!1),this._container.classList.remove(\"mapboxgl-crosshair\"),this._box&&(r.remove(this._box),this._box=null),r.enableDrag(),delete this._startPos,delete this._lastPos},dn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,{originalEvent:r}))};var gn=t.bezier(0,0,.25,1),vn=function(e,r){this._map=e,this._el=r.element||e.getCanvasContainer(),this._state=\"disabled\",this._button=r.button||\"right\",this._bearingSnap=r.bearingSnap||0,this._pitchWithRotate=!1!==r.pitchWithRotate,t.bindAll([\"onMouseDown\",\"_onMouseMove\",\"_onMouseUp\",\"_onBlur\",\"_onDragFrame\"],this)};vn.prototype.isEnabled=function(){return\"disabled\"!==this._state},vn.prototype.isActive=function(){return\"active\"===this._state},vn.prototype.enable=function(){this.isEnabled()||(this._state=\"enabled\")},vn.prototype.disable=function(){if(this.isEnabled())switch(this._state){case\"active\":this._state=\"disabled\",this._unbind(),this._deactivate(),this._fireEvent(\"rotateend\"),this._pitchWithRotate&&this._fireEvent(\"pitchend\"),this._fireEvent(\"moveend\");break;case\"pending\":this._state=\"disabled\",this._unbind();break;default:this._state=\"disabled\"}},vn.prototype.onMouseDown=function(e){if(\"enabled\"===this._state){if(\"right\"===this._button){if(this._eventButton=r.mouseButton(e),this._eventButton!==(e.ctrlKey?0:2))return}else{if(e.ctrlKey||0!==r.mouseButton(e))return;this._eventButton=0}r.disableDrag(),t.window.document.addEventListener(\"mousemove\",this._onMouseMove,{capture:!0}),t.window.document.addEventListener(\"mouseup\",this._onMouseUp),t.window.addEventListener(\"blur\",this._onBlur),this._state=\"pending\",this._inertia=[[t.browser.now(),this._map.getBearing()]],this._startPos=this._lastPos=r.mousePos(this._el,e),this._center=this._map.transform.centerPoint,e.preventDefault()}},vn.prototype._onMouseMove=function(t){var e=r.mousePos(this._el,t);this._lastPos.equals(e)||(this._lastMoveEvent=t,this._lastPos=e,\"pending\"===this._state&&(this._state=\"active\",this._fireEvent(\"rotatestart\",t),this._fireEvent(\"movestart\",t),this._pitchWithRotate&&this._fireEvent(\"pitchstart\",t)),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onDragFrame)))},vn.prototype._onDragFrame=function(){this._frameId=null;var e=this._lastMoveEvent;if(e){var r=this._map.transform,n=this._startPos,i=this._lastPos,a=.8*(n.x-i.x),o=-.5*(n.y-i.y),s=r.bearing-a,l=r.pitch-o,c=this._inertia,u=c[c.length-1];this._drainInertiaBuffer(),c.push([t.browser.now(),this._map._normalizeBearing(s,u[1])]),r.bearing=s,this._pitchWithRotate&&(this._fireEvent(\"pitch\",e),r.pitch=l),this._fireEvent(\"rotate\",e),this._fireEvent(\"move\",e),delete this._lastMoveEvent,this._startPos=this._lastPos}},vn.prototype._onMouseUp=function(t){if(r.mouseButton(t)===this._eventButton)switch(this._state){case\"active\":this._state=\"enabled\",r.suppressClick(),this._unbind(),this._deactivate(),this._inertialRotate(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},vn.prototype._onBlur=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._fireEvent(\"rotateend\",t),this._pitchWithRotate&&this._fireEvent(\"pitchend\",t),this._fireEvent(\"moveend\",t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},vn.prototype._unbind=function(){t.window.document.removeEventListener(\"mousemove\",this._onMouseMove,{capture:!0}),t.window.document.removeEventListener(\"mouseup\",this._onMouseUp),t.window.removeEventListener(\"blur\",this._onBlur),r.enableDrag()},vn.prototype._deactivate=function(){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._lastMoveEvent,delete this._startPos,delete this._lastPos},vn.prototype._inertialRotate=function(t){var e=this;this._fireEvent(\"rotateend\",t),this._drainInertiaBuffer();var r=this._map,n=r.getBearing(),i=this._inertia,a=function(){Math.abs(n)<e._bearingSnap?r.resetNorth({noMoveStart:!0},{originalEvent:t}):e._fireEvent(\"moveend\",t),e._pitchWithRotate&&e._fireEvent(\"pitchend\",t)};if(i.length<2)a();else{var o=i[0],s=i[i.length-1],l=i[i.length-2],c=r._normalizeBearing(n,l[1]),u=s[1]-o[1],h=u<0?-1:1,f=(s[0]-o[0])/1e3;if(0!==u&&0!==f){var p=Math.abs(u*(.25/f));p>180&&(p=180);var d=p/180;c+=h*p*(d/2),Math.abs(r._normalizeBearing(c,0))<this._bearingSnap&&(c=r._normalizeBearing(0,c)),r.rotateTo(c,{duration:1e3*d,easing:gn,noMoveStart:!0},{originalEvent:t})}else a()}},vn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},vn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>0&&r-e[0][0]>160;)e.shift()};var mn=t.bezier(0,0,.3,1),yn=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._state=\"disabled\",this._clickTolerance=r.clickTolerance||1,t.bindAll([\"_onMove\",\"_onMouseUp\",\"_onTouchEnd\",\"_onBlur\",\"_onDragFrame\"],this)};yn.prototype.isEnabled=function(){return\"disabled\"!==this._state},yn.prototype.isActive=function(){return\"active\"===this._state},yn.prototype.enable=function(){this.isEnabled()||(this._el.classList.add(\"mapboxgl-touch-drag-pan\"),this._state=\"enabled\")},yn.prototype.disable=function(){if(this.isEnabled())switch(this._el.classList.remove(\"mapboxgl-touch-drag-pan\"),this._state){case\"active\":this._state=\"disabled\",this._unbind(),this._deactivate(),this._fireEvent(\"dragend\"),this._fireEvent(\"moveend\");break;case\"pending\":this._state=\"disabled\",this._unbind();break;default:this._state=\"disabled\"}},yn.prototype.onMouseDown=function(e){\"enabled\"===this._state&&(e.ctrlKey||0!==r.mouseButton(e)||(r.addEventListener(t.window.document,\"mousemove\",this._onMove,{capture:!0}),r.addEventListener(t.window.document,\"mouseup\",this._onMouseUp),this._start(e)))},yn.prototype.onTouchStart=function(e){\"enabled\"===this._state&&(e.touches.length>1||(r.addEventListener(t.window.document,\"touchmove\",this._onMove,{capture:!0,passive:!1}),r.addEventListener(t.window.document,\"touchend\",this._onTouchEnd),this._start(e)))},yn.prototype._start=function(e){t.window.addEventListener(\"blur\",this._onBlur),this._state=\"pending\",this._startPos=this._mouseDownPos=this._lastPos=r.mousePos(this._el,e),this._inertia=[[t.browser.now(),this._startPos]]},yn.prototype._onMove=function(e){e.preventDefault();var n=r.mousePos(this._el,e);this._lastPos.equals(n)||\"pending\"===this._state&&n.dist(this._mouseDownPos)<this._clickTolerance||(this._lastMoveEvent=e,this._lastPos=n,this._drainInertiaBuffer(),this._inertia.push([t.browser.now(),this._lastPos]),\"pending\"===this._state&&(this._state=\"active\",this._fireEvent(\"dragstart\",e),this._fireEvent(\"movestart\",e)),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onDragFrame)))},yn.prototype._onDragFrame=function(){this._frameId=null;var t=this._lastMoveEvent;if(t){var e=this._map.transform;e.setLocationAtPoint(e.pointLocation(this._startPos),this._lastPos),this._fireEvent(\"drag\",t),this._fireEvent(\"move\",t),this._startPos=this._lastPos,delete this._lastMoveEvent}},yn.prototype._onMouseUp=function(t){if(0===r.mouseButton(t))switch(this._state){case\"active\":this._state=\"enabled\",r.suppressClick(),this._unbind(),this._deactivate(),this._inertialPan(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},yn.prototype._onTouchEnd=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._inertialPan(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},yn.prototype._onBlur=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._fireEvent(\"dragend\",t),this._fireEvent(\"moveend\",t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},yn.prototype._unbind=function(){r.removeEventListener(t.window.document,\"touchmove\",this._onMove,{capture:!0,passive:!1}),r.removeEventListener(t.window.document,\"touchend\",this._onTouchEnd),r.removeEventListener(t.window.document,\"mousemove\",this._onMove,{capture:!0}),r.removeEventListener(t.window.document,\"mouseup\",this._onMouseUp),r.removeEventListener(t.window,\"blur\",this._onBlur)},yn.prototype._deactivate=function(){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._lastMoveEvent,delete this._startPos,delete this._mouseDownPos,delete this._lastPos},yn.prototype._inertialPan=function(t){this._fireEvent(\"dragend\",t),this._drainInertiaBuffer();var e=this._inertia;if(e.length<2)this._fireEvent(\"moveend\",t);else{var r=e[e.length-1],n=e[0],i=r[1].sub(n[1]),a=(r[0]-n[0])/1e3;if(0===a||r[1].equals(n[1]))this._fireEvent(\"moveend\",t);else{var o=i.mult(.3/a),s=o.mag();s>1400&&(s=1400,o._unit()._mult(s));var l=s/750,c=o.mult(-l/2);this._map.panBy(c,{duration:1e3*l,easing:mn,noMoveStart:!0},{originalEvent:t})}}},yn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},yn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>0&&r-e[0][0]>160;)e.shift()};var xn=function(e){this._map=e,this._el=e.getCanvasContainer(),t.bindAll([\"_onKeyDown\"],this)};function bn(t){return t*(2-t)}xn.prototype.isEnabled=function(){return!!this._enabled},xn.prototype.enable=function(){this.isEnabled()||(this._el.addEventListener(\"keydown\",this._onKeyDown,!1),this._enabled=!0)},xn.prototype.disable=function(){this.isEnabled()&&(this._el.removeEventListener(\"keydown\",this._onKeyDown),this._enabled=!1)},xn.prototype._onKeyDown=function(t){if(!(t.altKey||t.ctrlKey||t.metaKey)){var e=0,r=0,n=0,i=0,a=0;switch(t.keyCode){case 61:case 107:case 171:case 187:e=1;break;case 189:case 109:case 173:e=-1;break;case 37:t.shiftKey?r=-1:(t.preventDefault(),i=-1);break;case 39:t.shiftKey?r=1:(t.preventDefault(),i=1);break;case 38:t.shiftKey?n=1:(t.preventDefault(),a=-1);break;case 40:t.shiftKey?n=-1:(a=1,t.preventDefault());break;default:return}var o=this._map,s=o.getZoom(),l={duration:300,delayEndEvents:500,easing:bn,zoom:e?Math.round(s)+e*(t.shiftKey?2:1):s,bearing:o.getBearing()+15*r,pitch:o.getPitch()+10*n,offset:[100*-i,100*-a],center:o.getCenter()};o.easeTo(l,{originalEvent:t})}};var _n=function(e){this._map=e,t.bindAll([\"_onDblClick\",\"_onZoomEnd\"],this)};_n.prototype.isEnabled=function(){return!!this._enabled},_n.prototype.isActive=function(){return!!this._active},_n.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},_n.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},_n.prototype.onTouchStart=function(t){var e=this;if(this.isEnabled()&&!(t.points.length>1))if(this._tapped){var r=t.points[0],n=this._tappedPoint;if(n&&n.dist(r)<=30){t.originalEvent.preventDefault();var i=function(){e._tapped&&e._zoom(t),e._map.off(\"touchcancel\",a),e._resetTapped()},a=function(){e._map.off(\"touchend\",i),e._resetTapped()};this._map.once(\"touchend\",i),this._map.once(\"touchcancel\",a)}else this._resetTapped()}else this._tappedPoint=t.points[0],this._tapped=setTimeout(function(){e._tapped=null,e._tappedPoint=null},300)},_n.prototype._resetTapped=function(){clearTimeout(this._tapped),this._tapped=null,this._tappedPoint=null},_n.prototype.onDblClick=function(t){this.isEnabled()&&(t.originalEvent.preventDefault(),this._zoom(t))},_n.prototype._zoom=function(t){this._active=!0,this._map.on(\"zoomend\",this._onZoomEnd),this._map.zoomTo(this._map.getZoom()+(t.originalEvent.shiftKey?-1:1),{around:t.lngLat},t)},_n.prototype._onZoomEnd=function(){this._active=!1,this._map.off(\"zoomend\",this._onZoomEnd)};var wn=t.bezier(0,0,.15,1),kn=function(e){this._map=e,this._el=e.getCanvasContainer(),t.bindAll([\"_onMove\",\"_onEnd\",\"_onTouchFrame\"],this)};kn.prototype.isEnabled=function(){return!!this._enabled},kn.prototype.enable=function(t){this.isEnabled()||(this._el.classList.add(\"mapboxgl-touch-zoom-rotate\"),this._enabled=!0,this._aroundCenter=!!t&&\"center\"===t.around)},kn.prototype.disable=function(){this.isEnabled()&&(this._el.classList.remove(\"mapboxgl-touch-zoom-rotate\"),this._enabled=!1)},kn.prototype.disableRotation=function(){this._rotationDisabled=!0},kn.prototype.enableRotation=function(){this._rotationDisabled=!1},kn.prototype.onStart=function(e){if(this.isEnabled()&&2===e.touches.length){var n=r.mousePos(this._el,e.touches[0]),i=r.mousePos(this._el,e.touches[1]),a=n.add(i).div(2);this._startVec=n.sub(i),this._startAround=this._map.transform.pointLocation(a),this._gestureIntent=void 0,this._inertia=[],r.addEventListener(t.window.document,\"touchmove\",this._onMove,{passive:!1}),r.addEventListener(t.window.document,\"touchend\",this._onEnd)}},kn.prototype._getTouchEventData=function(t){var e=r.mousePos(this._el,t.touches[0]),n=r.mousePos(this._el,t.touches[1]),i=e.sub(n);return{vec:i,center:e.add(n).div(2),scale:i.mag()/this._startVec.mag(),bearing:this._rotationDisabled?0:180*i.angleWith(this._startVec)/Math.PI}},kn.prototype._onMove=function(e){if(2===e.touches.length){var r=this._getTouchEventData(e),n=r.vec,i=r.scale,a=r.bearing;if(!this._gestureIntent){var o=this._rotationDisabled&&1!==i||Math.abs(1-i)>.15;Math.abs(a)>10?this._gestureIntent=\"rotate\":o&&(this._gestureIntent=\"zoom\"),this._gestureIntent&&(this._map.fire(new t.Event(this._gestureIntent+\"start\",{originalEvent:e})),this._map.fire(new t.Event(\"movestart\",{originalEvent:e})),this._startVec=n)}this._lastTouchEvent=e,this._frameId||(this._frameId=this._map._requestRenderFrame(this._onTouchFrame)),e.preventDefault()}},kn.prototype._onTouchFrame=function(){this._frameId=null;var e=this._gestureIntent;if(e){var r=this._map.transform;this._startScale||(this._startScale=r.scale,this._startBearing=r.bearing);var n=this._getTouchEventData(this._lastTouchEvent),i=n.center,a=n.bearing,o=n.scale,s=r.pointLocation(i),l=r.locationPoint(s);\"rotate\"===e&&(r.bearing=this._startBearing+a),r.zoom=r.scaleZoom(this._startScale*o),r.setLocationAtPoint(this._startAround,l),this._map.fire(new t.Event(e,{originalEvent:this._lastTouchEvent})),this._map.fire(new t.Event(\"move\",{originalEvent:this._lastTouchEvent})),this._drainInertiaBuffer(),this._inertia.push([t.browser.now(),o,i])}},kn.prototype._onEnd=function(e){r.removeEventListener(t.window.document,\"touchmove\",this._onMove,{passive:!1}),r.removeEventListener(t.window.document,\"touchend\",this._onEnd);var n=this._gestureIntent,i=this._startScale;if(this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._gestureIntent,delete this._startScale,delete this._startBearing,delete this._lastTouchEvent,n){this._map.fire(new t.Event(n+\"end\",{originalEvent:e})),this._drainInertiaBuffer();var a=this._inertia,o=this._map;if(a.length<2)o.snapToNorth({},{originalEvent:e});else{var s=a[a.length-1],l=a[0],c=o.transform.scaleZoom(i*s[1]),u=o.transform.scaleZoom(i*l[1]),h=c-u,f=(s[0]-l[0])/1e3,p=s[2];if(0!==f&&c!==u){var d=.15*h/f;Math.abs(d)>2.5&&(d=d>0?2.5:-2.5);var g=1e3*Math.abs(d/(12*.15)),v=c+d*g/2e3;v<0&&(v=0),o.easeTo({zoom:v,duration:g,easing:wn,around:this._aroundCenter?o.getCenter():o.unproject(p),noMoveStart:!0},{originalEvent:e})}else o.snapToNorth({},{originalEvent:e})}}},kn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>2&&r-e[0][0]>160;)e.shift()};var Tn={scrollZoom:pn,boxZoom:dn,dragRotate:vn,dragPan:yn,keyboard:xn,doubleClickZoom:_n,touchZoomRotate:kn},An=function(e){function r(r,n){e.call(this),this._moving=!1,this._zooming=!1,this.transform=r,this._bearingSnap=n.bearingSnap,t.bindAll([\"_renderFrameCallback\"],this)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getCenter=function(){return new t.LngLat(this.transform.center.lng,this.transform.center.lat)},r.prototype.setCenter=function(t,e){return this.jumpTo({center:t},e)},r.prototype.panBy=function(e,r,n){return e=t.Point.convert(e).mult(-1),this.panTo(this.transform.center,t.extend({offset:e},r),n)},r.prototype.panTo=function(e,r,n){return this.easeTo(t.extend({center:e},r),n)},r.prototype.getZoom=function(){return this.transform.zoom},r.prototype.setZoom=function(t,e){return this.jumpTo({zoom:t},e),this},r.prototype.zoomTo=function(e,r,n){return this.easeTo(t.extend({zoom:e},r),n)},r.prototype.zoomIn=function(t,e){return this.zoomTo(this.getZoom()+1,t,e),this},r.prototype.zoomOut=function(t,e){return this.zoomTo(this.getZoom()-1,t,e),this},r.prototype.getBearing=function(){return this.transform.bearing},r.prototype.setBearing=function(t,e){return this.jumpTo({bearing:t},e),this},r.prototype.rotateTo=function(e,r,n){return this.easeTo(t.extend({bearing:e},r),n)},r.prototype.resetNorth=function(e,r){return this.rotateTo(0,t.extend({duration:1e3},e),r),this},r.prototype.snapToNorth=function(t,e){return Math.abs(this.getBearing())<this._bearingSnap?this.resetNorth(t,e):this},r.prototype.getPitch=function(){return this.transform.pitch},r.prototype.setPitch=function(t,e){return this.jumpTo({pitch:t},e),this},r.prototype.cameraForBounds=function(e,r){return e=t.LngLatBounds.convert(e),this._cameraForBoxAndBearing(e.getNorthWest(),e.getSouthEast(),0,r)},r.prototype._cameraForBoxAndBearing=function(e,r,n,i){if(\"number\"==typeof(i=t.extend({padding:{top:0,bottom:0,right:0,left:0},offset:[0,0],maxZoom:this.transform.maxZoom},i)).padding){var a=i.padding;i.padding={top:a,bottom:a,right:a,left:a}}if(t.deepEqual(Object.keys(i.padding).sort(function(t,e){return t<e?-1:t>e?1:0}),[\"bottom\",\"left\",\"right\",\"top\"])){var o=this.transform,s=o.project(t.LngLat.convert(e)),l=o.project(t.LngLat.convert(r)),c=s.rotate(-n*Math.PI/180),u=l.rotate(-n*Math.PI/180),h=new t.Point(Math.max(c.x,u.x),Math.max(c.y,u.y)),f=new t.Point(Math.min(c.x,u.x),Math.min(c.y,u.y)),p=h.sub(f),d=(o.width-i.padding.left-i.padding.right)/p.x,g=(o.height-i.padding.top-i.padding.bottom)/p.y;if(!(g<0||d<0)){var v=Math.min(o.scaleZoom(o.scale*Math.min(d,g)),i.maxZoom),m=t.Point.convert(i.offset),y=(i.padding.left-i.padding.right)/2,x=(i.padding.top-i.padding.bottom)/2,b=new t.Point(m.x+y,m.y+x).mult(o.scale/o.zoomScale(v));return{center:o.unproject(s.add(l).div(2).sub(b)),zoom:v,bearing:n}}t.warnOnce(\"Map cannot fit within canvas with the given bounds, padding, and/or offset.\")}else t.warnOnce(\"options.padding must be a positive number, or an Object with keys 'bottom', 'left', 'right', 'top'\")},r.prototype.fitBounds=function(t,e,r){return this._fitInternal(this.cameraForBounds(t,e),e,r)},r.prototype.fitScreenCoordinates=function(e,r,n,i,a){return this._fitInternal(this._cameraForBoxAndBearing(this.transform.pointLocation(t.Point.convert(e)),this.transform.pointLocation(t.Point.convert(r)),n,i),i,a)},r.prototype._fitInternal=function(e,r,n){return e?(r=t.extend(e,r)).linear?this.easeTo(r,n):this.flyTo(r,n):this},r.prototype.jumpTo=function(e,r){this.stop();var n=this.transform,i=!1,a=!1,o=!1;return\"zoom\"in e&&n.zoom!==+e.zoom&&(i=!0,n.zoom=+e.zoom),void 0!==e.center&&(n.center=t.LngLat.convert(e.center)),\"bearing\"in e&&n.bearing!==+e.bearing&&(a=!0,n.bearing=+e.bearing),\"pitch\"in e&&n.pitch!==+e.pitch&&(o=!0,n.pitch=+e.pitch),this.fire(new t.Event(\"movestart\",r)).fire(new t.Event(\"move\",r)),i&&this.fire(new t.Event(\"zoomstart\",r)).fire(new t.Event(\"zoom\",r)).fire(new t.Event(\"zoomend\",r)),a&&this.fire(new t.Event(\"rotatestart\",r)).fire(new t.Event(\"rotate\",r)).fire(new t.Event(\"rotateend\",r)),o&&this.fire(new t.Event(\"pitchstart\",r)).fire(new t.Event(\"pitch\",r)).fire(new t.Event(\"pitchend\",r)),this.fire(new t.Event(\"moveend\",r))},r.prototype.easeTo=function(e,r){var n=this;this.stop(),!1===(e=t.extend({offset:[0,0],duration:500,easing:t.ease},e)).animate&&(e.duration=0);var i=this.transform,a=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=\"zoom\"in e?+e.zoom:a,c=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,u=\"pitch\"in e?+e.pitch:s,h=i.centerPoint.add(t.Point.convert(e.offset)),f=i.pointLocation(h),p=t.LngLat.convert(e.center||f);this._normalizeCenter(p);var d,g,v=i.project(f),m=i.project(p).sub(v),y=i.zoomScale(l-a);return e.around&&(d=t.LngLat.convert(e.around),g=i.locationPoint(d)),this._zooming=l!==a,this._rotating=o!==c,this._pitching=u!==s,this._prepareEase(r,e.noMoveStart),clearTimeout(this._easeEndTimeoutID),this._ease(function(e){if(n._zooming&&(i.zoom=t.number(a,l,e)),n._rotating&&(i.bearing=t.number(o,c,e)),n._pitching&&(i.pitch=t.number(s,u,e)),d)i.setLocationAtPoint(d,g);else{var f=i.zoomScale(i.zoom-a),p=l>a?Math.min(2,y):Math.max(.5,y),x=Math.pow(p,1-e),b=i.unproject(v.add(m.mult(e*x)).mult(f));i.setLocationAtPoint(i.renderWorldCopies?b.wrap():b,h)}n._fireMoveEvents(r)},function(){e.delayEndEvents?n._easeEndTimeoutID=setTimeout(function(){return n._afterEase(r)},e.delayEndEvents):n._afterEase(r)},e),this},r.prototype._prepareEase=function(e,r){this._moving=!0,r||this.fire(new t.Event(\"movestart\",e)),this._zooming&&this.fire(new t.Event(\"zoomstart\",e)),this._rotating&&this.fire(new t.Event(\"rotatestart\",e)),this._pitching&&this.fire(new t.Event(\"pitchstart\",e))},r.prototype._fireMoveEvents=function(e){this.fire(new t.Event(\"move\",e)),this._zooming&&this.fire(new t.Event(\"zoom\",e)),this._rotating&&this.fire(new t.Event(\"rotate\",e)),this._pitching&&this.fire(new t.Event(\"pitch\",e))},r.prototype._afterEase=function(e){var r=this._zooming,n=this._rotating,i=this._pitching;this._moving=!1,this._zooming=!1,this._rotating=!1,this._pitching=!1,r&&this.fire(new t.Event(\"zoomend\",e)),n&&this.fire(new t.Event(\"rotateend\",e)),i&&this.fire(new t.Event(\"pitchend\",e)),this.fire(new t.Event(\"moveend\",e))},r.prototype.flyTo=function(e,r){var n=this;this.stop(),e=t.extend({offset:[0,0],speed:1.2,curve:1.42,easing:t.ease},e);var i=this.transform,a=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=\"zoom\"in e?t.clamp(+e.zoom,i.minZoom,i.maxZoom):a,c=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,u=\"pitch\"in e?+e.pitch:s,h=i.zoomScale(l-a),f=i.centerPoint.add(t.Point.convert(e.offset)),p=i.pointLocation(f),d=t.LngLat.convert(e.center||p);this._normalizeCenter(d);var g=i.project(p),v=i.project(d).sub(g),m=e.curve,y=Math.max(i.width,i.height),x=y/h,b=v.mag();if(\"minZoom\"in e){var _=t.clamp(Math.min(e.minZoom,a,l),i.minZoom,i.maxZoom),w=y/i.zoomScale(_-a);m=Math.sqrt(w/b*2)}var k=m*m;function T(t){var e=(x*x-y*y+(t?-1:1)*k*k*b*b)/(2*(t?x:y)*k*b);return Math.log(Math.sqrt(e*e+1)-e)}function A(t){return(Math.exp(t)-Math.exp(-t))/2}function M(t){return(Math.exp(t)+Math.exp(-t))/2}var S=T(0),E=function(t){return M(S)/M(S+m*t)},C=function(t){return y*((M(S)*(A(e=S+m*t)/M(e))-A(S))/k)/b;var e},L=(T(1)-S)/m;if(Math.abs(b)<1e-6||!isFinite(L)){if(Math.abs(y-x)<1e-6)return this.easeTo(e,r);var P=x<y?-1:1;L=Math.abs(Math.log(x/y))/m,C=function(){return 0},E=function(t){return Math.exp(P*m*t)}}if(\"duration\"in e)e.duration=+e.duration;else{var O=\"screenSpeed\"in e?+e.screenSpeed/m:+e.speed;e.duration=1e3*L/O}return e.maxDuration&&e.duration>e.maxDuration&&(e.duration=0),this._zooming=!0,this._rotating=o!==c,this._pitching=u!==s,this._prepareEase(r,!1),this._ease(function(e){var h=e*L,p=1/E(h);i.zoom=1===e?l:a+i.scaleZoom(p),n._rotating&&(i.bearing=t.number(o,c,e)),n._pitching&&(i.pitch=t.number(s,u,e));var m=1===e?d:i.unproject(g.add(v.mult(C(h))).mult(p));i.setLocationAtPoint(i.renderWorldCopies?m.wrap():m,f),n._fireMoveEvents(r)},function(){return n._afterEase(r)},e),this},r.prototype.isEasing=function(){return!!this._easeFrameId},r.prototype.stop=function(){if(this._easeFrameId&&(this._cancelRenderFrame(this._easeFrameId),delete this._easeFrameId,delete this._onEaseFrame),this._onEaseEnd){var t=this._onEaseEnd;delete this._onEaseEnd,t.call(this)}return this},r.prototype._ease=function(e,r,n){!1===n.animate||0===n.duration?(e(1),r()):(this._easeStart=t.browser.now(),this._easeOptions=n,this._onEaseFrame=e,this._onEaseEnd=r,this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback))},r.prototype._renderFrameCallback=function(){var e=Math.min((t.browser.now()-this._easeStart)/this._easeOptions.duration,1);this._onEaseFrame(this._easeOptions.easing(e)),e<1?this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback):this.stop()},r.prototype._normalizeBearing=function(e,r){e=t.wrap(e,-180,180);var n=Math.abs(e-r);return Math.abs(e-360-r)<n&&(e-=360),Math.abs(e+360-r)<n&&(e+=360),e},r.prototype._normalizeCenter=function(t){var e=this.transform;if(e.renderWorldCopies&&!e.lngRange){var r=t.lng-e.center.lng;t.lng+=r>180?-360:r<-180?360:0}},r}(t.Evented),Mn=function(e){void 0===e&&(e={}),this.options=e,t.bindAll([\"_updateEditLink\",\"_updateData\",\"_updateCompact\"],this)};Mn.prototype.getDefaultPosition=function(){return\"bottom-right\"},Mn.prototype.onAdd=function(t){var e=this.options&&this.options.compact;return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-attrib\"),this._innerContainer=r.create(\"div\",\"mapboxgl-ctrl-attrib-inner\",this._container),e&&this._container.classList.add(\"mapboxgl-compact\"),this._updateAttributions(),this._updateEditLink(),this._map.on(\"styledata\",this._updateData),this._map.on(\"sourcedata\",this._updateData),this._map.on(\"moveend\",this._updateEditLink),void 0===e&&(this._map.on(\"resize\",this._updateCompact),this._updateCompact()),this._container},Mn.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"styledata\",this._updateData),this._map.off(\"sourcedata\",this._updateData),this._map.off(\"moveend\",this._updateEditLink),this._map.off(\"resize\",this._updateCompact),this._map=void 0},Mn.prototype._updateEditLink=function(){var e=this._editLink;e||(e=this._editLink=this._container.querySelector(\".mapbox-improve-map\"));var r=[{key:\"owner\",value:this.styleOwner},{key:\"id\",value:this.styleId},{key:\"access_token\",value:t.config.ACCESS_TOKEN}];if(e){var n=r.reduce(function(t,e,n){return e.value&&(t+=e.key+\"=\"+e.value+(n<r.length-1?\"&\":\"\")),t},\"?\");e.href=t.config.FEEDBACK_URL+\"/\"+n+(this._map._hash?this._map._hash.getHashString(!0):\"\"),e.rel=\"noopener nofollow\"}},Mn.prototype._updateData=function(t){!t||\"metadata\"!==t.sourceDataType&&\"style\"!==t.dataType||(this._updateAttributions(),this._updateEditLink())},Mn.prototype._updateAttributions=function(){if(this._map.style){var t=[];if(this.options.customAttribution&&(Array.isArray(this.options.customAttribution)?t=t.concat(this.options.customAttribution.map(function(t){return\"string\"!=typeof t?\"\":t})):\"string\"==typeof this.options.customAttribution&&t.push(this.options.customAttribution)),this._map.style.stylesheet){var e=this._map.style.stylesheet;this.styleOwner=e.owner,this.styleId=e.id}var r=this._map.style.sourceCaches;for(var n in r){var i=r[n];if(i.used){var a=i.getSource();a.attribution&&t.indexOf(a.attribution)<0&&t.push(a.attribution)}}t.sort(function(t,e){return t.length-e.length});var o=(t=t.filter(function(e,r){for(var n=r+1;n<t.length;n++)if(t[n].indexOf(e)>=0)return!1;return!0})).join(\" | \");o!==this._attribHTML&&(this._attribHTML=o,t.length?(this._innerContainer.innerHTML=o,this._container.classList.remove(\"mapboxgl-attrib-empty\")):this._container.classList.add(\"mapboxgl-attrib-empty\"),this._editLink=null)}},Mn.prototype._updateCompact=function(){this._map.getCanvasContainer().offsetWidth<=640?this._container.classList.add(\"mapboxgl-compact\"):this._container.classList.remove(\"mapboxgl-compact\")};var Sn=function(){t.bindAll([\"_updateLogo\"],this),t.bindAll([\"_updateCompact\"],this)};Sn.prototype.onAdd=function(t){this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl\");var e=r.create(\"a\",\"mapboxgl-ctrl-logo\");return e.target=\"_blank\",e.rel=\"noopener nofollow\",e.href=\"https://www.mapbox.com/\",e.setAttribute(\"aria-label\",\"Mapbox logo\"),e.setAttribute(\"rel\",\"noopener nofollow\"),this._container.appendChild(e),this._container.style.display=\"none\",this._map.on(\"sourcedata\",this._updateLogo),this._updateLogo(),this._map.on(\"resize\",this._updateCompact),this._updateCompact(),this._container},Sn.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"sourcedata\",this._updateLogo),this._map.off(\"resize\",this._updateCompact)},Sn.prototype.getDefaultPosition=function(){return\"bottom-left\"},Sn.prototype._updateLogo=function(t){t&&\"metadata\"!==t.sourceDataType||(this._container.style.display=this._logoRequired()?\"block\":\"none\")},Sn.prototype._logoRequired=function(){if(this._map.style){var t=this._map.style.sourceCaches;for(var e in t)if(t[e].getSource().mapbox_logo)return!0;return!1}},Sn.prototype._updateCompact=function(){var t=this._container.children;if(t.length){var e=t[0];this._map.getCanvasContainer().offsetWidth<250?e.classList.add(\"mapboxgl-compact\"):e.classList.remove(\"mapboxgl-compact\")}};var En=function(){this._queue=[],this._id=0,this._cleared=!1,this._currentlyRunning=!1};En.prototype.add=function(t){var e=++this._id;return this._queue.push({callback:t,id:e,cancelled:!1}),e},En.prototype.remove=function(t){for(var e=this._currentlyRunning,r=0,n=e?this._queue.concat(e):this._queue;r<n.length;r+=1){var i=n[r];if(i.id===t)return void(i.cancelled=!0)}},En.prototype.run=function(){var t=this._currentlyRunning=this._queue;this._queue=[];for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!n.cancelled&&(n.callback(),this._cleared))break}this._cleared=!1,this._currentlyRunning=!1},En.prototype.clear=function(){this._currentlyRunning&&(this._cleared=!0),this._queue=[]};var Cn=t.window.HTMLImageElement,Ln=t.window.HTMLElement,Pn={center:[0,0],zoom:0,bearing:0,pitch:0,minZoom:0,maxZoom:22,interactive:!0,scrollZoom:!0,boxZoom:!0,dragRotate:!0,dragPan:!0,keyboard:!0,doubleClickZoom:!0,touchZoomRotate:!0,bearingSnap:7,clickTolerance:3,hash:!1,attributionControl:!0,failIfMajorPerformanceCaveat:!1,preserveDrawingBuffer:!1,trackResize:!0,renderWorldCopies:!0,refreshExpiredTiles:!0,maxTileCacheSize:null,localIdeographFontFamily:\"sans-serif\",transformRequest:null,fadeDuration:300,crossSourceCollisions:!0},On=function(n){function i(e){var i=this;if(null!=(e=t.extend({},Pn,e)).minZoom&&null!=e.maxZoom&&e.minZoom>e.maxZoom)throw new Error(\"maxZoom must be greater than minZoom\");var a=new sn(e.minZoom,e.maxZoom,e.renderWorldCopies);if(n.call(this,a,e),this._interactive=e.interactive,this._maxTileCacheSize=e.maxTileCacheSize,this._failIfMajorPerformanceCaveat=e.failIfMajorPerformanceCaveat,this._preserveDrawingBuffer=e.preserveDrawingBuffer,this._antialias=e.antialias,this._trackResize=e.trackResize,this._bearingSnap=e.bearingSnap,this._refreshExpiredTiles=e.refreshExpiredTiles,this._fadeDuration=e.fadeDuration,this._crossSourceCollisions=e.crossSourceCollisions,this._crossFadingFactor=1,this._collectResourceTiming=e.collectResourceTiming,this._renderTaskQueue=new En,this._controls=[],this._mapId=t.uniqueId(),this._requestManager=new t.RequestManager(e.transformRequest),\"string\"==typeof e.container){if(this._container=t.window.document.getElementById(e.container),!this._container)throw new Error(\"Container '\"+e.container+\"' not found.\")}else{if(!(e.container instanceof Ln))throw new Error(\"Invalid type: 'container' must be a String or HTMLElement.\");this._container=e.container}if(e.maxBounds&&this.setMaxBounds(e.maxBounds),t.bindAll([\"_onWindowOnline\",\"_onWindowResize\",\"_contextLost\",\"_contextRestored\"],this),this._setupContainer(),this._setupPainter(),void 0===this.painter)throw new Error(\"Failed to initialize WebGL.\");this.on(\"move\",function(){return i._update(!1)}),this.on(\"moveend\",function(){return i._update(!1)}),this.on(\"zoom\",function(){return i._update(!0)}),void 0!==t.window&&(t.window.addEventListener(\"online\",this._onWindowOnline,!1),t.window.addEventListener(\"resize\",this._onWindowResize,!1)),function(t,e){var n=t.getCanvasContainer(),i=null,a=!1,o=null;for(var s in Tn)t[s]=new Tn[s](t,e),e.interactive&&e[s]&&t[s].enable(e[s]);r.addEventListener(n,\"mouseout\",function(e){t.fire(new un(\"mouseout\",t,e))}),r.addEventListener(n,\"mousedown\",function(i){a=!0,o=r.mousePos(n,i);var s=new un(\"mousedown\",t,i);t.fire(s),s.defaultPrevented||(e.interactive&&!t.doubleClickZoom.isActive()&&t.stop(),t.boxZoom.onMouseDown(i),t.boxZoom.isActive()||t.dragPan.isActive()||t.dragRotate.onMouseDown(i),t.boxZoom.isActive()||t.dragRotate.isActive()||t.dragPan.onMouseDown(i))}),r.addEventListener(n,\"mouseup\",function(e){var r=t.dragRotate.isActive();i&&!r&&t.fire(new un(\"contextmenu\",t,i)),i=null,a=!1,t.fire(new un(\"mouseup\",t,e))}),r.addEventListener(n,\"mousemove\",function(e){if(!t.dragPan.isActive()&&!t.dragRotate.isActive()){for(var r=e.target;r&&r!==n;)r=r.parentNode;r===n&&t.fire(new un(\"mousemove\",t,e))}}),r.addEventListener(n,\"mouseover\",function(e){for(var r=e.target;r&&r!==n;)r=r.parentNode;r===n&&t.fire(new un(\"mouseover\",t,e))}),r.addEventListener(n,\"touchstart\",function(r){var n=new hn(\"touchstart\",t,r);t.fire(n),n.defaultPrevented||(e.interactive&&t.stop(),t.boxZoom.isActive()||t.dragRotate.isActive()||t.dragPan.onTouchStart(r),t.touchZoomRotate.onStart(r),t.doubleClickZoom.onTouchStart(n))},{passive:!1}),r.addEventListener(n,\"touchmove\",function(e){t.fire(new hn(\"touchmove\",t,e))},{passive:!1}),r.addEventListener(n,\"touchend\",function(e){t.fire(new hn(\"touchend\",t,e))}),r.addEventListener(n,\"touchcancel\",function(e){t.fire(new hn(\"touchcancel\",t,e))}),r.addEventListener(n,\"click\",function(i){var a=r.mousePos(n,i);(a.equals(o)||a.dist(o)<e.clickTolerance)&&t.fire(new un(\"click\",t,i))}),r.addEventListener(n,\"dblclick\",function(e){var r=new un(\"dblclick\",t,e);t.fire(r),r.defaultPrevented||t.doubleClickZoom.onDblClick(r)}),r.addEventListener(n,\"contextmenu\",function(e){var r=t.dragRotate.isActive();a||r?a&&(i=e):t.fire(new un(\"contextmenu\",t,e)),(t.dragRotate.isEnabled()||t.listens(\"contextmenu\"))&&e.preventDefault()}),r.addEventListener(n,\"wheel\",function(r){e.interactive&&t.stop();var n=new fn(\"wheel\",t,r);t.fire(n),n.defaultPrevented||t.scrollZoom.onWheel(r)},{passive:!1})}(this,e),this._hash=e.hash&&(new cn).addTo(this),this._hash&&this._hash._onHashChange()||(this.jumpTo({center:e.center,zoom:e.zoom,bearing:e.bearing,pitch:e.pitch}),e.bounds&&(this.resize(),this.fitBounds(e.bounds,t.extend({},e.fitBoundsOptions,{duration:0})))),this.resize(),this._localIdeographFontFamily=e.localIdeographFontFamily,e.style&&this.setStyle(e.style,{localIdeographFontFamily:e.localIdeographFontFamily}),e.attributionControl&&this.addControl(new Mn({customAttribution:e.customAttribution})),this.addControl(new Sn,e.logoPosition),this.on(\"style.load\",function(){i.transform.unmodified&&i.jumpTo(i.style.stylesheet)}),this.on(\"data\",function(e){i._update(\"style\"===e.dataType),i.fire(new t.Event(e.dataType+\"data\",e))}),this.on(\"dataloading\",function(e){i.fire(new t.Event(e.dataType+\"dataloading\",e))})}n&&(i.__proto__=n),i.prototype=Object.create(n&&n.prototype),i.prototype.constructor=i;var a={showTileBoundaries:{configurable:!0},showCollisionBoxes:{configurable:!0},showOverdrawInspector:{configurable:!0},repaint:{configurable:!0},vertices:{configurable:!0}};return i.prototype._getMapId=function(){return this._mapId},i.prototype.addControl=function(e,r){if(void 0===r&&e.getDefaultPosition&&(r=e.getDefaultPosition()),void 0===r&&(r=\"top-right\"),!e||!e.onAdd)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.addControl(). Argument must be a control with onAdd and onRemove methods.\")));var n=e.onAdd(this);this._controls.push(e);var i=this._controlPositions[r];return-1!==r.indexOf(\"bottom\")?i.insertBefore(n,i.firstChild):i.appendChild(n),this},i.prototype.removeControl=function(e){if(!e||!e.onRemove)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.removeControl(). Argument must be a control with onAdd and onRemove methods.\")));var r=this._controls.indexOf(e);return r>-1&&this._controls.splice(r,1),e.onRemove(this),this},i.prototype.resize=function(e){var r=this._containerDimensions(),n=r[0],i=r[1];return this._resizeCanvas(n,i),this.transform.resize(n,i),this.painter.resize(n,i),this.fire(new t.Event(\"movestart\",e)).fire(new t.Event(\"move\",e)).fire(new t.Event(\"resize\",e)).fire(new t.Event(\"moveend\",e)),this},i.prototype.getBounds=function(){return this.transform.getBounds()},i.prototype.getMaxBounds=function(){return this.transform.getMaxBounds()},i.prototype.setMaxBounds=function(e){return this.transform.setMaxBounds(t.LngLatBounds.convert(e)),this._update()},i.prototype.setMinZoom=function(t){if((t=null==t?0:t)>=0&&t<=this.transform.maxZoom)return this.transform.minZoom=t,this._update(),this.getZoom()<t&&this.setZoom(t),this;throw new Error(\"minZoom must be between 0 and the current maxZoom, inclusive\")},i.prototype.getMinZoom=function(){return this.transform.minZoom},i.prototype.setMaxZoom=function(t){if((t=null==t?22:t)>=this.transform.minZoom)return this.transform.maxZoom=t,this._update(),this.getZoom()>t&&this.setZoom(t),this;throw new Error(\"maxZoom must be greater than the current minZoom\")},i.prototype.getRenderWorldCopies=function(){return this.transform.renderWorldCopies},i.prototype.setRenderWorldCopies=function(t){return this.transform.renderWorldCopies=t,this._update()},i.prototype.getMaxZoom=function(){return this.transform.maxZoom},i.prototype.project=function(e){return this.transform.locationPoint(t.LngLat.convert(e))},i.prototype.unproject=function(e){return this.transform.pointLocation(t.Point.convert(e))},i.prototype.isMoving=function(){return this._moving||this.dragPan.isActive()||this.dragRotate.isActive()||this.scrollZoom.isActive()},i.prototype.isZooming=function(){return this._zooming||this.scrollZoom.isZooming()},i.prototype.isRotating=function(){return this._rotating||this.dragRotate.isActive()},i.prototype.on=function(t,e,r){var i=this;if(void 0===r)return n.prototype.on.call(this,t,e);var a=function(){var n;if(\"mouseenter\"===t||\"mouseover\"===t){var a=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){var o=i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[];o.length?a||(a=!0,r.call(i,new un(t,i,n.originalEvent,{features:o}))):a=!1},mouseout:function(){a=!1}}}}if(\"mouseleave\"===t||\"mouseout\"===t){var o=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){(i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[]).length?o=!0:o&&(o=!1,r.call(i,new un(t,i,n.originalEvent)))},mouseout:function(e){o&&(o=!1,r.call(i,new un(t,i,e.originalEvent)))}}}}return{layer:e,listener:r,delegates:(n={},n[t]=function(t){var n=i.getLayer(e)?i.queryRenderedFeatures(t.point,{layers:[e]}):[];n.length&&(t.features=n,r.call(i,t),delete t.features)},n)}}();for(var o in this._delegatedListeners=this._delegatedListeners||{},this._delegatedListeners[t]=this._delegatedListeners[t]||[],this._delegatedListeners[t].push(a),a.delegates)this.on(o,a.delegates[o]);return this},i.prototype.off=function(t,e,r){if(void 0===r)return n.prototype.off.call(this,t,e);if(this._delegatedListeners&&this._delegatedListeners[t])for(var i=this._delegatedListeners[t],a=0;a<i.length;a++){var o=i[a];if(o.layer===e&&o.listener===r){for(var s in o.delegates)this.off(s,o.delegates[s]);return i.splice(a,1),this}}return this},i.prototype.queryRenderedFeatures=function(e,r){if(!this.style)return[];var n;if(void 0!==r||void 0===e||e instanceof t.Point||Array.isArray(e)||(r=e,e=void 0),r=r||{},(e=e||[[0,0],[this.transform.width,this.transform.height]])instanceof t.Point||\"number\"==typeof e[0])n=[t.Point.convert(e)];else{var i=t.Point.convert(e[0]),a=t.Point.convert(e[1]);n=[i,new t.Point(a.x,i.y),a,new t.Point(i.x,a.y),i]}return this.style.queryRenderedFeatures(n,r,this.transform)},i.prototype.querySourceFeatures=function(t,e){return this.style.querySourceFeatures(t,e)},i.prototype.setStyle=function(e,r){return!1!==(r=t.extend({},{localIdeographFontFamily:Pn.localIdeographFontFamily},r)).diff&&r.localIdeographFontFamily===this._localIdeographFontFamily&&this.style&&e?(this._diffStyle(e,r),this):(this._localIdeographFontFamily=r.localIdeographFontFamily,this._updateStyle(e,r))},i.prototype._updateStyle=function(t,e){return this.style&&(this.style.setEventedParent(null),this.style._remove()),t?(this.style=new De(this,e||{}),this.style.setEventedParent(this,{style:this.style}),\"string\"==typeof t?this.style.loadURL(t):this.style.loadJSON(t),this):(delete this.style,this)},i.prototype._diffStyle=function(e,r){var n=this;if(\"string\"==typeof e){var i=this._requestManager.normalizeStyleURL(e),a=this._requestManager.transformRequest(i,t.ResourceType.Style);t.getJSON(a,function(e,i){e?n.fire(new t.ErrorEvent(e)):i&&n._updateDiff(i,r)})}else\"object\"==typeof e&&this._updateDiff(e,r)},i.prototype._updateDiff=function(e,r){try{this.style.setState(e)&&this._update(!0)}catch(n){t.warnOnce(\"Unable to perform style diff: \"+(n.message||n.error||n)+\".  Rebuilding the style from scratch.\"),this._updateStyle(e,r)}},i.prototype.getStyle=function(){if(this.style)return this.style.serialize()},i.prototype.isStyleLoaded=function(){return this.style?this.style.loaded():t.warnOnce(\"There is no style added to the map.\")},i.prototype.addSource=function(t,e){return this.style.addSource(t,e),this._update(!0)},i.prototype.isSourceLoaded=function(e){var r=this.style&&this.style.sourceCaches[e];if(void 0!==r)return r.loaded();this.fire(new t.ErrorEvent(new Error(\"There is no source with ID '\"+e+\"'\")))},i.prototype.areTilesLoaded=function(){var t=this.style&&this.style.sourceCaches;for(var e in t){var r=t[e]._tiles;for(var n in r){var i=r[n];if(\"loaded\"!==i.state&&\"errored\"!==i.state)return!1}}return!0},i.prototype.addSourceType=function(t,e,r){return this.style.addSourceType(t,e,r)},i.prototype.removeSource=function(t){return this.style.removeSource(t),this._update(!0)},i.prototype.getSource=function(t){return this.style.getSource(t)},i.prototype.addImage=function(e,r,n){void 0===n&&(n={});var i=n.pixelRatio;void 0===i&&(i=1);var a=n.sdf;if(void 0===a&&(a=!1),r instanceof Cn){var o=t.browser.getImageData(r),s=o.width,l=o.height,c=o.data;this.style.addImage(e,{data:new t.RGBAImage({width:s,height:l},c),pixelRatio:i,sdf:a,version:0})}else{if(void 0===r.width||void 0===r.height)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.addImage(). The second argument must be an `HTMLImageElement`, `ImageData`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));var u=r.width,h=r.height,f=r.data,p=r;this.style.addImage(e,{data:new t.RGBAImage({width:u,height:h},new Uint8Array(f)),pixelRatio:i,sdf:a,version:0,userImage:p}),p.onAdd&&p.onAdd(this,e)}},i.prototype.updateImage=function(e,r){var n=this.style.getImage(e);if(!n)return this.fire(new t.ErrorEvent(new Error(\"The map has no image with that id. If you are adding a new image use `map.addImage(...)` instead.\")));var i=r instanceof Cn?t.browser.getImageData(r):r,a=i.width,o=i.height,s=i.data;if(void 0===a||void 0===o)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.updateImage(). The second argument must be an `HTMLImageElement`, `ImageData`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));if(a!==n.data.width||o!==n.data.height)return this.fire(new t.ErrorEvent(new Error(\"The width and height of the updated image must be that same as the previous version of the image\")));var l=!(r instanceof Cn);n.data.replace(s,l),this.style.updateImage(e,n)},i.prototype.hasImage=function(e){return e?!!this.style.getImage(e):(this.fire(new t.ErrorEvent(new Error(\"Missing required image id\"))),!1)},i.prototype.removeImage=function(t){this.style.removeImage(t)},i.prototype.loadImage=function(e,r){t.getImage(this._requestManager.transformRequest(e,t.ResourceType.Image),r)},i.prototype.listImages=function(){return this.style.listImages()},i.prototype.addLayer=function(t,e){return this.style.addLayer(t,e),this._update(!0)},i.prototype.moveLayer=function(t,e){return this.style.moveLayer(t,e),this._update(!0)},i.prototype.removeLayer=function(t){return this.style.removeLayer(t),this._update(!0)},i.prototype.getLayer=function(t){return this.style.getLayer(t)},i.prototype.setFilter=function(t,e,r){return void 0===r&&(r={}),this.style.setFilter(t,e,r),this._update(!0)},i.prototype.setLayerZoomRange=function(t,e,r){return this.style.setLayerZoomRange(t,e,r),this._update(!0)},i.prototype.getFilter=function(t){return this.style.getFilter(t)},i.prototype.setPaintProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setPaintProperty(t,e,r,n),this._update(!0)},i.prototype.getPaintProperty=function(t,e){return this.style.getPaintProperty(t,e)},i.prototype.setLayoutProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setLayoutProperty(t,e,r,n),this._update(!0)},i.prototype.getLayoutProperty=function(t,e){return this.style.getLayoutProperty(t,e)},i.prototype.setLight=function(t,e){return void 0===e&&(e={}),this.style.setLight(t,e),this._update(!0)},i.prototype.getLight=function(){return this.style.getLight()},i.prototype.setFeatureState=function(t,e){return this.style.setFeatureState(t,e),this._update()},i.prototype.removeFeatureState=function(t,e){return this.style.removeFeatureState(t,e),this._update()},i.prototype.getFeatureState=function(t){return this.style.getFeatureState(t)},i.prototype.getContainer=function(){return this._container},i.prototype.getCanvasContainer=function(){return this._canvasContainer},i.prototype.getCanvas=function(){return this._canvas},i.prototype._containerDimensions=function(){var t=0,e=0;return this._container&&(t=this._container.clientWidth||400,e=this._container.clientHeight||300),[t,e]},i.prototype._detectMissingCSS=function(){\"rgb(250, 128, 114)\"!==t.window.getComputedStyle(this._missingCSSCanary).getPropertyValue(\"background-color\")&&t.warnOnce(\"This page appears to be missing CSS declarations for Mapbox GL JS, which may cause the map to display incorrectly. Please ensure your page includes mapbox-gl.css, as described in https://www.mapbox.com/mapbox-gl-js/api/.\")},i.prototype._setupContainer=function(){var t=this._container;t.classList.add(\"mapboxgl-map\"),(this._missingCSSCanary=r.create(\"div\",\"mapboxgl-canary\",t)).style.visibility=\"hidden\",this._detectMissingCSS();var e=this._canvasContainer=r.create(\"div\",\"mapboxgl-canvas-container\",t);this._interactive&&e.classList.add(\"mapboxgl-interactive\"),this._canvas=r.create(\"canvas\",\"mapboxgl-canvas\",e),this._canvas.style.position=\"absolute\",this._canvas.addEventListener(\"webglcontextlost\",this._contextLost,!1),this._canvas.addEventListener(\"webglcontextrestored\",this._contextRestored,!1),this._canvas.setAttribute(\"tabindex\",\"0\"),this._canvas.setAttribute(\"aria-label\",\"Map\");var n=this._containerDimensions();this._resizeCanvas(n[0],n[1]);var i=this._controlContainer=r.create(\"div\",\"mapboxgl-control-container\",t),a=this._controlPositions={};[\"top-left\",\"top-right\",\"bottom-left\",\"bottom-right\"].forEach(function(t){a[t]=r.create(\"div\",\"mapboxgl-ctrl-\"+t,i)})},i.prototype._resizeCanvas=function(e,r){var n=t.window.devicePixelRatio||1;this._canvas.width=n*e,this._canvas.height=n*r,this._canvas.style.width=e+\"px\",this._canvas.style.height=r+\"px\"},i.prototype._setupPainter=function(){var r=t.extend({},e.webGLContextAttributes,{failIfMajorPerformanceCaveat:this._failIfMajorPerformanceCaveat,preserveDrawingBuffer:this._preserveDrawingBuffer,antialias:this._antialias||!1}),n=this._canvas.getContext(\"webgl\",r)||this._canvas.getContext(\"experimental-webgl\",r);n?(this.painter=new rn(n,this.transform),t.webpSupported.testSupport(n)):this.fire(new t.ErrorEvent(new Error(\"Failed to initialize WebGL\")))},i.prototype._contextLost=function(e){e.preventDefault(),this._frame&&(this._frame.cancel(),this._frame=null),this.fire(new t.Event(\"webglcontextlost\",{originalEvent:e}))},i.prototype._contextRestored=function(e){this._setupPainter(),this.resize(),this._update(),this.fire(new t.Event(\"webglcontextrestored\",{originalEvent:e}))},i.prototype.loaded=function(){return!this._styleDirty&&!this._sourcesDirty&&!!this.style&&this.style.loaded()},i.prototype._update=function(t){return this.style?(this._styleDirty=this._styleDirty||t,this._sourcesDirty=!0,this.triggerRepaint(),this):this},i.prototype._requestRenderFrame=function(t){return this._update(),this._renderTaskQueue.add(t)},i.prototype._cancelRenderFrame=function(t){this._renderTaskQueue.remove(t)},i.prototype._render=function(){this.painter.context.setDirty(),this.painter.setBaseState(),this._renderTaskQueue.run();var e=!1;if(this.style&&this._styleDirty){this._styleDirty=!1;var r=this.transform.zoom,n=t.browser.now();this.style.zoomHistory.update(r,n);var i=new t.EvaluationParameters(r,{now:n,fadeDuration:this._fadeDuration,zoomHistory:this.style.zoomHistory,transition:this.style.getTransition()}),a=i.crossFadingFactor();1===a&&a===this._crossFadingFactor||(e=!0,this._crossFadingFactor=a),this.style.update(i)}return this.style&&this._sourcesDirty&&(this._sourcesDirty=!1,this.style._updateSources(this.transform)),this._placementDirty=this.style&&this.style._updatePlacement(this.painter.transform,this.showCollisionBoxes,this._fadeDuration,this._crossSourceCollisions),this.painter.render(this.style,{showTileBoundaries:this.showTileBoundaries,showOverdrawInspector:this._showOverdrawInspector,rotating:this.isRotating(),zooming:this.isZooming(),moving:this.isMoving(),fadeDuration:this._fadeDuration}),this.fire(new t.Event(\"render\")),this.loaded()&&!this._loaded&&(this._loaded=!0,this.fire(new t.Event(\"load\"))),this.style&&(this.style.hasTransitions()||e)&&(this._styleDirty=!0),this.style&&!this._placementDirty&&this.style._releaseSymbolFadeTiles(),this._sourcesDirty||this._repaint||this._styleDirty||this._placementDirty?this.triggerRepaint():!this.isMoving()&&this.loaded()&&this.fire(new t.Event(\"idle\")),this},i.prototype.remove=function(){this._hash&&this._hash.remove();for(var e=0,r=this._controls;e<r.length;e+=1)r[e].onRemove(this);this._controls=[],this._frame&&(this._frame.cancel(),this._frame=null),this._renderTaskQueue.clear(),this.setStyle(null),void 0!==t.window&&(t.window.removeEventListener(\"resize\",this._onWindowResize,!1),t.window.removeEventListener(\"online\",this._onWindowOnline,!1));var n=this.painter.context.gl.getExtension(\"WEBGL_lose_context\");n&&n.loseContext(),zn(this._canvasContainer),zn(this._controlContainer),zn(this._missingCSSCanary),this._container.classList.remove(\"mapboxgl-map\"),this.fire(new t.Event(\"remove\"))},i.prototype.triggerRepaint=function(){var e=this;this.style&&!this._frame&&(this._frame=t.browser.frame(function(){e._frame=null,e._render()}))},i.prototype._onWindowOnline=function(){this._update()},i.prototype._onWindowResize=function(){this._trackResize&&this.resize()._update()},a.showTileBoundaries.get=function(){return!!this._showTileBoundaries},a.showTileBoundaries.set=function(t){this._showTileBoundaries!==t&&(this._showTileBoundaries=t,this._update())},a.showCollisionBoxes.get=function(){return!!this._showCollisionBoxes},a.showCollisionBoxes.set=function(t){this._showCollisionBoxes!==t&&(this._showCollisionBoxes=t,t?this.style._generateCollisionBoxes():this._update())},a.showOverdrawInspector.get=function(){return!!this._showOverdrawInspector},a.showOverdrawInspector.set=function(t){this._showOverdrawInspector!==t&&(this._showOverdrawInspector=t,this._update())},a.repaint.get=function(){return!!this._repaint},a.repaint.set=function(t){this._repaint!==t&&(this._repaint=t,this.triggerRepaint())},a.vertices.get=function(){return!!this._vertices},a.vertices.set=function(t){this._vertices=t,this._update()},i.prototype._setCacheLimits=function(e,r){t.setCacheLimits(e,r)},Object.defineProperties(i.prototype,a),i}(An);function zn(t){t.parentNode&&t.parentNode.removeChild(t)}var In={showCompass:!0,showZoom:!0},Dn=function(e){var n=this;this.options=t.extend({},In,e),this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),this._container.addEventListener(\"contextmenu\",function(t){return t.preventDefault()}),this.options.showZoom&&(t.bindAll([\"_updateZoomButtons\"],this),this._zoomInButton=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-zoom-in\",\"Zoom in\",function(){return n._map.zoomIn()}),this._zoomOutButton=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-zoom-out\",\"Zoom out\",function(){return n._map.zoomOut()})),this.options.showCompass&&(t.bindAll([\"_rotateCompassArrow\"],this),this._compass=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-compass\",\"Reset bearing to north\",function(){return n._map.resetNorth()}),this._compassArrow=r.create(\"span\",\"mapboxgl-ctrl-compass-arrow\",this._compass))};function Rn(e,r,n){if(e=new t.LngLat(e.lng,e.lat),r){var i=new t.LngLat(e.lng-360,e.lat),a=new t.LngLat(e.lng+360,e.lat),o=n.locationPoint(e).distSqr(r);n.locationPoint(i).distSqr(r)<o?e=i:n.locationPoint(a).distSqr(r)<o&&(e=a)}for(;Math.abs(e.lng-n.center.lng)>180;){var s=n.locationPoint(e);if(s.x>=0&&s.y>=0&&s.x<=n.width&&s.y<=n.height)break;e.lng>n.center.lng?e.lng-=360:e.lng+=360}return e}Dn.prototype._updateZoomButtons=function(){var t=this._map.getZoom();this._zoomInButton.classList.toggle(\"mapboxgl-ctrl-icon-disabled\",t===this._map.getMaxZoom()),this._zoomOutButton.classList.toggle(\"mapboxgl-ctrl-icon-disabled\",t===this._map.getMinZoom())},Dn.prototype._rotateCompassArrow=function(){var t=\"rotate(\"+this._map.transform.angle*(180/Math.PI)+\"deg)\";this._compassArrow.style.transform=t},Dn.prototype.onAdd=function(t){return this._map=t,this.options.showZoom&&(this._map.on(\"zoom\",this._updateZoomButtons),this._updateZoomButtons()),this.options.showCompass&&(this._map.on(\"rotate\",this._rotateCompassArrow),this._rotateCompassArrow(),this._handler=new vn(t,{button:\"left\",element:this._compass}),r.addEventListener(this._compass,\"mousedown\",this._handler.onMouseDown),this._handler.enable()),this._container},Dn.prototype.onRemove=function(){r.remove(this._container),this.options.showZoom&&this._map.off(\"zoom\",this._updateZoomButtons),this.options.showCompass&&(this._map.off(\"rotate\",this._rotateCompassArrow),r.removeEventListener(this._compass,\"mousedown\",this._handler.onMouseDown),this._handler.disable(),delete this._handler),delete this._map},Dn.prototype._createButton=function(t,e,n){var i=r.create(\"button\",t,this._container);return i.type=\"button\",i.title=e,i.setAttribute(\"aria-label\",e),i.addEventListener(\"click\",n),i};var Fn={center:\"translate(-50%,-50%)\",top:\"translate(-50%,0)\",\"top-left\":\"translate(0,0)\",\"top-right\":\"translate(-100%,0)\",bottom:\"translate(-50%,-100%)\",\"bottom-left\":\"translate(0,-100%)\",\"bottom-right\":\"translate(-100%,-100%)\",left:\"translate(0,-50%)\",right:\"translate(-100%,-50%)\"};function Bn(t,e,r){var n=t.classList;for(var i in Fn)n.remove(\"mapboxgl-\"+r+\"-anchor-\"+i);n.add(\"mapboxgl-\"+r+\"-anchor-\"+e)}var Nn,jn=function(e){function n(n,i){if(e.call(this),(n instanceof t.window.HTMLElement||i)&&(n=t.extend({element:n},i)),t.bindAll([\"_update\",\"_onMove\",\"_onUp\",\"_addDragHandler\",\"_onMapClick\"],this),this._anchor=n&&n.anchor||\"center\",this._color=n&&n.color||\"#3FB1CE\",this._draggable=n&&n.draggable||!1,this._state=\"inactive\",n&&n.element)this._element=n.element,this._offset=t.Point.convert(n&&n.offset||[0,0]);else{this._defaultMarker=!0,this._element=r.create(\"div\");var a=r.createNS(\"http://www.w3.org/2000/svg\",\"svg\");a.setAttributeNS(null,\"display\",\"block\"),a.setAttributeNS(null,\"height\",\"41px\"),a.setAttributeNS(null,\"width\",\"27px\"),a.setAttributeNS(null,\"viewBox\",\"0 0 27 41\");var o=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");o.setAttributeNS(null,\"stroke\",\"none\"),o.setAttributeNS(null,\"stroke-width\",\"1\"),o.setAttributeNS(null,\"fill\",\"none\"),o.setAttributeNS(null,\"fill-rule\",\"evenodd\");var s=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");s.setAttributeNS(null,\"fill-rule\",\"nonzero\");var l=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");l.setAttributeNS(null,\"transform\",\"translate(3.0, 29.0)\"),l.setAttributeNS(null,\"fill\",\"#000000\");for(var c=0,u=[{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"9.5\",ry:\"4.77275007\"},{rx:\"8.5\",ry:\"4.29549936\"},{rx:\"7.5\",ry:\"3.81822308\"},{rx:\"6.5\",ry:\"3.34094679\"},{rx:\"5.5\",ry:\"2.86367051\"},{rx:\"4.5\",ry:\"2.38636864\"}];c<u.length;c+=1){var h=u[c],f=r.createNS(\"http://www.w3.org/2000/svg\",\"ellipse\");f.setAttributeNS(null,\"opacity\",\"0.04\"),f.setAttributeNS(null,\"cx\",\"10.5\"),f.setAttributeNS(null,\"cy\",\"5.80029008\"),f.setAttributeNS(null,\"rx\",h.rx),f.setAttributeNS(null,\"ry\",h.ry),l.appendChild(f)}var p=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");p.setAttributeNS(null,\"fill\",this._color);var d=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");d.setAttributeNS(null,\"d\",\"M27,13.5 C27,19.074644 20.250001,27.000002 14.75,34.500002 C14.016665,35.500004 12.983335,35.500004 12.25,34.500002 C6.7499993,27.000002 0,19.222562 0,13.5 C0,6.0441559 6.0441559,0 13.5,0 C20.955844,0 27,6.0441559 27,13.5 Z\"),p.appendChild(d);var g=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");g.setAttributeNS(null,\"opacity\",\"0.25\"),g.setAttributeNS(null,\"fill\",\"#000000\");var v=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");v.setAttributeNS(null,\"d\",\"M13.5,0 C6.0441559,0 0,6.0441559 0,13.5 C0,19.222562 6.7499993,27 12.25,34.5 C13,35.522727 14.016664,35.500004 14.75,34.5 C20.250001,27 27,19.074644 27,13.5 C27,6.0441559 20.955844,0 13.5,0 Z M13.5,1 C20.415404,1 26,6.584596 26,13.5 C26,15.898657 24.495584,19.181431 22.220703,22.738281 C19.945823,26.295132 16.705119,30.142167 13.943359,33.908203 C13.743445,34.180814 13.612715,34.322738 13.5,34.441406 C13.387285,34.322738 13.256555,34.180814 13.056641,33.908203 C10.284481,30.127985 7.4148684,26.314159 5.015625,22.773438 C2.6163816,19.232715 1,15.953538 1,13.5 C1,6.584596 6.584596,1 13.5,1 Z\"),g.appendChild(v);var m=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");m.setAttributeNS(null,\"transform\",\"translate(6.0, 7.0)\"),m.setAttributeNS(null,\"fill\",\"#FFFFFF\");var y=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");y.setAttributeNS(null,\"transform\",\"translate(8.0, 8.0)\");var x=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");x.setAttributeNS(null,\"fill\",\"#000000\"),x.setAttributeNS(null,\"opacity\",\"0.25\"),x.setAttributeNS(null,\"cx\",\"5.5\"),x.setAttributeNS(null,\"cy\",\"5.5\"),x.setAttributeNS(null,\"r\",\"5.4999962\");var b=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");b.setAttributeNS(null,\"fill\",\"#FFFFFF\"),b.setAttributeNS(null,\"cx\",\"5.5\"),b.setAttributeNS(null,\"cy\",\"5.5\"),b.setAttributeNS(null,\"r\",\"5.4999962\"),y.appendChild(x),y.appendChild(b),s.appendChild(l),s.appendChild(p),s.appendChild(g),s.appendChild(m),s.appendChild(y),a.appendChild(s),this._element.appendChild(a),this._offset=t.Point.convert(n&&n.offset||[0,-14])}this._element.classList.add(\"mapboxgl-marker\"),this._element.addEventListener(\"dragstart\",function(t){t.preventDefault()}),Bn(this._element,this._anchor,\"marker\"),this._popup=null}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.addTo=function(t){return this.remove(),this._map=t,t.getCanvasContainer().appendChild(this._element),t.on(\"move\",this._update),t.on(\"moveend\",this._update),this.setDraggable(this._draggable),this._update(),this._map.on(\"click\",this._onMapClick),this},n.prototype.remove=function(){return this._map&&(this._map.off(\"click\",this._onMapClick),this._map.off(\"move\",this._update),this._map.off(\"moveend\",this._update),this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler),this._map.off(\"mouseup\",this._onUp),this._map.off(\"touchend\",this._onUp),delete this._map),r.remove(this._element),this._popup&&this._popup.remove(),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._popup&&this._popup.setLngLat(this._lngLat),this._update(),this},n.prototype.getElement=function(){return this._element},n.prototype.setPopup=function(t){if(this._popup&&(this._popup.remove(),this._popup=null),t){if(!(\"offset\"in t.options)){var e=Math.sqrt(Math.pow(13.5,2)/2);t.options.offset=this._defaultMarker?{top:[0,0],\"top-left\":[0,0],\"top-right\":[0,0],bottom:[0,-38.1],\"bottom-left\":[e,-1*(24.6+e)],\"bottom-right\":[-e,-1*(24.6+e)],left:[13.5,-24.6],right:[-13.5,-24.6]}:this._offset}this._popup=t,this._lngLat&&this._popup.setLngLat(this._lngLat)}return this},n.prototype._onMapClick=function(t){var e=t.originalEvent.target,r=this._element;this._popup&&(e===r||r.contains(e))&&this.togglePopup()},n.prototype.getPopup=function(){return this._popup},n.prototype.togglePopup=function(){var t=this._popup;return t?(t.isOpen()?t.remove():t.addTo(this._map),this):this},n.prototype._update=function(t){this._map&&(this._map.transform.renderWorldCopies&&(this._lngLat=Rn(this._lngLat,this._pos,this._map.transform)),this._pos=this._map.project(this._lngLat)._add(this._offset),t&&\"moveend\"!==t.type||(this._pos=this._pos.round()),r.setTransform(this._element,Fn[this._anchor]+\" translate(\"+this._pos.x+\"px, \"+this._pos.y+\"px)\"))},n.prototype.getOffset=function(){return this._offset},n.prototype.setOffset=function(e){return this._offset=t.Point.convert(e),this._update(),this},n.prototype._onMove=function(e){this._pos=e.point.sub(this._positionDelta),this._lngLat=this._map.unproject(this._pos),this.setLngLat(this._lngLat),this._element.style.pointerEvents=\"none\",\"pending\"===this._state&&(this._state=\"active\",this.fire(new t.Event(\"dragstart\"))),this.fire(new t.Event(\"drag\"))},n.prototype._onUp=function(){this._element.style.pointerEvents=\"auto\",this._positionDelta=null,this._map.off(\"mousemove\",this._onMove),this._map.off(\"touchmove\",this._onMove),\"active\"===this._state&&this.fire(new t.Event(\"dragend\")),this._state=\"inactive\"},n.prototype._addDragHandler=function(t){this._element.contains(t.originalEvent.target)&&(t.preventDefault(),this._positionDelta=t.point.sub(this._pos).add(this._offset),this._state=\"pending\",this._map.on(\"mousemove\",this._onMove),this._map.on(\"touchmove\",this._onMove),this._map.once(\"mouseup\",this._onUp),this._map.once(\"touchend\",this._onUp))},n.prototype.setDraggable=function(t){return this._draggable=!!t,this._map&&(t?(this._map.on(\"mousedown\",this._addDragHandler),this._map.on(\"touchstart\",this._addDragHandler)):(this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler))),this},n.prototype.isDraggable=function(){return this._draggable},n}(t.Evented),Un={positionOptions:{enableHighAccuracy:!1,maximumAge:0,timeout:6e3},fitBoundsOptions:{maxZoom:15},trackUserLocation:!1,showUserLocation:!0},Vn=function(e){function n(r){e.call(this),this.options=t.extend({},Un,r),t.bindAll([\"_onSuccess\",\"_onError\",\"_finish\",\"_setupUI\",\"_updateCamera\",\"_updateMarker\"],this)}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.onAdd=function(e){var n;return this._map=e,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),n=this._setupUI,void 0!==Nn?n(Nn):void 0!==t.window.navigator.permissions?t.window.navigator.permissions.query({name:\"geolocation\"}).then(function(t){Nn=\"denied\"!==t.state,n(Nn)}):(Nn=!!t.window.navigator.geolocation,n(Nn)),this._container},n.prototype.onRemove=function(){void 0!==this._geolocationWatchID&&(t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0),this.options.showUserLocation&&this._userLocationDotMarker&&this._userLocationDotMarker.remove(),r.remove(this._container),this._map=void 0},n.prototype._onSuccess=function(e){if(this.options.trackUserLocation)switch(this._lastKnownPosition=e,this._watchState){case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"BACKGROUND\":case\"BACKGROUND_ERROR\":this._watchState=\"BACKGROUND\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\")}this.options.showUserLocation&&\"OFF\"!==this._watchState&&this._updateMarker(e),this.options.trackUserLocation&&\"ACTIVE_LOCK\"!==this._watchState||this._updateCamera(e),this.options.showUserLocation&&this._dotElement.classList.remove(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"geolocate\",e)),this._finish()},n.prototype._updateCamera=function(e){var r=new t.LngLat(e.coords.longitude,e.coords.latitude),n=e.coords.accuracy,i=this._map.getBearing(),a=t.extend({bearing:i},this.options.fitBoundsOptions);this._map.fitBounds(r.toBounds(n),a,{geolocateSource:!0})},n.prototype._updateMarker=function(t){t?this._userLocationDotMarker.setLngLat([t.coords.longitude,t.coords.latitude]).addTo(this._map):this._userLocationDotMarker.remove()},n.prototype._onError=function(e){if(this.options.trackUserLocation)if(1===e.code)this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),void 0!==this._geolocationWatchID&&this._clearWatch();else switch(this._watchState){case\"WAITING_ACTIVE\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"ACTIVE_LOCK\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\");break;case\"BACKGROUND\":this._watchState=\"BACKGROUND_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\")}\"OFF\"!==this._watchState&&this.options.showUserLocation&&this._dotElement.classList.add(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"error\",e)),this._finish()},n.prototype._finish=function(){this._timeoutId&&clearTimeout(this._timeoutId),this._timeoutId=void 0},n.prototype._setupUI=function(e){var n=this;!1!==e?(this._container.addEventListener(\"contextmenu\",function(t){return t.preventDefault()}),this._geolocateButton=r.create(\"button\",\"mapboxgl-ctrl-icon mapboxgl-ctrl-geolocate\",this._container),this._geolocateButton.type=\"button\",this._geolocateButton.setAttribute(\"aria-label\",\"Geolocate\"),this.options.trackUserLocation&&(this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this._watchState=\"OFF\"),this.options.showUserLocation&&(this._dotElement=r.create(\"div\",\"mapboxgl-user-location-dot\"),this._userLocationDotMarker=new jn(this._dotElement),this.options.trackUserLocation&&(this._watchState=\"OFF\")),this._geolocateButton.addEventListener(\"click\",this.trigger.bind(this)),this._setup=!0,this.options.trackUserLocation&&this._map.on(\"movestart\",function(e){e.geolocateSource||\"ACTIVE_LOCK\"!==n._watchState||(n._watchState=\"BACKGROUND\",n._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\"),n._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),n.fire(new t.Event(\"trackuserlocationend\")))})):t.warnOnce(\"Geolocation support is not available, the GeolocateControl will not be visible.\")},n.prototype.trigger=function(){if(!this._setup)return t.warnOnce(\"Geolocate control triggered before added to a map\"),!1;if(this.options.trackUserLocation){switch(this._watchState){case\"OFF\":this._watchState=\"WAITING_ACTIVE\",this.fire(new t.Event(\"trackuserlocationstart\"));break;case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":case\"BACKGROUND_ERROR\":this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this.fire(new t.Event(\"trackuserlocationend\"));break;case\"BACKGROUND\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._lastKnownPosition&&this._updateCamera(this._lastKnownPosition),this.fire(new t.Event(\"trackuserlocationstart\"))}switch(this._watchState){case\"WAITING_ACTIVE\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_LOCK\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"BACKGROUND\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\");break;case\"BACKGROUND_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\")}\"OFF\"===this._watchState&&void 0!==this._geolocationWatchID?this._clearWatch():void 0===this._geolocationWatchID&&(this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"true\"),this._geolocationWatchID=t.window.navigator.geolocation.watchPosition(this._onSuccess,this._onError,this.options.positionOptions))}else t.window.navigator.geolocation.getCurrentPosition(this._onSuccess,this._onError,this.options.positionOptions),this._timeoutId=setTimeout(this._finish,1e4);return!0},n.prototype._clearWatch=function(){t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0,this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this.options.showUserLocation&&this._updateMarker(null)},n}(t.Evented),qn={maxWidth:100,unit:\"metric\"},Hn=function(e){this.options=t.extend({},qn,e),t.bindAll([\"_onMove\",\"setUnit\"],this)};function Gn(t,e,r){var n,i,a,o,s,l,c=r&&r.maxWidth||100,u=t._container.clientHeight/2,h=(n=t.unproject([0,u]),i=t.unproject([c,u]),a=Math.PI/180,o=n.lat*a,s=i.lat*a,l=Math.sin(o)*Math.sin(s)+Math.cos(o)*Math.cos(s)*Math.cos((i.lng-n.lng)*a),6371e3*Math.acos(Math.min(l,1)));if(r&&\"imperial\"===r.unit){var f=3.2808*h;f>5280?Yn(e,c,f/5280,\"mi\"):Yn(e,c,f,\"ft\")}else r&&\"nautical\"===r.unit?Yn(e,c,h/1852,\"nm\"):Yn(e,c,h,\"m\")}function Yn(t,e,r,n){var i,a,o,s=(i=r,(a=Math.pow(10,(\"\"+Math.floor(i)).length-1))*(o=(o=i/a)>=10?10:o>=5?5:o>=3?3:o>=2?2:o>=1?1:function(t){var e=Math.pow(10,Math.ceil(-Math.log(t)/Math.LN10));return Math.round(t*e)/e}(o))),l=s/r;\"m\"===n&&s>=1e3&&(s/=1e3,n=\"km\"),t.style.width=e*l+\"px\",t.innerHTML=s+n}Hn.prototype.getDefaultPosition=function(){return\"bottom-left\"},Hn.prototype._onMove=function(){Gn(this._map,this._container,this.options)},Hn.prototype.onAdd=function(t){return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-scale\",t.getContainer()),this._map.on(\"move\",this._onMove),this._onMove(),this._container},Hn.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"move\",this._onMove),this._map=void 0},Hn.prototype.setUnit=function(t){this.options.unit=t,Gn(this._map,this._container,this.options)};var Wn=function(e){this._fullscreen=!1,e&&e.container&&(e.container instanceof t.window.HTMLElement?this._container=e.container:t.warnOnce(\"Full screen control 'container' must be a DOM element.\")),t.bindAll([\"_onClickFullscreen\",\"_changeIcon\"],this),\"onfullscreenchange\"in t.window.document?this._fullscreenchange=\"fullscreenchange\":\"onmozfullscreenchange\"in t.window.document?this._fullscreenchange=\"mozfullscreenchange\":\"onwebkitfullscreenchange\"in t.window.document?this._fullscreenchange=\"webkitfullscreenchange\":\"onmsfullscreenchange\"in t.window.document&&(this._fullscreenchange=\"MSFullscreenChange\"),this._className=\"mapboxgl-ctrl\"};Wn.prototype.onAdd=function(e){return this._map=e,this._container||(this._container=this._map.getContainer()),this._controlContainer=r.create(\"div\",this._className+\" mapboxgl-ctrl-group\"),this._checkFullscreenSupport()?this._setupUI():(this._controlContainer.style.display=\"none\",t.warnOnce(\"This device does not support fullscreen mode.\")),this._controlContainer},Wn.prototype.onRemove=function(){r.remove(this._controlContainer),this._map=null,t.window.document.removeEventListener(this._fullscreenchange,this._changeIcon)},Wn.prototype._checkFullscreenSupport=function(){return!!(t.window.document.fullscreenEnabled||t.window.document.mozFullScreenEnabled||t.window.document.msFullscreenEnabled||t.window.document.webkitFullscreenEnabled)},Wn.prototype._setupUI=function(){(this._fullscreenButton=r.create(\"button\",this._className+\"-icon \"+this._className+\"-fullscreen\",this._controlContainer)).type=\"button\",this._updateTitle(),this._fullscreenButton.addEventListener(\"click\",this._onClickFullscreen),t.window.document.addEventListener(this._fullscreenchange,this._changeIcon)},Wn.prototype._updateTitle=function(){var t=this._isFullscreen()?\"Exit fullscreen\":\"Enter fullscreen\";this._fullscreenButton.setAttribute(\"aria-label\",t),this._fullscreenButton.title=t},Wn.prototype._isFullscreen=function(){return this._fullscreen},Wn.prototype._changeIcon=function(){(t.window.document.fullscreenElement||t.window.document.mozFullScreenElement||t.window.document.webkitFullscreenElement||t.window.document.msFullscreenElement)===this._container!==this._fullscreen&&(this._fullscreen=!this._fullscreen,this._fullscreenButton.classList.toggle(this._className+\"-shrink\"),this._fullscreenButton.classList.toggle(this._className+\"-fullscreen\"),this._updateTitle())},Wn.prototype._onClickFullscreen=function(){this._isFullscreen()?t.window.document.exitFullscreen?t.window.document.exitFullscreen():t.window.document.mozCancelFullScreen?t.window.document.mozCancelFullScreen():t.window.document.msExitFullscreen?t.window.document.msExitFullscreen():t.window.document.webkitCancelFullScreen&&t.window.document.webkitCancelFullScreen():this._container.requestFullscreen?this._container.requestFullscreen():this._container.mozRequestFullScreen?this._container.mozRequestFullScreen():this._container.msRequestFullscreen?this._container.msRequestFullscreen():this._container.webkitRequestFullscreen&&this._container.webkitRequestFullscreen()};var Xn={closeButton:!0,closeOnClick:!0,className:\"\",maxWidth:\"240px\"},Zn=function(e){function n(r){e.call(this),this.options=t.extend(Object.create(Xn),r),t.bindAll([\"_update\",\"_onClickClose\",\"remove\"],this)}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.addTo=function(e){var r=this;return this._map=e,this.options.closeOnClick&&this._map.on(\"click\",this._onClickClose),this._map.on(\"remove\",this.remove),this._update(),this._trackPointer?(this._map.on(\"mousemove\",function(t){r._update(t.point)}),this._map.on(\"mouseup\",function(t){r._update(t.point)}),this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")):this._map.on(\"move\",this._update),this.fire(new t.Event(\"open\")),this},n.prototype.isOpen=function(){return!!this._map},n.prototype.remove=function(){return this._content&&r.remove(this._content),this._container&&(r.remove(this._container),delete this._container),this._map&&(this._map.off(\"move\",this._update),this._map.off(\"click\",this._onClickClose),this._map.off(\"remove\",this.remove),this._map.off(\"mousemove\"),delete this._map),this.fire(new t.Event(\"close\")),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._map&&(this._map.on(\"move\",this._update),this._map.off(\"mousemove\"),this._container.classList.remove(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.remove(\"mapboxgl-track-pointer\")),this._trackPointer=!1,this._update(),this},n.prototype.trackPointer=function(){var t=this;return this._trackPointer=!0,this._pos=null,this._map&&(this._map.off(\"move\",this._update),this._map.on(\"mousemove\",function(e){t._update(e.point)}),this._map.on(\"drag\",function(e){t._update(e.point)}),this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")),this},n.prototype.getElement=function(){return this._container},n.prototype.setText=function(e){return this.setDOMContent(t.window.document.createTextNode(e))},n.prototype.setHTML=function(e){var r,n=t.window.document.createDocumentFragment(),i=t.window.document.createElement(\"body\");for(i.innerHTML=e;r=i.firstChild;)n.appendChild(r);return this.setDOMContent(n)},n.prototype.getMaxWidth=function(){return this._container.style.maxWidth},n.prototype.setMaxWidth=function(t){return this.options.maxWidth=t,this._update(),this},n.prototype.setDOMContent=function(t){return this._createContent(),this._content.appendChild(t),this._update(),this},n.prototype._createContent=function(){this._content&&r.remove(this._content),this._content=r.create(\"div\",\"mapboxgl-popup-content\",this._container),this.options.closeButton&&(this._closeButton=r.create(\"button\",\"mapboxgl-popup-close-button\",this._content),this._closeButton.type=\"button\",this._closeButton.setAttribute(\"aria-label\",\"Close popup\"),this._closeButton.innerHTML=\"&#215;\",this._closeButton.addEventListener(\"click\",this._onClickClose))},n.prototype._update=function(e){var n=this,i=this._lngLat||this._trackPointer;if(this._map&&i&&this._content&&(this._container||(this._container=r.create(\"div\",\"mapboxgl-popup\",this._map.getContainer()),this._tip=r.create(\"div\",\"mapboxgl-popup-tip\",this._container),this._container.appendChild(this._content),this.options.className&&this.options.className.split(\" \").forEach(function(t){return n._container.classList.add(t)})),this.options.maxWidth&&this._container.style.maxWidth!==this.options.maxWidth&&(this._container.style.maxWidth=this.options.maxWidth),this._map.transform.renderWorldCopies&&!this._trackPointer&&(this._lngLat=Rn(this._lngLat,this._pos,this._map.transform)),!this._trackPointer||e)){var a=this._pos=this._trackPointer&&e?e:this._map.project(this._lngLat),o=this.options.anchor,s=function e(r){if(r){if(\"number\"==typeof r){var n=Math.round(Math.sqrt(.5*Math.pow(r,2)));return{center:new t.Point(0,0),top:new t.Point(0,r),\"top-left\":new t.Point(n,n),\"top-right\":new t.Point(-n,n),bottom:new t.Point(0,-r),\"bottom-left\":new t.Point(n,-n),\"bottom-right\":new t.Point(-n,-n),left:new t.Point(r,0),right:new t.Point(-r,0)}}if(r instanceof t.Point||Array.isArray(r)){var i=t.Point.convert(r);return{center:i,top:i,\"top-left\":i,\"top-right\":i,bottom:i,\"bottom-left\":i,\"bottom-right\":i,left:i,right:i}}return{center:t.Point.convert(r.center||[0,0]),top:t.Point.convert(r.top||[0,0]),\"top-left\":t.Point.convert(r[\"top-left\"]||[0,0]),\"top-right\":t.Point.convert(r[\"top-right\"]||[0,0]),bottom:t.Point.convert(r.bottom||[0,0]),\"bottom-left\":t.Point.convert(r[\"bottom-left\"]||[0,0]),\"bottom-right\":t.Point.convert(r[\"bottom-right\"]||[0,0]),left:t.Point.convert(r.left||[0,0]),right:t.Point.convert(r.right||[0,0])}}return e(new t.Point(0,0))}(this.options.offset);if(!o){var l,c=this._container.offsetWidth,u=this._container.offsetHeight;l=a.y+s.bottom.y<u?[\"top\"]:a.y>this._map.transform.height-u?[\"bottom\"]:[],a.x<c/2?l.push(\"left\"):a.x>this._map.transform.width-c/2&&l.push(\"right\"),o=0===l.length?\"bottom\":l.join(\"-\")}var h=a.add(s[o]).round();r.setTransform(this._container,Fn[o]+\" translate(\"+h.x+\"px,\"+h.y+\"px)\"),Bn(this._container,o,\"popup\")}},n.prototype._onClickClose=function(){this.remove()},n}(t.Evented),Jn={version:t.version,supported:e,setRTLTextPlugin:t.setRTLTextPlugin,Map:On,NavigationControl:Dn,GeolocateControl:Vn,AttributionControl:Mn,ScaleControl:Hn,FullscreenControl:Wn,Popup:Zn,Marker:jn,Style:De,LngLat:t.LngLat,LngLatBounds:t.LngLatBounds,Point:t.Point,MercatorCoordinate:t.MercatorCoordinate,Evented:t.Evented,config:t.config,get accessToken(){return t.config.ACCESS_TOKEN},set accessToken(e){t.config.ACCESS_TOKEN=e},get baseApiUrl(){return t.config.API_URL},set baseApiUrl(e){t.config.API_URL=e},get workerCount(){return zt.workerCount},set workerCount(t){zt.workerCount=t},get maxParallelImageRequests(){return t.config.MAX_PARALLEL_IMAGE_REQUESTS},set maxParallelImageRequests(e){t.config.MAX_PARALLEL_IMAGE_REQUESTS=e},clearStorage:function(e){t.clearTileCache(e)},workerUrl:\"\"};return Jn}),r},\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=i():(n=n||self).mapboxgl=i()},{}],427:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1<<t+1,r=new Array(e),n=0;n<e;++n)r[n]=a(t,n);return r};var n=t(\"convex-hull\");function i(t,e,r){for(var n=new Array(t),i=0;i<t;++i)n[i]=0,i===e&&(n[i]+=.5),i===r&&(n[i]+=.5);return n}function a(t,e){if(0===e||e===(1<<t+1)-1)return[];for(var r=[],a=[],o=0;o<=t;++o)if(e&1<<o){r.push(i(t,o-1,o-1)),a.push(null);for(var s=0;s<=t;++s)~e&1<<s&&(r.push(i(t,o-1,s-1)),a.push([o,s]))}var l=n(r),c=[];t:for(o=0;o<l.length;++o){var u=l[o],h=[];for(s=0;s<u.length;++s){if(!a[u[s]])continue t;h.push(a[u[s]].slice())}c.push(h)}return c}},{\"convex-hull\":130}],428:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"gl-mat4/create\"),a=t(\"gl-mat4/clone\"),o=t(\"gl-mat4/determinant\"),s=t(\"gl-mat4/invert\"),l=t(\"gl-mat4/transpose\"),c={length:t(\"gl-vec3/length\"),normalize:t(\"gl-vec3/normalize\"),dot:t(\"gl-vec3/dot\"),cross:t(\"gl-vec3/cross\")},u=i(),h=i(),f=[0,0,0,0],p=[[0,0,0],[0,0,0],[0,0,0]],d=[0,0,0];function g(t,e,r,n,i){t[0]=e[0]*n+r[0]*i,t[1]=e[1]*n+r[1]*i,t[2]=e[2]*n+r[2]*i}e.exports=function(t,e,r,i,v,m){if(e||(e=[0,0,0]),r||(r=[0,0,0]),i||(i=[0,0,0]),v||(v=[0,0,0,1]),m||(m=[0,0,0,1]),!n(u,t))return!1;if(a(h,u),h[3]=0,h[7]=0,h[11]=0,h[15]=1,Math.abs(o(h)<1e-8))return!1;var y,x,b,_,w,k,T,A=u[3],M=u[7],S=u[11],E=u[12],C=u[13],L=u[14],P=u[15];if(0!==A||0!==M||0!==S){if(f[0]=A,f[1]=M,f[2]=S,f[3]=P,!s(h,h))return!1;l(h,h),y=v,b=h,_=(x=f)[0],w=x[1],k=x[2],T=x[3],y[0]=b[0]*_+b[4]*w+b[8]*k+b[12]*T,y[1]=b[1]*_+b[5]*w+b[9]*k+b[13]*T,y[2]=b[2]*_+b[6]*w+b[10]*k+b[14]*T,y[3]=b[3]*_+b[7]*w+b[11]*k+b[15]*T}else v[0]=v[1]=v[2]=0,v[3]=1;if(e[0]=E,e[1]=C,e[2]=L,function(t,e){t[0][0]=e[0],t[0][1]=e[1],t[0][2]=e[2],t[1][0]=e[4],t[1][1]=e[5],t[1][2]=e[6],t[2][0]=e[8],t[2][1]=e[9],t[2][2]=e[10]}(p,u),r[0]=c.length(p[0]),c.normalize(p[0],p[0]),i[0]=c.dot(p[0],p[1]),g(p[1],p[1],p[0],1,-i[0]),r[1]=c.length(p[1]),c.normalize(p[1],p[1]),i[0]/=r[1],i[1]=c.dot(p[0],p[2]),g(p[2],p[2],p[0],1,-i[1]),i[2]=c.dot(p[1],p[2]),g(p[2],p[2],p[1],1,-i[2]),r[2]=c.length(p[2]),c.normalize(p[2],p[2]),i[1]/=r[2],i[2]/=r[2],c.cross(d,p[1],p[2]),c.dot(p[0],d)<0)for(var O=0;O<3;O++)r[O]*=-1,p[O][0]*=-1,p[O][1]*=-1,p[O][2]*=-1;return m[0]=.5*Math.sqrt(Math.max(1+p[0][0]-p[1][1]-p[2][2],0)),m[1]=.5*Math.sqrt(Math.max(1-p[0][0]+p[1][1]-p[2][2],0)),m[2]=.5*Math.sqrt(Math.max(1-p[0][0]-p[1][1]+p[2][2],0)),m[3]=.5*Math.sqrt(Math.max(1+p[0][0]+p[1][1]+p[2][2],0)),p[2][1]>p[1][2]&&(m[0]=-m[0]),p[0][2]>p[2][0]&&(m[1]=-m[1]),p[1][0]>p[0][1]&&(m[2]=-m[2]),!0}},{\"./normalize\":429,\"gl-mat4/clone\":259,\"gl-mat4/create\":260,\"gl-mat4/determinant\":261,\"gl-mat4/invert\":265,\"gl-mat4/transpose\":276,\"gl-vec3/cross\":334,\"gl-vec3/dot\":339,\"gl-vec3/length\":349,\"gl-vec3/normalize\":356}],429:[function(t,e,r){e.exports=function(t,e){var r=e[15];if(0===r)return!1;for(var n=1/r,i=0;i<16;i++)t[i]=e[i]*n;return!0}},{}],430:[function(t,e,r){var n=t(\"gl-vec3/lerp\"),i=t(\"mat4-recompose\"),a=t(\"mat4-decompose\"),o=t(\"gl-mat4/determinant\"),s=t(\"quat-slerp\"),l=h(),c=h(),u=h();function h(){return{translate:f(),scale:f(1),skew:f(),perspective:[0,0,0,1],quaternion:[0,0,0,1]}}function f(t){return[t||0,t||0,t||0]}e.exports=function(t,e,r,h){if(0===o(e)||0===o(r))return!1;var f=a(e,l.translate,l.scale,l.skew,l.perspective,l.quaternion),p=a(r,c.translate,c.scale,c.skew,c.perspective,c.quaternion);return!(!f||!p||(n(u.translate,l.translate,c.translate,h),n(u.skew,l.skew,c.skew,h),n(u.scale,l.scale,c.scale,h),n(u.perspective,l.perspective,c.perspective,h),s(u.quaternion,l.quaternion,c.quaternion,h),i(t,u.translate,u.scale,u.skew,u.perspective,u.quaternion),0))}},{\"gl-mat4/determinant\":261,\"gl-vec3/lerp\":350,\"mat4-decompose\":428,\"mat4-recompose\":431,\"quat-slerp\":483}],431:[function(t,e,r){var n={identity:t(\"gl-mat4/identity\"),translate:t(\"gl-mat4/translate\"),multiply:t(\"gl-mat4/multiply\"),create:t(\"gl-mat4/create\"),scale:t(\"gl-mat4/scale\"),fromRotationTranslation:t(\"gl-mat4/fromRotationTranslation\")},i=(n.create(),n.create());e.exports=function(t,e,r,a,o,s){return n.identity(t),n.fromRotationTranslation(t,s,e),t[3]=o[0],t[7]=o[1],t[11]=o[2],t[15]=o[3],n.identity(i),0!==a[2]&&(i[9]=a[2],n.multiply(t,t,i)),0!==a[1]&&(i[9]=0,i[8]=a[1],n.multiply(t,t,i)),0!==a[0]&&(i[8]=0,i[4]=a[0],n.multiply(t,t,i)),n.scale(t,t,r),t}},{\"gl-mat4/create\":260,\"gl-mat4/fromRotationTranslation\":263,\"gl-mat4/identity\":264,\"gl-mat4/multiply\":267,\"gl-mat4/scale\":274,\"gl-mat4/translate\":275}],432:[function(t,e,r){\"use strict\";e.exports=Math.log2||function(t){return Math.log(t)*Math.LOG2E}},{}],433:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"mat4-interpolate\"),a=t(\"gl-mat4/invert\"),o=t(\"gl-mat4/rotateX\"),s=t(\"gl-mat4/rotateY\"),l=t(\"gl-mat4/rotateZ\"),c=t(\"gl-mat4/lookAt\"),u=t(\"gl-mat4/translate\"),h=(t(\"gl-mat4/scale\"),t(\"gl-vec3/normalize\")),f=[0,0,0];function p(t){this._components=t.slice(),this._time=[0],this.prevMatrix=t.slice(),this.nextMatrix=t.slice(),this.computedMatrix=t.slice(),this.computedInverse=t.slice(),this.computedEye=[0,0,0],this.computedUp=[0,0,0],this.computedCenter=[0,0,0],this.computedRadius=[0],this._limits=[-1/0,1/0]}e.exports=function(t){return new p((t=t||{}).matrix||[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1])};var d=p.prototype;d.recalcMatrix=function(t){var e=this._time,r=n.le(e,t),o=this.computedMatrix;if(!(r<0)){var s=this._components;if(r===e.length-1)for(var l=16*r,c=0;c<16;++c)o[c]=s[l++];else{var u=e[r+1]-e[r],f=(l=16*r,this.prevMatrix),p=!0;for(c=0;c<16;++c)f[c]=s[l++];var d=this.nextMatrix;for(c=0;c<16;++c)d[c]=s[l++],p=p&&f[c]===d[c];if(u<1e-6||p)for(c=0;c<16;++c)o[c]=f[c];else i(o,f,d,(t-e[r])/u)}var g=this.computedUp;g[0]=o[1],g[1]=o[5],g[2]=o[9],h(g,g);var v=this.computedInverse;a(v,o);var m=this.computedEye,y=v[15];m[0]=v[12]/y,m[1]=v[13]/y,m[2]=v[14]/y;var x=this.computedCenter,b=Math.exp(this.computedRadius[0]);for(c=0;c<3;++c)x[c]=m[c]-o[2+4*c]*b}},d.idle=function(t){if(!(t<this.lastT())){for(var e=this._components,r=e.length-16,n=0;n<16;++n)e.push(e[r++]);this._time.push(t)}},d.flush=function(t){var e=n.gt(this._time,t)-2;e<0||(this._time.splice(0,e),this._components.splice(0,16*e))},d.lastT=function(){return this._time[this._time.length-1]},d.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||f,n=n||this.computedUp,this.setMatrix(t,c(this.computedMatrix,e,r,n));for(var i=0,a=0;a<3;++a)i+=Math.pow(r[a]-e[a],2);i=Math.log(Math.sqrt(i)),this.computedRadius[0]=i},d.rotate=function(t,e,r,n){this.recalcMatrix(t);var i=this.computedInverse;e&&s(i,i,e),r&&o(i,i,r),n&&l(i,i,n),this.setMatrix(t,a(this.computedMatrix,i))};var g=[0,0,0];d.pan=function(t,e,r,n){g[0]=-(e||0),g[1]=-(r||0),g[2]=-(n||0),this.recalcMatrix(t);var i=this.computedInverse;u(i,i,g),this.setMatrix(t,a(i,i))},d.translate=function(t,e,r,n){g[0]=e||0,g[1]=r||0,g[2]=n||0,this.recalcMatrix(t);var i=this.computedMatrix;u(i,i,g),this.setMatrix(t,i)},d.setMatrix=function(t,e){if(!(t<this.lastT())){this._time.push(t);for(var r=0;r<16;++r)this._components.push(e[r])}},d.setDistance=function(t,e){this.computedRadius[0]=e},d.setDistanceLimits=function(t,e){var r=this._limits;r[0]=t,r[1]=e},d.getDistanceLimits=function(t){var e=this._limits;return t?(t[0]=e[0],t[1]=e[1],t):e}},{\"binary-search-bounds\":91,\"gl-mat4/invert\":265,\"gl-mat4/lookAt\":266,\"gl-mat4/rotateX\":271,\"gl-mat4/rotateY\":272,\"gl-mat4/rotateZ\":273,\"gl-mat4/scale\":274,\"gl-mat4/translate\":275,\"gl-vec3/normalize\":356,\"mat4-interpolate\":430}],434:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<3){for(var r=new Array(e),i=0;i<e;++i)r[i]=i;return 2===e&&t[0][0]===t[1][0]&&t[0][1]===t[1][1]?[0]:r}for(var a=new Array(e),i=0;i<e;++i)a[i]=i;a.sort(function(e,r){var n=t[e][0]-t[r][0];return n||t[e][1]-t[r][1]});for(var o=[a[0],a[1]],s=[a[0],a[1]],i=2;i<e;++i){for(var l=a[i],c=t[l],u=o.length;u>1&&n(t[o[u-2]],t[o[u-1]],c)<=0;)u-=1,o.pop();for(o.push(l),u=s.length;u>1&&n(t[s[u-2]],t[s[u-1]],c)>=0;)u-=1,s.pop();s.push(l)}for(var r=new Array(s.length+o.length-2),h=0,i=0,f=o.length;i<f;++i)r[h++]=o[i];for(var p=s.length-2;p>0;--p)r[h++]=s[p];return r};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":510}],435:[function(t,e,r){\"use strict\";e.exports=function(t,e){e||(e=t,t=window);var r=0,i=0,a=0,o={shift:!1,alt:!1,control:!1,meta:!1},s=!1;function l(t){var e=!1;return\"altKey\"in t&&(e=e||t.altKey!==o.alt,o.alt=!!t.altKey),\"shiftKey\"in t&&(e=e||t.shiftKey!==o.shift,o.shift=!!t.shiftKey),\"ctrlKey\"in t&&(e=e||t.ctrlKey!==o.control,o.control=!!t.ctrlKey),\"metaKey\"in t&&(e=e||t.metaKey!==o.meta,o.meta=!!t.metaKey),e}function c(t,s){var c=n.x(s),u=n.y(s);\"buttons\"in s&&(t=0|s.buttons),(t!==r||c!==i||u!==a||l(s))&&(r=0|t,i=c||0,a=u||0,e&&e(r,i,a,o))}function u(t){c(0,t)}function h(){(r||i||a||o.shift||o.alt||o.meta||o.control)&&(i=a=0,r=0,o.shift=o.alt=o.control=o.meta=!1,e&&e(0,0,0,o))}function f(t){l(t)&&e&&e(r,i,a,o)}function p(t){0===n.buttons(t)?c(0,t):c(r,t)}function d(t){c(r|n.buttons(t),t)}function g(t){c(r&~n.buttons(t),t)}function v(){s||(s=!0,t.addEventListener(\"mousemove\",p),t.addEventListener(\"mousedown\",d),t.addEventListener(\"mouseup\",g),t.addEventListener(\"mouseleave\",u),t.addEventListener(\"mouseenter\",u),t.addEventListener(\"mouseout\",u),t.addEventListener(\"mouseover\",u),t.addEventListener(\"blur\",h),t.addEventListener(\"keyup\",f),t.addEventListener(\"keydown\",f),t.addEventListener(\"keypress\",f),t!==window&&(window.addEventListener(\"blur\",h),window.addEventListener(\"keyup\",f),window.addEventListener(\"keydown\",f),window.addEventListener(\"keypress\",f)))}v();var m={element:t};return Object.defineProperties(m,{enabled:{get:function(){return s},set:function(e){e?v():s&&(s=!1,t.removeEventListener(\"mousemove\",p),t.removeEventListener(\"mousedown\",d),t.removeEventListener(\"mouseup\",g),t.removeEventListener(\"mouseleave\",u),t.removeEventListener(\"mouseenter\",u),t.removeEventListener(\"mouseout\",u),t.removeEventListener(\"mouseover\",u),t.removeEventListener(\"blur\",h),t.removeEventListener(\"keyup\",f),t.removeEventListener(\"keydown\",f),t.removeEventListener(\"keypress\",f),t!==window&&(window.removeEventListener(\"blur\",h),window.removeEventListener(\"keyup\",f),window.removeEventListener(\"keydown\",f),window.removeEventListener(\"keypress\",f)))},enumerable:!0},buttons:{get:function(){return r},enumerable:!0},x:{get:function(){return i},enumerable:!0},y:{get:function(){return a},enumerable:!0},mods:{get:function(){return o},enumerable:!0}}),m};var n=t(\"mouse-event\")},{\"mouse-event\":437}],436:[function(t,e,r){var n={left:0,top:0};e.exports=function(t,e,r){e=e||t.currentTarget||t.srcElement,Array.isArray(r)||(r=[0,0]);var i=t.clientX||0,a=t.clientY||0,o=(s=e,s===window||s===document||s===document.body?n:s.getBoundingClientRect());var s;return r[0]=i-o.left,r[1]=a-o.top,r}},{}],437:[function(t,e,r){\"use strict\";function n(t){return t.target||t.srcElement||window}r.buttons=function(t){if(\"object\"==typeof t){if(\"buttons\"in t)return t.buttons;if(\"which\"in t){if(2===(e=t.which))return 4;if(3===e)return 2;if(e>0)return 1<<e-1}else if(\"button\"in t){var e;if(1===(e=t.button))return 4;if(2===e)return 2;if(e>=0)return 1<<e}}return 0},r.element=n,r.x=function(t){if(\"object\"==typeof t){if(\"offsetX\"in t)return t.offsetX;var e=n(t).getBoundingClientRect();return t.clientX-e.left}return 0},r.y=function(t){if(\"object\"==typeof t){if(\"offsetY\"in t)return t.offsetY;var e=n(t).getBoundingClientRect();return t.clientY-e.top}return 0}},{}],438:[function(t,e,r){\"use strict\";var n=t(\"to-px\");e.exports=function(t,e,r){\"function\"==typeof t&&(r=!!e,e=t,t=window);var i=n(\"ex\",t),a=function(t){r&&t.preventDefault();var n=t.deltaX||0,a=t.deltaY||0,o=t.deltaZ||0,s=t.deltaMode,l=1;switch(s){case 1:l=i;break;case 2:l=window.innerHeight}if(a*=l,o*=l,(n*=l)||a||o)return e(n,a,o,t)};return t.addEventListener(\"wheel\",a),a}},{\"to-px\":539}],439:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\");function i(t){return\"a\"+t}function a(t){return\"d\"+t}function o(t,e){return\"c\"+t+\"_\"+e}function s(t){return\"s\"+t}function l(t,e){return\"t\"+t+\"_\"+e}function c(t){return\"o\"+t}function u(t){return\"x\"+t}function h(t){return\"p\"+t}function f(t,e){return\"d\"+t+\"_\"+e}function p(t){return\"i\"+t}function d(t,e){return\"u\"+t+\"_\"+e}function g(t){return\"b\"+t}function v(t){return\"y\"+t}function m(t){return\"e\"+t}function y(t){return\"v\"+t}e.exports=function(t){function e(t){throw new Error(\"ndarray-extract-contour: \"+t)}\"object\"!=typeof t&&e(\"Must specify arguments\");var r=t.order;Array.isArray(r)||e(\"Must specify order\");var M=t.arrayArguments||1;M<1&&e(\"Must have at least one array argument\");var S=t.scalarArguments||0;S<0&&e(\"Scalar arg count must be > 0\");\"function\"!=typeof t.vertex&&e(\"Must specify vertex creation function\");\"function\"!=typeof t.cell&&e(\"Must specify cell creation function\");\"function\"!=typeof t.phase&&e(\"Must specify phase function\");for(var E=t.getters||[],C=new Array(M),L=0;L<M;++L)E.indexOf(L)>=0?C[L]=!0:C[L]=!1;return function(t,e,r,M,S,E){var C=E.length,L=S.length;if(L<2)throw new Error(\"ndarray-extract-contour: Dimension must be at least 2\");for(var P=\"extractContour\"+S.join(\"_\"),O=[],z=[],I=[],D=0;D<C;++D)I.push(i(D));for(var D=0;D<M;++D)I.push(u(D));for(var D=0;D<L;++D)z.push(s(D)+\"=\"+i(0)+\".shape[\"+D+\"]|0\");for(var D=0;D<C;++D){z.push(a(D)+\"=\"+i(D)+\".data\",c(D)+\"=\"+i(D)+\".offset|0\");for(var R=0;R<L;++R)z.push(l(D,R)+\"=\"+i(D)+\".stride[\"+R+\"]|0\")}for(var D=0;D<C;++D){z.push(h(D)+\"=\"+c(D)),z.push(o(D,0));for(var R=1;R<1<<L;++R){for(var F=[],B=0;B<L;++B)R&1<<B&&F.push(\"-\"+l(D,B));z.push(f(D,R)+\"=(\"+F.join(\"\")+\")|0\"),z.push(o(D,R)+\"=0\")}}for(var D=0;D<C;++D)for(var R=0;R<L;++R){var N=[l(D,S[R])];R>0&&N.push(l(D,S[R-1])+\"*\"+s(S[R-1])),z.push(d(D,S[R])+\"=(\"+N.join(\"-\")+\")|0\")}for(var D=0;D<L;++D)z.push(p(D)+\"=0\");z.push(_+\"=0\");for(var j=[\"2\"],D=L-2;D>=0;--D)j.push(s(S[D]));z.push(w+\"=(\"+j.join(\"*\")+\")|0\",b+\"=mallocUint32(\"+w+\")\",x+\"=mallocUint32(\"+w+\")\",k+\"=0\"),z.push(g(0)+\"=0\");for(var R=1;R<1<<L;++R){for(var U=[],V=[],B=0;B<L;++B)R&1<<B&&(0===V.length?U.push(\"1\"):U.unshift(V.join(\"*\"))),V.push(s(S[B]));var q=\"\";U[0].indexOf(s(S[L-2]))<0&&(q=\"-\");var H=A(L,R,S);z.push(m(H)+\"=(-\"+U.join(\"-\")+\")|0\",v(H)+\"=(\"+q+U.join(\"-\")+\")|0\",g(H)+\"=0\")}function G(t,e){O.push(\"for(\",p(S[t]),\"=\",e,\";\",p(S[t]),\"<\",s(S[t]),\";\",\"++\",p(S[t]),\"){\")}function Y(t){for(var e=0;e<C;++e)O.push(h(e),\"+=\",d(e,S[t]),\";\");O.push(\"}\")}function W(){for(var t=1;t<1<<L;++t)O.push(T,\"=\",m(t),\";\",m(t),\"=\",v(t),\";\",v(t),\"=\",T,\";\")}z.push(y(0)+\"=0\",T+\"=0\"),function t(e,r){if(e<0)return void function(t){for(var e=0;e<C;++e)E[e]?O.push(o(e,0),\"=\",a(e),\".get(\",h(e),\");\"):O.push(o(e,0),\"=\",a(e),\"[\",h(e),\"];\");for(var r=[],e=0;e<C;++e)r.push(o(e,0));for(var e=0;e<M;++e)r.push(u(e));O.push(g(0),\"=\",b,\"[\",k,\"]=phase(\",r.join(),\");\");for(var n=1;n<1<<L;++n)O.push(g(n),\"=\",b,\"[\",k,\"+\",m(n),\"];\");for(var i=[],n=1;n<1<<L;++n)i.push(\"(\"+g(0)+\"!==\"+g(n)+\")\");O.push(\"if(\",i.join(\"||\"),\"){\");for(var s=[],e=0;e<L;++e)s.push(p(e));for(var e=0;e<C;++e){s.push(o(e,0));for(var n=1;n<1<<L;++n)E[e]?O.push(o(e,n),\"=\",a(e),\".get(\",h(e),\"+\",f(e,n),\");\"):O.push(o(e,n),\"=\",a(e),\"[\",h(e),\"+\",f(e,n),\"];\"),s.push(o(e,n))}for(var e=0;e<1<<L;++e)s.push(g(e));for(var e=0;e<M;++e)s.push(u(e));O.push(\"vertex(\",s.join(),\");\",y(0),\"=\",x,\"[\",k,\"]=\",_,\"++;\");for(var l=(1<<L)-1,c=g(l),n=0;n<L;++n)if(0==(t&~(1<<n))){for(var d=l^1<<n,v=g(d),w=[],T=d;T>0;T=T-1&d)w.push(x+\"[\"+k+\"+\"+m(T)+\"]\");w.push(y(0));for(var T=0;T<C;++T)1&n?w.push(o(T,l),o(T,d)):w.push(o(T,d),o(T,l));1&n?w.push(c,v):w.push(v,c);for(var T=0;T<M;++T)w.push(u(T));O.push(\"if(\",c,\"!==\",v,\"){\",\"face(\",w.join(),\")}\")}O.push(\"}\",k,\"+=1;\")}(r);!function(t){for(var e=t-1;e>=0;--e)G(e,0);for(var r=[],e=0;e<C;++e)E[e]?r.push(a(e)+\".get(\"+h(e)+\")\"):r.push(a(e)+\"[\"+h(e)+\"]\");for(var e=0;e<M;++e)r.push(u(e));O.push(b,\"[\",k,\"++]=phase(\",r.join(),\");\");for(var e=0;e<t;++e)Y(e);for(var n=0;n<C;++n)O.push(h(n),\"+=\",d(n,S[t]),\";\")}(e);O.push(\"if(\",s(S[e]),\">0){\",p(S[e]),\"=1;\");t(e-1,r|1<<S[e]);for(var n=0;n<C;++n)O.push(h(n),\"+=\",d(n,S[e]),\";\");e===L-1&&(O.push(k,\"=0;\"),W());G(e,2);t(e-1,r);e===L-1&&(O.push(\"if(\",p(S[L-1]),\"&1){\",k,\"=0;}\"),W());Y(e);O.push(\"}\")}(L-1,0),O.push(\"freeUint32(\",x,\");freeUint32(\",b,\");\");var X=[\"'use strict';\",\"function \",P,\"(\",I.join(),\"){\",\"var \",z.join(),\";\",O.join(\"\"),\"}\",\"return \",P].join(\"\");return new Function(\"vertex\",\"face\",\"phase\",\"mallocUint32\",\"freeUint32\",X)(t,e,r,n.mallocUint32,n.freeUint32)}(t.vertex,t.cell,t.phase,S,r,C)};var x=\"V\",b=\"P\",_=\"N\",w=\"Q\",k=\"X\",T=\"T\";function A(t,e,r){for(var n=0,i=0;i<t;++i)e&1<<i&&(n|=1<<r[i]);return n}},{\"typedarray-pool\":545}],440:[function(t,e,r){\"use strict\";var n=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{_inline_1_arg1_=_inline_1_arg2_.apply(void 0,_inline_1_arg0_)}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"cwise\",blockSize:64});e.exports=function(t,e){return n(t,e),t}},{\"cwise/lib/wrapper\":149}],441:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(Array.isArray(r)){if(r.length!==e.dimension)throw new Error(\"ndarray-gradient: invalid boundary conditions\")}else r=n(e.dimension,\"string\"==typeof r?r:\"clamp\");if(t.dimension!==e.dimension+1)throw new Error(\"ndarray-gradient: output dimension must be +1 input dimension\");if(t.shape[e.dimension]!==e.dimension)throw new Error(\"ndarray-gradient: output shape must match input shape\");for(var i=0;i<e.dimension;++i)if(t.shape[i]!==e.shape[i])throw new Error(\"ndarray-gradient: shape mismatch\");if(0===e.size)return t;if(e.dimension<=0)return t.set(0),t;return function(t){var e=t.join();if(m=o[e])return m;var r=t.length,n=[\"function gradient(dst,src){var s=src.shape.slice();\"];function i(e){for(var i=r-e.length,a=[],o=[],s=[],l=0;l<r;++l)e.indexOf(l+1)>=0?s.push(\"0\"):e.indexOf(-(l+1))>=0?s.push(\"s[\"+l+\"]-1\"):(s.push(\"-1\"),a.push(\"1\"),o.push(\"s[\"+l+\"]-2\"));var c=\".lo(\"+a.join()+\").hi(\"+o.join()+\")\";if(0===a.length&&(c=\"\"),i>0){n.push(\"if(1\");for(var l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\"&&s[\",l,\"]>2\");n.push(\"){grad\",i,\"(src.pick(\",s.join(),\")\",c);for(var l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\",dst.pick(\",s.join(),\",\",l,\")\",c);n.push(\");\")}for(var l=0;l<e.length;++l){var u=Math.abs(e[l])-1,h=\"dst.pick(\"+s.join()+\",\"+u+\")\"+c;switch(t[u]){case\"clamp\":var f=s.slice(),p=s.slice();e[l]<0?f[u]=\"s[\"+u+\"]-2\":p[u]=\"1\",0===i?n.push(\"if(s[\",u,\"]>1){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",f.join(),\")-src.get(\",p.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>1){diff(\",h,\",src.pick(\",f.join(),\")\",c,\",src.pick(\",p.join(),\")\",c,\");}else{zero(\",h,\");};\");break;case\"mirror\":0===i?n.push(\"dst.set(\",s.join(),\",\",u,\",0);\"):n.push(\"zero(\",h,\");\");break;case\"wrap\":var d=s.slice(),g=s.slice();e[l]<0?(d[u]=\"s[\"+u+\"]-2\",g[u]=\"0\"):(d[u]=\"s[\"+u+\"]-1\",g[u]=\"1\"),0===i?n.push(\"if(s[\",u,\"]>2){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",d.join(),\")-src.get(\",g.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>2){diff(\",h,\",src.pick(\",d.join(),\")\",c,\",src.pick(\",g.join(),\")\",c,\");}else{zero(\",h,\");};\");break;default:throw new Error(\"ndarray-gradient: Invalid boundary condition\")}}i>0&&n.push(\"};\")}for(var s=0;s<1<<r;++s){for(var h=[],f=0;f<r;++f)s&1<<f&&h.push(f+1);for(var p=0;p<1<<h.length;++p){for(var d=h.slice(),f=0;f<h.length;++f)p&1<<f&&(d[f]=-d[f]);i(d)}}n.push(\"return dst;};return gradient\");for(var g=[\"diff\",\"zero\"],v=[l,c],s=1;s<=r;++s)g.push(\"grad\"+s),v.push(u(s));g.push(n.join(\"\"));var m=Function.apply(void 0,g).apply(void 0,v);return a[e]=m,m}(r)(t,e)};var n=t(\"dup\"),i=t(\"cwise-compiler\"),a={},o={},s={body:\"\",args:[],thisVars:[],localVars:[]},l=i({args:[\"array\",\"array\",\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1},{name:\"left\",lvalue:!1,rvalue:!0,count:1},{name:\"right\",lvalue:!1,rvalue:!0,count:1}],body:\"out=0.5*(left-right)\",thisVars:[],localVars:[]},funcName:\"cdiff\"}),c=i({args:[\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1}],body:\"out=0\",thisVars:[],localVars:[]},funcName:\"zero\"});function u(t){if(t in a)return a[t];for(var e=[],r=0;r<t;++r)e.push(\"out\",r,\"s=0.5*(inp\",r,\"l-inp\",r,\"r);\");var o=[\"array\"],l=[\"junk\"];for(r=0;r<t;++r){o.push(\"array\"),l.push(\"out\"+r+\"s\");var c=n(t);c[r]=-1,o.push({array:0,offset:c.slice()}),c[r]=1,o.push({array:0,offset:c.slice()}),l.push(\"inp\"+r+\"l\",\"inp\"+r+\"r\")}return a[t]=i({args:o,pre:s,post:s,body:{body:e.join(\"\"),args:l.map(function(t){return{name:t,lvalue:0===t.indexOf(\"out\"),rvalue:0===t.indexOf(\"inp\"),count:\"junk\"!==t|0}}),thisVars:[],localVars:[]},funcName:\"fdTemplate\"+t})}},{\"cwise-compiler\":146,dup:170}],442:[function(t,e,r){\"use strict\";var n=t(\"ndarray-warp\"),i=t(\"gl-matrix-invert\");e.exports=function(t,e,r){var a=e.dimension,o=i([],r);return n(t,e,function(t,e){for(var r=0;r<a;++r){t[r]=o[(a+1)*a+r];for(var n=0;n<a;++n)t[r]+=o[(a+1)*n+r]*e[n]}var i=o[(a+1)*(a+1)-1];for(n=0;n<a;++n)i+=o[(a+1)*n+a]*e[n];var s=1/i;for(r=0;r<a;++r)t[r]*=s;return t}),t}},{\"gl-matrix-invert\":277,\"ndarray-warp\":449}],443:[function(t,e,r){\"use strict\";function n(t,e){var r=Math.floor(e),n=e-r,i=0<=r&&r<t.shape[0],a=0<=r+1&&r+1<t.shape[0];return(1-n)*(i?+t.get(r):0)+n*(a?+t.get(r+1):0)}function i(t,e,r){var n=Math.floor(e),i=e-n,a=0<=n&&n<t.shape[0],o=0<=n+1&&n+1<t.shape[0],s=Math.floor(r),l=r-s,c=0<=s&&s<t.shape[1],u=0<=s+1&&s+1<t.shape[1],h=a&&c?t.get(n,s):0,f=a&&u?t.get(n,s+1):0;return(1-l)*((1-i)*h+i*(o&&c?t.get(n+1,s):0))+l*((1-i)*f+i*(o&&u?t.get(n+1,s+1):0))}function a(t,e,r,n){var i=Math.floor(e),a=e-i,o=0<=i&&i<t.shape[0],s=0<=i+1&&i+1<t.shape[0],l=Math.floor(r),c=r-l,u=0<=l&&l<t.shape[1],h=0<=l+1&&l+1<t.shape[1],f=Math.floor(n),p=n-f,d=0<=f&&f<t.shape[2],g=0<=f+1&&f+1<t.shape[2],v=o&&u&&d?t.get(i,l,f):0,m=o&&h&&d?t.get(i,l+1,f):0,y=s&&u&&d?t.get(i+1,l,f):0,x=s&&h&&d?t.get(i+1,l+1,f):0,b=o&&u&&g?t.get(i,l,f+1):0,_=o&&h&&g?t.get(i,l+1,f+1):0;return(1-p)*((1-c)*((1-a)*v+a*y)+c*((1-a)*m+a*x))+p*((1-c)*((1-a)*b+a*(s&&u&&g?t.get(i+1,l,f+1):0))+c*((1-a)*_+a*(s&&h&&g?t.get(i+1,l+1,f+1):0)))}e.exports=function(t,e,r,o){switch(t.shape.length){case 0:return 0;case 1:return n(t,e);case 2:return i(t,e,r);case 3:return a(t,e,r,o);default:return function(t){var e,r,n=0|t.shape.length,i=new Array(n),a=new Array(n),o=new Array(n),s=new Array(n);for(e=0;e<n;++e)r=+arguments[e+1],i[e]=Math.floor(r),a[e]=r-i[e],o[e]=0<=i[e]&&i[e]<t.shape[e],s[e]=0<=i[e]+1&&i[e]+1<t.shape[e];var l,c,u,h=0;t:for(e=0;e<1<<n;++e){for(c=1,u=t.offset,l=0;l<n;++l)if(e&1<<l){if(!s[l])continue t;c*=a[l],u+=t.stride[l]*(i[l]+1)}else{if(!o[l])continue t;c*=1-a[l],u+=t.stride[l]*i[l]}h+=c*t.data[u]}return h}.apply(void 0,arguments)}},e.exports.d1=n,e.exports.d2=i,e.exports.d3=a},{}],444:[function(t,e,r){\"use strict\";var n=t(\"cwise-compiler\"),i={body:\"\",args:[],thisVars:[],localVars:[]};function a(t){if(!t)return i;for(var e=0;e<t.args.length;++e){var r=t.args[e];t.args[e]=0===e?{name:r,lvalue:!0,rvalue:!!t.rvalue,count:t.count||1}:{name:r,lvalue:!1,rvalue:!0,count:1}}return t.thisVars||(t.thisVars=[]),t.localVars||(t.localVars=[]),t}function o(t){for(var e=[],r=0;r<t.args.length;++r)e.push(\"a\"+r);return new Function(\"P\",[\"return function \",t.funcName,\"_ndarrayops(\",e.join(\",\"),\") {P(\",e.join(\",\"),\");return a0}\"].join(\"\"))(function(t){return n({args:t.args,pre:a(t.pre),body:a(t.body),post:a(t.proc),funcName:t.funcName})}(t))}var s={add:\"+\",sub:\"-\",mul:\"*\",div:\"/\",mod:\"%\",band:\"&\",bor:\"|\",bxor:\"^\",lshift:\"<<\",rshift:\">>\",rrshift:\">>>\"};!function(){for(var t in s){var e=s[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a\"+e+\"=b\"},rvalue:!0,funcName:t+\"eq\"}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a\"+e+\"=s\"},rvalue:!0,funcName:t+\"seq\"})}}();var l={not:\"!\",bnot:\"~\",neg:\"-\",recip:\"1.0/\"};!function(){for(var t in l){var e=l[t];r[t]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=\"+e+\"b\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\"],body:{args:[\"a\"],body:\"a=\"+e+\"a\"},rvalue:!0,count:2,funcName:t+\"eq\"})}}();var c={and:\"&&\",or:\"||\",eq:\"===\",neq:\"!==\",lt:\"<\",gt:\">\",leq:\"<=\",geq:\">=\"};!function(){for(var t in c){var e=c[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=a\"+e+\"b\"},rvalue:!0,count:2,funcName:t+\"eq\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a=a\"+e+\"s\"},rvalue:!0,count:2,funcName:t+\"seq\"})}}();var u=[\"abs\",\"acos\",\"asin\",\"atan\",\"ceil\",\"cos\",\"exp\",\"floor\",\"log\",\"round\",\"sin\",\"sqrt\",\"tan\"];!function(){for(var t=0;t<u.length;++t){var e=u[t];r[e]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"eq\"]=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f(a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"})}}();var h=[\"max\",\"min\",\"atan2\",\"pow\"];!function(){for(var t=0;t<h.length;++t){var e=h[t];r[e]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e+\"s\"}),r[e+\"eq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"}),r[e+\"seq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"seq\"})}}();var f=[\"atan2\",\"pow\"];!function(){for(var t=0;t<f.length;++t){var e=f[t];r[e+\"op\"]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"op\"}),r[e+\"ops\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"ops\"}),r[e+\"opeq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opeq\"}),r[e+\"opseq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opseq\"})}}(),r.any=n({args:[\"array\"],pre:i,body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"if(a){return true}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return false\"},funcName:\"any\"}),r.all=n({args:[\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1}],body:\"if(!x){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"all\"}),r.sum=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s+=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"sum\"}),r.prod=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=1\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s*=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"prod\"}),r.norm2squared=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm2squared\"}),r.norm2=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return Math.sqrt(this_s)\"},funcName:\"norm2\"}),r.norminf=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:4}],body:\"if(-a>this_s){this_s=-a}else if(a>this_s){this_s=a}\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norminf\"}),r.norm1=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:3}],body:\"this_s+=a<0?-a:a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm1\"}),r.sup=n({args:[\"array\"],pre:{body:\"this_h=-Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_>this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.inf=n({args:[\"array\"],pre:{body:\"this_h=Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_<this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.argmin=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_<this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.argmax=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=-Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_>this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.random=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.random\",thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f()\",thisVars:[\"this_f\"]},funcName:\"random\"}),r.assign=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assign\"}),r.assigns=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assigns\"}),r.equals=n({args:[\"array\",\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1},{name:\"y\",lvalue:!1,rvalue:!0,count:1}],body:\"if(x!==y){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"equals\"})},{\"cwise-compiler\":146}],445:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"./doConvert.js\");e.exports=function(t,e){for(var r=[],a=t,o=1;Array.isArray(a);)r.push(a.length),o*=a.length,a=a[0];return 0===r.length?n():(e||(e=n(new Float64Array(o),r)),i(e,t),e)}},{\"./doConvert.js\":446,ndarray:450}],446:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\nvar _inline_1_v=_inline_1_arg1_,_inline_1_i\\nfor(_inline_1_i=0;_inline_1_i<_inline_1_arg2_.length-1;++_inline_1_i) {\\n_inline_1_v=_inline_1_v[_inline_1_arg2_[_inline_1_i]]\\n}\\n_inline_1_arg0_=_inline_1_v[_inline_1_arg2_[_inline_1_arg2_.length-1]]\\n}\",args:[{name:\"_inline_1_arg0_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:4}],thisVars:[],localVars:[\"_inline_1_i\",\"_inline_1_v\"]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},funcName:\"convert\",blockSize:64})},{\"cwise-compiler\":146}],447:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=32;function a(t){switch(t){case\"uint8\":return[n.mallocUint8,n.freeUint8];case\"uint16\":return[n.mallocUint16,n.freeUint16];case\"uint32\":return[n.mallocUint32,n.freeUint32];case\"int8\":return[n.mallocInt8,n.freeInt8];case\"int16\":return[n.mallocInt16,n.freeInt16];case\"int32\":return[n.mallocInt32,n.freeInt32];case\"float32\":return[n.mallocFloat,n.freeFloat];case\"float64\":return[n.mallocDouble,n.freeDouble];default:return null}}function o(t){for(var e=[],r=0;r<t;++r)e.push(\"s\"+r);for(r=0;r<t;++r)e.push(\"n\"+r);for(r=1;r<t;++r)e.push(\"d\"+r);for(r=1;r<t;++r)e.push(\"e\"+r);for(r=1;r<t;++r)e.push(\"f\"+r);return e}e.exports=function(t,e){var r=[\"'use strict'\"],n=[\"ndarraySortWrapper\",t.join(\"d\"),e].join(\"\");r.push([\"function \",n,\"(\",[\"array\"].join(\",\"),\"){\"].join(\"\"));for(var s=[\"data=array.data,offset=array.offset|0,shape=array.shape,stride=array.stride\"],l=0;l<t.length;++l)s.push([\"s\",l,\"=stride[\",l,\"]|0,n\",l,\"=shape[\",l,\"]|0\"].join(\"\"));var c=new Array(t.length),u=[];for(l=0;l<t.length;++l)0!==(p=t[l])&&(0===u.length?c[p]=\"1\":c[p]=u.join(\"*\"),u.push(\"n\"+p));var h=-1,f=-1;for(l=0;l<t.length;++l){var p,d=t[l];0!==d&&(h>0?s.push([\"d\",d,\"=s\",d,\"-d\",h,\"*n\",h].join(\"\")):s.push([\"d\",d,\"=s\",d].join(\"\")),h=d),0!=(p=t.length-1-l)&&(f>0?s.push([\"e\",p,\"=s\",p,\"-e\",f,\"*n\",f,\",f\",p,\"=\",c[p],\"-f\",f,\"*n\",f].join(\"\")):s.push([\"e\",p,\"=s\",p,\",f\",p,\"=\",c[p]].join(\"\")),f=p)}r.push(\"var \"+s.join(\",\"));var g=[\"0\",\"n0-1\",\"data\",\"offset\"].concat(o(t.length));r.push([\"if(n0<=\",i,\"){\",\"insertionSort(\",g.join(\",\"),\")}else{\",\"quickSort(\",g.join(\",\"),\")}\"].join(\"\")),r.push(\"}return \"+n);var v=new Function(\"insertionSort\",\"quickSort\",r.join(\"\\n\")),m=function(t,e){var r=[\"'use strict'\"],n=[\"ndarrayInsertionSort\",t.join(\"d\"),e].join(\"\"),i=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),s=a(e),l=[\"i,j,cptr,ptr=left*s0+offset\"];if(t.length>1){for(var c=[],u=1;u<t.length;++u)l.push(\"i\"+u),c.push(\"n\"+u);s?l.push(\"scratch=malloc(\"+c.join(\"*\")+\")\"):l.push(\"scratch=new Array(\"+c.join(\"*\")+\")\"),l.push(\"dptr\",\"sptr\",\"a\",\"b\")}else l.push(\"scratch\");function h(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function f(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}if(r.push([\"function \",n,\"(\",i.join(\",\"),\"){var \",l.join(\",\")].join(\"\"),\"for(i=left+1;i<=right;++i){\",\"j=i;ptr+=s0\",\"cptr=ptr\"),t.length>1){for(r.push(\"dptr=0;sptr=ptr\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(\"scratch[dptr++]=\",h(\"sptr\")),u=0;u<t.length;++u)0!==(p=t[u])&&r.push(\"sptr+=d\"+p,\"}\");for(r.push(\"__g:while(j--\\x3eleft){\",\"dptr=0\",\"sptr=cptr-s0\"),u=1;u<t.length;++u)1===u&&r.push(\"__l:\"),r.push([\"for(i\",u,\"=0;i\",u,\"<n\",u,\";++i\",u,\"){\"].join(\"\"));for(r.push([\"a=\",h(\"sptr\"),\"\\nb=scratch[dptr]\\nif(a<b){break __g}\\nif(a>b){break __l}\"].join(\"\")),u=t.length-1;u>=1;--u)r.push(\"sptr+=e\"+u,\"dptr+=f\"+u,\"}\");for(r.push(\"dptr=cptr;sptr=cptr-s0\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(f(\"dptr\",h(\"sptr\"))),u=0;u<t.length;++u)0!==(p=t[u])&&r.push([\"dptr+=d\",p,\";sptr+=d\",p].join(\"\"),\"}\");for(r.push(\"cptr-=s0\\n}\"),r.push(\"dptr=cptr;sptr=0\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(f(\"dptr\",\"scratch[sptr++]\")),u=0;u<t.length;++u){var p;0!==(p=t[u])&&r.push(\"dptr+=d\"+p,\"}\")}}else r.push(\"scratch=\"+h(\"ptr\"),\"while((j--\\x3eleft)&&(\"+h(\"cptr-s0\")+\">scratch)){\",f(\"cptr\",h(\"cptr-s0\")),\"cptr-=s0\",\"}\",f(\"cptr\",\"scratch\"));return r.push(\"}\"),t.length>1&&s&&r.push(\"free(scratch)\"),r.push(\"} return \"+n),s?new Function(\"malloc\",\"free\",r.join(\"\\n\"))(s[0],s[1]):new Function(r.join(\"\\n\"))()}(t,e),y=function(t,e,r){var n=[\"'use strict'\"],s=[\"ndarrayQuickSort\",t.join(\"d\"),e].join(\"\"),l=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),c=a(e),u=0;n.push([\"function \",s,\"(\",l.join(\",\"),\"){\"].join(\"\"));var h=[\"sixth=((right-left+1)/6)|0\",\"index1=left+sixth\",\"index5=right-sixth\",\"index3=(left+right)>>1\",\"index2=index3-sixth\",\"index4=index3+sixth\",\"el1=index1\",\"el2=index2\",\"el3=index3\",\"el4=index4\",\"el5=index5\",\"less=left+1\",\"great=right-1\",\"pivots_are_equal=true\",\"tmp\",\"tmp0\",\"x\",\"y\",\"z\",\"k\",\"ptr0\",\"ptr1\",\"ptr2\",\"comp_pivot1=0\",\"comp_pivot2=0\",\"comp=0\"];if(t.length>1){for(var f=[],p=1;p<t.length;++p)f.push(\"n\"+p),h.push(\"i\"+p);for(p=0;p<8;++p)h.push(\"b_ptr\"+p);h.push(\"ptr3\",\"ptr4\",\"ptr5\",\"ptr6\",\"ptr7\",\"pivot_ptr\",\"ptr_shift\",\"elementSize=\"+f.join(\"*\")),c?h.push(\"pivot1=malloc(elementSize)\",\"pivot2=malloc(elementSize)\"):h.push(\"pivot1=new Array(elementSize),pivot2=new Array(elementSize)\")}else h.push(\"pivot1\",\"pivot2\");function d(t){return[\"(offset+\",t,\"*s0)\"].join(\"\")}function g(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function v(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}function m(e,r,i){if(1===e.length)n.push(\"ptr0=\"+d(e[0]));else for(var a=0;a<e.length;++a)n.push([\"b_ptr\",a,\"=s0*\",e[a]].join(\"\"));for(r&&n.push(\"pivot_ptr=0\"),n.push(\"ptr_shift=offset\"),a=t.length-1;a>=0;--a)0!==(o=t[a])&&n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"));if(e.length>1)for(a=0;a<e.length;++a)n.push([\"ptr\",a,\"=b_ptr\",a,\"+ptr_shift\"].join(\"\"));for(n.push(i),r&&n.push(\"++pivot_ptr\"),a=0;a<t.length;++a){var o;0!==(o=t[a])&&(e.length>1?n.push(\"ptr_shift+=d\"+o):n.push(\"ptr0+=d\"+o),n.push(\"}\"))}}function y(e,r,i,a){if(1===r.length)n.push(\"ptr0=\"+d(r[0]));else{for(var o=0;o<r.length;++o)n.push([\"b_ptr\",o,\"=s0*\",r[o]].join(\"\"));n.push(\"ptr_shift=offset\")}for(i&&n.push(\"pivot_ptr=0\"),e&&n.push(e+\":\"),o=1;o<t.length;++o)n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"));if(r.length>1)for(o=0;o<r.length;++o)n.push([\"ptr\",o,\"=b_ptr\",o,\"+ptr_shift\"].join(\"\"));for(n.push(a),o=t.length-1;o>=1;--o)i&&n.push(\"pivot_ptr+=f\"+o),r.length>1?n.push(\"ptr_shift+=e\"+o):n.push(\"ptr0+=e\"+o),n.push(\"}\")}function x(){t.length>1&&c&&n.push(\"free(pivot1)\",\"free(pivot2)\")}function b(e,r){var i=\"el\"+e,a=\"el\"+r;if(t.length>1){var o=\"__l\"+ ++u;y(o,[i,a],!1,[\"comp=\",g(\"ptr0\"),\"-\",g(\"ptr1\"),\"\\n\",\"if(comp>0){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0;break \",o,\"}\\n\",\"if(comp<0){break \",o,\"}\"].join(\"\"))}else n.push([\"if(\",g(d(i)),\">\",g(d(a)),\"){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0}\"].join(\"\"))}function _(e,r){t.length>1?m([e,r],!1,v(\"ptr0\",g(\"ptr1\"))):n.push(v(d(e),g(d(r))))}function w(e,r,i){if(t.length>1){var a=\"__l\"+ ++u;y(a,[r],!0,[e,\"=\",g(\"ptr0\"),\"-pivot\",i,\"[pivot_ptr]\\n\",\"if(\",e,\"!==0){break \",a,\"}\"].join(\"\"))}else n.push([e,\"=\",g(d(r)),\"-pivot\",i].join(\"\"))}function k(e,r){t.length>1?m([e,r],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",\"tmp\")].join(\"\")):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",\"tmp\")].join(\"\"))}function T(e,r,i){t.length>1?(m([e,r,i],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",g(\"ptr2\")),\"\\n\",v(\"ptr2\",\"tmp\")].join(\"\")),n.push(\"++\"+r,\"--\"+i)):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"ptr2=\",d(i),\"\\n\",\"++\",r,\"\\n\",\"--\",i,\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",g(\"ptr2\")),\"\\n\",v(\"ptr2\",\"tmp\")].join(\"\"))}function A(t,e){k(t,e),n.push(\"--\"+e)}function M(e,r,i){t.length>1?m([e,r],!0,[v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",[\"pivot\",i,\"[pivot_ptr]\"].join(\"\"))].join(\"\")):n.push(v(d(e),g(d(r))),v(d(r),\"pivot\"+i))}function S(e,r){n.push([\"if((\",r,\"-\",e,\")<=\",i,\"){\\n\",\"insertionSort(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}else{\\n\",s,\"(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}\"].join(\"\"))}function E(e,r,i){t.length>1?(n.push([\"__l\",++u,\":while(true){\"].join(\"\")),m([e],!0,[\"if(\",g(\"ptr0\"),\"!==pivot\",r,\"[pivot_ptr]){break __l\",u,\"}\"].join(\"\")),n.push(i,\"}\")):n.push([\"while(\",g(d(e)),\"===pivot\",r,\"){\",i,\"}\"].join(\"\"))}return n.push(\"var \"+h.join(\",\")),b(1,2),b(4,5),b(1,3),b(2,3),b(1,4),b(3,4),b(2,5),b(2,3),b(4,5),t.length>1?m([\"el1\",\"el2\",\"el3\",\"el4\",\"el5\",\"index1\",\"index3\",\"index5\"],!0,[\"pivot1[pivot_ptr]=\",g(\"ptr1\"),\"\\n\",\"pivot2[pivot_ptr]=\",g(\"ptr3\"),\"\\n\",\"pivots_are_equal=pivots_are_equal&&(pivot1[pivot_ptr]===pivot2[pivot_ptr])\\n\",\"x=\",g(\"ptr0\"),\"\\n\",\"y=\",g(\"ptr2\"),\"\\n\",\"z=\",g(\"ptr4\"),\"\\n\",v(\"ptr5\",\"x\"),\"\\n\",v(\"ptr6\",\"y\"),\"\\n\",v(\"ptr7\",\"z\")].join(\"\")):n.push([\"pivot1=\",g(d(\"el2\")),\"\\n\",\"pivot2=\",g(d(\"el4\")),\"\\n\",\"pivots_are_equal=pivot1===pivot2\\n\",\"x=\",g(d(\"el1\")),\"\\n\",\"y=\",g(d(\"el3\")),\"\\n\",\"z=\",g(d(\"el5\")),\"\\n\",v(d(\"index1\"),\"x\"),\"\\n\",v(d(\"index3\"),\"y\"),\"\\n\",v(d(\"index5\"),\"z\")].join(\"\")),_(\"index2\",\"left\"),_(\"index4\",\"right\"),n.push(\"if(pivots_are_equal){\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp\",\"k\",1),n.push(\"if(comp===0){continue}\"),n.push(\"if(comp<0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),n.push(\"while(true){\"),w(\"comp\",\"great\",1),n.push(\"if(comp>0){\"),n.push(\"great--\"),n.push(\"}else if(comp<0){\"),T(\"k\",\"less\",\"great\"),n.push(\"break\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}else{\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1<0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2>0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp>0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),T(\"k\",\"less\",\"great\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),M(\"left\",\"(less-1)\",1),M(\"right\",\"(great+1)\",2),S(\"left\",\"(less-2)\"),S(\"(great+2)\",\"right\"),n.push(\"if(pivots_are_equal){\"),x(),n.push(\"return\"),n.push(\"}\"),n.push(\"if(less<index1&&great>index5){\"),E(\"less\",1,\"++less\"),E(\"great\",2,\"--great\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1===0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2===0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp===0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),T(\"k\",\"less\",\"great\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),x(),S(\"less\",\"great\"),n.push(\"}return \"+s),t.length>1&&c?new Function(\"insertionSort\",\"malloc\",\"free\",n.join(\"\\n\"))(r,c[0],c[1]):new Function(\"insertionSort\",n.join(\"\\n\"))(r)}(t,e,m);return v(m,y)}},{\"typedarray-pool\":545}],448:[function(t,e,r){\"use strict\";var n=t(\"./lib/compile_sort.js\"),i={};e.exports=function(t){var e=t.order,r=t.dtype,a=[e,r].join(\":\"),o=i[a];return o||(i[a]=o=n(e,r)),o(t),t}},{\"./lib/compile_sort.js\":447}],449:[function(t,e,r){\"use strict\";var n=t(\"ndarray-linear-interpolate\"),i=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=new Array(_inline_3_arg4_)}\",args:[{name:\"_inline_3_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg2_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg3_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_4_arg2_(this_warped,_inline_4_arg0_),_inline_4_arg1_=_inline_4_arg3_.apply(void 0,this_warped)}\",args:[{name:\"_inline_4_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_4_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg4_\",lvalue:!1,rvalue:!1,count:0}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warpND\",blockSize:64}),a=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_7_arg2_(this_warped,_inline_7_arg0_),_inline_7_arg1_=_inline_7_arg3_(_inline_7_arg4_,this_warped[0])}\",args:[{name:\"_inline_7_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_7_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp1D\",blockSize:64}),o=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0,0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_10_arg2_(this_warped,_inline_10_arg0_),_inline_10_arg1_=_inline_10_arg3_(_inline_10_arg4_,this_warped[0],this_warped[1])}\",args:[{name:\"_inline_10_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_10_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp2D\",blockSize:64}),s=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0,0,0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_13_arg2_(this_warped,_inline_13_arg0_),_inline_13_arg1_=_inline_13_arg3_(_inline_13_arg4_,this_warped[0],this_warped[1],this_warped[2])}\",args:[{name:\"_inline_13_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_13_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp3D\",blockSize:64});e.exports=function(t,e,r){switch(e.shape.length){case 1:a(t,r,n.d1,e);break;case 2:o(t,r,n.d2,e);break;case 3:s(t,r,n.d3,e);break;default:i(t,r,n.bind(void 0,e),e.shape.length)}return t}},{\"cwise/lib/wrapper\":149,\"ndarray-linear-interpolate\":443}],450:[function(t,e,r){var n=t(\"iota-array\"),i=t(\"is-buffer\"),a=\"undefined\"!=typeof Float64Array;function o(t,e){return t[0]-e[0]}function s(){var t,e=this.stride,r=new Array(e.length);for(t=0;t<r.length;++t)r[t]=[Math.abs(e[t]),t];r.sort(o);var n=new Array(r.length);for(t=0;t<n.length;++t)n[t]=r[t][1];return n}function l(t,e){var r=[\"View\",e,\"d\",t].join(\"\");e<0&&(r=\"View_Nil\"+t);var i=\"generic\"===t;if(-1===e){var a=\"function \"+r+\"(a){this.data=a;};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return -1};proto.size=0;proto.dimension=-1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function(){return new \"+r+\"(this.data);};proto.get=proto.set=function(){};proto.pick=function(){return null};return function construct_\"+r+\"(a){return new \"+r+\"(a);}\";return new Function(a)()}if(0===e){a=\"function \"+r+\"(a,d) {this.data = a;this.offset = d};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return this.offset};proto.dimension=0;proto.size=1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function \"+r+\"_copy() {return new \"+r+\"(this.data,this.offset)};proto.pick=function \"+r+\"_pick(){return TrivialArray(this.data);};proto.valueOf=proto.get=function \"+r+\"_get(){return \"+(i?\"this.data.get(this.offset)\":\"this.data[this.offset]\")+\"};proto.set=function \"+r+\"_set(v){return \"+(i?\"this.data.set(this.offset,v)\":\"this.data[this.offset]=v\")+\"};return function construct_\"+r+\"(a,b,c,d){return new \"+r+\"(a,d)}\";return new Function(\"TrivialArray\",a)(c[t][0])}a=[\"'use strict'\"];var o=n(e),l=o.map(function(t){return\"i\"+t}),u=\"this.offset+\"+o.map(function(t){return\"this.stride[\"+t+\"]*i\"+t}).join(\"+\"),h=o.map(function(t){return\"b\"+t}).join(\",\"),f=o.map(function(t){return\"c\"+t}).join(\",\");a.push(\"function \"+r+\"(a,\"+h+\",\"+f+\",d){this.data=a\",\"this.shape=[\"+h+\"]\",\"this.stride=[\"+f+\"]\",\"this.offset=d|0}\",\"var proto=\"+r+\".prototype\",\"proto.dtype='\"+t+\"'\",\"proto.dimension=\"+e),a.push(\"Object.defineProperty(proto,'size',{get:function \"+r+\"_size(){return \"+o.map(function(t){return\"this.shape[\"+t+\"]\"}).join(\"*\"),\"}})\"),1===e?a.push(\"proto.order=[0]\"):(a.push(\"Object.defineProperty(proto,'order',{get:\"),e<4?(a.push(\"function \"+r+\"_order(){\"),2===e?a.push(\"return (Math.abs(this.stride[0])>Math.abs(this.stride[1]))?[1,0]:[0,1]}})\"):3===e&&a.push(\"var s0=Math.abs(this.stride[0]),s1=Math.abs(this.stride[1]),s2=Math.abs(this.stride[2]);if(s0>s1){if(s1>s2){return [2,1,0];}else if(s0>s2){return [1,2,0];}else{return [1,0,2];}}else if(s0>s2){return [2,0,1];}else if(s2>s1){return [0,1,2];}else{return [0,2,1];}}})\")):a.push(\"ORDER})\")),a.push(\"proto.set=function \"+r+\"_set(\"+l.join(\",\")+\",v){\"),i?a.push(\"return this.data.set(\"+u+\",v)}\"):a.push(\"return this.data[\"+u+\"]=v}\"),a.push(\"proto.get=function \"+r+\"_get(\"+l.join(\",\")+\"){\"),i?a.push(\"return this.data.get(\"+u+\")}\"):a.push(\"return this.data[\"+u+\"]}\"),a.push(\"proto.index=function \"+r+\"_index(\",l.join(),\"){return \"+u+\"}\"),a.push(\"proto.hi=function \"+r+\"_hi(\"+l.join(\",\")+\"){return new \"+r+\"(this.data,\"+o.map(function(t){return[\"(typeof i\",t,\"!=='number'||i\",t,\"<0)?this.shape[\",t,\"]:i\",t,\"|0\"].join(\"\")}).join(\",\")+\",\"+o.map(function(t){return\"this.stride[\"+t+\"]\"}).join(\",\")+\",this.offset)}\");var p=o.map(function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"}),d=o.map(function(t){return\"c\"+t+\"=this.stride[\"+t+\"]\"});a.push(\"proto.lo=function \"+r+\"_lo(\"+l.join(\",\")+\"){var b=this.offset,d=0,\"+p.join(\",\")+\",\"+d.join(\",\"));for(var g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){d=i\"+g+\"|0;b+=c\"+g+\"*d;a\"+g+\"-=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map(function(t){return\"a\"+t}).join(\",\")+\",\"+o.map(function(t){return\"c\"+t}).join(\",\")+\",b)}\"),a.push(\"proto.step=function \"+r+\"_step(\"+l.join(\",\")+\"){var \"+o.map(function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"}).join(\",\")+\",\"+o.map(function(t){return\"b\"+t+\"=this.stride[\"+t+\"]\"}).join(\",\")+\",c=this.offset,d=0,ceil=Math.ceil\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'){d=i\"+g+\"|0;if(d<0){c+=b\"+g+\"*(a\"+g+\"-1);a\"+g+\"=ceil(-a\"+g+\"/d)}else{a\"+g+\"=ceil(a\"+g+\"/d)}b\"+g+\"*=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map(function(t){return\"a\"+t}).join(\",\")+\",\"+o.map(function(t){return\"b\"+t}).join(\",\")+\",c)}\");var v=new Array(e),m=new Array(e);for(g=0;g<e;++g)v[g]=\"a[i\"+g+\"]\",m[g]=\"b[i\"+g+\"]\";a.push(\"proto.transpose=function \"+r+\"_transpose(\"+l+\"){\"+l.map(function(t,e){return t+\"=(\"+t+\"===undefined?\"+e+\":\"+t+\"|0)\"}).join(\";\"),\"var a=this.shape,b=this.stride;return new \"+r+\"(this.data,\"+v.join(\",\")+\",\"+m.join(\",\")+\",this.offset)}\"),a.push(\"proto.pick=function \"+r+\"_pick(\"+l+\"){var a=[],b=[],c=this.offset\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){c=(c+this.stride[\"+g+\"]*i\"+g+\")|0}else{a.push(this.shape[\"+g+\"]);b.push(this.stride[\"+g+\"])}\");return a.push(\"var ctor=CTOR_LIST[a.length+1];return ctor(this.data,a,b,c)}\"),a.push(\"return function construct_\"+r+\"(data,shape,stride,offset){return new \"+r+\"(data,\"+o.map(function(t){return\"shape[\"+t+\"]\"}).join(\",\")+\",\"+o.map(function(t){return\"stride[\"+t+\"]\"}).join(\",\")+\",offset)}\"),new Function(\"CTOR_LIST\",\"ORDER\",a.join(\"\\n\"))(c[t],s)}var c={float32:[],float64:[],int8:[],int16:[],int32:[],uint8:[],uint16:[],uint32:[],array:[],uint8_clamped:[],buffer:[],generic:[]};e.exports=function(t,e,r,n){if(void 0===t)return(0,c.array[0])([]);\"number\"==typeof t&&(t=[t]),void 0===e&&(e=[t.length]);var o=e.length;if(void 0===r){r=new Array(o);for(var s=o-1,u=1;s>=0;--s)r[s]=u,u*=e[s]}if(void 0===n)for(n=0,s=0;s<o;++s)r[s]<0&&(n-=(e[s]-1)*r[s]);for(var h=function(t){if(i(t))return\"buffer\";if(a)switch(Object.prototype.toString.call(t)){case\"[object Float64Array]\":return\"float64\";case\"[object Float32Array]\":return\"float32\";case\"[object Int8Array]\":return\"int8\";case\"[object Int16Array]\":return\"int16\";case\"[object Int32Array]\":return\"int32\";case\"[object Uint8Array]\":return\"uint8\";case\"[object Uint16Array]\":return\"uint16\";case\"[object Uint32Array]\":return\"uint32\";case\"[object Uint8ClampedArray]\":return\"uint8_clamped\"}return Array.isArray(t)?\"array\":\"generic\"}(t),f=c[h];f.length<=o+1;)f.push(l(h,f.length-1));return(0,f[o+1])(t,e,r,n)}},{\"iota-array\":416,\"is-buffer\":418}],451:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=Math.pow(2,-1074),a=-1>>>0;e.exports=function(t,e){if(isNaN(t)||isNaN(e))return NaN;if(t===e)return t;if(0===t)return e<0?-i:i;var r=n.hi(t),o=n.lo(t);e>t==t>0?o===a?(r+=1,o=0):o+=1:0===o?(o=a,r-=1):o-=1;return n.pack(o,r)}},{\"double-bits\":167}],452:[function(t,e,r){var n=Math.PI,i=c(120);function a(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function o(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}function s(t,e,r,a,o,c,u,h,f,p){if(p)k=p[0],T=p[1],_=p[2],w=p[3];else{var d=l(t,e,-o);t=d.x,e=d.y;var g=(t-(h=(d=l(h,f,-o)).x))/2,v=(e-(f=d.y))/2,m=g*g/(r*r)+v*v/(a*a);m>1&&(r*=m=Math.sqrt(m),a*=m);var y=r*r,x=a*a,b=(c==u?-1:1)*Math.sqrt(Math.abs((y*x-y*v*v-x*g*g)/(y*v*v+x*g*g)));b==1/0&&(b=1);var _=b*r*v/a+(t+h)/2,w=b*-a*g/r+(e+f)/2,k=Math.asin(((e-w)/a).toFixed(9)),T=Math.asin(((f-w)/a).toFixed(9));(k=t<_?n-k:k)<0&&(k=2*n+k),(T=h<_?n-T:T)<0&&(T=2*n+T),u&&k>T&&(k-=2*n),!u&&T>k&&(T-=2*n)}if(Math.abs(T-k)>i){var A=T,M=h,S=f;T=k+i*(u&&T>k?1:-1);var E=s(h=_+r*Math.cos(T),f=w+a*Math.sin(T),r,a,o,0,u,M,S,[T,A,_,w])}var C=Math.tan((T-k)/4),L=4/3*r*C,P=4/3*a*C,O=[2*t-(t+L*Math.sin(k)),2*e-(e-P*Math.cos(k)),h+L*Math.sin(T),f-P*Math.cos(T),h,f];if(p)return O;E&&(O=O.concat(E));for(var z=0;z<O.length;){var I=l(O[z],O[z+1],o);O[z++]=I.x,O[z++]=I.y}return O}function l(t,e,r){return{x:t*Math.cos(r)-e*Math.sin(r),y:t*Math.sin(r)+e*Math.cos(r)}}function c(t){return t*(n/180)}e.exports=function(t){for(var e,r=[],n=0,i=0,l=0,u=0,h=null,f=null,p=0,d=0,g=0,v=t.length;g<v;g++){var m=t[g],y=m[0];switch(y){case\"M\":l=m[1],u=m[2];break;case\"A\":(m=s(p,d,m[1],m[2],c(m[3]),m[4],m[5],m[6],m[7])).unshift(\"C\"),m.length>7&&(r.push(m.splice(0,7)),m.unshift(\"C\"));break;case\"S\":var x=p,b=d;\"C\"!=e&&\"S\"!=e||(x+=x-n,b+=b-i),m=[\"C\",x,b,m[1],m[2],m[3],m[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(h=2*p-h,f=2*d-f):(h=p,f=d),m=o(p,d,h,f,m[1],m[2]);break;case\"Q\":h=m[1],f=m[2],m=o(p,d,m[1],m[2],m[3],m[4]);break;case\"L\":m=a(p,d,m[1],m[2]);break;case\"H\":m=a(p,d,m[1],d);break;case\"V\":m=a(p,d,p,m[1]);break;case\"Z\":m=a(p,d,l,u)}e=y,p=m[m.length-2],d=m[m.length-1],m.length>4?(n=m[m.length-4],i=m[m.length-3]):(n=p,i=d),r.push(m)}return r}},{}],453:[function(t,e,r){r.vertexNormals=function(t,e,r){for(var n=e.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o)i[o]=[0,0,0];for(o=0;o<t.length;++o)for(var s=t[o],l=0,c=s[s.length-1],u=s[0],h=0;h<s.length;++h){l=c,c=u,u=s[(h+1)%s.length];for(var f=e[l],p=e[c],d=e[u],g=new Array(3),v=0,m=new Array(3),y=0,x=0;x<3;++x)g[x]=f[x]-p[x],v+=g[x]*g[x],m[x]=d[x]-p[x],y+=m[x]*m[x];if(v*y>a){var b=i[c],_=1/Math.sqrt(v*y);for(x=0;x<3;++x){var w=(x+1)%3,k=(x+2)%3;b[x]+=_*(m[w]*g[k]-m[k]*g[w])}}}for(o=0;o<n;++o){b=i[o];var T=0;for(x=0;x<3;++x)T+=b[x]*b[x];if(T>a)for(_=1/Math.sqrt(T),x=0;x<3;++x)b[x]*=_;else for(x=0;x<3;++x)b[x]=0}return i},r.faceNormals=function(t,e,r){for(var n=t.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o){for(var s=t[o],l=new Array(3),c=0;c<3;++c)l[c]=e[s[c]];var u=new Array(3),h=new Array(3);for(c=0;c<3;++c)u[c]=l[1][c]-l[0][c],h[c]=l[2][c]-l[0][c];var f=new Array(3),p=0;for(c=0;c<3;++c){var d=(c+1)%3,g=(c+2)%3;f[c]=u[d]*h[g]-u[g]*h[d],p+=f[c]*f[c]}p=p>a?1/Math.sqrt(p):0;for(c=0;c<3;++c)f[c]*=p;i[o]=f}return i}},{}],454:[function(t,e,r){\"use strict\";var n=Object.getOwnPropertySymbols,i=Object.prototype.hasOwnProperty,a=Object.prototype.propertyIsEnumerable;e.exports=function(){try{if(!Object.assign)return!1;var t=new String(\"abc\");if(t[5]=\"de\",\"5\"===Object.getOwnPropertyNames(t)[0])return!1;for(var e={},r=0;r<10;r++)e[\"_\"+String.fromCharCode(r)]=r;if(\"0123456789\"!==Object.getOwnPropertyNames(e).map(function(t){return e[t]}).join(\"\"))return!1;var n={};return\"abcdefghijklmnopqrst\".split(\"\").forEach(function(t){n[t]=t}),\"abcdefghijklmnopqrst\"===Object.keys(Object.assign({},n)).join(\"\")}catch(t){return!1}}()?Object.assign:function(t,e){for(var r,o,s=function(t){if(null==t)throw new TypeError(\"Object.assign cannot be called with null or undefined\");return Object(t)}(t),l=1;l<arguments.length;l++){for(var c in r=Object(arguments[l]))i.call(r,c)&&(s[c]=r[c]);if(n){o=n(r);for(var u=0;u<o.length;u++)a.call(r,o[u])&&(s[o[u]]=r[o[u]])}}return s}},{}],455:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a,o,s,l,c){var u=e+a+c;if(h>0){var h=Math.sqrt(u+1);t[0]=.5*(o-l)/h,t[1]=.5*(s-n)/h,t[2]=.5*(r-a)/h,t[3]=.5*h}else{var f=Math.max(e,a,c),h=Math.sqrt(2*f-u+1);e>=f?(t[0]=.5*h,t[1]=.5*(i+r)/h,t[2]=.5*(s+n)/h,t[3]=.5*(o-l)/h):a>=f?(t[0]=.5*(r+i)/h,t[1]=.5*h,t[2]=.5*(l+o)/h,t[3]=.5*(s-n)/h):(t[0]=.5*(n+s)/h,t[1]=.5*(o+l)/h,t[2]=.5*h,t[3]=.5*(r-i)/h)}return t}},{}],456:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.rotation||[0,0,0,1],n=t.radius||1;e=[].slice.call(e,0,3),u(r=[].slice.call(r,0,4),r);var i=new h(r,e,Math.log(n));i.setDistanceLimits(t.zoomMin,t.zoomMax),(\"eye\"in t||\"up\"in t)&&i.lookAt(0,t.eye,t.center,t.up);return i};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/lookAt\"),a=t(\"gl-mat4/fromQuat\"),o=t(\"gl-mat4/invert\"),s=t(\"./lib/quatFromFrame\");function l(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function c(t,e,r,n){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2)+Math.pow(n,2))}function u(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=c(r,n,i,a);o>1e-6?(t[0]=r/o,t[1]=n/o,t[2]=i/o,t[3]=a/o):(t[0]=t[1]=t[2]=0,t[3]=1)}function h(t,e,r){this.radius=n([r]),this.center=n(e),this.rotation=n(t),this.computedRadius=this.radius.curve(0),this.computedCenter=this.center.curve(0),this.computedRotation=this.rotation.curve(0),this.computedUp=[.1,0,0],this.computedEye=[.1,0,0],this.computedMatrix=[.1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],this.recalcMatrix(0)}var f=h.prototype;f.lastT=function(){return Math.max(this.radius.lastT(),this.center.lastT(),this.rotation.lastT())},f.recalcMatrix=function(t){this.radius.curve(t),this.center.curve(t),this.rotation.curve(t);var e=this.computedRotation;u(e,e);var r=this.computedMatrix;a(r,e);var n=this.computedCenter,i=this.computedEye,o=this.computedUp,s=Math.exp(this.computedRadius[0]);i[0]=n[0]+s*r[2],i[1]=n[1]+s*r[6],i[2]=n[2]+s*r[10],o[0]=r[1],o[1]=r[5],o[2]=r[9];for(var l=0;l<3;++l){for(var c=0,h=0;h<3;++h)c+=r[l+4*h]*i[h];r[12+l]=-c}},f.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r},f.idle=function(t){this.center.idle(t),this.radius.idle(t),this.rotation.idle(t)},f.flush=function(t){this.center.flush(t),this.radius.flush(t),this.rotation.flush(t)},f.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=i[1],o=i[5],s=i[9],c=l(a,o,s);a/=c,o/=c,s/=c;var u=i[0],h=i[4],f=i[8],p=u*a+h*o+f*s,d=l(u-=a*p,h-=o*p,f-=s*p);u/=d,h/=d,f/=d;var g=i[2],v=i[6],m=i[10],y=g*a+v*o+m*s,x=g*u+v*h+m*f,b=l(g-=y*a+x*u,v-=y*o+x*h,m-=y*s+x*f);g/=b,v/=b,m/=b;var _=u*e+a*r,w=h*e+o*r,k=f*e+s*r;this.center.move(t,_,w,k);var T=Math.exp(this.computedRadius[0]);T=Math.max(1e-4,T+n),this.radius.set(t,Math.log(T))},f.rotate=function(t,e,r,n){this.recalcMatrix(t),e=e||0,r=r||0;var i=this.computedMatrix,a=i[0],o=i[4],s=i[8],u=i[1],h=i[5],f=i[9],p=i[2],d=i[6],g=i[10],v=e*a+r*u,m=e*o+r*h,y=e*s+r*f,x=-(d*y-g*m),b=-(g*v-p*y),_=-(p*m-d*v),w=Math.sqrt(Math.max(0,1-Math.pow(x,2)-Math.pow(b,2)-Math.pow(_,2))),k=c(x,b,_,w);k>1e-6?(x/=k,b/=k,_/=k,w/=k):(x=b=_=0,w=1);var T=this.computedRotation,A=T[0],M=T[1],S=T[2],E=T[3],C=A*w+E*x+M*_-S*b,L=M*w+E*b+S*x-A*_,P=S*w+E*_+A*b-M*x,O=E*w-A*x-M*b-S*_;if(n){x=p,b=d,_=g;var z=Math.sin(n)/l(x,b,_);x*=z,b*=z,_*=z,O=O*(w=Math.cos(e))-(C=C*w+O*x+L*_-P*b)*x-(L=L*w+O*b+P*x-C*_)*b-(P=P*w+O*_+C*b-L*x)*_}var I=c(C,L,P,O);I>1e-6?(C/=I,L/=I,P/=I,O/=I):(C=L=P=0,O=1),this.rotation.set(t,C,L,P,O)},f.lookAt=function(t,e,r,n){this.recalcMatrix(t),r=r||this.computedCenter,e=e||this.computedEye,n=n||this.computedUp;var a=this.computedMatrix;i(a,e,r,n);var o=this.computedRotation;s(o,a[0],a[1],a[2],a[4],a[5],a[6],a[8],a[9],a[10]),u(o,o),this.rotation.set(t,o[0],o[1],o[2],o[3]);for(var l=0,c=0;c<3;++c)l+=Math.pow(r[c]-e[c],2);this.radius.set(t,.5*Math.log(Math.max(l,1e-6))),this.center.set(t,r[0],r[1],r[2])},f.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},f.setMatrix=function(t,e){var r=this.computedRotation;s(r,e[0],e[1],e[2],e[4],e[5],e[6],e[8],e[9],e[10]),u(r,r),this.rotation.set(t,r[0],r[1],r[2],r[3]);var n=this.computedMatrix;o(n,e);var i=n[15];if(Math.abs(i)>1e-6){var a=n[12]/i,l=n[13]/i,c=n[14]/i;this.recalcMatrix(t);var h=Math.exp(this.computedRadius[0]);this.center.set(t,a-n[2]*h,l-n[6]*h,c-n[10]*h),this.radius.idle(t)}else this.center.idle(t),this.radius.idle(t)},f.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},f.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},f.getDistanceLimits=function(t){var e=this.radius.bounds;return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},f.toJSON=function(){return this.recalcMatrix(this.lastT()),{center:this.computedCenter.slice(),rotation:this.computedRotation.slice(),distance:Math.log(this.computedRadius[0]),zoomMin:this.radius.bounds[0][0],zoomMax:this.radius.bounds[1][0]}},f.fromJSON=function(t){var e=this.lastT(),r=t.center;r&&this.center.set(e,r[0],r[1],r[2]);var n=t.rotation;n&&this.rotation.set(e,n[0],n[1],n[2],n[3]);var i=t.distance;i&&i>0&&this.radius.set(e,Math.log(i)),this.setDistanceLimits(t.zoomMin,t.zoomMax)}},{\"./lib/quatFromFrame\":455,\"filtered-vector\":226,\"gl-mat4/fromQuat\":262,\"gl-mat4/invert\":265,\"gl-mat4/lookAt\":266}],457:[function(t,e,r){\"use strict\";var n=t(\"repeat-string\");e.exports=function(t,e,r){return n(r=\"undefined\"!=typeof r?r+\"\":\" \",e)+t}},{\"repeat-string\":503}],458:[function(t,e,r){\"use strict\";function n(t,e){if(\"string\"!=typeof t)return[t];var r=[t];\"string\"==typeof e||Array.isArray(e)?e={brackets:e}:e||(e={});var n=e.brackets?Array.isArray(e.brackets)?e.brackets:[e.brackets]:[\"{}\",\"[]\",\"()\"],i=e.escape||\"___\",a=!!e.flat;n.forEach(function(t){var e=new RegExp([\"\\\\\",t[0],\"[^\\\\\",t[0],\"\\\\\",t[1],\"]*\\\\\",t[1]].join(\"\")),n=[];function a(e,a,o){var s=r.push(e.slice(t[0].length,-t[1].length))-1;return n.push(s),i+s+i}r.forEach(function(t,n){for(var i,o=0;t!=i;)if(i=t,t=t.replace(e,a),o++>1e4)throw Error(\"References have circular dependency. Please, check them.\");r[n]=t}),n=n.reverse(),r=r.map(function(e){return n.forEach(function(r){e=e.replace(new RegExp(\"(\\\\\"+i+r+\"\\\\\"+i+\")\",\"g\"),t[0]+\"$1\"+t[1])}),e})});var o=new RegExp(\"\\\\\"+i+\"([0-9]+)\\\\\"+i);return a?r:function t(e,r,n){for(var i,a=[],s=0;i=o.exec(e);){if(s++>1e4)throw Error(\"Circular references in parenthesis\");a.push(e.slice(0,i.index)),a.push(t(r[i[1]],r)),e=e.slice(i.index+i[0].length)}return a.push(e),a}(r[0],r)}function i(t,e){if(e&&e.flat){var r,n=e&&e.escape||\"___\",i=t[0];if(!i)return\"\";for(var a=new RegExp(\"\\\\\"+n+\"([0-9]+)\\\\\"+n),o=0;i!=r;){if(o++>1e4)throw Error(\"Circular references in \"+t);r=i,i=i.replace(a,s)}return i}return t.reduce(function t(e,r){return Array.isArray(r)&&(r=r.reduce(t,\"\")),e+r},\"\");function s(e,r){if(null==t[r])throw Error(\"Reference \"+r+\"is undefined\");return t[r]}}function a(t,e){return Array.isArray(t)?i(t,e):n(t,e)}a.parse=n,a.stringify=i,e.exports=a},{}],459:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\");e.exports=function(t){var e;arguments.length>1&&(t=arguments);\"string\"==typeof t?t=t.split(/\\s/).map(parseFloat):\"number\"==typeof t&&(t=[t]);t.length&&\"number\"==typeof t[0]?e=1===t.length?{width:t[0],height:t[0],x:0,y:0}:2===t.length?{width:t[0],height:t[1],x:0,y:0}:{x:t[0],y:t[1],width:t[2]-t[0]||0,height:t[3]-t[1]||0}:t&&(t=n(t,{left:\"x l left Left\",top:\"y t top Top\",width:\"w width W Width\",height:\"h height W Width\",bottom:\"b bottom Bottom\",right:\"r right Right\"}),e={x:t.left||0,y:t.top||0},null==t.width?t.right?e.width=t.right-e.x:e.width=0:e.width=t.width,null==t.height?t.bottom?e.height=t.bottom-e.y:e.height=0:e.height=t.height);return e}},{\"pick-by-alias\":465}],460:[function(t,e,r){e.exports=function(t){var e=[];return t.replace(i,function(t,r,i){var o=r.toLowerCase();for(i=function(t){var e=t.match(a);return e?e.map(Number):[]}(i),\"m\"==o&&i.length>2&&(e.push([r].concat(i.splice(0,2))),o=\"l\",r=\"m\"==r?\"l\":\"L\");;){if(i.length==n[o])return i.unshift(r),e.push(i);if(i.length<n[o])throw new Error(\"malformed path data\");e.push([r].concat(i.splice(0,n[o])))}}),e};var n={a:7,c:6,h:1,l:2,m:2,q:4,s:4,t:2,v:1,z:0},i=/([astvzqmhlc])([^astvzqmhlc]*)/gi;var a=/-?[0-9]*\\.?[0-9]+(?:e[-+]?\\d+)?/gi},{}],461:[function(t,e,r){e.exports=function(t,e){e||(e=[0,\"\"]),t=String(t);var r=parseFloat(t,10);return e[0]=r,e[1]=t.match(/[\\d.\\-\\+]*\\s*(.*)/)[1]||\"\",e}},{}],462:[function(t,e,r){(function(t){(function(){var r,n,i,a,o,s;\"undefined\"!=typeof performance&&null!==performance&&performance.now?e.exports=function(){return performance.now()}:\"undefined\"!=typeof t&&null!==t&&t.hrtime?(e.exports=function(){return(r()-o)/1e6},n=t.hrtime,a=(r=function(){var t;return 1e9*(t=n())[0]+t[1]})(),s=1e9*t.uptime(),o=a-s):Date.now?(e.exports=function(){return Date.now()-i},i=Date.now()):(e.exports=function(){return(new Date).getTime()-i},i=(new Date).getTime())}).call(this)}).call(this,t(\"_process\"))},{_process:482}],463:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<n){for(var r=1,a=0;a<e;++a)for(var o=0;o<a;++o)if(t[a]<t[o])r=-r;else if(t[a]===t[o])return 0;return r}for(var s=i.mallocUint8(e),a=0;a<e;++a)s[a]=0;for(var r=1,a=0;a<e;++a)if(!s[a]){var l=1;s[a]=1;for(var o=t[a];o!==a;o=t[o]){if(s[o])return i.freeUint8(s),0;l+=1,s[o]=1}1&l||(r=-r)}return i.freeUint8(s),r};var n=32,i=t(\"typedarray-pool\")},{\"typedarray-pool\":545}],464:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"invert-permutation\");r.rank=function(t){var e=t.length;switch(e){case 0:case 1:return 0;case 2:return t[1]}var r,a,o,s=n.mallocUint32(e),l=n.mallocUint32(e),c=0;for(i(t,l),o=0;o<e;++o)s[o]=t[o];for(o=e-1;o>0;--o)a=l[o],r=s[o],s[o]=s[a],s[a]=r,l[o]=l[r],l[r]=a,c=(c+r)*o;return n.freeUint32(l),n.freeUint32(s),c},r.unrank=function(t,e,r){switch(t){case 0:return r||[];case 1:return r?(r[0]=0,r):[0];case 2:return r?(e?(r[0]=0,r[1]=1):(r[0]=1,r[1]=0),r):e?[0,1]:[1,0]}var n,i,a,o=1;for((r=r||new Array(t))[0]=0,a=1;a<t;++a)r[a]=a,o=o*a|0;for(a=t-1;a>0;--a)e=e-(n=e/o|0)*o|0,o=o/a|0,i=0|r[a],r[a]=0|r[n],r[n]=0|i;return r}},{\"invert-permutation\":415,\"typedarray-pool\":545}],465:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n,a,o={};if(\"string\"==typeof e&&(e=i(e)),Array.isArray(e)){var s={};for(a=0;a<e.length;a++)s[e[a]]=!0;e=s}for(n in e)e[n]=i(e[n]);var l={};for(n in e){var c=e[n];if(Array.isArray(c))for(a=0;a<c.length;a++){var u=c[a];if(r&&(l[u]=!0),u in t){if(o[n]=t[u],r)for(var h=a;h<c.length;h++)l[c[h]]=!0;break}}else n in t&&(e[n]&&(o[n]=t[n]),r&&(l[n]=!0))}if(r)for(n in t)l[n]||(o[n]=t[n]);return o};var n={};function i(t){return n[t]?n[t]:(\"string\"==typeof t&&(t=n[t]=t.split(/\\s*,\\s*|\\s+/)),t)}},{}],466:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=0|e.length,i=t.length,a=[new Array(r),new Array(r)],o=0;o<r;++o)a[0][o]=[],a[1][o]=[];for(var o=0;o<i;++o){var s=t[o];a[0][s[0]].push(s),a[1][s[1]].push(s)}for(var l=[],o=0;o<r;++o)a[0][o].length+a[1][o].length===0&&l.push([o]);function c(t,e){var r=a[e][t[e]];r.splice(r.indexOf(t),1)}function u(t,r,i){for(var o,s,l,u=0;u<2;++u)if(a[u][r].length>0){o=a[u][r][0],l=u;break}s=o[1^l];for(var h=0;h<2;++h)for(var f=a[h][r],p=0;p<f.length;++p){var d=f[p],g=d[1^h],v=n(e[t],e[r],e[s],e[g]);v>0&&(o=d,s=g,l=h)}return i?s:(o&&c(o,l),s)}function h(t,r){var i=a[r][t][0],o=[t];c(i,r);for(var s=i[1^r];;){for(;s!==t;)o.push(s),s=u(o[o.length-2],s,!1);if(a[0][t].length+a[1][t].length===0)break;var l=o[o.length-1],h=t,f=o[1],p=u(l,h,!0);if(n(e[l],e[h],e[f],e[p])<0)break;o.push(t),s=u(l,h)}return o}function f(t,e){return e[1]===e[e.length-1]}for(var o=0;o<r;++o)for(var p=0;p<2;++p){for(var d=[];a[p][o].length>0;){a[0][o].length;var g=h(o,p);f(d,g)?d.push.apply(d,g):(d.length>0&&l.push(d),d=g)}d.length>0&&l.push(d)}return l};var n=t(\"compare-angle\")},{\"compare-angle\":127}],467:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=n(t,e.length),i=new Array(e.length),a=new Array(e.length),o=[],s=0;s<e.length;++s){var l=r[s].length;a[s]=l,i[s]=!0,l<=1&&o.push(s)}for(;o.length>0;){var c=o.pop();i[c]=!1;for(var u=r[c],s=0;s<u.length;++s){var h=u[s];0==--a[h]&&o.push(h)}}for(var f=new Array(e.length),p=[],s=0;s<e.length;++s)if(i[s]){var c=p.length;f[s]=c,p.push(e[s])}else f[s]=-1;for(var d=[],s=0;s<t.length;++s){var g=t[s];i[g[0]]&&i[g[1]]&&d.push([f[g[0]],f[g[1]]])}return[d,p]};var n=t(\"edges-to-adjacency-list\")},{\"edges-to-adjacency-list\":171}],468:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=c(t,e);t=r[0];for(var h=(e=r[1]).length,f=(t.length,n(t,e.length)),p=0;p<h;++p)if(f[p].length%2==1)throw new Error(\"planar-graph-to-polyline: graph must be manifold\");var d=i(t,e);for(var g=(d=d.filter(function(t){for(var r=t.length,n=[0],i=0;i<r;++i){var a=e[t[i]],l=e[t[(i+1)%r]],c=o(-a[0],a[1]),u=o(-a[0],l[1]),h=o(l[0],a[1]),f=o(l[0],l[1]);n=s(n,s(s(c,u),s(h,f)))}return n[n.length-1]>0})).length,v=new Array(g),m=new Array(g),p=0;p<g;++p){v[p]=p;var y=new Array(g),x=d[p].map(function(t){return e[t]}),b=a([x]),_=0;t:for(var w=0;w<g;++w)if(y[w]=0,p!==w){for(var k=d[w],T=k.length,A=0;A<T;++A){var M=b(e[k[A]]);if(0!==M){M<0&&(y[w]=1,_+=1);continue t}}y[w]=1,_+=1}m[p]=[_,p,y]}m.sort(function(t,e){return e[0]-t[0]});for(var p=0;p<g;++p)for(var y=m[p],S=y[1],E=y[2],w=0;w<g;++w)E[w]&&(v[w]=S);for(var C=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=[];return e}(g),p=0;p<g;++p)C[p].push(v[p]),C[v[p]].push(p);for(var L={},P=u(h,!1),p=0;p<g;++p)for(var k=d[p],T=k.length,w=0;w<T;++w){var O=k[w],z=k[(w+1)%T],I=Math.min(O,z)+\":\"+Math.max(O,z);if(I in L){var D=L[I];C[D].push(p),C[p].push(D),P[O]=P[z]=!0}else L[I]=p}function R(t){for(var e=t.length,r=0;r<e;++r)if(!P[t[r]])return!1;return!0}for(var F=[],B=u(g,-1),p=0;p<g;++p)v[p]!==p||R(d[p])?B[p]=-1:(F.push(p),B[p]=0);var r=[];for(;F.length>0;){var N=F.pop(),j=C[N];l(j,function(t,e){return t-e});var U,V=j.length,q=B[N];if(0===q){var k=d[N];U=[k]}for(var p=0;p<V;++p){var H=j[p];if(!(B[H]>=0)&&(B[H]=1^q,F.push(H),0===q)){var k=d[H];R(k)||(k.reverse(),U.push(k))}}0===q&&r.push(U)}return r};var n=t(\"edges-to-adjacency-list\"),i=t(\"planar-dual\"),a=t(\"point-in-big-polygon\"),o=t(\"two-product\"),s=t(\"robust-sum\"),l=t(\"uniq\"),c=t(\"./lib/trim-leaves\");function u(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}},{\"./lib/trim-leaves\":467,\"edges-to-adjacency-list\":171,\"planar-dual\":466,\"point-in-big-polygon\":472,\"robust-sum\":515,\"two-product\":543,uniq:547}],469:[function(t,e,r){\"use strict\";e.exports=t(\"./quad\")},{\"./quad\":471}],470:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],471:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"clamp\"),a=t(\"parse-rect\"),o=t(\"array-bounds\"),s=t(\"pick-by-alias\"),l=t(\"defined\"),c=t(\"flatten-vertex-data\"),u=t(\"is-obj\"),h=t(\"dtype\"),f=t(\"math-log2\");function p(t,e){for(var r=e[0],n=e[1],a=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=i((t[2*l]-r)*a,0,1),s[2*l+1]=i((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,\"float64\"),e=s(e,{bounds:\"range bounds dataBox databox\",maxDepth:\"depth maxDepth maxdepth level maxLevel maxlevel levels\",dtype:\"type dtype format out dst output destination\"});var r=l(e.maxDepth,255),i=l(e.bounds,o(t,2));i[0]===i[2]&&i[2]++,i[1]===i[3]&&i[3]++;var d,g=p(t,i),v=t.length>>>1;e.dtype||(e.dtype=\"array\"),\"string\"==typeof e.dtype?d=new(h(e.dtype))(v):e.dtype&&(d=e.dtype,Array.isArray(d)&&(d.length=v));for(var m=0;m<v;++m)d[m]=m;var y=[],x=[],b=[],_=[];!function t(e,n,i,a,o,s){if(!a.length)return null;var l=y[o]||(y[o]=[]);var c=b[o]||(b[o]=[]);var u=x[o]||(x[o]=[]);var h=l.length;o++;if(o>r){for(var f=0;f<a.length;f++)l.push(a[f]),c.push(s),u.push(null,null,null,null);return h}l.push(a[0]);c.push(s);if(a.length<=1)return u.push(null,null,null,null),h;var p=.5*i;var d=e+p,v=n+p;var m=[],_=[],w=[],k=[];for(var T=1,A=a.length;T<A;T++){var M=a[T],S=g[2*M],E=g[2*M+1];S<d?E<v?m.push(M):_.push(M):E<v?w.push(M):k.push(M)}s<<=2;u.push(t(e,n,p,m,o,s),t(e,v,p,_,o,s+1),t(d,n,p,w,o,s+2),t(d,v,p,k,o,s+3));return h}(0,0,1,d,0,1);for(var w=0,k=0;k<y.length;k++){var T=y[k];if(d.set)d.set(T,w);else for(var A=0,M=T.length;A<M;A++)d[A+w]=T[A];var S=w+y[k].length;_[k]=[w,S],w=S}return d.range=function(){var e,r=[],o=arguments.length;for(;o--;)r[o]=arguments[o];if(u(r[r.length-1])){var c=r.pop();r.length||null==c.x&&null==c.l&&null==c.left||(r=[c],e={}),e=s(c,{level:\"level maxLevel\",d:\"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize\",lod:\"lod details ranges offsets\"})}else e={};r.length||(r=i);var h=a.apply(void 0,r),d=[Math.min(h.x,h.x+h.width),Math.min(h.y,h.y+h.height),Math.max(h.x,h.x+h.width),Math.max(h.y,h.y+h.height)],g=d[0],v=d[1],m=d[2],w=d[3],k=p([g,v,m,w],i),T=k[0],A=k[1],M=k[2],S=k[3],C=l(e.level,y.length);if(null!=e.d){var L;\"number\"==typeof e.d?L=[e.d,e.d]:e.d.length&&(L=e.d),C=Math.min(Math.max(Math.ceil(-f(Math.abs(L[0])/(i[2]-i[0]))),Math.ceil(-f(Math.abs(L[1])/(i[3]-i[1])))),C)}if(C=Math.min(C,y.length),e.lod)return function(t,e,r,i,a){for(var o=[],s=0;s<a;s++){var l=b[s],c=_[s][0],u=E(t,e,s),h=E(r,i,s),f=n.ge(l,u),p=n.gt(l,h,f,l.length-1);o[s]=[f+c,p+c]}return o}(T,A,M,S,C);var P=[];return function e(r,n,i,a,o,s){if(null!==o&&null!==s){var l=r+i,c=n+i;if(!(T>l||A>c||M<r||S<n||a>=C||o===s)){var u=y[a];void 0===s&&(s=u.length);for(var h=o;h<s;h++){var f=u[h],p=t[2*f],d=t[2*f+1];p>=g&&p<=m&&d>=v&&d<=w&&P.push(f)}var b=x[a],_=b[4*o+0],k=b[4*o+1],E=b[4*o+2],L=b[4*o+3],O=function(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}(b,o+1),z=.5*i,I=a+1;e(r,n,z,I,_,k||E||L||O),e(r,n+z,z,I,k,E||L||O),e(r+z,n,z,I,E,L||O),e(r+z,n+z,z,I,L,O)}}}(0,0,1,0,0,1),P},d;function E(t,e,r){for(var n=1,i=.5,a=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<i?e<a?0:1:e<a?2:3,o*=.5,i+=t<i?-o:o,a+=e<a?-o:o;return n}}},{\"array-bounds\":65,\"binary-search-bounds\":470,clamp:115,defined:164,dtype:169,\"flatten-vertex-data\":227,\"is-obj\":421,\"math-log2\":432,\"parse-rect\":459,\"pick-by-alias\":465}],472:[function(t,e,r){e.exports=function(t){for(var e=t.length,r=[],a=[],s=0;s<e;++s)for(var u=t[s],h=u.length,f=h-1,p=0;p<h;f=p++){var d=u[f],g=u[p];d[0]===g[0]?a.push([d,g]):r.push([d,g])}if(0===r.length)return 0===a.length?c:(v=l(a),function(t){return v(t[0],t[1])?0:1});var v;var m=i(r),y=function(t,e){return function(r){var i=o.le(e,r[0]);if(i<0)return 1;var a=t[i];if(!a){if(!(i>0&&e[i]===r[0]))return 1;a=t[i-1]}for(var s=1;a;){var l=a.key,c=n(r,l[0],l[1]);if(l[0][0]<l[1][0])if(c<0)a=a.left;else{if(!(c>0))return 0;s=-1,a=a.right}else if(c>0)a=a.left;else{if(!(c<0))return 0;s=1,a=a.right}}return s}}(m.slabs,m.coordinates);return 0===a.length?y:function(t,e){return function(r){return t(r[0],r[1])?0:e(r)}}(l(a),y)};var n=t(\"robust-orientation\")[3],i=t(\"slab-decomposition\"),a=t(\"interval-tree-1d\"),o=t(\"binary-search-bounds\");function s(){return!0}function l(t){for(var e={},r=0;r<t.length;++r){var n=t[r],i=n[0][0],o=n[0][1],l=n[1][1],c=[Math.min(o,l),Math.max(o,l)];i in e?e[i].push(c):e[i]=[c]}var u={},h=Object.keys(e);for(r=0;r<h.length;++r){var f=e[h[r]];u[h[r]]=a(f)}return function(t){return function(e,r){var n=t[e];return!!n&&!!n.queryPoint(r,s)}}(u)}function c(t){return 1}},{\"binary-search-bounds\":91,\"interval-tree-1d\":414,\"robust-orientation\":510,\"slab-decomposition\":526}],473:[function(t,e,r){var n,i=t(\"./lib/build-log\"),a=t(\"./lib/epsilon\"),o=t(\"./lib/intersecter\"),s=t(\"./lib/segment-chainer\"),l=t(\"./lib/segment-selector\"),c=t(\"./lib/geojson\"),u=!1,h=a();function f(t,e,r){var i=n.segments(t),a=n.segments(e),o=r(n.combine(i,a));return n.polygon(o)}n={buildLog:function(t){return!0===t?u=i():!1===t&&(u=!1),!1!==u&&u.list},epsilon:function(t){return h.epsilon(t)},segments:function(t){var e=o(!0,h,u);return t.regions.forEach(e.addRegion),{segments:e.calculate(t.inverted),inverted:t.inverted}},combine:function(t,e){return{combined:o(!1,h,u).calculate(t.segments,t.inverted,e.segments,e.inverted),inverted1:t.inverted,inverted2:e.inverted}},selectUnion:function(t){return{segments:l.union(t.combined,u),inverted:t.inverted1||t.inverted2}},selectIntersect:function(t){return{segments:l.intersect(t.combined,u),inverted:t.inverted1&&t.inverted2}},selectDifference:function(t){return{segments:l.difference(t.combined,u),inverted:t.inverted1&&!t.inverted2}},selectDifferenceRev:function(t){return{segments:l.differenceRev(t.combined,u),inverted:!t.inverted1&&t.inverted2}},selectXor:function(t){return{segments:l.xor(t.combined,u),inverted:t.inverted1!==t.inverted2}},polygon:function(t){return{regions:s(t.segments,h,u),inverted:t.inverted}},polygonFromGeoJSON:function(t){return c.toPolygon(n,t)},polygonToGeoJSON:function(t){return c.fromPolygon(n,h,t)},union:function(t,e){return f(t,e,n.selectUnion)},intersect:function(t,e){return f(t,e,n.selectIntersect)},difference:function(t,e){return f(t,e,n.selectDifference)},differenceRev:function(t,e){return f(t,e,n.selectDifferenceRev)},xor:function(t,e){return f(t,e,n.selectXor)}},\"object\"==typeof window&&(window.PolyBool=n),e.exports=n},{\"./lib/build-log\":474,\"./lib/epsilon\":475,\"./lib/geojson\":476,\"./lib/intersecter\":477,\"./lib/segment-chainer\":479,\"./lib/segment-selector\":480}],474:[function(t,e,r){e.exports=function(){var t,e=0,r=!1;function n(e,r){return t.list.push({type:e,data:r?JSON.parse(JSON.stringify(r)):void 0}),t}return t={list:[],segmentId:function(){return e++},checkIntersection:function(t,e){return n(\"check\",{seg1:t,seg2:e})},segmentChop:function(t,e){return n(\"div_seg\",{seg:t,pt:e}),n(\"chop\",{seg:t,pt:e})},statusRemove:function(t){return n(\"pop_seg\",{seg:t})},segmentUpdate:function(t){return n(\"seg_update\",{seg:t})},segmentNew:function(t,e){return n(\"new_seg\",{seg:t,primary:e})},segmentRemove:function(t){return n(\"rem_seg\",{seg:t})},tempStatus:function(t,e,r){return n(\"temp_status\",{seg:t,above:e,below:r})},rewind:function(t){return n(\"rewind\",{seg:t})},status:function(t,e,r){return n(\"status\",{seg:t,above:e,below:r})},vert:function(e){return e===r?t:(r=e,n(\"vert\",{x:e}))},log:function(t){return\"string\"!=typeof t&&(t=JSON.stringify(t,!1,\"  \")),n(\"log\",{txt:t})},reset:function(){return n(\"reset\")},selected:function(t){return n(\"selected\",{segs:t})},chainStart:function(t){return n(\"chain_start\",{seg:t})},chainRemoveHead:function(t,e){return n(\"chain_rem_head\",{index:t,pt:e})},chainRemoveTail:function(t,e){return n(\"chain_rem_tail\",{index:t,pt:e})},chainNew:function(t,e){return n(\"chain_new\",{pt1:t,pt2:e})},chainMatch:function(t){return n(\"chain_match\",{index:t})},chainClose:function(t){return n(\"chain_close\",{index:t})},chainAddHead:function(t,e){return n(\"chain_add_head\",{index:t,pt:e})},chainAddTail:function(t,e){return n(\"chain_add_tail\",{index:t,pt:e})},chainConnect:function(t,e){return n(\"chain_con\",{index1:t,index2:e})},chainReverse:function(t){return n(\"chain_rev\",{index:t})},chainJoin:function(t,e){return n(\"chain_join\",{index1:t,index2:e})},done:function(){return n(\"done\")}}}},{}],475:[function(t,e,r){e.exports=function(t){\"number\"!=typeof t&&(t=1e-10);var e={epsilon:function(e){return\"number\"==typeof e&&(t=e),t},pointAboveOrOnLine:function(e,r,n){var i=r[0],a=r[1],o=n[0],s=n[1],l=e[0];return(o-i)*(e[1]-a)-(s-a)*(l-i)>=-t},pointBetween:function(e,r,n){var i=e[1]-r[1],a=n[0]-r[0],o=e[0]-r[0],s=n[1]-r[1],l=o*a+i*s;return!(l<t||l-(a*a+s*s)>-t)},pointsSameX:function(e,r){return Math.abs(e[0]-r[0])<t},pointsSameY:function(e,r){return Math.abs(e[1]-r[1])<t},pointsSame:function(t,r){return e.pointsSameX(t,r)&&e.pointsSameY(t,r)},pointsCompare:function(t,r){return e.pointsSameX(t,r)?e.pointsSameY(t,r)?0:t[1]<r[1]?-1:1:t[0]<r[0]?-1:1},pointsCollinear:function(e,r,n){var i=e[0]-r[0],a=e[1]-r[1],o=r[0]-n[0],s=r[1]-n[1];return Math.abs(i*s-o*a)<t},linesIntersect:function(e,r,n,i){var a=r[0]-e[0],o=r[1]-e[1],s=i[0]-n[0],l=i[1]-n[1],c=a*l-o*s;if(Math.abs(c)<t)return!1;var u=e[0]-n[0],h=e[1]-n[1],f=(s*h-l*u)/c,p=(a*h-o*u)/c,d={alongA:0,alongB:0,pt:[e[0]+f*a,e[1]+f*o]};return d.alongA=f<=-t?-2:f<t?-1:f-1<=-t?0:f-1<t?1:2,d.alongB=p<=-t?-2:p<t?-1:p-1<=-t?0:p-1<t?1:2,d},pointInsideRegion:function(e,r){for(var n=e[0],i=e[1],a=r[r.length-1][0],o=r[r.length-1][1],s=!1,l=0;l<r.length;l++){var c=r[l][0],u=r[l][1];u-i>t!=o-i>t&&(a-c)*(i-u)/(o-u)+c-n>t&&(s=!s),a=c,o=u}return s}};return e}},{}],476:[function(t,e,r){var n={toPolygon:function(t,e){function r(e){if(e.length<=0)return t.segments({inverted:!1,regions:[]});function r(e){var r=e.slice(0,e.length-1);return t.segments({inverted:!1,regions:[r]})}for(var n=r(e[0]),i=1;i<e.length;i++)n=t.selectDifference(t.combine(n,r(e[i])));return n}if(\"Polygon\"===e.type)return t.polygon(r(e.coordinates));if(\"MultiPolygon\"===e.type){for(var n=t.segments({inverted:!1,regions:[]}),i=0;i<e.coordinates.length;i++)n=t.selectUnion(t.combine(n,r(e.coordinates[i])));return t.polygon(n)}throw new Error(\"PolyBool: Cannot convert GeoJSON object to PolyBool polygon\")},fromPolygon:function(t,e,r){function n(t,r){return e.pointInsideRegion([.5*(t[0][0]+t[1][0]),.5*(t[0][1]+t[1][1])],r)}function i(t){return{region:t,children:[]}}r=t.polygon(t.segments(r));var a=i(null);function o(t,e){for(var r=0;r<t.children.length;r++){if(n(e,(s=t.children[r]).region))return void o(s,e)}var a=i(e);for(r=0;r<t.children.length;r++){var s;n((s=t.children[r]).region,e)&&(a.children.push(s),t.children.splice(r,1),r--)}t.children.push(a)}for(var s=0;s<r.regions.length;s++){var l=r.regions[s];l.length<3||o(a,l)}function c(t,e){for(var r=0,n=t[t.length-1][0],i=t[t.length-1][1],a=[],o=0;o<t.length;o++){var s=t[o][0],l=t[o][1];a.push([s,l]),r+=l*n-s*i,n=s,i=l}return r<0!==e&&a.reverse(),a.push([a[0][0],a[0][1]]),a}var u=[];function h(t){var e=[c(t.region,!1)];u.push(e);for(var r=0;r<t.children.length;r++)e.push(f(t.children[r]))}function f(t){for(var e=0;e<t.children.length;e++)h(t.children[e]);return c(t.region,!0)}for(s=0;s<a.children.length;s++)h(a.children[s]);return u.length<=0?{type:\"Polygon\",coordinates:[]}:1==u.length?{type:\"Polygon\",coordinates:u[0]}:{type:\"MultiPolygon\",coordinates:u}}};e.exports=n},{}],477:[function(t,e,r){var n=t(\"./linked-list\");e.exports=function(t,e,r){function i(t,e,n){return{id:r?r.segmentId():-1,start:t,end:e,myFill:{above:n.myFill.above,below:n.myFill.below},otherFill:null}}var a=n.create();function o(t,r){a.insertBefore(t,function(n){return function(t,r,n,i,a,o){var s=e.pointsCompare(r,a);return 0!==s?s:e.pointsSame(n,o)?0:t!==i?t?1:-1:e.pointAboveOrOnLine(n,i?a:o,i?o:a)?1:-1}(t.isStart,t.pt,r,n.isStart,n.pt,n.other.pt)<0})}function s(t,e){var r=function(t,e){var r=n.node({isStart:!0,pt:t.start,seg:t,primary:e,other:null,status:null});return o(r,t.end),r}(t,e);return function(t,e,r){var i=n.node({isStart:!1,pt:e.end,seg:e,primary:r,other:t,status:null});t.other=i,o(i,t.pt)}(r,t,e),r}function l(t,e){var n=i(e,t.seg.end,t.seg);return function(t,e){r&&r.segmentChop(t.seg,e),t.other.remove(),t.seg.end=e,t.other.pt=e,o(t.other,t.pt)}(t,e),s(n,t.primary)}function c(i,o){var s=n.create();function c(t){return s.findTransition(function(r){var n,i,a,o,s,l;return n=t,i=r.ev,a=n.seg.start,o=n.seg.end,s=i.seg.start,l=i.seg.end,(e.pointsCollinear(a,s,l)?e.pointsCollinear(o,s,l)?1:e.pointAboveOrOnLine(o,s,l)?1:-1:e.pointAboveOrOnLine(a,s,l)?1:-1)>0})}function u(t,n){var i=t.seg,a=n.seg,o=i.start,s=i.end,c=a.start,u=a.end;r&&r.checkIntersection(i,a);var h=e.linesIntersect(o,s,c,u);if(!1===h){if(!e.pointsCollinear(o,s,c))return!1;if(e.pointsSame(o,u)||e.pointsSame(s,c))return!1;var f=e.pointsSame(o,c),p=e.pointsSame(s,u);if(f&&p)return n;var d=!f&&e.pointBetween(o,c,u),g=!p&&e.pointBetween(s,c,u);if(f)return g?l(n,s):l(t,u),n;d&&(p||(g?l(n,s):l(t,u)),l(n,o))}else 0===h.alongA&&(-1===h.alongB?l(t,c):0===h.alongB?l(t,h.pt):1===h.alongB&&l(t,u)),0===h.alongB&&(-1===h.alongA?l(n,o):0===h.alongA?l(n,h.pt):1===h.alongA&&l(n,s));return!1}for(var h=[];!a.isEmpty();){var f=a.getHead();if(r&&r.vert(f.pt[0]),f.isStart){r&&r.segmentNew(f.seg,f.primary);var p=c(f),d=p.before?p.before.ev:null,g=p.after?p.after.ev:null;function v(){if(d){var t=u(f,d);if(t)return t}return!!g&&u(f,g)}r&&r.tempStatus(f.seg,!!d&&d.seg,!!g&&g.seg);var m,y,x=v();if(x)t?(y=null===f.seg.myFill.below||f.seg.myFill.above!==f.seg.myFill.below)&&(x.seg.myFill.above=!x.seg.myFill.above):x.seg.otherFill=f.seg.myFill,r&&r.segmentUpdate(x.seg),f.other.remove(),f.remove();if(a.getHead()!==f){r&&r.rewind(f.seg);continue}t?(y=null===f.seg.myFill.below||f.seg.myFill.above!==f.seg.myFill.below,f.seg.myFill.below=g?g.seg.myFill.above:i,f.seg.myFill.above=y?!f.seg.myFill.below:f.seg.myFill.below):null===f.seg.otherFill&&(m=g?f.primary===g.primary?g.seg.otherFill.above:g.seg.myFill.above:f.primary?o:i,f.seg.otherFill={above:m,below:m}),r&&r.status(f.seg,!!d&&d.seg,!!g&&g.seg),f.other.status=p.insert(n.node({ev:f}))}else{var b=f.status;if(null===b)throw new Error(\"PolyBool: Zero-length segment detected; your epsilon is probably too small or too large\");if(s.exists(b.prev)&&s.exists(b.next)&&u(b.prev.ev,b.next.ev),r&&r.statusRemove(b.ev.seg),b.remove(),!f.primary){var _=f.seg.myFill;f.seg.myFill=f.seg.otherFill,f.seg.otherFill=_}h.push(f.seg)}a.getHead().remove()}return r&&r.done(),h}return t?{addRegion:function(t){for(var n,i,a,o=t[t.length-1],l=0;l<t.length;l++){n=o,o=t[l];var c=e.pointsCompare(n,o);0!==c&&s((i=c<0?n:o,a=c<0?o:n,{id:r?r.segmentId():-1,start:i,end:a,myFill:{above:null,below:null},otherFill:null}),!0)}},calculate:function(t){return c(t,!1)}}:{calculate:function(t,e,r,n){return t.forEach(function(t){s(i(t.start,t.end,t),!0)}),r.forEach(function(t){s(i(t.start,t.end,t),!1)}),c(e,n)}}}},{\"./linked-list\":478}],478:[function(t,e,r){e.exports={create:function(){var t={root:{root:!0,next:null},exists:function(e){return null!==e&&e!==t.root},isEmpty:function(){return null===t.root.next},getHead:function(){return t.root.next},insertBefore:function(e,r){for(var n=t.root,i=t.root.next;null!==i;){if(r(i))return e.prev=i.prev,e.next=i,i.prev.next=e,void(i.prev=e);n=i,i=i.next}n.next=e,e.prev=n,e.next=null},findTransition:function(e){for(var r=t.root,n=t.root.next;null!==n&&!e(n);)r=n,n=n.next;return{before:r===t.root?null:r,after:n,insert:function(t){return t.prev=r,t.next=n,r.next=t,null!==n&&(n.prev=t),t}}}};return t},node:function(t){return t.prev=null,t.next=null,t.remove=function(){t.prev.next=t.next,t.next&&(t.next.prev=t.prev),t.prev=null,t.next=null},t}}},{}],479:[function(t,e,r){e.exports=function(t,e,r){var n=[],i=[];return t.forEach(function(t){var a=t.start,o=t.end;if(e.pointsSame(a,o))console.warn(\"PolyBool: Warning: Zero-length segment detected; your epsilon is probably too small or too large\");else{r&&r.chainStart(t);for(var s={index:0,matches_head:!1,matches_pt1:!1},l={index:0,matches_head:!1,matches_pt1:!1},c=s,u=0;u<n.length;u++){var h=(v=n[u])[0],f=(v[1],v[v.length-1]);if(v[v.length-2],e.pointsSame(h,a)){if(T(u,!0,!0))break}else if(e.pointsSame(h,o)){if(T(u,!0,!1))break}else if(e.pointsSame(f,a)){if(T(u,!1,!0))break}else if(e.pointsSame(f,o)&&T(u,!1,!1))break}if(c===s)return n.push([a,o]),void(r&&r.chainNew(a,o));if(c===l){r&&r.chainMatch(s.index);var p=s.index,d=s.matches_pt1?o:a,g=s.matches_head,v=n[p],m=g?v[0]:v[v.length-1],y=g?v[1]:v[v.length-2],x=g?v[v.length-1]:v[0],b=g?v[v.length-2]:v[1];return e.pointsCollinear(y,m,d)&&(g?(r&&r.chainRemoveHead(s.index,d),v.shift()):(r&&r.chainRemoveTail(s.index,d),v.pop()),m=y),e.pointsSame(x,d)?(n.splice(p,1),e.pointsCollinear(b,x,m)&&(g?(r&&r.chainRemoveTail(s.index,m),v.pop()):(r&&r.chainRemoveHead(s.index,m),v.shift())),r&&r.chainClose(s.index),void i.push(v)):void(g?(r&&r.chainAddHead(s.index,d),v.unshift(d)):(r&&r.chainAddTail(s.index,d),v.push(d)))}var _=s.index,w=l.index;r&&r.chainConnect(_,w);var k=n[_].length<n[w].length;s.matches_head?l.matches_head?k?(A(_),M(_,w)):(A(w),M(w,_)):M(w,_):l.matches_head?M(_,w):k?(A(_),M(w,_)):(A(w),M(_,w))}function T(t,e,r){return c.index=t,c.matches_head=e,c.matches_pt1=r,c===s?(c=l,!1):(c=null,!0)}function A(t){r&&r.chainReverse(t),n[t].reverse()}function M(t,i){var a=n[t],o=n[i],s=a[a.length-1],l=a[a.length-2],c=o[0],u=o[1];e.pointsCollinear(l,s,c)&&(r&&r.chainRemoveTail(t,s),a.pop(),s=l),e.pointsCollinear(s,c,u)&&(r&&r.chainRemoveHead(i,c),o.shift()),r&&r.chainJoin(t,i),n[t]=a.concat(o),n.splice(i,1)}}),i}},{}],480:[function(t,e,r){function n(t,e,r){var n=[];return t.forEach(function(t){var i=(t.myFill.above?8:0)+(t.myFill.below?4:0)+(t.otherFill&&t.otherFill.above?2:0)+(t.otherFill&&t.otherFill.below?1:0);0!==e[i]&&n.push({id:r?r.segmentId():-1,start:t.start,end:t.end,myFill:{above:1===e[i],below:2===e[i]},otherFill:null})}),r&&r.selected(n),n}var i={union:function(t,e){return n(t,[0,2,1,0,2,2,0,0,1,0,1,0,0,0,0,0],e)},intersect:function(t,e){return n(t,[0,0,0,0,0,2,0,2,0,0,1,1,0,2,1,0],e)},difference:function(t,e){return n(t,[0,0,0,0,2,0,2,0,1,1,0,0,0,1,2,0],e)},differenceRev:function(t,e){return n(t,[0,2,1,0,0,0,1,1,0,2,0,2,0,0,0,0],e)},xor:function(t,e){return n(t,[0,2,1,0,2,0,0,1,1,0,0,2,0,1,2,0],e)}};e.exports=i},{}],481:[function(t,e,r){\"use strict\";var n=new Float64Array(4),i=new Float64Array(4),a=new Float64Array(4);e.exports=function(t,e,r,o,s){n.length<o.length&&(n=new Float64Array(o.length),i=new Float64Array(o.length),a=new Float64Array(o.length));for(var l=0;l<o.length;++l)n[l]=t[l]-o[l],i[l]=e[l]-t[l],a[l]=r[l]-t[l];var c=0,u=0,h=0,f=0,p=0,d=0;for(l=0;l<o.length;++l){var g=i[l],v=a[l],m=n[l];c+=g*g,u+=g*v,h+=v*v,f+=m*g,p+=m*v,d+=m*m}var y,x,b,_,w,k=Math.abs(c*h-u*u),T=u*p-h*f,A=u*f-c*p;if(T+A<=k)if(T<0)A<0&&f<0?(A=0,-f>=c?(T=1,y=c+2*f+d):y=f*(T=-f/c)+d):(T=0,p>=0?(A=0,y=d):-p>=h?(A=1,y=h+2*p+d):y=p*(A=-p/h)+d);else if(A<0)A=0,f>=0?(T=0,y=d):-f>=c?(T=1,y=c+2*f+d):y=f*(T=-f/c)+d;else{var M=1/k;y=(T*=M)*(c*T+u*(A*=M)+2*f)+A*(u*T+h*A+2*p)+d}else T<0?(b=h+p)>(x=u+f)?(_=b-x)>=(w=c-2*u+h)?(T=1,A=0,y=c+2*f+d):y=(T=_/w)*(c*T+u*(A=1-T)+2*f)+A*(u*T+h*A+2*p)+d:(T=0,b<=0?(A=1,y=h+2*p+d):p>=0?(A=0,y=d):y=p*(A=-p/h)+d):A<0?(b=c+f)>(x=u+p)?(_=b-x)>=(w=c-2*u+h)?(A=1,T=0,y=h+2*p+d):y=(T=1-(A=_/w))*(c*T+u*A+2*f)+A*(u*T+h*A+2*p)+d:(A=0,b<=0?(T=1,y=c+2*f+d):f>=0?(T=0,y=d):y=f*(T=-f/c)+d):(_=h+p-u-f)<=0?(T=0,A=1,y=h+2*p+d):_>=(w=c-2*u+h)?(T=1,A=0,y=c+2*f+d):y=(T=_/w)*(c*T+u*(A=1-T)+2*f)+A*(u*T+h*A+2*p)+d;var S=1-T-A;for(l=0;l<o.length;++l)s[l]=S*t[l]+T*e[l]+A*r[l];return y<0?0:y}},{}],482:[function(t,e,r){var n,i,a=e.exports={};function o(){throw new Error(\"setTimeout has not been defined\")}function s(){throw new Error(\"clearTimeout has not been defined\")}function l(t){if(n===setTimeout)return setTimeout(t,0);if((n===o||!n)&&setTimeout)return n=setTimeout,setTimeout(t,0);try{return n(t,0)}catch(e){try{return n.call(null,t,0)}catch(e){return n.call(this,t,0)}}}!function(){try{n=\"function\"==typeof setTimeout?setTimeout:o}catch(t){n=o}try{i=\"function\"==typeof clearTimeout?clearTimeout:s}catch(t){i=s}}();var c,u=[],h=!1,f=-1;function p(){h&&c&&(h=!1,c.length?u=c.concat(u):f=-1,u.length&&d())}function d(){if(!h){var t=l(p);h=!0;for(var e=u.length;e;){for(c=u,u=[];++f<e;)c&&c[f].run();f=-1,e=u.length}c=null,h=!1,function(t){if(i===clearTimeout)return clearTimeout(t);if((i===s||!i)&&clearTimeout)return i=clearTimeout,clearTimeout(t);try{i(t)}catch(e){try{return i.call(null,t)}catch(e){return i.call(this,t)}}}(t)}}function g(t,e){this.fun=t,this.array=e}function v(){}a.nextTick=function(t){var e=new Array(arguments.length-1);if(arguments.length>1)for(var r=1;r<arguments.length;r++)e[r-1]=arguments[r];u.push(new g(t,e)),1!==u.length||h||l(d)},g.prototype.run=function(){this.fun.apply(null,this.array)},a.title=\"browser\",a.browser=!0,a.env={},a.argv=[],a.version=\"\",a.versions={},a.on=v,a.addListener=v,a.once=v,a.off=v,a.removeListener=v,a.removeAllListeners=v,a.emit=v,a.prependListener=v,a.prependOnceListener=v,a.listeners=function(t){return[]},a.binding=function(t){throw new Error(\"process.binding is not supported\")},a.cwd=function(){return\"/\"},a.chdir=function(t){throw new Error(\"process.chdir is not supported\")},a.umask=function(){return 0}},{}],483:[function(t,e,r){e.exports=t(\"gl-quat/slerp\")},{\"gl-quat/slerp\":293}],484:[function(t,e,r){(function(r){for(var n=t(\"performance-now\"),i=\"undefined\"==typeof window?r:window,a=[\"moz\",\"webkit\"],o=\"AnimationFrame\",s=i[\"request\"+o],l=i[\"cancel\"+o]||i[\"cancelRequest\"+o],c=0;!s&&c<a.length;c++)s=i[a[c]+\"Request\"+o],l=i[a[c]+\"Cancel\"+o]||i[a[c]+\"CancelRequest\"+o];if(!s||!l){var u=0,h=0,f=[];s=function(t){if(0===f.length){var e=n(),r=Math.max(0,1e3/60-(e-u));u=r+e,setTimeout(function(){var t=f.slice(0);f.length=0;for(var e=0;e<t.length;e++)if(!t[e].cancelled)try{t[e].callback(u)}catch(t){setTimeout(function(){throw t},0)}},Math.round(r))}return f.push({handle:++h,callback:t,cancelled:!1}),h},l=function(t){for(var e=0;e<f.length;e++)f[e].handle===t&&(f[e].cancelled=!0)}}e.exports=function(t){return s.call(i,t)},e.exports.cancel=function(){l.apply(i,arguments)},e.exports.polyfill=function(t){t||(t=i),t.requestAnimationFrame=s,t.cancelAnimationFrame=l}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"performance-now\":462}],485:[function(t,e,r){\"use strict\";var n=t(\"big-rat/add\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/add\":75}],486:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t.length),r=0;r<t.length;++r)e[r]=n(t[r]);return e};var n=t(\"big-rat\")},{\"big-rat\":78}],487:[function(t,e,r){\"use strict\";var n=t(\"big-rat\"),i=t(\"big-rat/mul\");e.exports=function(t,e){for(var r=n(e),a=t.length,o=new Array(a),s=0;s<a;++s)o[s]=i(t[s],r);return o}},{\"big-rat\":78,\"big-rat/mul\":87}],488:[function(t,e,r){\"use strict\";var n=t(\"big-rat/sub\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/sub\":89}],489:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"compare-oriented-cell\"),a=t(\"cell-orientation\");e.exports=function(t){t.sort(i);for(var e=t.length,r=0,o=0;o<e;++o){var s=t[o],l=a(s);if(0!==l){if(r>0){var c=t[r-1];if(0===n(s,c)&&a(c)!==l){r-=1;continue}}t[r++]=s}}return t.length=r,t}},{\"cell-orientation\":112,\"compare-cell\":128,\"compare-oriented-cell\":129}],490:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\"),i=t(\"color-normalize\"),a=t(\"update-diff\"),o=t(\"pick-by-alias\"),s=t(\"object-assign\"),l=t(\"flatten-vertex-data\"),c=t(\"to-float32\"),u=c.float32,h=c.fract32;e.exports=function(t,e){\"function\"==typeof t?(e||(e={}),e.regl=t):e=t;e.length&&(e.positions=e);if(!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");var r,c,p,d,g,v,m=t._gl,y={color:\"black\",capSize:5,lineWidth:1,opacity:1,viewport:null,range:null,offset:0,count:0,bounds:null,positions:[],errors:[]},x=[];return d=t.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array(0)}),c=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),p=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),g=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),v=t.buffer({usage:\"static\",type:\"float\",data:f}),k(e),r=t({vert:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tattribute vec2 position, positionFract;\\n\\t\\tattribute vec4 error;\\n\\t\\tattribute vec4 color;\\n\\n\\t\\tattribute vec2 direction, lineOffset, capOffset;\\n\\n\\t\\tuniform vec4 viewport;\\n\\t\\tuniform float lineWidth, capSize;\\n\\t\\tuniform vec2 scale, scaleFract, translate, translateFract;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tfragColor = color / 255.;\\n\\n\\t\\t\\tvec2 pixelOffset = lineWidth * lineOffset + (capSize + lineWidth) * capOffset;\\n\\n\\t\\t\\tvec2 dxy = -step(.5, direction.xy) * error.xz + step(direction.xy, vec2(-.5)) * error.yw;\\n\\n\\t\\t\\tvec2 position = position + dxy;\\n\\n\\t\\t\\tvec2 pos = (position + translate) * scale\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scale\\n\\t\\t\\t\\t+ (position + translate) * scaleFract\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scaleFract;\\n\\n\\t\\t\\tpos += pixelOffset / viewport.zw;\\n\\n\\t\\t\\tgl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\t\\t}\\n\\t\\t\",frag:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tuniform float opacity;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tgl_FragColor = fragColor;\\n\\t\\t\\tgl_FragColor.a *= opacity;\\n\\t\\t}\\n\\t\\t\",uniforms:{range:t.prop(\"range\"),lineWidth:t.prop(\"lineWidth\"),capSize:t.prop(\"capSize\"),opacity:t.prop(\"opacity\"),scale:t.prop(\"scale\"),translate:t.prop(\"translate\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{color:{buffer:d,offset:function(t,e){return 4*e.offset},divisor:1},position:{buffer:c,offset:function(t,e){return 8*e.offset},divisor:1},positionFract:{buffer:p,offset:function(t,e){return 8*e.offset},divisor:1},error:{buffer:g,offset:function(t,e){return 16*e.offset},divisor:1},direction:{buffer:v,stride:24,offset:0},lineOffset:{buffer:v,stride:24,offset:8},capOffset:{buffer:v,stride:24,offset:16}},primitive:\"triangles\",blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:!1,instances:t.prop(\"count\"),count:f.length}),s(b,{update:k,draw:_,destroy:T,regl:t,gl:m,canvas:m.canvas,groups:x}),b;function b(t){t?k(t):null===t&&T(),_()}function _(e){if(\"number\"==typeof e)return w(e);e&&!Array.isArray(e)&&(e=[e]),t._refresh(),x.forEach(function(t,r){t&&(e&&(e[r]?t.draw=!0:t.draw=!1),t.draw?w(r):t.draw=!0)})}function w(t){\"number\"==typeof t&&(t=x[t]),null!=t&&t&&t.count&&t.color&&t.opacity&&t.positions&&t.positions.length>1&&(t.scaleRatio=[t.scale[0]*t.viewport.width,t.scale[1]*t.viewport.height],r(t),t.after&&t.after(t))}function k(t){if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var e=0,r=0;if(b.groups=x=t.map(function(t,c){var u=x[c];return t?(\"function\"==typeof t?t={after:t}:\"number\"==typeof t[0]&&(t={positions:t}),t=o(t,{color:\"color colors fill\",capSize:\"capSize cap capsize cap-size\",lineWidth:\"lineWidth line-width width line thickness\",opacity:\"opacity alpha\",range:\"range dataBox\",viewport:\"viewport viewBox\",errors:\"errors error\",positions:\"positions position data points\"}),u||(x[c]=u={id:c,scale:null,translate:null,scaleFract:null,translateFract:null,draw:!0},t=s({},y,t)),a(u,t,[{lineWidth:function(t){return.5*+t},capSize:function(t){return.5*+t},opacity:parseFloat,errors:function(t){return t=l(t),r+=t.length,t},positions:function(t,r){return t=l(t,\"float64\"),r.count=Math.floor(t.length/2),r.bounds=n(t,2),r.offset=e,e+=r.count,t}},{color:function(t,e){var r=e.count;if(t||(t=\"transparent\"),!Array.isArray(t)||\"number\"==typeof t[0]){var n=t;t=Array(r);for(var a=0;a<r;a++)t[a]=n}if(t.length<r)throw Error(\"Not enough colors\");for(var o=new Uint8Array(4*r),s=0;s<r;s++){var l=i(t[s],\"uint8\");o.set(l,4*s)}return o},range:function(t,e,r){var n=e.bounds;return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=h(e.scale),e.translateFract=h(e.translate),t},viewport:function(t){var e;return Array.isArray(t)?e={x:t[0],y:t[1],width:t[2]-t[0],height:t[3]-t[1]}:t?(e={x:t.x||t.left||0,y:t.y||t.top||0},t.right?e.width=t.right-e.x:e.width=t.w||t.width||0,t.bottom?e.height=t.bottom-e.y:e.height=t.h||t.height||0):e={x:0,y:0,width:m.drawingBufferWidth,height:m.drawingBufferHeight},e}}]),u):u}),e||r){var f=x.reduce(function(t,e,r){return t+(e?e.count:0)},0),v=new Float64Array(2*f),_=new Uint8Array(4*f),w=new Float32Array(4*f);x.forEach(function(t,e){if(t){var r=t.positions,n=t.count,i=t.offset,a=t.color,o=t.errors;n&&(_.set(a,4*i),w.set(o,4*i),v.set(r,2*i))}}),c(u(v)),p(h(v)),d(_),g(w)}}}function T(){c.destroy(),p.destroy(),d.destroy(),g.destroy(),v.destroy()}};var f=[[1,0,0,1,0,0],[1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,1,0,0],[1,0,0,1,0,0],[1,0,-1,0,0,1],[1,0,-1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,1],[1,0,-1,0,0,1],[-1,0,-1,0,0,1],[-1,0,-1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,1],[-1,0,-1,0,0,1],[0,1,1,0,0,0],[0,1,-1,0,0,0],[0,-1,-1,0,0,0],[0,-1,-1,0,0,0],[0,1,1,0,0,0],[0,-1,1,0,0,0],[0,1,0,-1,1,0],[0,1,0,-1,-1,0],[0,1,0,1,-1,0],[0,1,0,1,1,0],[0,1,0,-1,1,0],[0,1,0,1,-1,0],[0,-1,0,-1,1,0],[0,-1,0,-1,-1,0],[0,-1,0,1,-1,0],[0,-1,0,1,1,0],[0,-1,0,-1,1,0],[0,-1,0,1,-1,0]]},{\"array-bounds\":65,\"color-normalize\":120,\"flatten-vertex-data\":227,\"object-assign\":454,\"pick-by-alias\":465,\"to-float32\":538,\"update-diff\":549}],491:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\"),i=t(\"array-bounds\"),a=t(\"object-assign\"),o=t(\"glslify\"),s=t(\"pick-by-alias\"),l=t(\"flatten-vertex-data\"),c=t(\"earcut\"),u=t(\"array-normalize\"),h=t(\"to-float32\"),f=h.float32,p=h.fract32,d=t(\"es6-weak-map\"),g=t(\"parse-rect\");function v(t,e){if(!(this instanceof v))return new v(t,e);if(\"function\"==typeof t?(e||(e={}),e.regl=t):e=t,e.length&&(e.positions=e),!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");this.gl=t._gl,this.regl=t,this.passes=[],this.shaders=v.shaders.has(t)?v.shaders.get(t):v.shaders.set(t,v.createShaders(t)).get(t),this.update(e)}e.exports=v,v.dashMult=2,v.maxPatternLength=256,v.precisionThreshold=3e6,v.maxPoints=1e4,v.maxLines=2048,v.shaders=new d,v.createShaders=function(t){var e,r=t.buffer({usage:\"static\",type:\"float\",data:[0,1,0,0,1,1,1,0]}),n={primitive:\"triangle strip\",instances:t.prop(\"count\"),count:4,offset:0,uniforms:{miterMode:function(t,e){return\"round\"===e.join?2:1},miterLimit:t.prop(\"miterLimit\"),scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),thickness:t.prop(\"thickness\"),dashPattern:t.prop(\"dashTexture\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),dashSize:t.prop(\"dashLength\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]},depth:t.prop(\"depth\")},blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:function(t,e){return!e.overlay}},stencil:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\")},i=t(a({vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, aCoordFract, bCoordFract;\\nattribute vec4 color;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvec2 project(vec2 position, vec2 positionFract, vec2 scale, vec2 scaleFract, vec2 translate, vec2 translateFract) {\\n\\t// the order is important\\n\\treturn position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n}\\n\\nvoid main() {\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineOffset = lineTop * 2. - 1.;\\n\\n\\tvec2 diff = (bCoord + bCoordFract - aCoord - aCoordFract);\\n\\ttangent = normalize(diff * scale * viewport.zw);\\n\\tvec2 normal = vec2(-tangent.y, tangent.x);\\n\\n\\tvec2 position = project(aCoord, aCoordFract, scale, scaleFract, translate, translateFract) * lineStart\\n\\t\\t+ project(bCoord, bCoordFract, scale, scaleFract, translate, translateFract) * lineEnd\\n\\n\\t\\t+ thickness * normal * .5 * lineOffset / viewport.zw;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\n\\nuniform float dashSize, pixelRatio, thickness, opacity, id;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvoid main() {\\n\\tfloat alpha = 1.;\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},aCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8,divisor:1},bCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:16,divisor:1},color:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1}}},n));try{e=t(a({cull:{enable:!0,face:\"back\"},vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, nextCoord, prevCoord;\\nattribute vec4 aColor, bColor;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, translate;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\nuniform float miterLimit, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 tangent;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nconst float REVERSE_THRESHOLD = -.875;\\nconst float MIN_DIFF = 1e-6;\\n\\n// TODO: possible optimizations: avoid overcalculating all for vertices and calc just one instead\\n// TODO: precalculate dot products, normalize things beforehead etc.\\n// TODO: refactor to rectangular algorithm\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nbool isNaN( float val ){\\n  return ( val < 0.0 || 0.0 < val || val == 0.0 ) ? false : true;\\n}\\n\\nvoid main() {\\n\\tvec2 aCoord = aCoord, bCoord = bCoord, prevCoord = prevCoord, nextCoord = nextCoord;\\n\\n  vec2 adjustedScale;\\n  adjustedScale.x = (abs(scale.x) < MIN_DIFF) ? MIN_DIFF : scale.x;\\n  adjustedScale.y = (abs(scale.y) < MIN_DIFF) ? MIN_DIFF : scale.y;\\n\\n  vec2 scaleRatio = adjustedScale * viewport.zw;\\n\\tvec2 normalWidth = thickness / scaleRatio;\\n\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineBot = 1. - lineTop;\\n\\n\\tfragColor = (lineStart * aColor + lineEnd * bColor) / 255.;\\n\\n\\tif (isNaN(aCoord.x) || isNaN(aCoord.y) || isNaN(bCoord.x) || isNaN(bCoord.y)) return;\\n\\n\\tif (aCoord == prevCoord) prevCoord = aCoord + normalize(bCoord - aCoord);\\n\\tif (bCoord == nextCoord) nextCoord = bCoord - normalize(bCoord - aCoord);\\n\\n\\tvec2 prevDiff = aCoord - prevCoord;\\n\\tvec2 currDiff = bCoord - aCoord;\\n\\tvec2 nextDiff = nextCoord - bCoord;\\n\\n\\tvec2 prevTangent = normalize(prevDiff * scaleRatio);\\n\\tvec2 currTangent = normalize(currDiff * scaleRatio);\\n\\tvec2 nextTangent = normalize(nextDiff * scaleRatio);\\n\\n\\tvec2 prevNormal = vec2(-prevTangent.y, prevTangent.x);\\n\\tvec2 currNormal = vec2(-currTangent.y, currTangent.x);\\n\\tvec2 nextNormal = vec2(-nextTangent.y, nextTangent.x);\\n\\n\\tvec2 startJoinDirection = normalize(prevTangent - currTangent);\\n\\tvec2 endJoinDirection = normalize(currTangent - nextTangent);\\n\\n\\t// collapsed/unidirectional segment cases\\n\\t// FIXME: there should be more elegant solution\\n\\tvec2 prevTanDiff = abs(prevTangent - currTangent);\\n\\tvec2 nextTanDiff = abs(nextTangent - currTangent);\\n\\tif (max(prevTanDiff.x, prevTanDiff.y) < MIN_DIFF) {\\n\\t\\tstartJoinDirection = currNormal;\\n\\t}\\n\\tif (max(nextTanDiff.x, nextTanDiff.y) < MIN_DIFF) {\\n\\t\\tendJoinDirection = currNormal;\\n\\t}\\n\\tif (aCoord == bCoord) {\\n\\t\\tendJoinDirection = startJoinDirection;\\n\\t\\tcurrNormal = prevNormal;\\n\\t\\tcurrTangent = prevTangent;\\n\\t}\\n\\n\\ttangent = currTangent;\\n\\n\\t//calculate join shifts relative to normals\\n\\tfloat startJoinShift = dot(currNormal, startJoinDirection);\\n\\tfloat endJoinShift = dot(currNormal, endJoinDirection);\\n\\n\\tfloat startMiterRatio = abs(1. / startJoinShift);\\n\\tfloat endMiterRatio = abs(1. / endJoinShift);\\n\\n\\tvec2 startJoin = startJoinDirection * startMiterRatio;\\n\\tvec2 endJoin = endJoinDirection * endMiterRatio;\\n\\n\\tvec2 startTopJoin, startBotJoin, endTopJoin, endBotJoin;\\n\\tstartTopJoin = sign(startJoinShift) * startJoin * .5;\\n\\tstartBotJoin = -startTopJoin;\\n\\n\\tendTopJoin = sign(endJoinShift) * endJoin * .5;\\n\\tendBotJoin = -endTopJoin;\\n\\n\\tvec2 aTopCoord = aCoord + normalWidth * startTopJoin;\\n\\tvec2 bTopCoord = bCoord + normalWidth * endTopJoin;\\n\\tvec2 aBotCoord = aCoord + normalWidth * startBotJoin;\\n\\tvec2 bBotCoord = bCoord + normalWidth * endBotJoin;\\n\\n\\t//miter anti-clipping\\n\\tfloat baClipping = distToLine(bCoord, aCoord, aBotCoord) / dot(normalize(normalWidth * endBotJoin), normalize(normalWidth.yx * vec2(-startBotJoin.y, startBotJoin.x)));\\n\\tfloat abClipping = distToLine(aCoord, bCoord, bTopCoord) / dot(normalize(normalWidth * startBotJoin), normalize(normalWidth.yx * vec2(-endBotJoin.y, endBotJoin.x)));\\n\\n\\t//prevent close to reverse direction switch\\n\\tbool prevReverse = dot(currTangent, prevTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, prevNormal)) * min(length(prevDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\tbool nextReverse = dot(currTangent, nextTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, nextNormal)) * min(length(nextDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\n\\tif (prevReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * startJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / startMiterRatio, 1.);\\n\\t\\taBotCoord = aCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\taTopCoord = aCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!nextReverse && baClipping > 0. && baClipping < length(normalWidth * endBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\tbTopCoord -= normalWidth * endTopJoin;\\n\\t\\tbTopCoord += normalize(endTopJoin * normalWidth) * baClipping;\\n\\t}\\n\\n\\tif (nextReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * endJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / endMiterRatio, 1.);\\n\\t\\tbBotCoord = bCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\tbTopCoord = bCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!prevReverse && abClipping > 0. && abClipping < length(normalWidth * startBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\taBotCoord -= normalWidth * startBotJoin;\\n\\t\\taBotCoord += normalize(startBotJoin * normalWidth) * abClipping;\\n\\t}\\n\\n\\tvec2 aTopPosition = (aTopCoord) * adjustedScale + translate;\\n\\tvec2 aBotPosition = (aBotCoord) * adjustedScale + translate;\\n\\n\\tvec2 bTopPosition = (bTopCoord) * adjustedScale + translate;\\n\\tvec2 bBotPosition = (bBotCoord) * adjustedScale + translate;\\n\\n\\t//position is normalized 0..1 coord on the screen\\n\\tvec2 position = (aTopPosition * lineTop + aBotPosition * lineBot) * lineStart + (bTopPosition * lineTop + bBotPosition * lineBot) * lineEnd;\\n\\n\\tstartCoord = aCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\tendCoord = bCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\n\\tgl_Position = vec4(position  * 2.0 - 1.0, depth, 1);\\n\\n\\tenableStartMiter = step(dot(currTangent, prevTangent), .5);\\n\\tenableEndMiter = step(dot(currTangent, nextTangent), .5);\\n\\n\\t//bevel miter cutoffs\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n\\n\\t//round miter cutoffs\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * abs(dot(startJoinDirection, currNormal)) * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * abs(dot(endJoinDirection, currNormal)) * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\nuniform float dashSize, pixelRatio, thickness, opacity, id, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nvoid main() {\\n\\tfloat alpha = 1., distToStart, distToEnd;\\n\\tfloat cutoff = thickness * .5;\\n\\n\\t//bevel miter\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToStart + 1., 0.), 1.);\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToEnd + 1., 0.), 1.);\\n\\t\\t}\\n\\t}\\n\\n\\t// round miter\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - startCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - endCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\t}\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1},bColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:4,divisor:1},prevCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:0,divisor:1},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},nextCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:24,divisor:1}}},n))}catch(t){e=i}return{fill:t({primitive:\"triangle\",elements:function(t,e){return e.triangles},offset:0,vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position, positionFract;\\n\\nuniform vec4 color;\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio, id;\\nuniform vec4 viewport;\\nuniform float opacity;\\n\\nvarying vec4 fragColor;\\n\\nconst float MAX_LINES = 256.;\\n\\nvoid main() {\\n\\tfloat depth = (MAX_LINES - 4. - id) / (MAX_LINES);\\n\\n\\tvec2 position = position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n\\tfragColor.a *= opacity;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n\\tgl_FragColor = fragColor;\\n}\\n\"]),uniforms:{scale:t.prop(\"scale\"),color:t.prop(\"fill\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{position:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8},positionFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8}},blend:n.blend,depth:{enable:!1},scissor:n.scissor,stencil:n.stencil,viewport:n.viewport}),rect:i,miter:e}},v.defaults={dashes:null,join:\"miter\",miterLimit:1,thickness:10,cap:\"square\",color:\"black\",opacity:1,overlay:!1,viewport:null,range:null,close:!1,fill:null},v.prototype.render=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];e.length&&(t=this).update.apply(t,e),this.draw()},v.prototype.draw=function(){for(var t=this,e=[],r=arguments.length;r--;)e[r]=arguments[r];return(e.length?e:this.passes).forEach(function(e,r){var n;if(e&&Array.isArray(e))return(n=t).draw.apply(n,e);\"number\"==typeof e&&(e=t.passes[e]),e&&e.count>1&&e.opacity&&(t.regl._refresh(),e.fill&&e.triangles&&e.triangles.length>2&&t.shaders.fill(e),e.thickness&&(e.scale[0]*e.viewport.width>v.precisionThreshold||e.scale[1]*e.viewport.height>v.precisionThreshold?t.shaders.rect(e):\"rect\"===e.join||!e.join&&(e.thickness<=2||e.count>=v.maxPoints)?t.shaders.rect(e):t.shaders.miter(e)))}),this},v.prototype.update=function(t){var e=this;if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var r=this.regl,o=this.gl;if(t.forEach(function(t,h){var d=e.passes[h];if(void 0!==t)if(null!==t){if(\"number\"==typeof t[0]&&(t={positions:t}),t=s(t,{positions:\"positions points data coords\",thickness:\"thickness lineWidth lineWidths line-width linewidth width stroke-width strokewidth strokeWidth\",join:\"lineJoin linejoin join type mode\",miterLimit:\"miterlimit miterLimit\",dashes:\"dash dashes dasharray dash-array dashArray\",color:\"color colour stroke colors colours stroke-color strokeColor\",fill:\"fill fill-color fillColor\",opacity:\"alpha opacity\",overlay:\"overlay crease overlap intersect\",close:\"closed close closed-path closePath\",range:\"range dataBox\",viewport:\"viewport viewBox\",hole:\"holes hole hollow\"}),d||(e.passes[h]=d={id:h,scale:null,scaleFract:null,translate:null,translateFract:null,count:0,hole:[],depth:0,dashLength:1,dashTexture:r.texture({channels:1,data:new Uint8Array([255]),width:1,height:1,mag:\"linear\",min:\"linear\"}),colorBuffer:r.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array}),positionBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),positionFractBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array})},t=a({},v.defaults,t)),null!=t.thickness&&(d.thickness=parseFloat(t.thickness)),null!=t.opacity&&(d.opacity=parseFloat(t.opacity)),null!=t.miterLimit&&(d.miterLimit=parseFloat(t.miterLimit)),null!=t.overlay&&(d.overlay=!!t.overlay,h<v.maxLines&&(d.depth=2*(v.maxLines-1-h%v.maxLines)/v.maxLines-1)),null!=t.join&&(d.join=t.join),null!=t.hole&&(d.hole=t.hole),null!=t.fill&&(d.fill=t.fill?n(t.fill,\"uint8\"):null),null!=t.viewport&&(d.viewport=g(t.viewport)),d.viewport||(d.viewport=g([o.drawingBufferWidth,o.drawingBufferHeight])),null!=t.close&&(d.close=t.close),null===t.positions&&(t.positions=[]),t.positions){var m,y;if(t.positions.x&&t.positions.y){var x=t.positions.x,b=t.positions.y;y=d.count=Math.max(x.length,b.length),m=new Float64Array(2*y);for(var _=0;_<y;_++)m[2*_]=x[_],m[2*_+1]=b[_]}else m=l(t.positions,\"float64\"),y=d.count=Math.floor(m.length/2);var w=d.bounds=i(m,2);if(d.fill){for(var k=[],T={},A=0,M=0,S=0,E=d.count;M<E;M++){var C=m[2*M],L=m[2*M+1];isNaN(C)||isNaN(L)||null==C||null==L?(C=m[2*A],L=m[2*A+1],T[M]=A):A=M,k[S++]=C,k[S++]=L}for(var P=c(k,d.hole||[]),O=0,z=P.length;O<z;O++)null!=T[P[O]]&&(P[O]=T[P[O]]);d.triangles=P}var I=new Float64Array(m);u(I,2,w);var D=new Float64Array(2*y+6);d.close?m[0]===m[2*y-2]&&m[1]===m[2*y-1]?(D[0]=I[2*y-4],D[1]=I[2*y-3]):(D[0]=I[2*y-2],D[1]=I[2*y-1]):(D[0]=I[0],D[1]=I[1]),D.set(I,2),d.close?m[0]===m[2*y-2]&&m[1]===m[2*y-1]?(D[2*y+2]=I[2],D[2*y+3]=I[3],d.count-=1):(D[2*y+2]=I[0],D[2*y+3]=I[1],D[2*y+4]=I[2],D[2*y+5]=I[3]):(D[2*y+2]=I[2*y-2],D[2*y+3]=I[2*y-1],D[2*y+4]=I[2*y-2],D[2*y+5]=I[2*y-1]),d.positionBuffer(f(D)),d.positionFractBuffer(p(D))}if(t.range?d.range=t.range:d.range||(d.range=d.bounds),(t.range||t.positions)&&d.count){var R=d.bounds,F=R[2]-R[0],B=R[3]-R[1],N=d.range[2]-d.range[0],j=d.range[3]-d.range[1];d.scale=[F/N,B/j],d.translate=[-d.range[0]/N+R[0]/N||0,-d.range[1]/j+R[1]/j||0],d.scaleFract=p(d.scale),d.translateFract=p(d.translate)}if(t.dashes){var U,V=0;if(!t.dashes||t.dashes.length<2)V=1,U=new Uint8Array([255,255,255,255,255,255,255,255]);else{V=0;for(var q=0;q<t.dashes.length;++q)V+=t.dashes[q];U=new Uint8Array(V*v.dashMult);for(var H=0,G=255,Y=0;Y<2;Y++)for(var W=0;W<t.dashes.length;++W){for(var X=0,Z=t.dashes[W]*v.dashMult*.5;X<Z;++X)U[H++]=G;G^=255}}d.dashLength=V,d.dashTexture({channels:1,data:U,width:U.length,height:1,mag:\"linear\",min:\"linear\"},0,0)}if(t.color){var J=d.count,K=t.color;K||(K=\"transparent\");var $=new Uint8Array(4*J+4);if(Array.isArray(K)&&\"number\"!=typeof K[0]){for(var Q=0;Q<J;Q++){var tt=n(K[Q],\"uint8\");$.set(tt,4*Q)}$.set(n(K[0],\"uint8\"),4*J)}else for(var et=n(K,\"uint8\"),rt=0;rt<J+1;rt++)$.set(et,4*rt);d.colorBuffer({usage:\"dynamic\",type:\"uint8\",data:$})}}else e.passes[h]=null}),t.length<this.passes.length){for(var h=t.length;h<this.passes.length;h++){var d=e.passes[h];d&&(d.colorBuffer.destroy(),d.positionBuffer.destroy(),d.dashTexture.destroy())}this.passes.length=t.length}for(var m=[],y=0;y<this.passes.length;y++)null!==e.passes[y]&&m.push(e.passes[y]);return this.passes=m,this}},v.prototype.destroy=function(){return this.passes.forEach(function(t){t.colorBuffer.destroy(),t.positionBuffer.destroy(),t.dashTexture.destroy()}),this.passes.length=0,this}},{\"array-bounds\":65,\"array-normalize\":66,\"color-normalize\":120,earcut:492,\"es6-weak-map\":493,\"flatten-vertex-data\":227,glslify:409,\"object-assign\":454,\"parse-rect\":459,\"pick-by-alias\":465,\"to-float32\":538}],492:[function(t,e,r){\"use strict\";function n(t,e,r){r=r||2;var n,s,l,c,u,p,g,v=e&&e.length,m=v?e[0]*r:t.length,y=i(t,0,m,r,!0),x=[];if(!y||y.next===y.prev)return x;if(v&&(y=function(t,e,r,n){var o,s,l,c,u,p=[];for(o=0,s=e.length;o<s;o++)l=e[o]*n,c=o<s-1?e[o+1]*n:t.length,(u=i(t,l,c,n,!1))===u.next&&(u.steiner=!0),p.push(d(u));for(p.sort(h),o=0;o<p.length;o++)f(p[o],r),r=a(r,r.next);return r}(t,e,y,r)),t.length>80*r){n=l=t[0],s=c=t[1];for(var b=r;b<m;b+=r)(u=t[b])<n&&(n=u),(p=t[b+1])<s&&(s=p),u>l&&(l=u),p>c&&(c=p);g=0!==(g=Math.max(l-n,c-s))?1/g:0}return o(y,x,r,n,s,g),x}function i(t,e,r,n,i){var a,o;if(i===A(t,e,r,n)>0)for(a=e;a<r;a+=n)o=w(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=w(a,t[a],t[a+1],o);return o&&y(o,o.next)&&(k(o),o=o.next),o}function a(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!y(n,n.next)&&0!==m(n.prev,n,n.next))n=n.next;else{if(k(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function o(t,e,r,n,i,h,f){if(t){!f&&h&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=p(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,h);for(var d,g,v=t;t.prev!==t.next;)if(d=t.prev,g=t.next,h?l(t,n,i,h):s(t))e.push(d.i/r),e.push(t.i/r),e.push(g.i/r),k(t),t=g.next,v=g.next;else if((t=g)===v){f?1===f?o(t=c(t,e,r),e,r,n,i,h,2):2===f&&u(t,e,r,n,i,h):o(a(t),e,r,n,i,h,1);break}}}function s(t){var e=t.prev,r=t,n=t.next;if(m(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(g(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&m(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function l(t,e,r,n){var i=t.prev,a=t,o=t.next;if(m(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,h=p(s,l,e,r,n),f=p(c,u,e,r,n),d=t.prevZ,v=t.nextZ;d&&d.z>=h&&v&&v.z<=f;){if(d!==t.prev&&d!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&m(d.prev,d,d.next)>=0)return!1;if(d=d.prevZ,v!==t.prev&&v!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,v.x,v.y)&&m(v.prev,v,v.next)>=0)return!1;v=v.nextZ}for(;d&&d.z>=h;){if(d!==t.prev&&d!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&m(d.prev,d,d.next)>=0)return!1;d=d.prevZ}for(;v&&v.z<=f;){if(v!==t.prev&&v!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,v.x,v.y)&&m(v.prev,v,v.next)>=0)return!1;v=v.nextZ}return!0}function c(t,e,r){var n=t;do{var i=n.prev,a=n.next.next;!y(i,a)&&x(i,n,n.next,a)&&b(i,a)&&b(a,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(a.i/r),k(n),k(n.next),n=t=a),n=n.next}while(n!==t);return n}function u(t,e,r,n,i,s){var l=t;do{for(var c=l.next.next;c!==l.prev;){if(l.i!==c.i&&v(l,c)){var u=_(l,c);return l=a(l,l.next),u=a(u,u.next),o(l,e,r,n,i,s),void o(u,e,r,n,i,s)}c=c.next}l=l.next}while(l!==t)}function h(t,e){return t.x-e.x}function f(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r.prev;var l,c=r,u=r.x,h=r.y,f=1/0;n=r.next;for(;n!==c;)i>=n.x&&n.x>=u&&i!==n.x&&g(a<h?i:o,a,u,h,a<h?o:i,a,n.x,n.y)&&((l=Math.abs(a-n.y)/(i-n.x))<f||l===f&&n.x>r.x)&&b(n,t)&&(r=n,f=l),n=n.next;return r}(t,e)){var r=_(e,t);a(r,r.next)}}function p(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function d(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function g(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function v(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&x(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&b(t,e)&&b(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)}function m(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function y(t,e){return t.x===e.x&&t.y===e.y}function x(t,e,r,n){return!!(y(t,e)&&y(r,n)||y(t,n)&&y(r,e))||m(t,e,r)>0!=m(t,e,n)>0&&m(r,n,t)>0!=m(r,n,e)>0}function b(t,e){return m(t.prev,t,t.next)<0?m(t,e,t.next)>=0&&m(t,t.prev,e)>=0:m(t,e,t.prev)<0||m(t,t.next,e)<0}function _(t,e){var r=new T(t.i,t.x,t.y),n=new T(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function w(t,e,r,n){var i=new T(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function k(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function T(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function A(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}e.exports=n,e.exports.default=n,n.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(A(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(A(t,c,u,r))}var h=0;for(s=0;s<n.length;s+=3){var f=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;h+=Math.abs((t[f]-t[d])*(t[p+1]-t[f+1])-(t[f]-t[p])*(t[d+1]-t[f+1]))}return 0===o&&0===h?0:Math.abs((h-o)/o)},n.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r}},{}],493:[function(t,e,r){arguments[4][318][0].apply(r,arguments)},{\"./is-implemented\":494,\"./polyfill\":496,dup:318}],494:[function(t,e,r){arguments[4][319][0].apply(r,arguments)},{dup:319}],495:[function(t,e,r){arguments[4][320][0].apply(r,arguments)},{dup:320}],496:[function(t,e,r){arguments[4][321][0].apply(r,arguments)},{\"./is-native-implemented\":495,d:151,dup:321,\"es5-ext/object/is-value\":194,\"es5-ext/object/set-prototype-of\":200,\"es5-ext/object/valid-object\":204,\"es5-ext/object/valid-value\":205,\"es5-ext/string/random-uniq\":210,\"es6-iterator/for-of\":212,\"es6-iterator/get\":213,\"es6-symbol\":219}],497:[function(t,e,r){\"use strict\";function n(t,e){return function(t){if(Array.isArray(t))return t}(t)||function(t,e){var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{n||null==s.return||s.return()}finally{if(i)throw a}}return r}(t,e)||function(){throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")}()}function i(t){return function(t){if(Array.isArray(t)){for(var e=0,r=new Array(t.length);e<t.length;e++)r[e]=t[e];return r}}(t)||function(t){if(Symbol.iterator in Object(t)||\"[object Arguments]\"===Object.prototype.toString.call(t))return Array.from(t)}(t)||function(){throw new TypeError(\"Invalid attempt to spread non-iterable instance\")}()}var a=t(\"color-normalize\"),o=t(\"array-bounds\"),s=t(\"color-id\"),l=t(\"point-cluster\"),c=t(\"object-assign\"),u=t(\"glslify\"),h=t(\"pick-by-alias\"),f=t(\"update-diff\"),p=t(\"flatten-vertex-data\"),d=t(\"is-iexplorer\"),g=t(\"to-float32\"),v=t(\"parse-rect\"),m=y;function y(t,e){var r=this;if(!(this instanceof y))return new y(t,e);\"function\"==typeof t?(e||(e={}),e.regl=t):(e=t,t=null),e&&e.length&&(e.positions=e);var n,i=(t=e.regl)._gl,a=[];this.tooManyColors=d,n=t.texture({data:new Uint8Array(1020),width:255,height:1,type:\"uint8\",format:\"rgba\",wrapS:\"clamp\",wrapT:\"clamp\",mag:\"nearest\",min:\"nearest\"}),c(this,{regl:t,gl:i,groups:[],markerCache:[null],markerTextures:[null],palette:a,paletteIds:{},paletteTexture:n,maxColors:255,maxSize:100,canvas:i.canvas}),this.update(e);var o={uniforms:{pixelRatio:t.context(\"pixelRatio\"),palette:n,paletteSize:function(t,e){return[r.tooManyColors?0:255,n.height]},scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translate:t.prop(\"translate\"),translateFract:t.prop(\"translateFract\"),opacity:t.prop(\"opacity\"),marker:t.prop(\"markerTexture\")},attributes:{x:function(t,e){return e.xAttr||{buffer:e.positionBuffer,stride:8,offset:0}},y:function(t,e){return e.yAttr||{buffer:e.positionBuffer,stride:8,offset:4}},xFract:function(t,e){return e.xAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:0}},yFract:function(t,e){return e.yAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:4}},size:function(t,e){return e.size.length?{buffer:e.sizeBuffer,stride:2,offset:0}:{constant:[Math.round(255*e.size/r.maxSize)]}},borderSize:function(t,e){return e.borderSize.length?{buffer:e.sizeBuffer,stride:2,offset:1}:{constant:[Math.round(255*e.borderSize/r.maxSize)]}},colorId:function(t,e){return e.color.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:0}:{constant:r.tooManyColors?a.slice(4*e.color,4*e.color+4):[e.color]}},borderColorId:function(t,e){return e.borderColor.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:r.tooManyColors?4:2}:{constant:r.tooManyColors?a.slice(4*e.borderColor,4*e.borderColor+4):[e.borderColor]}},isActive:function(t,e){return!0===e.activation?{constant:[1]}:e.activation?e.activation:{constant:[0]}}},blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:{enable:!1},depth:{enable:!1},elements:t.prop(\"elements\"),count:t.prop(\"count\"),offset:t.prop(\"offset\"),primitive:\"points\"},s=c({},o);s.frag=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nuniform sampler2D marker;\\nuniform float pixelRatio, opacity;\\n\\nfloat smoothStep(float x, float y) {\\n  return 1.0 / (1.0 + exp(50.0*(x - y)));\\n}\\n\\nvoid main() {\\n  float dist = texture2D(marker, gl_PointCoord).r, delta = fragWidth;\\n\\n  // max-distance alpha\\n  if (dist < 0.003) discard;\\n\\n  // null-border case\\n  if (fragBorderColorLevel == fragColorLevel || fragBorderColor.a == 0.) {\\n    float colorAmt = smoothstep(.5 - delta, .5 + delta, dist);\\n    gl_FragColor = vec4(fragColor.rgb, colorAmt * fragColor.a * opacity);\\n  }\\n  else {\\n    float borderColorAmt = smoothstep(fragBorderColorLevel - delta, fragBorderColorLevel + delta, dist);\\n    float colorAmt = smoothstep(fragColorLevel - delta, fragColorLevel + delta, dist);\\n\\n    vec4 color = fragBorderColor;\\n    color.a *= borderColorAmt;\\n    color = mix(color, fragColor, colorAmt);\\n    color.a *= opacity;\\n\\n    gl_FragColor = color;\\n  }\\n\\n}\\n\"]),s.vert=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract, paletteSize;\\nuniform float pixelRatio;\\nuniform sampler2D palette;\\n\\nconst float maxSize = 100.;\\nconst float borderLevel = .5;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragPointSize, fragBorderRadius, fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = 2. * size * pixelRatio;\\n  fragPointSize = size * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\n  fragColor = color;\\n  fragBorderColor = borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n\\n  fragBorderColorLevel = clamp(borderLevel - borderLevel * borderSize / size, 0., 1.);\\n  fragColorLevel = clamp(borderLevel + (1. - borderLevel) * borderSize / size, 0., 1.);\\n}\"]),this.drawMarker=t(s);var l=c({},o);l.frag=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\n\\nuniform float opacity;\\nvarying float fragBorderRadius, fragWidth;\\n\\nfloat smoothStep(float edge0, float edge1, float x) {\\n\\tfloat t;\\n\\tt = clamp((x - edge0) / (edge1 - edge0), 0.0, 1.0);\\n\\treturn t * t * (3.0 - 2.0 * t);\\n}\\n\\nvoid main() {\\n\\tfloat radius, alpha = 1.0, delta = fragWidth;\\n\\n\\tradius = length(2.0 * gl_PointCoord.xy - 1.0);\\n\\n\\tif (radius > 1.0 + delta) {\\n\\t\\tdiscard;\\n\\t}\\n\\n\\talpha -= smoothstep(1.0 - delta, 1.0 + delta, radius);\\n\\n\\tfloat borderRadius = fragBorderRadius;\\n\\tfloat ratio = smoothstep(borderRadius - delta, borderRadius + delta, radius);\\n\\tvec4 color = mix(fragColor, fragBorderColor, ratio);\\n\\tcolor.a *= alpha * opacity;\\n\\tgl_FragColor = color;\\n}\\n\"]),l.vert=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio;\\nuniform sampler2D palette;\\nuniform vec2 paletteSize;\\n\\nconst float maxSize = 100.;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragBorderRadius, fragWidth;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  // ignore inactive points\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = (size + borderSize) * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\n  fragBorderRadius = 1. - 2. * borderSize / (size + borderSize);\\n  fragColor = color;\\n  fragBorderColor = borderColor.a == 0. || borderSize == 0. ? vec4(color.rgb, 0.) : borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n}\\n\"]),d&&(l.frag=l.frag.replace(\"smoothstep\",\"smoothStep\"),s.frag=s.frag.replace(\"smoothstep\",\"smoothStep\")),this.drawCircle=t(l)}y.defaults={color:\"black\",borderColor:\"transparent\",borderSize:0,size:12,opacity:1,marker:void 0,viewport:null,range:null,pixelSize:null,count:0,offset:0,bounds:null,positions:[],snap:1e4},y.prototype.render=function(){return arguments.length&&this.update.apply(this,arguments),this.draw(),this},y.prototype.draw=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var i=this.groups;if(1===r.length&&Array.isArray(r[0])&&(null===r[0][0]||Array.isArray(r[0][0]))&&(r=r[0]),this.regl._refresh(),r.length)for(var a=0;a<r.length;a++)this.drawItem(a,r[a]);else i.forEach(function(e,r){t.drawItem(r)});return this},y.prototype.drawItem=function(t,e){var r=this.groups,n=r[t];if(\"number\"==typeof e&&(t=e,n=r[e],e=null),n&&n.count&&n.opacity){n.activation[0]&&this.drawCircle(this.getMarkerDrawOptions(0,n,e));for(var a=[],o=1;o<n.activation.length;o++)n.activation[o]&&(!0===n.activation[o]||n.activation[o].data.length)&&a.push.apply(a,i(this.getMarkerDrawOptions(o,n,e)));a.length&&this.drawMarker(a)}},y.prototype.getMarkerDrawOptions=function(t,e,r){var i=e.range,a=e.tree,o=e.viewport,s=e.activation,l=e.selectionBuffer,u=e.count;this.regl;if(!a)return r?[c({},e,{markerTexture:this.markerTextures[t],activation:s[t],count:r.length,elements:r,offset:0})]:[c({},e,{markerTexture:this.markerTextures[t],activation:s[t],offset:0})];var h=[],f=a.range(i,{lod:!0,px:[(i[2]-i[0])/o.width,(i[3]-i[1])/o.height]});if(r){for(var p=s[t].data,d=new Uint8Array(u),g=0;g<r.length;g++){var v=r[g];d[v]=p?p[v]:1}l.subdata(d)}for(var m=f.length;m--;){var y=n(f[m],2),x=y[0],b=y[1];h.push(c({},e,{markerTexture:this.markerTextures[t],activation:r?l:s[t],offset:x,count:b-x}))}return h},y.prototype.update=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];if(r.length){1===r.length&&Array.isArray(r[0])&&(r=r[0]);var i=this.groups,a=this.gl,s=this.regl,u=this.maxSize,d=this.maxColors,m=this.palette;this.groups=i=r.map(function(e,r){var n=i[r];if(void 0===e)return n;null===e?e={positions:null}:\"function\"==typeof e?e={ondraw:e}:\"number\"==typeof e[0]&&(e={positions:e}),null===(e=h(e,{positions:\"positions data points\",snap:\"snap cluster lod tree\",size:\"sizes size radius\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",color:\"colors color fill fill-color fillColor\",borderColor:\"borderColors borderColor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range dataBox databox\",viewport:\"viewport viewPort viewBox viewbox\",opacity:\"opacity alpha transparency\",bounds:\"bound bounds boundaries limits\",tooManyColors:\"tooManyColors palette paletteMode optimizePalette enablePalette\"})).positions&&(e.positions=[]),null!=e.tooManyColors&&(t.tooManyColors=e.tooManyColors),n||(i[r]=n={id:r,scale:null,translate:null,scaleFract:null,translateFract:null,activation:[],selectionBuffer:s.buffer({data:new Uint8Array(0),usage:\"stream\",type:\"uint8\"}),sizeBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),colorBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),positionBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"}),positionFractBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"})},e=c({},y.defaults,e)),!e.positions||\"marker\"in e||(e.marker=n.marker,delete n.marker),!e.marker||\"positions\"in e||(e.positions=n.positions,delete n.positions);var x=0,b=0;if(f(n,e,[{snap:!0,size:function(t,e){return null==t&&(t=y.defaults.size),x+=t&&t.length?1:0,t},borderSize:function(t,e){return null==t&&(t=y.defaults.borderSize),x+=t&&t.length?1:0,t},opacity:parseFloat,color:function(e,r){return null==e&&(e=y.defaults.color),e=t.updateColor(e),b++,e},borderColor:function(e,r){return null==e&&(e=y.defaults.borderColor),e=t.updateColor(e),b++,e},bounds:function(t,e,r){return\"range\"in r||(r.range=null),t},positions:function(t,e,r){var n=e.snap,i=e.positionBuffer,a=e.positionFractBuffer,c=e.selectionBuffer;if(t.x||t.y)return t.x.length?e.xAttr={buffer:s.buffer(t.x),offset:0,stride:4,count:t.x.length}:e.xAttr={buffer:t.x.buffer,offset:4*t.x.offset||0,stride:4*(t.x.stride||1),count:t.x.count},t.y.length?e.yAttr={buffer:s.buffer(t.y),offset:0,stride:4,count:t.y.length}:e.yAttr={buffer:t.y.buffer,offset:4*t.y.offset||0,stride:4*(t.y.stride||1),count:t.y.count},e.count=Math.max(e.xAttr.count,e.yAttr.count),t;t=p(t,\"float64\");var u=e.count=Math.floor(t.length/2),h=e.bounds=u?o(t,2):null;if(r.range||e.range||(delete e.range,r.range=h),r.marker||e.marker||(delete e.marker,r.marker=null),n&&(!0===n||u>n)?e.tree=l(t,{bounds:h}):n&&n.length&&(e.tree=n),e.tree){var f={primitive:\"points\",usage:\"static\",data:e.tree,type:\"uint32\"};e.elements?e.elements(f):e.elements=s.elements(f)}return i({data:g.float(t),usage:\"dynamic\"}),a({data:g.fract(t),usage:\"dynamic\"}),c({data:new Uint8Array(u),type:\"uint8\",usage:\"stream\"}),t}},{marker:function(e,r,n){var i=r.activation;if(i.forEach(function(t){return t&&t.destroy&&t.destroy()}),i.length=0,e&&\"number\"!=typeof e[0]){for(var a=[],o=0,l=Math.min(e.length,r.count);o<l;o++){var c=t.addMarker(e[o]);a[c]||(a[c]=new Uint8Array(r.count)),a[c][o]=1}for(var u=0;u<a.length;u++)if(a[u]){var h={data:a[u],type:\"uint8\",usage:\"static\"};i[u]?i[u](h):i[u]=s.buffer(h),i[u].data=a[u]}}else{i[t.addMarker(e)]=!0}return e},range:function(t,e,r){var n=e.bounds;if(n)return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=g.fract(e.scale),e.translateFract=g.fract(e.translate),t},viewport:function(t){return v(t||[a.drawingBufferWidth,a.drawingBufferHeight])}}]),x){var _=n,w=_.count,k=_.size,T=_.borderSize,A=_.sizeBuffer,M=new Uint8Array(2*w);if(k.length||T.length)for(var S=0;S<w;S++)M[2*S]=Math.round(255*(null==k[S]?k:k[S])/u),M[2*S+1]=Math.round(255*(null==T[S]?T:T[S])/u);A({data:M,usage:\"dynamic\"})}if(b){var E,C=n,L=C.count,P=C.color,O=C.borderColor,z=C.colorBuffer;if(t.tooManyColors){if(P.length||O.length){E=new Uint8Array(8*L);for(var I=0;I<L;I++){var D=P[I];E[8*I]=m[4*D],E[8*I+1]=m[4*D+1],E[8*I+2]=m[4*D+2],E[8*I+3]=m[4*D+3];var R=O[I];E[8*I+4]=m[4*R],E[8*I+5]=m[4*R+1],E[8*I+6]=m[4*R+2],E[8*I+7]=m[4*R+3]}}}else if(P.length||O.length){E=new Uint8Array(4*L+2);for(var F=0;F<L;F++)null!=P[F]&&(E[4*F]=P[F]%d,E[4*F+1]=Math.floor(P[F]/d)),null!=O[F]&&(E[4*F+2]=O[F]%d,E[4*F+3]=Math.floor(O[F]/d))}z({data:E||new Uint8Array(0),type:\"uint8\",usage:\"dynamic\"})}return n})}},y.prototype.addMarker=function(t){var e,r=this.markerTextures,n=this.regl,i=this.markerCache,a=null==t?0:i.indexOf(t);if(a>=0)return a;if(t instanceof Uint8Array||t instanceof Uint8ClampedArray)e=t;else{e=new Uint8Array(t.length);for(var o=0,s=t.length;o<s;o++)e[o]=255*t[o]}var l=Math.floor(Math.sqrt(e.length));return a=r.length,i.push(t),r.push(n.texture({channels:1,data:e,radius:l,mag:\"linear\",min:\"linear\"})),a},y.prototype.updateColor=function(t){var e=this.paletteIds,r=this.palette,n=this.maxColors;Array.isArray(t)||(t=[t]);var i=[];if(\"number\"==typeof t[0]){var o=[];if(Array.isArray(t))for(var l=0;l<t.length;l+=4)o.push(t.slice(l,l+4));else for(var c=0;c<t.length;c+=4)o.push(t.subarray(c,c+4));t=o}for(var u=0;u<t.length;u++){var h=t[u];h=a(h,\"uint8\");var f=s(h,!1);if(null==e[f]){var p=r.length;e[f]=Math.floor(p/4),r[p]=h[0],r[p+1]=h[1],r[p+2]=h[2],r[p+3]=h[3]}i[u]=e[f]}return!this.tooManyColors&&r.length>4*n&&(this.tooManyColors=!0),this.updatePalette(r),1===i.length?i[0]:i},y.prototype.updatePalette=function(t){if(!this.tooManyColors){var e=this.maxColors,r=this.paletteTexture,n=Math.ceil(.25*t.length/e);if(n>1)for(var i=.25*(t=t.slice()).length%e;i<n*e;i++)t.push(0,0,0,0);r.height<n&&r.resize(e,n),r.subimage({width:Math.min(.25*t.length,e),height:n,data:t},0,0)}},y.prototype.destroy=function(){return this.groups.forEach(function(t){t.sizeBuffer.destroy(),t.positionBuffer.destroy(),t.positionFractBuffer.destroy(),t.colorBuffer.destroy(),t.activation.forEach(function(t){return t&&t.destroy&&t.destroy()}),t.selectionBuffer.destroy(),t.elements&&t.elements.destroy()}),this.groups.length=0,this.paletteTexture.destroy(),this.markerTextures.forEach(function(t){return t&&t.destroy&&t.destroy()}),this};var x=t(\"object-assign\");e.exports=function(t,e){var r=new m(t,e),n=r.render.bind(r);return x(n,{render:n,update:r.update.bind(r),draw:r.draw.bind(r),destroy:r.destroy.bind(r),regl:r.regl,gl:r.gl,canvas:r.gl.canvas,groups:r.groups,markers:r.markerCache,palette:r.palette}),n}},{\"array-bounds\":65,\"color-id\":118,\"color-normalize\":120,\"flatten-vertex-data\":227,glslify:409,\"is-iexplorer\":419,\"object-assign\":454,\"parse-rect\":459,\"pick-by-alias\":465,\"point-cluster\":499,\"to-float32\":538,\"update-diff\":549}],498:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],499:[function(t,e,r){\"use strict\";e.exports=t(\"./quad\")},{\"./quad\":500}],500:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"clamp\"),a=t(\"parse-rect\"),o=t(\"array-bounds\"),s=t(\"pick-by-alias\"),l=t(\"defined\"),c=t(\"flatten-vertex-data\"),u=t(\"is-obj\"),h=t(\"dtype\"),f=t(\"math-log2\"),p=1073741824;function d(t,e){for(var r=e[0],n=e[1],a=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=i((t[2*l]-r)*a,0,1),s[2*l+1]=i((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,\"float64\"),e=s(e,{bounds:\"range bounds dataBox databox\",maxDepth:\"depth maxDepth maxdepth level maxLevel maxlevel levels\",dtype:\"type dtype format out dst output destination\"});var r=l(e.maxDepth,255),i=l(e.bounds,o(t,2));i[0]===i[2]&&i[2]++,i[1]===i[3]&&i[3]++;var g,v=d(t,i),m=t.length>>>1;e.dtype||(e.dtype=\"array\"),\"string\"==typeof e.dtype?g=new(h(e.dtype))(m):e.dtype&&(g=e.dtype,Array.isArray(g)&&(g.length=m));for(var y=0;y<m;++y)g[y]=y;var x=[],b=[],_=[],w=[];!function t(e,n,i,a,o,s){if(!a.length)return null;var l=x[o]||(x[o]=[]);var c=_[o]||(_[o]=[]);var u=b[o]||(b[o]=[]);var h=l.length;o++;if(o>r||s>p){for(var f=0;f<a.length;f++)l.push(a[f]),c.push(s),u.push(null,null,null,null);return h}l.push(a[0]);c.push(s);if(a.length<=1)return u.push(null,null,null,null),h;var d=.5*i;var g=e+d,m=n+d;var y=[],w=[],k=[],T=[];for(var A=1,M=a.length;A<M;A++){var S=a[A],E=v[2*S],C=v[2*S+1];E<g?C<m?y.push(S):w.push(S):C<m?k.push(S):T.push(S)}s<<=2;u.push(t(e,n,d,y,o,s),t(e,m,d,w,o,s+1),t(g,n,d,k,o,s+2),t(g,m,d,T,o,s+3));return h}(0,0,1,g,0,1);for(var k=0,T=0;T<x.length;T++){var A=x[T];if(g.set)g.set(A,k);else for(var M=0,S=A.length;M<S;M++)g[M+k]=A[M];var E=k+x[T].length;w[T]=[k,E],k=E}return g.range=function(){var e,r=[],o=arguments.length;for(;o--;)r[o]=arguments[o];if(u(r[r.length-1])){var c=r.pop();r.length||null==c.x&&null==c.l&&null==c.left||(r=[c],e={}),e=s(c,{level:\"level maxLevel\",d:\"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize\",lod:\"lod details ranges offsets\"})}else e={};r.length||(r=i);var h=a.apply(void 0,r),p=[Math.min(h.x,h.x+h.width),Math.min(h.y,h.y+h.height),Math.max(h.x,h.x+h.width),Math.max(h.y,h.y+h.height)],g=p[0],v=p[1],m=p[2],y=p[3],k=d([g,v,m,y],i),T=k[0],A=k[1],M=k[2],S=k[3],E=l(e.level,x.length);if(null!=e.d){var L;\"number\"==typeof e.d?L=[e.d,e.d]:e.d.length&&(L=e.d),E=Math.min(Math.max(Math.ceil(-f(Math.abs(L[0])/(i[2]-i[0]))),Math.ceil(-f(Math.abs(L[1])/(i[3]-i[1])))),E)}if(E=Math.min(E,x.length),e.lod)return function(t,e,r,i,a){for(var o=[],s=0;s<a;s++){var l=_[s],c=w[s][0],u=C(t,e,s),h=C(r,i,s),f=n.ge(l,u),p=n.gt(l,h,f,l.length-1);o[s]=[f+c,p+c]}return o}(T,A,M,S,E);var P=[];return function e(r,n,i,a,o,s){if(null!==o&&null!==s){var l=r+i,c=n+i;if(!(T>l||A>c||M<r||S<n||a>=E||o===s)){var u=x[a];void 0===s&&(s=u.length);for(var h=o;h<s;h++){var f=u[h],p=t[2*f],d=t[2*f+1];p>=g&&p<=m&&d>=v&&d<=y&&P.push(f)}var _=b[a],w=_[4*o+0],k=_[4*o+1],C=_[4*o+2],L=_[4*o+3],O=function(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}(_,o+1),z=.5*i,I=a+1;e(r,n,z,I,w,k||C||L||O),e(r,n+z,z,I,k,C||L||O),e(r+z,n,z,I,C,L||O),e(r+z,n+z,z,I,L,O)}}}(0,0,1,0,0,1),P},g;function C(t,e,r){for(var n=1,i=.5,a=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<i?e<a?0:1:e<a?2:3,o*=.5,i+=t<i?-o:o,a+=e<a?-o:o;return n}}},{\"array-bounds\":65,\"binary-search-bounds\":498,clamp:115,defined:164,dtype:169,\"flatten-vertex-data\":227,\"is-obj\":421,\"math-log2\":432,\"parse-rect\":459,\"pick-by-alias\":465}],501:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"pick-by-alias\"),a=t(\"array-bounds\"),o=t(\"raf\"),s=t(\"array-range\"),l=t(\"parse-rect\"),c=t(\"flatten-vertex-data\");function u(t,e){if(!(this instanceof u))return new u(t,e);this.traces=[],this.passes={},this.regl=t,this.scatter=n(t),this.canvas=this.scatter.canvas}function h(t,e,r){return(null!=t.id?t.id:t)<<16|(255&e)<<8|255&r}function f(t,e,r){var n,i,a,o,s=t[e],l=t[r];return s.length>2?(s[0],s[2],n=s[1],i=s[3]):s.length?(n=s[0],i=s[1]):(s.x,n=s.y,s.x+s.width,i=s.y+s.height),l.length>2?(a=l[0],o=l[2],l[1],l[3]):l.length?(a=l[0],o=l[1]):(a=l.x,l.y,o=l.x+l.width,l.y+l.height),[a,n,o,i]}function p(t){if(\"number\"==typeof t)return[t,t,t,t];if(2===t.length)return[t[0],t[1],t[0],t[1]];var e=l(t);return[e.x,e.y,e.x+e.width,e.y+e.height]}e.exports=u,u.prototype.render=function(){for(var t,e=this,r=[],n=arguments.length;n--;)r[n]=arguments[n];return r.length&&(t=this).update.apply(t,r),this.regl.attributes.preserveDrawingBuffer?this.draw():(this.dirty?null==this.planned&&(this.planned=o(function(){e.draw(),e.dirty=!0,e.planned=null})):(this.draw(),this.dirty=!0,o(function(){e.dirty=!1})),this)},u.prototype.update=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=0;n<e.length;n++)this.updateItem(n,e[n]);this.traces=this.traces.filter(Boolean);for(var i=[],a=0,o=0;o<this.traces.length;o++){for(var s=this.traces[o],l=this.traces[o].passes,c=0;c<l.length;c++)i.push(this.passes[l[c]]);s.passOffset=a,a+=s.passes.length}return(t=this.scatter).update.apply(t,i),this}},u.prototype.updateItem=function(t,e){var r=this.regl;if(null===e)return this.traces[t]=null,this;if(!e)return this;var n,o=i(e,{data:\"data items columns rows values dimensions samples x\",snap:\"snap cluster\",size:\"sizes size radius\",color:\"colors color fill fill-color fillColor\",opacity:\"opacity alpha transparency opaque\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",borderColor:\"borderColors borderColor bordercolor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range ranges databox dataBox\",viewport:\"viewport viewBox viewbox\",domain:\"domain domains area areas\",padding:\"pad padding paddings pads margin margins\",transpose:\"transpose transposed\",diagonal:\"diagonal diag showDiagonal\",upper:\"upper up top upperhalf upperHalf showupperhalf showUpper showUpperHalf\",lower:\"lower low bottom lowerhalf lowerHalf showlowerhalf showLowerHalf showLower\"}),s=this.traces[t]||(this.traces[t]={id:t,buffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),color:\"black\",marker:null,size:12,borderColor:\"transparent\",borderSize:1,viewport:l([r._gl.drawingBufferWidth,r._gl.drawingBufferHeight]),padding:[0,0,0,0],opacity:1,diagonal:!0,upper:!0,lower:!0});if(null!=o.color&&(s.color=o.color),null!=o.size&&(s.size=o.size),null!=o.marker&&(s.marker=o.marker),null!=o.borderColor&&(s.borderColor=o.borderColor),null!=o.borderSize&&(s.borderSize=o.borderSize),null!=o.opacity&&(s.opacity=o.opacity),o.viewport&&(s.viewport=l(o.viewport)),null!=o.diagonal&&(s.diagonal=o.diagonal),null!=o.upper&&(s.upper=o.upper),null!=o.lower&&(s.lower=o.lower),o.data){s.buffer(c(o.data)),s.columns=o.data.length,s.count=o.data[0].length,s.bounds=[];for(var u=0;u<s.columns;u++)s.bounds[u]=a(o.data[u],1)}o.range&&(s.range=o.range,n=s.range&&\"number\"!=typeof s.range[0]),o.domain&&(s.domain=o.domain);var d=!1;null!=o.padding&&(Array.isArray(o.padding)&&o.padding.length===s.columns&&\"number\"==typeof o.padding[o.padding.length-1]?(s.padding=o.padding.map(p),d=!0):s.padding=p(o.padding));var g=s.columns,v=s.count,m=s.viewport.width,y=s.viewport.height,x=s.viewport.x,b=s.viewport.y,_=m/g,w=y/g;s.passes=[];for(var k=0;k<g;k++)for(var T=0;T<g;T++)if((s.diagonal||T!==k)&&(s.upper||!(k>T))&&(s.lower||!(k<T))){var A=h(s.id,k,T),M=this.passes[A]||(this.passes[A]={});if(o.data&&(o.transpose?M.positions={x:{buffer:s.buffer,offset:T,count:v,stride:g},y:{buffer:s.buffer,offset:k,count:v,stride:g}}:M.positions={x:{buffer:s.buffer,offset:T*v,count:v},y:{buffer:s.buffer,offset:k*v,count:v}},M.bounds=f(s.bounds,k,T)),o.domain||o.viewport||o.data){var S=d?f(s.padding,k,T):s.padding;if(s.domain){var E=f(s.domain,k,T),C=E[0],L=E[1],P=E[2],O=E[3];M.viewport=[x+C*m+S[0],b+L*y+S[1],x+P*m-S[2],b+O*y-S[3]]}else M.viewport=[x+T*_+_*S[0],b+k*w+w*S[1],x+(T+1)*_-_*S[2],b+(k+1)*w-w*S[3]]}o.color&&(M.color=s.color),o.size&&(M.size=s.size),o.marker&&(M.marker=s.marker),o.borderSize&&(M.borderSize=s.borderSize),o.borderColor&&(M.borderColor=s.borderColor),o.opacity&&(M.opacity=s.opacity),o.range&&(M.range=n?f(s.range,k,T):s.range||M.bounds),s.passes.push(A)}return this},u.prototype.draw=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=[],i=0;i<e.length;i++)if(\"number\"==typeof e[i]){var a=this.traces[e[i]],o=a.passes,l=a.passOffset;n.push.apply(n,s(l,l+o.length))}else if(e[i].length){var c=e[i],u=this.traces[i],h=u.passes,f=u.passOffset;h=h.map(function(t,e){n[f+e]=c})}(t=this.scatter).draw.apply(t,n)}else this.scatter.draw();return this},u.prototype.destroy=function(){return this.traces.forEach(function(t){t.buffer&&t.buffer.destroy&&t.buffer.destroy()}),this.traces=null,this.passes=null,this.scatter.destroy(),this}},{\"array-bounds\":65,\"array-range\":67,\"flatten-vertex-data\":227,\"parse-rect\":459,\"pick-by-alias\":465,raf:484,\"regl-scatter2d\":497}],502:[function(t,e,r){var n,i;n=this,i=function(){function t(t,e){this.id=U++,this.type=t,this.data=e}function e(t){return\"[\"+function t(e){if(0===e.length)return[];var r=e.charAt(0),n=e.charAt(e.length-1);if(1<e.length&&r===n&&('\"'===r||\"'\"===r))return['\"'+e.substr(1,e.length-2).replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];if(r=/\\[(false|true|null|\\d+|'[^']*'|\"[^\"]*\")\\]/.exec(e))return t(e.substr(0,r.index)).concat(t(r[1])).concat(t(e.substr(r.index+r[0].length)));if(1===(r=e.split(\".\")).length)return['\"'+e.replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];for(e=[],n=0;n<r.length;++n)e=e.concat(t(r[n]));return e}(t).join(\"][\")+\"]\"}function r(t){return\"string\"==typeof t?t.split():t}function n(t){return\"string\"==typeof t?document.querySelector(t):t}function i(t){var e,i,a,o,s=t||{};t={};var l=[],c=[],u=\"undefined\"==typeof window?1:window.devicePixelRatio,h=!1,f=function(t){},p=function(){};if(\"string\"==typeof s?e=document.querySelector(s):\"object\"==typeof s&&(\"string\"==typeof s.nodeName&&\"function\"==typeof s.appendChild&&\"function\"==typeof s.getBoundingClientRect?e=s:\"function\"==typeof s.drawArrays||\"function\"==typeof s.drawElements?a=(o=s).canvas:(\"gl\"in s?o=s.gl:\"canvas\"in s?a=n(s.canvas):\"container\"in s&&(i=n(s.container)),\"attributes\"in s&&(t=s.attributes),\"extensions\"in s&&(l=r(s.extensions)),\"optionalExtensions\"in s&&(c=r(s.optionalExtensions)),\"onDone\"in s&&(f=s.onDone),\"profile\"in s&&(h=!!s.profile),\"pixelRatio\"in s&&(u=+s.pixelRatio))),e&&(\"canvas\"===e.nodeName.toLowerCase()?a=e:i=e),!o){if(!a){if(!(e=function(t,e,r){function n(){var e=window.innerWidth,n=window.innerHeight;t!==document.body&&(e=(n=t.getBoundingClientRect()).right-n.left,n=n.bottom-n.top),i.width=r*e,i.height=r*n,j(i.style,{width:e+\"px\",height:n+\"px\"})}var i=document.createElement(\"canvas\");return j(i.style,{border:0,margin:0,padding:0,top:0,left:0}),t.appendChild(i),t===document.body&&(i.style.position=\"absolute\",j(t.style,{margin:0,padding:0})),window.addEventListener(\"resize\",n,!1),n(),{canvas:i,onDestroy:function(){window.removeEventListener(\"resize\",n),t.removeChild(i)}}}(i||document.body,0,u)))return null;a=e.canvas,p=e.onDestroy}o=function(t,e){function r(r){try{return t.getContext(r,e)}catch(t){return null}}return r(\"webgl\")||r(\"experimental-webgl\")||r(\"webgl-experimental\")}(a,t)}return o?{gl:o,canvas:a,container:i,extensions:l,optionalExtensions:c,pixelRatio:u,profile:h,onDone:f,onDestroy:p}:(p(),f(\"webgl not supported, try upgrading your browser or graphics drivers http://get.webgl.org\"),null)}function a(t,e){for(var r=Array(t),n=0;n<t;++n)r[n]=e(n);return r}function o(t){var e,r;return e=(65535<t)<<4,e|=r=(255<(t>>>=e))<<3,(e|=r=(15<(t>>>=r))<<2)|(r=(3<(t>>>=r))<<1)|t>>>r>>1}function s(){function t(t){t:{for(var e=16;268435456>=e;e*=16)if(t<=e){t=e;break t}t=0}return 0<(e=r[o(t)>>2]).length?e.pop():new ArrayBuffer(t)}function e(t){r[o(t.byteLength)>>2].push(t)}var r=a(8,function(){return[]});return{alloc:t,free:e,allocType:function(e,r){var n=null;switch(e){case 5120:n=new Int8Array(t(r),0,r);break;case 5121:n=new Uint8Array(t(r),0,r);break;case 5122:n=new Int16Array(t(2*r),0,r);break;case 5123:n=new Uint16Array(t(2*r),0,r);break;case 5124:n=new Int32Array(t(4*r),0,r);break;case 5125:n=new Uint32Array(t(4*r),0,r);break;case 5126:n=new Float32Array(t(4*r),0,r);break;default:return null}return n.length!==r?n.subarray(0,r):n},freeType:function(t){e(t.buffer)}}}function l(t){return!!t&&\"object\"==typeof t&&Array.isArray(t.shape)&&Array.isArray(t.stride)&&\"number\"==typeof t.offset&&t.shape.length===t.stride.length&&(Array.isArray(t.data)||W(t.data))}function c(t,e,r,n,i,a){for(var o=0;o<e;++o)for(var s=t[o],l=0;l<r;++l)for(var c=s[l],u=0;u<n;++u)i[a++]=c[u]}function u(t){return 0|J[Object.prototype.toString.call(t)]}function h(t,e){for(var r=0;r<e.length;++r)t[r]=e[r]}function f(t,e,r,n,i,a,o){for(var s=0,l=0;l<r;++l)for(var c=0;c<n;++c)t[s++]=e[i*l+a*c+o]}function p(t,e,r,n){function i(e){this.id=c++,this.buffer=t.createBuffer(),this.type=e,this.usage=35044,this.byteLength=0,this.dimension=1,this.dtype=5121,this.persistentData=null,r.profile&&(this.stats={size:0})}function a(e,r,n){e.byteLength=r.byteLength,t.bufferData(e.type,r,n)}function o(t,e,r,n,i,o){if(t.usage=r,Array.isArray(e)){if(t.dtype=n||5126,0<e.length)if(Array.isArray(e[0])){i=tt(e);for(var s=n=1;s<i.length;++s)n*=i[s];t.dimension=n,a(t,e=Q(e,i,t.dtype),r),o?t.persistentData=e:G.freeType(e)}else\"number\"==typeof e[0]?(t.dimension=i,h(i=G.allocType(t.dtype,e.length),e),a(t,i,r),o?t.persistentData=i:G.freeType(i)):W(e[0])&&(t.dimension=e[0].length,t.dtype=n||u(e[0])||5126,a(t,e=Q(e,[e.length,e[0].length],t.dtype),r),o?t.persistentData=e:G.freeType(e))}else if(W(e))t.dtype=n||u(e),t.dimension=i,a(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e.buffer)));else if(l(e)){i=e.shape;var c=e.stride,p=(s=e.offset,0),d=0,g=0,v=0;1===i.length?(p=i[0],d=1,g=c[0],v=0):2===i.length&&(p=i[0],d=i[1],g=c[0],v=c[1]),t.dtype=n||u(e.data)||5126,t.dimension=d,f(i=G.allocType(t.dtype,p*d),e.data,p,d,g,v,s),a(t,i,r),o?t.persistentData=i:G.freeType(i)}}function s(r){e.bufferCount--;for(var i=0;i<n.state.length;++i){var a=n.state[i];a.buffer===r&&(t.disableVertexAttribArray(i),a.buffer=null)}t.deleteBuffer(r.buffer),r.buffer=null,delete p[r.id]}var c=0,p={};i.prototype.bind=function(){t.bindBuffer(this.type,this.buffer)},i.prototype.destroy=function(){s(this)};var d=[];return r.profile&&(e.getTotalBufferSize=function(){var t=0;return Object.keys(p).forEach(function(e){t+=p[e].stats.size}),t}),{create:function(n,a,c,d){function g(e){var n=35044,i=null,a=0,s=0,c=1;return Array.isArray(e)||W(e)||l(e)?i=e:\"number\"==typeof e?a=0|e:e&&(\"data\"in e&&(i=e.data),\"usage\"in e&&(n=$[e.usage]),\"type\"in e&&(s=K[e.type]),\"dimension\"in e&&(c=0|e.dimension),\"length\"in e&&(a=0|e.length)),v.bind(),i?o(v,i,n,s,c,d):(a&&t.bufferData(v.type,a,n),v.dtype=s||5121,v.usage=n,v.dimension=c,v.byteLength=a),r.profile&&(v.stats.size=v.byteLength*et[v.dtype]),g}e.bufferCount++;var v=new i(a);return p[v.id]=v,c||g(n),g._reglType=\"buffer\",g._buffer=v,g.subdata=function(e,r){var n,i=0|(r||0);if(v.bind(),W(e))t.bufferSubData(v.type,i,e);else if(Array.isArray(e)){if(0<e.length)if(\"number\"==typeof e[0]){var a=G.allocType(v.dtype,e.length);h(a,e),t.bufferSubData(v.type,i,a),G.freeType(a)}else(Array.isArray(e[0])||W(e[0]))&&(n=tt(e),a=Q(e,n,v.dtype),t.bufferSubData(v.type,i,a),G.freeType(a))}else if(l(e)){n=e.shape;var o=e.stride,s=a=0,c=0,p=0;1===n.length?(a=n[0],s=1,c=o[0],p=0):2===n.length&&(a=n[0],s=n[1],c=o[0],p=o[1]),n=Array.isArray(e.data)?v.dtype:u(e.data),f(n=G.allocType(n,a*s),e.data,a,s,c,p,e.offset),t.bufferSubData(v.type,i,n),G.freeType(n)}return g},r.profile&&(g.stats=v.stats),g.destroy=function(){s(v)},g},createStream:function(t,e){var r=d.pop();return r||(r=new i(t)),r.bind(),o(r,e,35040,0,1,!1),r},destroyStream:function(t){d.push(t)},clear:function(){X(p).forEach(s),d.forEach(s)},getBuffer:function(t){return t&&t._buffer instanceof i?t._buffer:null},restore:function(){X(p).forEach(function(e){e.buffer=t.createBuffer(),t.bindBuffer(e.type,e.buffer),t.bufferData(e.type,e.persistentData||e.byteLength,e.usage)})},_initBuffer:o}}function d(t,e,r,n){function i(t){this.id=c++,s[this.id]=this,this.buffer=t,this.primType=4,this.type=this.vertCount=0}function a(n,i,a,o,s,c,u){if(n.buffer.bind(),i){var h=u;u||W(i)&&(!l(i)||W(i.data))||(h=e.oes_element_index_uint?5125:5123),r._initBuffer(n.buffer,i,a,h,3)}else t.bufferData(34963,c,a),n.buffer.dtype=h||5121,n.buffer.usage=a,n.buffer.dimension=3,n.buffer.byteLength=c;if(h=u,!u){switch(n.buffer.dtype){case 5121:case 5120:h=5121;break;case 5123:case 5122:h=5123;break;case 5125:case 5124:h=5125}n.buffer.dtype=h}n.type=h,0>(i=s)&&(i=n.buffer.byteLength,5123===h?i>>=1:5125===h&&(i>>=2)),n.vertCount=i,i=o,0>o&&(i=4,1===(o=n.buffer.dimension)&&(i=0),2===o&&(i=1),3===o&&(i=4)),n.primType=i}function o(t){n.elementsCount--,delete s[t.id],t.buffer.destroy(),t.buffer=null}var s={},c=0,u={uint8:5121,uint16:5123};e.oes_element_index_uint&&(u.uint32=5125),i.prototype.bind=function(){this.buffer.bind()};var h=[];return{create:function(t,e){function s(t){if(t)if(\"number\"==typeof t)c(t),h.primType=4,h.vertCount=0|t,h.type=5121;else{var e=null,r=35044,n=-1,i=-1,o=0,f=0;Array.isArray(t)||W(t)||l(t)?e=t:(\"data\"in t&&(e=t.data),\"usage\"in t&&(r=$[t.usage]),\"primitive\"in t&&(n=rt[t.primitive]),\"count\"in t&&(i=0|t.count),\"type\"in t&&(f=u[t.type]),\"length\"in t?o=0|t.length:(o=i,5123===f||5122===f?o*=2:5125!==f&&5124!==f||(o*=4))),a(h,e,r,n,i,o,f)}else c(),h.primType=4,h.vertCount=0,h.type=5121;return s}var c=r.create(null,34963,!0),h=new i(c._buffer);return n.elementsCount++,s(t),s._reglType=\"elements\",s._elements=h,s.subdata=function(t,e){return c.subdata(t,e),s},s.destroy=function(){o(h)},s},createStream:function(t){var e=h.pop();return e||(e=new i(r.create(null,34963,!0,!1)._buffer)),a(e,t,35040,-1,-1,0,0),e},destroyStream:function(t){h.push(t)},getElements:function(t){return\"function\"==typeof t&&t._elements instanceof i?t._elements:null},clear:function(){X(s).forEach(o)}}}function g(t){for(var e=G.allocType(5123,t.length),r=0;r<t.length;++r)if(isNaN(t[r]))e[r]=65535;else if(1/0===t[r])e[r]=31744;else if(-1/0===t[r])e[r]=64512;else{nt[0]=t[r];var n=(a=it[0])>>>31<<15,i=(a<<1>>>24)-127,a=a>>13&1023;e[r]=-24>i?n:-14>i?n+(a+1024>>-14-i):15<i?n+31744:n+(i+15<<10)+a}return e}function v(t){return Array.isArray(t)||W(t)}function m(t){return\"[object \"+t+\"]\"}function y(t){return Array.isArray(t)&&(0===t.length||\"number\"==typeof t[0])}function x(t){return!(!Array.isArray(t)||0===t.length||!v(t[0]))}function b(t){return Object.prototype.toString.call(t)}function _(t){if(!t)return!1;var e=b(t);return 0<=pt.indexOf(e)||(y(t)||x(t)||l(t))}function w(t,e){36193===t.type?(t.data=g(e),G.freeType(e)):t.data=e}function k(t,e,r,n,i,a){if(t=\"undefined\"!=typeof gt[t]?gt[t]:st[t]*dt[e],a&&(t*=6),i){for(n=0;1<=r;)n+=t*r*r,r/=2;return n}return t*r*n}function T(t,e,r,n,i,a,o){function s(){this.format=this.internalformat=6408,this.type=5121,this.flipY=this.premultiplyAlpha=this.compressed=!1,this.unpackAlignment=1,this.colorSpace=37444,this.channels=this.height=this.width=0}function c(t,e){t.internalformat=e.internalformat,t.format=e.format,t.type=e.type,t.compressed=e.compressed,t.premultiplyAlpha=e.premultiplyAlpha,t.flipY=e.flipY,t.unpackAlignment=e.unpackAlignment,t.colorSpace=e.colorSpace,t.width=e.width,t.height=e.height,t.channels=e.channels}function u(t,e){if(\"object\"==typeof e&&e){\"premultiplyAlpha\"in e&&(t.premultiplyAlpha=e.premultiplyAlpha),\"flipY\"in e&&(t.flipY=e.flipY),\"alignment\"in e&&(t.unpackAlignment=e.alignment),\"colorSpace\"in e&&(t.colorSpace=q[e.colorSpace]),\"type\"in e&&(t.type=H[e.type]);var r=t.width,n=t.height,i=t.channels,a=!1;\"shape\"in e?(r=e.shape[0],n=e.shape[1],3===e.shape.length&&(i=e.shape[2],a=!0)):(\"radius\"in e&&(r=n=e.radius),\"width\"in e&&(r=e.width),\"height\"in e&&(n=e.height),\"channels\"in e&&(i=e.channels,a=!0)),t.width=0|r,t.height=0|n,t.channels=0|i,r=!1,\"format\"in e&&(r=e.format,n=t.internalformat=Y[r],t.format=pt[n],r in H&&!(\"type\"in e)&&(t.type=H[r]),r in K&&(t.compressed=!0),r=!0),!a&&r?t.channels=st[t.format]:a&&!r&&t.channels!==ot[t.format]&&(t.format=t.internalformat=ot[t.channels])}}function h(e){t.pixelStorei(37440,e.flipY),t.pixelStorei(37441,e.premultiplyAlpha),t.pixelStorei(37443,e.colorSpace),t.pixelStorei(3317,e.unpackAlignment)}function f(){s.call(this),this.yOffset=this.xOffset=0,this.data=null,this.needsFree=!1,this.element=null,this.needsCopy=!1}function p(t,e){var r=null;if(_(e)?r=e:e&&(u(t,e),\"x\"in e&&(t.xOffset=0|e.x),\"y\"in e&&(t.yOffset=0|e.y),_(e.data)&&(r=e.data)),e.copy){var n=i.viewportWidth,a=i.viewportHeight;t.width=t.width||n-t.xOffset,t.height=t.height||a-t.yOffset,t.needsCopy=!0}else if(r){if(W(r))t.channels=t.channels||4,t.data=r,\"type\"in e||5121!==t.type||(t.type=0|J[Object.prototype.toString.call(r)]);else if(y(r)){switch(t.channels=t.channels||4,a=(n=r).length,t.type){case 5121:case 5123:case 5125:case 5126:(a=G.allocType(t.type,a)).set(n),t.data=a;break;case 36193:t.data=g(n)}t.alignment=1,t.needsFree=!0}else if(l(r)){n=r.data,Array.isArray(n)||5121!==t.type||(t.type=0|J[Object.prototype.toString.call(n)]);a=r.shape;var o,s,c,h,f=r.stride;3===a.length?(c=a[2],h=f[2]):h=c=1,o=a[0],s=a[1],a=f[0],f=f[1],t.alignment=1,t.width=o,t.height=s,t.channels=c,t.format=t.internalformat=ot[c],t.needsFree=!0,o=h,r=r.offset,c=t.width,h=t.height,s=t.channels;for(var p=G.allocType(36193===t.type?5126:t.type,c*h*s),d=0,m=0;m<h;++m)for(var k=0;k<c;++k)for(var T=0;T<s;++T)p[d++]=n[a*k+f*m+o*T+r];w(t,p)}else if(b(r)===lt||b(r)===ct)b(r)===lt?t.element=r:t.element=r.canvas,t.width=t.element.width,t.height=t.element.height,t.channels=4;else if(b(r)===ut)t.element=r,t.width=r.width,t.height=r.height,t.channels=4;else if(b(r)===ht)t.element=r,t.width=r.naturalWidth,t.height=r.naturalHeight,t.channels=4;else if(b(r)===ft)t.element=r,t.width=r.videoWidth,t.height=r.videoHeight,t.channels=4;else if(x(r)){for(n=t.width||r[0].length,a=t.height||r.length,f=t.channels,f=v(r[0][0])?f||r[0][0].length:f||1,o=Z.shape(r),c=1,h=0;h<o.length;++h)c*=o[h];c=G.allocType(36193===t.type?5126:t.type,c),Z.flatten(r,o,\"\",c),w(t,c),t.alignment=1,t.width=n,t.height=a,t.channels=f,t.format=t.internalformat=ot[f],t.needsFree=!0}}else t.width=t.width||1,t.height=t.height||1,t.channels=t.channels||4}function d(e,r,i,a,o){var s=e.element,l=e.data,c=e.internalformat,u=e.format,f=e.type,p=e.width,d=e.height;h(e),s?t.texSubImage2D(r,o,i,a,u,f,s):e.compressed?t.compressedTexSubImage2D(r,o,i,a,c,p,d,l):e.needsCopy?(n(),t.copyTexSubImage2D(r,o,i,a,e.xOffset,e.yOffset,p,d)):t.texSubImage2D(r,o,i,a,p,d,u,f,l)}function m(){return dt.pop()||new f}function T(t){t.needsFree&&G.freeType(t.data),f.call(t),dt.push(t)}function A(){s.call(this),this.genMipmaps=!1,this.mipmapHint=4352,this.mipmask=0,this.images=Array(16)}function M(t,e,r){var n=t.images[0]=m();t.mipmask=1,n.width=t.width=e,n.height=t.height=r,n.channels=t.channels=4}function S(t,e){var r=null;if(_(e))c(r=t.images[0]=m(),t),p(r,e),t.mipmask=1;else if(u(t,e),Array.isArray(e.mipmap))for(var n=e.mipmap,i=0;i<n.length;++i)c(r=t.images[i]=m(),t),r.width>>=i,r.height>>=i,p(r,n[i]),t.mipmask|=1<<i;else c(r=t.images[0]=m(),t),p(r,e),t.mipmask=1;c(t,t.images[0])}function E(e,r){for(var i=e.images,a=0;a<i.length&&i[a];++a){var o=i[a],s=r,l=a,c=o.element,u=o.data,f=o.internalformat,p=o.format,d=o.type,g=o.width,v=o.height,m=o.channels;h(o),c?t.texImage2D(s,l,p,p,d,c):o.compressed?t.compressedTexImage2D(s,l,f,g,v,0,u):o.needsCopy?(n(),t.copyTexImage2D(s,l,p,o.xOffset,o.yOffset,g,v,0)):((o=!u)&&(u=G.zero.allocType(d,g*v*m)),t.texImage2D(s,l,p,g,v,0,p,d,u),o&&u&&G.zero.freeType(u))}}function C(){var t=gt.pop()||new A;s.call(t);for(var e=t.mipmask=0;16>e;++e)t.images[e]=null;return t}function L(t){for(var e=t.images,r=0;r<e.length;++r)e[r]&&T(e[r]),e[r]=null;gt.push(t)}function P(){this.magFilter=this.minFilter=9728,this.wrapT=this.wrapS=33071,this.anisotropic=1,this.genMipmaps=!1,this.mipmapHint=4352}function O(t,e){\"min\"in e&&(t.minFilter=V[e.min],0<=at.indexOf(t.minFilter)&&!(\"faces\"in e)&&(t.genMipmaps=!0)),\"mag\"in e&&(t.magFilter=U[e.mag]);var r=t.wrapS,n=t.wrapT;if(\"wrap\"in e){var i=e.wrap;\"string\"==typeof i?r=n=N[i]:Array.isArray(i)&&(r=N[i[0]],n=N[i[1]])}else\"wrapS\"in e&&(r=N[e.wrapS]),\"wrapT\"in e&&(n=N[e.wrapT]);if(t.wrapS=r,t.wrapT=n,\"anisotropic\"in e&&(t.anisotropic=e.anisotropic),\"mipmap\"in e){switch(r=!1,typeof e.mipmap){case\"string\":t.mipmapHint=B[e.mipmap],r=t.genMipmaps=!0;break;case\"boolean\":r=t.genMipmaps=e.mipmap;break;case\"object\":t.genMipmaps=!1,r=!0}!r||\"min\"in e||(t.minFilter=9984)}}function z(r,n){t.texParameteri(n,10241,r.minFilter),t.texParameteri(n,10240,r.magFilter),t.texParameteri(n,10242,r.wrapS),t.texParameteri(n,10243,r.wrapT),e.ext_texture_filter_anisotropic&&t.texParameteri(n,34046,r.anisotropic),r.genMipmaps&&(t.hint(33170,r.mipmapHint),t.generateMipmap(n))}function I(e){s.call(this),this.mipmask=0,this.internalformat=6408,this.id=vt++,this.refCount=1,this.target=e,this.texture=t.createTexture(),this.unit=-1,this.bindCount=0,this.texInfo=new P,o.profile&&(this.stats={size:0})}function D(e){t.activeTexture(33984),t.bindTexture(e.target,e.texture)}function R(){var e=xt[0];e?t.bindTexture(e.target,e.texture):t.bindTexture(3553,null)}function F(e){var r=e.texture,n=e.unit,i=e.target;0<=n&&(t.activeTexture(33984+n),t.bindTexture(i,null),xt[n]=null),t.deleteTexture(r),e.texture=null,e.params=null,e.pixels=null,e.refCount=0,delete mt[e.id],a.textureCount--}var B={\"don't care\":4352,\"dont care\":4352,nice:4354,fast:4353},N={repeat:10497,clamp:33071,mirror:33648},U={nearest:9728,linear:9729},V=j({mipmap:9987,\"nearest mipmap nearest\":9984,\"linear mipmap nearest\":9985,\"nearest mipmap linear\":9986,\"linear mipmap linear\":9987},U),q={none:0,browser:37444},H={uint8:5121,rgba4:32819,rgb565:33635,\"rgb5 a1\":32820},Y={alpha:6406,luminance:6409,\"luminance alpha\":6410,rgb:6407,rgba:6408,rgba4:32854,\"rgb5 a1\":32855,rgb565:36194},K={};e.ext_srgb&&(Y.srgb=35904,Y.srgba=35906),e.oes_texture_float&&(H.float32=H.float=5126),e.oes_texture_half_float&&(H.float16=H[\"half float\"]=36193),e.webgl_depth_texture&&(j(Y,{depth:6402,\"depth stencil\":34041}),j(H,{uint16:5123,uint32:5125,\"depth stencil\":34042})),e.webgl_compressed_texture_s3tc&&j(K,{\"rgb s3tc dxt1\":33776,\"rgba s3tc dxt1\":33777,\"rgba s3tc dxt3\":33778,\"rgba s3tc dxt5\":33779}),e.webgl_compressed_texture_atc&&j(K,{\"rgb atc\":35986,\"rgba atc explicit alpha\":35987,\"rgba atc interpolated alpha\":34798}),e.webgl_compressed_texture_pvrtc&&j(K,{\"rgb pvrtc 4bppv1\":35840,\"rgb pvrtc 2bppv1\":35841,\"rgba pvrtc 4bppv1\":35842,\"rgba pvrtc 2bppv1\":35843}),e.webgl_compressed_texture_etc1&&(K[\"rgb etc1\"]=36196);var $=Array.prototype.slice.call(t.getParameter(34467));Object.keys(K).forEach(function(t){var e=K[t];0<=$.indexOf(e)&&(Y[t]=e)});var Q=Object.keys(Y);r.textureFormats=Q;var tt=[];Object.keys(Y).forEach(function(t){tt[Y[t]]=t});var et=[];Object.keys(H).forEach(function(t){et[H[t]]=t});var rt=[];Object.keys(U).forEach(function(t){rt[U[t]]=t});var nt=[];Object.keys(V).forEach(function(t){nt[V[t]]=t});var it=[];Object.keys(N).forEach(function(t){it[N[t]]=t});var pt=Q.reduce(function(t,e){var r=Y[e];return 6409===r||6406===r||6409===r||6410===r||6402===r||34041===r?t[r]=r:32855===r||0<=e.indexOf(\"rgba\")?t[r]=6408:t[r]=6407,t},{}),dt=[],gt=[],vt=0,mt={},yt=r.maxTextureUnits,xt=Array(yt).map(function(){return null});return j(I.prototype,{bind:function(){this.bindCount+=1;var e=this.unit;if(0>e){for(var r=0;r<yt;++r){var n=xt[r];if(n){if(0<n.bindCount)continue;n.unit=-1}xt[r]=this,e=r;break}o.profile&&a.maxTextureUnits<e+1&&(a.maxTextureUnits=e+1),this.unit=e,t.activeTexture(33984+e),t.bindTexture(this.target,this.texture)}return e},unbind:function(){--this.bindCount},decRef:function(){0>=--this.refCount&&F(this)}}),o.profile&&(a.getTotalTextureSize=function(){var t=0;return Object.keys(mt).forEach(function(e){t+=mt[e].stats.size}),t}),{create2D:function(e,r){function n(t,e){var r=i.texInfo;P.call(r);var a=C();return\"number\"==typeof t?M(a,0|t,\"number\"==typeof e?0|e:0|t):t?(O(r,t),S(a,t)):M(a,1,1),r.genMipmaps&&(a.mipmask=(a.width<<1)-1),i.mipmask=a.mipmask,c(i,a),i.internalformat=a.internalformat,n.width=a.width,n.height=a.height,D(i),E(a,3553),z(r,3553),R(),L(a),o.profile&&(i.stats.size=k(i.internalformat,i.type,a.width,a.height,r.genMipmaps,!1)),n.format=tt[i.internalformat],n.type=et[i.type],n.mag=rt[r.magFilter],n.min=nt[r.minFilter],n.wrapS=it[r.wrapS],n.wrapT=it[r.wrapT],n}var i=new I(3553);return mt[i.id]=i,a.textureCount++,n(e,r),n.subimage=function(t,e,r,a){e|=0,r|=0,a|=0;var o=m();return c(o,i),o.width=0,o.height=0,p(o,t),o.width=o.width||(i.width>>a)-e,o.height=o.height||(i.height>>a)-r,D(i),d(o,3553,e,r,a),R(),T(o),n},n.resize=function(e,r){var a=0|e,s=0|r||a;if(a===i.width&&s===i.height)return n;n.width=i.width=a,n.height=i.height=s,D(i);for(var l,c=i.channels,u=i.type,h=0;i.mipmask>>h;++h){var f=a>>h,p=s>>h;if(!f||!p)break;l=G.zero.allocType(u,f*p*c),t.texImage2D(3553,h,i.format,f,p,0,i.format,i.type,l),l&&G.zero.freeType(l)}return R(),o.profile&&(i.stats.size=k(i.internalformat,i.type,a,s,!1,!1)),n},n._reglType=\"texture2d\",n._texture=i,o.profile&&(n.stats=i.stats),n.destroy=function(){i.decRef()},n},createCube:function(e,r,n,i,s,l){function h(t,e,r,n,i,a){var s,l=f.texInfo;for(P.call(l),s=0;6>s;++s)g[s]=C();if(\"number\"!=typeof t&&t){if(\"object\"==typeof t)if(e)S(g[0],t),S(g[1],e),S(g[2],r),S(g[3],n),S(g[4],i),S(g[5],a);else if(O(l,t),u(f,t),\"faces\"in t)for(t=t.faces,s=0;6>s;++s)c(g[s],f),S(g[s],t[s]);else for(s=0;6>s;++s)S(g[s],t)}else for(t=0|t||1,s=0;6>s;++s)M(g[s],t,t);for(c(f,g[0]),f.mipmask=l.genMipmaps?(g[0].width<<1)-1:g[0].mipmask,f.internalformat=g[0].internalformat,h.width=g[0].width,h.height=g[0].height,D(f),s=0;6>s;++s)E(g[s],34069+s);for(z(l,34067),R(),o.profile&&(f.stats.size=k(f.internalformat,f.type,h.width,h.height,l.genMipmaps,!0)),h.format=tt[f.internalformat],h.type=et[f.type],h.mag=rt[l.magFilter],h.min=nt[l.minFilter],h.wrapS=it[l.wrapS],h.wrapT=it[l.wrapT],s=0;6>s;++s)L(g[s]);return h}var f=new I(34067);mt[f.id]=f,a.cubeCount++;var g=Array(6);return h(e,r,n,i,s,l),h.subimage=function(t,e,r,n,i){r|=0,n|=0,i|=0;var a=m();return c(a,f),a.width=0,a.height=0,p(a,e),a.width=a.width||(f.width>>i)-r,a.height=a.height||(f.height>>i)-n,D(f),d(a,34069+t,r,n,i),R(),T(a),h},h.resize=function(e){if((e|=0)!==f.width){h.width=f.width=e,h.height=f.height=e,D(f);for(var r=0;6>r;++r)for(var n=0;f.mipmask>>n;++n)t.texImage2D(34069+r,n,f.format,e>>n,e>>n,0,f.format,f.type,null);return R(),o.profile&&(f.stats.size=k(f.internalformat,f.type,h.width,h.height,!1,!0)),h}},h._reglType=\"textureCube\",h._texture=f,o.profile&&(h.stats=f.stats),h.destroy=function(){f.decRef()},h},clear:function(){for(var e=0;e<yt;++e)t.activeTexture(33984+e),t.bindTexture(3553,null),xt[e]=null;X(mt).forEach(F),a.cubeCount=0,a.textureCount=0},getTexture:function(t){return null},restore:function(){for(var e=0;e<yt;++e){var r=xt[e];r&&(r.bindCount=0,r.unit=-1,xt[e]=null)}X(mt).forEach(function(e){e.texture=t.createTexture(),t.bindTexture(e.target,e.texture);for(var r=0;32>r;++r)if(0!=(e.mipmask&1<<r))if(3553===e.target)t.texImage2D(3553,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);else for(var n=0;6>n;++n)t.texImage2D(34069+n,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);z(e.texInfo,e.target)})}}}function A(t,e,r,n,i,a){function o(t,e,r){this.target=t,this.texture=e,this.renderbuffer=r;var n=t=0;e?(t=e.width,n=e.height):r&&(t=r.width,n=r.height),this.width=t,this.height=n}function s(t){t&&(t.texture&&t.texture._texture.decRef(),t.renderbuffer&&t.renderbuffer._renderbuffer.decRef())}function l(t,e,r){t&&(t.texture?t.texture._texture.refCount+=1:t.renderbuffer._renderbuffer.refCount+=1)}function c(e,r){r&&(r.texture?t.framebufferTexture2D(36160,e,r.target,r.texture._texture.texture,0):t.framebufferRenderbuffer(36160,e,36161,r.renderbuffer._renderbuffer.renderbuffer))}function u(t){var e=3553,r=null,n=null,i=t;return\"object\"==typeof t&&(i=t.data,\"target\"in t&&(e=0|t.target)),\"texture2d\"===(t=i._reglType)?r=i:\"textureCube\"===t?r=i:\"renderbuffer\"===t&&(n=i,e=36161),new o(e,r,n)}function h(t,e,r,a,s){return r?((t=n.create2D({width:t,height:e,format:a,type:s}))._texture.refCount=0,new o(3553,t,null)):((t=i.create({width:t,height:e,format:a}))._renderbuffer.refCount=0,new o(36161,null,t))}function f(t){return t&&(t.texture||t.renderbuffer)}function p(t,e,r){t&&(t.texture?t.texture.resize(e,r):t.renderbuffer&&t.renderbuffer.resize(e,r),t.width=e,t.height=r)}function d(){this.id=k++,T[this.id]=this,this.framebuffer=t.createFramebuffer(),this.height=this.width=0,this.colorAttachments=[],this.depthStencilAttachment=this.stencilAttachment=this.depthAttachment=null}function g(t){t.colorAttachments.forEach(s),s(t.depthAttachment),s(t.stencilAttachment),s(t.depthStencilAttachment)}function v(e){t.deleteFramebuffer(e.framebuffer),e.framebuffer=null,a.framebufferCount--,delete T[e.id]}function m(e){var n;t.bindFramebuffer(36160,e.framebuffer);var i=e.colorAttachments;for(n=0;n<i.length;++n)c(36064+n,i[n]);for(n=i.length;n<r.maxColorAttachments;++n)t.framebufferTexture2D(36160,36064+n,3553,null,0);t.framebufferTexture2D(36160,33306,3553,null,0),t.framebufferTexture2D(36160,36096,3553,null,0),t.framebufferTexture2D(36160,36128,3553,null,0),c(36096,e.depthAttachment),c(36128,e.stencilAttachment),c(33306,e.depthStencilAttachment),t.checkFramebufferStatus(36160),t.isContextLost(),t.bindFramebuffer(36160,x.next?x.next.framebuffer:null),x.cur=x.next,t.getError()}function y(t,e){function r(t,e){var i,a=0,o=0,s=!0,c=!0;i=null;var p=!0,d=\"rgba\",v=\"uint8\",y=1,x=null,w=null,k=null,T=!1;\"number\"==typeof t?(a=0|t,o=0|e||a):t?(\"shape\"in t?(a=(o=t.shape)[0],o=o[1]):(\"radius\"in t&&(a=o=t.radius),\"width\"in t&&(a=t.width),\"height\"in t&&(o=t.height)),(\"color\"in t||\"colors\"in t)&&(i=t.color||t.colors,Array.isArray(i)),i||(\"colorCount\"in t&&(y=0|t.colorCount),\"colorTexture\"in t&&(p=!!t.colorTexture,d=\"rgba4\"),\"colorType\"in t&&(v=t.colorType,!p)&&(\"half float\"===v||\"float16\"===v?d=\"rgba16f\":\"float\"!==v&&\"float32\"!==v||(d=\"rgba32f\")),\"colorFormat\"in t&&(d=t.colorFormat,0<=b.indexOf(d)?p=!0:0<=_.indexOf(d)&&(p=!1))),(\"depthTexture\"in t||\"depthStencilTexture\"in t)&&(T=!(!t.depthTexture&&!t.depthStencilTexture)),\"depth\"in t&&(\"boolean\"==typeof t.depth?s=t.depth:(x=t.depth,c=!1)),\"stencil\"in t&&(\"boolean\"==typeof t.stencil?c=t.stencil:(w=t.stencil,s=!1)),\"depthStencil\"in t&&(\"boolean\"==typeof t.depthStencil?s=c=t.depthStencil:(k=t.depthStencil,c=s=!1))):a=o=1;var A=null,M=null,S=null,E=null;if(Array.isArray(i))A=i.map(u);else if(i)A=[u(i)];else for(A=Array(y),i=0;i<y;++i)A[i]=h(a,o,p,d,v);for(a=a||A[0].width,o=o||A[0].height,x?M=u(x):s&&!c&&(M=h(a,o,T,\"depth\",\"uint32\")),w?S=u(w):c&&!s&&(S=h(a,o,!1,\"stencil\",\"uint8\")),k?E=u(k):!x&&!w&&c&&s&&(E=h(a,o,T,\"depth stencil\",\"depth stencil\")),s=null,i=0;i<A.length;++i)l(A[i]),A[i]&&A[i].texture&&(c=yt[A[i].texture._texture.format]*xt[A[i].texture._texture.type],null===s&&(s=c));return l(M),l(S),l(E),g(n),n.width=a,n.height=o,n.colorAttachments=A,n.depthAttachment=M,n.stencilAttachment=S,n.depthStencilAttachment=E,r.color=A.map(f),r.depth=f(M),r.stencil=f(S),r.depthStencil=f(E),r.width=n.width,r.height=n.height,m(n),r}var n=new d;return a.framebufferCount++,r(t,e),j(r,{resize:function(t,e){var i=Math.max(0|t,1),a=Math.max(0|e||i,1);if(i===n.width&&a===n.height)return r;for(var o=n.colorAttachments,s=0;s<o.length;++s)p(o[s],i,a);return p(n.depthAttachment,i,a),p(n.stencilAttachment,i,a),p(n.depthStencilAttachment,i,a),n.width=r.width=i,n.height=r.height=a,m(n),r},_reglType:\"framebuffer\",_framebuffer:n,destroy:function(){v(n),g(n)},use:function(t){x.setFBO({framebuffer:r},t)}})}var x={cur:null,next:null,dirty:!1,setFBO:null},b=[\"rgba\"],_=[\"rgba4\",\"rgb565\",\"rgb5 a1\"];e.ext_srgb&&_.push(\"srgba\"),e.ext_color_buffer_half_float&&_.push(\"rgba16f\",\"rgb16f\"),e.webgl_color_buffer_float&&_.push(\"rgba32f\");var w=[\"uint8\"];e.oes_texture_half_float&&w.push(\"half float\",\"float16\"),e.oes_texture_float&&w.push(\"float\",\"float32\");var k=0,T={};return j(x,{getFramebuffer:function(t){return\"function\"==typeof t&&\"framebuffer\"===t._reglType&&(t=t._framebuffer)instanceof d?t:null},create:y,createCube:function(t){function e(t){var i,a={color:null},o=0,s=null;i=\"rgba\";var l=\"uint8\",c=1;if(\"number\"==typeof t?o=0|t:t?(\"shape\"in t?o=t.shape[0]:(\"radius\"in t&&(o=0|t.radius),\"width\"in t?o=0|t.width:\"height\"in t&&(o=0|t.height)),(\"color\"in t||\"colors\"in t)&&(s=t.color||t.colors,Array.isArray(s)),s||(\"colorCount\"in t&&(c=0|t.colorCount),\"colorType\"in t&&(l=t.colorType),\"colorFormat\"in t&&(i=t.colorFormat)),\"depth\"in t&&(a.depth=t.depth),\"stencil\"in t&&(a.stencil=t.stencil),\"depthStencil\"in t&&(a.depthStencil=t.depthStencil)):o=1,s)if(Array.isArray(s))for(t=[],i=0;i<s.length;++i)t[i]=s[i];else t=[s];else for(t=Array(c),s={radius:o,format:i,type:l},i=0;i<c;++i)t[i]=n.createCube(s);for(a.color=Array(t.length),i=0;i<t.length;++i)c=t[i],o=o||c.width,a.color[i]={target:34069,data:t[i]};for(i=0;6>i;++i){for(c=0;c<t.length;++c)a.color[c].target=34069+i;0<i&&(a.depth=r[0].depth,a.stencil=r[0].stencil,a.depthStencil=r[0].depthStencil),r[i]?r[i](a):r[i]=y(a)}return j(e,{width:o,height:o,color:t})}var r=Array(6);return e(t),j(e,{faces:r,resize:function(t){var n=0|t;if(n===e.width)return e;var i=e.color;for(t=0;t<i.length;++t)i[t].resize(n);for(t=0;6>t;++t)r[t].resize(n);return e.width=e.height=n,e},_reglType:\"framebufferCube\",destroy:function(){r.forEach(function(t){t.destroy()})}})},clear:function(){X(T).forEach(v)},restore:function(){x.cur=null,x.next=null,x.dirty=!0,X(T).forEach(function(e){e.framebuffer=t.createFramebuffer(),m(e)})}})}function M(){this.w=this.z=this.y=this.x=this.state=0,this.buffer=null,this.size=0,this.normalized=!1,this.type=5126,this.divisor=this.stride=this.offset=0}function S(t,e,r,n){function i(t,e,r,n){this.name=t,this.id=e,this.location=r,this.info=n}function a(t,e){for(var r=0;r<t.length;++r)if(t[r].id===e.id)return void(t[r].location=e.location);t.push(e)}function o(r,n,i){if(!(o=(i=35632===r?c:u)[n])){var a=e.str(n),o=t.createShader(r);t.shaderSource(o,a),t.compileShader(o),i[n]=o}return o}function s(t,e){this.id=p++,this.fragId=t,this.vertId=e,this.program=null,this.uniforms=[],this.attributes=[],n.profile&&(this.stats={uniformsCount:0,attributesCount:0})}function l(r,s){var l,c;l=o(35632,r.fragId),c=o(35633,r.vertId);var u=r.program=t.createProgram();t.attachShader(u,l),t.attachShader(u,c),t.linkProgram(u);var h=t.getProgramParameter(u,35718);n.profile&&(r.stats.uniformsCount=h);var f=r.uniforms;for(l=0;l<h;++l)if(c=t.getActiveUniform(u,l))if(1<c.size)for(var p=0;p<c.size;++p){var d=c.name.replace(\"[0]\",\"[\"+p+\"]\");a(f,new i(d,e.id(d),t.getUniformLocation(u,d),c))}else a(f,new i(c.name,e.id(c.name),t.getUniformLocation(u,c.name),c));for(h=t.getProgramParameter(u,35721),n.profile&&(r.stats.attributesCount=h),f=r.attributes,l=0;l<h;++l)(c=t.getActiveAttrib(u,l))&&a(f,new i(c.name,e.id(c.name),t.getAttribLocation(u,c.name),c))}var c={},u={},h={},f=[],p=0;return n.profile&&(r.getMaxUniformsCount=function(){var t=0;return f.forEach(function(e){e.stats.uniformsCount>t&&(t=e.stats.uniformsCount)}),t},r.getMaxAttributesCount=function(){var t=0;return f.forEach(function(e){e.stats.attributesCount>t&&(t=e.stats.attributesCount)}),t}),{clear:function(){var e=t.deleteShader.bind(t);X(c).forEach(e),c={},X(u).forEach(e),u={},f.forEach(function(e){t.deleteProgram(e.program)}),f.length=0,h={},r.shaderCount=0},program:function(t,e,n){var i=h[e];i||(i=h[e]={});var a=i[t];return a||(a=new s(e,t),r.shaderCount++,l(a),i[t]=a,f.push(a)),a},restore:function(){c={},u={};for(var t=0;t<f.length;++t)l(f[t])},shader:o,frag:-1,vert:-1}}function E(t,e,r,n,i,a,o){function s(i){var a;a=null===e.next?5121:e.next.colorAttachments[0].texture._texture.type;var o=0,s=0,l=n.framebufferWidth,c=n.framebufferHeight,u=null;return W(i)?u=i:i&&(o=0|i.x,s=0|i.y,l=0|(i.width||n.framebufferWidth-o),c=0|(i.height||n.framebufferHeight-s),u=i.data||null),r(),i=l*c*4,u||(5121===a?u=new Uint8Array(i):5126===a&&(u=u||new Float32Array(i))),t.pixelStorei(3333,4),t.readPixels(o,s,l,c,6408,a,u),u}return function(t){return t&&\"framebuffer\"in t?function(t){var r;return e.setFBO({framebuffer:t.framebuffer},function(){r=s(t)}),r}(t):s(t)}}function C(t){return Array.prototype.slice.call(t)}function L(t){return C(t).join(\"\")}function P(){function t(){var t=[],e=[];return j(function(){t.push.apply(t,C(arguments))},{def:function(){var n=\"v\"+r++;return e.push(n),0<arguments.length&&(t.push(n,\"=\"),t.push.apply(t,C(arguments)),t.push(\";\")),n},toString:function(){return L([0<e.length?\"var \"+e+\";\":\"\",L(t)])}})}function e(){function e(t,e){n(t,e,\"=\",r.def(t,e),\";\")}var r=t(),n=t(),i=r.toString,a=n.toString;return j(function(){r.apply(r,C(arguments))},{def:r.def,entry:r,exit:n,save:e,set:function(t,n,i){e(t,n),r(t,n,\"=\",i,\";\")},toString:function(){return i()+a()}})}var r=0,n=[],i=[],a=t(),o={};return{global:a,link:function(t){for(var e=0;e<i.length;++e)if(i[e]===t)return n[e];return e=\"g\"+r++,n.push(e),i.push(t),e},block:t,proc:function(t,r){function n(){var t=\"a\"+i.length;return i.push(t),t}var i=[];r=r||0;for(var a=0;a<r;++a)n();var s=(a=e()).toString;return o[t]=j(a,{arg:n,toString:function(){return L([\"function(\",i.join(),\"){\",s(),\"}\"])}})},scope:e,cond:function(){var t=L(arguments),r=e(),n=e(),i=r.toString,a=n.toString;return j(r,{then:function(){return r.apply(r,C(arguments)),this},else:function(){return n.apply(n,C(arguments)),this},toString:function(){var e=a();return e&&(e=\"else{\"+e+\"}\"),L([\"if(\",t,\"){\",i(),\"}\",e])}})},compile:function(){var t=['\"use strict\";',a,\"return {\"];Object.keys(o).forEach(function(e){t.push('\"',e,'\":',o[e].toString(),\",\")}),t.push(\"}\");var e=L(t).replace(/;/g,\";\\n\").replace(/}/g,\"}\\n\").replace(/{/g,\"{\\n\");return Function.apply(null,n.concat(e)).apply(null,i)}}}function O(t){return Array.isArray(t)||W(t)||l(t)}function z(t){return t.sort(function(t,e){return\"viewport\"===t?-1:\"viewport\"===e?1:t<e?-1:1})}function I(t,e,r,n){this.thisDep=t,this.contextDep=e,this.propDep=r,this.append=n}function D(t){return t&&!(t.thisDep||t.contextDep||t.propDep)}function R(t){return new I(!1,!1,!1,t)}function F(t,e){var r=t.type;return 0===r?new I(!0,1<=(r=t.data.length),2<=r,e):4===r?new I((r=t.data).thisDep,r.contextDep,r.propDep,e):new I(3===r,2===r,1===r,e)}function B(t,e,r,n,i,o,s,l,c,u,h,f,p,d,g){function m(t){return t.replace(\".\",\"_\")}function y(t,e,r){var n=m(t);nt.push(t),et[n]=tt[n]=!!r,it[n]=e}function x(t,e,r){var n=m(t);nt.push(t),Array.isArray(r)?(tt[n]=r.slice(),et[n]=r.slice()):tt[n]=et[n]=r,at[n]=e}function b(){var t=P(),r=t.link,n=t.global;t.id=lt++,t.batchId=\"0\";var i=r(ot),a=t.shared={props:\"a0\"};Object.keys(ot).forEach(function(t){a[t]=n.def(i,\".\",t)});var o=t.next={},s=t.current={};Object.keys(at).forEach(function(t){Array.isArray(tt[t])&&(o[t]=n.def(a.next,\".\",t),s[t]=n.def(a.current,\".\",t))});var l=t.constants={};Object.keys(st).forEach(function(t){l[t]=n.def(JSON.stringify(st[t]))}),t.invoke=function(e,n){switch(n.type){case 0:var i=[\"this\",a.context,a.props,t.batchId];return e.def(r(n.data),\".call(\",i.slice(0,Math.max(n.data.length+1,4)),\")\");case 1:return e.def(a.props,n.data);case 2:return e.def(a.context,n.data);case 3:return e.def(\"this\",n.data);case 4:return n.data.append(t,e),n.data.ref}},t.attribCache={};var c={};return t.scopeAttrib=function(t){if((t=e.id(t))in c)return c[t];var n=u.scope[t];return n||(n=u.scope[t]=new Z),c[t]=r(n)},t}function _(t,e){var r=t.static,n=t.dynamic;if(\"framebuffer\"in r){var i=r.framebuffer;return i?(i=l.getFramebuffer(i),R(function(t,e){var r=t.link(i),n=t.shared;return e.set(n.framebuffer,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\".width\"),e.set(n,\".framebufferHeight\",r+\".height\"),r})):R(function(t,e){var r=t.shared;return e.set(r.framebuffer,\".next\",\"null\"),r=r.context,e.set(r,\".framebufferWidth\",r+\".drawingBufferWidth\"),e.set(r,\".framebufferHeight\",r+\".drawingBufferHeight\"),\"null\"})}if(\"framebuffer\"in n){var a=n.framebuffer;return F(a,function(t,e){var r=t.invoke(e,a),n=t.shared,i=n.framebuffer;r=e.def(i,\".getFramebuffer(\",r,\")\");return e.set(i,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\"?\"+r+\".width:\"+n+\".drawingBufferWidth\"),e.set(n,\".framebufferHeight\",r+\"?\"+r+\".height:\"+n+\".drawingBufferHeight\"),r})}return null}function w(t){function r(t){if(t in n){var r=e.id(n[t]);return(t=R(function(){return r})).id=r,t}if(t in i){var a=i[t];return F(a,function(t,e){var r=t.invoke(e,a);return e.def(t.shared.strings,\".id(\",r,\")\")})}return null}var n=t.static,i=t.dynamic,a=r(\"frag\"),o=r(\"vert\"),s=null;return D(a)&&D(o)?(s=h.program(o.id,a.id),t=R(function(t,e){return t.link(s)})):t=new I(a&&a.thisDep||o&&o.thisDep,a&&a.contextDep||o&&o.contextDep,a&&a.propDep||o&&o.propDep,function(t,e){var r,n,i=t.shared.shader;return r=a?a.append(t,e):e.def(i,\".\",\"frag\"),n=o?o.append(t,e):e.def(i,\".\",\"vert\"),e.def(i+\".program(\"+n+\",\"+r+\")\")}),{frag:a,vert:o,progVar:t,program:s}}function k(t,e){function r(t,e){if(t in n){var r=0|n[t];return R(function(t,n){return e&&(t.OFFSET=r),r})}if(t in i){var o=i[t];return F(o,function(t,r){var n=t.invoke(r,o);return e&&(t.OFFSET=n),n})}return e&&a?R(function(t,e){return t.OFFSET=\"0\",0}):null}var n=t.static,i=t.dynamic,a=function(){if(\"elements\"in n){var t=n.elements;O(t)?t=o.getElements(o.create(t,!0)):t&&(t=o.getElements(t));var e=R(function(e,r){if(t){var n=e.link(t);return e.ELEMENTS=n}return e.ELEMENTS=null});return e.value=t,e}if(\"elements\"in i){var r=i.elements;return F(r,function(t,e){var n=(i=t.shared).isBufferArgs,i=i.elements,a=t.invoke(e,r),o=e.def(\"null\");n=e.def(n,\"(\",a,\")\"),a=t.cond(n).then(o,\"=\",i,\".createStream(\",a,\");\").else(o,\"=\",i,\".getElements(\",a,\");\");return e.entry(a),e.exit(t.cond(n).then(i,\".destroyStream(\",o,\");\")),t.ELEMENTS=o})}return null}(),s=r(\"offset\",!0);return{elements:a,primitive:function(){if(\"primitive\"in n){var t=n.primitive;return R(function(e,r){return rt[t]})}if(\"primitive\"in i){var e=i.primitive;return F(e,function(t,r){var n=t.constants.primTypes,i=t.invoke(r,e);return r.def(n,\"[\",i,\"]\")})}return a?D(a)?a.value?R(function(t,e){return e.def(t.ELEMENTS,\".primType\")}):R(function(){return 4}):new I(a.thisDep,a.contextDep,a.propDep,function(t,e){var r=t.ELEMENTS;return e.def(r,\"?\",r,\".primType:\",4)}):null}(),count:function(){if(\"count\"in n){var t=0|n.count;return R(function(){return t})}if(\"count\"in i){var e=i.count;return F(e,function(t,r){return t.invoke(r,e)})}return a?D(a)?a?s?new I(s.thisDep,s.contextDep,s.propDep,function(t,e){return e.def(t.ELEMENTS,\".vertCount-\",t.OFFSET)}):R(function(t,e){return e.def(t.ELEMENTS,\".vertCount\")}):R(function(){return-1}):new I(a.thisDep||s.thisDep,a.contextDep||s.contextDep,a.propDep||s.propDep,function(t,e){var r=t.ELEMENTS;return t.OFFSET?e.def(r,\"?\",r,\".vertCount-\",t.OFFSET,\":-1\"):e.def(r,\"?\",r,\".vertCount:-1\")}):null}(),instances:r(\"instances\",!1),offset:s}}function T(t,r){var n=t.static,a=t.dynamic,o={};return Object.keys(n).forEach(function(t){var r=n[t],a=e.id(t),s=new Z;if(O(r))s.state=1,s.buffer=i.getBuffer(i.create(r,34962,!1,!0)),s.type=0;else if(c=i.getBuffer(r))s.state=1,s.buffer=c,s.type=0;else if(\"constant\"in r){var l=r.constant;s.buffer=\"null\",s.state=2,\"number\"==typeof l?s.x=l:bt.forEach(function(t,e){e<l.length&&(s[t]=l[e])})}else{var c=O(r.buffer)?i.getBuffer(i.create(r.buffer,34962,!1,!0)):i.getBuffer(r.buffer),u=0|r.offset,h=0|r.stride,f=0|r.size,p=!!r.normalized,d=0;\"type\"in r&&(d=K[r.type]),r=0|r.divisor,s.buffer=c,s.state=1,s.size=f,s.normalized=p,s.type=d||c.dtype,s.offset=u,s.stride=h,s.divisor=r}o[t]=R(function(t,e){var r=t.attribCache;if(a in r)return r[a];var n={isStream:!1};return Object.keys(s).forEach(function(t){n[t]=s[t]}),s.buffer&&(n.buffer=t.link(s.buffer),n.type=n.type||n.buffer+\".dtype\"),r[a]=n})}),Object.keys(a).forEach(function(t){var e=a[t];o[t]=F(e,function(t,r){function n(t){r(l[t],\"=\",i,\".\",t,\"|0;\")}var i=t.invoke(r,e),a=t.shared,o=a.isBufferArgs,s=a.buffer,l={isStream:r.def(!1)},c=new Z;c.state=1,Object.keys(c).forEach(function(t){l[t]=r.def(\"\"+c[t])});var u=l.buffer,h=l.type;return r(\"if(\",o,\"(\",i,\")){\",l.isStream,\"=true;\",u,\"=\",s,\".createStream(\",34962,\",\",i,\");\",h,\"=\",u,\".dtype;\",\"}else{\",u,\"=\",s,\".getBuffer(\",i,\");\",\"if(\",u,\"){\",h,\"=\",u,\".dtype;\",'}else if(\"constant\" in ',i,\"){\",l.state,\"=\",2,\";\",\"if(typeof \"+i+'.constant === \"number\"){',l[bt[0]],\"=\",i,\".constant;\",bt.slice(1).map(function(t){return l[t]}).join(\"=\"),\"=0;\",\"}else{\",bt.map(function(t,e){return l[t]+\"=\"+i+\".constant.length>\"+e+\"?\"+i+\".constant[\"+e+\"]:0;\"}).join(\"\"),\"}}else{\",\"if(\",o,\"(\",i,\".buffer)){\",u,\"=\",s,\".createStream(\",34962,\",\",i,\".buffer);\",\"}else{\",u,\"=\",s,\".getBuffer(\",i,\".buffer);\",\"}\",h,'=\"type\" in ',i,\"?\",a.glTypes,\"[\",i,\".type]:\",u,\".dtype;\",l.normalized,\"=!!\",i,\".normalized;\"),n(\"size\"),n(\"offset\"),n(\"stride\"),n(\"divisor\"),r(\"}}\"),r.exit(\"if(\",l.isStream,\"){\",s,\".destroyStream(\",u,\");\",\"}\"),l})}),o}function A(t,e,r,n,i){var o=_(t),s=function(t,e,r){function n(t){if(t in i){var r=i[t];t=!0;var n,o,s=0|r.x,l=0|r.y;return\"width\"in r?n=0|r.width:t=!1,\"height\"in r?o=0|r.height:t=!1,new I(!t&&e&&e.thisDep,!t&&e&&e.contextDep,!t&&e&&e.propDep,function(t,e){var i=t.shared.context,a=n;\"width\"in r||(a=e.def(i,\".\",\"framebufferWidth\",\"-\",s));var c=o;return\"height\"in r||(c=e.def(i,\".\",\"framebufferHeight\",\"-\",l)),[s,l,a,c]})}if(t in a){var c=a[t];return t=F(c,function(t,e){var r=t.invoke(e,c),n=t.shared.context,i=e.def(r,\".x|0\"),a=e.def(r,\".y|0\");return[i,a,e.def('\"width\" in ',r,\"?\",r,\".width|0:\",\"(\",n,\".\",\"framebufferWidth\",\"-\",i,\")\"),r=e.def('\"height\" in ',r,\"?\",r,\".height|0:\",\"(\",n,\".\",\"framebufferHeight\",\"-\",a,\")\")]}),e&&(t.thisDep=t.thisDep||e.thisDep,t.contextDep=t.contextDep||e.contextDep,t.propDep=t.propDep||e.propDep),t}return e?new I(e.thisDep,e.contextDep,e.propDep,function(t,e){var r=t.shared.context;return[0,0,e.def(r,\".\",\"framebufferWidth\"),e.def(r,\".\",\"framebufferHeight\")]}):null}var i=t.static,a=t.dynamic;if(t=n(\"viewport\")){var o=t;t=new I(t.thisDep,t.contextDep,t.propDep,function(t,e){var r=o.append(t,e),n=t.shared.context;return e.set(n,\".viewportWidth\",r[2]),e.set(n,\".viewportHeight\",r[3]),r})}return{viewport:t,scissor_box:n(\"scissor.box\")}}(t,o),l=k(t),c=function(t,e){var r=t.static,n=t.dynamic,i={};return nt.forEach(function(t){function e(e,a){if(t in r){var s=e(r[t]);i[o]=R(function(){return s})}else if(t in n){var l=n[t];i[o]=F(l,function(t,e){return a(t,e,t.invoke(e,l))})}}var o=m(t);switch(t){case\"cull.enable\":case\"blend.enable\":case\"dither\":case\"stencil.enable\":case\"depth.enable\":case\"scissor.enable\":case\"polygonOffset.enable\":case\"sample.alpha\":case\"sample.enable\":case\"depth.mask\":return e(function(t){return t},function(t,e,r){return r});case\"depth.func\":return e(function(t){return kt[t]},function(t,e,r){return e.def(t.constants.compareFuncs,\"[\",r,\"]\")});case\"depth.range\":return e(function(t){return t},function(t,e,r){return[e.def(\"+\",r,\"[0]\"),e=e.def(\"+\",r,\"[1]\")]});case\"blend.func\":return e(function(t){return[wt[\"srcRGB\"in t?t.srcRGB:t.src],wt[\"dstRGB\"in t?t.dstRGB:t.dst],wt[\"srcAlpha\"in t?t.srcAlpha:t.src],wt[\"dstAlpha\"in t?t.dstAlpha:t.dst]]},function(t,e,r){function n(t,n){return e.def('\"',t,n,'\" in ',r,\"?\",r,\".\",t,n,\":\",r,\".\",t)}t=t.constants.blendFuncs;var i=n(\"src\",\"RGB\"),a=n(\"dst\",\"RGB\"),o=(i=e.def(t,\"[\",i,\"]\"),e.def(t,\"[\",n(\"src\",\"Alpha\"),\"]\"));return[i,a=e.def(t,\"[\",a,\"]\"),o,t=e.def(t,\"[\",n(\"dst\",\"Alpha\"),\"]\")]});case\"blend.equation\":return e(function(t){return\"string\"==typeof t?[J[t],J[t]]:\"object\"==typeof t?[J[t.rgb],J[t.alpha]]:void 0},function(t,e,r){var n=t.constants.blendEquations,i=e.def(),a=e.def();return(t=t.cond(\"typeof \",r,'===\"string\"')).then(i,\"=\",a,\"=\",n,\"[\",r,\"];\"),t.else(i,\"=\",n,\"[\",r,\".rgb];\",a,\"=\",n,\"[\",r,\".alpha];\"),e(t),[i,a]});case\"blend.color\":return e(function(t){return a(4,function(e){return+t[e]})},function(t,e,r){return a(4,function(t){return e.def(\"+\",r,\"[\",t,\"]\")})});case\"stencil.mask\":return e(function(t){return 0|t},function(t,e,r){return e.def(r,\"|0\")});case\"stencil.func\":return e(function(t){return[kt[t.cmp||\"keep\"],t.ref||0,\"mask\"in t?t.mask:-1]},function(t,e,r){return[t=e.def('\"cmp\" in ',r,\"?\",t.constants.compareFuncs,\"[\",r,\".cmp]\",\":\",7680),e.def(r,\".ref|0\"),e=e.def('\"mask\" in ',r,\"?\",r,\".mask|0:-1\")]});case\"stencil.opFront\":case\"stencil.opBack\":return e(function(e){return[\"stencil.opBack\"===t?1029:1028,Tt[e.fail||\"keep\"],Tt[e.zfail||\"keep\"],Tt[e.zpass||\"keep\"]]},function(e,r,n){function i(t){return r.def('\"',t,'\" in ',n,\"?\",a,\"[\",n,\".\",t,\"]:\",7680)}var a=e.constants.stencilOps;return[\"stencil.opBack\"===t?1029:1028,i(\"fail\"),i(\"zfail\"),i(\"zpass\")]});case\"polygonOffset.offset\":return e(function(t){return[0|t.factor,0|t.units]},function(t,e,r){return[e.def(r,\".factor|0\"),e=e.def(r,\".units|0\")]});case\"cull.face\":return e(function(t){var e=0;return\"front\"===t?e=1028:\"back\"===t&&(e=1029),e},function(t,e,r){return e.def(r,'===\"front\"?',1028,\":\",1029)});case\"lineWidth\":return e(function(t){return t},function(t,e,r){return r});case\"frontFace\":return e(function(t){return At[t]},function(t,e,r){return e.def(r+'===\"cw\"?2304:2305')});case\"colorMask\":return e(function(t){return t.map(function(t){return!!t})},function(t,e,r){return a(4,function(t){return\"!!\"+r+\"[\"+t+\"]\"})});case\"sample.coverage\":return e(function(t){return[\"value\"in t?t.value:1,!!t.invert]},function(t,e,r){return[e.def('\"value\" in ',r,\"?+\",r,\".value:1\"),e=e.def(\"!!\",r,\".invert\")]})}}),i}(t),u=w(t),h=s.viewport;return h&&(c.viewport=h),(s=s[h=m(\"scissor.box\")])&&(c[h]=s),(o={framebuffer:o,draw:l,shader:u,state:c,dirty:s=0<Object.keys(c).length}).profile=function(t){var e,r=t.static;if(t=t.dynamic,\"profile\"in r){var n=!!r.profile;(e=R(function(t,e){return n})).enable=n}else if(\"profile\"in t){var i=t.profile;e=F(i,function(t,e){return t.invoke(e,i)})}return e}(t),o.uniforms=function(t,e){var r=t.static,n=t.dynamic,i={};return Object.keys(r).forEach(function(t){var e,n=r[t];if(\"number\"==typeof n||\"boolean\"==typeof n)e=R(function(){return n});else if(\"function\"==typeof n){var o=n._reglType;\"texture2d\"===o||\"textureCube\"===o?e=R(function(t){return t.link(n)}):\"framebuffer\"!==o&&\"framebufferCube\"!==o||(e=R(function(t){return t.link(n.color[0])}))}else v(n)&&(e=R(function(t){return t.global.def(\"[\",a(n.length,function(t){return n[t]}),\"]\")}));e.value=n,i[t]=e}),Object.keys(n).forEach(function(t){var e=n[t];i[t]=F(e,function(t,r){return t.invoke(r,e)})}),i}(r),o.attributes=T(e),o.context=function(t){var e=t.static,r=t.dynamic,n={};return Object.keys(e).forEach(function(t){var r=e[t];n[t]=R(function(t,e){return\"number\"==typeof r||\"boolean\"==typeof r?\"\"+r:t.link(r)})}),Object.keys(r).forEach(function(t){var e=r[t];n[t]=F(e,function(t,r){return t.invoke(r,e)})}),n}(n),o}function M(t,e,r){var n=t.shared.context,i=t.scope();Object.keys(r).forEach(function(a){e.save(n,\".\"+a),i(n,\".\",a,\"=\",r[a].append(t,e),\";\")}),e(i)}function S(t,e,r,n){var i,a=(s=t.shared).gl,o=s.framebuffer;Q&&(i=e.def(s.extensions,\".webgl_draw_buffers\"));var s=(l=t.constants).drawBuffer,l=l.backBuffer;t=r?r.append(t,e):e.def(o,\".next\"),n||e(\"if(\",t,\"!==\",o,\".cur){\"),e(\"if(\",t,\"){\",a,\".bindFramebuffer(\",36160,\",\",t,\".framebuffer);\"),Q&&e(i,\".drawBuffersWEBGL(\",s,\"[\",t,\".colorAttachments.length]);\"),e(\"}else{\",a,\".bindFramebuffer(\",36160,\",null);\"),Q&&e(i,\".drawBuffersWEBGL(\",l,\");\"),e(\"}\",o,\".cur=\",t,\";\"),n||e(\"}\")}function E(t,e,r){var n=t.shared,i=n.gl,o=t.current,s=t.next,l=n.current,c=n.next,u=t.cond(l,\".dirty\");nt.forEach(function(e){var n,h;if(!((e=m(e))in r.state))if(e in s){n=s[e],h=o[e];var f=a(tt[e].length,function(t){return u.def(n,\"[\",t,\"]\")});u(t.cond(f.map(function(t,e){return t+\"!==\"+h+\"[\"+e+\"]\"}).join(\"||\")).then(i,\".\",at[e],\"(\",f,\");\",f.map(function(t,e){return h+\"[\"+e+\"]=\"+t}).join(\";\"),\";\"))}else n=u.def(c,\".\",e),f=t.cond(n,\"!==\",l,\".\",e),u(f),e in it?f(t.cond(n).then(i,\".enable(\",it[e],\");\").else(i,\".disable(\",it[e],\");\"),l,\".\",e,\"=\",n,\";\"):f(i,\".\",at[e],\"(\",n,\");\",l,\".\",e,\"=\",n,\";\")}),0===Object.keys(r.state).length&&u(l,\".dirty=false;\"),e(u)}function C(t,e,r,n){var i=t.shared,a=t.current,o=i.current,s=i.gl;z(Object.keys(r)).forEach(function(i){var l=r[i];if(!n||n(l)){var c=l.append(t,e);if(it[i]){var u=it[i];D(l)?e(s,c?\".enable(\":\".disable(\",u,\");\"):e(t.cond(c).then(s,\".enable(\",u,\");\").else(s,\".disable(\",u,\");\")),e(o,\".\",i,\"=\",c,\";\")}else if(v(c)){var h=a[i];e(s,\".\",at[i],\"(\",c,\");\",c.map(function(t,e){return h+\"[\"+e+\"]=\"+t}).join(\";\"),\";\")}else e(s,\".\",at[i],\"(\",c,\");\",o,\".\",i,\"=\",c,\";\")}})}function L(t,e){$&&(t.instancing=e.def(t.shared.extensions,\".angle_instanced_arrays\"))}function B(t,e,r,n,i){function a(){return\"undefined\"==typeof performance?\"Date.now()\":\"performance.now()\"}function o(t){t(c=e.def(),\"=\",a(),\";\"),\"string\"==typeof i?t(f,\".count+=\",i,\";\"):t(f,\".count++;\"),d&&(n?t(u=e.def(),\"=\",g,\".getNumPendingQueries();\"):t(g,\".beginQuery(\",f,\");\"))}function s(t){t(f,\".cpuTime+=\",a(),\"-\",c,\";\"),d&&(n?t(g,\".pushScopeStats(\",u,\",\",g,\".getNumPendingQueries(),\",f,\");\"):t(g,\".endQuery();\"))}function l(t){var r=e.def(p,\".profile\");e(p,\".profile=\",t,\";\"),e.exit(p,\".profile=\",r,\";\")}var c,u,h=t.shared,f=t.stats,p=h.current,g=h.timer;if(r=r.profile){if(D(r))return void(r.enable?(o(e),s(e.exit),l(\"true\")):l(\"false\"));l(r=r.append(t,e))}else r=e.def(p,\".profile\");o(h=t.block()),e(\"if(\",r,\"){\",h,\"}\"),s(t=t.block()),e.exit(\"if(\",r,\"){\",t,\"}\")}function N(t,e,r,n,i){function a(r,n,i){function a(){e(\"if(!\",u,\".buffer){\",l,\".enableVertexAttribArray(\",c,\");}\");var r,a=i.type;r=i.size?e.def(i.size,\"||\",n):n,e(\"if(\",u,\".type!==\",a,\"||\",u,\".size!==\",r,\"||\",p.map(function(t){return u+\".\"+t+\"!==\"+i[t]}).join(\"||\"),\"){\",l,\".bindBuffer(\",34962,\",\",h,\".buffer);\",l,\".vertexAttribPointer(\",[c,r,a,i.normalized,i.stride,i.offset],\");\",u,\".type=\",a,\";\",u,\".size=\",r,\";\",p.map(function(t){return u+\".\"+t+\"=\"+i[t]+\";\"}).join(\"\"),\"}\"),$&&(a=i.divisor,e(\"if(\",u,\".divisor!==\",a,\"){\",t.instancing,\".vertexAttribDivisorANGLE(\",[c,a],\");\",u,\".divisor=\",a,\";}\"))}function s(){e(\"if(\",u,\".buffer){\",l,\".disableVertexAttribArray(\",c,\");\",\"}if(\",bt.map(function(t,e){return u+\".\"+t+\"!==\"+f[e]}).join(\"||\"),\"){\",l,\".vertexAttrib4f(\",c,\",\",f,\");\",bt.map(function(t,e){return u+\".\"+t+\"=\"+f[e]+\";\"}).join(\"\"),\"}\")}var l=o.gl,c=e.def(r,\".location\"),u=e.def(o.attributes,\"[\",c,\"]\");r=i.state;var h=i.buffer,f=[i.x,i.y,i.z,i.w],p=[\"buffer\",\"normalized\",\"offset\",\"stride\"];1===r?a():2===r?s():(e(\"if(\",r,\"===\",1,\"){\"),a(),e(\"}else{\"),s(),e(\"}\"))}var o=t.shared;n.forEach(function(n){var o,s=n.name,l=r.attributes[s];if(l){if(!i(l))return;o=l.append(t,e)}else{if(!i(Mt))return;var c=t.scopeAttrib(s);o={},Object.keys(new Z).forEach(function(t){o[t]=e.def(c,\".\",t)})}a(t.link(n),function(t){switch(t){case 35664:case 35667:case 35671:return 2;case 35665:case 35668:case 35672:return 3;case 35666:case 35669:case 35673:return 4;default:return 1}}(n.info.type),o)})}function j(t,r,n,i,o){for(var s,l=t.shared,c=l.gl,u=0;u<i.length;++u){var h,f=(g=i[u]).name,p=g.info.type,d=n.uniforms[f],g=t.link(g)+\".location\";if(d){if(!o(d))continue;if(D(d)){if(f=d.value,35678===p||35680===p)r(c,\".uniform1i(\",g,\",\",(p=t.link(f._texture||f.color[0]._texture))+\".bind());\"),r.exit(p,\".unbind();\");else if(35674===p||35675===p||35676===p)d=2,35675===p?d=3:35676===p&&(d=4),r(c,\".uniformMatrix\",d,\"fv(\",g,\",false,\",f=t.global.def(\"new Float32Array([\"+Array.prototype.slice.call(f)+\"])\"),\");\");else{switch(p){case 5126:s=\"1f\";break;case 35664:s=\"2f\";break;case 35665:s=\"3f\";break;case 35666:s=\"4f\";break;case 35670:case 5124:s=\"1i\";break;case 35671:case 35667:s=\"2i\";break;case 35672:case 35668:s=\"3i\";break;case 35673:s=\"4i\";break;case 35669:s=\"4i\"}r(c,\".uniform\",s,\"(\",g,\",\",v(f)?Array.prototype.slice.call(f):f,\");\")}continue}h=d.append(t,r)}else{if(!o(Mt))continue;h=r.def(l.uniforms,\"[\",e.id(f),\"]\")}switch(35678===p?r(\"if(\",h,\"&&\",h,'._reglType===\"framebuffer\"){',h,\"=\",h,\".color[0];\",\"}\"):35680===p&&r(\"if(\",h,\"&&\",h,'._reglType===\"framebufferCube\"){',h,\"=\",h,\".color[0];\",\"}\"),f=1,p){case 35678:case 35680:p=r.def(h,\"._texture\"),r(c,\".uniform1i(\",g,\",\",p,\".bind());\"),r.exit(p,\".unbind();\");continue;case 5124:case 35670:s=\"1i\";break;case 35667:case 35671:s=\"2i\",f=2;break;case 35668:case 35672:s=\"3i\",f=3;break;case 35669:case 35673:s=\"4i\",f=4;break;case 5126:s=\"1f\";break;case 35664:s=\"2f\",f=2;break;case 35665:s=\"3f\",f=3;break;case 35666:s=\"4f\",f=4;break;case 35674:s=\"Matrix2fv\";break;case 35675:s=\"Matrix3fv\";break;case 35676:s=\"Matrix4fv\"}if(r(c,\".uniform\",s,\"(\",g,\",\"),\"M\"===s.charAt(0)){g=Math.pow(p-35674+2,2);var m=t.global.def(\"new Float32Array(\",g,\")\");r(\"false,(Array.isArray(\",h,\")||\",h,\" instanceof Float32Array)?\",h,\":(\",a(g,function(t){return m+\"[\"+t+\"]=\"+h+\"[\"+t+\"]\"}),\",\",m,\")\")}else r(1<f?a(f,function(t){return h+\"[\"+t+\"]\"}):h);r(\");\")}}function U(t,e,r,n){function i(i){var a=f[i];return a?a.contextDep&&n.contextDynamic||a.propDep?a.append(t,r):a.append(t,e):e.def(h,\".\",i)}function a(){function t(){r(l,\".drawElementsInstancedANGLE(\",[d,v,m,g+\"<<((\"+m+\"-5121)>>1)\",s],\");\")}function e(){r(l,\".drawArraysInstancedANGLE(\",[d,g,v,s],\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}function o(){function t(){r(u+\".drawElements(\"+[d,v,m,g+\"<<((\"+m+\"-5121)>>1)\"]+\");\")}function e(){r(u+\".drawArrays(\"+[d,g,v]+\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}var s,l,c=t.shared,u=c.gl,h=c.draw,f=n.draw,p=function(){var i=f.elements,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(h,\".\",\"elements\"),i&&a(\"if(\"+i+\")\"+u+\".bindBuffer(34963,\"+i+\".buffer.buffer);\"),i}(),d=i(\"primitive\"),g=i(\"offset\"),v=function(){var i=f.count,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(h,\".\",\"count\"),i}();if(\"number\"==typeof v){if(0===v)return}else r(\"if(\",v,\"){\"),r.exit(\"}\");$&&(s=i(\"instances\"),l=t.instancing);var m=p+\".type\",y=f.elements&&D(f.elements);$&&(\"number\"!=typeof s||0<=s)?\"string\"==typeof s?(r(\"if(\",s,\">0){\"),a(),r(\"}else if(\",s,\"<0){\"),o(),r(\"}\")):a():o()}function q(t,e,r,n,i){return i=(e=b()).proc(\"body\",i),$&&(e.instancing=i.def(e.shared.extensions,\".angle_instanced_arrays\")),t(e,i,r,n),e.compile().body}function H(t,e,r,n){L(t,e),N(t,e,r,n.attributes,function(){return!0}),j(t,e,r,n.uniforms,function(){return!0}),U(t,e,e,r)}function G(t,e,r,n){function i(){return!0}t.batchId=\"a1\",L(t,e),N(t,e,r,n.attributes,i),j(t,e,r,n.uniforms,i),U(t,e,e,r)}function Y(t,e,r,n){function i(t){return t.contextDep&&o||t.propDep}function a(t){return!i(t)}L(t,e);var o=r.contextDep,s=e.def(),l=e.def();t.shared.props=l,t.batchId=s;var c=t.scope(),u=t.scope();e(c.entry,\"for(\",s,\"=0;\",s,\"<\",\"a1\",\";++\",s,\"){\",l,\"=\",\"a0\",\"[\",s,\"];\",u,\"}\",c.exit),r.needsContext&&M(t,u,r.context),r.needsFramebuffer&&S(t,u,r.framebuffer),C(t,u,r.state,i),r.profile&&i(r.profile)&&B(t,u,r,!1,!0),n?(N(t,c,r,n.attributes,a),N(t,u,r,n.attributes,i),j(t,c,r,n.uniforms,a),j(t,u,r,n.uniforms,i),U(t,c,u,r)):(e=t.global.def(\"{}\"),n=r.shader.progVar.append(t,u),l=u.def(n,\".id\"),c=u.def(e,\"[\",l,\"]\"),u(t.shared.gl,\".useProgram(\",n,\".program);\",\"if(!\",c,\"){\",c,\"=\",e,\"[\",l,\"]=\",t.link(function(e){return q(G,t,r,e,2)}),\"(\",n,\");}\",c,\".call(this,a0[\",s,\"],\",s,\");\"))}function W(t,r){function n(e){var n=r.shader[e];n&&i.set(a.shader,\".\"+e,n.append(t,i))}var i=t.proc(\"scope\",3);t.batchId=\"a2\";var a=t.shared,o=a.current;M(t,i,r.context),r.framebuffer&&r.framebuffer.append(t,i),z(Object.keys(r.state)).forEach(function(e){var n=r.state[e].append(t,i);v(n)?n.forEach(function(r,n){i.set(t.next[e],\"[\"+n+\"]\",r)}):i.set(a.next,\".\"+e,n)}),B(t,i,r,!0,!0),[\"elements\",\"offset\",\"count\",\"instances\",\"primitive\"].forEach(function(e){var n=r.draw[e];n&&i.set(a.draw,\".\"+e,\"\"+n.append(t,i))}),Object.keys(r.uniforms).forEach(function(n){i.set(a.uniforms,\"[\"+e.id(n)+\"]\",r.uniforms[n].append(t,i))}),Object.keys(r.attributes).forEach(function(e){var n=r.attributes[e].append(t,i),a=t.scopeAttrib(e);Object.keys(new Z).forEach(function(t){i.set(a,\".\"+t,n[t])})}),n(\"vert\"),n(\"frag\"),0<Object.keys(r.state).length&&(i(o,\".dirty=true;\"),i.exit(o,\".dirty=true;\")),i(\"a1(\",t.shared.context,\",a0,\",t.batchId,\");\")}function X(t,e,r){var n=e.static[r];if(n&&function(t){if(\"object\"==typeof t&&!v(t)){for(var e=Object.keys(t),r=0;r<e.length;++r)if(V.isDynamic(t[e[r]]))return!0;return!1}}(n)){var i=t.global,a=Object.keys(n),o=!1,s=!1,l=!1,c=t.global.def(\"{}\");a.forEach(function(e){var r=n[e];if(V.isDynamic(r))\"function\"==typeof r&&(r=n[e]=V.unbox(r)),e=F(r,null),o=o||e.thisDep,l=l||e.propDep,s=s||e.contextDep;else{switch(i(c,\".\",e,\"=\"),typeof r){case\"number\":i(r);break;case\"string\":i('\"',r,'\"');break;case\"object\":Array.isArray(r)&&i(\"[\",r.join(),\"]\");break;default:i(t.link(r))}i(\";\")}}),e.dynamic[r]=new V.DynamicVariable(4,{thisDep:o,contextDep:s,propDep:l,ref:c,append:function(t,e){a.forEach(function(r){var i=n[r];V.isDynamic(i)&&(i=t.invoke(e,i),e(c,\".\",r,\"=\",i,\";\"))})}}),delete e.static[r]}}var Z=u.Record,J={add:32774,subtract:32778,\"reverse subtract\":32779};r.ext_blend_minmax&&(J.min=32775,J.max=32776);var $=r.angle_instanced_arrays,Q=r.webgl_draw_buffers,tt={dirty:!0,profile:g.profile},et={},nt=[],it={},at={};y(\"dither\",3024),y(\"blend.enable\",3042),x(\"blend.color\",\"blendColor\",[0,0,0,0]),x(\"blend.equation\",\"blendEquationSeparate\",[32774,32774]),x(\"blend.func\",\"blendFuncSeparate\",[1,0,1,0]),y(\"depth.enable\",2929,!0),x(\"depth.func\",\"depthFunc\",513),x(\"depth.range\",\"depthRange\",[0,1]),x(\"depth.mask\",\"depthMask\",!0),x(\"colorMask\",\"colorMask\",[!0,!0,!0,!0]),y(\"cull.enable\",2884),x(\"cull.face\",\"cullFace\",1029),x(\"frontFace\",\"frontFace\",2305),x(\"lineWidth\",\"lineWidth\",1),y(\"polygonOffset.enable\",32823),x(\"polygonOffset.offset\",\"polygonOffset\",[0,0]),y(\"sample.alpha\",32926),y(\"sample.enable\",32928),x(\"sample.coverage\",\"sampleCoverage\",[1,!1]),y(\"stencil.enable\",2960),x(\"stencil.mask\",\"stencilMask\",-1),x(\"stencil.func\",\"stencilFunc\",[519,0,-1]),x(\"stencil.opFront\",\"stencilOpSeparate\",[1028,7680,7680,7680]),x(\"stencil.opBack\",\"stencilOpSeparate\",[1029,7680,7680,7680]),y(\"scissor.enable\",3089),x(\"scissor.box\",\"scissor\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]),x(\"viewport\",\"viewport\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]);var ot={gl:t,context:p,strings:e,next:et,current:tt,draw:f,elements:o,buffer:i,shader:h,attributes:u.state,uniforms:c,framebuffer:l,extensions:r,timer:d,isBufferArgs:O},st={primTypes:rt,compareFuncs:kt,blendFuncs:wt,blendEquations:J,stencilOps:Tt,glTypes:K,orientationType:At};Q&&(st.backBuffer=[1029],st.drawBuffer=a(n.maxDrawbuffers,function(t){return 0===t?[0]:a(t,function(t){return 36064+t})}));var lt=0;return{next:et,current:tt,procs:function(){var t=b(),e=t.proc(\"poll\"),r=t.proc(\"refresh\"),i=t.block();e(i),r(i);var o,s=t.shared,l=s.gl,c=s.next,u=s.current;i(u,\".dirty=false;\"),S(t,e),S(t,r,null,!0),$&&(o=t.link($));for(var h=0;h<n.maxAttributes;++h){var f=r.def(s.attributes,\"[\",h,\"]\"),p=t.cond(f,\".buffer\");p.then(l,\".enableVertexAttribArray(\",h,\");\",l,\".bindBuffer(\",34962,\",\",f,\".buffer.buffer);\",l,\".vertexAttribPointer(\",h,\",\",f,\".size,\",f,\".type,\",f,\".normalized,\",f,\".stride,\",f,\".offset);\").else(l,\".disableVertexAttribArray(\",h,\");\",l,\".vertexAttrib4f(\",h,\",\",f,\".x,\",f,\".y,\",f,\".z,\",f,\".w);\",f,\".buffer=null;\"),r(p),$&&r(o,\".vertexAttribDivisorANGLE(\",h,\",\",f,\".divisor);\")}return Object.keys(it).forEach(function(n){var a=it[n],o=i.def(c,\".\",n),s=t.block();s(\"if(\",o,\"){\",l,\".enable(\",a,\")}else{\",l,\".disable(\",a,\")}\",u,\".\",n,\"=\",o,\";\"),r(s),e(\"if(\",o,\"!==\",u,\".\",n,\"){\",s,\"}\")}),Object.keys(at).forEach(function(n){var o,s,h=at[n],f=tt[n],p=t.block();p(l,\".\",h,\"(\"),v(f)?(h=f.length,o=t.global.def(c,\".\",n),s=t.global.def(u,\".\",n),p(a(h,function(t){return o+\"[\"+t+\"]\"}),\");\",a(h,function(t){return s+\"[\"+t+\"]=\"+o+\"[\"+t+\"];\"}).join(\"\")),e(\"if(\",a(h,function(t){return o+\"[\"+t+\"]!==\"+s+\"[\"+t+\"]\"}).join(\"||\"),\"){\",p,\"}\")):(o=i.def(c,\".\",n),s=i.def(u,\".\",n),p(o,\");\",u,\".\",n,\"=\",o,\";\"),e(\"if(\",o,\"!==\",s,\"){\",p,\"}\")),r(p)}),t.compile()}(),compile:function(t,e,r,n,i){var a=b();return a.stats=a.link(i),Object.keys(e.static).forEach(function(t){X(a,e,t)}),_t.forEach(function(e){X(a,t,e)}),r=A(t,e,r,n),function(t,e){var r=t.proc(\"draw\",1);L(t,r),M(t,r,e.context),S(t,r,e.framebuffer),E(t,r,e),C(t,r,e.state),B(t,r,e,!1,!0);var n=e.shader.progVar.append(t,r);if(r(t.shared.gl,\".useProgram(\",n,\".program);\"),e.shader.program)H(t,r,e,e.shader.program);else{var i=t.global.def(\"{}\"),a=r.def(n,\".id\"),o=r.def(i,\"[\",a,\"]\");r(t.cond(o).then(o,\".call(this,a0);\").else(o,\"=\",i,\"[\",a,\"]=\",t.link(function(r){return q(H,t,e,r,1)}),\"(\",n,\");\",o,\".call(this,a0);\"))}0<Object.keys(e.state).length&&r(t.shared.current,\".dirty=true;\")}(a,r),W(a,r),function(t,e){function r(t){return t.contextDep&&i||t.propDep}var n=t.proc(\"batch\",2);t.batchId=\"0\",L(t,n);var i=!1,a=!0;Object.keys(e.context).forEach(function(t){i=i||e.context[t].propDep}),i||(M(t,n,e.context),a=!1);var o=!1;if((s=e.framebuffer)?(s.propDep?i=o=!0:s.contextDep&&i&&(o=!0),o||S(t,n,s)):S(t,n,null),e.state.viewport&&e.state.viewport.propDep&&(i=!0),E(t,n,e),C(t,n,e.state,function(t){return!r(t)}),e.profile&&r(e.profile)||B(t,n,e,!1,\"a1\"),e.contextDep=i,e.needsContext=a,e.needsFramebuffer=o,(a=e.shader.progVar).contextDep&&i||a.propDep)Y(t,n,e,null);else if(a=a.append(t,n),n(t.shared.gl,\".useProgram(\",a,\".program);\"),e.shader.program)Y(t,n,e,e.shader.program);else{var s=t.global.def(\"{}\"),l=(o=n.def(a,\".id\"),n.def(s,\"[\",o,\"]\"));n(t.cond(l).then(l,\".call(this,a0,a1);\").else(l,\"=\",s,\"[\",o,\"]=\",t.link(function(r){return q(Y,t,e,r,2)}),\"(\",a,\");\",l,\".call(this,a0,a1);\"))}0<Object.keys(e.state).length&&n(t.shared.current,\".dirty=true;\")}(a,r),a.compile()}}}function N(t,e){for(var r=0;r<t.length;++r)if(t[r]===e)return r;return-1}var j=function(t,e){for(var r=Object.keys(e),n=0;n<r.length;++n)t[r[n]]=e[r[n]];return t},U=0,V={DynamicVariable:t,define:function(r,n){return new t(r,e(n+\"\"))},isDynamic:function(e){return\"function\"==typeof e&&!e._reglType||e instanceof t},unbox:function(e,r){return\"function\"==typeof e?new t(0,e):e},accessor:e},q={next:\"function\"==typeof requestAnimationFrame?function(t){return requestAnimationFrame(t)}:function(t){return setTimeout(t,16)},cancel:\"function\"==typeof cancelAnimationFrame?function(t){return cancelAnimationFrame(t)}:clearTimeout},H=\"undefined\"!=typeof performance&&performance.now?function(){return performance.now()}:function(){return+new Date},G=s();G.zero=s();var Y=function(t,e){var r=1;e.ext_texture_filter_anisotropic&&(r=t.getParameter(34047));var n=1,i=1;e.webgl_draw_buffers&&(n=t.getParameter(34852),i=t.getParameter(36063));var a=!!e.oes_texture_float;if(a){a=t.createTexture(),t.bindTexture(3553,a),t.texImage2D(3553,0,6408,1,1,0,6408,5126,null);var o=t.createFramebuffer();if(t.bindFramebuffer(36160,o),t.framebufferTexture2D(36160,36064,3553,a,0),t.bindTexture(3553,null),36053!==t.checkFramebufferStatus(36160))a=!1;else{t.viewport(0,0,1,1),t.clearColor(1,0,0,1),t.clear(16384);var s=G.allocType(5126,4);t.readPixels(0,0,1,1,6408,5126,s),t.getError()?a=!1:(t.deleteFramebuffer(o),t.deleteTexture(a),a=1===s[0]),G.freeType(s)}}return s=!0,\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion)||/Edge/.test(navigator.userAgent))||(s=t.createTexture(),o=G.allocType(5121,36),t.activeTexture(33984),t.bindTexture(34067,s),t.texImage2D(34069,0,6408,3,3,0,6408,5121,o),G.freeType(o),t.bindTexture(34067,null),t.deleteTexture(s),s=!t.getError()),{colorBits:[t.getParameter(3410),t.getParameter(3411),t.getParameter(3412),t.getParameter(3413)],depthBits:t.getParameter(3414),stencilBits:t.getParameter(3415),subpixelBits:t.getParameter(3408),extensions:Object.keys(e).filter(function(t){return!!e[t]}),maxAnisotropic:r,maxDrawbuffers:n,maxColorAttachments:i,pointSizeDims:t.getParameter(33901),lineWidthDims:t.getParameter(33902),maxViewportDims:t.getParameter(3386),maxCombinedTextureUnits:t.getParameter(35661),maxCubeMapSize:t.getParameter(34076),maxRenderbufferSize:t.getParameter(34024),maxTextureUnits:t.getParameter(34930),maxTextureSize:t.getParameter(3379),maxAttributes:t.getParameter(34921),maxVertexUniforms:t.getParameter(36347),maxVertexTextureUnits:t.getParameter(35660),maxVaryingVectors:t.getParameter(36348),maxFragmentUniforms:t.getParameter(36349),glsl:t.getParameter(35724),renderer:t.getParameter(7937),vendor:t.getParameter(7936),version:t.getParameter(7938),readFloat:a,npotTextureCube:s}},W=function(t){return t instanceof Uint8Array||t instanceof Uint16Array||t instanceof Uint32Array||t instanceof Int8Array||t instanceof Int16Array||t instanceof Int32Array||t instanceof Float32Array||t instanceof Float64Array||t instanceof Uint8ClampedArray},X=function(t){return Object.keys(t).map(function(e){return t[e]})},Z={shape:function(t){for(var e=[];t.length;t=t[0])e.push(t.length);return e},flatten:function(t,e,r,n){var i=1;if(e.length)for(var a=0;a<e.length;++a)i*=e[a];else i=0;switch(r=n||G.allocType(r,i),e.length){case 0:break;case 1:for(n=e[0],e=0;e<n;++e)r[e]=t[e];break;case 2:for(n=e[0],e=e[1],a=i=0;a<n;++a)for(var o=t[a],s=0;s<e;++s)r[i++]=o[s];break;case 3:c(t,e[0],e[1],e[2],r,0);break;default:!function t(e,r,n,i,a){for(var o=1,s=n+1;s<r.length;++s)o*=r[s];var l=r[n];if(4==r.length-n){var u=r[n+1],h=r[n+2];for(r=r[n+3],s=0;s<l;++s)c(e[s],u,h,r,i,a),a+=o}else for(s=0;s<l;++s)t(e[s],r,n+1,i,a),a+=o}(t,e,0,r,0)}return r}},J={\"[object Int8Array]\":5120,\"[object Int16Array]\":5122,\"[object Int32Array]\":5124,\"[object Uint8Array]\":5121,\"[object Uint8ClampedArray]\":5121,\"[object Uint16Array]\":5123,\"[object Uint32Array]\":5125,\"[object Float32Array]\":5126,\"[object Float64Array]\":5121,\"[object ArrayBuffer]\":5121},K={int8:5120,int16:5122,int32:5124,uint8:5121,uint16:5123,uint32:5125,float:5126,float32:5126},$={dynamic:35048,stream:35040,static:35044},Q=Z.flatten,tt=Z.shape,et=[];et[5120]=1,et[5122]=2,et[5124]=4,et[5121]=1,et[5123]=2,et[5125]=4,et[5126]=4;var rt={points:0,point:0,lines:1,line:1,triangles:4,triangle:4,\"line loop\":2,\"line strip\":3,\"triangle strip\":5,\"triangle fan\":6},nt=new Float32Array(1),it=new Uint32Array(nt.buffer),at=[9984,9986,9985,9987],ot=[0,6409,6410,6407,6408],st={};st[6409]=st[6406]=st[6402]=1,st[34041]=st[6410]=2,st[6407]=st[35904]=3,st[6408]=st[35906]=4;var lt=m(\"HTMLCanvasElement\"),ct=m(\"CanvasRenderingContext2D\"),ut=m(\"ImageBitmap\"),ht=m(\"HTMLImageElement\"),ft=m(\"HTMLVideoElement\"),pt=Object.keys(J).concat([lt,ct,ut,ht,ft]),dt=[];dt[5121]=1,dt[5126]=4,dt[36193]=2,dt[5123]=2,dt[5125]=4;var gt=[];gt[32854]=2,gt[32855]=2,gt[36194]=2,gt[34041]=4,gt[33776]=.5,gt[33777]=.5,gt[33778]=1,gt[33779]=1,gt[35986]=.5,gt[35987]=1,gt[34798]=1,gt[35840]=.5,gt[35841]=.25,gt[35842]=.5,gt[35843]=.25,gt[36196]=.5;var vt=[];vt[32854]=2,vt[32855]=2,vt[36194]=2,vt[33189]=2,vt[36168]=1,vt[34041]=4,vt[35907]=4,vt[34836]=16,vt[34842]=8,vt[34843]=6;var mt=function(t,e,r,n,i){function a(t){this.id=c++,this.refCount=1,this.renderbuffer=t,this.format=32854,this.height=this.width=0,i.profile&&(this.stats={size:0})}function o(e){var r=e.renderbuffer;t.bindRenderbuffer(36161,null),t.deleteRenderbuffer(r),e.renderbuffer=null,e.refCount=0,delete u[e.id],n.renderbufferCount--}var s={rgba4:32854,rgb565:36194,\"rgb5 a1\":32855,depth:33189,stencil:36168,\"depth stencil\":34041};e.ext_srgb&&(s.srgba=35907),e.ext_color_buffer_half_float&&(s.rgba16f=34842,s.rgb16f=34843),e.webgl_color_buffer_float&&(s.rgba32f=34836);var l=[];Object.keys(s).forEach(function(t){l[s[t]]=t});var c=0,u={};return a.prototype.decRef=function(){0>=--this.refCount&&o(this)},i.profile&&(n.getTotalRenderbufferSize=function(){var t=0;return Object.keys(u).forEach(function(e){t+=u[e].stats.size}),t}),{create:function(e,r){function o(e,r){var n=0,a=0,u=32854;if(\"object\"==typeof e&&e?(\"shape\"in e?(n=0|(a=e.shape)[0],a=0|a[1]):(\"radius\"in e&&(n=a=0|e.radius),\"width\"in e&&(n=0|e.width),\"height\"in e&&(a=0|e.height)),\"format\"in e&&(u=s[e.format])):\"number\"==typeof e?(n=0|e,a=\"number\"==typeof r?0|r:n):e||(n=a=1),n!==c.width||a!==c.height||u!==c.format)return o.width=c.width=n,o.height=c.height=a,c.format=u,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,u,n,a),i.profile&&(c.stats.size=vt[c.format]*c.width*c.height),o.format=l[c.format],o}var c=new a(t.createRenderbuffer());return u[c.id]=c,n.renderbufferCount++,o(e,r),o.resize=function(e,r){var n=0|e,a=0|r||n;return n===c.width&&a===c.height?o:(o.width=c.width=n,o.height=c.height=a,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,c.format,n,a),i.profile&&(c.stats.size=vt[c.format]*c.width*c.height),o)},o._reglType=\"renderbuffer\",o._renderbuffer=c,i.profile&&(o.stats=c.stats),o.destroy=function(){c.decRef()},o},clear:function(){X(u).forEach(o)},restore:function(){X(u).forEach(function(e){e.renderbuffer=t.createRenderbuffer(),t.bindRenderbuffer(36161,e.renderbuffer),t.renderbufferStorage(36161,e.format,e.width,e.height)}),t.bindRenderbuffer(36161,null)}}},yt=[];yt[6408]=4,yt[6407]=3;var xt=[];xt[5121]=1,xt[5126]=4,xt[36193]=2;var bt=[\"x\",\"y\",\"z\",\"w\"],_t=\"blend.func blend.equation stencil.func stencil.opFront stencil.opBack sample.coverage viewport scissor.box polygonOffset.offset\".split(\" \"),wt={0:0,1:1,zero:0,one:1,\"src color\":768,\"one minus src color\":769,\"src alpha\":770,\"one minus src alpha\":771,\"dst color\":774,\"one minus dst color\":775,\"dst alpha\":772,\"one minus dst alpha\":773,\"constant color\":32769,\"one minus constant color\":32770,\"constant alpha\":32771,\"one minus constant alpha\":32772,\"src alpha saturate\":776},kt={never:512,less:513,\"<\":513,equal:514,\"=\":514,\"==\":514,\"===\":514,lequal:515,\"<=\":515,greater:516,\">\":516,notequal:517,\"!=\":517,\"!==\":517,gequal:518,\">=\":518,always:519},Tt={0:0,zero:0,keep:7680,replace:7681,increment:7682,decrement:7683,\"increment wrap\":34055,\"decrement wrap\":34056,invert:5386},At={cw:2304,ccw:2305},Mt=new I(!1,!1,!1,function(){});return function(t){function e(){if(0===Z.length)w&&w.update(),Q=null;else{Q=q.next(e),h();for(var t=Z.length-1;0<=t;--t){var r=Z[t];r&&r(P,null,0)}v.flush(),w&&w.update()}}function r(){!Q&&0<Z.length&&(Q=q.next(e))}function n(){Q&&(q.cancel(e),Q=null)}function a(t){t.preventDefault(),n(),J.forEach(function(t){t()})}function o(t){v.getError(),y.restore(),D.restore(),z.restore(),R.restore(),F.restore(),U.restore(),w&&w.restore(),G.procs.refresh(),r(),K.forEach(function(t){t()})}function s(t){function e(t){var e={},r={};return Object.keys(t).forEach(function(n){var i=t[n];V.isDynamic(i)?r[n]=V.unbox(i,n):e[n]=i}),{dynamic:r,static:e}}var r=e(t.context||{}),n=e(t.uniforms||{}),i=e(t.attributes||{}),a=e(function(t){function e(t){if(t in r){var e=r[t];delete r[t],Object.keys(e).forEach(function(n){r[t+\".\"+n]=e[n]})}}var r=j({},t);return delete r.uniforms,delete r.attributes,delete r.context,\"stencil\"in r&&r.stencil.op&&(r.stencil.opBack=r.stencil.opFront=r.stencil.op,delete r.stencil.op),e(\"blend\"),e(\"depth\"),e(\"cull\"),e(\"stencil\"),e(\"polygonOffset\"),e(\"scissor\"),e(\"sample\"),r}(t));t={gpuTime:0,cpuTime:0,count:0};var o=(r=G.compile(a,i,n,r,t)).draw,s=r.batch,l=r.scope,c=[];return j(function(t,e){var r;if(\"function\"==typeof t)return l.call(this,null,t,0);if(\"function\"==typeof e)if(\"number\"==typeof t)for(r=0;r<t;++r)l.call(this,null,e,r);else{if(!Array.isArray(t))return l.call(this,t,e,0);for(r=0;r<t.length;++r)l.call(this,t[r],e,r)}else if(\"number\"==typeof t){if(0<t)return s.call(this,function(t){for(;c.length<t;)c.push(null);return c}(0|t),0|t)}else{if(!Array.isArray(t))return o.call(this,t);if(t.length)return s.call(this,t,t.length)}},{stats:t})}function l(t,e){var r=0;G.procs.poll();var n=e.color;n&&(v.clearColor(+n[0]||0,+n[1]||0,+n[2]||0,+n[3]||0),r|=16384),\"depth\"in e&&(v.clearDepth(+e.depth),r|=256),\"stencil\"in e&&(v.clearStencil(0|e.stencil),r|=1024),v.clear(r)}function c(t){return Z.push(t),r(),{cancel:function(){var e=N(Z,t);Z[e]=function t(){var e=N(Z,t);Z[e]=Z[Z.length-1],--Z.length,0>=Z.length&&n()}}}}function u(){var t=W.viewport,e=W.scissor_box;t[0]=t[1]=e[0]=e[1]=0,P.viewportWidth=P.framebufferWidth=P.drawingBufferWidth=t[2]=e[2]=v.drawingBufferWidth,P.viewportHeight=P.framebufferHeight=P.drawingBufferHeight=t[3]=e[3]=v.drawingBufferHeight}function h(){P.tick+=1,P.time=g(),u(),G.procs.poll()}function f(){u(),G.procs.refresh(),w&&w.update()}function g(){return(H()-k)/1e3}if(!(t=i(t)))return null;var v=t.gl,m=v.getContextAttributes();v.isContextLost();var y=function(t,e){function r(e){var r;e=e.toLowerCase();try{r=n[e]=t.getExtension(e)}catch(t){}return!!r}for(var n={},i=0;i<e.extensions.length;++i){var a=e.extensions[i];if(!r(a))return e.onDestroy(),e.onDone('\"'+a+'\" extension is not supported by the current WebGL context, try upgrading your system or a different browser'),null}return e.optionalExtensions.forEach(r),{extensions:n,restore:function(){Object.keys(n).forEach(function(t){if(n[t]&&!r(t))throw Error(\"(regl): error restoring extension \"+t)})}}}(v,t);if(!y)return null;var x=function(){var t={\"\":0},e=[\"\"];return{id:function(r){var n=t[r];return n||(n=t[r]=e.length,e.push(r),n)},str:function(t){return e[t]}}}(),b={bufferCount:0,elementsCount:0,framebufferCount:0,shaderCount:0,textureCount:0,cubeCount:0,renderbufferCount:0,maxTextureUnits:0},_=y.extensions,w=function(t,e){function r(){this.endQueryIndex=this.startQueryIndex=-1,this.sum=0,this.stats=null}function n(t,e,n){var i=o.pop()||new r;i.startQueryIndex=t,i.endQueryIndex=e,i.sum=0,i.stats=n,s.push(i)}if(!e.ext_disjoint_timer_query)return null;var i=[],a=[],o=[],s=[],l=[],c=[];return{beginQuery:function(t){var r=i.pop()||e.ext_disjoint_timer_query.createQueryEXT();e.ext_disjoint_timer_query.beginQueryEXT(35007,r),a.push(r),n(a.length-1,a.length,t)},endQuery:function(){e.ext_disjoint_timer_query.endQueryEXT(35007)},pushScopeStats:n,update:function(){var t,r;if(0!==(t=a.length)){c.length=Math.max(c.length,t+1),l.length=Math.max(l.length,t+1),l[0]=0;var n=c[0]=0;for(r=t=0;r<a.length;++r){var u=a[r];e.ext_disjoint_timer_query.getQueryObjectEXT(u,34919)?(n+=e.ext_disjoint_timer_query.getQueryObjectEXT(u,34918),i.push(u)):a[t++]=u,l[r+1]=n,c[r+1]=t}for(a.length=t,r=t=0;r<s.length;++r){var h=(n=s[r]).startQueryIndex;u=n.endQueryIndex,n.sum+=l[u]-l[h],h=c[h],(u=c[u])===h?(n.stats.gpuTime+=n.sum/1e6,o.push(n)):(n.startQueryIndex=h,n.endQueryIndex=u,s[t++]=n)}s.length=t}},getNumPendingQueries:function(){return a.length},clear:function(){i.push.apply(i,a);for(var t=0;t<i.length;t++)e.ext_disjoint_timer_query.deleteQueryEXT(i[t]);a.length=0,i.length=0},restore:function(){a.length=0,i.length=0}}}(0,_),k=H(),C=v.drawingBufferWidth,L=v.drawingBufferHeight,P={tick:0,time:0,viewportWidth:C,viewportHeight:L,framebufferWidth:C,framebufferHeight:L,drawingBufferWidth:C,drawingBufferHeight:L,pixelRatio:t.pixelRatio},O=Y(v,_),z=(C=function(t,e,r,n){for(t=r.maxAttributes,e=Array(t),r=0;r<t;++r)e[r]=new M;return{Record:M,scope:{},state:e}}(v,_,O),p(v,b,t,C)),I=d(v,_,z,b),D=S(v,x,b,t),R=T(v,_,O,function(){G.procs.poll()},P,b,t),F=mt(v,_,0,b,t),U=A(v,_,O,R,F,b),G=B(v,x,_,O,z,I,0,U,{},C,D,{elements:null,primitive:4,count:-1,offset:0,instances:-1},P,w,t),W=(x=E(v,U,G.procs.poll,P),G.next),X=v.canvas,Z=[],J=[],K=[],$=[t.onDestroy],Q=null;X&&(X.addEventListener(\"webglcontextlost\",a,!1),X.addEventListener(\"webglcontextrestored\",o,!1));var tt=U.setFBO=s({framebuffer:V.define.call(null,1,\"framebuffer\")});return f(),m=j(s,{clear:function(t){if(\"framebuffer\"in t)if(t.framebuffer&&\"framebufferCube\"===t.framebuffer_reglType)for(var e=0;6>e;++e)tt(j({framebuffer:t.framebuffer.faces[e]},t),l);else tt(t,l);else l(0,t)},prop:V.define.bind(null,1),context:V.define.bind(null,2),this:V.define.bind(null,3),draw:s({}),buffer:function(t){return z.create(t,34962,!1,!1)},elements:function(t){return I.create(t,!1)},texture:R.create2D,cube:R.createCube,renderbuffer:F.create,framebuffer:U.create,framebufferCube:U.createCube,attributes:m,frame:c,on:function(t,e){var r;switch(t){case\"frame\":return c(e);case\"lost\":r=J;break;case\"restore\":r=K;break;case\"destroy\":r=$}return r.push(e),{cancel:function(){for(var t=0;t<r.length;++t)if(r[t]===e){r[t]=r[r.length-1],r.pop();break}}}},limits:O,hasExtension:function(t){return 0<=O.extensions.indexOf(t.toLowerCase())},read:x,destroy:function(){Z.length=0,n(),X&&(X.removeEventListener(\"webglcontextlost\",a),X.removeEventListener(\"webglcontextrestored\",o)),D.clear(),U.clear(),F.clear(),R.clear(),I.clear(),z.clear(),w&&w.clear(),$.forEach(function(t){t()})},_gl:v,_refresh:f,poll:function(){h(),w&&w.update()},now:g,stats:b}),t.onDone(null,m),m}},\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=i():n.createREGL=i()},{}],503:[function(t,e,r){\"use strict\";var n,i=\"\";e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"expected a string\");if(1===e)return t;if(2===e)return t+t;var r=t.length*e;if(n!==t||\"undefined\"==typeof n)n=t,i=\"\";else if(i.length>=r)return i.substr(0,r);for(;r>i.length&&e>1;)1&e&&(i+=t),e>>=1,t+=t;return i=(i+=t).substr(0,r)}},{}],504:[function(t,e,r){(function(t){e.exports=t.performance&&t.performance.now?function(){return performance.now()}:Date.now||function(){return+new Date}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{}],505:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=t[t.length-1],n=e,i=e-2;i>=0;--i){var a=r,o=t[i],s=(r=a+o)-a,l=o-s;l&&(t[--n]=r,r=l)}for(var c=0,i=n;i<e;++i){var a=t[i],o=r,s=(r=a+o)-a,l=o-s;l&&(t[c++]=l)}return t[c++]=r,t.length=c,t}},{}],506:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-compress\"),s=6;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(2===t.length)return[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\");for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(l(t,r)),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return function t(e){if(1===e.length)return e[0];if(2===e.length)return[\"sum(\",e[0],\",\",e[1],\")\"].join(\"\");var r=e.length>>1;return[\"sum(\",t(e.slice(0,r)),\",\",t(e.slice(r)),\")\"].join(\"\")}(e);var n}function u(t){return new Function(\"sum\",\"scale\",\"prod\",\"compress\",[\"function robustDeterminant\",t,\"(m){return compress(\",c(function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m[\",r,\"][\",n,\"]\"].join(\"\")}return e}(t)),\")};return robustDeterminant\",t].join(\"\"))(i,a,n,o)}var h=[function(){return[0]},function(t){return[t[0][0]]}];!function(){for(;h.length<s;)h.push(u(h.length));for(var t=[],r=[\"function robustDeterminant(m){switch(m.length){\"],n=0;n<s;++n)t.push(\"det\"+n),r.push(\"case \",n,\":return det\",n,\"(m);\");r.push(\"}var det=CACHE[m.length];if(!det)det=CACHE[m.length]=gen(m.length);return det(m);}return robustDeterminant\"),t.push(\"CACHE\",\"gen\",r.join(\"\"));var i=Function.apply(void 0,t);for(e.exports=i.apply(void 0,h.concat([h,u])),n=0;n<h.length;++n)e.exports[n]=h[n]}()},{\"robust-compress\":505,\"robust-scale\":512,\"robust-sum\":515,\"two-product\":543}],507:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\");e.exports=function(t,e){for(var r=n(t[0],e[0]),a=1;a<t.length;++a)r=i(r,n(t[a],e[a]));return r}},{\"robust-sum\":515,\"two-product\":543}],508:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-subtract\"),o=t(\"robust-scale\"),s=6;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",c(t.slice(0,e)),\",\",c(t.slice(e)),\")\"].join(\"\")}function u(t,e){if(\"m\"===t.charAt(0)){if(\"w\"===e.charAt(0)){var r=t.split(\"[\");return[\"w\",e.substr(1),\"m\",r[0].substr(1)].join(\"\")}return[\"prod(\",t,\",\",e,\")\"].join(\"\")}return u(e,t)}function h(t){if(2===t.length)return[[\"diff(\",u(t[0][0],t[1][1]),\",\",u(t[1][0],t[0][1]),\")\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(h(l(t,r))),\",\",(n=r,!0&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function f(t,e){for(var r=[],n=0;n<e-2;++n)r.push([\"prod(m\",t,\"[\",n,\"],m\",t,\"[\",n,\"])\"].join(\"\"));return c(r)}function p(t){for(var e=[],r=[],s=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-2,\"]\"].join(\"\")}return e}(t),u=0;u<t;++u)s[0][u]=\"1\",s[t-1][u]=\"w\"+u;for(u=0;u<t;++u)0==(1&u)?e.push.apply(e,h(l(s,u))):r.push.apply(r,h(l(s,u)));var p=c(e),d=c(r),g=\"exactInSphere\"+t,v=[];for(u=0;u<t;++u)v.push(\"m\"+u);var m=[\"function \",g,\"(\",v.join(),\"){\"];for(u=0;u<t;++u){m.push(\"var w\",u,\"=\",f(u,t),\";\");for(var y=0;y<t;++y)y!==u&&m.push(\"var w\",u,\"m\",y,\"=scale(w\",u,\",m\",y,\"[0]);\")}return m.push(\"var p=\",p,\",n=\",d,\",d=diff(p,n);return d[d.length-1];}return \",g),new Function(\"sum\",\"diff\",\"prod\",\"scale\",m.join(\"\"))(i,a,n,o)}var d=[function(){return 0},function(){return 0},function(){return 0}];!function(){for(;d.length<=s;)d.push(p(d.length));for(var t=[],r=[\"slow\"],n=0;n<=s;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function testInSphere(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=s;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return testInSphere\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[function(t){var e=d[t.length];return e||(e=d[t.length]=p(t.length)),e.apply(void 0,t)}].concat(d)),n=0;n<=s;++n)e.exports[n]=d[n]}()},{\"robust-scale\":512,\"robust-subtract\":514,\"robust-sum\":515,\"two-product\":543}],509:[function(t,e,r){\"use strict\";var n=t(\"robust-determinant\"),i=6;function a(t){for(var e=\"robustLinearSolve\"+t+\"d\",r=[\"function \",e,\"(A,b){return [\"],i=0;i<t;++i){r.push(\"det([\");for(var a=0;a<t;++a){a>0&&r.push(\",\"),r.push(\"[\");for(var o=0;o<t;++o)o>0&&r.push(\",\"),o===i?r.push(\"+b[\",a,\"]\"):r.push(\"+A[\",a,\"][\",o,\"]\");r.push(\"]\")}r.push(\"]),\")}r.push(\"det(A)]}return \",e);var s=new Function(\"det\",r.join(\"\"));return s(t<6?n[t]:n)}var o=[function(){return[0]},function(t,e){return[[e[0]],[t[0][0]]]}];!function(){for(;o.length<i;)o.push(a(o.length));for(var t=[],r=[\"function dispatchLinearSolve(A,b){switch(A.length){\"],n=0;n<i;++n)t.push(\"s\"+n),r.push(\"case \",n,\":return s\",n,\"(A,b);\");r.push(\"}var s=CACHE[A.length];if(!s)s=CACHE[A.length]=g(A.length);return s(A,b)}return dispatchLinearSolve\"),t.push(\"CACHE\",\"g\",r.join(\"\"));var s=Function.apply(void 0,t);for(e.exports=s.apply(void 0,o.concat([o,a])),n=0;n<i;++n)e.exports[n]=o[n]}()},{\"robust-determinant\":506}],510:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-subtract\"),s=5;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",c(t.slice(0,e)),\",\",c(t.slice(e)),\")\"].join(\"\")}function u(t){if(2===t.length)return[[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(u(l(t,r))),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function h(t){for(var e=[],r=[],s=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-1,\"]\"].join(\"\")}return e}(t),h=[],f=0;f<t;++f)0==(1&f)?e.push.apply(e,u(l(s,f))):r.push.apply(r,u(l(s,f))),h.push(\"m\"+f);var p=c(e),d=c(r),g=\"orientation\"+t+\"Exact\",v=[\"function \",g,\"(\",h.join(),\"){var p=\",p,\",n=\",d,\",d=sub(p,n);return d[d.length-1];};return \",g].join(\"\");return new Function(\"sum\",\"prod\",\"scale\",\"sub\",v)(i,n,a,o)}var f=h(3),p=h(4),d=[function(){return 0},function(){return 0},function(t,e){return e[0]-t[0]},function(t,e,r){var n,i=(t[1]-r[1])*(e[0]-r[0]),a=(t[0]-r[0])*(e[1]-r[1]),o=i-a;if(i>0){if(a<=0)return o;n=i+a}else{if(!(i<0))return o;if(a>=0)return o;n=-(i+a)}var s=3.3306690738754716e-16*n;return o>=s||o<=-s?o:f(t,e,r)},function(t,e,r,n){var i=t[0]-n[0],a=e[0]-n[0],o=r[0]-n[0],s=t[1]-n[1],l=e[1]-n[1],c=r[1]-n[1],u=t[2]-n[2],h=e[2]-n[2],f=r[2]-n[2],d=a*c,g=o*l,v=o*s,m=i*c,y=i*l,x=a*s,b=u*(d-g)+h*(v-m)+f*(y-x),_=7.771561172376103e-16*((Math.abs(d)+Math.abs(g))*Math.abs(u)+(Math.abs(v)+Math.abs(m))*Math.abs(h)+(Math.abs(y)+Math.abs(x))*Math.abs(f));return b>_||-b>_?b:p(t,e,r,n)}];!function(){for(;d.length<=s;)d.push(h(d.length));for(var t=[],r=[\"slow\"],n=0;n<=s;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function getOrientation(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=s;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return getOrientation\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[function(t){var e=d[t.length];return e||(e=d[t.length]=h(t.length)),e.apply(void 0,t)}].concat(d)),n=0;n<=s;++n)e.exports[n]=d[n]}()},{\"robust-scale\":512,\"robust-subtract\":514,\"robust-sum\":515,\"two-product\":543}],511:[function(t,e,r){\"use strict\";var n=t(\"robust-sum\"),i=t(\"robust-scale\");e.exports=function(t,e){if(1===t.length)return i(e,t[0]);if(1===e.length)return i(t,e[0]);if(0===t.length||0===e.length)return[0];var r=[0];if(t.length<e.length)for(var a=0;a<t.length;++a)r=n(r,i(e,t[a]));else for(var a=0;a<e.length;++a)r=n(r,i(t,e[a]));return r}},{\"robust-scale\":512,\"robust-sum\":515}],512:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"two-sum\");e.exports=function(t,e){var r=t.length;if(1===r){var a=n(t[0],e);return a[0]?a:[a[1]]}var o=new Array(2*r),s=[.1,.1],l=[.1,.1],c=0;n(t[0],e,s),s[0]&&(o[c++]=s[0]);for(var u=1;u<r;++u){n(t[u],e,l);var h=s[1];i(h,l[0],s),s[0]&&(o[c++]=s[0]);var f=l[1],p=s[1],d=f+p,g=d-f,v=p-g;s[1]=d,v&&(o[c++]=v)}s[1]&&(o[c++]=s[1]);0===c&&(o[c++]=0);return o.length=c,o}},{\"two-product\":543,\"two-sum\":544}],513:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){var a=n(t,r,i),o=n(e,r,i);if(a>0&&o>0||a<0&&o<0)return!1;var s=n(r,t,e),l=n(i,t,e);if(s>0&&l>0||s<0&&l<0)return!1;if(0===a&&0===o&&0===s&&0===l)return function(t,e,r,n){for(var i=0;i<2;++i){var a=t[i],o=e[i],s=Math.min(a,o),l=Math.max(a,o),c=r[i],u=n[i],h=Math.min(c,u),f=Math.max(c,u);if(f<s||l<h)return!1}return!0}(t,e,r,i);return!0};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":510}],514:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],-e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,h=t[l],f=u(h),p=-e[c],d=u(p);f<d?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=-e[c],d=u(p)));l<r&&f<d||c>=n?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p)));var g,v,m=i+a,y=m-i,x=a-y,b=x,_=m;for(;l<r&&c<n;)f<d?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p))),(x=(a=b)-(y=(m=i+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g;for(;l<r;)(x=(a=b)-(y=(m=(i=h)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(l+=1)<r&&(h=t[l]);for(;c<n;)(x=(a=b)-(y=(m=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(c+=1)<n&&(p=-e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],515:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,h=t[l],f=u(h),p=e[c],d=u(p);f<d?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=e[c],d=u(p)));l<r&&f<d||c>=n?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=e[c],d=u(p)));var g,v,m=i+a,y=m-i,x=a-y,b=x,_=m;for(;l<r&&c<n;)f<d?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=e[c],d=u(p))),(x=(a=b)-(y=(m=i+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g;for(;l<r;)(x=(a=b)-(y=(m=(i=h)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(l+=1)<r&&(h=t[l]);for(;c<n;)(x=(a=b)-(y=(m=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(c+=1)<n&&(p=e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],516:[function(t,e,r){\"use strict\";e.exports=function(t){return t<0?-1:t>0?1:0}},{}],517:[function(t,e,r){\"use strict\";e.exports=function(t){return i(n(t))};var n=t(\"boundary-cells\"),i=t(\"reduce-simplicial-complex\")},{\"boundary-cells\":95,\"reduce-simplicial-complex\":489}],518:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,s){r=r||0,\"undefined\"==typeof s&&(s=function(t){for(var e=t.length,r=0,n=0;n<e;++n)r=0|Math.max(r,t[n].length);return r-1}(t));if(0===t.length||s<1)return{cells:[],vertexIds:[],vertexWeights:[]};var l=function(t,e){for(var r=t.length,n=i.mallocUint8(r),a=0;a<r;++a)n[a]=t[a]<e|0;return n}(e,+r),c=function(t,e){for(var r=t.length,o=e*(e+1)/2*r|0,s=i.mallocUint32(2*o),l=0,c=0;c<r;++c)for(var u=t[c],e=u.length,h=0;h<e;++h)for(var f=0;f<h;++f){var p=u[f],d=u[h];s[l++]=0|Math.min(p,d),s[l++]=0|Math.max(p,d)}a(n(s,[l/2|0,2]));for(var g=2,c=2;c<l;c+=2)s[c-2]===s[c]&&s[c-1]===s[c+1]||(s[g++]=s[c],s[g++]=s[c+1]);return n(s,[g/2|0,2])}(t,s),u=function(t,e,r,a){for(var o=t.data,s=t.shape[0],l=i.mallocDouble(s),c=0,u=0;u<s;++u){var h=o[2*u],f=o[2*u+1];if(r[h]!==r[f]){var p=e[h],d=e[f];o[2*c]=h,o[2*c+1]=f,l[c++]=(d-a)/(d-p)}}return t.shape[0]=c,n(l,[c])}(c,e,l,+r),h=function(t,e){var r=i.mallocInt32(2*e),n=t.shape[0],a=t.data;r[0]=0;for(var o=0,s=0;s<n;++s){var l=a[2*s];if(l!==o){for(r[2*o+1]=s;++o<l;)r[2*o]=s,r[2*o+1]=s;r[2*o]=s}}r[2*o+1]=n;for(;++o<e;)r[2*o]=r[2*o+1]=n;return r}(c,0|e.length),f=o(s)(t,c.data,h,l),p=function(t){for(var e=0|t.shape[0],r=t.data,n=new Array(e),i=0;i<e;++i)n[i]=[r[2*i],r[2*i+1]];return n}(c),d=[].slice.call(u.data,0,u.shape[0]);return i.free(l),i.free(c.data),i.free(u.data),i.free(h),{cells:f,vertexIds:p,vertexWeights:d}};var n=t(\"ndarray\"),i=t(\"typedarray-pool\"),a=t(\"ndarray-sort\"),o=t(\"./lib/codegen\")},{\"./lib/codegen\":519,ndarray:450,\"ndarray-sort\":448,\"typedarray-pool\":545}],519:[function(t,e,r){\"use strict\";e.exports=function(t){var e=a[t];e||(e=a[t]=function(t){var e=0,r=new Array(t+1);r[0]=[[]];for(var a=1;a<=t;++a)for(var o=r[a]=i(a),s=0;s<o.length;++s)e=Math.max(e,o[a].length);var l=[\"function B(C,E,i,j){\",\"var a=Math.min(i,j)|0,b=Math.max(i,j)|0,l=C[2*a],h=C[2*a+1];\",\"while(l<h){\",\"var m=(l+h)>>1,v=E[2*m+1];\",\"if(v===b){return m}\",\"if(b<v){h=m}else{l=m+1}\",\"}\",\"return l;\",\"};\",\"function getContour\",t,\"d(F,E,C,S){\",\"var n=F.length,R=[];\",\"for(var i=0;i<n;++i){var c=F[i],l=c.length;\"];function c(t){if(!(t.length<=0)){l.push(\"R.push(\");for(var e=0;e<t.length;++e){var r=t[e];e>0&&l.push(\",\"),l.push(\"[\");for(var n=0;n<r.length;++n){var i=r[n];n>0&&l.push(\",\"),l.push(\"B(C,E,c[\",i[0],\"],c[\",i[1],\"])\")}l.push(\"]\")}l.push(\");\")}}for(var a=t+1;a>1;--a){a<t+1&&l.push(\"else \"),l.push(\"if(l===\",a,\"){\");for(var u=[],s=0;s<a;++s)u.push(\"(S[c[\"+s+\"]]<<\"+s+\")\");l.push(\"var M=\",u.join(\"+\"),\";if(M===0||M===\",(1<<a)-1,\"){continue}switch(M){\");for(var o=r[a-1],s=0;s<o.length;++s)l.push(\"case \",s,\":\"),c(o[s]),l.push(\"break;\");l.push(\"}}\")}return l.push(\"}return R;};return getContour\",t,\"d\"),new Function(\"pool\",l.join(\"\"))(n)}(t));return e};var n=t(\"typedarray-pool\"),i=t(\"marching-simplex-table\"),a={}},{\"marching-simplex-table\":427,\"typedarray-pool\":545}],520:[function(t,e,r){\"use strict\";var n=t(\"bit-twiddle\"),i=t(\"union-find\");function a(t,e){var r=t.length,n=t.length-e.length,i=Math.min;if(n)return n;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return(s=t[0]+t[1]-e[0]-e[1])||i(t[0],t[1])-i(e[0],e[1]);case 3:var a=t[0]+t[1],o=e[0]+e[1];if(s=a+t[2]-(o+e[2]))return s;var s,l=i(t[0],t[1]),c=i(e[0],e[1]);return(s=i(l,t[2])-i(c,e[2]))||i(l+t[2],a)-i(c+e[2],o);default:var u=t.slice(0);u.sort();var h=e.slice(0);h.sort();for(var f=0;f<r;++f)if(n=u[f]-h[f])return n;return 0}}function o(t,e){return a(t[0],e[0])}function s(t,e){if(e){for(var r=t.length,n=new Array(r),i=0;i<r;++i)n[i]=[t[i],e[i]];n.sort(o);for(i=0;i<r;++i)t[i]=n[i][0],e[i]=n[i][1];return t}return t.sort(a),t}function l(t){if(0===t.length)return[];for(var e=1,r=t.length,n=1;n<r;++n){var i=t[n];if(a(i,t[n-1])){if(n===e){e++;continue}t[e++]=i}}return t.length=e,t}function c(t,e){for(var r=0,n=t.length-1,i=-1;r<=n;){var o=r+n>>1,s=a(t[o],e);s<=0?(0===s&&(i=o),r=o+1):s>0&&(n=o-1)}return i}function u(t,e){for(var r=new Array(t.length),i=0,o=r.length;i<o;++i)r[i]=[];for(var s=[],l=(i=0,e.length);i<l;++i)for(var u=e[i],h=u.length,f=1,p=1<<h;f<p;++f){s.length=n.popCount(f);for(var d=0,g=0;g<h;++g)f&1<<g&&(s[d++]=u[g]);var v=c(t,s);if(!(v<0))for(;r[v++].push(i),!(v>=t.length||0!==a(t[v],s)););}return r}function h(t,e){if(e<0)return[];for(var r=[],i=(1<<e+1)-1,a=0;a<t.length;++a)for(var o=t[a],l=i;l<1<<o.length;l=n.nextCombination(l)){for(var c=new Array(e+1),u=0,h=0;h<o.length;++h)l&1<<h&&(c[u++]=o[h]);r.push(c)}return s(r)}r.dimension=function(t){for(var e=0,r=Math.max,n=0,i=t.length;n<i;++n)e=r(e,t[n].length);return e-1},r.countVertices=function(t){for(var e=-1,r=Math.max,n=0,i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)e=r(e,a[o]);return e+1},r.cloneCells=function(t){for(var e=new Array(t.length),r=0,n=t.length;r<n;++r)e[r]=t[r].slice(0);return e},r.compareCells=a,r.normalize=s,r.unique=l,r.findCell=c,r.incidence=u,r.dual=function(t,e){if(!e)return u(l(h(t,0)),t);for(var r=new Array(e),n=0;n<e;++n)r[n]=[];n=0;for(var i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)r[a[o]].push(n);return r},r.explode=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0|i.length,o=1,l=1<<a;o<l;++o){for(var c=[],u=0;u<a;++u)o>>>u&1&&c.push(i[u]);e.push(c)}return s(e)},r.skeleton=h,r.boundary=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;++a){for(var l=new Array(i.length-1),c=0,u=0;c<o;++c)c!==a&&(l[u++]=i[c]);e.push(l)}return s(e)},r.connectedComponents=function(t,e){return e?function(t,e){for(var r=new i(e),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var s=o+1;s<a.length;++s)r.link(a[o],a[s]);var l=[],c=r.ranks;for(n=0;n<c.length;++n)c[n]=-1;for(n=0;n<t.length;++n){var u=r.find(t[n][0]);c[u]<0?(c[u]=l.length,l.push([t[n].slice(0)])):l[c[u]].push(t[n].slice(0))}return l}(t,e):function(t){for(var e=l(s(h(t,0))),r=new i(e.length),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var u=c(e,[a[o]]),f=o+1;f<a.length;++f)r.link(u,c(e,[a[f]]));var p=[],d=r.ranks;for(n=0;n<d.length;++n)d[n]=-1;for(n=0;n<t.length;++n){var g=r.find(c(e,[t[n][0]]));d[g]<0?(d[g]=p.length,p.push([t[n].slice(0)])):p[d[g]].push(t[n].slice(0))}return p}(t)}},{\"bit-twiddle\":92,\"union-find\":546}],521:[function(t,e,r){arguments[4][92][0].apply(r,arguments)},{dup:92}],522:[function(t,e,r){arguments[4][520][0].apply(r,arguments)},{\"bit-twiddle\":521,dup:520,\"union-find\":523}],523:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n,n.prototype.length=function(){return this.roots.length},n.prototype.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},n.prototype.find=function(t){for(var e=this.roots;e[t]!==t;){var r=e[t];e[t]=e[r],t=r}return t},n.prototype.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],524:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){for(var a=e.length,o=t.length,s=new Array(a),l=new Array(a),c=new Array(a),u=new Array(a),h=0;h<a;++h)s[h]=l[h]=-1,c[h]=1/0,u[h]=!1;for(var h=0;h<o;++h){var f=t[h];if(2!==f.length)throw new Error(\"Input must be a graph\");var p=f[1],d=f[0];-1!==l[d]?l[d]=-2:l[d]=p,-1!==s[p]?s[p]=-2:s[p]=d}function g(t){if(u[t])return 1/0;var r,i,a,o,c,h=s[t],f=l[t];return h<0||f<0?1/0:(r=e[t],i=e[h],a=e[f],o=Math.abs(n(r,i,a)),c=Math.sqrt(Math.pow(i[0]-a[0],2)+Math.pow(i[1]-a[1],2)),o/c)}function v(t,e){var r=T[t],n=T[e];T[t]=n,T[e]=r,A[r]=e,A[n]=t}function m(t){return c[T[t]]}function y(t){return 1&t?t-1>>1:(t>>1)-1}function x(t){for(var e=m(t);;){var r=e,n=2*t+1,i=2*(t+1),a=t;if(n<S){var o=m(n);o<r&&(a=n,r=o)}if(i<S){var s=m(i);s<r&&(a=i)}if(a===t)return t;v(t,a),t=a}}function b(t){for(var e=m(t);t>0;){var r=y(t);if(r>=0){var n=m(r);if(e<n){v(t,r),t=r;continue}}return t}}function _(){if(S>0){var t=T[0];return v(0,S-1),S-=1,x(0),t}return-1}function w(t,e){var r=T[t];return c[r]===e?t:(c[r]=-1/0,b(t),_(),c[r]=e,b((S+=1)-1))}function k(t){if(!u[t]){u[t]=!0;var e=s[t],r=l[t];s[r]>=0&&(s[r]=e),l[e]>=0&&(l[e]=r),A[e]>=0&&w(A[e],g(e)),A[r]>=0&&w(A[r],g(r))}}for(var T=[],A=new Array(a),h=0;h<a;++h){var M=c[h]=g(h);M<1/0?(A[h]=T.length,T.push(h)):A[h]=-1}for(var S=T.length,h=S>>1;h>=0;--h)x(h);for(;;){var E=_();if(E<0||c[E]>r)break;k(E)}for(var C=[],h=0;h<a;++h)u[h]||(A[h]=C.length,C.push(e[h].slice()));C.length;function L(t,e){if(t[e]<0)return e;var r=e,n=e;do{var i=t[n];if(!u[n]||i<0||i===n)break;if(i=t[n=i],!u[n]||i<0||i===n)break;n=i,r=t[r]}while(r!==n);for(var a=e;a!==n;a=t[a])t[a]=n;return n}var P=[];return t.forEach(function(t){var e=L(s,t[0]),r=L(l,t[1]);if(e>=0&&r>=0&&e!==r){var n=A[e],i=A[r];n!==i&&P.push([n,i])}}),i.unique(i.normalize(P)),{positions:C,edges:P}};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\")},{\"robust-orientation\":510,\"simplicial-complex\":522}],525:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,a,o,s;if(e[0][0]<e[1][0])r=e[0],a=e[1];else{if(!(e[0][0]>e[1][0]))return i(e,t);r=e[1],a=e[0]}if(t[0][0]<t[1][0])o=t[0],s=t[1];else{if(!(t[0][0]>t[1][0]))return-i(t,e);o=t[1],s=t[0]}var l=n(r,a,s),c=n(r,a,o);if(l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;if(l=n(s,o,a),c=n(s,o,r),l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;return a[0]-s[0]};var n=t(\"robust-orientation\");function i(t,e){var r,i,a,o;if(e[0][0]<e[1][0])r=e[0],i=e[1];else{if(!(e[0][0]>e[1][0])){var s=Math.min(t[0][1],t[1][1]),l=Math.max(t[0][1],t[1][1]),c=Math.min(e[0][1],e[1][1]),u=Math.max(e[0][1],e[1][1]);return l<c?l-c:s>u?s-u:l-u}r=e[1],i=e[0]}t[0][1]<t[1][1]?(a=t[0],o=t[1]):(a=t[1],o=t[0]);var h=n(i,r,a);return h||((h=n(i,r,o))||o-i)}},{\"robust-orientation\":510}],526:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=2*e,n=new Array(r),a=0;a<e;++a){var l=t[a],c=l[0][0]<l[1][0];n[2*a]=new h(l[0][0],l,c,a),n[2*a+1]=new h(l[1][0],l,!c,a)}n.sort(function(t,e){var r=t.x-e.x;return r||((r=t.create-e.create)||Math.min(t.segment[0][1],t.segment[1][1])-Math.min(e.segment[0][1],e.segment[1][1]))});for(var f=i(o),p=[],d=[],g=[],a=0;a<r;){for(var v=n[a].x,m=[];a<r;){var y=n[a];if(y.x!==v)break;a+=1,y.segment[0][0]===y.x&&y.segment[1][0]===y.x?y.create&&(y.segment[0][1]<y.segment[1][1]?(m.push(new u(y.segment[0][1],y.index,!0,!0)),m.push(new u(y.segment[1][1],y.index,!1,!1))):(m.push(new u(y.segment[1][1],y.index,!0,!1)),m.push(new u(y.segment[0][1],y.index,!1,!0)))):f=y.create?f.insert(y.segment,y.index):f.remove(y.segment)}p.push(f.root),d.push(v),g.push(m)}return new s(p,d,g)};var n=t(\"binary-search-bounds\"),i=t(\"functional-red-black-tree\"),a=t(\"robust-orientation\"),o=t(\"./lib/order-segments\");function s(t,e,r){this.slabs=t,this.coordinates=e,this.horizontal=r}function l(t,e){return t.y-e}function c(t,e){for(var r=null;t;){var n,i,o=t.key;o[0][0]<o[1][0]?(n=o[0],i=o[1]):(n=o[1],i=o[0]);var s=a(n,i,e);if(s<0)t=t.left;else if(s>0)if(e[0]!==o[1][0])r=t,t=t.right;else{if(l=c(t.right,e))return l;t=t.left}else{if(e[0]!==o[1][0])return t;var l;if(l=c(t.right,e))return l;t=t.left}}return r}function u(t,e,r,n){this.y=t,this.index=e,this.start=r,this.closed=n}function h(t,e,r,n){this.x=t,this.segment=e,this.create=r,this.index=n}s.prototype.castUp=function(t){var e=n.le(this.coordinates,t[0]);if(e<0)return-1;this.slabs[e];var r=c(this.slabs[e],t),i=-1;if(r&&(i=r.value),this.coordinates[e]===t[0]){var s=null;if(r&&(s=r.key),e>0){var u=c(this.slabs[e-1],t);u&&(s?o(u.key,s)>0&&(s=u.key,i=u.value):(i=u.value,s=u.key))}var h=this.horizontal[e];if(h.length>0){var f=n.ge(h,t[1],l);if(f<h.length){var p=h[f];if(t[1]===p.y){if(p.closed)return p.index;for(;f<h.length-1&&h[f+1].y===t[1];)if((p=h[f+=1]).closed)return p.index;if(p.y===t[1]&&!p.start){if((f+=1)>=h.length)return i;p=h[f]}}if(p.start)if(s){var d=a(s[0],s[1],[t[0],p.y]);s[0][0]>s[1][0]&&(d=-d),d>0&&(i=p.index)}else i=p.index;else p.y!==t[1]&&(i=p.index)}}}return i}},{\"./lib/order-segments\":525,\"binary-search-bounds\":91,\"functional-red-black-tree\":230,\"robust-orientation\":510}],527:[function(t,e,r){\"use strict\";var n=t(\"robust-dot-product\"),i=t(\"robust-sum\");function a(t,e){var r=i(n(t,e),[e[e.length-1]]);return r[r.length-1]}function o(t,e,r,n){var i=-e/(n-e);i<0?i=0:i>1&&(i=1);for(var a=1-i,o=t.length,s=new Array(o),l=0;l<o;++l)s[l]=i*t[l]+a*r[l];return s}e.exports=function(t,e){for(var r=[],n=[],i=a(t[t.length-1],e),s=t[t.length-1],l=t[0],c=0;c<t.length;++c,s=l){var u=a(l=t[c],e);if(i<0&&u>0||i>0&&u<0){var h=o(s,u,l,i);r.push(h),n.push(h.slice())}u<0?n.push(l.slice()):u>0?r.push(l.slice()):(r.push(l.slice()),n.push(l.slice())),i=u}return{positive:r,negative:n}},e.exports.positive=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c>=0&&r.push(s.slice()),n=c}return r},e.exports.negative=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c<=0&&r.push(s.slice()),n=c}return r}},{\"robust-dot-product\":507,\"robust-sum\":515}],528:[function(t,e,r){!function(){\"use strict\";var t={not_string:/[^s]/,not_bool:/[^t]/,not_type:/[^T]/,not_primitive:/[^v]/,number:/[diefg]/,numeric_arg:/[bcdiefguxX]/,json:/[j]/,not_json:/[^j]/,text:/^[^\\x25]+/,modulo:/^\\x25{2}/,placeholder:/^\\x25(?:([1-9]\\d*)\\$|\\(([^)]+)\\))?(\\+)?(0|'[^$])?(-)?(\\d+)?(?:\\.(\\d+))?([b-gijostTuvxX])/,key:/^([a-z_][a-z_\\d]*)/i,key_access:/^\\.([a-z_][a-z_\\d]*)/i,index_access:/^\\[(\\d+)\\]/,sign:/^[+-]/};function e(r){return function(r,n){var i,a,o,s,l,c,u,h,f,p=1,d=r.length,g=\"\";for(a=0;a<d;a++)if(\"string\"==typeof r[a])g+=r[a];else if(\"object\"==typeof r[a]){if((s=r[a]).keys)for(i=n[p],o=0;o<s.keys.length;o++){if(null==i)throw new Error(e('[sprintf] Cannot access property \"%s\" of undefined value \"%s\"',s.keys[o],s.keys[o-1]));i=i[s.keys[o]]}else i=s.param_no?n[s.param_no]:n[p++];if(t.not_type.test(s.type)&&t.not_primitive.test(s.type)&&i instanceof Function&&(i=i()),t.numeric_arg.test(s.type)&&\"number\"!=typeof i&&isNaN(i))throw new TypeError(e(\"[sprintf] expecting number but found %T\",i));switch(t.number.test(s.type)&&(h=i>=0),s.type){case\"b\":i=parseInt(i,10).toString(2);break;case\"c\":i=String.fromCharCode(parseInt(i,10));break;case\"d\":case\"i\":i=parseInt(i,10);break;case\"j\":i=JSON.stringify(i,null,s.width?parseInt(s.width):0);break;case\"e\":i=s.precision?parseFloat(i).toExponential(s.precision):parseFloat(i).toExponential();break;case\"f\":i=s.precision?parseFloat(i).toFixed(s.precision):parseFloat(i);break;case\"g\":i=s.precision?String(Number(i.toPrecision(s.precision))):parseFloat(i);break;case\"o\":i=(parseInt(i,10)>>>0).toString(8);break;case\"s\":i=String(i),i=s.precision?i.substring(0,s.precision):i;break;case\"t\":i=String(!!i),i=s.precision?i.substring(0,s.precision):i;break;case\"T\":i=Object.prototype.toString.call(i).slice(8,-1).toLowerCase(),i=s.precision?i.substring(0,s.precision):i;break;case\"u\":i=parseInt(i,10)>>>0;break;case\"v\":i=i.valueOf(),i=s.precision?i.substring(0,s.precision):i;break;case\"x\":i=(parseInt(i,10)>>>0).toString(16);break;case\"X\":i=(parseInt(i,10)>>>0).toString(16).toUpperCase()}t.json.test(s.type)?g+=i:(!t.number.test(s.type)||h&&!s.sign?f=\"\":(f=h?\"+\":\"-\",i=i.toString().replace(t.sign,\"\")),c=s.pad_char?\"0\"===s.pad_char?\"0\":s.pad_char.charAt(1):\" \",u=s.width-(f+i).length,l=s.width&&u>0?c.repeat(u):\"\",g+=s.align?f+i+l:\"0\"===c?f+l+i:l+f+i)}return g}(function(e){if(i[e])return i[e];var r,n=e,a=[],o=0;for(;n;){if(null!==(r=t.text.exec(n)))a.push(r[0]);else if(null!==(r=t.modulo.exec(n)))a.push(\"%\");else{if(null===(r=t.placeholder.exec(n)))throw new SyntaxError(\"[sprintf] unexpected placeholder\");if(r[2]){o|=1;var s=[],l=r[2],c=[];if(null===(c=t.key.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");for(s.push(c[1]);\"\"!==(l=l.substring(c[0].length));)if(null!==(c=t.key_access.exec(l)))s.push(c[1]);else{if(null===(c=t.index_access.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");s.push(c[1])}r[2]=s}else o|=2;if(3===o)throw new Error(\"[sprintf] mixing positional and named placeholders is not (yet) supported\");a.push({placeholder:r[0],param_no:r[1],keys:r[2],sign:r[3],pad_char:r[4],align:r[5],width:r[6],precision:r[7],type:r[8]})}n=n.substring(r[0].length)}return i[e]=a}(r),arguments)}function n(t,r){return e.apply(null,[t].concat(r||[]))}var i=Object.create(null);\"undefined\"!=typeof r&&(r.sprintf=e,r.vsprintf=n),\"undefined\"!=typeof window&&(window.sprintf=e,window.vsprintf=n)}()},{}],529:[function(t,e,r){\"use strict\";var n=t(\"parenthesis\");e.exports=function(t,e,r){if(null==t)throw Error(\"First argument should be a string\");if(null==e)throw Error(\"Separator should be a string or a RegExp\");r?(\"string\"==typeof r||Array.isArray(r))&&(r={ignore:r}):r={},null==r.escape&&(r.escape=!0),null==r.ignore?r.ignore=[\"[]\",\"()\",\"{}\",\"<>\",'\"\"',\"''\",\"``\",\"\\u201c\\u201d\",\"\\xab\\xbb\"]:(\"string\"==typeof r.ignore&&(r.ignore=[r.ignore]),r.ignore=r.ignore.map(function(t){return 1===t.length&&(t+=t),t}));var i=n.parse(t,{flat:!0,brackets:r.ignore}),a=i[0].split(e);if(r.escape){for(var o=[],s=0;s<a.length;s++){var l=a[s],c=a[s+1];\"\\\\\"===l[l.length-1]&&\"\\\\\"!==l[l.length-2]?(o.push(l+e+c),s++):o.push(l)}a=o}for(s=0;s<a.length;s++)i[0]=a[s],a[s]=n.stringify(i,{flat:!0});return a}},{parenthesis:458}],530:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=new Array(e),n=new Array(e),i=new Array(e),a=new Array(e),o=new Array(e),s=new Array(e),l=0;l<e;++l)r[l]=-1,n[l]=0,i[l]=!1,a[l]=0,o[l]=-1,s[l]=[];var c,u=0,h=[],f=[];function p(e){var l=[e],c=[e];for(r[e]=n[e]=u,i[e]=!0,u+=1;c.length>0;){e=c[c.length-1];var p=t[e];if(a[e]<p.length){for(var d=a[e];d<p.length;++d){var g=p[d];if(r[g]<0){r[g]=n[g]=u,i[g]=!0,u+=1,l.push(g),c.push(g);break}i[g]&&(n[e]=0|Math.min(n[e],n[g])),o[g]>=0&&s[e].push(o[g])}a[e]=d}else{if(n[e]===r[e]){for(var v=[],m=[],y=0,d=l.length-1;d>=0;--d){var x=l[d];if(i[x]=!1,v.push(x),m.push(s[x]),y+=s[x].length,o[x]=h.length,x===e){l.length=d;break}}h.push(v);for(var b=new Array(y),d=0;d<m.length;d++)for(var _=0;_<m[d].length;_++)b[--y]=m[d][_];f.push(b)}c.pop()}}}for(var l=0;l<e;++l)r[l]<0&&p(l);for(var l=0;l<f.length;l++){var d=f[l];if(0!==d.length){d.sort(function(t,e){return t-e}),c=[d[0]];for(var g=1;g<d.length;g++)d[g]!==d[g-1]&&c.push(d[g]);f[l]=c}}return{components:h,adjacencyList:f}}},{}],531:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(t.dimension<=0)return{positions:[],cells:[]};if(1===t.dimension)return function(t,e){for(var r=a(t,e),n=r.length,i=new Array(n),o=new Array(n),s=0;s<n;++s)i[s]=[r[s]],o[s]=[s];return{positions:i,cells:o}}(t,e);var r=t.order.join()+\"-\"+t.dtype,s=o[r],e=+e||0;s||(s=o[r]=function(t,e){var r=t.length,a=[\"'use strict';\"],o=\"surfaceNets\"+t.join(\"_\")+\"d\"+e;a.push(\"var contour=genContour({\",\"order:[\",t.join(),\"],\",\"scalarArguments: 3,\",\"phase:function phaseFunc(p,a,b,c) { return (p > c)|0 },\"),\"generic\"===e&&a.push(\"getters:[0],\");for(var s=[],l=[],c=0;c<r;++c)s.push(\"d\"+c),l.push(\"d\"+c);for(var c=0;c<1<<r;++c)s.push(\"v\"+c),l.push(\"v\"+c);for(var c=0;c<1<<r;++c)s.push(\"p\"+c),l.push(\"p\"+c);s.push(\"a\",\"b\",\"c\"),l.push(\"a\",\"c\"),a.push(\"vertex:function vertexFunc(\",s.join(),\"){\");for(var u=[],c=0;c<1<<r;++c)u.push(\"(p\"+c+\"<<\"+c+\")\");a.push(\"var m=(\",u.join(\"+\"),\")|0;if(m===0||m===\",(1<<(1<<r))-1,\"){return}\");var h=[],f=[];1<<(1<<r)<=128?(a.push(\"switch(m){\"),f=a):a.push(\"switch(m>>>7){\");for(var c=0;c<1<<(1<<r);++c){if(1<<(1<<r)>128&&c%128==0){h.length>0&&f.push(\"}}\");var p=\"vExtra\"+h.length;a.push(\"case \",c>>>7,\":\",p,\"(m&0x7f,\",l.join(),\");break;\"),f=[\"function \",p,\"(m,\",l.join(),\"){switch(m){\"],h.push(f)}f.push(\"case \",127&c,\":\");for(var d=new Array(r),g=new Array(r),v=new Array(r),m=new Array(r),y=0,x=0;x<r;++x)d[x]=[],g[x]=[],v[x]=0,m[x]=0;for(var x=0;x<1<<r;++x)for(var b=0;b<r;++b){var _=x^1<<b;if(!(_>x)&&!(c&1<<_)!=!(c&1<<x)){var w=1;c&1<<_?g[b].push(\"v\"+_+\"-v\"+x):(g[b].push(\"v\"+x+\"-v\"+_),w=-w),w<0?(d[b].push(\"-v\"+x+\"-v\"+_),v[b]+=2):(d[b].push(\"v\"+x+\"+v\"+_),v[b]-=2),y+=1;for(var k=0;k<r;++k)k!==b&&(_&1<<k?m[k]+=1:m[k]-=1)}}for(var T=[],b=0;b<r;++b)if(0===d[b].length)T.push(\"d\"+b+\"-0.5\");else{var A=\"\";v[b]<0?A=v[b]+\"*c\":v[b]>0&&(A=\"+\"+v[b]+\"*c\");var M=d[b].length/y*.5,S=.5+m[b]/y*.5;T.push(\"d\"+b+\"-\"+S+\"-\"+M+\"*(\"+d[b].join(\"+\")+A+\")/(\"+g[b].join(\"+\")+\")\")}f.push(\"a.push([\",T.join(),\"]);\",\"break;\")}a.push(\"}},\"),h.length>0&&f.push(\"}}\");for(var E=[],c=0;c<1<<r-1;++c)E.push(\"v\"+c);E.push(\"c0\",\"c1\",\"p0\",\"p1\",\"a\",\"b\",\"c\"),a.push(\"cell:function cellFunc(\",E.join(),\"){\");var C=i(r-1);a.push(\"if(p0){b.push(\",C.map(function(t){return\"[\"+t.map(function(t){return\"v\"+t})+\"]\"}).join(),\")}else{b.push(\",C.map(function(t){var e=t.slice();return e.reverse(),\"[\"+e.map(function(t){return\"v\"+t})+\"]\"}).join(),\")}}});function \",o,\"(array,level){var verts=[],cells=[];contour(array,verts,cells,level);return {positions:verts,cells:cells};} return \",o,\";\");for(var c=0;c<h.length;++c)a.push(h[c].join(\"\"));return new Function(\"genContour\",a.join(\"\"))(n)}(t.order,t.dtype));return s(t,e)};var n=t(\"ndarray-extract-contour\"),i=t(\"triangulate-hypercube\"),a=t(\"zero-crossings\");var o={}},{\"ndarray-extract-contour\":439,\"triangulate-hypercube\":541,\"zero-crossings\":574}],532:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=function(){return function(t,e){if(Array.isArray(t))return t;if(Symbol.iterator in Object(t))return function(t,e){var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{!n&&s.return&&s.return()}finally{if(i)throw a}}return r}(t,e);throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")}}(),i=2*Math.PI,a=function(t,e,r,n,i,a,o){var s=t.x,l=t.y;return{x:n*(s*=e)-i*(l*=r)+a,y:i*s+n*l+o}},o=function(t,e){var r=.551915024494*(e<0?-1:1),n=Math.cos(t),i=Math.sin(t),a=Math.cos(t+e),o=Math.sin(t+e);return[{x:n-i*r,y:i+n*r},{x:a+o*r,y:o-a*r},{x:a,y:o}]},s=function(t,e,r,n){var i=t*n-e*r<0?-1:1,a=(t*r+e*n)/(Math.sqrt(t*t+e*e)*Math.sqrt(t*t+e*e));return a>1&&(a=1),a<-1&&(a=-1),i*Math.acos(a)};r.default=function(t){var e=t.px,r=t.py,l=t.cx,c=t.cy,u=t.rx,h=t.ry,f=t.xAxisRotation,p=void 0===f?0:f,d=t.largeArcFlag,g=void 0===d?0:d,v=t.sweepFlag,m=void 0===v?0:v,y=[];if(0===u||0===h)return[];var x=Math.sin(p*i/360),b=Math.cos(p*i/360),_=b*(e-l)/2+x*(r-c)/2,w=-x*(e-l)/2+b*(r-c)/2;if(0===_&&0===w)return[];u=Math.abs(u),h=Math.abs(h);var k=Math.pow(_,2)/Math.pow(u,2)+Math.pow(w,2)/Math.pow(h,2);k>1&&(u*=Math.sqrt(k),h*=Math.sqrt(k));var T=function(t,e,r,n,a,o,l,c,u,h,f,p){var d=Math.pow(a,2),g=Math.pow(o,2),v=Math.pow(f,2),m=Math.pow(p,2),y=d*g-d*m-g*v;y<0&&(y=0),y/=d*m+g*v;var x=(y=Math.sqrt(y)*(l===c?-1:1))*a/o*p,b=y*-o/a*f,_=h*x-u*b+(t+r)/2,w=u*x+h*b+(e+n)/2,k=(f-x)/a,T=(p-b)/o,A=(-f-x)/a,M=(-p-b)/o,S=s(1,0,k,T),E=s(k,T,A,M);return 0===c&&E>0&&(E-=i),1===c&&E<0&&(E+=i),[_,w,S,E]}(e,r,l,c,u,h,g,m,x,b,_,w),A=n(T,4),M=A[0],S=A[1],E=A[2],C=A[3],L=Math.abs(C)/(i/4);Math.abs(1-L)<1e-7&&(L=1);var P=Math.max(Math.ceil(L),1);C/=P;for(var O=0;O<P;O++)y.push(o(E,C)),E+=C;return y.map(function(t){var e=a(t[0],u,h,b,x,M,S),r=e.x,n=e.y,i=a(t[1],u,h,b,x,M,S),o=i.x,s=i.y,l=a(t[2],u,h,b,x,M,S);return{x1:r,y1:n,x2:o,y2:s,x:l.x,y:l.y}})},e.exports=r.default},{}],533:[function(t,e,r){\"use strict\";var n=t(\"parse-svg-path\"),i=t(\"abs-svg-path\"),a=t(\"normalize-svg-path\"),o=t(\"is-svg-path\"),s=t(\"assert\");e.exports=function(t){Array.isArray(t)&&1===t.length&&\"string\"==typeof t[0]&&(t=t[0]);\"string\"==typeof t&&(s(o(t),\"String is not an SVG path.\"),t=n(t));if(s(Array.isArray(t),\"Argument should be a string or an array of path segments.\"),t=i(t),!(t=a(t)).length)return[0,0,0,0];for(var e=[1/0,1/0,-1/0,-1/0],r=0,l=t.length;r<l;r++)for(var c=t[r].slice(1),u=0;u<c.length;u+=2)c[u+0]<e[0]&&(e[0]=c[u+0]),c[u+1]<e[1]&&(e[1]=c[u+1]),c[u+0]>e[2]&&(e[2]=c[u+0]),c[u+1]>e[3]&&(e[3]=c[u+1]);return e}},{\"abs-svg-path\":60,assert:68,\"is-svg-path\":424,\"normalize-svg-path\":534,\"parse-svg-path\":460}],534:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=[],o=0,s=0,l=0,c=0,u=null,h=null,f=0,p=0,d=0,g=t.length;d<g;d++){var v=t[d],m=v[0];switch(m){case\"M\":l=v[1],c=v[2];break;case\"A\":var y=n({px:f,py:p,cx:v[6],cy:v[7],rx:v[1],ry:v[2],xAxisRotation:v[3],largeArcFlag:v[4],sweepFlag:v[5]});if(!y.length)continue;for(var x,b=0;b<y.length;b++)x=y[b],v=[\"C\",x.x1,x.y1,x.x2,x.y2,x.x,x.y],b<y.length-1&&r.push(v);break;case\"S\":var _=f,w=p;\"C\"!=e&&\"S\"!=e||(_+=_-o,w+=w-s),v=[\"C\",_,w,v[1],v[2],v[3],v[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(u=2*f-u,h=2*p-h):(u=f,h=p),v=a(f,p,u,h,v[1],v[2]);break;case\"Q\":u=v[1],h=v[2],v=a(f,p,v[1],v[2],v[3],v[4]);break;case\"L\":v=i(f,p,v[1],v[2]);break;case\"H\":v=i(f,p,v[1],p);break;case\"V\":v=i(f,p,f,v[1]);break;case\"Z\":v=i(f,p,l,c)}e=m,f=v[v.length-2],p=v[v.length-1],v.length>4?(o=v[v.length-4],s=v[v.length-3]):(o=f,s=p),r.push(v)}return r};var n=t(\"svg-arc-to-cubic-bezier\");function i(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function a(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}},{\"svg-arc-to-cubic-bezier\":532}],535:[function(t,e,r){\"use strict\";var n,i=t(\"svg-path-bounds\"),a=t(\"parse-svg-path\"),o=t(\"draw-svg-path\"),s=t(\"is-svg-path\"),l=t(\"bitmap-sdf\"),c=document.createElement(\"canvas\"),u=c.getContext(\"2d\");e.exports=function(t,e){if(!s(t))throw Error(\"Argument should be valid svg path string\");e||(e={});var r,h;e.shape?(r=e.shape[0],h=e.shape[1]):(r=c.width=e.w||e.width||200,h=c.height=e.h||e.height||200);var f=Math.min(r,h),p=e.stroke||0,d=e.viewbox||e.viewBox||i(t),g=[r/(d[2]-d[0]),h/(d[3]-d[1])],v=Math.min(g[0]||0,g[1]||0)/2;u.fillStyle=\"black\",u.fillRect(0,0,r,h),u.fillStyle=\"white\",p&&(\"number\"!=typeof p&&(p=1),u.strokeStyle=p>0?\"white\":\"black\",u.lineWidth=Math.abs(p));if(u.translate(.5*r,.5*h),u.scale(v,v),function(){if(null!=n)return n;var t=document.createElement(\"canvas\").getContext(\"2d\");if(t.canvas.width=t.canvas.height=1,!window.Path2D)return n=!1;var e=new Path2D(\"M0,0h1v1h-1v-1Z\");t.fillStyle=\"black\",t.fill(e);var r=t.getImageData(0,0,1,1);return n=r&&r.data&&255===r.data[3]}()){var m=new Path2D(t);u.fill(m),p&&u.stroke(m)}else{var y=a(t);o(u,y),u.fill(),p&&u.stroke()}return u.setTransform(1,0,0,1,0,0),l(u,{cutoff:null!=e.cutoff?e.cutoff:.5,radius:null!=e.radius?e.radius:.5*f})}},{\"bitmap-sdf\":93,\"draw-svg-path\":168,\"is-svg-path\":424,\"parse-svg-path\":460,\"svg-path-bounds\":533}],536:[function(t,e,r){(function(r){\"use strict\";e.exports=function t(e,r,i){var i=i||{};var o=a[e];o||(o=a[e]={\" \":{data:new Float32Array(0),shape:.2}});var s=o[r];if(!s)if(r.length<=1||!/\\d/.test(r))s=o[r]=function(t){for(var e=t.cells,r=t.positions,n=new Float32Array(6*e.length),i=0,a=0,o=0;o<e.length;++o)for(var s=e[o],l=0;l<3;++l){var c=r[s[l]];n[i++]=c[0],n[i++]=c[1]+1.4,a=Math.max(c[0],a)}return{data:n,shape:a}}(n(r,{triangles:!0,font:e,textAlign:i.textAlign||\"left\",textBaseline:\"alphabetic\",styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0}}));else{for(var l=r.split(/(\\d|\\s)/),c=new Array(l.length),u=0,h=0,f=0;f<l.length;++f)c[f]=t(e,l[f]),u+=c[f].data.length,h+=c[f].shape,f>0&&(h+=.02);for(var p=new Float32Array(u),d=0,g=-.5*h,f=0;f<c.length;++f){for(var v=c[f].data,m=0;m<v.length;m+=2)p[d++]=v[m]+g,p[d++]=v[m+1];g+=c[f].shape+.02}s=o[r]={data:p,shape:h}}return s};var n=t(\"vectorize-text\"),i=window||r.global||{},a=i.__TEXT_CACHE||{};i.__TEXT_CACHE={}}).call(this,t(\"_process\"))},{_process:482,\"vectorize-text\":550}],537:[function(t,e,r){!function(t){var r=/^\\s+/,n=/\\s+$/,i=0,a=t.round,o=t.min,s=t.max,l=t.random;function c(e,l){if(l=l||{},(e=e||\"\")instanceof c)return e;if(!(this instanceof c))return new c(e,l);var u=function(e){var i={r:0,g:0,b:0},a=1,l=null,c=null,u=null,h=!1,f=!1;\"string\"==typeof e&&(e=function(t){t=t.replace(r,\"\").replace(n,\"\").toLowerCase();var e,i=!1;if(S[t])t=S[t],i=!0;else if(\"transparent\"==t)return{r:0,g:0,b:0,a:0,format:\"name\"};if(e=j.rgb.exec(t))return{r:e[1],g:e[2],b:e[3]};if(e=j.rgba.exec(t))return{r:e[1],g:e[2],b:e[3],a:e[4]};if(e=j.hsl.exec(t))return{h:e[1],s:e[2],l:e[3]};if(e=j.hsla.exec(t))return{h:e[1],s:e[2],l:e[3],a:e[4]};if(e=j.hsv.exec(t))return{h:e[1],s:e[2],v:e[3]};if(e=j.hsva.exec(t))return{h:e[1],s:e[2],v:e[3],a:e[4]};if(e=j.hex8.exec(t))return{r:O(e[1]),g:O(e[2]),b:O(e[3]),a:R(e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex6.exec(t))return{r:O(e[1]),g:O(e[2]),b:O(e[3]),format:i?\"name\":\"hex\"};if(e=j.hex4.exec(t))return{r:O(e[1]+\"\"+e[1]),g:O(e[2]+\"\"+e[2]),b:O(e[3]+\"\"+e[3]),a:R(e[4]+\"\"+e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex3.exec(t))return{r:O(e[1]+\"\"+e[1]),g:O(e[2]+\"\"+e[2]),b:O(e[3]+\"\"+e[3]),format:i?\"name\":\"hex\"};return!1}(e));\"object\"==typeof e&&(U(e.r)&&U(e.g)&&U(e.b)?(p=e.r,d=e.g,g=e.b,i={r:255*L(p,255),g:255*L(d,255),b:255*L(g,255)},h=!0,f=\"%\"===String(e.r).substr(-1)?\"prgb\":\"rgb\"):U(e.h)&&U(e.s)&&U(e.v)?(l=I(e.s),c=I(e.v),i=function(e,r,n){e=6*L(e,360),r=L(r,100),n=L(n,100);var i=t.floor(e),a=e-i,o=n*(1-r),s=n*(1-a*r),l=n*(1-(1-a)*r),c=i%6;return{r:255*[n,s,o,o,l,n][c],g:255*[l,n,n,s,o,o][c],b:255*[o,o,l,n,n,s][c]}}(e.h,l,c),h=!0,f=\"hsv\"):U(e.h)&&U(e.s)&&U(e.l)&&(l=I(e.s),u=I(e.l),i=function(t,e,r){var n,i,a;function o(t,e,r){return r<0&&(r+=1),r>1&&(r-=1),r<1/6?t+6*(e-t)*r:r<.5?e:r<2/3?t+(e-t)*(2/3-r)*6:t}if(t=L(t,360),e=L(e,100),r=L(r,100),0===e)n=i=a=r;else{var s=r<.5?r*(1+e):r+e-r*e,l=2*r-s;n=o(l,s,t+1/3),i=o(l,s,t),a=o(l,s,t-1/3)}return{r:255*n,g:255*i,b:255*a}}(e.h,l,u),h=!0,f=\"hsl\"),e.hasOwnProperty(\"a\")&&(a=e.a));var p,d,g;return a=C(a),{ok:h,format:e.format||f,r:o(255,s(i.r,0)),g:o(255,s(i.g,0)),b:o(255,s(i.b,0)),a:a}}(e);this._originalInput=e,this._r=u.r,this._g=u.g,this._b=u.b,this._a=u.a,this._roundA=a(100*this._a)/100,this._format=l.format||u.format,this._gradientType=l.gradientType,this._r<1&&(this._r=a(this._r)),this._g<1&&(this._g=a(this._g)),this._b<1&&(this._b=a(this._b)),this._ok=u.ok,this._tc_id=i++}function u(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=(a+l)/2;if(a==l)n=i=0;else{var u=a-l;switch(i=c>.5?u/(2-a-l):u/(a+l),a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,l:c}}function h(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=a,u=a-l;if(i=0===a?0:u/a,a==l)n=0;else{switch(a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,v:c}}function f(t,e,r,n){var i=[z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16))];return n&&i[0].charAt(0)==i[0].charAt(1)&&i[1].charAt(0)==i[1].charAt(1)&&i[2].charAt(0)==i[2].charAt(1)?i[0].charAt(0)+i[1].charAt(0)+i[2].charAt(0):i.join(\"\")}function p(t,e,r,n){return[z(D(n)),z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16))].join(\"\")}function d(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s-=e/100,r.s=P(r.s),c(r)}function g(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s+=e/100,r.s=P(r.s),c(r)}function v(t){return c(t).desaturate(100)}function m(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l+=e/100,r.l=P(r.l),c(r)}function y(t,e){e=0===e?0:e||10;var r=c(t).toRgb();return r.r=s(0,o(255,r.r-a(-e/100*255))),r.g=s(0,o(255,r.g-a(-e/100*255))),r.b=s(0,o(255,r.b-a(-e/100*255))),c(r)}function x(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l-=e/100,r.l=P(r.l),c(r)}function b(t,e){var r=c(t).toHsl(),n=(r.h+e)%360;return r.h=n<0?360+n:n,c(r)}function _(t){var e=c(t).toHsl();return e.h=(e.h+180)%360,c(e)}function w(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+120)%360,s:e.s,l:e.l}),c({h:(r+240)%360,s:e.s,l:e.l})]}function k(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+90)%360,s:e.s,l:e.l}),c({h:(r+180)%360,s:e.s,l:e.l}),c({h:(r+270)%360,s:e.s,l:e.l})]}function T(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+72)%360,s:e.s,l:e.l}),c({h:(r+216)%360,s:e.s,l:e.l})]}function A(t,e,r){e=e||6,r=r||30;var n=c(t).toHsl(),i=360/r,a=[c(t)];for(n.h=(n.h-(i*e>>1)+720)%360;--e;)n.h=(n.h+i)%360,a.push(c(n));return a}function M(t,e){e=e||6;for(var r=c(t).toHsv(),n=r.h,i=r.s,a=r.v,o=[],s=1/e;e--;)o.push(c({h:n,s:i,v:a})),a=(a+s)%1;return o}c.prototype={isDark:function(){return this.getBrightness()<128},isLight:function(){return!this.isDark()},isValid:function(){return this._ok},getOriginalInput:function(){return this._originalInput},getFormat:function(){return this._format},getAlpha:function(){return this._a},getBrightness:function(){var t=this.toRgb();return(299*t.r+587*t.g+114*t.b)/1e3},getLuminance:function(){var e,r,n,i=this.toRgb();return e=i.r/255,r=i.g/255,n=i.b/255,.2126*(e<=.03928?e/12.92:t.pow((e+.055)/1.055,2.4))+.7152*(r<=.03928?r/12.92:t.pow((r+.055)/1.055,2.4))+.0722*(n<=.03928?n/12.92:t.pow((n+.055)/1.055,2.4))},setAlpha:function(t){return this._a=C(t),this._roundA=a(100*this._a)/100,this},toHsv:function(){var t=h(this._r,this._g,this._b);return{h:360*t.h,s:t.s,v:t.v,a:this._a}},toHsvString:function(){var t=h(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.v);return 1==this._a?\"hsv(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsva(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHsl:function(){var t=u(this._r,this._g,this._b);return{h:360*t.h,s:t.s,l:t.l,a:this._a}},toHslString:function(){var t=u(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.l);return 1==this._a?\"hsl(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsla(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHex:function(t){return f(this._r,this._g,this._b,t)},toHexString:function(t){return\"#\"+this.toHex(t)},toHex8:function(t){return function(t,e,r,n,i){var o=[z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16)),z(D(n))];if(i&&o[0].charAt(0)==o[0].charAt(1)&&o[1].charAt(0)==o[1].charAt(1)&&o[2].charAt(0)==o[2].charAt(1)&&o[3].charAt(0)==o[3].charAt(1))return o[0].charAt(0)+o[1].charAt(0)+o[2].charAt(0)+o[3].charAt(0);return o.join(\"\")}(this._r,this._g,this._b,this._a,t)},toHex8String:function(t){return\"#\"+this.toHex8(t)},toRgb:function(){return{r:a(this._r),g:a(this._g),b:a(this._b),a:this._a}},toRgbString:function(){return 1==this._a?\"rgb(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\")\":\"rgba(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\", \"+this._roundA+\")\"},toPercentageRgb:function(){return{r:a(100*L(this._r,255))+\"%\",g:a(100*L(this._g,255))+\"%\",b:a(100*L(this._b,255))+\"%\",a:this._a}},toPercentageRgbString:function(){return 1==this._a?\"rgb(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%)\":\"rgba(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%, \"+this._roundA+\")\"},toName:function(){return 0===this._a?\"transparent\":!(this._a<1)&&(E[f(this._r,this._g,this._b,!0)]||!1)},toFilter:function(t){var e=\"#\"+p(this._r,this._g,this._b,this._a),r=e,n=this._gradientType?\"GradientType = 1, \":\"\";if(t){var i=c(t);r=\"#\"+p(i._r,i._g,i._b,i._a)}return\"progid:DXImageTransform.Microsoft.gradient(\"+n+\"startColorstr=\"+e+\",endColorstr=\"+r+\")\"},toString:function(t){var e=!!t;t=t||this._format;var r=!1,n=this._a<1&&this._a>=0;return e||!n||\"hex\"!==t&&\"hex6\"!==t&&\"hex3\"!==t&&\"hex4\"!==t&&\"hex8\"!==t&&\"name\"!==t?(\"rgb\"===t&&(r=this.toRgbString()),\"prgb\"===t&&(r=this.toPercentageRgbString()),\"hex\"!==t&&\"hex6\"!==t||(r=this.toHexString()),\"hex3\"===t&&(r=this.toHexString(!0)),\"hex4\"===t&&(r=this.toHex8String(!0)),\"hex8\"===t&&(r=this.toHex8String()),\"name\"===t&&(r=this.toName()),\"hsl\"===t&&(r=this.toHslString()),\"hsv\"===t&&(r=this.toHsvString()),r||this.toHexString()):\"name\"===t&&0===this._a?this.toName():this.toRgbString()},clone:function(){return c(this.toString())},_applyModification:function(t,e){var r=t.apply(null,[this].concat([].slice.call(e)));return this._r=r._r,this._g=r._g,this._b=r._b,this.setAlpha(r._a),this},lighten:function(){return this._applyModification(m,arguments)},brighten:function(){return this._applyModification(y,arguments)},darken:function(){return this._applyModification(x,arguments)},desaturate:function(){return this._applyModification(d,arguments)},saturate:function(){return this._applyModification(g,arguments)},greyscale:function(){return this._applyModification(v,arguments)},spin:function(){return this._applyModification(b,arguments)},_applyCombination:function(t,e){return t.apply(null,[this].concat([].slice.call(e)))},analogous:function(){return this._applyCombination(A,arguments)},complement:function(){return this._applyCombination(_,arguments)},monochromatic:function(){return this._applyCombination(M,arguments)},splitcomplement:function(){return this._applyCombination(T,arguments)},triad:function(){return this._applyCombination(w,arguments)},tetrad:function(){return this._applyCombination(k,arguments)}},c.fromRatio=function(t,e){if(\"object\"==typeof t){var r={};for(var n in t)t.hasOwnProperty(n)&&(r[n]=\"a\"===n?t[n]:I(t[n]));t=r}return c(t,e)},c.equals=function(t,e){return!(!t||!e)&&c(t).toRgbString()==c(e).toRgbString()},c.random=function(){return c.fromRatio({r:l(),g:l(),b:l()})},c.mix=function(t,e,r){r=0===r?0:r||50;var n=c(t).toRgb(),i=c(e).toRgb(),a=r/100;return c({r:(i.r-n.r)*a+n.r,g:(i.g-n.g)*a+n.g,b:(i.b-n.b)*a+n.b,a:(i.a-n.a)*a+n.a})},c.readability=function(e,r){var n=c(e),i=c(r);return(t.max(n.getLuminance(),i.getLuminance())+.05)/(t.min(n.getLuminance(),i.getLuminance())+.05)},c.isReadable=function(t,e,r){var n,i,a=c.readability(t,e);switch(i=!1,(n=function(t){var e,r;e=((t=t||{level:\"AA\",size:\"small\"}).level||\"AA\").toUpperCase(),r=(t.size||\"small\").toLowerCase(),\"AA\"!==e&&\"AAA\"!==e&&(e=\"AA\");\"small\"!==r&&\"large\"!==r&&(r=\"small\");return{level:e,size:r}}(r)).level+n.size){case\"AAsmall\":case\"AAAlarge\":i=a>=4.5;break;case\"AAlarge\":i=a>=3;break;case\"AAAsmall\":i=a>=7}return i},c.mostReadable=function(t,e,r){var n,i,a,o,s=null,l=0;i=(r=r||{}).includeFallbackColors,a=r.level,o=r.size;for(var u=0;u<e.length;u++)(n=c.readability(t,e[u]))>l&&(l=n,s=c(e[u]));return c.isReadable(t,s,{level:a,size:o})||!i?s:(r.includeFallbackColors=!1,c.mostReadable(t,[\"#fff\",\"#000\"],r))};var S=c.names={aliceblue:\"f0f8ff\",antiquewhite:\"faebd7\",aqua:\"0ff\",aquamarine:\"7fffd4\",azure:\"f0ffff\",beige:\"f5f5dc\",bisque:\"ffe4c4\",black:\"000\",blanchedalmond:\"ffebcd\",blue:\"00f\",blueviolet:\"8a2be2\",brown:\"a52a2a\",burlywood:\"deb887\",burntsienna:\"ea7e5d\",cadetblue:\"5f9ea0\",chartreuse:\"7fff00\",chocolate:\"d2691e\",coral:\"ff7f50\",cornflowerblue:\"6495ed\",cornsilk:\"fff8dc\",crimson:\"dc143c\",cyan:\"0ff\",darkblue:\"00008b\",darkcyan:\"008b8b\",darkgoldenrod:\"b8860b\",darkgray:\"a9a9a9\",darkgreen:\"006400\",darkgrey:\"a9a9a9\",darkkhaki:\"bdb76b\",darkmagenta:\"8b008b\",darkolivegreen:\"556b2f\",darkorange:\"ff8c00\",darkorchid:\"9932cc\",darkred:\"8b0000\",darksalmon:\"e9967a\",darkseagreen:\"8fbc8f\",darkslateblue:\"483d8b\",darkslategray:\"2f4f4f\",darkslategrey:\"2f4f4f\",darkturquoise:\"00ced1\",darkviolet:\"9400d3\",deeppink:\"ff1493\",deepskyblue:\"00bfff\",dimgray:\"696969\",dimgrey:\"696969\",dodgerblue:\"1e90ff\",firebrick:\"b22222\",floralwhite:\"fffaf0\",forestgreen:\"228b22\",fuchsia:\"f0f\",gainsboro:\"dcdcdc\",ghostwhite:\"f8f8ff\",gold:\"ffd700\",goldenrod:\"daa520\",gray:\"808080\",green:\"008000\",greenyellow:\"adff2f\",grey:\"808080\",honeydew:\"f0fff0\",hotpink:\"ff69b4\",indianred:\"cd5c5c\",indigo:\"4b0082\",ivory:\"fffff0\",khaki:\"f0e68c\",lavender:\"e6e6fa\",lavenderblush:\"fff0f5\",lawngreen:\"7cfc00\",lemonchiffon:\"fffacd\",lightblue:\"add8e6\",lightcoral:\"f08080\",lightcyan:\"e0ffff\",lightgoldenrodyellow:\"fafad2\",lightgray:\"d3d3d3\",lightgreen:\"90ee90\",lightgrey:\"d3d3d3\",lightpink:\"ffb6c1\",lightsalmon:\"ffa07a\",lightseagreen:\"20b2aa\",lightskyblue:\"87cefa\",lightslategray:\"789\",lightslategrey:\"789\",lightsteelblue:\"b0c4de\",lightyellow:\"ffffe0\",lime:\"0f0\",limegreen:\"32cd32\",linen:\"faf0e6\",magenta:\"f0f\",maroon:\"800000\",mediumaquamarine:\"66cdaa\",mediumblue:\"0000cd\",mediumorchid:\"ba55d3\",mediumpurple:\"9370db\",mediumseagreen:\"3cb371\",mediumslateblue:\"7b68ee\",mediumspringgreen:\"00fa9a\",mediumturquoise:\"48d1cc\",mediumvioletred:\"c71585\",midnightblue:\"191970\",mintcream:\"f5fffa\",mistyrose:\"ffe4e1\",moccasin:\"ffe4b5\",navajowhite:\"ffdead\",navy:\"000080\",oldlace:\"fdf5e6\",olive:\"808000\",olivedrab:\"6b8e23\",orange:\"ffa500\",orangered:\"ff4500\",orchid:\"da70d6\",palegoldenrod:\"eee8aa\",palegreen:\"98fb98\",paleturquoise:\"afeeee\",palevioletred:\"db7093\",papayawhip:\"ffefd5\",peachpuff:\"ffdab9\",peru:\"cd853f\",pink:\"ffc0cb\",plum:\"dda0dd\",powderblue:\"b0e0e6\",purple:\"800080\",rebeccapurple:\"663399\",red:\"f00\",rosybrown:\"bc8f8f\",royalblue:\"4169e1\",saddlebrown:\"8b4513\",salmon:\"fa8072\",sandybrown:\"f4a460\",seagreen:\"2e8b57\",seashell:\"fff5ee\",sienna:\"a0522d\",silver:\"c0c0c0\",skyblue:\"87ceeb\",slateblue:\"6a5acd\",slategray:\"708090\",slategrey:\"708090\",snow:\"fffafa\",springgreen:\"00ff7f\",steelblue:\"4682b4\",tan:\"d2b48c\",teal:\"008080\",thistle:\"d8bfd8\",tomato:\"ff6347\",turquoise:\"40e0d0\",violet:\"ee82ee\",wheat:\"f5deb3\",white:\"fff\",whitesmoke:\"f5f5f5\",yellow:\"ff0\",yellowgreen:\"9acd32\"},E=c.hexNames=function(t){var e={};for(var r in t)t.hasOwnProperty(r)&&(e[t[r]]=r);return e}(S);function C(t){return t=parseFloat(t),(isNaN(t)||t<0||t>1)&&(t=1),t}function L(e,r){(function(t){return\"string\"==typeof t&&-1!=t.indexOf(\".\")&&1===parseFloat(t)})(e)&&(e=\"100%\");var n=function(t){return\"string\"==typeof t&&-1!=t.indexOf(\"%\")}(e);return e=o(r,s(0,parseFloat(e))),n&&(e=parseInt(e*r,10)/100),t.abs(e-r)<1e-6?1:e%r/parseFloat(r)}function P(t){return o(1,s(0,t))}function O(t){return parseInt(t,16)}function z(t){return 1==t.length?\"0\"+t:\"\"+t}function I(t){return t<=1&&(t=100*t+\"%\"),t}function D(e){return t.round(255*parseFloat(e)).toString(16)}function R(t){return O(t)/255}var F,B,N,j=(B=\"[\\\\s|\\\\(]+(\"+(F=\"(?:[-\\\\+]?\\\\d*\\\\.\\\\d+%?)|(?:[-\\\\+]?\\\\d+%?)\")+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",N=\"[\\\\s|\\\\(]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",{CSS_UNIT:new RegExp(F),rgb:new RegExp(\"rgb\"+B),rgba:new RegExp(\"rgba\"+N),hsl:new RegExp(\"hsl\"+B),hsla:new RegExp(\"hsla\"+N),hsv:new RegExp(\"hsv\"+B),hsva:new RegExp(\"hsva\"+N),hex3:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex6:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/,hex4:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex8:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/});function U(t){return!!j.CSS_UNIT.exec(t)}\"undefined\"!=typeof e&&e.exports?e.exports=c:window.tinycolor=c}(Math)},{}],538:[function(t,e,r){\"use strict\";e.exports=i,e.exports.float32=e.exports.float=i,e.exports.fract32=e.exports.fract=function(t){if(t.length){for(var e=i(t),r=0,n=e.length;r<n;r++)e[r]=t[r]-e[r];return e}return i(t-i(t))};var n=new Float32Array(1);function i(t){if(t.length){if(t instanceof Float32Array)return t;var e=new Float32Array(t);return e.set(t),e}return n[0]=t,n[0]}},{}],539:[function(t,e,r){\"use strict\";var n=t(\"parse-unit\");e.exports=o;var i=96;function a(t,e){var r=n(getComputedStyle(t).getPropertyValue(e));return r[0]*o(r[1],t)}function o(t,e){switch(e=e||document.body,t=(t||\"px\").trim().toLowerCase(),e!==window&&e!==document||(e=document.body),t){case\"%\":return e.clientHeight/100;case\"ch\":case\"ex\":return function(t,e){var r=document.createElement(\"div\");r.style[\"font-size\"]=\"128\"+t,e.appendChild(r);var n=a(r,\"font-size\")/128;return e.removeChild(r),n}(t,e);case\"em\":return a(e,\"font-size\");case\"rem\":return a(document.body,\"font-size\");case\"vw\":return window.innerWidth/100;case\"vh\":return window.innerHeight/100;case\"vmin\":return Math.min(window.innerWidth,window.innerHeight)/100;case\"vmax\":return Math.max(window.innerWidth,window.innerHeight)/100;case\"in\":return i;case\"cm\":return i/2.54;case\"mm\":return i/25.4;case\"pt\":return i/72;case\"pc\":return i/6}return 1}},{\"parse-unit\":461}],540:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e=function(t){return t},r=function(t){if(null==(r=t.transform))return e;var r,n,i,a=r.scale[0],o=r.scale[1],s=r.translate[0],l=r.translate[1];return function(t,e){return e||(n=i=0),t[0]=(n+=t[0])*a+s,t[1]=(i+=t[1])*o+l,t}},n=function(t){var e=t.bbox;function n(t){l[0]=t[0],l[1]=t[1],s(l),l[0]<c&&(c=l[0]),l[0]>h&&(h=l[0]),l[1]<u&&(u=l[1]),l[1]>f&&(f=l[1])}function i(t){switch(t.type){case\"GeometryCollection\":t.geometries.forEach(i);break;case\"Point\":n(t.coordinates);break;case\"MultiPoint\":t.coordinates.forEach(n)}}if(!e){var a,o,s=r(t),l=new Array(2),c=1/0,u=c,h=-c,f=-c;for(o in t.arcs.forEach(function(t){for(var e=-1,r=t.length;++e<r;)a=t[e],l[0]=a[0],l[1]=a[1],s(l,e),l[0]<c&&(c=l[0]),l[0]>h&&(h=l[0]),l[1]<u&&(u=l[1]),l[1]>f&&(f=l[1])}),t.objects)i(t.objects[o]);e=t.bbox=[c,u,h,f]}return e},i=function(t,e){for(var r,n=t.length,i=n-e;i<--n;)r=t[i],t[i++]=t[n],t[n]=r};function a(t,e){var r=e.id,n=e.bbox,i=null==e.properties?{}:e.properties,a=o(t,e);return null==r&&null==n?{type:\"Feature\",properties:i,geometry:a}:null==n?{type:\"Feature\",id:r,properties:i,geometry:a}:{type:\"Feature\",id:r,bbox:n,properties:i,geometry:a}}function o(t,e){var n=r(t),a=t.arcs;function o(t,e){e.length&&e.pop();for(var r=a[t<0?~t:t],o=0,s=r.length;o<s;++o)e.push(n(r[o].slice(),o));t<0&&i(e,s)}function s(t){return n(t.slice())}function l(t){for(var e=[],r=0,n=t.length;r<n;++r)o(t[r],e);return e.length<2&&e.push(e[0].slice()),e}function c(t){for(var e=l(t);e.length<4;)e.push(e[0].slice());return e}function u(t){return t.map(c)}return function t(e){var r,n=e.type;switch(n){case\"GeometryCollection\":return{type:n,geometries:e.geometries.map(t)};case\"Point\":r=s(e.coordinates);break;case\"MultiPoint\":r=e.coordinates.map(s);break;case\"LineString\":r=l(e.arcs);break;case\"MultiLineString\":r=e.arcs.map(l);break;case\"Polygon\":r=u(e.arcs);break;case\"MultiPolygon\":r=e.arcs.map(u);break;default:return null}return{type:n,coordinates:r}}(e)}var s=function(t,e){var r={},n={},i={},a=[],o=-1;function s(t,e){for(var n in t){var i=t[n];delete e[i.start],delete i.start,delete i.end,i.forEach(function(t){r[t<0?~t:t]=1}),a.push(i)}}return e.forEach(function(r,n){var i,a=t.arcs[r<0?~r:r];a.length<3&&!a[1][0]&&!a[1][1]&&(i=e[++o],e[o]=r,e[n]=i)}),e.forEach(function(e){var r,a,o=function(e){var r,n=t.arcs[e<0?~e:e],i=n[0];t.transform?(r=[0,0],n.forEach(function(t){r[0]+=t[0],r[1]+=t[1]})):r=n[n.length-1];return e<0?[r,i]:[i,r]}(e),s=o[0],l=o[1];if(r=i[s])if(delete i[r.end],r.push(e),r.end=l,a=n[l]){delete n[a.start];var c=a===r?r:r.concat(a);n[c.start=r.start]=i[c.end=a.end]=c}else n[r.start]=i[r.end]=r;else if(r=n[l])if(delete n[r.start],r.unshift(e),r.start=s,a=i[s]){delete i[a.end];var u=a===r?r:a.concat(r);n[u.start=a.start]=i[u.end=r.end]=u}else n[r.start]=i[r.end]=r;else n[(r=[e]).start=s]=i[r.end=l]=r}),s(i,n),s(n,i),e.forEach(function(t){r[t<0?~t:t]||a.push([t])}),a};function l(t,e,r){var n,i,a;if(arguments.length>1)n=function(t,e,r){var n,i=[],a=[];function o(t){var e=t<0?~t:t;(a[e]||(a[e]=[])).push({i:t,g:n})}function s(t){t.forEach(o)}function l(t){t.forEach(s)}return function t(e){switch(n=e,e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"LineString\":s(e.arcs);break;case\"MultiLineString\":case\"Polygon\":l(e.arcs);break;case\"MultiPolygon\":e.arcs.forEach(l)}}(e),a.forEach(null==r?function(t){i.push(t[0].i)}:function(t){r(t[0].g,t[t.length-1].g)&&i.push(t[0].i)}),i}(0,e,r);else for(i=0,n=new Array(a=t.arcs.length);i<a;++i)n[i]=i;return{type:\"MultiLineString\",arcs:s(t,n)}}function c(t,e){var r={},n=[],i=[];function a(t){t.forEach(function(e){e.forEach(function(e){(r[e=e<0?~e:e]||(r[e]=[])).push(t)})}),n.push(t)}function l(e){return function(t){for(var e,r=-1,n=t.length,i=t[n-1],a=0;++r<n;)e=i,i=t[r],a+=e[0]*i[1]-e[1]*i[0];return Math.abs(a)}(o(t,{type:\"Polygon\",arcs:[e]}).coordinates[0])}return e.forEach(function t(e){switch(e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"Polygon\":a(e.arcs);break;case\"MultiPolygon\":e.arcs.forEach(a)}}),n.forEach(function(t){if(!t._){var e=[],n=[t];for(t._=1,i.push(e);t=n.pop();)e.push(t),t.forEach(function(t){t.forEach(function(t){r[t<0?~t:t].forEach(function(t){t._||(t._=1,n.push(t))})})})}}),n.forEach(function(t){delete t._}),{type:\"MultiPolygon\",arcs:i.map(function(e){var n,i=[];if(e.forEach(function(t){t.forEach(function(t){t.forEach(function(t){r[t<0?~t:t].length<2&&i.push(t)})})}),(n=(i=s(t,i)).length)>1)for(var a,o,c=1,u=l(i[0]);c<n;++c)(a=l(i[c]))>u&&(o=i[0],i[0]=i[c],i[c]=o,u=a);return i})}}var u=function(t,e){for(var r=0,n=t.length;r<n;){var i=r+n>>>1;t[i]<e?r=i+1:n=i}return r};t.bbox=n,t.feature=function(t,e){return\"GeometryCollection\"===e.type?{type:\"FeatureCollection\",features:e.geometries.map(function(e){return a(t,e)})}:a(t,e)},t.mesh=function(t){return o(t,l.apply(this,arguments))},t.meshArcs=l,t.merge=function(t){return o(t,c.apply(this,arguments))},t.mergeArcs=c,t.neighbors=function(t){var e={},r=t.map(function(){return[]});function n(t,r){t.forEach(function(t){t<0&&(t=~t);var n=e[t];n?n.push(r):e[t]=[r]})}function i(t,e){t.forEach(function(t){n(t,e)})}var a={LineString:n,MultiLineString:i,Polygon:i,MultiPolygon:function(t,e){t.forEach(function(t){i(t,e)})}};for(var o in t.forEach(function t(e,r){\"GeometryCollection\"===e.type?e.geometries.forEach(function(e){t(e,r)}):e.type in a&&a[e.type](e.arcs,r)}),e)for(var s=e[o],l=s.length,c=0;c<l;++c)for(var h=c+1;h<l;++h){var f,p=s[c],d=s[h];(f=r[p])[o=u(f,d)]!==d&&f.splice(o,0,d),(f=r[d])[o=u(f,p)]!==p&&f.splice(o,0,p)}return r},t.quantize=function(t,e){if(!((e=Math.floor(e))>=2))throw new Error(\"n must be \\u22652\");if(t.transform)throw new Error(\"already quantized\");var r,i=n(t),a=i[0],o=(i[2]-a)/(e-1)||1,s=i[1],l=(i[3]-s)/(e-1)||1;function c(t){t[0]=Math.round((t[0]-a)/o),t[1]=Math.round((t[1]-s)/l)}function u(t){switch(t.type){case\"GeometryCollection\":t.geometries.forEach(u);break;case\"Point\":c(t.coordinates);break;case\"MultiPoint\":t.coordinates.forEach(c)}}for(r in t.arcs.forEach(function(t){for(var e,r,n,i=1,c=1,u=t.length,h=t[0],f=h[0]=Math.round((h[0]-a)/o),p=h[1]=Math.round((h[1]-s)/l);i<u;++i)h=t[i],r=Math.round((h[0]-a)/o),n=Math.round((h[1]-s)/l),r===f&&n===p||((e=t[c++])[0]=r-f,f=r,e[1]=n-p,p=n);c<2&&((e=t[c++])[0]=0,e[1]=0),t.length=c}),t.objects)u(t.objects[r]);return t.transform={scale:[o,l],translate:[a,s]},t},t.transform=r,t.untransform=function(t){if(null==(r=t.transform))return e;var r,n,i,a=r.scale[0],o=r.scale[1],s=r.translate[0],l=r.translate[1];return function(t,e){e||(n=i=0);var r=Math.round((t[0]-s)/a),c=Math.round((t[1]-l)/o);return t[0]=r-n,n=r,t[1]=c-i,i=c,t}},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.topojson=n.topojson||{})},{}],541:[function(t,e,r){\"use strict\";e.exports=function(t){if(t<0)return[];if(0===t)return[[0]];for(var e=0|Math.round(a(t+1)),r=[],o=0;o<e;++o){for(var s=n.unrank(t,o),l=[0],c=0,u=0;u<s.length;++u)c+=1<<s[u],l.push(c);i(s)<1&&(l[0]=c,l[t]=0),r.push(l)}return r};var n=t(\"permutation-rank\"),i=t(\"permutation-parity\"),a=t(\"gamma\")},{gamma:231,\"permutation-parity\":463,\"permutation-rank\":464}],542:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.up||[0,1,0],n=t.right||h(r),i=t.radius||1,a=t.theta||0,u=t.phi||0;if(e=[].slice.call(e,0,3),r=[].slice.call(r,0,3),s(r,r),n=[].slice.call(n,0,3),s(n,n),\"eye\"in t){var p=t.eye,d=[p[0]-e[0],p[1]-e[1],p[2]-e[2]];o(n,d,r),c(n[0],n[1],n[2])<1e-6?n=h(r):s(n,n),i=c(d[0],d[1],d[2]);var g=l(r,d)/i,v=l(n,d)/i;u=Math.acos(g),a=Math.acos(v)}return i=Math.log(i),new f(t.zoomMin,t.zoomMax,e,r,n,i,a,u)};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/invert\"),a=t(\"gl-mat4/rotate\"),o=t(\"gl-vec3/cross\"),s=t(\"gl-vec3/normalize\"),l=t(\"gl-vec3/dot\");function c(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function u(t){return Math.min(1,Math.max(-1,t))}function h(t){var e=Math.abs(t[0]),r=Math.abs(t[1]),n=Math.abs(t[2]),i=[0,0,0];e>Math.max(r,n)?i[2]=1:r>Math.max(e,n)?i[0]=1:i[1]=1;for(var a=0,o=0,l=0;l<3;++l)a+=t[l]*t[l],o+=i[l]*t[l];for(l=0;l<3;++l)i[l]-=o/a*t[l];return s(i,i),i}function f(t,e,r,i,a,o,s,l){this.center=n(r),this.up=n(i),this.right=n(a),this.radius=n([o]),this.angle=n([s,l]),this.angle.bounds=[[-1/0,-Math.PI/2],[1/0,Math.PI/2]],this.setDistanceLimits(t,e),this.computedCenter=this.center.curve(0),this.computedUp=this.up.curve(0),this.computedRight=this.right.curve(0),this.computedRadius=this.radius.curve(0),this.computedAngle=this.angle.curve(0),this.computedToward=[0,0,0],this.computedEye=[0,0,0],this.computedMatrix=new Array(16);for(var c=0;c<16;++c)this.computedMatrix[c]=.5;this.recalcMatrix(0)}var p=f.prototype;p.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},p.getDistanceLimits=function(t){var e=this.radius.bounds[0];return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},p.recalcMatrix=function(t){this.center.curve(t),this.up.curve(t),this.right.curve(t),this.radius.curve(t),this.angle.curve(t);for(var e=this.computedUp,r=this.computedRight,n=0,i=0,a=0;a<3;++a)i+=e[a]*r[a],n+=e[a]*e[a];var l=Math.sqrt(n),u=0;for(a=0;a<3;++a)r[a]-=e[a]*i/n,u+=r[a]*r[a],e[a]/=l;var h=Math.sqrt(u);for(a=0;a<3;++a)r[a]/=h;var f=this.computedToward;o(f,e,r),s(f,f);var p=Math.exp(this.computedRadius[0]),d=this.computedAngle[0],g=this.computedAngle[1],v=Math.cos(d),m=Math.sin(d),y=Math.cos(g),x=Math.sin(g),b=this.computedCenter,_=v*y,w=m*y,k=x,T=-v*x,A=-m*x,M=y,S=this.computedEye,E=this.computedMatrix;for(a=0;a<3;++a){var C=_*r[a]+w*f[a]+k*e[a];E[4*a+1]=T*r[a]+A*f[a]+M*e[a],E[4*a+2]=C,E[4*a+3]=0}var L=E[1],P=E[5],O=E[9],z=E[2],I=E[6],D=E[10],R=P*D-O*I,F=O*z-L*D,B=L*I-P*z,N=c(R,F,B);R/=N,F/=N,B/=N,E[0]=R,E[4]=F,E[8]=B;for(a=0;a<3;++a)S[a]=b[a]+E[2+4*a]*p;for(a=0;a<3;++a){u=0;for(var j=0;j<3;++j)u+=E[a+4*j]*S[j];E[12+a]=-u}E[15]=1},p.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r};var d=[0,0,0];p.rotate=function(t,e,r,n){if(this.angle.move(t,e,r),n){this.recalcMatrix(t);var i=this.computedMatrix;d[0]=i[2],d[1]=i[6],d[2]=i[10];for(var o=this.computedUp,s=this.computedRight,l=this.computedToward,c=0;c<3;++c)i[4*c]=o[c],i[4*c+1]=s[c],i[4*c+2]=l[c];a(i,i,n,d);for(c=0;c<3;++c)o[c]=i[4*c],s[c]=i[4*c+1];this.up.set(t,o[0],o[1],o[2]),this.right.set(t,s[0],s[1],s[2])}},p.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=(Math.exp(this.computedRadius[0]),i[1]),o=i[5],s=i[9],l=c(a,o,s);a/=l,o/=l,s/=l;var u=i[0],h=i[4],f=i[8],p=u*a+h*o+f*s,d=c(u-=a*p,h-=o*p,f-=s*p),g=(u/=d)*e+a*r,v=(h/=d)*e+o*r,m=(f/=d)*e+s*r;this.center.move(t,g,v,m);var y=Math.exp(this.computedRadius[0]);y=Math.max(1e-4,y+n),this.radius.set(t,Math.log(y))},p.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},p.setMatrix=function(t,e,r,n){var a=1;\"number\"==typeof r&&(a=0|r),(a<0||a>3)&&(a=1);var o=(a+2)%3;e||(this.recalcMatrix(t),e=this.computedMatrix);var s=e[a],l=e[a+4],h=e[a+8];if(n){var f=Math.abs(s),p=Math.abs(l),d=Math.abs(h),g=Math.max(f,p,d);f===g?(s=s<0?-1:1,l=h=0):d===g?(h=h<0?-1:1,s=l=0):(l=l<0?-1:1,s=h=0)}else{var v=c(s,l,h);s/=v,l/=v,h/=v}var m,y,x=e[o],b=e[o+4],_=e[o+8],w=x*s+b*l+_*h,k=c(x-=s*w,b-=l*w,_-=h*w),T=l*(_/=k)-h*(b/=k),A=h*(x/=k)-s*_,M=s*b-l*x,S=c(T,A,M);if(T/=S,A/=S,M/=S,this.center.jump(t,H,G,Y),this.radius.idle(t),this.up.jump(t,s,l,h),this.right.jump(t,x,b,_),2===a){var E=e[1],C=e[5],L=e[9],P=E*x+C*b+L*_,O=E*T+C*A+L*M;m=R<0?-Math.PI/2:Math.PI/2,y=Math.atan2(O,P)}else{var z=e[2],I=e[6],D=e[10],R=z*s+I*l+D*h,F=z*x+I*b+D*_,B=z*T+I*A+D*M;m=Math.asin(u(R)),y=Math.atan2(B,F)}this.angle.jump(t,y,m),this.recalcMatrix(t);var N=e[2],j=e[6],U=e[10],V=this.computedMatrix;i(V,e);var q=V[15],H=V[12]/q,G=V[13]/q,Y=V[14]/q,W=Math.exp(this.computedRadius[0]);this.center.jump(t,H-N*W,G-j*W,Y-U*W)},p.lastT=function(){return Math.max(this.center.lastT(),this.up.lastT(),this.right.lastT(),this.radius.lastT(),this.angle.lastT())},p.idle=function(t){this.center.idle(t),this.up.idle(t),this.right.idle(t),this.radius.idle(t),this.angle.idle(t)},p.flush=function(t){this.center.flush(t),this.up.flush(t),this.right.flush(t),this.radius.flush(t),this.angle.flush(t)},p.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},p.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||this.computedCenter;var i=(n=n||this.computedUp)[0],a=n[1],o=n[2],s=c(i,a,o);if(!(s<1e-6)){i/=s,a/=s,o/=s;var l=e[0]-r[0],h=e[1]-r[1],f=e[2]-r[2],p=c(l,h,f);if(!(p<1e-6)){l/=p,h/=p,f/=p;var d=this.computedRight,g=d[0],v=d[1],m=d[2],y=i*g+a*v+o*m,x=c(g-=y*i,v-=y*a,m-=y*o);if(!(x<.01&&(x=c(g=a*f-o*h,v=o*l-i*f,m=i*h-a*l))<1e-6)){g/=x,v/=x,m/=x,this.up.set(t,i,a,o),this.right.set(t,g,v,m),this.center.set(t,r[0],r[1],r[2]),this.radius.set(t,Math.log(p));var b=a*m-o*v,_=o*g-i*m,w=i*v-a*g,k=c(b,_,w),T=i*l+a*h+o*f,A=g*l+v*h+m*f,M=(b/=k)*l+(_/=k)*h+(w/=k)*f,S=Math.asin(u(T)),E=Math.atan2(M,A),C=this.angle._state,L=C[C.length-1],P=C[C.length-2];L%=2*Math.PI;var O=Math.abs(L+2*Math.PI-E),z=Math.abs(L-E),I=Math.abs(L-2*Math.PI-E);O<z&&(L+=2*Math.PI),I<z&&(L-=2*Math.PI),this.angle.jump(this.angle.lastT(),L,P),this.angle.set(t,E,S)}}}}},{\"filtered-vector\":226,\"gl-mat4/invert\":265,\"gl-mat4/rotate\":270,\"gl-vec3/cross\":334,\"gl-vec3/dot\":339,\"gl-vec3/normalize\":356}],543:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var i=t*e,a=n*t,o=a-(a-t),s=t-o,l=n*e,c=l-(l-e),u=e-c,h=s*u-(i-o*c-s*c-o*u);if(r)return r[0]=h,r[1]=i,r;return[h,i]};var n=+(Math.pow(2,27)+1)},{}],544:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=t+e,i=n-t,a=e-i,o=t-(n-i);if(r)return r[0]=o+a,r[1]=n,r;return[o+a,n]}},{}],545:[function(t,e,r){(function(e,n){\"use strict\";var i=t(\"bit-twiddle\"),a=t(\"dup\");e.__TYPEDARRAY_POOL||(e.__TYPEDARRAY_POOL={UINT8:a([32,0]),UINT16:a([32,0]),UINT32:a([32,0]),INT8:a([32,0]),INT16:a([32,0]),INT32:a([32,0]),FLOAT:a([32,0]),DOUBLE:a([32,0]),DATA:a([32,0]),UINT8C:a([32,0]),BUFFER:a([32,0])});var o=\"undefined\"!=typeof Uint8ClampedArray,s=e.__TYPEDARRAY_POOL;s.UINT8C||(s.UINT8C=a([32,0])),s.BUFFER||(s.BUFFER=a([32,0]));var l=s.DATA,c=s.BUFFER;function u(t){if(t){var e=t.length||t.byteLength,r=i.log2(e);l[r].push(t)}}function h(t){t=i.nextPow2(t);var e=i.log2(t),r=l[e];return r.length>0?r.pop():new ArrayBuffer(t)}function f(t){return new Uint8Array(h(t),0,t)}function p(t){return new Uint16Array(h(2*t),0,t)}function d(t){return new Uint32Array(h(4*t),0,t)}function g(t){return new Int8Array(h(t),0,t)}function v(t){return new Int16Array(h(2*t),0,t)}function m(t){return new Int32Array(h(4*t),0,t)}function y(t){return new Float32Array(h(4*t),0,t)}function x(t){return new Float64Array(h(8*t),0,t)}function b(t){return o?new Uint8ClampedArray(h(t),0,t):f(t)}function _(t){return new DataView(h(t),0,t)}function w(t){t=i.nextPow2(t);var e=i.log2(t),r=c[e];return r.length>0?r.pop():new n(t)}r.free=function(t){if(n.isBuffer(t))c[i.log2(t.length)].push(t);else{if(\"[object ArrayBuffer]\"!==Object.prototype.toString.call(t)&&(t=t.buffer),!t)return;var e=t.length||t.byteLength,r=0|i.log2(e);l[r].push(t)}},r.freeUint8=r.freeUint16=r.freeUint32=r.freeInt8=r.freeInt16=r.freeInt32=r.freeFloat32=r.freeFloat=r.freeFloat64=r.freeDouble=r.freeUint8Clamped=r.freeDataView=function(t){u(t.buffer)},r.freeArrayBuffer=u,r.freeBuffer=function(t){c[i.log2(t.length)].push(t)},r.malloc=function(t,e){if(void 0===e||\"arraybuffer\"===e)return h(t);switch(e){case\"uint8\":return f(t);case\"uint16\":return p(t);case\"uint32\":return d(t);case\"int8\":return g(t);case\"int16\":return v(t);case\"int32\":return m(t);case\"float\":case\"float32\":return y(t);case\"double\":case\"float64\":return x(t);case\"uint8_clamped\":return b(t);case\"buffer\":return w(t);case\"data\":case\"dataview\":return _(t);default:return null}return null},r.mallocArrayBuffer=h,r.mallocUint8=f,r.mallocUint16=p,r.mallocUint32=d,r.mallocInt8=g,r.mallocInt16=v,r.mallocInt32=m,r.mallocFloat32=r.mallocFloat=y,r.mallocFloat64=r.mallocDouble=x,r.mallocUint8Clamped=b,r.mallocDataView=_,r.mallocBuffer=w,r.clearCache=function(){for(var t=0;t<32;++t)s.UINT8[t].length=0,s.UINT16[t].length=0,s.UINT32[t].length=0,s.INT8[t].length=0,s.INT16[t].length=0,s.INT32[t].length=0,s.FLOAT[t].length=0,s.DOUBLE[t].length=0,s.UINT8C[t].length=0,l[t].length=0,c[t].length=0}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{},t(\"buffer\").Buffer)},{\"bit-twiddle\":92,buffer:105,dup:170}],546:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n;var i=n.prototype;Object.defineProperty(i,\"length\",{get:function(){return this.roots.length}}),i.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},i.find=function(t){for(var e=t,r=this.roots;r[t]!==t;)t=r[t];for(;r[e]!==t;){var n=r[e];r[e]=t,e=n}return t},i.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],547:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return 0===t.length?t:e?(r||t.sort(e),function(t,e){for(var r=1,n=t.length,i=t[0],a=t[0],o=1;o<n;++o)if(a=i,e(i=t[o],a)){if(o===r){r++;continue}t[r++]=i}return t.length=r,t}(t,e)):(r||t.sort(),function(t){for(var e=1,r=t.length,n=t[0],i=t[0],a=1;a<r;++a,i=n)if(i=n,(n=t[a])!==i){if(a===e){e++;continue}t[e++]=n}return t.length=e,t}(t))}},{}],548:[function(t,e,r){var n=/[\\'\\\"]/;e.exports=function(t){return t?(n.test(t.charAt(0))&&(t=t.substr(1)),n.test(t.charAt(t.length-1))&&(t=t.substr(0,t.length-1)),t):\"\"}},{}],549:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){Array.isArray(r)||(r=[].slice.call(arguments,2));for(var n=0,i=r.length;n<i;n++){var a=r[n];for(var o in a)if((void 0===e[o]||Array.isArray(e[o])||t[o]!==e[o])&&o in e){var s;if(!0===a[o])s=e[o];else{if(!1===a[o])continue;if(\"function\"==typeof a[o]&&void 0===(s=a[o](e[o],t,e)))continue}t[o]=s}}return t}},{}],550:[function(t,e,r){\"use strict\";e.exports=function(t,e){\"object\"==typeof e&&null!==e||(e={});return n(t,e.canvas||i,e.context||a,e)};var n=t(\"./lib/vtext\"),i=null,a=null;\"undefined\"!=typeof document&&((i=document.createElement(\"canvas\")).width=8192,i.height=1024,a=i.getContext(\"2d\"))},{\"./lib/vtext\":551}],551:[function(t,e,r){e.exports=function(t,e,r,n){var a=64,o=1.25,s={breaklines:!1,bolds:!1,italics:!1,subscripts:!1,superscripts:!1};n&&(n.size&&n.size>0&&(a=n.size),n.lineSpacing&&n.lineSpacing>0&&(o=n.lineSpacing),n.styletags&&n.styletags.breaklines&&(s.breaklines=!!n.styletags.breaklines),n.styletags&&n.styletags.bolds&&(s.bolds=!!n.styletags.bolds),n.styletags&&n.styletags.italics&&(s.italics=!!n.styletags.italics),n.styletags&&n.styletags.subscripts&&(s.subscripts=!!n.styletags.subscripts),n.styletags&&n.styletags.superscripts&&(s.superscripts=!!n.styletags.superscripts));return r.font=[n.fontStyle,n.fontVariant,n.fontWeight,a+\"px\",n.font].filter(function(t){return t}).join(\" \"),r.textAlign=\"start\",r.textBaseline=\"alphabetic\",r.direction=\"ltr\",w(function(t,e,r,n,a,o){r=r.replace(/\\n/g,\"\"),r=!0===o.breaklines?r.replace(/\\<br\\>/g,\"\\n\"):r.replace(/\\<br\\>/g,\" \");var s=\"\",l=[];for(k=0;k<r.length;++k)l[k]=s;!0===o.bolds&&(l=x(c,u,r,l)),!0===o.italics&&(l=x(h,f,r,l)),!0===o.superscripts&&(l=x(p,g,r,l)),!0===o.subscripts&&(l=x(v,y,r,l));var b=[],_=\"\";for(k=0;k<r.length;++k)null!==l[k]&&(_+=r[k],b.push(l[k]));var w,k,T,A,M,S=_.split(\"\\n\"),E=S.length,C=Math.round(a*n),L=n,P=2*n,O=0,z=E*C+P;t.height<z&&(t.height=z),e.fillStyle=\"#000\",e.fillRect(0,0,t.width,t.height),e.fillStyle=\"#fff\";var I=0,D=\"\";function R(){if(\"\"!==D){var t=e.measureText(D).width;e.fillText(D,L+T,P+A),T+=t}}function F(){return Math.round(M)+\"px \"}function B(t,r){var n=\"\"+e.font;if(!0===o.subscripts){var i=t.indexOf(m),a=r.indexOf(m),s=i>-1?parseInt(t[1+i]):0,l=a>-1?parseInt(r[1+a]):0;s!==l&&(n=n.replace(F(),\"?px \"),M*=Math.pow(.75,l-s),n=n.replace(\"?px \",F())),A+=.25*C*(l-s)}if(!0===o.superscripts){var c=t.indexOf(d),h=r.indexOf(d),p=c>-1?parseInt(t[1+c]):0,g=h>-1?parseInt(r[1+h]):0;p!==g&&(n=n.replace(F(),\"?px \"),M*=Math.pow(.75,g-p),n=n.replace(\"?px \",F())),A-=.25*C*(g-p)}if(!0===o.bolds){var v=t.indexOf(u)>-1,y=r.indexOf(u)>-1;!v&&y&&(n=x?n.replace(\"italic \",\"italic bold \"):\"bold \"+n),v&&!y&&(n=n.replace(\"bold \",\"\"))}if(!0===o.italics){var x=t.indexOf(f)>-1,b=r.indexOf(f)>-1;!x&&b&&(n=\"italic \"+n),x&&!b&&(n=n.replace(\"italic \",\"\"))}e.font=n}for(w=0;w<E;++w){var N=S[w]+\"\\n\";for(T=0,A=w*C,M=n,D=\"\",k=0;k<N.length;++k){var j=k+I<b.length?b[k+I]:b[b.length-1];s===j?D+=N[k]:(R(),D=N[k],void 0!==j&&(B(s,j),s=j))}R(),I+=N.length;var U=0|Math.round(T+2*L);O<U&&(O=U)}var V=O,q=P+C*E;return i(e.getImageData(0,0,V,q).data,[q,V,4]).pick(-1,-1,0).transpose(1,0)}(e,r,t,a,o,s),n,a)},e.exports.processPixels=w;var n=t(\"surface-nets\"),i=t(\"ndarray\"),a=t(\"simplify-planar-graph\"),o=t(\"clean-pslg\"),s=t(\"cdt2d\"),l=t(\"planar-graph-to-polyline\"),c=\"b\",u=\"b|\",h=\"i\",f=\"i|\",p=\"sup\",d=\"+\",g=\"+1\",v=\"sub\",m=\"-\",y=\"-1\";function x(t,e,r,n){for(var i=\"<\"+t+\">\",a=\"</\"+t+\">\",o=i.length,s=a.length,l=e[0]===d||e[0]===m,c=0,u=-s;c>-1&&-1!==(c=r.indexOf(i,c))&&-1!==(u=r.indexOf(a,c+o))&&!(u<=c);){for(var h=c;h<u+s;++h)if(h<c+o||h>=u)n[h]=null,r=r.substr(0,h)+\" \"+r.substr(h+1);else if(null!==n[h]){var f=n[h].indexOf(e[0]);-1===f?n[h]+=e:l&&(n[h]=n[h].substr(0,f+1)+(1+parseInt(n[h][f+1]))+n[h].substr(f+2))}var p=c+o,g=r.substr(p,u-p).indexOf(i);c=-1!==g?g:u+s}return n}function b(t,e){var r=n(t,128);return e?a(r.cells,r.positions,.25):{edges:r.cells,positions:r.positions}}function _(t,e,r,n){var i=b(t,n),a=function(t,e,r){for(var n=e.textAlign||\"start\",i=e.textBaseline||\"alphabetic\",a=[1<<30,1<<30],o=[0,0],s=t.length,l=0;l<s;++l)for(var c=t[l],u=0;u<2;++u)a[u]=0|Math.min(a[u],c[u]),o[u]=0|Math.max(o[u],c[u]);var h=0;switch(n){case\"center\":h=-.5*(a[0]+o[0]);break;case\"right\":case\"end\":h=-o[0];break;case\"left\":case\"start\":h=-a[0];break;default:throw new Error(\"vectorize-text: Unrecognized textAlign: '\"+n+\"'\")}var f=0;switch(i){case\"hanging\":case\"top\":f=-a[1];break;case\"middle\":f=-.5*(a[1]+o[1]);break;case\"alphabetic\":case\"ideographic\":f=-3*r;break;case\"bottom\":f=-o[1];break;default:throw new Error(\"vectorize-text: Unrecoginized textBaseline: '\"+i+\"'\")}var p=1/r;return\"lineHeight\"in e?p*=+e.lineHeight:\"width\"in e?p=e.width/(o[0]-a[0]):\"height\"in e&&(p=e.height/(o[1]-a[1])),t.map(function(t){return[p*(t[0]+h),p*(t[1]+f)]})}(i.positions,e,r),c=i.edges,u=\"ccw\"===e.orientation;if(o(a,c),e.polygons||e.polygon||e.polyline){for(var h=l(c,a),f=new Array(h.length),p=0;p<h.length;++p){for(var d=h[p],g=new Array(d.length),v=0;v<d.length;++v){for(var m=d[v],y=new Array(m.length),x=0;x<m.length;++x)y[x]=a[m[x]].slice();u&&y.reverse(),g[v]=y}f[p]=g}return f}return e.triangles||e.triangulate||e.triangle?{cells:s(a,c,{delaunay:!1,exterior:!1,interior:!0}),positions:a}:{edges:c,positions:a}}function w(t,e,r){try{return _(t,e,r,!0)}catch(t){}try{return _(t,e,r,!1)}catch(t){}return e.polygons||e.polyline||e.polygon?[]:e.triangles||e.triangulate||e.triangle?{cells:[],positions:[]}:{edges:[],positions:[]}}},{cdt2d:106,\"clean-pslg\":116,ndarray:450,\"planar-graph-to-polyline\":468,\"simplify-planar-graph\":524,\"surface-nets\":531}],552:[function(t,e,r){!function(){\"use strict\";if(\"undefined\"==typeof ses||!ses.ok||ses.ok()){\"undefined\"!=typeof ses&&(ses.weakMapPermitHostObjects=v);var t=!1;if(\"function\"==typeof WeakMap){var r=WeakMap;if(\"undefined\"!=typeof navigator&&/Firefox/.test(navigator.userAgent));else{var n=new r,i=Object.freeze({});if(n.set(i,1),1===n.get(i))return void(e.exports=WeakMap);t=!0}}Object.prototype.hasOwnProperty;var a=Object.getOwnPropertyNames,o=Object.defineProperty,s=Object.isExtensible,l=\"weakmap:\",c=l+\"ident:\"+Math.random()+\"___\";if(\"undefined\"!=typeof crypto&&\"function\"==typeof crypto.getRandomValues&&\"function\"==typeof ArrayBuffer&&\"function\"==typeof Uint8Array){var u=new ArrayBuffer(25),h=new Uint8Array(u);crypto.getRandomValues(h),c=l+\"rand:\"+Array.prototype.map.call(h,function(t){return(t%36).toString(36)}).join(\"\")+\"___\"}if(o(Object,\"getOwnPropertyNames\",{value:function(t){return a(t).filter(m)}}),\"getPropertyNames\"in Object){var f=Object.getPropertyNames;o(Object,\"getPropertyNames\",{value:function(t){return f(t).filter(m)}})}!function(){var t=Object.freeze;o(Object,\"freeze\",{value:function(e){return y(e),t(e)}});var e=Object.seal;o(Object,\"seal\",{value:function(t){return y(t),e(t)}});var r=Object.preventExtensions;o(Object,\"preventExtensions\",{value:function(t){return y(t),r(t)}})}();var p=!1,d=0,g=function(){this instanceof g||b();var t=[],e=[],r=d++;return Object.create(g.prototype,{get___:{value:x(function(n,i){var a,o=y(n);return o?r in o?o[r]:i:(a=t.indexOf(n))>=0?e[a]:i})},has___:{value:x(function(e){var n=y(e);return n?r in n:t.indexOf(e)>=0})},set___:{value:x(function(n,i){var a,o=y(n);return o?o[r]=i:(a=t.indexOf(n))>=0?e[a]=i:(a=t.length,e[a]=i,t[a]=n),this})},delete___:{value:x(function(n){var i,a,o=y(n);return o?r in o&&delete o[r]:!((i=t.indexOf(n))<0||(a=t.length-1,t[i]=void 0,e[i]=e[a],t[i]=t[a],t.length=a,e.length=a,0))})}})};g.prototype=Object.create(Object.prototype,{get:{value:function(t,e){return this.get___(t,e)},writable:!0,configurable:!0},has:{value:function(t){return this.has___(t)},writable:!0,configurable:!0},set:{value:function(t,e){return this.set___(t,e)},writable:!0,configurable:!0},delete:{value:function(t){return this.delete___(t)},writable:!0,configurable:!0}}),\"function\"==typeof r?function(){function n(){this instanceof g||b();var e,n=new r,i=void 0,a=!1;return e=t?function(t,e){return n.set(t,e),n.has(t)||(i||(i=new g),i.set(t,e)),this}:function(t,e){if(a)try{n.set(t,e)}catch(r){i||(i=new g),i.set___(t,e)}else n.set(t,e);return this},Object.create(g.prototype,{get___:{value:x(function(t,e){return i?n.has(t)?n.get(t):i.get___(t,e):n.get(t,e)})},has___:{value:x(function(t){return n.has(t)||!!i&&i.has___(t)})},set___:{value:x(e)},delete___:{value:x(function(t){var e=!!n.delete(t);return i&&i.delete___(t)||e})},permitHostObjects___:{value:x(function(t){if(t!==v)throw new Error(\"bogus call to permitHostObjects___\");a=!0})}})}t&&\"undefined\"!=typeof Proxy&&(Proxy=void 0),n.prototype=g.prototype,e.exports=n,Object.defineProperty(WeakMap.prototype,\"constructor\",{value:WeakMap,enumerable:!1,configurable:!0,writable:!0})}():(\"undefined\"!=typeof Proxy&&(Proxy=void 0),e.exports=g)}function v(t){t.permitHostObjects___&&t.permitHostObjects___(v)}function m(t){return!(t.substr(0,l.length)==l&&\"___\"===t.substr(t.length-3))}function y(t){if(t!==Object(t))throw new TypeError(\"Not an object: \"+t);var e=t[c];if(e&&e.key===t)return e;if(s(t)){e={key:t};try{return o(t,c,{value:e,writable:!1,enumerable:!1,configurable:!1}),e}catch(t){return}}}function x(t){return t.prototype=null,Object.freeze(t)}function b(){p||\"undefined\"==typeof console||(p=!0,console.warn(\"WeakMap should be invoked as new WeakMap(), not WeakMap(). This will be an error in the future.\"))}}()},{}],553:[function(t,e,r){var n=t(\"./hidden-store.js\");e.exports=function(){var t={};return function(e){if((\"object\"!=typeof e||null===e)&&\"function\"!=typeof e)throw new Error(\"Weakmap-shim: Key must be object\");var r=e.valueOf(t);return r&&r.identity===t?r:n(e,t)}}},{\"./hidden-store.js\":554}],554:[function(t,e,r){e.exports=function(t,e){var r={identity:e},n=t.valueOf;return Object.defineProperty(t,\"valueOf\",{value:function(t){return t!==e?n.apply(this,arguments):r},writable:!0}),r}},{}],555:[function(t,e,r){var n=t(\"./create-store.js\");e.exports=function(){var t=n();return{get:function(e,r){var n=t(e);return n.hasOwnProperty(\"value\")?n.value:r},set:function(e,r){return t(e).value=r,this},has:function(e){return\"value\"in t(e)},delete:function(e){return delete t(e).value}}}},{\"./create-store.js\":553}],556:[function(t,e,r){var n=t(\"get-canvas-context\");e.exports=function(t){return n(\"webgl\",t)}},{\"get-canvas-context\":232}],557:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Chinese\",jdEpoch:1721425.5,hasYearZero:!1,minMonth:0,firstMonth:0,minDay:1,regionalOptions:{\"\":{name:\"Chinese\",epochs:[\"BEC\",\"EC\"],monthNumbers:function(t,e){if(\"string\"==typeof t){var r=t.match(l);return r?r[0]:\"\"}var n=this._validateYear(t),i=t.month(),a=\"\"+this.toChineseMonth(n,i);return e&&a.length<2&&(a=\"0\"+a),this.isIntercalaryMonth(n,i)&&(a+=\"i\"),a},monthNames:function(t){if(\"string\"==typeof t){var e=t.match(c);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\\u6708\",\"\\u4e8c\\u6708\",\"\\u4e09\\u6708\",\"\\u56db\\u6708\",\"\\u4e94\\u6708\",\"\\u516d\\u6708\",\"\\u4e03\\u6708\",\"\\u516b\\u6708\",\"\\u4e5d\\u6708\",\"\\u5341\\u6708\",\"\\u5341\\u4e00\\u6708\",\"\\u5341\\u4e8c\\u6708\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},monthNamesShort:function(t){if(\"string\"==typeof t){var e=t.match(u);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},parseMonth:function(t,e){t=this._validateYear(t);var r,n=parseInt(e);if(isNaN(n))\"\\u95f0\"===e[0]&&(r=!0,e=e.substring(1)),\"\\u6708\"===e[e.length-1]&&(e=e.substring(0,e.length-1)),n=1+[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"].indexOf(e);else{var i=e[e.length-1];r=\"i\"===i||\"I\"===i}return this.toMonthIndex(t,n,r)},dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},_validateYear:function(t,e){if(t.year&&(t=t.year()),\"number\"!=typeof t||t<1888||t>2111)throw e.replace(/\\{0\\}/,this.local.name);return t},toMonthIndex:function(t,e,r){var i=this.intercalaryMonth(t);if(r&&e!==i||e<1||e>12)throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return i?!r&&e<=i?e-1:e:e-1},toChineseMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);if(e<0||e>(r?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r?e<r?e+1:e:e+1},intercalaryMonth:function(t){return t=this._validateYear(t),h[t-h[0]]>>13},isIntercalaryMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);return!!r&&r===e},leapYear:function(t){return 0!==this.intercalaryMonth(t)},weekOfYear:function(t,e,r){var i,o=this._validateYear(t,n.local.invalidyear),s=f[o-f[0]],l=s>>9&4095,c=s>>5&15,u=31&s;(i=a.newDate(l,c,u)).add(4-(i.dayOfWeek()||7),\"d\");var h=this.toJD(t,e,r)-i.toJD();return 1+Math.floor(h/7)},monthsInYear:function(t){return this.leapYear(t)?13:12},daysInMonth:function(t,e){t.year&&(e=t.month(),t=t.year()),t=this._validateYear(t);var r=h[t-h[0]];if(e>(r>>13?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r&1<<12-e?30:29},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,s,r,n.local.invalidDate);t=this._validateYear(i.year()),e=i.month(),r=i.day();var o=this.isIntercalaryMonth(t,e),s=this.toChineseMonth(t,e),l=function(t,e,r,n,i){var a,o,s;if(\"object\"==typeof t)o=t,a=e||{};else{var l=\"number\"==typeof t&&t>=1888&&t<=2111;if(!l)throw new Error(\"Lunar year outside range 1888-2111\");var c=\"number\"==typeof e&&e>=1&&e<=12;if(!c)throw new Error(\"Lunar month outside range 1 - 12\");var u,p=\"number\"==typeof r&&r>=1&&r<=30;if(!p)throw new Error(\"Lunar day outside range 1 - 30\");\"object\"==typeof n?(u=!1,a=n):(u=!!n,a=i||{}),o={year:t,month:e,day:r,isIntercalary:u}}s=o.day-1;var d,g=h[o.year-h[0]],v=g>>13;d=v?o.month>v?o.month:o.isIntercalary?o.month:o.month-1:o.month-1;for(var m=0;m<d;m++){var y=g&1<<12-m?30:29;s+=y}var x=f[o.year-f[0]],b=new Date(x>>9&4095,(x>>5&15)-1,(31&x)+s);return a.year=b.getFullYear(),a.month=1+b.getMonth(),a.day=b.getDate(),a}(t,s,r,o);return a.toJD(l.year,l.month,l.day)},fromJD:function(t){var e=a.fromJD(t),r=function(t,e,r,n){var i,a;if(\"object\"==typeof t)i=t,a=e||{};else{var o=\"number\"==typeof t&&t>=1888&&t<=2111;if(!o)throw new Error(\"Solar year outside range 1888-2111\");var s=\"number\"==typeof e&&e>=1&&e<=12;if(!s)throw new Error(\"Solar month outside range 1 - 12\");var l=\"number\"==typeof r&&r>=1&&r<=31;if(!l)throw new Error(\"Solar day outside range 1 - 31\");i={year:t,month:e,day:r},a=n||{}}var c=f[i.year-f[0]],u=i.year<<9|i.month<<5|i.day;a.year=u>=c?i.year:i.year-1,c=f[a.year-f[0]];var p,d=new Date(c>>9&4095,(c>>5&15)-1,31&c),g=new Date(i.year,i.month-1,i.day);p=Math.round((g-d)/864e5);var v,m=h[a.year-h[0]];for(v=0;v<13;v++){var y=m&1<<12-v?30:29;if(p<y)break;p-=y}var x=m>>13;!x||v<x?(a.isIntercalary=!1,a.month=1+v):v===x?(a.isIntercalary=!0,a.month=v):(a.isIntercalary=!1,a.month=v);return a.day=1+p,a}(e.year(),e.month(),e.day()),n=this.toMonthIndex(r.year,r.month,r.isIntercalary);return this.newDate(r.year,n,r.day)},fromString:function(t){var e=t.match(s),r=this._validateYear(+e[1]),n=+e[2],i=!!e[3],a=this.toMonthIndex(r,n,i),o=+e[4];return this.newDate(r,a,o)},add:function(t,e,r){var n=t.year(),i=t.month(),a=this.isIntercalaryMonth(n,i),s=this.toChineseMonth(n,i),l=Object.getPrototypeOf(o.prototype).add.call(this,t,e,r);if(\"y\"===r){var c=l.year(),u=l.month(),h=this.isIntercalaryMonth(c,s),f=a&&h?this.toMonthIndex(c,s,!0):this.toMonthIndex(c,s,!1);f!==u&&l.month(f)}return l}});var s=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)[-\\/](\\d?\\d)([iI]?)[-\\/](\\d?\\d)/m,l=/^\\d?\\d[iI]?/m,c=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?\\u6708/m,u=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?/m;n.calendars.chinese=o;var h=[1887,5780,5802,19157,2742,50359,1198,2646,46378,7466,3412,30122,5482,67949,2396,5294,43597,6732,6954,36181,2772,4954,18781,2396,54427,5274,6730,47781,5800,6868,21210,4790,59703,2350,5270,46667,3402,3496,38325,1388,4782,18735,2350,52374,6804,7498,44457,2906,1388,29294,4700,63789,6442,6804,56138,5802,2772,38235,1210,4698,22827,5418,63125,3476,5802,43701,2484,5302,27223,2646,70954,7466,3412,54698,5482,2412,38062,5294,2636,32038,6954,60245,2772,4826,43357,2394,5274,39501,6730,72357,5800,5844,53978,4790,2358,38039,5270,87627,3402,3496,54708,5484,4782,43311,2350,3222,27978,7498,68965,2904,5484,45677,4700,6444,39573,6804,6986,19285,2772,62811,1210,4698,47403,5418,5780,38570,5546,76469,2420,5302,51799,2646,5414,36501,3412,5546,18869,2412,54446,5276,6732,48422,6822,2900,28010,4826,92509,2394,5274,55883,6730,6820,47956,5812,2778,18779,2358,62615,5270,5450,46757,3492,5556,27318,4718,67887,2350,3222,52554,7498,3428,38252,5468,4700,31022,6444,64149,6804,6986,43861,2772,5338,35421,2650,70955,5418,5780,54954,5546,2740,38074,5302,2646,29991,3366,61011,3412,5546,43445,2412,5294,35406,6732,72998,6820,6996,52586,2778,2396,38045,5274,6698,23333,6820,64338,5812,2746,43355,2358,5270,39499,5450,79525,3492,5548],f=[1887,966732,967231,967733,968265,968766,969297,969798,970298,970829,971330,971830,972362,972863,973395,973896,974397,974928,975428,975929,976461,976962,977462,977994,978494,979026,979526,980026,980558,981059,981559,982091,982593,983124,983624,984124,984656,985157,985656,986189,986690,987191,987722,988222,988753,989254,989754,990286,990788,991288,991819,992319,992851,993352,993851,994383,994885,995385,995917,996418,996918,997450,997949,998481,998982,999483,1000014,1000515,1001016,1001548,1002047,1002578,1003080,1003580,1004111,1004613,1005113,1005645,1006146,1006645,1007177,1007678,1008209,1008710,1009211,1009743,1010243,1010743,1011275,1011775,1012306,1012807,1013308,1013840,1014341,1014841,1015373,1015874,1016404,1016905,1017405,1017937,1018438,1018939,1019471,1019972,1020471,1021002,1021503,1022035,1022535,1023036,1023568,1024069,1024568,1025100,1025601,1026102,1026633,1027133,1027666,1028167,1028666,1029198,1029699,1030199,1030730,1031231,1031763,1032264,1032764,1033296,1033797,1034297,1034828,1035329,1035830,1036362,1036861,1037393,1037894,1038394,1038925,1039427,1039927,1040459,1040959,1041491,1041992,1042492,1043023,1043524,1044024,1044556,1045057,1045558,1046090,1046590,1047121,1047622,1048122,1048654,1049154,1049655,1050187,1050689,1051219,1051720,1052220,1052751,1053252,1053752,1054284,1054786,1055285,1055817,1056317,1056849,1057349,1057850,1058382,1058883,1059383,1059915,1060415,1060947,1061447,1061947,1062479,1062981,1063480,1064012,1064514,1065014,1065545,1066045,1066577,1067078,1067578,1068110,1068611,1069112,1069642,1070142,1070674,1071175,1071675,1072207,1072709,1073209,1073740,1074241,1074741,1075273,1075773,1076305,1076807,1077308,1077839,1078340,1078840,1079372,1079871,1080403,1080904]},{\"../main\":571,\"object-assign\":454}],558:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Coptic\",jdEpoch:1825029.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Coptic\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Thout\",\"Paopi\",\"Hathor\",\"Koiak\",\"Tobi\",\"Meshir\",\"Paremhat\",\"Paremoude\",\"Pashons\",\"Paoni\",\"Epip\",\"Mesori\",\"Pi Kogi Enavot\"],monthNamesShort:[\"Tho\",\"Pao\",\"Hath\",\"Koi\",\"Tob\",\"Mesh\",\"Pat\",\"Pad\",\"Pash\",\"Pao\",\"Epi\",\"Meso\",\"PiK\"],dayNames:[\"Tkyriaka\",\"Pesnau\",\"Pshoment\",\"Peftoou\",\"Ptiou\",\"Psoou\",\"Psabbaton\"],dayNamesShort:[\"Tky\",\"Pes\",\"Psh\",\"Pef\",\"Pti\",\"Pso\",\"Psa\"],dayNamesMin:[\"Tk\",\"Pes\",\"Psh\",\"Pef\",\"Pt\",\"Pso\",\"Psa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.coptic=a},{\"../main\":571,\"object-assign\":454}],559:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Discworld\",jdEpoch:1721425.5,daysPerMonth:[16,32,32,32,32,32,32,32,32,32,32,32,32],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Discworld\",epochs:[\"BUC\",\"UC\"],monthNames:[\"Ick\",\"Offle\",\"February\",\"March\",\"April\",\"May\",\"June\",\"Grune\",\"August\",\"Spune\",\"Sektober\",\"Ember\",\"December\"],monthNamesShort:[\"Ick\",\"Off\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Gru\",\"Aug\",\"Spu\",\"Sek\",\"Emb\",\"Dec\"],dayNames:[\"Sunday\",\"Octeday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Oct\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Oc\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:2,isRTL:!1}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),13},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),400},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/8)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]},daysInWeek:function(){return 8},dayOfWeek:function(t,e,r){return(this._validate(t,e,r,n.local.invalidDate).day()+1)%8},weekDay:function(t,e,r){var n=this.dayOfWeek(t,e,r);return n>=2&&n<=6},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{century:o[Math.floor((i.year()-1)/100)+1]||\"\"}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year()+(i.year()<0?1:0),e=i.month(),(r=i.day())+(e>1?16:0)+(e>2?32*(e-2):0)+400*(t-1)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t+.5)-Math.floor(this.jdEpoch)-1;var e=Math.floor(t/400)+1;t-=400*(e-1),t+=t>15?16:0;var r=Math.floor(t/32)+1,n=t-32*(r-1)+1;return this.newDate(e<=0?e-1:e,r,n)}});var o={20:\"Fruitbat\",21:\"Anchovy\"};n.calendars.discworld=a},{\"../main\":571,\"object-assign\":454}],560:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Ethiopian\",jdEpoch:1724220.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Ethiopian\",epochs:[\"BEE\",\"EE\"],monthNames:[\"Meskerem\",\"Tikemet\",\"Hidar\",\"Tahesas\",\"Tir\",\"Yekatit\",\"Megabit\",\"Miazia\",\"Genbot\",\"Sene\",\"Hamle\",\"Nehase\",\"Pagume\"],monthNamesShort:[\"Mes\",\"Tik\",\"Hid\",\"Tah\",\"Tir\",\"Yek\",\"Meg\",\"Mia\",\"Gen\",\"Sen\",\"Ham\",\"Neh\",\"Pag\"],dayNames:[\"Ehud\",\"Segno\",\"Maksegno\",\"Irob\",\"Hamus\",\"Arb\",\"Kidame\"],dayNamesShort:[\"Ehu\",\"Seg\",\"Mak\",\"Iro\",\"Ham\",\"Arb\",\"Kid\"],dayNamesMin:[\"Eh\",\"Se\",\"Ma\",\"Ir\",\"Ha\",\"Ar\",\"Ki\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.ethiopian=a},{\"../main\":571,\"object-assign\":454}],561:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Hebrew\",jdEpoch:347995.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29,29],hasYearZero:!1,minMonth:1,firstMonth:7,minDay:1,regionalOptions:{\"\":{name:\"Hebrew\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Nisan\",\"Iyar\",\"Sivan\",\"Tammuz\",\"Av\",\"Elul\",\"Tishrei\",\"Cheshvan\",\"Kislev\",\"Tevet\",\"Shevat\",\"Adar\",\"Adar II\"],monthNamesShort:[\"Nis\",\"Iya\",\"Siv\",\"Tam\",\"Av\",\"Elu\",\"Tis\",\"Che\",\"Kis\",\"Tev\",\"She\",\"Ada\",\"Ad2\"],dayNames:[\"Yom Rishon\",\"Yom Sheni\",\"Yom Shlishi\",\"Yom Revi'i\",\"Yom Chamishi\",\"Yom Shishi\",\"Yom Shabbat\"],dayNamesShort:[\"Ris\",\"She\",\"Shl\",\"Rev\",\"Cha\",\"Shi\",\"Sha\"],dayNamesMin:[\"Ri\",\"She\",\"Shl\",\"Re\",\"Ch\",\"Shi\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return this._leapYear(e.year())},_leapYear:function(t){return o(7*(t=t<0?t+1:t)+1,19)<7},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),this._leapYear(t.year?t.year():t)?13:12},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),this.toJD(-1===t?1:t+1,7,1)-this.toJD(t,7,1)},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),12===e&&this.leapYear(t)?30:8===e&&5===o(this.daysInYear(t),10)?30:9===e&&3===o(this.daysInYear(t),10)?29:this.daysPerMonth[e-1]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{yearType:(this.leapYear(i)?\"embolismic\":\"common\")+\" \"+[\"deficient\",\"regular\",\"complete\"][this.daysInYear(i)%10-3]}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t<=0?t+1:t,o=this.jdEpoch+this._delay1(a)+this._delay2(a)+r+1;if(e<7){for(var s=7;s<=this.monthsInYear(t);s++)o+=this.daysInMonth(t,s);for(s=1;s<e;s++)o+=this.daysInMonth(t,s)}else for(s=7;s<e;s++)o+=this.daysInMonth(t,s);return o},_delay1:function(t){var e=Math.floor((235*t-234)/19),r=12084+13753*e,n=29*e+Math.floor(r/25920);return o(3*(n+1),7)<3&&n++,n},_delay2:function(t){var e=this._delay1(t-1),r=this._delay1(t);return this._delay1(t+1)-r==356?2:r-e==382?1:0},fromJD:function(t){t=Math.floor(t)+.5;for(var e=Math.floor(98496*(t-this.jdEpoch)/35975351)-1;t>=this.toJD(-1===e?1:e+1,7,1);)e++;for(var r=t<this.toJD(e,1,1)?7:1;t>this.toJD(e,r,this.daysInMonth(e,r));)r++;var n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.hebrew=a},{\"../main\":571,\"object-assign\":454}],562:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Islamic\",jdEpoch:1948439.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Islamic\",epochs:[\"BH\",\"AH\"],monthNames:[\"Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' al-thani\",\"Jumada al-awwal\",\"Jumada al-thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-ahad\",\"Yawm al-ithnayn\",\"Yawm ath-thulaathaa'\",\"Yawm al-arbi'aa'\",\"Yawm al-kham\\u012bs\",\"Yawm al-jum'a\",\"Yawm as-sabt\"],dayNamesShort:[\"Aha\",\"Ith\",\"Thu\",\"Arb\",\"Kha\",\"Jum\",\"Sab\"],dayNamesMin:[\"Ah\",\"It\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){return(11*this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year()+14)%30<11},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return this.leapYear(t)?355:354},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),t=t<=0?t+1:t,(r=i.day())+Math.ceil(29.5*(e-1))+354*(t-1)+Math.floor((3+11*t)/30)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t)+.5;var e=Math.floor((30*(t-this.jdEpoch)+10646)/10631);e=e<=0?e-1:e;var r=Math.min(12,Math.ceil((t-29-this.toJD(e,1,1))/29.5)+1),n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.islamic=a},{\"../main\":571,\"object-assign\":454}],563:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Julian\",jdEpoch:1721423.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Julian\",epochs:[\"BC\",\"AD\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()<0?e.year()+1:e.year())%4==0},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),r=i.day(),t<0&&t++,e<=2&&(t--,e+=12),Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r-1524.5},fromJD:function(t){var e=Math.floor(t+.5)+1524,r=Math.floor((e-122.1)/365.25),n=Math.floor(365.25*r),i=Math.floor((e-n)/30.6001),a=i-Math.floor(i<14?1:13),o=r-Math.floor(a>2?4716:4715),s=e-n-Math.floor(30.6001*i);return o<=0&&o--,this.newDate(o,a,s)}}),n.calendars.julian=a},{\"../main\":571,\"object-assign\":454}],564:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}function s(t,e){return o(t-1,e)+1}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Mayan\",jdEpoch:584282.5,hasYearZero:!0,minMonth:0,firstMonth:0,minDay:0,regionalOptions:{\"\":{name:\"Mayan\",epochs:[\"\",\"\"],monthNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],monthNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],dayNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesMin:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],digits:null,dateFormat:\"YYYY.m.d\",firstDay:0,isRTL:!1,haabMonths:[\"Pop\",\"Uo\",\"Zip\",\"Zotz\",\"Tzec\",\"Xul\",\"Yaxkin\",\"Mol\",\"Chen\",\"Yax\",\"Zac\",\"Ceh\",\"Mac\",\"Kankin\",\"Muan\",\"Pax\",\"Kayab\",\"Cumku\",\"Uayeb\"],tzolkinMonths:[\"Imix\",\"Ik\",\"Akbal\",\"Kan\",\"Chicchan\",\"Cimi\",\"Manik\",\"Lamat\",\"Muluc\",\"Oc\",\"Chuen\",\"Eb\",\"Ben\",\"Ix\",\"Men\",\"Cib\",\"Caban\",\"Etznab\",\"Cauac\",\"Ahau\"]}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},formatYear:function(t){t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year();var e=Math.floor(t/400);return t%=400,t+=t<0?400:0,e+\".\"+Math.floor(t/20)+\".\"+t%20},forYear:function(t){if((t=t.split(\".\")).length<3)throw\"Invalid Mayan year\";for(var e=0,r=0;r<t.length;r++){var n=parseInt(t[r],10);if(Math.abs(n)>19||r>0&&n<0)throw\"Invalid Mayan year\";e=20*e+n}return e},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),18},weekOfYear:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),0},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),360},daysInMonth:function(t,e){return this._validate(t,e,this.minDay,n.local.invalidMonth),20},daysInWeek:function(){return 5},dayOfWeek:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate).day()},weekDay:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),!0},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate).toJD(),a=this._toHaab(i),o=this._toTzolkin(i);return{haabMonthName:this.local.haabMonths[a[0]-1],haabMonth:a[0],haabDay:a[1],tzolkinDayName:this.local.tzolkinMonths[o[0]-1],tzolkinDay:o[0],tzolkinTrecena:o[1]}},_toHaab:function(t){var e=o((t-=this.jdEpoch)+8+340,365);return[Math.floor(e/20)+1,o(e,20)]},_toTzolkin:function(t){return[s((t-=this.jdEpoch)+20,20),s(t+4,13)]},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return i.day()+20*i.month()+360*i.year()+this.jdEpoch},fromJD:function(t){t=Math.floor(t)+.5-this.jdEpoch;var e=Math.floor(t/360);t%=360,t+=t<0?360:0;var r=Math.floor(t/20),n=t%20;return this.newDate(e,r,n)}}),n.calendars.mayan=a},{\"../main\":571,\"object-assign\":454}],565:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar;var o=n.instance(\"gregorian\");i(a.prototype,{name:\"Nanakshahi\",jdEpoch:2257673.5,daysPerMonth:[31,31,31,31,31,30,30,30,30,30,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Nanakshahi\",epochs:[\"BN\",\"AN\"],monthNames:[\"Chet\",\"Vaisakh\",\"Jeth\",\"Harh\",\"Sawan\",\"Bhadon\",\"Assu\",\"Katak\",\"Maghar\",\"Poh\",\"Magh\",\"Phagun\"],monthNamesShort:[\"Che\",\"Vai\",\"Jet\",\"Har\",\"Saw\",\"Bha\",\"Ass\",\"Kat\",\"Mgr\",\"Poh\",\"Mgh\",\"Pha\"],dayNames:[\"Somvaar\",\"Mangalvar\",\"Budhvaar\",\"Veervaar\",\"Shukarvaar\",\"Sanicharvaar\",\"Etvaar\"],dayNamesShort:[\"Som\",\"Mangal\",\"Budh\",\"Veer\",\"Shukar\",\"Sanichar\",\"Et\"],dayNamesMin:[\"So\",\"Ma\",\"Bu\",\"Ve\",\"Sh\",\"Sa\",\"Et\"],digits:null,dateFormat:\"dd-mm-yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear);return o.leapYear(e.year()+(e.year()<1?1:0)+1469)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(1-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidMonth);(t=i.year())<0&&t++;for(var a=i.day(),s=1;s<i.month();s++)a+=this.daysPerMonth[s-1];return a+o.toJD(t+1468,3,13)},fromJD:function(t){t=Math.floor(t+.5);for(var e=Math.floor((t-(this.jdEpoch-1))/366);t>=this.toJD(e+1,1,1);)e++;for(var r=t-Math.floor(this.toJD(e,1,1)+.5)+1,n=1;r>this.daysInMonth(e,n);)r-=this.daysInMonth(e,n),n++;return this.newDate(e,n,r)}}),n.calendars.nanakshahi=a},{\"../main\":571,\"object-assign\":454}],566:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Nepali\",jdEpoch:1700709.5,daysPerMonth:[31,31,32,32,31,30,30,29,30,29,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,daysPerYear:365,regionalOptions:{\"\":{name:\"Nepali\",epochs:[\"BBS\",\"ABS\"],monthNames:[\"Baisakh\",\"Jestha\",\"Ashadh\",\"Shrawan\",\"Bhadra\",\"Ashwin\",\"Kartik\",\"Mangsir\",\"Paush\",\"Mangh\",\"Falgun\",\"Chaitra\"],monthNamesShort:[\"Bai\",\"Je\",\"As\",\"Shra\",\"Bha\",\"Ash\",\"Kar\",\"Mang\",\"Pau\",\"Ma\",\"Fal\",\"Chai\"],dayNames:[\"Aaitabaar\",\"Sombaar\",\"Manglbaar\",\"Budhabaar\",\"Bihibaar\",\"Shukrabaar\",\"Shanibaar\"],dayNamesShort:[\"Aaita\",\"Som\",\"Mangl\",\"Budha\",\"Bihi\",\"Shukra\",\"Shani\"],dayNamesMin:[\"Aai\",\"So\",\"Man\",\"Bu\",\"Bi\",\"Shu\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:1,isRTL:!1}},leapYear:function(t){return this.daysInYear(t)!==this.daysPerYear},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){if(t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t])return this.daysPerYear;for(var e=0,r=this.minMonth;r<=12;r++)e+=this.NEPALI_CALENDAR_DATA[t][r];return e},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t]?this.daysPerMonth[e-1]:this.NEPALI_CALENDAR_DATA[t][e]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=n.instance(),o=0,s=e,l=t;this._createMissingCalendarData(t);var c=t-(s>9||9===s&&r>=this.NEPALI_CALENDAR_DATA[l][0]?56:57);for(9!==e&&(o=r,s--);9!==s;)s<=0&&(s=12,l--),o+=this.NEPALI_CALENDAR_DATA[l][s],s--;return 9===e?(o+=r-this.NEPALI_CALENDAR_DATA[l][0])<0&&(o+=a.daysInYear(c)):o+=this.NEPALI_CALENDAR_DATA[l][9]-this.NEPALI_CALENDAR_DATA[l][0],a.newDate(c,1,1).add(o,\"d\").toJD()},fromJD:function(t){var e=n.instance().fromJD(t),r=e.year(),i=e.dayOfYear(),a=r+56;this._createMissingCalendarData(a);for(var o=9,s=this.NEPALI_CALENDAR_DATA[a][0],l=this.NEPALI_CALENDAR_DATA[a][o]-s+1;i>l;)++o>12&&(o=1,a++),l+=this.NEPALI_CALENDAR_DATA[a][o];var c=this.NEPALI_CALENDAR_DATA[a][o]-(l-i);return this.newDate(a,o,c)},_createMissingCalendarData:function(t){var e=this.daysPerMonth.slice(0);e.unshift(17);for(var r=t-1;r<t+2;r++)\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[r]&&(this.NEPALI_CALENDAR_DATA[r]=e)},NEPALI_CALENDAR_DATA:{1970:[18,31,31,32,31,31,31,30,29,30,29,30,30],1971:[18,31,31,32,31,32,30,30,29,30,29,30,30],1972:[17,31,32,31,32,31,30,30,30,29,29,30,30],1973:[19,30,32,31,32,31,30,30,30,29,30,29,31],1974:[19,31,31,32,30,31,31,30,29,30,29,30,30],1975:[18,31,31,32,32,30,31,30,29,30,29,30,30],1976:[17,31,32,31,32,31,30,30,30,29,29,30,31],1977:[18,31,32,31,32,31,31,29,30,29,30,29,31],1978:[18,31,31,32,31,31,31,30,29,30,29,30,30],1979:[18,31,31,32,32,31,30,30,29,30,29,30,30],1980:[17,31,32,31,32,31,30,30,30,29,29,30,31],1981:[18,31,31,31,32,31,31,29,30,30,29,30,30],1982:[18,31,31,32,31,31,31,30,29,30,29,30,30],1983:[18,31,31,32,32,31,30,30,29,30,29,30,30],1984:[17,31,32,31,32,31,30,30,30,29,29,30,31],1985:[18,31,31,31,32,31,31,29,30,30,29,30,30],1986:[18,31,31,32,31,31,31,30,29,30,29,30,30],1987:[18,31,32,31,32,31,30,30,29,30,29,30,30],1988:[17,31,32,31,32,31,30,30,30,29,29,30,31],1989:[18,31,31,31,32,31,31,30,29,30,29,30,30],1990:[18,31,31,32,31,31,31,30,29,30,29,30,30],1991:[18,31,32,31,32,31,30,30,29,30,29,30,30],1992:[17,31,32,31,32,31,30,30,30,29,30,29,31],1993:[18,31,31,31,32,31,31,30,29,30,29,30,30],1994:[18,31,31,32,31,31,31,30,29,30,29,30,30],1995:[17,31,32,31,32,31,30,30,30,29,29,30,30],1996:[17,31,32,31,32,31,30,30,30,29,30,29,31],1997:[18,31,31,32,31,31,31,30,29,30,29,30,30],1998:[18,31,31,32,31,31,31,30,29,30,29,30,30],1999:[17,31,32,31,32,31,30,30,30,29,29,30,31],2000:[17,30,32,31,32,31,30,30,30,29,30,29,31],2001:[18,31,31,32,31,31,31,30,29,30,29,30,30],2002:[18,31,31,32,32,31,30,30,29,30,29,30,30],2003:[17,31,32,31,32,31,30,30,30,29,29,30,31],2004:[17,30,32,31,32,31,30,30,30,29,30,29,31],2005:[18,31,31,32,31,31,31,30,29,30,29,30,30],2006:[18,31,31,32,32,31,30,30,29,30,29,30,30],2007:[17,31,32,31,32,31,30,30,30,29,29,30,31],2008:[17,31,31,31,32,31,31,29,30,30,29,29,31],2009:[18,31,31,32,31,31,31,30,29,30,29,30,30],2010:[18,31,31,32,32,31,30,30,29,30,29,30,30],2011:[17,31,32,31,32,31,30,30,30,29,29,30,31],2012:[17,31,31,31,32,31,31,29,30,30,29,30,30],2013:[18,31,31,32,31,31,31,30,29,30,29,30,30],2014:[18,31,31,32,32,31,30,30,29,30,29,30,30],2015:[17,31,32,31,32,31,30,30,30,29,29,30,31],2016:[17,31,31,31,32,31,31,29,30,30,29,30,30],2017:[18,31,31,32,31,31,31,30,29,30,29,30,30],2018:[18,31,32,31,32,31,30,30,29,30,29,30,30],2019:[17,31,32,31,32,31,30,30,30,29,30,29,31],2020:[17,31,31,31,32,31,31,30,29,30,29,30,30],2021:[18,31,31,32,31,31,31,30,29,30,29,30,30],2022:[17,31,32,31,32,31,30,30,30,29,29,30,30],2023:[17,31,32,31,32,31,30,30,30,29,30,29,31],2024:[17,31,31,31,32,31,31,30,29,30,29,30,30],2025:[18,31,31,32,31,31,31,30,29,30,29,30,30],2026:[17,31,32,31,32,31,30,30,30,29,29,30,31],2027:[17,30,32,31,32,31,30,30,30,29,30,29,31],2028:[17,31,31,32,31,31,31,30,29,30,29,30,30],2029:[18,31,31,32,31,32,30,30,29,30,29,30,30],2030:[17,31,32,31,32,31,30,30,30,30,30,30,31],2031:[17,31,32,31,32,31,31,31,31,31,31,31,31],2032:[17,32,32,32,32,32,32,32,32,32,32,32,32],2033:[18,31,31,32,32,31,30,30,29,30,29,30,30],2034:[17,31,32,31,32,31,30,30,30,29,29,30,31],2035:[17,30,32,31,32,31,31,29,30,30,29,29,31],2036:[17,31,31,32,31,31,31,30,29,30,29,30,30],2037:[18,31,31,32,32,31,30,30,29,30,29,30,30],2038:[17,31,32,31,32,31,30,30,30,29,29,30,31],2039:[17,31,31,31,32,31,31,29,30,30,29,30,30],2040:[17,31,31,32,31,31,31,30,29,30,29,30,30],2041:[18,31,31,32,32,31,30,30,29,30,29,30,30],2042:[17,31,32,31,32,31,30,30,30,29,29,30,31],2043:[17,31,31,31,32,31,31,29,30,30,29,30,30],2044:[17,31,31,32,31,31,31,30,29,30,29,30,30],2045:[18,31,32,31,32,31,30,30,29,30,29,30,30],2046:[17,31,32,31,32,31,30,30,30,29,29,30,31],2047:[17,31,31,31,32,31,31,30,29,30,29,30,30],2048:[17,31,31,32,31,31,31,30,29,30,29,30,30],2049:[17,31,32,31,32,31,30,30,30,29,29,30,30],2050:[17,31,32,31,32,31,30,30,30,29,30,29,31],2051:[17,31,31,31,32,31,31,30,29,30,29,30,30],2052:[17,31,31,32,31,31,31,30,29,30,29,30,30],2053:[17,31,32,31,32,31,30,30,30,29,29,30,30],2054:[17,31,32,31,32,31,30,30,30,29,30,29,31],2055:[17,31,31,32,31,31,31,30,29,30,30,29,30],2056:[17,31,31,32,31,32,30,30,29,30,29,30,30],2057:[17,31,32,31,32,31,30,30,30,29,29,30,31],2058:[17,30,32,31,32,31,30,30,30,29,30,29,31],2059:[17,31,31,32,31,31,31,30,29,30,29,30,30],2060:[17,31,31,32,32,31,30,30,29,30,29,30,30],2061:[17,31,32,31,32,31,30,30,30,29,29,30,31],2062:[17,30,32,31,32,31,31,29,30,29,30,29,31],2063:[17,31,31,32,31,31,31,30,29,30,29,30,30],2064:[17,31,31,32,32,31,30,30,29,30,29,30,30],2065:[17,31,32,31,32,31,30,30,30,29,29,30,31],2066:[17,31,31,31,32,31,31,29,30,30,29,29,31],2067:[17,31,31,32,31,31,31,30,29,30,29,30,30],2068:[17,31,31,32,32,31,30,30,29,30,29,30,30],2069:[17,31,32,31,32,31,30,30,30,29,29,30,31],2070:[17,31,31,31,32,31,31,29,30,30,29,30,30],2071:[17,31,31,32,31,31,31,30,29,30,29,30,30],2072:[17,31,32,31,32,31,30,30,29,30,29,30,30],2073:[17,31,32,31,32,31,30,30,30,29,29,30,31],2074:[17,31,31,31,32,31,31,30,29,30,29,30,30],2075:[17,31,31,32,31,31,31,30,29,30,29,30,30],2076:[16,31,32,31,32,31,30,30,30,29,29,30,30],2077:[17,31,32,31,32,31,30,30,30,29,30,29,31],2078:[17,31,31,31,32,31,31,30,29,30,29,30,30],2079:[17,31,31,32,31,31,31,30,29,30,29,30,30],2080:[16,31,32,31,32,31,30,30,30,29,29,30,30],2081:[17,31,31,32,32,31,30,30,30,29,30,30,30],2082:[17,31,32,31,32,31,30,30,30,29,30,30,30],2083:[17,31,31,32,31,31,30,30,30,29,30,30,30],2084:[17,31,31,32,31,31,30,30,30,29,30,30,30],2085:[17,31,32,31,32,31,31,30,30,29,30,30,30],2086:[17,31,32,31,32,31,30,30,30,29,30,30,30],2087:[16,31,31,32,31,31,31,30,30,29,30,30,30],2088:[16,30,31,32,32,30,31,30,30,29,30,30,30],2089:[17,31,32,31,32,31,30,30,30,29,30,30,30],2090:[17,31,32,31,32,31,30,30,30,29,30,30,30],2091:[16,31,31,32,31,31,31,30,30,29,30,30,30],2092:[16,31,31,32,32,31,30,30,30,29,30,30,30],2093:[17,31,32,31,32,31,30,30,30,29,30,30,30],2094:[17,31,31,32,31,31,30,30,30,29,30,30,30],2095:[17,31,31,32,31,31,31,30,29,30,30,30,30],2096:[17,30,31,32,32,31,30,30,29,30,29,30,30],2097:[17,31,32,31,32,31,30,30,30,29,30,30,30],2098:[17,31,31,32,31,31,31,29,30,29,30,30,31],2099:[17,31,31,32,31,31,31,30,29,29,30,30,30],2100:[17,31,32,31,32,30,31,30,29,30,29,30,30]}}),n.calendars.nepali=a},{\"../main\":571,\"object-assign\":454}],567:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Persian\",jdEpoch:1948320.5,daysPerMonth:[31,31,31,31,31,31,30,30,30,30,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Persian\",epochs:[\"BP\",\"AP\"],monthNames:[\"Farvardin\",\"Ordibehesht\",\"Khordad\",\"Tir\",\"Mordad\",\"Shahrivar\",\"Mehr\",\"Aban\",\"Azar\",\"Day\",\"Bahman\",\"Esfand\"],monthNamesShort:[\"Far\",\"Ord\",\"Kho\",\"Tir\",\"Mor\",\"Sha\",\"Meh\",\"Aba\",\"Aza\",\"Day\",\"Bah\",\"Esf\"],dayNames:[\"Yekshambe\",\"Doshambe\",\"Seshambe\",\"Ch\\xe6harshambe\",\"Panjshambe\",\"Jom'e\",\"Shambe\"],dayNamesShort:[\"Yek\",\"Do\",\"Se\",\"Ch\\xe6\",\"Panj\",\"Jom\",\"Sha\"],dayNamesMin:[\"Ye\",\"Do\",\"Se\",\"Ch\",\"Pa\",\"Jo\",\"Sh\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 682*((e.year()-(e.year()>0?474:473))%2820+474+38)%2816<682},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-(n.dayOfWeek()+1)%7,\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t-(t>=0?474:473),s=474+o(a,2820);return r+(e<=7?31*(e-1):30*(e-1)+6)+Math.floor((682*s-110)/2816)+365*(s-1)+1029983*Math.floor(a/2820)+this.jdEpoch-1},fromJD:function(t){var e=(t=Math.floor(t)+.5)-this.toJD(475,1,1),r=Math.floor(e/1029983),n=o(e,1029983),i=2820;if(1029982!==n){var a=Math.floor(n/366),s=o(n,366);i=Math.floor((2134*a+2816*s+2815)/1028522)+a+1}var l=i+2820*r+474;l=l<=0?l-1:l;var c=t-this.toJD(l,1,1)+1,u=c<=186?Math.ceil(c/31):Math.ceil((c-6)/30),h=t-this.toJD(l,u,1)+1;return this.newDate(l,u,h)}}),n.calendars.persian=a,n.calendars.jalali=a},{\"../main\":571,\"object-assign\":454}],568:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Taiwan\",jdEpoch:2419402.5,yearsOffset:1911,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Taiwan\",epochs:[\"BROC\",\"ROC\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)},_g2tYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)}}),n.calendars.taiwan=o},{\"../main\":571,\"object-assign\":454}],569:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Thai\",jdEpoch:1523098.5,yearsOffset:543,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Thai\",epochs:[\"BBE\",\"BE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)},_g2tYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)}}),n.calendars.thai=o},{\"../main\":571,\"object-assign\":454}],570:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"UmmAlQura\",hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Umm al-Qura\",epochs:[\"BH\",\"AH\"],monthNames:[\"Al-Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' Al-Thani\",\"Jumada Al-Awwal\",\"Jumada Al-Thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-Ahad\",\"Yawm al-Ithnain\",\"Yawm al-Thal\\u0101th\\u0101\\u2019\",\"Yawm al-Arba\\u2018\\u0101\\u2019\",\"Yawm al-Kham\\u012bs\",\"Yawm al-Jum\\u2018a\",\"Yawm al-Sabt\"],dayNamesMin:[\"Ah\",\"Ith\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!0}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 355===this.daysInYear(e.year())},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){for(var e=0,r=1;r<=12;r++)e+=this.daysInMonth(t,r);return e},daysInMonth:function(t,e){for(var r=this._validate(t,e,this.minDay,n.local.invalidMonth).toJD()-24e5+.5,i=0,a=0;a<o.length;a++){if(o[a]>r)return o[i]-o[i-1];i++}return 30},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate),a=12*(i.year()-1)+i.month()-15292;return i.day()+o[a-1]-1+24e5-.5},fromJD:function(t){for(var e=t-24e5+.5,r=0,n=0;n<o.length&&!(o[n]>e);n++)r++;var i=r+15292,a=Math.floor((i-1)/12),s=a+1,l=i-12*a,c=e-o[r-1]+1;return this.newDate(s,l,c)},isValid:function(t,e,r){var i=n.baseCalendar.prototype.isValid.apply(this,arguments);return i&&(i=(t=null!=t.year?t.year:t)>=1276&&t<=1500),i},_validate:function(t,e,r,i){var a=n.baseCalendar.prototype._validate.apply(this,arguments);if(a.year<1276||a.year>1500)throw i.replace(/\\{0\\}/,this.local.name);return a}}),n.calendars.ummalqura=a;var o=[20,50,79,109,138,168,197,227,256,286,315,345,374,404,433,463,492,522,551,581,611,641,670,700,729,759,788,818,847,877,906,936,965,995,1024,1054,1083,1113,1142,1172,1201,1231,1260,1290,1320,1350,1379,1409,1438,1468,1497,1527,1556,1586,1615,1645,1674,1704,1733,1763,1792,1822,1851,1881,1910,1940,1969,1999,2028,2058,2087,2117,2146,2176,2205,2235,2264,2294,2323,2353,2383,2413,2442,2472,2501,2531,2560,2590,2619,2649,2678,2708,2737,2767,2796,2826,2855,2885,2914,2944,2973,3003,3032,3062,3091,3121,3150,3180,3209,3239,3268,3298,3327,3357,3386,3416,3446,3476,3505,3535,3564,3594,3623,3653,3682,3712,3741,3771,3800,3830,3859,3889,3918,3948,3977,4007,4036,4066,4095,4125,4155,4185,4214,4244,4273,4303,4332,4362,4391,4421,4450,4480,4509,4539,4568,4598,4627,4657,4686,4716,4745,4775,4804,4834,4863,4893,4922,4952,4981,5011,5040,5070,5099,5129,5158,5188,5218,5248,5277,5307,5336,5366,5395,5425,5454,5484,5513,5543,5572,5602,5631,5661,5690,5720,5749,5779,5808,5838,5867,5897,5926,5956,5985,6015,6044,6074,6103,6133,6162,6192,6221,6251,6281,6311,6340,6370,6399,6429,6458,6488,6517,6547,6576,6606,6635,6665,6694,6724,6753,6783,6812,6842,6871,6901,6930,6960,6989,7019,7048,7078,7107,7137,7166,7196,7225,7255,7284,7314,7344,7374,7403,7433,7462,7492,7521,7551,7580,7610,7639,7669,7698,7728,7757,7787,7816,7846,7875,7905,7934,7964,7993,8023,8053,8083,8112,8142,8171,8201,8230,8260,8289,8319,8348,8378,8407,8437,8466,8496,8525,8555,8584,8614,8643,8673,8702,8732,8761,8791,8821,8850,8880,8909,8938,8968,8997,9027,9056,9086,9115,9145,9175,9205,9234,9264,9293,9322,9352,9381,9410,9440,9470,9499,9529,9559,9589,9618,9648,9677,9706,9736,9765,9794,9824,9853,9883,9913,9943,9972,10002,10032,10061,10090,10120,10149,10178,10208,10237,10267,10297,10326,10356,10386,10415,10445,10474,10504,10533,10562,10592,10621,10651,10680,10710,10740,10770,10799,10829,10858,10888,10917,10947,10976,11005,11035,11064,11094,11124,11153,11183,11213,11242,11272,11301,11331,11360,11389,11419,11448,11478,11507,11537,11567,11596,11626,11655,11685,11715,11744,11774,11803,11832,11862,11891,11921,11950,11980,12010,12039,12069,12099,12128,12158,12187,12216,12246,12275,12304,12334,12364,12393,12423,12453,12483,12512,12542,12571,12600,12630,12659,12688,12718,12747,12777,12807,12837,12866,12896,12926,12955,12984,13014,13043,13072,13102,13131,13161,13191,13220,13250,13280,13310,13339,13368,13398,13427,13456,13486,13515,13545,13574,13604,13634,13664,13693,13723,13752,13782,13811,13840,13870,13899,13929,13958,13988,14018,14047,14077,14107,14136,14166,14195,14224,14254,14283,14313,14342,14372,14401,14431,14461,14490,14520,14550,14579,14609,14638,14667,14697,14726,14756,14785,14815,14844,14874,14904,14933,14963,14993,15021,15051,15081,15110,15140,15169,15199,15228,15258,15287,15317,15347,15377,15406,15436,15465,15494,15524,15553,15582,15612,15641,15671,15701,15731,15760,15790,15820,15849,15878,15908,15937,15966,15996,16025,16055,16085,16114,16144,16174,16204,16233,16262,16292,16321,16350,16380,16409,16439,16468,16498,16528,16558,16587,16617,16646,16676,16705,16734,16764,16793,16823,16852,16882,16912,16941,16971,17001,17030,17060,17089,17118,17148,17177,17207,17236,17266,17295,17325,17355,17384,17414,17444,17473,17502,17532,17561,17591,17620,17650,17679,17709,17738,17768,17798,17827,17857,17886,17916,17945,17975,18004,18034,18063,18093,18122,18152,18181,18211,18241,18270,18300,18330,18359,18388,18418,18447,18476,18506,18535,18565,18595,18625,18654,18684,18714,18743,18772,18802,18831,18860,18890,18919,18949,18979,19008,19038,19068,19098,19127,19156,19186,19215,19244,19274,19303,19333,19362,19392,19422,19452,19481,19511,19540,19570,19599,19628,19658,19687,19717,19746,19776,19806,19836,19865,19895,19924,19954,19983,20012,20042,20071,20101,20130,20160,20190,20219,20249,20279,20308,20338,20367,20396,20426,20455,20485,20514,20544,20573,20603,20633,20662,20692,20721,20751,20780,20810,20839,20869,20898,20928,20957,20987,21016,21046,21076,21105,21135,21164,21194,21223,21253,21282,21312,21341,21371,21400,21430,21459,21489,21519,21548,21578,21607,21637,21666,21696,21725,21754,21784,21813,21843,21873,21902,21932,21962,21991,22021,22050,22080,22109,22138,22168,22197,22227,22256,22286,22316,22346,22375,22405,22434,22464,22493,22522,22552,22581,22611,22640,22670,22700,22730,22759,22789,22818,22848,22877,22906,22936,22965,22994,23024,23054,23083,23113,23143,23173,23202,23232,23261,23290,23320,23349,23379,23408,23438,23467,23497,23527,23556,23586,23616,23645,23674,23704,23733,23763,23792,23822,23851,23881,23910,23940,23970,23999,24029,24058,24088,24117,24147,24176,24206,24235,24265,24294,24324,24353,24383,24413,24442,24472,24501,24531,24560,24590,24619,24648,24678,24707,24737,24767,24796,24826,24856,24885,24915,24944,24974,25003,25032,25062,25091,25121,25150,25180,25210,25240,25269,25299,25328,25358,25387,25416,25446,25475,25505,25534,25564,25594,25624,25653,25683,25712,25742,25771,25800,25830,25859,25888,25918,25948,25977,26007,26037,26067,26096,26126,26155,26184,26214,26243,26272,26302,26332,26361,26391,26421,26451,26480,26510,26539,26568,26598,26627,26656,26686,26715,26745,26775,26805,26834,26864,26893,26923,26952,26982,27011,27041,27070,27099,27129,27159,27188,27218,27248,27277,27307,27336,27366,27395,27425,27454,27484,27513,27542,27572,27602,27631,27661,27691,27720,27750,27779,27809,27838,27868,27897,27926,27956,27985,28015,28045,28074,28104,28134,28163,28193,28222,28252,28281,28310,28340,28369,28399,28428,28458,28488,28517,28547,28577,28607,28636,28665,28695,28724,28754,28783,28813,28843,28872,28901,28931,28960,28990,29019,29049,29078,29108,29137,29167,29196,29226,29255,29285,29315,29345,29375,29404,29434,29463,29492,29522,29551,29580,29610,29640,29669,29699,29729,29759,29788,29818,29847,29876,29906,29935,29964,29994,30023,30053,30082,30112,30141,30171,30200,30230,30259,30289,30318,30348,30378,30408,30437,30467,30496,30526,30555,30585,30614,30644,30673,30703,30732,30762,30791,30821,30850,30880,30909,30939,30968,30998,31027,31057,31086,31116,31145,31175,31204,31234,31263,31293,31322,31352,31381,31411,31441,31471,31500,31530,31559,31589,31618,31648,31676,31706,31736,31766,31795,31825,31854,31884,31913,31943,31972,32002,32031,32061,32090,32120,32150,32180,32209,32239,32268,32298,32327,32357,32386,32416,32445,32475,32504,32534,32563,32593,32622,32652,32681,32711,32740,32770,32799,32829,32858,32888,32917,32947,32976,33006,33035,33065,33094,33124,33153,33183,33213,33243,33272,33302,33331,33361,33390,33420,33450,33479,33509,33539,33568,33598,33627,33657,33686,33716,33745,33775,33804,33834,33863,33893,33922,33952,33981,34011,34040,34069,34099,34128,34158,34187,34217,34247,34277,34306,34336,34365,34395,34424,34454,34483,34512,34542,34571,34601,34631,34660,34690,34719,34749,34778,34808,34837,34867,34896,34926,34955,34985,35015,35044,35074,35103,35133,35162,35192,35222,35251,35280,35310,35340,35370,35399,35429,35458,35488,35517,35547,35576,35605,35635,35665,35694,35723,35753,35782,35811,35841,35871,35901,35930,35960,35989,36019,36048,36078,36107,36136,36166,36195,36225,36254,36284,36314,36343,36373,36403,36433,36462,36492,36521,36551,36580,36610,36639,36669,36698,36728,36757,36786,36816,36845,36875,36904,36934,36963,36993,37022,37052,37081,37111,37141,37170,37200,37229,37259,37288,37318,37347,37377,37406,37436,37465,37495,37524,37554,37584,37613,37643,37672,37701,37731,37760,37790,37819,37849,37878,37908,37938,37967,37997,38027,38056,38085,38115,38144,38174,38203,38233,38262,38292,38322,38351,38381,38410,38440,38469,38499,38528,38558,38587,38617,38646,38676,38705,38735,38764,38794,38823,38853,38882,38912,38941,38971,39001,39030,39059,39089,39118,39148,39178,39208,39237,39267,39297,39326,39355,39385,39414,39444,39473,39503,39532,39562,39592,39621,39650,39680,39709,39739,39768,39798,39827,39857,39886,39916,39946,39975,40005,40035,40064,40094,40123,40153,40182,40212,40241,40271,40300,40330,40359,40389,40418,40448,40477,40507,40536,40566,40595,40625,40655,40685,40714,40744,40773,40803,40832,40862,40892,40921,40951,40980,41009,41039,41068,41098,41127,41157,41186,41216,41245,41275,41304,41334,41364,41393,41422,41452,41481,41511,41540,41570,41599,41629,41658,41688,41718,41748,41777,41807,41836,41865,41894,41924,41953,41983,42012,42042,42072,42102,42131,42161,42190,42220,42249,42279,42308,42337,42367,42397,42426,42456,42485,42515,42545,42574,42604,42633,42662,42692,42721,42751,42780,42810,42839,42869,42899,42929,42958,42988,43017,43046,43076,43105,43135,43164,43194,43223,43253,43283,43312,43342,43371,43401,43430,43460,43489,43519,43548,43578,43607,43637,43666,43696,43726,43755,43785,43814,43844,43873,43903,43932,43962,43991,44021,44050,44080,44109,44139,44169,44198,44228,44258,44287,44317,44346,44375,44405,44434,44464,44493,44523,44553,44582,44612,44641,44671,44700,44730,44759,44788,44818,44847,44877,44906,44936,44966,44996,45025,45055,45084,45114,45143,45172,45202,45231,45261,45290,45320,45350,45380,45409,45439,45468,45498,45527,45556,45586,45615,45644,45674,45704,45733,45763,45793,45823,45852,45882,45911,45940,45970,45999,46028,46058,46088,46117,46147,46177,46206,46236,46265,46295,46324,46354,46383,46413,46442,46472,46501,46531,46560,46590,46620,46649,46679,46708,46738,46767,46797,46826,46856,46885,46915,46944,46974,47003,47033,47063,47092,47122,47151,47181,47210,47240,47269,47298,47328,47357,47387,47417,47446,47476,47506,47535,47565,47594,47624,47653,47682,47712,47741,47771,47800,47830,47860,47890,47919,47949,47978,48008,48037,48066,48096,48125,48155,48184,48214,48244,48273,48303,48333,48362,48392,48421,48450,48480,48509,48538,48568,48598,48627,48657,48687,48717,48746,48776,48805,48834,48864,48893,48922,48952,48982,49011,49041,49071,49100,49130,49160,49189,49218,49248,49277,49306,49336,49365,49395,49425,49455,49484,49514,49543,49573,49602,49632,49661,49690,49720,49749,49779,49809,49838,49868,49898,49927,49957,49986,50016,50045,50075,50104,50133,50163,50192,50222,50252,50281,50311,50340,50370,50400,50429,50459,50488,50518,50547,50576,50606,50635,50665,50694,50724,50754,50784,50813,50843,50872,50902,50931,50960,50990,51019,51049,51078,51108,51138,51167,51197,51227,51256,51286,51315,51345,51374,51403,51433,51462,51492,51522,51552,51582,51611,51641,51670,51699,51729,51758,51787,51816,51846,51876,51906,51936,51965,51995,52025,52054,52083,52113,52142,52171,52200,52230,52260,52290,52319,52349,52379,52408,52438,52467,52497,52526,52555,52585,52614,52644,52673,52703,52733,52762,52792,52822,52851,52881,52910,52939,52969,52998,53028,53057,53087,53116,53146,53176,53205,53235,53264,53294,53324,53353,53383,53412,53441,53471,53500,53530,53559,53589,53619,53648,53678,53708,53737,53767,53796,53825,53855,53884,53913,53943,53973,54003,54032,54062,54092,54121,54151,54180,54209,54239,54268,54297,54327,54357,54387,54416,54446,54476,54505,54535,54564,54593,54623,54652,54681,54711,54741,54770,54800,54830,54859,54889,54919,54948,54977,55007,55036,55066,55095,55125,55154,55184,55213,55243,55273,55302,55332,55361,55391,55420,55450,55479,55508,55538,55567,55597,55627,55657,55686,55716,55745,55775,55804,55834,55863,55892,55922,55951,55981,56011,56040,56070,56100,56129,56159,56188,56218,56247,56276,56306,56335,56365,56394,56424,56454,56483,56513,56543,56572,56601,56631,56660,56690,56719,56749,56778,56808,56837,56867,56897,56926,56956,56985,57015,57044,57074,57103,57133,57162,57192,57221,57251,57280,57310,57340,57369,57399,57429,57458,57487,57517,57546,57576,57605,57634,57664,57694,57723,57753,57783,57813,57842,57871,57901,57930,57959,57989,58018,58048,58077,58107,58137,58167,58196,58226,58255,58285,58314,58343,58373,58402,58432,58461,58491,58521,58551,58580,58610,58639,58669,58698,58727,58757,58786,58816,58845,58875,58905,58934,58964,58994,59023,59053,59082,59111,59141,59170,59200,59229,59259,59288,59318,59348,59377,59407,59436,59466,59495,59525,59554,59584,59613,59643,59672,59702,59731,59761,59791,59820,59850,59879,59909,59939,59968,59997,60027,60056,60086,60115,60145,60174,60204,60234,60264,60293,60323,60352,60381,60411,60440,60469,60499,60528,60558,60588,60618,60648,60677,60707,60736,60765,60795,60824,60853,60883,60912,60942,60972,61002,61031,61061,61090,61120,61149,61179,61208,61237,61267,61296,61326,61356,61385,61415,61445,61474,61504,61533,61563,61592,61621,61651,61680,61710,61739,61769,61799,61828,61858,61888,61917,61947,61976,62006,62035,62064,62094,62123,62153,62182,62212,62242,62271,62301,62331,62360,62390,62419,62448,62478,62507,62537,62566,62596,62625,62655,62685,62715,62744,62774,62803,62832,62862,62891,62921,62950,62980,63009,63039,63069,63099,63128,63157,63187,63216,63246,63275,63305,63334,63363,63393,63423,63453,63482,63512,63541,63571,63600,63630,63659,63689,63718,63747,63777,63807,63836,63866,63895,63925,63955,63984,64014,64043,64073,64102,64131,64161,64190,64220,64249,64279,64309,64339,64368,64398,64427,64457,64486,64515,64545,64574,64603,64633,64663,64692,64722,64752,64782,64811,64841,64870,64899,64929,64958,64987,65017,65047,65076,65106,65136,65166,65195,65225,65254,65283,65313,65342,65371,65401,65431,65460,65490,65520,65549,65579,65608,65638,65667,65697,65726,65755,65785,65815,65844,65874,65903,65933,65963,65992,66022,66051,66081,66110,66140,66169,66199,66228,66258,66287,66317,66346,66376,66405,66435,66465,66494,66524,66553,66583,66612,66641,66671,66700,66730,66760,66789,66819,66849,66878,66908,66937,66967,66996,67025,67055,67084,67114,67143,67173,67203,67233,67262,67292,67321,67351,67380,67409,67439,67468,67497,67527,67557,67587,67617,67646,67676,67705,67735,67764,67793,67823,67852,67882,67911,67941,67971,68e3,68030,68060,68089,68119,68148,68177,68207,68236,68266,68295,68325,68354,68384,68414,68443,68473,68502,68532,68561,68591,68620,68650,68679,68708,68738,68768,68797,68827,68857,68886,68916,68946,68975,69004,69034,69063,69092,69122,69152,69181,69211,69240,69270,69300,69330,69359,69388,69418,69447,69476,69506,69535,69565,69595,69624,69654,69684,69713,69743,69772,69802,69831,69861,69890,69919,69949,69978,70008,70038,70067,70097,70126,70156,70186,70215,70245,70274,70303,70333,70362,70392,70421,70451,70481,70510,70540,70570,70599,70629,70658,70687,70717,70746,70776,70805,70835,70864,70894,70924,70954,70983,71013,71042,71071,71101,71130,71159,71189,71218,71248,71278,71308,71337,71367,71397,71426,71455,71485,71514,71543,71573,71602,71632,71662,71691,71721,71751,71781,71810,71839,71869,71898,71927,71957,71986,72016,72046,72075,72105,72135,72164,72194,72223,72253,72282,72311,72341,72370,72400,72429,72459,72489,72518,72548,72577,72607,72637,72666,72695,72725,72754,72784,72813,72843,72872,72902,72931,72961,72991,73020,73050,73080,73109,73139,73168,73197,73227,73256,73286,73315,73345,73375,73404,73434,73464,73493,73523,73552,73581,73611,73640,73669,73699,73729,73758,73788,73818,73848,73877,73907,73936,73965,73995,74024,74053,74083,74113,74142,74172,74202,74231,74261,74291,74320,74349,74379,74408,74437,74467,74497,74526,74556,74586,74615,74645,74675,74704,74733,74763,74792,74822,74851,74881,74910,74940,74969,74999,75029,75058,75088,75117,75147,75176,75206,75235,75264,75294,75323,75353,75383,75412,75442,75472,75501,75531,75560,75590,75619,75648,75678,75707,75737,75766,75796,75826,75856,75885,75915,75944,75974,76003,76032,76062,76091,76121,76150,76180,76210,76239,76269,76299,76328,76358,76387,76416,76446,76475,76505,76534,76564,76593,76623,76653,76682,76712,76741,76771,76801,76830,76859,76889,76918,76948,76977,77007,77036,77066,77096,77125,77155,77185,77214,77243,77273,77302,77332,77361,77390,77420,77450,77479,77509,77539,77569,77598,77627,77657,77686,77715,77745,77774,77804,77833,77863,77893,77923,77952,77982,78011,78041,78070,78099,78129,78158,78188,78217,78247,78277,78307,78336,78366,78395,78425,78454,78483,78513,78542,78572,78601,78631,78661,78690,78720,78750,78779,78808,78838,78867,78897,78926,78956,78985,79015,79044,79074,79104,79133,79163,79192,79222,79251,79281,79310,79340,79369,79399,79428,79458,79487,79517,79546,79576,79606,79635,79665,79695,79724,79753,79783,79812,79841,79871,79900,79930,79960,79990]},{\"../main\":571,\"object-assign\":454}],571:[function(t,e,r){var n=t(\"object-assign\");function i(){this.regionalOptions=[],this.regionalOptions[\"\"]={invalidCalendar:\"Calendar {0} not found\",invalidDate:\"Invalid {0} date\",invalidMonth:\"Invalid {0} month\",invalidYear:\"Invalid {0} year\",differentCalendars:\"Cannot mix {0} and {1} dates\"},this.local=this.regionalOptions[\"\"],this.calendars={},this._localCals={}}function a(t,e,r,n){if(this._calendar=t,this._year=e,this._month=r,this._day=n,0===this._calendar._validateLevel&&!this._calendar.isValid(this._year,this._month,this._day))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name)}function o(t,e){return\"000000\".substring(0,e-(t=\"\"+t).length)+t}function s(){this.shortYearCutoff=\"+10\"}function l(t){this.local=this.regionalOptions[t]||this.regionalOptions[\"\"]}n(i.prototype,{instance:function(t,e){t=(t||\"gregorian\").toLowerCase(),e=e||\"\";var r=this._localCals[t+\"-\"+e];if(!r&&this.calendars[t]&&(r=new this.calendars[t](e),this._localCals[t+\"-\"+e]=r),!r)throw(this.local.invalidCalendar||this.regionalOptions[\"\"].invalidCalendar).replace(/\\{0\\}/,t);return r},newDate:function(t,e,r,n,i){return(n=(null!=t&&t.year?t.calendar():\"string\"==typeof n?this.instance(n,i):n)||this.instance()).newDate(t,e,r)},substituteDigits:function(t){return function(e){return(e+\"\").replace(/[0-9]/g,function(e){return t[e]})}},substituteChineseDigits:function(t,e){return function(r){for(var n=\"\",i=0;r>0;){var a=r%10;n=(0===a?\"\":t[a]+e[i])+n,i++,r=Math.floor(r/10)}return 0===n.indexOf(t[1]+e[1])&&(n=n.substr(1)),n||t[0]}}}),n(a.prototype,{newDate:function(t,e,r){return this._calendar.newDate(null==t?this:t,e,r)},year:function(t){return 0===arguments.length?this._year:this.set(t,\"y\")},month:function(t){return 0===arguments.length?this._month:this.set(t,\"m\")},day:function(t){return 0===arguments.length?this._day:this.set(t,\"d\")},date:function(t,e,r){if(!this._calendar.isValid(t,e,r))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name);return this._year=t,this._month=e,this._day=r,this},leapYear:function(){return this._calendar.leapYear(this)},epoch:function(){return this._calendar.epoch(this)},formatYear:function(){return this._calendar.formatYear(this)},monthOfYear:function(){return this._calendar.monthOfYear(this)},weekOfYear:function(){return this._calendar.weekOfYear(this)},daysInYear:function(){return this._calendar.daysInYear(this)},dayOfYear:function(){return this._calendar.dayOfYear(this)},daysInMonth:function(){return this._calendar.daysInMonth(this)},dayOfWeek:function(){return this._calendar.dayOfWeek(this)},weekDay:function(){return this._calendar.weekDay(this)},extraInfo:function(){return this._calendar.extraInfo(this)},add:function(t,e){return this._calendar.add(this,t,e)},set:function(t,e){return this._calendar.set(this,t,e)},compareTo:function(t){if(this._calendar.name!==t._calendar.name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this._calendar.local.name).replace(/\\{1\\}/,t._calendar.local.name);var e=this._year!==t._year?this._year-t._year:this._month!==t._month?this.monthOfYear()-t.monthOfYear():this._day-t._day;return 0===e?0:e<0?-1:1},calendar:function(){return this._calendar},toJD:function(){return this._calendar.toJD(this)},fromJD:function(t){return this._calendar.fromJD(t)},toJSDate:function(){return this._calendar.toJSDate(this)},fromJSDate:function(t){return this._calendar.fromJSDate(t)},toString:function(){return(this.year()<0?\"-\":\"\")+o(Math.abs(this.year()),4)+\"-\"+o(this.month(),2)+\"-\"+o(this.day(),2)}}),n(s.prototype,{_validateLevel:0,newDate:function(t,e,r){return null==t?this.today():(t.year&&(this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),r=t.day(),e=t.month(),t=t.year()),new a(this,t,e,r))},today:function(){return this.fromJSDate(new Date)},epoch:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear).year()<0?this.local.epochs[0]:this.local.epochs[1]},formatYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(e.year()<0?\"-\":\"\")+o(Math.abs(e.year()),4)},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear),12},monthOfYear:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return(r.month()+this.monthsInYear(r)-this.firstMonth)%this.monthsInYear(r)+this.minMonth},fromMonthOfYear:function(t,e){var r=(e+this.firstMonth-2*this.minMonth)%this.monthsInYear(t)+this.minMonth;return this._validate(t,r,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth),r},daysInYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return this.leapYear(e)?366:365},dayOfYear:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return n.toJD()-this.newDate(n.year(),this.fromMonthOfYear(n.year(),this.minMonth),this.minDay).toJD()+1},daysInWeek:function(){return 7},dayOfWeek:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return(Math.floor(this.toJD(n))+2)%this.daysInWeek()},extraInfo:function(t,e,r){return this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),{}},add:function(t,e,r){return this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),this._correctAdd(t,this._add(t,e,r),e,r)},_add:function(t,e,r){if(this._validateLevel++,\"d\"===r||\"w\"===r){var n=t.toJD()+e*(\"w\"===r?this.daysInWeek():1),i=t.calendar().fromJD(n);return this._validateLevel--,[i.year(),i.month(),i.day()]}try{var a=t.year()+(\"y\"===r?e:0),o=t.monthOfYear()+(\"m\"===r?e:0);i=t.day();\"y\"===r?(t.month()!==this.fromMonthOfYear(a,o)&&(o=this.newDate(a,t.month(),this.minDay).monthOfYear()),o=Math.min(o,this.monthsInYear(a)),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o)))):\"m\"===r&&(!function(t){for(;o<t.minMonth;)a--,o+=t.monthsInYear(a);for(var e=t.monthsInYear(a);o>e-1+t.minMonth;)a++,o-=e,e=t.monthsInYear(a)}(this),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o))));var s=[a,this.fromMonthOfYear(a,o),i];return this._validateLevel--,s}catch(t){throw this._validateLevel--,t}},_correctAdd:function(t,e,r,n){if(!(this.hasYearZero||\"y\"!==n&&\"m\"!==n||0!==e[0]&&t.year()>0==e[0]>0)){var i={y:[1,1,\"y\"],m:[1,this.monthsInYear(-1),\"m\"],w:[this.daysInWeek(),this.daysInYear(-1),\"d\"],d:[1,this.daysInYear(-1),\"d\"]}[n],a=r<0?-1:1;e=this._add(t,r*i[0]+a*i[1],i[2])}return t.date(e[0],e[1],e[2])},set:function(t,e,r){this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);var n=\"y\"===r?e:t.year(),i=\"m\"===r?e:t.month(),a=\"d\"===r?e:t.day();return\"y\"!==r&&\"m\"!==r||(a=Math.min(a,this.daysInMonth(n,i))),t.date(n,i,a)},isValid:function(t,e,r){this._validateLevel++;var n=this.hasYearZero||0!==t;if(n){var i=this.newDate(t,e,this.minDay);n=e>=this.minMonth&&e-this.minMonth<this.monthsInYear(i)&&r>=this.minDay&&r-this.minDay<this.daysInMonth(i)}return this._validateLevel--,n},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return c.instance().fromJD(this.toJD(n)).toJSDate()},fromJSDate:function(t){return this.fromJD(c.instance().fromJSDate(t).toJD())},_validate:function(t,e,r,n){if(t.year){if(0===this._validateLevel&&this.name!==t.calendar().name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this.local.name).replace(/\\{1\\}/,t.calendar().local.name);return t}try{if(this._validateLevel++,1===this._validateLevel&&!this.isValid(t,e,r))throw n.replace(/\\{0\\}/,this.local.name);var i=this.newDate(t,e,r);return this._validateLevel--,i}catch(t){throw this._validateLevel--,t}}}),l.prototype=new s,n(l.prototype,{name:\"Gregorian\",jdEpoch:1721425.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Gregorian\",epochs:[\"BCE\",\"CE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==0&&(t%100!=0||t%400==0)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);t=n.year(),e=n.month(),r=n.day(),t<0&&t++,e<3&&(e+=12,t--);var i=Math.floor(t/100),a=2-i+Math.floor(i/4);return Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r+a-1524.5},fromJD:function(t){var e=Math.floor(t+.5),r=Math.floor((e-1867216.25)/36524.25),n=(r=e+1+r-Math.floor(r/4))+1524,i=Math.floor((n-122.1)/365.25),a=Math.floor(365.25*i),o=Math.floor((n-a)/30.6001),s=n-a-Math.floor(30.6001*o),l=o-(o>13.5?13:1),c=i-(l>2.5?4716:4715);return c<=0&&c--,this.newDate(c,l,s)},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),i=new Date(n.year(),n.month()-1,n.day());return i.setHours(0),i.setMinutes(0),i.setSeconds(0),i.setMilliseconds(0),i.setHours(i.getHours()>12?i.getHours()+2:0),i},fromJSDate:function(t){return this.newDate(t.getFullYear(),t.getMonth()+1,t.getDate())}});var c=e.exports=new i;c.cdate=a,c.baseCalendar=s,c.calendars.gregorian=l},{\"object-assign\":454}],572:[function(t,e,r){var n=t(\"object-assign\"),i=t(\"./main\");n(i.regionalOptions[\"\"],{invalidArguments:\"Invalid arguments\",invalidFormat:\"Cannot format a date from another calendar\",missingNumberAt:\"Missing number at position {0}\",unknownNameAt:\"Unknown name at position {0}\",unexpectedLiteralAt:\"Unexpected literal at position {0}\",unexpectedText:\"Additional text found at end\"}),i.local=i.regionalOptions[\"\"],n(i.cdate.prototype,{formatDate:function(t,e){return\"string\"!=typeof t&&(e=t,t=\"\"),this._calendar.formatDate(t||\"\",this,e)}}),n(i.baseCalendar.prototype,{UNIX_EPOCH:i.instance().newDate(1970,1,1).toJD(),SECS_PER_DAY:86400,TICKS_EPOCH:i.instance().jdEpoch,TICKS_PER_DAY:864e9,ATOM:\"yyyy-mm-dd\",COOKIE:\"D, dd M yyyy\",FULL:\"DD, MM d, yyyy\",ISO_8601:\"yyyy-mm-dd\",JULIAN:\"J\",RFC_822:\"D, d M yy\",RFC_850:\"DD, dd-M-yy\",RFC_1036:\"D, d M yy\",RFC_1123:\"D, d M yyyy\",RFC_2822:\"D, d M yyyy\",RSS:\"D, d M yy\",TICKS:\"!\",TIMESTAMP:\"@\",W3C:\"yyyy-mm-dd\",formatDate:function(t,e,r){if(\"string\"!=typeof t&&(r=e,e=t,t=\"\"),!e)return\"\";if(e.calendar()!==this)throw i.local.invalidFormat||i.regionalOptions[\"\"].invalidFormat;t=t||this.local.dateFormat;for(var n,a,o,s,l=(r=r||{}).dayNamesShort||this.local.dayNamesShort,c=r.dayNames||this.local.dayNames,u=r.monthNumbers||this.local.monthNumbers,h=r.monthNamesShort||this.local.monthNamesShort,f=r.monthNames||this.local.monthNames,p=(r.calculateWeek||this.local.calculateWeek,function(e,r){for(var n=1;w+n<t.length&&t.charAt(w+n)===e;)n++;return w+=n-1,Math.floor(n/(r||1))>1}),d=function(t,e,r,n){var i=\"\"+e;if(p(t,n))for(;i.length<r;)i=\"0\"+i;return i},g=this,v=function(t){return\"function\"==typeof u?u.call(g,t,p(\"m\")):x(d(\"m\",t.month(),2))},m=function(t,e){return e?\"function\"==typeof f?f.call(g,t):f[t.month()-g.minMonth]:\"function\"==typeof h?h.call(g,t):h[t.month()-g.minMonth]},y=this.local.digits,x=function(t){return r.localNumbers&&y?y(t):t},b=\"\",_=!1,w=0;w<t.length;w++)if(_)\"'\"!==t.charAt(w)||p(\"'\")?b+=t.charAt(w):_=!1;else switch(t.charAt(w)){case\"d\":b+=x(d(\"d\",e.day(),2));break;case\"D\":b+=(n=\"D\",a=e.dayOfWeek(),o=l,s=c,p(n)?s[a]:o[a]);break;case\"o\":b+=d(\"o\",e.dayOfYear(),3);break;case\"w\":b+=d(\"w\",e.weekOfYear(),2);break;case\"m\":b+=v(e);break;case\"M\":b+=m(e,p(\"M\"));break;case\"y\":b+=p(\"y\",2)?e.year():(e.year()%100<10?\"0\":\"\")+e.year()%100;break;case\"Y\":p(\"Y\",2),b+=e.formatYear();break;case\"J\":b+=e.toJD();break;case\"@\":b+=(e.toJD()-this.UNIX_EPOCH)*this.SECS_PER_DAY;break;case\"!\":b+=(e.toJD()-this.TICKS_EPOCH)*this.TICKS_PER_DAY;break;case\"'\":p(\"'\")?b+=\"'\":_=!0;break;default:b+=t.charAt(w)}return b},parseDate:function(t,e,r){if(null==e)throw i.local.invalidArguments||i.regionalOptions[\"\"].invalidArguments;if(\"\"===(e=\"object\"==typeof e?e.toString():e+\"\"))return null;t=t||this.local.dateFormat;var n=(r=r||{}).shortYearCutoff||this.shortYearCutoff;n=\"string\"!=typeof n?n:this.today().year()%100+parseInt(n,10);for(var a=r.dayNamesShort||this.local.dayNamesShort,o=r.dayNames||this.local.dayNames,s=r.parseMonth||this.local.parseMonth,l=r.monthNumbers||this.local.monthNumbers,c=r.monthNamesShort||this.local.monthNamesShort,u=r.monthNames||this.local.monthNames,h=-1,f=-1,p=-1,d=-1,g=-1,v=!1,m=!1,y=function(e,r){for(var n=1;M+n<t.length&&t.charAt(M+n)===e;)n++;return M+=n-1,Math.floor(n/(r||1))>1},x=function(t,r){var n=y(t,r),a=[2,3,n?4:2,n?4:2,10,11,20][\"oyYJ@!\".indexOf(t)+1],o=new RegExp(\"^-?\\\\d{1,\"+a+\"}\"),s=e.substring(A).match(o);if(!s)throw(i.local.missingNumberAt||i.regionalOptions[\"\"].missingNumberAt).replace(/\\{0\\}/,A);return A+=s[0].length,parseInt(s[0],10)},b=this,_=function(){if(\"function\"==typeof l){y(\"m\");var t=l.call(b,e.substring(A));return A+=t.length,t}return x(\"m\")},w=function(t,r,n,a){for(var o=y(t,a)?n:r,s=0;s<o.length;s++)if(e.substr(A,o[s].length).toLowerCase()===o[s].toLowerCase())return A+=o[s].length,s+b.minMonth;throw(i.local.unknownNameAt||i.regionalOptions[\"\"].unknownNameAt).replace(/\\{0\\}/,A)},k=function(){if(\"function\"==typeof u){var t=y(\"M\")?u.call(b,e.substring(A)):c.call(b,e.substring(A));return A+=t.length,t}return w(\"M\",c,u)},T=function(){if(e.charAt(A)!==t.charAt(M))throw(i.local.unexpectedLiteralAt||i.regionalOptions[\"\"].unexpectedLiteralAt).replace(/\\{0\\}/,A);A++},A=0,M=0;M<t.length;M++)if(m)\"'\"!==t.charAt(M)||y(\"'\")?T():m=!1;else switch(t.charAt(M)){case\"d\":d=x(\"d\");break;case\"D\":w(\"D\",a,o);break;case\"o\":g=x(\"o\");break;case\"w\":x(\"w\");break;case\"m\":p=_();break;case\"M\":p=k();break;case\"y\":var S=M;v=!y(\"y\",2),M=S,f=x(\"y\",2);break;case\"Y\":f=x(\"Y\",2);break;case\"J\":h=x(\"J\")+.5,\".\"===e.charAt(A)&&(A++,x(\"J\"));break;case\"@\":h=x(\"@\")/this.SECS_PER_DAY+this.UNIX_EPOCH;break;case\"!\":h=x(\"!\")/this.TICKS_PER_DAY+this.TICKS_EPOCH;break;case\"*\":A=e.length;break;case\"'\":y(\"'\")?T():m=!0;break;default:T()}if(A<e.length)throw i.local.unexpectedText||i.regionalOptions[\"\"].unexpectedText;if(-1===f?f=this.today().year():f<100&&v&&(f+=-1===n?1900:this.today().year()-this.today().year()%100-(f<=n?0:100)),\"string\"==typeof p&&(p=s.call(this,f,p)),g>-1){p=1,d=g;for(var E=this.daysInMonth(f,p);d>E;E=this.daysInMonth(f,p))p++,d-=E}return h>-1?this.fromJD(h):this.newDate(f,p,d)},determineDate:function(t,e,r,n,i){r&&\"object\"!=typeof r&&(i=n,n=r,r=null),\"string\"!=typeof n&&(i=n,n=\"\");var a=this;return e=e?e.newDate():null,t=null==t?e:\"string\"==typeof t?function(t){try{return a.parseDate(n,t,i)}catch(t){}for(var e=((t=t.toLowerCase()).match(/^c/)&&r?r.newDate():null)||a.today(),o=/([+-]?[0-9]+)\\s*(d|w|m|y)?/g,s=o.exec(t);s;)e.add(parseInt(s[1],10),s[2]||\"d\"),s=o.exec(t);return e}(t):\"number\"==typeof t?isNaN(t)||t===1/0||t===-1/0?e:a.today().add(t,\"d\"):a.newDate(t)}})},{\"./main\":571,\"object-assign\":454}],573:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",{offset:[1],array:0},\"scalar\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\n        var _inline_1_da = _inline_1_arg0_ - _inline_1_arg3_\\n        var _inline_1_db = _inline_1_arg1_ - _inline_1_arg3_\\n        if((_inline_1_da >= 0) !== (_inline_1_db >= 0)) {\\n          _inline_1_arg2_.push(_inline_1_arg4_[0] + 0.5 + 0.5 * (_inline_1_da + _inline_1_db) / (_inline_1_da - _inline_1_db))\\n        }\\n      }\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg3_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[\"_inline_1_da\",\"_inline_1_db\"]},funcName:\"zeroCrossings\"})},{\"cwise-compiler\":146}],574:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=[];return e=+e||0,n(t.hi(t.shape[0]-1),r,e),r};var n=t(\"./lib/zc-core\")},{\"./lib/zc-core\":573}],575:[function(t,e,r){\"use strict\";e.exports=[{path:\"\",backoff:0},{path:\"M-2.4,-3V3L0.6,0Z\",backoff:.6},{path:\"M-3.7,-2.5V2.5L1.3,0Z\",backoff:1.3},{path:\"M-4.45,-3L-1.65,-0.2V0.2L-4.45,3L1.55,0Z\",backoff:1.55},{path:\"M-2.2,-2.2L-0.2,-0.2V0.2L-2.2,2.2L-1.4,3L1.6,0L-1.4,-3Z\",backoff:1.6},{path:\"M-4.4,-2.1L-0.6,-0.2V0.2L-4.4,2.1L-4,3L2,0L-4,-3Z\",backoff:2},{path:\"M2,0A2,2 0 1,1 0,-2A2,2 0 0,1 2,0Z\",backoff:0,noRotate:!0},{path:\"M2,2V-2H-2V2Z\",backoff:0,noRotate:!0}]},{}],576:[function(t,e,r){\"use strict\";var n=t(\"./arrow_paths\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../plots/cartesian/constants\"),o=t(\"../../plot_api/plot_template\").templatedArray;e.exports=o(\"annotation\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},text:{valType:\"string\",editType:\"calc+arraydraw\"},textangle:{valType:\"angle\",dflt:0,editType:\"calc+arraydraw\"},font:i({editType:\"calc+arraydraw\",colorEditType:\"arraydraw\"}),width:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},height:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"center\",editType:\"arraydraw\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"arraydraw\"},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},borderpad:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},showarrow:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},arrowcolor:{valType:\"color\",editType:\"arraydraw\"},arrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},startarrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},arrowside:{valType:\"flaglist\",flags:[\"end\",\"start\"],extras:[\"none\"],dflt:\"end\",editType:\"arraydraw\"},arrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},startarrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},arrowwidth:{valType:\"number\",min:.1,editType:\"calc+arraydraw\"},standoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},startstandoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},ax:{valType:\"any\",editType:\"calc+arraydraw\"},ay:{valType:\"any\",editType:\"calc+arraydraw\"},axref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.x.toString()],editType:\"calc\"},ayref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.y.toString()],editType:\"calc\"},xref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.x.toString()],editType:\"calc\"},x:{valType:\"any\",editType:\"calc+arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"auto\",editType:\"calc+arraydraw\"},xshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.y.toString()],editType:\"calc\"},y:{valType:\"any\",editType:\"calc+arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"calc+arraydraw\"},yshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},clicktoshow:{valType:\"enumerated\",values:[!1,\"onoff\",\"onout\"],dflt:!1,editType:\"arraydraw\"},xclick:{valType:\"any\",editType:\"arraydraw\"},yclick:{valType:\"any\",editType:\"arraydraw\"},hovertext:{valType:\"string\",editType:\"arraydraw\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",editType:\"arraydraw\"},font:i({editType:\"arraydraw\"}),editType:\"arraydraw\"},captureevents:{valType:\"boolean\",editType:\"arraydraw\"},editType:\"calc\",_deprecated:{ref:{valType:\"string\",editType:\"calc\"}}})},{\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773,\"../../plots/font_attributes\":793,\"./arrow_paths\":575}],577:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./draw\").draw;function o(t){var e=t._fullLayout;n.filterVisible(e.annotations).forEach(function(e){var r=i.getFromId(t,e.xref),n=i.getFromId(t,e.yref);e._extremes={},r&&s(e,r),n&&s(e,n)})}function s(t,e){var r,n=e._id,a=n.charAt(0),o=t[a],s=t[\"a\"+a],l=t[a+\"ref\"],c=t[\"a\"+a+\"ref\"],u=t[\"_\"+a+\"padplus\"],h=t[\"_\"+a+\"padminus\"],f={x:1,y:-1}[a]*t[a+\"shift\"],p=3*t.arrowsize*t.arrowwidth||0,d=p+f,g=p-f,v=3*t.startarrowsize*t.arrowwidth||0,m=v+f,y=v-f;if(c===l){var x=i.findExtremes(e,[e.r2c(o)],{ppadplus:d,ppadminus:g}),b=i.findExtremes(e,[e.r2c(s)],{ppadplus:Math.max(u,m),ppadminus:Math.max(h,y)});r={min:[x.min[0],b.min[0]],max:[x.max[0],b.max[0]]}}else m=s?m+s:m,y=s?y-s:y,r=i.findExtremes(e,[e.r2c(o)],{ppadplus:Math.max(u,d,m),ppadminus:Math.max(h,g,y)});t._extremes[n]=r}e.exports=function(t){var e=t._fullLayout;if(n.filterVisible(e.annotations).length&&t._fullData.length)return n.syncOrAsync([a,o],t)}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./draw\":582}],578:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../plot_api/plot_template\").arrayEditor;function o(t,e){var r,n,i,a,o,l,c,u=t._fullLayout.annotations,h=[],f=[],p=[],d=(e||[]).length;for(r=0;r<u.length;r++)if(a=(i=u[r]).clicktoshow){for(n=0;n<d;n++)if(l=(o=e[n]).xaxis,c=o.yaxis,l._id===i.xref&&c._id===i.yref&&l.d2r(o.x)===s(i._xclick,l)&&c.d2r(o.y)===s(i._yclick,c)){(i.visible?\"onout\"===a?f:p:h).push(r);break}n===d&&i.visible&&\"onout\"===a&&f.push(r)}return{on:h,off:f,explicitOff:p}}function s(t,e){return\"log\"===e.type?e.l2r(t):e.d2r(t)}e.exports={hasClickToShow:function(t,e){var r=o(t,e);return r.on.length>0||r.explicitOff.length>0},onClick:function(t,e){var r,s,l=o(t,e),c=l.on,u=l.off.concat(l.explicitOff),h={},f=t._fullLayout.annotations;if(!c.length&&!u.length)return;for(r=0;r<c.length;r++)(s=a(t.layout,\"annotations\",f[c[r]])).modifyItem(\"visible\",!0),n.extendFlat(h,s.getUpdateObj());for(r=0;r<u.length;r++)(s=a(t.layout,\"annotations\",f[u[r]])).modifyItem(\"visible\",!1),n.extendFlat(h,s.getUpdateObj());return i.call(\"update\",t,{},h)}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../registry\":847}],579:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\");e.exports=function(t,e,r,a){a(\"opacity\");var o=a(\"bgcolor\"),s=a(\"bordercolor\"),l=i.opacity(s);a(\"borderpad\");var c=a(\"borderwidth\"),u=a(\"showarrow\");if(a(\"text\",u?\" \":r._dfltTitle.annotation),a(\"textangle\"),n.coerceFont(a,\"font\",r.font),a(\"width\"),a(\"align\"),a(\"height\")&&a(\"valign\"),u){var h,f,p=a(\"arrowside\");-1!==p.indexOf(\"end\")&&(h=a(\"arrowhead\"),f=a(\"arrowsize\")),-1!==p.indexOf(\"start\")&&(a(\"startarrowhead\",h),a(\"startarrowsize\",f)),a(\"arrowcolor\",l?e.bordercolor:i.defaultLine),a(\"arrowwidth\",2*(l&&c||1)),a(\"standoff\"),a(\"startstandoff\")}var d=a(\"hovertext\"),g=r.hoverlabel||{};if(d){var v=a(\"hoverlabel.bgcolor\",g.bgcolor||(i.opacity(o)?i.rgb(o):i.defaultLine)),m=a(\"hoverlabel.bordercolor\",g.bordercolor||i.contrast(v));n.coerceFont(a,\"hoverlabel.font\",{family:g.font.family,size:g.font.size,color:g.font.color||m})}a(\"captureevents\",!!d)}},{\"../../lib\":719,\"../color\":593}],580:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.annotations,h=e._id.charAt(0),f=0;f<u.length;f++)l=u[f],c=\"annotations[\"+f+\"].\",l[h+\"ref\"]===e._id&&p(h),l[\"a\"+h+\"ref\"]===e._id&&p(\"a\"+h);function p(t){var r=l[t],s=null;s=o?i(r,e.range):Math.pow(10,r),n(s)||(s=null),a(c+t,s)}}},{\"../../lib/to_log_range\":745,\"fast-isnumeric\":225}],581:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./common_defaults\"),s=t(\"./attributes\");function l(t,e,r){function a(r,i){return n.coerce(t,e,s,r,i)}var l=a(\"visible\"),c=a(\"clicktoshow\");if(l||c){o(t,e,r,a);for(var u=e.showarrow,h=[\"x\",\"y\"],f=[-10,-30],p={_fullLayout:r},d=0;d<2;d++){var g=h[d],v=i.coerceRef(t,e,p,g,\"\",\"paper\");if(\"paper\"!==v)i.getFromId(p,v)._annIndices.push(e._index);if(i.coercePosition(e,p,a,v,g,.5),u){var m=\"a\"+g,y=i.coerceRef(t,e,p,m,\"pixel\");\"pixel\"!==y&&y!==v&&(y=e[m]=\"pixel\");var x=\"pixel\"===y?f[d]:.4;i.coercePosition(e,p,a,y,m,x)}a(g+\"anchor\"),a(g+\"shift\")}if(n.noneOrAll(t,e,[\"x\",\"y\"]),u&&n.noneOrAll(t,e,[\"ax\",\"ay\"]),c){var b=a(\"xclick\"),_=a(\"yclick\");e._xclick=void 0===b?e.x:i.cleanPosition(b,p,e.xref),e._yclick=void 0===_?e.y:i.cleanPosition(_,p,e.yref)}}}e.exports=function(t,e){a(t,e,{name:\"annotations\",handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"./attributes\":576,\"./common_defaults\":579}],582:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../color\"),c=t(\"../drawing\"),u=t(\"../fx\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"../../lib/setcursor\"),p=t(\"../dragelement\"),d=t(\"../../plot_api/plot_template\").arrayEditor,g=t(\"./draw_arrow_head\");function v(t,e){var r=t._fullLayout.annotations[e]||{},n=s.getFromId(t,r.xref),i=s.getFromId(t,r.yref);n&&n.setScale(),i&&i.setScale(),m(t,r,e,!1,n,i)}function m(t,e,r,a,s,v){var m,y,x=t._fullLayout,b=t._fullLayout._size,_=t._context.edits;a?(m=\"annotation-\"+a,y=a+\".annotations\"):(m=\"annotation\",y=\"annotations\");var w=d(t.layout,y,e),k=w.modifyBase,T=w.modifyItem,A=w.getUpdateObj;x._infolayer.selectAll(\".\"+m+'[data-index=\"'+r+'\"]').remove();var M=\"clip\"+x._uid+\"_ann\"+r;if(e._input&&!1!==e.visible){var S={x:{},y:{}},E=+e.textangle||0,C=x._infolayer.append(\"g\").classed(m,!0).attr(\"data-index\",String(r)).style(\"opacity\",e.opacity),L=C.append(\"g\").classed(\"annotation-text-g\",!0),P=_[e.showarrow?\"annotationTail\":\"annotationPosition\"],O=e.captureevents||_.annotationText||P,z=L.append(\"g\").style(\"pointer-events\",O?\"all\":null).call(f,\"pointer\").on(\"click\",function(){t._dragging=!1,t.emit(\"plotly_clickannotation\",q(n.event))});e.hovertext&&z.on(\"mouseover\",function(){var r=e.hoverlabel,n=r.font,i=this.getBoundingClientRect(),a=t.getBoundingClientRect();u.loneHover({x0:i.left-a.left,x1:i.right-a.left,y:(i.top+i.bottom)/2-a.top,text:e.hovertext,color:r.bgcolor,borderColor:r.bordercolor,fontFamily:n.family,fontSize:n.size,fontColor:n.color},{container:x._hoverlayer.node(),outerContainer:x._paper.node(),gd:t})}).on(\"mouseout\",function(){u.loneUnhover(x._hoverlayer.node())});var I=e.borderwidth,D=e.borderpad,R=I+D,F=z.append(\"rect\").attr(\"class\",\"bg\").style(\"stroke-width\",I+\"px\").call(l.stroke,e.bordercolor).call(l.fill,e.bgcolor),B=e.width||e.height,N=x._topclips.selectAll(\"#\"+M).data(B?[0]:[]);N.enter().append(\"clipPath\").classed(\"annclip\",!0).attr(\"id\",M).append(\"rect\"),N.exit().remove();var j=e.font,U=x._meta?o.templateString(e.text,x._meta):e.text,V=z.append(\"text\").classed(\"annotation-text\",!0).text(U);_.annotationText?V.call(h.makeEditable,{delegate:z,gd:t}).call(H).on(\"edit\",function(r){e.text=r,this.call(H),T(\"text\",r),s&&s.autorange&&k(s._name+\".autorange\",!0),v&&v.autorange&&k(v._name+\".autorange\",!0),i.call(\"_guiRelayout\",t,A())}):V.call(H)}else n.selectAll(\"#\"+M).remove();function q(t){var n={index:r,annotation:e._input,fullAnnotation:e,event:t};return a&&(n.subplotId=a),n}function H(r){return r.call(c.font,j).attr({\"text-anchor\":{left:\"start\",right:\"end\"}[e.align]||\"middle\"}),h.convertToTspans(r,t,G),r}function G(){var r=V.selectAll(\"a\");1===r.size()&&r.text()===V.text()&&z.insert(\"a\",\":first-child\").attr({\"xlink:xlink:href\":r.attr(\"xlink:href\"),\"xlink:xlink:show\":r.attr(\"xlink:show\")}).style({cursor:\"pointer\"}).node().appendChild(F.node());var n=z.select(\".annotation-text-math-group\"),u=!n.empty(),d=c.bBox((u?n:V).node()),m=d.width,y=d.height,w=e.width||m,O=e.height||y,D=Math.round(w+2*R),j=Math.round(O+2*R);function U(t,e){return\"auto\"===e&&(e=t<1/3?\"left\":t>2/3?\"right\":\"center\"),{center:0,middle:0,left:.5,bottom:-.5,right:-.5,top:.5}[e]}for(var H=!1,G=[\"x\",\"y\"],Y=0;Y<G.length;Y++){var W,X,Z,J,K,$=G[Y],Q=e[$+\"ref\"]||$,tt=e[\"a\"+$+\"ref\"],et={x:s,y:v}[$],rt=(E+(\"x\"===$?0:-90))*Math.PI/180,nt=D*Math.cos(rt),it=j*Math.sin(rt),at=Math.abs(nt)+Math.abs(it),ot=e[$+\"anchor\"],st=e[$+\"shift\"]*(\"x\"===$?1:-1),lt=S[$];if(et){var ct=et.r2fraction(e[$]);(ct<0||ct>1)&&(tt===Q?((ct=et.r2fraction(e[\"a\"+$]))<0||ct>1)&&(H=!0):H=!0),W=et._offset+et.r2p(e[$]),J=.5}else\"x\"===$?(Z=e[$],W=b.l+b.w*Z):(Z=1-e[$],W=b.t+b.h*Z),J=e.showarrow?.5:Z;if(e.showarrow){lt.head=W;var ut=e[\"a\"+$];K=nt*U(.5,e.xanchor)-it*U(.5,e.yanchor),tt===Q?(lt.tail=et._offset+et.r2p(ut),X=K):(lt.tail=W+ut,X=K+ut),lt.text=lt.tail+K;var ht=x[\"x\"===$?\"width\":\"height\"];if(\"paper\"===Q&&(lt.head=o.constrain(lt.head,1,ht-1)),\"pixel\"===tt){var ft=-Math.max(lt.tail-3,lt.text),pt=Math.min(lt.tail+3,lt.text)-ht;ft>0?(lt.tail+=ft,lt.text+=ft):pt>0&&(lt.tail-=pt,lt.text-=pt)}lt.tail+=st,lt.head+=st}else X=K=at*U(J,ot),lt.text=W+K;lt.text+=st,K+=st,X+=st,e[\"_\"+$+\"padplus\"]=at/2+X,e[\"_\"+$+\"padminus\"]=at/2-X,e[\"_\"+$+\"size\"]=at,e[\"_\"+$+\"shift\"]=K}if(t._dragging||!H){var dt=0,gt=0;if(\"left\"!==e.align&&(dt=(w-m)*(\"center\"===e.align?.5:1)),\"top\"!==e.valign&&(gt=(O-y)*(\"middle\"===e.valign?.5:1)),u)n.select(\"svg\").attr({x:R+dt-1,y:R+gt}).call(c.setClipUrl,B?M:null,t);else{var vt=R+gt-d.top,mt=R+dt-d.left;V.call(h.positionText,mt,vt).call(c.setClipUrl,B?M:null,t)}N.select(\"rect\").call(c.setRect,R,R,w,O),F.call(c.setRect,I/2,I/2,D-I,j-I),z.call(c.setTranslate,Math.round(S.x.text-D/2),Math.round(S.y.text-j/2)),L.attr({transform:\"rotate(\"+E+\",\"+S.x.text+\",\"+S.y.text+\")\"});var yt,xt=function(r,n){C.selectAll(\".annotation-arrow-g\").remove();var u=S.x.head,h=S.y.head,f=S.x.tail+r,d=S.y.tail+n,m=S.x.text+r,y=S.y.text+n,x=o.rotationXYMatrix(E,m,y),w=o.apply2DTransform(x),M=o.apply2DTransform2(x),P=+F.attr(\"width\"),O=+F.attr(\"height\"),I=m-.5*P,D=I+P,R=y-.5*O,B=R+O,N=[[I,R,I,B],[I,B,D,B],[D,B,D,R],[D,R,I,R]].map(M);if(!N.reduce(function(t,e){return t^!!o.segmentsIntersect(u,h,u+1e6,h+1e6,e[0],e[1],e[2],e[3])},!1)){N.forEach(function(t){var e=o.segmentsIntersect(f,d,u,h,t[0],t[1],t[2],t[3]);e&&(f=e.x,d=e.y)});var j=e.arrowwidth,U=e.arrowcolor,V=e.arrowside,q=C.append(\"g\").style({opacity:l.opacity(U)}).classed(\"annotation-arrow-g\",!0),H=q.append(\"path\").attr(\"d\",\"M\"+f+\",\"+d+\"L\"+u+\",\"+h).style(\"stroke-width\",j+\"px\").call(l.stroke,l.rgb(U));if(g(H,V,e),_.annotationPosition&&H.node().parentNode&&!a){var G=u,Y=h;if(e.standoff){var W=Math.sqrt(Math.pow(u-f,2)+Math.pow(h-d,2));G+=e.standoff*(f-u)/W,Y+=e.standoff*(d-h)/W}var X,Z,J=q.append(\"path\").classed(\"annotation-arrow\",!0).classed(\"anndrag\",!0).classed(\"cursor-move\",!0).attr({d:\"M3,3H-3V-3H3ZM0,0L\"+(f-G)+\",\"+(d-Y),transform:\"translate(\"+G+\",\"+Y+\")\"}).style(\"stroke-width\",j+6+\"px\").call(l.stroke,\"rgba(0,0,0,0)\").call(l.fill,\"rgba(0,0,0,0)\");p.init({element:J.node(),gd:t,prepFn:function(){var t=c.getTranslate(z);X=t.x,Z=t.y,s&&s.autorange&&k(s._name+\".autorange\",!0),v&&v.autorange&&k(v._name+\".autorange\",!0)},moveFn:function(t,r){var n=w(X,Z),i=n[0]+t,a=n[1]+r;z.call(c.setTranslate,i,a),T(\"x\",s?s.p2r(s.r2p(e.x)+t):e.x+t/b.w),T(\"y\",v?v.p2r(v.r2p(e.y)+r):e.y-r/b.h),e.axref===e.xref&&T(\"ax\",s.p2r(s.r2p(e.ax)+t)),e.ayref===e.yref&&T(\"ay\",v.p2r(v.r2p(e.ay)+r)),q.attr(\"transform\",\"translate(\"+t+\",\"+r+\")\"),L.attr({transform:\"rotate(\"+E+\",\"+i+\",\"+a+\")\"})},doneFn:function(){i.call(\"_guiRelayout\",t,A());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}}};if(e.showarrow&&xt(0,0),P)p.init({element:z.node(),gd:t,prepFn:function(){yt=L.attr(\"transform\")},moveFn:function(t,r){var n=\"pointer\";if(e.showarrow)e.axref===e.xref?T(\"ax\",s.p2r(s.r2p(e.ax)+t)):T(\"ax\",e.ax+t),e.ayref===e.yref?T(\"ay\",v.p2r(v.r2p(e.ay)+r)):T(\"ay\",e.ay+r),xt(t,r);else{if(a)return;var i,o;if(s)i=s.p2r(s.r2p(e.x)+t);else{var l=e._xsize/b.w,c=e.x+(e._xshift-e.xshift)/b.w-l/2;i=p.align(c+t/b.w,l,0,1,e.xanchor)}if(v)o=v.p2r(v.r2p(e.y)+r);else{var u=e._ysize/b.h,h=e.y-(e._yshift+e.yshift)/b.h-u/2;o=p.align(h-r/b.h,u,0,1,e.yanchor)}T(\"x\",i),T(\"y\",o),s&&v||(n=p.getCursor(s?.5:i,v?.5:o,e.xanchor,e.yanchor))}L.attr({transform:\"translate(\"+t+\",\"+r+\")\"+yt}),f(z,n)},clickFn:function(r,n){e.captureevents&&t.emit(\"plotly_clickannotation\",q(n))},doneFn:function(){f(z),i.call(\"_guiRelayout\",t,A());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}else z.remove()}}e.exports={draw:function(t){var e=t._fullLayout;e._infolayer.selectAll(\".annotation\").remove();for(var r=0;r<e.annotations.length;r++)e.annotations[r].visible&&v(t,r);return a.previousPromises(t)},drawOne:v,drawRaw:m}},{\"../../lib\":719,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/axes\":767,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"../fx\":632,\"./draw_arrow_head\":583,d3:163}],583:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\"),a=t(\"./arrow_paths\");e.exports=function(t,e,r){var o,s,l,c,u=t.node(),h=a[r.arrowhead||0],f=a[r.startarrowhead||0],p=(r.arrowwidth||1)*(r.arrowsize||1),d=(r.arrowwidth||1)*(r.startarrowsize||1),g=e.indexOf(\"start\")>=0,v=e.indexOf(\"end\")>=0,m=h.backoff*p+r.standoff,y=f.backoff*d+r.startstandoff;if(\"line\"===u.nodeName){o={x:+t.attr(\"x1\"),y:+t.attr(\"y1\")},s={x:+t.attr(\"x2\"),y:+t.attr(\"y2\")};var x=o.x-s.x,b=o.y-s.y;if(c=(l=Math.atan2(b,x))+Math.PI,m&&y&&m+y>Math.sqrt(x*x+b*b))return void P();if(m){if(m*m>x*x+b*b)return void P();var _=m*Math.cos(l),w=m*Math.sin(l);s.x+=_,s.y+=w,t.attr({x2:s.x,y2:s.y})}if(y){if(y*y>x*x+b*b)return void P();var k=y*Math.cos(l),T=y*Math.sin(l);o.x-=k,o.y-=T,t.attr({x1:o.x,y1:o.y})}}else if(\"path\"===u.nodeName){var A=u.getTotalLength(),M=\"\";if(A<m+y)return void P();var S=u.getPointAtLength(0),E=u.getPointAtLength(.1);l=Math.atan2(S.y-E.y,S.x-E.x),o=u.getPointAtLength(Math.min(y,A)),M=\"0px,\"+y+\"px,\";var C=u.getPointAtLength(A),L=u.getPointAtLength(A-.1);c=Math.atan2(C.y-L.y,C.x-L.x),s=u.getPointAtLength(Math.max(0,A-m)),M+=A-(M?y+m:m)+\"px,\"+A+\"px\",t.style(\"stroke-dasharray\",M)}function P(){t.style(\"stroke-dasharray\",\"0px,100px\")}function O(e,a,o,s){e.path&&(e.noRotate&&(o=0),n.select(u.parentNode).append(\"path\").attr({class:t.attr(\"class\"),d:e.path,transform:\"translate(\"+a.x+\",\"+a.y+\")\"+(o?\"rotate(\"+180*o/Math.PI+\")\":\"\")+\"scale(\"+s+\")\"}).style({fill:i.rgb(r.arrowcolor),\"stroke-width\":0}))}g&&O(f,o,l,d),v&&O(h,s,c,p)}},{\"../color\":593,\"./arrow_paths\":575,d3:163}],584:[function(t,e,r){\"use strict\";var n=t(\"./draw\"),i=t(\"./click\");e.exports={moduleType:\"component\",name:\"annotations\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"annotations\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne,drawRaw:n.drawRaw,hasClickToShow:i.hasClickToShow,onClick:i.onClick,convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":777,\"./attributes\":576,\"./calc_autorange\":577,\"./click\":578,\"./convert_coords\":580,\"./defaults\":581,\"./draw\":582}],585:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"../../plot_api/plot_template\").templatedArray;e.exports=i(a(\"annotation\",{visible:n.visible,x:{valType:\"any\"},y:{valType:\"any\"},z:{valType:\"any\"},ax:{valType:\"number\"},ay:{valType:\"number\"},xanchor:n.xanchor,xshift:n.xshift,yanchor:n.yanchor,yshift:n.yshift,text:n.text,textangle:n.textangle,font:n.font,width:n.width,height:n.height,opacity:n.opacity,align:n.align,valign:n.valign,bgcolor:n.bgcolor,bordercolor:n.bordercolor,borderpad:n.borderpad,borderwidth:n.borderwidth,showarrow:n.showarrow,arrowcolor:n.arrowcolor,arrowhead:n.arrowhead,startarrowhead:n.startarrowhead,arrowside:n.arrowside,arrowsize:n.arrowsize,startarrowsize:n.startarrowsize,arrowwidth:n.arrowwidth,standoff:n.standoff,startstandoff:n.startstandoff,hovertext:n.hovertext,hoverlabel:n.hoverlabel,captureevents:n.captureevents}),\"calc\",\"from-root\")},{\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../annotations/attributes\":576}],586:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\");function a(t,e){var r=e.fullSceneLayout.domain,a=e.fullLayout._size,o={pdata:null,type:\"linear\",autorange:!1,range:[-1/0,1/0]};t._xa={},n.extendFlat(t._xa,o),i.setConvert(t._xa),t._xa._offset=a.l+r.x[0]*a.w,t._xa.l2p=function(){return.5*(1+t._pdata[0]/t._pdata[3])*a.w*(r.x[1]-r.x[0])},t._ya={},n.extendFlat(t._ya,o),i.setConvert(t._ya),t._ya._offset=a.t+(1-r.y[1])*a.h,t._ya.l2p=function(){return.5*(1-t._pdata[1]/t._pdata[3])*a.h*(r.y[1]-r.y[0])}}e.exports=function(t){for(var e=t.fullSceneLayout.annotations,r=0;r<e.length;r++)a(e[r],t);t.fullLayout._infolayer.selectAll(\".annotation-\"+t.id).remove()}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767}],587:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"../annotations/common_defaults\"),s=t(\"./attributes\");function l(t,e,r,a){function l(r,i){return n.coerce(t,e,s,r,i)}function c(t){var n=t+\"axis\",a={_fullLayout:{}};return a._fullLayout[n]=r[n],i.coercePosition(e,a,l,t,t,.5)}l(\"visible\")&&(o(t,e,a.fullLayout,l),c(\"x\"),c(\"y\"),c(\"z\"),n.noneOrAll(t,e,[\"x\",\"y\",\"z\"]),e.xref=\"x\",e.yref=\"y\",e.zref=\"z\",l(\"xanchor\"),l(\"yanchor\"),l(\"xshift\"),l(\"yshift\"),e.showarrow&&(e.axref=\"pixel\",e.ayref=\"pixel\",l(\"ax\",-10),l(\"ay\",-30),n.noneOrAll(t,e,[\"ax\",\"ay\"])))}e.exports=function(t,e,r){a(t,e,{name:\"annotations\",handleItemDefaults:l,fullLayout:r.fullLayout})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"../annotations/common_defaults\":579,\"./attributes\":585}],588:[function(t,e,r){\"use strict\";var n=t(\"../annotations/draw\").drawRaw,i=t(\"../../plots/gl3d/project\"),a=[\"x\",\"y\",\"z\"];e.exports=function(t){for(var e=t.fullSceneLayout,r=t.dataScale,o=e.annotations,s=0;s<o.length;s++){for(var l=o[s],c=!1,u=0;u<3;u++){var h=a[u],f=l[h],p=e[h+\"axis\"].r2fraction(f);if(p<0||p>1){c=!0;break}}c?t.fullLayout._infolayer.select(\".annotation-\"+t.id+'[data-index=\"'+s+'\"]').remove():(l._pdata=i(t.glplot.cameraParams,[e.xaxis.r2l(l.x)*r[0],e.yaxis.r2l(l.y)*r[1],e.zaxis.r2l(l.z)*r[2]]),n(t.graphDiv,l,s,t.id,l._xa,l._ya))}}},{\"../../plots/gl3d/project\":816,\"../annotations/draw\":582}],589:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports={moduleType:\"component\",name:\"annotations3d\",schema:{subplots:{scene:{annotations:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),includeBasePlot:function(t,e){var r=n.subplotsRegistry.gl3d;if(!r)return;for(var a=r.attrRegex,o=Object.keys(t),s=0;s<o.length;s++){var l=o[s];a.test(l)&&(t[l].annotations||[]).length&&(i.pushUnique(e._basePlotModules,r),i.pushUnique(e._subplots.gl3d,l))}},convert:t(\"./convert\"),draw:t(\"./draw\")}},{\"../../lib\":719,\"../../registry\":847,\"./attributes\":585,\"./convert\":586,\"./defaults\":587,\"./draw\":588}],590:[function(t,e,r){\"use strict\";e.exports=t(\"world-calendars/dist/main\"),t(\"world-calendars/dist/plus\"),t(\"world-calendars/dist/calendars/chinese\"),t(\"world-calendars/dist/calendars/coptic\"),t(\"world-calendars/dist/calendars/discworld\"),t(\"world-calendars/dist/calendars/ethiopian\"),t(\"world-calendars/dist/calendars/hebrew\"),t(\"world-calendars/dist/calendars/islamic\"),t(\"world-calendars/dist/calendars/julian\"),t(\"world-calendars/dist/calendars/mayan\"),t(\"world-calendars/dist/calendars/nanakshahi\"),t(\"world-calendars/dist/calendars/nepali\"),t(\"world-calendars/dist/calendars/persian\"),t(\"world-calendars/dist/calendars/taiwan\"),t(\"world-calendars/dist/calendars/thai\"),t(\"world-calendars/dist/calendars/ummalqura\")},{\"world-calendars/dist/calendars/chinese\":557,\"world-calendars/dist/calendars/coptic\":558,\"world-calendars/dist/calendars/discworld\":559,\"world-calendars/dist/calendars/ethiopian\":560,\"world-calendars/dist/calendars/hebrew\":561,\"world-calendars/dist/calendars/islamic\":562,\"world-calendars/dist/calendars/julian\":563,\"world-calendars/dist/calendars/mayan\":564,\"world-calendars/dist/calendars/nanakshahi\":565,\"world-calendars/dist/calendars/nepali\":566,\"world-calendars/dist/calendars/persian\":567,\"world-calendars/dist/calendars/taiwan\":568,\"world-calendars/dist/calendars/thai\":569,\"world-calendars/dist/calendars/ummalqura\":570,\"world-calendars/dist/main\":571,\"world-calendars/dist/plus\":572}],591:[function(t,e,r){\"use strict\";var n=t(\"./calendars\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\"),o=a.EPOCHJD,s=a.ONEDAY,l={valType:\"enumerated\",values:Object.keys(n.calendars),editType:\"calc\",dflt:\"gregorian\"},c=function(t,e,r,n){var a={};return a[r]=l,i.coerce(t,e,a,r,n)},u=\"##\",h={d:{0:\"dd\",\"-\":\"d\"},e:{0:\"d\",\"-\":\"d\"},a:{0:\"D\",\"-\":\"D\"},A:{0:\"DD\",\"-\":\"DD\"},j:{0:\"oo\",\"-\":\"o\"},W:{0:\"ww\",\"-\":\"w\"},m:{0:\"mm\",\"-\":\"m\"},b:{0:\"M\",\"-\":\"M\"},B:{0:\"MM\",\"-\":\"MM\"},y:{0:\"yy\",\"-\":\"yy\"},Y:{0:\"yyyy\",\"-\":\"yyyy\"},U:u,w:u,c:{0:\"D M d %X yyyy\",\"-\":\"D M d %X yyyy\"},x:{0:\"mm/dd/yyyy\",\"-\":\"mm/dd/yyyy\"}};var f={};function p(t){var e=f[t];return e||(e=f[t]=n.instance(t))}function d(t){return i.extendFlat({},l,{description:t})}function g(t){return\"Sets the calendar system to use with `\"+t+\"` date data.\"}var v={xcalendar:d(g(\"x\"))},m=i.extendFlat({},v,{ycalendar:d(g(\"y\"))}),y=i.extendFlat({},m,{zcalendar:d(g(\"z\"))}),x=d([\"Sets the calendar system to use for `range` and `tick0`\",\"if this is a date axis. This does not set the calendar for\",\"interpreting data on this axis, that's specified in the trace\",\"or via the global `layout.calendar`\"].join(\" \"));e.exports={moduleType:\"component\",name:\"calendars\",schema:{traces:{scatter:m,bar:m,box:m,heatmap:m,contour:m,histogram:m,histogram2d:m,histogram2dcontour:m,scatter3d:y,surface:y,mesh3d:y,scattergl:m,ohlc:v,candlestick:v},layout:{calendar:d([\"Sets the default calendar system to use for interpreting and\",\"displaying dates throughout the plot.\"].join(\" \"))},subplots:{xaxis:{calendar:x},yaxis:{calendar:x},scene:{xaxis:{calendar:x},yaxis:{calendar:x},zaxis:{calendar:x}},polar:{radialaxis:{calendar:x}}},transforms:{filter:{valuecalendar:d([\"Sets the calendar system to use for `value`, if it is a date.\"].join(\" \")),targetcalendar:d([\"Sets the calendar system to use for `target`, if it is an\",\"array of dates. If `target` is a string (eg *x*) we use the\",\"corresponding trace attribute (eg `xcalendar`) if it exists,\",\"even if `targetcalendar` is provided.\"].join(\" \"))}}},layoutAttributes:l,handleDefaults:c,handleTraceDefaults:function(t,e,r,n){for(var i=0;i<r.length;i++)c(t,e,r[i]+\"calendar\",n.calendar)},CANONICAL_SUNDAY:{chinese:\"2000-01-02\",coptic:\"2000-01-03\",discworld:\"2000-01-03\",ethiopian:\"2000-01-05\",hebrew:\"5000-01-01\",islamic:\"1000-01-02\",julian:\"2000-01-03\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-05\",nepali:\"2000-01-05\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-04\",thai:\"2000-01-04\",ummalqura:\"1400-01-06\"},CANONICAL_TICK:{chinese:\"2000-01-01\",coptic:\"2000-01-01\",discworld:\"2000-01-01\",ethiopian:\"2000-01-01\",hebrew:\"5000-01-01\",islamic:\"1000-01-01\",julian:\"2000-01-01\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-01\",nepali:\"2000-01-01\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-01\",thai:\"2000-01-01\",ummalqura:\"1400-01-01\"},DFLTRANGE:{chinese:[\"2000-01-01\",\"2001-01-01\"],coptic:[\"1700-01-01\",\"1701-01-01\"],discworld:[\"1800-01-01\",\"1801-01-01\"],ethiopian:[\"2000-01-01\",\"2001-01-01\"],hebrew:[\"5700-01-01\",\"5701-01-01\"],islamic:[\"1400-01-01\",\"1401-01-01\"],julian:[\"2000-01-01\",\"2001-01-01\"],mayan:[\"5200-01-01\",\"5201-01-01\"],nanakshahi:[\"0500-01-01\",\"0501-01-01\"],nepali:[\"2000-01-01\",\"2001-01-01\"],persian:[\"1400-01-01\",\"1401-01-01\"],jalali:[\"1400-01-01\",\"1401-01-01\"],taiwan:[\"0100-01-01\",\"0101-01-01\"],thai:[\"2500-01-01\",\"2501-01-01\"],ummalqura:[\"1400-01-01\",\"1401-01-01\"]},getCal:p,worldCalFmt:function(t,e,r){for(var n,i,a,l,c,f=Math.floor((e+.05)/s)+o,d=p(r).fromJD(f),g=0;-1!==(g=t.indexOf(\"%\",g));)\"0\"===(n=t.charAt(g+1))||\"-\"===n||\"_\"===n?(a=3,i=t.charAt(g+2),\"_\"===n&&(n=\"-\")):(i=n,n=\"0\",a=2),(l=h[i])?(c=l===u?u:d.formatDate(l[n]),t=t.substr(0,g)+c+t.substr(g+a),g+=c.length):g+=a;return t}}},{\"../../constants/numerical\":695,\"../../lib\":719,\"./calendars\":590}],592:[function(t,e,r){\"use strict\";r.defaults=[\"#1f77b4\",\"#ff7f0e\",\"#2ca02c\",\"#d62728\",\"#9467bd\",\"#8c564b\",\"#e377c2\",\"#7f7f7f\",\"#bcbd22\",\"#17becf\"],r.defaultLine=\"#444\",r.lightLine=\"#eee\",r.background=\"#fff\",r.borderLine=\"#BEC8D9\",r.lightFraction=1e3/11},{}],593:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i=t(\"fast-isnumeric\"),a=e.exports={},o=t(\"./attributes\");a.defaults=o.defaults;var s=a.defaultLine=o.defaultLine;a.lightLine=o.lightLine;var l=a.background=o.background;function c(t){if(i(t)||\"string\"!=typeof t)return t;var e=t.trim();if(\"rgb\"!==e.substr(0,3))return t;var r=e.match(/^rgba?\\s*\\(([^()]*)\\)$/);if(!r)return t;var n=r[1].trim().split(/\\s*[\\s,]\\s*/),a=\"a\"===e.charAt(3)&&4===n.length;if(!a&&3!==n.length)return t;for(var o=0;o<n.length;o++){if(!n[o].length)return t;if(n[o]=Number(n[o]),!(n[o]>=0))return t;if(3===o)n[o]>1&&(n[o]=1);else if(n[o]>=1)return t}var s=Math.round(255*n[0])+\", \"+Math.round(255*n[1])+\", \"+Math.round(255*n[2]);return a?\"rgba(\"+s+\", \"+n[3]+\")\":\"rgb(\"+s+\")\"}a.tinyRGB=function(t){var e=t.toRgb();return\"rgb(\"+Math.round(e.r)+\", \"+Math.round(e.g)+\", \"+Math.round(e.b)+\")\"},a.rgb=function(t){return a.tinyRGB(n(t))},a.opacity=function(t){return t?n(t).getAlpha():0},a.addOpacity=function(t,e){var r=n(t).toRgb();return\"rgba(\"+Math.round(r.r)+\", \"+Math.round(r.g)+\", \"+Math.round(r.b)+\", \"+e+\")\"},a.combine=function(t,e){var r=n(t).toRgb();if(1===r.a)return n(t).toRgbString();var i=n(e||l).toRgb(),a=1===i.a?i:{r:255*(1-i.a)+i.r*i.a,g:255*(1-i.a)+i.g*i.a,b:255*(1-i.a)+i.b*i.a},o={r:a.r*(1-r.a)+r.r*r.a,g:a.g*(1-r.a)+r.g*r.a,b:a.b*(1-r.a)+r.b*r.a};return n(o).toRgbString()},a.contrast=function(t,e,r){var i=n(t);return 1!==i.getAlpha()&&(i=n(a.combine(t,l))),(i.isDark()?e?i.lighten(e):l:r?i.darken(r):s).toString()},a.stroke=function(t,e){var r=n(e);t.style({stroke:a.tinyRGB(r),\"stroke-opacity\":r.getAlpha()})},a.fill=function(t,e){var r=n(e);t.style({fill:a.tinyRGB(r),\"fill-opacity\":r.getAlpha()})},a.clean=function(t){if(t&&\"object\"==typeof t){var e,r,n,i,o=Object.keys(t);for(e=0;e<o.length;e++)if(i=t[n=o[e]],\"color\"===n.substr(n.length-5))if(Array.isArray(i))for(r=0;r<i.length;r++)i[r]=c(i[r]);else t[n]=c(i);else if(\"colorscale\"===n.substr(n.length-10)&&Array.isArray(i))for(r=0;r<i.length;r++)Array.isArray(i[r])&&(i[r][1]=c(i[r][1]));else if(Array.isArray(i)){var s=i[0];if(!Array.isArray(s)&&s&&\"object\"==typeof s)for(r=0;r<i.length;r++)a.clean(i[r])}else i&&\"object\"==typeof i&&a.clean(i)}}},{\"./attributes\":592,\"fast-isnumeric\":225,tinycolor2:537}],594:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/layout_attributes\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll;e.exports=o({thicknessmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"pixels\"},thickness:{valType:\"number\",min:0,dflt:30},lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",dflt:1.02,min:-2,max:3},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},xpad:{valType:\"number\",min:0,dflt:10},y:{valType:\"number\",dflt:.5,min:-2,max:3},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\"},ypad:{valType:\"number\",min:0,dflt:10},outlinecolor:n.linecolor,outlinewidth:n.linewidth,bordercolor:n.linecolor,borderwidth:{valType:\"number\",min:0,dflt:0},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\"},tickmode:n.tickmode,nticks:n.nticks,tick0:n.tick0,dtick:n.dtick,tickvals:n.tickvals,ticktext:n.ticktext,ticks:a({},n.ticks,{dflt:\"\"}),ticklen:n.ticklen,tickwidth:n.tickwidth,tickcolor:n.tickcolor,showticklabels:n.showticklabels,tickfont:i({}),tickangle:n.tickangle,tickformat:n.tickformat,tickformatstops:n.tickformatstops,tickprefix:n.tickprefix,showtickprefix:n.showtickprefix,ticksuffix:n.ticksuffix,showticksuffix:n.showticksuffix,separatethousands:n.separatethousands,exponentformat:n.exponentformat,showexponent:n.showexponent,title:{text:{valType:\"string\"},font:i({}),side:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}},_deprecated:{title:{valType:\"string\"},titlefont:i({}),titleside:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}}},\"colorbars\",\"from-root\")},{\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/font_attributes\":793}],595:[function(t,e,r){\"use strict\";e.exports={cn:{colorbar:\"colorbar\",cbbg:\"cbbg\",cbfill:\"cbfill\",cbfills:\"cbfills\",cbline:\"cbline\",cblines:\"cblines\",cbaxis:\"cbaxis\",cbtitleunshift:\"cbtitleunshift\",cbtitle:\"cbtitle\",cboutline:\"cboutline\",crisp:\"crisp\",jsPlaceholder:\"js-placeholder\"}}},{}],596:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/tick_value_defaults\"),o=t(\"../../plots/cartesian/tick_mark_defaults\"),s=t(\"../../plots/cartesian/tick_label_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r){var c=i.newContainer(e,\"colorbar\"),u=t.colorbar||{};function h(t,e){return n.coerce(u,c,l,t,e)}var f=h(\"thicknessmode\");h(\"thickness\",\"fraction\"===f?30/(r.width-r.margin.l-r.margin.r):30);var p=h(\"lenmode\");h(\"len\",\"fraction\"===p?1:r.height-r.margin.t-r.margin.b),h(\"x\"),h(\"xanchor\"),h(\"xpad\"),h(\"y\"),h(\"yanchor\"),h(\"ypad\"),n.noneOrAll(u,c,[\"x\",\"y\"]),h(\"outlinecolor\"),h(\"outlinewidth\"),h(\"bordercolor\"),h(\"borderwidth\"),h(\"bgcolor\"),a(u,c,h,\"linear\");var d={outerTicks:!1,font:r.font};s(u,c,h,\"linear\",d),o(u,c,h,\"linear\",d),h(\"title.text\",r._dfltTitle.colorbar),n.coerceFont(h,\"title.font\",r.font),h(\"title.side\")}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/tick_label_defaults\":786,\"../../plots/cartesian/tick_mark_defaults\":787,\"../../plots/cartesian/tick_value_defaults\":788,\"./attributes\":594}],597:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../dragelement\"),c=t(\"../../lib\"),u=t(\"../../lib/extend\").extendFlat,h=t(\"../../lib/setcursor\"),f=t(\"../drawing\"),p=t(\"../color\"),d=t(\"../titles\"),g=t(\"../../lib/svg_text_utils\"),v=t(\"../colorscale/helpers\").flipScale,m=t(\"../../plots/cartesian/axis_defaults\"),y=t(\"../../plots/cartesian/position_defaults\"),x=t(\"../../plots/cartesian/layout_attributes\"),b=t(\"../../constants/alignment\"),_=b.LINE_SPACING,w=b.FROM_TL,k=b.FROM_BR,T=t(\"./constants\").cn;e.exports={draw:function(t){var e=t._fullLayout._infolayer.selectAll(\"g.\"+T.colorbar).data(function(t){var e,r,n,i,a=t._fullLayout,o=t.calcdata,s=[];function l(t){return u(t,{_fillcolor:null,_line:{color:null,width:null,dash:null},_levels:{start:null,end:null,size:null},_filllevels:null,_fillgradient:null,_zrange:null})}function c(){\"function\"==typeof i.calc?i.calc(t,n,e):(e._fillgradient=r.reversescale?v(r.colorscale):r.colorscale,e._zrange=[r[i.min],r[i.max]])}for(var h=0;h<o.length;h++){var f=o[h],p=(n=f[0].trace)._module.colorbar;if(!0===n.visible&&p)for(var d=Array.isArray(p),g=d?p:[p],m=0;m<g.length;m++){var y=(i=g[m]).container;(r=y?n[y]:n)&&r.showscale&&((e=l(r.colorbar))._id=\"cb\"+n.uid+(d&&y?\"-\"+y:\"\"),e._traceIndex=n.index,e._propPrefix=(y?y+\".\":\"\")+\"colorbar.\",e._meta=n._meta,c(),s.push(e))}}for(var x in a._colorAxes)if((r=a[x]).showscale){var b=a._colorAxes[x];(e=l(r.colorbar))._id=\"cb\"+x,e._propPrefix=x+\".colorbar.\",e._meta=a._meta,i={min:\"cmin\",max:\"cmax\"},\"heatmap\"!==b[0]&&(n=b[1],i.calc=n._module.colorbar.calc),c(),s.push(e)}return s}(t),function(t){return t._id});e.enter().append(\"g\").attr(\"class\",function(t){return t._id}).classed(T.colorbar,!0),e.each(function(e){var r=n.select(this);c.ensureSingle(r,\"rect\",T.cbbg),c.ensureSingle(r,\"g\",T.cbfills),c.ensureSingle(r,\"g\",T.cblines),c.ensureSingle(r,\"g\",T.cbaxis,function(t){t.classed(T.crisp,!0)}),c.ensureSingle(r,\"g\",T.cbtitleunshift,function(t){t.append(\"g\").classed(T.cbtitle,!0)}),c.ensureSingle(r,\"rect\",T.cboutline);var v=function(t,e,r){var o=r._fullLayout,l=o._size,h=e._fillcolor,v=e._line,b=e.title,A=b.side,M=e._zrange||n.extent((\"function\"==typeof h?h:v.color).domain()),S=\"function\"==typeof v.color?v.color:function(){return v.color},E=\"function\"==typeof h?h:function(){return h},C=e._levels,L=function(t,e,r){var n,i,a=e._levels,o=[],s=[],l=a.end+a.size/100,c=a.size,u=1.001*r[0]-.001*r[1],h=1.001*r[1]-.001*r[0];for(i=0;i<1e5&&(n=a.start+i*c,!(c>0?n>=l:n<=l));i++)n>u&&n<h&&o.push(n);if(e._fillgradient)s=[0];else if(\"function\"==typeof e._fillcolor){var f=e._filllevels;if(f)for(l=f.end+f.size/100,c=f.size,i=0;i<1e5&&(n=f.start+i*c,!(c>0?n>=l:n<=l));i++)n>r[0]&&n<r[1]&&s.push(n);else(s=o.map(function(t){return t-a.size/2})).push(s[s.length-1]+a.size)}else e._fillcolor&&\"string\"==typeof e._fillcolor&&(s=[0]);return a.size<0&&(o.reverse(),s.reverse()),{line:o,fill:s}}(0,e,M),P=L.fill,O=L.line,z=Math.round(e.thickness*(\"fraction\"===e.thicknessmode?l.w:1)),I=z/l.w,D=Math.round(e.len*(\"fraction\"===e.lenmode?l.h:1)),R=D/l.h,F=e.xpad/l.w,B=(e.borderwidth+e.outlinewidth)/2,N=e.ypad/l.h,j=Math.round(e.x*l.w+e.xpad),U=e.x-I*({middle:.5,right:1}[e.xanchor]||0),V=e.y+R*(({top:-.5,bottom:.5}[e.yanchor]||0)-.5),q=Math.round(l.h*(1-V)),H=q-D;e._lenFrac=R,e._thickFrac=I,e._xLeftFrac=U,e._yBottomFrac=V;var G=function(t,e,r){var n=t._fullLayout,i={type:\"linear\",range:r,tickmode:e.tickmode,nticks:e.nticks,tick0:e.tick0,dtick:e.dtick,tickvals:e.tickvals,ticktext:e.ticktext,ticks:e.ticks,ticklen:e.ticklen,tickwidth:e.tickwidth,tickcolor:e.tickcolor,showticklabels:e.showticklabels,tickfont:e.tickfont,tickangle:e.tickangle,tickformat:e.tickformat,exponentformat:e.exponentformat,separatethousands:e.separatethousands,showexponent:e.showexponent,showtickprefix:e.showtickprefix,tickprefix:e.tickprefix,showticksuffix:e.showticksuffix,ticksuffix:e.ticksuffix,title:e.title,showline:!0,anchor:\"free\",side:\"right\",position:1},a={type:\"linear\",_id:\"y\"+e._id},o={letter:\"y\",font:n.font,noHover:!0,noTickson:!0,calendar:n.calendar};function s(t,e){return c.coerce(i,a,x,t,e)}return m(i,a,s,o,n),y(i,a,s,o),a}(r,e,M);if(G.position=e.x+F+I,-1!==[\"top\",\"bottom\"].indexOf(A)&&(G.title.side=A,G.titlex=e.x+F,G.titley=V+(\"top\"===b.side?R-N:N)),v.color&&\"auto\"===e.tickmode){G.tickmode=\"linear\",G.tick0=C.start;var Y=C.size,W=c.constrain((q-H)/50,4,15)+1,X=(M[1]-M[0])/((e.nticks||W)*Y);if(X>1){var Z=Math.pow(10,Math.floor(Math.log(X)/Math.LN10));Y*=Z*c.roundUp(X/Z,[2,5,10]),(Math.abs(C.start)/C.size+1e-6)%1<2e-6&&(G.tick0=0)}G.dtick=Y}G.domain=[V+N,V+R-N],G.setScale(),t.attr(\"transform\",\"translate(\"+Math.round(l.l)+\",\"+Math.round(l.t)+\")\");var J,K=t.select(\".\"+T.cbtitleunshift).attr(\"transform\",\"translate(-\"+Math.round(l.l)+\",-\"+Math.round(l.t)+\")\"),$=t.select(\".\"+T.cbaxis),Q=0;function tt(n,i){var a={propContainer:G,propName:e._propPrefix+\"title\",traceIndex:e._traceIndex,_meta:e._meta,placeholder:o._dfltTitle.colorbar,containerGroup:t.select(\".\"+T.cbtitle)},s=\"h\"===n.charAt(0)?n.substr(1):\"h\"+n;t.selectAll(\".\"+s+\",.\"+s+\"-math-group\").remove(),d.draw(r,n,u(a,i||{}))}return c.syncOrAsync([a.previousPromises,function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var t,r=l.l+(e.x+F)*l.w,n=G.title.font.size;t=\"top\"===A?(1-(V+R-N))*l.h+l.t+3+.75*n:(1-(V+N))*l.h+l.t-3-.25*n,tt(G._id+\"title\",{attributes:{x:r,y:t,\"text-anchor\":\"start\"}})}},function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var a=t.select(\".\"+T.cbtitle),o=a.select(\"text\"),u=[-e.outlinewidth/2,e.outlinewidth/2],h=a.select(\".h\"+G._id+\"title-math-group\").node(),p=15.6;if(o.node()&&(p=parseInt(o.node().style.fontSize,10)*_),h?(Q=f.bBox(h).height)>p&&(u[1]-=(Q-p)/2):o.node()&&!o.classed(T.jsPlaceholder)&&(Q=f.bBox(o.node()).height),Q){if(Q+=5,\"top\"===A)G.domain[1]-=Q/l.h,u[1]*=-1;else{G.domain[0]+=Q/l.h;var d=g.lineCount(o);u[1]+=(1-d)*p}a.attr(\"transform\",\"translate(\"+u+\")\"),G.setScale()}}t.selectAll(\".\"+T.cbfills+\",.\"+T.cblines).attr(\"transform\",\"translate(0,\"+Math.round(l.h*(1-G.domain[1]))+\")\"),$.attr(\"transform\",\"translate(0,\"+Math.round(-l.t)+\")\");var m=t.select(\".\"+T.cbfills).selectAll(\"rect.\"+T.cbfill).data(P);m.enter().append(\"rect\").classed(T.cbfill,!0).style(\"stroke\",\"none\"),m.exit().remove();var y=M.map(G.c2p).map(Math.round).sort(function(t,e){return t-e});m.each(function(t,a){var o=[0===a?M[0]:(P[a]+P[a-1])/2,a===P.length-1?M[1]:(P[a]+P[a+1])/2].map(G.c2p).map(Math.round);o[1]=c.constrain(o[1]+(o[1]>o[0])?1:-1,y[0],y[1]);var s=n.select(this).attr({x:j,width:Math.max(z,2),y:n.min(o),height:Math.max(n.max(o)-n.min(o),2)});if(e._fillgradient)f.gradient(s,r,e._id,\"vertical\",e._fillgradient,\"fill\");else{var l=E(t).replace(\"e-\",\"\");s.attr(\"fill\",i(l).toHexString())}});var x=t.select(\".\"+T.cblines).selectAll(\"path.\"+T.cbline).data(v.color&&v.width?O:[]);x.enter().append(\"path\").classed(T.cbline,!0),x.exit().remove(),x.each(function(t){n.select(this).attr(\"d\",\"M\"+j+\",\"+(Math.round(G.c2p(t))+v.width/2%1)+\"h\"+z).call(f.lineGroupStyle,v.width,S(t),v.dash)}),$.selectAll(\"g.\"+G._id+\"tick,path\").remove();var b=j+z+(e.outlinewidth||0)/2-(\"outside\"===e.ticks?1:0),w=s.calcTicks(G),k=s.makeTransFn(G),C=s.getTickSigns(G)[2];return s.drawTicks(r,G,{vals:\"inside\"===G.ticks?s.clipEnds(G,w):w,layer:$,path:s.makeTickPath(G,b,C),transFn:k}),s.drawLabels(r,G,{vals:w,layer:$,transFn:k,labelFns:s.makeLabelFns(G,b)})},function(){if(-1===[\"top\",\"bottom\"].indexOf(A)){var t=G.title.font.size,e=G._offset+G._length/2,i=l.l+(G.position||0)*l.w+(\"right\"===G.side?10+t*(G.showticklabels?1:.5):-10-t*(G.showticklabels?.5:0));tt(\"h\"+G._id+\"title\",{avoid:{selection:n.select(r).selectAll(\"g.\"+G._id+\"tick\"),side:A,offsetLeft:l.l,offsetTop:0,maxShift:o.width},attributes:{x:i,y:e,\"text-anchor\":\"middle\"},transform:{rotate:\"-90\",offset:0}})}},a.previousPromises,function(){var n=z+e.outlinewidth/2+f.bBox($.node()).width;if((J=K.select(\"text\")).node()&&!J.classed(T.jsPlaceholder)){var i,o=K.select(\".h\"+G._id+\"title-math-group\").node();i=o&&-1!==[\"top\",\"bottom\"].indexOf(A)?f.bBox(o).width:f.bBox(K.node()).right-j-l.l,n=Math.max(n,i)}var s=2*e.xpad+n+e.borderwidth+e.outlinewidth/2,c=q-H;t.select(\".\"+T.cbbg).attr({x:j-e.xpad-(e.borderwidth+e.outlinewidth)/2,y:H-B,width:Math.max(s,2),height:Math.max(c+2*B,2)}).call(p.fill,e.bgcolor).call(p.stroke,e.bordercolor).style(\"stroke-width\",e.borderwidth),t.selectAll(\".\"+T.cboutline).attr({x:j,y:H+e.ypad+(\"top\"===A?Q:0),width:Math.max(z,2),height:Math.max(c-2*e.ypad-Q,2)}).call(p.stroke,e.outlinecolor).style({fill:\"none\",\"stroke-width\":e.outlinewidth});var u=({center:.5,right:1}[e.xanchor]||0)*s;t.attr(\"transform\",\"translate(\"+(l.l-u)+\",\"+l.t+\")\");var h={},d=w[e.yanchor],g=k[e.yanchor];\"pixels\"===e.lenmode?(h.y=e.y,h.t=c*d,h.b=c*g):(h.t=h.b=0,h.yt=e.y+e.len*d,h.yb=e.y-e.len*g);var v=w[e.xanchor],m=k[e.xanchor];if(\"pixels\"===e.thicknessmode)h.x=e.x,h.l=s*v,h.r=s*m;else{var y=s-z;h.l=y*v,h.r=y*m,h.xl=e.x-e.thickness*v,h.xr=e.x+e.thickness*m}a.autoMargin(r,e._id,h)}],r)}(r,e,t);v&&v.then&&(t._promises||[]).push(v),t._context.edits.colorbarPosition&&function(t,e,r){var n,i,a,s=r._fullLayout._size;l.init({element:t.node(),gd:r,prepFn:function(){n=t.attr(\"transform\"),h(t)},moveFn:function(r,o){t.attr(\"transform\",n+\" translate(\"+r+\",\"+o+\")\"),i=l.align(e._xLeftFrac+r/s.w,e._thickFrac,0,1,e.xanchor),a=l.align(e._yBottomFrac-o/s.h,e._lenFrac,0,1,e.yanchor);var c=l.getCursor(i,a,e.xanchor,e.yanchor);h(t,c)},doneFn:function(){if(h(t),void 0!==i&&void 0!==a){var n={};n[e._propPrefix+\"x\"]=i,n[e._propPrefix+\"y\"]=a,void 0!==e._traceIndex?o.call(\"_guiRestyle\",r,n,e._traceIndex):o.call(\"_guiRelayout\",r,n)}}})}(r,e,t)}),e.exit().each(function(e){a.autoMargin(t,e._id)}).remove(),e.order()}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/extend\":710,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_defaults\":769,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/cartesian/position_defaults\":782,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../colorscale/helpers\":604,\"../dragelement\":611,\"../drawing\":614,\"../titles\":681,\"./constants\":595,d3:163,tinycolor2:537}],598:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t){return n.isPlainObject(t.colorbar)}},{\"../../lib\":719}],599:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"colorbar\",attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),draw:t(\"./draw\").draw,hasColorbar:t(\"./has_colorbar\")}},{\"./attributes\":594,\"./defaults\":596,\"./draw\":597,\"./has_colorbar\":598}],600:[function(t,e,r){\"use strict\";var n=t(\"../colorbar/attributes\"),i=t(\"../../lib/regex\").counter,a=t(\"./scales.js\").scales;Object.keys(a);function o(t){return\"`\"+t+\"`\"}e.exports=function(t,e){t=t||\"\";var r,s=(e=e||{}).cLetter||\"c\",l=(\"onlyIfNumerical\"in e?e.onlyIfNumerical:Boolean(t),\"noScale\"in e?e.noScale:\"marker.line\"===t),c=\"showScaleDflt\"in e?e.showScaleDflt:\"z\"===s,u=\"string\"==typeof e.colorscaleDflt?a[e.colorscaleDflt]:null,h=e.editTypeOverride||\"\",f=t?t+\".\":\"\";\"colorAttr\"in e?(r=e.colorAttr,e.colorAttr):o(f+(r={z:\"z\",c:\"color\"}[s]));var p=s+\"auto\",d=s+\"min\",g=s+\"max\",v=s+\"mid\",m=(o(f+p),o(f+d),o(f+g),{});m[d]=m[g]=void 0;var y={};y[p]=!1;var x={};return\"color\"===r&&(x.color={valType:\"color\",arrayOk:!0,editType:h||\"style\"},e.anim&&(x.color.anim=!0)),x[p]={valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:m},x[d]={valType:\"number\",dflt:null,editType:h||\"plot\",impliedEdits:y},x[g]={valType:\"number\",dflt:null,editType:h||\"plot\",impliedEdits:y},x[v]={valType:\"number\",dflt:null,editType:\"calc\",impliedEdits:m},x.colorscale={valType:\"colorscale\",editType:\"calc\",dflt:u,impliedEdits:{autocolorscale:!1}},x.autocolorscale={valType:\"boolean\",dflt:!1!==e.autoColorDflt,editType:\"calc\",impliedEdits:{colorscale:void 0}},x.reversescale={valType:\"boolean\",dflt:!1,editType:\"plot\"},l||(x.showscale={valType:\"boolean\",dflt:c,editType:\"calc\"},x.colorbar=n),e.noColorAxis||(x.coloraxis={valType:\"subplotid\",regex:i(\"coloraxis\"),dflt:null,editType:\"calc\"}),x}},{\"../../lib/regex\":735,\"../colorbar/attributes\":594,\"./scales.js\":608}],601:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"./helpers\").extractOpts;e.exports=function(t,e,r){var o,s=t._fullLayout,l=r.vals,c=r.containerStr,u=c?i.nestedProperty(e,c).get():e,h=a(u),f=!1!==h.auto,p=h.min,d=h.max,g=h.mid,v=function(){return i.aggNums(Math.min,null,l)},m=function(){return i.aggNums(Math.max,null,l)};(void 0===p?p=v():f&&(p=u._colorAx&&n(p)?Math.min(p,v()):v()),void 0===d?d=m():f&&(d=u._colorAx&&n(d)?Math.max(d,m()):m()),f&&void 0!==g&&(d-g>g-p?p=g-(d-g):d-g<g-p&&(d=g+(g-p))),p===d&&(p-=.5,d+=.5),h._sync(\"min\",p),h._sync(\"max\",d),h.autocolorscale)&&(o=p*d<0?s.colorscale.diverging:p>=0?s.colorscale.sequential:s.colorscale.sequentialminus,h._sync(\"colorscale\",o))}},{\"../../lib\":719,\"./helpers\":604,\"fast-isnumeric\":225}],602:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./helpers\").hasColorscale,a=t(\"./helpers\").extractOpts;e.exports=function(t,e){function r(t,e){var r=t[\"_\"+e];void 0!==r&&(t[e]=r)}function o(t,i){var o=i.container?n.nestedProperty(t,i.container).get():t;if(o)if(o.coloraxis)o._colorAx=e[o.coloraxis];else{var s=a(o),l=s.auto;(l||void 0===s.min)&&r(o,i.min),(l||void 0===s.max)&&r(o,i.max),s.autocolorscale&&r(o,\"colorscale\")}}for(var s=0;s<t.length;s++){var l=t[s],c=l._module.colorbar;if(c)if(Array.isArray(c))for(var u=0;u<c.length;u++)o(l,c[u]);else o(l,c);i(l,\"marker.line\")&&o(l,{container:\"marker.line\",min:\"cmin\",max:\"cmax\"})}for(var h in e._colorAxes)o(e[h],{min:\"cmin\",max:\"cmax\"})}},{\"../../lib\":719,\"./helpers\":604}],603:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../colorbar/has_colorbar\"),o=t(\"../colorbar/defaults\"),s=t(\"./scales\").isValid,l=t(\"../../registry\").traceIs;function c(t,e){var r=e.slice(0,e.length-1);return e?i.nestedProperty(t,r).get()||{}:t}e.exports=function t(e,r,u,h,f){var p=f.prefix,d=f.cLetter,g=\"_module\"in r,v=c(e,p),m=c(r,p),y=c(r._template||{},p)||{},x=function(){return delete e.coloraxis,delete r.coloraxis,t(e,r,u,h,f)};if(g){var b=u._colorAxes||{},_=h(p+\"coloraxis\");if(_){var w=l(r,\"contour\")&&i.nestedProperty(r,\"contours.coloring\").get()||\"heatmap\",k=b[_];return void(k?(k[2].push(x),k[0]!==w&&(k[0]=!1,i.warn([\"Ignoring coloraxis:\",_,\"setting\",\"as it is linked to incompatible colorscales.\"].join(\" \")))):b[_]=[w,r,[x]])}}var T=v[d+\"min\"],A=v[d+\"max\"],M=n(T)&&n(A)&&T<A;h(p+d+\"auto\",!M)?h(p+d+\"mid\"):(h(p+d+\"min\"),h(p+d+\"max\"));var S,E,C=v.colorscale,L=y.colorscale;(void 0!==C&&(S=!s(C)),void 0!==L&&(S=!s(L)),h(p+\"autocolorscale\",S),h(p+\"colorscale\"),h(p+\"reversescale\"),\"marker.line.\"!==p)&&(p&&g&&(E=a(v)),h(p+\"showscale\",E)&&o(v,m,u))}},{\"../../lib\":719,\"../../registry\":847,\"../colorbar/defaults\":596,\"../colorbar/has_colorbar\":598,\"./scales\":608,\"fast-isnumeric\":225}],604:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"fast-isnumeric\"),o=t(\"../../lib\"),s=t(\"../color\"),l=t(\"./scales\").isValid;var c=[\"showscale\",\"autocolorscale\",\"colorscale\",\"reversescale\",\"colorbar\"],u=[\"min\",\"max\",\"mid\",\"auto\"];function h(t){var e,r,n,i=t._colorAx,a=i||t,o={};for(r=0;r<c.length;r++)o[n=c[r]]=a[n];if(i)for(e=\"c\",r=0;r<u.length;r++)o[n=u[r]]=a[\"c\"+n];else{var s;for(r=0;r<u.length;r++)(s=\"c\"+(n=u[r]))in a?o[n]=a[s]:(s=\"z\"+n)in a&&(o[n]=a[s]);e=s.charAt(0)}return o._sync=function(t,r){var n=-1!==u.indexOf(t)?e+t:t;a[n]=a[\"_\"+n]=r},o}function f(t){for(var e=h(t),r=e.min,n=e.max,i=e.reversescale?p(e.colorscale):e.colorscale,a=i.length,o=new Array(a),s=new Array(a),l=0;l<a;l++){var c=i[l];o[l]=r+c[0]*(n-r),s[l]=c[1]}return{domain:o,range:s}}function p(t){for(var e=t.length,r=new Array(e),n=e-1,i=0;n>=0;n--,i++){var a=t[n];r[i]=[1-a[0],a[1]]}return r}function d(t,e){e=e||{};for(var r=t.domain,o=t.range,l=o.length,c=new Array(l),u=0;u<l;u++){var h=i(o[u]).toRgb();c[u]=[h.r,h.g,h.b,h.a]}var f,p=n.scale.linear().domain(r).range(c).clamp(!0),d=e.noNumericCheck,v=e.returnArray;return(f=d&&v?p:d?function(t){return g(p(t))}:v?function(t){return a(t)?p(t):i(t).isValid()?t:s.defaultLine}:function(t){return a(t)?g(p(t)):i(t).isValid()?t:s.defaultLine}).domain=p.domain,f.range=function(){return o},f}function g(t){var e={r:t[0],g:t[1],b:t[2],a:t[3]};return i(e).toRgbString()}e.exports={hasColorscale:function(t,e){var r=e?o.nestedProperty(t,e).get()||{}:t,n=r.color,i=!1;if(o.isArrayOrTypedArray(n))for(var s=0;s<n.length;s++)if(a(n[s])){i=!0;break}return o.isPlainObject(r)&&(i||!0===r.showscale||a(r.cmin)&&a(r.cmax)||l(r.colorscale)||o.isPlainObject(r.colorbar))},extractOpts:h,extractScale:f,flipScale:p,makeColorScaleFunc:d,makeColorScaleFuncFromTrace:function(t,e){return d(f(t),e)}}},{\"../../lib\":719,\"../color\":593,\"./scales\":608,d3:163,\"fast-isnumeric\":225,tinycolor2:537}],605:[function(t,e,r){\"use strict\";var n=t(\"./scales\"),i=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"colorscale\",attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),handleDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\"),scales:n.scales,defaultScale:n.defaultScale,getScale:n.get,isValidScale:n.isValid,hasColorscale:i.hasColorscale,extractOpts:i.extractOpts,extractScale:i.extractScale,flipScale:i.flipScale,makeColorScaleFunc:i.makeColorScaleFunc,makeColorScaleFuncFromTrace:i.makeColorScaleFuncFromTrace}},{\"./attributes\":600,\"./calc\":601,\"./cross_trace_defaults\":602,\"./defaults\":603,\"./helpers\":604,\"./layout_attributes\":606,\"./layout_defaults\":607,\"./scales\":608}],606:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"./attributes\"),a=t(\"./scales\").scales;e.exports={editType:\"calc\",colorscale:{editType:\"calc\",sequential:{valType:\"colorscale\",dflt:a.Reds,editType:\"calc\"},sequentialminus:{valType:\"colorscale\",dflt:a.Blues,editType:\"calc\"},diverging:{valType:\"colorscale\",dflt:a.RdBu,editType:\"calc\"}},coloraxis:n({_isSubplotObj:!0,editType:\"calc\"},i(\"\",{colorAttr:\"corresponding trace color array(s)\",noColorAxis:!0,showScaleDflt:!0}))}},{\"../../lib/extend\":710,\"./attributes\":600,\"./scales\":608}],607:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"./layout_attributes\"),o=t(\"./defaults\");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r(\"colorscale.sequential\"),r(\"colorscale.sequentialminus\"),r(\"colorscale.diverging\");var s,l,c=e._colorAxes;function u(t,e){return n.coerce(s,l,a.coloraxis,t,e)}for(var h in c){var f=c[h];if(f[0])s=t[h]||{},(l=i.newContainer(e,h,\"coloraxis\"))._name=h,o(s,l,e,u,{prefix:\"\",cLetter:\"c\"});else{for(var p=0;p<f[2].length;p++)f[2][p]();delete e._colorAxes[h]}}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"./defaults\":603,\"./layout_attributes\":606}],608:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i={Greys:[[0,\"rgb(0,0,0)\"],[1,\"rgb(255,255,255)\"]],YlGnBu:[[0,\"rgb(8,29,88)\"],[.125,\"rgb(37,52,148)\"],[.25,\"rgb(34,94,168)\"],[.375,\"rgb(29,145,192)\"],[.5,\"rgb(65,182,196)\"],[.625,\"rgb(127,205,187)\"],[.75,\"rgb(199,233,180)\"],[.875,\"rgb(237,248,217)\"],[1,\"rgb(255,255,217)\"]],Greens:[[0,\"rgb(0,68,27)\"],[.125,\"rgb(0,109,44)\"],[.25,\"rgb(35,139,69)\"],[.375,\"rgb(65,171,93)\"],[.5,\"rgb(116,196,118)\"],[.625,\"rgb(161,217,155)\"],[.75,\"rgb(199,233,192)\"],[.875,\"rgb(229,245,224)\"],[1,\"rgb(247,252,245)\"]],YlOrRd:[[0,\"rgb(128,0,38)\"],[.125,\"rgb(189,0,38)\"],[.25,\"rgb(227,26,28)\"],[.375,\"rgb(252,78,42)\"],[.5,\"rgb(253,141,60)\"],[.625,\"rgb(254,178,76)\"],[.75,\"rgb(254,217,118)\"],[.875,\"rgb(255,237,160)\"],[1,\"rgb(255,255,204)\"]],Bluered:[[0,\"rgb(0,0,255)\"],[1,\"rgb(255,0,0)\"]],RdBu:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(106,137,247)\"],[.5,\"rgb(190,190,190)\"],[.6,\"rgb(220,170,132)\"],[.7,\"rgb(230,145,90)\"],[1,\"rgb(178,10,28)\"]],Reds:[[0,\"rgb(220,220,220)\"],[.2,\"rgb(245,195,157)\"],[.4,\"rgb(245,160,105)\"],[1,\"rgb(178,10,28)\"]],Blues:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(40,60,190)\"],[.5,\"rgb(70,100,245)\"],[.6,\"rgb(90,120,245)\"],[.7,\"rgb(106,137,247)\"],[1,\"rgb(220,220,220)\"]],Picnic:[[0,\"rgb(0,0,255)\"],[.1,\"rgb(51,153,255)\"],[.2,\"rgb(102,204,255)\"],[.3,\"rgb(153,204,255)\"],[.4,\"rgb(204,204,255)\"],[.5,\"rgb(255,255,255)\"],[.6,\"rgb(255,204,255)\"],[.7,\"rgb(255,153,255)\"],[.8,\"rgb(255,102,204)\"],[.9,\"rgb(255,102,102)\"],[1,\"rgb(255,0,0)\"]],Rainbow:[[0,\"rgb(150,0,90)\"],[.125,\"rgb(0,0,200)\"],[.25,\"rgb(0,25,255)\"],[.375,\"rgb(0,152,255)\"],[.5,\"rgb(44,255,150)\"],[.625,\"rgb(151,255,0)\"],[.75,\"rgb(255,234,0)\"],[.875,\"rgb(255,111,0)\"],[1,\"rgb(255,0,0)\"]],Portland:[[0,\"rgb(12,51,131)\"],[.25,\"rgb(10,136,186)\"],[.5,\"rgb(242,211,56)\"],[.75,\"rgb(242,143,56)\"],[1,\"rgb(217,30,30)\"]],Jet:[[0,\"rgb(0,0,131)\"],[.125,\"rgb(0,60,170)\"],[.375,\"rgb(5,255,255)\"],[.625,\"rgb(255,255,0)\"],[.875,\"rgb(250,0,0)\"],[1,\"rgb(128,0,0)\"]],Hot:[[0,\"rgb(0,0,0)\"],[.3,\"rgb(230,0,0)\"],[.6,\"rgb(255,210,0)\"],[1,\"rgb(255,255,255)\"]],Blackbody:[[0,\"rgb(0,0,0)\"],[.2,\"rgb(230,0,0)\"],[.4,\"rgb(230,210,0)\"],[.7,\"rgb(255,255,255)\"],[1,\"rgb(160,200,255)\"]],Earth:[[0,\"rgb(0,0,130)\"],[.1,\"rgb(0,180,180)\"],[.2,\"rgb(40,210,40)\"],[.4,\"rgb(230,230,50)\"],[.6,\"rgb(120,70,20)\"],[1,\"rgb(255,255,255)\"]],Electric:[[0,\"rgb(0,0,0)\"],[.15,\"rgb(30,0,100)\"],[.4,\"rgb(120,0,100)\"],[.6,\"rgb(160,90,0)\"],[.8,\"rgb(230,200,0)\"],[1,\"rgb(255,250,220)\"]],Viridis:[[0,\"#440154\"],[.06274509803921569,\"#48186a\"],[.12549019607843137,\"#472d7b\"],[.18823529411764706,\"#424086\"],[.25098039215686274,\"#3b528b\"],[.3137254901960784,\"#33638d\"],[.3764705882352941,\"#2c728e\"],[.4392156862745098,\"#26828e\"],[.5019607843137255,\"#21918c\"],[.5647058823529412,\"#1fa088\"],[.6274509803921569,\"#28ae80\"],[.6901960784313725,\"#3fbc73\"],[.7529411764705882,\"#5ec962\"],[.8156862745098039,\"#84d44b\"],[.8784313725490196,\"#addc30\"],[.9411764705882353,\"#d8e219\"],[1,\"#fde725\"]],Cividis:[[0,\"rgb(0,32,76)\"],[.058824,\"rgb(0,42,102)\"],[.117647,\"rgb(0,52,110)\"],[.176471,\"rgb(39,63,108)\"],[.235294,\"rgb(60,74,107)\"],[.294118,\"rgb(76,85,107)\"],[.352941,\"rgb(91,95,109)\"],[.411765,\"rgb(104,106,112)\"],[.470588,\"rgb(117,117,117)\"],[.529412,\"rgb(131,129,120)\"],[.588235,\"rgb(146,140,120)\"],[.647059,\"rgb(161,152,118)\"],[.705882,\"rgb(176,165,114)\"],[.764706,\"rgb(192,177,109)\"],[.823529,\"rgb(209,191,102)\"],[.882353,\"rgb(225,204,92)\"],[.941176,\"rgb(243,219,79)\"],[1,\"rgb(255,233,69)\"]]},a=i.RdBu;function o(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var i=t[r];if(2!==i.length||+i[0]<e||!n(i[1]).isValid())return!1;e=+i[0]}return!0}e.exports={scales:i,defaultScale:a,get:function(t,e){if(e||(e=a),!t)return e;function r(){try{t=i[t]||JSON.parse(t)}catch(r){t=e}}return\"string\"==typeof t&&(r(),\"string\"==typeof t&&r()),o(t)?t:e},isValid:function(t){return void 0!==i[t]||o(t)}}},{tinycolor2:537}],609:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=(t-r)/(n-r),o=a+e/(n-r),s=(a+o)/2;return\"left\"===i||\"bottom\"===i?a:\"center\"===i||\"middle\"===i?s:\"right\"===i||\"top\"===i?o:a<2/3-s?a:o>4/3-s?o:s}},{}],610:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[\"sw-resize\",\"s-resize\",\"se-resize\"],[\"w-resize\",\"move\",\"e-resize\"],[\"nw-resize\",\"n-resize\",\"ne-resize\"]];e.exports=function(t,e,r,a){return t=\"left\"===r?0:\"center\"===r?1:\"right\"===r?2:n.constrain(Math.floor(3*t),0,2),e=\"bottom\"===a?0:\"middle\"===a?1:\"top\"===a?2:n.constrain(Math.floor(3*e),0,2),i[e][t]}},{\"../../lib\":719}],611:[function(t,e,r){\"use strict\";var n=t(\"mouse-event-offset\"),i=t(\"has-hover\"),a=t(\"has-passive-events\"),o=t(\"../../lib\").removeElement,s=t(\"../../plots/cartesian/constants\"),l=e.exports={};l.align=t(\"./align\"),l.getCursor=t(\"./cursor\");var c=t(\"./unhover\");function u(){var t=document.createElement(\"div\");t.className=\"dragcover\";var e=t.style;return e.position=\"fixed\",e.left=0,e.right=0,e.top=0,e.bottom=0,e.zIndex=999999999,e.background=\"none\",document.body.appendChild(t),t}function h(t){return n(t.changedTouches?t.changedTouches[0]:t,document.body)}l.unhover=c.wrapped,l.unhoverRaw=c.raw,l.init=function(t){var e,r,n,c,f,p,d,g,v=t.gd,m=1,y=v._context.doubleClickDelay,x=t.element;v._mouseDownTime||(v._mouseDownTime=0),x.style.pointerEvents=\"all\",x.onmousedown=_,a?(x._ontouchstart&&x.removeEventListener(\"touchstart\",x._ontouchstart),x._ontouchstart=_,x.addEventListener(\"touchstart\",_,{passive:!1})):x.ontouchstart=_;var b=t.clampFn||function(t,e,r){return Math.abs(t)<r&&(t=0),Math.abs(e)<r&&(e=0),[t,e]};function _(a){v._dragged=!1,v._dragging=!0;var o=h(a);e=o[0],r=o[1],d=a.target,p=a,g=2===a.buttons||a.ctrlKey,\"undefined\"==typeof a.clientX&&\"undefined\"==typeof a.clientY&&(a.clientX=e,a.clientY=r),(n=(new Date).getTime())-v._mouseDownTime<y?m+=1:(m=1,v._mouseDownTime=n),t.prepFn&&t.prepFn(a,e,r),i&&!g?(f=u()).style.cursor=window.getComputedStyle(x).cursor:i||(f=document,c=window.getComputedStyle(document.documentElement).cursor,document.documentElement.style.cursor=window.getComputedStyle(x).cursor),document.addEventListener(\"mouseup\",k),document.addEventListener(\"touchend\",k),!1!==t.dragmode&&(a.preventDefault(),document.addEventListener(\"mousemove\",w),document.addEventListener(\"touchmove\",w))}function w(n){n.preventDefault();var i=h(n),a=t.minDrag||s.MINDRAG,o=b(i[0]-e,i[1]-r,a),c=o[0],u=o[1];(c||u)&&(v._dragged=!0,l.unhover(v)),v._dragged&&t.moveFn&&!g&&(v._dragdata={element:x,dx:c,dy:u},t.moveFn(c,u))}function k(e){if(delete v._dragdata,!1!==t.dragmode&&(e.preventDefault(),document.removeEventListener(\"mousemove\",w),document.removeEventListener(\"touchmove\",w)),document.removeEventListener(\"mouseup\",k),document.removeEventListener(\"touchend\",k),i?o(f):c&&(f.documentElement.style.cursor=c,c=null),v._dragging){if(v._dragging=!1,(new Date).getTime()-v._mouseDownTime>y&&(m=Math.max(m-1,1)),v._dragged)t.doneFn&&t.doneFn();else if(t.clickFn&&t.clickFn(m,p),!g){var r;try{r=new MouseEvent(\"click\",e)}catch(t){var n=h(e);(r=document.createEvent(\"MouseEvents\")).initMouseEvent(\"click\",e.bubbles,e.cancelable,e.view,e.detail,e.screenX,e.screenY,n[0],n[1],e.ctrlKey,e.altKey,e.shiftKey,e.metaKey,e.button,e.relatedTarget)}d.dispatchEvent(r)}v._dragging=!1,v._dragged=!1}else v._dragged=!1}},l.coverSlip=u},{\"../../lib\":719,\"../../plots/cartesian/constants\":773,\"./align\":609,\"./cursor\":610,\"./unhover\":612,\"has-hover\":410,\"has-passive-events\":411,\"mouse-event-offset\":436}],612:[function(t,e,r){\"use strict\";var n=t(\"../../lib/events\"),i=t(\"../../lib/throttle\"),a=t(\"../../lib/dom\").getGraphDiv,o=t(\"../fx/constants\"),s=e.exports={};s.wrapped=function(t,e,r){(t=a(t))._fullLayout&&i.clear(t._fullLayout._uid+o.HOVERID),s.raw(t,e,r)},s.raw=function(t,e){var r=t._fullLayout,i=t._hoverdata;e||(e={}),e.target&&!1===n.triggerHandler(t,\"plotly_beforehover\",e)||(r._hoverlayer.selectAll(\"g\").remove(),r._hoverlayer.selectAll(\"line\").remove(),r._hoverlayer.selectAll(\"circle\").remove(),t._hoverdata=void 0,e.target&&i&&t.emit(\"plotly_unhover\",{event:e,points:i}))}},{\"../../lib/dom\":708,\"../../lib/events\":709,\"../../lib/throttle\":744,\"../fx/constants\":626}],613:[function(t,e,r){\"use strict\";r.dash={valType:\"string\",values:[\"solid\",\"dot\",\"dash\",\"longdash\",\"dashdot\",\"longdashdot\"],dflt:\"solid\",editType:\"style\"}},{}],614:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../registry\"),s=t(\"../color\"),l=t(\"../colorscale\"),c=t(\"../../lib\"),u=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/xmlns_namespaces\"),f=t(\"../../constants/alignment\").LINE_SPACING,p=t(\"../../constants/interactions\").DESELECTDIM,d=t(\"../../traces/scatter/subtypes\"),g=t(\"../../traces/scatter/make_bubble_size_func\"),v=e.exports={};v.font=function(t,e,r,n){c.isPlainObject(e)&&(n=e.color,r=e.size,e=e.family),e&&t.style(\"font-family\",e),r+1&&t.style(\"font-size\",r+\"px\"),n&&t.call(s.fill,n)},v.setPosition=function(t,e,r){t.attr(\"x\",e).attr(\"y\",r)},v.setSize=function(t,e,r){t.attr(\"width\",e).attr(\"height\",r)},v.setRect=function(t,e,r,n,i){t.call(v.setPosition,e,r).call(v.setSize,n,i)},v.translatePoint=function(t,e,r,n){var a=r.c2p(t.x),o=n.c2p(t.y);return!!(i(a)&&i(o)&&e.node())&&(\"text\"===e.node().nodeName?e.attr(\"x\",a).attr(\"y\",o):e.attr(\"transform\",\"translate(\"+a+\",\"+o+\")\"),!0)},v.translatePoints=function(t,e,r){t.each(function(t){var i=n.select(this);v.translatePoint(t,i,e,r)})},v.hideOutsideRangePoint=function(t,e,r,n,i,a){e.attr(\"display\",r.isPtWithinRange(t,i)&&n.isPtWithinRange(t,a)?null:\"none\")},v.hideOutsideRangePoints=function(t,e){if(e._hasClipOnAxisFalse){var r=e.xaxis,i=e.yaxis;t.each(function(e){var a=e[0].trace,s=a.xcalendar,l=a.ycalendar,c=o.traceIs(a,\"bar-like\")?\".bartext\":\".point,.textpoint\";t.selectAll(c).each(function(t){v.hideOutsideRangePoint(t,n.select(this),r,i,s,l)})})}},v.crispRound=function(t,e,r){return e&&i(e)?t._context.staticPlot?e:e<1?1:Math.round(e):r||0},v.singleLineStyle=function(t,e,r,n,i){e.style(\"fill\",\"none\");var a=(((t||[])[0]||{}).trace||{}).line||{},o=r||a.width||0,l=i||a.dash||\"\";s.stroke(e,n||a.color),v.dashLine(e,l,o)},v.lineGroupStyle=function(t,e,r,i){t.style(\"fill\",\"none\").each(function(t){var a=(((t||[])[0]||{}).trace||{}).line||{},o=e||a.width||0,l=i||a.dash||\"\";n.select(this).call(s.stroke,r||a.color).call(v.dashLine,l,o)})},v.dashLine=function(t,e,r){r=+r||0,e=v.dashStyle(e,r),t.style({\"stroke-dasharray\":e,\"stroke-width\":r+\"px\"})},v.dashStyle=function(t,e){e=+e||1;var r=Math.max(e,3);return\"solid\"===t?t=\"\":\"dot\"===t?t=r+\"px,\"+r+\"px\":\"dash\"===t?t=3*r+\"px,\"+3*r+\"px\":\"longdash\"===t?t=5*r+\"px,\"+5*r+\"px\":\"dashdot\"===t?t=3*r+\"px,\"+r+\"px,\"+r+\"px,\"+r+\"px\":\"longdashdot\"===t&&(t=5*r+\"px,\"+2*r+\"px,\"+r+\"px,\"+2*r+\"px\"),t},v.singleFillStyle=function(t){var e=(((n.select(t.node()).data()[0]||[])[0]||{}).trace||{}).fillcolor;e&&t.call(s.fill,e)},v.fillGroupStyle=function(t){t.style(\"stroke-width\",0).each(function(t){var e=n.select(this);t[0].trace&&e.call(s.fill,t[0].trace.fillcolor)})};var m=t(\"./symbol_defs\");v.symbolNames=[],v.symbolFuncs=[],v.symbolNeedLines={},v.symbolNoDot={},v.symbolNoFill={},v.symbolList=[],Object.keys(m).forEach(function(t){var e=m[t];v.symbolList=v.symbolList.concat([e.n,t,e.n+100,t+\"-open\"]),v.symbolNames[e.n]=t,v.symbolFuncs[e.n]=e.f,e.needLine&&(v.symbolNeedLines[e.n]=!0),e.noDot?v.symbolNoDot[e.n]=!0:v.symbolList=v.symbolList.concat([e.n+200,t+\"-dot\",e.n+300,t+\"-open-dot\"]),e.noFill&&(v.symbolNoFill[e.n]=!0)});var y=v.symbolNames.length,x=\"M0,0.5L0.5,0L0,-0.5L-0.5,0Z\";function b(t,e){var r=t%100;return v.symbolFuncs[r](e)+(t>=200?x:\"\")}v.symbolNumber=function(t){if(\"string\"==typeof t){var e=0;t.indexOf(\"-open\")>0&&(e=100,t=t.replace(\"-open\",\"\")),t.indexOf(\"-dot\")>0&&(e+=200,t=t.replace(\"-dot\",\"\")),(t=v.symbolNames.indexOf(t))>=0&&(t+=e)}return t%100>=y||t>=400?0:Math.floor(Math.max(t,0))};var _={x1:1,x2:0,y1:0,y2:0},w={x1:0,x2:0,y1:1,y2:0},k=n.format(\"~.1f\"),T={radial:{node:\"radialGradient\"},radialreversed:{node:\"radialGradient\",reversed:!0},horizontal:{node:\"linearGradient\",attrs:_},horizontalreversed:{node:\"linearGradient\",attrs:_,reversed:!0},vertical:{node:\"linearGradient\",attrs:w},verticalreversed:{node:\"linearGradient\",attrs:w,reversed:!0}};v.gradient=function(t,e,r,i,o,l){for(var u=o.length,h=T[i],f=new Array(u),p=0;p<u;p++)h.reversed?f[u-1-p]=[k(100*(1-o[p][0])),o[p][1]]:f[p]=[k(100*o[p][0]),o[p][1]];var d=\"g\"+e._fullLayout._uid+\"-\"+r,g=e._fullLayout._defs.select(\".gradients\").selectAll(\"#\"+d).data([i+f.join(\";\")],c.identity);g.exit().remove(),g.enter().append(h.node).each(function(){var t=n.select(this);h.attrs&&t.attr(h.attrs),t.attr(\"id\",d);var e=t.selectAll(\"stop\").data(f);e.exit().remove(),e.enter().append(\"stop\"),e.each(function(t){var e=a(t[1]);n.select(this).attr({offset:t[0]+\"%\",\"stop-color\":s.tinyRGB(e),\"stop-opacity\":e.getAlpha()})})}),t.style(l,I(d,e)).style(l+\"-opacity\",null)},v.initGradients=function(t){c.ensureSingle(t._fullLayout._defs,\"g\",\"gradients\").selectAll(\"linearGradient,radialGradient\").remove()},v.pointStyle=function(t,e,r){if(t.size()){var i=v.makePointStyleFns(e);t.each(function(t){v.singlePointStyle(t,n.select(this),e,i,r)})}},v.singlePointStyle=function(t,e,r,n,i){var a=r.marker,o=a.line;if(e.style(\"opacity\",n.selectedOpacityFn?n.selectedOpacityFn(t):void 0===t.mo?a.opacity:t.mo),n.ms2mrc){var l;l=\"various\"===t.ms||\"various\"===a.size?3:n.ms2mrc(t.ms),t.mrc=l,n.selectedSizeFn&&(l=t.mrc=n.selectedSizeFn(t));var u=v.symbolNumber(t.mx||a.symbol)||0;t.om=u%200>=100,e.attr(\"d\",b(u,l))}var h,f,p,d=!1;if(t.so)p=o.outlierwidth,f=o.outliercolor,h=a.outliercolor;else{var g=(o||{}).width;p=(t.mlw+1||g+1||(t.trace?(t.trace.marker.line||{}).width:0)+1)-1||0,f=\"mlc\"in t?t.mlcc=n.lineScale(t.mlc):c.isArrayOrTypedArray(o.color)?s.defaultLine:o.color,c.isArrayOrTypedArray(a.color)&&(h=s.defaultLine,d=!0),h=\"mc\"in t?t.mcc=n.markerScale(t.mc):a.color||\"rgba(0,0,0,0)\",n.selectedColorFn&&(h=n.selectedColorFn(t))}if(t.om)e.call(s.stroke,h).style({\"stroke-width\":(p||1)+\"px\",fill:\"none\"});else{e.style(\"stroke-width\",p+\"px\");var m=a.gradient,y=t.mgt;if(y?d=!0:y=m&&m.type,Array.isArray(y)&&(y=y[0],T[y]||(y=0)),y&&\"none\"!==y){var x=t.mgc;x?d=!0:x=m.color;var _=r.uid;d&&(_+=\"-\"+t.i),v.gradient(e,i,_,y,[[0,x],[1,h]],\"fill\")}else s.fill(e,h);p&&s.stroke(e,f)}},v.makePointStyleFns=function(t){var e={},r=t.marker;return e.markerScale=v.tryColorscale(r,\"\"),e.lineScale=v.tryColorscale(r,\"line\"),o.traceIs(t,\"symbols\")&&(e.ms2mrc=d.isBubble(t)?g(t):function(){return(r.size||6)/2}),t.selectedpoints&&c.extendFlat(e,v.makeSelectedPointStyleFns(t)),e},v.makeSelectedPointStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.marker||{},a=r.marker||{},s=n.marker||{},l=i.opacity,u=a.opacity,h=s.opacity,f=void 0!==u,d=void 0!==h;(c.isArrayOrTypedArray(l)||f||d)&&(e.selectedOpacityFn=function(t){var e=void 0===t.mo?i.opacity:t.mo;return t.selected?f?u:e:d?h:p*e});var g=i.color,v=a.color,m=s.color;(v||m)&&(e.selectedColorFn=function(t){var e=t.mcc||g;return t.selected?v||e:m||e});var y=i.size,x=a.size,b=s.size,_=void 0!==x,w=void 0!==b;return o.traceIs(t,\"symbols\")&&(_||w)&&(e.selectedSizeFn=function(t){var e=t.mrc||y/2;return t.selected?_?x/2:e:w?b/2:e}),e},v.makeSelectedTextStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.textfont||{},a=r.textfont||{},o=n.textfont||{},l=i.color,c=a.color,u=o.color;return e.selectedTextColorFn=function(t){var e=t.tc||l;return t.selected?c||e:u||(c?e:s.addOpacity(e,p))},e},v.selectedPointStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=v.makeSelectedPointStyleFns(e),i=e.marker||{},a=[];r.selectedOpacityFn&&a.push(function(t,e){t.style(\"opacity\",r.selectedOpacityFn(e))}),r.selectedColorFn&&a.push(function(t,e){s.fill(t,r.selectedColorFn(e))}),r.selectedSizeFn&&a.push(function(t,e){var n=e.mx||i.symbol||0,a=r.selectedSizeFn(e);t.attr(\"d\",b(v.symbolNumber(n),a)),e.mrc2=a}),a.length&&t.each(function(t){for(var e=n.select(this),r=0;r<a.length;r++)a[r](e,t)})}},v.tryColorscale=function(t,e){var r=e?c.nestedProperty(t,e).get():t;if(r){var n=r.color;if((r.colorscale||r._colorAx)&&c.isArrayOrTypedArray(n))return l.makeColorScaleFuncFromTrace(r)}return c.identity};var A={start:1,end:-1,middle:0,bottom:1,top:-1};function M(t,e,r,i){var a=n.select(t.node().parentNode),o=-1!==e.indexOf(\"top\")?\"top\":-1!==e.indexOf(\"bottom\")?\"bottom\":\"middle\",s=-1!==e.indexOf(\"left\")?\"end\":-1!==e.indexOf(\"right\")?\"start\":\"middle\",l=i?i/.8+1:0,c=(u.lineCount(t)-1)*f+1,h=A[s]*l,p=.75*r+A[o]*l+(A[o]-1)*c*r/2;t.attr(\"text-anchor\",s),a.attr(\"transform\",\"translate(\"+h+\",\"+p+\")\")}function S(t,e){var r=t.ts||e.textfont.size;return i(r)&&r>0?r:0}v.textPointStyle=function(t,e,r){if(t.size()){var i;if(e.selectedpoints){var a=v.makeSelectedTextStyleFns(e);i=a.selectedTextColorFn}t.each(function(t){var a=n.select(this),o=c.extractOption(t,e,\"tx\",\"text\");if(o||0===o){var s=t.tp||e.textposition,l=S(t,e),h=i?i(t):t.tc||e.textfont.color;a.call(v.font,t.tf||e.textfont.family,l,h).text(o).call(u.convertToTspans,r).call(M,s,l,t.mrc)}else a.remove()})}},v.selectedTextStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=v.makeSelectedTextStyleFns(e);t.each(function(t){var i=n.select(this),a=r.selectedTextColorFn(t),o=t.tp||e.textposition,l=S(t,e);s.fill(i,a),M(i,o,l,t.mrc2||t.mrc)})}};var E=.5;function C(t,e,r,i){var a=t[0]-e[0],o=t[1]-e[1],s=r[0]-e[0],l=r[1]-e[1],c=Math.pow(a*a+o*o,E/2),u=Math.pow(s*s+l*l,E/2),h=(u*u*a-c*c*s)*i,f=(u*u*o-c*c*l)*i,p=3*u*(c+u),d=3*c*(c+u);return[[n.round(e[0]+(p&&h/p),2),n.round(e[1]+(p&&f/p),2)],[n.round(e[0]-(d&&h/d),2),n.round(e[1]-(d&&f/d),2)]]}v.smoothopen=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\");var r,n=\"M\"+t[0],i=[];for(r=1;r<t.length-1;r++)i.push(C(t[r-1],t[r],t[r+1],e));for(n+=\"Q\"+i[0][0]+\" \"+t[1],r=2;r<t.length-1;r++)n+=\"C\"+i[r-2][1]+\" \"+i[r-1][0]+\" \"+t[r];return n+=\"Q\"+i[t.length-3][1]+\" \"+t[t.length-1]},v.smoothclosed=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\")+\"Z\";var r,n=\"M\"+t[0],i=t.length-1,a=[C(t[i],t[0],t[1],e)];for(r=1;r<i;r++)a.push(C(t[r-1],t[r],t[r+1],e));for(a.push(C(t[i-1],t[i],t[0],e)),r=1;r<=i;r++)n+=\"C\"+a[r-1][1]+\" \"+a[r][0]+\" \"+t[r];return n+=\"C\"+a[i][1]+\" \"+a[0][0]+\" \"+t[0]+\"Z\"};var L={hv:function(t,e){return\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)},vh:function(t,e){return\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},hvh:function(t,e){return\"H\"+n.round((t[0]+e[0])/2,2)+\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},vhv:function(t,e){return\"V\"+n.round((t[1]+e[1])/2,2)+\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)}},P=function(t,e){return\"L\"+n.round(e[0],2)+\",\"+n.round(e[1],2)};v.steps=function(t){var e=L[t]||P;return function(t){for(var r=\"M\"+n.round(t[0][0],2)+\",\"+n.round(t[0][1],2),i=1;i<t.length;i++)r+=e(t[i-1],t[i]);return r}},v.makeTester=function(){var t=c.ensureSingleById(n.select(\"body\"),\"svg\",\"js-plotly-tester\",function(t){t.attr(h.svgAttrs).style({position:\"absolute\",left:\"-10000px\",top:\"-10000px\",width:\"9000px\",height:\"9000px\",\"z-index\":\"1\"})}),e=c.ensureSingle(t,\"path\",\"js-reference-point\",function(t){t.attr(\"d\",\"M0,0H1V1H0Z\").style({\"stroke-width\":0,fill:\"black\"})});v.tester=t,v.testref=e},v.savedBBoxes={};var O=0;function z(t){var e=t.getAttribute(\"data-unformatted\");if(null!==e)return e+t.getAttribute(\"data-math\")+t.getAttribute(\"text-anchor\")+t.getAttribute(\"style\")}function I(t,e){if(!t)return null;var r=e._context;return\"url('\"+(r._exportedPlot?\"\":r._baseUrl||\"\")+\"#\"+t+\"')\"}v.bBox=function(t,e,r){var i,a,o;if(r||(r=z(t)),r){if(i=v.savedBBoxes[r])return c.extendFlat({},i)}else if(1===t.childNodes.length){var s=t.childNodes[0];if(r=z(s)){var l=+s.getAttribute(\"x\")||0,h=+s.getAttribute(\"y\")||0,f=s.getAttribute(\"transform\");if(!f){var p=v.bBox(s,!1,r);return l&&(p.left+=l,p.right+=l),h&&(p.top+=h,p.bottom+=h),p}if(r+=\"~\"+l+\"~\"+h+\"~\"+f,i=v.savedBBoxes[r])return c.extendFlat({},i)}}e?a=t:(o=v.tester.node(),a=t.cloneNode(!0),o.appendChild(a)),n.select(a).attr(\"transform\",null).call(u.positionText,0,0);var d=a.getBoundingClientRect(),g=v.testref.node().getBoundingClientRect();e||o.removeChild(a);var m={height:d.height,width:d.width,left:d.left-g.left,top:d.top-g.top,right:d.right-g.left,bottom:d.bottom-g.top};return O>=1e4&&(v.savedBBoxes={},O=0),r&&(v.savedBBoxes[r]=m),O++,c.extendFlat({},m)},v.setClipUrl=function(t,e,r){t.attr(\"clip-path\",I(e,r))},v.getTranslate=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\btranslate\\((-?\\d*\\.?\\d*)[^-\\d]*(-?\\d*\\.?\\d*)[^\\d].*/,function(t,e,r){return[e,r].join(\" \")}).split(\" \");return{x:+e[0]||0,y:+e[1]||0}},v.setTranslate=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||0,r=r||0,a=a.replace(/(\\btranslate\\(.*?\\);?)/,\"\").trim(),a=(a+=\" translate(\"+e+\", \"+r+\")\").trim(),t[i](\"transform\",a),a},v.getScale=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\bscale\\((\\d*\\.?\\d*)[^\\d]*(\\d*\\.?\\d*)[^\\d].*/,function(t,e,r){return[e,r].join(\" \")}).split(\" \");return{x:+e[0]||1,y:+e[1]||1}},v.setScale=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||1,r=r||1,a=a.replace(/(\\bscale\\(.*?\\);?)/,\"\").trim(),a=(a+=\" scale(\"+e+\", \"+r+\")\").trim(),t[i](\"transform\",a),a};var D=/\\s*sc.*/;v.setPointGroupScale=function(t,e,r){if(e=e||1,r=r||1,t){var n=1===e&&1===r?\"\":\" scale(\"+e+\",\"+r+\")\";t.each(function(){var t=(this.getAttribute(\"transform\")||\"\").replace(D,\"\");t=(t+=n).trim(),this.setAttribute(\"transform\",t)})}};var R=/translate\\([^)]*\\)\\s*$/;v.setTextPointsScale=function(t,e,r){t&&t.each(function(){var t,i=n.select(this),a=i.select(\"text\");if(a.node()){var o=parseFloat(a.attr(\"x\")||0),s=parseFloat(a.attr(\"y\")||0),l=(i.attr(\"transform\")||\"\").match(R);t=1===e&&1===r?[]:[\"translate(\"+o+\",\"+s+\")\",\"scale(\"+e+\",\"+r+\")\",\"translate(\"+-o+\",\"+-s+\")\"],l&&t.push(l),i.attr(\"transform\",t.join(\" \"))}})}},{\"../../constants/alignment\":688,\"../../constants/interactions\":694,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../registry\":847,\"../../traces/scatter/make_bubble_size_func\":1128,\"../../traces/scatter/subtypes\":1135,\"../color\":593,\"../colorscale\":605,\"./symbol_defs\":615,d3:163,\"fast-isnumeric\":225,tinycolor2:537}],615:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports={circle:{n:0,f:function(t){var e=n.round(t,2);return\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"}},square:{n:1,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"}},diamond:{n:2,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"Z\"}},cross:{n:3,f:function(t){var e=n.round(.4*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H\"+e+\"V\"+r+\"H-\"+e+\"V\"+e+\"H-\"+r+\"V-\"+e+\"H-\"+e+\"V-\"+r+\"H\"+e+\"V-\"+e+\"H\"+r+\"Z\"}},x:{n:4,f:function(t){var e=n.round(.8*t/Math.sqrt(2),2),r=\"l\"+e+\",\"+e,i=\"l\"+e+\",-\"+e,a=\"l-\"+e+\",-\"+e,o=\"l-\"+e+\",\"+e;return\"M0,\"+e+r+i+a+i+a+o+a+o+r+o+r+\"Z\"}},\"triangle-up\":{n:5,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",\"+n.round(t/2,2)+\"H\"+e+\"L0,-\"+n.round(t,2)+\"Z\"}},\"triangle-down\":{n:6,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",-\"+n.round(t/2,2)+\"H\"+e+\"L0,\"+n.round(t,2)+\"Z\"}},\"triangle-left\":{n:7,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L-\"+n.round(t,2)+\",0Z\"}},\"triangle-right\":{n:8,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L\"+n.round(t,2)+\",0Z\"}},\"triangle-ne\":{n:9,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+r+\",-\"+e+\"H\"+e+\"V\"+r+\"Z\"}},\"triangle-se\":{n:10,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+e+\",-\"+r+\"V\"+e+\"H-\"+r+\"Z\"}},\"triangle-sw\":{n:11,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H-\"+e+\"V-\"+r+\"Z\"}},\"triangle-nw\":{n:12,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+e+\",\"+r+\"V-\"+e+\"H\"+r+\"Z\"}},pentagon:{n:13,f:function(t){var e=n.round(.951*t,2),r=n.round(.588*t,2),i=n.round(-t,2),a=n.round(-.309*t,2);return\"M\"+e+\",\"+a+\"L\"+r+\",\"+n.round(.809*t,2)+\"H-\"+r+\"L-\"+e+\",\"+a+\"L0,\"+i+\"Z\"}},hexagon:{n:14,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M\"+i+\",-\"+r+\"V\"+r+\"L0,\"+e+\"L-\"+i+\",\"+r+\"V-\"+r+\"L0,-\"+e+\"Z\"}},hexagon2:{n:15,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M-\"+r+\",\"+i+\"H\"+r+\"L\"+e+\",0L\"+r+\",-\"+i+\"H-\"+r+\"L-\"+e+\",0Z\"}},octagon:{n:16,f:function(t){var e=n.round(.924*t,2),r=n.round(.383*t,2);return\"M-\"+r+\",-\"+e+\"H\"+r+\"L\"+e+\",-\"+r+\"V\"+r+\"L\"+r+\",\"+e+\"H-\"+r+\"L-\"+e+\",\"+r+\"V-\"+r+\"Z\"}},star:{n:17,f:function(t){var e=1.4*t,r=n.round(.225*e,2),i=n.round(.951*e,2),a=n.round(.363*e,2),o=n.round(.588*e,2),s=n.round(-e,2),l=n.round(-.309*e,2),c=n.round(.118*e,2),u=n.round(.809*e,2);return\"M\"+r+\",\"+l+\"H\"+i+\"L\"+a+\",\"+c+\"L\"+o+\",\"+u+\"L0,\"+n.round(.382*e,2)+\"L-\"+o+\",\"+u+\"L-\"+a+\",\"+c+\"L-\"+i+\",\"+l+\"H-\"+r+\"L0,\"+s+\"Z\"}},hexagram:{n:18,f:function(t){var e=n.round(.66*t,2),r=n.round(.38*t,2),i=n.round(.76*t,2);return\"M-\"+i+\",0l-\"+r+\",-\"+e+\"h\"+i+\"l\"+r+\",-\"+e+\"l\"+r+\",\"+e+\"h\"+i+\"l-\"+r+\",\"+e+\"l\"+r+\",\"+e+\"h-\"+i+\"l-\"+r+\",\"+e+\"l-\"+r+\",-\"+e+\"h-\"+i+\"Z\"}},\"star-triangle-up\":{n:19,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M-\"+e+\",\"+r+o+e+\",\"+r+o+\"0,-\"+i+o+\"-\"+e+\",\"+r+\"Z\"}},\"star-triangle-down\":{n:20,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M\"+e+\",-\"+r+o+\"-\"+e+\",-\"+r+o+\"0,\"+i+o+e+\",-\"+r+\"Z\"}},\"star-square\":{n:21,f:function(t){var e=n.round(1.1*t,2),r=n.round(2*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",-\"+e+i+\"-\"+e+\",\"+e+i+e+\",\"+e+i+e+\",-\"+e+i+\"-\"+e+\",-\"+e+\"Z\"}},\"star-diamond\":{n:22,f:function(t){var e=n.round(1.4*t,2),r=n.round(1.9*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",0\"+i+\"0,\"+e+i+e+\",0\"+i+\"0,-\"+e+i+\"-\"+e+\",0Z\"}},\"diamond-tall\":{n:23,f:function(t){var e=n.round(.7*t,2),r=n.round(1.4*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},\"diamond-wide\":{n:24,f:function(t){var e=n.round(1.4*t,2),r=n.round(.7*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},hourglass:{n:25,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"L\"+e+\",-\"+e+\"H-\"+e+\"Z\"},noDot:!0},bowtie:{n:26,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"V-\"+e+\"L-\"+e+\",\"+e+\"V-\"+e+\"Z\"},noDot:!0},\"circle-cross\":{n:27,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"circle-x\":{n:28,f:function(t){var e=n.round(t,2),r=n.round(t/Math.sqrt(2),2);return\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"square-cross\":{n:29,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"square-x\":{n:30,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"diamond-cross\":{n:31,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM0,-\"+e+\"V\"+e+\"M-\"+e+\",0H\"+e},needLine:!0,noDot:!0},\"diamond-x\":{n:32,f:function(t){var e=n.round(1.3*t,2),r=n.round(.65*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM-\"+r+\",-\"+r+\"L\"+r+\",\"+r+\"M-\"+r+\",\"+r+\"L\"+r+\",-\"+r},needLine:!0,noDot:!0},\"cross-thin\":{n:33,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"x-thin\":{n:34,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},asterisk:{n:35,f:function(t){var e=n.round(1.2*t,2),r=n.round(.85*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r},needLine:!0,noDot:!0,noFill:!0},hash:{n:36,f:function(t){var e=n.round(t/2,2),r=n.round(t,2);return\"M\"+e+\",\"+r+\"V-\"+r+\"m-\"+r+\",0V\"+r+\"M\"+r+\",\"+e+\"H-\"+r+\"m0,-\"+r+\"H\"+r},needLine:!0,noFill:!0},\"y-up\":{n:37,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",\"+i+\"L0,0M\"+e+\",\"+i+\"L0,0M0,-\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-down\":{n:38,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",-\"+i+\"L0,0M\"+e+\",-\"+i+\"L0,0M0,\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-left\":{n:39,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M\"+i+\",\"+e+\"L0,0M\"+i+\",-\"+e+\"L0,0M-\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-right\":{n:40,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+i+\",\"+e+\"L0,0M-\"+i+\",-\"+e+\"L0,0M\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"line-ew\":{n:41,f:function(t){var e=n.round(1.4*t,2);return\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ns\":{n:42,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ne\":{n:43,f:function(t){var e=n.round(t,2);return\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-nw\":{n:44,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e},needLine:!0,noDot:!0,noFill:!0}}},{d3:163}],616:[function(t,e,r){\"use strict\";e.exports={visible:{valType:\"boolean\",editType:\"calc\"},type:{valType:\"enumerated\",values:[\"percent\",\"constant\",\"sqrt\",\"data\"],editType:\"calc\"},symmetric:{valType:\"boolean\",editType:\"calc\"},array:{valType:\"data_array\",editType:\"calc\"},arrayminus:{valType:\"data_array\",editType:\"calc\"},value:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},valueminus:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},traceref:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},tracerefminus:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},copy_ystyle:{valType:\"boolean\",editType:\"plot\"},copy_zstyle:{valType:\"boolean\",editType:\"style\"},color:{valType:\"color\",editType:\"style\"},thickness:{valType:\"number\",min:0,dflt:2,editType:\"style\"},width:{valType:\"number\",min:0,editType:\"plot\"},editType:\"calc\",_deprecated:{opacity:{valType:\"number\",editType:\"style\"}}}},{}],617:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=t(\"./compute_error\");function l(t,e,r,i){var l=e[\"error_\"+i]||{},c=[];if(l.visible&&-1!==[\"linear\",\"log\"].indexOf(r.type)){for(var u=s(l),h=0;h<t.length;h++){var f=t[h],p=f.i;if(void 0===p)p=h;else if(null===p)continue;var d=f[i];if(n(r.c2l(d))){var g=u(d,p);if(n(g[0])&&n(g[1])){var v=f[i+\"s\"]=d-g[0],m=f[i+\"h\"]=d+g[1];c.push(v,m)}}}var y=r._id,x=e._extremes[y],b=a.findExtremes(r,c,o.extendFlat({tozero:x.opts.tozero},{padded:!0}));x.min=x.min.concat(b.min),x.max=x.max.concat(b.max)}}e.exports=function(t){for(var e=t.calcdata,r=0;r<e.length;r++){var n=e[r],o=n[0].trace;if(!0===o.visible&&i.traceIs(o,\"errorBarsOK\")){var s=a.getFromId(t,o.xaxis),c=a.getFromId(t,o.yaxis);l(n,o,s,\"x\"),l(n,o,c,\"y\")}}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./compute_error\":618,\"fast-isnumeric\":225}],618:[function(t,e,r){\"use strict\";function n(t,e){return\"percent\"===t?function(t){return Math.abs(t*e/100)}:\"constant\"===t?function(){return Math.abs(e)}:\"sqrt\"===t?function(t){return Math.sqrt(Math.abs(t))}:void 0}e.exports=function(t){var e=t.type,r=t.symmetric;if(\"data\"===e){var i=t.array||[];if(r)return function(t,e){var r=+i[e];return[r,r]};var a=t.arrayminus||[];return function(t,e){var r=+i[e],n=+a[e];return isNaN(r)&&isNaN(n)?[NaN,NaN]:[n||0,r||0]}}var o=n(e,t.value),s=n(e,t.valueminus);return r||void 0===t.valueminus?function(t){var e=o(t);return[e,e]}:function(t){return[s(t),o(t)]}}},{}],619:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../plot_api/plot_template\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){var c=\"error_\"+l.axis,u=o.newContainer(e,c),h=t[c]||{};function f(t,e){return a.coerce(h,u,s,t,e)}if(!1!==f(\"visible\",void 0!==h.array||void 0!==h.value||\"sqrt\"===h.type)){var p=f(\"type\",\"array\"in h?\"data\":\"percent\"),d=!0;\"sqrt\"!==p&&(d=f(\"symmetric\",!((\"data\"===p?\"arrayminus\":\"valueminus\")in h))),\"data\"===p?(f(\"array\"),f(\"traceref\"),d||(f(\"arrayminus\"),f(\"tracerefminus\"))):\"percent\"!==p&&\"constant\"!==p||(f(\"value\"),d||f(\"valueminus\"));var g=\"copy_\"+l.inherit+\"style\";if(l.inherit)(e[\"error_\"+l.inherit]||{}).visible&&f(g,!(h.color||n(h.thickness)||n(h.width)));l.inherit&&u[g]||(f(\"color\",r),f(\"thickness\"),f(\"width\",i.traceIs(e,\"gl3d\")?0:4))}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../registry\":847,\"./attributes\":616,\"fast-isnumeric\":225}],620:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"./attributes\"),o={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a)};delete o.error_x.copy_zstyle,delete o.error_y.copy_zstyle,delete o.error_y.copy_ystyle;var s={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a),error_z:n.extendFlat({},a)};delete s.error_x.copy_ystyle,delete s.error_y.copy_ystyle,delete s.error_z.copy_ystyle,delete s.error_z.copy_zstyle,e.exports={moduleType:\"component\",name:\"errorbars\",schema:{traces:{scatter:o,bar:o,histogram:o,scatter3d:i(s,\"calc\",\"nested\"),scattergl:i(o,\"calc\",\"nested\")}},supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),makeComputeError:t(\"./compute_error\"),plot:t(\"./plot\"),style:t(\"./style\"),hoverInfo:function(t,e,r){(e.error_y||{}).visible&&(r.yerr=t.yh-t.y,e.error_y.symmetric||(r.yerrneg=t.y-t.ys));(e.error_x||{}).visible&&(r.xerr=t.xh-t.x,e.error_x.symmetric||(r.xerrneg=t.x-t.xs))}}},{\"../../lib\":719,\"../../plot_api/edit_types\":750,\"./attributes\":616,\"./calc\":617,\"./compute_error\":618,\"./defaults\":619,\"./plot\":621,\"./style\":622}],621:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../drawing\"),o=t(\"../../traces/scatter/subtypes\");e.exports=function(t,e,r,s){var l=r.xaxis,c=r.yaxis,u=s&&s.duration>0;e.each(function(e){var h,f=e[0].trace,p=f.error_x||{},d=f.error_y||{};f.ids&&(h=function(t){return t.id});var g=o.hasMarkers(f)&&f.marker.maxdisplayed>0;d.visible||p.visible||(e=[]);var v=n.select(this).selectAll(\"g.errorbar\").data(e,h);if(v.exit().remove(),e.length){p.visible||v.selectAll(\"path.xerror\").remove(),d.visible||v.selectAll(\"path.yerror\").remove(),v.style(\"opacity\",1);var m=v.enter().append(\"g\").classed(\"errorbar\",!0);u&&m.style(\"opacity\",0).transition().duration(s.duration).style(\"opacity\",1),a.setClipUrl(v,r.layerClipId,t),v.each(function(t){var e=n.select(this),r=function(t,e,r){var n={x:e.c2p(t.x),y:r.c2p(t.y)};void 0!==t.yh&&(n.yh=r.c2p(t.yh),n.ys=r.c2p(t.ys),i(n.ys)||(n.noYS=!0,n.ys=r.c2p(t.ys,!0)));void 0!==t.xh&&(n.xh=e.c2p(t.xh),n.xs=e.c2p(t.xs),i(n.xs)||(n.noXS=!0,n.xs=e.c2p(t.xs,!0)));return n}(t,l,c);if(!g||t.vis){var a,o=e.select(\"path.yerror\");if(d.visible&&i(r.x)&&i(r.yh)&&i(r.ys)){var h=d.width;a=\"M\"+(r.x-h)+\",\"+r.yh+\"h\"+2*h+\"m-\"+h+\",0V\"+r.ys,r.noYS||(a+=\"m-\"+h+\",0h\"+2*h),!o.size()?o=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"yerror\",!0):u&&(o=o.transition().duration(s.duration).ease(s.easing)),o.attr(\"d\",a)}else o.remove();var f=e.select(\"path.xerror\");if(p.visible&&i(r.y)&&i(r.xh)&&i(r.xs)){var v=(p.copy_ystyle?d:p).width;a=\"M\"+r.xh+\",\"+(r.y-v)+\"v\"+2*v+\"m0,-\"+v+\"H\"+r.xs,r.noXS||(a+=\"m0,-\"+v+\"v\"+2*v),!f.size()?f=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"xerror\",!0):u&&(f=f.transition().duration(s.duration).ease(s.easing)),f.attr(\"d\",a)}else f.remove()}})}})}},{\"../../traces/scatter/subtypes\":1135,\"../drawing\":614,d3:163,\"fast-isnumeric\":225}],622:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\");e.exports=function(t){t.each(function(t){var e=t[0].trace,r=e.error_y||{},a=e.error_x||{},o=n.select(this);o.selectAll(\"path.yerror\").style(\"stroke-width\",r.thickness+\"px\").call(i.stroke,r.color),a.copy_ystyle&&(a=r),o.selectAll(\"path.xerror\").style(\"stroke-width\",a.thickness+\"px\").call(i.stroke,a.color)})}},{\"../color\":593,d3:163}],623:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./layout_attributes\").hoverlabel,a=t(\"../../lib/extend\").extendFlat;e.exports={hoverlabel:{bgcolor:a({},i.bgcolor,{arrayOk:!0}),bordercolor:a({},i.bordercolor,{arrayOk:!0}),font:n({arrayOk:!0,editType:\"none\"}),align:a({},i.align,{arrayOk:!0}),namelength:a({},i.namelength,{arrayOk:!0}),editType:\"none\"}}},{\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"./layout_attributes\":633}],624:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");function a(t,e,r,i){i=i||n.identity,Array.isArray(t)&&(e[0][r]=i(t))}e.exports=function(t){var e=t.calcdata,r=t._fullLayout;function o(t){return function(e){return n.coerceHoverinfo({hoverinfo:e},{_module:t._module},r)}}for(var s=0;s<e.length;s++){var l=e[s],c=l[0].trace;if(!i.traceIs(c,\"pie-like\")){var u=i.traceIs(c,\"2dMap\")?a:n.fillArray;u(c.hoverinfo,l,\"hi\",o(c)),c.hovertemplate&&u(c.hovertemplate,l,\"ht\"),c.hoverlabel&&(u(c.hoverlabel.bgcolor,l,\"hbg\"),u(c.hoverlabel.bordercolor,l,\"hbc\"),u(c.hoverlabel.font.size,l,\"hts\"),u(c.hoverlabel.font.color,l,\"htc\"),u(c.hoverlabel.font.family,l,\"htf\"),u(c.hoverlabel.namelength,l,\"hnl\"),u(c.hoverlabel.align,l,\"hta\"))}}}},{\"../../lib\":719,\"../../registry\":847}],625:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./hover\").hover;e.exports=function(t,e,r){var a=n.getComponentMethod(\"annotations\",\"onClick\")(t,t._hoverdata);function o(){t.emit(\"plotly_click\",{points:t._hoverdata,event:e})}void 0!==r&&i(t,e,r,!0),t._hoverdata&&e&&e.target&&(a&&a.then?a.then(o):o(),e.stopImmediatePropagation&&e.stopImmediatePropagation())}},{\"../../registry\":847,\"./hover\":629}],626:[function(t,e,r){\"use strict\";e.exports={YANGLE:60,HOVERARROWSIZE:6,HOVERTEXTPAD:3,HOVERFONTSIZE:13,HOVERFONT:\"Arial, sans-serif\",HOVERMINTIME:50,HOVERID:\"-hover\"}},{}],627:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./hoverlabel_defaults\");e.exports=function(t,e,r,o){var s=n.extendFlat({},o.hoverlabel);e.hovertemplate&&(s.namelength=-1),a(t,e,function(r,a){return n.coerce(t,e,i,r,a)},s)}},{\"../../lib\":719,\"./attributes\":623,\"./hoverlabel_defaults\":630}],628:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");r.getSubplot=function(t){return t.subplot||t.xaxis+t.yaxis||t.geo},r.isTraceInSubplots=function(t,e){if(\"splom\"===t.type){for(var n=t.xaxes||[],i=t.yaxes||[],a=0;a<n.length;a++)for(var o=0;o<i.length;o++)if(-1!==e.indexOf(n[a]+i[o]))return!0;return!1}return-1!==e.indexOf(r.getSubplot(t))},r.flat=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=e;return r},r.p2c=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=t[n].p2c(e);return r},r.getDistanceFunction=function(t,e,n,i){return\"closest\"===t?i||r.quadrature(e,n):\"x\"===t?e:n},r.getClosest=function(t,e,r){if(!1!==r.index)r.index>=0&&r.index<t.length?r.distance=0:r.index=!1;else for(var n=0;n<t.length;n++){var i=e(t[n]);i<=r.distance&&(r.index=n,r.distance=i)}return r},r.inbox=function(t,e,r){return t*e<0||0===t?r:1/0},r.quadrature=function(t,e){return function(r){var n=t(r),i=e(r);return Math.sqrt(n*n+i*i)}},r.makeEventData=function(t,e,n){var i=\"index\"in t?t.index:t.pointNumber,a={data:e._input,fullData:e,curveNumber:e.index,pointNumber:i};if(e._indexToPoints){var o=e._indexToPoints[i];1===o.length?a.pointIndex=o[0]:a.pointIndices=o}else a.pointIndex=i;return e._module.eventData?a=e._module.eventData(a,t,e,n,i):(\"xVal\"in t?a.x=t.xVal:\"x\"in t&&(a.x=t.x),\"yVal\"in t?a.y=t.yVal:\"y\"in t&&(a.y=t.y),t.xa&&(a.xaxis=t.xa),t.ya&&(a.yaxis=t.ya),void 0!==t.zLabelVal&&(a.z=t.zLabelVal)),r.appendArrayPointValue(a,e,i),a},r.appendArrayPointValue=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){var u=o(n.nestedProperty(e,l).get(),r);void 0!==u&&(t[c]=u)}}},r.appendArrayMultiPointValues=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){for(var u=n.nestedProperty(e,l).get(),h=new Array(r.length),f=0;f<r.length;f++)h[f]=o(u,r[f]);t[c]=h}}};var i={ids:\"id\",locations:\"location\",labels:\"label\",values:\"value\",\"marker.colors\":\"color\",parents:\"parent\"};function a(t){return i[t]||t}function o(t,e){return Array.isArray(e)?Array.isArray(t)&&Array.isArray(t[e[0]])?t[e[0]][e[1]]:void 0:t[e]}},{\"../../lib\":719}],629:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../lib\"),s=t(\"../../lib/events\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib/override_cursor\"),u=t(\"../drawing\"),h=t(\"../color\"),f=t(\"../dragelement\"),p=t(\"../../plots/cartesian/axes\"),d=t(\"../../registry\"),g=t(\"./helpers\"),v=t(\"./constants\"),m=v.YANGLE,y=Math.PI*m/180,x=1/Math.sin(y),b=Math.cos(y),_=Math.sin(y),w=v.HOVERARROWSIZE,k=v.HOVERTEXTPAD;r.hover=function(t,e,r,a){t=o.getGraphDiv(t),o.throttle(t._fullLayout._uid+v.HOVERID,v.HOVERMINTIME,function(){!function(t,e,r,a){r||(r=\"xy\");var l=Array.isArray(r)?r:[r],u=t._fullLayout,v=u._plots||[],m=v[r],y=u._has(\"cartesian\");if(m){var b=m.overlays.map(function(t){return t.id});l=l.concat(b)}for(var _=l.length,w=new Array(_),k=new Array(_),T=!1,L=0;L<_;L++){var P=l[L],O=v[P];if(O)T=!0,w[L]=p.getFromId(t,O.xaxis._id),k[L]=p.getFromId(t,O.yaxis._id);else{var z=u[P]._subplot;w[L]=z.xaxis,k[L]=z.yaxis}}var I=e.hovermode||u.hovermode;I&&!T&&(I=\"closest\");if(-1===[\"x\",\"y\",\"closest\"].indexOf(I)||!t.calcdata||t.querySelector(\".zoombox\")||t._dragging)return f.unhoverRaw(t,e);var D,R,F,B,N,j,U,V,q,H,G,Y,W,X=-1===u.hoverdistance?1/0:u.hoverdistance,Z=-1===u.spikedistance?1/0:u.spikedistance,J=[],K=[],$={hLinePoint:null,vLinePoint:null},Q=!1;if(Array.isArray(e))for(I=\"array\",F=0;F<e.length;F++)(N=t.calcdata[e[F].curveNumber||0])&&(j=N[0].trace,\"skip\"!==N[0].trace.hoverinfo&&(K.push(N),\"h\"===j.orientation&&(Q=!0)));else{for(B=0;B<t.calcdata.length;B++)N=t.calcdata[B],\"skip\"!==(j=N[0].trace).hoverinfo&&g.isTraceInSubplots(j,l)&&(K.push(N),\"h\"===j.orientation&&(Q=!0));var tt,et,rt=!e.target;if(rt)tt=\"xpx\"in e?e.xpx:w[0]._length/2,et=\"ypx\"in e?e.ypx:k[0]._length/2;else{if(!1===s.triggerHandler(t,\"plotly_beforehover\",e))return;var nt=e.target.getBoundingClientRect();if(tt=e.clientX-nt.left,et=e.clientY-nt.top,tt<0||tt>w[0]._length||et<0||et>k[0]._length)return f.unhoverRaw(t,e)}if(e.pointerX=tt+w[0]._offset,e.pointerY=et+k[0]._offset,D=\"xval\"in e?g.flat(l,e.xval):g.p2c(w,tt),R=\"yval\"in e?g.flat(l,e.yval):g.p2c(k,et),!i(D[0])||!i(R[0]))return o.warn(\"Fx.hover failed\",e,t),f.unhoverRaw(t,e)}var it=1/0;for(B=0;B<K.length;B++)if((N=K[B])&&N[0]&&N[0].trace&&!0===(j=N[0].trace).visible&&0!==j._length&&-1===[\"carpet\",\"contourcarpet\"].indexOf(j._module.name)){if(\"splom\"===j.type?U=l[V=0]:(U=g.getSubplot(j),V=l.indexOf(U)),q=I,Y={cd:N,trace:j,xa:w[V],ya:k[V],maxHoverDistance:X,maxSpikeDistance:Z,index:!1,distance:Math.min(it,X),spikeDistance:1/0,xSpike:void 0,ySpike:void 0,color:h.defaultLine,name:j.name,x0:void 0,x1:void 0,y0:void 0,y1:void 0,xLabelVal:void 0,yLabelVal:void 0,zLabelVal:void 0,text:void 0},u[U]&&(Y.subplot=u[U]._subplot),u._splomScenes&&u._splomScenes[j.uid]&&(Y.scene=u._splomScenes[j.uid]),W=J.length,\"array\"===q){var at=e[B];\"pointNumber\"in at?(Y.index=at.pointNumber,q=\"closest\"):(q=\"\",\"xval\"in at&&(H=at.xval,q=\"x\"),\"yval\"in at&&(G=at.yval,q=q?\"closest\":\"y\"))}else H=D[V],G=R[V];if(0!==X)if(j._module&&j._module.hoverPoints){var ot=j._module.hoverPoints(Y,H,G,q,u._hoverlayer);if(ot)for(var st,lt=0;lt<ot.length;lt++)st=ot[lt],i(st.x0)&&i(st.y0)&&J.push(S(st,I))}else o.log(\"Unrecognized trace type in hover:\",j);if(\"closest\"===I&&J.length>W&&(J.splice(0,W),it=J[0].distance),y&&0!==Z&&0===J.length){Y.distance=Z,Y.index=!1;var ct=j._module.hoverPoints(Y,H,G,\"closest\",u._hoverlayer);if(ct&&(ct=ct.filter(function(t){return t.spikeDistance<=Z})),ct&&ct.length){var ut,ht=ct.filter(function(t){return t.xa.showspikes});if(ht.length){var ft=ht[0];i(ft.x0)&&i(ft.y0)&&(ut=vt(ft),(!$.vLinePoint||$.vLinePoint.spikeDistance>ut.spikeDistance)&&($.vLinePoint=ut))}var pt=ct.filter(function(t){return t.ya.showspikes});if(pt.length){var dt=pt[0];i(dt.x0)&&i(dt.y0)&&(ut=vt(dt),(!$.hLinePoint||$.hLinePoint.spikeDistance>ut.spikeDistance)&&($.hLinePoint=ut))}}}}function gt(t,e){for(var r,n=null,i=1/0,a=0;a<t.length;a++)(r=t[a].spikeDistance)<i&&r<=e&&(n=t[a],i=r);return n}function vt(t){return t?{xa:t.xa,ya:t.ya,x:void 0!==t.xSpike?t.xSpike:(t.x0+t.x1)/2,y:void 0!==t.ySpike?t.ySpike:(t.y0+t.y1)/2,distance:t.distance,spikeDistance:t.spikeDistance,curveNumber:t.trace.index,color:t.color,pointNumber:t.index}:null}var mt={fullLayout:u,container:u._hoverlayer,outerContainer:u._paperdiv,event:e},yt=t._spikepoints,xt={vLinePoint:$.vLinePoint,hLinePoint:$.hLinePoint};if(t._spikepoints=xt,y&&0!==Z&&0!==J.length){var bt=J.filter(function(t){return t.ya.showspikes}),_t=gt(bt,Z);$.hLinePoint=vt(_t);var wt=J.filter(function(t){return t.xa.showspikes}),kt=gt(wt,Z);$.vLinePoint=vt(kt)}if(0===J.length){var Tt=f.unhoverRaw(t,e);return!y||null===$.hLinePoint&&null===$.vLinePoint||C(yt)&&E($,mt),Tt}y&&C(yt)&&E($,mt);J.sort(function(t,e){return t.distance-e.distance});var At=t._hoverdata,Mt=[];for(F=0;F<J.length;F++){var St=J[F],Et=g.makeEventData(St,St.trace,St.cd);if(!1!==St.hovertemplate){var Ct=!1;St.cd[St.index]&&St.cd[St.index].ht&&(Ct=St.cd[St.index].ht),St.hovertemplate=Ct||St.trace.hovertemplate||!1}St.eventData=[Et],Mt.push(Et)}t._hoverdata=Mt;var Lt=\"y\"===I&&(K.length>1||J.length>1)||\"closest\"===I&&Q&&J.length>1,Pt=h.combine(u.plot_bgcolor||h.background,u.paper_bgcolor),Ot={hovermode:I,rotateLabels:Lt,bgColor:Pt,container:u._hoverlayer,outerContainer:u._paperdiv,commonLabelOpts:u.hoverlabel,hoverdistance:u.hoverdistance},zt=A(J,Ot,t);if(function(t,e,r){var n,i,a,o,s,l,c,u=0,h=1,f=t.size(),p=new Array(f),d=0;function g(t){var e=t[0],r=t[t.length-1];if(i=e.pmin-e.pos-e.dp+e.size,a=r.pos+r.dp+r.size-e.pmax,i>.01){for(s=t.length-1;s>=0;s--)t[s].dp+=i;n=!1}if(!(a<.01)){if(i<-.01){for(s=t.length-1;s>=0;s--)t[s].dp-=a;n=!1}if(n){var c=0;for(o=0;o<t.length;o++)(l=t[o]).pos+l.dp+l.size>e.pmax&&c++;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos>e.pmax-1&&(l.del=!0,c--);for(o=0;o<t.length&&!(c<=0);o++)if((l=t[o]).pos<e.pmin+1)for(l.del=!0,c--,a=2*l.size,s=t.length-1;s>=0;s--)t[s].dp-=a;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos+l.dp+l.size>e.pmax&&(l.del=!0,c--)}}}for(t.each(function(t){var n=t[e],i=\"x\"===n._id.charAt(0),a=n.range;0===d&&a&&a[0]>a[1]!==i&&(h=-1),p[d++]=[{datum:t,traceIndex:t.trace.index,dp:0,pos:t.pos,posref:t.posref,size:t.by*(i?x:1)/2,pmin:0,pmax:i?r.width:r.height}]}),p.sort(function(t,e){return t[0].posref-e[0].posref||h*(e[0].traceIndex-t[0].traceIndex)});!n&&u<=f;){for(u++,n=!0,o=0;o<p.length-1;){var v=p[o],m=p[o+1],y=v[v.length-1],b=m[0];if((i=y.pos+y.dp+y.size-b.pos-b.dp+b.size)>.01&&y.pmin===b.pmin&&y.pmax===b.pmax){for(s=m.length-1;s>=0;s--)m[s].dp+=i;for(v.push.apply(v,m),p.splice(o+1,1),c=0,s=v.length-1;s>=0;s--)c+=v[s].dp;for(a=c/v.length,s=v.length-1;s>=0;s--)v[s].dp-=a;n=!1}else o++}p.forEach(g)}for(o=p.length-1;o>=0;o--){var _=p[o];for(s=_.length-1;s>=0;s--){var w=_[s],k=w.datum;k.offset=w.dp,k.del=w.del}}}(zt,Lt?\"xa\":\"ya\",u),M(zt,Lt),e.target&&e.target.tagName){var It=d.getComponentMethod(\"annotations\",\"hasClickToShow\")(t,Mt);c(n.select(e.target),It?\"pointer\":\"\")}if(!e.target||a||!function(t,e,r){if(!r||r.length!==t._hoverdata.length)return!0;for(var n=r.length-1;n>=0;n--){var i=r[n],a=t._hoverdata[n];if(i.curveNumber!==a.curveNumber||String(i.pointNumber)!==String(a.pointNumber)||String(i.pointNumbers)!==String(a.pointNumbers))return!0}return!1}(t,0,At))return;At&&t.emit(\"plotly_unhover\",{event:e,points:At});t.emit(\"plotly_hover\",{event:e,points:t._hoverdata,xaxes:w,yaxes:k,xvals:D,yvals:R})}(t,e,r,a)})},r.loneHover=function(t,e){var r=!0;Array.isArray(t)||(r=!1,t=[t]);var i=t.map(function(t){return{color:t.color||h.defaultLine,x0:t.x0||t.x||0,x1:t.x1||t.x||0,y0:t.y0||t.y||0,y1:t.y1||t.y||0,xLabel:t.xLabel,yLabel:t.yLabel,zLabel:t.zLabel,text:t.text,name:t.name,idealAlign:t.idealAlign,borderColor:t.borderColor,fontFamily:t.fontFamily,fontSize:t.fontSize,fontColor:t.fontColor,nameLength:t.nameLength,textAlign:t.textAlign,trace:t.trace||{index:0,hoverinfo:\"\"},xa:{_offset:0},ya:{_offset:0},index:0,hovertemplate:t.hovertemplate||!1,eventData:t.eventData||!1,hovertemplateLabels:t.hovertemplateLabels||!1}}),a=n.select(e.container),o=e.outerContainer?n.select(e.outerContainer):a,s={hovermode:\"closest\",rotateLabels:!1,bgColor:e.bgColor||h.background,container:a,outerContainer:o},l=A(i,s,e.gd),c=0,u=0;return l.sort(function(t,e){return t.y0-e.y0}).each(function(t,r){var n=t.y0-t.by/2;t.offset=n-5<c?c-n+5:0,c=n+t.by+t.offset,r===e.anchorIndex&&(u=t.offset)}).each(function(t){t.offset-=u}),M(l,s.rotateLabels),r?l:l.node()};var T=/<extra>([\\s\\S]*)<\\/extra>/;function A(t,e,r){var i=r._fullLayout,a=e.hovermode,s=e.rotateLabels,c=e.bgColor,f=e.container,p=e.outerContainer,d=e.commonLabelOpts||{},g=e.fontFamily||v.HOVERFONT,y=e.fontSize||v.HOVERFONTSIZE,x=t[0],b=x.xa,_=x.ya,A=\"y\"===a?\"yLabel\":\"xLabel\",M=x[A],S=(String(M)||\"\").split(\" \")[0],E=p.node().getBoundingClientRect(),C=E.top,P=E.width,O=E.height,z=void 0!==M&&x.distance<=e.hoverdistance&&(\"x\"===a||\"y\"===a);if(z){var I,D,R=!0;for(I=0;I<t.length;I++)if(R&&void 0===t[I].zLabel&&(R=!1),D=t[I].hoverinfo||t[I].trace.hoverinfo){var F=Array.isArray(D)?D:D.split(\"+\");if(-1===F.indexOf(\"all\")&&-1===F.indexOf(a)){z=!1;break}}R&&(z=!1)}var B=f.selectAll(\"g.axistext\").data(z?[0]:[]);B.enter().append(\"g\").classed(\"axistext\",!0),B.exit().remove(),B.each(function(){var e=n.select(this),i=o.ensureSingle(e,\"path\",\"\",function(t){t.style({\"stroke-width\":\"1px\"})}),s=o.ensureSingle(e,\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),c=d.bgcolor||h.defaultLine,f=d.bordercolor||h.contrast(c),p=h.contrast(c);i.style({fill:c,stroke:f}),s.text(M).call(u.font,d.font.family||g,d.font.size||y,d.font.color||p).call(l.positionText,0,0).call(l.convertToTspans,r),e.attr(\"transform\",\"\");var v=s.node().getBoundingClientRect();if(\"x\"===a){s.attr(\"text-anchor\",\"middle\").call(l.positionText,0,\"top\"===b.side?C-v.bottom-w-k:C-v.top+w+k);var m=\"top\"===b.side?\"-\":\"\";i.attr(\"d\",\"M0,0L\"+w+\",\"+m+w+\"H\"+(k+v.width/2)+\"v\"+m+(2*k+v.height)+\"H-\"+(k+v.width/2)+\"V\"+m+w+\"H-\"+w+\"Z\"),e.attr(\"transform\",\"translate(\"+(b._offset+(x.x0+x.x1)/2)+\",\"+(_._offset+(\"top\"===b.side?0:_._length))+\")\")}else{s.attr(\"text-anchor\",\"right\"===_.side?\"start\":\"end\").call(l.positionText,(\"right\"===_.side?1:-1)*(k+w),C-v.top-v.height/2);var T=\"right\"===_.side?\"\":\"-\";i.attr(\"d\",\"M0,0L\"+T+w+\",\"+w+\"V\"+(k+v.height/2)+\"h\"+T+(2*k+v.width)+\"V-\"+(k+v.height/2)+\"H\"+T+w+\"V-\"+w+\"Z\"),e.attr(\"transform\",\"translate(\"+(b._offset+(\"right\"===_.side?b._length:0))+\",\"+(_._offset+(x.y0+x.y1)/2)+\")\")}t=t.filter(function(t){return void 0!==t.zLabelVal||(t[A]||\"\").split(\" \")[0]===S})});var N=f.selectAll(\"g.hovertext\").data(t,function(t){return[t.trace.index,t.index,t.x0,t.y0,t.name,t.attr,t.xa,t.ya||\"\"].join(\",\")});return N.enter().append(\"g\").classed(\"hovertext\",!0).each(function(){var t=n.select(this);t.append(\"rect\").call(h.fill,h.addOpacity(c,.8)),t.append(\"text\").classed(\"name\",!0),t.append(\"path\").style(\"stroke-width\",\"1px\"),t.append(\"text\").classed(\"nums\",!0).call(u.font,g,y)}),N.exit().remove(),N.each(function(t){var e=n.select(this).attr(\"transform\",\"\"),f=\"\",p=\"\",d=t.bgcolor||t.color,v=h.combine(h.opacity(d)?d:h.defaultLine,c),x=h.combine(h.opacity(t.color)?t.color:h.defaultLine,c),b=t.borderColor||h.contrast(v);void 0!==t.nameOverride&&(t.name=t.nameOverride),t.name&&(t.trace._meta&&(t.name=o.templateString(t.name,t.trace._meta)),f=L(t.name,t.nameLength)),void 0!==t.zLabel?(void 0!==t.xLabel&&(p+=\"x: \"+t.xLabel+\"<br>\"),void 0!==t.yLabel&&(p+=\"y: \"+t.yLabel+\"<br>\"),\"choropleth\"!==t.trace.type&&\"choroplethmapbox\"!==t.trace.type&&(p+=(p?\"z: \":\"\")+t.zLabel)):z&&t[a+\"Label\"]===M?p=t[(\"x\"===a?\"y\":\"x\")+\"Label\"]||\"\":void 0===t.xLabel?void 0!==t.yLabel&&\"scattercarpet\"!==t.trace.type&&(p=t.yLabel):p=void 0===t.yLabel?t.xLabel:\"(\"+t.xLabel+\", \"+t.yLabel+\")\",!t.text&&0!==t.text||Array.isArray(t.text)||(p+=(p?\"<br>\":\"\")+t.text),void 0!==t.extraText&&(p+=(p?\"<br>\":\"\")+t.extraText),\"\"!==p||t.hovertemplate||(\"\"===f&&e.remove(),p=f);var _=i._d3locale,A=t.hovertemplate||!1,S=t.hovertemplateLabels||t,E=t.eventData[0]||{};A&&(p=(p=o.hovertemplateString(A,S,_,E,t.trace._meta)).replace(T,function(e,r){return f=L(r,t.nameLength),\"\"}));var I=e.select(\"text.nums\").call(u.font,t.fontFamily||g,t.fontSize||y,t.fontColor||b).text(p).attr(\"data-notex\",1).call(l.positionText,0,0).call(l.convertToTspans,r),D=e.select(\"text.name\"),R=0,F=0;if(f&&f!==p){D.call(u.font,t.fontFamily||g,t.fontSize||y,x).text(f).attr(\"data-notex\",1).call(l.positionText,0,0).call(l.convertToTspans,r);var B=D.node().getBoundingClientRect();R=B.width+2*k,F=B.height+2*k}else D.remove(),e.select(\"rect\").remove();e.select(\"path\").style({fill:v,stroke:b});var N,j,U=I.node().getBoundingClientRect(),V=t.xa._offset+(t.x0+t.x1)/2,q=t.ya._offset+(t.y0+t.y1)/2,H=Math.abs(t.x1-t.x0),G=Math.abs(t.y1-t.y0),Y=U.width+w+k+R;if(t.ty0=C-U.top,t.bx=U.width+2*k,t.by=Math.max(U.height+2*k,F),t.anchor=\"start\",t.txwidth=U.width,t.tx2width=R,t.offset=0,s)t.pos=V,N=q+G/2+Y<=O,j=q-G/2-Y>=0,\"top\"!==t.idealAlign&&N||!j?N?(q+=G/2,t.anchor=\"start\"):t.anchor=\"middle\":(q-=G/2,t.anchor=\"end\");else if(t.pos=q,N=V+H/2+Y<=P,j=V-H/2-Y>=0,\"left\"!==t.idealAlign&&N||!j)if(N)V+=H/2,t.anchor=\"start\";else{t.anchor=\"middle\";var W=Y/2,X=V+W-P,Z=V-W;X>0&&(V-=X),Z<0&&(V+=-Z)}else V-=H/2,t.anchor=\"end\";I.attr(\"text-anchor\",t.anchor),R&&D.attr(\"text-anchor\",t.anchor),e.attr(\"transform\",\"translate(\"+V+\",\"+q+\")\"+(s?\"rotate(\"+m+\")\":\"\"))}),N}function M(t,e){t.each(function(t){var r=n.select(this);if(t.del)return r.remove();var i=r.select(\"text.nums\"),a=t.anchor,o=\"end\"===a?-1:1,s={start:1,end:-1,middle:0}[a],c=s*(w+k),h=c+s*(t.txwidth+k),f=0,p=t.offset;\"middle\"===a&&(c-=t.tx2width/2,h+=t.txwidth/2+k),e&&(p*=-_,f=t.offset*b),r.select(\"path\").attr(\"d\",\"middle\"===a?\"M-\"+(t.bx/2+t.tx2width/2)+\",\"+(p-t.by/2)+\"h\"+t.bx+\"v\"+t.by+\"h-\"+t.bx+\"Z\":\"M0,0L\"+(o*w+f)+\",\"+(w+p)+\"v\"+(t.by/2-w)+\"h\"+o*t.bx+\"v-\"+t.by+\"H\"+(o*w+f)+\"V\"+(p-w)+\"Z\");var d=c+f,g=p+t.ty0-t.by/2+k,v=t.textAlign||\"auto\";\"auto\"!==v&&(\"left\"===v&&\"start\"!==a?(i.attr(\"text-anchor\",\"start\"),d=\"middle\"===a?-t.bx/2-t.tx2width/2+k:-t.bx-k):\"right\"===v&&\"end\"!==a&&(i.attr(\"text-anchor\",\"end\"),d=\"middle\"===a?t.bx/2-t.tx2width/2-k:t.bx+k)),i.call(l.positionText,d,g),t.tx2width&&(r.select(\"text.name\").call(l.positionText,h+s*k+f,p+t.ty0-t.by/2+k),r.select(\"rect\").call(u.setRect,h+(s-1)*t.tx2width/2+f,p-t.by/2-1,t.tx2width,t.by+2))})}function S(t,e){var r=t.index,n=t.trace||{},a=t.cd[0],s=t.cd[r]||{};function l(t){return t||i(t)&&0===t}var c=Array.isArray(r)?function(t,e){var i=o.castOption(a,r,t);return l(i)?i:o.extractOption({},n,\"\",e)}:function(t,e){return o.extractOption(s,n,t,e)};function u(e,r,n){var i=c(r,n);l(i)&&(t[e]=i)}if(u(\"hoverinfo\",\"hi\",\"hoverinfo\"),u(\"bgcolor\",\"hbg\",\"hoverlabel.bgcolor\"),u(\"borderColor\",\"hbc\",\"hoverlabel.bordercolor\"),u(\"fontFamily\",\"htf\",\"hoverlabel.font.family\"),u(\"fontSize\",\"hts\",\"hoverlabel.font.size\"),u(\"fontColor\",\"htc\",\"hoverlabel.font.color\"),u(\"nameLength\",\"hnl\",\"hoverlabel.namelength\"),u(\"textAlign\",\"hta\",\"hoverlabel.align\"),t.posref=\"y\"===e||\"closest\"===e&&\"h\"===n.orientation?t.xa._offset+(t.x0+t.x1)/2:t.ya._offset+(t.y0+t.y1)/2,t.x0=o.constrain(t.x0,0,t.xa._length),t.x1=o.constrain(t.x1,0,t.xa._length),t.y0=o.constrain(t.y0,0,t.ya._length),t.y1=o.constrain(t.y1,0,t.ya._length),void 0!==t.xLabelVal&&(t.xLabel=\"xLabel\"in t?t.xLabel:p.hoverLabelText(t.xa,t.xLabelVal),t.xVal=t.xa.c2d(t.xLabelVal)),void 0!==t.yLabelVal&&(t.yLabel=\"yLabel\"in t?t.yLabel:p.hoverLabelText(t.ya,t.yLabelVal),t.yVal=t.ya.c2d(t.yLabelVal)),void 0!==t.zLabelVal&&void 0===t.zLabel&&(t.zLabel=String(t.zLabelVal)),!(isNaN(t.xerr)||\"log\"===t.xa.type&&t.xerr<=0)){var h=p.tickText(t.xa,t.xa.c2l(t.xerr),\"hover\").text;void 0!==t.xerrneg?t.xLabel+=\" +\"+h+\" / -\"+p.tickText(t.xa,t.xa.c2l(t.xerrneg),\"hover\").text:t.xLabel+=\" \\xb1 \"+h,\"x\"===e&&(t.distance+=1)}if(!(isNaN(t.yerr)||\"log\"===t.ya.type&&t.yerr<=0)){var f=p.tickText(t.ya,t.ya.c2l(t.yerr),\"hover\").text;void 0!==t.yerrneg?t.yLabel+=\" +\"+f+\" / -\"+p.tickText(t.ya,t.ya.c2l(t.yerrneg),\"hover\").text:t.yLabel+=\" \\xb1 \"+f,\"y\"===e&&(t.distance+=1)}var d=t.hoverinfo||t.trace.hoverinfo;return d&&\"all\"!==d&&(-1===(d=Array.isArray(d)?d:d.split(\"+\")).indexOf(\"x\")&&(t.xLabel=void 0),-1===d.indexOf(\"y\")&&(t.yLabel=void 0),-1===d.indexOf(\"z\")&&(t.zLabel=void 0),-1===d.indexOf(\"text\")&&(t.text=void 0),-1===d.indexOf(\"name\")&&(t.name=void 0)),t}function E(t,e){var r,n,i=e.container,o=e.fullLayout,s=e.event,l=!!t.hLinePoint,c=!!t.vLinePoint;if(i.selectAll(\".spikeline\").remove(),c||l){var f=h.combine(o.plot_bgcolor,o.paper_bgcolor);if(l){var p,d,g=t.hLinePoint;r=g&&g.xa,\"cursor\"===(n=g&&g.ya).spikesnap?(p=s.pointerX,d=s.pointerY):(p=r._offset+g.x,d=n._offset+g.y);var v,m,y=a.readability(g.color,f)<1.5?h.contrast(f):g.color,x=n.spikemode,b=n.spikethickness,_=n.spikecolor||y,w=n._boundingBox,k=(w.left+w.right)/2<p?w.right:w.left;-1===x.indexOf(\"toaxis\")&&-1===x.indexOf(\"across\")||(-1!==x.indexOf(\"toaxis\")&&(v=k,m=p),-1!==x.indexOf(\"across\")&&(v=n._counterSpan[0],m=n._counterSpan[1]),i.insert(\"line\",\":first-child\").attr({x1:v,x2:m,y1:d,y2:d,\"stroke-width\":b,stroke:_,\"stroke-dasharray\":u.dashStyle(n.spikedash,b)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),i.insert(\"line\",\":first-child\").attr({x1:v,x2:m,y1:d,y2:d,\"stroke-width\":b+2,stroke:f}).classed(\"spikeline\",!0).classed(\"crisp\",!0)),-1!==x.indexOf(\"marker\")&&i.insert(\"circle\",\":first-child\").attr({cx:k+(\"right\"!==n.side?b:-b),cy:d,r:b,fill:_}).classed(\"spikeline\",!0)}if(c){var T,A,M=t.vLinePoint;r=M&&M.xa,n=M&&M.ya,\"cursor\"===r.spikesnap?(T=s.pointerX,A=s.pointerY):(T=r._offset+M.x,A=n._offset+M.y);var S,E,C=a.readability(M.color,f)<1.5?h.contrast(f):M.color,L=r.spikemode,P=r.spikethickness,O=r.spikecolor||C,z=r._boundingBox,I=(z.top+z.bottom)/2<A?z.bottom:z.top;-1===L.indexOf(\"toaxis\")&&-1===L.indexOf(\"across\")||(-1!==L.indexOf(\"toaxis\")&&(S=I,E=A),-1!==L.indexOf(\"across\")&&(S=r._counterSpan[0],E=r._counterSpan[1]),i.insert(\"line\",\":first-child\").attr({x1:T,x2:T,y1:S,y2:E,\"stroke-width\":P,stroke:O,\"stroke-dasharray\":u.dashStyle(r.spikedash,P)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),i.insert(\"line\",\":first-child\").attr({x1:T,x2:T,y1:S,y2:E,\"stroke-width\":P+2,stroke:f}).classed(\"spikeline\",!0).classed(\"crisp\",!0)),-1!==L.indexOf(\"marker\")&&i.insert(\"circle\",\":first-child\").attr({cx:T,cy:I-(\"top\"!==r.side?P:-P),r:P,fill:O}).classed(\"spikeline\",!0)}}}function C(t,e){return!e||(e.vLinePoint!==t._spikepoints.vLinePoint||e.hLinePoint!==t._spikepoints.hLinePoint)}function L(t,e){return l.plainText(t||\"\",{len:e,allowedTags:[\"br\",\"sub\",\"sup\",\"b\",\"i\",\"em\"]})}},{\"../../lib\":719,\"../../lib/events\":709,\"../../lib/override_cursor\":730,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"./constants\":626,\"./helpers\":628,d3:163,\"fast-isnumeric\":225,tinycolor2:537}],630:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i){r(\"hoverlabel.bgcolor\",(i=i||{}).bgcolor),r(\"hoverlabel.bordercolor\",i.bordercolor),r(\"hoverlabel.namelength\",i.namelength),n.coerceFont(r,\"hoverlabel.font\",i.font),r(\"hoverlabel.align\",i.align)}},{\"../../lib\":719}],631:[function(t,e,r){\"use strict\";t(\"../../constants/docs\").FORMAT_LINK;e.exports=function(t,e){t=t||{};(e=e||{}).description&&e.description;var r=e.keys||[];if(r.length>0){for(var n=[],i=0;i<r.length;i++)n[i]=\"`\"+r[i]+\"`\";\"Finally, the template string has access to \",1===r.length?\"variable \"+n[0]:\"variables \"+n.slice(0,-1).join(\", \")+\" and \"+n.slice(-1)+\".\"}var a={valType:\"string\",dflt:\"\",editType:t.editType||\"none\"};return!1!==t.arrayOk&&(a.arrayOk=!0),a}},{\"../../constants/docs\":690}],632:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../dragelement\"),o=t(\"./helpers\"),s=t(\"./layout_attributes\"),l=t(\"./hover\");e.exports={moduleType:\"component\",name:\"fx\",constants:t(\"./constants\"),schema:{layout:s},attributes:t(\"./attributes\"),layoutAttributes:s,supplyLayoutGlobalDefaults:t(\"./layout_global_defaults\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),getDistanceFunction:o.getDistanceFunction,getClosest:o.getClosest,inbox:o.inbox,quadrature:o.quadrature,appendArrayPointValue:o.appendArrayPointValue,castHoverOption:function(t,e,r){return i.castOption(t,e,\"hoverlabel.\"+r)},castHoverinfo:function(t,e,r){return i.castOption(t,r,\"hoverinfo\",function(r){return i.coerceHoverinfo({hoverinfo:r},{_module:t._module},e)})},hover:l.hover,unhover:a.unhover,loneHover:l.loneHover,loneUnhover:function(t){var e=i.isD3Selection(t)?t:n.select(t);e.selectAll(\"g.hovertext\").remove(),e.selectAll(\".spikeline\").remove()},click:t(\"./click\")}},{\"../../lib\":719,\"../dragelement\":611,\"./attributes\":623,\"./calc\":624,\"./click\":625,\"./constants\":626,\"./defaults\":627,\"./helpers\":628,\"./hover\":629,\"./layout_attributes\":633,\"./layout_defaults\":634,\"./layout_global_defaults\":635,d3:163}],633:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../plots/font_attributes\")({editType:\"none\"});i.family.dflt=n.HOVERFONT,i.size.dflt=n.HOVERFONTSIZE,e.exports={clickmode:{valType:\"flaglist\",flags:[\"event\",\"select\"],dflt:\"event\",editType:\"plot\",extras:[\"none\"]},dragmode:{valType:\"enumerated\",values:[\"zoom\",\"pan\",\"select\",\"lasso\",\"orbit\",\"turntable\",!1],dflt:\"zoom\",editType:\"modebar\"},hovermode:{valType:\"enumerated\",values:[\"x\",\"y\",\"closest\",!1],editType:\"modebar\"},hoverdistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},spikedistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"none\"},bordercolor:{valType:\"color\",editType:\"none\"},font:i,align:{valType:\"enumerated\",values:[\"left\",\"right\",\"auto\"],dflt:\"auto\",editType:\"none\"},namelength:{valType:\"integer\",min:-1,dflt:15,editType:\"none\"},editType:\"none\"},selectdirection:{valType:\"enumerated\",values:[\"h\",\"v\",\"d\",\"any\"],dflt:\"any\",editType:\"none\"}}},{\"../../plots/font_attributes\":793,\"./constants\":626}],634:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){function a(r,a){return n.coerce(t,e,i,r,a)}var o,s=a(\"clickmode\");\"select\"===a(\"dragmode\")&&a(\"selectdirection\"),e._has(\"cartesian\")?s.indexOf(\"select\")>-1?o=\"closest\":(e._isHoriz=function(t,e){for(var r=e._scatterStackOpts||{},n=0;n<t.length;n++){var i=t[n],a=i.xaxis+i.yaxis,o=r[a]||{},s=o[i.stackgroup]||{};if(\"h\"!==i.orientation&&\"h\"!==s.orientation)return!1}return!0}(r,e),o=e._isHoriz?\"y\":\"x\"):o=\"closest\",a(\"hovermode\",o)&&(a(\"hoverdistance\"),a(\"spikedistance\"));var l=e._has(\"mapbox\"),c=e._has(\"geo\"),u=e._basePlotModules.length;\"zoom\"===e.dragmode&&((l||c)&&1===u||l&&c&&2===u)&&(e.dragmode=\"pan\")}},{\"../../lib\":719,\"./layout_attributes\":633}],635:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./hoverlabel_defaults\"),a=t(\"./layout_attributes\");e.exports=function(t,e){i(t,e,function(r,i){return n.coerce(t,e,a,r,i)})}},{\"../../lib\":719,\"./hoverlabel_defaults\":630,\"./layout_attributes\":633}],636:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/regex\").counter,a=t(\"../../plots/domain\").attributes,o=t(\"../../plots/cartesian/constants\").idRegex,s=t(\"../../plot_api/plot_template\"),l={rows:{valType:\"integer\",min:1,editType:\"plot\"},roworder:{valType:\"enumerated\",values:[\"top to bottom\",\"bottom to top\"],dflt:\"top to bottom\",editType:\"plot\"},columns:{valType:\"integer\",min:1,editType:\"plot\"},subplots:{valType:\"info_array\",freeLength:!0,dimensions:2,items:{valType:\"enumerated\",values:[i(\"xy\").toString(),\"\"],editType:\"plot\"},editType:\"plot\"},xaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.x.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},yaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.y.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},pattern:{valType:\"enumerated\",values:[\"independent\",\"coupled\"],dflt:\"coupled\",editType:\"plot\"},xgap:{valType:\"number\",min:0,max:1,editType:\"plot\"},ygap:{valType:\"number\",min:0,max:1,editType:\"plot\"},domain:a({name:\"grid\",editType:\"plot\",noGridCell:!0},{}),xside:{valType:\"enumerated\",values:[\"bottom\",\"bottom plot\",\"top plot\",\"top\"],dflt:\"bottom plot\",editType:\"plot\"},yside:{valType:\"enumerated\",values:[\"left\",\"left plot\",\"right plot\",\"right\"],dflt:\"left plot\",editType:\"plot\"},editType:\"plot\"};function c(t,e,r){var n=e[r+\"axes\"],i=Object.keys((t._splomAxes||{})[r]||{});return Array.isArray(n)?n:i.length?i:void 0}function u(t,e,r,n,i,a){var o=e(t+\"gap\",r),s=e(\"domain.\"+t);e(t+\"side\",n);for(var l=new Array(i),c=s[0],u=(s[1]-c)/(i-o),h=u*(1-o),f=0;f<i;f++){var p=c+u*f;l[a?i-1-f:f]=[p,p+h]}return l}function h(t,e,r,n,i){var a,o=new Array(r);function s(t,r){-1!==e.indexOf(r)&&void 0===n[r]?(o[t]=r,n[r]=t):o[t]=\"\"}if(Array.isArray(t))for(a=0;a<r;a++)s(a,t[a]);else for(s(0,i),a=1;a<r;a++)s(a,i+(a+1));return o}e.exports={moduleType:\"component\",name:\"grid\",schema:{layout:{grid:l}},layoutAttributes:l,sizeDefaults:function(t,e){var r=t.grid||{},i=c(e,r,\"x\"),a=c(e,r,\"y\");if(t.grid||i||a){var o,h,f=Array.isArray(r.subplots)&&Array.isArray(r.subplots[0]),p=Array.isArray(i),d=Array.isArray(a),g=p&&i!==r.xaxes&&d&&a!==r.yaxes;f?(o=r.subplots.length,h=r.subplots[0].length):(d&&(o=a.length),p&&(h=i.length));var v=s.newContainer(e,\"grid\"),m=T(\"rows\",o),y=T(\"columns\",h);if(m*y>1){f||p||d||\"independent\"===T(\"pattern\")&&(f=!0),v._hasSubplotGrid=f;var x,b,_=\"top to bottom\"===T(\"roworder\"),w=f?.2:.1,k=f?.3:.1;g&&e._splomGridDflt&&(x=e._splomGridDflt.xside,b=e._splomGridDflt.yside),v._domains={x:u(\"x\",T,w,x,y),y:u(\"y\",T,k,b,m,_)}}else delete e.grid}function T(t,e){return n.coerce(r,v,l,t,e)}},contentDefaults:function(t,e){var r=e.grid;if(r&&r._domains){var n,i,a,o,s,l,u,f=t.grid||{},p=e._subplots,d=r._hasSubplotGrid,g=r.rows,v=r.columns,m=\"independent\"===r.pattern,y=r._axisMap={};if(d){var x=f.subplots||[];l=r.subplots=new Array(g);var b=1;for(n=0;n<g;n++){var _=l[n]=new Array(v),w=x[n]||[];for(i=0;i<v;i++)if(m?(s=1===b?\"xy\":\"x\"+b+\"y\"+b,b++):s=w[i],_[i]=\"\",-1!==p.cartesian.indexOf(s)){if(u=s.indexOf(\"y\"),a=s.slice(0,u),o=s.slice(u),void 0!==y[a]&&y[a]!==i||void 0!==y[o]&&y[o]!==n)continue;_[i]=s,y[a]=i,y[o]=n}}}else{var k=c(e,f,\"x\"),T=c(e,f,\"y\");r.xaxes=h(k,p.xaxis,v,y,\"x\"),r.yaxes=h(T,p.yaxis,g,y,\"y\")}var A=r._anchors={},M=\"top to bottom\"===r.roworder;for(var S in y){var E,C,L,P=S.charAt(0),O=r[P+\"side\"];if(O.length<8)A[S]=\"free\";else if(\"x\"===P){if(\"t\"===O.charAt(0)===M?(E=0,C=1,L=g):(E=g-1,C=-1,L=-1),d){var z=y[S];for(n=E;n!==L;n+=C)if((s=l[n][z])&&(u=s.indexOf(\"y\"),s.slice(0,u)===S)){A[S]=s.slice(u);break}}else for(n=E;n!==L;n+=C)if(o=r.yaxes[n],-1!==p.cartesian.indexOf(S+o)){A[S]=o;break}}else if(\"l\"===O.charAt(0)?(E=0,C=1,L=v):(E=v-1,C=-1,L=-1),d){var I=y[S];for(n=E;n!==L;n+=C)if((s=l[I][n])&&(u=s.indexOf(\"y\"),s.slice(u)===S)){A[S]=s.slice(0,u);break}}else for(n=E;n!==L;n+=C)if(a=r.xaxes[n],-1!==p.cartesian.indexOf(a+S)){A[S]=a;break}}}}}},{\"../../lib\":719,\"../../lib/regex\":735,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773,\"../../plots/domain\":792}],637:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/constants\"),i=t(\"../../plot_api/plot_template\").templatedArray;e.exports=i(\"image\",{visible:{valType:\"boolean\",dflt:!0,editType:\"arraydraw\"},source:{valType:\"string\",editType:\"arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},sizex:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizey:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizing:{valType:\"enumerated\",values:[\"fill\",\"contain\",\"stretch\"],dflt:\"contain\",editType:\"arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},x:{valType:\"any\",dflt:0,editType:\"arraydraw\"},y:{valType:\"any\",dflt:0,editType:\"arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"top\",editType:\"arraydraw\"},xref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.x.toString()],dflt:\"paper\",editType:\"arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.y.toString()],dflt:\"paper\",editType:\"arraydraw\"},editType:\"arraydraw\"})},{\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773}],638:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.images,h=e._id.charAt(0),f=0;f<u.length;f++)if(c=\"images[\"+f+\"].\",(l=u[f])[h+\"ref\"]===e._id){var p=l[h],d=l[\"size\"+h],g=null,v=null;if(o){g=i(p,e.range);var m=d/Math.pow(10,g)/2;v=2*Math.log(m+Math.sqrt(1+m*m))/Math.LN10}else v=(g=Math.pow(10,p))*(Math.pow(10,d/2)-Math.pow(10,-d/2));n(g)?n(v)||(v=null):(g=null,v=null),a(c+h,g),a(c+\"size\"+h,v)}}},{\"../../lib/to_log_range\":745,\"fast-isnumeric\":225}],639:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\");function s(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}var s=a(\"source\");if(!a(\"visible\",!!s))return e;a(\"layer\"),a(\"xanchor\"),a(\"yanchor\"),a(\"sizex\"),a(\"sizey\"),a(\"sizing\"),a(\"opacity\");for(var l={_fullLayout:r},c=[\"x\",\"y\"],u=0;u<2;u++){var h=c[u],f=i.coerceRef(t,e,l,h,\"paper\");if(\"paper\"!==f)i.getFromId(l,f)._imgIndices.push(e._index);i.coercePosition(e,l,a,f,h,0)}return e}e.exports=function(t,e){a(t,e,{name:\"images\",handleItemDefaults:s})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"./attributes\":637}],640:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../drawing\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/xmlns_namespaces\");e.exports=function(t){var e,r,s=t._fullLayout,l=[],c={},u=[];for(r=0;r<s.images.length;r++){var h=s.images[r];if(h.visible)if(\"below\"===h.layer&&\"paper\"!==h.xref&&\"paper\"!==h.yref){e=h.xref+h.yref;var f=s._plots[e];if(!f){u.push(h);continue}f.mainplot&&(e=f.mainplot.id),c[e]||(c[e]=[]),c[e].push(h)}else\"above\"===h.layer?l.push(h):u.push(h)}var p={x:{left:{sizing:\"xMin\",offset:0},center:{sizing:\"xMid\",offset:-.5},right:{sizing:\"xMax\",offset:-1}},y:{top:{sizing:\"YMin\",offset:0},middle:{sizing:\"YMid\",offset:-.5},bottom:{sizing:\"YMax\",offset:-1}}};function d(e){var r=n.select(this);if(!this.img||this.img.src!==e.source){r.attr(\"xmlns\",o.svg);var i=new Promise(function(t){var n=new Image;function i(){r.remove(),t()}this.img=n,n.setAttribute(\"crossOrigin\",\"anonymous\"),n.onerror=i,n.onload=function(){var e=document.createElement(\"canvas\");e.width=this.width,e.height=this.height,e.getContext(\"2d\").drawImage(this,0,0);var n=e.toDataURL(\"image/png\");r.attr(\"xlink:href\",n),t()},r.on(\"error\",i),n.src=e.source}.bind(this));t._promises.push(i)}}function g(e){var r=n.select(this),o=a.getFromId(t,e.xref),l=a.getFromId(t,e.yref),c=s._size,u=o?Math.abs(o.l2p(e.sizex)-o.l2p(0)):e.sizex*c.w,h=l?Math.abs(l.l2p(e.sizey)-l.l2p(0)):e.sizey*c.h,f=u*p.x[e.xanchor].offset,d=h*p.y[e.yanchor].offset,g=p.x[e.xanchor].sizing+p.y[e.yanchor].sizing,v=(o?o.r2p(e.x)+o._offset:e.x*c.w+c.l)+f,m=(l?l.r2p(e.y)+l._offset:c.h-e.y*c.h+c.t)+d;switch(e.sizing){case\"fill\":g+=\" slice\";break;case\"stretch\":g=\"none\"}r.attr({x:v,y:m,width:u,height:h,preserveAspectRatio:g,opacity:e.opacity});var y=(o?o._id:\"\")+(l?l._id:\"\");i.setClipUrl(r,y?\"clip\"+s._uid+y:null,t)}var v=s._imageLowerLayer.selectAll(\"image\").data(u),m=s._imageUpperLayer.selectAll(\"image\").data(l);v.enter().append(\"image\"),m.enter().append(\"image\"),v.exit().remove(),m.exit().remove(),v.each(function(t){d.bind(this)(t),g.bind(this)(t)}),m.each(function(t){d.bind(this)(t),g.bind(this)(t)});var y=Object.keys(s._plots);for(r=0;r<y.length;r++){e=y[r];var x=s._plots[e];if(x.imagelayer){var b=x.imagelayer.selectAll(\"image\").data(c[e]||[]);b.enter().append(\"image\"),b.exit().remove(),b.each(function(t){d.bind(this)(t),g.bind(this)(t)})}}}},{\"../../constants/xmlns_namespaces\":696,\"../../plots/cartesian/axes\":767,\"../drawing\":614,d3:163}],641:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"images\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"images\"),draw:t(\"./draw\"),convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":777,\"./attributes\":637,\"./convert_coords\":638,\"./defaults\":639,\"./draw\":640}],642:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",editType:\"legend\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"legend\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"legend\"},font:n({editType:\"legend\"}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"v\",editType:\"legend\"},traceorder:{valType:\"flaglist\",flags:[\"reversed\",\"grouped\"],extras:[\"normal\"],editType:\"legend\"},tracegroupgap:{valType:\"number\",min:0,dflt:10,editType:\"legend\"},itemsizing:{valType:\"enumerated\",values:[\"trace\",\"constant\"],dflt:\"trace\",editType:\"legend\"},itemclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggle\",editType:\"legend\"},itemdoubleclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggleothers\",editType:\"legend\"},x:{valType:\"number\",min:-2,max:3,dflt:1.02,editType:\"legend\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"legend\"},y:{valType:\"number\",min:-2,max:3,dflt:1,editType:\"legend\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"legend\"},uirevision:{valType:\"any\",editType:\"none\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"legend\"},editType:\"legend\"}},{\"../../plots/font_attributes\":793,\"../color/attributes\":592}],643:[function(t,e,r){\"use strict\";e.exports={scrollBarWidth:6,scrollBarMinHeight:20,scrollBarColor:\"#808BA4\",scrollBarMargin:4,textOffsetX:40}},{}],644:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plot_api/plot_template\"),o=t(\"./attributes\"),s=t(\"../../plots/layout_attributes\"),l=t(\"./helpers\");e.exports=function(t,e,r){for(var c,u,h,f,p=t.legend||{},d=0,g=!1,v=\"normal\",m=0;m<r.length;m++){var y=r[m];y.visible&&((y.showlegend||y._dfltShowLegend)&&(d++,y.showlegend&&(g=!0,(n.traceIs(y,\"pie-like\")||!0===y._input.showlegend)&&d++)),(n.traceIs(y,\"bar\")&&\"stack\"===e.barmode||-1!==[\"tonextx\",\"tonexty\"].indexOf(y.fill))&&(v=l.isGrouped({traceorder:v})?\"grouped+reversed\":\"reversed\"),void 0!==y.legendgroup&&\"\"!==y.legendgroup&&(v=l.isReversed({traceorder:v})?\"reversed+grouped\":\"grouped\"))}var x=i.coerce(t,e,s,\"showlegend\",g&&d>1);if(!1!==x||p.uirevision){var b=a.newContainer(e,\"legend\");if(w(\"uirevision\",e.uirevision),!1!==x){if(w(\"bgcolor\",e.paper_bgcolor),w(\"bordercolor\"),w(\"borderwidth\"),i.coerceFont(w,\"font\",e.font),w(\"orientation\"),\"h\"===b.orientation){var _=t.xaxis;n.getComponentMethod(\"rangeslider\",\"isVisible\")(_)?(c=0,h=\"left\",u=1.1,f=\"bottom\"):(c=0,h=\"left\",u=-.1,f=\"top\")}w(\"traceorder\",v),l.isGrouped(e.legend)&&w(\"tracegroupgap\"),w(\"itemsizing\"),w(\"itemclick\"),w(\"itemdoubleclick\"),w(\"x\",c),w(\"xanchor\",h),w(\"y\",u),w(\"yanchor\",f),w(\"valign\"),i.noneOrAll(p,b,[\"x\",\"y\"])}}function w(t,e){return i.coerce(p,b,o,t,e)}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/layout_attributes\":819,\"../../registry\":847,\"./attributes\":642,\"./helpers\":648}],645:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib/events\"),l=t(\"../dragelement\"),c=t(\"../drawing\"),u=t(\"../color\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"./handle_click\"),p=t(\"./constants\"),d=t(\"../../constants/alignment\"),g=d.LINE_SPACING,v=d.FROM_TL,m=d.FROM_BR,y=t(\"./get_legend_data\"),x=t(\"./style\"),b=t(\"./helpers\");function _(t,e,r,n,i){var a=r.data()[0][0].trace,l={event:i,node:r.node(),curveNumber:a.index,expandedIndex:a._expandedIndex,data:t.data,layout:t.layout,frames:t._transitionData._frames,config:t._context,fullData:t._fullData,fullLayout:t._fullLayout};if(a._group&&(l.group=a._group),o.traceIs(a,\"pie-like\")&&(l.label=r.datum()[0].label),!1!==s.triggerHandler(t,\"plotly_legendclick\",l))if(1===n)e._clickTimeout=setTimeout(function(){f(r,t,n)},t._context.doubleClickDelay);else if(2===n){e._clickTimeout&&clearTimeout(e._clickTimeout),t._legendMouseDownTime=0,!1!==s.triggerHandler(t,\"plotly_legenddoubleclick\",l)&&f(r,t,n)}}function w(t,e,r){var n=t.data()[0][0],a=e._fullLayout,s=n.trace,l=o.traceIs(s,\"pie-like\"),u=s.index,f=e._context.edits.legendText&&!l,d=l?n.label:s.name;s._meta&&(d=i.templateString(d,s._meta));var v=i.ensureSingle(t,\"text\",\"legendtext\");function m(r){h.convertToTspans(r,e,function(){!function(t,e){var r=t.data()[0][0];if(!r.trace.showlegend)return void t.remove();var n,i,a=t.select(\"g[class*=math-group]\"),o=a.node(),s=e._fullLayout.legend.font.size*g;if(o){var l=c.bBox(o);n=l.height,i=l.width,c.setTranslate(a,0,n/4)}else{var u=t.select(\".legendtext\"),f=h.lineCount(u),d=u.node();n=s*f,i=d?c.bBox(d).width:0;var v=s*(.3+(1-f)/2);h.positionText(u,p.textOffsetX,v)}r.lineHeight=s,r.height=Math.max(n,16)+3,r.width=i}(t,e)})}v.attr(\"text-anchor\",\"start\").classed(\"user-select-none\",!0).call(c.font,a.legend.font).text(f?k(d,r):d),h.positionText(v,p.textOffsetX,0),f?v.call(h.makeEditable,{gd:e,text:d}).call(m).on(\"edit\",function(t){this.text(k(t,r)).call(m);var a=n.trace._fullInput||{},s={};if(o.hasTransform(a,\"groupby\")){var l=o.getTransformIndices(a,\"groupby\"),c=l[l.length-1],h=i.keyedContainer(a,\"transforms[\"+c+\"].styles\",\"target\",\"value.name\");h.set(n.trace._group,t),s=h.constructUpdate()}else s.name=t;return o.call(\"_guiRestyle\",e,s,u)}):m(v)}function k(t,e){var r=Math.max(4,e);if(t&&t.trim().length>=r/2)return t;for(var n=r-(t=t||\"\").length;n>0;n--)t+=\" \";return t}function T(t,e){var r,a=e._context.doubleClickDelay,o=1,s=i.ensureSingle(t,\"rect\",\"legendtoggle\",function(t){t.style(\"cursor\",\"pointer\").attr(\"pointer-events\",\"all\").call(u.fill,\"rgba(0,0,0,0)\")});s.on(\"mousedown\",function(){(r=(new Date).getTime())-e._legendMouseDownTime<a?o+=1:(o=1,e._legendMouseDownTime=r)}),s.on(\"mouseup\",function(){if(!e._dragged&&!e._editing){var r=e._fullLayout.legend;(new Date).getTime()-e._legendMouseDownTime>a&&(o=Math.max(o-1,1)),_(e,r,t,o,n.event)}})}function A(t,e,r){var a=t._fullLayout,o=a.legend,s=o.borderwidth,l=b.isGrouped(o),u=0;if(o._width=0,o._height=0,b.isVertical(o))l&&e.each(function(t,e){c.setTranslate(this,0,e*o.tracegroupgap)}),r.each(function(t){var e=t[0],r=e.height,n=e.width;c.setTranslate(this,s,5+s+o._height+r/2),o._height+=r,o._width=Math.max(o._width,n)}),o._width+=45+2*s,o._height+=10+2*s,l&&(o._height+=(o._lgroupsLength-1)*o.tracegroupgap),u=40;else if(l){var h,f=0,p=0,d=e.data(),g=0;for(h=0;h<d.length;h++){var v=d[h],m=v.map(function(t){return t[0].width}),y=i.aggNums(Math.max,null,m),x=v.reduce(function(t,e){return t+e[0].height},0);p=Math.max(p,y),f=Math.max(f,x),g=Math.max(g,v.length)}p+=5,p+=40;var _=[o._width],w=[],k=0;for(h=0;h<d.length;h++){a._size.w<s+o._width+5+p?(_[_.length-1]=_[0],o._width=p,k++):o._width+=p+s;var T=k*f;T+=k>0?o.tracegroupgap:0,w.push(T),_.push(o._width)}e.each(function(t,e){c.setTranslate(this,_[e],w[e])}),e.each(function(){var t=n.select(this).selectAll(\"g.traces\"),e=0;t.each(function(t){var r=t[0].height;c.setTranslate(this,0,5+s+e+r/2),e+=r})});var A=w[w.length-1]+f;o._height=10+2*s+A;var M=Math.max.apply(null,_);o._width=M+p+40,o._width+=2*s}else{var S=0,E=0,C=0,L=0,P=0;r.each(function(t){C=Math.max(40+t[0].width,C),P+=40+t[0].width+5});var O=a._size.w>s+P-5;r.each(function(t){var e=t[0],r=O?40+t[0].width:C;s+L+5+r>a._size.w&&(L=0,S+=E,o._height+=E,E=0),c.setTranslate(this,s+L,5+s+e.height/2+S),o._width+=5+r,L+=5+r,E=Math.max(e.height,E)}),O?o._height=E:o._height+=E,o._width+=2*s,o._height+=10+2*s}o._width=Math.ceil(o._width),o._height=Math.ceil(o._height);var z=t._context.edits.legendText||t._context.edits.legendPosition;r.each(function(t){var e=t[0],r=n.select(this).select(\".legendtoggle\");c.setRect(r,0,-e.height/2,(z?0:o._width)+u,e.height)})}function M(t){var e=t._fullLayout.legend,r=\"left\";i.isRightAnchor(e)?r=\"right\":i.isCenterAnchor(e)&&(r=\"center\");var n=\"top\";i.isBottomAnchor(e)?n=\"bottom\":i.isMiddleAnchor(e)&&(n=\"middle\"),a.autoMargin(t,\"legend\",{x:e.x,y:e.y,l:e._width*v[r],r:e._width*m[r],b:e._height*m[n],t:e._height*v[n]})}e.exports=function(t){var e=t._fullLayout,r=\"legend\"+e._uid;if(e._infolayer&&t.calcdata){t._legendMouseDownTime||(t._legendMouseDownTime=0);var s=e.legend,h=e.showlegend&&y(t.calcdata,s),f=e.hiddenlabels||[];if(!e.showlegend||!h.length)return e._infolayer.selectAll(\".legend\").remove(),e._topdefs.select(\"#\"+r).remove(),void a.autoMargin(t,\"legend\");for(var d=0,g=0;g<h.length;g++)for(var b=0;b<h[g].length;b++){var k=h[g][b][0],S=k.trace,E=o.traceIs(S,\"pie-like\")?k.label:S.name;d=Math.max(d,E&&E.length||0)}var C=!1,L=i.ensureSingle(e._infolayer,\"g\",\"legend\",function(t){t.attr(\"pointer-events\",\"all\"),C=!0}),P=i.ensureSingleById(e._topdefs,\"clipPath\",r,function(t){t.append(\"rect\")}),O=i.ensureSingle(L,\"rect\",\"bg\",function(t){t.attr(\"shape-rendering\",\"crispEdges\")});O.call(u.stroke,s.bordercolor).call(u.fill,s.bgcolor).style(\"stroke-width\",s.borderwidth+\"px\");var z=i.ensureSingle(L,\"g\",\"scrollbox\"),I=i.ensureSingle(L,\"rect\",\"scrollbar\",function(t){t.attr({rx:20,ry:3,width:0,height:0}).call(u.fill,\"#808BA4\")}),D=z.selectAll(\"g.groups\").data(h);D.enter().append(\"g\").attr(\"class\",\"groups\"),D.exit().remove();var R=D.selectAll(\"g.traces\").data(i.identity);R.enter().append(\"g\").attr(\"class\",\"traces\"),R.exit().remove(),R.style(\"opacity\",function(t){var e=t[0].trace;return o.traceIs(e,\"pie-like\")?-1!==f.indexOf(t[0].label)?.5:1:\"legendonly\"===e.visible?.5:1}).each(function(){n.select(this).call(w,t,d)}).call(x,t).each(function(){n.select(this).call(T,t)}),i.syncOrAsync([a.previousPromises,function(){C&&(A(t,D,R),M(t));var u=e.width,h=e.height;A(t,D,R),s._height>h?function(t){var e=t._fullLayout.legend,r=\"left\";i.isRightAnchor(e)?r=\"right\":i.isCenterAnchor(e)&&(r=\"center\");a.autoMargin(t,\"legend\",{x:e.x,y:.5,l:e._width*v[r],r:e._width*m[r],b:0,t:0})}(t):M(t);var f=e._size,d=f.l+f.w*s.x,g=f.t+f.h*(1-s.y);i.isRightAnchor(s)?d-=s._width:i.isCenterAnchor(s)&&(d-=s._width/2),i.isBottomAnchor(s)?g-=s._height:i.isMiddleAnchor(s)&&(g-=s._height/2);var y=s._width,x=f.w;y>x?(d=f.l,y=x):(d+y>u&&(d=u-y),d<0&&(d=0),y=Math.min(u-d,s._width));var b,w,k,T,S=s._height,E=f.h;if(S>E?(g=f.t,S=E):(g+S>h&&(g=h-S),g<0&&(g=0),S=Math.min(h-g,s._height)),c.setTranslate(L,d,g),I.on(\".drag\",null),L.on(\"wheel\",null),s._height<=S||t._context.staticPlot)O.attr({width:y-s.borderwidth,height:S-s.borderwidth,x:s.borderwidth/2,y:s.borderwidth/2}),c.setTranslate(z,0,0),P.select(\"rect\").attr({width:y-2*s.borderwidth,height:S-2*s.borderwidth,x:s.borderwidth,y:s.borderwidth}),c.setClipUrl(z,r,t),c.setRect(I,0,0,0,0),delete s._scrollY;else{var F,B,N=Math.max(p.scrollBarMinHeight,S*S/s._height),j=S-N-2*p.scrollBarMargin,U=s._height-S,V=j/U,q=Math.min(s._scrollY||0,U);O.attr({width:y-2*s.borderwidth+p.scrollBarWidth+p.scrollBarMargin,height:S-s.borderwidth,x:s.borderwidth/2,y:s.borderwidth/2}),P.select(\"rect\").attr({width:y-2*s.borderwidth+p.scrollBarWidth+p.scrollBarMargin,height:S-2*s.borderwidth,x:s.borderwidth,y:s.borderwidth+q}),c.setClipUrl(z,r,t),G(q,N,V),L.on(\"wheel\",function(){G(q=i.constrain(s._scrollY+n.event.deltaY/j*U,0,U),N,V),0!==q&&q!==U&&n.event.preventDefault()});var H=n.behavior.drag().on(\"dragstart\",function(){F=n.event.sourceEvent.clientY,B=q}).on(\"drag\",function(){var t=n.event.sourceEvent;2===t.buttons||t.ctrlKey||G(q=i.constrain((t.clientY-F)/V+B,0,U),N,V)});I.call(H)}function G(e,r,n){s._scrollY=t._fullLayout.legend._scrollY=e,c.setTranslate(z,0,-e),c.setRect(I,y,p.scrollBarMargin+e*n,p.scrollBarWidth,r),P.select(\"rect\").attr({y:s.borderwidth+e})}t._context.edits.legendPosition&&(L.classed(\"cursor-move\",!0),l.init({element:L.node(),gd:t,prepFn:function(){var t=c.getTranslate(L);k=t.x,T=t.y},moveFn:function(t,e){var r=k+t,n=T+e;c.setTranslate(L,r,n),b=l.align(r,0,f.l,f.l+f.w,s.xanchor),w=l.align(n,0,f.t+f.h,f.t,s.yanchor)},doneFn:function(){void 0!==b&&void 0!==w&&o.call(\"_guiRelayout\",t,{\"legend.x\":b,\"legend.y\":w})},clickFn:function(r,n){var i=e._infolayer.selectAll(\"g.traces\").filter(function(){var t=this.getBoundingClientRect();return n.clientX>=t.left&&n.clientX<=t.right&&n.clientY>=t.top&&n.clientY<=t.bottom});i.size()>0&&_(t,L,i,r,n)}}))}],t)}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/events\":709,\"../../lib/svg_text_utils\":743,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"./constants\":643,\"./get_legend_data\":646,\"./handle_click\":647,\"./helpers\":648,\"./style\":650,d3:163}],646:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./helpers\");e.exports=function(t,e){var r,a,o={},s=[],l=!1,c={},u=0;function h(t,r){if(\"\"!==t&&i.isGrouped(e))-1===s.indexOf(t)?(s.push(t),l=!0,o[t]=[[r]]):o[t].push([r]);else{var n=\"~~i\"+u;s.push(n),o[n]=[[r]],u++}}for(r=0;r<t.length;r++){var f=t[r],p=f[0],d=p.trace,g=d.legendgroup;if(d.visible&&d.showlegend)if(n.traceIs(d,\"pie-like\"))for(c[g]||(c[g]={}),a=0;a<f.length;a++){var v=f[a].label;c[g][v]||(h(g,{label:v,color:f[a].color,i:f[a].i,trace:d,pts:f[a].pts}),c[g][v]=!0)}else h(g,p)}if(!s.length)return[];var m,y,x=s.length;if(l&&i.isGrouped(e))for(y=new Array(x),r=0;r<x;r++)m=o[s[r]],y[r]=i.isReversed(e)?m.reverse():m;else{for(y=[new Array(x)],r=0;r<x;r++)m=o[s[r]][0],y[0][i.isReversed(e)?x-r-1:r]=m;x=1}return e._lgroupsLength=x,y}},{\"../../registry\":847,\"./helpers\":648}],647:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=!0;e.exports=function(t,e,r){var o=e._fullLayout;if(!e._dragged&&!e._editing){var s,l=o.legend.itemclick,c=o.legend.itemdoubleclick;if(1===r&&\"toggle\"===l&&\"toggleothers\"===c&&a&&e.data&&e._context.showTips?(n.notifier(n._(e,\"Double-click on legend to isolate one trace\"),\"long\"),a=!1):a=!1,1===r?s=l:2===r&&(s=c),s){var u,h,f,p,d,g=o.hiddenlabels?o.hiddenlabels.slice():[],v=t.data()[0][0],m=e._fullData,y=v.trace,x=y.legendgroup,b={},_=[],w=[],k=[];if(i.traceIs(y,\"pie-like\")){var T=v.label,A=g.indexOf(T);\"toggle\"===s?-1===A?g.push(T):g.splice(A,1):\"toggleothers\"===s&&(g=[],e.calcdata[0].forEach(function(t){T!==t.label&&g.push(t.label)}),e._fullLayout.hiddenlabels&&e._fullLayout.hiddenlabels.length===g.length&&-1===A&&(g=[])),i.call(\"_guiRelayout\",e,\"hiddenlabels\",g)}else{var M,S=x&&x.length,E=[];if(S)for(u=0;u<m.length;u++)(M=m[u]).visible&&M.legendgroup===x&&E.push(u);if(\"toggle\"===s){var C;switch(y.visible){case!0:C=\"legendonly\";break;case!1:C=!1;break;case\"legendonly\":C=!0}if(S)for(u=0;u<m.length;u++)!1!==m[u].visible&&m[u].legendgroup===x&&R(m[u],C);else R(y,C)}else if(\"toggleothers\"===s){var L,P,O=!0;for(u=0;u<m.length;u++)if(!(m[u]===y)&&!(L=S&&m[u].legendgroup===x)&&!0===m[u].visible&&!i.traceIs(m[u],\"notLegendIsolatable\")){O=!1;break}for(u=0;u<m.length;u++)if(!1!==m[u].visible&&!i.traceIs(m[u],\"notLegendIsolatable\"))switch(y.visible){case\"legendonly\":R(m[u],!0);break;case!0:P=!!O||\"legendonly\",L=m[u]===y||S&&m[u].legendgroup===x,R(m[u],!!L||P)}}for(u=0;u<w.length;u++)if(f=w[u]){var z=f.constructUpdate(),I=Object.keys(z);for(h=0;h<I.length;h++)p=I[h],(b[p]=b[p]||[])[k[u]]=z[p]}for(d=Object.keys(b),u=0;u<d.length;u++)for(p=d[u],h=0;h<_.length;h++)b[p].hasOwnProperty(h)||(b[p][h]=void 0);i.call(\"_guiRestyle\",e,b,_)}}}function D(t,e,r){var n=_.indexOf(t),i=b[e];return i||(i=b[e]=[]),-1===_.indexOf(t)&&(_.push(t),n=_.length-1),i[n]=r,n}function R(t,e){var r=t._fullInput;if(i.hasTransform(r,\"groupby\")){var a=w[r.index];if(!a){var o=i.getTransformIndices(r,\"groupby\"),s=o[o.length-1];a=n.keyedContainer(r,\"transforms[\"+s+\"].styles\",\"target\",\"value.visible\"),w[r.index]=a}var l=a.get(t._group);void 0===l&&(l=!0),!1!==l&&a.set(t._group,e),k[r.index]=D(r.index,\"visible\",!1!==r.visible)}else{var c=!1!==r.visible&&e;D(r.index,\"visible\",c)}}}},{\"../../lib\":719,\"../../registry\":847}],648:[function(t,e,r){\"use strict\";r.isGrouped=function(t){return-1!==(t.traceorder||\"\").indexOf(\"grouped\")},r.isVertical=function(t){return\"h\"!==t.orientation},r.isReversed=function(t){return-1!==(t.traceorder||\"\").indexOf(\"reversed\")}},{}],649:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"legend\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\"),style:t(\"./style\")}},{\"./attributes\":642,\"./defaults\":644,\"./draw\":645,\"./style\":650}],650:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../drawing\"),s=t(\"../color\"),l=t(\"../../traces/scatter/subtypes\"),c=t(\"../../traces/pie/style_one\"),u=t(\"../../traces/pie/helpers\").castOption,h=12,f=5,p=2,d=10,g=5;e.exports=function(t,e){var r=e._fullLayout.legend,v=\"constant\"===r.itemsizing;function m(t,e,r,n){var i;if(t+1)i=t;else{if(!(e&&e.width>0))return 0;i=e.width}return v?n:Math.min(i,r)}function y(t,e,r){var a=t[0].trace,o=a.marker||{},l=o.line||{},c=r?a.type===r&&a.visible:i.traceIs(a,\"bar\"),u=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(c?[t]:[]);u.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),u.exit().remove(),u.each(function(t){var e=n.select(this),r=t[0],i=m(r.mlw,o.line,g,p);e.style(\"stroke-width\",i+\"px\").call(s.fill,r.mc||o.color),i&&s.stroke(e,r.mlc||l.color)})}function x(t,e,r){var o=t[0],s=o.trace,l=r?s.type===r&&s.visible:i.traceIs(s,r),h=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(l?[t]:[]);if(h.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),h.exit().remove(),h.size()){var f=(s.marker||{}).line,d=m(u(f.width,o.pts),f,g,p),v=a.minExtend(s,{marker:{line:{width:d}}});v.marker.line.color=f.color;var y=a.minExtend(o,{trace:v});c(h,y,v)}}t.each(function(t){var e=n.select(this),i=a.ensureSingle(e,\"g\",\"layers\");i.style(\"opacity\",t[0].trace.opacity);var o=r.valign,s=t[0].lineHeight,l=t[0].height;if(\"middle\"!==o&&s&&l){var c={top:1,bottom:-1}[o]*(.5*(s-l+3));i.attr(\"transform\",\"translate(0,\"+c+\")\")}else i.attr(\"transform\",null);i.selectAll(\"g.legendfill\").data([t]).enter().append(\"g\").classed(\"legendfill\",!0),i.selectAll(\"g.legendlines\").data([t]).enter().append(\"g\").classed(\"legendlines\",!0);var u=i.selectAll(\"g.legendsymbols\").data([t]);u.enter().append(\"g\").classed(\"legendsymbols\",!0),u.selectAll(\"g.legendpoints\").data([t]).enter().append(\"g\").classed(\"legendpoints\",!0)}).each(function(t){var e=t[0].trace,r=[];\"waterfall\"===e.type&&e.visible&&(r=t[0].hasTotals?[[\"increasing\",\"M-6,-6V6H0Z\"],[\"totals\",\"M6,6H0L-6,-6H-0Z\"],[\"decreasing\",\"M6,6V-6H0Z\"]]:[[\"increasing\",\"M-6,-6V6H6Z\"],[\"decreasing\",\"M6,6V-6H-6Z\"]]);var i=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendwaterfall\").data(r);i.enter().append(\"path\").classed(\"legendwaterfall\",!0).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),i.exit().remove(),i.each(function(t){var r=n.select(this),i=e[t[0]].marker,a=m(void 0,i.line,g,p);r.attr(\"d\",t[1]).style(\"stroke-width\",a+\"px\").call(s.fill,i.color),a&&r.call(s.stroke,i.line.color)})}).each(function(t){y(t,this,\"funnel\")}).each(function(t){y(t,this)}).each(function(t){var r=t[0].trace,l=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendbox\").data(i.traceIs(r,\"box-violin\")&&r.visible?[t]:[]);l.enter().append(\"path\").classed(\"legendbox\",!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),l.exit().remove(),l.each(function(){var t=n.select(this);if(\"all\"!==r.boxpoints&&\"all\"!==r.points||0!==s.opacity(r.fillcolor)||0!==s.opacity((r.line||{}).color)){var i=m(void 0,r.line,g,p);t.style(\"stroke-width\",i+\"px\").call(s.fill,r.fillcolor),i&&s.stroke(t,r.line.color)}else{var c=a.minExtend(r,{marker:{size:v?h:a.constrain(r.marker.size,2,16),sizeref:1,sizemin:1,sizemode:\"diameter\"}});l.call(o.pointStyle,c,e)}})}).each(function(t){x(t,this,\"funnelarea\")}).each(function(t){x(t,this,\"pie\")}).each(function(t){var r,i,s=t[0],c=s.trace,u=c.visible&&c.fill&&\"none\"!==c.fill,h=l.hasLines(c),p=c.contours,g=!1,v=!1;if(p){var y=p.coloring;\"lines\"===y?g=!0:h=\"none\"===y||\"heatmap\"===y||p.showlines,\"constraint\"===p.type?u=\"=\"!==p._operation:\"fill\"!==y&&\"heatmap\"!==y||(v=!0)}var x=l.hasMarkers(c)||l.hasText(c),b=u||v,_=h||g,w=x||!b?\"M5,0\":_?\"M5,-2\":\"M5,-3\",k=n.select(this),T=k.select(\".legendfill\").selectAll(\"path\").data(u||v?[t]:[]);if(T.enter().append(\"path\").classed(\"js-fill\",!0),T.exit().remove(),T.attr(\"d\",w+\"h30v6h-30z\").call(u?o.fillGroupStyle:function(t){if(t.size()){var r=\"legendfill-\"+c.uid;o.gradient(t,e,r,\"horizontalreversed\",c.colorscale,\"fill\")}}),h||g){var A=m(void 0,c.line,d,f);i=a.minExtend(c,{line:{width:A}}),r=[a.minExtend(s,{trace:i})]}var M=k.select(\".legendlines\").selectAll(\"path\").data(h||g?[r]:[]);M.enter().append(\"path\").classed(\"js-line\",!0),M.exit().remove(),M.attr(\"d\",w+(g?\"l30,0.0001\":\"h30\")).call(h?o.lineGroupStyle:function(t){if(t.size()){var r=\"legendline-\"+c.uid;o.lineGroupStyle(t),o.gradient(t,e,r,\"horizontalreversed\",c.colorscale,\"stroke\")}})}).each(function(t){var r,i,s=t[0],c=s.trace,u=l.hasMarkers(c),d=l.hasText(c),g=l.hasLines(c);function m(t,e,r,n){var i=a.nestedProperty(c,t).get(),o=a.isArrayOrTypedArray(i)&&e?e(i):i;if(v&&o&&void 0!==n&&(o=n),r){if(o<r[0])return r[0];if(o>r[1])return r[1]}return o}function y(t){return t[0]}if(u||d||g){var x={},b={};if(u){x.mc=m(\"marker.color\",y),x.mx=m(\"marker.symbol\",y),x.mo=m(\"marker.opacity\",a.mean,[.2,1]),x.mlc=m(\"marker.line.color\",y),x.mlw=m(\"marker.line.width\",a.mean,[0,5],p),b.marker={sizeref:1,sizemin:1,sizemode:\"diameter\"};var _=m(\"marker.size\",a.mean,[2,16],h);x.ms=_,b.marker.size=_}g&&(b.line={width:m(\"line.width\",y,[0,10],f)}),d&&(x.tx=\"Aa\",x.tp=m(\"textposition\",y),x.ts=10,x.tc=m(\"textfont.color\",y),x.tf=m(\"textfont.family\",y)),r=[a.minExtend(s,x)],(i=a.minExtend(c,b)).selectedpoints=null}var w=n.select(this).select(\"g.legendpoints\"),k=w.selectAll(\"path.scatterpts\").data(u?r:[]);k.enter().insert(\"path\",\":first-child\").classed(\"scatterpts\",!0).attr(\"transform\",\"translate(20,0)\"),k.exit().remove(),k.call(o.pointStyle,i,e),u&&(r[0].mrc=3);var T=w.selectAll(\"g.pointtext\").data(d?r:[]);T.enter().append(\"g\").classed(\"pointtext\",!0).append(\"text\").attr(\"transform\",\"translate(20,0)\"),T.exit().remove(),T.selectAll(\"text\").call(o.textPointStyle,i,e)}).each(function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendcandle\").data(\"candlestick\"===e.type&&e.visible?[t,t]:[]);r.enter().append(\"path\").classed(\"legendcandle\",!0).attr(\"d\",function(t,e){return e?\"M-15,0H-8M-8,6V-6H8Z\":\"M15,0H8M8,-6V6H-8Z\"}).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),r.exit().remove(),r.each(function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],o=m(void 0,a.line,g,p);i.style(\"stroke-width\",o+\"px\").call(s.fill,a.fillcolor),o&&s.stroke(i,a.line.color)})}).each(function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendohlc\").data(\"ohlc\"===e.type&&e.visible?[t,t]:[]);r.enter().append(\"path\").classed(\"legendohlc\",!0).attr(\"d\",function(t,e){return e?\"M-15,0H0M-8,-6V0\":\"M15,0H0M8,6V0\"}).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),r.exit().remove(),r.each(function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],l=m(void 0,a.line,g,p);i.style(\"fill\",\"none\").call(o.dashLine,a.line.dash,l),l&&s.stroke(i,a.line.color)})})}},{\"../../lib\":719,\"../../registry\":847,\"../../traces/pie/helpers\":1091,\"../../traces/pie/style_one\":1097,\"../../traces/scatter/subtypes\":1135,\"../color\":593,\"../drawing\":614,d3:163}],651:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/plots\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../lib\"),s=t(\"../../fonts/ploticon\"),l=o._,c=e.exports={};function u(t,e){var r,i,o=e.currentTarget,s=o.getAttribute(\"data-attr\"),l=o.getAttribute(\"data-val\")||!0,c=t._fullLayout,u={},h=a.list(t,null,!0),f=\"on\";if(\"zoom\"===s){var p,d=\"in\"===l?.5:2,g=(1+d)/2,v=(1-d)/2;for(i=0;i<h.length;i++)if(!(r=h[i]).fixedrange)if(p=r._name,\"auto\"===l)u[p+\".autorange\"]=!0;else if(\"reset\"===l){if(void 0===r._rangeInitial)u[p+\".autorange\"]=!0;else{var m=r._rangeInitial.slice();u[p+\".range[0]\"]=m[0],u[p+\".range[1]\"]=m[1]}void 0!==r._showSpikeInitial&&(u[p+\".showspikes\"]=r._showSpikeInitial,\"on\"!==f||r._showSpikeInitial||(f=\"off\"))}else{var y=[r.r2l(r.range[0]),r.r2l(r.range[1])],x=[g*y[0]+v*y[1],g*y[1]+v*y[0]];u[p+\".range[0]\"]=r.l2r(x[0]),u[p+\".range[1]\"]=r.l2r(x[1])}c._cartesianSpikesEnabled=f}else{if(\"hovermode\"!==s||\"x\"!==l&&\"y\"!==l){if(\"hovermode\"===s&&\"closest\"===l){for(i=0;i<h.length;i++)r=h[i],\"on\"!==f||r.showspikes||(f=\"off\");c._cartesianSpikesEnabled=f}}else l=c._isHoriz?\"y\":\"x\",o.setAttribute(\"data-val\",l);u[s]=l}n.call(\"_guiRelayout\",t,u)}function h(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout._subplots.gl3d,s={},l=i.split(\".\"),c=0;c<o.length;c++)s[o[c]+\".\"+l[1]]=a;var u=\"pan\"===a?a:\"zoom\";s.dragmode=u,n.call(\"_guiRelayout\",t,s)}function f(t,e){for(var r=e.currentTarget.getAttribute(\"data-attr\"),i=t._fullLayout,a=i._subplots.gl3d,o={},s=0;s<a.length;s++){var l=a[s],c=l+\".camera\",u=i[l]._scene;\"resetLastSave\"===r?(o[c+\".up\"]=u.viewInitial.up,o[c+\".eye\"]=u.viewInitial.eye,o[c+\".center\"]=u.viewInitial.center):\"resetDefault\"===r&&(o[c+\".up\"]=null,o[c+\".eye\"]=null,o[c+\".center\"]=null)}n.call(\"_guiRelayout\",t,o)}function p(t,e){var r=e.currentTarget,n=r._previousVal,i=t._fullLayout,a=i._subplots.gl3d,o=[\"xaxis\",\"yaxis\",\"zaxis\"],s={},l={};if(n)l=n,r._previousVal=null;else{for(var c=0;c<a.length;c++){var u=a[c],h=i[u],f=u+\".hovermode\";s[f]=h.hovermode,l[f]=!1;for(var p=0;p<3;p++){var d=o[p],g=u+\".\"+d+\".showspikes\";l[g]=!1,s[g]=h[d].showspikes}}r._previousVal=s}return l}function d(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout,s=o._subplots.geo,l=0;l<s.length;l++){var c=s[l],u=o[c];if(\"zoom\"===i){var h=u.projection.scale,f=\"in\"===a?2*h:.5*h;n.call(\"_guiRelayout\",t,c+\".projection.scale\",f)}else\"reset\"===i&&m(t,\"geo\")}}function g(t){var e=t._fullLayout;return!e.hovermode&&(e._has(\"cartesian\")?e._isHoriz?\"y\":\"x\":\"closest\")}function v(t){var e=g(t);n.call(\"_guiRelayout\",t,\"hovermode\",e)}function m(t,e){for(var r=t._fullLayout,i=r._subplots[e],a={},o=0;o<i.length;o++)for(var s=i[o],l=r[s]._subplot.viewInitial,c=Object.keys(l),u=0;u<c.length;u++){var h=c[u];a[s+\".\"+h]=l[h]}n.call(\"_guiRelayout\",t,a)}c.toImage={name:\"toImage\",title:function(t){var e=(t._context.toImageButtonOptions||{}).format||\"png\";return l(t,\"png\"===e?\"Download plot as a png\":\"Download plot\")},icon:s.camera,click:function(t){var e=t._context.toImageButtonOptions,r={format:e.format||\"png\"};o.notifier(l(t,\"Taking snapshot - this may take a few seconds\"),\"long\"),\"svg\"!==r.format&&o.isIE()&&(o.notifier(l(t,\"IE only supports svg.  Changing format to svg.\"),\"long\"),r.format=\"svg\"),[\"filename\",\"width\",\"height\",\"scale\"].forEach(function(t){t in e&&(r[t]=e[t])}),n.call(\"downloadImage\",t,r).then(function(e){o.notifier(l(t,\"Snapshot succeeded\")+\" - \"+e,\"long\")}).catch(function(){o.notifier(l(t,\"Sorry, there was a problem downloading your snapshot!\"),\"long\")})}},c.sendDataToCloud={name:\"sendDataToCloud\",title:function(t){return l(t,\"Edit in Chart Studio\")},icon:s.disk,click:function(t){i.sendDataToCloud(t)}},c.editInChartStudio={name:\"editInChartStudio\",title:function(t){return l(t,\"Edit in Chart Studio\")},icon:s.pencil,click:function(t){i.sendDataToCloud(t)}},c.zoom2d={name:\"zoom2d\",title:function(t){return l(t,\"Zoom\")},attr:\"dragmode\",val:\"zoom\",icon:s.zoombox,click:u},c.pan2d={name:\"pan2d\",title:function(t){return l(t,\"Pan\")},attr:\"dragmode\",val:\"pan\",icon:s.pan,click:u},c.select2d={name:\"select2d\",title:function(t){return l(t,\"Box Select\")},attr:\"dragmode\",val:\"select\",icon:s.selectbox,click:u},c.lasso2d={name:\"lasso2d\",title:function(t){return l(t,\"Lasso Select\")},attr:\"dragmode\",val:\"lasso\",icon:s.lasso,click:u},c.zoomIn2d={name:\"zoomIn2d\",title:function(t){return l(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:s.zoom_plus,click:u},c.zoomOut2d={name:\"zoomOut2d\",title:function(t){return l(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:s.zoom_minus,click:u},c.autoScale2d={name:\"autoScale2d\",title:function(t){return l(t,\"Autoscale\")},attr:\"zoom\",val:\"auto\",icon:s.autoscale,click:u},c.resetScale2d={name:\"resetScale2d\",title:function(t){return l(t,\"Reset axes\")},attr:\"zoom\",val:\"reset\",icon:s.home,click:u},c.hoverClosestCartesian={name:\"hoverClosestCartesian\",title:function(t){return l(t,\"Show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:s.tooltip_basic,gravity:\"ne\",click:u},c.hoverCompareCartesian={name:\"hoverCompareCartesian\",title:function(t){return l(t,\"Compare data on hover\")},attr:\"hovermode\",val:function(t){return t._fullLayout._isHoriz?\"y\":\"x\"},icon:s.tooltip_compare,gravity:\"ne\",click:u},c.zoom3d={name:\"zoom3d\",title:function(t){return l(t,\"Zoom\")},attr:\"scene.dragmode\",val:\"zoom\",icon:s.zoombox,click:h},c.pan3d={name:\"pan3d\",title:function(t){return l(t,\"Pan\")},attr:\"scene.dragmode\",val:\"pan\",icon:s.pan,click:h},c.orbitRotation={name:\"orbitRotation\",title:function(t){return l(t,\"Orbital rotation\")},attr:\"scene.dragmode\",val:\"orbit\",icon:s[\"3d_rotate\"],click:h},c.tableRotation={name:\"tableRotation\",title:function(t){return l(t,\"Turntable rotation\")},attr:\"scene.dragmode\",val:\"turntable\",icon:s[\"z-axis\"],click:h},c.resetCameraDefault3d={name:\"resetCameraDefault3d\",title:function(t){return l(t,\"Reset camera to default\")},attr:\"resetDefault\",icon:s.home,click:f},c.resetCameraLastSave3d={name:\"resetCameraLastSave3d\",title:function(t){return l(t,\"Reset camera to last save\")},attr:\"resetLastSave\",icon:s.movie,click:f},c.hoverClosest3d={name:\"hoverClosest3d\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=p(t,e);n.call(\"_guiRelayout\",t,r)}},c.zoomInGeo={name:\"zoomInGeo\",title:function(t){return l(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:s.zoom_plus,click:d},c.zoomOutGeo={name:\"zoomOutGeo\",title:function(t){return l(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:s.zoom_minus,click:d},c.resetGeo={name:\"resetGeo\",title:function(t){return l(t,\"Reset\")},attr:\"reset\",val:null,icon:s.autoscale,click:d},c.hoverClosestGeo={name:\"hoverClosestGeo\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:v},c.hoverClosestGl2d={name:\"hoverClosestGl2d\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:v},c.hoverClosestPie={name:\"hoverClosestPie\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:s.tooltip_basic,gravity:\"ne\",click:v},c.resetViewSankey={name:\"resetSankeyGroup\",title:function(t){return l(t,\"Reset view\")},icon:s.home,click:function(t){for(var e={\"node.groups\":[],\"node.x\":[],\"node.y\":[]},r=0;r<t._fullData.length;r++){var i=t._fullData[r]._viewInitial;e[\"node.groups\"].push(i.node.groups.slice()),e[\"node.x\"].push(i.node.x.slice()),e[\"node.y\"].push(i.node.y.slice())}n.call(\"restyle\",t,e)}},c.toggleHover={name:\"toggleHover\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=p(t,e);r.hovermode=g(t),n.call(\"_guiRelayout\",t,r)}},c.resetViews={name:\"resetViews\",title:function(t){return l(t,\"Reset views\")},icon:s.home,click:function(t,e){var r=e.currentTarget;r.setAttribute(\"data-attr\",\"zoom\"),r.setAttribute(\"data-val\",\"reset\"),u(t,e),r.setAttribute(\"data-attr\",\"resetLastSave\"),f(t,e),m(t,\"geo\"),m(t,\"mapbox\")}},c.toggleSpikelines={name:\"toggleSpikelines\",title:function(t){return l(t,\"Toggle Spike Lines\")},icon:s.spikeline,attr:\"_cartesianSpikesEnabled\",val:\"on\",click:function(t){var e=t._fullLayout;e._cartesianSpikesEnabled=\"on\"===e._cartesianSpikesEnabled?\"off\":\"on\";var r=function(t){for(var e,r,n=t._fullLayout,i=a.list(t,null,!0),o={},s=0;s<i.length;s++)e=i[s],r=e._name,o[r+\".showspikes\"]=\"on\"===n._cartesianSpikesEnabled||e._showSpikeInitial;return o}(t);n.call(\"_guiRelayout\",t,r)}},c.resetViewMapbox={name:\"resetViewMapbox\",title:function(t){return l(t,\"Reset view\")},attr:\"reset\",icon:s.home,click:function(t){m(t,\"mapbox\")}}},{\"../../fonts/ploticon\":699,\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../../plots/plots\":828,\"../../registry\":847}],652:[function(t,e,r){\"use strict\";r.manage=t(\"./manage\")},{\"./manage\":653}],653:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"../../traces/scatter/subtypes\"),a=t(\"../../registry\"),o=t(\"./modebar\"),s=t(\"./buttons\");e.exports=function(t){var e=t._fullLayout,r=t._context,l=e._modeBar;if(r.displayModeBar||r.watermark){if(!Array.isArray(r.modeBarButtonsToRemove))throw new Error([\"*modeBarButtonsToRemove* configuration options\",\"must be an array.\"].join(\" \"));if(!Array.isArray(r.modeBarButtonsToAdd))throw new Error([\"*modeBarButtonsToAdd* configuration options\",\"must be an array.\"].join(\" \"));var c,u=r.modeBarButtons;c=Array.isArray(u)&&u.length?function(t){for(var e=0;e<t.length;e++)for(var r=t[e],n=0;n<r.length;n++){var i=r[n];if(\"string\"==typeof i){if(void 0===s[i])throw new Error([\"*modeBarButtons* configuration options\",\"invalid button name\"].join(\" \"));t[e][n]=s[i]}}return t}(u):!r.displayModeBar&&r.watermark?[]:function(t){var e=t._fullLayout,r=t._fullData,o=t._context,l=o.modeBarButtonsToRemove,c=o.modeBarButtonsToAdd,u=e._has(\"cartesian\"),h=e._has(\"gl3d\"),f=e._has(\"geo\"),p=e._has(\"pie\"),d=e._has(\"funnelarea\"),g=e._has(\"gl2d\"),v=e._has(\"ternary\"),m=e._has(\"mapbox\"),y=e._has(\"polar\"),x=e._has(\"sankey\"),b=function(t){for(var e=n.list({_fullLayout:t},null,!0),r=0;r<e.length;r++)if(!e[r].fixedrange)return!1;return!0}(e),_=[];function w(t){if(t.length){for(var e=[],r=0;r<t.length;r++){var n=t[r];-1===l.indexOf(n)&&e.push(s[n])}_.push(e)}}var k=[\"toImage\"];o.showEditInChartStudio?k.push(\"editInChartStudio\"):o.showSendToCloud&&k.push(\"sendDataToCloud\");w(k);var T=[],A=[],M=[],S=[];(u||g||p||d||v)+f+h+m+y>1?(A=[\"toggleHover\"],M=[\"resetViews\"]):f?(T=[\"zoomInGeo\",\"zoomOutGeo\"],A=[\"hoverClosestGeo\"],M=[\"resetGeo\"]):h?(A=[\"hoverClosest3d\"],M=[\"resetCameraDefault3d\",\"resetCameraLastSave3d\"]):m?(A=[\"toggleHover\"],M=[\"resetViewMapbox\"]):g?A=[\"hoverClosestGl2d\"]:p?A=[\"hoverClosestPie\"]:x?(A=[\"hoverClosestCartesian\",\"hoverCompareCartesian\"],M=[\"resetViewSankey\"]):A=[\"toggleHover\"];u&&(A=[\"toggleSpikelines\",\"hoverClosestCartesian\",\"hoverCompareCartesian\"]);(function(t){for(var e=0;e<t.length;e++)if(!a.traceIs(t[e],\"noHover\"))return!1;return!0})(r)&&(A=[]);!u&&!g||b||(T=[\"zoomIn2d\",\"zoomOut2d\",\"autoScale2d\"],\"resetViews\"!==M[0]&&(M=[\"resetScale2d\"]));h?S=[\"zoom3d\",\"pan3d\",\"orbitRotation\",\"tableRotation\"]:(u||g)&&!b||v?S=[\"zoom2d\",\"pan2d\"]:m||f?S=[\"pan2d\"]:y&&(S=[\"zoom2d\"]);(function(t){for(var e=!1,r=0;r<t.length&&!e;r++){var n=t[r];n._module&&n._module.selectPoints&&(a.traceIs(n,\"scatter-like\")?(i.hasMarkers(n)||i.hasText(n))&&(e=!0):a.traceIs(n,\"box-violin\")&&\"all\"!==n.boxpoints&&\"all\"!==n.points||(e=!0))}return e})(r)&&S.push(\"select2d\",\"lasso2d\");return w(S),w(T.concat(M)),w(A),function(t,e){if(e.length)if(Array.isArray(e[0]))for(var r=0;r<e.length;r++)t.push(e[r]);else t.push(e);return t}(_,c)}(t),l?l.update(t,c):e._modeBar=o(t,c)}else l&&(l.destroy(),delete e._modeBar)}},{\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../../traces/scatter/subtypes\":1135,\"./buttons\":651,\"./modebar\":654}],654:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../fonts/ploticon\"),s=new DOMParser;function l(t){this.container=t.container,this.element=document.createElement(\"div\"),this.update(t.graphInfo,t.buttons),this.container.appendChild(this.element)}var c=l.prototype;c.update=function(t,e){this.graphInfo=t;var r=this.graphInfo._context,n=this.graphInfo._fullLayout,i=\"modebar-\"+n._uid;this.element.setAttribute(\"id\",i),this._uid=i,this.element.className=\"modebar\",\"hover\"===r.displayModeBar&&(this.element.className+=\" modebar--hover ease-bg\"),\"v\"===n.modebar.orientation&&(this.element.className+=\" vertical\",e=e.reverse());var o=n.modebar,s=\"hover\"===r.displayModeBar?\".js-plotly-plot .plotly:hover \":\"\";a.deleteRelatedStyleRule(i),a.addRelatedStyleRule(i,s+\"#\"+i+\" .modebar-group\",\"background-color: \"+o.bgcolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn .icon path\",\"fill: \"+o.color),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn:hover .icon path\",\"fill: \"+o.activecolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn.active .icon path\",\"fill: \"+o.activecolor);var l=!this.hasButtons(e),c=this.hasLogo!==r.displaylogo,u=this.locale!==r.locale;if(this.locale=r.locale,(l||c||u)&&(this.removeAllButtons(),this.updateButtons(e),r.watermark||r.displaylogo)){var h=this.getLogo();r.watermark&&(h.className=h.className+\" watermark\"),\"v\"===n.modebar.orientation?this.element.insertBefore(h,this.element.childNodes[0]):this.element.appendChild(h),this.hasLogo=!0}this.updateActiveButton()},c.updateButtons=function(t){var e=this;this.buttons=t,this.buttonElements=[],this.buttonsNames=[],this.buttons.forEach(function(t){var r=e.createGroup();t.forEach(function(t){var n=t.name;if(!n)throw new Error(\"must provide button 'name' in button config\");if(-1!==e.buttonsNames.indexOf(n))throw new Error(\"button name '\"+n+\"' is taken\");e.buttonsNames.push(n);var i=e.createButton(t);e.buttonElements.push(i),r.appendChild(i)}),e.element.appendChild(r)})},c.createGroup=function(){var t=document.createElement(\"div\");return t.className=\"modebar-group\",t},c.createButton=function(t){var e=this,r=document.createElement(\"a\");r.setAttribute(\"rel\",\"tooltip\"),r.className=\"modebar-btn\";var i=t.title;void 0===i?i=t.name:\"function\"==typeof i&&(i=i(this.graphInfo)),(i||0===i)&&r.setAttribute(\"data-title\",i),void 0!==t.attr&&r.setAttribute(\"data-attr\",t.attr);var a=t.val;if(void 0!==a&&(\"function\"==typeof a&&(a=a(this.graphInfo)),r.setAttribute(\"data-val\",a)),\"function\"!=typeof t.click)throw new Error(\"must provide button 'click' function in button config\");r.addEventListener(\"click\",function(r){t.click(e.graphInfo,r),e.updateActiveButton(r.currentTarget)}),r.setAttribute(\"data-toggle\",t.toggle||!1),t.toggle&&n.select(r).classed(\"active\",!0);var s=t.icon;return\"function\"==typeof s?r.appendChild(s()):r.appendChild(this.createIcon(s||o.question)),r.setAttribute(\"data-gravity\",t.gravity||\"n\"),r},c.createIcon=function(t){var e,r=i(t.height)?Number(t.height):t.ascent-t.descent,n=\"http://www.w3.org/2000/svg\";if(t.path){(e=document.createElementNS(n,\"svg\")).setAttribute(\"viewBox\",[0,0,t.width,r].join(\" \")),e.setAttribute(\"class\",\"icon\");var a=document.createElementNS(n,\"path\");a.setAttribute(\"d\",t.path),t.transform?a.setAttribute(\"transform\",t.transform):void 0!==t.ascent&&a.setAttribute(\"transform\",\"matrix(1 0 0 -1 0 \"+t.ascent+\")\"),e.appendChild(a)}t.svg&&(e=s.parseFromString(t.svg,\"application/xml\").childNodes[0]);return e.setAttribute(\"height\",\"1em\"),e.setAttribute(\"width\",\"1em\"),e},c.updateActiveButton=function(t){var e=this.graphInfo._fullLayout,r=void 0!==t?t.getAttribute(\"data-attr\"):null;this.buttonElements.forEach(function(t){var i=t.getAttribute(\"data-val\")||!0,o=t.getAttribute(\"data-attr\"),s=\"true\"===t.getAttribute(\"data-toggle\"),l=n.select(t);if(s)o===r&&l.classed(\"active\",!l.classed(\"active\"));else{var c=null===o?o:a.nestedProperty(e,o).get();l.classed(\"active\",c===i)}})},c.hasButtons=function(t){var e=this.buttons;if(!e)return!1;if(t.length!==e.length)return!1;for(var r=0;r<t.length;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;n++)if(t[r][n].name!==e[r][n].name)return!1}return!0},c.getLogo=function(){var t=this.createGroup(),e=document.createElement(\"a\");return e.href=\"https://plot.ly/\",e.target=\"_blank\",e.setAttribute(\"data-title\",a._(this.graphInfo,\"Produced with Plotly\")),e.className=\"modebar-btn plotlyjsicon modebar-btn--logo\",e.appendChild(this.createIcon(o.newplotlylogo)),t.appendChild(e),t},c.removeAllButtons=function(){for(;this.element.firstChild;)this.element.removeChild(this.element.firstChild);this.hasLogo=!1},c.destroy=function(){a.removeElement(this.container.querySelector(\".modebar\")),a.deleteRelatedStyleRule(this._uid)},e.exports=function(t,e){var r=t._fullLayout,i=new l({graphInfo:t,container:r._modebardiv.node(),buttons:e});return r._privateplot&&n.select(i.element).append(\"span\").classed(\"badge-private float--left\",!0).text(\"PRIVATE\"),i}},{\"../../fonts/ploticon\":699,\"../../lib\":719,d3:163,\"fast-isnumeric\":225}],655:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=(0,t(\"../../plot_api/plot_template\").templatedArray)(\"button\",{visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},step:{valType:\"enumerated\",values:[\"month\",\"year\",\"day\",\"hour\",\"minute\",\"second\",\"all\"],dflt:\"month\",editType:\"plot\"},stepmode:{valType:\"enumerated\",values:[\"backward\",\"todate\"],dflt:\"backward\",editType:\"plot\"},count:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},label:{valType:\"string\",editType:\"plot\"},editType:\"plot\"});e.exports={visible:{valType:\"boolean\",editType:\"plot\"},buttons:a,x:{valType:\"number\",min:-2,max:3,editType:\"plot\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"plot\"},y:{valType:\"number\",min:-2,max:3,editType:\"plot\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"bottom\",editType:\"plot\"},font:n({editType:\"plot\"}),bgcolor:{valType:\"color\",dflt:i.lightLine,editType:\"plot\"},activecolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"plot\"}},{\"../../plot_api/plot_template\":757,\"../../plots/font_attributes\":793,\"../color/attributes\":592}],656:[function(t,e,r){\"use strict\";e.exports={yPad:.02,minButtonWidth:30,rx:3,ry:3,lightAmount:25,darkAmount:10}},{}],657:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../../plots/array_container_defaults\"),s=t(\"./attributes\"),l=t(\"./constants\");function c(t,e,r,i){var a=i.calendar;function o(r,i){return n.coerce(t,e,s.buttons,r,i)}if(o(\"visible\")){var l=o(\"step\");\"all\"!==l&&(!a||\"gregorian\"===a||\"month\"!==l&&\"year\"!==l?o(\"stepmode\"):e.stepmode=\"backward\",o(\"count\")),o(\"label\")}}e.exports=function(t,e,r,u,h){var f=t.rangeselector||{},p=a.newContainer(e,\"rangeselector\");function d(t,e){return n.coerce(f,p,s,t,e)}if(d(\"visible\",o(f,p,{name:\"buttons\",handleItemDefaults:c,calendar:h}).length>0)){var g=function(t,e,r){for(var n=r.filter(function(r){return e[r].anchor===t._id}),i=0,a=0;a<n.length;a++){var o=e[n[a]].domain;o&&(i=Math.max(o[1],i))}return[t.domain[0],i+l.yPad]}(e,r,u);d(\"x\",g[0]),d(\"y\",g[1]),n.noneOrAll(t,e,[\"x\",\"y\"]),d(\"xanchor\"),d(\"yanchor\"),n.coerceFont(d,\"font\",r.font);var v=d(\"bgcolor\");d(\"activecolor\",i.contrast(v,l.lightAmount,l.darkAmount)),d(\"bordercolor\"),d(\"borderwidth\")}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/array_container_defaults\":763,\"../color\":593,\"./attributes\":655,\"./constants\":656}],658:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../color\"),s=t(\"../drawing\"),l=t(\"../../lib\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"../../plots/cartesian/axis_ids\"),h=t(\"../../constants/alignment\"),f=h.LINE_SPACING,p=h.FROM_TL,d=h.FROM_BR,g=t(\"./constants\"),v=t(\"./get_update_object\");function m(t){return t._id}function y(t,e,r){var n=l.ensureSingle(t,\"rect\",\"selector-rect\",function(t){t.attr(\"shape-rendering\",\"crispEdges\")});n.attr({rx:g.rx,ry:g.ry}),n.call(o.stroke,e.bordercolor).call(o.fill,function(t,e){return e._isActive||e._isHovered?t.activecolor:t.bgcolor}(e,r)).style(\"stroke-width\",e.borderwidth+\"px\")}function x(t,e,r,n){l.ensureSingle(t,\"text\",\"selector-text\",function(t){t.classed(\"user-select-none\",!0).attr(\"text-anchor\",\"middle\")}).call(s.font,e.font).text(function(t,e){if(t.label)return e?l.templateString(t.label,e):t.label;return\"all\"===t.step?\"all\":t.count+t.step.charAt(0)}(r,n._fullLayout._meta)).call(function(t){c.convertToTspans(t,n)})}e.exports=function(t){var e=t._fullLayout._infolayer.selectAll(\".rangeselector\").data(function(t){for(var e=u.list(t,\"x\",!0),r=[],n=0;n<e.length;n++){var i=e[n];i.rangeselector&&i.rangeselector.visible&&r.push(i)}return r}(t),m);e.enter().append(\"g\").classed(\"rangeselector\",!0),e.exit().remove(),e.style({cursor:\"pointer\",\"pointer-events\":\"all\"}),e.each(function(e){var r=n.select(this),o=e,u=o.rangeselector,h=r.selectAll(\"g.button\").data(l.filterVisible(u.buttons));h.enter().append(\"g\").classed(\"button\",!0),h.exit().remove(),h.each(function(e){var r=n.select(this),a=v(o,e);e._isActive=function(t,e,r){if(\"all\"===e.step)return!0===t.autorange;var n=Object.keys(r);return t.range[0]===r[n[0]]&&t.range[1]===r[n[1]]}(o,e,a),r.call(y,u,e),r.call(x,u,e,t),r.on(\"click\",function(){t._dragged||i.call(\"_guiRelayout\",t,a)}),r.on(\"mouseover\",function(){e._isHovered=!0,r.call(y,u,e)}),r.on(\"mouseout\",function(){e._isHovered=!1,r.call(y,u,e)})}),function(t,e,r,i,o){var u=0,h=0,v=r.borderwidth;e.each(function(){var t=n.select(this),e=t.select(\".selector-text\"),i=r.font.size*f,a=Math.max(i*c.lineCount(e),16)+3;h=Math.max(h,a)}),e.each(function(){var t=n.select(this),e=t.select(\".selector-rect\"),i=t.select(\".selector-text\"),a=i.node()&&s.bBox(i.node()).width,o=r.font.size*f,l=c.lineCount(i),p=Math.max(a+10,g.minButtonWidth);t.attr(\"transform\",\"translate(\"+(v+u)+\",\"+v+\")\"),e.attr({x:0,y:0,width:p,height:h}),c.positionText(i,p/2,h/2-(l-1)*o/2+3),u+=p+5});var m=t._fullLayout._size,y=m.l+m.w*r.x,x=m.t+m.h*(1-r.y),b=\"left\";l.isRightAnchor(r)&&(y-=u,b=\"right\");l.isCenterAnchor(r)&&(y-=u/2,b=\"center\");var _=\"top\";l.isBottomAnchor(r)&&(x-=h,_=\"bottom\");l.isMiddleAnchor(r)&&(x-=h/2,_=\"middle\");u=Math.ceil(u),h=Math.ceil(h),y=Math.round(y),x=Math.round(x),a.autoMargin(t,i+\"-range-selector\",{x:r.x,y:r.y,l:u*p[b],r:u*d[b],b:h*d[_],t:h*p[_]}),o.attr(\"transform\",\"translate(\"+y+\",\"+x+\")\")}(t,h,u,o._name,r)})}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axis_ids\":770,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../drawing\":614,\"./constants\":656,\"./get_update_object\":659,d3:163}],659:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e){var r=t._name,i={};if(\"all\"===e.step)i[r+\".autorange\"]=!0;else{var a=function(t,e){var r,i=t.range,a=new Date(t.r2l(i[1])),o=e.step,s=e.count;switch(e.stepmode){case\"backward\":r=t.l2r(+n.time[o].utc.offset(a,-s));break;case\"todate\":var l=n.time[o].utc.offset(a,-s);r=t.l2r(+n.time[o].utc.ceil(l))}var c=i[1];return[r,c]}(t,e);i[r+\".range[0]\"]=a[0],i[r+\".range[1]\"]=a[1]}return i}},{d3:163}],660:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"rangeselector\",schema:{subplots:{xaxis:{rangeselector:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":655,\"./defaults\":657,\"./draw\":658}],661:[function(t,e,r){\"use strict\";var n=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",dflt:n.background,editType:\"plot\"},bordercolor:{valType:\"color\",dflt:n.defaultLine,editType:\"plot\"},borderwidth:{valType:\"integer\",dflt:0,min:0,editType:\"plot\"},autorange:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}}],editType:\"calc\",impliedEdits:{autorange:!1}},thickness:{valType:\"number\",dflt:.15,min:0,max:1,editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"}},{\"../color/attributes\":592}],662:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\").list,i=t(\"../../plots/cartesian/autorange\").getAutoRange,a=t(\"./constants\");e.exports=function(t){for(var e=n(t,\"x\",!0),r=0;r<e.length;r++){var o=e[r],s=o[a.name];s&&s.visible&&s.autorange&&(s._input.autorange=!0,s._input.range=s.range=i(t,o))}}},{\"../../plots/cartesian/autorange\":766,\"../../plots/cartesian/axis_ids\":770,\"./constants\":663}],663:[function(t,e,r){\"use strict\";e.exports={name:\"rangeslider\",containerClassName:\"rangeslider-container\",bgClassName:\"rangeslider-bg\",rangePlotClassName:\"rangeslider-rangeplot\",maskMinClassName:\"rangeslider-mask-min\",maskMaxClassName:\"rangeslider-mask-max\",slideBoxClassName:\"rangeslider-slidebox\",grabberMinClassName:\"rangeslider-grabber-min\",grabAreaMinClassName:\"rangeslider-grabarea-min\",handleMinClassName:\"rangeslider-handle-min\",grabberMaxClassName:\"rangeslider-grabber-max\",grabAreaMaxClassName:\"rangeslider-grabarea-max\",handleMaxClassName:\"rangeslider-handle-max\",maskMinOppAxisClassName:\"rangeslider-mask-min-opp-axis\",maskMaxOppAxisClassName:\"rangeslider-mask-max-opp-axis\",maskColor:\"rgba(0,0,0,0.4)\",maskOppAxisColor:\"rgba(0,0,0,0.2)\",slideBoxFill:\"transparent\",slideBoxCursor:\"ew-resize\",grabAreaFill:\"transparent\",grabAreaCursor:\"col-resize\",grabAreaWidth:10,handleWidth:4,handleRadius:1,handleStrokeWidth:1,extraPad:15}},{}],664:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"./attributes\"),s=t(\"./oppaxis_attributes\");e.exports=function(t,e,r){var l=t[r],c=e[r];if(l.rangeslider||e._requestRangeslider[c._id]){n.isPlainObject(l.rangeslider)||(l.rangeslider={});var u,h,f=l.rangeslider,p=i.newContainer(c,\"rangeslider\");if(_(\"visible\")){_(\"bgcolor\",e.plot_bgcolor),_(\"bordercolor\"),_(\"borderwidth\"),_(\"thickness\"),_(\"autorange\",!c.isValidRange(f.range)),_(\"range\");var d=e._subplots;if(d)for(var g=d.cartesian.filter(function(t){return t.substr(0,t.indexOf(\"y\"))===a.name2id(r)}).map(function(t){return t.substr(t.indexOf(\"y\"),t.length)}),v=n.simpleMap(g,a.id2name),m=0;m<v.length;m++){var y=v[m];u=f[y]||{},h=i.newContainer(p,y,\"yaxis\");var x,b=e[y];u.range&&b.isValidRange(u.range)&&(x=\"fixed\"),\"match\"!==w(\"rangemode\",x)&&w(\"range\",b.range.slice())}p._input=f}}function _(t,e){return n.coerce(f,p,o,t,e)}function w(t,e){return n.coerce(u,h,s,t,e)}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/axis_ids\":770,\"./attributes\":661,\"./oppaxis_attributes\":668}],665:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=t(\"../drawing\"),l=t(\"../color\"),c=t(\"../titles\"),u=t(\"../../plots/cartesian\"),h=t(\"../../plots/cartesian/axis_ids\"),f=t(\"../dragelement\"),p=t(\"../../lib/setcursor\"),d=t(\"./constants\");function g(t,e,r,n){var i=o.ensureSingle(t,\"rect\",d.bgClassName,function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})}),a=n.borderwidth%2==0?n.borderwidth:n.borderwidth-1,l=-n._offsetShift,c=s.crispRound(e,n.borderwidth);i.attr({width:n._width+a,height:n._height+a,transform:\"translate(\"+l+\",\"+l+\")\",fill:n.bgcolor,stroke:n.bordercolor,\"stroke-width\":c})}function v(t,e,r,n){var i=e._fullLayout;o.ensureSingleById(i._topdefs,\"clipPath\",n._clipId,function(t){t.append(\"rect\").attr({x:0,y:0})}).select(\"rect\").attr({width:n._width,height:n._height})}function m(t,e,r,i){var l,c=e.calcdata,f=t.selectAll(\"g.\"+d.rangePlotClassName).data(r._subplotsWith,o.identity);f.enter().append(\"g\").attr(\"class\",function(t){return d.rangePlotClassName+\" \"+t}).call(s.setClipUrl,i._clipId,e),f.order(),f.exit().remove(),f.each(function(t,o){var s=n.select(this),f=0===o,p=h.getFromId(e,t,\"y\"),d=p._name,g=i[d],v={data:[],layout:{xaxis:{type:r.type,domain:[0,1],range:i.range.slice(),calendar:r.calendar},width:i._width,height:i._height,margin:{t:0,b:0,l:0,r:0}},_context:e._context};v.layout[d]={type:p.type,domain:[0,1],range:\"match\"!==g.rangemode?g.range.slice():p.range.slice(),calendar:p.calendar},a.supplyDefaults(v);var m=v._fullLayout.xaxis,y=v._fullLayout[d];m.clearCalc(),m.setScale(),y.clearCalc(),y.setScale();var x={id:t,plotgroup:s,xaxis:m,yaxis:y,isRangePlot:!0};f?l=x:(x.mainplot=\"xy\",x.mainplotinfo=l),u.rangePlot(e,x,function(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n],a=i[0].trace;a.xaxis+a.yaxis===e&&r.push(i)}return r}(c,t))})}function y(t,e,r,n,i){(o.ensureSingle(t,\"rect\",d.maskMinClassName,function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"height\",n._height).call(l.fill,d.maskColor),o.ensureSingle(t,\"rect\",d.maskMaxClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"height\",n._height).call(l.fill,d.maskColor),\"match\"!==i.rangemode)&&(o.ensureSingle(t,\"rect\",d.maskMinOppAxisClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"width\",n._width).call(l.fill,d.maskOppAxisColor),o.ensureSingle(t,\"rect\",d.maskMaxOppAxisClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"width\",n._width).style(\"border-top\",d.maskOppBorder).call(l.fill,d.maskOppAxisColor))}function x(t,e,r,n){e._context.staticPlot||o.ensureSingle(t,\"rect\",d.slideBoxClassName,function(t){t.attr({y:0,cursor:d.slideBoxCursor,\"shape-rendering\":\"crispEdges\"})}).attr({height:n._height,fill:d.slideBoxFill})}function b(t,e,r,n){var i=o.ensureSingle(t,\"g\",d.grabberMinClassName),a=o.ensureSingle(t,\"g\",d.grabberMaxClassName),s={x:0,width:d.handleWidth,rx:d.handleRadius,fill:l.background,stroke:l.defaultLine,\"stroke-width\":d.handleStrokeWidth,\"shape-rendering\":\"crispEdges\"},c={y:Math.round(n._height/4),height:Math.round(n._height/2)};if(o.ensureSingle(i,\"rect\",d.handleMinClassName,function(t){t.attr(s)}).attr(c),o.ensureSingle(a,\"rect\",d.handleMaxClassName,function(t){t.attr(s)}).attr(c),!e._context.staticPlot){var u={width:d.grabAreaWidth,x:0,y:0,fill:d.grabAreaFill,cursor:d.grabAreaCursor};o.ensureSingle(i,\"rect\",d.grabAreaMinClassName,function(t){t.attr(u)}).attr(\"height\",n._height),o.ensureSingle(a,\"rect\",d.grabAreaMaxClassName,function(t){t.attr(u)}).attr(\"height\",n._height)}}e.exports=function(t){for(var e=t._fullLayout,r=e._rangeSliderData,a=0;a<r.length;a++){var s=r[a][d.name];s._clipId=s._id+\"-\"+e._uid}var l=e._infolayer.selectAll(\"g.\"+d.containerClassName).data(r,function(t){return t._name});l.exit().each(function(t){var r=t[d.name];e._topdefs.select(\"#\"+r._clipId).remove()}).remove(),0!==r.length&&(l.enter().append(\"g\").classed(d.containerClassName,!0).attr(\"pointer-events\",\"all\"),l.each(function(r){var a=n.select(this),s=r[d.name],l=e[h.id2name(r.anchor)],u=s[h.id2name(r.anchor)];if(s.range){var _,w=o.simpleMap(s.range,r.r2l),k=o.simpleMap(r.range,r.r2l);_=k[0]<k[1]?[Math.min(w[0],k[0]),Math.max(w[1],k[1])]:[Math.max(w[0],k[0]),Math.min(w[1],k[1])],s.range=s._input.range=o.simpleMap(_,r.l2r)}r.cleanRange(\"rangeslider.range\");var T=e.margin,A=e._size,M=r.domain,S=s._tickHeight,E=s._oppBottom;s._width=A.w*(M[1]-M[0]);var C=Math.round(T.l+A.w*M[0]),L=Math.round(A.t+A.h*(1-E)+S+s._offsetShift+d.extraPad);a.attr(\"transform\",\"translate(\"+C+\",\"+L+\")\");var P=r.r2l(s.range[0]),O=r.r2l(s.range[1]),z=O-P;if(s.p2d=function(t){return t/s._width*z+P},s.d2p=function(t){return(t-P)/z*s._width},s._rl=[P,O],\"match\"!==u.rangemode){var I=l.r2l(u.range[0]),D=l.r2l(u.range[1])-I;s.d2pOppAxis=function(t){return(t-I)/D*s._height}}a.call(g,t,r,s).call(v,t,r,s).call(m,t,r,s).call(y,t,r,s,u).call(x,t,r,s).call(b,t,r,s),function(t,e,r,a){var s=t.select(\"rect.\"+d.slideBoxClassName).node(),l=t.select(\"rect.\"+d.grabAreaMinClassName).node(),c=t.select(\"rect.\"+d.grabAreaMaxClassName).node();t.on(\"mousedown\",function(){var u=n.event,h=u.target,d=u.clientX,g=d-t.node().getBoundingClientRect().left,v=a.d2p(r._rl[0]),m=a.d2p(r._rl[1]),y=f.coverSlip();function x(t){var u,f,x,b=+t.clientX-d;switch(h){case s:x=\"ew-resize\",u=v+b,f=m+b;break;case l:x=\"col-resize\",u=v+b,f=m;break;case c:x=\"col-resize\",u=v,f=m+b;break;default:x=\"ew-resize\",u=g,f=g+b}if(f<u){var _=f;f=u,u=_}a._pixelMin=u,a._pixelMax=f,p(n.select(y),x),function(t,e,r,n){function a(t){return r.l2r(o.constrain(t,n._rl[0],n._rl[1]))}var s=a(n.p2d(n._pixelMin)),l=a(n.p2d(n._pixelMax));window.requestAnimationFrame(function(){i.call(\"_guiRelayout\",e,r._name+\".range\",[s,l])})}(0,e,r,a)}y.addEventListener(\"mousemove\",x),y.addEventListener(\"mouseup\",function t(){y.removeEventListener(\"mousemove\",x);y.removeEventListener(\"mouseup\",t);o.removeElement(y)})})}(a,t,r,s),function(t,e,r,n,i,a){var s=d.handleWidth/2;function l(t){return o.constrain(t,0,n._width)}function c(t){return o.constrain(t,0,n._height)}function u(t){return o.constrain(t,-s,n._width+s)}var h=l(n.d2p(r._rl[0])),f=l(n.d2p(r._rl[1]));if(t.select(\"rect.\"+d.slideBoxClassName).attr(\"x\",h).attr(\"width\",f-h),t.select(\"rect.\"+d.maskMinClassName).attr(\"width\",h),t.select(\"rect.\"+d.maskMaxClassName).attr(\"x\",f).attr(\"width\",n._width-f),\"match\"!==a.rangemode){var p=n._height-c(n.d2pOppAxis(i._rl[1])),g=n._height-c(n.d2pOppAxis(i._rl[0]));t.select(\"rect.\"+d.maskMinOppAxisClassName).attr(\"x\",h).attr(\"height\",p).attr(\"width\",f-h),t.select(\"rect.\"+d.maskMaxOppAxisClassName).attr(\"x\",h).attr(\"y\",g).attr(\"height\",n._height-g).attr(\"width\",f-h),t.select(\"rect.\"+d.slideBoxClassName).attr(\"y\",p).attr(\"height\",g-p)}var v=Math.round(u(h-s))-.5,m=Math.round(u(f-s))+.5;t.select(\"g.\"+d.grabberMinClassName).attr(\"transform\",\"translate(\"+v+\",0.5)\"),t.select(\"g.\"+d.grabberMaxClassName).attr(\"transform\",\"translate(\"+m+\",0.5)\")}(a,0,r,s,l,u),\"bottom\"===r.side&&c.draw(t,r._id+\"title\",{propContainer:r,propName:r._name+\".title\",placeholder:e._dfltTitle.x,attributes:{x:r._offset+r._length/2,y:L+s._height+s._offsetShift+10+1.5*r.title.font.size,\"text-anchor\":\"middle\"}})}))}},{\"../../lib\":719,\"../../lib/setcursor\":739,\"../../plots/cartesian\":778,\"../../plots/cartesian/axis_ids\":770,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"../titles\":681,\"./constants\":663,d3:163}],666:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"./constants\"),a=i.name;function o(t){var e=t&&t[a];return e&&e.visible}r.isVisible=o,r.makeData=function(t){var e=n.list({_fullLayout:t},\"x\",!0),r=t.margin,i=[];if(!t._has(\"gl2d\"))for(var s=0;s<e.length;s++){var l=e[s];if(o(l)){i.push(l);var c=l[a];c._id=a+l._id,c._height=(t.height-r.b-r.t)*c.thickness,c._offsetShift=Math.floor(c.borderwidth/2)}}t._rangeSliderData=i},r.autoMarginOpts=function(t,e){for(var r=e[a],o=1/0,s=e._counterAxes,l=0;l<s.length;l++){var c=s[l],u=n.getFromId(t,c);o=Math.min(o,u.domain[0])}r._oppBottom=o;var h=\"bottom\"===e.side&&e._boundingBox.height||0;return r._tickHeight=h,{x:0,y:o,l:0,r:0,t:0,b:r._height+t._fullLayout.margin.b+h,pad:i.extraPad+2*r._offsetShift}}},{\"../../plots/cartesian/axis_ids\":770,\"./constants\":663}],667:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./oppaxis_attributes\"),o=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"rangeslider\",schema:{subplots:{xaxis:{rangeslider:n.extendFlat({},i,{yaxis:a})}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),calcAutorange:t(\"./calc_autorange\"),draw:t(\"./draw\"),isVisible:o.isVisible,makeData:o.makeData,autoMarginOpts:o.autoMarginOpts}},{\"../../lib\":719,\"./attributes\":661,\"./calc_autorange\":662,\"./defaults\":664,\"./draw\":665,\"./helpers\":666,\"./oppaxis_attributes\":668}],668:[function(t,e,r){\"use strict\";e.exports={_isSubplotObj:!0,rangemode:{valType:\"enumerated\",values:[\"auto\",\"fixed\",\"match\"],dflt:\"match\",editType:\"calc\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"plot\"},{valType:\"any\",editType:\"plot\"}],editType:\"plot\"},editType:\"calc\"}},{}],669:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../traces/scatter/attributes\").line,a=t(\"../drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray;e.exports=s(\"shape\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},type:{valType:\"enumerated\",values:[\"circle\",\"rect\",\"path\",\"line\"],editType:\"calc+arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},xref:o({},n.xref,{}),xsizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},xanchor:{valType:\"any\",editType:\"calc+arraydraw\"},x0:{valType:\"any\",editType:\"calc+arraydraw\"},x1:{valType:\"any\",editType:\"calc+arraydraw\"},yref:o({},n.yref,{}),ysizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},yanchor:{valType:\"any\",editType:\"calc+arraydraw\"},y0:{valType:\"any\",editType:\"calc+arraydraw\"},y1:{valType:\"any\",editType:\"calc+arraydraw\"},path:{valType:\"string\",editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},line:{color:o({},i.color,{editType:\"arraydraw\"}),width:o({},i.width,{editType:\"calc+arraydraw\"}),dash:o({},a,{editType:\"arraydraw\"}),editType:\"calc+arraydraw\"},fillcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},editType:\"arraydraw\"})},{\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../../traces/scatter/attributes\":1112,\"../annotations/attributes\":576,\"../drawing/attributes\":613}],670:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./constants\"),o=t(\"./helpers\");function s(t){return c(t.line.width,t.xsizemode,t.x0,t.x1,t.path,!1)}function l(t){return c(t.line.width,t.ysizemode,t.y0,t.y1,t.path,!0)}function c(t,e,r,i,s,l){var c=t/2,u=l;if(\"pixel\"===e){var h=s?o.extractPathCoords(s,l?a.paramIsY:a.paramIsX):[r,i],f=n.aggNums(Math.max,null,h),p=n.aggNums(Math.min,null,h),d=p<0?Math.abs(p)+c:c,g=f>0?f+c:c;return{ppad:c,ppadplus:u?d:g,ppadminus:u?g:d}}return{ppad:c}}function u(t,e,r,n,i){var s=\"category\"===t.type||\"multicategory\"===t.type?t.r2c:t.d2c;if(void 0!==e)return[s(e),s(r)];if(n){var l,c,u,h,f=1/0,p=-1/0,d=n.match(a.segmentRE);for(\"date\"===t.type&&(s=o.decodeDate(s)),l=0;l<d.length;l++)void 0!==(c=i[d[l].charAt(0)].drawn)&&(!(u=d[l].substr(1).match(a.paramRE))||u.length<c||((h=s(u[c]))<f&&(f=h),h>p&&(p=h)));return p>=f?[f,p]:void 0}}e.exports=function(t){var e=t._fullLayout,r=n.filterVisible(e.shapes);if(r.length&&t._fullData.length)for(var o=0;o<r.length;o++){var c,h,f=r[o];if(f._extremes={},\"paper\"!==f.xref){var p=\"pixel\"===f.xsizemode?f.xanchor:f.x0,d=\"pixel\"===f.xsizemode?f.xanchor:f.x1;(h=u(c=i.getFromId(t,f.xref),p,d,f.path,a.paramIsX))&&(f._extremes[c._id]=i.findExtremes(c,h,s(f)))}if(\"paper\"!==f.yref){var g=\"pixel\"===f.ysizemode?f.yanchor:f.y0,v=\"pixel\"===f.ysizemode?f.yanchor:f.y1;(h=u(c=i.getFromId(t,f.yref),g,v,f.path,a.paramIsY))&&(f._extremes[c._id]=i.findExtremes(c,h,l(f)))}}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./constants\":671,\"./helpers\":674}],671:[function(t,e,r){\"use strict\";e.exports={segmentRE:/[MLHVQCTSZ][^MLHVQCTSZ]*/g,paramRE:/[^\\s,]+/g,paramIsX:{M:{0:!0,drawn:0},L:{0:!0,drawn:0},H:{0:!0,drawn:0},V:{},Q:{0:!0,2:!0,drawn:2},C:{0:!0,2:!0,4:!0,drawn:4},T:{0:!0,drawn:0},S:{0:!0,2:!0,drawn:2},Z:{}},paramIsY:{M:{1:!0,drawn:1},L:{1:!0,drawn:1},H:{},V:{0:!0,drawn:0},Q:{1:!0,3:!0,drawn:3},C:{1:!0,3:!0,5:!0,drawn:5},T:{1:!0,drawn:1},S:{1:!0,3:!0,drawn:5},Z:{}},numParams:{M:2,L:2,H:1,V:1,Q:4,C:6,T:2,S:4,Z:0}}},{}],672:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\"),s=t(\"./helpers\");function l(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}if(a(\"visible\")){a(\"layer\"),a(\"opacity\"),a(\"fillcolor\"),a(\"line.color\"),a(\"line.width\"),a(\"line.dash\");for(var l=a(\"type\",t.path?\"path\":\"rect\"),c=a(\"xsizemode\"),u=a(\"ysizemode\"),h=[\"x\",\"y\"],f=0;f<2;f++){var p,d,g,v=h[f],m=v+\"anchor\",y=\"x\"===v?c:u,x={_fullLayout:r},b=i.coerceRef(t,e,x,v,\"\",\"paper\");if(\"paper\"!==b?((p=i.getFromId(x,b))._shapeIndices.push(e._index),g=s.rangeToShapePosition(p),d=s.shapePositionToRange(p)):d=g=n.identity,\"path\"!==l){var _=v+\"0\",w=v+\"1\",k=t[_],T=t[w];t[_]=d(t[_],!0),t[w]=d(t[w],!0),\"pixel\"===y?(a(_,0),a(w,10)):(i.coercePosition(e,x,a,b,_,.25),i.coercePosition(e,x,a,b,w,.75)),e[_]=g(e[_]),e[w]=g(e[w]),t[_]=k,t[w]=T}if(\"pixel\"===y){var A=t[m];t[m]=d(t[m],!0),i.coercePosition(e,x,a,b,m,.25),e[m]=g(e[m]),t[m]=A}}\"path\"===l?a(\"path\"):n.noneOrAll(t,e,[\"x0\",\"x1\",\"y0\",\"y1\"])}}e.exports=function(t,e){a(t,e,{name:\"shapes\",handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"./attributes\":669,\"./helpers\":674}],673:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../color\"),s=t(\"../drawing\"),l=t(\"../../plot_api/plot_template\").arrayEditor,c=t(\"../dragelement\"),u=t(\"../../lib/setcursor\"),h=t(\"./constants\"),f=t(\"./helpers\");function p(t,e){t._fullLayout._paperdiv.selectAll('.shapelayer [data-index=\"'+e+'\"]').remove();var r=t._fullLayout.shapes[e]||{};if(r._input&&!1!==r.visible)if(\"below\"!==r.layer)m(t._fullLayout._shapeUpperLayer);else if(\"paper\"===r.xref||\"paper\"===r.yref)m(t._fullLayout._shapeLowerLayer);else{var p=t._fullLayout._plots[r.xref+r.yref];if(p)m((p.mainplotinfo||p).shapelayer);else m(t._fullLayout._shapeLowerLayer)}function m(p){var m={\"data-index\":e,\"fill-rule\":\"evenodd\",d:g(t,r)},y=r.line.width?r.line.color:\"rgba(0,0,0,0)\",x=p.append(\"path\").attr(m).style(\"opacity\",r.opacity).call(o.stroke,y).call(o.fill,r.fillcolor).call(s.dashLine,r.line.dash,r.line.width);d(x,t,r),t._context.edits.shapePosition&&function(t,e,r,o,p){var m,y,x,b,_,w,k,T,A,M,S,E,C,L,P,O,z=10,I=10,D=\"pixel\"===r.xsizemode,R=\"pixel\"===r.ysizemode,F=\"line\"===r.type,B=\"path\"===r.type,N=l(t.layout,\"shapes\",r),j=N.modifyItem,U=a.getFromId(t,r.xref),V=a.getFromId(t,r.yref),q=f.getDataToPixel(t,U),H=f.getDataToPixel(t,V,!0),G=f.getPixelToData(t,U),Y=f.getPixelToData(t,V,!0),W=F?function(){var t=Math.max(r.line.width,10),n=p.append(\"g\").attr(\"data-index\",o);n.append(\"path\").attr(\"d\",e.attr(\"d\")).style({cursor:\"move\",\"stroke-width\":t,\"stroke-opacity\":\"0\"});var i={\"fill-opacity\":\"0\"},a=t/2>10?t/2:10;return n.append(\"circle\").attr({\"data-line-point\":\"start-point\",cx:D?q(r.xanchor)+r.x0:q(r.x0),cy:R?H(r.yanchor)-r.y0:H(r.y0),r:a}).style(i).classed(\"cursor-grab\",!0),n.append(\"circle\").attr({\"data-line-point\":\"end-point\",cx:D?q(r.xanchor)+r.x1:q(r.x1),cy:R?H(r.yanchor)-r.y1:H(r.y1),r:a}).style(i).classed(\"cursor-grab\",!0),n}():e,X={element:W.node(),gd:t,prepFn:function(n){D&&(_=q(r.xanchor));R&&(w=H(r.yanchor));\"path\"===r.type?P=r.path:(m=D?r.x0:q(r.x0),y=R?r.y0:H(r.y0),x=D?r.x1:q(r.x1),b=R?r.y1:H(r.y1));m<x?(A=m,C=\"x0\",M=x,L=\"x1\"):(A=x,C=\"x1\",M=m,L=\"x0\");!R&&y<b||R&&y>b?(k=y,S=\"y0\",T=b,E=\"y1\"):(k=b,S=\"y1\",T=y,E=\"y0\");Z(n),$(p,r),function(t,e,r){var n=e.xref,i=e.yref,o=a.getFromId(r,n),l=a.getFromId(r,i),c=\"\";\"paper\"===n||o.autorange||(c+=n);\"paper\"===i||l.autorange||(c+=i);s.setClipUrl(t,c?\"clip\"+r._fullLayout._uid+c:null,r)}(e,r,t),X.moveFn=\"move\"===O?J:K},doneFn:function(){u(e),Q(p),d(e,t,r),n.call(\"_guiRelayout\",t,N.getUpdateObj())},clickFn:function(){Q(p)}};function Z(t){if(F)O=\"path\"===t.target.tagName?\"move\":\"start-point\"===t.target.attributes[\"data-line-point\"].value?\"resize-over-start-point\":\"resize-over-end-point\";else{var r=X.element.getBoundingClientRect(),n=r.right-r.left,i=r.bottom-r.top,a=t.clientX-r.left,o=t.clientY-r.top,s=!B&&n>z&&i>I&&!t.shiftKey?c.getCursor(a/n,1-o/i):\"move\";u(e,s),O=s.split(\"-\")[0]}}function J(n,i){if(\"path\"===r.type){var a=function(t){return t},o=a,s=a;D?j(\"xanchor\",r.xanchor=G(_+n)):(o=function(t){return G(q(t)+n)},U&&\"date\"===U.type&&(o=f.encodeDate(o))),R?j(\"yanchor\",r.yanchor=Y(w+i)):(s=function(t){return Y(H(t)+i)},V&&\"date\"===V.type&&(s=f.encodeDate(s))),j(\"path\",r.path=v(P,o,s))}else D?j(\"xanchor\",r.xanchor=G(_+n)):(j(\"x0\",r.x0=G(m+n)),j(\"x1\",r.x1=G(x+n))),R?j(\"yanchor\",r.yanchor=Y(w+i)):(j(\"y0\",r.y0=Y(y+i)),j(\"y1\",r.y1=Y(b+i)));e.attr(\"d\",g(t,r)),$(p,r)}function K(n,i){if(B){var a=function(t){return t},o=a,s=a;D?j(\"xanchor\",r.xanchor=G(_+n)):(o=function(t){return G(q(t)+n)},U&&\"date\"===U.type&&(o=f.encodeDate(o))),R?j(\"yanchor\",r.yanchor=Y(w+i)):(s=function(t){return Y(H(t)+i)},V&&\"date\"===V.type&&(s=f.encodeDate(s))),j(\"path\",r.path=v(P,o,s))}else if(F){if(\"resize-over-start-point\"===O){var l=m+n,c=R?y-i:y+i;j(\"x0\",r.x0=D?l:G(l)),j(\"y0\",r.y0=R?c:Y(c))}else if(\"resize-over-end-point\"===O){var u=x+n,h=R?b-i:b+i;j(\"x1\",r.x1=D?u:G(u)),j(\"y1\",r.y1=R?h:Y(h))}}else{var d=~O.indexOf(\"n\")?k+i:k,N=~O.indexOf(\"s\")?T+i:T,W=~O.indexOf(\"w\")?A+n:A,X=~O.indexOf(\"e\")?M+n:M;~O.indexOf(\"n\")&&R&&(d=k-i),~O.indexOf(\"s\")&&R&&(N=T-i),(!R&&N-d>I||R&&d-N>I)&&(j(S,r[S]=R?d:Y(d)),j(E,r[E]=R?N:Y(N))),X-W>z&&(j(C,r[C]=D?W:G(W)),j(L,r[L]=D?X:G(X)))}e.attr(\"d\",g(t,r)),$(p,r)}function $(t,e){(D||R)&&function(){var r=\"path\"!==e.type,n=t.selectAll(\".visual-cue\").data([0]);n.enter().append(\"path\").attr({fill:\"#fff\",\"fill-rule\":\"evenodd\",stroke:\"#000\",\"stroke-width\":1}).classed(\"visual-cue\",!0);var a=q(D?e.xanchor:i.midRange(r?[e.x0,e.x1]:f.extractPathCoords(e.path,h.paramIsX))),o=H(R?e.yanchor:i.midRange(r?[e.y0,e.y1]:f.extractPathCoords(e.path,h.paramIsY)));if(a=f.roundPositionForSharpStrokeRendering(a,1),o=f.roundPositionForSharpStrokeRendering(o,1),D&&R){var s=\"M\"+(a-1-1)+\",\"+(o-1-1)+\"h-8v2h8 v8h2v-8 h8v-2h-8 v-8h-2 Z\";n.attr(\"d\",s)}else if(D){var l=\"M\"+(a-1-1)+\",\"+(o-9-1)+\"v18 h2 v-18 Z\";n.attr(\"d\",l)}else{var c=\"M\"+(a-9-1)+\",\"+(o-1-1)+\"h18 v2 h-18 Z\";n.attr(\"d\",c)}}()}function Q(t){t.selectAll(\".visual-cue\").remove()}c.init(X),W.node().onmousemove=Z}(t,x,r,e,p)}}function d(t,e,r){var n=(r.xref+r.yref).replace(/paper/g,\"\");s.setClipUrl(t,n?\"clip\"+e._fullLayout._uid+n:null,e)}function g(t,e){var r,n,o,s,l,c,u,p,d=e.type,g=a.getFromId(t,e.xref),v=a.getFromId(t,e.yref),m=t._fullLayout._size;if(g?(r=f.shapePositionToRange(g),n=function(t){return g._offset+g.r2p(r(t,!0))}):n=function(t){return m.l+m.w*t},v?(o=f.shapePositionToRange(v),s=function(t){return v._offset+v.r2p(o(t,!0))}):s=function(t){return m.t+m.h*(1-t)},\"path\"===d)return g&&\"date\"===g.type&&(n=f.decodeDate(n)),v&&\"date\"===v.type&&(s=f.decodeDate(s)),function(t,e,r){var n=t.path,a=t.xsizemode,o=t.ysizemode,s=t.xanchor,l=t.yanchor;return n.replace(h.segmentRE,function(t){var n=0,c=t.charAt(0),u=h.paramIsX[c],f=h.paramIsY[c],p=h.numParams[c],d=t.substr(1).replace(h.paramRE,function(t){return u[n]?t=\"pixel\"===a?e(s)+Number(t):e(t):f[n]&&(t=\"pixel\"===o?r(l)-Number(t):r(t)),++n>p&&(t=\"X\"),t});return n>p&&(d=d.replace(/[\\s,]*X.*/,\"\"),i.log(\"Ignoring extra params in segment \"+t)),c+d})}(e,n,s);if(\"pixel\"===e.xsizemode){var y=n(e.xanchor);l=y+e.x0,c=y+e.x1}else l=n(e.x0),c=n(e.x1);if(\"pixel\"===e.ysizemode){var x=s(e.yanchor);u=x-e.y0,p=x-e.y1}else u=s(e.y0),p=s(e.y1);if(\"line\"===d)return\"M\"+l+\",\"+u+\"L\"+c+\",\"+p;if(\"rect\"===d)return\"M\"+l+\",\"+u+\"H\"+c+\"V\"+p+\"H\"+l+\"Z\";var b=(l+c)/2,_=(u+p)/2,w=Math.abs(b-l),k=Math.abs(_-u),T=\"A\"+w+\",\"+k,A=b+w+\",\"+_;return\"M\"+A+T+\" 0 1,1 \"+(b+\",\"+(_-k))+T+\" 0 0,1 \"+A+\"Z\"}function v(t,e,r){return t.replace(h.segmentRE,function(t){var n=0,i=t.charAt(0),a=h.paramIsX[i],o=h.paramIsY[i],s=h.numParams[i];return i+t.substr(1).replace(h.paramRE,function(t){return n>=s?t:(a[n]?t=e(t):o[n]&&(t=r(t)),n++,t)})})}e.exports={draw:function(t){var e=t._fullLayout;for(var r in e._shapeUpperLayer.selectAll(\"path\").remove(),e._shapeLowerLayer.selectAll(\"path\").remove(),e._plots){var n=e._plots[r].shapelayer;n&&n.selectAll(\"path\").remove()}for(var i=0;i<e.shapes.length;i++)e.shapes[i].visible&&p(t,i)},drawOne:p}},{\"../../lib\":719,\"../../lib/setcursor\":739,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"./constants\":671,\"./helpers\":674}],674:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib\");r.rangeToShapePosition=function(t){return\"log\"===t.type?t.r2d:function(t){return t}},r.shapePositionToRange=function(t){return\"log\"===t.type?t.d2r:function(t){return t}},r.decodeDate=function(t){return function(e){return e.replace&&(e=e.replace(\"_\",\" \")),t(e)}},r.encodeDate=function(t){return function(e){return t(e).replace(\" \",\"_\")}},r.extractPathCoords=function(t,e){var r=[];return t.match(n.segmentRE).forEach(function(t){var a=e[t.charAt(0)].drawn;if(void 0!==a){var o=t.substr(1).match(n.paramRE);!o||o.length<a||r.push(i.cleanNumber(o[a]))}}),r},r.getDataToPixel=function(t,e,n){var i,a=t._fullLayout._size;if(e){var o=r.shapePositionToRange(e);i=function(t){return e._offset+e.r2p(o(t,!0))},\"date\"===e.type&&(i=r.decodeDate(i))}else i=n?function(t){return a.t+a.h*(1-t)}:function(t){return a.l+a.w*t};return i},r.getPixelToData=function(t,e,n){var i,a=t._fullLayout._size;if(e){var o=r.rangeToShapePosition(e);i=function(t){return o(e.p2r(t-e._offset))}}else i=n?function(t){return 1-(t-a.t)/a.h}:function(t){return(t-a.l)/a.w};return i},r.roundPositionForSharpStrokeRendering=function(t,e){var r=1===Math.round(e%2),n=Math.round(t);return r?n+.5:n}},{\"../../lib\":719,\"./constants\":671}],675:[function(t,e,r){\"use strict\";var n=t(\"./draw\");e.exports={moduleType:\"component\",name:\"shapes\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"shapes\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne}},{\"../../plots/cartesian/include_components\":777,\"./attributes\":669,\"./calc_autorange\":670,\"./defaults\":672,\"./draw\":673}],676:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/pad_attributes\"),a=t(\"../../lib/extend\").extendDeepAll,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/animation_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"./constants\"),u=l(\"step\",{visible:{valType:\"boolean\",dflt:!0},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\"},value:{valType:\"string\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"slider\",{visible:{valType:\"boolean\",dflt:!0},active:{valType:\"number\",min:0,dflt:0},steps:u,lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",min:-2,max:3,dflt:0},pad:a(i({editType:\"arraydraw\"}),{},{t:{dflt:20}}),xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\"},y:{valType:\"number\",min:-2,max:3,dflt:0},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},transition:{duration:{valType:\"number\",min:0,dflt:150},easing:{valType:\"enumerated\",values:s.transition.easing.values,dflt:\"cubic-in-out\"}},currentvalue:{visible:{valType:\"boolean\",dflt:!0},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},offset:{valType:\"number\",dflt:10},prefix:{valType:\"string\"},suffix:{valType:\"string\"},font:n({})},font:n({}),activebgcolor:{valType:\"color\",dflt:c.gripBgActiveColor},bgcolor:{valType:\"color\",dflt:c.railBgColor},bordercolor:{valType:\"color\",dflt:c.railBorderColor},borderwidth:{valType:\"number\",min:0,dflt:c.railBorderWidth},ticklen:{valType:\"number\",min:0,dflt:c.tickLength},tickcolor:{valType:\"color\",dflt:c.tickColor},tickwidth:{valType:\"number\",min:0,dflt:1},minorticklen:{valType:\"number\",min:0,dflt:c.minorTickLength}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/animation_attributes\":762,\"../../plots/font_attributes\":793,\"../../plots/pad_attributes\":827,\"./constants\":677}],677:[function(t,e,r){\"use strict\";e.exports={name:\"sliders\",containerClassName:\"slider-container\",groupClassName:\"slider-group\",inputAreaClass:\"slider-input-area\",railRectClass:\"slider-rail-rect\",railTouchRectClass:\"slider-rail-touch-rect\",gripRectClass:\"slider-grip-rect\",tickRectClass:\"slider-tick-rect\",inputProxyClass:\"slider-input-proxy\",labelsClass:\"slider-labels\",labelGroupClass:\"slider-label-group\",labelClass:\"slider-label\",currentValueClass:\"slider-current-value\",railHeight:5,menuIndexAttrName:\"slider-active-index\",autoMarginIdRoot:\"slider-\",minWidth:30,minHeight:30,textPadX:40,arrowOffsetX:4,railRadius:2,railWidth:5,railBorder:4,railBorderWidth:1,railBorderColor:\"#bec8d9\",railBgColor:\"#f8fafc\",railInset:8,stepInset:10,gripRadius:10,gripWidth:20,gripHeight:20,gripBorder:20,gripBorderWidth:1,gripBorderColor:\"#bec8d9\",gripBgColor:\"#f6f8fa\",gripBgActiveColor:\"#dbdde0\",labelPadding:8,labelOffset:0,tickWidth:1,tickColor:\"#333\",tickOffset:25,tickLength:7,minorTickOffset:25,minorTickColor:\"#333\",minorTickLength:4,currentValuePadding:8,currentValueInset:0}},{}],678:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.steps;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}for(var s=i(t,e,{name:\"steps\",handleItemDefaults:c}),l=0,u=0;u<s.length;u++)s[u].visible&&l++;if(l<2?e.visible=!1:o(\"visible\")){e._stepCount=l;var h=e._visibleSteps=n.filterVisible(s);(s[o(\"active\")]||{}).visible||(e.active=h[0]._index),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"len\"),o(\"lenmode\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"currentvalue.visible\")&&(o(\"currentvalue.xanchor\"),o(\"currentvalue.prefix\"),o(\"currentvalue.suffix\"),o(\"currentvalue.offset\"),n.coerceFont(o,\"currentvalue.font\",e.font)),o(\"transition.duration\"),o(\"transition.easing\"),o(\"bgcolor\"),o(\"activebgcolor\"),o(\"bordercolor\"),o(\"borderwidth\"),o(\"ticklen\"),o(\"tickwidth\"),o(\"tickcolor\"),o(\"minorticklen\")}}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}if(\"skip\"===t.method||Array.isArray(t.args)?r(\"visible\"):e.visible=!1){r(\"method\"),r(\"args\");var i=r(\"label\",\"step-\"+e._index);r(\"value\",i),r(\"execute\")}}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"./attributes\":676,\"./constants\":677}],679:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"./constants\"),h=t(\"../../constants/alignment\"),f=h.LINE_SPACING,p=h.FROM_TL,d=h.FROM_BR;function g(t){return u.autoMarginIdRoot+t._index}function v(t){return t._index}function m(t,e){var r=o.tester.selectAll(\"g.\"+u.labelGroupClass).data(e._visibleSteps);r.enter().append(\"g\").classed(u.labelGroupClass,!0);var a=0,c=0;r.each(function(t){var r=b(n.select(this),{step:t},e).node();if(r){var i=o.bBox(r);c=Math.max(c,i.height),a=Math.max(a,i.width)}}),r.remove();var h=e._dims={};h.inputAreaWidth=Math.max(u.railWidth,u.gripHeight);var f=t._fullLayout._size;h.lx=f.l+f.w*e.x,h.ly=f.t+f.h*(1-e.y),\"fraction\"===e.lenmode?h.outerLength=Math.round(f.w*e.len):h.outerLength=e.len,h.inputAreaStart=0,h.inputAreaLength=Math.round(h.outerLength-e.pad.l-e.pad.r);var v=(h.inputAreaLength-2*u.stepInset)/(e._stepCount-1),m=a+u.labelPadding;if(h.labelStride=Math.max(1,Math.ceil(m/v)),h.labelHeight=c,h.currentValueMaxWidth=0,h.currentValueHeight=0,h.currentValueTotalHeight=0,h.currentValueMaxLines=1,e.currentvalue.visible){var x=o.tester.append(\"g\");r.each(function(t){var r=y(x,e,t.label),n=r.node()&&o.bBox(r.node())||{width:0,height:0},i=l.lineCount(r);h.currentValueMaxWidth=Math.max(h.currentValueMaxWidth,Math.ceil(n.width)),h.currentValueHeight=Math.max(h.currentValueHeight,Math.ceil(n.height)),h.currentValueMaxLines=Math.max(h.currentValueMaxLines,i)}),h.currentValueTotalHeight=h.currentValueHeight+e.currentvalue.offset,x.remove()}h.height=h.currentValueTotalHeight+u.tickOffset+e.ticklen+u.labelOffset+h.labelHeight+e.pad.t+e.pad.b;var _=\"left\";s.isRightAnchor(e)&&(h.lx-=h.outerLength,_=\"right\"),s.isCenterAnchor(e)&&(h.lx-=h.outerLength/2,_=\"center\");var w=\"top\";s.isBottomAnchor(e)&&(h.ly-=h.height,w=\"bottom\"),s.isMiddleAnchor(e)&&(h.ly-=h.height/2,w=\"middle\"),h.outerLength=Math.ceil(h.outerLength),h.height=Math.ceil(h.height),h.lx=Math.round(h.lx),h.ly=Math.round(h.ly);var k={y:e.y,b:h.height*d[w],t:h.height*p[w]};\"fraction\"===e.lenmode?(k.l=0,k.xl=e.x-e.len*p[_],k.r=0,k.xr=e.x+e.len*d[_]):(k.x=e.x,k.l=h.outerLength*p[_],k.r=h.outerLength*d[_]),i.autoMargin(t,g(e),k)}function y(t,e,r){if(e.currentvalue.visible){var n,i,a=e._dims;switch(e.currentvalue.xanchor){case\"right\":n=a.inputAreaLength-u.currentValueInset-a.currentValueMaxWidth,i=\"left\";break;case\"center\":n=.5*a.inputAreaLength,i=\"middle\";break;default:n=u.currentValueInset,i=\"left\"}var c=s.ensureSingle(t,\"text\",u.labelClass,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":i,\"data-notex\":1})}),h=e.currentvalue.prefix?e.currentvalue.prefix:\"\";if(\"string\"==typeof r)h+=r;else{var p=e.steps[e.active].label,d=e._gd._fullLayout._meta;d&&(p=s.templateString(p,d)),h+=p}e.currentvalue.suffix&&(h+=e.currentvalue.suffix),c.call(o.font,e.currentvalue.font).text(h).call(l.convertToTspans,e._gd);var g=l.lineCount(c),v=(a.currentValueMaxLines+1-g)*e.currentvalue.font.size*f;return l.positionText(c,n,v),c}}function x(t,e,r){s.ensureSingle(t,\"rect\",u.gripRectClass,function(n){n.call(T,e,t,r).style(\"pointer-events\",\"all\")}).attr({width:u.gripWidth,height:u.gripHeight,rx:u.gripRadius,ry:u.gripRadius}).call(a.stroke,r.bordercolor).call(a.fill,r.bgcolor).style(\"stroke-width\",r.borderwidth+\"px\")}function b(t,e,r){var n=s.ensureSingle(t,\"text\",u.labelClass,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":\"middle\",\"data-notex\":1})}),i=e.step.label,a=r._gd._fullLayout._meta;return a&&(i=s.templateString(i,a)),n.call(o.font,r.font).text(i).call(l.convertToTspans,r._gd),n}function _(t,e){var r=s.ensureSingle(t,\"g\",u.labelsClass),i=e._dims,a=r.selectAll(\"g.\"+u.labelGroupClass).data(i.labelSteps);a.enter().append(\"g\").classed(u.labelGroupClass,!0),a.exit().remove(),a.each(function(t){var r=n.select(this);r.call(b,t,e),o.setTranslate(r,S(e,t.fraction),u.tickOffset+e.ticklen+e.font.size*f+u.labelOffset+i.currentValueTotalHeight)})}function w(t,e,r,n,i){var a=Math.round(n*(r._stepCount-1)),o=r._visibleSteps[a]._index;o!==r.active&&k(t,e,r,o,!0,i)}function k(t,e,r,n,a,o){var s=r.active;r.active=n,c(t.layout,u.name,r).applyUpdate(\"active\",n);var l=r.steps[r.active];e.call(M,r,o),e.call(y,r),t.emit(\"plotly_sliderchange\",{slider:r,step:r.steps[r.active],interaction:a,previousActive:s}),l&&l.method&&a&&(e._nextMethod?(e._nextMethod.step=l,e._nextMethod.doCallback=a,e._nextMethod.doTransition=o):(e._nextMethod={step:l,doCallback:a,doTransition:o},e._nextMethodRaf=window.requestAnimationFrame(function(){var r=e._nextMethod.step;r.method&&(r.execute&&i.executeAPICommand(t,r.method,r.args),e._nextMethod=null,e._nextMethodRaf=null)})))}function T(t,e,r){var i=r.node(),o=n.select(e);function s(){return r.data()[0]}t.on(\"mousedown\",function(){var t=s();e.emit(\"plotly_sliderstart\",{slider:t});var l=r.select(\".\"+u.gripRectClass);n.event.stopPropagation(),n.event.preventDefault(),l.call(a.fill,t.activebgcolor);var c=E(t,n.mouse(i)[0]);w(e,r,t,c,!0),t._dragging=!0,o.on(\"mousemove\",function(){var t=s(),a=E(t,n.mouse(i)[0]);w(e,r,t,a,!1)}),o.on(\"mouseup\",function(){var t=s();t._dragging=!1,l.call(a.fill,t.bgcolor),o.on(\"mouseup\",null),o.on(\"mousemove\",null),e.emit(\"plotly_sliderend\",{slider:t,step:t.steps[t.active]})})})}function A(t,e){var r=t.selectAll(\"rect.\"+u.tickRectClass).data(e._visibleSteps),i=e._dims;r.enter().append(\"rect\").classed(u.tickRectClass,!0),r.exit().remove(),r.attr({width:e.tickwidth+\"px\",\"shape-rendering\":\"crispEdges\"}),r.each(function(t,r){var s=r%i.labelStride==0,l=n.select(this);l.attr({height:s?e.ticklen:e.minorticklen}).call(a.fill,e.tickcolor),o.setTranslate(l,S(e,r/(e._stepCount-1))-.5*e.tickwidth,(s?u.tickOffset:u.minorTickOffset)+i.currentValueTotalHeight)})}function M(t,e,r){for(var n=t.select(\"rect.\"+u.gripRectClass),i=0,a=0;a<e._stepCount;a++)if(e._visibleSteps[a]._index===e.active){i=a;break}var o=S(e,i/(e._stepCount-1));if(!e._invokingCommand){var s=n;r&&e.transition.duration>0&&(s=s.transition().duration(e.transition.duration).ease(e.transition.easing)),s.attr(\"transform\",\"translate(\"+(o-.5*u.gripWidth)+\",\"+e._dims.currentValueTotalHeight+\")\")}}function S(t,e){var r=t._dims;return r.inputAreaStart+u.stepInset+(r.inputAreaLength-2*u.stepInset)*Math.min(1,Math.max(0,e))}function E(t,e){var r=t._dims;return Math.min(1,Math.max(0,(e-u.stepInset-r.inputAreaStart)/(r.inputAreaLength-2*u.stepInset-2*r.inputAreaStart)))}function C(t,e,r){var n=r._dims,i=s.ensureSingle(t,\"rect\",u.railTouchRectClass,function(n){n.call(T,e,t,r).style(\"pointer-events\",\"all\")});i.attr({width:n.inputAreaLength,height:Math.max(n.inputAreaWidth,u.tickOffset+r.ticklen+n.labelHeight)}).call(a.fill,r.bgcolor).attr(\"opacity\",0),o.setTranslate(i,0,n.currentValueTotalHeight)}function L(t,e){var r=e._dims,n=r.inputAreaLength-2*u.railInset,i=s.ensureSingle(t,\"rect\",u.railRectClass);i.attr({width:n,height:u.railWidth,rx:u.railRadius,ry:u.railRadius,\"shape-rendering\":\"crispEdges\"}).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\"),o.setTranslate(i,u.railInset,.5*(r.inputAreaWidth-u.railWidth)+r.currentValueTotalHeight)}e.exports=function(t){var e=t._fullLayout,r=function(t,e){for(var r=t[u.name],n=[],i=0;i<r.length;i++){var a=r[i];a.visible&&(a._gd=e,n.push(a))}return n}(e,t),a=e._infolayer.selectAll(\"g.\"+u.containerClassName).data(r.length>0?[0]:[]);function s(e){e._commandObserver&&(e._commandObserver.remove(),delete e._commandObserver),i.autoMargin(t,g(e))}if(a.enter().append(\"g\").classed(u.containerClassName,!0).style(\"cursor\",\"ew-resize\"),a.exit().each(function(){n.select(this).selectAll(\"g.\"+u.groupClassName).each(s)}).remove(),0!==r.length){var l=a.selectAll(\"g.\"+u.groupClassName).data(r,v);l.enter().append(\"g\").classed(u.groupClassName,!0),l.exit().each(s).remove();for(var c=0;c<r.length;c++){var h=r[c];m(t,h)}l.each(function(e){var r=n.select(this);!function(t){var e=t._dims;e.labelSteps=[];for(var r=t._stepCount,n=0;n<r;n+=e.labelStride)e.labelSteps.push({fraction:n/(r-1),step:t._visibleSteps[n]})}(e),i.manageCommandObserver(t,e,e._visibleSteps,function(e){var n=r.data()[0];n.active!==e.index&&(n._dragging||k(t,r,n,e.index,!1,!0))}),function(t,e,r){(r.steps[r.active]||{}).visible||(r.active=r._visibleSteps[0]._index);e.call(y,r).call(L,r).call(_,r).call(A,r).call(C,t,r).call(x,t,r);var n=r._dims;o.setTranslate(e,n.lx+r.pad.l,n.ly+r.pad.t),e.call(M,r,!1),e.call(y,r)}(t,n.select(this),e)})}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_template\":757,\"../../plots/plots\":828,\"../color\":593,\"../drawing\":614,\"./constants\":677,d3:163}],680:[function(t,e,r){\"use strict\";var n=t(\"./constants\");e.exports={moduleType:\"component\",name:n.name,layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":676,\"./constants\":677,\"./defaults\":678,\"./draw\":679}],681:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../drawing\"),c=t(\"../color\"),u=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/interactions\");e.exports={draw:function(t,e,r){var p,d=r.propContainer,g=r.propName,v=r.placeholder,m=r.traceIndex,y=r.avoid||{},x=r.attributes,b=r.transform,_=r.containerGroup,w=t._fullLayout,k=1,T=!1,A=d.title,M=(A&&A.text?A.text:\"\").trim(),S=A&&A.font?A.font:{},E=S.family,C=S.size,L=S.color;\"title.text\"===g?p=\"titleText\":-1!==g.indexOf(\"axis\")?p=\"axisTitleText\":g.indexOf(!0)&&(p=\"colorbarTitleText\");var P=t._context.edits[p];\"\"===M?k=0:M.replace(f,\" % \")===v.replace(f,\" % \")&&(k=.2,T=!0,P||(M=\"\"));r._meta?M=s.templateString(M,r._meta):w._meta&&(M=s.templateString(M,w._meta));var O=M||P;_||(_=s.ensureSingle(w._infolayer,\"g\",\"g-\"+e));var z=_.selectAll(\"text\").data(O?[0]:[]);if(z.enter().append(\"text\"),z.text(M).attr(\"class\",e),z.exit().remove(),!O)return _;function I(t){s.syncOrAsync([D,R],t)}function D(e){var r;return b?(r=\"\",b.rotate&&(r+=\"rotate(\"+[b.rotate,x.x,x.y]+\")\"),b.offset&&(r+=\"translate(0, \"+b.offset+\")\")):r=null,e.attr(\"transform\",r),e.style({\"font-family\":E,\"font-size\":n.round(C,2)+\"px\",fill:c.rgb(L),opacity:k*c.opacity(L),\"font-weight\":a.fontWeight}).attr(x).call(u.convertToTspans,t),a.previousPromises(t)}function R(t){var e=n.select(t.node().parentNode);if(y&&y.selection&&y.side&&M){e.attr(\"transform\",null);var r=0,a={left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}[y.side],o=-1!==[\"left\",\"top\"].indexOf(y.side)?-1:1,c=i(y.pad)?y.pad:2,u=l.bBox(e.node()),h={left:0,top:0,right:w.width,bottom:w.height},f=y.maxShift||(h[y.side]-u[y.side])*(\"left\"===y.side||\"top\"===y.side?-1:1);if(f<0)r=f;else{var p=y.offsetLeft||0,d=y.offsetTop||0;u.left-=p,u.right-=p,u.top-=d,u.bottom-=d,y.selection.each(function(){var t=l.bBox(this);s.bBoxIntersect(u,t,c)&&(r=Math.max(r,o*(t[y.side]-u[a])+c))}),r=Math.min(f,r)}if(r>0||f<0){var g={left:[-r,0],right:[r,0],top:[0,-r],bottom:[0,r]}[y.side];e.attr(\"transform\",\"translate(\"+g+\")\")}}}z.call(I),P&&(M?z.on(\".opacity\",null):(k=0,T=!0,z.text(v).on(\"mouseover.opacity\",function(){n.select(this).transition().duration(h.SHOW_PLACEHOLDER).style(\"opacity\",1)}).on(\"mouseout.opacity\",function(){n.select(this).transition().duration(h.HIDE_PLACEHOLDER).style(\"opacity\",0)})),z.call(u.makeEditable,{gd:t}).on(\"edit\",function(e){void 0!==m?o.call(\"_guiRestyle\",t,g,e,m):o.call(\"_guiRelayout\",t,g,e)}).on(\"cancel\",function(){this.text(this.attr(\"data-unformatted\")).call(I)}).on(\"input\",function(t){this.text(t||\" \").call(u.positionText,x.x,x.y)}));return z.classed(\"js-placeholder\",T),_}};var f=/ [XY][0-9]* /},{\"../../constants/interactions\":694,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../drawing\":614,d3:163,\"fast-isnumeric\":225}],682:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/pad_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=l(\"button\",{visible:{valType:\"boolean\"},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\",dflt:\"\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"updatemenu\",{_arrayAttrRegexps:[/^updatemenus\\[(0|[1-9][0-9]+)\\]\\.buttons/],visible:{valType:\"boolean\"},type:{valType:\"enumerated\",values:[\"dropdown\",\"buttons\"],dflt:\"dropdown\"},direction:{valType:\"enumerated\",values:[\"left\",\"right\",\"up\",\"down\"],dflt:\"down\"},active:{valType:\"integer\",min:-1,dflt:0},showactive:{valType:\"boolean\",dflt:!0},buttons:c,x:{valType:\"number\",min:-2,max:3,dflt:-.05},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"right\"},y:{valType:\"number\",min:-2,max:3,dflt:1},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},pad:a(s({editType:\"arraydraw\"}),{}),font:n({}),bgcolor:{valType:\"color\"},bordercolor:{valType:\"color\",dflt:i.borderLine},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"arraydraw\"}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/font_attributes\":793,\"../../plots/pad_attributes\":827,\"../color/attributes\":592}],683:[function(t,e,r){\"use strict\";e.exports={name:\"updatemenus\",containerClassName:\"updatemenu-container\",headerGroupClassName:\"updatemenu-header-group\",headerClassName:\"updatemenu-header\",headerArrowClassName:\"updatemenu-header-arrow\",dropdownButtonGroupClassName:\"updatemenu-dropdown-button-group\",dropdownButtonClassName:\"updatemenu-dropdown-button\",buttonClassName:\"updatemenu-button\",itemRectClassName:\"updatemenu-item-rect\",itemTextClassName:\"updatemenu-item-text\",menuIndexAttrName:\"updatemenu-active-index\",autoMarginIdRoot:\"updatemenu-\",blankHeaderOpts:{label:\"  \"},minWidth:30,minHeight:30,textPadX:24,arrowPadX:16,rx:2,ry:2,textOffsetX:12,textOffsetY:3,arrowOffsetX:4,gapButtonHeader:5,gapButton:2,activeColor:\"#F4FAFF\",hoverColor:\"#F4FAFF\",arrowSymbol:{left:\"\\u25c4\",right:\"\\u25ba\",up:\"\\u25b2\",down:\"\\u25bc\"}}},{}],684:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.buttons;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}o(\"visible\",i(t,e,{name:\"buttons\",handleItemDefaults:c}).length>0)&&(o(\"active\"),o(\"direction\"),o(\"type\"),o(\"showactive\"),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"bgcolor\",r.paper_bgcolor),o(\"bordercolor\"),o(\"borderwidth\"))}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}r(\"visible\",\"skip\"===t.method||Array.isArray(t.args))&&(r(\"method\"),r(\"args\"),r(\"label\"),r(\"execute\"))}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"./attributes\":682,\"./constants\":683}],685:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"../../constants/alignment\").LINE_SPACING,h=t(\"./constants\"),f=t(\"./scrollbox\");function p(t){return t._index}function d(t,e){return+t.attr(h.menuIndexAttrName)===e._index}function g(t,e,r,n,i,a,o,s){e.active=o,c(t.layout,h.name,e).applyUpdate(\"active\",o),\"buttons\"===e.type?m(t,n,null,null,e):\"dropdown\"===e.type&&(i.attr(h.menuIndexAttrName,\"-1\"),v(t,n,i,a,e),s||m(t,n,i,a,e))}function v(t,e,r,n,i){var a=s.ensureSingle(e,\"g\",h.headerClassName,function(t){t.style(\"pointer-events\",\"all\")}),l=i._dims,c=i.active,u=i.buttons[c]||h.blankHeaderOpts,f={y:i.pad.t,yPad:0,x:i.pad.l,xPad:0,index:0},p={width:l.headerWidth,height:l.headerHeight};a.call(y,i,u,t).call(M,i,f,p),s.ensureSingle(e,\"text\",h.headerArrowClassName,function(t){t.classed(\"user-select-none\",!0).attr(\"text-anchor\",\"end\").call(o.font,i.font).text(h.arrowSymbol[i.direction])}).attr({x:l.headerWidth-h.arrowOffsetX+i.pad.l,y:l.headerHeight/2+h.textOffsetY+i.pad.t}),a.on(\"click\",function(){r.call(S,String(d(r,i)?-1:i._index)),m(t,e,r,n,i)}),a.on(\"mouseover\",function(){a.call(w)}),a.on(\"mouseout\",function(){a.call(k,i)}),o.setTranslate(e,l.lx,l.ly)}function m(t,e,r,a,o){r||(r=e).attr(\"pointer-events\",\"all\");var l=function(t){return-1==+t.attr(h.menuIndexAttrName)}(r)&&\"buttons\"!==o.type?[]:o.buttons,c=\"dropdown\"===o.type?h.dropdownButtonClassName:h.buttonClassName,u=r.selectAll(\"g.\"+c).data(s.filterVisible(l)),f=u.enter().append(\"g\").classed(c,!0),p=u.exit();\"dropdown\"===o.type?(f.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\"),p.transition().attr(\"opacity\",\"0\").remove()):p.remove();var d=0,v=0,m=o._dims,x=-1!==[\"up\",\"down\"].indexOf(o.direction);\"dropdown\"===o.type&&(x?v=m.headerHeight+h.gapButtonHeader:d=m.headerWidth+h.gapButtonHeader),\"dropdown\"===o.type&&\"up\"===o.direction&&(v=-h.gapButtonHeader+h.gapButton-m.openHeight),\"dropdown\"===o.type&&\"left\"===o.direction&&(d=-h.gapButtonHeader+h.gapButton-m.openWidth);var b={x:m.lx+d+o.pad.l,y:m.ly+v+o.pad.t,yPad:h.gapButton,xPad:h.gapButton,index:0},T={l:b.x+o.borderwidth,t:b.y+o.borderwidth};u.each(function(s,l){var c=n.select(this);c.call(y,o,s,t).call(M,o,b),c.on(\"click\",function(){n.event.defaultPrevented||(g(t,o,0,e,r,a,l),s.execute&&i.executeAPICommand(t,s.method,s.args),t.emit(\"plotly_buttonclicked\",{menu:o,button:s,active:o.active}))}),c.on(\"mouseover\",function(){c.call(w)}),c.on(\"mouseout\",function(){c.call(k,o),u.call(_,o)})}),u.call(_,o),x?(T.w=Math.max(m.openWidth,m.headerWidth),T.h=b.y-T.t):(T.w=b.x-T.l,T.h=Math.max(m.openHeight,m.headerHeight)),T.direction=o.direction,a&&(u.size()?function(t,e,r,n,i,a){var o,s,l,c=i.direction,u=\"up\"===c||\"down\"===c,f=i._dims,p=i.active;if(u)for(s=0,l=0;l<p;l++)s+=f.heights[l]+h.gapButton;else for(o=0,l=0;l<p;l++)o+=f.widths[l]+h.gapButton;n.enable(a,o,s),n.hbar&&n.hbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\");n.vbar&&n.vbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\")}(0,0,0,a,o,T):function(t){var e=!!t.hbar,r=!!t.vbar;e&&t.hbar.transition().attr(\"opacity\",\"0\").each(\"end\",function(){e=!1,r||t.disable()});r&&t.vbar.transition().attr(\"opacity\",\"0\").each(\"end\",function(){r=!1,e||t.disable()})}(a))}function y(t,e,r,n){t.call(x,e).call(b,e,r,n)}function x(t,e){s.ensureSingle(t,\"rect\",h.itemRectClassName,function(t){t.attr({rx:h.rx,ry:h.ry,\"shape-rendering\":\"crispEdges\"})}).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\")}function b(t,e,r,n){var i=s.ensureSingle(t,\"text\",h.itemTextClassName,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":\"start\",\"data-notex\":1})}),a=r.label,c=n._fullLayout._meta;c&&(a=s.templateString(a,c)),i.call(o.font,e.font).text(a).call(l.convertToTspans,n)}function _(t,e){var r=e.active;t.each(function(t,i){var o=n.select(this);i===r&&e.showactive&&o.select(\"rect.\"+h.itemRectClassName).call(a.fill,h.activeColor)})}function w(t){t.select(\"rect.\"+h.itemRectClassName).call(a.fill,h.hoverColor)}function k(t,e){t.select(\"rect.\"+h.itemRectClassName).call(a.fill,e.bgcolor)}function T(t,e){var r=e._dims={width1:0,height1:0,heights:[],widths:[],totalWidth:0,totalHeight:0,openWidth:0,openHeight:0,lx:0,ly:0},a=o.tester.selectAll(\"g.\"+h.dropdownButtonClassName).data(s.filterVisible(e.buttons));a.enter().append(\"g\").classed(h.dropdownButtonClassName,!0);var c=-1!==[\"up\",\"down\"].indexOf(e.direction);a.each(function(i,a){var s=n.select(this);s.call(y,e,i,t);var f=s.select(\".\"+h.itemTextClassName),p=f.node()&&o.bBox(f.node()).width,d=Math.max(p+h.textPadX,h.minWidth),g=e.font.size*u,v=l.lineCount(f),m=Math.max(g*v,h.minHeight)+h.textOffsetY;m=Math.ceil(m),d=Math.ceil(d),r.widths[a]=d,r.heights[a]=m,r.height1=Math.max(r.height1,m),r.width1=Math.max(r.width1,d),c?(r.totalWidth=Math.max(r.totalWidth,d),r.openWidth=r.totalWidth,r.totalHeight+=m+h.gapButton,r.openHeight+=m+h.gapButton):(r.totalWidth+=d+h.gapButton,r.openWidth+=d+h.gapButton,r.totalHeight=Math.max(r.totalHeight,m),r.openHeight=r.totalHeight)}),c?r.totalHeight-=h.gapButton:r.totalWidth-=h.gapButton,r.headerWidth=r.width1+h.arrowPadX,r.headerHeight=r.height1,\"dropdown\"===e.type&&(c?(r.width1+=h.arrowPadX,r.totalHeight=r.height1):r.totalWidth=r.width1,r.totalWidth+=h.arrowPadX),a.remove();var f=r.totalWidth+e.pad.l+e.pad.r,p=r.totalHeight+e.pad.t+e.pad.b,d=t._fullLayout._size;r.lx=d.l+d.w*e.x,r.ly=d.t+d.h*(1-e.y);var g=\"left\";s.isRightAnchor(e)&&(r.lx-=f,g=\"right\"),s.isCenterAnchor(e)&&(r.lx-=f/2,g=\"center\");var v=\"top\";s.isBottomAnchor(e)&&(r.ly-=p,v=\"bottom\"),s.isMiddleAnchor(e)&&(r.ly-=p/2,v=\"middle\"),r.totalWidth=Math.ceil(r.totalWidth),r.totalHeight=Math.ceil(r.totalHeight),r.lx=Math.round(r.lx),r.ly=Math.round(r.ly),i.autoMargin(t,A(e),{x:e.x,y:e.y,l:f*({right:1,center:.5}[g]||0),r:f*({left:1,center:.5}[g]||0),b:p*({top:1,middle:.5}[v]||0),t:p*({bottom:1,middle:.5}[v]||0)})}function A(t){return h.autoMarginIdRoot+t._index}function M(t,e,r,n){n=n||{};var i=t.select(\".\"+h.itemRectClassName),a=t.select(\".\"+h.itemTextClassName),s=e.borderwidth,c=r.index,f=e._dims;o.setTranslate(t,s+r.x,s+r.y);var p=-1!==[\"up\",\"down\"].indexOf(e.direction),d=n.height||(p?f.heights[c]:f.height1);i.attr({x:0,y:0,width:n.width||(p?f.width1:f.widths[c]),height:d});var g=e.font.size*u,v=(l.lineCount(a)-1)*g/2;l.positionText(a,h.textOffsetX,d/2-v+h.textOffsetY),p?r.y+=f.heights[c]+r.yPad:r.x+=f.widths[c]+r.xPad,r.index++}function S(t,e){t.attr(h.menuIndexAttrName,e||\"-1\").selectAll(\"g.\"+h.dropdownButtonClassName).remove()}e.exports=function(t){var e=t._fullLayout,r=s.filterVisible(e[h.name]);function a(e){i.autoMargin(t,A(e))}var o=e._menulayer.selectAll(\"g.\"+h.containerClassName).data(r.length>0?[0]:[]);if(o.enter().append(\"g\").classed(h.containerClassName,!0).style(\"cursor\",\"pointer\"),o.exit().each(function(){n.select(this).selectAll(\"g.\"+h.headerGroupClassName).each(a)}).remove(),0!==r.length){var l=o.selectAll(\"g.\"+h.headerGroupClassName).data(r,p);l.enter().append(\"g\").classed(h.headerGroupClassName,!0);for(var c=s.ensureSingle(o,\"g\",h.dropdownButtonGroupClassName,function(t){t.style(\"pointer-events\",\"all\")}),u=0;u<r.length;u++){var y=r[u];T(t,y)}var x=\"updatemenus\"+e._uid,b=new f(t,c,x);l.enter().size()&&(c.node().parentNode.appendChild(c.node()),c.call(S)),l.exit().each(function(t){c.call(S),a(t)}).remove(),l.each(function(e){var r=n.select(this),a=\"dropdown\"===e.type?c:null;i.manageCommandObserver(t,e,e.buttons,function(n){g(t,e,e.buttons[n.index],r,a,b,n.index,!0)}),\"dropdown\"===e.type?(v(t,r,c,b,e),d(c,e)&&m(t,r,c,b,e)):m(t,r,null,null,e)})}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_template\":757,\"../../plots/plots\":828,\"../color\":593,\"../drawing\":614,\"./constants\":683,\"./scrollbox\":687,d3:163}],686:[function(t,e,r){arguments[4][680][0].apply(r,arguments)},{\"./attributes\":682,\"./constants\":683,\"./defaults\":684,\"./draw\":685,dup:680}],687:[function(t,e,r){\"use strict\";e.exports=s;var n=t(\"d3\"),i=t(\"../color\"),a=t(\"../drawing\"),o=t(\"../../lib\");function s(t,e,r){this.gd=t,this.container=e,this.id=r,this.position=null,this.translateX=null,this.translateY=null,this.hbar=null,this.vbar=null,this.bg=this.container.selectAll(\"rect.scrollbox-bg\").data([0]),this.bg.exit().on(\".drag\",null).on(\"wheel\",null).remove(),this.bg.enter().append(\"rect\").classed(\"scrollbox-bg\",!0).style(\"pointer-events\",\"all\").attr({opacity:0,x:0,y:0,width:0,height:0})}s.barWidth=2,s.barLength=20,s.barRadius=2,s.barPad=1,s.barColor=\"#808BA4\",s.prototype.enable=function(t,e,r){var o=this.gd._fullLayout,l=o.width,c=o.height;this.position=t;var u,h,f,p,d=this.position.l,g=this.position.w,v=this.position.t,m=this.position.h,y=this.position.direction,x=\"down\"===y,b=\"left\"===y,_=\"up\"===y,w=g,k=m;x||b||\"right\"===y||_||(this.position.direction=\"down\",x=!0),x||_?(h=(u=d)+w,x?(f=v,k=(p=Math.min(f+k,c))-f):k=(p=v+k)-(f=Math.max(p-k,0))):(p=(f=v)+k,b?w=(h=d+w)-(u=Math.max(h-w,0)):(u=d,w=(h=Math.min(u+w,l))-u)),this._box={l:u,t:f,w:w,h:k};var T=g>w,A=s.barLength+2*s.barPad,M=s.barWidth+2*s.barPad,S=d,E=v+m;E+M>c&&(E=c-M);var C=this.container.selectAll(\"rect.scrollbar-horizontal\").data(T?[0]:[]);C.exit().on(\".drag\",null).remove(),C.enter().append(\"rect\").classed(\"scrollbar-horizontal\",!0).call(i.fill,s.barColor),T?(this.hbar=C.attr({rx:s.barRadius,ry:s.barRadius,x:S,y:E,width:A,height:M}),this._hbarXMin=S+A/2,this._hbarTranslateMax=w-A):(delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax);var L=m>k,P=s.barWidth+2*s.barPad,O=s.barLength+2*s.barPad,z=d+g,I=v;z+P>l&&(z=l-P);var D=this.container.selectAll(\"rect.scrollbar-vertical\").data(L?[0]:[]);D.exit().on(\".drag\",null).remove(),D.enter().append(\"rect\").classed(\"scrollbar-vertical\",!0).call(i.fill,s.barColor),L?(this.vbar=D.attr({rx:s.barRadius,ry:s.barRadius,x:z,y:I,width:P,height:O}),this._vbarYMin=I+O/2,this._vbarTranslateMax=k-O):(delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax);var R=this.id,F=u-.5,B=L?h+P+.5:h+.5,N=f-.5,j=T?p+M+.5:p+.5,U=o._topdefs.selectAll(\"#\"+R).data(T||L?[0]:[]);if(U.exit().remove(),U.enter().append(\"clipPath\").attr(\"id\",R).append(\"rect\"),T||L?(this._clipRect=U.select(\"rect\").attr({x:Math.floor(F),y:Math.floor(N),width:Math.ceil(B)-Math.floor(F),height:Math.ceil(j)-Math.floor(N)}),this.container.call(a.setClipUrl,R,this.gd),this.bg.attr({x:d,y:v,width:g,height:m})):(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),T||L){var V=n.behavior.drag().on(\"dragstart\",function(){n.event.sourceEvent.preventDefault()}).on(\"drag\",this._onBoxDrag.bind(this));this.container.on(\"wheel\",null).on(\"wheel\",this._onBoxWheel.bind(this)).on(\".drag\",null).call(V);var q=n.behavior.drag().on(\"dragstart\",function(){n.event.sourceEvent.preventDefault(),n.event.sourceEvent.stopPropagation()}).on(\"drag\",this._onBarDrag.bind(this));T&&this.hbar.on(\".drag\",null).call(q),L&&this.vbar.on(\".drag\",null).call(q)}this.setTranslate(e,r)},s.prototype.disable=function(){(this.hbar||this.vbar)&&(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),this.hbar&&(this.hbar.on(\".drag\",null),this.hbar.remove(),delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax),this.vbar&&(this.vbar.on(\".drag\",null),this.vbar.remove(),delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax)},s.prototype._onBoxDrag=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t-=n.event.dx),this.vbar&&(e-=n.event.dy),this.setTranslate(t,e)},s.prototype._onBoxWheel=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t+=n.event.deltaY),this.vbar&&(e+=n.event.deltaY),this.setTranslate(t,e)},s.prototype._onBarDrag=function(){var t=this.translateX,e=this.translateY;if(this.hbar){var r=t+this._hbarXMin,i=r+this._hbarTranslateMax;t=(o.constrain(n.event.x,r,i)-r)/(i-r)*(this.position.w-this._box.w)}if(this.vbar){var a=e+this._vbarYMin,s=a+this._vbarTranslateMax;e=(o.constrain(n.event.y,a,s)-a)/(s-a)*(this.position.h-this._box.h)}this.setTranslate(t,e)},s.prototype.setTranslate=function(t,e){var r=this.position.w-this._box.w,n=this.position.h-this._box.h;if(t=o.constrain(t||0,0,r),e=o.constrain(e||0,0,n),this.translateX=t,this.translateY=e,this.container.call(a.setTranslate,this._box.l-this.position.l-t,this._box.t-this.position.t-e),this._clipRect&&this._clipRect.attr({x:Math.floor(this.position.l+t-.5),y:Math.floor(this.position.t+e-.5)}),this.hbar){var i=t/r;this.hbar.call(a.setTranslate,t+i*this._hbarTranslateMax,e)}if(this.vbar){var s=e/n;this.vbar.call(a.setTranslate,t,e+s*this._vbarTranslateMax)}}},{\"../../lib\":719,\"../color\":593,\"../drawing\":614,d3:163}],688:[function(t,e,r){\"use strict\";e.exports={FROM_BL:{left:0,center:.5,right:1,bottom:0,middle:.5,top:1},FROM_TL:{left:0,center:.5,right:1,bottom:1,middle:.5,top:0},FROM_BR:{left:1,center:.5,right:0,bottom:0,middle:.5,top:1},LINE_SPACING:1.3,CAP_SHIFT:.7,MID_SHIFT:.35,OPPOSITE_SIDE:{left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}}},{}],689:[function(t,e,r){\"use strict\";e.exports={INCREASING:{COLOR:\"#3D9970\",SYMBOL:\"\\u25b2\"},DECREASING:{COLOR:\"#FF4136\",SYMBOL:\"\\u25bc\"}}},{}],690:[function(t,e,r){\"use strict\";e.exports={FORMAT_LINK:\"https://github.com/d3/d3-3.x-api-reference/blob/master/Formatting.md#d3_format\",DATE_FORMAT_LINK:\"https://github.com/d3/d3-3.x-api-reference/blob/master/Time-Formatting.md#format\"}},{}],691:[function(t,e,r){\"use strict\";e.exports={COMPARISON_OPS:[\"=\",\"!=\",\"<\",\">=\",\">\",\"<=\"],COMPARISON_OPS2:[\"=\",\"<\",\">=\",\">\",\"<=\"],INTERVAL_OPS:[\"[]\",\"()\",\"[)\",\"(]\",\"][\",\")(\",\"](\",\")[\"],SET_OPS:[\"{}\",\"}{\"],CONSTRAINT_REDUCTION:{\"=\":\"=\",\"<\":\"<\",\"<=\":\"<\",\">\":\">\",\">=\":\">\",\"[]\":\"[]\",\"()\":\"[]\",\"[)\":\"[]\",\"(]\":\"[]\",\"][\":\"][\",\")(\":\"][\",\"](\":\"][\",\")[\":\"][\"}}},{}],692:[function(t,e,r){\"use strict\";e.exports={solid:[[],0],dot:[[.5,1],200],dash:[[.5,1],50],longdash:[[.5,1],10],dashdot:[[.5,.625,.875,1],50],longdashdot:[[.5,.7,.8,1],10]}},{}],693:[function(t,e,r){\"use strict\";e.exports={circle:\"\\u25cf\",\"circle-open\":\"\\u25cb\",square:\"\\u25a0\",\"square-open\":\"\\u25a1\",diamond:\"\\u25c6\",\"diamond-open\":\"\\u25c7\",cross:\"+\",x:\"\\u274c\"}},{}],694:[function(t,e,r){\"use strict\";e.exports={SHOW_PLACEHOLDER:100,HIDE_PLACEHOLDER:1e3,DESELECTDIM:.2}},{}],695:[function(t,e,r){\"use strict\";e.exports={BADNUM:void 0,FP_SAFE:Number.MAX_VALUE/1e4,ONEAVGYEAR:315576e5,ONEAVGMONTH:26298e5,ONEDAY:864e5,ONEHOUR:36e5,ONEMIN:6e4,ONESEC:1e3,EPOCHJD:2440587.5,ALMOST_EQUAL:1-1e-6,LOG_CLIP:10,MINUS_SIGN:\"\\u2212\"}},{}],696:[function(t,e,r){\"use strict\";r.xmlns=\"http://www.w3.org/2000/xmlns/\",r.svg=\"http://www.w3.org/2000/svg\",r.xlink=\"http://www.w3.org/1999/xlink\",r.svgAttrs={xmlns:r.svg,\"xmlns:xlink\":r.xlink}},{}],697:[function(t,e,r){\"use strict\";r.version=\"1.49.1\",t(\"es6-promise\").polyfill(),t(\"../build/plotcss\"),t(\"./fonts/mathjax_config\")();for(var n=t(\"./registry\"),i=r.register=n.register,a=t(\"./plot_api\"),o=Object.keys(a),s=0;s<o.length;s++){var l=o[s];\"_\"!==l.charAt(0)&&(r[l]=a[l]),i({moduleType:\"apiMethod\",name:l,fn:a[l]})}i(t(\"./traces/scatter\")),i([t(\"./components/fx\"),t(\"./components/legend\"),t(\"./components/annotations\"),t(\"./components/annotations3d\"),t(\"./components/shapes\"),t(\"./components/images\"),t(\"./components/updatemenus\"),t(\"./components/sliders\"),t(\"./components/rangeslider\"),t(\"./components/rangeselector\"),t(\"./components/grid\"),t(\"./components/errorbars\"),t(\"./components/colorscale\"),t(\"./components/colorbar\")]),i([t(\"./locale-en\"),t(\"./locale-en-us\")]),r.Icons=t(\"./fonts/ploticon\"),r.Plots=t(\"./plots/plots\"),r.Fx=t(\"./components/fx\"),r.Snapshot=t(\"./snapshot\"),r.PlotSchema=t(\"./plot_api/plot_schema\"),r.Queue=t(\"./lib/queue\"),r.d3=t(\"d3\")},{\"../build/plotcss\":1,\"./components/annotations\":584,\"./components/annotations3d\":589,\"./components/colorbar\":599,\"./components/colorscale\":605,\"./components/errorbars\":620,\"./components/fx\":632,\"./components/grid\":636,\"./components/images\":641,\"./components/legend\":649,\"./components/rangeselector\":660,\"./components/rangeslider\":667,\"./components/shapes\":675,\"./components/sliders\":680,\"./components/updatemenus\":686,\"./fonts/mathjax_config\":698,\"./fonts/ploticon\":699,\"./lib/queue\":734,\"./locale-en\":748,\"./locale-en-us\":747,\"./plot_api\":752,\"./plot_api/plot_schema\":756,\"./plots/plots\":828,\"./registry\":847,\"./snapshot\":852,\"./traces/scatter\":1123,d3:163,\"es6-promise\":218}],698:[function(t,e,r){\"use strict\";e.exports=function(){\"undefined\"!=typeof MathJax&&(\"local\"!==(window.PlotlyConfig||{}).MathJaxConfig&&(MathJax.Hub.Config({messageStyle:\"none\",skipStartupTypeset:!0,displayAlign:\"left\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]}}),MathJax.Hub.Configured()))}},{}],699:[function(t,e,r){\"use strict\";e.exports={undo:{width:857.1,height:1e3,path:\"m857 350q0-87-34-166t-91-137-137-92-166-34q-96 0-183 41t-147 114q-4 6-4 13t5 11l76 77q6 5 14 5 9-1 13-7 41-53 100-82t126-29q58 0 110 23t92 61 61 91 22 111-22 111-61 91-92 61-110 23q-55 0-105-20t-90-57l77-77q17-16 8-38-10-23-33-23h-250q-15 0-25 11t-11 25v250q0 24 22 33 22 10 39-8l72-72q60 57 137 88t159 31q87 0 166-34t137-92 91-137 34-166z\",transform:\"matrix(1 0 0 -1 0 850)\"},home:{width:928.6,height:1e3,path:\"m786 296v-267q0-15-11-26t-25-10h-214v214h-143v-214h-214q-15 0-25 10t-11 26v267q0 1 0 2t0 2l321 264 321-264q1-1 1-4z m124 39l-34-41q-5-5-12-6h-2q-7 0-12 3l-386 322-386-322q-7-4-13-4-7 2-12 7l-35 41q-4 5-3 13t6 12l401 334q18 15 42 15t43-15l136-114v109q0 8 5 13t13 5h107q8 0 13-5t5-13v-227l122-102q5-5 6-12t-4-13z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"camera-retro\":{width:1e3,height:1e3,path:\"m518 386q0 8-5 13t-13 5q-37 0-63-27t-26-63q0-8 5-13t13-5 12 5 5 13q0 23 16 38t38 16q8 0 13 5t5 13z m125-73q0-59-42-101t-101-42-101 42-42 101 42 101 101 42 101-42 42-101z m-572-320h858v71h-858v-71z m643 320q0 89-62 152t-152 62-151-62-63-152 63-151 151-63 152 63 62 151z m-571 358h214v72h-214v-72z m-72-107h858v143h-462l-36-71h-360v-72z m929 143v-714q0-30-21-51t-50-21h-858q-29 0-50 21t-21 51v714q0 30 21 51t50 21h858q29 0 50-21t21-51z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoombox:{width:1e3,height:1e3,path:\"m1000-25l-250 251c40 63 63 138 63 218 0 224-182 406-407 406-224 0-406-182-406-406s183-406 407-406c80 0 155 22 218 62l250-250 125 125z m-812 250l0 438 437 0 0-438-437 0z m62 375l313 0 0-312-313 0 0 312z\",transform:\"matrix(1 0 0 -1 0 850)\"},pan:{width:1e3,height:1e3,path:\"m1000 350l-187 188 0-125-250 0 0 250 125 0-188 187-187-187 125 0 0-250-250 0 0 125-188-188 186-187 0 125 252 0 0-250-125 0 187-188 188 188-125 0 0 250 250 0 0-126 187 188z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_plus:{width:875,height:1e3,path:\"m1 787l0-875 875 0 0 875-875 0z m687-500l-187 0 0-187-125 0 0 187-188 0 0 125 188 0 0 187 125 0 0-187 187 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_minus:{width:875,height:1e3,path:\"m0 788l0-876 875 0 0 876-875 0z m688-500l-500 0 0 125 500 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},autoscale:{width:1e3,height:1e3,path:\"m250 850l-187 0-63 0 0-62 0-188 63 0 0 188 187 0 0 62z m688 0l-188 0 0-62 188 0 0-188 62 0 0 188 0 62-62 0z m-875-938l0 188-63 0 0-188 0-62 63 0 187 0 0 62-187 0z m875 188l0-188-188 0 0-62 188 0 62 0 0 62 0 188-62 0z m-125 188l-1 0-93-94-156 156 156 156 92-93 2 0 0 250-250 0 0-2 93-92-156-156-156 156 94 92 0 2-250 0 0-250 0 0 93 93 157-156-157-156-93 94 0 0 0-250 250 0 0 0-94 93 156 157 156-157-93-93 0 0 250 0 0 250z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_basic:{width:1500,height:1e3,path:\"m375 725l0 0-375-375 375-374 0-1 1125 0 0 750-1125 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_compare:{width:1125,height:1e3,path:\"m187 786l0 2-187-188 188-187 0 0 937 0 0 373-938 0z m0-499l0 1-187-188 188-188 0 0 937 0 0 376-938-1z\",transform:\"matrix(1 0 0 -1 0 850)\"},plotlylogo:{width:1542,height:1e3,path:\"m0-10h182v-140h-182v140z m228 146h183v-286h-183v286z m225 714h182v-1000h-182v1000z m225-285h182v-715h-182v715z m225 142h183v-857h-183v857z m231-428h182v-429h-182v429z m225-291h183v-138h-183v138z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"z-axis\":{width:1e3,height:1e3,path:\"m833 5l-17 108v41l-130-65 130-66c0 0 0 38 0 39 0-1 36-14 39-25 4-15-6-22-16-30-15-12-39-16-56-20-90-22-187-23-279-23-261 0-341 34-353 59 3 60 228 110 228 110-140-8-351-35-351-116 0-120 293-142 474-142 155 0 477 22 477 142 0 50-74 79-163 96z m-374 94c-58-5-99-21-99-40 0-24 65-43 144-43 79 0 143 19 143 43 0 19-42 34-98 40v216h87l-132 135-133-135h88v-216z m167 515h-136v1c16 16 31 34 46 52l84 109v54h-230v-71h124v-1c-16-17-28-32-44-51l-89-114v-51h245v72z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"3d_rotate\":{width:1e3,height:1e3,path:\"m922 660c-5 4-9 7-14 11-359 263-580-31-580-31l-102 28 58-400c0 1 1 1 2 2 118 108 351 249 351 249s-62 27-100 42c88 83 222 183 347 122 16-8 30-17 44-27-2 1-4 2-6 4z m36-329c0 0 64 229-88 296-62 27-124 14-175-11 157-78 225-208 249-266 8-19 11-31 11-31 2 5 6 15 11 32-5-13-8-20-8-20z m-775-239c70-31 117-50 198-32-121 80-199 346-199 346l-96-15-58-12c0 0 55-226 155-287z m603 133l-317-139c0 0 4-4 19-14 7-5 24-15 24-15s-177-147-389 4c235-287 536-112 536-112l31-22 100 299-4-1z m-298-153c6-4 14-9 24-15 0 0-17 10-24 15z\",transform:\"matrix(1 0 0 -1 0 850)\"},camera:{width:1e3,height:1e3,path:\"m500 450c-83 0-150-67-150-150 0-83 67-150 150-150 83 0 150 67 150 150 0 83-67 150-150 150z m400 150h-120c-16 0-34 13-39 29l-31 93c-6 15-23 28-40 28h-340c-16 0-34-13-39-28l-31-94c-6-15-23-28-40-28h-120c-55 0-100-45-100-100v-450c0-55 45-100 100-100h800c55 0 100 45 100 100v450c0 55-45 100-100 100z m-400-550c-138 0-250 112-250 250 0 138 112 250 250 250 138 0 250-112 250-250 0-138-112-250-250-250z m365 380c-19 0-35 16-35 35 0 19 16 35 35 35 19 0 35-16 35-35 0-19-16-35-35-35z\",transform:\"matrix(1 0 0 -1 0 850)\"},movie:{width:1e3,height:1e3,path:\"m938 413l-188-125c0 37-17 71-44 94 64 38 107 107 107 187 0 121-98 219-219 219-121 0-219-98-219-219 0-61 25-117 66-156h-115c30 33 49 76 49 125 0 103-84 187-187 187s-188-84-188-187c0-57 26-107 65-141-38-22-65-62-65-109v-250c0-70 56-126 125-126h500c69 0 125 56 125 126l188-126c34 0 62 28 62 63v375c0 35-28 63-62 63z m-750 0c-69 0-125 56-125 125s56 125 125 125 125-56 125-125-56-125-125-125z m406-1c-87 0-157 70-157 157 0 86 70 156 157 156s156-70 156-156-70-157-156-157z\",transform:\"matrix(1 0 0 -1 0 850)\"},question:{width:857.1,height:1e3,path:\"m500 82v107q0 8-5 13t-13 5h-107q-8 0-13-5t-5-13v-107q0-8 5-13t13-5h107q8 0 13 5t5 13z m143 375q0 49-31 91t-77 65-95 23q-136 0-207-119-9-14 4-24l74-55q4-4 10-4 9 0 14 7 30 38 48 51 19 14 48 14 27 0 48-15t21-33q0-21-11-34t-38-25q-35-16-65-48t-29-70v-20q0-8 5-13t13-5h107q8 0 13 5t5 13q0 10 12 27t30 28q18 10 28 16t25 19 25 27 16 34 7 45z m214-107q0-117-57-215t-156-156-215-58-216 58-155 156-58 215 58 215 155 156 216 58 215-58 156-156 57-215z\",transform:\"matrix(1 0 0 -1 0 850)\"},disk:{width:857.1,height:1e3,path:\"m214-7h429v214h-429v-214z m500 0h72v500q0 8-6 21t-11 20l-157 156q-5 6-19 12t-22 5v-232q0-22-15-38t-38-16h-322q-22 0-37 16t-16 38v232h-72v-714h72v232q0 22 16 38t37 16h465q22 0 38-16t15-38v-232z m-214 518v178q0 8-5 13t-13 5h-107q-7 0-13-5t-5-13v-178q0-8 5-13t13-5h107q7 0 13 5t5 13z m357-18v-518q0-22-15-38t-38-16h-750q-23 0-38 16t-16 38v750q0 22 16 38t38 16h517q23 0 50-12t42-26l156-157q16-15 27-42t11-49z\",transform:\"matrix(1 0 0 -1 0 850)\"},lasso:{width:1031,height:1e3,path:\"m1018 538c-36 207-290 336-568 286-277-48-473-256-436-463 10-57 36-108 76-151-13-66 11-137 68-183 34-28 75-41 114-42l-55-70 0 0c-2-1-3-2-4-3-10-14-8-34 5-45 14-11 34-8 45 4 1 1 2 3 2 5l0 0 113 140c16 11 31 24 45 40 4 3 6 7 8 11 48-3 100 0 151 9 278 48 473 255 436 462z m-624-379c-80 14-149 48-197 96 42 42 109 47 156 9 33-26 47-66 41-105z m-187-74c-19 16-33 37-39 60 50-32 109-55 174-68-42-25-95-24-135 8z m360 75c-34-7-69-9-102-8 8 62-16 128-68 170-73 59-175 54-244-5-9 20-16 40-20 61-28 159 121 317 333 354s407-60 434-217c28-159-121-318-333-355z\",transform:\"matrix(1 0 0 -1 0 850)\"},selectbox:{width:1e3,height:1e3,path:\"m0 850l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-285l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},spikeline:{width:1e3,height:1e3,path:\"M512 409c0-57-46-104-103-104-57 0-104 47-104 104 0 57 47 103 104 103 57 0 103-46 103-103z m-327-39l92 0 0 92-92 0z m-185 0l92 0 0 92-92 0z m370-186l92 0 0 93-92 0z m0-184l92 0 0 92-92 0z\",transform:\"matrix(1.5 0 0 -1.5 0 850)\"},pencil:{width:1792,height:1792,path:\"M491 1536l91-91-235-235-91 91v107h128v128h107zm523-928q0-22-22-22-10 0-17 7l-542 542q-7 7-7 17 0 22 22 22 10 0 17-7l542-542q7-7 7-17zm-54-192l416 416-832 832h-416v-416zm683 96q0 53-37 90l-166 166-416-416 166-165q36-38 90-38 53 0 91 38l235 234q37 39 37 91z\",transform:\"matrix(1 0 0 1 0 1)\"},newplotlylogo:{name:\"newplotlylogo\",svg:\"<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 132 132'><defs><style>.cls-1 {fill: #119dff;} .cls-2 {fill: #25fefd;} .cls-3 {fill: #fff;}</style></defs><title>plotly-logomark</title><g id='symbol'><rect class='cls-1' width='132' height='132' rx='6' ry='6'/><circle class='cls-2' cx='78' cy='54' r='6'/><circle class='cls-2' cx='102' cy='30' r='6'/><circle class='cls-2' cx='78' cy='30' r='6'/><circle class='cls-2' cx='54' cy='30' r='6'/><circle class='cls-2' cx='30' cy='30' r='6'/><circle class='cls-2' cx='30' cy='54' r='6'/><path class='cls-3' d='M30,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,30,72Z'/><path class='cls-3' d='M78,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,78,72Z'/><path class='cls-3' d='M54,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,54,48Z'/><path class='cls-3' d='M102,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,102,48Z'/></g></svg>\"}}},{}],700:[function(t,e,r){\"use strict\";r.isLeftAnchor=function(t){return\"left\"===t.xanchor||\"auto\"===t.xanchor&&t.x<=1/3},r.isCenterAnchor=function(t){return\"center\"===t.xanchor||\"auto\"===t.xanchor&&t.x>1/3&&t.x<2/3},r.isRightAnchor=function(t){return\"right\"===t.xanchor||\"auto\"===t.xanchor&&t.x>=2/3},r.isTopAnchor=function(t){return\"top\"===t.yanchor||\"auto\"===t.yanchor&&t.y>=2/3},r.isMiddleAnchor=function(t){return\"middle\"===t.yanchor||\"auto\"===t.yanchor&&t.y>1/3&&t.y<2/3},r.isBottomAnchor=function(t){return\"bottom\"===t.yanchor||\"auto\"===t.yanchor&&t.y<=1/3}},{}],701:[function(t,e,r){\"use strict\";var n=t(\"./mod\"),i=n.mod,a=n.modHalf,o=Math.PI,s=2*o;function l(t){return Math.abs(t[1]-t[0])>s-1e-14}function c(t,e){return a(e-t,s)}function u(t,e){if(l(e))return!0;var r,n;e[0]<e[1]?(r=e[0],n=e[1]):(r=e[1],n=e[0]),(r=i(r,s))>(n=i(n,s))&&(n+=s);var a=i(t,s),o=a+s;return a>=r&&a<=n||o>=r&&o<=n}function h(t,e,r,n,i,a,c){i=i||0,a=a||0;var u,h,f,p,d,g=l([r,n]);function v(t,e){return[t*Math.cos(e)+i,a-t*Math.sin(e)]}g?(u=0,h=o,f=s):r<n?(u=r,f=n):(u=n,f=r),t<e?(p=t,d=e):(p=e,d=t);var m,y=Math.abs(f-u)<=o?0:1;function x(t,e,r){return\"A\"+[t,t]+\" \"+[0,y,r]+\" \"+v(t,e)}return g?m=null===p?\"M\"+v(d,u)+x(d,h,0)+x(d,f,0)+\"Z\":\"M\"+v(p,u)+x(p,h,0)+x(p,f,0)+\"ZM\"+v(d,u)+x(d,h,1)+x(d,f,1)+\"Z\":null===p?(m=\"M\"+v(d,u)+x(d,f,0),c&&(m+=\"L0,0Z\")):m=\"M\"+v(p,u)+\"L\"+v(d,u)+x(d,f,0)+\"L\"+v(p,f)+x(p,u,1)+\"Z\",m}e.exports={deg2rad:function(t){return t/180*o},rad2deg:function(t){return t/o*180},angleDelta:c,angleDist:function(t,e){return Math.abs(c(t,e))},isFullCircle:l,isAngleInsideSector:u,isPtInsideSector:function(t,e,r,n){return!!u(e,n)&&(r[0]<r[1]?(i=r[0],a=r[1]):(i=r[1],a=r[0]),t>=i&&t<=a);var i,a},pathArc:function(t,e,r,n,i){return h(null,t,e,r,n,i,0)},pathSector:function(t,e,r,n,i){return h(null,t,e,r,n,i,1)},pathAnnulus:function(t,e,r,n,i,a){return h(t,e,r,n,i,a,1)}}},{\"./mod\":726}],702:[function(t,e,r){\"use strict\";var n=Array.isArray,i=\"undefined\"!=typeof ArrayBuffer&&ArrayBuffer.isView?ArrayBuffer:{isView:function(){return!1}},a=\"undefined\"==typeof DataView?function(){}:DataView;function o(t){return i.isView(t)&&!(t instanceof a)}function s(t){return n(t)||o(t)}function l(t,e,r){if(s(t)){if(s(t[0])){for(var n=r,i=0;i<t.length;i++)n=e(n,t[i].length);return n}return t.length}return 0}r.isTypedArray=o,r.isArrayOrTypedArray=s,r.isArray1D=function(t){return!s(t[0])},r.ensureArray=function(t,e){return n(t)||(t=[]),t.length=e,t},r.concat=function(){var t,e,r,i,a,o,s,l,c=[],u=!0,h=0;for(r=0;r<arguments.length;r++)(o=(i=arguments[r]).length)&&(e?c.push(i):(e=i,a=o),n(i)?t=!1:(u=!1,h?t!==i.constructor&&(t=!1):t=i.constructor),h+=o);if(!h)return[];if(!c.length)return e;if(u)return e.concat.apply(e,c);if(t){for((s=new t(h)).set(e),r=0;r<c.length;r++)i=c[r],s.set(i,a),a+=i.length;return s}for(s=new Array(h),l=0;l<e.length;l++)s[l]=e[l];for(r=0;r<c.length;r++){for(i=c[r],l=0;l<i.length;l++)s[a+l]=i[l];a+=l}return s},r.maxRowLength=function(t){return l(t,Math.max,0)},r.minRowLength=function(t){return l(t,Math.min,1/0)}},{}],703:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../constants/numerical\").BADNUM,a=/^['\"%,$#\\s']+|[, ]|['\"%,$#\\s']+$/g;e.exports=function(t){return\"string\"==typeof t&&(t=t.replace(a,\"\")),n(t)?Number(t):i}},{\"../constants/numerical\":695,\"fast-isnumeric\":225}],704:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t._fullLayout;e._glcanvas&&e._glcanvas.size()&&e._glcanvas.each(function(t){t.regl&&t.regl.clear({color:!0,depth:!0})})}},{}],705:[function(t,e,r){\"use strict\";e.exports=function(t){t._responsiveChartHandler&&(window.removeEventListener(\"resize\",t._responsiveChartHandler),delete t._responsiveChartHandler)}},{}],706:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../plots/attributes\"),o=t(\"../components/colorscale/scales\"),s=t(\"../constants/interactions\").DESELECTDIM,l=t(\"./nested_property\"),c=t(\"./regex\").counter,u=t(\"./mod\").modHalf,h=t(\"./array\").isArrayOrTypedArray;function f(t,e){var n=r.valObjectMeta[e.valType];if(e.arrayOk&&h(t))return!0;if(n.validateFunction)return n.validateFunction(t,e);var i={},a=i,o={set:function(t){a=t}};return n.coerceFunction(t,o,i,e),a!==i}r.valObjectMeta={data_array:{coerceFunction:function(t,e,r){h(t)?e.set(t):void 0!==r&&e.set(r)}},enumerated:{coerceFunction:function(t,e,r,n){n.coerceNumber&&(t=+t),-1===n.values.indexOf(t)?e.set(r):e.set(t)},validateFunction:function(t,e){e.coerceNumber&&(t=+t);for(var r=e.values,n=0;n<r.length;n++){var i=String(r[n]);if(\"/\"===i.charAt(0)&&\"/\"===i.charAt(i.length-1)){if(new RegExp(i.substr(1,i.length-2)).test(t))return!0}else if(t===r[n])return!0}return!1}},boolean:{coerceFunction:function(t,e,r){!0===t||!1===t?e.set(t):e.set(r)}},number:{coerceFunction:function(t,e,r,i){!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},integer:{coerceFunction:function(t,e,r,i){t%1||!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},string:{coerceFunction:function(t,e,r,n){if(\"string\"!=typeof t){var i=\"number\"==typeof t;!0!==n.strict&&i?e.set(String(t)):e.set(r)}else n.noBlank&&!t?e.set(r):e.set(t)}},color:{coerceFunction:function(t,e,r){i(t).isValid()?e.set(t):e.set(r)}},colorlist:{coerceFunction:function(t,e,r){Array.isArray(t)&&t.length&&t.every(function(t){return i(t).isValid()})?e.set(t):e.set(r)}},colorscale:{coerceFunction:function(t,e,r){e.set(o.get(t,r))}},angle:{coerceFunction:function(t,e,r){\"auto\"===t?e.set(\"auto\"):n(t)?e.set(u(+t,360)):e.set(r)}},subplotid:{coerceFunction:function(t,e,r,n){var i=n.regex||c(r);\"string\"==typeof t&&i.test(t)?e.set(t):e.set(r)},validateFunction:function(t,e){var r=e.dflt;return t===r||\"string\"==typeof t&&!!c(r).test(t)}},flaglist:{coerceFunction:function(t,e,r,n){if(\"string\"==typeof t)if(-1===(n.extras||[]).indexOf(t)){for(var i=t.split(\"+\"),a=0;a<i.length;){var o=i[a];-1===n.flags.indexOf(o)||i.indexOf(o)<a?i.splice(a,1):a++}i.length?e.set(i.join(\"+\")):e.set(r)}else e.set(t);else e.set(r)}},any:{coerceFunction:function(t,e,r){void 0===t?e.set(r):e.set(t)}},info_array:{coerceFunction:function(t,e,n,i){function a(t,e,n){var i,a={set:function(t){i=t}};return void 0===n&&(n=e.dflt),r.valObjectMeta[e.valType].coerceFunction(t,a,n,e),i}var o=2===i.dimensions||\"1-2\"===i.dimensions&&Array.isArray(t)&&Array.isArray(t[0]);if(Array.isArray(t)){var s,l,c,u,h,f,p=i.items,d=[],g=Array.isArray(p),v=g&&o&&Array.isArray(p[0]),m=o&&g&&!v,y=g&&!m?p.length:t.length;if(n=Array.isArray(n)?n:[],o)for(s=0;s<y;s++)for(d[s]=[],c=Array.isArray(t[s])?t[s]:[],h=m?p.length:g?p[s].length:c.length,l=0;l<h;l++)u=m?p[l]:g?p[s][l]:p,void 0!==(f=a(c[l],u,(n[s]||[])[l]))&&(d[s][l]=f);else for(s=0;s<y;s++)void 0!==(f=a(t[s],g?p[s]:p,n[s]))&&(d[s]=f);e.set(d)}else e.set(n)},validateFunction:function(t,e){if(!Array.isArray(t))return!1;var r=e.items,n=Array.isArray(r),i=2===e.dimensions;if(!e.freeLength&&t.length!==r.length)return!1;for(var a=0;a<t.length;a++)if(i){if(!Array.isArray(t[a])||!e.freeLength&&t[a].length!==r[a].length)return!1;for(var o=0;o<t[a].length;o++)if(!f(t[a][o],n?r[a][o]:r))return!1}else if(!f(t[a],n?r[a]:r))return!1;return!0}}},r.coerce=function(t,e,n,i,a){var o=l(n,i).get(),s=l(t,i),c=l(e,i),u=s.get(),p=e._template;if(void 0===u&&p&&(u=l(p,i).get(),p=0),void 0===a&&(a=o.dflt),o.arrayOk&&h(u))return c.set(u),u;var d=r.valObjectMeta[o.valType].coerceFunction;d(u,c,a,o);var g=c.get();return p&&g===a&&!f(u,o)&&(d(u=l(p,i).get(),c,a,o),g=c.get()),g},r.coerce2=function(t,e,n,i,a){var o=l(t,i),s=r.coerce(t,e,n,i,a),c=o.get();return null!=c&&s},r.coerceFont=function(t,e,r){var n={};return r=r||{},n.family=t(e+\".family\",r.family),n.size=t(e+\".size\",r.size),n.color=t(e+\".color\",r.color),n},r.coerceHoverinfo=function(t,e,n){var i,o=e._module.attributes,s=o.hoverinfo?o:a,l=s.hoverinfo;if(1===n._dataLength){var c=\"all\"===l.dflt?l.flags.slice():l.dflt.split(\"+\");c.splice(c.indexOf(\"name\"),1),i=c.join(\"+\")}return r.coerce(t,e,s,\"hoverinfo\",i)},r.coerceSelectionMarkerOpacity=function(t,e){if(t.marker){var r,n,i=t.marker.opacity;if(void 0!==i)h(i)||t.selected||t.unselected||(r=i,n=s*i),e(\"selected.marker.opacity\",r),e(\"unselected.marker.opacity\",n)}},r.validate=f},{\"../components/colorscale/scales\":608,\"../constants/interactions\":694,\"../plots/attributes\":764,\"./array\":702,\"./mod\":726,\"./nested_property\":727,\"./regex\":735,\"fast-isnumeric\":225,tinycolor2:537}],707:[function(t,e,r){\"use strict\";var n,i,a=t(\"d3\"),o=t(\"fast-isnumeric\"),s=t(\"./loggers\"),l=t(\"./mod\").mod,c=t(\"../constants/numerical\"),u=c.BADNUM,h=c.ONEDAY,f=c.ONEHOUR,p=c.ONEMIN,d=c.ONESEC,g=c.EPOCHJD,v=t(\"../registry\"),m=a.time.format.utc,y=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\d)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d:?\\d\\d)?)?)?)?)?\\s*$/m,x=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\di?)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d:?\\d\\d)?)?)?)?)?\\s*$/m,b=(new Date).getFullYear()-70;function _(t){return t&&v.componentsRegistry.calendars&&\"string\"==typeof t&&\"gregorian\"!==t}function w(t,e){return String(t+Math.pow(10,e)).substr(1)}r.dateTick0=function(t,e){return _(t)?e?v.getComponentMethod(\"calendars\",\"CANONICAL_SUNDAY\")[t]:v.getComponentMethod(\"calendars\",\"CANONICAL_TICK\")[t]:e?\"2000-01-02\":\"2000-01-01\"},r.dfltRange=function(t){return _(t)?v.getComponentMethod(\"calendars\",\"DFLTRANGE\")[t]:[\"2000-01-01\",\"2001-01-01\"]},r.isJSDate=function(t){return\"object\"==typeof t&&null!==t&&\"function\"==typeof t.getTime},r.dateTime2ms=function(t,e){if(r.isJSDate(t)){var a=t.getTimezoneOffset()*p,o=(t.getUTCMinutes()-t.getMinutes())*p+(t.getUTCSeconds()-t.getSeconds())*d+(t.getUTCMilliseconds()-t.getMilliseconds());if(o){var s=3*p;a=a-s/2+l(o-a+s/2,s)}return(t=Number(t)-a)>=n&&t<=i?t:u}if(\"string\"!=typeof t&&\"number\"!=typeof t)return u;t=String(t);var c=_(e),m=t.charAt(0);!c||\"G\"!==m&&\"g\"!==m||(t=t.substr(1),e=\"\");var w=c&&\"chinese\"===e.substr(0,7),k=t.match(w?x:y);if(!k)return u;var T=k[1],A=k[3]||\"1\",M=Number(k[5]||1),S=Number(k[7]||0),E=Number(k[9]||0),C=Number(k[11]||0);if(c){if(2===T.length)return u;var L;T=Number(T);try{var P=v.getComponentMethod(\"calendars\",\"getCal\")(e);if(w){var O=\"i\"===A.charAt(A.length-1);A=parseInt(A,10),L=P.newDate(T,P.toMonthIndex(T,A,O),M)}else L=P.newDate(T,Number(A),M)}catch(t){return u}return L?(L.toJD()-g)*h+S*f+E*p+C*d:u}T=2===T.length?(Number(T)+2e3-b)%100+b:Number(T),A-=1;var z=new Date(Date.UTC(2e3,A,M,S,E));return z.setUTCFullYear(T),z.getUTCMonth()!==A?u:z.getUTCDate()!==M?u:z.getTime()+C*d},n=r.MIN_MS=r.dateTime2ms(\"-9999\"),i=r.MAX_MS=r.dateTime2ms(\"9999-12-31 23:59:59.9999\"),r.isDateTime=function(t,e){return r.dateTime2ms(t,e)!==u};var k=90*h,T=3*f,A=5*p;function M(t,e,r,n,i){if((e||r||n||i)&&(t+=\" \"+w(e,2)+\":\"+w(r,2),(n||i)&&(t+=\":\"+w(n,2),i))){for(var a=4;i%10==0;)a-=1,i/=10;t+=\".\"+w(i,a)}return t}r.ms2DateTime=function(t,e,r){if(\"number\"!=typeof t||!(t>=n&&t<=i))return u;e||(e=0);var a,o,s,c,y,x,b=Math.floor(10*l(t+.05,1)),w=Math.round(t-b/10);if(_(r)){var S=Math.floor(w/h)+g,E=Math.floor(l(t,h));try{a=v.getComponentMethod(\"calendars\",\"getCal\")(r).fromJD(S).formatDate(\"yyyy-mm-dd\")}catch(t){a=m(\"G%Y-%m-%d\")(new Date(w))}if(\"-\"===a.charAt(0))for(;a.length<11;)a=\"-0\"+a.substr(1);else for(;a.length<10;)a=\"0\"+a;o=e<k?Math.floor(E/f):0,s=e<k?Math.floor(E%f/p):0,c=e<T?Math.floor(E%p/d):0,y=e<A?E%d*10+b:0}else x=new Date(w),a=m(\"%Y-%m-%d\")(x),o=e<k?x.getUTCHours():0,s=e<k?x.getUTCMinutes():0,c=e<T?x.getUTCSeconds():0,y=e<A?10*x.getUTCMilliseconds()+b:0;return M(a,o,s,c,y)},r.ms2DateTimeLocal=function(t){if(!(t>=n+h&&t<=i-h))return u;var e=Math.floor(10*l(t+.05,1)),r=new Date(Math.round(t-e/10));return M(a.time.format(\"%Y-%m-%d\")(r),r.getHours(),r.getMinutes(),r.getSeconds(),10*r.getUTCMilliseconds()+e)},r.cleanDate=function(t,e,n){if(t===u)return e;if(r.isJSDate(t)||\"number\"==typeof t&&isFinite(t)){if(_(n))return s.error(\"JS Dates and milliseconds are incompatible with world calendars\",t),e;if(!(t=r.ms2DateTimeLocal(+t))&&void 0!==e)return e}else if(!r.isDateTime(t,n))return s.error(\"unrecognized date\",t),e;return t};var S=/%\\d?f/g;function E(t,e,r,n){t=t.replace(S,function(t){var r=Math.min(+t.charAt(1)||6,6);return(e/1e3%1+2).toFixed(r).substr(2).replace(/0+$/,\"\")||\"0\"});var i=new Date(Math.floor(e+.05));if(_(n))try{t=v.getComponentMethod(\"calendars\",\"worldCalFmt\")(t,e,n)}catch(t){return\"Invalid\"}return r(t)(i)}var C=[59,59.9,59.99,59.999,59.9999];r.formatDate=function(t,e,r,n,i,a){if(i=_(i)&&i,!e)if(\"y\"===r)e=a.year;else if(\"m\"===r)e=a.month;else{if(\"d\"!==r)return function(t,e){var r=l(t+.05,h),n=w(Math.floor(r/f),2)+\":\"+w(l(Math.floor(r/p),60),2);if(\"M\"!==e){o(e)||(e=0);var i=(100+Math.min(l(t/d,60),C[e])).toFixed(e).substr(1);e>0&&(i=i.replace(/0+$/,\"\").replace(/[\\.]$/,\"\")),n+=\":\"+i}return n}(t,r)+\"\\n\"+E(a.dayMonthYear,t,n,i);e=a.dayMonth+\"\\n\"+a.year}return E(e,t,n,i)};var L=3*h;r.incrementMonth=function(t,e,r){r=_(r)&&r;var n=l(t,h);if(t=Math.round(t-n),r)try{var i=Math.round(t/h)+g,a=v.getComponentMethod(\"calendars\",\"getCal\")(r),o=a.fromJD(i);return e%12?a.add(o,e,\"m\"):a.add(o,e/12,\"y\"),(o.toJD()-g)*h+n}catch(e){s.error(\"invalid ms \"+t+\" in calendar \"+r)}var c=new Date(t+L);return c.setUTCMonth(c.getUTCMonth()+e)+n-L},r.findExactDates=function(t,e){for(var r,n,i=0,a=0,s=0,l=0,c=_(e)&&v.getComponentMethod(\"calendars\",\"getCal\")(e),u=0;u<t.length;u++)if(n=t[u],o(n)){if(!(n%h))if(c)try{1===(r=c.fromJD(n/h+g)).day()?1===r.month()?i++:a++:s++}catch(t){}else 1===(r=new Date(n)).getUTCDate()?0===r.getUTCMonth()?i++:a++:s++}else l++;s+=a+=i;var f=t.length-l;return{exactYears:i/f,exactMonths:a/f,exactDays:s/f}}},{\"../constants/numerical\":695,\"../registry\":847,\"./loggers\":723,\"./mod\":726,d3:163,\"fast-isnumeric\":225}],708:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./loggers\");function a(t){var e=t&&t.parentNode;e&&e.removeChild(t)}function o(t,e,r){var n=\"plotly.js-style-\"+t,a=document.getElementById(n);a||((a=document.createElement(\"style\")).setAttribute(\"id\",n),a.appendChild(document.createTextNode(\"\")),document.head.appendChild(a));var o=a.sheet;o.insertRule?o.insertRule(e+\"{\"+r+\"}\",0):o.addRule?o.addRule(e,r,0):i.warn(\"addStyleRule failed\")}e.exports={getGraphDiv:function(t){var e;if(\"string\"==typeof t){if(null===(e=document.getElementById(t)))throw new Error(\"No DOM element with id '\"+t+\"' exists on the page.\");return e}if(null==t)throw new Error(\"DOM element provided is null or undefined\");return t},isPlotDiv:function(t){var e=n.select(t);return e.node()instanceof HTMLElement&&e.size()&&e.classed(\"js-plotly-plot\")},removeElement:a,addStyleRule:function(t,e){o(\"global\",t,e)},addRelatedStyleRule:o,deleteRelatedStyleRule:function(t){var e=\"plotly.js-style-\"+t,r=document.getElementById(e);r&&a(r)}}},{\"./loggers\":723,d3:163}],709:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i={init:function(t){if(t._ev instanceof n)return t;var e=new n,r=new n;return t._ev=e,t._internalEv=r,t.on=e.on.bind(e),t.once=e.once.bind(e),t.removeListener=e.removeListener.bind(e),t.removeAllListeners=e.removeAllListeners.bind(e),t._internalOn=r.on.bind(r),t._internalOnce=r.once.bind(r),t._removeInternalListener=r.removeListener.bind(r),t._removeAllInternalListeners=r.removeAllListeners.bind(r),t.emit=function(n,i){\"undefined\"!=typeof jQuery&&jQuery(t).trigger(n,i),e.emit(n,i),r.emit(n,i)},t},triggerHandler:function(t,e,r){var n,i;\"undefined\"!=typeof jQuery&&(n=jQuery(t).triggerHandler(e,r));var a=t._ev;if(!a)return n;var o,s=a._events[e];if(!s)return n;function l(t){return t.listener?(a.removeListener(e,t.listener),t.fired?void 0:(t.fired=!0,t.listener.apply(a,[r]))):t.apply(a,[r])}for(s=Array.isArray(s)?s:[s],o=0;o<s.length-1;o++)l(s[o]);return i=l(s[o]),void 0!==n?n:i},purge:function(t){return delete t._ev,delete t.on,delete t.once,delete t.removeListener,delete t.removeAllListeners,delete t.emit,delete t._ev,delete t._internalEv,delete t._internalOn,delete t._internalOnce,delete t._removeInternalListener,delete t._removeAllInternalListeners,t}};e.exports=i},{events:104}],710:[function(t,e,r){\"use strict\";var n=t(\"./is_plain_object.js\"),i=Array.isArray;function a(t,e,r,o){var s,l,c,u,h,f,p=t[0],d=t.length;if(2===d&&i(p)&&i(t[1])&&0===p.length){if(function(t,e){var r,n;for(r=0;r<t.length;r++){if(null!==(n=t[r])&&\"object\"==typeof n)return!1;void 0!==n&&(e[r]=n)}return!0}(t[1],p))return p;p.splice(0,p.length)}for(var g=1;g<d;g++)for(l in s=t[g])c=p[l],u=s[l],o&&i(u)?p[l]=u:e&&u&&(n(u)||(h=i(u)))?(h?(h=!1,f=c&&i(c)?c:[]):f=c&&n(c)?c:{},p[l]=a([f,u],e,r,o)):(\"undefined\"!=typeof u||r)&&(p[l]=u);return p}r.extendFlat=function(){return a(arguments,!1,!1,!1)},r.extendDeep=function(){return a(arguments,!0,!1,!1)},r.extendDeepAll=function(){return a(arguments,!0,!0,!1)},r.extendDeepNoArrays=function(){return a(arguments,!0,!1,!0)}},{\"./is_plain_object.js\":720}],711:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e={},r=[],n=0,i=0;i<t.length;i++){var a=t[i];1!==e[a]&&(e[a]=1,r[n++]=a)}return r}},{}],712:[function(t,e,r){\"use strict\";function n(t){return!0===t.visible}function i(t){var e=t[0].trace;return!0===e.visible&&0!==e._length}e.exports=function(t){for(var e,r=(e=t,Array.isArray(e)&&Array.isArray(e[0])&&e[0][0]&&e[0][0].trace?i:n),a=[],o=0;o<t.length;o++){var s=t[o];r(s)&&a.push(s)}return a}},{}],713:[function(t,e,r){\"use strict\";var n=t(\"country-regex\"),i=t(\"../lib\"),a=Object.keys(n),o={\"ISO-3\":i.identity,\"USA-states\":i.identity,\"country names\":function(t){for(var e=0;e<a.length;e++){var r=a[e],o=new RegExp(n[r]);if(o.test(t.trim().toLowerCase()))return r}return i.log(\"Unrecognized country name: \"+t+\".\"),!1}};e.exports={locationToFeature:function(t,e,r){if(!e||\"string\"!=typeof e)return!1;var n,a,s,l=o[t](e);if(l){if(\"USA-states\"===t)for(n=[],s=0;s<r.length;s++)(a=r[s]).properties&&a.properties.gu&&\"USA\"===a.properties.gu&&n.push(a);else n=r;for(s=0;s<n.length;s++)if((a=n[s]).id===l)return a;i.log([\"Location with id\",l,\"does not have a matching topojson feature at this resolution.\"].join(\" \"))}return!1}}},{\"../lib\":719,\"country-regex\":134}],714:[function(t,e,r){\"use strict\";var n=t(\"../constants/numerical\").BADNUM;r.calcTraceToLineCoords=function(t){for(var e=t[0].trace.connectgaps,r=[],i=[],a=0;a<t.length;a++){var o=t[a].lonlat;o[0]!==n?i.push(o):!e&&i.length>0&&(r.push(i),i=[])}return i.length>0&&r.push(i),r},r.makeLine=function(t){return 1===t.length?{type:\"LineString\",coordinates:t[0]}:{type:\"MultiLineString\",coordinates:t}},r.makePolygon=function(t){if(1===t.length)return{type:\"Polygon\",coordinates:t};for(var e=new Array(t.length),r=0;r<t.length;r++)e[r]=[t[r]];return{type:\"MultiPolygon\",coordinates:e}},r.makeBlank=function(){return{type:\"Point\",coordinates:[]}}},{\"../constants/numerical\":695}],715:[function(t,e,r){\"use strict\";var n,i,a,o=t(\"./mod\").mod;function s(t,e,r,n,i,a,o,s){var l=r-t,c=i-t,u=o-i,h=n-e,f=a-e,p=s-a,d=l*p-u*h;if(0===d)return null;var g=(c*p-u*f)/d,v=(c*h-l*f)/d;return v<0||v>1||g<0||g>1?null:{x:t+l*g,y:e+h*g}}function l(t,e,r,n,i){var a=n*t+i*e;if(a<0)return n*n+i*i;if(a>r){var o=n-t,s=i-e;return o*o+s*s}var l=n*e-i*t;return l*l/r}r.segmentsIntersect=s,r.segmentDistance=function(t,e,r,n,i,a,o,c){if(s(t,e,r,n,i,a,o,c))return 0;var u=r-t,h=n-e,f=o-i,p=c-a,d=u*u+h*h,g=f*f+p*p,v=Math.min(l(u,h,d,i-t,a-e),l(u,h,d,o-t,c-e),l(f,p,g,t-i,e-a),l(f,p,g,r-i,n-a));return Math.sqrt(v)},r.getTextLocation=function(t,e,r,s){if(t===i&&s===a||(n={},i=t,a=s),n[r])return n[r];var l=t.getPointAtLength(o(r-s/2,e)),c=t.getPointAtLength(o(r+s/2,e)),u=Math.atan((c.y-l.y)/(c.x-l.x)),h=t.getPointAtLength(o(r,e)),f={x:(4*h.x+l.x+c.x)/6,y:(4*h.y+l.y+c.y)/6,theta:u};return n[r]=f,f},r.clearLocationCache=function(){i=null},r.getVisibleSegment=function(t,e,r){var n,i,a=e.left,o=e.right,s=e.top,l=e.bottom,c=0,u=t.getTotalLength(),h=u;function f(e){var r=t.getPointAtLength(e);0===e?n=r:e===u&&(i=r);var c=r.x<a?a-r.x:r.x>o?r.x-o:0,h=r.y<s?s-r.y:r.y>l?r.y-l:0;return Math.sqrt(c*c+h*h)}for(var p=f(c);p;){if((c+=p+r)>h)return;p=f(c)}for(p=f(h);p;){if(c>(h-=p+r))return;p=f(h)}return{min:c,max:h,len:h-c,total:u,isClosed:0===c&&h===u&&Math.abs(n.x-i.x)<.1&&Math.abs(n.y-i.y)<.1}},r.findPointOnPath=function(t,e,r,n){for(var i,a,o,s=(n=n||{}).pathLength||t.getTotalLength(),l=n.tolerance||.001,c=n.iterationLimit||30,u=t.getPointAtLength(0)[r]>t.getPointAtLength(s)[r]?-1:1,h=0,f=0,p=s;h<c;){if(i=(f+p)/2,o=(a=t.getPointAtLength(i))[r]-e,Math.abs(o)<l)return a;u*o>0?p=i:f=i,h++}return a}},{\"./mod\":726}],716:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"color-normalize\"),o=t(\"../components/colorscale\"),s=t(\"../components/color/attributes\").defaultLine,l=t(\"./array\").isArrayOrTypedArray,c=a(s),u=1;function h(t,e){var r=t;return r[3]*=e,r}function f(t){if(n(t))return c;var e=a(t);return e.length?e:c}function p(t){return n(t)?t:u}e.exports={formatColor:function(t,e,r){var n,i,s,d,g,v=t.color,m=l(v),y=l(e),x=o.extractOpts(t),b=[];if(n=void 0!==x.colorscale?o.makeColorScaleFuncFromTrace(t):f,i=m?function(t,e){return void 0===t[e]?c:a(n(t[e]))}:f,s=y?function(t,e){return void 0===t[e]?u:p(t[e])}:p,m||y)for(var _=0;_<r;_++)d=i(v,_),g=s(e,_),b[_]=h(d,g);else b=h(a(v),e);return b},parseColorScale:function(t,e){void 0===e&&(e=1);var r=o.extractOpts(t);return(r.reversescale?o.flipScale(r.colorscale):r.colorscale).map(function(t){var r=t[0],n=i(t[1]).toRgb();return{index:r,rgb:[n.r,n.g,n.b,e]}})}}},{\"../components/color/attributes\":592,\"../components/colorscale\":605,\"./array\":702,\"color-normalize\":120,\"fast-isnumeric\":225,tinycolor2:537}],717:[function(t,e,r){\"use strict\";var n=t(\"./identity\");function i(t){return[t]}e.exports={keyFun:function(t){return t.key},repeat:i,descend:n,wrap:i,unwrap:function(t){return t[0]}}},{\"./identity\":718}],718:[function(t,e,r){\"use strict\";e.exports=function(t){return t}},{}],719:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../constants/numerical\"),o=a.FP_SAFE,s=a.BADNUM,l=e.exports={};l.nestedProperty=t(\"./nested_property\"),l.keyedContainer=t(\"./keyed_container\"),l.relativeAttr=t(\"./relative_attr\"),l.isPlainObject=t(\"./is_plain_object\"),l.toLogRange=t(\"./to_log_range\"),l.relinkPrivateKeys=t(\"./relink_private\");var c=t(\"./array\");l.isTypedArray=c.isTypedArray,l.isArrayOrTypedArray=c.isArrayOrTypedArray,l.isArray1D=c.isArray1D,l.ensureArray=c.ensureArray,l.concat=c.concat,l.maxRowLength=c.maxRowLength,l.minRowLength=c.minRowLength;var u=t(\"./mod\");l.mod=u.mod,l.modHalf=u.modHalf;var h=t(\"./coerce\");l.valObjectMeta=h.valObjectMeta,l.coerce=h.coerce,l.coerce2=h.coerce2,l.coerceFont=h.coerceFont,l.coerceHoverinfo=h.coerceHoverinfo,l.coerceSelectionMarkerOpacity=h.coerceSelectionMarkerOpacity,l.validate=h.validate;var f=t(\"./dates\");l.dateTime2ms=f.dateTime2ms,l.isDateTime=f.isDateTime,l.ms2DateTime=f.ms2DateTime,l.ms2DateTimeLocal=f.ms2DateTimeLocal,l.cleanDate=f.cleanDate,l.isJSDate=f.isJSDate,l.formatDate=f.formatDate,l.incrementMonth=f.incrementMonth,l.dateTick0=f.dateTick0,l.dfltRange=f.dfltRange,l.findExactDates=f.findExactDates,l.MIN_MS=f.MIN_MS,l.MAX_MS=f.MAX_MS;var p=t(\"./search\");l.findBin=p.findBin,l.sorterAsc=p.sorterAsc,l.sorterDes=p.sorterDes,l.distinctVals=p.distinctVals,l.roundUp=p.roundUp,l.sort=p.sort,l.findIndexOfMin=p.findIndexOfMin;var d=t(\"./stats\");l.aggNums=d.aggNums,l.len=d.len,l.mean=d.mean,l.median=d.median,l.midRange=d.midRange,l.variance=d.variance,l.stdev=d.stdev,l.interp=d.interp;var g=t(\"./matrix\");l.init2dArray=g.init2dArray,l.transposeRagged=g.transposeRagged,l.dot=g.dot,l.translationMatrix=g.translationMatrix,l.rotationMatrix=g.rotationMatrix,l.rotationXYMatrix=g.rotationXYMatrix,l.apply2DTransform=g.apply2DTransform,l.apply2DTransform2=g.apply2DTransform2;var v=t(\"./angles\");l.deg2rad=v.deg2rad,l.rad2deg=v.rad2deg,l.angleDelta=v.angleDelta,l.angleDist=v.angleDist,l.isFullCircle=v.isFullCircle,l.isAngleInsideSector=v.isAngleInsideSector,l.isPtInsideSector=v.isPtInsideSector,l.pathArc=v.pathArc,l.pathSector=v.pathSector,l.pathAnnulus=v.pathAnnulus;var m=t(\"./anchor_utils\");l.isLeftAnchor=m.isLeftAnchor,l.isCenterAnchor=m.isCenterAnchor,l.isRightAnchor=m.isRightAnchor,l.isTopAnchor=m.isTopAnchor,l.isMiddleAnchor=m.isMiddleAnchor,l.isBottomAnchor=m.isBottomAnchor;var y=t(\"./geometry2d\");l.segmentsIntersect=y.segmentsIntersect,l.segmentDistance=y.segmentDistance,l.getTextLocation=y.getTextLocation,l.clearLocationCache=y.clearLocationCache,l.getVisibleSegment=y.getVisibleSegment,l.findPointOnPath=y.findPointOnPath;var x=t(\"./extend\");l.extendFlat=x.extendFlat,l.extendDeep=x.extendDeep,l.extendDeepAll=x.extendDeepAll,l.extendDeepNoArrays=x.extendDeepNoArrays;var b=t(\"./loggers\");l.log=b.log,l.warn=b.warn,l.error=b.error;var _=t(\"./regex\");l.counterRegex=_.counter;var w=t(\"./throttle\");l.throttle=w.throttle,l.throttleDone=w.done,l.clearThrottle=w.clear;var k=t(\"./dom\");function T(t){var e={};for(var r in t)for(var n=t[r],i=0;i<n.length;i++)e[n[i]]=+r;return e}l.getGraphDiv=k.getGraphDiv,l.isPlotDiv=k.isPlotDiv,l.removeElement=k.removeElement,l.addStyleRule=k.addStyleRule,l.addRelatedStyleRule=k.addRelatedStyleRule,l.deleteRelatedStyleRule=k.deleteRelatedStyleRule,l.clearResponsive=t(\"./clear_responsive\"),l.makeTraceGroups=t(\"./make_trace_groups\"),l._=t(\"./localize\"),l.notifier=t(\"./notifier\"),l.filterUnique=t(\"./filter_unique\"),l.filterVisible=t(\"./filter_visible\"),l.pushUnique=t(\"./push_unique\"),l.cleanNumber=t(\"./clean_number\"),l.ensureNumber=function(t){return i(t)?(t=Number(t))<-o||t>o?s:i(t)?Number(t):s:s},l.isIndex=function(t,e){return!(void 0!==e&&t>=e)&&(i(t)&&t>=0&&t%1==0)},l.noop=t(\"./noop\"),l.identity=t(\"./identity\"),l.repeat=function(t,e){for(var r=new Array(e),n=0;n<e;n++)r[n]=t;return r},l.swapAttrs=function(t,e,r,n){r||(r=\"x\"),n||(n=\"y\");for(var i=0;i<e.length;i++){var a=e[i],o=l.nestedProperty(t,a.replace(\"?\",r)),s=l.nestedProperty(t,a.replace(\"?\",n)),c=o.get();o.set(s.get()),s.set(c)}},l.raiseToTop=function(t){t.parentNode.appendChild(t)},l.cancelTransition=function(t){return t.transition().duration(0)},l.constrain=function(t,e,r){return e>r?Math.max(r,Math.min(e,t)):Math.max(e,Math.min(r,t))},l.bBoxIntersect=function(t,e,r){return r=r||0,t.left<=e.right+r&&e.left<=t.right+r&&t.top<=e.bottom+r&&e.top<=t.bottom+r},l.simpleMap=function(t,e,r,n){for(var i=t.length,a=new Array(i),o=0;o<i;o++)a[o]=e(t[o],r,n);return a},l.randstr=function t(e,r,n,i){if(n||(n=16),void 0===r&&(r=24),r<=0)return\"0\";var a,o,s=Math.log(Math.pow(2,r))/Math.log(n),c=\"\";for(a=2;s===1/0;a*=2)s=Math.log(Math.pow(2,r/a))/Math.log(n)*a;var u=s-Math.floor(s);for(a=0;a<Math.floor(s);a++)c=Math.floor(Math.random()*n).toString(n)+c;u&&(o=Math.pow(n,u),c=Math.floor(Math.random()*o).toString(n)+c);var h=parseInt(c,n);return e&&e[c]||h!==1/0&&h>=Math.pow(2,r)?i>10?(l.warn(\"randstr failed uniqueness\"),c):t(e,r,n,(i||0)+1):c},l.OptionControl=function(t,e){t||(t={}),e||(e=\"opt\");var r={optionList:[],_newoption:function(n){n[e]=t,r[n.name]=n,r.optionList.push(n)}};return r[\"_\"+e]=t,r},l.smooth=function(t,e){if((e=Math.round(e)||0)<2)return t;var r,n,i,a,o=t.length,s=2*o,l=2*e-1,c=new Array(l),u=new Array(o);for(r=0;r<l;r++)c[r]=(1-Math.cos(Math.PI*(r+1)/e))/(2*e);for(r=0;r<o;r++){for(a=0,n=0;n<l;n++)(i=r+n+1-e)<-o?i-=s*Math.round(i/s):i>=s&&(i-=s*Math.floor(i/s)),i<0?i=-1-i:i>=o&&(i=s-1-i),a+=t[i]*c[n];u[r]=a}return u},l.syncOrAsync=function(t,e,r){var n;function i(){return l.syncOrAsync(t,e,r)}for(;t.length;)if((n=(0,t.splice(0,1)[0])(e))&&n.then)return n.then(i).then(void 0,l.promiseError);return r&&r(e)},l.stripTrailingSlash=function(t){return\"/\"===t.substr(-1)?t.substr(0,t.length-1):t},l.noneOrAll=function(t,e,r){if(t){var n,i=!1,a=!0;for(n=0;n<r.length;n++)null!=t[r[n]]?i=!0:a=!1;if(i&&!a)for(n=0;n<r.length;n++)t[r[n]]=e[r[n]]}},l.mergeArray=function(t,e,r,n){var i=\"function\"==typeof n;if(l.isArrayOrTypedArray(t))for(var a=Math.min(t.length,e.length),o=0;o<a;o++){var s=t[o];e[o][r]=i?n(s):s}},l.mergeArrayCastPositive=function(t,e,r){return l.mergeArray(t,e,r,function(t){var e=+t;return isFinite(e)&&e>0?e:0})},l.fillArray=function(t,e,r,n){if(n=n||l.identity,l.isArrayOrTypedArray(t))for(var i=0;i<e.length;i++)e[i][r]=n(t[i])},l.castOption=function(t,e,r,n){n=n||l.identity;var i=l.nestedProperty(t,r).get();return l.isArrayOrTypedArray(i)?Array.isArray(e)&&l.isArrayOrTypedArray(i[e[0]])?n(i[e[0]][e[1]]):n(i[e]):i},l.extractOption=function(t,e,r,n){if(r in t)return t[r];var i=l.nestedProperty(e,n).get();return Array.isArray(i)?void 0:i},l.tagSelected=function(t,e,r){var n,i,a=e.selectedpoints,o=e._indexToPoints;o&&(n=T(o));for(var s=0;s<a.length;s++){var c=a[s];if(l.isIndex(c)){var u=n?n[c]:c,h=r?r[u]:u;void 0!==(i=h)&&i<t.length&&(t[h].selected=1)}}},l.selIndices2selPoints=function(t){var e=t.selectedpoints,r=t._indexToPoints;if(r){for(var n=T(r),i=[],a=0;a<e.length;a++){var o=e[a];if(l.isIndex(o)){var s=n[o];l.isIndex(s)&&i.push(s)}}return i}return e},l.getTargetArray=function(t,e){var r=e.target;if(\"string\"==typeof r&&r){var n=l.nestedProperty(t,r).get();return!!Array.isArray(n)&&n}return!!Array.isArray(r)&&r},l.minExtend=function(t,e){var r={};\"object\"!=typeof e&&(e={});var n,i,a,o=Object.keys(t);for(n=0;n<o.length;n++)a=t[i=o[n]],\"_\"!==i.charAt(0)&&\"function\"!=typeof a&&(\"module\"===i?r[i]=a:Array.isArray(a)?r[i]=\"colorscale\"===i?a.slice():a.slice(0,3):r[i]=a&&\"object\"==typeof a?l.minExtend(t[i],e[i]):a);for(o=Object.keys(e),n=0;n<o.length;n++)\"object\"==typeof(a=e[i=o[n]])&&i in r&&\"object\"==typeof r[i]||(r[i]=a);return r},l.titleCase=function(t){return t.charAt(0).toUpperCase()+t.substr(1)},l.containsAny=function(t,e){for(var r=0;r<e.length;r++)if(-1!==t.indexOf(e[r]))return!0;return!1},l.isIE=function(){return\"undefined\"!=typeof window.navigator.msSaveBlob};var A=/MSIE [1-9]\\./;l.isIE9orBelow=function(){return l.isIE()&&A.test(window.navigator.userAgent)};var M=/Version\\/[\\d\\.]+.*Safari/;l.isSafari=function(){return M.test(window.navigator.userAgent)},l.isD3Selection=function(t){return t&&\"function\"==typeof t.classed},l.ensureSingle=function(t,e,r,n){var i=t.select(e+(r?\".\"+r:\"\"));if(i.size())return i;var a=t.append(e);return r&&a.classed(r,!0),n&&a.call(n),a},l.ensureSingleById=function(t,e,r,n){var i=t.select(e+\"#\"+r);if(i.size())return i;var a=t.append(e).attr(\"id\",r);return n&&a.call(n),a},l.objectFromPath=function(t,e){for(var r,n=t.split(\".\"),i=r={},a=0;a<n.length;a++){var o=n[a],s=null,l=n[a].match(/(.*)\\[([0-9]+)\\]/);l?(o=l[1],s=l[2],r=r[o]=[],a===n.length-1?r[s]=e:r[s]={},r=r[s]):(a===n.length-1?r[o]=e:r[o]={},r=r[o])}return i};var S=/^([^\\[\\.]+)\\.(.+)?/,E=/^([^\\.]+)\\[([0-9]+)\\](\\.)?(.+)?/;l.expandObjectPaths=function(t){var e,r,n,i,a,o,s;if(\"object\"==typeof t&&!Array.isArray(t))for(r in t)t.hasOwnProperty(r)&&((e=r.match(S))?(i=t[r],n=e[1],delete t[r],t[n]=l.extendDeepNoArrays(t[n]||{},l.objectFromPath(r,l.expandObjectPaths(i))[n])):(e=r.match(E))?(i=t[r],n=e[1],a=parseInt(e[2]),delete t[r],t[n]=t[n]||[],\".\"===e[3]?(s=e[4],o=t[n][a]=t[n][a]||{},l.extendDeepNoArrays(o,l.objectFromPath(s,l.expandObjectPaths(i)))):t[n][a]=l.expandObjectPaths(i)):t[r]=l.expandObjectPaths(t[r]));return t},l.numSeparate=function(t,e,r){if(r||(r=!1),\"string\"!=typeof e||0===e.length)throw new Error(\"Separator string required for formatting!\");\"number\"==typeof t&&(t=String(t));var n=/(\\d+)(\\d{3})/,i=e.charAt(0),a=e.charAt(1),o=t.split(\".\"),s=o[0],l=o.length>1?i+o[1]:\"\";if(a&&(o.length>1||s.length>4||r))for(;n.test(s);)s=s.replace(n,\"$1\"+a+\"$2\");return s+l},l.TEMPLATE_STRING_REGEX=/%{([^\\s%{}:]*)(:[^}]*)?}/g;var C=/^\\w*$/;l.templateString=function(t,e){var r={};return t.replace(l.TEMPLATE_STRING_REGEX,function(t,n){return C.test(n)?e[n]||\"\":(r[n]=r[n]||l.nestedProperty(e,n).get,r[n]()||\"\")})};var L=/^:/,P=0;l.hovertemplateString=function(t,e,r){var i=arguments,a={};return t.replace(l.TEMPLATE_STRING_REGEX,function(t,o,s){var c,u,h;for(h=3;h<i.length;h++){if((c=i[h]).hasOwnProperty(o)){u=c[o];break}if(C.test(o)||(u=a[o]||l.nestedProperty(c,o).get())&&(a[o]=u),void 0!==u)break}(void 0===u&&(P<10&&(l.warn(\"Variable '\"+o+\"' in hovertemplate could not be found!\"),u=t),10===P&&l.warn(\"Too many hovertemplate warnings - additional warnings will be suppressed\"),P++),s)?u=(r?r.numberFormat:n.format)(s.replace(L,\"\"))(u):e.hasOwnProperty(o+\"Label\")&&(u=e[o+\"Label\"]);return u})};l.subplotSort=function(t,e){for(var r=Math.min(t.length,e.length)+1,n=0,i=0,a=0;a<r;a++){var o=t.charCodeAt(a)||0,s=e.charCodeAt(a)||0,l=o>=48&&o<=57,c=s>=48&&s<=57;if(l&&(n=10*n+o-48),c&&(i=10*i+s-48),!l||!c){if(n!==i)return n-i;if(o!==s)return o-s}}return i-n};var O=2e9;l.seedPseudoRandom=function(){O=2e9},l.pseudoRandom=function(){var t=O;return O=(69069*O+1)%4294967296,Math.abs(O-t)<429496729?l.pseudoRandom():O/4294967296},l.fillText=function(t,e,r){var n=Array.isArray(r)?function(t){r.push(t)}:function(t){r.text=t},i=l.extractOption(t,e,\"htx\",\"hovertext\");if(l.isValidTextValue(i))return n(i);var a=l.extractOption(t,e,\"tx\",\"text\");return l.isValidTextValue(a)?n(a):void 0},l.isValidTextValue=function(t){return t||0===t},l.formatPercent=function(t,e){e=e||0;for(var r=(Math.round(100*t*Math.pow(10,e))*Math.pow(.1,e)).toFixed(e)+\"%\",n=0;n<e;n++)-1!==r.indexOf(\".\")&&(r=(r=r.replace(\"0%\",\"%\")).replace(\".%\",\"%\"));return r},l.isHidden=function(t){var e=window.getComputedStyle(t).display;return!e||\"none\"===e}},{\"../constants/numerical\":695,\"./anchor_utils\":700,\"./angles\":701,\"./array\":702,\"./clean_number\":703,\"./clear_responsive\":705,\"./coerce\":706,\"./dates\":707,\"./dom\":708,\"./extend\":710,\"./filter_unique\":711,\"./filter_visible\":712,\"./geometry2d\":715,\"./identity\":718,\"./is_plain_object\":720,\"./keyed_container\":721,\"./localize\":722,\"./loggers\":723,\"./make_trace_groups\":724,\"./matrix\":725,\"./mod\":726,\"./nested_property\":727,\"./noop\":728,\"./notifier\":729,\"./push_unique\":733,\"./regex\":735,\"./relative_attr\":736,\"./relink_private\":737,\"./search\":738,\"./stats\":741,\"./throttle\":744,\"./to_log_range\":745,d3:163,\"fast-isnumeric\":225}],720:[function(t,e,r){\"use strict\";e.exports=function(t){return window&&window.process&&window.process.versions?\"[object Object]\"===Object.prototype.toString.call(t):\"[object Object]\"===Object.prototype.toString.call(t)&&Object.getPrototypeOf(t)===Object.prototype}},{}],721:[function(t,e,r){\"use strict\";var n=t(\"./nested_property\"),i=/^\\w*$/;e.exports=function(t,e,r,a){var o,s,l;r=r||\"name\",a=a||\"value\";var c={};e&&e.length?(l=n(t,e),s=l.get()):s=t,e=e||\"\";var u={};if(s)for(o=0;o<s.length;o++)u[s[o][r]]=o;var h=i.test(a),f={set:function(t,e){var i=null===e?4:0;if(!s){if(!l||4===i)return;s=[],l.set(s)}var o=u[t];if(void 0===o){if(4===i)return;i|=3,o=s.length,u[t]=o}else e!==(h?s[o][a]:n(s[o],a).get())&&(i|=2);var p=s[o]=s[o]||{};return p[r]=t,h?p[a]=e:n(p,a).set(e),null!==e&&(i&=-5),c[o]=c[o]|i,f},get:function(t){if(s){var e=u[t];return void 0===e?void 0:h?s[e][a]:n(s[e],a).get()}},rename:function(t,e){var n=u[t];return void 0===n?f:(c[n]=1|c[n],u[e]=n,delete u[t],s[n][r]=e,f)},remove:function(t){var e=u[t];if(void 0===e)return f;var i=s[e];if(Object.keys(i).length>2)return c[e]=2|c[e],f.set(t,null);if(h){for(o=e;o<s.length;o++)c[o]=3|c[o];for(o=e;o<s.length;o++)u[s[o][r]]--;s.splice(e,1),delete u[t]}else n(i,a).set(null),c[e]=6|c[e];return f},constructUpdate:function(){for(var t,i,o={},l=Object.keys(c),u=0;u<l.length;u++)i=l[u],t=e+\"[\"+i+\"]\",s[i]?(1&c[i]&&(o[t+\".\"+r]=s[i][r]),2&c[i]&&(o[t+\".\"+a]=h?4&c[i]?null:s[i][a]:4&c[i]?null:n(s[i],a).get())):o[t]=null;return o}};return f}},{\"./nested_property\":727}],722:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t,e){for(var r=t._context.locale,i=0;i<2;i++){for(var a=t._context.locales,o=0;o<2;o++){var s=(a[r]||{}).dictionary;if(s){var l=s[e];if(l)return l}a=n.localeRegistry}var c=r.split(\"-\")[0];if(c===r)break;r=c}return e}},{\"../registry\":847}],723:[function(t,e,r){\"use strict\";var n=t(\"../plot_api/plot_config\").dfltConfig,i=e.exports={};function a(t,e){if(t&&t.apply)try{return void t.apply(console,e)}catch(t){}for(var r=0;r<e.length;r++)try{t(e[r])}catch(t){console.log(e[r])}}i.log=function(){if(n.logging>1){for(var t=[\"LOG:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.trace||console.log,t)}},i.warn=function(){if(n.logging>0){for(var t=[\"WARN:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.trace||console.log,t)}},i.error=function(){if(n.logging>0){for(var t=[\"ERROR:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.error,t)}}},{\"../plot_api/plot_config\":755}],724:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e,r){var i=t.selectAll(\"g.\"+r.replace(/\\s/g,\".\")).data(e,function(t){return t[0].trace.uid});i.exit().remove(),i.enter().append(\"g\").attr(\"class\",r),i.order();var a=t.classed(\"rangeplot\")?\"nodeRangePlot3\":\"node3\";return i.each(function(t){t[0][a]=n.select(this)}),i}},{d3:163}],725:[function(t,e,r){\"use strict\";r.init2dArray=function(t,e){for(var r=new Array(t),n=0;n<t;n++)r[n]=new Array(e);return r},r.transposeRagged=function(t){var e,r,n=0,i=t.length;for(e=0;e<i;e++)n=Math.max(n,t[e].length);var a=new Array(n);for(e=0;e<n;e++)for(a[e]=new Array(i),r=0;r<i;r++)a[e][r]=t[r][e];return a},r.dot=function(t,e){if(!t.length||!e.length||t.length!==e.length)return null;var n,i,a=t.length;if(t[0].length)for(n=new Array(a),i=0;i<a;i++)n[i]=r.dot(t[i],e);else if(e[0].length){var o=r.transposeRagged(e);for(n=new Array(o.length),i=0;i<o.length;i++)n[i]=r.dot(t,o[i])}else for(n=0,i=0;i<a;i++)n+=t[i]*e[i];return n},r.translationMatrix=function(t,e){return[[1,0,t],[0,1,e],[0,0,1]]},r.rotationMatrix=function(t){var e=t*Math.PI/180;return[[Math.cos(e),-Math.sin(e),0],[Math.sin(e),Math.cos(e),0],[0,0,1]]},r.rotationXYMatrix=function(t,e,n){return r.dot(r.dot(r.translationMatrix(e,n),r.rotationMatrix(t)),r.translationMatrix(-e,-n))},r.apply2DTransform=function(t){return function(){var e=arguments;3===e.length&&(e=e[0]);var n=1===arguments.length?e[0]:[e[0],e[1]];return r.dot(t,[n[0],n[1],1]).slice(0,2)}},r.apply2DTransform2=function(t){var e=r.apply2DTransform(t);return function(t){return e(t.slice(0,2)).concat(e(t.slice(2,4)))}}},{}],726:[function(t,e,r){\"use strict\";e.exports={mod:function(t,e){var r=t%e;return r<0?r+e:r},modHalf:function(t,e){return Math.abs(t)>e/2?t-Math.round(t/e)*e:t}}},{}],727:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;e.exports=function(t,e){if(n(e))e=String(e);else if(\"string\"!=typeof e||\"[-1]\"===e.substr(e.length-4))throw\"bad property string\";for(var r,a,o,l=0,c=e.split(\".\");l<c.length;){if(r=String(c[l]).match(/^([^\\[\\]]*)((\\[\\-?[0-9]*\\])+)$/)){if(r[1])c[l]=r[1];else{if(0!==l)throw\"bad property string\";c.splice(0,1)}for(a=r[2].substr(1,r[2].length-2).split(\"][\"),o=0;o<a.length;o++)l++,c.splice(l,0,Number(a[o]))}l++}return\"object\"!=typeof t?function(t,e,r){return{set:function(){throw\"bad container\"},get:function(){},astr:e,parts:r,obj:t}}(t,e,c):{set:s(t,c,e),get:function t(e,r){return function(){var n,a,o,s,l,c=e;for(s=0;s<r.length-1;s++){if(-1===(n=r[s])){for(a=!0,o=[],l=0;l<c.length;l++)o[l]=t(c[l],r.slice(s+1))(),o[l]!==o[0]&&(a=!1);return a?o[0]:o}if(\"number\"==typeof n&&!i(c))return;if(\"object\"!=typeof(c=c[n])||null===c)return}if(\"object\"==typeof c&&null!==c&&null!==(o=c[r[s]]))return o}}(t,c),astr:e,parts:c,obj:t}};var a=/(^|\\.)args\\[/;function o(t,e){return void 0===t||null===t&&!e.match(a)}function s(t,e,r){return function(n){var a,s,h=t,f=\"\",p=[[t,f]],d=o(n,r);for(s=0;s<e.length-1;s++){if(\"number\"==typeof(a=e[s])&&!i(h))throw\"array index but container is not an array\";if(-1===a){if(d=!c(h,e.slice(s+1),n,r))break;return}if(!u(h,a,e[s+1],d))break;if(\"object\"!=typeof(h=h[a])||null===h)throw\"container is not an object\";f=l(f,a),p.push([h,f])}if(d){if(s===e.length-1&&(delete h[e[s]],Array.isArray(h)&&+e[s]==h.length-1))for(;h.length&&void 0===h[h.length-1];)h.pop()}else h[e[s]]=n}}function l(t,e){var r=e;return n(e)?r=\"[\"+e+\"]\":t&&(r=\".\"+e),t+r}function c(t,e,r,n){var a,l=i(r),c=!0,h=r,f=n.replace(\"-1\",0),p=!l&&o(r,f),d=e[0];for(a=0;a<t.length;a++)f=n.replace(\"-1\",a),l&&(p=o(h=r[a%r.length],f)),p&&(c=!1),u(t,a,d,p)&&s(t[a],e,n.replace(\"-1\",a))(h);return c}function u(t,e,r,n){if(void 0===t[e]){if(n)return!1;t[e]=\"number\"==typeof r?[]:{}}return!0}},{\"./array\":702,\"fast-isnumeric\":225}],728:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],729:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=[];e.exports=function(t,e){if(-1===a.indexOf(t)){a.push(t);var r=1e3;i(e)?r=e:\"long\"===e&&(r=3e3);var o=n.select(\"body\").selectAll(\".plotly-notifier\").data([0]);o.enter().append(\"div\").classed(\"plotly-notifier\",!0),o.selectAll(\".notifier-note\").data(a).enter().append(\"div\").classed(\"notifier-note\",!0).style(\"opacity\",0).each(function(t){var e=n.select(this);e.append(\"button\").classed(\"notifier-close\",!0).html(\"&times;\").on(\"click\",function(){e.transition().call(s)});for(var i=e.append(\"p\"),a=t.split(/<br\\s*\\/?>/g),o=0;o<a.length;o++)o&&i.append(\"br\"),i.append(\"span\").text(a[o]);e.transition().duration(700).style(\"opacity\",1).transition().delay(r).call(s)})}function s(t){t.duration(700).style(\"opacity\",0).each(\"end\",function(t){var e=a.indexOf(t);-1!==e&&a.splice(e,1),n.select(this).remove()})}}},{d3:163,\"fast-isnumeric\":225}],730:[function(t,e,r){\"use strict\";var n=t(\"./setcursor\"),i=\"data-savedcursor\";e.exports=function(t,e){var r=t.attr(i);if(e){if(!r){for(var a=(t.attr(\"class\")||\"\").split(\" \"),o=0;o<a.length;o++){var s=a[o];0===s.indexOf(\"cursor-\")&&t.attr(i,s.substr(7)).classed(s,!1)}t.attr(i)||t.attr(i,\"!!\")}n(t,e)}else r&&(t.attr(i,null),\"!!\"===r?n(t):n(t,r))}},{\"./setcursor\":739}],731:[function(t,e,r){\"use strict\";var n=t(\"./matrix\").dot,i=t(\"../constants/numerical\").BADNUM,a=e.exports={};a.tester=function(t){var e,r=t.slice(),n=r[0][0],a=n,o=r[0][1],s=o;for(r.push(r[0]),e=1;e<r.length;e++)n=Math.min(n,r[e][0]),a=Math.max(a,r[e][0]),o=Math.min(o,r[e][1]),s=Math.max(s,r[e][1]);var l,c=!1;5===r.length&&(r[0][0]===r[1][0]?r[2][0]===r[3][0]&&r[0][1]===r[3][1]&&r[1][1]===r[2][1]&&(c=!0,l=function(t){return t[0]===r[0][0]}):r[0][1]===r[1][1]&&r[2][1]===r[3][1]&&r[0][0]===r[3][0]&&r[1][0]===r[2][0]&&(c=!0,l=function(t){return t[1]===r[0][1]}));var u=!0,h=r[0];for(e=1;e<r.length;e++)if(h[0]!==r[e][0]||h[1]!==r[e][1]){u=!1;break}return{xmin:n,xmax:a,ymin:o,ymax:s,pts:r,contains:c?function(t,e){var r=t[0],c=t[1];return!(r===i||r<n||r>a||c===i||c<o||c>s||e&&l(t))}:function(t,e){var l=t[0],c=t[1];if(l===i||l<n||l>a||c===i||c<o||c>s)return!1;var u,h,f,p,d,g=r.length,v=r[0][0],m=r[0][1],y=0;for(u=1;u<g;u++)if(h=v,f=m,v=r[u][0],m=r[u][1],!(l<(p=Math.min(h,v))||l>Math.max(h,v)||c>Math.max(f,m)))if(c<Math.min(f,m))l!==p&&y++;else{if(c===(d=v===h?c:f+(l-h)*(m-f)/(v-h)))return 1!==u||!e;c<=d&&l!==p&&y++}return y%2==1},isRect:c,degenerate:u}},a.isSegmentBent=function(t,e,r,i){var a,o,s,l=t[e],c=[t[r][0]-l[0],t[r][1]-l[1]],u=n(c,c),h=Math.sqrt(u),f=[-c[1]/h,c[0]/h];for(a=e+1;a<r;a++)if(o=[t[a][0]-l[0],t[a][1]-l[1]],(s=n(o,c))<0||s>u||Math.abs(n(o,f))>i)return!0;return!1},a.filter=function(t,e){var r=[t[0]],n=0,i=0;function o(o){t.push(o);var s=r.length,l=n;r.splice(i+1);for(var c=l+1;c<t.length;c++)(c===t.length-1||a.isSegmentBent(t,l,c+1,e))&&(r.push(t[c]),r.length<s-2&&(n=c,i=r.length-1),l=c)}t.length>1&&o(t.pop());return{addPt:o,raw:t,filtered:r}}},{\"../constants/numerical\":695,\"./matrix\":725}],732:[function(t,e,r){(function(r){\"use strict\";var n=t(\"./show_no_webgl_msg\"),i=t(\"regl\");e.exports=function(t,e){var a=t._fullLayout,o=!0;return a._glcanvas.each(function(n){if(!n.regl&&(!n.pick||a._has(\"parcoords\"))){try{n.regl=i({canvas:this,attributes:{antialias:!n.pick,preserveDrawingBuffer:!0},pixelRatio:t._context.plotGlPixelRatio||r.devicePixelRatio,extensions:e||[]})}catch(t){o=!1}o&&this.addEventListener(\"webglcontextlost\",function(e){t&&t.emit&&t.emit(\"plotly_webglcontextlost\",{event:e,layer:n.key})},!1)}}),o||n({container:a._glcontainer.node()}),o}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./show_no_webgl_msg\":740,regl:502}],733:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(e instanceof RegExp){for(var r=e.toString(),n=0;n<t.length;n++)if(t[n]instanceof RegExp&&t[n].toString()===r)return t;t.push(e)}else!e&&0!==e||-1!==t.indexOf(e)||t.push(e);return t}},{}],734:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_config\").dfltConfig;var a={add:function(t,e,r,n,a){var o,s;t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},s=t.undoQueue.index,t.autoplay?t.undoQueue.inSequence||(t.autoplay=!1):(!t.undoQueue.sequence||t.undoQueue.beginSequence?(o={undo:{calls:[],args:[]},redo:{calls:[],args:[]}},t.undoQueue.queue.splice(s,t.undoQueue.queue.length-s,o),t.undoQueue.index+=1):o=t.undoQueue.queue[s-1],t.undoQueue.beginSequence=!1,o&&(o.undo.calls.unshift(e),o.undo.args.unshift(r),o.redo.calls.push(n),o.redo.args.push(a)),t.undoQueue.queue.length>i.queueLength&&(t.undoQueue.queue.shift(),t.undoQueue.index--))},startSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!0,t.undoQueue.beginSequence=!0},stopSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!1,t.undoQueue.beginSequence=!1},undo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.undo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index<=0)){for(t.undoQueue.index--,e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.undo.calls.length;r++)a.plotDo(t,e.undo.calls[r],e.undo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1}},redo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.redo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index>=t.undoQueue.queue.length)){for(e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.redo.calls.length;r++)a.plotDo(t,e.redo.calls[r],e.redo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1,t.undoQueue.index++}}};a.plotDo=function(t,e,r){t.autoplay=!0,r=function(t,e){for(var r,i=[],a=0;a<e.length;a++)r=e[a],i[a]=r===t?r:\"object\"==typeof r?Array.isArray(r)?n.extendDeep([],r):n.extendDeepAll({},r):r;return i}(t,r),e.apply(null,r)},e.exports=a},{\"../lib\":719,\"../plot_api/plot_config\":755}],735:[function(t,e,r){\"use strict\";r.counter=function(t,e,r,n){var i=(e||\"\")+(r?\"\":\"$\"),a=!1===n?\"\":\"^\";return\"xy\"===t?new RegExp(a+\"x([2-9]|[1-9][0-9]+)?y([2-9]|[1-9][0-9]+)?\"+i):new RegExp(a+t+\"([2-9]|[1-9][0-9]+)?\"+i)}},{}],736:[function(t,e,r){\"use strict\";var n=/^(.*)(\\.[^\\.\\[\\]]+|\\[\\d\\])$/,i=/^[^\\.\\[\\]]+$/;e.exports=function(t,e){for(;e;){var r=t.match(n);if(r)t=r[1];else{if(!t.match(i))throw new Error(\"bad relativeAttr call:\"+[t,e]);t=\"\"}if(\"^\"!==e.charAt(0))break;e=e.slice(1)}return t&&\"[\"!==e.charAt(0)?t+\".\"+e:t+e}},{}],737:[function(t,e,r){\"use strict\";var n=t(\"./array\").isArrayOrTypedArray,i=t(\"./is_plain_object\");e.exports=function t(e,r){for(var a in r){var o=r[a],s=e[a];if(s!==o)if(\"_\"===a.charAt(0)||\"function\"==typeof o){if(a in e)continue;e[a]=o}else if(n(o)&&n(s)&&i(o[0])){if(\"customdata\"===a||\"ids\"===a)continue;for(var l=Math.min(o.length,s.length),c=0;c<l;c++)s[c]!==o[c]&&i(o[c])&&i(s[c])&&t(s[c],o[c])}else i(o)&&i(s)&&(t(s,o),Object.keys(s).length||delete e[a])}}},{\"./array\":702,\"./is_plain_object\":720}],738:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./loggers\"),a=t(\"./identity\");function o(t,e){return t<e}function s(t,e){return t<=e}function l(t,e){return t>e}function c(t,e){return t>=e}r.findBin=function(t,e,r){if(n(e.start))return r?Math.ceil((t-e.start)/e.size-1e-9)-1:Math.floor((t-e.start)/e.size+1e-9);var a,u,h=0,f=e.length,p=0,d=f>1?(e[f-1]-e[0])/(f-1):1;for(u=d>=0?r?o:s:r?c:l,t+=1e-9*d*(r?-1:1)*(d>=0?1:-1);h<f&&p++<100;)u(e[a=Math.floor((h+f)/2)],t)?h=a+1:f=a;return p>90&&i.log(\"Long binary search...\"),h-1},r.sorterAsc=function(t,e){return t-e},r.sorterDes=function(t,e){return e-t},r.distinctVals=function(t){var e=t.slice();e.sort(r.sorterAsc);for(var n=e.length-1,i=e[n]-e[0]||1,a=i/(n||1)/1e4,o=[e[0]],s=0;s<n;s++)e[s+1]>e[s]+a&&(i=Math.min(i,e[s+1]-e[s]),o.push(e[s+1]));return{vals:o,minDiff:i}},r.roundUp=function(t,e,r){for(var n,i=0,a=e.length-1,o=0,s=r?0:1,l=r?1:0,c=r?Math.ceil:Math.floor;i<a&&o++<100;)e[n=c((i+a)/2)]<=t?i=n+s:a=n-l;return e[i]},r.sort=function(t,e){for(var r=0,n=0,i=1;i<t.length;i++){var a=e(t[i],t[i-1]);if(a<0?r=1:a>0&&(n=1),r&&n)return t.sort(e)}return n?t:t.reverse()},r.findIndexOfMin=function(t,e){e=e||a;for(var r,n=1/0,i=0;i<t.length;i++){var o=e(t[i]);o<n&&(n=o,r=i)}return r}},{\"./identity\":718,\"./loggers\":723,\"fast-isnumeric\":225}],739:[function(t,e,r){\"use strict\";e.exports=function(t,e){(t.attr(\"class\")||\"\").split(\" \").forEach(function(e){0===e.indexOf(\"cursor-\")&&t.classed(e,!1)}),e&&t.classed(\"cursor-\"+e,!0)}},{}],740:[function(t,e,r){\"use strict\";var n=t(\"../components/color\"),i=function(){};e.exports=function(t){for(var e in t)\"function\"==typeof t[e]&&(t[e]=i);t.destroy=function(){t.container.parentNode.removeChild(t.container)};var r=document.createElement(\"div\");r.className=\"no-webgl\",r.style.cursor=\"pointer\",r.style.fontSize=\"24px\",r.style.color=n.defaults[0],r.style.position=\"absolute\",r.style.left=r.style.top=\"0px\",r.style.width=r.style.height=\"100%\",r.style[\"background-color\"]=n.lightLine,r.style[\"z-index\"]=30;var a=document.createElement(\"p\");return a.textContent=\"WebGL is not supported by your browser - visit https://get.webgl.org for more info\",a.style.position=\"relative\",a.style.top=\"50%\",a.style.left=\"50%\",a.style.height=\"30%\",a.style.width=\"50%\",a.style.margin=\"-15% 0 0 -25%\",r.appendChild(a),t.container.appendChild(r),t.container.style.background=\"#FFFFFF\",t.container.onclick=function(){window.open(\"https://get.webgl.org\")},!1}},{\"../components/color\":593}],741:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;r.aggNums=function(t,e,a,o){var s,l;if((!o||o>a.length)&&(o=a.length),n(e)||(e=!1),i(a[0])){for(l=new Array(o),s=0;s<o;s++)l[s]=r.aggNums(t,e,a[s]);a=l}for(s=0;s<o;s++)n(e)?n(a[s])&&(e=t(+e,+a[s])):e=a[s];return e},r.len=function(t){return r.aggNums(function(t){return t+1},0,t)},r.mean=function(t,e){return e||(e=r.len(t)),r.aggNums(function(t,e){return t+e},0,t)/e},r.midRange=function(t){if(void 0!==t&&0!==t.length)return(r.aggNums(Math.max,null,t)+r.aggNums(Math.min,null,t))/2},r.variance=function(t,e,i){return e||(e=r.len(t)),n(i)||(i=r.mean(t,e)),r.aggNums(function(t,e){return t+Math.pow(e-i,2)},0,t)/e},r.stdev=function(t,e,n){return Math.sqrt(r.variance(t,e,n))},r.median=function(t){var e=t.slice().sort();return r.interp(e,.5)},r.interp=function(t,e){if(!n(e))throw\"n should be a finite number\";if((e=e*t.length-.5)<0)return t[0];if(e>t.length-1)return t[t.length-1];var r=e%1;return r*t[Math.ceil(e)]+(1-r)*t[Math.floor(e)]}},{\"./array\":702,\"fast-isnumeric\":225}],742:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\");e.exports=function(t){return t?n(t):[0,0,0,1]}},{\"color-normalize\":120}],743:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=t(\"../constants/xmlns_namespaces\"),o=t(\"../constants/alignment\").LINE_SPACING;function s(t,e){return t.node().getBoundingClientRect()[e]}var l=/([^$]*)([$]+[^$]*[$]+)([^$]*)/;r.convertToTspans=function(t,e,M){var S=t.text(),C=!t.attr(\"data-notex\")&&\"undefined\"!=typeof MathJax&&S.match(l),L=n.select(t.node().parentNode);if(!L.empty()){var P=t.attr(\"class\")?t.attr(\"class\").split(\" \")[0]:\"text\";return P+=\"-math\",L.selectAll(\"svg.\"+P).remove(),L.selectAll(\"g.\"+P+\"-group\").remove(),t.style(\"display\",null).attr({\"data-unformatted\":S,\"data-math\":\"N\"}),C?(e&&e._promises||[]).push(new Promise(function(e){t.style(\"display\",\"none\");var r=parseInt(t.node().style.fontSize,10),a={fontSize:r};!function(t,e,r){var a,o,s,l;MathJax.Hub.Queue(function(){return o=i.extendDeepAll({},MathJax.Hub.config),s=MathJax.Hub.processSectionDelay,void 0!==MathJax.Hub.processSectionDelay&&(MathJax.Hub.processSectionDelay=0),MathJax.Hub.Config({messageStyle:\"none\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]},displayAlign:\"left\"})},function(){if(\"SVG\"!==(a=MathJax.Hub.config.menuSettings.renderer))return MathJax.Hub.setRenderer(\"SVG\")},function(){var r=\"math-output-\"+i.randstr({},64);return l=n.select(\"body\").append(\"div\").attr({id:r}).style({visibility:\"hidden\",position:\"absolute\"}).style({\"font-size\":e.fontSize+\"px\"}).text(t.replace(c,\"\\\\lt \").replace(u,\"\\\\gt \")),MathJax.Hub.Typeset(l.node())},function(){var e=n.select(\"body\").select(\"#MathJax_SVG_glyphs\");if(l.select(\".MathJax_SVG\").empty()||!l.select(\"svg\").node())i.log(\"There was an error in the tex syntax.\",t),r();else{var o=l.select(\"svg\").node().getBoundingClientRect();r(l.select(\".MathJax_SVG\"),e,o)}if(l.remove(),\"SVG\"!==a)return MathJax.Hub.setRenderer(a)},function(){return void 0!==s&&(MathJax.Hub.processSectionDelay=s),MathJax.Hub.Config(o)})}(C[2],a,function(n,i,a){L.selectAll(\"svg.\"+P).remove(),L.selectAll(\"g.\"+P+\"-group\").remove();var o=n&&n.select(\"svg\");if(!o||!o.node())return O(),void e();var l=L.append(\"g\").classed(P+\"-group\",!0).attr({\"pointer-events\":\"none\",\"data-unformatted\":S,\"data-math\":\"Y\"});l.node().appendChild(o.node()),i&&i.node()&&o.node().insertBefore(i.node().cloneNode(!0),o.node().firstChild),o.attr({class:P,height:a.height,preserveAspectRatio:\"xMinYMin meet\"}).style({overflow:\"visible\",\"pointer-events\":\"none\"});var c=t.node().style.fill||\"black\",u=o.select(\"g\");u.attr({fill:c,stroke:c});var h=s(u,\"width\"),f=s(u,\"height\"),p=+t.attr(\"x\")-h*{start:0,middle:.5,end:1}[t.attr(\"text-anchor\")||\"start\"],d=-(r||s(t,\"height\"))/4;\"y\"===P[0]?(l.attr({transform:\"rotate(\"+[-90,+t.attr(\"x\"),+t.attr(\"y\")]+\") translate(\"+[-h/2,d-f/2]+\")\"}),o.attr({x:+t.attr(\"x\"),y:+t.attr(\"y\")})):\"l\"===P[0]?o.attr({x:t.attr(\"x\"),y:d-f/2}):\"a\"===P[0]&&0!==P.indexOf(\"atitle\")?o.attr({x:0,y:d}):o.attr({x:p,y:+t.attr(\"y\")+d-f/2}),M&&M.call(t,l),e(l)})})):O(),t}function O(){L.empty()||(P=t.attr(\"class\")+\"-math\",L.select(\"svg.\"+P).remove()),t.text(\"\").style(\"white-space\",\"pre\"),function(t,e){e=e.replace(v,\" \");var r,s=!1,l=[],c=-1;function u(){c++;var e=document.createElementNS(a.svg,\"tspan\");n.select(e).attr({class:\"line\",dy:c*o+\"em\"}),t.appendChild(e),r=e;var i=l;if(l=[{node:e}],i.length>1)for(var s=1;s<i.length;s++)M(i[s])}function M(t){var e,i=t.type,o={};if(\"a\"===i){e=\"a\";var s=t.target,c=t.href,u=t.popup;c&&(o={\"xlink:xlink:show\":\"_blank\"===s||\"_\"!==s.charAt(0)?\"new\":\"replace\",target:s,\"xlink:xlink:href\":c},u&&(o.onclick='window.open(this.href.baseVal,this.target.baseVal,\"'+u+'\");return false;'))}else e=\"tspan\";t.style&&(o.style=t.style);var h=document.createElementNS(a.svg,e);if(\"sup\"===i||\"sub\"===i){S(r,d),r.appendChild(h);var g=document.createElementNS(a.svg,\"tspan\");S(g,d),n.select(g).attr(\"dy\",p[i]),o.dy=f[i],r.appendChild(h),r.appendChild(g)}else r.appendChild(h);n.select(h).attr(o),r=t.node=h,l.push(t)}function S(t,e){t.appendChild(document.createTextNode(e))}function C(t){if(1!==l.length){var n=l.pop();t!==n.type&&i.log(\"Start tag <\"+n.type+\"> doesnt match end tag <\"+t+\">. Pretending it did match.\",e),r=l[l.length-1].node}else i.log(\"Ignoring unexpected end tag </\"+t+\">.\",e)}x.test(e)?u():(r=t,l=[{node:t}]);for(var L=e.split(m),P=0;P<L.length;P++){var O=L[P],z=O.match(y),I=z&&z[2].toLowerCase(),D=h[I];if(\"br\"===I)u();else if(void 0===D)S(r,E(O));else if(z[1])C(I);else{var R=z[4],F={type:I},B=T(R,b);if(B?(B=B.replace(A,\"$1 fill:\"),D&&(B+=\";\"+D)):D&&(B=D),B&&(F.style=B),\"a\"===I){s=!0;var N=T(R,_);if(N){var j=document.createElement(\"a\");j.href=N,-1!==g.indexOf(j.protocol)&&(F.href=encodeURI(decodeURI(N)),F.target=T(R,w)||\"_blank\",F.popup=T(R,k))}}M(F)}}return s}(t.node(),S)&&t.style(\"pointer-events\",\"all\"),r.positionText(t),M&&M.call(t)}};var c=/(<|&lt;|&#60;)/g,u=/(>|&gt;|&#62;)/g;var h={sup:\"font-size:70%\",sub:\"font-size:70%\",b:\"font-weight:bold\",i:\"font-style:italic\",a:\"cursor:pointer\",span:\"\",em:\"font-style:italic;font-weight:bold\"},f={sub:\"0.3em\",sup:\"-0.6em\"},p={sub:\"-0.21em\",sup:\"0.42em\"},d=\"\\u200b\",g=[\"http:\",\"https:\",\"mailto:\",\"\",void 0,\":\"],v=/(\\r\\n?|\\n)/g,m=/(<[^<>]*>)/,y=/<(\\/?)([^ >]*)(\\s+(.*))?>/i,x=/<br(\\s+.*)?>/i,b=/(^|[\\s\"'])style\\s*=\\s*(\"([^\"]*);?\"|'([^']*);?')/i,_=/(^|[\\s\"'])href\\s*=\\s*(\"([^\"]*)\"|'([^']*)')/i,w=/(^|[\\s\"'])target\\s*=\\s*(\"([^\"\\s]*)\"|'([^'\\s]*)')/i,k=/(^|[\\s\"'])popup\\s*=\\s*(\"([\\w=,]*)\"|'([\\w=,]*)')/i;function T(t,e){if(!t)return null;var r=t.match(e),n=r&&(r[3]||r[4]);return n&&E(n)}var A=/(^|;)\\s*color:/;r.plainText=function(t,e){for(var r=void 0!==(e=e||{}).len&&-1!==e.len?e.len:1/0,n=void 0!==e.allowedTags?e.allowedTags:[\"br\"],i=\"...\".length,a=t.split(m),o=[],s=\"\",l=0,c=0;c<a.length;c++){var u=a[c],h=u.match(y),f=h&&h[2].toLowerCase();if(f)-1!==n.indexOf(f)&&(o.push(u),s=f);else{var p=u.length;if(l+p<r)o.push(u),l+=p;else if(l<r){var d=r-l;s&&(\"br\"!==s||d<=i||p<=i)&&o.pop(),r>i?o.push(u.substr(0,d-i)+\"...\"):o.push(u.substr(0,d));break}s=\"\"}}return o.join(\"\")};var M={mu:\"\\u03bc\",amp:\"&\",lt:\"<\",gt:\">\",nbsp:\"\\xa0\",times:\"\\xd7\",plusmn:\"\\xb1\",deg:\"\\xb0\"},S=/&(#\\d+|#x[\\da-fA-F]+|[a-z]+);/g;function E(t){return t.replace(S,function(t,e){return(\"#\"===e.charAt(0)?function(t){if(t>1114111)return;var e=String.fromCodePoint;if(e)return e(t);var r=String.fromCharCode;return t<=65535?r(t):r(55232+(t>>10),t%1024+56320)}(\"x\"===e.charAt(1)?parseInt(e.substr(2),16):parseInt(e.substr(1),10)):M[e])||t})}function C(t,e,r){var n,i,a,o=r.horizontalAlign,s=r.verticalAlign||\"top\",l=t.node().getBoundingClientRect(),c=e.node().getBoundingClientRect();return i=\"bottom\"===s?function(){return l.bottom-n.height}:\"middle\"===s?function(){return l.top+(l.height-n.height)/2}:function(){return l.top},a=\"right\"===o?function(){return l.right-n.width}:\"center\"===o?function(){return l.left+(l.width-n.width)/2}:function(){return l.left},function(){return n=this.node().getBoundingClientRect(),this.style({top:i()-c.top+\"px\",left:a()-c.left+\"px\",\"z-index\":1e3}),this}}r.convertEntities=E,r.lineCount=function(t){return t.selectAll(\"tspan.line\").size()||1},r.positionText=function(t,e,r){return t.each(function(){var t=n.select(this);function i(e,r){return void 0===r?null===(r=t.attr(e))&&(t.attr(e,0),r=0):t.attr(e,r),r}var a=i(\"x\",e),o=i(\"y\",r);\"text\"===this.nodeName&&t.selectAll(\"tspan.line\").attr({x:a,y:o})})},r.makeEditable=function(t,e){var r=e.gd,i=e.delegate,a=n.dispatch(\"edit\",\"input\",\"cancel\"),o=i||t;if(t.style({\"pointer-events\":i?\"none\":\"all\"}),1!==t.size())throw new Error(\"boo\");function s(){!function(){var i=n.select(r).select(\".svg-container\"),o=i.append(\"div\"),s=t.node().style,c=parseFloat(s.fontSize||12),u=e.text;void 0===u&&(u=t.attr(\"data-unformatted\"));o.classed(\"plugin-editable editable\",!0).style({position:\"absolute\",\"font-family\":s.fontFamily||\"Arial\",\"font-size\":c,color:e.fill||s.fill||\"black\",opacity:1,\"background-color\":e.background||\"transparent\",outline:\"#ffffff33 1px solid\",margin:[-c/8+1,0,0,-1].join(\"px \")+\"px\",padding:\"0\",\"box-sizing\":\"border-box\"}).attr({contenteditable:!0}).text(u).call(C(t,i,e)).on(\"blur\",function(){r._editing=!1,t.text(this.textContent).style({opacity:1});var e,i=n.select(this).attr(\"class\");(e=i?\".\"+i.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(e).style({opacity:0});var o=this.textContent;n.select(this).transition().duration(0).remove(),n.select(document).on(\"mouseup\",null),a.edit.call(t,o)}).on(\"focus\",function(){var t=this;r._editing=!0,n.select(document).on(\"mouseup\",function(){if(n.event.target===t)return!1;document.activeElement===o.node()&&o.node().blur()})}).on(\"keyup\",function(){27===n.event.which?(r._editing=!1,t.style({opacity:1}),n.select(this).style({opacity:0}).on(\"blur\",function(){return!1}).transition().remove(),a.cancel.call(t,this.textContent)):(a.input.call(t,this.textContent),n.select(this).call(C(t,i,e)))}).on(\"keydown\",function(){13===n.event.which&&this.blur()}).call(l)}(),t.style({opacity:0});var i,s=o.attr(\"class\");(i=s?\".\"+s.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(i).style({opacity:0})}function l(t){var e=t.node(),r=document.createRange();r.selectNodeContents(e);var n=window.getSelection();n.removeAllRanges(),n.addRange(r),e.focus()}return e.immediate?s():o.on(\"click\",s),n.rebind(t,a,\"on\")}},{\"../constants/alignment\":688,\"../constants/xmlns_namespaces\":696,\"../lib\":719,d3:163}],744:[function(t,e,r){\"use strict\";var n={};function i(t){t&&null!==t.timer&&(clearTimeout(t.timer),t.timer=null)}r.throttle=function(t,e,r){var a=n[t],o=Date.now();if(!a){for(var s in n)n[s].ts<o-6e4&&delete n[s];a=n[t]={ts:0,timer:null}}function l(){r(),a.ts=Date.now(),a.onDone&&(a.onDone(),a.onDone=null)}i(a),o>a.ts+e?l():a.timer=setTimeout(function(){l(),a.timer=null},e)},r.done=function(t){var e=n[t];return e&&e.timer?new Promise(function(t){var r=e.onDone;e.onDone=function(){r&&r(),t(),e.onDone=null}}):Promise.resolve()},r.clear=function(t){if(t)i(n[t]),delete n[t];else for(var e in n)r.clear(e)}},{}],745:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t,e){if(t>0)return Math.log(t)/Math.LN10;var r=Math.log(Math.min(e[0],e[1]))/Math.LN10;return n(r)||(r=Math.log(Math.max(e[0],e[1]))/Math.LN10-6),r}},{\"fast-isnumeric\":225}],746:[function(t,e,r){\"use strict\";var n=e.exports={},i=t(\"../plots/geo/constants\").locationmodeToLayer,a=t(\"topojson-client\").feature;n.getTopojsonName=function(t){return[t.scope.replace(/ /g,\"-\"),\"_\",t.resolution.toString(),\"m\"].join(\"\")},n.getTopojsonPath=function(t,e){return t+e+\".json\"},n.getTopojsonFeatures=function(t,e){var r=i[t.locationmode],n=e.objects[r];return a(e,n).features}},{\"../plots/geo/constants\":795,\"topojson-client\":540}],747:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en-US\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colorscale title\"},format:{date:\"%m/%d/%Y\"}}},{}],748:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colourscale title\"},format:{days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],periods:[\"AM\",\"PM\"],dateTime:\"%a %b %e %X %Y\",date:\"%d/%m/%Y\",time:\"%H:%M:%S\",decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],year:\"%Y\",month:\"%b %Y\",dayMonth:\"%b %-d\",dayMonthYear:\"%b %-d, %Y\"}}},{}],749:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t){for(var e,r,i=n.layoutArrayContainers,a=n.layoutArrayRegexes,o=t.split(\"[\")[0],s=0;s<a.length;s++)if((r=t.match(a[s]))&&0===r.index){e=r[0];break}if(e||(e=i[i.indexOf(o)]),!e)return!1;var l=t.substr(e.length);return l?!!(r=l.match(/^\\[(0|[1-9][0-9]*)\\](\\.(.+))?$/))&&{array:e,index:Number(r[1]),property:r[3]||\"\"}:{array:e,index:\"\",property:\"\"}}},{\"../registry\":847}],750:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.extendFlat,a=n.isPlainObject,o={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"clearAxisTypes\",\"plot\",\"style\",\"markerSize\",\"colorbars\"]},s={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"plot\",\"legend\",\"ticks\",\"axrange\",\"layoutstyle\",\"modebar\",\"camera\",\"arraydraw\",\"colorbars\"]},l=o.flags.slice().concat([\"fullReplot\"]),c=s.flags.slice().concat(\"layoutReplot\");function u(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=!1;return e}function h(t,e,r){var n=i({},t);for(var o in n){var s=n[o];a(s)&&(n[o]=f(s,e,r,o))}return\"from-root\"===r&&(n.editType=e),n}function f(t,e,r,n){if(t.valType){var a=i({},t);if(a.editType=e,Array.isArray(t.items)){a.items=new Array(t.items.length);for(var o=0;o<t.items.length;o++)a.items[o]=f(t.items[o],e,\"from-root\")}return a}return h(t,e,\"_\"===n.charAt(0)?\"nested\":\"from-root\")}e.exports={traces:o,layout:s,traceFlags:function(){return u(l)},layoutFlags:function(){return u(c)},update:function(t,e){var r=e.editType;if(r&&\"none\"!==r)for(var n=r.split(\"+\"),i=0;i<n.length;i++)t[n[i]]=!0},overrideAll:h}},{\"../lib\":719}],751:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"gl-mat4/fromQuat\"),a=t(\"../registry\"),o=t(\"../lib\"),s=t(\"../plots/plots\"),l=t(\"../plots/cartesian/axis_ids\"),c=t(\"../components/color\"),u=l.cleanId,h=l.getFromTrace,f=a.traceIs;function p(t,e){var r=t[e],n=e.charAt(0);r&&\"paper\"!==r&&(t[e]=u(r,n))}function d(t){function e(e,r){var n=t[e],i=t.title&&t.title[r];n&&!i&&(t.title||(t.title={}),t.title[r]=t[e],delete t[e])}t&&(\"string\"!=typeof t.title&&\"number\"!=typeof t.title||(t.title={text:t.title}),e(\"titlefont\",\"font\"),e(\"titleposition\",\"position\"),e(\"titleside\",\"side\"),e(\"titleoffset\",\"offset\"))}function g(t){if(!o.isPlainObject(t))return!1;var e=t.name;return delete t.name,delete t.showlegend,(\"string\"==typeof e||\"number\"==typeof e)&&String(e)}function v(t,e,r,n){if(r&&!n)return t;if(n&&!r)return e;if(!t.trim())return e;if(!e.trim())return t;var i,a=Math.min(t.length,e.length);for(i=0;i<a&&t.charAt(i)===e.charAt(i);i++);return t.substr(0,i).trim()}function m(t){var e=\"middle\",r=\"center\";return\"string\"==typeof t&&(-1!==t.indexOf(\"top\")?e=\"top\":-1!==t.indexOf(\"bottom\")&&(e=\"bottom\"),-1!==t.indexOf(\"left\")?r=\"left\":-1!==t.indexOf(\"right\")&&(r=\"right\")),e+\" \"+r}function y(t,e){return e in t&&\"object\"==typeof t[e]&&0===Object.keys(t[e]).length}r.clearPromiseQueue=function(t){Array.isArray(t._promises)&&t._promises.length>0&&o.log(\"Clearing previous rejected promises from queue.\"),t._promises=[]},r.cleanLayout=function(t){var e,n;t||(t={}),t.xaxis1&&(t.xaxis||(t.xaxis=t.xaxis1),delete t.xaxis1),t.yaxis1&&(t.yaxis||(t.yaxis=t.yaxis1),delete t.yaxis1),t.scene1&&(t.scene||(t.scene=t.scene1),delete t.scene1);var a=(s.subplotsRegistry.cartesian||{}).attrRegex,l=(s.subplotsRegistry.polar||{}).attrRegex,h=(s.subplotsRegistry.ternary||{}).attrRegex,f=(s.subplotsRegistry.gl3d||{}).attrRegex,g=Object.keys(t);for(e=0;e<g.length;e++){var v=g[e];if(a&&a.test(v)){var m=t[v];m.anchor&&\"free\"!==m.anchor&&(m.anchor=u(m.anchor)),m.overlaying&&(m.overlaying=u(m.overlaying)),m.type||(m.isdate?m.type=\"date\":m.islog?m.type=\"log\":!1===m.isdate&&!1===m.islog&&(m.type=\"linear\")),\"withzero\"!==m.autorange&&\"tozero\"!==m.autorange||(m.autorange=!0,m.rangemode=\"tozero\"),delete m.islog,delete m.isdate,delete m.categories,y(m,\"domain\")&&delete m.domain,void 0!==m.autotick&&(void 0===m.tickmode&&(m.tickmode=m.autotick?\"auto\":\"linear\"),delete m.autotick),d(m)}else if(l&&l.test(v)){d(t[v].radialaxis)}else if(h&&h.test(v)){var x=t[v];d(x.aaxis),d(x.baxis),d(x.caxis)}else if(f&&f.test(v)){var b=t[v],_=b.cameraposition;if(Array.isArray(_)&&4===_[0].length){var w=_[0],k=_[1],T=_[2],A=i([],w),M=[];for(n=0;n<3;++n)M[n]=k[n]+T*A[2+4*n];b.camera={eye:{x:M[0],y:M[1],z:M[2]},center:{x:k[0],y:k[1],z:k[2]},up:{x:0,y:0,z:1}},delete b.cameraposition}d(b.xaxis),d(b.yaxis),d(b.zaxis)}}var S=Array.isArray(t.annotations)?t.annotations.length:0;for(e=0;e<S;e++){var E=t.annotations[e];o.isPlainObject(E)&&(E.ref&&(\"paper\"===E.ref?(E.xref=\"paper\",E.yref=\"paper\"):\"data\"===E.ref&&(E.xref=\"x\",E.yref=\"y\"),delete E.ref),p(E,\"xref\"),p(E,\"yref\"))}var C=Array.isArray(t.shapes)?t.shapes.length:0;for(e=0;e<C;e++){var L=t.shapes[e];o.isPlainObject(L)&&(p(L,\"xref\"),p(L,\"yref\"))}var P=t.legend;return P&&(P.x>3?(P.x=1.02,P.xanchor=\"left\"):P.x<-2&&(P.x=-.02,P.xanchor=\"right\"),P.y>3?(P.y=1.02,P.yanchor=\"bottom\"):P.y<-2&&(P.y=-.02,P.yanchor=\"top\")),d(t),\"rotate\"===t.dragmode&&(t.dragmode=\"orbit\"),c.clean(t),t.template&&t.template.layout&&r.cleanLayout(t.template.layout),t},r.cleanData=function(t){for(var e=0;e<t.length;e++){var n,i=t[e];if(\"histogramy\"===i.type&&\"xbins\"in i&&!(\"ybins\"in i)&&(i.ybins=i.xbins,delete i.xbins),i.error_y&&\"opacity\"in i.error_y){var l=c.defaults,h=i.error_y.color||(f(i,\"bar\")?c.defaultLine:l[e%l.length]);i.error_y.color=c.addOpacity(c.rgb(h),c.opacity(h)*i.error_y.opacity),delete i.error_y.opacity}if(\"bardir\"in i&&(\"h\"!==i.bardir||!f(i,\"bar\")&&\"histogram\"!==i.type.substr(0,9)||(i.orientation=\"h\",r.swapXYData(i)),delete i.bardir),\"histogramy\"===i.type&&r.swapXYData(i),\"histogramx\"!==i.type&&\"histogramy\"!==i.type||(i.type=\"histogram\"),\"scl\"in i&&!(\"colorscale\"in i)&&(i.colorscale=i.scl,delete i.scl),\"reversescl\"in i&&!(\"reversescale\"in i)&&(i.reversescale=i.reversescl,delete i.reversescl),i.xaxis&&(i.xaxis=u(i.xaxis,\"x\")),i.yaxis&&(i.yaxis=u(i.yaxis,\"y\")),f(i,\"gl3d\")&&i.scene&&(i.scene=s.subplotsRegistry.gl3d.cleanId(i.scene)),!f(i,\"pie-like\")&&!f(i,\"bar-like\"))if(Array.isArray(i.textposition))for(n=0;n<i.textposition.length;n++)i.textposition[n]=m(i.textposition[n]);else i.textposition&&(i.textposition=m(i.textposition));var p=a.getModule(i);if(p&&p.colorbar){var x=p.colorbar.container,b=x?i[x]:i;b&&b.colorscale&&(\"YIGnBu\"===b.colorscale&&(b.colorscale=\"YlGnBu\"),\"YIOrRd\"===b.colorscale&&(b.colorscale=\"YlOrRd\"))}if(\"surface\"===i.type&&o.isPlainObject(i.contours)){var _=[\"x\",\"y\",\"z\"];for(n=0;n<_.length;n++){var w=i.contours[_[n]];o.isPlainObject(w)&&(w.highlightColor&&(w.highlightcolor=w.highlightColor,delete w.highlightColor),w.highlightWidth&&(w.highlightwidth=w.highlightWidth,delete w.highlightWidth))}}if(\"candlestick\"===i.type||\"ohlc\"===i.type){var k=!1!==(i.increasing||{}).showlegend,T=!1!==(i.decreasing||{}).showlegend,A=g(i.increasing),M=g(i.decreasing);if(!1!==A&&!1!==M){var S=v(A,M,k,T);S&&(i.name=S)}else!A&&!M||i.name||(i.name=A||M)}if(Array.isArray(i.transforms)){var E=i.transforms;for(n=0;n<E.length;n++){var C=E[n];if(o.isPlainObject(C))switch(C.type){case\"filter\":C.filtersrc&&(C.target=C.filtersrc,delete C.filtersrc),C.calendar&&(C.valuecalendar||(C.valuecalendar=C.calendar),delete C.calendar);break;case\"groupby\":if(C.styles=C.styles||C.style,C.styles&&!Array.isArray(C.styles)){var L=C.styles,P=Object.keys(L);C.styles=[];for(var O=0;O<P.length;O++)C.styles.push({target:P[O],value:L[P[O]]})}}}}y(i,\"line\")&&delete i.line,\"marker\"in i&&(y(i.marker,\"line\")&&delete i.marker.line,y(i,\"marker\")&&delete i.marker),c.clean(i),i.autobinx&&(delete i.autobinx,delete i.xbins),i.autobiny&&(delete i.autobiny,delete i.ybins),d(i),i.colorbar&&d(i.colorbar),i.marker&&i.marker.colorbar&&d(i.marker.colorbar),i.line&&i.line.colorbar&&d(i.line.colorbar),i.aaxis&&d(i.aaxis),i.baxis&&d(i.baxis)}},r.swapXYData=function(t){var e;if(o.swapAttrs(t,[\"?\",\"?0\",\"d?\",\"?bins\",\"nbins?\",\"autobin?\",\"?src\",\"error_?\"]),Array.isArray(t.z)&&Array.isArray(t.z[0])&&(t.transpose?delete t.transpose:t.transpose=!0),t.error_x&&t.error_y){var r=t.error_y,n=\"copy_ystyle\"in r?r.copy_ystyle:!(r.color||r.thickness||r.width);o.swapAttrs(t,[\"error_?.copy_ystyle\"]),n&&o.swapAttrs(t,[\"error_?.color\",\"error_?.thickness\",\"error_?.width\"])}if(\"string\"==typeof t.hoverinfo){var i=t.hoverinfo.split(\"+\");for(e=0;e<i.length;e++)\"x\"===i[e]?i[e]=\"y\":\"y\"===i[e]&&(i[e]=\"x\");t.hoverinfo=i.join(\"+\")}},r.coerceTraceIndices=function(t,e){if(n(e))return[e];if(!Array.isArray(e)||!e.length)return t.data.map(function(t,e){return e});if(Array.isArray(e)){for(var r=[],i=0;i<e.length;i++)o.isIndex(e[i],t.data.length)?r.push(e[i]):o.warn(\"trace index (\",e[i],\") is not a number or is out of bounds\");return r}return e},r.manageArrayContainers=function(t,e,r){var i=t.obj,a=t.parts,s=a.length,l=a[s-1],c=n(l);if(c&&null===e){var u=a.slice(0,s-1).join(\".\");o.nestedProperty(i,u).get().splice(l,1)}else c&&void 0===t.get()?(void 0===t.get()&&(r[t.astr]=null),t.set(e)):t.set(e)};var x=/(\\.[^\\[\\]\\.]+|\\[[^\\[\\]\\.]+\\])$/;function b(t){var e=t.search(x);if(e>0)return t.substr(0,e)}r.hasParent=function(t,e){for(var r=b(e);r;){if(r in t)return!0;r=b(r)}return!1};var _=[\"x\",\"y\",\"z\"];r.clearAxisTypes=function(t,e,r){for(var n=0;n<e.length;n++)for(var i=t._fullData[n],a=0;a<3;a++){var s=h(t,i,_[a]);if(s&&\"log\"!==s.type){var l=s._name,c=s._id.substr(1);if(\"scene\"===c.substr(0,5)){if(void 0!==r[c])continue;l=c+\".\"+l}var u=l+\".type\";void 0===r[l]&&void 0===r[u]&&o.nestedProperty(t.layout,u).set(null)}}}},{\"../components/color\":593,\"../lib\":719,\"../plots/cartesian/axis_ids\":770,\"../plots/plots\":828,\"../registry\":847,\"fast-isnumeric\":225,\"gl-mat4/fromQuat\":262}],752:[function(t,e,r){\"use strict\";var n=t(\"./plot_api\");r.plot=n.plot,r.newPlot=n.newPlot,r.restyle=n.restyle,r.relayout=n.relayout,r.redraw=n.redraw,r.update=n.update,r._guiRestyle=n._guiRestyle,r._guiRelayout=n._guiRelayout,r._guiUpdate=n._guiUpdate,r._storeDirectGUIEdit=n._storeDirectGUIEdit,r.react=n.react,r.extendTraces=n.extendTraces,r.prependTraces=n.prependTraces,r.addTraces=n.addTraces,r.deleteTraces=n.deleteTraces,r.moveTraces=n.moveTraces,r.purge=n.purge,r.addFrames=n.addFrames,r.deleteFrames=n.deleteFrames,r.animate=n.animate,r.setPlotConfig=n.setPlotConfig,r.toImage=t(\"./to_image\"),r.validate=t(\"./validate\"),r.downloadImage=t(\"../snapshot/download\");var i=t(\"./template_api\");r.makeTemplate=i.makeTemplate,r.validateTemplate=i.validateTemplate},{\"../snapshot/download\":849,\"./plot_api\":754,\"./template_api\":759,\"./to_image\":760,\"./validate\":761}],753:[function(t,e,r){\"use strict\";var n=t(\"../lib/is_plain_object\"),i=t(\"../lib/noop\"),a=t(\"../lib/loggers\"),o=t(\"../lib/search\").sorterAsc,s=t(\"../registry\");r.containerArrayMatch=t(\"./container_array_match\");var l=r.isAddVal=function(t){return\"add\"===t||n(t)},c=r.isRemoveVal=function(t){return null===t||\"remove\"===t};r.applyContainerArrayChanges=function(t,e,r,n,u){var h=e.astr,f=s.getComponentMethod(h,\"supplyLayoutDefaults\"),p=s.getComponentMethod(h,\"draw\"),d=s.getComponentMethod(h,\"drawOne\"),g=n.replot||n.recalc||f===i||p===i,v=t.layout,m=t._fullLayout;if(r[\"\"]){Object.keys(r).length>1&&a.warn(\"Full array edits are incompatible with other edits\",h);var y=r[\"\"][\"\"];if(c(y))e.set(null);else{if(!Array.isArray(y))return a.warn(\"Unrecognized full array edit value\",h,y),!0;e.set(y)}return!g&&(f(v,m),p(t),!0)}var x,b,_,w,k,T,A,M,S=Object.keys(r).map(Number).sort(o),E=e.get(),C=E||[],L=u(m,h).get(),P=[],O=-1,z=C.length;for(x=0;x<S.length;x++)if(w=r[_=S[x]],k=Object.keys(w),T=w[\"\"],A=l(T),_<0||_>C.length-(A?0:1))a.warn(\"index out of range\",h,_);else if(void 0!==T)k.length>1&&a.warn(\"Insertion & removal are incompatible with edits to the same index.\",h,_),c(T)?P.push(_):A?(\"add\"===T&&(T={}),C.splice(_,0,T),L&&L.splice(_,0,{})):a.warn(\"Unrecognized full object edit value\",h,_,T),-1===O&&(O=_);else for(b=0;b<k.length;b++)M=h+\"[\"+_+\"].\",u(C[_],k[b],M).set(w[k[b]]);for(x=P.length-1;x>=0;x--)C.splice(P[x],1),L&&L.splice(P[x],1);if(C.length?E||e.set(C):e.set(null),g)return!1;if(f(v,m),d!==i){var I;if(-1===O)I=S;else{for(z=Math.max(C.length,z),I=[],x=0;x<S.length&&!((_=S[x])>=O);x++)I.push(_);for(x=O;x<z;x++)I.push(x)}for(x=0;x<I.length;x++)d(t,I[x])}else p(t);return!0}},{\"../lib/is_plain_object\":720,\"../lib/loggers\":723,\"../lib/noop\":728,\"../lib/search\":738,\"../registry\":847,\"./container_array_match\":749}],754:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"has-hover\"),o=t(\"../lib\"),s=o.nestedProperty,l=t(\"../lib/events\"),c=t(\"../lib/queue\"),u=t(\"../registry\"),h=t(\"./plot_schema\"),f=t(\"../plots/plots\"),p=t(\"../plots/polar/legacy\"),d=t(\"../plots/cartesian/axes\"),g=t(\"../components/drawing\"),v=t(\"../components/color\"),m=t(\"../plots/cartesian/graph_interact\").initInteractions,y=t(\"../constants/xmlns_namespaces\"),x=t(\"../lib/svg_text_utils\"),b=t(\"../plots/cartesian/select\").clearSelect,_=t(\"./plot_config\").dfltConfig,w=t(\"./manage_arrays\"),k=t(\"./helpers\"),T=t(\"./subroutines\"),A=t(\"./edit_types\"),M=t(\"../plots/cartesian/constants\").AX_NAME_PATTERN,S=0,E=5;function C(t){var e=t._fullLayout;e._redrawFromAutoMarginCount?e._redrawFromAutoMarginCount--:t.emit(\"plotly_afterplot\")}function L(t,e){try{t._fullLayout._paper.style(\"background\",e)}catch(t){o.error(t)}}function P(t,e){L(t,v.combine(e,\"white\"))}function O(t,e){if(!t._context){t._context=o.extendDeep({},_);var r=n.select(\"base\");t._context._baseUrl=r.size()&&r.attr(\"href\")?window.location.href.split(\"#\")[0]:\"\"}var i,s,l,c=t._context;if(e){for(s=Object.keys(e),i=0;i<s.length;i++)\"editable\"!==(l=s[i])&&\"edits\"!==l&&l in c&&(\"setBackground\"===l&&\"opaque\"===e[l]?c[l]=P:c[l]=e[l]);e.plot3dPixelRatio&&!c.plotGlPixelRatio&&(c.plotGlPixelRatio=c.plot3dPixelRatio);var u=e.editable;if(void 0!==u)for(c.editable=u,s=Object.keys(c.edits),i=0;i<s.length;i++)c.edits[s[i]]=u;if(e.edits)for(s=Object.keys(e.edits),i=0;i<s.length;i++)(l=s[i])in c.edits&&(c.edits[l]=e.edits[l]);c._exportedPlot=e._exportedPlot}c.staticPlot&&(c.editable=!1,c.edits={},c.autosizable=!1,c.scrollZoom=!1,c.doubleClick=!1,c.showTips=!1,c.showLink=!1,c.displayModeBar=!1),\"hover\"!==c.displayModeBar||a||(c.displayModeBar=!0),\"transparent\"!==c.setBackground&&\"function\"==typeof c.setBackground||(c.setBackground=L),c._hasZeroHeight=c._hasZeroHeight||0===t.clientHeight,c._hasZeroWidth=c._hasZeroWidth||0===t.clientWidth;var h=c.scrollZoom,f=c._scrollZoom={};if(!0===h)f.cartesian=1,f.gl3d=1,f.geo=1,f.mapbox=1;else if(\"string\"==typeof h){var p=h.split(\"+\");for(i=0;i<p.length;i++)f[p[i]]=1}else!1!==h&&(f.gl3d=1,f.geo=1,f.mapbox=1)}function z(t,e){var r,n,i=e+1,a=[];for(r=0;r<t.length;r++)(n=t[r])<0?a.push(i+n):a.push(n);return a}function I(t,e,r){var n,i;for(n=0;n<e.length;n++){if((i=e[n])!==parseInt(i,10))throw new Error(\"all values in \"+r+\" must be integers\");if(i>=t.data.length||i<-t.data.length)throw new Error(r+\" must be valid indices for gd.data.\");if(e.indexOf(i,n+1)>-1||i>=0&&e.indexOf(-t.data.length+i)>-1||i<0&&e.indexOf(t.data.length+i)>-1)throw new Error(\"each index in \"+r+\" must be unique.\")}}function D(t,e,r){if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"currentIndices is a required argument.\");if(Array.isArray(e)||(e=[e]),I(t,e,\"currentIndices\"),\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&I(t,r,\"newIndices\"),\"undefined\"!=typeof r&&e.length!==r.length)throw new Error(\"current and new indices must be of equal length.\")}function R(t,e,r,n,a){!function(t,e,r,n){var i=o.isPlainObject(n);if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array\");if(!o.isPlainObject(e))throw new Error(\"update must be a key:value object\");if(\"undefined\"==typeof r)throw new Error(\"indices must be an integer or array of integers\");for(var a in I(t,r,\"indices\"),e){if(!Array.isArray(e[a])||e[a].length!==r.length)throw new Error(\"attribute \"+a+\" must be an array of length equal to indices array length\");if(i&&(!(a in n)||!Array.isArray(n[a])||n[a].length!==e[a].length))throw new Error(\"when maxPoints is set as a key:value object it must contain a 1:1 corrispondence with the keys and number of traces in the update object\")}}(t,e,r,n);for(var l=function(t,e,r,n){var a,l,c,u,h,f=o.isPlainObject(n),p=[];for(var d in Array.isArray(r)||(r=[r]),r=z(r,t.data.length-1),e)for(var g=0;g<r.length;g++){if(a=t.data[r[g]],l=(c=s(a,d)).get(),u=e[d][g],!o.isArrayOrTypedArray(u))throw new Error(\"attribute: \"+d+\" index: \"+g+\" must be an array\");if(!o.isArrayOrTypedArray(l))throw new Error(\"cannot extend missing or non-array attribute: \"+d);if(l.constructor!==u.constructor)throw new Error(\"cannot extend array with an array of a different type: \"+d);h=f?n[d][g]:n,i(h)||(h=-1),p.push({prop:c,target:l,insert:u,maxp:Math.floor(h)})}return p}(t,e,r,n),c={},u={},h=0;h<l.length;h++){var f=l[h].prop,p=l[h].maxp,d=a(l[h].target,l[h].insert,p);f.set(d[0]),Array.isArray(c[f.astr])||(c[f.astr]=[]),c[f.astr].push(d[1]),Array.isArray(u[f.astr])||(u[f.astr]=[]),u[f.astr].push(l[h].target.length)}return{update:c,maxPoints:u}}function F(t,e){var r=new t.constructor(t.length+e.length);return r.set(t),r.set(e,t.length),r}function B(t,e,n,i){t=o.getGraphDiv(t),k.clearPromiseQueue(t);var a={};if(\"string\"==typeof e)a[e]=n;else{if(!o.isPlainObject(e))return o.warn(\"Restyle fail.\",e,n,i),Promise.reject();a=o.extendFlat({},e),void 0===i&&(i=n)}Object.keys(a).length&&(t.changed=!0);var s=k.coerceTraceIndices(t,i),l=V(t,a,s),u=l.flags;u.calc&&(t.calcdata=void 0),u.clearAxisTypes&&k.clearAxisTypes(t,s,{});var h=[];u.fullReplot?h.push(r.plot):(h.push(f.previousPromises),f.supplyDefaults(t),u.markerSize&&(f.doCalcdata(t),Y(h)),u.style&&h.push(T.doTraceStyle),u.colorbars&&h.push(T.doColorBars),h.push(C)),h.push(f.rehover,f.redrag),c.add(t,B,[t,l.undoit,l.traces],B,[t,l.redoit,l.traces]);var p=o.syncOrAsync(h,t);return p&&p.then||(p=Promise.resolve()),p.then(function(){return t.emit(\"plotly_restyle\",l.eventData),t})}function N(t){return void 0===t?null:t}function j(t,e){return e?function(e,r,n){var i=s(e,r),a=i.set;return i.set=function(e){U((n||\"\")+r,i.get(),e,t),a(e)},i}:s}function U(t,e,r,n){if(Array.isArray(e)||Array.isArray(r))for(var i=Array.isArray(e)?e:[],a=Array.isArray(r)?r:[],s=Math.max(i.length,a.length),l=0;l<s;l++)U(t+\"[\"+l+\"]\",i[l],a[l],n);else if(o.isPlainObject(e)||o.isPlainObject(r)){var c=o.isPlainObject(e)?e:{},u=o.isPlainObject(r)?r:{},h=o.extendFlat({},c,u);for(var f in h)U(t+\".\"+f,c[f],u[f],n)}else void 0===n[t]&&(n[t]=N(e))}function V(t,e,r){var n,i=t._fullLayout,a=t._fullData,l=t.data,c=i._guiEditing,p=j(i._preGUI,c),g=o.extendDeepAll({},e);q(e);var v,m=A.traceFlags(),y={},x={};function b(){return r.map(function(){})}function _(t){var e=d.id2name(t);-1===v.indexOf(e)&&v.push(e)}function w(t){return\"LAYOUT\"+t+\".autorange\"}function T(t){return\"LAYOUT\"+t+\".range\"}function M(t){for(var e=t;e<a.length;e++)if(a[e]._input===l[t])return a[e]}function S(n,a,o){if(Array.isArray(n))n.forEach(function(t){S(t,a,o)});else if(!(n in e||k.hasParent(e,n))){var s;if(\"LAYOUT\"===n.substr(0,6))s=p(t.layout,n.replace(\"LAYOUT\",\"\"));else{var u=r[o];s=j(i._tracePreGUI[M(u)._fullInput.uid],c)(l[u],n)}n in x||(x[n]=b()),void 0===x[n][o]&&(x[n][o]=N(s.get())),void 0!==a&&s.set(a)}}function E(t){return function(e){return a[e][t]}}function C(t){return function(e,n){return!1===e?a[r[n]][t]:null}}for(var L in e){if(k.hasParent(e,L))throw new Error(\"cannot set \"+L+\" and a parent attribute simultaneously\");var P,O,z,I,D,R,F=e[L];if(\"autobinx\"!==L&&\"autobiny\"!==L||(L=L.charAt(L.length-1)+\"bins\",F=Array.isArray(F)?F.map(C(L)):!1===F?r.map(E(L)):null),y[L]=F,\"LAYOUT\"!==L.substr(0,6)){for(x[L]=b(),n=0;n<r.length;n++){if(P=l[r[n]],O=M(r[n]),I=(z=j(i._tracePreGUI[O._fullInput.uid],c)(P,L)).get(),void 0!==(D=Array.isArray(F)?F[n%F.length]:F)){var B=z.parts[z.parts.length-1],U=L.substr(0,L.length-B.length-1),V=U?U+\".\":\"\",H=U?s(O,U).get():O;if((R=h.getTraceValObject(O,z.parts))&&R.impliedEdits&&null!==D)for(var G in R.impliedEdits)S(o.relativeAttr(L,G),R.impliedEdits[G],n);else if(\"thicknessmode\"!==B&&\"lenmode\"!==B||I===D||\"fraction\"!==D&&\"pixels\"!==D||!H){if(\"type\"===L&&(\"pie\"===D!=(\"pie\"===I)||\"funnelarea\"===D!=(\"funnelarea\"===I))){var Y=\"x\",W=\"y\";\"bar\"!==D&&\"bar\"!==I||\"h\"!==P.orientation||(Y=\"y\",W=\"x\"),o.swapAttrs(P,[\"?\",\"?src\"],\"labels\",Y),o.swapAttrs(P,[\"d?\",\"?0\"],\"label\",Y),o.swapAttrs(P,[\"?\",\"?src\"],\"values\",W),\"pie\"===I||\"funnelarea\"===I?(s(P,\"marker.color\").set(s(P,\"marker.colors\").get()),i._pielayer.selectAll(\"g.trace\").remove()):u.traceIs(P,\"cartesian\")&&s(P,\"marker.colors\").set(s(P,\"marker.color\").get())}}else{var X=i._size,Z=H.orient,J=\"top\"===Z||\"bottom\"===Z;if(\"thicknessmode\"===B){var K=J?X.h:X.w;S(V+\"thickness\",H.thickness*(\"fraction\"===D?1/K:K),n)}else{var $=J?X.w:X.h;S(V+\"len\",H.len*(\"fraction\"===D?1/$:$),n)}}x[L][n]=N(I);if(-1!==[\"swapxy\",\"swapxyaxes\",\"orientation\",\"orientationaxes\"].indexOf(L)){if(\"orientation\"===L){z.set(D);var Q=P.x&&!P.y?\"h\":\"v\";if((z.get()||Q)===O.orientation)continue}else\"orientationaxes\"===L&&(P.orientation={v:\"h\",h:\"v\"}[O.orientation]);k.swapXYData(P),m.calc=m.clearAxisTypes=!0}else-1!==f.dataArrayContainers.indexOf(z.parts[0])?(k.manageArrayContainers(z,D,x),m.calc=!0):(R?R.arrayOk&&!u.traceIs(O,\"regl\")&&(o.isArrayOrTypedArray(D)||o.isArrayOrTypedArray(I))?m.calc=!0:A.update(m,R):m.calc=!0,z.set(D))}}if(-1!==[\"swapxyaxes\",\"orientationaxes\"].indexOf(L)&&d.swap(t,r),\"orientationaxes\"===L){var tt=s(t.layout,\"hovermode\");\"x\"===tt.get()?tt.set(\"y\"):\"y\"===tt.get()&&tt.set(\"x\")}if(-1!==[\"orientation\",\"type\"].indexOf(L)){for(v=[],n=0;n<r.length;n++){var et=l[r[n]];u.traceIs(et,\"cartesian\")&&(_(et.xaxis||\"x\"),_(et.yaxis||\"y\"))}S(v.map(w),!0,0),S(v.map(T),[0,1],0)}}else z=p(t.layout,L.replace(\"LAYOUT\",\"\")),x[L]=[N(z.get())],z.set(Array.isArray(F)?F[0]:F),m.calc=!0}return(m.calc||m.plot)&&(m.fullReplot=!0),{flags:m,undoit:x,redoit:y,traces:r,eventData:o.extendDeepNoArrays([],[g,r])}}function q(t){var e,r,n,i=o.counterRegex(\"axis\",\".title\",!1,!1),a=/colorbar\\.title$/,s=Object.keys(t);for(e=0;e<s.length;e++)r=s[e],n=t[r],\"title\"!==r&&!i.test(r)&&!a.test(r)||\"string\"!=typeof n&&\"number\"!=typeof n?r.indexOf(\"titlefont\")>-1?l(r,r.replace(\"titlefont\",\"title.font\")):r.indexOf(\"titleposition\")>-1?l(r,r.replace(\"titleposition\",\"title.position\")):r.indexOf(\"titleside\")>-1?l(r,r.replace(\"titleside\",\"title.side\")):r.indexOf(\"titleoffset\")>-1&&l(r,r.replace(\"titleoffset\",\"title.offset\")):l(r,r.replace(\"title\",\"title.text\"));function l(e,r){t[r]=t[e],delete t[e]}}function H(t,e,r){if(t=o.getGraphDiv(t),k.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);var n={};if(\"string\"==typeof e)n[e]=r;else{if(!o.isPlainObject(e))return o.warn(\"Relayout fail.\",e,r),Promise.reject();n=o.extendFlat({},e)}Object.keys(n).length&&(t.changed=!0);var i=J(t,n),a=i.flags;a.calc&&(t.calcdata=void 0);var s=[f.previousPromises];a.layoutReplot?s.push(T.layoutReplot):Object.keys(n).length&&(G(t,a,i)||f.supplyDefaults(t),a.legend&&s.push(T.doLegend),a.layoutstyle&&s.push(T.layoutStyles),a.axrange&&Y(s,i.rangesAltered),a.ticks&&s.push(T.doTicksRelayout),a.modebar&&s.push(T.doModeBar),a.camera&&s.push(T.doCamera),a.colorbars&&s.push(T.doColorBars),s.push(C)),s.push(f.rehover,f.redrag),c.add(t,H,[t,i.undoit],H,[t,i.redoit]);var l=o.syncOrAsync(s,t);return l&&l.then||(l=Promise.resolve(t)),l.then(function(){return t.emit(\"plotly_relayout\",i.eventData),t})}function G(t,e,r){var n=t._fullLayout;if(!e.axrange)return!1;for(var i in e)if(\"axrange\"!==i&&e[i])return!1;for(var a in r.rangesAltered){var o=d.id2name(a),s=t.layout[o],l=n[o];if(l.autorange=s.autorange,l.range=s.range.slice(),l.cleanRange(),l._matchGroup)for(var c in l._matchGroup)if(c!==a){var u=n[d.id2name(c)];u.autorange=l.autorange,u.range=l.range.slice(),u._input.range=l.range.slice()}}return!0}function Y(t,e){var r=e?function(t){var r=[],n=!0;for(var i in e){var a=d.getFromId(t,i);if(r.push(i),a._matchGroup)for(var o in a._matchGroup)e[o]||r.push(o);a.automargin&&(n=!1)}return d.draw(t,r,{skipTitle:n})}:function(t){return d.draw(t,\"redraw\")};t.push(b,T.doAutoRangeAndConstraints,r,T.drawData,T.finalDraw)}var W=/^[xyz]axis[0-9]*\\.range(\\[[0|1]\\])?$/,X=/^[xyz]axis[0-9]*\\.autorange$/,Z=/^[xyz]axis[0-9]*\\.domain(\\[[0|1]\\])?$/;function J(t,e){var r,n,i,a=t.layout,l=t._fullLayout,c=l._guiEditing,f=j(l._preGUI,c),p=Object.keys(e),g=d.list(t),v=o.extendDeepAll({},e),m={};for(q(e),p=Object.keys(e),n=0;n<p.length;n++)if(0===p[n].indexOf(\"allaxes\")){for(i=0;i<g.length;i++){var y=g[i]._id.substr(1),x=-1!==y.indexOf(\"scene\")?y+\".\":\"\",b=p[n].replace(\"allaxes\",x+g[i]._name);e[b]||(e[b]=e[p[n]])}delete e[p[n]]}var _=A.layoutFlags(),T={},S={};function E(t,r){if(Array.isArray(t))t.forEach(function(t){E(t,r)});else if(!(t in e||k.hasParent(e,t))){var n=f(a,t);t in S||(S[t]=N(n.get())),void 0!==r&&n.set(r)}}var C,L={};function P(t){var e=d.name2id(t.split(\".\")[0]);return L[e]=1,e}for(var O in e){if(k.hasParent(e,O))throw new Error(\"cannot set \"+O+\" and a parent attribute simultaneously\");for(var z=f(a,O),I=e[O],D=z.parts.length-1;D>0&&\"string\"!=typeof z.parts[D];)D--;var R=z.parts[D],F=z.parts[D-1]+\".\"+R,B=z.parts.slice(0,D).join(\".\"),U=s(t.layout,B).get(),V=s(l,B).get(),H=z.get();if(void 0!==I){T[O]=I,S[O]=\"reverse\"===R?I:N(H);var G=h.getLayoutValObject(l,z.parts);if(G&&G.impliedEdits&&null!==I)for(var Y in G.impliedEdits)E(o.relativeAttr(O,Y),G.impliedEdits[Y]);if(-1!==[\"width\",\"height\"].indexOf(O))if(I){E(\"autosize\",null);var J=\"height\"===O?\"width\":\"height\";E(J,l[J])}else l[O]=t._initialAutoSize[O];else if(\"autosize\"===O)E(\"width\",I?null:l.width),E(\"height\",I?null:l.height);else if(F.match(W))P(F),s(l,B+\"._inputRange\").set(null);else if(F.match(X)){P(F),s(l,B+\"._inputRange\").set(null);var $=s(l,B).get();$._inputDomain&&($._input.domain=$._inputDomain.slice())}else F.match(Z)&&s(l,B+\"._inputDomain\").set(null);if(\"type\"===R){var Q=U,tt=\"linear\"===V.type&&\"log\"===I,et=\"log\"===V.type&&\"linear\"===I;if(tt||et){if(Q&&Q.range)if(V.autorange)tt&&(Q.range=Q.range[1]>Q.range[0]?[1,2]:[2,1]);else{var rt=Q.range[0],nt=Q.range[1];tt?(rt<=0&&nt<=0&&E(B+\".autorange\",!0),rt<=0?rt=nt/1e6:nt<=0&&(nt=rt/1e6),E(B+\".range[0]\",Math.log(rt)/Math.LN10),E(B+\".range[1]\",Math.log(nt)/Math.LN10)):(E(B+\".range[0]\",Math.pow(10,rt)),E(B+\".range[1]\",Math.pow(10,nt)))}else E(B+\".autorange\",!0);Array.isArray(l._subplots.polar)&&l._subplots.polar.length&&l[z.parts[0]]&&\"radialaxis\"===z.parts[1]&&delete l[z.parts[0]]._subplot.viewInitial[\"radialaxis.range\"],u.getComponentMethod(\"annotations\",\"convertCoords\")(t,V,I,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,V,I,E)}else E(B+\".autorange\",!0),E(B+\".range\",null);s(l,B+\"._inputRange\").set(null)}else if(R.match(M)){var it=s(l,O).get(),at=(I||{}).type;at&&\"-\"!==at||(at=\"linear\"),u.getComponentMethod(\"annotations\",\"convertCoords\")(t,it,at,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,it,at,E)}var ot=w.containerArrayMatch(O);if(ot){r=ot.array,n=ot.index;var st=ot.property,lt=G||{editType:\"calc\"};\"\"!==n&&\"\"===st&&(w.isAddVal(I)?S[O]=null:w.isRemoveVal(I)?S[O]=(s(a,r).get()||[])[n]:o.warn(\"unrecognized full object value\",e)),A.update(_,lt),m[r]||(m[r]={});var ct=m[r][n];ct||(ct=m[r][n]={}),ct[st]=I,delete e[O]}else\"reverse\"===R?(U.range?U.range.reverse():(E(B+\".autorange\",!0),U.range=[1,0]),V.autorange?_.calc=!0:_.plot=!0):(l._has(\"scatter-like\")&&l._has(\"regl\")&&\"dragmode\"===O&&(\"lasso\"===I||\"select\"===I)&&\"lasso\"!==H&&\"select\"!==H?_.plot=!0:l._has(\"gl2d\")?_.plot=!0:G?A.update(_,G):_.calc=!0,z.set(I))}}for(r in m){w.applyContainerArrayChanges(t,f(a,r),m[r],_,f)||(_.plot=!0)}var ut=l._axisConstraintGroups||[];for(C in L)for(n=0;n<ut.length;n++){var ht=ut[n];if(ht[C])for(var ft in _.calc=!0,ht)L[ft]||(d.getFromId(t,ft)._constraintShrinkable=!0)}return(K(t)||e.height||e.width)&&(_.plot=!0),(_.plot||_.calc)&&(_.layoutReplot=!0),{flags:_,rangesAltered:L,undoit:S,redoit:T,eventData:v}}function K(t){var e=t._fullLayout,r=e.width,n=e.height;return t.layout.autosize&&f.plotAutoSize(t,t.layout,e),e.width!==r||e.height!==n}function $(t,e,n,i){if(t=o.getGraphDiv(t),k.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);o.isPlainObject(e)||(e={}),o.isPlainObject(n)||(n={}),Object.keys(e).length&&(t.changed=!0),Object.keys(n).length&&(t.changed=!0);var a=k.coerceTraceIndices(t,i),s=V(t,o.extendFlat({},e),a),l=s.flags,u=J(t,o.extendFlat({},n)),h=u.flags;(l.calc||h.calc)&&(t.calcdata=void 0),l.clearAxisTypes&&k.clearAxisTypes(t,a,n);var p=[];h.layoutReplot?p.push(T.layoutReplot):l.fullReplot?p.push(r.plot):(p.push(f.previousPromises),G(t,h,u)||f.supplyDefaults(t),l.style&&p.push(T.doTraceStyle),(l.colorbars||h.colorbars)&&p.push(T.doColorBars),h.legend&&p.push(T.doLegend),h.layoutstyle&&p.push(T.layoutStyles),h.axrange&&Y(p,u.rangesAltered),h.ticks&&p.push(T.doTicksRelayout),h.modebar&&p.push(T.doModeBar),h.camera&&p.push(T.doCamera),p.push(C)),p.push(f.rehover,f.redrag),c.add(t,$,[t,s.undoit,u.undoit,s.traces],$,[t,s.redoit,u.redoit,s.traces]);var d=o.syncOrAsync(p,t);return d&&d.then||(d=Promise.resolve(t)),d.then(function(){return t.emit(\"plotly_update\",{data:s.eventData,layout:u.eventData}),t})}function Q(t){return function(e){e._fullLayout._guiEditing=!0;var r=t.apply(null,arguments);return e._fullLayout._guiEditing=!1,r}}var tt=[{pattern:/^hiddenlabels/,attr:\"legend.uirevision\"},{pattern:/^((x|y)axis\\d*)\\.((auto)?range|title\\.text)/},{pattern:/axis\\d*\\.showspikes$/,attr:\"modebar.uirevision\"},{pattern:/(hover|drag)mode$/,attr:\"modebar.uirevision\"},{pattern:/^(scene\\d*)\\.camera/},{pattern:/^(geo\\d*)\\.(projection|center)/},{pattern:/^(ternary\\d*\\.[abc]axis)\\.(min|title\\.text)$/},{pattern:/^(polar\\d*\\.radialaxis)\\.((auto)?range|angle|title\\.text)/},{pattern:/^(polar\\d*\\.angularaxis)\\.rotation/},{pattern:/^(mapbox\\d*)\\.(center|zoom|bearing|pitch)/},{pattern:/^legend\\.(x|y)$/,attr:\"editrevision\"},{pattern:/^(shapes|annotations)/,attr:\"editrevision\"},{pattern:/^title\\.text$/,attr:\"editrevision\"}],et=[{pattern:/^selectedpoints$/,attr:\"selectionrevision\"},{pattern:/(^|value\\.)visible$/,attr:\"legend.uirevision\"},{pattern:/^dimensions\\[\\d+\\]\\.constraintrange/},{pattern:/^node\\.(x|y|groups)/},{pattern:/^level$/},{pattern:/(^|value\\.)name$/},{pattern:/colorbar\\.title\\.text$/},{pattern:/colorbar\\.(x|y)$/,attr:\"editrevision\"}];function rt(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=t.match(n.pattern);if(i)return{head:i[1],attr:n.attr}}}function nt(t,e){var r=s(e,t).get();if(void 0!==r)return r;var n=t.split(\".\");for(n.pop();n.length>1;)if(n.pop(),void 0!==(r=s(e,n.join(\".\")+\".uirevision\").get()))return r;return e.uirevision}function it(t,e){for(var r=0;r<e.length;r++)if(e[r]._fullInput.uid===t)return r;return-1}function at(t,e,r){for(var n=0;n<e.length;n++)if(e[n].uid===t)return n;return!e[r]||e[r].uid?-1:r}function ot(t,e){var r=o.isPlainObject(t),n=Array.isArray(t);return r||n?(r&&o.isPlainObject(e)||n&&Array.isArray(e))&&JSON.stringify(t)===JSON.stringify(e):t===e}function st(t,e,r,n){var i,a,l,c=n.getValObject,u=n.flags,h=n.immutable,f=n.inArray,p=n.arrayIndex;function d(){var t=i.editType;f&&-1!==t.indexOf(\"arraydraw\")?o.pushUnique(u.arrays[f],p):(A.update(u,i),\"none\"!==t&&u.nChanges++,n.transition&&i.anim&&u.nChangesAnim++,(W.test(l)||X.test(l))&&(u.rangesAltered[r[0]]=1),Z.test(l)&&s(e,\"_inputDomain\").set(null),\"datarevision\"===a&&(u.newDataRevision=1))}function g(t){return\"data_array\"===t.valType||t.arrayOk}for(a in t){if(u.calc&&!n.transition)return;var v=t[a],m=e[a],y=r.concat(a);if(l=y.join(\".\"),\"_\"!==a.charAt(0)&&\"function\"!=typeof v&&v!==m){if((\"tick0\"===a||\"dtick\"===a)&&\"geo\"!==r[0]){var x=e.tickmode;if(\"auto\"===x||\"array\"===x||!x)continue}if((\"range\"!==a||!e.autorange)&&(\"zmin\"!==a&&\"zmax\"!==a||\"contourcarpet\"!==e.type)&&(i=c(y))&&(!i._compareAsJSON||JSON.stringify(v)!==JSON.stringify(m))){var b,_=i.valType,w=g(i),k=Array.isArray(v),T=Array.isArray(m);if(k&&T){var M=\"_input_\"+a,S=t[M],E=e[M];if(Array.isArray(S)&&S===E)continue}if(void 0===m)w&&k?u.calc=!0:d();else if(i._isLinkedToArray){var C=[],L=!1;f||(u.arrays[a]=C);var P=Math.min(v.length,m.length),O=Math.max(v.length,m.length);if(P!==O){if(\"arraydraw\"!==i.editType){d();continue}L=!0}for(b=0;b<P;b++)st(v[b],m[b],y.concat(b),o.extendFlat({inArray:a,arrayIndex:b},n));if(L)for(b=P;b<O;b++)C.push(b)}else!_&&o.isPlainObject(v)?st(v,m,y,n):w?k&&T?(h&&(u.calc=!0),(h||n.newDataRevision)&&d()):k!==T?u.calc=!0:d():k&&T&&v.length===m.length&&String(v)===String(m)||d()}}}for(a in e)if(!(a in t||\"_\"===a.charAt(0)||\"function\"==typeof e[a])){if(g(i=c(r.concat(a)))&&Array.isArray(e[a]))return void(u.calc=!0);d()}}function lt(t){var e=n.select(t),r=t._fullLayout;if(r._container=e.selectAll(\".plot-container\").data([0]),r._container.enter().insert(\"div\",\":first-child\").classed(\"plot-container\",!0).classed(\"plotly\",!0),r._paperdiv=r._container.selectAll(\".svg-container\").data([0]),r._paperdiv.enter().append(\"div\").classed(\"svg-container\",!0).style(\"position\",\"relative\"),r._glcontainer=r._paperdiv.selectAll(\".gl-container\").data([{}]),r._glcontainer.enter().append(\"div\").classed(\"gl-container\",!0),r._paperdiv.selectAll(\".main-svg\").remove(),r._paperdiv.select(\".modebar-container\").remove(),r._paper=r._paperdiv.insert(\"svg\",\":first-child\").classed(\"main-svg\",!0),r._toppaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),r._modebardiv=r._paperdiv.append(\"div\"),r._hoverpaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),!r._uid){var i={};n.selectAll(\"defs\").each(function(){this.id&&(i[this.id.split(\"-\")[1]]=1)}),r._uid=o.randstr(i)}r._paperdiv.selectAll(\".main-svg\").attr(y.svgAttrs),r._defs=r._paper.append(\"defs\").attr(\"id\",\"defs-\"+r._uid),r._clips=r._defs.append(\"g\").classed(\"clips\",!0),r._topdefs=r._toppaper.append(\"defs\").attr(\"id\",\"topdefs-\"+r._uid),r._topclips=r._topdefs.append(\"g\").classed(\"clips\",!0),r._bgLayer=r._paper.append(\"g\").classed(\"bglayer\",!0),r._draggers=r._paper.append(\"g\").classed(\"draglayer\",!0);var a=r._paper.append(\"g\").classed(\"layer-below\",!0);r._imageLowerLayer=a.append(\"g\").classed(\"imagelayer\",!0),r._shapeLowerLayer=a.append(\"g\").classed(\"shapelayer\",!0),r._cartesianlayer=r._paper.append(\"g\").classed(\"cartesianlayer\",!0),r._polarlayer=r._paper.append(\"g\").classed(\"polarlayer\",!0),r._ternarylayer=r._paper.append(\"g\").classed(\"ternarylayer\",!0),r._geolayer=r._paper.append(\"g\").classed(\"geolayer\",!0),r._funnelarealayer=r._paper.append(\"g\").classed(\"funnelarealayer\",!0),r._pielayer=r._paper.append(\"g\").classed(\"pielayer\",!0),r._sunburstlayer=r._paper.append(\"g\").classed(\"sunburstlayer\",!0),r._indicatorlayer=r._toppaper.append(\"g\").classed(\"indicatorlayer\",!0),r._glimages=r._paper.append(\"g\").classed(\"glimages\",!0);var s=r._toppaper.append(\"g\").classed(\"layer-above\",!0);r._imageUpperLayer=s.append(\"g\").classed(\"imagelayer\",!0),r._shapeUpperLayer=s.append(\"g\").classed(\"shapelayer\",!0),r._infolayer=r._toppaper.append(\"g\").classed(\"infolayer\",!0),r._menulayer=r._toppaper.append(\"g\").classed(\"menulayer\",!0),r._zoomlayer=r._toppaper.append(\"g\").classed(\"zoomlayer\",!0),r._hoverlayer=r._hoverpaper.append(\"g\").classed(\"hoverlayer\",!0),r._modebardiv.classed(\"modebar-container\",!0).style(\"position\",\"absolute\").style(\"top\",\"0px\").style(\"right\",\"0px\"),t.emit(\"plotly_framework\")}r.animate=function(t,e,r){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before animating it. For more details, see https://plot.ly/javascript/animations/\");var n=t._transitionData;n._frameQueue||(n._frameQueue=[]);var i=(r=f.supplyAnimationDefaults(r)).transition,a=r.frame;function s(t){return Array.isArray(i)?t>=i.length?i[0]:i[t]:i}function l(t){return Array.isArray(a)?t>=a.length?a[0]:a[t]:a}function c(t,e){var r=0;return function(){if(t&&++r===e)return t()}}return void 0===n._frameWaitingCnt&&(n._frameWaitingCnt=0),new Promise(function(a,u){function h(){n._currentFrame&&n._currentFrame.onComplete&&n._currentFrame.onComplete();var e=n._currentFrame=n._frameQueue.shift();if(e){var r=e.name?e.name.toString():null;t._fullLayout._currentFrame=r,n._lastFrameAt=Date.now(),n._timeToNext=e.frameOpts.duration,f.transition(t,e.frame.data,e.frame.layout,k.coerceTraceIndices(t,e.frame.traces),e.frameOpts,e.transitionOpts).then(function(){e.onComplete&&e.onComplete()}),t.emit(\"plotly_animatingframe\",{name:r,frame:e.frame,animation:{frame:e.frameOpts,transition:e.transitionOpts}})}else t.emit(\"plotly_animated\"),window.cancelAnimationFrame(n._animationRaf),n._animationRaf=null}function p(){t.emit(\"plotly_animating\"),n._lastFrameAt=-1/0,n._timeToNext=0,n._runningTransitions=0,n._currentFrame=null;var e=function(){n._animationRaf=window.requestAnimationFrame(e),Date.now()-n._lastFrameAt>n._timeToNext&&h()};e()}var d,g,v=0;function m(t){return Array.isArray(i)?v>=i.length?t.transitionOpts=i[v]:t.transitionOpts=i[0]:t.transitionOpts=i,v++,t}var y=[],x=null==e,b=Array.isArray(e);if(x||b||!o.isPlainObject(e)){if(x||-1!==[\"string\",\"number\"].indexOf(typeof e))for(d=0;d<n._frames.length;d++)(g=n._frames[d])&&(x||String(g.group)===String(e))&&y.push({type:\"byname\",name:String(g.name),data:m({name:g.name})});else if(b)for(d=0;d<e.length;d++){var _=e[d];-1!==[\"number\",\"string\"].indexOf(typeof _)?(_=String(_),y.push({type:\"byname\",name:_,data:m({name:_})})):o.isPlainObject(_)&&y.push({type:\"object\",data:m(o.extendFlat({},_))})}}else y.push({type:\"object\",data:m(o.extendFlat({},e))});for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&!n._frameHash[g.data.name])return o.warn('animate failure: frame not found: \"'+g.data.name+'\"'),void u();-1!==[\"next\",\"immediate\"].indexOf(r.mode)&&function(){if(0!==n._frameQueue.length){for(;n._frameQueue.length;){var e=n._frameQueue.pop();e.onInterrupt&&e.onInterrupt()}t.emit(\"plotly_animationinterrupted\",[])}}(),\"reverse\"===r.direction&&y.reverse();var w=t._fullLayout._currentFrame;if(w&&r.fromcurrent){var T=-1;for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&g.name===w){T=d;break}if(T>0&&T<y.length-1){var A=[];for(d=0;d<y.length;d++)g=y[d],(\"byname\"!==y[d].type||d>T)&&A.push(g);y=A}}y.length>0?function(e){if(0!==e.length){for(var i=0;i<e.length;i++){var o;o=\"byname\"===e[i].type?f.computeFrame(t,e[i].name):e[i].data;var h=l(i),d=s(i);d.duration=Math.min(d.duration,h.duration);var g={frame:o,name:e[i].name,frameOpts:h,transitionOpts:d};i===e.length-1&&(g.onComplete=c(a,2),g.onInterrupt=u),n._frameQueue.push(g)}\"immediate\"===r.mode&&(n._lastFrameAt=-1/0),n._animationRaf||p()}}(y):(t.emit(\"plotly_animated\"),a())})},r.addFrames=function(t,e,r){if(t=o.getGraphDiv(t),null==e)return Promise.resolve();if(!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before adding frames. For more details, see https://plot.ly/javascript/animations/\");var n,i,a,s,l=t._transitionData._frames,u=t._transitionData._frameHash;if(!Array.isArray(e))throw new Error(\"addFrames failure: frameList must be an Array of frame definitions\"+e);var h=l.length+2*e.length,p=[],d={};for(n=e.length-1;n>=0;n--)if(o.isPlainObject(e[n])){var g=e[n].name,v=(u[g]||d[g]||{}).name,m=e[n].name,y=u[v]||d[v];v&&m&&\"number\"==typeof m&&y&&S<E&&(S++,o.warn('addFrames: overwriting frame \"'+(u[v]||d[v]).name+'\" with a frame whose name of type \"number\" also equates to \"'+v+'\". This is valid but may potentially lead to unexpected behavior since all plotly.js frame names are stored internally as strings.'),S===E&&o.warn(\"addFrames: This API call has yielded too many of these warnings. For the rest of this call, further warnings about numeric frame names will be suppressed.\")),d[g]={name:g},p.push({frame:f.supplyFrameDefaults(e[n]),index:r&&void 0!==r[n]&&null!==r[n]?r[n]:h+n})}p.sort(function(t,e){return t.index>e.index?-1:t.index<e.index?1:0});var x=[],b=[],_=l.length;for(n=p.length-1;n>=0;n--){if(\"number\"==typeof(i=p[n].frame).name&&o.warn(\"Warning: addFrames accepts frames with numeric names, but the numbers areimplicitly cast to strings\"),!i.name)for(;u[i.name=\"frame \"+t._transitionData._counter++];);if(u[i.name]){for(a=0;a<l.length&&(l[a]||{}).name!==i.name;a++);x.push({type:\"replace\",index:a,value:i}),b.unshift({type:\"replace\",index:a,value:l[a]})}else s=Math.max(0,Math.min(p[n].index,_)),x.push({type:\"insert\",index:s,value:i}),b.unshift({type:\"delete\",index:s}),_++}var w=f.modifyFrames,k=f.modifyFrames,T=[t,b],A=[t,x];return c&&c.add(t,w,T,k,A),f.modifyFrames(t,x)},r.deleteFrames=function(t,e){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);var r,n,i=t._transitionData._frames,a=[],s=[];if(!e)for(e=[],r=0;r<i.length;r++)e.push(r);for((e=e.slice()).sort(),r=e.length-1;r>=0;r--)n=e[r],a.push({type:\"delete\",index:n}),s.unshift({type:\"insert\",index:n,value:i[n]});var l=f.modifyFrames,u=f.modifyFrames,h=[t,s],p=[t,a];return c&&c.add(t,l,h,u,p),f.modifyFrames(t,a)},r.addTraces=function t(e,n,i){e=o.getGraphDiv(e);var a,s,l=[],u=r.deleteTraces,h=t,f=[e,l],p=[e,n];for(function(t,e,r){var n,i;if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"traces must be defined.\");for(Array.isArray(e)||(e=[e]),n=0;n<e.length;n++)if(\"object\"!=typeof(i=e[n])||Array.isArray(i)||null===i)throw new Error(\"all values in traces array must be non-array objects\");if(\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&r.length!==e.length)throw new Error(\"if indices is specified, traces.length must equal indices.length\")}(e,n,i),Array.isArray(n)||(n=[n]),n=n.map(function(t){return o.extendFlat({},t)}),k.cleanData(n),a=0;a<n.length;a++)e.data.push(n[a]);for(a=0;a<n.length;a++)l.push(-n.length+a);if(\"undefined\"==typeof i)return s=r.redraw(e),c.add(e,u,f,h,p),s;Array.isArray(i)||(i=[i]);try{D(e,l,i)}catch(t){throw e.data.splice(e.data.length-n.length,n.length),t}return c.startSequence(e),c.add(e,u,f,h,p),s=r.moveTraces(e,l,i),c.stopSequence(e),s},r.deleteTraces=function t(e,n){e=o.getGraphDiv(e);var i,a,s=[],l=r.addTraces,u=t,h=[e,s,n],f=[e,n];if(\"undefined\"==typeof n)throw new Error(\"indices must be an integer or array of integers.\");for(Array.isArray(n)||(n=[n]),I(e,n,\"indices\"),(n=z(n,e.data.length-1)).sort(o.sorterDes),i=0;i<n.length;i+=1)a=e.data.splice(n[i],1)[0],s.push(a);var p=r.redraw(e);return c.add(e,l,h,u,f),p},r.extendTraces=function t(e,n,i,a){var s=R(e=o.getGraphDiv(e),n,i,a,function(t,e,r){var n,i;if(o.isTypedArray(t))if(r<0){var a=new t.constructor(0),s=F(t,e);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(l)),i.set(t),i.set(e.subarray(0,l),t.length)}else{var c=r-e.length,u=t.length-c;n.set(t.subarray(u)),n.set(e,c),i.set(t.subarray(0,u))}else n=t.concat(e),i=r>=0&&r<n.length?n.splice(0,n.length-r):[];return[n,i]}),l=r.redraw(e),u=[e,s.update,i,s.maxPoints];return c.add(e,r.prependTraces,u,t,arguments),l},r.moveTraces=function t(e,n,i){var a,s=[],l=[],u=t,h=t,f=[e=o.getGraphDiv(e),i,n],p=[e,n,i];if(D(e,n,i),n=Array.isArray(n)?n:[n],\"undefined\"==typeof i)for(i=[],a=0;a<n.length;a++)i.push(-n.length+a);for(i=Array.isArray(i)?i:[i],n=z(n,e.data.length-1),i=z(i,e.data.length-1),a=0;a<e.data.length;a++)-1===n.indexOf(a)&&s.push(e.data[a]);for(a=0;a<n.length;a++)l.push({newIndex:i[a],trace:e.data[n[a]]});for(l.sort(function(t,e){return t.newIndex-e.newIndex}),a=0;a<l.length;a+=1)s.splice(l[a].newIndex,0,l[a].trace);e.data=s;var d=r.redraw(e);return c.add(e,u,f,h,p),d},r.prependTraces=function t(e,n,i,a){var s=R(e=o.getGraphDiv(e),n,i,a,function(t,e,r){var n,i;if(o.isTypedArray(t))if(r<=0){var a=new t.constructor(0),s=F(e,t);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(0,l)),i.set(e.subarray(l)),i.set(t,l)}else{var c=r-e.length;n.set(e),n.set(t.subarray(0,c),e.length),i.set(t.subarray(c))}else n=e.concat(t),i=r>=0&&r<n.length?n.splice(r,n.length):[];return[n,i]}),l=r.redraw(e),u=[e,s.update,i,s.maxPoints];return c.add(e,r.extendTraces,u,t,arguments),l},r.newPlot=function(t,e,n,i){return t=o.getGraphDiv(t),f.cleanPlot([],{},t._fullData||[],t._fullLayout||{}),f.purge(t),r.plot(t,e,n,i)},r.plot=function(t,e,i,a){var s;if(t=o.getGraphDiv(t),l.init(t),o.isPlainObject(e)){var c=e;e=c.data,i=c.layout,a=c.config,s=c.frames}if(!1===l.triggerHandler(t,\"plotly_beforeplot\",[e,i,a]))return Promise.reject();e||i||o.isPlotDiv(t)||o.warn(\"Calling Plotly.plot as if redrawing but this container doesn't yet have a plot.\",t),O(t,a),i||(i={}),n.select(t).classed(\"js-plotly-plot\",!0),g.makeTester(),Array.isArray(t._promises)||(t._promises=[]);var h=0===(t.data||[]).length&&Array.isArray(e);Array.isArray(e)&&(k.cleanData(e),h?t.data=e:t.data.push.apply(t.data,e),t.empty=!1),t.layout&&!h||(t.layout=k.cleanLayout(i)),f.supplyDefaults(t);var v=t._fullLayout,y=v._has(\"cartesian\");if(!v._has(\"polar\")&&e&&e[0]&&e[0].r)return o.log(\"Legacy polar charts are deprecated!\"),function(t,e,r){var i=n.select(t).selectAll(\".plot-container\").data([0]);i.enter().insert(\"div\",\":first-child\").classed(\"plot-container plotly\",!0);var a=i.selectAll(\".svg-container\").data([0]);a.enter().append(\"div\").classed(\"svg-container\",!0).style(\"position\",\"relative\"),a.html(\"\"),e&&(t.data=e),r&&(t.layout=r),p.manager.fillLayout(t),a.style({width:t._fullLayout.width+\"px\",height:t._fullLayout.height+\"px\"}),t.framework=p.manager.framework(t),t.framework({data:t.data,layout:t.layout},a.node()),t.framework.setUndoPoint();var s=t.framework.svg(),l=1,c=t._fullLayout.title?t._fullLayout.title.text:\"\";\"\"!==c&&c||(l=0);var u=function(){this.call(x.convertToTspans,t)},h=s.select(\".title-group text\").call(u);if(t._context.edits.titleText){var d=o._(t,\"Click to enter Plot title\");c&&c!==d||(l=.2,h.attr({\"data-unformatted\":d}).text(d).style({opacity:l}).on(\"mouseover.opacity\",function(){n.select(this).transition().duration(100).style(\"opacity\",1)}).on(\"mouseout.opacity\",function(){n.select(this).transition().duration(1e3).style(\"opacity\",0)}));var g=function(){this.call(x.makeEditable,{gd:t}).on(\"edit\",function(e){t.framework({layout:{title:{text:e}}}),this.text(e).call(u),this.call(g)}).on(\"cancel\",function(){var t=this.attr(\"data-unformatted\");this.text(t).call(u)})};h.call(g)}return t._context.setBackground(t,t._fullLayout.paper_bgcolor),f.addLinks(t),Promise.resolve()}(t,e,i);v._replotting=!0,h&&lt(t),t.framework!==lt&&(t.framework=lt,lt(t)),g.initGradients(t),h&&d.saveShowSpikeInitial(t);var b=!t.calcdata||t.calcdata.length!==(t._fullData||[]).length;b&&f.doCalcdata(t);for(var _=0;_<t.calcdata.length;_++)t.calcdata[_][0].trace=t._fullData[_];t._context.responsive?t._responsiveChartHandler||(t._responsiveChartHandler=function(){o.isHidden(t)||f.resize(t)},window.addEventListener(\"resize\",t._responsiveChartHandler)):o.clearResponsive(t);var w=o.extendFlat({},v._size),A=0;function M(){return f.clearAutoMarginIds(t),T.drawMarginPushers(t),d.allowAutoMargin(t),f.doAutoMargin(t),f.previousPromises(t)}function S(){t._transitioning||(T.doAutoRangeAndConstraints(t),h&&d.saveRangeInitial(t),u.getComponentMethod(\"rangeslider\",\"calcAutorange\")(t))}var E=[f.previousPromises,function(){if(s)return r.addFrames(t,s)},function e(){for(var r=v._basePlotModules,n=0;n<r.length;n++)r[n].drawFramework&&r[n].drawFramework(t);if(!v._glcanvas&&v._has(\"gl\")&&(v._glcanvas=v._glcontainer.selectAll(\".gl-canvas\").data([{key:\"contextLayer\",context:!0,pick:!1},{key:\"focusLayer\",context:!1,pick:!1},{key:\"pickLayer\",context:!1,pick:!0}],function(t){return t.key}),v._glcanvas.enter().append(\"canvas\").attr(\"class\",function(t){return\"gl-canvas gl-canvas-\"+t.key.replace(\"Layer\",\"\")}).style({position:\"absolute\",top:0,left:0,overflow:\"visible\",\"pointer-events\":\"none\"})),v._glcanvas){v._glcanvas.attr(\"width\",v.width).attr(\"height\",v.height);var i=v._glcanvas.data()[0].regl;if(i&&(Math.floor(v.width)!==i._gl.drawingBufferWidth||Math.floor(v.height)!==i._gl.drawingBufferHeight)){var a=\"WebGL context buffer and canvas dimensions do not match due to browser/WebGL bug.\";if(!A)return o.log(a+\" Clearing graph and plotting again.\"),f.cleanPlot([],{},t._fullData,v),f.supplyDefaults(t),v=t._fullLayout,f.doCalcdata(t),A++,e();o.error(a)}}return\"h\"===v.modebar.orientation?v._modebardiv.style(\"height\",null).style(\"width\",\"100%\"):v._modebardiv.style(\"width\",null).style(\"height\",v.height+\"px\"),f.previousPromises(t)},M,function(){if(f.didMarginChange(w,v._size))return o.syncOrAsync([M,T.layoutStyles],t)}];y&&E.push(function(){if(b)return o.syncOrAsync([u.getComponentMethod(\"shapes\",\"calcAutorange\"),u.getComponentMethod(\"annotations\",\"calcAutorange\"),S],t);S()}),E.push(T.layoutStyles),y&&E.push(function(){return d.draw(t,h?\"\":\"redraw\")}),E.push(T.drawData,T.finalDraw,m,f.addLinks,f.rehover,f.redrag,f.doAutoMargin,f.previousPromises);var L=o.syncOrAsync(E,t);return L&&L.then||(L=Promise.resolve()),L.then(function(){return C(t),t})},r.purge=function(t){var e=(t=o.getGraphDiv(t))._fullLayout||{},r=t._fullData||[];return f.cleanPlot([],{},r,e),f.purge(t),l.purge(t),e._container&&e._container.remove(),delete t._context,t},r.react=function(t,e,n,i){var a,l,c=(t=o.getGraphDiv(t))._fullData,p=t._fullLayout;if(o.isPlotDiv(t)&&c&&p){if(o.isPlainObject(e)){var d=e;e=d.data,n=d.layout,i=d.config,a=d.frames}var g=!1;if(i){var v=o.extendDeep({},t._context);t._context=void 0,O(t,i),g=function t(e,r){var n;for(n in e)if(\"_\"!==n.charAt(0)){var i=e[n],a=r[n];if(i!==a)if(o.isPlainObject(i)&&o.isPlainObject(a)){if(t(i,a))return!0}else{if(!Array.isArray(i)||!Array.isArray(a))return!0;if(i.length!==a.length)return!0;for(var s=0;s<i.length;s++)if(i[s]!==a[s]){if(!o.isPlainObject(i[s])||!o.isPlainObject(a[s]))return!0;if(t(i[s],a[s]))return!0}}}}(v,t._context)}t.data=e||[],k.cleanData(t.data),t.layout=n||{},k.cleanLayout(t.layout),function(t,e,r,n){var i,a,l,c,u,h,f,p,d=n._preGUI,g=[],v={};for(i in d){if(u=rt(i,tt)){if(a=u.attr||u.head+\".uirevision\",(c=(l=s(n,a).get())&&nt(a,e))&&c===l&&(null===(h=d[i])&&(h=void 0),ot(p=(f=s(e,i)).get(),h))){void 0===p&&\"autorange\"===i.substr(i.length-9)&&g.push(i.substr(0,i.length-10)),f.set(N(s(n,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i);delete d[i],\"range[\"===i.substr(i.length-8,6)&&(v[i.substr(0,i.length-9)]=1)}for(var m=0;m<g.length;m++){var y=g[m];if(v[y]){var x=s(e,y).get();x&&delete x.autorange}}var b=n._tracePreGUI;for(var _ in b){var w,k=b[_],T=null;for(i in k){if(!T){var A=it(_,r);if(A<0){delete b[_];break}var M=at(_,t,(w=r[A]._fullInput).index);if(M<0){delete b[_];break}T=t[M]}if(u=rt(i,et)){if(u.attr?c=(l=s(n,u.attr).get())&&nt(u.attr,e):(l=w.uirevision,void 0===(c=T.uirevision)&&(c=e.uirevision)),c&&c===l&&(null===(h=k[i])&&(h=void 0),ot(p=(f=s(T,i)).get(),h))){f.set(N(s(w,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i+\" in trace uid \"+_);delete k[i]}}}(t.data,t.layout,c,p),f.supplyDefaults(t,{skipUpdateCalc:!0});var m=t._fullData,y=t._fullLayout,x=void 0===y.datarevision,b=y.transition,_=function(t,e,r,n,i){var a=A.layoutFlags();return a.arrays={},a.rangesAltered={},a.nChanges=0,a.nChangesAnim=0,st(e,r,[],{getValObject:function(t){return h.getLayoutValObject(r,t)},flags:a,immutable:n,transition:i,gd:t}),(a.plot||a.calc)&&(a.layoutReplot=!0),i&&a.nChanges&&a.nChangesAnim&&(a.anim=a.nChanges===a.nChangesAnim?\"all\":\"some\"),a}(t,p,y,x,b),w=_.newDataRevision,M=function(t,e,r,n,i,a){var o=e.length===r.length;if(!i&&!o)return{fullReplot:!0,calc:!0};var s,l,c=A.traceFlags();c.arrays={},c.nChanges=0,c.nChangesAnim=0;var u={getValObject:function(t){var e=h.getTraceValObject(l,t);return!l._module.animatable&&e.anim&&(e.anim=!1),e},flags:c,immutable:n,transition:i,newDataRevision:a,gd:t},p={};for(s=0;s<e.length;s++)if(r[s]){if(l=r[s]._fullInput,f.hasMakesDataTransform(l)&&(l=r[s]),p[l.uid])continue;p[l.uid]=1,st(e[s]._fullInput,l,[],u)}return(c.calc||c.plot)&&(c.fullReplot=!0),i&&c.nChanges&&c.nChangesAnim&&(c.anim=c.nChanges===c.nChangesAnim&&o?\"all\":\"some\"),c}(t,c,m,x,b,w);K(t)&&(_.layoutReplot=!0),M.calc||_.calc?t.calcdata=void 0:f.supplyDefaultsUpdateCalc(t.calcdata,m);var S=[];if(a&&(t._transitionData={},f.createTransitionData(t),S.push(function(){return r.addFrames(t,a)})),y.transition&&!g&&(M.anim||_.anim))f.doCalcdata(t),T.doAutoRangeAndConstraints(t),S.push(function(){return f.transitionFromReact(t,M,_,p)});else if(M.fullReplot||_.layoutReplot||g)t._fullLayout._skipDefaults=!0,S.push(r.plot);else{for(var E in _.arrays){var L=_.arrays[E];if(L.length){var P=u.getComponentMethod(E,\"drawOne\");if(P!==o.noop)for(var z=0;z<L.length;z++)P(t,L[z]);else{var I=u.getComponentMethod(E,\"draw\");if(I===o.noop)throw new Error(\"cannot draw components: \"+E);I(t)}}}S.push(f.previousPromises),M.style&&S.push(T.doTraceStyle),(M.colorbars||_.colorbars)&&S.push(T.doColorBars),_.legend&&S.push(T.doLegend),_.layoutstyle&&S.push(T.layoutStyles),_.axrange&&Y(S),_.ticks&&S.push(T.doTicksRelayout),_.modebar&&S.push(T.doModeBar),_.camera&&S.push(T.doCamera),S.push(C)}S.push(f.rehover,f.redrag),(l=o.syncOrAsync(S,t))&&l.then||(l=Promise.resolve(t))}else l=r.newPlot(t,e,n,i);return l.then(function(){return t.emit(\"plotly_react\",{data:e,layout:n}),t})},r.redraw=function(t){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);return k.cleanData(t.data),k.cleanLayout(t.layout),t.calcdata=void 0,r.plot(t).then(function(){return t.emit(\"plotly_redraw\"),t})},r.relayout=H,r.restyle=B,r.setPlotConfig=function(t){return o.extendFlat(_,t)},r.update=$,r._guiRelayout=Q(H),r._guiRestyle=Q(B),r._guiUpdate=Q($),r._storeDirectGUIEdit=function(t,e,r){for(var n in r)U(n,s(t,n).get(),r[n],e)}},{\"../components/color\":593,\"../components/drawing\":614,\"../constants/xmlns_namespaces\":696,\"../lib\":719,\"../lib/events\":709,\"../lib/queue\":734,\"../lib/svg_text_utils\":743,\"../plots/cartesian/axes\":767,\"../plots/cartesian/constants\":773,\"../plots/cartesian/graph_interact\":776,\"../plots/cartesian/select\":784,\"../plots/plots\":828,\"../plots/polar/legacy\":836,\"../registry\":847,\"./edit_types\":750,\"./helpers\":751,\"./manage_arrays\":753,\"./plot_config\":755,\"./plot_schema\":756,\"./subroutines\":758,d3:163,\"fast-isnumeric\":225,\"has-hover\":410}],755:[function(t,e,r){\"use strict\";var n={staticPlot:{valType:\"boolean\",dflt:!1},plotlyServerURL:{valType:\"string\",dflt:\"https://plot.ly\"},editable:{valType:\"boolean\",dflt:!1},edits:{annotationPosition:{valType:\"boolean\",dflt:!1},annotationTail:{valType:\"boolean\",dflt:!1},annotationText:{valType:\"boolean\",dflt:!1},axisTitleText:{valType:\"boolean\",dflt:!1},colorbarPosition:{valType:\"boolean\",dflt:!1},colorbarTitleText:{valType:\"boolean\",dflt:!1},legendPosition:{valType:\"boolean\",dflt:!1},legendText:{valType:\"boolean\",dflt:!1},shapePosition:{valType:\"boolean\",dflt:!1},titleText:{valType:\"boolean\",dflt:!1}},autosizable:{valType:\"boolean\",dflt:!1},responsive:{valType:\"boolean\",dflt:!1},fillFrame:{valType:\"boolean\",dflt:!1},frameMargins:{valType:\"number\",dflt:0,min:0,max:.5},scrollZoom:{valType:\"flaglist\",flags:[\"cartesian\",\"gl3d\",\"geo\",\"mapbox\"],extras:[!0,!1],dflt:\"gl3d+geo+mapbox\"},doubleClick:{valType:\"enumerated\",values:[!1,\"reset\",\"autosize\",\"reset+autosize\"],dflt:\"reset+autosize\"},doubleClickDelay:{valType:\"number\",dflt:300,min:0},showAxisDragHandles:{valType:\"boolean\",dflt:!0},showAxisRangeEntryBoxes:{valType:\"boolean\",dflt:!0},showTips:{valType:\"boolean\",dflt:!0},showLink:{valType:\"boolean\",dflt:!1},linkText:{valType:\"string\",dflt:\"Edit chart\",noBlank:!0},sendData:{valType:\"boolean\",dflt:!0},showSources:{valType:\"any\",dflt:!1},displayModeBar:{valType:\"enumerated\",values:[\"hover\",!0,!1],dflt:\"hover\"},showSendToCloud:{valType:\"boolean\",dflt:!1},showEditInChartStudio:{valType:\"boolean\",dflt:!1},modeBarButtonsToRemove:{valType:\"any\",dflt:[]},modeBarButtonsToAdd:{valType:\"any\",dflt:[]},modeBarButtons:{valType:\"any\",dflt:!1},toImageButtonOptions:{valType:\"any\",dflt:{}},displaylogo:{valType:\"boolean\",dflt:!0},watermark:{valType:\"boolean\",dflt:!1},plotGlPixelRatio:{valType:\"number\",dflt:2,min:1,max:4},setBackground:{valType:\"any\",dflt:\"transparent\"},topojsonURL:{valType:\"string\",noBlank:!0,dflt:\"https://cdn.plot.ly/\"},mapboxAccessToken:{valType:\"string\",dflt:null},logging:{valType:\"boolean\",dflt:1},queueLength:{valType:\"integer\",min:0,dflt:0},globalTransforms:{valType:\"any\",dflt:[]},locale:{valType:\"string\",dflt:\"en-US\"},locales:{valType:\"any\",dflt:{}}},i={};!function t(e,r){for(var n in e){var i=e[n];i.valType?r[n]=i.dflt:(r[n]||(r[n]={}),t(i,r[n]))}}(n,i),e.exports={configAttributes:n,dfltConfig:i}},{}],756:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=t(\"../plots/attributes\"),o=t(\"../plots/layout_attributes\"),s=t(\"../plots/frame_attributes\"),l=t(\"../plots/animation_attributes\"),c=t(\"./plot_config\").configAttributes,u=t(\"../plots/polar/legacy/area_attributes\"),h=t(\"../plots/polar/legacy/axis_attributes\"),f=t(\"./edit_types\"),p=i.extendFlat,d=i.extendDeepAll,g=i.isPlainObject,v=i.isArrayOrTypedArray,m=i.nestedProperty,y=i.valObjectMeta,x=\"_isSubplotObj\",b=\"_isLinkedToArray\",_=[x,b,\"_arrayAttrRegexps\",\"_deprecated\"];function w(t,e,r){if(!t)return!1;if(t._isLinkedToArray)if(k(e[r]))r++;else if(r<e.length)return!1;for(;r<e.length;r++){var n=t[e[r]];if(!g(n))break;if(t=n,r===e.length-1)break;if(t._isLinkedToArray){if(!k(e[++r]))return!1}else if(\"info_array\"===t.valType){var i=e[++r];if(!k(i))return!1;var a=t.items;if(Array.isArray(a)){if(i>=a.length)return!1;if(2===t.dimensions){if(r++,e.length===r)return t;var o=e[r];if(!k(o))return!1;t=a[i][o]}else t=a[i]}else t=a}}return t}function k(t){return t===Math.round(t)&&t>=0}function T(t){return function(t){r.crawl(t,function(t,e,n){r.isValObject(t)?\"data_array\"===t.valType?(t.role=\"data\",n[e+\"src\"]={valType:\"string\",editType:\"none\"}):!0===t.arrayOk&&(n[e+\"src\"]={valType:\"string\",editType:\"none\"}):g(t)&&(t.role=\"object\")})}(t),function(t){r.crawl(t,function(t,e,r){if(!t)return;var n=t[b];if(!n)return;delete t[b],r[e]={items:{}},r[e].items[n]=t,r[e].role=\"object\"})}(t),function(t){!function t(e){for(var r in e)if(g(e[r]))t(e[r]);else if(Array.isArray(e[r]))for(var n=0;n<e[r].length;n++)t(e[r][n]);else e[r]instanceof RegExp&&(e[r]=e[r].toString())}(t)}(t),t}function A(t,e,r){var n=m(t,r),i=d({},e.layoutAttributes);i[x]=!0,n.set(i)}function M(t,e,r){var n=m(t,r);n.set(d(n.get()||{},e))}r.IS_SUBPLOT_OBJ=x,r.IS_LINKED_TO_ARRAY=b,r.DEPRECATED=\"_deprecated\",r.UNDERSCORE_ATTRS=_,r.get=function(){var t={};n.allTypes.concat(\"area\").forEach(function(e){t[e]=function(t){var e,i;\"area\"===t?(e={attributes:u},i={}):(e=n.modules[t]._module,i=e.basePlotModule);var o={type:null},s=d({},a),l=d({},e.attributes);r.crawl(l,function(t,e,r,n,i){m(s,i).set(void 0),void 0===t&&m(l,i).set(void 0)}),d(o,s),n.traceIs(t,\"noOpacity\")&&delete o.opacity;n.traceIs(t,\"showLegend\")||(delete o.showlegend,delete o.legendgroup);n.traceIs(t,\"noHover\")&&(delete o.hoverinfo,delete o.hoverlabel);e.selectPoints||delete o.selectedpoints;d(o,l),i.attributes&&d(o,i.attributes);o.type=t;var c={meta:e.meta||{},categories:e.categories||{},animatable:Boolean(e.animatable),type:t,attributes:T(o)};if(e.layoutAttributes){var h={};d(h,e.layoutAttributes),c.layoutAttributes=T(h)}e.animatable||r.crawl(c,function(t){r.isValObject(t)&&\"anim\"in t&&delete t.anim});return c}(e)});var e,i={};return Object.keys(n.transformsRegistry).forEach(function(t){i[t]=function(t){var e=n.transformsRegistry[t],r=d({},e.attributes);return Object.keys(n.componentsRegistry).forEach(function(e){var i=n.componentsRegistry[e];i.schema&&i.schema.transforms&&i.schema.transforms[t]&&Object.keys(i.schema.transforms[t]).forEach(function(e){M(r,i.schema.transforms[t][e],e)})}),{attributes:T(r)}}(t)}),{defs:{valObjects:y,metaKeys:_.concat([\"description\",\"role\",\"editType\",\"impliedEdits\"]),editType:{traces:f.traces,layout:f.layout},impliedEdits:{}},traces:t,layout:function(){var t,e,r={};for(t in d(r,o),n.subplotsRegistry)if((e=n.subplotsRegistry[t]).layoutAttributes)if(Array.isArray(e.attr))for(var i=0;i<e.attr.length;i++)A(r,e,e.attr[i]);else{var a=\"subplot\"===e.attr?e.name:e.attr;A(r,e,a)}for(t in r=function(t){return p(t,{radialaxis:h.radialaxis,angularaxis:h.angularaxis}),p(t,h.layout),t}(r),n.componentsRegistry){var s=(e=n.componentsRegistry[t]).schema;if(s&&(s.subplots||s.layout)){var l=s.subplots;if(l&&l.xaxis&&!l.yaxis)for(var c in l.xaxis)delete r.yaxis[c]}else\"colorscale\"===e.name?d(r,e.layoutAttributes):e.layoutAttributes&&M(r,e.layoutAttributes,e.name)}return{layoutAttributes:T(r)}}(),transforms:i,frames:(e={frames:d({},s)},T(e),e.frames),animation:T(l),config:T(c)}},r.crawl=function(t,e,n,i){var a=n||0;i=i||\"\",Object.keys(t).forEach(function(n){var o=t[n];if(-1===_.indexOf(n)){var s=(i?i+\".\":\"\")+n;e(o,n,t,a,s),r.isValObject(o)||g(o)&&\"impliedEdits\"!==n&&r.crawl(o,e,a+1,s)}})},r.isValObject=function(t){return t&&void 0!==t.valType},r.findArrayAttributes=function(t){var e,n,i=[],o=[],s=[];function l(t,r,a,l){o=o.slice(0,l).concat([r]),s=s.slice(0,l).concat([t&&t._isLinkedToArray]),t&&(\"data_array\"===t.valType||!0===t.arrayOk)&&!(\"colorbar\"===o[l-1]&&(\"ticktext\"===r||\"tickvals\"===r))&&function t(e,r,a){var l=e[o[r]];var c=a+o[r];if(r===o.length-1)v(l)&&i.push(n+c);else if(s[r]){if(Array.isArray(l))for(var u=0;u<l.length;u++)g(l[u])&&t(l[u],r+1,c+\"[\"+u+\"].\")}else g(l)&&t(l,r+1,c+\".\")}(e,0,\"\")}e=t,n=\"\",r.crawl(a,l),t._module&&t._module.attributes&&r.crawl(t._module.attributes,l);var c=t.transforms;if(c)for(var u=0;u<c.length;u++){var h=c[u],f=h._module;f&&(n=\"transforms[\"+u+\"].\",e=h,r.crawl(f.attributes,l))}return i},r.getTraceValObject=function(t,e){var r,i,o=e[0],s=1;if(\"transforms\"===o){if(1===e.length)return a.transforms;var l=t.transforms;if(!Array.isArray(l)||!l.length)return!1;var c=e[1];if(!k(c)||c>=l.length)return!1;i=(r=(n.transformsRegistry[l[c].type]||{}).attributes)&&r[e[2]],s=3}else if(\"area\"===t.type)i=u[o];else{var h=t._module;if(h||(h=(n.modules[t.type||a.type.dflt]||{})._module),!h)return!1;if(!(i=(r=h.attributes)&&r[o])){var f=h.basePlotModule;f&&f.attributes&&(i=f.attributes[o])}i||(i=a[o])}return w(i,e,s)},r.getLayoutValObject=function(t,e){return w(function(t,e){var r,i,a,s,l=t._basePlotModules;if(l){var c;for(r=0;r<l.length;r++){if((a=l[r]).attrRegex&&a.attrRegex.test(e)){if(a.layoutAttrOverrides)return a.layoutAttrOverrides;!c&&a.layoutAttributes&&(c=a.layoutAttributes)}var u=a.baseLayoutAttrOverrides;if(u&&e in u)return u[e]}if(c)return c}var f=t._modules;if(f)for(r=0;r<f.length;r++)if((s=f[r].layoutAttributes)&&e in s)return s[e];for(i in n.componentsRegistry){if(\"colorscale\"===(a=n.componentsRegistry[i]).name&&0===e.indexOf(\"coloraxis\"))return a.layoutAttributes[e];if(!a.schema&&e===a.name)return a.layoutAttributes}if(e in o)return o[e];if(\"radialaxis\"===e||\"angularaxis\"===e)return h[e];return h.layout[e]||!1}(t,e[0]),e,1)}},{\"../lib\":719,\"../plots/animation_attributes\":762,\"../plots/attributes\":764,\"../plots/frame_attributes\":794,\"../plots/layout_attributes\":819,\"../plots/polar/legacy/area_attributes\":834,\"../plots/polar/legacy/axis_attributes\":835,\"../registry\":847,\"./edit_types\":750,\"./plot_config\":755}],757:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/attributes\"),a=\"templateitemname\",o={name:{valType:\"string\",editType:\"none\"}};function s(t){return t&&\"string\"==typeof t}function l(t){var e=t.length-1;return\"s\"!==t.charAt(e)&&n.warn(\"bad argument to arrayDefaultKey: \"+t),t.substr(0,t.length-1)+\"defaults\"}o[a]={valType:\"string\",editType:\"calc\"},r.templatedArray=function(t,e){return e._isLinkedToArray=t,e.name=o.name,e[a]=o[a],e},r.traceTemplater=function(t){var e,r,a={};for(e in t)r=t[e],Array.isArray(r)&&r.length&&(a[e]=0);return{newTrace:function(o){var s={type:e=n.coerce(o,{},i,\"type\"),_template:null};if(e in a){r=t[e];var l=a[e]%r.length;a[e]++,s._template=r[l]}return s}}},r.newContainer=function(t,e,r){var i=t._template,a=i&&(i[e]||r&&i[r]);return n.isPlainObject(a)||(a=null),t[e]={_template:a}},r.arrayTemplater=function(t,e,r){var n=t._template,i=n&&n[l(e)],o=n&&n[e];Array.isArray(o)&&o.length||(o=[]);var c={};return{newItem:function(t){var e={name:t.name,_input:t},n=e[a]=t[a];if(!s(n))return e._template=i,e;for(var l=0;l<o.length;l++){var u=o[l];if(u.name===n)return c[n]=1,e._template=u,e}return e[r]=t[r]||!1,e._template=!1,e},defaultItems:function(){for(var t=[],e=0;e<o.length;e++){var r=o[e],n=r.name;if(s(n)&&!c[n]){var i={_template:r,name:n,_input:{_templateitemname:n}};i[a]=r[a],t.push(i),c[n]=1}}return t}}},r.arrayDefaultKey=l,r.arrayEditor=function(t,e,r){var i=(n.nestedProperty(t,e).get()||[]).length,o=r._index,s=o>=i&&(r._input||{})._templateitemname;s&&(o=i);var l,c=e+\"[\"+o+\"]\";function u(){l={},s&&(l[c]={},l[c][a]=s)}function h(t,e){s?n.nestedProperty(l[c],t).set(e):l[c+\".\"+t]=e}function f(){var t=l;return u(),t}return u(),{modifyBase:function(t,e){l[t]=e},modifyItem:h,getUpdateObj:f,applyUpdate:function(e,r){e&&h(e,r);var i=f();for(var a in i)n.nestedProperty(t,a).set(i[a])}}}},{\"../lib\":719,\"../plots/attributes\":764}],758:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../registry\"),a=t(\"../plots/plots\"),o=t(\"../lib\"),s=t(\"../lib/clear_gl_canvases\"),l=t(\"../components/color\"),c=t(\"../components/drawing\"),u=t(\"../components/titles\"),h=t(\"../components/modebar\"),f=t(\"../plots/cartesian/axes\"),p=t(\"../constants/alignment\"),d=t(\"../plots/cartesian/constraints\"),g=d.enforce,v=d.clean,m=t(\"../plots/cartesian/autorange\").doAutoRange,y=\"start\",x=\"middle\",b=\"end\";function _(t,e,r){for(var n=0;n<r.length;n++){var i=r[n][0],a=r[n][1];if(!(i[0]>=t[1]||i[1]<=t[0])&&(a[0]<e[1]&&a[1]>e[0]))return!0}return!1}function w(t){var e,i,a,s,u,d,g=t._fullLayout,v=g._size,m=v.p,y=f.list(t,\"\",!0);if(g._paperdiv.style({width:t._context.responsive&&g.autosize&&!t._context._hasZeroWidth&&!t.layout.width?\"100%\":g.width+\"px\",height:t._context.responsive&&g.autosize&&!t._context._hasZeroHeight&&!t.layout.height?\"100%\":g.height+\"px\"}).selectAll(\".main-svg\").call(c.setSize,g.width,g.height),t._context.setBackground(t,g.paper_bgcolor),r.drawMainTitle(t),h.manage(t),!g._has(\"cartesian\"))return t._promises.length&&Promise.all(t._promises);function x(t,e,r){var n=t._lw/2;return\"x\"===t._id.charAt(0)?e?\"top\"===r?e._offset-m-n:e._offset+e._length+m+n:v.t+v.h*(1-(t.position||0))+n%1:e?\"right\"===r?e._offset+e._length+m+n:e._offset-m-n:v.l+v.w*(t.position||0)+n%1}for(e=0;e<y.length;e++){var b=(s=y[e])._anchorAxis;s._linepositions={},s._lw=c.crispRound(t,s.linewidth,1),s._mainLinePosition=x(s,b,s.side),s._mainMirrorPosition=s.mirror&&b?x(s,b,p.OPPOSITE_SIDE[s.side]):null}var w=[],T=[],M=[],S=1===l.opacity(g.paper_bgcolor)&&1===l.opacity(g.plot_bgcolor)&&g.paper_bgcolor===g.plot_bgcolor;for(i in g._plots)if((a=g._plots[i]).mainplot)a.bg&&a.bg.remove(),a.bg=void 0;else{var E=a.xaxis.domain,C=a.yaxis.domain,L=a.plotgroup;if(_(E,C,M)){var P=L.node(),O=a.bg=o.ensureSingle(L,\"rect\",\"bg\");P.insertBefore(O.node(),P.childNodes[0]),T.push(i)}else L.select(\"rect.bg\").remove(),M.push([E,C]),S||(w.push(i),T.push(i))}var z,I,D,R,F,B,N,j,U,V,q,H,G,Y=g._bgLayer.selectAll(\".bg\").data(w);for(Y.enter().append(\"rect\").classed(\"bg\",!0),Y.exit().remove(),Y.each(function(t){g._plots[t].bg=n.select(this)}),e=0;e<T.length;e++)a=g._plots[T[e]],u=a.xaxis,d=a.yaxis,a.bg&&a.bg.call(c.setRect,u._offset-m,d._offset-m,u._length+2*m,d._length+2*m).call(l.fill,g.plot_bgcolor).style(\"stroke-width\",0);if(!g._hasOnlyLargeSploms)for(i in g._plots){a=g._plots[i],u=a.xaxis,d=a.yaxis;var W,X,Z=a.clipId=\"clip\"+g._uid+i+\"plot\",J=o.ensureSingleById(g._clips,\"clipPath\",Z,function(t){t.classed(\"plotclip\",!0).append(\"rect\")});a.clipRect=J.select(\"rect\").attr({width:u._length,height:d._length}),c.setTranslate(a.plot,u._offset,d._offset),a._hasClipOnAxisFalse?(W=null,X=Z):(W=Z,X=null),c.setClipUrl(a.plot,W,t),a.layerClipId=X}function K(t){return\"M\"+z+\",\"+t+\"H\"+I}function $(t){return\"M\"+u._offset+\",\"+t+\"h\"+u._length}function Q(t){return\"M\"+t+\",\"+j+\"V\"+N}function tt(t){return\"M\"+t+\",\"+d._offset+\"v\"+d._length}function et(t,e,r){if(!t.showline||i!==t._mainSubplot)return\"\";if(!t._anchorAxis)return r(t._mainLinePosition);var n=e(t._mainLinePosition);return t.mirror&&(n+=e(t._mainMirrorPosition)),n}for(i in g._plots){a=g._plots[i],u=a.xaxis,d=a.yaxis;var rt=\"M0,0\";k(u,i)&&(F=A(u,\"left\",d,y),z=u._offset-(F?m+F:0),B=A(u,\"right\",d,y),I=u._offset+u._length+(B?m+B:0),D=x(u,d,\"bottom\"),R=x(u,d,\"top\"),!(G=!u._anchorAxis||i!==u._mainSubplot)||\"allticks\"!==u.mirror&&\"all\"!==u.mirror||(u._linepositions[i]=[D,R]),rt=et(u,K,$),G&&u.showline&&(\"all\"===u.mirror||\"allticks\"===u.mirror)&&(rt+=K(D)+K(R)),a.xlines.style(\"stroke-width\",u._lw+\"px\").call(l.stroke,u.showline?u.linecolor:\"rgba(0,0,0,0)\")),a.xlines.attr(\"d\",rt);var nt=\"M0,0\";k(d,i)&&(q=A(d,\"bottom\",u,y),N=d._offset+d._length+(q?m:0),H=A(d,\"top\",u,y),j=d._offset-(H?m:0),U=x(d,u,\"left\"),V=x(d,u,\"right\"),!(G=!d._anchorAxis||i!==d._mainSubplot)||\"allticks\"!==d.mirror&&\"all\"!==d.mirror||(d._linepositions[i]=[U,V]),nt=et(d,Q,tt),G&&d.showline&&(\"all\"===d.mirror||\"allticks\"===d.mirror)&&(nt+=Q(U)+Q(V)),a.ylines.style(\"stroke-width\",d._lw+\"px\").call(l.stroke,d.showline?d.linecolor:\"rgba(0,0,0,0)\")),a.ylines.attr(\"d\",nt)}return f.makeClipPaths(t),t._promises.length&&Promise.all(t._promises)}function k(t,e){return(t.ticks||t.showline)&&(e===t._mainSubplot||\"all\"===t.mirror||\"allticks\"===t.mirror)}function T(t,e,r){if(!r.showline||!r._lw)return!1;if(\"all\"===r.mirror||\"allticks\"===r.mirror)return!0;var n=r._anchorAxis;if(!n)return!1;var i=p.FROM_BL[e];return r.side===e?n.domain[i]===t.domain[i]:r.mirror&&n.domain[1-i]===t.domain[1-i]}function A(t,e,r,n){if(T(t,e,r))return r._lw;for(var i=0;i<n.length;i++){var a=n[i];if(a._mainAxis===r._mainAxis&&T(t,e,a))return a._lw}return 0}r.layoutStyles=function(t){return o.syncOrAsync([a.doAutoMargin,w],t)},r.drawMainTitle=function(t){var e=t._fullLayout,r=function(t){var e=t.title,r=x;o.isRightAnchor(e)?r=b:o.isLeftAnchor(e)&&(r=y);return r}(e),n=function(t){var e=t.title,r=\"0em\";o.isTopAnchor(e)?r=p.CAP_SHIFT+\"em\":o.isMiddleAnchor(e)&&(r=p.MID_SHIFT+\"em\");return r}(e);u.draw(t,\"gtitle\",{propContainer:e,propName:\"title.text\",placeholder:e._dfltTitle.plot,attributes:{x:function(t,e){var r=t.title,n=t._size,i=0;e===y?i=r.pad.l:e===b&&(i=-r.pad.r);switch(r.xref){case\"paper\":return n.l+n.w*r.x+i;case\"container\":default:return t.width*r.x+i}}(e,r),y:function(t,e){var r=t.title,n=t._size,i=0;\"0em\"!==e&&e?e===p.CAP_SHIFT+\"em\"&&(i=r.pad.t):i=-r.pad.b;if(\"auto\"===r.y)return n.t/2;switch(r.yref){case\"paper\":return n.t+n.h-n.h*r.y+i;case\"container\":default:return t.height-t.height*r.y+i}}(e,n),\"text-anchor\":r,dy:n}})},r.doTraceStyle=function(t){var e,n=t.calcdata,o=[];for(e=0;e<n.length;e++){var l=n[e],c=l[0]||{},u=c.trace||{},h=u._module||{},f=h.arraysToCalcdata;f&&f(l,u);var p=h.editStyle;p&&o.push({fn:p,cd0:c})}if(o.length){for(e=0;e<o.length;e++){var d=o[e];d.fn(t,d.cd0)}s(t),r.redrawReglTraces(t)}return a.style(t),i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doColorBars=function(t){return i.getComponentMethod(\"colorbar\",\"draw\")(t),a.previousPromises(t)},r.layoutReplot=function(t){var e=t.layout;return t.layout=void 0,i.call(\"plot\",t,\"\",e)},r.doLegend=function(t){return i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doTicksRelayout=function(t){return f.draw(t,\"redraw\"),t._fullLayout._hasOnlyLargeSploms&&(i.subplotsRegistry.splom.updateGrid(t),s(t),r.redrawReglTraces(t)),r.drawMainTitle(t),a.previousPromises(t)},r.doModeBar=function(t){var e=t._fullLayout;h.manage(t);for(var r=0;r<e._basePlotModules.length;r++){var n=e._basePlotModules[r].updateFx;n&&n(t)}return a.previousPromises(t)},r.doCamera=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){var i=e[r[n]],a=i._scene,o=i.camera;a.setCamera(o)}},r.drawData=function(t){var e=t._fullLayout;s(t);for(var n=e._basePlotModules,o=0;o<n.length;o++)n[o].plot(t);return r.redrawReglTraces(t),a.style(t),i.getComponentMethod(\"shapes\",\"draw\")(t),i.getComponentMethod(\"annotations\",\"draw\")(t),e._replotting=!1,a.previousPromises(t)},r.redrawReglTraces=function(t){var e=t._fullLayout;if(e._has(\"regl\")){var r,n,i=t._fullData,a=[],s=[];for(e._hasOnlyLargeSploms&&e._splomGrid.draw(),r=0;r<i.length;r++){var l=i[r];!0===l.visible&&0!==l._length&&(\"splom\"===l.type?e._splomScenes[l.uid].draw():\"scattergl\"===l.type?o.pushUnique(a,l.xaxis+l.yaxis):\"scatterpolargl\"===l.type&&o.pushUnique(s,l.subplot))}for(r=0;r<a.length;r++)(n=e._plots[a[r]])._scene&&n._scene.draw();for(r=0;r<s.length;r++)(n=e[s[r]]._subplot)._scene&&n._scene.draw()}},r.doAutoRangeAndConstraints=function(t){for(var e,r,n=t._fullLayout,i=f.list(t,\"\",!0),a=n._axisMatchGroups||[],s=0;s<i.length;s++)e=i[s],v(t,e),m(t,e);g(t);t:for(var l=0;l<a.length;l++){var c,u=a[l],h=null;for(c in u){if(!1===(e=f.getFromId(t,c)).autorange)continue t;r=o.simpleMap(e.range,e.r2l),h?h[0]<h[1]?(h[0]=Math.min(h[0],r[0]),h[1]=Math.max(h[1],r[1])):(h[0]=Math.max(h[0],r[0]),h[1]=Math.min(h[1],r[1])):h=r}for(c in u)(e=f.getFromId(t,c)).range=o.simpleMap(h,e.l2r),e._input.range=e.range.slice(),e.setScale()}},r.finalDraw=function(t){i.getComponentMethod(\"shapes\",\"draw\")(t),i.getComponentMethod(\"images\",\"draw\")(t),i.getComponentMethod(\"annotations\",\"draw\")(t),i.getComponentMethod(\"rangeslider\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t)},r.drawMarginPushers=function(t){i.getComponentMethod(\"legend\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t),i.getComponentMethod(\"sliders\",\"draw\")(t),i.getComponentMethod(\"updatemenus\",\"draw\")(t),i.getComponentMethod(\"colorbar\",\"draw\")(t)}},{\"../components/color\":593,\"../components/drawing\":614,\"../components/modebar\":652,\"../components/titles\":681,\"../constants/alignment\":688,\"../lib\":719,\"../lib/clear_gl_canvases\":704,\"../plots/cartesian/autorange\":766,\"../plots/cartesian/axes\":767,\"../plots/cartesian/constraints\":774,\"../plots/plots\":828,\"../registry\":847,d3:163}],759:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.isPlainObject,a=t(\"./plot_schema\"),o=t(\"../plots/plots\"),s=t(\"../plots/attributes\"),l=t(\"./plot_template\"),c=t(\"./plot_config\").dfltConfig;function u(t,e){t=n.extendDeep({},t);var r,a,o=Object.keys(t).sort();function s(e,r,n){if(i(r)&&i(e))u(e,r);else if(Array.isArray(r)&&Array.isArray(e)){var o=l.arrayTemplater({_template:t},n);for(a=0;a<r.length;a++){var s=r[a],c=o.newItem(s)._template;c&&u(c,s)}var h=o.defaultItems();for(a=0;a<h.length;a++)r.push(h[a]._template);for(a=0;a<r.length;a++)delete r[a].templateitemname}}for(r=0;r<o.length;r++){var c=o[r],f=t[c];if(c in e?s(f,e[c],c):e[c]=f,h(c)===c)for(var p in e){var d=h(p);p===d||d!==c||p in t||s(f,e[p],c)}}}function h(t){return t.replace(/[0-9]+$/,\"\")}function f(t,e,r,a,o){var s=o&&r(o);for(var c in t){var u=t[c],d=p(t,c,a),g=p(t,c,o),v=r(g);if(!v){var m=h(c);m!==c&&(v=r(g=p(t,m,o)))}if((!s||s!==v)&&!(!v||v._noTemplating||\"data_array\"===v.valType||v.arrayOk&&Array.isArray(u)))if(!v.valType&&i(u))f(u,e,r,d,g);else if(v._isLinkedToArray&&Array.isArray(u))for(var y=!1,x=0,b={},_=0;_<u.length;_++){var w=u[_];if(i(w)){var k=w.name;if(k)b[k]||(f(w,e,r,p(u,x,d),p(u,x,g)),x++,b[k]=1);else if(!y){var T=p(t,l.arrayDefaultKey(c),a),A=p(u,x,d);f(w,e,r,A,p(u,x,g));var M=n.nestedProperty(e,A);n.nestedProperty(e,T).set(M.get()),M.set(null),y=!0}}}else{n.nestedProperty(e,d).set(u)}}}function p(t,e,r){return r?Array.isArray(t)?r+\"[\"+e+\"]\":r+\".\"+e:e}function d(t){for(var e=0;e<t.length;e++)if(i(t[e]))return!0}function g(t){var e;switch(t.code){case\"data\":e=\"The template has no key data.\";break;case\"layout\":e=\"The template has no key layout.\";break;case\"missing\":e=t.path?\"There are no templates for item \"+t.path+\" with name \"+t.templateitemname:\"There are no templates for trace \"+t.index+\", of type \"+t.traceType+\".\";break;case\"unused\":e=t.path?\"The template item at \"+t.path+\" was not used in constructing the plot.\":t.dataCount?\"Some of the templates of type \"+t.traceType+\" were not used. The template has \"+t.templateCount+\" traces, the data only has \"+t.dataCount+\" of this type.\":\"The template has \"+t.templateCount+\" traces of type \"+t.traceType+\" but there are none in the data.\";break;case\"reused\":e=\"Some of the templates of type \"+t.traceType+\" were used more than once. The template has \"+t.templateCount+\" traces, the data has \"+t.dataCount+\" of this type.\"}return t.msg=e,t}r.makeTemplate=function(t){t=n.isPlainObject(t)?t:n.getGraphDiv(t),t=n.extendDeep({_context:c},{data:t.data,layout:t.layout}),o.supplyDefaults(t);var e=t.data||[],r=t.layout||{};r._basePlotModules=t._fullLayout._basePlotModules,r._modules=t._fullLayout._modules;var l={data:{},layout:{}};e.forEach(function(t){var e={};f(t,e,function(t,e){return a.getTraceValObject(t,n.nestedProperty({},e).parts)}.bind(null,t));var r=n.coerce(t,{},s,\"type\"),i=l.data[r];i||(i=l.data[r]=[]),i.push(e)}),f(r,l.layout,function(t,e){return a.getLayoutValObject(t,n.nestedProperty({},e).parts)}.bind(null,r)),delete l.layout.template;var h=r.template;if(i(h)){var p,d,g,v,m,y,x=h.layout;i(x)&&u(x,l.layout);var b=h.data;if(i(b)){for(d in l.data)if(g=b[d],Array.isArray(g)){for(y=(m=l.data[d]).length,v=g.length,p=0;p<y;p++)u(g[p%v],m[p]);for(p=y;p<v;p++)m.push(n.extendDeep({},g[p]))}for(d in b)d in l.data||(l.data[d]=n.extendDeep([],b[d]))}}return l},r.validateTemplate=function(t,e){var r=n.extendDeep({},{_context:c,data:t.data,layout:t.layout}),a=r.layout||{};i(e)||(e=a.template||{});var s=e.layout,l=e.data,u=[];r.layout=a,r.layout.template=e,o.supplyDefaults(r);var f=r._fullLayout,v=r._fullData,m={};if(i(s)?(!function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)&&i(e[n])){var a,o=h(n),s=[];for(a=0;a<r.length;a++)s.push(p(e,n,r[a])),o!==n&&s.push(p(e,o,r[a]));for(a=0;a<s.length;a++)m[s[a]]=1;t(e[n],s)}}(f,[\"layout\"]),function t(e,r){for(var n in e)if(-1===n.indexOf(\"defaults\")&&i(e[n])){var a=p(e,n,r);m[a]?t(e[n],a):u.push({code:\"unused\",path:a})}}(s,\"layout\")):u.push({code:\"layout\"}),i(l)){for(var y,x={},b=0;b<v.length;b++){var _=v[b];x[y=_.type]=(x[y]||0)+1,_._fullInput._template||u.push({code:\"missing\",index:_._fullInput.index,traceType:y})}for(y in l){var w=l[y].length,k=x[y]||0;w>k?u.push({code:\"unused\",traceType:y,templateCount:w,dataCount:k}):k>w&&u.push({code:\"reused\",traceType:y,templateCount:w,dataCount:k})}}else u.push({code:\"data\"});if(function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)){var a=e[n],o=p(e,n,r);i(a)?(Array.isArray(e)&&!1===a._template&&a.templateitemname&&u.push({code:\"missing\",path:o,templateitemname:a.templateitemname}),t(a,o)):Array.isArray(a)&&d(a)&&t(a,o)}}({data:v,layout:f},\"\"),u.length)return u.map(g)}},{\"../lib\":719,\"../plots/attributes\":764,\"../plots/plots\":828,\"./plot_config\":755,\"./plot_schema\":756,\"./plot_template\":757}],760:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./plot_api\"),a=t(\"../lib\"),o=t(\"../snapshot/helpers\"),s=t(\"../snapshot/tosvg\"),l=t(\"../snapshot/svgtoimg\"),c={format:{valType:\"enumerated\",values:[\"png\",\"jpeg\",\"webp\",\"svg\"],dflt:\"png\"},width:{valType:\"number\",min:1},height:{valType:\"number\",min:1},scale:{valType:\"number\",min:0,dflt:1},setBackground:{valType:\"any\",dflt:!1},imageDataOnly:{valType:\"boolean\",dflt:!1}};e.exports=function(t,e){var r,u,h,f;function p(t){return!(t in e)||a.validate(e[t],c[t])}if(e=e||{},a.isPlainObject(t)?(r=t.data||[],u=t.layout||{},h=t.config||{},f={}):(t=a.getGraphDiv(t),r=a.extendDeep([],t.data),u=a.extendDeep({},t.layout),h=t._context,f=t._fullLayout||{}),!p(\"width\")&&null!==e.width||!p(\"height\")&&null!==e.height)throw new Error(\"Height and width should be pixel values.\");if(!p(\"format\"))throw new Error(\"Image format is not jpeg, png, svg or webp.\");var d={};function g(t,r){return a.coerce(e,d,c,t,r)}var v=g(\"format\"),m=g(\"width\"),y=g(\"height\"),x=g(\"scale\"),b=g(\"setBackground\"),_=g(\"imageDataOnly\"),w=document.createElement(\"div\");w.style.position=\"absolute\",w.style.left=\"-5000px\",document.body.appendChild(w);var k=a.extendFlat({},u);m?k.width=m:null===e.width&&n(f.width)&&(k.width=f.width),y?k.height=y:null===e.height&&n(f.height)&&(k.height=f.height);var T=a.extendFlat({},h,{_exportedPlot:!0,staticPlot:!0,setBackground:b}),A=o.getRedrawFunc(w);function M(){return new Promise(function(t){setTimeout(t,o.getDelay(w._fullLayout))})}function S(){return new Promise(function(t,e){var r=s(w,v,x),n=w._fullLayout.width,c=w._fullLayout.height;if(i.purge(w),document.body.removeChild(w),\"svg\"===v)return t(_?r:o.encodeSVG(r));var u=document.createElement(\"canvas\");u.id=a.randstr(),l({format:v,width:n,height:c,scale:x,canvas:u,svg:r,promise:!0}).then(t).catch(e)})}return new Promise(function(t,e){i.plot(w,r,k,T).then(A).then(M).then(S).then(function(e){t(function(t){return _?t.replace(o.IMAGE_URL_PREFIX,\"\"):t}(e))}).catch(function(t){e(t)})})}},{\"../lib\":719,\"../snapshot/helpers\":851,\"../snapshot/svgtoimg\":853,\"../snapshot/tosvg\":855,\"./plot_api\":754,\"fast-isnumeric\":225}],761:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/plots\"),a=t(\"./plot_schema\"),o=t(\"./plot_config\").dfltConfig,s=n.isPlainObject,l=Array.isArray,c=n.isArrayOrTypedArray;function u(t,e,r,i,a,o){o=o||[];for(var h=Object.keys(t),f=0;f<h.length;f++){var v=h[f];if(\"transforms\"!==v){var m=o.slice();m.push(v);var y=t[v],x=e[v],b=g(r,v),_=\"info_array\"===(b||{}).valType,w=\"colorscale\"===(b||{}).valType,k=(b||{}).items;if(d(r,v))if(s(y)&&s(x))u(y,x,b,i,a,m);else if(_&&l(y)){y.length>x.length&&i.push(p(\"unused\",a,m.concat(x.length)));var T,A,M,S,E,C=x.length,L=Array.isArray(k);if(L&&(C=Math.min(C,k.length)),2===b.dimensions)for(A=0;A<C;A++)if(l(y[A])){y[A].length>x[A].length&&i.push(p(\"unused\",a,m.concat(A,x[A].length)));var P=x[A].length;for(T=0;T<(L?Math.min(P,k[A].length):P);T++)M=L?k[A][T]:k,S=y[A][T],E=x[A][T],n.validate(S,M)?E!==S&&E!==+S&&i.push(p(\"dynamic\",a,m.concat(A,T),S,E)):i.push(p(\"value\",a,m.concat(A,T),S))}else i.push(p(\"array\",a,m.concat(A),y[A]));else for(A=0;A<C;A++)M=L?k[A]:k,S=y[A],E=x[A],n.validate(S,M)?E!==S&&E!==+S&&i.push(p(\"dynamic\",a,m.concat(A),S,E)):i.push(p(\"value\",a,m.concat(A),S))}else if(b.items&&!_&&l(y)){var O,z,I=k[Object.keys(k)[0]],D=[];for(O=0;O<x.length;O++){var R=x[O]._index||O;if((z=m.slice()).push(R),s(y[R])&&s(x[O])){D.push(R);var F=y[R],B=x[O];s(F)&&!1!==F.visible&&!1===B.visible?i.push(p(\"invisible\",a,z)):u(F,B,I,i,a,z)}}for(O=0;O<y.length;O++)(z=m.slice()).push(O),s(y[O])?-1===D.indexOf(O)&&i.push(p(\"unused\",a,z)):i.push(p(\"object\",a,z,y[O]))}else!s(y)&&s(x)?i.push(p(\"object\",a,m,y)):c(y)||!c(x)||_||w?v in e?n.validate(y,b)?\"enumerated\"===b.valType&&(b.coerceNumber&&y!==+x||y!==x)&&i.push(p(\"dynamic\",a,m,y,x)):i.push(p(\"value\",a,m,y)):i.push(p(\"unused\",a,m,y)):i.push(p(\"array\",a,m,y));else i.push(p(\"schema\",a,m))}}return i}e.exports=function(t,e){var r,c,h=a.get(),f=[],d={_context:n.extendFlat({},o)};l(t)?(d.data=n.extendDeep([],t),r=t):(d.data=[],r=[],f.push(p(\"array\",\"data\"))),s(e)?(d.layout=n.extendDeep({},e),c=e):(d.layout={},c={},arguments.length>1&&f.push(p(\"object\",\"layout\"))),i.supplyDefaults(d);for(var g=d._fullData,v=r.length,m=0;m<v;m++){var y=r[m],x=[\"data\",m];if(s(y)){var b=g[m],_=b.type,w=h.traces[_].attributes;w.type={valType:\"enumerated\",values:[_]},!1===b.visible&&!1!==y.visible&&f.push(p(\"invisible\",x)),u(y,b,w,f,x);var k=y.transforms,T=b.transforms;if(k){l(k)||f.push(p(\"array\",x,[\"transforms\"])),x.push(\"transforms\");for(var A=0;A<k.length;A++){var M=[\"transforms\",A],S=k[A].type;if(s(k[A])){var E=h.transforms[S]?h.transforms[S].attributes:{};E.type={valType:\"enumerated\",values:Object.keys(h.transforms)},u(k[A],T[A],E,f,x,M)}else f.push(p(\"object\",x,M))}}}else f.push(p(\"object\",x))}return u(c,d._fullLayout,function(t,e){for(var r=t.layout.layoutAttributes,i=0;i<e.length;i++){var a=e[i],o=t.traces[a.type],s=o.layoutAttributes;s&&(a.subplot?n.extendFlat(r[o.attributes.subplot.dflt],s):n.extendFlat(r,s))}return r}(h,g),f,\"layout\"),0===f.length?void 0:f};var h={object:function(t,e){return(\"layout\"===t&&\"\"===e?\"The layout argument\":\"data\"===t[0]&&\"\"===e?\"Trace \"+t[1]+\" in the data argument\":f(t)+\"key \"+e)+\" must be linked to an object container\"},array:function(t,e){return(\"data\"===t?\"The data argument\":f(t)+\"key \"+e)+\" must be linked to an array container\"},schema:function(t,e){return f(t)+\"key \"+e+\" is not part of the schema\"},unused:function(t,e,r){var n=s(r)?\"container\":\"key\";return f(t)+n+\" \"+e+\" did not get coerced\"},dynamic:function(t,e,r,n){return[f(t)+\"key\",e,\"(set to '\"+r+\"')\",\"got reset to\",\"'\"+n+\"'\",\"during defaults.\"].join(\" \")},invisible:function(t,e){return(e?f(t)+\"item \"+e:\"Trace \"+t[1])+\" got defaulted to be not visible\"},value:function(t,e,r){return[f(t)+\"key \"+e,\"is set to an invalid value (\"+r+\")\"].join(\" \")}};function f(t){return l(t)?\"In data trace \"+t[1]+\", \":\"In \"+t+\", \"}function p(t,e,r,i,a){var o,s;r=r||\"\",l(e)?(o=e[0],s=e[1]):(o=e,s=null);var c=function(t){if(!l(t))return String(t);for(var e=\"\",r=0;r<t.length;r++){var n=t[r];\"number\"==typeof n?e=e.substr(0,e.length-1)+\"[\"+n+\"]\":e+=n,r<t.length-1&&(e+=\".\")}return e}(r),u=h[t](e,c,i,a);return n.log(u),{code:t,container:o,trace:s,path:r,astr:c,msg:u}}function d(t,e){var r=m(e),n=r.keyMinusId,i=r.id;return!!(n in t&&t[n]._isSubplotObj&&i)||e in t}function g(t,e){return e in t?t[e]:t[m(e).keyMinusId]}var v=n.counterRegex(\"([a-z]+)\");function m(t){var e=t.match(v);return{keyMinusId:e&&e[1],id:e&&e[2]}}},{\"../lib\":719,\"../plots/plots\":828,\"./plot_config\":755,\"./plot_schema\":756}],762:[function(t,e,r){\"use strict\";e.exports={mode:{valType:\"enumerated\",dflt:\"afterall\",values:[\"immediate\",\"next\",\"afterall\"]},direction:{valType:\"enumerated\",values:[\"forward\",\"reverse\"],dflt:\"forward\"},fromcurrent:{valType:\"boolean\",dflt:!1},frame:{duration:{valType:\"number\",min:0,dflt:500},redraw:{valType:\"boolean\",dflt:!0}},transition:{duration:{valType:\"number\",min:0,dflt:500,editType:\"none\"},easing:{valType:\"enumerated\",dflt:\"cubic-in-out\",values:[\"linear\",\"quad\",\"cubic\",\"sin\",\"exp\",\"circle\",\"elastic\",\"back\",\"bounce\",\"linear-in\",\"quad-in\",\"cubic-in\",\"sin-in\",\"exp-in\",\"circle-in\",\"elastic-in\",\"back-in\",\"bounce-in\",\"linear-out\",\"quad-out\",\"cubic-out\",\"sin-out\",\"exp-out\",\"circle-out\",\"elastic-out\",\"back-out\",\"bounce-out\",\"linear-in-out\",\"quad-in-out\",\"cubic-in-out\",\"sin-in-out\",\"exp-in-out\",\"circle-in-out\",\"elastic-in-out\",\"back-in-out\",\"bounce-in-out\"],editType:\"none\"},ordering:{valType:\"enumerated\",values:[\"layout first\",\"traces first\"],dflt:\"layout first\",editType:\"none\"}}}},{}],763:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\");e.exports=function(t,e,r){var a,o,s=r.name,l=r.inclusionAttr||\"visible\",c=e[s],u=n.isArrayOrTypedArray(t[s])?t[s]:[],h=e[s]=[],f=i.arrayTemplater(e,s,l);for(a=0;a<u.length;a++){var p=u[a];n.isPlainObject(p)?o=f.newItem(p):(o=f.newItem({}))[l]=!1,o._index=a,!1!==o[l]&&r.handleItemDefaults(p,o,e,r),h.push(o)}var d=f.defaultItems();for(a=0;a<d.length;a++)(o=d[a])._index=h.length,r.handleItemDefaults({},o,e,r,{}),h.push(o);if(n.isArrayOrTypedArray(c)){var g=Math.min(c.length,h.length);for(a=0;a<g;a++)n.relinkPrivateKeys(h[a],c[a])}return h}},{\"../lib\":719,\"../plot_api/plot_template\":757}],764:[function(t,e,r){\"use strict\";var n=t(\"../components/fx/attributes\");e.exports={type:{valType:\"enumerated\",values:[],dflt:\"scatter\",editType:\"calc+clearAxisTypes\",_noTemplating:!0},visible:{valType:\"enumerated\",values:[!0,!1,\"legendonly\"],dflt:!0,editType:\"calc\"},showlegend:{valType:\"boolean\",dflt:!0,editType:\"style\"},legendgroup:{valType:\"string\",dflt:\"\",editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"style\"},name:{valType:\"string\",editType:\"style\"},uid:{valType:\"string\",editType:\"plot\",anim:!0},ids:{valType:\"data_array\",editType:\"calc\",anim:!0},customdata:{valType:\"data_array\",editType:\"calc\"},meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},selectedpoints:{valType:\"any\",editType:\"calc\"},hoverinfo:{valType:\"flaglist\",flags:[\"x\",\"y\",\"z\",\"text\",\"name\"],extras:[\"all\",\"none\",\"skip\"],arrayOk:!0,dflt:\"all\",editType:\"none\"},hoverlabel:n.hoverlabel,stream:{token:{valType:\"string\",noBlank:!0,strict:!0,editType:\"calc\"},maxpoints:{valType:\"number\",min:0,max:1e4,dflt:500,editType:\"calc\"},editType:\"calc\"},transforms:{_isLinkedToArray:\"transform\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"}}},{\"../components/fx/attributes\":623}],765:[function(t,e,r){\"use strict\";e.exports={xaxis:{valType:\"subplotid\",dflt:\"x\",editType:\"calc+clearAxisTypes\"},yaxis:{valType:\"subplotid\",dflt:\"y\",editType:\"calc+clearAxisTypes\"}}},{}],766:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").FP_SAFE,o=t(\"../../registry\");function s(t,e){var r,n,a=[],o=l(e),s=c(t,e),u=s.min,h=s.max;if(0===u.length||0===h.length)return i.simpleMap(e.range,e.r2l);var f=u[0].val,p=h[0].val;for(r=1;r<u.length&&f===p;r++)f=Math.min(f,u[r].val);for(r=1;r<h.length&&f===p;r++)p=Math.max(p,h[r].val);var d=!1;if(e.range){var g=i.simpleMap(e.range,e.r2l);d=g[1]<g[0]}\"reversed\"===e.autorange&&(d=!0,e.autorange=!0);var v,m,y,x,b,_,w=e.rangemode,k=\"tozero\"===w,T=\"nonnegative\"===w,A=e._length,M=A/10,S=0;for(r=0;r<u.length;r++)for(v=u[r],n=0;n<h.length;n++)(_=(m=h[n]).val-v.val)>0&&((b=A-o(v)-o(m))>M?_/b>S&&(y=v,x=m,S=_/b):_/A>S&&(y={val:v.val,pad:0},x={val:m.val,pad:0},S=_/A));if(f===p){var E=f-1,C=f+1;if(k)if(0===f)a=[0,1];else{var L=(f>0?h:u).reduce(function(t,e){return Math.max(t,o(e))},0),P=f/(1-Math.min(.5,L/A));a=f>0?[0,P]:[P,0]}else a=T?[Math.max(0,E),Math.max(1,C)]:[E,C]}else k?(y.val>=0&&(y={val:0,pad:0}),x.val<=0&&(x={val:0,pad:0})):T&&(y.val-S*o(y)<0&&(y={val:0,pad:0}),x.val<=0&&(x={val:1,pad:0})),S=(x.val-y.val)/(A-o(y)-o(x)),a=[y.val-S*o(y),x.val+S*o(x)];return d&&a.reverse(),i.simpleMap(a,e.l2r||Number)}function l(t){var e=t._length/20;return\"domain\"===t.constrain&&t._inputDomain&&(e*=(t._inputDomain[1]-t._inputDomain[0])/(t.domain[1]-t.domain[0])),function(t){return t.pad+(t.extrapad?e:0)}}function c(t,e){var r,n,i,a=e._id,o=t._fullData,s=t._fullLayout,l=[],c=[];function f(t,e){for(r=0;r<e.length;r++){var o=t[e[r]],s=(o._extremes||{})[a];if(!0===o.visible&&s){for(n=0;n<s.min.length;n++)i=s.min[n],u(l,i.val,i.pad,{extrapad:i.extrapad});for(n=0;n<s.max.length;n++)i=s.max[n],h(c,i.val,i.pad,{extrapad:i.extrapad})}}}return f(o,e._traceIndices),f(s.annotations||[],e._annIndices||[]),f(s.shapes||[],e._shapeIndices||[]),{min:l,max:c}}function u(t,e,r,n){f(t,e,r,n,d)}function h(t,e,r,n){f(t,e,r,n,g)}function f(t,e,r,n,i){for(var a=n.tozero,o=n.extrapad,s=!0,l=0;l<t.length&&s;l++){var c=t[l];if(i(c.val,e)&&c.pad>=r&&(c.extrapad||!o)){s=!1;break}i(e,c.val)&&c.pad<=r&&(o||!c.extrapad)&&(t.splice(l,1),l--)}if(s){var u=a&&0===e;t.push({val:e,pad:u?0:r,extrapad:!u&&o})}}function p(t){return n(t)&&Math.abs(t)<a}function d(t,e){return t<=e}function g(t,e){return t>=e}e.exports={getAutoRange:s,makePadFn:l,doAutoRange:function(t,e){if(e.setScale(),e.autorange){e.range=s(t,e),e._r=e.range.slice(),e._rl=i.simpleMap(e._r,e.r2l);var r=e._input,n={};n[e._attr+\".range\"]=e.range,n[e._attr+\".autorange\"]=e.autorange,o.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,n),r.range=e.range.slice(),r.autorange=e.autorange}var a=e._anchorAxis;if(a&&a.rangeslider){var l=a.rangeslider[e._name];l&&\"auto\"===l.rangemode&&(l.range=s(t,e)),a._input.rangeslider[e._name]=i.extendFlat({},l)}},findExtremes:function(t,e,r){r||(r={});t._m||t.setScale();var i,o,s,l,c,f,d,g,v,m=[],y=[],x=e.length,b=r.padded||!1,_=r.tozero&&(\"linear\"===t.type||\"-\"===t.type),w=\"log\"===t.type,k=!1;function T(t){if(Array.isArray(t))return k=!0,function(e){return Math.max(Number(t[e]||0),0)};var e=Math.max(Number(t||0),0);return function(){return e}}var A=T((t._m>0?r.ppadplus:r.ppadminus)||r.ppad||0),M=T((t._m>0?r.ppadminus:r.ppadplus)||r.ppad||0),S=T(r.vpadplus||r.vpad),E=T(r.vpadminus||r.vpad);if(!k){if(g=1/0,v=-1/0,w)for(i=0;i<x;i++)(o=e[i])<g&&o>0&&(g=o),o>v&&o<a&&(v=o);else for(i=0;i<x;i++)(o=e[i])<g&&o>-a&&(g=o),o>v&&o<a&&(v=o);e=[g,v],x=2}var C={tozero:_,extrapad:b};function L(r){s=e[r],n(s)&&(f=A(r),d=M(r),g=s-E(r),v=s+S(r),w&&g<v/10&&(g=v/10),l=t.c2l(g),c=t.c2l(v),_&&(l=Math.min(0,l),c=Math.max(0,c)),p(l)&&u(m,l,d,C),p(c)&&h(y,c,f,C))}var P=Math.min(6,x);for(i=0;i<P;i++)L(i);for(i=x-1;i>=P;i--)L(i);return{min:m,max:y,opts:r}},concatExtremes:c}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../registry\":847,\"fast-isnumeric\":225}],767:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../components/titles\"),u=t(\"../../components/color\"),h=t(\"../../components/drawing\"),f=t(\"./layout_attributes\"),p=t(\"./clean_ticks\"),d=t(\"../../constants/numerical\"),g=d.ONEAVGYEAR,v=d.ONEAVGMONTH,m=d.ONEDAY,y=d.ONEHOUR,x=d.ONEMIN,b=d.ONESEC,_=d.MINUS_SIGN,w=d.BADNUM,k=t(\"../../constants/alignment\").MID_SHIFT,T=t(\"../../constants/alignment\").LINE_SPACING,A=e.exports={};A.setConvert=t(\"./set_convert\");var M=t(\"./axis_autotype\"),S=t(\"./axis_ids\");A.id2name=S.id2name,A.name2id=S.name2id,A.cleanId=S.cleanId,A.list=S.list,A.listIds=S.listIds,A.getFromId=S.getFromId,A.getFromTrace=S.getFromTrace;var E=t(\"./autorange\");A.getAutoRange=E.getAutoRange,A.findExtremes=E.findExtremes,A.coerceRef=function(t,e,r,n,i,a){var o=n.charAt(n.length-1),l=r._fullLayout._subplots[o+\"axis\"],c=n+\"ref\",u={};return i||(i=l[0]||a),a||(a=i),u[c]={valType:\"enumerated\",values:l.concat(a?[a]:[]),dflt:i},s.coerce(t,e,u,c)},A.coercePosition=function(t,e,r,n,i,a){var o,l;if(\"paper\"===n||\"pixel\"===n)o=s.ensureNumber,l=r(i,a);else{var c=A.getFromId(e,n);l=r(i,a=c.fraction2r(a)),o=c.cleanPos}t[i]=o(l)},A.cleanPosition=function(t,e,r){return(\"paper\"===r||\"pixel\"===r?s.ensureNumber:A.getFromId(e,r).cleanPos)(t)},A.redrawComponents=function(t,e){e=e||A.listIds(t);var r=t._fullLayout;function n(n,i,a,s){for(var l=o.getComponentMethod(n,i),c={},u=0;u<e.length;u++)for(var h=r[A.id2name(e[u])][a],f=0;f<h.length;f++){var p=h[f];if(!c[p]&&(l(t,p),c[p]=1,s))return}}n(\"annotations\",\"drawOne\",\"_annIndices\"),n(\"shapes\",\"drawOne\",\"_shapeIndices\"),n(\"images\",\"draw\",\"_imgIndices\",!0)};var C=A.getDataConversions=function(t,e,r,n){var i,a=\"x\"===r||\"y\"===r||\"z\"===r?r:n;if(Array.isArray(a)){if(i={type:M(n),_categories:[]},A.setConvert(i),\"category\"===i.type)for(var o=0;o<n.length;o++)i.d2c(n[o])}else i=A.getFromTrace(t,e,a);return i?{d2c:i.d2c,c2d:i.c2d}:\"ids\"===a?{d2c:P,c2d:P}:{d2c:L,c2d:L}};function L(t){return+t}function P(t){return String(t)}A.getDataToCoordFunc=function(t,e,r,n){return C(t,e,r,n).d2c},A.counterLetter=function(t){var e=t.charAt(0);return\"x\"===e?\"y\":\"y\"===e?\"x\":void 0},A.minDtick=function(t,e,r,n){-1===[\"log\",\"category\",\"multicategory\"].indexOf(t.type)&&n?void 0===t._minDtick?(t._minDtick=e,t._forceTick0=r):t._minDtick&&((t._minDtick/e+1e-6)%1<2e-6&&((r-t._forceTick0)/e%1+1.000001)%1<2e-6?(t._minDtick=e,t._forceTick0=r):((e/t._minDtick+1e-6)%1>2e-6||((r-t._forceTick0)/t._minDtick%1+1.000001)%1>2e-6)&&(t._minDtick=0)):t._minDtick=0},A.saveRangeInitial=function(t,e){for(var r=A.list(t,\"\",!0),n=!1,i=0;i<r.length;i++){var a=r[i],o=void 0===a._rangeInitial,s=o||!(a.range[0]===a._rangeInitial[0]&&a.range[1]===a._rangeInitial[1]);(o&&!1===a.autorange||e&&s)&&(a._rangeInitial=a.range.slice(),n=!0)}return n},A.saveShowSpikeInitial=function(t,e){for(var r=A.list(t,\"\",!0),n=!1,i=\"on\",a=0;a<r.length;a++){var o=r[a],s=void 0===o._showSpikeInitial,l=s||!(o.showspikes===o._showspikes);(s||e&&l)&&(o._showSpikeInitial=o.showspikes,n=!0),\"on\"!==i||o.showspikes||(i=\"off\")}return t._fullLayout._cartesianSpikesEnabled=i,n},A.autoBin=function(t,e,r,n,a,o){var l,c=s.aggNums(Math.min,null,t),u=s.aggNums(Math.max,null,t);if(\"category\"===e.type||\"multicategory\"===e.type)return{start:c-.5,end:u+.5,size:Math.max(1,Math.round(o)||1),_dataSpan:u-c};if(a||(a=e.calendar),l=\"log\"===e.type?{type:\"linear\",range:[c,u]}:{type:e.type,range:s.simpleMap([c,u],e.c2r,0,a),calendar:a},A.setConvert(l),o=o&&p.dtick(o,l.type))l.dtick=o,l.tick0=p.tick0(void 0,l.type,a);else{var h;if(r)h=(u-c)/r;else{var f=s.distinctVals(t),d=Math.pow(10,Math.floor(Math.log(f.minDiff)/Math.LN10)),g=d*s.roundUp(f.minDiff/d,[.9,1.9,4.9,9.9],!0);h=Math.max(g,2*s.stdev(t)/Math.pow(t.length,n?.25:.4)),i(h)||(h=1)}A.autoTicks(l,h)}var v,y=l.dtick,x=A.tickIncrement(A.tickFirst(l),y,\"reverse\",a);if(\"number\"==typeof y)v=(x=function(t,e,r,n,a){var o=0,s=0,l=0,c=0;function u(e){return(1+100*(e-t)/r.dtick)%100<2}for(var h=0;h<e.length;h++)e[h]%1==0?l++:i(e[h])||c++,u(e[h])&&o++,u(e[h]+r.dtick/2)&&s++;var f=e.length-c;if(l===f&&\"date\"!==r.type)r.dtick<1?t=n-.5*r.dtick:(t-=.5)+r.dtick<n&&(t+=r.dtick);else if(s<.1*f&&(o>.3*f||u(n)||u(a))){var p=r.dtick/2;t+=t+p<n?p:-p}return t}(x,t,l,c,u))+(1+Math.floor((u-x)/y))*y;else for(\"M\"===l.dtick.charAt(0)&&(x=function(t,e,r,n,i){var a=s.findExactDates(e,i);if(a.exactDays>.8){var o=Number(r.substr(1));a.exactYears>.8&&o%12==0?t=A.tickIncrement(t,\"M6\",\"reverse\")+1.5*m:a.exactMonths>.8?t=A.tickIncrement(t,\"M1\",\"reverse\")+15.5*m:t-=m/2;var l=A.tickIncrement(t,r);if(l<=n)return l}return t}(x,t,y,c,a)),v=x,0;v<=u;)v=A.tickIncrement(v,y,!1,a),0;return{start:e.c2r(x,0,a),end:e.c2r(v,0,a),size:y,_dataSpan:u-c}},A.prepTicks=function(t){var e=s.simpleMap(t.range,t.r2l);if(\"auto\"===t.tickmode||!t.dtick){var r,n=t.nticks;n||(\"category\"===t.type||\"multicategory\"===t.type?(r=t.tickfont?1.2*(t.tickfont.size||12):15,n=t._length/r):(r=\"y\"===t._id.charAt(0)?40:80,n=s.constrain(t._length/r,4,9)+1),\"radialaxis\"===t._name&&(n*=2)),\"array\"===t.tickmode&&(n*=100),A.autoTicks(t,Math.abs(e[1]-e[0])/n),t._minDtick>0&&t.dtick<2*t._minDtick&&(t.dtick=t._minDtick,t.tick0=t.l2r(t._forceTick0))}t.tick0||(t.tick0=\"date\"===t.type?\"2000-01-01\":0),\"date\"===t.type&&t.dtick<.1&&(t.dtick=.1),j(t)},A.calcTicks=function(t){A.prepTicks(t);var e=s.simpleMap(t.range,t.r2l);if(\"array\"===t.tickmode)return function(t){var e=t.tickvals,r=t.ticktext,n=new Array(e.length),i=s.simpleMap(t.range,t.r2l),a=1.0001*i[0]-1e-4*i[1],o=1.0001*i[1]-1e-4*i[0],l=Math.min(a,o),c=Math.max(a,o),u=0;Array.isArray(r)||(r=[]);var h=\"category\"===t.type?t.d2l_noadd:t.d2l;\"log\"===t.type&&\"L\"!==String(t.dtick).charAt(0)&&(t.dtick=\"L\"+Math.pow(10,Math.floor(Math.min(t.range[0],t.range[1]))-1));for(var f=0;f<e.length;f++){var p=h(e[f]);p>l&&p<c&&(void 0===r[f]?n[u]=A.tickText(t,p):n[u]=U(t,p,String(r[f])),u++)}u<e.length&&n.splice(u,e.length-u);return n}(t);t._tmin=A.tickFirst(t);var r=1.0001*e[0]-1e-4*e[1],n=1.0001*e[1]-1e-4*e[0],a=e[1]<e[0];if(t._tmin<r!==a)return[];var o=[];\"category\"!==t.type&&\"multicategory\"!==t.type||(n=a?Math.max(-.5,n):Math.min(t._categories.length-.5,n));for(var l=\"log\"===t.type&&!(i(t.dtick)||\"L\"===t.dtick.charAt(0)),c=null,u=Math.max(1e3,t._length||0),h=t._tmin;(a?h>=n:h<=n)&&!(o.length>u||h===c);h=A.tickIncrement(h,t.dtick,a,t.calendar)){c=h;var f=!1;l&&h!==(0|h)&&(f=!0),o.push({minor:f,value:h})}rt(t)&&360===Math.abs(e[1]-e[0])&&o.pop(),t._tmax=(o[o.length-1]||{}).value,t._prevDateHead=\"\",t._inCalcTicks=!0;for(var p=new Array(o.length),d=0;d<o.length;d++)p[d]=A.tickText(t,o[d].value,!1,o[d].minor);return t._inCalcTicks=!1,p};var O=[2,5,10],z=[1,2,3,6,12],I=[1,2,5,10,15,30],D=[1,2,3,7,14],R=[-.046,0,.301,.477,.602,.699,.778,.845,.903,.954,1],F=[-.301,0,.301,.699,1],B=[15,30,45,90,180];function N(t,e,r){return e*s.roundUp(t/e,r)}function j(t){var e=t.dtick;if(t._tickexponent=0,i(e)||\"string\"==typeof e||(e=1),\"category\"!==t.type&&\"multicategory\"!==t.type||(t._tickround=null),\"date\"===t.type){var r=t.r2l(t.tick0),n=t.l2r(r).replace(/(^-|i)/g,\"\"),a=n.length;if(\"M\"===String(e).charAt(0))a>10||\"01-01\"!==n.substr(5)?t._tickround=\"d\":t._tickround=+e.substr(1)%12==0?\"y\":\"m\";else if(e>=m&&a<=10||e>=15*m)t._tickround=\"d\";else if(e>=x&&a<=16||e>=y)t._tickround=\"M\";else if(e>=b&&a<=19||e>=x)t._tickround=\"S\";else{var o=t.l2r(r+e).replace(/^-/,\"\").length;t._tickround=Math.max(a,o)-20,t._tickround<0&&(t._tickround=4)}}else if(i(e)||\"L\"===e.charAt(0)){var s=t.range.map(t.r2d||Number);i(e)||(e=Number(e.substr(1))),t._tickround=2-Math.floor(Math.log(e)/Math.LN10+.01);var l=Math.max(Math.abs(s[0]),Math.abs(s[1])),c=Math.floor(Math.log(l)/Math.LN10+.01);Math.abs(c)>3&&(q(t.exponentformat)&&!H(c)?t._tickexponent=3*Math.round((c-1)/3):t._tickexponent=c)}else t._tickround=null}function U(t,e,r){var n=t.tickfont||{};return{x:e,dx:0,dy:0,text:r||\"\",fontSize:n.size,font:n.family,fontColor:n.color}}A.autoTicks=function(t,e){var r;function n(t){return Math.pow(t,Math.floor(Math.log(e)/Math.LN10))}if(\"date\"===t.type){t.tick0=s.dateTick0(t.calendar);var a=2*e;a>g?(e/=g,r=n(10),t.dtick=\"M\"+12*N(e,r,O)):a>v?(e/=v,t.dtick=\"M\"+N(e,1,z)):a>m?(t.dtick=N(e,m,D),t.tick0=s.dateTick0(t.calendar,!0)):a>y?t.dtick=N(e,y,z):a>x?t.dtick=N(e,x,I):a>b?t.dtick=N(e,b,I):(r=n(10),t.dtick=N(e,r,O))}else if(\"log\"===t.type){t.tick0=0;var o=s.simpleMap(t.range,t.r2l);if(e>.7)t.dtick=Math.ceil(e);else if(Math.abs(o[1]-o[0])<1){var l=1.5*Math.abs((o[1]-o[0])/e);e=Math.abs(Math.pow(10,o[1])-Math.pow(10,o[0]))/l,r=n(10),t.dtick=\"L\"+N(e,r,O)}else t.dtick=e>.3?\"D2\":\"D1\"}else\"category\"===t.type||\"multicategory\"===t.type?(t.tick0=0,t.dtick=Math.ceil(Math.max(e,1))):rt(t)?(t.tick0=0,r=1,t.dtick=N(e,r,B)):(t.tick0=0,r=n(10),t.dtick=N(e,r,O));if(0===t.dtick&&(t.dtick=1),!i(t.dtick)&&\"string\"!=typeof t.dtick){var c=t.dtick;throw t.dtick=1,\"ax.dtick error: \"+String(c)}},A.tickIncrement=function(t,e,r,a){var o=r?-1:1;if(i(e))return t+o*e;var l=e.charAt(0),c=o*Number(e.substr(1));if(\"M\"===l)return s.incrementMonth(t,c,a);if(\"L\"===l)return Math.log(Math.pow(10,t)+c)/Math.LN10;if(\"D\"===l){var u=\"D2\"===e?F:R,h=t+.01*o,f=s.roundUp(s.mod(h,1),u,r);return Math.floor(h)+Math.log(n.round(Math.pow(10,f),1))/Math.LN10}throw\"unrecognized dtick \"+String(e)},A.tickFirst=function(t){var e=t.r2l||Number,r=s.simpleMap(t.range,e),a=r[1]<r[0],o=a?Math.floor:Math.ceil,l=1.0001*r[0]-1e-4*r[1],c=t.dtick,u=e(t.tick0);if(i(c)){var h=o((l-u)/c)*c+u;return\"category\"!==t.type&&\"multicategory\"!==t.type||(h=s.constrain(h,0,t._categories.length-1)),h}var f=c.charAt(0),p=Number(c.substr(1));if(\"M\"===f){for(var d,g,v,m=0,y=u;m<10;){if(((d=A.tickIncrement(y,c,a,t.calendar))-l)*(y-l)<=0)return a?Math.min(y,d):Math.max(y,d);g=(l-(y+d)/2)/(d-y),v=f+(Math.abs(Math.round(g))||1)*p,y=A.tickIncrement(y,v,g<0?!a:a,t.calendar),m++}return s.error(\"tickFirst did not converge\",t),y}if(\"L\"===f)return Math.log(o((Math.pow(10,l)-u)/p)*p+u)/Math.LN10;if(\"D\"===f){var x=\"D2\"===c?F:R,b=s.roundUp(s.mod(l,1),x,a);return Math.floor(l)+Math.log(n.round(Math.pow(10,b),1))/Math.LN10}throw\"unrecognized dtick \"+String(c)},A.tickText=function(t,e,r,n){var a,o=U(t,e),l=\"array\"===t.tickmode,c=r||l,u=t.type,h=\"category\"===u?t.d2l_noadd:t.d2l;if(l&&Array.isArray(t.ticktext)){var f=s.simpleMap(t.range,t.r2l),p=Math.abs(f[1]-f[0])/1e4;for(a=0;a<t.ticktext.length&&!(Math.abs(e-h(t.tickvals[a]))<p);a++);if(a<t.ticktext.length)return o.text=String(t.ticktext[a]),o}function d(n){if(void 0===n)return!0;if(r)return\"none\"===n;var i={first:t._tmin,last:t._tmax}[n];return\"all\"!==n&&e!==i}var g=r?\"never\":\"none\"!==t.exponentformat&&d(t.showexponent)?\"hide\":\"\";if(\"date\"===u?function(t,e,r,n){var a=t._tickround,o=r&&t.hoverformat||A.getTickFormat(t);n&&(a=i(a)?4:{y:\"m\",m:\"d\",d:\"M\",M:\"S\",S:4}[a]);var l,c=s.formatDate(e.x,o,a,t._dateFormat,t.calendar,t._extraFormat),u=c.indexOf(\"\\n\");-1!==u&&(l=c.substr(u+1),c=c.substr(0,u));n&&(\"00:00:00\"===c||\"00:00\"===c?(c=l,l=\"\"):8===c.length&&(c=c.replace(/:00$/,\"\")));l&&(r?\"d\"===a?c+=\", \"+l:c=l+(c?\", \"+c:\"\"):t._inCalcTicks&&l===t._prevDateHead||(c+=\"<br>\"+l,t._prevDateHead=l));e.text=c}(t,o,r,c):\"log\"===u?function(t,e,r,n,a){var o=t.dtick,l=e.x,c=t.tickformat,u=\"string\"==typeof o&&o.charAt(0);\"never\"===a&&(a=\"\");n&&\"L\"!==u&&(o=\"L3\",u=\"L\");if(c||\"L\"===u)e.text=G(Math.pow(10,l),t,a,n);else if(i(o)||\"D\"===u&&s.mod(l+.01,1)<.1){var h=Math.round(l),f=Math.abs(h),p=t.exponentformat;\"power\"===p||q(p)&&H(h)?(e.text=0===h?1:1===h?\"10\":\"10<sup>\"+(h>1?\"\":_)+f+\"</sup>\",e.fontSize*=1.25):(\"e\"===p||\"E\"===p)&&f>2?e.text=\"1\"+p+(h>0?\"+\":_)+f:(e.text=G(Math.pow(10,l),t,\"\",\"fakehover\"),\"D1\"===o&&\"y\"===t._id.charAt(0)&&(e.dy-=e.fontSize/6))}else{if(\"D\"!==u)throw\"unrecognized dtick \"+String(o);e.text=String(Math.round(Math.pow(10,s.mod(l,1)))),e.fontSize*=.75}if(\"D1\"===t.dtick){var d=String(e.text).charAt(0);\"0\"!==d&&\"1\"!==d||(\"y\"===t._id.charAt(0)?e.dx-=e.fontSize/4:(e.dy+=e.fontSize/2,e.dx+=(t.range[1]>t.range[0]?1:-1)*e.fontSize*(l<0?.5:.25)))}}(t,o,0,c,g):\"category\"===u?function(t,e){var r=t._categories[Math.round(e.x)];void 0===r&&(r=\"\");e.text=String(r)}(t,o):\"multicategory\"===u?function(t,e,r){var n=Math.round(e.x),i=t._categories[n]||[],a=void 0===i[1]?\"\":String(i[1]),o=void 0===i[0]?\"\":String(i[0]);r?e.text=o+\" - \"+a:(e.text=a,e.text2=o)}(t,o,r):rt(t)?function(t,e,r,n,i){if(\"radians\"!==t.thetaunit||r)e.text=G(e.x,t,i,n);else{var a=e.x/180;if(0===a)e.text=\"0\";else{var o=function(t){function e(t,e){return Math.abs(t-e)<=1e-6}var r=function(t){var r=1;for(;!e(Math.round(t*r)/r,t);)r*=10;return r}(t),n=t*r,i=Math.abs(function t(r,n){return e(n,0)?r:t(n,r%n)}(n,r));return[Math.round(n/i),Math.round(r/i)]}(a);if(o[1]>=100)e.text=G(s.deg2rad(e.x),t,i,n);else{var l=e.x<0;1===o[1]?1===o[0]?e.text=\"\\u03c0\":e.text=o[0]+\"\\u03c0\":e.text=[\"<sup>\",o[0],\"</sup>\",\"\\u2044\",\"<sub>\",o[1],\"</sub>\",\"\\u03c0\"].join(\"\"),l&&(e.text=_+e.text)}}}}(t,o,r,c,g):function(t,e,r,n,i){\"never\"===i?i=\"\":\"all\"===t.showexponent&&Math.abs(e.x/t.dtick)<1e-6&&(i=\"hide\");e.text=G(e.x,t,i,n)}(t,o,0,c,g),n||(t.tickprefix&&!d(t.showtickprefix)&&(o.text=t.tickprefix+o.text),t.ticksuffix&&!d(t.showticksuffix)&&(o.text+=t.ticksuffix)),\"boundaries\"===t.tickson||t.showdividers){var v=function(e){var r=t.l2p(e);return r>=0&&r<=t._length?e:null};o.xbnd=[v(o.x-.5),v(o.x+t.dtick-.5)]}return o},A.hoverLabelText=function(t,e,r){if(r!==w&&r!==e)return A.hoverLabelText(t,e)+\" - \"+A.hoverLabelText(t,r);var n=\"log\"===t.type&&e<=0,i=A.tickText(t,t.c2l(n?-e:e),\"hover\").text;return n?0===e?\"0\":_+i:i};var V=[\"f\",\"p\",\"n\",\"\\u03bc\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\"];function q(t){return\"SI\"===t||\"B\"===t}function H(t){return t>14||t<-15}function G(t,e,r,n){var a=t<0,o=e._tickround,l=r||e.exponentformat||\"B\",c=e._tickexponent,u=A.getTickFormat(e),h=e.separatethousands;if(n){var f={exponentformat:l,dtick:\"none\"===e.showexponent?e.dtick:i(t)&&Math.abs(t)||1,range:\"none\"===e.showexponent?e.range.map(e.r2d):[0,t||1]};j(f),o=(Number(f._tickround)||0)+4,c=f._tickexponent,e.hoverformat&&(u=e.hoverformat)}if(u)return e._numFormat(u)(t).replace(/-/g,_);var p,d=Math.pow(10,-o)/2;if(\"none\"===l&&(c=0),(t=Math.abs(t))<d)t=\"0\",a=!1;else{if(t+=d,c&&(t*=Math.pow(10,-c),o+=c),0===o)t=String(Math.floor(t));else if(o<0){t=(t=String(Math.round(t))).substr(0,t.length+o);for(var g=o;g<0;g++)t+=\"0\"}else{var v=(t=String(t)).indexOf(\".\")+1;v&&(t=t.substr(0,v+o).replace(/\\.?0+$/,\"\"))}t=s.numSeparate(t,e._separators,h)}c&&\"hide\"!==l&&(q(l)&&H(c)&&(l=\"power\"),p=c<0?_+-c:\"power\"!==l?\"+\"+c:String(c),\"e\"===l||\"E\"===l?t+=l+p:\"power\"===l?t+=\"\\xd710<sup>\"+p+\"</sup>\":\"B\"===l&&9===c?t+=\"B\":q(l)&&(t+=V[c/3+5]));return a?_+t:t}function Y(t,e){var r=t._id.charAt(0),n=t._tickAngles[e]||0,i=s.deg2rad(n),a=Math.sin(i),o=Math.cos(i),l=0,c=0;return t._selections[e].each(function(){var t=J(this),e=h.bBox(t.node()),r=e.width,n=e.height;l=Math.max(l,o*r,a*n),c=Math.max(c,a*r,o*n)}),{x:c,y:l}[r]}function W(t){return[t.text,t.x,t.axInfo,t.font,t.fontSize,t.fontColor].join(\"_\")}function X(t,e){var r,n=t._fullLayout._size,i=e._id.charAt(0),a=e.side;return\"free\"!==e.anchor?r=S.getFromId(t,e.anchor):\"x\"===i?r={_offset:n.t+(1-(e.position||0))*n.h,_length:0}:\"y\"===i&&(r={_offset:n.l+(e.position||0)*n.w,_length:0}),\"top\"===a||\"left\"===a?r._offset:\"bottom\"===a||\"right\"===a?r._offset+r._length:void 0}function Z(t,e){var r=t.l2p(e);return r>1&&r<t._length-1}function J(t){var e=n.select(t),r=e.select(\".text-math-group\");return r.empty()?e.select(\"text\"):r}function K(t){return t._id+\".automargin\"}function $(t){return t._id+\".rangeslider\"}function Q(t,e){for(var r=0;r<e.length;r++)-1===t.indexOf(e[r])&&t.push(e[r])}function tt(t,e,r){var n,i,a=[],o=[],l=t.layout;for(n=0;n<e.length;n++)a.push(A.getFromId(t,e[n]));for(n=0;n<r.length;n++)o.push(A.getFromId(t,r[n]));var c=Object.keys(f),u=[\"anchor\",\"domain\",\"overlaying\",\"position\",\"side\",\"tickangle\",\"editType\"],h=[\"linear\",\"log\"];for(n=0;n<c.length;n++){var p=c[n],d=a[0][p],g=o[0][p],v=!0,m=!1,y=!1;if(\"_\"!==p.charAt(0)&&\"function\"!=typeof d&&-1===u.indexOf(p)){for(i=1;i<a.length&&v;i++){var x=a[i][p];\"type\"===p&&-1!==h.indexOf(d)&&-1!==h.indexOf(x)&&d!==x?m=!0:x!==d&&(v=!1)}for(i=1;i<o.length&&v;i++){var b=o[i][p];\"type\"===p&&-1!==h.indexOf(g)&&-1!==h.indexOf(b)&&g!==b?y=!0:o[i][p]!==g&&(v=!1)}v&&(m&&(l[a[0]._name].type=\"linear\"),y&&(l[o[0]._name].type=\"linear\"),et(l,p,a,o,t._fullLayout._dfltTitle))}}for(n=0;n<t._fullLayout.annotations.length;n++){var _=t._fullLayout.annotations[n];-1!==e.indexOf(_.xref)&&-1!==r.indexOf(_.yref)&&s.swapAttrs(l.annotations[n],[\"?\"])}}function et(t,e,r,n,i){var a,o=s.nestedProperty,l=o(t[r[0]._name],e).get(),c=o(t[n[0]._name],e).get();for(\"title\"===e&&(l&&l.text===i.x&&(l.text=i.y),c&&c.text===i.y&&(c.text=i.x)),a=0;a<r.length;a++)o(t,r[a]._name+\".\"+e).set(c);for(a=0;a<n.length;a++)o(t,n[a]._name+\".\"+e).set(l)}function rt(t){return\"angularaxis\"===t._id}A.getTickFormat=function(t){var e,r,n,i,a,o,s,l;function c(t){return\"string\"!=typeof t?t:Number(t.replace(\"M\",\"\"))*v}function u(t,e){var r=[\"L\",\"D\"];if(typeof t==typeof e){if(\"number\"==typeof t)return t-e;var n=r.indexOf(t.charAt(0)),i=r.indexOf(e.charAt(0));return n===i?Number(t.replace(/(L|D)/g,\"\"))-Number(e.replace(/(L|D)/g,\"\")):n-i}return\"number\"==typeof t?1:-1}function h(t,e){var r=null===e[0],n=null===e[1],i=u(t,e[0])>=0,a=u(t,e[1])<=0;return(r||i)&&(n||a)}if(t.tickformatstops&&t.tickformatstops.length>0)switch(t.type){case\"date\":case\"linear\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&(i=t.dtick,a=n.dtickrange,o=void 0,void 0,void 0,o=c||function(t){return t},s=a[0],l=a[1],(!s&&\"number\"!=typeof s||o(s)<=o(i))&&(!l&&\"number\"!=typeof l||o(l)>=o(i)))){r=n;break}break;case\"log\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&h(t.dtick,n.dtickrange)){r=n;break}}return r?r.value:t.tickformat},A.getSubplots=function(t,e){var r=t._fullLayout._subplots,n=r.cartesian.concat(r.gl2d||[]),i=e?A.findSubplotsWithAxis(n,e):n;return i.sort(function(t,e){var r=t.substr(1).split(\"y\"),n=e.substr(1).split(\"y\");return r[0]===n[0]?+r[1]-+n[1]:+r[0]-+n[0]}),i},A.findSubplotsWithAxis=function(t,e){for(var r=new RegExp(\"x\"===e._id.charAt(0)?\"^\"+e._id+\"y\":e._id+\"$\"),n=[],i=0;i<t.length;i++){var a=t[i];r.test(a)&&n.push(a)}return n},A.makeClipPaths=function(t){var e=t._fullLayout;if(!e._hasOnlyLargeSploms){var r,i,a={_offset:0,_length:e.width,_id:\"\"},o={_offset:0,_length:e.height,_id:\"\"},s=A.list(t,\"x\",!0),l=A.list(t,\"y\",!0),c=[];for(r=0;r<s.length;r++)for(c.push({x:s[r],y:o}),i=0;i<l.length;i++)0===r&&c.push({x:a,y:l[i]}),c.push({x:s[r],y:l[i]});var u=e._clips.selectAll(\".axesclip\").data(c,function(t){return t.x._id+t.y._id});u.enter().append(\"clipPath\").classed(\"axesclip\",!0).attr(\"id\",function(t){return\"clip\"+e._uid+t.x._id+t.y._id}).append(\"rect\"),u.exit().remove(),u.each(function(t){n.select(this).select(\"rect\").attr({x:t.x._offset||0,y:t.y._offset||0,width:t.x._length||1,height:t.y._length||1})})}},A.draw=function(t,e,r){var n=t._fullLayout;\"redraw\"===e&&n._paper.selectAll(\"g.subplot\").each(function(t){var e=t[0],r=n._plots[e],i=r.xaxis,a=r.yaxis;r.xaxislayer.selectAll(\".\"+i._id+\"tick\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"tick2\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick2\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"divider\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"divider\").remove(),r.gridlayer&&r.gridlayer.selectAll(\"path\").remove(),r.zerolinelayer&&r.zerolinelayer.selectAll(\"path\").remove(),n._infolayer.select(\".g-\"+i._id+\"title\").remove(),n._infolayer.select(\".g-\"+a._id+\"title\").remove()});var i=e&&\"redraw\"!==e?e:A.listIds(t);return s.syncOrAsync(i.map(function(e){return function(){if(e){var n=A.getFromId(t,e),i=A.drawOne(t,n,r);return n._r=n.range.slice(),n._rl=s.simpleMap(n._r,n.r2l),i}}}))},A.drawOne=function(t,e,r){var n,i,l;r=r||{},e.setScale();var f=t._fullLayout,p=e._id,d=p.charAt(0),g=A.counterLetter(p),v=e._mainSubplot,m=e._mainLinePosition,y=e._mainMirrorPosition,x=f._plots[v][d+\"axislayer\"],b=e._subplotsWith,_=e._vals=A.calcTicks(e),w=[e.mirror,m,y].join(\"_\");for(n=0;n<_.length;n++)_[n].axInfo=w;if(e.visible){e._selections={},e._tickAngles={};var k,M,S=A.makeTransFn(e);if(\"boundaries\"===e.tickson){var E=function(t,e){var r,n=[],i=function(t,e){var r=t.xbnd[e];null!==r&&n.push(s.extendFlat({},t,{x:r}))};if(e.length){for(r=0;r<e.length;r++)i(e[r],0);i(e[r-1],1)}return n}(0,_);M=A.clipEnds(e,E),k=\"inside\"===e.ticks?M:E}else M=A.clipEnds(e,_),k=\"inside\"===e.ticks?M:_;var C=e._gridVals=M,L=function(t,e){var r,n,i=[],a=function(t,e){var r=t.xbnd[e];null!==r&&i.push(s.extendFlat({},t,{x:r}))};if(t.showdividers&&e.length){for(r=0;r<e.length;r++){var o=e[r];o.text2!==n&&a(o,0),n=o.text2}a(e[r-1],1)}return i}(e,_);if(!f._hasOnlyLargeSploms){var P={};for(n=0;n<b.length;n++){i=b[n];var O=(l=f._plots[i])[g+\"axis\"],z=O._mainAxis._id;if(!P[z]){P[z]=1;var I=\"x\"===d?\"M0,\"+O._offset+\"v\"+O._length:\"M\"+O._offset+\",0h\"+O._length;A.drawGrid(t,e,{vals:C,counterAxis:O,layer:l.gridlayer.select(\".\"+p),path:I,transFn:S}),A.drawZeroLine(t,e,{counterAxis:O,layer:l.zerolinelayer,path:I,transFn:S})}}}var D=A.getTickSigns(e),R=[];if(e.ticks){var F,B,N,j=A.makeTickPath(e,m,D[2]);if(e._anchorAxis&&e.mirror&&!0!==e.mirror?(F=A.makeTickPath(e,y,D[3]),B=j+F):(F=\"\",B=j),e.showdividers&&\"outside\"===e.ticks&&\"boundaries\"===e.tickson){var V={};for(n=0;n<L.length;n++)V[L[n].x]=1;N=function(t){return V[t.x]?F:B}}else N=B;A.drawTicks(t,e,{vals:k,layer:x,path:N,transFn:S}),R=Object.keys(e._linepositions||{})}for(n=0;n<R.length;n++){i=R[n],l=f._plots[i];var q=e._linepositions[i]||[],H=A.makeTickPath(e,q[0],D[0])+A.makeTickPath(e,q[1],D[1]);A.drawTicks(t,e,{vals:k,layer:l[d+\"axislayer\"],path:H,transFn:S})}var G=[];if(G.push(function(){return A.drawLabels(t,e,{vals:_,layer:x,transFn:S,labelFns:A.makeLabelFns(e,m)})}),\"multicategory\"===e.type){var Z=0,J={x:2,y:10}[d],Q=D[2]*(\"inside\"===e.ticks?-1:1);G.push(function(){return Z+=Y(e,p+\"tick\")+J,Z+=e._tickAngles[p+\"tick\"]?e.tickfont.size*T:0,A.drawLabels(t,e,{vals:function(t,e){for(var r=[],n={},i=0;i<e.length;i++){var a=e[i];n[a.text2]?n[a.text2].push(a.x):n[a.text2]=[a.x]}for(var o in n)r.push(U(t,s.interp(n[o],.5),o));return r}(e,_),layer:x,cls:p+\"tick2\",repositionOnUpdate:!0,secondary:!0,transFn:S,labelFns:A.makeLabelFns(e,m+Z*Q)})}),G.push(function(){return Z+=Y(e,p+\"tick2\"),e._labelLength=Z,function(t,e,r){var n=e._id+\"divider\",i=r.vals,a=r.layer.selectAll(\"path.\"+n).data(i,W);a.exit().remove(),a.enter().insert(\"path\",\":first-child\").classed(n,1).classed(\"crisp\",1).call(u.stroke,e.dividercolor).style(\"stroke-width\",h.crispRound(t,e.dividerwidth,1)+\"px\"),a.attr(\"transform\",r.transFn).attr(\"d\",r.path)}(t,e,{vals:L,layer:x,path:A.makeTickPath(e,m,Q,Z),transFn:S})})}var tt=o.getComponentMethod(\"rangeslider\",\"isVisible\")(e);return G.push(function(){if(e.showticklabels){var r=t.getBoundingClientRect(),n=x.node().getBoundingClientRect();e._boundingBox={width:n.width,height:n.height,left:n.left-r.left,right:n.right-r.left,top:n.top-r.top,bottom:n.bottom-r.top}}else{var i,a=f._size;\"x\"===d?(i=\"free\"===e.anchor?a.t+a.h*(1-e.position):a.t+a.h*(1-e._anchorAxis.domain[{bottom:0,top:1}[e.side]]),e._boundingBox={top:i,bottom:i,left:e._offset,right:e._offset+e._length,width:e._length,height:0}):(i=\"free\"===e.anchor?a.l+a.w*e.position:a.l+a.w*e._anchorAxis.domain[{left:0,right:1}[e.side]],e._boundingBox={left:i,right:i,bottom:e._offset+e._length,top:e._offset,height:e._length,width:0})}if(b){for(var o=e._counterSpan=[1/0,-1/0],s=0;s<b.length;s++){var l=f._plots[b[s]][\"x\"===d?\"yaxis\":\"xaxis\"];et(o,[l._offset,l._offset+l._length])}\"free\"===e.anchor&&et(o,\"x\"===d?[e._boundingBox.bottom,e._boundingBox.top]:[e._boundingBox.right,e._boundingBox.left])}},function(){var r,n,i=e.side.charAt(0);if(tt&&(n=o.getComponentMethod(\"rangeslider\",\"autoMarginOpts\")(t,e)),a.autoMargin(t,$(e),n),e.automargin&&(!tt||\"b\"!==i)){r={x:0,y:0,r:0,l:0,t:0,b:0};var s,l,c=e._boundingBox,u=X(t,e);switch(d+i){case\"xb\":s=0,l=c.top-u,r[i]=c.height;break;case\"xt\":s=1,l=u-c.bottom,r[i]=c.height;break;case\"yl\":s=0,l=u-c.right,r[i]=c.width;break;case\"yr\":s=1,l=c.left-u,r[i]=c.width}if(r[g]=\"free\"===e.anchor?e.position:e._anchorAxis.domain[s],r[i]>0&&(r[i]+=l),e.title.text!==f._dfltTitle[d]&&(r[i]+=e.title.font.size),\"x\"===d&&c.width>0){var h=c.right-(e._offset+e._length);h>0&&(r.x=1,r.r=h);var p=e._offset-c.left;p>0&&(r.x=0,r.l=p)}else if(\"y\"===d&&c.height>0){var v=c.bottom-(e._offset+e._length);v>0&&(r.y=0,r.b=v);var m=e._offset-c.top;m>0&&(r.y=1,r.t=m)}}a.autoMargin(t,K(e),r)}),r.skipTitle||tt&&e._boundingBox&&\"bottom\"===e.side||G.push(function(){return function(t,e){var r,n=t._fullLayout,i=e._id,a=i.charAt(0),o=e.title.font.size;if(\"multicategory\"===e.type)r=e._labelLength;else{r=10+1.5*o+(e.linewidth?e.linewidth-1:0)}var s,l,u,f,p=X(t,e);\"x\"===a?(l=e._offset+e._length/2,u=\"top\"===e.side?-r-o*(e.showticklabels?1:0):r+o*(e.showticklabels?1.5:.5),u+=p):(u=e._offset+e._length/2,l=\"right\"===e.side?r+o*(e.showticklabels?1:.5):-r-o*(e.showticklabels?.5:0),l+=p,s={rotate:\"-90\",offset:0});if(\"multicategory\"!==e.type){var d=e._selections[e._id+\"tick\"];if(f={selection:d,side:e.side},d&&d.node()&&d.node().parentNode){var g=h.getTranslate(d.node().parentNode);f.offsetLeft=g.x,f.offsetTop=g.y}}return c.draw(t,i+\"title\",{propContainer:e,propName:e._name+\".title.text\",placeholder:n._dfltTitle[a],avoid:f,transform:s,attributes:{x:l,y:u,\"text-anchor\":\"middle\"}})}(t,e)}),s.syncOrAsync(G)}function et(t,e){t[0]=Math.min(t[0],e[0]),t[1]=Math.max(t[1],e[1])}},A.getTickSigns=function(t){var e=t._id.charAt(0),r={x:\"top\",y:\"right\"}[e],n=t.side===r?1:-1,i=[-1,1,n,-n];return\"inside\"!==t.ticks==(\"x\"===e)&&(i=i.map(function(t){return-t})),i},A.makeTransFn=function(t){var e=t._id.charAt(0),r=t._offset;return\"x\"===e?function(e){return\"translate(\"+(r+t.l2p(e.x))+\",0)\"}:function(e){return\"translate(0,\"+(r+t.l2p(e.x))+\")\"}},A.makeTickPath=function(t,e,r,n){n=void 0!==n?n:t.ticklen;var i=t._id.charAt(0),a=(t.linewidth||1)/2;return\"x\"===i?\"M0,\"+(e+a*r)+\"v\"+n*r:\"M\"+(e+a*r)+\",0h\"+n*r},A.makeLabelFns=function(t,e,r){var n=t._id.charAt(0),a=\"boundaries\"!==t.tickson&&\"outside\"===t.ticks,o=0,l=0;if(a&&(o+=t.ticklen),r&&\"outside\"===t.ticks){var c=s.deg2rad(r);o=t.ticklen*Math.cos(c)+1,l=t.ticklen*Math.sin(c)}t.showticklabels&&(a||t.showline)&&(o+=.2*t.tickfont.size);var u,h,f,p,d={labelStandoff:o+=(t.linewidth||1)/2,labelShift:l};return\"x\"===n?(p=\"bottom\"===t.side?1:-1,u=l*p,h=e+o*p,f=\"bottom\"===t.side?1:-.2,d.xFn=function(t){return t.dx+u},d.yFn=function(t){return t.dy+h+t.fontSize*f},d.anchorFn=function(t,e){return i(e)&&0!==e&&180!==e?e*p<0?\"end\":\"start\":\"middle\"},d.heightFn=function(e,r,n){return r<-60||r>60?-.5*n:\"top\"===t.side?-n:0}):\"y\"===n&&(p=\"right\"===t.side?1:-1,u=o,h=-l*p,f=90===Math.abs(t.tickangle)?.5:0,d.xFn=function(t){return t.dx+e+(u+t.fontSize*f)*p},d.yFn=function(t){return t.dy+h+t.fontSize*k},d.anchorFn=function(e,r){return i(r)&&90===Math.abs(r)?\"middle\":\"right\"===t.side?\"start\":\"end\"},d.heightFn=function(e,r,n){return(r*=\"left\"===t.side?1:-1)<-30?-n:r<30?-.5*n:0}),d},A.drawTicks=function(t,e,r){r=r||{};var n=e._id+\"tick\",i=r.layer.selectAll(\"path.\"+n).data(e.ticks?r.vals:[],W);i.exit().remove(),i.enter().append(\"path\").classed(n,1).classed(\"ticks\",1).classed(\"crisp\",!1!==r.crisp).call(u.stroke,e.tickcolor).style(\"stroke-width\",h.crispRound(t,e.tickwidth,1)+\"px\").attr(\"d\",r.path),i.attr(\"transform\",r.transFn)},A.drawGrid=function(t,e,r){r=r||{};var n=e._id+\"grid\",i=r.vals,a=r.counterAxis;if(!1===e.showgrid)i=[];else if(a&&A.shouldShowZeroLine(t,e,a))for(var o=\"array\"===e.tickmode,s=0;s<i.length;s++){var l=i[s].x;if(o?!l:Math.abs(l)<e.dtick/100){if(i=i.slice(0,s).concat(i.slice(s+1)),!o)break;s--}}var c=r.layer.selectAll(\"path.\"+n).data(i,W);c.exit().remove(),c.enter().append(\"path\").classed(n,1).classed(\"crisp\",!1!==r.crisp),e._gw=h.crispRound(t,e.gridwidth,1),c.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(u.stroke,e.gridcolor||\"#ddd\").style(\"stroke-width\",e._gw+\"px\"),\"function\"==typeof r.path&&c.attr(\"d\",r.path)},A.drawZeroLine=function(t,e,r){r=r||r;var n=e._id+\"zl\",i=A.shouldShowZeroLine(t,e,r.counterAxis),a=r.layer.selectAll(\"path.\"+n).data(i?[{x:0,id:e._id}]:[]);a.exit().remove(),a.enter().append(\"path\").classed(n,1).classed(\"zl\",1).classed(\"crisp\",!1!==r.crisp).each(function(){r.layer.selectAll(\"path\").sort(function(t,e){return S.idSort(t.id,e.id)})}),a.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(u.stroke,e.zerolinecolor||u.defaultLine).style(\"stroke-width\",h.crispRound(t,e.zerolinewidth,e._gw||1)+\"px\")},A.drawLabels=function(t,e,r){r=r||{};var a=e._id,o=a.charAt(0),c=r.cls||a+\"tick\",u=r.vals,f=r.labelFns,p=r.secondary?0:e.tickangle,d=(e._tickAngles||{})[c],g=r.layer.selectAll(\"g.\"+c).data(e.showticklabels?u:[],W),v=[];function m(t,e){t.each(function(t){var a=n.select(this),o=a.select(\".text-math-group\"),s=f.anchorFn(t,e),c=r.transFn.call(a.node(),t)+(i(e)&&0!=+e?\" rotate(\"+e+\",\"+f.xFn(t)+\",\"+(f.yFn(t)-t.fontSize/2)+\")\":\"\"),u=l.lineCount(a),p=T*t.fontSize,d=f.heightFn(t,i(e)?+e:0,(u-1)*p);if(d&&(c+=\" translate(0, \"+d+\")\"),o.empty())a.select(\"text\").attr({transform:c,\"text-anchor\":s});else{var g=h.bBox(o.node()).width*{end:-.5,start:.5}[s];o.attr(\"transform\",c+(g?\"translate(\"+g+\",0)\":\"\"))}})}g.enter().append(\"g\").classed(c,1).append(\"text\").attr(\"text-anchor\",\"middle\").each(function(e){var r=n.select(this),i=t._promises.length;r.call(l.positionText,f.xFn(e),f.yFn(e)).call(h.font,e.font,e.fontSize,e.fontColor).text(e.text).call(l.convertToTspans,t),t._promises[i]?v.push(t._promises.pop().then(function(){m(r,p)})):m(r,p)}),g.exit().remove(),r.repositionOnUpdate&&g.each(function(t){n.select(this).select(\"text\").call(l.positionText,f.xFn(t),f.yFn(t))}),m(g,d||p),e._selections&&(e._selections[c]=g);var y=s.syncOrAsync([function(){return v.length&&Promise.all(v)},function(){m(g,p);var t=null;if(u.length&&\"x\"===o&&!i(p)&&(\"log\"!==e.type||\"D\"!==String(e.dtick).charAt(0))){t=0;var n,a=0,l=[];if(g.each(function(t){a=Math.max(a,t.fontSize);var r=e.l2p(t.x),n=J(this),i=h.bBox(n.node());l.push({top:0,bottom:10,height:10,left:r-i.width/2,right:r+i.width/2+2,width:i.width+2})}),\"boundaries\"!==e.tickson&&!e.showdividers||r.secondary){var f=u.length,d=Math.abs((u[f-1].x-u[0].x)*e._m)/(f-1)<2.5*a||\"multicategory\"===e.type;for(n=0;n<l.length-1;n++)if(s.bBoxIntersect(l[n],l[n+1])){t=d?90:30;break}}else{var v=2;for(e.ticks&&(v+=e.tickwidth/2),n=0;n<l.length;n++){var y=u[n].xbnd,x=l[n];if(null!==y[0]&&x.left-e.l2p(y[0])<v||null!==y[1]&&e.l2p(y[1])-x.right<v){t=90;break}}}t&&m(g,t)}e._tickAngles&&(e._tickAngles[c]=null===t?i(p)?p:0:t)}]);return y&&y.then&&t._promises.push(y),y},A.shouldShowZeroLine=function(t,e,r){var n=s.simpleMap(e.range,e.r2l);return n[0]*n[1]<=0&&e.zeroline&&(\"linear\"===e.type||\"-\"===e.type)&&e._gridVals.length&&(Z(e,0)||!function(t,e,r,n){var i=r._mainAxis;if(!i)return;var a=t._fullLayout,o=e._id.charAt(0),s=A.counterLetter(e._id),l=e._offset+(Math.abs(n[0])<Math.abs(n[1])==(\"x\"===o)?0:e._length);function c(t){if(!t.showline||!t.linewidth)return!1;var r=Math.max((t.linewidth+e.zerolinewidth)/2,1);function n(t){return\"number\"==typeof t&&Math.abs(t-l)<r}if(n(t._mainLinePosition)||n(t._mainMirrorPosition))return!0;var i=t._linepositions||{};for(var a in i)if(n(i[a][0])||n(i[a][1]))return!0}var u=a._plots[r._mainSubplot];if(!(u.mainplotinfo||u).overlays.length)return c(r);for(var h=A.list(t,s),f=0;f<h.length;f++){var p=h[f];if(p._mainAxis===i&&c(p))return!0}}(t,e,r,n)||function(t,e){for(var r=t._fullData,n=e._mainSubplot,i=e._id.charAt(0),a=0;a<r.length;a++){var s=r[a];if(!0===s.visible&&s.xaxis+s.yaxis===n){if(o.traceIs(s,\"bar-like\")&&s.orientation==={x:\"h\",y:\"v\"}[i])return!0;if(s.fill&&s.fill.charAt(s.fill.length-1)===i)return!0}}return!1}(t,e))},A.clipEnds=function(t,e){return e.filter(function(e){return Z(t,e.x)})},A.allowAutoMargin=function(t){for(var e=A.list(t,\"\",!0),r=0;r<e.length;r++){var n=e[r];n.automargin&&a.allowAutoMargin(t,K(n)),o.getComponentMethod(\"rangeslider\",\"isVisible\")(n)&&a.allowAutoMargin(t,$(n))}},A.swap=function(t,e){for(var r=function(t,e){var r,n,i=[];for(r=0;r<e.length;r++){var a=[],o=t._fullData[e[r]].xaxis,s=t._fullData[e[r]].yaxis;if(o&&s){for(n=0;n<i.length;n++)-1===i[n].x.indexOf(o)&&-1===i[n].y.indexOf(s)||a.push(n);if(a.length){var l,c=i[a[0]];if(a.length>1)for(n=1;n<a.length;n++)l=i[a[n]],Q(c.x,l.x),Q(c.y,l.y);Q(c.x,[o]),Q(c.y,[s])}else i.push({x:[o],y:[s]})}}return i}(t,e),n=0;n<r.length;n++)tt(t,r[n].x,r[n].y)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../components/titles\":681,\"../../constants/alignment\":688,\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/plots\":828,\"../../registry\":847,\"./autorange\":766,\"./axis_autotype\":768,\"./axis_ids\":770,\"./clean_ticks\":772,\"./layout_attributes\":779,\"./set_convert\":785,d3:163,\"fast-isnumeric\":225}],768:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){return!(r=r||{}).noMultiCategory&&(o=t,i.isArrayOrTypedArray(o[0])&&i.isArrayOrTypedArray(o[1]))?\"multicategory\":function(t,e){for(var r=Math.max(1,(t.length-1)/1e3),a=0,o=0,s={},l=0;l<t.length;l+=r){var c=t[Math.round(l)],u=String(c);s[u]||(s[u]=1,i.isDateTime(c,e)&&(a+=1),n(c)&&(o+=1))}return a>2*o}(t,e)?\"date\":function(t){for(var e=Math.max(1,(t.length-1)/1e3),r=0,n=0,o={},s=0;s<t.length;s+=e){var l=t[Math.round(s)],c=String(l);o[c]||(o[c]=1,\"boolean\"==typeof l?n++:i.cleanNumber(l)!==a?r++:\"string\"==typeof l&&n++)}return n>2*r}(t)?\"category\":function(t){if(!t)return!1;for(var e=0;e<t.length;e++)if(n(t[e]))return!0;return!1}(t)?\"linear\":\"-\";var o}},{\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],769:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./layout_attributes\"),o=t(\"./tick_value_defaults\"),s=t(\"./tick_mark_defaults\"),l=t(\"./tick_label_defaults\"),c=t(\"./category_order_defaults\"),u=t(\"./line_grid_defaults\"),h=t(\"./set_convert\");e.exports=function(t,e,r,f,p){var d=f.letter,g=f.font||{},v=f.splomStash||{},m=r(\"visible\",!f.visibleDflt),y=e.type;\"date\"===y&&n.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",f.calendar);h(e,p);var x=!e.isValidRange(t.range);x&&f.reverseDflt&&(x=\"reversed\"),!r(\"autorange\",x)||\"linear\"!==y&&\"-\"!==y||r(\"rangemode\"),r(\"range\"),e.cleanRange(),c(t,e,r,f),\"category\"===y||f.noHover||r(\"hoverformat\");var b=r(\"color\"),_=b!==a.color.dflt?b:g.color,w=v.label||p._dfltTitle[d];if(l(t,e,r,y,f,{pass:1}),!m)return e;r(\"title.text\",w),i.coerceFont(r,\"title.font\",{family:g.family,size:Math.round(1.2*g.size),color:_}),o(t,e,r,y),l(t,e,r,y,f,{pass:2}),s(t,e,r,f),u(t,e,r,{dfltColor:b,bgColor:f.bgColor,showGrid:f.showGrid,attributes:a}),(e.showline||e.ticks)&&r(\"mirror\"),f.automargin&&r(\"automargin\");var k,T=\"multicategory\"===e.type;f.noTickson||\"category\"!==e.type&&!T||!e.ticks&&!e.showgrid||(T&&(k=\"boundaries\"),r(\"tickson\",k));T&&(r(\"showdividers\")&&(r(\"dividercolor\"),r(\"dividerwidth\")));return e}},{\"../../lib\":719,\"../../registry\":847,\"./category_order_defaults\":771,\"./layout_attributes\":779,\"./line_grid_defaults\":781,\"./set_convert\":785,\"./tick_label_defaults\":786,\"./tick_mark_defaults\":787,\"./tick_value_defaults\":788}],770:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./constants\");r.id2name=function(t){if(\"string\"==typeof t&&t.match(i.AX_ID_PATTERN)){var e=t.substr(1);return\"1\"===e&&(e=\"\"),t.charAt(0)+\"axis\"+e}},r.name2id=function(t){if(t.match(i.AX_NAME_PATTERN)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),t.charAt(0)+e}},r.cleanId=function(t,e){if(t.match(i.AX_ID_PATTERN)&&(!e||t.charAt(0)===e)){var r=t.substr(1).replace(/^0+/,\"\");return\"1\"===r&&(r=\"\"),t.charAt(0)+r}},r.list=function(t,e,n){var i=t._fullLayout;if(!i)return[];var a,o=r.listIds(t,e),s=new Array(o.length);for(a=0;a<o.length;a++){var l=o[a];s[a]=i[l.charAt(0)+\"axis\"+l.substr(1)]}if(!n){var c=i._subplots.gl3d||[];for(a=0;a<c.length;a++){var u=i[c[a]];e?s.push(u[e+\"axis\"]):s.push(u.xaxis,u.yaxis,u.zaxis)}}return s},r.listIds=function(t,e){var r=t._fullLayout;if(!r)return[];var n=r._subplots;return e?n[e+\"axis\"]:n.xaxis.concat(n.yaxis)},r.getFromId=function(t,e,n){var i=t._fullLayout;return\"x\"===n?e=e.replace(/y[0-9]*/,\"\"):\"y\"===n&&(e=e.replace(/x[0-9]*/,\"\")),i[r.id2name(e)]},r.getFromTrace=function(t,e,i){var a=t._fullLayout,o=null;if(n.traceIs(e,\"gl3d\")){var s=e.scene;\"scene\"===s.substr(0,5)&&(o=a[s][i+\"axis\"])}else o=r.getFromId(t,e[i+\"axis\"]||i);return o},r.idSort=function(t,e){var r=t.charAt(0),n=e.charAt(0);return r!==n?r>n?1:-1:+(t.substr(1)||1)-+(e.substr(1)||1)},r.getAxisGroup=function(t,e){for(var r=t._axisMatchGroups,n=0;n<r.length;n++){if(r[n][e])return\"g\"+n}return e}},{\"../../registry\":847,\"./constants\":773}],771:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){if(\"category\"===e.type){var i,a=t.categoryarray,o=Array.isArray(a)&&a.length>0;o&&(i=\"array\");var s,l=r(\"categoryorder\",i);\"array\"===l&&(s=r(\"categoryarray\")),o||\"array\"!==l||(l=e.categoryorder=\"trace\"),\"trace\"===l?e._initialCategories=[]:\"array\"===l?e._initialCategories=s.slice():(s=function(t,e){var r,n,i,a=e.dataAttr||t._id.charAt(0),o={};if(e.axData)r=e.axData;else for(r=[],n=0;n<e.data.length;n++){var s=e.data[n];s[a+\"axis\"]===t._id&&r.push(s)}for(n=0;n<r.length;n++){var l=r[n][a];for(i=0;i<l.length;i++){var c=l[i];null!=c&&(o[c]=1)}}return Object.keys(o)}(e,n).sort(),\"category ascending\"===l?e._initialCategories=s:\"category descending\"===l&&(e._initialCategories=s.reverse()))}}},{}],772:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").ONEDAY;r.dtick=function(t,e){var r=\"log\"===e,i=\"date\"===e,o=\"category\"===e,s=i?a:1;if(!t)return s;if(n(t))return(t=Number(t))<=0?s:o?Math.max(1,Math.round(t)):i?Math.max(.1,t):t;if(\"string\"!=typeof t||!i&&!r)return s;var l=t.charAt(0),c=t.substr(1);return(c=n(c)?Number(c):0)<=0||!(i&&\"M\"===l&&c===Math.round(c)||r&&\"L\"===l||r&&\"D\"===l&&(1===c||2===c))?s:t},r.tick0=function(t,e,r,a){return\"date\"===e?i.cleanDate(t,i.dateTick0(r)):\"D1\"!==a&&\"D2\"!==a?n(t)?Number(t):0:void 0}},{\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],773:[function(t,e,r){\"use strict\";var n=t(\"../../lib/regex\").counter;e.exports={idRegex:{x:n(\"x\"),y:n(\"y\")},attrRegex:n(\"[xy]axis\"),xAxisMatch:n(\"xaxis\"),yAxisMatch:n(\"yaxis\"),AX_ID_PATTERN:/^[xyz][0-9]*$/,AX_NAME_PATTERN:/^[xyz]axis[0-9]*$/,SUBPLOT_PATTERN:/^x([0-9]*)y([0-9]*)$/,MINDRAG:8,MINSELECT:12,MINZOOM:20,DRAGGERSIZE:20,BENDPX:1.5,REDRAWDELAY:50,SELECTDELAY:100,SELECTID:\"-select\",DFLTRANGEX:[-1,6],DFLTRANGEY:[-1,4],traceLayerClasses:[\"heatmaplayer\",\"contourcarpetlayer\",\"contourlayer\",\"funnellayer\",\"waterfalllayer\",\"barlayer\",\"carpetlayer\",\"violinlayer\",\"boxlayer\",\"ohlclayer\",\"scattercarpetlayer\",\"scatterlayer\"],clipOnAxisFalseQuery:[\".scatterlayer\",\".barlayer\",\".funnellayer\",\".waterfalllayer\"],layerValue2layerClass:{\"above traces\":\"above\",\"below traces\":\"below\"}}},{\"../../lib/regex\":735}],774:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./axis_ids\").id2name,a=t(\"./scale_zoom\"),o=t(\"./autorange\").makePadFn,s=t(\"./autorange\").concatExtremes,l=t(\"../../constants/numerical\").ALMOST_EQUAL,c=t(\"../../constants/alignment\").FROM_BL;function u(t,e,r,n,a){var o,s,l,c,u=\"range\"!==a,h=n[i(e)].type,f=[];for(s=0;s<r.length;s++)if((l=r[s])!==e&&(c=n[i(l)]).type===h)if(c.fixedrange){if(u&&c.anchor){n[i(c.anchor)].fixedrange&&f.push(l)}}else f.push(l);for(o=0;o<t.length;o++)if(t[o][e]){var p=t[o],d=[];for(s=0;s<f.length;s++)p[l=f[s]]||d.push(l);return{linkableAxes:d,thisGroup:p}}return{linkableAxes:f,thisGroup:null}}function h(t,e,r,n,i){var a,o,s,l,c;null===e?((e={})[r]=1,c=t.length,t.push(e)):c=t.indexOf(e);var u=Object.keys(e);for(a=0;a<t.length;a++)if(s=t[a],a!==c&&s[n]){var h=s[n];for(o=0;o<u.length;o++)s[l=u[o]]=h*i*e[l];return void t.splice(c,1)}if(1!==i)for(o=0;o<u.length;o++)e[u[o]]*=i;e[n]=1}function f(t,e){var r=t._inputDomain,n=c[t.constraintoward],i=r[0]+(r[1]-r[0])*n;t.domain=t._input.domain=[i+(r[0]-i)/e,i+(r[1]-i)/e],t.setScale()}r.handleConstraintDefaults=function(t,e,r,i,a){var o,s,l,c,f=a._axisConstraintGroups,p=a._axisMatchGroups,d=e._id,g=d.charAt(0),v=((a._splomAxes||{})[g]||{})[d]||{},m=e._id,y=m.charAt(0),x=r(\"constrain\");if(n.coerce(t,e,{constraintoward:{valType:\"enumerated\",values:\"x\"===y?[\"left\",\"center\",\"right\"]:[\"bottom\",\"middle\",\"top\"],dflt:\"x\"===y?\"center\":\"middle\"}},\"constraintoward\"),!t.matches&&!v.matches||e.fixedrange||(s=u(p,m,i,a),o=n.coerce(t,e,{matches:{valType:\"enumerated\",values:s.linkableAxes||[],dflt:v.matches}},\"matches\")),o||!t.scaleanchor||e.fixedrange&&\"domain\"!==x||(c=u(f,m,i,a,x),l=n.coerce(t,e,{scaleanchor:{valType:\"enumerated\",values:c.linkableAxes||[]}},\"scaleanchor\")),o?(delete e.constrain,h(p,s.thisGroup,m,o,1)):-1!==i.indexOf(t.matches)&&n.warn(\"ignored \"+e._name+'.matches: \"'+t.matches+'\" to avoid either an infinite loop or because the target axis has fixed range.'),l){var b=r(\"scaleratio\");b||(b=e.scaleratio=1),h(f,c.thisGroup,m,l,b)}else-1!==i.indexOf(t.scaleanchor)&&n.warn(\"ignored \"+e._name+'.scaleanchor: \"'+t.scaleanchor+'\" to avoid either an infinite loop and possibly inconsistent scaleratios, or because the target axis has fixed range or this axis declares a *matches* constraint.')},r.enforce=function(t){var e,r,n,c,u,h,p,d=t._fullLayout,g=d._axisConstraintGroups||[];for(e=0;e<g.length;e++){var v=g[e],m=Object.keys(v),y=1/0,x=0,b=1/0,_={},w={},k=!1;for(r=0;r<m.length;r++)w[n=m[r]]=c=d[i(n)],c._inputDomain?c.domain=c._inputDomain.slice():c._inputDomain=c.domain.slice(),c._inputRange||(c._inputRange=c.range.slice()),c.setScale(),_[n]=u=Math.abs(c._m)/v[n],y=Math.min(y,u),\"domain\"!==c.constrain&&c._constraintShrinkable||(b=Math.min(b,u)),delete c._constraintShrinkable,x=Math.max(x,u),\"domain\"===c.constrain&&(k=!0);if(!(y>l*x)||k)for(r=0;r<m.length;r++)if(u=_[n=m[r]],h=(c=w[n]).constrain,u!==b||\"domain\"===h)if(p=u/b,\"range\"===h)a(c,p);else{var T=c._inputDomain,A=(c.domain[1]-c.domain[0])/(T[1]-T[0]),M=(c.r2l(c.range[1])-c.r2l(c.range[0]))/(c.r2l(c._inputRange[1])-c.r2l(c._inputRange[0]));if((p/=A)*M<1){c.domain=c._input.domain=T.slice(),a(c,p);continue}if(M<1&&(c.range=c._input.range=c._inputRange.slice(),p*=M),c.autorange){var S=c.r2l(c.range[0]),E=c.r2l(c.range[1]),C=(S+E)/2,L=C,P=C,O=Math.abs(E-C),z=C-O*p*1.0001,I=C+O*p*1.0001,D=o(c);f(c,p);var R,F,B=Math.abs(c._m),N=s(t,c),j=N.min,U=N.max;for(F=0;F<j.length;F++)(R=j[F].val-D(j[F])/B)>z&&R<L&&(L=R);for(F=0;F<U.length;F++)(R=U[F].val+D(U[F])/B)<I&&R>P&&(P=R);p/=(P-L)/(2*O),L=c.l2r(L),P=c.l2r(P),c.range=c._input.range=S<E?[L,P]:[P,L]}f(c,p)}}},r.clean=function(t,e){if(e._inputDomain){for(var r=!1,n=e._id,i=t._fullLayout._axisConstraintGroups,a=0;a<i.length;a++)if(i[a][n]){r=!0;break}r&&\"domain\"===e.constrain||(e._input.domain=e.domain=e._inputDomain,delete e._inputDomain)}}},{\"../../constants/alignment\":688,\"../../constants/numerical\":695,\"../../lib\":719,\"./autorange\":766,\"./axis_ids\":770,\"./scale_zoom\":783}],775:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"has-passive-events\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../components/color\"),u=t(\"../../components/drawing\"),h=t(\"../../components/fx\"),f=t(\"./axes\"),p=t(\"../../lib/setcursor\"),d=t(\"../../components/dragelement\"),g=t(\"../../constants/alignment\").FROM_TL,v=t(\"../../lib/clear_gl_canvases\"),m=t(\"../../plot_api/subroutines\").redrawReglTraces,y=t(\"../plots\"),x=t(\"./axis_ids\").getFromId,b=t(\"./select\").prepSelect,_=t(\"./select\").clearSelect,w=t(\"./select\").selectOnClick,k=t(\"./scale_zoom\"),T=t(\"./constants\"),A=T.MINDRAG,M=T.MINZOOM,S=!0;function E(t,e,r,n){var i=s.ensureSingle(t.draglayer,e,r,function(e){e.classed(\"drag\",!0).style({fill:\"transparent\",\"stroke-width\":0}).attr(\"data-subplot\",t.id)});return i.call(p,n),i.node()}function C(t,e,r,i,a,o,s){var l=E(t,\"rect\",e,r);return n.select(l).call(u.setRect,i,a,o,s),l}function L(t,e){for(var r=0;r<t.length;r++)if(!t[r].fixedrange)return e;return\"\"}function P(t,e,r,n,i){for(var a=0;a<t.length;a++){var o=t[a];if(!o.fixedrange){var s=o._rl[0],l=o._rl[1]-s;n[o._name+\".range[0]\"]=o.l2r(s+l*e),n[o._name+\".range[1]\"]=o.l2r(s+l*r)}}if(i&&i.length){var c=(e+(1-r))/2;P(i,c,1-c,n,[])}}function O(t,e){for(var r=0;r<t.length;r++){var n=t[r];n.fixedrange||(n.range=[n.l2r(n._rl[0]-e/n._m),n.l2r(n._rl[1]-e/n._m)])}}function z(t){return 1-(t>=0?Math.min(t,.9):1/(1/Math.max(t,-.3)+3.222))}function I(t,e,r,n,i){return t.append(\"path\").attr(\"class\",\"zoombox\").style({fill:e>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"transform\",\"translate(\"+r+\", \"+n+\")\").attr(\"d\",i+\"Z\")}function D(t,e,r){return t.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:c.background,stroke:c.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"transform\",\"translate(\"+e+\", \"+r+\")\").attr(\"d\",\"M0,0Z\")}function R(t,e,r,n,i,a){t.attr(\"d\",n+\"M\"+r.l+\",\"+r.t+\"v\"+r.h+\"h\"+r.w+\"v-\"+r.h+\"h-\"+r.w+\"Z\"),F(t,e,i,a)}function F(t,e,r,n){r||(t.transition().style(\"fill\",n>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),e.transition().style(\"opacity\",1).duration(200))}function B(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}function N(t){S&&t.data&&t._context.showTips&&(s.notifier(s._(t,\"Double-click to zoom back out\"),\"long\"),S=!1)}function j(t){return\"lasso\"===t||\"select\"===t}function U(t){var e=Math.floor(Math.min(t.b-t.t,t.r-t.l,M)/2);return\"M\"+(t.l-3.5)+\",\"+(t.t-.5+e)+\"h3v\"+-e+\"h\"+e+\"v-3h-\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.t-.5+e)+\"h-3v\"+-e+\"h\"+-e+\"v-3h\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.b+.5-e)+\"h-3v\"+e+\"h\"+-e+\"v3h\"+(e+3)+\"ZM\"+(t.l-3.5)+\",\"+(t.b+.5-e)+\"h3v\"+e+\"h\"+e+\"v3h-\"+(e+3)+\"Z\"}function V(t,e,r,n){for(var i,a,o,l,c=!1,u={},h={},f=0;f<e.length;f++){var p=e[f];for(i in r)if(p[i]){for(o in p)(\"x\"===o.charAt(0)?r:n)[o]||(u[o]=i);for(a in n)p[a]&&(c=!0)}for(a in n)if(p[a])for(l in p)(\"x\"===l.charAt(0)?r:n)[l]||(h[l]=a)}c&&(s.extendFlat(u,h),h={});var d={},g=[];for(o in u){var v=x(t,o);g.push(v),d[v._id]=v}var m={},y=[];for(l in h){var b=x(t,l);y.push(b),m[b._id]=b}return{xaHash:d,yaHash:m,xaxes:g,yaxes:y,xLinks:u,yLinks:h,isSubplotConstrained:c}}function q(t,e){if(a){var r=void 0!==t.onwheel?\"wheel\":\"mousewheel\";t._onwheel&&t.removeEventListener(r,t._onwheel),t._onwheel=e,t.addEventListener(r,e,{passive:!1})}else void 0!==t.onwheel?t.onwheel=e:void 0!==t.onmousewheel&&(t.onmousewheel=e)}function H(t){var e=[];for(var r in t)e.push(t[r]);return e}e.exports={makeDragBox:function(t,e,r,a,c,p,S,E){var F,G,Y,W,X,Z,J,K,$,Q,tt,et,rt,nt,it,at,ot,st,lt,ct,ut,ht=t._fullLayout._zoomlayer,ft=S+E===\"nsew\",pt=1===(S+E).length;function dt(){if(F=e.xaxis,G=e.yaxis,$=F._length,Q=G._length,J=F._offset,K=G._offset,(Y={})[F._id]=F,(W={})[G._id]=G,S&&E)for(var r=e.overlays,n=0;n<r.length;n++){var i=r[n].xaxis;Y[i._id]=i;var a=r[n].yaxis;W[a._id]=a}X=H(Y),Z=H(W),rt=L(X,E),nt=L(Z,S),it=!nt&&!rt,tt=V(t,t._fullLayout._axisConstraintGroups,Y,W),et=V(t,t._fullLayout._axisMatchGroups,Y,W),at=E||tt.isSubplotConstrained||et.isSubplotConstrained,ot=S||tt.isSubplotConstrained||et.isSubplotConstrained;var o=t._fullLayout;st=o._has(\"scattergl\"),lt=o._has(\"splom\"),ct=o._has(\"svg\")}dt();var gt=function(t,e,r){return t?\"nsew\"===t?r?\"\":\"pan\"===e?\"move\":\"crosshair\":t.toLowerCase()+\"-resize\":\"pointer\"}(nt+rt,t._fullLayout.dragmode,ft),vt=C(e,S+E+\"drag\",gt,r,a,c,p);if(it&&!ft)return vt.onmousedown=null,vt.style.pointerEvents=\"none\",vt;var mt,yt,xt,bt,_t,wt,kt,Tt,At,Mt,St={element:vt,gd:t,plotinfo:e};function Et(){St.plotinfo.selection=!1,_(t)}function Ct(r,i){var a=t._fullLayout.clickmode;if(B(t),2!==r||pt||function(){if(!t._transitioningWithDuration){var e=t._context.doubleClick,r=[];rt&&(r=r.concat(X)),nt&&(r=r.concat(Z)),et.xaxes&&(r=r.concat(et.xaxes)),et.yaxes&&(r=r.concat(et.yaxes));var n,i,a,s={};if(\"reset+autosize\"===e)for(e=\"autosize\",i=0;i<r.length;i++)if((n=r[i])._rangeInitial&&(n.range[0]!==n._rangeInitial[0]||n.range[1]!==n._rangeInitial[1])||!n._rangeInitial&&!n.autorange){e=\"reset\";break}if(\"autosize\"===e)for(i=0;i<r.length;i++)(n=r[i]).fixedrange||(s[n._name+\".autorange\"]=!0);else if(\"reset\"===e)for((rt||tt.isSubplotConstrained)&&(r=r.concat(tt.xaxes)),nt&&!tt.isSubplotConstrained&&(r=r.concat(tt.yaxes)),tt.isSubplotConstrained&&(rt?nt||(r=r.concat(Z)):r=r.concat(X)),i=0;i<r.length;i++)(n=r[i]).fixedrange||(n._rangeInitial?(a=n._rangeInitial,s[n._name+\".range[0]\"]=a[0],s[n._name+\".range[1]\"]=a[1]):s[n._name+\".autorange\"]=!0);t.emit(\"plotly_doubleclick\",null),o.call(\"_guiRelayout\",t,s)}}(),ft)a.indexOf(\"select\")>-1&&w(i,t,X,Z,e.id,St),a.indexOf(\"event\")>-1&&h.click(t,i,e.id);else if(1===r&&pt){var s=S?G:F,c=\"s\"===S||\"w\"===E?0:1,u=s._name+\".range[\"+c+\"]\",f=function(t,e){var r,i=t.range[e],a=Math.abs(i-t.range[1-e]);return\"date\"===t.type?i:\"log\"===t.type?(r=Math.ceil(Math.max(0,-Math.log(a)/Math.LN10))+3,n.format(\".\"+r+\"g\")(Math.pow(10,i))):(r=Math.floor(Math.log(Math.abs(i))/Math.LN10)-Math.floor(Math.log(a)/Math.LN10)+4,n.format(\".\"+String(r)+\"g\")(i))}(s,c),p=\"left\",d=\"middle\";if(s.fixedrange)return;S?(d=\"n\"===S?\"top\":\"bottom\",\"right\"===s.side&&(p=\"right\")):\"e\"===E&&(p=\"right\"),t._context.showAxisRangeEntryBoxes&&n.select(vt).call(l.makeEditable,{gd:t,immediate:!0,background:t._fullLayout.paper_bgcolor,text:String(f),fill:s.tickfont?s.tickfont.color:\"#444\",horizontalAlign:p,verticalAlign:d}).on(\"edit\",function(e){var r=s.d2r(e);void 0!==r&&o.call(\"_guiRelayout\",t,u,r)})}}function Lt(e,r){if(t._transitioningWithDuration)return!1;var n=Math.max(0,Math.min($,e+mt)),i=Math.max(0,Math.min(Q,r+yt)),a=Math.abs(n-mt),o=Math.abs(i-yt);function s(){kt=\"\",xt.r=xt.l,xt.t=xt.b,At.attr(\"d\",\"M0,0Z\")}if(xt.l=Math.min(mt,n),xt.r=Math.max(mt,n),xt.t=Math.min(yt,i),xt.b=Math.max(yt,i),tt.isSubplotConstrained)a>M||o>M?(kt=\"xy\",a/$>o/Q?(o=a*Q/$,yt>i?xt.t=yt-o:xt.b=yt+o):(a=o*$/Q,mt>n?xt.l=mt-a:xt.r=mt+a),At.attr(\"d\",U(xt))):s();else if(et.isSubplotConstrained)if(a>M||o>M){kt=\"xy\";var l=Math.min(xt.l/$,(Q-xt.b)/Q),c=Math.max(xt.r/$,(Q-xt.t)/Q);xt.l=l*$,xt.r=c*$,xt.b=(1-l)*Q,xt.t=(1-c)*Q,At.attr(\"d\",U(xt))}else s();else!nt||o<Math.min(Math.max(.6*a,A),M)?a<A||!rt?s():(xt.t=0,xt.b=Q,kt=\"x\",At.attr(\"d\",function(t,e){return\"M\"+(t.l-.5)+\",\"+(e-M-.5)+\"h-3v\"+(2*M+1)+\"h3ZM\"+(t.r+.5)+\",\"+(e-M-.5)+\"h3v\"+(2*M+1)+\"h-3Z\"}(xt,yt))):!rt||a<Math.min(.6*o,M)?(xt.l=0,xt.r=$,kt=\"y\",At.attr(\"d\",function(t,e){return\"M\"+(e-M-.5)+\",\"+(t.t-.5)+\"v-3h\"+(2*M+1)+\"v3ZM\"+(e-M-.5)+\",\"+(t.b+.5)+\"v3h\"+(2*M+1)+\"v-3Z\"}(xt,mt))):(kt=\"xy\",At.attr(\"d\",U(xt)));xt.w=xt.r-xt.l,xt.h=xt.b-xt.t,kt&&(Mt=!0),t._dragged=Mt,R(Tt,At,xt,_t,wt,bt),Pt(),t.emit(\"plotly_relayouting\",ut),wt=!0}function Pt(){ut={},\"xy\"!==kt&&\"x\"!==kt||(P(X,xt.l/$,xt.r/$,ut,tt.xaxes),Bt(\"x\",ut)),\"xy\"!==kt&&\"y\"!==kt||(P(Z,(Q-xt.b)/Q,(Q-xt.t)/Q,ut,tt.yaxes),Bt(\"y\",ut))}function Ot(){if(Math.min(xt.h,xt.w)<2*A)return B(t);Pt(),B(t),jt(),N(t)}St.prepFn=function(e,r,n){var a=St.dragmode,o=t._fullLayout.dragmode;o!==a&&(St.dragmode=o),dt(),it||(ft?e.shiftKey?\"pan\"===o?o=\"zoom\":j(o)||(o=\"pan\"):e.ctrlKey&&(o=\"pan\"):o=\"pan\"),St.minDrag=\"lasso\"===o?1:void 0,j(o)?(St.xaxes=X,St.yaxes=Z,b(e,r,n,St,o)):(St.clickFn=Ct,j(a)&&Et(),it||(\"zoom\"===o?(St.moveFn=Lt,St.doneFn=Ot,St.minDrag=1,function(e,r,n){var a=vt.getBoundingClientRect();mt=r-a.left,yt=n-a.top,xt={l:mt,r:mt,w:0,t:yt,b:yt,h:0},bt=t._hmpixcount?t._hmlumcount/t._hmpixcount:i(t._fullLayout.plot_bgcolor).getLuminance(),wt=!1,kt=\"xy\",Mt=!1,Tt=I(ht,bt,J,K,_t=\"M0,0H\"+$+\"V\"+Q+\"H0V0\"),At=D(ht,J,K)}(0,r,n)):\"pan\"===o&&(St.moveFn=Ft,St.doneFn=jt))),t._fullLayout._redrag=function(){var e=t._dragdata;e&&e.element===vt&&(j(t._fullLayout.dragmode)||(dt(),Ut([0,0,$,Q]),St.moveFn(e.dx,e.dy)))}},d.init(St);var zt=[0,0,$,Q],It=null,Dt=T.REDRAWDELAY,Rt=e.mainplot?t._fullLayout._plots[e.mainplot]:e;function Ft(e,r){if(!t._transitioningWithDuration){if(t._fullLayout._replotting=!0,\"ew\"===rt||\"ns\"===nt)return rt&&(O(X,e),Bt(\"x\")),nt&&(O(Z,r),Bt(\"y\")),Ut([rt?-e:0,nt?-r:0,$,Q]),Nt(),void t.emit(\"plotly_relayouting\",ut);if(tt.isSubplotConstrained&&rt&&nt){var n=\"w\"===rt==(\"n\"===nt)?1:-1,i=(e/$+n*r/Q)/2;e=i*$,r=n*i*Q}\"w\"===rt?e=l(X,0,e):\"e\"===rt?e=l(X,1,-e):rt||(e=0),\"n\"===nt?r=l(Z,1,r):\"s\"===nt?r=l(Z,0,-r):nt||(r=0);var a=\"w\"===rt?e:0,o=\"n\"===nt?r:0;if(tt.isSubplotConstrained){var s;if(!rt&&1===nt.length){for(s=0;s<X.length;s++)X[s].range=X[s]._r.slice(),k(X[s],1-r/Q);a=(e=r*$/Q)/2}if(!nt&&1===rt.length){for(s=0;s<Z.length;s++)Z[s].range=Z[s]._r.slice(),k(Z[s],1-e/$);o=(r=e*Q/$)/2}}Bt(\"x\"),Bt(\"y\"),Ut([a,o,$-e,Q-r]),Nt(),t.emit(\"plotly_relayouting\",ut)}function l(t,e,r){for(var n,i,a=1-e,o=0;o<t.length;o++){var s=t[o];if(!s.fixedrange){n=s,i=s._rl[a]+(s._rl[e]-s._rl[a])/z(r/s._length);var l=s.l2r(i);!1!==l&&void 0!==l&&(s.range[e]=l)}}return n._length*(n._rl[e]-i)/(n._rl[e]-n._rl[a])}}function Bt(t,e){for(var r=et.isSubplotConstrained?{x:Z,y:X}[t]:et[t+\"axes\"],n=et.isSubplotConstrained?{x:X,y:Z}[t]:[],i=0;i<r.length;i++){var a=r[i],o=a._id,s=et.xLinks[o]||et.yLinks[o],l=n[0]||Y[s]||W[s];l&&(e?(e[a._name+\".range[0]\"]=e[l._name+\".range[0]\"],e[a._name+\".range[1]\"]=e[l._name+\".range[1]\"]):a.range=l.range.slice())}}function Nt(){var e,r=[];function n(t){for(e=0;e<t.length;e++)t[e].fixedrange||r.push(t[e]._id)}for(at&&(n(X),n(tt.xaxes),n(et.xaxes)),ot&&(n(Z),n(tt.yaxes),n(et.yaxes)),ut={},e=0;e<r.length;e++){var i=r[e],a=x(t,i);f.drawOne(t,a,{skipTitle:!0}),ut[a._name+\".range[0]\"]=a.range[0],ut[a._name+\".range[1]\"]=a.range[1]}f.redrawComponents(t,r)}function jt(){Ut([0,0,$,Q]),s.syncOrAsync([y.previousPromises,function(){t._fullLayout._replotting=!1,o.call(\"_guiRelayout\",t,ut)}],t)}function Ut(e){var r,n,i,a,l=t._fullLayout,c=l._plots,h=l._subplots.cartesian;if(lt&&o.subplotsRegistry.splom.drag(t),st)for(r=0;r<h.length;r++)if(i=(n=c[h[r]]).xaxis,a=n.yaxis,n._scene){var f=s.simpleMap(i.range,i.r2l),p=s.simpleMap(a.range,a.r2l);n._scene.update({range:[f[0],p[0],f[1],p[1]]})}if((lt||st)&&(v(t),m(t)),ct){var d=e[2]/F._length,g=e[3]/G._length;for(r=0;r<h.length;r++){i=(n=c[h[r]]).xaxis,a=n.yaxis;var y,x,b,_,w=at&&!i.fixedrange&&Y[i._id],k=ot&&!a.fixedrange&&W[a._id];if(w?(y=d,b=E?e[0]:Ht(i,y)):et.xaHash[i._id]?(y=d,b=e[0]*i._length/F._length):et.yaHash[i._id]?(y=g,b=\"ns\"===nt?-e[1]*i._length/G._length:Ht(i,y,{n:\"top\",s:\"bottom\"}[nt])):b=qt(i,y=Vt(i,d,g)),k?(x=g,_=S?e[1]:Ht(a,x)):et.yaHash[a._id]?(x=g,_=e[1]*a._length/G._length):et.xaHash[a._id]?(x=d,_=\"ew\"===rt?-e[0]*a._length/F._length:Ht(a,x,{e:\"right\",w:\"left\"}[rt])):_=qt(a,x=Vt(a,d,g)),y||x){y||(y=1),x||(x=1);var T=i._offset-b/y,A=a._offset-_/x;n.clipRect.call(u.setTranslate,b,_).call(u.setScale,y,x),n.plot.call(u.setTranslate,T,A).call(u.setScale,1/y,1/x),y===n.xScaleFactor&&x===n.yScaleFactor||(u.setPointGroupScale(n.zoomScalePts,y,x),u.setTextPointsScale(n.zoomScaleTxt,y,x)),u.hideOutsideRangePoints(n.clipOnAxisFalseTraces,n),n.xScaleFactor=y,n.yScaleFactor=x}}}}function Vt(t,e,r){return t.fixedrange?0:at&&tt.xaHash[t._id]?e:ot&&(tt.isSubplotConstrained?tt.xaHash:tt.yaHash)[t._id]?r:0}function qt(t,e){return e?(t.range=t._r.slice(),k(t,e),Ht(t,e)):0}function Ht(t,e,r){return t._length*(1-e)*g[r||t.constraintoward||\"middle\"]}return S.length*E.length!=1&&q(vt,function(e){if(t._context._scrollZoom.cartesian||t._fullLayout._enablescrollzoom){if(Et(),t._transitioningWithDuration)return e.preventDefault(),void e.stopPropagation();dt(),clearTimeout(It);var r=-e.deltaY;if(isFinite(r)||(r=e.wheelDelta/10),isFinite(r)){var n,i=Math.exp(-Math.min(Math.max(r,-20),20)/200),a=Rt.draglayer.select(\".nsewdrag\").node().getBoundingClientRect(),o=(e.clientX-a.left)/a.width,l=(a.bottom-e.clientY)/a.height;if(at){for(E||(o=.5),n=0;n<X.length;n++)c(X[n],o,i);Bt(\"x\"),zt[2]*=i,zt[0]+=zt[2]*o*(1/i-1)}if(ot){for(S||(l=.5),n=0;n<Z.length;n++)c(Z[n],l,i);Bt(\"y\"),zt[3]*=i,zt[1]+=zt[3]*(1-l)*(1/i-1)}Ut(zt),Nt(),t.emit(\"plotly_relayouting\",ut),It=setTimeout(function(){zt=[0,0,$,Q],jt()},Dt),e.preventDefault()}else s.log(\"Did not find wheel motion attributes: \",e)}function c(t,e,r){if(!t.fixedrange){var n=s.simpleMap(t.range,t.r2l),i=n[0]+(n[1]-n[0])*e;t.range=n.map(function(e){return t.l2r(i+(e-i)*r)})}}}),vt},makeDragger:E,makeRectDragger:C,makeZoombox:I,makeCorners:D,updateZoombox:R,xyCorners:U,transitionZoombox:F,removeZoombox:B,showDoubleClickNotifier:N,attachWheelEventHandler:q}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/clear_gl_canvases\":704,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../plot_api/subroutines\":758,\"../../registry\":847,\"../plots\":828,\"./axes\":767,\"./axis_ids\":770,\"./constants\":773,\"./scale_zoom\":783,\"./select\":784,d3:163,\"has-passive-events\":411,tinycolor2:537}],776:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/fx\"),a=t(\"../../components/dragelement\"),o=t(\"../../lib/setcursor\"),s=t(\"./dragbox\").makeDragBox,l=t(\"./constants\").DRAGGERSIZE;r.initInteractions=function(t){var e=t._fullLayout;if(t._context.staticPlot)n.select(t).selectAll(\".drag\").remove();else if(e._has(\"cartesian\")||e._has(\"splom\")){Object.keys(e._plots||{}).sort(function(t,r){if((e._plots[t].mainplot&&!0)===(e._plots[r].mainplot&&!0)){var n=t.split(\"y\"),i=r.split(\"y\");return n[0]===i[0]?Number(n[1]||1)-Number(i[1]||1):Number(n[0]||1)-Number(i[0]||1)}return e._plots[t].mainplot?1:-1}).forEach(function(r){var n=e._plots[r],o=n.xaxis,c=n.yaxis;if(!n.mainplot){var u=s(t,n,o._offset,c._offset,o._length,c._length,\"ns\",\"ew\");u.onmousemove=function(e){t._fullLayout._rehover=function(){t._fullLayout._hoversubplot===r&&i.hover(t,e,r)},i.hover(t,e,r),t._fullLayout._lasthover=u,t._fullLayout._hoversubplot=r},u.onmouseout=function(e){t._dragging||(t._fullLayout._hoversubplot=null,a.unhover(t,e))},t._context.showAxisDragHandles&&(s(t,n,o._offset-l,c._offset-l,l,l,\"n\",\"w\"),s(t,n,o._offset+o._length,c._offset-l,l,l,\"n\",\"e\"),s(t,n,o._offset-l,c._offset+c._length,l,l,\"s\",\"w\"),s(t,n,o._offset+o._length,c._offset+c._length,l,l,\"s\",\"e\"))}if(t._context.showAxisDragHandles){if(r===o._mainSubplot){var h=o._mainLinePosition;\"top\"===o.side&&(h-=l),s(t,n,o._offset+.1*o._length,h,.8*o._length,l,\"\",\"ew\"),s(t,n,o._offset,h,.1*o._length,l,\"\",\"w\"),s(t,n,o._offset+.9*o._length,h,.1*o._length,l,\"\",\"e\")}if(r===c._mainSubplot){var f=c._mainLinePosition;\"right\"!==c.side&&(f-=l),s(t,n,f,c._offset+.1*c._length,l,.8*c._length,\"ns\",\"\"),s(t,n,f,c._offset+.9*c._length,l,.1*c._length,\"s\",\"\"),s(t,n,f,c._offset,l,.1*c._length,\"n\",\"\")}}});var o=e._hoverlayer.node();o.onmousemove=function(r){r.target=t._fullLayout._lasthover,i.hover(t,r,e._hoversubplot)},o.onclick=function(e){e.target=t._fullLayout._lasthover,i.click(t,e)},o.onmousedown=function(e){t._fullLayout._lasthover.onmousedown(e)},r.updateFx(t)}},r.updateFx=function(t){var e=t._fullLayout,r=\"pan\"===e.dragmode?\"move\":\"crosshair\";o(e._draggers,r)}},{\"../../components/dragelement\":611,\"../../components/fx\":632,\"../../lib/setcursor\":739,\"./constants\":773,\"./dragbox\":775,d3:163}],777:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t){return function(e,r){var a=e[t];if(Array.isArray(a))for(var o=n.subplotsRegistry.cartesian,s=o.idRegex,l=r._subplots,c=l.xaxis,u=l.yaxis,h=l.cartesian,f=r._has(\"cartesian\")||r._has(\"gl2d\"),p=0;p<a.length;p++){var d=a[p];if(i.isPlainObject(d)){var g=d.xref,v=d.yref,m=s.x.test(g),y=s.y.test(v);if(m||y){f||i.pushUnique(r._basePlotModules,o);var x=!1;m&&-1===c.indexOf(g)&&(c.push(g),x=!0),y&&-1===u.indexOf(v)&&(u.push(v),x=!0),x&&m&&y&&h.push(g+v)}}}}}},{\"../../lib\":719,\"../../registry\":847}],778:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../plots\"),s=t(\"../../components/drawing\"),l=t(\"../get_data\").getModuleCalcData,c=t(\"./axis_ids\"),u=t(\"./constants\"),h=t(\"../../constants/xmlns_namespaces\"),f=a.ensureSingle;function p(t,e,r){return a.ensureSingle(t,e,r,function(t){t.datum(r)})}function d(t,e,r,a,o){for(var c,h,f,p=u.traceLayerClasses,d=t._fullLayout,g=d._modules,v=[],m=[],y=0;y<g.length;y++){var x=(c=g[y]).name,b=i.modules[x].categories;if(b.svg){var _=c.layerName||x+\"layer\",w=c.plot;f=(h=l(r,w))[0],r=h[1],f.length&&v.push({i:p.indexOf(_),className:_,plotMethod:w,cdModule:f}),b.zoomScale&&m.push(\".\"+_)}}v.sort(function(t,e){return t.i-e.i});var k=e.plot.selectAll(\"g.mlayer\").data(v,function(t){return t.className});if(k.enter().append(\"g\").attr(\"class\",function(t){return t.className}).classed(\"mlayer\",!0).classed(\"rangeplot\",e.isRangePlot),k.exit().remove(),k.order(),k.each(function(r){var i=n.select(this),l=r.className;r.plotMethod(t,e,r.cdModule,i,a,o),-1===u.clipOnAxisFalseQuery.indexOf(\".\"+l)&&s.setClipUrl(i,e.layerClipId,t)}),d._has(\"scattergl\")&&(c=i.getModule(\"scattergl\"),f=l(r,c)[0],c.plot(t,e,f)),!t._context.staticPlot&&(e._hasClipOnAxisFalse&&(e.clipOnAxisFalseTraces=e.plot.selectAll(u.clipOnAxisFalseQuery.join(\",\")).selectAll(\".trace\")),m.length)){var T=e.plot.selectAll(m.join(\",\")).selectAll(\".trace\");e.zoomScalePts=T.selectAll(\"path.point\"),e.zoomScaleTxt=T.selectAll(\".textpoint\")}}function g(t,e){var r=e.plotgroup,n=e.id,i=u.layerValue2layerClass[e.xaxis.layer],a=u.layerValue2layerClass[e.yaxis.layer],o=t._fullLayout._hasOnlyLargeSploms;if(e.mainplot){var s=e.mainplotinfo,l=s.plotgroup,h=n+\"-x\",d=n+\"-y\";e.gridlayer=s.gridlayer,e.zerolinelayer=s.zerolinelayer,f(s.overlinesBelow,\"path\",h),f(s.overlinesBelow,\"path\",d),f(s.overaxesBelow,\"g\",h),f(s.overaxesBelow,\"g\",d),e.plot=f(s.overplot,\"g\",n),f(s.overlinesAbove,\"path\",h),f(s.overlinesAbove,\"path\",d),f(s.overaxesAbove,\"g\",h),f(s.overaxesAbove,\"g\",d),e.xlines=l.select(\".overlines-\"+i).select(\".\"+h),e.ylines=l.select(\".overlines-\"+a).select(\".\"+d),e.xaxislayer=l.select(\".overaxes-\"+i).select(\".\"+h),e.yaxislayer=l.select(\".overaxes-\"+a).select(\".\"+d)}else if(o)e.xlines=f(r,\"path\",\"xlines-above\"),e.ylines=f(r,\"path\",\"ylines-above\"),e.xaxislayer=f(r,\"g\",\"xaxislayer-above\"),e.yaxislayer=f(r,\"g\",\"yaxislayer-above\");else{var g=f(r,\"g\",\"layer-subplot\");e.shapelayer=f(g,\"g\",\"shapelayer\"),e.imagelayer=f(g,\"g\",\"imagelayer\"),e.gridlayer=f(r,\"g\",\"gridlayer\"),e.zerolinelayer=f(r,\"g\",\"zerolinelayer\"),f(r,\"path\",\"xlines-below\"),f(r,\"path\",\"ylines-below\"),e.overlinesBelow=f(r,\"g\",\"overlines-below\"),f(r,\"g\",\"xaxislayer-below\"),f(r,\"g\",\"yaxislayer-below\"),e.overaxesBelow=f(r,\"g\",\"overaxes-below\"),e.plot=f(r,\"g\",\"plot\"),e.overplot=f(r,\"g\",\"overplot\"),e.xlines=f(r,\"path\",\"xlines-above\"),e.ylines=f(r,\"path\",\"ylines-above\"),e.overlinesAbove=f(r,\"g\",\"overlines-above\"),f(r,\"g\",\"xaxislayer-above\"),f(r,\"g\",\"yaxislayer-above\"),e.overaxesAbove=f(r,\"g\",\"overaxes-above\"),e.xlines=r.select(\".xlines-\"+i),e.ylines=r.select(\".ylines-\"+a),e.xaxislayer=r.select(\".xaxislayer-\"+i),e.yaxislayer=r.select(\".yaxislayer-\"+a)}o||(p(e.gridlayer,\"g\",e.xaxis._id),p(e.gridlayer,\"g\",e.yaxis._id),e.gridlayer.selectAll(\"g\").map(function(t){return t[0]}).sort(c.idSort)),e.xlines.style(\"fill\",\"none\").classed(\"crisp\",!0),e.ylines.style(\"fill\",\"none\").classed(\"crisp\",!0)}function v(t,e){if(t){var r={};for(var i in t.each(function(t){var i=t[0];n.select(this).remove(),m(i,e),r[i]=!0}),e._plots)for(var a=e._plots[i].overlays||[],o=0;o<a.length;o++){var s=a[o];r[s.id]&&s.plot.selectAll(\".trace\").remove()}}}function m(t,e){e._draggers.selectAll(\"g.\"+t).remove(),e._defs.select(\"#clip\"+e._uid+t+\"plot\").remove()}r.name=\"cartesian\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=u.idRegex,r.attrRegex=u.attrRegex,r.attributes=t(\"./attributes\"),r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.transitionAxes=t(\"./transition_axes\"),r.finalizeSubplots=function(t,e){var r,n,i,o=e._subplots,s=o.xaxis,l=o.yaxis,h=o.cartesian,f=h.concat(o.gl2d||[]),p={},d={};for(r=0;r<f.length;r++){var g=f[r].split(\"y\");p[g[0]]=1,d[\"y\"+g[1]]=1}for(r=0;r<s.length;r++)p[n=s[r]]||(i=(t[c.id2name(n)]||{}).anchor,u.idRegex.y.test(i)||(i=\"y\"),h.push(n+i),f.push(n+i),d[i]||(d[i]=1,a.pushUnique(l,i)));for(r=0;r<l.length;r++)d[i=l[r]]||(n=(t[c.id2name(i)]||{}).anchor,u.idRegex.x.test(n)||(n=\"x\"),h.push(n+i),f.push(n+i),p[n]||(p[n]=1,a.pushUnique(s,n)));if(!f.length){for(var v in n=\"\",i=\"\",t){if(u.attrRegex.test(v))\"x\"===v.charAt(0)?(!n||+v.substr(5)<+n.substr(5))&&(n=v):(!i||+v.substr(5)<+i.substr(5))&&(i=v)}n=n?c.name2id(n):\"x\",i=i?c.name2id(i):\"y\",s.push(n),l.push(i),h.push(n+i)}},r.plot=function(t,e,r,n){var i,a=t._fullLayout,o=a._subplots.cartesian,s=t.calcdata;if(!Array.isArray(e))for(e=[],i=0;i<s.length;i++)e.push(i);for(i=0;i<o.length;i++){for(var l,c=o[i],u=a._plots[c],h=[],f=0;f<s.length;f++){var p=s[f],g=p[0].trace;g.xaxis+g.yaxis===c&&((-1!==e.indexOf(g.index)||g.carpet)&&(l&&l[0].trace.xaxis+l[0].trace.yaxis===c&&-1!==[\"tonextx\",\"tonexty\",\"tonext\"].indexOf(g.fill)&&-1===h.indexOf(l)&&h.push(l),h.push(p)),l=p)}d(t,u,h,r,n)}},r.clean=function(t,e,r,n){var i,a,o,s=n._plots||{},l=e._plots||{},u=n._subplots||{};if(n._hasOnlyLargeSploms&&!e._hasOnlyLargeSploms)for(o in s)(i=s[o]).plotgroup&&i.plotgroup.remove();var h=n._has&&n._has(\"gl\"),f=e._has&&e._has(\"gl\");if(h&&!f)for(o in s)(i=s[o])._scene&&i._scene.destroy();if(u.xaxis&&u.yaxis){var p=c.listIds({_fullLayout:n});for(a=0;a<p.length;a++){var d=p[a];e[c.id2name(d)]||n._infolayer.selectAll(\".g-\"+d+\"title\").remove()}}var g=n._has&&n._has(\"cartesian\"),y=e._has&&e._has(\"cartesian\");if(g&&!y)v(n._cartesianlayer.selectAll(\".subplot\"),n),n._defs.selectAll(\".axesclip\").remove(),delete n._axisConstraintGroups;else if(u.cartesian)for(a=0;a<u.cartesian.length;a++){var x=u.cartesian[a];if(!l[x]){var b=\".\"+x+\",.\"+x+\"-x,.\"+x+\"-y\";n._cartesianlayer.selectAll(b).remove(),m(x,n)}}},r.drawFramework=function(t){var e=t._fullLayout,r=function(t){var e,r,n,i,a,o,s=t._fullLayout,l=s._subplots.cartesian,c=l.length,u=[],h=[];for(e=0;e<c;e++){n=l[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var f=a._mainAxis,p=o._mainAxis,d=f._id+p._id,g=s._plots[d];i.overlays=[],d!==n&&g?(i.mainplot=d,i.mainplotinfo=g,h.push(n)):(i.mainplot=void 0,i.mainPlotinfo=void 0,u.push(n))}for(e=0;e<h.length;e++)n=h[e],(i=s._plots[n]).mainplotinfo.overlays.push(i);var v=u.concat(h),m=new Array(c);for(e=0;e<c;e++){n=v[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var y=[n,a.layer,o.layer,a.overlaying||\"\",o.overlaying||\"\"];for(r=0;r<i.overlays.length;r++)y.push(i.overlays[r].id);m[e]=y}return m}(t),i=e._cartesianlayer.selectAll(\".subplot\").data(r,String);i.enter().append(\"g\").attr(\"class\",function(t){return\"subplot \"+t[0]}),i.order(),i.exit().call(v,e),i.each(function(r){var i=r[0],a=e._plots[i];a.plotgroup=n.select(this),g(t,a),a.draglayer=f(e._draggers,\"g\",i)})},r.rangePlot=function(t,e,r){g(t,e),d(t,e,r),o.style(t)},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter(function(t,e){return e===r.size()-1}).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each(function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:h.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})})},r.updateFx=t(\"./graph_interact\").updateFx},{\"../../components/drawing\":614,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../registry\":847,\"../get_data\":802,\"../plots\":828,\"./attributes\":765,\"./axis_ids\":770,\"./constants\":773,\"./graph_interact\":776,\"./layout_attributes\":779,\"./layout_defaults\":780,\"./transition_axes\":789,d3:163}],779:[function(t,e,r){\"use strict\";var n=t(\"../font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray,l=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").DATE_FORMAT_LINK,t(\"./constants\"));e.exports={visible:{valType:\"boolean\",editType:\"plot\"},color:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},title:{text:{valType:\"string\",editType:\"ticks\"},font:n({editType:\"ticks\"}),editType:\"ticks\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"log\",\"date\",\"category\",\"multicategory\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"axrange\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0},{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0}],editType:\"axrange\",impliedEdits:{autorange:!1},anim:!0},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},scaleanchor:{valType:\"enumerated\",values:[l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},scaleratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},constrain:{valType:\"enumerated\",values:[\"range\",\"domain\"],dflt:\"range\",editType:\"plot\"},constraintoward:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\",\"top\",\"middle\",\"bottom\"],editType:\"plot\"},matches:{valType:\"enumerated\",values:[l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"calc\"},tickmode:{valType:\"enumerated\",values:[\"auto\",\"linear\",\"array\"],editType:\"ticks\",impliedEdits:{tick0:void 0,dtick:void 0}},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"ticks\"},tick0:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},dtick:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},tickvals:{valType:\"data_array\",editType:\"ticks\"},ticktext:{valType:\"data_array\",editType:\"ticks\"},ticks:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"\"],editType:\"ticks\"},tickson:{valType:\"enumerated\",values:[\"labels\",\"boundaries\"],dflt:\"labels\",editType:\"ticks\"},mirror:{valType:\"enumerated\",values:[!0,\"ticks\",!1,\"all\",\"allticks\"],dflt:!1,editType:\"ticks+layoutstyle\"},ticklen:{valType:\"number\",min:0,dflt:5,editType:\"ticks\"},tickwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},tickcolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},showticklabels:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},automargin:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},showspikes:{valType:\"boolean\",dflt:!1,editType:\"modebar\"},spikecolor:{valType:\"color\",dflt:null,editType:\"none\"},spikethickness:{valType:\"number\",dflt:3,editType:\"none\"},spikedash:o({},a,{dflt:\"dash\",editType:\"none\"}),spikemode:{valType:\"flaglist\",flags:[\"toaxis\",\"across\",\"marker\"],dflt:\"toaxis\",editType:\"none\"},spikesnap:{valType:\"enumerated\",values:[\"data\",\"cursor\"],dflt:\"data\",editType:\"none\"},tickfont:n({editType:\"ticks\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"ticks\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"ticks\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"ticks\"},tickformatstops:s(\"tickformatstop\",{enabled:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dtickrange:{valType:\"info_array\",items:[{valType:\"any\",editType:\"ticks\"},{valType:\"any\",editType:\"ticks\"}],editType:\"ticks\"},value:{valType:\"string\",dflt:\"\",editType:\"ticks\"},editType:\"ticks\"}),hoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},showline:{valType:\"boolean\",dflt:!1,editType:\"ticks+layoutstyle\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"layoutstyle\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks+layoutstyle\"},showgrid:{valType:\"boolean\",editType:\"ticks\"},gridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"ticks\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},zeroline:{valType:\"boolean\",editType:\"ticks\"},zerolinecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},zerolinewidth:{valType:\"number\",dflt:1,editType:\"ticks\"},showdividers:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dividercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},dividerwidth:{valType:\"number\",dflt:1,editType:\"ticks\"},anchor:{valType:\"enumerated\",values:[\"free\",l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},side:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],editType:\"plot\"},overlaying:{valType:\"enumerated\",values:[\"free\",l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},layer:{valType:\"enumerated\",values:[\"above traces\",\"below traces\"],dflt:\"above traces\",editType:\"plot\"},domain:{valType:\"info_array\",items:[{valType:\"number\",min:0,max:1,editType:\"plot\"},{valType:\"number\",min:0,max:1,editType:\"plot\"}],dflt:[0,1],editType:\"plot\"},position:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\",\"total ascending\",\"total descending\",\"min ascending\",\"min descending\",\"max ascending\",\"max descending\",\"sum ascending\",\"sum descending\",\"mean ascending\",\"mean descending\",\"median ascending\",\"median descending\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{autotick:{valType:\"boolean\",editType:\"ticks\"},title:{valType:\"string\",editType:\"ticks\"},titlefont:n({editType:\"ticks\"})}}},{\"../../components/color/attributes\":592,\"../../components/drawing/attributes\":613,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../font_attributes\":793,\"./constants\":773}],780:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../layout_attributes\"),s=t(\"./layout_attributes\"),l=t(\"./type_defaults\"),c=t(\"./axis_defaults\"),u=t(\"./constraints\").handleConstraintDefaults,h=t(\"./position_defaults\"),f=t(\"./axis_ids\"),p=f.id2name,d=f.name2id,g=t(\"../../registry\"),v=g.traceIs,m=g.getComponentMethod;function y(t,e,r){Array.isArray(t[e])?t[e].push(r):t[e]=[r]}e.exports=function(t,e,r){var f,g,x={},b={},_={},w={},k={},T={},A={},M={},S={};for(f=0;f<r.length;f++){var E=r[f];if(v(E,\"cartesian\")||v(E,\"gl2d\")){var C,L;if(E.xaxis)y(x,C=p(E.xaxis),E);else if(E.xaxes)for(g=0;g<E.xaxes.length;g++)y(x,p(E.xaxes[g]),E);if(E.yaxis)y(x,L=p(E.yaxis),E);else if(E.yaxes)for(g=0;g<E.yaxes.length;g++)y(x,p(E.yaxes[g]),E);if(\"funnel\"===E.type?\"h\"===E.orientation?(C&&(b[C]=!0),L&&(A[L]=!0)):L&&(_[L]=!0):(L&&(k[L]=!0,T[L]=!0),v(E,\"carpet\")&&(\"carpet\"!==E.type||E._cheater)||C&&(w[C]=!0)),\"carpet\"===E.type&&E._cheater&&C&&(b[C]=!0),v(E,\"2dMap\")&&(M[C]=!0,M[L]=!0),v(E,\"oriented\"))S[\"h\"===E.orientation?L:C]=!0}}var P=e._subplots,O=P.xaxis,z=P.yaxis,I=n.simpleMap(O,p),D=n.simpleMap(z,p),R=I.concat(D),F=i.background;O.length&&z.length&&(F=n.coerce(t,e,o,\"plot_bgcolor\"));var B,N,j,U,V=i.combine(F,e.paper_bgcolor);function q(t,e){return n.coerce(j,U,s,t,e)}function H(t,e){return n.coerce2(j,U,s,t,e)}function G(t){return\"x\"===t?z:O}var Y={x:G(\"x\"),y:G(\"y\")},W=Y.x.concat(Y.y);function X(e,r){for(var n=\"x\"===e?I:D,i=[],a=0;a<n.length;a++){var o=n[a];o===r||(t[o]||{}).overlaying||i.push(d(o))}return i}for(f=0;f<R.length;f++){N=(B=R[f]).charAt(0),n.isPlainObject(t[B])||(t[B]={}),j=t[B],U=a.newContainer(e,B,N+\"axis\");var Z=x[B]||[];U._traceIndices=Z.map(function(t){return t._expandedIndex}),U._annIndices=[],U._shapeIndices=[],U._imgIndices=[],U._subplotsWith=[],U._counterAxes=[],U._name=U._attr=B;var J=U._id=d(B),K=X(N,B),$=\"x\"===N&&!w[B]&&b[B]||\"y\"===N&&!k[B]&&_[B],Q=\"y\"===N&&!T[B]&&A[B],tt={letter:N,font:e.font,outerTicks:M[B],showGrid:!S[B],data:Z,bgColor:V,calendar:e.calendar,automargin:!0,visibleDflt:$,reverseDflt:Q,splomStash:((e._splomAxes||{})[N]||{})[J]};q(\"uirevision\",e.uirevision),l(j,U,q,tt),c(j,U,q,tt,e);var et=H(\"spikecolor\"),rt=H(\"spikethickness\"),nt=H(\"spikedash\"),it=H(\"spikemode\"),at=H(\"spikesnap\");q(\"showspikes\",!!(et||rt||nt||it||at))||(delete U.spikecolor,delete U.spikethickness,delete U.spikedash,delete U.spikemode,delete U.spikesnap),h(j,U,q,{letter:N,counterAxes:Y[N],overlayableAxes:K,grid:e.grid}),U._input=j}var ot=m(\"rangeslider\",\"handleDefaults\"),st=m(\"rangeselector\",\"handleDefaults\");for(f=0;f<I.length;f++)B=I[f],j=t[B],U=e[B],ot(t,e,B),\"date\"===U.type&&st(j,U,e,D,U.calendar),q(\"fixedrange\");for(f=0;f<D.length;f++){B=D[f],j=t[B],U=e[B];var lt=e[p(U.anchor)];q(\"fixedrange\",m(\"rangeslider\",\"isVisible\")(lt))}var ct=e._axisConstraintGroups=[],ut=e._axisMatchGroups=[];for(f=0;f<R.length;f++)N=(B=R[f]).charAt(0),j=t[B],U=e[B],u(j,U,q,W,e);for(f=0;f<ut.length;f++){var ht,ft=ut[f],pt=null,dt=null;for(ht in ft)(U=e[p(ht)]).matches||(pt=U.range,dt=U.autorange);if(null===pt||null===dt)for(ht in ft){pt=(U=e[p(ht)]).range,dt=U.autorange;break}for(ht in ft)(U=e[p(ht)]).matches&&(U.range=pt.slice(),U.autorange=dt),U._matchGroup=ft;if(ct.length)for(ht in ft)for(g=0;g<ct.length;g++){var gt=ct[g];for(var vt in gt)ht===vt&&(n.warn(\"Axis \"+vt+\" is set with both a *scaleanchor* and *matches* constraint; ignoring the scale constraint.\"),delete gt[vt],Object.keys(gt).length<2&&ct.splice(g,1))}}}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../registry\":847,\"../layout_attributes\":819,\"./axis_defaults\":769,\"./axis_ids\":770,\"./constraints\":774,\"./layout_attributes\":779,\"./position_defaults\":782,\"./type_defaults\":790}],781:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../components/color/attributes\").lightFraction,a=t(\"../../lib\");e.exports=function(t,e,r,o){var s=(o=o||{}).dfltColor;function l(r,n){return a.coerce2(t,e,o.attributes,r,n)}var c=l(\"linecolor\",s),u=l(\"linewidth\");r(\"showline\",o.showLine||!!c||!!u)||(delete e.linecolor,delete e.linewidth);var h=l(\"gridcolor\",n(s,o.bgColor,o.blend||i).toRgbString()),f=l(\"gridwidth\");if(r(\"showgrid\",o.showGrid||!!h||!!f)||(delete e.gridcolor,delete e.gridwidth),!o.noZeroLine){var p=l(\"zerolinecolor\",s),d=l(\"zerolinewidth\");r(\"zeroline\",o.showGrid||!!p||!!d)||(delete e.zerolinecolor,delete e.zerolinewidth)}}},{\"../../components/color/attributes\":592,\"../../lib\":719,tinycolor2:537}],782:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o,s,l,c,u=a.counterAxes||[],h=a.overlayableAxes||[],f=a.letter,p=a.grid;p&&(s=p._domains[f][p._axisMap[e._id]],o=p._anchors[e._id],s&&(l=p[f+\"side\"].split(\" \")[0],c=p.domain[f][\"right\"===l||\"top\"===l?1:0])),s=s||[0,1],o=o||(n(t.position)?\"free\":u[0]||\"free\"),l=l||(\"x\"===f?\"bottom\":\"left\"),c=c||0,\"free\"===i.coerce(t,e,{anchor:{valType:\"enumerated\",values:[\"free\"].concat(u),dflt:o}},\"anchor\")&&r(\"position\",c),i.coerce(t,e,{side:{valType:\"enumerated\",values:\"x\"===f?[\"bottom\",\"top\"]:[\"left\",\"right\"],dflt:l}},\"side\");var d=!1;if(h.length&&(d=i.coerce(t,e,{overlaying:{valType:\"enumerated\",values:[!1].concat(h),dflt:!1}},\"overlaying\")),!d){var g=r(\"domain\",s);g[0]>g[1]-1/4096&&(e.domain=s),i.noneOrAll(t.domain,e.domain,s)}return r(\"layer\"),e}},{\"../../lib\":719,\"fast-isnumeric\":225}],783:[function(t,e,r){\"use strict\";var n=t(\"../../constants/alignment\").FROM_BL;e.exports=function(t,e,r){void 0===r&&(r=n[t.constraintoward||\"center\"]);var i=[t.r2l(t.range[0]),t.r2l(t.range[1])],a=i[0]+(i[1]-i[0])*r;t.range=t._input.range=[t.l2r(a+(i[0]-a)*e),t.l2r(a+(i[1]-a)*e)]}},{\"../../constants/alignment\":688}],784:[function(t,e,r){\"use strict\";var n=t(\"polybooljs\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../../components/fx\"),s=t(\"../../lib\"),l=t(\"../../lib/polygon\"),c=t(\"../../lib/throttle\"),u=t(\"../../components/fx/helpers\").makeEventData,h=t(\"./axis_ids\").getFromId,f=t(\"../../lib/clear_gl_canvases\"),p=t(\"../../plot_api/subroutines\").redrawReglTraces,d=t(\"./constants\"),g=d.MINSELECT,v=l.filter,m=l.tester;function y(t){return t._id}function x(t,e,r,n,i,a,o){var s,l,c,u,h,f,p,d,g,v=e._hoverdata,m=e._fullLayout.clickmode.indexOf(\"event\")>-1,y=[];if(function(t){return t&&Array.isArray(t)&&!0!==t[0].hoverOnBox}(v)){k(t,e,a);var x=function(t,e){var r,n,i=t[0],a=-1,o=[];for(n=0;n<e.length;n++)if(r=e[n],i.fullData._expandedIndex===r.cd[0].trace._expandedIndex){if(!0===i.hoverOnBox)break;void 0!==i.pointNumber?a=i.pointNumber:void 0!==i.binNumber&&(a=i.binNumber,o=i.pointNumbers);break}return{pointNumber:a,pointNumbers:o,searchInfo:r}}(v,s=A(e,r,n,i));if(x.pointNumbers.length>0?function(t,e){var r,n,i,a=[];for(i=0;i<t.length;i++)(r=t[i]).cd[0].trace.selectedpoints&&r.cd[0].trace.selectedpoints.length>0&&a.push(r);if(1===a.length&&a[0]===e.searchInfo&&(n=e.searchInfo.cd[0].trace).selectedpoints.length===e.pointNumbers.length){for(i=0;i<e.pointNumbers.length;i++)if(n.selectedpoints.indexOf(e.pointNumbers[i])<0)return!1;return!0}return!1}(s,x):function(t){var e,r,n,i=0;for(n=0;n<t.length;n++)if(e=t[n],(r=e.cd[0].trace).selectedpoints){if(r.selectedpoints.length>1)return!1;if((i+=r.selectedpoints.length)>1)return!1}return 1===i}(s)&&(f=S(x))){for(o&&o.remove(),g=0;g<s.length;g++)(l=s[g])._module.selectPoints(l,!1);E(e,s),T(a),m&&e.emit(\"plotly_deselect\",null)}else{for(p=t.shiftKey&&(void 0!==f?f:S(x)),c=function(t,e,r){return{pointNumber:t,searchInfo:e,subtract:r}}(x.pointNumber,x.searchInfo,p),u=w(a.selectionDefs.concat([c])),g=0;g<s.length;g++)if(h=C(s[g]._module.selectPoints(s[g],u),s[g]),y.length)for(var b=0;b<h.length;b++)y.push(h[b]);else y=h;E(e,s,d={points:y}),c&&a&&a.selectionDefs.push(c),o&&M(a.mergedPolygons,o),m&&e.emit(\"plotly_selected\",d)}}}function b(t){return\"pointNumber\"in t&&\"searchInfo\"in t}function _(t){return{xmin:0,xmax:0,ymin:0,ymax:0,pts:[],contains:function(e,r,n,i){var a=t.searchInfo.cd[0].trace._expandedIndex;return i.cd[0].trace._expandedIndex===a&&n===t.pointNumber},isRect:!1,degenerate:!1,subtract:t.subtract}}function w(t){for(var e=[],r=b(t[0])?0:t[0][0][0],n=r,i=b(t[0])?0:t[0][0][1],a=i,o=0;o<t.length;o++)if(b(t[o]))e.push(_(t[o]));else{var s=l.tester(t[o]);s.subtract=t[o].subtract,e.push(s),r=Math.min(r,s.xmin),n=Math.max(n,s.xmax),i=Math.min(i,s.ymin),a=Math.max(a,s.ymax)}return{xmin:r,xmax:n,ymin:i,ymax:a,pts:[],contains:function(t,r,n,i){for(var a=!1,o=0;o<e.length;o++)e[o].contains(t,r,n,i)&&(a=!1===e[o].subtract);return a},isRect:!1,degenerate:!1}}function k(t,e,r){var n=e._fullLayout,i=r.plotinfo,a=n._lastSelectedSubplot&&n._lastSelectedSubplot===i.id,o=t.shiftKey||t.altKey;a&&o&&i.selection&&i.selection.selectionDefs&&!r.selectionDefs?(r.selectionDefs=i.selection.selectionDefs,r.mergedPolygons=i.selection.mergedPolygons):o&&i.selection||T(r),a||(L(e),n._lastSelectedSubplot=i.id)}function T(t){var e=t.plotinfo;e.selection={},e.selection.selectionDefs=t.selectionDefs=[],e.selection.mergedPolygons=t.mergedPolygons=[]}function A(t,e,r,n){var i,a,o,s=[],l=e.map(y),c=r.map(y);for(o=0;o<t.calcdata.length;o++)if(!0===(a=(i=t.calcdata[o])[0].trace).visible&&a._module&&a._module.selectPoints)if(!n||a.subplot!==n&&a.geo!==n)if(\"splom\"===a.type&&a._xaxes[l[0]]&&a._yaxes[c[0]]){var u=p(a._module,i,e[0],r[0]);u.scene=t._fullLayout._splomScenes[a.uid],s.push(u)}else if(\"sankey\"===a.type){var f=p(a._module,i,e[0],r[0]);s.push(f)}else{if(-1===l.indexOf(a.xaxis))continue;if(-1===c.indexOf(a.yaxis))continue;s.push(p(a._module,i,h(t,a.xaxis),h(t,a.yaxis)))}else s.push(p(a._module,i,e[0],r[0]));return s;function p(t,e,r,n){return{_module:t,cd:e,xaxis:r,yaxis:n}}}function M(t,e){var r,n,i=[];for(r=0;r<t.length;r++){var a=t[r];i.push(a.join(\"L\")+\"L\"+a[0])}n=t.length>0?\"M\"+i.join(\"M\")+\"Z\":\"M0,0Z\",e.attr(\"d\",n)}function S(t){var e=t.searchInfo.cd[0].trace,r=t.pointNumber,n=t.pointNumbers,i=n.length>0?n[0]:r;return!!e.selectedpoints&&e.selectedpoints.indexOf(i)>-1}function E(t,e,r){var n,a,o,s;for(n=0;n<e.length;n++){var l=e[n].cd[0].trace._fullInput,c=t._fullLayout._tracePreGUI[l.uid]||{};void 0===c.selectedpoints&&(c.selectedpoints=l._input.selectedpoints||null)}if(r){var u=r.points||[];for(n=0;n<e.length;n++)(s=e[n].cd[0].trace)._input.selectedpoints=s._fullInput.selectedpoints=[],s._fullInput!==s&&(s.selectedpoints=[]);for(n=0;n<u.length;n++){var h=u[n],d=h.data,g=h.fullData;h.pointIndices?([].push.apply(d.selectedpoints,h.pointIndices),s._fullInput!==s&&[].push.apply(g.selectedpoints,h.pointIndices)):(d.selectedpoints.push(h.pointIndex),s._fullInput!==s&&g.selectedpoints.push(h.pointIndex))}}else for(n=0;n<e.length;n++)delete(s=e[n].cd[0].trace).selectedpoints,delete s._input.selectedpoints,s._fullInput!==s&&delete s._fullInput.selectedpoints;var v=!1;for(n=0;n<e.length;n++){s=(o=(a=e[n]).cd)[0].trace,i.traceIs(s,\"regl\")&&(v=!0);var m=a._module,y=m.styleOnSelect||m.style;y&&(y(t,o,o[0].node3),o[0].nodeRangePlot3&&y(t,o,o[0].nodeRangePlot3))}v&&(f(t),p(t))}function C(t,e){if(Array.isArray(t))for(var r=e.cd,n=e.cd[0].trace,i=0;i<t.length;i++)t[i]=u(t[i],n,r);return t}function L(t){var e=(t._fullLayout||{})._zoomlayer;e&&e.selectAll(\".select-outline\").remove()}e.exports={prepSelect:function(t,e,r,i,l){var u,h,f,p,y,b,_,S=i.gd,L=S._fullLayout,P=L._zoomlayer,O=i.element.getBoundingClientRect(),z=i.plotinfo,I=z.xaxis._offset,D=z.yaxis._offset,R=e-O.left,F=r-O.top,B=R,N=F,j=\"M\"+R+\",\"+F,U=i.xaxes[0]._length,V=i.yaxes[0]._length,q=i.xaxes.concat(i.yaxes),H=t.altKey;k(t,S,i),\"lasso\"===l&&(u=v([[R,F]],d.BENDPX));var G=P.selectAll(\"path.select-outline-\"+z.id).data([1,2]);G.enter().append(\"path\").attr(\"class\",function(t){return\"select-outline select-outline-\"+t+\" select-outline-\"+z.id}).attr(\"transform\",\"translate(\"+I+\", \"+D+\")\").attr(\"d\",j+\"Z\");var Y,W=P.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:a.background,stroke:a.defaultLine,\"stroke-width\":1}).attr(\"transform\",\"translate(\"+I+\", \"+D+\")\").attr(\"d\",\"M0,0Z\"),X=L._uid+d.SELECTID,Z=[],J=A(S,i.xaxes,i.yaxes,i.subplot);function K(t,e){return\"log\"===t.type?t.p2d(e):t.p2r(e)}function $(t){var e=\"y\"===t._id.charAt(0)?1:0;return function(r){return K(t,r[e])}}function Q(t,e){return t-e}Y=z.fillRangeItems?z.fillRangeItems:\"select\"===l?function(t,e){var r=t.range={};for(y=0;y<q.length;y++){var n=q[y],i=n._id.charAt(0);r[n._id]=[K(n,e[i+\"min\"]),K(n,e[i+\"max\"])].sort(Q)}}:function(t,e,r){var n=t.lassoPoints={};for(y=0;y<q.length;y++){var i=q[y];n[i._id]=r.filtered.map($(i))}},i.moveFn=function(t,e){B=Math.max(0,Math.min(U,t+R)),N=Math.max(0,Math.min(V,e+F));var r=Math.abs(B-R),a=Math.abs(N-F);if(\"select\"===l){var o=L.selectdirection;\"h\"===(o=\"any\"===L.selectdirection?a<Math.min(.6*r,g)?\"h\":r<Math.min(.6*a,g)?\"v\":\"d\":L.selectdirection)?((p=[[R,0],[R,V],[B,V],[B,0]]).xmin=Math.min(R,B),p.xmax=Math.max(R,B),p.ymin=Math.min(0,V),p.ymax=Math.max(0,V),W.attr(\"d\",\"M\"+p.xmin+\",\"+(F-g)+\"h-4v\"+2*g+\"h4ZM\"+(p.xmax-1)+\",\"+(F-g)+\"h4v\"+2*g+\"h-4Z\")):\"v\"===o?((p=[[0,F],[0,N],[U,N],[U,F]]).xmin=Math.min(0,U),p.xmax=Math.max(0,U),p.ymin=Math.min(F,N),p.ymax=Math.max(F,N),W.attr(\"d\",\"M\"+(R-g)+\",\"+p.ymin+\"v-4h\"+2*g+\"v4ZM\"+(R-g)+\",\"+(p.ymax-1)+\"v4h\"+2*g+\"v-4Z\")):\"d\"===o&&((p=[[R,F],[R,N],[B,N],[B,F]]).xmin=Math.min(R,B),p.xmax=Math.max(R,B),p.ymin=Math.min(F,N),p.ymax=Math.max(F,N),W.attr(\"d\",\"M0,0Z\"))}else\"lasso\"===l&&(u.addPt([B,N]),p=u.filtered);i.selectionDefs&&i.selectionDefs.length?(f=function(t,e,r){return r?n.difference({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions:n.union({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions}(i.mergedPolygons,p,H),p.subtract=H,h=w(i.selectionDefs.concat([p]))):(f=[p],h=m(p)),M(f,G),c.throttle(X,d.SELECTDELAY,function(){var t;Z=[];var e,r=[];for(y=0;y<J.length;y++)if(e=(b=J[y])._module.selectPoints(b,h),r.push(e),t=C(e,b),Z.length)for(var n=0;n<t.length;n++)Z.push(t[n]);else Z=t;E(S,J,_={points:Z}),Y(_,p,u),i.gd.emit(\"plotly_selecting\",_)})},i.clickFn=function(t,e){var r=L.clickmode;W.remove(),c.done(X).then(function(){if(c.clear(X),2===t){for(G.remove(),y=0;y<J.length;y++)(b=J[y])._module.selectPoints(b,!1);E(S,J),T(i),S.emit(\"plotly_deselect\",null)}else r.indexOf(\"select\")>-1&&x(e,S,i.xaxes,i.yaxes,i.subplot,i,G),\"event\"===r&&S.emit(\"plotly_selected\",void 0);o.click(S,e)}).catch(s.error)},i.doneFn=function(){W.remove(),c.done(X).then(function(){c.clear(X),i.gd.emit(\"plotly_selected\",_),p&&i.selectionDefs&&(p.subtract=H,i.selectionDefs.push(p),i.mergedPolygons.length=0,[].push.apply(i.mergedPolygons,f)),i.doneFnCompleted&&i.doneFnCompleted(Z)}).catch(s.error)}},clearSelect:L,selectOnClick:x}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../components/fx/helpers\":628,\"../../lib\":719,\"../../lib/clear_gl_canvases\":704,\"../../lib/polygon\":731,\"../../lib/throttle\":744,\"../../plot_api/subroutines\":758,\"../../registry\":847,\"./axis_ids\":770,\"./constants\":773,polybooljs:473}],785:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=a.cleanNumber,s=a.ms2DateTime,l=a.dateTime2ms,c=a.ensureNumber,u=a.isArrayOrTypedArray,h=t(\"../../constants/numerical\"),f=h.FP_SAFE,p=h.BADNUM,d=h.LOG_CLIP,g=t(\"./constants\"),v=t(\"./axis_ids\");function m(t){return Math.pow(10,t)}function y(t){return null!=t}e.exports=function(t,e){e=e||{};var r=t._id||\"x\",h=r.charAt(0);function x(e,r){if(e>0)return Math.log(e)/Math.LN10;if(e<=0&&r&&t.range&&2===t.range.length){var n=t.range[0],i=t.range[1];return.5*(n+i-2*d*Math.abs(n-i))}return p}function b(e,r,n){var o=l(e,n||t.calendar);if(o===p){if(!i(e))return p;e=+e;var s=Math.floor(10*a.mod(e+.05,1)),c=Math.round(e-s/10);o=l(new Date(c))+s/10}return o}function _(e,r,n){return s(e,r,n||t.calendar)}function w(e){return t._categories[Math.round(e)]}function k(e){if(y(e)){if(void 0===t._categoriesMap&&(t._categoriesMap={}),void 0!==t._categoriesMap[e])return t._categoriesMap[e];t._categories.push(\"number\"==typeof e?String(e):e);var r=t._categories.length-1;return t._categoriesMap[e]=r,r}return p}function T(e){if(t._categoriesMap)return t._categoriesMap[e]}function A(t){var e=T(t);return void 0!==e?e:i(t)?+t:void 0}function M(e){return i(e)?n.round(t._b+t._m*e,2):p}function S(e){return(e-t._b)/t._m}t.c2l=\"log\"===t.type?x:c,t.l2c=\"log\"===t.type?m:c,t.l2p=M,t.p2l=S,t.c2p=\"log\"===t.type?function(t,e){return M(x(t,e))}:M,t.p2c=\"log\"===t.type?function(t){return m(S(t))}:S,-1!==[\"linear\",\"-\"].indexOf(t.type)?(t.d2r=t.r2d=t.d2c=t.r2c=t.d2l=t.r2l=o,t.c2d=t.c2r=t.l2d=t.l2r=c,t.d2p=t.r2p=function(e){return t.l2p(o(e))},t.p2d=t.p2r=S,t.cleanPos=c):\"log\"===t.type?(t.d2r=t.d2l=function(t,e){return x(o(t),e)},t.r2d=t.r2c=function(t){return m(o(t))},t.d2c=t.r2l=o,t.c2d=t.l2r=c,t.c2r=x,t.l2d=m,t.d2p=function(e,r){return t.l2p(t.d2r(e,r))},t.p2d=function(t){return m(S(t))},t.r2p=function(e){return t.l2p(o(e))},t.p2r=S,t.cleanPos=c):\"date\"===t.type?(t.d2r=t.r2d=a.identity,t.d2c=t.r2c=t.d2l=t.r2l=b,t.c2d=t.c2r=t.l2d=t.l2r=_,t.d2p=t.r2p=function(e,r,n){return t.l2p(b(e,0,n))},t.p2d=t.p2r=function(t,e,r){return _(S(t),e,r)},t.cleanPos=function(e){return a.cleanDate(e,p,t.calendar)}):\"category\"===t.type?(t.d2c=t.d2l=k,t.r2d=t.c2d=t.l2d=w,t.d2r=t.d2l_noadd=A,t.r2c=function(e){var r=A(e);return void 0!==r?r:t.fraction2r(.5)},t.l2r=t.c2r=c,t.r2l=A,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return w(S(t))},t.r2p=t.d2p,t.p2r=S,t.cleanPos=function(t){return\"string\"==typeof t&&\"\"!==t?t:c(t)}):\"multicategory\"===t.type&&(t.r2d=t.c2d=t.l2d=w,t.d2r=t.d2l_noadd=A,t.r2c=function(e){var r=A(e);return void 0!==r?r:t.fraction2r(.5)},t.r2c_just_indices=T,t.l2r=t.c2r=c,t.r2l=A,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return w(S(t))},t.r2p=t.d2p,t.p2r=S,t.cleanPos=function(t){return Array.isArray(t)||\"string\"==typeof t&&\"\"!==t?t:c(t)},t.setupMultiCategory=function(n){var i,o,s=t._traceIndices,l=e._axisMatchGroups;if(l&&l.length&&0===t._categories.length)for(i=0;i<l.length;i++){var c=l[i];if(c[r])for(var f in c)if(f!==r){var p=e[v.id2name(f)];s=s.concat(p._traceIndices)}}var d=[[0,{}],[0,{}]],g=[];for(i=0;i<s.length;i++){var m=n[s[i]];if(h in m){var x=m[h],b=m._length||a.minRowLength(x);if(u(x[0])&&u(x[1]))for(o=0;o<b;o++){var _=x[0][o],w=x[1][o];y(_)&&y(w)&&(g.push([_,w]),_ in d[0][1]||(d[0][1][_]=d[0][0]++),w in d[1][1]||(d[1][1][w]=d[1][0]++))}}}for(g.sort(function(t,e){var r=d[0][1],n=r[t[0]]-r[e[0]];if(n)return n;var i=d[1][1];return i[t[1]]-i[e[1]]}),i=0;i<g.length;i++)k(g[i])}),t.fraction2r=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return t.l2r(r+e*(n-r))},t.r2fraction=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return(t.r2l(e)-r)/(n-r)},t.cleanRange=function(e,r){r||(r={}),e||(e=\"range\");var n,o,s=a.nestedProperty(t,e).get();if(o=(o=\"date\"===t.type?a.dfltRange(t.calendar):\"y\"===h?g.DFLTRANGEY:r.dfltRange||g.DFLTRANGEX).slice(),s&&2===s.length)for(\"date\"!==t.type||t.autorange||(s[0]=a.cleanDate(s[0],p,t.calendar),s[1]=a.cleanDate(s[1],p,t.calendar)),n=0;n<2;n++)if(\"date\"===t.type){if(!a.isDateTime(s[n],t.calendar)){t[e]=o;break}if(t.r2l(s[0])===t.r2l(s[1])){var l=a.constrain(t.r2l(s[0]),a.MIN_MS+1e3,a.MAX_MS-1e3);s[0]=t.l2r(l-1e3),s[1]=t.l2r(l+1e3);break}}else{if(!i(s[n])){if(!i(s[1-n])){t[e]=o;break}s[n]=s[1-n]*(n?10:.1)}if(s[n]<-f?s[n]=-f:s[n]>f&&(s[n]=f),s[0]===s[1]){var c=Math.max(1,Math.abs(1e-6*s[0]));s[0]-=c,s[1]+=c}}else a.nestedProperty(t,e).set(o)},t.setScale=function(r){var n=e._size;if(t.overlaying){var i=v.getFromId({_fullLayout:e},t.overlaying);t.domain=i.domain}var a=r&&t._r?\"_r\":\"range\",o=t.calendar;t.cleanRange(a);var s=t.r2l(t[a][0],o),l=t.r2l(t[a][1],o);if(\"y\"===h?(t._offset=n.t+(1-t.domain[1])*n.h,t._length=n.h*(t.domain[1]-t.domain[0]),t._m=t._length/(s-l),t._b=-t._m*l):(t._offset=n.l+t.domain[0]*n.w,t._length=n.w*(t.domain[1]-t.domain[0]),t._m=t._length/(l-s),t._b=-t._m*s),!isFinite(t._m)||!isFinite(t._b)||t._length<0)throw e._replotting=!1,new Error(\"Something went wrong with axis scaling\")},t.makeCalcdata=function(e,r){var n,i,o,s,l=t.type,c=\"date\"===l&&e[r+\"calendar\"];if(r in e){if(n=e[r],s=e._length||a.minRowLength(n),a.isTypedArray(n)&&(\"linear\"===l||\"log\"===l)){if(s===n.length)return n;if(n.subarray)return n.subarray(0,s)}if(\"multicategory\"===l)return function(t,e){for(var r=new Array(e),n=0;n<e;n++){var i=(t[0]||[])[n],a=(t[1]||[])[n];r[n]=T([i,a])}return r}(n,s);for(i=new Array(s),o=0;o<s;o++)i[o]=t.d2c(n[o],0,c)}else{var u=r+\"0\"in e?t.d2c(e[r+\"0\"],0,c):0,h=e[\"d\"+r]?Number(e[\"d\"+r]):1;for(n=e[{x:\"y\",y:\"x\"}[r]],s=e._length||n.length,i=new Array(s),o=0;o<s;o++)i[o]=u+o*h}return i},t.isValidRange=function(e){return Array.isArray(e)&&2===e.length&&i(t.r2l(e[0]))&&i(t.r2l(e[1]))},t.isPtWithinRange=function(e,r){var n=t.c2l(e[h],null,r),i=t.r2l(t.range[0]),a=t.r2l(t.range[1]);return i<a?i<=n&&n<=a:a<=n&&n<=i},t.clearCalc=function(){var n=function(){t._categories=[],t._categoriesMap={}},i=e._axisMatchGroups;if(i&&i.length){for(var a=!1,o=0;o<i.length;o++){var s=i[o];if(s[r]){a=!0;var l=null,c=null;for(var u in s){var h=e[v.id2name(u)];if(h._categories){l=h._categories,c=h._categoriesMap;break}}l&&c?(t._categories=l,t._categoriesMap=c):n();break}}a||n()}else n();if(t._initialCategories)for(var f=0;f<t._initialCategories.length;f++)k(t._initialCategories[f])},t.sortByInitialCategories=function(){var n=[];if(t._categories=[],t._categoriesMap={},t._initialCategories)for(var i=0;i<t._initialCategories.length;i++)k(t._initialCategories[i]);n=n.concat(t._traceIndices);var a=t._matchGroup;for(var o in a)if(r!==o){var s=e[v.id2name(o)];s._categories=t._categories,s._categoriesMap=t._categoriesMap,n=n.concat(s._traceIndices)}return n};var E=e._d3locale;\"date\"===t.type&&(t._dateFormat=E?E.timeFormat.utc:n.time.format.utc,t._extraFormat=e._extraFormat),t._separators=e.separators,t._numFormat=E?E.numberFormat:n.format,delete t._minDtick,delete t._forceTick0}},{\"../../constants/numerical\":695,\"../../lib\":719,\"./axis_ids\":770,\"./constants\":773,d3:163,\"fast-isnumeric\":225}],786:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"../array_container_defaults\");function o(t){var e=[\"showexponent\",\"showtickprefix\",\"showticksuffix\"].filter(function(e){return void 0!==t[e]});if(e.every(function(r){return t[r]===t[e[0]]})||1===e.length)return t[e[0]]}function s(t,e){function r(r,a){return n.coerce(t,e,i.tickformatstops,r,a)}r(\"enabled\")&&(r(\"dtickrange\"),r(\"value\"))}e.exports=function(t,e,r,l,c,u){u&&1!==u.pass||function(t,e,r,n,i){var a=o(t);r(\"tickprefix\")&&r(\"showtickprefix\",a);r(\"ticksuffix\",i.tickSuffixDflt)&&r(\"showticksuffix\",a)}(t,0,r,0,c),u&&2!==u.pass||function(t,e,r,l,c){var u=o(t);r(\"tickprefix\")&&r(\"showtickprefix\",u);r(\"ticksuffix\",c.tickSuffixDflt)&&r(\"showticksuffix\",u);if(r(\"showticklabels\")){var h=c.font||{},f=e.color,p=f&&f!==i.color.dflt?f:h.color;if(n.coerceFont(r,\"tickfont\",{family:h.family,size:h.size,color:p}),r(\"tickangle\"),\"category\"!==l){var d=r(\"tickformat\"),g=t.tickformatstops;Array.isArray(g)&&g.length&&a(t,e,{name:\"tickformatstops\",inclusionAttr:\"enabled\",handleItemDefaults:s}),d||\"date\"===l||(r(\"showexponent\",u),r(\"exponentformat\"),r(\"separatethousands\"))}}}(t,e,r,l,c)}},{\"../../lib\":719,\"../array_container_defaults\":763,\"./layout_attributes\":779}],787:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r,a){var o=n.coerce2(t,e,i,\"ticklen\"),s=n.coerce2(t,e,i,\"tickwidth\"),l=n.coerce2(t,e,i,\"tickcolor\",e.color);r(\"ticks\",a.outerTicks||o||s||l?\"outside\":\"\")||(delete e.ticklen,delete e.tickwidth,delete e.tickcolor)}},{\"../../lib\":719,\"./layout_attributes\":779}],788:[function(t,e,r){\"use strict\";var n=t(\"./clean_ticks\");e.exports=function(t,e,r,i){var a;\"array\"!==t.tickmode||\"log\"!==i&&\"date\"!==i?a=r(\"tickmode\",Array.isArray(t.tickvals)?\"array\":t.dtick?\"linear\":\"auto\"):a=e.tickmode=\"auto\";if(\"auto\"===a)r(\"nticks\");else if(\"linear\"===a){var o=e.dtick=n.dtick(t.dtick,i);e.tick0=n.tick0(t.tick0,i,e.calendar,o)}else if(\"multicategory\"!==i){void 0===r(\"tickvals\")?e.tickmode=\"auto\":r(\"ticktext\")}}},{\"./clean_ticks\":772}],789:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../components/drawing\"),o=t(\"./axes\");e.exports=function(t,e,r,s){var l=t._fullLayout;if(0!==e.length){var c,u,h,f;s&&(c=s());var p=n.ease(r.easing);return t._transitionData._interruptCallbacks.push(function(){return window.cancelAnimationFrame(f),f=null,function(){for(var r={},n=0;n<e.length;n++){var a=e[n];a.xr0&&(r[a.plotinfo.xaxis._name+\".range\"]=a.xr0.slice()),a.yr0&&(r[a.plotinfo.yaxis._name+\".range\"]=a.yr0.slice())}return i.call(\"relayout\",t,r).then(function(){for(var t=0;t<e.length;t++)d(e[t].plotinfo)})}()}),u=Date.now(),f=window.requestAnimationFrame(function n(){h=Date.now();for(var a=Math.min(1,(h-u)/r.duration),o=p(a),s=0;s<e.length;s++)g(e[s],o);h-u>r.duration?(function(){for(var r={},n=0;n<e.length;n++){var a=e[n];a.xr1&&(r[a.plotinfo.xaxis._name+\".range\"]=a.xr1.slice()),a.yr1&&(r[a.plotinfo.yaxis._name+\".range\"]=a.yr1.slice())}c&&c(),i.call(\"relayout\",t,r).then(function(){for(var t=0;t<e.length;t++)d(e[t].plotinfo)})}(),f=window.cancelAnimationFrame(n)):f=window.requestAnimationFrame(n)}),Promise.resolve()}function d(t){var e=t.xaxis,r=t.yaxis;l._defs.select(\"#\"+t.clipId+\"> rect\").call(a.setTranslate,0,0).call(a.setScale,1,1),t.plot.call(a.setTranslate,e._offset,r._offset).call(a.setScale,1,1);var n=t.plot.selectAll(\".scatterlayer .trace\");n.selectAll(\".point\").call(a.setPointGroupScale,1,1),n.selectAll(\".textpoint\").call(a.setTextPointsScale,1,1),n.call(a.hideOutsideRangePoints,t)}function g(e,r){var n=e.plotinfo,i=n.xaxis,s=n.yaxis,l=e.xr0,c=e.xr1,u=i._length,h=e.yr0,f=e.yr1,p=s._length,d=!!c,g=!!f,v=[];if(d){var m=l[1]-l[0],y=c[1]-c[0];v[0]=(l[0]*(1-r)+r*c[0]-l[0])/(l[1]-l[0])*u,v[2]=u*(1-r+r*y/m),i.range[0]=l[0]*(1-r)+r*c[0],i.range[1]=l[1]*(1-r)+r*c[1]}else v[0]=0,v[2]=u;if(g){var x=h[1]-h[0],b=f[1]-f[0];v[1]=(h[1]*(1-r)+r*f[1]-h[1])/(h[0]-h[1])*p,v[3]=p*(1-r+r*b/x),s.range[0]=h[0]*(1-r)+r*f[0],s.range[1]=h[1]*(1-r)+r*f[1]}else v[1]=0,v[3]=p;o.drawOne(t,i,{skipTitle:!0}),o.drawOne(t,s,{skipTitle:!0}),o.redrawComponents(t,[i._id,s._id]);var _=d?u/v[2]:1,w=g?p/v[3]:1,k=d?v[0]:0,T=g?v[1]:0,A=d?v[0]/v[2]*u:0,M=g?v[1]/v[3]*p:0,S=i._offset-A,E=s._offset-M;n.clipRect.call(a.setTranslate,k,T).call(a.setScale,1/_,1/w),n.plot.call(a.setTranslate,S,E).call(a.setScale,_,w),a.setPointGroupScale(n.zoomScalePts,1/_,1/w),a.setTextPointsScale(n.zoomScaleTxt,1/_,1/w)}o.redrawComponents(t)}},{\"../../components/drawing\":614,\"../../registry\":847,\"./axes\":767,d3:163}],790:[function(t,e,r){\"use strict\";var n=t(\"../../registry\").traceIs,i=t(\"./axis_autotype\");function a(t){return{v:\"x\",h:\"y\"}[t.orientation||\"v\"]}function o(t,e){var r=a(t),i=n(t,\"box-violin\"),o=n(t._fullInput||{},\"candlestick\");return i&&!o&&e===r&&void 0===t[r]&&void 0===t[r+\"0\"]}e.exports=function(t,e,r,s){\"-\"===r(\"type\",(s.splomStash||{}).type)&&(!function(t,e){if(\"-\"!==t.type)return;var r=t._id,s=r.charAt(0);-1!==r.indexOf(\"scene\")&&(r=s);var l=function(t,e,r){for(var n=0;n<t.length;n++){var i=t[n];if(\"splom\"===i.type&&i._length>0&&(i[\"_\"+r+\"axes\"]||{})[e])return i;if((i[r+\"axis\"]||r)===e){if(o(i,r))return i;if((i[r]||[]).length||i[r+\"0\"])return i}}}(e,r,s);if(!l)return;if(\"histogram\"===l.type&&s==={v:\"y\",h:\"x\"}[l.orientation||\"v\"])return void(t.type=\"linear\");var c,u=s+\"calendar\",h=l[u],f={noMultiCategory:!n(l,\"cartesian\")||n(l,\"noMultiCategory\")};if(o(l,s)){var p=a(l),d=[];for(c=0;c<e.length;c++){var g=e[c];n(g,\"box-violin\")&&(g[s+\"axis\"]||s)===r&&(void 0!==g[p]?d.push(g[p][0]):void 0!==g.name?d.push(g.name):d.push(\"text\"),g[u]!==h&&(h=void 0))}t.type=i(d,h,f)}else if(\"splom\"===l.type){var v=l.dimensions,m=v[l._axesDim[r]];m.visible&&(t.type=i(m.values,h,f))}else t.type=i(l[s]||[l[s+\"0\"]],h,f)}(e,s.data),\"-\"===e.type?e.type=\"linear\":t.type=e.type)}},{\"../../registry\":847,\"./axis_autotype\":768}],791:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\");function a(t,e,r){var n,a,o,s=!1;if(\"data\"===e.type)n=t._fullData[null!==e.traces?e.traces[0]:0];else{if(\"layout\"!==e.type)return!1;n=t._fullLayout}return a=i.nestedProperty(n,e.prop).get(),(o=r[e.type]=r[e.type]||{}).hasOwnProperty(e.prop)&&o[e.prop]!==a&&(s=!0),o[e.prop]=a,{changed:s,value:a}}function o(t,e){var r=[],n=e[0],a={};if(\"string\"==typeof n)a[n]=e[1];else{if(!i.isPlainObject(n))return r;a=n}return l(a,function(t,e,n){r.push({type:\"layout\",prop:t,value:n})},\"\",0),r}function s(t,e){var r,n,a,o,s=[];if(n=e[0],a=e[1],r=e[2],o={},\"string\"==typeof n)o[n]=a;else{if(!i.isPlainObject(n))return s;o=n,void 0===r&&(r=a)}return void 0===r&&(r=null),l(o,function(e,n,i){var a,o;if(Array.isArray(i)){o=i.slice();var l=Math.min(o.length,t.data.length);r&&(l=Math.min(l,r.length)),a=[];for(var c=0;c<l;c++)a[c]=r?r[c]:c}else o=i,a=r?r.slice():null;if(null===a)Array.isArray(o)&&(o=o[0]);else if(Array.isArray(a)){if(!Array.isArray(o)){var u=o;o=[];for(var h=0;h<a.length;h++)o[h]=u}o.length=Math.min(a.length,o.length)}s.push({type:\"data\",prop:e,traces:a,value:o})},\"\",0),s}function l(t,e,r,n){Object.keys(t).forEach(function(a){var o=t[a];if(\"_\"!==a[0]){var s=r+(n>0?\".\":\"\")+a;i.isPlainObject(o)?l(o,e,s,n+1):e(s,a,o)}})}r.manageCommandObserver=function(t,e,n,o){var s={},l=!0;e&&e._commandObserver&&(s=e._commandObserver),s.cache||(s.cache={}),s.lookupTable={};var c=r.hasSimpleAPICommandBindings(t,n,s.lookupTable);if(e&&e._commandObserver){if(c)return s;if(e._commandObserver.remove)return e._commandObserver.remove(),e._commandObserver=null,s}if(c){a(t,c,s.cache),s.check=function(){if(l){var e=a(t,c,s.cache);return e.changed&&o&&void 0!==s.lookupTable[e.value]&&(s.disable(),Promise.resolve(o({value:e.value,type:c.type,prop:c.prop,traces:c.traces,index:s.lookupTable[e.value]})).then(s.enable,s.enable)),e.changed}};for(var u=[\"plotly_relayout\",\"plotly_redraw\",\"plotly_restyle\",\"plotly_update\",\"plotly_animatingframe\",\"plotly_afterplot\"],h=0;h<u.length;h++)t._internalOn(u[h],s.check);s.remove=function(){for(var e=0;e<u.length;e++)t._removeInternalListener(u[e],s.check)}}else i.log(\"Unable to automatically bind plot updates to API command\"),s.lookupTable={},s.remove=function(){};return s.disable=function(){l=!1},s.enable=function(){l=!0},e&&(e._commandObserver=s),s},r.hasSimpleAPICommandBindings=function(t,e,n){var i,a,o=e.length;for(i=0;i<o;i++){var s,l=e[i],c=l.method,u=l.args;if(Array.isArray(u)||(u=[]),!c)return!1;var h=r.computeAPICommandBindings(t,c,u);if(1!==h.length)return!1;if(a){if((s=h[0]).type!==a.type)return!1;if(s.prop!==a.prop)return!1;if(Array.isArray(a.traces)){if(!Array.isArray(s.traces))return!1;s.traces.sort();for(var f=0;f<a.traces.length;f++)if(a.traces[f]!==s.traces[f])return!1}else if(s.prop!==a.prop)return!1}else a=h[0],Array.isArray(a.traces)&&a.traces.sort();var p=(s=h[0]).value;if(Array.isArray(p)){if(1!==p.length)return!1;p=p[0]}n&&(n[p]=i)}return a},r.executeAPICommand=function(t,e,r){if(\"skip\"===e)return Promise.resolve();var a=n.apiMethodRegistry[e],o=[t];Array.isArray(r)||(r=[]);for(var s=0;s<r.length;s++)o.push(r[s]);return a.apply(null,o).catch(function(t){return i.warn(\"API call to Plotly.\"+e+\" rejected.\",t),Promise.reject(t)})},r.computeAPICommandBindings=function(t,e,r){var n;switch(Array.isArray(r)||(r=[]),e){case\"restyle\":n=s(t,r);break;case\"relayout\":n=o(t,r);break;case\"update\":n=s(t,[r[0],r[2]]).concat(o(t,[r[1]]));break;case\"animate\":n=function(t,e){return Array.isArray(e[0])&&1===e[0].length&&-1!==[\"string\",\"number\"].indexOf(typeof e[0][0])?[{type:\"layout\",prop:\"_currentFrame\",value:e[0][0].toString()}]:[]}(0,r);break;default:n=[]}return n}},{\"../lib\":719,\"../registry\":847}],792:[function(t,e,r){\"use strict\";var n=t(\"../lib/extend\").extendFlat;r.attributes=function(t,e){e=e||{};var r={valType:\"info_array\",editType:(t=t||{}).editType,items:[{valType:\"number\",min:0,max:1,editType:t.editType},{valType:\"number\",min:0,max:1,editType:t.editType}],dflt:[0,1]},i=(t.name&&t.name,t.trace,e.description&&e.description,{x:n({},r,{}),y:n({},r,{}),editType:t.editType});return t.noGridCell||(i.row={valType:\"integer\",min:0,dflt:0,editType:t.editType},i.column={valType:\"integer\",min:0,dflt:0,editType:t.editType}),i},r.defaults=function(t,e,r,n){var i=n&&n.x||[0,1],a=n&&n.y||[0,1],o=e.grid;if(o){var s=r(\"domain.column\");void 0!==s&&(s<o.columns?i=o._domains.x[s]:delete t.domain.column);var l=r(\"domain.row\");void 0!==l&&(l<o.rows?a=o._domains.y[l]:delete t.domain.row)}r(\"domain.x\",i),r(\"domain.y\",a)}},{\"../lib/extend\":710}],793:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType,r=t.colorEditType;void 0===r&&(r=e);var n={family:{valType:\"string\",noBlank:!0,strict:!0,editType:e},size:{valType:\"number\",min:1,editType:e},color:{valType:\"color\",editType:r},editType:e};return t.arrayOk&&(n.family.arrayOk=!0,n.size.arrayOk=!0,n.color.arrayOk=!0),n}},{}],794:[function(t,e,r){\"use strict\";e.exports={_isLinkedToArray:\"frames_entry\",group:{valType:\"string\"},name:{valType:\"string\"},traces:{valType:\"any\"},baseframe:{valType:\"string\"},data:{valType:\"any\"},layout:{valType:\"any\"}}},{}],795:[function(t,e,r){\"use strict\";r.projNames={equirectangular:\"equirectangular\",mercator:\"mercator\",orthographic:\"orthographic\",\"natural earth\":\"naturalEarth\",kavrayskiy7:\"kavrayskiy7\",miller:\"miller\",robinson:\"robinson\",eckert4:\"eckert4\",\"azimuthal equal area\":\"azimuthalEqualArea\",\"azimuthal equidistant\":\"azimuthalEquidistant\",\"conic equal area\":\"conicEqualArea\",\"conic conformal\":\"conicConformal\",\"conic equidistant\":\"conicEquidistant\",gnomonic:\"gnomonic\",stereographic:\"stereographic\",mollweide:\"mollweide\",hammer:\"hammer\",\"transverse mercator\":\"transverseMercator\",\"albers usa\":\"albersUsa\",\"winkel tripel\":\"winkel3\",aitoff:\"aitoff\",sinusoidal:\"sinusoidal\"},r.axesNames=[\"lonaxis\",\"lataxis\"],r.lonaxisSpan={orthographic:180,\"azimuthal equal area\":360,\"azimuthal equidistant\":360,\"conic conformal\":180,gnomonic:160,stereographic:180,\"transverse mercator\":180,\"*\":360},r.lataxisSpan={\"conic conformal\":150,stereographic:179.5,\"*\":180},r.scopeDefaults={world:{lonaxisRange:[-180,180],lataxisRange:[-90,90],projType:\"equirectangular\",projRotate:[0,0,0]},usa:{lonaxisRange:[-180,-50],lataxisRange:[15,80],projType:\"albers usa\"},europe:{lonaxisRange:[-30,60],lataxisRange:[30,85],projType:\"conic conformal\",projRotate:[15,0,0],projParallels:[0,60]},asia:{lonaxisRange:[22,160],lataxisRange:[-15,55],projType:\"mercator\",projRotate:[0,0,0]},africa:{lonaxisRange:[-30,60],lataxisRange:[-40,40],projType:\"mercator\",projRotate:[0,0,0]},\"north america\":{lonaxisRange:[-180,-45],lataxisRange:[5,85],projType:\"conic conformal\",projRotate:[-100,0,0],projParallels:[29.5,45.5]},\"south america\":{lonaxisRange:[-100,-30],lataxisRange:[-60,15],projType:\"mercator\",projRotate:[0,0,0]}},r.clipPad=.001,r.precision=.1,r.landColor=\"#F0DC82\",r.waterColor=\"#3399FF\",r.locationmodeToLayer={\"ISO-3\":\"countries\",\"USA-states\":\"subunits\",\"country names\":\"countries\"},r.sphereSVG={type:\"Sphere\"},r.fillLayers={ocean:1,land:1,lakes:1},r.lineLayers={subunits:1,countries:1,coastlines:1,rivers:1,frame:1},r.layers=[\"bg\",\"ocean\",\"land\",\"lakes\",\"subunits\",\"countries\",\"coastlines\",\"rivers\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"frontplot\"],r.layersForChoropleth=[\"bg\",\"ocean\",\"land\",\"subunits\",\"countries\",\"coastlines\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"rivers\",\"lakes\",\"frontplot\"],r.layerNameToAdjective={ocean:\"ocean\",land:\"land\",lakes:\"lake\",subunits:\"subunit\",countries:\"country\",coastlines:\"coastline\",rivers:\"river\",frame:\"frame\"}},{}],796:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"../../components/fx\"),c=t(\"../plots\"),u=t(\"../cartesian/axes\"),h=t(\"../../components/dragelement\"),f=t(\"../cartesian/select\").prepSelect,p=t(\"../cartesian/select\").selectOnClick,d=t(\"./zoom\"),g=t(\"./constants\"),v=t(\"../../lib/topojson_utils\"),m=t(\"topojson-client\").feature;function y(t){this.id=t.id,this.graphDiv=t.graphDiv,this.container=t.container,this.topojsonURL=t.topojsonURL,this.isStatic=t.staticPlot,this.topojsonName=null,this.topojson=null,this.projection=null,this.scope=null,this.viewInitial=null,this.fitScale=null,this.bounds=null,this.midPt=null,this.hasChoropleth=!1,this.traceHash={},this.layers={},this.basePaths={},this.dataPaths={},this.dataPoints={},this.clipDef=null,this.clipRect=null,this.bgRect=null,this.makeFramework()}t(\"./projections\")(n);var x=y.prototype;e.exports=function(t){return new y(t)},x.plot=function(t,e,r){var n=this,i=e[this.id],a=!1;for(var o in g.layerNameToAdjective)if(\"frame\"!==o&&i[\"show\"+o]){a=!0;break}for(var s=0;s<t.length;s++)if(t[0][0].trace.locationmode){a=!0;break}if(!a)return n.update(t,e);var l=v.getTopojsonName(i);null===n.topojson||l!==n.topojsonName?(n.topojsonName=l,void 0===PlotlyGeoAssets.topojson[n.topojsonName]?r.push(n.fetchTopojson().then(function(r){PlotlyGeoAssets.topojson[n.topojsonName]=r,n.topojson=r,n.update(t,e)})):(n.topojson=PlotlyGeoAssets.topojson[n.topojsonName],n.update(t,e))):n.update(t,e)},x.fetchTopojson=function(){var t=v.getTopojsonPath(this.topojsonURL,this.topojsonName);return new Promise(function(e,r){n.json(t,function(n,i){if(n)return 404===n.status?r(new Error([\"plotly.js could not find topojson file at\",t,\".\",\"Make sure the *topojsonURL* plot config option\",\"is set properly.\"].join(\" \"))):r(new Error([\"unexpected error while fetching topojson file at\",t].join(\" \")));e(i)})})},x.update=function(t,e){var r=e[this.id];if(!this.updateProjection(e,r)){this.hasChoropleth=!1;for(var n=0;n<t.length;n++)if(\"choropleth\"===t[n][0].trace.type){this.hasChoropleth=!0;break}this.viewInitial&&this.scope===r.scope||this.saveViewInitial(r),this.scope=r.scope,this.updateBaseLayers(e,r),this.updateDims(e,r),this.updateFx(e,r),c.generalUpdatePerTraceModule(this.graphDiv,this,t,r);var i=this.layers.frontplot.select(\".scatterlayer\");this.dataPoints.point=i.selectAll(\".point\"),this.dataPoints.text=i.selectAll(\"text\"),this.dataPaths.line=i.selectAll(\".js-line\");var a=this.layers.backplot.select(\".choroplethlayer\");this.dataPaths.choropleth=a.selectAll(\"path\"),this.render()}},x.updateProjection=function(t,e){var r=t._size,o=e.domain,s=e.projection,l=s.rotation||{},c=e.center||{},u=this.projection=function(t){for(var e=t.projection.type,r=n.geo[g.projNames[e]](),i=t._isClipped?g.lonaxisSpan[e]/2:null,a=[\"center\",\"rotate\",\"parallels\",\"clipExtent\"],o=function(t){return t?r:[]},s=0;s<a.length;s++){var l=a[s];\"function\"!=typeof r[l]&&(r[l]=o)}r.isLonLatOverEdges=function(t){if(null===r(t))return!0;if(i){var e=r.rotate();return n.geo.distance(t,[-e[0],-e[1]])>i*Math.PI/180}return!1},r.getPath=function(){return n.geo.path().projection(r)},r.getBounds=function(t){return r.getPath().bounds(t)},r.fitExtent=function(t,e){var n=t[1][0]-t[0][0],i=t[1][1]-t[0][1],a=r.clipExtent&&r.clipExtent();r.scale(150).translate([0,0]),a&&r.clipExtent(null);var o=r.getBounds(e),s=Math.min(n/(o[1][0]-o[0][0]),i/(o[1][1]-o[0][1])),l=+t[0][0]+(n-s*(o[1][0]+o[0][0]))/2,c=+t[0][1]+(i-s*(o[1][1]+o[0][1]))/2;return a&&r.clipExtent(a),r.scale(150*s).translate([l,c])},r.precision(g.precision),i&&r.clipAngle(i-g.clipPad);return r}(e);u.center([c.lon-l.lon,c.lat-l.lat]).rotate([-l.lon,-l.lat,l.roll]).parallels(s.parallels);var h=[[r.l+r.w*o.x[0],r.t+r.h*(1-o.y[1])],[r.l+r.w*o.x[1],r.t+r.h*(1-o.y[0])]],f=e.lonaxis,p=e.lataxis,d=function(t,e){var r=g.clipPad,n=t[0]+r,i=t[1]-r,a=e[0]+r,o=e[1]-r;n>0&&i<0&&(i+=360);var s=(i-n)/4;return{type:\"Polygon\",coordinates:[[[n,a],[n,o],[n+s,o],[n+2*s,o],[n+3*s,o],[i,o],[i,a],[i-s,a],[i-2*s,a],[i-3*s,a],[n,a]]]}}(f.range,p.range);u.fitExtent(h,d);var v=this.bounds=u.getBounds(d),m=this.fitScale=u.scale(),y=u.translate();if(!isFinite(v[0][0])||!isFinite(v[0][1])||!isFinite(v[1][0])||!isFinite(v[1][1])||isNaN(y[0])||isNaN(y[0])){for(var x=this.graphDiv,b=[\"projection.rotation\",\"center\",\"lonaxis.range\",\"lataxis.range\"],_=\"Invalid geo settings, relayout'ing to default view.\",w={},k=0;k<b.length;k++)w[this.id+\".\"+b[k]]=null;return this.viewInitial=null,a.warn(_),x._promises.push(i.call(\"relayout\",x,w)),_}var T=this.midPt=[(v[0][0]+v[1][0])/2,(v[0][1]+v[1][1])/2];if(u.scale(s.scale*m).translate([y[0]+(T[0]-y[0]),y[1]+(T[1]-y[1])]).clipExtent(v),e._isAlbersUsa){var A=u([c.lon,c.lat]),M=u.translate();u.translate([M[0]-(A[0]-M[0]),M[1]-(A[1]-M[1])])}},x.updateBaseLayers=function(t,e){var r=this,i=r.topojson,a=r.layers,l=r.basePaths;function c(t){return\"lonaxis\"===t||\"lataxis\"===t}function h(t){return Boolean(g.lineLayers[t])}function f(t){return Boolean(g.fillLayers[t])}var p=(this.hasChoropleth?g.layersForChoropleth:g.layers).filter(function(t){return h(t)||f(t)?e[\"show\"+t]:!c(t)||e[t].showgrid}),d=r.framework.selectAll(\".layer\").data(p,String);d.exit().each(function(t){delete a[t],delete l[t],n.select(this).remove()}),d.enter().append(\"g\").attr(\"class\",function(t){return\"layer \"+t}).each(function(t){var e=a[t]=n.select(this);\"bg\"===t?r.bgRect=e.append(\"rect\").style(\"pointer-events\",\"all\"):c(t)?l[t]=e.append(\"path\").style(\"fill\",\"none\"):\"backplot\"===t?e.append(\"g\").classed(\"choroplethlayer\",!0):\"frontplot\"===t?e.append(\"g\").classed(\"scatterlayer\",!0):h(t)?l[t]=e.append(\"path\").style(\"fill\",\"none\").style(\"stroke-miterlimit\",2):f(t)&&(l[t]=e.append(\"path\").style(\"stroke\",\"none\"))}),d.order(),d.each(function(r){var n=l[r],a=g.layerNameToAdjective[r];\"frame\"===r?n.datum(g.sphereSVG):h(r)||f(r)?n.datum(m(i,i.objects[r])):c(r)&&n.datum(function(t,e,r){var n,i,a,o=e[t],s=g.scopeDefaults[e.scope];\"lonaxis\"===t?(n=s.lonaxisRange,i=s.lataxisRange,a=function(t,e){return[t,e]}):\"lataxis\"===t&&(n=s.lataxisRange,i=s.lonaxisRange,a=function(t,e){return[e,t]});var l={type:\"linear\",range:[n[0],n[1]-1e-6],tick0:o.tick0,dtick:o.dtick};u.setConvert(l,r);var c=u.calcTicks(l);e.isScoped||\"lonaxis\"!==t||c.pop();for(var h=c.length,f=new Array(h),p=0;p<h;p++)for(var d=c[p].x,v=f[p]=[],m=i[0];m<i[1]+2.5;m+=2.5)v.push(a(d,m));return{type:\"MultiLineString\",coordinates:f}}(r,e,t)).call(o.stroke,e[r].gridcolor).call(s.dashLine,\"\",e[r].gridwidth),h(r)?n.call(o.stroke,e[a+\"color\"]).call(s.dashLine,\"\",e[a+\"width\"]):f(r)&&n.call(o.fill,e[a+\"color\"])})},x.updateDims=function(t,e){var r=this.bounds,n=(e.framewidth||0)/2,i=r[0][0]-n,a=r[0][1]-n,l=r[1][0]-i+n,c=r[1][1]-a+n;s.setRect(this.clipRect,i,a,l,c),this.bgRect.call(s.setRect,i,a,l,c).call(o.fill,e.bgcolor),this.xaxis._offset=i,this.xaxis._length=l,this.yaxis._offset=a,this.yaxis._length=c},x.updateFx=function(t,e){var r=this,a=r.graphDiv,o=r.bgRect,s=t.dragmode,c=t.clickmode;if(!r.isStatic){var u;\"select\"===s?u=function(t,e){(t.range={})[r.id]=[v([e.xmin,e.ymin]),v([e.xmax,e.ymax])]}:\"lasso\"===s&&(u=function(t,e,n){(t.lassoPoints={})[r.id]=n.filtered.map(v)});var g={element:r.bgRect.node(),gd:a,plotinfo:{id:r.id,xaxis:r.xaxis,yaxis:r.yaxis,fillRangeItems:u},xaxes:[r.xaxis],yaxes:[r.yaxis],subplot:r.id,clickFn:function(e){2===e&&t._zoomlayer.selectAll(\".select-outline\").remove()}};\"pan\"===s?(o.node().onmousedown=null,o.call(d(r,e)),o.on(\"dblclick.zoom\",function(){var t=r.viewInitial,e={};for(var n in t)e[r.id+\".\"+n]=t[n];i.call(\"_guiRelayout\",a,e),a.emit(\"plotly_doubleclick\",null)}),a._context._scrollZoom.geo||o.on(\"wheel.zoom\",null)):\"select\"!==s&&\"lasso\"!==s||(o.on(\".zoom\",null),g.prepFn=function(t,e,r){f(t,e,r,g,s)},h.init(g)),o.on(\"mousemove\",function(){var t=r.projection.invert(n.mouse(this));if(!t||isNaN(t[0])||isNaN(t[1]))return h.unhover(a,n.event);r.xaxis.p2c=function(){return t[0]},r.yaxis.p2c=function(){return t[1]},l.hover(a,n.event,r.id)}),o.on(\"mouseout\",function(){a._dragging||h.unhover(a,n.event)}),o.on(\"click\",function(){\"select\"!==s&&\"lasso\"!==s&&(c.indexOf(\"select\")>-1&&p(n.event,a,[r.xaxis],[r.yaxis],r.id,g),c.indexOf(\"event\")>-1&&l.click(a,n.event))})}function v(t){return r.projection.invert([t[0]+r.xaxis._offset,t[1]+r.yaxis._offset])}},x.makeFramework=function(){var t=this,e=t.graphDiv,r=e._fullLayout,i=\"clip\"+r._uid+t.id;t.clipDef=r._clips.append(\"clipPath\").attr(\"id\",i),t.clipRect=t.clipDef.append(\"rect\"),t.framework=n.select(t.container).append(\"g\").attr(\"class\",\"geo \"+t.id).call(s.setClipUrl,i,e),t.project=function(e){var r=t.projection(e);return r?[r[0]-t.xaxis._offset,r[1]-t.yaxis._offset]:[null,null]},t.xaxis={_id:\"x\",c2p:function(e){return t.project(e)[0]}},t.yaxis={_id:\"y\",c2p:function(e){return t.project(e)[1]}},t.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},u.setConvert(t.mockAxis,r)},x.saveViewInitial=function(t){var e=t.center||{},r=t.projection,n=r.rotation||{};t._isScoped?this.viewInitial={\"center.lon\":e.lon,\"center.lat\":e.lat,\"projection.scale\":r.scale}:t._isClipped?this.viewInitial={\"projection.scale\":r.scale,\"projection.rotation.lon\":n.lon,\"projection.rotation.lat\":n.lat}:this.viewInitial={\"center.lon\":e.lon,\"center.lat\":e.lat,\"projection.scale\":r.scale,\"projection.rotation.lon\":n.lon}},x.render=function(){var t,e=this.projection,r=e.getPath();function n(t){var r=e(t.lonlat);return r?\"translate(\"+r[0]+\",\"+r[1]+\")\":null}function i(t){return e.isLonLatOverEdges(t.lonlat)?\"none\":null}for(t in this.basePaths)this.basePaths[t].attr(\"d\",r);for(t in this.dataPaths)this.dataPaths[t].attr(\"d\",function(t){return r(t.geojson)});for(t in this.dataPoints)this.dataPoints[t].attr(\"display\",i).attr(\"transform\",n)}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../lib\":719,\"../../lib/topojson_utils\":746,\"../../registry\":847,\"../cartesian/axes\":767,\"../cartesian/select\":784,\"../plots\":828,\"./constants\":795,\"./projections\":800,\"./zoom\":801,d3:163,\"topojson-client\":540}],797:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./geo\"),o=\"geo\",s=i(o),l={};l[o]={valType:\"subplotid\",dflt:o,editType:\"calc\"},e.exports={attr:o,name:o,idRoot:o,idRegex:s,attrRegex:s,attributes:l,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[o],s=0;s<i.length;s++){var l=i[s],c=n(r,o,l),u=e[l]._subplot;u||(u=a({id:l,graphDiv:t,container:e._geolayer.node(),topojsonURL:t._context.topojsonURL,staticPlot:t._context.staticPlot}),e[l]._subplot=u),u.plot(c,e,t._promises)}},updateFx:function(t){for(var e=t._fullLayout,r=e._subplots[o],n=0;n<r.length;n++){var i=e[r[n]];i._subplot.updateFx(e,i)}},clean:function(t,e,r,n){for(var i=n._subplots[o]||[],a=0;a<i.length;a++){var s=i[a],l=n[s]._subplot;!e[s]&&l&&(l.framework.remove(),l.clipDef.remove())}}}},{\"../../lib\":719,\"../../plots/get_data\":802,\"./geo\":796,\"./layout_attributes\":798,\"./layout_defaults\":799}],798:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"./constants\"),o=t(\"../../plot_api/edit_types\").overrideAll,s={range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},showgrid:{valType:\"boolean\",dflt:!1},tick0:{valType:\"number\",dflt:0},dtick:{valType:\"number\"},gridcolor:{valType:\"color\",dflt:n.lightLine},gridwidth:{valType:\"number\",min:0,dflt:1}};(e.exports=o({domain:i({name:\"geo\"},{}),resolution:{valType:\"enumerated\",values:[110,50],dflt:110,coerceNumber:!0},scope:{valType:\"enumerated\",values:Object.keys(a.scopeDefaults),dflt:\"world\"},projection:{type:{valType:\"enumerated\",values:Object.keys(a.projNames)},rotation:{lon:{valType:\"number\"},lat:{valType:\"number\"},roll:{valType:\"number\"}},parallels:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},scale:{valType:\"number\",min:0,dflt:1}},center:{lon:{valType:\"number\"},lat:{valType:\"number\"}},showcoastlines:{valType:\"boolean\"},coastlinecolor:{valType:\"color\",dflt:n.defaultLine},coastlinewidth:{valType:\"number\",min:0,dflt:1},showland:{valType:\"boolean\",dflt:!1},landcolor:{valType:\"color\",dflt:a.landColor},showocean:{valType:\"boolean\",dflt:!1},oceancolor:{valType:\"color\",dflt:a.waterColor},showlakes:{valType:\"boolean\",dflt:!1},lakecolor:{valType:\"color\",dflt:a.waterColor},showrivers:{valType:\"boolean\",dflt:!1},rivercolor:{valType:\"color\",dflt:a.waterColor},riverwidth:{valType:\"number\",min:0,dflt:1},showcountries:{valType:\"boolean\"},countrycolor:{valType:\"color\",dflt:n.defaultLine},countrywidth:{valType:\"number\",min:0,dflt:1},showsubunits:{valType:\"boolean\"},subunitcolor:{valType:\"color\",dflt:n.defaultLine},subunitwidth:{valType:\"number\",min:0,dflt:1},showframe:{valType:\"boolean\"},framecolor:{valType:\"color\",dflt:n.defaultLine},framewidth:{valType:\"number\",min:0,dflt:1},bgcolor:{valType:\"color\",dflt:n.background},lonaxis:s,lataxis:s},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":592,\"../../plot_api/edit_types\":750,\"../domain\":792,\"./constants\":795}],799:[function(t,e,r){\"use strict\";var n=t(\"../subplot_defaults\"),i=t(\"./constants\"),a=t(\"./layout_attributes\"),o=i.axesNames;function s(t,e,r){var n=r(\"resolution\"),a=r(\"scope\"),s=i.scopeDefaults[a],l=r(\"projection.type\",s.projType),c=e._isAlbersUsa=\"albers usa\"===l;c&&(a=e.scope=\"usa\");var u=e._isScoped=\"world\"!==a,h=e._isConic=-1!==l.indexOf(\"conic\");e._isClipped=!!i.lonaxisSpan[l];for(var f=0;f<o.length;f++){var p,d=o[f],g=[30,10][f];if(u)p=s[d+\"Range\"];else{var v=i[d+\"Span\"],m=(v[l]||v[\"*\"])/2,y=r(\"projection.rotation.\"+d.substr(0,3),s.projRotate[f]);p=[y-m,y+m]}r(d+\".range\",p),r(d+\".tick0\"),r(d+\".dtick\",g),r(d+\".showgrid\")&&(r(d+\".gridcolor\"),r(d+\".gridwidth\"))}var x=e.lonaxis.range,b=e.lataxis.range,_=x[0],w=x[1];_>0&&w<0&&(w+=360);var k,T,A,M=(_+w)/2;if(!c){var S=u?s.projRotate:[M,0,0];k=r(\"projection.rotation.lon\",S[0]),r(\"projection.rotation.lat\",S[1]),r(\"projection.rotation.roll\",S[2]),r(\"showcoastlines\",!u)&&(r(\"coastlinecolor\"),r(\"coastlinewidth\")),r(\"showocean\")&&r(\"oceancolor\")}(c?(T=-96.6,A=38.7):(T=u?M:k,A=(b[0]+b[1])/2),r(\"center.lon\",T),r(\"center.lat\",A),h)&&r(\"projection.parallels\",s.projParallels||[0,60]);r(\"projection.scale\"),r(\"showland\")&&r(\"landcolor\"),r(\"showlakes\")&&r(\"lakecolor\"),r(\"showrivers\")&&(r(\"rivercolor\"),r(\"riverwidth\")),r(\"showcountries\",u&&\"usa\"!==a)&&(r(\"countrycolor\"),r(\"countrywidth\")),(\"usa\"===a||\"north america\"===a&&50===n)&&(r(\"showsubunits\",!0),r(\"subunitcolor\"),r(\"subunitwidth\")),u||r(\"showframe\",!0)&&(r(\"framecolor\"),r(\"framewidth\")),r(\"bgcolor\")}e.exports=function(t,e,r){n(t,e,r,{type:\"geo\",attributes:a,handleDefaults:s,partition:\"y\"})}},{\"../subplot_defaults\":842,\"./constants\":795,\"./layout_attributes\":798}],800:[function(t,e,r){\"use strict\";e.exports=function(t){function e(t,e){return{type:\"Feature\",id:t.id,properties:t.properties,geometry:r(t.geometry,e)}}function r(e,n){if(!e)return null;if(\"GeometryCollection\"===e.type)return{type:\"GeometryCollection\",geometries:object.geometries.map(function(t){return r(t,n)})};if(!c.hasOwnProperty(e.type))return null;var i=c[e.type];return t.geo.stream(e,n(i)),i.result()}t.geo.project=function(t,e){var i=e.stream;if(!i)throw new Error(\"not yet supported\");return(t&&n.hasOwnProperty(t.type)?n[t.type]:r)(t,i)};var n={Feature:e,FeatureCollection:function(t,r){return{type:\"FeatureCollection\",features:t.features.map(function(t){return e(t,r)})}}},i=[],a=[],o={point:function(t,e){i.push([t,e])},result:function(){var t=i.length?i.length<2?{type:\"Point\",coordinates:i[0]}:{type:\"MultiPoint\",coordinates:i}:null;return i=[],t}},s={lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){i.length&&(a.push(i),i=[])},result:function(){var t=a.length?a.length<2?{type:\"LineString\",coordinates:a[0]}:{type:\"MultiLineString\",coordinates:a}:null;return a=[],t}},l={polygonStart:u,lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){var t=i.length;if(t){do{i.push(i[0].slice())}while(++t<4);a.push(i),i=[]}},polygonEnd:u,result:function(){if(!a.length)return null;var t=[],e=[];return a.forEach(function(r){!function(t){if((e=t.length)<4)return!1;for(var e,r=0,n=t[e-1][1]*t[0][0]-t[e-1][0]*t[0][1];++r<e;)n+=t[r-1][1]*t[r][0]-t[r-1][0]*t[r][1];return n<=0}(r)?e.push(r):t.push([r])}),e.forEach(function(e){var r=e[0];t.some(function(t){if(function(t,e){for(var r=e[0],n=e[1],i=!1,a=0,o=t.length,s=o-1;a<o;s=a++){var l=t[a],c=l[0],u=l[1],h=t[s],f=h[0],p=h[1];u>n^p>n&&r<(f-c)*(n-u)/(p-u)+c&&(i=!i)}return i}(t[0],r))return t.push(e),!0})||t.push([e])}),a=[],t.length?t.length>1?{type:\"MultiPolygon\",coordinates:t}:{type:\"Polygon\",coordinates:t[0]}:null}},c={Point:o,MultiPoint:o,LineString:s,MultiLineString:s,Polygon:l,MultiPolygon:l,Sphere:l};function u(){}var h=1e-6,f=h*h,p=Math.PI,d=p/2,g=(Math.sqrt(p),p/180),v=180/p;function m(t){return t>1?d:t<-1?-d:Math.asin(t)}function y(t){return t>1?0:t<-1?p:Math.acos(t)}var x=t.geo.projection,b=t.geo.projectionMutator;function _(t,e){var r=(2+d)*Math.sin(e);e/=2;for(var n=0,i=1/0;n<10&&Math.abs(i)>h;n++){var a=Math.cos(e);e-=i=(e+Math.sin(e)*(a+2)-r)/(2*a*(1+a))}return[2/Math.sqrt(p*(4+p))*t*(1+Math.cos(e)),2*Math.sqrt(p/(4+p))*Math.sin(e)]}t.geo.interrupt=function(e){var r,n=[[[[-p,0],[0,d],[p,0]]],[[[-p,0],[0,-d],[p,0]]]];function i(t,r){for(var i=r<0?-1:1,a=n[+(r<0)],o=0,s=a.length-1;o<s&&t>a[o][2][0];++o);var l=e(t-a[o][1][0],r);return l[0]+=e(a[o][1][0],i*r>i*a[o][0][1]?a[o][0][1]:r)[0],l}e.invert&&(i.invert=function(t,a){for(var o=r[+(a<0)],s=n[+(a<0)],c=0,u=o.length;c<u;++c){var h=o[c];if(h[0][0]<=t&&t<h[1][0]&&h[0][1]<=a&&a<h[1][1]){var f=e.invert(t-e(s[c][1][0],0)[0],a);return f[0]+=s[c][1][0],l(i(f[0],f[1]),[t,a])?f:null}}});var a=t.geo.projection(i),o=a.stream;function s(t,e){for(var r,n,i,a=-1,o=t.length,s=t[0],l=[];++a<o;){n=((r=t[a])[0]-s[0])/e,i=(r[1]-s[1])/e;for(var c=0;c<e;++c)l.push([s[0]+c*n,s[1]+c*i]);s=r}return l.push(r),l}function l(t,e){return Math.abs(t[0]-e[0])<h&&Math.abs(t[1]-e[1])<h}return a.stream=function(e){var r=a.rotate(),i=o(e),l=(a.rotate([0,0]),o(e));return a.rotate(r),i.sphere=function(){t.geo.stream(function(){for(var e=1e-6,r=[],i=0,a=n[0].length;i<a;++i){var o=n[0][i],l=180*o[0][0]/p,c=180*o[0][1]/p,u=180*o[1][1]/p,h=180*o[2][0]/p,f=180*o[2][1]/p;r.push(s([[l+e,c+e],[l+e,u-e],[h-e,u-e],[h-e,f+e]],30))}for(var i=n[1].length-1;i>=0;--i){var o=n[1][i],l=180*o[0][0]/p,c=180*o[0][1]/p,u=180*o[1][1]/p,h=180*o[2][0]/p,f=180*o[2][1]/p;r.push(s([[h-e,f-e],[h-e,u+e],[l+e,u+e],[l+e,c-e]],30))}return{type:\"Polygon\",coordinates:[t.merge(r)]}}(),l)},i},a.lobes=function(t){return arguments.length?(n=t.map(function(t){return t.map(function(t){return[[t[0][0]*p/180,t[0][1]*p/180],[t[1][0]*p/180,t[1][1]*p/180],[t[2][0]*p/180,t[2][1]*p/180]]})}),r=n.map(function(t){return t.map(function(t){var r,n=e(t[0][0],t[0][1])[0],i=e(t[2][0],t[2][1])[0],a=e(t[1][0],t[0][1])[1],o=e(t[1][0],t[1][1])[1];return a>o&&(r=a,a=o,o=r),[[n,a],[i,o]]})}),a):n.map(function(t){return t.map(function(t){return[[180*t[0][0]/p,180*t[0][1]/p],[180*t[1][0]/p,180*t[1][1]/p],[180*t[2][0]/p,180*t[2][1]/p]]})})},a},_.invert=function(t,e){var r=.5*e*Math.sqrt((4+p)/p),n=m(r),i=Math.cos(n);return[t/(2/Math.sqrt(p*(4+p))*(1+i)),m((n+r*(i+2))/(2+d))]},(t.geo.eckert4=function(){return x(_)}).raw=_;var w=t.geo.azimuthalEqualArea.raw;function k(t,e){if(arguments.length<2&&(e=t),1===e)return w;if(e===1/0)return T;function r(r,n){var i=w(r/e,n);return i[0]*=t,i}return r.invert=function(r,n){var i=w.invert(r/t,n);return i[0]*=e,i},r}function T(t,e){return[t*Math.cos(e)/Math.cos(e/=2),2*Math.sin(e)]}function A(t,e){return[3*t/(2*p)*Math.sqrt(p*p/3-e*e),e]}function M(t,e){return[t,1.25*Math.log(Math.tan(p/4+.4*e))]}function S(t){return function(e){var r,n=t*Math.sin(e),i=30;do{e-=r=(e+Math.sin(e)-n)/(1+Math.cos(e))}while(Math.abs(r)>h&&--i>0);return e/2}}T.invert=function(t,e){var r=2*m(e/2);return[t*Math.cos(r/2)/Math.cos(r),r]},(t.geo.hammer=function(){var t=2,e=b(k),r=e(t);return r.coefficient=function(r){return arguments.length?e(t=+r):t},r}).raw=k,A.invert=function(t,e){return[2/3*p*t/Math.sqrt(p*p/3-e*e),e]},(t.geo.kavrayskiy7=function(){return x(A)}).raw=A,M.invert=function(t,e){return[t,2.5*Math.atan(Math.exp(.8*e))-.625*p]},(t.geo.miller=function(){return x(M)}).raw=M,S(p);var E=function(t,e,r){var n=S(r);function i(r,i){return[t*r*Math.cos(i=n(i)),e*Math.sin(i)]}return i.invert=function(n,i){var a=m(i/e);return[n/(t*Math.cos(a)),m((2*a+Math.sin(2*a))/r)]},i}(Math.SQRT2/d,Math.SQRT2,p);function C(t,e){var r=e*e,n=r*r;return[t*(.8707-.131979*r+n*(n*(.003971*r-.001529*n)-.013791)),e*(1.007226+r*(.015085+n*(.028874*r-.044475-.005916*n)))]}(t.geo.mollweide=function(){return x(E)}).raw=E,C.invert=function(t,e){var r,n=e,i=25;do{var a=n*n,o=a*a;n-=r=(n*(1.007226+a*(.015085+o*(.028874*a-.044475-.005916*o)))-e)/(1.007226+a*(.045255+o*(.259866*a-.311325-.005916*11*o)))}while(Math.abs(r)>h&&--i>0);return[t/(.8707+(a=n*n)*(a*(a*a*a*(.003971-.001529*a)-.013791)-.131979)),n]},(t.geo.naturalEarth=function(){return x(C)}).raw=C;var L=[[.9986,-.062],[1,0],[.9986,.062],[.9954,.124],[.99,.186],[.9822,.248],[.973,.31],[.96,.372],[.9427,.434],[.9216,.4958],[.8962,.5571],[.8679,.6176],[.835,.6769],[.7986,.7346],[.7597,.7903],[.7186,.8435],[.6732,.8936],[.6213,.9394],[.5722,.9761],[.5322,1]];function P(t,e){var r,n=Math.min(18,36*Math.abs(e)/p),i=Math.floor(n),a=n-i,o=(r=L[i])[0],s=r[1],l=(r=L[++i])[0],c=r[1],u=(r=L[Math.min(19,++i)])[0],h=r[1];return[t*(l+a*(u-o)/2+a*a*(u-2*l+o)/2),(e>0?d:-d)*(c+a*(h-s)/2+a*a*(h-2*c+s)/2)]}function O(t,e){return[t*Math.cos(e),e]}function z(t,e){var r,n=Math.cos(e),i=(r=y(n*Math.cos(t/=2)))?r/Math.sin(r):1;return[2*n*Math.sin(t)*i,Math.sin(e)*i]}function I(t,e){var r=z(t,e);return[(r[0]+t/d)/2,(r[1]+e)/2]}L.forEach(function(t){t[1]*=1.0144}),P.invert=function(t,e){var r=e/d,n=90*r,i=Math.min(18,Math.abs(n/5)),a=Math.max(0,Math.floor(i));do{var o=L[a][1],s=L[a+1][1],l=L[Math.min(19,a+2)][1],c=l-o,u=l-2*s+o,h=2*(Math.abs(r)-s)/c,p=u/c,m=h*(1-p*h*(1-2*p*h));if(m>=0||1===a){n=(e>=0?5:-5)*(m+i);var y,x=50;do{m=(i=Math.min(18,Math.abs(n)/5))-(a=Math.floor(i)),o=L[a][1],s=L[a+1][1],l=L[Math.min(19,a+2)][1],n-=(y=(e>=0?d:-d)*(s+m*(l-o)/2+m*m*(l-2*s+o)/2)-e)*v}while(Math.abs(y)>f&&--x>0);break}}while(--a>=0);var b=L[a][0],_=L[a+1][0],w=L[Math.min(19,a+2)][0];return[t/(_+m*(w-b)/2+m*m*(w-2*_+b)/2),n*g]},(t.geo.robinson=function(){return x(P)}).raw=P,O.invert=function(t,e){return[t/Math.cos(e),e]},(t.geo.sinusoidal=function(){return x(O)}).raw=O,z.invert=function(t,e){if(!(t*t+4*e*e>p*p+h)){var r=t,n=e,i=25;do{var a,o=Math.sin(r),s=Math.sin(r/2),l=Math.cos(r/2),c=Math.sin(n),u=Math.cos(n),f=Math.sin(2*n),d=c*c,g=u*u,v=s*s,m=1-g*l*l,x=m?y(u*l)*Math.sqrt(a=1/m):a=0,b=2*x*u*s-t,_=x*c-e,w=a*(g*v+x*u*l*d),k=a*(.5*o*f-2*x*c*s),T=.25*a*(f*s-x*c*g*o),A=a*(d*l+x*v*u),M=k*T-A*w;if(!M)break;var S=(_*k-b*A)/M,E=(b*T-_*w)/M;r-=S,n-=E}while((Math.abs(S)>h||Math.abs(E)>h)&&--i>0);return[r,n]}},(t.geo.aitoff=function(){return x(z)}).raw=z,I.invert=function(t,e){var r=t,n=e,i=25;do{var a,o=Math.cos(n),s=Math.sin(n),l=Math.sin(2*n),c=s*s,u=o*o,f=Math.sin(r),p=Math.cos(r/2),g=Math.sin(r/2),v=g*g,m=1-u*p*p,x=m?y(o*p)*Math.sqrt(a=1/m):a=0,b=.5*(2*x*o*g+r/d)-t,_=.5*(x*s+n)-e,w=.5*a*(u*v+x*o*p*c)+.5/d,k=a*(f*l/4-x*s*g),T=.125*a*(l*g-x*s*u*f),A=.5*a*(c*p+x*v*o)+.5,M=k*T-A*w,S=(_*k-b*A)/M,E=(b*T-_*w)/M;r-=S,n-=E}while((Math.abs(S)>h||Math.abs(E)>h)&&--i>0);return[r,n]},(t.geo.winkel3=function(){return x(I)}).raw=I}},{}],801:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=Math.PI/180,s=180/Math.PI,l={cursor:\"pointer\"},c={cursor:\"auto\"};function u(t,e){return n.behavior.zoom().translate(e.translate()).scale(e.scale())}function h(t,e,r){var n=t.id,o=t.graphDiv,s=o.layout,l=s[n],c=o._fullLayout,u=c[n],h={},f={};function p(t,e){h[n+\".\"+t]=i.nestedProperty(l,t).get(),a.call(\"_storeDirectGUIEdit\",s,c._preGUI,h);var r=i.nestedProperty(u,t);r.get()!==e&&(r.set(e),i.nestedProperty(l,t).set(e),f[n+\".\"+t]=e)}r(p),p(\"projection.scale\",e.scale()/t.fitScale),o.emit(\"plotly_relayout\",f)}function f(t,e){var r=u(0,e);function i(r){var n=e.invert(t.midPt);r(\"center.lon\",n[0]),r(\"center.lat\",n[1])}return r.on(\"zoomstart\",function(){n.select(this).style(l)}).on(\"zoom\",function(){e.scale(n.event.scale).translate(n.event.translate),t.render();var r=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":r[0],\"geo.center.lat\":r[1]})}).on(\"zoomend\",function(){n.select(this).style(c),h(t,e,i)}),r}function p(t,e){var r,i,a,o,s,f,p,d,g,v=u(0,e),m=2;function y(t){return e.invert(t)}function x(r){var n=e.rotate(),i=e.invert(t.midPt);r(\"projection.rotation.lon\",-n[0]),r(\"center.lon\",i[0]),r(\"center.lat\",i[1])}return v.on(\"zoomstart\",function(){n.select(this).style(l),r=n.mouse(this),i=e.rotate(),a=e.translate(),o=i,s=y(r)}).on(\"zoom\",function(){if(f=n.mouse(this),function(t){var r=y(t);if(!r)return!0;var n=e(r);return Math.abs(n[0]-t[0])>m||Math.abs(n[1]-t[1])>m}(r))return v.scale(e.scale()),void v.translate(e.translate());e.scale(n.event.scale),e.translate([a[0],n.event.translate[1]]),s?y(f)&&(d=y(f),p=[o[0]+(d[0]-s[0]),i[1],i[2]],e.rotate(p),o=p):s=y(r=f),g=!0,t.render();var l=e.rotate(),c=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":c[0],\"geo.center.lat\":c[1],\"geo.projection.rotation.lon\":-l[0]})}).on(\"zoomend\",function(){n.select(this).style(c),g&&h(t,e,x)}),v}function d(t,e){var r,i={r:e.rotate(),k:e.scale()},a=u(0,e),f=function(t){var e=0,r=arguments.length,i=[];for(;++e<r;)i.push(arguments[e]);var a=n.dispatch.apply(null,i);return a.of=function(e,r){return function(i){var o;try{o=i.sourceEvent=n.event,i.target=t,n.event=i,a[i.type].apply(e,r)}finally{n.event=o}}},a}(a,\"zoomstart\",\"zoom\",\"zoomend\"),p=0,d=a.on;function m(t){var r=e.rotate();t(\"projection.rotation.lon\",-r[0]),t(\"projection.rotation.lat\",-r[1])}return a.on(\"zoomstart\",function(){n.select(this).style(l);var t,c,u,h,m,b,_,w,k,T,A,M=n.mouse(this),S=e.rotate(),E=S,C=e.translate(),L=(c=.5*(t=S)[0]*o,u=.5*t[1]*o,h=.5*t[2]*o,m=Math.sin(c),b=Math.cos(c),_=Math.sin(u),w=Math.cos(u),k=Math.sin(h),T=Math.cos(h),[b*w*T+m*_*k,m*w*T-b*_*k,b*_*T+m*w*k,b*w*k-m*_*T]);r=g(e,M),d.call(a,\"zoom\",function(){var t,a,o,l,c,u,h,p,d,m,b=n.mouse(this);if(e.scale(i.k=n.event.scale),r){if(g(e,b)){e.rotate(S).translate(C);var _=g(e,b),w=function(t,e){if(!t||!e)return;var r=function(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}(t,e),n=Math.sqrt(x(r,r)),i=.5*Math.acos(Math.max(-1,Math.min(1,x(t,e)))),a=Math.sin(i)/n;return n&&[Math.cos(i),r[2]*a,-r[1]*a,r[0]*a]}(r,_),k=function(t){return[Math.atan2(2*(t[0]*t[1]+t[2]*t[3]),1-2*(t[1]*t[1]+t[2]*t[2]))*s,Math.asin(Math.max(-1,Math.min(1,2*(t[0]*t[2]-t[3]*t[1]))))*s,Math.atan2(2*(t[0]*t[3]+t[1]*t[2]),1-2*(t[2]*t[2]+t[3]*t[3]))*s]}((a=w,o=(t=L)[0],l=t[1],c=t[2],u=t[3],h=a[0],p=a[1],d=a[2],m=a[3],[o*h-l*p-c*d-u*m,o*p+l*h+c*m-u*d,o*d-l*m+c*h+u*p,o*m+l*d-c*p+u*h])),T=i.r=function(t,e,r){var n=y(e,2,t[0]);n=y(n,1,t[1]),n=y(n,0,t[2]-r[2]);var i,a,o=e[0],l=e[1],c=e[2],u=n[0],h=n[1],f=n[2],p=Math.atan2(l,o)*s,d=Math.sqrt(o*o+l*l);Math.abs(h)>d?(a=(h>0?90:-90)-p,i=0):(a=Math.asin(h/d)*s-p,i=Math.sqrt(d*d-h*h));var g=180-a-2*p,m=(Math.atan2(f,u)-Math.atan2(c,i))*s,x=(Math.atan2(f,u)-Math.atan2(c,-i))*s,b=v(r[0],r[1],a,m),_=v(r[0],r[1],g,x);return b<=_?[a,m,r[2]]:[g,x,r[2]]}(k,r,E);isFinite(T[0])&&isFinite(T[1])&&isFinite(T[2])||(T=E),e.rotate(T),E=T}}else r=g(e,M=b);f.of(this,arguments)({type:\"zoom\"})}),A=f.of(this,arguments),p++||A({type:\"zoomstart\"})}).on(\"zoomend\",function(){var r;n.select(this).style(c),d.call(a,\"zoom\",null),r=f.of(this,arguments),--p||r({type:\"zoomend\"}),h(t,e,m)}).on(\"zoom.redraw\",function(){t.render();var r=e.rotate();t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.projection.rotation.lon\":-r[0],\"geo.projection.rotation.lat\":-r[1]})}),n.rebind(a,f,\"on\")}function g(t,e){var r=t.invert(e);return r&&isFinite(r[0])&&isFinite(r[1])&&function(t){var e=t[0]*o,r=t[1]*o,n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}(r)}function v(t,e,r,n){var i=m(r-t),a=m(n-e);return Math.sqrt(i*i+a*a)}function m(t){return(t%360+540)%360-180}function y(t,e,r){var n=r*o,i=t.slice(),a=0===e?1:0,s=2===e?1:2,l=Math.cos(n),c=Math.sin(n);return i[a]=t[a]*l-t[s]*c,i[s]=t[s]*l+t[a]*c,i}function x(t,e){for(var r=0,n=0,i=t.length;n<i;++n)r+=t[n]*e[n];return r}e.exports=function(t,e){var r=t.projection;return(e._isScoped?f:e._isClipped?d:p)(t,r)}},{\"../../lib\":719,\"../../registry\":847,d3:163}],802:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"./cartesian/constants\").SUBPLOT_PATTERN;r.getSubplotCalcData=function(t,e,r){var i=n.subplotsRegistry[e];if(!i)return[];for(var a=i.attr,o=[],s=0;s<t.length;s++){var l=t[s];l[0].trace[a]===r&&o.push(l)}return o},r.getModuleCalcData=function(t,e){var r,i=[],a=[];if(!(r=\"string\"==typeof e?n.getModule(e).plot:\"function\"==typeof e?e:e.plot))return[i,t];for(var o=0;o<t.length;o++){var s=t[o],l=s[0].trace;!0===l.visible&&0!==l._length&&(l._module.plot===r?i.push(s):a.push(s))}return[i,a]},r.getSubplotData=function(t,e,r){if(!n.subplotsRegistry[e])return[];var a,o,s,l=n.subplotsRegistry[e].attr,c=[];if(\"gl2d\"===e){var u=r.match(i);o=\"x\"+u[1],s=\"y\"+u[2]}for(var h=0;h<t.length;h++)a=t[h],\"gl2d\"===e&&n.traceIs(a,\"gl2d\")?a[l[0]]===o&&a[l[1]]===s&&c.push(a):a[l]===r&&c.push(a);return c}},{\"../registry\":847,\"./cartesian/constants\":773}],803:[function(t,e,r){\"use strict\";var n=t(\"mouse-change\"),i=t(\"mouse-wheel\"),a=t(\"mouse-event-offset\"),o=t(\"../cartesian/constants\"),s=t(\"has-passive-events\");function l(t,e){this.element=t,this.plot=e,this.mouseListener=null,this.wheelListener=null,this.lastInputTime=Date.now(),this.lastPos=[0,0],this.boxEnabled=!1,this.boxInited=!1,this.boxStart=[0,0],this.boxEnd=[0,0],this.dragStart=[0,0]}e.exports=function(t){var e=t.mouseContainer,r=t.glplot,c=new l(e,r);function u(){t.xaxis.autorange=!1,t.yaxis.autorange=!1}function h(e,n,i){var a,s,l=t.calcDataBox(),h=r.viewBox,f=c.lastPos[0],p=c.lastPos[1],d=o.MINDRAG*r.pixelRatio,g=o.MINZOOM*r.pixelRatio;function v(e,r,n){var i=Math.min(r,n),a=Math.max(r,n);i!==a?(l[e]=i,l[e+2]=a,c.dataBox=l,t.setRanges(l)):(t.selectBox.selectBox=[0,0,1,1],t.glplot.setDirty())}switch(n*=r.pixelRatio,i*=r.pixelRatio,i=h[3]-h[1]-i,t.fullLayout.dragmode){case\"zoom\":if(e){var m=n/(h[2]-h[0])*(l[2]-l[0])+l[0],y=i/(h[3]-h[1])*(l[3]-l[1])+l[1];c.boxInited||(c.boxStart[0]=m,c.boxStart[1]=y,c.dragStart[0]=n,c.dragStart[1]=i),c.boxEnd[0]=m,c.boxEnd[1]=y,c.boxInited=!0,c.boxEnabled||c.boxStart[0]===c.boxEnd[0]&&c.boxStart[1]===c.boxEnd[1]||(c.boxEnabled=!0);var x=Math.abs(c.dragStart[0]-n)<g,b=Math.abs(c.dragStart[1]-i)<g;if(!function(){for(var e=t.graphDiv._fullLayout._axisConstraintGroups,r=t.xaxis._id,n=t.yaxis._id,i=0;i<e.length;i++)if(-1!==e[i][r]){if(-1!==e[i][n])return!0;break}return!1}()||x&&b)x&&(c.boxEnd[0]=c.boxStart[0]),b&&(c.boxEnd[1]=c.boxStart[1]);else{a=c.boxEnd[0]-c.boxStart[0],s=c.boxEnd[1]-c.boxStart[1];var _=(l[3]-l[1])/(l[2]-l[0]);Math.abs(a*_)>Math.abs(s)?(c.boxEnd[1]=c.boxStart[1]+Math.abs(a)*_*(s>=0?1:-1),c.boxEnd[1]<l[1]?(c.boxEnd[1]=l[1],c.boxEnd[0]=c.boxStart[0]+(l[1]-c.boxStart[1])/Math.abs(_)):c.boxEnd[1]>l[3]&&(c.boxEnd[1]=l[3],c.boxEnd[0]=c.boxStart[0]+(l[3]-c.boxStart[1])/Math.abs(_))):(c.boxEnd[0]=c.boxStart[0]+Math.abs(s)/_*(a>=0?1:-1),c.boxEnd[0]<l[0]?(c.boxEnd[0]=l[0],c.boxEnd[1]=c.boxStart[1]+(l[0]-c.boxStart[0])*Math.abs(_)):c.boxEnd[0]>l[2]&&(c.boxEnd[0]=l[2],c.boxEnd[1]=c.boxStart[1]+(l[2]-c.boxStart[0])*Math.abs(_)))}}else c.boxEnabled?(a=c.boxStart[0]!==c.boxEnd[0],s=c.boxStart[1]!==c.boxEnd[1],a||s?(a&&(v(0,c.boxStart[0],c.boxEnd[0]),t.xaxis.autorange=!1),s&&(v(1,c.boxStart[1],c.boxEnd[1]),t.yaxis.autorange=!1),t.relayoutCallback()):t.glplot.setDirty(),c.boxEnabled=!1,c.boxInited=!1):c.boxInited&&(c.boxInited=!1);break;case\"pan\":c.boxEnabled=!1,c.boxInited=!1,e?(c.panning||(c.dragStart[0]=n,c.dragStart[1]=i),Math.abs(c.dragStart[0]-n)<d&&(n=c.dragStart[0]),Math.abs(c.dragStart[1]-i)<d&&(i=c.dragStart[1]),a=(f-n)*(l[2]-l[0])/(r.viewBox[2]-r.viewBox[0]),s=(p-i)*(l[3]-l[1])/(r.viewBox[3]-r.viewBox[1]),l[0]+=a,l[2]+=a,l[1]+=s,l[3]+=s,t.setRanges(l),c.panning=!0,c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations()):c.panning&&(c.panning=!1,t.relayoutCallback())}c.lastPos[0]=n,c.lastPos[1]=i}return c.mouseListener=n(e,h),e.addEventListener(\"touchstart\",function(t){var r=a(t.changedTouches[0],e);h(0,r[0],r[1]),h(1,r[0],r[1]),t.preventDefault()},!!s&&{passive:!1}),e.addEventListener(\"touchmove\",function(t){t.preventDefault();var r=a(t.changedTouches[0],e);h(1,r[0],r[1]),t.preventDefault()},!!s&&{passive:!1}),e.addEventListener(\"touchend\",function(t){h(0,c.lastPos[0],c.lastPos[1]),t.preventDefault()},!!s&&{passive:!1}),c.wheelListener=i(e,function(e,n){if(!t.scrollZoom)return!1;var i=t.calcDataBox(),a=r.viewBox,o=c.lastPos[0],s=c.lastPos[1],l=Math.exp(5*n/(a[3]-a[1])),h=o/(a[2]-a[0])*(i[2]-i[0])+i[0],f=s/(a[3]-a[1])*(i[3]-i[1])+i[1];return i[0]=(i[0]-h)*l+h,i[2]=(i[2]-h)*l+h,i[1]=(i[1]-f)*l+f,i[3]=(i[3]-f)*l+f,t.setRanges(i),c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations(),t.relayoutCallback(),!0},!0),c}},{\"../cartesian/constants\":773,\"has-passive-events\":411,\"mouse-change\":435,\"mouse-event-offset\":436,\"mouse-wheel\":438}],804:[function(t,e,r){\"use strict\";var n=t(\"../cartesian/axes\"),i=t(\"../../lib/str2rgbarray\");function a(t){this.scene=t,this.gl=t.gl,this.pixelRatio=t.pixelRatio,this.screenBox=[0,0,1,1],this.viewBox=[0,0,1,1],this.dataBox=[-1,-1,1,1],this.borderLineEnable=[!1,!1,!1,!1],this.borderLineWidth=[1,1,1,1],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.ticks=[[],[]],this.tickEnable=[!0,!0,!1,!1],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labels=[\"x\",\"y\"],this.labelEnable=[!0,!0,!1,!1],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelPad=[15,15,15,15],this.labelSize=[12,12],this.labelFont=[\"sans-serif\",\"sans-serif\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.title=\"\",this.titleEnable=!0,this.titleCenter=[0,0,0,0],this.titleAngle=0,this.titleColor=[0,0,0,1],this.titleFont=\"sans-serif\",this.titleSize=18,this.gridLineEnable=[!0,!0],this.gridLineColor=[[0,0,0,.5],[0,0,0,.5]],this.gridLineWidth=[1,1],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[1,1],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.static=this.scene.staticPlot}var o=a.prototype,s=[\"xaxis\",\"yaxis\"];o.merge=function(t){var e,r,n,a,o,l,c,u,h,f,p;for(this.titleEnable=!1,this.backgroundColor=i(t.plot_bgcolor),f=0;f<2;++f){var d=(e=s[f]).charAt(0);for(n=(r=t[this.scene[e]._name]).title.text===this.scene.fullLayout._dfltTitle[d]?\"\":r.title.text,p=0;p<=2;p+=2)this.labelEnable[f+p]=!1,this.labels[f+p]=n,this.labelColor[f+p]=i(r.title.font.color),this.labelFont[f+p]=r.title.font.family,this.labelSize[f+p]=r.title.font.size,this.labelPad[f+p]=this.getLabelPad(e,r),this.tickEnable[f+p]=!1,this.tickColor[f+p]=i((r.tickfont||{}).color),this.tickAngle[f+p]=\"auto\"===r.tickangle?0:Math.PI*-r.tickangle/180,this.tickPad[f+p]=this.getTickPad(r),this.tickMarkLength[f+p]=0,this.tickMarkWidth[f+p]=r.tickwidth||0,this.tickMarkColor[f+p]=i(r.tickcolor),this.borderLineEnable[f+p]=!1,this.borderLineColor[f+p]=i(r.linecolor),this.borderLineWidth[f+p]=r.linewidth||0;c=this.hasSharedAxis(r),o=this.hasAxisInDfltPos(e,r)&&!c,l=this.hasAxisInAltrPos(e,r)&&!c,a=r.mirror||!1,u=c?-1!==String(a).indexOf(\"all\"):!!a,h=c?\"allticks\"===a:-1!==String(a).indexOf(\"ticks\"),o?this.labelEnable[f]=!0:l&&(this.labelEnable[f+2]=!0),o?this.tickEnable[f]=r.showticklabels:l&&(this.tickEnable[f+2]=r.showticklabels),(o||u)&&(this.borderLineEnable[f]=r.showline),(l||u)&&(this.borderLineEnable[f+2]=r.showline),(o||h)&&(this.tickMarkLength[f]=this.getTickMarkLength(r)),(l||h)&&(this.tickMarkLength[f+2]=this.getTickMarkLength(r)),this.gridLineEnable[f]=r.showgrid,this.gridLineColor[f]=i(r.gridcolor),this.gridLineWidth[f]=r.gridwidth,this.zeroLineEnable[f]=r.zeroline,this.zeroLineColor[f]=i(r.zerolinecolor),this.zeroLineWidth[f]=r.zerolinewidth}},o.hasSharedAxis=function(t){var e=this.scene,r=e.fullLayout._subplots.gl2d;return 0!==n.findSubplotsWithAxis(r,t).indexOf(e.id)},o.hasAxisInDfltPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"bottom\"===r:\"yaxis\"===t?\"left\"===r:void 0},o.hasAxisInAltrPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"top\"===r:\"yaxis\"===t?\"right\"===r:void 0},o.getLabelPad=function(t,e){var r=e.title.font.size,n=e.showticklabels;return\"xaxis\"===t?\"top\"===e.side?r*(1.5+(n?1:0))-10:r*(1.5+(n?.5:0))-10:\"yaxis\"===t?\"right\"===e.side?10+r*(1.5+(n?1:.5)):10+r*(1.5+(n?.5:0)):void 0},o.getTickPad=function(t){return\"outside\"===t.ticks?10+t.ticklen:15},o.getTickMarkLength=function(t){if(!t.ticks)return 0;var e=t.ticklen;return\"inside\"===t.ticks?-e:e},e.exports=function(t){return new a(t)}},{\"../../lib/str2rgbarray\":742,\"../cartesian/axes\":767}],805:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"./scene2d\"),a=t(\"../layout_attributes\"),o=t(\"../../constants/xmlns_namespaces\"),s=t(\"../cartesian/constants\"),l=t(\"../cartesian\"),c=t(\"../../components/fx/layout_attributes\"),u=t(\"../get_data\").getSubplotData;r.name=\"gl2d\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=s.idRegex,r.attrRegex=s.attrRegex,r.attributes=t(\"../cartesian/attributes\"),r.supplyLayoutDefaults=function(t,e,r){e._has(\"cartesian\")||l.supplyLayoutDefaults(t,e,r)},r.layoutAttrOverrides=n(l.layoutAttributes,\"plot\",\"from-root\"),r.baseLayoutAttrOverrides=n({plot_bgcolor:a.plot_bgcolor,hoverlabel:c.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl2d,a=0;a<n.length;a++){var o=n[a],s=e._plots[o],l=u(r,\"gl2d\",o),c=s._scene2d;void 0===c&&(c=new i({id:o,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio},e),s._scene2d=c),c.plot(l,t.calcdata,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl2d||[],a=0;a<i.length;a++){var o=i[a],s=n._plots[o];if(s._scene2d)0===u(t,\"gl2d\",o).length&&(s._scene2d.destroy(),delete n._plots[o])}l.clean.apply(this,arguments)},r.drawFramework=function(t){t._context.staticPlot||l.drawFramework(t)},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){var i=e._plots[r[n]]._scene2d,a=i.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":a,x:0,y:0,width:\"100%\",height:\"100%\",preserveAspectRatio:\"none\"}),i.destroy()}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){e._plots[r[n]]._scene2d.updateFx(e.dragmode)}}},{\"../../components/fx/layout_attributes\":633,\"../../constants/xmlns_namespaces\":696,\"../../plot_api/edit_types\":750,\"../cartesian\":778,\"../cartesian/attributes\":765,\"../cartesian/constants\":773,\"../get_data\":802,\"../layout_attributes\":819,\"./scene2d\":806}],806:[function(t,e,r){\"use strict\";var n,i,a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../../components/fx\"),l=t(\"gl-plot2d\"),c=t(\"gl-spikes2d\"),u=t(\"gl-select-box\"),h=t(\"webgl-context\"),f=t(\"./convert\"),p=t(\"./camera\"),d=t(\"../../lib/show_no_webgl_msg\"),g=t(\"../cartesian/constraints\"),v=g.enforce,m=g.clean,y=t(\"../cartesian/autorange\").doAutoRange,x=[\"xaxis\",\"yaxis\"],b=t(\"../cartesian/constants\").SUBPLOT_PATTERN;function _(t,e){this.container=t.container,this.graphDiv=t.graphDiv,this.pixelRatio=t.plotGlPixelRatio||window.devicePixelRatio,this.id=t.id,this.staticPlot=!!t.staticPlot,this.scrollZoom=this.graphDiv._context._scrollZoom.cartesian,this.fullData=null,this.updateRefs(e),this.makeFramework(),this.stopped||(this.glplotOptions=f(this),this.glplotOptions.merge(e),this.glplot=l(this.glplotOptions),this.camera=p(this),this.traces={},this.spikes=c(this.glplot),this.selectBox=u(this.glplot,{innerFill:!1,outerFill:!0}),this.lastButtonState=0,this.pickResult=null,this.isMouseOver=!0,this.stopped=!1,this.redraw=this.draw.bind(this),this.redraw())}e.exports=_;var w=_.prototype;w.makeFramework=function(){if(this.staticPlot){if(!(i||(n=document.createElement(\"canvas\"),i=h({canvas:n,preserveDrawingBuffer:!1,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"Error creating static canvas/context for image server\");this.canvas=n,this.gl=i}else{var t=this.container.querySelector(\".gl-canvas-focus\"),e=h({canvas:t,preserveDrawingBuffer:!0,premultipliedAlpha:!0});if(!e)return d(this),void(this.stopped=!0);this.canvas=t,this.gl=e}var r=this.canvas;r.style.width=\"100%\",r.style.height=\"100%\",r.style.position=\"absolute\",r.style.top=\"0px\",r.style.left=\"0px\",r.style[\"pointer-events\"]=\"none\",this.updateSize(r),r.className+=\" user-select-none\";var a=this.svgContainer=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");a.style.position=\"absolute\",a.style.top=a.style.left=\"0px\",a.style.width=a.style.height=\"100%\",a.style[\"z-index\"]=20,a.style[\"pointer-events\"]=\"none\";var o=this.mouseContainer=document.createElement(\"div\");o.style.position=\"absolute\",o.style[\"pointer-events\"]=\"auto\",this.pickCanvas=this.container.querySelector(\".gl-canvas-pick\");var s=this.container;s.appendChild(a),s.appendChild(o);var l=this;o.addEventListener(\"mouseout\",function(){l.isMouseOver=!1,l.unhover()}),o.addEventListener(\"mouseover\",function(){l.isMouseOver=!0})},w.toImage=function(t){t||(t=\"png\"),this.stopped=!0,this.staticPlot&&this.container.appendChild(n),this.updateSize(this.canvas);var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.clearColor(1,1,1,0),e.clear(e.COLOR_BUFFER_BIT|e.DEPTH_BUFFER_BIT),this.glplot.setDirty(),this.glplot.draw(),e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a);for(var o=0,s=i-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=a[4*(r*o+l)+c];a[4*(r*o+l)+c]=a[4*(r*s+l)+c],a[4*(r*s+l)+c]=u}var h=document.createElement(\"canvas\");h.width=r,h.height=i;var f,p=h.getContext(\"2d\"),d=p.createImageData(r,i);switch(d.data.set(a),p.putImageData(d,0,0),t){case\"jpeg\":f=h.toDataURL(\"image/jpeg\");break;case\"webp\":f=h.toDataURL(\"image/webp\");break;default:f=h.toDataURL(\"image/png\")}return this.staticPlot&&this.container.removeChild(n),f},w.updateSize=function(t){t||(t=this.canvas);var e=this.pixelRatio,r=this.fullLayout,n=r.width,i=r.height,a=0|Math.ceil(e*n),o=0|Math.ceil(e*i);return t.width===a&&t.height===o||(t.width=a,t.height=o),t},w.computeTickMarks=function(){this.xaxis.setScale(),this.yaxis.setScale();for(var t=[o.calcTicks(this.xaxis),o.calcTicks(this.yaxis)],e=0;e<2;++e)for(var r=0;r<t[e].length;++r)t[e][r].text=t[e][r].text+\"\";return t},w.updateRefs=function(t){this.fullLayout=t;var e=this.id.match(b),r=\"xaxis\"+e[1],n=\"yaxis\"+e[2];this.xaxis=this.fullLayout[r],this.yaxis=this.fullLayout[n]},w.relayoutCallback=function(){var t=this.graphDiv,e=this.xaxis,r=this.yaxis,n=t.layout,i={},o=i[e._name+\".range\"]=e.range.slice(),s=i[r._name+\".range\"]=r.range.slice();i[e._name+\".autorange\"]=e.autorange,i[r._name+\".autorange\"]=r.autorange,a.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,i);var l=n[e._name];l.range=o,l.autorange=e.autorange;var c=n[r._name];c.range=s,c.autorange=r.autorange,i.lastInputTime=this.camera.lastInputTime,t.emit(\"plotly_relayout\",i)},w.cameraChanged=function(){var t=this.camera;this.glplot.setDataBox(this.calcDataBox());var e=this.computeTickMarks();(function(t,e){for(var r=0;r<2;++r){var n=t[r],i=e[r];if(n.length!==i.length)return!0;for(var a=0;a<n.length;++a)if(n[a].x!==i[a].x)return!0}return!1})(e,this.glplotOptions.ticks)&&(this.glplotOptions.ticks=e,this.glplotOptions.dataBox=t.dataBox,this.glplot.update(this.glplotOptions),this.handleAnnotations())},w.handleAnnotations=function(){for(var t=this.graphDiv,e=this.fullLayout.annotations,r=0;r<e.length;r++){var n=e[r];n.xref===this.xaxis._id&&n.yref===this.yaxis._id&&a.getComponentMethod(\"annotations\",\"drawOne\")(t,r)}},w.destroy=function(){if(this.glplot){var t=this.traces;t&&Object.keys(t).map(function(e){t[e].dispose(),delete t[e]}),this.glplot.dispose(),this.container.removeChild(this.svgContainer),this.container.removeChild(this.mouseContainer),this.fullData=null,this.glplot=null,this.stopped=!0,this.camera.mouseListener.enabled=!1,this.mouseContainer.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=null}},w.plot=function(t,e,r){var n=this.glplot;this.updateRefs(r),this.xaxis.clearCalc(),this.yaxis.clearCalc(),this.updateTraces(t,e),this.updateFx(r.dragmode);var i=r.width,a=r.height;this.updateSize(this.canvas);var o=this.glplotOptions;o.merge(r),o.screenBox=[0,0,i,a];var s={_fullLayout:{_axisConstraintGroups:this.graphDiv._fullLayout._axisConstraintGroups,xaxis:this.xaxis,yaxis:this.yaxis}};m(s,this.xaxis),m(s,this.yaxis);var l,c,u=r._size,h=this.xaxis.domain,f=this.yaxis.domain;for(o.viewBox=[u.l+h[0]*u.w,u.b+f[0]*u.h,i-u.r-(1-h[1])*u.w,a-u.t-(1-f[1])*u.h],this.mouseContainer.style.width=u.w*(h[1]-h[0])+\"px\",this.mouseContainer.style.height=u.h*(f[1]-f[0])+\"px\",this.mouseContainer.height=u.h*(f[1]-f[0]),this.mouseContainer.style.left=u.l+h[0]*u.w+\"px\",this.mouseContainer.style.top=u.t+(1-f[1])*u.h+\"px\",c=0;c<2;++c)(l=this[x[c]])._length=o.viewBox[c+2]-o.viewBox[c],y(this.graphDiv,l),l.setScale();v(s),o.ticks=this.computeTickMarks(),o.dataBox=this.calcDataBox(),o.merge(r),n.update(o),this.glplot.draw()},w.calcDataBox=function(){var t=this.xaxis,e=this.yaxis,r=t.range,n=e.range,i=t.r2l,a=e.r2l;return[i(r[0]),a(n[0]),i(r[1]),a(n[1])]},w.setRanges=function(t){var e=this.xaxis,r=this.yaxis,n=e.l2r,i=r.l2r;e.range=[n(t[0]),n(t[2])],r.range=[i(t[1]),i(t[3])]},w.updateTraces=function(t,e){var r,n,i,a=Object.keys(this.traces);this.fullData=t;t:for(r=0;r<a.length;r++){var o=a[r],s=this.traces[o];for(n=0;n<t.length;n++)if((i=t[n]).uid===o&&i.type===s.type)continue t;s.dispose(),delete this.traces[o]}for(r=0;r<t.length;r++){i=t[r];var l=e[r],c=this.traces[i.uid];c?c.update(i,l):(c=i._module.plot(this,i,l),this.traces[i.uid]=c)}this.glplot.objects.sort(function(t,e){return t._trace.index-e._trace.index})},w.updateFx=function(t){\"lasso\"===t||\"select\"===t?(this.pickCanvas.style[\"pointer-events\"]=\"none\",this.mouseContainer.style[\"pointer-events\"]=\"none\"):(this.pickCanvas.style[\"pointer-events\"]=\"auto\",this.mouseContainer.style[\"pointer-events\"]=\"auto\"),this.mouseContainer.style.cursor=\"pan\"===t?\"move\":\"zoom\"===t?\"crosshair\":null},w.emitPointAction=function(t,e){for(var r,n=t.trace.uid,i=t.pointIndex,a=0;a<this.fullData.length;a++)this.fullData[a].uid===n&&(r=this.fullData[a]);var o={x:t.traceCoord[0],y:t.traceCoord[1],curveNumber:r.index,pointNumber:i,data:r._input,fullData:this.fullData,xaxis:this.xaxis,yaxis:this.yaxis};s.appendArrayPointValue(o,r,i),this.graphDiv.emit(e,{points:[o]})},w.draw=function(){if(!this.stopped){requestAnimationFrame(this.redraw);var t=this.glplot,e=this.camera,r=e.mouseListener,n=1===this.lastButtonState&&0===r.buttons,i=this.fullLayout;this.lastButtonState=r.buttons,this.cameraChanged();var a,o=r.x*t.pixelRatio,l=this.canvas.height-t.pixelRatio*r.y;if(e.boxEnabled&&\"zoom\"===i.dragmode){this.selectBox.enabled=!0;for(var c=this.selectBox.selectBox=[Math.min(e.boxStart[0],e.boxEnd[0]),Math.min(e.boxStart[1],e.boxEnd[1]),Math.max(e.boxStart[0],e.boxEnd[0]),Math.max(e.boxStart[1],e.boxEnd[1])],u=0;u<2;u++)e.boxStart[u]===e.boxEnd[u]&&(c[u]=t.dataBox[u],c[u+2]=t.dataBox[u+2]);t.setDirty()}else if(!e.panning&&this.isMouseOver){this.selectBox.enabled=!1;var h=i._size,f=this.xaxis.domain,p=this.yaxis.domain,d=(a=t.pick(o/t.pixelRatio+h.l+f[0]*h.w,l/t.pixelRatio-(h.t+(1-p[1])*h.h)))&&a.object._trace.handlePick(a);if(d&&n&&this.emitPointAction(d,\"plotly_click\"),a&&\"skip\"!==a.object._trace.hoverinfo&&i.hovermode&&d&&(!this.lastPickResult||this.lastPickResult.traceUid!==d.trace.uid||this.lastPickResult.dataCoord[0]!==d.dataCoord[0]||this.lastPickResult.dataCoord[1]!==d.dataCoord[1])){var g=d;this.lastPickResult={traceUid:d.trace?d.trace.uid:null,dataCoord:d.dataCoord.slice()},this.spikes.update({center:a.dataCoord}),g.screenCoord=[((t.viewBox[2]-t.viewBox[0])*(a.dataCoord[0]-t.dataBox[0])/(t.dataBox[2]-t.dataBox[0])+t.viewBox[0])/t.pixelRatio,(this.canvas.height-(t.viewBox[3]-t.viewBox[1])*(a.dataCoord[1]-t.dataBox[1])/(t.dataBox[3]-t.dataBox[1])-t.viewBox[1])/t.pixelRatio],this.emitPointAction(d,\"plotly_hover\");var v=this.fullData[g.trace.index]||{},m=g.pointIndex,y=s.castHoverinfo(v,i,m);if(y&&\"all\"!==y){var x=y.split(\"+\");-1===x.indexOf(\"x\")&&(g.traceCoord[0]=void 0),-1===x.indexOf(\"y\")&&(g.traceCoord[1]=void 0),-1===x.indexOf(\"z\")&&(g.traceCoord[2]=void 0),-1===x.indexOf(\"text\")&&(g.textLabel=void 0),-1===x.indexOf(\"name\")&&(g.name=void 0)}s.loneHover({x:g.screenCoord[0],y:g.screenCoord[1],xLabel:this.hoverFormatter(\"xaxis\",g.traceCoord[0]),yLabel:this.hoverFormatter(\"yaxis\",g.traceCoord[1]),zLabel:g.traceCoord[2],text:g.textLabel,name:g.name,color:s.castHoverOption(v,m,\"bgcolor\")||g.color,borderColor:s.castHoverOption(v,m,\"bordercolor\"),fontFamily:s.castHoverOption(v,m,\"font.family\"),fontSize:s.castHoverOption(v,m,\"font.size\"),fontColor:s.castHoverOption(v,m,\"font.color\"),nameLength:s.castHoverOption(v,m,\"namelength\"),textAlign:s.castHoverOption(v,m,\"align\")},{container:this.svgContainer,gd:this.graphDiv})}}a||this.unhover(),t.draw()}},w.unhover=function(){this.lastPickResult&&(this.spikes.update({}),this.lastPickResult=null,this.graphDiv.emit(\"plotly_unhover\"),s.loneUnhover(this.svgContainer))},w.hoverFormatter=function(t,e){if(void 0!==e){var r=this[t];return o.tickText(r,r.c2l(e),\"hover\").text}}},{\"../../components/fx\":632,\"../../lib/show_no_webgl_msg\":740,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../cartesian/autorange\":766,\"../cartesian/constants\":773,\"../cartesian/constraints\":774,\"./camera\":803,\"./convert\":804,\"gl-plot2d\":287,\"gl-select-box\":299,\"gl-spikes2d\":308,\"webgl-context\":556}],807:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../components/fx/layout_attributes\"),a=t(\"./scene\"),o=t(\"../get_data\").getSubplotData,s=t(\"../../lib\"),l=t(\"../../constants/xmlns_namespaces\");r.name=\"gl3d\",r.attr=\"scene\",r.idRoot=\"scene\",r.idRegex=r.attrRegex=s.counterRegex(\"scene\"),r.attributes=t(\"./layout/attributes\"),r.layoutAttributes=t(\"./layout/layout_attributes\"),r.baseLayoutAttrOverrides=n({hoverlabel:i.hoverlabel},\"plot\",\"nested\"),r.supplyLayoutDefaults=t(\"./layout/defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl3d,i=0;i<n.length;i++){var s=n[i],l=o(r,\"gl3d\",s),c=e[s],u=c.camera,h=c._scene;h||(h=new a({id:s,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio,camera:u},e),c._scene=h),h.viewInitial||(h.viewInitial={up:{x:u.up.x,y:u.up.y,z:u.up.z},eye:{x:u.eye.x,y:u.eye.y,z:u.eye.z},center:{x:u.center.x,y:u.center.y,z:u.center.z}}),h.plot(l,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl3d||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._scene&&(n[o]._scene.destroy(),n._infolayer&&n._infolayer.selectAll(\".annotation-\"+o).remove())}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=e._size,i=0;i<r.length;i++){var a=e[r[i]],o=a.domain,s=a._scene,c=s.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:l.svg,\"xlink:href\":c,x:n.l+n.w*o.x[0],y:n.t+n.h*(1-o.y[1]),width:n.w*(o.x[1]-o.x[0]),height:n.h*(o.y[1]-o.y[0]),preserveAspectRatio:\"none\"}),s.destroy()}},r.cleanId=function(t){if(t.match(/^scene[0-9]*$/)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),\"scene\"+e}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){e[r[n]]._scene.updateFx(e.dragmode,e.hovermode)}}},{\"../../components/fx/layout_attributes\":633,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../plot_api/edit_types\":750,\"../get_data\":802,\"./layout/attributes\":808,\"./layout/defaults\":812,\"./layout/layout_attributes\":813,\"./scene\":817}],808:[function(t,e,r){\"use strict\";e.exports={scene:{valType:\"subplotid\",dflt:\"scene\",editType:\"calc+clearAxisTypes\"}}},{}],809:[function(t,e,r){\"use strict\";var n=t(\"../../../components/color\"),i=t(\"../../cartesian/layout_attributes\"),a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../plot_api/edit_types\").overrideAll;e.exports=o({visible:i.visible,showspikes:{valType:\"boolean\",dflt:!0},spikesides:{valType:\"boolean\",dflt:!0},spikethickness:{valType:\"number\",min:0,dflt:2},spikecolor:{valType:\"color\",dflt:n.defaultLine},showbackground:{valType:\"boolean\",dflt:!1},backgroundcolor:{valType:\"color\",dflt:\"rgba(204, 204, 204, 0.5)\"},showaxeslabels:{valType:\"boolean\",dflt:!0},color:i.color,categoryorder:i.categoryorder,categoryarray:i.categoryarray,title:i.title,type:a({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autorange:i.autorange,rangemode:i.rangemode,range:a({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],anim:!1}),tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,mirror:i.mirror,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,tickfont:i.tickfont,tickangle:i.tickangle,tickprefix:i.tickprefix,showtickprefix:i.showtickprefix,ticksuffix:i.ticksuffix,showticksuffix:i.showticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,separatethousands:i.separatethousands,tickformat:i.tickformat,tickformatstops:i.tickformatstops,hoverformat:i.hoverformat,showline:i.showline,linecolor:i.linecolor,linewidth:i.linewidth,showgrid:i.showgrid,gridcolor:a({},i.gridcolor,{dflt:\"rgb(204, 204, 204)\"}),gridwidth:i.gridwidth,zeroline:i.zeroline,zerolinecolor:i.zerolinecolor,zerolinewidth:i.zerolinewidth,_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}},\"plot\",\"from-root\")},{\"../../../components/color\":593,\"../../../lib/extend\":710,\"../../../plot_api/edit_types\":750,\"../../cartesian/layout_attributes\":779}],810:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../../lib\"),a=t(\"../../../plot_api/plot_template\"),o=t(\"./axis_attributes\"),s=t(\"../../cartesian/type_defaults\"),l=t(\"../../cartesian/axis_defaults\"),c=[\"xaxis\",\"yaxis\",\"zaxis\"];e.exports=function(t,e,r){var u,h;function f(t,e){return i.coerce(u,h,o,t,e)}for(var p=0;p<c.length;p++){var d=c[p];u=t[d]||{},(h=a.newContainer(e,d))._id=d[0]+r.scene,h._name=d,s(u,h,f,r),l(u,h,f,{font:r.font,letter:d[0],data:r.data,showGrid:!0,noTickson:!0,bgColor:r.bgColor,calendar:r.calendar},r.fullLayout),f(\"gridcolor\",n(h.color,r.bgColor,13600/187).toRgbString()),f(\"title.text\",d[0]),h.setScale=i.noop,f(\"showspikes\")&&(f(\"spikesides\"),f(\"spikethickness\"),f(\"spikecolor\",h.color)),f(\"showaxeslabels\"),f(\"showbackground\")&&f(\"backgroundcolor\")}}},{\"../../../lib\":719,\"../../../plot_api/plot_template\":757,\"../../cartesian/axis_defaults\":769,\"../../cartesian/type_defaults\":790,\"./axis_attributes\":809,tinycolor2:537}],811:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"];function o(){this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[18,18,18],this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=[\"Open Sans\",\"Open Sans\",\"Open Sans\"],this.labelSize=[20,20,20],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[30,30,30],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[10,10,10],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!0,!0,!0],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._defaultTickPad=this.tickPad.slice(),this._defaultLabelPad=this.labelPad.slice(),this._defaultLineTickLength=this.lineTickLength.slice()}o.prototype.merge=function(t,e){for(var r=0;r<3;++r){var o=e[a[r]];o.visible?(this.labels[r]=t._meta?i.templateString(o.title.text,t._meta):o.title.text,\"font\"in o.title&&(o.title.font.color&&(this.labelColor[r]=n(o.title.font.color)),o.title.font.family&&(this.labelFont[r]=o.title.font.family),o.title.font.size&&(this.labelSize[r]=o.title.font.size)),\"showline\"in o&&(this.lineEnable[r]=o.showline),\"linecolor\"in o&&(this.lineColor[r]=n(o.linecolor)),\"linewidth\"in o&&(this.lineWidth[r]=o.linewidth),\"showgrid\"in o&&(this.gridEnable[r]=o.showgrid),\"gridcolor\"in o&&(this.gridColor[r]=n(o.gridcolor)),\"gridwidth\"in o&&(this.gridWidth[r]=o.gridwidth),\"log\"===o.type?this.zeroEnable[r]=!1:\"zeroline\"in o&&(this.zeroEnable[r]=o.zeroline),\"zerolinecolor\"in o&&(this.zeroLineColor[r]=n(o.zerolinecolor)),\"zerolinewidth\"in o&&(this.zeroLineWidth[r]=o.zerolinewidth),\"ticks\"in o&&o.ticks?this.lineTickEnable[r]=!0:this.lineTickEnable[r]=!1,\"ticklen\"in o&&(this.lineTickLength[r]=this._defaultLineTickLength[r]=o.ticklen),\"tickcolor\"in o&&(this.lineTickColor[r]=n(o.tickcolor)),\"tickwidth\"in o&&(this.lineTickWidth[r]=o.tickwidth),\"tickangle\"in o&&(this.tickAngle[r]=\"auto\"===o.tickangle?-3600:Math.PI*-o.tickangle/180),\"showticklabels\"in o&&(this.tickEnable[r]=o.showticklabels),\"tickfont\"in o&&(o.tickfont.color&&(this.tickColor[r]=n(o.tickfont.color)),o.tickfont.family&&(this.tickFont[r]=o.tickfont.family),o.tickfont.size&&(this.tickSize[r]=o.tickfont.size)),\"mirror\"in o?-1!==[\"ticks\",\"all\",\"allticks\"].indexOf(o.mirror)?(this.lineTickMirror[r]=!0,this.lineMirror[r]=!0):!0===o.mirror?(this.lineTickMirror[r]=!1,this.lineMirror[r]=!0):(this.lineTickMirror[r]=!1,this.lineMirror[r]=!1):this.lineMirror[r]=!1,\"showbackground\"in o&&!1!==o.showbackground?(this.backgroundEnable[r]=!0,this.backgroundColor[r]=n(o.backgroundcolor)):this.backgroundEnable[r]=!1):(this.tickEnable[r]=!1,this.labelEnable[r]=!1,this.lineEnable[r]=!1,this.lineTickEnable[r]=!1,this.gridEnable[r]=!1,this.zeroEnable[r]=!1,this.backgroundEnable[r]=!1)}},e.exports=function(t,e){var r=new o;return r.merge(t,e),r}},{\"../../../lib\":719,\"../../../lib/str2rgbarray\":742}],812:[function(t,e,r){\"use strict\";var n=t(\"../../../lib\"),i=t(\"../../../components/color\"),a=t(\"../../../registry\"),o=t(\"../../subplot_defaults\"),s=t(\"./axis_defaults\"),l=t(\"./layout_attributes\"),c=t(\"../../get_data\").getSubplotData,u=\"gl3d\";function h(t,e,r,n){for(var o=r(\"bgcolor\"),l=i.combine(o,n.paper_bgcolor),h=[\"up\",\"center\",\"eye\"],f=0;f<h.length;f++)r(\"camera.\"+h[f]+\".x\"),r(\"camera.\"+h[f]+\".y\"),r(\"camera.\"+h[f]+\".z\");r(\"camera.projection.type\");var p=!!r(\"aspectratio.x\")&&!!r(\"aspectratio.y\")&&!!r(\"aspectratio.z\"),d=r(\"aspectmode\",p?\"manual\":\"auto\");p||(t.aspectratio=e.aspectratio={x:1,y:1,z:1},\"manual\"===d&&(e.aspectmode=\"auto\"),t.aspectmode=e.aspectmode);var g=c(n.fullData,u,n.id);s(t,e,{font:n.font,scene:n.id,data:g,bgColor:l,calendar:n.calendar,fullLayout:n.fullLayout}),a.getComponentMethod(\"annotations3d\",\"handleDefaults\")(t,e,n);var v=n.getDfltFromLayout(\"dragmode\");if(!1!==v&&!v)if(v=\"orbit\",t.camera&&t.camera.up){var m=t.camera.up.x,y=t.camera.up.y,x=t.camera.up.z;0!==x&&(m&&y&&x?x/Math.sqrt(m*m+y*y+x*x)>.999&&(v=\"turntable\"):v=\"turntable\")}else v=\"turntable\";r(\"dragmode\",v),r(\"hovermode\",n.getDfltFromLayout(\"hovermode\"))}e.exports=function(t,e,r){var i=e._basePlotModules.length>1;o(t,e,r,{type:u,attributes:l,handleDefaults:h,fullLayout:e,font:e.font,fullData:r,getDfltFromLayout:function(e){if(!i)return n.validate(t[e],l[e])?t[e]:void 0},paper_bgcolor:e.paper_bgcolor,calendar:e.calendar})}},{\"../../../components/color\":593,\"../../../lib\":719,\"../../../registry\":847,\"../../get_data\":802,\"../../subplot_defaults\":842,\"./axis_defaults\":810,\"./layout_attributes\":813}],813:[function(t,e,r){\"use strict\";var n=t(\"./axis_attributes\"),i=t(\"../../domain\").attributes,a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../lib\").counterRegex;function s(t,e,r){return{x:{valType:\"number\",dflt:t,editType:\"camera\"},y:{valType:\"number\",dflt:e,editType:\"camera\"},z:{valType:\"number\",dflt:r,editType:\"camera\"},editType:\"camera\"}}e.exports={_arrayAttrRegexps:[o(\"scene\",\".annotations\",!0)],bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"plot\"},camera:{up:a(s(0,0,1),{}),center:a(s(0,0,0),{}),eye:a(s(1.25,1.25,1.25),{}),projection:{type:{valType:\"enumerated\",values:[\"perspective\",\"orthographic\"],dflt:\"perspective\",editType:\"calc\"},editType:\"calc\"},editType:\"camera\"},domain:i({name:\"scene\",editType:\"plot\"}),aspectmode:{valType:\"enumerated\",values:[\"auto\",\"cube\",\"data\",\"manual\"],dflt:\"auto\",editType:\"plot\",impliedEdits:{\"aspectratio.x\":void 0,\"aspectratio.y\":void 0,\"aspectratio.z\":void 0}},aspectratio:{x:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},y:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},z:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},editType:\"plot\",impliedEdits:{aspectmode:\"manual\"}},xaxis:n,yaxis:n,zaxis:n,dragmode:{valType:\"enumerated\",values:[\"orbit\",\"turntable\",\"zoom\",\"pan\",!1],editType:\"plot\"},hovermode:{valType:\"enumerated\",values:[\"closest\",!1],dflt:\"closest\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"plot\",_deprecated:{cameraposition:{valType:\"info_array\",editType:\"camera\"}}}},{\"../../../lib\":719,\"../../../lib/extend\":710,\"../../domain\":792,\"./axis_attributes\":809}],814:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=[\"xaxis\",\"yaxis\",\"zaxis\"];function a(){this.enabled=[!0,!0,!0],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.drawSides=[!0,!0,!0],this.lineWidth=[1,1,1]}a.prototype.merge=function(t){for(var e=0;e<3;++e){var r=t[i[e]];r.visible?(this.enabled[e]=r.showspikes,this.colors[e]=n(r.spikecolor),this.drawSides[e]=r.spikesides,this.lineWidth[e]=r.spikethickness):(this.enabled[e]=!1,this.drawSides[e]=!1)}},e.exports=function(t){var e=new a;return e.merge(t),e}},{\"../../../lib/str2rgbarray\":742}],815:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.axesOptions,r=t.glplot.axesPixels,s=t.fullSceneLayout,l=[[],[],[]],c=0;c<3;++c){var u=s[a[c]];if(u._length=(r[c].hi-r[c].lo)*r[c].pixelsPerDataUnit/t.dataScale[c],Math.abs(u._length)===1/0||isNaN(u._length))l[c]=[];else{u._input_range=u.range.slice(),u.range[0]=r[c].lo/t.dataScale[c],u.range[1]=r[c].hi/t.dataScale[c],u._m=1/(t.dataScale[c]*r[c].pixelsPerDataUnit),u.range[0]===u.range[1]&&(u.range[0]-=1,u.range[1]+=1);var h=u.tickmode;if(\"auto\"===u.tickmode){u.tickmode=\"linear\";var f=u.nticks||i.constrain(u._length/40,4,9);n.autoTicks(u,Math.abs(u.range[1]-u.range[0])/f)}for(var p=n.calcTicks(u),d=0;d<p.length;++d)p[d].x=p[d].x*t.dataScale[c],\"date\"===u.type&&(p[d].text=p[d].text.replace(/\\<br\\>/g,\" \"));l[c]=p,u.tickmode=h}}e.ticks=l;for(var c=0;c<3;++c){o[c]=.5*(t.glplot.bounds[0][c]+t.glplot.bounds[1][c]);for(var d=0;d<2;++d)e.bounds[d][c]=t.glplot.bounds[d][c]}t.contourLevels=function(t){for(var e=new Array(3),r=0;r<3;++r){for(var n=t[r],i=new Array(n.length),a=0;a<n.length;++a)i[a]=n[a].x;e[r]=i}return e}(l)};var n=t(\"../../cartesian/axes\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"],o=[0,0,0]},{\"../../../lib\":719,\"../../cartesian/axes\":767}],816:[function(t,e,r){\"use strict\";function n(t,e){var r,n,i=[0,0,0,0];for(r=0;r<4;++r)for(n=0;n<4;++n)i[n]+=t[4*r+n]*e[r];return i}e.exports=function(t,e){return n(t.projection,n(t.view,n(t.model,[e[0],e[1],e[2],1])))}},{}],817:[function(t,e,r){\"use strict\";var n,i,a=t(\"gl-plot3d\").createCamera,o=t(\"gl-plot3d\").createScene,s=t(\"webgl-context\"),l=t(\"has-passive-events\"),c=t(\"../../registry\"),u=t(\"../../lib\"),h=t(\"../../plots/cartesian/axes\"),f=t(\"../../components/fx\"),p=t(\"../../lib/str2rgbarray\"),d=t(\"../../lib/show_no_webgl_msg\"),g=t(\"./project\"),v=t(\"./layout/convert\"),m=t(\"./layout/spikes\"),y=t(\"./layout/tick_marks\");function x(t,e,r,a){if(t.initializeGLCamera(),!function(t,e,r,a,l){var c={canvas:a,gl:l,container:t.container,axes:t.axesOptions,spikes:t.spikeOptions,pickRadius:10,snapToData:!0,autoScale:!0,autoBounds:!1,cameraObject:e,pixelRatio:r};if(t.staticMode){if(!(i||(n=document.createElement(\"canvas\"),i=s({canvas:n,preserveDrawingBuffer:!0,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"error creating static canvas/context for image server\");c.pixelRatio=t.pixelRatio,c.gl=i,c.canvas=n}try{t.glplot=o(c)}catch(t){return!1}return!0}(t,t.camera,e,r,a))return d(t);var c=t.graphDiv,p=function(t){if(!1!==t.fullSceneLayout.dragmode){var e={};e[t.id+\".camera\"]=T(t.camera),t.saveCamera(c.layout),t.graphDiv.emit(\"plotly_relayout\",e)}};return t.glplot.canvas.addEventListener(\"mouseup\",function(){p(t)}),t.glplot.canvas.addEventListener(\"wheel\",function(){c._context._scrollZoom.gl3d&&p(t)},!!l&&{passive:!1}),t.glplot.canvas.addEventListener(\"mousemove\",function(){if(!1!==t.fullSceneLayout.dragmode&&0!==t.camera.mouseListener.buttons){var e={};e[t.id+\".camera\"]=T(t.camera),t.graphDiv.emit(\"plotly_relayouting\",e)}}),t.staticMode||t.glplot.canvas.addEventListener(\"webglcontextlost\",function(e){c&&c.emit&&c.emit(\"plotly_webglcontextlost\",{event:e,layer:t.id})},!1),t.glplot.camera=t.camera,t.glplot.oncontextloss=function(){t.recoverContext()},t.glplot.onrender=function(t){var e,r=t.graphDiv,n=t.svgContainer,i=t.container.getBoundingClientRect(),a=i.width,o=i.height;n.setAttributeNS(null,\"viewBox\",\"0 0 \"+a+\" \"+o),n.setAttributeNS(null,\"width\",a),n.setAttributeNS(null,\"height\",o),y(t),t.glplot.axes.update(t.axesOptions);for(var s,l=Object.keys(t.traces),c=null,p=t.glplot.selection,d=0;d<l.length;++d)\"skip\"!==(e=t.traces[l[d]]).data.hoverinfo&&e.handlePick(p)&&(c=e),e.setContourLevels&&e.setContourLevels();function v(e,r){var n=t.fullSceneLayout[e];return h.tickText(n,n.d2l(r),\"hover\").text}if(null!==c){var m=g(t.glplot.cameraParams,p.dataCoordinate);e=c.data;var x,b=r._fullData[e.index],_=p.index,w={xLabel:v(\"xaxis\",p.traceCoordinate[0]),yLabel:v(\"yaxis\",p.traceCoordinate[1]),zLabel:v(\"zaxis\",p.traceCoordinate[2])},k=f.castHoverinfo(b,t.fullLayout,_),T=(k||\"\").split(\"+\"),A=k&&\"all\"===k;b.hovertemplate||A||(-1===T.indexOf(\"x\")&&(w.xLabel=void 0),-1===T.indexOf(\"y\")&&(w.yLabel=void 0),-1===T.indexOf(\"z\")&&(w.zLabel=void 0),-1===T.indexOf(\"text\")&&(p.textLabel=void 0),-1===T.indexOf(\"name\")&&(c.name=void 0));var M=[];\"cone\"===e.type||\"streamtube\"===e.type?(w.uLabel=v(\"xaxis\",p.traceCoordinate[3]),(A||-1!==T.indexOf(\"u\"))&&M.push(\"u: \"+w.uLabel),w.vLabel=v(\"yaxis\",p.traceCoordinate[4]),(A||-1!==T.indexOf(\"v\"))&&M.push(\"v: \"+w.vLabel),w.wLabel=v(\"zaxis\",p.traceCoordinate[5]),(A||-1!==T.indexOf(\"w\"))&&M.push(\"w: \"+w.wLabel),w.normLabel=p.traceCoordinate[6].toPrecision(3),(A||-1!==T.indexOf(\"norm\"))&&M.push(\"norm: \"+w.normLabel),\"streamtube\"===e.type&&(w.divergenceLabel=p.traceCoordinate[7].toPrecision(3),(A||-1!==T.indexOf(\"divergence\"))&&M.push(\"divergence: \"+w.divergenceLabel)),p.textLabel&&M.push(p.textLabel),x=M.join(\"<br>\")):\"isosurface\"===e.type||\"volume\"===e.type?(w.valueLabel=h.tickText(t.mockAxis,t.mockAxis.d2l(p.traceCoordinate[3]),\"hover\").text,M.push(\"value: \"+w.valueLabel),p.textLabel&&M.push(p.textLabel),x=M.join(\"<br>\")):x=p.textLabel;var S={x:p.traceCoordinate[0],y:p.traceCoordinate[1],z:p.traceCoordinate[2],data:b._input,fullData:b,curveNumber:b.index,pointNumber:_};f.appendArrayPointValue(S,b,_),e._module.eventData&&(S=b._module.eventData(S,p,b,{},_));var E={points:[S]};t.fullSceneLayout.hovermode&&f.loneHover({trace:b,x:(.5+.5*m[0]/m[3])*a,y:(.5-.5*m[1]/m[3])*o,xLabel:w.xLabel,yLabel:w.yLabel,zLabel:w.zLabel,text:x,name:c.name,color:f.castHoverOption(b,_,\"bgcolor\")||c.color,borderColor:f.castHoverOption(b,_,\"bordercolor\"),fontFamily:f.castHoverOption(b,_,\"font.family\"),fontSize:f.castHoverOption(b,_,\"font.size\"),fontColor:f.castHoverOption(b,_,\"font.color\"),nameLength:f.castHoverOption(b,_,\"namelength\"),textAlign:f.castHoverOption(b,_,\"align\"),hovertemplate:u.castOption(b,_,\"hovertemplate\"),hovertemplateLabels:u.extendFlat({},S,w),eventData:[S]},{container:n,gd:r}),p.buttons&&p.distance<5?r.emit(\"plotly_click\",E):r.emit(\"plotly_hover\",E),s=E}else f.loneUnhover(n),r.emit(\"plotly_unhover\",s);t.drawAnnotations(t)}.bind(null,t),t.traces={},t.make4thDimension(),!0}function b(t,e){var r=document.createElement(\"div\"),n=t.container;this.graphDiv=t.graphDiv;var i=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");i.style.position=\"absolute\",i.style.top=i.style.left=\"0px\",i.style.width=i.style.height=\"100%\",i.style[\"z-index\"]=20,i.style[\"pointer-events\"]=\"none\",r.appendChild(i),this.svgContainer=i,r.id=t.id,r.style.position=\"absolute\",r.style.top=r.style.left=\"0px\",r.style.width=r.style.height=\"100%\",n.appendChild(r),this.fullLayout=e,this.id=t.id||\"scene\",this.fullSceneLayout=e[this.id],this.plotArgs=[[],{},{}],this.axesOptions=v(e,e[this.id]),this.spikeOptions=m(e[this.id]),this.container=r,this.staticMode=!!t.staticPlot,this.pixelRatio=this.pixelRatio||t.plotGlPixelRatio||2,this.dataScale=[1,1,1],this.contourLevels=[[],[],[]],this.convertAnnotations=c.getComponentMethod(\"annotations3d\",\"convert\"),this.drawAnnotations=c.getComponentMethod(\"annotations3d\",\"draw\"),x(this,this.pixelRatio)}var _=b.prototype;_.initializeGLCamera=function(){var t=this.fullSceneLayout.camera,e=\"orthographic\"===t.projection.type;this.camera=a(this.container,{center:[t.center.x,t.center.y,t.center.z],eye:[t.eye.x,t.eye.y,t.eye.z],up:[t.up.x,t.up.y,t.up.z],_ortho:e,zoomMin:.01,zoomMax:100,mode:\"orbit\"})},_.recoverContext=function(){var t=this,e=this.glplot.gl,r=this.glplot.canvas,n=this.glplot.camera,i=this.glplot.pixelRatio;this.glplot.dispose(),requestAnimationFrame(function a(){e.isContextLost()?requestAnimationFrame(a):x(t,n,i,r)?t.plot.apply(t,t.plotArgs):u.error(\"Catastrophic and unrecoverable WebGL error. Context lost.\")})};var w=[\"xaxis\",\"yaxis\",\"zaxis\"];function k(t,e,r){for(var n=t.fullSceneLayout,i=0;i<3;i++){var a=w[i],o=a.charAt(0),s=n[a],l=e[o],c=e[o+\"calendar\"],h=e[\"_\"+o+\"length\"];if(u.isArrayOrTypedArray(l))for(var f,p=0;p<(h||l.length);p++)if(u.isArrayOrTypedArray(l[p]))for(var d=0;d<l[p].length;++d)f=s.d2l(l[p][d],0,c),!isNaN(f)&&isFinite(f)&&(r[0][i]=Math.min(r[0][i],f),r[1][i]=Math.max(r[1][i],f));else f=s.d2l(l[p],0,c),!isNaN(f)&&isFinite(f)&&(r[0][i]=Math.min(r[0][i],f),r[1][i]=Math.max(r[1][i],f));else r[0][i]=Math.min(r[0][i],0),r[1][i]=Math.max(r[1][i],h-1)}}function T(t){return{up:{x:t.up[0],y:t.up[1],z:t.up[2]},center:{x:t.center[0],y:t.center[1],z:t.center[2]},eye:{x:t.eye[0],y:t.eye[1],z:t.eye[2]},projection:{type:!0===t._ortho?\"orthographic\":\"perspective\"}}}_.plot=function(t,e,r){if(this.plotArgs=[t,e,r],!this.glplot.contextLost){var n,i,a,o,s,l,c=e[this.id],u=r[this.id];c.bgcolor?this.glplot.clearColor=p(c.bgcolor):this.glplot.clearColor=[0,0,0,0],this.glplot.snapToData=!0,this.fullLayout=e,this.fullSceneLayout=c,this.glplotLayout=c,this.axesOptions.merge(e,c),this.spikeOptions.merge(c),this.setCamera(c.camera),this.updateFx(c.dragmode,c.hovermode),this.camera.enableWheel=this.graphDiv._context._scrollZoom.gl3d,this.glplot.update({}),this.setConvert(s),t?Array.isArray(t)||(t=[t]):t=[];var h=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&k(this,n,h);!function(t,e){for(var r=t.fullSceneLayout,n=r.annotations||[],i=0;i<3;i++)for(var a=w[i],o=a.charAt(0),s=r[a],l=0;l<n.length;l++){var c=n[l];if(c.visible){var u=s.r2l(c[o]);!isNaN(u)&&isFinite(u)&&(e[0][i]=Math.min(e[0][i],u),e[1][i]=Math.max(e[1][i],u))}}}(this,h);var f=[1,1,1];for(o=0;o<3;++o)h[1][o]===h[0][o]?f[o]=1:f[o]=1/(h[1][o]-h[0][o]);for(this.dataScale=f,this.convertAnnotations(this),a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&((i=this.traces[n.uid])?i.data.type===n.type?i.update(n):(i.dispose(),i=n._module.plot(this,n),this.traces[n.uid]=i):(i=n._module.plot(this,n),this.traces[n.uid]=i),i.name=n.name);var d=Object.keys(this.traces);t:for(a=0;a<d.length;++a){for(o=0;o<t.length;++o)if(t[o].uid===d[a]&&!0===t[o].visible&&0!==t[o]._length)continue t;(i=this.traces[d[a]]).dispose(),delete this.traces[d[a]]}this.glplot.objects.sort(function(t,e){return t._trace.data.index-e._trace.data.index});var g=[[0,0,0],[0,0,0]],v=[],m={};for(a=0;a<3;++a){if((l=(s=c[w[a]]).type)in m?(m[l].acc*=f[a],m[l].count+=1):m[l]={acc:f[a],count:1},s.autorange){g[0][a]=1/0,g[1][a]=-1/0;var y=this.glplot.objects,x=this.fullSceneLayout.annotations||[],b=s._name.charAt(0);for(o=0;o<y.length;o++){var _=y[o],T=_.bounds,A=_._trace.data._pad||0;\"ErrorBars\"===_.constructor.name&&s._lowerLogErrorBound?g[0][a]=Math.min(g[0][a],s._lowerLogErrorBound):g[0][a]=Math.min(g[0][a],T[0][a]/f[a]-A),g[1][a]=Math.max(g[1][a],T[1][a]/f[a]+A)}for(o=0;o<x.length;o++){var M=x[o];if(M.visible){var S=s.r2l(M[b]);g[0][a]=Math.min(g[0][a],S),g[1][a]=Math.max(g[1][a],S)}}if(\"rangemode\"in s&&\"tozero\"===s.rangemode&&(g[0][a]=Math.min(g[0][a],0),g[1][a]=Math.max(g[1][a],0)),g[0][a]>g[1][a])g[0][a]=-1,g[1][a]=1;else{var E=g[1][a]-g[0][a];g[0][a]-=E/32,g[1][a]+=E/32}if(\"reversed\"===s.autorange){var C=g[0][a];g[0][a]=g[1][a],g[1][a]=C}}else{var L=s.range;g[0][a]=s.r2l(L[0]),g[1][a]=s.r2l(L[1])}g[0][a]===g[1][a]&&(g[0][a]-=1,g[1][a]+=1),v[a]=g[1][a]-g[0][a],this.glplot.bounds[0][a]=g[0][a]*f[a],this.glplot.bounds[1][a]=g[1][a]*f[a]}var P=[1,1,1];for(a=0;a<3;++a){var O=m[l=(s=c[w[a]]).type];P[a]=Math.pow(O.acc,1/O.count)/f[a]}var z;if(\"auto\"===c.aspectmode)z=Math.max.apply(null,P)/Math.min.apply(null,P)<=4?P:[1,1,1];else if(\"cube\"===c.aspectmode)z=[1,1,1];else if(\"data\"===c.aspectmode)z=P;else{if(\"manual\"!==c.aspectmode)throw new Error(\"scene.js aspectRatio was not one of the enumerated types\");var I=c.aspectratio;z=[I.x,I.y,I.z]}c.aspectratio.x=u.aspectratio.x=z[0],c.aspectratio.y=u.aspectratio.y=z[1],c.aspectratio.z=u.aspectratio.z=z[2],this.glplot.aspect=z;var D=c.domain||null,R=e._size||null;if(D&&R){var F=this.container.style;F.position=\"absolute\",F.left=R.l+D.x[0]*R.w+\"px\",F.top=R.t+(1-D.y[1])*R.h+\"px\",F.width=R.w*(D.x[1]-D.x[0])+\"px\",F.height=R.h*(D.y[1]-D.y[0])+\"px\"}this.glplot.redraw()}},_.destroy=function(){this.glplot&&(this.camera.mouseListener.enabled=!1,this.container.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=this.glplot.camera=null,this.glplot.dispose(),this.container.parentNode.removeChild(this.container),this.glplot=null)},_.getCamera=function(){return this.glplot.camera.view.recalcMatrix(this.camera.view.lastT()),T(this.glplot.camera)},_.setCamera=function(t){var e;this.glplot.camera.lookAt.apply(this,[[(e=t).eye.x,e.eye.y,e.eye.z],[e.center.x,e.center.y,e.center.z],[e.up.x,e.up.y,e.up.z]]);var r=\"orthographic\"===t.projection.type;if(r!==this.glplot.camera._ortho){this.glplot.redraw();var n=this.glplot.pixelRatio,i=this.glplot.clearColor;this.glplot.gl.clearColor(i[0],i[1],i[2],i[3]),this.glplot.gl.clear(this.glplot.gl.DEPTH_BUFFER_BIT|this.glplot.gl.COLOR_BUFFER_BIT),this.glplot.dispose(),x(this,n),this.glplot.camera._ortho=r}},_.saveCamera=function(t){var e=this.fullLayout,r=this.getCamera(),n=u.nestedProperty(t,this.id+\".camera\"),i=n.get(),a=!1;function o(t,e,r,n){var i=[\"up\",\"center\",\"eye\"],a=[\"x\",\"y\",\"z\"];return e[i[r]]&&t[i[r]][a[n]]===e[i[r]][a[n]]}if(void 0===i)a=!0;else{for(var s=0;s<3;s++)for(var l=0;l<3;l++)if(!o(r,i,s,l)){a=!0;break}(!i.projection||r.projection&&r.projection.type!==i.projection.type)&&(a=!0)}if(a){var h={};h[this.id+\".camera\"]=i,c.call(\"_storeDirectGUIEdit\",t,e._preGUI,h),n.set(r),u.nestedProperty(e,this.id+\".camera\").set(r)}return a},_.updateFx=function(t,e){var r=this.camera;if(r)if(\"orbit\"===t)r.mode=\"orbit\",r.keyBindingMode=\"rotate\";else if(\"turntable\"===t){r.up=[0,0,1],r.mode=\"turntable\",r.keyBindingMode=\"rotate\";var n=this.graphDiv,i=n._fullLayout,a=this.fullSceneLayout.camera,o=a.up.x,s=a.up.y,l=a.up.z;if(l/Math.sqrt(o*o+s*s+l*l)<.999){var h=this.id+\".camera.up\",f={x:0,y:0,z:1},p={};p[h]=f;var d=n.layout;c.call(\"_storeDirectGUIEdit\",d,i._preGUI,p),a.up=f,u.nestedProperty(d,h).set(f)}}else r.keyBindingMode=t;this.fullSceneLayout.hovermode=e},_.toImage=function(t){t||(t=\"png\"),this.staticMode&&this.container.appendChild(n),this.glplot.redraw();var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a);for(var o=0,s=i-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=a[4*(r*o+l)+c];a[4*(r*o+l)+c]=a[4*(r*s+l)+c],a[4*(r*s+l)+c]=u}var h=document.createElement(\"canvas\");h.width=r,h.height=i;var f,p=h.getContext(\"2d\"),d=p.createImageData(r,i);switch(d.data.set(a),p.putImageData(d,0,0),t){case\"jpeg\":f=h.toDataURL(\"image/jpeg\");break;case\"webp\":f=h.toDataURL(\"image/webp\");break;default:f=h.toDataURL(\"image/png\")}return this.staticMode&&this.container.removeChild(n),f},_.setConvert=function(){for(var t=0;t<3;t++){var e=this.fullSceneLayout[w[t]];h.setConvert(e,this.fullLayout),e.setScale=u.noop}},_.make4thDimension=function(){var t=this.graphDiv._fullLayout;this.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},h.setConvert(this.mockAxis,t)},e.exports=b},{\"../../components/fx\":632,\"../../lib\":719,\"../../lib/show_no_webgl_msg\":740,\"../../lib/str2rgbarray\":742,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./layout/convert\":811,\"./layout/spikes\":814,\"./layout/tick_marks\":815,\"./project\":816,\"gl-plot3d\":290,\"has-passive-events\":411,\"webgl-context\":556}],818:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){n=n||t.length;for(var i=new Array(n),a=0;a<n;a++)i[a]=[t[a],e[a],r[a]];return i}},{}],819:[function(t,e,r){\"use strict\";var n=t(\"./font_attributes\"),i=t(\"./animation_attributes\"),a=t(\"../components/color/attributes\"),o=t(\"./pad_attributes\"),s=t(\"../lib/extend\").extendFlat,l=n({editType:\"calc\"});l.family.dflt='\"Open Sans\", verdana, arial, sans-serif',l.size.dflt=12,l.color.dflt=a.defaultLine,e.exports={font:l,title:{text:{valType:\"string\",editType:\"layoutstyle\"},font:n({editType:\"layoutstyle\"}),xref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},yref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},x:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"layoutstyle\"},y:{valType:\"number\",min:0,max:1,dflt:\"auto\",editType:\"layoutstyle\"},xanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"left\",\"center\",\"right\"],editType:\"layoutstyle\"},yanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],editType:\"layoutstyle\"},pad:s(o({editType:\"layoutstyle\"}),{}),editType:\"layoutstyle\"},autosize:{valType:\"boolean\",dflt:!1,editType:\"none\"},width:{valType:\"number\",min:10,dflt:700,editType:\"plot\"},height:{valType:\"number\",min:10,dflt:450,editType:\"plot\"},margin:{l:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},r:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},t:{valType:\"number\",min:0,dflt:100,editType:\"plot\"},b:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},pad:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},autoexpand:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},paper_bgcolor:{valType:\"color\",dflt:a.background,editType:\"plot\"},plot_bgcolor:{valType:\"color\",dflt:a.background,editType:\"layoutstyle\"},separators:{valType:\"string\",editType:\"plot\"},hidesources:{valType:\"boolean\",dflt:!1,editType:\"plot\"},showlegend:{valType:\"boolean\",editType:\"legend\"},colorway:{valType:\"colorlist\",dflt:a.defaults,editType:\"calc\"},datarevision:{valType:\"any\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editrevision:{valType:\"any\",editType:\"none\"},selectionrevision:{valType:\"any\",editType:\"none\"},template:{valType:\"any\",editType:\"calc\"},modebar:{orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\",editType:\"modebar\"},bgcolor:{valType:\"color\",editType:\"modebar\"},color:{valType:\"color\",editType:\"modebar\"},activecolor:{valType:\"color\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"modebar\"},meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},transition:s({},i.transition,{editType:\"none\"}),_deprecated:{title:{valType:\"string\",editType:\"layoutstyle\"},titlefont:n({editType:\"layoutstyle\"})}}},{\"../components/color/attributes\":592,\"../lib/extend\":710,\"./animation_attributes\":762,\"./font_attributes\":793,\"./pad_attributes\":827}],820:[function(t,e,r){\"use strict\";var n={\"open-street-map\":{id:\"osm\",version:8,sources:{\"plotly-osm-tiles\":{type:\"raster\",attribution:'<a href=\"http://www.openstreetmap.org/about/\" target=\"_blank\">\\xa9 OpenStreetMap</a>',tiles:[\"https://a.tile.openstreetmap.org/{z}/{x}/{y}.png\",\"https://b.tile.openstreetmap.org/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-osm-tiles\",type:\"raster\",source:\"plotly-osm-tiles\",minzoom:0,maxzoom:22}]},\"white-bg\":{id:\"white-bg\",version:8,sources:{},layers:[{id:\"white-bg\",type:\"background\",paint:{\"background-color\":\"#FFFFFF\"},minzoom:0,maxzoom:22}]},\"carto-positron\":{id:\"carto-positron\",version:8,sources:{\"plotly-carto-positron\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/light_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-positron\",type:\"raster\",source:\"plotly-carto-positron\",minzoom:0,maxzoom:22}]},\"carto-darkmatter\":{id:\"carto-darkmatter\",version:8,sources:{\"plotly-carto-darkmatter\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/dark_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-darkmatter\",type:\"raster\",source:\"plotly-carto-darkmatter\",minzoom:0,maxzoom:22}]},\"stamen-terrain\":{id:\"stamen-terrain\",version:8,sources:{\"plotly-stamen-terrain\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/terrain/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-terrain\",type:\"raster\",source:\"plotly-stamen-terrain\",minzoom:0,maxzoom:22}]},\"stamen-toner\":{id:\"stamen-toner\",version:8,sources:{\"plotly-stamen-toner\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/toner/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-toner\",type:\"raster\",source:\"plotly-stamen-toner\",minzoom:0,maxzoom:22}]},\"stamen-watercolor\":{id:\"stamen-watercolor\",version:8,sources:{\"plotly-stamen-watercolor\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://creativecommons.org/licenses/by-sa/3.0\">CC BY SA</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/watercolor/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-watercolor\",type:\"raster\",source:\"plotly-stamen-watercolor\",minzoom:0,maxzoom:22}]}},i=Object.keys(n);e.exports={requiredVersion:\"1.1.1\",styleUrlPrefix:\"mapbox://styles/mapbox/\",styleUrlSuffix:\"v9\",styleValuesMapbox:[\"basic\",\"streets\",\"outdoors\",\"light\",\"dark\",\"satellite\",\"satellite-streets\"],styleValueDflt:\"basic\",stylesNonMapbox:n,styleValuesNonMapbox:i,traceLayerPrefix:\"plotly-trace-layer-\",layoutLayerPrefix:\"plotly-layout-layer-\",wrongVersionErrorMsg:[\"Your custom plotly.js bundle is not using the correct mapbox-gl version\",\"Please install mapbox-gl@1.1.1.\"].join(\"\\n\"),noAccessTokenErrorMsg:[\"Missing Mapbox access token.\",\"Mapbox trace type require a Mapbox access token to be registered.\",\"For example:\",\"  Plotly.plot(gd, data, layout, { mapboxAccessToken: 'my-access-token' });\",\"More info here: https://www.mapbox.com/help/define-access-token/\"].join(\"\\n\"),missingStyleErrorMsg:[\"No valid mapbox style found, please set `mapbox.style` to one of:\",i.join(\", \"),\"or register a Mapbox access token to use a Mapbox-served style.\"].join(\"\\n\"),multipleTokensErrorMsg:[\"Set multiple mapbox access token across different mapbox subplot,\",\"using first token found as mapbox-gl does not allow multipleaccess tokens on the same page.\"].join(\"\\n\"),mapOnErrorMsg:\"Mapbox error.\",mapboxLogo:{path0:\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\",path1:\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\",path2:\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\",polygon:\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34\"},styleRules:{map:\"overflow:hidden;position:relative;\",\"missing-css\":\"display:none;\",canary:\"background-color:salmon;\",\"ctrl-bottom-left\":\"position: absolute; pointer-events: none; z-index: 2; bottom: 0; left: 0;\",\"ctrl-bottom-right\":\"position: absolute; pointer-events: none; z-index: 2; right: 0; bottom: 0;\",ctrl:\"clear: both; pointer-events: auto; transform: translate(0, 0);\",\"ctrl-attrib.mapboxgl-compact .mapboxgl-ctrl-attrib-inner\":\"display: none;\",\"ctrl-attrib.mapboxgl-compact:hover .mapboxgl-ctrl-attrib-inner\":\"display: block; margin-top:2px\",\"ctrl-attrib.mapboxgl-compact:hover\":\"padding: 2px 24px 2px 4px; visibility: visible; margin-top: 6px;\",\"ctrl-attrib.mapboxgl-compact::after\":'content: \"\"; cursor: pointer; position: absolute; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3Csvg viewBox=\"0 0 20 20\" xmlns=\"http://www.w3.org/2000/svg\"%3E %3Cpath fill=\"%23333333\" fill-rule=\"evenodd\" d=\"M4,10a6,6 0 1,0 12,0a6,6 0 1,0 -12,0 M9,7a1,1 0 1,0 2,0a1,1 0 1,0 -2,0 M9,10a1,1 0 1,1 2,0l0,3a1,1 0 1,1 -2,0\"/%3E %3C/svg%3E\\'); background-color: rgba(255, 255, 255, 0.5); width: 24px; height: 24px; box-sizing: border-box; border-radius: 12px;',\"ctrl-attrib.mapboxgl-compact\":\"min-height: 20px; padding: 0; margin: 10px; position: relative; background-color: #fff; border-radius: 3px 12px 12px 3px;\",\"ctrl-bottom-right > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; right: 0\",\"ctrl-bottom-left > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; left: 0\",\"ctrl-bottom-left .mapboxgl-ctrl\":\"margin: 0 0 10px 10px; float: left;\",\"ctrl-bottom-right .mapboxgl-ctrl\":\"margin: 0 10px 10px 0; float: right;\",\"ctrl-attrib\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a:hover\":\"color: inherit; text-decoration: underline;\",\"ctrl-attrib .mapbox-improve-map\":\"font-weight: bold; margin-left: 2px;\",\"attrib-empty\":\"display: none;\",\"ctrl-logo\":'display:block; width: 21px; height: 21px; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3C?xml version=\"1.0\" encoding=\"utf-8\"?%3E %3Csvg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\" viewBox=\"0 0 21 21\" style=\"enable-background:new 0 0 21 21;\" xml:space=\"preserve\"%3E%3Cg transform=\"translate(0,0.01)\"%3E%3Cpath d=\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3Cpath d=\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpath d=\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpolygon points=\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34 \" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3C/g%3E%3C/svg%3E\\')'}}},{}],821:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t.split(\" \"),i=r[0],a=r[1],o=n.isArrayOrTypedArray(e)?n.mean(e):e,s=.5+o/100,l=1.5+o/100,c=[\"\",\"\"],u=[0,0];switch(i){case\"top\":c[0]=\"top\",u[1]=-l;break;case\"bottom\":c[0]=\"bottom\",u[1]=l}switch(a){case\"left\":c[1]=\"right\",u[0]=-s;break;case\"right\":c[1]=\"left\",u[0]=s}return{anchor:c[0]&&c[1]?c.join(\"-\"):c[0]?c[0]:c[1]?c[1]:\"center\",offset:u}}},{\"../../lib\":719}],822:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"../../lib\"),a=t(\"../../plots/get_data\").getSubplotCalcData,o=t(\"../../constants/xmlns_namespaces\"),s=t(\"d3\"),l=t(\"../../components/drawing\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"./mapbox\"),h=r.constants=t(\"./constants\");function f(t){return\"string\"==typeof t&&-1!==h.styleValuesMapbox.indexOf(t)}r.name=\"mapbox\",r.attr=\"subplot\",r.idRoot=\"mapbox\",r.idRegex=r.attrRegex=i.counterRegex(\"mapbox\"),r.attributes={subplot:{valType:\"subplotid\",dflt:\"mapbox\",editType:\"calc\"}},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){var e=t._fullLayout,r=t.calcdata,o=e._subplots.mapbox;if(n.version!==h.requiredVersion)throw new Error(h.wrongVersionErrorMsg);var s=function(t,e){var r=t._fullLayout;if(\"\"===t._context.mapboxAccessToken)return\"\";for(var n=[],a=[],o=!1,s=!1,l=0;l<e.length;l++){var c=r[e[l]],u=c.accesstoken;f(c.style)&&(u?i.pushUnique(n,u):(f(c._input.style)&&(i.error(\"Uses Mapbox map style, but did not set an access token.\"),o=!0),s=!0)),u&&i.pushUnique(a,u)}if(s){var p=o?h.noAccessTokenErrorMsg:h.missingStyleErrorMsg;throw new Error(p)}return n.length?(n.length>1&&i.warn(h.multipleTokensErrorMsg),n[0]):(a.length&&i.log([\"Listed mapbox access token(s)\",a.join(\",\"),\"but did not use a Mapbox map style, ignoring token(s).\"].join(\" \")),\"\")}(t,o);n.accessToken=s;for(var l=0;l<o.length;l++){var c=o[l],p=a(r,\"mapbox\",c),d=e[c],g=d._subplot;g||(g=new u(t,c),e[c]._subplot=g),g.viewInitial||(g.viewInitial={center:i.extendFlat({},d.center),zoom:d.zoom,bearing:d.bearing,pitch:d.pitch}),g.plot(p,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.mapbox||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._subplot&&n[o]._subplot.destroy()}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=e._size,i=0;i<r.length;i++){var a=e[r[i]],u=a.domain,f=a._subplot.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":f,x:n.l+n.w*u.x[0],y:n.t+n.h*(1-u.y[1]),width:n.w*(u.x[1]-u.x[0]),height:n.h*(u.y[1]-u.y[0]),preserveAspectRatio:\"none\"});var p=s.select(a._subplot.div);if(!(null===p.select(\".mapboxgl-ctrl-logo\").node().offsetParent)){var d=e._glimages.append(\"g\");d.attr(\"transform\",\"translate(\"+(n.l+n.w*u.x[0]+10)+\", \"+(n.t+n.h*(1-u.y[0])-31)+\")\"),d.append(\"path\").attr(\"d\",h.mapboxLogo.path0).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"}),d.append(\"path\").attr(\"d\",h.mapboxLogo.path1).style(\"opacity\",.35).style(\"enable-background\",\"new\"),d.append(\"path\").attr(\"d\",h.mapboxLogo.path2).style(\"opacity\",.35).style(\"enable-background\",\"new\"),d.append(\"polygon\").attr(\"points\",h.mapboxLogo.polygon).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"})}var g=p.select(\".mapboxgl-ctrl-attrib\").text().replace(\"Improve this map\",\"\"),v=e._glimages.append(\"g\"),m=v.append(\"text\");m.text(g).classed(\"static-attribution\",!0).attr({\"font-size\":12,\"font-family\":\"Arial\",color:\"rgba(0, 0, 0, 0.75)\",\"text-anchor\":\"end\",\"data-unformatted\":g});var y=l.bBox(m.node()),x=n.w*(u.x[1]-u.x[0]);if(y.width>x/2){var b=g.split(\"|\").join(\"<br>\");m.text(b).attr(\"data-unformatted\",b).call(c.convertToTspans,t),y=l.bBox(m.node())}m.attr(\"transform\",\"translate(-3, \"+(8-y.height)+\")\"),v.insert(\"rect\",\".static-attribution\").attr({x:-y.width-6,y:-y.height-3,width:y.width+6,height:y.height+3,fill:\"rgba(255, 255, 255, 0.75)\"});var _=1;y.width+6>x&&(_=x/(y.width+6));var w=[n.l+n.w*u.x[1],n.t+n.h*(1-u.y[0])];v.attr(\"transform\",\"translate(\"+w[0]+\",\"+w[1]+\") scale(\"+_+\")\")}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=0;n<r.length;n++){e[r[n]]._subplot.updateFx(e)}}},{\"../../components/drawing\":614,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/get_data\":802,\"./constants\":820,\"./layout_attributes\":824,\"./layout_defaults\":825,\"./mapbox\":826,d3:163,\"mapbox-gl\":426}],823:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./convert_text_opts\"),a=t(\"./constants\");function o(t,e){this.subplot=t,this.uid=t.uid+\"-\"+e,this.index=e,this.idSource=\"source-\"+this.uid,this.idLayer=a.layoutLayerPrefix+this.uid,this.sourceType=null,this.source=null,this.layerType=null,this.below=null,this.visible=!1}var s=o.prototype;function l(t){var e=t.source;return t.visible&&(n.isPlainObject(e)||(\"string\"==typeof e||Array.isArray(e))&&e.length>0)}function c(t){var e={},r={};switch(t.type){case\"circle\":n.extendFlat(r,{\"circle-radius\":t.circle.radius,\"circle-color\":t.color,\"circle-opacity\":t.opacity});break;case\"line\":n.extendFlat(r,{\"line-width\":t.line.width,\"line-color\":t.color,\"line-opacity\":t.opacity,\"line-dasharray\":t.line.dash});break;case\"fill\":n.extendFlat(r,{\"fill-color\":t.color,\"fill-outline-color\":t.fill.outlinecolor,\"fill-opacity\":t.opacity});break;case\"symbol\":var a=t.symbol,o=i(a.textposition,a.iconsize);n.extendFlat(e,{\"icon-image\":a.icon+\"-15\",\"icon-size\":a.iconsize/10,\"text-field\":a.text,\"text-size\":a.textfont.size,\"text-anchor\":o.anchor,\"text-offset\":o.offset,\"symbol-placement\":a.placement}),n.extendFlat(r,{\"icon-color\":t.color,\"text-color\":a.textfont.color,\"text-opacity\":t.opacity})}return{layout:e,paint:r}}s.update=function(t){this.visible?this.needsNewSource(t)?(this.removeLayer(),this.updateSource(t),this.updateLayer(t)):this.needsNewLayer(t)?this.updateLayer(t):this.updateStyle(t):(this.updateSource(t),this.updateLayer(t)),this.visible=l(t)},s.needsNewSource=function(t){return this.sourceType!==t.sourcetype||this.source!==t.source||this.layerType!==t.type},s.needsNewLayer=function(t){return this.layerType!==t.type||this.below!==this.subplot.belowLookup[\"layout-\"+this.index]},s.updateSource=function(t){var e=this.subplot.map;if(e.getSource(this.idSource)&&e.removeSource(this.idSource),this.sourceType=t.sourcetype,this.source=t.source,l(t)){var r=function(t){var e,r=t.sourcetype,n=t.source,i={type:r};\"geojson\"===r?e=\"data\":\"vector\"===r?e=\"string\"==typeof n?\"url\":\"tiles\":\"raster\"===r?(e=\"tiles\",i.tileSize=256):\"image\"===r&&(e=\"url\",i.coordinates=t.coordinates);i[e]=n,t.sourceattribution&&(i.attribution=t.sourceattribution);return i}(t);e.addSource(this.idSource,r)}},s.updateLayer=function(t){var e,r=this.subplot,n=c(t),i=this.subplot.belowLookup[\"layout-\"+this.index];if(\"traces\"===i)for(var o=r.getMapLayers(),s=0;s<o.length;s++){var u=o[s].id;if(\"string\"==typeof u&&0===u.indexOf(a.traceLayerPrefix)){e=u;break}}else e=i;this.removeLayer(),l(t)&&r.addLayer({id:this.idLayer,source:this.idSource,\"source-layer\":t.sourcelayer||\"\",type:t.type,minzoom:t.minzoom,maxzoom:t.maxzoom,layout:n.layout,paint:n.paint},e),this.layerType=t.type,this.below=i},s.updateStyle=function(t){if(l(t)){var e=c(t);this.subplot.setOptions(this.idLayer,\"setLayoutProperty\",e.layout),this.subplot.setOptions(this.idLayer,\"setPaintProperty\",e.paint)}},s.removeLayer=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer)},s.dispose=function(){var t=this.subplot.map;t.removeLayer(this.idLayer),t.removeSource(this.idSource)},e.exports=function(t,e,r){var n=new o(t,e);return n.update(r),n}},{\"../../lib\":719,\"./constants\":820,\"./convert_text_opts\":821}],824:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\").defaultLine,a=t(\"../domain\").attributes,o=t(\"../font_attributes\"),s=t(\"../../traces/scatter/attributes\").textposition,l=t(\"../../plot_api/edit_types\").overrideAll,c=t(\"../../plot_api/plot_template\").templatedArray,u=t(\"./constants\"),h=o({});h.family.dflt=\"Open Sans Regular, Arial Unicode MS Regular\",(e.exports=l({_arrayAttrRegexps:[n.counterRegex(\"mapbox\",\".layers\",!0)],domain:a({name:\"mapbox\"}),accesstoken:{valType:\"string\",noBlank:!0,strict:!0},style:{valType:\"any\",values:u.styleValuesMapbox.concat(u.styleValuesNonMapbox),dflt:u.styleValueDflt},center:{lon:{valType:\"number\",dflt:0},lat:{valType:\"number\",dflt:0}},zoom:{valType:\"number\",dflt:1},bearing:{valType:\"number\",dflt:0},pitch:{valType:\"number\",dflt:0},layers:c(\"layer\",{visible:{valType:\"boolean\",dflt:!0},sourcetype:{valType:\"enumerated\",values:[\"geojson\",\"vector\",\"raster\",\"image\"],dflt:\"geojson\"},source:{valType:\"any\"},sourcelayer:{valType:\"string\",dflt:\"\"},sourceattribution:{valType:\"string\"},type:{valType:\"enumerated\",values:[\"circle\",\"line\",\"fill\",\"symbol\",\"raster\"],dflt:\"circle\"},coordinates:{valType:\"any\"},below:{valType:\"string\"},color:{valType:\"color\",dflt:i},opacity:{valType:\"number\",min:0,max:1,dflt:1},minzoom:{valType:\"number\",min:0,max:24,dflt:0},maxzoom:{valType:\"number\",min:0,max:24,dflt:24},circle:{radius:{valType:\"number\",dflt:15}},line:{width:{valType:\"number\",dflt:2},dash:{valType:\"data_array\"}},fill:{outlinecolor:{valType:\"color\",dflt:i}},symbol:{icon:{valType:\"string\",dflt:\"marker\"},iconsize:{valType:\"number\",dflt:10},text:{valType:\"string\",dflt:\"\"},placement:{valType:\"enumerated\",values:[\"point\",\"line\",\"line-center\"],dflt:\"point\"},textfont:h,textposition:n.extendFlat({},s,{arrayOk:!1})}})},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../traces/scatter/attributes\":1112,\"../domain\":792,\"../font_attributes\":793,\"./constants\":820}],825:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../subplot_defaults\"),a=t(\"../array_container_defaults\"),o=t(\"./layout_attributes\");function s(t,e,r,n){r(\"accesstoken\",n.accessToken),r(\"style\"),r(\"center.lon\"),r(\"center.lat\"),r(\"zoom\"),r(\"bearing\"),r(\"pitch\"),a(t,e,{name:\"layers\",handleItemDefaults:l}),e._input=t}function l(t,e){function r(r,i){return n.coerce(t,e,o.layers,r,i)}if(r(\"visible\")){var i,a=r(\"sourcetype\"),s=\"raster\"===a||\"image\"===a;r(\"source\"),r(\"sourceattribution\"),\"vector\"===a&&r(\"sourcelayer\"),\"image\"===a&&r(\"coordinates\"),s&&(i=\"raster\");var l=r(\"type\",i);s&&\"raster\"!==l&&(l=e.type=\"raster\",n.log(\"Source types *raster* and *image* must drawn *raster* layer type.\")),r(\"below\"),r(\"color\"),r(\"opacity\"),r(\"minzoom\"),r(\"maxzoom\"),\"circle\"===l&&r(\"circle.radius\"),\"line\"===l&&(r(\"line.width\"),r(\"line.dash\")),\"fill\"===l&&r(\"fill.outlinecolor\"),\"symbol\"===l&&(r(\"symbol.icon\"),r(\"symbol.iconsize\"),r(\"symbol.text\"),n.coerceFont(r,\"symbol.textfont\"),r(\"symbol.textposition\"),r(\"symbol.placement\"))}}e.exports=function(t,e,r){i(t,e,r,{type:\"mapbox\",attributes:o,handleDefaults:s,partition:\"y\",accessToken:e._mapboxAccessToken})}},{\"../../lib\":719,\"../array_container_defaults\":763,\"../subplot_defaults\":842,\"./layout_attributes\":824}],826:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"d3\"),a=t(\"../../components/fx\"),o=t(\"../../lib\"),s=t(\"../../registry\"),l=t(\"../cartesian/axes\"),c=t(\"../../components/dragelement\"),u=t(\"../cartesian/select\").prepSelect,h=t(\"../cartesian/select\").selectOnClick,f=t(\"./constants\"),p=t(\"./layers\");function d(t,e){this.id=e,this.gd=t;var r=t._fullLayout,n=t._context;this.container=r._glcontainer.node(),this.isStatic=n.staticPlot,this.uid=r._uid+\"-\"+this.id,this.div=null,this.xaxis=null,this.yaxis=null,this.createFramework(r),this.map=null,this.accessToken=null,this.styleObj=null,this.traceHash={},this.layerList=[],this.belowLookup={}}var g=d.prototype;g.plot=function(t,e,r){var n,i=this,a=e[i.id];i.map&&a.accesstoken!==i.accessToken&&(i.map.remove(),i.map=null,i.styleObj=null,i.traceHash=[],i.layerList={}),n=i.map?new Promise(function(r,n){i.updateMap(t,e,r,n)}):new Promise(function(r,n){i.createMap(t,e,r,n)}),r.push(n)},g.createMap=function(t,e,r,i){var a=this,o=e[a.id],s=a.styleObj=m(o.style);a.accessToken=o.accesstoken;var l=a.map=new n.Map({container:a.div,style:s.style,center:x(o.center),zoom:o.zoom,bearing:o.bearing,pitch:o.pitch,interactive:!a.isStatic,preserveDrawingBuffer:a.isStatic,doubleClickZoom:!1,boxZoom:!1,attributionControl:!1}).addControl(new n.AttributionControl({compact:!0}));l._canvas.style.left=\"0px\",l._canvas.style.top=\"0px\",a.rejectOnError(i),a.isStatic||a.initFx(t,e);var c=[];c.push(new Promise(function(t){l.once(\"load\",t)})),c=c.concat(a.fetchMapData(t,e)),Promise.all(c).then(function(){a.fillBelowLookup(t,e),a.updateData(t),a.updateLayout(e),a.resolveOnRender(r)}).catch(i)},g.fetchMapData=function(t){var e=[];function r(t){return new Promise(function(e,r){i.json(t,function(n,i){if(n){delete PlotlyGeoAssets[t];var a=404===n.status?'GeoJSON at URL \"'+t+'\" does not exist.':\"Unexpected error while fetching from \"+t;return r(new Error(a))}PlotlyGeoAssets[t]=i,e(i)})})}for(var n=0;n<t.length;n++){var a=t[n][0].trace.geojson;\"string\"!=typeof a||PlotlyGeoAssets[a]||(PlotlyGeoAssets[a]=\"pending\",e.push(r(a)))}return e},g.updateMap=function(t,e,r,n){var i=this,a=i.map,o=e[this.id];i.rejectOnError(n);var s=[],l=m(o.style);i.styleObj.id!==l.id&&(i.styleObj=l,a.setStyle(l.style),i.traceHash={},s.push(new Promise(function(t){a.once(\"styledata\",t)}))),s=s.concat(i.fetchMapData(t,e)),Promise.all(s).then(function(){i.fillBelowLookup(t,e),i.updateData(t),i.updateLayout(e),i.resolveOnRender(r)}).catch(n)},g.fillBelowLookup=function(t,e){var r,n,i=e[this.id].layers,a=this.belowLookup={},o=!1;for(r=0;r<t.length;r++){var s=t[r][0].trace,l=s._module;\"string\"==typeof s.below?n=s.below:l.getBelow&&(n=l.getBelow(s,this)),\"\"===n&&(o=!0),a[\"trace-\"+s.uid]=n||\"\"}for(r=0;r<i.length;r++){var c=i[r];n=\"string\"==typeof c.below?c.below:o?\"traces\":\"\",a[\"layout-\"+r]=n}var u,h,f={};for(u in a)f[n=a[u]]?f[n].push(u):f[n]=[u];for(n in f){var p=f[n];if(p.length>1)for(r=0;r<p.length;r++)0===(u=p[r]).indexOf(\"trace-\")?(h=u.split(\"trace-\")[1],this.traceHash[h]&&(this.traceHash[h].below=null)):0===u.indexOf(\"layout-\")&&(h=u.split(\"layout-\")[1],this.layerList[h]&&(this.layerList[h].below=null))}};var v={choroplethmapbox:0,densitymapbox:1,scattermapbox:2};function m(t){var e={};return o.isPlainObject(t)?(e.id=t.id,e.style=t):\"string\"==typeof t?(e.id=t,-1!==f.styleValuesMapbox.indexOf(t)?e.style=y(t):f.stylesNonMapbox[t]?e.style=f.stylesNonMapbox[t]:e.style=t):(e.id=f.styleValueDflt,e.style=y(f.styleValueDflt)),e.transition={duration:0,delay:0},e}function y(t){return f.styleUrlPrefix+t+\"-\"+f.styleUrlSuffix}function x(t){return[t.lon,t.lat]}g.updateData=function(t){var e,r,n,i,a=this.traceHash,o=t.slice().sort(function(t,e){return v[t[0].trace.type]-v[e[0].trace.type]});for(n=0;n<o.length;n++){var s=o[n];(e=a[(r=s[0].trace).uid])?e.update(s):r._module&&(a[r.uid]=r._module.plot(this,s))}var l=Object.keys(a);t:for(n=0;n<l.length;n++){var c=l[n];for(i=0;i<t.length;i++)if(c===(r=t[i][0].trace).uid)continue t;(e=a[c]).dispose(),delete a[c]}},g.updateLayout=function(t){var e=this.map,r=t[this.id];e.setCenter(x(r.center)),e.setZoom(r.zoom),e.setBearing(r.bearing),e.setPitch(r.pitch),this.updateLayers(t),this.updateFramework(t),this.updateFx(t),this.map.resize(),this.gd._context._scrollZoom.mapbox?e.scrollZoom.enable():e.scrollZoom.disable()},g.resolveOnRender=function(t){var e=this.map;e.on(\"render\",function r(){e.loaded()&&(e.off(\"render\",r),setTimeout(t,0))})},g.rejectOnError=function(t){var e=this.map;function r(){t(new Error(f.mapOnErrorMsg))}e.once(\"error\",r),e.once(\"style.error\",r),e.once(\"source.error\",r),e.once(\"tile.error\",r),e.once(\"layer.error\",r)},g.createFramework=function(t){var e=this,r=e.div=document.createElement(\"div\");r.id=e.uid,r.style.position=\"absolute\",e.container.appendChild(r),e.xaxis={_id:\"x\",c2p:function(t){return e.project(t).x}},e.yaxis={_id:\"y\",c2p:function(t){return e.project(t).y}},e.updateFramework(t),e.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},l.setConvert(e.mockAxis,t)},g.initFx=function(t,e){var r=this,n=r.gd,i=r.map,o=!1;function l(){a.loneUnhover(e._hoverlayer)}function c(){var t=r.getView();n.emit(\"plotly_relayouting\",r.getViewEdits(t))}i.on(\"moveend\",function(t){if(r.map){var e=n._fullLayout;if(t.originalEvent||o){var i=e[r.id];s.call(\"_storeDirectGUIEdit\",n.layout,e._preGUI,r.getViewEdits(i));var a=r.getView();i._input.center=i.center=a.center,i._input.zoom=i.zoom=a.zoom,i._input.bearing=i.bearing=a.bearing,i._input.pitch=i.pitch=a.pitch,n.emit(\"plotly_relayout\",r.getViewEdits(a))}o=!1,e._rehover&&e._rehover()}}),i.on(\"wheel\",function(){o=!0}),i.on(\"mousemove\",function(t){var e=r.div.getBoundingClientRect();t.clientX=t.point.x+e.left,t.clientY=t.point.y+e.top,t.target.getBoundingClientRect=function(){return e},r.xaxis.p2c=function(){return t.lngLat.lng},r.yaxis.p2c=function(){return t.lngLat.lat},n._fullLayout._rehover=function(){n._fullLayout._hoversubplot===r.id&&a.hover(n,t,r.id)},a.hover(n,t,r.id),n._fullLayout._hoversubplot=r.id}),i.on(\"dragstart\",l),i.on(\"zoomstart\",l),i.on(\"mouseout\",function(){n._fullLayout._hoversubplot=null}),i.on(\"drag\",c),i.on(\"zoom\",c),i.on(\"dblclick\",function(){var t=n._fullLayout[r.id];s.call(\"_storeDirectGUIEdit\",n.layout,n._fullLayout._preGUI,r.getViewEdits(t));var e=r.viewInitial;i.setCenter(x(e.center)),i.setZoom(e.zoom),i.setBearing(e.bearing),i.setPitch(e.pitch);var a=r.getView();t._input.center=t.center=a.center,t._input.zoom=t.zoom=a.zoom,t._input.bearing=t.bearing=a.bearing,t._input.pitch=t.pitch=a.pitch,n.emit(\"plotly_doubleclick\",null),n.emit(\"plotly_relayout\",r.getViewEdits(a))}),r.clearSelect=function(){n._fullLayout._zoomlayer.selectAll(\".select-outline\").remove()},r.onClickInPanFn=function(t){return function(e){var i=n._fullLayout.clickmode;i.indexOf(\"select\")>-1&&h(e.originalEvent,n,[r.xaxis],[r.yaxis],r.id,t),i.indexOf(\"event\")>-1&&a.click(n,e.originalEvent)}}},g.updateFx=function(t){var e=this,r=e.map,n=e.gd;if(!e.isStatic){var i,a=t.dragmode;i=\"select\"===a?function(t,r){(t.range={})[e.id]=[l([r.xmin,r.ymin]),l([r.xmax,r.ymax])]}:function(t,r,n){(t.lassoPoints={})[e.id]=n.filtered.map(l)};var s=e.dragOptions;e.dragOptions=o.extendDeep(s||{},{element:e.div,gd:n,plotinfo:{id:e.id,xaxis:e.xaxis,yaxis:e.yaxis,fillRangeItems:i},xaxes:[e.xaxis],yaxes:[e.yaxis],subplot:e.id}),r.off(\"click\",e.onClickInPanHandler),\"select\"===a||\"lasso\"===a?(r.dragPan.disable(),r.on(\"zoomstart\",e.clearSelect),e.dragOptions.prepFn=function(t,r,n){u(t,r,n,e.dragOptions,a)},c.init(e.dragOptions)):(r.dragPan.enable(),r.off(\"zoomstart\",e.clearSelect),e.div.onmousedown=null,e.onClickInPanHandler=e.onClickInPanFn(e.dragOptions),r.on(\"click\",e.onClickInPanHandler))}function l(t){var r=e.map.unproject(t);return[r.lng,r.lat]}},g.updateFramework=function(t){var e=t[this.id].domain,r=t._size,n=this.div.style;n.width=r.w*(e.x[1]-e.x[0])+\"px\",n.height=r.h*(e.y[1]-e.y[0])+\"px\",n.left=r.l+e.x[0]*r.w+\"px\",n.top=r.t+(1-e.y[1])*r.h+\"px\",this.xaxis._offset=r.l+e.x[0]*r.w,this.xaxis._length=r.w*(e.x[1]-e.x[0]),this.yaxis._offset=r.t+(1-e.y[1])*r.h,this.yaxis._length=r.h*(e.y[1]-e.y[0])},g.updateLayers=function(t){var e,r=t[this.id].layers,n=this.layerList;if(r.length!==n.length){for(e=0;e<n.length;e++)n[e].dispose();for(n=this.layerList=[],e=0;e<r.length;e++)n.push(p(this,e,r[e]))}else for(e=0;e<r.length;e++)n[e].update(r[e])},g.destroy=function(){this.map&&(this.map.remove(),this.map=null,this.container.removeChild(this.div))},g.toImage=function(){return this.map.stop(),this.map.getCanvas().toDataURL()},g.setOptions=function(t,e,r){for(var n in r)this.map[e](t,n,r[n])},g.getMapLayers=function(){return this.map.getStyle().layers},g.addLayer=function(t,e){var r=this.map;if(\"string\"==typeof e){if(\"\"===e)return void r.addLayer(t,e);for(var n=this.getMapLayers(),i=0;i<n.length;i++)if(e===n[i].id)return void r.addLayer(t,e);o.warn([\"Trying to add layer with *below* value\",e,\"referencing a layer that does not exist\",\"or that does not yet exist.\"].join(\" \"))}r.addLayer(t)},g.project=function(t){return this.map.project(new n.LngLat(t[0],t[1]))},g.getView=function(){var t=this.map,e=t.getCenter();return{center:{lon:e.lng,lat:e.lat},zoom:t.getZoom(),bearing:t.getBearing(),pitch:t.getPitch()}},g.getViewEdits=function(t){for(var e=this.id,r=[\"center\",\"zoom\",\"bearing\",\"pitch\"],n={},i=0;i<r.length;i++){var a=r[i];n[e+\".\"+a]=t[a]}return n},e.exports=d},{\"../../components/dragelement\":611,\"../../components/fx\":632,\"../../lib\":719,\"../../registry\":847,\"../cartesian/axes\":767,\"../cartesian/select\":784,\"./constants\":820,\"./layers\":823,d3:163,\"mapbox-gl\":426}],827:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType;return{t:{valType:\"number\",dflt:0,editType:e},r:{valType:\"number\",dflt:0,editType:e},b:{valType:\"number\",dflt:0,editType:e},l:{valType:\"number\",dflt:0,editType:e},editType:e}}},{}],828:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../registry\"),o=t(\"../plot_api/plot_schema\"),s=t(\"../plot_api/plot_template\"),l=t(\"../lib\"),c=t(\"../components/color\"),u=t(\"../constants/numerical\").BADNUM,h=t(\"./cartesian/axis_ids\"),f=t(\"./animation_attributes\"),p=t(\"./frame_attributes\"),d=l.relinkPrivateKeys,g=l._,v=e.exports={};l.extendFlat(v,a),v.attributes=t(\"./attributes\"),v.attributes.type.values=v.allTypes,v.fontAttrs=t(\"./font_attributes\"),v.layoutAttributes=t(\"./layout_attributes\"),v.fontWeight=\"normal\";var m=v.transformsRegistry,y=t(\"./command\");v.executeAPICommand=y.executeAPICommand,v.computeAPICommandBindings=y.computeAPICommandBindings,v.manageCommandObserver=y.manageCommandObserver,v.hasSimpleAPICommandBindings=y.hasSimpleAPICommandBindings,v.redrawText=function(t){var e=(t=l.getGraphDiv(t))._fullLayout||{};if(!(!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r))return new Promise(function(e){setTimeout(function(){a.getComponentMethod(\"annotations\",\"draw\")(t),a.getComponentMethod(\"legend\",\"draw\")(t),a.getComponentMethod(\"colorbar\",\"draw\")(t),e(v.previousPromises(t))},300)})},v.resize=function(t){return t=l.getGraphDiv(t),new Promise(function(e,r){t&&!l.isHidden(t)||r(new Error(\"Resize must be passed a displayed plot div element.\")),t._redrawTimer&&clearTimeout(t._redrawTimer),t._redrawTimer=setTimeout(function(){if(!t.layout||t.layout.width&&t.layout.height||l.isHidden(t))e(t);else{delete t.layout.width,delete t.layout.height;var r=t.changed;t.autoplay=!0,a.call(\"relayout\",t,{autosize:!0}).then(function(){t.changed=r,e(t)})}},100)})},v.previousPromises=function(t){if((t._promises||[]).length)return Promise.all(t._promises).then(function(){t._promises=[]})},v.addLinks=function(t){if(t._context.showLink||t._context.showSources){var e=t._fullLayout,r=l.ensureSingle(e._paper,\"text\",\"js-plot-link-container\",function(t){t.style({\"font-family\":'\"Open Sans\", Arial, sans-serif',\"font-size\":\"12px\",fill:c.defaultLine,\"pointer-events\":\"all\"}).each(function(){var t=n.select(this);t.append(\"tspan\").classed(\"js-link-to-tool\",!0),t.append(\"tspan\").classed(\"js-link-spacer\",!0),t.append(\"tspan\").classed(\"js-sourcelinks\",!0)})}),i=r.node(),a={y:e._paper.attr(\"height\")-9};document.body.contains(i)&&i.getComputedTextLength()>=e.width-20?(a[\"text-anchor\"]=\"start\",a.x=5):(a[\"text-anchor\"]=\"end\",a.x=e._paper.attr(\"width\")-7),r.attr(a);var o=r.select(\".js-link-to-tool\"),s=r.select(\".js-link-spacer\"),u=r.select(\".js-sourcelinks\");t._context.showSources&&t._context.showSources(t),t._context.showLink&&function(t,e){e.text(\"\");var r=e.append(\"a\").attr({\"xlink:xlink:href\":\"#\",class:\"link--impt link--embedview\",\"font-weight\":\"bold\"}).text(t._context.linkText+\" \"+String.fromCharCode(187));if(t._context.sendData)r.on(\"click\",function(){v.sendDataToCloud(t)});else{var n=window.location.pathname.split(\"/\"),i=window.location.search;r.attr({\"xlink:xlink:show\":\"new\",\"xlink:xlink:href\":\"/\"+n[2].split(\".\")[0]+\"/\"+n[1]+i})}}(t,o),s.text(o.text()&&u.text()?\" - \":\"\")}},v.sendDataToCloud=function(t){t.emit(\"plotly_beforeexport\");var e=(window.PLOTLYENV||{}).BASE_URL||t._context.plotlyServerURL,r=n.select(t).append(\"div\").attr(\"id\",\"hiddenform\").style(\"display\",\"none\"),i=r.append(\"form\").attr({action:e+\"/external\",method:\"post\",target:\"_blank\"});return i.append(\"input\").attr({type:\"text\",name:\"data\"}).node().value=v.graphJson(t,!1,\"keepdata\"),i.node().submit(),r.remove(),t.emit(\"plotly_afterexport\"),!1};var x=[\"days\",\"shortDays\",\"months\",\"shortMonths\",\"periods\",\"dateTime\",\"date\",\"time\",\"decimal\",\"thousands\",\"grouping\",\"currency\"],b=[\"year\",\"month\",\"dayMonth\",\"dayMonthYear\"];function _(t,e){var r=t._context.locale,n=!1,i={};function o(t){for(var r=!0,a=0;a<e.length;a++){var o=e[a];i[o]||(t[o]?i[o]=t[o]:r=!1)}r&&(n=!0)}for(var s=0;s<2;s++){for(var l=t._context.locales,c=0;c<2;c++){var u=(l[r]||{}).format;if(u&&(o(u),n))break;l=a.localeRegistry}var h=r.split(\"-\")[0];if(n||h===r)break;r=h}return n||o(a.localeRegistry.en.format),i}function w(t,e){var r={_fullLayout:e},n=\"x\"===t._id.charAt(0),i=t._mainAxis._anchorAxis,a=\"\",o=\"\",s=\"\";if(i&&(s=i._mainAxis._id,a=n?t._id+s:s+t._id),!a||!e._plots[a]){a=\"\";for(var l=t._counterAxes,c=0;c<l.length;c++){var u=l[c],f=n?t._id+u:u+t._id;o||(o=f);var p=h.getFromId(r,u);if(s&&p.overlaying===s){a=f;break}}}return a||o}function k(t){var e=t.transforms;if(Array.isArray(e)&&e.length)for(var r=0;r<e.length;r++){var n=e[r],i=n._module||m[n.type];if(i&&i.makesData)return!0}return!1}function T(t,e,r,n){for(var i=t.transforms,a=[t],o=0;o<i.length;o++){var s=i[o],l=m[s.type];l&&l.transform&&(a=l.transform(a,{transform:s,fullTrace:t,fullData:e,layout:r,fullLayout:n,transformIndex:o}))}return a}function A(t){var e=t.margin;if(!t._size){var r=t._size={l:Math.round(e.l),r:Math.round(e.r),t:Math.round(e.t),b:Math.round(e.b),p:Math.round(e.pad)};r.w=Math.round(t.width)-r.l-r.r,r.h=Math.round(t.height)-r.t-r.b}t._pushmargin||(t._pushmargin={}),t._pushmarginIds||(t._pushmarginIds={})}v.supplyDefaults=function(t,e){var r=e&&e.skipUpdateCalc,i=t._fullLayout||{};if(i._skipDefaults)delete i._skipDefaults;else{var o,s=t._fullLayout={},c=t.layout||{},u=t._fullData||[],h=t._fullData=[],f=t.data||[],p=t.calcdata||[],m=t._context||{};t._transitionData||v.createTransitionData(t),s._dfltTitle={plot:g(t,\"Click to enter Plot title\"),x:g(t,\"Click to enter X axis title\"),y:g(t,\"Click to enter Y axis title\"),colorbar:g(t,\"Click to enter Colorscale title\"),annotation:g(t,\"new text\")},s._traceWord=g(t,\"trace\");var y=_(t,x);if(s._mapboxAccessToken=m.mapboxAccessToken,i._initialAutoSizeIsDone){var w=i.width,k=i.height;v.supplyLayoutGlobalDefaults(c,s,y),c.width||(s.width=w),c.height||(s.height=k),v.sanitizeMargins(s)}else{v.supplyLayoutGlobalDefaults(c,s,y);var T=!c.width||!c.height,M=s.autosize,S=m.autosizable;T&&(M||S)?v.plotAutoSize(t,c,s):T&&v.sanitizeMargins(s),!M&&T&&(c.width=s.width,c.height=s.height)}s._d3locale=function(t,e){return t.decimal=e.charAt(0),t.thousands=e.charAt(1),n.locale(t)}(y,s.separators),s._extraFormat=_(t,b),s._initialAutoSizeIsDone=!0,s._dataLength=f.length,s._modules=[],s._visibleModules=[],s._basePlotModules=[];var E=s._subplots=function(){var t,e,r=a.collectableSubplotTypes,n={};if(!r){r=[];var i=a.subplotsRegistry;for(var o in i){var s=i[o],c=s.attr;if(c&&(r.push(o),Array.isArray(c)))for(e=0;e<c.length;e++)l.pushUnique(r,c[e])}}for(t=0;t<r.length;t++)n[r[t]]=[];return n}(),C=s._splomAxes={x:{},y:{}},L=s._splomSubplots={};s._splomGridDflt={},s._scatterStackOpts={},s._firstScatter={},s._alignmentOpts={},s._colorAxes={},s._requestRangeslider={},s._traceUids=function(t,e){var r,n,i=e.length,a=[];for(r=0;r<t.length;r++){var o=t[r]._fullInput;o!==n&&a.push(o),n=o}var s=a.length,c=new Array(i),u={};function h(t,e){c[e]=t,u[t]=1}function f(t,e){if(t&&\"string\"==typeof t&&!u[t])return h(t,e),!0}for(r=0;r<i;r++){var p=e[r].uid;\"number\"==typeof p&&(p=String(p)),f(p,r)||(r<s&&f(a[r].uid,r)||h(l.randstr(u),r))}return c}(u,f),s._globalTransforms=(t._context||{}).globalTransforms,v.supplyDataDefaults(f,h,c,s);var P=Object.keys(C.x),O=Object.keys(C.y);if(P.length>1&&O.length>1){for(a.getComponentMethod(\"grid\",\"sizeDefaults\")(c,s),o=0;o<P.length;o++)l.pushUnique(E.xaxis,P[o]);for(o=0;o<O.length;o++)l.pushUnique(E.yaxis,O[o]);for(var z in L)l.pushUnique(E.cartesian,z)}if(s._has=v._hasPlotType.bind(s),u.length===h.length)for(o=0;o<h.length;o++)d(h[o],u[o]);v.supplyLayoutModuleDefaults(c,s,h,t._transitionData);var I=s._visibleModules,D=[];for(o=0;o<I.length;o++){var R=I[o].crossTraceDefaults;R&&l.pushUnique(D,R)}for(o=0;o<D.length;o++)D[o](h,s);s._hasOnlyLargeSploms=1===s._basePlotModules.length&&\"splom\"===s._basePlotModules[0].name&&P.length>15&&O.length>15&&0===s.shapes.length&&0===s.images.length,s._hasCartesian=s._has(\"cartesian\"),s._hasGeo=s._has(\"geo\"),s._hasGL3D=s._has(\"gl3d\"),s._hasGL2D=s._has(\"gl2d\"),s._hasTernary=s._has(\"ternary\"),s._hasPie=s._has(\"pie\"),v.linkSubplots(h,s,u,i),v.cleanPlot(h,s,u,i),i._zoomlayer&&!t._dragging&&i._zoomlayer.selectAll(\".select-outline\").remove(),function(t,e){var r,n=[];e.meta&&(r=e._meta={meta:e.meta,layout:{meta:e.meta}});for(var i=0;i<t.length;i++){var a=t[i];a.meta?n[a.index]=a._meta={meta:a.meta}:e.meta&&(a._meta={meta:e.meta}),e.meta&&(a._meta.layout={meta:e.meta})}n.length&&(r||(r=e._meta={}),r.data=n)}(h,s),d(s,i),a.getComponentMethod(\"colorscale\",\"crossTraceDefaults\")(h,s),s._preGUI||(s._preGUI={}),s._tracePreGUI||(s._tracePreGUI={});var F,B=s._tracePreGUI,N={};for(F in B)N[F]=\"old\";for(o=0;o<h.length;o++)N[F=h[o]._fullInput.uid]||(B[F]={}),N[F]=\"new\";for(F in N)\"old\"===N[F]&&delete B[F];A(s),a.getComponentMethod(\"rangeslider\",\"makeData\")(s),r||p.length!==h.length||v.supplyDefaultsUpdateCalc(p,h)}},v.supplyDefaultsUpdateCalc=function(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=(t[r]||[])[0];if(i&&i.trace){var a=i.trace;if(a._hasCalcTransform){var o,s,c,u=a._arrayAttrs;for(o=0;o<u.length;o++)s=u[o],c=l.nestedProperty(a,s).get().slice(),l.nestedProperty(n,s).set(c)}i.trace=n}}},v.createTransitionData=function(t){t._transitionData||(t._transitionData={}),t._transitionData._frames||(t._transitionData._frames=[]),t._transitionData._frameHash||(t._transitionData._frameHash={}),t._transitionData._counter||(t._transitionData._counter=0),t._transitionData._interruptCallbacks||(t._transitionData._interruptCallbacks=[])},v._hasPlotType=function(t){var e,r=this._basePlotModules||[];for(e=0;e<r.length;e++)if(r[e].name===t)return!0;var n=this._modules||[];for(e=0;e<n.length;e++){var i=n[e].name;if(i===t)return!0;var o=a.modules[i];if(o&&o.categories[t])return!0}return!1},v.cleanPlot=function(t,e,r,n){var i,a,o=n._basePlotModules||[];for(i=0;i<o.length;i++){var s=o[i];s.clean&&s.clean(t,e,r,n)}var l=n._has&&n._has(\"gl\"),c=e._has&&e._has(\"gl\");l&&!c&&void 0!==n._glcontainer&&(n._glcontainer.selectAll(\".gl-canvas\").remove(),n._glcontainer.selectAll(\".no-webgl\").remove(),n._glcanvas=null);var u=!!n._infolayer;t:for(i=0;i<r.length;i++){var h=r[i].uid;for(a=0;a<t.length;a++){if(h===t[a].uid)continue t}u&&n._infolayer.select(\".cb\"+h).remove()}},v.linkSubplots=function(t,e,r,n){var i,a,o=n._plots||{},s=e._plots={},c=e._subplots,u={_fullData:t,_fullLayout:e},f=c.cartesian.concat(c.gl2d||[]);for(i=0;i<f.length;i++){var p,d=f[i],g=o[d],v=h.getFromId(u,d,\"x\"),m=h.getFromId(u,d,\"y\");for(g?p=s[d]=g:(p=s[d]={}).id=d,v._counterAxes.push(m._id),m._counterAxes.push(v._id),v._subplotsWith.push(d),m._subplotsWith.push(d),p.xaxis=v,p.yaxis=m,p._hasClipOnAxisFalse=!1,a=0;a<t.length;a++){var y=t[a];if(y.xaxis===p.xaxis._id&&y.yaxis===p.yaxis._id&&!1===y.cliponaxis){p._hasClipOnAxisFalse=!0;break}}}var x,b=h.list(u,null,!0);for(i=0;i<b.length;i++){var _=null;(x=b[i]).overlaying&&(_=h.getFromId(u,x.overlaying))&&_.overlaying&&(x.overlaying=!1,_=null),x._mainAxis=_||x,_&&(x.domain=_.domain.slice()),x._anchorAxis=\"free\"===x.anchor?null:h.getFromId(u,x.anchor)}for(i=0;i<b.length;i++)(x=b[i])._counterAxes.sort(h.idSort),x._subplotsWith.sort(l.subplotSort),x._mainSubplot=w(x,e)},v.clearExpandedTraceDefaultColors=function(t){var e,r,n;for(r=[],(e=t._module._colorAttrs)||(t._module._colorAttrs=e=[],o.crawl(t._module.attributes,function(t,n,i,a){r[a]=n,r.length=a+1,\"color\"===t.valType&&void 0===t.dflt&&e.push(r.join(\".\"))})),n=0;n<e.length;n++){l.nestedProperty(t,\"_input.\"+e[n]).get()||l.nestedProperty(t,e[n]).set(null)}},v.supplyDataDefaults=function(t,e,r,n){var i,o,c,u=n._modules,h=n._visibleModules,f=n._basePlotModules,p=0,g=0;function m(t){e.push(t);var r=t._module;r&&(l.pushUnique(u,r),!0===t.visible&&l.pushUnique(h,r),l.pushUnique(f,t._module.basePlotModule),p++,!1!==t._input.visible&&g++)}n._transformModules=[];var y={},x=[],b=(r.template||{}).data||{},_=s.traceTemplater(b);for(i=0;i<t.length;i++){if(c=t[i],(o=_.newTrace(c)).uid=n._traceUids[i],v.supplyTraceDefaults(c,o,g,n,i),o.index=i,o._input=c,o._expandedIndex=p,o.transforms&&o.transforms.length)for(var w=!1!==c.visible&&!1===o.visible,k=T(o,e,r,n),A=0;A<k.length;A++){var M=k[A],S={_template:o._template,type:o.type,uid:o.uid+A};w&&!1===M.visible&&delete M.visible,v.supplyTraceDefaults(M,S,p,n,i),d(S,M),S.index=i,S._input=c,S._fullInput=o,S._expandedIndex=p,S._expandedInput=M,m(S)}else o._fullInput=o,o._expandedInput=o,m(o);a.traceIs(o,\"carpetAxis\")&&(y[o.carpet]=o),a.traceIs(o,\"carpetDependent\")&&x.push(i)}for(i=0;i<x.length;i++)if((o=e[x[i]]).visible){var E=y[o.carpet];o._carpet=E,E&&E.visible?(o.xaxis=E.xaxis,o.yaxis=E.yaxis):o.visible=!1}},v.supplyAnimationDefaults=function(t){var e;t=t||{};var r={};function n(e,n){return l.coerce(t||{},r,f,e,n)}if(n(\"mode\"),n(\"direction\"),n(\"fromcurrent\"),Array.isArray(t.frame))for(r.frame=[],e=0;e<t.frame.length;e++)r.frame[e]=v.supplyAnimationFrameDefaults(t.frame[e]||{});else r.frame=v.supplyAnimationFrameDefaults(t.frame||{});if(Array.isArray(t.transition))for(r.transition=[],e=0;e<t.transition.length;e++)r.transition[e]=v.supplyAnimationTransitionDefaults(t.transition[e]||{});else r.transition=v.supplyAnimationTransitionDefaults(t.transition||{});return r},v.supplyAnimationFrameDefaults=function(t){var e={};function r(r,n){return l.coerce(t||{},e,f.frame,r,n)}return r(\"duration\"),r(\"redraw\"),e},v.supplyAnimationTransitionDefaults=function(t){var e={};function r(r,n){return l.coerce(t||{},e,f.transition,r,n)}return r(\"duration\"),r(\"easing\"),e},v.supplyFrameDefaults=function(t){var e={};function r(r,n){return l.coerce(t,e,p,r,n)}return r(\"group\"),r(\"name\"),r(\"traces\"),r(\"baseframe\"),r(\"data\"),r(\"layout\"),e},v.supplyTraceDefaults=function(t,e,r,n,i){var o,s=n.colorway||c.defaults,u=s[r%s.length];function h(r,n){return l.coerce(t,e,v.attributes,r,n)}var f=h(\"visible\");h(\"type\"),h(\"name\",n._traceWord+\" \"+i),h(\"uirevision\",n.uirevision);var p=v.getModule(e);if(e._module=p,p){var d=p.basePlotModule,g=d.attr,m=d.attributes;if(g&&m){var y=n._subplots,x=\"\";if(\"gl2d\"!==d.name||f){if(Array.isArray(g))for(o=0;o<g.length;o++){var b=g[o],_=l.coerce(t,e,m,b);y[b]&&l.pushUnique(y[b],_),x+=_}else x=l.coerce(t,e,m,g);y[d.name]&&l.pushUnique(y[d.name],x)}}}return f&&(h(\"customdata\"),h(\"ids\"),h(\"meta\"),a.traceIs(e,\"showLegend\")?(e._dfltShowLegend=!0,h(\"showlegend\"),h(\"legendgroup\")):e._dfltShowLegend=!1,p&&p.supplyDefaults(t,e,u,n),a.traceIs(e,\"noOpacity\")||h(\"opacity\"),a.traceIs(e,\"notLegendIsolatable\")&&(e.visible=!!e.visible),a.traceIs(e,\"noHover\")||(e.hovertemplate||l.coerceHoverinfo(t,e,n),\"parcats\"!==e.type&&a.getComponentMethod(\"fx\",\"supplyDefaults\")(t,e,u,n)),p&&p.selectPoints&&h(\"selectedpoints\"),v.supplyTransformDefaults(t,e,n)),e},v.hasMakesDataTransform=k,v.supplyTransformDefaults=function(t,e,r){if(e._length||k(t)){var n=r._globalTransforms||[],i=r._transformModules||[];if(Array.isArray(t.transforms)||0!==n.length)for(var a=t.transforms||[],o=n.concat(a),s=e.transforms=[],c=0;c<o.length;c++){var u,h=o[c],f=h.type,p=m[f],d=!(h._module&&h._module===p),g=p&&\"function\"==typeof p.transform;p||l.warn(\"Unrecognized transform type \"+f+\".\"),p&&p.supplyDefaults&&(d||g)?((u=p.supplyDefaults(h,e,r,t)).type=f,u._module=p,l.pushUnique(i,p)):u=l.extendFlat({},h),s.push(u)}}},v.supplyLayoutGlobalDefaults=function(t,e,r){function n(r,n){return l.coerce(t,e,v.layoutAttributes,r,n)}var i=t.template;l.isPlainObject(i)&&(e.template=i,e._template=i.layout,e._dataTemplate=i.data);var o=l.coerceFont(n,\"font\");n(\"title.text\",e._dfltTitle.plot),l.coerceFont(n,\"title.font\",{family:o.family,size:Math.round(1.4*o.size),color:o.color}),n(\"title.xref\"),n(\"title.yref\"),n(\"title.x\"),n(\"title.y\"),n(\"title.xanchor\"),n(\"title.yanchor\"),n(\"title.pad.t\"),n(\"title.pad.r\"),n(\"title.pad.b\"),n(\"title.pad.l\"),n(\"autosize\",!(t.width&&t.height)),n(\"width\"),n(\"height\"),n(\"margin.l\"),n(\"margin.r\"),n(\"margin.t\"),n(\"margin.b\"),n(\"margin.pad\"),n(\"margin.autoexpand\"),t.width&&t.height&&v.sanitizeMargins(e),a.getComponentMethod(\"grid\",\"sizeDefaults\")(t,e),n(\"paper_bgcolor\"),n(\"separators\",r.decimal+r.thousands),n(\"hidesources\"),n(\"colorway\"),n(\"datarevision\");var s=n(\"uirevision\");n(\"editrevision\",s),n(\"selectionrevision\",s),n(\"modebar.orientation\"),n(\"modebar.bgcolor\",c.addOpacity(e.paper_bgcolor,.5));var u=c.contrast(c.rgb(e.modebar.bgcolor));n(\"modebar.color\",c.addOpacity(u,.3)),n(\"modebar.activecolor\",c.addOpacity(u,.7)),n(\"modebar.uirevision\",s),n(\"meta\"),l.isPlainObject(t.transition)&&(n(\"transition.duration\"),n(\"transition.easing\"),n(\"transition.ordering\")),a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\"),a.getComponentMethod(\"fx\",\"supplyLayoutGlobalDefaults\")(t,e,n)},v.plotAutoSize=function(t,e,r){var n,a,o=t._context||{},s=o.frameMargins,c=l.isPlotDiv(t);if(c&&t.emit(\"plotly_autosize\"),o.fillFrame)n=window.innerWidth,a=window.innerHeight,document.body.style.overflow=\"hidden\";else{var u=c?window.getComputedStyle(t):{};if(n=parseFloat(u.width)||parseFloat(u.maxWidth)||r.width,a=parseFloat(u.height)||parseFloat(u.maxHeight)||r.height,i(s)&&s>0){var h=1-2*s;n=Math.round(h*n),a=Math.round(h*a)}}var f=v.layoutAttributes.width.min,p=v.layoutAttributes.height.min;n<f&&(n=f),a<p&&(a=p);var d=!e.width&&Math.abs(r.width-n)>1,g=!e.height&&Math.abs(r.height-a)>1;(g||d)&&(d&&(r.width=n),g&&(r.height=a)),t._initialAutoSize||(t._initialAutoSize={width:n,height:a}),v.sanitizeMargins(r)},v.supplyLayoutModuleDefaults=function(t,e,r,n){var i,o,s,c=a.componentsRegistry,u=e._basePlotModules,h=a.subplotsRegistry.cartesian;for(i in c)(s=c[i]).includeBasePlot&&s.includeBasePlot(t,e);for(var f in u.length||u.push(h),e._has(\"cartesian\")&&(a.getComponentMethod(\"grid\",\"contentDefaults\")(t,e),h.finalizeSubplots(t,e)),e._subplots)e._subplots[f].sort(l.subplotSort);for(o=0;o<u.length;o++)(s=u[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var p=e._modules;for(o=0;o<p.length;o++)(s=p[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var d=e._transformModules;for(o=0;o<d.length;o++)(s=d[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r,n);for(i in c)(s=c[i]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r)},v.purge=function(t){var e=t._fullLayout||{};void 0!==e._glcontainer&&(e._glcontainer.selectAll(\".gl-canvas\").remove(),e._glcontainer.remove(),e._glcanvas=null),void 0!==e._geocontainer&&e._geocontainer.remove(),e._modeBar&&e._modeBar.destroy(),t._transitionData&&(t._transitionData._interruptCallbacks&&(t._transitionData._interruptCallbacks.length=0),t._transitionData._animationRaf&&window.cancelAnimationFrame(t._transitionData._animationRaf)),l.clearThrottle(),l.clearResponsive(t),delete t.data,delete t.layout,delete t._fullData,delete t._fullLayout,delete t.calcdata,delete t.framework,delete t.empty,delete t.fid,delete t.undoqueue,delete t.undonum,delete t.autoplay,delete t.changed,delete t._promises,delete t._redrawTimer,delete t._hmlumcount,delete t._hmpixcount,delete t._transitionData,delete t._transitioning,delete t._initialAutoSize,delete t._transitioningWithDuration,delete t._dragging,delete t._dragged,delete t._dragdata,delete t._hoverdata,delete t._snapshotInProgress,delete t._editing,delete t._mouseDownTime,delete t._legendMouseDownTime,t.removeAllListeners&&t.removeAllListeners()},v.style=function(t){var e,r=t._fullLayout._visibleModules,n=[];for(e=0;e<r.length;e++){var i=r[e];i.style&&l.pushUnique(n,i.style)}for(e=0;e<n.length;e++)n[e](t)},v.sanitizeMargins=function(t){if(t&&t.margin){var e,r=t.width,n=t.height,i=t.margin,a=r-(i.l+i.r),o=n-(i.t+i.b);a<0&&(e=(r-1)/(i.l+i.r),i.l=Math.floor(e*i.l),i.r=Math.floor(e*i.r)),o<0&&(e=(n-1)/(i.t+i.b),i.t=Math.floor(e*i.t),i.b=Math.floor(e*i.b))}},v.clearAutoMarginIds=function(t){t._fullLayout._pushmarginIds={}},v.allowAutoMargin=function(t,e){t._fullLayout._pushmarginIds[e]=1},v.autoMargin=function(t,e,r){var n=t._fullLayout,i=n._pushmargin,a=n._pushmarginIds;if(!1!==n.margin.autoexpand){if(r){var o=r.pad;if(void 0===o){var s=n.margin;o=Math.min(12,s.l,s.r,s.t,s.b)}r.l+r.r>.5*n.width&&(r.l=r.r=0),r.b+r.t>.5*n.height&&(r.b=r.t=0);var l=void 0!==r.xl?r.xl:r.x,c=void 0!==r.xr?r.xr:r.x,u=void 0!==r.yt?r.yt:r.y,h=void 0!==r.yb?r.yb:r.y;i[e]={l:{val:l,size:r.l+o},r:{val:c,size:r.r+o},b:{val:h,size:r.b+o},t:{val:u,size:r.t+o}},a[e]=1}else delete i[e],delete a[e];n._replotting||v.doAutoMargin(t)}},v.doAutoMargin=function(t){var e=t._fullLayout;e._size||(e._size={}),A(e);var r=e._size,n=e.margin,o=l.extendFlat({},r),s=n.l,c=n.r,u=n.t,h=n.b,f=e.width,p=e.height,d=e._pushmargin,g=e._pushmarginIds;if(!1!==e.margin.autoexpand){for(var m in d)g[m]||delete d[m];for(var y in d.base={l:{val:0,size:s},r:{val:1,size:c},t:{val:1,size:u},b:{val:0,size:h}},d){var x=d[y].l||{},b=d[y].b||{},_=x.val,w=x.size,k=b.val,T=b.size;for(var M in d){if(i(w)&&d[M].r){var S=d[M].r.val,E=d[M].r.size;if(S>_){var C=(w*S+(E-f)*_)/(S-_),L=(E*(1-_)+(w-f)*(1-S))/(S-_);C>=0&&L>=0&&f-(C+L)>0&&C+L>s+c&&(s=C,c=L)}}if(i(T)&&d[M].t){var P=d[M].t.val,O=d[M].t.size;if(P>k){var z=(T*P+(O-p)*k)/(P-k),I=(O*(1-k)+(T-p)*(1-P))/(P-k);z>=0&&I>=0&&p-(I+z)>0&&z+I>h+u&&(h=z,u=I)}}}}}if(r.l=Math.round(s),r.r=Math.round(c),r.t=Math.round(u),r.b=Math.round(h),r.p=Math.round(n.pad),r.w=Math.round(f)-r.l-r.r,r.h=Math.round(p)-r.t-r.b,!e._replotting&&v.didMarginChange(o,r))return\"_redrawFromAutoMarginCount\"in e?e._redrawFromAutoMarginCount++:e._redrawFromAutoMarginCount=1,a.call(\"plot\",t)};var M=[\"l\",\"r\",\"t\",\"b\",\"p\",\"w\",\"h\"];function S(t,e,r){var n=!1;var i=[v.previousPromises,function(){if(t._transitionData)return t._transitioning=!1,function(t){var e=Promise.resolve();if(!t)return e;for(;t.length;)e=e.then(t.shift());return e}(t._transitionData._interruptCallbacks)},r.prepareFn,v.rehover,function(){return t.emit(\"plotly_transitioning\",[]),new Promise(function(i){t._transitioning=!0,e.duration>0&&(t._transitioningWithDuration=!0),t._transitionData._interruptCallbacks.push(function(){n=!0}),r.redraw&&t._transitionData._interruptCallbacks.push(function(){return a.call(\"redraw\",t)}),t._transitionData._interruptCallbacks.push(function(){t.emit(\"plotly_transitioninterrupted\",[])});var o=0,s=0;function l(){return o++,function(){var e;s++,n||s!==o||(e=i,t._transitionData&&(function(t){if(t)for(;t.length;)t.shift()}(t._transitionData._interruptCallbacks),Promise.resolve().then(function(){if(r.redraw)return a.call(\"redraw\",t)}).then(function(){t._transitioning=!1,t._transitioningWithDuration=!1,t.emit(\"plotly_transitioned\",[])}).then(e)))}}r.runFn(l),setTimeout(l())})}],o=l.syncOrAsync(i,t);return o&&o.then||(o=Promise.resolve()),o.then(function(){return t})}v.didMarginChange=function(t,e){for(var r=0;r<M.length;r++){var n=M[r],a=t[n],o=e[n];if(!i(a)||Math.abs(o-a)>1)return!0}return!1},v.graphJson=function(t,e,r,n,i){(i&&e&&!t._fullData||i&&!e&&!t._fullLayout)&&v.supplyDefaults(t);var a=i?t._fullData:t.data,o=i?t._fullLayout:t.layout,s=(t._transitionData||{})._frames;function c(t){if(\"function\"==typeof t)return null;if(l.isPlainObject(t)){var e,n,i={};for(e in t)if(\"function\"!=typeof t[e]&&-1===[\"_\",\"[\"].indexOf(e.charAt(0))){if(\"keepdata\"===r){if(\"src\"===e.substr(e.length-3))continue}else if(\"keepstream\"===r){if(\"string\"==typeof(n=t[e+\"src\"])&&n.indexOf(\":\")>0&&!l.isPlainObject(t.stream))continue}else if(\"keepall\"!==r&&\"string\"==typeof(n=t[e+\"src\"])&&n.indexOf(\":\")>0)continue;i[e]=c(t[e])}return i}return Array.isArray(t)?t.map(c):l.isTypedArray(t)?l.simpleMap(t,l.identity):l.isJSDate(t)?l.ms2DateTimeLocal(+t):t}var u={data:(a||[]).map(function(t){var r=c(t);return e&&delete r.fit,r})};return e||(u.layout=c(o)),t.framework&&t.framework.isPolar&&(u=t.framework.getConfig()),s&&(u.frames=c(s)),\"object\"===n?u:JSON.stringify(u)},v.modifyFrames=function(t,e){var r,n,i,a=t._transitionData._frames,o=t._transitionData._frameHash;for(r=0;r<e.length;r++)switch((n=e[r]).type){case\"replace\":i=n.value;var s=(a[n.index]||{}).name,l=i.name;a[n.index]=o[l]=i,l!==s&&(delete o[s],o[l]=i);break;case\"insert\":o[(i=n.value).name]=i,a.splice(n.index,0,i);break;case\"delete\":delete o[(i=a[n.index]).name],a.splice(n.index,1)}return Promise.resolve()},v.computeFrame=function(t,e){var r,n,i,a,o=t._transitionData._frameHash;if(!e)throw new Error(\"computeFrame must be given a string frame name\");var s=o[e.toString()];if(!s)return!1;for(var l=[s],c=[s.name];s.baseframe&&(s=o[s.baseframe.toString()])&&-1===c.indexOf(s.name);)l.push(s),c.push(s.name);for(var u={};s=l.pop();)if(s.layout&&(u.layout=v.extendLayout(u.layout,s.layout)),s.data){if(u.data||(u.data=[]),!(n=s.traces))for(n=[],r=0;r<s.data.length;r++)n[r]=r;for(u.traces||(u.traces=[]),r=0;r<s.data.length;r++)null!=(i=n[r])&&(-1===(a=u.traces.indexOf(i))&&(a=u.data.length,u.traces[a]=i),u.data[a]=v.extendTrace(u.data[a],s.data[r]))}return u},v.recomputeFrameHash=function(t){for(var e=t._transitionData._frameHash={},r=t._transitionData._frames,n=0;n<r.length;n++){var i=r[n];i&&i.name&&(e[i.name]=i)}},v.extendObjectWithContainers=function(t,e,r){var n,i,a,o,s,c,u,h=l.extendDeepNoArrays({},e||{}),f=l.expandObjectPaths(h),p={};if(r&&r.length)for(a=0;a<r.length;a++)void 0===(i=(n=l.nestedProperty(f,r[a])).get())?l.nestedProperty(p,r[a]).set(null):(n.set(null),l.nestedProperty(p,r[a]).set(i));if(t=l.extendDeepNoArrays(t||{},f),r&&r.length)for(a=0;a<r.length;a++)if(c=l.nestedProperty(p,r[a]).get()){for(u=(s=l.nestedProperty(t,r[a])).get(),Array.isArray(u)||(u=[],s.set(u)),o=0;o<c.length;o++){var d=c[o];u[o]=null===d?null:v.extendObjectWithContainers(u[o],d)}s.set(u)}return t},v.dataArrayContainers=[\"transforms\",\"dimensions\"],v.layoutArrayContainers=a.layoutArrayContainers,v.extendTrace=function(t,e){return v.extendObjectWithContainers(t,e,v.dataArrayContainers)},v.extendLayout=function(t,e){return v.extendObjectWithContainers(t,e,v.layoutArrayContainers)},v.transition=function(t,e,r,n,i,a){var o={redraw:i.redraw},s={},c=[];return o.prepareFn=function(){for(var i=Array.isArray(e)?e.length:0,a=n.slice(0,i),o=0;o<a.length;o++){var u=a[o],h=t._fullData[u]._module;if(h){if(h.animatable){var f=h.basePlotModule.name;s[f]||(s[f]=[]),s[f].push(u)}t.data[a[o]]=v.extendTrace(t.data[a[o]],e[o])}}var p=l.expandObjectPaths(l.extendDeepNoArrays({},r)),d=/^[xy]axis[0-9]*$/;for(var g in p)d.test(g)&&delete p[g].range;v.extendLayout(t.layout,p),delete t.calcdata,v.supplyDefaults(t),v.doCalcdata(t);var m=l.expandObjectPaths(r);if(m){var y=t._fullLayout._plots;for(var x in y){var b,_,w,k,T=y[x],A=T.xaxis,M=T.yaxis,S=A.range.slice(),E=M.range.slice();Array.isArray(m[A._name+\".range\"])?b=m[A._name+\".range\"].slice():Array.isArray((m[A._name]||{}).range)&&(b=m[A._name].range.slice()),Array.isArray(m[M._name+\".range\"])?_=m[M._name+\".range\"].slice():Array.isArray((m[M._name]||{}).range)&&(_=m[M._name].range.slice()),S&&b&&(S[0]!==b[0]||S[1]!==b[1])&&(w={xr0:S,xr1:b}),E&&_&&(E[0]!==_[0]||E[1]!==_[1])&&(k={yr0:E,yr1:_}),(w||k)&&c.push(l.extendFlat({plotinfo:T},w,k))}}return Promise.resolve()},o.runFn=function(e){var n,i,o=t._fullLayout._basePlotModules,u=c.length;if(r)for(i=0;i<o.length;i++)o[i].transitionAxes&&o[i].transitionAxes(t,c,a,e);for(var h in u?((n=l.extendFlat({},a)).duration=0,delete s.cartesian):n=a,s){var f=s[h];t._fullData[f[0]]._module.basePlotModule.plot(t,f,n,e)}},S(t,a,o)},v.transitionFromReact=function(t,e,r,n){var i=t._fullLayout,a=i.transition,o={},s=[];return o.prepareFn=function(){var t=i._plots;for(var a in o.redraw=!1,\"some\"===e.anim&&(o.redraw=!0),\"some\"===r.anim&&(o.redraw=!0),t){var c,u,h=t[a],f=h.xaxis,p=h.yaxis,d=n[f._name].range.slice(),g=n[p._name].range.slice(),v=f.range.slice(),m=p.range.slice();f.setScale(),p.setScale(),d[0]===v[0]&&d[1]===v[1]||(c={xr0:d,xr1:v}),g[0]===m[0]&&g[1]===m[1]||(u={yr0:g,yr1:m}),(c||u)&&s.push(l.extendFlat({plotinfo:h},c,u))}return Promise.resolve()},o.runFn=function(r){for(var n,i,o,c=t._fullData,u=t._fullLayout._basePlotModules,h=[],f=0;f<c.length;f++)h.push(f);function p(){for(var e=0;e<u.length;e++)u[e].transitionAxes&&u[e].transitionAxes(t,s,n,r)}function d(){for(var e=0;e<u.length;e++)u[e].plot(t,o,i,r)}s.length&&e.anim?\"traces first\"===a.ordering?(n=l.extendFlat({},a,{duration:0}),o=h,i=a,d(),setTimeout(p,a.duration)):(n=a,o=null,i=l.extendFlat({},a,{duration:0}),p(),d()):s.length?(n=a,p()):e.anim&&(o=h,i=a,d())},S(t,a,o)},v.doCalcdata=function(t,e){var r,n,i,s,c=h.list(t),f=t._fullData,p=t._fullLayout,d=new Array(f.length),g=(t.calcdata||[]).slice();for(t.calcdata=d,p._numBoxes=0,p._numViolins=0,p._violinScaleGroupStats={},t._hmpixcount=0,t._hmlumcount=0,p._piecolormap={},p._sunburstcolormap={},p._funnelareacolormap={},i=0;i<f.length;i++)Array.isArray(e)&&-1===e.indexOf(i)&&(d[i]=g[i]);for(i=0;i<f.length;i++)(r=f[i])._arrayAttrs=o.findArrayAttributes(r),r._extremes={};var v=p._subplots.polar||[];for(i=0;i<v.length;i++)c.push(p[v[i]].radialaxis,p[v[i]].angularaxis);var y=!1;function x(e){if(r=f[e],n=r._module,!0===r.visible&&r.transforms){if(n&&n.calc){var i=n.calc(t,r);i[0]&&i[0].t&&i[0].t._scene&&delete i[0].t._scene.dirty}for(s=0;s<r.transforms.length;s++){var a=r.transforms[s];(n=m[a.type])&&n.calcTransform&&(r._hasCalcTransform=!0,y=!0,n.calcTransform(t,r,a))}}}function b(e,i){if(r=f[e],!!(n=r._module).isContainer===i){var a=[];if(!0===r.visible&&0!==r._length){delete r._indexToPoints;var o=r.transforms||[];for(s=o.length-1;s>=0;s--)if(o[s].enabled){r._indexToPoints=o[s]._indexToPoints;break}n&&n.calc&&(a=n.calc(t,r))}Array.isArray(a)&&a[0]||(a=[{x:u,y:u}]),a[0].t||(a[0].t={}),a[0].trace=r,d[e]=a}}for(C(c,f),i=0;i<f.length;i++)b(i,!0);for(i=0;i<f.length;i++)x(i);for(y&&C(c,f),i=0;i<f.length;i++)b(i,!0);for(i=0;i<f.length;i++)b(i,!1);L(t);var _=function(t,e){var r,n,i,o,s,c=[];function u(t,r,n){var i=r._id.charAt(0);if(\"histogram2dcontour\"===t){var a=r._counterAxes[0],o=h.getFromId(e,a),s=\"x\"===i||\"x\"===a&&\"category\"===o.type,l=\"y\"===i||\"y\"===a&&\"category\"===o.type;return function(t,e){return 0===t||0===e?-1:s&&t===n[e].length-1?-1:l&&e===n.length-1?-1:(\"y\"===i?e:t)-1}}return function(t,e){return\"y\"===i?e:t}}var f={min:function(t){return l.aggNums(Math.min,null,t)},max:function(t){return l.aggNums(Math.max,null,t)},sum:function(t){return l.aggNums(function(t,e){return t+e},null,t)},total:function(t){return l.aggNums(function(t,e){return t+e},null,t)},mean:function(t){return l.mean(t)},median:function(t){return l.median(t)}};for(r=0;r<t.length;r++){var p=t[r];if(\"category\"===p.type){var d=p.categoryorder.match(E);if(d){var g=d[1],v=d[2],m=[];for(n=0;n<p._categories.length;n++)m.push([p._categories[n],[]]);for(n=0;n<p._traceIndices.length;n++){var y=p._traceIndices[n],x=e._fullData[y],b=p._id.charAt(0);if(!0===x.visible){var _=x.type;a.traceIs(x,\"histogram\")&&(delete x._xautoBinFinished,delete x._yautoBinFinished);var w=e.calcdata[y];for(i=0;i<w.length;i++){var k,T,A,M=w[i];if(\"splom\"===_){var S=x._axesDim[p._id];if(\"y\"===b){var C=x._diag[S][0];C&&(p=e._fullLayout[h.id2name(C)])}var L=M.trace.dimensions[S].values;for(o=0;o<L.length;o++)for(k=L[o],T=p._categoriesMap[k],s=0;s<M.trace.dimensions.length;s++)if(s!==S){var P=M.trace.dimensions[s];m[T][1].push(P.values[o])}}else if(\"scattergl\"===_){for(o=0;o<M.t.x.length;o++)\"x\"===b&&(k=M.t.x[o],T=k,A=M.t.y[o]),\"y\"===b&&(k=M.t.y[o],T=k,A=M.t.x[o]),m[T][1].push(A);M.t&&M.t._scene&&delete M.t._scene.dirty}else if(M.hasOwnProperty(\"z\")){A=M.z;var O=u(x.type,p,A);for(o=0;o<A.length;o++)for(s=0;s<A[o].length;s++)(T=O(s,o))+1&&m[T][1].push(A[o][s])}else for(\"x\"===b?(k=M.p+1?M.p:M.x,A=M.s||M.v||M.y):\"y\"===b&&(k=M.p+1?M.p:M.y,A=M.s||M.v||M.x),Array.isArray(A)||(A=[A]),o=0;o<A.length;o++)m[k][1].push(A[o])}}}p._categoriesValue=m;var z=[];for(n=0;n<m.length;n++)z.push([m[n][0],f[g](m[n][1])]);z.sort(function(t,e){return t[1]-e[1]}),p._categoriesAggregatedValue=z,p._initialCategories=z.map(function(t){return t[0]}),\"descending\"===v&&p._initialCategories.reverse(),c=c.concat(p.sortByInitialCategories())}}}return c}(c,t);if(_.length){for(p._numBoxes=0,p._numViolins=0,i=0;i<_.length;i++)b(_[i],!0);for(i=0;i<_.length;i++)b(_[i],!1);L(t)}a.getComponentMethod(\"fx\",\"calc\")(t),a.getComponentMethod(\"errorbars\",\"calc\")(t)};var E=/(total|sum|min|max|mean|median) (ascending|descending)/;function C(t,e){for(var r=0;r<t.length;r++){var n=t[r];n.clearCalc(),\"multicategory\"===n.type&&n.setupMultiCategory(e)}}function L(t){var e,r,n,i=t._fullLayout,a=i._visibleModules,o={};for(r=0;r<a.length;r++){var s=a[r],c=s.crossTraceCalc;if(c){var u=s.basePlotModule.name;o[u]?l.pushUnique(o[u],c):o[u]=[c]}}for(n in o){var h=o[n],f=i._subplots[n];if(Array.isArray(f))for(e=0;e<f.length;e++){var p=f[e],d=\"cartesian\"===n?i._plots[p]:i[p];for(r=0;r<h.length;r++)h[r](t,d,p)}else for(r=0;r<h.length;r++)h[r](t)}}v.rehover=function(t){t._fullLayout._rehover&&t._fullLayout._rehover()},v.redrag=function(t){t._fullLayout._redrag&&t._fullLayout._redrag()},v.generalUpdatePerTraceModule=function(t,e,r,n){var i,a=e.traceHash,o={};for(i=0;i<r.length;i++){var s=r[i],c=s[0].trace;c.visible&&(o[c.type]=o[c.type]||[],o[c.type].push(s))}for(var u in a)if(!o[u]){var h=a[u][0];h[0].trace.visible=!1,o[u]=[h]}for(var f in o){var p=o[f];p[0][0].trace._module.plot(t,e,l.filterVisible(p),n)}e.traceHash=o}},{\"../components/color\":593,\"../constants/numerical\":695,\"../lib\":719,\"../plot_api/plot_schema\":756,\"../plot_api/plot_template\":757,\"../registry\":847,\"./animation_attributes\":762,\"./attributes\":764,\"./cartesian/axis_ids\":770,\"./command\":791,\"./font_attributes\":793,\"./frame_attributes\":794,\"./layout_attributes\":819,d3:163,\"fast-isnumeric\":225}],829:[function(t,e,r){\"use strict\";e.exports={attr:\"subplot\",name:\"polar\",axisNames:[\"angularaxis\",\"radialaxis\"],axisName2dataArray:{angularaxis:\"theta\",radialaxis:\"r\"},layerNames:[\"draglayer\",\"plotbg\",\"backplot\",\"angular-grid\",\"radial-grid\",\"frontplot\",\"angular-line\",\"radial-line\",\"angular-axis\",\"radial-axis\"],radialDragBoxSize:50,angularDragBoxSize:30,cornerLen:25,cornerHalfWidth:2,MINDRAG:8,MINZOOM:20,OFFEDGE:20}},{}],830:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/polygon\").tester,a=n.findIndexOfMin,o=n.isAngleInsideSector,s=n.angleDelta,l=n.angleDist;function c(t,e,r,n){var i,a,o=n[0],s=n[1],l=h(Math.sin(e)-Math.sin(t)),c=h(Math.cos(e)-Math.cos(t)),u=Math.tan(r),f=h(1/u),p=l/c,d=s-p*o;return f?l&&c?a=u*(i=d/(u-p)):c?(i=s*f,a=s):(i=o,a=o*u):l&&c?(i=0,a=d):c?(i=0,a=s):i=a=NaN,[i,a]}function u(t,e,r,i){return n.isFullCircle([e,r])?function(t,e){var r,n=e.length,i=new Array(n+1);for(r=0;r<n;r++){var a=e[r];i[r]=[t*Math.cos(a),t*Math.sin(a)]}return i[r]=i[0].slice(),i}(t,i):function(t,e,r,i){var s,u,h=i.length,f=[];function p(e){return[t*Math.cos(e),t*Math.sin(e)]}function d(t,e,r){return c(t,e,r,p(t))}function g(t){return n.mod(t,h)}function v(t){return o(t,[e,r])}var m=a(i,function(t){return v(t)?l(t,e):1/0}),y=d(i[m],i[g(m-1)],e);for(f.push(y),s=m,u=0;u<h;s++,u++){var x=i[g(s)];if(!v(x))break;f.push(p(x))}var b=a(i,function(t){return v(t)?l(t,r):1/0}),_=d(i[b],i[g(b+1)],r);return f.push(_),f.push([0,0]),f.push(f[0].slice()),f}(t,e,r,i)}function h(t){return Math.abs(t)>1e-10?t:0}function f(t,e,r){e=e||0,r=r||0;for(var n=t.length,i=new Array(n),a=0;a<n;a++){var o=t[a];i[a]=[e+o[0],r-o[1]]}return i}e.exports={isPtInsidePolygon:function(t,e,r,n,a){if(!o(e,n))return!1;var s,l;r[0]<r[1]?(s=r[0],l=r[1]):(s=r[1],l=r[0]);var c=i(u(s,n[0],n[1],a)),h=i(u(l,n[0],n[1],a)),f=[t*Math.cos(e),t*Math.sin(e)];return h.contains(f)&&!c.contains(f)},findPolygonOffset:function(t,e,r,n){for(var i=1/0,a=1/0,o=u(t,e,r,n),s=0;s<o.length;s++){var l=o[s];i=Math.min(i,l[0]),a=Math.min(a,-l[1])}return[i,a]},findEnclosingVertexAngles:function(t,e){var r=a(e,function(e){var r=s(e,t);return r>0?r:1/0}),i=n.mod(r+1,e.length);return[e[r],e[i]]},findIntersectionXY:c,findXYatLength:function(t,e,r,n){var i=-e*r,a=e*e+1,o=2*(e*i-r),s=i*i+r*r-t*t,l=Math.sqrt(o*o-4*a*s),c=(-o+l)/(2*a),u=(-o-l)/(2*a);return[[c,e*c+i+n],[u,e*u+i+n]]},clampTiny:h,pathPolygon:function(t,e,r,n,i,a){return\"M\"+f(u(t,e,r,n),i,a).join(\"L\")},pathPolygonAnnulus:function(t,e,r,n,i,a,o){var s,l;t<e?(s=t,l=e):(s=e,l=t);var c=f(u(s,r,n,i),a,o);return\"M\"+f(u(l,r,n,i),a,o).reverse().join(\"L\")+\"M\"+c.join(\"L\")}}},{\"../../lib\":719,\"../../lib/polygon\":731}],831:[function(t,e,r){\"use strict\";var n=t(\"../get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./polar\"),o=t(\"./constants\"),s=o.attr,l=o.name,c=i(l),u={};u[s]={valType:\"subplotid\",dflt:l,editType:\"calc\"},e.exports={attr:s,name:l,idRoot:l,idRegex:c,attrRegex:c,attributes:u,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[l],o=0;o<i.length;o++){var s=i[o],c=n(r,l,s),u=e[s]._subplot;u||(u=a(t,s),e[s]._subplot=u),u.plot(c,e,t._promises)}},clean:function(t,e,r,n){for(var i=n._subplots[l]||[],a=n._has&&n._has(\"gl\"),o=e._has&&e._has(\"gl\"),s=a&&!o,c=0;c<i.length;c++){var u=i[c],h=n[u]._subplot;if(!e[u]&&h)for(var f in h.framework.remove(),h.layers[\"radial-axis-title\"].remove(),h.clipPaths)h.clipPaths[f].remove();s&&h._scene&&(h._scene.destroy(),h._scene=null)}},toSVG:t(\"../cartesian\").toSVG}},{\"../../lib\":719,\"../cartesian\":778,\"../get_data\":802,\"./constants\":829,\"./layout_attributes\":832,\"./layout_defaults\":833,\"./polar\":840}],832:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../cartesian/layout_attributes\"),a=t(\"../domain\").attributes,o=t(\"../../lib\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=s({color:i.color,showline:o({},i.showline,{dflt:!0}),linecolor:i.linecolor,linewidth:i.linewidth,showgrid:o({},i.showgrid,{dflt:!0}),gridcolor:i.gridcolor,gridwidth:i.gridwidth},\"plot\",\"from-root\"),c=s({tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,showtickprefix:i.showtickprefix,tickprefix:i.tickprefix,showticksuffix:i.showticksuffix,ticksuffix:i.ticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,separatethousands:i.separatethousands,tickfont:i.tickfont,tickangle:i.tickangle,tickformat:i.tickformat,tickformatstops:i.tickformatstops,layer:i.layer},\"plot\",\"from-root\"),u={visible:o({},i.visible,{dflt:!0}),type:o({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autorange:o({},i.autorange,{editType:\"plot\"}),rangemode:{valType:\"enumerated\",values:[\"tozero\",\"nonnegative\",\"normal\"],dflt:\"tozero\",editType:\"calc\"},range:o({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],editType:\"plot\"}),categoryorder:i.categoryorder,categoryarray:i.categoryarray,angle:{valType:\"angle\",editType:\"plot\"},side:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"clockwise\",editType:\"plot\"},title:s(i.title,\"plot\",\"from-root\"),hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}};u.title.text.dflt=\"\",o(u,l,c);var h={visible:o({},i.visible,{dflt:!0}),type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"category\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},categoryorder:i.categoryorder,categoryarray:i.categoryarray,thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\"],dflt:\"degrees\",editType:\"calc\"},period:{valType:\"number\",editType:\"calc\",min:0},direction:{valType:\"enumerated\",values:[\"counterclockwise\",\"clockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"angle\",editType:\"calc\"},hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"};o(h,l,c),e.exports={domain:a({name:\"polar\",editType:\"plot\"}),sector:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],dflt:[0,360],editType:\"plot\"},hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},bgcolor:{valType:\"color\",editType:\"plot\",dflt:n.background},radialaxis:u,angularaxis:h,gridshape:{valType:\"enumerated\",values:[\"circular\",\"linear\"],dflt:\"circular\",editType:\"plot\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"}},{\"../../components/color/attributes\":592,\"../../lib\":719,\"../../plot_api/edit_types\":750,\"../cartesian/layout_attributes\":779,\"../domain\":792}],833:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../subplot_defaults\"),s=t(\"../get_data\").getSubplotData,l=t(\"../cartesian/tick_value_defaults\"),c=t(\"../cartesian/tick_mark_defaults\"),u=t(\"../cartesian/tick_label_defaults\"),h=t(\"../cartesian/category_order_defaults\"),f=t(\"../cartesian/line_grid_defaults\"),p=t(\"../cartesian/axis_autotype\"),d=t(\"./layout_attributes\"),g=t(\"./set_convert\"),v=t(\"./constants\"),m=v.axisNames;function y(t,e,r,o){var p=r(\"bgcolor\");o.bgColor=i.combine(p,o.paper_bgcolor);var y=r(\"sector\");r(\"hole\");var b,_=s(o.fullData,v.name,o.id),w=o.layoutOut;function k(t,e){return r(b+\".\"+t,e)}for(var T=0;T<m.length;T++){b=m[T],n.isPlainObject(t[b])||(t[b]={});var A=t[b],M=a.newContainer(e,b);M._id=M._name=b,M._attr=o.id+\".\"+b,M._traceIndices=_.map(function(t){return t._expandedIndex});var S=v.axisName2dataArray[b],E=x(A,M,k,_,S);h(A,M,k,{axData:_,dataAttr:S});var C,L,P=k(\"visible\");switch(g(M,e,w),k(\"uirevision\",e.uirevision),P&&(L=(C=k(\"color\"))===A.color?C:o.font.color),M._m=1,b){case\"radialaxis\":var O=k(\"autorange\",!M.isValidRange(A.range));A.autorange=O,!O||\"linear\"!==E&&\"-\"!==E||k(\"rangemode\"),\"reversed\"===O&&(M._m=-1),k(\"range\"),M.cleanRange(\"range\",{dfltRange:[0,1]}),P&&(k(\"side\"),k(\"angle\",y[0]),k(\"title.text\"),n.coerceFont(k,\"title.font\",{family:o.font.family,size:Math.round(1.2*o.font.size),color:L}));break;case\"angularaxis\":if(\"date\"===E){n.log(\"Polar plots do not support date angular axes yet.\");for(var z=0;z<_.length;z++)_[z].visible=!1;E=A.type=M.type=\"linear\"}k(\"linear\"===E?\"thetaunit\":\"period\");var I=k(\"direction\");k(\"rotation\",{counterclockwise:0,clockwise:90}[I])}if(P)l(A,M,k,M.type),u(A,M,k,M.type,{tickSuffixDflt:\"degrees\"===M.thetaunit?\"\\xb0\":void 0}),c(A,M,k,{outerTicks:!0}),k(\"showticklabels\")&&(n.coerceFont(k,\"tickfont\",{family:o.font.family,size:o.font.size,color:L}),k(\"tickangle\"),k(\"tickformat\")),f(A,M,k,{dfltColor:C,bgColor:o.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:d[b]}),k(\"layer\");\"category\"!==E&&k(\"hoverformat\"),M._input=A}\"category\"===e.angularaxis.type&&r(\"gridshape\")}function x(t,e,r,n,i){if(\"-\"===r(\"type\")){for(var a,o=0;o<n.length;o++)if(n[o].visible){a=n[o];break}a&&a[i]&&(e.type=p(a[i],\"gregorian\")),\"-\"===e.type?e.type=\"linear\":t.type=e.type}return e.type}e.exports=function(t,e,r){o(t,e,r,{type:v.name,attributes:d,handleDefaults:y,font:e.font,paper_bgcolor:e.paper_bgcolor,fullData:r,layoutOut:e})}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../cartesian/axis_autotype\":768,\"../cartesian/category_order_defaults\":771,\"../cartesian/line_grid_defaults\":781,\"../cartesian/tick_label_defaults\":786,\"../cartesian/tick_mark_defaults\":787,\"../cartesian/tick_value_defaults\":788,\"../get_data\":802,\"../subplot_defaults\":842,\"./constants\":829,\"./layout_attributes\":832,\"./set_convert\":841}],834:[function(t,e,r){\"use strict\";var n=t(\"../../../traces/scatter/attributes\"),i=n.marker,a=t(\"../../../lib/extend\").extendFlat;[\"Area traces are deprecated!\",\"Please switch to the *barpolar* trace type.\"].join(\" \");e.exports={r:a({},n.r,{}),t:a({},n.t,{}),marker:{color:a({},i.color,{}),size:a({},i.size,{}),symbol:a({},i.symbol,{}),opacity:a({},i.opacity,{}),editType:\"calc\"}}},{\"../../../lib/extend\":710,\"../../../traces/scatter/attributes\":1112}],835:[function(t,e,r){\"use strict\";var n=t(\"../../cartesian/layout_attributes\"),i=t(\"../../../lib/extend\").extendFlat,a=t(\"../../../plot_api/edit_types\").overrideAll,o=[\"Legacy polar charts are deprecated!\",\"Please switch to *polar* subplots.\"].join(\" \"),s=i({},n.domain,{});function l(t,e){return i({},e,{showline:{valType:\"boolean\"},showticklabels:{valType:\"boolean\"},tickorientation:{valType:\"enumerated\",values:[\"horizontal\",\"vertical\"]},ticklen:{valType:\"number\",min:0},tickcolor:{valType:\"color\"},ticksuffix:{valType:\"string\"},endpadding:{valType:\"number\",description:o},visible:{valType:\"boolean\"}})}e.exports=a({radialaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},domain:s,orientation:{valType:\"number\"}}),angularaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\",dflt:0},{valType:\"number\",dflt:360}]},domain:s}),layout:{direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"]},orientation:{valType:\"angle\"}}},\"plot\",\"nested\")},{\"../../../lib/extend\":710,\"../../../plot_api/edit_types\":750,\"../../cartesian/layout_attributes\":779}],836:[function(t,e,r){\"use strict\";(e.exports=t(\"./micropolar\")).manager=t(\"./micropolar_manager\")},{\"./micropolar\":837,\"./micropolar_manager\":838}],837:[function(t,e,r){var n=t(\"d3\"),i=t(\"../../../lib\").extendDeepAll,a=t(\"../../../constants/alignment\").MID_SHIFT,o=e.exports={version:\"0.2.2\"};o.Axis=function(){var t,e,r,s,l={data:[],layout:{}},c={},u={},h=n.dispatch(\"hover\"),f={};return f.render=function(c){return function(c){e=c||e;var h=l.data,f=l.layout;(\"string\"==typeof e||e.nodeName)&&(e=n.select(e)),e.datum(h).each(function(e,l){var c=e.slice();u={data:o.util.cloneJson(c),layout:o.util.cloneJson(f)};var h=0;c.forEach(function(t,e){t.color||(t.color=f.defaultColorRange[h],h=(h+1)%f.defaultColorRange.length),t.strokeColor||(t.strokeColor=\"LinePlot\"===t.geometry?t.color:n.rgb(t.color).darker().toString()),u.data[e].color=t.color,u.data[e].strokeColor=t.strokeColor,u.data[e].strokeDash=t.strokeDash,u.data[e].strokeSize=t.strokeSize});var p=c.filter(function(t,e){var r=t.visible;return\"undefined\"==typeof r||!0===r}),d=!1,g=p.map(function(t,e){return d=d||\"undefined\"!=typeof t.groupId,t});if(d){var v=n.nest().key(function(t,e){return\"undefined\"!=typeof t.groupId?t.groupId:\"unstacked\"}).entries(g),m=[],y=v.map(function(t,e){if(\"unstacked\"===t.key)return t.values;var r=t.values[0].r.map(function(t,e){return 0});return t.values.forEach(function(t,e,n){t.yStack=[r],m.push(r),r=o.util.sumArrays(t.r,r)}),t.values});p=n.merge(y)}p.forEach(function(t,e){t.t=Array.isArray(t.t[0])?t.t:[t.t],t.r=Array.isArray(t.r[0])?t.r:[t.r]});var x=Math.min(f.width-f.margin.left-f.margin.right,f.height-f.margin.top-f.margin.bottom)/2;x=Math.max(10,x);var b,_=[f.margin.left+x,f.margin.top+x];b=d?[0,n.max(o.util.sumArrays(o.util.arrayLast(p).r[0],o.util.arrayLast(m)))]:n.extent(o.util.flattenArray(p.map(function(t,e){return t.r}))),f.radialAxis.domain!=o.DATAEXTENT&&(b[0]=0),r=n.scale.linear().domain(f.radialAxis.domain!=o.DATAEXTENT&&f.radialAxis.domain?f.radialAxis.domain:b).range([0,x]),u.layout.radialAxis.domain=r.domain();var w,k=o.util.flattenArray(p.map(function(t,e){return t.t})),T=\"string\"==typeof k[0];T&&(k=o.util.deduplicate(k),w=k.slice(),k=n.range(k.length),p=p.map(function(t,e){var r=t;return t.t=[k],d&&(r.yStack=t.yStack),r}));var A=p.filter(function(t,e){return\"LinePlot\"===t.geometry||\"DotPlot\"===t.geometry}).length===p.length,M=null===f.needsEndSpacing?T||!A:f.needsEndSpacing,S=f.angularAxis.domain&&f.angularAxis.domain!=o.DATAEXTENT&&!T&&f.angularAxis.domain[0]>=0?f.angularAxis.domain:n.extent(k),E=Math.abs(k[1]-k[0]);A&&!T&&(E=0);var C=S.slice();M&&T&&(C[1]+=E);var L=f.angularAxis.ticksCount||4;L>8&&(L=L/(L/8)+L%8),f.angularAxis.ticksStep&&(L=(C[1]-C[0])/L);var P=f.angularAxis.ticksStep||(C[1]-C[0])/(L*(f.minorTicks+1));w&&(P=Math.max(Math.round(P),1)),C[2]||(C[2]=P);var O=n.range.apply(this,C);if(O=O.map(function(t,e){return parseFloat(t.toPrecision(12))}),s=n.scale.linear().domain(C.slice(0,2)).range(\"clockwise\"===f.direction?[0,360]:[360,0]),u.layout.angularAxis.domain=s.domain(),u.layout.angularAxis.endPadding=M?E:0,\"undefined\"==typeof(t=n.select(this).select(\"svg.chart-root\"))||t.empty()){var z=(new DOMParser).parseFromString(\"<svg xmlns='http://www.w3.org/2000/svg' class='chart-root'>' + '<g class='outer-group'>' + '<g class='chart-group'>' + '<circle class='background-circle'></circle>' + '<g class='geometry-group'></g>' + '<g class='radial axis-group'>' + '<circle class='outside-circle'></circle>' + '</g>' + '<g class='angular axis-group'></g>' + '<g class='guides-group'><line></line><circle r='0'></circle></g>' + '</g>' + '<g class='legend-group'></g>' + '<g class='tooltips-group'></g>' + '<g class='title-group'><text></text></g>' + '</g>' + '</svg>\",\"application/xml\"),I=this.appendChild(this.ownerDocument.importNode(z.documentElement,!0));t=n.select(I)}t.select(\".guides-group\").style({\"pointer-events\":\"none\"}),t.select(\".angular.axis-group\").style({\"pointer-events\":\"none\"}),t.select(\".radial.axis-group\").style({\"pointer-events\":\"none\"});var D,R=t.select(\".chart-group\"),F={fill:\"none\",stroke:f.tickColor},B={\"font-size\":f.font.size,\"font-family\":f.font.family,fill:f.font.color,\"text-shadow\":[\"-1px 0px\",\"1px -1px\",\"-1px 1px\",\"1px 1px\"].map(function(t,e){return\" \"+t+\" 0 \"+f.font.outlineColor}).join(\",\")};if(f.showLegend){D=t.select(\".legend-group\").attr({transform:\"translate(\"+[x,f.margin.top]+\")\"}).style({display:\"block\"});var N=p.map(function(t,e){var r=o.util.cloneJson(t);return r.symbol=\"DotPlot\"===t.geometry?t.dotType||\"circle\":\"LinePlot\"!=t.geometry?\"square\":\"line\",r.visibleInLegend=\"undefined\"==typeof t.visibleInLegend||t.visibleInLegend,r.color=\"LinePlot\"===t.geometry?t.strokeColor:t.color,r});o.Legend().config({data:p.map(function(t,e){return t.name||\"Element\"+e}),legendConfig:i({},o.Legend.defaultConfig().legendConfig,{container:D,elements:N,reverseOrder:f.legend.reverseOrder})})();var j=D.node().getBBox();x=Math.min(f.width-j.width-f.margin.left-f.margin.right,f.height-f.margin.top-f.margin.bottom)/2,x=Math.max(10,x),_=[f.margin.left+x,f.margin.top+x],r.range([0,x]),u.layout.radialAxis.domain=r.domain(),D.attr(\"transform\",\"translate(\"+[_[0]+x,_[1]-x]+\")\")}else D=t.select(\".legend-group\").style({display:\"none\"});t.attr({width:f.width,height:f.height}).style({opacity:f.opacity}),R.attr(\"transform\",\"translate(\"+_+\")\").style({cursor:\"crosshair\"});var U=[(f.width-(f.margin.left+f.margin.right+2*x+(j?j.width:0)))/2,(f.height-(f.margin.top+f.margin.bottom+2*x))/2];if(U[0]=Math.max(0,U[0]),U[1]=Math.max(0,U[1]),t.select(\".outer-group\").attr(\"transform\",\"translate(\"+U+\")\"),f.title&&f.title.text){var V=t.select(\"g.title-group text\").style(B).text(f.title.text),q=V.node().getBBox();V.attr({x:_[0]-q.width/2,y:_[1]-x-20})}var H=t.select(\".radial.axis-group\");if(f.radialAxis.gridLinesVisible){var G=H.selectAll(\"circle.grid-circle\").data(r.ticks(5));G.enter().append(\"circle\").attr({class:\"grid-circle\"}).style(F),G.attr(\"r\",r),G.exit().remove()}H.select(\"circle.outside-circle\").attr({r:x}).style(F);var Y=t.select(\"circle.background-circle\").attr({r:x}).style({fill:f.backgroundColor,stroke:f.stroke});function W(t,e){return s(t)%360+f.orientation}if(f.radialAxis.visible){var X=n.svg.axis().scale(r).ticks(5).tickSize(5);H.call(X).attr({transform:\"rotate(\"+f.radialAxis.orientation+\")\"}),H.selectAll(\".domain\").style(F),H.selectAll(\"g>text\").text(function(t,e){return this.textContent+f.radialAxis.ticksSuffix}).style(B).style({\"text-anchor\":\"start\"}).attr({x:0,y:0,dx:0,dy:0,transform:function(t,e){return\"horizontal\"===f.radialAxis.tickOrientation?\"rotate(\"+-f.radialAxis.orientation+\") translate(\"+[0,B[\"font-size\"]]+\")\":\"translate(\"+[0,B[\"font-size\"]]+\")\"}}),H.selectAll(\"g>line\").style({stroke:\"black\"})}var Z=t.select(\".angular.axis-group\").selectAll(\"g.angular-tick\").data(O),J=Z.enter().append(\"g\").classed(\"angular-tick\",!0);Z.attr({transform:function(t,e){return\"rotate(\"+W(t)+\")\"}}).style({display:f.angularAxis.visible?\"block\":\"none\"}),Z.exit().remove(),J.append(\"line\").classed(\"grid-line\",!0).classed(\"major\",function(t,e){return e%(f.minorTicks+1)==0}).classed(\"minor\",function(t,e){return!(e%(f.minorTicks+1)==0)}).style(F),J.selectAll(\".minor\").style({stroke:f.minorTickColor}),Z.select(\"line.grid-line\").attr({x1:f.tickLength?x-f.tickLength:0,x2:x}).style({display:f.angularAxis.gridLinesVisible?\"block\":\"none\"}),J.append(\"text\").classed(\"axis-text\",!0).style(B);var K=Z.select(\"text.axis-text\").attr({x:x+f.labelOffset,dy:a+\"em\",transform:function(t,e){var r=W(t),n=x+f.labelOffset,i=f.angularAxis.tickOrientation;return\"horizontal\"==i?\"rotate(\"+-r+\" \"+n+\" 0)\":\"radial\"==i?r<270&&r>90?\"rotate(180 \"+n+\" 0)\":null:\"rotate(\"+(r<=180&&r>0?-90:90)+\" \"+n+\" 0)\"}}).style({\"text-anchor\":\"middle\",display:f.angularAxis.labelsVisible?\"block\":\"none\"}).text(function(t,e){return e%(f.minorTicks+1)!=0?\"\":w?w[t]+f.angularAxis.ticksSuffix:t+f.angularAxis.ticksSuffix}).style(B);f.angularAxis.rewriteTicks&&K.text(function(t,e){return e%(f.minorTicks+1)!=0?\"\":f.angularAxis.rewriteTicks(this.textContent,e)});var $=n.max(R.selectAll(\".angular-tick text\")[0].map(function(t,e){return t.getCTM().e+t.getBBox().width}));D.attr({transform:\"translate(\"+[x+$,f.margin.top]+\")\"});var Q=t.select(\"g.geometry-group\").selectAll(\"g\").size()>0,tt=t.select(\"g.geometry-group\").selectAll(\"g.geometry\").data(p);if(tt.enter().append(\"g\").attr({class:function(t,e){return\"geometry geometry\"+e}}),tt.exit().remove(),p[0]||Q){var et=[];p.forEach(function(t,e){var n={};n.radialScale=r,n.angularScale=s,n.container=tt.filter(function(t,r){return r==e}),n.geometry=t.geometry,n.orientation=f.orientation,n.direction=f.direction,n.index=e,et.push({data:t,geometryConfig:n})});var rt=n.nest().key(function(t,e){return\"undefined\"!=typeof t.data.groupId||\"unstacked\"}).entries(et),nt=[];rt.forEach(function(t,e){\"unstacked\"===t.key?nt=nt.concat(t.values.map(function(t,e){return[t]})):nt.push(t.values)}),nt.forEach(function(t,e){var r;r=Array.isArray(t)?t[0].geometryConfig.geometry:t.geometryConfig.geometry;var n=t.map(function(t,e){return i(o[r].defaultConfig(),t)});o[r]().config(n)()})}var it,at,ot=t.select(\".guides-group\"),st=t.select(\".tooltips-group\"),lt=o.tooltipPanel().config({container:st,fontSize:8})(),ct=o.tooltipPanel().config({container:st,fontSize:8})(),ut=o.tooltipPanel().config({container:st,hasTick:!0})();if(!T){var ht=ot.select(\"line\").attr({x1:0,y1:0,y2:0}).style({stroke:\"grey\",\"pointer-events\":\"none\"});R.on(\"mousemove.angular-guide\",function(t,e){var r=o.util.getMousePos(Y).angle;ht.attr({x2:-x,transform:\"rotate(\"+r+\")\"}).style({opacity:.5});var n=(r+180+360-f.orientation)%360;it=s.invert(n);var i=o.util.convertToCartesian(x+12,r+180);lt.text(o.util.round(it)).move([i[0]+_[0],i[1]+_[1]])}).on(\"mouseout.angular-guide\",function(t,e){ot.select(\"line\").style({opacity:0})})}var ft=ot.select(\"circle\").style({stroke:\"grey\",fill:\"none\"});R.on(\"mousemove.radial-guide\",function(t,e){var n=o.util.getMousePos(Y).radius;ft.attr({r:n}).style({opacity:.5}),at=r.invert(o.util.getMousePos(Y).radius);var i=o.util.convertToCartesian(n,f.radialAxis.orientation);ct.text(o.util.round(at)).move([i[0]+_[0],i[1]+_[1]])}).on(\"mouseout.radial-guide\",function(t,e){ft.style({opacity:0}),ut.hide(),lt.hide(),ct.hide()}),t.selectAll(\".geometry-group .mark\").on(\"mouseover.tooltip\",function(e,r){var i=n.select(this),a=this.style.fill,s=\"black\",l=this.style.opacity||1;if(i.attr({\"data-opacity\":l}),a&&\"none\"!==a){i.attr({\"data-fill\":a}),s=n.hsl(a).darker().toString(),i.style({fill:s,opacity:1});var c={t:o.util.round(e[0]),r:o.util.round(e[1])};T&&(c.t=w[e[0]]);var u=\"t: \"+c.t+\", r: \"+c.r,h=this.getBoundingClientRect(),f=t.node().getBoundingClientRect(),p=[h.left+h.width/2-U[0]-f.left,h.top+h.height/2-U[1]-f.top];ut.config({color:s}).text(u),ut.move(p)}else a=this.style.stroke||\"black\",i.attr({\"data-stroke\":a}),s=n.hsl(a).darker().toString(),i.style({stroke:s,opacity:1})}).on(\"mousemove.tooltip\",function(t,e){if(0!=n.event.which)return!1;n.select(this).attr(\"data-fill\")&&ut.show()}).on(\"mouseout.tooltip\",function(t,e){ut.hide();var r=n.select(this),i=r.attr(\"data-fill\");i?r.style({fill:i,opacity:r.attr(\"data-opacity\")}):r.style({stroke:r.attr(\"data-stroke\"),opacity:r.attr(\"data-opacity\")})})})}(c),this},f.config=function(t){if(!arguments.length)return l;var e=o.util.cloneJson(t);return e.data.forEach(function(t,e){l.data[e]||(l.data[e]={}),i(l.data[e],o.Axis.defaultConfig().data[0]),i(l.data[e],t)}),i(l.layout,o.Axis.defaultConfig().layout),i(l.layout,e.layout),this},f.getLiveConfig=function(){return u},f.getinputConfig=function(){return c},f.radialScale=function(t){return r},f.angularScale=function(t){return s},f.svg=function(){return t},n.rebind(f,h,\"on\"),f},o.Axis.defaultConfig=function(t,e){return{data:[{t:[1,2,3,4],r:[10,11,12,13],name:\"Line1\",geometry:\"LinePlot\",color:null,strokeDash:\"solid\",strokeColor:null,strokeSize:\"1\",visibleInLegend:!0,opacity:1}],layout:{defaultColorRange:n.scale.category10().range(),title:null,height:450,width:500,margin:{top:40,right:40,bottom:40,left:40},font:{size:12,color:\"gray\",outlineColor:\"white\",family:\"Tahoma, sans-serif\"},direction:\"clockwise\",orientation:0,labelOffset:10,radialAxis:{domain:null,orientation:-45,ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null},angularAxis:{domain:[0,360],ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,labelsVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null,ticksCount:null,ticksStep:null},minorTicks:0,tickLength:null,tickColor:\"silver\",minorTickColor:\"#eee\",backgroundColor:\"none\",needsEndSpacing:null,showLegend:!0,legend:{reverseOrder:!1},opacity:1}}},o.util={},o.DATAEXTENT=\"dataExtent\",o.AREA=\"AreaChart\",o.LINE=\"LinePlot\",o.DOT=\"DotPlot\",o.BAR=\"BarChart\",o.util._override=function(t,e){for(var r in t)r in e&&(e[r]=t[r])},o.util._extend=function(t,e){for(var r in t)e[r]=t[r]},o.util._rndSnd=function(){return 2*Math.random()-1+(2*Math.random()-1)+(2*Math.random()-1)},o.util.dataFromEquation2=function(t,e){var r=e||6;return n.range(0,360+r,r).map(function(e,r){var n=e*Math.PI/180;return[e,t(n)]})},o.util.dataFromEquation=function(t,e,r){var i=e||6,a=[],o=[];n.range(0,360+i,i).forEach(function(e,r){var n=e*Math.PI/180,i=t(n);a.push(e),o.push(i)});var s={t:a,r:o};return r&&(s.name=r),s},o.util.ensureArray=function(t,e){if(\"undefined\"==typeof t)return null;var r=[].concat(t);return n.range(e).map(function(t,e){return r[e]||r[0]})},o.util.fillArrays=function(t,e,r){return e.forEach(function(e,n){t[e]=o.util.ensureArray(t[e],r)}),t},o.util.cloneJson=function(t){return JSON.parse(JSON.stringify(t))},o.util.validateKeys=function(t,e){\"string\"==typeof e&&(e=e.split(\".\"));var r=e.shift();return t[r]&&(!e.length||objHasKeys(t[r],e))},o.util.sumArrays=function(t,e){return n.zip(t,e).map(function(t,e){return n.sum(t)})},o.util.arrayLast=function(t){return t[t.length-1]},o.util.arrayEqual=function(t,e){for(var r=Math.max(t.length,e.length,1);r-- >=0&&t[r]===e[r];);return-2===r},o.util.flattenArray=function(t){for(var e=[];!o.util.arrayEqual(e,t);)e=t,t=[].concat.apply([],t);return t},o.util.deduplicate=function(t){return t.filter(function(t,e,r){return r.indexOf(t)==e})},o.util.convertToCartesian=function(t,e){var r=e*Math.PI/180;return[t*Math.cos(r),t*Math.sin(r)]},o.util.round=function(t,e){var r=e||2,n=Math.pow(10,r);return Math.round(t*n)/n},o.util.getMousePos=function(t){var e=n.mouse(t.node()),r=e[0],i=e[1],a={};return a.x=r,a.y=i,a.pos=e,a.angle=180*(Math.atan2(i,r)+Math.PI)/Math.PI,a.radius=Math.sqrt(r*r+i*i),a},o.util.duplicatesCount=function(t){for(var e,r={},n={},i=0,a=t.length;i<a;i++)(e=t[i])in r?(r[e]++,n[e]=r[e]):r[e]=1;return n},o.util.duplicates=function(t){return Object.keys(o.util.duplicatesCount(t))},o.util.translator=function(t,e,r,n){if(n){var i=r.slice();r=e,e=i}var a=e.reduce(function(t,e){if(\"undefined\"!=typeof t)return t[e]},t);\"undefined\"!=typeof a&&(e.reduce(function(t,r,n){if(\"undefined\"!=typeof t)return n===e.length-1&&delete t[r],t[r]},t),r.reduce(function(t,e,n){return\"undefined\"==typeof t[e]&&(t[e]={}),n===r.length-1&&(t[e]=a),t[e]},t))},o.PolyChart=function(){var t=[o.PolyChart.defaultConfig()],e=n.dispatch(\"hover\"),r={solid:\"none\",dash:[5,2],dot:[2,5]};function a(){var e=t[0].geometryConfig,i=e.container;\"string\"==typeof i&&(i=n.select(i)),i.datum(t).each(function(t,i){var a=!!t[0].data.yStack,o=t.map(function(t,e){return a?n.zip(t.data.t[0],t.data.r[0],t.data.yStack[0]):n.zip(t.data.t[0],t.data.r[0])}),s=e.angularScale,l=e.radialScale.domain()[0],c={bar:function(r,i,a){var o=t[a].data,l=e.radialScale(r[1])-e.radialScale(0),c=e.radialScale(r[2]||0),u=o.barWidth;n.select(this).attr({class:\"mark bar\",d:\"M\"+[[l+c,-u/2],[l+c,u/2],[c,u/2],[c,-u/2]].join(\"L\")+\"Z\",transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0]))+\")\"}})}};c.dot=function(r,i,a){var o=r[2]?[r[0],r[1]+r[2]]:r,s=n.svg.symbol().size(t[a].data.dotSize).type(t[a].data.dotType)(r,i);n.select(this).attr({class:\"mark dot\",d:s,transform:function(t,r){var n,i,a,s=(n=function(t,r){var n=e.radialScale(t[1]),i=(e.angularScale(t[0])+e.orientation)*Math.PI/180;return{r:n,t:i}}(o),i=n.r*Math.cos(n.t),a=n.r*Math.sin(n.t),{x:i,y:a});return\"translate(\"+[s.x,s.y]+\")\"}})};var u=n.svg.line.radial().interpolate(t[0].data.lineInterpolation).radius(function(t){return e.radialScale(t[1])}).angle(function(t){return e.angularScale(t[0])*Math.PI/180});c.line=function(r,i,a){var s=r[2]?o[a].map(function(t,e){return[t[0],t[1]+t[2]]}):o[a];if(n.select(this).each(c.dot).style({opacity:function(e,r){return+t[a].data.dotVisible},fill:d.stroke(r,i,a)}).attr({class:\"mark dot\"}),!(i>0)){var l=n.select(this.parentNode).selectAll(\"path.line\").data([0]);l.enter().insert(\"path\"),l.attr({class:\"line\",d:u(s),transform:function(t,r){return\"rotate(\"+(e.orientation+90)+\")\"},\"pointer-events\":\"none\"}).style({fill:function(t,e){return d.fill(r,i,a)},\"fill-opacity\":0,stroke:function(t,e){return d.stroke(r,i,a)},\"stroke-width\":function(t,e){return d[\"stroke-width\"](r,i,a)},\"stroke-dasharray\":function(t,e){return d[\"stroke-dasharray\"](r,i,a)},opacity:function(t,e){return d.opacity(r,i,a)},display:function(t,e){return d.display(r,i,a)}})}};var h=e.angularScale.range(),f=Math.abs(h[1]-h[0])/o[0].length*Math.PI/180,p=n.svg.arc().startAngle(function(t){return-f/2}).endAngle(function(t){return f/2}).innerRadius(function(t){return e.radialScale(l+(t[2]||0))}).outerRadius(function(t){return e.radialScale(l+(t[2]||0))+e.radialScale(t[1])});c.arc=function(t,r,i){n.select(this).attr({class:\"mark arc\",d:p,transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0])+90)+\")\"}})};var d={fill:function(e,r,n){return t[n].data.color},stroke:function(e,r,n){return t[n].data.strokeColor},\"stroke-width\":function(e,r,n){return t[n].data.strokeSize+\"px\"},\"stroke-dasharray\":function(e,n,i){return r[t[i].data.strokeDash]},opacity:function(e,r,n){return t[n].data.opacity},display:function(e,r,n){return\"undefined\"==typeof t[n].data.visible||t[n].data.visible?\"block\":\"none\"}},g=n.select(this).selectAll(\"g.layer\").data(o);g.enter().append(\"g\").attr({class:\"layer\"});var v=g.selectAll(\"path.mark\").data(function(t,e){return t});v.enter().append(\"path\").attr({class:\"mark\"}),v.style(d).each(c[e.geometryType]),v.exit().remove(),g.exit().remove()})}return a.config=function(e){return arguments.length?(e.forEach(function(e,r){t[r]||(t[r]={}),i(t[r],o.PolyChart.defaultConfig()),i(t[r],e)}),this):t},a.getColorScale=function(){},n.rebind(a,e,\"on\"),a},o.PolyChart.defaultConfig=function(){return{data:{name:\"geom1\",t:[[1,2,3,4]],r:[[1,2,3,4]],dotType:\"circle\",dotSize:64,dotVisible:!1,barWidth:20,color:\"#ffa500\",strokeSize:1,strokeColor:\"silver\",strokeDash:\"solid\",opacity:1,index:0,visible:!0,visibleInLegend:!0},geometryConfig:{geometry:\"LinePlot\",geometryType:\"arc\",direction:\"clockwise\",orientation:0,container:\"body\",radialScale:null,angularScale:null,colorScale:n.scale.category20()}}},o.BarChart=function(){return o.PolyChart()},o.BarChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"bar\"}}},o.AreaChart=function(){return o.PolyChart()},o.AreaChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"arc\"}}},o.DotPlot=function(){return o.PolyChart()},o.DotPlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"dot\",dotType:\"circle\"}}},o.LinePlot=function(){return o.PolyChart()},o.LinePlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"line\"}}},o.Legend=function(){var t=o.Legend.defaultConfig(),e=n.dispatch(\"hover\");function r(){var e=t.legendConfig,a=t.data.map(function(t,r){return[].concat(t).map(function(t,n){var a=i({},e.elements[r]);return a.name=t,a.color=[].concat(e.elements[r].color)[n],a})}),o=n.merge(a);o=o.filter(function(t,r){return e.elements[r]&&(e.elements[r].visibleInLegend||\"undefined\"==typeof e.elements[r].visibleInLegend)}),e.reverseOrder&&(o=o.reverse());var s=e.container;(\"string\"==typeof s||s.nodeName)&&(s=n.select(s));var l=o.map(function(t,e){return t.color}),c=e.fontSize,u=null==e.isContinuous?\"number\"==typeof o[0]:e.isContinuous,h=u?e.height:c*o.length,f=s.classed(\"legend-group\",!0).selectAll(\"svg\").data([0]),p=f.enter().append(\"svg\").attr({width:300,height:h+c,xmlns:\"http://www.w3.org/2000/svg\",\"xmlns:xlink\":\"http://www.w3.org/1999/xlink\",version:\"1.1\"});p.append(\"g\").classed(\"legend-axis\",!0),p.append(\"g\").classed(\"legend-marks\",!0);var d=n.range(o.length),g=n.scale[u?\"linear\":\"ordinal\"]().domain(d).range(l),v=n.scale[u?\"linear\":\"ordinal\"]().domain(d)[u?\"range\":\"rangePoints\"]([0,h]);if(u){var m=f.select(\".legend-marks\").append(\"defs\").append(\"linearGradient\").attr({id:\"grad1\",x1:\"0%\",y1:\"0%\",x2:\"0%\",y2:\"100%\"}).selectAll(\"stop\").data(l);m.enter().append(\"stop\"),m.attr({offset:function(t,e){return e/(l.length-1)*100+\"%\"}}).style({\"stop-color\":function(t,e){return t}}),f.append(\"rect\").classed(\"legend-mark\",!0).attr({height:e.height,width:e.colorBandWidth,fill:\"url(#grad1)\"})}else{var y=f.select(\".legend-marks\").selectAll(\"path.legend-mark\").data(o);y.enter().append(\"path\").classed(\"legend-mark\",!0),y.attr({transform:function(t,e){return\"translate(\"+[c/2,v(e)+c/2]+\")\"},d:function(t,e){var r,i,a,o=t.symbol;return a=3*(i=c),\"line\"===(r=o)?\"M\"+[[-i/2,-i/12],[i/2,-i/12],[i/2,i/12],[-i/2,i/12]]+\"Z\":-1!=n.svg.symbolTypes.indexOf(r)?n.svg.symbol().type(r).size(a)():n.svg.symbol().type(\"square\").size(a)()},fill:function(t,e){return g(e)}}),y.exit().remove()}var x=n.svg.axis().scale(v).orient(\"right\"),b=f.select(\"g.legend-axis\").attr({transform:\"translate(\"+[u?e.colorBandWidth:c,c/2]+\")\"}).call(x);return b.selectAll(\".domain\").style({fill:\"none\",stroke:\"none\"}),b.selectAll(\"line\").style({fill:\"none\",stroke:u?e.textColor:\"none\"}),b.selectAll(\"text\").style({fill:e.textColor,\"font-size\":e.fontSize}).text(function(t,e){return o[e].name}),r}return r.config=function(e){return arguments.length?(i(t,e),this):t},n.rebind(r,e,\"on\"),r},o.Legend.defaultConfig=function(t,e){return{data:[\"a\",\"b\",\"c\"],legendConfig:{elements:[{symbol:\"line\",color:\"red\"},{symbol:\"square\",color:\"yellow\"},{symbol:\"diamond\",color:\"limegreen\"}],height:150,colorBandWidth:30,fontSize:12,container:\"body\",isContinuous:null,textColor:\"grey\",reverseOrder:!1}}},o.tooltipPanel=function(){var t,e,r,a={container:null,hasTick:!1,fontSize:12,color:\"white\",padding:5},s=\"tooltip-\"+o.tooltipPanel.uid++,l=10,c=function(){var n=(t=a.container.selectAll(\"g.\"+s).data([0])).enter().append(\"g\").classed(s,!0).style({\"pointer-events\":\"none\",display:\"none\"});return r=n.append(\"path\").style({fill:\"white\",\"fill-opacity\":.9}).attr({d:\"M0 0\"}),e=n.append(\"text\").attr({dx:a.padding+l,dy:.3*+a.fontSize}),c};return c.text=function(i){var o=n.hsl(a.color).l,s=o>=.5?\"#aaa\":\"white\",u=o>=.5?\"black\":\"white\",h=i||\"\";e.style({fill:u,\"font-size\":a.fontSize+\"px\"}).text(h);var f=a.padding,p=e.node().getBBox(),d={fill:a.color,stroke:s,\"stroke-width\":\"2px\"},g=p.width+2*f+l,v=p.height+2*f;return r.attr({d:\"M\"+[[l,-v/2],[l,-v/4],[a.hasTick?0:l,0],[l,v/4],[l,v/2],[g,v/2],[g,-v/2]].join(\"L\")+\"Z\"}).style(d),t.attr({transform:\"translate(\"+[l,-v/2+2*f]+\")\"}),t.style({display:\"block\"}),c},c.move=function(e){if(t)return t.attr({transform:\"translate(\"+[e[0],e[1]]+\")\"}).style({display:\"block\"}),c},c.hide=function(){if(t)return t.style({display:\"none\"}),c},c.show=function(){if(t)return t.style({display:\"block\"}),c},c.config=function(t){return i(a,t),c},c},o.tooltipPanel.uid=1,o.adapter={},o.adapter.plotly=function(){var t={convert:function(t,e){var r={};if(t.data&&(r.data=t.data.map(function(t,r){var n=i({},t);return[[n,[\"marker\",\"color\"],[\"color\"]],[n,[\"marker\",\"opacity\"],[\"opacity\"]],[n,[\"marker\",\"line\",\"color\"],[\"strokeColor\"]],[n,[\"marker\",\"line\",\"dash\"],[\"strokeDash\"]],[n,[\"marker\",\"line\",\"width\"],[\"strokeSize\"]],[n,[\"marker\",\"symbol\"],[\"dotType\"]],[n,[\"marker\",\"size\"],[\"dotSize\"]],[n,[\"marker\",\"barWidth\"],[\"barWidth\"]],[n,[\"line\",\"interpolation\"],[\"lineInterpolation\"]],[n,[\"showlegend\"],[\"visibleInLegend\"]]].forEach(function(t,r){o.util.translator.apply(null,t.concat(e))}),e||delete n.marker,e&&delete n.groupId,e?(\"LinePlot\"===n.geometry?(n.type=\"scatter\",!0===n.dotVisible?(delete n.dotVisible,n.mode=\"lines+markers\"):n.mode=\"lines\"):\"DotPlot\"===n.geometry?(n.type=\"scatter\",n.mode=\"markers\"):\"AreaChart\"===n.geometry?n.type=\"area\":\"BarChart\"===n.geometry&&(n.type=\"bar\"),delete n.geometry):(\"scatter\"===n.type?\"lines\"===n.mode?n.geometry=\"LinePlot\":\"markers\"===n.mode?n.geometry=\"DotPlot\":\"lines+markers\"===n.mode&&(n.geometry=\"LinePlot\",n.dotVisible=!0):\"area\"===n.type?n.geometry=\"AreaChart\":\"bar\"===n.type&&(n.geometry=\"BarChart\"),delete n.mode,delete n.type),n}),!e&&t.layout&&\"stack\"===t.layout.barmode)){var a=o.util.duplicates(r.data.map(function(t,e){return t.geometry}));r.data.forEach(function(t,e){var n=a.indexOf(t.geometry);-1!=n&&(r.data[e].groupId=n)})}if(t.layout){var s=i({},t.layout);if([[s,[\"plot_bgcolor\"],[\"backgroundColor\"]],[s,[\"showlegend\"],[\"showLegend\"]],[s,[\"radialaxis\"],[\"radialAxis\"]],[s,[\"angularaxis\"],[\"angularAxis\"]],[s.angularaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularaxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularaxis,[\"nticks\"],[\"ticksCount\"]],[s.angularaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularaxis,[\"range\"],[\"domain\"]],[s.angularaxis,[\"endpadding\"],[\"endPadding\"]],[s.radialaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialaxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularAxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularAxis,[\"nticks\"],[\"ticksCount\"]],[s.angularAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularAxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"endpadding\"],[\"endPadding\"]],[s.radialAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialAxis,[\"range\"],[\"domain\"]],[s.font,[\"outlinecolor\"],[\"outlineColor\"]],[s.legend,[\"traceorder\"],[\"reverseOrder\"]],[s,[\"labeloffset\"],[\"labelOffset\"]],[s,[\"defaultcolorrange\"],[\"defaultColorRange\"]]].forEach(function(t,r){o.util.translator.apply(null,t.concat(e))}),e?(\"undefined\"!=typeof s.tickLength&&(s.angularaxis.ticklen=s.tickLength,delete s.tickLength),s.tickColor&&(s.angularaxis.tickcolor=s.tickColor,delete s.tickColor)):(s.angularAxis&&\"undefined\"!=typeof s.angularAxis.ticklen&&(s.tickLength=s.angularAxis.ticklen),s.angularAxis&&\"undefined\"!=typeof s.angularAxis.tickcolor&&(s.tickColor=s.angularAxis.tickcolor)),s.legend&&\"boolean\"!=typeof s.legend.reverseOrder&&(s.legend.reverseOrder=\"normal\"!=s.legend.reverseOrder),s.legend&&\"boolean\"==typeof s.legend.traceorder&&(s.legend.traceorder=s.legend.traceorder?\"reversed\":\"normal\",delete s.legend.reverseOrder),s.margin&&\"undefined\"!=typeof s.margin.t){var l=[\"t\",\"r\",\"b\",\"l\",\"pad\"],c=[\"top\",\"right\",\"bottom\",\"left\",\"pad\"],u={};n.entries(s.margin).forEach(function(t,e){u[c[l.indexOf(t.key)]]=t.value}),s.margin=u}e&&(delete s.needsEndSpacing,delete s.minorTickColor,delete s.minorTicks,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksStep,delete s.angularaxis.rewriteTicks,delete s.angularaxis.nticks,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksStep,delete s.radialaxis.rewriteTicks,delete s.radialaxis.nticks),r.layout=s}return r}};return t}},{\"../../../constants/alignment\":688,\"../../../lib\":719,d3:163}],838:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../../lib\"),a=t(\"../../../components/color\"),o=t(\"./micropolar\"),s=t(\"./undo_manager\"),l=i.extendDeepAll,c=e.exports={};c.framework=function(t){var e,r,i,a,u,h=new s;function f(r,s){return s&&(u=s),n.select(n.select(u).node().parentNode).selectAll(\".svg-container>*:not(.chart-root)\").remove(),e=e?l(e,r):r,i||(i=o.Axis()),a=o.adapter.plotly().convert(e),i.config(a).render(u),t.data=e.data,t.layout=e.layout,c.fillLayout(t),e}return f.isPolar=!0,f.svg=function(){return i.svg()},f.getConfig=function(){return e},f.getLiveConfig=function(){return o.adapter.plotly().convert(i.getLiveConfig(),!0)},f.getLiveScales=function(){return{t:i.angularScale(),r:i.radialScale()}},f.setUndoPoint=function(){var t,n,i=this,a=o.util.cloneJson(e);t=a,n=r,h.add({undo:function(){n&&i(n)},redo:function(){i(t)}}),r=o.util.cloneJson(a)},f.undo=function(){h.undo()},f.redo=function(){h.redo()},f},c.fillLayout=function(t){var e=n.select(t).selectAll(\".plot-container\"),r=e.selectAll(\".svg-container\"),i=t.framework&&t.framework.svg&&t.framework.svg(),o={width:800,height:600,paper_bgcolor:a.background,_container:e,_paperdiv:r,_paper:i};t._fullLayout=l(o,t.layout)}},{\"../../../components/color\":593,\"../../../lib\":719,\"./micropolar\":837,\"./undo_manager\":839,d3:163}],839:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=[],r=-1,n=!1;function i(t,e){return t?(n=!0,t[e](),n=!1,this):this}return{add:function(t){return n?this:(e.splice(r+1,e.length-r),e.push(t),r=e.length-1,this)},setCallback:function(e){t=e},undo:function(){var n=e[r];return n?(i(n,\"undo\"),r-=1,t&&t(n.undo),this):this},redo:function(){var n=e[r+1];return n?(i(n,\"redo\"),r+=1,t&&t(n.redo),this):this},clear:function(){e=[],r=-1},hasUndo:function(){return-1!==r},hasRedo:function(){return r<e.length-1},getCommands:function(){return e},getPreviousCommand:function(){return e[r-1]},getIndex:function(){return r}}}},{}],840:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../plots\"),u=t(\"../../plots/cartesian/axes\"),h=t(\"../cartesian/set_convert\"),f=t(\"./set_convert\"),p=t(\"../cartesian/autorange\").doAutoRange,d=t(\"../cartesian/dragbox\"),g=t(\"../../components/dragelement\"),v=t(\"../../components/fx\"),m=t(\"../../components/titles\"),y=t(\"../cartesian/select\").prepSelect,x=t(\"../cartesian/select\").selectOnClick,b=t(\"../cartesian/select\").clearSelect,_=t(\"../../lib/setcursor\"),w=t(\"../../lib/clear_gl_canvases\"),k=t(\"../../plot_api/subroutines\").redrawReglTraces,T=t(\"../../constants/alignment\").MID_SHIFT,A=t(\"./constants\"),M=t(\"./helpers\"),S=o._,E=o.mod,C=o.deg2rad,L=o.rad2deg;function P(t,e){this.id=e,this.gd=t,this._hasClipOnAxisFalse=null,this.vangles=null,this.radialAxisAngle=null,this.traceHash={},this.layers={},this.clipPaths={},this.clipIds={},this.viewInitial={};var r=t._fullLayout,n=\"clip\"+r._uid+e;this.clipIds.forTraces=n+\"-for-traces\",this.clipPaths.forTraces=r._clips.append(\"clipPath\").attr(\"id\",this.clipIds.forTraces),this.clipPaths.forTraces.append(\"path\"),this.framework=r._polarlayer.append(\"g\").attr(\"class\",e),this.radialTickLayout=null,this.angularTickLayout=null}var O=P.prototype;function z(t){var e=t.ticks+String(t.ticklen)+String(t.showticklabels);return\"side\"in t&&(e+=t.side),e}function I(t,e){return e[o.findIndexOfMin(e,function(e){return o.angleDist(t,e)})]}function D(t,e,r){return e?(t.attr(\"display\",null),t.attr(r)):t&&t.attr(\"display\",\"none\"),t}function R(t,e){return\"translate(\"+t+\",\"+e+\")\"}function F(t){return\"rotate(\"+t+\")\"}e.exports=function(t,e){return new P(t,e)},O.plot=function(t,e){var r=e[this.id];this._hasClipOnAxisFalse=!1;for(var n=0;n<t.length;n++){if(!1===t[n][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(e,r),this.updateLayout(e,r),c.generalUpdatePerTraceModule(this.gd,this,t,r),this.updateFx(e,r)},O.updateLayers=function(t,e){var r=this.layers,i=e.radialaxis,a=e.angularaxis,o=A.layerNames,s=o.indexOf(\"frontplot\"),l=o.slice(0,s),c=\"below traces\"===a.layer,u=\"below traces\"===i.layer;c&&l.push(\"angular-line\"),u&&l.push(\"radial-line\"),c&&l.push(\"angular-axis\"),u&&l.push(\"radial-axis\"),l.push(\"frontplot\"),c||l.push(\"angular-line\"),u||l.push(\"radial-line\"),c||l.push(\"angular-axis\"),u||l.push(\"radial-axis\");var h=this.framework.selectAll(\".polarsublayer\").data(l,String);h.enter().append(\"g\").attr(\"class\",function(t){return\"polarsublayer \"+t}).each(function(t){var e=r[t]=n.select(this);switch(t){case\"frontplot\":e.append(\"g\").classed(\"barlayer\",!0),e.append(\"g\").classed(\"scatterlayer\",!0);break;case\"backplot\":e.append(\"g\").classed(\"maplayer\",!0);break;case\"plotbg\":r.bg=e.append(\"path\");break;case\"radial-grid\":case\"angular-grid\":e.style(\"fill\",\"none\");break;case\"radial-line\":e.append(\"line\").style(\"fill\",\"none\");break;case\"angular-line\":e.append(\"path\").style(\"fill\",\"none\")}}),h.order()},O.updateLayout=function(t,e){var r=this.layers,n=t._size,i=e.radialaxis,a=e.angularaxis,o=e.domain.x,c=e.domain.y;this.xOffset=n.l+n.w*o[0],this.yOffset=n.t+n.h*(1-c[1]);var u=this.xLength=n.w*(o[1]-o[0]),h=this.yLength=n.h*(c[1]-c[0]),f=e.sector;this.sectorInRad=f.map(C);var p,d,g,v,m,y=this.sectorBBox=function(t){var e,r,n,i,a=t[0],o=t[1]-a,s=E(a,360),l=s+o,c=Math.cos(C(s)),u=Math.sin(C(s)),h=Math.cos(C(l)),f=Math.sin(C(l));i=s<=90&&l>=90||s>90&&l>=450?1:u<=0&&f<=0?0:Math.max(u,f);e=s<=180&&l>=180||s>180&&l>=540?-1:c>=0&&h>=0?0:Math.min(c,h);r=s<=270&&l>=270||s>270&&l>=630?-1:u>=0&&f>=0?0:Math.min(u,f);n=l>=360?1:c<=0&&h<=0?0:Math.max(c,h);return[e,r,n,i]}(f),x=y[2]-y[0],b=y[3]-y[1],_=h/u,w=Math.abs(b/x);_>w?(p=u,m=(h-(d=u*w))/n.h/2,g=[o[0],o[1]],v=[c[0]+m,c[1]-m]):(d=h,m=(u-(p=h/w))/n.w/2,g=[o[0]+m,o[1]-m],v=[c[0],c[1]]),this.xLength2=p,this.yLength2=d,this.xDomain2=g,this.yDomain2=v;var k=this.xOffset2=n.l+n.w*g[0],T=this.yOffset2=n.t+n.h*(1-v[1]),A=this.radius=p/x,M=this.innerRadius=e.hole*A,S=this.cx=k-A*y[0],L=this.cy=T+A*y[3],P=this.cxx=S-k,O=this.cyy=L-T;this.radialAxis=this.mockAxis(t,e,i,{_id:\"x\",side:{counterclockwise:\"top\",clockwise:\"bottom\"}[i.side],domain:[M/n.w,A/n.w]}),this.angularAxis=this.mockAxis(t,e,a,{side:\"right\",domain:[0,Math.PI],autorange:!1}),this.doAutoRange(t,e),this.updateAngularAxis(t,e),this.updateRadialAxis(t,e),this.updateRadialAxisTitle(t,e),this.xaxis=this.mockCartesianAxis(t,e,{_id:\"x\",domain:g}),this.yaxis=this.mockCartesianAxis(t,e,{_id:\"y\",domain:v});var z=this.pathSubplot();this.clipPaths.forTraces.select(\"path\").attr(\"d\",z).attr(\"transform\",R(P,O)),r.frontplot.attr(\"transform\",R(k,T)).call(l.setClipUrl,this._hasClipOnAxisFalse?null:this.clipIds.forTraces,this.gd),r.bg.attr(\"d\",z).attr(\"transform\",R(S,L)).call(s.fill,e.bgcolor)},O.mockAxis=function(t,e,r,n){var i=o.extendFlat({anchor:\"free\",position:0},r,n);return f(i,e,t),i},O.mockCartesianAxis=function(t,e,r){var n=this,i=r._id,a=o.extendFlat({type:\"linear\"},r);h(a,t);var s={x:[0,2],y:[1,3]};return a.setRange=function(){var t=n.sectorBBox,r=s[i],o=n.radialAxis._rl,l=(o[1]-o[0])/(1-e.hole);a.range=[t[r[0]]*l,t[r[1]]*l]},a.isPtWithinRange=\"x\"===i?function(t){return n.isPtInside(t)}:function(){return!0},a.setRange(),a.setScale(),a},O.doAutoRange=function(t,e){var r=this.gd,n=this.radialAxis,i=e.radialaxis;n.setScale(),p(r,n);var a=n.range;i.range=a.slice(),i._input.range=a.slice(),n._rl=[n.r2l(a[0],null,\"gregorian\"),n.r2l(a[1],null,\"gregorian\")]},O.updateRadialAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,l=r.innerRadius,c=r.cx,h=r.cy,f=e.radialaxis,p=E(e.sector[0],360),d=r.radialAxis,g=l<a;r.fillViewInitialKey(\"radialaxis.angle\",f.angle),r.fillViewInitialKey(\"radialaxis.range\",d.range.slice()),d.setGeometry(),\"auto\"===d.tickangle&&p>90&&p<=270&&(d.tickangle=180);var v=function(t){return\"translate(\"+(d.l2p(t.x)+l)+\",0)\"},m=z(f);if(r.radialTickLayout!==m&&(i[\"radial-axis\"].selectAll(\".xtick\").remove(),r.radialTickLayout=m),g){d.setScale();var y=u.calcTicks(d),x=u.clipEnds(d,y),b=u.getTickSigns(d)[2];u.drawTicks(n,d,{vals:y,layer:i[\"radial-axis\"],path:u.makeTickPath(d,0,b),transFn:v,crisp:!1}),u.drawGrid(n,d,{vals:x,layer:i[\"radial-grid\"],path:function(t){return r.pathArc(d.r2p(t.x)+l)},transFn:o.noop,crisp:!1}),u.drawLabels(n,d,{vals:y,layer:i[\"radial-axis\"],transFn:v,labelFns:u.makeLabelFns(d,0)})}var _=r.radialAxisAngle=r.vangles?L(I(C(f.angle),r.vangles)):f.angle,w=R(c,h),k=w+F(-_);D(i[\"radial-axis\"],g&&(f.showticklabels||f.ticks),{transform:k}),D(i[\"radial-grid\"],g&&f.showgrid,{transform:w}),D(i[\"radial-line\"].select(\"line\"),g&&f.showline,{x1:l,y1:0,x2:a,y2:0,transform:k}).attr(\"stroke-width\",f.linewidth).call(s.stroke,f.linecolor)},O.updateRadialAxisTitle=function(t,e,r){var n=this.gd,i=this.radius,a=this.cx,o=this.cy,s=e.radialaxis,c=this.id+\"title\",u=void 0!==r?r:this.radialAxisAngle,h=C(u),f=Math.cos(h),p=Math.sin(h),d=0;if(s.title){var g=l.bBox(this.layers[\"radial-axis\"].node()).height,v=s.title.font.size;d=\"counterclockwise\"===s.side?-g-.4*v:g+.8*v}this.layers[\"radial-axis-title\"]=m.draw(n,c,{propContainer:s,propName:this.id+\".radialaxis.title\",placeholder:S(n,\"Click to enter radial axis title\"),attributes:{x:a+i/2*f+d*p,y:o-i/2*p+d*f,\"text-anchor\":\"middle\"},transform:{rotate:-u}})},O.updateAngularAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,l=r.innerRadius,c=r.cx,h=r.cy,f=e.angularaxis,p=r.angularAxis;r.fillViewInitialKey(\"angularaxis.rotation\",f.rotation),p.setGeometry(),p.setScale();var d=function(t){return p.t2g(t.x)};\"linear\"===p.type&&\"radians\"===p.thetaunit&&(p.tick0=L(p.tick0),p.dtick=L(p.dtick));var g=function(t){return R(c+a*Math.cos(t),h-a*Math.sin(t))},v=u.makeLabelFns(p,0).labelStandoff,m={xFn:function(t){var e=d(t);return Math.cos(e)*v},yFn:function(t){var e=d(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(v+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*T)},anchorFn:function(t){var e=d(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},heightFn:function(t,e,r){var n=d(t);return-.5*(1+Math.sin(n))*r}},y=z(f);r.angularTickLayout!==y&&(i[\"angular-axis\"].selectAll(\".\"+p._id+\"tick\").remove(),r.angularTickLayout=y);var x,b=u.calcTicks(p);if(\"linear\"===e.gridshape?(x=b.map(d),o.angleDelta(x[0],x[1])<0&&(x=x.slice().reverse())):x=null,r.vangles=x,\"category\"===p.type&&(b=b.filter(function(t){return o.isAngleInsideSector(d(t),r.sectorInRad)})),p.visible){var _=\"inside\"===p.ticks?-1:1,w=(p.linewidth||1)/2;u.drawTicks(n,p,{vals:b,layer:i[\"angular-axis\"],path:\"M\"+_*w+\",0h\"+_*p.ticklen,transFn:function(t){var e=d(t);return g(e)+F(-L(e))},crisp:!1}),u.drawGrid(n,p,{vals:b,layer:i[\"angular-grid\"],path:function(t){var e=d(t),r=Math.cos(e),n=Math.sin(e);return\"M\"+[c+l*r,h-l*n]+\"L\"+[c+a*r,h-a*n]},transFn:o.noop,crisp:!1}),u.drawLabels(n,p,{vals:b,layer:i[\"angular-axis\"],repositionOnUpdate:!0,transFn:function(t){return g(d(t))},labelFns:m})}D(i[\"angular-line\"].select(\"path\"),f.showline,{d:r.pathSubplot(),transform:R(c,h)}).attr(\"stroke-width\",f.linewidth).call(s.stroke,f.linecolor)},O.updateFx=function(t,e){this.gd._context.staticPlot||(this.updateAngularDrag(t),this.updateRadialDrag(t,e,0),this.updateRadialDrag(t,e,1),this.updateMainDrag(t))},O.updateMainDrag=function(t){var e=this,r=e.gd,o=e.layers,s=t._zoomlayer,l=A.MINZOOM,c=A.OFFEDGE,u=e.radius,h=e.innerRadius,f=e.cx,p=e.cy,m=e.cxx,_=e.cyy,w=e.sectorInRad,k=e.vangles,T=e.radialAxis,S=M.clampTiny,E=M.findXYatLength,C=M.findEnclosingVertexAngles,L=A.cornerHalfWidth,P=A.cornerLen/2,O=d.makeDragger(o,\"path\",\"maindrag\",\"crosshair\");n.select(O).attr(\"d\",e.pathSubplot()).attr(\"transform\",R(f,p));var z,I,D,F,B,N,j,U,V,q={element:O,gd:r,subplot:e.id,plotinfo:{id:e.id,xaxis:e.xaxis,yaxis:e.yaxis},xaxes:[e.xaxis],yaxes:[e.yaxis]};function H(t,e){return Math.sqrt(t*t+e*e)}function G(t,e){return H(t-m,e-_)}function Y(t,e){return Math.atan2(_-e,t-m)}function W(t,e){return[t*Math.cos(e),t*Math.sin(-e)]}function X(t,r){if(0===t)return e.pathSector(2*L);var n=P/t,i=r-n,a=r+n,o=Math.max(0,Math.min(t,u)),s=o-L,l=o+L;return\"M\"+W(s,i)+\"A\"+[s,s]+\" 0,0,0 \"+W(s,a)+\"L\"+W(l,a)+\"A\"+[l,l]+\" 0,0,1 \"+W(l,i)+\"Z\"}function Z(t,r,n){if(0===t)return e.pathSector(2*L);var i,a,o=W(t,r),s=W(t,n),l=S((o[0]+s[0])/2),c=S((o[1]+s[1])/2);if(l&&c){var u=c/l,h=-1/u,f=E(L,u,l,c);i=E(P,h,f[0][0],f[0][1]),a=E(P,h,f[1][0],f[1][1])}else{var p,d;c?(p=P,d=L):(p=L,d=P),i=[[l-p,c-d],[l+p,c-d]],a=[[l-p,c+d],[l+p,c+d]]}return\"M\"+i.join(\"L\")+\"L\"+a.reverse().join(\"L\")+\"Z\"}function J(t,e){return e=Math.max(Math.min(e,u),h),t<c?t=0:u-t<c?t=u:e<c?e=0:u-e<c&&(e=u),Math.abs(e-t)>l?(t<e?(D=t,F=e):(D=e,F=t),!0):(D=null,F=null,!1)}function K(t,e){t=t||B,e=e||\"M0,0Z\",U.attr(\"d\",t),V.attr(\"d\",e),d.transitionZoombox(U,V,N,j),N=!0;var n={};rt(n),r.emit(\"plotly_relayouting\",n)}function $(t,r){var n,i,a=z+t,o=I+r,s=G(z,I),l=Math.min(G(a,o),u),c=Y(z,I);J(s,l)&&(n=B+e.pathSector(F),D&&(n+=e.pathSector(D)),i=X(D,c)+X(F,c)),K(n,i)}function Q(t,e,r,n){var i=M.findIntersectionXY(r,n,r,[t-m,_-e]);return H(i[0],i[1])}function tt(t,r){var n,i,a=z+t,o=I+r,s=Y(z,I),l=Y(a,o),c=C(s,k),h=C(l,k);J(Q(z,I,c[0],c[1]),Math.min(Q(a,o,h[0],h[1]),u))&&(n=B+e.pathSector(F),D&&(n+=e.pathSector(D)),i=[Z(D,c[0],c[1]),Z(F,c[0],c[1])].join(\" \")),K(n,i)}function et(){if(d.removeZoombox(r),null!==D&&null!==F){var t={};rt(t),d.showDoubleClickNotifier(r),a.call(\"_guiRelayout\",r,t)}}function rt(t){var r=T._rl,n=(r[1]-r[0])/(1-h/u)/u,i=[r[0]+(D-h)*n,r[0]+(F-h)*n];t[e.id+\".radialaxis.range\"]=i}function nt(t,n){var i=r._fullLayout.clickmode;if(d.removeZoombox(r),2===t){var o={};for(var s in e.viewInitial)o[e.id+\".\"+s]=e.viewInitial[s];r.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",r,o)}i.indexOf(\"select\")>-1&&1===t&&x(n,r,[e.xaxis],[e.yaxis],e.id,q),i.indexOf(\"event\")>-1&&v.click(r,n,e.id)}q.prepFn=function(t,n,a){var o=r._fullLayout.dragmode,l=O.getBoundingClientRect();if(z=n-l.left,I=a-l.top,k){var c=M.findPolygonOffset(u,w[0],w[1],k);z+=m+c[0],I+=_+c[1]}switch(o){case\"zoom\":q.moveFn=k?tt:$,q.clickFn=nt,q.doneFn=et,function(){D=null,F=null,B=e.pathSubplot(),N=!1;var t=r._fullLayout[e.id];j=i(t.bgcolor).getLuminance(),(U=d.makeZoombox(s,j,f,p,B)).attr(\"fill-rule\",\"evenodd\"),V=d.makeCorners(s,f,p),b(r)}();break;case\"select\":case\"lasso\":y(t,n,a,q,o)}},O.onmousemove=function(t){v.hover(r,t,e.id),r._fullLayout._lasthover=O,r._fullLayout._hoversubplot=e.id},O.onmouseout=function(t){r._dragging||g.unhover(r,t)},g.init(q)},O.updateRadialDrag=function(t,e,r){var i=this,s=i.gd,l=i.layers,c=i.radius,u=i.innerRadius,h=i.cx,f=i.cy,p=i.radialAxis,v=A.radialDragBoxSize,m=v/2;if(p.visible){var y,x,_,T=C(i.radialAxisAngle),M=p._rl,S=M[0],E=M[1],P=M[r],O=.75*(M[1]-M[0])/(1-e.hole)/c;r?(y=h+(c+m)*Math.cos(T),x=f-(c+m)*Math.sin(T),_=\"radialdrag\"):(y=h+(u-m)*Math.cos(T),x=f-(u-m)*Math.sin(T),_=\"radialdrag-inner\");var z,B,N,j=d.makeRectDragger(l,_,\"crosshair\",-m,-m,v,v),U={element:j,gd:s};D(n.select(j),p.visible&&u<c,{transform:R(y,x)}),U.prepFn=function(){z=null,B=null,N=null,U.moveFn=V,U.doneFn=q,b(s)},U.clampFn=function(t,e){return Math.sqrt(t*t+e*e)<A.MINDRAG&&(t=0,e=0),[t,e]},g.init(U)}function V(t,e){if(z)z(t,e);else{var n=[t,-e],a=[Math.cos(T),Math.sin(T)],l=Math.abs(o.dot(n,a)/Math.sqrt(o.dot(n,n)));isNaN(l)||(z=l<.5?H:G)}var c={};!function(t){null!==B?t[i.id+\".radialaxis.angle\"]=B:null!==N&&(t[i.id+\".radialaxis.range[\"+r+\"]\"]=N)}(c),s.emit(\"plotly_relayouting\",c)}function q(){null!==B?a.call(\"_guiRelayout\",s,i.id+\".radialaxis.angle\",B):null!==N&&a.call(\"_guiRelayout\",s,i.id+\".radialaxis.range[\"+r+\"]\",N)}function H(t,e){if(0!==r){var n=y+t,a=x+e;B=Math.atan2(f-a,n-h),i.vangles&&(B=I(B,i.vangles)),B=L(B);var o=R(h,f)+F(-B);l[\"radial-axis\"].attr(\"transform\",o),l[\"radial-line\"].select(\"line\").attr(\"transform\",o);var s=i.gd._fullLayout,c=s[i.id];i.updateRadialAxisTitle(s,c,B)}}function G(t,e){var n=o.dot([t,-e],[Math.cos(T),Math.sin(T)]);if(N=P-O*n,O>0==(r?N>S:N<E)){var l=s._fullLayout,c=l[i.id];p.range[r]=N,p._rl[r]=N,i.updateRadialAxis(l,c),i.xaxis.setRange(),i.xaxis.setScale(),i.yaxis.setRange(),i.yaxis.setScale();var u=!1;for(var h in i.traceHash){var f=i.traceHash[h],d=o.filterVisible(f);f[0][0].trace._module.plot(s,i,d,c),a.traceIs(h,\"gl\")&&d.length&&(u=!0)}u&&(w(s),k(s))}else N=null}},O.updateAngularDrag=function(t){var e=this,r=e.gd,i=e.layers,s=e.radius,c=e.angularAxis,u=e.cx,h=e.cy,f=e.cxx,p=e.cyy,v=A.angularDragBoxSize,m=d.makeDragger(i,\"path\",\"angulardrag\",\"move\"),y={element:m,gd:r};function x(t,e){return Math.atan2(p+v-e,t-f-v)}n.select(m).attr(\"d\",e.pathAnnulus(s,s+v)).attr(\"transform\",R(u,h)).call(_,\"move\");var T,M,S,E,C,P,O=i.frontplot.select(\".scatterlayer\").selectAll(\".trace\"),z=O.selectAll(\".point\"),I=O.selectAll(\".textpoint\");function D(t,s){var d=e.gd._fullLayout,g=d[e.id],v=x(T+t,M+s),m=L(v-P);if(E=S+m,i.frontplot.attr(\"transform\",R(e.xOffset2,e.yOffset2)+F([-m,f,p])),e.vangles){C=e.radialAxisAngle+m;var y=R(u,h)+F(-m),b=R(u,h)+F(-C);i.bg.attr(\"transform\",y),i[\"radial-grid\"].attr(\"transform\",y),i[\"radial-axis\"].attr(\"transform\",b),i[\"radial-line\"].select(\"line\").attr(\"transform\",b),e.updateRadialAxisTitle(d,g,C)}else e.clipPaths.forTraces.select(\"path\").attr(\"transform\",R(f,p)+F(m));z.each(function(){var t=n.select(this),e=l.getTranslate(t);t.attr(\"transform\",R(e.x,e.y)+F([m]))}),I.each(function(){var t=n.select(this),e=t.select(\"text\"),r=l.getTranslate(t);t.attr(\"transform\",F([m,e.attr(\"x\"),e.attr(\"y\")])+R(r.x,r.y))}),c.rotation=o.modHalf(E,360),e.updateAngularAxis(d,g),e._hasClipOnAxisFalse&&!o.isFullCircle(e.sectorInRad)&&O.call(l.hideOutsideRangePoints,e);var _=!1;for(var A in e.traceHash)if(a.traceIs(A,\"gl\")){var D=e.traceHash[A],N=o.filterVisible(D);D[0][0].trace._module.plot(r,e,N,g),N.length&&(_=!0)}_&&(w(r),k(r));var j={};B(j),r.emit(\"plotly_relayouting\",j)}function B(t){t[e.id+\".angularaxis.rotation\"]=E,e.vangles&&(t[e.id+\".radialaxis.angle\"]=C)}function N(){I.select(\"text\").attr(\"transform\",null);var t={};B(t),a.call(\"_guiRelayout\",r,t)}y.prepFn=function(n,i,a){var o=t[e.id];S=o.angularaxis.rotation;var s=m.getBoundingClientRect();T=i-s.left,M=a-s.top,P=x(T,M),y.moveFn=D,y.doneFn=N,b(r)},e.vangles&&!o.isFullCircle(e.sectorInRad)&&(y.prepFn=o.noop,_(n.select(m),null)),g.init(y)},O.isPtInside=function(t){var e=this.sectorInRad,r=this.vangles,n=this.angularAxis.c2g(t.theta),i=this.radialAxis,a=i.c2l(t.r),s=i._rl;return(r?M.isPtInsidePolygon:o.isPtInsideSector)(a,n,s,e,r)},O.pathArc=function(t){var e=this.sectorInRad,r=this.vangles;return(r?M.pathPolygon:o.pathArc)(t,e[0],e[1],r)},O.pathSector=function(t){var e=this.sectorInRad,r=this.vangles;return(r?M.pathPolygon:o.pathSector)(t,e[0],e[1],r)},O.pathAnnulus=function(t,e){var r=this.sectorInRad,n=this.vangles;return(n?M.pathPolygonAnnulus:o.pathAnnulus)(t,e,r[0],r[1],n)},O.pathSubplot=function(){var t=this.innerRadius,e=this.radius;return t?this.pathAnnulus(t,e):this.pathSector(e)},O.fillViewInitialKey=function(t,e){t in this.viewInitial||(this.viewInitial[t]=e)}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../components/titles\":681,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/clear_gl_canvases\":704,\"../../lib/setcursor\":739,\"../../plot_api/subroutines\":758,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../cartesian/autorange\":766,\"../cartesian/dragbox\":775,\"../cartesian/select\":784,\"../cartesian/set_convert\":785,\"../plots\":828,\"./constants\":829,\"./helpers\":830,\"./set_convert\":841,d3:163,tinycolor2:537}],841:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../cartesian/set_convert\"),a=n.deg2rad,o=n.rad2deg;e.exports=function(t,e,r){switch(i(t,r),t._id){case\"x\":case\"radialaxis\":!function(t,e){var r=e._subplot;t.setGeometry=function(){var e=t._rl[0],n=t._rl[1],i=r.innerRadius,a=(r.radius-i)/(n-e),o=i/a,s=e>n?function(t){return t<=0}:function(t){return t>=0};t.c2g=function(r){var n=t.c2l(r)-e;return(s(n)?n:0)+o},t.g2c=function(r){return t.l2c(r+e-o)},t.g2p=function(t){return t*a},t.c2p=function(e){return t.g2p(t.c2g(e))}}}(t,e);break;case\"angularaxis\":!function(t,e){var r=t.type;if(\"linear\"===r){var i=t.d2c,s=t.c2d;t.d2c=function(t,e){return function(t,e){return\"degrees\"===e?a(t):t}(i(t),e)},t.c2d=function(t,e){return s(function(t,e){return\"degrees\"===e?o(t):t}(t,e))}}t.makeCalcdata=function(e,i){var a,o,s=e[i],l=e._length,c=function(r){return t.d2c(r,e.thetaunit)};if(s){if(n.isTypedArray(s)&&\"linear\"===r){if(l===s.length)return s;if(s.subarray)return s.subarray(0,l)}for(a=new Array(l),o=0;o<l;o++)a[o]=c(s[o])}else{var u=i+\"0\",h=\"d\"+i,f=u in e?c(e[u]):0,p=e[h]?c(e[h]):(t.period||2*Math.PI)/l;for(a=new Array(l),o=0;o<l;o++)a[o]=f+o*p}return a},t.setGeometry=function(){var i,s,l,c,u=e.sector,h=u.map(a),f={clockwise:-1,counterclockwise:1}[t.direction],p=a(t.rotation),d=function(t){return f*t+p},g=function(t){return(t-p)/f};switch(r){case\"linear\":s=i=n.identity,c=a,l=o,t.range=n.isFullCircle(h)?[u[0],u[0]+360]:h.map(g).map(o);break;case\"category\":var v=t._categories.length,m=t.period?Math.max(t.period,v):v;0===m&&(m=1),s=c=function(t){return 2*t*Math.PI/m},i=l=function(t){return t*m/Math.PI/2},t.range=[0,m]}t.c2g=function(t){return d(s(t))},t.g2c=function(t){return i(g(t))},t.t2g=function(t){return d(c(t))},t.g2t=function(t){return l(g(t))}}}(t,e)}}},{\"../../lib\":719,\"../cartesian/set_convert\":785}],842:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\"),a=t(\"./domain\").defaults;e.exports=function(t,e,r,o){var s,l,c=o.type,u=o.attributes,h=o.handleDefaults,f=o.partition||\"x\",p=e._subplots[c],d=p.length,g=d&&p[0].replace(/\\d+$/,\"\");function v(t,e){return n.coerce(s,l,u,t,e)}for(var m=0;m<d;m++){var y=p[m];s=t[y]?t[y]:t[y]={},l=i.newContainer(e,y,g),v(\"uirevision\",e.uirevision);var x={};x[f]=[m/d,(m+1)/d],a(l,e,v,x),o.id=y,h(s,l,v,o)}}},{\"../lib\":719,\"../plot_api/plot_template\":757,\"./domain\":792}],843:[function(t,e,r){\"use strict\";var n=t(\"./ternary\"),i=t(\"../../plots/get_data\").getSubplotCalcData,a=t(\"../../lib\").counterRegex;r.name=\"ternary\";var o=r.attr=\"subplot\";r.idRoot=\"ternary\",r.idRegex=r.attrRegex=a(\"ternary\"),(r.attributes={})[o]={valType:\"subplotid\",dflt:\"ternary\",editType:\"calc\"},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t.calcdata,a=e._subplots.ternary,o=0;o<a.length;o++){var s=a[o],l=i(r,\"ternary\",s),c=e[s]._subplot;c||(c=new n({id:s,graphDiv:t,container:e._ternarylayer.node()},e),e[s]._subplot=c),c.plot(l,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.ternary||[],a=0;a<i.length;a++){var o=i[a],s=n[o]._subplot;!e[o]&&s&&(s.plotContainer.remove(),s.clipDef.remove(),s.clipDefRelative.remove(),s.layers[\"a-title\"].remove(),s.layers[\"b-title\"].remove(),s.layers[\"c-title\"].remove())}}},{\"../../lib\":719,\"../../plots/get_data\":802,\"./layout_attributes\":844,\"./layout_defaults\":845,\"./ternary\":846}],844:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"../cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../lib/extend\").extendFlat,l={title:a.title,color:a.color,tickmode:a.tickmode,nticks:s({},a.nticks,{dflt:6,min:1}),tick0:a.tick0,dtick:a.dtick,tickvals:a.tickvals,ticktext:a.ticktext,ticks:a.ticks,ticklen:a.ticklen,tickwidth:a.tickwidth,tickcolor:a.tickcolor,showticklabels:a.showticklabels,showtickprefix:a.showtickprefix,tickprefix:a.tickprefix,showticksuffix:a.showticksuffix,ticksuffix:a.ticksuffix,showexponent:a.showexponent,exponentformat:a.exponentformat,separatethousands:a.separatethousands,tickfont:a.tickfont,tickangle:a.tickangle,tickformat:a.tickformat,tickformatstops:a.tickformatstops,hoverformat:a.hoverformat,showline:s({},a.showline,{dflt:!0}),linecolor:a.linecolor,linewidth:a.linewidth,showgrid:s({},a.showgrid,{dflt:!0}),gridcolor:a.gridcolor,gridwidth:a.gridwidth,layer:a.layer,min:{valType:\"number\",dflt:0,min:0},_deprecated:{title:a._deprecated.title,titlefont:a._deprecated.titlefont}},c=e.exports=o({domain:i({name:\"ternary\"}),bgcolor:{valType:\"color\",dflt:n.background},sum:{valType:\"number\",dflt:1,min:0},aaxis:l,baxis:l,caxis:l},\"plot\",\"from-root\");c.uirevision={valType:\"any\",editType:\"none\"},c.aaxis.uirevision=c.baxis.uirevision=c.caxis.uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":592,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../cartesian/layout_attributes\":779,\"../domain\":792}],845:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../lib\"),o=t(\"../subplot_defaults\"),s=t(\"../cartesian/tick_label_defaults\"),l=t(\"../cartesian/tick_mark_defaults\"),c=t(\"../cartesian/tick_value_defaults\"),u=t(\"../cartesian/line_grid_defaults\"),h=t(\"./layout_attributes\"),f=[\"aaxis\",\"baxis\",\"caxis\"];function p(t,e,r,a){var o,s,l,c=r(\"bgcolor\"),u=r(\"sum\");a.bgColor=n.combine(c,a.paper_bgcolor);for(var h=0;h<f.length;h++)s=t[o=f[h]]||{},(l=i.newContainer(e,o))._name=o,d(s,l,a,e);var p=e.aaxis,g=e.baxis,v=e.caxis;p.min+g.min+v.min>=u&&(p.min=0,g.min=0,v.min=0,t.aaxis&&delete t.aaxis.min,t.baxis&&delete t.baxis.min,t.caxis&&delete t.caxis.min)}function d(t,e,r,n){var i=h[e._name];function o(r,n){return a.coerce(t,e,i,r,n)}o(\"uirevision\",n.uirevision),e.type=\"linear\";var f=o(\"color\"),p=f!==i.color.dflt?f:r.font.color,d=e._name.charAt(0).toUpperCase(),g=\"Component \"+d,v=o(\"title.text\",g);e._hovertitle=v===g?v:d,a.coerceFont(o,\"title.font\",{family:r.font.family,size:Math.round(1.2*r.font.size),color:p}),o(\"min\"),c(t,e,o,\"linear\"),s(t,e,o,\"linear\",{}),l(t,e,o,{outerTicks:!0}),o(\"showticklabels\")&&(a.coerceFont(o,\"tickfont\",{family:r.font.family,size:r.font.size,color:p}),o(\"tickangle\"),o(\"tickformat\")),u(t,e,o,{dfltColor:f,bgColor:r.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:i}),o(\"hoverformat\"),o(\"layer\")}e.exports=function(t,e,r){o(t,e,r,{type:\"ternary\",attributes:h,handleDefaults:p,font:e.font,paper_bgcolor:e.paper_bgcolor})}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../cartesian/line_grid_defaults\":781,\"../cartesian/tick_label_defaults\":786,\"../cartesian/tick_mark_defaults\":787,\"../cartesian/tick_value_defaults\":788,\"../subplot_defaults\":842,\"./layout_attributes\":844}],846:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=o._,l=t(\"../../components/color\"),c=t(\"../../components/drawing\"),u=t(\"../cartesian/set_convert\"),h=t(\"../../lib/extend\").extendFlat,f=t(\"../plots\"),p=t(\"../cartesian/axes\"),d=t(\"../../components/dragelement\"),g=t(\"../../components/fx\"),v=t(\"../../components/titles\"),m=t(\"../cartesian/select\").prepSelect,y=t(\"../cartesian/select\").selectOnClick,x=t(\"../cartesian/select\").clearSelect,b=t(\"../cartesian/constants\");function _(t,e){this.id=t.id,this.graphDiv=t.graphDiv,this.init(e),this.makeFramework(e),this.aTickLayout=null,this.bTickLayout=null,this.cTickLayout=null}e.exports=_;var w=_.prototype;w.init=function(t){this.container=t._ternarylayer,this.defs=t._defs,this.layoutId=t._uid,this.traceHash={},this.layers={}},w.plot=function(t,e){var r=e[this.id],n=e._size;this._hasClipOnAxisFalse=!1;for(var i=0;i<t.length;i++){if(!1===t[i][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(r),this.adjustLayout(r,n),f.generalUpdatePerTraceModule(this.graphDiv,this,t,r),this.layers.plotbg.select(\"path\").call(l.fill,r.bgcolor)},w.makeFramework=function(t){var e=this.graphDiv,r=t[this.id],n=this.clipId=\"clip\"+this.layoutId+this.id,i=this.clipIdRelative=\"clip-relative\"+this.layoutId+this.id;this.clipDef=o.ensureSingleById(t._clips,\"clipPath\",n,function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")}),this.clipDefRelative=o.ensureSingleById(t._clips,\"clipPath\",i,function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")}),this.plotContainer=o.ensureSingle(this.container,\"g\",this.id),this.updateLayers(r),c.setClipUrl(this.layers.backplot,n,e),c.setClipUrl(this.layers.grids,n,e)},w.updateLayers=function(t){var e=this.layers,r=[\"draglayer\",\"plotbg\",\"backplot\",\"grids\"];\"below traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"below traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"below traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\"),r.push(\"frontplot\"),\"above traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"above traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"above traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\");var i=this.plotContainer.selectAll(\"g.toplevel\").data(r,String),a=[\"agrid\",\"bgrid\",\"cgrid\"];i.enter().append(\"g\").attr(\"class\",function(t){return\"toplevel \"+t}).each(function(t){var r=n.select(this);e[t]=r,\"frontplot\"===t?r.append(\"g\").classed(\"scatterlayer\",!0):\"backplot\"===t?r.append(\"g\").classed(\"maplayer\",!0):\"plotbg\"===t?r.append(\"path\").attr(\"d\",\"M0,0Z\"):\"aline\"===t||\"bline\"===t||\"cline\"===t?r.append(\"path\"):\"grids\"===t&&a.forEach(function(t){e[t]=r.append(\"g\").classed(\"grid \"+t,!0)})}),i.order()};var k=Math.sqrt(4/3);w.adjustLayout=function(t,e){var r,n,i,a,o,s,f=this,p=t.domain,d=(p.x[0]+p.x[1])/2,g=(p.y[0]+p.y[1])/2,v=p.x[1]-p.x[0],m=p.y[1]-p.y[0],y=v*e.w,x=m*e.h,b=t.sum,_=t.aaxis.min,w=t.baxis.min,T=t.caxis.min;y>k*x?i=(a=x)*k:a=(i=y)/k,o=v*i/y,s=m*a/x,r=e.l+e.w*d-i/2,n=e.t+e.h*(1-g)-a/2,f.x0=r,f.y0=n,f.w=i,f.h=a,f.sum=b,f.xaxis={type:\"linear\",range:[_+2*T-b,b-_-2*w],domain:[d-o/2,d+o/2],_id:\"x\"},u(f.xaxis,f.graphDiv._fullLayout),f.xaxis.setScale(),f.xaxis.isPtWithinRange=function(t){return t.a>=f.aaxis.range[0]&&t.a<=f.aaxis.range[1]&&t.b>=f.baxis.range[1]&&t.b<=f.baxis.range[0]&&t.c>=f.caxis.range[1]&&t.c<=f.caxis.range[0]},f.yaxis={type:\"linear\",range:[_,b-w-T],domain:[g-s/2,g+s/2],_id:\"y\"},u(f.yaxis,f.graphDiv._fullLayout),f.yaxis.setScale(),f.yaxis.isPtWithinRange=function(){return!0};var A=f.yaxis.domain[0],M=f.aaxis=h({},t.aaxis,{range:[_,b-w-T],side:\"left\",tickangle:(+t.aaxis.tickangle||0)-30,domain:[A,A+s*k],anchor:\"free\",position:0,_id:\"y\",_length:i});u(M,f.graphDiv._fullLayout),M.setScale();var S=f.baxis=h({},t.baxis,{range:[b-_-T,w],side:\"bottom\",domain:f.xaxis.domain,anchor:\"free\",position:0,_id:\"x\",_length:i});u(S,f.graphDiv._fullLayout),S.setScale();var E=f.caxis=h({},t.caxis,{range:[b-_-w,T],side:\"right\",tickangle:(+t.caxis.tickangle||0)+30,domain:[A,A+s*k],anchor:\"free\",position:0,_id:\"y\",_length:i});u(E,f.graphDiv._fullLayout),E.setScale();var C=\"M\"+r+\",\"+(n+a)+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";f.clipDef.select(\"path\").attr(\"d\",C),f.layers.plotbg.select(\"path\").attr(\"d\",C);var L=\"M0,\"+a+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";f.clipDefRelative.select(\"path\").attr(\"d\",L);var P=\"translate(\"+r+\",\"+n+\")\";f.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",P),f.clipDefRelative.select(\"path\").attr(\"transform\",null);var O=\"translate(\"+(r-S._offset)+\",\"+(n+a)+\")\";f.layers.baxis.attr(\"transform\",O),f.layers.bgrid.attr(\"transform\",O);var z=\"translate(\"+(r+i/2)+\",\"+n+\")rotate(30)translate(0,\"+-M._offset+\")\";f.layers.aaxis.attr(\"transform\",z),f.layers.agrid.attr(\"transform\",z);var I=\"translate(\"+(r+i/2)+\",\"+n+\")rotate(-30)translate(0,\"+-E._offset+\")\";f.layers.caxis.attr(\"transform\",I),f.layers.cgrid.attr(\"transform\",I),f.drawAxes(!0),f.layers.aline.select(\"path\").attr(\"d\",M.showline?\"M\"+r+\",\"+(n+a)+\"l\"+i/2+\",-\"+a:\"M0,0\").call(l.stroke,M.linecolor||\"#000\").style(\"stroke-width\",(M.linewidth||0)+\"px\"),f.layers.bline.select(\"path\").attr(\"d\",S.showline?\"M\"+r+\",\"+(n+a)+\"h\"+i:\"M0,0\").call(l.stroke,S.linecolor||\"#000\").style(\"stroke-width\",(S.linewidth||0)+\"px\"),f.layers.cline.select(\"path\").attr(\"d\",E.showline?\"M\"+(r+i/2)+\",\"+n+\"l\"+i/2+\",\"+a:\"M0,0\").call(l.stroke,E.linecolor||\"#000\").style(\"stroke-width\",(E.linewidth||0)+\"px\"),f.graphDiv._context.staticPlot||f.initInteractions(),c.setClipUrl(f.layers.frontplot,f._hasClipOnAxisFalse?null:f.clipId,f.graphDiv)},w.drawAxes=function(t){var e=this.graphDiv,r=this.id.substr(7)+\"title\",n=this.layers,i=this.aaxis,a=this.baxis,o=this.caxis;if(this.drawAx(i),this.drawAx(a),this.drawAx(o),t){var l=Math.max(i.showticklabels?i.tickfont.size/2:0,(o.showticklabels?.75*o.tickfont.size:0)+(\"outside\"===o.ticks?.87*o.ticklen:0)),c=(a.showticklabels?a.tickfont.size:0)+(\"outside\"===a.ticks?a.ticklen:0)+3;n[\"a-title\"]=v.draw(e,\"a\"+r,{propContainer:i,propName:this.id+\".aaxis.title\",placeholder:s(e,\"Click to enter Component A title\"),attributes:{x:this.x0+this.w/2,y:this.y0-i.title.font.size/3-l,\"text-anchor\":\"middle\"}}),n[\"b-title\"]=v.draw(e,\"b\"+r,{propContainer:a,propName:this.id+\".baxis.title\",placeholder:s(e,\"Click to enter Component B title\"),attributes:{x:this.x0-c,y:this.y0+this.h+.83*a.title.font.size+c,\"text-anchor\":\"middle\"}}),n[\"c-title\"]=v.draw(e,\"c\"+r,{propContainer:o,propName:this.id+\".caxis.title\",placeholder:s(e,\"Click to enter Component C title\"),attributes:{x:this.x0+this.w+c,y:this.y0+this.h+.83*o.title.font.size+c,\"text-anchor\":\"middle\"}})}},w.drawAx=function(t){var e,r=this.graphDiv,n=t._name,i=n.charAt(0),a=t._id,s=this.layers[n],l=i+\"tickLayout\",c=(e=t).ticks+String(e.ticklen)+String(e.showticklabels);this[l]!==c&&(s.selectAll(\".\"+a+\"tick\").remove(),this[l]=c),t.setScale();var u=p.calcTicks(t),h=p.clipEnds(t,u),f=p.makeTransFn(t),d=p.getTickSigns(t)[2],g=o.deg2rad(30),v=d*(t.linewidth||1)/2,m=d*t.ticklen,y=this.w,x=this.h,b=\"b\"===i?\"M0,\"+v+\"l\"+Math.sin(g)*m+\",\"+Math.cos(g)*m:\"M\"+v+\",0l\"+Math.cos(g)*m+\",\"+-Math.sin(g)*m,_={a:\"M0,0l\"+x+\",-\"+y/2,b:\"M0,0l-\"+y/2+\",-\"+x,c:\"M0,0l-\"+x+\",\"+y/2}[i];p.drawTicks(r,t,{vals:\"inside\"===t.ticks?h:u,layer:s,path:b,transFn:f,crisp:!1}),p.drawGrid(r,t,{vals:h,layer:this.layers[i+\"grid\"],path:_,transFn:f,crisp:!1}),p.drawLabels(r,t,{vals:u,layer:s,transFn:f,labelFns:p.makeLabelFns(t,0,30)})};var T=b.MINZOOM/2+.87,A=\"m-0.87,.5h\"+T+\"v3h-\"+(T+5.2)+\"l\"+(T/2+2.6)+\",-\"+(.87*T+4.5)+\"l2.6,1.5l-\"+T/2+\",\"+.87*T+\"Z\",M=\"m0.87,.5h-\"+T+\"v3h\"+(T+5.2)+\"l-\"+(T/2+2.6)+\",-\"+(.87*T+4.5)+\"l-2.6,1.5l\"+T/2+\",\"+.87*T+\"Z\",S=\"m0,1l\"+T/2+\",\"+.87*T+\"l2.6,-1.5l-\"+(T/2+2.6)+\",-\"+(.87*T+4.5)+\"l-\"+(T/2+2.6)+\",\"+(.87*T+4.5)+\"l2.6,1.5l\"+T/2+\",-\"+.87*T+\"Z\",E=\"m0.5,0.5h5v-2h-5v-5h-2v5h-5v2h5v5h2Z\",C=!0;function L(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}w.initInteractions=function(){var t,e,r,n,u,h,f,p,v,_,w=this,T=w.layers.plotbg.select(\"path\").node(),P=w.graphDiv,O=P._fullLayout._zoomlayer,z={element:T,gd:P,plotinfo:{id:w.id,xaxis:w.xaxis,yaxis:w.yaxis},subplot:w.id,prepFn:function(a,o,s){z.xaxes=[w.xaxis],z.yaxes=[w.yaxis];var c=P._fullLayout.dragmode;z.minDrag=\"lasso\"===c?1:void 0,\"zoom\"===c?(z.moveFn=N,z.clickFn=D,z.doneFn=j,function(a,o,s){var c=T.getBoundingClientRect();t=o-c.left,e=s-c.top,r={a:w.aaxis.range[0],b:w.baxis.range[1],c:w.caxis.range[1]},u=r,n=w.aaxis.range[1]-r.a,h=i(w.graphDiv._fullLayout[w.id].bgcolor).getLuminance(),f=\"M0,\"+w.h+\"L\"+w.w/2+\", 0L\"+w.w+\",\"+w.h+\"Z\",p=!1,v=O.append(\"path\").attr(\"class\",\"zoombox\").attr(\"transform\",\"translate(\"+w.x0+\", \"+w.y0+\")\").style({fill:h>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"d\",f),_=O.append(\"path\").attr(\"class\",\"zoombox-corners\").attr(\"transform\",\"translate(\"+w.x0+\", \"+w.y0+\")\").style({fill:l.background,stroke:l.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"d\",\"M0,0Z\"),x(P)}(0,o,s)):\"pan\"===c?(z.moveFn=U,z.clickFn=D,z.doneFn=V,r={a:w.aaxis.range[0],b:w.baxis.range[1],c:w.caxis.range[1]},u=r,x(P)):\"select\"!==c&&\"lasso\"!==c||m(a,o,s,z,c)}};function I(t){var e={};return e[w.id+\".aaxis.min\"]=t.a,e[w.id+\".baxis.min\"]=t.b,e[w.id+\".caxis.min\"]=t.c,e}function D(t,e){var r=P._fullLayout.clickmode;L(P),2===t&&(P.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",P,I({a:0,b:0,c:0}))),r.indexOf(\"select\")>-1&&1===t&&y(e,P,[w.xaxis],[w.yaxis],w.id,z),r.indexOf(\"event\")>-1&&g.click(P,e,w.id)}function R(t,e){return 1-e/w.h}function F(t,e){return 1-(t+(w.h-e)/Math.sqrt(3))/w.w}function B(t,e){return(t-(w.h-e)/Math.sqrt(3))/w.w}function N(i,a){var o=t+i,s=e+a,l=Math.max(0,Math.min(1,R(0,e),R(0,s))),c=Math.max(0,Math.min(1,F(t,e),F(o,s))),d=Math.max(0,Math.min(1,B(t,e),B(o,s))),g=(l/2+d)*w.w,m=(1-l/2-c)*w.w,y=(g+m)/2,x=m-g,T=(1-l)*w.h,C=T-x/k;x<b.MINZOOM?(u=r,v.attr(\"d\",f),_.attr(\"d\",\"M0,0Z\")):(u={a:r.a+l*n,b:r.b+c*n,c:r.c+d*n},v.attr(\"d\",f+\"M\"+g+\",\"+T+\"H\"+m+\"L\"+y+\",\"+C+\"L\"+g+\",\"+T+\"Z\"),_.attr(\"d\",\"M\"+t+\",\"+e+E+\"M\"+g+\",\"+T+A+\"M\"+m+\",\"+T+M+\"M\"+y+\",\"+C+S)),p||(v.transition().style(\"fill\",h>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),_.transition().style(\"opacity\",1).duration(200),p=!0),P.emit(\"plotly_relayouting\",I(u))}function j(){L(P),u!==r&&(a.call(\"_guiRelayout\",P,I(u)),C&&P.data&&P._context.showTips&&(o.notifier(s(P,\"Double-click to zoom back out\"),\"long\"),C=!1))}function U(t,e){var n=t/w.xaxis._m,i=e/w.yaxis._m,a=[(u={a:r.a-i,b:r.b+(n+i)/2,c:r.c-(n-i)/2}).a,u.b,u.c].sort(),o=a.indexOf(u.a),s=a.indexOf(u.b),l=a.indexOf(u.c);a[0]<0&&(a[1]+a[0]/2<0?(a[2]+=a[0]+a[1],a[0]=a[1]=0):(a[2]+=a[0]/2,a[1]+=a[0]/2,a[0]=0),u={a:a[o],b:a[s],c:a[l]},e=(r.a-u.a)*w.yaxis._m,t=(r.c-u.c-r.b+u.b)*w.xaxis._m);var h=\"translate(\"+(w.x0+t)+\",\"+(w.y0+e)+\")\";w.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",h);var f=\"translate(\"+-t+\",\"+-e+\")\";w.clipDefRelative.select(\"path\").attr(\"transform\",f),w.aaxis.range=[u.a,w.sum-u.b-u.c],w.baxis.range=[w.sum-u.a-u.c,u.b],w.caxis.range=[w.sum-u.a-u.b,u.c],w.drawAxes(!1),w._hasClipOnAxisFalse&&w.plotContainer.select(\".scatterlayer\").selectAll(\".trace\").call(c.hideOutsideRangePoints,w),P.emit(\"plotly_relayouting\",I(u))}function V(){a.call(\"_guiRelayout\",P,I(u))}T.onmousemove=function(t){g.hover(P,t,w.id),P._fullLayout._lasthover=T,P._fullLayout._hoversubplot=w.id},T.onmouseout=function(t){P._dragging||d.unhover(P,t)},d.init(z)}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../components/titles\":681,\"../../lib\":719,\"../../lib/extend\":710,\"../../registry\":847,\"../cartesian/axes\":767,\"../cartesian/constants\":773,\"../cartesian/select\":784,\"../cartesian/set_convert\":785,\"../plots\":828,d3:163,tinycolor2:537}],847:[function(t,e,r){\"use strict\";var n=t(\"./lib/loggers\"),i=t(\"./lib/noop\"),a=t(\"./lib/push_unique\"),o=t(\"./lib/is_plain_object\"),s=t(\"./lib/dom\").addStyleRule,l=t(\"./lib/extend\"),c=t(\"./plots/attributes\"),u=t(\"./plots/layout_attributes\"),h=l.extendFlat,f=l.extendDeepAll;function p(t){var e=t.name,i=t.categories,a=t.meta;if(r.modules[e])n.log(\"Type \"+e+\" already registered\");else{r.subplotsRegistry[t.basePlotModule.name]||function(t){var e=t.name;if(r.subplotsRegistry[e])return void n.log(\"Plot type \"+e+\" already registered.\");for(var i in m(t),r.subplotsRegistry[e]=t,r.componentsRegistry)b(i,t.name)}(t.basePlotModule);for(var o={},l=0;l<i.length;l++)o[i[l]]=!0,r.allCategories[i[l]]=!0;for(var c in r.modules[e]={_module:t,categories:o},a&&Object.keys(a).length&&(r.modules[e].meta=a),r.allTypes.push(e),r.componentsRegistry)y(c,e);t.layoutAttributes&&h(r.traceLayoutAttributes,t.layoutAttributes);var u=t.basePlotModule,f=u.name;if(\"mapbox\"===f){var p=u.constants.styleRules;for(var d in p)s(\".js-plotly-plot .plotly .mapboxgl-\"+d,p[d])}\"geo\"!==f&&\"mapbox\"!==f||void 0===typeof window||void 0!==window.PlotlyGeoAssets||(window.PlotlyGeoAssets={topojson:{}})}}function d(t){if(\"string\"!=typeof t.name)throw new Error(\"Component module *name* must be a string.\");var e=t.name;for(var n in r.componentsRegistry[e]=t,t.layoutAttributes&&(t.layoutAttributes._isLinkedToArray&&a(r.layoutArrayContainers,e),m(t)),r.modules)y(e,n);for(var i in r.subplotsRegistry)b(e,i);for(var o in r.transformsRegistry)x(e,o);t.schema&&t.schema.layout&&f(u,t.schema.layout)}function g(t){if(\"string\"!=typeof t.name)throw new Error(\"Transform module *name* must be a string.\");var e=\"Transform module \"+t.name,i=\"function\"==typeof t.transform,a=\"function\"==typeof t.calcTransform;if(!i&&!a)throw new Error(e+\" is missing a *transform* or *calcTransform* method.\");for(var s in i&&a&&n.log([e+\" has both a *transform* and *calcTransform* methods.\",\"Please note that all *transform* methods are executed\",\"before all *calcTransform* methods.\"].join(\" \")),o(t.attributes)||n.log(e+\" registered without an *attributes* object.\"),\"function\"!=typeof t.supplyDefaults&&n.log(e+\" registered without a *supplyDefaults* method.\"),r.transformsRegistry[t.name]=t,r.componentsRegistry)x(s,t.name)}function v(t){var e=t.name,n=e.split(\"-\")[0],i=t.dictionary,a=t.format,o=i&&Object.keys(i).length,s=a&&Object.keys(a).length,l=r.localeRegistry,c=l[e];if(c||(l[e]=c={}),n!==e){var u=l[n];u||(l[n]=u={}),o&&u.dictionary===c.dictionary&&(u.dictionary=i),s&&u.format===c.format&&(u.format=a)}o&&(c.dictionary=i),s&&(c.format=a)}function m(t){if(t.layoutAttributes){var e=t.layoutAttributes._arrayAttrRegexps;if(e)for(var n=0;n<e.length;n++)a(r.layoutArrayRegexes,e[n])}}function y(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.traces){var i=n.traces[e];i&&f(r.modules[e]._module.attributes,i)}}function x(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.transforms){var i=n.transforms[e];i&&f(r.transformsRegistry[e].attributes,i)}}function b(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.subplots){var i=r.subplotsRegistry[e],a=i.layoutAttributes,o=\"subplot\"===i.attr?i.name:i.attr;Array.isArray(o)&&(o=o[0]);var s=n.subplots[o];a&&s&&f(a,s)}}function _(t){return\"object\"==typeof t&&(t=t.type),t}r.modules={},r.allCategories={},r.allTypes=[],r.subplotsRegistry={},r.transformsRegistry={},r.componentsRegistry={},r.layoutArrayContainers=[],r.layoutArrayRegexes=[],r.traceLayoutAttributes={},r.localeRegistry={},r.apiMethodRegistry={},r.collectableSubplotTypes=null,r.register=function(t){if(r.collectableSubplotTypes=null,!t)throw new Error(\"No argument passed to Plotly.register.\");t&&!Array.isArray(t)&&(t=[t]);for(var e=0;e<t.length;e++){var n=t[e];if(!n)throw new Error(\"Invalid module was attempted to be registered!\");switch(n.moduleType){case\"trace\":p(n);break;case\"transform\":g(n);break;case\"component\":d(n);break;case\"locale\":v(n);break;case\"apiMethod\":var i=n.name;r.apiMethodRegistry[i]=n.fn;break;default:throw new Error(\"Invalid module was attempted to be registered!\")}}},r.getModule=function(t){var e=r.modules[_(t)];return!!e&&e._module},r.traceIs=function(t,e){if(\"various\"===(t=_(t)))return!1;var i=r.modules[t];return i||(t&&\"area\"!==t&&n.log(\"Unrecognized trace type \"+t+\".\"),i=r.modules[c.type.dflt]),!!i.categories[e]},r.getTransformIndices=function(t,e){for(var r=[],n=t.transforms||[],i=0;i<n.length;i++)n[i].type===e&&r.push(i);return r},r.hasTransform=function(t,e){for(var r=t.transforms||[],n=0;n<r.length;n++)if(r[n].type===e)return!0;return!1},r.getComponentMethod=function(t,e){var n=r.componentsRegistry[t];return n&&n[e]||i},r.call=function(){var t=arguments[0],e=[].slice.call(arguments,1);return r.apiMethodRegistry[t].apply(null,e)}},{\"./lib/dom\":708,\"./lib/extend\":710,\"./lib/is_plain_object\":720,\"./lib/loggers\":723,\"./lib/noop\":728,\"./lib/push_unique\":733,\"./plots/attributes\":764,\"./plots/layout_attributes\":819}],848:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=i.extendFlat,o=i.extendDeep;function s(t){var e;switch(t){case\"themes__thumb\":e={autosize:!0,width:150,height:150,title:{text:\"\"},showlegend:!1,margin:{l:5,r:5,t:5,b:5,pad:0},annotations:[]};break;case\"thumbnail\":e={title:{text:\"\"},hidesources:!0,showlegend:!1,borderwidth:0,bordercolor:\"\",margin:{l:1,r:1,t:1,b:1,pad:0},annotations:[]};break;default:e={}}return e}e.exports=function(t,e){var r;t.framework&&t.framework.isPolar&&(t=t.framework.getConfig());var i,l=t.data,c=t.layout,u=o([],l),h=o({},c,s(e.tileClass)),f=t._context||{};if(e.width&&(h.width=e.width),e.height&&(h.height=e.height),\"thumbnail\"===e.tileClass||\"themes__thumb\"===e.tileClass){h.annotations=[];var p=Object.keys(h);for(r=0;r<p.length;r++)i=p[r],[\"xaxis\",\"yaxis\",\"zaxis\"].indexOf(i.slice(0,5))>-1&&(h[p[r]].title={text:\"\"});for(r=0;r<u.length;r++){var d=u[r];d.showscale=!1,d.marker&&(d.marker.showscale=!1),n.traceIs(d,\"pie-like\")&&(d.textposition=\"none\")}}if(Array.isArray(e.annotations))for(r=0;r<e.annotations.length;r++)h.annotations.push(e.annotations[r]);var g=Object.keys(h).filter(function(t){return t.match(/^scene\\d*$/)});if(g.length){var v={};for(\"thumbnail\"===e.tileClass&&(v={title:{text:\"\"},showaxeslabels:!1,showticklabels:!1,linetickenable:!1}),r=0;r<g.length;r++){var m=h[g[r]];m.xaxis||(m.xaxis={}),m.yaxis||(m.yaxis={}),m.zaxis||(m.zaxis={}),a(m.xaxis,v),a(m.yaxis,v),a(m.zaxis,v),m._scene=null}}var y=document.createElement(\"div\");e.tileClass&&(y.className=e.tileClass);var x={gd:y,td:y,layout:h,data:u,config:{staticPlot:void 0===e.staticPlot||e.staticPlot,plotGlPixelRatio:void 0===e.plotGlPixelRatio?2:e.plotGlPixelRatio,displaylogo:e.displaylogo||!1,showLink:e.showLink||!1,showTips:e.showTips||!1,mapboxAccessToken:f.mapboxAccessToken}};return\"transparent\"!==e.setBackground&&(x.config.setBackground=e.setBackground||\"opaque\"),x.gd.defaultLayout=s(e.tileClass),x}},{\"../lib\":719,\"../registry\":847}],849:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/to_image\"),a=t(\"./filesaver\"),o=t(\"./helpers\");e.exports=function(t,e){var r;return n.isPlainObject(t)||(r=n.getGraphDiv(t)),(e=e||{}).format=e.format||\"png\",e.imageDataOnly=!0,new Promise(function(s,l){r&&r._snapshotInProgress&&l(new Error(\"Snapshotting already in progress.\")),n.isIE()&&\"svg\"!==e.format&&l(new Error(o.MSG_IE_BAD_FORMAT)),r&&(r._snapshotInProgress=!0);var c=i(t,e),u=e.filename||t.fn||\"newplot\";u+=\".\"+e.format,c.then(function(t){return r&&(r._snapshotInProgress=!1),a(t,u,e.format)}).then(function(t){s(t)}).catch(function(t){r&&(r._snapshotInProgress=!1),l(t)})})}},{\"../lib\":719,\"../plot_api/to_image\":760,\"./filesaver\":850,\"./helpers\":851}],850:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"./helpers\");e.exports=function(t,e,r){var a=document.createElement(\"a\"),o=\"download\"in a;return new Promise(function(s,l){var c,u;if(n.isIE9orBelow()&&l(new Error(\"IE < 10 unsupported\")),n.isSafari()){var h=\"svg\"===r?\",\":\";base64,\";return i.octetStream(h+encodeURIComponent(t)),s(e)}return n.isIE()?(c=i.createBlob(t,\"svg\"),window.navigator.msSaveBlob(c,e),c=null,s(e)):o?(c=i.createBlob(t,r),u=i.createObjectURL(c),a.href=u,a.download=e,document.body.appendChild(a),a.click(),document.body.removeChild(a),i.revokeObjectURL(u),c=null,s(e)):void l(new Error(\"download error\"))})}},{\"../lib\":719,\"./helpers\":851}],851:[function(t,e,r){\"use strict\";var n=t(\"../registry\");r.getDelay=function(t){return t._has&&(t._has(\"gl3d\")||t._has(\"gl2d\")||t._has(\"mapbox\"))?500:0},r.getRedrawFunc=function(t){return function(){var e=t._fullLayout||{};!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r||n.getComponentMethod(\"colorbar\",\"draw\")(t)}},r.encodeSVG=function(t){return\"data:image/svg+xml,\"+encodeURIComponent(t)};var i=window.URL||window.webkitURL;r.createObjectURL=function(t){return i.createObjectURL(t)},r.revokeObjectURL=function(t){return i.revokeObjectURL(t)},r.createBlob=function(t,e){if(\"svg\"===e)return new window.Blob([t],{type:\"image/svg+xml;charset=utf-8\"});var r=function(t){for(var e=t.length,r=new ArrayBuffer(e),n=new Uint8Array(r),i=0;i<e;i++)n[i]=t.charCodeAt(i);return r}(window.atob(t));return new window.Blob([r],{type:\"image/\"+e})},r.octetStream=function(t){document.location.href=\"data:application/octet-stream\"+t},r.IMAGE_URL_PREFIX=/^data:image\\/\\w+;base64,/,r.MSG_IE_BAD_FORMAT=\"Sorry IE does not support downloading from canvas. Try {format:'svg'} instead.\"},{\"../registry\":847}],852:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i={getDelay:n.getDelay,getRedrawFunc:n.getRedrawFunc,clone:t(\"./cloneplot\"),toSVG:t(\"./tosvg\"),svgToImg:t(\"./svgtoimg\"),toImage:t(\"./toimage\"),downloadImage:t(\"./download\")};e.exports=i},{\"./cloneplot\":848,\"./download\":849,\"./helpers\":851,\"./svgtoimg\":853,\"./toimage\":854,\"./tosvg\":855}],853:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"events\").EventEmitter,a=t(\"./helpers\");e.exports=function(t){var e=t.emitter||new i,r=new Promise(function(i,o){var s=window.Image,l=t.svg,c=t.format||\"png\";if(n.isIE()&&\"svg\"!==c){var u=new Error(a.MSG_IE_BAD_FORMAT);return o(u),t.promise?r:e.emit(\"error\",u)}var h,f,p=t.canvas,d=t.scale||1,g=t.width||300,v=t.height||150,m=d*g,y=d*v,x=p.getContext(\"2d\"),b=new s;\"svg\"===c||n.isIE9orBelow()||n.isSafari()?f=a.encodeSVG(l):(h=a.createBlob(l,\"svg\"),f=a.createObjectURL(h)),p.width=m,p.height=y,b.onload=function(){var r;switch(h=null,a.revokeObjectURL(f),\"svg\"!==c&&x.drawImage(b,0,0,m,y),c){case\"jpeg\":r=p.toDataURL(\"image/jpeg\");break;case\"png\":r=p.toDataURL(\"image/png\");break;case\"webp\":r=p.toDataURL(\"image/webp\");break;case\"svg\":r=f;break;default:var n=\"Image format is not jpeg, png, svg or webp.\";if(o(new Error(n)),!t.promise)return e.emit(\"error\",n)}i(r),t.promise||e.emit(\"success\",r)},b.onerror=function(r){if(h=null,a.revokeObjectURL(f),o(r),!t.promise)return e.emit(\"error\",r)},b.src=f});return t.promise?r:e}},{\"../lib\":719,\"./helpers\":851,events:104}],854:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i=t(\"../registry\"),a=t(\"../lib\"),o=t(\"./helpers\"),s=t(\"./cloneplot\"),l=t(\"./tosvg\"),c=t(\"./svgtoimg\");e.exports=function(t,e){var r=new n,u=s(t,{format:\"png\"}),h=u.gd;h.style.position=\"absolute\",h.style.left=\"-5000px\",document.body.appendChild(h);var f=o.getRedrawFunc(h);return i.call(\"plot\",h,u.data,u.layout,u.config).then(f).then(function(){var t=o.getDelay(h._fullLayout);setTimeout(function(){var t=l(h),n=document.createElement(\"canvas\");n.id=a.randstr(),(r=c({format:e.format,width:h._fullLayout.width,height:h._fullLayout.height,canvas:n,emitter:r,svg:t})).clean=function(){h&&document.body.removeChild(h)}},t)}).catch(function(t){r.emit(\"error\",t)}),r}},{\"../lib\":719,\"../registry\":847,\"./cloneplot\":848,\"./helpers\":851,\"./svgtoimg\":853,\"./tosvg\":855,events:104}],855:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=t(\"../components/drawing\"),o=t(\"../components/color\"),s=t(\"../constants/xmlns_namespaces\"),l=/\"/g,c=new RegExp('(\"TOBESTRIPPED)|(TOBESTRIPPED\")',\"g\");e.exports=function(t,e,r){var u,h=t._fullLayout,f=h._paper,p=h._toppaper,d=h.width,g=h.height;f.insert(\"rect\",\":first-child\").call(a.setRect,0,0,d,g).call(o.fill,h.paper_bgcolor);var v=h._basePlotModules||[];for(u=0;u<v.length;u++){var m=v[u];m.toSVG&&m.toSVG(t)}if(p){var y=p.node().childNodes,x=Array.prototype.slice.call(y);for(u=0;u<x.length;u++){var b=x[u];b.childNodes.length&&f.node().appendChild(b)}}h._draggers&&h._draggers.remove(),f.node().style.background=\"\",f.selectAll(\"text\").attr({\"data-unformatted\":null,\"data-math\":null}).each(function(){var t=n.select(this);if(\"hidden\"!==this.style.visibility&&\"none\"!==this.style.display){t.style({visibility:null,display:null});var e=this.style.fontFamily;e&&-1!==e.indexOf('\"')&&t.style(\"font-family\",e.replace(l,\"TOBESTRIPPED\"))}else t.remove()}),f.selectAll(\".point, .scatterpts, .legendfill>path, .legendlines>path, .cbfill\").each(function(){var t=n.select(this),e=this.style.fill;e&&-1!==e.indexOf(\"url(\")&&t.style(\"fill\",e.replace(l,\"TOBESTRIPPED\"));var r=this.style.stroke;r&&-1!==r.indexOf(\"url(\")&&t.style(\"stroke\",r.replace(l,\"TOBESTRIPPED\"))}),\"pdf\"!==e&&\"eps\"!==e||f.selectAll(\"#MathJax_SVG_glyphs path\").attr(\"stroke-width\",0),f.node().setAttributeNS(s.xmlns,\"xmlns\",s.svg),f.node().setAttributeNS(s.xmlns,\"xmlns:xlink\",s.xlink),\"svg\"===e&&r&&(f.attr(\"width\",r*d),f.attr(\"height\",r*g),f.attr(\"viewBox\",\"0 0 \"+d+\" \"+g));var _=(new window.XMLSerializer).serializeToString(f.node());return _=function(t){var e=n.select(\"body\").append(\"div\").style({display:\"none\"}).html(\"\"),r=t.replace(/(&[^;]*;)/gi,function(t){return\"&lt;\"===t?\"&#60;\":\"&rt;\"===t?\"&#62;\":-1!==t.indexOf(\"<\")||-1!==t.indexOf(\">\")?\"\":e.html(t).text()});return e.remove(),r}(_),_=(_=_.replace(/&(?!\\w+;|\\#[0-9]+;| \\#x[0-9A-F]+;)/g,\"&amp;\")).replace(c,\"'\"),i.isIE()&&(_=(_=(_=_.replace(/\"/gi,\"'\")).replace(/(\\('#)([^']*)('\\))/gi,'(\"#$2\")')).replace(/(\\\\')/gi,'\"')),_}},{\"../components/color\":593,\"../components/drawing\":614,\"../constants/xmlns_namespaces\":696,\"../lib\":719,d3:163}],856:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\",!0),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":719}],857:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/font_attributes\"),s=t(\"./constants.js\"),l=t(\"../../lib/extend\").extendFlat,c=o({editType:\"calc\",arrayOk:!0,colorEditType:\"style\"}),u=l({},n.marker.line.width,{dflt:0}),h=l({width:u,editType:\"calc\"},a(\"marker.line\")),f=l({line:h,editType:\"calc\"},a(\"marker\"),{opacity:{valType:\"number\",arrayOk:!0,dflt:1,min:0,max:1,editType:\"style\"}});e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,text:n.text,hovertext:n.hovertext,hovertemplate:i({},{keys:s.eventDataKeys}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"none\",arrayOk:!0,editType:\"calc\"},insidetextanchor:{valType:\"enumerated\",values:[\"end\",\"middle\",\"start\"],dflt:\"end\",editType:\"plot\"},textangle:{valType:\"angle\",dflt:\"auto\",editType:\"plot\"},textfont:l({},c,{}),insidetextfont:l({},c,{}),outsidetextfont:l({},c,{}),constraintext:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"both\",\"none\"],dflt:\"both\",editType:\"calc\"},cliponaxis:l({},n.cliponaxis,{}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},base:{valType:\"any\",dflt:null,arrayOk:!0,editType:\"calc\"},offset:{valType:\"number\",dflt:null,arrayOk:!0,editType:\"calc\"},width:{valType:\"number\",dflt:null,min:0,arrayOk:!0,editType:\"calc\"},marker:f,offsetgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},alignmentgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},selected:{marker:{opacity:n.selected.marker.opacity,color:n.selected.marker.color,editType:\"style\"},textfont:n.selected.textfont,editType:\"style\"},unselected:{marker:{opacity:n.unselected.marker.opacity,color:n.unselected.marker.color,editType:\"style\"},textfont:n.unselected.textfont,editType:\"style\"},r:n.r,t:n.t,_deprecated:{bardir:{valType:\"enumerated\",editType:\"calc\",values:[\"v\",\"h\"]}}}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"../scatter/attributes\":1112,\"./constants.js\":859}],858:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),o=t(\"./arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\");e.exports=function(t,e){var r,l,c=n.getFromId(t,e.xaxis||\"x\"),u=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=c.makeCalcdata(e,\"x\"),l=u.makeCalcdata(e,\"y\")):(r=u.makeCalcdata(e,\"y\"),l=c.makeCalcdata(e,\"x\"));for(var h=Math.min(l.length,r.length),f=new Array(h),p=0;p<h;p++)f[p]={p:l[p],s:r[p]},e.ids&&(f[p].id=String(e.ids[p]));return i(e,\"marker\")&&a(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),i(e,\"marker.line\")&&a(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),o(f,e),s(f,e),f}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"../../plots/cartesian/axes\":767,\"../scatter/calc_selection\":1114,\"./arrays_to_calcdata\":856}],859:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[]}},{}],860:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,c=t(\"./sieve.js\");function u(t,e,r,o,u){if(o.length){var b,_,w,k;switch(function(t,e){var r,a;for(r=0;r<e.length;r++){var o,s=e[r],l=s[0].trace,c=\"funnel\"===l.type?l._base:l.base,u=\"h\"===l.orientation?l.xcalendar:l.ycalendar,h=\"category\"===t.type||\"multicategory\"===t.type?function(){return null}:t.d2c;if(i(c)){for(a=0;a<Math.min(c.length,s.length);a++)o=h(c[a],0,u),n(o)?(s[a].b=+o,s[a].hasB=1):s[a].b=0;for(;a<s.length;a++)s[a].b=0}else{o=h(c,0,u);var f=n(o);for(o=f?o:0,a=0;a<s.length;a++)s[a].b=o,f&&(s[a].hasB=1)}}}(r,o),u.mode){case\"overlay\":h(e,r,o,u);break;case\"group\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(k=o[w])[0].trace.offset?_.push(k):b.push(k);_.length&&function(t,e,r,n,i){var o=new c(n,{sepNegVal:!1,overlapNoMerge:!i.norm});(function(t,e,r,n){for(var i=t._fullLayout,a=r.positions,o=r.distinctPositions,s=r.minDiff,c=r.traces,u=c.length,h=a.length!==o.length,f=s*(1-n.gap),v=l(i,e._id)+c[0][0].trace.orientation,m=i._alignmentOpts[v]||{},y=0;y<u;y++){var x,b,_=c[y],w=_[0].trace,k=m[w.alignmentgroup]||{},T=Object.keys(k.offsetGroups||{}).length,A=(x=T?f/T:h?f/u:f)*(1-(n.groupgap||0));b=T?((2*w._offsetIndex+1-T)*x-A)/2:h?((2*y+1-u)*x-A)/2:-A/2;var M=_[0].t;M.barwidth=A,M.poffset=b,M.bargroupwidth=f,M.bardelta=s}r.binWidth=c[0][0].t.barwidth/100,p(r),d(e,r),g(e,r,h)})(t,e,o,i),function(t){for(var e=t.traces,r=0;r<e.length;r++){var n=e[r],i=n[0].trace;if(void 0===i.base)for(var o=new c([n],{sepNegVal:!0,overlapNoMerge:!0}),s=0;s<n.length;s++){var l=n[s];if(l.p!==a){var u=o.put(l.p,l.b+l.s);u&&(l.b=u)}}}}(o),i.norm?(m(o),y(r,o,i)):v(r,o)}(t,e,r,_,u),b.length&&h(e,r,b,u);break;case\"stack\":case\"relative\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(k=o[w])[0].trace.base?_.push(k):b.push(k);_.length&&function(t,e,r,n,i){var o=new c(n,{sepNegVal:\"relative\"===i.mode,overlapNoMerge:!(i.norm||\"stack\"===i.mode||\"relative\"===i.mode)});f(e,o,i),function(t,e,r){var n,i,o,l,c,u,h=x(t),f=e.traces;for(l=0;l<f.length;l++)if(n=f[l],\"funnel\"===(i=n[0].trace).type)for(c=0;c<n.length;c++)(u=n[c]).s!==a&&e.put(u.p,-.5*u.s);for(l=0;l<f.length;l++){n=f[l],i=n[0].trace,o=\"funnel\"===i.type;var p=[];for(c=0;c<n.length;c++)if((u=n[c]).s!==a){var d;d=o?u.s:u.s+u.b;var g=e.put(u.p,d),v=g+d;u.b=g,u[h]=v,r.norm||(p.push(v),u.hasB&&p.push(g))}r.norm||(i._extremes[t._id]=s.findExtremes(t,p,{tozero:!0,padded:!0}))}}(r,o,i);for(var l=0;l<n.length;l++)for(var u=n[l],h=0;h<u.length;h++){var p=u[h];if(p.s!==a){var d=p.b+p.s===o.get(p.p,p.s);d&&(p._outmost=!0)}}i.norm&&y(r,o,i)}(0,e,r,_,u),b.length&&h(e,r,b,u)}!function(t,e){var r,i,a,o=x(e),s={},l=1/0,c=-1/0;for(r=0;r<t.length;r++)for(a=t[r],i=0;i<a.length;i++){var u=a[i].p;n(u)&&(l=Math.min(l,u),c=Math.max(c,u))}var h=1e4/(c-l),f=s.round=function(t){return String(Math.round(h*(t-l)))};for(r=0;r<t.length;r++){(a=t[r])[0].t.extents=s;var p=a[0].t.poffset,d=Array.isArray(p);for(i=0;i<a.length;i++){var g=a[i],v=g[o]-g.w/2;if(n(v)){var m=g[o]+g.w/2,y=f(g.p);s[y]?s[y]=[Math.min(v,s[y][0]),Math.max(m,s[y][1])]:s[y]=[v,m]}g.p0=g.p+(d?p[i]:p),g.p1=g.p0+g.w,g.s0=g.b,g.s1=g.s0+g.s}}}(o,e)}}function h(t,e,r,n){for(var i=0;i<r.length;i++){var a=r[i],o=new c([a],{sepNegVal:!1,overlapNoMerge:!n.norm});f(t,o,n),n.norm?(m(o),y(e,o,n)):v(e,o)}}function f(t,e,r){for(var n=e.minDiff,i=e.traces,a=n*(1-r.gap),o=a*(1-(r.groupgap||0)),s=-o/2,l=0;l<i.length;l++){var c=i[l][0].t;c.barwidth=o,c.poffset=s,c.bargroupwidth=a,c.bardelta=n}e.binWidth=i[0][0].t.barwidth/100,p(e),d(t,e),g(t,e)}function p(t){var e,r,a=t.traces;for(e=0;e<a.length;e++){var o,s=a[e],l=s[0],c=l.trace,u=l.t,h=c._offset||c.offset,f=u.poffset;if(i(h)){for(o=Array.prototype.slice.call(h,0,s.length),r=0;r<o.length;r++)n(o[r])||(o[r]=f);for(r=o.length;r<s.length;r++)o.push(f);u.poffset=o}else void 0!==h&&(u.poffset=h);var p=c._width||c.width,d=u.barwidth;if(i(p)){var g=Array.prototype.slice.call(p,0,s.length);for(r=0;r<g.length;r++)n(g[r])||(g[r]=d);for(r=g.length;r<s.length;r++)g.push(d);if(u.barwidth=g,void 0===h){for(o=[],r=0;r<s.length;r++)o.push(f+(d-g[r])/2);u.poffset=o}}else void 0!==p&&(u.barwidth=p,void 0===h&&(u.poffset=f+(d-p)/2))}}function d(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++)for(var a=r[i],o=a[0].t,s=o.poffset,l=Array.isArray(s),c=o.barwidth,u=Array.isArray(c),h=0;h<a.length;h++){var f=a[h],p=f.w=u?c[h]:c;f[n]=f.p+(l?s[h]:s)+p/2}}function g(t,e,r){var n=e.traces,i=e.minDiff/2;s.minDtick(t,e.minDiff,e.distinctPositions[0],r);for(var a=0;a<n.length;a++){var o,l,c,u,h=n[a],f=h[0],p=f.trace,d=[];for(u=0;u<h.length;u++)l=(o=h[u]).p-i,c=o.p+i,d.push(l,c);if(p.width||p.offset){var g=f.t,v=g.poffset,m=g.barwidth,y=Array.isArray(v),x=Array.isArray(m);for(u=0;u<h.length;u++){o=h[u];var b=y?v[u]:v,_=x?m[u]:m;c=(l=o.p+b)+_,d.push(l,c)}}p._extremes[t._id]=s.findExtremes(t,d,{padded:!1})}}function v(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++){for(var a=r[i],o=a[0].trace,l=[],c=!0,u=0;u<a.length;u++){var h=a[u],f=h.b,p=f+h.s;h[n]=p,l.push(p),h.hasB&&l.push(f),h.hasB&&h.b>0&&h.s>0||(c=!1)}o._extremes[t._id]=s.findExtremes(t,l,{tozero:!c,padded:!0})}}function m(t){for(var e=t.traces,r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++){var o=n[i];o.s!==a&&t.put(o.p,o.b+o.s)}}function y(t,e,r){var i=e.traces,o=x(t),l=\"fraction\"===r.norm?1:100,c=l/1e9,u=t.l2c(t.c2l(0)),h=\"stack\"===r.mode?l:u;function f(e){return n(t.c2l(e))&&(e<u-c||e>h+c||!n(u))}for(var p=0;p<i.length;p++){for(var d=i[p],g=d[0].trace,v=[],m=!0,y=!1,b=0;b<d.length;b++){var _=d[b];if(_.s!==a){var w=Math.abs(l/e.get(_.p,_.s));_.b*=w,_.s*=w;var k=_.b,T=k+_.s;_[o]=T,v.push(T),y=y||f(T),_.hasB&&(v.push(k),y=y||f(k)),_.hasB&&_.b>0&&_.s>0||(m=!1)}}g._extremes[t._id]=s.findExtremes(t,v,{tozero:!m,padded:y})}}function x(t){return t._id.charAt(0)}e.exports={crossTraceCalc:function(t,e){for(var r=e.xaxis,n=e.yaxis,i=t._fullLayout,a=t._fullData,s=t.calcdata,l=[],c=[],h=0;h<a.length;h++){var f=a[h];!0===f.visible&&o.traceIs(f,\"bar\")&&f.xaxis===r._id&&f.yaxis===n._id&&(\"h\"===f.orientation?l.push(s[h]):c.push(s[h]))}var p={mode:i.barmode,norm:i.barnorm,gap:i.bargap,groupgap:i.bargroupgap};u(t,r,n,c,p),u(t,n,r,l,p)},setGroupPositions:u}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"./sieve.js\":869,\"fast-isnumeric\":225}],861:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../registry\"),o=t(\"../scatter/xy_defaults\"),s=t(\"./style_defaults\"),l=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,c=t(\"./attributes\"),u=n.coerceFont;function h(t,e,r,n){var i=e.orientation,a=e[{v:\"x\",h:\"y\"}[i]+\"axis\"],o=l(r,a)+i,s=r._alignmentOpts||{},c=n(\"alignmentgroup\"),u=s[o];u||(u=s[o]={});var h=u[c];h?h.traces.push(e):h=u[c]={traces:[e],alignmentIndex:Object.keys(u).length,offsetGroups:{}};var f=n(\"offsetgroup\"),p=h.offsetGroups,d=p[f];f&&(d||(d=p[f]={offsetIndex:Object.keys(p).length}),e._offsetIndex=d.offsetIndex)}function f(t,e,r,i,a,o){var s=!(!1===(o=o||{}).moduleHasSelected),l=!(!1===o.moduleHasUnselected),c=!(!1===o.moduleHasConstrain),h=!(!1===o.moduleHasCliponaxis),f=!(!1===o.moduleHasTextangle),p=!(!1===o.moduleHasInsideanchor),d=Array.isArray(a)||\"auto\"===a,g=d||\"inside\"===a,v=d||\"outside\"===a;if(g||v){var m=u(i,\"textfont\",r.font),y=n.extendFlat({},m);!(t.textfont&&t.textfont.color)&&delete y.color,u(i,\"insidetextfont\",y),v&&u(i,\"outsidetextfont\",m),s&&i(\"selected.textfont.color\"),l&&i(\"unselected.textfont.color\"),c&&i(\"constraintext\"),h&&i(\"cliponaxis\"),f&&i(\"textangle\")}g&&p&&i(\"insidetextanchor\")}e.exports={supplyDefaults:function(t,e,r,l){function u(r,i){return n.coerce(t,e,c,r,i)}if(o(t,e,l,u)){u(\"orientation\",e.x&&!e.y?\"h\":\"v\"),u(\"base\"),u(\"offset\"),u(\"width\"),u(\"text\"),u(\"hovertext\"),u(\"hovertemplate\");var h=u(\"textposition\");f(t,0,l,u,h,{moduleHasSelected:!0,moduleHasUnselected:!0,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),s(t,e,u,r,l);var p=(e.marker.line||{}).color,d=a.getComponentMethod(\"errorbars\",\"supplyDefaults\");d(t,e,p||i.defaultLine,{axis:\"y\"}),d(t,e,p||i.defaultLine,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,u)}else e.visible=!1},crossTraceDefaults:function(t,e){var r;function i(t){return n.coerce(r._input,r,c,t)}if(\"group\"===e.barmode)for(var a=0;a<t.length;a++)\"bar\"===(r=t[a]).type&&(r._input,h(0,r,e,i))},handleGroupingDefaults:h,handleText:f}},{\"../../components/color\":593,\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../scatter/xy_defaults\":1137,\"./attributes\":857,\"./style_defaults\":871}],862:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../../lib\").isArrayOrTypedArray;r.coerceString=function(t,e,r){if(\"string\"==typeof e){if(e||!t.noBlank)return e}else if((\"number\"==typeof e||!0===e)&&!t.strict)return String(e);return void 0!==r?r:t.dflt},r.coerceNumber=function(t,e,r){if(n(e)){e=+e;var i=t.min,a=t.max;if(!(void 0!==i&&e<i||void 0!==a&&e>a))return e}return void 0!==r?r:t.dflt},r.coerceColor=function(t,e,r){return i(e).isValid()?e:void 0!==r?r:t.dflt},r.coerceEnumerated=function(t,e,r){return t.coerceNumber&&(e=+e),-1!==t.values.indexOf(e)?e:void 0!==r?r:t.dflt},r.getValue=function(t,e){var r;return Array.isArray(t)?e<t.length&&(r=t[e]):r=t,r},r.getLineWidth=function(t,e){return 0<e.mlw?e.mlw:a(t.marker.line.width)?0:t.marker.line.width}},{\"../../lib\":719,\"fast-isnumeric\":225,tinycolor2:537}],863:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../../lib\").fillText,s=t(\"./helpers\").getLineWidth;function l(t,e,r,i){var a,s,l,c,u,h,f,p=t.cd,d=p[0].trace,g=p[0].t,v=\"closest\"===i,m=\"waterfall\"===d.type,y=t.maxHoverDistance,x=t.maxSpikeDistance;function b(t){return t[l]-t.w/2}function _(t){return t[l]+t.w/2}var w=v?b:function(t){return Math.min(b(t),t.p-g.bardelta/2)},k=v?_:function(t){return Math.max(_(t),t.p+g.bardelta/2)};function T(t,e){return n.inbox(t-a,e-a,y+Math.min(1,Math.abs(e-t)/f)-1)}function A(t){return T(w(t),k(t))}function M(t){var e=s,r=t.b,i=t[c];return m&&(i+=Math.abs(t.rawS||0)),n.inbox(r-e,i-e,y+(i-e)/(i-r)-1)}\"h\"===d.orientation?(a=r,s=e,l=\"y\",c=\"x\",u=M,h=A):(a=e,s=r,l=\"x\",c=\"y\",h=M,u=A);var S=t[l+\"a\"],E=t[c+\"a\"];f=Math.abs(S.r2c(S.range[1])-S.r2c(S.range[0]));var C=n.getDistanceFunction(i,u,h,function(t){return(u(t)+h(t))/2});if(n.getClosest(p,C,t),!1!==t.index){v||(w=function(t){return Math.min(b(t),t.p-g.bargroupwidth/2)},k=function(t){return Math.max(_(t),t.p+g.bargroupwidth/2)});var L=p[t.index],P=d.base?L.b+L.s:L.s;t[c+\"0\"]=t[c+\"1\"]=E.c2p(L[c],!0),t[c+\"LabelVal\"]=P;var O=g.extents[g.extents.round(L.p)];return t[l+\"0\"]=S.c2p(v?w(L):O[0],!0),t[l+\"1\"]=S.c2p(v?k(L):O[1],!0),t[l+\"LabelVal\"]=L.p,t.spikeDistance=(M(L)+function(t){return T(b(t),_(t))}(L))/2+x-y,t[l+\"Spike\"]=S.c2p(L.p,!0),o(L,d,t),t.hovertemplate=d.hovertemplate,t}}function c(t,e){var r=e.mcc||t.marker.color,n=e.mlcc||t.marker.line.color,i=s(t,e);return a.opacity(r)?r:a.opacity(n)&&i?n:void 0}e.exports={hoverPoints:function(t,e,r,n){var a=l(t,e,r,n);if(a){var o=a.cd,s=o[0].trace,u=o[a.index];return a.color=c(s,u),i.getComponentMethod(\"errorbars\",\"hoverInfo\")(u,s,a),[a]}},hoverOnBars:l,getTraceColor:c}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"../../registry\":847,\"./helpers\":862}],864:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,colorbar:t(\"../scatter/marker_colorbar\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"bar\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"oriented\",\"errorBarsOK\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../scatter/marker_colorbar\":1129,\"./arrays_to_calcdata\":856,\"./attributes\":857,\"./calc\":858,\"./cross_trace_calc\":860,\"./defaults\":861,\"./hover\":863,\"./layout_attributes\":865,\"./layout_defaults\":866,\"./plot\":867,\"./select\":868,\"./style\":870}],865:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\",\"relative\"],dflt:\"group\",editType:\"calc\"},barnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},bargap:{valType:\"number\",min:0,max:1,editType:\"calc\"},bargroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],866:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\"),o=t(\"./layout_attributes\");e.exports=function(t,e,r){function s(r,n){return a.coerce(t,e,o,r,n)}for(var l=!1,c=!1,u=!1,h={},f=s(\"barmode\"),p=0;p<r.length;p++){var d=r[p];if(n.traceIs(d,\"bar\")&&d.visible){if(l=!0,\"group\"===f){var g=d.xaxis+d.yaxis;h[g]&&(u=!0),h[g]=!0}if(d.visible&&\"histogram\"===d.type)\"category\"!==i.getFromId({_fullLayout:e},d[\"v\"===d.orientation?\"xaxis\":\"yaxis\"]).type&&(c=!0)}}l?(\"overlay\"!==f&&s(\"barnorm\"),s(\"bargap\",c&&!u?0:.2),s(\"bargroupgap\")):delete e.barmode}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./layout_attributes\":865}],867:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../registry\"),u=t(\"../../plots/cartesian/axes\").tickText,h=t(\"./style\"),f=t(\"./helpers\"),p=t(\"./attributes\"),d=p.text,g=p.textposition,v=3;function m(t,e){return t<e?1:-1}function y(t){return\"auto\"===t?0:t}function x(t,e,r,n,i,a){var o=!!a.isHorizontal,s=!!a.constrained,l=a.angle||0,c=a.anchor||0,u=i.width,h=i.height,f=Math.abs(e-t),p=Math.abs(n-r),d=f>2*v&&p>2*v?v:0;f-=2*d,p-=2*d;var g=!1;if(!(\"auto\"===l)||u<=f&&h<=p||!(u>f||h>p)||(u>p||h>f)&&u<h==f<p||(g=!0),g){var x=p;p=f,f=x}var b=y(l),_=Math.abs(Math.sin(Math.PI/180*b)),w=Math.abs(Math.cos(Math.PI/180*b)),k=Math.max(f*w,p*_),T=Math.max(f*_,p*w),A=s?Math.min(k/u,T/h):Math.max(w,_);A=Math.min(1,A);var M=(t+e)/2,S=(r+n)/2;\"middle\"!==c&&(d+=.5*(A*(o!==g?h:u)*_+A*(o!==g?u:h)*w),o?(d*=m(t,e),M=\"start\"===c?t+d:e-d):(d*=m(r,n),S=\"start\"===c?r+d:n-d));return g&&(b+=90),{textX:(i.left+i.right)/2,textY:(i.top+i.bottom)/2,targetX:M,targetY:S,scale:A,rotate:b}}function b(t,e,r,n,i,a){var o,s=!!a.isHorizontal,l=!!a.constrained,c=a.angle||0,u=i.width,h=i.height,f=Math.abs(e-t),p=Math.abs(n-r);o=s?p>2*v?v:0:f>2*v?v:0;var d=1;l&&(d=s?Math.min(1,p/h):Math.min(1,f/u));var g=y(c);o+=.5*(d*(s?h:u)*Math.abs(Math.sin(Math.PI/180*g))+d*(s?u:h)*Math.abs(Math.cos(Math.PI/180*g)));var x=(t+e)/2,b=(r+n)/2;return s?x=e-o*m(e,t):b=n+o*m(r,n),{textX:(i.left+i.right)/2,textY:(i.top+i.bottom)/2,targetX:x,targetY:b,scale:d,rotate:g}}function _(t){var e,r=t.textX,n=t.textY,i=t.targetX,a=t.targetY,o=t.scale,s=t.rotate;return o<1?e=\"scale(\"+o+\") \":(o=1,e=\"\"),\"translate(\"+(i-o*r)+\" \"+(a-o*n)+\")\"+e+(s?\"rotate(\"+s+\" \"+r+\" \"+n+\") \":\"\")}e.exports={plot:function(t,e,r,p,y){var w=e.xaxis,k=e.yaxis,T=t._fullLayout;y||(y={mode:T.barmode,norm:T.barmode,gap:T.bargap,groupgap:T.bargroupgap});var A=a.makeTraceGroups(p,r,\"trace bars\").each(function(r){var c=n.select(this),p=r[0].trace,T=\"waterfall\"===p.type,A=\"funnel\"===p.type,M=\"bar\"===p.type||A,S=0;T&&p.connector.visible&&\"between\"===p.connector.mode&&(S=p.connector.line.width/2);var E=\"h\"===p.orientation,C=a.ensureSingle(c,\"g\",\"points\").selectAll(\"g.point\").data(a.identity);C.enter().append(\"g\").classed(\"point\",!0),C.exit().remove(),C.each(function(c,T){var A,C,L=n.select(this),P=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),n?[i,a]:[a,i]}(c,w,k,E),O=P[0][0],z=P[0][1],I=P[1][0],D=P[1][1],R=!(O!==z&&I!==D&&i(O)&&i(z)&&i(I)&&i(D));if(R&&M&&f.getLineWidth(p,c)&&(E?z-O==0:D-I==0)&&(R=!1),c.isBlank=R,S&&(E?(O-=m(O,z)*S,z+=m(O,z)*S):(I-=m(I,D)*S,D+=m(I,D)*S)),\"waterfall\"===p.type){if(!R){var F=p[c.dir].marker;A=F.line.width,C=F.color}}else A=f.getLineWidth(p,c),C=c.mc||p.marker.color;var B=n.round(A/2%1,2);function N(t){return 0===y.gap&&0===y.groupgap?n.round(Math.round(t)-B,2):t}if(!t._context.staticPlot){var j=s.opacity(C)<1||A>.01?N:function(t,e){return Math.abs(t-e)>=2?N(t):t>e?Math.ceil(t):Math.floor(t)};O=j(O,z),z=j(z,O),I=j(I,D),D=j(D,I)}a.ensureSingle(L,\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"d\",R?\"M0,0Z\":\"M\"+O+\",\"+I+\"V\"+D+\"H\"+z+\"V\"+I+\"Z\").call(l.setClipUrl,e.layerClipId,t),function(t,e,r,n,i,s,c,p,m,y){var w,k=e.xaxis,T=e.yaxis,A=t._fullLayout;function M(e,r,n){var i=a.ensureSingle(e,\"text\").text(r).attr({class:\"bartext bartext-\"+w,transform:\"\",\"text-anchor\":\"middle\",\"data-notex\":1}).call(l.font,n).call(o.convertToTspans,t);return i}var S=n[0].trace,E=\"h\"===S.orientation,C=function(t,e,r,n){var i,o=t[0].trace;return i=o.textinfo?function(t,e,r,n){var i=t[0].trace,o=\"h\"===i.orientation,s=\"waterfall\"===i.type,l=\"funnel\"===i.type;function c(t){var e=o?r:n;return u(e,+t,!0).text}var h,f,p=i.textinfo,d=t[e],g=p.split(\"+\"),v=[],m=function(t){return-1!==g.indexOf(t)};if(m(\"label\")&&v.push((f=t[e].p,u(o?n:r,f,!0).text)),m(\"text\")&&(0===(h=a.castOption(i,d.i,\"text\"))||h)&&v.push(h),s){var y=+d.rawS||d.s,x=d.v,b=x-y;m(\"initial\")&&v.push(c(b)),m(\"delta\")&&v.push(c(y)),m(\"final\")&&v.push(c(x))}if(l){m(\"value\")&&v.push(c(d.s));var _=0;m(\"percent initial\")&&_++,m(\"percent previous\")&&_++,m(\"percent total\")&&_++;var w=_>1;m(\"percent initial\")&&(h=a.formatPercent(d.begR),w&&(h+=\" of initial\"),v.push(h)),m(\"percent previous\")&&(h=a.formatPercent(d.difR),w&&(h+=\" of previous\"),v.push(h)),m(\"percent total\")&&(h=a.formatPercent(d.sumR),w&&(h+=\" of total\"),v.push(h))}return v.join(\"<br>\")}(t,e,r,n):f.getValue(o.text,e),f.coerceString(d,i)}(n,i,k,T);w=function(t,e){var r=f.getValue(t.textposition,e);return f.coerceEnumerated(g,r)}(S,i);var L=\"stack\"===y.mode||\"relative\"===y.mode,P=n[i],O=!L||P._outmost;if(C&&\"none\"!==w&&(!P.isBlank&&s!==c&&p!==m||\"auto\"!==w&&\"inside\"!==w)){var z=A.font,I=h.getBarColor(n[i],S),D=h.getInsideTextFont(S,i,z,I),R=h.getOutsideTextFont(S,i,z),F=r.datum();E?\"log\"===k.type&&F.s0<=0&&(s=k.range[0]<k.range[1]?0:k._length):\"log\"===T.type&&F.s0<=0&&(p=T.range[0]<T.range[1]?T._length:0);var B,N,j,U,V,q,H=Math.abs(c-s)-2*v,G=Math.abs(m-p)-2*v;if(\"outside\"===w&&(O||P.hasB||(w=\"inside\")),\"auto\"===w)if(O){w=\"inside\",B=M(r,C,D),N=l.bBox(B.node()),j=N.width,U=N.height;var Y=j>0&&U>0,W=j<=H&&U<=G,X=j<=G&&U<=H,Z=E?H>=j*(G/U):G>=U*(H/j);Y&&(W||X||Z)?w=\"inside\":(w=\"outside\",B.remove(),B=null)}else w=\"inside\";!B&&(B=M(r,C,\"outside\"===w?R:D),N=l.bBox(B.node()),j=N.width,U=N.height,j<=0||U<=0)?B.remove():(\"outside\"===w?(q=\"both\"===S.constraintext||\"outside\"===S.constraintext,V=_(b(s,c,p,m,N,{isHorizontal:E,constrained:q,angle:S.textangle}))):(q=\"both\"===S.constraintext||\"inside\"===S.constraintext,V=_(x(s,c,p,m,N,{isHorizontal:E,constrained:q,angle:S.textangle,anchor:S.insidetextanchor}))),B.attr(\"transform\",V))}else r.select(\"text\").remove()}(t,e,L,r,T,O,z,I,D,y),e.layerClipId&&l.hideOutsideRangePoint(c,L.select(\"text\"),w,k,p.xcalendar,p.ycalendar)});var L=!1===p.cliponaxis;l.setClipUrl(c,L?null:e.layerClipId,t)});c.getComponentMethod(\"errorbars\",\"plot\")(t,A,e)},getTransform:_,toMoveInsideBar:x,toMoveOutsideBar:b}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./attributes\":857,\"./helpers\":862,\"./style\":870,d3:163,\"fast-isnumeric\":225}],868:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=e.c2p(n?t.s0:t.p0,!0),o=e.c2p(n?t.s1:t.p1,!0),s=r.c2p(n?t.p0:t.s0,!0),l=r.c2p(n?t.p1:t.s1,!0);return i?[(a+o)/2,(s+l)/2]:n?[o,(s+l)/2]:[(a+o)/2,l]}e.exports=function(t,e){var r,i=t.cd,a=t.xaxis,o=t.yaxis,s=i[0].trace,l=\"funnel\"===s.type,c=\"h\"===s.orientation,u=[];if(!1===e)for(r=0;r<i.length;r++)i[r].selected=0;else for(r=0;r<i.length;r++){var h=i[r],f=\"ct\"in h?h.ct:n(h,a,o,c,l);e.contains(f,!1,r,t)?(u.push({pointNumber:r,x:a.c2d(h.x),y:o.c2d(h.y)}),h.selected=1):h.selected=0}return u}},{}],869:[function(t,e,r){\"use strict\";e.exports=a;var n=t(\"../../lib\").distinctVals,i=t(\"../../constants/numerical\").BADNUM;function a(t,e){this.traces=t,this.sepNegVal=e.sepNegVal,this.overlapNoMerge=e.overlapNoMerge;for(var r=1/0,a=[],o=0;o<t.length;o++){for(var s=t[o],l=0;l<s.length;l++){var c=s[l];c.p!==i&&a.push(c.p)}s[0]&&s[0].width1&&(r=Math.min(s[0].width1,r))}this.positions=a;var u=n(a);this.distinctPositions=u.vals,1===u.vals.length&&r!==1/0?this.minDiff=r:this.minDiff=Math.min(u.minDiff,r),this.binWidth=this.minDiff,this.bins={}}a.prototype.put=function(t,e){var r=this.getLabel(t,e),n=this.bins[r]||0;return this.bins[r]=n+e,n},a.prototype.get=function(t,e){var r=this.getLabel(t,e);return this.bins[r]||0},a.prototype.getLabel=function(t,e){return(e<0&&this.sepNegVal?\"v\":\"^\")+(this.overlapNoMerge?t:Math.round(t/this.binWidth))}},{\"../../constants/numerical\":695,\"../../lib\":719}],870:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../lib\"),s=t(\"../../registry\"),l=t(\"./attributes\"),c=l.textfont,u=l.insidetextfont,h=l.outsidetextfont,f=t(\"./helpers\");function p(t,e,r){a.pointStyle(t.selectAll(\"path\"),e,r),d(t,e,r)}function d(t,e,r){t.selectAll(\"text\").each(function(t){var i=n.select(this),o=g(i,t,e,r);a.font(i,o)})}function g(t,e,r,n){var i=n._fullLayout.font,a=r.textfont;if(t.classed(\"bartext-inside\")){var o=b(e,r);a=m(r,e.i,i,o)}else t.classed(\"bartext-outside\")&&(a=y(r,e.i,i));return a}function v(t,e,r){return x(c,t.textfont,e,r)}function m(t,e,r,n){var a=v(t,e,r);return(void 0===t._input.textfont||void 0===t._input.textfont.color||Array.isArray(t.textfont.color)&&void 0===t.textfont.color[e])&&(a={color:i.contrast(n),family:a.family,size:a.size}),x(u,t.insidetextfont,e,a)}function y(t,e,r){var n=v(t,e,r);return x(h,t.outsidetextfont,e,n)}function x(t,e,r,n){e=e||{};var i=f.getValue(e.family,r),a=f.getValue(e.size,r),o=f.getValue(e.color,r);return{family:f.coerceString(t.family,i,n.family),size:f.coerceNumber(t.size,a,n.size),color:f.coerceColor(t.color,o,n.color)}}function b(t,e){return\"waterfall\"===e.type?e[t.dir].marker.color:t.mc||e.marker.color}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.barlayer\").selectAll(\"g.trace\"),r=e.size(),i=t._fullLayout;e.style(\"opacity\",function(t){return t[0].trace.opacity}).each(function(t){(\"stack\"===i.barmode&&r>1||0===i.bargap&&0===i.bargroupgap&&!t[0].trace.marker.line.width)&&n.select(this).attr(\"shape-rendering\",\"crispEdges\")}),e.selectAll(\"g.points\").each(function(e){p(n.select(this),e[0].trace,t)}),s.getComponentMethod(\"errorbars\",\"style\")(e)},styleTextPoints:d,styleOnSelect:function(t,e,r){var i=e[0].trace;i.selectedpoints?function(t,e,r){a.selectedPointStyle(t.selectAll(\"path\"),e),function(t,e,r){t.each(function(t){var i,s=n.select(this);if(t.selected){i=o.extendFlat({},g(s,t,e,r));var l=e.selected.textfont&&e.selected.textfont.color;l&&(i.color=l),a.font(s,i)}else a.selectedTextStyle(s,e)})}(t.selectAll(\"text\"),e,r)}(r,i,t):(p(r,i,t),s.getComponentMethod(\"errorbars\",\"style\")(r))},getInsideTextFont:m,getOutsideTextFont:y,getBarColor:b}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../registry\":847,\"./attributes\":857,\"./helpers\":862,d3:163}],871:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s){r(\"marker.color\",o),i(t,\"marker\")&&a(t,e,s,r,{prefix:\"marker.\",cLetter:\"c\"}),r(\"marker.line.color\",n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,r,{prefix:\"marker.line.\",cLetter:\"c\"}),r(\"marker.line.width\"),r(\"marker.opacity\"),r(\"selected.marker.color\"),r(\"unselected.marker.color\")}},{\"../../components/color\":593,\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604}],872:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../scatterpolar/attributes\"),o=t(\"../bar/attributes\");e.exports={r:a.r,theta:a.theta,r0:a.r0,dr:a.dr,theta0:a.theta0,dtheta:a.dtheta,thetaunit:a.thetaunit,base:i({},o.base,{}),offset:i({},o.offset,{}),width:i({},o.width,{}),text:i({},o.text,{}),hovertext:i({},o.hovertext,{}),marker:o.marker,hoverinfo:a.hoverinfo,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../bar/attributes\":857,\"../scatterpolar/attributes\":1179}],873:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"../bar/arrays_to_calcdata\"),o=t(\"../bar/cross_trace_calc\").setGroupPositions,s=t(\"../scatter/calc_selection\"),l=t(\"../../registry\").traceIs,c=t(\"../../lib\").extendFlat;e.exports={calc:function(t,e){for(var r=t._fullLayout,o=e.subplot,l=r[o].radialaxis,c=r[o].angularaxis,u=l.makeCalcdata(e,\"r\"),h=c.makeCalcdata(e,\"theta\"),f=e._length,p=new Array(f),d=u,g=h,v=0;v<f;v++)p[v]={p:g[v],s:d[v]};function m(t){var r=e[t];void 0!==r&&(e[\"_\"+t]=Array.isArray(r)?c.makeCalcdata(e,t):c.d2c(r,e.thetaunit))}return\"linear\"===c.type&&(m(\"width\"),m(\"offset\")),n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),a(p,e),s(p,e),p},crossTraceCalc:function(t,e,r){for(var n=t.calcdata,i=[],a=0;a<n.length;a++){var s=n[a],u=s[0].trace;!0===u.visible&&l(u,\"bar\")&&u.subplot===r&&i.push(s)}var h=c({},e.radialaxis,{_id:\"x\"}),f=e.angularaxis;o(t,f,h,i,{mode:e.barmode,norm:e.barnorm,gap:e.bargap,groupgap:e.bargroupgap})}}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"../../lib\":719,\"../../registry\":847,\"../bar/arrays_to_calcdata\":856,\"../bar/cross_trace_calc\":860,\"../scatter/calc_selection\":1114}],874:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatterpolar/defaults\").handleRThetaDefaults,a=t(\"../bar/style_defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}i(t,e,s,l)?(l(\"thetaunit\"),l(\"base\"),l(\"offset\"),l(\"width\"),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),a(t,e,l,r,s),n.coerceSelectionMarkerOpacity(e,l)):e.visible=!1}},{\"../../lib\":719,\"../bar/style_defaults\":871,\"../scatterpolar/defaults\":1181,\"./attributes\":872}],875:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../bar/hover\").getTraceColor,o=i.fillText,s=t(\"../scatterpolar/hover\").makeHoverPointText,l=t(\"../../plots/polar/helpers\").isPtInsidePolygon;e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,h=t.subplot,f=h.radialAxis,p=h.angularAxis,d=h.vangles,g=d?l:i.isPtInsideSector,v=t.maxHoverDistance,m=p._period||2*Math.PI,y=Math.abs(f.g2p(Math.sqrt(e*e+r*r))),x=Math.atan2(r,e);f.range[0]>f.range[1]&&(x+=Math.PI);if(n.getClosest(c,function(t){return g(y,x,[t.rp0,t.rp1],[t.thetag0,t.thetag1],d)?v+Math.min(1,Math.abs(t.thetag1-t.thetag0)/m)-1+(t.rp1-y)/(t.rp1-t.rp0)-1:1/0},t),!1!==t.index){var b=c[t.index];t.x0=t.x1=b.ct[0],t.y0=t.y1=b.ct[1];var _=i.extendFlat({},b,{r:b.s,theta:b.p});return o(b,u,t),s(_,u,h,t),t.hovertemplate=u.hovertemplate,t.color=a(u,b),t.xLabelVal=t.yLabelVal=void 0,b.s<0&&(t.idealAlign=\"left\"),[t]}}},{\"../../components/fx\":632,\"../../lib\":719,\"../../plots/polar/helpers\":830,\"../bar/hover\":863,\"../scatterpolar/hover\":1182}],876:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"barpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"bar\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),colorbar:t(\"../scatter/marker_colorbar\"),style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),meta:{}}},{\"../../plots/polar\":831,\"../bar/select\":868,\"../bar/style\":870,\"../scatter/marker_colorbar\":1129,\"./attributes\":872,\"./calc\":873,\"./defaults\":874,\"./hover\":875,\"./layout_attributes\":877,\"./layout_defaults\":878,\"./plot\":879}],877:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},bargap:{valType:\"number\",dflt:.1,min:0,max:1,editType:\"calc\"}}},{}],878:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a,o={};function s(r,o){return n.coerce(t[a]||{},e[a],i,r,o)}for(var l=0;l<r.length;l++){var c=r[l];\"barpolar\"===c.type&&!0===c.visible&&(o[a=c.subplot]||(s(\"barmode\"),s(\"bargap\"),o[a]=1))}}},{\"../../lib\":719,\"./layout_attributes\":877}],879:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../components/drawing\"),s=t(\"../../plots/polar/helpers\");e.exports=function(t,e,r){var l=e.xaxis,c=e.yaxis,u=e.radialAxis,h=e.angularAxis,f=function(t){var e=t.cxx,r=t.cyy;if(t.vangles)return function(n,i,o,l){var c,u;a.angleDelta(o,l)>0?(c=o,u=l):(c=l,u=o);var h=s.findEnclosingVertexAngles(c,t.vangles)[0],f=s.findEnclosingVertexAngles(u,t.vangles)[1],p=[h,(c+u)/2,f];return s.pathPolygonAnnulus(n,i,c,u,p,e,r)};return function(t,n,i,o){return a.pathAnnulus(t,n,i,o,e,r)}}(e),p=e.layers.frontplot.select(\"g.barlayer\");a.makeTraceGroups(p,r,\"trace bars\").each(function(){var r=n.select(this),s=a.ensureSingle(r,\"g\",\"points\").selectAll(\"g.point\").data(a.identity);s.enter().append(\"g\").style(\"vector-effect\",\"non-scaling-stroke\").style(\"stroke-miterlimit\",2).classed(\"point\",!0),s.exit().remove(),s.each(function(t){var e,r=n.select(this),o=t.rp0=u.c2p(t.s0),s=t.rp1=u.c2p(t.s1),p=t.thetag0=h.c2g(t.p0),d=t.thetag1=h.c2g(t.p1);if(i(o)&&i(s)&&i(p)&&i(d)&&o!==s&&p!==d){var g=u.c2g(t.s1),v=(p+d)/2;t.ct=[l.c2p(g*Math.cos(v)),c.c2p(g*Math.sin(v))],e=f(o,s,p,d)}else e=\"M0,0Z\";a.ensureSingle(r,\"path\").attr(\"d\",e)}),o.setClipUrl(r,e._hasClipOnAxisFalse?e.clipIds.forTraces:null,t)})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../plots/polar/helpers\":830,d3:163,\"fast-isnumeric\":225}],880:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../bar/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../lib/extend\").extendFlat,l=n.marker,c=l.line;e.exports={y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},y0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},name:{valType:\"string\",editType:\"calc+clearAxisTypes\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),hovertemplate:o({}),whiskerwidth:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"calc\"},notched:{valType:\"boolean\",editType:\"calc\"},notchwidth:{valType:\"number\",min:0,max:.5,dflt:.25,editType:\"calc\"},boxpoints:{valType:\"enumerated\",values:[\"all\",\"outliers\",\"suspectedoutliers\",!1],dflt:\"outliers\",editType:\"calc\"},boxmean:{valType:\"enumerated\",values:[!0,\"sd\",!1],dflt:!1,editType:\"calc\"},jitter:{valType:\"number\",min:0,max:1,editType:\"calc\"},pointpos:{valType:\"number\",min:-2,max:2,editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},width:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},marker:{outliercolor:{valType:\"color\",dflt:\"rgba(0, 0, 0, 0)\",editType:\"style\"},symbol:s({},l.symbol,{arrayOk:!1,editType:\"plot\"}),opacity:s({},l.opacity,{arrayOk:!1,dflt:1,editType:\"style\"}),size:s({},l.size,{arrayOk:!1,editType:\"calc\"}),color:s({},l.color,{arrayOk:!1,editType:\"style\"}),line:{color:s({},c.color,{arrayOk:!1,dflt:a.defaultLine,editType:\"style\"}),width:s({},c.width,{arrayOk:!1,dflt:0,editType:\"style\"}),outliercolor:{valType:\"color\",editType:\"style\"},outlierwidth:{valType:\"number\",min:0,dflt:1,editType:\"style\"},editType:\"style\"},editType:\"plot\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,offsetgroup:i.offsetgroup,alignmentgroup:i.alignmentgroup,selected:{marker:n.selected.marker,editType:\"style\"},unselected:{marker:n.unselected.marker,editType:\"style\"},hoveron:{valType:\"flaglist\",flags:[\"boxes\",\"points\"],dflt:\"boxes+points\",editType:\"style\"}}},{\"../../components/color/attributes\":592,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../bar/attributes\":857,\"../scatter/attributes\":1112}],881:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=i._,o=t(\"../../plots/cartesian/axes\");function s(t,e,r){var n={text:\"tx\",hovertext:\"htx\"};for(var i in n)Array.isArray(e[i])&&(t[n[i]]=e[i][r])}function l(t,e){return t.v-e.v}function c(t){return t.v}e.exports=function(t,e){var r,u,h,f,p,d=t._fullLayout,g=o.getFromId(t,e.xaxis||\"x\"),v=o.getFromId(t,e.yaxis||\"y\"),m=[],y=\"violin\"===e.type?\"_numViolins\":\"_numBoxes\";\"h\"===e.orientation?(u=g,h=\"x\",f=v,p=\"y\"):(u=v,h=\"y\",f=g,p=\"x\");var x,b=u.makeCalcdata(e,h),_=function(t,e,r,a,o){if(e in t)return r.makeCalcdata(t,e);var s;s=e+\"0\"in t?t[e+\"0\"]:\"name\"in t&&(\"category\"===r.type||n(t.name)&&-1!==[\"linear\",\"log\"].indexOf(r.type)||i.isDateTime(t.name)&&\"date\"===r.type)?t.name:o;var l=\"multicategory\"===r.type?r.r2c_just_indices(s):r.d2c(s,0,t[e+\"calendar\"]);return a.map(function(){return l})}(e,p,f,b,d[y]),w=i.distinctVals(_),k=w.vals,T=w.minDiff/2,A=function(t,e){for(var r=t.length,n=new Array(r+1),i=0;i<r;i++)n[i]=t[i]-e;return n[r]=t[r-1]+e,n}(k,T),M=k.length,S=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=[];return e}(M);for(r=0;r<e._length;r++){var E=b[r];if(n(E)){var C=i.findBin(_[r],A);if(C>=0&&C<M){var L={v:E,i:r};s(L,e,r),S[C].push(L)}}}var P=\"all\"===(e.boxpoints||e.points)?i.identity:function(t){return t.v<x.lf||t.v>x.uf};for(r=0;r<M;r++)if(S[r].length>0){var O=S[r].sort(l),z=O.map(c),I=z.length;(x={}).pos=k[r],x.pts=O,x[p]=x.pos,x[h]=x.pts.map(function(t){return t.v}),x.min=z[0],x.max=z[I-1],x.mean=i.mean(z,I),x.sd=i.stdev(z,I,x.mean),x.q1=i.interp(z,.25),x.med=i.interp(z,.5),x.q3=i.interp(z,.75),x.lf=Math.min(x.q1,z[Math.min(i.findBin(2.5*x.q1-1.5*x.q3,z,!0)+1,I-1)]),x.uf=Math.max(x.q3,z[Math.max(i.findBin(2.5*x.q3-1.5*x.q1,z),0)]),x.lo=4*x.q1-3*x.q3,x.uo=4*x.q3-3*x.q1;var D=1.57*(x.q3-x.q1)/Math.sqrt(I);x.ln=x.med-D,x.un=x.med+D,x.pts2=O.filter(P),m.push(x)}!function(t,e){if(i.isArrayOrTypedArray(e.selectedpoints))for(var r=0;r<t.length;r++){for(var n=t[r].pts||[],a={},o=0;o<n.length;o++)a[n[o].i]=o;i.tagSelected(n,e,a)}}(m,e);var R=o.findExtremes(u,b,{padded:!0});return e._extremes[u._id]=R,m.length>0?(m[0].t={num:d[y],dPos:T,posLetter:p,valLetter:h,labels:{med:a(t,\"median:\"),min:a(t,\"min:\"),q1:a(t,\"q1:\"),q3:a(t,\"q3:\"),max:a(t,\"max:\"),mean:\"sd\"===e.boxmean?a(t,\"mean \\xb1 \\u03c3:\"):a(t,\"mean:\"),lf:a(t,\"lower fence:\"),uf:a(t,\"upper fence:\")}},d[y]++,m):[{t:{empty:!0}}]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"fast-isnumeric\":225}],882:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,o=[\"v\",\"h\"];function s(t,e,r,o){var s,l,c,u=e.calcdata,h=e._fullLayout,f=o._id,p=f.charAt(0),d=[],g=0;for(s=0;s<r.length;s++)for(c=u[r[s]],l=0;l<c.length;l++)d.push(c[l].pos),g+=(c[l].pts2||[]).length;if(d.length){var v=i.distinctVals(d),m=v.minDiff/2;n.minDtick(o,v.minDiff,v.vals[0],!0);var y=h[\"violin\"===t?\"_numViolins\":\"_numBoxes\"],x=\"group\"===h[t+\"mode\"]&&y>1,b=1-h[t+\"gap\"],_=1-h[t+\"groupgap\"];for(s=0;s<r.length;s++){var w,k,T,A,M,S,E=(c=u[r[s]])[0].trace,C=c[0].t,L=E.width,P=E.side;if(L)w=k=A=L/2,T=0;else if(w=m,x){var O=a(h,o._id)+E.orientation,z=(h._alignmentOpts[O]||{})[E.alignmentgroup]||{},I=Object.keys(z.offsetGroups||{}).length,D=I||y;k=w*b*_/D,T=2*w*(((I?E._offsetIndex:C.num)+.5)/D-.5)*b,A=w*b/D}else k=w*b*_,T=0,A=w;C.dPos=w,C.bPos=T,C.bdPos=k,C.wHover=A;var R,F,B,N,j,U,V=T+k,q=Boolean(L);if(\"positive\"===P?(M=w*(L?1:.5),R=V,S=R=T):\"negative\"===P?(M=R=T,S=w*(L?1:.5),F=V):(M=S=w,R=F=V),(E.boxpoints||E.points)&&g>0){var H=E.pointpos,G=E.jitter,Y=E.marker.size/2,W=0;H+G>=0&&((W=V*(H+G))>M?(q=!0,j=Y,B=W):W>R&&(j=Y,B=M)),W<=M&&(B=M);var X=0;H-G<=0&&((X=-V*(H-G))>S?(q=!0,U=Y,N=X):X>F&&(U=Y,N=S)),X<=S&&(N=S)}else B=M,N=S;var Z=new Array(c.length);for(l=0;l<c.length;l++)Z[l]=c[l].pos;E._extremes[f]=n.findExtremes(o,Z,{padded:q,vpadminus:N,vpadplus:B,ppadminus:{x:U,y:j}[p],ppadplus:{x:j,y:U}[p]})}}}e.exports={crossTraceCalc:function(t,e){for(var r=t.calcdata,n=e.xaxis,i=e.yaxis,a=0;a<o.length;a++){for(var l=o[a],c=\"h\"===l?i:n,u=[],h=0;h<r.length;h++){var f=r[h],p=f[0].t,d=f[0].trace;!0!==d.visible||\"box\"!==d.type&&\"candlestick\"!==d.type||p.empty||(d.orientation||\"v\")!==l||d.xaxis!==n._id||d.yaxis!==i._id||u.push(h)}s(\"box\",t,u,c)}},setPositionOffset:s}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_ids\":770}],883:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../bar/defaults\").handleGroupingDefaults,s=t(\"./attributes\");function l(t,e,r,a){var o,s,l=r(\"y\"),c=r(\"x\"),u=c&&c.length;if(l&&l.length)o=\"v\",u?s=Math.min(n.minRowLength(c),n.minRowLength(l)):(r(\"x0\"),s=n.minRowLength(l));else{if(!u)return void(e.visible=!1);o=\"h\",r(\"y0\"),s=n.minRowLength(c)}e._length=s,i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a),r(\"orientation\",o)}function c(t,e,r,i){var a=i.prefix,o=n.coerce2(t,e,s,\"marker.outliercolor\"),l=r(\"marker.line.outliercolor\"),c=r(a+\"points\",o||l?\"suspectedoutliers\":void 0);c?(r(\"jitter\",\"all\"===c?.3:0),r(\"pointpos\",\"all\"===c?-1.5:0),r(\"marker.symbol\"),r(\"marker.opacity\"),r(\"marker.size\"),r(\"marker.color\",e.line.color),r(\"marker.line.color\"),r(\"marker.line.width\"),\"suspectedoutliers\"===c&&(r(\"marker.line.outliercolor\",e.marker.color),r(\"marker.line.outlierwidth\")),r(\"selected.marker.color\"),r(\"unselected.marker.color\"),r(\"selected.marker.size\"),r(\"unselected.marker.size\"),r(\"text\"),r(\"hovertext\")):delete e.marker;var u=r(\"hoveron\");\"all\"!==u&&-1===u.indexOf(\"points\")||r(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,r)}e.exports={supplyDefaults:function(t,e,r,i){function o(r,i){return n.coerce(t,e,s,r,i)}l(t,e,o,i),!1!==e.visible&&(o(\"line.color\",(t.marker||{}).color||r),o(\"line.width\"),o(\"fillcolor\",a.addOpacity(e.line.color,.5)),o(\"whiskerwidth\"),o(\"boxmean\"),o(\"width\"),o(\"notched\",void 0!==t.notchwidth)&&o(\"notchwidth\"),c(t,e,o,{prefix:\"box\"}))},crossTraceDefaults:function(t,e){var r,i;function a(t){return n.coerce(i._input,i,s,t)}for(var l=0;l<t.length;l++){var c=(i=t[l]).type;\"box\"!==c&&\"violin\"!==c||(r=i._input,\"group\"===e[c+\"mode\"]&&o(r,i,e,a))}},handleSampleDefaults:l,handlePointsDefaults:c}},{\"../../components/color\":593,\"../../lib\":719,\"../../registry\":847,\"../bar/defaults\":861,\"./attributes\":880}],884:[function(t,e,r){\"use strict\";e.exports=function(t,e){return e.hoverOnBox&&(t.hoverOnBox=e.hoverOnBox),\"xVal\"in e&&(t.x=e.xVal),\"yVal\"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],885:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=i.fillText;function l(t,e,r,s){var l,c,u,h,f,p,d,g,v,m,y,x,b,_,w=t.cd,k=t.xa,T=t.ya,A=w[0].trace,M=w[0].t,S=\"violin\"===A.type,E=[],C=M.bdPos,L=M.wHover,P=function(t){return t.pos+M.bPos-p};S&&\"both\"!==A.side?(\"positive\"===A.side&&(v=function(t){var e=P(t);return a.inbox(e,e+L,m)},x=C,b=0),\"negative\"===A.side&&(v=function(t){var e=P(t);return a.inbox(e-L,e,m)},x=0,b=C)):(v=function(t){var e=P(t);return a.inbox(e-L,e+L,m)},x=b=C),_=S?function(t){return a.inbox(t.span[0]-f,t.span[1]-f,m)}:function(t){return a.inbox(t.min-f,t.max-f,m)},\"h\"===A.orientation?(f=e,p=r,d=_,g=v,l=\"y\",u=T,c=\"x\",h=k):(f=r,p=e,d=v,g=_,l=\"x\",u=k,c=\"y\",h=T);var O=Math.min(1,C/Math.abs(u.r2c(u.range[1])-u.r2c(u.range[0])));function z(t){return(d(t)+g(t))/2}m=t.maxHoverDistance-O,y=t.maxSpikeDistance-O;var I=a.getDistanceFunction(s,d,g,z);if(a.getClosest(w,I,t),!1===t.index)return[];var D=w[t.index],R=A.line.color,F=(A.marker||{}).color;o.opacity(R)&&A.line.width?t.color=R:o.opacity(F)&&A.boxpoints?t.color=F:t.color=A.fillcolor,t[l+\"0\"]=u.c2p(D.pos+M.bPos-b,!0),t[l+\"1\"]=u.c2p(D.pos+M.bPos+x,!0),t[l+\"LabelVal\"]=D.pos;var B=l+\"Spike\";t.spikeDistance=z(D)*y/m,t[B]=u.c2p(D.pos,!0);var N={},j=[\"med\",\"q1\",\"q3\",\"min\",\"max\"];(A.boxmean||(A.meanline||{}).visible)&&j.push(\"mean\"),(A.boxpoints||A.points)&&j.push(\"lf\",\"uf\");for(var U=0;U<j.length;U++){var V=j[U];if(V in D&&!(D[V]in N)){N[D[V]]=!0;var q=D[V],H=h.c2p(q,!0),G=i.extendFlat({},t);G.attr=V,G[c+\"0\"]=G[c+\"1\"]=H,G[c+\"LabelVal\"]=q,G[c+\"Label\"]=(M.labels?M.labels[V]+\" \":\"\")+n.hoverLabelText(h,q),G.hoverOnBox=!0,\"mean\"===V&&\"sd\"in D&&\"sd\"===A.boxmean&&(G[c+\"err\"]=D.sd),t.name=\"\",t.spikeDistance=void 0,t[B]=void 0,G.hovertemplate=!1,E.push(G)}}return E}function c(t,e,r){for(var n,o,l,c=t.cd,u=t.xa,h=t.ya,f=c[0].trace,p=u.c2p(e),d=h.c2p(r),g=a.quadrature(function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(u.c2p(t.x)-p)-e,1-3/e)},function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(h.c2p(t.y)-d)-e,1-3/e)}),v=!1,m=0;m<c.length;m++){o=c[m];for(var y=0;y<(o.pts||[]).length;y++){var x=g(l=o.pts[y]);x<=t.distance&&(t.distance=x,v=[m,y])}}if(!v)return!1;l=(o=c[v[0]]).pts[v[1]];var b,_=u.c2p(l.x,!0),w=h.c2p(l.y,!0),k=l.mrc||1;return n=i.extendFlat({},t,{index:l.i,color:(f.marker||{}).color,name:f.name,x0:_-k,x1:_+k,y0:w-k,y1:w+k,spikeDistance:t.distance,hovertemplate:f.hovertemplate}),\"h\"===f.orientation?(b=h,n.xLabelVal=l.x,n.yLabelVal=o.pos):(b=u,n.xLabelVal=o.pos,n.yLabelVal=l.y),n[b._id.charAt(0)+\"Spike\"]=b.c2p(o.pos,!0),s(l,f,n),n}e.exports={hoverPoints:function(t,e,r,n){var i,a=t.cd[0].trace.hoveron,o=[];return-1!==a.indexOf(\"boxes\")&&(o=o.concat(l(t,e,r,n))),-1!==a.indexOf(\"points\")&&(i=c(t,e,r)),\"closest\"===n?i?[i]:o:i?(o.push(i),o):o},hoverOnBoxes:l,hoverOnPoints:c}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],886:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\").supplyLayoutDefaults,calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"box\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"boxLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":880,\"./calc\":881,\"./cross_trace_calc\":882,\"./defaults\":883,\"./event_data\":884,\"./hover\":885,\"./layout_attributes\":887,\"./layout_defaults\":888,\"./plot\":889,\"./select\":890,\"./style\":891}],887:[function(t,e,r){\"use strict\";e.exports={boxmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"overlay\",editType:\"calc\"},boxgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"},boxgroupgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"}}},{}],888:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./layout_attributes\");function o(t,e,r,i,a){for(var o=a+\"Layout\",s=!1,l=0;l<r.length;l++){var c=r[l];if(n.traceIs(c,o)){s=!0;break}}s&&(i(a+\"mode\"),i(a+\"gap\"),i(a+\"groupgap\"))}e.exports={supplyLayoutDefaults:function(t,e,r){o(0,0,r,function(r,n){return i.coerce(t,e,a,r,n)},\"box\")},_supply:o}},{\"../../lib\":719,\"../../registry\":847,\"./layout_attributes\":887}],889:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=5,s=.01;function l(t,e,r,a){var o,s,l=e.pos,c=e.val,u=a.bPos,h=a.wdPos||0,f=a.bPosPxOffset||0,p=r.whiskerwidth||0,d=r.notched||!1,g=d?1-2*r.notchwidth:1;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var v=t.selectAll(\"path.box\").data(\"violin\"!==r.type||r.box.visible?i.identity:[]);v.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"box\"),v.exit().remove(),v.each(function(t){if(t.empty)return\"M0,0Z\";var e=t.pos,a=l.c2p(e+u,!0)+f,v=l.c2p(e+u-o,!0)+f,m=l.c2p(e+u+s,!0)+f,y=l.c2p(e+u-h,!0)+f,x=l.c2p(e+u+h,!0)+f,b=l.c2p(e+u-o*g,!0)+f,_=l.c2p(e+u+s*g,!0)+f,w=c.c2p(t.q1,!0),k=c.c2p(t.q3,!0),T=i.constrain(c.c2p(t.med,!0),Math.min(w,k)+1,Math.max(w,k)-1),A=void 0===t.lf||!1===r.boxpoints,M=c.c2p(A?t.min:t.lf,!0),S=c.c2p(A?t.max:t.uf,!0),E=c.c2p(t.ln,!0),C=c.c2p(t.un,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+T+\",\"+b+\"V\"+_+\"M\"+w+\",\"+v+\"V\"+m+(d?\"H\"+E+\"L\"+T+\",\"+_+\"L\"+C+\",\"+m:\"\")+\"H\"+k+\"V\"+v+(d?\"H\"+C+\"L\"+T+\",\"+b+\"L\"+E+\",\"+v:\"\")+\"ZM\"+w+\",\"+a+\"H\"+M+\"M\"+k+\",\"+a+\"H\"+S+(0===p?\"\":\"M\"+M+\",\"+y+\"V\"+x+\"M\"+S+\",\"+y+\"V\"+x)):n.select(this).attr(\"d\",\"M\"+b+\",\"+T+\"H\"+_+\"M\"+v+\",\"+w+\"H\"+m+(d?\"V\"+E+\"L\"+_+\",\"+T+\"L\"+m+\",\"+C:\"\")+\"V\"+k+\"H\"+v+(d?\"V\"+C+\"L\"+b+\",\"+T+\"L\"+v+\",\"+E:\"\")+\"ZM\"+a+\",\"+w+\"V\"+M+\"M\"+a+\",\"+k+\"V\"+S+(0===p?\"\":\"M\"+y+\",\"+M+\"H\"+x+\"M\"+y+\",\"+S+\"H\"+x))})}function c(t,e,r,n){var l=e.x,c=e.y,u=n.bdPos,h=n.bPos,f=r.boxpoints||r.points;i.seedPseudoRandom();var p=t.selectAll(\"g.points\").data(f?function(t){return t.forEach(function(t){t.t=n,t.trace=r}),t}:[]);p.enter().append(\"g\").attr(\"class\",\"points\"),p.exit().remove();var d=p.selectAll(\"path\").data(function(t){var e,n,a=t.pts2,l=Math.max((t.max-t.min)/10,t.q3-t.q1),c=1e-9*l,p=l*s,d=[],g=0;if(r.jitter){if(0===l)for(g=1,d=new Array(a.length),e=0;e<a.length;e++)d[e]=1;else for(e=0;e<a.length;e++){var v=Math.max(0,e-o),m=a[v].v,y=Math.min(a.length-1,e+o),x=a[y].v;\"all\"!==f&&(a[e].v<t.lf?x=Math.min(x,t.lf):m=Math.max(m,t.uf));var b=Math.sqrt(p*(y-v)/(x-m+c))||0;b=i.constrain(Math.abs(b),0,1),d.push(b),g=Math.max(b,g)}n=2*r.jitter/(g||1)}for(e=0;e<a.length;e++){var _=a[e],w=_.v,k=r.jitter?n*d[e]*(i.pseudoRandom()-.5):0,T=t.pos+h+u*(r.pointpos+k);\"h\"===r.orientation?(_.y=T,_.x=w):(_.x=T,_.y=w),\"suspectedoutliers\"===f&&w<t.uo&&w>t.lo&&(_.so=!0)}return a});d.enter().append(\"path\").classed(\"point\",!0),d.exit().remove(),d.call(a.translatePoints,l,c)}function u(t,e,r,a){var o,s,l=e.pos,c=e.val,u=a.bPos,h=a.bPosPxOffset||0,f=r.boxmean||(r.meanline||{}).visible;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var p=t.selectAll(\"path.mean\").data(\"box\"===r.type&&r.boxmean||\"violin\"===r.type&&r.box.visible&&r.meanline.visible?i.identity:[]);p.enter().append(\"path\").attr(\"class\",\"mean\").style({fill:\"none\",\"vector-effect\":\"non-scaling-stroke\"}),p.exit().remove(),p.each(function(t){var e=l.c2p(t.pos+u,!0)+h,i=l.c2p(t.pos+u-o,!0)+h,a=l.c2p(t.pos+u+s,!0)+h,p=c.c2p(t.mean,!0),d=c.c2p(t.mean-t.sd,!0),g=c.c2p(t.mean+t.sd,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+p+\",\"+i+\"V\"+a+(\"sd\"===f?\"m0,0L\"+d+\",\"+e+\"L\"+p+\",\"+i+\"L\"+g+\",\"+e+\"Z\":\"\")):n.select(this).attr(\"d\",\"M\"+i+\",\"+p+\"H\"+a+(\"sd\"===f?\"m0,0L\"+e+\",\"+d+\"L\"+i+\",\"+p+\"L\"+e+\",\"+g+\"Z\":\"\"))})}e.exports={plot:function(t,e,r,a){var o=e.xaxis,s=e.yaxis;i.makeTraceGroups(a,r,\"trace boxes\").each(function(t){var e,r,i=n.select(this),a=t[0],h=a.t,f=a.trace;h.wdPos=h.bdPos*f.whiskerwidth,!0!==f.visible||h.empty?i.remove():(\"h\"===f.orientation?(e=s,r=o):(e=o,r=s),l(i,{pos:e,val:r},f,h),c(i,{x:o,y:s},f,h),u(i,{pos:e,val:r},f,h))})},plotBoxAndWhiskers:l,plotPoints:c,plotBoxMean:u}},{\"../../components/drawing\":614,\"../../lib\":719,d3:163}],890:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i=t.cd,a=t.xaxis,o=t.yaxis,s=[];if(!1===e)for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++)i[r].pts[n].selected=0;else for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++){var l=i[r].pts[n],c=a.c2p(l.x),u=o.c2p(l.y);e.contains([c,u],null,l.i,t)?(s.push({pointNumber:l.i,x:a.c2d(l.x),y:o.c2d(l.y)}),l.selected=1):l.selected=0}return s}},{}],891:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\");e.exports={style:function(t,e,r){var o=r||n.select(t).selectAll(\"g.trace.boxes\");o.style(\"opacity\",function(t){return t[0].trace.opacity}),o.each(function(e){var r=n.select(this),o=e[0].trace,s=o.line.width;function l(t,e,r,n){t.style(\"stroke-width\",e+\"px\").call(i.stroke,r).call(i.fill,n)}var c=r.selectAll(\"path.box\");if(\"candlestick\"===o.type)c.each(function(t){if(!t.empty){var e=n.select(this),r=o[t.dir];l(e,r.line.width,r.line.color,r.fillcolor),e.style(\"opacity\",o.selectedpoints&&!t.selected?.3:1)}});else{l(c,s,o.line.color,o.fillcolor),r.selectAll(\"path.mean\").style({\"stroke-width\":s,\"stroke-dasharray\":2*s+\"px,\"+s+\"px\"}).call(i.stroke,o.line.color);var u=r.selectAll(\"path.point\");a.pointStyle(u,o,t)}})},styleOnSelect:function(t,e,r){var n=e[0].trace,i=r.selectAll(\"path.point\");n.selectedpoints?a.selectedPointStyle(i,n):a.pointStyle(i,n,t)}}},{\"../../components/color\":593,\"../../components/drawing\":614,d3:163}],892:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../ohlc/attributes\"),a=t(\"../box/attributes\");function o(t){return{line:{color:n({},a.line.color,{dflt:t}),width:a.line.width,editType:\"style\"},fillcolor:a.fillcolor,editType:\"style\"}}e.exports={x:i.x,open:i.open,high:i.high,low:i.low,close:i.close,line:{width:n({},a.line.width,{}),editType:\"style\"},increasing:o(i.increasing.line.color.dflt),decreasing:o(i.decreasing.line.color.dflt),text:i.text,hovertext:i.hovertext,whiskerwidth:n({},a.whiskerwidth,{dflt:0}),hoverlabel:i.hoverlabel}},{\"../../lib\":719,\"../box/attributes\":880,\"../ohlc/attributes\":1058}],893:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../ohlc/calc\").calcCommon;function o(t,e,r,n){return{min:r,q1:Math.min(t,n),med:n,q3:Math.max(t,n),max:e}}e.exports=function(t,e){var r=t._fullLayout,s=i.getFromId(t,e.xaxis),l=i.getFromId(t,e.yaxis),c=s.makeCalcdata(e,\"x\"),u=a(t,e,c,l,o);return u.length?(n.extendFlat(u[0].t,{num:r._numBoxes,dPos:n.distinctVals(c).minDiff/2,posLetter:\"x\",valLetter:\"y\"}),r._numBoxes++,u):[{t:{empty:!0}}]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../ohlc/calc\":1059}],894:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../ohlc/ohlc_defaults\"),o=t(\"./attributes\");function s(t,e,r,n){var a=r(n+\".line.color\");r(n+\".line.width\",e.line.width),r(n+\".fillcolor\",i.addOpacity(a,.5))}e.exports=function(t,e,r,i){function l(r,i){return n.coerce(t,e,o,r,i)}a(t,e,l,i)?(l(\"line.width\"),s(t,e,l,\"increasing\"),s(t,e,l,\"decreasing\"),l(\"text\"),l(\"hovertext\"),l(\"whiskerwidth\"),i._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../components/color\":593,\"../../lib\":719,\"../ohlc/ohlc_defaults\":1063,\"./attributes\":892}],895:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"candlestick\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\",\"candlestick\",\"boxLayout\"],meta:{},attributes:t(\"./attributes\"),layoutAttributes:t(\"../box/layout_attributes\"),supplyLayoutDefaults:t(\"../box/layout_defaults\").supplyLayoutDefaults,crossTraceCalc:t(\"../box/cross_trace_calc\").crossTraceCalc,supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"../box/plot\").plot,layerName:\"boxlayer\",style:t(\"../box/style\").style,hoverPoints:t(\"../ohlc/hover\").hoverPoints,selectPoints:t(\"../ohlc/select\")}},{\"../../plots/cartesian\":778,\"../box/cross_trace_calc\":882,\"../box/layout_attributes\":887,\"../box/layout_defaults\":888,\"../box/plot\":889,\"../box/style\":891,\"../ohlc/hover\":1061,\"../ohlc/select\":1065,\"./attributes\":892,\"./calc\":893,\"./defaults\":894}],896:[function(t,e,r){\"use strict\";var n=t(\"./axis_defaults\"),i=t(\"../../plot_api/plot_template\");e.exports=function(t,e,r,a,o){a(\"a\")||(a(\"da\"),a(\"a0\")),a(\"b\")||(a(\"db\"),a(\"b0\")),function(t,e,r,a){[\"aaxis\",\"baxis\"].forEach(function(o){var s=o.charAt(0),l=t[o]||{},c=i.newContainer(e,o),u={tickfont:\"x\",id:s+\"axis\",letter:s,font:e.font,name:o,data:t[s],calendar:e.calendar,dfltColor:a,bgColor:r.paper_bgcolor,fullLayout:r};n(l,c,u),c._categories=c._categories||[],t[o]||\"-\"===l.type||(t[o]={type:l.type})})}(t,e,r,o)}},{\"../../plot_api/plot_template\":757,\"./axis_defaults\":901}],897:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t){return function t(e,r){if(!n(e)||r>=10)return null;var i=1/0;var a=-1/0;var o=e.length;for(var s=0;s<o;s++){var l=e[s];if(n(l)){var c=t(l,r+1);c&&(i=Math.min(c[0],i),a=Math.max(c[1],a))}else i=Math.min(l,i),a=Math.max(l,a)}return[i,a]}(t,0)}},{\"../../lib\":719}],898:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./axis_attributes\"),a=t(\"../../components/color/attributes\"),o=n({editType:\"calc\"});o.family.dflt='\"Open Sans\", verdana, arial, sans-serif',o.size.dflt=12,o.color.dflt=a.defaultLine,e.exports={carpet:{valType:\"string\",editType:\"calc\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},a:{valType:\"data_array\",editType:\"calc\"},a0:{valType:\"number\",dflt:0,editType:\"calc\"},da:{valType:\"number\",dflt:1,editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},b0:{valType:\"number\",dflt:0,editType:\"calc\"},db:{valType:\"number\",dflt:1,editType:\"calc\"},cheaterslope:{valType:\"number\",dflt:1,editType:\"calc\"},aaxis:i,baxis:i,font:o,color:{valType:\"color\",dflt:a.defaultLine,editType:\"plot\"},transforms:void 0}},{\"../../components/color/attributes\":592,\"../../plots/font_attributes\":793,\"./axis_attributes\":900}],899:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,i){var a,o,s,l,c,u,h,f,p,d,g,v,m,y=n(r)?\"a\":\"b\",x=(\"a\"===y?t.aaxis:t.baxis).smoothing,b=\"a\"===y?t.a2i:t.b2j,_=\"a\"===y?r:i,w=\"a\"===y?i:r,k=\"a\"===y?e.a.length:e.b.length,T=\"a\"===y?e.b.length:e.a.length,A=Math.floor(\"a\"===y?t.b2j(w):t.a2i(w)),M=\"a\"===y?function(e){return t.evalxy([],e,A)}:function(e){return t.evalxy([],A,e)};x&&(s=Math.max(0,Math.min(T-2,A)),l=A-s,o=\"a\"===y?function(e,r){return t.dxydi([],e,s,r,l)}:function(e,r){return t.dxydj([],s,e,l,r)});var S=b(_[0]),E=b(_[1]),C=S<E?1:-1,L=1e-8*(E-S),P=C>0?Math.floor:Math.ceil,O=C>0?Math.ceil:Math.floor,z=C>0?Math.min:Math.max,I=C>0?Math.max:Math.min,D=P(S+L),R=O(E-L),F=[[h=M(S)]];for(a=D;a*C<R*C;a+=C)c=[],g=I(S,a),m=(v=z(E,a+C))-g,u=Math.max(0,Math.min(k-2,Math.floor(.5*(g+v)))),f=M(v),x&&(p=o(u,g-u),d=o(u,v-u),c.push([h[0]+p[0]/3*m,h[1]+p[1]/3*m]),c.push([f[0]-d[0]/3*m,f[1]-d[1]/3*m])),c.push(f),F.push(c),h=f;return F}},{\"../../lib\":719}],900:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../plots/cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").TIME_FORMAT_LINK;e.exports={color:{valType:\"color\",editType:\"calc\"},smoothing:{valType:\"number\",dflt:1,min:0,max:1.3,editType:\"calc\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"calc\"},font:n({editType:\"calc\"}),offset:{valType:\"number\",dflt:10,editType:\"calc\"},editType:\"calc\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"date\",\"category\"],dflt:\"-\",editType:\"calc\"},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"calc\"},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"calc\"},range:{valType:\"info_array\",editType:\"calc\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}]},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cheatertype:{valType:\"enumerated\",values:[\"index\",\"value\"],dflt:\"value\",editType:\"calc\"},tickmode:{valType:\"enumerated\",values:[\"linear\",\"array\"],dflt:\"array\",editType:\"calc\"},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},tickvals:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},showticklabels:{valType:\"enumerated\",values:[\"start\",\"end\",\"both\",\"none\"],dflt:\"start\",editType:\"calc\"},tickfont:n({editType:\"calc\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"calc\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"calc\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"calc\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"calc\"},tickformatstops:o(a.tickformatstops,\"calc\",\"from-root\"),categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},labelpadding:{valType:\"integer\",dflt:10,editType:\"calc\"},labelprefix:{valType:\"string\",editType:\"calc\"},labelsuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showline:{valType:\"boolean\",dflt:!1,editType:\"calc\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"calc\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},gridcolor:{valType:\"color\",editType:\"calc\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},showgrid:{valType:\"boolean\",dflt:!0,editType:\"calc\"},minorgridcount:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},minorgridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},minorgridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"calc\"},startline:{valType:\"boolean\",editType:\"calc\"},startlinecolor:{valType:\"color\",editType:\"calc\"},startlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endline:{valType:\"boolean\",editType:\"calc\"},endlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endlinecolor:{valType:\"color\",editType:\"calc\"},tick0:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},dtick:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},arraytick0:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},arraydtick:{valType:\"integer\",min:1,dflt:1,editType:\"calc\"},_deprecated:{title:{valType:\"string\",editType:\"calc\"},titlefont:n({editType:\"calc\"}),titleoffset:{valType:\"number\",dflt:10,editType:\"calc\"}},editType:\"calc\"}},{\"../../components/color/attributes\":592,\"../../constants/docs\":690,\"../../plot_api/edit_types\":750,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/font_attributes\":793}],901:[function(t,e,r){\"use strict\";var n=t(\"./attributes\"),i=t(\"../../components/color\").addOpacity,a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/tick_value_defaults\"),l=t(\"../../plots/cartesian/tick_label_defaults\"),c=t(\"../../plots/cartesian/category_order_defaults\"),u=t(\"../../plots/cartesian/set_convert\"),h=t(\"../../plots/cartesian/axis_autotype\");e.exports=function(t,e,r){var f=r.letter,p=r.font||{},d=n[f+\"axis\"];function g(r,n){return o.coerce(t,e,d,r,n)}function v(r,n){return o.coerce2(t,e,d,r,n)}r.name&&(e._name=r.name,e._id=r.name);var m=g(\"type\");(\"-\"===m&&(r.data&&function(t,e){if(\"-\"!==t.type)return;var r=t._id.charAt(0),n=t[r+\"calendar\"];t.type=h(e,n)}(e,r.data),\"-\"===e.type?e.type=\"linear\":m=t.type=e.type),g(\"smoothing\"),g(\"cheatertype\"),g(\"showticklabels\"),g(\"labelprefix\",f+\" = \"),g(\"labelsuffix\"),g(\"showtickprefix\"),g(\"showticksuffix\"),g(\"separatethousands\"),g(\"tickformat\"),g(\"exponentformat\"),g(\"showexponent\"),g(\"categoryorder\"),g(\"tickmode\"),g(\"tickvals\"),g(\"ticktext\"),g(\"tick0\"),g(\"dtick\"),\"array\"===e.tickmode&&(g(\"arraytick0\"),g(\"arraydtick\")),g(\"labelpadding\"),e._hovertitle=f,\"date\"===m)&&a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",r.calendar);u(e,r.fullLayout),e.c2p=o.identity;var y=g(\"color\",r.dfltColor),x=y===t.color?y:p.color;g(\"title.text\")&&(o.coerceFont(g,\"title.font\",{family:p.family,size:Math.round(1.2*p.size),color:x}),g(\"title.offset\")),g(\"tickangle\"),g(\"autorange\",!e.isValidRange(t.range))&&g(\"rangemode\"),g(\"range\"),e.cleanRange(),g(\"fixedrange\"),s(t,e,g,m),l(t,e,g,m,r),c(t,e,g,{data:r.data,dataAttr:f});var b=v(\"gridcolor\",i(y,.3)),_=v(\"gridwidth\"),w=g(\"showgrid\");w||(delete e.gridcolor,delete e.gridwidth);var k=v(\"startlinecolor\",y),T=v(\"startlinewidth\",_);g(\"startline\",e.showgrid||!!k||!!T)||(delete e.startlinecolor,delete e.startlinewidth);var A=v(\"endlinecolor\",y),M=v(\"endlinewidth\",_);return g(\"endline\",e.showgrid||!!A||!!M)||(delete e.endlinecolor,delete e.endlinewidth),w?(g(\"minorgridcount\"),g(\"minorgridwidth\",_),g(\"minorgridcolor\",i(b,.06)),e.minorgridcount||(delete e.minorgridwidth,delete e.minorgridcolor)):(delete e.gridcolor,delete e.gridWidth),\"none\"===e.showticklabels&&(delete e.tickfont,delete e.tickangle,delete e.showexponent,delete e.exponentformat,delete e.tickformat,delete e.showticksuffix,delete e.showtickprefix),e.showticksuffix||delete e.ticksuffix,e.showtickprefix||delete e.tickprefix,g(\"tickmode\"),e}},{\"../../components/color\":593,\"../../lib\":719,\"../../plots/cartesian/axis_autotype\":768,\"../../plots/cartesian/category_order_defaults\":771,\"../../plots/cartesian/set_convert\":785,\"../../plots/cartesian/tick_label_defaults\":786,\"../../plots/cartesian/tick_value_defaults\":788,\"../../registry\":847,\"./attributes\":898}],902:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\").isArray1D,a=t(\"./cheater_basis\"),o=t(\"./array_minmax\"),s=t(\"./calc_gridlines\"),l=t(\"./calc_labels\"),c=t(\"./calc_clippath\"),u=t(\"../heatmap/clean_2d_array\"),h=t(\"./smooth_fill_2d_array\"),f=t(\"../heatmap/convert_column_xyz\"),p=t(\"./set_convert\");e.exports=function(t,e){var r=n.getFromId(t,e.xaxis),d=n.getFromId(t,e.yaxis),g=e.aaxis,v=e.baxis,m=e.x,y=e.y,x=[];m&&i(m)&&x.push(\"x\"),y&&i(y)&&x.push(\"y\"),x.length&&f(e,g,v,\"a\",\"b\",x);var b=e._a=e._a||e.a,_=e._b=e._b||e.b;m=e._x||e.x,y=e._y||e.y;var w={};if(e._cheater){var k=\"index\"===g.cheatertype?b.length:b,T=\"index\"===v.cheatertype?_.length:_;m=a(k,T,e.cheaterslope)}e._x=m=u(m),e._y=y=u(y),h(m,b,_),h(y,b,_),p(e),e.setScale();var A=o(m),M=o(y),S=.5*(A[1]-A[0]),E=.5*(A[1]+A[0]),C=.5*(M[1]-M[0]),L=.5*(M[1]+M[0]);return A=[E-1.3*S,E+1.3*S],M=[L-1.3*C,L+1.3*C],e._extremes[r._id]=n.findExtremes(r,A,{padded:!0}),e._extremes[d._id]=n.findExtremes(d,M,{padded:!0}),s(e,\"a\",\"b\"),s(e,\"b\",\"a\"),l(e,g),l(e,v),w.clipsegments=c(e._xctrl,e._yctrl,g,v),w.x=m,w.y=y,w.a=b,w.b=_,[w]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../heatmap/clean_2d_array\":1003,\"../heatmap/convert_column_xyz\":1005,\"./array_minmax\":897,\"./calc_clippath\":903,\"./calc_gridlines\":904,\"./calc_labels\":905,\"./cheater_basis\":907,\"./set_convert\":920,\"./smooth_fill_2d_array\":921}],903:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a,o,s=[],l=!!r.smoothing,c=!!n.smoothing,u=t[0].length-1,h=t.length-1;for(i=0,a=[],o=[];i<=u;i++)a[i]=t[0][i],o[i]=e[0][i];for(s.push({x:a,y:o,bicubic:l}),i=0,a=[],o=[];i<=h;i++)a[i]=t[i][u],o[i]=e[i][u];for(s.push({x:a,y:o,bicubic:c}),i=u,a=[],o=[];i>=0;i--)a[u-i]=t[h][i],o[u-i]=e[h][i];for(s.push({x:a,y:o,bicubic:l}),i=h,a=[],o=[];i>=0;i--)a[h-i]=t[i][0],o[h-i]=e[i][0];return s.push({x:a,y:o,bicubic:c}),s}},{}],904:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e,r){var a,o,s,l,c,u,h,f,p,d,g,v,m,y,x=t[\"_\"+e],b=t[e+\"axis\"],_=b._gridlines=[],w=b._minorgridlines=[],k=b._boundarylines=[],T=t[\"_\"+r],A=t[r+\"axis\"];\"array\"===b.tickmode&&(b.tickvals=x.slice());var M=t._xctrl,S=t._yctrl,E=M[0].length,C=M.length,L=t._a.length,P=t._b.length;n.prepTicks(b),\"array\"===b.tickmode&&delete b.tickvals;var O=b.smoothing?3:1;function z(n){var i,a,o,s,l,c,u,h,p,d,g,v,m=[],y=[],x={};if(\"b\"===e)for(a=t.b2j(n),o=Math.floor(Math.max(0,Math.min(P-2,a))),s=a-o,x.length=P,x.crossLength=L,x.xy=function(e){return t.evalxy([],e,a)},x.dxy=function(e,r){return t.dxydi([],e,o,r,s)},i=0;i<L;i++)c=Math.min(L-2,i),u=i-c,h=t.evalxy([],i,a),A.smoothing&&i>0&&(p=t.dxydi([],i-1,o,0,s),m.push(l[0]+p[0]/3),y.push(l[1]+p[1]/3),d=t.dxydi([],i-1,o,1,s),m.push(h[0]-d[0]/3),y.push(h[1]-d[1]/3)),m.push(h[0]),y.push(h[1]),l=h;else for(i=t.a2i(n),c=Math.floor(Math.max(0,Math.min(L-2,i))),u=i-c,x.length=L,x.crossLength=P,x.xy=function(e){return t.evalxy([],i,e)},x.dxy=function(e,r){return t.dxydj([],c,e,u,r)},a=0;a<P;a++)o=Math.min(P-2,a),s=a-o,h=t.evalxy([],i,a),A.smoothing&&a>0&&(g=t.dxydj([],c,a-1,u,0),m.push(l[0]+g[0]/3),y.push(l[1]+g[1]/3),v=t.dxydj([],c,a-1,u,1),m.push(h[0]-v[0]/3),y.push(h[1]-v[1]/3)),m.push(h[0]),y.push(h[1]),l=h;return x.axisLetter=e,x.axis=b,x.crossAxis=A,x.value=n,x.constvar=r,x.index=f,x.x=m,x.y=y,x.smoothing=A.smoothing,x}function I(n){var i,a,o,s,l,c=[],u=[],h={};if(h.length=x.length,h.crossLength=T.length,\"b\"===e)for(o=Math.max(0,Math.min(P-2,n)),l=Math.min(1,Math.max(0,n-o)),h.xy=function(e){return t.evalxy([],e,n)},h.dxy=function(e,r){return t.dxydi([],e,o,r,l)},i=0;i<E;i++)c[i]=M[n*O][i],u[i]=S[n*O][i];else for(a=Math.max(0,Math.min(L-2,n)),s=Math.min(1,Math.max(0,n-a)),h.xy=function(e){return t.evalxy([],n,e)},h.dxy=function(e,r){return t.dxydj([],a,e,s,r)},i=0;i<C;i++)c[i]=M[i][n*O],u[i]=S[i][n*O];return h.axisLetter=e,h.axis=b,h.crossAxis=A,h.value=x[n],h.constvar=r,h.index=n,h.x=c,h.y=u,h.smoothing=A.smoothing,h}if(\"array\"===b.tickmode){for(l=5e-15,u=(c=[Math.floor((x.length-1-b.arraytick0)/b.arraydtick*(1+l)),Math.ceil(-b.arraytick0/b.arraydtick/(1+l))].sort(function(t,e){return t-e}))[0]-1,h=c[1]+1,f=u;f<h;f++)(o=b.arraytick0+b.arraydtick*f)<0||o>x.length-1||_.push(i(I(o),{color:b.gridcolor,width:b.gridwidth}));for(f=u;f<h;f++)if(s=b.arraytick0+b.arraydtick*f,g=Math.min(s+b.arraydtick,x.length-1),!(s<0||s>x.length-1||g<0||g>x.length-1))for(v=x[s],m=x[g],a=0;a<b.minorgridcount;a++)(y=g-s)<=0||(d=v+(m-v)*(a+1)/(b.minorgridcount+1)*(b.arraydtick/y))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&k.push(i(I(0),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&k.push(i(I(x.length-1),{color:b.endlinecolor,width:b.endlinewidth}))}else{for(l=5e-15,u=(c=[Math.floor((x[x.length-1]-b.tick0)/b.dtick*(1+l)),Math.ceil((x[0]-b.tick0)/b.dtick/(1+l))].sort(function(t,e){return t-e}))[0],h=c[1],f=u;f<=h;f++)p=b.tick0+b.dtick*f,_.push(i(z(p),{color:b.gridcolor,width:b.gridwidth}));for(f=u-1;f<h+1;f++)for(p=b.tick0+b.dtick*f,a=0;a<b.minorgridcount;a++)(d=p+b.dtick*(a+1)/(b.minorgridcount+1))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&k.push(i(z(x[0]),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&k.push(i(z(x[x.length-1]),{color:b.endlinecolor,width:b.endlinewidth}))}}},{\"../../lib/extend\":710,\"../../plots/cartesian/axes\":767}],905:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e){var r,a,o,s=e._labels=[],l=e._gridlines;for(r=0;r<l.length;r++)o=l[r],-1!==[\"start\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{prefix:void 0,suffix:void 0,endAnchor:!0,xy:o.xy(0),dxy:o.dxy(0,0),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a)),-1!==[\"end\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{endAnchor:!1,xy:o.xy(o.crossLength-1),dxy:o.dxy(o.crossLength-2,1),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a))}},{\"../../lib/extend\":710,\"../../plots/cartesian/axes\":767}],906:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=t[0]-e[0],a=t[1]-e[1],o=r[0]-e[0],s=r[1]-e[1],l=Math.pow(i*i+a*a,.25),c=Math.pow(o*o+s*s,.25),u=(c*c*i-l*l*o)*n,h=(c*c*a-l*l*s)*n,f=c*(l+c)*3,p=l*(l+c)*3;return[[e[0]+(f&&u/f),e[1]+(f&&h/f)],[e[0]-(p&&u/p),e[1]-(p&&h/p)]]}},{}],907:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i,a,o,s,l,c,u=[],h=n(t)?t.length:t,f=n(e)?e.length:e,p=n(t)?t:null,d=n(e)?e:null;p&&(o=(p.length-1)/(p[p.length-1]-p[0])/(h-1)),d&&(s=(d.length-1)/(d[d.length-1]-d[0])/(f-1));var g=1/0,v=-1/0;for(a=0;a<f;a++)for(u[a]=[],l=d?(d[a]-d[0])*s:a/(f-1),i=0;i<h;i++)c=(p?(p[i]-p[0])*o:i/(h-1))-l*r,g=Math.min(c,g),v=Math.max(c,v),u[a][i]=c;var m=1/(v-g),y=-g*m;for(a=0;a<f;a++)for(i=0;i<h;i++)u[a][i]=m*u[a][i]+y;return u}},{\"../../lib\":719}],908:[function(t,e,r){\"use strict\";var n=t(\"./catmull_rom\"),i=t(\"../../lib\").ensureArray;function a(t,e,r){var n=-.5*r[0]+1.5*e[0],i=-.5*r[1]+1.5*e[1];return[(2*n+t[0])/3,(2*i+t[1])/3]}e.exports=function(t,e,r,o,s,l){var c,u,h,f,p,d,g,v,m,y,x=r[0].length,b=r.length,_=s?3*x-2:x,w=l?3*b-2:b;for(t=i(t,w),e=i(e,w),h=0;h<w;h++)t[h]=i(t[h],_),e[h]=i(e[h],_);for(u=0,f=0;u<b;u++,f+=l?3:1)for(p=t[f],d=e[f],g=r[u],v=o[u],c=0,h=0;c<x;c++,h+=s?3:1)p[h]=g[c],d[h]=v[c];if(s)for(u=0,f=0;u<b;u++,f+=l?3:1){for(c=1,h=3;c<x-1;c++,h+=3)m=n([r[u][c-1],o[u][c-1]],[r[u][c],o[u][c]],[r[u][c+1],o[u][c+1]],s),t[f][h-1]=m[0][0],e[f][h-1]=m[0][1],t[f][h+1]=m[1][0],e[f][h+1]=m[1][1];y=a([t[f][0],e[f][0]],[t[f][2],e[f][2]],[t[f][3],e[f][3]]),t[f][1]=y[0],e[f][1]=y[1],y=a([t[f][_-1],e[f][_-1]],[t[f][_-3],e[f][_-3]],[t[f][_-4],e[f][_-4]]),t[f][_-2]=y[0],e[f][_-2]=y[1]}if(l)for(h=0;h<_;h++){for(f=3;f<w-3;f+=3)m=n([t[f-3][h],e[f-3][h]],[t[f][h],e[f][h]],[t[f+3][h],e[f+3][h]],l),t[f-1][h]=m[0][0],e[f-1][h]=m[0][1],t[f+1][h]=m[1][0],e[f+1][h]=m[1][1];y=a([t[0][h],e[0][h]],[t[2][h],e[2][h]],[t[3][h],e[3][h]]),t[1][h]=y[0],e[1][h]=y[1],y=a([t[w-1][h],e[w-1][h]],[t[w-3][h],e[w-3][h]],[t[w-4][h],e[w-4][h]]),t[w-2][h]=y[0],e[w-2][h]=y[1]}if(s&&l)for(f=1;f<w;f+=(f+1)%3==0?2:1){for(h=3;h<_-3;h+=3)m=n([t[f][h-3],e[f][h-3]],[t[f][h],e[f][h]],[t[f][h+3],e[f][h+3]],s),t[f][h-1]=.5*(t[f][h-1]+m[0][0]),e[f][h-1]=.5*(e[f][h-1]+m[0][1]),t[f][h+1]=.5*(t[f][h+1]+m[1][0]),e[f][h+1]=.5*(e[f][h+1]+m[1][1]);y=a([t[f][0],e[f][0]],[t[f][2],e[f][2]],[t[f][3],e[f][3]]),t[f][1]=.5*(t[f][1]+y[0]),e[f][1]=.5*(e[f][1]+y[1]),y=a([t[f][_-1],e[f][_-1]],[t[f][_-3],e[f][_-3]],[t[f][_-4],e[f][_-4]]),t[f][_-2]=.5*(t[f][_-2]+y[0]),e[f][_-2]=.5*(e[f][_-2]+y[1])}return[t,e]}},{\"../../lib\":719,\"./catmull_rom\":906}],909:[function(t,e,r){\"use strict\";e.exports={RELATIVE_CULL_TOLERANCE:1e-6}},{}],910:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3,n*=3;var f=i*i,p=1-i,d=p*p,g=p*i*2,v=-3*d,m=3*(d-g),y=3*(g-f),x=3*f,b=a*a,_=b*a,w=1-a,k=w*w,T=k*w;for(h=0;h<t.length;h++)o=v*(u=t[h])[n][r]+m*u[n][r+1]+y*u[n][r+2]+x*u[n][r+3],s=v*u[n+1][r]+m*u[n+1][r+1]+y*u[n+1][r+2]+x*u[n+1][r+3],l=v*u[n+2][r]+m*u[n+2][r+1]+y*u[n+2][r+2]+x*u[n+2][r+3],c=v*u[n+3][r]+m*u[n+3][r+1]+y*u[n+3][r+2]+x*u[n+3][r+3],e[h]=T*o+3*(k*a*s+w*b*l)+_*c;return e}:e?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),r*=3;var u=i*i,h=1-i,f=h*h,p=h*i*2,d=-3*f,g=3*(f-p),v=3*(p-u),m=3*u,y=1-a;for(l=0;l<t.length;l++)o=d*(c=t[l])[n][r]+g*c[n][r+1]+v*c[n][r+2]+m*c[n][r+3],s=d*c[n+1][r]+g*c[n+1][r+1]+v*c[n+1][r+2]+m*c[n+1][r+3],e[l]=y*o+a*s;return e}:r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),n*=3;var f=a*a,p=f*a,d=1-a,g=d*d,v=g*d;for(u=0;u<t.length;u++)o=(h=t[u])[n][r+1]-h[n][r],s=h[n+1][r+1]-h[n+1][r],l=h[n+2][r+1]-h[n+2][r],c=h[n+3][r+1]-h[n+3][r],e[u]=v*o+3*(g*a*s+d*f*l)+p*c;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-a;for(l=0;l<t.length;l++)o=(c=t[l])[n][r+1]-c[n][r],s=c[n+1][r+1]-c[n+1][r],e[l]=u*o+a*s;return e}}},{}],911:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3,n*=3;var f=i*i,p=f*i,d=1-i,g=d*d,v=g*d,m=a*a,y=1-a,x=y*y,b=y*a*2,_=-3*x,w=3*(x-b),k=3*(b-m),T=3*m;for(h=0;h<t.length;h++)o=_*(u=t[h])[n][r]+w*u[n+1][r]+k*u[n+2][r]+T*u[n+3][r],s=_*u[n][r+1]+w*u[n+1][r+1]+k*u[n+2][r+1]+T*u[n+3][r+1],l=_*u[n][r+2]+w*u[n+1][r+2]+k*u[n+2][r+2]+T*u[n+3][r+2],c=_*u[n][r+3]+w*u[n+1][r+3]+k*u[n+2][r+3]+T*u[n+3][r+3],e[h]=v*o+3*(g*i*s+d*f*l)+p*c;return e}:e?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3;var f=a*a,p=f*a,d=1-a,g=d*d,v=g*d;for(u=0;u<t.length;u++)o=(h=t[u])[n+1][r]-h[n][r],s=h[n+1][r+1]-h[n][r+1],l=h[n+1][r+2]-h[n][r+2],c=h[n+1][r+3]-h[n][r+3],e[u]=v*o+3*(g*a*s+d*f*l)+p*c;return e}:r?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),n*=3;var u=1-i,h=a*a,f=1-a,p=f*f,d=f*a*2,g=-3*p,v=3*(p-d),m=3*(d-h),y=3*h;for(l=0;l<t.length;l++)o=g*(c=t[l])[n][r]+v*c[n+1][r]+m*c[n+2][r]+y*c[n+3][r],s=g*c[n][r+1]+v*c[n+1][r+1]+m*c[n+2][r+1]+y*c[n+3][r+1],e[l]=u*o+i*s;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-i;for(l=0;l<t.length;l++)o=(c=t[l])[n+1][r]-c[n][r],s=c[n+1][r+1]-c[n][r+1],e[l]=u*o+i*s;return e}}},{}],912:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=e-2,o=r-2;return n&&i?function(e,r,n){var i,s,l,c,u,h;e||(e=[]);var f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));f*=3,p*=3;var v=d*d,m=v*d,y=1-d,x=y*y,b=x*y,_=g*g,w=_*g,k=1-g,T=k*k,A=T*k;for(h=0;h<t.length;h++)i=b*(u=t[h])[p][f]+3*(x*d*u[p][f+1]+y*v*u[p][f+2])+m*u[p][f+3],s=b*u[p+1][f]+3*(x*d*u[p+1][f+1]+y*v*u[p+1][f+2])+m*u[p+1][f+3],l=b*u[p+2][f]+3*(x*d*u[p+2][f+1]+y*v*u[p+2][f+2])+m*u[p+2][f+3],c=b*u[p+3][f]+3*(x*d*u[p+3][f+1]+y*v*u[p+3][f+2])+m*u[p+3][f+3],e[h]=A*i+3*(T*g*s+k*_*l)+w*c;return e}:n?function(e,r,n){e||(e=[]);var i,s,l,c,u,h,f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));f*=3;var v=d*d,m=v*d,y=1-d,x=y*y,b=x*y,_=1-g;for(u=0;u<t.length;u++)i=_*(h=t[u])[p][f]+g*h[p+1][f],s=_*h[p][f+1]+g*h[p+1][f+1],l=_*h[p][f+2]+g*h[p+1][f+1],c=_*h[p][f+3]+g*h[p+1][f+1],e[u]=b*i+3*(x*d*s+y*v*l)+m*c;return e}:i?function(e,r,n){e||(e=[]);var i,s,l,c,u,h,f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));p*=3;var v=g*g,m=v*g,y=1-g,x=y*y,b=x*y,_=1-d;for(u=0;u<t.length;u++)i=_*(h=t[u])[p][f]+d*h[p][f+1],s=_*h[p+1][f]+d*h[p+1][f+1],l=_*h[p+2][f]+d*h[p+2][f+1],c=_*h[p+3][f]+d*h[p+3][f+1],e[u]=b*i+3*(x*g*s+y*v*l)+m*c;return e}:function(e,r,n){e||(e=[]);var i,s,l,c,u=Math.max(0,Math.min(Math.floor(r),a)),h=Math.max(0,Math.min(Math.floor(n),o)),f=Math.max(0,Math.min(1,r-u)),p=Math.max(0,Math.min(1,n-h)),d=1-p,g=1-f;for(l=0;l<t.length;l++)i=g*(c=t[l])[h][u]+f*c[h][u+1],s=g*c[h+1][u]+f*c[h+1][u+1],e[l]=d*i+p*s;return e}}},{}],913:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xy_defaults\"),a=t(\"./ab_defaults\"),o=t(\"./attributes\"),s=t(\"../../components/color/attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,o,r,i)}e._clipPathId=\"clip\"+e.uid+\"carpet\";var u=c(\"color\",s.defaultLine);(n.coerceFont(c,\"font\"),c(\"carpet\"),a(t,e,l,c,u),e.a&&e.b)?(e.a.length<3&&(e.aaxis.smoothing=0),e.b.length<3&&(e.baxis.smoothing=0),i(t,e,c)||(e.visible=!1),e._cheater&&c(\"cheaterslope\")):e.visible=!1}},{\"../../components/color/attributes\":592,\"../../lib\":719,\"./ab_defaults\":896,\"./attributes\":898,\"./xy_defaults\":922}],914:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),plot:t(\"./plot\"),calc:t(\"./calc\"),animatable:!0,isContainer:!0,moduleType:\"trace\",name:\"carpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"carpetAxis\",\"notLegendIsolatable\",\"noMultiCategory\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":898,\"./calc\":902,\"./defaults\":913,\"./plot\":919}],915:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r,n=t._fullData.length,i=0;i<n;i++){var a=t._fullData[i];if(a.index!==e.index&&(\"carpet\"===a.type&&(r||(r=a),a.carpet===e.carpet)))return a}return r}},{}],916:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(0===t.length)return\"\";var n,i=[],a=r?3:1;for(n=0;n<t.length;n+=a)i.push(t[n]+\",\"+e[n]),r&&n<t.length-a&&(i.push(\"C\"),i.push([t[n+1]+\",\"+e[n+1],t[n+2]+\",\"+e[n+2]+\" \"].join(\" \")));return i.join(r?\"\":\"L\")}},{}],917:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i;for(n(t)?t.length>e.length&&(t=t.slice(0,e.length)):t=[],i=0;i<e.length;i++)t[i]=r(e[i]);return t}},{\"../../lib\":719}],918:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i[0]*t.dpdx(e),s=i[1]*t.dpdy(r),l=1,c=1;if(a){var u=Math.sqrt(i[0]*i[0]+i[1]*i[1]),h=Math.sqrt(a[0]*a[0]+a[1]*a[1]),f=(i[0]*a[0]+i[1]*a[1])/u/h;c=Math.max(0,f)}var p=180*Math.atan2(s,o)/Math.PI;return p<-90?(p+=180,l=-l):p>90&&(p-=180,l=-l),{angle:p,flip:l,p:t.c2p(n,e,r),offsetMultplier:c}}},{}],919:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"./map_1d_array\"),o=t(\"./makepath\"),s=t(\"./orient_text\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib\"),u=t(\"../../constants/alignment\");function h(t,e,r,i,s,l){var c=\"const-\"+s+\"-lines\",u=r.selectAll(\".\"+c).data(l);u.enter().append(\"path\").classed(c,!0).style(\"vector-effect\",\"non-scaling-stroke\"),u.each(function(r){var i=r,s=i.x,l=i.y,c=a([],s,t.c2p),u=a([],l,e.c2p),h=\"M\"+o(c,u,i.smoothing);n.select(this).attr(\"d\",h).style(\"stroke-width\",i.width).style(\"stroke\",i.color).style(\"fill\",\"none\")}),u.exit().remove()}function f(t,e,r,a,o,c,u,h){var f=c.selectAll(\"text.\"+h).data(u);f.enter().append(\"text\").classed(h,!0);var p=0,d={};return f.each(function(o,c){var u;if(\"auto\"===o.axis.tickangle)u=s(a,e,r,o.xy,o.dxy);else{var h=(o.axis.tickangle+180)*Math.PI/180;u=s(a,e,r,o.xy,[Math.cos(h),Math.sin(h)])}c||(d={angle:u.angle,flip:u.flip});var f=(o.endAnchor?-1:1)*u.flip,g=n.select(this).attr({\"text-anchor\":f>0?\"start\":\"end\",\"data-notex\":1}).call(i.font,o.font).text(o.text).call(l.convertToTspans,t),v=i.bBox(this);g.attr(\"transform\",\"translate(\"+u.p[0]+\",\"+u.p[1]+\") rotate(\"+u.angle+\")translate(\"+o.axis.labelpadding*f+\",\"+.3*v.height+\")\"),p=Math.max(p,v.width+o.axis.labelpadding)}),f.exit().remove(),d.maxExtent=p,d}e.exports=function(t,e,r,i){var l=e.xaxis,u=e.yaxis,p=t._fullLayout._clips;c.makeTraceGroups(i,r,\"trace\").each(function(e){var r=n.select(this),i=e[0],d=i.trace,v=d.aaxis,m=d.baxis,y=c.ensureSingle(r,\"g\",\"minorlayer\"),x=c.ensureSingle(r,\"g\",\"majorlayer\"),b=c.ensureSingle(r,\"g\",\"boundarylayer\"),_=c.ensureSingle(r,\"g\",\"labellayer\");r.style(\"opacity\",d.opacity),h(l,u,x,v,\"a\",v._gridlines),h(l,u,x,m,\"b\",m._gridlines),h(l,u,y,v,\"a\",v._minorgridlines),h(l,u,y,m,\"b\",m._minorgridlines),h(l,u,b,v,\"a-boundary\",v._boundarylines),h(l,u,b,m,\"b-boundary\",m._boundarylines);var w=f(t,l,u,d,i,_,v._labels,\"a-label\"),k=f(t,l,u,d,i,_,m._labels,\"b-label\");!function(t,e,r,n,i,a,o,l){var u,h,f,p,d=c.aggNums(Math.min,null,r.a),v=c.aggNums(Math.max,null,r.a),m=c.aggNums(Math.min,null,r.b),y=c.aggNums(Math.max,null,r.b);u=.5*(d+v),h=m,f=r.ab2xy(u,h,!0),p=r.dxyda_rough(u,h),void 0===o.angle&&c.extendFlat(o,s(r,i,a,f,r.dxydb_rough(u,h)));g(t,e,r,n,f,p,r.aaxis,i,a,o,\"a-title\"),u=d,h=.5*(m+y),f=r.ab2xy(u,h,!0),p=r.dxydb_rough(u,h),void 0===l.angle&&c.extendFlat(l,s(r,i,a,f,r.dxyda_rough(u,h)));g(t,e,r,n,f,p,r.baxis,i,a,l,\"b-title\")}(t,_,d,i,l,u,w,k),function(t,e,r,n,i){var s,l,u,h,f=r.select(\"#\"+t._clipPathId);f.size()||(f=r.append(\"clipPath\").classed(\"carpetclip\",!0));var p=c.ensureSingle(f,\"path\",\"carpetboundary\"),d=e.clipsegments,g=[];for(h=0;h<d.length;h++)s=d[h],l=a([],s.x,n.c2p),u=a([],s.y,i.c2p),g.push(o(l,u,s.bicubic));var v=\"M\"+g.join(\"L\")+\"Z\";f.attr(\"id\",t._clipPathId),p.attr(\"d\",v)}(d,i,p,l,u)})};var p=u.LINE_SPACING,d=(1-u.MID_SHIFT)/p+1;function g(t,e,r,a,o,c,u,h,f,g,v){var m=[];u.title.text&&m.push(u.title.text);var y=e.selectAll(\"text.\"+v).data(m),x=g.maxExtent;y.enter().append(\"text\").classed(v,!0),y.each(function(){var e=s(r,h,f,o,c);-1===[\"start\",\"both\"].indexOf(u.showticklabels)&&(x=0);var a=u.title.font.size;x+=a+u.title.offset;var v=(g.angle+(g.flip<0?180:0)-e.angle+450)%360,m=v>90&&v<270,y=n.select(this);y.text(u.title.text).call(l.convertToTspans,t),m&&(x=(-l.lineCount(y)+d)*p*a-x),y.attr(\"transform\",\"translate(\"+e.p[0]+\",\"+e.p[1]+\") rotate(\"+e.angle+\") translate(0,\"+x+\")\").classed(\"user-select-none\",!0).attr(\"text-anchor\",\"middle\").call(i.font,u.title.font)}),y.exit().remove()}},{\"../../components/drawing\":614,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"./makepath\":916,\"./map_1d_array\":917,\"./orient_text\":918,d3:163}],920:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/search\").findBin,a=t(\"./compute_control_points\"),o=t(\"./create_spline_evaluator\"),s=t(\"./create_i_derivative_evaluator\"),l=t(\"./create_j_derivative_evaluator\");e.exports=function(t){var e=t._a,r=t._b,c=e.length,u=r.length,h=t.aaxis,f=t.baxis,p=e[0],d=e[c-1],g=r[0],v=r[u-1],m=e[e.length-1]-e[0],y=r[r.length-1]-r[0],x=m*n.RELATIVE_CULL_TOLERANCE,b=y*n.RELATIVE_CULL_TOLERANCE;p-=x,d+=x,g-=b,v+=b,t.isVisible=function(t,e){return t>p&&t<d&&e>g&&e<v},t.isOccluded=function(t,e){return t<p||t>d||e<g||e>v},t.setScale=function(){var e=t._x,r=t._y,n=a(t._xctrl,t._yctrl,e,r,h.smoothing,f.smoothing);t._xctrl=n[0],t._yctrl=n[1],t.evalxy=o([t._xctrl,t._yctrl],c,u,h.smoothing,f.smoothing),t.dxydi=s([t._xctrl,t._yctrl],h.smoothing,f.smoothing),t.dxydj=l([t._xctrl,t._yctrl],h.smoothing,f.smoothing)},t.i2a=function(t){var r=Math.max(0,Math.floor(t[0]),c-2),n=t[0]-r;return(1-n)*e[r]+n*e[r+1]},t.j2b=function(t){var e=Math.max(0,Math.floor(t[1]),c-2),n=t[1]-e;return(1-n)*r[e]+n*r[e+1]},t.ij2ab=function(e){return[t.i2a(e[0]),t.j2b(e[1])]},t.a2i=function(t){var r=Math.max(0,Math.min(i(t,e),c-2)),n=e[r],a=e[r+1];return Math.max(0,Math.min(c-1,r+(t-n)/(a-n)))},t.b2j=function(t){var e=Math.max(0,Math.min(i(t,r),u-2)),n=r[e],a=r[e+1];return Math.max(0,Math.min(u-1,e+(t-n)/(a-n)))},t.ab2ij=function(e){return[t.a2i(e[0]),t.b2j(e[1])]},t.i2c=function(e,r){return t.evalxy([],e,r)},t.ab2xy=function(n,i,a){if(!a&&(n<e[0]||n>e[c-1]|i<r[0]||i>r[u-1]))return[!1,!1];var o=t.a2i(n),s=t.b2j(i),l=t.evalxy([],o,s);if(a){var h,f,p,d,g=0,v=0,m=[];n<e[0]?(h=0,f=0,g=(n-e[0])/(e[1]-e[0])):n>e[c-1]?(h=c-2,f=1,g=(n-e[c-1])/(e[c-1]-e[c-2])):f=o-(h=Math.max(0,Math.min(c-2,Math.floor(o)))),i<r[0]?(p=0,d=0,v=(i-r[0])/(r[1]-r[0])):i>r[u-1]?(p=u-2,d=1,v=(i-r[u-1])/(r[u-1]-r[u-2])):d=s-(p=Math.max(0,Math.min(u-2,Math.floor(s)))),g&&(t.dxydi(m,h,p,f,d),l[0]+=m[0]*g,l[1]+=m[1]*g),v&&(t.dxydj(m,h,p,f,d),l[0]+=m[0]*v,l[1]+=m[1]*v)}return l},t.c2p=function(t,e,r){return[e.c2p(t[0]),r.c2p(t[1])]},t.p2x=function(t,e,r){return[e.p2c(t[0]),r.p2c(t[1])]},t.dadi=function(t){var r=Math.max(0,Math.min(e.length-2,t));return e[r+1]-e[r]},t.dbdj=function(t){var e=Math.max(0,Math.min(r.length-2,t));return r[e+1]-r[e]},t.dxyda=function(e,r,n,i){var a=t.dxydi(null,e,r,n,i),o=t.dadi(e,n);return[a[0]/o,a[1]/o]},t.dxydb=function(e,r,n,i){var a=t.dxydj(null,e,r,n,i),o=t.dbdj(r,i);return[a[0]/o,a[1]/o]},t.dxyda_rough=function(e,r,n){var i=m*(n||.1),a=t.ab2xy(e+i,r,!0),o=t.ab2xy(e-i,r,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dxydb_rough=function(e,r,n){var i=y*(n||.1),a=t.ab2xy(e,r+i,!0),o=t.ab2xy(e,r-i,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dpdx=function(t){return t._m},t.dpdy=function(t){return t._m}}},{\"../../lib/search\":738,\"./compute_control_points\":908,\"./constants\":909,\"./create_i_derivative_evaluator\":910,\"./create_j_derivative_evaluator\":911,\"./create_spline_evaluator\":912}],921:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r){var i,a,o,s=[],l=[],c=t[0].length,u=t.length;function h(e,r){var n,i=0,a=0;return e>0&&void 0!==(n=t[r][e-1])&&(a++,i+=n),e<c-1&&void 0!==(n=t[r][e+1])&&(a++,i+=n),r>0&&void 0!==(n=t[r-1][e])&&(a++,i+=n),r<u-1&&void 0!==(n=t[r+1][e])&&(a++,i+=n),i/Math.max(1,a)}var f,p,d,g,v,m,y,x,b,_,w,k=0;for(i=0;i<c;i++)for(a=0;a<u;a++)void 0===t[a][i]&&(s.push(i),l.push(a),t[a][i]=h(i,a)),k=Math.max(k,Math.abs(t[a][i]));if(!s.length)return t;var T=0,A=0,M=s.length;do{for(T=0,o=0;o<M;o++){i=s[o],a=l[o];var S,E,C,L,P,O,z=0,I=0;0===i?(C=e[P=Math.min(c-1,2)],L=e[1],S=t[a][P],I+=(E=t[a][1])+(E-S)*(e[0]-L)/(L-C),z++):i===c-1&&(C=e[P=Math.max(0,c-3)],L=e[c-2],S=t[a][P],I+=(E=t[a][c-2])+(E-S)*(e[c-1]-L)/(L-C),z++),(0===i||i===c-1)&&a>0&&a<u-1&&(f=r[a+1]-r[a],I+=((p=r[a]-r[a-1])*t[a+1][i]+f*t[a-1][i])/(p+f),z++),0===a?(C=r[O=Math.min(u-1,2)],L=r[1],S=t[O][i],I+=(E=t[1][i])+(E-S)*(r[0]-L)/(L-C),z++):a===u-1&&(C=r[O=Math.max(0,u-3)],L=r[u-2],S=t[O][i],I+=(E=t[u-2][i])+(E-S)*(r[u-1]-L)/(L-C),z++),(0===a||a===u-1)&&i>0&&i<c-1&&(f=e[i+1]-e[i],I+=((p=e[i]-e[i-1])*t[a][i+1]+f*t[a][i-1])/(p+f),z++),z?I/=z:(d=e[i+1]-e[i],g=e[i]-e[i-1],x=(v=r[a+1]-r[a])*(m=r[a]-r[a-1])*(v+m),I=((y=d*g*(d+g))*(m*t[a+1][i]+v*t[a-1][i])+x*(g*t[a][i+1]+d*t[a][i-1]))/(x*(g+d)+y*(m+v))),T+=(_=(b=I-t[a][i])/k)*_,w=z?0:.85,t[a][i]+=b*(1+w)}T=Math.sqrt(T)}while(A++<100&&T>1e-5);return n.log(\"Smoother converged to\",T,\"after\",A,\"iterations\"),t}},{\"../../lib\":719}],922:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArray1D;e.exports=function(t,e,r){var i=r(\"x\"),a=i&&i.length,o=r(\"y\"),s=o&&o.length;if(!a&&!s)return!1;if(e._cheater=!i,a&&!n(i)||s&&!n(o))e._length=null;else{var l=a?i.length:1/0;s&&(l=Math.min(l,o.length)),e.a&&e.a.length&&(l=Math.min(l,e.a.length)),e.b&&e.b.length&&(l=Math.min(l,e.b.length)),e._length=l}return!0}},{\"../../lib\":719}],923:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scattergeo/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/color/attributes\").defaultLine,l=t(\"../../lib/extend\").extendFlat,c=i.marker.line;e.exports=l({locations:{valType:\"data_array\",editType:\"calc\"},locationmode:i.locationmode,z:{valType:\"data_array\",editType:\"calc\"},text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),marker:{line:{color:l({},c.color,{dflt:s}),width:l({},c.width,{dflt:1}),editType:\"calc\"},opacity:{valType:\"number\",arrayOk:!0,min:0,max:1,dflt:1,editType:\"style\"},editType:\"calc\"},selected:{marker:{opacity:i.selected.marker.opacity,editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:i.unselected.marker.opacity,editType:\"plot\"},editType:\"plot\"},hoverinfo:l({},o.hoverinfo,{editType:\"calc\",flags:[\"location\",\"z\",\"text\",\"name\"]}),hovertemplate:n()},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/color/attributes\":592,\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scattergeo/attributes\":1151}],924:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../components/colorscale/calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\");function l(t){return t&&\"string\"==typeof t}e.exports=function(t,e){var r,c=e._length,u=new Array(c);r=e.geojson?function(t){return l(t)||n(t)}:l;for(var h=0;h<c;h++){var f=u[h]={},p=e.locations[h],d=e.z[h];r(p)&&n(d)?(f.loc=p,f.z=d):(f.loc=null,f.z=i),f.index=h}return o(u,e),a(t,e,{vals:e.z,containerStr:\"\",cLetter:\"z\"}),s(u,e),u}},{\"../../components/colorscale/calc\":601,\"../../constants/numerical\":695,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc_selection\":1114,\"fast-isnumeric\":225}],925:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\");l&&l.length&&n.isArrayOrTypedArray(c)&&c.length?(e._length=Math.min(l.length,c.length),s(\"locationmode\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":923}],926:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){t.location=e.location,t.z=e.z;var a=n[i];return a.fIn&&(t.properties=a.fIn.properties),t}},{}],927:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"./attributes\"),a=t(\"../../lib\").fillText;e.exports=function(t,e,r){var o,s,l,c,u=t.cd,h=u[0].trace,f=t.subplot;for(s=0;s<u.length;s++)if(c=!1,(o=u[s])._polygons){for(l=0;l<o._polygons.length;l++)o._polygons[l].contains([e,r])&&(c=!c),o._polygons[l].contains([e+360,r])&&(c=!c);if(c)break}if(c&&o)return t.x0=t.x1=t.xa.c2p(o.ct),t.y0=t.y1=t.ya.c2p(o.ct),t.index=o.index,t.location=o.loc,t.z=o.z,t.zLabel=n.tickText(f.mockAxis,f.mockAxis.c2l(o.z),\"hover\").text,t.hovertemplate=o.hovertemplate,function(t,e,r){if(e.hovertemplate)return;var n=r.hi||e.hoverinfo,o=\"all\"===n?i.hoverinfo.flags:n.split(\"+\"),s=-1!==o.indexOf(\"name\"),l=-1!==o.indexOf(\"location\"),c=-1!==o.indexOf(\"z\"),u=-1!==o.indexOf(\"text\"),h=[];!s&&l?t.nameOverride=r.loc:(s&&(t.nameOverride=e.name),l&&h.push(r.loc));c&&h.push(t.zLabel);u&&a(r,e,h);t.extraText=h.join(\"<br>\")}(t,h,o,f.mockAxis),[t]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./attributes\":923}],928:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"choropleth\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"noOpacity\"],meta:{}}},{\"../../plots/geo\":797,\"../heatmap/colorbar\":1004,\"./attributes\":923,\"./calc\":924,\"./defaults\":925,\"./event_data\":926,\"./hover\":927,\"./plot\":929,\"./select\":930,\"./style\":931}],929:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../lib/polygon\"),o=t(\"../../lib/topojson_utils\").getTopojsonFeatures,s=t(\"../../lib/geo_location_utils\").locationToFeature,l=t(\"./style\").style;function c(t,e){for(var r=t[0].trace,n=t.length,i=o(r,e),a=0;a<n;a++){var l=t[a],c=s(r.locationmode,l.loc,i);c?(l.geojson=c,l.ct=c.properties.ct,l._polygons=u(c)):l.geojson=null}}function u(t){var e,r,n,i,o=t.geometry,s=o.coordinates,l=t.id,c=[];function u(t){for(var e=0;e<t.length-1;e++)if(t[e][0]>0&&t[e+1][0]<0)return e;return null}switch(e=\"RUS\"===l||\"FJI\"===l?function(t){var e;if(null===u(t))e=t;else for(e=new Array(t.length),i=0;i<t.length;i++)e[i]=[t[i][0]<0?t[i][0]+360:t[i][0],t[i][1]];c.push(a.tester(e))}:\"ATA\"===l?function(t){var e=u(t);if(null===e)return c.push(a.tester(t));var r=new Array(t.length+1),n=0;for(i=0;i<t.length;i++)i>e?r[n++]=[t[i][0]+360,t[i][1]]:i===e?(r[n++]=t[i],r[n++]=[t[i][0],-90]):r[n++]=t[i];var o=a.tester(r);o.pts.pop(),c.push(o)}:function(t){c.push(a.tester(t))},o.type){case\"MultiPolygon\":for(r=0;r<s.length;r++)for(n=0;n<s[r].length;n++)e(s[r][n]);break;case\"Polygon\":for(r=0;r<s.length;r++)e(s[r])}return c}e.exports={plot:function(t,e,r){for(var a=0;a<r.length;a++)c(r[a],e.topojson);var o=e.layers.backplot.select(\".choroplethlayer\");i.makeTraceGroups(o,r,\"trace choropleth\").each(function(e){var r=n.select(this).selectAll(\"path.choroplethlocation\").data(i.identity);r.enter().append(\"path\").classed(\"choroplethlocation\",!0),r.exit().remove(),l(t,e)})},feature2polygons:u}},{\"../../lib\":719,\"../../lib/geo_location_utils\":713,\"../../lib/polygon\":731,\"../../lib/topojson_utils\":746,\"./style\":931,d3:163}],930:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)(i=(n=s[r]).ct)&&(a=l.c2p(i),o=c.c2p(i),e.contains([a,o],null,r,t)?(u.push({pointNumber:r,lon:i[0],lat:i[1]}),n.selected=1):n.selected=0);return u}},{}],931:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../components/colorscale\");function s(t,e){var r=e[0].trace,s=e[0].node3.selectAll(\".choroplethlocation\"),l=r.marker||{},c=l.line||{},u=o.makeColorScaleFuncFromTrace(r);s.each(function(t){n.select(this).attr(\"fill\",u(t.z)).call(i.stroke,t.mlc||c.color).call(a.dashLine,\"\",t.mlw||c.width||0).style(\"opacity\",l.opacity)}),a.selectedPointStyle(s,r,t)}e.exports={style:function(t,e){e&&s(t,e)},styleOnSelect:function(t,e){var r=e[0].node3,n=e[0].trace;n.selectedpoints?a.selectedPointStyle(r.selectAll(\".choroplethlocation\"),n,t):s(t,e)}}},{\"../../components/color\":593,\"../../components/colorscale\":605,\"../../components/drawing\":614,d3:163}],932:[function(t,e,r){\"use strict\";var n=t(\"../choropleth/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../lib/extend\").extendFlat;e.exports=o({locations:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},geojson:{valType:\"any\",editType:\"calc\"},below:{valType:\"string\",editType:\"plot\"},text:n.text,hovertext:n.hovertext,marker:{line:{color:o({},n.marker.line.color,{editType:\"plot\"}),width:o({},n.marker.line.width,{editType:\"plot\"}),editType:\"calc\"},opacity:o({},n.marker.opacity,{editType:\"plot\"}),editType:\"calc\"},selected:{marker:{opacity:o({},n.selected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:o({},n.unselected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},hoverinfo:n.hoverinfo,hovertemplate:a({},{keys:[\"properties\"]})},i(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../choropleth/attributes\":923}],933:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"@turf/area\"),a=t(\"@turf/centroid\"),o=t(\"../../lib\"),s=t(\"../../components/colorscale\"),l=t(\"../../components/drawing\"),c=t(\"../../lib/geojson_utils\").makeBlank,u=t(\"../choropleth/plot\").feature2polygons;function h(t){var e,r=t[0].trace,n=r._opts;if(r.selectedpoints){for(var i=l.makeSelectedPointStyleFns(r),a=0;a<t.length;a++){var s=t[a];s.fOut&&(s.fOut.properties.mo2=i.selectedOpacityFn(s))}e={type:\"identity\",property:\"mo2\"}}else e=o.isArrayOrTypedArray(r.marker.opacity)?{type:\"identity\",property:\"mo\"}:r.marker.opacity;return o.extendFlat(n.fill.paint,{\"fill-opacity\":e}),o.extendFlat(n.line.paint,{\"line-opacity\":e}),n}e.exports={convert:function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,l={layout:{visibility:\"none\"},paint:{}},f={layout:{visibility:\"none\"},paint:{}},p=e._opts={fill:l,line:f,geojson:c()};if(!r)return p;var d=\"string\"==typeof e.geojson?(window.PlotlyGeoAssets||{})[e.geojson]:e.geojson;if(!o.isPlainObject(d))return o.error(\"Oops ... something when wrong when fetching \"+e.geojson),p;var g,v={},m=[];for(g=0;g<t.length;g++){var y=t[g];y.loc&&(v[y.loc]=y)}var x,b,_,w=s.makeColorScaleFuncFromTrace(e),k=e.marker,T=k.line||{};function A(t){var e=v[t.id];if(e){var r=t.geometry;if(\"Polygon\"===r.type||\"MultiPolygon\"===r.type){var n={fc:w(e.z)};x&&(n.mo=x(e)),b&&(n.mlc=b(e)),_&&(n.mlw=_(e));var s={type:\"Feature\",geometry:r,properties:n};e._polygons=u(s),e.ct=function(t){var e,r=t.geometry;if(\"MultiPolygon\"===r.type)for(var n=r.coordinates,o=0,s=0;s<n.length;s++){var l={type:\"Polygon\",coordinates:n[s]},c=i.default(l);c>o&&(o=c,e=l)}else e=r;return a.default(e).geometry.coordinates}(s),e.fIn=t,e.fOut=s,m.push(s)}else o.log([\"Location with id\",e.loc,\"does not have a valid GeoJSON geometry,\",\"choroplethmapbox traces only support *Polygon* and *MultiPolygon* geometries.\"].join(\" \"))}delete v[t.id]}switch(o.isArrayOrTypedArray(k.opacity)&&(x=function(t){var e=t.mo;return n(e)?+o.constrain(e,0,1):0}),o.isArrayOrTypedArray(T.color)&&(b=function(t){return t.mlc}),o.isArrayOrTypedArray(T.width)&&(_=function(t){return t.mlw}),d.type){case\"FeatureCollection\":var M=d.features;for(g=0;g<M.length;g++)A(M[g]);break;case\"Feature\":A(d);break;default:return o.warn([\"Invalid GeoJSON type\",(d.type||\"none\")+\",\",\"choroplethmapbox traces only support *FeatureCollection* and *Feature* types.\"].join(\" \")),p}for(var S in v)o.log(\"Location with id \"+S+\" does not have a matching feature\");var E=x?{type:\"identity\",property:\"mo\"}:k.opacity;return o.extendFlat(l.paint,{\"fill-color\":{type:\"identity\",property:\"fc\"},\"fill-opacity\":E}),o.extendFlat(f.paint,{\"line-color\":b?{type:\"identity\",property:\"mlc\"}:T.color,\"line-width\":_?{type:\"identity\",property:\"mlw\"}:T.width,\"line-opacity\":E}),l.layout.visibility=\"visible\",f.layout.visibility=\"visible\",p.geojson={type:\"FeatureCollection\",features:m},h(t),p},convertOnSelect:h}},{\"../../components/colorscale\":605,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/geojson_utils\":714,\"../choropleth/plot\":929,\"@turf/area\":55,\"@turf/centroid\":56,\"fast-isnumeric\":225}],934:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\"),u=s(\"geojson\");n.isArrayOrTypedArray(l)&&l.length&&n.isArrayOrTypedArray(c)&&c.length&&(\"string\"==typeof u&&\"\"!==u||n.isPlainObject(u))?(e._length=Math.min(l.length,c.length),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":932}],935:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../choropleth/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"../choropleth/hover\"),eventData:t(\"../choropleth/event_data\"),selectPoints:t(\"../choropleth/select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.updateOnSelect(e)},getBelow:function(t,e){for(var r=e.getMapLayers(),n=r.length-2;n>=0;n--){var i=r[n].id;if(\"string\"==typeof i&&0===i.indexOf(\"water\"))for(var a=n+1;a<r.length;a++)if(\"string\"==typeof(i=r[a].id)&&-1===i.indexOf(\"plotly-\"))return i}},moduleType:\"trace\",name:\"choroplethmapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"noOpacity\"],meta:{hr_name:\"choropleth_mapbox\"}}},{\"../../plots/mapbox\":822,\"../choropleth/calc\":924,\"../choropleth/event_data\":926,\"../choropleth/hover\":927,\"../choropleth/select\":930,\"../heatmap/colorbar\":1004,\"./attributes\":932,\"./defaults\":934,\"./plot\":936}],936:[function(t,e,r){\"use strict\";var n=t(\"./convert\").convert,i=t(\"./convert\").convertOnSelect,a=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function o(t,e){this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"fill\",a+e+\"-fill\"],[\"line\",a+e+\"-line\"]],this.below=null}var s=o.prototype;s.update=function(t){this._update(n(t))},s.updateOnSelect=function(t){this._update(i(t))},s._update=function(t){var e=this.subplot,r=this.layerList,n=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(t.geojson),n!==this.below&&(this._removeLayers(),this._addLayers(t,n),this.below=n);for(var i=0;i<r.length;i++){var a=r[i],o=a[0],s=a[1],l=t[o];e.setOptions(s,\"setLayoutProperty\",l.layout),\"visible\"===l.layout.visibility&&e.setOptions(s,\"setPaintProperty\",l.paint)}},s._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},s._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},s.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new o(t,r.uid),a=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(a,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":820,\"./convert\":933}],937:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"scaled\",\"absolute\"],editType:\"calc\",dflt:\"scaled\"},sizeref:{valType:\"number\",editType:\"calc\",min:0},anchor:{valType:\"enumerated\",editType:\"calc\",values:[\"tip\",\"tail\",\"cm\",\"center\"],dflt:\"cm\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:i({editType:\"calc\"},{keys:[\"norm\"]})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach(function(t){l[t]=a[t]}),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../mesh3d/attributes\":1053}],938:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){for(var r=e.u,i=e.v,a=e.w,o=Math.min(e.x.length,e.y.length,e.z.length,r.length,i.length,a.length),s=-1/0,l=1/0,c=0;c<o;c++){var u=r[c],h=i[c],f=a[c],p=Math.sqrt(u*u+h*h+f*f);s=Math.max(s,p),l=Math.min(l,p)}e._len=o,e._normMax=s,n(t,e,{vals:[l,s],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],939:[function(t,e,r){\"use strict\";var n=t(\"gl-cone3d\"),i=t(\"gl-cone3d\").createConeMesh,a=t(\"../../lib\").simpleMap,o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\");function c(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var u=c.prototype;u.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index,r=this.data.x[e],n=this.data.y[e],i=this.data.z[e],a=this.data.u[e],o=this.data.v[e],s=this.data.w[e];t.traceCoordinate=[r,n,i,a,o,s,Math.sqrt(a*a+o*o+s*s)];var l=this.data.hovertext||this.data.text;return Array.isArray(l)&&void 0!==l[e]?t.textLabel=l[e]:l&&(t.textLabel=l),!0}};var h={xaxis:0,yaxis:1,zaxis:2},f={tip:1,tail:0,cm:.25,center:.5},p={tip:1,tail:1,cm:.75,center:.5};function d(t,e){var r=t.fullSceneLayout,i=t.dataScale,c={};function u(t,e){var n=r[e],o=i[h[e]];return a(t,function(t){return n.d2l(t)*o})}c.vectors=l(u(e.u,\"xaxis\"),u(e.v,\"yaxis\"),u(e.w,\"zaxis\"),e._len),c.positions=l(u(e.x,\"xaxis\"),u(e.y,\"yaxis\"),u(e.z,\"zaxis\"),e._len);var d=s(e);c.colormap=o(e),c.vertexIntensityBounds=[d.min/e._normMax,d.max/e._normMax],c.coneOffset=f[e.anchor],\"scaled\"===e.sizemode?c.coneSize=e.sizeref||.5:c.coneSize=e.sizeref&&e._normMax?e.sizeref/e._normMax:.5;var g=n(c),v=e.lightposition;return g.lightPosition=[v.x,v.y,v.z],g.ambient=e.lighting.ambient,g.diffuse=e.lighting.diffuse,g.specular=e.lighting.specular,g.roughness=e.lighting.roughness,g.fresnel=e.lighting.fresnel,g.opacity=e.opacity,e._pad=p[e.anchor]*g.vectorScale*g.coneScale*e._normMax,g}u.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),a=i(r,n),o=new c(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../plots/gl3d/zip3\":818,\"gl-cone3d\":242}],940:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),h=s(\"x\"),f=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length&&p&&p.length?(s(\"sizeref\"),s(\"sizemode\"),s(\"anchor\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":937}],941:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"cone\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),eventData:function(t,e){return t.norm=e.traceCoordinate[6],t},meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":937,\"./calc\":938,\"./convert\":939,\"./defaults\":940}],942:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../components/drawing/attributes\").dash,s=t(\"../../plots/font_attributes\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../constants/filter_ops\"),u=c.COMPARISON_OPS2,h=c.INTERVAL_OPS,f=(t(\"../../constants/docs\").FORMAT_LINK,i.line);e.exports=l({z:n.z,x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,xtype:n.xtype,ytype:n.ytype,zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate,connectgaps:n.connectgaps,fillcolor:{valType:\"color\",editType:\"calc\"},autocontour:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"contours.start\":void 0,\"contours.end\":void 0,\"contours.size\":void 0}},ncontours:{valType:\"integer\",dflt:15,min:1,editType:\"calc\"},contours:{type:{valType:\"enumerated\",values:[\"levels\",\"constraint\"],dflt:\"levels\",editType:\"calc\"},start:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},end:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},coloring:{valType:\"enumerated\",values:[\"fill\",\"heatmap\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:{valType:\"boolean\",dflt:!0,editType:\"plot\"},showlabels:{valType:\"boolean\",dflt:!1,editType:\"plot\"},labelfont:s({editType:\"plot\",colorEditType:\"style\"}),labelformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},operation:{valType:\"enumerated\",values:[].concat(u).concat(h),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:l({},f.color,{editType:\"style+colorbars\"}),width:l({},f.width,{editType:\"style+colorbars\"}),dash:o,smoothing:l({},f.smoothing,{}),editType:\"plot\"}},a(\"\",{cLetter:\"z\",autoColorDflt:!1,editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../components/drawing/attributes\":613,\"../../constants/docs\":690,\"../../constants/filter_ops\":691,\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"../heatmap/attributes\":1001,\"../scatter/attributes\":1112}],943:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\"),i=t(\"../heatmap/calc\"),a=t(\"./set_contours\"),o=t(\"./end_plus\");e.exports=function(t,e){var r=i(t,e),s=r[0].z;a(e,s);var l,c=e.contours,u=n.extractOpts(e);if(\"heatmap\"===c.coloring&&u.auto&&!1===e.autocontour){var h=c.start,f=o(c),p=c.size||1,d=Math.floor((f-h)/p)+1;isFinite(p)||(p=1,d=1);var g=h-p/2;l=[g,g+d*p]}else l=s;return n.calc(t,e,{vals:l,cLetter:\"z\"}),r}},{\"../../components/colorscale\":605,\"../heatmap/calc\":1002,\"./end_plus\":953,\"./set_contours\":961}],944:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a,o,s=t[0],l=s.x.length,c=s.y.length,u=s.z,h=n.contours,f=-1/0,p=1/0;for(i=0;i<c;i++)p=Math.min(p,u[i][0]),p=Math.min(p,u[i][l-1]),f=Math.max(f,u[i][0]),f=Math.max(f,u[i][l-1]);for(i=1;i<l-1;i++)p=Math.min(p,u[0][i]),p=Math.min(p,u[c-1][i]),f=Math.max(f,u[0][i]),f=Math.max(f,u[c-1][i]);switch(s.prefixBoundary=!1,e){case\">\":h.value>f&&(s.prefixBoundary=!0);break;case\"<\":h.value<p&&(s.prefixBoundary=!0);break;case\"[]\":a=Math.min.apply(null,h.value),((o=Math.max.apply(null,h.value))<p||a>f)&&(s.prefixBoundary=!0);break;case\"][\":a=Math.min.apply(null,h.value),o=Math.max.apply(null,h.value),a<p&&o>f&&(s.prefixBoundary=!0)}}},{}],945:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\").extractOpts,i=t(\"./make_color_map\"),a=t(\"./end_plus\");e.exports={min:\"zmin\",max:\"zmax\",calc:function(t,e,r){var o=e.contours,s=e.line,l=o.size||1,c=o.coloring,u=i(e,{isColorbar:!0});if(\"heatmap\"===c){var h=n(e);r._fillgradient=e.colorscale,r._zrange=[h.min,h.max]}else\"fill\"===c&&(r._fillcolor=u);r._line={color:\"lines\"===c?u:s.color,width:!1!==o.showlines?s.width:0,dash:s.dash},r._levels={start:o.start,end:a(o),size:l}}}},{\"../../components/colorscale\":605,\"./end_plus\":953,\"./make_color_map\":958}],946:[function(t,e,r){\"use strict\";e.exports={BOTTOMSTART:[1,9,13,104,713],TOPSTART:[4,6,7,104,713],LEFTSTART:[8,12,14,208,1114],RIGHTSTART:[2,3,11,208,1114],NEWDELTA:[null,[-1,0],[0,-1],[-1,0],[1,0],null,[0,-1],[-1,0],[0,1],[0,1],null,[0,1],[1,0],[1,0],[0,-1]],CHOOSESADDLE:{104:[4,1],208:[2,8],713:[7,13],1114:[11,14]},SADDLEREMAINDER:{1:4,2:8,4:1,7:13,8:2,11:14,13:7,14:11},LABELDISTANCE:2,LABELINCREASE:10,LABELMIN:3,LABELMAX:10,LABELOPTIMIZER:{EDGECOST:1,ANGLECOST:1,NEIGHBORCOST:5,SAMELEVELFACTOR:10,SAMELEVELDISTANCE:5,MAXCOST:100,INITIALSEARCHPOINTS:10,ITERATIONS:5}}},{}],947:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./label_defaults\"),a=t(\"../../components/color\"),o=a.addOpacity,s=a.opacity,l=t(\"../../constants/filter_ops\"),c=l.CONSTRAINT_REDUCTION,u=l.COMPARISON_OPS2;e.exports=function(t,e,r,a,l,h){var f,p,d,g=e.contours,v=r(\"contours.operation\");(g._operation=c[v],function(t,e){var r;-1===u.indexOf(e.operation)?(t(\"contours.value\",[0,1]),Array.isArray(e.value)?e.value.length>2?e.value=e.value.slice(2):0===e.length?e.value=[0,1]:e.length<2?(r=parseFloat(e.value[0]),e.value=[r,r+1]):e.value=[parseFloat(e.value[0]),parseFloat(e.value[1])]:n(e.value)&&(r=parseFloat(e.value),e.value=[r,r+1])):(t(\"contours.value\",0),n(e.value)||(Array.isArray(e.value)?e.value=parseFloat(e.value[0]):e.value=0))}(r,g),\"=\"===v?f=g.showlines=!0:(f=r(\"contours.showlines\"),d=r(\"fillcolor\",o((t.line||{}).color||l,.5))),f)&&(p=r(\"line.color\",d&&s(d)?o(e.fillcolor,1):l),r(\"line.width\",2),r(\"line.dash\"));r(\"line.smoothing\"),i(r,a,p,h)}},{\"../../components/color\":593,\"../../constants/filter_ops\":691,\"./label_defaults\":957,\"fast-isnumeric\":225}],948:[function(t,e,r){\"use strict\";var n=t(\"../../constants/filter_ops\"),i=t(\"fast-isnumeric\");function a(t,e){var r,a=Array.isArray(e);function o(t){return i(t)?+t:null}return-1!==n.COMPARISON_OPS2.indexOf(t)?r=o(a?e[0]:e):-1!==n.INTERVAL_OPS.indexOf(t)?r=a?[o(e[0]),o(e[1])]:[o(e),o(e)]:-1!==n.SET_OPS.indexOf(t)&&(r=a?e.map(o):[o(e)]),r}function o(t){return function(e){e=a(t,e);var r=Math.min(e[0],e[1]),n=Math.max(e[0],e[1]);return{start:r,end:n,size:n-r}}}function s(t){return function(e){return{start:e=a(t,e),end:1/0,size:1/0}}}e.exports={\"[]\":o(\"[]\"),\"][\":o(\"][\"),\">\":s(\">\"),\"<\":s(\"<\"),\"=\":s(\"=\")}},{\"../../constants/filter_ops\":691,\"fast-isnumeric\":225}],949:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=n(\"contours.start\"),a=n(\"contours.end\"),o=!1===i||!1===a,s=r(\"contours.size\");!(o?e.autocontour=!0:r(\"autocontour\",!1))&&s||r(\"ncontours\")}},{}],950:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");function i(t){return n.extendFlat({},t,{edgepaths:n.extendDeep([],t.edgepaths),paths:n.extendDeep([],t.paths)})}e.exports=function(t,e){var r,a,o,s=function(t){return t.reverse()},l=function(t){return t};switch(e){case\"=\":case\"<\":return t;case\">\":for(1!==t.length&&n.warn(\"Contour data invalid for the specified inequality operation.\"),a=t[0],r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);return t;case\"][\":var c=s;s=l,l=c;case\"[]\":for(2!==t.length&&n.warn(\"Contour data invalid for the specified inequality range operation.\"),a=i(t[0]),o=i(t[1]),r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);for(;o.edgepaths.length;)a.edgepaths.push(l(o.edgepaths.shift()));for(;o.paths.length;)a.paths.push(l(o.paths.shift()));return[a]}}},{\"../../lib\":719}],951:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"./constraint_defaults\"),o=t(\"./contours_defaults\"),s=t(\"./style_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,l,r,i)}if(i(t,e,u,c)){u(\"text\"),u(\"hovertext\"),u(\"hovertemplate\");var h=\"constraint\"===u(\"contours.type\");u(\"connectgaps\",n.isArray1D(e.z)),h?a(t,e,u,c,r):(o(t,e,u,function(r){return n.coerce2(t,e,l,r)}),s(t,e,u,c))}else e.visible=!1}},{\"../../lib\":719,\"../heatmap/xyz_defaults\":1015,\"./attributes\":942,\"./constraint_defaults\":947,\"./contours_defaults\":949,\"./style_defaults\":963}],952:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constraint_mapping\"),a=t(\"./end_plus\");e.exports=function(t,e,r){for(var o=\"constraint\"===t.type?i[t._operation](t.value):t,s=o.size,l=[],c=a(o),u=r.trace._carpetTrace,h=u?{xaxis:u.aaxis,yaxis:u.baxis,x:r.a,y:r.b}:{xaxis:e.xaxis,yaxis:e.yaxis,x:r.x,y:r.y},f=o.start;f<c;f+=s)if(l.push(n.extendFlat({level:f,crossings:{},starts:[],edgepaths:[],paths:[],z:r.z,smoothing:r.trace.line.smoothing},h)),l.length>1e3){n.warn(\"Too many contours, clipping at 1000\",t);break}return l}},{\"../../lib\":719,\"./constraint_mapping\":948,\"./end_plus\":953}],953:[function(t,e,r){\"use strict\";e.exports=function(t){return t.end+t.size/1e6}},{}],954:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constants\");function a(t,e,r,n){return Math.abs(t[0]-e[0])<r&&Math.abs(t[1]-e[1])<n}function o(t,e,r,o,l){var c,u=e.join(\",\"),h=u,f=t.crossings[h],p=function(t,e,r){var n=0,a=0;t>20&&e?208===t||1114===t?n=0===r[0]?1:-1:a=0===r[1]?1:-1:-1!==i.BOTTOMSTART.indexOf(t)?a=1:-1!==i.LEFTSTART.indexOf(t)?n=1:-1!==i.TOPSTART.indexOf(t)?a=-1:n=-1;return[n,a]}(f,r,e),d=[s(t,e,[-p[0],-p[1]])],g=p.join(\",\"),v=t.z.length,m=t.z[0].length;for(c=0;c<1e4;c++){if(f>20?(f=i.CHOOSESADDLE[f][(p[0]||p[1])<0?0:1],t.crossings[h]=i.SADDLEREMAINDER[f]):delete t.crossings[h],!(p=i.NEWDELTA[f])){n.log(\"Found bad marching index:\",f,e,t.level);break}d.push(s(t,e,p)),e[0]+=p[0],e[1]+=p[1],a(d[d.length-1],d[d.length-2],o,l)&&d.pop(),h=e.join(\",\");var y=p[0]&&(e[0]<0||e[0]>m-2)||p[1]&&(e[1]<0||e[1]>v-2);if(h===u&&p.join(\",\")===g||r&&y)break;f=t.crossings[h]}1e4===c&&n.log(\"Infinite loop in contour?\");var x,b,_,w,k,T,A,M,S,E,C,L,P,O,z,I=a(d[0],d[d.length-1],o,l),D=0,R=.2*t.smoothing,F=[],B=0;for(c=1;c<d.length;c++)L=d[c],P=d[c-1],void 0,void 0,O=L[2]-P[2],z=L[3]-P[3],D+=A=Math.sqrt(O*O+z*z),F.push(A);var N=D/F.length*R;function j(t){return d[t%d.length]}for(c=d.length-2;c>=B;c--)if((x=F[c])<N){for(_=0,b=c-1;b>=B&&x+F[b]<N;b--)x+=F[b];if(I&&c===d.length-2)for(_=0;_<b&&x+F[_]<N;_++)x+=F[_];k=c-b+_+1,T=Math.floor((c+b+_+2)/2),w=I||c!==d.length-2?I||-1!==b?k%2?j(T):[(j(T)[0]+j(T+1)[0])/2,(j(T)[1]+j(T+1)[1])/2]:d[0]:d[d.length-1],d.splice(b+1,c-b+1,w),c=b+1,_&&(B=_),I&&(c===d.length-2?d[_]=d[d.length-1]:0===c&&(d[d.length-1]=d[0]))}for(d.splice(0,B),c=0;c<d.length;c++)d[c].length=2;if(!(d.length<2))if(I)d.pop(),t.paths.push(d);else{r||n.log(\"Unclosed interior contour?\",t.level,u,d.join(\"L\"));var U=!1;for(M=0;M<t.edgepaths.length;M++)if(E=t.edgepaths[M],!U&&a(E[0],d[d.length-1],o,l)){d.pop(),U=!0;var V=!1;for(S=0;S<t.edgepaths.length;S++)if(a((C=t.edgepaths[S])[C.length-1],d[0],o,l)){V=!0,d.shift(),t.edgepaths.splice(M,1),S===M?t.paths.push(d.concat(C)):(S>M&&S--,t.edgepaths[S]=C.concat(d,E));break}V||(t.edgepaths[M]=d.concat(E))}for(M=0;M<t.edgepaths.length&&!U;M++)a((E=t.edgepaths[M])[E.length-1],d[0],o,l)&&(d.shift(),t.edgepaths[M]=E.concat(d),U=!0);U||t.edgepaths.push(d)}}function s(t,e,r){var n=e[0]+Math.max(r[0],0),i=e[1]+Math.max(r[1],0),a=t.z[i][n],o=t.xaxis,s=t.yaxis;if(r[1]){var l=(t.level-a)/(t.z[i][n+1]-a);return[o.c2p((1-l)*t.x[n]+l*t.x[n+1],!0),s.c2p(t.y[i],!0),n+l,i]}var c=(t.level-a)/(t.z[i+1][n]-a);return[o.c2p(t.x[n],!0),s.c2p((1-c)*t.y[i]+c*t.y[i+1],!0),n,i+c]}e.exports=function(t,e,r){var i,a,s,l;for(e=e||.01,r=r||.01,a=0;a<t.length;a++){for(s=t[a],l=0;l<s.starts.length;l++)o(s,s.starts[l],\"edge\",e,r);for(i=0;Object.keys(s.crossings).length&&i<1e4;)i++,o(s,Object.keys(s.crossings)[0].split(\",\").map(Number),void 0,e,r);1e4===i&&n.log(\"Infinite loop in contour?\")}}},{\"../../lib\":719,\"./constants\":946}],955:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../heatmap/hover\");e.exports=function(t,e,r,a,o){var s=i(t,e,r,a,o,!0);return s&&s.forEach(function(t){var e=t.trace;\"constraint\"===e.contours.type&&(e.fillcolor&&n.opacity(e.fillcolor)?t.color=n.addOpacity(e.fillcolor,1):e.contours.showlines&&n.opacity(e.line.color)&&(t.color=n.addOpacity(e.line.color,1)))}),s}},{\"../../components/color\":593,\"../heatmap/hover\":1008}],956:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\").plot,style:t(\"./style\"),colorbar:t(\"./colorbar\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"contour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":942,\"./calc\":943,\"./colorbar\":945,\"./defaults\":951,\"./hover\":955,\"./plot\":960,\"./style\":962}],957:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i){if(i||(i={}),t(\"contours.showlabels\")){var a=e.font;n.coerceFont(t,\"contours.labelfont\",{family:a.family,size:a.size,color:r}),t(\"contours.labelformat\")}!1!==i.hasHover&&t(\"zhoverformat\")}},{\"../../lib\":719}],958:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/colorscale\"),a=t(\"./end_plus\");e.exports=function(t){var e=t.contours,r=e.start,o=a(e),s=e.size||1,l=Math.floor((o-r)/s)+1,c=\"lines\"===e.coloring?0:1,u=i.extractOpts(t);isFinite(s)||(s=1,l=1);var h,f,p=u.reversescale?i.flipScale(u.colorscale):u.colorscale,d=p.length,g=new Array(d),v=new Array(d);if(\"heatmap\"===e.coloring){var m=u.min,y=u.max;for(f=0;f<d;f++)h=p[f],g[f]=h[0]*(y-m)+m,v[f]=h[1];var x=n.extent([m,y,e.start,e.start+s*(l-1)]),b=x[m<y?0:1],_=x[m<y?1:0];b!==m&&(g.splice(0,0,b),v.splice(0,0,v[0])),_!==y&&(g.push(_),v.push(v[v.length-1]))}else for(f=0;f<d;f++)h=p[f],g[f]=(h[0]*(l+c-1)-c/2)*s+r,v[f]=h[1];return i.makeColorScaleFunc({domain:g,range:v},{noNumericCheck:!0})}},{\"../../components/colorscale\":605,\"./end_plus\":953,d3:163}],959:[function(t,e,r){\"use strict\";var n=t(\"./constants\");function i(t,e){var r=(e[0][0]>t?0:1)+(e[0][1]>t?0:2)+(e[1][1]>t?0:4)+(e[1][0]>t?0:8);return 5===r||10===r?t>(e[0][0]+e[0][1]+e[1][0]+e[1][1])/4?5===r?713:1114:5===r?104:208:15===r?0:r}e.exports=function(t){var e,r,a,o,s,l,c,u,h,f=t[0].z,p=f.length,d=f[0].length,g=2===p||2===d;for(r=0;r<p-1;r++)for(o=[],0===r&&(o=o.concat(n.BOTTOMSTART)),r===p-2&&(o=o.concat(n.TOPSTART)),e=0;e<d-1;e++)for(a=o.slice(),0===e&&(a=a.concat(n.LEFTSTART)),e===d-2&&(a=a.concat(n.RIGHTSTART)),s=e+\",\"+r,l=[[f[r][e],f[r][e+1]],[f[r+1][e],f[r+1][e+1]]],h=0;h<t.length;h++)(c=i((u=t[h]).level,l))&&(u.crossings[s]=c,-1!==a.indexOf(c)&&(u.starts.push([e,r]),g&&-1!==a.indexOf(c,a.indexOf(c)+1)&&u.starts.push([e,r])))}},{\"./constants\":946}],960:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../../plots/cartesian/set_convert\"),c=t(\"../heatmap/plot\"),u=t(\"./make_crossings\"),h=t(\"./find_all_paths\"),f=t(\"./empty_pathinfo\"),p=t(\"./convert_to_constraints\"),d=t(\"./close_boundaries\"),g=t(\"./constants\"),v=g.LABELOPTIMIZER;function m(t,e){var r,n,o,s,l,c,u,h=function(t,e){var r=t.prefixBoundary;if(void 0===r){var n=Math.min(t.z[0][0],t.z[0][1]);r=!t.edgepaths.length&&n>t.level}return r?\"M\"+e.join(\"L\")+\"Z\":\"\"}(t,e),f=0,p=t.edgepaths.map(function(t,e){return e}),d=!0;function g(t){return Math.abs(t[1]-e[2][1])<.01}function v(t){return Math.abs(t[0]-e[0][0])<.01}function m(t){return Math.abs(t[0]-e[2][0])<.01}for(;p.length;){for(c=a.smoothopen(t.edgepaths[f],t.smoothing),h+=d?c:c.replace(/^M/,\"L\"),p.splice(p.indexOf(f),1),r=t.edgepaths[f][t.edgepaths[f].length-1],s=-1,o=0;o<4;o++){if(!r){i.log(\"Missing end?\",f,t);break}for(u=r,Math.abs(u[1]-e[0][1])<.01&&!m(r)?n=e[1]:v(r)?n=e[0]:g(r)?n=e[3]:m(r)&&(n=e[2]),l=0;l<t.edgepaths.length;l++){var y=t.edgepaths[l][0];Math.abs(r[0]-n[0])<.01?Math.abs(r[0]-y[0])<.01&&(y[1]-r[1])*(n[1]-y[1])>=0&&(n=y,s=l):Math.abs(r[1]-n[1])<.01?Math.abs(r[1]-y[1])<.01&&(y[0]-r[0])*(n[0]-y[0])>=0&&(n=y,s=l):i.log(\"endpt to newendpt is not vert. or horz.\",r,n,y)}if(r=n,s>=0)break;h+=\"L\"+n}if(s===t.edgepaths.length){i.log(\"unclosed perimeter path\");break}f=s,(d=-1===p.indexOf(f))&&(f=p[0],h+=\"Z\")}for(f=0;f<t.paths.length;f++)h+=a.smoothclosed(t.paths[f],t.smoothing);return h}function y(t,e,r,n){var a=e.width/2,o=e.height/2,s=t.x,l=t.y,c=t.theta,u=Math.cos(c)*a,h=Math.sin(c)*a,f=(s>n.center?n.right-s:s-n.left)/(u+Math.abs(Math.sin(c)*o)),p=(l>n.middle?n.bottom-l:l-n.top)/(Math.abs(h)+Math.cos(c)*o);if(f<1||p<1)return 1/0;var d=v.EDGECOST*(1/(f-1)+1/(p-1));d+=v.ANGLECOST*c*c;for(var g=s-u,m=l-h,y=s+u,x=l+h,b=0;b<r.length;b++){var _=r[b],w=Math.cos(_.theta)*_.width/2,k=Math.sin(_.theta)*_.width/2,T=2*i.segmentDistance(g,m,y,x,_.x-w,_.y-k,_.x+w,_.y+k)/(e.height+_.height),A=_.level===e.level,M=A?v.SAMELEVELDISTANCE:1;if(T<=M)return 1/0;d+=v.NEIGHBORCOST*(A?v.SAMELEVELFACTOR:1)/(T-M)}return d}r.plot=function(t,e,o,s){var l=e.xaxis,v=e.yaxis;i.makeTraceGroups(s,o,\"contour\").each(function(o){var s=n.select(this),y=o[0],x=y.trace,b=y.x,_=y.y,w=x.contours,k=f(w,e,y),T=i.ensureSingle(s,\"g\",\"heatmapcoloring\"),A=[];\"heatmap\"===w.coloring&&(A=[o]),c(t,e,A,T),u(k),h(k);var M=l.c2p(b[0],!0),S=l.c2p(b[b.length-1],!0),E=v.c2p(_[0],!0),C=v.c2p(_[_.length-1],!0),L=[[M,C],[S,C],[S,E],[M,E]],P=k;\"constraint\"===w.type&&(P=p(k,w._operation),d(P,w._operation,L,x)),function(t,e,r){var n=i.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"===r.coloring?[0]:[]);n.enter().append(\"path\"),n.exit().remove(),n.attr(\"d\",\"M\"+e.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(s,L,w),function(t,e,r,a){var o=i.ensureSingle(t,\"g\",\"contourfill\").selectAll(\"path\").data(\"fill\"===a.coloring||\"constraint\"===a.type&&\"=\"!==a._operation?e:[]);o.enter().append(\"path\"),o.exit().remove(),o.each(function(t){var e=m(t,r);e?n.select(this).attr(\"d\",e).style(\"stroke\",\"none\"):n.select(this).remove()})}(s,P,L,w),function(t,e,o,s,l){var c=i.ensureSingle(t,\"g\",\"contourlines\"),u=!1!==l.showlines,h=l.showlabels,f=u&&h,p=r.createLines(c,u||h,e),d=r.createLineClip(c,f,o,s.trace.uid),v=t.selectAll(\"g.contourlabels\").data(h?[0]:[]);if(v.exit().remove(),v.enter().append(\"g\").classed(\"contourlabels\",!0),h){var m=[],y=[];i.clearLocationCache();var x=r.labelFormatter(l,s.t.cb,o._fullLayout),b=a.tester.append(\"text\").attr(\"data-notex\",1).call(a.font,l.labelfont),_=e[0].xaxis,w=e[0].yaxis,k=_._length,T=w._length,A=_.range,M=w.range,S=i.aggNums(Math.min,null,s.x),E=i.aggNums(Math.max,null,s.x),C=i.aggNums(Math.min,null,s.y),L=i.aggNums(Math.max,null,s.y),P=Math.max(_.c2p(S,!0),0),O=Math.min(_.c2p(E,!0),k),z=Math.max(w.c2p(L,!0),0),I=Math.min(w.c2p(C,!0),T),D={};A[0]<A[1]?(D.left=P,D.right=O):(D.left=O,D.right=P),M[0]<M[1]?(D.top=z,D.bottom=I):(D.top=I,D.bottom=z),D.middle=(D.top+D.bottom)/2,D.center=(D.left+D.right)/2,m.push([[D.left,D.top],[D.right,D.top],[D.right,D.bottom],[D.left,D.bottom]]);var R=Math.sqrt(k*k+T*T),F=g.LABELDISTANCE*R/Math.max(1,e.length/g.LABELINCREASE);p.each(function(t){var e=r.calcTextOpts(t.level,x,b,o);n.select(this).selectAll(\"path\").each(function(){var t=i.getVisibleSegment(this,D,e.height/2);if(t&&!(t.len<(e.width+e.height)*g.LABELMIN))for(var n=Math.min(Math.ceil(t.len/F),g.LABELMAX),a=0;a<n;a++){var o=r.findBestTextLocation(this,t,e,y,D);if(!o)break;r.addLabelData(o,e,y,m)}})}),b.remove(),r.drawLabels(v,y,o,d,f?m:null)}h&&!u&&p.remove()}(s,k,t,y,w),function(t,e,r,n,o){var s=r._fullLayout._clips,l=\"clip\"+n.trace.uid,c=s.selectAll(\"#\"+l).data(n.trace.connectgaps?[]:[0]);if(c.enter().append(\"clipPath\").classed(\"contourclip\",!0).attr(\"id\",l),c.exit().remove(),!1===n.trace.connectgaps){var f={level:.9,crossings:{},starts:[],edgepaths:[],paths:[],xaxis:e.xaxis,yaxis:e.yaxis,x:n.x,y:n.y,z:function(t){var e,r,n=t.trace._emptypoints,i=[],a=t.z.length,o=t.z[0].length,s=[];for(e=0;e<o;e++)s.push(1);for(e=0;e<a;e++)i.push(s.slice());for(e=0;e<n.length;e++)r=n[e],i[r[0]][r[1]]=0;return t.zmask=i,i}(n),smoothing:0};u([f]),h([f]);var p=m(f,o),d=i.ensureSingle(c,\"path\",\"\");d.attr(\"d\",p)}else l=null;a.setClipUrl(t,l,r)}(s,e,t,y,L)})},r.createLines=function(t,e,r){var n=r[0].smoothing,i=t.selectAll(\"g.contourlevel\").data(e?r:[]);if(i.exit().remove(),i.enter().append(\"g\").classed(\"contourlevel\",!0),e){var o=i.selectAll(\"path.openline\").data(function(t){return t.pedgepaths||t.edgepaths});o.exit().remove(),o.enter().append(\"path\").classed(\"openline\",!0),o.attr(\"d\",function(t){return a.smoothopen(t,n)}).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\");var s=i.selectAll(\"path.closedline\").data(function(t){return t.ppaths||t.paths});s.exit().remove(),s.enter().append(\"path\").classed(\"closedline\",!0),s.attr(\"d\",function(t){return a.smoothclosed(t,n)}).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\")}return i},r.createLineClip=function(t,e,r,n){var i=e?\"clipline\"+n:null,o=r._fullLayout._clips.selectAll(\"#\"+i).data(e?[0]:[]);return o.exit().remove(),o.enter().append(\"clipPath\").classed(\"contourlineclip\",!0).attr(\"id\",i),a.setClipUrl(t,i,r),o},r.labelFormatter=function(t,e,r){if(t.labelformat)return r._d3locale.numberFormat(t.labelformat);var n;if(e)n=e.axis;else{if(n={type:\"linear\",_id:\"ycontour\",showexponent:\"all\",exponentformat:\"B\"},\"constraint\"===t.type){var i=t.value;Array.isArray(i)?n.range=[i[0],i[i.length-1]]:n.range=[i,i]}else n.range=[t.start,t.end],n.nticks=(t.end-t.start)/t.size;n.range[0]===n.range[1]&&(n.range[1]+=n.range[0]||1),n.nticks||(n.nticks=1e3),l(n,r),s.prepTicks(n),n._tmin=null,n._tmax=null}return function(t){return s.tickText(n,t).text}},r.calcTextOpts=function(t,e,r,n){var i=e(t);r.text(i).call(o.convertToTspans,n);var s=a.bBox(r.node(),!0);return{text:i,width:s.width,height:s.height,level:t,dy:(s.top+s.bottom)/2}},r.findBestTextLocation=function(t,e,r,n,a){var o,s,l,c,u,h=r.width;e.isClosed?(s=e.len/v.INITIALSEARCHPOINTS,o=e.min+s/2,l=e.max):(s=(e.len-h)/(v.INITIALSEARCHPOINTS+1),o=e.min+s+h/2,l=e.max-(s+h)/2);for(var f=1/0,p=0;p<v.ITERATIONS;p++){for(var d=o;d<l;d+=s){var g=i.getTextLocation(t,e.total,d,h),m=y(g,r,n,a);m<f&&(f=m,u=g,c=d)}if(f>2*v.MAXCOST)break;p&&(s/=2),l=(o=c-s/2)+1.5*s}if(f<=v.MAXCOST)return u},r.addLabelData=function(t,e,r,n){var i=e.width/2,a=e.height/2,o=t.x,s=t.y,l=t.theta,c=Math.sin(l),u=Math.cos(l),h=i*u,f=a*c,p=i*c,d=-a*u,g=[[o-h-f,s-p-d],[o+h-f,s+p-d],[o+h+f,s+p+d],[o-h+f,s-p+d]];r.push({text:e.text,x:o,y:s,dy:e.dy,theta:l,level:e.level,width:e.width,height:e.height}),n.push(g)},r.drawLabels=function(t,e,r,a,s){var l=t.selectAll(\"text\").data(e,function(t){return t.text+\",\"+t.x+\",\"+t.y+\",\"+t.theta});if(l.exit().remove(),l.enter().append(\"text\").attr({\"data-notex\":1,\"text-anchor\":\"middle\"}).each(function(t){var e=t.x+Math.sin(t.theta)*t.dy,i=t.y-Math.cos(t.theta)*t.dy;n.select(this).text(t.text).attr({x:e,y:i,transform:\"rotate(\"+180*t.theta/Math.PI+\" \"+e+\" \"+i+\")\"}).call(o.convertToTspans,r)}),s){for(var c=\"\",u=0;u<s.length;u++)c+=\"M\"+s[u].join(\"L\")+\"Z\";i.ensureSingle(a,\"path\",\"\").attr(\"d\",c)}}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/set_convert\":785,\"../heatmap/plot\":1012,\"./close_boundaries\":944,\"./constants\":946,\"./convert_to_constraints\":950,\"./empty_pathinfo\":952,\"./find_all_paths\":954,\"./make_crossings\":959,d3:163}],961:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\");function a(t,e,r){var i={type:\"linear\",range:[t,e]};return n.autoTicks(i,(e-t)/(r||15)),i}e.exports=function(t,e){var r=t.contours;if(t.autocontour){var o=t.zmin,s=t.zmax;(t.zauto||void 0===o)&&(o=i.aggNums(Math.min,null,e)),(t.zauto||void 0===s)&&(s=i.aggNums(Math.max,null,e));var l=a(o,s,t.ncontours);r.size=l.dtick,r.start=n.tickFirst(l),l.range.reverse(),r.end=n.tickFirst(l),r.start===o&&(r.start+=r.size),r.end===s&&(r.end-=r.size),r.start>r.end&&(r.start=r.end=(r.start+r.end)/2),t._input.contours||(t._input.contours={}),i.extendFlat(t._input.contours,{start:r.start,end:r.end,size:r.size}),t._input.autocontour=!0}else if(\"constraint\"!==r.type){var c,u=r.start,h=r.end,f=t._input.contours;if(u>h&&(r.start=f.start=h,h=r.end=f.end=u,u=r.start),!(r.size>0))c=u===h?1:a(u,h,t.ncontours).dtick,f.size=r.size=c}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767}],962:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../heatmap/style\"),o=t(\"./make_color_map\");e.exports=function(t){var e=n.select(t).selectAll(\"g.contour\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.each(function(t){var e=n.select(this),r=t[0].trace,a=r.contours,s=r.line,l=a.size||1,c=a.start,u=\"constraint\"===a.type,h=!u&&\"lines\"===a.coloring,f=!u&&\"fill\"===a.coloring,p=h||f?o(r):null;e.selectAll(\"g.contourlevel\").each(function(t){n.select(this).selectAll(\"path\").call(i.lineGroupStyle,s.width,h?p(t.level):s.color,s.dash)});var d=a.labelfont;if(e.selectAll(\"g.contourlabels text\").each(function(t){i.font(n.select(this),{family:d.family,size:d.size,color:d.color||(h?p(t.level):s.color)})}),u)e.selectAll(\"g.contourfill path\").style(\"fill\",r.fillcolor);else if(f){var g;e.selectAll(\"g.contourfill path\").style(\"fill\",function(t){return void 0===g&&(g=t.level),p(t.level+.5*l)}),void 0===g&&(g=c),e.selectAll(\"g.contourbg path\").style(\"fill\",p(g-.5*l))}}),a(t)}},{\"../../components/drawing\":614,\"../heatmap/style\":1013,\"./make_color_map\":958,d3:163}],963:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/defaults\"),i=t(\"./label_defaults\");e.exports=function(t,e,r,a,o){var s,l=r(\"contours.coloring\"),c=\"\";\"fill\"===l&&(s=r(\"contours.showlines\")),!1!==s&&(\"lines\"!==l&&(c=r(\"line.color\",\"#000\")),r(\"line.width\",.5),r(\"line.dash\")),\"none\"!==l&&(!0!==t.showlegend&&(e.showlegend=!1),e._dfltShowLegend=!1,n(t,e,a,r,{prefix:\"\",cLetter:\"z\"})),r(\"line.smoothing\"),i(r,a,c,o)}},{\"../../components/colorscale/defaults\":603,\"./label_defaults\":957}],964:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../contour/attributes\"),a=i.contours,o=t(\"../scatter/attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../lib/extend\").extendFlat,c=o.line;e.exports=l({carpet:{valType:\"string\",editType:\"calc\"},z:n.z,a:n.x,a0:n.x0,da:n.dx,b:n.y,b0:n.y0,db:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,atype:n.xtype,btype:n.ytype,fillcolor:i.fillcolor,autocontour:i.autocontour,ncontours:i.ncontours,contours:{type:a.type,start:a.start,end:a.end,size:a.size,coloring:{valType:\"enumerated\",values:[\"fill\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:a.showlines,showlabels:a.showlabels,labelfont:a.labelfont,labelformat:a.labelformat,operation:a.operation,value:a.value,editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:l({},c.color,{}),width:c.width,dash:c.dash,smoothing:l({},c.smoothing,{}),editType:\"plot\"},transforms:void 0},s(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../contour/attributes\":942,\"../heatmap/attributes\":1001,\"../scatter/attributes\":1112}],965:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\"),i=t(\"../../lib\"),a=t(\"../heatmap/convert_column_xyz\"),o=t(\"../heatmap/clean_2d_array\"),s=t(\"../heatmap/interp2d\"),l=t(\"../heatmap/find_empties\"),c=t(\"../heatmap/make_bound_array\"),u=t(\"./defaults\"),h=t(\"../carpet/lookup_carpetid\"),f=t(\"../contour/set_contours\");e.exports=function(t,e){var r=e._carpetTrace=h(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){if(!e.a||!e.b){var p=t.data[r.index],d=t.data[e.index];d.a||(d.a=p.a),d.b||(d.b=p.b),u(d,e,e._defaultColor,t._fullLayout)}var g=function(t,e){var r,u,h,f,p,d,g,v=e._carpetTrace,m=v.aaxis,y=v.baxis;m._minDtick=0,y._minDtick=0,i.isArray1D(e.z)&&a(e,m,y,\"a\",\"b\",[\"z\"]);r=e._a=e._a||e.a,f=e._b=e._b||e.b,r=r?m.makeCalcdata(e,\"_a\"):[],f=f?y.makeCalcdata(e,\"_b\"):[],u=e.a0||0,h=e.da||1,p=e.b0||0,d=e.db||1,g=e._z=o(e._z||e.z,e.transpose),e._emptypoints=l(g),s(g,e._emptypoints);var x=i.maxRowLength(g),b=\"scaled\"===e.xtype?\"\":r,_=c(e,b,u,h,x,m),w=\"scaled\"===e.ytype?\"\":f,k=c(e,w,p,d,g.length,y),T={a:_,b:k,z:g};\"levels\"===e.contours.type&&\"none\"!==e.contours.coloring&&n(t,e,{vals:g,containerStr:\"\",cLetter:\"z\"});return[T]}(t,e);return f(e,e._z),g}}},{\"../../components/colorscale/calc\":601,\"../../lib\":719,\"../carpet/lookup_carpetid\":915,\"../contour/set_contours\":961,\"../heatmap/clean_2d_array\":1003,\"../heatmap/convert_column_xyz\":1005,\"../heatmap/find_empties\":1007,\"../heatmap/interp2d\":1010,\"../heatmap/make_bound_array\":1011,\"./defaults\":966}],966:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"./attributes\"),o=t(\"../contour/constraint_defaults\"),s=t(\"../contour/contours_defaults\"),l=t(\"../contour/style_defaults\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,a,r,i)}if(u(\"carpet\"),t.a&&t.b){if(!i(t,e,u,c,\"a\",\"b\"))return void(e.visible=!1);u(\"text\"),\"constraint\"===u(\"contours.type\")?o(t,e,u,c,r,{hasHover:!1}):(s(t,e,u,function(r){return n.coerce2(t,e,a,r)}),l(t,e,u,c,{hasHover:!1}))}else e._defaultColor=r,e._length=null}},{\"../../lib\":719,\"../contour/constraint_defaults\":947,\"../contour/contours_defaults\":949,\"../contour/style_defaults\":963,\"../heatmap/xyz_defaults\":1015,\"./attributes\":964}],967:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../contour/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../contour/style\"),moduleType:\"trace\",name:\"contourcarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"contour\",\"symbols\",\"showLegend\",\"hasLines\",\"carpetDependent\"],meta:{}}},{\"../../plots/cartesian\":778,\"../contour/colorbar\":945,\"../contour/style\":962,\"./attributes\":964,\"./calc\":965,\"./defaults\":966,\"./plot\":970}],968:[function(t,e,r){\"use strict\";var n=t(\"../../components/drawing\"),i=t(\"../carpet/axis_aligned_line\"),a=t(\"../../lib\");e.exports=function(t,e,r,o,s,l,c,u){var h,f,p,d,g,v,m,y=\"\",x=e.edgepaths.map(function(t,e){return e}),b=!0,_=1e-4*Math.abs(r[0][0]-r[2][0]),w=1e-4*Math.abs(r[0][1]-r[2][1]);function k(t){return Math.abs(t[1]-r[0][1])<w}function T(t){return Math.abs(t[1]-r[2][1])<w}function A(t){return Math.abs(t[0]-r[0][0])<_}function M(t){return Math.abs(t[0]-r[2][0])<_}function S(t,e){var r,n,a,o,h=\"\";for(k(t)&&!M(t)||T(t)&&!A(t)?(o=s.aaxis,a=i(s,l,[t[0],e[0]],.5*(t[1]+e[1]))):(o=s.baxis,a=i(s,l,.5*(t[0]+e[0]),[t[1],e[1]])),r=1;r<a.length;r++)for(h+=o.smoothing?\"C\":\"L\",n=0;n<a[r].length;n++){var f=a[r][n];h+=[c.c2p(f[0]),u.c2p(f[1])]+\" \"}return h}for(h=0,f=null;x.length;){var E=e.edgepaths[h][0];for(f&&(y+=S(f,E)),m=n.smoothopen(e.edgepaths[h].map(o),e.smoothing),y+=b?m:m.replace(/^M/,\"L\"),x.splice(x.indexOf(h),1),f=e.edgepaths[h][e.edgepaths[h].length-1],g=-1,d=0;d<4;d++){if(!f){a.log(\"Missing end?\",h,e);break}for(k(f)&&!M(f)?p=r[1]:A(f)?p=r[0]:T(f)?p=r[3]:M(f)&&(p=r[2]),v=0;v<e.edgepaths.length;v++){var C=e.edgepaths[v][0];Math.abs(f[0]-p[0])<_?Math.abs(f[0]-C[0])<_&&(C[1]-f[1])*(p[1]-C[1])>=0&&(p=C,g=v):Math.abs(f[1]-p[1])<w?Math.abs(f[1]-C[1])<w&&(C[0]-f[0])*(p[0]-C[0])>=0&&(p=C,g=v):a.log(\"endpt to newendpt is not vert. or horz.\",f,p,C)}if(g>=0)break;y+=S(f,p),f=p}if(g===e.edgepaths.length){a.log(\"unclosed perimeter path\");break}h=g,(b=-1===x.indexOf(h))&&(h=x[0],y+=S(f,p)+\"Z\",f=null)}for(h=0;h<e.paths.length;h++)y+=n.smoothclosed(e.paths[h].map(o),e.smoothing);return y}},{\"../../components/drawing\":614,\"../../lib\":719,\"../carpet/axis_aligned_line\":899}],969:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i,a,o,s,l,c,u;for(r=0;r<t.length;r++){for(o=(a=t[r]).pedgepaths=[],s=a.ppaths=[],n=0;n<a.edgepaths.length;n++){for(u=a.edgepaths[n],l=[],i=0;i<u.length;i++)l[i]=e(u[i]);o.push(l)}for(n=0;n<a.paths.length;n++){for(u=a.paths[n],c=[],i=0;i<u.length;i++)c[i]=e(u[i]);s.push(c)}}}},{}],970:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../carpet/map_1d_array\"),a=t(\"../carpet/makepath\"),o=t(\"../../components/drawing\"),s=t(\"../../lib\"),l=t(\"../contour/make_crossings\"),c=t(\"../contour/find_all_paths\"),u=t(\"../contour/plot\"),h=t(\"../contour/constants\"),f=t(\"../contour/convert_to_constraints\"),p=t(\"./join_all_paths\"),d=t(\"../contour/empty_pathinfo\"),g=t(\"./map_pathinfo\"),v=t(\"../carpet/lookup_carpetid\"),m=t(\"../contour/close_boundaries\");function y(t,e,r){var n=t.getPointAtLength(e),i=t.getPointAtLength(r),a=i.x-n.x,o=i.y-n.y,s=Math.sqrt(a*a+o*o);return[a/s,o/s]}function x(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]);return[t[0]/e,t[1]/e]}function b(t,e){var r=Math.abs(t[0]*e[0]+t[1]*e[1]);return Math.sqrt(1-r*r)/r}e.exports=function(t,e,r,_){var w=e.xaxis,k=e.yaxis;s.makeTraceGroups(_,r,\"contour\").each(function(r){var _=n.select(this),T=r[0],A=T.trace,M=A._carpetTrace=v(t,A),S=t.calcdata[M.index][0];if(M.visible&&\"legendonly\"!==M.visible){var E=T.a,C=T.b,L=A.contours,P=d(L,e,T),O=\"constraint\"===L.type,z=L._operation,I=O?\"=\"===z?\"lines\":\"fill\":L.coloring,D=[[E[0],C[C.length-1]],[E[E.length-1],C[C.length-1]],[E[E.length-1],C[0]],[E[0],C[0]]];l(P);var R=1e-8*(E[E.length-1]-E[0]),F=1e-8*(C[C.length-1]-C[0]);c(P,R,F);var B,N,j,U,V=P;\"constraint\"===L.type&&(V=f(P,z),m(V,z,D,A)),g(P,G);var q=[];for(U=S.clipsegments.length-1;U>=0;U--)B=S.clipsegments[U],N=i([],B.x,w.c2p),j=i([],B.y,k.c2p),N.reverse(),j.reverse(),q.push(a(N,j,B.bicubic));var H=\"M\"+q.join(\"L\")+\"Z\";!function(t,e,r,n,o,l){var c,u,h,f,p=s.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"!==l||o?[]:[0]);p.enter().append(\"path\"),p.exit().remove();var d=[];for(f=0;f<e.length;f++)c=e[f],u=i([],c.x,r.c2p),h=i([],c.y,n.c2p),d.push(a(u,h,c.bicubic));p.attr(\"d\",\"M\"+d.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(_,S.clipsegments,w,k,O,I),function(t,e,r,i,a,o,l,c,u,h,f){var d=s.ensureSingle(e,\"g\",\"contourfill\").selectAll(\"path\").data(\"fill\"===h?a:[]);d.enter().append(\"path\"),d.exit().remove(),d.each(function(e){var a=p(t,e,o,l,c,u,r,i);e.prefixBoundary&&(a=f+a),a?n.select(this).attr(\"d\",a).style(\"stroke\",\"none\"):n.select(this).remove()})}(A,_,w,k,V,D,G,M,S,I,H),function(t,e,r,i,a,l,c){var f=s.ensureSingle(t,\"g\",\"contourlines\"),p=!1!==a.showlines,d=a.showlabels,g=p&&d,v=u.createLines(f,p||d,e),m=u.createLineClip(f,g,r,i.trace.uid),_=t.selectAll(\"g.contourlabels\").data(d?[0]:[]);if(_.exit().remove(),_.enter().append(\"g\").classed(\"contourlabels\",!0),d){var w=l.xaxis,k=l.yaxis,T=w._length,A=k._length,M=[[[0,0],[T,0],[T,A],[0,A]]],S=[];s.clearLocationCache();var E=u.labelFormatter(a,i.t.cb,r._fullLayout),C=o.tester.append(\"text\").attr(\"data-notex\",1).call(o.font,a.labelfont),L={left:0,right:T,center:T/2,top:0,bottom:A,middle:A/2},P=Math.sqrt(T*T+A*A),O=h.LABELDISTANCE*P/Math.max(1,e.length/h.LABELINCREASE);v.each(function(t){var e=u.calcTextOpts(t.level,E,C,r);n.select(this).selectAll(\"path\").each(function(r){var n=s.getVisibleSegment(this,L,e.height/2);if(n&&(function(t,e,r,n,i,a){for(var o,s=0;s<r.pedgepaths.length;s++)e===r.pedgepaths[s]&&(o=r.edgepaths[s]);if(!o)return;var l=i.a[0],c=i.a[i.a.length-1],u=i.b[0],h=i.b[i.b.length-1];function f(t,e){var r,n=0;return(Math.abs(t[0]-l)<.1||Math.abs(t[0]-c)<.1)&&(r=x(i.dxydb_rough(t[0],t[1],.1)),n=Math.max(n,a*b(e,r)/2)),(Math.abs(t[1]-u)<.1||Math.abs(t[1]-h)<.1)&&(r=x(i.dxyda_rough(t[0],t[1],.1)),n=Math.max(n,a*b(e,r)/2)),n}var p=y(t,0,1),d=y(t,n.total,n.total-1),g=f(o[0],p),v=n.total-f(o[o.length-1],d);n.min<g&&(n.min=g);n.max>v&&(n.max=v);n.len=n.max-n.min}(this,r,t,n,c,e.height),!(n.len<(e.width+e.height)*h.LABELMIN)))for(var i=Math.min(Math.ceil(n.len/O),h.LABELMAX),a=0;a<i;a++){var o=u.findBestTextLocation(this,n,e,S,L);if(!o)break;u.addLabelData(o,e,S,M)}})}),C.remove(),u.drawLabels(_,S,r,m,g?M:null)}d&&!p&&v.remove()}(_,P,t,T,L,e,M),o.setClipUrl(_,M._clipPathId,t)}function G(t){var e=M.ab2xy(t[0],t[1],!0);return[w.c2p(e[0]),k.c2p(e[1])]}})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../carpet/lookup_carpetid\":915,\"../carpet/makepath\":916,\"../carpet/map_1d_array\":917,\"../contour/close_boundaries\":944,\"../contour/constants\":946,\"../contour/convert_to_constraints\":950,\"../contour/empty_pathinfo\":952,\"../contour/find_all_paths\":954,\"../contour/make_crossings\":959,\"../contour/plot\":960,\"./join_all_paths\":968,\"./map_pathinfo\":969,d3:163}],971:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../scattermapbox/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({lon:o.lon,lat:o.lat,z:{valType:\"data_array\",editType:\"calc\"},radius:{valType:\"number\",editType:\"plot\",arrayOk:!0,min:1,dflt:30},below:{valType:\"string\",editType:\"plot\"},text:o.text,hovertext:o.hovertext,hoverinfo:s({},a.hoverinfo,{flags:[\"lon\",\"lat\",\"z\",\"text\",\"name\"]}),hovertemplate:i()},n(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scattermapbox/attributes\":1171}],972:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../components/colorscale/calc\"),s=t(\"../../lib\")._;e.exports=function(t,e){for(var r=e._length,l=new Array(r),c=e.z,u=i(c)&&c.length,h=0;h<r;h++){var f=l[h]={},p=e.lon[h],d=e.lat[h];if(f.lonlat=n(p)&&n(d)?[+p,+d]:[a,a],u){var g=c[h];f.z=n(g)?g:a}}return o(t,e,{vals:u?c:[0,1],containerStr:\"\",cLetter:\"z\"}),r&&(l[0].t={labels:{lat:s(t,\"lat:\")+\" \",lon:s(t,\"lon:\")+\" \"}}),l}},{\"../../components/colorscale/calc\":601,\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],973:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../../components/colorscale\"),s=t(\"../../constants/numerical\").BADNUM,l=t(\"../../lib/geojson_utils\").makeBlank;e.exports=function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,c=e._opts={heatmap:{layout:{visibility:\"none\"},paint:{}},geojson:l()};if(!r)return c;var u,h=[],f=e.z,p=e.radius,d=i.isArrayOrTypedArray(f)&&f.length,g=i.isArrayOrTypedArray(p);for(u=0;u<t.length;u++){var v=t[u],m=v.lonlat;if(m[0]!==s){var y={};if(d){var x=v.z;y.z=x!==s?x:0}g&&(y.r=n(p[u])&&p[u]>0?+p[u]:0),h.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:m},properties:y})}}var b=o.extractOpts(e),_=b.reversescale?o.flipScale(b.colorscale):b.colorscale,w=_[0][1],k=[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,a.opacity(w)<1?w:a.addOpacity(w,0)];for(u=1;u<_.length;u++)k.push(_[u][0],_[u][1]);var T=[\"interpolate\",[\"linear\"],[\"get\",\"z\"],b.min,0,b.max,1];return i.extendFlat(c.heatmap.paint,{\"heatmap-weight\":d?T:1/(b.max-b.min),\"heatmap-color\":k,\"heatmap-radius\":g?{type:\"identity\",property:\"r\"}:e.radius,\"heatmap-opacity\":e.opacity}),c.geojson={type:\"FeatureCollection\",features:h},c.heatmap.layout.visibility=\"visible\",c}},{\"../../components/color\":593,\"../../components/colorscale\":605,\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/geojson_utils\":714,\"fast-isnumeric\":225}],974:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"lon\")||[],c=s(\"lat\")||[],u=Math.min(l.length,c.length);u?(e._length=u,s(\"z\"),s(\"radius\"),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":971}],975:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.z=e.z,t}},{}],976:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../scattermapbox/hover\");e.exports=function(t,e,r){var o=a(t,e,r);if(o){var s=o[0],l=s.cd,c=l[0].trace,u=l[s.index];if(delete s.color,\"z\"in u){var h=s.subplot.mockAxis;s.z=u.z,s.zLabel=i.tickText(h,h.c2l(u.z),\"hover\").text}return s.extraText=function(t,e,r){if(t.hovertemplate)return;var i=(e.hi||t.hoverinfo).split(\"+\"),a=-1!==i.indexOf(\"all\"),o=-1!==i.indexOf(\"lon\"),s=-1!==i.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}a||o&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):o?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(a||-1!==i.indexOf(\"text\"))&&n.fillText(e,t,c);return c.join(\"<br>\")}(c,u,l[0].t.labels),[s]}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scattermapbox/hover\":1175}],977:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),getBelow:function(t,e){for(var r=e.getMapLayers(),n=0;n<r.length;n++){var i=r[n],a=i.id;if(\"symbol\"===i.type&&\"string\"==typeof a&&-1===a.indexOf(\"plotly-\"))return a}},moduleType:\"trace\",name:\"densitymapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\"],meta:{hr_name:\"density_mapbox\"}}},{\"../../plots/mapbox\":822,\"../heatmap/colorbar\":1004,\"./attributes\":971,\"./calc\":972,\"./defaults\":974,\"./event_data\":975,\"./hover\":976,\"./plot\":978}],978:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function a(t,e){this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"heatmap\",i+e+\"-heatmap\"]],this.below=null}var o=a.prototype;o.update=function(t){var e=this.subplot,r=this.layerList,i=n(t),a=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(i.geojson),a!==this.below&&(this._removeLayers(),this._addLayers(i,a),this.below=a);for(var o=0;o<r.length;o++){var s=r[o],l=s[0],c=s[1],u=i[l];e.setOptions(c,\"setLayoutProperty\",u.layout),\"visible\"===u.layout.visibility&&e.setOptions(c,\"setPaintProperty\",u.paint)}},o._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},o._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},o.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new a(t,r.uid),o=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(o,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),i}},{\"../../plots/mapbox/constants\":820,\"./convert\":973}],979:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":719}],980:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"./constants\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../components/color\");e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,hovertext:n.hovertext,hovertemplate:o({},{keys:s.eventDataKeys}),hoverinfo:l({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"percent initial\",\"percent previous\",\"percent total\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"percent initial\",\"percent previous\",\"percent total\",\"value\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},text:n.text,textposition:l({},n.textposition,{dflt:\"auto\"}),insidetextanchor:l({},n.insidetextanchor,{dflt:\"middle\"}),textangle:l({},n.textangle,{dflt:0}),textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:l({},n.orientation,{}),offset:l({},n.offset,{arrayOk:!1}),width:l({},n.width,{arrayOk:!1}),marker:n.marker,connector:{fillcolor:{valType:\"color\",editType:\"style\"},line:{color:l({},i.color,{dflt:c.defaultLine}),width:l({},i.width,{dflt:0,editType:\"plot\"}),dash:i.dash,editType:\"style\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":593,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../bar/attributes\":857,\"../scatter/attributes\":1112,\"./constants\":982}],981:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"./arrays_to_calcdata\"),a=t(\"../scatter/calc_selection\"),o=t(\"../../constants/numerical\").BADNUM;function s(t){return t===o?0:t}e.exports=function(t,e){var r,l,c,u,h=n.getFromId(t,e.xaxis||\"x\"),f=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=h.makeCalcdata(e,\"x\"),l=f.makeCalcdata(e,\"y\")):(r=f.makeCalcdata(e,\"y\"),l=h.makeCalcdata(e,\"x\"));var p,d=Math.min(l.length,r.length),g=new Array(d);for(e._base=[],c=0;c<d;c++){r[c]<0&&(r[c]=o);var v=!1;r[c]!==o&&c+1<d&&r[c+1]!==o&&(v=!0),u=g[c]={p:l[c],s:r[c],cNext:v},e._base[c]=-.5*u.s,e.ids&&(u.id=String(e.ids[c])),0===c&&(g[0].vTotal=0),g[0].vTotal+=s(u.s),u.begR=s(u.s)/s(g[0].s)}for(c=0;c<d;c++)(u=g[c]).s!==o&&(u.sumR=u.s/g[0].vTotal,u.difR=void 0!==p?u.s/p:1,p=u.s);return i(g,e),a(g,e),g}},{\"../../constants/numerical\":695,\"../../plots/cartesian/axes\":767,\"../scatter/calc_selection\":1114,\"./arrays_to_calcdata\":979}],982:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"percentInitial\",\"percentPrevious\",\"percentTotal\"]}},{}],983:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],h=[],f=[];for(i=0;i<o.length;i++){var p=o[i],d=\"h\"===p.orientation;!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"funnel\"===p.type&&(r=s[i],d?f.push(r):h.push(r),u.push(r))}var g={mode:a.funnelmode,norm:a.funnelnorm,gap:a.funnelgap,groupgap:a.funnelgroupgap};for(n(t,l,c,h,g),n(t,c,l,f,g),i=0;i<u.length;i++){r=u[i];for(var v=0;v<r.length;v++)v+1<r.length&&(r[v].nextP0=r[v+1].p0,r[v].nextS0=r[v+1].s0,r[v].nextP1=r[v+1].p1,r[v].nextS1=r[v+1].s1)}}},{\"../bar/cross_trace_calc\":860}],984:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"./attributes\"),l=t(\"../../components/color\");e.exports={supplyDefaults:function(t,e,r,i){function c(r,i){return n.coerce(t,e,s,r,i)}if(o(t,e,i,c)){c(\"orientation\",e.y&&!e.x?\"v\":\"h\"),c(\"offset\"),c(\"width\");var u=c(\"text\");c(\"hovertext\"),c(\"hovertemplate\");var h=c(\"textposition\");a(t,e,i,c,h,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"!==e.textposition&&c(\"textinfo\",Array.isArray(u)?\"text+value\":\"value\");var f=c(\"marker.color\",r);c(\"marker.line.color\",l.defaultLine),c(\"marker.line.width\"),c(\"connector.visible\")&&(c(\"connector.fillcolor\",function(t){var e=n.isArrayOrTypedArray(t)?\"#000\":t;return l.addOpacity(e,.5*l.opacity(e))}(f)),c(\"connector.line.width\")&&(c(\"connector.line.color\"),c(\"connector.line.dash\")))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,s,t)}if(\"group\"===e.funnelmode)for(var l=0;l<t.length;l++)r=(a=t[l])._input,i(r,a,e,o)}}},{\"../../components/color\":593,\"../../lib\":719,\"../bar/defaults\":861,\"../scatter/xy_defaults\":1137,\"./attributes\":980}],985:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"percentInitial\"in e&&(t.percentInitial=e.percentInitial),\"percentPrevious\"in e&&(t.percentPrevious=e.percentPrevious),\"percentTotal\"in e&&(t.percentTotal=e.percentTotal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],986:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\").opacity,i=t(\"../bar/hover\").hoverOnBars,a=t(\"../../lib\").formatPercent;e.exports=function(t,e,r,o){var s=i(t,e,r,o);if(s){var l=s.cd,c=l[0].trace,u=\"h\"===c.orientation,h=l[s.index];s[(u?\"x\":\"y\")+\"LabelVal\"]=h.s,s.percentInitial=h.begR,s.percentInitialLabel=a(h.begR,1),s.percentPrevious=h.difR,s.percentPreviousLabel=a(h.difR,1),s.percentTotal=h.sumR,s.percentTotalLabel=a(h.sumR,1);var f=h.hi||c.hoverinfo,p=[];if(f&&\"none\"!==f&&\"skip\"!==f){var d=\"all\"===f,g=f.split(\"+\"),v=function(t){return d||-1!==g.indexOf(t)};v(\"percent initial\")&&p.push(s.percentInitialLabel+\" of initial\"),v(\"percent previous\")&&p.push(s.percentPreviousLabel+\" of previous\"),v(\"percent total\")&&p.push(s.percentTotalLabel+\" of total\")}return s.extraText=p.join(\"<br>\"),s.color=function(t,e){var r=t.marker,i=e.mc||r.color,a=e.mlc||r.line.color,o=e.mlw||r.line.width;if(n(i))return i;if(n(a)&&o)return a}(c,h),[s]}}},{\"../../components/color\":593,\"../../lib\":719,\"../bar/hover\":863}],987:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"funnel\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../bar/select\":868,\"./attributes\":980,\"./calc\":981,\"./cross_trace_calc\":983,\"./defaults\":984,\"./event_data\":985,\"./hover\":986,\"./layout_attributes\":988,\"./layout_defaults\":989,\"./plot\":990,\"./style\":991}],988:[function(t,e,r){\"use strict\";e.exports={funnelmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},funnelgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},funnelgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],989:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"funnel\"===l.type){a=!0;break}}a&&(o(\"funnelmode\"),o(\"funnelgap\",.2),o(\"funnelgroupgap\"))}},{\"../../lib\":719,\"./layout_attributes\":988}],990:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../bar/plot\").plot;function s(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),i[3]=o.c2p(t.nextS1,!0),a[3]=s.c2p(t.nextP1,!0),n?[i,a]:[a,i]}e.exports=function(t,e,r,l){var c=t._fullLayout;!function(t,e,r,o){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each(function(r){var o=n.select(this),u=r[0].trace,h=i.ensureSingle(o,\"g\",\"regions\");if(u.connector&&u.connector.visible){var f=\"h\"===u.orientation,p=h.selectAll(\"g.region\").data(i.identity);p.enter().append(\"g\").classed(\"region\",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var u=s(r,l,c,f),h=u[0],p=u[1],g=\"\";void 0!==h[3]&&void 0!==p[3]&&(g+=f?\"M\"+h[0]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[2]+\"H\"+h[3]+\"L\"+h[1]+\",\"+p[1]+\"Z\":\"M\"+h[1]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[3]+\"V\"+p[2]+\"L\"+h[1]+\",\"+p[0]+\"Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}})}else h.remove()})}(t,e,r,l),function(t,e,r,o){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each(function(r){var o=n.select(this),u=r[0].trace,h=i.ensureSingle(o,\"g\",\"lines\");if(u.connector&&u.connector.visible&&u.connector.line.width){var f=\"h\"===u.orientation,p=h.selectAll(\"g.line\").data(i.identity);p.enter().append(\"g\").classed(\"line\",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var u=s(r,l,c,f),h=u[0],p=u[1],g=\"\";void 0!==h[3]&&void 0!==p[3]&&(f?(g+=\"M\"+h[0]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[2],g+=\"M\"+h[1]+\",\"+p[1]+\"L\"+h[3]+\",\"+p[2]):(g+=\"M\"+h[1]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[3],g+=\"M\"+h[1]+\",\"+p[0]+\"L\"+h[2]+\",\"+p[2])),\"\"===g&&(g=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}})}else h.remove()})}(t,e,r,l),o(t,e,r,l,{mode:c.funnelmode,norm:c.funnelmode,gap:c.funnelgap,groupgap:c.funnelgroupgap})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../bar/plot\":867,d3:163}],991:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\").styleTextPoints;e.exports={style:function(t,e,r){var l=r||n.select(t).selectAll(\"g.funnellayer\").selectAll(\"g.trace\");l.style(\"opacity\",function(t){return t[0].trace.opacity}),l.each(function(e){var r=n.select(this),l=e[0].trace;r.selectAll(\".point > path\").each(function(t){if(!t.isBlank){var e=l.marker;n.select(this).call(a.fill,t.mc||e.color).call(a.stroke,t.mlc||e.line.color).call(i.dashLine,e.line.dash,t.mlw||e.line.width).style(\"opacity\",l.selectedpoints&&!t.selected?o:1)}}),s(r,l,t),r.selectAll(\".regions\").each(function(){n.select(this).selectAll(\"path\").style(\"stroke-width\",0).call(a.fill,l.connector.fillcolor)}),r.selectAll(\".lines\").each(function(){var t=l.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)})})}}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../constants/interactions\":694,\"../bar/style\":870,d3:163}],992:[function(t,e,r){\"use strict\";var n=t(\"../pie/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../plots/domain\").attributes,o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports={labels:n.labels,label0:n.label0,dlabel:n.dlabel,values:n.values,marker:{colors:n.marker.colors,line:{color:s({},n.marker.line.color,{dflt:null}),width:s({},n.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},text:n.text,hovertext:n.hovertext,scalegroup:s({},n.scalegroup,{}),textinfo:s({},n.textinfo,{flags:[\"label\",\"text\",\"value\",\"percent\"]}),hoverinfo:s({},i.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:o({},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),textposition:s({},n.textposition,{values:[\"inside\",\"none\"],dflt:\"inside\"}),textfont:n.textfont,insidetextfont:n.insidetextfont,title:{text:n.title.text,font:n.title.font,position:s({},n.title.position,{values:[\"top left\",\"top center\",\"top right\"],dflt:\"top center\"}),editType:\"plot\"},domain:a({name:\"funnelarea\",trace:!0,editType:\"calc\"}),aspectratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},baseratio:{valType:\"number\",min:0,max:1,dflt:.333,editType:\"plot\"}}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../pie/attributes\":1086}],993:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData;r.name=\"funnelarea\",r.plot=function(t){var e=n.getModule(\"funnelarea\"),r=i(t.calcdata,e)[0];e.plot(t,r)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"funnelarea\"),a=e._has&&e._has(\"funnelarea\");i&&!a&&n._funnelarealayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],994:[function(t,e,r){\"use strict\";var n=t(\"../pie/calc\");e.exports={calc:function(t,e){return n.calc(t,e)},crossTraceCalc:function(t){n.crossTraceCalc(t,{type:\"funnelarea\"})}}},{\"../pie/calc\":1088}],995:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}var c,u=l(\"values\"),h=n.isArrayOrTypedArray(u),f=l(\"labels\");if(Array.isArray(f)?(c=f.length,h&&(c=Math.min(c,u.length))):h&&(c=u.length,l(\"label0\"),l(\"dlabel\")),c){e._length=c,l(\"marker.line.width\")&&l(\"marker.line.color\",s.paper_bgcolor),l(\"marker.colors\"),l(\"scalegroup\");var p=l(\"text\"),d=l(\"textinfo\",Array.isArray(p)?\"text+percent\":\"percent\");if(l(\"hovertext\"),l(\"hovertemplate\"),d&&\"none\"!==d){var g=l(\"textposition\");o(t,e,s,l,g,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}a(e,s,l),l(\"title.text\")&&(l(\"title.position\"),n.coerceFont(l,\"title.font\",s.font)),l(\"aspectratio\"),l(\"baseratio\")}else e.visible=!1}},{\"../../lib\":719,\"../../plots/domain\":792,\"../bar/defaults\":861,\"./attributes\":992}],996:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"funnelarea\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"funnelarea\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\"),styleOne:t(\"../pie/style_one\"),meta:{}}},{\"../pie/style_one\":1097,\"./attributes\":992,\"./base_plot\":993,\"./calc\":994,\"./defaults\":995,\"./layout_attributes\":997,\"./layout_defaults\":998,\"./plot\":999,\"./style\":1e3}],997:[function(t,e,r){\"use strict\";var n=t(\"../pie/layout_attributes\").hiddenlabels;e.exports={hiddenlabels:n,funnelareacolorway:{valType:\"colorlist\",editType:\"calc\"},extendfunnelareacolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{\"../pie/layout_attributes\":1093}],998:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"funnelareacolorway\",e.colorway),r(\"extendfunnelareacolors\")}},{\"../../lib\":719,\"./layout_attributes\":997}],999:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../lib\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../bar/plot\"),l=s.getTransform,c=s.toMoveInsideBar,u=t(\"../pie/helpers\"),h=t(\"../pie/plot\"),f=h.attachFxHandlers,p=h.determineInsideTextFont,d=h.layoutAreas,g=h.prerenderTitles,v=h.positionTitleOutside;function m(t,e){return\"l\"+(e[0]-t[0])+\",\"+(e[1]-t[1])}e.exports=function(t,e){var r=t._fullLayout;g(e,t),d(e,r._size),a.makeTraceGroups(r._funnelarealayer,e,\"trace\").each(function(e){var s=n.select(this),h=e[0],d=h.trace;!function(t){if(!t.length)return;var e=t[0],r=e.trace,n=r.aspectratio,i=r.baseratio;i>.999&&(i=.999);var a,o=Math.pow(i,2),s=e.vTotal,l=s,c=s*o/(1-o)/s;function u(){var t,e={x:t=Math.sqrt(c),y:-t};return[e.x,e.y]}var h,f,p=[];for(p.push(u()),h=t.length-1;h>-1;h--)if(!(f=t[h]).hidden){var d=f.v/l;c+=d,p.push(u())}var g=1/0,v=-1/0;for(h=0;h<p.length;h++)a=p[h],g=Math.min(g,a[1]),v=Math.max(v,a[1]);for(h=0;h<p.length;h++)p[h][1]-=(v+g)/2;var m=p[p.length-1][0],y=e.r,x=(v-g)/2,b=y/m,_=y/x*n;for(e.r=_*x,h=0;h<p.length;h++)p[h][0]*=b,p[h][1]*=_;var w=[-(a=p[0])[0],a[1]],k=[a[0],a[1]],T=0;for(h=t.length-1;h>-1;h--)if(!(f=t[h]).hidden){var A=p[T+=1][0],M=p[T][1];f.TL=[-A,M],f.TR=[A,M],f.BL=w,f.BR=k,f.pxmid=(S=f.TR,E=f.BR,[.5*(S[0]+E[0]),.5*(S[1]+E[1])]),w=f.TL,k=f.TR}var S,E}(e),s.each(function(){var s=n.select(this).selectAll(\"g.slice\").data(e);s.enter().append(\"g\").classed(\"slice\",!0),s.exit().remove(),s.each(function(r){if(r.hidden)n.select(this).selectAll(\"path,g\").remove();else{r.pointNumber=r.i,r.curveNumber=d.index;var s=h.cx,g=h.cy,v=n.select(this),y=v.selectAll(\"path.surface\").data([r]);y.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),v.call(f,t,e);var x=\"M\"+(s+r.TR[0])+\",\"+(g+r.TR[1])+m(r.TR,r.BR)+m(r.BR,r.BL)+m(r.BL,r.TL)+\"Z\";y.attr(\"d\",x);var b=u.castOption(d.textposition,r.pts),_=v.selectAll(\"g.slicetext\").data(r.text&&\"none\"!==b?[0]:[]);_.enter().append(\"g\").classed(\"slicetext\",!0),_.exit().remove(),_.each(function(){var e=a.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)});e.text(r.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,p(d,r,t._fullLayout.font)).call(o.convertToTspans,t);var u,h,f,v=i.bBox(e.node()),m=Math.min(r.BL[1],r.BR[1]),y=Math.max(r.TL[1],r.TR[1]);h=Math.max(r.TL[0],r.BL[0]),f=Math.min(r.TR[0],r.BR[0]),u=l(c(h,f,m,y,v,{isHorizontal:!0,constrained:!0,angle:0,anchor:\"middle\"})),e.attr(\"transform\",\"translate(\"+s+\",\"+g+\")\"+u)})}});var g=n.select(this).selectAll(\"g.titletext\").data(d.title.text?[0]:[]);g.enter().append(\"g\").classed(\"titletext\",!0),g.exit().remove(),g.each(function(){var e=a.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),s=d.title.text;d._meta&&(s=a.templateString(s,d._meta)),e.text(s).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,d.title.font).call(o.convertToTspans,t);var l=v(h,r._size);e.attr(\"transform\",\"translate(\"+l.x+\",\"+l.y+\")\"+(l.scale<1?\"scale(\"+l.scale+\")\":\"\")+\"translate(\"+l.tx+\",\"+l.ty+\")\")})})})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../bar/plot\":867,\"../pie/helpers\":1091,\"../pie/plot\":1095,d3:163}],1000:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../pie/style_one\");e.exports=function(t){t._fullLayout._funnelarealayer.selectAll(\".trace\").each(function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each(function(t){n.select(this).call(i,t,e)})})}},{\"../pie/style_one\":1097,d3:163}],1001:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../components/colorscale/attributes\"),o=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../lib/extend\").extendFlat);e.exports=o({z:{valType:\"data_array\",editType:\"calc\"},x:o({},n.x,{impliedEdits:{xtype:\"array\"}}),x0:o({},n.x0,{impliedEdits:{xtype:\"scaled\"}}),dx:o({},n.dx,{impliedEdits:{xtype:\"scaled\"}}),y:o({},n.y,{impliedEdits:{ytype:\"array\"}}),y0:o({},n.y0,{impliedEdits:{ytype:\"scaled\"}}),dy:o({},n.dy,{impliedEdits:{ytype:\"scaled\"}}),text:{valType:\"data_array\",editType:\"calc\"},hovertext:{valType:\"data_array\",editType:\"calc\"},transpose:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xtype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},ytype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},zsmooth:{valType:\"enumerated\",values:[\"fast\",\"best\",!1],dflt:!1,editType:\"calc\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xgap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},ygap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},zhoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},hovertemplate:i()},{transforms:void 0},a(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../scatter/attributes\":1112}],1002:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../histogram2d/calc\"),s=t(\"../../components/colorscale/calc\"),l=t(\"./convert_column_xyz\"),c=t(\"./clean_2d_array\"),u=t(\"./interp2d\"),h=t(\"./find_empties\"),f=t(\"./make_bound_array\");e.exports=function(t,e){var r,p,d,g,v,m,y,x,b,_=a.getFromId(t,e.xaxis||\"x\"),w=a.getFromId(t,e.yaxis||\"y\"),k=n.traceIs(e,\"contour\"),T=n.traceIs(e,\"histogram\"),A=n.traceIs(e,\"gl2d\"),M=k?\"best\":e.zsmooth;if(_._minDtick=0,w._minDtick=0,T)r=(b=o(t,e)).x,p=b.x0,d=b.dx,g=b.y,v=b.y0,m=b.dy,y=b.z;else{var S=e.z;i.isArray1D(S)?(l(e,_,w,\"x\",\"y\",[\"z\"]),r=e._x,g=e._y,S=e._z):(r=e._x=e.x?_.makeCalcdata(e,\"x\"):[],g=e._y=e.y?w.makeCalcdata(e,\"y\"):[]),p=e.x0,d=e.dx,v=e.y0,m=e.dy,y=c(S,e,_,w),(k||e.connectgaps)&&(e._emptypoints=h(y),u(y,e._emptypoints))}function E(t){M=e._input.zsmooth=e.zsmooth=!1,i.warn('cannot use zsmooth: \"fast\": '+t)}if(\"fast\"===M)if(\"log\"===_.type||\"log\"===w.type)E(\"log axis found\");else if(!T){if(r.length){var C=(r[r.length-1]-r[0])/(r.length-1),L=Math.abs(C/100);for(x=0;x<r.length-1;x++)if(Math.abs(r[x+1]-r[x]-C)>L){E(\"x scale is not linear\");break}}if(g.length&&\"fast\"===M){var P=(g[g.length-1]-g[0])/(g.length-1),O=Math.abs(P/100);for(x=0;x<g.length-1;x++)if(Math.abs(g[x+1]-g[x]-P)>O){E(\"y scale is not linear\");break}}}var z=i.maxRowLength(y),I=\"scaled\"===e.xtype?\"\":r,D=f(e,I,p,d,z,_),R=\"scaled\"===e.ytype?\"\":g,F=f(e,R,v,m,y.length,w);A||(e._extremes[_._id]=a.findExtremes(_,D),e._extremes[w._id]=a.findExtremes(w,F));var B={x:D,y:F,z:y,text:e._text||e.text,hovertext:e._hovertext||e.hovertext};if(I&&I.length===D.length-1&&(B.xCenter=I),R&&R.length===F.length-1&&(B.yCenter=R),T&&(B.xRanges=b.xRanges,B.yRanges=b.yRanges,B.pts=b.pts),k||s(t,e,{vals:y,cLetter:\"z\"}),k&&e.contours&&\"heatmap\"===e.contours.coloring){var N={type:\"contour\"===e.type?\"heatmap\":\"histogram2d\",xcalendar:e.xcalendar,ycalendar:e.ycalendar};B.xfill=f(N,I,p,d,z,_),B.yfill=f(N,R,v,m,y.length,w)}return[B]}},{\"../../components/colorscale/calc\":601,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../histogram2d/calc\":1033,\"./clean_2d_array\":1003,\"./convert_column_xyz\":1005,\"./find_empties\":1007,\"./interp2d\":1010,\"./make_bound_array\":1011}],1003:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r,o){var s,l,c,u,h,f;function p(t){if(n(t))return+t}if(e&&e.transpose){for(s=0,h=0;h<t.length;h++)s=Math.max(s,t[h].length);if(0===s)return!1;c=function(t){return t.length},u=function(t,e,r){return(t[r]||[])[e]}}else s=t.length,c=function(t,e){return t[e].length},u=function(t,e,r){return(t[e]||[])[r]};var d=function(t,e,r){return e===a||r===a?a:u(t,e,r)};function g(t){if(e&&\"carpet\"!==e.type&&\"contourcarpet\"!==e.type&&t&&\"category\"===t.type&&e[\"_\"+t._id.charAt(0)].length){var r=t._id.charAt(0),n={},o=e[\"_\"+r+\"CategoryMap\"]||e[r];for(h=0;h<o.length;h++)n[o[h]]=h;return function(e){var r=n[t._categories[e]];return r+1?r:a}}return i.identity}var v=g(r),m=g(o);o&&\"category\"===o.type&&(s=o._categories.length);var y=new Array(s);for(h=0;h<s;h++)for(l=r&&\"category\"===r.type?r._categories.length:c(t,h),y[h]=new Array(l),f=0;f<l;f++)y[h][f]=p(d(t,m(h),v(f)));return y}},{\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],1004:[function(t,e,r){\"use strict\";e.exports={min:\"zmin\",max:\"zmax\"}},{}],1005:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r,a,o,s){var l,c,u,h,f=t._length,p=e.makeCalcdata(t,a),d=r.makeCalcdata(t,o),g=t.text,v=void 0!==g&&n.isArray1D(g),m=t.hovertext,y=void 0!==m&&n.isArray1D(m),x=n.distinctVals(p),b=x.vals,_=n.distinctVals(d),w=_.vals,k=[];for(l=0;l<s.length;l++)k[l]=n.init2dArray(w.length,b.length);for(v&&(u=n.init2dArray(w.length,b.length)),y&&(h=n.init2dArray(w.length,b.length)),l=0;l<f;l++)if(p[l]!==i&&d[l]!==i){var T=n.findBin(p[l]+x.minDiff/2,b),A=n.findBin(d[l]+_.minDiff/2,w);for(c=0;c<s.length;c++){var M=t[s[c]];k[c][A][T]=M[l]}v&&(u[A][T]=g[l]),y&&(h[A][T]=m[l])}for(t[\"_\"+a]=b,t[\"_\"+o]=w,c=0;c<s.length;c++)t[\"_\"+s[c]]=k[c];v&&(t._text=u),y&&(t._hovertext=h),e&&\"category\"===e.type&&(t[\"_\"+a+\"CategoryMap\"]=b.map(function(t){return e._categories[t]})),r&&\"category\"===r.type&&(t[\"_\"+o+\"CategoryMap\"]=w.map(function(t){return r._categories[t]}))}},{\"../../constants/numerical\":695,\"../../lib\":719}],1006:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xyz_defaults\"),a=t(\"./style_defaults\"),o=t(\"../../components/colorscale/defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l)?(c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\"),a(t,e,c,l),c(\"connectgaps\",n.isArray1D(e.z)&&!1!==e.zsmooth),o(t,e,l,c,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":1001,\"./style_defaults\":1014,\"./xyz_defaults\":1015}],1007:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").maxRowLength;e.exports=function(t){var e,r,i,a,o,s,l,c,u=[],h={},f=[],p=t[0],d=[],g=[0,0,0],v=n(t);for(r=0;r<t.length;r++)for(e=d,d=p,p=t[r+1]||[],i=0;i<v;i++)void 0===d[i]&&((s=(void 0!==d[i-1]?1:0)+(void 0!==d[i+1]?1:0)+(void 0!==e[i]?1:0)+(void 0!==p[i]?1:0))?(0===r&&s++,0===i&&s++,r===t.length-1&&s++,i===d.length-1&&s++,s<4&&(h[[r,i]]=[r,i,s]),u.push([r,i,s])):f.push([r,i]));for(;f.length;){for(l={},c=!1,o=f.length-1;o>=0;o--)(s=((h[[(r=(a=f[o])[0])-1,i=a[1]]]||g)[2]+(h[[r+1,i]]||g)[2]+(h[[r,i-1]]||g)[2]+(h[[r,i+1]]||g)[2])/20)&&(l[a]=[r,i,s],f.splice(o,1),c=!0);if(!c)throw\"findEmpties iterated with no new neighbors\";for(a in l)h[a]=l[a],u.push(l[a])}return u.sort(function(t,e){return e[2]-t[2]})}},{\"../../lib\":719}],1008:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../components/colorscale\").extractOpts;e.exports=function(t,e,r,s,l,c){var u,h,f,p,d=t.cd[0],g=d.trace,v=t.xa,m=t.ya,y=d.x,x=d.y,b=d.z,_=d.xCenter,w=d.yCenter,k=d.zmask,T=g.zhoverformat,A=y,M=x;if(!1!==t.index){try{f=Math.round(t.index[1]),p=Math.round(t.index[0])}catch(e){return void i.error(\"Error hovering on heatmap, pointNumber must be [row,col], found:\",t.index)}if(f<0||f>=b[0].length||p<0||p>b.length)return}else{if(n.inbox(e-y[0],e-y[y.length-1],0)>0||n.inbox(r-x[0],r-x[x.length-1],0)>0)return;if(c){var S;for(A=[2*y[0]-y[1]],S=1;S<y.length;S++)A.push((y[S]+y[S-1])/2);for(A.push([2*y[y.length-1]-y[y.length-2]]),M=[2*x[0]-x[1]],S=1;S<x.length;S++)M.push((x[S]+x[S-1])/2);M.push([2*x[x.length-1]-x[x.length-2]])}f=Math.max(0,Math.min(A.length-2,i.findBin(e,A))),p=Math.max(0,Math.min(M.length-2,i.findBin(r,M)))}var E=v.c2p(y[f]),C=v.c2p(y[f+1]),L=m.c2p(x[p]),P=m.c2p(x[p+1]);c?(C=E,u=y[f],P=L,h=x[p]):(u=_?_[f]:(y[f]+y[f+1])/2,h=w?w[p]:(x[p]+x[p+1])/2,v&&\"category\"===v.type&&(u=y[f]),m&&\"category\"===m.type&&(h=x[p]),g.zsmooth&&(E=C=v.c2p(u),L=P=m.c2p(h)));var O,z=b[p][f];k&&!k[p][f]&&(z=void 0),Array.isArray(d.hovertext)&&Array.isArray(d.hovertext[p])?O=d.hovertext[p][f]:Array.isArray(d.text)&&Array.isArray(d.text[p])&&(O=d.text[p][f]);var I=o(g),D={type:\"linear\",range:[I.min,I.max],hoverformat:T,_separators:v._separators,_numFormat:v._numFormat},R=a.tickText(D,z,\"hover\").text;return[i.extendFlat(t,{index:[p,f],distance:t.maxHoverDistance,spikeDistance:t.maxSpikeDistance,x0:E,x1:C,y0:L,y1:P,xLabelVal:u,yLabelVal:h,zLabelVal:z,zLabel:R,text:O})]}},{\"../../components/colorscale\":605,\"../../components/fx\":632,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],1009:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:t(\"./colorbar\"),style:t(\"./style\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"heatmap\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":1001,\"./calc\":1002,\"./colorbar\":1004,\"./defaults\":1006,\"./hover\":1008,\"./plot\":1012,\"./style\":1013}],1010:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[-1,0],[1,0],[0,-1],[0,1]];function a(t){return.5-.25*Math.min(1,.5*t)}function o(t,e,r){var n,a,o,s,l,c,u,h,f,p,d,g,v,m=0;for(s=0;s<e.length;s++){for(a=(n=e[s])[0],o=n[1],d=t[a][o],p=0,f=0,l=0;l<4;l++)(u=t[a+(c=i[l])[0]])&&void 0!==(h=u[o+c[1]])&&(0===p?g=v=h:(g=Math.min(g,h),v=Math.max(v,h)),f++,p+=h);if(0===f)throw\"iterateInterp2d order is wrong: no defined neighbors\";t[a][o]=p/f,void 0===d?f<4&&(m=1):(t[a][o]=(1+r)*t[a][o]-r*d,v>g&&(m=Math.max(m,Math.abs(t[a][o]-d)/(v-g))))}return m}e.exports=function(t,e){var r,i=1;for(o(t,e),r=0;r<e.length&&!(e[r][2]<4);r++);for(e=e.slice(r),r=0;r<100&&i>.01;r++)i=o(t,e,a(i));return i>.01&&n.log(\"interp2d didn't converge quickly\",i),t}},{\"../../lib\":719}],1011:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a,o,s){var l,c,u,h=[],f=n.traceIs(t,\"contour\"),p=n.traceIs(t,\"histogram\"),d=n.traceIs(t,\"gl2d\");if(i(e)&&e.length>1&&!p&&\"category\"!==s.type){var g=e.length;if(!(g<=o))return f?e.slice(0,o):e.slice(0,o+1);if(f||d)h=e.slice(0,o);else if(1===o)h=[e[0]-.5,e[0]+.5];else{for(h=[1.5*e[0]-.5*e[1]],u=1;u<g;u++)h.push(.5*(e[u-1]+e[u]));h.push(1.5*e[g-1]-.5*e[g-2])}if(g<o){var v=h[h.length-1],m=v-h[h.length-2];for(u=g;u<o;u++)v+=m,h.push(v)}}else{var y=t[s._id.charAt(0)+\"calendar\"];if(p)l=s.r2c(r,0,y);else if(i(e)&&1===e.length)l=e[0];else if(void 0===r)l=0;else{l=(\"log\"===s.type?s.d2c:s.r2c)(r,0,y)}for(c=a||1,u=f||d?0:-.5;u<o;u++)h.push(l+c*u)}return h}},{\"../../lib\":719,\"../../registry\":847}],1012:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/colorscale\").makeColorScaleFuncFromTrace,l=t(\"../../constants/xmlns_namespaces\");function c(t,e){var r=e.length-2,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=e[n+1],s=o.constrain(n+(t-i)/(a-i)-.5,0,r),l=Math.round(s),c=Math.abs(s-l);return s&&s!==r&&c?{bin0:l,frac:c,bin1:Math.round(l+c/(s-l))}:{bin0:l,bin1:l,frac:0}}function u(t,e){var r=e.length-1,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=(t-i)/(e[n+1]-i)||0;return a<=0?{bin0:n,bin1:n,frac:0}:a<.5?{bin0:n,bin1:n+1,frac:a}:{bin0:n+1,bin1:n,frac:1-a}}function h(t,e,r){t[e]=r[0],t[e+1]=r[1],t[e+2]=r[2],t[e+3]=Math.round(255*r[3])}e.exports=function(t,e,r,f){var p=e.xaxis,d=e.yaxis;o.makeTraceGroups(f,r,\"hm\").each(function(e){var r,f,g,v,m,y,x=n.select(this),b=e[0],_=b.trace,w=b.z,k=b.x,T=b.y,A=b.xCenter,M=b.yCenter,S=a.traceIs(_,\"contour\"),E=S?\"best\":_.zsmooth,C=w.length,L=o.maxRowLength(w),P=!1,O=!1;for(y=0;void 0===r&&y<k.length-1;)r=p.c2p(k[y]),y++;for(y=k.length-1;void 0===f&&y>0;)f=p.c2p(k[y]),y--;for(f<r&&(g=f,f=r,r=g,P=!0),y=0;void 0===v&&y<T.length-1;)v=d.c2p(T[y]),y++;for(y=T.length-1;void 0===m&&y>0;)m=d.c2p(T[y]),y--;if(m<v&&(g=v,v=m,m=g,O=!0),S&&(A=k,M=T,k=b.xfill,T=b.yfill),\"fast\"!==E){var z=\"best\"===E?0:.5;r=Math.max(-z*p._length,r),f=Math.min((1+z)*p._length,f),v=Math.max(-z*d._length,v),m=Math.min((1+z)*d._length,m)}var I=Math.round(f-r),D=Math.round(m-v);if(I<=0||D<=0){x.selectAll(\"image\").data([]).exit().remove()}else{var R,F;\"fast\"===E?(R=L,F=C):(R=I,F=D);var B=document.createElement(\"canvas\");B.width=R,B.height=F;var N,j,U=B.getContext(\"2d\"),V=s(_,{noNumericCheck:!0,returnArray:!0});\"fast\"===E?(N=P?function(t){return L-1-t}:o.identity,j=O?function(t){return C-1-t}:o.identity):(N=function(t){return o.constrain(Math.round(p.c2p(k[t])-r),0,I)},j=function(t){return o.constrain(Math.round(d.c2p(T[t])-v),0,D)});var q,H,G,Y,W,X=j(0),Z=[X,X],J=P?0:1,K=O?0:1,$=0,Q=0,tt=0,et=0;if(E){var rt,nt=0;try{rt=new Uint8Array(I*D*4)}catch(t){rt=new Array(I*D*4)}if(\"best\"===E){var it,at,ot,st=A||k,lt=M||T,ct=new Array(st.length),ut=new Array(lt.length),ht=new Array(I),ft=A?u:c,pt=M?u:c;for(y=0;y<st.length;y++)ct[y]=Math.round(p.c2p(st[y])-r);for(y=0;y<lt.length;y++)ut[y]=Math.round(d.c2p(lt[y])-v);for(y=0;y<I;y++)ht[y]=ft(y,ct);for(H=0;H<D;H++)for(at=w[(it=pt(H,ut)).bin0],ot=w[it.bin1],y=0;y<I;y++,nt+=4)h(rt,nt,W=Tt(at,ot,ht[y],it))}else for(H=0;H<C;H++)for(Y=w[H],Z=j(H),y=0;y<I;y++)W=kt(Y[y],1),h(rt,nt=4*(Z*I+N(y)),W);var dt=U.createImageData(I,D);try{dt.data.set(rt)}catch(t){var gt=dt.data,vt=gt.length;for(H=0;H<vt;H++)gt[H]=rt[H]}U.putImageData(dt,0,0)}else{var mt=_.xgap,yt=_.ygap,xt=Math.floor(mt/2),bt=Math.floor(yt/2);for(H=0;H<C;H++)if(Y=w[H],Z.reverse(),Z[K]=j(H+1),Z[0]!==Z[1]&&void 0!==Z[0]&&void 0!==Z[1])for(q=[G=N(0),G],y=0;y<L;y++)q.reverse(),q[J]=N(y+1),q[0]!==q[1]&&void 0!==q[0]&&void 0!==q[1]&&(W=kt(Y[y],(q[1]-q[0])*(Z[1]-Z[0])),U.fillStyle=\"rgba(\"+W.join(\",\")+\")\",U.fillRect(q[0]+xt,Z[0]+bt,q[1]-q[0]-mt,Z[1]-Z[0]-yt))}Q=Math.round(Q/$),tt=Math.round(tt/$),et=Math.round(et/$);var _t=i(\"rgb(\"+Q+\",\"+tt+\",\"+et+\")\");t._hmpixcount=(t._hmpixcount||0)+$,t._hmlumcount=(t._hmlumcount||0)+$*_t.getLuminance();var wt=x.selectAll(\"image\").data(e);wt.enter().append(\"svg:image\").attr({xmlns:l.svg,preserveAspectRatio:\"none\"}),wt.attr({height:D,width:I,x:r,y:v,\"xlink:href\":B.toDataURL(\"image/png\")})}function kt(t,e){if(void 0!==t){var r=V(t);return r[0]=Math.round(r[0]),r[1]=Math.round(r[1]),r[2]=Math.round(r[2]),$+=e,Q+=r[0]*e,tt+=r[1]*e,et+=r[2]*e,r}return[0,0,0,0]}function Tt(t,e,r,n){var i=t[r.bin0];if(void 0===i)return kt(void 0,1);var a,o=t[r.bin1],s=e[r.bin0],l=e[r.bin1],c=o-i||0,u=s-i||0;return a=void 0===o?void 0===l?0:void 0===s?2*(l-i):2*(2*l-s-i)/3:void 0===l?void 0===s?0:2*(2*i-o-s)/3:void 0===s?2*(2*l-o-i)/3:l+i-o-s,kt(i+r.frac*c+n.frac*(u+r.frac*a))}})}},{\"../../components/colorscale\":605,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../registry\":847,d3:163,tinycolor2:537}],1013:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t){n.select(t).selectAll(\".hm image\").style(\"opacity\",function(t){return t.trace.opacity})}},{d3:163}],1014:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){!1===r(\"zsmooth\")&&(r(\"xgap\"),r(\"ygap\")),r(\"zhoverformat\")}},{}],1015:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\");function o(t,e){var r=e(t);return\"scaled\"===(r?e(t+\"type\",\"array\"):\"scaled\")&&(e(t+\"0\"),e(\"d\"+t)),r}e.exports=function(t,e,r,s,l,c){var u,h,f=r(\"z\");if(l=l||\"x\",c=c||\"y\",void 0===f||!f.length)return 0;if(i.isArray1D(t.z)){u=r(l),h=r(c);var p=i.minRowLength(u),d=i.minRowLength(h);if(0===p||0===d)return 0;e._length=Math.min(p,d,f.length)}else{if(u=o(l,r),h=o(c,r),!function(t){for(var e,r=!0,a=!1,o=!1,s=0;s<t.length;s++){if(e=t[s],!i.isArrayOrTypedArray(e)){r=!1;break}e.length>0&&(a=!0);for(var l=0;l<e.length;l++)if(n(e[l])){o=!0;break}}return r&&a&&o}(f))return 0;r(\"transpose\"),e._length=null}return a.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[l,c],s),!0}},{\"../../lib\":719,\"../../registry\":847,\"fast-isnumeric\":225}],1016:[function(t,e,r){\"use strict\";for(var n=t(\"../heatmap/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=[\"z\",\"x\",\"x0\",\"dx\",\"y\",\"y0\",\"dy\",\"text\",\"transpose\",\"xtype\",\"ytype\"],l={},c=0;c<s.length;c++){var u=s[c];l[u]=n[u]}a(l,i(\"\",{cLetter:\"z\",autoColorDflt:!1})),e.exports=o(l,\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../heatmap/attributes\":1001}],1017:[function(t,e,r){\"use strict\";var n=t(\"gl-heatmap2d\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib/str2rgbarray\");function o(t,e){this.scene=t,this.uid=e,this.type=\"heatmapgl\",this.name=\"\",this.hoverinfo=\"all\",this.xData=[],this.yData=[],this.zData=[],this.textLabels=[],this.idToIndex=[],this.bounds=[0,0,0,0],this.options={z:[],x:[],y:[],shape:[0,0],colorLevels:[0],colorValues:[0,0,0,1]},this.heatmap=n(t.glplot,this.options),this.heatmap._trace=this}var s=o.prototype;s.handlePick=function(t){var e=this.options,r=e.shape,n=t.pointId,i=n%r[0],a=Math.floor(n/r[0]),o=n;return{trace:this,dataCoord:t.dataCoord,traceCoord:[e.x[i],e.y[a],e.z[o]],textLabel:this.textLabels[n],name:this.name,pointIndex:[a,i],hoverinfo:this.hoverinfo}},s.update=function(t,e){var r=e[0];this.index=t.index,this.name=t.name,this.hoverinfo=t.hoverinfo;var n=r.z;this.options.z=[].concat.apply([],n);var o=n[0].length,s=n.length;this.options.shape=[o,s],this.options.x=r.x,this.options.y=r.y;var l=function(t){for(var e=t.colorscale,r=t.zmin,n=t.zmax,i=e.length,o=new Array(i),s=new Array(4*i),l=0;l<i;l++){var c=e[l],u=a(c[1]);o[l]=r+c[0]*(n-r);for(var h=0;h<4;h++)s[4*l+h]=u[h]}return{colorLevels:o,colorValues:s}}(t);this.options.colorLevels=l.colorLevels,this.options.colorValues=l.colorValues,this.textLabels=[].concat.apply([],t.text),this.heatmap.update(this.options);var c=this.scene.xaxis,u=this.scene.yaxis;t._extremes[c._id]=i.findExtremes(c,r.x),t._extremes[u._id]=i.findExtremes(u,r.y)},s.dispose=function(){this.heatmap.dispose()},e.exports=function(t,e,r){var n=new o(t,e.uid);return n.update(e,r),n}},{\"../../lib/str2rgbarray\":742,\"../../plots/cartesian/axes\":767,\"gl-heatmap2d\":251}],1018:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"../heatmap/defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../heatmap/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"heatmapgl\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"2dMap\"],meta:{}}},{\"../../plots/gl2d\":805,\"../heatmap/calc\":1002,\"../heatmap/colorbar\":1004,\"../heatmap/defaults\":1006,\"./attributes\":1016,\"./convert\":1017}],1019:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"./bin_attributes\"),o=t(\"./constants\"),s=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),orientation:n.orientation,histfunc:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"min\",\"max\"],dflt:\"count\",editType:\"calc\"},histnorm:{valType:\"enumerated\",values:[\"\",\"percent\",\"probability\",\"density\",\"probability density\"],dflt:\"\",editType:\"calc\"},cumulative:{enabled:{valType:\"boolean\",dflt:!1,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"increasing\",\"decreasing\"],dflt:\"increasing\",editType:\"calc\"},currentbin:{valType:\"enumerated\",values:[\"include\",\"exclude\",\"half\"],dflt:\"include\",editType:\"calc\"},editType:\"calc\"},nbinsx:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},xbins:a(\"x\",!0),nbinsy:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},ybins:a(\"y\",!0),autobinx:{valType:\"boolean\",dflt:null,editType:\"calc\"},autobiny:{valType:\"boolean\",dflt:null,editType:\"calc\"},bingroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:i({},{keys:o.eventDataKeys}),marker:n.marker,offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,_deprecated:{bardir:n._deprecated.bardir}}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../bar/attributes\":857,\"./bin_attributes\":1021,\"./constants\":1025}],1020:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=t.length,n=0,i=0;i<r;i++)e[i]?(t[i]/=e[i],n+=t[i]):t[i]=null;return n}},{}],1021:[function(t,e,r){\"use strict\";e.exports=function(t,e){return{start:{valType:\"any\",editType:\"calc\"},end:{valType:\"any\",editType:\"calc\"},size:{valType:\"any\",editType:\"calc\"},editType:\"calc\"}}},{}],1022:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports={count:function(t,e,r){return r[t]++,1},sum:function(t,e,r,i){var a=i[e];return n(a)?(a=Number(a),r[t]+=a,a):0},avg:function(t,e,r,i,a){var o=i[e];return n(o)&&(o=Number(o),r[t]+=o,a[t]++),0},min:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]>a){var o=a-r[t];return r[t]=a,o}}return 0},max:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]<a){var o=a-r[t];return r[t]=a,o}}return 0}}},{\"fast-isnumeric\":225}],1023:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.ONEAVGYEAR,a=n.ONEAVGMONTH,o=n.ONEDAY,s=n.ONEHOUR,l=n.ONEMIN,c=n.ONESEC,u=t(\"../../plots/cartesian/axes\").tickIncrement;function h(t,e,r,n){if(t*e<=0)return 1/0;for(var i=Math.abs(e-t),a=\"date\"===r.type,o=f(i,a),s=0;s<10;s++){var l=f(80*o,a);if(o===l)break;if(!p(l,t,e,a,r,n))break;o=l}return o}function f(t,e){return e&&t>c?t>o?t>1.1*i?i:t>1.1*a?a:o:t>s?s:t>l?l:c:Math.pow(10,Math.floor(Math.log(t)/Math.LN10))}function p(t,e,r,n,a,s){if(n&&t>o){var l=d(e,a,s),c=d(r,a,s),u=t===i?0:1;return l[u]!==c[u]}return Math.floor(r/t)-Math.floor(e/t)>.1}function d(t,e,r){var n=e.c2d(t,i,r).split(\"-\");return\"\"===n[0]&&(n.unshift(),n[0]=\"-\"+n[0]),n}e.exports=function(t,e,r,n,a){var s,l,c=-1.1*e,f=-.1*e,p=t-f,d=r[0],g=r[1],v=Math.min(h(d+f,d+p,n,a),h(g+f,g+p,n,a)),m=Math.min(h(d+c,d+f,n,a),h(g+c,g+f,n,a));if(v>m&&m<Math.abs(g-d)/4e3?(s=v,l=!1):(s=Math.min(v,m),l=!0),\"date\"===n.type&&s>o){var y=s===i?1:6,x=s===i?\"M12\":\"M1\";return function(e,r){var o=n.c2d(e,i,a),s=o.indexOf(\"-\",y);s>0&&(o=o.substr(0,s));var c=n.d2c(o,0,a);if(c<e){var h=u(c,x,!1,a);(c+h)/2<e+t&&(c=h)}return r&&l?u(c,x,!0,a):c}}return function(e,r){var n=s*Math.round(e/s);return n+s/10<e&&n+.9*s<e+t&&(n+=s),r&&l&&(n-=s),n}}},{\"../../constants/numerical\":695,\"../../plots/cartesian/axes\":767}],1024:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../bar/arrays_to_calcdata\"),l=t(\"./bin_functions\"),c=t(\"./norm_functions\"),u=t(\"./average\"),h=t(\"./bin_label_vals\");function f(t,e,r,s,l){var c,u,h,p,d,g,v,m=s+\"bins\",y=t._fullLayout,x=e[\"_\"+s+\"bingroup\"],b=y._histogramBinOpts[x],_=\"overlay\"===y.barmode,w=function(t){return r.r2c(t,0,p)},k=function(t){return r.c2r(t,0,p)},T=\"date\"===r.type?function(t){return t||0===t?i.cleanDate(t,null,p):null}:function(t){return n(t)?Number(t):null};function A(t,e,r){e[t+\"Found\"]?(e[t]=T(e[t]),null===e[t]&&(e[t]=r[t])):(g[t]=e[t]=r[t],i.nestedProperty(u[0],m+\".\"+t).set(r[t]))}if(e[\"_\"+s+\"autoBinFinished\"])delete e[\"_\"+s+\"autoBinFinished\"];else{u=b.traces;var M=[],S=!0,E=!1,C=!1;for(c=0;c<u.length;c++)if((h=u[c]).visible){var L=b.dirs[c];d=h[\"_\"+L+\"pos0\"]=r.makeCalcdata(h,L),M=i.concat(M,d),delete h[\"_\"+s+\"autoBinFinished\"],!0===e.visible&&(S?S=!1:(delete h._autoBin,h[\"_\"+s+\"autoBinFinished\"]=1),a.traceIs(h,\"2dMap\")&&(E=!0),\"histogram2dcontour\"===h.type&&(C=!0))}p=u[0][s+\"calendar\"];var P=o.autoBin(M,r,b.nbins,E,p,b.sizeFound&&b.size),O=u[0]._autoBin={};if(g=O[b.dirs[0]]={},C&&(b.size||(P.start=k(o.tickIncrement(w(P.start),P.size,!0,p))),void 0===b.end&&(P.end=k(o.tickIncrement(w(P.end),P.size,!1,p)))),_&&!a.traceIs(e,\"2dMap\")&&0===P._dataSpan&&\"category\"!==r.type&&\"multicategory\"!==r.type){if(l)return[P,d,!0];P=function(t,e,r,n,a){var o,s,l,c=t._fullLayout,u=function(t,e){for(var r=e.xaxis,n=e.yaxis,i=e.orientation,a=[],o=t._fullData,s=0;s<o.length;s++){var l=o[s];\"histogram\"===l.type&&!0===l.visible&&l.orientation===i&&l.xaxis===r&&l.yaxis===n&&a.push(l)}return a}(t,e),h=!1,p=1/0,d=[e];for(o=0;o<u.length;o++)if((s=u[o])===e)h=!0;else if(h){var g=f(t,s,r,n,!0),v=g[0],m=g[2];s[\"_\"+n+\"autoBinFinished\"]=1,s[\"_\"+n+\"pos0\"]=g[1],m?d.push(s):p=Math.min(p,v.size)}else l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]],p=Math.min(p,l.size||s[a].size);var y=new Array(d.length);for(o=0;o<d.length;o++)for(var x=d[o][\"_\"+n+\"pos0\"],b=0;b<x.length;b++)if(void 0!==x[b]){y[o]=x[b];break}isFinite(p)||(p=i.distinctVals(y).minDiff);for(o=0;o<d.length;o++){var _=(s=d[o])[n+\"calendar\"],w={start:r.c2r(y[o]-p/2,0,_),end:r.c2r(y[o]+p/2,0,_),size:p};s._input[a]=s[a]=w,(l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]])&&i.extendFlat(l,w)}return e[a]}(t,e,r,s,m)}(v=h.cumulative||{}).enabled&&\"include\"!==v.currentbin&&(\"decreasing\"===v.direction?P.start=k(o.tickIncrement(w(P.start),P.size,!0,p)):P.end=k(o.tickIncrement(w(P.end),P.size,!1,p))),b.size=P.size,b.sizeFound||(g.size=P.size,i.nestedProperty(u[0],m+\".size\").set(P.size)),A(\"start\",b,P),A(\"end\",b,P)}d=e[\"_\"+s+\"pos0\"],delete e[\"_\"+s+\"pos0\"];var z=e._input[m]||{},I=i.extendFlat({},b),D=b.start,R=r.r2l(z.start),F=void 0!==R;if((b.startFound||F)&&R!==r.r2l(D)){var B=F?R:i.aggNums(Math.min,null,d),N={type:\"category\"===r.type||\"multicategory\"===r.type?\"linear\":r.type,r2l:r.r2l,dtick:b.size,tick0:D,calendar:p,range:[B,o.tickIncrement(B,b.size,!1,p)].map(r.l2r)},j=o.tickFirst(N);j>r.r2l(B)&&(j=o.tickIncrement(j,b.size,!0,p)),I.start=r.l2r(j),F||i.nestedProperty(e,m+\".start\").set(I.start)}var U=b.end,V=r.r2l(z.end),q=void 0!==V;if((b.endFound||q)&&V!==r.r2l(U)){var H=q?V:i.aggNums(Math.max,null,d);I.end=r.l2r(H),q||i.nestedProperty(e,m+\".start\").set(I.end)}var G=\"autobin\"+s;return!1===e._input[G]&&(e._input[m]=i.extendFlat({},e[m]||{}),delete e._input[G],delete e[G]),[I,d]}e.exports={calc:function(t,e){var r,a,p,d,g=[],v=[],m=o.getFromId(t,\"h\"===e.orientation?e.yaxis:e.xaxis),y=\"h\"===e.orientation?\"y\":\"x\",x={x:\"y\",y:\"x\"}[y],b=e[y+\"calendar\"],_=e.cumulative,w=f(t,e,m,y),k=w[0],T=w[1],A=\"string\"==typeof k.size,M=[],S=A?M:k,E=[],C=[],L=[],P=0,O=e.histnorm,z=e.histfunc,I=-1!==O.indexOf(\"density\");_.enabled&&I&&(O=O.replace(/ ?density$/,\"\"),I=!1);var D,R=\"max\"===z||\"min\"===z?null:0,F=l.count,B=c[O],N=!1,j=function(t){return m.r2c(t,0,b)};for(i.isArrayOrTypedArray(e[x])&&\"count\"!==z&&(D=e[x],N=\"avg\"===z,F=l[z]),r=j(k.start),p=j(k.end)+(r-o.tickIncrement(r,k.size,!1,b))/1e6;r<p&&g.length<1e6&&(a=o.tickIncrement(r,k.size,!1,b),g.push((r+a)/2),v.push(R),L.push([]),M.push(r),I&&E.push(1/(a-r)),N&&C.push(0),!(a<=r));)r=a;M.push(r),A||\"date\"!==m.type||(S={start:j(S.start),end:j(S.end),size:S.size});var U,V=v.length,q=!0,H=1/0,G=1/0,Y={};for(r=0;r<T.length;r++){var W=T[r];(d=i.findBin(W,S))>=0&&d<V&&(P+=F(d,r,v,D,C),q&&L[d].length&&W!==T[L[d][0]]&&(q=!1),L[d].push(r),Y[r]=d,H=Math.min(H,W-M[d]),G=Math.min(G,M[d+1]-W))}q||(U=h(H,G,M,m,b)),N&&(P=u(v,C)),B&&B(v,P,E),_.enabled&&function(t,e,r){var n,i,a;function o(e){a=t[e],t[e]/=2}function s(e){i=t[e],t[e]=a+i/2,a+=i}if(\"half\"===r)if(\"increasing\"===e)for(o(0),n=1;n<t.length;n++)s(n);else for(o(t.length-1),n=t.length-2;n>=0;n--)s(n);else if(\"increasing\"===e){for(n=1;n<t.length;n++)t[n]+=t[n-1];\"exclude\"===r&&(t.unshift(0),t.pop())}else{for(n=t.length-2;n>=0;n--)t[n]+=t[n+1];\"exclude\"===r&&(t.push(0),t.shift())}}(v,_.direction,_.currentbin);var X=Math.min(g.length,v.length),Z=[],J=0,K=X-1;for(r=0;r<X;r++)if(v[r]){J=r;break}for(r=X-1;r>=J;r--)if(v[r]){K=r;break}for(r=J;r<=K;r++)if(n(g[r])&&n(v[r])){var $={p:g[r],s:v[r],b:0};_.enabled||($.pts=L[r],q?$.ph0=$.ph1=L[r].length?T[L[r][0]]:g[r]:($.ph0=U(M[r]),$.ph1=U(M[r+1],!0))),Z.push($)}return 1===Z.length&&(Z[0].width1=o.tickIncrement(Z[0].p,k.size,!1,b)-Z[0].p),s(Z,e),i.isArrayOrTypedArray(e.selectedpoints)&&i.tagSelected(Z,e,Y),Z},calcAllAutoBins:f}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../bar/arrays_to_calcdata\":856,\"./average\":1020,\"./bin_functions\":1022,\"./bin_label_vals\":1023,\"./norm_functions\":1031,\"fast-isnumeric\":225}],1025:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"binNumber\"]}},{}],1026:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../../registry\").traceIs,o=t(\"../bar/defaults\").handleGroupingDefaults,s=n.nestedProperty,l=i.getAxisGroup,c=[{aStr:{x:\"xbins.start\",y:\"ybins.start\"},name:\"start\"},{aStr:{x:\"xbins.end\",y:\"ybins.end\"},name:\"end\"},{aStr:{x:\"xbins.size\",y:\"ybins.size\"},name:\"size\"},{aStr:{x:\"nbinsx\",y:\"nbinsy\"},name:\"nbins\"}],u=[\"x\",\"y\"];e.exports=function(t,e){var r,h,f,p,d,g,v,m=e._histogramBinOpts={},y=[],x={},b=[];function _(t,e){return n.coerce(r._input,r,r._module.attributes,t,e)}function w(t){return\"v\"===t.orientation?\"x\":\"y\"}function k(t,r,a){var o=t.uid+\"__\"+a;r||(r=o);var s=function(t,r){return i.getFromTrace({_fullLayout:e},t,r).type}(t,a),l=t[a+\"calendar\"],c=m[r],u=!0;c&&(s===c.axType&&l===c.calendar?(u=!1,c.traces.push(t),c.dirs.push(a)):(r=o,s!==c.axType&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set on a\",\"type:\"+s,\"axis\",\"with bins on\",\"type:\"+c.axType,\"axis.\"].join(\" \")),l!==c.calendar&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set with a\",l,\"calendar\",\"with bins\",c.calendar?\"on a \"+c.calendar+\" calendar\":\"w/o a set calendar\"].join(\" \")))),u&&(m[r]={traces:[t],dirs:[a],axType:s,calendar:t[a+\"calendar\"]||\"\"}),t[\"_\"+a+\"bingroup\"]=r}for(d=0;d<t.length;d++)r=t[d],a(r,\"histogram\")&&(y.push(r),delete r._xautoBinFinished,delete r._yautoBinFinished,a(r,\"2dMap\")||o(r._input,r,e,_));var T=e._alignmentOpts||{};for(d=0;d<y.length;d++){if(r=y[d],f=\"\",!a(r,\"2dMap\")){if(p=w(r),\"group\"===e.barmode&&r.alignmentgroup){var A=r[p+\"axis\"],M=l(e,A)+r.orientation;(T[M]||{})[r.alignmentgroup]&&(f=M)}f||\"overlay\"===e.barmode||(f=l(e,r.xaxis)+l(e,r.yaxis)+w(r))}f?(x[f]||(x[f]=[]),x[f].push(r)):b.push(r)}for(f in x)if(1!==(h=x[f]).length){var S=!1;for(d=0;d<h.length;d++){r=h[d],S=_(\"bingroup\");break}for(f=S||f,d=0;d<h.length;d++){var E=(r=h[d])._input.bingroup;E&&E!==f&&n.warn([\"Trace\",r.index,\"must match\",\"within bingroup\",f+\".\",\"Ignoring its bingroup:\",E,\"setting.\"].join(\" \")),r.bingroup=f,k(r,f,w(r))}}else b.push(h[0]);for(d=0;d<b.length;d++){r=b[d];var C=_(\"bingroup\");if(a(r,\"2dMap\"))for(v=0;v<2;v++){var L=_((p=u[v])+\"bingroup\",C?C+\"__\"+p:null);k(r,L,p)}else k(r,C,w(r))}for(f in m){var P=m[f];for(h=P.traces,g=0;g<c.length;g++){var O,z,I=c[g],D=I.name;if(\"nbins\"!==D||!P.sizeFound){for(d=0;d<h.length;d++){if(r=h[d],p=P.dirs[d],O=I.aStr[p],void 0!==s(r._input,O).get()){P[D]=_(O),P[D+\"Found\"]=!0;break}(z=(r._autoBin||{})[p]||{})[D]&&s(r,O).set(z[D])}if(\"start\"===D||\"end\"===D)for(;d<h.length;d++)(r=h[d])[\"_\"+p+\"bingroup\"]&&_(O,(z=(r._autoBin||{})[p]||{})[D]);\"nbins\"!==D||P.sizeFound||P.nbinsFound||(r=h[0],P[D]=_(O))}}}}},{\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../bar/defaults\":861}],1027:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../bar/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,n){return i.coerce(t,e,s,r,n)}var u=c(\"x\"),h=c(\"y\");c(\"cumulative.enabled\")&&(c(\"cumulative.direction\"),c(\"cumulative.currentbin\")),c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\");var f=c(\"orientation\",h&&!u?\"h\":\"v\"),p=\"v\"===f?\"x\":\"y\",d=\"v\"===f?\"y\":\"x\",g=u&&h?Math.min(i.minRowLength(u)&&i.minRowLength(h)):i.minRowLength(e[p]||[]);if(g){e._length=g,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],l),e[d]&&c(\"histfunc\"),c(\"histnorm\"),c(\"autobin\"+p),o(t,e,c,r,l),i.coerceSelectionMarkerOpacity(e,c);var v=(e.marker.line||{}).color,m=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");m(t,e,v||a.defaultLine,{axis:\"y\"}),m(t,e,v||a.defaultLine,{axis:\"x\",inherit:\"y\"})}else e.visible=!1}},{\"../../components/color\":593,\"../../lib\":719,\"../../registry\":847,\"../bar/style_defaults\":871,\"./attributes\":1019}],1028:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"zLabelVal\"in e&&(t.z=e.zLabelVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),!(r.cumulative||{}).enabled){var a,o=Array.isArray(i)?n[0].pts[i[0]][i[1]]:n[i].pts;if(t.pointNumbers=o,t.binNumber=t.pointNumber,delete t.pointNumber,delete t.pointIndex,r._indexToPoints){a=[];for(var s=0;s<o.length;s++)a=a.concat(r._indexToPoints[o[s]])}else a=o;t.pointIndices=a}return t}},{}],1029:[function(t,e,r){\"use strict\";var n=t(\"../bar/hover\").hoverPoints,i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o){var s=(t=o[0]).cd[t.index],l=t.cd[0].trace;if(!l.cumulative.enabled){var c=\"h\"===l.orientation?\"y\":\"x\";t[c+\"Label\"]=i(t[c+\"a\"],s.ph0,s.ph1)}return l.hovermplate&&(t.hovertemplate=l.hovertemplate),o}}},{\"../../plots/cartesian/axes\":767,\"../bar/hover\":863}],1030:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"../bar/layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),supplyLayoutDefaults:t(\"../bar/layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"../bar/cross_trace_calc\").crossTraceCalc,plot:t(\"../bar/plot\").plot,layerName:\"barlayer\",style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,colorbar:t(\"../scatter/marker_colorbar\"),hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"histogram\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"histogram\",\"oriented\",\"errorBarsOK\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":778,\"../bar/cross_trace_calc\":860,\"../bar/layout_attributes\":865,\"../bar/layout_defaults\":866,\"../bar/plot\":867,\"../bar/select\":868,\"../bar/style\":870,\"../scatter/marker_colorbar\":1129,\"./attributes\":1019,\"./calc\":1024,\"./cross_trace_defaults\":1026,\"./defaults\":1027,\"./event_data\":1028,\"./hover\":1029}],1031:[function(t,e,r){\"use strict\";e.exports={percent:function(t,e){for(var r=t.length,n=100/e,i=0;i<r;i++)t[i]*=n},probability:function(t,e){for(var r=t.length,n=0;n<r;n++)t[n]/=e},density:function(t,e,r,n){var i=t.length;n=n||1;for(var a=0;a<i;a++)t[a]*=r[a]*n},\"probability density\":function(t,e,r,n){var i=t.length;n&&(e/=n);for(var a=0;a<i;a++)t[a]*=r[a]/e}}},{}],1032:[function(t,e,r){\"use strict\";var n=t(\"../histogram/attributes\"),i=t(\"../histogram/bin_attributes\"),a=t(\"../heatmap/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../lib/extend\").extendFlat;e.exports=l({x:n.x,y:n.y,z:{valType:\"data_array\",editType:\"calc\"},marker:{color:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:i(\"x\"),nbinsy:n.nbinsy,ybins:i(\"y\"),autobinx:n.autobinx,autobiny:n.autobiny,bingroup:l({},n.bingroup,{}),xbingroup:l({},n.bingroup,{}),ybingroup:l({},n.bingroup,{}),xgap:a.xgap,ygap:a.ygap,zsmooth:a.zsmooth,zhoverformat:a.zhoverformat,hovertemplate:o({},{keys:\"z\"})},s(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../heatmap/attributes\":1001,\"../histogram/attributes\":1019,\"../histogram/bin_attributes\":1021}],1033:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../histogram/bin_functions\"),o=t(\"../histogram/norm_functions\"),s=t(\"../histogram/average\"),l=t(\"../histogram/bin_label_vals\"),c=t(\"../histogram/calc\").calcAllAutoBins;function u(t,e,r,n){var i,a=new Array(t);if(n)for(i=0;i<t;i++)a[i]=1/(e[i+1]-e[i]);else{var o=1/r;for(i=0;i<t;i++)a[i]=o}return a}function h(t,e){return{start:t(e.start),end:t(e.end),size:e.size}}function f(t,e,r,n,i,a){var o,s=t.length-1,c=new Array(s),u=l(r,n,t,i,a);for(o=0;o<s;o++){var h=(e||[])[o];c[o]=void 0===h?[u(t[o]),u(t[o+1],!0)]:[h,h]}return c}e.exports=function(t,e){var r,l,p,d,g=i.getFromId(t,e.xaxis),v=i.getFromId(t,e.yaxis),m=e.xcalendar,y=e.ycalendar,x=function(t){return g.r2c(t,0,m)},b=function(t){return v.r2c(t,0,y)},_=c(t,e,g,\"x\"),w=_[0],k=_[1],T=c(t,e,v,\"y\"),A=T[0],M=T[1],S=e._length;k.length>S&&k.splice(S,k.length-S),M.length>S&&M.splice(S,M.length-S);var E=[],C=[],L=[],P=\"string\"==typeof w.size,O=\"string\"==typeof A.size,z=[],I=[],D=P?z:w,R=O?I:A,F=0,B=[],N=[],j=e.histnorm,U=e.histfunc,V=-1!==j.indexOf(\"density\"),q=\"max\"===U||\"min\"===U?null:0,H=a.count,G=o[j],Y=!1,W=[],X=[],Z=\"z\"in e?e.z:\"marker\"in e&&Array.isArray(e.marker.color)?e.marker.color:\"\";Z&&\"count\"!==U&&(Y=\"avg\"===U,H=a[U]);var J=w.size,K=x(w.start),$=x(w.end)+(K-i.tickIncrement(K,J,!1,m))/1e6;for(r=K;r<$;r=i.tickIncrement(r,J,!1,m))C.push(q),z.push(r),Y&&L.push(0);z.push(r);var Q,tt=C.length,et=(r-K)/tt,rt=(Q=K+et/2,g.c2r(Q,0,m)),nt=A.size,it=b(A.start),at=b(A.end)+(it-i.tickIncrement(it,nt,!1,y))/1e6;for(r=it;r<at;r=i.tickIncrement(r,nt,!1,y)){E.push(C.slice()),I.push(r);var ot=new Array(tt);for(l=0;l<tt;l++)ot[l]=[];N.push(ot),Y&&B.push(L.slice())}I.push(r);var st=E.length,lt=(r-it)/st,ct=function(t){return v.c2r(t,0,y)}(it+lt/2);V&&(W=u(C.length,D,et,P),X=u(E.length,R,lt,O)),P||\"date\"!==g.type||(D=h(x,D)),O||\"date\"!==v.type||(R=h(b,R));var ut=!0,ht=!0,ft=new Array(tt),pt=new Array(st),dt=1/0,gt=1/0,vt=1/0,mt=1/0;for(r=0;r<S;r++){var yt=k[r],xt=M[r];p=n.findBin(yt,D),d=n.findBin(xt,R),p>=0&&p<tt&&d>=0&&d<st&&(F+=H(p,r,E[d],Z,B[d]),N[d][p].push(r),ut&&(void 0===ft[p]?ft[p]=yt:ft[p]!==yt&&(ut=!1)),ht&&(void 0===pt[d]?pt[d]=xt:pt[d]!==xt&&(ht=!1)),dt=Math.min(dt,yt-z[p]),gt=Math.min(gt,z[p+1]-yt),vt=Math.min(vt,xt-I[d]),mt=Math.min(mt,I[d+1]-xt))}if(Y)for(d=0;d<st;d++)F+=s(E[d],B[d]);if(G)for(d=0;d<st;d++)G(E[d],F,W,X[d]);return{x:k,xRanges:f(z,ut&&ft,dt,gt,g,m),x0:rt,dx:et,y:M,yRanges:f(I,ht&&pt,vt,mt,v,y),y0:ct,dy:lt,z:E,pts:N}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../histogram/average\":1020,\"../histogram/bin_functions\":1022,\"../histogram/bin_label_vals\":1023,\"../histogram/calc\":1024,\"../histogram/norm_functions\":1031}],1034:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./sample_defaults\"),a=t(\"../heatmap/style_defaults\"),o=t(\"../../components/colorscale/defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,l),o(t,e,l,c,{prefix:\"\",cLetter:\"z\"}),c(\"hovertemplate\"))}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../heatmap/style_defaults\":1014,\"./attributes\":1032,\"./sample_defaults\":1037}],1035:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/hover\"),i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a,o,s){var l=n(t,e,r,a,o,s);if(l){var c=(t=l[0]).index,u=c[0],h=c[1],f=t.cd[0],p=f.xRanges[h],d=f.yRanges[u];return t.xLabel=i(t.xa,p[0],p[1]),t.yLabel=i(t.ya,d[0],d[1]),l}}},{\"../../plots/cartesian/axes\":767,\"../heatmap/hover\":1008}],1036:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../heatmap/calc\"),plot:t(\"../heatmap/plot\"),layerName:\"heatmaplayer\",colorbar:t(\"../heatmap/colorbar\"),style:t(\"../heatmap/style\"),hoverPoints:t(\"./hover\"),eventData:t(\"../histogram/event_data\"),moduleType:\"trace\",name:\"histogram2d\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"histogram\"],meta:{}}},{\"../../plots/cartesian\":778,\"../heatmap/calc\":1002,\"../heatmap/colorbar\":1004,\"../heatmap/plot\":1012,\"../heatmap/style\":1013,\"../histogram/cross_trace_defaults\":1026,\"../histogram/event_data\":1028,\"./attributes\":1032,\"./defaults\":1034,\"./hover\":1035}],1037:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"y\"),l=i.minRowLength(o),c=i.minRowLength(s);l&&c?(e._length=Math.min(l,c),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a),(r(\"z\")||r(\"marker.color\"))&&r(\"histfunc\"),r(\"histnorm\"),r(\"autobinx\"),r(\"autobiny\")):e.visible=!1}},{\"../../lib\":719,\"../../registry\":847}],1038:[function(t,e,r){\"use strict\";var n=t(\"../histogram2d/attributes\"),i=t(\"../contour/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat;e.exports=o({x:n.x,y:n.y,z:n.z,marker:n.marker,histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:n.xbins,nbinsy:n.nbinsy,ybins:n.ybins,autobinx:n.autobinx,autobiny:n.autobiny,bingroup:n.bingroup,xbingroup:n.xbingroup,ybingroup:n.ybingroup,autocontour:i.autocontour,ncontours:i.ncontours,contours:i.contours,line:i.line,zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../contour/attributes\":942,\"../histogram2d/attributes\":1032}],1039:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../histogram2d/sample_defaults\"),a=t(\"../contour/contours_defaults\"),o=t(\"../contour/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,function(r){return n.coerce2(t,e,s,r)}),o(t,e,c,l),c(\"hovertemplate\"))}},{\"../../lib\":719,\"../contour/contours_defaults\":949,\"../contour/style_defaults\":963,\"../histogram2d/sample_defaults\":1037,\"./attributes\":1038}],1040:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../contour/calc\"),plot:t(\"../contour/plot\").plot,layerName:\"contourlayer\",style:t(\"../contour/style\"),colorbar:t(\"../contour/colorbar\"),hoverPoints:t(\"../contour/hover\"),moduleType:\"trace\",name:\"histogram2dcontour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"histogram\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":778,\"../contour/calc\":943,\"../contour/colorbar\":945,\"../contour/hover\":955,\"../contour/plot\":960,\"../contour/style\":962,\"../histogram/cross_trace_defaults\":1026,\"./attributes\":1038,\"./defaults\":1039}],1041:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../lib/extend\").extendDeep,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../components/color/attributes\"),l=t(\"../../plots/domain\").attributes,c=t(\"../../plots/cartesian/layout_attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,h=t(\"../../constants/delta.js\"),f=(t(\"../../constants/docs\").FORMAT_LINK,o({editType:\"plot\",colorEditType:\"plot\"})),p={color:{valType:\"color\",editType:\"plot\"},line:{color:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},width:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"calc\"},thickness:{valType:\"number\",min:0,max:1,dflt:1,editType:\"plot\"},editType:\"calc\"},d={valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},g=u(\"steps\",i({},p,{range:d}));e.exports={mode:{valType:\"flaglist\",editType:\"calc\",flags:[\"number\",\"delta\",\"gauge\"],dflt:\"number\"},value:{valType:\"number\",editType:\"calc\",anim:!0},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},domain:l({name:\"indicator\",trace:!0,editType:\"calc\"}),title:{text:{valType:\"string\",editType:\"plot\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},font:n({},f,{}),editType:\"plot\"},number:{valueformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:n({},f,{}),prefix:{valType:\"string\",dflt:\"\",editType:\"plot\"},suffix:{valType:\"string\",dflt:\"\",editType:\"plot\"},editType:\"plot\"},delta:{reference:{valType:\"number\",editType:\"calc\"},position:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],dflt:\"bottom\",editType:\"plot\"},relative:{valType:\"boolean\",editType:\"plot\",dflt:!1},valueformat:{valType:\"string\",editType:\"plot\"},increasing:{symbol:{valType:\"string\",dflt:h.INCREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:h.INCREASING.COLOR,editType:\"plot\"},editType:\"plot\"},decreasing:{symbol:{valType:\"string\",dflt:h.DECREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:h.DECREASING.COLOR,editType:\"plot\"},editType:\"plot\"},font:n({},f,{}),editType:\"calc\"},gauge:{shape:{valType:\"enumerated\",editType:\"plot\",dflt:\"angular\",values:[\"angular\",\"bullet\"]},bar:i({},p,{color:{dflt:\"green\"}}),bgcolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},axis:a({range:d,visible:n({},c.visible,{dflt:!0}),tickmode:c.tickmode,nticks:c.nticks,tick0:c.tick0,dtick:c.dtick,tickvals:c.tickvals,ticktext:c.ticktext,ticks:n({},c.ticks,{dflt:\"outside\"}),ticklen:c.ticklen,tickwidth:c.tickwidth,tickcolor:c.tickcolor,showticklabels:c.showticklabels,tickfont:o({}),tickangle:c.tickangle,tickformat:c.tickformat,tickformatstops:c.tickformatstops,tickprefix:c.tickprefix,showtickprefix:c.showtickprefix,ticksuffix:c.ticksuffix,showticksuffix:c.showticksuffix,separatethousands:c.separatethousands,exponentformat:c.exponentformat,showexponent:c.showexponent,editType:\"plot\"},\"plot\"),steps:g,threshold:{line:{color:n({},p.line.color,{}),width:n({},p.line.width,{dflt:1}),editType:\"plot\"},thickness:n({},p.thickness,{dflt:.85}),value:{valType:\"number\",editType:\"calc\",dflt:!1},editType:\"plot\"},editType:\"plot\"}}},{\"../../components/color/attributes\":592,\"../../constants/delta.js\":689,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1042:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=r.name=\"indicator\";r.plot=function(t,e,r,o){var s=n.getModule(a),l=i(t.calcdata,s)[0];s.plot(t,l,r,o)},r.clean=function(t,e,r,n){var i=n._has&&n._has(a),o=e._has&&e._has(a);i&&!o&&n._indicatorlayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],1043:[function(t,e,r){\"use strict\";e.exports={calc:function(t,e){var r=[],n=e.value;\"number\"!=typeof e._lastValue&&(e._lastValue=e.value);var i=e._lastValue,a=i;return e._hasDelta&&\"number\"==typeof e.delta.reference&&(a=e.delta.reference),r[0]={y:n,lastY:i,delta:n-a,relativeDelta:(n-a)/a},r}}},{}],1044:[function(t,e,r){\"use strict\";e.exports={defaultNumberFontSize:80,bulletNumberDomainSize:.25,bulletPadding:.025,innerRadius:.75,valueThickness:.5,titlePadding:5,horizontalPadding:10}},{}],1045:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../../plot_api/plot_template\"),s=t(\"../../plots/array_container_defaults\"),l=t(\"./constants.js\"),c=t(\"../../plots/cartesian/tick_value_defaults\"),u=t(\"../../plots/cartesian/tick_mark_defaults\"),h=t(\"../../plots/cartesian/tick_label_defaults\");function f(t,e){function r(r,a){return n.coerce(t,e,i.gauge.steps,r,a)}r(\"color\"),r(\"line.color\"),r(\"line.width\"),r(\"range\"),r(\"thickness\")}e.exports={supplyDefaults:function(t,e,r,p){function d(r,a){return n.coerce(t,e,i,r,a)}a(e,p,d),d(\"mode\"),e._hasNumber=-1!==e.mode.indexOf(\"number\"),e._hasDelta=-1!==e.mode.indexOf(\"delta\"),e._hasGauge=-1!==e.mode.indexOf(\"gauge\");var g=d(\"value\");e._range=[0,\"number\"==typeof g?1.5*g:1];var v,m,y,x,b,_,w=new Array(2);function k(t,e){return n.coerce(y,x,i.gauge,t,e)}function T(t,e){return n.coerce(b,_,i.gauge.axis,t,e)}if(e._hasNumber&&(d(\"number.valueformat\"),d(\"number.font.color\",p.font.color),d(\"number.font.family\",p.font.family),d(\"number.font.size\"),void 0===e.number.font.size&&(e.number.font.size=l.defaultNumberFontSize,w[0]=!0),d(\"number.prefix\"),d(\"number.suffix\"),v=e.number.font.size),e._hasDelta&&(d(\"delta.font.color\",p.font.color),d(\"delta.font.family\",p.font.family),d(\"delta.font.size\"),void 0===e.delta.font.size&&(e.delta.font.size=(e._hasNumber?.5:1)*(v||l.defaultNumberFontSize),w[1]=!0),d(\"delta.reference\",e.value),d(\"delta.relative\"),d(\"delta.valueformat\",e.delta.relative?\"2%\":\"\"),d(\"delta.increasing.symbol\"),d(\"delta.increasing.color\"),d(\"delta.decreasing.symbol\"),d(\"delta.decreasing.color\"),d(\"delta.position\"),m=e.delta.font.size),e._scaleNumbers=(!e._hasNumber||w[0])&&(!e._hasDelta||w[1])||!1,d(\"title.font.color\",p.font.color),d(\"title.font.family\",p.font.family),d(\"title.font.size\",.25*(v||m||l.defaultNumberFontSize)),d(\"title.text\"),e._hasGauge){(y=t.gauge)||(y={}),x=o.newContainer(e,\"gauge\"),k(\"shape\"),(e._isBullet=\"bullet\"===e.gauge.shape)||d(\"title.align\",\"center\"),(e._isAngular=\"angular\"===e.gauge.shape)||d(\"align\",\"center\"),k(\"bgcolor\",p.paper_bgcolor),k(\"borderwidth\"),k(\"bordercolor\"),k(\"bar.color\"),k(\"bar.line.color\"),k(\"bar.line.width\"),k(\"bar.thickness\",l.valueThickness*(\"bullet\"===e.gauge.shape?.5:1)),s(y,x,{name:\"steps\",handleItemDefaults:f}),k(\"threshold.value\"),k(\"threshold.thickness\"),k(\"threshold.line.width\"),k(\"threshold.line.color\"),b={},y&&(b=y.axis||{}),_=o.newContainer(x,\"axis\"),T(\"visible\"),e._range=T(\"range\",e._range);var A={outerTicks:!0};c(b,_,T,\"linear\"),h(b,_,T,\"linear\",A),u(b,_,T,A)}else d(\"title.align\",\"center\"),d(\"align\",\"center\"),e._isAngular=e._isBullet=!1;e._length=null}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/tick_label_defaults\":786,\"../../plots/cartesian/tick_mark_defaults\":787,\"../../plots/cartesian/tick_value_defaults\":788,\"../../plots/domain\":792,\"./attributes\":1041,\"./constants.js\":1044}],1046:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"indicator\",basePlotModule:t(\"./base_plot\"),categories:[\"svg\",\"noOpacity\",\"noHover\"],animatable:!0,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\").calc,plot:t(\"./plot\"),meta:{}}},{\"./attributes\":1041,\"./base_plot\":1042,\"./calc\":1043,\"./defaults\":1045,\"./plot\":1047}],1047:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=i.rad2deg,o=t(\"../../constants/alignment\").MID_SHIFT,s=t(\"../../components/drawing\"),l=t(\"./constants\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"../../plots/cartesian/axes\"),h=t(\"../../plots/cartesian/axis_defaults\"),f=t(\"../../plots/cartesian/position_defaults\"),p=t(\"../../plots/cartesian/layout_attributes\"),d=t(\"../../components/color\"),g={left:\"start\",center:\"middle\",right:\"end\"},v={left:0,center:.5,right:1},m=/[yzafpn\\xb5mkMGTPEZY]/;function y(t){return t&&t.duration>0}function x(t){t.each(function(t){d.stroke(n.select(this),t.line.color)}).each(function(t){d.fill(n.select(this),t.color)}).style(\"stroke-width\",function(t){return t.line.width})}function b(t,e,r){var n=t._fullLayout,a=i.extendFlat({type:\"linear\",ticks:\"outside\",range:r,showline:!0},e),o={type:\"linear\",_id:\"x\"+e._id},s={letter:\"x\",font:n.font,noHover:!0,noTickson:!0};function l(t,e){return i.coerce(a,o,p,t,e)}return h(a,o,l,s,n),f(a,o,l,s),o}function _(t,e){return\"translate(\"+t+\",\"+e+\")\"}function w(t,e,r){return[Math.min(e/t.width,r/t.height),t,e+\"x\"+r]}function k(t,e,r,i){var a=document.createElementNS(\"http://www.w3.org/2000/svg\",\"text\"),o=n.select(a);return o.text(t).attr(\"x\",0).attr(\"y\",0).attr(\"text-anchor\",r).attr(\"data-unformatted\",t).call(c.convertToTspans,i).call(s.font,e),s.bBox(o.node())}function T(t,e,r,n,a,o){var s=\"_cache\"+e;t[s]&&t[s].key===a||(t[s]={key:a,value:r});var l=i.aggNums(o,null,[t[s].value,n],2);return t[s].value=l,l}e.exports=function(t,e,r,h){var f,p=t._fullLayout;y(r)&&h&&(f=h()),i.makeTraceGroups(p._indicatorlayer,e,\"trace\").each(function(e){var h,A,M,S,E,C=e[0].trace,L=n.select(this),P=C._hasGauge,O=C._isAngular,z=C._isBullet,I=C.domain,D={w:p._size.w*(I.x[1]-I.x[0]),h:p._size.h*(I.y[1]-I.y[0]),l:p._size.l+p._size.w*I.x[0],r:p._size.r+p._size.w*(1-I.x[1]),t:p._size.t+p._size.h*(1-I.y[1]),b:p._size.b+p._size.h*I.y[0]},R=D.l+D.w/2,F=D.t+D.h/2,B=Math.min(D.w/2,D.h),N=l.innerRadius*B,j=C.align||\"center\";if(A=F,P){if(O&&(h=R,A=F+B/2,M=function(t){return e=t,r=.9*N,n=Math.sqrt(e.width/2*(e.width/2)+e.height*e.height),[r/n,e,r];var e,r,n}),z){var U=l.bulletPadding,V=1-l.bulletNumberDomainSize+U;h=D.l+(V+(1-V)*v[j])*D.w,M=function(t){return w(t,(l.bulletNumberDomainSize-U)*D.w,D.h)}}}else h=D.l+v[j]*D.w,M=function(t){return w(t,D.w,D.h)};!function(t,e,r,a){var o,l,h,f=r[0].trace,p=a.numbersX,x=a.numbersY,w=f.align||\"center\",A=g[w],M=a.transitionOpts,S=a.onComplete,E=i.ensureSingle(e,\"g\",\"numbers\"),C=[];f._hasNumber&&C.push(\"number\");f._hasDelta&&(C.push(\"delta\"),\"left\"===f.delta.position&&C.reverse());var L=E.selectAll(\"text\").data(C);function P(e,r,n,i){if(!e.match(\"s\")||n>=0==i>=0||r(n).slice(-1).match(m)||r(i).slice(-1).match(m))return r;var a=e.slice().replace(\"s\",\"f\").replace(/\\d+/,function(t){return parseInt(t)-1}),o=b(t,{tickformat:a});return function(t){return Math.abs(t)<1?u.tickText(o,t).text:r(t)}}L.enter().append(\"text\"),L.attr(\"text-anchor\",function(){return A}).attr(\"class\",function(t){return t}).attr(\"x\",null).attr(\"y\",null).attr(\"dx\",null).attr(\"dy\",null),L.exit().remove();var O,z=f.mode+f.align;f._hasDelta&&(O=function(){var e=b(t,{tickformat:f.delta.valueformat},f._range);e.setScale(),u.calcTicks(e);var i=function(t){return u.tickText(e,t).text},a=function(t){var e=f.delta.relative?t.relativeDelta:t.delta;return e},o=function(t,e){return 0===t||\"number\"!=typeof t||isNaN(t)?\"-\":(t>0?f.delta.increasing.symbol:f.delta.decreasing.symbol)+e(t)},h=function(t){return t.delta>=0?f.delta.increasing.color:f.delta.decreasing.color};void 0===f._deltaLastValue&&(f._deltaLastValue=a(r[0]));var p=E.select(\"text.delta\");function g(){p.text(o(a(r[0]),i)).call(d.fill,h(r[0])).call(c.convertToTspans,t)}p.call(s.font,f.delta.font).call(d.fill,h({delta:f._deltaLastValue})),y(M)?p.transition().duration(M.duration).ease(M.easing).tween(\"text\",function(){var t=n.select(this),e=a(r[0]),s=f._deltaLastValue,l=P(f.delta.valueformat,i,s,e),c=n.interpolateNumber(s,e);return f._deltaLastValue=e,function(e){t.text(o(c(e),l)),t.call(d.fill,h({delta:c(e)}))}}).each(\"end\",function(){g(),S&&S()}).each(\"interrupt\",function(){g(),S&&S()}):g();return l=k(o(a(r[0]),i),f.delta.font,A,t),p}(),z+=f.delta.position+f.delta.font.size+f.delta.font.family+f.delta.valueformat,z+=f.delta.increasing.symbol+f.delta.decreasing.symbol,h=l);f._hasNumber&&(!function(){var e=b(t,{tickformat:f.number.valueformat},f._range);e.setScale(),u.calcTicks(e);var i=function(t){return u.tickText(e,t).text},a=f.number.suffix,l=f.number.prefix,h=E.select(\"text.number\");function p(){var e=\"number\"==typeof r[0].y?l+i(r[0].y)+a:\"-\";h.text(e).call(s.font,f.number.font).call(c.convertToTspans,t)}y(M)?h.transition().duration(M.duration).ease(M.easing).each(\"end\",function(){p(),S&&S()}).each(\"interrupt\",function(){p(),S&&S()}).attrTween(\"text\",function(){var t=n.select(this),e=n.interpolateNumber(r[0].lastY,r[0].y);f._lastValue=r[0].y;var o=P(f.number.valueformat,i,r[0].lastY,r[0].y);return function(r){t.text(l+o(e(r))+a)}}):p();o=k(l+i(r[0].y)+a,f.number.font,A,t)}(),z+=f.number.font.size+f.number.font.family+f.number.valueformat+f.number.suffix+f.number.prefix,h=o);if(f._hasDelta&&f._hasNumber){var I,D,R=[(o.left+o.right)/2,(o.top+o.bottom)/2],F=[(l.left+l.right)/2,(l.top+l.bottom)/2],B=.75*f.delta.font.size;\"left\"===f.delta.position&&(I=T(f,\"deltaPos\",0,-1*(o.width*v[f.align]+l.width*(1-v[f.align])+B),z,Math.min),D=R[1]-F[1],h={width:o.width+l.width+B,height:Math.max(o.height,l.height),left:l.left+I,right:o.right,top:Math.min(o.top,l.top+D),bottom:Math.max(o.bottom,l.bottom+D)}),\"right\"===f.delta.position&&(I=T(f,\"deltaPos\",0,o.width*(1-v[f.align])+l.width*v[f.align]+B,z,Math.max),D=R[1]-F[1],h={width:o.width+l.width+B,height:Math.max(o.height,l.height),left:o.left,right:l.right+I,top:Math.min(o.top,l.top+D),bottom:Math.max(o.bottom,l.bottom+D)}),\"bottom\"===f.delta.position&&(I=null,D=l.height,h={width:Math.max(o.width,l.width),height:o.height+l.height,left:Math.min(o.left,l.left),right:Math.max(o.right,l.right),top:o.bottom-o.height,bottom:o.bottom+l.height}),\"top\"===f.delta.position&&(I=null,D=o.top,h={width:Math.max(o.width,l.width),height:o.height+l.height,left:Math.min(o.left,l.left),right:Math.max(o.right,l.right),top:o.bottom-o.height-l.height,bottom:o.bottom}),O.attr({dx:I,dy:D})}(f._hasNumber||f._hasDelta)&&E.attr(\"transform\",function(){var t=a.numbersScaler(h);z+=t[2];var e,r=T(f,\"numbersScale\",1,t[0],z,Math.min);f._scaleNumbers||(r=1),e=f._isAngular?x-r*h.bottom:x-r*(h.top+h.bottom)/2,f._numbersTop=r*h.top+e;var n=h[w];\"center\"===w&&(n=(h.left+h.right)/2);var i=p-r*n;return _(i=T(f,\"numbersTranslate\",0,i,z,Math.max),e)+\" scale(\"+r+\")\"})}(t,L,e,{numbersX:h,numbersY:A,numbersScaler:M,transitionOpts:r,onComplete:f}),P&&(S={range:C.gauge.axis.range,color:C.gauge.bgcolor,line:{color:C.gauge.bordercolor,width:0},thickness:1},E={range:C.gauge.axis.range,color:\"rgba(0, 0, 0, 0)\",line:{color:C.gauge.bordercolor,width:C.gauge.borderwidth},thickness:1});var q=L.selectAll(\"g.angular\").data(O?e:[]);q.exit().remove();var H=L.selectAll(\"g.angularaxis\").data(O?e:[]);H.exit().remove(),O&&function(t,e,r,i){var s,l,c,h,f=r[0].trace,p=i.size,d=i.radius,g=i.innerRadius,v=i.gaugeBg,m=i.gaugeOutline,w=[p.l+p.w/2,p.t+p.h/2+d/2],k=i.gauge,T=i.layer,A=i.transitionOpts,M=i.onComplete,S=Math.PI/2;function E(t){var e=f.gauge.axis.range[0],r=f.gauge.axis.range[1],n=(t-e)/(r-e)*Math.PI-S;return n<-S?-S:n>S?S:n}function C(t){return n.svg.arc().innerRadius((g+d)/2-t/2*(d-g)).outerRadius((g+d)/2+t/2*(d-g)).startAngle(-S)}function L(t){t.attr(\"d\",function(t){return C(t.thickness).startAngle(E(t.range[0])).endAngle(E(t.range[1]))()})}k.enter().append(\"g\").classed(\"angular\",!0),k.attr(\"transform\",_(w[0],w[1])),T.enter().append(\"g\").classed(\"angularaxis\",!0).classed(\"crisp\",!0),T.selectAll(\"g.xangularaxistick,path,text\").remove(),(s=b(t,f.gauge.axis)).type=\"linear\",s.range=f.gauge.axis.range,s._id=\"xangularaxis\",s.setScale();var P=function(t){return(s.range[0]-t.x)/(s.range[1]-s.range[0])*Math.PI+Math.PI},O={},z=u.makeLabelFns(s,0).labelStandoff;O.xFn=function(t){var e=P(t);return Math.cos(e)*z},O.yFn=function(t){var e=P(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(z+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*o)},O.anchorFn=function(t){var e=P(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},O.heightFn=function(t,e,r){var n=P(t);return-.5*(1+Math.sin(n))*r};var I=function(t){return _(w[0]+d*Math.cos(t),w[1]-d*Math.sin(t))};c=function(t){return I(P(t))};if(l=u.calcTicks(s),h=u.getTickSigns(s)[2],s.visible){h=\"inside\"===s.ticks?-1:1;var D=(s.linewidth||1)/2;u.drawTicks(t,s,{vals:l,layer:T,path:\"M\"+h*D+\",0h\"+h*s.ticklen,transFn:function(t){var e=P(t);return I(e)+\"rotate(\"+-a(e)+\")\"}}),u.drawLabels(t,s,{vals:l,layer:T,transFn:c,labelFns:O})}var R=[v].concat(f.gauge.steps),F=k.selectAll(\"g.bg-arc\").data(R);F.enter().append(\"g\").classed(\"bg-arc\",!0).append(\"path\"),F.select(\"path\").call(L).call(x),F.exit().remove();var B=C(f.gauge.bar.thickness),N=k.selectAll(\"g.value-arc\").data([f.gauge.bar]);N.enter().append(\"g\").classed(\"value-arc\",!0).append(\"path\");var j=N.select(\"path\");y(A)?(j.transition().duration(A.duration).ease(A.easing).each(\"end\",function(){M&&M()}).each(\"interrupt\",function(){M&&M()}).attrTween(\"d\",(U=B,V=E(r[0].lastY),q=E(r[0].y),function(){var t=n.interpolate(V,q);return function(e){return U.endAngle(t(e))()}})),f._lastValue=r[0].y):j.attr(\"d\",\"number\"==typeof r[0].y?B.endAngle(E(r[0].y)):\"M0,0Z\");var U,V,q;j.call(x),N.exit().remove(),R=[];var H=f.gauge.threshold.value;H&&R.push({range:[H,H],color:f.gauge.threshold.color,line:{color:f.gauge.threshold.line.color,width:f.gauge.threshold.line.width},thickness:f.gauge.threshold.thickness});var G=k.selectAll(\"g.threshold-arc\").data(R);G.enter().append(\"g\").classed(\"threshold-arc\",!0).append(\"path\"),G.select(\"path\").call(L).call(x),G.exit().remove();var Y=k.selectAll(\"g.gauge-outline\").data([m]);Y.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"path\"),Y.select(\"path\").call(L).call(x),Y.exit().remove()}(t,0,e,{radius:B,innerRadius:N,gauge:q,layer:H,size:D,gaugeBg:S,gaugeOutline:E,transitionOpts:r,onComplete:f});var G=L.selectAll(\"g.bullet\").data(z?e:[]);G.exit().remove();var Y=L.selectAll(\"g.bulletaxis\").data(z?e:[]);Y.exit().remove(),z&&function(t,e,r,n){var i,a,o,s,c,h=r[0].trace,f=n.gauge,p=n.layer,g=n.gaugeBg,v=n.gaugeOutline,m=n.size,_=h.domain,w=n.transitionOpts,k=n.onComplete;f.enter().append(\"g\").classed(\"bullet\",!0),f.attr(\"transform\",\"translate(\"+m.l+\", \"+m.t+\")\"),p.enter().append(\"g\").classed(\"bulletaxis\",!0).classed(\"crisp\",!0),p.selectAll(\"g.xbulletaxistick,path,text\").remove();var T=m.h,A=h.gauge.bar.thickness*T,M=_.x[0],S=_.x[0]+(_.x[1]-_.x[0])*(h._hasNumber||h._hasDelta?1-l.bulletNumberDomainSize:1);(i=b(t,h.gauge.axis))._id=\"xbulletaxis\",i.domain=[M,S],i.setScale(),a=u.calcTicks(i),o=u.makeTransFn(i),s=u.getTickSigns(i)[2],c=m.t+m.h,i.visible&&(u.drawTicks(t,i,{vals:\"inside\"===i.ticks?u.clipEnds(i,a):a,layer:p,path:u.makeTickPath(i,c,s),transFn:o}),u.drawLabels(t,i,{vals:a,layer:p,transFn:o,labelFns:u.makeLabelFns(i,c)}));function E(t){t.attr(\"width\",function(t){return Math.max(0,i.c2p(t.range[1])-i.c2p(t.range[0]))}).attr(\"x\",function(t){return i.c2p(t.range[0])}).attr(\"y\",function(t){return.5*(1-t.thickness)*T}).attr(\"height\",function(t){return t.thickness*T})}var C=[g].concat(h.gauge.steps),L=f.selectAll(\"g.bg-bullet\").data(C);L.enter().append(\"g\").classed(\"bg-bullet\",!0).append(\"rect\"),L.select(\"rect\").call(E).call(x),L.exit().remove();var P=f.selectAll(\"g.value-bullet\").data([h.gauge.bar]);P.enter().append(\"g\").classed(\"value-bullet\",!0).append(\"rect\"),P.select(\"rect\").attr(\"height\",A).attr(\"y\",(T-A)/2).call(x),y(w)?P.select(\"rect\").transition().duration(w.duration).ease(w.easing).each(\"end\",function(){k&&k()}).each(\"interrupt\",function(){k&&k()}).attr(\"width\",Math.max(0,i.c2p(Math.min(h.gauge.axis.range[1],r[0].y)))):P.select(\"rect\").attr(\"width\",\"number\"==typeof r[0].y?Math.max(0,i.c2p(Math.min(h.gauge.axis.range[1],r[0].y))):0);P.exit().remove();var O=r.filter(function(){return h.gauge.threshold.value}),z=f.selectAll(\"g.threshold-bullet\").data(O);z.enter().append(\"g\").classed(\"threshold-bullet\",!0).append(\"line\"),z.select(\"line\").attr(\"x1\",i.c2p(h.gauge.threshold.value)).attr(\"x2\",i.c2p(h.gauge.threshold.value)).attr(\"y1\",(1-h.gauge.threshold.thickness)/2*T).attr(\"y2\",(1-(1-h.gauge.threshold.thickness)/2)*T).call(d.stroke,h.gauge.threshold.line.color).style(\"stroke-width\",h.gauge.threshold.line.width),z.exit().remove();var I=f.selectAll(\"g.gauge-outline\").data([v]);I.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"rect\"),I.select(\"rect\").call(E).call(x),I.exit().remove()}(t,0,e,{gauge:G,layer:Y,size:D,gaugeBg:S,gaugeOutline:E,transitionOpts:r,onComplete:f});var W=L.selectAll(\"text.title\").data(e);W.exit().remove(),W.enter().append(\"text\").classed(\"title\",!0),W.attr(\"text-anchor\",function(){return z?g.right:g[C.title.align]}).text(C.title.text).call(s.font,C.title.font).call(c.convertToTspans,t),W.attr(\"transform\",function(){var t,e=D.l+D.w*v[C.title.align],r=l.titlePadding,n=s.bBox(W.node());if(P){if(O)if(C.gauge.axis.visible)t=s.bBox(H.node()).top-r-n.bottom;else t=D.t+D.h/2-B/2-n.bottom-r;z&&(t=A-(n.top+n.bottom)/2,e=D.l-l.bulletPadding*D.w)}else t=C._numbersTop-r-n.bottom;return _(e,t)})})}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_defaults\":769,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/cartesian/position_defaults\":782,\"./constants\":1044,d3:163}],1048:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;var c=e.exports=l(s({x:{valType:\"data_array\"},y:{valType:\"data_array\"},z:{valType:\"data_array\"},value:{valType:\"data_array\"},isomin:{valType:\"number\"},isomax:{valType:\"number\"},surface:{show:{valType:\"boolean\",dflt:!0},count:{valType:\"integer\",dflt:2,min:1},fill:{valType:\"number\",min:0,max:1,dflt:1},pattern:{valType:\"flaglist\",flags:[\"A\",\"B\",\"C\",\"D\",\"E\"],extras:[\"all\",\"odd\",\"even\"],dflt:\"all\"}},spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:.15}},slices:{x:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}}},caps:{x:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}}},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:i()},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:a.opacity,lightposition:a.lightposition,lighting:a.lighting,flatshading:a.flatshading,contour:a.contour,hoverinfo:s({},o.hoverinfo)}),\"calc\",\"nested\");c.flatshading.dflt=!0,c.lighting.facenormalsepsilon.dflt=0,c.x.editType=c.y.editType=c.z.editType=c.value.editType=\"calc+clearAxisTypes\",c.transforms=void 0},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../mesh3d/attributes\":1053}],1049:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e._len=Math.min(e.x.length,e.y.length,e.z.length,e.value.length);for(var r=1/0,i=-1/0,a=e.value.length,o=0;o<a;o++){var s=e.value[o];r=Math.min(r,s),i=Math.max(i,s)}e._minValues=r,e._maxValues=i,e._vMin=void 0===e.isomin||null===e.isomin?r:e.isomin,e._vMax=void 0===e.isomax||null===e.isomin?i:e.isomax,n(t,e,{vals:[e._vMin,e._vMax],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],1050:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib\"),a=t(\"../../lib/gl_format_color\").parseColorScale,o=t(\"../../lib/str2rgbarray\"),s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\");function c(t){return i.distinctVals(t).vals}var u=function(t,e){for(var r=e.length-1;r>0;r--){var n=Math.min(e[r],e[r-1]),i=Math.max(e[r],e[r-1]);if(i>n&&n<t&&t<=i)return{id:r,distRatio:(i-t)/(i-n)}}return{id:0,distRatio:0}};function h(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var f=h.prototype;function p(t){t._i=[],t._j=[],t._k=[];var e,r,n=t.surface.show,i=t.spaceframe.show,a=t.surface.fill,o=t.spaceframe.fill,s=!1,l=!1,h=0,f=c(t.x.slice(0,t._len)),p=c(t.y.slice(0,t._len)),d=c(t.z.slice(0,t._len)),g=f.length,v=p.length,m=d.length;function y(t,e,r){return r+m*e+m*v*t}var x,b,_,w,k,T=t._minValues,A=t._maxValues,M=t._vMin,S=t._vMax;function E(t,e,n){for(var i=w.length,a=r;a<i;a++)if(t===x[a]&&e===b[a]&&n===_[a])return a;return-1}function C(){r=e}function L(){x=[],b=[],_=[],w=[],e=0,C()}function P(t,r,n,i){return x.push(t),b.push(r),_.push(n),w.push(i),++e-1}function O(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=t[i]*(1-r)+r*e[i];return n}function z(t){k=t}function I(t,e){return\"all\"===t||null===t||t.indexOf(e)>-1}function D(t,e){return null===t?e:t}function R(e,r,n){C();var i,a,o,s=[r],l=[n];if(k>=1)s=[r],l=[n];else if(k>0){var c=function(t,e){var r=t[0],n=t[1],i=t[2],a=function(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=(t[i]+e[i]+r[i])/3;return n}(r,n,i),o=Math.sqrt(1-k),s=O(a,r,o),l=O(a,n,o),c=O(a,i,o),u=e[0],h=e[1],f=e[2];return{xyzv:[[r,n,l],[l,s,r],[n,i,c],[c,l,n],[i,r,s],[s,c,i]],abc:[[u,h,-1],[-1,-1,u],[h,f,-1],[-1,-1,h],[f,u,-1],[-1,-1,f]]}}(r,n);s=c.xyzv,l=c.abc}for(var u=0;u<s.length;u++){r=s[u],n=l[u];for(var f=[],p=0;p<3;p++){var d=r[p][0],g=r[p][1],v=r[p][2],m=r[p][3],y=n[p]>-1?n[p]:E(d,g,v);f[p]=y>-1?y:P(d,g,v,D(e,m))}i=f[0],a=f[1],o=f[2],t._i.push(i),t._j.push(a),t._k.push(o),++h}}function F(t,e,r,n){var i=t[3];i<r&&(i=r),i>n&&(i=n);for(var a=(t[3]-i)/(t[3]-e[3]+1e-9),o=[],s=0;s<4;s++)o[s]=(1-a)*t[s]+a*e[s];return o}function B(t,e,r){return t>=e&&t<=r}function N(t){var e=.001*(S-M);return t>=M-e&&t<=S+e}function j(e){for(var r=[],n=0;n<4;n++){var i=e[n];r.push([t.x[i],t.y[i],t.z[i],t.value[i]])}return r}var U=3;function V(t,e,r,n,i,a){a||(a=1),r=[-1,-1,-1];var o=!1,s=[B(e[0][3],n,i),B(e[1][3],n,i),B(e[2][3],n,i)];if(!s[0]&&!s[1]&&!s[2])return!1;var l=function(t,e,r){return N(e[0][3])&&N(e[1][3])&&N(e[2][3])?(R(t,e,r),!0):a<U&&V(t,e,r,M,S,++a)};if(s[0]&&s[1]&&s[2])return l(t,e,r)||o;var c=!1;return[[0,1,2],[2,0,1],[1,2,0]].forEach(function(a){if(s[a[0]]&&s[a[1]]&&!s[a[2]]){var u=e[a[0]],h=e[a[1]],f=e[a[2]],p=F(f,u,n,i),d=F(f,h,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,o=l(t,[u,h,d],[r[a[0]],r[a[1]],-1])||o,c=!0}}),c?o:([[0,1,2],[1,2,0],[2,0,1]].forEach(function(a){if(s[a[0]]&&!s[a[1]]&&!s[a[2]]){var u=e[a[0]],h=e[a[1]],f=e[a[2]],p=F(h,u,n,i),d=F(f,u,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,c=!0}}),o)}function q(t,e,r,n){var i=!1,a=j(e),o=[B(a[0][3],r,n),B(a[1][3],r,n),B(a[2][3],r,n),B(a[3][3],r,n)];if(!(o[0]||o[1]||o[2]||o[3]))return i;if(o[0]&&o[1]&&o[2]&&o[3])return l&&(i=function(t,e,r){var n=function(n,i,a){R(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(3,0,1),n(2,3,0),n(1,2,3)}(t,a,e)||i),i;var s=!1;return[[0,1,2,3],[3,0,1,2],[2,3,0,1],[1,2,3,0]].forEach(function(c){if(o[c[0]]&&o[c[1]]&&o[c[2]]&&!o[c[3]]){var u=a[c[0]],h=a[c[1]],f=a[c[2]],p=a[c[3]];if(l)i=R(t,[u,h,f],[e[c[0]],e[c[1]],e[c[2]]])||i;else{var d=F(p,u,r,n),g=F(p,h,r,n),v=F(p,f,r,n);i=R(null,[d,g,v],[-1,-1,-1])||i}s=!0}}),s?i:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2],[0,2,3,1],[1,3,2,0]].forEach(function(c){if(o[c[0]]&&o[c[1]]&&!o[c[2]]&&!o[c[3]]){var u=a[c[0]],h=a[c[1]],f=a[c[2]],p=a[c[3]],d=F(f,u,r,n),g=F(f,h,r,n),v=F(p,h,r,n),m=F(p,u,r,n);l?(i=R(t,[u,m,d],[e[c[0]],-1,-1])||i,i=R(t,[h,g,v],[e[c[1]],-1,-1])||i):i=function(t,e,r){var n=function(n,i,a){R(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(2,3,0)}(null,[d,g,v,m],[-1,-1,-1,-1])||i,s=!0}}),s?i:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2]].forEach(function(c){if(o[c[0]]&&!o[c[1]]&&!o[c[2]]&&!o[c[3]]){var u=a[c[0]],h=a[c[1]],f=a[c[2]],p=a[c[3]],d=F(h,u,r,n),g=F(f,u,r,n),v=F(p,u,r,n);l?(i=R(t,[u,d,g],[e[c[0]],-1,-1])||i,i=R(t,[u,g,v],[e[c[0]],-1,-1])||i,i=R(t,[u,v,d],[e[c[0]],-1,-1])||i):i=R(null,[d,g,v],[-1,-1,-1])||i,s=!0}}),i))}function H(t,e,r,n,i,a,o,c,u,h,f){var p=!1;return s&&(I(t,\"A\")&&(p=q(null,[e,r,n,a],h,f)||p),I(t,\"B\")&&(p=q(null,[r,n,i,u],h,f)||p),I(t,\"C\")&&(p=q(null,[r,a,o,u],h,f)||p),I(t,\"D\")&&(p=q(null,[n,a,c,u],h,f)||p),I(t,\"E\")&&(p=q(null,[r,n,a,u],h,f)||p)),l&&(p=q(t,[r,n,a,u],h,f)||p),p}function G(t,e,r,n,i,a,o,s){return[!0===s[0]||V(t,j([e,r,n]),[e,r,n],a,o),!0===s[1]||V(t,j([n,i,e]),[n,i,e],a,o)]}function Y(t,e,r,n,i,a,o,s,l){return s?G(t,e,r,i,n,a,o,l):G(t,r,i,n,e,a,o,l)}function W(t,e,r,n,i,a,o){var s,l,c,u,h=!1,f=function(){h=V(t,[s,l,c],[-1,-1,-1],i,a)||h,h=V(t,[c,u,s],[-1,-1,-1],i,a)||h},p=o[0],d=o[1],g=o[2];return p&&(s=O(j([y(e,r-0,n-0)])[0],j([y(e-1,r-0,n-0)])[0],p),l=O(j([y(e,r-0,n-1)])[0],j([y(e-1,r-0,n-1)])[0],p),c=O(j([y(e,r-1,n-1)])[0],j([y(e-1,r-1,n-1)])[0],p),u=O(j([y(e,r-1,n-0)])[0],j([y(e-1,r-1,n-0)])[0],p),f()),d&&(s=O(j([y(e-0,r,n-0)])[0],j([y(e-0,r-1,n-0)])[0],d),l=O(j([y(e-0,r,n-1)])[0],j([y(e-0,r-1,n-1)])[0],d),c=O(j([y(e-1,r,n-1)])[0],j([y(e-1,r-1,n-1)])[0],d),u=O(j([y(e-1,r,n-0)])[0],j([y(e-1,r-1,n-0)])[0],d),f()),g&&(s=O(j([y(e-0,r-0,n)])[0],j([y(e-0,r-0,n-1)])[0],g),l=O(j([y(e-0,r-1,n)])[0],j([y(e-0,r-1,n-1)])[0],g),c=O(j([y(e-1,r-1,n)])[0],j([y(e-1,r-1,n-1)])[0],g),u=O(j([y(e-1,r-0,n)])[0],j([y(e-1,r-0,n-1)])[0],g),f()),h}function X(t,e,r,n,i,a,o,l,c,u,h,f){var p=t;return f?(s&&\"even\"===t&&(p=null),H(p,e,r,n,i,a,o,l,c,u,h)):(s&&\"odd\"===t&&(p=null),H(p,c,l,o,a,i,n,r,e,u,h))}function Z(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<m;c++)for(var u=1;u<v;u++)a.push(Y(t,y(l,u-1,c-1),y(l,u-1,c),y(l,u,c-1),y(l,u,c),r,n,(l+u+c)%2,i&&i[o]?i[o]:[])),o++;return a}function J(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<g;c++)for(var u=1;u<m;u++)a.push(Y(t,y(c-1,l,u-1),y(c,l,u-1),y(c-1,l,u),y(c,l,u),r,n,(c+l+u)%2,i&&i[o]?i[o]:[])),o++;return a}function K(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<v;c++)for(var u=1;u<g;u++)a.push(Y(t,y(u-1,c-1,l),y(u-1,c,l),y(u,c-1,l),y(u,c,l),r,n,(u+c+l)%2,i&&i[o]?i[o]:[])),o++;return a}function $(t,e,r){for(var n=1;n<m;n++)for(var i=1;i<v;i++)for(var a=1;a<g;a++)X(t,y(a-1,i-1,n-1),y(a-1,i-1,n),y(a-1,i,n-1),y(a-1,i,n),y(a,i-1,n-1),y(a,i-1,n),y(a,i,n-1),y(a,i,n),e,r,(a+i+n)%2)}function Q(t,e,r){s=!0,$(t,e,r),s=!1}function tt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<m;u++)for(var h=1;h<v;h++)o.push(W(t,c,h,u,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function et(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<g;u++)for(var h=1;h<m;h++)o.push(W(t,u,c,h,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function rt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<v;u++)for(var h=1;h<g;h++)o.push(W(t,h,u,c,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function nt(t,e){for(var r=[],n=t;n<e;n++)r.push(n);return r}return function(){if(L(),function(){for(var e=0;e<g;e++)for(var r=0;r<v;r++)for(var n=0;n<m;n++){var i=y(e,r,n);P(t.x[i],t.y[i],t.z[i],t.value[i])}}(),i&&o&&(z(o),l=!0,$(null,M,S),l=!1),n&&a){z(a);for(var e=t.surface.pattern,r=t.surface.count,s=0;s<r;s++){var c=1===r?.5:s/(r-1),k=(1-c)*M+c*S,E=Math.abs(k-T)>Math.abs(k-A)?[T,k]:[k,A];Q(e,E[0],E[1])}}var C=[[Math.min(M,A),Math.max(M,A)],[Math.min(T,S),Math.max(T,S)]];[\"x\",\"y\",\"z\"].forEach(function(e){for(var r=[],n=0;n<C.length;n++){var i=0,a=C[n][0],o=C[n][1],s=t.slices[e];if(s.show&&s.fill){z(s.fill);var l=[],c=[],h=[];if(s.locations.length)for(var y=0;y<s.locations.length;y++){var x=u(s.locations[y],\"x\"===e?f:\"y\"===e?p:d);0===x.distRatio?l.push(x.id):x.id>0&&(c.push(x.id),\"x\"===e?h.push([x.distRatio,0,0]):\"y\"===e?h.push([0,x.distRatio,0]):h.push([0,0,x.distRatio]))}else l=nt(1,\"x\"===e?g-1:\"y\"===e?v-1:m-1);c.length>0&&(r[i]=\"x\"===e?tt(null,c,a,o,h,r[i]):\"y\"===e?et(null,c,a,o,h,r[i]):rt(null,c,a,o,h,r[i]),i++),l.length>0&&(r[i]=\"x\"===e?Z(null,l,a,o,r[i]):\"y\"===e?J(null,l,a,o,r[i]):K(null,l,a,o,r[i]),i++)}var b=t.caps[e];b.show&&b.fill&&(z(b.fill),r[i]=\"x\"===e?Z(null,[0,g-1],a,o,r[i]):\"y\"===e?J(null,[0,v-1],a,o,r[i]):K(null,[0,m-1],a,o,r[i]),i++)}}),0===h&&L(),t._x=x,t._y=b,t._z=_,t._intensity=w,t._Xs=f,t._Ys=p,t._Zs=d}(),t}f.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._x[e],n=this.data._y[e],i=this.data._z[e],a=this.data._Ys.length,o=this.data._Zs.length,s=u(r,this.data._Xs).id,l=u(n,this.data._Ys).id,c=u(i,this.data._Zs).id,h=t.index=c+o*l+o*a*s;t.traceCoordinate=[this.data._x[h],this.data._y[h],this.data._z[h],this.data.value[h]];var f=this.data.hovertext||this.data.text;return Array.isArray(f)&&void 0!==f[h]?t.textLabel=f[h]:f&&(t.textLabel=f),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map(function(e){return t.d2l(e,0,n)*r})}this.data=p(t);var i={positions:l(n(r.xaxis,t._x,e.dataScale[0],t.xcalendar),n(r.yaxis,t._y,e.dataScale[1],t.ycalendar),n(r.zaxis,t._z,e.dataScale[2],t.zcalendar)),cells:l(t._i,t._j,t._k),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:o(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},c=s(t);i.vertexIntensity=t._intensity,i.vertexIntensityBounds=[c.min,c.max],i.colormap=a(t),this.mesh.update(i)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports={findNearestOnAxis:u,generateIsoMeshes:p,createIsosurfaceTrace:function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new h(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../../plots/gl3d/zip3\":818,\"gl-mesh3d\":280}],1051:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"../../components/colorscale/defaults\");function s(t,e,r,n,a){var s=a(\"isomin\"),l=a(\"isomax\");null!=l&&null!=s&&s>l&&(e.isomin=null,e.isomax=null);var c=a(\"x\"),u=a(\"y\"),h=a(\"z\"),f=a(\"value\");c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length?(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],n),[\"x\",\"y\",\"z\"].forEach(function(t){var e=\"caps.\"+t;a(e+\".show\")&&a(e+\".fill\");var r=\"slices.\"+t;a(r+\".show\")&&(a(r+\".fill\"),a(r+\".locations\"))}),a(\"spaceframe.show\")&&a(\"spaceframe.fill\"),a(\"surface.show\")&&(a(\"surface.count\"),a(\"surface.fill\"),a(\"surface.pattern\")),a(\"contour.show\")&&(a(\"contour.color\"),a(\"contour.width\")),[\"text\",\"hovertext\",\"hovertemplate\",\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"flatshading\",\"opacity\"].forEach(function(t){a(t)}),o(t,e,n,a,{prefix:\"\",cLetter:\"c\"}),e._length=null):e.visible=!1}e.exports={supplyDefaults:function(t,e,r,i){s(t,e,0,i,function(r,i){return n.coerce(t,e,a,r,i)})},supplyIsoDefaults:s}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../../registry\":847,\"./attributes\":1048}],1052:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\").createIsosurfaceTrace,moduleType:\"trace\",name:\"isosurface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1048,\"./calc\":1049,\"./convert\":1050,\"./defaults\":1051}],1053:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../surface/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},i:{valType:\"data_array\",editType:\"calc\"},j:{valType:\"data_array\",editType:\"calc\"},k:{valType:\"data_array\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:i({editType:\"calc\"}),delaunayaxis:{valType:\"enumerated\",values:[\"x\",\"y\",\"z\"],dflt:\"z\",editType:\"calc\"},alphahull:{valType:\"number\",dflt:-1,editType:\"calc\"},intensity:{valType:\"data_array\",editType:\"calc\"},color:{valType:\"color\",editType:\"calc\"},vertexcolor:{valType:\"data_array\",editType:\"calc\"},facecolor:{valType:\"data_array\",editType:\"calc\"},transforms:void 0},n(\"\",{colorAttr:\"`intensity`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:a.opacity,flatshading:{valType:\"boolean\",dflt:!1,editType:\"calc\"},contour:{show:s({},a.contours.x.show,{}),color:a.contours.x.color,width:a.contours.x.width,editType:\"calc\"},lightposition:{x:s({},a.lightposition.x,{dflt:1e5}),y:s({},a.lightposition.y,{dflt:1e5}),z:s({},a.lightposition.z,{dflt:0}),editType:\"calc\"},lighting:s({vertexnormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-12,editType:\"calc\"},facenormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-6,editType:\"calc\"},editType:\"calc\"},a.lighting),hoverinfo:s({},o.hoverinfo,{editType:\"calc\"})})},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../surface/attributes\":1224}],1054:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.intensity&&n(t,e,{vals:e.intensity,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],1055:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"delaunay-triangulate\"),a=t(\"alpha-shape\"),o=t(\"convex-hull\"),s=t(\"../../lib/gl_format_color\").parseColorScale,l=t(\"../../lib/str2rgbarray\"),c=t(\"../../components/colorscale\").extractOpts,u=t(\"../../plots/gl3d/zip3\");function h(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.color=\"#fff\",this.data=null,this.showContour=!1}var f=h.prototype;function p(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=l(t[n]);return e}function d(t,e,r,n){for(var i=[],a=e.length,o=0;o<a;o++)i[o]=t.d2l(e[o],0,n)*r;return i}function g(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=Math.round(t[n]);return e}function v(t,e){for(var r=t.length,n=0;n<r;n++)if(t[n]<=-.5||t[n]>=e-.5)return!1;return!0}f.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index;t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]];var r=this.data.hovertext||this.data.text;return Array.isArray(r)&&void 0!==r[e]?t.textLabel=r[e]:r&&(t.textLabel=r),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;this.data=t;var n,h=t.x.length,f=u(d(r.xaxis,t.x,e.dataScale[0],t.xcalendar),d(r.yaxis,t.y,e.dataScale[1],t.ycalendar),d(r.zaxis,t.z,e.dataScale[2],t.zcalendar));if(t.i&&t.j&&t.k){if(t.i.length!==t.j.length||t.j.length!==t.k.length||!v(t.i,h)||!v(t.j,h)||!v(t.k,h))return;n=u(g(t.i),g(t.j),g(t.k))}else n=0===t.alphahull?o(f):t.alphahull>0?a(t.alphahull,f):function(t,e){for(var r=[\"x\",\"y\",\"z\"].indexOf(t),n=[],a=e.length,o=0;o<a;o++)n[o]=[e[o][(r+1)%3],e[o][(r+2)%3]];return i(n)}(t.delaunayaxis,f);var m={positions:f,cells:n,lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:l(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading};if(t.intensity){var y=c(t);this.color=\"#fff\",m.vertexIntensity=t.intensity,m.vertexIntensityBounds=[y.min,y.max],m.colormap=s(t)}else t.vertexcolor?(this.color=t.vertexcolor[0],m.vertexColors=p(t.vertexcolor)):t.facecolor?(this.color=t.facecolor[0],m.cellColors=p(t.facecolor)):(this.color=t.color,m.meshColor=l(t.color));this.mesh.update(m)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new h(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":605,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../../plots/gl3d/zip3\":818,\"alpha-shape\":64,\"convex-hull\":130,\"delaunay-triangulate\":165,\"gl-mesh3d\":280}],1056:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,n){return i.coerce(t,e,o,r,n)}function c(t){var e=t.map(function(t){var e=l(t);return e&&i.isArrayOrTypedArray(e)?e:null});return e.every(function(t){return t&&t.length===e[0].length})&&e}c([\"x\",\"y\",\"z\"])?(c([\"i\",\"j\",\"k\"]),(!e.i||e.j&&e.k)&&(!e.j||e.k&&e.i)&&(!e.k||e.i&&e.j)?(n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],s),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"contour.show\",\"contour.color\",\"contour.width\",\"colorscale\",\"reversescale\",\"flatshading\",\"alphahull\",\"delaunayaxis\",\"opacity\"].forEach(function(t){l(t)}),\"intensity\"in t?(l(\"intensity\"),a(t,e,s,l,{prefix:\"\",cLetter:\"c\"})):(e.showscale=!1,\"facecolor\"in t?l(\"facecolor\"):\"vertexcolor\"in t?l(\"vertexcolor\"):l(\"color\",r)),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),e._length=null):e.visible=!1):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../../registry\":847,\"./attributes\":1053}],1057:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"mesh3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1053,\"./calc\":1054,\"./convert\":1055,\"./defaults\":1056}],1058:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../scatter/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../components/fx/attributes\"),s=t(\"../../constants/delta.js\"),l=s.INCREASING.COLOR,c=s.DECREASING.COLOR,u=i.line;function h(t){return{line:{color:n({},u.color,{dflt:t}),width:u.width,dash:a,editType:\"style\"},editType:\"style\"}}e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},open:{valType:\"data_array\",editType:\"calc\"},high:{valType:\"data_array\",editType:\"calc\"},low:{valType:\"data_array\",editType:\"calc\"},close:{valType:\"data_array\",editType:\"calc\"},line:{width:n({},u.width,{}),dash:n({},a,{}),editType:\"style\"},increasing:h(l),decreasing:h(c),text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},tickwidth:{valType:\"number\",min:0,max:.5,dflt:.3,editType:\"calc\"},hoverlabel:n({},o.hoverlabel,{split:{valType:\"boolean\",dflt:!1,editType:\"style\"}})}},{\"../../components/drawing/attributes\":613,\"../../components/fx/attributes\":623,\"../../constants/delta.js\":689,\"../../lib\":719,\"../scatter/attributes\":1112}],1059:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=n._,a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/numerical\").BADNUM;function s(t,e,r,n){return{o:t,h:e,l:r,c:n}}function l(t,e,r,s,l){for(var c=s.makeCalcdata(e,\"open\"),u=s.makeCalcdata(e,\"high\"),h=s.makeCalcdata(e,\"low\"),f=s.makeCalcdata(e,\"close\"),p=Array.isArray(e.text),d=Array.isArray(e.hovertext),g=!0,v=null,m=[],y=0;y<r.length;y++){var x=r[y],b=c[y],_=u[y],w=h[y],k=f[y];if(x!==o&&b!==o&&_!==o&&w!==o&&k!==o){k===b?null!==v&&k!==v&&(g=k>v):g=k>b,v=k;var T=l(b,_,w,k);T.pos=x,T.yc=(b+k)/2,T.i=y,T.dir=g?\"increasing\":\"decreasing\",T.x=T.pos,T.y=[w,_],p&&(T.tx=e.text[y]),d&&(T.htx=e.hovertext[y]),m.push(T)}else m.push({pos:x,empty:!0})}return e._extremes[s._id]=a.findExtremes(s,n.concat(h,u),{padded:!0}),m.length&&(m[0].t={labels:{open:i(t,\"open:\")+\" \",high:i(t,\"high:\")+\" \",low:i(t,\"low:\")+\" \",close:i(t,\"close:\")+\" \"}}),m}e.exports={calc:function(t,e){var r=a.getFromId(t,e.xaxis),i=a.getFromId(t,e.yaxis),o=function(t,e,r){var i=r._minDiff;if(!i){var a,o=t._fullData,s=[];for(i=1/0,a=0;a<o.length;a++){var l=o[a];if(\"ohlc\"===l.type&&!0===l.visible&&l.xaxis===e._id){s.push(l);var c=e.makeCalcdata(l,\"x\");l._xcalc=c;var u=n.distinctVals(c).minDiff;u&&isFinite(u)&&(i=Math.min(i,u))}}for(i===1/0&&(i=1),a=0;a<s.length;a++)s[a]._minDiff=i}return i*r.tickwidth}(t,r,e),c=e._minDiff;e._minDiff=null;var u=e._xcalc;e._xcalc=null;var h=l(t,e,u,i,s);return e._extremes[r._id]=a.findExtremes(r,u,{vpad:c/2}),h.length?(n.extendFlat(h[0].t,{wHover:c/2,tickLen:o}),h):[{t:{empty:!0}}]},calcCommon:l}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],1060:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./ohlc_defaults\"),a=t(\"./attributes\");function o(t,e,r,n){r(n+\".line.color\"),r(n+\".line.width\",e.line.width),r(n+\".line.dash\",e.line.dash)}e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,a,r,i)}i(t,e,l,s)?(l(\"line.width\"),l(\"line.dash\"),o(t,e,l,\"increasing\"),o(t,e,l,\"decreasing\"),l(\"text\"),l(\"hovertext\"),l(\"tickwidth\"),s._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../lib\":719,\"./attributes\":1058,\"./ohlc_defaults\":1063}],1061:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\").fillText,l=t(\"../../constants/delta.js\"),c={increasing:l.INCREASING.SYMBOL,decreasing:l.DECREASING.SYMBOL};function u(t,e,r,n){var i,s,l=t.cd,c=t.xa,u=l[0].trace,h=l[0].t,f=u.type,p=\"ohlc\"===f?\"l\":\"min\",d=\"ohlc\"===f?\"h\":\"max\",g=h.bPos||0,v=function(t){return t.pos+g-e},m=h.bdPos||h.tickLen,y=h.wHover,x=Math.min(1,m/Math.abs(c.r2c(c.range[1])-c.r2c(c.range[0])));function b(t){var e=v(t);return a.inbox(e-y,e+y,i)}function _(t){var e=t[p],n=t[d];return e===n||a.inbox(e-r,n-r,i)}function w(t){return(b(t)+_(t))/2}i=t.maxHoverDistance-x,s=t.maxSpikeDistance-x;var k=a.getDistanceFunction(n,b,_,w);if(a.getClosest(l,k,t),!1===t.index)return null;var T=l[t.index];if(T.empty)return null;var A=u[T.dir],M=A.line.color;return o.opacity(M)&&A.line.width?t.color=M:t.color=A.fillcolor,t.x0=c.c2p(T.pos+g-m,!0),t.x1=c.c2p(T.pos+g+m,!0),t.xLabelVal=T.pos,t.spikeDistance=w(T)*s/i,t.xSpike=c.c2p(T.pos,!0),t}function h(t,e,r,a){var o=t.cd,s=t.ya,l=o[0].trace,c=o[0].t,h=[],f=u(t,e,r,a);if(!f)return[];var p=o[f.index].hi||l.hoverinfo,d=p.split(\"+\");if(!(\"all\"===p||-1!==d.indexOf(\"y\")))return[];for(var g=[\"high\",\"open\",\"close\",\"low\"],v={},m=0;m<g.length;m++){var y,x=g[m],b=l[x][f.index],_=s.c2p(b,!0);b in v?(y=v[b]).yLabel+=\"<br>\"+c.labels[x]+n.hoverLabelText(s,b):((y=i.extendFlat({},f)).y0=y.y1=_,y.yLabelVal=b,y.yLabel=c.labels[x]+n.hoverLabelText(s,b),y.name=\"\",h.push(y),v[b]=y)}return h}function f(t,e,r,i){var a=t.cd,o=t.ya,l=a[0].trace,h=a[0].t,f=u(t,e,r,i);if(!f)return[];var p=a[f.index],d=f.index=p.i,g=p.dir;function v(t){return h.labels[t]+n.hoverLabelText(o,l[t][d])}var m=p.hi||l.hoverinfo,y=m.split(\"+\"),x=\"all\"===m,b=x||-1!==y.indexOf(\"y\"),_=x||-1!==y.indexOf(\"text\"),w=b?[v(\"open\"),v(\"high\"),v(\"low\"),v(\"close\")+\"  \"+c[g]]:[];return _&&s(p,l,w),f.extraText=w.join(\"<br>\"),f.y0=f.y1=o.c2p(p.yc,!0),[f]}e.exports={hoverPoints:function(t,e,r,n){return t.cd[0].trace.hoverlabel.split?h(t,e,r,n):f(t,e,r,n)},hoverSplit:h,hoverOnPoints:f}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../constants/delta.js\":689,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],1062:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"ohlc\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\"],meta:{},attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\").calc,plot:t(\"./plot\"),style:t(\"./style\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\")}},{\"../../plots/cartesian\":778,\"./attributes\":1058,\"./calc\":1059,\"./defaults\":1060,\"./hover\":1061,\"./plot\":1064,\"./select\":1065,\"./style\":1066}],1063:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"open\"),l=r(\"high\"),c=r(\"low\"),u=r(\"close\");if(r(\"hoverlabel.split\"),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\"],a),s&&l&&c&&u){var h=Math.min(s.length,l.length,c.length,u.length);return o&&(h=Math.min(h,i.minRowLength(o))),e._length=h,h}}},{\"../../lib\":719,\"../../registry\":847}],1064:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=e.xaxis,s=e.yaxis;i.makeTraceGroups(a,r,\"trace ohlc\").each(function(t){var e=n.select(this),r=t[0],a=r.t;if(!0!==r.trace.visible||a.empty)e.remove();else{var l=a.tickLen,c=e.selectAll(\"path\").data(i.identity);c.enter().append(\"path\"),c.exit().remove(),c.attr(\"d\",function(t){if(t.empty)return\"M0,0Z\";var e=o.c2p(t.pos,!0),r=o.c2p(t.pos-l,!0),n=o.c2p(t.pos+l,!0);return\"M\"+r+\",\"+s.c2p(t.o,!0)+\"H\"+e+\"M\"+e+\",\"+s.c2p(t.h,!0)+\"V\"+s.c2p(t.l,!0)+\"M\"+n+\",\"+s.c2p(t.c,!0)+\"H\"+e})}})}},{\"../../lib\":719,d3:163}],1065:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n=t.cd,i=t.xaxis,a=t.yaxis,o=[],s=n[0].t.bPos||0;if(!1===e)for(r=0;r<n.length;r++)n[r].selected=0;else for(r=0;r<n.length;r++){var l=n[r];e.contains([i.c2p(l.pos+s),a.c2p(l.yc)],null,l.i,t)?(o.push({pointNumber:l.i,x:i.c2d(l.pos),y:a.c2d(l.yc)}),l.selected=1):l.selected=0}return o}},{}],1066:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\");e.exports=function(t,e,r){var o=r||n.select(t).selectAll(\"g.ohlclayer\").selectAll(\"g.trace\");o.style(\"opacity\",function(t){return t[0].trace.opacity}),o.each(function(t){var e=t[0].trace;n.select(this).selectAll(\"path\").each(function(t){if(!t.empty){var r=e[t.dir].line;n.select(this).style(\"fill\",\"none\").call(a.stroke,r.color).call(i.dashLine,r.dash,r.width).style(\"opacity\",e.selectedpoints&&!t.selected?.3:1)}})})}},{\"../../components/color\":593,\"../../components/drawing\":614,d3:163}],1067:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../plots/attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/fx/hovertemplate_attributes\"),l=t(\"../../plots/domain\").attributes,c=n({editType:\"calc\"},o(\"line\",{editTypeOverride:\"calc\"}),{shape:{valType:\"enumerated\",values:[\"linear\",\"hspline\"],dflt:\"linear\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\"]})});e.exports={domain:l({name:\"parcats\",trace:!0,editType:\"calc\"}),hoverinfo:n({},i.hoverinfo,{flags:[\"count\",\"probability\"],editType:\"plot\",arrayOk:!1}),hoveron:{valType:\"enumerated\",values:[\"category\",\"color\",\"dimension\"],dflt:\"category\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\",\"category\",\"categorycount\",\"colorcount\",\"bandcolorcount\"]}),arrangement:{valType:\"enumerated\",values:[\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"perpendicular\",editType:\"plot\"},bundlecolors:{valType:\"boolean\",dflt:!0,editType:\"plot\"},sortpaths:{valType:\"enumerated\",values:[\"forward\",\"backward\"],dflt:\"forward\",editType:\"plot\"},labelfont:a({editType:\"calc\"}),tickfont:a({editType:\"calc\"}),dimensions:{_isLinkedToArray:\"dimension\",label:{valType:\"string\",editType:\"calc\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",dflt:[],editType:\"calc\"},displayindex:{valType:\"integer\",editType:\"calc\"},editType:\"calc\",visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"}},line:c,counts:{valType:\"number\",min:0,dflt:1,arrayOk:!0,editType:\"calc\"},customdata:void 0,hoverlabel:void 0,ids:void 0,legendgroup:void 0,opacity:void 0,selectedpoints:void 0,showlegend:void 0}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1068:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"parcats\",r.plot=function(t,e,r,a){var o=n(t.calcdata,\"parcats\");if(o.length){var s=o[0];i(t,s,r,a)}},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcats\"),a=e._has&&e._has(\"parcats\");i&&!a&&n._paperdiv.selectAll(\".parcats\").remove()}},{\"../../plots/get_data\":802,\"./plot\":1073}],1069:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),o=t(\"../../lib/filter_unique.js\"),s=t(\"../../components/drawing\"),l=t(\"../../lib\");function c(t,e,r){t.valueInds.push(e),t.count+=r}function u(t,e,r){t.valueInds.push(e),t.count+=r}e.exports=function(t,e){var r=l.filterVisible(e.dimensions);if(0===r.length)return[];var h,f,p,d=r.map(function(t){var e;return\"trace\"===t.categoryorder?e=null:\"array\"===t.categoryorder?e=t.categoryarray:(e=o(t.values).sort(),\"category descending\"===t.categoryorder&&(e=e.reverse())),function(t,e){e=null==e?[]:e.map(function(t){return t});var r={},n={},i=[];e.forEach(function(t,e){r[t]=0,n[t]=e});for(var a=0;a<t.length;a++){var o,s=t[a];void 0===r[s]?(r[s]=1,o=e.push(s)-1,n[s]=o):(r[s]++,o=n[s]),i.push(o)}var l=e.map(function(t){return r[t]});return{uniqueValues:e,uniqueCounts:l,inds:i}}(t.values,e)});h=l.isArrayOrTypedArray(e.counts)?e.counts:[e.counts],function(t){var e;if(function(t){for(var e=new Array(t.length),r=0;r<t.length;r++){if(t[r]<0||t[r]>=t.length)return!1;if(void 0!==e[t[r]])return!1;e[t[r]]=!0}return!0}(t.map(function(t){return t.displayindex})))for(e=0;e<t.length;e++)t[e]._displayindex=t[e].displayindex;else for(e=0;e<t.length;e++)t[e]._displayindex=e}(r),r.forEach(function(t,e){!function(t,e){t._categoryarray=e.uniqueValues,null===t.ticktext||void 0===t.ticktext?t._ticktext=[]:t._ticktext=t.ticktext.slice();for(var r=t._ticktext.length;r<e.uniqueValues.length;r++)t._ticktext.push(e.uniqueValues[r])}(t,d[e])});var g,v=e.line;v?(i(e,\"line\")&&a(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),g=s.tryColorscale(v)):g=l.identity;var m,y,x,b,_=r[0].values.length,w={},k=d.map(function(t){return t.inds});for(p=0,m=0;m<_;m++){var T=[];for(y=0;y<k.length;y++)T.push(k[y][m]);f=h[m%h.length],p+=f;var A=(x=m,b=void 0,b=l.isArrayOrTypedArray(v.color)?v.color[x%v.color.length]:v.color,{color:g(b),rawColor:b}),M=T+\"-\"+A.rawColor;void 0===w[M]&&(w[M]={categoryInds:T,color:A.color,rawColor:A.rawColor,valueInds:[],count:0}),u(w[M],m,f)}var S,E=r.map(function(t,e){return r=e,n=t._index,i=t._displayindex,a=t.label,{dimensionInd:r,containerInd:n,displayInd:i,dimensionLabel:a,count:p,categories:[],dragX:null};var r,n,i,a});for(m=0;m<_;m++)for(f=h[m%h.length],y=0;y<E.length;y++){var C=E[y].containerInd,L=d[y].inds[m],P=E[y].categories;if(void 0===P[L]){var O=e.dimensions[C]._categoryarray[L],z=e.dimensions[C]._ticktext[L];P[L]={dimensionInd:y,categoryInd:S=L,categoryValue:O,displayInd:S,categoryLabel:z,valueInds:[],count:0,dragY:null}}c(P[L],m,f)}return n(function(t,e,r){var n=t.map(function(t){return t.categories.length}).reduce(function(t,e){return Math.max(t,e)});return{dimensions:t,paths:e,trace:void 0,maxCats:n,count:r}}(E,w,p))}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/filter_unique.js\":711,\"../../lib/gup\":717}],1070:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"./attributes\"),c=t(\"../parcoords/merge_length\");function u(t,e){function r(r,i){return n.coerce(t,e,l.dimensions,r,i)}var i=r(\"values\"),a=r(\"visible\");if(i&&i.length||(a=e.visible=!1),a){r(\"label\"),r(\"displayindex\",e._index);var o,s=t.categoryarray,c=Array.isArray(s)&&s.length>0;c&&(o=\"array\");var u=r(\"categoryorder\",o);\"array\"===u?(r(\"categoryarray\"),r(\"ticktext\")):(delete t.categoryarray,delete t.ticktext),c||\"array\"!==u||(e.categoryorder=\"trace\")}}e.exports=function(t,e,r,h){function f(r,i){return n.coerce(t,e,l,r,i)}var p=s(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=function(t,e,r,o,s){s(\"line.shape\"),s(\"line.hovertemplate\");var l=s(\"line.color\",o.colorway[0]);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,h,f);o(e,h,f),Array.isArray(p)&&p.length||(e.visible=!1),c(e,p,\"values\",d),f(\"hoveron\"),f(\"hovertemplate\"),f(\"arrangement\"),f(\"bundlecolors\"),f(\"sortpaths\"),f(\"counts\");var g={family:h.font.family,size:Math.round(h.font.size),color:h.font.color};n.coerceFont(f,\"labelfont\",g);var v={family:h.font.family,size:Math.round(h.font.size/1.2),color:h.font.color};n.coerceFont(f,\"tickfont\",v)}},{\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/domain\":792,\"../parcoords/merge_length\":1083,\"./attributes\":1067}],1071:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcats\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1067,\"./base_plot\":1068,\"./calc\":1069,\"./defaults\":1070,\"./plot\":1073}],1072:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plot_api/plot_api\"),a=t(\"../../components/fx\"),o=t(\"../../lib\"),s=t(\"../../components/drawing\"),l=t(\"tinycolor2\"),c=t(\"../../lib/svg_text_utils\");function u(t,e,r,i){var a=t.map(function(t,e,r){var n,i=r[0],a=e.margin||{l:80,r:80,t:100,b:80},o=i.trace,s=o.domain,l=e.width,c=e.height,u=Math.floor(l*(s.x[1]-s.x[0])),h=Math.floor(c*(s.y[1]-s.y[0])),f=s.x[0]*l+a.l,p=e.height-s.y[1]*e.height+a.t,d=o.line.shape;n=\"all\"===o.hoverinfo?[\"count\",\"probability\"]:(o.hoverinfo||\"\").split(\"+\");var g={trace:o,key:o.uid,model:i,x:f,y:p,width:u,height:h,hoveron:o.hoveron,hoverinfoItems:n,arrangement:o.arrangement,bundlecolors:o.bundlecolors,sortpaths:o.sortpaths,labelfont:o.labelfont,categorylabelfont:o.tickfont,pathShape:d,dragDimension:null,margin:a,paths:[],dimensions:[],graphDiv:t,traceSelection:null,pathSelection:null,dimensionSelection:null};i.dimensions&&(R(g),D(g));return g}.bind(0,e,r)),l=i.selectAll(\"g.parcatslayer\").data([null]);l.enter().append(\"g\").attr(\"class\",\"parcatslayer\").style(\"pointer-events\",\"all\");var u=l.selectAll(\"g.trace.parcats\").data(a,h),v=u.enter().append(\"g\").attr(\"class\",\"trace parcats\");u.attr(\"transform\",function(t){return\"translate(\"+t.x+\", \"+t.y+\")\"}),v.append(\"g\").attr(\"class\",\"paths\");var x=u.select(\"g.paths\").selectAll(\"path.path\").data(function(t){return t.paths},h);x.attr(\"fill\",function(t){return t.model.color});var w=x.enter().append(\"path\").attr(\"class\",\"path\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.model.color}).attr(\"fill-opacity\",0);y(w),x.attr(\"d\",function(t){return t.svgD}),w.empty()||x.sort(p),x.exit().remove(),x.on(\"mouseover\",d).on(\"mouseout\",g).on(\"click\",m),v.append(\"g\").attr(\"class\",\"dimensions\");var k=u.select(\"g.dimensions\").selectAll(\"g.dimension\").data(function(t){return t.dimensions},h);k.enter().append(\"g\").attr(\"class\",\"dimension\"),k.attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),k.exit().remove();var T=k.selectAll(\"g.category\").data(function(t){return t.categories},h),A=T.enter().append(\"g\").attr(\"class\",\"category\");T.attr(\"transform\",function(t){return\"translate(0, \"+t.y+\")\"}),A.append(\"rect\").attr(\"class\",\"catrect\").attr(\"pointer-events\",\"none\"),T.select(\"rect.catrect\").attr(\"fill\",\"none\").attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}),b(A);var P=T.selectAll(\"rect.bandrect\").data(function(t){return t.bands},h);P.each(function(){o.raiseToTop(this)}),P.attr(\"fill\",function(t){return t.color});var O=P.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.color}).attr(\"fill-opacity\",0);P.attr(\"fill\",function(t){return t.color}).attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}).attr(\"y\",function(t){return t.y}).attr(\"cursor\",function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"perpendicular\"===t.parcatsViewModel.arrangement?\"ns-resize\":\"move\"}),_(O),P.exit().remove(),A.append(\"text\").attr(\"class\",\"catlabel\").attr(\"pointer-events\",\"none\");var z=e._fullLayout.paper_bgcolor;T.select(\"text.catlabel\").attr(\"text-anchor\",function(t){return f(t)?\"start\":\"end\"}).attr(\"alignment-baseline\",\"middle\").style(\"text-shadow\",z+\" -1px  1px 2px, \"+z+\" 1px  1px 2px, \"+z+\"  1px -1px 2px, \"+z+\" -1px -1px 2px\").style(\"fill\",\"rgb(0, 0, 0)\").attr(\"x\",function(t){return f(t)?t.width+5:-5}).attr(\"y\",function(t){return t.height/2}).text(function(t){return t.model.categoryLabel}).each(function(t){s.font(n.select(this),t.parcatsViewModel.categorylabelfont),c.convertToTspans(n.select(this),e)}),A.append(\"text\").attr(\"class\",\"dimlabel\"),T.select(\"text.dimlabel\").attr(\"text-anchor\",\"middle\").attr(\"alignment-baseline\",\"baseline\").attr(\"cursor\",function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"ew-resize\"}).attr(\"x\",function(t){return t.width/2}).attr(\"y\",-5).text(function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null}).each(function(t){s.font(n.select(this),t.parcatsViewModel.labelfont)}),T.selectAll(\"rect.bandrect\").on(\"mouseover\",M).on(\"mouseout\",S),T.exit().remove(),k.call(n.behavior.drag().origin(function(t){return{x:t.x,y:0}}).on(\"dragstart\",E).on(\"drag\",C).on(\"dragend\",L)),u.each(function(t){t.traceSelection=n.select(this),t.pathSelection=n.select(this).selectAll(\"g.paths\").selectAll(\"path.path\"),t.dimensionSelection=n.select(this).selectAll(\"g.dimensions\").selectAll(\"g.dimension\")}),u.exit().remove()}function h(t){return t.key}function f(t){var e=t.parcatsViewModel.dimensions.length,r=t.parcatsViewModel.dimensions[e-1].model.dimensionInd;return t.model.dimensionInd===r}function p(t,e){return t.model.rawColor>e.model.rawColor?1:t.model.rawColor<e.model.rawColor?-1:0}function d(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){o.raiseToTop(this),x(n.select(this));var e=v(t);if(t.parcatsViewModel.graphDiv.emit(\"plotly_hover\",{points:e,event:n.event}),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\")){var r,i,s,c=n.mouse(this)[0],u=t.parcatsViewModel.graphDiv,h=t.parcatsViewModel.trace,f=u._fullLayout,p=f._paperdiv.node().getBoundingClientRect(),d=t.parcatsViewModel.graphDiv.getBoundingClientRect();for(s=0;s<t.leftXs.length-1;s++)if(t.leftXs[s]+t.dimWidths[s]-2<=c&&c<=t.leftXs[s+1]+2){var g=t.parcatsViewModel.dimensions[s],m=t.parcatsViewModel.dimensions[s+1];r=(g.x+g.width+m.x)/2,i=(t.topYs[s]+t.topYs[s+1]+t.height)/2;break}var y=t.parcatsViewModel.x+r,b=t.parcatsViewModel.y+i,_=l.mostReadable(t.model.color,[\"black\",\"white\"]),w=t.model.count,k=w/t.parcatsViewModel.model.count,T={countLabel:w,probabilityLabel:k.toFixed(3)},A=[];-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&A.push([\"Count:\",T.countLabel].join(\" \")),-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&A.push([\"P:\",T.probabilityLabel].join(\" \"));var M=A.join(\"<br>\"),S=n.mouse(u)[0];a.loneHover({trace:h,x:y-p.left+d.left,y:b-p.top+d.top,text:M,color:t.model.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:10,fontColor:_,idealAlign:S<y?\"right\":\"left\",hovertemplate:(h.line||{}).hovertemplate,hovertemplateLabels:T,eventData:[{data:h._input,fullData:h,count:w,probability:k}]},{container:f._hoverlayer.node(),outerContainer:f._paper.node(),gd:u})}}}function g(t){if(!t.parcatsViewModel.dragDimension&&(y(n.select(this)),a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()),t.parcatsViewModel.pathSelection.sort(p),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\"))){var e=v(t);t.parcatsViewModel.graphDiv.emit(\"plotly_unhover\",{points:e,event:n.event})}}function v(t){for(var e=[],r=P(t.parcatsViewModel),n=0;n<t.model.valueInds.length;n++){var i=t.model.valueInds[n];e.push({curveNumber:r,pointNumber:i})}return e}function m(t){if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){var e=v(t);t.parcatsViewModel.graphDiv.emit(\"plotly_click\",{points:e,event:n.event})}}function y(t){t.attr(\"fill\",function(t){return t.model.color}).attr(\"fill-opacity\",.6).attr(\"stroke\",\"lightgray\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1)}function x(t){t.attr(\"fill-opacity\",.8).attr(\"stroke\",function(t){return l.mostReadable(t.model.color,[\"black\",\"white\"])}).attr(\"stroke-width\",.3)}function b(t){t.select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",1).attr(\"stroke-opacity\",1)}function _(t){t.attr(\"stroke\",\"black\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1).attr(\"fill-opacity\",1)}function w(t){var e=t.parcatsViewModel.pathSelection,r=t.categoryViewModel.model.dimensionInd,n=t.categoryViewModel.model.categoryInd;return e.filter(function(e){return e.model.categoryInds[r]===n&&e.model.color===t.color})}function k(t,e,r){var i=n.select(t).datum().parcatsViewModel.graphDiv,a=n.select(t.parentNode).selectAll(\"rect.bandrect\"),o=[];a.each(function(t){w(t).each(function(t){Array.prototype.push.apply(o,v(t))})}),i.emit(e,{points:o,event:r})}function T(t,e,r){var i=n.select(t).datum(),a=i.parcatsViewModel.graphDiv,o=w(i),s=[];o.each(function(t){Array.prototype.push.apply(s,v(t))}),a.emit(e,{points:s,event:r})}function A(t,e){var r,i,a=n.select(e.parentNode).select(\"rect.catrect\"),o=a.node().getBoundingClientRect(),s=a.datum(),l=s.parcatsViewModel,c=l.model.dimensions[s.model.dimensionInd],u=l.trace,h=o.top+o.height/2;l.dimensions.length>1&&c.displayInd===l.dimensions.length-1?(r=o.left,i=\"left\"):(r=o.left+o.width,i=\"right\");var f=s.model.count,p=s.model.categoryLabel,d=f/s.parcatsViewModel.model.count,g={countLabel:f,categoryLabel:p,probabilityLabel:d.toFixed(3)},v=[];-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&v.push([\"Count:\",g.countLabel].join(\" \")),-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&v.push([\"P(\"+g.categoryLabel+\"):\",g.probabilityLabel].join(\" \"));var m=v.join(\"<br>\");return{trace:u,x:r-t.left,y:h-t.top,text:m,color:\"lightgray\",borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:12,fontColor:\"black\",idealAlign:i,hovertemplate:u.hovertemplate,hovertemplateLabels:g,eventData:[{data:u._input,fullData:u,count:f,category:p,probability:d}]}}function M(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){if(n.mouse(this)[1]<-1)return;var e,r=t.parcatsViewModel.graphDiv,i=r._fullLayout,s=i._paperdiv.node().getBoundingClientRect(),c=t.parcatsViewModel.hoveron;if(\"color\"===c?(!function(t){var e=n.select(t).datum(),r=w(e);x(r),r.each(function(){o.raiseToTop(this)}),n.select(t.parentNode).selectAll(\"rect.bandrect\").filter(function(t){return t.color===e.color}).each(function(){o.raiseToTop(this),n.select(this).attr(\"stroke\",\"black\").attr(\"stroke-width\",1.5)})}(this),T(this,\"plotly_hover\",n.event)):(!function(t){n.select(t.parentNode).selectAll(\"rect.bandrect\").each(function(t){var e=w(t);x(e),e.each(function(){o.raiseToTop(this)})}),n.select(t.parentNode).select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",2.5)}(this),k(this,\"plotly_hover\",n.event)),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\"))\"category\"===c?e=A(s,this):\"color\"===c?e=function(t,e){var r,i,a=e.getBoundingClientRect(),o=n.select(e).datum(),s=o.categoryViewModel,c=s.parcatsViewModel,u=c.model.dimensions[s.model.dimensionInd],h=c.trace,f=a.y+a.height/2;c.dimensions.length>1&&u.displayInd===c.dimensions.length-1?(r=a.left,i=\"left\"):(r=a.left+a.width,i=\"right\");var p=s.model.categoryLabel,d=o.parcatsViewModel.model.count,g=0;o.categoryViewModel.bands.forEach(function(t){t.color===o.color&&(g+=t.count)});var v=s.model.count,m=0;c.pathSelection.each(function(t){t.model.color===o.color&&(m+=t.model.count)});var y=g/d,x=g/m,b=g/v,_={countLabel:d,categoryLabel:p,probabilityLabel:y.toFixed(3)},w=[];-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&w.push([\"Count:\",_.countLabel].join(\" \")),-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&(w.push(\"P(color \\u2229 \"+p+\"): \"+_.probabilityLabel),w.push(\"P(\"+p+\" | color): \"+x.toFixed(3)),w.push(\"P(color | \"+p+\"): \"+b.toFixed(3)));var k=w.join(\"<br>\"),T=l.mostReadable(o.color,[\"black\",\"white\"]);return{trace:h,x:r-t.left,y:f-t.top,text:k,color:o.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontColor:T,fontSize:10,idealAlign:i,hovertemplate:h.hovertemplate,hovertemplateLabels:_,eventData:[{data:h._input,fullData:h,category:p,count:d,probability:y,categorycount:v,colorcount:m,bandcolorcount:g}]}}(s,this):\"dimension\"===c&&(e=function(t,e){var r=[];return n.select(e.parentNode.parentNode).selectAll(\"g.category\").select(\"rect.catrect\").each(function(){r.push(A(t,this))}),r}(s,this)),e&&a.loneHover(e,{container:i._hoverlayer.node(),outerContainer:i._paper.node(),gd:r})}}function S(t){var e=t.parcatsViewModel;if(!e.dragDimension&&(y(e.pathSelection),b(e.dimensionSelection.selectAll(\"g.category\")),_(e.dimensionSelection.selectAll(\"g.category\").selectAll(\"rect.bandrect\")),a.loneUnhover(e.graphDiv._fullLayout._hoverlayer.node()),e.pathSelection.sort(p),-1===e.hoverinfoItems.indexOf(\"skip\"))){\"color\"===t.parcatsViewModel.hoveron?T(this,\"plotly_unhover\",n.event):k(this,\"plotly_unhover\",n.event)}}function E(t){\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragDimensionDisplayInd=t.model.displayInd,t.initialDragDimensionDisplayInds=t.parcatsViewModel.model.dimensions.map(function(t){return t.displayInd}),t.dragHasMoved=!1,t.dragCategoryDisplayInd=null,n.select(this).selectAll(\"g.category\").select(\"rect.catrect\").each(function(e){var r=n.mouse(this)[0],i=n.mouse(this)[1];-2<=r&&r<=e.width+2&&-2<=i&&i<=e.height+2&&(t.dragCategoryDisplayInd=e.model.displayInd,t.initialDragCategoryDisplayInds=t.model.categories.map(function(t){return t.displayInd}),e.model.dragY=e.y,o.raiseToTop(this.parentNode),n.select(this.parentNode).selectAll(\"rect.bandrect\").each(function(e){e.y<i&&i<=e.y+e.height&&(t.potentialClickBand=this)}))}),t.parcatsViewModel.dragDimension=t,a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()))}function C(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragHasMoved=!0,null!==t.dragDimensionDisplayInd)){var e=t.dragDimensionDisplayInd,r=e-1,i=e+1,a=t.parcatsViewModel.dimensions[e];if(null!==t.dragCategoryDisplayInd){var o=a.categories[t.dragCategoryDisplayInd];o.model.dragY+=n.event.dy;var s=o.model.dragY,l=o.model.displayInd,c=a.categories,u=c[l-1],h=c[l+1];void 0!==u&&s<u.y+u.height/2&&(o.model.displayInd=u.model.displayInd,u.model.displayInd=l),void 0!==h&&s+o.height>h.y+h.height/2&&(o.model.displayInd=h.model.displayInd,h.model.displayInd=l),t.dragCategoryDisplayInd=o.model.displayInd}if(null===t.dragCategoryDisplayInd||\"freeform\"===t.parcatsViewModel.arrangement){a.model.dragX=n.event.x;var f=t.parcatsViewModel.dimensions[r],p=t.parcatsViewModel.dimensions[i];void 0!==f&&a.model.dragX<f.x+f.width&&(a.model.displayInd=f.model.displayInd,f.model.displayInd=e),void 0!==p&&a.model.dragX+a.width>p.x&&(a.model.displayInd=p.model.displayInd,p.model.displayInd=t.dragDimensionDisplayInd),t.dragDimensionDisplayInd=a.model.displayInd}R(t.parcatsViewModel),D(t.parcatsViewModel),z(t.parcatsViewModel),O(t.parcatsViewModel)}}function L(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&null!==t.dragDimensionDisplayInd){n.select(this).selectAll(\"text\").attr(\"font-weight\",\"normal\");var e={},r=P(t.parcatsViewModel),a=t.parcatsViewModel.model.dimensions.map(function(t){return t.displayInd}),o=t.initialDragDimensionDisplayInds.some(function(t,e){return t!==a[e]});o&&a.forEach(function(r,n){var i=t.parcatsViewModel.model.dimensions[n].containerInd;e[\"dimensions[\"+i+\"].displayindex\"]=r});var s=!1;if(null!==t.dragCategoryDisplayInd){var l=t.model.categories.map(function(t){return t.displayInd});if(s=t.initialDragCategoryDisplayInds.some(function(t,e){return t!==l[e]})){var c=t.model.categories.slice().sort(function(t,e){return t.displayInd-e.displayInd}),u=c.map(function(t){return t.categoryValue}),h=c.map(function(t){return t.categoryLabel});e[\"dimensions[\"+t.model.containerInd+\"].categoryarray\"]=[u],e[\"dimensions[\"+t.model.containerInd+\"].ticktext\"]=[h],e[\"dimensions[\"+t.model.containerInd+\"].categoryorder\"]=\"array\"}}if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")&&!t.dragHasMoved&&t.potentialClickBand&&(\"color\"===t.parcatsViewModel.hoveron?T(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent):k(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent)),t.model.dragX=null,null!==t.dragCategoryDisplayInd)t.parcatsViewModel.dimensions[t.dragDimensionDisplayInd].categories[t.dragCategoryDisplayInd].model.dragY=null,t.dragCategoryDisplayInd=null;t.dragDimensionDisplayInd=null,t.parcatsViewModel.dragDimension=null,t.dragHasMoved=null,t.potentialClickBand=null,R(t.parcatsViewModel),D(t.parcatsViewModel),n.transition().duration(300).ease(\"cubic-in-out\").each(function(){z(t.parcatsViewModel,!0),O(t.parcatsViewModel,!0)}).each(\"end\",function(){(o||s)&&i.restyle(t.parcatsViewModel.graphDiv,e,[r])})}}function P(t){for(var e,r=t.graphDiv._fullData,n=0;n<r.length;n++)if(t.key===r[n].uid){e=n;break}return e}function O(t,e){var r;void 0===e&&(e=!1),t.pathSelection.data(function(t){return t.paths},h),(r=t.pathSelection,e?r.transition():r).attr(\"d\",function(t){return t.svgD})}function z(t,e){function r(t){return e?t.transition():t}void 0===e&&(e=!1),t.dimensionSelection.data(function(t){return t.dimensions},h);var i=t.dimensionSelection.selectAll(\"g.category\").data(function(t){return t.categories},h);r(t.dimensionSelection).attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),r(i).attr(\"transform\",function(t){return\"translate(0, \"+t.y+\")\"}),i.select(\".dimlabel\").text(function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null}),i.select(\".catlabel\").attr(\"text-anchor\",function(t){return f(t)?\"start\":\"end\"}).attr(\"x\",function(t){return f(t)?t.width+5:-5}).each(function(t){var e,r;f(t)?(e=t.width+5,r=\"start\"):(e=-5,r=\"end\"),n.select(this).selectAll(\"tspan\").attr(\"x\",e).attr(\"text-anchor\",r)});var a=i.selectAll(\"rect.bandrect\").data(function(t){return t.bands},h),s=a.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"cursor\",\"move\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.color}).attr(\"fill-opacity\",0);a.attr(\"fill\",function(t){return t.color}).attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}).attr(\"y\",function(t){return t.y}),_(s),a.each(function(){o.raiseToTop(this)}),a.exit().remove()}function I(t,e,r,i,a){var o,s,l=[],c=[];for(s=0;s<r.length-1;s++)o=n.interpolateNumber(r[s]+t[s],t[s+1]),l.push(o(a)),c.push(o(1-a));var u=\"M \"+t[0]+\",\"+e[0];for(u+=\"l\"+r[0]+\",0 \",s=1;s<r.length;s++)u+=\"C\"+l[s-1]+\",\"+e[s-1]+\" \"+c[s-1]+\",\"+e[s]+\" \"+t[s]+\",\"+e[s],u+=\"l\"+r[s]+\",0 \";for(u+=\"l0,\"+i+\" \",u+=\"l -\"+r[r.length-1]+\",0 \",s=r.length-2;s>=0;s--)u+=\"C\"+c[s]+\",\"+(e[s+1]+i)+\" \"+l[s]+\",\"+(e[s]+i)+\" \"+(t[s]+r[s])+\",\"+(e[s]+i),u+=\"l-\"+r[s]+\",0 \";return u+=\"Z\"}function D(t){var e=t.dimensions,r=t.model,n=e.map(function(t){return t.categories.map(function(t){return t.y})}),i=t.model.dimensions.map(function(t){return t.categories.map(function(t){return t.displayInd})}),a=t.model.dimensions.map(function(t){return t.displayInd}),o=t.dimensions.map(function(t){return t.model.dimensionInd}),s=e.map(function(t){return t.x}),l=e.map(function(t){return t.width}),c=[];for(var u in r.paths)r.paths.hasOwnProperty(u)&&c.push(r.paths[u]);function h(t){var e=t.categoryInds.map(function(t,e){return i[e][t]});return o.map(function(t){return e[t]})}c.sort(function(e,r){var n=h(e),i=h(r);return\"backward\"===t.sortpaths&&(n.reverse(),i.reverse()),n.push(e.valueInds[0]),i.push(r.valueInds[0]),t.bundlecolors&&(n.unshift(e.rawColor),i.unshift(r.rawColor)),n<i?-1:n>i?1:0});for(var f=new Array(c.length),p=e[0].model.count,d=e[0].categories.map(function(t){return t.height}).reduce(function(t,e){return t+e}),g=0;g<c.length;g++){var v,m=c[g];v=p>0?d*(m.count/p):0;for(var y,x=new Array(n.length),b=0;b<m.categoryInds.length;b++){var _=m.categoryInds[b],w=i[b][_],k=a[b];x[k]=n[k][w],n[k][w]+=v;var T=t.dimensions[k].categories[w],A=T.bands.length,M=T.bands[A-1];if(void 0===M||m.rawColor!==M.rawColor){var S=void 0===M?0:M.y+M.height;T.bands.push({key:S,color:m.color,rawColor:m.rawColor,height:v,width:T.width,count:m.count,y:S,categoryViewModel:T,parcatsViewModel:t})}else{var E=T.bands[A-1];E.height+=v,E.count+=m.count}}y=\"hspline\"===t.pathShape?I(s,x,l,v,.5):I(s,x,l,v,0),f[g]={key:m.valueInds[0],model:m,height:v,leftXs:s,topYs:x,dimWidths:l,svgD:y,parcatsViewModel:t}}t.paths=f}function R(t){var e=t.model.dimensions.map(function(t){return{displayInd:t.displayInd,dimensionInd:t.dimensionInd}});e.sort(function(t,e){return t.displayInd-e.displayInd});var r=[];for(var n in e){var i=e[n].dimensionInd,a=t.model.dimensions[i];r.push(F(t,a))}t.dimensions=r}function F(t,e){var r,n=t.model.dimensions.length,i=e.displayInd;r=40+(n>1?(t.width-80-16)/(n-1):0)*i;var a,o,s,l,c,u=[],h=t.model.maxCats,f=e.categories.length,p=e.count,d=t.height-8*(h-1),g=8*(h-f)/2,v=e.categories.map(function(t){return{displayInd:t.displayInd,categoryInd:t.categoryInd}});for(v.sort(function(t,e){return t.displayInd-e.displayInd}),c=0;c<f;c++)l=v[c].categoryInd,o=e.categories[l],a=p>0?o.count/p*d:0,s={key:o.valueInds[0],model:o,width:16,height:a,y:null!==o.dragY?o.dragY:g,bands:[],parcatsViewModel:t},g=g+a+8,u.push(s);return{key:e.dimensionInd,x:null!==e.dragX?e.dragX:r,y:0,width:16,model:e,categories:u,parcatsViewModel:t,dragCategoryDisplayInd:null,dragDimensionDisplayInd:null,initialDragDimensionDisplayInds:null,initialDragCategoryDisplayInds:null,dragHasMoved:null,potentialClickBand:null}}e.exports=function(t,e,r,n){u(r,t,n,e)}},{\"../../components/drawing\":614,\"../../components/fx\":632,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_api\":754,d3:163,tinycolor2:537}],1073:[function(t,e,r){\"use strict\";var n=t(\"./parcats\");e.exports=function(t,e,r,i){var a=t._fullLayout,o=a._paper,s=a._size;n(t,o,e,{width:s.w,height:s.h,margin:{t:s.t,r:s.r,b:s.b,l:s.l}},r,i)}},{\"./parcats\":1072}],1074:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/cartesian/layout_attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../plots/domain\").attributes,s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/plot_template\").templatedArray;e.exports={domain:o({name:\"parcoords\",trace:!0,editType:\"plot\"}),labelangle:{valType:\"angle\",dflt:0,editType:\"plot\"},labelside:{valType:\"enumerated\",values:[\"top\",\"bottom\"],dflt:\"top\",editType:\"plot\"},labelfont:a({editType:\"plot\"}),tickfont:a({editType:\"plot\"}),rangefont:a({editType:\"plot\"}),dimensions:l(\"dimension\",{label:{valType:\"string\",editType:\"plot\"},tickvals:s({},i.tickvals,{editType:\"plot\"}),ticktext:s({},i.ticktext,{editType:\"plot\"}),tickformat:s({},i.tickformat,{editType:\"plot\"}),visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},constraintrange:{valType:\"info_array\",freeLength:!0,dimensions:\"1-2\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},multiselect:{valType:\"boolean\",dflt:!0,editType:\"plot\"},values:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"}),line:s({editType:\"calc\"},n(\"line\",{colorscaleDflt:\"Viridis\",autoColorDflt:!1,editTypeOverride:\"calc\"}))}},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1075:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\").keyFun,o=t(\"../../lib/gup\").repeat,s=t(\"../../lib\").sorterAsc,l=n.bar.snapRatio;function c(t,e){return t*(1-l)+e*l}var u=n.bar.snapClose;function h(t,e){return t*(1-u)+e*u}function f(t,e,r,n){if(function(t,e){for(var r=0;r<e.length;r++)if(t>=e[r][0]&&t<=e[r][1])return!0;return!1}(r,n))return r;var i=t?-1:1,a=0,o=e.length-1;if(i<0){var s=a;a=o,o=s}for(var l=e[a],u=l,f=a;i*f<i*o;f+=i){var p=f+i,d=e[p];if(i*r<i*h(l,d))return c(l,u);if(i*r<i*d||p===o)return c(d,l);u=l,l=d}}function p(t){t.attr(\"x\",-n.bar.captureWidth/2).attr(\"width\",n.bar.captureWidth)}function d(t){t.attr(\"visibility\",\"visible\").style(\"visibility\",\"visible\").attr(\"fill\",\"yellow\").attr(\"opacity\",0)}function g(t){if(!t.brush.filterSpecified)return\"0,\"+t.height;for(var e,r,n,i=v(t.brush.filter.getConsolidated(),t.height),a=[0],o=i.length?i[0][0]:null,s=0;s<i.length;s++)r=(e=i[s])[1]-e[0],a.push(o),a.push(r),(n=s+1)<i.length&&(o=i[n][0]-e[1]);return a.push(t.height),a}function v(t,e){return t.map(function(t){return t.map(function(t){return Math.max(0,t*e)}).sort(s)})}function m(){i.select(document.body).style(\"cursor\",null)}function y(t){t.attr(\"stroke-dasharray\",g)}function x(t,e){var r=i.select(t).selectAll(\".highlight, .highlight-shadow\");y(e?r.transition().duration(n.bar.snapDuration).each(\"end\",e):r)}function b(t,e){var r,i=t.brush,a=NaN,o={};if(i.filterSpecified){var s=t.height,l=i.filter.getConsolidated(),c=v(l,s),u=NaN,h=NaN,f=NaN;for(r=0;r<=c.length;r++){var p=c[r];if(p&&p[0]<=e&&e<=p[1]){u=r;break}if(h=r?r-1:NaN,p&&p[0]>e){f=r;break}}if(a=u,isNaN(a)&&(a=isNaN(h)||isNaN(f)?isNaN(h)?f:h:e-c[h][1]<c[f][0]-e?h:f),!isNaN(a)){var d=c[a],g=function(t,e){var r=n.bar.handleHeight;if(!(e>t[1]+r||e<t[0]-r))return e>=.9*t[1]+.1*t[0]?\"n\":e<=.9*t[0]+.1*t[1]?\"s\":\"ns\"}(d,e);g&&(o.interval=l[a],o.intervalPix=d,o.region=g)}}if(t.ordinal&&!o.region){var m=t.unitTickvals,y=t.unitToPaddedPx.invert(e);for(r=0;r<m.length;r++){var x=[.25*m[Math.max(r-1,0)]+.75*m[r],.25*m[Math.min(r+1,m.length-1)]+.75*m[r]];if(y>=x[0]&&y<=x[1]){o.clickableOrdinalRange=x;break}}}return o}function _(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.brush.svgBrush;a.wasDragged=!0,a._dragging=!0,a.grabbingBar?a.newExtent=[r-a.grabPoint,r+a.barLength-a.grabPoint].map(e.unitToPaddedPx.invert):a.newExtent=[a.startExtent,e.unitToPaddedPx.invert(r)].sort(s),e.brush.filterSpecified=!0,a.extent=a.stayingIntervals.concat([a.newExtent]),a.brushCallback(e),x(t.parentNode)}function w(t,e){var r=b(e,e.height-i.mouse(t)[1]-2*n.verticalPadding),a=\"crosshair\";r.clickableOrdinalRange?a=\"pointer\":r.region&&(a=r.region+\"-resize\"),i.select(document.body).style(\"cursor\",a)}function k(t){t.on(\"mousemove\",function(t){i.event.preventDefault(),t.parent.inBrushDrag||w(this,t)}).on(\"mouseleave\",function(t){t.parent.inBrushDrag||m()}).call(i.behavior.drag().on(\"dragstart\",function(t){!function(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.unitToPaddedPx.invert(r),o=e.brush,s=b(e,r),l=s.interval,c=o.svgBrush;if(c.wasDragged=!1,c.grabbingBar=\"ns\"===s.region,c.grabbingBar){var u=l.map(e.unitToPaddedPx);c.grabPoint=r-u[0]-n.verticalPadding,c.barLength=u[1]-u[0]}c.clickableOrdinalRange=s.clickableOrdinalRange,c.stayingIntervals=e.multiselect&&o.filterSpecified?o.filter.getConsolidated():[],l&&(c.stayingIntervals=c.stayingIntervals.filter(function(t){return t[0]!==l[0]&&t[1]!==l[1]})),c.startExtent=s.region?l[\"s\"===s.region?1:0]:a,e.parent.inBrushDrag=!0,c.brushStartCallback()}(this,t)}).on(\"drag\",function(t){_(this,t)}).on(\"dragend\",function(t){!function(t,e){var r=e.brush,n=r.filter,a=r.svgBrush;a._dragging||(w(t,e),_(t,e),e.brush.svgBrush.wasDragged=!1),a._dragging=!1,i.event.sourceEvent.stopPropagation();var o=a.grabbingBar;if(a.grabbingBar=!1,a.grabLocation=void 0,e.parent.inBrushDrag=!1,m(),!a.wasDragged)return a.wasDragged=void 0,a.clickableOrdinalRange?r.filterSpecified&&e.multiselect?a.extent.push(a.clickableOrdinalRange):(a.extent=[a.clickableOrdinalRange],r.filterSpecified=!0):o?(a.extent=a.stayingIntervals,0===a.extent.length&&A(r)):A(r),a.brushCallback(e),x(t.parentNode),void a.brushEndCallback(r.filterSpecified?n.getConsolidated():[]);var s=function(){n.set(n.getConsolidated())};if(e.ordinal){var l=e.unitTickvals;l[l.length-1]<l[0]&&l.reverse(),a.newExtent=[f(0,l,a.newExtent[0],a.stayingIntervals),f(1,l,a.newExtent[1],a.stayingIntervals)];var c=a.newExtent[1]>a.newExtent[0];a.extent=a.stayingIntervals.concat(c?[a.newExtent]:[]),a.extent.length||A(r),a.brushCallback(e),c?x(t.parentNode,s):(s(),x(t.parentNode))}else s();a.brushEndCallback(r.filterSpecified?n.getConsolidated():[])}(this,t)}))}function T(t,e){return t[0]-e[0]}function A(t){t.filterSpecified=!1,t.svgBrush.extent=[[-1/0,1/0]]}function M(t){for(var e,r=t.slice(),n=[],i=r.shift();i;){for(e=i.slice();(i=r.shift())&&i[0]<=e[1];)e[1]=Math.max(e[1],i[1]);n.push(e)}return n}e.exports={makeBrush:function(t,e,r,n,i,a){var o,l=function(){var t,e,r=[];return{set:function(n){1===(r=n.map(function(t){return t.slice().sort(s)}).sort(T)).length&&r[0][0]===-1/0&&r[0][1]===1/0&&(r=[[0,-1]]),t=M(r),e=r.reduce(function(t,e){return[Math.min(t[0],e[0]),Math.max(t[1],e[1])]},[1/0,-1/0])},get:function(){return r.slice()},getConsolidated:function(){return t},getBounds:function(){return e}}}();return l.set(r),{filter:l,filterSpecified:e,svgBrush:{extent:[],brushStartCallback:n,brushCallback:(o=i,function(t){var e=t.brush,r=function(t){return t.svgBrush.extent.map(function(t){return t.slice()})}(e).slice();e.filter.set(r),o()}),brushEndCallback:a}}},ensureAxisBrush:function(t){var e=t.selectAll(\".\"+n.cn.axisBrush).data(o,a);e.enter().append(\"g\").classed(n.cn.axisBrush,!0),function(t){var e=t.selectAll(\".background\").data(o);e.enter().append(\"rect\").classed(\"background\",!0).call(p).call(d).style(\"pointer-events\",\"auto\").attr(\"transform\",\"translate(0 \"+n.verticalPadding+\")\"),e.call(k).attr(\"height\",function(t){return t.height-n.verticalPadding});var r=t.selectAll(\".highlight-shadow\").data(o);r.enter().append(\"line\").classed(\"highlight-shadow\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width+n.bar.strokeWidth).attr(\"stroke\",n.bar.strokeColor).attr(\"opacity\",n.bar.strokeOpacity).attr(\"stroke-linecap\",\"butt\"),r.attr(\"y1\",function(t){return t.height}).call(y);var i=t.selectAll(\".highlight\").data(o);i.enter().append(\"line\").classed(\"highlight\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width-n.bar.strokeWidth).attr(\"stroke\",n.bar.fillColor).attr(\"opacity\",n.bar.fillOpacity).attr(\"stroke-linecap\",\"butt\"),i.attr(\"y1\",function(t){return t.height}).call(y)}(e)},cleanRanges:function(t,e){if(Array.isArray(t[0])?(t=t.map(function(t){return t.sort(s)}),t=e.multiselect?M(t.sort(T)):[t[0]]):t=[t.sort(s)],e.tickvals){var r=e.tickvals.slice().sort(s);if(!(t=t.map(function(t){var e=[f(0,r,t[0],[]),f(1,r,t[1],[])];if(e[1]>e[0])return e}).filter(function(t){return t})).length)return}return t.length>1?t:t[0]}}},{\"../../lib\":719,\"../../lib/gup\":717,\"./constants\":1078,d3:163}],1076:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../constants/xmlns_namespaces\");r.name=\"parcoords\",r.plot=function(t){var e=i(t.calcdata,\"parcoords\")[0];e.length&&a(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcoords\"),a=e._has&&e._has(\"parcoords\");i&&!a&&(n._paperdiv.selectAll(\".parcoords\").remove(),n._glimages.selectAll(\"*\").remove())},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter(function(t,e){return e===r.size()-1}).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each(function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})}),window.setTimeout(function(){n.selectAll(\"#filterBarPattern\").attr(\"id\",\"filterBarPattern\")},60)}},{\"../../constants/xmlns_namespaces\":696,\"../../plots/get_data\":802,\"./plot\":1085,d3:163}],1077:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale\"),a=t(\"../../lib/gup\").wrap;e.exports=function(t,e){var r,o;return i.hasColorscale(e,\"line\")&&n(e.line.color)?(r=e.line.color,o=i.extractOpts(e.line).colorscale,i.calc(t,e,{vals:r,containerStr:\"line\",cLetter:\"c\"})):(r=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=.5;return e}(e._length),o=[[0,e.line.color],[1,e.line.color]]),a({lineColor:r,cscale:o})}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gup\":717}],1078:[function(t,e,r){\"use strict\";e.exports={maxDimensionCount:60,overdrag:45,verticalPadding:2,tickDistance:50,canvasPixelRatio:1,blockLineCount:5e3,layers:[\"contextLineLayer\",\"focusLineLayer\",\"pickLineLayer\"],axisTitleOffset:28,axisExtentOffset:10,deselectedLineColor:\"#777\",bar:{width:4,captureWidth:10,fillColor:\"magenta\",fillOpacity:1,snapDuration:150,snapRatio:.25,snapClose:.01,strokeColor:\"white\",strokeOpacity:1,strokeWidth:1,handleHeight:8,handleOpacity:1,handleOverlap:0},cn:{axisExtentText:\"axis-extent-text\",parcoordsLineLayers:\"parcoords-line-layers\",parcoordsLineLayer:\"parcoords-lines\",parcoords:\"parcoords\",parcoordsControlView:\"parcoords-control-view\",yAxis:\"y-axis\",axisOverlays:\"axis-overlays\",axis:\"axis\",axisHeading:\"axis-heading\",axisTitle:\"axis-title\",axisExtent:\"axis-extent\",axisExtentTop:\"axis-extent-top\",axisExtentTopText:\"axis-extent-top-text\",axisExtentBottom:\"axis-extent-bottom\",axisExtentBottomText:\"axis-extent-bottom-text\",axisBrush:\"axis-brush\"},id:{filterBarPattern:\"filter-bar-pattern\"}}},{}],1079:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"../../plots/cartesian/axes\"),c=t(\"./attributes\"),u=t(\"./axisbrush\"),h=t(\"./constants\").maxDimensionCount,f=t(\"./merge_length\");function p(t,e,r,i){function a(r,i){return n.coerce(t,e,c.dimensions,r,i)}var o=a(\"values\"),s=a(\"visible\");if(o&&o.length||(s=e.visible=!1),s){a(\"label\"),a(\"tickvals\"),a(\"ticktext\"),a(\"tickformat\");var h=a(\"range\");e._ax={_id:\"y\",type:\"linear\",showexponent:\"all\",exponentformat:\"B\",range:h},l.setConvert(e._ax,i.layout),a(\"multiselect\");var f=a(\"constraintrange\");f&&(e.constraintrange=u.cleanRanges(f,e))}}e.exports=function(t,e,r,l){function u(r,i){return n.coerce(t,e,c,r,i)}var d=t.dimensions;Array.isArray(d)&&d.length>h&&(n.log(\"parcoords traces support up to \"+h+\" dimensions at the moment\"),d.splice(h));var g=s(t,e,{name:\"dimensions\",layout:l,handleItemDefaults:p}),v=function(t,e,r,o,s){var l=s(\"line.color\",r);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,l,u);o(e,l,u),Array.isArray(g)&&g.length||(e.visible=!1),f(e,g,\"values\",v);var m={family:l.font.family,size:Math.round(l.font.size/1.2),color:l.font.color};n.coerceFont(u,\"labelfont\",m),n.coerceFont(u,\"tickfont\",m),n.coerceFont(u,\"rangefont\",m),u(\"labelangle\"),u(\"labelside\")}},{\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"../../plots/domain\":792,\"./attributes\":1074,\"./axisbrush\":1075,\"./constants\":1078,\"./merge_length\":1083}],1080:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isTypedArray;r.convertTypedArray=function(t){return n(t)?Array.prototype.slice.call(t):t},r.isOrdinal=function(t){return!!t.tickvals},r.isVisible=function(t){return t.visible||!(\"visible\"in t)}},{\"../../lib\":719}],1081:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcoords\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"noOpacity\",\"noHover\"],meta:{}}},{\"./attributes\":1074,\"./base_plot\":1076,\"./calc\":1077,\"./defaults\":1079,\"./plot\":1085}],1082:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nattribute vec4 p01_04, p05_08, p09_12, p13_16,\\n               p17_20, p21_24, p25_28, p29_32,\\n               p33_36, p37_40, p41_44, p45_48,\\n               p49_52, p53_56, p57_60, colors;\\n\\nuniform mat4 dim0A, dim1A, dim0B, dim1B, dim0C, dim1C, dim0D, dim1D,\\n             loA, hiA, loB, hiB, loC, hiC, loD, hiD;\\n\\nuniform vec2 resolution, viewBoxPos, viewBoxSize;\\nuniform sampler2D mask, palette;\\nuniform float maskHeight;\\nuniform float drwLayer; // 0: context, 1: focus, 2: pick\\nuniform vec4 contextColor;\\n\\nbool isPick    = (drwLayer > 1.5);\\nbool isContext = (drwLayer < 0.5);\\n\\nconst vec4 ZEROS = vec4(0.0, 0.0, 0.0, 0.0);\\nconst vec4 UNITS = vec4(1.0, 1.0, 1.0, 1.0);\\n\\nfloat val(mat4 p, mat4 v) {\\n    return dot(matrixCompMult(p, v) * UNITS, UNITS);\\n}\\n\\nfloat axisY(float ratio, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float y1 = val(A, dim0A) + val(B, dim0B) + val(C, dim0C) + val(D, dim0D);\\n    float y2 = val(A, dim1A) + val(B, dim1B) + val(C, dim1C) + val(D, dim1D);\\n    return y1 * (1.0 - ratio) + y2 * ratio;\\n}\\n\\nint iMod(int a, int b) {\\n    return a - b * (a / b);\\n}\\n\\nbool fOutside(float p, float lo, float hi) {\\n    return (lo < hi) && (lo > p || p > hi);\\n}\\n\\nbool vOutside(vec4 p, vec4 lo, vec4 hi) {\\n    return (\\n        fOutside(p[0], lo[0], hi[0]) ||\\n        fOutside(p[1], lo[1], hi[1]) ||\\n        fOutside(p[2], lo[2], hi[2]) ||\\n        fOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool mOutside(mat4 p, mat4 lo, mat4 hi) {\\n    return (\\n        vOutside(p[0], lo[0], hi[0]) ||\\n        vOutside(p[1], lo[1], hi[1]) ||\\n        vOutside(p[2], lo[2], hi[2]) ||\\n        vOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool outsideBoundingBox(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    return mOutside(A, loA, hiA) ||\\n           mOutside(B, loB, hiB) ||\\n           mOutside(C, loC, hiC) ||\\n           mOutside(D, loD, hiD);\\n}\\n\\nbool outsideRasterMask(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    mat4 pnts[4];\\n    pnts[0] = A;\\n    pnts[1] = B;\\n    pnts[2] = C;\\n    pnts[3] = D;\\n\\n    for(int i = 0; i < 4; ++i) {\\n        for(int j = 0; j < 4; ++j) {\\n            for(int k = 0; k < 4; ++k) {\\n                if(0 == iMod(\\n                    int(255.0 * texture2D(mask,\\n                        vec2(\\n                            (float(i * 2 + j / 2) + 0.5) / 8.0,\\n                            (pnts[i][j][k] * (maskHeight - 1.0) + 1.0) / maskHeight\\n                        ))[3]\\n                    ) / int(pow(2.0, float(iMod(j * 4 + k, 8)))),\\n                    2\\n                )) return true;\\n            }\\n        }\\n    }\\n    return false;\\n}\\n\\nvec4 position(bool isContext, float v, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float x = 0.5 * sign(v) + 0.5;\\n    float y = axisY(x, A, B, C, D);\\n    float z = 1.0 - abs(v);\\n\\n    z += isContext ? 0.0 : 2.0 * float(\\n        outsideBoundingBox(A, B, C, D) ||\\n        outsideRasterMask(A, B, C, D)\\n    );\\n\\n    return vec4(\\n        2.0 * (vec2(x, y) * viewBoxSize + viewBoxPos) / resolution - 1.0,\\n        z,\\n        1.0\\n    );\\n}\\n\\nvoid main() {\\n    mat4 A = mat4(p01_04, p05_08, p09_12, p13_16);\\n    mat4 B = mat4(p17_20, p21_24, p25_28, p29_32);\\n    mat4 C = mat4(p33_36, p37_40, p41_44, p45_48);\\n    mat4 D = mat4(p49_52, p53_56, p57_60, ZEROS);\\n\\n    float v = colors[3];\\n\\n    gl_Position = position(isContext, v, A, B, C, D);\\n\\n    fragColor =\\n        isContext ? vec4(contextColor) :\\n        isPick ? vec4(colors.rgb, 1.0) : texture2D(palette, vec2(abs(v), 0.5));\\n}\\n\"]),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n    gl_FragColor = fragColor;\\n}\\n\"]),o=t(\"./constants\").maxDimensionCount,s=t(\"../../lib\"),l=1e-6,c=2048,u=new Uint8Array(4),h=new Uint8Array(4),f={shape:[256,1],format:\"rgba\",type:\"uint8\",mag:\"nearest\",min:\"nearest\"};function p(t,e,r,n,i){var a=t._gl;a.enable(a.SCISSOR_TEST),a.scissor(e,r,n,i),t.clear({color:[0,0,0,0],depth:1})}function d(t,e,r,n,i,a){var o=a.key;r.drawCompleted||(!function(t){t.read({x:0,y:0,width:1,height:1,data:u})}(t),r.drawCompleted=!0),function s(l){var c=Math.min(n,i-l*n);0===l&&(window.cancelAnimationFrame(r.currentRafs[o]),delete r.currentRafs[o],p(t,a.scissorX,a.scissorY,a.scissorWidth,a.viewBoxSize[1])),r.clearOnly||(a.count=2*c,a.offset=2*l*n,e(a),l*n+c<i&&(r.currentRafs[o]=window.requestAnimationFrame(function(){s(l+1)})),r.drawCompleted=!1)}(0)}function g(t,e){return(t>>>8*e)%256/255}function v(t,e,r){for(var n=new Array(8*e),i=0,a=0;a<e;a++)for(var o=0;o<2;o++)for(var s=0;s<4;s++){var l=4*t+s,c=r[64*a+l];63===l&&0===o&&(c*=-1),n[i++]=c}return n}function m(t){var e=\"0\"+t;return e.substr(e.length-2)}function y(t){return t<o?\"p\"+m(t+1)+\"_\"+m(t+4):\"colors\"}function x(t,e,r,n,i,a,o,l,c,u,h,f,p){for(var d=[[],[]],g=0;g<64;g++)d[0][g]=g===i?1:0,d[1][g]=g===a?1:0;var v=t.lines.canvasOverdrag,m=t.domain,y=t.canvasWidth,x=t.canvasHeight,b=t.deselectedLines.color;return s.extendFlat({key:h,resolution:[y,x],viewBoxPos:[o+v,l],viewBoxSize:[c,u],i0:i,i1:a,dim0A:d[0].slice(0,16),dim0B:d[0].slice(16,32),dim0C:d[0].slice(32,48),dim0D:d[0].slice(48,64),dim1A:d[1].slice(0,16),dim1B:d[1].slice(16,32),dim1C:d[1].slice(32,48),dim1D:d[1].slice(48,64),drwLayer:f,contextColor:[b[0]/255,b[1]/255,b[2]/255,b[3]<1?b[3]:Math.max(1/255,Math.pow(1/t.lines.color.length,1/3))],scissorX:(n===e?0:o+v)+(t.pad.l-v)+t.layoutWidth*m.x[0],scissorWidth:(n===r?y-o+v:c+.5)+(n===e?o+v:0),scissorY:l+t.pad.b+t.layoutHeight*m.y[0],scissorHeight:u,viewportX:t.pad.l-v+t.layoutWidth*m.x[0],viewportY:t.pad.b+t.layoutHeight*m.y[0],viewportWidth:y,viewportHeight:x},p)}function b(t){var e=c-1,r=Math.max(0,Math.floor(t[0]*e),0),n=Math.min(e,Math.ceil(t[1]*e),e);return[Math.min(r,n),Math.max(r,n)]}e.exports=function(t,e){var r,n,u,m,_,w=e.context,k=e.pick,T=e.regl,A={currentRafs:{},drawCompleted:!0,clearOnly:!1},M=function(t){for(var e={},r=0;r<=o;r+=4)e[y(r)]=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)});return e}(T),S=T.texture(f),E=[];L(e);var C=T({profile:!1,blend:{enable:w,func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:1,dstAlpha:1},equation:{rgb:\"add\",alpha:\"add\"},color:[0,0,0,0]},depth:{enable:!w,mask:!0,func:\"less\",range:[0,1]},cull:{enable:!0,face:\"back\"},scissor:{enable:!0,box:{x:T.prop(\"scissorX\"),y:T.prop(\"scissorY\"),width:T.prop(\"scissorWidth\"),height:T.prop(\"scissorHeight\")}},viewport:{x:T.prop(\"viewportX\"),y:T.prop(\"viewportY\"),width:T.prop(\"viewportWidth\"),height:T.prop(\"viewportHeight\")},dither:!1,vert:i,frag:a,primitive:\"lines\",lineWidth:1,attributes:M,uniforms:{resolution:T.prop(\"resolution\"),viewBoxPos:T.prop(\"viewBoxPos\"),viewBoxSize:T.prop(\"viewBoxSize\"),dim0A:T.prop(\"dim0A\"),dim1A:T.prop(\"dim1A\"),dim0B:T.prop(\"dim0B\"),dim1B:T.prop(\"dim1B\"),dim0C:T.prop(\"dim0C\"),dim1C:T.prop(\"dim1C\"),dim0D:T.prop(\"dim0D\"),dim1D:T.prop(\"dim1D\"),loA:T.prop(\"loA\"),hiA:T.prop(\"hiA\"),loB:T.prop(\"loB\"),hiB:T.prop(\"hiB\"),loC:T.prop(\"loC\"),hiC:T.prop(\"hiC\"),loD:T.prop(\"loD\"),hiD:T.prop(\"hiD\"),palette:S,contextColor:T.prop(\"contextColor\"),mask:T.prop(\"maskTexture\"),drwLayer:T.prop(\"drwLayer\"),maskHeight:T.prop(\"maskHeight\")},offset:T.prop(\"offset\"),count:T.prop(\"count\")});function L(t){r=t.model,n=t.viewModel,u=n.dimensions.slice(),m=u[0]?u[0].values.length:0;var e=r.lines,i=k?e.color.map(function(t,r){return r/e.color.length}):e.color,a=function(t,e,r){for(var n,i=new Array(t*(o+4)),a=0,s=0;s<t;s++){for(var c=0;c<o;c++)i[a++]=c<e.length?e[c].paddedUnitValues[s]:.5;i[a++]=g(s,2),i[a++]=g(s,1),i[a++]=g(s,0),i[a++]=(n=r[s],Math.max(l,Math.min(1-l,n)))}return i}(m,u,i);!function(t,e,r){for(var n=0;n<=o;n+=4)t[y(n)](v(n/4,e,r))}(M,m,a),w||k||(S=T.texture(s.extendFlat({data:function(t,e){for(var r=new Array(256),n=0;n<256;n++)r[n]=t(n/255).concat(e);return r}(r.unitToColor,255)},f)))}return{render:function(t,e,n){var i,a,o,s=t.length,l=1/0,h=-1/0;for(i=0;i<s;i++)t[i].dim0.canvasX<l&&(l=t[i].dim0.canvasX,a=i),t[i].dim1.canvasX>h&&(h=t[i].dim1.canvasX,o=i);0===s&&p(T,0,0,r.canvasWidth,r.canvasHeight);var f=function(t){var e,r,n,i=[[],[]];for(n=0;n<64;n++){var a=!t&&n<u.length?u[n].brush.filter.getBounds():[-1/0,1/0];i[0][n]=a[0],i[1][n]=a[1]}var o=8*c,s=new Array(o);for(e=0;e<o;e++)s[e]=255;if(!t)for(e=0;e<u.length;e++){var l=e%8,h=(e-l)/8,f=Math.pow(2,l),p=u[e].brush.filter.get();if(!(p.length<2)){var d=b(p[0])[1];for(r=1;r<p.length;r++){var g=b(p[r]);for(n=d+1;n<g[0];n++)s[8*n+h]&=~f;d=Math.max(d,g[1])}}}var v={shape:[8,c],format:\"alpha\",type:\"uint8\",mag:\"nearest\",min:\"nearest\",data:s};return _?_(v):_=T.texture(v),{maskTexture:_,maskHeight:c,loA:i[0].slice(0,16),loB:i[0].slice(16,32),loC:i[0].slice(32,48),loD:i[0].slice(48,64),hiA:i[1].slice(0,16),hiB:i[1].slice(16,32),hiC:i[1].slice(32,48),hiD:i[1].slice(48,64)}}(w);for(i=0;i<s;i++){var g=t[i],v=g.dim0.crossfilterDimensionIndex,y=g.dim1.crossfilterDimensionIndex,M=g.canvasX,S=g.canvasY,L=M+g.panelSizeX;if(e||!E[v]||E[v][0]!==M||E[v][1]!==L){E[v]=[M,L];var P=x(r,a,o,i,v,y,M,S,g.panelSizeX,g.panelSizeY,g.dim0.crossfilterDimensionIndex,w?0:k?2:1,f);A.clearOnly=n;var O=e?r.lines.blockLineCount:m;d(T,C,A,O,m,P)}}},readPixel:function(t,e){return T.read({x:t,y:e,width:1,height:1,data:h}),h},readPixels:function(t,e,r,n){var i=new Uint8Array(4*r*n);return T.read({x:t,y:e,width:r,height:n,data:i}),i},destroy:function(){for(var e in t.style[\"pointer-events\"]=\"none\",S.destroy(),_&&_.destroy(),M)M[e].destroy()},update:L}}},{\"../../lib\":719,\"./constants\":1078,glslify:409}],1083:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a;for(n||(n=1/0),i=0;i<e.length;i++)(a=e[i]).visible&&(n=Math.min(n,a[r].length));for(n===1/0&&(n=0),t._length=n,i=0;i<e.length;i++)(a=e[i]).visible&&(a._length=n);return n}},{}],1084:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"color-rgba\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../components/drawing\"),c=t(\"../../components/colorscale\"),u=t(\"../../lib/gup\"),h=u.keyFun,f=u.repeat,p=u.unwrap,d=t(\"./helpers\"),g=t(\"./constants\"),v=t(\"./axisbrush\"),m=t(\"./lines\");function y(t,e,r){return o.aggNums(t,null,e,r)}function x(t,e){return _(y(Math.min,t,e),y(Math.max,t,e))}function b(t){var e=t.range;return e?_(e[0],e[1]):x(t.values,t._length)}function _(t,e){return!isNaN(t)&&isFinite(t)||(t=0),!isNaN(e)&&isFinite(e)||(e=0),t===e&&(0===t?(t-=1,e+=1):(t*=.9,e*=1.1)),[t,e]}function w(t){return t.dimensions.some(function(t){return t.brush.filterSpecified})}function k(t,e,r){var a=p(e),s=a.trace,l=d.convertTypedArray(a.lineColor),u=s.line,h={color:i(g.deselectedLineColor)},f=c.extractOpts(u),v=f.reversescale?c.flipScale(a.cscale):a.cscale,m=s.domain,y=s.dimensions,x=t.width,_=s.labelangle,w=s.labelside,k=s.labelfont,T=s.tickfont,A=s.rangefont,M=o.extendDeepNoArrays({},u,{color:l.map(n.scale.linear().domain(b({values:l,range:[f.min,f.max],_length:s._length}))),blockLineCount:g.blockLineCount,canvasOverdrag:g.overdrag*g.canvasPixelRatio}),S=Math.floor(x*(m.x[1]-m.x[0])),E=Math.floor(t.height*(m.y[1]-m.y[0])),C=t.margin||{l:80,r:80,t:100,b:80},L=S,P=E;return{key:r,colCount:y.filter(d.isVisible).length,dimensions:y,tickDistance:g.tickDistance,unitToColor:function(t){var e=t.map(function(t){return t[0]}),r=t.map(function(t){var e=i(t[1]);return n.rgb(\"rgb(\"+e[0]+\",\"+e[1]+\",\"+e[2]+\")\")}),a=\"rgb\".split(\"\").map(function(t){return n.scale.linear().clamp(!0).domain(e).range(r.map((i=t,function(t){return t[i]})));var i});return function(t){return a.map(function(e){return e(t)})}}(v),lines:M,deselectedLines:h,labelAngle:_,labelSide:w,labelFont:k,tickFont:T,rangeFont:A,layoutWidth:x,layoutHeight:t.height,domain:m,translateX:m.x[0]*x,translateY:t.height-m.y[1]*t.height,pad:C,canvasWidth:L*g.canvasPixelRatio+2*M.canvasOverdrag,canvasHeight:P*g.canvasPixelRatio,width:L,height:P,canvasPixelRatio:g.canvasPixelRatio}}function T(t,e,r){var i=r.width,a=r.height,s=r.dimensions,l=r.canvasPixelRatio,c=function(t){return i*t/Math.max(1,r.colCount-1)},u=g.verticalPadding/a,h=function(t,e){return n.scale.linear().range([e,t-e])}(a,g.verticalPadding),f={key:r.key,xScale:c,model:r,inBrushDrag:!1},p={};return f.dimensions=s.filter(d.isVisible).map(function(i,s){var m=function(t,e){return n.scale.linear().domain(b(t)).range([e,1-e])}(i,u),y=p[i.label];p[i.label]=(y||0)+1;var x=i.label+(y?\"__\"+y:\"\"),_=i.constraintrange,k=_&&_.length;k&&!Array.isArray(_[0])&&(_=[_]);var T=k?_.map(function(t){return t.map(m)}):[[-1/0,1/0]],A=i.values;A.length>i._length&&(A=A.slice(0,i._length));var M,S=i.tickvals;function E(t,e){return{val:t,text:M[e]}}function C(t,e){return t.val-e.val}if(Array.isArray(S)&&S.length){M=i.ticktext,Array.isArray(M)&&M.length?M.length>S.length?M=M.slice(0,S.length):S.length>M.length&&(S=S.slice(0,M.length)):M=S.map(n.format(i.tickformat));for(var L=1;L<S.length;L++)if(S[L]<S[L-1]){for(var P=S.map(E).sort(C),O=0;O<S.length;O++)S[O]=P[O].val,M[O]=P[O].text;break}}else S=void 0;return A=d.convertTypedArray(A),A=d.convertTypedArray(A),{key:x,label:i.label,tickFormat:i.tickformat,tickvals:S,ticktext:M,ordinal:d.isOrdinal(i),multiselect:i.multiselect,xIndex:s,crossfilterDimensionIndex:s,visibleIndex:i._index,height:a,values:A,paddedUnitValues:A.map(m),unitTickvals:S&&S.map(m),xScale:c,x:c(s),canvasX:c(s)*l,unitToPaddedPx:h,domainScale:function(t,e,r,i,a){var o,s,l=b(r);return i?n.scale.ordinal().domain(i.map((o=n.format(r.tickformat),s=a,s?function(t,e){var r=s[e];return null==r?o(t):r}:o))).range(i.map(function(r){var n=(r-l[0])/(l[1]-l[0]);return t-e+n*(2*e-t)})):n.scale.linear().domain(l).range([t-e,e])}(a,g.verticalPadding,i,S,M),ordinalScale:function(t){if(t.tickvals){var e=b(t);return n.scale.ordinal().domain(t.tickvals).range(t.tickvals.map(function(t){return(t-e[0])/(e[1]-e[0])}))}}(i),parent:f,model:r,brush:v.makeBrush(t,k,T,function(){t.linePickActive(!1)},function(){var e=f;e.focusLayer&&e.focusLayer.render(e.panels,!0);var r=w(e);!t.contextShown()&&r?(e.contextLayer&&e.contextLayer.render(e.panels,!0),t.contextShown(!0)):t.contextShown()&&!r&&(e.contextLayer&&e.contextLayer.render(e.panels,!0,!0),t.contextShown(!1))},function(r){if(f.focusLayer.render(f.panels,!0),f.pickLayer&&f.pickLayer.render(f.panels,!0),t.linePickActive(!0),e&&e.filterChanged){var n=m.invert,a=r.map(function(t){return t.map(n).sort(o.sorterAsc)}).sort(function(t,e){return t[0]-e[0]});e.filterChanged(f.key,i._index,a)}})}}),f}function A(t){t.classed(g.cn.axisExtentText,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"default\").style(\"user-select\",\"none\")}function M(t,e){var r=\"top\"===e?1:-1,n=t*Math.PI/180;return{dir:r,dx:Math.sin(n),dy:Math.cos(n),degrees:t}}function S(t,e){for(var r=e.panels||(e.panels=[]),n=t.data(),i=0;i<n.length-1;i++){var a=r[i]||(r[i]={}),o=n[i],s=n[i+1];a.dim0=o,a.dim1=s,a.canvasX=o.canvasX,a.panelSizeX=s.canvasX-o.canvasX,a.panelSizeY=e.model.canvasHeight,a.y=0,a.canvasY=0}}function E(t,e){return a.tickText(t._ax,e,!1).text}function C(t,e){if(t.ordinal)return\"\";var r=t.domainScale.domain(),n=r[e?r.length-1:0];return E(t.model.dimensions[t.visibleIndex],n)}e.exports=function(t,e,r,i){var c=t._fullLayout,u=c._toppaper,y=c._glcontainer;!function(t){for(var e=0;e<t.length;e++)for(var r=0;r<t[e].length;r++)for(var n=t[e][r].trace,i=n.dimensions,o=0;o<i.length;o++){var s=i[o].values,l=i[o]._ax;l&&(l.range?l.range=_(l.range[0],l.range[1]):l.range=x(s,n._length),l.dtick||(l.dtick=.01*(Math.abs(l.range[1]-l.range[0])||1)),l.tickformat=i[o].tickformat,a.calcTicks(l),l.cleanRange())}}(e);var b,L,P=(b=!0,L=!1,{linePickActive:function(t){return arguments.length?b=!!t:b},contextShown:function(t){return arguments.length?L=!!t:L}}),O=e.filter(function(t){return p(t).trace.visible}).map(k.bind(0,r)).map(T.bind(0,P,i));y.each(function(t,e){return o.extendFlat(t,O[e])});var z=y.selectAll(\".gl-canvas\").each(function(t){t.viewModel=O[0],t.model=t.viewModel?t.viewModel.model:null}),I=null;z.filter(function(t){return t.pick}).style(\"pointer-events\",\"auto\").on(\"mousemove\",function(t){if(P.linePickActive()&&t.lineLayer&&i&&i.hover){var e=n.event,r=this.width,a=this.height,o=n.mouse(this),s=o[0],l=o[1];if(s<0||l<0||s>=r||l>=a)return;var c=t.lineLayer.readPixel(s,a-1-l),u=0!==c[3],h=u?c[2]+256*(c[1]+256*c[0]):null,f={x:s,y:l,clientX:e.clientX,clientY:e.clientY,dataIndex:t.model.key,curveNumber:h};h!==I&&(u?i.hover(f):i.unhover&&i.unhover(f),I=h)}}),z.style(\"opacity\",function(t){return t.pick?0:1}),u.style(\"background\",\"rgba(255, 255, 255, 0)\");var D=u.selectAll(\".\"+g.cn.parcoords).data(O,h);D.exit().remove(),D.enter().append(\"g\").classed(g.cn.parcoords,!0).style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"none\"),D.attr(\"transform\",function(t){return\"translate(\"+t.model.translateX+\",\"+t.model.translateY+\")\"});var R=D.selectAll(\".\"+g.cn.parcoordsControlView).data(f,h);R.enter().append(\"g\").classed(g.cn.parcoordsControlView,!0),R.attr(\"transform\",function(t){return\"translate(\"+t.model.pad.l+\",\"+t.model.pad.t+\")\"});var F=R.selectAll(\".\"+g.cn.yAxis).data(function(t){return t.dimensions},h);F.enter().append(\"g\").classed(g.cn.yAxis,!0),R.each(function(t){S(F,t)}),z.each(function(t){if(t.viewModel){!t.lineLayer||i?t.lineLayer=m(this,t):t.lineLayer.update(t),(t.key||0===t.key)&&(t.viewModel[t.key]=t.lineLayer);var e=!t.context||i;t.lineLayer.render(t.viewModel.panels,e)}}),F.attr(\"transform\",function(t){return\"translate(\"+t.xScale(t.xIndex)+\", 0)\"}),F.call(n.behavior.drag().origin(function(t){return t}).on(\"drag\",function(t){var e=t.parent;P.linePickActive(!1),t.x=Math.max(-g.overdrag,Math.min(t.model.width+g.overdrag,n.event.x)),t.canvasX=t.x*t.model.canvasPixelRatio,F.sort(function(t,e){return t.x-e.x}).each(function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e.xIndex),e.canvasX=e.x*e.model.canvasPixelRatio}),S(F,e),F.filter(function(e){return 0!==Math.abs(t.xIndex-e.xIndex)}).attr(\"transform\",function(t){return\"translate(\"+t.xScale(t.xIndex)+\", 0)\"}),n.select(this).attr(\"transform\",\"translate(\"+t.x+\", 0)\"),F.each(function(r,n,i){i===t.parent.key&&(e.dimensions[n]=r)}),e.contextLayer&&e.contextLayer.render(e.panels,!1,!w(e)),e.focusLayer.render&&e.focusLayer.render(e.panels)}).on(\"dragend\",function(t){var e=t.parent;t.x=t.xScale(t.xIndex),t.canvasX=t.x*t.model.canvasPixelRatio,S(F,e),n.select(this).attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),e.contextLayer&&e.contextLayer.render(e.panels,!1,!w(e)),e.focusLayer&&e.focusLayer.render(e.panels),e.pickLayer&&e.pickLayer.render(e.panels,!0),P.linePickActive(!0),i&&i.axesMoved&&i.axesMoved(e.key,e.dimensions.map(function(t){return t.crossfilterDimensionIndex}))})),F.exit().remove();var B=F.selectAll(\".\"+g.cn.axisOverlays).data(f,h);B.enter().append(\"g\").classed(g.cn.axisOverlays,!0),B.selectAll(\".\"+g.cn.axis).remove();var N=B.selectAll(\".\"+g.cn.axis).data(f,h);N.enter().append(\"g\").classed(g.cn.axis,!0),N.each(function(t){var e=t.model.height/t.model.tickDistance,r=t.domainScale,i=r.domain();n.select(this).call(n.svg.axis().orient(\"left\").tickSize(4).outerTickSize(2).ticks(e,t.tickFormat).tickValues(t.ordinal?i:null).tickFormat(function(e){return d.isOrdinal(t)?e:E(t.model.dimensions[t.visibleIndex],e)}).scale(r)),l.font(N.selectAll(\"text\"),t.model.tickFont)}),N.selectAll(\".domain, .tick>line\").attr(\"fill\",\"none\").attr(\"stroke\",\"black\").attr(\"stroke-opacity\",.25).attr(\"stroke-width\",\"1px\"),N.selectAll(\"text\").style(\"text-shadow\",\"1px 1px 1px #fff, -1px -1px 1px #fff, 1px -1px 1px #fff, -1px 1px 1px #fff\").style(\"cursor\",\"default\").style(\"user-select\",\"none\");var j=B.selectAll(\".\"+g.cn.axisHeading).data(f,h);j.enter().append(\"g\").classed(g.cn.axisHeading,!0);var U=j.selectAll(\".\"+g.cn.axisTitle).data(f,h);U.enter().append(\"text\").classed(g.cn.axisTitle,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"ew-resize\").style(\"user-select\",\"none\").style(\"pointer-events\",\"auto\"),U.text(function(t){return t.label}).each(function(e){var r=n.select(this);l.font(r,e.model.labelFont),s.convertToTspans(r,t)}).attr(\"transform\",function(t){var e=M(t.model.labelAngle,t.model.labelSide),r=g.axisTitleOffset;return(e.dir>0?\"\":\"translate(0,\"+(2*r+t.model.height)+\")\")+\"rotate(\"+e.degrees+\")translate(\"+-r*e.dx+\",\"+-r*e.dy+\")\"}).attr(\"text-anchor\",function(t){var e=M(t.model.labelAngle,t.model.labelSide);return 2*Math.abs(e.dx)>Math.abs(e.dy)?e.dir*e.dx<0?\"start\":\"end\":\"middle\"});var V=B.selectAll(\".\"+g.cn.axisExtent).data(f,h);V.enter().append(\"g\").classed(g.cn.axisExtent,!0);var q=V.selectAll(\".\"+g.cn.axisExtentTop).data(f,h);q.enter().append(\"g\").classed(g.cn.axisExtentTop,!0),q.attr(\"transform\",\"translate(0,\"+-g.axisExtentOffset+\")\");var H=q.selectAll(\".\"+g.cn.axisExtentTopText).data(f,h);H.enter().append(\"text\").classed(g.cn.axisExtentTopText,!0).call(A),H.text(function(t){return C(t,!0)}).each(function(t){l.font(n.select(this),t.model.rangeFont)});var G=V.selectAll(\".\"+g.cn.axisExtentBottom).data(f,h);G.enter().append(\"g\").classed(g.cn.axisExtentBottom,!0),G.attr(\"transform\",function(t){return\"translate(0,\"+(t.model.height+g.axisExtentOffset)+\")\"});var Y=G.selectAll(\".\"+g.cn.axisExtentBottomText).data(f,h);Y.enter().append(\"text\").classed(g.cn.axisExtentBottomText,!0).attr(\"dy\",\"0.75em\").call(A),Y.text(function(t){return C(t,!1)}).each(function(t){l.font(n.select(this),t.model.rangeFont)}),v.ensureAxisBrush(B)}},{\"../../components/colorscale\":605,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/gup\":717,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"./axisbrush\":1075,\"./constants\":1078,\"./helpers\":1080,\"./lines\":1082,\"color-rgba\":122,d3:163}],1085:[function(t,e,r){\"use strict\";var n=t(\"./parcoords\"),i=t(\"../../lib/prepare_regl\"),a=t(\"./helpers\").isVisible;function o(t,e,r){var n=e.indexOf(r),i=t.indexOf(n);return-1===i&&(i+=e.length),i}e.exports=function(t,e){var r=t._fullLayout;if(i(t)){var s={},l={},c={},u={},h=r._size;e.forEach(function(e,r){var n=e[0].trace;c[r]=n.index;var i=u[r]=n._fullInput.index;s[r]=t.data[i].dimensions,l[r]=t.data[i].dimensions.slice()});n(t,e,{width:h.w,height:h.h,margin:{t:h.t,r:h.r,b:h.b,l:h.l}},{filterChanged:function(e,n,i){var a=l[e][n],o=i.map(function(t){return t.slice()}),s=\"dimensions[\"+n+\"].constraintrange\",h=r._tracePreGUI[t._fullData[c[e]]._fullInput.uid];if(void 0===h[s]){var f=a.constraintrange;h[s]=f||null}var p=t._fullData[c[e]].dimensions[n];o.length?(1===o.length&&(o=o[0]),a.constraintrange=o,p.constraintrange=o.slice(),o=[o]):(delete a.constraintrange,delete p.constraintrange,o=null);var d={};d[s]=o,t.emit(\"plotly_restyle\",[d,[u[e]]])},hover:function(e){t.emit(\"plotly_hover\",e)},unhover:function(e){t.emit(\"plotly_unhover\",e)},axesMoved:function(e,r){var n=function(t,e){return function(r,n){return o(t,e,r)-o(t,e,n)}}(r,l[e].filter(a));s[e].sort(n),l[e].filter(function(t){return!a(t)}).sort(function(t){return l[e].indexOf(t)}).forEach(function(t){s[e].splice(s[e].indexOf(t),1),s[e].splice(l[e].indexOf(t),0,t)}),t.emit(\"plotly_restyle\",[{dimensions:[s[e]]},[u[e]]])}})}}},{\"../../lib/prepare_regl\":732,\"./helpers\":1080,\"./parcoords\":1084}],1086:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../plots/domain\").attributes,a=t(\"../../plots/font_attributes\"),o=t(\"../../components/color/attributes\"),s=t(\"../../components/fx/hovertemplate_attributes\"),l=t(\"../../lib/extend\").extendFlat,c=a({editType:\"plot\",arrayOk:!0,colorEditType:\"plot\"});e.exports={labels:{valType:\"data_array\",editType:\"calc\"},label0:{valType:\"number\",dflt:0,editType:\"calc\"},dlabel:{valType:\"number\",dflt:1,editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},marker:{colors:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:o.defaultLine,arrayOk:!0,editType:\"style\"},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0,editType:\"style\"},editType:\"calc\"},editType:\"calc\"},text:{valType:\"data_array\",editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"value\",\"percent\"],extras:[\"none\"],editType:\"calc\"},hoverinfo:l({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:s({},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"auto\",arrayOk:!0,editType:\"plot\"},textfont:l({},c,{}),insidetextfont:l({},c,{}),outsidetextfont:l({},c,{}),title:{text:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:l({},c,{}),position:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"plot\"},editType:\"plot\"},domain:i({name:\"pie\",trace:!0,editType:\"calc\"}),hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},sort:{valType:\"boolean\",dflt:!0,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"number\",min:-360,max:360,dflt:0,editType:\"calc\"},pull:{valType:\"number\",min:0,max:1,dflt:0,arrayOk:!0,editType:\"calc\"},_deprecated:{title:{valType:\"string\",dflt:\"\",editType:\"calc\"},titlefont:l({},c,{}),titleposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"calc\"}}}},{\"../../components/color/attributes\":592,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1087:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData;r.name=\"pie\",r.plot=function(t){var e=n.getModule(\"pie\"),r=i(t.calcdata,e)[0];e.plot(t,r)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"pie\"),a=e._has&&e._has(\"pie\");i&&!a&&n._pielayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],1088:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"tinycolor2\"),o=t(\"../../components/color\"),s=t(\"./helpers\"),l=t(\"../../lib\").isValidTextValue,c={};function u(t){return function(e,r){return!!e&&(!!(e=a(e)).isValid()&&(e=o.addOpacity(e,e.getAlpha()),t[r]||(t[r]=e),e))}}function h(t,e){var r,n=JSON.stringify(t),i=e[n];if(!i){for(i=t.slice(),r=0;r<t.length;r++)i.push(a(t[r]).lighten(20).toHexString());for(r=0;r<t.length;r++)i.push(a(t[r]).darken(20).toHexString());e[n]=i}return i}e.exports={calc:function(t,e){var r,a,o=[],c=t._fullLayout,h=c.hiddenlabels||[],f=e.labels,p=e.marker.colors||[],d=e.values,g=i(d)&&d.length;if(e.dlabel)for(f=new Array(d.length),r=0;r<d.length;r++)f[r]=String(e.label0+r*e.dlabel);var v={},m=u(c[\"_\"+e.type+\"colormap\"]),y=(g?d:f).length,x=0,b=!1;for(r=0;r<y;r++){var _,w,k;if(g){if(_=d[r],!n(_))continue;if((_=+_)<0)continue}else _=1;void 0!==(w=f[r])&&\"\"!==w||(w=r);var T=v[w=String(w)];void 0===T?(v[w]=o.length,(k=-1!==h.indexOf(w))||(x+=_),o.push({v:_,label:w,color:m(p[r],w),i:r,pts:[r],hidden:k})):(b=!0,(a=o[T]).v+=_,a.pts.push(r),a.hidden||(x+=_),!1===a.color&&p[r]&&(a.color=m(p[r],w)))}(\"funnelarea\"===e.type?b:e.sort)&&o.sort(function(t,e){return e.v-t.v}),o[0]&&(o[0].vTotal=x);var A=e.textinfo;if(A&&\"none\"!==A){var M,S=A.split(\"+\"),E=function(t){return-1!==S.indexOf(t)},C=E(\"label\"),L=E(\"text\"),P=E(\"value\"),O=E(\"percent\"),z=c.separators;for(r=0;r<o.length;r++){if(a=o[r],M=C?[a.label]:[],L){var I=s.getFirstFilled(e.text,a.pts);l(I)&&M.push(I)}P&&M.push(s.formatPieValue(a.v,z)),O&&M.push(s.formatPiePercent(a.v/x,z)),a.text=M.join(\"<br>\")}}return o},crossTraceCalc:function(t,e){var r=(e||{}).type;r||(r=\"pie\");var n=t._fullLayout,i=t.calcdata,a=n[r+\"colorway\"],o=n[\"_\"+r+\"colormap\"];n[\"extend\"+r+\"colors\"]&&(a=h(a,c));for(var s=0,l=0;l<i.length;l++){var u=i[l];if(u[0].trace.type===r)for(var f=0;f<u.length;f++){var p=u[f];!1===p.color&&(o[p.label]?p.color=o[p.label]:(o[p.label]=p.color=a[s%a.length],s++))}}},makePullColorFn:u,generateExtendedColors:h}},{\"../../components/color\":593,\"../../lib\":719,\"./helpers\":1091,\"fast-isnumeric\":225,tinycolor2:537}],1089:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}var c,u=l(\"values\"),h=n.isArrayOrTypedArray(u),f=l(\"labels\");if(Array.isArray(f)?(c=f.length,h&&(c=Math.min(c,u.length))):h&&(c=u.length,l(\"label0\"),l(\"dlabel\")),c){e._length=c,l(\"marker.line.width\")&&l(\"marker.line.color\"),l(\"marker.colors\"),l(\"scalegroup\");var p=l(\"text\"),d=l(\"textinfo\",Array.isArray(p)?\"text+percent\":\"percent\");if(l(\"hovertext\"),l(\"hovertemplate\"),d&&\"none\"!==d){var g=l(\"textposition\");o(t,e,s,l,g,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}a(e,s,l);var v=l(\"hole\");if(l(\"title.text\")){var m=l(\"title.position\",v?\"middle center\":\"top center\");v||\"middle center\"!==m||(e.title.position=\"top center\"),n.coerceFont(l,\"title.font\",s.font)}l(\"sort\"),l(\"direction\"),l(\"rotation\"),l(\"pull\")}else e.visible=!1}},{\"../../lib\":719,\"../../plots/domain\":792,\"../bar/defaults\":861,\"./attributes\":1086}],1090:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/helpers\").appendArrayMultiPointValues;e.exports=function(t,e){var r={curveNumber:e.index,pointNumbers:t.pts,data:e._input,fullData:e,label:t.label,color:t.color,value:t.v,percent:t.percent,text:t.text,v:t.v};return 1===t.pts.length&&(r.pointNumber=r.i=t.pts[0]),n(r,e,t.pts),\"funnelarea\"===e.type&&(delete r.v,delete r.i),r}},{\"../../components/fx/helpers\":628}],1091:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");r.formatPiePercent=function(t,e){var r=(100*t).toPrecision(3);return-1!==r.lastIndexOf(\".\")&&(r=r.replace(/[.]?0+$/,\"\")),n.numSeparate(r,e)+\"%\"},r.formatPieValue=function(t,e){var r=t.toPrecision(10);return-1!==r.lastIndexOf(\".\")&&(r=r.replace(/[.]?0+$/,\"\")),n.numSeparate(r,e)},r.getFirstFilled=function(t,e){if(Array.isArray(t))for(var r=0;r<e.length;r++){var n=t[e[r]];if(n||0===n)return n}},r.castOption=function(t,e){return Array.isArray(t)?r.getFirstFilled(t,e):t||void 0}},{\"../../lib\":719}],1092:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),layoutAttributes:t(\"./layout_attributes\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\"),styleOne:t(\"./style_one\"),moduleType:\"trace\",name:\"pie\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"pie\",\"showLegend\"],meta:{}}},{\"./attributes\":1086,\"./base_plot\":1087,\"./calc\":1088,\"./defaults\":1089,\"./layout_attributes\":1093,\"./layout_defaults\":1094,\"./plot\":1095,\"./style\":1096,\"./style_one\":1097}],1093:[function(t,e,r){\"use strict\";e.exports={hiddenlabels:{valType:\"data_array\",editType:\"calc\"},piecolorway:{valType:\"colorlist\",editType:\"calc\"},extendpiecolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1094:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"piecolorway\",e.colorway),r(\"extendpiecolors\")}},{\"../../lib\":719,\"./layout_attributes\":1093}],1095:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/fx\"),a=t(\"../../components/color\"),o=t(\"../../components/drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"./helpers\"),u=t(\"./event_data\");function h(t,e,r){var a=r[0],o=a.trace,l=a.cx,h=a.cy;\"_hasHoverLabel\"in o||(o._hasHoverLabel=!1),\"_hasHoverEvent\"in o||(o._hasHoverEvent=!1),t.on(\"mouseover\",function(t){var r=e._fullLayout,f=e._fullData[o.index];if(!e._dragging&&!1!==r.hovermode){var p=f.hoverinfo;if(Array.isArray(p)&&(p=i.castHoverinfo({hoverinfo:[c.castOption(p,t.pts)],_module:o._module},r,0)),\"all\"===p&&(p=\"label+text+value+percent+name\"),f.hovertemplate||\"none\"!==p&&\"skip\"!==p&&p){var d=t.rInscribed||0,g=l+t.pxmid[0]*(1-d),v=h+t.pxmid[1]*(1-d),m=r.separators,y=[];if(p&&-1!==p.indexOf(\"label\")&&y.push(t.label),t.text=c.castOption(f.hovertext||f.text,t.pts),p&&-1!==p.indexOf(\"text\")){var x=t.text;s.isValidTextValue(x)&&y.push(x)}t.value=t.v,t.valueLabel=c.formatPieValue(t.v,m),p&&-1!==p.indexOf(\"value\")&&y.push(t.valueLabel),t.percent=t.v/a.vTotal,t.percentLabel=c.formatPiePercent(t.percent,m),p&&-1!==p.indexOf(\"percent\")&&y.push(t.percentLabel);var b=f.hoverlabel,_=b.font;i.loneHover({trace:o,x0:g-d*a.r,x1:g+d*a.r,y:v,text:y.join(\"<br>\"),name:f.hovertemplate||-1!==p.indexOf(\"name\")?f.name:void 0,idealAlign:t.pxmid[0]<0?\"left\":\"right\",color:c.castOption(b.bgcolor,t.pts)||t.color,borderColor:c.castOption(b.bordercolor,t.pts),fontFamily:c.castOption(_.family,t.pts),fontSize:c.castOption(_.size,t.pts),fontColor:c.castOption(_.color,t.pts),nameLength:c.castOption(b.namelength,t.pts),textAlign:c.castOption(b.align,t.pts),hovertemplate:c.castOption(f.hovertemplate,t.pts),hovertemplateLabels:t,eventData:[u(t,f)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e}),o._hasHoverLabel=!0}o._hasHoverEvent=!0,e.emit(\"plotly_hover\",{points:[u(t,f)],event:n.event})}}),t.on(\"mouseout\",function(t){var r=e._fullLayout,a=e._fullData[o.index],s=n.select(this).datum();o._hasHoverEvent&&(t.originalEvent=n.event,e.emit(\"plotly_unhover\",{points:[u(s,a)],event:n.event}),o._hasHoverEvent=!1),o._hasHoverLabel&&(i.loneUnhover(r._hoverlayer.node()),o._hasHoverLabel=!1)}),t.on(\"click\",function(t){var r=e._fullLayout,a=e._fullData[o.index];e._dragging||!1===r.hovermode||(e._hoverdata=[u(t,a)],i.click(e,n.event))})}function f(t,e,r){var n=c.castOption(t.insidetextfont.color,e.pts);!n&&t._input.textfont&&(n=c.castOption(t._input.textfont.color,e.pts));var i=c.castOption(t.insidetextfont.family,e.pts)||c.castOption(t.textfont.family,e.pts)||r.family,o=c.castOption(t.insidetextfont.size,e.pts)||c.castOption(t.textfont.size,e.pts)||r.size;return{color:n||a.contrast(e.color),family:i,size:o}}function p(t,e){for(var r,n,i=0;i<t.length;i++)if((n=(r=t[i][0]).trace).title.text){var a=n.title.text;n._meta&&(a=s.templateString(a,n._meta));var c=o.tester.append(\"text\").attr(\"data-notex\",1).text(a).call(o.font,n.title.font).call(l.convertToTspans,e),u=o.bBox(c.node(),!0);r.titleBox={width:u.width,height:u.height},c.remove()}}function d(t,e,r){var n=Math.sqrt(t.width*t.width+t.height*t.height),i=t.width/t.height,a=e.halfangle,o=e.ring,s=e.rInscribed,l=r.r||e.rpx1,c={scale:s*l*2/n,rCenter:1-s,rotate:0};if(c.scale>=1)return c;var u=i+1/(2*Math.tan(a)),h=l*Math.min(1/(Math.sqrt(u*u+.5)+u),o/(Math.sqrt(i*i+o/2)+i)),f={scale:2*h/t.height,rCenter:Math.cos(h/l)-h*i/l,rotate:(180/Math.PI*e.midangle+720)%180-90},p=1/i,d=p+1/(2*Math.tan(a)),g=l*Math.min(1/(Math.sqrt(d*d+.5)+d),o/(Math.sqrt(p*p+o/2)+p)),v={scale:2*g/t.width,rCenter:Math.cos(g/l)-g/i/l,rotate:(180/Math.PI*e.midangle+810)%180-90},m=v.scale>f.scale?v:f;return c.scale<1&&m.scale>c.scale?m:c}function g(t,e){return t.v!==e.vTotal||e.trace.hole?Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2):1}function v(t,e){var r=e.pxmid[0],n=e.pxmid[1],i=t.width/2,a=t.height/2;return r<0&&(i*=-1),n<0&&(a*=-1),{scale:1,rCenter:1,rotate:0,x:i+Math.abs(a)*(i>0?1:-1)/2,y:a/(1+r*r/(n*n)),outside:!0}}function m(t,e){var r,n,i,a=t.trace,o={x:t.cx,y:t.cy},s={tx:0,ty:0};s.ty+=a.title.font.size,i=x(a),-1!==a.title.position.indexOf(\"top\")?(o.y-=(1+i)*t.r,s.ty-=t.titleBox.height):-1!==a.title.position.indexOf(\"bottom\")&&(o.y+=(1+i)*t.r);var l,c,u=(l=t.r,c=t.trace.aspectratio,l/(void 0===c?1:c)),h=e.w*(a.domain.x[1]-a.domain.x[0])/2;return-1!==a.title.position.indexOf(\"left\")?(h+=u,o.x-=(1+i)*u,s.tx+=t.titleBox.width/2):-1!==a.title.position.indexOf(\"center\")?h*=2:-1!==a.title.position.indexOf(\"right\")&&(h+=u,o.x+=(1+i)*u,s.tx-=t.titleBox.width/2),r=h/t.titleBox.width,n=y(t,e)/t.titleBox.height,{x:o.x,y:o.y,scale:Math.min(r,n),tx:s.tx,ty:s.ty}}function y(t,e){var r=t.trace,n=e.h*(r.domain.y[1]-r.domain.y[0]);return Math.min(t.titleBox.height,n/2)}function x(t){var e,r=t.pull;if(!r)return 0;if(Array.isArray(r))for(r=0,e=0;e<t.pull.length;e++)t.pull[e]>r&&(r=t.pull[e]);return r}function b(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n][0],a=i.trace,o=a.domain,s=e.w*(o.x[1]-o.x[0]),l=e.h*(o.y[1]-o.y[0]);a.title.text&&\"middle center\"!==a.title.position&&(l-=y(i,e));var c=s/2,u=l/2;\"funnelarea\"!==a.type||a.scalegroup||(u/=a.aspectratio),i.r=Math.min(c,u)/(1+x(a)),i.cx=e.l+e.w*(a.domain.x[1]+a.domain.x[0])/2,i.cy=e.t+e.h*(1-a.domain.y[0])-l/2,a.title.text&&-1!==a.title.position.indexOf(\"bottom\")&&(i.cy-=y(i,e)),a.scalegroup&&-1===r.indexOf(a.scalegroup)&&r.push(a.scalegroup)}!function(t,e){for(var r,n,i,a=0;a<e.length;a++){var o=1/0,s=e[a];for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var l;if(\"pie\"===i.type)l=r.r*r.r;else if(\"funnelarea\"===i.type){var c,u;i.aspectratio>1?(c=r.r,u=c/i.aspectratio):(u=r.r,c=u*i.aspectratio),c*=(1+i.baseratio)/2,l=c*u}o=Math.min(o,l/r.vTotal)}for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var h=o*r.vTotal;\"funnelarea\"===i.type&&(h/=(1+i.baseratio)/2,h/=i.aspectratio),r.r=Math.sqrt(h)}}}(t,r)}e.exports={plot:function(t,e){var r=t._fullLayout;p(e,t),b(e,r._size);var i=s.makeTraceGroups(r._pielayer,e,\"trace\").each(function(e){var i=n.select(this),u=e[0],p=u.trace;!function(t){var e,r,n,i=t[0],a=i.trace,o=a.rotation*Math.PI/180,s=2*Math.PI/i.vTotal,l=\"px0\",c=\"px1\";if(\"counterclockwise\"===a.direction){for(e=0;e<t.length&&t[e].hidden;e++);if(e===t.length)return;o+=s*t[e].v,s*=-1,l=\"px1\",c=\"px0\"}function u(t){return[i.r*Math.sin(t),-i.r*Math.cos(t)]}for(n=u(o),e=0;e<t.length;e++)(r=t[e]).hidden||(r[l]=n,o+=s*r.v/2,r.pxmid=u(o),r.midangle=o,o+=s*r.v/2,n=u(o),r[c]=n,r.largeArc=r.v>i.vTotal/2?1:0,r.halfangle=Math.PI*Math.min(r.v/i.vTotal,.5),r.ring=1-a.hole,r.rInscribed=g(r,i))}(e),i.attr(\"stroke-linejoin\",\"round\"),i.each(function(){var i=n.select(this).selectAll(\"g.slice\").data(e);i.enter().append(\"g\").classed(\"slice\",!0),i.exit().remove();var g=[[[],[]],[[],[]]],y=!1;i.each(function(r){if(r.hidden)n.select(this).selectAll(\"path,g\").remove();else{r.pointNumber=r.i,r.curveNumber=p.index,g[r.pxmid[1]<0?0:1][r.pxmid[0]<0?0:1].push(r);var i=u.cx,a=u.cy,m=n.select(this),x=m.selectAll(\"path.surface\").data([r]);if(x.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),m.call(h,t,e),p.pull){var b=+c.castOption(p.pull,r.pts)||0;b>0&&(i+=b*r.pxmid[0],a+=b*r.pxmid[1])}r.cxFinal=i,r.cyFinal=a;var _=p.hole;if(r.v===u.vTotal){var w=\"M\"+(i+r.px0[0])+\",\"+(a+r.px0[1])+S(r.px0,r.pxmid,!0,1)+S(r.pxmid,r.px0,!0,1)+\"Z\";_?x.attr(\"d\",\"M\"+(i+_*r.px0[0])+\",\"+(a+_*r.px0[1])+S(r.px0,r.pxmid,!1,_)+S(r.pxmid,r.px0,!1,_)+\"Z\"+w):x.attr(\"d\",w)}else{var k=S(r.px0,r.px1,!0,1);if(_){var T=1-_;x.attr(\"d\",\"M\"+(i+_*r.px1[0])+\",\"+(a+_*r.px1[1])+S(r.px1,r.px0,!1,_)+\"l\"+T*r.px0[0]+\",\"+T*r.px0[1]+k+\"Z\")}else x.attr(\"d\",\"M\"+i+\",\"+a+\"l\"+r.px0[0]+\",\"+r.px0[1]+k+\"Z\")}var A=c.castOption(p.textposition,r.pts),M=m.selectAll(\"g.slicetext\").data(r.text&&\"none\"!==A?[0]:[]);M.enter().append(\"g\").classed(\"slicetext\",!0),M.exit().remove(),M.each(function(){var e=s.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)});e.text(r.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(o.font,\"outside\"===A?function(t,e,r){var n=c.castOption(t.outsidetextfont.color,e.pts)||c.castOption(t.textfont.color,e.pts)||r.color,i=c.castOption(t.outsidetextfont.family,e.pts)||c.castOption(t.textfont.family,e.pts)||r.family,a=c.castOption(t.outsidetextfont.size,e.pts)||c.castOption(t.textfont.size,e.pts)||r.size;return{color:n,family:i,size:a}}(p,r,t._fullLayout.font):f(p,r,t._fullLayout.font)).call(l.convertToTspans,t);var h,g=o.bBox(e.node());\"outside\"===A?h=v(g,r):(h=d(g,r,u),\"auto\"===A&&h.scale<1&&(e.call(o.font,p.outsidetextfont),p.outsidetextfont.family===p.insidetextfont.family&&p.outsidetextfont.size===p.insidetextfont.size||(g=o.bBox(e.node())),h=v(g,r)));var m=i+r.pxmid[0]*h.rCenter+(h.x||0),x=a+r.pxmid[1]*h.rCenter+(h.y||0);h.outside&&(r.yLabelMin=x-g.height/2,r.yLabelMid=x,r.yLabelMax=x+g.height/2,r.labelExtraX=0,r.labelExtraY=0,y=!0),e.attr(\"transform\",\"translate(\"+m+\",\"+x+\")\"+(h.scale<1?\"scale(\"+h.scale+\")\":\"\")+(h.rotate?\"rotate(\"+h.rotate+\")\":\"\")+\"translate(\"+-(g.left+g.right)/2+\",\"+-(g.top+g.bottom)/2+\")\")})}function S(t,e,n,i){var a=i*(e[0]-t[0]),o=i*(e[1]-t[1]);return\"a\"+i*u.r+\",\"+i*u.r+\" 0 \"+r.largeArc+(n?\" 1 \":\" 0 \")+a+\",\"+o}});var x=n.select(this).selectAll(\"g.titletext\").data(p.title.text?[0]:[]);x.enter().append(\"g\").classed(\"titletext\",!0),x.exit().remove(),x.each(function(){var e,i=s.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),a=p.title.text;p._meta&&(a=s.templateString(a,p._meta)),i.text(a).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(o.font,p.title.font).call(l.convertToTspans,t),e=\"middle center\"===p.title.position?function(t){var e=Math.sqrt(t.titleBox.width*t.titleBox.width+t.titleBox.height*t.titleBox.height);return{x:t.cx,y:t.cy,scale:t.trace.hole*t.r*2/e,tx:0,ty:-t.titleBox.height/2+t.trace.title.font.size}}(u):m(u,r._size),i.attr(\"transform\",\"translate(\"+e.x+\",\"+e.y+\")\"+(e.scale<1?\"scale(\"+e.scale+\")\":\"\")+\"translate(\"+e.tx+\",\"+e.ty+\")\")}),y&&function(t,e){var r,n,i,a,o,s,l,u,h,f,p,d,g;function v(t,e){return t.pxmid[1]-e.pxmid[1]}function m(t,e){return e.pxmid[1]-t.pxmid[1]}function y(t,r){r||(r={});var i,u,h,p,d,g,v=r.labelExtraY+(n?r.yLabelMax:r.yLabelMin),m=n?t.yLabelMin:t.yLabelMax,y=n?t.yLabelMax:t.yLabelMin,x=t.cyFinal+o(t.px0[1],t.px1[1]),b=v-m;if(b*l>0&&(t.labelExtraY=b),Array.isArray(e.pull))for(u=0;u<f.length;u++)(h=f[u])===t||(c.castOption(e.pull,t.pts)||0)>=(c.castOption(e.pull,h.pts)||0)||((t.pxmid[1]-h.pxmid[1])*l>0?(p=h.cyFinal+o(h.px0[1],h.px1[1]),(b=p-m-t.labelExtraY)*l>0&&(t.labelExtraY+=b)):(y+t.labelExtraY-x)*l>0&&(i=3*s*Math.abs(u-f.indexOf(t)),d=h.cxFinal+a(h.px0[0],h.px1[0]),(g=d+i-(t.cxFinal+t.pxmid[0])-t.labelExtraX)*s>0&&(t.labelExtraX+=g)))}for(n=0;n<2;n++)for(i=n?v:m,o=n?Math.max:Math.min,l=n?1:-1,r=0;r<2;r++){for(a=r?Math.max:Math.min,s=r?1:-1,(u=t[n][r]).sort(i),h=t[1-n][r],f=h.concat(u),d=[],p=0;p<u.length;p++)void 0!==u[p].yLabelMid&&d.push(u[p]);for(g=!1,p=0;n&&p<h.length;p++)if(void 0!==h[p].yLabelMid){g=h[p];break}for(p=0;p<d.length;p++){var x=p&&d[p-1];g&&!p&&(x=g),y(d[p],x)}}}(g,p),function(t,e){t.each(function(t){var r=n.select(this);if(t.labelExtraX||t.labelExtraY){var i=r.select(\"g.slicetext text\");i.attr(\"transform\",\"translate(\"+t.labelExtraX+\",\"+t.labelExtraY+\")\"+i.attr(\"transform\"));var o=t.cxFinal+t.pxmid[0],l=t.cyFinal+t.pxmid[1],c=\"M\"+o+\",\"+l,u=(t.yLabelMax-t.yLabelMin)*(t.pxmid[0]<0?-1:1)/4;if(t.labelExtraX){var h=t.labelExtraX*t.pxmid[1]/t.pxmid[0],f=t.yLabelMid+t.labelExtraY-(t.cyFinal+t.pxmid[1]);Math.abs(h)>Math.abs(f)?c+=\"l\"+f*t.pxmid[0]/t.pxmid[1]+\",\"+f+\"H\"+(o+t.labelExtraX+u):c+=\"l\"+t.labelExtraX+\",\"+h+\"v\"+(f-h)+\"h\"+u}else c+=\"V\"+(t.yLabelMid+t.labelExtraY)+\"h\"+u;s.ensureSingle(r,\"path\",\"textline\").call(a.stroke,e.outsidetextfont.color).attr({\"stroke-width\":Math.min(2,e.outsidetextfont.size/8),d:c,fill:\"none\"})}else r.select(\"path.textline\").remove()})}(i,p)})});setTimeout(function(){i.selectAll(\"tspan\").each(function(){var t=n.select(this);t.attr(\"dy\")&&t.attr(\"dy\",t.attr(\"dy\"))})},0)},transformInsideText:d,determineInsideTextFont:f,positionTitleOutside:m,prerenderTitles:p,layoutAreas:b,attachFxHandlers:h}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"./event_data\":1090,\"./helpers\":1091,d3:163}],1096:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./style_one\");e.exports=function(t){t._fullLayout._pielayer.selectAll(\".trace\").each(function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each(function(t){n.select(this).call(i,t,e)})})}},{\"./style_one\":1097,d3:163}],1097:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./helpers\").castOption;e.exports=function(t,e,r){var a=r.marker.line,o=i(a.color,e.pts)||n.defaultLine,s=i(a.width,e.pts)||0;t.style(\"stroke-width\",s).call(n.fill,e.color).call(n.stroke,o)}},{\"../../components/color\":593,\"./helpers\":1091}],1098:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\");e.exports={x:n.x,y:n.y,xy:{valType:\"data_array\",editType:\"calc\"},indices:{valType:\"data_array\",editType:\"calc\"},xbounds:{valType:\"data_array\",editType:\"calc\"},ybounds:{valType:\"data_array\",editType:\"calc\"},text:n.text,marker:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,arrayOk:!1,editType:\"calc\"},blend:{valType:\"boolean\",dflt:null,editType:\"calc\"},sizemin:{valType:\"number\",min:.1,max:2,dflt:.5,editType:\"calc\"},sizemax:{valType:\"number\",min:.1,dflt:20,editType:\"calc\"},border:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},arearatio:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},transforms:void 0}},{\"../scatter/attributes\":1112}],1099:[function(t,e,r){\"use strict\";var n=t(\"gl-pointcloud2d\"),i=t(\"../../lib/str2rgbarray\"),a=t(\"../../plots/cartesian/autorange\").findExtremes,o=t(\"../scatter/get_trace_color\");function s(t,e){this.scene=t,this.uid=e,this.type=\"pointcloud\",this.pickXData=[],this.pickYData=[],this.xData=[],this.yData=[],this.textLabels=[],this.color=\"rgb(0, 0, 0)\",this.name=\"\",this.hoverinfo=\"all\",this.idToIndex=new Int32Array(0),this.bounds=[0,0,0,0],this.pointcloudOptions={positions:new Float32Array(0),idToIndex:this.idToIndex,sizemin:.5,sizemax:12,color:[0,0,0,1],areaRatio:1,borderColor:[0,0,0,1]},this.pointcloud=n(t.glplot,this.pointcloudOptions),this.pointcloud._trace=this}var l=s.prototype;l.handlePick=function(t){var e=this.idToIndex[t.pointId];return{trace:this,dataCoord:t.dataCoord,traceCoord:this.pickXYData?[this.pickXYData[2*e],this.pickXYData[2*e+1]]:[this.pickXData[e],this.pickYData[e]],textLabel:Array.isArray(this.textLabels)?this.textLabels[e]:this.textLabels,color:this.color,name:this.name,pointIndex:e,hoverinfo:this.hoverinfo}},l.update=function(t){this.index=t.index,this.textLabels=t.text,this.name=t.name,this.hoverinfo=t.hoverinfo,this.bounds=[1/0,1/0,-1/0,-1/0],this.updateFast(t),this.color=o(t,{})},l.updateFast=function(t){var e,r,n,o,s,l,c=this.xData=this.pickXData=t.x,u=this.yData=this.pickYData=t.y,h=this.pickXYData=t.xy,f=t.xbounds&&t.ybounds,p=t.indices,d=this.bounds;if(h){if(n=h,e=h.length>>>1,f)d[0]=t.xbounds[0],d[2]=t.xbounds[1],d[1]=t.ybounds[0],d[3]=t.ybounds[1];else for(l=0;l<e;l++)o=n[2*l],s=n[2*l+1],o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);if(p)r=p;else for(r=new Int32Array(e),l=0;l<e;l++)r[l]=l}else for(e=c.length,n=new Float32Array(2*e),r=new Int32Array(e),l=0;l<e;l++)o=c[l],s=u[l],r[l]=l,n[2*l]=o,n[2*l+1]=s,o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);this.idToIndex=r,this.pointcloudOptions.idToIndex=r,this.pointcloudOptions.positions=n;var g=i(t.marker.color),v=i(t.marker.border.color),m=t.opacity*t.marker.opacity;g[3]*=m,this.pointcloudOptions.color=g;var y=t.marker.blend;if(null===y){y=c.length<100||u.length<100}this.pointcloudOptions.blend=y,v[3]*=m,this.pointcloudOptions.borderColor=v;var x=t.marker.sizemin,b=Math.max(t.marker.sizemax,t.marker.sizemin);this.pointcloudOptions.sizeMin=x,this.pointcloudOptions.sizeMax=b,this.pointcloudOptions.areaRatio=t.marker.border.arearatio,this.pointcloud.update(this.pointcloudOptions);var _=this.scene.xaxis,w=this.scene.yaxis,k=b/2||.5;t._extremes[_._id]=a(_,[d[0],d[2]],{ppad:k}),t._extremes[w._id]=a(w,[d[1],d[3]],{ppad:k})},l.dispose=function(){this.pointcloud.dispose()},e.exports=function(t,e){var r=new s(t,e.uid);return r.update(e),r}},{\"../../lib/str2rgbarray\":742,\"../../plots/cartesian/autorange\":766,\"../scatter/get_trace_color\":1121,\"gl-pointcloud2d\":292}],1100:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\");e.exports=function(t,e,r){function a(r,a){return n.coerce(t,e,i,r,a)}a(\"x\"),a(\"y\"),a(\"xbounds\"),a(\"ybounds\"),t.xy&&t.xy instanceof Float32Array&&(e.xy=t.xy),t.indices&&t.indices instanceof Int32Array&&(e.indices=t.indices),a(\"text\"),a(\"marker.color\",r),a(\"marker.opacity\"),a(\"marker.blend\"),a(\"marker.sizemin\"),a(\"marker.sizemax\"),a(\"marker.border.color\",r),a(\"marker.border.arearatio\"),e._length=null}},{\"../../lib\":719,\"./attributes\":1098}],1101:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../scatter3d/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"pointcloud\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"showLegend\"],meta:{}}},{\"../../plots/gl2d\":805,\"../scatter3d/calc\":1139,\"./attributes\":1098,\"./convert\":1099,\"./defaults\":1100}],1102:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../components/fx/attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../../components/fx/hovertemplate_attributes\"),c=t(\"../../components/colorscale/attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,h=t(\"../../lib/extend\").extendFlat,f=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=f({hoverinfo:h({},i.hoverinfo,{flags:[],arrayOk:!1}),hoverlabel:o.hoverlabel,domain:s({name:\"sankey\",trace:!0}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\"},valueformat:{valType:\"string\",dflt:\".3s\"},valuesuffix:{valType:\"string\",dflt:\"\"},arrangement:{valType:\"enumerated\",values:[\"snap\",\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"snap\"},textfont:n({}),node:{label:{valType:\"data_array\",dflt:[]},groups:{valType:\"info_array\",impliedEdits:{x:[],y:[]},dimensions:2,freeLength:!0,dflt:[],items:{valType:\"number\",editType:\"calc\"}},x:{valType:\"data_array\",dflt:[]},y:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:.5,arrayOk:!0}},pad:{valType:\"number\",arrayOk:!1,min:0,dflt:20},thickness:{valType:\"number\",arrayOk:!1,min:1,dflt:20},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]})},link:{label:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0}},source:{valType:\"data_array\",dflt:[]},target:{valType:\"data_array\",dflt:[]},value:{valType:\"data_array\",dflt:[]},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]}),colorscales:u(\"concentrationscales\",{editType:\"calc\",label:{valType:\"string\",editType:\"calc\",dflt:\"\"},cmax:{valType:\"number\",editType:\"calc\",dflt:1},cmin:{valType:\"number\",editType:\"calc\",dflt:0},colorscale:h(c().colorscale,{dflt:[[0,\"white\"],[1,\"black\"]]})})}},\"calc\",\"nested\")).transforms=void 0},{\"../../components/color/attributes\":592,\"../../components/colorscale/attributes\":600,\"../../components/fx/attributes\":623,\"../../components/fx/hovertemplate_attributes\":631,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1103:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../components/fx/layout_attributes\"),s=t(\"../../lib/setcursor\"),l=t(\"../../components/dragelement\"),c=t(\"../../plots/cartesian/select\").prepSelect,u=t(\"../../lib\"),h=t(\"../../registry\");function f(t,e){var r=t._fullData[e],n=t._fullLayout,i=n.dragmode,a=\"pan\"===n.dragmode?\"move\":\"crosshair\",o=r._bgRect;if(\"pan\"!==i&&\"zoom\"!==i){s(o,a);var f={_id:\"x\",c2p:u.identity,_offset:r._sankey.translateX,_length:r._sankey.width},p={_id:\"y\",c2p:u.identity,_offset:r._sankey.translateY,_length:r._sankey.height},d={gd:t,element:o.node(),plotinfo:{id:e,xaxis:f,yaxis:p,fillRangeItems:u.noop},subplot:e,xaxes:[f],yaxes:[p],doneFnCompleted:function(r){var n,i=t._fullData[e],a=i.node.groups.slice(),o=[];function s(t){for(var e=i._sankey.graph.nodes,r=0;r<e.length;r++)if(e[r].pointNumber===t)return e[r]}for(var l=0;l<r.length;l++){var c=s(r[l].pointNumber);if(c)if(c.group){for(var u=0;u<c.childrenNodes.length;u++)o.push(c.childrenNodes[u].pointNumber);a[c.pointNumber-i.node._count]=!1}else o.push(c.pointNumber)}n=a.filter(Boolean).concat([o]),h.call(\"_guiRestyle\",t,{\"node.groups\":[n]},e)},prepFn:function(t,e,r){c(t,e,r,d,i)}};l.init(d)}}r.name=\"sankey\",r.baseLayoutAttrOverrides=n({hoverlabel:o.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){var e=i(t.calcdata,\"sankey\")[0];a(t,e),r.updateFx(t)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"sankey\"),a=e._has&&e._has(\"sankey\");i&&!a&&(n._paperdiv.selectAll(\".sankey\").remove(),n._paperdiv.selectAll(\".bgsankey\").remove())},r.updateFx=function(t){for(var e=0;e<t._fullData.length;e++)f(t,e)}},{\"../../components/dragelement\":611,\"../../components/fx/layout_attributes\":633,\"../../lib\":719,\"../../lib/setcursor\":739,\"../../plot_api/edit_types\":750,\"../../plots/cartesian/select\":784,\"../../plots/get_data\":802,\"../../registry\":847,\"./plot\":1108}],1104:[function(t,e,r){\"use strict\";var n=t(\"strongly-connected-components\"),i=t(\"../../lib\"),a=t(\"../../lib/gup\").wrap,o=i.isArrayOrTypedArray,s=i.isIndex,l=t(\"../../components/colorscale\");function c(t){var e,r=t.node,a=t.link,c=[],u=o(a.color),h={},f={},p=a.colorscales.length;for(e=0;e<p;e++){var d=a.colorscales[e],g=l.extractScale(d,{cLetter:\"c\"}),v=l.makeColorScaleFunc(g);f[d.label]=v}var m=0;for(e=0;e<a.value.length;e++)a.source[e]>m&&(m=a.source[e]),a.target[e]>m&&(m=a.target[e]);var y,x=m+1;t.node._count=x;var b=t.node.groups,_={};for(e=0;e<b.length;e++){var w=b[e];for(y=0;y<w.length;y++){var k=w[y],T=x+e;_.hasOwnProperty(k)?i.warn(\"Node \"+k+\" is already part of a group.\"):_[k]=T}}var A={source:[],target:[]};for(e=0;e<a.value.length;e++){var M=a.value[e],S=a.source[e],E=a.target[e];if(M>0&&s(S,x)&&s(E,x)&&(!_.hasOwnProperty(S)||!_.hasOwnProperty(E)||_[S]!==_[E])){_.hasOwnProperty(E)&&(E=_[E]),_.hasOwnProperty(S)&&(S=_[S]),E=+E,h[S=+S]=h[E]=!0;var C=\"\";a.label&&a.label[e]&&(C=a.label[e]);var L=null;C&&f.hasOwnProperty(C)&&(L=f[C]),c.push({pointNumber:e,label:C,color:u?a.color[e]:a.color,concentrationscale:L,source:S,target:E,value:+M}),A.source.push(S),A.target.push(E)}}var P=x+b.length,O=o(r.color),z=[];for(e=0;e<P;e++)if(h[e]){var I=r.label[e];z.push({group:e>x-1,childrenNodes:[],pointNumber:e,label:I,color:O?r.color[e]:r.color})}var D=!1;return function(t,e,r){for(var a=i.init2dArray(t,0),o=0;o<Math.min(e.length,r.length);o++)if(i.isIndex(e[o],t)&&i.isIndex(r[o],t)){if(e[o]===r[o])return!0;a[e[o]].push(r[o])}return n(a).components.some(function(t){return t.length>1})}(P,A.source,A.target)&&(D=!0),{circular:D,links:c,nodes:z,groups:b,groupLookup:_}}e.exports=function(t,e){var r=c(e);return a({circular:r.circular,_nodes:r.nodes,_links:r.links,_groups:r.groups,_groupLookup:r.groupLookup})}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gup\":717,\"strongly-connected-components\":530}],1105:[function(t,e,r){\"use strict\";e.exports={nodeTextOffsetHorizontal:4,nodeTextOffsetVertical:3,nodePadAcross:10,sankeyIterations:50,forceIterations:5,forceTicksPerFrame:10,duration:500,ease:\"linear\",cn:{sankey:\"sankey\",sankeyLinks:\"sankey-links\",sankeyLink:\"sankey-link\",sankeyNodeSet:\"sankey-node-set\",sankeyNode:\"sankey-node\",nodeRect:\"node-rect\",nodeCapture:\"node-capture\",nodeCentered:\"node-entered\",nodeLabelGuide:\"node-label-guide\",nodeLabel:\"node-label\",nodeLabelTextPath:\"node-label-text-path\"}}},{}],1106:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../components/color\"),o=t(\"tinycolor2\"),s=t(\"../../plots/domain\").defaults,l=t(\"../../components/fx/hoverlabel_defaults\"),c=t(\"../../plot_api/plot_template\"),u=t(\"../../plots/array_container_defaults\");function h(t,e){function r(r,a){return n.coerce(t,e,i.link.colorscales,r,a)}r(\"label\"),r(\"cmin\"),r(\"cmax\"),r(\"colorscale\")}e.exports=function(t,e,r,f){function p(r,a){return n.coerce(t,e,i,r,a)}var d=n.extendDeep(f.hoverlabel,t.hoverlabel),g=t.node,v=c.newContainer(e,\"node\");function m(t,e){return n.coerce(g,v,i.node,t,e)}m(\"label\"),m(\"groups\"),m(\"x\"),m(\"y\"),m(\"pad\"),m(\"thickness\"),m(\"line.color\"),m(\"line.width\"),m(\"hoverinfo\",t.hoverinfo),l(g,v,m,d),m(\"hovertemplate\");var y=f.colorway;m(\"color\",v.label.map(function(t,e){return a.addOpacity(function(t){return y[t%y.length]}(e),.8)}));var x=t.link||{},b=c.newContainer(e,\"link\");function _(t,e){return n.coerce(x,b,i.link,t,e)}_(\"label\"),_(\"source\"),_(\"target\"),_(\"value\"),_(\"line.color\"),_(\"line.width\"),_(\"hoverinfo\",t.hoverinfo),l(x,b,_,d),_(\"hovertemplate\");var w,k=o(f.paper_bgcolor).getLuminance()<.333?\"rgba(255, 255, 255, 0.6)\":\"rgba(0, 0, 0, 0.2)\";_(\"color\",n.repeat(k,b.value.length)),u(x,b,{name:\"colorscales\",handleItemDefaults:h}),s(e,f,p),p(\"orientation\"),p(\"valueformat\"),p(\"valuesuffix\"),v.x.length&&v.y.length&&(w=\"freeform\"),p(\"arrangement\",w),n.coerceFont(p,\"textfont\",n.extendFlat({},f.font)),e._length=null}},{\"../../components/color\":593,\"../../components/fx/hoverlabel_defaults\":630,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/array_container_defaults\":763,\"../../plots/domain\":792,\"./attributes\":1102,tinycolor2:537}],1107:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"sankey\",basePlotModule:t(\"./base_plot\"),selectPoints:t(\"./select.js\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1102,\"./base_plot\":1103,\"./calc\":1104,\"./defaults\":1106,\"./plot\":1108,\"./select.js\":1110}],1108:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./render\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\"),l=t(\"./constants\").cn,c=s._;function u(t){return\"\"!==t}function h(t,e){return t.filter(function(t){return t.key===e.traceId})}function f(t,e){n.select(t).select(\"path\").style(\"fill-opacity\",e),n.select(t).select(\"rect\").style(\"fill-opacity\",e)}function p(t){n.select(t).select(\"text.name\").style(\"fill\",\"black\")}function d(t){return function(e){return-1!==t.node.sourceLinks.indexOf(e.link)||-1!==t.node.targetLinks.indexOf(e.link)}}function g(t){return function(e){return-1!==e.node.sourceLinks.indexOf(t.link)||-1!==e.node.targetLinks.indexOf(t.link)}}function v(t,e,r){e&&r&&h(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(y.bind(0,e,r,!1))}function m(t,e,r){e&&r&&h(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(x.bind(0,e,r,!1))}function y(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",function(t){if(!t.link.concentrationscale)return.4}),i&&h(e,t).selectAll(\".\"+l.sankeyLink).filter(function(t){return t.link.label===i}).style(\"fill-opacity\",function(t){if(!t.link.concentrationscale)return.4}),r&&h(e,t).selectAll(\".\"+l.sankeyNode).filter(g(t)).call(v)}function x(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),i&&h(e,t).selectAll(\".\"+l.sankeyLink).filter(function(t){return t.link.label===i}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),r&&h(e,t).selectAll(l.sankeyNode).filter(g(t)).call(m)}function b(t,e){var r=t.hoverlabel||{},n=s.nestedProperty(r,e).get();return!Array.isArray(n)&&n}e.exports=function(t,e){for(var r=t._fullLayout,s=r._paper,h=r._size,d=0;d<t._fullData.length;d++)if(t._fullData[d].type===l.sankey&&!t._fullData[d]._viewInitial){var g=t._fullData[d].node;t._fullData[d]._viewInitial={node:{groups:g.groups.slice(),x:g.x.slice(),y:g.y.slice()}}}var _=c(t,\"source:\")+\" \",w=c(t,\"target:\")+\" \",k=c(t,\"concentration:\")+\" \",T=c(t,\"incoming flow count:\")+\" \",A=c(t,\"outgoing flow count:\")+\" \";i(t,s,e,{width:h.w,height:h.h,margin:{t:h.t,r:h.r,b:h.b,l:h.l}},{linkEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(y.bind(0,r,i,!0)),\"skip\"!==r.link.trace.link.hoverinfo&&(r.link.fullData=r.link.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.link]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var s=i.link.trace.link;if(\"none\"!==s.hoverinfo&&\"skip\"!==s.hoverinfo){for(var l=[],c=0,h=0;h<i.flow.links.length;h++){var d=i.flow.links[h];if(\"closest\"!==t._fullLayout.hovermode||i.link.pointNumber===d.pointNumber){i.link.pointNumber===d.pointNumber&&(c=h),d.fullData=d.trace,s=i.link.trace.link;var g=m(d),v={valueLabel:n.format(i.valueFormat)(d.value)+i.valueSuffix};l.push({x:g[0],y:g[1],name:v.valueLabel,text:[d.label||\"\",_+d.source.label,w+d.target.label,d.concentrationscale?k+n.format(\"%0.2f\")(d.flow.labelConcentration):\"\"].filter(u).join(\"<br>\"),color:b(s,\"bgcolor\")||o.addOpacity(d.color,1),borderColor:b(s,\"bordercolor\"),fontFamily:b(s,\"font.family\"),fontSize:b(s,\"font.size\"),fontColor:b(s,\"font.color\"),nameLength:b(s,\"namelength\"),textAlign:b(s,\"align\"),idealAlign:n.event.x<g[0]?\"right\":\"left\",hovertemplate:s.hovertemplate,hovertemplateLabels:v,eventData:[d]})}}a.loneHover(l,{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t,anchorIndex:c}).each(function(){i.link.concentrationscale||f(this,.65),p(this)})}}function m(t){var e,r;return t.circular?(e=(t.circularPathData.leftInnerExtent+t.circularPathData.rightInnerExtent)/2+i.parent.translateX,r=t.circularPathData.verticalFullExtent+i.parent.translateY):(e=(t.source.x1+t.target.x0)/2+i.parent.translateX,r=(t.y0+t.y1)/2+i.parent.translateY),[e,r]}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(x.bind(0,i,o,!0)),\"skip\"!==i.link.trace.link.hoverinfo&&(i.link.fullData=i.link.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.link]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r){var i=r.link;i.originalEvent=n.event,t._hoverdata=[i],a.click(t,{target:!0})}},nodeEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(v,r,i),\"skip\"!==r.node.trace.node.hoverinfo&&(r.node.fullData=r.node.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.node]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var o=i.node.trace.node;if(\"none\"!==o.hoverinfo&&\"skip\"!==o.hoverinfo){var s=n.select(e).select(\".\"+l.nodeRect),c=t._fullLayout._paperdiv.node().getBoundingClientRect(),h=s.node().getBoundingClientRect(),d=h.left-2-c.left,g=h.right+2-c.left,v=h.top+h.height/4-c.top,m={valueLabel:n.format(i.valueFormat)(i.node.value)+i.valueSuffix};i.node.fullData=i.node.trace;var y=a.loneHover({x0:d,x1:g,y:v,name:n.format(i.valueFormat)(i.node.value)+i.valueSuffix,text:[i.node.label,T+i.node.targetLinks.length,A+i.node.sourceLinks.length].filter(u).join(\"<br>\"),color:b(o,\"bgcolor\")||i.tinyColorHue,borderColor:b(o,\"bordercolor\"),fontFamily:b(o,\"font.family\"),fontSize:b(o,\"font.size\"),fontColor:b(o,\"font.color\"),nameLength:b(o,\"namelength\"),textAlign:b(o,\"align\"),idealAlign:\"left\",hovertemplate:o.hovertemplate,hovertemplateLabels:m,eventData:[i.node]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t});f(y,.85),p(y)}}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(m,i,o),\"skip\"!==i.node.trace.node.hoverinfo&&(i.node.fullData=i.node.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.node]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r,i){var o=r.node;o.originalEvent=n.event,t._hoverdata=[o],n.select(e).call(m,r,i),a.click(t,{target:!0})}}})}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"./constants\":1105,\"./render\":1109,d3:163}],1109:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"tinycolor2\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"@plotly/d3-sankey\"),c=t(\"@plotly/d3-sankey-circular\"),u=t(\"d3-force\"),h=t(\"../../lib\"),f=t(\"../../lib/gup\"),p=f.keyFun,d=f.repeat,g=f.unwrap,v=t(\"d3-interpolate\").interpolateNumber,m=t(\"../../registry\");function y(){var t=.5;return function(e){if(e.link.circular)return r=e.link,n=r.width/2,i=r.circularPathData,\"top\"===r.circularLinkType?\"M \"+i.targetX+\" \"+(i.targetY+n)+\" L\"+i.rightInnerExtent+\" \"+(i.targetY+n)+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightSmallArcRadius+n)+\" 0 0 1 \"+(i.rightFullExtent-n)+\" \"+(i.targetY-i.rightSmallArcRadius)+\"L\"+(i.rightFullExtent-n)+\" \"+i.verticalRightInnerExtent+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightLargeArcRadius+n)+\" 0 0 1 \"+i.rightInnerExtent+\" \"+(i.verticalFullExtent-n)+\"L\"+i.leftInnerExtent+\" \"+(i.verticalFullExtent-n)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftLargeArcRadius+n)+\" 0 0 1 \"+(i.leftFullExtent+n)+\" \"+i.verticalLeftInnerExtent+\"L\"+(i.leftFullExtent+n)+\" \"+(i.sourceY-i.leftSmallArcRadius)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftSmallArcRadius+n)+\" 0 0 1 \"+i.leftInnerExtent+\" \"+(i.sourceY+n)+\"L\"+i.sourceX+\" \"+(i.sourceY+n)+\"L\"+i.sourceX+\" \"+(i.sourceY-n)+\"L\"+i.leftInnerExtent+\" \"+(i.sourceY-n)+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftSmallArcRadius-n)+\" 0 0 0 \"+(i.leftFullExtent-n)+\" \"+(i.sourceY-i.leftSmallArcRadius)+\"L\"+(i.leftFullExtent-n)+\" \"+i.verticalLeftInnerExtent+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftLargeArcRadius-n)+\" 0 0 0 \"+i.leftInnerExtent+\" \"+(i.verticalFullExtent+n)+\"L\"+i.rightInnerExtent+\" \"+(i.verticalFullExtent+n)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightLargeArcRadius-n)+\" 0 0 0 \"+(i.rightFullExtent+n)+\" \"+i.verticalRightInnerExtent+\"L\"+(i.rightFullExtent+n)+\" \"+(i.targetY-i.rightSmallArcRadius)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightSmallArcRadius-n)+\" 0 0 0 \"+i.rightInnerExtent+\" \"+(i.targetY-n)+\"L\"+i.targetX+\" \"+(i.targetY-n)+\"Z\":\"M \"+i.targetX+\" \"+(i.targetY-n)+\" L\"+i.rightInnerExtent+\" \"+(i.targetY-n)+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightSmallArcRadius+n)+\" 0 0 0 \"+(i.rightFullExtent-n)+\" \"+(i.targetY+i.rightSmallArcRadius)+\"L\"+(i.rightFullExtent-n)+\" \"+i.verticalRightInnerExtent+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightLargeArcRadius+n)+\" 0 0 0 \"+i.rightInnerExtent+\" \"+(i.verticalFullExtent+n)+\"L\"+i.leftInnerExtent+\" \"+(i.verticalFullExtent+n)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftLargeArcRadius+n)+\" 0 0 0 \"+(i.leftFullExtent+n)+\" \"+i.verticalLeftInnerExtent+\"L\"+(i.leftFullExtent+n)+\" \"+(i.sourceY+i.leftSmallArcRadius)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftSmallArcRadius+n)+\" 0 0 0 \"+i.leftInnerExtent+\" \"+(i.sourceY-n)+\"L\"+i.sourceX+\" \"+(i.sourceY-n)+\"L\"+i.sourceX+\" \"+(i.sourceY+n)+\"L\"+i.leftInnerExtent+\" \"+(i.sourceY+n)+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftSmallArcRadius-n)+\" 0 0 1 \"+(i.leftFullExtent-n)+\" \"+(i.sourceY+i.leftSmallArcRadius)+\"L\"+(i.leftFullExtent-n)+\" \"+i.verticalLeftInnerExtent+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftLargeArcRadius-n)+\" 0 0 1 \"+i.leftInnerExtent+\" \"+(i.verticalFullExtent-n)+\"L\"+i.rightInnerExtent+\" \"+(i.verticalFullExtent-n)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightLargeArcRadius-n)+\" 0 0 1 \"+(i.rightFullExtent+n)+\" \"+i.verticalRightInnerExtent+\"L\"+(i.rightFullExtent+n)+\" \"+(i.targetY+i.rightSmallArcRadius)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightSmallArcRadius-n)+\" 0 0 1 \"+i.rightInnerExtent+\" \"+(i.targetY+n)+\"L\"+i.targetX+\" \"+(i.targetY+n)+\"Z\";var r,n,i,a=e.link.source.x1,o=e.link.target.x0,s=v(a,o),l=s(t),c=s(1-t),u=e.link.y0-e.link.width/2,h=e.link.y0+e.link.width/2,f=e.link.y1-e.link.width/2,p=e.link.y1+e.link.width/2;return\"M\"+a+\",\"+u+\"C\"+l+\",\"+u+\" \"+c+\",\"+f+\" \"+o+\",\"+f+\"L\"+o+\",\"+p+\"C\"+c+\",\"+p+\" \"+l+\",\"+h+\" \"+a+\",\"+h+\"Z\"}}function x(t){t.attr(\"transform\",function(t){return\"translate(\"+t.node.x0.toFixed(3)+\", \"+t.node.y0.toFixed(3)+\")\"})}function b(t){t.call(x)}function _(t,e){t.call(b),e.attr(\"d\",y())}function w(t){t.attr(\"width\",function(t){return t.node.x1-t.node.x0}).attr(\"height\",function(t){return t.visibleHeight})}function k(t){return t.link.width>1||t.linkLineWidth>0}function T(t){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"+(t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\")}function A(t){return\"translate(\"+(t.horizontal?0:t.labelY)+\" \"+(t.horizontal?t.labelY:0)+\")\"}function M(t){return i.svg.line()([[t.horizontal?t.left?-t.sizeAcross:t.visibleWidth+n.nodeTextOffsetHorizontal:n.nodeTextOffsetHorizontal,0],[t.horizontal?t.left?-n.nodeTextOffsetHorizontal:t.sizeAcross:t.visibleHeight-n.nodeTextOffsetHorizontal,0]])}function S(t){return t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\"}function E(t){return t.horizontal?\"scale(1 1)\":\"scale(-1 1)\"}function C(t){return t.darkBackground&&!t.horizontal?\"rgb(255,255,255)\":\"rgb(0,0,0)\"}function L(t){return t.horizontal&&t.left?\"100%\":\"0%\"}function P(t,e,r){t.on(\".basic\",null).on(\"mouseover.basic\",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.hover(this,t,e),t.interactionState.hovered=[this,t])}).on(\"mousemove.basic\",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.follow(this,t),t.interactionState.hovered=[this,t])}).on(\"mouseout.basic\",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.unhover(this,t,e),t.interactionState.hovered=!1)}).on(\"click.basic\",function(t){t.interactionState.hovered&&(r.unhover(this,t,e),t.interactionState.hovered=!1),t.interactionState.dragInProgress||t.partOfGroup||r.select(this,t,e)})}function O(t,e,r,a){var o=i.behavior.drag().origin(function(t){return{x:t.node.x0+t.visibleWidth/2,y:t.node.y0+t.visibleHeight/2}}).on(\"dragstart\",function(i){if(\"fixed\"!==i.arrangement&&(h.ensureSingle(a._fullLayout._infolayer,\"g\",\"dragcover\",function(t){a._fullLayout._dragCover=t}),h.raiseToTop(this),i.interactionState.dragInProgress=i.node,I(i.node),i.interactionState.hovered&&(r.nodeEvents.unhover.apply(0,i.interactionState.hovered),i.interactionState.hovered=!1),\"snap\"===i.arrangement)){var o=i.traceId+\"|\"+i.key;i.forceLayouts[o]?i.forceLayouts[o].alpha(1):function(t,e,r,i){!function(t){for(var e=0;e<t.length;e++)t[e].y=(t[e].y0+t[e].y1)/2,t[e].x=(t[e].x0+t[e].x1)/2}(r.graph.nodes);var a=r.graph.nodes.filter(function(t){return t.originalX===r.node.originalX}).filter(function(t){return!t.partOfGroup});r.forceLayouts[e]=u.forceSimulation(a).alphaDecay(0).force(\"collide\",u.forceCollide().radius(function(t){return t.dy/2+r.nodePad/2}).strength(1).iterations(n.forceIterations)).force(\"constrain\",function(t,e,r,i){return function(){for(var t=0,a=0;a<r.length;a++){var o=r[a];o===i.interactionState.dragInProgress?(o.x=o.lastDraggedX,o.y=o.lastDraggedY):(o.vx=(o.originalX-o.x)/n.forceTicksPerFrame,o.y=Math.min(i.size-o.dy/2,Math.max(o.dy/2,o.y))),t=Math.max(t,Math.abs(o.vx),Math.abs(o.vy))}!i.interactionState.dragInProgress&&t<.1&&i.forceLayouts[e].alpha()>0&&i.forceLayouts[e].alpha(0)}}(0,e,a,r)).stop()}(0,o,i),function(t,e,r,i,a){window.requestAnimationFrame(function o(){var s;for(s=0;s<n.forceTicksPerFrame;s++)r.forceLayouts[i].tick();var l=r.graph.nodes;if(function(t){for(var e=0;e<t.length;e++)t[e].y0=t[e].y-t[e].dy/2,t[e].y1=t[e].y0+t[e].dy,t[e].x0=t[e].x-t[e].dx/2,t[e].x1=t[e].x0+t[e].dx}(l),r.sankey.update(r.graph),_(t.filter(D(r)),e),r.forceLayouts[i].alpha()>0)window.requestAnimationFrame(o);else{var c=r.node.originalX;r.node.x0=c-r.visibleWidth/2,r.node.x1=c+r.visibleWidth/2,z(r,a)}})}(t,e,i,o,a)}}).on(\"drag\",function(r){if(\"fixed\"!==r.arrangement){var n=i.event.x,a=i.event.y;\"snap\"===r.arrangement?(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2,r.node.y0=a-r.visibleHeight/2,r.node.y1=a+r.visibleHeight/2):(\"freeform\"===r.arrangement&&(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2),a=Math.max(0,Math.min(r.size-r.visibleHeight/2,a)),r.node.y0=a-r.visibleHeight/2,r.node.y1=a+r.visibleHeight/2),I(r.node),\"snap\"!==r.arrangement&&(r.sankey.update(r.graph),_(t.filter(D(r)),e))}}).on(\"dragend\",function(t){if(\"fixed\"!==t.arrangement){t.interactionState.dragInProgress=!1;for(var e=0;e<t.node.childrenNodes.length;e++)t.node.childrenNodes[e].x=t.node.x,t.node.childrenNodes[e].y=t.node.y;\"snap\"!==t.arrangement&&z(t,a)}});t.on(\".drag\",null).call(o)}function z(t,e){for(var r=[],n=[],i=0;i<t.graph.nodes.length;i++){var a=(t.graph.nodes[i].x0+t.graph.nodes[i].x1)/2,o=(t.graph.nodes[i].y0+t.graph.nodes[i].y1)/2;r.push(a/t.figure.width),n.push(o/t.figure.height)}m.call(\"_guiRestyle\",e,{\"node.x\":[r],\"node.y\":[n]},t.trace.index).then(function(){e._fullLayout._dragCover&&e._fullLayout._dragCover.remove()})}function I(t){t.lastDraggedX=t.x0+t.dx/2,t.lastDraggedY=t.y0+t.dy/2}function D(t){return function(e){return e.node.originalX===t.node.originalX}}e.exports=function(t,e,r,u,f){var v=!1;h.ensureSingle(t._fullLayout._infolayer,\"g\",\"first-render\",function(){v=!0});var m=t._fullLayout._dragCover,b=r.filter(function(t){return g(t).trace.visible}).map(function(t,e,r){var i,o=g(e),s=o.trace,u=s.domain,f=\"h\"===s.orientation,p=s.node.pad,d=s.node.thickness,v=t.width*(u.x[1]-u.x[0]),m=t.height*(u.y[1]-u.y[0]),y=o._nodes,x=o._links,b=o.circular;(i=b?c.sankeyCircular().circularLinkGap(0):l.sankey()).iterations(n.sankeyIterations).size(f?[v,m]:[m,v]).nodeWidth(d).nodePadding(p).nodeId(function(t){return t.pointNumber}).nodes(y).links(x);var _,w,k,T=i();for(var A in i.nodePadding()<p&&h.warn(\"node.pad was reduced to \",i.nodePadding(),\" to fit within the figure.\"),o._groupLookup){var M,S=parseInt(o._groupLookup[A]);for(_=0;_<T.nodes.length;_++)if(T.nodes[_].pointNumber===S){M=T.nodes[_];break}if(M){var E={pointNumber:parseInt(A),x0:M.x0,x1:M.x1,y0:M.y0,y1:M.y1,partOfGroup:!0,sourceLinks:[],targetLinks:[]};T.nodes.unshift(E),M.childrenNodes.unshift(E)}}if(function(){for(_=0;_<T.nodes.length;_++){var t,e,r=T.nodes[_],n={};for(w=0;w<r.targetLinks.length;w++)t=(e=r.targetLinks[w]).source.pointNumber+\":\"+e.target.pointNumber,n.hasOwnProperty(t)||(n[t]=[]),n[t].push(e);var i=Object.keys(n);for(w=0;w<i.length;w++){var o=n[t=i[w]],s=0,l={};for(k=0;k<o.length;k++)l[(e=o[k]).label]||(l[e.label]=0),l[e.label]+=e.value,s+=e.value;for(k=0;k<o.length;k++)(e=o[k]).flow={value:s,labelConcentration:l[e.label]/s,concentration:e.value/s,links:o},e.concentrationscale&&(e.color=a(e.concentrationscale(e.flow.labelConcentration)))}var c=0;for(w=0;w<r.sourceLinks.length;w++)c+=r.sourceLinks[w].value;for(w=0;w<r.sourceLinks.length;w++)(e=r.sourceLinks[w]).concentrationOut=e.value/c;var u=0;for(w=0;w<r.targetLinks.length;w++)u+=r.targetLinks[w].value;for(w=0;w<r.targetLinks.length;w++)(e=r.targetLinks[w]).concenrationIn=e.value/u}}(),s.node.x.length&&s.node.y.length){for(_=0;_<Math.min(s.node.x.length,s.node.y.length,T.nodes.length);_++)if(s.node.x[_]&&s.node.y[_]){var C=[s.node.x[_]*v,s.node.y[_]*m];T.nodes[_].x0=C[0]-d/2,T.nodes[_].x1=C[0]+d/2;var L=T.nodes[_].y1-T.nodes[_].y0;T.nodes[_].y0=C[1]-L/2,T.nodes[_].y1=C[1]+L/2}\"snap\"===s.arrangement&&function(t){t.forEach(function(t){var e,r,n,i=0,a=t.length;for(t.sort(function(t,e){return t.y0-e.y0}),n=0;n<a;++n)(e=t[n]).y0>=i||(r=i-e.y0)>1e-6&&(e.y0+=r,e.y1+=r),i=e.y1+p})}(function(t){var e,r,n=t.map(function(t,e){return{x0:t.x0,index:e}}).sort(function(t,e){return t.x0-e.x0}),i=[],a=-1,o=-1/0;for(_=0;_<n.length;_++){var s=t[n[_].index];s.x0>o+d&&(a+=1,e=s.x0),o=s.x0,i[a]||(i[a]=[]),i[a].push(s),r=e-s.x0,s.x0+=r,s.x1+=r}return i}(y=T.nodes)),i.update(T)}return{circular:b,key:r,trace:s,guid:h.randstr(),horizontal:f,width:v,height:m,nodePad:s.node.pad,nodeLineColor:s.node.line.color,nodeLineWidth:s.node.line.width,linkLineColor:s.link.line.color,linkLineWidth:s.link.line.width,valueFormat:s.valueformat,valueSuffix:s.valuesuffix,textFont:s.textfont,translateX:u.x[0]*t.width+t.margin.l,translateY:t.height-u.y[1]*t.height+t.margin.t,dragParallel:f?m:v,dragPerpendicular:f?v:m,arrangement:s.arrangement,sankey:i,graph:T,forceLayouts:{},interactionState:{dragInProgress:!1,hovered:!1}}}.bind(null,u)),_=e.selectAll(\".\"+n.cn.sankey).data(b,p);_.exit().remove(),_.enter().append(\"g\").classed(n.cn.sankey,!0).style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"shape-rendering\",\"geometricPrecision\").style(\"pointer-events\",\"auto\").attr(\"transform\",T),_.each(function(e,r){t._fullData[r]._sankey=e;var n=\"bgsankey-\"+e.trace.uid+\"-\"+r;h.ensureSingle(t._fullLayout._draggers,\"rect\",n),t._fullData[r]._bgRect=i.select(\".\"+n),t._fullData[r]._bgRect.style(\"pointer-events\",\"all\").attr(\"width\",e.width).attr(\"height\",e.height).attr(\"x\",e.translateX).attr(\"y\",e.translateY).classed(\"bgsankey\",!0).style({fill:\"transparent\",\"stroke-width\":0})}),_.transition().ease(n.ease).duration(n.duration).attr(\"transform\",T);var z=_.selectAll(\".\"+n.cn.sankeyLinks).data(d,p);z.enter().append(\"g\").classed(n.cn.sankeyLinks,!0).style(\"fill\",\"none\");var I=z.selectAll(\".\"+n.cn.sankeyLink).data(function(t){return t.graph.links.filter(function(t){return t.value}).map(function(t,e,r){var n=a(e.color),i=e.source.label+\"|\"+e.target.label+\"__\"+r;return e.trace=t.trace,e.curveNumber=t.trace.index,{circular:t.circular,key:i,traceId:t.key,pointNumber:e.pointNumber,link:e,tinyColorHue:o.tinyRGB(n),tinyColorAlpha:n.getAlpha(),linkPath:y,linkLineColor:t.linkLineColor,linkLineWidth:t.linkLineWidth,valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,parent:t,interactionState:t.interactionState,flow:e.flow}}.bind(null,t))},p);I.enter().append(\"path\").classed(n.cn.sankeyLink,!0).call(P,_,f.linkEvents),I.style(\"stroke\",function(t){return k(t)?o.tinyRGB(a(t.linkLineColor)):t.tinyColorHue}).style(\"stroke-opacity\",function(t){return k(t)?o.opacity(t.linkLineColor):t.tinyColorAlpha}).style(\"fill\",function(t){return t.tinyColorHue}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}).style(\"stroke-width\",function(t){return k(t)?t.linkLineWidth:1}).attr(\"d\",y()),I.style(\"opacity\",function(){return t._context.staticPlot||v||m?1:0}).transition().ease(n.ease).duration(n.duration).style(\"opacity\",1),I.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var D=_.selectAll(\".\"+n.cn.sankeyNodeSet).data(d,p);D.enter().append(\"g\").classed(n.cn.sankeyNodeSet,!0),D.style(\"cursor\",function(t){switch(t.arrangement){case\"fixed\":return\"default\";case\"perpendicular\":return\"ns-resize\";default:return\"move\"}});var R=D.selectAll(\".\"+n.cn.sankeyNode).data(function(t){var e=t.graph.nodes;return function(t){var e,r=[];for(e=0;e<t.length;e++)t[e].originalX=(t[e].x0+t[e].x1)/2,t[e].originalY=(t[e].y0+t[e].y1)/2,-1===r.indexOf(t[e].originalX)&&r.push(t[e].originalX);for(r.sort(function(t,e){return t-e}),e=0;e<t.length;e++)t[e].originalLayerIndex=r.indexOf(t[e].originalX),t[e].originalLayer=t[e].originalLayerIndex/(r.length-1)}(e),e.map(function(t,e){var r=a(e.color),i=n.nodePadAcross,s=t.nodePad/2;e.dx=e.x1-e.x0,e.dy=e.y1-e.y0;var l=e.dx,c=Math.max(.5,e.dy),u=\"node_\"+e.pointNumber;return e.group&&(u=h.randstr()),e.trace=t.trace,e.curveNumber=t.trace.index,{index:e.pointNumber,key:u,partOfGroup:e.partOfGroup||!1,group:e.group,traceId:t.key,trace:t.trace,node:e,nodePad:t.nodePad,nodeLineColor:t.nodeLineColor,nodeLineWidth:t.nodeLineWidth,textFont:t.textFont,size:t.horizontal?t.height:t.width,visibleWidth:Math.ceil(l),visibleHeight:c,zoneX:-i,zoneY:-s,zoneWidth:l+2*i,zoneHeight:c+2*s,labelY:t.horizontal?e.dy/2+1:e.dx/2+1,left:1===e.originalLayer,sizeAcross:t.width,forceLayouts:t.forceLayouts,horizontal:t.horizontal,darkBackground:r.getBrightness()<=128,tinyColorHue:o.tinyRGB(r),tinyColorAlpha:r.getAlpha(),valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,graph:t.graph,arrangement:t.arrangement,uniqueNodeLabelPathId:[t.guid,t.key,u].join(\"_\"),interactionState:t.interactionState,figure:t}}.bind(null,t))},p);R.enter().append(\"g\").classed(n.cn.sankeyNode,!0).call(x).style(\"opacity\",function(e){return!t._context.staticPlot&&!v||e.partOfGroup?0:1}),R.call(P,_,f.nodeEvents).call(O,I,f,t),R.transition().ease(n.ease).duration(n.duration).call(x).style(\"opacity\",function(t){return t.partOfGroup?0:1}),R.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var F=R.selectAll(\".\"+n.cn.nodeRect).data(d);F.enter().append(\"rect\").classed(n.cn.nodeRect,!0).call(w),F.style(\"stroke-width\",function(t){return t.nodeLineWidth}).style(\"stroke\",function(t){return o.tinyRGB(a(t.nodeLineColor))}).style(\"stroke-opacity\",function(t){return o.opacity(t.nodeLineColor)}).style(\"fill\",function(t){return t.tinyColorHue}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),F.transition().ease(n.ease).duration(n.duration).call(w);var B=R.selectAll(\".\"+n.cn.nodeCapture).data(d);B.enter().append(\"rect\").classed(n.cn.nodeCapture,!0).style(\"fill-opacity\",0),B.attr(\"x\",function(t){return t.zoneX}).attr(\"y\",function(t){return t.zoneY}).attr(\"width\",function(t){return t.zoneWidth}).attr(\"height\",function(t){return t.zoneHeight});var N=R.selectAll(\".\"+n.cn.nodeCentered).data(d);N.enter().append(\"g\").classed(n.cn.nodeCentered,!0).attr(\"transform\",A),N.transition().ease(n.ease).duration(n.duration).attr(\"transform\",A);var j=N.selectAll(\".\"+n.cn.nodeLabelGuide).data(d);j.enter().append(\"path\").classed(n.cn.nodeLabelGuide,!0).attr(\"id\",function(t){return t.uniqueNodeLabelPathId}).attr(\"d\",M).attr(\"transform\",S),j.transition().ease(n.ease).duration(n.duration).attr(\"d\",M).attr(\"transform\",S);var U=N.selectAll(\".\"+n.cn.nodeLabel).data(d);U.enter().append(\"text\").classed(n.cn.nodeLabel,!0).attr(\"transform\",E).style(\"user-select\",\"none\").style(\"cursor\",\"default\").style(\"fill\",\"black\"),U.style(\"text-shadow\",function(t){return t.horizontal?\"-1px 1px 1px #fff, 1px 1px 1px #fff, 1px -1px 1px #fff, -1px -1px 1px #fff\":\"none\"}).each(function(t){s.font(U,t.textFont)}),U.transition().ease(n.ease).duration(n.duration).attr(\"transform\",E);var V=U.selectAll(\".\"+n.cn.nodeLabelTextPath).data(d);V.enter().append(\"textPath\").classed(n.cn.nodeLabelTextPath,!0).attr(\"alignment-baseline\",\"middle\").attr(\"xlink:href\",function(t){return\"#\"+t.uniqueNodeLabelPathId}).attr(\"startOffset\",L).style(\"fill\",C),V.text(function(t){return t.horizontal||t.node.dy>5?t.node.label:\"\"}).attr(\"text-anchor\",function(t){return t.horizontal&&t.left?\"end\":\"start\"}),V.transition().ease(n.ease).duration(n.duration).attr(\"startOffset\",L).style(\"fill\",C)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/gup\":717,\"../../registry\":847,\"./constants\":1105,\"@plotly/d3-sankey\":54,\"@plotly/d3-sankey-circular\":53,d3:163,\"d3-force\":156,\"d3-interpolate\":158,tinycolor2:537}],1110:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=[],n=t.cd[0].trace,i=n._sankey.graph.nodes,a=0;a<i.length;a++){var o=i[a];if(!o.partOfGroup){var s=[(o.x0+o.x1)/2,(o.y0+o.y1)/2];\"v\"===n.orientation&&s.reverse(),e&&e.contains(s,!1,a,t)&&r.push({pointNumber:o.pointNumber})}}return r}},{}],1111:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\"),n.mergeArray(e.customdata,t,\"data\"),n.mergeArray(e.textposition,t,\"tp\"),e.textfont&&(n.mergeArrayCastPositive(e.textfont.size,t,\"ts\"),n.mergeArray(e.textfont.color,t,\"tc\"),n.mergeArray(e.textfont.family,t,\"tf\"));var i=e.marker;if(i){n.mergeArrayCastPositive(i.size,t,\"ms\"),n.mergeArrayCastPositive(i.opacity,t,\"mo\"),n.mergeArray(i.symbol,t,\"mx\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;i.line&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"));var o=i.gradient;o&&\"none\"!==o.type&&(n.mergeArray(o.type,t,\"mgt\"),n.mergeArray(o.color,t,\"mgc\"))}}},{\"../../lib\":719}],1112:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../components/drawing/attributes\").dash,s=t(\"../../components/drawing\"),l=t(\"./constants\"),c=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},x0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dx:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},y0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dy:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},stackgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc\"},groupnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},stackgaps:{valType:\"enumerated\",values:[\"infer zero\",\"interpolate\"],dflt:\"infer zero\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"],editType:\"calc\"},hoveron:{valType:\"flaglist\",flags:[\"points\",\"fills\"],editType:\"style\"},hovertemplate:n({},{keys:l.eventDataKeys}),line:{color:{valType:\"color\",editType:\"style\",anim:!0},width:{valType:\"number\",min:0,dflt:2,editType:\"style\",anim:!0},shape:{valType:\"enumerated\",values:[\"linear\",\"spline\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},smoothing:{valType:\"number\",min:0,max:1.3,dflt:1,editType:\"plot\"},dash:c({},o,{editType:\"style\"}),simplify:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cliponaxis:{valType:\"boolean\",dflt:!0,editType:\"plot\"},fill:{valType:\"enumerated\",values:[\"none\",\"tozeroy\",\"tozerox\",\"tonexty\",\"tonextx\",\"toself\",\"tonext\"],editType:\"calc\"},fillcolor:{valType:\"color\",editType:\"style\",anim:!0},marker:c({symbol:{valType:\"enumerated\",values:s.symbolList,dflt:\"circle\",arrayOk:!0,editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,arrayOk:!0,editType:\"style\",anim:!0},size:{valType:\"number\",min:0,dflt:6,arrayOk:!0,editType:\"calc\",anim:!0},maxdisplayed:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},sizeref:{valType:\"number\",dflt:1,editType:\"calc\"},sizemin:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"diameter\",\"area\"],dflt:\"diameter\",editType:\"calc\"},line:c({width:{valType:\"number\",min:0,arrayOk:!0,editType:\"style\",anim:!0},editType:\"calc\"},i(\"marker.line\",{anim:!0})),gradient:{type:{valType:\"enumerated\",values:[\"radial\",\"horizontal\",\"vertical\",\"none\"],arrayOk:!0,dflt:\"none\",editType:\"calc\"},color:{valType:\"color\",arrayOk:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},i(\"marker\",{anim:!0})),selected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},unselected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\"],dflt:\"middle center\",arrayOk:!0,editType:\"calc\"},textfont:a({editType:\"calc\",colorEditType:\"style\",arrayOk:!0}),r:{valType:\"data_array\",editType:\"calc\"},t:{valType:\"data_array\",editType:\"calc\"}}},{\"../../components/colorscale/attributes\":600,\"../../components/drawing\":614,\"../../components/drawing/attributes\":613,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"./constants\":1116}],1113:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/numerical\").BADNUM,s=t(\"./subtypes\"),l=t(\"./colorscale_calc\"),c=t(\"./arrays_to_calcdata\"),u=t(\"./calc_selection\");function h(t,e,r,n,i,o,l){var c=e._length,u=t._fullLayout,h=r._id,f=n._id,p=u._firstScatter[d(e)]===e.uid,v=(g(e,u,r,n)||{}).orientation,m=e.fill;r._minDtick=0,n._minDtick=0;var y={padded:!0},x={padded:!0};l&&(y.ppad=x.ppad=l);var b=c<2||i[0]!==i[c-1]||o[0]!==o[c-1];b&&(\"tozerox\"===m||\"tonextx\"===m&&(p||\"h\"===v))?y.tozero=!0:(e.error_y||{}).visible||\"tonexty\"!==m&&\"tozeroy\"!==m&&(s.hasMarkers(e)||s.hasText(e))||(y.padded=!1,y.ppad=0),b&&(\"tozeroy\"===m||\"tonexty\"===m&&(p||\"v\"===v))?x.tozero=!0:\"tonextx\"!==m&&\"tozerox\"!==m||(x.padded=!1),h&&(e._extremes[h]=a.findExtremes(r,i,y)),f&&(e._extremes[f]=a.findExtremes(n,o,x))}function f(t,e){if(s.hasMarkers(t)){var r,n=t.marker,o=1.6*(t.marker.sizeref||1);if(r=\"area\"===t.marker.sizemode?function(t){return Math.max(Math.sqrt((t||0)/o),3)}:function(t){return Math.max((t||0)/o,3)},i.isArrayOrTypedArray(n.size)){var l={type:\"linear\"};a.setConvert(l);for(var c=l.makeCalcdata(t.marker,\"size\"),u=new Array(e),h=0;h<e;h++)u[h]=r(c[h]);return u}return r(n.size)}}function p(t,e){var r=d(e),n=t._firstScatter;n[r]||(n[r]=e.uid)}function d(t){var e=t.stackgroup;return t.xaxis+t.yaxis+t.type+(e?\"-\"+e:\"\")}function g(t,e,r,n){var i=t.stackgroup;if(i){var a=e._scatterStackOpts[r._id+n._id][i],o=\"v\"===a.orientation?n:r;return\"linear\"===o.type||\"log\"===o.type?a:void 0}}e.exports={calc:function(t,e){var r,s,d,v,m,y,x=t._fullLayout,b=a.getFromId(t,e.xaxis||\"x\"),_=a.getFromId(t,e.yaxis||\"y\"),w=b.makeCalcdata(e,\"x\"),k=_.makeCalcdata(e,\"y\"),T=e._length,A=new Array(T),M=e.ids,S=g(e,x,b,_),E=!1;p(x,e);var C,L=\"x\",P=\"y\";for(S?(i.pushUnique(S.traceIndices,e._expandedIndex),(r=\"v\"===S.orientation)?(P=\"s\",C=\"x\"):(L=\"s\",C=\"y\"),m=\"interpolate\"===S.stackgaps):h(t,e,b,_,w,k,f(e,T)),s=0;s<T;s++){var O=A[s]={},z=n(w[s]),I=n(k[s]);z&&I?(O[L]=w[s],O[P]=k[s]):S&&(r?z:I)?(O[C]=r?w[s]:k[s],O.gap=!0,m?(O.s=o,E=!0):O.s=0):O[L]=O[P]=o,M&&(O.id=String(M[s]))}if(c(A,e),l(t,e),u(A,e),S){for(s=0;s<A.length;)A[s][C]===o?A.splice(s,1):s++;if(i.sort(A,function(t,e){return t[C]-e[C]||t.i-e.i}),E){for(s=0;s<A.length-1&&A[s].gap;)s++;for((y=A[s].s)||(y=A[s].s=0),d=0;d<s;d++)A[d].s=y;for(v=A.length-1;v>s&&A[v].gap;)v--;for(y=A[v].s,d=A.length-1;d>v;d--)A[d].s=y;for(;s<v;)if(A[++s].gap){for(d=s+1;A[d].gap;)d++;for(var D=A[s-1][C],R=A[s-1].s,F=(A[d].s-R)/(A[d][C]-D);s<d;)A[s].s=R+(A[s][C]-D)*F,s++}}}return A},calcMarkerSize:f,calcAxisExpansion:h,setFirstScatter:p,getStackOpts:g}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./arrays_to_calcdata\":1111,\"./calc_selection\":1114,\"./colorscale_calc\":1115,\"./subtypes\":1135,\"fast-isnumeric\":225}],1114:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){n.isArrayOrTypedArray(e.selectedpoints)&&n.tagSelected(t,e)}},{\"../../lib\":719}],1115:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"./subtypes\");e.exports=function(t,e){a.hasLines(e)&&n(e,\"line\")&&i(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),a.hasMarkers(e)&&(n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}))}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"./subtypes\":1135}],1116:[function(t,e,r){\"use strict\";e.exports={PTS_LINESONLY:20,minTolerance:.2,toleranceGrowth:10,maxScreensAway:20,eventDataKeys:[]}},{}],1117:[function(t,e,r){\"use strict\";var n=t(\"./calc\");function i(t,e,r,n,i,a,o){i[n]=!0;var s={i:null,gap:!0,s:0};if(s[o]=r,t.splice(e,0,s),e&&r===t[e-1][o]){var l=t[e-1];s.s=l.s,s.i=l.i,s.gap=l.gap}else a&&(s.s=function(t,e,r,n){var i=t[e-1],a=t[e+1];return a?i?i.s+(a.s-i.s)*(r-i[n])/(a[n]-i[n]):a.s:i.s}(t,e,r,o));e||(t[0].t=t[1].t,t[0].trace=t[1].trace,delete t[1].t,delete t[1].trace)}e.exports=function(t,e){var r=e.xaxis,a=e.yaxis,o=r._id+a._id,s=t._fullLayout._scatterStackOpts[o];if(s){var l,c,u,h,f,p,d,g,v,m,y,x,b,_,w,k=t.calcdata;for(var T in s){var A=(m=s[T]).traceIndices;if(A.length){for(y=\"interpolate\"===m.stackgaps,x=m.groupnorm,\"v\"===m.orientation?(b=\"x\",_=\"y\"):(b=\"y\",_=\"x\"),w=new Array(A.length),l=0;l<w.length;l++)w[l]=!1;p=k[A[0]];var M=new Array(p.length);for(l=0;l<p.length;l++)M[l]=p[l][b];for(l=1;l<A.length;l++){for(f=k[A[l]],c=u=0;c<f.length;c++){for(d=f[c][b];d>M[u]&&u<M.length;u++)i(f,c,M[u],l,w,y,b),c++;if(d!==M[u]){for(h=0;h<l;h++)i(k[A[h]],u,d,h,w,y,b);M.splice(u,0,d)}u++}for(;u<M.length;u++)i(f,c,M[u],l,w,y,b),c++}var S=M.length;for(c=0;c<p.length;c++){for(g=p[c][_]=p[c].s,l=1;l<A.length;l++)(f=k[A[l]])[0].trace._rawLength=f[0].trace._length,f[0].trace._length=S,g+=f[c].s,f[c][_]=g;if(x)for(v=(\"fraction\"===x?g:g/100)||1,l=0;l<A.length;l++){var E=k[A[l]][c];E[_]/=v,E.sNorm=E.s/v}}for(l=0;l<A.length;l++){var C=(f=k[A[l]])[0].trace,L=n.calcMarkerSize(C,C._rawLength),P=Array.isArray(L);if(L&&w[l]||P){var O=L;for(L=new Array(S),c=0;c<S;c++)L[c]=f[c].gap?0:P?O[f[c].i]:O}var z=new Array(S),I=new Array(S);for(c=0;c<S;c++)z[c]=f[c].x,I[c]=f[c].y;n.calcAxisExpansion(t,C,r,a,z,I,L),f[0].t.orientation=m.orientation}}}}}},{\"./calc\":1113}],1118:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0;e<t.length;e++){var r=t[e];if(\"scatter\"===r.type){var n=r.fill;if(\"none\"!==n&&\"toself\"!==n&&(r.opacity=void 0,\"tonexty\"===n||\"tonextx\"===n))for(var i=e-1;i>=0;i--){var a=t[i];if(\"scatter\"===a.type&&a.xaxis===r.xaxis&&a.yaxis===r.yaxis){a.opacity=void 0;break}}}}}},{}],1119:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"./constants\"),s=t(\"./subtypes\"),l=t(\"./xy_defaults\"),c=t(\"./stack_defaults\"),u=t(\"./marker_defaults\"),h=t(\"./line_defaults\"),f=t(\"./line_shape_defaults\"),p=t(\"./text_defaults\"),d=t(\"./fillcolor_defaults\");e.exports=function(t,e,r,g){function v(r,i){return n.coerce(t,e,a,r,i)}var m=l(t,e,g,v);if(m||(e.visible=!1),e.visible){var y=c(t,e,g,v),x=!y&&m<o.PTS_LINESONLY?\"lines+markers\":\"lines\";v(\"text\"),v(\"hovertext\"),v(\"mode\",x),s.hasLines(e)&&(h(t,e,r,g,v),f(t,e,v),v(\"connectgaps\"),v(\"line.simplify\")),s.hasMarkers(e)&&u(t,e,r,g,v,{gradient:!0}),s.hasText(e)&&p(t,e,g,v);var b=[];(s.hasMarkers(e)||s.hasText(e))&&(v(\"cliponaxis\"),v(\"marker.maxdisplayed\"),b.push(\"points\")),v(\"fill\",y?y.fillDflt:\"none\"),\"none\"!==e.fill&&(d(t,e,r,v),s.hasLines(e)||f(t,e,v));var _=(e.line||{}).color,w=(e.marker||{}).color;\"tonext\"!==e.fill&&\"toself\"!==e.fill||b.push(\"fills\"),v(\"hoveron\",b.join(\"+\")||\"points\"),\"fills\"!==e.hoveron&&v(\"hovertemplate\");var k=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");k(t,e,_||w||r,{axis:\"y\"}),k(t,e,_||w||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,v)}}},{\"../../lib\":719,\"../../registry\":847,\"./attributes\":1112,\"./constants\":1116,\"./fillcolor_defaults\":1120,\"./line_defaults\":1124,\"./line_shape_defaults\":1126,\"./marker_defaults\":1130,\"./stack_defaults\":1133,\"./subtypes\":1135,\"./text_defaults\":1136,\"./xy_defaults\":1137}],1120:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a){var o=!1;if(e.marker){var s=e.marker.color,l=(e.marker.line||{}).color;s&&!i(s)?o=s:l&&!i(l)&&(o=l)}a(\"fillcolor\",n.addOpacity((e.line||{}).color||o||r,.5))}},{\"../../components/color\":593,\"../../lib\":719}],1121:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./subtypes\");e.exports=function(t,e){var r,a;if(\"lines\"===t.mode)return(r=t.line.color)&&n.opacity(r)?r:t.fillcolor;if(\"none\"===t.mode)return t.fill?t.fillcolor:\"\";var o=e.mcc||(t.marker||{}).color,s=e.mlcc||((t.marker||{}).line||{}).color;return(a=o&&n.opacity(o)?o:s&&n.opacity(s)&&(e.mlw||((t.marker||{}).line||{}).width)?s:\"\")?n.opacity(a)<.3?n.addOpacity(a,.3):a:(r=(t.line||{}).color)&&n.opacity(r)&&i.hasLines(t)&&t.line.width?r:t.fillcolor}},{\"../../components/color\":593,\"./subtypes\":1135}],1122:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/fx\"),a=t(\"../../registry\"),o=t(\"./get_trace_color\"),s=t(\"../../components/color\"),l=n.fillText;e.exports=function(t,e,r,c){var u=t.cd,h=u[0].trace,f=t.xa,p=t.ya,d=f.c2p(e),g=p.c2p(r),v=[d,g],m=h.hoveron||\"\",y=-1!==h.mode.indexOf(\"markers\")?3:.5;if(-1!==m.indexOf(\"points\")){var x=function(t){var e=Math.max(y,t.mrc||0),r=f.c2p(t.x)-d,n=p.c2p(t.y)-g;return Math.max(Math.sqrt(r*r+n*n)-e,1-y/e)},b=i.getDistanceFunction(c,function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(f.c2p(t.x)-d);return n<e?r*n/e:n-e+r},function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(p.c2p(t.y)-g);return n<e?r*n/e:n-e+r},x);if(i.getClosest(u,b,t),!1!==t.index){var _=u[t.index],w=f.c2p(_.x,!0),k=p.c2p(_.y,!0),T=_.mrc||1;t.index=_.i;var A=u[0].t.orientation,M=A&&(_.sNorm||_.s),S=\"h\"===A?M:_.x,E=\"v\"===A?M:_.y;return n.extendFlat(t,{color:o(h,_),x0:w-T,x1:w+T,xLabelVal:S,y0:k-T,y1:k+T,yLabelVal:E,spikeDistance:x(_),hovertemplate:h.hovertemplate}),l(_,h,t),a.getComponentMethod(\"errorbars\",\"hoverInfo\")(_,h,t),[t]}}if(-1!==m.indexOf(\"fills\")&&h._polygons){var C,L,P,O,z,I,D,R,F,B=h._polygons,N=[],j=!1,U=1/0,V=-1/0,q=1/0,H=-1/0;for(C=0;C<B.length;C++)(P=B[C]).contains(v)&&(j=!j,N.push(P),q=Math.min(q,P.ymin),H=Math.max(H,P.ymax));if(j){var G=((q=Math.max(q,0))+(H=Math.min(H,p._length)))/2;for(C=0;C<N.length;C++)for(O=N[C].pts,L=1;L<O.length;L++)(R=O[L-1][1])>G!=(F=O[L][1])>=G&&(I=O[L-1][0],D=O[L][0],F-R&&(z=I+(D-I)*(G-R)/(F-R),U=Math.min(U,z),V=Math.max(V,z)));U=Math.max(U,0),V=Math.min(V,f._length);var Y=s.defaultLine;return s.opacity(h.fillcolor)?Y=h.fillcolor:s.opacity((h.line||{}).color)&&(Y=h.line.color),n.extendFlat(t,{distance:t.maxHoverDistance,x0:U,x1:V,y0:G,y1:G,color:Y,hovertemplate:!1}),delete t.index,h.text&&!Array.isArray(h.text)?t.text=String(h.text):t.text=h.name,[t]}}}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"../../registry\":847,\"./get_trace_color\":1121}],1123:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports={hasLines:n.hasLines,hasMarkers:n.hasMarkers,hasText:n.hasText,isBubble:n.isBubble,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./cross_trace_calc\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\"),colorbar:t(\"./marker_colorbar\"),style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"./select\"),animatable:!0,moduleType:\"trace\",name:\"scatter\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"./arrays_to_calcdata\":1111,\"./attributes\":1112,\"./calc\":1113,\"./cross_trace_calc\":1117,\"./cross_trace_defaults\":1118,\"./defaults\":1119,\"./hover\":1122,\"./marker_colorbar\":1129,\"./plot\":1131,\"./select\":1132,\"./style\":1134,\"./subtypes\":1135}],1124:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s,l){var c=(t.marker||{}).color;(s(\"line.color\",r),i(t,\"line\"))?a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}):s(\"line.color\",!n(c)&&c||r);s(\"line.width\"),(l||{}).noDash||s(\"line.dash\")}},{\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"../../lib\":719}],1125:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.BADNUM,a=n.LOG_CLIP,o=a+.5,s=a-.5,l=t(\"../../lib\"),c=l.segmentsIntersect,u=l.constrain,h=t(\"./constants\");e.exports=function(t,e){var r,n,a,f,p,d,g,v,m,y,x,b,_,w,k,T,A,M,S=e.xaxis,E=e.yaxis,C=\"log\"===S.type,L=\"log\"===E.type,P=S._length,O=E._length,z=e.connectGaps,I=e.baseTolerance,D=e.shape,R=\"linear\"===D,F=e.fill&&\"none\"!==e.fill,B=[],N=h.minTolerance,j=t.length,U=new Array(j),V=0;function q(e){var r=t[e];if(!r)return!1;var n=S.c2p(r.x),a=E.c2p(r.y);if(n===i){if(C&&(n=S.c2p(r.x,!0)),n===i)return!1;L&&a===i&&(n*=Math.abs(S._m*O*(S._m>0?o:s)/(E._m*P*(E._m>0?o:s)))),n*=1e3}if(a===i){if(L&&(a=E.c2p(r.y,!0)),a===i)return!1;a*=1e3}return[n,a]}function H(t,e,r,n){var i=r-t,a=n-e,o=.5-t,s=.5-e,l=i*i+a*a,c=i*o+a*s;if(c>0&&c<l){var u=o*a-s*i;if(u*u<l)return!0}}function G(t,e){var r=t[0]/P,n=t[1]/O,i=Math.max(0,-r,r-1,-n,n-1);return i&&void 0!==A&&H(r,n,A,M)&&(i=0),i&&e&&H(r,n,e[0]/P,e[1]/O)&&(i=0),(1+h.toleranceGrowth*i)*I}function Y(t,e){var r=t[0]-e[0],n=t[1]-e[1];return Math.sqrt(r*r+n*n)}var W,X,Z,J,K,$,Q,tt=h.maxScreensAway,et=-P*tt,rt=P*(1+tt),nt=-O*tt,it=O*(1+tt),at=[[et,nt,rt,nt],[rt,nt,rt,it],[rt,it,et,it],[et,it,et,nt]];function ot(t){if(t[0]<et||t[0]>rt||t[1]<nt||t[1]>it)return[u(t[0],et,rt),u(t[1],nt,it)]}function st(t,e){return t[0]===e[0]&&(t[0]===et||t[0]===rt)||(t[1]===e[1]&&(t[1]===nt||t[1]===it)||void 0)}function lt(t,e,r){return function(n,i){var a=ot(n),o=ot(i),s=[];if(a&&o&&st(a,o))return s;a&&s.push(a),o&&s.push(o);var c=2*l.constrain((n[t]+i[t])/2,e,r)-((a||n)[t]+(o||i)[t]);c&&((a&&o?c>0==a[t]>o[t]?a:o:a||o)[t]+=c);return s}}function ct(t){var e=t[0],r=t[1],n=e===U[V-1][0],i=r===U[V-1][1];if(!n||!i)if(V>1){var a=e===U[V-2][0],o=r===U[V-2][1];n&&(e===et||e===rt)&&a?o?V--:U[V-1]=t:i&&(r===nt||r===it)&&o?a?V--:U[V-1]=t:U[V++]=t}else U[V++]=t}function ut(t){U[V-1][0]!==t[0]&&U[V-1][1]!==t[1]&&ct([Z,J]),ct(t),K=null,Z=J=0}function ht(t){if(A=t[0]/P,M=t[1]/O,W=t[0]<et?et:t[0]>rt?rt:0,X=t[1]<nt?nt:t[1]>it?it:0,W||X){if(V)if(K){var e=Q(K,t);e.length>1&&(ut(e[0]),U[V++]=e[1])}else $=Q(U[V-1],t)[0],U[V++]=$;else U[V++]=[W||t[0],X||t[1]];var r=U[V-1];W&&X&&(r[0]!==W||r[1]!==X)?(K&&(Z!==W&&J!==X?ct(Z&&J?(n=K,a=(i=t)[0]-n[0],o=(i[1]-n[1])/a,(n[1]*i[0]-i[1]*n[0])/a>0?[o>0?et:rt,it]:[o>0?rt:et,nt]):[Z||W,J||X]):Z&&J&&ct([Z,J])),ct([W,X])):Z-W&&J-X&&ct([W||Z,X||J]),K=t,Z=W,J=X}else K&&ut(Q(K,t)[0]),U[V++]=t;var n,i,a,o}for(\"linear\"===D||\"spline\"===D?Q=function(t,e){for(var r=[],n=0,i=0;i<4;i++){var a=at[i],o=c(t[0],t[1],e[0],e[1],a[0],a[1],a[2],a[3]);o&&(!n||Math.abs(o.x-r[0][0])>1||Math.abs(o.y-r[0][1])>1)&&(o=[o.x,o.y],n&&Y(o,t)<Y(r[0],t)?r.unshift(o):r.push(o),n++)}return r}:\"hv\"===D||\"vh\"===D?Q=function(t,e){var r=[],n=ot(t),i=ot(e);return n&&i&&st(n,i)?r:(n&&r.push(n),i&&r.push(i),r)}:\"hvh\"===D?Q=lt(0,et,rt):\"vhv\"===D&&(Q=lt(1,nt,it)),r=0;r<j;r++)if(n=q(r)){for(V=0,K=null,ht(n),r++;r<j;r++){if(!(f=q(r))){if(z)continue;break}if(R&&e.simplify){var ft=q(r+1);if(y=Y(f,n),F&&(0===V||V===j-1)||!(y<G(f,ft)*N)){for(v=[(f[0]-n[0])/y,(f[1]-n[1])/y],p=n,x=y,b=w=k=0,g=!1,a=f,r++;r<t.length;r++){if(d=ft,ft=q(r+1),!d){if(z)continue;break}if(T=(m=[d[0]-n[0],d[1]-n[1]])[0]*v[1]-m[1]*v[0],w=Math.min(w,T),(k=Math.max(k,T))-w>G(d,ft))break;a=d,(_=m[0]*v[0]+m[1]*v[1])>x?(x=_,f=d,g=!1):_<b&&(b=_,p=d,g=!0)}if(g?(ht(f),a!==p&&ht(p)):(p!==n&&ht(p),a!==f&&ht(f)),ht(a),r>=t.length||!d)break;ht(d),n=d}}else ht(f)}K&&ct([Z||K[0],J||K[1]]),B.push(U.slice(0,V))}return B}},{\"../../constants/numerical\":695,\"../../lib\":719,\"./constants\":1116}],1126:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){\"spline\"===r(\"line.shape\")&&r(\"line.smoothing\")}},{}],1127:[function(t,e,r){\"use strict\";var n={tonextx:1,tonexty:1,tonext:1};e.exports=function(t,e,r){var i,a,o,s,l,c={},u=!1,h=-1,f=0,p=-1;for(a=0;a<r.length;a++)(o=(i=r[a][0].trace).stackgroup||\"\")?o in c?l=c[o]:(l=c[o]=f,f++):i.fill in n&&p>=0?l=p:(l=p=f,f++),l<h&&(u=!0),i._groupIndex=h=l;var d=r.slice();u&&d.sort(function(t,e){var r=t[0].trace,n=e[0].trace;return r._groupIndex-n._groupIndex||r.index-n.index});var g={};for(a=0;a<d.length;a++)o=(i=d[a][0].trace).stackgroup||\"\",!0===i.visible?(i._nexttrace=null,i.fill in n&&(s=g[o],i._prevtrace=s||null,s&&(s._nexttrace=i)),i._ownfill=i.fill&&(\"tozero\"===i.fill.substr(0,6)||\"toself\"===i.fill||\"to\"===i.fill.substr(0,2)&&!i._prevtrace),g[o]=i):i._prevtrace=i._nexttrace=i._ownfill=null;return d}},{}],1128:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t){var e=t.marker,r=e.sizeref||1,i=e.sizemin||0,a=\"area\"===e.sizemode?function(t){return Math.sqrt(t/r)}:function(t){return t/r};return function(t){var e=a(t/2);return n(e)&&e>0?Math.max(e,i):0}}},{\"fast-isnumeric\":225}],1129:[function(t,e,r){\"use strict\";e.exports={container:\"marker\",min:\"cmin\",max:\"cmax\"}},{}],1130:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"./subtypes\");e.exports=function(t,e,r,s,l,c){var u=o.isBubble(t),h=(t.line||{}).color;(c=c||{},h&&(r=h),l(\"marker.symbol\"),l(\"marker.opacity\",u?.7:1),l(\"marker.size\"),l(\"marker.color\",r),i(t,\"marker\")&&a(t,e,s,l,{prefix:\"marker.\",cLetter:\"c\"}),c.noSelect||(l(\"selected.marker.color\"),l(\"unselected.marker.color\"),l(\"selected.marker.size\"),l(\"unselected.marker.size\")),c.noLine||(l(\"marker.line.color\",h&&!Array.isArray(h)&&e.marker.color!==h?h:u?n.background:n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,l,{prefix:\"marker.line.\",cLetter:\"c\"}),l(\"marker.line.width\",u?1:0)),u&&(l(\"marker.sizeref\"),l(\"marker.sizemin\"),l(\"marker.sizemode\")),c.gradient)&&(\"none\"!==l(\"marker.gradient.type\")&&l(\"marker.gradient.color\"))}},{\"../../components/color\":593,\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"./subtypes\":1135}],1131:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=a.ensureSingle,s=a.identity,l=t(\"../../components/drawing\"),c=t(\"./subtypes\"),u=t(\"./line_points\"),h=t(\"./link_traces\"),f=t(\"../../lib/polygon\").tester;function p(t,e,r,h,p,d,g){var v;!function(t,e,r,i,o){var s=r.xaxis,l=r.yaxis,u=n.extent(a.simpleMap(s.range,s.r2c)),h=n.extent(a.simpleMap(l.range,l.r2c)),f=i[0].trace;if(!c.hasMarkers(f))return;var p=f.marker.maxdisplayed;if(0===p)return;var d=i.filter(function(t){return t.x>=u[0]&&t.x<=u[1]&&t.y>=h[0]&&t.y<=h[1]}),g=Math.ceil(d.length/p),v=0;o.forEach(function(t,r){var n=t[0].trace;c.hasMarkers(n)&&n.marker.maxdisplayed>0&&r<e&&v++});var m=Math.round(v*g/3+Math.floor(v/3)*g/7.1);i.forEach(function(t){delete t.vis}),d.forEach(function(t,e){0===Math.round((e+m)%g)&&(t.vis=!0)})}(0,e,r,h,p);var m=!!g&&g.duration>0;function y(t){return m?t.transition():t}var x=r.xaxis,b=r.yaxis,_=h[0].trace,w=_.line,k=n.select(d),T=o(k,\"g\",\"errorbars\"),A=o(k,\"g\",\"lines\"),M=o(k,\"g\",\"points\"),S=o(k,\"g\",\"text\");if(i.getComponentMethod(\"errorbars\",\"plot\")(t,T,r,g),!0===_.visible){var E,C;y(k).style(\"opacity\",_.opacity);var L=_.fill.charAt(_.fill.length-1);\"x\"!==L&&\"y\"!==L&&(L=\"\"),h[0][r.isRangePlot?\"nodeRangePlot3\":\"node3\"]=k;var P,O,z=\"\",I=[],D=_._prevtrace;D&&(z=D._prevRevpath||\"\",C=D._nextFill,I=D._polygons);var R,F,B,N,j,U,V,q=\"\",H=\"\",G=[],Y=a.noop;if(E=_._ownFill,c.hasLines(_)||\"none\"!==_.fill){for(C&&C.datum(h),-1!==[\"hv\",\"vh\",\"hvh\",\"vhv\"].indexOf(w.shape)?(R=l.steps(w.shape),F=l.steps(w.shape.split(\"\").reverse().join(\"\"))):R=F=\"spline\"===w.shape?function(t){var e=t[t.length-1];return t.length>1&&t[0][0]===e[0]&&t[0][1]===e[1]?l.smoothclosed(t.slice(1),w.smoothing):l.smoothopen(t,w.smoothing)}:function(t){return\"M\"+t.join(\"L\")},B=function(t){return F(t.reverse())},G=u(h,{xaxis:x,yaxis:b,connectGaps:_.connectgaps,baseTolerance:Math.max(w.width||1,3)/4,shape:w.shape,simplify:w.simplify,fill:_.fill}),V=_._polygons=new Array(G.length),v=0;v<G.length;v++)_._polygons[v]=f(G[v]);G.length&&(N=G[0][0],U=(j=G[G.length-1])[j.length-1]),Y=function(t){return function(e){if(P=R(e),O=B(e),q?L?(q+=\"L\"+P.substr(1),H=O+\"L\"+H.substr(1)):(q+=\"Z\"+P,H=O+\"Z\"+H):(q=P,H=O),c.hasLines(_)&&e.length>1){var r=n.select(this);if(r.datum(h),t)y(r.style(\"opacity\",0).attr(\"d\",P).call(l.lineGroupStyle)).style(\"opacity\",1);else{var i=y(r);i.attr(\"d\",P),l.singleLineStyle(h,i)}}}}}var W=A.selectAll(\".js-line\").data(G);y(W.exit()).style(\"opacity\",0).remove(),W.each(Y(!1)),W.enter().append(\"path\").classed(\"js-line\",!0).style(\"vector-effect\",\"non-scaling-stroke\").call(l.lineGroupStyle).each(Y(!0)),l.setClipUrl(W,r.layerClipId,t),G.length?(E?(E.datum(h),N&&U&&(L?(\"y\"===L?N[1]=U[1]=b.c2p(0,!0):\"x\"===L&&(N[0]=U[0]=x.c2p(0,!0)),y(E).attr(\"d\",\"M\"+U+\"L\"+N+\"L\"+q.substr(1)).call(l.singleFillStyle)):y(E).attr(\"d\",q+\"Z\").call(l.singleFillStyle))):C&&(\"tonext\"===_.fill.substr(0,6)&&q&&z?(\"tonext\"===_.fill?y(C).attr(\"d\",q+\"Z\"+z+\"Z\").call(l.singleFillStyle):y(C).attr(\"d\",q+\"L\"+z.substr(1)+\"Z\").call(l.singleFillStyle),_._polygons=_._polygons.concat(I)):(Z(C),_._polygons=null)),_._prevRevpath=H,_._prevPolygons=V):(E?Z(E):C&&Z(C),_._polygons=_._prevRevpath=_._prevPolygons=null),M.datum(h),S.datum(h),function(e,i,a){var o,u=a[0].trace,h=c.hasMarkers(u),f=c.hasText(u),p=tt(u),d=et,g=et;if(h||f){var v=s,_=u.stackgroup,w=_&&\"infer zero\"===t._fullLayout._scatterStackOpts[x._id+b._id][_].stackgaps;u.marker.maxdisplayed||u._needsCull?v=w?K:J:_&&!w&&(v=$),h&&(d=v),f&&(g=v)}var k,T=(o=e.selectAll(\"path.point\").data(d,p)).enter().append(\"path\").classed(\"point\",!0);m&&T.call(l.pointStyle,u,t).call(l.translatePoints,x,b).style(\"opacity\",0).transition().style(\"opacity\",1),o.order(),h&&(k=l.makePointStyleFns(u)),o.each(function(e){var i=n.select(this),a=y(i);l.translatePoint(e,a,x,b)?(l.singlePointStyle(e,a,u,k,t),r.layerClipId&&l.hideOutsideRangePoint(e,a,x,b,u.xcalendar,u.ycalendar),u.customdata&&i.classed(\"plotly-customdata\",null!==e.data&&void 0!==e.data)):a.remove()}),m?o.exit().transition().style(\"opacity\",0).remove():o.exit().remove(),(o=i.selectAll(\"g\").data(g,p)).enter().append(\"g\").classed(\"textpoint\",!0).append(\"text\"),o.order(),o.each(function(t){var e=n.select(this),i=y(e.select(\"text\"));l.translatePoint(t,i,x,b)?r.layerClipId&&l.hideOutsideRangePoint(t,e,x,b,u.xcalendar,u.ycalendar):e.remove()}),o.selectAll(\"text\").call(l.textPointStyle,u,t).each(function(t){var e=x.c2p(t.x),r=b.c2p(t.y);n.select(this).selectAll(\"tspan.line\").each(function(){y(n.select(this)).attr({x:e,y:r})})}),o.exit().remove()}(M,S,h);var X=!1===_.cliponaxis?null:r.layerClipId;l.setClipUrl(M,X,t),l.setClipUrl(S,X,t)}function Z(t){y(t).attr(\"d\",\"M0,0Z\")}function J(t){return t.filter(function(t){return!t.gap&&t.vis})}function K(t){return t.filter(function(t){return t.vis})}function $(t){return t.filter(function(t){return!t.gap})}function Q(t){return t.id}function tt(t){if(t.ids)return Q}function et(){return!1}}e.exports=function(t,e,r,i,a,c){var u,f,d=!a,g=!!a&&a.duration>0,v=h(t,e,r);((u=i.selectAll(\"g.trace\").data(v,function(t){return t[0].trace.uid})).enter().append(\"g\").attr(\"class\",function(t){return\"trace scatter trace\"+t[0].trace.uid}).style(\"stroke-miterlimit\",2),u.order(),function(t,e,r){e.each(function(e){var i=o(n.select(this),\"g\",\"fills\");l.setClipUrl(i,r.layerClipId,t);var a=e[0].trace,c=[];a._ownfill&&c.push(\"_ownFill\"),a._nexttrace&&c.push(\"_nextFill\");var u=i.selectAll(\"g\").data(c,s);u.enter().append(\"g\"),u.exit().each(function(t){a[t]=null}).remove(),u.order().each(function(t){a[t]=o(n.select(this),\"path\",\"js-fill\")})})}(t,u,e),g)?(c&&(f=c()),n.transition().duration(a.duration).ease(a.easing).each(\"end\",function(){f&&f()}).each(\"interrupt\",function(){f&&f()}).each(function(){i.selectAll(\"g.trace\").each(function(r,n){p(t,n,e,r,v,this,a)})})):u.each(function(r,n){p(t,n,e,r,v,this,a)});d&&u.exit().remove(),i.selectAll(\"path:not([d])\").remove()}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/polygon\":731,\"../../registry\":847,\"./line_points\":1125,\"./link_traces\":1127,\"./subtypes\":1135,d3:163}],1132:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports=function(t,e){var r,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[],h=s[0].trace;if(!n.hasMarkers(h)&&!n.hasText(h))return[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)i=s[r],a=l.c2p(i.x),o=c.c2p(i.y),null!==i.i&&e.contains([a,o],!1,r,t)?(u.push({pointNumber:i.i,x:l.c2d(i.x),y:c.c2d(i.y)}),i.selected=1):i.selected=0;return u}},{\"./subtypes\":1135}],1133:[function(t,e,r){\"use strict\";var n=[\"orientation\",\"groupnorm\",\"stackgaps\"];e.exports=function(t,e,r,i){var a=r._scatterStackOpts,o=i(\"stackgroup\");if(o){var s=e.xaxis+e.yaxis,l=a[s];l||(l=a[s]={});var c=l[o],u=!1;c?c.traces.push(e):(c=l[o]={traceIndices:[],traces:[e]},u=!0);for(var h={orientation:e.x&&!e.y?\"h\":\"v\"},f=0;f<n.length;f++){var p=n[f],d=p+\"Found\";if(!c[d]){var g=void 0!==t[p],v=\"orientation\"===p;if((g||u)&&(c[p]=i(p,h[p]),v&&(c.fillDflt=\"h\"===c[p]?\"tonextx\":\"tonexty\"),g&&(c[d]=!0,!u&&(delete c.traces[0][p],v))))for(var m=0;m<c.traces.length-1;m++){var y=c.traces[m];y._input.fill!==y.fill&&(y.fill=c.fillDflt)}}}return c}}},{}],1134:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../registry\");function o(t,e,r){i.pointStyle(t.selectAll(\"path.point\"),e,r)}function s(t,e,r){i.textPointStyle(t.selectAll(\"text\"),e,r)}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.trace.scatter\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.selectAll(\"g.points\").each(function(e){o(n.select(this),e.trace||e[0].trace,t)}),e.selectAll(\"g.text\").each(function(e){s(n.select(this),e.trace||e[0].trace,t)}),e.selectAll(\"g.trace path.js-line\").call(i.lineGroupStyle),e.selectAll(\"g.trace path.js-fill\").call(i.fillGroupStyle),a.getComponentMethod(\"errorbars\",\"style\")(e)},stylePoints:o,styleText:s,styleOnSelect:function(t,e,r){var n=e[0].trace;n.selectedpoints?(i.selectedPointStyle(r.selectAll(\"path.point\"),n),i.selectedTextStyle(r.selectAll(\"text\"),n)):(o(r,n,t),s(r,n,t))}}},{\"../../components/drawing\":614,\"../../registry\":847,d3:163}],1135:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports={hasLines:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"lines\")},hasMarkers:function(t){return t.visible&&(t.mode&&-1!==t.mode.indexOf(\"markers\")||\"splom\"===t.type)},hasText:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"text\")},isBubble:function(t){return n.isPlainObject(t.marker)&&n.isArrayOrTypedArray(t.marker.size)}}},{\"../../lib\":719}],1136:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i,a){a=a||{},i(\"textposition\"),n.coerceFont(i,\"textfont\",r.font),a.noSelect||(i(\"selected.textfont.color\"),i(\"unselected.textfont.color\"))}},{\"../../lib\":719}],1137:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");e.exports=function(t,e,r,a){var o,s=a(\"x\"),l=a(\"y\");if(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],r),s){var c=n.minRowLength(s);l?o=Math.min(c,n.minRowLength(l)):(o=c,a(\"y0\"),a(\"dy\"))}else{if(!l)return 0;o=n.minRowLength(l),a(\"x0\"),a(\"dx\")}return e._length=o,o}},{\"../../lib\":719,\"../../registry\":847}],1138:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../constants/gl3d_dashes\"),l=t(\"../../constants/gl3d_markers\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../plot_api/edit_types\").overrideAll,h=n.line,f=n.marker,p=f.line,d=c({width:h.width,dash:{valType:\"enumerated\",values:Object.keys(s),dflt:\"solid\"}},i(\"line\"));var g=e.exports=u({x:n.x,y:n.y,z:{valType:\"data_array\"},text:c({},n.text,{}),hovertext:c({},n.hovertext,{}),hovertemplate:a(),mode:c({},n.mode,{dflt:\"lines+markers\"}),surfaceaxis:{valType:\"enumerated\",values:[-1,0,1,2],dflt:-1},surfacecolor:{valType:\"color\"},projection:{x:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},y:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},z:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}}},connectgaps:n.connectgaps,line:d,marker:c({symbol:{valType:\"enumerated\",values:Object.keys(l),dflt:\"circle\",arrayOk:!0},size:c({},f.size,{dflt:8}),sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode,opacity:c({},f.opacity,{arrayOk:!1}),colorbar:f.colorbar,line:c({width:c({},p.width,{arrayOk:!1})},i(\"marker.line\"))},i(\"marker\")),textposition:c({},n.textposition,{dflt:\"top center\"}),textfont:{color:n.textfont.color,size:n.textfont.size,family:c({},n.textfont.family,{arrayOk:!1})},hoverinfo:c({},o.hoverinfo)},\"calc\",\"nested\");g.x.editType=g.y.editType=g.z.editType=\"calc+clearAxisTypes\"},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../constants/gl3d_dashes\":692,\"../../constants/gl3d_markers\":693,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1139:[function(t,e,r){\"use strict\";var n=t(\"../scatter/arrays_to_calcdata\"),i=t(\"../scatter/colorscale_calc\");e.exports=function(t,e){var r=[{x:!1,y:!1,trace:e,t:{}}];return n(r,e),i(t,e),r}},{\"../scatter/arrays_to_calcdata\":1111,\"../scatter/colorscale_calc\":1115}],1140:[function(t,e,r){\"use strict\";var n=t(\"../../registry\");function i(t,e,r,i){if(!e||!e.visible)return null;for(var a=n.getComponentMethod(\"errorbars\",\"makeComputeError\")(e),o=new Array(t.length),s=0;s<t.length;s++){var l=a(+t[s],s);if(\"log\"===i.type){var c=i.c2l(t[s]),u=t[s]-l[0],h=t[s]+l[1];if(o[s]=[(i.c2l(u,!0)-c)*r,(i.c2l(h,!0)-c)*r],u>0){var f=i.c2l(u);i._lowerLogErrorBound||(i._lowerLogErrorBound=f),i._lowerErrorBound=Math.min(i._lowerLogErrorBound,f)}}else o[s]=[-l[0]*r,l[1]*r]}return o}e.exports=function(t,e,r){var n=[i(t.x,t.error_x,e[0],r.xaxis),i(t.y,t.error_y,e[1],r.yaxis),i(t.z,t.error_z,e[2],r.zaxis)],a=function(t){for(var e=0;e<t.length;e++)if(t[e])return t[e].length;return 0}(n);if(0===a)return null;for(var o=new Array(a),s=0;s<a;s++){for(var l=[[0,0,0],[0,0,0]],c=0;c<3;c++)if(n[c])for(var u=0;u<2;u++)l[u][c]=n[c][s][u];o[s]=l}return o}},{\"../../registry\":847}],1141:[function(t,e,r){\"use strict\";var n=t(\"gl-line3d\"),i=t(\"gl-scatter3d\"),a=t(\"gl-error3d\"),o=t(\"gl-mesh3d\"),s=t(\"delaunay-triangulate\"),l=t(\"../../lib\"),c=t(\"../../lib/str2rgbarray\"),u=t(\"../../lib/gl_format_color\").formatColor,h=t(\"../scatter/make_bubble_size_func\"),f=t(\"../../constants/gl3d_dashes\"),p=t(\"../../constants/gl3d_markers\"),d=t(\"./calc_errors\");function g(t,e){this.scene=t,this.uid=e,this.linePlot=null,this.scatterPlot=null,this.errorBars=null,this.textMarkers=null,this.delaunayMesh=null,this.color=null,this.mode=\"\",this.dataPoints=[],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.textLabels=null,this.data=null}var v=g.prototype;function m(t){return null==t?0:t.indexOf(\"left\")>-1?-1:t.indexOf(\"right\")>-1?1:0}function y(t){return null==t?0:t.indexOf(\"top\")>-1?-1:t.indexOf(\"bottom\")>-1?1:0}function x(t,e){return e(4*t)}function b(t){return p[t]}function _(t,e,r,n,i){var a=null;if(l.isArrayOrTypedArray(t)){a=[];for(var o=0;o<e;o++)void 0===t[o]?a[o]=n:a[o]=r(t[o],i)}else a=r(t,l.identity);return a}function w(t,e){var r,n,i,a,o,s,f=[],p=t.fullSceneLayout,g=t.dataScale,v=p.xaxis,w=p.yaxis,k=p.zaxis,T=e.marker,A=e.line,M=e.x||[],S=e.y||[],E=e.z||[],C=M.length,L=e.xcalendar,P=e.ycalendar,O=e.zcalendar;for(o=0;o<C;o++)r=v.d2l(M[o],0,L)*g[0],n=w.d2l(S[o],0,P)*g[1],i=k.d2l(E[o],0,O)*g[2],f[o]=[r,n,i];if(Array.isArray(e.text))s=e.text;else if(void 0!==e.text)for(s=new Array(C),o=0;o<C;o++)s[o]=e.text;if(a={position:f,mode:e.mode,text:s},\"line\"in e&&(a.lineColor=u(A,1,C),a.lineWidth=A.width,a.lineDashes=A.dash),\"marker\"in e){var z=h(e);a.scatterColor=u(T,1,C),a.scatterSize=_(T.size,C,x,20,z),a.scatterMarker=_(T.symbol,C,b,\"\\u25cf\"),a.scatterLineWidth=T.line.width,a.scatterLineColor=u(T.line,1,C),a.scatterAngle=0}\"textposition\"in e&&(a.textOffset=function(t){var e=[0,0];if(Array.isArray(t))for(var r=0;r<t.length;r++)e[r]=[0,0],t[r]&&(e[r][0]=m(t[r]),e[r][1]=y(t[r]));else e[0]=m(t),e[1]=y(t);return e}(e.textposition),a.textColor=u(e.textfont,1,C),a.textSize=_(e.textfont.size,C,l.identity,12),a.textFont=e.textfont.family,a.textAngle=0);var I=[\"x\",\"y\",\"z\"];for(a.project=[!1,!1,!1],a.projectScale=[1,1,1],a.projectOpacity=[1,1,1],o=0;o<3;++o){var D=e.projection[I[o]];(a.project[o]=D.show)&&(a.projectOpacity[o]=D.opacity,a.projectScale[o]=D.scale)}a.errorBounds=d(e,g,p);var R=function(t){for(var e=[0,0,0],r=[[0,0,0],[0,0,0],[0,0,0]],n=[1,1,1],i=0;i<3;i++){var a=t[i];a&&!1!==a.copy_zstyle&&!1!==t[2].visible&&(a=t[2]),a&&a.visible&&(e[i]=a.width/2,r[i]=c(a.color),n[i]=a.thickness)}return{capSize:e,color:r,lineWidth:n}}([e.error_x,e.error_y,e.error_z]);return a.errorColor=R.color,a.errorLineWidth=R.lineWidth,a.errorCapSize=R.capSize,a.delaunayAxis=e.surfaceaxis,a.delaunayColor=c(e.surfacecolor),a}function k(t){if(Array.isArray(t)){var e=t[0];return Array.isArray(e)&&(t=e),\"rgb(\"+t.slice(0,3).map(function(t){return Math.round(255*t)})+\")\"}return null}v.handlePick=function(t){if(t.object&&(t.object===this.linePlot||t.object===this.delaunayMesh||t.object===this.textMarkers||t.object===this.scatterPlot)){var e=t.index=t.data.index;return t.object.highlight&&t.object.highlight(null),this.scatterPlot&&(t.object=this.scatterPlot,this.scatterPlot.highlight(t.data)),t.textLabel=\"\",this.textLabels&&(Array.isArray(this.textLabels)?(this.textLabels[e]||0===this.textLabels[e])&&(t.textLabel=this.textLabels[e]):t.textLabel=this.textLabels),t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]],!0}},v.update=function(t){var e,r,l,c,u=this.scene.glplot.gl,h=f.solid;this.data=t;var p=w(this.scene,t);\"mode\"in p&&(this.mode=p.mode),\"lineDashes\"in p&&p.lineDashes in f&&(h=f[p.lineDashes]),this.color=k(p.scatterColor)||k(p.lineColor),this.dataPoints=p.position,e={gl:this.scene.glplot.gl,position:p.position,color:p.lineColor,lineWidth:p.lineWidth||1,dashes:h[0],dashScale:h[1],opacity:t.opacity,connectGaps:t.connectgaps},-1!==this.mode.indexOf(\"lines\")?this.linePlot?this.linePlot.update(e):(this.linePlot=n(e),this.linePlot._trace=this,this.scene.glplot.add(this.linePlot)):this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose(),this.linePlot=null);var d=t.opacity;if(t.marker&&t.marker.opacity&&(d*=t.marker.opacity),r={gl:this.scene.glplot.gl,position:p.position,color:p.scatterColor,size:p.scatterSize,glyph:p.scatterMarker,opacity:d,orthographic:!0,lineWidth:p.scatterLineWidth,lineColor:p.scatterLineColor,project:p.project,projectScale:p.projectScale,projectOpacity:p.projectOpacity},-1!==this.mode.indexOf(\"markers\")?this.scatterPlot?this.scatterPlot.update(r):(this.scatterPlot=i(r),this.scatterPlot._trace=this,this.scatterPlot.highlightScale=1,this.scene.glplot.add(this.scatterPlot)):this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose(),this.scatterPlot=null),c={gl:this.scene.glplot.gl,position:p.position,glyph:p.text,color:p.textColor,size:p.textSize,angle:p.textAngle,alignment:p.textOffset,font:p.textFont,orthographic:!0,lineWidth:0,project:!1,opacity:t.opacity},this.textLabels=t.hovertext||t.text,-1!==this.mode.indexOf(\"text\")?this.textMarkers?this.textMarkers.update(c):(this.textMarkers=i(c),this.textMarkers._trace=this,this.textMarkers.highlightScale=1,this.scene.glplot.add(this.textMarkers)):this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose(),this.textMarkers=null),l={gl:this.scene.glplot.gl,position:p.position,color:p.errorColor,error:p.errorBounds,lineWidth:p.errorLineWidth,capSize:p.errorCapSize,opacity:t.opacity},this.errorBars?p.errorBounds?this.errorBars.update(l):(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose(),this.errorBars=null):p.errorBounds&&(this.errorBars=a(l),this.errorBars._trace=this,this.scene.glplot.add(this.errorBars)),p.delaunayAxis>=0){var g=function(t,e,r){var n,i=(r+1)%3,a=(r+2)%3,o=[],l=[];for(n=0;n<t.length;++n){var c=t[n];!isNaN(c[i])&&isFinite(c[i])&&!isNaN(c[a])&&isFinite(c[a])&&(o.push([c[i],c[a]]),l.push(n))}var u=s(o);for(n=0;n<u.length;++n)for(var h=u[n],f=0;f<h.length;++f)h[f]=l[h[f]];return{positions:t,cells:u,meshColor:e}}(p.position,p.delaunayColor,p.delaunayAxis);g.opacity=t.opacity,this.delaunayMesh?this.delaunayMesh.update(g):(g.gl=u,this.delaunayMesh=o(g),this.delaunayMesh._trace=this,this.scene.glplot.add(this.delaunayMesh))}else this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose(),this.delaunayMesh=null)},v.dispose=function(){this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose()),this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose()),this.errorBars&&(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose()),this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose()),this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose())},e.exports=function(t,e){var r=new g(t,e.uid);return r.update(e),r}},{\"../../constants/gl3d_dashes\":692,\"../../constants/gl3d_markers\":693,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../scatter/make_bubble_size_func\":1128,\"./calc_errors\":1140,\"delaunay-triangulate\":165,\"gl-error3d\":247,\"gl-line3d\":255,\"gl-mesh3d\":280,\"gl-scatter3d\":297}],1142:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,n){return i.coerce(t,e,c,r,n)}if(function(t,e,r,i){var a=0,o=r(\"x\"),s=r(\"y\"),l=r(\"z\");n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],i),o&&s&&l&&(a=Math.min(o.length,s.length,l.length),e._length=e._xlength=e._ylength=e._zlength=a);return a}(t,e,h,u)){h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),a.hasLines(e)&&(h(\"connectgaps\"),s(t,e,r,u,h)),a.hasMarkers(e)&&o(t,e,r,u,h,{noSelect:!0}),a.hasText(e)&&l(t,e,u,h,{noSelect:!0});var f=(e.line||{}).color,p=(e.marker||{}).color;h(\"surfaceaxis\")>=0&&h(\"surfacecolor\",f||p);for(var d=[\"x\",\"y\",\"z\"],g=0;g<3;++g){var v=\"projection.\"+d[g];h(v+\".show\")&&(h(v+\".opacity\"),h(v+\".scale\"))}var m=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");m(t,e,f||p||r,{axis:\"z\"}),m(t,e,f||p||r,{axis:\"y\",inherit:\"z\"}),m(t,e,f||p||r,{axis:\"x\",inherit:\"z\"})}else e.visible=!1}},{\"../../lib\":719,\"../../registry\":847,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1138}],1143:[function(t,e,r){\"use strict\";e.exports={plot:t(\"./convert\"),attributes:t(\"./attributes\"),markerSymbols:t(\"../../constants/gl3d_markers\"),supplyDefaults:t(\"./defaults\"),colorbar:[{container:\"marker\",min:\"cmin\",max:\"cmax\"},{container:\"line\",min:\"cmin\",max:\"cmax\"}],calc:t(\"./calc\"),moduleType:\"trace\",name:\"scatter3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"symbols\",\"showLegend\"],meta:{}}},{\"../../constants/gl3d_markers\":693,\"../../plots/gl3d\":807,\"./attributes\":1138,\"./calc\":1139,\"./convert\":1141,\"./defaults\":1142}],1144:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=n.marker,c=n.line,u=l.line;e.exports={carpet:{valType:\"string\",editType:\"calc\"},a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},mode:s({},n.mode,{dflt:\"markers\"}),text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),line:{color:c.color,width:c.width,dash:c.dash,shape:s({},c.shape,{values:[\"linear\",\"spline\"]}),smoothing:c.smoothing,editType:\"calc\"},connectgaps:n.connectgaps,fill:s({},n.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:n.fillcolor,marker:s({symbol:l.symbol,opacity:l.opacity,maxdisplayed:l.maxdisplayed,size:l.size,sizeref:l.sizeref,sizemin:l.sizemin,sizemode:l.sizemode,line:s({width:u.width,editType:\"calc\"},o(\"marker.line\")),gradient:l.gradient,editType:\"calc\"},o(\"marker\")),textfont:n.textfont,textposition:n.textposition,selected:n.selected,unselected:n.unselected,hoverinfo:s({},i.hoverinfo,{flags:[\"a\",\"b\",\"text\",\"name\"]}),hoveron:n.hoveron,hovertemplate:a()}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1145:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=t(\"../carpet/lookup_carpetid\");e.exports=function(t,e){var r=e._carpetTrace=l(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){var c;e.xaxis=r.xaxis,e.yaxis=r.yaxis;var u,h,f=e._length,p=new Array(f),d=!1;for(c=0;c<f;c++)if(u=e.a[c],h=e.b[c],n(u)&&n(h)){var g=r.ab2xy(+u,+h,!0),v=r.isVisible(+u,+h);v||(d=!0),p[c]={x:g[0],y:g[1],a:u,b:h,vis:v}}else p[c]={x:!1,y:!1};return e._needsCull=d,p[0].carpet=r,p[0].trace=e,s(e,f),i(t,e),a(p,e),o(p,e),p}}},{\"../carpet/lookup_carpetid\":915,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc\":1113,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1146:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}p(\"carpet\"),e.xaxis=\"x\",e.yaxis=\"y\";var d=p(\"a\"),g=p(\"b\"),v=Math.min(d.length,g.length);if(v){e._length=v,p(\"text\"),p(\"hovertext\"),p(\"mode\",v<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,f,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,f,p,{gradient:!0}),a.hasText(e)&&c(t,e,f,p);var m=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"marker.maxdisplayed\"),m.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||m.push(\"fills\"),\"fills\"!==p(\"hoveron\",m.join(\"+\")||\"points\")&&p(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/line_shape_defaults\":1126,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1144}],1147:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=n[i];return t.a=a.a,t.b=a.b,t.y=a.y,t}},{}],1148:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../lib\").fillText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,h=c-u;return s.x0=Math.max(Math.min(s.x0,h),u),s.x1=Math.max(Math.min(s.x1,h),u),o}var f=s.cd[s.index];s.a=f.a,s.b=f.b,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.trace,d=p._carpet,g=d.ab2ij([f.a,f.b]),v=Math.floor(g[0]),m=g[0]-v,y=Math.floor(g[1]),x=g[1]-y,b=d.evalxy([],v,y,m,x);s.yLabel=b[1].toFixed(3),delete s.text;var _=[];if(!p.hovertemplate){var w=(f.hi||p.hoverinfo).split(\"+\");-1!==w.indexOf(\"all\")&&(w=[\"a\",\"b\",\"text\"]),-1!==w.indexOf(\"a\")&&k(d.aaxis,f.a),-1!==w.indexOf(\"b\")&&k(d.baxis,f.b),_.push(\"y: \"+s.yLabel),-1!==w.indexOf(\"text\")&&i(f,p,_),s.extraText=_.join(\"<br>\")}return o}function k(t,e){var r;r=t.labelprefix&&t.labelprefix.length>0?t.labelprefix.replace(/ = $/,\"\"):t._hovertitle,_.push(r+\": \"+e.toFixed(3)+t.labelsuffix)}}},{\"../../lib\":719,\"../scatter/hover\":1122}],1149:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scattercarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"svg\",\"carpet\",\"symbols\",\"showLegend\",\"carpetDependent\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../scatter/marker_colorbar\":1129,\"../scatter/select\":1132,\"../scatter/style\":1134,\"./attributes\":1144,\"./calc\":1145,\"./defaults\":1146,\"./event_data\":1147,\"./hover\":1148,\"./plot\":1150}],1150:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../components/drawing\");e.exports=function(t,e,r,o){var s,l,c,u=r[0][0].carpet,h={xaxis:i.getFromId(t,u.xaxis||\"x\"),yaxis:i.getFromId(t,u.yaxis||\"y\"),plot:e.plot};for(n(t,h,r,o),s=0;s<r.length;s++)l=r[s][0].trace,c=o.selectAll(\"g.trace\"+l.uid+\" .js-line\"),a.setClipUrl(c,r[s][0].carpet._clipPathId,t)}},{\"../../components/drawing\":614,\"../../plots/cartesian/axes\":767,\"../scatter/plot\":1131}],1151:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/drawing/attributes\").dash,l=t(\"../../lib/extend\").extendFlat,c=t(\"../../plot_api/edit_types\").overrideAll,u=i.marker,h=i.line,f=u.line;e.exports=c({lon:{valType:\"data_array\"},lat:{valType:\"data_array\"},locations:{valType:\"data_array\"},locationmode:{valType:\"enumerated\",values:[\"ISO-3\",\"USA-states\",\"country names\"],dflt:\"ISO-3\"},mode:l({},i.mode,{dflt:\"markers\"}),text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),textfont:i.textfont,textposition:i.textposition,line:{color:h.color,width:h.width,dash:s},connectgaps:i.connectgaps,marker:l({symbol:u.symbol,opacity:u.opacity,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,colorbar:u.colorbar,line:l({width:f.width},o(\"marker.line\")),gradient:u.gradient},o(\"marker\")),fill:{valType:\"enumerated\",values:[\"none\",\"toself\"],dflt:\"none\"},fillcolor:i.fillcolor,selected:i.selected,unselected:i.unselected,hoverinfo:l({},a.hoverinfo,{flags:[\"lon\",\"lat\",\"location\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":600,\"../../components/drawing/attributes\":613,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1152:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../scatter/colorscale_calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\"),l=t(\"../../lib\")._;e.exports=function(t,e){for(var r=Array.isArray(e.locations),c=r?e.locations.length:e._length,u=new Array(c),h=0;h<c;h++){var f=u[h]={};if(r){var p=e.locations[h];f.loc=\"string\"==typeof p?p:null}else{var d=e.lon[h],g=e.lat[h];n(d)&&n(g)?f.lonlat=[+d,+g]:f.lonlat=[i,i]}}return o(u,e),a(t,e),s(u,e),c&&(u[0].t={labels:{lat:l(t,\"lat:\")+\" \",lon:l(t,\"lon:\")+\" \"}}),u}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1153:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,i){return n.coerce(t,e,c,r,i)}!function(t,e,r){var n,i,a=0,o=r(\"locations\");if(o)return r(\"locationmode\"),a=o.length;return n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length),e._length=a,a}(0,e,h)?e.visible=!1:(h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),i.hasLines(e)&&(o(t,e,r,u,h),h(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,u,h,{gradient:!0}),i.hasText(e)&&s(t,e,u,h),h(\"fill\"),\"none\"!==e.fill&&l(t,e,r,h),n.coerceSelectionMarkerOpacity(e,h))}},{\"../../lib\":719,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1151}],1154:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.location=e.loc?e.loc:null,t}},{}],1155:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../scatter/get_trace_color\"),s=t(\"../../lib\").fillText,l=t(\"./attributes\");e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,h=t.xa,f=t.ya,p=t.subplot,d=p.projection.isLonLatOverEdges,g=p.project;if(n.getClosest(c,function(t){var n=t.lonlat;if(n[0]===a)return 1/0;if(d(n))return 1/0;var i=g(n),o=g([e,r]),s=Math.abs(i[0]-o[0]),l=Math.abs(i[1]-o[1]),c=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(s*s+l*l)-c,1-3/c)},t),!1!==t.index){var v=c[t.index],m=v.lonlat,y=[h.c2p(m),f.c2p(m)],x=v.mrc||1;t.x0=y[0]-x,t.x1=y[0]+x,t.y0=y[1]-x,t.y1=y[1]+x,t.loc=v.loc,t.lon=m[0],t.lat=m[1];var b=p.mockAxis;return t.lonLabel=i.tickText(b,b.c2l(t.lon),\"hover\").text,t.latLabel=i.tickText(b,b.c2l(t.lat),\"hover\").text,t.color=o(u,v),t.extraText=function(t,e,r,n){if(t.hovertemplate)return;var i=e.hi||t.hoverinfo,a=\"all\"===i?l.hoverinfo.flags:i.split(\"+\"),o=-1!==a.indexOf(\"location\")&&Array.isArray(t.locations),c=-1!==a.indexOf(\"lon\"),u=-1!==a.indexOf(\"lat\"),h=-1!==a.indexOf(\"text\"),f=[];function p(t){return t+\"\\xb0\"}o?f.push(e.loc):c&&u?f.push(\"(\"+p(r.lonLabel)+\", \"+p(r.latLabel)+\")\"):c?f.push(n.lon+p(r.lonLabel)):u&&f.push(n.lat+p(r.latLabel));h&&s(e,t,f);return f.join(\"<br>\")}(u,v,t,c[0].t.labels),t.hovertemplate=u.hovertemplate,[t]}}},{\"../../components/fx\":632,\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scatter/get_trace_color\":1121,\"./attributes\":1151}],1156:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"scattergeo\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/geo\":797,\"../scatter/marker_colorbar\":1129,\"../scatter/style\":1134,\"./attributes\":1151,\"./calc\":1152,\"./defaults\":1153,\"./event_data\":1154,\"./hover\":1155,\"./plot\":1157,\"./select\":1158,\"./style\":1159}],1157:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../lib/topojson_utils\").getTopojsonFeatures,s=t(\"../../lib/geo_location_utils\").locationToFeature,l=t(\"../../lib/geojson_utils\"),c=t(\"../scatter/subtypes\"),u=t(\"./style\");function h(t,e){var r=t[0].trace;if(Array.isArray(r.locations))for(var n=o(r,e),i=r.locationmode,l=0;l<t.length;l++){var c=t[l],u=s(i,c.loc,n);c.lonlat=u?u.properties.ct:[a,a]}}e.exports=function(t,e,r){for(var o=0;o<r.length;o++)h(r[o],e.topojson);function s(t,e){t.lonlat[0]===a&&n.select(e).remove()}var f=e.layers.frontplot.select(\".scatterlayer\"),p=i.makeTraceGroups(f,r,\"trace scattergeo\");p.selectAll(\"*\").remove(),p.each(function(e){var r=n.select(this),a=e[0].trace;if(c.hasLines(a)||\"none\"!==a.fill){var o=l.calcTraceToLineCoords(e),h=\"none\"!==a.fill?l.makePolygon(o):l.makeLine(o);r.selectAll(\"path.js-line\").data([{geojson:h,trace:a}]).enter().append(\"path\").classed(\"js-line\",!0).style(\"stroke-miterlimit\",2)}c.hasMarkers(a)&&r.selectAll(\"path.point\").data(i.identity).enter().append(\"path\").classed(\"point\",!0).each(function(t){s(t,this)}),c.hasText(a)&&r.selectAll(\"g\").data(i.identity).enter().append(\"g\").append(\"text\").each(function(t){s(t,this)}),u(t,e)})}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/geo_location_utils\":713,\"../../lib/geojson_utils\":714,\"../../lib/topojson_utils\":746,\"../scatter/subtypes\":1135,\"./style\":1159,d3:163}],1158:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,a,o,s,l,c=t.cd,u=t.xaxis,h=t.yaxis,f=[],p=c[0].trace;if(!n.hasMarkers(p)&&!n.hasText(p))return[];if(!1===e)for(l=0;l<c.length;l++)c[l].selected=0;else for(l=0;l<c.length;l++)(a=(r=c[l]).lonlat)[0]!==i&&(o=u.c2p(a),s=h.c2p(a),e.contains([o,s],null,l,t)?(f.push({pointNumber:l,lon:a[0],lat:a[1]}),r.selected=1):r.selected=0);return f}},{\"../../constants/numerical\":695,\"../scatter/subtypes\":1135}],1159:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../scatter/style\"),s=o.stylePoints,l=o.styleText;e.exports=function(t,e){e&&function(t,e){var r=e[0].trace,o=e[0].node3;o.style(\"opacity\",e[0].trace.opacity),s(o,r,t),l(o,r,t),o.selectAll(\"path.js-line\").style(\"fill\",\"none\").each(function(t){var e=n.select(this),r=t.trace,o=r.line||{};e.call(a.stroke,o.color).call(i.dashLine,o.dash||\"\",o.width||0),\"none\"!==r.fill&&e.call(a.fill,r.fillcolor)})}(t,e)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../scatter/style\":1134,d3:163}],1160:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=t(\"./constants\").DASHES,c=i.line,u=i.marker,h=u.line,f=e.exports=s({x:i.x,x0:i.x0,dx:i.dx,y:i.y,y0:i.y0,dy:i.dy,text:i.text,hovertext:i.hovertext,textposition:i.textposition,textfont:i.textfont,mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"]},line:{color:c.color,width:c.width,shape:{valType:\"enumerated\",values:[\"linear\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},dash:{valType:\"enumerated\",values:Object.keys(l),dflt:\"solid\"}},marker:o({},a(\"marker\"),{symbol:u.symbol,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:o({},a(\"marker.line\"),{width:h.width})}),connectgaps:i.connectgaps,fill:o({},i.fill,{dflt:\"none\"}),fillcolor:i.fillcolor,selected:{marker:i.selected.marker,textfont:i.selected.textfont},unselected:{marker:i.unselected.marker,textfont:i.unselected.textfont},opacity:n.opacity},\"calc\",\"nested\");f.x.editType=f.y.editType=f.x0.editType=f.y0.editType=\"calc+clearAxisTypes\",f.hovertemplate=i.hovertemplate},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../scatter/attributes\":1112,\"./constants\":1162}],1161:[function(t,e,r){\"use strict\";var n=t(\"point-cluster\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../plots/cartesian/autorange\").findExtremes,s=t(\"../scatter/calc\"),l=s.calcMarkerSize,c=s.calcAxisExpansion,u=s.setFirstScatter,h=t(\"../scatter/colorscale_calc\"),f=t(\"./convert\"),p=t(\"./scene_update\"),d=t(\"../../constants/numerical\").BADNUM,g=t(\"./constants\").TOO_MANY_POINTS;function v(t,e,r){var n=t._extremes[e._id],i=o(e,r._bnds,{padded:!0});n.min=n.min.concat(i.min),n.max=n.max.concat(i.max)}e.exports=function(t,e){var r,o,s,m=t._fullLayout,y=a.getFromId(t,e.xaxis),x=a.getFromId(t,e.yaxis),b=m._plots[e.xaxis+e.yaxis],_=e._length,w=_>=g,k=2*_,T={},A=y.makeCalcdata(e,\"x\"),M=x.makeCalcdata(e,\"y\"),S=new Array(k);for(r=0;r<_;r++)o=A[r],s=M[r],S[2*r]=o===d?NaN:o,S[2*r+1]=s===d?NaN:s;if(\"log\"===y.type)for(r=0;r<k;r+=2)S[r]=y.c2l(S[r]);if(\"log\"===x.type)for(r=1;r<k;r+=2)S[r]=x.c2l(S[r]);if(w&&\"log\"!==y.type&&\"log\"!==x.type)T.tree=n(S);else{var E=T.ids=new Array(_);for(r=0;r<_;r++)E[r]=r}h(t,e);var C,L=function(t,e,r,n,a,o){var s=f.style(t,r);s.marker&&(s.marker.positions=n);s.line&&n.length>1&&i.extendFlat(s.line,f.linePositions(t,r,n));if(s.errorX||s.errorY){var l=f.errorBarPositions(t,r,n,a,o);s.errorX&&i.extendFlat(s.errorX,l.x),s.errorY&&i.extendFlat(s.errorY,l.y)}s.text&&(i.extendFlat(s.text,{positions:n},f.textPosition(t,r,s.text,s.marker)),i.extendFlat(s.textSel,{positions:n},f.textPosition(t,r,s.text,s.markerSel)),i.extendFlat(s.textUnsel,{positions:n},f.textPosition(t,r,s.text,s.markerUnsel)));return s}(t,0,e,S,A,M),P=p(t,b);return u(m,e),w?L.marker&&(C=2*(L.marker.sizeAvg||Math.max(L.marker.size,3))):C=l(e,_),c(t,e,y,x,A,M,C),L.errorX&&v(e,y,L.errorX),L.errorY&&v(e,x,L.errorY),L.fill&&!P.fill2d&&(P.fill2d=!0),L.marker&&!P.scatter2d&&(P.scatter2d=!0),L.line&&!P.line2d&&(P.line2d=!0),!L.errorX&&!L.errorY||P.error2d||(P.error2d=!0),L.text&&!P.glText&&(P.glText=!0),L.marker&&(L.marker.snap=T.tree||g),P.lineOptions.push(L.line),P.errorXOptions.push(L.errorX),P.errorYOptions.push(L.errorY),P.fillOptions.push(L.fill),P.markerOptions.push(L.marker),P.markerSelectedOptions.push(L.markerSel),P.markerUnselectedOptions.push(L.markerUnsel),P.textOptions.push(L.text),P.textSelectedOptions.push(L.textSel),P.textUnselectedOptions.push(L.textUnsel),P.selectBatch.push([]),P.unselectBatch.push([]),T._scene=P,T.index=P.count,T.x=A,T.y=M,T.positions=S,P.count++,[{x:!1,y:!1,t:T,trace:e}]}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/autorange\":766,\"../../plots/cartesian/axis_ids\":770,\"../scatter/calc\":1113,\"../scatter/colorscale_calc\":1115,\"./constants\":1162,\"./convert\":1163,\"./scene_update\":1169,\"point-cluster\":469}],1162:[function(t,e,r){\"use strict\";e.exports={TOO_MANY_POINTS:1e5,SYMBOL_SDF_SIZE:200,SYMBOL_SIZE:20,SYMBOL_STROKE:1,DOT_RE:/-dot/,OPEN_RE:/-open/,DASHES:{solid:[1],dot:[1,1],dash:[4,1],longdash:[8,1],dashdot:[4,1,1,1],longdashdot:[8,1,1,1]}}},{}],1163:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"svg-path-sdf\"),a=t(\"color-normalize\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../components/drawing\"),c=t(\"../../plots/cartesian/axis_ids\"),u=t(\"../../lib/gl_format_color\").formatColor,h=t(\"../scatter/subtypes\"),f=t(\"../scatter/make_bubble_size_func\"),p=t(\"./constants\"),d=t(\"../../constants/interactions\").DESELECTDIM,g={start:1,left:1,end:-1,right:-1,middle:0,center:0,bottom:1,top:-1};function v(t){var e,r=t._length,i=t.textfont,a=t.textposition,o=Array.isArray(a)?a:[a],s=i.color,l=i.size,c=i.family,u={};for(u.text=t.text,u.opacity=t.opacity,u.font={},u.align=[],u.baseline=[],e=0;e<o.length;e++){var h=o[e].split(/\\s+/);switch(h[1]){case\"left\":u.align.push(\"right\");break;case\"right\":u.align.push(\"left\");break;default:u.align.push(h[1])}switch(h[0]){case\"top\":u.baseline.push(\"bottom\");break;case\"bottom\":u.baseline.push(\"top\");break;default:u.baseline.push(h[0])}}if(Array.isArray(s))for(u.color=new Array(r),e=0;e<r;e++)u.color[e]=s[e];else u.color=s;if(Array.isArray(l)||Array.isArray(c))for(u.font=new Array(r),e=0;e<r;e++){var f=u.font[e]={};f.size=Array.isArray(l)?n(l[e])?l[e]:0:l,f.family=Array.isArray(c)?c[e]:c}else u.font={size:l,family:c};return u}function m(t){var e,r,n=t._length,i=t.marker,o={},l=Array.isArray(i.symbol),c=s.isArrayOrTypedArray(i.color),h=s.isArrayOrTypedArray(i.line.color),d=s.isArrayOrTypedArray(i.opacity),g=s.isArrayOrTypedArray(i.size),v=s.isArrayOrTypedArray(i.line.width);if(l||(r=p.OPEN_RE.test(i.symbol)),l||c||h||d){o.colors=new Array(n),o.borderColors=new Array(n);var m=u(i,i.opacity,n),y=u(i.line,i.opacity,n);if(!Array.isArray(y[0])){var x=y;for(y=Array(n),e=0;e<n;e++)y[e]=x}if(!Array.isArray(m[0])){var b=m;for(m=Array(n),e=0;e<n;e++)m[e]=b}for(o.colors=m,o.borderColors=y,e=0;e<n;e++){if(l){var _=i.symbol[e];r=p.OPEN_RE.test(_)}r&&(y[e]=m[e].slice(),m[e]=m[e].slice(),m[e][3]=0)}o.opacity=t.opacity}else r?(o.color=a(i.color,\"uint8\"),o.color[3]=0,o.borderColor=a(i.color,\"uint8\")):(o.color=a(i.color,\"uint8\"),o.borderColor=a(i.line.color,\"uint8\")),o.opacity=t.opacity*i.opacity;if(l)for(o.markers=new Array(n),e=0;e<n;e++)o.markers[e]=M(i.symbol[e]);else o.marker=M(i.symbol);var w,k=f(t);if(g||v){var T,A=o.sizes=new Array(n),S=o.borderSizes=new Array(n),E=0;if(g){for(e=0;e<n;e++)A[e]=k(i.size[e]),E+=A[e];T=E/n}else for(w=k(i.size),e=0;e<n;e++)A[e]=w;if(v)for(e=0;e<n;e++)S[e]=i.line.width[e]/2;else for(w=i.line.width/2,e=0;e<n;e++)S[e]=w;o.sizeAvg=T}else o.size=k(i&&i.size||10),o.borderSizes=k(i.line.width);return o}function y(t,e){var r=t.marker,n={};return e?(e.marker&&e.marker.symbol?n=m(s.extendFlat({},r,e.marker)):e.marker&&(e.marker.size&&(n.size=e.marker.size/2),e.marker.color&&(n.colors=e.marker.color),void 0!==e.marker.opacity&&(n.opacity=e.marker.opacity)),n):n}function x(t,e){var r={};if(!e)return r;if(e.textfont){var n={opacity:1,text:t.text,textposition:t.textposition,textfont:s.extendFlat({},t.textfont)};e.textfont&&s.extendFlat(n.textfont,e.textfont),r=v(n)}return r}function b(t,e){var r={capSize:2*e.width,lineWidth:e.thickness,color:e.color};return e.copy_ystyle&&(r=t.error_y),r}var _=p.SYMBOL_SDF_SIZE,w=p.SYMBOL_SIZE,k=p.SYMBOL_STROKE,T={},A=l.symbolFuncs[0](.05*w);function M(t){if(\"circle\"===t)return null;var e,r,n=l.symbolNumber(t),a=l.symbolFuncs[n%100],o=!!l.symbolNoDot[n%100],s=!!l.symbolNoFill[n%100],c=p.DOT_RE.test(t);return T[t]?T[t]:(e=c&&!o?a(1.1*w)+A:a(w),r=i(e,{w:_,h:_,viewBox:[-w,-w,w,w],stroke:s?k:-k}),T[t]=r,r||null)}e.exports={style:function(t,e){var r,n={marker:void 0,markerSel:void 0,markerUnsel:void 0,line:void 0,fill:void 0,errorX:void 0,errorY:void 0,text:void 0,textSel:void 0,textUnsel:void 0};if(!0!==e.visible)return n;if(h.hasText(e)&&(n.text=v(e),n.textSel=x(e,e.selected),n.textUnsel=x(e,e.unselected)),h.hasMarkers(e)&&(n.marker=m(e),n.markerSel=y(e,e.selected),n.markerUnsel=y(e,e.unselected),!e.unselected&&Array.isArray(e.marker.opacity))){var i=e.marker.opacity;for(n.markerUnsel.opacity=new Array(i.length),r=0;r<i.length;r++)n.markerUnsel.opacity[r]=d*i[r]}if(h.hasLines(e)){n.line={overlay:!0,thickness:e.line.width,color:e.line.color,opacity:e.opacity};var a=(p.DASHES[e.line.dash]||[1]).slice();for(r=0;r<a.length;++r)a[r]*=e.line.width;n.line.dashes=a}return e.error_x&&e.error_x.visible&&(n.errorX=b(e,e.error_x)),e.error_y&&e.error_y.visible&&(n.errorY=b(e,e.error_y)),e.fill&&\"none\"!==e.fill&&(n.fill={closed:!0,fill:e.fillcolor,thickness:0}),n},markerStyle:m,markerSelection:y,linePositions:function(t,e,r){var n,i,a=r.length,o=a/2;if(h.hasLines(e)&&o)if(\"hv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i+2],r[2*i+1]));n.push(r[a-2],r[a-1])}else if(\"hvh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var s=(r[2*i]+r[2*i+2])/2;n.push(r[2*i],r[2*i+1],s,r[2*i+1],s,r[2*i+3])}n.push(r[a-2],r[a-1])}else if(\"vhv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var l=(r[2*i+1]+r[2*i+3])/2;n.push(r[2*i],r[2*i+1],r[2*i],l,r[2*i+2],l)}n.push(r[a-2],r[a-1])}else if(\"vh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+3]));n.push(r[a-2],r[a-1])}else n=r;var c=!1;for(i=0;i<n.length;i++)if(isNaN(n[i])){c=!0;break}var u=c||n.length>p.TOO_MANY_POINTS?\"rect\":h.hasMarkers(e)?\"rect\":\"round\";if(c&&e.connectgaps){var f=n[0],d=n[1];for(i=0;i<n.length;i+=2)isNaN(n[i])||isNaN(n[i+1])?(n[i]=f,n[i+1]=d):(f=n[i],d=n[i+1])}return{join:u,positions:n}},errorBarPositions:function(t,e,r,i,a){var s=o.getComponentMethod(\"errorbars\",\"makeComputeError\"),l=c.getFromId(t,e.xaxis),u=c.getFromId(t,e.yaxis),h=r.length/2,f={};function p(t,i){var a=i._id.charAt(0),o=e[\"error_\"+a];if(o&&o.visible&&(\"linear\"===i.type||\"log\"===i.type)){for(var l=s(o),c={x:0,y:1}[a],u={x:[0,1,2,3],y:[2,3,0,1]}[a],p=new Float64Array(4*h),d=1/0,g=-1/0,v=0,m=0;v<h;v++,m+=4){var y=t[v];if(n(y)){var x=r[2*v+c],b=l(y,v),_=b[0],w=b[1];if(n(_)&&n(w)){var k=y-_,T=y+w;p[m+u[0]]=x-i.c2l(k),p[m+u[1]]=i.c2l(T)-x,p[m+u[2]]=0,p[m+u[3]]=0,d=Math.min(d,y-_),g=Math.max(g,y+w)}}}f[a]={positions:r,errors:p,_bnds:[d,g]}}}return p(i,l),p(a,u),f},textPosition:function(t,e,r,n){var i,a=e._length,o={};if(h.hasMarkers(e)){var s=r.font,l=r.align,c=r.baseline;for(o.offset=new Array(a),i=0;i<a;i++){var u=n.sizes?n.sizes[i]:n.size,f=Array.isArray(s)?s[i].size:s.size,p=Array.isArray(l)?l.length>1?l[i]:l[0]:l,d=Array.isArray(c)?c.length>1?c[i]:c[0]:c,v=g[p],m=g[d],y=u?u/.8+1:0,x=-m*y-.5*m;o.offset[i]=[v*y/f,x/f]}}return o}}},{\"../../components/drawing\":614,\"../../constants/interactions\":694,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../scatter/make_bubble_size_func\":1128,\"../scatter/subtypes\":1135,\"./constants\":1162,\"color-normalize\":120,\"fast-isnumeric\":225,\"svg-path-sdf\":535}],1164:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"../scatter/constants\"),s=t(\"../scatter/subtypes\"),l=t(\"../scatter/xy_defaults\"),c=t(\"../scatter/marker_defaults\"),u=t(\"../scatter/line_defaults\"),h=t(\"../scatter/fillcolor_defaults\"),f=t(\"../scatter/text_defaults\");e.exports=function(t,e,r,p){function d(r,i){return n.coerce(t,e,a,r,i)}var g=!!t.marker&&/-open/.test(t.marker.symbol),v=s.isBubble(t),m=l(t,e,p,d);if(m){var y=m<o.PTS_LINESONLY?\"lines+markers\":\"lines\";d(\"text\"),d(\"hovertext\"),d(\"hovertemplate\"),d(\"mode\",y),s.hasLines(e)&&(d(\"connectgaps\"),u(t,e,r,p,d),d(\"line.shape\")),s.hasMarkers(e)&&(c(t,e,r,p,d),d(\"marker.line.width\",g||v?1:0)),s.hasText(e)&&f(t,e,p,d);var x=(e.line||{}).color,b=(e.marker||{}).color;d(\"fill\"),\"none\"!==e.fill&&h(t,e,r,d);var _=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");_(t,e,x||b||r,{axis:\"y\"}),_(t,e,x||b||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}},{\"../../lib\":719,\"../../registry\":847,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"../scatter/xy_defaults\":1137,\"./attributes\":1160}],1165:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../constants/interactions\").DESELECTDIM;e.exports={styleTextSelection:function(t){var e,r,o=t[0],s=o.trace,l=o.t,c=l._scene,u=l.index,h=c.selectBatch[u],f=c.unselectBatch[u],p=c.textOptions[u],d=c.textSelectedOptions[u]||{},g=c.textUnselectedOptions[u]||{},v=n.extendFlat({},p);if(h.length||f.length){var m=d.color,y=g.color,x=p.color,b=Array.isArray(x);for(v.color=new Array(s._length),e=0;e<h.length;e++)r=h[e],v.color[r]=m||(b?x[r]:x);for(e=0;e<f.length;e++){r=f[e];var _=b?x[r]:x;v.color[r]=y||(m?_:i.addOpacity(_,a))}}c.glText[u].update(v)}}},{\"../../components/color\":593,\"../../constants/interactions\":694,\"../../lib\":719}],1166:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\");function o(t,e,r,o){var s=t.xa,l=t.ya,c=t.distance,u=t.dxy,h=t.index,f={pointNumber:h,x:e[h],y:r[h]};f.tx=Array.isArray(o.text)?o.text[h]:o.text,f.htx=Array.isArray(o.hovertext)?o.hovertext[h]:o.hovertext,f.data=Array.isArray(o.customdata)?o.customdata[h]:o.customdata,f.tp=Array.isArray(o.textposition)?o.textposition[h]:o.textposition;var p=o.textfont;p&&(f.ts=Array.isArray(p.size)?p.size[h]:p.size,f.tc=Array.isArray(p.color)?p.color[h]:p.color,f.tf=Array.isArray(p.family)?p.family[h]:p.family);var d=o.marker;d&&(f.ms=i.isArrayOrTypedArray(d.size)?d.size[h]:d.size,f.mo=i.isArrayOrTypedArray(d.opacity)?d.opacity[h]:d.opacity,f.mx=Array.isArray(d.symbol)?d.symbol[h]:d.symbol,f.mc=i.isArrayOrTypedArray(d.color)?d.color[h]:d.color);var g=d&&d.line;g&&(f.mlc=Array.isArray(g.color)?g.color[h]:g.color,f.mlw=i.isArrayOrTypedArray(g.width)?g.width[h]:g.width);var v=d&&d.gradient;v&&\"none\"!==v.type&&(f.mgt=Array.isArray(v.type)?v.type[h]:v.type,f.mgc=Array.isArray(v.color)?v.color[h]:v.color);var m=s.c2p(f.x,!0),y=l.c2p(f.y,!0),x=f.mrc||1,b=o.hoverlabel;b&&(f.hbg=Array.isArray(b.bgcolor)?b.bgcolor[h]:b.bgcolor,f.hbc=Array.isArray(b.bordercolor)?b.bordercolor[h]:b.bordercolor,f.hts=Array.isArray(b.font.size)?b.font.size[h]:b.font.size,f.htc=Array.isArray(b.font.color)?b.font.color[h]:b.font.color,f.htf=Array.isArray(b.font.family)?b.font.family[h]:b.font.family,f.hnl=Array.isArray(b.namelength)?b.namelength[h]:b.namelength);var _=o.hoverinfo;_&&(f.hi=Array.isArray(_)?_[h]:_);var w=o.hovertemplate;w&&(f.ht=Array.isArray(w)?w[h]:w);var k={};return k[t.index]=f,i.extendFlat(t,{color:a(o,f),x0:m-x,x1:m+x,xLabelVal:f.x,y0:y-x,y1:y+x,yLabelVal:f.y,cd:k,distance:c,spikeDistance:u,hovertemplate:f.ht}),f.htx?t.text=f.htx:f.tx?t.text=f.tx:o.text&&(t.text=o.text),i.fillText(f,o,t),n.getComponentMethod(\"errorbars\",\"hoverInfo\")(f,o,t),t}e.exports={hoverPoints:function(t,e,r,n){var i,a,s,l,c,u,h,f,p,d=t.cd,g=d[0].t,v=d[0].trace,m=t.xa,y=t.ya,x=g.x,b=g.y,_=m.c2p(e),w=y.c2p(r),k=t.distance;if(g.tree){var T=m.p2c(_-k),A=m.p2c(_+k),M=y.p2c(w-k),S=y.p2c(w+k);i=\"x\"===n?g.tree.range(Math.min(T,A),Math.min(y._rl[0],y._rl[1]),Math.max(T,A),Math.max(y._rl[0],y._rl[1])):g.tree.range(Math.min(T,A),Math.min(M,S),Math.max(T,A),Math.max(M,S))}else{if(!g.ids)return[t];i=g.ids}var E=k;if(\"x\"===n)for(c=0;c<i.length;c++)s=x[i[c]],(u=Math.abs(m.c2p(s)-_))<E&&(E=u,h=y.c2p(b[i[c]])-w,p=Math.sqrt(u*u+h*h),a=i[c]);else for(c=i.length-1;c>-1;c--)s=x[i[c]],l=b[i[c]],u=m.c2p(s)-_,h=y.c2p(l)-w,(f=Math.sqrt(u*u+h*h))<E&&(E=p=f,a=i[c]);return t.index=a,t.distance=E,t.dxy=p,void 0===a?[t]:(o(t,x,b,v),[t])},calcHover:o}},{\"../../lib\":719,\"../../registry\":847,\"../scatter/get_trace_color\":1121}],1167:[function(t,e,r){\"use strict\";var n=t(\"./hover\");e.exports={moduleType:\"trace\",name:\"scattergl\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../scatter/cross_trace_defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:n.hoverPoints,selectPoints:t(\"./select\"),meta:{}}},{\"../../plots/cartesian\":778,\"../scatter/cross_trace_defaults\":1118,\"../scatter/marker_colorbar\":1129,\"./attributes\":1160,\"./calc\":1161,\"./defaults\":1164,\"./hover\":1166,\"./plot\":1168,\"./select\":1170}],1168:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"regl-line2d\"),a=t(\"regl-error2d\"),o=t(\"gl-text\"),s=t(\"../../lib\"),l=t(\"../../lib/prepare_regl\"),c=t(\"../scatter/subtypes\"),u=t(\"../scatter/link_traces\"),h=t(\"./edit_style\").styleTextSelection;e.exports=function(t,e,r){if(r.length){var f,p,d=t._fullLayout,g=e._scene,v=e.xaxis,m=e.yaxis;if(g)if(l(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])){var y=g.count,x=d._glcanvas.data()[0].regl;if(u(t,e,r),g.dirty){if(!0===g.error2d&&(g.error2d=a(x)),!0===g.line2d&&(g.line2d=i(x)),!0===g.scatter2d&&(g.scatter2d=n(x)),!0===g.fill2d&&(g.fill2d=i(x)),!0===g.glText)for(g.glText=new Array(y),f=0;f<y;f++)g.glText[f]=new o(x);if(g.glText){if(y>g.glText.length){var b=y-g.glText.length;for(f=0;f<b;f++)g.glText.push(new o(x))}else if(y<g.glText.length){var _=g.glText.length-y;g.glText.splice(y,_).forEach(function(t){t.destroy()})}for(f=0;f<y;f++)g.glText[f].update(g.textOptions[f])}if(g.line2d&&(g.line2d.update(g.lineOptions),g.lineOptions=g.lineOptions.map(function(t){if(t&&t.positions){for(var e=t.positions,r=0;r<e.length&&(isNaN(e[r])||isNaN(e[r+1]));)r+=2;for(var n=e.length-2;n>r&&(isNaN(e[n])||isNaN(e[n+1]));)n-=2;t.positions=e.slice(r,n+2)}return t}),g.line2d.update(g.lineOptions)),g.error2d){var w=(g.errorXOptions||[]).concat(g.errorYOptions||[]);g.error2d.update(w)}g.scatter2d&&g.scatter2d.update(g.markerOptions),g.fillOrder=s.repeat(null,y),g.fill2d&&(g.fillOptions=g.fillOptions.map(function(t,e){var n=r[e];if(t&&n&&n[0]&&n[0].trace){var i,a,o=n[0],s=o.trace,l=o.t,c=g.lineOptions[e],u=[];s._ownfill&&u.push(e),s._nexttrace&&u.push(e+1),u.length&&(g.fillOrder[e]=u);var h,f,p=[],d=c&&c.positions||l.positions;if(\"tozeroy\"===s.fill){for(h=0;h<d.length&&isNaN(d[h+1]);)h+=2;for(f=d.length-2;f>h&&isNaN(d[f+1]);)f-=2;0!==d[h+1]&&(p=[d[h],0]),p=p.concat(d.slice(h,f+2)),0!==d[f+1]&&(p=p.concat([d[f],0]))}else if(\"tozerox\"===s.fill){for(h=0;h<d.length&&isNaN(d[h]);)h+=2;for(f=d.length-2;f>h&&isNaN(d[f]);)f-=2;0!==d[h]&&(p=[0,d[h+1]]),p=p.concat(d.slice(h,f+2)),0!==d[f]&&(p=p.concat([0,d[f+1]]))}else if(\"toself\"===s.fill||\"tonext\"===s.fill){for(p=[],i=0,a=0;a<d.length;a+=2)(isNaN(d[a])||isNaN(d[a+1]))&&((p=p.concat(d.slice(i,a))).push(d[i],d[i+1]),i=a+2);p=p.concat(d.slice(i)),i&&p.push(d[i],d[i+1])}else{var v=s._nexttrace;if(v){var m=g.lineOptions[e+1];if(m){var y=m.positions;if(\"tonexty\"===s.fill){for(p=d.slice(),e=Math.floor(y.length/2);e--;){var x=y[2*e],b=y[2*e+1];isNaN(x)||isNaN(b)||p.push(x,b)}t.fill=v.fillcolor}}}}if(s._prevtrace&&\"tonext\"===s._prevtrace.fill){var _=g.lineOptions[e-1].positions,w=p.length/2,k=[i=w];for(a=0;a<_.length;a+=2)(isNaN(_[a])||isNaN(_[a+1]))&&(k.push(a/2+w+1),i=a+2);p=p.concat(_),t.hole=k}return t.fillmode=s.fill,t.opacity=s.opacity,t.positions=p,t}}),g.fill2d.update(g.fillOptions))}var k=d.dragmode,T=\"lasso\"===k||\"select\"===k,A=d.clickmode.indexOf(\"select\")>-1;for(f=0;f<y;f++){var M=r[f][0],S=M.trace,E=M.t,C=E.index,L=S._length,P=E.x,O=E.y;if(S.selectedpoints||T||A){if(T||(T=!0),S.selectedpoints){var z=g.selectBatch[C]=s.selIndices2selPoints(S),I={};for(p=0;p<z.length;p++)I[z[p]]=1;var D=[];for(p=0;p<L;p++)I[p]||D.push(p);g.unselectBatch[C]=D}var R=E.xpx=new Array(L),F=E.ypx=new Array(L);for(p=0;p<L;p++)R[p]=v.c2p(P[p]),F[p]=m.c2p(O[p])}else E.xpx=E.ypx=null}if(T){if(g.select2d||(g.select2d=n(d._glcanvas.data()[1].regl)),g.scatter2d){var B=new Array(y);for(f=0;f<y;f++)B[f]=g.selectBatch[f].length||g.unselectBatch[f].length?g.markerUnselectedOptions[f]:{};g.scatter2d.update(B)}g.select2d&&(g.select2d.update(g.markerOptions),g.select2d.update(g.markerSelectedOptions)),g.glText&&r.forEach(function(t){var e=((t||[])[0]||{}).trace||{};c.hasText(e)&&h(t)})}else g.scatter2d&&g.scatter2d.update(g.markerOptions);var N={viewport:function(t,e,r){var n=t._size,i=t.width,a=t.height;return[n.l+e.domain[0]*n.w,n.b+r.domain[0]*n.h,i-n.r-(1-e.domain[1])*n.w,a-n.t-(1-r.domain[1])*n.h]}(d,v,m),range:[(v._rl||v.range)[0],(m._rl||m.range)[0],(v._rl||v.range)[1],(m._rl||m.range)[1]]},j=s.repeat(N,g.count);g.fill2d&&g.fill2d.update(j),g.line2d&&g.line2d.update(j),g.error2d&&g.error2d.update(j.concat(j)),g.scatter2d&&g.scatter2d.update(j),g.select2d&&g.select2d.update(j),g.glText&&g.glText.forEach(function(t){t.update(N)})}else g.init()}}},{\"../../lib\":719,\"../../lib/prepare_regl\":732,\"../scatter/link_traces\":1127,\"../scatter/subtypes\":1135,\"./edit_style\":1165,\"gl-text\":317,\"regl-error2d\":490,\"regl-line2d\":491,\"regl-scatter2d\":497}],1169:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=e._scene,i={count:0,dirty:!0,lineOptions:[],fillOptions:[],markerOptions:[],markerSelectedOptions:[],markerUnselectedOptions:[],errorXOptions:[],errorYOptions:[],textOptions:[],textSelectedOptions:[],textUnselectedOptions:[],selectBatch:[],unselectBatch:[]},a={fill2d:!1,scatter2d:!1,error2d:!1,line2d:!1,glText:!1,select2d:!1};return e._scene||((r=e._scene={}).init=function(){n.extendFlat(r,a,i)},r.init(),r.update=function(t){var e=n.repeat(t,r.count);if(r.fill2d&&r.fill2d.update(e),r.scatter2d&&r.scatter2d.update(e),r.line2d&&r.line2d.update(e),r.error2d&&r.error2d.update(e.concat(e)),r.select2d&&r.select2d.update(e),r.glText)for(var i=0;i<r.count;i++)r.glText[i].update(t)},r.draw=function(){for(var t=r.count,e=r.fill2d,i=r.error2d,a=r.line2d,o=r.scatter2d,s=r.glText,l=r.select2d,c=r.selectBatch,u=r.unselectBatch,h=0;h<t;h++){if(e&&r.fillOrder[h]&&e.draw(r.fillOrder[h]),a&&r.lineOptions[h]&&a.draw(h),i&&(r.errorXOptions[h]&&i.draw(h),r.errorYOptions[h]&&i.draw(h+t)),o&&r.markerOptions[h])if(u[h].length){var f=n.repeat([],r.count);f[h]=u[h],o.draw(f)}else c[h].length||o.draw(h);s[h]&&r.textOptions[h]&&s[h].render()}l&&l.draw(c),r.dirty=!1},r.destroy=function(){r.fill2d&&r.fill2d.destroy&&r.fill2d.destroy(),r.scatter2d&&r.scatter2d.destroy&&r.scatter2d.destroy(),r.error2d&&r.error2d.destroy&&r.error2d.destroy(),r.line2d&&r.line2d.destroy&&r.line2d.destroy(),r.select2d&&r.select2d.destroy&&r.select2d.destroy(),r.glText&&r.glText.forEach(function(t){t.destroy&&t.destroy()}),r.lineOptions=null,r.fillOptions=null,r.markerOptions=null,r.markerSelectedOptions=null,r.markerUnselectedOptions=null,r.errorXOptions=null,r.errorYOptions=null,r.textOptions=null,r.textSelectedOptions=null,r.textUnselectedOptions=null,r.selectBatch=null,r.unselectBatch=null,e._scene=null}),r.dirty||n.extendFlat(r,i),r}},{\"../../lib\":719}],1170:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"./edit_style\").styleTextSelection;e.exports=function(t,e){var r=t.cd,a=[],o=r[0].trace,s=r[0].t,l=o._length,c=s.x,u=s.y,h=s._scene,f=s.index;if(!h)return a;var p=n.hasText(o),d=n.hasMarkers(o),g=!d&&!p;if(!0!==o.visible||g)return a;var v=[],m=[];if(!1!==e&&!e.degenerate)for(var y=0;y<l;y++)e.contains([s.xpx[y],s.ypx[y]],!1,y,t)?(v.push(y),a.push({pointNumber:y,x:c[y],y:u[y]})):m.push(y);if(d){var x=h.scatter2d;if(v.length||m.length){if(!h.selectBatch[f].length&&!h.unselectBatch[f].length){var b=new Array(h.count);b[f]=h.markerUnselectedOptions[f],x.update.apply(x,b)}}else{var _=new Array(h.count);_[f]=h.markerOptions[f],x.update.apply(x,_)}}return h.selectBatch[f]=v,h.unselectBatch[f]=m,p&&i(r),a}},{\"../scatter/subtypes\":1135,\"./edit_style\":1165}],1171:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scattergeo/attributes\"),a=t(\"../scatter/attributes\"),o=t(\"../../plots/mapbox/layout_attributes\"),s=t(\"../../plots/attributes\"),l=t(\"../../components/colorscale/attributes\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../plot_api/edit_types\").overrideAll,h=i.line,f=i.marker;e.exports=u({lon:i.lon,lat:i.lat,mode:c({},a.mode,{dflt:\"markers\"}),text:c({},a.text,{}),hovertext:c({},a.hovertext,{}),line:{color:h.color,width:h.width},connectgaps:a.connectgaps,marker:c({symbol:{valType:\"string\",dflt:\"circle\",arrayOk:!0},opacity:f.opacity,size:f.size,sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode},l(\"marker\")),fill:i.fill,fillcolor:a.fillcolor,textfont:o.layers.symbol.textfont,textposition:o.layers.symbol.textposition,below:{valType:\"string\"},selected:{marker:a.selected.marker},unselected:{marker:a.unselected.marker},hoverinfo:c({},s.hoverinfo,{flags:[\"lon\",\"lat\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../../plots/mapbox/layout_attributes\":824,\"../scatter/attributes\":1112,\"../scattergeo/attributes\":1151}],1172:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../lib/geojson_utils\"),s=t(\"../../components/colorscale\"),l=t(\"../../components/drawing\"),c=t(\"../scatter/make_bubble_size_func\"),u=t(\"../scatter/subtypes\"),h=t(\"../../plots/mapbox/convert_text_opts\");function f(){return{geojson:o.makeBlank(),layout:{visibility:\"none\"},paint:{}}}function p(t){return i.isArrayOrTypedArray(t)?function(t){return t}:t?function(){return t}:d}function d(){return\"\"}function g(t){return t[0]===a}e.exports=function(t){var e,r=t[0].trace,a=!0===r.visible&&0!==r._length,v=\"none\"!==r.fill,m=u.hasLines(r),y=u.hasMarkers(r),x=u.hasText(r),b=y&&\"circle\"===r.marker.symbol,_=y&&\"circle\"!==r.marker.symbol,w=f(),k=f(),T=f(),A=f(),M={fill:w,line:k,circle:T,symbol:A};if(!a)return M;if((v||m)&&(e=o.calcTraceToLineCoords(t)),v&&(w.geojson=o.makePolygon(e),w.layout.visibility=\"visible\",i.extendFlat(w.paint,{\"fill-color\":r.fillcolor})),m&&(k.geojson=o.makeLine(e),k.layout.visibility=\"visible\",i.extendFlat(k.paint,{\"line-width\":r.line.width,\"line-color\":r.line.color,\"line-opacity\":r.opacity})),b){var S=function(t){var e,r,a,o,u=t[0].trace,h=u.marker,f=u.selectedpoints,p=i.isArrayOrTypedArray(h.color),d=i.isArrayOrTypedArray(h.size),v=i.isArrayOrTypedArray(h.opacity);function m(t){return u.opacity*t}p&&(r=s.hasColorscale(u,\"marker\")?s.makeColorScaleFuncFromTrace(h):i.identity);d&&(a=c(u));v&&(o=function(t){var e=n(t)?+i.constrain(t,0,1):0;return m(e)});var y,x=[];for(e=0;e<t.length;e++){var b=t[e],_=b.lonlat;if(!g(_)){var w={};r&&(w.mcc=b.mcc=r(b.mc)),a&&(w.mrc=b.mrc=a(b.ms)),o&&(w.mo=o(b.mo)),f&&(w.selected=b.selected||0),x.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:_},properties:w})}}if(f)for(y=l.makeSelectedPointStyleFns(u),e=0;e<x.length;e++){var k=x[e].properties;y.selectedOpacityFn&&(k.mo=m(y.selectedOpacityFn(k))),y.selectedColorFn&&(k.mcc=y.selectedColorFn(k)),y.selectedSizeFn&&(k.mrc=y.selectedSizeFn(k))}return{geojson:{type:\"FeatureCollection\",features:x},mcc:p||y&&y.selectedColorFn?{type:\"identity\",property:\"mcc\"}:h.color,mrc:d||y&&y.selectedSizeFn?{type:\"identity\",property:\"mrc\"}:(T=h.size,T/2),mo:v||y&&y.selectedOpacityFn?{type:\"identity\",property:\"mo\"}:m(h.opacity)};var T}(t);T.geojson=S.geojson,T.layout.visibility=\"visible\",i.extendFlat(T.paint,{\"circle-color\":S.mcc,\"circle-radius\":S.mrc,\"circle-opacity\":S.mo})}if((_||x)&&(A.geojson=function(t){for(var e=t[0].trace,r=(e.marker||{}).symbol,n=e.text,i=\"circle\"!==r?p(r):d,a=u.hasText(e)?p(n):d,o=[],s=0;s<t.length;s++){var l=t[s];g(l.lonlat)||o.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:l.lonlat},properties:{symbol:i(l.mx),text:a(l.tx)}})}return{type:\"FeatureCollection\",features:o}}(t),i.extendFlat(A.layout,{visibility:\"visible\",\"icon-image\":\"{symbol}-15\",\"text-field\":\"{text}\"}),_&&(i.extendFlat(A.layout,{\"icon-size\":r.marker.size/10}),i.extendFlat(A.paint,{\"icon-opacity\":r.opacity*r.marker.opacity,\"icon-color\":r.marker.color})),x)){var E=(r.marker||{}).size,C=h(r.textposition,E);i.extendFlat(A.layout,{\"text-size\":r.textfont.size,\"text-anchor\":C.anchor,\"text-offset\":C.offset}),i.extendFlat(A.paint,{\"text-color\":r.textfont.color,\"text-opacity\":r.opacity})}return M}},{\"../../components/colorscale\":605,\"../../components/drawing\":614,\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/geojson_utils\":714,\"../../plots/mapbox/convert_text_opts\":821,\"../scatter/make_bubble_size_func\":1128,\"../scatter/subtypes\":1135,\"fast-isnumeric\":225}],1173:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,i){return n.coerce(t,e,c,r,i)}if(function(t,e,r){var n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length);return e._length=a,a}(0,e,h)){if(h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),h(\"below\"),i.hasLines(e)&&(o(t,e,r,u,h,{noDash:!0}),h(\"connectgaps\")),i.hasMarkers(e)){a(t,e,r,u,h,{noLine:!0});var f=e.marker;\"circle\"!==f.symbol&&(n.isArrayOrTypedArray(f.size)&&(f.size=f.size[0]),n.isArrayOrTypedArray(f.color)&&(f.color=f.color[0]))}i.hasText(e)&&s(t,e,u,h,{noSelect:!0}),h(\"fill\"),\"none\"!==e.fill&&l(t,e,r,h),n.coerceSelectionMarkerOpacity(e,h)}else e.visible=!1}},{\"../../lib\":719,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1171}],1174:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t}},{}],1175:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\"),o=i.fillText,s=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,h=t.ya,f=t.subplot,p=360*(e>=0?Math.floor((e+180)/360):Math.ceil((e-180)/360)),d=e-p;if(n.getClosest(l,function(t){var e=t.lonlat;if(e[0]===s)return 1/0;var n=i.modHalf(e[0],360),a=e[1],o=f.project([n,a]),l=o.x-u.c2p([d,a]),c=o.y-h.c2p([n,r]),p=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(l*l+c*c)-p,1-3/p)},t),!1!==t.index){var g=l[t.index],v=g.lonlat,m=[i.modHalf(v[0],360)+p,v[1]],y=u.c2p(m),x=h.c2p(m),b=g.mrc||1;return t.x0=y-b,t.x1=y+b,t.y0=x-b,t.y1=x+b,t.color=a(c,g),t.extraText=function(t,e,r){if(t.hovertemplate)return;var n=(e.hi||t.hoverinfo).split(\"+\"),i=-1!==n.indexOf(\"all\"),a=-1!==n.indexOf(\"lon\"),s=-1!==n.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}i||a&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):a?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(i||-1!==n.indexOf(\"text\"))&&o(e,t,c);return c.join(\"<br>\")}(c,g,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},{\"../../components/fx\":632,\"../../constants/numerical\":695,\"../../lib\":719,\"../scatter/get_trace_color\":1121}],1176:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"../scattergeo/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.update(e)},moduleType:\"trace\",name:\"scattermapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"symbols\",\"showLegend\",\"scatterlike\"],meta:{}}},{\"../../plots/mapbox\":822,\"../scatter/marker_colorbar\":1129,\"../scattergeo/calc\":1152,\"./attributes\":1171,\"./defaults\":1173,\"./event_data\":1174,\"./hover\":1175,\"./plot\":1177,\"./select\":1178}],1177:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix,a=[\"fill\",\"line\",\"circle\",\"symbol\"];function o(t,e){this.subplot=t,this.uid=e,this.sourceIds={fill:\"source-\"+e+\"-fill\",line:\"source-\"+e+\"-line\",circle:\"source-\"+e+\"-circle\",symbol:\"source-\"+e+\"-symbol\"},this.layerIds={fill:i+e+\"-fill\",line:i+e+\"-line\",circle:i+e+\"-circle\",symbol:i+e+\"-symbol\"},this.below=null}var s=o.prototype;s.addSource=function(t,e){this.subplot.map.addSource(this.sourceIds[t],{type:\"geojson\",data:e.geojson})},s.setSourceData=function(t,e){this.subplot.map.getSource(this.sourceIds[t]).setData(e.geojson)},s.addLayer=function(t,e,r){this.subplot.addLayer({type:t,id:this.layerIds[t],source:this.sourceIds[t],layout:e.layout,paint:e.paint},r)},s.update=function(t){var e,r,i,o=this.subplot,s=o.map,l=n(t),c=o.belowLookup[\"trace-\"+this.uid];if(c!==this.below){for(e=a.length-1;e>=0;e--)r=a[e],s.removeLayer(this.layerIds[r]);for(e=0;e<a.length;e++)i=l[r=a[e]],this.addLayer(r,i,c);this.below=c}for(e=0;e<a.length;e++)i=l[r=a[e]],o.setOptions(this.layerIds[r],\"setLayoutProperty\",i.layout),\"visible\"===i.layout.visibility&&(this.setSourceData(r,i),o.setOptions(this.layerIds[r],\"setPaintProperty\",i.paint));t[0].trace._glTrace=this},s.dispose=function(){for(var t=this.subplot.map,e=a.length-1;e>=0;e--){var r=a[e];t.removeLayer(this.layerIds[r]),t.removeSource(this.sourceIds[r])}},e.exports=function(t,e){for(var r=e[0].trace,i=new o(t,r.uid),s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid],c=0;c<a.length;c++){var u=a[c],h=s[u];i.addSource(u,h),i.addLayer(u,h,l)}return e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":820,\"./convert\":1172}],1178:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,o=t.cd,s=t.xaxis,l=t.yaxis,c=[],u=o[0].trace;if(!i.hasMarkers(u))return[];if(!1===e)for(r=0;r<o.length;r++)o[r].selected=0;else for(r=0;r<o.length;r++){var h=o[r],f=h.lonlat;if(f[0]!==a){var p=[n.modHalf(f[0],360),f[1]],d=[s.c2p(p),l.c2p(p)];e.contains(d,null,r,t)?(c.push({pointNumber:r,lon:f[0],lat:f[1]}),h.selected=1):h.selected=0}}return c}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../scatter/subtypes\":1135}],1179:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../scatter/attributes\"),o=t(\"../../plots/attributes\"),s=a.line;e.exports={mode:a.mode,r:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},theta:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},r0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dr:{valType:\"number\",dflt:1,editType:\"calc\"},theta0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dtheta:{valType:\"number\",editType:\"calc\"},thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\",\"gradians\"],dflt:\"degrees\",editType:\"calc+clearAxisTypes\"},text:a.text,hovertext:a.hovertext,line:{color:s.color,width:s.width,dash:s.dash,shape:i({},s.shape,{values:[\"linear\",\"spline\"]}),smoothing:s.smoothing,editType:\"calc\"},connectgaps:a.connectgaps,marker:a.marker,cliponaxis:i({},a.cliponaxis,{dflt:!1}),textposition:a.textposition,textfont:a.textfont,fill:i({},a.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:a.fillcolor,hoverinfo:i({},o.hoverinfo,{flags:[\"r\",\"theta\",\"text\",\"name\"]}),hoveron:a.hoveron,hovertemplate:n(),selected:a.selected,unselected:a.unselected}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1180:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../plots/cartesian/axes\"),o=t(\"../scatter/colorscale_calc\"),s=t(\"../scatter/arrays_to_calcdata\"),l=t(\"../scatter/calc_selection\"),c=t(\"../scatter/calc\").calcMarkerSize;e.exports=function(t,e){for(var r=t._fullLayout,u=e.subplot,h=r[u].radialaxis,f=r[u].angularaxis,p=h.makeCalcdata(e,\"r\"),d=f.makeCalcdata(e,\"theta\"),g=e._length,v=new Array(g),m=0;m<g;m++){var y=p[m],x=d[m],b=v[m]={};n(y)&&n(x)?(b.r=y,b.theta=x):b.r=i}var _=c(e,g);return e._extremes.x=a.findExtremes(h,p,{ppad:_}),o(t,e),s(v,e),l(v,e),v}},{\"../../constants/numerical\":695,\"../../plots/cartesian/axes\":767,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc\":1113,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1181:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/line_shape_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,h=t(\"./attributes\");function f(t,e,r,n){var i,a=n(\"r\"),o=n(\"theta\");if(a)o?i=Math.min(a.length,o.length):(i=a.length,n(\"theta0\"),n(\"dtheta\"));else{if(!o)return 0;i=e.theta.length,n(\"r0\"),n(\"dr\")}return e._length=i,i}e.exports={handleRThetaDefaults:f,supplyDefaults:function(t,e,r,p){function d(r,i){return n.coerce(t,e,h,r,i)}var g=f(0,e,0,d);if(g){d(\"thetaunit\"),d(\"mode\",g<u?\"lines+markers\":\"lines\"),d(\"text\"),d(\"hovertext\"),\"fills\"!==e.hoveron&&d(\"hovertemplate\"),i.hasLines(e)&&(o(t,e,r,p,d),s(t,e,d),d(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,p,d,{gradient:!0}),i.hasText(e)&&l(t,e,p,d);var v=[];(i.hasMarkers(e)||i.hasText(e))&&(d(\"cliponaxis\"),d(\"marker.maxdisplayed\"),v.push(\"points\")),d(\"fill\"),\"none\"!==e.fill&&(c(t,e,r,d),i.hasLines(e)||s(t,e,d)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||v.push(\"fills\"),d(\"hoveron\",v.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/line_shape_defaults\":1126,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1179}],1182:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\");function o(t,e,r,n){var o=r.radialAxis,s=r.angularAxis;o._hovertitle=\"r\",s._hovertitle=\"\\u03b8\";var l=o.c2l(t.r);n.rLabel=i.tickText(o,l,\"hover\").text;var c=\"degrees\"===s.thetaunit?a.rad2deg(t.theta):t.theta;n.thetaLabel=i.tickText(s,c,\"hover\").text;var u=t.hi||e.hoverinfo,h=[];function f(t,e){h.push(t._hovertitle+\": \"+e)}if(!e.hovertemplate){var p=u.split(\"+\");-1!==p.indexOf(\"all\")&&(p=[\"r\",\"theta\",\"text\"]),-1!==p.indexOf(\"r\")&&f(o,n.rLabel),-1!==p.indexOf(\"theta\")&&f(s,n.thetaLabel),-1!==p.indexOf(\"text\")&&n.text&&(h.push(n.text),delete n.text),n.extraText=h.join(\"<br>\")}}e.exports={hoverPoints:function(t,e,r,i){var a=n(t,e,r,i);if(a&&!1!==a[0].index){var s=a[0];if(void 0===s.index)return a;var l=t.subplot,c=s.cd[s.index],u=s.trace;if(l.isPtInside(c))return s.xLabelVal=void 0,s.yLabelVal=void 0,o(c,u,l,s),s.hovertemplate=u.hovertemplate,a}},makeHoverPointText:o}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scatter/hover\":1122}],1183:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scatter/select\"),meta:{}}},{\"../../plots/polar\":831,\"../scatter/marker_colorbar\":1129,\"../scatter/select\":1132,\"../scatter/style\":1134,\"./attributes\":1179,\"./calc\":1180,\"./defaults\":1181,\"./hover\":1182,\"./plot\":1184}],1184:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){for(var a=e.layers.frontplot.select(\"g.scatterlayer\"),o={xaxis:e.xaxis,yaxis:e.yaxis,plot:e.framework,layerClipId:e._hasClipOnAxisFalse?e.clipIds.forTraces:null},s=e.radialAxis,l=e.angularAxis,c=0;c<r.length;c++)for(var u=r[c],h=0;h<u.length;h++){var f=u[h],p=f.r;if(p===i)f.x=f.y=i;else{var d=s.c2g(p),g=l.c2g(f.theta);f.x=d*Math.cos(g),f.y=d*Math.sin(g)}}n(t,o,r,a)}},{\"../../constants/numerical\":695,\"../scatter/plot\":1131}],1185:[function(t,e,r){\"use strict\";var n=t(\"../scatterpolar/attributes\"),i=t(\"../scattergl/attributes\");e.exports={mode:n.mode,r:n.r,theta:n.theta,r0:n.r0,dr:n.dr,theta0:n.theta0,dtheta:n.dtheta,thetaunit:n.thetaunit,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,line:i.line,connectgaps:i.connectgaps,marker:i.marker,fill:i.fill,fillcolor:i.fillcolor,textposition:i.textposition,textfont:i.textfont,hoverinfo:n.hoverinfo,selected:n.selected,unselected:n.unselected}},{\"../scattergl/attributes\":1160,\"../scatterpolar/attributes\":1179}],1186:[function(t,e,r){\"use strict\";var n=t(\"../scatter/colorscale_calc\"),i=t(\"../scatter/calc\").calcMarkerSize,a=t(\"../scattergl/convert\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r=t._fullLayout,l=e.subplot,c=r[l].radialaxis,u=r[l].angularaxis,h=c.makeCalcdata(e,\"r\"),f=u.makeCalcdata(e,\"theta\"),p=e._length,d={};p<h.length&&(h=h.slice(0,p)),p<f.length&&(f=f.slice(0,p)),d.r=h,d.theta=f,n(t,e);var g,v=d.opts=a.style(t,e);return p<s?g=i(e,p):v.marker&&(g=2*(v.marker.sizeAvg||Math.max(v.marker.size,3))),e._extremes.x=o.findExtremes(c,h,{ppad:g}),[{x:!1,y:!1,t:d,trace:e}]}},{\"../../plots/cartesian/axes\":767,\"../scatter/calc\":1113,\"../scatter/colorscale_calc\":1115,\"../scattergl/constants\":1162,\"../scattergl/convert\":1163}],1187:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatterpolar/defaults\").handleRThetaDefaults,o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}var d=a(t,e,f,p);d?(p(\"thetaunit\"),p(\"mode\",d<u?\"lines+markers\":\"lines\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),i.hasLines(e)&&(s(t,e,r,f,p),p(\"connectgaps\")),i.hasMarkers(e)&&o(t,e,r,f,p),i.hasText(e)&&l(t,e,f,p),p(\"fill\"),\"none\"!==e.fill&&c(t,e,r,p),n.coerceSelectionMarkerOpacity(e,p)):e.visible=!1}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"../scatterpolar/defaults\":1181,\"./attributes\":1185}],1188:[function(t,e,r){\"use strict\";var n=t(\"../scattergl/hover\"),i=t(\"../scatterpolar/hover\").makeHoverPointText;e.exports={hoverPoints:function(t,e,r,a){var o=t.cd[0].t,s=o.r,l=o.theta,c=n.hoverPoints(t,e,r,a);if(c&&!1!==c[0].index){var u=c[0];if(void 0===u.index)return c;var h=t.subplot,f=u.cd[u.index],p=u.trace;if(f.r=s[u.index],f.theta=l[u.index],h.isPtInside(f))return u.xLabelVal=void 0,u.yLabelVal=void 0,i(f,p,h,u),c}}}},{\"../scattergl/hover\":1166,\"../scatterpolar/hover\":1182}],1189:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolargl\",basePlotModule:t(\"../../plots/polar\"),categories:[\"gl\",\"regl\",\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scattergl/select\"),meta:{}}},{\"../../plots/polar\":831,\"../scatter/marker_colorbar\":1129,\"../scattergl/select\":1170,\"./attributes\":1185,\"./calc\":1186,\"./defaults\":1187,\"./hover\":1188,\"./plot\":1190}],1190:[function(t,e,r){\"use strict\";var n=t(\"point-cluster\"),i=t(\"fast-isnumeric\"),a=t(\"../scattergl/plot\"),o=t(\"../scattergl/scene_update\"),s=t(\"../scattergl/convert\"),l=t(\"../../lib\"),c=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e,r){if(r.length){var u=e.radialAxis,h=e.angularAxis,f=o(t,e);return r.forEach(function(r){if(r&&r[0]&&r[0].trace){var a,o=r[0],p=o.trace,d=o.t,g=p._length,v=d.r,m=d.theta,y=d.opts,x=v.slice(),b=m.slice();for(a=0;a<v.length;a++)e.isPtInside({r:v[a],theta:m[a]})||(x[a]=NaN,b[a]=NaN);var _=new Array(2*g),w=Array(g),k=Array(g);for(a=0;a<g;a++){var T,A,M=x[a];if(i(M)){var S=u.c2g(M),E=h.c2g(b[a],p.thetaunit);T=S*Math.cos(E),A=S*Math.sin(E)}else T=A=NaN;w[a]=_[2*a]=T,k[a]=_[2*a+1]=A}d.tree=n(_),y.marker&&g>=c&&(y.marker.cluster=d.tree),y.marker&&(y.markerSel.positions=y.markerUnsel.positions=y.marker.positions=_),y.line&&_.length>1&&l.extendFlat(y.line,s.linePositions(t,p,_)),y.text&&(l.extendFlat(y.text,{positions:_},s.textPosition(t,p,y.text,y.marker)),l.extendFlat(y.textSel,{positions:_},s.textPosition(t,p,y.text,y.markerSel)),l.extendFlat(y.textUnsel,{positions:_},s.textPosition(t,p,y.text,y.markerUnsel))),y.fill&&!f.fill2d&&(f.fill2d=!0),y.marker&&!f.scatter2d&&(f.scatter2d=!0),y.line&&!f.line2d&&(f.line2d=!0),y.text&&!f.glText&&(f.glText=!0),f.lineOptions.push(y.line),f.fillOptions.push(y.fill),f.markerOptions.push(y.marker),f.markerSelectedOptions.push(y.markerSel),f.markerUnselectedOptions.push(y.markerUnsel),f.textOptions.push(y.text),f.textSelectedOptions.push(y.textSel),f.textUnselectedOptions.push(y.textUnsel),f.selectBatch.push([]),f.unselectBatch.push([]),d.x=w,d.y=k,d.rawx=w,d.rawy=k,d.r=v,d.theta=m,d.positions=_,d._scene=f,d.index=f.count,f.count++}}),a(t,e,r)}}},{\"../../lib\":719,\"../scattergl/constants\":1162,\"../scattergl/convert\":1163,\"../scattergl/plot\":1168,\"../scattergl/scene_update\":1169,\"fast-isnumeric\":225,\"point-cluster\":469}],1191:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/drawing/attributes\").dash,l=t(\"../../lib/extend\").extendFlat,c=i.marker,u=i.line,h=c.line;e.exports={a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},c:{valType:\"data_array\",editType:\"calc\"},sum:{valType:\"number\",dflt:0,min:0,editType:\"calc\"},mode:l({},i.mode,{dflt:\"markers\"}),text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),line:{color:u.color,width:u.width,dash:s,shape:l({},u.shape,{values:[\"linear\",\"spline\"]}),smoothing:u.smoothing,editType:\"calc\"},connectgaps:i.connectgaps,cliponaxis:i.cliponaxis,fill:l({},i.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:i.fillcolor,marker:l({symbol:c.symbol,opacity:c.opacity,maxdisplayed:c.maxdisplayed,size:c.size,sizeref:c.sizeref,sizemin:c.sizemin,sizemode:c.sizemode,line:l({width:h.width,editType:\"calc\"},o(\"marker.line\")),gradient:c.gradient,editType:\"calc\"},o(\"marker\")),textfont:i.textfont,textposition:i.textposition,selected:i.selected,unselected:i.unselected,hoverinfo:l({},a.hoverinfo,{flags:[\"a\",\"b\",\"c\",\"text\",\"name\"]}),hoveron:i.hoveron,hovertemplate:n()}},{\"../../components/colorscale/attributes\":600,\"../../components/drawing/attributes\":613,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1192:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=[\"a\",\"b\",\"c\"],c={a:[\"b\",\"c\"],b:[\"a\",\"c\"],c:[\"a\",\"b\"]};e.exports=function(t,e){var r,u,h,f,p,d,g=t._fullLayout[e.subplot].sum,v=e.sum||g,m={a:e.a,b:e.b,c:e.c};for(r=0;r<l.length;r++)if(!m[h=l[r]]){for(p=m[c[h][0]],d=m[c[h][1]],f=new Array(p.length),u=0;u<p.length;u++)f[u]=v-p[u]-d[u];m[h]=f}var y,x,b,_,w,k,T=e._length,A=new Array(T);for(r=0;r<T;r++)y=m.a[r],x=m.b[r],b=m.c[r],n(y)&&n(x)&&n(b)?(1!==(_=g/((y=+y)+(x=+x)+(b=+b)))&&(y*=_,x*=_,b*=_),k=y,w=b-x,A[r]={x:w,y:k,a:y,b:x,c:b}):A[r]={x:!1,y:!1};return s(e,T),i(t,e),a(A,e),o(A,e),A}},{\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc\":1113,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1193:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}var d,g=p(\"a\"),v=p(\"b\"),m=p(\"c\");if(g?(d=g.length,v?(d=Math.min(d,v.length),m&&(d=Math.min(d,m.length))):d=m?Math.min(d,m.length):0):v&&m&&(d=Math.min(v.length,m.length)),d){e._length=d,p(\"sum\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),p(\"mode\",d<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,f,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,f,p,{gradient:!0}),a.hasText(e)&&c(t,e,f,p);var y=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"cliponaxis\"),p(\"marker.maxdisplayed\"),y.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||y.push(\"fills\"),p(\"hoveron\",y.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/line_shape_defaults\":1126,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1191}],1194:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),n[i]){var a=n[i];t.a=a.a,t.b=a.b,t.c=a.c}else t.a=e.a,t.b=e.b,t.c=e.c;return t}},{}],1195:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,h=c-u;return s.x0=Math.max(Math.min(s.x0,h),u),s.x1=Math.max(Math.min(s.x1,h),u),o}var f=s.cd[s.index];s.a=f.a,s.b=f.b,s.c=f.c,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.subplot;s.aLabel=i.tickText(p.aaxis,f.a,\"hover\").text,s.bLabel=i.tickText(p.baxis,f.b,\"hover\").text,s.cLabel=i.tickText(p.caxis,f.c,\"hover\").text;var d=s.trace,g=f.hi||d.hoverinfo,v=[];if(!d.hovertemplate){var m=g.split(\"+\");-1!==m.indexOf(\"all\")&&(m=[\"a\",\"b\",\"c\"]),-1!==m.indexOf(\"a\")&&y(p.aaxis,s.aLabel),-1!==m.indexOf(\"b\")&&y(p.baxis,s.bLabel),-1!==m.indexOf(\"c\")&&y(p.caxis,s.cLabel)}return s.extraText=v.join(\"<br>\"),s.hovertemplate=d.hovertemplate,o}function y(t,e){v.push(t._hovertitle+\": \"+e)}}},{\"../../plots/cartesian/axes\":767,\"../scatter/hover\":1122}],1196:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scatterternary\",basePlotModule:t(\"../../plots/ternary\"),categories:[\"ternary\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/ternary\":843,\"../scatter/marker_colorbar\":1129,\"../scatter/select\":1132,\"../scatter/style\":1134,\"./attributes\":1191,\"./calc\":1192,\"./defaults\":1193,\"./event_data\":1194,\"./hover\":1195,\"./plot\":1197}],1197:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\");e.exports=function(t,e,r){var i=e.plotContainer;i.select(\".scatterlayer\").selectAll(\"*\").remove();var a={xaxis:e.xaxis,yaxis:e.yaxis,plot:i,layerClipId:e._hasClipOnAxisFalse?e.clipIdRelative:null},o=e.layers.frontplot.select(\"g.scatterlayer\");n(t,a,r,o)}},{\"../scatter/plot\":1131}],1198:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../scattergl/attributes\"),s=t(\"../../plots/cartesian/constants\").idRegex,l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"../../lib/extend\").extendFlat,u=n.marker,h=u.line,f=c(i(\"marker.line\",{editTypeOverride:\"calc\"}),{width:c({},h.width,{editType:\"calc\"}),editType:\"calc\"}),p=c(i(\"marker\"),{symbol:u.symbol,size:c({},u.size,{editType:\"markerSize\"}),sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:f,editType:\"calc\"});function d(t){return{valType:\"info_array\",freeLength:!0,editType:\"calc\",items:{valType:\"subplotid\",regex:s[t],editType:\"plot\"}}}p.color.editType=p.cmin.editType=p.cmax.editType=\"style\",e.exports={dimensions:l(\"dimension\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},label:{valType:\"string\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},axis:{type:{valType:\"enumerated\",values:[\"linear\",\"log\",\"date\",\"category\"],editType:\"calc+clearAxisTypes\"},matches:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc+clearAxisTypes\"},editType:\"calc+clearAxisTypes\"}),text:c({},o.text,{}),hovertext:c({},o.hovertext,{}),hovertemplate:a(),marker:p,xaxes:d(\"x\"),yaxes:d(\"y\"),diagonal:{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},showupperhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},showlowerhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},selected:{marker:o.selected.marker,editType:\"calc\"},unselected:{marker:o.unselected.marker,editType:\"calc\"},opacity:o.opacity}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773,\"../scatter/attributes\":1112,\"../scattergl/attributes\":1160}],1199:[function(t,e,r){\"use strict\";var n=t(\"regl-line2d\"),i=t(\"../../registry\"),a=t(\"../../lib/prepare_regl\"),o=t(\"../../plots/get_data\").getModuleCalcData,s=t(\"../../plots/cartesian\"),l=t(\"../../plots/cartesian/axis_ids\").getFromId,c=t(\"../../plots/cartesian/axes\").shouldShowZeroLine,u=\"splom\";function h(t,e,r){for(var n=r.matrixOptions.data.length,i=e._visibleDims,a=r.viewOpts.ranges=new Array(n),o=0;o<i.length;o++){var s=i[o],c=a[o]=new Array(4),u=l(t,e._diag[s][0]);u&&(c[0]=u.r2l(u.range[0]),c[2]=u.r2l(u.range[1]));var h=l(t,e._diag[s][1]);h&&(c[1]=h.r2l(h.range[0]),c[3]=h.r2l(h.range[1]))}r.selectBatch.length||r.unselectBatch.length?r.matrix.update({ranges:a},{ranges:a}):r.matrix.update({ranges:a})}function f(t){var e=t._fullLayout,r=e._glcanvas.data()[0].regl,i=e._splomGrid;i||(i=e._splomGrid=n(r)),i.update(function(t){var e,r=t._fullLayout,n=r._size,i=[0,0,r.width,r.height],a={};function o(t,e,r,n,o,s){var l=e[t+\"color\"],c=e[t+\"width\"],u=String(l+c);u in a?a[u].data.push(NaN,NaN,r,n,o,s):a[u]={data:[r,n,o,s],join:\"rect\",thickness:c,color:l,viewport:i,range:i,overlay:!1}}for(e in r._splomSubplots){var s,l,u=r._plots[e],h=u.xaxis,f=u.yaxis,p=h._vals,d=f._vals,g=n.b+f.domain[0]*n.h,v=-f._m,m=-v*f.r2l(f.range[0],f.calendar);if(h.showgrid)for(e=0;e<p.length;e++)s=h._offset+h.l2p(p[e].x),o(\"grid\",h,s,g,s,g+f._length);if(f.showgrid)for(e=0;e<d.length;e++)l=g+m+v*d[e].x,o(\"grid\",f,h._offset,l,h._offset+h._length,l);c(t,h,f)&&(s=h._offset+h.l2p(0),o(\"zeroline\",h,s,g,s,g+f._length)),c(t,f,h)&&(l=g+m+0,o(\"zeroline\",f,h._offset,l,h._offset+h._length,l))}var y=[];for(e in a)y.push(a[e]);return y}(t))}e.exports={name:u,attr:s.attr,attrRegex:s.attrRegex,layoutAttributes:s.layoutAttributes,supplyLayoutDefaults:s.supplyLayoutDefaults,drawFramework:s.drawFramework,plot:function(t){var e=t._fullLayout,r=i.getModule(u),n=o(t.calcdata,r)[0];a(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])&&(e._hasOnlyLargeSploms&&f(t),r.plot(t,{},n))},drag:function(t){var e=t.calcdata,r=t._fullLayout;r._hasOnlyLargeSploms&&f(t);for(var n=0;n<e.length;n++){var i=e[n][0].trace,a=r._splomScenes[i.uid];\"splom\"===i.type&&a&&a.matrix&&h(t,i,a)}},updateGrid:f,clean:function(t,e,r,n){var i,a={};if(n._splomScenes){for(i=0;i<t.length;i++){var o=t[i];\"splom\"===o.type&&(a[o.uid]=1)}for(i=0;i<r.length;i++){var l=r[i];if(!a[l.uid]){var c=n._splomScenes[l.uid];c&&c.destroy&&c.destroy(),n._splomScenes[l.uid]=null,delete n._splomScenes[l.uid]}}}0===Object.keys(n._splomScenes||{}).length&&delete n._splomScenes,n._splomGrid&&!e._hasOnlyLargeSploms&&n._hasOnlyLargeSploms&&(n._splomGrid.destroy(),n._splomGrid=null,delete n._splomGrid),s.clean(t,e,r,n)},updateFx:s.updateFx,toSVG:s.toSVG}},{\"../../lib/prepare_regl\":732,\"../../plots/cartesian\":778,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_ids\":770,\"../../plots/get_data\":802,\"../../registry\":847,\"regl-line2d\":491}],1200:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../scatter/calc\").calcMarkerSize,o=t(\"../scatter/calc\").calcAxisExpansion,s=t(\"../scatter/colorscale_calc\"),l=t(\"../scattergl/convert\").markerSelection,c=t(\"../scattergl/convert\").markerStyle,u=t(\"./scene_update\"),h=t(\"../../constants/numerical\").BADNUM,f=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r,p,d,g,v,m,y=e.dimensions,x=e._length,b={},_=b.cdata=[],w=b.data=[],k=e._visibleDims=[];function T(t,r){for(var i=t.makeCalcdata({v:r.values,vcalendar:e.calendar},\"v\"),a=0;a<i.length;a++)i[a]=i[a]===h?NaN:i[a];_.push(i),w.push(\"log\"===t.type?n.simpleMap(i,t.c2l):i)}for(r=0;r<y.length;r++)if((d=y[r]).visible){if(g=i.getFromId(t,e._diag[r][0]),v=i.getFromId(t,e._diag[r][1]),g&&v&&g.type!==v.type){n.log(\"Skipping splom dimension \"+r+\" with conflicting axis types\");continue}g?(T(g,d),v&&\"category\"===v.type&&(v._categories=g._categories.slice())):T(v,d),k.push(r)}for(s(t,e),n.extendFlat(b,c(e)),m=_.length*x>f?2*(b.sizeAvg||Math.max(b.size,3)):a(e,x),p=0;p<k.length;p++)d=y[r=k[p]],g=i.getFromId(t,e._diag[r][0])||{},v=i.getFromId(t,e._diag[r][1])||{},o(t,e,g,v,_[p],_[p],m);var A=u(t,e);return A.matrix||(A.matrix=!0),A.matrixOptions=b,A.selectedOptions=l(e,e.selected),A.unselectedOptions=l(e,e.unselected),[{x:!1,y:!1,t:{},trace:e}]}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../scatter/calc\":1113,\"../scatter/colorscale_calc\":1115,\"../scattergl/constants\":1162,\"../scattergl/convert\":1163,\"./scene_update\":1207}],1201:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"../scatter/subtypes\"),s=t(\"../scatter/marker_defaults\"),l=t(\"../parcoords/merge_length\"),c=/-open/;function u(t,e){function r(r,i){return n.coerce(t,e,a.dimensions,r,i)}r(\"label\");var i=r(\"values\");i&&i.length?r(\"visible\"):e.visible=!1,r(\"axis.type\"),r(\"axis.matches\")}e.exports=function(t,e,r,h){function f(r,i){return n.coerce(t,e,a,r,i)}var p=i(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=f(\"diagonal.visible\"),g=f(\"showupperhalf\"),v=f(\"showlowerhalf\");if(l(e,p,\"values\")&&(d||g||v)){f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),s(t,e,r,h,f);var m=c.test(e.marker.symbol),y=o.isBubble(e);f(\"marker.line.width\",m||y?1:0),function(t,e,r,n){var i,a,o=e.dimensions,s=o.length,l=e.showupperhalf,c=e.showlowerhalf,u=e.diagonal.visible,h=new Array(s),f=new Array(s);for(i=0;i<s;i++){var p=i?i+1:\"\";h[i]=\"x\"+p,f[i]=\"y\"+p}var d=n(\"xaxes\",h),g=n(\"yaxes\",f),v=e._diag=new Array(s);e._xaxes={},e._yaxes={};var m=[],y=[];function x(t,n,i,a){if(t){var o=t.charAt(0),s=r._splomAxes[o];if(e[\"_\"+o+\"axes\"][t]=1,a.push(t),!(t in s)){var l=s[t]={};i&&(l.label=i.label||\"\",i.visible&&i.axis&&(i.axis.type&&(l.type=i.axis.type),i.axis.matches&&(l.matches=n)))}}}var b=!u&&!c,_=!u&&!l;for(e._axesDim={},i=0;i<s;i++){var w=o[i],k=0===i,T=i===s-1,A=k&&b||T&&_?void 0:d[i],M=k&&_||T&&b?void 0:g[i];x(A,M,w,m),x(M,A,w,y),v[i]=[A,M],e._axesDim[A]=i,e._axesDim[M]=i}for(i=0;i<m.length;i++)for(a=0;a<y.length;a++){var S=m[i]+y[a];i>a&&l?r._splomSubplots[S]=1:i<a&&c?r._splomSubplots[S]=1:i!==a||!u&&c&&l||(r._splomSubplots[S]=1)}(!c||!u&&l&&c)&&(r._splomGridDflt.xside=\"bottom\",r._splomGridDflt.yside=\"left\")}(0,e,h,f),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../parcoords/merge_length\":1083,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"./attributes\":1198}],1202:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scattergl/convert\").markerStyle;e.exports=function(t,e){var r=e.trace,o=t._fullLayout._splomScenes[r.uid];if(o){i(t,r),n.extendFlat(o.matrixOptions,a(r));var s=n.extendFlat({},o.matrixOptions,o.viewOpts);o.matrix.update(s,null)}}},{\"../../lib\":719,\"../scatter/colorscale_calc\":1115,\"../scattergl/convert\":1163}],1203:[function(t,e,r){\"use strict\";r.getDimIndex=function(t,e){for(var r=e._id,n={x:0,y:1}[r.charAt(0)],i=t._visibleDims,a=0;a<i.length;a++){var o=i[a];if(t._diag[o][n]===r)return a}return!1}},{}],1204:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i=t(\"../scattergl/hover\").calcHover;e.exports={hoverPoints:function(t,e,r){var a=t.cd[0].trace,o=t.scene.matrixOptions.cdata,s=t.xa,l=t.ya,c=s.c2p(e),u=l.c2p(r),h=t.distance,f=n.getDimIndex(a,s),p=n.getDimIndex(a,l);if(!1===f||!1===p)return[t];for(var d,g,v=o[f],m=o[p],y=h,x=0;x<v.length;x++){var b=v[x],_=m[x],w=s.c2p(b)-c,k=l.c2p(_)-u,T=Math.sqrt(w*w+k*k);T<y&&(y=g=T,d=x)}return t.index=d,t.distance=y,t.dxy=g,void 0===d?[t]:(i(t,v,m,a),[t])}}},{\"../scattergl/hover\":1166,\"./helpers\":1203}],1205:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../components/grid\");e.exports={moduleType:\"trace\",name:\"splom\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\"),editStyle:t(\"./edit_style\"),meta:{}},n.register(i)},{\"../../components/grid\":636,\"../../registry\":847,\"../scatter/marker_colorbar\":1129,\"./attributes\":1198,\"./base_plot\":1199,\"./calc\":1200,\"./defaults\":1201,\"./edit_style\":1202,\"./hover\":1204,\"./plot\":1206,\"./select\":1208}],1206:[function(t,e,r){\"use strict\";var n=t(\"regl-splom\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\");function o(t,e){var r,o,s,l,c,u=t._fullLayout,h=u._size,f=e.trace,p=e.t,d=u._splomScenes[f.uid],g=d.matrixOptions,v=g.cdata,m=u._glcanvas.data()[0].regl,y=u.dragmode;if(0!==v.length){g.lower=f.showupperhalf,g.upper=f.showlowerhalf,g.diagonal=f.diagonal.visible;var x=f._visibleDims,b=v.length,_=d.viewOpts={};for(_.ranges=new Array(b),_.domains=new Array(b),c=0;c<x.length;c++){s=x[c];var w=_.ranges[c]=new Array(4),k=_.domains[c]=new Array(4);(r=a.getFromId(t,f._diag[s][0]))&&(w[0]=r._rl[0],w[2]=r._rl[1],k[0]=r.domain[0],k[2]=r.domain[1]),(o=a.getFromId(t,f._diag[s][1]))&&(w[1]=o._rl[0],w[3]=o._rl[1],k[1]=o.domain[0],k[3]=o.domain[1])}_.viewport=[h.l,h.b,h.w+h.l,h.h+h.b],!0===d.matrix&&(d.matrix=n(m));var T=u.clickmode.indexOf(\"select\")>-1,A=!0;if(\"lasso\"===y||\"select\"===y||!!f.selectedpoints||T){var M=f._length;if(f.selectedpoints){d.selectBatch=f.selectedpoints;var S=f.selectedpoints,E={};for(s=0;s<S.length;s++)E[S[s]]=!0;var C=[];for(s=0;s<M;s++)E[s]||C.push(s);d.unselectBatch=C}var L=p.xpx=new Array(b),P=p.ypx=new Array(b);for(c=0;c<x.length;c++){if(s=x[c],r=a.getFromId(t,f._diag[s][0]))for(L[c]=new Array(M),l=0;l<M;l++)L[c][l]=r.c2p(v[c][l]);if(o=a.getFromId(t,f._diag[s][1]))for(P[c]=new Array(M),l=0;l<M;l++)P[c][l]=o.c2p(v[c][l])}if(d.selectBatch.length||d.unselectBatch.length){var O=i.extendFlat({},g,d.unselectedOptions,_),z=i.extendFlat({},g,d.selectedOptions,_);d.matrix.update(O,z),A=!1}}else p.xpx=p.ypx=null;if(A){var I=i.extendFlat({},g,_);d.matrix.update(I,null)}}}e.exports=function(t,e,r){if(r.length)for(var n=0;n<r.length;n++)o(t,r[n][0])}},{\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"regl-splom\":501}],1207:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t._fullLayout,i=e.uid,a=r._splomScenes;a||(a=r._splomScenes={});var o={dirty:!0},s=a[e.uid];return s||((s=a[i]=n.extendFlat({},o,{matrix:!1,selectBatch:[],unselectBatch:[]})).draw=function(){s.matrix&&s.matrix.draw&&(s.selectBatch.length||s.unselectBatch.length?s.matrix.draw(s.unselectBatch,s.selectBatch):s.matrix.draw()),s.dirty=!1},s.destroy=function(){s.matrix&&s.matrix.destroy&&s.matrix.destroy(),s.matrixOptions=null,s.selectBatch=null,s.unselectBatch=null,s=null}),s.dirty||n.extendFlat(s,o),s}},{\"../../lib\":719}],1208:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"./helpers\");e.exports=function(t,e){var r=t.cd,o=r[0].trace,s=r[0].t,l=t.scene,c=l.matrixOptions.cdata,u=t.xaxis,h=t.yaxis,f=[];if(!l)return f;var p=!i.hasMarkers(o)&&!i.hasText(o);if(!0!==o.visible||p)return f;var d=a.getDimIndex(o,u),g=a.getDimIndex(o,h);if(!1===d||!1===g)return f;var v=s.xpx[d],m=s.ypx[g],y=c[d],x=c[g],b=[],_=[];if(!1!==e&&!e.degenerate)for(var w=0;w<y.length;w++)e.contains([v[w],m[w]],null,w,t)?(b.push(w),f.push({pointNumber:w,x:y[w],y:x[w]})):_.push(w);var k=l.matrixOptions;return b.length||_.length?l.selectBatch.length||l.unselectBatch.length||l.matrix.update(l.unselectedOptions,n.extendFlat({},k,l.selectedOptions,l.viewOpts)):l.matrix.update(k,null),l.selectBatch=b,l.unselectBatch=_,f}},{\"../../lib\":719,\"../scatter/subtypes\":1135,\"./helpers\":1203}],1209:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},starts:{x:{valType:\"data_array\",editType:\"calc\"},y:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},maxdisplayed:{valType:\"integer\",min:0,dflt:1e3,editType:\"calc\"},sizeref:{valType:\"number\",editType:\"calc\",min:0,dflt:1},text:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:i({editType:\"calc\"},{keys:[\"tubex\",\"tubey\",\"tubez\",\"tubeu\",\"tubev\",\"tubew\",\"norm\",\"divergence\"]})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach(function(t){l[t]=a[t]}),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"divergence\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../mesh3d/attributes\":1053}],1210:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){var r,i,a,o,s=e.u,l=e.v,c=e.w,u=e.x,h=e.y,f=e.z,p=Math.min(u.length,h.length,f.length,s.length,l.length,c.length),d=0;e.starts&&(i=e.starts.x||[],a=e.starts.y||[],o=e.starts.z||[],d=Math.min(i.length,a.length,o.length));var g=0,v=1/0;for(r=0;r<p;r++){var m=s[r],y=l[r],x=c[r],b=Math.sqrt(m*m+y*y+x*x);g=Math.max(g,b),v=Math.min(v,b)}n(t,e,{vals:[v,g],containerStr:\"\",cLetter:\"c\"});var _=-1/0,w=1/0,k=-1/0,T=1/0,A=-1/0,M=1/0;for(r=0;r<p;r++){var S=u[r];_=Math.max(_,S),w=Math.min(w,S);var E=h[r];k=Math.max(k,E),T=Math.min(T,E);var C=f[r];A=Math.max(A,C),M=Math.min(M,C)}for(r=0;r<d;r++){var L=i[r];_=Math.max(_,L),w=Math.min(w,L);var P=a[r];k=Math.max(k,P),T=Math.min(T,P);var O=o[r];A=Math.max(A,O),M=Math.min(M,O)}e._len=p,e._slen=d,e._normMax=g,e._xbnds=[w,_],e._ybnds=[T,k],e._zbnds=[M,A]}},{\"../../components/colorscale/calc\":601}],1211:[function(t,e,r){\"use strict\";var n=t(\"gl-streamtube3d\"),i=n.createTubeMesh,a=t(\"../../lib\"),o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\"),c={xaxis:0,yaxis:1,zaxis:2};function u(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var h=u.prototype;function f(t){return a.distinctVals(t).vals}function p(t){var e=t.length;return e>2?t.slice(1,e-1):2===e?[(t[0]+t[1])/2]:t}function d(t){var e=t.length;return 1===e?[.5,.5]:[t[1]-t[0],t[e-1]-t[e-2]]}function g(t,e){var r=t.fullSceneLayout,i=t.dataScale,u=e._len,h={};function g(t,e){var n=r[e],o=i[c[e]];return a.simpleMap(t,function(t){return n.d2l(t)*o})}h.vectors=l(g(e.u,\"xaxis\"),g(e.v,\"yaxis\"),g(e.w,\"zaxis\"),u);var v=f(e.x.slice(0,u)),m=f(e.y.slice(0,u)),y=f(e.z.slice(0,u));if(v.length*m.length*y.length>u)return{positions:[],cells:[]};var x=g(v,\"xaxis\"),b=g(m,\"yaxis\"),_=g(y,\"zaxis\");if(h.meshgrid=[x,b,_],e.starts){var w=e._slen;h.startingPositions=l(g(e.starts.x.slice(0,w),\"xaxis\"),g(e.starts.y.slice(0,w),\"yaxis\"),g(e.starts.z.slice(0,w),\"zaxis\"))}else{for(var k=b[0],T=p(x),A=p(_),M=new Array(T.length*A.length),S=0,E=0;E<T.length;E++)for(var C=0;C<A.length;C++)M[S++]=[T[E],k,A[C]];h.startingPositions=M}h.colormap=o(e),h.tubeSize=e.sizeref,h.maxLength=e.maxdisplayed;var L=g(e._xbnds,\"xaxis\"),P=g(e._ybnds,\"yaxis\"),O=g(e._zbnds,\"zaxis\"),z=d(x),I=d(b),D=d(_),R=[[L[0]-z[0],P[0]-I[0],O[0]-D[0]],[L[1]+z[1],P[1]+I[1],O[1]+D[1]]],F=n(h,R),B=s(e);F.vertexIntensityBounds=[B.min/e._normMax,B.max/e._normMax];var N=e.lightposition;return F.lightPosition=[N.x,N.y,N.z],F.ambient=e.lighting.ambient,F.diffuse=e.lighting.diffuse,F.specular=e.lighting.specular,F.roughness=e.lighting.roughness,F.fresnel=e.lighting.fresnel,F.opacity=e.opacity,e._pad=F.tubeScale*e.sizeref*2,F}h.handlePick=function(t){var e=this.scene.fullSceneLayout,r=this.scene.dataScale;function n(t,n){var i=e[n],a=r[c[n]];return i.l2c(t)/a}if(t.object===this.mesh){var i=t.data.position,a=t.data.velocity;return t.traceCoordinate=[n(i[0],\"xaxis\"),n(i[1],\"yaxis\"),n(i[2],\"zaxis\"),n(a[0],\"xaxis\"),n(a[1],\"yaxis\"),n(a[2],\"zaxis\"),t.data.intensity*this.data._normMax,t.data.divergence],t.textLabel=this.data.hovertext||this.data.text,!0}},h.update=function(t){this.data=t;var e=g(this.scene,t);this.mesh.update(e)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=g(t,e),a=i(r,n),o=new u(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../plots/gl3d/zip3\":818,\"gl-streamtube3d\":313}],1212:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),h=s(\"x\"),f=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length&&p&&p.length?(s(\"starts.x\"),s(\"starts.y\"),s(\"starts.z\"),s(\"maxdisplayed\"),s(\"sizeref\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":1209}],1213:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"streamtube\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),eventData:function(t,e){return t.tubex=t.x,t.tubey=t.y,t.tubez=t.z,t.tubeu=e.traceCoordinate[3],t.tubev=e.traceCoordinate[4],t.tubew=e.traceCoordinate[5],t.norm=e.traceCoordinate[6],t.divergence=e.traceCoordinate[7],delete t.x,delete t.y,delete t.z,t},meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1209,\"./calc\":1210,\"./convert\":1211,\"./defaults\":1212}],1214:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../plots/domain\").attributes,o=t(\"../pie/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports={labels:{valType:\"data_array\",editType:\"calc\"},parents:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},branchvalues:{valType:\"enumerated\",values:[\"remainder\",\"total\"],dflt:\"remainder\",editType:\"calc\"},level:{valType:\"any\",editType:\"plot\",anim:!0},maxdepth:{valType:\"integer\",editType:\"plot\",dflt:-1},marker:{colors:{valType:\"data_array\",editType:\"calc\"},line:{color:s({},o.marker.line.color,{dflt:null}),width:s({},o.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},leaf:{opacity:{valType:\"number\",editType:\"style\",min:0,max:1,dflt:.7},editType:\"plot\"},text:o.text,textinfo:s({},o.textinfo,{editType:\"plot\",flags:[\"label\",\"text\",\"value\"]}),textfont:o.textfont,hovertext:o.hovertext,hoverinfo:s({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"name\"]}),hovertemplate:i(),insidetextfont:o.insidetextfont,outsidetextfont:o.outsidetextfont,domain:a({name:\"sunburst\",trace:!0,editType:\"calc\"})}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../pie/attributes\":1086}],1215:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=r.name=\"sunburst\";r.plot=function(t,e,r,o){var s=n.getModule(a),l=i(t.calcdata,s)[0];s.plot(t,l,r,o)},r.clean=function(t,e,r,n){var i=n._has&&n._has(a),o=e._has&&e._has(a);i&&!o&&n._sunburstlayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],1216:[function(t,e,r){\"use strict\";var n=t(\"d3-hierarchy\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../pie/calc\").makePullColorFn,s=t(\"../pie/calc\").generateExtendedColors,l=a.isArrayOrTypedArray,c={};r.calc=function(t,e){var r,s,c,u,h,f,p=t._fullLayout,d=e.ids,g=l(d),v=e.labels,m=e.parents,y=e.values,x=l(y),b=[],_={},w={},k=function(t){return t||\"number\"==typeof t},T=function(t){return!x||i(y[t])&&y[t]>=0};g?(r=Math.min(d.length,m.length),s=function(t){return k(d[t])&&T(t)},c=function(t){return String(d[t])}):(r=Math.min(v.length,m.length),s=function(t){return k(v[t])&&T(t)},c=function(t){return String(v[t])}),x&&(r=Math.min(r,y.length));for(var A=0;A<r;A++)if(s(A)){var M=c(A),S=k(m[A])?String(m[A]):\"\",E={i:A,id:M,pid:S,label:k(v[A])?String(v[A]):\"\"};x&&(E.v=+y[A]),b.push(E),h=M,_[u=S]?_[u].push(h):_[u]=[h],w[h]=1}if(_[\"\"]){if(_[\"\"].length>1){for(var C=a.randstr(),L=0;L<b.length;L++)\"\"===b[L].pid&&(b[L].pid=C);b.unshift({hasMultipleRoots:!0,id:C,pid:\"\"})}}else{var P,O=[];for(P in _)w[P]||O.push(P);if(1!==O.length)return a.warn(\"Multiple implied roots, cannot build sunburst hierarchy.\");P=O[0],b.unshift({id:P,pid:\"\",label:P})}try{f=n.stratify().id(function(t){return t.id}).parentId(function(t){return t.pid})(b)}catch(t){return a.warn(\"Failed to build sunburst hierarchy. Error: \"+t.message)}var z=n.hierarchy(f),I=!1;if(x)switch(e.branchvalues){case\"remainder\":z.sum(function(t){return t.data.v});break;case\"total\":z.each(function(t){var e=t.data.data.v;if(t.children&&e<t.children.reduce(function(t,e){return t+e.data.data.v},0))return I=!0,a.warn([\"Total value for node\",t.data.data.id,\"is smaller than the sum of its children.\"].join(\" \"));t.value=e})}else z.count();if(!I){z.sort(function(t,e){return e.value-t.value});var D=e.marker.colors||[],R=o(p._sunburstcolormap);return z.each(function(t){var e=t.data.data,r=e.id;e.color=R(D[e.i],r)}),b[0].hierarchy=z,b}},r.crossTraceCalc=function(t){var e=t._fullLayout,r=t.calcdata,n=e.sunburstcolorway,i=e._sunburstcolormap;e.extendsunburstcolors&&(n=s(n,c));var a=0;function o(t){var e=t.data.data,r=e.id;!1===e.color&&(i[r]?e.color=i[r]:t.parent?t.parent.parent?e.color=t.parent.data.data.color:(i[r]=e.color=n[a%n.length],a++):e.color=\"rgba(0,0,0,0)\")}for(var l=0;l<r.length;l++){var u=r[l][0];\"sunburst\"===u.trace.type&&u.hierarchy&&u.hierarchy.each(o)}}},{\"../../lib\":719,\"../pie/calc\":1088,\"d3-hierarchy\":157,\"fast-isnumeric\":225}],1217:[function(t,e,r){\"use strict\";e.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:\"linear\"}},{}],1218:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}var c=l(\"labels\"),u=l(\"parents\");if(c&&c.length&&u&&u.length){var h=l(\"values\");h&&h.length&&l(\"branchvalues\"),l(\"level\"),l(\"maxdepth\"),l(\"marker.line.width\")&&l(\"marker.line.color\",s.paper_bgcolor),l(\"marker.colors\"),l(\"leaf.opacity\");var f=l(\"text\");l(\"textinfo\",Array.isArray(f)?\"text+label\":\"label\"),l(\"hovertext\"),l(\"hovertemplate\");o(t,e,s,l,\"auto\",{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),a(e,s,l),e._length=null}else e.visible=!1}},{\"../../lib\":719,\"../../plots/domain\":792,\"../bar/defaults\":861,\"./attributes\":1214}],1219:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"sunburst\",basePlotModule:t(\"./base_plot\"),categories:[],animatable:!0,attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\").style,meta:{}}},{\"./attributes\":1214,\"./base_plot\":1215,\"./calc\":1216,\"./defaults\":1218,\"./layout_attributes\":1220,\"./layout_defaults\":1221,\"./plot\":1222,\"./style\":1223}],1220:[function(t,e,r){\"use strict\";e.exports={sunburstcolorway:{valType:\"colorlist\",editType:\"calc\"},extendsunburstcolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1221:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"sunburstcolorway\",e.colorway),r(\"extendsunburstcolors\")}},{\"../../lib\":719,\"./layout_attributes\":1220}],1222:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"d3-hierarchy\"),a=t(\"../../registry\"),o=t(\"../../components/fx\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../lib\"),u=t(\"../../lib/events\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"../../lib/setcursor\"),p=t(\"../../components/fx/helpers\").appendArrayPointValue,d=t(\"../pie/plot\").transformInsideText,g=t(\"../pie/helpers\").formatPieValue,v=t(\"./style\").styleOne,m=t(\"./constants\");function y(t,e,r,a){var o=t._fullLayout,u=a&&a.duration>0,f=n.select(r).selectAll(\"g.slice\"),p=e[0],m=p.trace,y=x(p.hierarchy,m.level),w=m.maxdepth>=0?m.maxdepth:1/0,M=o._size,S=m.domain,E=M.w*(S.x[1]-S.x[0]),C=M.h*(S.y[1]-S.y[0]),L=.5*Math.min(E,C),P=p.cx=M.l+M.w*(S.x[1]+S.x[0])/2,O=p.cy=M.t+M.h*(1-S.y[0])-C/2;if(!y)return f.remove();var z=null,I={};u&&f.each(function(t){I[k(t)]={rpx0:t.rpx0,rpx1:t.rpx1,x0:t.x0,x1:t.x1,transform:t.transform},!z&&_(t)&&(z=t)});var D=function(t){return i.partition().size([2*Math.PI,t.height+1])(t)}(y).descendants(),R=y.height+1,F=0,B=w;p.hasMultipleRoots&&b(y)&&(D=D.slice(1),R-=1,F=1,B+=1),D=D.filter(function(t){return t.y1<=B});var N=Math.min(R,w),j=function(t){return(t-F)/N*L},U=function(t,e){return[t*Math.cos(e),-t*Math.sin(e)]},V=function(t){return c.pathAnnulus(t.rpx0,t.rpx1,t.x0,t.x1,P,O)},q=function(t){return P+t.pxmid[0]*t.transform.rCenter+(t.transform.x||0)},H=function(t){return O+t.pxmid[1]*t.transform.rCenter+(t.transform.y||0)};(f=f.data(D,function(t){return k(t)})).enter().append(\"g\").classed(\"slice\",!0),u?f.exit().transition().each(function(){var t=n.select(this);t.select(\"path.surface\").transition().attrTween(\"d\",function(t){var e=function(t){var e,r=k(t),i=I[r],a=I[k(y)];if(a){var o=t.x1>a.x1?2*Math.PI:0;e=t.rpx1<a.rpx1?{rpx0:0,rpx1:0}:{x0:o,x1:o}}else{var s,l=k(t.parent);f.each(function(t){if(k(t)===l)return s=t});var c,u=s.children;u.forEach(function(t,e){if(k(t)===r)return c=e});var h=u.length,p=n.interpolate(s.x0,s.x1);e={rpx0:L,rpx1:L,x0:p(c/h),x1:p((c+1)/h)}}return n.interpolate(i,e)}(t);return function(t){return V(e(t))}}),t.select(\"g.slicetext\").attr(\"opacity\",0)}).remove():f.exit().remove(),f.order();var G=null;if(u&&z){var Y=k(z);f.each(function(t){null===G&&k(t)===Y&&(G=t.x1)})}var W=f;function X(t){var e=t.parent,r=I[k(e)],i={};if(r){var a=e.children,o=a.indexOf(t),s=a.length,l=n.interpolate(r.x0,r.x1);i.x0=l(o/s),i.x1=l(o/s)}else i.x0=i.x1=0;return i}u&&(W=W.transition().each(\"end\",function(){T(n.select(this),t,{isTransitioning:!1})})),W.each(function(r){var i=n.select(this),a=c.ensureSingle(i,\"path\",\"surface\",function(t){t.style(\"pointer-events\",\"all\")});r.rpx0=j(r.y0),r.rpx1=j(r.y1),r.xmid=(r.x0+r.x1)/2,r.pxmid=U(r.rpx1,r.xmid),r.midangle=-(r.xmid-Math.PI/2),r.halfangle=.5*Math.min(c.angleDelta(r.x0,r.x1)||Math.PI,Math.PI),r.ring=1-r.rpx0/r.rpx1,r.rInscribed=function(t){return 0===t.rpx0&&c.isFullCircle([t.x0,t.x1])?1:Math.max(0,Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2))}(r),u?a.transition().attrTween(\"d\",function(t){var e=function(t){var e,r=I[k(t)],i={x0:t.x0,x1:t.x1,rpx0:t.rpx0,rpx1:t.rpx1};if(r)e=r;else if(z)if(t.parent)if(G){var a=t.x1>G?2*Math.PI:0;e={x0:a,x1:a}}else e={rpx0:L,rpx1:L},c.extendFlat(e,X(t));else e={rpx0:0,rpx1:0};else e={x0:0,x1:0};return n.interpolate(e,i)}(t);return function(t){return V(e(t))}}):a.attr(\"d\",V),i.call(A,t,e).call(T,t,{isTransitioning:t._transitioning}),a.call(v,r,m);var f=c.ensureSingle(i,\"g\",\"slicetext\"),y=c.ensureSingle(f,\"text\",\"\",function(t){t.attr(\"data-notex\",1)});y.text(function(t,e,r){var n=e.textinfo;if(!n||\"none\"===n)return\"\";var i=t.data.data,a=r.separators,o=n.split(\"+\"),s=function(t){return-1!==o.indexOf(t)},l=[];s(\"label\")&&i.label&&l.push(i.label);i.hasOwnProperty(\"v\")&&s(\"value\")&&l.push(g(i.v,a));if(s(\"text\")){var u=c.castOption(e,i.i,\"text\");c.isValidTextValue(u)&&l.push(u)}return l.join(\"<br>\")}(r,m,o)).classed(\"slicetext\",!0).attr(\"text-anchor\",\"middle\").call(l.font,b(r)?function(t,e,r){var n=e.data.data.i,i=c.castOption(t,n,\"outsidetextfont.color\")||c.castOption(t,n,\"textfont.color\")||r.color,a=c.castOption(t,n,\"outsidetextfont.family\")||c.castOption(t,n,\"textfont.family\")||r.family,o=c.castOption(t,n,\"outsidetextfont.size\")||c.castOption(t,n,\"textfont.size\")||r.size;return{color:i,family:a,size:o}}(m,r,o.font):function(t,e,r){var n=e.data.data,i=n.i,a=c.castOption(t,i,\"insidetextfont.color\");!a&&t._input.textfont&&(a=c.castOption(t._input,i,\"textfont.color\"));var o=c.castOption(t,i,\"insidetextfont.family\")||c.castOption(t,i,\"textfont.family\")||r.family,l=c.castOption(t,i,\"insidetextfont.size\")||c.castOption(t,i,\"textfont.size\")||r.size;return{color:a||s.contrast(n.color),family:o,size:l}}(m,r,o.font)).call(h.convertToTspans,t);var x=l.bBox(y.node());r.transform=d(x,r,p),r.translateX=q(r),r.translateY=H(r);var _=function(t,e){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"+(t.transform.scale<1?\"scale(\"+t.transform.scale+\")\":\"\")+(t.transform.rotate?\"rotate(\"+t.transform.rotate+\")\":\"\")+\"translate(\"+-(e.left+e.right)/2+\",\"+-(e.top+e.bottom)/2+\")\"};u?y.transition().attrTween(\"transform\",function(t){var e=function(t){var e,r=I[k(t)],i=t.transform;if(r)e=r;else if(e={rpx1:t.rpx1,transform:{scale:0,rotate:i.rotate,rCenter:i.rCenter,x:i.x,y:i.y}},z)if(t.parent)if(G){var a=t.x1>G?2*Math.PI:0;e.x0=e.x1=a}else c.extendFlat(e,X(t));else e.x0=e.x1=0;else e.x0=e.x1=0;var o=n.interpolate(e.rpx1,t.rpx1),s=n.interpolate(e.x0,t.x0),l=n.interpolate(e.x1,t.x1),u=n.interpolate(e.transform.scale,i.scale),h=n.interpolate(e.transform.rotate,i.rotate),f=0===i.rCenter?3:0===e.transform.rCenter?1/3:1,p=n.interpolate(e.transform.rCenter,i.rCenter);return function(t){var e=o(t),r=s(t),n=l(t),a=function(t){return p(Math.pow(t,f))}(t),c={pxmid:U(e,(r+n)/2),transform:{rCenter:a,x:i.x,y:i.y}},d={rpx1:o(t),translateX:q(c),translateY:H(c),transform:{scale:u(t),rotate:h(t),rCenter:a}};return d}}(t);return function(t){return _(e(t),x)}}):y.attr(\"transform\",_(r,x))})}function x(t,e){var r;return e&&t.eachAfter(function(t){if(k(t)===e)return r=t.copy()}),r||t}function b(t){return\"\"===t.data.data.pid}function _(t){return!t.parent}function w(t){return!t.children}function k(t){return t.data.data.id}function T(t,e,r){var n=t.datum(),i=(r||{}).isTransitioning;f(t,i||w(n)||b(n)?null:\"pointer\")}function A(t,e,r){var i=r[0],s=i.trace;\"_hasHoverLabel\"in s||(s._hasHoverLabel=!1),\"_hasHoverEvent\"in s||(s._hasHoverEvent=!1),t.on(\"mouseover\",function(t){var r=e._fullLayout;if(!e._dragging&&!1!==r.hovermode){var a=e._fullData[s.index],l=t.data.data,u=l.i,h=function(t){return c.castOption(a,u,t)},f=h(\"hovertemplate\"),p=o.castHoverinfo(a,r,u),d=r.separators;if(f||p&&\"none\"!==p&&\"skip\"!==p){var v=t.rInscribed,m=i.cx+t.pxmid[0]*(1-v),y=i.cy+t.pxmid[1]*(1-v),x={},b=[],_=[],w=function(t){return-1!==b.indexOf(t)};if(p&&(b=\"all\"===p?a._module.attributes.hoverinfo.flags:p.split(\"+\")),x.label=l.label,w(\"label\")&&x.label&&_.push(x.label),l.hasOwnProperty(\"v\")&&(x.value=l.v,x.valueLabel=g(x.value,d),w(\"value\")&&_.push(x.valueLabel)),x.text=h(\"hovertext\")||h(\"text\"),w(\"text\")){var k=x.text;c.isValidTextValue(k)&&_.push(k)}o.loneHover({trace:a,x0:m-v*t.rpx1,x1:m+v*t.rpx1,y:y,idealAlign:t.pxmid[0]<0?\"left\":\"right\",text:_.join(\"<br>\"),name:f||w(\"name\")?a.name:void 0,color:h(\"hoverlabel.bgcolor\")||l.color,borderColor:h(\"hoverlabel.bordercolor\"),fontFamily:h(\"hoverlabel.font.family\"),fontSize:h(\"hoverlabel.font.size\"),fontColor:h(\"hoverlabel.font.color\"),nameLength:h(\"hoverlabel.namelength\"),textAlign:h(\"hoverlabel.align\"),hovertemplate:f,hovertemplateLabels:x,eventData:[M(t,a)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e}),s._hasHoverLabel=!0}s._hasHoverEvent=!0,e.emit(\"plotly_hover\",{points:[M(t,a)],event:n.event})}}),t.on(\"mouseout\",function(t){var r=e._fullLayout,i=e._fullData[s.index],a=n.select(this).datum();s._hasHoverEvent&&(t.originalEvent=n.event,e.emit(\"plotly_unhover\",{points:[M(a,i)],event:n.event}),s._hasHoverEvent=!1),s._hasHoverLabel&&(o.loneUnhover(r._hoverlayer.node()),s._hasHoverLabel=!1)}),t.on(\"click\",function(t){var r=e._fullLayout,l=e._fullData[s.index];if(!1===u.triggerHandler(e,\"plotly_sunburstclick\",{points:[M(t,l)],event:n.event})||w(t)||b(t))r.hovermode&&(e._hoverdata=[M(t,l)],o.click(e,n.event));else if(!e._dragging&&!e._transitioning){a.call(\"_storeDirectGUIEdit\",l,r._tracePreGUI[l.uid],{level:l.level});var c=i.hierarchy,h=k(t),f=_(t)?function(t,e){var r;return t.eachAfter(function(t){for(var n=t.children||[],i=0;i<n.length;i++)if(k(n[i])===e)return r=t.copy()}),r||t}(c,h):x(c,h),p={data:[{level:k(f)}],traces:[s.index]},d={frame:{redraw:!1,duration:m.CLICK_TRANSITION_TIME},transition:{duration:m.CLICK_TRANSITION_TIME,easing:m.CLICK_TRANSITION_EASING},mode:\"immediate\",fromcurrent:!0};o.loneUnhover(r._hoverlayer.node()),a.call(\"animate\",e,p,d)}})}function M(t,e){var r=t.data.data,n={curveNumber:e.index,pointNumber:r.i,data:e._input,fullData:e};return p(n,e,r.i),n}e.exports=function(t,e,r,i){var a,o,s=t._fullLayout._sunburstlayer,l=!r,c=r&&r.duration>0;((a=s.selectAll(\"g.trace.sunburst\").data(e,function(t){return t[0].trace.uid})).enter().append(\"g\").classed(\"trace\",!0).classed(\"sunburst\",!0).attr(\"stroke-linejoin\",\"round\"),a.order(),c)?(i&&(o=i()),n.transition().duration(r.duration).ease(r.easing).each(\"end\",function(){o&&o()}).each(\"interrupt\",function(){o&&o()}).each(function(){s.selectAll(\"g.trace\").each(function(e){y(t,e,this,r)})})):a.each(function(e){y(t,e,this,r)});l&&a.exit().remove()}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../components/fx/helpers\":628,\"../../lib\":719,\"../../lib/events\":709,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../registry\":847,\"../pie/helpers\":1091,\"../pie/plot\":1095,\"./constants\":1217,\"./style\":1223,d3:163,\"d3-hierarchy\":157}],1223:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../lib\");function o(t,e,r){var n=e.data.data,o=!e.children,s=n.i,l=a.castOption(r,s,\"marker.line.color\")||i.defaultLine,c=a.castOption(r,s,\"marker.line.width\")||0;t.style(\"stroke-width\",c).call(i.fill,n.color).call(i.stroke,l).style(\"opacity\",o?r.leaf.opacity:null)}e.exports={style:function(t){t._fullLayout._sunburstlayer.selectAll(\".trace\").each(function(t){var e=n.select(this),r=t[0].trace;e.style(\"opacity\",r.opacity),e.selectAll(\"path.surface\").each(function(t){n.select(this).call(o,t,r)})})},styleOne:o}},{\"../../components/color\":593,\"../../lib\":719,d3:163}],1224:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;function c(t){return{show:{valType:\"boolean\",dflt:!1},start:{valType:\"number\",dflt:null,editType:\"plot\"},end:{valType:\"number\",dflt:null,editType:\"plot\"},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\"},project:{x:{valType:\"boolean\",dflt:!1},y:{valType:\"boolean\",dflt:!1},z:{valType:\"boolean\",dflt:!1}},color:{valType:\"color\",dflt:n.defaultLine},usecolormap:{valType:\"boolean\",dflt:!1},width:{valType:\"number\",min:1,max:16,dflt:2},highlight:{valType:\"boolean\",dflt:!0},highlightcolor:{valType:\"color\",dflt:n.defaultLine},highlightwidth:{valType:\"number\",min:1,max:16,dflt:2}}}var u=e.exports=l(s({z:{valType:\"data_array\"},x:{valType:\"data_array\"},y:{valType:\"data_array\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:a(),connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},surfacecolor:{valType:\"data_array\"}},i(\"\",{colorAttr:\"z or surfacecolor\",showScaleDflt:!0,autoColorDflt:!1,editTypeOverride:\"calc\"}),{contours:{x:c(),y:c(),z:c()},hidesurface:{valType:\"boolean\",dflt:!1},lightposition:{x:{valType:\"number\",min:-1e5,max:1e5,dflt:10},y:{valType:\"number\",min:-1e5,max:1e5,dflt:1e4},z:{valType:\"number\",min:-1e5,max:1e5,dflt:0}},lighting:{ambient:{valType:\"number\",min:0,max:1,dflt:.8},diffuse:{valType:\"number\",min:0,max:1,dflt:.8},specular:{valType:\"number\",min:0,max:2,dflt:.05},roughness:{valType:\"number\",min:0,max:1,dflt:.5},fresnel:{valType:\"number\",min:0,max:5,dflt:.2}},opacity:{valType:\"number\",min:0,max:1,dflt:1},_deprecated:{zauto:s({},i.zauto,{}),zmin:s({},i.zmin,{}),zmax:s({},i.zmax,{})},hoverinfo:s({},o.hoverinfo)}),\"calc\",\"nested\");u.x.editType=u.y.editType=u.z.editType=\"calc+clearAxisTypes\",u.transforms=void 0},{\"../../components/color\":593,\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764}],1225:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.surfacecolor?n(t,e,{vals:e.surfacecolor,containerStr:\"\",cLetter:\"c\"}):n(t,e,{vals:e.z,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],1226:[function(t,e,r){\"use strict\";var n=t(\"gl-surface3d\"),i=t(\"ndarray\"),a=t(\"ndarray-homography\"),o=t(\"ndarray-fill\"),s=t(\"../../lib\").isArrayOrTypedArray,l=t(\"../../lib/gl_format_color\").parseColorScale,c=t(\"../../lib/str2rgbarray\"),u=t(\"../../components/colorscale\").extractOpts,h=t(\"../heatmap/interp2d\"),f=t(\"../heatmap/find_empties\");function p(t,e,r){this.scene=t,this.uid=r,this.surface=e,this.data=null,this.showContour=[!1,!1,!1],this.contourStart=[null,null,null],this.contourEnd=[null,null,null],this.contourSize=[0,0,0],this.minValues=[1/0,1/0,1/0],this.maxValues=[-1/0,-1/0,-1/0],this.dataScaleX=1,this.dataScaleY=1,this.refineData=!0,this.objectOffset=[0,0,0]}var d=p.prototype;d.getXat=function(t,e,r,n){var i=s(this.data.x)?s(this.data.x[0])?this.data.x[e][t]:this.data.x[t]:t;return void 0===r?i:n.d2l(i,0,r)},d.getYat=function(t,e,r,n){var i=s(this.data.y)?s(this.data.y[0])?this.data.y[e][t]:this.data.y[e]:e;return void 0===r?i:n.d2l(i,0,r)},d.getZat=function(t,e,r,n){var i=this.data.z[e][t];return null===i&&this.data.connectgaps&&this.data._interpolatedZ&&(i=this.data._interpolatedZ[e][t]),void 0===r?i:n.d2l(i,0,r)},d.handlePick=function(t){if(t.object===this.surface){var e=(t.data.index[0]-1)/this.dataScaleX-1,r=(t.data.index[1]-1)/this.dataScaleY-1,n=Math.max(Math.min(Math.round(e),this.data.z[0].length-1),0),i=Math.max(Math.min(Math.round(r),this.data._ylength-1),0);t.index=[n,i],t.traceCoordinate=[this.getXat(n,i),this.getYat(n,i),this.getZat(n,i)],t.dataCoordinate=[this.getXat(n,i,this.data.xcalendar,this.scene.fullSceneLayout.xaxis),this.getYat(n,i,this.data.ycalendar,this.scene.fullSceneLayout.yaxis),this.getZat(n,i,this.data.zcalendar,this.scene.fullSceneLayout.zaxis)];for(var a=0;a<3;a++){var o=t.dataCoordinate[a];null!=o&&(t.dataCoordinate[a]*=this.scene.dataScale[a])}var s=this.data.hovertext||this.data.text;return Array.isArray(s)&&s[i]&&void 0!==s[i][n]?t.textLabel=s[i][n]:t.textLabel=s||\"\",t.data.dataCoordinate=t.dataCoordinate.slice(),this.surface.highlight(t.data),this.scene.glplot.spikes.position=t.dataCoordinate,!0}};var g=[2,3,5,7,11,13,17,19,23,29,31,37,41,43,47,53,59,61,67,71,73,79,83,89,97,101,103,107,109,113,127,131,137,139,149,151,157,163,167,173,179,181,191,193,197,199,211,223,227,229,233,239,241,251,257,263,269,271,277,281,283,293,307,311,313,317,331,337,347,349,353,359,367,373,379,383,389,397,401,409,419,421,431,433,439,443,449,457,461,463,467,479,487,491,499,503,509,521,523,541,547,557,563,569,571,577,587,593,599,601,607,613,617,619,631,641,643,647,653,659,661,673,677,683,691,701,709,719,727,733,739,743,751,757,761,769,773,787,797,809,811,821,823,827,829,839,853,857,859,863,877,881,883,887,907,911,919,929,937,941,947,953,967,971,977,983,991,997,1009,1013,1019,1021,1031,1033,1039,1049,1051,1061,1063,1069,1087,1091,1093,1097,1103,1109,1117,1123,1129,1151,1153,1163,1171,1181,1187,1193,1201,1213,1217,1223,1229,1231,1237,1249,1259,1277,1279,1283,1289,1291,1297,1301,1303,1307,1319,1321,1327,1361,1367,1373,1381,1399,1409,1423,1427,1429,1433,1439,1447,1451,1453,1459,1471,1481,1483,1487,1489,1493,1499,1511,1523,1531,1543,1549,1553,1559,1567,1571,1579,1583,1597,1601,1607,1609,1613,1619,1621,1627,1637,1657,1663,1667,1669,1693,1697,1699,1709,1721,1723,1733,1741,1747,1753,1759,1777,1783,1787,1789,1801,1811,1823,1831,1847,1861,1867,1871,1873,1877,1879,1889,1901,1907,1913,1931,1933,1949,1951,1973,1979,1987,1993,1997,1999,2003,2011,2017,2027,2029,2039,2053,2063,2069,2081,2083,2087,2089,2099,2111,2113,2129,2131,2137,2141,2143,2153,2161,2179,2203,2207,2213,2221,2237,2239,2243,2251,2267,2269,2273,2281,2287,2293,2297,2309,2311,2333,2339,2341,2347,2351,2357,2371,2377,2381,2383,2389,2393,2399,2411,2417,2423,2437,2441,2447,2459,2467,2473,2477,2503,2521,2531,2539,2543,2549,2551,2557,2579,2591,2593,2609,2617,2621,2633,2647,2657,2659,2663,2671,2677,2683,2687,2689,2693,2699,2707,2711,2713,2719,2729,2731,2741,2749,2753,2767,2777,2789,2791,2797,2801,2803,2819,2833,2837,2843,2851,2857,2861,2879,2887,2897,2903,2909,2917,2927,2939,2953,2957,2963,2969,2971,2999];function v(t,e){if(t<e)return 0;for(var r=0;0===Math.floor(t%e);)t/=e,r++;return r}function m(t){for(var e=[],r=0;r<g.length;r++){var n=g[r];e.push(v(t,n))}return e}function y(t){for(var e=m(t),r=t,n=0;n<g.length;n++)if(e[n]>0){r=g[n];break}return r}function x(t,e){if(!(t<1||e<1)){for(var r=m(t),n=m(e),i=1,a=0;a<g.length;a++)i*=Math.pow(g[a],Math.max(r[a],n[a]));return i}}d.calcXnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getXat(e-1,0),i=this.getXat(e,0);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r},d.calcYnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getYat(0,e-1),i=this.getYat(0,e);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r};var b=[1,2,4,6,12,24,36,48,60,120,180,240,360,720,840,1260],_=b[9],w=b[13];function k(t,e){for(var r=!1,n=0;n<t.length;n++)if(e===t[n]){r=!0;break}!1===r&&t.push(e)}d.estimateScale=function(t,e){for(var r=1+function(t){if(0!==t.length){for(var e=1,r=0;r<t.length;r++)e=x(e,t[r]);return e}}(0===e?this.calcXnums(t):this.calcYnums(t));r<_;)r*=2;for(;r>w;)r--,r/=y(r),++r<_&&(r=w);var n=Math.round(r/t);return n>1?n:1},d.refineCoords=function(t){for(var e=this.dataScaleX,r=this.dataScaleY,n=t[0].shape[0],o=t[0].shape[1],s=0|Math.floor(t[0].shape[0]*e+1),l=0|Math.floor(t[0].shape[1]*r+1),c=1+n+1,u=1+o+1,h=i(new Float32Array(c*u),[c,u]),f=0;f<t.length;++f){this.surface.padField(h,t[f]);var p=i(new Float32Array(s*l),[s,l]);a(p,h,[e,0,0,0,r,0,0,0,1]),t[f]=p}},d.setContourLevels=function(){var t,e,r,n=[[],[],[]],i=[!1,!1,!1],a=!1;for(t=0;t<3;++t)if(this.showContour[t]&&(a=!0,this.contourSize[t]>0&&null!==this.contourStart[t]&&null!==this.contourEnd[t]&&this.contourEnd[t]>this.contourStart[t]))for(i[t]=!0,e=this.contourStart[t];e<this.contourEnd[t];e+=this.contourSize[t])r=e*this.scene.dataScale[t],k(n[t],r);if(a){var o=[[],[],[]];for(t=0;t<3;++t)this.showContour[t]&&(o[t]=i[t]?n[t]:this.scene.contourLevels[t]);this.surface.update({levels:o})}},d.update=function(t){var e,r,n,a,s=this.scene,p=s.fullSceneLayout,d=this.surface,g=t.opacity,v=l(t,g),m=s.dataScale,y=t.z[0].length,x=t._ylength,b=s.contourLevels;this.data=t;var _=[];for(e=0;e<3;e++)for(_[e]=[],r=0;r<y;r++)_[e][r]=[];for(r=0;r<y;r++)for(n=0;n<x;n++)_[0][r][n]=this.getXat(r,n,t.xcalendar,p.xaxis),_[1][r][n]=this.getYat(r,n,t.ycalendar,p.yaxis),_[2][r][n]=this.getZat(r,n,t.zcalendar,p.zaxis);if(t.connectgaps)for(t._emptypoints=f(_[2]),h(_[2],t._emptypoints),t._interpolatedZ=[],r=0;r<y;r++)for(t._interpolatedZ[r]=[],n=0;n<x;n++)t._interpolatedZ[r][n]=_[2][r][n];for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null==(a=_[e][r][n])?_[e][r][n]=NaN:a=_[e][r][n]*=m[e];for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null!=(a=_[e][r][n])&&(this.minValues[e]>a&&(this.minValues[e]=a),this.maxValues[e]<a&&(this.maxValues[e]=a));for(e=0;e<3;e++)this.objectOffset[e]=.5*(this.minValues[e]+this.maxValues[e]);for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null!=(a=_[e][r][n])&&(_[e][r][n]-=this.objectOffset[e]);var k=[i(new Float32Array(y*x),[y,x]),i(new Float32Array(y*x),[y,x]),i(new Float32Array(y*x),[y,x])];o(k[0],function(t,e){return _[0][t][e]}),o(k[1],function(t,e){return _[1][t][e]}),o(k[2],function(t,e){return _[2][t][e]}),_=[];var T={colormap:v,levels:[[],[],[]],showContour:[!0,!0,!0],showSurface:!t.hidesurface,contourProject:[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],contourWidth:[1,1,1],contourColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],contourTint:[1,1,1],dynamicColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],dynamicWidth:[1,1,1],dynamicTint:[1,1,1],opacity:t.opacity},A=u(t);if(T.intensityBounds=[A.min,A.max],t.surfacecolor){var M=i(new Float32Array(y*x),[y,x]);o(M,function(e,r){return t.surfacecolor[r][e]}),k.push(M)}else T.intensityBounds[0]*=m[2],T.intensityBounds[1]*=m[2];(w<k[0].shape[0]||w<k[0].shape[1])&&(this.refineData=!1),!0===this.refineData&&(this.dataScaleX=this.estimateScale(k[0].shape[0],0),this.dataScaleY=this.estimateScale(k[0].shape[1],1),1===this.dataScaleX&&1===this.dataScaleY||this.refineCoords(k)),t.surfacecolor&&(T.intensity=k.pop());var S=[!0,!0,!0],E=[\"x\",\"y\",\"z\"];for(e=0;e<3;++e){var C=t.contours[E[e]];S[e]=C.highlight,T.showContour[e]=C.show||C.highlight,T.showContour[e]&&(T.contourProject[e]=[C.project.x,C.project.y,C.project.z],C.show?(this.showContour[e]=!0,T.levels[e]=b[e],d.highlightColor[e]=T.contourColor[e]=c(C.color),C.usecolormap?d.highlightTint[e]=T.contourTint[e]=0:d.highlightTint[e]=T.contourTint[e]=1,T.contourWidth[e]=C.width,this.contourStart[e]=C.start,this.contourEnd[e]=C.end,this.contourSize[e]=C.size):(this.showContour[e]=!1,this.contourStart[e]=null,this.contourEnd[e]=null,this.contourSize[e]=0),C.highlight&&(T.dynamicColor[e]=c(C.highlightcolor),T.dynamicWidth[e]=C.highlightwidth))}(function(t){var e=t[0].rgb,r=t[t.length-1].rgb;return e[0]===r[0]&&e[1]===r[1]&&e[2]===r[2]&&e[3]===r[3]})(v)&&(T.vertexColor=!0),T.objectOffset=this.objectOffset,T.coords=k,d.update(T),d.visible=t.visible,d.enableDynamic=S,d.enableHighlight=S,d.snapToData=!0,\"lighting\"in t&&(d.ambientLight=t.lighting.ambient,d.diffuseLight=t.lighting.diffuse,d.specularLight=t.lighting.specular,d.roughness=t.lighting.roughness,d.fresnel=t.lighting.fresnel),\"lightposition\"in t&&(d.lightPosition=[t.lightposition.x,t.lightposition.y,t.lightposition.z]),g&&g<1&&(d.supportsTransparency=!0)},d.dispose=function(){this.scene.glplot.remove(this.surface),this.surface.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new p(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../heatmap/find_empties\":1007,\"../heatmap/interp2d\":1010,\"gl-surface3d\":316,ndarray:450,\"ndarray-fill\":440,\"ndarray-homography\":442}],1227:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");function s(t,e,r){e in t&&!(r in t)&&(t[r]=t[e])}e.exports=function(t,e,r,l){var c,u;function h(r,n){return i.coerce(t,e,o,r,n)}var f=h(\"x\"),p=h(\"y\"),d=h(\"z\");if(!d||!d.length||f&&f.length<1||p&&p.length<1)e.visible=!1;else{e._xlength=Array.isArray(f)&&i.isArrayOrTypedArray(f[0])?d.length:d[0].length,e._ylength=d.length,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],l),h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"hidesurface\",\"connectgaps\",\"opacity\"].forEach(function(t){h(t)});var g=h(\"surfacecolor\"),v=[\"x\",\"y\",\"z\"];for(c=0;c<3;++c){var m=\"contours.\"+v[c],y=h(m+\".show\"),x=h(m+\".highlight\");if(y||x)for(u=0;u<3;++u)h(m+\".project.\"+v[u]);y&&(h(m+\".color\"),h(m+\".width\"),h(m+\".usecolormap\")),x&&(h(m+\".highlightcolor\"),h(m+\".highlightwidth\")),h(m+\".start\"),h(m+\".end\"),h(m+\".size\")}g||(s(t,\"zmin\",\"cmin\"),s(t,\"zmax\",\"cmax\"),s(t,\"zauto\",\"cauto\")),a(t,e,l,h,{prefix:\"\",cLetter:\"c\"}),e._length=null}}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../../registry\":847,\"./attributes\":1224}],1228:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"surface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"2dMap\",\"noOpacity\"],meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1224,\"./calc\":1225,\"./convert\":1226,\"./defaults\":1227}],1229:[function(t,e,r){\"use strict\";var n=t(\"../../components/annotations/attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../plots/domain\").attributes;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=a({domain:s({name:\"table\",trace:!0}),columnwidth:{valType:\"number\",arrayOk:!0,dflt:null},columnorder:{valType:\"data_array\"},header:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:28},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))},cells:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:20},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))}},\"calc\",\"from-root\")).transforms=void 0},{\"../../components/annotations/attributes\":576,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1230:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"table\",r.plot=function(t){var e=n(t.calcdata,\"table\")[0];e.length&&i(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"table\"),a=e._has&&e._has(\"table\");i&&!a&&n._paperdiv.selectAll(\".table\").remove()}},{\"../../plots/get_data\":802,\"./plot\":1237}],1231:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap;e.exports=function(){return n({})}},{\"../../lib/gup\":717}],1232:[function(t,e,r){\"use strict\";e.exports={cellPad:8,columnExtentOffset:10,columnTitleOffset:28,emptyHeaderHeight:16,latexCheck:/^\\$.*\\$$/,goldenRatio:1.618,lineBreaker:\"<br>\",maxDimensionCount:60,overdrag:45,releaseTransitionDuration:120,releaseTransitionEase:\"cubic-out\",scrollbarCaptureWidth:18,scrollbarHideDelay:1e3,scrollbarHideDuration:1e3,scrollbarOffset:5,scrollbarWidth:8,transitionDuration:100,transitionEase:\"cubic-out\",uplift:5,wrapSpacer:\" \",wrapSplitCharacter:\" \",cn:{table:\"table\",tableControlView:\"table-control-view\",scrollBackground:\"scroll-background\",yColumn:\"y-column\",columnBlock:\"column-block\",scrollAreaClip:\"scroll-area-clip\",scrollAreaClipRect:\"scroll-area-clip-rect\",columnBoundary:\"column-boundary\",columnBoundaryClippath:\"column-boundary-clippath\",columnBoundaryRect:\"column-boundary-rect\",columnCells:\"column-cells\",columnCell:\"column-cell\",cellRect:\"cell-rect\",cellText:\"cell-text\",cellTextHolder:\"cell-text-holder\",scrollbarKit:\"scrollbar-kit\",scrollbar:\"scrollbar\",scrollbarSlider:\"scrollbar-slider\",scrollbarGlyph:\"scrollbar-glyph\",scrollbarCaptureZone:\"scrollbar-capture-zone\"}}},{}],1233:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"fast-isnumeric\");function o(t){if(Array.isArray(t)){for(var e=0,r=0;r<t.length;r++)e=Math.max(e,o(t[r]));return e}return t}function s(t,e){return t+e}function l(t){var e,r=t.slice(),n=1/0,i=0;for(e=0;e<r.length;e++)Array.isArray(r[e])||(r[e]=[r[e]]),n=Math.min(n,r[e].length),i=Math.max(i,r[e].length);if(n!==i)for(e=0;e<r.length;e++){var a=i-r[e].length;a&&(r[e]=r[e].concat(c(a)))}return r}function c(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=\"\";return e}function u(t){return t.calcdata.columns.reduce(function(e,r){return r.xIndex<t.xIndex?e+r.columnWidth:e},0)}function h(t,e){return Object.keys(t).map(function(r){return i({},t[r],{auxiliaryBlocks:e})})}function f(t,e){for(var r,n={},i=0,a=0,o={firstRowIndex:null,lastRowIndex:null,rows:[]},s=0,l=0,c=0;c<t.length;c++)r=t[c],o.rows.push({rowIndex:c,rowHeight:r}),((a+=r)>=e||c===t.length-1)&&(n[i]=o,o.key=l++,o.firstRowIndex=s,o.lastRowIndex=c,o={firstRowIndex:null,lastRowIndex:null,rows:[]},i+=a,s=c+1,a=0);return n}e.exports=function(t,e){var r=l(e.cells.values),p=function(t){return t.slice(e.header.values.length,t.length)},d=l(e.header.values);d.length&&!d[0].length&&(d[0]=[\"\"],d=l(d));var g=d.concat(p(r).map(function(){return c((d[0]||[\"\"]).length)})),v=e.domain,m=Math.floor(t._fullLayout._size.w*(v.x[1]-v.x[0])),y=Math.floor(t._fullLayout._size.h*(v.y[1]-v.y[0])),x=e.header.values.length?g[0].map(function(){return e.header.height}):[n.emptyHeaderHeight],b=r.length?r[0].map(function(){return e.cells.height}):[],_=x.reduce(s,0),w=f(b,y-_+n.uplift),k=h(f(x,_),[]),T=h(w,k),A={},M=e._fullInput.columnorder.concat(p(r.map(function(t,e){return e}))),S=g.map(function(t,r){var n=Array.isArray(e.columnwidth)?e.columnwidth[Math.min(r,e.columnwidth.length-1)]:e.columnwidth;return a(n)?Number(n):1}),E=S.reduce(s,0);S=S.map(function(t){return t/E*m});var C=Math.max(o(e.header.line.width),o(e.cells.line.width)),L={key:e.uid+t._context.staticPlot,translateX:v.x[0]*t._fullLayout._size.w,translateY:t._fullLayout._size.h*(1-v.y[1]),size:t._fullLayout._size,width:m,maxLineWidth:C,height:y,columnOrder:M,groupHeight:y,rowBlocks:T,headerRowBlocks:k,scrollY:0,cells:i({},e.cells,{values:r}),headerCells:i({},e.header,{values:g}),gdColumns:g.map(function(t){return t[0]}),gdColumnsOriginalOrder:g.map(function(t){return t[0]}),prevPages:[0,0],scrollbarState:{scrollbarScrollInProgress:!1},columns:g.map(function(t,e){var r=A[t];return A[t]=(r||0)+1,{key:t+\"__\"+A[t],label:t,specIndex:e,xIndex:M[e],xScale:u,x:void 0,calcdata:void 0,columnWidth:S[e]}})};return L.columns.forEach(function(t){t.calcdata=L,t.x=u(t)}),L}},{\"../../lib/extend\":710,\"./constants\":1232,\"fast-isnumeric\":225}],1234:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat;r.splitToPanels=function(t){var e=[0,0],r=n({},t,{key:\"header\",type:\"header\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!0,values:t.calcdata.headerCells.values[t.specIndex],rowBlocks:t.calcdata.headerRowBlocks,calcdata:n({},t.calcdata,{cells:t.calcdata.headerCells})});return[n({},t,{key:\"cells1\",type:\"cells\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),n({},t,{key:\"cells2\",type:\"cells\",page:1,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),r]},r.splitToCells=function(t){var e=function(t){var e=t.rowBlocks[t.page],r=e?e.rows[0].rowIndex:0,n=e?r+e.rows.length:0;return[r,n]}(t);return(t.values||[]).slice(e[0],e[1]).map(function(r,n){return{keyWithinBlock:n+(\"string\"==typeof r&&r.match(/[<$&> ]/)?\"_keybuster_\"+Math.random():\"\"),key:e[0]+n,column:t,calcdata:t.calcdata,page:t.page,rowBlocks:t.rowBlocks,value:r}})}},{\"../../lib/extend\":710}],1235:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults;e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}a(e,o,s),s(\"columnwidth\"),s(\"header.values\"),s(\"header.format\"),s(\"header.align\"),s(\"header.prefix\"),s(\"header.suffix\"),s(\"header.height\"),s(\"header.line.width\"),s(\"header.line.color\"),s(\"header.fill.color\"),n.coerceFont(s,\"header.font\",n.extendFlat({},o.font)),function(t,e){for(var r=t.columnorder||[],n=t.header.values.length,i=r.slice(0,n),a=i.slice().sort(function(t,e){return t-e}),o=i.map(function(t){return a.indexOf(t)}),s=o.length;s<n;s++)o.push(s);e(\"columnorder\",o)}(e,s),s(\"cells.values\"),s(\"cells.format\"),s(\"cells.align\"),s(\"cells.prefix\"),s(\"cells.suffix\"),s(\"cells.height\"),s(\"cells.line.width\"),s(\"cells.line.color\"),s(\"cells.fill.color\"),n.coerceFont(s,\"cells.font\",n.extendFlat({},o.font)),e._length=null}},{\"../../lib\":719,\"../../plots/domain\":792,\"./attributes\":1229}],1236:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"table\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1229,\"./base_plot\":1230,\"./calc\":1231,\"./defaults\":1235,\"./plot\":1237}],1237:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\"),o=t(\"../../components/drawing\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../lib\").raiseToTop,c=t(\"../../lib\").cancelTransition,u=t(\"./data_preparation_helper\"),h=t(\"./data_split_helpers\"),f=t(\"../../components/color\");function p(t){return Math.ceil(t.calcdata.maxLineWidth/2)}function d(t,e){return\"clip\"+t._fullLayout._uid+\"_scrollAreaBottomClip_\"+e.key}function g(t,e){return\"clip\"+t._fullLayout._uid+\"_columnBoundaryClippath_\"+e.calcdata.key+\"_\"+e.specIndex}function v(t){return[].concat.apply([],t.map(function(t){return t})).map(function(t){return t.__data__})}function m(t,e,r){var o=t.selectAll(\".\"+n.cn.scrollbarKit).data(a.repeat,a.keyFun);o.enter().append(\"g\").classed(n.cn.scrollbarKit,!0).style(\"shape-rendering\",\"geometricPrecision\"),o.each(function(t){var e=t.scrollbarState;e.totalHeight=function(t){var e=t.rowBlocks;return z(e,e.length-1)+(e.length?I(e[e.length-1],1/0):1)}(t),e.scrollableAreaHeight=t.groupHeight-A(t),e.currentlyVisibleHeight=Math.min(e.totalHeight,e.scrollableAreaHeight),e.ratio=e.currentlyVisibleHeight/e.totalHeight,e.barLength=Math.max(e.ratio*e.currentlyVisibleHeight,n.goldenRatio*n.scrollbarWidth),e.barWiggleRoom=e.currentlyVisibleHeight-e.barLength,e.wiggleRoom=Math.max(0,e.totalHeight-e.scrollableAreaHeight),e.topY=0===e.barWiggleRoom?0:t.scrollY/e.wiggleRoom*e.barWiggleRoom,e.bottomY=e.topY+e.barLength,e.dragMultiplier=e.wiggleRoom/e.barWiggleRoom}).attr(\"transform\",function(t){return\"translate(\"+(t.width+n.scrollbarWidth/2+n.scrollbarOffset)+\" \"+A(t)+\")\"});var s=o.selectAll(\".\"+n.cn.scrollbar).data(a.repeat,a.keyFun);s.enter().append(\"g\").classed(n.cn.scrollbar,!0);var l=s.selectAll(\".\"+n.cn.scrollbarSlider).data(a.repeat,a.keyFun);l.enter().append(\"g\").classed(n.cn.scrollbarSlider,!0),l.attr(\"transform\",function(t){return\"translate(0 \"+(t.scrollbarState.topY||0)+\")\"});var c=l.selectAll(\".\"+n.cn.scrollbarGlyph).data(a.repeat,a.keyFun);c.enter().append(\"line\").classed(n.cn.scrollbarGlyph,!0).attr(\"stroke\",\"black\").attr(\"stroke-width\",n.scrollbarWidth).attr(\"stroke-linecap\",\"round\").attr(\"y1\",n.scrollbarWidth/2),c.attr(\"y2\",function(t){return t.scrollbarState.barLength-n.scrollbarWidth/2}).attr(\"stroke-opacity\",function(t){return t.columnDragInProgress||!t.scrollbarState.barWiggleRoom||r?0:.4}),c.transition().delay(0).duration(0),c.transition().delay(n.scrollbarHideDelay).duration(n.scrollbarHideDuration).attr(\"stroke-opacity\",0);var u=s.selectAll(\".\"+n.cn.scrollbarCaptureZone).data(a.repeat,a.keyFun);u.enter().append(\"line\").classed(n.cn.scrollbarCaptureZone,!0).attr(\"stroke\",\"white\").attr(\"stroke-opacity\",.01).attr(\"stroke-width\",n.scrollbarCaptureWidth).attr(\"stroke-linecap\",\"butt\").attr(\"y1\",0).on(\"mousedown\",function(r){var n=i.event.y,a=this.getBoundingClientRect(),o=r.scrollbarState,s=n-a.top,l=i.scale.linear().domain([0,o.scrollableAreaHeight]).range([0,o.totalHeight]).clamp(!0);o.topY<=s&&s<=o.bottomY||S(e,t,null,l(s-o.barLength/2))(r)}).call(i.behavior.drag().origin(function(t){return i.event.stopPropagation(),t.scrollbarState.scrollbarScrollInProgress=!0,t}).on(\"drag\",S(e,t)).on(\"dragend\",function(){})),u.attr(\"y2\",function(t){return t.scrollbarState.scrollableAreaHeight}),e._context.staticPlot&&(c.remove(),u.remove())}function y(t,e,r,s){var l=function(t){var e=t.selectAll(\".\"+n.cn.columnCell).data(h.splitToCells,function(t){return t.keyWithinBlock});return e.enter().append(\"g\").classed(n.cn.columnCell,!0),e.exit().remove(),e}(function(t){var e=t.selectAll(\".\"+n.cn.columnCells).data(a.repeat,a.keyFun);return e.enter().append(\"g\").classed(n.cn.columnCells,!0),e.exit().remove(),e}(r));!function(t){t.each(function(t,e){var r=t.calcdata.cells.font,n=t.column.specIndex,i={size:_(r.size,n,e),color:_(r.color,n,e),family:_(r.family,n,e)};t.rowNumber=t.key,t.align=_(t.calcdata.cells.align,n,e),t.cellBorderWidth=_(t.calcdata.cells.line.width,n,e),t.font=i})}(l),function(t){t.attr(\"width\",function(t){return t.column.columnWidth}).attr(\"stroke-width\",function(t){return t.cellBorderWidth}).each(function(t){var e=i.select(this);f.stroke(e,_(t.calcdata.cells.line.color,t.column.specIndex,t.rowNumber)),f.fill(e,_(t.calcdata.cells.fill.color,t.column.specIndex,t.rowNumber))})}(function(t){var e=t.selectAll(\".\"+n.cn.cellRect).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"rect\").classed(n.cn.cellRect,!0),e}(l));var c=function(t){var e=t.selectAll(\".\"+n.cn.cellText).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"text\").classed(n.cn.cellText,!0).style(\"cursor\",function(){return\"auto\"}).on(\"mousedown\",function(){i.event.stopPropagation()}),e}(function(t){var e=t.selectAll(\".\"+n.cn.cellTextHolder).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"g\").classed(n.cn.cellTextHolder,!0).style(\"shape-rendering\",\"geometricPrecision\"),e}(l));!function(t){t.each(function(t){o.font(i.select(this),t.font)})}(c),x(c,e,s,t),O(l)}function x(t,e,r,a){t.text(function(t){var e=t.column.specIndex,r=t.rowNumber,a=t.value,o=\"string\"==typeof a,s=o&&a.match(/<br>/i),l=!o||s;t.mayHaveMarkup=o&&a.match(/[<&>]/);var c,u=\"string\"==typeof(c=a)&&c.match(n.latexCheck);t.latex=u;var h,f,p=u?\"\":_(t.calcdata.cells.prefix,e,r)||\"\",d=u?\"\":_(t.calcdata.cells.suffix,e,r)||\"\",g=u?null:_(t.calcdata.cells.format,e,r)||null,v=p+(g?i.format(g)(t.value):t.value)+d;if(t.wrappingNeeded=!t.wrapped&&!l&&!u&&(h=b(v)),t.cellHeightMayIncrease=s||u||t.mayHaveMarkup||(void 0===h?b(v):h),t.needsConvertToTspans=t.mayHaveMarkup||t.wrappingNeeded||t.latex,t.wrappingNeeded){var m=(\" \"===n.wrapSplitCharacter?v.replace(/<a href=/gi,\"<a_href=\"):v).split(n.wrapSplitCharacter),y=\" \"===n.wrapSplitCharacter?m.map(function(t){return t.replace(/<a_href=/gi,\"<a href=\")}):m;t.fragments=y.map(function(t){return{text:t,width:null}}),t.fragments.push({fragment:n.wrapSpacer,width:null}),f=y.join(n.lineBreaker)+n.lineBreaker+n.wrapSpacer}else delete t.fragments,f=v;return f}).attr(\"dy\",function(t){return t.needsConvertToTspans?0:\"0.75em\"}).each(function(t){var o=i.select(this),l=t.wrappingNeeded?C:L;t.needsConvertToTspans?s.convertToTspans(o,a,l(r,this,e,a,t)):i.select(this.parentNode).attr(\"transform\",function(t){return\"translate(\"+P(t)+\" \"+n.cellPad+\")\"}).attr(\"text-anchor\",function(t){return{left:\"start\",center:\"middle\",right:\"end\"}[t.align]})})}function b(t){return-1!==t.indexOf(n.wrapSplitCharacter)}function _(t,e,r){if(Array.isArray(t)){var n=t[Math.min(e,t.length-1)];return Array.isArray(n)?n[Math.min(r,n.length-1)]:n}return t}function w(t,e,r){t.transition().ease(n.releaseTransitionEase).duration(n.releaseTransitionDuration).attr(\"transform\",\"translate(\"+e.x+\" \"+r+\")\")}function k(t){return\"cells\"===t.type}function T(t){return\"header\"===t.type}function A(t){return(t.rowBlocks.length?t.rowBlocks[0].auxiliaryBlocks:[]).reduce(function(t,e){return t+I(e,1/0)},0)}function M(t,e,r){var n=v(e)[0];if(void 0!==n){var i=n.rowBlocks,a=n.calcdata,o=z(i,i.length),s=n.calcdata.groupHeight-A(n),l=a.scrollY=Math.max(0,Math.min(o-s,a.scrollY)),c=function(t,e,r){for(var n=[],i=0,a=0;a<t.length;a++){for(var o=t[a],s=o.rows,l=0,c=0;c<s.length;c++)l+=s[c].rowHeight;o.allRowsHeight=l,e<i+l&&e+r>i&&n.push(a),i+=l}return n}(i,l,s);1===c.length&&(c[0]===i.length-1?c.unshift(c[0]-1):c.push(c[0]+1)),c[0]%2&&c.reverse(),e.each(function(t,e){t.page=c[e],t.scrollY=l}),e.attr(\"transform\",function(t){return\"translate(0 \"+(z(t.rowBlocks,t.page)-t.scrollY)+\")\"}),t&&(E(t,r,e,c,n.prevPages,n,0),E(t,r,e,c,n.prevPages,n,1),m(r,t))}}function S(t,e,r,a){return function(o){var s=o.calcdata?o.calcdata:o,l=e.filter(function(t){return s.key===t.key}),c=r||s.scrollbarState.dragMultiplier,u=s.scrollY;s.scrollY=void 0===a?s.scrollY+c*i.event.dy:a;var h=l.selectAll(\".\"+n.cn.yColumn).selectAll(\".\"+n.cn.columnBlock).filter(k);return M(t,h,l),s.scrollY===u}}function E(t,e,r,n,i,a,o){n[o]!==i[o]&&(clearTimeout(a.currentRepaint[o]),a.currentRepaint[o]=setTimeout(function(){var a=r.filter(function(t,e){return e===o&&n[e]!==i[e]});y(t,e,a,r),i[o]=n[o]}))}function C(t,e,r,a){return function(){var o=i.select(e.parentNode);o.each(function(t){var e=t.fragments;o.selectAll(\"tspan.line\").each(function(t,r){e[r].width=this.getComputedTextLength()});var r,i,a=e[e.length-1].width,s=e.slice(0,-1),l=[],c=0,u=t.column.columnWidth-2*n.cellPad;for(t.value=\"\";s.length;)c+(i=(r=s.shift()).width+a)>u&&(t.value+=l.join(n.wrapSpacer)+n.lineBreaker,l=[],c=0),l.push(r.text),c+=i;c&&(t.value+=l.join(n.wrapSpacer)),t.wrapped=!0}),o.selectAll(\"tspan.line\").remove(),x(o.select(\".\"+n.cn.cellText),r,t,a),i.select(e.parentNode.parentNode).call(O)}}function L(t,e,r,a,o){return function(){if(!o.settledY){var s=i.select(e.parentNode),l=R(o),c=o.key-l.firstRowIndex,u=l.rows[c].rowHeight,h=o.cellHeightMayIncrease?e.parentNode.getBoundingClientRect().height+2*n.cellPad:u,f=Math.max(h,u);f-l.rows[c].rowHeight&&(l.rows[c].rowHeight=f,t.selectAll(\".\"+n.cn.columnCell).call(O),M(null,t.filter(k),0),m(r,a,!0)),s.attr(\"transform\",function(){var t=this.parentNode.getBoundingClientRect(),e=i.select(this.parentNode).select(\".\"+n.cn.cellRect).node().getBoundingClientRect(),r=this.transform.baseVal.consolidate(),a=e.top-t.top+(r?r.matrix.f:n.cellPad);return\"translate(\"+P(o,i.select(this.parentNode).select(\".\"+n.cn.cellTextHolder).node().getBoundingClientRect().width)+\" \"+a+\")\"}),o.settledY=!0}}}function P(t,e){switch(t.align){case\"left\":return n.cellPad;case\"right\":return t.column.columnWidth-(e||0)-n.cellPad;case\"center\":return(t.column.columnWidth-(e||0))/2;default:return n.cellPad}}function O(t){t.attr(\"transform\",function(t){var e=t.rowBlocks[0].auxiliaryBlocks.reduce(function(t,e){return t+I(e,1/0)},0);return\"translate(0 \"+(I(R(t),t.key)+e)+\")\"}).selectAll(\".\"+n.cn.cellRect).attr(\"height\",function(t){return(e=R(t),r=t.key,e.rows[r-e.firstRowIndex]).rowHeight;var e,r})}function z(t,e){for(var r=0,n=e-1;n>=0;n--)r+=D(t[n]);return r}function I(t,e){for(var r=0,n=0;n<t.rows.length&&t.rows[n].rowIndex<e;n++)r+=t.rows[n].rowHeight;return r}function D(t){var e=t.allRowsHeight;if(void 0!==e)return e;for(var r=0,n=0;n<t.rows.length;n++)r+=t.rows[n].rowHeight;return t.allRowsHeight=r,r}function R(t){return t.rowBlocks[t.page]}e.exports=function(t,e){var r=!t._context.staticPlot,s=t._fullLayout._paper.selectAll(\".\"+n.cn.table).data(e.map(function(e){var r=a.unwrap(e).trace;return u(t,r)}),a.keyFun);s.exit().remove(),s.enter().append(\"g\").classed(n.cn.table,!0).attr(\"overflow\",\"visible\").style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"overflow\",\"visible\").style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"all\"),s.attr(\"width\",function(t){return t.width+t.size.l+t.size.r}).attr(\"height\",function(t){return t.height+t.size.t+t.size.b}).attr(\"transform\",function(t){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"});var f=s.selectAll(\".\"+n.cn.tableControlView).data(a.repeat,a.keyFun),x=f.enter().append(\"g\").classed(n.cn.tableControlView,!0).style(\"box-sizing\",\"content-box\");r&&x.on(\"mousemove\",function(e){f.filter(function(t){return e===t}).call(m,t)}).on(\"mousewheel\",function(e){if(!e.scrollbarState.wheeling){e.scrollbarState.wheeling=!0;var r=e.scrollY+i.event.deltaY;S(t,f,null,r)(e)||(i.event.stopPropagation(),i.event.preventDefault()),e.scrollbarState.wheeling=!1}}).call(m,t,!0),f.attr(\"transform\",function(t){return\"translate(\"+t.size.l+\" \"+t.size.t+\")\"});var b=f.selectAll(\".\"+n.cn.scrollBackground).data(a.repeat,a.keyFun);b.enter().append(\"rect\").classed(n.cn.scrollBackground,!0).attr(\"fill\",\"none\"),b.attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}),f.each(function(e){o.setClipUrl(i.select(this),d(t,e),t)});var _=f.selectAll(\".\"+n.cn.yColumn).data(function(t){return t.columns},a.keyFun);_.enter().append(\"g\").classed(n.cn.yColumn,!0),_.exit().remove(),_.attr(\"transform\",function(t){return\"translate(\"+t.x+\" 0)\"}),r&&_.call(i.behavior.drag().origin(function(e){return w(i.select(this),e,-n.uplift),l(this),e.calcdata.columnDragInProgress=!0,m(f.filter(function(t){return e.calcdata.key===t.key}),t),e}).on(\"drag\",function(t){var e=i.select(this),r=function(e){return(t===e?i.event.x:e.x)+e.columnWidth/2};t.x=Math.max(-n.overdrag,Math.min(t.calcdata.width+n.overdrag-t.columnWidth,i.event.x)),v(_).filter(function(e){return e.calcdata.key===t.calcdata.key}).sort(function(t,e){return r(t)-r(e)}).forEach(function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e)}),_.filter(function(e){return t!==e}).transition().ease(n.transitionEase).duration(n.transitionDuration).attr(\"transform\",function(t){return\"translate(\"+t.x+\" 0)\"}),e.call(c).attr(\"transform\",\"translate(\"+t.x+\" -\"+n.uplift+\" )\")}).on(\"dragend\",function(e){var r=i.select(this),n=e.calcdata;e.x=e.xScale(e),e.calcdata.columnDragInProgress=!1,w(r,e,0),function(t,e,r){var n=e.gdColumnsOriginalOrder;e.gdColumns.sort(function(t,e){return r[n.indexOf(t)]-r[n.indexOf(e)]}),e.columnorder=r,t.emit(\"plotly_restyle\")}(t,n,n.columns.map(function(t){return t.xIndex}))})),_.each(function(e){o.setClipUrl(i.select(this),g(t,e),t)});var A=_.selectAll(\".\"+n.cn.columnBlock).data(h.splitToPanels,a.keyFun);A.enter().append(\"g\").classed(n.cn.columnBlock,!0).attr(\"id\",function(t){return t.key}),A.style(\"cursor\",function(t){return t.dragHandle?\"ew-resize\":t.calcdata.scrollbarState.barWiggleRoom?\"ns-resize\":\"default\"});var E=A.filter(T),C=A.filter(k);r&&C.call(i.behavior.drag().origin(function(t){return i.event.stopPropagation(),t}).on(\"drag\",S(t,f,-1)).on(\"dragend\",function(){})),y(t,f,E,A),y(t,f,C,A);var L=f.selectAll(\".\"+n.cn.scrollAreaClip).data(a.repeat,a.keyFun);L.enter().append(\"clipPath\").classed(n.cn.scrollAreaClip,!0).attr(\"id\",function(e){return d(t,e)});var P=L.selectAll(\".\"+n.cn.scrollAreaClipRect).data(a.repeat,a.keyFun);P.enter().append(\"rect\").classed(n.cn.scrollAreaClipRect,!0).attr(\"x\",-n.overdrag).attr(\"y\",-n.uplift).attr(\"fill\",\"none\"),P.attr(\"width\",function(t){return t.width+2*n.overdrag}).attr(\"height\",function(t){return t.height+n.uplift}),_.selectAll(\".\"+n.cn.columnBoundary).data(a.repeat,a.keyFun).enter().append(\"g\").classed(n.cn.columnBoundary,!0);var O=_.selectAll(\".\"+n.cn.columnBoundaryClippath).data(a.repeat,a.keyFun);O.enter().append(\"clipPath\").classed(n.cn.columnBoundaryClippath,!0),O.attr(\"id\",function(e){return g(t,e)});var z=O.selectAll(\".\"+n.cn.columnBoundaryRect).data(a.repeat,a.keyFun);z.enter().append(\"rect\").classed(n.cn.columnBoundaryRect,!0).attr(\"fill\",\"none\"),z.attr(\"width\",function(t){return t.columnWidth+2*p(t)}).attr(\"height\",function(t){return t.calcdata.height+2*p(t)+n.uplift}).attr(\"x\",function(t){return-p(t)}).attr(\"y\",function(t){return-p(t)}),M(null,C,f)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/gup\":717,\"../../lib/svg_text_utils\":743,\"./constants\":1232,\"./data_preparation_helper\":1233,\"./data_split_helpers\":1234,d3:163}],1238:[function(t,e,r){\"use strict\";var n=t(\"../box/attributes\"),i=t(\"../../lib/extend\").extendFlat;e.exports={y:n.y,x:n.x,x0:n.x0,y0:n.y0,name:i({},n.name,{}),orientation:i({},n.orientation,{}),bandwidth:{valType:\"number\",min:0,editType:\"calc\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},scalemode:{valType:\"enumerated\",values:[\"width\",\"count\"],dflt:\"width\",editType:\"calc\"},spanmode:{valType:\"enumerated\",values:[\"soft\",\"hard\",\"manual\"],dflt:\"soft\",editType:\"calc\"},span:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}],editType:\"calc\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,points:i({},n.boxpoints,{}),jitter:i({},n.jitter,{}),pointpos:i({},n.pointpos,{}),width:i({},n.width,{}),marker:n.marker,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,box:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},width:{valType:\"number\",min:0,max:1,dflt:.25,editType:\"plot\"},fillcolor:{valType:\"color\",editType:\"style\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},editType:\"plot\"},meanline:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"plot\"},side:{valType:\"enumerated\",values:[\"both\",\"positive\",\"negative\"],dflt:\"both\",editType:\"calc\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,hoveron:{valType:\"flaglist\",flags:[\"violins\",\"points\",\"kde\"],dflt:\"violins+points+kde\",extras:[\"all\"],editType:\"style\"}}},{\"../../lib/extend\":710,\"../box/attributes\":880}],1239:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/calc\"),o=t(\"./helpers\"),s=t(\"../../constants/numerical\").BADNUM;function l(t,e,r){var i=e.max-e.min;if(!i)return t.bandwidth?t.bandwidth:0;if(t.bandwidth)return Math.max(t.bandwidth,i/1e4);var a=r.length,o=n.stdev(r,a-1,e.mean);return Math.max(function(t,e,r){return 1.059*Math.min(e,r/1.349)*Math.pow(t,-.2)}(a,o,e.q3-e.q1),i/100)}function c(t,e,r,n){var a,o=t.spanmode,l=t.span||[],c=[e.min,e.max],u=[e.min-2*n,e.max+2*n];function h(n){var i=l[n],a=\"multicategory\"===r.type?r.r2c(i):r.d2c(i,0,t[e.valLetter+\"calendar\"]);return a===s?u[n]:a}var f={type:\"linear\",range:a=\"soft\"===o?u:\"hard\"===o?c:[h(0),h(1)]};return i.setConvert(f),f.cleanRange(),a}e.exports=function(t,e){var r=a(t,e);if(r[0].t.empty)return r;for(var s=t._fullLayout,u=i.getFromId(t,e[\"h\"===e.orientation?\"xaxis\":\"yaxis\"]),h=1/0,f=-1/0,p=0,d=0,g=0;g<r.length;g++){var v=r[g],m=v.pts.map(o.extractVal),y=v.bandwidth=l(e,v,m),x=v.span=c(e,v,u,y);if(v.min===v.max&&0===y)x=v.span=[v.min,v.max],v.density=[{v:1,t:x[0]}],v.bandwidth=y,p=Math.max(p,1);else{var b=x[1]-x[0],_=Math.ceil(b/(y/3)),w=b/_;if(!isFinite(w)||!isFinite(_))return n.error(\"Something went wrong with computing the violin span\"),r[0].t.empty=!0,r;var k=o.makeKDE(v,e,m);v.density=new Array(_);for(var T=0,A=x[0];A<x[1]+w/2;T++,A+=w){var M=k(A);v.density[T]={v:M,t:A},p=Math.max(p,M)}}d=Math.max(d,m.length),h=Math.min(h,x[0]),f=Math.max(f,x[1])}var S=i.findExtremes(u,[h,f],{padded:!0});if(e._extremes[u._id]=S,e.width)r[0].t.maxKDE=p;else{var E=s._violinScaleGroupStats,C=e.scalegroup,L=E[C];L?(L.maxKDE=Math.max(L.maxKDE,p),L.maxCount=Math.max(L.maxCount,d)):E[C]={maxKDE:p,maxCount:d}}return r[0].t.labels.kde=n._(t,\"kde:\"),r}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../box/calc\":881,\"./helpers\":1242}],1240:[function(t,e,r){\"use strict\";var n=t(\"../box/cross_trace_calc\").setPositionOffset,i=[\"v\",\"h\"];e.exports=function(t,e){for(var r=t.calcdata,a=e.xaxis,o=e.yaxis,s=0;s<i.length;s++){for(var l=i[s],c=\"h\"===l?o:a,u=[],h=0;h<r.length;h++){var f=r[h],p=f[0].t,d=f[0].trace;!0!==d.visible||\"violin\"!==d.type||p.empty||d.orientation!==l||d.xaxis!==a._id||d.yaxis!==o._id||u.push(h)}n(\"violin\",t,u,c)}}},{\"../box/cross_trace_calc\":882}],1241:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../box/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}function c(r,i){return n.coerce2(t,e,o,r,i)}if(a.handleSampleDefaults(t,e,l,s),!1!==e.visible){l(\"bandwidth\"),l(\"side\"),l(\"width\")||(l(\"scalegroup\",e.name),l(\"scalemode\"));var u,h=l(\"span\");Array.isArray(h)&&(u=\"manual\"),l(\"spanmode\",u);var f=l(\"line.color\",(t.marker||{}).color||r),p=l(\"line.width\"),d=l(\"fillcolor\",i.addOpacity(e.line.color,.5));a.handlePointsDefaults(t,e,l,{prefix:\"\"});var g=c(\"box.width\"),v=c(\"box.fillcolor\",d),m=c(\"box.line.color\",f),y=c(\"box.line.width\",p);l(\"box.visible\",Boolean(g||v||m||y))||(e.box={visible:!1});var x=c(\"meanline.color\",f),b=c(\"meanline.width\",p);l(\"meanline.visible\",Boolean(x||b))||(e.meanline={visible:!1})}}},{\"../../components/color\":593,\"../../lib\":719,\"../box/defaults\":883,\"./attributes\":1238}],1242:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=function(t){return 1/Math.sqrt(2*Math.PI)*Math.exp(-.5*t*t)};r.makeKDE=function(t,e,r){var n=r.length,a=i,o=t.bandwidth,s=1/(n*o);return function(t){for(var e=0,i=0;i<n;i++)e+=a((t-r[i])/o);return s*e}},r.getPositionOnKdePath=function(t,e,r){var i,a;\"h\"===e.orientation?(i=\"y\",a=\"x\"):(i=\"x\",a=\"y\");var o=n.findPointOnPath(t.path,r,a,{pathLength:t.pathLength}),s=t.posCenterPx,l=o[i];return[l,\"both\"===e.side?2*s-l:s]},r.getKdeValue=function(t,e,n){var i=t.pts.map(r.extractVal);return r.makeKDE(t,e,i)(n)/t.posDensityScale},r.extractVal=function(t){return t.v}},{\"../../lib\":719}],1243:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/hover\"),o=t(\"./helpers\");e.exports=function(t,e,r,s,l){var c,u,h=t.cd,f=h[0].trace,p=f.hoveron,d=-1!==p.indexOf(\"violins\"),g=-1!==p.indexOf(\"kde\"),v=[];if(d||g){var m=a.hoverOnBoxes(t,e,r,s);if(g&&m.length>0){var y,x,b,_,w,k=t.xa,T=t.ya;\"h\"===f.orientation?(w=e,y=\"y\",b=T,x=\"x\",_=k):(w=r,y=\"x\",b=k,x=\"y\",_=T);var A=h[t.index];if(w>=A.span[0]&&w<=A.span[1]){var M=n.extendFlat({},t),S=_.c2p(w,!0),E=o.getKdeValue(A,f,w),C=o.getPositionOnKdePath(A,f,S),L=b._offset,P=b._length;M[y+\"0\"]=C[0],M[y+\"1\"]=C[1],M[x+\"0\"]=M[x+\"1\"]=S,M[x+\"Label\"]=x+\": \"+i.hoverLabelText(_,w)+\", \"+h[0].t.labels.kde+\" \"+E.toFixed(3),M.spikeDistance=m[0].spikeDistance;var O=y+\"Spike\";M[O]=m[0][O],m[0].spikeDistance=void 0,m[0][O]=void 0,M.hovertemplate=!1,v.push(M),(u={stroke:t.color})[y+\"1\"]=n.constrain(L+C[0],L,L+P),u[y+\"2\"]=n.constrain(L+C[1],L,L+P),u[x+\"1\"]=u[x+\"2\"]=_._offset+S}}d&&(v=v.concat(m))}-1!==p.indexOf(\"points\")&&(c=a.hoverOnPoints(t,e,r));var z=l.selectAll(\".violinline-\"+f.uid).data(u?[0]:[]);return z.enter().append(\"line\").classed(\"violinline-\"+f.uid,!0).attr(\"stroke-width\",1.5),z.exit().remove(),z.attr(u),\"closest\"===s?c?[c]:v:c?(v.push(c),v):v}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../box/hover\":885,\"./helpers\":1242}],1244:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../box/defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../box/select\"),moduleType:\"trace\",name:\"violin\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"violinLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../box/defaults\":883,\"../box/select\":890,\"../scatter/style\":1134,\"./attributes\":1238,\"./calc\":1239,\"./cross_trace_calc\":1240,\"./defaults\":1241,\"./hover\":1243,\"./layout_attributes\":1245,\"./layout_defaults\":1246,\"./plot\":1247,\"./style\":1248}],1245:[function(t,e,r){\"use strict\";var n=t(\"../box/layout_attributes\"),i=t(\"../../lib\").extendFlat;e.exports={violinmode:i({},n.boxmode,{}),violingap:i({},n.boxgap,{}),violingroupgap:i({},n.boxgroupgap,{})}},{\"../../lib\":719,\"../box/layout_attributes\":887}],1246:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"../box/layout_defaults\");e.exports=function(t,e,r){a._supply(t,e,r,function(r,a){return n.coerce(t,e,i,r,a)},\"violin\")}},{\"../../lib\":719,\"../box/layout_defaults\":888,\"./layout_attributes\":1245}],1247:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../box/plot\"),s=t(\"../scatter/line_points\"),l=t(\"./helpers\");e.exports=function(t,e,r,c){var u=t._fullLayout,h=e.xaxis,f=e.yaxis;function p(t){var e=s(t,{xaxis:h,yaxis:f,connectGaps:!0,baseTolerance:.75,shape:\"spline\",simplify:!0});return a.smoothopen(e[0],1)}i.makeTraceGroups(c,r,\"trace violins\").each(function(t){var r=n.select(this),a=t[0],s=a.t,c=a.trace;if(!0!==c.visible||s.empty)r.remove();else{var d=s.bPos,g=s.bdPos,v=e[s.valLetter+\"axis\"],m=e[s.posLetter+\"axis\"],y=\"both\"===c.side,x=y||\"positive\"===c.side,b=y||\"negative\"===c.side,_=r.selectAll(\"path.violin\").data(i.identity);_.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"violin\"),_.exit().remove(),_.each(function(t){var e,r,i,a,o,l,h,f,_=n.select(this),w=t.density,k=w.length,T=t.pos+d,A=m.c2p(T);if(c.width)e=s.maxKDE/g;else{var M=u._violinScaleGroupStats[c.scalegroup];e=\"count\"===c.scalemode?M.maxKDE/g*(M.maxCount/t.pts.length):M.maxKDE/g}if(x){for(h=new Array(k),o=0;o<k;o++)(f=h[o]={})[s.posLetter]=T+w[o].v/e,f[s.valLetter]=w[o].t;r=p(h)}if(b){for(h=new Array(k),l=0,o=k-1;l<k;l++,o--)(f=h[l]={})[s.posLetter]=T-w[o].v/e,f[s.valLetter]=w[o].t;i=p(h)}if(y)a=r+\"L\"+i.substr(1)+\"Z\";else{var S=[A,v.c2p(w[0].t)],E=[A,v.c2p(w[k-1].t)];\"h\"===c.orientation&&(S.reverse(),E.reverse()),a=x?\"M\"+S+\"L\"+r.substr(1)+\"L\"+E:\"M\"+E+\"L\"+i.substr(1)+\"L\"+S}_.attr(\"d\",a),t.posCenterPx=A,t.posDensityScale=e*g,t.path=_.node(),t.pathLength=t.path.getTotalLength()/(y?2:1)});var w,k,T,A=c.box,M=A.width,S=(A.line||{}).width;y?(w=g*M,k=0):x?(w=[0,g*M/2],k=-S):(w=[g*M/2,0],k=S),o.plotBoxAndWhiskers(r,{pos:m,val:v},c,{bPos:d,bdPos:w,bPosPxOffset:k}),o.plotBoxMean(r,{pos:m,val:v},c,{bPos:d,bdPos:w,bPosPxOffset:k}),!c.box.visible&&c.meanline.visible&&(T=i.identity);var E=r.selectAll(\"path.meanline\").data(T||[]);E.enter().append(\"path\").attr(\"class\",\"meanline\").style(\"fill\",\"none\").style(\"vector-effect\",\"non-scaling-stroke\"),E.exit().remove(),E.each(function(t){var e=v.c2p(t.mean,!0),r=l.getPositionOnKdePath(t,c,e);n.select(this).attr(\"d\",\"h\"===c.orientation?\"M\"+e+\",\"+r[0]+\"V\"+r[1]:\"M\"+r[0]+\",\"+e+\"H\"+r[1])}),o.plotPoints(r,{x:h,y:f},c,s)}})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../box/plot\":889,\"../scatter/line_points\":1125,\"./helpers\":1242,d3:163}],1248:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../scatter/style\").stylePoints;e.exports=function(t){var e=n.select(t).selectAll(\"g.trace.violins\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.each(function(e){var r=e[0].trace,o=n.select(this),s=r.box||{},l=s.line||{},c=r.meanline||{},u=c.width;o.selectAll(\"path.violin\").style(\"stroke-width\",r.line.width+\"px\").call(i.stroke,r.line.color).call(i.fill,r.fillcolor),o.selectAll(\"path.box\").style(\"stroke-width\",l.width+\"px\").call(i.stroke,l.color).call(i.fill,s.fillcolor);var h={\"stroke-width\":u+\"px\",\"stroke-dasharray\":2*u+\"px,\"+u+\"px\"};o.selectAll(\"path.mean\").style(h).call(i.stroke,c.color),o.selectAll(\"path.meanline\").style(h).call(i.stroke,c.color),a(o,r,t)})}},{\"../../components/color\":593,\"../scatter/style\":1134,d3:163}],1249:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../isosurface/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=e.exports=s(o({x:i.x,y:i.y,z:i.z,value:i.value,isomin:i.isomin,isomax:i.isomax,surface:i.surface,spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:1}},slices:i.slices,caps:i.caps,text:i.text,hovertext:i.hovertext,hovertemplate:i.hovertemplate},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{colorbar:i.colorbar,opacity:i.opacity,opacityscale:{valType:\"any\",editType:\"calc\"},lightposition:i.lightposition,lighting:i.lighting,flatshading:i.flatshading,contour:i.contour,hoverinfo:o({},a.hoverinfo)}),\"calc\",\"nested\");l.x.editType=l.y.editType=l.z.editType=l.value.editType=\"calc+clearAxisTypes\",l.transforms=void 0},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../isosurface/attributes\":1048}],1250:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib/gl_format_color\").parseColorScale,a=t(\"../../lib/str2rgbarray\"),o=t(\"../../components/colorscale\").extractOpts,s=t(\"../../plots/gl3d/zip3\"),l=t(\"../isosurface/convert\").findNearestOnAxis,c=t(\"../isosurface/convert\").generateIsoMeshes;function u(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var h=u.prototype;h.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._x[e],n=this.data._y[e],i=this.data._z[e],a=this.data._Ys.length,o=this.data._Zs.length,s=l(r,this.data._Xs).id,c=l(n,this.data._Ys).id,u=l(i,this.data._Zs).id,h=t.index=u+o*c+o*a*s;t.traceCoordinate=[this.data._x[h],this.data._y[h],this.data._z[h],this.data.value[h]];var f=this.data.hovertext||this.data.text;return Array.isArray(f)&&void 0!==f[h]?t.textLabel=f[h]:f&&(t.textLabel=f),!0}},h.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map(function(e){return t.d2l(e,0,n)*r})}this.data=c(t);var l={positions:s(n(r.xaxis,t._x,e.dataScale[0],t.xcalendar),n(r.yaxis,t._y,e.dataScale[1],t.ycalendar),n(r.zaxis,t._z,e.dataScale[2],t.zcalendar)),cells:s(t._i,t._j,t._k),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,opacityscale:t.opacityscale,contourEnable:t.contour.show,contourColor:a(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},u=o(t);l.vertexIntensity=t._intensity,l.vertexIntensityBounds=[u.min,u.max],l.colormap=i(t),this.mesh.update(l)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new u(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":605,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../../plots/gl3d/zip3\":818,\"../isosurface/convert\":1050,\"gl-mesh3d\":280}],1251:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../isosurface/defaults\").supplyIsoDefaults;e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}a(t,e,r,o,s);var l=s(\"opacityscale\");\"max\"===l?e.opacityscale=[[0,.1],[1,1]]:\"min\"===l?e.opacityscale=[[0,1],[1,.1]]:\"extremes\"===l?e.opacityscale=function(t,e){for(var r=[],n=0;n<32;n++){var i=n/31,a=e+(1-e)*(1-Math.pow(Math.sin(t*i*Math.PI),2));r.push([i,Math.max(1,Math.min(0,a))])}return r}(1,.1):function(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var n=t[r];if(2!==n.length||+n[0]<e)return!1;e=+n[0]}return!0}(l)||(e.opacityscale=void 0)}},{\"../../lib\":719,\"../isosurface/defaults\":1051,\"./attributes\":1249}],1252:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../isosurface/calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"volume\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],meta:{}}},{\"../../plots/gl3d\":807,\"../isosurface/calc\":1049,\"./attributes\":1249,\"./convert\":1250,\"./defaults\":1251}],1253:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"./constants\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../components/color\");function u(t){return{marker:{color:l({},n.marker.color,{arrayOk:!1,editType:\"style\"}),line:{color:l({},n.marker.line.color,{arrayOk:!1,editType:\"style\"}),width:l({},n.marker.line.width,{arrayOk:!1,editType:\"style\"}),editType:\"style\"},editType:\"style\"},editType:\"style\"}}e.exports={measure:{valType:\"data_array\",dflt:[],editType:\"calc\"},base:{valType:\"number\",dflt:null,arrayOk:!1,editType:\"calc\"},x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,hovertext:n.hovertext,hovertemplate:o({},{keys:s.eventDataKeys}),hoverinfo:l({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"initial\",\"delta\",\"final\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"initial\",\"delta\",\"final\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},text:n.text,textposition:n.textposition,insidetextanchor:n.insidetextanchor,textangle:n.textangle,textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:n.orientation,offset:n.offset,width:n.width,increasing:u(),decreasing:u(),totals:u(),connector:{line:{color:l({},i.color,{dflt:c.defaultLine}),width:l({},i.width,{editType:\"plot\"}),dash:i.dash,editType:\"plot\"},mode:{valType:\"enumerated\",values:[\"spanning\",\"between\"],dflt:\"between\",editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":593,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../bar/attributes\":857,\"../scatter/attributes\":1112,\"./constants\":1255}],1254:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\").mergeArray,a=t(\"../scatter/calc_selection\"),o=t(\"../../constants/numerical\").BADNUM;function s(t){return\"a\"===t||\"absolute\"===t}function l(t){return\"t\"===t||\"total\"===t}e.exports=function(t,e){var r,c,u=n.getFromId(t,e.xaxis||\"x\"),h=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=u.makeCalcdata(e,\"x\"),c=h.makeCalcdata(e,\"y\")):(r=h.makeCalcdata(e,\"y\"),c=u.makeCalcdata(e,\"x\"));for(var f,p=Math.min(c.length,r.length),d=new Array(p),g=0,v=!1,m=0;m<p;m++){var y=r[m]||0,x=!1;(r[m]!==o||l(e.measure[m])||s(e.measure[m]))&&m+1<p&&(r[m+1]!==o||l(e.measure[m+1])||s(e.measure[m+1]))&&(x=!0);var b=d[m]={i:m,p:c[m],s:y,rawS:y,cNext:x};s(e.measure[m])?(g=b.s,b.isSum=!0,b.dir=\"totals\",b.s=g):l(e.measure[m])?(b.isSum=!0,b.dir=\"totals\",b.s=g):(b.isSum=!1,b.dir=b.rawS<0?\"decreasing\":\"increasing\",f=b.s,b.s=g+f,g+=f),\"totals\"===b.dir&&(v=!0),e.ids&&(b.id=String(e.ids[m])),b.v=(e.base||0)+g}return d.length&&(d[0].hasTotals=v),i(e.text,d,\"tx\"),i(e.hovertext,d,\"htx\"),a(d,e),d}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scatter/calc_selection\":1114}],1255:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"initial\",\"delta\",\"final\"]}},{}],1256:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],h=[],f=[];for(i=0;i<o.length;i++){var p=o[i];!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"waterfall\"===p.type&&(r=s[i],\"h\"===p.orientation?f.push(r):h.push(r),u.push(r))}var d={mode:a.waterfallmode,norm:a.waterfallnorm,gap:a.waterfallgap,groupgap:a.waterfallgroupgap};for(n(t,l,c,h,d),n(t,c,l,f,d),i=0;i<u.length;i++){r=u[i];for(var g=0;g<r.length;g++){var v=r[g];!1===v.isSum&&(v.s0+=0===g?0:r[g-1].s),g+1<r.length&&(r[g].nextP0=r[g+1].p0,r[g].nextS0=r[g+1].s0)}}}},{\"../bar/cross_trace_calc\":860}],1257:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"./attributes\"),l=t(\"../../components/color\"),c=t(\"../../constants/delta.js\"),u=c.INCREASING.COLOR,h=c.DECREASING.COLOR,f=\"#4499FF\";function p(t,e,r){t(e+\".marker.color\",r),t(e+\".marker.line.color\",l.defaultLine),t(e+\".marker.line.width\")}e.exports={supplyDefaults:function(t,e,r,i){function l(r,i){return n.coerce(t,e,s,r,i)}if(o(t,e,i,l)){l(\"measure\"),l(\"orientation\",e.x&&!e.y?\"h\":\"v\"),l(\"base\"),l(\"offset\"),l(\"width\"),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\");var c=l(\"textposition\");a(t,e,i,l,c,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"!==e.textposition&&l(\"textinfo\"),p(l,\"increasing\",u),p(l,\"decreasing\",h),p(l,\"totals\",f),l(\"connector.visible\")&&(l(\"connector.mode\"),l(\"connector.line.width\")&&(l(\"connector.line.color\"),l(\"connector.line.dash\")))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,s,t)}if(\"group\"===e.waterfallmode)for(var l=0;l<t.length;l++)r=(a=t[l])._input,i(r,a,e,o)}}},{\"../../components/color\":593,\"../../constants/delta.js\":689,\"../../lib\":719,\"../bar/defaults\":861,\"../scatter/xy_defaults\":1137,\"./attributes\":1253}],1258:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"initial\"in e&&(t.initial=e.initial),\"delta\"in e&&(t.delta=e.delta),\"final\"in e&&(t.final=e.final),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],1259:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\").hoverLabelText,i=t(\"../../components/color\").opacity,a=t(\"../bar/hover\").hoverOnBars,o=t(\"../../constants/delta.js\"),s=o.INCREASING.SYMBOL,l=o.DECREASING.SYMBOL;e.exports=function(t,e,r,o){var c=a(t,e,r,o);if(c){var u=c.cd,h=u[0].trace,f=\"h\"===h.orientation,p=f?t.xa:t.ya,d=u[c.index],g=d.isSum?d.b+d.s:d.rawS;if(!d.isSum){c.initial=d.b+d.s-g,c.delta=g,c.final=c.initial+c.delta;var v=w(Math.abs(c.delta));c.deltaLabel=g<0?\"(\"+v+\")\":v,c.finalLabel=w(c.final),c.initialLabel=w(c.initial)}var m=d.hi||h.hoverinfo,y=[];if(m&&\"none\"!==m&&\"skip\"!==m){var x=\"all\"===m,b=m.split(\"+\"),_=function(t){return x||-1!==b.indexOf(t)};d.isSum||(!_(\"final\")||_(f?\"x\":\"y\")||y.push(c.finalLabel),_(\"delta\")&&(g<0?y.push(c.deltaLabel+\" \"+l):y.push(c.deltaLabel+\" \"+s)),_(\"initial\")&&y.push(\"Initial: \"+c.initialLabel))}return y.length&&(c.extraText=y.join(\"<br>\")),c.color=function(t,e){var r=t[e.dir].marker,n=r.color,a=r.line.color,o=r.line.width;if(i(n))return n;if(i(a)&&o)return a}(h,d),[c]}function w(t){return n(p,t)}}},{\"../../components/color\":593,\"../../constants/delta.js\":689,\"../../plots/cartesian/axes\":767,\"../bar/hover\":863}],1260:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"waterfall\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../bar/select\":868,\"./attributes\":1253,\"./calc\":1254,\"./cross_trace_calc\":1256,\"./defaults\":1257,\"./event_data\":1258,\"./hover\":1259,\"./layout_attributes\":1261,\"./layout_defaults\":1262,\"./plot\":1263,\"./style\":1264}],1261:[function(t,e,r){\"use strict\";e.exports={waterfallmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"group\",editType:\"calc\"},waterfallgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},waterfallgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],1262:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"waterfall\"===l.type){a=!0;break}}a&&(o(\"waterfallmode\"),o(\"waterfallgap\",.2),o(\"waterfallgroupgap\"))}},{\"../../lib\":719,\"./layout_attributes\":1261}],1263:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../bar/plot\").plot;e.exports=function(t,e,r,s){var l=t._fullLayout;o(t,e,r,s,{mode:l.waterfallmode,norm:l.waterfallmode,gap:l.waterfallgap,groupgap:l.waterfallgroupgap}),function(t,e,r,o){var s=e.xaxis,l=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each(function(r){var o=n.select(this),c=r[0].trace,u=i.ensureSingle(o,\"g\",\"lines\");if(c.connector&&c.connector.visible){var h=\"h\"===c.orientation,f=c.connector.mode,p=u.selectAll(\"g.line\").data(i.identity);p.enter().append(\"g\").classed(\"line\",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var c=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),n?[i,a]:[a,i]}(r,s,l,h),u=c[0],p=c[1],g=\"\";\"spanning\"===f&&!r.isSum&&o>0&&(g+=h?\"M\"+u[0]+\",\"+p[1]+\"V\"+p[0]:\"M\"+u[1]+\",\"+p[0]+\"H\"+u[0]),\"between\"!==f&&(r.isSum||o<d-1)&&(g+=h?\"M\"+u[1]+\",\"+p[0]+\"V\"+p[1]:\"M\"+u[0]+\",\"+p[1]+\"H\"+u[1]),void 0!==u[2]&&void 0!==p[2]&&(g+=h?\"M\"+u[1]+\",\"+p[1]+\"V\"+p[2]:\"M\"+u[1]+\",\"+p[1]+\"H\"+u[2]),\"\"===g&&(g=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}})}else u.remove()})}(t,e,r,s)}},{\"../../components/drawing\":614,\"../../lib\":719,\"../bar/plot\":867,d3:163}],1264:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\").styleTextPoints;e.exports={style:function(t,e,r){var l=r||n.select(t).selectAll(\"g.waterfalllayer\").selectAll(\"g.trace\");l.style(\"opacity\",function(t){return t[0].trace.opacity}),l.each(function(e){var r=n.select(this),l=e[0].trace;r.selectAll(\".point > path\").each(function(t){if(!t.isBlank){var e=l[t.dir].marker;n.select(this).call(a.fill,e.color).call(a.stroke,e.line.color).call(i.dashLine,e.line.dash,e.line.width).style(\"opacity\",l.selectedpoints&&!t.selected?o:1)}}),s(r,l,t),r.selectAll(\".lines\").each(function(){var t=l.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)})})}}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../constants/interactions\":694,\"../bar/style\":870,d3:163}],1265:[function(t,e,r){\"use strict\";var n=t(\"../plots/cartesian/axes\"),i=t(\"../lib\"),a=t(\"../plot_api/plot_schema\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/numerical\").BADNUM;r.moduleType=\"transform\",r.name=\"aggregate\";var l=r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},aggregations:{_isLinkedToArray:\"aggregation\",target:{valType:\"string\",editType:\"calc\"},func:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"median\",\"mode\",\"rms\",\"stddev\",\"min\",\"max\",\"first\",\"last\",\"change\",\"range\"],dflt:\"first\",editType:\"calc\"},funcmode:{valType:\"enumerated\",values:[\"sample\",\"population\"],dflt:\"sample\",editType:\"calc\"},enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},c=l.aggregations;function u(t,e,r,a){if(a.enabled){for(var o=a.target,l=i.nestedProperty(e,o),c=l.get(),u=function(t,e){var r=t.func,n=e.d2c,i=e.c2d;switch(r){case\"count\":return h;case\"first\":return f;case\"last\":return p;case\"sum\":return function(t,e){for(var r=0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r+=o)}return i(r)};case\"avg\":return function(t,e){for(var r=0,a=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l,a++)}return a?i(r/a):s};case\"min\":return function(t,e){for(var r=1/0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r=Math.min(r,o))}return r===1/0?s:i(r)};case\"max\":return function(t,e){for(var r=-1/0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r=Math.max(r,o))}return r===-1/0?s:i(r)};case\"range\":return function(t,e){for(var r=1/0,a=-1/0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r=Math.min(r,l),a=Math.max(a,l))}return a===-1/0||r===1/0?s:i(a-r)};case\"change\":return function(t,e){var r=n(t[e[0]]),a=n(t[e[e.length-1]]);return r===s||a===s?s:i(a-r)};case\"median\":return function(t,e){for(var r=[],a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&r.push(o)}if(!r.length)return s;r.sort();var l=(r.length-1)/2;return i((r[Math.floor(l)]+r[Math.ceil(l)])/2)};case\"mode\":return function(t,e){for(var r={},a=0,o=s,l=0;l<e.length;l++){var c=n(t[e[l]]);if(c!==s){var u=r[c]=(r[c]||0)+1;u>a&&(a=u,o=c)}}return a?i(o):s};case\"rms\":return function(t,e){for(var r=0,a=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l*l,a++)}return a?i(Math.sqrt(r/a)):s};case\"stddev\":return function(e,r){var i,a=0,o=0,l=1,c=s;for(i=0;i<r.length&&c===s;i++)c=n(e[r[i]]);if(c===s)return s;for(;i<r.length;i++){var u=n(e[r[i]]);if(u!==s){var h=u-c;a+=h,o+=h*h,l++}}var f=\"sample\"===t.funcmode?l-1:l;return f?Math.sqrt((o-a*a/l)/f):0}}}(a,n.getDataConversions(t,e,o,c)),d=new Array(r.length),g=0;g<r.length;g++)d[g]=u(c,r[g]);l.set(d),\"count\"===a.func&&i.pushUnique(e._arrayAttrs,o)}}function h(t,e){return e.length}function f(t,e){return t[e[0]]}function p(t,e){return t[e[e.length-1]]}r.supplyDefaults=function(t,e){var r,n={};function o(e,r){return i.coerce(t,n,l,e,r)}if(!o(\"enabled\"))return n;var s=a.findArrayAttributes(e),u={};for(r=0;r<s.length;r++)u[s[r]]=1;var h=o(\"groups\");if(!Array.isArray(h)){if(!u[h])return n.enabled=!1,n;u[h]=0}var f,p=t.aggregations||[],d=n.aggregations=new Array(p.length);function g(t,e){return i.coerce(p[r],f,c,t,e)}for(r=0;r<p.length;r++){f={_index:r};var v=g(\"target\"),m=g(\"func\");g(\"enabled\")&&v&&(u[v]||\"count\"===m&&void 0===u[v])?(\"stddev\"===m&&g(\"funcmode\"),u[v]=0,d[r]=f):d[r]={enabled:!1,_index:r}}for(r=0;r<s.length;r++)u[s[r]]&&d.push({target:s[r],func:c.func.dflt,enabled:!0,_index:-1});return n},r.calcTransform=function(t,e,r){if(r.enabled){var n=r.groups,a=i.getTargetArray(e,{target:n});if(a){var s,l,c,h,f={},p={},d=[],g=o(e.transforms,r),v=a.length;for(e._length&&(v=Math.min(v,e._length)),s=0;s<v;s++)void 0===(c=f[l=a[s]])?(f[l]=d.length,h=[s],d.push(h),p[f[l]]=g(s)):(d[c].push(s),p[f[l]]=(p[f[l]]||[]).concat(g(s)));r._indexToPoints=p;var m=r.aggregations;for(s=0;s<m.length;s++)u(t,e,d,m[s]);\"string\"==typeof n&&u(t,e,d,{target:n,func:\"first\",enabled:!0}),e._length=d.length}}}},{\"../constants/numerical\":695,\"../lib\":719,\"../plot_api/plot_schema\":756,\"../plots/cartesian/axes\":767,\"./helpers\":1268}],1266:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../registry\"),a=t(\"../plots/cartesian/axes\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/filter_ops\"),l=s.COMPARISON_OPS,c=s.INTERVAL_OPS,u=s.SET_OPS;r.moduleType=\"transform\",r.name=\"filter\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},operation:{valType:\"enumerated\",values:[].concat(l).concat(c).concat(u),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},preservegaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function a(i,a){return n.coerce(t,e,r.attributes,i,a)}if(a(\"enabled\")){var o=a(\"target\");if(n.isArrayOrTypedArray(o)&&0===o.length)return e.enabled=!1,e;a(\"preservegaps\"),a(\"operation\"),a(\"value\");var s=i.getComponentMethod(\"calendars\",\"handleDefaults\");s(t,e,\"valuecalendar\",null),s(t,e,\"targetcalendar\",null)}return e},r.calcTransform=function(t,e,r){if(r.enabled){var i=n.getTargetArray(e,r);if(i){var s=r.target,h=i.length;e._length&&(h=Math.min(h,e._length));var f=r.targetcalendar,p=e._arrayAttrs,d=r.preservegaps;if(\"string\"==typeof s){var g=n.nestedProperty(e,s+\"calendar\").get();g&&(f=g)}var v,m,y=function(t,e,r){var n=t.operation,i=t.value,a=Array.isArray(i);function o(t){return-1!==t.indexOf(n)}var s,h=function(r){return e(r,0,t.valuecalendar)},f=function(t){return e(t,0,r)};o(l)?s=h(a?i[0]:i):o(c)?s=a?[h(i[0]),h(i[1])]:[h(i),h(i)]:o(u)&&(s=a?i.map(h):[h(i)]);switch(n){case\"=\":return function(t){return f(t)===s};case\"!=\":return function(t){return f(t)!==s};case\"<\":return function(t){return f(t)<s};case\"<=\":return function(t){return f(t)<=s};case\">\":return function(t){return f(t)>s};case\">=\":return function(t){return f(t)>=s};case\"[]\":return function(t){var e=f(t);return e>=s[0]&&e<=s[1]};case\"()\":return function(t){var e=f(t);return e>s[0]&&e<s[1]};case\"[)\":return function(t){var e=f(t);return e>=s[0]&&e<s[1]};case\"(]\":return function(t){var e=f(t);return e>s[0]&&e<=s[1]};case\"][\":return function(t){var e=f(t);return e<=s[0]||e>=s[1]};case\")(\":return function(t){var e=f(t);return e<s[0]||e>s[1]};case\"](\":return function(t){var e=f(t);return e<=s[0]||e>s[1]};case\")[\":return function(t){var e=f(t);return e<s[0]||e>=s[1]};case\"{}\":return function(t){return-1!==s.indexOf(f(t))};case\"}{\":return function(t){return-1===s.indexOf(f(t))}}}(r,a.getDataToCoordFunc(t,e,s,i),f),x={},b={},_=0;d?(v=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set(new Array(h))},m=function(t,e){var r=x[t.astr][e];t.get()[e]=r}):(v=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set([])},m=function(t,e){var r=x[t.astr][e];t.get().push(r)}),T(v);for(var w=o(e.transforms,r),k=0;k<h;k++){y(i[k])?(T(m,k),b[_++]=w(k)):d&&_++}r._indexToPoints=b,e._length=_}}function T(t,r){for(var i=0;i<p.length;i++){t(n.nestedProperty(e,p[i]),r)}}}},{\"../constants/filter_ops\":691,\"../lib\":719,\"../plots/cartesian/axes\":767,\"../registry\":847,\"./helpers\":1268}],1267:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_schema\"),a=t(\"../plots/plots\"),o=t(\"./helpers\").pointsAccessorFunction;function s(t,e){var r,s,l,c,u,h,f,p,d,g,v=e.transform,m=e.transformIndex,y=t.transforms[m].groups,x=o(t.transforms,v);if(!Array.isArray(y)||0===y.length)return[t];var b=n.filterUnique(y),_=new Array(b.length),w=y.length,k=i.findArrayAttributes(t),T=v.styles||[],A={};for(r=0;r<T.length;r++)A[T[r].target]=T[r].value;v.styles&&(g=n.keyedContainer(v,\"styles\",\"target\",\"value.name\"));var M={},S={};for(r=0;r<b.length;r++){M[h=b[r]]=r,S[h]=0,(f=_[r]=n.extendDeepNoArrays({},t))._group=h,f.transforms[m]._indexToPoints={};var E=null;for(g&&(E=g.get(h)),f.name=E||\"\"===E?E:n.templateString(v.nameformat,{trace:t.name,group:h}),p=f.transforms,f.transforms=[],s=0;s<p.length;s++)f.transforms[s]=n.extendDeepNoArrays({},p[s]);for(s=0;s<k.length;s++)n.nestedProperty(f,k[s]).set([])}for(l=0;l<k.length;l++){for(c=k[l],s=0,d=[];s<b.length;s++)d[s]=n.nestedProperty(_[s],c).get();for(u=n.nestedProperty(t,c).get(),s=0;s<w;s++)d[M[y[s]]].push(u[s])}for(s=0;s<w;s++){(f=_[M[y[s]]]).transforms[m]._indexToPoints[S[y[s]]]=x(s),S[y[s]]++}for(r=0;r<b.length;r++)h=b[r],f=_[r],a.clearExpandedTraceDefaultColors(f),f=n.extendDeepNoArrays(f,A[h]||{});return _}r.moduleType=\"transform\",r.name=\"groupby\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"data_array\",dflt:[],editType:\"calc\"},nameformat:{valType:\"string\",editType:\"calc\"},styles:{_isLinkedToArray:\"style\",target:{valType:\"string\",editType:\"calc\"},value:{valType:\"any\",dflt:{},editType:\"calc\",_compareAsJSON:!0},editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t,e,i){var a,o={};function s(e,i){return n.coerce(t,o,r.attributes,e,i)}if(!s(\"enabled\"))return o;s(\"groups\"),s(\"nameformat\",i._dataLength>1?\"%{group} (%{trace})\":\"%{group}\");var l=t.styles,c=o.styles=[];if(l)for(a=0;a<l.length;a++){var u=c[a]={};n.coerce(l[a],c[a],r.attributes.styles,\"target\");var h=n.coerce(l[a],c[a],r.attributes.styles,\"value\");n.isPlainObject(h)?u.value=n.extendDeep({},h):h&&delete u.value}return o},r.transform=function(t,e){var r,n,i,a=[];for(n=0;n<t.length;n++)for(r=s(t[n],e),i=0;i<r.length;i++)a.push(r[i]);return a}},{\"../lib\":719,\"../plot_api/plot_schema\":756,\"../plots/plots\":828,\"./helpers\":1268}],1268:[function(t,e,r){\"use strict\";r.pointsAccessorFunction=function(t,e){for(var r,n,i=0;i<t.length&&(r=t[i])!==e;i++)r._indexToPoints&&!1!==r.enabled&&(n=r._indexToPoints);return n?function(t){return n[t]}:function(t){return[t]}}},{}],1269:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/cartesian/axes\"),a=t(\"./helpers\").pointsAccessorFunction;r.moduleType=\"transform\",r.name=\"sort\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},order:{valType:\"enumerated\",values:[\"ascending\",\"descending\"],dflt:\"ascending\",editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function i(i,a){return n.coerce(t,e,r.attributes,i,a)}return i(\"enabled\")&&(i(\"target\"),i(\"order\")),e},r.calcTransform=function(t,e,r){if(r.enabled){var o=n.getTargetArray(e,r);if(o){var s=r.target,l=o.length;e._length&&(l=Math.min(l,e._length));var c,u,h=e._arrayAttrs,f=function(t,e,r,n){var i,a=new Array(n),o=new Array(n);for(i=0;i<n;i++)a[i]={v:e[i],i:i};for(a.sort(function(t,e){switch(t.order){case\"ascending\":return function(t,r){return e(t.v)-e(r.v)};case\"descending\":return function(t,r){return e(r.v)-e(t.v)}}}(t,r)),i=0;i<n;i++)o[i]=a[i].i;return o}(r,o,i.getDataToCoordFunc(t,e,s,o),l),p=a(e.transforms,r),d={};for(c=0;c<h.length;c++){var g=n.nestedProperty(e,h[c]),v=g.get(),m=new Array(l);for(u=0;u<l;u++)m[u]=v[f[u]];g.set(m)}for(u=0;u<l;u++)d[u]=p(f[u]);r._indexToPoints=d,e._length=l}}}},{\"../lib\":719,\"../plots/cartesian/axes\":767,\"./helpers\":1268}]},{},[25])(25)});</script>    \n",
       "            <div id=\"b08b1d78-c407-4ffe-8eab-5235fb44609d\" class=\"plotly-graph-div\" style=\"height:500px; width:500px;\"></div>\n",
       "            <script type=\"text/javascript\">\n",
       "                \n",
       "                    window.PLOTLYENV=window.PLOTLYENV || {};\n",
       "                    \n",
       "                if (document.getElementById(\"b08b1d78-c407-4ffe-8eab-5235fb44609d\")) {\n",
       "                    Plotly.newPlot(\n",
       "                        'b08b1d78-c407-4ffe-8eab-5235fb44609d',\n",
       "                        [{\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha = 0.3\", \"showscale\": false, \"type\": \"surface\", \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.10000000000000003, 0.12311444133449166, 0.13903891703159096, 0.15157165665103983, 0.1620656596692763, 0.17117698594097056, 0.17927899625209978, 0.18660659830736154, 0.1933182044931763, 0.199526231496888, 0.20531364136588445, 0.21074358993444717, 0.21586538444215803, 0.2207183346658568, 0.2253343380842656, 0.22973967099940704, 0.23395626336814518, 0.23800262745964412, 0.2418945481487588, 0.24564560522315815, 0.249267574854026, 0.2527707425511104, 0.25616415021458133, 0.2594557933960466, 0.26265278044037677, 0.26576146209051543, 0.2687875379522287, 0.2717361446466632, 0.27461192933624795, 0.27741911146721815, 0.2801615349437184, 0.28284271247461906, 0.28546586347325026, 0.2880339466127438, 0.2905496879244225, 0.29301560515835223, 0.2954340289925339, 0.2978071215719373, 0.3001368927744569, 0.3024252145332219, 0.3046738334899584, 0.3068843822095699, 0.3090583891496703, 0.3111972875488456, 0.3133024233726666, 0.3153750624359297, 0.31741639680246597, 0.31942755054951555, 0.32140958497160393, 0.32336350328867874, 0.32529025491464575, 0.3271907393351149, 0.3290658096369191, 0.330916275726621, 0.33274290727063266, 0.3345464363856255, 0.33632756010449455, 0.33808694264019057, 0.3398252174671689, 0.3415429892379762, 0.3432408355505488, 0.34491930858009545, 0.3465789365879481, 0.34822022531844976, 0.3498436592938026, 0.35144970301577466, 0.3530388020822698, 0.35461138422596744, 0.3561678602815317, 0.35770862508726164, 0.359234058326496, 0.3607445253135852, 0.3622403777287989, 0.36372195430613813, 0.3651895814776622, 0.3666435739776209, 0.36808423540939345, 0.36951185877797477, 0.3709267269905159, 0.37232911332721397, 0.37371928188465525, 0.37509748799354153, 0.37646397861257275, 0.37781899270011793, 0.37916276156517376, 0.3804955091989957, 0.3818174525886769, 0.3831288020138528, 0.38442976132762086, 0.3857205282226822, 0.3870012944836371, 0.3882722462262991, 0.3895335641248283, 0.39078542362742913, 0.392027995161301, 0.3932614443274869, 0.3944859320862162, 0.39570161493329836, 0.39690864506808704, 0.3981071705534973, 0.39929733546852786], [0.0, 0.16245047927124714, 0.20000000000000007, 0.22586938709137114, 0.24622888266898332, 0.26327644086684754, 0.27807783406318193, 0.29123958864421723, 0.3031433133020797, 0.3140463497177345, 0.32413131933855255, 0.3335329944081287, 0.34235397188194105, 0.3506743516070058, 0.3585579925041995, 0.3660567121805817, 0.373213196614723, 0.380063071126653, 0.38663640898635265, 0.39295885279867626, 0.399052462993776, 0.4049363700181799, 0.4106272827317689, 0.4161398897447047, 0.42148717986889433, 0.42668070064464847, 0.43173076888431605, 0.4366466436247808, 0.4414366693317136, 0.4461083953427532, 0.4506686761685311, 0.455123756249753, 0.4594793419988141, 0.46374066336809894, 0.46791252673629036, 0.4719993605543371, 0.4760052549192882, 0.47993399602872644, 0.4837890962975176, 0.48757382078193423, 0.49129121044631624, 0.49494410271851874, 0.498535149708052, 0.5020668344016354, 0.5055414851022206, 0.5089612883373287, 0.5123283004291627, 0.5156444578911294, 0.5189115867920931, 0.5221314112100968, 0.5253055608807535, 0.5284355781315034, 0.531522924181031, 0.5345689848729848, 0.5375750759044574, 0.540542447602224, 0.5434722892933264, 0.5463657333110431, 0.5492238586724959, 0.5520476944599736, 0.5548382229344363, 0.5575963824064996, 0.5603230698874369, 0.5630191435403132, 0.5656854249492381, 0.5683227012228511, 0.5709317269465005, 0.5735132259961168, 0.5760678932254877, 0.578596396037494, 0.581099375848845, 0.5835774494569441, 0.5860312103167045, 0.5884612297344097, 0.5908680579850678, 0.5932522253591236, 0.5956142431438745, 0.597954604544465, 0.6002737855489138, 0.6025722457412434, 0.6048504290664438, 0.6071087645506854, 0.6093476669799167, 0.6115675375397297, 0.6137687644191396, 0.6159517233807207, 0.6181167782993406, 0.6202642816715723, 0.6223945750976912, 0.6245079897380315, 0.6266048467453332, 0.6286854576745988, 0.6307501248718594, 0.6327991418431543, 0.6348327936049319, 0.6368513570169948, 0.6388551010990311, 0.6408442873317045, 0.6428191699432079, 0.6447799961821205, 0.6467270065773575, 0.6486604351859429], [0.0, 0.21576692799745936, 0.2656402479886669, 0.30000000000000004, 0.3270415072708054, 0.3496840952072148, 0.3693433240034749, 0.38682478275783583, 0.4026353246083529, 0.41711675109477286, 0.4305116202499343, 0.4429989367348897, 0.4547149699531195, 0.4657661086207498, 0.47623717023567047, 0.4861969790078288, 0.49570223050689044, 0.5048002423270921, 0.5135309578229116, 0.5219284355339119, 0.5300219761507747, 0.5378369887562993, 0.5453956660788974, 0.5527175175487992, 0.5598197949220846, 0.5667178356561127, 0.5734253425538376, 0.5799546134795289, 0.5863167315628376, 0.5925217238433759, 0.5985786944906639, 0.6044959373785896, 0.6102810317711721, 0.6159409240976533, 0.6214819981961592, 0.6269101359407314, 0.6322307698033415, 0.6374489286163136, 0.642569277573428, 0.647596153326474, 0.6525335948880587, 0.6573853709333776, 0.6621550039975703, 0.6668457919866767, 0.6714608273555641, 0.6760030142527966, 0.6804750838880748, 0.6848796083409064, 0.6892190129982211, 0.6934955877826134, 0.6977114973109454, 0.7018687901044355, 0.705969406955552, 0.7100151885435477, 0.7140078823789322, 0.7179491491472787, 0.7218405685142385, 0.7256836444462764, 0.7294798100952715, 0.7332304322895958, 0.7369368156694743, 0.7406002065002303, 0.744221796193349, 0.747802724562078, 0.75134408283545, 0.7548469164521359, 0.7583122276533311, 0.7617409778919438, 0.7651340900736369, 0.7684924506437439, 0.7718169115327335, 0.7751082919716815, 0.7783673801881397, 0.7815949349918221, 0.7847916872586769, 0.7879583413211303, 0.7910955762716047, 0.7942040471857845, 0.7972843862715463, 0.8003372039489588, 0.8033630898663083, 0.8063626138566861, 0.8093363268393032, 0.8122847616693605, 0.8152084339399894, 0.8181078427395068, 0.8209834713669633, 0.8238357880087437, 0.826665246378758, 0.8294722863245723, 0.8322573344016544, 0.8350208044177447, 0.8377630979492166, 0.8404846048311553, 0.8431857036227614, 0.8458667620495675, 0.8485281374238571, 0.8511701770445722, 0.8537932185779135, 0.8563975904197506, 0.858983612040887, 0.8615515943161519], [0.0, 0.2639015821545789, 0.32490095854249423, 0.36692590185696067, 0.4, 0.42769383999647526, 0.45173877418274216, 0.47312010758013934, 0.49245776533796654, 0.5101698002503163, 0.526552881733695, 0.5418259479437468, 0.5561556681263637, 0.5696721648669191, 0.5824791772884342, 0.5946608833419245, 0.6062866266041592, 0.6174142805782684, 0.6280926994354689, 0.6383635397102438, 0.648262638677105, 0.6578210738381236, 0.6670659888162573, 0.676021245329112, 0.6847079437638821, 0.6931448431551465, 0.7013487032140114, 0.7093345652902706, 0.7171159850083989, 0.7247052263035723, 0.7321134243611632, 0.739350723305026, 0.7464263932294459, 0.7533489302171372, 0.7601261422533058, 0.7667652233777422, 0.7732728179727051, 0.779655076734314, 0.7859177055973524, 0.7920660086613834, 0.7981049259875518, 0.8040390669910071, 0.8098727400363596, 0.8156099787474351, 0.8212545654635376, 0.8268100522091041, 0.8322797794894092, 0.8376668931797636, 0.8429743597377886, 0.8482049799365281, 0.8533614012892967, 0.8584461293144126, 0.863461537768632, 0.868409877961604, 0.8732932872495612, 0.8781137967943426, 0.8828733386634271, 0.887573752337653, 0.8922167906855062, 0.8968041254560969, 0.9013373523370621, 0.9058179956184942, 0.9102475124995059, 0.9146272970701094, 0.918958683997628, 0.9232429519438192, 0.9274813267361978, 0.931674984314682, 0.9358250534725805, 0.9399326184090718, 0.943998721108674, 0.9480243635617254, 0.9520105098385763, 0.9559580880290228, 0.9598679920574528, 0.9637410833832352, 0.967578192595035, 0.9713801209069737, 0.9751476415638682, 0.9788815011621665, 0.9825824208926324, 0.9862510977103355, 0.9898882054370373, 0.9934943958006547, 0.9970702994161038, 1.0006165267114868, 1.0041336688032707, 1.007622298323827, 1.0110829702044413, 1.0145162224166626, 1.0179225766746571, 1.021302539101019, 1.024656600858325, 1.0279852387485426, 1.0312889157822587, 1.0345680817195488, 1.037823173584186, 1.0410546161527616, 1.0442628224201933, 1.0474481940429832, 1.0506111217615068, 1.053751985802521], [0.0, 0.30851693136000485, 0.379828896466187, 0.42895860022204746, 0.4676242239113107, 0.5, 0.5281099842196291, 0.5531060578099961, 0.5757129508131624, 0.5964193922626064, 0.6155722066724582, 0.6334273460055121, 0.6501796567036683, 0.665981259949423, 0.680953433060007, 0.6951945851579547, 0.7087857830839414, 0.7217946844679325, 0.7342784027946782, 0.7462856370756998, 0.7578582832551991, 0.7690326728151439, 0.7798405382945836, 0.7903097754864594, 0.8004650520212367, 0.8103282983463813, 0.8199191075791407, 0.8292550639683243, 0.8383520148598691, 0.8472242975366968, 0.8558849297048525, 0.8643457704594475, 0.872617657102096, 0.8807105220680124, 0.8886334933647516, 0.8963949812604987, 0.9040027534404961, 0.9114640004409924, 0.9187853928452996, 0.9259731314670222, 0.9330329915368074, 0.9399703617401102, 0.9467902788160732, 0.9534974583152248, 0.9600963220212687, 0.9665910224658815, 0.9729854649020294, 0.9792833270484643, 0.9854880768737935, 0.9916029886513195, 0.9976311574844398, 1.0035755124758021, 1.0094388286908085, 1.0152237380467777, 1.0209327392425835, 1.026568206829422, 1.0321323995111822, 1.0376274677523623, 1.0430554607623754, 1.0484183329171723, 1.0537179496722355, 1.0589560930149935, 1.064134466499456, 1.0692546999012742, 1.0743183535273755, 1.07932692221079, 1.0842818390181181, 1.0891844786943392, 1.0940361608671907, 1.0988381530311708, 1.1035916733292837, 1.1082978931489151, 1.1129579395466886, 1.1175728975157806, 1.1221438121079361, 1.1266716904213276, 1.1311575034644048, 1.1356021879049967, 1.140006647713122, 1.1443717557052422, 1.148698354997035, 1.1529872603711846, 1.1572392595661365, 1.1614551144912941, 1.1656355623736843, 1.1697813168407256, 1.1738930689433662, 1.177971488123527, 1.1820172231294868, 1.1860309028825662, 1.1900131372982203, 1.1939645180644125, 1.1978856193799399, 1.2017769986551767, 1.2056391971775395, 1.2094727407437937, 1.213278140261196, 1.2170558923193064, 1.2208064797341944, 1.224530372066635, 1.2282280261157903, 1.2318998863897659], [0.0, 0.3505144086407194, 0.4315338559949187, 0.4873514378137414, 0.5312804959773337, 0.5680634885994444, 0.6000000000000001, 0.6283987135300648, 0.6540830145416108, 0.6776081612741134, 0.6993681904144295, 0.7196538958923571, 0.7386866480069498, 0.7566392757374455, 0.7736495655156717, 0.7898293226005426, 0.8052706492167057, 0.8200504130227778, 0.8342335021895457, 0.8478752449777619, 0.8610232404998686, 0.8737187659326515, 0.8859978734697794, 0.8978922562741636, 0.909429939906239, 0.9206358401389935, 0.9315322172414996, 0.9421390491532035, 0.9524743404713409, 0.9625543801698194, 0.9723939580156575, 0.9820065474467368, 0.9914044610137809, 1.000598983224386, 1.009600484654184, 1.018418520435745, 1.0270619156458232, 1.0355388396466314, 1.0438568710678238, 1.0520230548210172, 1.0600439523015495, 1.0679256857403374, 1.0756739775125985, 1.0832941850825, 1.090791332157795, 1.0981701365417451, 1.1054350350975983, 1.1125902061808426, 1.1196395898441691, 1.1265869060778075, 1.1334356713122251, 1.1401892133799587, 1.1468506851076752, 1.153423076687642, 1.1599092269590578, 1.166311833713595, 1.1726334631256752, 1.1788765583960288, 1.1850434476867517, 1.1911363514170854, 1.1971573889813278, 1.2031085849434697, 1.2089918747571793, 1.2148091100545397, 1.2205620635423444, 1.226252433540725, 1.2318818481953067, 1.2374518693909473, 1.2429639963923187, 1.248419669234114, 1.2538202718814626, 1.259167135179174, 1.264461539606683, 1.2697047178540073, 1.2748978572326273, 1.2800421019339452, 1.285138555146856, 1.2901882810449485, 1.295192306652948, 1.300151623601182, 1.3050671897761175, 1.3099399308743422, 1.3147707418667551, 1.3195604883791834, 1.3243100079951406, 1.3290201114859892, 1.3336915839733534, 1.3383251860282595, 1.3429216547111282, 1.3474817045564387, 1.3520060285055933, 1.356495298791249, 1.3609501677761497, 1.365371268749259, 1.3697592166818129, 1.3741146089457017, 1.3784380259964422, 1.38273003202283, 1.3869911755652269, 1.3912219901042966, 1.3954229946218908, 1.3995946941356594], [0.0, 0.3904528777122723, 0.4807038790699098, 0.5428814526898255, 0.5918158951901497, 0.6327900319620665, 0.668365467587651, 0.7000000000000001, 0.7286108330920733, 0.7548164925853019, 0.7790559126704492, 0.8016530210489499, 0.8228544114931993, 0.8428526055390655, 0.8618010893414415, 0.8798244075239154, 0.8970251566638912, 0.9134889629090254, 0.9292881079469989, 0.9444842242759265, 0.9591303345675485, 0.9732724192211366, 0.9869506383054892, 1.0002002961800205, 1.0130526117060712, 1.0255353396207472, 1.0376732765826269, 1.0494886768664426, 1.0610015965572788, 1.0722301806345713, 1.0831909040475693, 1.0938987754306215, 1.104367510256598, 1.1146096788174915, 1.124636833337688, 1.1344596176849338, 1.1440878624868152, 1.1535306679426571, 1.1627964762097138, 1.1718931349140636, 1.1808279530724777, 1.1896077504978388, 1.1982389015867936, 1.2067273742460805, 1.215078764597002, 1.2232983280008631, 1.2313910068679625, 1.239361455645833, 1.2472140633264064, 1.254952973764698, 1.262582104061864, 1.2701051612318202, 1.2775256573420153, 1.284846923294538, 1.292072121392869, 1.2992042568216624, 1.3062461881515306, 1.3132006369674707, 1.320070196708063, 1.326857340792548, 1.3335644301041942, 1.3401937198907654, 1.3467473661362548, 1.3532274314522341, 1.3596358905320451, 1.3659746352065691, 1.3722454791363263, 1.3784501621711553, 1.3845903544056122, 1.3906676599554653, 1.3966836204782158, 1.4026397184583859, 1.4085373802763694, 1.4143779790778999, 1.420162837459632, 1.4258932299849347, 1.4315703855427442, 1.437195489561191, 1.4427696860867096, 1.4482940797384127, 1.453769737546694, 1.4591976906842747, 1.4645789360972274, 1.4699144380429032, 1.47520512954113, 1.480451913744542, 1.485655665233442, 1.4908172312401793, 1.4959374328076418, 1.5010170658861153, 1.5060569023724397, 1.511057691095106, 1.5160201587486637, 1.5209450107805713, 1.5258329322333906, 1.5306845885450266, 1.5355006263095177, 1.5402816740007106, 1.5450283426609974, 1.5497412265571342, 1.5544209038050336, 1.5590679369652922], [0.0, 0.4287093850145174, 0.5278031643091579, 0.5960728861369785, 0.6498019170849885, 0.6947906928878749, 0.7338518037139214, 0.7685858822925763, 0.8000000000000002, 0.8287732856038029, 0.8553876799929505, 0.8801988492505947, 0.9034775483654844, 0.925435162101199, 0.9462402151602787, 0.9660294550275881, 0.9849155306759331, 1.0029924578885194, 1.0203396005006329, 1.037024629752189, 1.0531057634673902, 1.0686334871972962, 1.0836518958874939, 1.0981997530125958, 1.1123113362527277, 1.1260171197494695, 1.1393443297338381, 1.1523174009506618, 1.1649583545768687, 1.1772871134339291, 1.189321766683849, 1.201078793504447, 1.2125732532083184, 1.2238189477225525, 1.2348285611565368, 1.2456137802623908, 1.2561853988709377, 1.2665534088175026, 1.276727079420488, 1.2867150272150552, 1.29652527735421, 1.3061653178549548, 1.3156421476762474, 1.3249623194593252, 1.334131977632515, 1.3431568924765382, 1.352042490658224, 1.3607938826670916, 1.3694158875277642, 1.3779130551094754, 1.386289686310293, 1.3945498513567331, 1.402697406428023, 1.4107360087874778, 1.4186691305805412, 1.4265000714393545, 1.434231970016798, 1.4418678145583093, 1.4494104526071445, 1.4568625999277456, 1.4642268487223267, 1.471505675207448, 1.4787014466100523, 1.4858164276360457, 1.492852786458892, 1.4998126002707441, 1.5066978604342747, 1.5135104772695174, 1.5202522845066118, 1.5269250434323196, 1.5335304467554844, 1.540070122214213, 1.5465456359454104, 1.5529584956353981, 1.5593101534686282, 1.565602008889975, 1.5718354111947048, 1.5780116619589986, 1.5841320173227669, 1.590197690135518, 1.5962098519751038, 1.6021696350483756, 1.6080781339820145, 1.6139364075111444, 1.6197454800727193, 1.6255063433101167, 1.6312199574948705, 1.6368872528710126, 1.6425091309270756, 1.6480864656004197, 1.6536201044182084, 1.6591108695790213, 1.664559558978819, 1.6699669471846816, 1.6753337863595275, 1.6806608071407547, 1.6859487194755771, 1.6911982134156034, 1.6964099598730564, 1.7015846113408488, 1.7067228025785934, 1.7118251512664795], [0.0, 0.46555367217460797, 0.5731638026099791, 0.6473007839923779, 0.7056474135148042, 0.754502629924318, 0.7969207439660005, 0.834639950489428, 0.8687538709400412, 0.8999999999999999, 0.928901697685371, 0.9558451968542797, 0.9811245218124158, 1.0049692242243011, 1.0275623121995368, 1.0490522856216442, 1.0695614747796018, 1.0891919753928967, 1.1080299720104247, 1.1261489516967214, 1.1436121356519529, 1.1604743482735074, 1.1767834741297183, 1.1925816081188618, 1.2079059738250584, 1.222789664408884, 1.2372622459873228, 1.2513502532843184, 1.2650776000282442, 1.2784659212544414, 1.2915348607498025, 1.3043023139512282, 1.3167846344038565, 1.3289968102046688, 1.3409526155650782, 1.3526647416240118, 1.364144909859358, 1.3754039708281371, 1.3864519904756525, 1.3972983258622491, 1.4079516918413502, 1.4184202199676512, 1.4287115107070112, 1.4388326798499798, 1.4487903998914242, 1.4585909370234862, 1.468240184293433, 1.4777436913982047, 1.4871066915206712, 1.4963341255564684, 1.5054306640329027, 1.5144007269812758, 1.5232485019898763, 1.5319779606357815, 1.5405928734687344, 1.5490968236989804, 1.5574932197225675, 1.5657853066017355, 1.573976176604267, 1.5820687788937515, 1.590065928452324, 1.5979703143083865, 1.6057845071339016, 1.6135109662688976, 1.6211520462247362, 1.6287100027123216, 1.6361869982366921, 1.6435851072952525, 1.6509063212131994, 1.6581525526463972, 1.6653256397790468, 1.6724273502408746, 1.6794593847662533, 1.6864233806155935, 1.6933209147774753, 1.7001535069683376, 1.7069226224450387, 1.7136296746442592, 1.7202760276615123, 1.7268629985814288, 1.7333918596700015, 1.7398638404385864, 1.746280129588641, 1.7526418768454626, 1.7589501946885124, 1.7652061599853188, 1.7714108155353971, 1.7775651715301273, 1.7836702069340744, 1.7897268707928191, 1.7957360834719915, 1.8016987378318405, 1.8076157003413704, 1.813487812135769, 1.819315890020594, 1.8251007274259305, 1.8308430953135162, 1.8365437430396088, 1.8422033991761966, 1.8478227722929594, 1.8534025517022357, 1.858943408169094], [0.0, 0.5011872336272724, 0.6170338627200097, 0.696845301935949, 0.7596577929323739, 0.8122523963562356, 0.8579172004440949, 0.8985234417906398, 0.9352484478226214, 0.9688861611972633, 1.0, 1.029005759421095, 1.0562199684392581, 1.0818897486445278, 1.1062121156199922, 1.1293469354568555, 1.1514259016263246, 1.172558924272542, 1.1928387845252129, 1.2123445941619542, 1.2311444133449163, 1.2492972627406829, 1.2668546920110242, 1.2838620180052702, 1.3003593134073366, 1.3163822043342375, 1.331962519898846, 1.3471288257976295, 1.361906866120014, 1.3763199318508206, 1.3903891703159093, 1.4041338466721258, 1.4175715661678827, 1.4307184640917885, 1.4435893689358648, 1.4561979432210856, 1.468556805589356, 1.480677637101274, 1.4925712741513997, 1.5042477899911526, 1.515716566510398, 1.526986357654484, 1.5380653456302877, 1.5489611908722423, 1.5596810765891669, 1.570231748588672, 1.5806195509729186, 1.5908504582136445, 1.6009301040424735, 1.6108638075320785, 1.6206565966927624, 1.6303132298658147, 1.6398382151582813, 1.6492358281324606, 1.6585101279366483, 1.6676649720406433, 1.6767040297197382, 1.6856307944138174, 1.6944485950733936, 1.7031606065915657, 1.711769859409705, 1.72027924837493, 1.728691540918895, 1.7370093846199548, 1.7452353142041923, 1.7533717580350285, 1.7614210441360247, 1.7693854057869884, 1.7772669867295032, 1.7850678460144567, 1.792789962520997, 1.8004352391735468, 1.8080055068809922, 1.8155025282199486, 1.8229280008819848, 1.8302835609029082, 1.8375707856905992, 1.8447911968664352, 1.8519462629340444, 1.859037401787951, 1.8660659830736148, 1.8730333304094111, 1.8799407234802201, 1.886789400011519, 1.8935805576321465, 1.9003153556332644, 1.9069949166304496, 1.9136203281353112, 1.9201926440425374, 1.926712886037828, 1.9331820449317627, 1.939601081924274, 1.945970929804059, 1.9522924940869435, 1.9585666540969286, 1.9647942639933809, 1.9709761537475867, 1.9771131300716664, 1.983205977302639, 1.9892554582442339, 1.9952623149688795, 2.0012272695821234], [0.0, 0.5357656669484114, 0.6596049077255498, 0.7449227811521515, 0.8120688971611996, 0.8682921624214405, 0.917107520388829, 0.9605153099684796, 0.9997740859911782, 1.0357325676355595, 1.068993044916333, 1.1, 1.1290918001633157, 1.1565326166672798, 1.182533057799954, 1.2072640193009534, 1.2308662805750588, 1.2534573348019247, 1.2751363643639049, 1.2959879392010434, 1.3160848151533144, 1.3354900849028026, 1.3542588546794079, 1.3724395678798817, 1.390075061924621, 1.4072034208849309, 1.423858669861099, 1.4400713453839722, 1.4558689677060943, 1.4712764347282485, 1.4863163527946976, 1.5010093162241192, 1.5153741449046199, 1.5294280873475001, 1.5431869951075976, 1.5566654733248098, 1.569877011239569, 1.582834095824412, 1.5955483111097555, 1.6080304253313067, 1.62029046766408, 1.6323377960147674, 1.6441811571056133, 1.6558287398877474, 1.6672882231614379, 1.6785668181481024, 1.6896713066488271, 1.7006080753323474, 1.7113831466185854, 1.7220022065592342, 1.7324706300623374, 1.7427935037616387, 1.752975646792216, 1.763021629700429, 1.7729357916875745, 1.7827222563620386, 1.7923849461535886, 1.801927595525164, 1.8113537631017096, 1.8206668428218664, 1.8298700742063838, 1.838966551826697, 1.8479592340479971, 1.8568509511131313, 1.8656444126266527, 1.8743422144921689, 1.8829468453506757, 1.8914606925627542, 1.8998860477732475, 1.9082251120932339, 1.9164800009307592, 1.9246527484987959, 1.9327453120262097, 1.9407595756951437, 1.9486973543260766, 1.9565603968299083, 1.9643503894446919, 1.9720689587730968, 1.9797176746352878, 1.98729805275065, 1.9948115572606537, 2.0022596031041364, 2.0096435582553345, 2.0169647458341746, 2.024224446097556, 2.0314238983196673, 2.0385643025687528, 2.0456468213871584, 2.0526725813809765, 2.0596426747251133, 2.0665581605891883, 2.0734200664892435, 2.080229389569909, 2.0869870978213036, 2.09369413123467, 2.1003514029004298, 2.106959800052115, 2.1135201850593726, 2.12003339637302, 2.126500249424939, 2.132921537485394, 2.1392980324801933], [0.0, 0.5694123367516263, 0.7010288172814388, 0.7917047464637367, 0.8630677119898374, 0.9228218597947637, 0.9747028756274828, 1.0208367218639414, 1.0625609919546677, 1.1007777055708823, 1.1361269771988889, 1.1690812029713358, 1.2000000000000002, 1.2291641297899731, 1.2567974270601296, 1.2830815199894259, 1.3081660290832213, 1.3321758262213441, 1.3552163225482268, 1.3773773990886347, 1.398736380828859, 1.4193603227404181, 1.4393077917847144, 1.458630273656793, 1.4773732960138999, 1.4955773346486674, 1.5132785514748908, 1.5305094007509494, 1.5472991310313433, 1.5636742038322535, 1.579658645201085, 1.5952743428022504, 1.6105412984334113, 1.6254778438312407, 1.6401008260455556, 1.6544257674350114, 1.6684670043790915, 1.6822378080458638, 1.6957504899555238, 1.7090164946007573, 1.7220464809997371, 1.7348503947459304, 1.747437531865303, 1.7598165955840717, 1.7719957469395589, 1.7839826500257736, 1.7957845125483272, 1.8074081222657352, 1.818859879812478, 1.830145828330513, 1.841271680277987, 1.8522428417348054, 1.8630644344829994, 1.8737413161042387, 1.8842780983064067, 1.8946791636650058, 1.904948680942682, 1.915090619130732, 1.9251087603396388, 1.9350067116511014, 1.9447879160313153, 1.954455662394186, 1.9640130948934735, 1.9734632215143715, 1.982808922027562, 1.9920529553622386, 2.0011979664487725, 2.0102464925766004, 2.0192009693083683, 2.0280637359873364, 2.0368370408714895, 2.0455230459246003, 2.0541238312916463, 2.0626413994834705, 2.071077679293263, 2.0794345294654395, 2.0877137421356475, 2.0959170460589833, 2.1040461096420344, 2.112102543793021, 2.120087904603099, 2.1280036958708117, 2.135851371480675, 2.1436323376459923, 2.151347955025197, 2.1589995407202522, 2.166588370165, 2.174115678910717, 2.1815826643155902, 2.188990487144305, 2.1963402730834902, 2.2036331141783196, 2.2108700701951967, 2.2180521699150786, 2.225180412361685, 2.2322557679685153, 2.2392791796883382, 2.246251564048556, 2.2531738121556155, 2.260046790651412, 2.2668713426244502, 2.2736482884783236], [0.0, 0.6022271719754775, 0.7414286183421172, 0.8373301379846805, 0.9128057013659376, 0.9760034389696842, 1.0308743215051672, 1.0796668290750424, 1.1237956397060622, 1.1642147558330256, 1.2016011812929526, 1.2364545360776396, 1.2691551617818178, 1.3, 1.3292257848895588, 1.3570246117345335, 1.3835547235654946, 1.4089481885414803, 1.4333164925775455, 1.4567546964791294, 1.4793445814174706, 1.5011570666952567, 1.5222540944469662, 1.5426901174522867, 1.5625132870955483, 1.5817664117610406, 1.6004877373483912, 1.6187115884322196, 1.6364688991407919, 1.653787655948982, 1.6706932695085248, 1.687208888854644, 1.7033556684746287, 1.7191529965503318, 1.734618691015283, 1.7497691687708243, 1.7646195923919752, 1.7791839978549486, 1.7934754061842493, 1.8075059214106821, 1.8212868168241922, 1.834828611175851, 1.8481411362151072, 1.861233596729025, 1.874114624069807, 1.8867923240078468, 1.8992743196237953, 1.9115677898499501, 1.9236795041848855, 1.935615854032609, 1.9473828810562395, 1.958986302884292, 1.9704315364635177, 1.9817237193146255, 1.9928677289150025, 2.003868200404916, 2.0147295427898912, 2.025455953791421, 2.0360514334803734, 2.046519796812047, 2.0568646851683727, 2.0670895770010684, 2.0771977976592786, 2.0871925284762822, 2.097076815181935, 2.1068535757005913, 2.1165256073881134, 2.1260955937561556, 2.1355661107271375, 2.1449396324590375, 2.154218536775378, 2.1634051102323935, 2.1725015528523635, 2.181509982549432, 2.1904324392717935, 2.199270888882006, 2.208027226795243, 2.2167032813935483, 2.2253008172326165, 2.233821538056183, 2.2422670896318504, 2.2506390624210217, 2.2589389940945606, 2.2671683719048623, 2.275328634924155, 2.283421176158068, 2.291447344542804, 2.2994084468335974, 2.307305749391551, 2.315140479875408, 2.3229138288443316, 2.3306269512772966, 2.3382809680143026, 2.345876967124236, 2.3534160052038553, 2.3608991086120636, 2.3683272746433404, 2.375701472643921, 2.3830226450740954, 2.390291708519725, 2.3975095546559166, 2.4046770511655495], [0.0, 0.6342925711719627, 0.7809057554245447, 0.88191352176933, 0.9614077581398196, 1.027970439703055, 1.085762905379651, 1.13715335489873, 1.1836317903802993, 1.2262030098232404, 1.265580063924133, 1.3022891747864505, 1.336730935175302, 1.3692180972484058, 1.4000000000000001, 1.4292789667680108, 1.4572216661841464, 1.4839671983356564, 1.509632985170604, 1.5343191489775632, 1.5581118253408985, 1.5810857096395978, 1.6033060420979, 1.6248301748168763, 1.6457088229863988, 1.6659870743099154, 1.685705211078131, 1.7048993854670063, 1.723602178682883, 1.74184306733182, 1.7596488150478307, 1.7770438034293479, 1.7940503133277823, 1.810688765242723, 1.8269779258180505, 1.8429350860679325, 1.8585762158939978, 1.8739160986136645, 1.888968448551853, 1.9037460142147387, 1.918260669135097, 1.932523492131641, 1.9465448384422732, 1.9603344029600935, 1.9739012766109785, 1.9872539967545548, 2.000400592360041, 2.0133486245997605, 2.0261052234121424, 2.03867712050952, 2.0510706792414943, 2.0632919216699377, 2.0753465531652537, 2.08723998479385, 2.0989773537328853, 2.110563541919235, 2.1220031931145575, 2.1333007285467263, 2.144460361269143, 2.1554861093632187, 2.1663818080951387, 2.1771511211257035, 2.187797550861243, 2.1983244480241413, 2.208735020513196, 2.219032341616741, 2.2292193576349835, 2.239298894962325, 2.249273666675376, 2.2591462786678904, 2.2689192353698675, 2.278594945084519, 2.2881757249736308, 2.2976638057190275, 2.3070613358853143, 2.3163703860067923, 2.3255929524194277, 2.334730960856901, 2.343786269828127, 2.352760673792149, 2.361655906144956, 2.370473642031574, 2.3792155009956777, 2.387883049477955, 2.3964778031735876, 2.4050012292583585, 2.4134547484921614, 2.421839737208008, 2.4301575291940045, 2.438409417475205, 2.4465966560017263, 2.4547204612490403, 2.4627820137359255, 2.470782459465159, 2.4787229112916664, 2.486604450222513, 2.4944281266528128, 2.5021949615413424, 2.5099059475293966, 2.517562050006168, 2.525164208123728, 2.532713335764462], [0.0, 0.6656775051475126, 0.8195451415517419, 0.9255507940800144, 1.0089784225053955, 1.0788346399872966, 1.1394866893985607, 1.19341994950448, 1.2421981480530844, 1.2868758006661423, 1.328201239943334, 1.3667267255719306, 1.402872671733932, 1.4369673056316439, 1.4692723036068125, 1.5, 1.5293253102429558, 1.5573942171254123, 1.5843299526588872, 1.6102375932045057, 1.6352075363540264, 1.6593181734299882, 1.6826379727570728, 1.705227124230751, 1.727138852439487, 1.7484204760360735, 1.7691142704876952, 1.789258176787819, 1.808886388267943, 1.8280298400429849, 1.8467166200173741, 1.8649723161963208, 1.882820311892596, 1.900282038016536, 1.9173771897896308, 1.9341239137891788, 1.9505389701110045, 1.9666378735542782, 1.9824350170316911, 1.9979437798482689, 2.0131766230417636, 2.028145173613241, 2.042860299180021, 2.0573321743406154, 2.0715703398418857, 2.0855837554738637, 2.0993808474809064, 2.1129695511637836, 2.126357349251824, 2.1395513065439467, 2.152558101249671, 2.165384053403797, 2.178035150679693, 2.1905170718845057, 2.202835208384034, 2.214994683674448, 2.227000371291741, 2.2388569112270993, 2.2505687249967217, 2.2621400294975587, 2.273574849765597, 2.2848770307403687, 2.296050248128029, 2.3070980184454317, 2.3180237083189024, 2.3288305431037486, 2.33952161488375, 2.3500998899039174, 2.3605682154844794, 2.370929326459378, 2.3811858511783517, 2.391340317107978, 2.40139515606371, 2.4113527091019935, 2.4212152310988753, 2.4309848950391433, 2.4406637960379003, 2.4502539551145466, 2.4597573227374214, 2.4691757821557907, 2.478511152534452, 2.4877651919049724, 2.496939599946397, 2.506036020607239, 2.515056044579607, 2.5240012116354595, 2.532873012834198, 2.54167289261009, 2.5504022507473674, 2.5590624442502428, 2.5676547891145574, 2.576180562007253, 2.584641001859434, 2.5930373113783425, 2.6013706584832077, 2.609642177669559, 2.617852971306288, 2.6260041108694336, 2.6340966381163966, 2.6421315662040366, 2.650109880753873, 2.658032540867389], [0.0, 0.6964404506368994, 0.8574187700290347, 0.9683232603354766, 1.0556063286183155, 1.1286908105283713, 1.1921457722739568, 1.2485714493954332, 1.299603834169977, 1.3463461745354395, 1.3895813857757495, 1.429887249147593, 1.4677036074278427, 1.5033738561780403, 1.5371717645851524, 1.5693194795937333, 1.6, 1.6293660548943611, 1.657546571207606, 1.6846514811933069, 1.710775359985901, 1.7360002216050487, 1.7603976985011893, 1.7840307621246136, 1.8069550967309689, 1.8292202077093056, 1.8508703242023978, 1.8719451405703282, 1.8924804303205571, 1.9125085581720485, 1.9320589100551757, 1.9511582564732863, 1.9698310613518661, 1.9880997459876193, 2.005984915777039, 2.0235055559049524, 2.0406792010012653, 2.0575220828503507, 2.074049259504378, 2.0902747285660146, 2.10621152693478, 2.121871818930182, 2.1372669743945925, 2.152407638125106, 2.1673037917749873, 2.1819648091929253, 2.196399506025191, 2.210616184286502, 2.224622672505455, 2.2384263619664257, 2.252034239498939, 2.2654529172054767, 2.2786886594676763, 2.2917474075273203, 2.304634801901323, 2.3173562028579138, 2.3299167091537374, 2.3423211752078297, 2.3545742268678582, 2.366680275906174, 2.378643533367698, 2.3904680218781, 2.402157587008894, 2.413715907785679, 2.4251465064166373, 2.436452757310377, 2.447637895445105, 2.4587050241448702, 2.4696571223130737, 2.480497051168501, 2.491227560524781, 2.5018512946502702, 2.5123707977418754, 2.522788519043253, 2.533106817635005, 2.5433279669220368, 2.553454158840976, 2.563487507808565, 2.57343005443011, 2.5832837689854498, 2.59305055470842, 2.602732250874477, 2.612330635709909, 2.6218474291350016, 2.631284295352495, 2.640642845291808, 2.64992463891865, 2.6591311874189105, 2.66826395526503, 2.6773243621724387, 2.686313784953076, 2.695233559272476, 2.704084981316448, 2.712869309372929, 2.721587765334183, 2.730241536124166, 2.7388317750555284, 2.747359603120416, 2.7558261102189507, 2.7642323563289963, 2.7725793726205854, 2.7808681625181464], [0.0, 0.7266315402400413, 0.8945883613267386, 1.0103006243597221, 1.1013674632907975, 1.1776201990550452, 1.2438259694793528, 1.302697731793518, 1.3559423994703275, 1.4047110468731592, 1.4498205291087471, 1.4918736745798402, 1.5313293934978294, 1.5685459678171387, 1.6038090347746836, 1.6373503715114004, 1.6693609099253943, 1.7000000000000002, 1.7294021577217789, 1.7576820809700138, 1.7849384447650047, 1.8112568184808064, 1.836711939875322, 1.8613695102470247, 1.8852876277957118, 1.908517943997203, 1.9311066053527652, 1.9530950269955645, 1.9745205332349542, 1.9954168918188715, 2.0158147625744833, 2.035742076521682, 2.055224358111035, 2.0742850006152107, 2.0929455026863577, 2.1112256725278638, 2.129143804905812, 2.1467168352616586, 2.1639604744226992, 2.1808893267956364, 2.1975169944369988, 2.2138561689964624, 2.229918713205532, 2.2457157333193094, 2.2612576437014065, 2.2765542245621817, 2.2916146737111873, 2.3064476530601987, 2.3210613305089804, 2.335463417758289, 2.3496612045206824, 2.363661589537046, 2.377471108753523, 2.391095960968107, 2.4045420312173276, 2.4178149121400896, 2.430919923527039, 2.4438621302390384, 2.4566463586568807, 2.4692772118057587, 2.4817590832817844, 2.494096170093739, 2.5062924845208476, 2.518351865076562, 2.5302779866587928, 2.542074369958679, 2.5537443901925734, 2.565291285215387, 2.576718163067677, 2.588028009003691, 2.599223692043043, 2.6103079710846253, 2.6212835006177286, 2.6321528360621143, 2.6429184387658697, 2.6535826806872964, 2.6641478487847206, 2.674616149136054, 2.6849897108080034, 2.6952705894931577, 2.7054607709316225, 2.7155621741324913, 2.7255766544091737, 2.735506006241476, 2.7453519659762753, 2.755116214377696, 2.7648003790368496, 2.774406036650391, 2.7839347151764757, 2.793387895876005, 2.802767015246498, 2.8120734668553493, 2.8213086030787617, 2.830473736752168, 2.8395701427375575, 2.848599059412715, 2.8575616900870497, 2.8664592043483546, 2.875292739344542, 2.8840634010041186, 2.8927722651989245, 2.9014203788524076], [0.0, 0.7562941717125412, 0.9311073443492159, 1.051543225922158, 1.1463276052199582, 1.2256931384262186, 1.2946015679847558, 1.3558765997593754, 1.4112948270296084, 1.4620543134412238, 1.509005259848636, 1.5527751033809727, 1.5938414879320009, 1.6325773212809114, 1.669279900978856, 1.704190465798333, 1.7375077418800822, 1.7693975842097245, 1.8, 1.829434369339449, 1.857803395370742, 1.885196140590194, 1.9116903937085594, 1.9373545380898372, 1.9622490436248319, 1.9864276703115065, 2.0099384484486023, 2.0328244838223397, 2.0551246243990735, 2.0768740163974044, 2.098104571243288, 2.118845360159736, 2.1391229495592037, 2.158961687677071, 2.1783839507857934, 2.197410355701384, 2.216059944020849, 2.2343503425260725, 2.2522979033934427, 2.269917827212336, 2.2872242713039057, 2.304230445417727, 2.3209486965470147, 2.3373905843276206, 2.353566948259436, 2.369487967801627, 2.3851632162377236, 2.4006017090770024, 2.4158119476501168, 2.4308019584657075, 2.445579328817768, 2.460151239068333, 2.474524491974646, 2.4887055393827042, 2.5027005065686367, 2.5165152144746594, 2.530155200056489, 2.5436257349332854, 2.5569318425088827, 2.5700783137136662, 2.5830697214996055, 2.595910434206228, 2.6086046279024564, 2.6211562977979543, 2.6335692688077135, 2.645847205344908, 2.657993620409338, 2.670011884031979, 2.6819052311301563, 2.6936767688224905, 2.7053294832480237, 2.7168662459297193, 2.7282898197187166, 2.7396028643523995, 2.7508079416562743, 2.76190752041698, 2.772903980951305, 2.7837996193939114, 2.7945966517244982, 2.80529721755336, 2.8159033836827008, 2.8264171474596096, 2.8368404399353024, 2.8471751288440346, 2.8574230214140224, 2.8675858670217274, 2.87766535969996, 2.8876631405094577, 2.897580799782849, 2.907419879249228, 2.9171818740469724, 2.9268682346318347, 2.9364803685868663, 2.94601964234021, 2.9554873827964094, 2.9648848788864415, 2.9742133830413424, 2.9834741125939455, 2.9926682511129368, 3.001796949673158, 3.0108613280658054, 3.019862475951949], [0.0, 0.7854662349940812, 0.9670223670840282, 1.0921037467845816, 1.1905441848150782, 1.2729710352225851, 1.3445374266468886, 1.4081759819965476, 1.465731821975361, 1.5184492223907102, 1.5672111783641802, 1.6126693287658624, 1.655319741349467, 1.6955497078333173, 1.7336679932415409, 1.7699251414993142, 1.804527544086831, 1.8376474534106062, 1.8694302770942552, 1.9000000000000001, 1.9294632867747636, 1.9579126352669705, 1.9854288346827877, 2.012082906095054, 2.0379376518619483, 2.0630489056322974, 2.0874665503475933, 2.1112353544866576, 2.134395664474215, 2.156983982202033, 2.179033449995591, 2.2005742604240512, 2.2216340046295238, 2.242237970016682, 2.2624093959639797, 2.2821696945270133, 2.301538641782431, 2.3205345444189778, 2.339174385355341, 2.3574739515037484, 2.37544794626687, 2.3931100889257113, 2.4104732027263536, 2.427549293187271, 2.4443496179136215, 2.4608847490105, 2.4771646290257294, 2.493198621218202, 2.5089955548350944, 2.5245637659865587, 2.539911134626546, 2.555045118080716, 2.5699727815048243, 2.5847008256078983, 2.5992356119325217, 2.6135831859484844, 2.6277492981850403, 2.641739423600228, 2.655558779362503, 2.6692123411998194, 2.682704858453771, 2.6960408679611203, 2.7092247068716917, 2.722260524499879, 2.7351522932967325, 2.7479038190205514, 2.760518750175884, 2.7730005867838092, 2.7853526885401005, 2.7975782824123256, 2.8096804697220064, 2.8216622327535688, 2.8335264409278866, 2.8452758565747343, 2.856913140335315, 2.8684408562232346, 2.8798614763697565, 2.8911773854769125, 2.9023908850000035, 2.9135041970791784, 2.9245194682381124, 2.935438772866318, 2.9462641165002452, 2.956997438917097, 2.967640617054178, 2.9781954677655547, 2.9886637504269085, 2.9990471693985903, 3.009347376356136, 3.0195659724967947, 3.0297045106299834, 3.03976449715898, 3.0497473939606587, 3.059654620169543, 3.069487553872037, 3.0792475337162486, 3.088935860442455, 3.098553798338909, 3.1081025766273545, 3.117583390782323, 3.1269974037880197, 3.1363457473363305], [0.0, 0.8141810630738088, 1.0023744672545447, 1.132028532774118, 1.2340677254400192, 1.3195079107728942, 1.3936906038718977, 1.4596556375533993, 1.5193155858647478, 1.573960212457742, 1.624504792712471, 1.6716247879083048, 1.7158344008881896, 1.757535081859526, 1.7970468835812794, 1.8346295092848033, 1.8704968956452424, 1.9048275922185238, 1.9377723223945267, 1.9694596036351502, 2.0, 2.02948939084481, 2.05801151884219, 2.085640001431066, 2.1124399368785163, 2.138469199982376, 2.163779497289055, 2.1884172339093726, 2.2124242312399844, 2.2358383255973595, 2.2586938709137105, 2.2810221635286663, 2.3028518032526493, 2.3242090019393356, 2.3451178485450836, 2.365600537900696, 2.3856775690504253, 2.405367917933196, 2.4246891883239083, 2.44365774426777, 2.462288826689832, 2.4805966564162687, 2.4985945254813657, 2.516294878297574, 2.533709384022048, 2.5508490012515814, 2.56772403601054, 2.584344193856896, 2.600718626814673, 2.616855975742921, 2.6327644086684745, 2.6484516555395645, 2.663925039797692, 2.6791915071143033, 2.6942576515952585, 2.709129739718734, 2.723813732240028, 2.7383153042689763, 2.7526398637016407, 2.7667925681670775, 2.7807783406318185, 2.7946018837888813, 2.8082676933442516, 2.8217800703016565, 2.8351431323357654, 2.848360824334595, 2.861436928183577, 2.874375071856463, 2.8871787378717295, 2.899851271167412, 2.912395886442171, 2.9248156750058505, 2.937113611178712, 2.9492925582749145, 2.961355274202548, 2.973304416709622, 2.9851425483027993, 2.9968721408632994, 3.008495579982305, 3.0200151690362658, 3.031433133020796, 3.0427516221602895, 3.0539727153089675, 3.0650984231578002, 3.0761306912605755, 3.0870714028913415, 3.0979223817444845, 3.1086853944878245, 3.1193621531783338, 3.1299543175493283, 3.1404634971773437, 3.150891253536277, 3.1612391019458372, 3.171508513420823, 3.181700916427289, 3.191817698551219, 3.2018602080849465, 3.211829755536177, 3.221727615064157, 3.2315550258472006, 3.2413131933855244, 3.2510032907430517], [0.0, 0.8424681795174463, 1.037199992633766, 1.1713586331368167, 1.2769429764524494, 1.3653516126386918, 1.4421116372097291, 1.5103684959822152, 1.5721012116194621, 1.628644358069476, 1.6809450101515975, 1.729702096716145, 1.7754476855704486, 1.818597174518185, 1.859481735920668, 1.8983700958861995, 1.9354836238980746, 1.9710070728646545, 2.005096402762953, 2.0378845961408003, 2.069486058388153, 2.1, 2.12951307312307, 2.1581014528891194, 2.1858324992762195, 2.212766097827997, 2.238955751532913, 2.264449477755906, 2.2892905508956374, 2.3135181218168235, 2.337167738011347, 2.360271783148478, 2.3828598506826877, 2.4049590631468494, 2.4265943464206354, 2.4477886664505033, 2.4685632344795976, 2.488937685728444, 2.5089302355804075, 2.5285578166171963, 2.5478361992797653, 2.5667800984688673, 2.5854032680243244, 2.6037185847151716, 2.6217381231204318, 2.639473222571746, 2.656934547155986, 2.6741321396316082, 2.6910754699916737, 2.7077734793048505, 2.724234619379969, 2.7404668887270756, 2.7564778652262145, 2.772274735862497, 2.7878643238409966, 2.8032531133563228, 2.81844727225847, 2.8334526728277796, 2.848274910847006, 2.86291932313686, 2.877391003702645, 2.8916948186231792, 2.9058354197988927, 2.91981725766341, 2.9336445929518926, 2.9473215076097152, 2.9608519149164674, 2.9742395688926977, 2.9874880730501236, 3.000600888540061, 3.0135813417495396, 3.0264326313898713, 3.0391578351182136, 3.0517599157289323, 3.0642417269481994, 3.076606018862241, 3.0888554430069632, 3.1009925571442274, 3.11301982974788, 3.1249396442206465, 3.1367543028612284, 3.148466030599328, 3.16007697851486, 3.1715892271562893, 3.1830047896718363, 3.194325614766194, 3.205553589494416, 3.216690541903714, 3.2277382435331057, 3.2386984117800703, 3.249572712142708, 3.2603627603452483, 3.2710701243541975, 3.281696326291865, 3.292242844253542, 3.302711114034154, 3.3131025307697937, 3.323418450499174, 3.333660191649693, 3.3438290364524743, 3.3539262322904633, 3.3639529929833762], [0.0, 0.8703538937284879, 1.0715313338968229, 1.2101306281823734, 1.3192098154510994, 1.4105447793283052, 1.489845562304303, 1.5603617245174997, 1.6241377943223991, 1.6825525200923601, 1.7365843248428807, 1.786955271983718, 1.8342150407776578, 1.8787927787042913, 1.921030619936959, 1.9612061854237197, 1.9995481719823562, 2.036247447846327, 2.071465135271119, 2.1053386185296534, 2.137986089832666, 2.1695100435445878, 2.2, 2.2295346557291005, 2.2581836003266313, 2.2860087015489547, 2.3130652333345596, 2.339402802424159, 2.365066115599908, 2.390095619620957, 2.4145280386019063, 2.4383968281121504, 2.4617325611501175, 2.484563258005082, 2.506914669603849, 2.5288105220661805, 2.5502727287278097, 2.571321574735468, 2.5919758784020868, 2.6122531327781813, 2.632169630306629, 2.651740572951702, 2.6709801698056053, 2.6899017238586973, 2.7085177093588158, 2.726839840969715, 2.744879135759763, 2.762645968902929, 2.7801501238492414, 2.7974008376169266, 2.8144068417698618, 2.831176399568942, 2.8477173397221986, 2.8640370871040983, 2.880142690767944, 2.8960408495353223, 2.911737935412189, 2.927240015051488, 2.942552869456497, 2.957682012096805, 2.9726327055893953, 2.987409977080396, 3.0020186324482383, 3.016463269435992, 3.03074828980924, 3.044877910625835, 3.0588561746950007, 3.0726869602954436, 3.086373990215195, 3.0999208401697507, 3.113330946649619, 3.126607614243524, 3.139754022479138, 3.1527732322193827, 3.165668191648824, 3.1784417418816004, 3.191096622219511, 3.2036354750863882, 3.2160608506626134, 3.228375211241592, 3.24058093532816, 3.2526803214972397, 3.2646755920295347, 3.276568896339708, 3.2883623142112266, 3.300057858850951, 3.311657479775495, 3.3231630655404714, 3.3345764463228758, 3.3458993963660797, 3.3571336362962048, 3.3682808353179863, 3.3793426132976547, 3.3903205427397984, 3.4012161506646947, 3.41203092039211, 3.4227662932371707, 3.4334236701234997, 3.444004413118469, 3.4545098468950783, 3.4649412601246747, 3.4752999068044335], [0.0, 0.8978617804534152, 1.105397514961142, 1.248377295982989, 1.3609039750697631, 1.4551256174101361, 1.5369327336960898, 1.609677587728114, 1.6754693260060283, 1.7357302728030064, 1.791469774589561, 1.8434327158814692, 1.892186148776871, 1.938172784134969, 1.9817455694179889, 2.023190899896304, 2.0627447004430937, 2.100603871759509, 2.136934628435069, 2.171878696828189, 2.2055580046622145, 2.2380782856774064, 2.269531889534717, 2.3000000000000003, 2.3295544060752773, 2.3582589308723656, 2.3861705952849293, 2.413340573894779, 2.439814986459997, 2.4656355580759093, 2.4908401735376087, 2.5154633457912863, 2.5395366141073477, 2.563088884367639, 2.5861467213674203, 2.6087346011000605, 2.6308751294811294, 2.652589232777623, 2.6738963240628615, 2.6948144492622954, 2.7153604157480458, 2.7355499059486132, 2.7553975780403066, 2.7749171554598737, 2.7941215067087986, 2.8130227166975206, 2.8316321506933075, 2.8499605117816973, 2.8680178926226123, 2.8858138221739744, 2.903357307964268, 2.92065687441809, 2.9377205976729543, 2.954556137269487, 2.971170765049171, 2.987571391552558, 3.003764590175428, 3.019756619309744, 3.035553442669731, 3.051160747980412, 3.0665839641859085, 3.081828277317335, 3.0968986451448535, 3.111799810725062, 3.126536314943126, 3.141112508138715, 3.1555325608956735, 3.169800474067275, 3.1839200881017713, 3.1978950917265916, 3.211729030043918, 3.225425312085336, 3.2389872178687757, 3.2524179049969693, 3.2657204148330483, 3.2788976782857118, 3.2919525212335, 3.304887669615119, 3.3177057542104325, 3.3304093151346237, 3.343000806066136, 3.3554825982272822, 3.367856984134846, 3.380126181136609, 3.3922923347484364, 3.404357521805405, 3.41632375343939, 3.4281929778945677, 3.4399670831914175, 3.45164789964899, 3.4632372022744913, 3.4747367130285474, 3.486148102973916, 3.4974729943148284, 3.5087129623336555, 3.5198695372310844, 3.530944205875589, 3.5419384134675496, 3.552853565123028, 3.5636910273818514, 3.574452129644344, 3.585138165540769], [0.0, 0.9250130700826243, 1.1388246735032523, 1.286128155043552, 1.4020576345628775, 1.4991285340564295, 1.5834094929274733, 1.6583541472448604, 1.726135423979675, 1.7882186584109354, 1.8456437195895272, 1.899178017296996, 1.9494057512549654, 1.996783019874065, 2.0416734437278827, 2.0843720786636246, 2.125121983909335, 2.164126014432269, 2.2015554111417646, 2.237556186193325, 2.2722539543977778, 2.305757646877729, 2.3381624059426716, 2.3695518703509637, 2.4000000000000004, 2.429572548008903, 2.458328259579946, 2.4863198568114093, 2.513594854120259, 2.540196238366353, 2.5661630399788513, 2.5915308155734933, 2.6163320581664427, 2.640596547751784, 2.664351652442688, 2.687622588385184, 2.7104326450964535, 2.7328033816526274, 2.7547547981772693, 2.7763054863035967, 2.797472761657718, 2.818272780903886, 2.8387206454808362, 2.858830493821269, 2.8786155835694283, 2.898088365082764, 2.9172605473135858, 2.9361431570081344, 2.9547465920277998, 2.9730806694856535, 2.9911546692973343, 3.0089773736655583, 3.026557102949782, 3.043901748314709, 3.0610188015018984, 3.0779153820262577, 3.0945982620626866, 3.1110738892565677, 3.127348407664507, 3.1434276770080127, 3.15931729040217, 3.175022590703382, 3.190548685604501, 3.205900461591889, 3.2210825968668226, 3.2360995733229987, 3.2509556876624814, 3.2656550617241225, 3.2802016520911113, 3.294599259037787, 3.3088515348700223, 3.322961991708325, 3.336934008758183, 3.3507708391080566, 3.3644756160917275, 3.3780513592484085, 3.3915009799110476, 3.4048272864505833, 3.418032989201514, 3.4311207050919643, 3.4440929619994742, 3.4569522028519852, 3.4697007894918603, 3.4823410063193525, 3.494875063730606, 3.5073051013640733, 3.5196331911681433, 3.5318613403017873, 3.5439914938791177, 3.5560255375679297, 3.567965300051547, 3.5798125553625884, 3.5915690250966543, 3.6032363805133416, 3.6148162445314704, 3.626310193624911, 3.637719759624956, 3.6490464314347633, 3.660291656661026, 3.671456843167657, 3.6825433605559734, 3.693552541575544], [0.0, 0.9518269693579394, 1.17183645579605, 1.3234099102098917, 1.4426999059072136, 1.542584656800024, 1.6293087175202055, 1.7064258367216945, 1.7761719292909024, 1.8400548070445832, 1.8991444823309347, 1.9542306102913258, 2.005914325189171, 2.0546649466286566, 2.100856635667338, 2.144793001110237, 2.1867241478865562, 2.2268588112400947, 2.2653731959413967, 2.3024175466864114, 2.338121119556553, 2.372596003325108, 2.4059400982477923, 2.4382394675689683, 2.4695702151051857, 2.5, 2.5295892703375014, 2.558392276502519, 2.5864579102404397, 2.613830404496574, 2.6405499210981453, 2.6666530473614785, 2.692173218196956, 2.7171410768489097, 2.7415847847661436, 2.7655302890499804, 2.7890015543245688, 2.8120207646116904, 2.8346084997902836, 2.8567838904202, 2.8785647540658115, 2.8999677157341246, 2.921008314618183, 2.9417010989897725, 2.9620597108002884, 2.982096961313032, 3.001824898894618, 3.021254869930082, 3.0403975736897526, 3.0592631118611475, 3.0778610333622907, 3.096200374970787, 3.114289698233258, 3.1321371230602524, 3.1497503583608584, 3.1671367300275604, 3.1843032065442842, 3.2012564224581115, 3.2180026999270397, 3.2345480685317796, 3.250898283518341, 3.267058842619656, 3.2830350015882805, 3.2988317885580396, 3.314454017339987, 3.329906299747115, 3.345193057032525, 3.360318530517241, 3.3752867914762628, 3.390101750344722, 3.4047671653000346, 3.419286650270618, 3.433663682416981, 3.4479016091267773, 3.462003654561583, 3.4759729257897733, 3.489812418536822, 3.5035250225815715, 3.517113526824585, 3.530580624052424, 3.543928915419707, 3.5571609146689678, 3.5702790521066854, 3.583285678352371, 3.5961830678762254, 3.608973422339662, 3.6216588737518594, 3.634241487454489, 3.6467232649458334, 3.659106146554652, 3.6713920139733904, 3.6835826926595963, 3.6956799541137775, 3.7076855180413175, 3.7196010544055422, 3.731428185378499, 3.7431684871955775, 3.754823491919649, 3.7663946891200357, 3.7778835274712317, 3.789291416275995, 3.8006197269170916], [0.0, 0.9783209271758405, 1.2044543439509547, 1.3602468222387079, 1.482857236684234, 1.5855222643101055, 1.6746602759693607, 1.7539239383650822, 1.825611402731875, 1.8912724505973293, 1.952006877939368, 2.0086263198292, 2.061748643010334, 2.1118562305262123, 2.1593336581500844, 2.2044929855915294, 2.247591279412124, 2.2888430849691885, 2.328429511666051, 2.3665049862367464, 2.4032023625859047, 2.4386368494606385, 2.472909072155279, 2.5061074894714044, 2.538310323563635, 2.5695871168574183, 2.5999999999999996, 2.6296047334273576, 2.6584515697791176, 2.686585973217844, 2.714049223469066, 2.7408789262514515, 2.767109447130989, 2.79277228230202, 2.8178963770829597, 2.8425084008087205, 2.8666329851550905, 2.890292931632698, 2.9135093929582583, 2.936302032187824, 2.9586891628349403, 2.9806878726611363, 3.002314133390513, 3.023582898243771, 3.044508188893932, 3.0651031732038483, 3.0853802349045725, 3.105351036206029, 3.125026574191096, 3.1444172317262153, 3.1635328235220808, 3.182382637893616, 3.2009754746967825, 3.2193196798585926, 3.237423176864439, 3.2552934955218995, 3.2729377982815833, 3.2903629043621723, 3.3075753118979634, 3.3245812183021224, 3.341386539017049, 3.35799692480423, 3.3744177777092874, 3.3906542658233807, 3.4067113369492574, 3.422593731269017, 3.438305993100663, 3.453852481821741, 3.469237382030566, 3.484464713008632, 3.4995383375416482, 3.5144619701511743, 3.52923918478395, 3.5438734220016515, 3.558367995709897, 3.572726099461835, 3.586950812368498, 3.60104510464528, 3.615011842821364, 3.628853794636613, 3.6425736336483845, 3.6561739435688514, 3.669657222351701, 3.683025886045579, 3.6962822724302136, 3.709428644449928, 3.7224671934580496, 3.735400042284718, 3.7482292481396136, 3.76095680536025, 3.773584648015693, 3.786114652374822, 3.7985486392475902, 3.810888376207117, 3.8231355796999, 3.8352919170508977, 3.8473590083697706, 3.859338428364125, 3.8712317080652174, 3.883040336471174, 3.8947657621124785, 3.9064093945441267], [0.0, 1.004510856630514, 1.2366979292849736, 1.3966610165238238, 1.5225537466344214, 1.6279671462477403, 1.7194914078299375, 1.800876981010554, 1.8744835391863393, 1.941902351977134, 2.0042626572119717, 2.0623978176637467, 2.1169422405444123, 2.1683912224286734, 2.2171396342926024, 2.263507889772954, 2.3077599371762676, 2.3501160653000963, 2.3907622318980017, 2.4298569977516076, 2.467536773302356, 2.5039198514682837, 2.539109551311469, 2.5731966997007674, 2.6062616128201235, 2.6383756947654917, 2.669602739439215, 2.7, 2.7296190743649285, 2.7585066437851253, 2.786705093056113, 2.814253034612342, 2.841185753995777, 2.867535590562839, 2.8933322645063497, 2.918603159106901, 2.943373565437248, 2.967666895410943, 2.9915048680089424, 3.0149076726729036, 3.0378941131743367, 3.0604817347190063, 3.08268693659861, 3.10452507233582, 3.1260105389678325, 3.1471568568649326, 3.1679767412741753, 3.188482166606162, 3.208684424338806, 3.2285941752908376, 3.248221496915547, 3.26757592617869, 3.286666498510874, 3.305501783261952, 3.324089916031274, 3.342438628201508, 3.360555273964103, 3.3784468550901643, 3.396120043670892, 3.413581203025965, 3.4308364069558586, 3.447891457494551, 3.4647519013019625, 3.4814230448205223, 3.4979099683070647, 3.5142175388397128, 3.5303504223891546, 3.546313095034712, 3.562109853397588, 3.5777448243565857, 3.5932219741052847, 3.6085451166040445, 3.6237179214751754, 3.638743921385167, 3.6536265189538346, 3.6683689932266526, 3.682974505743331, 3.6974461062327753, 3.711786737961969, 3.7259992427639586, 3.7400863657679935, 3.754050759852955, 3.7678949898434624, 3.781621536466469, 3.795232800084733, 3.8087311042222396, 3.8221186988954674, 3.835397763763324, 3.848570411107578, 3.861638688654724, 3.874604582249408, 3.8874700183887607, 3.9002368666263347, 3.912906941853685, 3.925482006467071, 3.937963772426214, 3.9503539032115698, 3.962654015686117, 3.9748656818672523, 3.9869904306140067, 3.9990297492344364, 4.010985085017725], [0.0, 1.0304113218507696, 1.2685851423439254, 1.4326727428722108, 1.5618115108490889, 1.6699429060643587, 1.7638270435386598, 1.847311075082052, 1.922815516279639, 1.991972666296311, 2.0559408794061094, 2.1155750059381577, 2.1715258107593014, 2.2243013612486853, 2.2743067097974596, 2.321870531637762, 2.367263580760598, 2.4107118259243716, 2.4524060196464808, 2.492508811064571, 2.531160127848266, 2.568481312998725, 2.604578349572901, 2.6395444063338576, 2.673461870350604, 2.706403986813485, 2.738436194496811, 2.769617222783698, 2.8, 2.8296324110335327, 2.858557933536021, 2.8868161755309734, 2.9144433323682923, 2.94147257724743, 2.9679343966713123, 2.9938568799753265, 3.0192659703412077, 3.044185683338953, 3.068638297955126, 3.0926445241991067, 3.116223650681796, 3.1393936749972915, 3.162171419279195, 3.184572632927812, 3.206612084195799, 3.2283036420647875, 3.249660349633752, 3.2706944900633723, 3.291417645972797, 3.311840753060975, 3.3319741486198304, 3.351827615517738, 3.3714104221562615, 3.390731358838714, 3.4097987709340116, 3.428620589172005, 3.447204357365766, 3.465557257821162, 3.4836861346636394, 3.501597515285706, 3.5192976300956613, 3.5367924307280347, 3.5540876068586953, 3.5711886017522145, 3.5881006266555646, 3.604828674140373, 3.621377530485446, 3.6377517871820366, 3.653955851636101, 3.6699939571345315, 3.6858701721358647, 3.7015884089402107, 3.7171524317879956, 3.732565864432536, 3.747832197227329, 3.7629547937652705, 3.777936897103706, 3.792781635606228, 3.8074920284294773, 3.8220709906807686, 3.8365213382701935, 3.8508457924788786, 3.865046984263281, 3.879127458313808, 3.8930896768845464, 3.906936023409587, 3.9206688059201866, 3.9342902602759193, 3.9478025532219565, 3.961207785283695, 3.974507993509109, 3.9877051540684327, 4.000801184720081, 4.013797947151057, 4.026697249199521, 4.0395008469666305, 4.052210446824285, 4.064827707324907, 4.07735424101904, 4.089791616186053, 4.102141358482988, 4.114404952516158], [0.0, 1.0560356962676238, 1.3001324477526939, 1.468300595557525, 1.6006507996591803, 1.7114712174991589, 1.8076900753316603, 1.8932501963324684, 1.9706322897164728, 2.0415092468315827, 2.1070682280247115, 2.1681853421306294, 2.2255275373036243, 2.279615515594526, 2.3308644022788845, 2.3796110461182147, 2.4261329342415356, 2.470661654821507, 2.513392704028691, 2.5544927757761666, 2.594105277469196, 2.632354569679133, 2.6693492710604603, 2.705184867306595, 2.739945794296627, 2.7737071186898055, 2.806535906598591, 2.8384923478944213, 2.869630687130186, 2.9000000000000004, 2.929644845362292, 2.958605816216958, 2.9869200080235756, 3.014621418936122, 3.0417412935990042, 3.0683084198760824, 3.094349386106795, 3.119888805082798, 3.1449495098267755, 3.169552725366746, 3.1937182199847642, 3.217464438840942, 3.240808622403426, 3.2637669117302224, 3.28635444233241, 3.3085854280868774, 3.330473236449723, 3.352030456040524, 3.3732689575161916, 3.3941999485257566, 3.4148340234299783, 3.4351812083786064, 3.4552510022607654, 3.4750524139779313, 3.4945939964325112, 3.5138838775765584, 3.532929788823462, 3.551739091089409, 3.5703187987002574, 3.588675601372383, 3.6068158844525167, 3.6247457475810463, 3.6424710219252843, 3.659997286113463, 3.677329880986378, 3.694473923271441, 3.7114343182731306, 3.7282157716643747, 3.7448228004549526, 3.76125974320557, 3.7775307695496063, 3.7936398890786527, 3.8095909596426525, 3.825387695110791, 3.8410336726350334, 3.85653233945445, 3.871887019275068, 3.8871009182569463, 3.9021771306374236, 3.9171186440170014, 3.9319283443321127, 3.946609020536982, 3.9611633690149617, 3.97559399773808, 3.989903430192012, 4.004094109082332, 4.018168399836654, 4.032128593916137, 4.045976911948795, 4.059715506696104, 4.073346465863557, 4.086871814764993, 4.100293518849839, 4.113613486101721, 4.126833569316304, 4.13995556826565, 4.152981231755889, 4.1659122595844975, 4.178750304403088, 4.191496973491163, 4.204153830445961, 4.216722396793136], [0.0, 1.081396297513015, 1.3313550102950253, 1.503561700881817, 1.6390902831034837, 1.7525720432035967, 1.851101588160029, 1.938716427688703, 2.0179568450107914, 2.0905359058078465, 2.157669279974593, 2.2202541160198237, 2.2789733787971214, 2.3343602749697316, 2.38683989900896, 2.4367571890687065, 2.4843962961061687, 2.5299943698629193, 2.573751601332285, 2.615838687566514, 2.6564024798866686, 2.695570325371919, 2.7334534511438613, 2.7701496359761597, 2.8057453434678643, 2.8403174429972218, 2.8739346112632878, 2.9066584835917904, 2.938544607213625, 2.9696432363712413, 3.0, 3.0296564659370016, 3.0586506204859116, 3.087017278263285, 3.1147884342508245, 3.1419935676503234, 3.1686599053177744, 3.1948126511187875, 3.2204751864090118, 3.245669245933583, 3.2704150727080528, 3.294731554851377, 3.3186363468599764, 3.3421459774178994, 3.365275945514146, 3.3880408063705665, 3.410454248461502, 3.4325291627210857, 3.454277704878974, 3.4757113517348714, 3.496840952072147, 3.5176767728176257, 3.538228540975391, 3.5585054817948683, 3.578516353575638, 3.598269479461785, 3.6177727765358862, 3.6370337824858625, 3.65605968008597, 3.6748573197055148, 3.6934332400347487, 3.7117936871963697, 3.729944632392642, 3.747891788222049, 3.7656406237851923, 3.7831963786872267, 3.8005640760330723, 3.817748534501965, 3.834754379579262, 3.8515860540158107, 3.8682478275783576, 3.884743806148471, 3.9010779402220095, 3.91725403285639, 3.9332757471085564, 3.9491466130027124, 3.9648700340633827, 3.980449293446269, 3.995887559696538, 4.011187892161646, 4.026353246083528, 4.041386477392888, 4.056290347226482, 4.071067526186549, 4.085720598360042, 4.100252065113889, 4.114664348681232, 4.128959795552461, 4.143140679683772, 4.15720920553501, 4.171167510947728, 4.18501766987349, 4.198761694961814, 4.212401540016378, 4.225939102327568, 4.239376224888809, 4.252714698503649, 4.265956263790047, 4.279102613087894, 4.292155392275365, 4.305116202499342, 4.3179866018247814], [0.0, 1.106504503062049, 1.3622668372858346, 1.5384718779632598, 1.6771472062095032, 1.7932638221577568, 1.8940810576427292, 1.9837301665739255, 2.0648104132818643, 2.1390746379556957, 2.2077667363030735, 2.2718046871141766, 2.3318873125392763, 2.3885601994046817, 2.4422583121612687, 2.4933345978474595, 2.5420798049283744, 2.588736589364233, 2.633509790246954, 2.6765740679276115, 2.718079683368268, 2.7581569404333606, 2.7969196487514143, 2.8344678573549733, 2.870890037382621, 2.906264842990445, 2.940662545435093, 2.974146211111024, 3.0067726769625303, 3.0385933640511547, 3.069654960739493, 3.0999999999999996, 3.1296673501145027, 3.158692634036474, 3.1871085896173477, 3.2149453805164647, 3.24223086575168, 3.2689908343800265, 3.2952492106329556, 3.3210282338998782, 3.346348617205162, 3.371229687218158, 3.395689508343039, 3.4197449930321326, 3.443412000134929, 3.466705422821081, 3.48963926738831, 3.5122267240765868, 3.534480230851192, 3.5564115309838393, 3.5780317251484264, 3.5993513186525723, 3.620380264345056, 3.6411280016700993, 3.661603492280287, 3.6818152525691277, 3.701771383440558, 3.721479597594951, 3.7409472445785146, 3.7601813338146237, 3.7791885558109355, 3.7979753017146236, 3.81654768136924, 3.8349115400102076, 3.8530724737214586, 3.8710358437629773, 3.8888067898677434, 3.906390242596629, 3.9237909348309934, 3.9410134124748946, 3.958062044431891, 3.974941031915225, 3.991654417144632, 4.008206091478135, 4.024599803022706, 4.040839163763781, 4.056927656250009, 4.07286863986645, 4.088665356726569, 4.10432093721073, 4.119838405176621, 4.135220682864862, 4.150470595521164, 4.165590875754666, 4.180584167650478, 4.195453030653066, 4.21019994323576, 4.224827306370512, 4.239337446810962, 4.253732620200811, 4.268015014018699, 4.282186750369864, 4.296249888634165, 4.310206427979319, 4.324058309747607, 4.337807419723666, 4.351455590290494, 4.365004602480277, 4.3784561879261945, 4.391812030720947, 4.405073769187358, 4.418242997566035], [0.0, 1.1313708498984762, 1.3928809012737988, 1.5730457773099473, 1.714837540058069, 1.8335636311938626, 1.9366465206709529, 2.0283103035868377, 2.111212657236631, 2.1871458131829224, 2.257381621056742, 2.3228586892787155, 2.3842915445479136, 2.4422380345998556, 2.4971428987908664, 2.5493670158970603, 2.5992076683399534, 2.6469129652589007, 2.692692349070879, 2.7367244052486903, 2.779162771551499, 2.8201406801473135, 2.8597744982951854, 2.8981665234179173, 2.935407214855686, 2.9715769943502686, 3.00674771235608, 3.040983852551318, 3.0743435291703047, 3.1068793188541104, 3.1386389591874657, 3.169665938981362, 3.1999999999999997, 3.229677565747334, 3.258732109788722, 3.287194473647908, 3.3150931424152117, 3.3424544847021402, 3.3693029623866138, 3.39566131464125, 3.4215507199718016, 3.446990939373609, 3.4720004432100975, 3.496596524005164, 3.520795397002378, 3.5446122900638595, 3.568061524249227, 3.5911565862211776, 3.6139101934619378, 3.636334353148399, 3.6584404154186108, 3.680239121664746, 3.7017406484047957, 3.7229546472145123, 3.743890281140656, 3.764556257964654, 3.7849608606411147, 3.805111975197027, 3.8250171163440965, 3.844683451027653, 3.8641178201103514, 3.8833267583668736, 3.9023165129465727, 3.921093060444168, 3.9396621227037323, 3.9580291814682225, 3.976199491975239, 3.9941780955895734, 4.011969831554078, 4.029579347932381, 4.047011111809905, 4.064269418813264, 4.081358402002531, 4.098282040185762, 4.115044165700701, 4.131648471704513, 4.148098519008756, 4.164397742493561, 4.180549457132028, 4.196556863653199, 4.21242305386956, 4.228151015692905, 4.243743637860364, 4.259203714390681, 4.274533948789185, 4.2897369580184375, 4.304815276250211, 4.319771358413224, 4.334607583549975, 4.349326257994986, 4.36392961838585, 4.378419834517628, 4.392799012050382, 4.407069195078894, 4.421232368573004, 4.435290460696367, 4.44924534501091, 4.463098842573748, 4.4768527239328515, 4.490508711027341, 4.504068478997877, 4.517533657912251], [0.0, 1.1560051208396864, 1.4232092463198949, 1.607297000845234, 1.7521761126275672, 1.8734873248994517, 1.978814723176649, 2.072474377264262, 2.157181832257842, 2.2347683434564543, 2.306533453522472, 2.3734362079720523, 2.4362066914835983, 2.4954148982716218, 2.5515152513693806, 2.6048764872643213, 2.6558023613533925, 2.704546385060941, 2.751322561166487, 2.796313363631672, 2.8396757754973474, 2.8815459299054385, 2.9220427278753354, 2.961270694236026, 2.9993222579735344, 3.036279591918573, 3.0722161109847796, 3.107197702906679, 3.141283747287763, 3.1745279655636867, 3.2069791347489986, 3.2386816905724514, 3.269676240128466, 3.3, 3.329687172599966, 3.3587692709900514, 3.387275400489947, 3.415232503856695, 3.4426655755968643, 3.4695978500018394, 3.496050966714452, 3.5220451170024973, 3.547599173399862, 3.572730804954834, 3.597456579978858, 3.62179205790286, 3.6457518716107047, 3.6693498014213244, 3.692598841725177, 3.7155112611413235, 3.738098656943733, 3.7603720044057733, 3.782341701627157, 3.8040176103353582, 3.8254090930917144, 3.846525047279362, 3.867373936204513, 3.88796381760313, 3.908302369810935, 3.928396915825072, 3.948254445459943, 3.9678816357772697, 3.9872848699507424, 4.006470254708408, 4.025443636480772, 4.044210616369303, 4.062776564038224, 4.081146630622123, 4.099325760732678, 4.117318703639645, 4.1351300236939785, 4.152764110054519, 4.170225185773862, 4.187517316293937, 4.20464441739714, 4.221610262654792, 4.23841849041094, 4.255072610336193, 4.271576009583297, 4.287931958573406, 4.304143616439592, 4.320214036151916, 4.3361461693463665, 4.351942870878162, 4.367606903118283, 4.383140940010578, 4.398547570905429, 4.413829304184746, 4.428988570691881, 4.444027726979081, 4.458949058384094, 4.4737547819467185, 4.488447049175292, 4.503027948672358, 4.517499508628141, 4.531863699189796, 4.54612243471386, 4.560277575908825, 4.574330931874265, 4.5882842620425, 4.602139278028412, 4.615897645392602], [0.0, 1.1804164196559916, 1.4532630804800823, 1.6412382063527704, 1.7891767226534767, 1.913049657359935, 2.020601248719444, 2.116238708754235, 2.2027349265815945, 2.2819598280215994, 2.35524039811009, 2.4235559344765156, 2.487651938958705, 2.548110442308763, 2.6053954635870356, 2.6598835258698146, 2.711884798940654, 2.7616581476112008, 2.8094220937463183, 2.8553629646006162, 2.899641058217494, 2.942395382455212, 2.98374734915968, 3.023803690405156, 3.0626587869956587, 3.1003965470012074, 3.137091935634277, 3.1728122319771868, 3.207618069549367, 3.2415643042191786, 3.2747007430228, 3.3070727600359096, 3.3387218198507878, 3.3696859249510003, 3.4, 3.429696223519124, 3.4588043154435573, 3.487351787479112, 3.5153641619400267, 3.5428651637549855, 3.5698768895300086, 3.596419956910823, 3.622513636961612, 3.648175971847019, 3.673423879750643, 3.6982732486710868, 3.7227390204940485, 3.7468352665367233, 3.770575255591423, 3.793971515352988, 3.8170358879944053, 3.839779580553308, 3.86221321070553, 3.8843468484281205, 3.906190053991128, 3.9277519126632567, 3.9490410664699085, 3.9700657433018263, 3.990833783637742, 4.011352665114141, 4.031629525148967, 4.051671181803097, 4.071484153043363, 4.091074674553265, 4.11044871622207, 4.129611997429409, 4.148570001230421, 4.16732798753593, 4.185891005372715, 4.20426390430061, 4.222451345055727, 4.24045780948254, 4.258287609811623, 4.275944897334627, 4.293433670523316, 4.310757782635319, 4.327920948845398, 4.344926752937693, 4.361778653591272, 4.378479990288601, 4.395033988873997, 4.411443766786929, 4.427712337992924, 4.443842617633028, 4.459837426411063, 4.475699494736407, 4.491431466638618, 4.507035903468972, 4.522515287402812, 4.537872024755575, 4.5531084491243625, 4.568226824366088, 4.583229347422374, 4.598118151000674, 4.612895306120397, 4.627562824532192, 4.64212266101796, 4.6565767155786775, 4.670926835516577, 4.685174817417819, 4.699322409041364, 4.713371311119369], [0.0, 1.2046132367247344, 1.483052856634994, 1.6748811987612655, 1.8258522391413918, 1.952264388561361, 2.0620206308713684, 2.1596185195200337, 2.2478877838122306, 2.3287366803233915, 2.4035193953495484, 2.473235300694993, 2.5386451798992447, 2.6003429944969705, 2.6588022752633083, 2.714407263449127, 2.7674744868667123, 2.818268116679257, 2.86701115413153, 2.9138937459154337, 2.9590794759507477, 3.002710201554332, 3.044909823338075, 3.085787261228278, 3.1254388306979557, 3.163950159810332, 3.201397750455535, 3.2378502608390654, 3.2733695673791745, 3.308011650409616, 3.3418273379382546, 3.3748629341432235, 3.4071607535805417, 3.43875957772933, 3.469695047157766, 3.4999999999999996, 3.5297047654065934, 3.558837419033252, 3.5874240063644773, 3.6154887386554297, 3.643054165460365, 3.6701413270567147, 3.6967698895374035, 3.7229582649051682, 3.748723718141727, 3.774082462926509, 3.799049747432104, 3.823639931417211, 3.8478665556650555, 3.8717424046699724, 3.8952795633522452, 3.9184894684774525, 3.941382955368315, 3.9639703004217433, 3.986261259879395, 4.008265105244749, 4.029990655692137, 4.0514463077720775, 4.072640062681695, 4.09357955133813, 4.114272057465996, 4.134724538886488, 4.154943647175261, 4.174935745838245, 4.194706927138739, 4.214263027695327, 4.233609642957789, 4.252752140657458, 4.27169567331881, 4.290445189910588, 4.309005446707206, 4.327381017424423, 4.345576302687256, 4.363595538882787, 4.381442806445629, 4.399122037619576, 4.416637023735063, 4.433991422038584, 4.4511887621070905, 4.468232451877571, 4.4851257833194556, 4.501871937775179, 4.518473990992171, 4.5349349178676235, 4.551257596925677, 4.567444814545126, 4.583499268954281, 4.599423574008387, 4.61522026276377, 4.630891790861823, 4.646440539734994, 4.661868819645961, 4.67717887257045, 4.692372874933312, 4.707452940206838, 4.722421121379631, 4.737279413303778, 4.752029754927505, 4.766674031420049, 4.78121407619497, 4.795651672837741, 4.809988556943053], [0.0, 1.2286035066475316, 1.5125883434250822, 1.708237010254878, 1.8622146886984314, 1.991144377768182, 2.1030864518443155, 2.2026280346357936, 2.2926552104399165, 2.3751142393912095, 2.451386276852437, 2.5224905974469927, 2.589203135969511, 2.6521296828945276, 2.7117531995187503, 2.7684655793842903, 2.822589654059216, 2.8743948557625654, 2.9241086268824477, 2.971924900944851, 3.0180105196972717, 3.062510165591823, 3.105550206761945, 3.1472417323101958, 3.1876829758640017, 3.2269612707977102, 3.265154642561822, 3.3023331167126457, 3.3385598019577114, 3.3738917934975827, 3.4083809315966653, 3.442074442596073, 3.475015483760164, 3.507243608914006, 3.5387951684194485, 3.5697036543929133, 3.5999999999999996, 3.6297128400323557, 3.6588687386788976, 3.687492389369918, 3.7156067907414836, 3.743233402095089, 3.7703922811803876, 3.7971022066812226, 3.823380787417118, 3.8492445599682763, 3.8747090761796734, 3.899788981789339, 3.9244980872496633, 3.9488494316624023, 3.972855340623012, 3.9965274786640306, 4.0198768968972045, 4.042914076377278, 4.0656489676446785, 4.088091026847936, 4.110249248798147, 4.1321321972659035, 4.153748032794809, 4.175104538274236, 4.196209142486576, 4.217068941820329, 4.237690720319472, 4.258080968221253, 4.278245899118407, 4.2981914658677, 4.317923375354141, 4.337447102209204, 4.356767901571586, 4.375890820970378, 4.394820711402767, 4.4135622376715675, 4.432119888041698, 4.450497983269286, 4.468700685052144, 4.486732003946001, 4.504595806786885, 4.522295823656561, 4.539835654424671, 4.557218774898392, 4.574448542607811, 4.591528202252847, 4.608460890835453, 4.625249642498881, 4.641897393094029, 4.658406984491342, 4.674781168655241, 4.691022611496759, 4.707133896518872, 4.723117528267885, 4.738975935603254, 4.754711474797304, 4.770326432475447, 4.7858230284067504, 4.801203418154004, 4.816469695591758, 4.831623895300233, 4.84666799484245, 4.861603916931414, 4.876433531493721, 4.891158657635535, 4.905781065516489], [0.0, 1.2523946590098145, 1.5418786877429445, 1.741315970848732, 1.8982753324703165, 2.0297016657870386, 2.1438114293786956, 2.2452805737877024, 2.337051070561294, 2.4211068679662104, 2.4988558665905827, 2.571337078684901, 2.63934146454456, 2.7034865454045893, 2.7642646348105977, 2.8220752150824593, 2.8772473692232925, 2.9300557468415844, 2.980732194607608, 3.0294744014509782, 3.0764524399071655, 3.121813794115112, 3.1656872792495534, 3.2081861355852936, 3.249410498983625, 3.2894493939760525, 3.328382356928007, 3.3662807693976897, 3.4032089621539923, 3.439225136010974, 3.4743821350879225, 3.5087281002350434, 3.542307024430614, 3.5751592274352335, 3.6073217635131827, 3.63882877333515, 3.6697117890684883, 3.7, 3.729720484717806, 3.7588984148253104, 3.7875572343130433, 3.815718818028693, 3.8434036121279167, 3.8706307589322377, 3.8974182082451554, 3.9237828168675923, 3.94974043779645, 3.975306000375482, 4.000493582488007, 4.025316475729977, 4.049787244374437, 4.073917778830432, 4.097719344207701, 4.121202624520177, 4.144377762994392, 4.167254398891382, 4.189841701201239, 4.212148399526712, 4.2341828124353205, 4.255952873527309, 4.277466155438878, 4.298729891975732, 4.319750998550695, 4.340536091080472, 4.361091503480205, 4.381423303880075, 4.401537309675415, 4.4214391015105745, 4.441134036286787, 4.46062725927544, 4.479923715410305, 4.499028159825236, 4.517945167697647, 4.536679143452454, 4.555234329376191, 4.573614813686534, 4.59182453809842, 4.609867304924355, 4.627746783743243, 4.645466517669135, 4.6630299292486255, 4.6804403260132545, 4.697700905711092, 4.71481476123971, 4.731784885300956, 4.748614174796352, 4.7653054349804185, 4.781861383387918, 4.798284653549777, 4.814577798511299, 4.830743294165314, 4.846783542411913, 4.862700874155604, 4.878497552149919, 4.894175773698799, 4.909737673223386, 4.9251853247023, 4.940520743992853, 4.955745891040209, 4.9708626719809414, 4.9858729411470915, 5.000778502976343], [0.0, 1.2759936632617048, 1.5709324699881622, 1.7741277707907994, 1.9340447341680562, 2.067947547703245, 2.1842074935691627, 2.2875886317359817, 2.381088369630156, 2.466728039264233, 2.54594207044517, 2.619789053640547, 2.6890748532937767, 2.7544286266574534, 2.8163519639930947, 2.875251875107934, 2.9314636439507216, 2.985267095381397, 3.0368984447814205, 3.0865591061536946, 3.1344223567283604, 3.1806384597034976, 3.225338657531725, 3.268638324286252, 3.310639482698934, 3.351432834799885, 3.391099415666634, 3.429711951907587, 3.4673359864830813, 3.504030816891233, 3.539850282998628, 3.5748434327785725, 3.6090550881736614, 3.6425263286939815, 3.6752949068212115, 3.707395606542289, 3.73886055418851, 3.7697194890634793, 3.8, 3.8297277329126462, 3.858926573549527, 3.8876188089483854, 3.9158252705339405, 3.9435654613284923, 3.970857669365575, 3.997719069080583, 4.024165812190107, 4.050213109353093, 4.075875303723896, 4.101165937353409, 4.126097811264594, 4.150683039918724, 4.174933100695187, 4.198858878927911, 4.222470708973314, 4.245778411726042, 4.26879132894843, 4.29151835473605, 4.313967964404065, 4.336148241046382, 4.358066899991182, 4.37973131135153, 4.4011485208481025, 4.422325269062018, 4.4432680092590475, 4.463982923911788, 4.484475940033364, 4.504752743424793, 4.524818791927959, 4.544679327767145, 4.564339389054026, 4.583803820523944, 4.603077283564862, 4.622164265594736, 4.641069088837955, 4.659795918546909, 4.678348770710682, 4.696731519289155, 4.714947903007496, 4.733001531743025, 4.75089589253374, 4.768634355235348, 4.786220177851422, 4.803656511559327, 4.820946405452706, 4.838092811019703, 4.855098586374541, 4.87196650025878, 4.888699235827243, 4.905299394232537, 4.921769498020999, 4.938111994351978, 4.954329258051458, 4.970423594510278, 4.986397242436404, 5.002252376470102, 5.017991109670188, 5.033615495878989, 5.0491275319731175, 5.06452916000668, 5.079822269253092, 5.095008698151245], [0.0, 1.2994070685374637, 1.5997577530907932, 1.806681515926432, 1.9695328204229459, 2.105892637414445, 2.224285855026351, 2.3295639497027985, 2.424779328763166, 2.5119904139540408, 2.592657955656985, 2.6678599685799598, 2.7384171040978122, 2.804970063966971, 2.8680296422063174, 2.928010316909052, 2.9852535242010076, 3.0400442234918024, 3.0926229645155012, 3.1431948570517294, 3.191936357821349, 3.2390004872251263, 3.2845208959037615, 3.328615074947195, 3.3713869191181858, 3.41292879475244, 3.4533232238526685, 3.492644267499077, 3.530958671309927, 3.5683268208423096, 3.604803543878857, 3.6404387883817324, 3.6752781987382934, 3.709363608232918, 3.7427334620734163, 3.7754231825034865, 3.8074654853454524, 3.838890655594004, 3.8697267883137094, 3.8999999999999995, 3.929734614684273, 3.9589533283525804, 3.987677354668676, 4.0159265545188365, 4.043719551506555, 4.0710738352036, 4.098005853696909, 4.124531096748165, 4.1506641706964835, 4.176418866077945, 4.201808218803464, 4.2268445656244396, 4.251539594520469, 4.27590439056216, 4.2999494777326355, 4.323684857131657, 4.347120041935005, 4.370264089437388, 4.393125630468835, 4.4157128964412, 4.438033744252411, 4.460095679250881, 4.4819058764403055, 4.5034712000857695, 4.524798221865018, 4.545893237693791, 4.566762283340898, 4.587411148936998, 4.607845392470764, 4.628070352356859, 4.6480911591520515, 4.667912746488483, 4.687539861286644, 4.70697707330482, 4.726228784076562, 4.745299235283121, 4.764192516603589, 4.782912573081735, 4.801463212045173, 4.819848109609422, 4.83807081679668, 4.856134765296658, 4.874043272894541, 4.891799548589135, 4.909406697422375, 4.926867725039716, 4.9441855419993646, 4.961362967846945, 4.978402734970906, 4.995307492252805, 5.0120798085255736, 5.028722175851865, 5.045237012633714, 5.061626666563932, 5.077893417428885, 5.0940394797716495, 5.110067005423886, 5.1259780859141895, 5.141774754760173, 5.157458989650994, 5.173032714526639, 5.188497801559798], [0.0, 1.3226410390991372, 1.6283621261476176, 1.8389857769788214, 2.004748934509089, 2.1435469250725863, 2.264057065548236, 2.3712175789152745, 2.468135450880039, 2.5569059086763413, 2.6390158215457884, 2.715562479574009, 2.7873812077437954, 2.855124163841105, 2.919311275106798, 2.980364430684892, 3.038631171729495, 3.0944015528499484, 3.147920424915484, 3.1993965651589047, 3.249009585424942, 3.296915242186508, 3.3432495758166096, 3.388132178197612, 3.4316688017763797, 3.4739534644393735, 3.515070163719052, 3.5550942849403446, 3.594093767162559, 3.6321300756631367, 3.6692590185696066, 3.705531436935688, 3.740993791290485, 3.7756886629159196, 3.809655184437047, 3.8429294114628805, 3.8755446447890534, 3.907531710919295, 3.9389192072703003, 3.969733717311938, 3.9999999999999996, 4.029741157134759, 4.05897878168962, 4.087733089672253, 4.11602303768438, 4.143866428019014, 4.171280002862132, 4.1982795289391746, 4.2248798737570326, 4.251095074432645, 4.2769383999647514, 4.302422407691301, 4.327558994578111, 4.352359443901734, 4.376834467818744, 4.4009942462529725, 4.424848462479969, 4.4484063357428605, 4.471676651194719, 4.494667787428664, 4.517387741827421, 4.539844153938337, 4.5620443270573325, 4.583995248185574, 4.6057036065052985, 4.627175810505994, 4.648418003878672, 4.669436080284077, 4.690235697090168, 4.710822288164812, 4.731201075801392, 4.751377081847566, 4.771355138100851, 4.791139896028824, 4.810735835866393, 4.830147275137939, 4.849378376647817, 4.868433155978914, 4.88731548853554, 4.9060291161637775, 4.924577653379665, 4.942964593233036, 4.9611933128325365, 4.979267078555284, 4.9971890509627315, 5.014962289442596, 5.032589756595148, 5.05007432238073, 5.067418768044097, 5.084625789829976, 5.101698002503163, 5.1186379426854876, 5.135448072021081, 5.152130780180531, 5.168688387713792, 5.185123148760945, 5.201437253629345, 5.217632831245044, 5.233711951485842, 5.249676627402851, 5.265528817336949, 5.281270426936103], [0.0, 1.3457013859823743, 1.656752743382711, 1.8710486335490026, 2.0397018843094883, 2.180919828370928, 2.303531072290494, 2.412559937339795, 2.511167579756725, 2.6014857572209134, 2.6850272626520217, 2.7629085174715877, 2.835979410616866, 2.9049034702943004, 2.9702096887156495, 3.0323273106941704, 3.0916099367903667, 3.148352678737703, 3.202804656398897, 3.255178287053648, 3.30565631409283, 3.3543972096152794, 3.4015393858682303, 3.4472045198275914, 3.4915002077421633, 3.534522106707392, 3.5763556787590876, 3.6170776235710416, 3.656757064725215, 3.695456539150826, 3.7332328279943416, 3.7701376587271116, 3.8062183019210893, 3.84151808126608, 3.8760768116674242, 3.9099311773664156, 3.943115059760586, 3.9756598228160973, 4.007594562547773, 4.038946325910298, 4.069740303533735, 4.1000000000000005, 4.129747384757628, 4.159003026281912, 4.187786211684369, 4.21611505364234, 4.244006586243083, 4.2714768511060965, 4.298540974954379, 4.32521323964307, 4.351507145516909, 4.377435468851985, 4.403010314038617, 4.428243161078141, 4.4531449088943935, 4.477725914898949, 4.501996031196002, 4.525964637766885, 4.549640672934478, 4.5730326613733085, 4.596148739901077, 4.6189966812612155, 4.6415839160831665, 4.66391755318699, 4.686004398381324, 4.707850971888155, 4.729463524514216, 4.750848052676674, 4.772010312380125, 4.792955832232337, 4.813689925577774, 4.8342177018203865, 4.854544077000451, 4.8746737836842335, 4.894611380219878, 4.914361259408131, 4.933927656632155, 4.953314657486832, 4.9725262049444385, 4.991566106090429, 5.010438038460202, 5.029145556005181, 5.047692094714157, 5.06608097791378, 5.084315421270131, 5.102398537511587, 5.120333340891577, 5.138122751408418, 5.1557695987980825, 5.173276626314526, 5.190646494311168, 5.207881783636033, 5.224984998852202, 5.241958571294354, 5.258804861971406, 5.275526164324541, 5.292124706849293, 5.308602655589697, 5.324962116512032, 5.341205137765108, 5.357333711833626, 5.3733497775906685], [0.0, 1.368593595333842, 1.6849363590348925, 1.9028777135158876, 2.0743999852675317, 2.218020238469256, 2.3427172662736333, 2.453600860485035, 2.5538859529048987, 2.6457405653079893, 2.730703225277383, 2.8099093460801874, 2.884223274419458, 2.9543198260181494, 3.02073699196443, 3.083911319109164, 3.1442024232389234, 3.2019104363388093, 3.257288716138952, 3.3105532934256483, 3.3618900203031945, 3.411460064696189, 3.4594041934322894, 3.505846153378121, 3.5508953711408973, 3.5946491310732536, 3.6371943490363696, 3.6786090294697207, 3.7189634718413354, 3.7583212769185836, 3.796740191772398, 3.8342728238287123, 3.8709672477961488, 3.9068675243593507, 3.942014145729308, 3.97644442019611, 4.0101928055259055, 4.043291199228544, 4.075769192281601, 4.107654291745216, 4.138972116776305, 4.169746571801663, 4.199999999999999, 4.229753319744328, 4.259026146246139, 4.287836900304032, 4.316202905778238, 4.3441404771780014, 4.371664998552439, 4.398790994710453, 4.425532195655993, 4.451901595006968, 4.477911503065826, 4.503573595124326, 4.528898955511811, 4.553898117833501, 4.578581101791274, 4.602957446932688, 4.627036243633646, 4.650826161584972, 4.674335476022694, 4.697572091915174, 4.720543566296956, 4.743257128918793, 4.765719701365375, 4.787937914776528, 4.809918126293699, 4.831666434341261, 4.853188692841271, 4.874490524450628, 4.895577332901006, 4.916454314514261, 4.937126468959195, 4.957598609309457, 4.977875371456888, 4.997961222929745, 5.017860471160814, 5.037577271246499, 5.057115633234392, 5.076479428973644, 5.095672398559531, 5.114698156401017, 5.133560196937734, 5.152261900030633, 5.170806536048648, 5.189197270671892, 5.207437169430343, 5.2255292019954585, 5.243476246240863, 5.261281092086992, 5.278946445143491, 5.296474930162116, 5.313869094311972, 5.331131410288043, 5.348264279263216, 5.3652700336932275, 5.3821509399833465, 5.398909201024962, 5.415546958609701, 5.432066295728168, 5.448469238759937, 5.464757759560955], [0.0, 1.3913228538564613, 1.7129193586844875, 1.9344802284150482, 2.1088510989547635, 2.254856561231874, 2.381624525939384, 2.494349647019932, 2.5963002490544445, 2.6896803597785293, 2.7760540582547506, 2.8565756144084427, 2.932123729795507, 3.0033844273088537, 3.0709046328574527, 3.1351281433525697, 3.1964205469893936, 3.2550869602696153, 3.311384948624881, 3.3655341306265014, 3.417723444963819, 3.4681167361978242, 3.516857108976276, 3.564070365322664, 3.6098677491737976, 3.654348160556394, 3.6975999588084156, 3.739702443847466, 3.7807270826574744, 3.8207385322713723, 3.8597954988089356, 3.8979514633870087, 3.9352552991268936, 3.971751798462013, 4.0074821260878215, 4.042484209901116, 4.076793079933965, 4.110441163442046, 4.143458542842457, 4.175873182025679, 4.207711125625147, 4.23899667506637, 4.269752544597956, 4.3, 4.329758982248495, 4.359048218070036, 4.387885319035172, 4.416286870600417, 4.444268512309309, 4.471845010195126, 4.499030322286275, 4.525837657995405, 4.552279532071374, 4.578367813706252, 4.604113771315138, 4.629528113442723, 4.654621026195573, 4.679402207551657, 4.703880898857555, 4.7280659137881385, 4.7519656650124755, 4.775588188782657, 4.7989411676385565, 4.822031951400812, 4.8448675766060525, 4.867454784522407, 4.889800037869132, 4.911909536351698, 4.9337892311126295, 4.955444838188499, 4.976881851054796, 4.998105552332587, 5.0191210247239155, 5.039933161236748, 5.0605466747546535, 5.080966107001474, 5.101195836946759, 5.121240088693706, 5.141102938887774, 5.1607883236808085, 5.1803000452826495, 5.199641778129457, 5.218817074695637, 5.237829370974024, 5.256681991647014, 5.275378154969543, 5.29392097738314, 5.312313477878818, 5.330558582125206, 5.3486591263770356, 5.366617861178037, 5.384437454871185, 5.402120496928329, 5.419669501110349, 5.437086908468207, 5.454375090194481, 5.471536350334327, 5.488572928364202, 5.5054870016460695, 5.522280687764319, 5.538956046752126, 5.555515083213527], [0.0, 1.4138940717178894, 1.7407077874569759, 1.9658630052904187, 2.1430626677936453, 2.291436754354387, 2.4202612563647468, 2.5348150998437746, 2.638419630902199, 2.7333146328804854, 2.8210895586566105, 2.9029174037003673, 2.979691124608606, 3.052107873518702, 3.1207234490349993, 3.185988847718176, 3.248275588644798, 3.3078937381748954, 3.3651050401847202, 3.4201326760840747, 3.4731686496857614, 3.5243794635760244, 3.5739105439674366, 3.621889733750473, 3.668430081555316, 3.71363209184869, 3.7575855574085826, 3.8003710646230324, 3.842061239873918, 3.882721789115328, 3.9224123708474394, 3.961187333803076, 3.9990963439647125, 4.036184920426567, 4.072494895692653, 4.1080648129582364, 4.142930270542238, 4.177124221762746, 4.210677237059307, 4.243617733976323, 4.275972179665332, 4.307765269790154, 4.3390200870891755, 4.369758242333992, 4.3999999999999995, 4.429764390614615, 4.459069311458201, 4.487931617050597, 4.516367200653263, 4.544391067846578, 4.5720174030979095, 4.599259630114185, 4.62613046666912, 4.652641974506873, 4.678805604848318, 4.704632239961227, 4.730132231199817, 4.755315433870868, 4.780191239241914, 4.804768603970725, 4.829056077203813, 4.853061825564157, 4.876793656224302, 4.9002590382398985, 4.923465122300236, 4.946418759036004, 4.969126516010164, 4.991594693505063, 5.013829339207699, 5.03583626188503, 5.057621044132361, 5.07918905426991, 5.1005454574556195, 5.121695226075976, 5.142643149470936, 5.163393843044035, 5.1839517568041735, 5.204321183381532, 5.2245062655563625, 5.244511003336102, 5.264339260613258, 5.2839947714338065, 5.303481145903403, 5.3228018757564675, 5.3419603396112105, 5.360959807931826, 5.379803447717395, 5.398494326935563, 5.4170354187176315, 5.4354296053304605, 5.45367968193943, 5.471788360175634, 5.489758271519527, 5.507591970512348, 5.525291937805859, 5.5428605830601265, 5.560300247698483, 5.577613207528067, 5.594801675233853, 5.611867802753479, 5.6288136835397236, 5.645641354717006], [0.0, 1.4363119032269172, 1.768307375478623, 1.9970325154425377, 2.1770417463971174, 2.3277683608730397, 2.4586354246552253, 2.5750055631546465, 2.6802527836954715, 2.776652382240043, 2.8658190130498955, 2.948944269886821, 3.0269352675161865, 3.10050021168926, 3.170203713409923, 3.2365039199618897, 3.29977824099884, 3.3603416591015836, 3.4184600681956825, 3.4743601883175876, 3.5282370675740204, 3.58025984851344, 3.6305762631366627, 3.6793161813321107, 3.726594444159253, 3.7725131496215902, 3.817163514195963, 3.860627401998427, 3.902978590929935, 3.944283828737618, 3.984603719830002, 4.023993474659865, 4.062503546682836, 4.100180176715791, 4.137065860533101, 4.17319975244714, 4.208618015201796, 4.243354124602624, 4.2774391357951895, 4.310901916894932, 4.343769354700205, 4.376066536434028, 4.407816910820437, 4.4390424312780805, 4.4697636835833645, 4.5, 4.529769561576579, 4.559089490067801, 4.587975930728868, 4.616444127059378, 4.644508488426855, 4.672182651376237, 4.699479535326408, 4.726411393265096, 4.752989857976662, 4.779225984271398, 4.805130287628203, 4.830712779613517, 4.855983000397015, 4.880950048647702, 4.905622609062079, 4.9300089777480585, 4.95411708566389, 4.977954520289965, 5.001528545692483, 5.024846121121506, 5.0479139182712185, 5.070738337317356, 5.093325521835307, 5.115681372692253, 5.137811560997683, 5.1597215401885865, 5.181416557318461, 5.2029016636128835, 5.224181724348629, 5.245261428108221, 5.266145295457154, 5.286837687086903, 5.307342811463085, 5.327664732014788, 5.34780737389801, 5.367774530363457, 5.387569868756391, 5.407196936174016, 5.426659164803829, 5.445959876964483, 5.4651022898690425, 5.484089520128955, 5.502924588015654, 5.521610421495444, 5.540149860052123, 5.558545658310733, 5.576800489474856, 5.594916948588963, 5.612897555636496, 5.630744758483607, 5.648460935677788, 5.666048399109973, 5.683509396548102, 5.700846114049608, 5.718060678259764, 5.735155158602378], [0.0, 1.4585807655399254, 1.7957235609068303, 2.0279949004378004, 2.2107950299222834, 2.3638585394814595, 2.4967545919659777, 2.61492895598617, 2.7218079501395267, 2.8197021470246084, 2.910251234820272, 2.9946652819924133, 3.0738654673921797, 3.1485709769321306, 3.2193551754562275, 3.2866833134538034, 3.350938652012056, 3.412441057263695, 3.471460545606013, 3.5282273521875083, 3.582939549179122, 3.635768901548658, 3.6868654317629383, 3.736361023238684, 3.784372297553742, 3.831002935659146, 3.8763455682699375, 3.920483328739534, 3.9634911388359773, 4.005436781176603, 4.046381799792608, 4.086382261130493, 4.125489400886187, 4.1637501768032905, 4.201207743519017, 4.2379018624019045, 4.273869256870137, 4.309143921744745, 4.343757393656377, 4.377738988297417, 4.411116009324428, 4.443913932917671, 4.476156571354813, 4.507866218424621, 4.5390637790694335, 4.569768885284177, 4.6, 4.629774510430654, 4.659108812150555, 4.688018384997516, 4.716517861744731, 4.744621090360813, 4.7723411905698585, 4.799690605332327, 4.826681147789558, 4.853324044147796, 4.879629972919994, 4.905609100893888, 4.931271116151819, 4.956625258430347, 4.981680347075217, 5.00644480681883, 5.0309266915825726, 5.055133706484624, 5.079073228214695, 5.102752323920432, 5.126177768735278, 5.149356062064551, 5.172293442734841, 5.194995903101535, 5.217469202200121, 5.239718878018746, 5.261750258962259, 5.283568474571431, 5.305178465555246, 5.326584993188932, 5.347792648125723, 5.368805858666111, 5.389628898524591, 5.410265894130454, 5.430720831496092, 5.450997562683515, 5.471099811897226, 5.4910311812293235, 5.510795156080613, 5.530395110279632, 5.549834310919747, 5.569115922932963, 5.588243013417597, 5.607218555735718, 5.62604543339504, 5.644726443728853, 5.663264301386615, 5.681661641646875, 5.699921023563395, 5.718044932954524, 5.736035785245225, 5.75389592817044, 5.771627644347949, 5.789233153728247, 5.806714615928536, 5.824074132457375], [0.0, 1.4807048556237303, 1.8229615108138466, 2.0587559956934167, 2.2443288797812753, 2.399714092021603, 2.5346259425383004, 2.654592802618326, 2.7630929620513713, 2.8624720407350734, 2.9543945980174646, 3.0400890569625423, 3.120490569075121, 3.1963292290458654, 3.268187098649176, 3.336536485401312, 3.4017664637822023, 3.4642017517279675, 3.5241164613070075, 3.5817443199277528, 3.6372864041656014, 3.6909170843590786, 3.742788658550449, 3.793035010594571, 3.8417745310123346, 3.8891124734113935, 3.9351428735508804, 3.979950125770127, 4.0236102882678635, 4.066192171803829, 4.107758253923307, 4.148365451501611, 4.18806577738955, 4.226906901596624, 4.264932633339559, 4.302183337096518, 4.338696293314977, 4.3745060124572674, 4.409644509508939, 4.444141544829571, 4.478024836223899, 4.511320246300771, 4.544051948527986, 4.576242574851651, 4.607913347305098, 4.63908419566589, 4.669773862915181, 4.699999999999999, 4.7297792511866215, 4.759127331114618, 4.788059094510466, 4.816588599391968, 4.844729164486227, 4.872493421491401, 4.899893362733288, 4.926940384699823, 4.953645327878109, 4.980018513268069, 5.006069775903116, 5.03180849567027, 5.057243625689147, 5.082383718480438, 5.10723695012927, 5.131811142626835, 5.1561137845541785, 5.1801520502550735, 5.203932817629753, 5.227462684668018, 5.250747984828421, 5.273794801359782, 5.296608980651967, 5.319196144694608, 5.3415617027150315, 5.363710862060066, 5.385648638380512, 5.4073798651717215, 5.428909202719014, 5.4502411464923695, 5.471380035030972, 5.492330057354745, 5.513095259936837, 5.533679553268225, 5.554086718043006, 5.574320410990645, 5.594384170379312, 5.614281421212554, 5.634015480139766, 5.6535895600993715, 5.673006774712145, 5.6922701424407975, 5.711382590530755, 5.730346958745905, 5.749166002912135, 5.767842398280509, 5.786378742721106, 5.804777559757745, 5.82304130145311, 5.841172351153133, 5.859173026098863, 5.877045579913521, 5.894792204971878, 5.9124150346586655], [0.0, 1.5026881656709, 1.8500261401652485, 2.089321351910698, 2.2776493470065042, 2.4353414884666904, 2.572256310087104, 2.6940042602138785, 2.8041152691257545, 2.904969781006429, 2.9982570681128586, 3.085223791313138, 3.1668189858549463, 3.2437835857922996, 3.3167082944897204, 3.3860724315851134, 3.452270847959349, 3.5156330824789594, 3.576437316821871, 3.634920748434494, 3.691287439179054, 3.7457143481862993, 3.7983560345939917, 3.8493483699659397, 3.898811502509931, 3.946852248483113, 3.993566039748129, 4.039038523606319, 4.083346887455765, 4.12656096365633, 4.168744157327248, 4.209954230361198, 4.250243967818669, 4.289661747442778, 4.328252028864537, 4.3660557758340275, 4.403110822283528, 4.439452191035541, 4.47511237238665, 4.51012156853412, 4.544507908795555, 4.578297639749466, 4.611515293755457, 4.644183838765211, 4.676324811885342, 4.7079584387811995, 4.7391037407019265, 4.76977863064964, 4.800000000000001, 4.829783796700246, 4.859145096017805, 4.888098164683083, 4.916656519159892, 4.944832978683114, 4.972639713622817, 5.000088289665092, 5.027189708240518, 5.05395444357992, 5.0803924767327056, 5.106513326844546, 5.132326079957703, 5.15783941556801, 5.183061631146986, 5.208000664815146, 5.232664116332885, 5.257059266557993, 5.281193095503568, 5.305072299116577, 5.328703304885376, 5.352092286373841, 5.375245176770367, 5.398167681531552, 5.420865290192906, 5.443343287412225, 5.465606763305255, 5.487660623127916, 5.509509596354538, 5.53115824519717, 5.5526109726071935, 5.573872029796888, 5.5949455233154355, 5.615835421710984, 5.636545561807771, 5.657079654624956, 5.677441290961672, 5.697633946670836, 5.717660987642537, 5.737525674516145, 5.7572311671388565, 5.776780528787042, 5.796176730165527, 5.8154226531988025, 5.8345210946271715, 5.85347476941986, 5.872286314016269, 5.890958289405756, 5.909493184055599, 5.9278934166961115, 5.946161338971307, 5.964299237962858, 5.982309338594668, 6.000193805924798], [0.0, 1.5245344971379462, 1.8769221291029836, 2.119696254593611, 2.310762193528584, 2.4707468896722955, 2.609652201831067, 2.7331701439859057, 2.84488196513136, 2.9472027167461508, 3.0418462300093747, 3.130077289952992, 3.212858729057578, 3.290942253200147, 3.3649271534893677, 3.4352997179920766, 3.5024605379971807, 3.56674394326228, 3.6284321597169837, 3.6877658332237857, 3.744951992330337, 3.8001701688287772, 3.8535771688634215, 3.905310839321559, 3.955493075145686, 4.004232245505531, 4.051625169668092, 4.097758740089475, 4.142711266331046, 4.186553595987178, 4.229350055971311, 4.271159247928168, 4.312034724316259, 4.35202556620241, 4.391176879579173, 4.4295302237344645, 4.467123982636593, 4.503993688275699, 4.540172303297724, 4.575690468984521, 4.610576723602407, 4.644857695307039, 4.678558273113556, 4.711701758885561, 4.74431000283972, 4.77640352468548, 4.808001622206083, 4.8391224688258605, 4.869783201490114, 4.8999999999999995, 4.929788158789703, 4.959162152001736, 4.98813569260452, 5.016721786201114, 5.04493278009646, 5.07278040812052, 5.100275831644512, 5.127429677175377, 5.154252070868684, 5.180752670261033, 5.206940693489089, 5.2328249462326415, 5.258413846593237, 5.283715448097113, 5.3087374609912485, 5.333487271983761, 5.357971962564343, 5.382198326026758, 5.4061728833032605, 5.42990189771003, 5.453391388693143, 5.47664714465608, 5.499674734942134, 5.522479521038339, 5.545066667061391, 5.567441149580645, 5.589607766828314, 5.611571147342648, 5.633335758085873, 5.654905912075102, 5.676285775561213, 5.697479374787771, 5.718490602359404, 5.739323223246689, 5.759980880452394, 5.780467100361969, 5.800785297799375, 5.820938780807699, 5.840930755172526, 5.860764328704649, 5.880442515297496, 5.899968238773457, 5.919344336532315, 5.938573563013969, 5.957658592986817, 5.976602024672309, 5.995406382715474, 6.014074121010533, 6.0326076253900895, 6.051009216185794, 6.069281150667864, 6.0874256253703365], [0.0, 1.5462474735549587, 1.9036539387158784, 2.1498857418591495, 2.3436729115920993, 2.5059361681363614, 2.646819820419783, 2.772096950162781, 2.885399811814427, 2.989177852897546, 3.0851693136000478, 3.174656992483676, 3.25861743504041, 3.337813053216566, 3.412851673443388, 3.4842265096797442, 3.552343858581804, 3.617542811553529, 3.680109614089166, 3.7402883394173645, 3.798288964661869, 3.854293578572091, 3.908461220582651, 3.9609317008464915, 4.011828650378342, 4.061261981781177, 4.109329893257313, 4.1561205148169105, 4.201713271334675, 4.246180019442261, 4.2895860022204735, 4.331990655940037, 4.373448295773112, 4.414008701816978, 4.4537176224801875, 4.492617208953198, 4.530746391882793, 4.568141209318678, 4.604835093372823, 4.640859121731393, 4.6762422391131055, 4.711011452921522, 4.745192006650215, 4.778807534036428, 4.811880196495584, 4.844430805986316, 4.876478935137935, 4.908043016207311, 4.939140430210371, 4.969787587386902, 4.999999999999999, 5.0297923483381926, 5.059178540675002, 5.08817176784403, 5.116784553005036, 5.145028797105475, 5.1729158204808785, 5.2004564009847805, 5.227660808993147, 5.254538839588742, 5.28109984219629, 5.307352747909289, 5.333306094722956, 5.358968050864787, 5.384346436393912, 5.409448743222638, 5.4342821536978185, 5.458853557865785, 5.483169569532286, 5.507236541217937, 5.53106057809996, 5.554647551022389, 5.578003108649137, 5.60113268882749, 5.624041529223381, 5.646734677284276, 5.669216999580566, 5.691493190571831, 5.7135677808404, 5.7354451448309485, 5.757129508131623, 5.7786249543292145, 5.799935431468248, 5.821064758141384, 5.842016629236365, 5.862794621362709, 5.883402197979545, 5.903842714244316, 5.924119421600576, 5.944235472121693, 5.964193922626063, 5.983997738578222, 6.003649797789236, 6.02315289392874, 6.042509739860163, 6.06172297080977, 6.080795147379504, 6.099728758412845, 6.118526223722294, 6.137189896686512, 6.15572206672458, 6.174124961654377], [0.0, 1.5678305522365592, 1.9302258254575149, 2.1798946207201233, 2.376386741506099, 2.5409149269786364, 2.683765083980215, 2.810790876983455, 2.9256752607521634, 3.030901873079166, 3.128233217134454, 3.2189699972437342, 3.3041023898723916, 3.3844034489870567, 3.4604894852790387, 3.5328605971651355, 3.6019287525364567, 3.6680377759568086, 3.731477908438058, 3.7924966300708136, 3.8513068489150775, 3.9080931953805536, 3.963016928831524, 4.016219810941359, 4.067827198410982, 4.1179505380430355, 4.166689398725681, 4.214133140619477, 4.260362297240113, 4.305449728219965, 4.349461587326241, 4.39245814046252, 4.434494460951682, 4.47562102373952, 4.515884215807336, 4.555326776707071, 4.593988180493488, 4.631904968248359, 4.669111038741104, 4.705637903451415, 4.74151491111881, 4.7767694461259085, 4.811427104324051, 4.845511849338689, 4.879046151922258, 4.912051114534201, 4.9445465830056285, 4.976551246877489, 5.0080827297761825, 5.039157671001529, 5.069791799342375, 5.1, 5.129796375384611, 5.159194300452213, 5.188206473165336, 5.216844960589141, 5.2451212410724795, 5.273046242910041, 5.300630379835398, 5.327883583654601, 5.354815334295013, 5.381434687513548, 5.4077503004818315, 5.433770455442419, 5.45950308160964, 5.484955775470611, 5.510135819625965, 5.535050200295782, 5.559705623603691, 5.584108530741074, 5.608265112103416, 5.632181320482104, 5.655862883387135, 5.679315314569225, 5.70254392480353, 5.725553831991609, 5.748349970633189, 5.770937100714808, 5.793319816058295, 5.815502552168398, 5.837489593615541, 5.859285080986693, 5.880893017434602, 5.90231727485322, 5.923561599704863, 5.94462961852265, 5.965524843109921, 5.986250675456613, 6.0068104123911, 6.027207249984523, 6.04744428772345, 6.0675245324654385, 6.087450902191076, 6.107226229565046, 6.126853265317898, 6.146334681459335, 6.165673074333105, 6.184870967522859, 6.203930814617713, 6.222855001845632, 6.241645850582236, 6.260305619742085], [0.0, 1.5892870350080615, 1.956641854351681, 2.20972748199869, 2.4089086879019095, 2.575688517324096, 2.720493644477416, 2.849257843927209, 2.9657144733684686, 3.0723811603204214, 3.171044528620211, 3.2630230833309484, 3.3493205519387215, 3.430720568009525, 3.5078478767301644, 3.581209420594464, 3.65122280546375, 3.7182365612992445, 3.782544901194659, 3.844398692119555, 3.9040137558787364, 3.9615772496340487, 4.017252639658401, 4.071183627698915, 4.123497286020669, 4.174306586627096, 4.223712461052425, 4.271805492392142, 4.318667316300169, 4.364371789526486, 4.408985971183059, 4.4525709519400944, 4.495182558824248, 4.536871957554178, 4.577686169938377, 4.617668520439228, 4.656859023332102, 4.695294719780297, 4.733009972473493, 4.770036724140488, 4.806404725171809, 4.842141734717956, 4.877273698921278, 4.91182490936047, 4.945818144310557, 4.979274795027855, 5.012214978942808, 5.044657641371333, 5.07662064712727, 5.108120863226918, 5.139174233714836, 5.169795847503136, 5.2, 5.229800249203862, 5.259209466854714, 5.288239885161059, 5.316903139558235, 5.345210307899675, 5.373171946435688, 5.400798122893664, 5.428098446938133, 5.45508209825821, 5.481757852502904, 5.5081341052610675, 5.534218894261978, 5.560019919954177, 5.5855445646040405, 5.6107999100412815, 5.63579275416592, 5.660529626320008, 5.685016801617441, 5.709260314316296, 5.733265970310181, 5.757039358808028, 5.780585863265397, 5.803910671624684, 5.827018785916517, 5.84991503127004, 5.872604064375648, 5.895090381440014, 5.9173783256698815, 5.939472094318055, 5.961375745322273, 5.983093203565138, 6.004628266781026, 6.0259846111338335, 6.047165796487542, 6.068175271389891, 6.089016377787864, 6.10969235549231, 6.130206346407697, 6.15056139854181, 6.170760469809146, 6.190806431640707, 6.210702072412059, 6.230450100700585, 6.250053148382192, 6.2695137735769375, 6.288834463452432, 6.308017636893268, 6.3270656470441615, 6.345980783733956], [0.0, 1.6106200780469582, 1.9829059111086655, 2.239388714009855, 2.4412435346500447, 2.6102620542526145, 2.7570109045608895, 2.8875035093573715, 3.005523339298799, 3.1136218160869733, 3.213609545459331, 3.306822730808259, 3.394278572681153, 3.476771223378651, 3.554933814059168, 3.629280091919394, 3.7002332683554733, 3.7681465516557657, 3.8333181041443303, 3.8960021601848744, 3.9564174385641513, 4.014753608659673, 4.071176330956568, 4.125831236114416, 4.1788471020927584, 4.230338417321301, 4.280407468140996, 4.329146053546682, 4.37663690498988, 4.422954870601733, 4.468167909630486, 4.512337932768072, 4.555521516408842, 4.597770513070285, 4.639132575735907, 4.679651610413526, 4.719368168491218, 4.758319788336821, 4.796541293891334, 4.834065056651671, 4.870921226348658, 4.907137934744625, 4.942741476257698, 4.977756468533091, 5.012205995599232, 5.046111735847853, 5.0794940767462124, 5.112372217913719, 5.144764263964093, 5.17668730832005, 5.208157509043494, 5.239190157585415, 5.269799741241645, 5.3, 5.329803978378189, 5.359224072777979, 5.388272074817476, 5.416959211048439, 5.44529617941801, 5.473293182792959, 5.500959959828605, 5.5283058134332785, 5.555339637051761, 5.582069938967125, 5.608504864799307, 5.634652218360176, 5.66051948100847, 5.686113829633498, 5.711442153383674, 5.736511069244585, 5.761326936561153, 5.785895870589464, 5.810223755155793, 5.834316254493175, 5.858178824319442, 5.8818167222148805, 5.905235017352512, 5.92843859962932, 5.951432188242581, 5.974220339751673, 5.996807455662319, 6.019197789567165, 6.041395453873756, 6.063404426148502, 6.085228555102868, 6.106871566246002, 6.128337067226034, 6.149628552880653, 6.1707494100158895, 6.19170292193066, 6.212492272703302, 6.233120551255093, 6.253590755204694, 6.2739057945264065, 6.294068495024233, 6.31408160163287, 6.333947781555962, 6.353669627251283, 6.373249659271762, 6.392690328970746, 6.411994021079273, 6.431163056162625], [0.0, 1.6318327009279798, 2.009021713261028, 2.2688825151376233, 2.4733958585699467, 2.644640431457898, 2.793322033047647, 2.9255332867372106, 3.045107493268843, 3.1546296777664735, 3.25593429249548, 3.3503751392744974, 3.4389828156598745, 3.5225619333110334, 3.6017539620211076, 3.6770794152786554, 3.7489670783726776, 3.8177748115105805, 3.8838047039542674, 3.947314338453422, 4.008525314423943, 4.067629799278126, 4.1247956353274935, 4.180170371255809, 4.2338844810888245, 4.2860539611226365, 4.336782444857346, 4.386162940323672, 4.434279268585205, 4.481207263558129, 4.527015779545907, 4.571767542633365, 4.615519874352535, 4.658325310142917, 4.700232130600192, 4.7412848199949185, 4.781524463796003, 4.8209890947692156, 4.859713995503215, 4.897731963842733, 4.935073546604711, 4.971767246060002, 5.007839702936567, 5.0433158591055705, 5.0782191026229375, 5.112571397394999, 5.146393399401533, 5.179704561129953, 5.212523225640246, 5.2448667114835335, 5.2767513895309826, 5.308192752629172, 5.33920547887843, 5.36980348922866, 5.3999999999999995, 5.429807570860647, 5.459238148729856, 5.488303108018346, 5.517013287570251, 5.5453790246288825, 5.573410186112225, 5.601116197452284, 5.6285060692246836, 5.655588421770582, 5.6823715079915535, 5.708863234479337, 5.735071181125678, 5.761002619342887, 5.7866645290126995, 5.812063614269511, 5.837206318213801, 5.862098836642453, 5.886747130874495, 5.911156939743574, 5.935333790821885, 5.959283010934518, 5.983009736017885, 6.006518920371207, 6.029815345345806, 6.052903627513087, 6.075788226348672, 6.098473451467019, 6.120963469438012, 6.143262310214477, 6.16537387319722, 6.1873019329620895, 6.20905014467164, 6.230622049192213, 6.252021077935664, 6.2732505574435, 6.294313713729864, 6.315213676398579, 6.335953482548351, 6.356536080479208, 6.376964333212324, 6.397241021834466, 6.4173688486776115, 6.437350440343415, 6.457188350581675, 6.476885063031212, 6.496442993831093, 6.5158644941095325], [0.0, 1.6529277949497025, 2.0349928204148573, 2.298212905412222, 2.505370042050766, 2.678828334742057, 2.8294319791754456, 2.9633523595577915, 3.084472330632519, 3.195410334765415, 3.2980245386277485, 3.393686244960053, 3.4834393741012994, 3.5680989391194595, 3.6483147022420503, 3.7246139057607577, 3.7974308779751986, 3.8671281052377995, 3.9340115819910495, 3.9983422208188237, 4.060344485805998, 4.12021302855925, 4.178117861128056, 4.234208439593521, 4.288616924650527, 4.3414608121072025, 4.392845075158845, 4.442863924173367, 4.491602263789422, 4.539136908246476, 4.585537601944145, 4.630867881842444, 4.675185810482646, 4.718544602442521, 4.760993162452628, 4.802576549842398, 4.843336381202477, 4.883311180957354, 4.922536687802201, 4.961046123567382, 4.998870429955891, 5.036038477694295, 5.0725772519016585, 5.108512016878715, 5.143866463024417, 5.178662838177798, 5.2129220653434585, 5.246663848475797, 5.279906767759952, 5.312668365628121, 5.344965224581665, 5.376813037746918, 5.408226672971542, 5.439220231164911, 5.469807099497713, 5.5, 5.529811034031726, 5.559251723043355, 5.588333045995365, 5.6170654737631045, 5.645459000816579, 5.673523174432619, 5.70126712166873, 5.728699574303295, 5.755828891925135, 5.7826630833363994, 5.80920982641592, 5.835476486575304, 5.861470133926899, 5.8871975592710575, 5.9126652889997695, 5.937879599004477, 5.962846527667613, 5.987571888010107, 6.012061279060412, 6.036320096504767, 6.0603535426730675, 6.084166635909957, 6.107764219376435, 6.131150969323436, 6.154331402875294, 6.177309885357893, 6.200090637203369, 6.222677740460717, 6.245075144939235, 6.267286674009623, 6.2893160300856, 6.311166799807141, 6.332842458944786, 6.354346377043045, 6.375681821819524, 6.396851963335186, 6.417859877950042, 6.438708552077508, 6.459400885749716, 6.479939696005217, 6.500327720109679, 6.520567618619471, 6.5406619782973285, 6.56061331488867, 6.580424075766572, 6.6000966424528515], [0.0, 1.6739081308117676, 2.0608226437015387, 2.327383737184428, 2.5371702846878503, 2.7128302544577423, 2.865345485744421, 3.000965695101621, 3.1236230216981777, 3.2359691433505966, 3.339885812128717, 3.436761736489251, 3.5276540870773196, 3.613388221785362, 3.6946221501641037, 3.7718898067033977, 3.8456310325592775, 3.916212915062774, 3.983945332592622, 4.049092509452458, 4.111881758812219, 4.172510202958849, 4.2311500118763155, 4.287952538666746, 4.343051621518603, 4.396566247594645, 4.44860272249737, 4.499256452391121, 4.548613419594918, 4.596751413338518, 4.643741063275524, 4.689646712829952, 4.734527161521196, 4.778436299370753, 4.821423651848742, 4.863534850215123, 4.904812039292961, 4.945294232490818, 4.985017622129141, 5.0240158517174285, 5.062320255696531, 5.099960071244317, 5.136962625997449, 5.173353504932203, 5.209156699145801, 5.244394738865372, 5.279088812667714, 5.31325887460622, 5.346923740701208, 5.380101176048033, 5.412807973626969, 5.445060025754578, 5.476872388993622, 5.50825934323396, 5.539234445567395, 5.569810579502578, 5.6000000000000005, 5.629814374749967, 5.6592648220670645, 5.688361945731709, 5.717115867072042, 5.745536254546882, 5.773632351061947, 5.801412999226621, 5.828886664736586, 5.856061458048377, 5.88294515449486, 5.9095452129755754, 5.935868793342625, 5.961922772590853, 5.987713759950652, 6.0132481109723015, 6.038531940682415, 6.063571135885622, 6.088371366677906, 6.11293809723205, 6.137276595910251, 6.161391944754162, 6.1852890483982135, 6.20897264244821, 6.232447301363592, 6.255717445878592, 6.278787349994583, 6.301661147573327, 6.32434283855839, 6.346836294849877, 6.369145265855624, 6.391273383740225, 6.413224168391598, 6.435001032123315, 6.456607284129574, 6.478046134708392, 6.499320699267504, 6.520434002126369, 6.541388980126745, 6.562188486063378, 6.582835291945593, 6.603332092099757, 6.62368150612195, 6.643886081689526, 6.66394829723966, 6.683870564522425], [0.0, 1.6947763657040336, 2.086514454505522, 2.3563987049822432, 2.5688006140278885, 2.7466504969972276, 2.9010671012520843, 3.038378057152006, 3.1625645249574257, 3.276311240353744, 3.381523414789174, 3.4796070694353487, 3.571632554445234, 3.658435517261845, 3.7406821706924727, 3.818913105667755, 3.893573646744153, 3.9650354576476072, 4.033612279940666, 4.099571631951727, 4.163143660712716, 4.224527945989642, 4.283898804170806, 4.341409475243301, 4.397195465926083, 4.451377246768011, 4.504062448659539, 4.55534766717213, 4.605319956546972, 4.65405807579459, 4.70163353509254, 4.7481114800197854, 4.793551443136057, 4.838007986297587, 4.881531252397354, 4.924167441569938, 4.965959224048401, 5.006946099612666, 5.04716471178467, 5.086649123499951, 5.125431059838763, 5.163540122472274, 5.201003979724622, 5.23784853553421, 5.274098080089855, 5.309775424497943, 5.344902021488475, 5.379498073877525, 5.413582632260493, 5.447173683206165, 5.480288229049111, 5.5129423602318175, 5.545151321023816, 5.576929569339129, 5.6082908312827655, 5.639248150979169, 5.669813936168658, 5.7, 5.7298175993973, 5.759277470335912, 5.7883898603242905, 5.817164558355747, 5.845610922565221, 5.873737905800912, 5.901554079298418, 5.9290676546255074, 5.9562865040483635, 5.983218179454946, 6.009869929957616, 6.036248718285162, 6.062361236063758, 6.088213918076895, 6.1138129555858445, 6.1391643087847, 6.164273718457252, 6.189146716896891, 6.2137886381453, 6.238204627600796, 6.26239965104278, 6.286378503114786, 6.310145815305007, 6.333706063459972, 6.357063574864065, 6.380222534914969, 6.403186993422644, 6.4259608705573, 6.448547962469794, 6.470951946606098, 6.493176386735774, 6.515224737712941, 6.537100349986773, 6.558806473877348, 6.580346263631486, 6.601722781272155, 6.622939000254053, 6.64399780893708, 6.664902013888572, 6.685654343024455, 6.706257448598721, 6.726713910050045, 6.747026236713718, 6.767196870406557], [0.0, 1.7155350498622062, 2.1120713925352477, 2.385261354625775, 2.6002648955053873, 2.7802931954168315, 2.9366011911150496, 3.0755940177459213, 3.2013015993183602, 3.3164415558447327, 3.4229424349983173, 3.5222274797801356, 3.61538015066332, 3.7032463306250176, 3.7865003926649363, 3.8656895492105763, 3.9412645794329446, 4.013601699428462, 4.0830184936631655, 4.149785757197766, 4.214136456049423, 4.276272614562326, 4.336370684261259, 4.394585782112813, 4.451055074607249, 4.505900507892287, 4.559231031189051, 4.611144423232162, 4.661728804557768, 4.711063898866166, 4.759222092236429, 4.806269328191441, 4.85226586848307, 4.897266943275399, 4.941323309643013, 4.984481733608725, 5.026785408057381, 5.068274316586989, 5.108985551552333, 5.148953593113153, 5.188210554938391, 5.226786401279051, 5.264709139358265, 5.302004990402127, 5.33869854212092, 5.374812885025775, 5.410369734613189, 5.445389541156001, 5.4798915885932535, 5.513894083804513, 5.54741423737961, 5.580468336846863, 5.613071813197182, 5.645239301434191, 5.676984695788842, 5.708321200158201, 5.739261374260372, 5.76981717593898, 5.8, 5.829820713919744, 5.859289690724583, 5.888416839309558, 5.917211632433916, 5.945683132605957, 5.973840016047151, 6.001690594905701, 6.029242837872243, 6.056504389335, 6.083482587198008, 6.110184479473926, 6.136616839752164, 6.162786181633478, 6.18869877221359, 6.214360644690792, 6.2397776101655955, 6.264955268694392, 6.289899019653551, 6.3146140714654555, 6.339105450733492, 6.363378010828994, 6.387436439969528, 6.411285268824598, 6.434928877681883, 6.458371503204443, 6.481617244806851, 6.50467007067602, 6.527533823460445, 6.550212225649761, 6.57270888466482, 6.595027297676959, 6.617170856173754, 6.639142850287245, 6.660946472899446, 6.6825848235389005, 6.704060912081048, 6.72537766226423, 6.746537915032382, 6.767544431714655, 6.788399897051512, 6.809106922076212, 6.829668046859956, 6.850085743128467], [0.0, 1.7361866326385889, 2.137496473297121, 2.41397509166794, 2.6315668416442115, 2.8137623192755226, 2.9719519480607666, 3.112617968057592, 3.2398388154339974, 3.356364824867458, 3.4641477598564943, 3.564627996378017, 3.658902037584553, 3.7478259491786465, 3.8320822222511093, 3.9122246565636627, 3.9887094577595765, 4.061917370818467, 4.1321698032829595, 4.1997408100402644, 4.26486616154863, 4.327750314117987, 4.388571843393678, 4.447487733637795, 4.5046368025485535, 4.560142464259402, 4.614114979520399, 4.666653304124968, 4.717846619402825, 4.767775608766863, 4.816513529678587, 4.864127119487927, 4.910677365376733, 4.9562201623688935, 5.000806878551826, 5.044484842916958, 5.087297768304377, 5.129286119633986, 5.170487435777725, 5.210936611966933, 5.250666148454372, 5.289706370200208, 5.328085621578066, 5.365830439464726, 5.402965707556928, 5.4395147943289945, 5.475499676688214, 5.510941051087474, 5.5458584336055585, 5.580270250296152, 5.614193918929883, 5.647645923104068, 5.680641879567632, 5.713196599500134, 5.745324144391048, 5.777037877085737, 5.808350508495987, 5.839274140413748, 5.86982030481548, 5.9, 5.929823723863996, 5.9593015045856275, 5.9884429289570615, 6.017257168580924, 6.045753004122898, 6.073938847792687, 6.101822764207897, 6.12941248977977, 6.15671545074591, 6.183738779962837, 6.2104893325603205, 6.236973700549734, 6.263198226469995, 6.2891690161469365, 6.314891950635005, 6.340372697403977, 6.365616720827827, 6.3906292920278425, 6.415415498117576, 6.439980250893168, 6.46432829500887, 6.48846421567431, 6.512392445907001, 6.536117273370882, 6.559642846829211, 6.58297318223787, 6.606112168503094, 6.629063572925788, 6.651831046352875, 6.674418128054583, 6.696828250345162, 6.719064742963206, 6.74113083722659, 6.763029669975934, 6.784764287319504, 6.80633764819156, 6.827752627735272, 6.849012020520625, 6.870118543606946, 6.891074839459066, 6.911883478725527, 6.932546962886641], [0.0, 1.7567334681314137, 2.1627925950260294, 2.442543189221426, 2.66271002059005, 2.84706168375813, 3.0071234017636335, 3.1494541284906985, 3.278180566206967, 3.3960855983223537, 3.5051440864071925, 3.606813452513794, 3.702203176320057, 3.7921794546059306, 3.877432855377405, 3.9585237323186826, 4.035913690021582, 4.1099879793778795, 4.181071811615693, 4.249442484914502, 4.315338559949185, 4.378966912660197, 4.4405082320396465, 4.500121360173978, 4.557946757594243, 4.614109298973817, 4.668720549939462, 4.721880637373226, 4.773679798017919, 4.824199670131254, 4.873514378137412, 4.921691449186985, 4.968792592212337, 5.014874363724914, 5.059988739725838, 5.104183609319705, 5.147503202664568, 5.189988463560906, 5.231677375133027, 5.2726052455785775, 5.312804959773335, 5.352307201557073, 5.3911406507438375, 5.429332158260083, 5.466906902287722, 5.50388852785441, 5.540299271952318, 5.576160075965729, 5.611490686935728, 5.646309748978439, 5.680634885994443, 5.71448277665557, 5.7478692225265755, 5.780809210069363, 5.813316967183579, 5.845406014856677, 5.87708921442725, 5.90837881090545, 5.939286472742482, 5.969823328396113, 5.999999999999999, 6.029826634410396, 6.059312931874002, 6.088468172534431, 6.117301240971823, 6.145820648949863, 6.1740345565265695, 6.201950791669454, 6.229576868501648, 6.256920004293198, 6.283987135300645, 6.310784931548277, 6.337319810635548, 6.36359795064746, 6.389625302237574, 6.415407599947128, 6.440950372818023, 6.4662589543524325, 6.4913384918671655, 6.516193955286829, 6.5408301454161055, 6.5652517017281165, 6.589463109702753, 6.613468707746151, 6.637272693719952, 6.660879131106718, 6.684291954835798, 6.707514976792077, 6.730551891028291, 6.7534062787000275, 6.776081612741132, 6.798581262295861, 6.820908496923003, 6.843066490585999, 6.865058325442171, 6.886886995443171, 6.908555409757947, 6.9300663960287165, 6.951422703469742, 6.972627005818007, 6.993681904144293, 7.014589929532592], [0.0, 1.7771778204116566, 2.187962545120306, 2.4709687952259993, 2.6936978640327887, 2.8801949581462165, 3.0421194277921075, 3.1861065580489614, 3.316331076543102, 3.4356082530707788, 3.5459359320659094, 3.6487884966340296, 3.7452883382542863, 3.8363117342523863, 3.9225572892635787, 4.004591878204983, 4.082882477688171, 4.1578188220425565, 4.229729907209777, 4.298896258484736, 4.365559212841943, 4.429928053783772, 4.4921855731081815, 4.552492461459537, 4.61099081400763, 4.667806958680901, 4.7230537594743724, 4.776832508517572, 4.829234492702233, 4.880342300368328, 4.9302309185784905, 4.9789686603446155, 5.026617952749642, 5.073236010493222, 5.118875414458033, 5.163584611068121, 5.2074083452192275, 5.250388037203854, 5.2925621121828454, 5.333966289260362, 5.3746338360167885, 5.414595793381481, 5.45388117493581, 5.4925171440894855, 5.530529172040769, 5.567941178991256, 5.6047756607207555, 5.641053802323278, 5.6767955806502215, 5.712019856792501, 5.746744459752515, 5.780986262303621, 5.814761249904578, 5.8480845834253685, 5.88097065634579, 5.913433147006607, 5.945485066422926, 5.977138802108759, 6.008406158309345, 6.039298392992203, 6.0698262519082835, 6.1, 6.129829450402695, 6.159323991259591, 6.188492610546983, 6.217343919085981, 6.245886171898983, 6.274127288053102, 6.302074869118651, 6.329736216358158, 6.3571183467502985, 6.384228007943159, 6.411071692222348, 6.437655649571618, 6.463985899896506, 6.490068244475165, 6.51590827669488, 6.541511392127568, 6.566882797993008, 6.5920275220543445, 6.616950420986626, 6.641656188255809, 6.6661493615424945, 6.690434329741924, 6.71451533956923, 6.7383965017966, 6.762081797146944, 6.785575081866757, 6.808880092999078, 6.832000453375944, 6.854939676348191, 6.877701170269197, 6.90028824274792, 6.922704104685465, 6.944951874108402, 6.967034579811122, 6.98895516481863, 7.010716489680422, 7.032321335605316, 7.053772407446465, 7.0750723365451575, 7.096223683441401], [0.0, 1.7975218683822298, 2.213009006124098, 2.4992549392046715, 2.724533674571669, 2.91316567369316, 3.0769437559265196, 3.2225791630476506, 3.3542944124190064, 3.4749370013287213, 3.586527644315513, 3.690557602323636, 3.7881621152854583, 3.880227491615161, 3.9674603331478506, 4.05043400403902, 4.129620826563728, 4.205414996492332, 4.2781492759113915, 4.3481074013983205, 4.415533472606147, 4.48063916878716, 4.543609374228353, 4.6046066190626025, 4.663774625078553, 4.721241166329735, 4.777120398809363, 4.831514774177496, 4.884516624322536, 4.9362094830054115, 4.986669195694919, 5.0359648574086595, 5.084159609856749, 5.131311322697831, 5.177473178728465, 5.222694178957815, 5.267019580493908, 5.310491277783492, 5.353148135855223, 5.395026282703785, 5.436159366736535, 5.476578784220462, 5.516313880866721, 5.555392131035175, 5.593839297502829, 5.631679574295159, 5.668935714709946, 5.705629146355237, 5.741780074765241, 5.777407576941144, 5.8125296859808895, 5.847163467807056, 5.881325090870186, 5.915029889592659, 5.948292422222048, 5.981126523680425, 6.0135453539250605, 6.045561442274676, 6.077186728102309, 6.108432598249829, 6.139309921478986, 6.1698290802389995, 6.199999999999999, 6.229832176374946, 6.259334700229006, 6.288516280954721, 6.3173852680729485, 6.345949671303456, 6.374217179234695, 6.402195176709596, 6.429890761032929, 6.457310757095738, 6.484461731503361, 6.511350005785551, 6.537981668760053, 6.564362588114516, 6.590498421265911, 6.616394625551372, 6.6420564677997564, 6.667489033328972, 6.692697234410324, 6.7176858182377055, 6.742459374436315, 6.767022342142794, 6.791379016686078, 6.815533555895969, 6.839489986064265, 6.863252207581417, 6.886824000269859, 6.910209028433595, 6.933410845642162, 6.956432899265687, 6.979278534776621, 7.001950999832504, 7.024453448153174, 7.046788943204813, 7.068960461702383, 7.090970896941204, 7.112823061967679, 7.134519692598469, 7.156063450296853, 7.177456924914339], [0.0, 1.8177677103009147, 2.2379345612957513, 2.527404538552339, 2.7552206325707704, 2.9459772309542758, 3.111599977901298, 3.2588757052222554, 3.3920744893221504, 3.5140758994104497, 3.6269234097306824, 3.7321250775920682, 3.830828929357348, 3.923931256106482, 4.012146618269854, 4.096054837916075, 4.176133557178774, 4.252781411732709, 4.326334911629187, 4.397080989226435, 4.465266493519825, 4.531105487946646, 4.594784939181937, 4.6564692079673895, 4.716303634858386, 4.774417433052724, 4.830926044304995, 4.885933074208428, 4.939531894603629, 4.991806980108678, 5.042835030454792, 5.092685918890326, 5.141423498302881, 5.189106290148434, 5.235788076231831, 5.281518409470227, 5.326343056711346, 5.370304384267323, 5.413441694911263, 5.455791523554555, 5.497387897593176, 5.538262566916436, 5.5784452077620035, 5.617963603938851, 5.656843808395203, 5.695110287658598, 5.732786051301678, 5.76989276827585, 5.806450871694224, 5.842479653425996, 5.877997349679437, 5.913021218593962, 5.94756761072855, 5.98165203322019, 6.015289208288859, 6.048493126682073, 6.081277096580289, 6.113653788422401, 6.145635276056957, 6.177233074578059, 6.208458175164458, 6.239321077204937, 6.269831817962146, 6.300000000000001, 6.329834816575868, 6.359345075177886, 6.38853921936921, 6.417425349084652, 6.446011239510745, 6.474304358667358, 6.5023118837975975, 6.5300407166625964, 6.557497497828659, 6.584688620026171, 6.6116202406524245, 6.638298293483991, 6.664728499658437, 6.690916377979958, 6.716867254598739, 6.742586272109624, 6.768078398111793, 6.793348433267717, 6.818401018896446, 6.843240644133487, 6.867871652686912, 6.8922982492169735, 6.9165245053643885, 6.94055436545047, 6.964391651870534, 6.988040070200363, 7.011503214034042, 7.034784569570109, 7.057887519961724, 7.080815349445436, 7.103571247262046, 7.126158311382159, 7.148579552048063, 7.170837895142831, 7.192936185396757, 7.214877189440548, 7.236663598714063, 7.258298032238819], [0.0, 1.8379173679952563, 2.2627416997969525, 2.555420404396124, 2.785761802547597, 2.9786329066177113, 3.1460915546198946, 3.294999809284905, 3.429675080116138, 3.553028855876672, 3.6671272623877247, 3.773495073527082, 3.8732930413419058, 3.967427392152151, 4.0566206071736755, 4.141458935707865, 4.222425314473261, 4.299922797955863, 4.374291626365845, 4.445821912659684, 4.514763242113484, 4.581332051022718, 4.645717378557431, 4.708085407371247, 4.768583089095827, 4.82734106923613, 4.88447606919971, 4.940092843030851, 4.994285797581733, 5.04714034385776, 5.0987340317941205, 5.149137509172698, 5.198415336679907, 5.24662668447249, 5.293825930517801, 5.340063177018975, 5.385384698141757, 5.4298333298219195, 5.473448810497381, 5.516268080063041, 5.558325543102997, 5.599653301448891, 5.640281360294627, 5.680237811428156, 5.719548996590371, 5.758239653516267, 5.796333046835834, 5.833851085697259, 5.870814429711371, 5.907242584594577, 5.943153988700536, 5.978566091472315, 6.013495424712161, 6.047957667451143, 6.081967705102636, 6.115539683499306, 6.1486870583406095, 6.181422640515188, 6.21375863770822, 6.245706692656745, 6.277277918374932, 6.30848293063557, 6.339331877962724, 6.369834469363161, 6.4, 6.429837374990946, 6.459355131494668, 6.488561459232432, 6.517464219577444, 6.546070963331347, 6.574388947295816, 6.602425149736876, 6.630186284830423, 6.657678816169213, 6.6849089694042805, 6.711882744087138, 6.7386059247732275, 6.765084091441785, 6.7913226292825, 6.817326737895037, 6.843101439943603, 6.868651589305227, 6.893981878747218, 6.919096847166419, 6.944000886420194, 6.968698247776768, 6.993193048010328, 7.017489275164343, 7.041590794004757, 7.065501351183053, 7.089224580127718, 7.112764005681232, 7.136123048498455, 7.159305029221156, 7.182313172442356, 7.205150610473151, 7.227820386923875, 7.250325460110536, 7.272668706296798, 7.294852922781017, 7.3168808308372215, 7.3387550785183535], [0.0, 1.8579727907948815, 2.287432821533981, 2.58330524706283, 2.81616013913336, 3.0111358598773865, 3.1804218228860113, 3.3309549699741883, 3.467099822378678, 3.591799639136423, 3.7071430917105848, 3.8146715923683168, 3.9155585593263678, 4.010720107680062, 4.100886602387205, 4.186650689923401, 4.268500576830661, 4.346843715740549, 4.422024059577094, 4.494334887020161, 4.564028506829687, 4.631323717062066, 4.696411619689809, 4.759460210757848, 4.820618045439527, 4.88001719484842, 4.937775654060429, 4.993999320199874, 5.048783630290022, 5.1022149273443524, 5.154371607525834, 5.205325089527581, 5.255140638524621, 5.303878070340652, 5.3515923563174335, 5.39833414537521, 5.444150216625146, 5.48908387343034, 5.533175287856027, 5.576461802886616, 5.618978198530309, 5.660756926915129, 5.7018283206527745, 5.742220778069833, 5.781960928349258, 5.821073779165127, 5.859582849011942, 5.897510286111331, 5.934876975512563, 5.971702635779153, 6.008005906464762, 6.043804427421426, 6.079114910847038, 6.113953206862837, 6.148334363312384, 6.182272680388197, 6.215781760618826, 6.248874554685808, 6.281563403485037, 6.313860076799531, 6.345775808909087, 6.3773213314262, 6.408506903616007, 6.439342340430319, 6.469837038461423, 6.499999999999999, 6.529839855362509, 6.559364883636764, 6.5885830319795655, 6.617501933587187, 6.646128924447792, 6.674471058974508, 6.7025351246085645, 6.730327655473683, 6.757854945155437, 6.785123058672665, 6.8121378437020965, 6.838904941111907, 6.865429794855177, 6.891717661269797, 6.917773617827472, 6.943602571370918, 6.969209265875096, 6.994598289765462, 7.0197740828234885, 7.044740942707399, 7.069503031113774, 7.094064379603761, 7.118428895115774, 7.142600365184897, 7.1665824628877255, 7.190378751529948, 7.21399268909274, 7.237427632452841, 7.260686841390143, 7.283773482395644, 7.306690632291666, 7.329441281675469, 7.352028338196616, 7.374454629677685, 7.396722907087351, 7.418835847374205], [0.0, 1.87793585920423, 2.312010241679373, 2.6110616811854634, 2.8464184926397897, 3.043489138385226, 3.214594001690468, 3.366744558639588, 3.504352225255135, 3.6303918845471195, 3.7469746497989034, 3.8556584950479125, 3.957629446353298, 4.053813462048353, 4.144948754528524, 4.231634337984916, 4.314363664515684, 4.3935485646446875, 4.469536686912909, 4.542624461145582, 4.613066907044944, 4.681085173552499, 4.746872415944105, 4.810598435305411, 4.872413382967197, 4.9324507490867875, 4.9908297965432435, 5.047657560277081, 5.103030502738761, 5.157035894657979, 5.209752974528642, 5.261253928405075, 5.311604722706785, 5.360865815951154, 5.409092770121882, 5.456336778338711, 5.502645122332973, 5.548061570742614, 5.592626727263344, 5.636378336112873, 5.679351550994695, 5.721579172720113, 5.763091859810877, 5.803918315720613, 5.84408545575067, 5.883618556271159, 5.922541388472052, 5.960876338547496, 5.998644515947069, 6.035865851101238, 6.072559183837146, 6.10874234353898, 6.14443222196956, 6.179644839552431, 6.214395405813358, 6.2486983745938876, 6.2825674945755265, 6.316015855588961, 6.349055931127373, 6.38169961743472, 6.413958269497997, 6.445842734235974, 6.477363381144904, 6.508530130633764, 6.539352480256933, 6.569839529030588, 6.6, 6.629842261207991, 6.659374345199932, 6.688603967187301, 6.717538541980102, 6.746185199787905, 6.7745508009798945, 6.802641949885966, 6.83046500771339, 6.858026104646864, 6.8853311511937285, 6.912385848830711, 6.939195700003679, 6.9657660175274705, 6.992101933428904, 7.018208407272477, 7.044090234004995, 7.069752051352444, 7.095198346799724, 7.1204334641814295, 7.145461609909668, 7.1702868588628705, 7.194913159957717, 7.219344341424625, 7.243584115805719, 7.26763608469278, 7.29150374322141, 7.315190484336453, 7.338699602842649, 7.362034299253493, 7.385197683450353, 7.408192778163096, 7.431022522282648, 7.4536897740152455, 7.476197313887466, 7.498547847610492], [0.0, 1.8978083883364978, 2.3364761948995985, 2.638692230477756, 2.8765396142640283, 3.075695683816405, 3.2486111980893253, 3.402371829397824, 3.541435675866499, 3.668809101053003, 3.7866255582796384, 3.8964595082408673, 3.9995095276574077, 4.096711373458103, 4.1888110698852525, 4.276413969965715, 4.360018747563418, 4.440041591239287, 4.516833828390389, 4.590695025695811, 4.661882901505051, 4.730620944982663, 4.797104355395424, 4.8615047306832295, 4.923973811095183, 4.984646499396513, 5.043643320519522, 5.101072442060542, 5.157031347246571, 5.211608230316007, 5.264883168273443, 5.316929111054175, 5.3678127231418005, 5.417595102832555, 5.46633240007332, 5.5140763497152046, 5.560874733830158, 5.606771784220787, 5.651808534255695, 5.696023127566161, 5.739451089856132, 5.7821255690388025, 5.824077548067853, 5.865336034140098, 5.9059282273776414, 5.945879671627993, 5.985214389630539, 6.02395500447266, 6.062122848986511, 6.099738064508621, 6.13681969023131, 6.173385744211322, 6.209453296962013, 6.2450385384368605, 6.280156839110545, 6.3148228057767986, 6.349050332607223, 6.382852647950571, 6.416242357295938, 6.449231482774675, 6.481831499533532, 6.514053369274596, 6.545907571225299, 6.577404130773507, 6.60855264597779, 6.639362312141141, 6.669841944617079, 6.699999999999999, 6.729844595836576, 6.759383528981524, 6.788624292709203, 6.817574092681866, 6.8462398618658975, 6.874628274478958, 6.902745759043331, 6.930598510614019, 6.958192502244019, 6.985533495743728, 7.012627051786516, 7.039478539408028, 7.066093144942769, 7.092475880437907, 7.1186315915809155, 7.144564965174722, 7.170280536191296, 7.19578269443218, 7.221075690822209, 7.246163643360638, 7.271050542752028, 7.295740257737564, 7.320236540145909, 7.344543029681295, 7.368663258465242, 7.39260065534712, 7.416358549997666, 7.439940176798567, 7.46334867854031, 7.486587109939627, 7.509658440987121, 7.53256556013489, 7.555311277333357, 7.577898326925844], [0.0, 1.917592131127654, 2.3608328393119833, 2.666199332202895, 2.9065261609601647, 3.107758337078165, 3.282476412705541, 3.437839924894906, 3.578353445306954, 3.7070546773984145, 3.82609931471987, 3.9370782309638512, 4.0412024974388885, 4.13941762589128, 4.23247741750847, 4.32099353583246, 4.405469853163189, 4.486326896627841, 4.5639196560432, 4.638550820927391, 4.710480796220181, 4.779935400853536, 4.847111868953031, 4.912183587284834, 4.975303877917411, 5.0366090499126575, 5.096220884617526, 5.154248677223693, 5.210790927174071, 5.265936748089723, 5.319767051739629, 5.372355548527195, 5.423769597881309, 5.4740709350186565, 5.5233162952224015, 5.57155795265468, 5.618844187492637, 5.665219692634221, 5.710725929201233, 5.755401438454028, 5.799282116434988, 5.842401456608411, 5.884790764910424, 5.92647935092396, 5.96749469831936, 6.007862617226501, 6.047607380810312, 6.086751847993016, 6.1253175739913175, 6.163324910105525, 6.200793094002415, 6.2377403315683315, 6.274183871268555, 6.310140071829065, 6.3456244639543735, 6.380651806707037, 6.4152361390987345, 6.4493908273774165, 6.483128608438357, 6.516461629737867, 6.549401486045601, 6.581959253334133, 6.61414552007182, 6.645970416156392, 6.677443639701577, 6.708574481866997, 6.739371849902002, 6.769844288556936, 6.800000000000001, 6.829846862364387, 6.859392447038248, 6.8886440347994125, 6.917608630887115, 6.946292979094537, 6.974703574958224, 7.00284667811366, 7.030728323880054, 7.058354334131916, 7.085730327509971, 7.112861729019486, 7.139753779060018, 7.166411541926924, 7.192839913821647, 7.219043630404787, 7.245027273923225, 7.270795279940079, 7.296351943694039, 7.321701426112527, 7.346847759501287, 7.371794852931276, 7.396546497342174, 7.421106370380382, 7.445478040988099, 7.4696649737588, 7.493670533073447, 7.517497987030605, 7.541150511182846, 7.56463119209086, 7.5879430307059765, 7.611088945591024, 7.6340717759888115, 7.656894284746879], [0.0, 1.9372887813476263, 2.3850822601919113, 2.693585341360245, 2.9363807000033373, 3.139679843189913, 3.3161925448834246, 3.4731518817045592, 3.6151086942629433, 3.745131887948966, 3.865399298634904, 3.9775181407575775, 4.0827119252092885, 4.181935875610851, 4.275951535858951, 4.3653768522304075, 4.450720872576457, 4.532408443491182, 4.610798201088269, 4.6861959439774346, 4.7588647518617195, 4.829032763184341, 4.89689923797175, 4.962639343941564, 5.026407978018084, 5.08834284936903, 5.148566990224979, 5.2071908184090185, 5.264313845106362, 5.3200260992734005, 5.374409323768681, 5.427537986115965, 5.479480137630116, 5.530298147644406, 5.580049334201496, 5.628786508400374, 5.676558446330612, 5.723410299955651, 5.769383956267426, 5.814518352404906, 5.858849753118597, 5.902411995902709, 5.945236708253965, 5.987353500810251, 6.028790139541898, 6.069572699688912, 6.109725703739336, 6.149272245412037, 6.1882341013292805, 6.226631831830847, 6.2644848721842346, 6.301811615278525, 6.338629486747533, 6.374955013346768, 6.410803885305206, 6.446191013283899, 6.481130580496993, 6.515636090484565, 6.549720410969594, 6.583395814181635, 6.616674013986642, 6.649566200124634, 6.682083069823988, 6.71423485703222, 6.746031359477751, 6.777481963754848, 6.80859566860415, 6.83938110654386, 6.8698465639911905, 6.8999999999999995, 6.929849063728358, 6.959401110738993, 6.988663218225831, 7.017642199251284, 7.046344616071152, 7.074776792617096, 7.1029448262004315, 7.130854598495364, 7.158511785854786, 7.1859218690072, 7.213090142179203, 7.240021721684336, 7.2667215540156365, 7.293194423476297, 7.3194449593799895, 7.345477642849958, 7.371296813243667, 7.3969066742277265, 7.4223112995259255, 7.447514638361452, 7.472520520612825, 7.49733266170159, 7.521954667228521, 7.546390037373858, 7.570642171075979, 7.594714370001896, 7.6186098423220425, 7.6423317063008795, 7.6658829937141695, 7.689266653102916, 7.712485552873361, 7.735542484251783], [0.0, 1.9568999764242136, 2.409226473449469, 2.7208525346116845, 2.9661057132699877, 3.171462855859813, 3.349762397522531, 3.508310635390906, 3.6517044782827837, 3.783043898150679, 3.9045287771227217, 4.017782599484686, 4.124041261742736, 4.2242696572566265, 4.319237039040067, 4.4095676088466496, 4.49577556762446, 4.578290062694203, 4.657473360646783, 4.733634355694517, 4.807038790699097, 4.877917113551642, 4.946470601389986, 5.012876195156427, 5.07729035979849, 5.139852198515273, 5.20068598899394, 5.2599032668183865, 5.3176045505266165, 5.373880780439112, 5.428814526898253, 5.482481011263339, 5.5349489737334245, 5.5862814150072095, 5.636536233358513, 5.685766774493648, 5.734022308263059, 5.781348443703998, 5.827787491830867, 5.8733787839437115, 5.9181589519014945, 5.962162175735742, 6.005420403108664, 6.047963544406951, 6.08981964667615, 6.1310150491162005, 6.171574522456555, 6.211521394194043, 6.2508776613959105, 6.289664092534478, 6.327900319620664, 6.365604921734964, 6.402795500911071, 6.439488751205015, 6.47570052167813, 6.511445873932251, 6.546739134758349, 6.581593944392984, 6.616023300819231, 6.650039600498559, 6.683654675876509, 6.7168798299669605, 6.749725868286447, 6.782203128380844, 6.814321507161084, 6.846090486242026, 6.8775191554586605, 6.908616234716261, 6.939390094315532, 6.969848773879917, 6.999999999999999, 7.029851202698944, 7.059409530813187, 7.088681866373846, 7.117674838066504, 7.146394833840053, 7.174848012728954, 7.203040315947664, 7.230977477310859, 7.25866503302851, 7.28610833092073, 7.313312539093557, 7.3402826541134285, 7.36702350871509, 7.393539779074806, 7.41983599167828, 7.4459165298103365, 7.4717856396913485, 7.497447436283454, 7.5229059087878705, 7.548164925853018, 7.5732282405116935, 7.598099494864209, 7.622782224523162, 7.647279862834422, 7.671595744887814, 7.69573311133011, 7.719695111992, 7.743484809339945, 7.767105181763058, 7.79055912670449, 7.8138494636461315], [0.0, 1.9764273000938697, 2.433267428892944, 2.748003113967228, 2.995703601255696, 3.2031099417807956, 3.383188681615186, 3.543319025260764, 3.6881437527231973, 3.820793769654429, 3.9434909101529865, 4.057874858772159, 4.165193844662289, 4.266422389567395, 4.362337422648544, 4.453569374383241, 4.540637576778118, 4.623975459487534, 4.703948904053114, 4.780869887050778, 4.8550068031113085, 4.92659239969689, 4.995829962430135, 5.062898197894453, 5.12795513235461, 5.191141257079217, 5.252582089885566, 5.312390279338018, 5.370667347019215, 5.427505140716089, 5.482987054715941, 5.537189060989675, 5.5901805856743785, 5.64202525813401, 5.692781554392068, 5.7425033524758256, 5.791240413884932, 5.8390388027756766, 5.885941252371506, 5.931987486447829, 5.977214502402049, 6.021656821338075, 6.065346709714351, 6.108314376384432, 6.150588148267004, 6.192194627393058, 6.233158831671799, 6.27350432137822, 6.313253313081769, 6.352426782497181, 6.391044557537383, 6.429125402677997, 6.4666870955981794, 6.503746496938992, 6.540319613914839, 6.576421658422811, 6.61206710021667, 6.647269715644846, 6.6820426323934266, 6.716398370624486, 6.750348880856028, 6.783905578891348, 6.817079378072022, 6.849880719099224, 6.882319597642224, 6.914405589930096, 6.946147876502596, 6.977555264278342, 7.008636207082785, 7.039398824764381, 7.069850921015066, 7.1, 7.1298532818917355, 7.159417717395133, 7.188700001341463, 7.217706585423058, 7.246443690133559, 7.274917315973036, 7.303133253972197, 7.33109709558521, 7.358814241996496, 7.386289912883088, 7.413529154670677, 7.440536848318432, 7.467317716664793, 7.493876331363918, 7.52021711944013, 7.546344369485575, 7.5722622375243755, 7.597974752564801, 7.623485821859369, 7.648799235891272, 7.673918673104263, 7.698847704391765, 7.7235897973599865, 7.7481483203786246, 7.772526546431903, 7.796727656781735, 7.820754744454026, 7.84461081755835, 7.868298802450582, 7.891821546747384], [0.0, 1.9958722848922634, 2.457207013295063, 2.775039210247872, 3.0251766868501644, 3.234623584666903, 3.416474020509756, 3.578179798828698, 3.7244293773968633, 3.858384465130655, 3.982288755536364, 4.097798065124784, 4.206172903688631, 4.3083973807571665, 4.405256069271587, 4.497385602169287, 4.585310420879832, 4.66946821933436, 4.750228478782419, 4.827906245166447, 4.902772553704874, 4.97506244173458, 5.044981194893985, 5.112709277962613, 5.178406271939023, 5.242214050308406, 5.304259365789055, 5.364655975232806, 5.4235063990375005, 5.4809033886300975, 5.5369311587685806, 5.591666428870428, 5.645179308118433, 5.697534051890987, 5.74878971152513, 5.79900069512451, 5.848217253764895, 5.896485904802557, 5.943849801889703, 5.9903490596221936, 6.0360210393945435, 6.08090060194488, 6.125020331183647, 6.168410733172746, 6.21110041352389, 6.2531162359908725, 6.294483464620391, 6.335225891484069, 6.3753659517280035, 6.41492482743549, 6.4539225415954204, 6.492378043296806, 6.530309285123645, 6.567733293599602, 6.6046662334252915, 6.6411234661593195, 6.677119603915423, 6.712668558579973, 6.7477835869951655, 6.7824773325020855, 6.8167618631933315, 6.850648707186032, 6.884148885192146, 6.917272940633185, 6.950030967520329, 6.982432636297921, 7.014487217828013, 7.046203605675671, 7.077590336838897, 7.108655611052889, 7.1394073087858265, 7.16985300803224, 7.199999999999999, 7.229855303778142, 7.2594256800647115, 7.288717644026708, 7.317737477357795, 7.346491239593676, 7.374984778739836, 7.403223741261695, 7.431213581482967, 7.458959570434225, 7.486466804190178, 7.513740211731076, 7.540784562360775, 7.5676044727114355, 7.594204413362446, 7.620588715099058, 7.646761574834237, 7.6727270612154586, 7.698489119936553, 7.724051578773202, 7.749418152359348, 7.7745924467204786, 7.799577963578678, 7.824378104443188, 7.848996174499327, 7.873435386307702, 7.897698863324805, 7.92178964325535, 7.945710681246024, 7.96946485292963], [0.0, 2.0152364144963832, 2.4810470532764626, 2.801962886342034, 3.0545272188871833, 3.2660061890490337, 3.449620953919792, 3.6128956160159196, 3.76056412094294, 3.8958188527970714, 4.020925273597638, 4.137555264733812, 4.246981565575912, 4.350197833570978, 4.447996253656339, 4.541019635438511, 4.629797508524236, 4.714771813389923, 4.796315616024915, 4.874747018975273, 4.950339687067111, 5.023330937990361, 5.093928049082879, 5.162313236009457, 5.228647628037631, 5.293074475121705, 5.355721759746067, 5.416704342441598, 5.476125738268119, 5.534079598535143, 5.59065095505969, 5.645917271597821, 5.699949337537826, 5.752812031669467, 5.804564978251084, 5.8552631132585615, 5.904957175308055, 5.953694133071344, 6.001517558881192, 6.0484679565288175, 6.094583049892295, 6.139898037931717, 6.18444582068951, 6.228257200200094, 6.2713610596093545, 6.313784523305604, 6.3555531004495585, 6.396690813945626, 6.437220316607678, 6.477162996029455, 6.516539069464662, 6.55536766984805, 6.593666923941175, 6.631454023460541, 6.668745289938121, 6.705556233971721, 6.741901609443101, 6.777795463212982, 6.813251180742618, 6.8482815280399105, 6.882898690283159, 6.917114307436305, 6.95093950713523, 6.984384935094656, 7.017460783258752, 7.050176815895369, 7.0825423938132825, 7.114566496863715, 7.146257744871377, 7.177624417126025, 7.20867447055284, 7.239415556668722, 7.26985503742149, 7.300000000000001, 7.32985727069519, 7.3594334278847855, 7.388734814207999, 7.417767547990685, 7.446537533976196, 7.475050473412459, 7.50331187354152, 7.531327056533956, 7.559101167907046, 7.586639184462441, 7.613945921776207, 7.641026041271476, 7.667884056901595, 7.694524341469478, 7.720951132606912, 7.747168538435748, 7.773180542931289, 7.798991011006636, 7.824603693335436, 7.8500222309291585, 7.875250159483903, 7.900290913510655, 7.925147830261936, 7.949824153466897, 7.9743230368860845, 7.998647547696291, 8.022800669715298, 8.046785306475554], [0.0, 2.0345211259289444, 2.5047893180196286, 2.8287761402705343, 3.0837573754858885, 3.29726008384753, 3.4826319416974636, 3.647469053102329, 3.796550664940633, 3.9330997106801884, 4.059403331574076, 4.177149408002906, 4.28762285875739, 4.3918268500434365, 4.490561147575404, 4.584474712296532, 4.674102141122587, 4.7598896036588725, 4.842213735932421, 4.921395684556858, 4.997711733181165, 5.0714014704959025, 5.142674157369802, 5.211713753172011, 5.27868292908912, 5.34372630589923, 5.406973090809178, 5.468539243502371, 5.5285292696211945, 5.587037716667027, 5.644150430164918, 5.699945615156751, 5.754494738446584, 5.807863299678751, 5.860111493683168, 5.911294782142993, 5.961464389215215, 6.010667733036143, 6.058948802901956, 6.106348490203026, 6.152904879814329, 6.198653507530777, 6.243627588230223, 6.287858218705729, 6.331374558499106, 6.374203991564243, 6.416372271170586, 6.457903650108614, 6.4988209979672495, 6.539145907007821, 6.578898787952104, 6.618098956826581, 6.656764713856014, 6.694913415272241, 6.732561538795378, 6.769724743451176, 6.8064179243079845, 6.842655262647307, 6.878450272021947, 6.913815840603526, 6.948764270175845, 6.983307312090939, 7.017456200470086, 7.051221682901681, 7.084614048861228, 7.11764315605529, 7.150318454870467, 7.18264901109025, 7.214643527026365, 7.246310361196846, 7.277657546670299, 7.308692808184465, 7.339423578136976, 7.369857011537218, 7.3999999999999995, 7.4298591848545295, 7.459440969435612, 7.488751530618135, 7.51779682965062, 7.546582622338823, 7.575114468626086, 7.603397741613251, 7.631437636057385, 7.659239176385413, 7.6868072242558325, 7.714146485699049, 7.7412615178644755, 7.76815673540036, 7.794836416490311, 7.821304708568663, 7.847565633735183, 7.873623093888081, 7.8994808755929, 7.925142654703601, 7.950612000750963, 7.975892381112366, 8.000987164976012, 8.025899627111773, 8.050632951459955, 8.07519023454856, 8.099574488748873, 8.123788645378564], [0.0, 2.053727811634944, 2.528435521825442, 2.855480908073818, 3.1128692671982305, 3.328387525737563, 3.515509367388149, 3.6819026064493405, 3.8323916077841855, 3.9702297306296748, 4.097725707758709, 4.216583353811595, 4.32809971772164, 4.433287435981289, 4.532953824410192, 4.6277539704000725, 4.718227517673441, 4.804824847853493, 4.887926152560616, 4.967855610159739, 5.044892112526978, 5.119277510165083, 5.191223039448316, 5.2609143963951706, 5.328515787872707, 5.394173199936483, 5.458017059560572, 5.52016442113375, 5.58072077687308, 5.639781566845822, 5.697433446992804, 5.753755360642495, 5.8088194492739085, 5.8626918308739775, 5.915433268535665, 5.9670997475224, 6.017742975567513, 6.067410818453311, 6.116147680752363, 6.163994839885969, 6.210990740265421, 6.257171253157614, 6.302569907002014, 6.347218092157732, 6.3911452434442095, 6.4343790033307116, 6.476945368207756, 6.518868819821773, 6.560172443659669, 6.600878035822275, 6.641006199716671, 6.680576433720282, 6.719607210819246, 6.758116051095108, 6.796119587824189, 6.833633627859653, 6.8706732068851935, 6.907252640059235, 6.943385568507872, 6.979085002072176, 7.01436335866966, 7.04923250058978, 7.083703768008372, 7.117788009975324, 7.151495613102867, 7.184836528158219, 7.217820294743376, 7.250456064226418, 7.2827526210723414, 7.314718402706903, 7.346361518034063, 7.377689764716142, 7.408710645315557, 7.439431382387815, 7.4698589326073, 7.5, 7.529861048350737, 7.559448312846549, 7.588767811012503, 7.617825352991443, 7.646626551214779, 7.675176829507556, 7.703481431667404, 7.731545429553832, 7.759373730721318, 7.786971085627061, 7.81434209444177, 7.8414912134897214, 7.8684227613422735, 7.895140924587183, 7.921649763294436, 7.947953216197703, 7.974055105609211, 7.999959142084436, 8.025668928851944, 8.051187966022528, 8.076519654590868, 8.101667300241957, 8.126634116973758, 8.151423230546728, 8.176037681770133, 8.200480429634435], [0.0, 2.0728578214393827, 2.5519873265234096, 2.8820790665339464, 3.1418649399763243, 3.3593907023219236, 3.5482555415815993, 3.7161986960096662, 3.868089468336113, 4.007211522102984, 4.13589509540649, 4.255859873534738, 4.368414987138326, 4.474582505189463, 4.575177263471963, 4.670860451368359, 4.762176739260312, 4.849580703973917, 4.933456078528467, 5.014130060936998, 5.091884140890341, 5.166962421673944, 5.239578107281095, 5.309918623446676, 5.378149706587554, 5.444418702586357, 5.508857253314908, 5.57158350349712, 5.6327039279861895, 5.692314855852004, 5.750503750215868, 5.807350289745494, 5.862927287901443, 5.917301478544735, 5.970534190762794, 6.022681931309107, 6.073796889562841, 6.12392737716523, 6.17311821230739, 6.22141105690046, 6.268844713456721, 6.315455387375801, 6.361276919406995, 6.4063409923035035, 6.45067731506345, 6.494313787639446, 6.537276648572504, 6.57959060765098, 6.6212789653978685, 6.662363720939748, 6.70286566959977, 6.742804491378338, 6.782198831333269, 6.821066372741705, 6.859423903815174, 6.897287378644099, 6.9346719729661634, 6.971592135282253, 7.008061633782467, 7.0440935994916, 7.079700565997257, 7.114894506083437, 7.149686865557146, 7.1840885945247175, 7.2181101763473245, 7.25176165448133, 7.285052657387964, 7.317992421678229, 7.350589813642425, 7.38285334929902, 7.414791213084578, 7.446411275294883, 7.477721108377021, 7.508728002162969, 7.5394389781269595, 7.569860802741465, 7.6000000000000005, 7.629862863168959, 7.6594554658252925, 7.688783672232011, 7.717853147099055, 7.746669364773168, 7.775237617896772, 7.803563025572596, 7.831650541067882, 7.859504959089259, 7.8871309226569855, 7.914532929604992, 7.941715338731151, 7.968682375620337, 7.995438138161167, 8.021986601775726, 8.048331624380216, 8.074476951093095, 8.100426218706188, 8.126182959933029, 8.151750607447793, 8.177132497727179, 8.20233187470682, 8.227351893262917, 8.25219562252919, 8.276866049058427], [0.0, 2.0919124643944205, 2.575446343745787, 2.9085724357428675, 3.170746377972216, 3.3902717351246308, 3.5808727050738467, 3.75035966863888, 3.9036466893741224, 4.044047615736249, 4.173914106419865, 4.294981654834994, 4.408571425750964, 4.515714883458436, 4.617234354078848, 4.713797104945414, 4.8059528132953275, 4.894160234629665, 4.978806629414511, 5.060222203414447, 5.138691033900355, 5.21445946806506, 5.287742669769007, 5.358729787648872, 5.427588081645332, 5.494466252110751, 5.559497151028343, 5.622800009161555, 5.684482280128397, 5.744641178498967, 5.803364971394986, 5.860734069926374, 5.916821956887826, 5.971695979588079, 6.025418030879156, 6.078045136950083, 6.1296299669283085, 6.1802212765574405, 6.229864296017598, 6.278601070194978, 6.326470758292033, 6.373509898524739, 6.419752642721803, 6.465230964878565, 6.509974847091645, 6.554012445782589, 6.597370240688898, 6.640073168742436, 6.682144744655102, 6.723607169779356, 6.76448143059833, 6.8047873880198555, 6.844543858495523, 6.883768687855125, 6.922478818634991, 6.9606903515827305, 6.998418601938248, 7.035678151019555, 7.072482893580159, 7.10884608135115, 7.144780363134517, 7.1802978217734825, 7.2154100082900685, 7.250127973448918, 7.284462296978983, 7.318423114660604, 7.352020143464161, 7.385262704907748, 7.4181597467846006, 7.450719863396264, 7.482951314414331, 7.51486204248189, 7.5464596896553715, 7.577751612778172, 7.60874489786908, 7.6394463736010305, 7.669862623939026, 7.7, 7.72986463119196, 7.7594624356848625, 7.788799130261213, 7.817880239590421, 7.846711104967257, 7.875296892551552, 7.90364260114321, 7.931753069523964, 7.959632983394807, 7.987286881935786, 8.014719164012805, 8.04193409405422, 8.068935807618285, 8.095728316670959, 8.122315514592144, 8.148701180927114, 8.174888985898727, 8.200882494694808, 8.22668517154422, 8.252300383594061, 8.27773140459968, 8.30298141843832, 8.328053522456562, 8.352950730660934], [0.0, 2.110893010523572, 2.5988141370749274, 2.934962781527521, 3.199515506181586, 3.4210326824176716, 3.6133630318528636, 3.7843878012223895, 3.9390656408458917, 4.080740466716123, 4.211785274828889, 4.333951305243887, 4.448571710052701, 4.55668731232935, 4.659127899405596, 4.756566792930316, 4.849558657526331, 4.938566411120295, 5.0239808279080815, 5.106135109709724, 5.18531591131397, 5.261771815095246, 5.3357199371599195, 5.407351142346699, 5.4768342081956245, 5.544319184261735, 5.609940127933942, 5.673817351791988, 5.736059284412635, 5.796764022422787, 5.856020633818103, 5.913910259302505, 5.970507048402015, 6.0258789594876, 6.080088446983604, 6.133193054494684, 6.185245929031002, 6.2362962687115795, 6.286389714103459, 6.3355686915786364, 6.383872715642697, 6.4313386560337555, 6.478000974450252, 6.52389193499713, 6.569041791807522, 6.613478956774587, 6.6572301498943895, 6.700320534359019, 6.7427738382363716, 6.784612464318406, 6.825857589504879, 6.866529254907564, 6.906646447705337, 6.946227175648526, 6.985288534998153, 7.023846772588713, 7.061917342619854, 7.099514958710238, 7.136653641684618, 7.173346763510995, 7.209607087757714, 7.24544680689924, 7.280877576763464, 7.3159105483819165, 7.350556397476587, 7.3848253517927755, 7.418727216465836, 7.452271397590777, 7.485466924146833, 7.518322468414212, 7.550846365006972, 7.583046628634174, 7.614930970690905, 7.646506814771399, 7.677781311188008, 7.708761350572254, 7.739453576627418, 7.769864398096015, 7.799999999999999, 7.82986635420665, 7.859469229368546, 7.888814200282072, 7.91790665670516, 7.946751811671751, 7.975354709337352, 8.003720232387407, 8.031853109037673, 8.059757919653531, 8.08743910301311, 8.114900962237195, 8.142147670407198, 8.16918327589084, 8.196011707393819, 8.222636778754355, 8.24906219349633, 8.275291549155586, 8.301328341392967, 8.3271759679067, 8.35283773215589, 8.378316846906058, 8.403616437606928, 8.42873954561201], [0.0, 2.129800692469916, 2.622092224072471, 2.9612518177414953, 3.228174192941969, 3.4516755418921825, 3.6457286319199205, 3.8182853036303346, 3.9743486229447393, 4.117292457966076, 4.249511060079847, 4.372771355545805, 4.488418437759814, 4.597502452651926, 4.7008606201214835, 4.799172292891188, 4.892997103823476, 4.982802117291495, 5.068981607732093, 5.151871761519238, 5.231761801064737, 5.308902535344011, 5.383513025214896, 5.455785845129827, 5.525891284402313, 5.593980736610631, 5.66018945992197, 5.724638844579404, 5.7874382903756825, 5.848686772608403, 5.908474157072698, 5.966882311265659, 6.023986048885128, 6.079853937018506, 6.134548989506644, 6.1881292653835285, 6.240648387707498, 6.292155995274758, 6.3426981374638425, 6.39231762066807, 6.441054313332187, 6.48894541544377, 6.53602569738144, 6.582327712246045, 6.627881985162907, 6.67271718251608, 6.716860263637859, 6.7603366171119745, 6.803170183543271, 6.845383566389901, 6.886998132237258, 6.928034101709278, 6.968510632056712, 7.008445892328837, 7.047857131921229, 7.086760743194462, 7.125172318774476, 7.163106704072695, 7.200578045501144, 7.237599834803159, 7.274184949872867, 7.310345692395112, 7.3460938226013175, 7.381440591404987, 7.416396770152642, 7.450972678201499, 7.485178208513429, 7.519022851435675, 7.552515716821807, 7.585665554631342, 7.618480774133111, 7.6509694618254915, 7.683139398176046, 7.714998073273596, 7.746552701477239, 7.777810235139235, 7.808777377471816, 7.839460594621855, 7.869866127011762, 7.8999999999999995, 7.929868033910099, 7.959475853472982, 7.988828896723705, 8.017932423390368, 8.04679152280997, 8.075411121403125, 8.103795989737142, 8.13195074920463, 8.159879878342727, 8.187587718816111, 8.215078481085301, 8.24235624978004, 8.269424988796212, 8.296288546133335, 8.322950658488478, 8.349414955621315, 8.375684964504007, 8.401764113268632, 8.427655734964025, 8.453363071133076, 8.478889275220773, 8.504237415822626], [0.0, 2.148636707054751, 2.6452820781982744, 2.9874412084321627, 3.256724252295235, 3.4822022531844965, 3.6779715539576427, 3.852054321511926, 4.009497869018179, 4.153705903159552, 4.2870938501451725, 4.411444262978139, 4.528114131096472, 4.638162887949061, 4.742435157830549, 4.841616301677382, 4.936270901760077, 5.026870153181654, 5.1138118173526825, 5.197435053888459, 5.278031643091577, 5.3558546120987796, 5.431124959148018, 5.504036961825364, 5.574762415487592, 5.6434540526418555, 5.71024832768221, 5.775267704430305, 5.838622550213596, 5.900412715669876, 5.960728861369783, 6.0196535788487555, 6.07726234345899, 6.133624328697053, 6.188803105699896, 6.242857246977166, 6.295840849830968, 6.347803992064358, 6.39879313031781, 6.448851449565537, 6.498019170849884, 6.5463338231561155, 6.593830484373016, 6.640541995501932, 6.686499151633219, 6.731730872677197, 6.776264356395224, 6.8201252159083445, 6.863337603552759, 6.9059243226922105, 6.947906928878747, 6.989305821568047, 7.0301403274381045, 7.070428776225753, 7.110188569880688, 7.149436245737963, 7.1881875343251185, 7.226457412346798, 7.2642601513262735, 7.3016093623282226, 7.338518037139213, 7.3749985862405225, 7.411062873871376, 7.4467222504486585, 7.48198758258097, 7.516869280890201, 7.55137732583184, 7.585521291686018, 7.619310368874095, 7.652753384740467, 7.685858822925761, 7.718634841445565, 7.751089289578107, 7.783229723654754, 7.815063421838591, 7.846597397968665, 7.877838414540601, 7.908792994888047, 7.939467434623876, 7.969867812394985, 8.0, 8.029869671915117, 8.059482314269518, 8.088843233308483, 8.117957563379242, 8.146830274471805, 8.175466179344507, 8.20386994026168, 8.23204607536876, 8.25999896472823, 8.287732856038028, 8.315251870052478, 8.342560005724264, 8.369661145084716, 8.39655905787835, 8.423257405966533, 8.449759747514065, 8.476069540971514, 8.50219014886529, 8.528124841406573, 8.553876799929503, 8.579449120168336], [0.0, 2.167402216752623, 2.668385130626379, 3.0135325698915416, 3.2851674462233107, 3.5126147002666546, 3.71009378785492, 3.885696938939861, 4.044515548320415, 4.18998304957147, 4.324535964466519, 4.449972414259708, 4.567661239903264, 4.678671127600903, 4.783854078327251, 4.88390143874322, 4.979382722001329, 5.070773238472782, 5.1584742234898115, 5.242827798779937, 5.324128292962125, 5.402630943031661, 5.47855867735483, 5.552107470276352, 5.623450617559016, 5.692742185627124, 5.760119820624012, 5.825707055931401, 5.889615222789889, 5.951945043900982, 6.012787971635914, 6.072227318858325, 6.130339220098139, 6.18719345299124, 6.242854143884673, 6.297380376841759, 6.350826721633236, 6.403243693425765, 6.454678154597344, 6.505173667286019, 6.554770803811925, 6.603507420926551, 6.651418902877807, 6.6985383774899, 6.7448969088077115, 6.790523669318862, 6.835446094321307, 6.879690020632947, 6.923279811528803, 6.966238469529946, 7.008587738447762, 7.050348195900287, 7.091539337358573, 7.132179652645549, 7.1722866956940035, 7.211877148270815, 7.250966878288947, 7.289570993254823, 7.327703889334656, 7.365379296467838, 7.402610319907066, 7.439409478522816, 7.475788740172806, 7.511759554404851, 7.5473328827330555, 7.582519226702368, 7.617328653934407, 7.651770822328017, 7.685855002570777, 7.7195900991023, 7.752984669656635, 7.786046943498882, 7.8187848384603695, 7.8512059768670595, 7.883317700447198, 7.915127084296473, 7.946640949971995, 7.9778658777801335, 8.008808218317643, 8.039474103320389, 8.069869455869418, 8.1, 8.12987126975542, 8.15948861772402, 8.188857223094784, 8.217982099264034, 8.24686810102321, 8.275519931355374, 8.30394214786601, 8.332139168871668, 8.360115279168339, 8.387874635499694, 8.415421271744005, 8.442759103837027, 8.469891934447025, 8.4968234574169, 8.52355726198733, 8.550096836813893, 8.576445573790233, 8.602606771688516, 8.628583639627642, 8.654379300379027], [0.0, 2.186098351088182, 2.6914027719647486, 3.0395274725984747, 3.313505486765422, 3.542914713710233, 3.7420972670980053, 3.9192151809145956, 4.079403768618977, 4.226126080778606, 4.361839656741856, 4.488358128458702, 4.607062144580988, 4.71902960986018, 4.825119874679589, 4.926030249295598, 5.02233515951345, 5.114514015758545, 5.202971514441828, 5.288052728452223, 5.3700545253040435, 5.44923434368136, 5.525817034943175, 5.600000263920014, 5.671958821233733, 5.741848102294338, 5.809806940588601, 5.875959935104192, 5.940419377431299, 6.003286859111158, 6.06465462138834, 6.124606695787968, 6.183219873580733, 6.240564534308363, 6.296705357475405, 6.3517019368076575, 6.405609312797794, 6.458478436359163, 6.510356574107296, 6.561287663949705, 6.611312628185659, 6.660469650121132, 6.708794419230559, 6.756320349100638, 6.803078771736461, 6.849099111269179, 6.894409039655183, 6.939034616582227, 6.983000415484327, 7.026329637303601, 7.0690442134147835, 7.111164898939612, 7.152711357518176, 7.193702238467663, 7.234155247142082, 7.2740872092061775, 7.3135141294504304, 7.352451245699467, 7.390913078301652, 7.428913475631607, 7.466465655988683, 7.5035822462318436, 7.540275317454223, 7.576556417968087, 7.61243660384218, 7.647926467208374, 7.683036162532161, 7.717775431021968, 7.752153623334849, 7.7861797207206225, 7.819862354732831, 7.853209825622685, 7.886230119521173, 7.918930924504873, 7.951319645632195, 7.9834034190290035, 8.015189125095546, 8.04668340090029, 8.077892651820596, 8.108823062485028, 8.13948060706747, 8.16987105897904, 8.200000000000001, 8.229872828890418, 8.259494769515255, 8.288870878516676, 8.318006052563826, 8.346905035207964, 8.37557242336874, 8.40401267347535, 8.43223010728468, 8.460228917396709, 8.488013172486168, 8.515586822267895, 8.542953702212193, 8.570117538025256, 8.597081949908757, 8.623850456611615, 8.650426479286141, 8.676813345159893, 8.703014291033819, 8.72903246661653], [0.0, 2.2047262079599155, 2.714336353884972, 3.0654274430591273, 3.3417400380244926, 3.5731040728316557, 3.773983871036436, 3.9526110157375167, 4.114164578664882, 4.2621371192185995, 4.39900711756666, 4.526603659710483, 4.646319158880329, 4.759240704709682, 4.866234970150819, 4.968005207276803, 5.065130736604811, 5.158095053641218, 5.247306303235974, 5.3331124986619, 5.415813037056717, 5.495667550752809, 5.572902807079214, 5.647718155178679, 5.720289875072968, 5.7907746863044, 5.859312605367047, 5.926029292962989, 5.991037997524845, 6.05444117626062, 6.116331856407287, 6.176794785526934, 6.235907409232633, 6.293740706773817, 6.350359908792432, 6.405825116815486, 6.460191840338535, 6.513511464430287, 6.565831658467546, 6.617196734754998, 6.66764796429294, 6.717223855749264, 6.7659604027102604, 6.8138913034815225, 6.861048157049775, 6.90746063827071, 6.953156654894887, 6.998162488666003, 7.042502922409573, 7.0862013547641425, 7.129279903982821, 7.171759502042809, 7.213659980139087, 7.255000146500638, 7.295797857349707, 7.336070081723395, 7.375832960789828, 7.415101862215925, 7.453891430078685, 7.492215630755447, 7.530087795179373, 7.5675206578035406, 7.604526392579496, 7.6411166462232645, 7.6773025690129275, 7.7130948433364575, 7.74850371018607, 7.783538993775535, 7.818210124439335, 7.852526159956981, 7.886495805431931, 7.920127431842263, 7.953429093369201, 7.986408543599819, 8.019073250691413, 8.051430411577144, 8.083486965285505, 8.115249605439764, 8.146724791997837, 8.177918762287826, 8.208837541389858, 8.239486951910584, 8.269872623192905, 8.299999999999999, 8.329874350709657, 8.359500775051949, 8.388884211420786, 8.41802944378748, 8.446941108242266, 8.475623699187805, 8.504081575206895, 8.532318964624874, 8.560339970785867, 8.58814857706043, 8.615748651601107, 8.64314395186103, 8.670338128889792, 8.697334731419758, 8.724137209755051, 8.750748919474711, 8.777173124960632, 8.803413002760253], [0.0, 2.2232868548954183, 2.7371871906676835, 3.091233965552308, 3.3698727180697845, 3.603184507726564, 3.8057554270317753, 3.9858863572613825, 4.148799970535063, 4.298018228616631, 4.436040476938511, 4.5647111997948295, 4.685434532547266, 4.799306716571957, 4.90720172097007, 5.009828718193075, 5.107771905809797, 5.201518849668475, 5.2914811306159795, 5.378009691700021, 5.461406450554766, 5.541933225246155, 5.619818692160375, 5.6952638786753385, 5.7684465488389165, 5.839524741548219, 5.908639652036298, 5.975917998888932, 6.04147398392886, 6.105410926907493, 6.167822638218327, 6.228794578876923, 6.288404846477847, 6.346725017814472, 6.403820872677618, 6.459753018563344, 6.514577432277903, 6.568345931478923, 6.621106586851297, 6.672904083746054, 6.723780040606388, 6.773773290288197, 6.822920129392378, 6.871254539916146, 6.918808386864578, 6.965611594913285, 7.011692306756241, 7.057077025391904, 7.1017907422817945, 7.145857053047587, 7.189298262146506, 7.232135477773113, 7.274388698072739, 7.316076889612801, 7.3572180589394405, 7.397829317944824, 7.437926943682671, 7.477526433193712, 7.516642553837167, 7.555289389567333, 7.593480383544796, 7.631228377428548, 7.6685456476574245, 7.705443938996174, 7.7419344955922975, 7.7780280897642236, 7.813735048718701, 7.8490652793753535, 7.884028291458616, 7.918633219001571, 7.9528888403922195, 7.986803597080323, 8.020385611051811, 8.053642701167893, 8.086582398457086, 8.119211960440454, 8.1515383845632, 8.183568420799348, 8.215308583490431, 8.246765162473952, 8.27794423355261, 8.308851668351092, 8.339493143603326, 8.369874149909625, 8.399999999999999, 8.429875836536963, 8.459506639488655, 8.488897233100596, 8.518052292492278, 8.546976349902822, 8.575673800608064, 8.604148908529808, 8.632405811556476, 8.660448526592921, 8.688280954356003, 8.715906883931249, 8.743329997104876, 8.770553872484507, 8.797581989420904, 8.824417731742288, 8.851064391311986, 8.877525171419437], [0.0, 2.2417813302425134, 2.7599565606690053, 3.1169484837855834, 3.3979051007422947, 3.633157701200205, 3.837413712496528, 4.019043067025747, 4.183311881855071, 4.3337714162880685, 4.472941806633691, 4.602682880581466, 4.724410453833276, 4.839229886880524, 4.948022418961365, 5.05150312179861, 5.150261052625279, 5.244787833120082, 5.335498467876942, 5.42274681927336, 5.506837316453986, 5.588033955425835, 5.666567314826159, 5.742640094284869, 5.816431536585158, 5.888100995275225, 5.957790840124708, 6.025628843831572, 6.091730158209684, 6.156198962478768, 6.219129847396762, 6.280608984889133, 6.34071512220752, 6.399520431558904, 6.457091239925177, 6.513488658967588, 6.568769131137056, 6.622984905137877, 6.676184451532312, 6.728412827387763, 6.779711997351635, 6.830121117312047, 6.879676785804212, 6.928413267505561, 6.976362692491128, 7.023555234365794, 7.0700192699293405, 7.115781522646174, 7.160867191870004, 7.2053000695033615, 7.249102645543734, 7.292296203774805, 7.33490090869705, 7.37693588465182, 7.418419287973226, 7.459368372899199, 7.499799551884596, 7.539728450882724, 7.579169960095505, 7.61813828063501, 7.656646967489145, 7.694708969140608, 7.732336664150141, 7.769541894981656, 7.806335999317417, 7.842729839085692, 7.878733827400393, 7.9143579535921385, 7.94961180649228, 7.984504596115615, 8.019045173873415, 8.053242051435886, 8.087103418351928, 8.12063715852417, 8.153850865628208, 8.186751857556999, 8.2193471899642, 8.251643668973681, 8.283647863116718, 8.315366114553001, 8.346804549626968, 8.37796908880659, 8.408865456047863, 8.439499187624822, 8.469875640461565, 8.499999999999998, 8.529877287634267, 8.559512367740515, 8.58890995432835, 8.618074617338456, 8.647010788608892, 8.675722767531024, 8.704214726414412, 8.732490715578647, 8.760554668188819, 8.788410404850067, 8.816061637975654, 8.84351197594195, 8.870764927042801, 8.897823903254894, 8.924692223825021, 8.951373118689272], [0.0, 2.260210644300214, 2.782645707712922, 3.1425724024677613, 3.4258387173689746, 3.6630252906003404, 3.868960456830096, 4.052082956284539, 4.217702197909527, 4.369398635324824, 4.509713122463747, 4.640520776352086, 4.763249051878767, 4.879012396521232, 4.988699294039863, 5.093030694644, 5.192600498108888, 5.287904367653858, 5.3793607195570585, 5.467326325240151, 5.552108116509501, 5.633972259639697, 5.713151228816884, 5.789849390031155, 5.864247459591014, 5.9365061010638644, 6.0067688546177065, 6.075164543348749, 6.141809265714905, 6.206808057376056, 6.270256286705138, 6.332240834032785, 6.392841093978787, 6.452129832065916, 6.510173920539229, 6.567034973448848, 6.6227698972497615, 6.677431370174229, 6.731068261253002, 6.783725997960192, 6.835446889927637, 6.886270414937547, 6.936233472395648, 6.985370608663624, 7.033714217952551, 7.08129472191953, 7.128140730645327, 7.174279187283537, 7.219735498347595, 7.26453365132933, 7.308696321112787, 7.35224496645212, 7.395199917616831, 7.437580456166323, 7.4794048876949315, 7.520690608284827, 7.561454165314948, 7.601711313196983, 7.641477064542744, 7.680765737209299, 7.71959099761787, 7.757965900698494, 7.7959029267740165, 7.833414015663289, 7.870510598253787, 7.907203625767899, 7.943503596924026, 7.979420583173424, 8.014964252175643, 8.050143889659491, 8.08496841980223, 8.1194464242471, 8.15358615986793, 8.187395575379611, 8.220882326884093, 8.25405379243352, 8.286917085684914, 8.319479068714164, 8.351746364051357, 8.383725365994032, 8.415422251250293, 8.446842988959297, 8.47799335013274, 8.508878916557448, 8.539505089195911, 8.569877096118695, 8.599999999999998, 8.629878705205195, 8.65951796449699, 8.68892238538479, 8.718096436140073, 8.74704445149878, 8.775770638070345, 8.804279079471367, 8.832573741200834, 8.86065847527245, 8.888537024618616, 8.916213027279568, 8.943690020390251, 8.970971443976657, 8.99806064457255, 9.024960878666796], [0.0, 2.278575780393232, 2.80525584241416, 3.168107088802871, 3.45367505839138, 3.6927888695586497, 3.900397343258081, 4.085007787932433, 4.251972753647225, 4.404901786672574, 4.54635638641942, 4.678226906006461, 4.80195239897754, 4.91865636815175, 5.0292345165834895, 5.134413652497476, 5.23479250134758, 5.330870753819557, 5.42307022599498, 5.511750588209261, 5.597221266215251, 5.679750588997404, 5.759572919689727, 5.836894284839585, 5.911896869149417, 5.984742641643835, 6.055576308813423, 6.124527740494748, 6.191713978493184, 6.25724091192632, 6.321204684074133, 6.383692881205486, 6.444785543053934, 6.504556026391887, 6.56307174682875, 6.620394819054007, 6.676582611910872, 6.731688231663794, 6.785760944424387, 6.838846546783576, 6.890987692156264, 6.942224179097792, 6.992593206836652, 7.042129602437849, 7.090866023328676, 7.138833138354643, 7.186059790065125, 7.2325731405378635, 7.278398802724606, 7.323560959025369, 7.368082468566903, 7.411984964464519, 7.455288942179476, 7.498013839941733, 7.540178112086071, 7.5817992960449425, 7.622894073651509, 7.6634783273285, 7.703567191671337, 7.743175100875538, 7.782315832407586, 7.821002547274164, 7.859247827205847, 7.897063709037399, 7.9344617165369336, 7.971452889909998, 8.00804781318138, 8.044256639636993, 8.080089115490075, 8.115554601919783, 8.150662095615969, 8.18542024795123, 8.21983738288988, 8.253921513733367, 8.2876803587926, 8.321121356069415, 8.354251677022207, 8.387078239484044, 8.419607719795772, 8.451846564211216, 8.483800999626762, 8.515477043683262, 8.546880514284243, 8.578017038570836, 8.608892061390556, 8.639510853294183, 8.669878518092215, 8.7, 8.729880090398384, 8.759523434234673, 8.788934536086874, 8.81811776591244, 8.84707736450122, 8.875817448650874, 8.904342016081687, 8.932654950106551, 8.960760024070726, 8.98866090557501, 9.01636116049502, 9.043864256808364, 9.071173568240763, 9.098292377741386], [0.0, 2.2968776958934614, 2.8277881434357783, 3.1935538739104268, 3.481415574913951, 3.7224499896462104, 3.931726010580837, 4.117819278336152, 4.286125335587291, 4.4402827211054765, 4.582873508708773, 4.715803235159689, 4.840522512729493, 4.9581638684066, 5.069630199687548, 5.1756541526466595, 5.276839261804397, 5.373689231448689, 5.466629265760971, 5.556021924011109, 5.642179117313221, 5.725371329916659, 5.805834807400735, 5.883777231153739, 5.959382249217212, 6.032813131579036, 6.104215747037403, 6.173721008565912, 6.241446898069998, 6.30750015518699, 6.3719776954363505, 6.434967808595031, 6.496551177289596, 6.5568017475067615, 6.61578747634979, 6.673570977424116, 6.73021008036944, 6.785758318008931, 6.840265352168149, 6.893777347284171, 6.946337299371522, 6.997985326654434, 7.048758927152049, 7.0986932076663924, 7.147821087934872, 7.1961734831404796, 7.243779467500945, 7.2906664212645245, 7.336860163110631, 7.38238506967651, 7.427264183697379, 7.4715193120494785, 7.515171114817164, 7.558239186361629, 7.600742129246064, 7.642697621766621, 7.684122479747836, 7.725032713182808, 7.765443578230655, 7.805369625024851, 7.844824741694878, 7.883822194958907, 7.922374667606152, 7.960494293153319, 7.998192687929425, 8.03548098081686, 8.072369840853135, 8.108869502877113, 8.144989791385306, 8.180740142747485, 8.216129625916471, 8.25116696175419, 8.285860541084476, 8.320218441573004, 8.354248443525492, 8.387958044687098, 8.421354474118614, 8.454444705218338, 8.487235467952644, 8.519733260352789, 8.551944359330664, 8.583874830861857, 8.615530539580305, 8.64691715782531, 8.678040174178351, 8.708904901524178, 8.739516484667982, 8.769879907537907, 8.799999999999999, 8.829881444310587, 8.859528781229228, 8.88894641581363, 8.918138622916402, 8.947109552402033, 8.975863234101194, 9.004403582518217, 9.032734401306525, 9.060859387525722, 9.088782135693156, 9.11650614164183, 9.144034806195817, 9.171371438673503], [0.0, 2.3151173231916338, 2.8502437586854166, 3.218914054176404, 3.509061680176766, 3.752010161948211, 3.962948054836715, 4.15051909907644, 4.320161683632351, 4.475543241104551, 4.619266349695894, 4.753251678137133, 4.878961358088325, 4.997536909994617, 5.109888401309334, 5.216754296088033, 5.3187429215507365, 5.4163619819277695, 5.5100400579694675, 5.60014258804804, 5.686983960180265, 5.770836806545226, 5.85193924876088, 5.930500617424409, 6.006706018936167, 6.080720019819648, 6.1526896472248875, 6.222746853712332, 6.291010558087971, 6.357588347614242, 6.422577907421873, 6.486068228401605, 6.548140633885007, 6.608869657067792, 6.668323794704172, 6.726566157617533, 6.7836550346758075, 6.839644383809143, 6.8945842612102854, 6.948521197910547, 7.00149853135808, 7.053556698358057, 7.104733494703373, 7.1550643059810275, 7.204582313345803, 7.253318677479796, 7.301302703480637, 7.348561989024582, 7.395122557818545, 7.441008980075933, 7.4862444815155476, 7.530851042183185, 7.574849486226024, 7.6182595636051165, 7.661100024607592, 7.703388687913888, 7.745142502883891, 7.786377606646904, 7.827109376512011, 7.867352478156066, 7.907120909994922, 7.94642804409846, 7.985286663970594, 8.02370899948093, 8.061706759204366, 8.099291160398339, 8.136472956823745, 8.17326246459485, 8.209669586225013, 8.245703833018712, 8.281374345945805, 8.316689915121044, 8.351658998000236, 8.386289736394229, 8.420589972392559, 8.45456726328038, 8.48822889552483, 8.521581897900338, 8.554633053816296, 8.587388912905167, 8.619855801924137, 8.652039835019025, 8.683946923395135, 8.715582784436116, 8.746952950308561, 8.778062776087124, 8.808917447432163, 8.839521987849459, 8.869881265559279, 8.899999999999999, 8.929882767989588, 8.959534009566548, 8.98895803353032, 9.018159022699688, 9.047141038906421, 9.075908027740136, 9.104463823059268, 9.13281215128197, 9.160956635469839, 9.188900799216475, 9.216648070352075, 9.244201784474496], [0.0, 2.3332955706220977, 2.872623806453834, 3.2441888925390443, 3.5366147509572454, 3.7814708585627055, 3.994065030885075, 4.1831088786059984, 4.354083492794235, 4.51068510264545, 4.655536721746079, 4.790574099873119, 4.917270849310451, 5.036777453695234, 5.150011126309293, 5.257716129610789, 5.360505567390942, 5.4588911303618985, 5.553304764480086, 5.644114777531324, 5.731638026099791, 5.816149283066108, 5.897888539773642, 5.977066770478561, 6.053870535032373, 6.128465692131092, 6.201000423378519, 6.2716077174235405, 6.340407426819845, 6.407507983602556, 6.4730078399237785, 6.53699668542866, 6.599556481997679, 6.660762348059469, 6.720683318203166, 6.7793829987968754, 6.836920136391364, 6.893349112593195, 6.948720376635174, 7.003080824909194, 7.05647413514804, 7.108941061665742, 7.160519697026879, 7.21124570466526, 7.2611525262733245, 7.310271567206119, 7.3586323626642205, 7.406262727020198, 7.453188888318506, 7.499435609697299, 7.54502629924318, 7.589983109588756, 7.634327028391926, 7.678077960689975, 7.721254803996853, 7.7638755169048626, 7.80595718185987, 7.847516062699541, 7.888567657475235, 7.92912674701836, 7.969207439660004, 8.00882321246723, 8.04798694931973, 8.086710976115757, 8.125007093365673, 8.162886606404555, 8.200360353431583, 8.23743873156291, 8.274131721066203, 8.310448907928478, 8.346399504894277, 8.38199237109813, 8.417236030403592, 8.452138688550818, 8.486708249205249, 8.520952328991665, 8.554878271590377, 8.588493160965589, 8.621803833789862, 8.654816891123225, 8.68753870940041, 8.719975450775369, 8.752133072868055, 8.784017337954879, 8.815633821640875, 8.84698792104862, 8.87808486255616, 8.908929709113723, 8.939527367166729, 8.969882593210476, 8.999999999999998, 9.029884062436881, 9.059539123153158, 9.088969397811004, 9.118178980135601, 9.147171846697244, 9.175951861457735, 9.204522780094974, 9.232888254118755, 9.261051834789853, 9.28901697685371, 9.316787042099214], [0.0, 2.351413323343486, 2.8949293764991357, 3.269379619713324, 3.5640761289049925, 3.810833514027872, 4.025078453913786, 4.2155902038283415, 4.387892414837357, 4.5457100169009514, 4.69168639098299, 4.827772317719068, 4.95545285181095, 5.075887410259539, 5.190000328394819, 5.298541647781274, 5.402129232885546, 5.50127874763514, 5.5964254919936325, 5.687940633611436, 5.77614348942508, 5.861310965892763, 5.943684917861069, 6.023477957775285, 6.100878094101185, 6.176052473407132, 6.249150427908826, 6.320305978895633, 6.389639909561562, 6.457261493903131, 6.523269948541282, 6.587755659550209, 6.650801225234298, 6.712482347307529, 6.772868596404119, 6.832024072787788, 6.8900079791690345, 6.9468751194208975, 7.002676334508263, 7.057458884967729, 7.111266787684298, 7.164141113424227, 7.21612025053617, 7.267240139376105, 7.317534481307092, 7.367034925542896, 7.4157712366212865, 7.463771444890009, 7.5110619820510545, 7.557667803525295, 7.603612499160241, 7.648918393600966, 7.6936066374719445, 7.737697290370627, 7.781209396547831, 7.824161054042115, 7.866569477942434, 7.908451058373153, 7.949821413726087, 7.990695439603982, 8.03108735388738, 8.071010738291106, 8.110478576736593, 8.149503290831179, 8.188096772714731, 8.226270415506862, 8.264035141564035, 8.301401428734728, 8.338379334782156, 8.374978520127346, 8.411208269050666, 8.447077509476733, 8.482594831455852, 8.517768504444744, 8.552606493479836, 8.587116474328061, 8.621305847692504, 8.655181752543475, 8.688751078639461, 8.722020478296907, 8.754996377462772, 8.78768498613938, 8.820092308206865, 8.852224150685004, 8.884086132472722, 8.915683692600586, 8.947022098028821, 8.978106451020842, 9.008941696120017, 9.039532626755237, 9.069883891499018, 9.1, 9.129885328610218, 9.159544125725953, 9.18898051685965, 9.218198509459185, 9.24720199748955, 9.275994765791019, 9.304580494226911, 9.332962761633103, 9.361145049580708, 9.389130745962495], [0.0, 2.3694714441778335, 2.9171615310798504, 3.294487435357657, 3.59144712181366, 3.8400995266819327, 4.055989800875601, 4.247964621602152, 4.421590059844567, 4.580619651863121, 4.727717078962918, 4.864848103166318, 4.993509183931955, 5.114868642221633, 5.229857911972339, 5.3392327948338085, 5.443615900279052, 5.5435268523736845, 5.639404294049217, 5.7316222434078385, 5.820502469640544, 5.906324005760751, 5.989330563984827, 6.069736389555313, 6.147730934784359, 6.223482629873828, 6.29714195386426, 6.368843957286715, 6.438710350912455, 6.506851247928204, 6.573366626907606, 6.638347568061708, 6.701877304024111, 6.7640321178743426, 6.824882114527389, 6.884491886517, 6.942921091212025, 7.000224953362151, 7.0564547043750165, 7.1116579677333975, 7.165879098358243, 7.219159482426483, 7.271537803097315, 7.32305027673744, 7.373730863525876, 7.423611455732472, 7.472722046477366, 7.521090881372631, 7.568744595107483, 7.615708334752642, 7.662005871318291, 7.70765970089581, 7.752691136539875, 7.797120391899386, 7.840966657479067, 7.884248170304767, 7.9269822776719545, 7.969185495576036, 8.010873562353204, 8.052061487999788, 8.092763599585215, 8.132993583127648, 8.172764522260984, 8.212088933986628, 8.250978801772375, 8.289445606233441, 8.327500353606581, 8.36515360220688, 8.402415487038034, 8.439295742710096, 8.475803724803807, 8.511948429807463, 8.547738513740274, 8.583182309565808, 8.618287843489489, 8.653062850225746, 8.687514787312754, 8.721650848545888, 8.755477976594833, 8.789002874863744, 8.822232018648856, 8.855171665643367, 8.887827865835341, 8.920206470840656, 8.952313142709626, 8.984153362242875, 9.015732436849243, 9.047055507975935, 9.078127558138867, 9.108953417578974, 9.139537770568355, 9.169885161388343, 9.2, 9.229886567425954, 9.259549020861307, 9.288991398529884, 9.318217624301107, 9.34723151208165, 9.376036769995032, 9.40463700436147, 9.43303572348946, 9.461236341289732], [0.0, 2.3874707744105366, 2.939321305939793, 3.3195135091861476, 3.6187290048334595, 3.869270259959614, 4.086800511857504, 4.280233640175442, 4.455177997709923, 4.61541563388978, 4.763630464270911, 4.9018031834885525, 5.03144161862851, 5.15372296562547, 5.26958573391297, 5.379791466473271, 5.484967502337761, 5.585637412817409, 5.682243172928189, 5.775161641944038, 5.864717033326782, 5.951190499721777, 6.034827604668257, 6.115844220890233, 6.194431239845593, 6.270758371190668, 6.344977237057192, 6.417223913867089, 6.487621036949023, 6.556279555947833, 6.623300208909221, 6.688774767921238, 6.752787097881553, 6.815414061342531, 6.876726295760505, 6.936788884336606, 6.99566193761783, 7.053401099860297, 7.110057991643257, 7.1656805982140455, 7.220313611429038, 7.273998731848977, 7.326774936483806, 7.378678716812362, 7.429744290987006, 7.48000379354238, 7.529487445436803, 7.578223706845854, 7.626239414785125, 7.673559907351242, 7.720209136127258, 7.766209768092699, 7.811583278203625, 7.856350033658853, 7.9005293707408635, 7.944139665010305, 7.987198395538743, 8.029722203782837, 8.071726947632662, 8.113227751105706, 8.154239050104804, 8.194774634611882, 8.234847687648672, 8.274470821300085, 8.313656110064505, 8.352415121767907, 8.390758946254243, 8.428698222043245, 8.466243161127625, 8.50340357206492, 8.540188881504125, 8.576608154273991, 8.612670112147864, 8.648383151389407, 8.683755359173892, 8.718794528971337, 8.753508174969971, 8.787903545611746, 8.82198763630528, 8.855767201376125, 8.889248765309118, 8.922438633333073, 8.955342901393873, 8.987967465558306, 9.020318030887593, 9.052400119816427, 9.084219080070575, 9.115780092153464, 9.14708817642994, 9.178148199833124, 9.208964882218481, 9.23954280238729, 9.269886403800205, 9.3, 9.329887779761277, 9.359553811983611, 9.38900205034351, 9.418236337719406, 9.447260410403015, 9.476077902109424, 9.504692347797455, 9.533107187311098], [0.0, 2.4054121345533774, 2.9614097112474607, 3.3444589820294905, 3.6459230216276928, 3.8983470436287497, 4.117511991386833, 4.312398730553501, 4.4886577595625505, 4.650099549179574, 4.799428184043205, 4.938639243308386, 5.0692518850766, 5.192452151671966, 5.309185605236651, 5.420219511594455, 5.526185924102742, 5.6276123486050205, 5.724944081470147, 5.8185608139933045, 5.908789196034929, 5.995912493045663, 6.080178113925084, 6.161803553637079, 6.240981138150243, 6.317881852454661, 6.392658458091731, 6.465448054070173, 6.536374197298351, 6.605548671185252, 6.6730729708026235, 6.739039557887201, 6.803532927564404, 6.866630519993136, 6.928403503455934, 6.988917450241026, 7.048232922614014, 7.1064059829863515, 7.1634886398555055, 7.219529239068242, 7.274572808331202, 7.328661361576408, 7.381834168718157, 7.434127995461367, 7.485577317100897, 7.536214509655918, 7.586070021189141, 7.6351725257486125, 7.683549062024668, 7.731225158524607, 7.778224946822786, 7.8245712642365, 7.870285747101761, 7.915388915672767, 7.959900251540252, 8.003838268353487, 8.047220576535727, 8.090063942600812, 8.132384343607658, 8.174197017227682, 8.215516507846614, 8.2563567090753, 8.296730903003223, 8.336651796492555, 8.3761315547791, 8.4151818326187, 8.453813803193247, 8.492038184968797, 8.529865266679119, 8.56730493059108, 8.604366674193034, 8.64105963043409, 8.677392586629955, 8.713374002140517, 8.749012024914535, 8.784314506988377, 8.819289019017878, 8.853942863915567, 8.888283089659142, 8.922316501331544, 8.956049672447797, 8.989488955619237, 9.022640492601543, 9.055510223769254, 9.088103897055973, 9.120427076396377, 9.152485149703303, 9.18428333641062, 9.215826694610197, 9.247120127809175, 9.27816839133178, 9.308976098388055, 9.339547725830363, 9.369887619616879, 9.399999999999999, 9.429888966456257, 9.459558502373241, 9.489012479507835, 9.518254662229234, 9.547288711559158, 9.576118189020931, 9.604746560308273], [0.0, 2.423296325072703, 2.9834277324925247, 3.3693249668474277, 3.6730303854764625, 3.927331174970405, 4.148125609677756, 4.344461327804361, 4.522030839125471, 4.684672945179673, 4.83511183542014, 4.975357926092426, 5.1069416702077435, 5.231057928290876, 5.348659292719376, 5.460518733922907, 5.567273004562748, 5.669453532477675, 5.76750892480603, 5.86182169584009, 5.95272092407539, 6.040491981035459, 6.125384115100039, 6.207616438303667, 6.28738270655462, 6.364855176112925, 6.440187744298944, 6.513518529449754, 6.584972007116831, 6.654660791816543, 6.722687133234441, 6.789144180558403, 6.854117057133394, 6.917683778884331, 6.97991604322849, 7.040879909982736, 7.100636391691888, 7.1592419675902965, 7.2167490328575505, 7.27320629279081, 7.328659109876803, 7.383149810420286, 7.436717956306572, 7.489400586592852, 7.5412324328971065, 7.59224611195355, 7.642472298205625, 7.691939878892344, 7.740676093736159, 7.788706661048303, 7.8360558918209, 7.882746793166236, 7.928801162286043, 7.974239672002196, 8.019081948750658, 8.06334664382931, 8.107051498594547, 8.150213404218901, 8.192848456550394, 8.234972006552223, 8.276598706747333, 8.317742554045287, 8.358416929287628, 8.398634633811797, 8.438407923301876, 8.477748539166583, 8.516667737660194, 8.555176316940335, 8.59328464223731, 8.631002669292435, 8.668339966207702, 8.705305733835505, 8.741908824825074, 8.77815776143146, 8.81406075218326, 8.84962570749657, 8.884860254314901, 8.919771749847786, 8.954367294474496, 8.988653743873627, 9.022637720434153, 9.056325623998944, 9.089723641987513, 9.12283775894096, 9.15567376552866, 9.188237267053028, 9.22053369148593, 9.252568297067615, 9.284346179496763, 9.315872278737997, 9.347151385471275, 9.378188147205766, 9.408987074079139, 9.439552544361684, 9.469888809683283, 9.499999999999998, 9.529890128315822, 9.559563095174072, 9.589022692931954, 9.61827260983081, 9.647316433873815, 9.676157656522054], [0.0, 2.441124127084689, 3.0053763313418, 3.3941125496954285, 3.7000522803304965, 3.956223919905662, 4.178642703821396, 4.376422832305261, 4.555298694013009, 4.719137331929842, 4.870682976933381, 5.0119608355787335, 5.144512620174208, 5.269541981641636, 5.388008520427757, 5.500690893581588, 5.608230538251509, 5.711162791905588, 5.809939562012859, 5.904946176961839, 5.996514136225717, 6.084930910760513, 6.170447582626276, 6.253284875829607, 6.333637971709893, 6.41168039378881, 6.487567171584599, 6.561437439548768, 6.633416588979441, 6.703618062879903, 6.772144863170226, 6.839090824321909, 6.904541695918698, 6.968576067836147, 7.031266164957918, 7.092678533092344, 7.152874633643741, 7.211911361355117, 7.269841496868989, 7.326714103799566, 7.382574878358108, 7.4374664582372025, 7.4914286963726, 7.5444989043118875, 7.5967120691879835, 7.648101047691181, 7.698696739931879, 7.748528245667867, 7.797623005019862, 7.846006925504585, 7.893704496966225, 7.940738895776701, 7.987132079496259, 8.032904873033402, 8.078077047212636, 8.122667390546445, 8.166693774911531, 8.210173215746071, 8.253121927312662, 8.29555537350907, 8.337488314654497, 8.378934850631524, 8.419908460722397, 8.46042204044194, 8.50048793563734, 8.540117974096969, 8.579323494885557, 8.618115375601047, 8.656504057729077, 8.694499570253752, 8.732111551668055, 8.769349270513574, 8.806221644567056, 8.842737258780419, 8.878904382071083, 8.914730983050806, 8.9502247447733, 8.985393078573903, 9.020243137068242, 9.054781826371034, 9.08901581759111, 9.122951557653955, 9.156595279498932, 9.189953011694453, 9.223030587510914, 9.255833653488045, 9.288367677530422, 9.320637956562331, 9.352649623770686, 9.384407655462633, 9.415916877562399, 9.447181971770128, 9.478207481403853, 9.508997816944088, 9.53955726129928, 9.56988997480891, 9.600000000000001, 9.629891266111539, 9.659567593400492, 9.689032697242002, 9.71829019203561, 9.747343594928518], [0.0, 2.458896303019505, 3.0272564464569314, 3.4188227906481456, 3.7269898618178345, 3.985026514072006, 4.2090645789227406, 4.4082846109333556, 4.588462746970169, 4.753494183346397, 4.906143129831116, 5.048449537140455, 5.181966341748704, 5.307905957547063, 5.427234971184968, 5.540737708587476, 5.649060276773591, 5.7527419106418956, 5.852237807694472, 5.947936101635563, 6.0401707053621205, 6.12923118271202, 6.2153704437042006, 6.298810819287668, 6.3797489117853114, 6.458359508026359, 6.534798766194265, 6.609206833684498, 6.681710014684532, 6.752422578099533, 6.821448275736984, 6.888881625213787, 6.954809000398493, 7.019309563326454, 7.082456064701929, 7.144315534808331, 7.204949882508949, 7.264416416758985, 7.3227683024611645, 7.380054960428732, 7.4363224195561966, 7.491613627952385, 7.545968728695357, 7.599425304972875, 7.652018598635539, 7.703781705581013, 7.7547457508825275, 7.804940046153554, 7.854392231287795, 7.903128402417099, 7.951173227679674, 7.998550052178944, 8.045280993333321, 8.091387027663403, 8.136888069931713, 8.181803045437203, 8.22614995616964, 8.269945941445116, 8.313207333571317, 8.355949709028206, 8.3981879355949, 8.439936215805698, 8.481208127076401, 8.522016658805365, 8.562374246721546, 8.602292804723461, 8.641783754427909, 8.680858052625274, 8.7195262168186, 8.757798349006254, 8.795684157852573, 8.833192979377138, 8.870333796281004, 8.907115256017322, 8.94354568770392, 8.979633117966634, 9.015385285794299, 9.050809656479183, 9.085913434710271, 9.120703576881043, 9.155186802668162, 9.189369605932827, 9.22325826499222, 9.256858852304687, 9.29017724360873, 9.323219126552713, 9.355990008849341, 9.388495225986222, 9.42073994852154, 9.45272918899157, 9.484467808454834, 9.515960522695776, 9.547211908109253, 9.578226407285513, 9.609008334313963, 9.63956187982271, 9.66989111576968, 9.7, 9.729892380583346, 9.759571999943995, 9.789042498795496, 9.818307419891017], [0.0, 2.4766135972560908, 3.0490689942758924, 3.443456724681995, 3.7538442582059672, 4.013740163852075, 4.239392509187222, 4.440047998203738, 4.621524387057168, 4.787744938449338, 4.941493779344591, 5.084825559089098, 5.219304403662134, 5.3461514628636175, 5.466340287971811, 5.580660856281929, 5.68976393026272, 5.7941926302077515, 5.894405433492302, 5.990793270473339, 6.083692460018749, 6.173394652385309, 6.260154579905984, 6.344196175509836, 6.425717458115157, 6.504894473957555, 6.581884506400294, 6.656828712654769, 6.729854306978736, 6.801076381628802, 6.870599435984152, 6.938518668697501, 7.004921075994361, 7.0698863903030205, 7.133487886524559, 7.195793077921382, 7.256864319433967, 7.3167593329505936, 7.375531666447571, 7.433231096834129, 7.489903984660674, 7.545593587493688, 7.600340337657555, 7.654182089141375, 7.707154337726843, 7.759290417780303, 7.810621678643118, 7.861177643130216, 7.910986150291372, 7.960073484291108, 8.008464491011061, 8.056182683765112, 8.103250339336185, 8.149688585388779, 8.19551748017895, 8.24075608536971, 8.285422532662094, 8.329534084867559, 8.373107191974356, 8.416157542696983, 8.458700111942623, 8.500749204580305, 8.542318495856335, 8.583421068762682, 8.624069448632518, 8.664275635208583, 8.704051132404821, 8.743406975959509, 8.782353759158346, 8.820901656788486, 8.859060447468929, 8.896839534488873, 8.934247965273187, 8.971294449583255, 9.0079873765514, 9.044334830638388, 9.080344606595448, 9.116024223505152, 9.151380937969043, 9.18642175650409, 9.221153447204816, 9.255582550723187, 9.289715390614077, 9.323558083090235, 9.357116546227113, 9.39039650865478, 9.423403517771124, 9.456142947507995, 9.488620005679442, 9.52083974093899, 9.55280704937096, 9.584526680738838, 9.616003244412168, 9.647241214991768, 9.678244937651723, 9.709018633215226, 9.739566402980229, 9.769892233309653, 9.8, 9.829893472441155, 9.859576317579407, 9.889052103694823], [0.0, 2.494276736729109, 3.070814869760231, 3.468015362519059, 3.7806165713218047, 4.042366047357326, 4.269627738959684, 4.471714297357574, 4.654484970782052, 4.821891002535702, 4.976736375899144, 5.121090393920687, 5.256528337882702, 5.384280066791603, 5.505326075266365, 5.6204619746983555, 5.730343168776199, 5.8355166513123296, 5.936444169529947, 6.033519441890482, 6.127081185878656, 6.217423131792787, 6.3048018287097705, 6.389442806642109, 6.471545496773527, 6.551287200896499, 6.628826324114874, 6.704305030369364, 6.777851441206279, 6.849581469717009, 6.919600360567415, 6.9880039913643595, 7.054879978788022, 7.120308623916157, 7.184363724244407, 7.247113274537893, 7.308620074450795, 7.368942257542302, 7.428133753691404, 7.486244694814865, 7.5433217721052515, 7.59940855164081, 7.654545754108142, 7.708771503469944, 7.762121548662845, 7.814629461792963, 7.866326815784295, 7.917243344007665, 7.967407084060178, 8.016844507564292, 8.065580637601778, 8.113639155182822, 8.161042495967745, 8.207811938302966, 8.25396768349946, 8.299528929167497, 8.3445139363229, 8.388940090895016, 8.432823960192957, 8.476181344822695, 8.519027326492042, 8.561376312091951, 8.603242074400208, 8.644637789716315, 8.685576072703775, 8.726069008687158, 8.766128183626005, 8.805764711965173, 8.844989262541379, 8.883812082708078, 8.922243020825109, 8.960291547245665, 8.997966773920604, 9.03527747272908, 9.07223209263448, 9.10883877575572, 9.145105372435975, 9.181039455383706, 9.216648332954339, 9.251939061635127, 9.286918457790454, 9.321593108720036, 9.355969383078165, 9.390053440698248, 9.423851241863288, 9.457368556059784, 9.490610970249513, 9.52358389669106, 9.556292580340452, 9.58874210585808, 9.620937404246996, 9.652883259145868, 9.68458431279814, 9.716045071717355, 9.74726991206726, 9.778263084773844, 9.809028720385399, 9.839570833695477, 9.869893328142654, 9.899999999999999, 9.929894542366357, 9.959580548970676], [0.0, 2.51188643150958, 3.092494947109917, 3.4924996914343946, 3.8073078774317564, 4.0709053153690435, 4.299771483718299, 4.503284781403061, 4.687345823184199, 4.8559337483020375, 5.011872336272722, 5.157245499507891, 5.293639640839565, 5.4222933021285575, 5.544193900325561, 5.660142663870589, 5.770799623628853, 5.876715635211255, 5.978355705795092, 6.076116333510078, 6.1703386272000955, 6.261318390911263, 6.349313984967352, 6.434552531631885, 6.517234870080821, 6.59753955386447, 6.675626106433132, 6.751637695410694, 6.825703346886776, 6.897939792303886, 6.968453019359488, 7.037339582560231, 7.104687717163608, 7.170578291176232, 7.235085623107057, 7.298278187766995, 7.360219228178332, 7.420967288325536, 7.480576678834729, 7.539097885556037, 7.596577929323737, 7.653060683794353, 7.708587157144182, 7.763195742492642, 7.816922441165302, 7.869801062288709, 7.921863401692982, 7.973139402667749, 8.023657300756684, 8.07344375447297, 8.122523963562355, 8.170921776223908, 8.218659786514626, 8.265759423006912, 8.312241029633821, 8.358123939541523, 8.403426542669353, 8.448166347692023, 8.49236003888452, 8.536023528405737, 8.579172004440947, 8.621819975594343, 8.663981311880073, 8.705669282622855, 8.746896591546223, 8.787675409297629, 8.828017403633956, 8.867933767468491, 8.907435244960377, 8.946532155809791, 8.985234417906396, 9.02355156846446, 9.061492783765585, 9.099066897618748, 9.136282418637355, 9.173147546424016, 9.209670186745644, 9.245857965774332, 9.281718243462786, 9.317258126117348, 9.352484478226211, 9.387403933595692, 9.422022905843042, 9.456347598290339, 9.49038401330043, 9.524137961092617, 9.557615068072856, 9.590820784710495, 9.623760392991167, 9.656439013473168, 9.688861611972632, 9.72103300590091, 9.752957870275871, 9.784640743427229, 9.816086032414622, 9.84729801817575, 9.878280860420741, 9.909038602287756, 9.939575174773804, 9.969894400953793, 9.999999999999998, 10.029895591013236], [0.0, 2.5294433753605836, 3.11411008044749, 3.5169106760286746, 3.833919228084015, 4.099359092238936, 4.3298249310257955, 4.534760694111685, 4.72010823887129, 4.889874516918672, 5.046903044704654, 5.193292300240949, 5.330639774593945, 5.46019266646882, 5.582945294411715, 5.699704487085074, 5.811134888669699, 5.917791205006706, 6.0201416934620955, 6.118585623507194, 6.213466488181583, 6.305082159067142, 6.393692802308815, 6.479527127651459, 6.56278737804554, 6.643653355049486, 6.722285697109969, 6.798828572527461, 6.873411909225272, 6.9461532545456075, 7.01715933699174, 7.086527385942409, 7.1543462533794315, 7.220697372540013, 7.285655581385686, 7.349289833335152, 7.411663813450661, 7.472836474912512, 7.5328625079534035, 7.591792751296595, 7.649674554430612, 7.706552097668885, 7.762466675816214, 7.817456950342466, 7.871559174206099, 7.924807392844081, 7.977233624324925, 8.028868021228236, 8.079739016451297, 8.129873454838178, 8.179296712269384, 8.228032803632058, 8.276104480905374, 8.323533322437717, 8.370339814356974, 8.416543424939224, 8.462162672661108, 8.50721518857502, 8.551717773571433, 8.595686451027998, 8.639136515288497, 8.682082576365667, 8.72453860121875, 8.766517951919006, 8.808033420983222, 8.849097264126137, 8.889721230656953, 8.929916591722332, 8.969694166578195, 9.00906434705474, 9.048037120363162, 9.086622090378524, 9.12482849752046, 9.162665237342255, 9.200140877928657, 9.237263676193763, 9.274041593162208, 9.310482308309554, 9.346593233031234, 9.382381523303438, 9.417854091594009, 9.453017618076554, 9.487878561196592, 9.522443167634602, 9.556717481707215, 9.590707354244529, 9.624418450978514, 9.657856260474821, 9.691026101637762, 9.723933130816004, 9.756582348534481, 9.788978605876059, 9.82112661053485, 9.853030932561436, 9.884696009818795, 9.916126153166433, 9.947325551388962, 9.978298275884242, 10.009048285125157, 10.039579428908175, 10.069895452400894, 10.1]]}, {\"colorscale\": [[0.0, \"#440154\"], [0.1111111111111111, \"#482878\"], [0.2222222222222222, \"#3e4989\"], [0.3333333333333333, \"#31688e\"], [0.4444444444444444, \"#26828e\"], [0.5555555555555556, \"#1f9e89\"], [0.6666666666666666, \"#35b779\"], [0.7777777777777778, \"#6ece58\"], [0.8888888888888888, \"#b5de2b\"], [1.0, \"#fde725\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha = 0.5\", \"showscale\": false, \"type\": \"surface\", \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.1, 0.1414213562373095, 0.17320508075688776, 0.2, 0.223606797749979, 0.24494897427831783, 0.2645751311064591, 0.282842712474619, 0.3, 0.31622776601683794, 0.33166247903554, 0.3464101615137755, 0.36055512754639896, 0.37416573867739417, 0.38729833462074165, 0.4, 0.41231056256176607, 0.4242640687119285, 0.43588989435406744, 0.447213595499958, 0.45825756949558405, 0.469041575982343, 0.479583152331272, 0.48989794855663565, 0.5, 0.5099019513592785, 0.5196152422706632, 0.5291502622129182, 0.5385164807134505, 0.5477225575051661, 0.5567764362830022, 0.565685424949238, 0.574456264653803, 0.5830951894845301, 0.5916079783099616, 0.6, 0.608276253029822, 0.6164414002968976, 0.6244997998398399, 0.6324555320336759, 0.6403124237432849, 0.6480740698407861, 0.6557438524302001, 0.66332495807108, 0.6708203932499369, 0.6782329983125268, 0.6855654600401044, 0.692820323027551, 0.7000000000000001, 0.7071067811865476, 0.7141428428542851, 0.7211102550927979, 0.7280109889280519, 0.7348469228349535, 0.7416198487095663, 0.7483314773547883, 0.754983443527075, 0.7615773105863909, 0.7681145747868608, 0.7745966692414833, 0.7810249675906654, 0.787400787401181, 0.7937253933193772, 0.8, 0.8062257748298549, 0.812403840463596, 0.8185352771872451, 0.8246211251235321, 0.8306623862918076, 0.8366600265340756, 0.8426149773176359, 0.848528137423857, 0.8544003745317531, 0.8602325267042626, 0.8660254037844387, 0.8717797887081349, 0.8774964387392122, 0.8831760866327848, 0.8888194417315589, 0.894427190999916, 0.9, 0.9055385138137417, 0.9110433579144299, 0.9165151389911681, 0.9219544457292888, 0.9273618495495705, 0.9327379053088816, 0.938083151964686, 0.9433981132056604, 0.9486832980505138, 0.9539392014169457, 0.959166304662544, 0.9643650760992956, 0.9695359714832659, 0.9746794344808963, 0.9797958971132713, 0.9848857801796106, 0.9899494936611666, 0.9949874371066201, 1.0, 1.0049875621120892], [0.0, 0.1414213562373095, 0.19999999999999998, 0.24494897427831783, 0.282842712474619, 0.31622776601683794, 0.34641016151377546, 0.3741657386773941, 0.39999999999999997, 0.4242640687119285, 0.4472135954999579, 0.469041575982343, 0.48989794855663565, 0.5099019513592785, 0.529150262212918, 0.5477225575051661, 0.565685424949238, 0.58309518948453, 0.6, 0.6164414002968976, 0.6324555320336759, 0.6480740698407861, 0.6633249580710799, 0.6782329983125268, 0.6928203230275509, 0.7071067811865476, 0.7211102550927979, 0.7348469228349535, 0.7483314773547882, 0.7615773105863909, 0.7745966692414833, 0.7874007874011811, 0.7999999999999999, 0.812403840463596, 0.8246211251235321, 0.8366600265340756, 0.848528137423857, 0.8602325267042626, 0.8717797887081348, 0.8831760866327847, 0.8944271909999159, 0.9055385138137417, 0.9165151389911681, 0.9273618495495702, 0.938083151964686, 0.9486832980505137, 0.9591663046625439, 0.9695359714832658, 0.9797958971132713, 0.9899494936611665, 1.0, 1.0099504938362078, 1.019803902718557, 1.0295630140987002, 1.0392304845413265, 1.0488088481701516, 1.058300524425836, 1.0677078252031311, 1.0770329614269007, 1.0862780491200215, 1.0954451150103321, 1.104536101718726, 1.1135528725660042, 1.1224972160321824, 1.131370849898476, 1.1401754250991378, 1.1489125293076057, 1.1575836902790224, 1.16619037896906, 1.174734012447073, 1.1832159566199232, 1.1916375287812984, 1.2, 1.2083045973594573, 1.2165525060596438, 1.224744871391589, 1.2328828005937953, 1.2409673645990857, 1.2489995996796797, 1.2569805089976536, 1.2649110640673518, 1.2727922061357855, 1.2806248474865698, 1.2884098726725124, 1.2961481396815722, 1.3038404810405297, 1.3114877048604001, 1.3190905958272918, 1.3266499161421599, 1.3341664064126333, 1.3416407864998738, 1.349073756323204, 1.3564659966250536, 1.3638181696985856, 1.3711309200802089, 1.378404875209022, 1.3856406460551018, 1.392838827718412, 1.4, 1.407124727947029, 1.4142135623730951, 1.4212670403551897], [0.0, 0.17320508075688776, 0.24494897427831783, 0.3000000000000001, 0.3464101615137755, 0.38729833462074176, 0.42426406871192857, 0.45825756949558405, 0.48989794855663565, 0.5196152422706632, 0.5477225575051662, 0.574456264653803, 0.6000000000000002, 0.6244997998398399, 0.6480740698407861, 0.6708203932499369, 0.692820323027551, 0.7141428428542851, 0.7348469228349536, 0.7549834435270751, 0.7745966692414835, 0.7937253933193773, 0.8124038404635961, 0.8306623862918077, 0.8485281374238571, 0.8660254037844388, 0.8831760866327849, 0.9000000000000001, 0.9165151389911681, 0.9327379053088817, 0.9486832980505139, 0.9643650760992957, 0.9797958971132713, 0.9949874371066202, 1.009950493836208, 1.02469507659596, 1.0392304845413265, 1.053565375285274, 1.0677078252031313, 1.081665382639197, 1.0954451150103324, 1.1090536506409419, 1.1224972160321827, 1.1357816691600549, 1.148912529307606, 1.161895003862225, 1.1747340124470733, 1.187434208703792, 1.2000000000000004, 1.2124355652982142, 1.2247448713915892, 1.2369316876852985, 1.2489995996796799, 1.2609520212918495, 1.2727922061357857, 1.2845232578665131, 1.2961481396815722, 1.3076696830622023, 1.3190905958272923, 1.3304134695650072, 1.3416407864998738, 1.3527749258468684, 1.3638181696985856, 1.3747727084867523, 1.385640646055102, 1.3964240043768943, 1.4071247279470291, 1.4177446878757827, 1.4282856857085702, 1.4387494569938162, 1.4491376746189442, 1.4594519519326425, 1.4696938456699071, 1.4798648586948744, 1.489966442575134, 1.5000000000000002, 1.5099668870541503, 1.5198684153570665, 1.5297058540778359, 1.5394804318340656, 1.549193338482967, 1.5588457268119897, 1.5684387141358125, 1.5779733838059502, 1.5874507866387546, 1.5968719422671316, 1.6062378404209012, 1.6155494421403516, 1.6248076809271923, 1.6340134638368193, 1.6431676725154984, 1.6522711641858308, 1.6613247725836153, 1.670329308849007, 1.6792855623746668, 1.6881943016134133, 1.6970562748477143, 1.7058722109231985, 1.7146428199482249, 1.7233687939614089, 1.7320508075688776, 1.7406895185529214], [0.0, 0.2, 0.282842712474619, 0.3464101615137755, 0.4, 0.447213595499958, 0.48989794855663565, 0.5291502622129182, 0.565685424949238, 0.6, 0.6324555320336759, 0.66332495807108, 0.692820323027551, 0.7211102550927979, 0.7483314773547883, 0.7745966692414833, 0.8, 0.8246211251235321, 0.848528137423857, 0.8717797887081349, 0.894427190999916, 0.9165151389911681, 0.938083151964686, 0.959166304662544, 0.9797958971132713, 1.0, 1.019803902718557, 1.0392304845413265, 1.0583005244258363, 1.077032961426901, 1.0954451150103321, 1.1135528725660044, 1.131370849898476, 1.148912529307606, 1.1661903789690602, 1.1832159566199232, 1.2, 1.216552506059644, 1.2328828005937953, 1.2489995996796799, 1.2649110640673518, 1.2806248474865698, 1.2961481396815722, 1.3114877048604001, 1.32664991614216, 1.3416407864998738, 1.3564659966250536, 1.3711309200802089, 1.385640646055102, 1.4000000000000001, 1.4142135623730951, 1.4282856857085702, 1.4422205101855958, 1.4560219778561039, 1.469693845669907, 1.4832396974191326, 1.4966629547095767, 1.50996688705415, 1.5231546211727818, 1.5362291495737217, 1.5491933384829666, 1.5620499351813308, 1.574801574802362, 1.5874507866387544, 1.6, 1.6124515496597098, 1.624807680927192, 1.6370705543744901, 1.6492422502470643, 1.661324772583615, 1.6733200530681511, 1.6852299546352718, 1.697056274847714, 1.7088007490635062, 1.7204650534085253, 1.7320508075688774, 1.7435595774162698, 1.7549928774784245, 1.7663521732655696, 1.7776388834631178, 1.788854381999832, 1.8, 1.8110770276274835, 1.8220867158288598, 1.8330302779823362, 1.8439088914585775, 1.854723699099141, 1.8654758106177631, 1.876166303929372, 1.8867962264113207, 1.8973665961010275, 1.9078784028338913, 1.918332609325088, 1.9287301521985911, 1.9390719429665317, 1.9493588689617927, 1.9595917942265426, 1.9697715603592212, 1.9798989873223332, 1.9899748742132402, 2.0, 2.0099751242241783], [0.0, 0.223606797749979, 0.31622776601683794, 0.38729833462074176, 0.447213595499958, 0.5000000000000001, 0.5477225575051662, 0.5916079783099617, 0.6324555320336759, 0.6708203932499369, 0.7071067811865476, 0.7416198487095664, 0.7745966692414835, 0.806225774829855, 0.8366600265340756, 0.8660254037844386, 0.894427190999916, 0.9219544457292888, 0.9486832980505139, 0.9746794344808966, 1.0000000000000002, 1.02469507659596, 1.0488088481701516, 1.072380529476361, 1.0954451150103324, 1.118033988749895, 1.140175425099138, 1.1618950038622253, 1.1832159566199234, 1.2041594578792296, 1.2247448713915892, 1.2449899597988734, 1.2649110640673518, 1.2845232578665131, 1.30384048104053, 1.3228756555322954, 1.3416407864998738, 1.3601470508735445, 1.3784048752090223, 1.3964240043768943, 1.4142135623730951, 1.4317821063276355, 1.4491376746189442, 1.466287829861518, 1.4832396974191329, 1.5, 1.5165750888103102, 1.5329709716755893, 1.549193338482967, 1.565247584249853, 1.5811388300841898, 1.5968719422671316, 1.61245154965971, 1.627882059609971, 1.6431676725154984, 1.6583123951777001, 1.6733200530681511, 1.6881943016134133, 1.7029386365926404, 1.7175564037317668, 1.7320508075688772, 1.746424919657298, 1.760681686165901, 1.7748239349298849, 1.788854381999832, 1.8027756377319946, 1.8165902124584952, 1.8303005217723127, 1.8439088914585775, 1.8574175621006712, 1.8708286933869709, 1.8841443681416774, 1.8973665961010278, 1.91049731745428, 1.9235384061671346, 1.9364916731037085, 1.9493588689617931, 1.9621416870348585, 1.9748417658131503, 1.9874606914351793, 2.0000000000000004, 2.012461179749811, 2.024845673131659, 2.0371548787463363, 2.04939015319192, 2.0615528128088303, 2.0736441353327724, 2.0856653614614213, 2.0976176963403033, 2.1095023109728985, 2.121320343559643, 2.1330729007701543, 2.144761058952722, 2.1563858652847827, 2.1679483388678804, 2.179449471770337, 2.1908902300206647, 2.2022715545545246, 2.2135943621178655, 2.224859546128699, 2.23606797749979, 2.2472205054244236], [0.0, 0.24494897427831783, 0.34641016151377546, 0.42426406871192857, 0.48989794855663565, 0.5477225575051662, 0.6000000000000001, 0.6480740698407861, 0.6928203230275509, 0.7348469228349535, 0.7745966692414834, 0.8124038404635961, 0.8485281374238571, 0.8831760866327848, 0.916515138991168, 0.9486832980505138, 0.9797958971132713, 1.0099504938362078, 1.0392304845413265, 1.0677078252031313, 1.0954451150103324, 1.1224972160321824, 1.148912529307606, 1.174734012447073, 1.2000000000000002, 1.2247448713915892, 1.2489995996796799, 1.2727922061357857, 1.2961481396815722, 1.319090595827292, 1.3416407864998738, 1.3638181696985856, 1.3856406460551018, 1.4071247279470291, 1.4282856857085702, 1.449137674618944, 1.469693845669907, 1.489966442575134, 1.50996688705415, 1.5297058540778357, 1.5491933384829668, 1.5684387141358125, 1.5874507866387546, 1.606237840420901, 1.6248076809271923, 1.6431676725154982, 1.661324772583615, 1.6792855623746665, 1.6970562748477143, 1.7146428199482247, 1.7320508075688774, 1.7492855684535904, 1.7663521732655696, 1.7832554500127011, 1.8, 1.8165902124584952, 1.833030277982336, 1.849324200890693, 1.8654758106177631, 1.8814887722226779, 1.8973665961010275, 1.9131126469708992, 1.928730152198591, 1.9442222095223582, 1.9595917942265426, 1.9748417658131499, 1.98997487421324, 2.004993765576342, 2.0199009876724157, 2.0346989949375804, 2.04939015319192, 2.0639767440550294, 2.078460969082653, 2.092844953645635, 2.1071307505705477, 2.121320343559643, 2.1354156504062627, 2.149418526020468, 2.1633307652783937, 2.177154105707724, 2.1908902300206647, 2.2045407685048604, 2.2181073012818837, 2.2315913604421396, 2.244994432064365, 2.2583179581272432, 2.2715633383201097, 2.2847319317591728, 2.297825058615212, 2.3108440016582685, 2.32379000772445, 2.3366642891095846, 2.349468024894146, 2.3622023622035435, 2.374868417407584, 2.3874672772626644, 2.4000000000000004, 2.412467616362964, 2.4248711305964283, 2.4372115213907883, 2.4494897427831783, 2.4617067250182347], [0.0, 0.2645751311064591, 0.3741657386773941, 0.45825756949558405, 0.5291502622129182, 0.5916079783099617, 0.6480740698407861, 0.7000000000000001, 0.7483314773547882, 0.7937253933193772, 0.8366600265340756, 0.8774964387392122, 0.9165151389911681, 0.9539392014169458, 0.9899494936611666, 1.0246950765959597, 1.0583005244258363, 1.0908712114635715, 1.1224972160321824, 1.1532562594670797, 1.1832159566199234, 1.2124355652982142, 1.2409673645990857, 1.2688577540449522, 1.2961481396815722, 1.3228756555322954, 1.3490737563232043, 1.374772708486752, 1.4000000000000001, 1.4247806848775009, 1.4491376746189437, 1.4730919862656235, 1.4966629547095764, 1.5198684153570665, 1.5427248620541514, 1.5652475842498528, 1.5874507866387544, 1.6093476939431082, 1.6309506430300091, 1.6522711641858308, 1.6733200530681511, 1.6941074346097418, 1.7146428199482249, 1.7349351572897471, 1.7549928774784245, 1.7748239349298847, 1.7944358444926363, 1.8138357147217055, 1.8330302779823362, 1.8520259177452134, 1.8708286933869709, 1.8894443627691186, 1.9078784028338915, 1.9261360284258224, 1.9442222095223582, 1.9621416870348585, 1.9798989873223332, 1.997498435543818, 2.0149441679609885, 2.0322401432901573, 2.0493901531919194, 2.0663978319771825, 2.083266665599966, 2.1, 2.1166010488516727, 2.133072900770154, 2.149418526020468, 2.1656407827707715, 2.181742422927143, 2.1977260975835913, 2.2135943621178655, 2.2293496809607953, 2.244994432064365, 2.260530911091463, 2.2759613353482084, 2.29128784747792, 2.3065125189341593, 2.32163735324878, 2.336664289109585, 2.3515952032609695, 2.366431913239847, 2.3811761799581315, 2.395829710142188, 2.41039415863879, 2.4248711305964283, 2.4392621835300936, 2.4535688292770597, 2.4677925358506134, 2.4819347291981715, 2.495996794869737, 2.5099800796022267, 2.5238858928247927, 2.5377155080899043, 2.551470164434615, 2.5651510676761324, 2.578759391645525, 2.5922962793631443, 2.6057628441590768, 2.619160170741759, 2.632489316217637, 2.6457513110645907, 2.6589471600616665], [0.0, 0.282842712474619, 0.39999999999999997, 0.48989794855663565, 0.565685424949238, 0.6324555320336759, 0.6928203230275509, 0.7483314773547882, 0.7999999999999999, 0.848528137423857, 0.8944271909999159, 0.938083151964686, 0.9797958971132713, 1.019803902718557, 1.058300524425836, 1.0954451150103321, 1.131370849898476, 1.16619037896906, 1.2, 1.2328828005937953, 1.2649110640673518, 1.2961481396815722, 1.3266499161421599, 1.3564659966250536, 1.3856406460551018, 1.4142135623730951, 1.4422205101855958, 1.469693845669907, 1.4966629547095764, 1.5231546211727818, 1.5491933384829666, 1.5748015748023623, 1.5999999999999999, 1.624807680927192, 1.6492422502470643, 1.6733200530681511, 1.697056274847714, 1.7204650534085253, 1.7435595774162695, 1.7663521732655694, 1.7888543819998317, 1.8110770276274835, 1.8330302779823362, 1.8547236990991405, 1.876166303929372, 1.8973665961010273, 1.9183326093250879, 1.9390719429665315, 1.9595917942265426, 1.979898987322333, 2.0, 2.0199009876724157, 2.039607805437114, 2.0591260281974004, 2.078460969082653, 2.0976176963403033, 2.116601048851672, 2.1354156504062622, 2.1540659228538015, 2.172556098240043, 2.1908902300206643, 2.209072203437452, 2.2271057451320084, 2.244994432064365, 2.262741699796952, 2.2803508501982757, 2.2978250586152114, 2.315167380558045, 2.33238075793812, 2.349468024894146, 2.3664319132398464, 2.3832750575625967, 2.4, 2.4166091947189146, 2.4331050121192876, 2.449489742783178, 2.4657656011875906, 2.4819347291981715, 2.4979991993593593, 2.513961017995307, 2.5298221281347035, 2.545584412271571, 2.5612496949731396, 2.576819745345025, 2.5922962793631443, 2.6076809620810595, 2.6229754097208002, 2.6381811916545836, 2.6532998322843198, 2.6683328128252666, 2.6832815729997477, 2.698147512646408, 2.7129319932501073, 2.727636339397171, 2.7422618401604177, 2.756809750418044, 2.7712812921102037, 2.785677655436824, 2.8, 2.814249455894058, 2.8284271247461903, 2.8425340807103794], [0.0, 0.3, 0.4242640687119285, 0.5196152422706632, 0.6, 0.6708203932499369, 0.7348469228349535, 0.7937253933193772, 0.848528137423857, 0.8999999999999999, 0.9486832980505138, 0.99498743710662, 1.0392304845413265, 1.0816653826391969, 1.1224972160321824, 1.1618950038622249, 1.2, 1.236931687685298, 1.2727922061357855, 1.307669683062202, 1.3416407864998738, 1.374772708486752, 1.407124727947029, 1.438749456993816, 1.469693845669907, 1.5, 1.5297058540778354, 1.5588457268119895, 1.5874507866387544, 1.6155494421403513, 1.6431676725154982, 1.6703293088490065, 1.697056274847714, 1.7233687939614086, 1.7492855684535902, 1.7748239349298847, 1.7999999999999998, 1.8248287590894658, 1.849324200890693, 1.8734993995195195, 1.8973665961010275, 1.9209372712298547, 1.9442222095223582, 1.9672315572906, 1.98997487421324, 2.0124611797498106, 2.0346989949375804, 2.056696380120313, 2.078460969082653, 2.1, 2.1213203435596424, 2.142428528562855, 2.1633307652783937, 2.1840329667841556, 2.2045407685048604, 2.224859546128699, 2.244994432064365, 2.264950330581225, 2.2847319317591723, 2.3043437243605824, 2.3237900077244498, 2.3430749027719964, 2.362202362203543, 2.3811761799581315, 2.4, 2.4186773244895647, 2.437211521390788, 2.455605831561735, 2.473863375370596, 2.4919871588754225, 2.5099800796022267, 2.5278449319529073, 2.545584412271571, 2.563201123595259, 2.580697580112788, 2.598076211353316, 2.615339366124404, 2.6324893162176366, 2.6495282598983545, 2.6664583251946765, 2.6832815729997477, 2.7, 2.716615541441225, 2.7331300737432893, 2.749545416973504, 2.765863337187866, 2.7820855486487113, 2.7982137159266447, 2.814249455894058, 2.830194339616981, 2.846049894151541, 2.8618176042508368, 2.877498913987632, 2.8930952282978866, 2.9086079144497976, 2.9240383034426887, 2.939387691339814, 2.9546573405388314, 2.9698484809834995, 2.98496231131986, 3.0, 3.0149626863362675], [0.0, 0.31622776601683794, 0.4472135954999579, 0.5477225575051662, 0.6324555320336759, 0.7071067811865476, 0.7745966692414834, 0.8366600265340756, 0.8944271909999159, 0.9486832980505138, 1.0, 1.0488088481701516, 1.0954451150103324, 1.140175425099138, 1.1832159566199232, 1.224744871391589, 1.2649110640673518, 1.3038404810405297, 1.3416407864998738, 1.3784048752090223, 1.4142135623730951, 1.449137674618944, 1.4832396974191326, 1.5165750888103102, 1.5491933384829668, 1.5811388300841898, 1.61245154965971, 1.6431676725154984, 1.6733200530681511, 1.7029386365926402, 1.7320508075688772, 1.760681686165901, 1.7888543819998317, 1.8165902124584952, 1.8439088914585775, 1.8708286933869707, 1.8973665961010275, 1.9235384061671346, 1.949358868961793, 1.97484176581315, 2.0, 2.024845673131659, 2.04939015319192, 2.073644135332772, 2.0976176963403033, 2.1213203435596424, 2.1447610589527217, 2.16794833886788, 2.1908902300206647, 2.2135943621178655, 2.23606797749979, 2.2583179581272432, 2.280350850198276, 2.302172886644268, 2.32379000772445, 2.345207879911715, 2.3664319132398464, 2.3874672772626644, 2.4083189157584592, 2.4289915602982237, 2.449489742783178, 2.4698178070456938, 2.4899799195977463, 2.5099800796022267, 2.5298221281347035, 2.5495097567963922, 2.569046515733026, 2.588435821108957, 2.6076809620810595, 2.6267851073127395, 2.6457513110645907, 2.6645825188948455, 2.6832815729997477, 2.701851217221259, 2.7202941017470885, 2.7386127875258306, 2.7568097504180447, 2.7748873851023217, 2.7928480087537886, 2.8106938645110393, 2.8284271247461903, 2.8460498941515415, 2.863564212655271, 2.8809720581775866, 2.898275349237888, 2.9154759474226504, 2.932575659723036, 2.9495762407505253, 2.9664793948382653, 2.9832867780352594, 3.0, 3.0166206257996713, 3.0331501776206204, 3.0495901363953815, 3.0659419433511785, 3.082207001484488, 3.0983866769659336, 3.1144823004794877, 3.1304951684997055, 3.146426544510455, 3.1622776601683795, 3.178049716414141], [0.0, 0.33166247903554, 0.469041575982343, 0.574456264653803, 0.66332495807108, 0.7416198487095664, 0.8124038404635961, 0.8774964387392122, 0.938083151964686, 0.99498743710662, 1.0488088481701516, 1.1, 1.148912529307606, 1.1958260743101399, 1.2409673645990857, 1.284523257866513, 1.32664991614216, 1.3674794331177345, 1.407124727947029, 1.4456832294800963, 1.4832396974191329, 1.5198684153570665, 1.5556349186104048, 1.5905973720586868, 1.6248076809271923, 1.6583123951777001, 1.6911534525287766, 1.7233687939614089, 1.7549928774784245, 1.7860571099491753, 1.816590212458495, 1.846618531261939, 1.876166303929372, 1.9052558883257653, 1.9339079605813718, 1.9621416870348585, 1.98997487421324, 2.017424100183202, 2.0445048300260877, 2.0712315177207983, 2.0976176963403033, 2.1236760581595306, 2.149418526020468, 2.1748563170931545, 2.2, 2.224859546128699, 2.249444375840399, 2.273763400180415, 2.297825058615212, 2.32163735324878, 2.345207879911715, 2.368543856465403, 2.3916521486202797, 2.4145392935299275, 2.4372115213907883, 2.459674775249769, 2.4819347291981715, 2.503996805109783, 2.525866188063018, 2.5475478405713994, 2.569046515733026, 2.5903667693977237, 2.6115129714401193, 2.632489316217637, 2.65329983228432, 2.6739483914241875, 2.6944387170614963, 2.714774392099646, 2.734958866235469, 2.7549954627911823, 2.774887385102322, 2.7946377224964243, 2.814249455894058, 2.833725463060951, 2.8530685235374214, 2.8722813232690148, 2.8913664589601926, 2.91032644217105, 2.9291637031753623, 2.9478805945967355, 2.9664793948382657, 2.9849623113198605, 3.003331483536242, 3.0215889859476257, 3.039736830714133, 3.0577769702841313, 3.07571129984594, 3.093541659651604, 3.1112698372208096, 3.1288975694324033, 3.146426544510455, 3.1638584039112754, 3.1811947441173736, 3.1984371183438958, 3.2155870381627056, 3.2326459750489227, 3.2496153618543846, 3.2664965942122155, 3.283291031876401, 3.3000000000000007, 3.3166247903554003, 3.333166662499792], [0.0, 0.3464101615137755, 0.48989794855663565, 0.6000000000000002, 0.692820323027551, 0.7745966692414835, 0.8485281374238571, 0.9165151389911681, 0.9797958971132713, 1.0392304845413265, 1.0954451150103324, 1.148912529307606, 1.2000000000000004, 1.2489995996796799, 1.2961481396815722, 1.3416407864998738, 1.385640646055102, 1.4282856857085702, 1.4696938456699071, 1.5099668870541503, 1.549193338482967, 1.5874507866387546, 1.6248076809271923, 1.6613247725836153, 1.6970562748477143, 1.7320508075688776, 1.7663521732655698, 1.8000000000000003, 1.8330302779823362, 1.8654758106177634, 1.8973665961010278, 1.9287301521985913, 1.9595917942265426, 1.9899748742132404, 2.019900987672416, 2.04939015319192, 2.078460969082653, 2.107130750570548, 2.1354156504062627, 2.163330765278394, 2.1908902300206647, 2.2181073012818837, 2.2449944320643653, 2.2715633383201097, 2.297825058615212, 2.32379000772445, 2.3494680248941466, 2.374868417407584, 2.400000000000001, 2.4248711305964283, 2.4494897427831783, 2.473863375370597, 2.4979991993593598, 2.521904042583699, 2.5455844122715714, 2.5690465157330262, 2.5922962793631443, 2.6153393661244047, 2.6381811916545845, 2.6608269391300143, 2.6832815729997477, 2.705549851693737, 2.727636339397171, 2.7495454169735045, 2.771281292110204, 2.7928480087537886, 2.8142494558940583, 2.8354893757515653, 2.8565713714171403, 2.8774989139876324, 2.8982753492378883, 2.918903903865285, 2.9393876913398143, 2.9597297173897488, 2.979932885150268, 3.0000000000000004, 3.0199337741083006, 3.039736830714133, 3.0594117081556718, 3.078960863668131, 3.098386676965934, 3.1176914536239795, 3.136877428271625, 3.1559467676119004, 3.174901573277509, 3.193743884534263, 3.2124756808418025, 3.231098884280703, 3.2496153618543846, 3.2680269276736387, 3.286335345030997, 3.3045423283716615, 3.3226495451672307, 3.340658617698014, 3.3585711247493335, 3.3763886032268267, 3.3941125496954285, 3.411744421846397, 3.4292856398964497, 3.4467375879228177, 3.4641016151377553, 3.481379037105843], [0.0, 0.36055512754639896, 0.5099019513592785, 0.6244997998398399, 0.7211102550927979, 0.806225774829855, 0.8831760866327848, 0.9539392014169458, 1.019803902718557, 1.0816653826391969, 1.140175425099138, 1.1958260743101399, 1.2489995996796799, 1.3000000000000003, 1.3490737563232043, 1.396424004376894, 1.4422205101855958, 1.4866068747318506, 1.5297058540778357, 1.5716233645501714, 1.61245154965971, 1.6522711641858308, 1.6911534525287764, 1.7291616465790585, 1.7663521732655696, 1.8027756377319948, 1.8384776310850237, 1.8734993995195197, 1.9078784028338915, 1.94164878389476, 1.9748417658131499, 2.0074859899884734, 2.039607805437114, 2.0712315177207983, 2.102379604162864, 2.1330729007701543, 2.1633307652783937, 2.193171219946131, 2.222611077089287, 2.2516660498395407, 2.280350850198276, 2.3086792761230397, 2.336664289109585, 2.364318083507378, 2.3916521486202797, 2.4186773244895647, 2.445403852127497, 2.471841418861655, 2.4979991993593598, 2.5238858928247927, 2.5495097567963927, 2.574878637916747, 2.6000000000000005, 2.624880949681338, 2.6495282598983545, 2.673948391424188, 2.6981475126464085, 2.72213151776324, 2.7459060435491964, 2.7694764848252458, 2.792848008753788, 2.816025568065745, 2.839013913315678, 2.861817604250837, 2.8844410203711917, 2.9068883707497264, 2.9291637031753623, 2.951270912674741, 2.973213749463701, 2.994995826374388, 3.0166206257996717, 3.0380915061926625, 3.0594117081556713, 3.0805843601498726, 3.1016124838541645, 3.122498999199199, 3.1432467291003428, 3.1638584039112754, 3.1843366656181322, 3.204684071792413, 3.22490309931942, 3.2449961479175906, 3.264965543462902, 3.2848135411313684, 3.3045423283716615, 3.3241540277189325, 3.343650699460098, 3.363034344160048, 3.3823069050575527, 3.4014702703389896, 3.420526275297414, 3.439476704383968, 3.458323293158117, 3.4770677301427426, 3.4957116585897072, 3.5142566781611158, 3.532704346531139, 3.5510561809129415, 3.5693136595149495, 3.58747822293042, 3.6055512754639896, 3.6235341863986883], [0.0, 0.37416573867739417, 0.529150262212918, 0.6480740698407861, 0.7483314773547883, 0.8366600265340756, 0.916515138991168, 0.9899494936611666, 1.058300524425836, 1.1224972160321824, 1.1832159566199232, 1.2409673645990857, 1.2961481396815722, 1.3490737563232043, 1.4, 1.4491376746189437, 1.4966629547095767, 1.5427248620541512, 1.5874507866387544, 1.6309506430300091, 1.6733200530681511, 1.7146428199482247, 1.7549928774784245, 1.7944358444926363, 1.833030277982336, 1.8708286933869707, 1.9078784028338913, 1.9442222095223582, 1.9798989873223332, 2.0149441679609885, 2.0493901531919194, 2.083266665599966, 2.116601048851672, 2.149418526020468, 2.181742422927143, 2.2135943621178655, 2.244994432064365, 2.2759613353482084, 2.3065125189341593, 2.3366642891095846, 2.3664319132398464, 2.395829710142188, 2.4248711305964283, 2.453568829277059, 2.4819347291981715, 2.5099800796022262, 2.5377155080899043, 2.565151067676132, 2.5922962793631443, 2.619160170741759, 2.6457513110645907, 2.672077843177478, 2.6981475126464085, 2.7239676943752476, 2.749545416973504, 2.7748873851023217, 2.8, 2.824889378365107, 2.8495613697550017, 2.8740215726399825, 2.8982753492378874, 2.9223278392404914, 2.9461839725312466, 2.9698484809834995, 2.9933259094191533, 3.016620625799671, 3.0397368307141326, 3.062678566222711, 3.0854497241083023, 3.1080540535840107, 3.1304951684997055, 3.152776554086889, 3.1749015732775088, 3.196873472629156, 3.218695387886216, 3.24037034920393, 3.2619012860600183, 3.283291031876401, 3.3045423283716615, 3.3256578296631782, 3.3466401061363023, 3.3674916480965473, 3.3882148692194836, 3.408812109811862, 3.4292856398964493, 3.449637662132068, 3.4698703145794947, 3.4899856733230297, 3.509985754956849, 3.529872518944558, 3.5496478698597693, 3.5693136595149495, 3.5888716889852725, 3.6083237105337433, 3.627671429443411, 3.6469165057620936, 3.666060555964672, 3.685105154537656, 3.704051835490427, 3.722902093797257, 3.7416573867739413, 3.7603191353926335], [0.0, 0.38729833462074165, 0.5477225575051661, 0.6708203932499369, 0.7745966692414833, 0.8660254037844386, 0.9486832980505138, 1.0246950765959597, 1.0954451150103321, 1.1618950038622249, 1.224744871391589, 1.284523257866513, 1.3416407864998738, 1.396424004376894, 1.4491376746189437, 1.4999999999999998, 1.5491933384829666, 1.5968719422671311, 1.6431676725154982, 1.6881943016134133, 1.7320508075688772, 1.7748239349298847, 1.816590212458495, 1.857417562100671, 1.8973665961010275, 1.9364916731037083, 1.9748417658131499, 2.0124611797498106, 2.0493901531919194, 2.085665361461421, 2.1213203435596424, 2.1563858652847823, 2.1908902300206643, 2.224859546128699, 2.258317958127243, 2.29128784747792, 2.3237900077244498, 2.355843797877949, 2.3874672772626644, 2.4186773244895647, 2.449489742783178, 2.479919353527449, 2.5099800796022267, 2.5396850198400585, 2.569046515733026, 2.5980762113533156, 2.626785107312739, 2.6551836094703507, 2.6832815729997477, 2.7110883423451915, 2.7386127875258306, 2.765863337187866, 2.792848008753788, 2.819574435974337, 2.846049894151541, 2.8722813232690143, 2.8982753492378874, 2.924038303442689, 2.9495762407505253, 2.974894956128703, 2.9999999999999996, 3.0248966924508345, 3.049590136395381, 3.074085229787879, 3.098386676965933, 3.1224989991991987, 3.1464265445104544, 3.1701734968294715, 3.1937438845342623, 3.217141588429082, 3.24037034920393, 3.2634337744161437, 3.2863353450309964, 3.309078421554859, 3.3316662497915357, 3.3541019662496843, 3.3763886032268267, 3.3985290935932855, 3.420526275297414, 3.442382895611701, 3.4641016151377544, 3.485685011586675, 3.5071355833500366, 3.5284557528754696, 3.5496478698597693, 3.5707142142714248, 3.591656999213594, 3.6124783736376886, 3.63318042491699, 3.6537651812890215, 3.674234614174767, 3.694590640382233, 3.714835124201342, 3.7349698793966195, 3.7549966711037173, 3.7749172176353745, 3.794733192202055, 3.8144462245521304, 3.8340579025361623, 3.853569773599539, 3.8729833462074166, 3.892300091205713], [0.0, 0.4, 0.565685424949238, 0.692820323027551, 0.8, 0.894427190999916, 0.9797958971132713, 1.0583005244258363, 1.131370849898476, 1.2, 1.2649110640673518, 1.32664991614216, 1.385640646055102, 1.4422205101855958, 1.4966629547095767, 1.5491933384829666, 1.6, 1.6492422502470643, 1.697056274847714, 1.7435595774162698, 1.788854381999832, 1.8330302779823362, 1.876166303929372, 1.918332609325088, 1.9595917942265426, 2.0, 2.039607805437114, 2.078460969082653, 2.1166010488516727, 2.154065922853802, 2.1908902300206643, 2.227105745132009, 2.262741699796952, 2.297825058615212, 2.3323807579381204, 2.3664319132398464, 2.4, 2.433105012119288, 2.4657656011875906, 2.4979991993593598, 2.5298221281347035, 2.5612496949731396, 2.5922962793631443, 2.6229754097208002, 2.65329983228432, 2.6832815729997477, 2.7129319932501073, 2.7422618401604177, 2.771281292110204, 2.8000000000000003, 2.8284271247461903, 2.8565713714171403, 2.8844410203711917, 2.9120439557122078, 2.939387691339814, 2.9664793948382653, 2.9933259094191533, 3.0199337741083, 3.0463092423455636, 3.0724582991474434, 3.098386676965933, 3.1240998703626617, 3.149603149604724, 3.1749015732775088, 3.2, 3.2249030993194197, 3.249615361854384, 3.2741411087489802, 3.2984845004941286, 3.32264954516723, 3.3466401061363023, 3.3704599092705436, 3.394112549695428, 3.4176014981270124, 3.4409301068170506, 3.464101615137755, 3.4871191548325395, 3.509985754956849, 3.532704346531139, 3.5552777669262356, 3.577708763999664, 3.6, 3.622154055254967, 3.6441734316577197, 3.6660605559646724, 3.687817782917155, 3.709447398198282, 3.7309516212355263, 3.752332607858744, 3.7735924528226414, 3.794733192202055, 3.8157568056677826, 3.836665218650176, 3.8574603043971822, 3.8781438859330635, 3.8987177379235853, 3.9191835884530852, 3.9395431207184424, 3.9597979746446663, 3.9799497484264803, 4.0, 4.019950248448357], [0.0, 0.41231056256176607, 0.58309518948453, 0.7141428428542851, 0.8246211251235321, 0.9219544457292888, 1.0099504938362078, 1.0908712114635715, 1.16619037896906, 1.236931687685298, 1.3038404810405297, 1.3674794331177345, 1.4282856857085702, 1.4866068747318506, 1.5427248620541512, 1.5968719422671311, 1.6492422502470643, 1.7, 1.7492855684535902, 1.797220075561143, 1.8439088914585775, 1.8894443627691184, 1.9339079605813716, 1.977371993328519, 2.0199009876724157, 2.0615528128088303, 2.102379604162864, 2.142428528562855, 2.181742422927143, 2.220360331117452, 2.258317958127243, 2.2956480566497994, 2.33238075793812, 2.3685438564654024, 2.4041630560342617, 2.4392621835300936, 2.473863375370596, 2.5079872407968904, 2.541653005427767, 2.574878637916747, 2.6076809620810595, 2.6400757564888173, 2.672077843177478, 2.7037011669191546, 2.734958866235469, 2.765863337187866, 2.7964262908219126, 2.826658805020514, 2.8565713714171403, 2.8861739379323623, 2.9154759474226504, 2.944486372867092, 2.973213749463701, 3.001666203960727, 3.0298514815086235, 3.0577769702841313, 3.0854497241083023, 3.1128764832546763, 3.1400636936215167, 3.167017524422623, 3.1937438845342623, 3.2202484376209237, 3.246536616149585, 3.2726136343907144, 3.2984845004941286, 3.324154027718932, 3.3496268448888453, 3.374907406137241, 3.4, 3.424908757908742, 3.4496376621320683, 3.4741905532080417, 3.4985711369071804, 3.522782990761707, 3.5468295701936396, 3.570714214271425, 3.594440151122286, 3.6180105030251086, 3.6414282912066254, 3.664696440361739, 3.687817782917155, 3.710795063055895, 3.733630940518894, 3.7563279941985894, 3.778888725538237, 3.8013155617496426, 3.8236108588610325, 3.845776904605882, 3.867815921162743, 3.8897300677553446, 3.9115214431215892, 3.9331920878594273, 3.954743986657038, 3.976179070414209, 3.9974992182613374, 4.018706259482023, 4.039801975344831, 4.060788100849391, 4.08166632639171, 4.102438299353203, 4.123105625617661, 4.1436698710201325], [0.0, 0.4242640687119285, 0.6, 0.7348469228349536, 0.848528137423857, 0.9486832980505139, 1.0392304845413265, 1.1224972160321824, 1.2, 1.2727922061357855, 1.3416407864998738, 1.407124727947029, 1.4696938456699071, 1.5297058540778357, 1.5874507866387544, 1.6431676725154982, 1.697056274847714, 1.7492855684535902, 1.8, 1.8493242008906932, 1.8973665961010278, 1.9442222095223582, 1.98997487421324, 2.0346989949375804, 2.078460969082653, 2.121320343559643, 2.1633307652783937, 2.2045407685048604, 2.244994432064365, 2.2847319317591728, 2.32379000772445, 2.3622023622035435, 2.4, 2.4372115213907883, 2.4738633753705965, 2.5099800796022267, 2.545584412271571, 2.5806975801127883, 2.615339366124404, 2.6495282598983545, 2.6832815729997477, 2.716615541441225, 2.749545416973504, 2.782085548648711, 2.814249455894058, 2.846049894151541, 2.877498913987632, 2.9086079144497976, 2.9393876913398143, 2.9698484809834995, 3.0, 3.029851481508624, 3.0594117081556713, 3.0886890422961004, 3.1176914536239795, 3.146426544510455, 3.1749015732775088, 3.2031234756093934, 3.2310988842807027, 3.2588341473600644, 3.2863353450309964, 3.3136083051561784, 3.340658617698013, 3.3674916480965473, 3.394112549695428, 3.420526275297414, 3.4467375879228173, 3.4727510708370675, 3.4985711369071804, 3.5242020373412193, 3.5496478698597698, 3.5749125863438955, 3.6, 3.6249137920783716, 3.6496575181789317, 3.6742346141747673, 3.6986484017813863, 3.722902093797257, 3.7469987990390394, 3.7709415269929605, 3.7947331922020555, 3.8183766184073566, 3.84187454245971, 3.8652296180175374, 3.8884444190447165, 3.9115214431215897, 3.9344631145812006, 3.957271787481876, 3.97994974842648, 4.0024992192379, 4.024922359499621, 4.047221268969612, 4.069397989875161, 4.091454509095757, 4.113392760240627, 4.135214625627066, 4.156921938165306, 4.178516483155236, 4.2, 4.221374183841087, 4.242640687119286, 4.263801121065569], [0.0, 0.43588989435406744, 0.6164414002968976, 0.7549834435270751, 0.8717797887081349, 0.9746794344808966, 1.0677078252031313, 1.1532562594670797, 1.2328828005937953, 1.307669683062202, 1.3784048752090223, 1.4456832294800963, 1.5099668870541503, 1.5716233645501714, 1.6309506430300091, 1.6881943016134133, 1.7435595774162698, 1.797220075561143, 1.8493242008906932, 1.9000000000000004, 1.9493588689617931, 1.9974984355438181, 2.0445048300260877, 2.0904544960366875, 2.1354156504062627, 2.179449471770337, 2.2226110770892875, 2.2649503305812253, 2.3065125189341593, 2.3473389188611007, 2.3874672772626644, 2.4269322199023198, 2.4657656011875906, 2.503996805109783, 2.5416530054277673, 2.5787593916455256, 2.615339366124404, 2.651414716712571, 2.687005768508881, 2.7221315177632404, 2.7568097504180447, 2.791057147390573, 2.8248893783651075, 2.8583211855912904, 2.8913664589601926, 2.924038303442689, 2.956349099818897, 2.9883105594967874, 3.0199337741083006, 3.051229260478472, 3.082207001484489, 3.1128764832546767, 3.1432467291003428, 3.1733263305244868, 3.203123475609394, 3.232645975048923, 3.2619012860600183, 3.290896534380867, 3.319638534539567, 3.3481338085566414, 3.3763886032268267, 3.4044089061098406, 3.432200460346103, 3.4597687784012394, 3.4871191548325395, 3.5142566781611158, 3.541186241925155, 3.567912554982255, 3.594440151122286, 3.6207733980463352, 3.6469165057620945, 3.672873534441392, 3.6986484017813863, 3.7242448899072147, 3.749666651850535, 3.7749172176353754, 3.8000000000000007, 3.824918299781056, 3.8496753109840323, 3.874274125562104, 3.8987177379235862, 3.9230090491866068, 3.947150871198111, 3.9711459303329564, 3.9949968710876362, 4.018706259482024, 4.042276586281548, 4.065710270051225, 4.0890096600521755, 4.112177038990418, 4.135214625627067, 4.158124577258358, 4.180908992073375, 4.203569911396741, 4.226109321823088, 4.2485291572496005, 4.270831300812525, 4.293017586733137, 4.315089802078284, 4.337049688440289, 4.358898943540674, 4.380639222761903], [0.0, 0.447213595499958, 0.6324555320336759, 0.7745966692414835, 0.894427190999916, 1.0000000000000002, 1.0954451150103324, 1.1832159566199234, 1.2649110640673518, 1.3416407864998738, 1.4142135623730951, 1.4832396974191329, 1.549193338482967, 1.61245154965971, 1.6733200530681511, 1.7320508075688772, 1.788854381999832, 1.8439088914585775, 1.8973665961010278, 1.9493588689617931, 2.0000000000000004, 2.04939015319192, 2.0976176963403033, 2.144761058952722, 2.1908902300206647, 2.23606797749979, 2.280350850198276, 2.3237900077244507, 2.366431913239847, 2.4083189157584592, 2.4494897427831783, 2.489979919597747, 2.5298221281347035, 2.5690465157330262, 2.60768096208106, 2.6457513110645907, 2.6832815729997477, 2.720294101747089, 2.7568097504180447, 2.7928480087537886, 2.8284271247461903, 2.863564212655271, 2.8982753492378883, 2.932575659723036, 2.9664793948382657, 3.0, 3.0331501776206204, 3.0659419433511785, 3.098386676965934, 3.130495168499706, 3.1622776601683795, 3.193743884534263, 3.22490309931942, 3.255764119219942, 3.286335345030997, 3.3166247903554003, 3.3466401061363023, 3.3763886032268267, 3.405877273185281, 3.4351128074635335, 3.4641016151377544, 3.492849839314596, 3.521363372331802, 3.5496478698597698, 3.577708763999664, 3.605551275463989, 3.6331804249169903, 3.6606010435446255, 3.687817782917155, 3.7148351242013424, 3.7416573867739418, 3.768288736283355, 3.7947331922020555, 3.82099463490856, 3.847076812334269, 3.872983346207417, 3.8987177379235862, 3.924283374069717, 3.9496835316263006, 3.9749213828703587, 4.000000000000001, 4.024922359499622, 4.049691346263318, 4.0743097574926725, 4.09878030638384, 4.123105625617661, 4.147288270665545, 4.171330722922843, 4.1952353926806065, 4.219004621945797, 4.242640687119286, 4.266145801540309, 4.289522117905444, 4.312771730569565, 4.335896677735761, 4.358898943540674, 4.3817804600413295, 4.404543109109049, 4.427188724235731, 4.449719092257398, 4.47213595499958, 4.494441010848847], [0.0, 0.45825756949558405, 0.6480740698407861, 0.7937253933193773, 0.9165151389911681, 1.02469507659596, 1.1224972160321824, 1.2124355652982142, 1.2961481396815722, 1.374772708486752, 1.449137674618944, 1.5198684153570665, 1.5874507866387546, 1.6522711641858308, 1.7146428199482247, 1.7748239349298847, 1.8330302779823362, 1.8894443627691184, 1.9442222095223582, 1.9974984355438181, 2.04939015319192, 2.1, 2.149418526020468, 2.1977260975835913, 2.244994432064365, 2.2912878474779204, 2.336664289109585, 2.381176179958132, 2.4248711305964283, 2.4677925358506134, 2.5099800796022267, 2.551470164434615, 2.5922962793631443, 2.632489316217637, 2.672077843177478, 2.711088342345192, 2.749545416973504, 2.787471972953271, 2.824889378365107, 2.861817604250837, 2.898275349237888, 2.934280150224242, 2.9698484809835, 3.004995840263344, 3.039736830714133, 3.0740852297878796, 3.108054053584011, 3.1416556144810017, 3.174901573277509, 3.2078029864690882, 3.2403703492039306, 3.272613634390715, 3.3045423283716615, 3.336165463522456, 3.3674916480965478, 3.398529093593286, 3.4292856398964493, 3.459768778401239, 3.48998567332303, 3.5199431813596083, 3.5496478698597693, 3.5791060336346563, 3.608323710533743, 3.6373066958946425, 3.6660605559646724, 3.6945906403822333, 3.722902093797257, 3.7509998667022106, 3.778888725538237, 3.8065732621348563, 3.834057902536163, 3.861346915261565, 3.8884444190447165, 3.915354390090379, 3.9420806688854046, 3.968626966596886, 3.9949968710876362, 4.02119385257662, 4.047221268969613, 4.07308237088326, 4.09878030638384, 4.124318125460256, 4.149698784249287, 4.174925149029621, 4.2, 4.224926034855522, 4.249705872175156, 4.274342054632503, 4.298837052040936, 4.323193264243457, 4.347413023856832, 4.371498598878879, 4.3954521951671826, 4.419275958796871, 4.442971978304612, 4.466542286825459, 4.48998886412873, 4.513313638558704, 4.536518488885503, 4.559605246071199, 4.582575694955841, 4.605431575867782], [0.0, 0.469041575982343, 0.6633249580710799, 0.8124038404635961, 0.938083151964686, 1.0488088481701516, 1.148912529307606, 1.2409673645990857, 1.3266499161421599, 1.407124727947029, 1.4832396974191326, 1.5556349186104048, 1.6248076809271923, 1.6911534525287764, 1.7549928774784245, 1.816590212458495, 1.876166303929372, 1.9339079605813716, 1.98997487421324, 2.0445048300260877, 2.0976176963403033, 2.149418526020468, 2.2, 2.249444375840399, 2.297825058615212, 2.345207879911715, 2.3916521486202797, 2.4372115213907883, 2.4819347291981715, 2.5258661880630178, 2.569046515733026, 2.6115129714401193, 2.6532998322843198, 2.6944387170614963, 2.734958866235469, 2.7748873851023217, 2.814249455894058, 2.8530685235374214, 2.891366458960192, 2.9291637031753623, 2.9664793948382653, 3.0033314835362415, 3.039736830714133, 3.0757112998459397, 3.1112698372208096, 3.1464265445104544, 3.1811947441173736, 3.2155870381627056, 3.2496153618543846, 3.283291031876401, 3.3166247903554003, 3.3496268448888458, 3.3823069050575527, 3.414674215792775, 3.4467375879228173, 3.4785054261852175, 3.509985754956849, 3.5411862419251547, 3.5721142198983507, 3.602776706930364, 3.63318042491699, 3.6633318168028404, 3.6932370625238775, 3.722902093797257, 3.752332607858744, 3.7815340802378072, 3.81051177665153, 3.8392707640904935, 3.867815921162743, 3.8961519477556315, 3.924283374069717, 3.952214569073901, 3.97994974842648, 4.007492981902776, 4.034848200366403, 4.06201920231798, 4.0890096600521755, 4.115823125451336, 4.1424630354415966, 4.168932717135166, 4.1952353926806065, 4.221374183841087, 4.247352116319061, 4.273172123844299, 4.298837052040936, 4.324349662087931, 4.349712634186309, 4.374928570845472, 4.4, 4.424929377967517, 4.449719092257398, 4.474371464239419, 4.498888751680798, 4.523273151159457, 4.54752680036083, 4.571651780264984, 4.595650117230424, 4.61952378498044, 4.64327470649756, 4.666904755831214, 4.69041575982343, 4.713809499757071], [0.0, 0.479583152331272, 0.6782329983125268, 0.8306623862918077, 0.959166304662544, 1.072380529476361, 1.174734012447073, 1.2688577540449522, 1.3564659966250536, 1.438749456993816, 1.5165750888103102, 1.5905973720586868, 1.6613247725836153, 1.7291616465790585, 1.7944358444926363, 1.857417562100671, 1.918332609325088, 1.977371993328519, 2.0346989949375804, 2.0904544960366875, 2.144761058952722, 2.1977260975835913, 2.249444375840399, 2.3000000000000003, 2.349468024894146, 2.39791576165636, 2.4454038521274972, 2.491987158875423, 2.5377155080899043, 2.582634314028992, 2.6267851073127395, 2.670205984563738, 2.7129319932501073, 2.754995462791183, 2.7964262908219126, 2.8372521918222215, 2.877498913987632, 2.917190429162965, 2.956349099818897, 2.994995826374388, 3.0331501776206204, 3.0708305065568178, 3.108054053584011, 3.1448370387032774, 3.1811947441173736, 3.2171415884290826, 3.252691193458119, 3.2878564445547194, 3.3226495451672307, 3.357082066318904, 3.3911649915626345, 3.4249087579087423, 3.458323293158117, 3.491418050019219, 3.5242020373412197, 3.5566838487557484, 3.5888716889852725, 3.620773398046335, 3.6523964735499352, 3.6837480912787726, 3.714835124201342, 3.745664160065609, 3.7762415176998414, 3.8065732621348563, 3.836665218650176, 3.866522985836241, 3.8961519477556315, 3.9255572852781047, 3.954743986657038, 3.9837168574084183, 4.012480529547776, 4.041039470235351, 4.069397989875161, 4.097560249709576, 4.125530268947254, 4.153311931459037, 4.180908992073375, 4.2083250825001635, 4.235563716909475, 4.262628297189424, 4.289522117905444, 4.316248370981448, 4.342810150121694, 4.369210454990696, 4.3954521951671826, 4.421538193886829, 4.447471191587417, 4.473253849269009, 4.498888751680798, 4.524378410345448, 4.549725266430931, 4.57493169347915, 4.6000000000000005, 4.624932431938872, 4.649731175025068, 4.674398357008098, 4.698936049788292, 4.723346271447818, 4.747630988187688, 4.77179211617606, 4.79583152331272, 4.819751030914357], [0.0, 0.48989794855663565, 0.6928203230275509, 0.8485281374238571, 0.9797958971132713, 1.0954451150103324, 1.2000000000000002, 1.2961481396815722, 1.3856406460551018, 1.469693845669907, 1.5491933384829668, 1.6248076809271923, 1.6970562748477143, 1.7663521732655696, 1.833030277982336, 1.8973665961010275, 1.9595917942265426, 2.0199009876724157, 2.078460969082653, 2.1354156504062627, 2.1908902300206647, 2.244994432064365, 2.297825058615212, 2.349468024894146, 2.4000000000000004, 2.4494897427831783, 2.4979991993593598, 2.5455844122715714, 2.5922962793631443, 2.638181191654584, 2.6832815729997477, 2.727636339397171, 2.7712812921102037, 2.8142494558940583, 2.8565713714171403, 2.898275349237888, 2.939387691339814, 2.979932885150268, 3.0199337741083, 3.0594117081556713, 3.0983866769659336, 3.136877428271625, 3.174901573277509, 3.212475680841802, 3.2496153618543846, 3.2863353450309964, 3.32264954516723, 3.358571124749333, 3.3941125496954285, 3.4292856398964493, 3.464101615137755, 3.498571136907181, 3.532704346531139, 3.5665109000254023, 3.6, 3.6331804249169903, 3.666060555964672, 3.698648401781386, 3.7309516212355263, 3.7629775444453557, 3.794733192202055, 3.8262252939417984, 3.857460304397182, 3.8884444190447165, 3.9191835884530852, 3.9496835316262997, 3.97994974842648, 4.009987531152684, 4.039801975344831, 4.069397989875161, 4.09878030638384, 4.127953488110059, 4.156921938165306, 4.18568990729127, 4.214261501141095, 4.242640687119286, 4.270831300812525, 4.298837052040936, 4.3266615305567875, 4.354308211415448, 4.3817804600413295, 4.409081537009721, 4.436214602563767, 4.463182720884279, 4.48998886412873, 4.5166359162544865, 4.543126676640219, 4.5694638635183455, 4.595650117230424, 4.621688003316537, 4.6475800154489, 4.673328578219169, 4.698936049788292, 4.724404724407087, 4.749736834815168, 4.774934554525329, 4.800000000000001, 4.824935232725928, 4.849742261192857, 4.874423042781577, 4.898979485566357, 4.9234134500364695], [0.0, 0.5, 0.7071067811865476, 0.8660254037844388, 1.0, 1.118033988749895, 1.2247448713915892, 1.3228756555322954, 1.4142135623730951, 1.5, 1.5811388300841898, 1.6583123951777001, 1.7320508075688776, 1.8027756377319948, 1.8708286933869707, 1.9364916731037083, 2.0, 2.0615528128088303, 2.121320343559643, 2.179449471770337, 2.23606797749979, 2.2912878474779204, 2.345207879911715, 2.39791576165636, 2.4494897427831783, 2.5000000000000004, 2.5495097567963927, 2.5980762113533165, 2.6457513110645907, 2.6925824035672523, 2.7386127875258306, 2.783882181415011, 2.8284271247461903, 2.8722813232690148, 2.9154759474226504, 2.958039891549808, 3.0, 3.04138126514911, 3.0822070014844885, 3.1224989991991996, 3.1622776601683795, 3.2015621187164247, 3.2403703492039306, 3.278719262151, 3.3166247903554003, 3.3541019662496843, 3.3911649915626345, 3.4278273002005224, 3.4641016151377553, 3.5, 3.535533905932738, 3.5707142142714257, 3.6055512754639896, 3.64005494464026, 3.6742346141747677, 3.708099243547832, 3.7416573867739413, 3.774917217635375, 3.8078865529319548, 3.840572873934304, 3.8729833462074166, 3.9051248379533274, 3.9370039370059056, 3.968626966596886, 4.0, 4.031128874149275, 4.06201920231798, 4.092676385936225, 4.123105625617661, 4.153311931459037, 4.183300132670378, 4.2130748865881795, 4.242640687119286, 4.272001872658766, 4.301162633521313, 4.330127018922194, 4.358898943540674, 4.387482193696061, 4.415880433163924, 4.444097208657795, 4.47213595499958, 4.500000000000001, 4.527692569068709, 4.55521678957215, 4.582575694955841, 4.609772228646444, 4.636809247747852, 4.663689526544408, 4.69041575982343, 4.716990566028302, 4.743416490252569, 4.769696007084729, 4.79583152331272, 4.821825380496478, 4.847679857416329, 4.873397172404482, 4.898979485566357, 4.924428900898053, 4.949747468305833, 4.974937185533101, 5.000000000000001, 5.024937810560446], [0.0, 0.5099019513592785, 0.7211102550927979, 0.8831760866327849, 1.019803902718557, 1.140175425099138, 1.2489995996796799, 1.3490737563232043, 1.4422205101855958, 1.5297058540778354, 1.61245154965971, 1.6911534525287766, 1.7663521732655698, 1.8384776310850237, 1.9078784028338913, 1.9748417658131499, 2.039607805437114, 2.102379604162864, 2.1633307652783937, 2.2226110770892875, 2.280350850198276, 2.336664289109585, 2.3916521486202797, 2.4454038521274972, 2.4979991993593598, 2.5495097567963927, 2.6000000000000005, 2.6495282598983545, 2.6981475126464085, 2.7459060435491964, 2.792848008753788, 2.839013913315678, 2.8844410203711917, 2.9291637031753623, 2.973213749463701, 3.0166206257996713, 3.059411708155671, 3.101612483854165, 3.1432467291003428, 3.1843366656181322, 3.22490309931942, 3.264965543462902, 3.304542328371662, 3.3436506994600976, 3.382306905057553, 3.420526275297414, 3.458323293158117, 3.4957116585897072, 3.5327043465311396, 3.5693136595149495, 3.6055512754639896, 3.6414282912066254, 3.6769552621700474, 3.712142238654118, 3.7469987990390394, 3.7815340802378077, 3.8157568056677826, 3.849675310984032, 3.8832975677895205, 3.916631205513228, 3.9496835316262997, 3.9824615503479754, 4.014971979976946, 4.047221268969613, 4.079215610874228, 4.110960958218893, 4.142463035441596, 4.173727350941841, 4.204759208325728, 4.235563716909475, 4.266145801540309, 4.296510211788167, 4.3266615305567875, 4.356604182158393, 4.386342439892262, 4.415880433163924, 4.445222154178575, 4.474371464239419, 4.503332099679082, 4.532107677449864, 4.560701700396552, 4.589117562233507, 4.617358552246079, 4.645427859734774, 4.67332857821917, 4.701063709417264, 4.7286361670147565, 4.756048780237647, 4.7833042972405595, 4.810405388322278, 4.83735464897913, 4.864154602806124, 4.8908077042549944, 4.917316341257699, 4.943682837723311, 4.969909455915671, 4.9959983987187195, 5.021951811795889, 5.047771785649585, 5.073460357586329, 5.099019513592785, 5.1244511901275835], [0.0, 0.5196152422706632, 0.7348469228349535, 0.9000000000000001, 1.0392304845413265, 1.1618950038622253, 1.2727922061357857, 1.374772708486752, 1.469693845669907, 1.5588457268119895, 1.6431676725154984, 1.7233687939614089, 1.8000000000000003, 1.8734993995195197, 1.9442222095223582, 2.0124611797498106, 2.078460969082653, 2.142428528562855, 2.2045407685048604, 2.2649503305812253, 2.3237900077244507, 2.381176179958132, 2.4372115213907883, 2.491987158875423, 2.5455844122715714, 2.5980762113533165, 2.6495282598983545, 2.7, 2.749545416973504, 2.7982137159266447, 2.8460498941515415, 2.8930952282978866, 2.939387691339814, 2.9849623113198605, 3.0298514815086235, 3.0740852297878796, 3.117691453623979, 3.160696125855822, 3.203123475609394, 3.244996147917591, 3.286335345030997, 3.3271609519228256, 3.3674916480965478, 3.407345007480164, 3.4467375879228177, 3.4856850115866753, 3.5242020373412197, 3.5623026261113755, 3.6000000000000005, 3.6373066958946425, 3.6742346141747677, 3.7107950630558952, 3.7469987990390394, 3.782856063875548, 3.818376618407357, 3.853569773599539, 3.8884444190447165, 3.9230090491866063, 3.957271787481876, 3.9912404086950213, 4.024922359499621, 4.058324777540605, 4.091454509095756, 4.124318125460256, 4.156921938165306, 4.189272013130682, 4.221374183841087, 4.253234063627348, 4.28485705712571, 4.316248370981448, 4.3474130238568325, 4.378355855797928, 4.409081537009721, 4.439594576084623, 4.469899327725402, 4.5, 4.529900661162451, 4.559605246071199, 4.589117562233508, 4.618441295502196, 4.647580015448901, 4.676537180435969, 4.705316142407438, 4.73392015141785, 4.762352359916264, 4.790615826801394, 4.818713521262704, 4.846648326421054, 4.874423042781577, 4.902040391510457, 4.929503017546495, 4.956813492557492, 4.983974317750846, 5.0109879265470205, 5.037856687124, 5.06458290484024, 5.091168824543143, 5.117616632769595, 5.143928459844674, 5.170106381884226, 5.196152422706633, 5.222068555658764], [0.0, 0.5291502622129182, 0.7483314773547882, 0.9165151389911681, 1.0583005244258363, 1.1832159566199234, 1.2961481396815722, 1.4000000000000001, 1.4966629547095764, 1.5874507866387544, 1.6733200530681511, 1.7549928774784245, 1.8330302779823362, 1.9078784028338915, 1.9798989873223332, 2.0493901531919194, 2.1166010488516727, 2.181742422927143, 2.244994432064365, 2.3065125189341593, 2.366431913239847, 2.4248711305964283, 2.4819347291981715, 2.5377155080899043, 2.5922962793631443, 2.6457513110645907, 2.6981475126464085, 2.749545416973504, 2.8000000000000003, 2.8495613697550017, 2.8982753492378874, 2.946183972531247, 2.993325909419153, 3.039736830714133, 3.0854497241083028, 3.1304951684997055, 3.1749015732775088, 3.2186953878862163, 3.2619012860600183, 3.3045423283716615, 3.3466401061363023, 3.3882148692194836, 3.4292856398964497, 3.4698703145794942, 3.509985754956849, 3.5496478698597693, 3.5888716889852725, 3.627671429443411, 3.6660605559646724, 3.704051835490427, 3.7416573867739418, 3.7788887255382373, 3.815756805667783, 3.852272056851645, 3.8884444190447165, 3.924283374069717, 3.9597979746446663, 3.994996871087636, 4.029888335921977, 4.064480286580315, 4.098780306383839, 4.132795663954365, 4.166533331199932, 4.2, 4.233202097703345, 4.266145801540308, 4.298837052040936, 4.331281565541543, 4.363484845854286, 4.3954521951671826, 4.427188724235731, 4.458699361921591, 4.48998886412873, 4.521061822182926, 4.551922670696417, 4.58257569495584, 4.613025037868319, 4.64327470649756, 4.67332857821917, 4.703190406521939, 4.732863826479694, 4.762352359916263, 4.791659420284376, 4.82078831727758, 4.849742261192857, 4.878524367060187, 4.907137658554119, 4.935585071701227, 4.963869458396343, 4.991993589739474, 5.019960159204453, 5.047771785649585, 5.075431016179809, 5.10294032886923, 5.130302135352265, 5.15751878329105, 5.184592558726289, 5.2115256883181535, 5.238320341483518, 5.264978632435274, 5.291502622129181, 5.317894320123333], [0.0, 0.5385164807134505, 0.7615773105863909, 0.9327379053088817, 1.077032961426901, 1.2041594578792296, 1.319090595827292, 1.4247806848775009, 1.5231546211727818, 1.6155494421403513, 1.7029386365926402, 1.7860571099491753, 1.8654758106177634, 1.94164878389476, 2.0149441679609885, 2.085665361461421, 2.154065922853802, 2.220360331117452, 2.2847319317591728, 2.3473389188611007, 2.4083189157584592, 2.4677925358506134, 2.5258661880630178, 2.582634314028992, 2.638181191654584, 2.6925824035672523, 2.7459060435491964, 2.7982137159266447, 2.8495613697550017, 2.9000000000000004, 2.9495762407505253, 2.99833287011299, 3.0463092423455636, 3.0935416596516045, 3.1400636936215167, 3.1859064644147983, 3.2310988842807027, 3.2756678708318403, 3.3196385345395667, 3.363034344160048, 3.4058772731852804, 3.448187929913334, 3.48998567332303, 3.531288716601915, 3.5721142198983507, 3.6124783736376886, 3.6523964735499352, 3.691882988394947, 3.7309516212355267, 3.769615364994153, 3.8078865529319548, 3.845776904605883, 3.88329756778952, 3.9204591567825324, 3.957271787481876, 3.993745109543172, 4.029888335921977, 4.065710270051224, 4.101219330881976, 4.136423575989287, 4.171330722922842, 4.205948168962618, 4.240283009422838, 4.274342054632503, 4.308131845707604, 4.341658669218482, 4.374928570845472, 4.407947368106838, 4.440720662234904, 4.473253849269009, 4.505552130427525, 4.537620521815371, 4.5694638635183455, 4.601086828130937, 4.632493928760188, 4.663689526544408, 4.694677837722201, 4.725462940284264, 4.756048780237647, 4.786439177509728, 4.8166378315169185, 4.846648326421054, 4.876474136094644, 4.906118628814432, 4.935585071701227, 4.964876634922565, 4.993996395673509, 5.022947341949744, 5.0517323761260355, 5.0803543183522155, 5.10881590977792, 5.137119815616529, 5.165268628057984, 5.193264869039514, 5.221110992882646, 5.2488093888042835, 5.276362383309168, 5.3037722424704485, 5.331041174104736, 5.358171329847527, 5.385164807134505, 5.412023651093924], [0.0, 0.5477225575051661, 0.7745966692414833, 0.9486832980505139, 1.0954451150103321, 1.2247448713915892, 1.3416407864998738, 1.4491376746189437, 1.5491933384829666, 1.6431676725154982, 1.7320508075688772, 1.816590212458495, 1.8973665961010278, 1.9748417658131499, 2.0493901531919194, 2.1213203435596424, 2.1908902300206643, 2.258317958127243, 2.32379000772445, 2.3874672772626644, 2.4494897427831783, 2.5099800796022267, 2.569046515733026, 2.6267851073127395, 2.6832815729997477, 2.7386127875258306, 2.792848008753788, 2.8460498941515415, 2.8982753492378874, 2.9495762407505253, 2.9999999999999996, 3.049590136395381, 3.098386676965933, 3.146426544510455, 3.1937438845342623, 3.2403703492039297, 3.2863353450309964, 3.331666249791536, 3.376388603226826, 3.420526275297414, 3.4641016151377544, 3.5071355833500366, 3.5496478698597698, 3.5916569992135936, 3.63318042491699, 3.674234614174767, 3.714835124201342, 3.7549966711037173, 3.7947331922020555, 3.8340579025361627, 3.872983346207417, 3.9115214431215892, 3.9496835316262997, 3.9874804074753776, 4.024922359499621, 4.06201920231798, 4.098780306383839, 4.135214625627066, 4.171330722922842, 4.207136793592525, 4.242640687119285, 4.277849927241487, 4.3127717305695645, 4.347413023856832, 4.381780460041329, 4.415880433163923, 4.449719092257397, 4.483302354291978, 4.516635916254486, 4.54972526643093, 4.58257569495584, 4.61519230368573, 4.6475800154489, 4.679743582719036, 4.711687595755898, 4.743416490252569, 4.774934554525329, 4.806245936279166, 4.83735464897913, 4.868264577855234, 4.898979485566357, 4.929503017546495, 4.959838707054898, 4.9899899799498595, 5.019960159204453, 5.049752469181039, 5.079370039680118, 5.10881590977792, 5.138093031466052, 5.167204273105525, 5.196152422706632, 5.224940191045253, 5.253570214625479, 5.282045058497703, 5.310367218940701, 5.338539126015655, 5.366563145999495, 5.394441583704471, 5.422176684690383, 5.449770637375485, 5.477225575051661, 5.504543577809154], [0.0, 0.5567764362830022, 0.7874007874011811, 0.9643650760992957, 1.1135528725660044, 1.2449899597988734, 1.3638181696985856, 1.4730919862656235, 1.5748015748023623, 1.6703293088490065, 1.760681686165901, 1.846618531261939, 1.9287301521985913, 2.0074859899884734, 2.083266665599966, 2.1563858652847823, 2.227105745132009, 2.2956480566497994, 2.3622023622035435, 2.4269322199023198, 2.489979919597747, 2.551470164434615, 2.6115129714401193, 2.670205984563738, 2.727636339397171, 2.783882181415011, 2.839013913315678, 2.8930952282978866, 2.946183972531247, 2.99833287011299, 3.049590136395381, 3.1, 3.1496031496047245, 3.1984371183438953, 3.2465366161495854, 3.2939338184001206, 3.340658617698013, 3.38673884437522, 3.432200460346103, 3.477067730142742, 3.521363372331802, 3.5651086939951777, 3.6083237105337433, 3.6510272527057364, 3.693237062523878, 3.7349698793966195, 3.7762415176998414, 3.817066936798463, 3.8574603043971827, 3.8974350539810154, 3.9370039370059056, 3.9761790704142093, 4.014971979976947, 4.053393639902249, 4.091454509095757, 4.129164564412516, 4.166533331199932, 4.20356991139674, 4.240283009422838, 4.276680956068619, 4.3127717305695645, 4.34856298103178, 4.384062043356595, 4.419275958796871, 4.454211490264018, 4.488875137492688, 4.523273151159456, 4.557411546042337, 4.591296113299599, 4.624932431938872, 4.658325879540847, 4.69148164229596, 4.724404724407087, 4.757099956906519, 4.789572005931219, 4.8218253804964775, 4.8538644398046396, 4.8856934001224435, 4.917316341257699, 4.948737212663449, 4.979959839195494, 5.01098792654702, 5.041825066382213, 5.072474741188959, 5.10294032886923, 5.13322510708424, 5.163332257370235, 5.193264869039514, 5.223025942880239, 5.252618394667558, 5.282045058497703, 5.3113086899558, 5.340411969127476, 5.36935750346352, 5.398147830506312, 5.426785420486054, 5.455272678794342, 5.483611948342078, 5.511805511808268, 5.539855593785817, 5.567764362830022, 5.595533933415113], [0.0, 0.565685424949238, 0.7999999999999999, 0.9797958971132713, 1.131370849898476, 1.2649110640673518, 1.3856406460551018, 1.4966629547095764, 1.5999999999999999, 1.697056274847714, 1.7888543819998317, 1.876166303929372, 1.9595917942265426, 2.039607805437114, 2.116601048851672, 2.1908902300206643, 2.262741699796952, 2.33238075793812, 2.4, 2.4657656011875906, 2.5298221281347035, 2.5922962793631443, 2.6532998322843198, 2.7129319932501073, 2.7712812921102037, 2.8284271247461903, 2.8844410203711917, 2.939387691339814, 2.993325909419153, 3.0463092423455636, 3.098386676965933, 3.1496031496047245, 3.1999999999999997, 3.249615361854384, 3.2984845004941286, 3.3466401061363023, 3.394112549695428, 3.4409301068170506, 3.487119154832539, 3.5327043465311387, 3.5777087639996634, 3.622154055254967, 3.6660605559646724, 3.709447398198281, 3.752332607858744, 3.7947331922020546, 3.8366652186501757, 3.878143885933063, 3.9191835884530852, 3.959797974644666, 4.0, 4.039801975344831, 4.079215610874228, 4.118252056394801, 4.156921938165306, 4.1952353926806065, 4.233202097703344, 4.2708313008125245, 4.308131845707603, 4.345112196480086, 4.381780460041329, 4.418144406874904, 4.454211490264017, 4.48998886412873, 4.525483399593904, 4.560701700396551, 4.595650117230423, 4.63033476111609, 4.66476151587624, 4.698936049788292, 4.732863826479693, 4.766550115125193, 4.8, 4.833218389437829, 4.866210024238575, 4.898979485566356, 4.931531202375181, 4.963869458396343, 4.995998398718719, 5.027922035990614, 5.059644256269407, 5.091168824543142, 5.122499389946279, 5.15363949069005, 5.184592558726289, 5.215361924162119, 5.2459508194416005, 5.276362383309167, 5.3065996645686395, 5.336665625650533, 5.366563145999495, 5.396295025292816, 5.4258639865002145, 5.455272678794342, 5.4845236803208355, 5.513619500836088, 5.542562584220407, 5.571355310873648, 5.6, 5.628498911788116, 5.656854249492381, 5.685068161420759], [0.0, 0.574456264653803, 0.812403840463596, 0.9949874371066202, 1.148912529307606, 1.2845232578665131, 1.4071247279470291, 1.5198684153570665, 1.624807680927192, 1.7233687939614086, 1.8165902124584952, 1.9052558883257653, 1.9899748742132404, 2.0712315177207983, 2.149418526020468, 2.224859546128699, 2.297825058615212, 2.3685438564654024, 2.4372115213907883, 2.503996805109783, 2.5690465157330262, 2.632489316217637, 2.6944387170614963, 2.754995462791183, 2.8142494558940583, 2.8722813232690148, 2.9291637031753623, 2.9849623113198605, 3.039736830714133, 3.0935416596516045, 3.146426544510455, 3.1984371183438953, 3.249615361854384, 3.3000000000000007, 3.3496268448888458, 3.398529093593286, 3.4467375879228173, 3.49428104193123, 3.541186241925155, 3.58747822293042, 3.6331804249169903, 3.678314831549905, 3.7229020937972575, 3.7669616403674726, 3.8105117766515306, 3.853569773599539, 3.896151947755632, 3.9382737335030438, 3.9799497484264807, 4.02119385257662, 4.06201920231798, 4.102438299353204, 4.1424630354415966, 4.182104733265298, 4.221374183841087, 4.260281680828159, 4.298837052040936, 4.337049688440288, 4.374928570845472, 4.412482294582042, 4.449719092257398, 4.486646854834912, 4.523273151159457, 4.559605246071199, 4.595650117230424, 4.631414470763764, 4.666904755831214, 4.702127178203499, 4.737087712930805, 4.77179211617606, 4.806245936279167, 4.8404545241123795, 4.874423042781577, 4.908156476723211, 4.941659640242335, 4.974937185533101, 5.007993610219566, 5.040833264451424, 5.07346035758633, 5.105878964487898, 5.1380930314660525, 5.170106381884226, 5.201922721455982, 5.23354564325181, 5.264978632435274, 5.296225070746145, 5.327288240746882, 5.358171329847526, 5.388877434122993, 5.419409561935692, 5.449770637375486, 5.479963503528103, 5.509990925582366, 5.539855593785817, 5.569560126257729, 5.599107071667768, 5.628498911788117, 5.657738063926256, 5.686826883245173, 5.715767664977296, 5.7445626465380295, 5.773214009544425], [0.0, 0.5830951894845301, 0.8246211251235321, 1.009950493836208, 1.1661903789690602, 1.30384048104053, 1.4282856857085702, 1.5427248620541514, 1.6492422502470643, 1.7492855684535902, 1.8439088914585775, 1.9339079605813718, 2.019900987672416, 2.102379604162864, 2.181742422927143, 2.258317958127243, 2.3323807579381204, 2.4041630560342617, 2.4738633753705965, 2.5416530054277673, 2.60768096208106, 2.672077843177478, 2.734958866235469, 2.7964262908219126, 2.8565713714171403, 2.9154759474226504, 2.973213749463701, 3.0298514815086235, 3.0854497241083028, 3.1400636936215167, 3.1937438845342623, 3.2465366161495854, 3.2984845004941286, 3.3496268448888458, 3.4000000000000004, 3.449637662132068, 3.4985711369071804, 3.54682957019364, 3.594440151122286, 3.6414282912066254, 3.687817782917155, 3.733630940518894, 3.7788887255382373, 3.823610858861032, 3.8678159211627436, 3.911521443121589, 3.954743986657038, 3.997499218261337, 4.039801975344832, 4.08166632639171, 4.123105625617661, 4.164132562731403, 4.204759208325728, 4.244997055358225, 4.28485705712571, 4.324349662087931, 4.363484845854286, 4.402272140611028, 4.440720662234904, 4.4788391353117385, 4.516635916254486, 4.5541190146942805, 4.591296113299598, 4.628174586162454, 4.664761515876241, 4.701063709417263, 4.737087712930805, 4.77283982551269, 4.8083261120685235, 4.843552415324934, 4.878524367060187, 4.913247398615299, 4.947726750741193, 4.98196748283246, 5.015974481593781, 5.049752469181039, 5.083306010855535, 5.1166395221864125, 5.149757275833494, 5.182663407939976, 5.21536192416212, 5.247856705360771, 5.280151512977635, 5.31224999411737, 5.344155686354956, 5.375872022286245, 5.40740233383831, 5.4387498563548595, 5.469917732470938, 5.500909015790026, 5.531726674375733, 5.562373594069352, 5.592852581643825, 5.62316636780382, 5.653317610041029, 5.683308895353129, 5.713142742834281, 5.742821606144492, 5.772347875864725, 5.801723881744115, 5.830951894845301, 5.860034129593445], [0.0, 0.5916079783099616, 0.8366600265340756, 1.02469507659596, 1.1832159566199232, 1.3228756555322954, 1.449137674618944, 1.5652475842498528, 1.6733200530681511, 1.7748239349298847, 1.8708286933869707, 1.9621416870348585, 2.04939015319192, 2.1330729007701543, 2.2135943621178655, 2.29128784747792, 2.3664319132398464, 2.4392621835300936, 2.5099800796022267, 2.5787593916455256, 2.6457513110645907, 2.711088342345192, 2.7748873851023217, 2.8372521918222215, 2.898275349237888, 2.958039891549808, 3.0166206257996713, 3.0740852297878796, 3.1304951684997055, 3.1859064644147983, 3.2403703492039297, 3.2939338184001206, 3.3466401061363023, 3.398529093593286, 3.449637662132068, 3.5, 3.5496478698597693, 3.5986108430893164, 3.646916505762094, 3.6945906403822333, 3.7416573867739413, 3.7881393849751626, 3.834057902536163, 3.879432948254164, 3.924283374069717, 3.9686269665968856, 4.012480529547776, 4.05585995813465, 4.09878030638384, 4.141255848169731, 4.183300132670378, 4.224926034855522, 4.266145801540309, 4.306971093471606, 4.347413023856832, 4.387482193696061, 4.427188724235731, 4.466542286825459, 4.505552130427525, 4.544227107000705, 4.58257569495584, 4.620606020859168, 4.658325879540846, 4.695742752749559, 4.732863826479693, 4.769696007084728, 4.806245936279166, 4.8425200051213, 4.878524367060187, 4.914264950122246, 4.949747468305833, 4.984977432245807, 5.019960159204453, 5.054700782440045, 5.089204259999788, 5.123475382979799, 5.157518783291051, 5.191338940966964, 5.2249401910452535, 5.2583267300539625, 5.291502622129181, 5.324471804789654, 5.35723809439155, 5.389805191284746, 5.422176684690384, 5.454356057317858, 5.486346689738081, 5.518151864528558, 5.549774770204643, 5.58121850495033, 5.612486080160912, 5.643580423808984, 5.674504383644443, 5.705260730238365, 5.735852159879995, 5.766281297335397, 5.796550698475776, 5.826662852782887, 5.856620185738529, 5.886425061104576, 5.916079783099616, 5.9455865984779], [0.0, 0.6, 0.848528137423857, 1.0392304845413265, 1.2, 1.3416407864998738, 1.469693845669907, 1.5874507866387544, 1.697056274847714, 1.7999999999999998, 1.8973665961010275, 1.98997487421324, 2.078460969082653, 2.1633307652783937, 2.244994432064365, 2.3237900077244498, 2.4, 2.473863375370596, 2.545584412271571, 2.615339366124404, 2.6832815729997477, 2.749545416973504, 2.814249455894058, 2.877498913987632, 2.939387691339814, 3.0, 3.059411708155671, 3.117691453623979, 3.1749015732775088, 3.2310988842807027, 3.2863353450309964, 3.340658617698013, 3.394112549695428, 3.4467375879228173, 3.4985711369071804, 3.5496478698597693, 3.5999999999999996, 3.6496575181789317, 3.698648401781386, 3.746998799039039, 3.794733192202055, 3.8418745424597094, 3.8884444190447165, 3.9344631145812, 3.97994974842648, 4.024922359499621, 4.069397989875161, 4.113392760240626, 4.156921938165306, 4.2, 4.242640687119285, 4.28485705712571, 4.3266615305567875, 4.368065933568311, 4.409081537009721, 4.449719092257398, 4.48998886412873, 4.52990066116245, 4.569463863518345, 4.608687448721165, 4.6475800154488995, 4.686149805543993, 4.724404724407086, 4.762352359916263, 4.8, 4.8373546489791295, 4.874423042781576, 4.91121166312347, 4.947726750741192, 4.983974317750845, 5.019960159204453, 5.0556898639058145, 5.091168824543142, 5.126402247190518, 5.161395160225576, 5.196152422706632, 5.230678732248808, 5.264978632435273, 5.299056519796709, 5.332916650389353, 5.366563145999495, 5.4, 5.43323108288245, 5.466260147486579, 5.499090833947008, 5.531726674375732, 5.5641710972974225, 5.596427431853289, 5.628498911788116, 5.660388679233962, 5.692099788303082, 5.7236352085016735, 5.754997827975264, 5.786190456595773, 5.817215828899595, 5.848076606885377, 5.878775382679628, 5.909314681077663, 5.939696961966999, 5.96992462263972, 6.0, 6.029925372672535], [0.0, 0.608276253029822, 0.8602325267042626, 1.053565375285274, 1.216552506059644, 1.3601470508735445, 1.489966442575134, 1.6093476939431082, 1.7204650534085253, 1.8248287590894658, 1.9235384061671346, 2.017424100183202, 2.107130750570548, 2.193171219946131, 2.2759613353482084, 2.355843797877949, 2.433105012119288, 2.5079872407968904, 2.5806975801127883, 2.651414716712571, 2.720294101747089, 2.787471972953271, 2.8530685235374214, 2.917190429162965, 2.979932885150268, 3.04138126514911, 3.101612483854165, 3.160696125855822, 3.2186953878862163, 3.2756678708318403, 3.331666249791536, 3.38673884437522, 3.4409301068170506, 3.49428104193123, 3.54682957019364, 3.5986108430893164, 3.6496575181789317, 3.7, 3.7496666518505353, 3.7986839826445165, 3.847076812334269, 3.89486841883009, 3.942080668885405, 3.988734135035826, 4.034848200366404, 4.080441152620633, 4.125530268947254, 4.170131892398609, 4.214261501141096, 4.257933771208754, 4.301162633521314, 4.343961325794695, 4.386342439892262, 4.428317965096906, 4.469899327725402, 4.511097427455985, 4.551922670696417, 4.592385001282014, 4.632493928760188, 4.672258554489466, 4.711687595755898, 4.750789408087881, 4.789572005931219, 4.828043081829325, 4.866210024238576, 4.904079934095691, 4.941659640242335, 4.978955713801841, 5.015974481593781, 5.052722038663912, 5.089204259999789, 5.1254268114957995, 5.1613951602255765, 5.197114584074513, 5.232590180780452, 5.26782687642637, 5.302829433425142, 5.3376024580330075, 5.372150407425318, 5.406477596365309, 5.440588203494178, 5.474486277268398, 5.508175741568166, 5.541660400998964, 5.574943945906542, 5.608029957123981, 5.640921910468182, 5.673623181001714, 5.706137047074843, 5.7384666941614295, 5.770615218501404, 5.8025856305616035, 5.83438085832593, 5.866003750424986, 5.897457079114693, 5.928743543112655, 5.959865770300536, 5.990826320300065, 6.021627686929839, 6.052272300549605, 6.08276253029822, 6.113100686231171], [0.0, 0.6164414002968976, 0.8717797887081348, 1.0677078252031313, 1.2328828005937953, 1.3784048752090223, 1.50996688705415, 1.6309506430300091, 1.7435595774162695, 1.849324200890693, 1.949358868961793, 2.0445048300260877, 2.1354156504062627, 2.222611077089287, 2.3065125189341593, 2.3874672772626644, 2.4657656011875906, 2.541653005427767, 2.615339366124404, 2.687005768508881, 2.7568097504180447, 2.824889378365107, 2.891366458960192, 2.956349099818897, 3.0199337741083, 3.0822070014844885, 3.1432467291003428, 3.203123475609394, 3.2619012860600183, 3.3196385345395667, 3.376388603226826, 3.432200460346103, 3.487119154832539, 3.541186241925155, 3.594440151122286, 3.646916505762094, 3.698648401781386, 3.7496666518505353, 3.8000000000000003, 3.8496753109840323, 3.898717737923586, 3.9471508711981107, 3.9949968710876362, 4.042276586281547, 4.0890096600521755, 4.135214625627066, 4.180908992073375, 4.226109321823088, 4.270831300812525, 4.315089802078284, 4.358898943540674, 4.402272140611029, 4.445222154178574, 4.487761134463376, 4.529900661162451, 4.571651780264984, 4.613025037868319, 4.654030511288038, 4.694677837722201, 4.734976240700686, 4.774934554525329, 4.814561246884289, 4.853864439804639, 4.892851929090027, 4.931531202375181, 4.969909455915671, 5.007993610219566, 5.045790324617146, 5.083306010855534, 5.120546845796843, 5.157518783291051, 5.194227565288221, 5.230678732248808, 5.266877632905477, 5.302829433425141, 5.338539126015656, 5.374011537017762, 5.409251334519409, 5.444263035526481, 5.47905101272109, 5.513619500836089, 5.547972602672079, 5.582114294781146, 5.616048432839589, 5.649778756730214, 5.68330889535313, 5.716642371182581, 5.749782604586021, 5.782732917920384, 5.815496539419485, 5.848076606885378, 5.880476171195663, 5.912698199637794, 5.944745579080741, 5.976621118993575, 6.008327554319921, 6.0398675482166, 6.071243694664217, 6.102458520956943, 6.133514490078262, 6.164414002968977, 6.1951594006934165], [0.0, 0.6244997998398399, 0.8831760866327847, 1.081665382639197, 1.2489995996796799, 1.3964240043768943, 1.5297058540778357, 1.6522711641858308, 1.7663521732655694, 1.8734993995195195, 1.97484176581315, 2.0712315177207983, 2.163330765278394, 2.2516660498395407, 2.3366642891095846, 2.4186773244895647, 2.4979991993593598, 2.574878637916747, 2.6495282598983545, 2.7221315177632404, 2.7928480087537886, 2.861817604250837, 2.9291637031753623, 2.994995826374388, 3.0594117081556713, 3.1224989991991996, 3.1843366656181322, 3.244996147917591, 3.3045423283716615, 3.363034344160048, 3.420526275297414, 3.477067730142742, 3.5327043465311387, 3.58747822293042, 3.6414282912066254, 3.6945906403822333, 3.746998799039039, 3.7986839826445165, 3.8496753109840323, 3.900000000000001, 3.9496835316263, 3.9987498046264416, 4.047221268969613, 4.095119045888654, 4.1424630354415966, 4.189272013130682, 4.235563716909475, 4.281354925721529, 4.326661530556788, 4.371498598878879, 4.415880433163924, 4.459820624195553, 4.503332099679081, 4.546427168667723, 4.589117562233507, 4.631414470763765, 4.673328578219169, 4.7148700936505135, 4.756048780237647, 4.796873982084583, 4.8373546489791295, 4.87749935930288, 4.917316341257699, 4.956813492557492, 4.9959983987187195, 5.034878350069642, 5.073460357586329, 5.111751167652823, 5.149757275833494, 5.187484939737176, 5.2249401910452535, 5.262128846769148, 5.299056519796709, 5.335728628781641, 5.372150407425317, 5.408326913195984, 5.444263035526481, 5.479963503528103, 5.515432893255072, 5.550675634551168, 5.585696017507577, 5.620498198558559, 5.655086206239478, 5.68946394662977, 5.723635208501674, 5.757603668193913, 5.791372894228104, 5.8249463516842805, 5.858327406350725, 5.8915193286621745, 5.92452529743945, 5.957348403442593, 5.989991652748776, 6.02245796996542, 6.054750201288242, 6.08687111741328, 6.118823416311343, 6.150609725872713, 6.182232606429493, 6.213694553162394, 6.244997998398399, 6.276145313805283], [0.0, 0.6324555320336759, 0.8944271909999159, 1.0954451150103324, 1.2649110640673518, 1.4142135623730951, 1.5491933384829668, 1.6733200530681511, 1.7888543819998317, 1.8973665961010275, 2.0, 2.0976176963403033, 2.1908902300206647, 2.280350850198276, 2.3664319132398464, 2.449489742783178, 2.5298221281347035, 2.6076809620810595, 2.6832815729997477, 2.7568097504180447, 2.8284271247461903, 2.898275349237888, 2.9664793948382653, 3.0331501776206204, 3.0983866769659336, 3.1622776601683795, 3.22490309931942, 3.286335345030997, 3.3466401061363023, 3.4058772731852804, 3.4641016151377544, 3.521363372331802, 3.5777087639996634, 3.6331804249169903, 3.687817782917155, 3.7416573867739413, 3.794733192202055, 3.847076812334269, 3.898717737923586, 3.9496835316263, 4.0, 4.049691346263318, 4.09878030638384, 4.147288270665544, 4.1952353926806065, 4.242640687119285, 4.2895221179054435, 4.33589667773576, 4.3817804600413295, 4.427188724235731, 4.47213595499958, 4.5166359162544865, 4.560701700396552, 4.604345773288536, 4.6475800154489, 4.69041575982343, 4.732863826479693, 4.774934554525329, 4.8166378315169185, 4.857983120596447, 4.898979485566356, 4.9396356140913875, 4.979959839195493, 5.019960159204453, 5.059644256269407, 5.0990195135927845, 5.138093031466052, 5.176871642217914, 5.215361924162119, 5.253570214625479, 5.291502622129181, 5.329165037789691, 5.366563145999495, 5.403702434442518, 5.440588203494177, 5.477225575051661, 5.513619500836089, 5.549774770204643, 5.585696017507577, 5.621387729022079, 5.656854249492381, 5.692099788303083, 5.727128425310542, 5.761944116355173, 5.796550698475776, 5.830951894845301, 5.865151319446072, 5.8991524815010505, 5.932958789676531, 5.966573556070519, 6.0, 6.0332412515993425, 6.066300355241241, 6.099180272790763, 6.131883886702357, 6.164414002968976, 6.196773353931867, 6.228964600958975, 6.260990336999411, 6.29285308902091, 6.324555320336759, 6.356099432828282], [0.0, 0.6403124237432849, 0.9055385138137417, 1.1090536506409419, 1.2806248474865698, 1.4317821063276355, 1.5684387141358125, 1.6941074346097418, 1.8110770276274835, 1.9209372712298547, 2.024845673131659, 2.1236760581595306, 2.2181073012818837, 2.3086792761230397, 2.395829710142188, 2.479919353527449, 2.5612496949731396, 2.6400757564888173, 2.716615541441225, 2.791057147390573, 2.863564212655271, 2.934280150224242, 3.0033314835362415, 3.0708305065568178, 3.136877428271625, 3.2015621187164247, 3.264965543462902, 3.3271609519228256, 3.3882148692194836, 3.448187929913334, 3.5071355833500366, 3.5651086939951777, 3.622154055254967, 3.678314831549905, 3.733630940518894, 3.7881393849751626, 3.8418745424597094, 3.89486841883009, 3.9471508711981107, 3.9987498046264416, 4.049691346263318, 4.1000000000000005, 4.149698784249287, 4.198809355043403, 4.247352116319061, 4.295346318982906, 4.342810150121693, 4.389760813529594, 4.436214602563767, 4.4821869662029945, 4.527692569068709, 4.572745346069471, 4.617358552246079, 4.661544808322667, 4.705316142407437, 4.748684028233507, 4.791659420284376, 4.8342527861087286, 4.876474136094644, 4.9183330509431755, 4.959838707054898, 5.000999900019996, 5.041825066382213, 5.082322303829225, 5.122499389946279, 5.162363799656123, 5.201922721455982, 5.241183072551464, 5.280151512977635, 5.3188344587888805, 5.35723809439155, 5.395368384086485, 5.43323108288245, 5.470831746635972, 5.508175741568165, 5.545268253204709, 5.582114294781146, 5.61871871515206, 5.655086206239478, 5.691221310052879, 5.727128425310542, 5.762811813689565, 5.798275605729691, 5.833523806414096, 5.868560300448484, 5.903388857258177, 5.93801313572141, 5.9724366886556455, 6.006662967072483, 6.040695324215583, 6.074537019394977, 6.1081912216301815, 6.1416610131136355, 6.174949392505174, 6.208059278067504, 6.24099351065197, 6.27375485654325, 6.306346010171025, 6.338769596696192, 6.3710281744785915, 6.403124237432849, 6.435060217278469], [0.0, 0.6480740698407861, 0.9165151389911681, 1.1224972160321827, 1.2961481396815722, 1.4491376746189442, 1.5874507866387546, 1.7146428199482249, 1.8330302779823362, 1.9442222095223582, 2.04939015319192, 2.149418526020468, 2.2449944320643653, 2.336664289109585, 2.4248711305964283, 2.5099800796022267, 2.5922962793631443, 2.672077843177478, 2.749545416973504, 2.8248893783651075, 2.8982753492378883, 2.9698484809835, 3.039736830714133, 3.108054053584011, 3.174901573277509, 3.2403703492039306, 3.304542328371662, 3.3674916480965478, 3.4292856398964497, 3.48998567332303, 3.5496478698597698, 3.6083237105337433, 3.6660605559646724, 3.7229020937972575, 3.7788887255382373, 3.834057902536163, 3.8884444190447165, 3.942080668885405, 3.9949968710876362, 4.047221268969613, 4.09878030638384, 4.149698784249287, 4.200000000000001, 4.249705872175156, 4.298837052040936, 4.347413023856832, 4.3954521951671826, 4.442971978304612, 4.489988864128731, 4.536518488885503, 4.582575694955841, 4.628174586162455, 4.67332857821917, 4.718050444834181, 4.762352359916264, 4.806245936279167, 4.849742261192857, 4.892851929090027, 4.935585071701227, 4.9779513858614575, 5.019960159204453, 5.061620293937506, 5.10294032886923, 5.143928459844674, 5.184592558726289, 5.224940191045253, 5.264978632435274, 5.304714883949938, 5.344155686354956, 5.383307533477909, 5.422176684690385, 5.46076917659042, 5.499090833947008, 5.537147279962851, 5.574943945906542, 5.612486080160912, 5.649778756730215, 5.686826883245173, 5.723635208501675, 5.760208329565868, 5.796550698475777, 5.832666628567075, 5.868560300448485, 5.904235767650205, 5.939696961967, 5.974947698515863, 6.009991680526689, 6.044832503882966, 6.079473661428266, 6.113918547053109, 6.148170459575759, 6.182232606429493, 6.216108107168022, 6.249799996799899, 6.283311228962004, 6.316644678941503, 6.349803146555018, 6.38278935889318, 6.4156059729381765, 6.448255578061405, 6.480740698407861, 6.5130637951735135], [0.0, 0.6557438524302001, 0.9273618495495702, 1.1357816691600549, 1.3114877048604001, 1.466287829861518, 1.606237840420901, 1.7349351572897471, 1.8547236990991405, 1.9672315572906, 2.073644135332772, 2.1748563170931545, 2.2715633383201097, 2.364318083507378, 2.453568829277059, 2.5396850198400585, 2.6229754097208002, 2.7037011669191546, 2.782085548648711, 2.8583211855912904, 2.932575659723036, 3.004995840263344, 3.0757112998459397, 3.1448370387032774, 3.212475680841802, 3.278719262151, 3.3436506994600976, 3.407345007480164, 3.4698703145794942, 3.531288716601915, 3.5916569992135936, 3.6510272527057364, 3.709447398198281, 3.7669616403674726, 3.823610858861032, 3.879432948254164, 3.9344631145812, 3.988734135035826, 4.042276586281547, 4.095119045888654, 4.147288270665544, 4.198809355043403, 4.249705872175156, 4.299999999999999, 4.349712634186309, 4.398863489584553, 4.447471191587417, 4.495553358597804, 4.543126676640219, 4.5902069670114, 4.636809247747852, 4.682947789587239, 4.728636167014756, 4.773887304912004, 4.818713521262703, 4.863126566315131, 4.907137658554118, 4.950757517794625, 4.993996395673509, 5.03686410378521, 5.079370039680117, 5.121523210920751, 5.163332257370234, 5.204805471869242, 5.2459508194416005, 5.28677595515452, 5.3272882407468805, 5.367494760127856, 5.407402333838309, 5.447017532558529, 5.486346689738081, 5.525395913416522, 5.564171097297422, 5.602677931132575, 5.6409219104681805, 5.678908345800274, 5.716642371182581, 5.754128952326321, 5.791372894228104, 5.8283788483591215, 5.865151319446072, 5.9016946718718, 5.938013135721409, 5.974110812497538, 6.009991680526688, 6.0456596000767355, 6.081118318204308, 6.1163714733492105, 6.151422599691879, 6.186275131288617, 6.220932405998315, 6.255397669213365, 6.289674077406555, 6.323764701504951, 6.357672530100933, 6.3914004725099165, 6.424951361683604, 6.458327956987009, 6.491532946846992, 6.524568951279464, 6.557438524302, 6.590144156238162], [0.0, 0.66332495807108, 0.938083151964686, 1.148912529307606, 1.32664991614216, 1.4832396974191329, 1.6248076809271923, 1.7549928774784245, 1.876166303929372, 1.98997487421324, 2.0976176963403033, 2.2, 2.297825058615212, 2.3916521486202797, 2.4819347291981715, 2.569046515733026, 2.65329983228432, 2.734958866235469, 2.814249455894058, 2.8913664589601926, 2.9664793948382657, 3.039736830714133, 3.1112698372208096, 3.1811947441173736, 3.2496153618543846, 3.3166247903554003, 3.382306905057553, 3.4467375879228177, 3.509985754956849, 3.5721142198983507, 3.63318042491699, 3.693237062523878, 3.752332607858744, 3.8105117766515306, 3.8678159211627436, 3.924283374069717, 3.97994974842648, 4.034848200366404, 4.0890096600521755, 4.1424630354415966, 4.1952353926806065, 4.247352116319061, 4.298837052040936, 4.349712634186309, 4.4, 4.449719092257398, 4.498888751680798, 4.54752680036083, 4.595650117230424, 4.64327470649756, 4.69041575982343, 4.737087712930806, 4.7833042972405595, 4.829078587059855, 4.874423042781577, 4.919349550499538, 4.963869458396343, 5.007993610219566, 5.051732376126036, 5.095095681142799, 5.138093031466052, 5.180733538795447, 5.223025942880239, 5.264978632435274, 5.30659966456864, 5.347896782848375, 5.388877434122993, 5.429548784199292, 5.469917732470938, 5.509990925582365, 5.549774770204644, 5.589275444992849, 5.628498911788116, 5.667450926121902, 5.706137047074843, 5.7445626465380295, 5.782732917920385, 5.8206528843421, 5.858327406350725, 5.895761189193471, 5.9329587896765315, 5.969924622639721, 6.006662967072484, 6.043177971895251, 6.079473661428266, 6.115553940568263, 6.15142259969188, 6.187083319303208, 6.222539674441619, 6.2577951388648065, 6.29285308902091, 6.327716807822551, 6.362389488234747, 6.3968742366877915, 6.431174076325411, 6.465291950097845, 6.499230723708769, 6.532993188424431, 6.566582063752802, 6.600000000000001, 6.6332495807108005, 6.666333324999584], [0.0, 0.6708203932499369, 0.9486832980505137, 1.161895003862225, 1.3416407864998738, 1.5, 1.6431676725154982, 1.7748239349298847, 1.8973665961010273, 2.0124611797498106, 2.1213203435596424, 2.224859546128699, 2.32379000772445, 2.4186773244895647, 2.5099800796022262, 2.5980762113533156, 2.6832815729997477, 2.765863337187866, 2.846049894151541, 2.924038303442689, 3.0, 3.0740852297878796, 3.1464265445104544, 3.2171415884290826, 3.2863353450309964, 3.3541019662496843, 3.420526275297414, 3.4856850115866753, 3.5496478698597693, 3.6124783736376886, 3.674234614174767, 3.7349698793966195, 3.7947331922020546, 3.853569773599539, 3.911521443121589, 3.9686269665968856, 4.024922359499621, 4.080441152620633, 4.135214625627066, 4.189272013130682, 4.242640687119285, 4.295346318982906, 4.347413023856832, 4.398863489584553, 4.449719092257398, 4.499999999999999, 4.54972526643093, 4.598912915026768, 4.6475800154489, 4.695742752749558, 4.743416490252569, 4.790615826801393, 4.8373546489791295, 4.883646178829912, 4.9295030175464944, 4.9749371855331, 5.0199601592044525, 5.064582904840239, 5.10881590977792, 5.1526692111953, 5.196152422706631, 5.239274758971893, 5.282045058497702, 5.324471804789654, 5.366563145999495, 5.4083269131959835, 5.449770637375485, 5.490901565316937, 5.531726674375732, 5.572252686302012, 5.612486080160912, 5.652433104425031, 5.692099788303082, 5.731491952362839, 5.770615218501403, 5.809475019311125, 5.848076606885378, 5.886425061104575, 5.92452529743945, 5.962382074305537, 6.0, 6.037383539249432, 6.074537019394977, 6.111464636239008, 6.148170459575759, 6.18465843842649, 6.220932405998316, 6.256996084384263, 6.292853089020909, 6.328506932918695, 6.363961030678928, 6.399218702310462, 6.434283176858165, 6.469157595854347, 6.5038450166036395, 6.53834841531101, 6.572670690061993, 6.606814663663572, 6.640783086353596, 6.674578638386096, 6.7082039324993685, 6.74166151627327], [0.0, 0.6782329983125268, 0.9591663046625439, 1.1747340124470733, 1.3564659966250536, 1.5165750888103102, 1.661324772583615, 1.7944358444926363, 1.9183326093250879, 2.0346989949375804, 2.1447610589527217, 2.249444375840399, 2.3494680248941466, 2.445403852127497, 2.5377155080899043, 2.626785107312739, 2.7129319932501073, 2.7964262908219126, 2.877498913987632, 2.956349099818897, 3.0331501776206204, 3.108054053584011, 3.1811947441173736, 3.252691193458119, 3.32264954516723, 3.3911649915626345, 3.458323293158117, 3.5242020373412197, 3.5888716889852725, 3.6523964735499352, 3.714835124201342, 3.7762415176998414, 3.8366652186501757, 3.896151947755632, 3.954743986657038, 4.012480529547776, 4.069397989875161, 4.125530268947254, 4.180908992073375, 4.235563716909475, 4.2895221179054435, 4.342810150121693, 4.3954521951671826, 4.447471191587417, 4.498888751680798, 4.54972526643093, 4.6000000000000005, 4.649731175025068, 4.698936049788293, 4.747630988187688, 4.79583152331272, 4.843552415324934, 4.890807704254994, 4.937610758251404, 4.983974317750845, 5.029910535983717, 5.075431016179809, 5.120546845796843, 5.165268628057984, 5.209606511052442, 5.253570214625478, 5.297169055259611, 5.340411969127476, 5.383307533477908, 5.4258639865002145, 5.468089245796926, 5.509990925582365, 5.551576352712804, 5.592852581643825, 5.63382640840131, 5.674504383644443, 5.71489282489182, 5.754997827975264, 5.794825277780168, 5.834380858325929, 5.873670062235366, 5.912698199637794, 5.951470406546605, 5.989991652748776, 6.028266749240615, 6.066300355241241, 6.104096984812742, 6.1416610131136355, 6.178996682310163, 6.216108107168022, 6.252999280345393, 6.289674077406556, 6.326136261573884, 6.362389488234747, 6.398437309218556, 6.434283176858165, 6.469930447848725, 6.505382386916238, 6.540642170307134, 6.57571288910944, 6.6105975524153635, 6.64529909033446, 6.679820356865895, 6.714164132637808, 6.748333127521196, 6.782329983125269, 6.81615727518079], [0.0, 0.6855654600401044, 0.9695359714832658, 1.187434208703792, 1.3711309200802089, 1.5329709716755893, 1.6792855623746665, 1.8138357147217055, 1.9390719429665315, 2.056696380120313, 2.16794833886788, 2.273763400180415, 2.374868417407584, 2.471841418861655, 2.565151067676132, 2.6551836094703507, 2.7422618401604177, 2.826658805020514, 2.9086079144497976, 2.9883105594967874, 3.0659419433511785, 3.1416556144810017, 3.2155870381627056, 3.2878564445547194, 3.358571124749333, 3.4278273002005224, 3.4957116585897072, 3.5623026261113755, 3.627671429443411, 3.691882988394947, 3.7549966711037173, 3.817066936798463, 3.878143885933063, 3.9382737335030438, 3.997499218261337, 4.05585995813465, 4.113392760240626, 4.170131892398609, 4.226109321823088, 4.281354925721529, 4.33589667773576, 4.389760813529594, 4.442971978304612, 4.495553358597804, 4.54752680036083, 4.598912915026768, 4.649731175025068, 4.7, 4.749736834815168, 4.798958220280731, 4.847679857416329, 4.89591666595746, 4.94368283772331, 4.990991885387113, 5.037856687124, 5.084289527554465, 5.130302135352264, 5.175905717843014, 5.221110992882646, 5.265928218272634, 5.310367218940701, 5.354437412091022, 5.3981478305063115, 5.441507144165117, 5.4845236803208355, 5.527205442174191, 5.569560126257728, 5.61159513863928, 5.653317610041028, 5.69473440996154, 5.735852159879995, 5.776677245614472, 5.817215828899595, 5.857473858242988, 5.897457079114692, 5.937171043518958, 5.976621118993575, 6.015812497078014, 6.054750201288242, 6.09343909463285, 6.131883886702357, 6.17008914036094, 6.208059278067503, 6.245798587850876, 6.2833112289620034, 6.320601237224193, 6.357672530100934, 6.394528911499267, 6.431174076325411, 6.4676116148080505, 6.5038450166036395, 6.539877674696982, 6.575712889109439, 6.611353870426239, 6.646803743153547, 6.682065548915245, 6.717142249498666, 6.7520367297579185, 6.786751800382861, 6.821290200541244, 6.855654600401045, 6.889847603539574], [0.0, 0.692820323027551, 0.9797958971132713, 1.2000000000000004, 1.385640646055102, 1.549193338482967, 1.6970562748477143, 1.8330302779823362, 1.9595917942265426, 2.078460969082653, 2.1908902300206647, 2.297825058615212, 2.400000000000001, 2.4979991993593598, 2.5922962793631443, 2.6832815729997477, 2.771281292110204, 2.8565713714171403, 2.9393876913398143, 3.0199337741083006, 3.098386676965934, 3.174901573277509, 3.2496153618543846, 3.3226495451672307, 3.3941125496954285, 3.4641016151377553, 3.5327043465311396, 3.6000000000000005, 3.6660605559646724, 3.7309516212355267, 3.7947331922020555, 3.8574603043971827, 3.9191835884530852, 3.9799497484264807, 4.039801975344832, 4.09878030638384, 4.156921938165306, 4.214261501141096, 4.270831300812525, 4.326661530556788, 4.3817804600413295, 4.436214602563767, 4.489988864128731, 4.543126676640219, 4.595650117230424, 4.6475800154489, 4.698936049788293, 4.749736834815168, 4.800000000000002, 4.849742261192857, 4.898979485566357, 4.947726750741194, 4.9959983987187195, 5.043808085167398, 5.091168824543143, 5.1380930314660525, 5.184592558726289, 5.230678732248809, 5.276362383309169, 5.321653878260029, 5.366563145999495, 5.411099703387474, 5.455272678794342, 5.499090833947009, 5.542562584220408, 5.585696017507577, 5.628498911788117, 5.670978751503131, 5.713142742834281, 5.754997827975265, 5.796550698475777, 5.83780780773057, 5.8787753826796285, 5.9194594347794975, 5.959865770300536, 6.000000000000001, 6.039867548216601, 6.079473661428266, 6.1188234163113435, 6.157921727336262, 6.196773353931868, 6.235382907247959, 6.27375485654325, 6.311893535223801, 6.349803146555018, 6.387487769068526, 6.424951361683605, 6.462197768561406, 6.499230723708769, 6.536053855347277, 6.572670690061994, 6.609084656743323, 6.645299090334461, 6.681317235396028, 6.717142249498667, 6.752777206453653, 6.788225099390857, 6.823488843692794, 6.8585712797928995, 6.893475175845635, 6.9282032302755105, 6.962758074211686], [0.0, 0.7000000000000001, 0.9899494936611665, 1.2124355652982142, 1.4000000000000001, 1.565247584249853, 1.7146428199482247, 1.8520259177452134, 1.979898987322333, 2.1, 2.2135943621178655, 2.32163735324878, 2.4248711305964283, 2.5238858928247927, 2.619160170741759, 2.7110883423451915, 2.8000000000000003, 2.8861739379323623, 2.9698484809834995, 3.051229260478472, 3.130495168499706, 3.2078029864690882, 3.283291031876401, 3.357082066318904, 3.4292856398964493, 3.5, 3.5693136595149495, 3.6373066958946425, 3.704051835490427, 3.769615364994153, 3.8340579025361627, 3.8974350539810154, 3.959797974644666, 4.02119385257662, 4.08166632639171, 4.141255848169731, 4.2, 4.257933771208754, 4.315089802078284, 4.371498598878879, 4.427188724235731, 4.4821869662029945, 4.536518488885503, 4.5902069670114, 4.64327470649756, 4.695742752749558, 4.747630988187688, 4.798958220280731, 4.849742261192857, 4.9, 4.949747468305833, 4.998999899979996, 5.047771785649585, 5.096076922496363, 5.143928459844674, 5.191338940966964, 5.238320341483518, 5.2848841046895245, 5.331041174104736, 5.376802023508025, 5.422176684690383, 5.467174773134658, 5.511805511808268, 5.55607775323564, 5.6000000000000005, 5.643580423808984, 5.686826883245172, 5.729746940310715, 5.772347875864725, 5.814636704042653, 5.856620185738529, 5.898304841223451, 5.939696961966999, 5.980802621722272, 6.021627686929839, 6.06217782649107, 6.102458520956944, 6.142475071174486, 6.182232606429493, 6.221736092120913, 6.260990336999412, 6.300000000000001, 6.338769596696192, 6.377303505401009, 6.4156059729381765, 6.4536811201050215, 6.491532946846993, 6.529165337162171, 6.566582063752802, 6.603786792439623, 6.640783086353597, 6.67757440991862, 6.714164132637808, 6.750555532695069, 6.786751800382861, 6.822756041366274, 6.858571279792899, 6.894200461257274, 6.929646455628165, 6.96491205974634, 7.0, 7.034912934784624], [0.0, 0.7071067811865476, 1.0, 1.2247448713915892, 1.4142135623730951, 1.5811388300841898, 1.7320508075688774, 1.8708286933869709, 2.0, 2.1213203435596424, 2.23606797749979, 2.345207879911715, 2.4494897427831783, 2.5495097567963927, 2.6457513110645907, 2.7386127875258306, 2.8284271247461903, 2.9154759474226504, 3.0, 3.082207001484489, 3.1622776601683795, 3.2403703492039306, 3.3166247903554003, 3.3911649915626345, 3.464101615137755, 3.535533905932738, 3.6055512754639896, 3.6742346141747677, 3.7416573867739418, 3.8078865529319548, 3.872983346207417, 3.9370039370059056, 4.0, 4.06201920231798, 4.123105625617661, 4.183300132670378, 4.242640687119285, 4.301162633521314, 4.358898943540674, 4.415880433163924, 4.47213595499958, 4.527692569068709, 4.582575694955841, 4.636809247747852, 4.69041575982343, 4.743416490252569, 4.79583152331272, 4.847679857416329, 4.898979485566357, 4.949747468305833, 5.000000000000001, 5.04975246918104, 5.099019513592785, 5.147815070493501, 5.196152422706632, 5.244044240850759, 5.291502622129181, 5.338539126015656, 5.385164807134505, 5.431390245600108, 5.477225575051661, 5.522680508593631, 5.5677643628300215, 5.612486080160912, 5.656854249492381, 5.70087712549569, 5.744562646538029, 5.787918451395113, 5.830951894845301, 5.873670062235366, 5.916079783099617, 5.958187643906493, 6.0, 6.041522986797286, 6.082762530298219, 6.123724356957946, 6.164414002968978, 6.2048368229954285, 6.244997998398399, 6.284902544988268, 6.324555320336759, 6.3639610306789285, 6.403124237432849, 6.442049363362563, 6.480740698407861, 6.519202405202649, 6.557438524302001, 6.59545297913646, 6.6332495807108005, 6.670832032063167, 6.708203932499369, 6.745368781616021, 6.782329983125269, 6.8190908484929285, 6.855654600401045, 6.892024376045111, 6.92820323027551, 6.9641941385920605, 7.0, 7.035623639735145, 7.071067811865476, 7.1063352017759485], [0.0, 0.7141428428542851, 1.0099504938362078, 1.2369316876852985, 1.4282856857085702, 1.5968719422671316, 1.7492855684535904, 1.8894443627691186, 2.0199009876724157, 2.142428528562855, 2.2583179581272432, 2.368543856465403, 2.473863375370597, 2.574878637916747, 2.672077843177478, 2.765863337187866, 2.8565713714171403, 2.944486372867092, 3.029851481508624, 3.1128764832546767, 3.193743884534263, 3.272613634390715, 3.3496268448888458, 3.4249087579087423, 3.498571136907181, 3.5707142142714257, 3.6414282912066254, 3.7107950630558952, 3.7788887255382373, 3.845776904605883, 3.9115214431215892, 3.9761790704142093, 4.039801975344831, 4.102438299353204, 4.164132562731403, 4.224926034855522, 4.28485705712571, 4.343961325794695, 4.402272140611029, 4.459820624195553, 4.5166359162544865, 4.572745346069471, 4.628174586162455, 4.682947789587239, 4.737087712930806, 4.790615826801393, 4.843552415324934, 4.89591666595746, 4.947726750741194, 4.998999899979996, 5.04975246918104, 5.100000000000001, 5.149757275833494, 5.199038372622384, 5.247856705360771, 5.296225070746145, 5.344155686354956, 5.391660226683429, 5.43874985635486, 5.485435260760991, 5.531726674375732, 5.577633906953737, 5.62316636780382, 5.668333088307356, 5.713142742834281, 5.757603668193913, 5.801723881744115, 5.845511098270194, 5.888972745734184, 5.932115979985557, 5.974947698515863, 6.017474553332154, 6.059702963017248, 6.101639124038721, 6.143289021363068, 6.184658438426491, 6.225752966509353, 6.266578013557321, 6.307138812488593, 6.347440429023341, 6.387487769068526, 6.427285585688566, 6.466838485689898, 6.506150935845249, 6.54522726878143, 6.584071688552609, 6.62268827591938, 6.661080993352356, 6.6992536897776915, 6.73721010508059, 6.77495387438173, 6.81248853210044, 6.8498175158174845, 6.886944169949399, 6.923871749245506, 6.960603422117942, 6.997142273814362, 7.033491309442276, 7.069653456853455, 7.105631569396208, 7.141428428542851, 7.177046746399247], [0.0, 0.7211102550927979, 1.019803902718557, 1.2489995996796799, 1.4422205101855958, 1.61245154965971, 1.7663521732655696, 1.9078784028338915, 2.039607805437114, 2.1633307652783937, 2.280350850198276, 2.3916521486202797, 2.4979991993593598, 2.6000000000000005, 2.6981475126464085, 2.792848008753788, 2.8844410203711917, 2.973213749463701, 3.0594117081556713, 3.1432467291003428, 3.22490309931942, 3.3045423283716615, 3.3823069050575527, 3.458323293158117, 3.532704346531139, 3.6055512754639896, 3.6769552621700474, 3.7469987990390394, 3.815756805667783, 3.88329756778952, 3.9496835316262997, 4.014971979976947, 4.079215610874228, 4.1424630354415966, 4.204759208325728, 4.266145801540309, 4.3266615305567875, 4.386342439892262, 4.445222154178574, 4.503332099679081, 4.560701700396552, 4.617358552246079, 4.67332857821917, 4.728636167014756, 4.7833042972405595, 4.8373546489791295, 4.890807704254994, 4.94368283772331, 4.9959983987187195, 5.047771785649585, 5.099019513592785, 5.149757275833494, 5.200000000000001, 5.249761899362676, 5.299056519796709, 5.347896782848376, 5.396295025292817, 5.44426303552648, 5.491812087098393, 5.5389529696504916, 5.585696017507576, 5.63205113613149, 5.678027826631356, 5.723635208501674, 5.768882040742383, 5.813776741499453, 5.858327406350725, 5.902541825349482, 5.946427498927402, 5.989991652748776, 6.033241251599343, 6.076183012385325, 6.118823416311343, 6.161168720299745, 6.203224967708329, 6.244997998398398, 6.2864934582006855, 6.327716807822551, 6.3686733312362644, 6.409368143584826, 6.44980619863884, 6.489992295835181, 6.529931086925804, 6.569627082262737, 6.609084656743323, 6.648308055437865, 6.687301398920196, 6.726068688320096, 6.764613810115105, 6.802940540677979, 6.841052550594828, 6.878953408767936, 6.916646586316234, 6.954135460285485, 6.9914233171794145, 7.0285133563222315, 7.065408693062278, 7.102112361825883, 7.138627319029899, 7.17495644586084, 7.211102550927979, 7.247068372797377], [0.0, 0.7280109889280519, 1.0295630140987002, 1.2609520212918495, 1.4560219778561039, 1.627882059609971, 1.7832554500127011, 1.9261360284258224, 2.0591260281974004, 2.1840329667841556, 2.302172886644268, 2.4145392935299275, 2.521904042583699, 2.624880949681338, 2.7239676943752476, 2.819574435974337, 2.9120439557122078, 3.001666203960727, 3.0886890422961004, 3.1733263305244868, 3.255764119219942, 3.336165463522456, 3.414674215792775, 3.491418050019219, 3.5665109000254023, 3.64005494464026, 3.712142238654118, 3.782856063875548, 3.852272056851645, 3.9204591567825324, 3.9874804074753776, 4.053393639902249, 4.118252056394801, 4.182104733265298, 4.244997055358225, 4.306971093471606, 4.368065933568311, 4.428317965096906, 4.487761134463376, 4.546427168667723, 4.604345773288536, 4.661544808322667, 4.718050444834181, 4.773887304912004, 4.829078587059855, 4.883646178829912, 4.937610758251404, 4.990991885387113, 5.043808085167398, 5.096076922496363, 5.147815070493501, 5.199038372622384, 5.249761899362676, 5.300000000000001, 5.349766350038103, 5.399073994677236, 5.447935388750495, 5.496362433464519, 5.5443665102516455, 5.591958512006326, 5.639148871948674, 5.6859475903318, 5.732364259186606, 5.7784080852774675, 5.8240879114244155, 5.869412236331676, 5.914389233048499, 5.959026766175833, 6.003332407921454, 6.047313453096343, 6.090976933136425, 6.134329629226001, 6.177378084592201, 6.220128616033596, 6.262587324740471, 6.304760106459247, 6.3466526610489735, 6.388270501473776, 6.429618962271405, 6.470703207534712, 6.511528238439884, 6.552098900352467, 6.592419889539805, 6.632495759516172, 6.672330927044912, 6.711929677819935, 6.751296171847301, 6.790434448545985, 6.82934843158555, 6.868041933477111, 6.906518659932804, 6.944782214007867, 6.982836100038438, 7.020683727387242, 7.058328414008519, 7.095773389842717, 7.1330218000508046, 7.170076708097342, 7.206941098690901, 7.243617880589783, 7.28010988928052, 7.31641988953614], [0.0, 0.7348469228349535, 1.0392304845413265, 1.2727922061357857, 1.469693845669907, 1.6431676725154984, 1.8, 1.9442222095223582, 2.078460969082653, 2.2045407685048604, 2.32379000772445, 2.4372115213907883, 2.5455844122715714, 2.6495282598983545, 2.749545416973504, 2.846049894151541, 2.939387691339814, 3.0298514815086235, 3.1176914536239795, 3.203123475609394, 3.286335345030997, 3.3674916480965478, 3.4467375879228173, 3.5242020373412197, 3.6, 3.6742346141747677, 3.7469987990390394, 3.818376618407357, 3.8884444190447165, 3.957271787481876, 4.024922359499621, 4.091454509095757, 4.156921938165306, 4.221374183841087, 4.28485705712571, 4.347413023856832, 4.409081537009721, 4.469899327725402, 4.529900661162451, 4.589117562233507, 4.6475800154489, 4.705316142407437, 4.762352359916264, 4.818713521262703, 4.874423042781577, 4.9295030175464944, 4.983974317750845, 5.037856687124, 5.091168824543143, 5.143928459844674, 5.196152422706632, 5.247856705360771, 5.299056519796709, 5.349766350038103, 5.4, 5.449770637375486, 5.499090833947008, 5.547972602672079, 5.596427431853289, 5.644466316668034, 5.692099788303082, 5.739337940912697, 5.786190456595773, 5.8326666285670745, 5.878775382679628, 5.924525297439449, 5.96992462263972, 6.014981296729027, 6.059702963017247, 6.104096984812742, 6.148170459575759, 6.191930232165088, 6.235382907247959, 6.278534860936905, 6.321392251711643, 6.363961030678928, 6.406246951218788, 6.448255578061404, 6.489992295835182, 6.5314623171231725, 6.572670690061994, 6.613622305514581, 6.654321903845651, 6.694774081326419, 6.7349832961930955, 6.77495387438173, 6.814690014960329, 6.854195795277518, 6.8934751758456345, 6.932532004974806, 6.971370023173351, 7.009992867328754, 7.0484040746824395, 7.0866070866106305, 7.124605252222751, 7.162401831787993, 7.2, 7.237402849088892, 7.274613391789285, 7.3116345641723655, 7.348469228349535, 7.385120175054704], [0.0, 0.7416198487095663, 1.0488088481701516, 1.2845232578665131, 1.4832396974191326, 1.6583123951777001, 1.8165902124584952, 1.9621416870348585, 2.0976176963403033, 2.224859546128699, 2.345207879911715, 2.459674775249769, 2.5690465157330262, 2.673948391424188, 2.7748873851023217, 2.8722813232690143, 2.9664793948382653, 3.0577769702841313, 3.146426544510455, 3.232645975048923, 3.3166247903554003, 3.398529093593286, 3.4785054261852175, 3.5566838487557484, 3.6331804249169903, 3.708099243547832, 3.7815340802378077, 3.853569773599539, 3.924283374069717, 3.993745109543172, 4.06201920231798, 4.129164564412516, 4.1952353926806065, 4.260281680828159, 4.324349662087931, 4.387482193696061, 4.449719092257398, 4.511097427455985, 4.571651780264984, 4.631414470763765, 4.69041575982343, 4.748684028233507, 4.806245936279167, 4.863126566315131, 4.919349550499538, 4.9749371855331, 5.029910535983717, 5.084289527554465, 5.1380930314660525, 5.191338940966964, 5.244044240850759, 5.296225070746145, 5.347896782848376, 5.399073994677236, 5.449770637375486, 5.5, 5.549774770204643, 5.599107071667768, 5.648008498577176, 5.6964901474504455, 5.744562646538029, 5.792236183029832, 5.839520528262573, 5.886425061104576, 5.932958789676531, 5.979130371550699, 6.024948132556827, 6.070420084310475, 6.115553940568263, 6.1603571325045765, 6.2048368229954285, 6.248999919987198, 6.29285308902091, 6.336402764976356, 6.3796551630946325, 6.422616289332565, 6.465291950097846, 6.507687761409578, 6.549809157525127, 6.591661399070799, 6.6332495807108005, 6.674578638386097, 6.715653356152327, 6.756478372643548, 6.797058187186572, 6.837397165588672, 6.87749954561976, 6.917369442208505, 6.957010852370435, 6.996427659884722, 7.035623639735144, 7.074602462329597, 7.113367697511497, 7.15192281837549, 7.1902712048990205, 7.2284161474004796, 7.266360849833981, 7.30410843293006, 7.341661937191061, 7.379024325749307, 7.416198487095664, 7.4531872376856345], [0.0, 0.7483314773547883, 1.058300524425836, 1.2961481396815722, 1.4966629547095767, 1.6733200530681511, 1.833030277982336, 1.9798989873223332, 2.116601048851672, 2.244994432064365, 2.3664319132398464, 2.4819347291981715, 2.5922962793631443, 2.6981475126464085, 2.8, 2.8982753492378874, 2.9933259094191533, 3.0854497241083023, 3.1749015732775088, 3.2619012860600183, 3.3466401061363023, 3.4292856398964493, 3.509985754956849, 3.5888716889852725, 3.666060555964672, 3.7416573867739413, 3.8157568056677826, 3.8884444190447165, 3.9597979746446663, 4.029888335921977, 4.098780306383839, 4.166533331199932, 4.233202097703344, 4.298837052040936, 4.363484845854286, 4.427188724235731, 4.48998886412873, 4.551922670696417, 4.613025037868319, 4.673328578219169, 4.732863826479693, 4.791659420284376, 4.849742261192857, 4.907137658554118, 4.963869458396343, 5.0199601592044525, 5.075431016179809, 5.130302135352264, 5.184592558726289, 5.238320341483518, 5.291502622129181, 5.344155686354956, 5.396295025292817, 5.447935388750495, 5.499090833947008, 5.549774770204643, 5.6, 5.649778756730214, 5.6991227395100035, 5.748043145279965, 5.796550698475775, 5.844655678480983, 5.892367945062493, 5.939696961966999, 5.986651818838307, 6.033241251599342, 6.079473661428265, 6.125357132445422, 6.170899448216605, 6.216108107168021, 6.260990336999411, 6.305553108173778, 6.3498031465550175, 6.393746945258312, 6.437390775772432, 6.48074069840786, 6.523802572120037, 6.566582063752802, 6.609084656743323, 6.6513156593263565, 6.6932802122726045, 6.734983296193095, 6.776429738438967, 6.817624219623724, 6.858571279792899, 6.899275324264136, 6.939740629158989, 6.979971346646059, 7.019971509913698, 7.059745037889116, 7.099295739719539, 7.138627319029899, 7.177743377970545, 7.216647421067487, 7.255342858886822, 7.293833011524187, 7.332121111929344, 7.370210309075312, 7.408103670980854, 7.445804187594514, 7.483314773547883, 7.520638270785267], [0.0, 0.754983443527075, 1.0677078252031311, 1.3076696830622023, 1.50996688705415, 1.6881943016134133, 1.849324200890693, 1.997498435543818, 2.1354156504062622, 2.264950330581225, 2.3874672772626644, 2.503996805109783, 2.6153393661244047, 2.72213151776324, 2.824889378365107, 2.924038303442689, 3.0199337741083, 3.1128764832546763, 3.2031234756093934, 3.290896534380867, 3.3763886032268267, 3.459768778401239, 3.5411862419251547, 3.620773398046335, 3.698648401781386, 3.774917217635375, 3.849675310984032, 3.9230090491866063, 3.994996871087636, 4.065710270051224, 4.135214625627066, 4.20356991139674, 4.2708313008125245, 4.337049688440288, 4.402272140611028, 4.466542286825459, 4.52990066116245, 4.592385001282014, 4.654030511288038, 4.7148700936505135, 4.774934554525329, 4.8342527861087286, 4.892851929090027, 4.950757517794625, 5.007993610219566, 5.064582904840239, 5.120546845796843, 5.175905717843014, 5.230678732248809, 5.2848841046895245, 5.338539126015656, 5.391660226683429, 5.44426303552648, 5.496362433464519, 5.547972602672079, 5.599107071667768, 5.649778756730214, 5.7, 5.749782604586021, 5.799137866959191, 5.848076606885378, 5.8966091951222275, 5.944745579080739, 5.9924953066314535, 6.0398675482166, 6.08687111741328, 6.133514490078261, 6.17980582219215, 6.2257529665093525, 6.271363488110062, 6.316644678941503, 6.361603571427569, 6.406246951218787, 6.450581369148055, 6.494613152451807, 6.5383484153110105, 6.581793068761734, 6.624952830020755, 6.667833231267862, 6.710439627923047, 6.752777206453653, 6.794850991743675, 6.836665854054885, 6.878226515607057, 6.919537556802478, 6.960603422117942, 7.001428425685718, 7.042016756583302, 7.0823724838503095, 7.122499561249548, 7.162401831787993, 7.202083032012336, 7.24154679609267, 7.280796659706959, 7.31983606373804, 7.358668357794092, 7.397296803562772, 7.4357245780085215, 7.473954776421918, 7.5119904153293495, 7.54983443527075, 7.587489703452652], [0.0, 0.7615773105863909, 1.0770329614269007, 1.3190905958272923, 1.5231546211727818, 1.7029386365926404, 1.8654758106177631, 2.0149441679609885, 2.1540659228538015, 2.2847319317591723, 2.4083189157584592, 2.525866188063018, 2.6381811916545845, 2.7459060435491964, 2.8495613697550017, 2.9495762407505253, 3.0463092423455636, 3.1400636936215167, 3.2310988842807027, 3.319638534539567, 3.405877273185281, 3.48998567332303, 3.5721142198983507, 3.6523964735499352, 3.7309516212355263, 3.8078865529319548, 3.8832975677895205, 3.957271787481876, 4.029888335921977, 4.101219330881976, 4.171330722922842, 4.240283009422838, 4.308131845707603, 4.374928570845472, 4.440720662234904, 4.505552130427525, 4.569463863518345, 4.632493928760188, 4.694677837722201, 4.756048780237647, 4.8166378315169185, 4.876474136094644, 4.935585071701227, 4.993996395673509, 5.051732376126036, 5.10881590977792, 5.165268628057984, 5.221110992882646, 5.276362383309169, 5.331041174104736, 5.385164807134505, 5.43874985635486, 5.491812087098393, 5.5443665102516455, 5.596427431853289, 5.648008498577176, 5.6991227395100035, 5.749782604586021, 5.800000000000001, 5.849786320883866, 5.8991524815010505, 5.948108943185221, 5.99666574022598, 6.044832503882966, 6.092618484691127, 6.1400325732035, 6.187083319303208, 6.23377895020348, 6.280127387243033, 6.326136261573885, 6.3718129288295975, 6.417164482853779, 6.462197768561405, 6.5069193939989765, 6.55133574166368, 6.59545297913646, 6.639277069079134, 6.682813778641449, 6.726068688320096, 6.76904720030818, 6.811754546370562, 6.854195795277518, 6.8963758598266685, 6.938299503480662, 6.97997134664606, 7.021395872616784, 7.062577433203831, 7.103520254071217, 7.144228439796701, 7.184705978674423, 7.224956747275378, 7.264984514780469, 7.3047929470998705, 7.3443856107914165, 7.383765976789894, 7.4229374239582535, 7.4619032424710525, 7.5006666370396715, 7.539230729988306, 7.577598564189055, 7.6157731058639095, 7.653757247260983], [0.0, 0.7681145747868608, 1.0862780491200215, 1.3304134695650072, 1.5362291495737217, 1.7175564037317668, 1.8814887722226779, 2.0322401432901573, 2.172556098240043, 2.3043437243605824, 2.4289915602982237, 2.5475478405713994, 2.6608269391300143, 2.7694764848252458, 2.8740215726399825, 2.974894956128703, 3.0724582991474434, 3.167017524422623, 3.2588341473600644, 3.3481338085566414, 3.4351128074635335, 3.5199431813596083, 3.602776706930364, 3.6837480912787726, 3.7629775444453557, 3.840572873934304, 3.916631205513228, 3.9912404086950213, 4.064480286580315, 4.136423575989287, 4.207136793592525, 4.276680956068619, 4.345112196480086, 4.412482294582042, 4.4788391353117385, 4.544227107000705, 4.608687448721165, 4.672258554489466, 4.734976240700686, 4.796873982084583, 4.857983120596447, 4.9183330509431755, 4.9779513858614575, 5.03686410378521, 5.095095681142799, 5.1526692111953, 5.209606511052442, 5.265928218272634, 5.321653878260029, 5.376802023508025, 5.431390245600108, 5.485435260760991, 5.5389529696504916, 5.591958512006326, 5.644466316668034, 5.6964901474504455, 5.748043145279965, 5.799137866959191, 5.849786320883866, 5.8999999999999995, 5.949789912257406, 5.999166608788257, 6.048140210014975, 6.096720429870472, 6.144916598294887, 6.192737682156413, 6.240192304729077, 6.287288763847259, 6.334035048845246, 6.380438856379708, 6.4265076052238514, 6.472248450113762, 6.517668294720129, 6.562773803811921, 6.607571414672716, 6.652067347825035, 6.696267617113283, 6.740178039191546, 6.783804242458652, 6.827151675479314, 6.870225614927067, 6.913031173081747, 6.955573304911681, 6.997856814768361, 7.0398863627192165, 7.0816664705420855, 7.123201527403251, 7.164495795239188, 7.205553413860728, 7.246378405796926, 7.286974680894671, 7.327346040688948, 7.367496182557545, 7.407428703673091, 7.447147104764348, 7.486654793697916, 7.525955088890711, 7.565051222562872, 7.603946343840151, 7.642643521714199, 7.681145747868608, 7.719455939378112], [0.0, 0.7745966692414833, 1.0954451150103321, 1.3416407864998738, 1.5491933384829666, 1.7320508075688772, 1.8973665961010275, 2.0493901531919194, 2.1908902300206643, 2.3237900077244498, 2.449489742783178, 2.569046515733026, 2.6832815729997477, 2.792848008753788, 2.8982753492378874, 2.9999999999999996, 3.098386676965933, 3.1937438845342623, 3.2863353450309964, 3.3763886032268267, 3.4641016151377544, 3.5496478698597693, 3.63318042491699, 3.714835124201342, 3.794733192202055, 3.8729833462074166, 3.9496835316262997, 4.024922359499621, 4.098780306383839, 4.171330722922842, 4.242640687119285, 4.3127717305695645, 4.381780460041329, 4.449719092257398, 4.516635916254486, 4.58257569495584, 4.6475800154488995, 4.711687595755898, 4.774934554525329, 4.8373546489791295, 4.898979485566356, 4.959838707054898, 5.019960159204453, 5.079370039680117, 5.138093031466052, 5.196152422706631, 5.253570214625478, 5.310367218940701, 5.366563145999495, 5.422176684690383, 5.477225575051661, 5.531726674375732, 5.585696017507576, 5.639148871948674, 5.692099788303082, 5.744562646538029, 5.796550698475775, 5.848076606885378, 5.8991524815010505, 5.949789912257406, 5.999999999999999, 6.049793384901669, 6.099180272790762, 6.148170459575758, 6.196773353931866, 6.244997998398397, 6.292853089020909, 6.340346993658943, 6.387487769068525, 6.434283176858164, 6.48074069840786, 6.526867548832287, 6.572670690061993, 6.618156843109718, 6.663332499583071, 6.7082039324993685, 6.752777206453653, 6.797058187186571, 6.841052550594828, 6.884765791223402, 6.928203230275509, 6.97137002317335, 7.014271166700073, 7.056911505750939, 7.099295739719539, 7.1414284285428495, 7.183313998427188, 7.224956747275377, 7.26636084983398, 7.307530362578043, 7.348469228349534, 7.389181280764466, 7.429670248402684, 7.469939758793239, 7.5099933422074345, 7.549834435270749, 7.58946638440411, 7.628892449104261, 7.668115805072325, 7.707139547199078, 7.745966692414833, 7.784600182411426], [0.0, 0.7810249675906654, 1.104536101718726, 1.3527749258468684, 1.5620499351813308, 1.746424919657298, 1.9131126469708992, 2.0663978319771825, 2.209072203437452, 2.3430749027719964, 2.4698178070456938, 2.5903667693977237, 2.705549851693737, 2.816025568065745, 2.9223278392404914, 3.0248966924508345, 3.1240998703626617, 3.2202484376209237, 3.3136083051561784, 3.4044089061098406, 3.492849839314596, 3.5791060336346563, 3.6633318168028404, 3.745664160065609, 3.8262252939417984, 3.9051248379533274, 3.9824615503479754, 4.058324777540605, 4.132795663954365, 4.205948168962618, 4.277849927241487, 4.34856298103178, 4.418144406874904, 4.486646854834912, 4.5541190146942805, 4.620606020859168, 4.686149805543993, 4.750789408087881, 4.814561246884289, 4.87749935930288, 4.9396356140913875, 5.000999900019996, 5.061620293937506, 5.121523210920751, 5.180733538795447, 5.239274758971893, 5.297169055259611, 5.354437412091022, 5.411099703387474, 5.467174773134658, 5.522680508593631, 5.577633906953737, 5.63205113613149, 5.6859475903318, 5.739337940912697, 5.792236183029832, 5.844655678480983, 5.8966091951222275, 5.948108943185221, 5.999166608788257, 6.049793384901669, 6.1, 6.149796744608719, 6.199193495931548, 6.248199740725323, 6.296824596572465, 6.345076831686122, 6.392964883369843, 6.440496875241847, 6.487680633323437, 6.534523701081817, 6.5810333535091585, 6.627216610312357, 6.673080248281149, 6.71863081289633, 6.7638746292343415, 6.808817812219681, 6.853466276272176, 6.897825744392215, 6.941901756723442, 6.985699678629192, 7.029224708315989, 7.07248188403477, 7.115476090888086, 7.158212067269313, 7.200694410957877, 7.242927584892728, 7.284915922644544, 7.326663633605681, 7.368174807915458, 7.409453421137082, 7.450503338701353, 7.491328320131218, 7.531932023060219, 7.572318007057021, 7.6124897372673015, 7.652450587883597, 7.692203845452876, 7.731752712031082, 7.771100308193172, 7.810249675906655, 7.849203781276163], [0.0, 0.787400787401181, 1.1135528725660042, 1.3638181696985856, 1.574801574802362, 1.760681686165901, 1.928730152198591, 2.083266665599966, 2.2271057451320084, 2.362202362203543, 2.4899799195977463, 2.6115129714401193, 2.727636339397171, 2.839013913315678, 2.9461839725312466, 3.049590136395381, 3.149603149604724, 3.246536616149585, 3.340658617698013, 3.432200460346103, 3.521363372331802, 3.608323710533743, 3.6932370625238775, 3.7762415176998414, 3.857460304397182, 3.9370039370059056, 4.014971979976946, 4.091454509095756, 4.166533331199932, 4.240283009422838, 4.3127717305695645, 4.384062043356595, 4.454211490264017, 4.523273151159457, 4.591296113299598, 4.658325879540846, 4.724404724407086, 4.789572005931219, 4.853864439804639, 4.917316341257699, 4.979959839195493, 5.041825066382213, 5.10294032886923, 5.163332257370234, 5.223025942880239, 5.282045058497702, 5.340411969127476, 5.3981478305063115, 5.455272678794342, 5.511805511808268, 5.5677643628300215, 5.62316636780382, 5.678027826631356, 5.732364259186606, 5.786190456595773, 5.839520528262573, 5.892367945062493, 5.944745579080739, 5.99666574022598, 6.048140210014975, 6.099180272790762, 6.149796744608719, 6.199999999999999, 6.249799996799897, 6.299206299209448, 6.348228099241551, 6.39687423668779, 6.445153217728807, 6.49307323229917, 6.540642170307133, 6.587867636800241, 6.6347569661593475, 6.681317235396026, 6.727555276621664, 6.773477688750439, 6.819090848492928, 6.864400920692206, 6.90941386804988, 6.954135460285484, 6.998571282769077, 7.042726744663604, 7.08660708661063, 7.130217387990355, 7.173562573784381, 7.216647421067486, 7.259476565152615, 7.302054505411474, 7.344385610791416, 7.386474125047755, 7.428324171709255, 7.469939758793239, 7.511324783285569, 7.552483035399683, 7.593418202627852, 7.634133873596926, 7.674633541739956, 7.714920608794364, 7.754998388136519, 7.79487010796203, 7.834538914320357, 7.874007874011811, 7.913279977354524], [0.0, 0.7937253933193772, 1.1224972160321824, 1.3747727084867523, 1.5874507866387544, 1.7748239349298849, 1.9442222095223582, 2.1, 2.244994432064365, 2.3811761799581315, 2.5099800796022267, 2.632489316217637, 2.7495454169735045, 2.861817604250837, 2.9698484809834995, 3.074085229787879, 3.1749015732775088, 3.2726136343907144, 3.3674916480965473, 3.4597687784012394, 3.5496478698597698, 3.6373066958946425, 3.722902093797257, 3.8065732621348563, 3.8884444190447165, 3.968626966596886, 4.047221268969613, 4.124318125460256, 4.2, 4.274342054632503, 4.347413023856832, 4.419275958796871, 4.48998886412873, 4.559605246071199, 4.628174586162454, 4.695742752749559, 4.762352359916263, 4.828043081829325, 4.892851929090027, 4.956813492557492, 5.019960159204453, 5.082322303829225, 5.143928459844674, 5.204805471869242, 5.264978632435274, 5.324471804789654, 5.383307533477908, 5.441507144165117, 5.499090833947009, 5.55607775323564, 5.612486080160912, 5.668333088307356, 5.723635208501674, 5.7784080852774675, 5.8326666285670745, 5.886425061104576, 5.939696961966999, 5.9924953066314535, 6.044832503882966, 6.096720429870472, 6.148170459575758, 6.199193495931548, 6.249799996799897, 6.3, 6.3498031465550175, 6.3992187023104625, 6.448255578061403, 6.496922348312315, 6.545227268781429, 6.593178292750774, 6.640783086353597, 6.688049042882386, 6.734983296193095, 6.7815927332743895, 6.827884006044625, 6.87386354243376, 6.919537556802479, 6.96491205974634, 7.009992867328754, 7.0547856097829085, 7.0992957397195395, 7.143528539874395, 7.187489130426565, 7.23118247591637, 7.274613391789285, 7.317786550590281, 7.3607064878311785, 7.40337760755184, 7.445804187594514, 7.487990384609211, 7.52994023880668, 7.571657678474378, 7.6131465242697125, 7.654410493303845, 7.695453203028396, 7.736278174936576, 7.776888838089433, 7.817288532477231, 7.857480512225277, 7.897467948652911, 7.937253933193772, 7.976841480185], [0.0, 0.8, 1.131370849898476, 1.385640646055102, 1.6, 1.788854381999832, 1.9595917942265426, 2.1166010488516727, 2.262741699796952, 2.4, 2.5298221281347035, 2.65329983228432, 2.771281292110204, 2.8844410203711917, 2.9933259094191533, 3.098386676965933, 3.2, 3.2984845004941286, 3.394112549695428, 3.4871191548325395, 3.577708763999664, 3.6660605559646724, 3.752332607858744, 3.836665218650176, 3.9191835884530852, 4.0, 4.079215610874228, 4.156921938165306, 4.233202097703345, 4.308131845707604, 4.381780460041329, 4.454211490264018, 4.525483399593904, 4.595650117230424, 4.664761515876241, 4.732863826479693, 4.8, 4.866210024238576, 4.931531202375181, 4.9959983987187195, 5.059644256269407, 5.122499389946279, 5.184592558726289, 5.2459508194416005, 5.30659966456864, 5.366563145999495, 5.4258639865002145, 5.4845236803208355, 5.542562584220408, 5.6000000000000005, 5.656854249492381, 5.713142742834281, 5.768882040742383, 5.8240879114244155, 5.878775382679628, 5.932958789676531, 5.986651818838307, 6.0398675482166, 6.092618484691127, 6.144916598294887, 6.196773353931866, 6.248199740725323, 6.299206299209448, 6.3498031465550175, 6.4, 6.449806198638839, 6.499230723708768, 6.5482822174979605, 6.596969000988257, 6.64529909033446, 6.6932802122726045, 6.740919818541087, 6.788225099390856, 6.835202996254025, 6.881860213634101, 6.92820323027551, 6.974238309665079, 7.019971509913698, 7.065408693062278, 7.110555533852471, 7.155417527999328, 7.2, 7.244308110509934, 7.288346863315439, 7.332121111929345, 7.37563556583431, 7.418894796396564, 7.4619032424710525, 7.504665215717488, 7.547184905645283, 7.58946638440411, 7.631513611335565, 7.673330437300352, 7.7149206087943645, 7.756287771866127, 7.797435475847171, 7.8383671769061705, 7.879086241436885, 7.919595949289333, 7.959899496852961, 8.0, 8.039900496896713], [0.0, 0.8062257748298549, 1.1401754250991378, 1.3964240043768943, 1.6124515496597098, 1.8027756377319946, 1.9748417658131499, 2.133072900770154, 2.2803508501982757, 2.4186773244895647, 2.5495097567963922, 2.6739483914241875, 2.7928480087537886, 2.9068883707497264, 3.016620625799671, 3.1224989991991987, 3.2249030993194197, 3.324154027718932, 3.420526275297414, 3.5142566781611158, 3.605551275463989, 3.6945906403822333, 3.7815340802378072, 3.866522985836241, 3.9496835316262997, 4.031128874149275, 4.110960958218893, 4.189272013130682, 4.266145801540308, 4.341658669218482, 4.415880433163923, 4.488875137492688, 4.560701700396551, 4.631414470763764, 4.701063709417263, 4.769696007084728, 4.8373546489791295, 4.904079934095691, 4.969909455915671, 5.034878350069642, 5.0990195135927845, 5.162363799656123, 5.224940191045253, 5.28677595515452, 5.347896782848375, 5.4083269131959835, 5.468089245796926, 5.527205442174191, 5.585696017507577, 5.643580423808984, 5.70087712549569, 5.757603668193913, 5.813776741499453, 5.869412236331676, 5.924525297439449, 5.979130371550699, 6.033241251599342, 6.08687111741328, 6.1400325732035, 6.192737682156413, 6.244997998398397, 6.296824596572465, 6.348228099241551, 6.3992187023104625, 6.449806198638839, 6.499999999999999, 6.549809157525125, 6.599242380758566, 6.648308055437864, 6.697014260101287, 6.745368781616021, 6.793379129711516, 6.841052550594828, 6.888396039717809, 6.93541635375988, 6.98212002188447, 7.0285133563222315, 7.074602462329597, 7.12039324756716, 7.165891430938652, 7.211102550927978, 7.256031973468694, 7.300684899377592, 7.345066371381541, 7.389181280764467, 7.433034373659253, 7.476630257007497, 7.519973404208288, 7.5630681604756145, 7.6059187479225665, 7.648529270389177, 7.6909037180295, 7.733045971672482, 7.774959806970066, 7.816648898345122, 7.858116822750854, 7.899367063252599, 7.940403012442127, 7.981227975693965, 8.021845174272563, 8.06225774829855, 8.10246875958186], [0.0, 0.812403840463596, 1.1489125293076057, 1.4071247279470291, 1.624807680927192, 1.8165902124584952, 1.98997487421324, 2.149418526020468, 2.2978250586152114, 2.437211521390788, 2.569046515733026, 2.6944387170614963, 2.8142494558940583, 2.9291637031753623, 3.0397368307141326, 3.1464265445104544, 3.249615361854384, 3.3496268448888453, 3.4467375879228173, 3.541186241925155, 3.6331804249169903, 3.722902093797257, 3.81051177665153, 3.8961519477556315, 3.97994974842648, 4.06201920231798, 4.142463035441596, 4.221374183841087, 4.298837052040936, 4.374928570845472, 4.449719092257397, 4.523273151159456, 4.595650117230423, 4.666904755831214, 4.737087712930805, 4.806245936279166, 4.874423042781576, 4.941659640242335, 5.007993610219566, 5.073460357586329, 5.138093031466052, 5.201922721455982, 5.264978632435274, 5.3272882407468805, 5.388877434122993, 5.449770637375485, 5.509990925582365, 5.569560126257728, 5.628498911788117, 5.686826883245172, 5.744562646538029, 5.801723881744115, 5.858327406350725, 5.914389233048499, 5.96992462263972, 6.024948132556827, 6.079473661428265, 6.133514490078261, 6.187083319303208, 6.240192304729077, 6.292853089020909, 6.345076831686122, 6.39687423668779, 6.448255578061403, 6.499230723708768, 6.549809157525125, 6.6, 6.649812027418519, 6.699253689777691, 6.748333127521196, 6.797058187186572, 6.8454364360499325, 6.8934751758456345, 6.941181455631311, 6.988562083862459, 7.035623639735144, 7.08237248385031, 7.128814768248646, 7.17495644586084, 7.2208032794142785, 7.266360849833981, 7.311634564172365, 7.356629663099809, 7.401351227985333, 7.445804187594514, 7.489993324429602, 7.533923280734945, 7.577598564189054, 7.62102355330306, 7.664202502543888, 7.707139547199077, 7.749838707999025, 7.792303895511263, 7.834538914320357, 7.8765474670060875, 7.918333157931661, 7.95989949685296, 8.001249902359007, 8.04238770515324, 8.083316151184489, 8.12403840463596, 8.16455755078008], [0.0, 0.8185352771872451, 1.1575836902790224, 1.4177446878757827, 1.6370705543744901, 1.8303005217723127, 2.004993765576342, 2.1656407827707715, 2.315167380558045, 2.455605831561735, 2.588435821108957, 2.714774392099646, 2.8354893757515653, 2.951270912674741, 3.062678566222711, 3.1701734968294715, 3.2741411087489802, 3.374907406137241, 3.4727510708370675, 3.567912554982255, 3.6606010435446255, 3.7509998667022106, 3.8392707640904935, 3.9255572852781047, 4.009987531152684, 4.092676385936225, 4.173727350941841, 4.253234063627348, 4.331281565541543, 4.407947368106838, 4.483302354291978, 4.557411546042337, 4.63033476111609, 4.702127178203499, 4.77283982551269, 4.8425200051213, 4.91121166312347, 4.978955713801841, 5.045790324617146, 5.111751167652823, 5.176871642217914, 5.241183072551464, 5.304714883949938, 5.367494760127856, 5.429548784199292, 5.490901565316937, 5.551576352712804, 5.61159513863928, 5.670978751503131, 5.729746940310715, 5.787918451395113, 5.845511098270194, 5.902541825349482, 5.959026766175833, 6.014981296729027, 6.070420084310475, 6.125357132445422, 6.17980582219215, 6.23377895020348, 6.287288763847259, 6.340346993658943, 6.392964883369843, 6.445153217728807, 6.496922348312315, 6.5482822174979605, 6.599242380758566, 6.649812027418519, 6.7, 6.749814812274482, 6.79926466612383, 6.848357467305573, 6.897100840208152, 6.945502141674135, 6.993568473962345, 7.041306696913577, 7.088723439378913, 7.13582510996451, 7.182617907142214, 7.229107828771128, 7.275300681071539, 7.321202087089251, 7.366817494685205, 7.4121521840825695, 7.457211275000863, 7.501999733404421, 7.546522377890362, 7.590783885739338, 7.634788798650556, 7.678541528180987, 7.722046360907191, 7.76530746332687, 7.808328886515987, 7.851114570556209, 7.893668348746355, 7.935993951610599, 7.978095010715276, 8.019975062305368, 8.061637550770936, 8.103085831953157, 8.144323176298936, 8.18535277187245, 8.226177727231525], [0.0, 0.8246211251235321, 1.16619037896906, 1.4282856857085702, 1.6492422502470643, 1.8439088914585775, 2.0199009876724157, 2.181742422927143, 2.33238075793812, 2.473863375370596, 2.6076809620810595, 2.734958866235469, 2.8565713714171403, 2.973213749463701, 3.0854497241083023, 3.1937438845342623, 3.2984845004941286, 3.4, 3.4985711369071804, 3.594440151122286, 3.687817782917155, 3.778888725538237, 3.867815921162743, 3.954743986657038, 4.039801975344831, 4.123105625617661, 4.204759208325728, 4.28485705712571, 4.363484845854286, 4.440720662234904, 4.516635916254486, 4.591296113299599, 4.66476151587624, 4.737087712930805, 4.8083261120685235, 4.878524367060187, 4.947726750741192, 5.015974481593781, 5.083306010855534, 5.149757275833494, 5.215361924162119, 5.280151512977635, 5.344155686354956, 5.407402333838309, 5.469917732470938, 5.531726674375732, 5.592852581643825, 5.653317610041028, 5.713142742834281, 5.772347875864725, 5.830951894845301, 5.888972745734184, 5.946427498927402, 6.003332407921454, 6.059702963017247, 6.115553940568263, 6.170899448216605, 6.2257529665093525, 6.280127387243033, 6.334035048845246, 6.387487769068525, 6.440496875241847, 6.49307323229917, 6.545227268781429, 6.596969000988257, 6.648308055437864, 6.699253689777691, 6.749814812274482, 6.8, 6.849817515817484, 6.899275324264137, 6.948381106416083, 6.997142273814361, 7.045565981523414, 7.093659140387279, 7.14142842854285, 7.188880302244572, 7.236021006050217, 7.282856582413251, 7.329392880723478, 7.37563556583431, 7.42159012611179, 7.467261881037788, 7.512655988397179, 7.557777451076474, 7.602631123499285, 7.647221717722065, 7.691553809211764, 7.735631842325486, 7.779460135510689, 7.8230428862431785, 7.866384175718855, 7.909487973314076, 7.952358140828418, 7.994998436522675, 8.037412518964047, 8.079603950689663, 8.121576201698781, 8.16333265278342, 8.204876598706406, 8.246211251235321, 8.287339742040265], [0.0, 0.8306623862918076, 1.174734012447073, 1.4387494569938162, 1.661324772583615, 1.8574175621006712, 2.0346989949375804, 2.1977260975835913, 2.349468024894146, 2.4919871588754225, 2.6267851073127395, 2.7549954627911823, 2.8774989139876324, 2.994995826374388, 3.1080540535840107, 3.217141588429082, 3.32264954516723, 3.424908757908742, 3.5242020373412193, 3.6207733980463352, 3.7148351242013424, 3.8065732621348563, 3.8961519477556315, 3.9837168574084183, 4.069397989875161, 4.153311931459037, 4.235563716909475, 4.316248370981448, 4.3954521951671826, 4.473253849269009, 4.54972526643093, 4.624932431938872, 4.698936049788292, 4.77179211617606, 4.843552415324934, 4.914264950122246, 4.983974317750845, 5.052722038663912, 5.120546845796843, 5.187484939737176, 5.253570214625479, 5.3188344587888805, 5.383307533477909, 5.447017532558529, 5.509990925582365, 5.572252686302012, 5.63382640840131, 5.69473440996154, 5.754997827975265, 5.814636704042653, 5.873670062235366, 5.932115979985557, 5.989991652748776, 6.047313453096343, 6.104096984812742, 6.1603571325045765, 6.216108107168021, 6.271363488110062, 6.326136261573885, 6.380438856379708, 6.434283176858164, 6.487680633323437, 6.540642170307133, 6.593178292750774, 6.64529909033446, 6.697014260101287, 6.748333127521196, 6.79926466612383, 6.849817515817484, 6.9, 6.949820141557622, 6.999285677838847, 7.048404074682439, 7.097182539571601, 7.145628033979938, 7.19374728496908, 7.2415467960926705, 7.289032857656769, 7.336211556382492, 7.383088784512889, 7.429670248402685, 7.475961476626268, 7.521967827636597, 7.567694497005016, 7.6131465242697125, 7.658328799418317, 7.703246069028303, 7.747902942086975, 7.792303895511263, 7.836453279386026, 7.880355321938218, 7.924014134263013, 7.967433714816837, 8.010617953691215, 8.053570636680355, 8.096295449154509, 8.138795979750322, 8.18107572388864, 8.223138087129511, 8.264986388373547, 8.306623862918075, 8.34805366537614], [0.0, 0.8366600265340756, 1.1832159566199232, 1.4491376746189442, 1.6733200530681511, 1.8708286933869709, 2.04939015319192, 2.2135943621178655, 2.3664319132398464, 2.5099800796022267, 2.6457513110645907, 2.774887385102322, 2.8982753492378883, 3.0166206257996717, 3.1304951684997055, 3.24037034920393, 3.3466401061363023, 3.4496376621320683, 3.5496478698597698, 3.6469165057620945, 3.7416573867739418, 3.834057902536163, 3.924283374069717, 4.012480529547776, 4.09878030638384, 4.183300132670378, 4.266145801540309, 4.3474130238568325, 4.427188724235731, 4.505552130427525, 4.58257569495584, 4.658325879540847, 4.732863826479693, 4.806245936279167, 4.878524367060187, 4.949747468305833, 5.019960159204453, 5.089204259999789, 5.157518783291051, 5.2249401910452535, 5.291502622129181, 5.35723809439155, 5.422176684690385, 5.486346689738081, 5.549774770204644, 5.612486080160912, 5.674504383644443, 5.735852159879995, 5.796550698475777, 5.856620185738529, 5.916079783099617, 5.974947698515863, 6.033241251599343, 6.090976933136425, 6.148170459575759, 6.2048368229954285, 6.260990336999411, 6.316644678941503, 6.3718129288295975, 6.4265076052238514, 6.48074069840786, 6.534523701081817, 6.587867636800241, 6.640783086353597, 6.6932802122726045, 6.745368781616021, 6.797058187186572, 6.848357467305573, 6.899275324264137, 6.949820141557622, 7.000000000000001, 7.049822692805827, 7.0992957397195395, 7.148426400264607, 7.197221686178633, 7.24568837309472, 7.293833011524189, 7.341661937191062, 7.3891812807644675, 7.436396977031284, 7.4833147735478835, 7.529940238806681, 7.576278769950325, 7.622335600063802, 7.668115805072326, 7.713624310270757, 7.75886589650833, 7.803845206050669, 7.848566748139434, 7.893034904268446, 7.937253933193772, 7.981227975693966, 8.024961059095553, 8.068457101577724, 8.1117199162693, 8.154753215150045, 8.19756061276768, 8.240145629781066, 8.282511696339462, 8.324662155306966, 8.366600265340756, 8.408329203831164], [0.0, 0.8426149773176359, 1.1916375287812984, 1.4594519519326425, 1.6852299546352718, 1.8841443681416774, 2.0639767440550294, 2.2293496809607953, 2.3832750575625967, 2.5278449319529073, 2.6645825188948455, 2.7946377224964243, 2.918903903865285, 3.0380915061926625, 3.152776554086889, 3.2634337744161437, 3.3704599092705436, 3.4741905532080417, 3.5749125863438955, 3.672873534441392, 3.768288736283355, 3.861346915261565, 3.952214569073901, 4.041039470235351, 4.127953488110059, 4.2130748865881795, 4.296510211788167, 4.378355855797928, 4.458699361921591, 4.537620521815371, 4.61519230368573, 4.69148164229596, 4.766550115125193, 4.8404545241123795, 4.913247398615299, 4.984977432245807, 5.0556898639058145, 5.1254268114957995, 5.194227565288221, 5.262128846769148, 5.329165037789691, 5.395368384086485, 5.46076917659042, 5.525395913416522, 5.589275444992849, 5.652433104425031, 5.71489282489182, 5.776677245614472, 5.83780780773057, 5.898304841223451, 5.958187643906493, 6.017474553332154, 6.076183012385325, 6.134329629226001, 6.191930232165088, 6.248999919987198, 6.305553108173778, 6.361603571427569, 6.417164482853779, 6.472248450113762, 6.526867548832287, 6.5810333535091585, 6.6347569661593475, 6.688049042882386, 6.740919818541087, 6.793379129711516, 6.8454364360499325, 6.897100840208152, 6.948381106416083, 6.999285677838847, 7.049822692805827, 7.1, 7.149825172687791, 7.199305522062527, 7.248448109768049, 7.297259759663212, 7.345747068882784, 7.3939164182454755, 7.441773982055624, 7.489325737341113, 7.53657747256671, 7.583534795858723, 7.630203142774117, 7.676587783644501, 7.72269383052313, 7.768526243760782, 7.814089838234521, 7.859389289251424, 7.904429138147802, 7.949213797602879, 7.993747556684537, 8.038034585643434, 8.082078940470701, 8.125884567233282, 8.16945530620004, 8.212794895770866, 8.255906976220118, 8.298795093265047, 8.341462701469089, 8.383913167489272, 8.426149773176359, 8.468175718535841], [0.0, 0.848528137423857, 1.2, 1.4696938456699071, 1.697056274847714, 1.8973665961010278, 2.078460969082653, 2.244994432064365, 2.4, 2.545584412271571, 2.6832815729997477, 2.814249455894058, 2.9393876913398143, 3.0594117081556713, 3.1749015732775088, 3.2863353450309964, 3.394112549695428, 3.4985711369071804, 3.6, 3.6986484017813863, 3.7947331922020555, 3.8884444190447165, 3.97994974842648, 4.069397989875161, 4.156921938165306, 4.242640687119286, 4.3266615305567875, 4.409081537009721, 4.48998886412873, 4.5694638635183455, 4.6475800154489, 4.724404724407087, 4.8, 4.874423042781577, 4.947726750741193, 5.019960159204453, 5.091168824543142, 5.1613951602255765, 5.230678732248808, 5.299056519796709, 5.366563145999495, 5.43323108288245, 5.499090833947008, 5.564171097297422, 5.628498911788116, 5.692099788303082, 5.754997827975264, 5.817215828899595, 5.8787753826796285, 5.939696961966999, 6.0, 6.059702963017248, 6.118823416311343, 6.177378084592201, 6.235382907247959, 6.29285308902091, 6.3498031465550175, 6.406246951218787, 6.462197768561405, 6.517668294720129, 6.572670690061993, 6.627216610312357, 6.681317235396026, 6.734983296193095, 6.788225099390856, 6.841052550594828, 6.8934751758456345, 6.945502141674135, 6.997142273814361, 7.048404074682439, 7.0992957397195395, 7.149825172687791, 7.2, 7.249827584156743, 7.299315036357863, 7.3484692283495345, 7.397296803562773, 7.445804187594514, 7.493997598078079, 7.541883053985921, 7.589466384404111, 7.636753236814713, 7.68374908491942, 7.730459236035075, 7.776888838089433, 7.823042886243179, 7.868926229162401, 7.914543574963752, 7.95989949685296, 8.0049984384758, 8.049844718999243, 8.094442537939225, 8.138795979750322, 8.182909018191515, 8.226785520481254, 8.270429251254132, 8.313843876330612, 8.357032966310472, 8.4, 8.442748367682174, 8.485281374238571, 8.527602242131138], [0.0, 0.8544003745317531, 1.2083045973594573, 1.4798648586948744, 1.7088007490635062, 1.91049731745428, 2.092844953645635, 2.260530911091463, 2.4166091947189146, 2.563201123595259, 2.701851217221259, 2.833725463060951, 2.9597297173897488, 3.0805843601498726, 3.196873472629156, 3.309078421554859, 3.4176014981270124, 3.522782990761707, 3.6249137920783716, 3.7242448899072147, 3.82099463490856, 3.915354390090379, 4.007492981902776, 4.097560249709576, 4.18568990729127, 4.272001872658766, 4.356604182158393, 4.439594576084623, 4.521061822182926, 4.601086828130937, 4.679743582719036, 4.757099956906519, 4.833218389437829, 4.908156476723211, 4.98196748283246, 5.054700782440045, 5.126402247190518, 5.197114584074513, 5.266877632905477, 5.335728628781641, 5.403702434442518, 5.470831746635972, 5.537147279962851, 5.602677931132575, 5.667450926121902, 5.731491952362839, 5.794825277780168, 5.857473858242988, 5.9194594347794975, 5.980802621722272, 6.041522986797286, 6.101639124038721, 6.161168720299745, 6.220128616033596, 6.278534860936905, 6.336402764976356, 6.393746945258312, 6.450581369148055, 6.5069193939989765, 6.562773803811921, 6.618156843109718, 6.673080248281149, 6.727555276621664, 6.7815927332743895, 6.835202996254025, 6.888396039717809, 6.941181455631311, 6.993568473962345, 7.045565981523414, 7.097182539571601, 7.148426400264607, 7.199305522062527, 7.249827584156743, 7.3, 7.349829930005183, 7.399324293474371, 7.448489779814429, 7.4973328590906245, 7.545859791965394, 7.594076639065476, 7.64198926981712, 7.689603370785778, 7.736924453553881, 7.783957862167549, 7.830708780180758, 7.877182237323192, 7.923383115816122, 7.969316156358713, 8.014985963805552, 8.060397012554654, 8.105553651663778, 8.150460109711599, 8.195120499419152, 8.239538822045807, 8.283718971573094, 8.327664738688751, 8.37137981458254, 8.414867794564572, 8.4581321815162, 8.501176389182852, 8.544003745317532, 8.586617494683225], [0.0, 0.8602325267042626, 1.2165525060596438, 1.489966442575134, 1.7204650534085253, 1.9235384061671346, 2.1071307505705477, 2.2759613353482084, 2.4331050121192876, 2.580697580112788, 2.7202941017470885, 2.8530685235374214, 2.979932885150268, 3.1016124838541645, 3.218695387886216, 3.3316662497915357, 3.4409301068170506, 3.5468295701936396, 3.6496575181789317, 3.749666651850535, 3.847076812334269, 3.9420806688854046, 4.034848200366403, 4.125530268947254, 4.214261501141095, 4.301162633521313, 4.386342439892262, 4.469899327725402, 4.551922670696417, 4.632493928760188, 4.711687595755898, 4.789572005931219, 4.866210024238575, 4.941659640242335, 5.015974481593781, 5.089204259999788, 5.161395160225576, 5.232590180780452, 5.302829433425141, 5.372150407425317, 5.440588203494177, 5.508175741568165, 5.574943945906542, 5.6409219104681805, 5.706137047074843, 5.770615218501403, 5.834380858325929, 5.897457079114692, 5.959865770300536, 6.021627686929839, 6.082762530298219, 6.143289021363068, 6.203224967708329, 6.262587324740471, 6.321392251711643, 6.3796551630946325, 6.437390775772432, 6.494613152451807, 6.55133574166368, 6.607571414672716, 6.663332499583071, 6.71863081289633, 6.773477688750439, 6.827884006044625, 6.881860213634101, 6.93541635375988, 6.988562083862459, 7.041306696913577, 7.093659140387279, 7.145628033979938, 7.197221686178633, 7.248448109768049, 7.299315036357863, 7.349829930005183, 7.3999999999999995, 7.44983221287567, 7.49933330370107, 7.548509786706248, 7.597367965289032, 7.645913941446111, 7.694153624668538, 7.742092740338364, 7.789736837660179, 7.837091297158659, 7.884161337770809, 7.930952023559341, 7.977468270071652, 8.023714850367003, 8.069696400732806, 8.115417426109392, 8.160882305241266, 8.206095295571457, 8.251060537894508, 8.295782060782456, 8.340263784797218, 8.384509526501832, 8.42852300228219, 8.472307831990054, 8.515867542417507, 8.559205570612264, 8.602325267042627, 8.645229898620395], [0.0, 0.8660254037844387, 1.224744871391589, 1.5000000000000002, 1.7320508075688774, 1.9364916731037085, 2.121320343559643, 2.29128784747792, 2.449489742783178, 2.598076211353316, 2.7386127875258306, 2.8722813232690148, 3.0000000000000004, 3.122498999199199, 3.24037034920393, 3.3541019662496843, 3.464101615137755, 3.570714214271425, 3.6742346141747673, 3.7749172176353754, 3.872983346207417, 3.968626966596886, 4.06201920231798, 4.153311931459037, 4.242640687119286, 4.330127018922194, 4.415880433163924, 4.5, 4.58257569495584, 4.663689526544408, 4.743416490252569, 4.8218253804964775, 4.898979485566356, 4.974937185533101, 5.049752469181039, 5.123475382979799, 5.196152422706632, 5.26782687642637, 5.338539126015656, 5.408326913195984, 5.477225575051661, 5.545268253204709, 5.612486080160912, 5.678908345800274, 5.7445626465380295, 5.809475019311125, 5.873670062235366, 5.937171043518958, 6.000000000000001, 6.06217782649107, 6.123724356957946, 6.184658438426491, 6.244997998398398, 6.304760106459247, 6.363961030678928, 6.422616289332565, 6.48074069840786, 6.5383484153110105, 6.59545297913646, 6.652067347825035, 6.7082039324993685, 6.7638746292343415, 6.819090848492928, 6.87386354243376, 6.92820323027551, 6.98212002188447, 7.035623639735144, 7.088723439378913, 7.14142842854285, 7.19374728496908, 7.24568837309472, 7.297259759663212, 7.3484692283495345, 7.399324293474371, 7.44983221287567, 7.5, 7.549834435270751, 7.599342076785332, 7.6485292703891785, 7.697402159170327, 7.745966692414834, 7.794228634059948, 7.842193570679062, 7.88986691902975, 7.937253933193772, 7.984359711335657, 8.031189202104505, 8.077747210701757, 8.12403840463596, 8.170067319184096, 8.215838362577491, 8.261355820929154, 8.306623862918075, 8.351646544245034, 8.396427811873334, 8.440971508067065, 8.485281374238571, 8.529361054615991, 8.573214099741124, 8.616843969807043, 8.660254037844387, 8.703447592764606], [0.0, 0.8717797887081349, 1.2328828005937953, 1.5099668870541503, 1.7435595774162698, 1.9493588689617931, 2.1354156504062627, 2.3065125189341593, 2.4657656011875906, 2.615339366124404, 2.7568097504180447, 2.8913664589601926, 3.0199337741083006, 3.1432467291003428, 3.2619012860600183, 3.3763886032268267, 3.4871191548325395, 3.594440151122286, 3.6986484017813863, 3.8000000000000007, 3.8987177379235862, 3.9949968710876362, 4.0890096600521755, 4.180908992073375, 4.270831300812525, 4.358898943540674, 4.445222154178575, 4.529900661162451, 4.613025037868319, 4.694677837722201, 4.774934554525329, 4.8538644398046396, 4.931531202375181, 5.007993610219566, 5.083306010855535, 5.157518783291051, 5.230678732248808, 5.302829433425142, 5.374011537017762, 5.444263035526481, 5.513619500836089, 5.582114294781146, 5.649778756730215, 5.716642371182581, 5.782732917920385, 5.848076606885378, 5.912698199637794, 5.976621118993575, 6.039867548216601, 6.102458520956944, 6.164414002968978, 6.225752966509353, 6.2864934582006855, 6.3466526610489735, 6.406246951218788, 6.465291950097846, 6.523802572120037, 6.581793068761734, 6.639277069079134, 6.696267617113283, 6.752777206453653, 6.808817812219681, 6.864400920692206, 6.919537556802479, 6.974238309665079, 7.0285133563222315, 7.08237248385031, 7.13582510996451, 7.188880302244572, 7.2415467960926705, 7.293833011524189, 7.345747068882784, 7.397296803562773, 7.448489779814429, 7.49933330370107, 7.549834435270751, 7.600000000000001, 7.649836599562112, 7.6993506219680645, 7.748548251124208, 7.7974354758471724, 7.8460180983732135, 7.894301742396222, 7.942291860665913, 7.9899937421752725, 8.037412518964048, 8.084553172563096, 8.13142054010245, 8.178019320104351, 8.224354077980836, 8.270429251254134, 8.316249154516717, 8.36181798414675, 8.407139822793482, 8.452218643646177, 8.497058314499201, 8.54166260162505, 8.586035173466273, 8.630179604156568, 8.674099376880578, 8.717797887081348, 8.761278445523805], [0.0, 0.8774964387392122, 1.2409673645990857, 1.5198684153570665, 1.7549928774784245, 1.9621416870348585, 2.149418526020468, 2.32163735324878, 2.4819347291981715, 2.6324893162176366, 2.7748873851023217, 2.91032644217105, 3.039736830714133, 3.1638584039112754, 3.283291031876401, 3.3985290935932855, 3.509985754956849, 3.6180105030251086, 3.722902093797257, 3.824918299781056, 3.924283374069717, 4.02119385257662, 4.115823125451336, 4.2083250825001635, 4.298837052040936, 4.387482193696061, 4.474371464239419, 4.559605246071199, 4.64327470649756, 4.725462940284264, 4.806245936279166, 4.8856934001224435, 4.963869458396343, 5.040833264451424, 5.1166395221864125, 5.191338940966964, 5.264978632435273, 5.3376024580330075, 5.409251334519409, 5.479963503528103, 5.549774770204643, 5.61871871515206, 5.686826883245173, 5.754128952326321, 5.8206528843421, 5.886425061104575, 5.951470406546605, 6.015812497078014, 6.079473661428266, 6.142475071174486, 6.2048368229954285, 6.266578013557321, 6.327716807822551, 6.388270501473776, 6.448255578061404, 6.507687761409578, 6.566582063752802, 6.624952830020755, 6.682813778641449, 6.740178039191546, 6.797058187186571, 6.853466276272176, 6.90941386804988, 6.96491205974634, 7.019971509913698, 7.074602462329597, 7.128814768248646, 7.182617907142214, 7.236021006050217, 7.289032857656769, 7.341661937191062, 7.3939164182454755, 7.445804187594514, 7.4973328590906245, 7.548509786706248, 7.599342076785332, 7.649836599562112, 7.7, 7.749838707999026, 7.799358948016177, 7.848566748139434, 7.897467948652911, 7.9460682101275735, 7.994373021069257, 8.04238770515324, 8.090117428072352, 8.137567204023572, 8.184741901856162, 8.231646250902672, 8.278284846512591, 8.324662155306966, 8.370782520170978, 8.416650165000327, 8.462269199216012, 8.507643622061282, 8.55277732669336, 8.597674104081872, 8.64233764672499, 8.6867715521936, 8.73097932651315, 8.774964387392123, 8.81873006730561], [0.0, 0.8831760866327848, 1.2489995996796797, 1.5297058540778359, 1.7663521732655696, 1.9748417658131503, 2.1633307652783937, 2.336664289109585, 2.4979991993593593, 2.6495282598983545, 2.7928480087537886, 2.9291637031753623, 3.0594117081556718, 3.1843366656181322, 3.3045423283716615, 3.420526275297414, 3.532704346531139, 3.6414282912066254, 3.7469987990390394, 3.8496753109840323, 3.9496835316263006, 4.047221268969613, 4.1424630354415966, 4.235563716909475, 4.3266615305567875, 4.415880433163924, 4.503332099679082, 4.589117562233508, 4.67332857821917, 4.756048780237647, 4.83735464897913, 4.917316341257699, 4.995998398718719, 5.07346035758633, 5.149757275833494, 5.2249401910452535, 5.299056519796709, 5.372150407425318, 5.444263035526481, 5.515432893255072, 5.585696017507577, 5.655086206239478, 5.723635208501675, 5.791372894228104, 5.858327406350725, 5.92452529743945, 5.989991652748776, 6.054750201288242, 6.1188234163113435, 6.182232606429493, 6.244997998398399, 6.307138812488593, 6.3686733312362644, 6.429618962271405, 6.489992295835182, 6.549809157525127, 6.609084656743323, 6.667833231267862, 6.726068688320096, 6.783804242458652, 6.841052550594828, 6.897825744392215, 6.954135460285484, 7.009992867328754, 7.065408693062278, 7.12039324756716, 7.17495644586084, 7.229107828771128, 7.282856582413251, 7.336211556382492, 7.3891812807644675, 7.441773982055624, 7.493997598078079, 7.545859791965394, 7.597367965289032, 7.6485292703891785, 7.6993506219680645, 7.749838707999026, 7.800000000000002, 7.849840762716147, 7.899367063252601, 7.9485847796950635, 7.997499609252884, 8.046117075956577, 8.094442537939226, 8.142481194328914, 8.19023809177731, 8.23771813064759, 8.284926070883193, 8.33186653757728, 8.378544026261366, 8.424962907930219, 8.47112743381895, 8.517041739947036, 8.56270985144306, 8.608135686662937, 8.653323061113575, 8.698275691193055, 8.742997197757758, 8.787491109526087, 8.831760866327848, 8.875809822207776], [0.0, 0.8888194417315589, 1.2569805089976536, 1.5394804318340656, 1.7776388834631178, 1.9874606914351793, 2.177154105707724, 2.3515952032609695, 2.513961017995307, 2.6664583251946765, 2.8106938645110393, 2.9478805945967355, 3.078960863668131, 3.204684071792413, 3.3256578296631782, 3.442382895611701, 3.5552777669262356, 3.664696440361739, 3.7709415269929605, 3.874274125562104, 3.9749213828703587, 4.07308237088326, 4.168932717135166, 4.262628297189424, 4.354308211415448, 4.444097208657795, 4.532107677449864, 4.618441295502196, 4.703190406521939, 4.786439177509728, 4.868264577855234, 4.948737212663449, 5.027922035990614, 5.105878964487898, 5.182663407939976, 5.2583267300539625, 5.332916650389353, 5.406477596365309, 5.47905101272109, 5.550675634551168, 5.621387729022079, 5.691221310052879, 5.760208329565868, 5.8283788483591215, 5.895761189193471, 5.962382074305537, 6.028266749240615, 6.09343909463285, 6.157921727336262, 6.221736092120913, 6.284902544988268, 6.347440429023341, 6.409368143584826, 6.470703207534712, 6.5314623171231725, 6.591661399070799, 6.6513156593263565, 6.710439627923047, 6.76904720030818, 6.827151675479314, 6.884765791223402, 6.941901756723442, 6.998571282769077, 7.0547856097829085, 7.110555533852471, 7.165891430938652, 7.2208032794142785, 7.275300681071539, 7.329392880723478, 7.383088784512889, 7.436396977031284, 7.489325737341113, 7.541883053985921, 7.594076639065476, 7.645913941446111, 7.697402159170327, 7.748548251124208, 7.799358948016177, 7.849840762716147, 7.9, 7.949842765740717, 7.999374975584031, 8.048602363143555, 8.097530487747484, 8.14616474176652, 8.194510357550353, 8.242572413997951, 8.290355842785038, 8.337865434270332, 8.385105843100611, 8.432081593533118, 8.478797084492587, 8.525256594378847, 8.571464285639882, 8.61742420912421, 8.663140308225419, 8.708616422830897, 8.753856293085923, 8.798863562983575, 8.843641783790206, 8.88819441731559, 8.932524839036274], [0.0, 0.894427190999916, 1.2649110640673518, 1.549193338482967, 1.788854381999832, 2.0000000000000004, 2.1908902300206647, 2.366431913239847, 2.5298221281347035, 2.6832815729997477, 2.8284271247461903, 2.9664793948382657, 3.098386676965934, 3.22490309931942, 3.3466401061363023, 3.4641016151377544, 3.577708763999664, 3.687817782917155, 3.7947331922020555, 3.8987177379235862, 4.000000000000001, 4.09878030638384, 4.1952353926806065, 4.289522117905444, 4.3817804600413295, 4.47213595499958, 4.560701700396552, 4.647580015448901, 4.732863826479694, 4.8166378315169185, 4.898979485566357, 4.979959839195494, 5.059644256269407, 5.1380930314660525, 5.21536192416212, 5.291502622129181, 5.366563145999495, 5.440588203494178, 5.513619500836089, 5.585696017507577, 5.656854249492381, 5.727128425310542, 5.796550698475777, 5.865151319446072, 5.9329587896765315, 6.0, 6.066300355241241, 6.131883886702357, 6.196773353931868, 6.260990336999412, 6.324555320336759, 6.387487769068526, 6.44980619863884, 6.511528238439884, 6.572670690061994, 6.6332495807108005, 6.6932802122726045, 6.752777206453653, 6.811754546370562, 6.870225614927067, 6.928203230275509, 6.985699678629192, 7.042726744663604, 7.0992957397195395, 7.155417527999328, 7.211102550927978, 7.266360849833981, 7.321202087089251, 7.37563556583431, 7.429670248402685, 7.4833147735478835, 7.53657747256671, 7.589466384404111, 7.64198926981712, 7.694153624668538, 7.745966692414834, 7.7974354758471724, 7.848566748139434, 7.899367063252601, 7.949842765740717, 8.000000000000002, 8.049844718999244, 8.099382692526635, 8.148619514985345, 8.19756061276768, 8.246211251235321, 8.29457654133109, 8.342661445845685, 8.390470785361213, 8.438009243891594, 8.485281374238571, 8.532291603080617, 8.579044235810889, 8.62554346113913, 8.671793355471522, 8.717797887081348, 8.763560920082659, 8.809086218218098, 8.854377448471462, 8.899438184514796, 8.94427190999916, 8.988882021697695], [0.0, 0.9, 1.2727922061357855, 1.5588457268119897, 1.8, 2.012461179749811, 2.2045407685048604, 2.3811761799581315, 2.545584412271571, 2.7, 2.8460498941515415, 2.9849623113198605, 3.1176914536239795, 3.2449961479175906, 3.3674916480965473, 3.485685011586675, 3.6, 3.710795063055895, 3.8183766184073566, 3.9230090491866068, 4.024922359499622, 4.124318125460256, 4.221374183841087, 4.316248370981448, 4.409081537009721, 4.500000000000001, 4.589117562233507, 4.676537180435969, 4.762352359916263, 4.846648326421054, 4.929503017546495, 5.01098792654702, 5.091168824543142, 5.170106381884226, 5.247856705360771, 5.324471804789654, 5.4, 5.474486277268398, 5.547972602672079, 5.620498198558559, 5.692099788303083, 5.762811813689565, 5.832666628567075, 5.9016946718718, 5.969924622639721, 6.037383539249432, 6.104096984812742, 6.17008914036094, 6.235382907247959, 6.300000000000001, 6.3639610306789285, 6.427285585688566, 6.489992295835181, 6.552098900352467, 6.613622305514581, 6.674578638386097, 6.734983296193095, 6.794850991743675, 6.854195795277518, 6.913031173081747, 6.97137002317335, 7.029224708315989, 7.08660708661063, 7.143528539874395, 7.2, 7.256031973468694, 7.311634564172365, 7.366817494685205, 7.42159012611179, 7.475961476626268, 7.529940238806681, 7.583534795858723, 7.636753236814713, 7.689603370785778, 7.742092740338364, 7.794228634059948, 7.8460180983732135, 7.897467948652911, 7.9485847796950635, 7.999374975584031, 8.049844718999244, 8.100000000000001, 8.149846624323676, 8.19939022122987, 8.248636250920512, 8.2975900115636, 8.346256645946134, 8.394641147779934, 8.442748367682174, 8.490583018850943, 8.538149682454625, 8.58545281275251, 8.632496741962896, 8.67928568489366, 8.725823743349393, 8.772114910328067, 8.818163074019441, 8.863972021616496, 8.909545442950499, 8.95488693395958, 9.000000000000002, 9.044888059008803], [0.0, 0.9055385138137417, 1.2806248474865698, 1.5684387141358125, 1.8110770276274835, 2.024845673131659, 2.2181073012818837, 2.395829710142188, 2.5612496949731396, 2.716615541441225, 2.863564212655271, 3.003331483536242, 3.136877428271625, 3.264965543462902, 3.3882148692194836, 3.5071355833500366, 3.622154055254967, 3.733630940518894, 3.84187454245971, 3.947150871198111, 4.049691346263318, 4.149698784249287, 4.247352116319061, 4.342810150121694, 4.436214602563767, 4.527692569068709, 4.617358552246079, 4.705316142407438, 4.791659420284376, 4.876474136094644, 4.959838707054898, 5.041825066382213, 5.122499389946279, 5.201922721455982, 5.280151512977635, 5.35723809439155, 5.43323108288245, 5.508175741568166, 5.582114294781146, 5.655086206239478, 5.727128425310542, 5.798275605729691, 5.868560300448485, 5.938013135721409, 6.006662967072484, 6.074537019394977, 6.1416610131136355, 6.208059278067503, 6.27375485654325, 6.338769596696192, 6.403124237432849, 6.466838485689898, 6.529931086925804, 6.592419889539805, 6.654321903845651, 6.715653356152327, 6.776429738438967, 6.836665854054885, 6.8963758598266685, 6.955573304911681, 7.014271166700073, 7.07248188403477, 7.130217387990355, 7.187489130426565, 7.244308110509934, 7.300684899377592, 7.356629663099809, 7.4121521840825695, 7.467261881037788, 7.521967827636597, 7.576278769950325, 7.630203142774117, 7.68374908491942, 7.736924453553881, 7.789736837660179, 7.842193570679062, 7.894301742396222, 7.9460682101275735, 7.997499609252884, 8.048602363143555, 8.099382692526635, 8.149846624323676, 8.200000000000001, 8.249848483457136, 8.299397568498573, 8.348652585896723, 8.397618710086808, 8.446300965511472, 8.494704232638123, 8.542833253669418, 8.590692637965812, 8.638286867197687, 8.685620300243388, 8.732697177848321, 8.77952162705919, 8.826097665446492, 8.872429205127535, 8.918520056601322, 8.964373932405989, 9.009994450608726, 9.055385138137417, 9.100549433962767], [0.0, 0.9110433579144299, 1.2884098726725124, 1.5779733838059502, 1.8220867158288598, 2.0371548787463363, 2.2315913604421396, 2.41039415863879, 2.576819745345025, 2.7331300737432893, 2.8809720581775866, 3.0215889859476257, 3.1559467676119004, 3.2848135411313684, 3.408812109811862, 3.5284557528754696, 3.6441734316577197, 3.7563279941985894, 3.8652296180175374, 3.9711459303329564, 4.0743097574926725, 4.174925149029621, 4.273172123844299, 4.369210454990696, 4.463182720884279, 4.55521678957215, 4.645427859734774, 4.73392015141785, 4.82078831727758, 4.906118628814432, 4.9899899799498595, 5.072474741188959, 5.15363949069005, 5.23354564325181, 5.31224999411737, 5.389805191284746, 5.466260147486579, 5.541660400998964, 5.616048432839589, 5.68946394662977, 5.761944116355173, 5.833523806414096, 5.904235767650205, 5.974110812497538, 6.043177971895251, 6.111464636239008, 6.178996682310163, 6.245798587850876, 6.311893535223801, 6.377303505401009, 6.442049363362563, 6.506150935845249, 6.569627082262737, 6.632495759516172, 6.694774081326419, 6.756478372643548, 6.817624219623724, 6.878226515607057, 6.938299503480662, 6.997856814768361, 7.056911505750939, 7.115476090888086, 7.173562573784381, 7.23118247591637, 7.288346863315439, 7.345066371381541, 7.401351227985333, 7.457211275000863, 7.512655988397179, 7.567694497005016, 7.622335600063802, 7.676587783644501, 7.730459236035075, 7.783957862167549, 7.837091297158659, 7.88986691902975, 7.942291860665913, 7.994373021069257, 8.046117075956577, 8.097530487747484, 8.148619514985345, 8.19939022122987, 8.249848483457136, 8.299999999999999, 8.349850298059241, 8.399404740813482, 8.44866853415377, 8.49764673306675, 8.546344247688598, 8.594765849050223, 8.64291617453276, 8.690799733051039, 8.738420909981391, 8.78578397184907, 8.832893070789435, 8.879752248796134, 8.926365441768558, 8.972736483370054, 9.018869108707587, 9.064766957842878, 9.1104335791443, 9.155872432488342], [0.0, 0.9165151389911681, 1.2961481396815722, 1.5874507866387546, 1.8330302779823362, 2.04939015319192, 2.244994432064365, 2.4248711305964283, 2.5922962793631443, 2.749545416973504, 2.898275349237888, 3.039736830714133, 3.174901573277509, 3.3045423283716615, 3.4292856398964493, 3.5496478698597693, 3.6660605559646724, 3.778888725538237, 3.8884444190447165, 3.9949968710876362, 4.09878030638384, 4.2, 4.298837052040936, 4.3954521951671826, 4.48998886412873, 4.582575694955841, 4.67332857821917, 4.762352359916264, 4.849742261192857, 4.935585071701227, 5.019960159204453, 5.10294032886923, 5.184592558726289, 5.264978632435274, 5.344155686354956, 5.422176684690384, 5.499090833947008, 5.574943945906542, 5.649778756730214, 5.723635208501674, 5.796550698475776, 5.868560300448484, 5.939696961967, 6.009991680526688, 6.079473661428266, 6.148170459575759, 6.216108107168022, 6.2833112289620034, 6.349803146555018, 6.4156059729381765, 6.480740698407861, 6.54522726878143, 6.609084656743323, 6.672330927044912, 6.7349832961930955, 6.797058187186572, 6.858571279792899, 6.919537556802478, 6.97997134664606, 7.0398863627192165, 7.099295739719539, 7.158212067269313, 7.216647421067486, 7.274613391789285, 7.332121111929345, 7.389181280764467, 7.445804187594514, 7.501999733404421, 7.557777451076474, 7.6131465242697125, 7.668115805072326, 7.72269383052313, 7.776888838089433, 7.830708780180758, 7.884161337770809, 7.937253933193772, 7.9899937421752725, 8.04238770515324, 8.094442537939226, 8.14616474176652, 8.19756061276768, 8.248636250920512, 8.299397568498573, 8.349850298059241, 8.4, 8.449852069711044, 8.499411744350311, 8.548684109265006, 8.597674104081872, 8.646386528486914, 8.694826047713663, 8.742997197757758, 8.790904390334365, 8.838551917593742, 8.885943956609225, 8.933084573650918, 8.97997772825746, 9.026627277117408, 9.073036977771006, 9.119210492142399, 9.165151389911681, 9.210863151735564], [0.0, 0.9219544457292888, 1.3038404810405297, 1.5968719422671316, 1.8439088914585775, 2.0615528128088303, 2.2583179581272432, 2.4392621835300936, 2.6076809620810595, 2.765863337187866, 2.9154759474226504, 3.0577769702841313, 3.193743884534263, 3.3241540277189325, 3.449637662132068, 3.5707142142714248, 3.687817782917155, 3.8013155617496426, 3.9115214431215897, 4.018706259482024, 4.123105625617661, 4.224926034855522, 4.324349662087931, 4.421538193886829, 4.5166359162544865, 4.609772228646444, 4.701063709417264, 4.790615826801394, 4.878524367060187, 4.964876634922565, 5.049752469181039, 5.13322510708424, 5.215361924162119, 5.296225070746145, 5.375872022286245, 5.454356057317858, 5.531726674375732, 5.608029957123981, 5.68330889535313, 5.757603668193913, 5.830951894845301, 5.903388857258177, 5.974947698515863, 6.0456596000767355, 6.115553940568263, 6.18465843842649, 6.252999280345393, 6.320601237224193, 6.387487769068526, 6.4536811201050215, 6.519202405202649, 6.584071688552609, 6.648308055437865, 6.711929677819935, 6.77495387438173, 6.837397165588672, 6.899275324264136, 6.960603422117942, 7.021395872616784, 7.0816664705420855, 7.1414284285428495, 7.200694410957877, 7.259476565152615, 7.317786550590281, 7.37563556583431, 7.433034373659253, 7.489993324429602, 7.546522377890362, 7.602631123499285, 7.658328799418317, 7.713624310270757, 7.768526243760782, 7.823042886243179, 7.877182237323192, 7.930952023559341, 7.984359711335657, 8.037412518964048, 8.090117428072352, 8.142481194328914, 8.194510357550353, 8.246211251235321, 8.2975900115636, 8.348652585896723, 8.399404740813482, 8.449852069711044, 8.5, 8.549853799919623, 8.599418584997478, 8.648699324175862, 8.697700845625814, 8.746427842267952, 8.794884877018005, 8.843076387773658, 8.891006692158093, 8.938679992034618, 8.986100377805714, 9.033271832508973, 9.080198235721511, 9.126883367283709, 9.173330910852394, 9.219544457292889, 9.265527507918803], [0.0, 0.9273618495495705, 1.3114877048604001, 1.6062378404209012, 1.854723699099141, 2.0736441353327724, 2.2715633383201097, 2.4535688292770597, 2.6229754097208002, 2.7820855486487113, 2.932575659723036, 3.07571129984594, 3.2124756808418025, 3.343650699460098, 3.4698703145794947, 3.591656999213594, 3.709447398198282, 3.8236108588610325, 3.9344631145812006, 4.042276586281548, 4.147288270665545, 4.249705872175156, 4.349712634186309, 4.447471191587417, 4.543126676640219, 4.636809247747852, 4.7286361670147565, 4.818713521262704, 4.907137658554119, 4.993996395673509, 5.079370039680118, 5.163332257370235, 5.2459508194416005, 5.327288240746882, 5.40740233383831, 5.486346689738081, 5.5641710972974225, 5.640921910468182, 5.716642371182581, 5.791372894228104, 5.865151319446072, 5.93801313572141, 6.009991680526689, 6.081118318204308, 6.15142259969188, 6.220932405998316, 6.289674077406556, 6.357672530100934, 6.424951361683605, 6.491532946846993, 6.557438524302001, 6.62268827591938, 6.687301398920196, 6.751296171847301, 6.814690014960329, 6.87749954561976, 6.939740629158989, 7.001428425685718, 7.062577433203831, 7.123201527403251, 7.183313998427188, 7.242927584892728, 7.302054505411474, 7.3607064878311785, 7.418894796396564, 7.476630257007497, 7.533923280734945, 7.590783885739338, 7.647221717722065, 7.703246069028303, 7.75886589650833, 7.814089838234521, 7.868926229162401, 7.923383115816122, 7.977468270071652, 8.031189202104505, 8.084553172563096, 8.137567204023572, 8.19023809177731, 8.242572413997951, 8.29457654133109, 8.346256645946134, 8.397618710086808, 8.44866853415377, 8.499411744350311, 8.549853799919623, 8.600000000000001, 8.649855490122365, 8.699425268372618, 8.748714191239761, 8.79772697916911, 8.84646822183859, 8.894942383174834, 8.943153806124549, 8.99110671719561, 9.038805230781334, 9.086253353280439, 9.133454987024352, 9.180413934022802, 9.22713389953782, 9.273618495495704, 9.319871243745807], [0.0, 0.9327379053088816, 1.3190905958272918, 1.6155494421403516, 1.8654758106177631, 2.0856653614614213, 2.2847319317591728, 2.4677925358506134, 2.6381811916545836, 2.7982137159266447, 2.9495762407505253, 3.093541659651604, 3.231098884280703, 3.363034344160048, 3.4899856733230297, 3.6124783736376886, 3.7309516212355263, 3.845776904605882, 3.957271787481876, 4.065710270051225, 4.171330722922843, 4.274342054632503, 4.374928570845472, 4.473253849269009, 4.5694638635183455, 4.663689526544408, 4.756048780237647, 4.846648326421054, 4.935585071701227, 5.022947341949744, 5.10881590977792, 5.193264869039514, 5.276362383309167, 5.358171329847526, 5.4387498563548595, 5.518151864528558, 5.596427431853289, 5.673623181001714, 5.749782604586021, 5.8249463516842805, 5.8991524815010505, 5.9724366886556455, 6.044832503882966, 6.1163714733492105, 6.187083319303208, 6.256996084384263, 6.326136261573884, 6.394528911499267, 6.462197768561406, 6.529165337162171, 6.59545297913646, 6.661080993352356, 6.726068688320096, 6.790434448545985, 6.854195795277518, 6.917369442208505, 6.979971346646059, 7.042016756583302, 7.103520254071217, 7.164495795239188, 7.224956747275377, 7.284915922644544, 7.344385610791416, 7.40337760755184, 7.4619032424710525, 7.519973404208288, 7.577598564189054, 7.634788798650556, 7.691553809211764, 7.747902942086975, 7.803845206050669, 7.859389289251424, 7.914543574963752, 7.969316156358713, 8.023714850367003, 8.077747210701757, 8.13142054010245, 8.184741901856162, 8.23771813064759, 8.290355842785038, 8.342661445845685, 8.394641147779934, 8.446300965511472, 8.49764673306675, 8.548684109265006, 8.599418584997478, 8.649855490122365, 8.700000000000001, 8.749857141690944, 8.799431799837988, 8.848728722251575, 8.897752525216692, 8.946507698538017, 8.994998610338971, 9.043229511629129, 9.091204540653564, 9.138927727036691, 9.186402995732335, 9.233634170791044, 9.280624978954814, 9.327379053088816, 9.373899935459095], [0.0, 0.938083151964686, 1.3266499161421599, 1.6248076809271923, 1.876166303929372, 2.0976176963403033, 2.297825058615212, 2.4819347291981715, 2.6532998322843198, 2.814249455894058, 2.9664793948382653, 3.1112698372208096, 3.2496153618543846, 3.3823069050575527, 3.509985754956849, 3.63318042491699, 3.752332607858744, 3.867815921162743, 3.97994974842648, 4.0890096600521755, 4.1952353926806065, 4.298837052040936, 4.4, 4.498888751680798, 4.595650117230424, 4.69041575982343, 4.7833042972405595, 4.874423042781577, 4.963869458396343, 5.0517323761260355, 5.138093031466052, 5.223025942880239, 5.3065996645686395, 5.388877434122993, 5.469917732470938, 5.549774770204643, 5.628498911788116, 5.706137047074843, 5.782732917920384, 5.858327406350725, 5.932958789676531, 6.006662967072483, 6.079473661428266, 6.151422599691879, 6.222539674441619, 6.292853089020909, 6.362389488234747, 6.431174076325411, 6.499230723708769, 6.566582063752802, 6.6332495807108005, 6.6992536897776915, 6.764613810115105, 6.82934843158555, 6.8934751758456345, 6.957010852370435, 7.019971509913698, 7.0823724838503095, 7.144228439796701, 7.205553413860728, 7.26636084983398, 7.326663633605681, 7.386474125047755, 7.445804187594514, 7.504665215717488, 7.5630681604756145, 7.62102355330306, 7.678541528180987, 7.735631842325486, 7.792303895511263, 7.848566748139434, 7.904429138147802, 7.95989949685296, 8.014985963805552, 8.069696400732806, 8.12403840463596, 8.178019320104351, 8.231646250902672, 8.284926070883193, 8.337865434270332, 8.390470785361213, 8.442748367682174, 8.494704232638123, 8.546344247688598, 8.597674104081872, 8.648699324175862, 8.699425268372618, 8.749857141690944, 8.8, 8.849858755935035, 8.899438184514796, 8.948742928478838, 8.997777503361595, 9.046546302318914, 9.09505360072166, 9.143303560529969, 9.191300234460847, 9.23904756996088, 9.28654941299512, 9.333809511662428, 9.38083151964686, 9.427618999514142], [0.0, 0.9433981132056604, 1.3341664064126333, 1.6340134638368193, 1.8867962264113207, 2.1095023109728985, 2.3108440016582685, 2.495996794869737, 2.6683328128252666, 2.830194339616981, 2.9832867780352594, 3.1288975694324033, 3.2680269276736387, 3.4014702703389896, 3.529872518944558, 3.6537651812890215, 3.7735924528226414, 3.8897300677553446, 4.0024992192379, 4.112177038990418, 4.219004621945797, 4.323193264243457, 4.424929377967517, 4.524378410345448, 4.621688003316537, 4.716990566028302, 4.810405388322278, 4.902040391510457, 4.991993589739474, 5.0803543183522155, 5.167204273105525, 5.252618394667558, 5.336665625650533, 5.419409561935692, 5.500909015790026, 5.58121850495033, 5.660388679233962, 5.7384666941614295, 5.815496539419485, 5.8915193286621745, 5.966573556070519, 6.040695324215583, 6.113918547053109, 6.186275131288617, 6.2577951388648065, 6.328506932918695, 6.398437309218556, 6.4676116148080505, 6.536053855347277, 6.603786792439623, 6.670832032063167, 6.73721010508059, 6.802940540677979, 6.868041933477111, 6.932532004974806, 6.996427659884722, 7.059745037889116, 7.122499561249548, 7.184705978674423, 7.246378405796926, 7.307530362578043, 7.368174807915458, 7.428324171709255, 7.487990384609211, 7.547184905645283, 7.6059187479225665, 7.664202502543888, 7.722046360907191, 7.779460135510689, 7.836453279386026, 7.893034904268446, 7.949213797602879, 8.0049984384758, 8.060397012554654, 8.115417426109392, 8.170067319184096, 8.224354077980836, 8.278284846512591, 8.33186653757728, 8.385105843100611, 8.438009243891594, 8.490583018850943, 8.542833253669418, 8.594765849050223, 8.646386528486914, 8.697700845625814, 8.748714191239761, 8.799431799837988, 8.849858755935035, 8.899999999999999, 8.949860334105779, 8.99944442729661, 9.048756820690896, 9.097801932335084, 9.1465840618233, 9.195107394696377, 9.243376006633074, 9.291393867445294, 9.339164844888433, 9.38669270829721, 9.433981132056603, 9.481033698917013], [0.0, 0.9486832980505138, 1.3416407864998738, 1.6431676725154984, 1.8973665961010275, 2.121320343559643, 2.32379000772445, 2.5099800796022267, 2.6832815729997477, 2.846049894151541, 3.0, 3.146426544510455, 3.286335345030997, 3.420526275297414, 3.5496478698597693, 3.674234614174767, 3.794733192202055, 3.9115214431215892, 4.024922359499621, 4.135214625627067, 4.242640687119286, 4.347413023856832, 4.449719092257398, 4.549725266430931, 4.6475800154489, 4.743416490252569, 4.83735464897913, 4.929503017546495, 5.019960159204453, 5.10881590977792, 5.196152422706632, 5.282045058497703, 5.366563145999495, 5.449770637375486, 5.531726674375733, 5.612486080160912, 5.692099788303082, 5.770615218501404, 5.848076606885378, 5.92452529743945, 6.0, 6.074537019394977, 6.148170459575759, 6.220932405998315, 6.29285308902091, 6.363961030678928, 6.434283176858165, 6.5038450166036395, 6.572670690061994, 6.640783086353597, 6.708203932499369, 6.77495387438173, 6.841052550594828, 6.906518659932804, 6.971370023173351, 7.035623639735144, 7.099295739719539, 7.162401831787993, 7.224956747275378, 7.286974680894671, 7.348469228349534, 7.409453421137082, 7.469939758793239, 7.52994023880668, 7.58946638440411, 7.648529270389177, 7.707139547199077, 7.76530746332687, 7.8230428862431785, 7.880355321938218, 7.937253933193772, 7.993747556684537, 8.049844718999243, 8.105553651663778, 8.160882305241266, 8.215838362577491, 8.270429251254134, 8.324662155306966, 8.378544026261366, 8.432081593533118, 8.485281374238571, 8.538149682454625, 8.590692637965812, 8.64291617453276, 8.694826047713663, 8.746427842267952, 8.79772697916911, 8.848728722251575, 8.899438184514796, 8.949860334105779, 9.0, 9.049861877399014, 9.099450532861862, 9.148770409186145, 9.197825830053535, 9.246621004453464, 9.2951600308978, 9.343446901438464, 9.391485505499116, 9.439279633531365, 9.486832980505138, 9.534149149242424], [0.0, 0.9539392014169457, 1.349073756323204, 1.6522711641858308, 1.9078784028338913, 2.1330729007701543, 2.3366642891095846, 2.5238858928247927, 2.698147512646408, 2.8618176042508368, 3.0166206257996713, 3.1638584039112754, 3.3045423283716615, 3.439476704383968, 3.5693136595149495, 3.694590640382233, 3.8157568056677826, 3.9331920878594273, 4.047221268969612, 4.158124577258358, 4.266145801540309, 4.371498598878879, 4.474371464239419, 4.57493169347915, 4.673328578219169, 4.769696007084729, 4.864154602806124, 4.956813492557492, 5.047771785649585, 5.137119815616529, 5.224940191045253, 5.3113086899558, 5.396295025292816, 5.479963503528103, 5.562373594069352, 5.643580423808984, 5.7236352085016735, 5.8025856305616035, 5.880476171195663, 5.957348403442593, 6.0332412515993425, 6.1081912216301815, 6.182232606429493, 6.255397669213365, 6.327716807822551, 6.399218702310462, 6.469930447848725, 6.539877674696982, 6.609084656743323, 6.67757440991862, 6.745368781616021, 6.81248853210044, 6.878953408767936, 6.944782214007867, 7.009992867328754, 7.074602462329597, 7.138627319029899, 7.202083032012336, 7.264984514780469, 7.327346040688948, 7.389181280764466, 7.450503338701353, 7.511324783285569, 7.571657678474378, 7.631513611335565, 7.6909037180295, 7.749838707999025, 7.808328886515987, 7.866384175718855, 7.924014134263013, 7.981227975693966, 8.038034585643434, 8.094442537939225, 8.150460109711599, 8.206095295571457, 8.261355820929154, 8.316249154516717, 8.370782520170978, 8.424962907930219, 8.478797084492587, 8.532291603080617, 8.58545281275251, 8.638286867197687, 8.690799733051039, 8.742997197757758, 8.794884877018005, 8.84646822183859, 8.897752525216692, 8.948742928478838, 8.99944442729661, 9.049861877399014, 9.1, 9.1498633869583, 9.199456505685541, 9.248783703817493, 9.297849213662264, 9.346657156438338, 9.395211546314432, 9.443516294262428, 9.491575211733826, 9.539392014169458, 9.586970324351693], [0.0, 0.959166304662544, 1.3564659966250536, 1.6613247725836153, 1.918332609325088, 2.144761058952722, 2.349468024894146, 2.5377155080899043, 2.7129319932501073, 2.877498913987632, 3.0331501776206204, 3.1811947441173736, 3.3226495451672307, 3.458323293158117, 3.5888716889852725, 3.714835124201342, 3.836665218650176, 3.954743986657038, 4.069397989875161, 4.180908992073375, 4.289522117905444, 4.3954521951671826, 4.498888751680798, 4.6000000000000005, 4.698936049788292, 4.79583152331272, 4.8908077042549944, 4.983974317750846, 5.075431016179809, 5.165268628057984, 5.253570214625479, 5.340411969127476, 5.4258639865002145, 5.509990925582366, 5.592852581643825, 5.674504383644443, 5.754997827975264, 5.83438085832593, 5.912698199637794, 5.989991652748776, 6.066300355241241, 6.1416610131136355, 6.216108107168022, 6.289674077406555, 6.362389488234747, 6.434283176858165, 6.505382386916238, 6.575712889109439, 6.645299090334461, 6.714164132637808, 6.782329983125269, 6.8498175158174845, 6.916646586316234, 6.982836100038438, 7.0484040746824395, 7.113367697511497, 7.177743377970545, 7.24154679609267, 7.3047929470998705, 7.367496182557545, 7.429670248402684, 7.491328320131218, 7.552483035399683, 7.6131465242697125, 7.673330437300352, 7.733045971672482, 7.792303895511263, 7.851114570556209, 7.909487973314076, 7.967433714816837, 8.024961059095553, 8.082078940470701, 8.138795979750322, 8.195120499419152, 8.251060537894508, 8.306623862918075, 8.36181798414675, 8.416650165000327, 8.47112743381895, 8.525256594378847, 8.579044235810889, 8.632496741962896, 8.685620300243388, 8.738420909981391, 8.790904390334365, 8.843076387773658, 8.894942383174834, 8.946507698538017, 8.997777503361595, 9.048756820690896, 9.099450532861862, 9.1498633869583, 9.200000000000001, 9.249864863877743, 9.299462350050137, 9.348796714016196, 9.397872099576585, 9.446692542895637, 9.495261976375376, 9.54358423235212, 9.59166304662544, 9.639502061828715], [0.0, 0.9643650760992956, 1.3638181696985856, 1.670329308849007, 1.9287301521985911, 2.1563858652847827, 2.3622023622035435, 2.551470164434615, 2.727636339397171, 2.8930952282978866, 3.0495901363953815, 3.1984371183438958, 3.340658617698014, 3.4770677301427426, 3.6083237105337433, 3.7349698793966195, 3.8574603043971822, 3.976179070414209, 4.091454509095757, 4.203569911396741, 4.312771730569565, 4.419275958796871, 4.523273151159457, 4.624932431938872, 4.724404724407087, 4.821825380496478, 4.917316341257699, 5.0109879265470205, 5.10294032886923, 5.193264869039514, 5.282045058497703, 5.36935750346352, 5.455272678794342, 5.539855593785817, 5.62316636780382, 5.705260730238365, 5.786190456595773, 5.866003750424986, 5.944745579080741, 6.02245796996542, 6.099180272790763, 6.174949392505174, 6.249799996799899, 6.323764701504951, 6.3968742366877915, 6.469157595854347, 6.540642170307134, 6.611353870426239, 6.681317235396028, 6.750555532695069, 6.8190908484929285, 6.886944169949399, 6.954135460285485, 7.020683727387242, 7.0866070866106305, 7.15192281837549, 7.216647421067487, 7.280796659706959, 7.3443856107914165, 7.407428703673091, 7.469939758793239, 7.531932023060219, 7.593418202627852, 7.654410493303845, 7.7149206087943645, 7.774959806970066, 7.834538914320357, 7.893668348746355, 7.952358140828418, 8.010617953691215, 8.068457101577724, 8.125884567233282, 8.182909018191515, 8.239538822045807, 8.295782060782456, 8.351646544245034, 8.407139822793482, 8.462269199216012, 8.517041739947036, 8.571464285639882, 8.62554346113913, 8.67928568489366, 8.732697177848321, 8.78578397184907, 8.838551917593742, 8.891006692158093, 8.943153806124549, 8.994998610338971, 9.046546302318914, 9.097801932335084, 9.148770409186145, 9.199456505685541, 9.249864863877743, 9.3, 9.349866309204641, 9.39946807005588, 9.448809448814174, 9.497894503520243, 9.5467271878901, 9.595311355031686, 9.643650760992957, 9.691749068150704], [0.0, 0.9695359714832659, 1.3711309200802089, 1.6792855623746668, 1.9390719429665317, 2.1679483388678804, 2.374868417407584, 2.5651510676761324, 2.7422618401604177, 2.9086079144497976, 3.0659419433511785, 3.2155870381627056, 3.3585711247493335, 3.4957116585897072, 3.627671429443411, 3.7549966711037173, 3.8781438859330635, 3.9974992182613374, 4.113392760240627, 4.226109321823088, 4.335896677735761, 4.442971978304612, 4.54752680036083, 4.649731175025068, 4.749736834815168, 4.847679857416329, 4.943682837723311, 5.037856687124, 5.130302135352265, 5.221110992882646, 5.310367218940701, 5.398147830506312, 5.4845236803208355, 5.569560126257729, 5.653317610041029, 5.735852159879995, 5.817215828899595, 5.897457079114693, 5.976621118993575, 6.054750201288242, 6.131883886702357, 6.208059278067504, 6.283311228962004, 6.357672530100933, 6.431174076325411, 6.5038450166036395, 6.57571288910944, 6.646803743153547, 6.717142249498667, 6.786751800382861, 6.855654600401045, 6.923871749245506, 6.9914233171794145, 7.058328414008519, 7.124605252222751, 7.1902712048990205, 7.255342858886822, 7.31983606373804, 7.383765976789894, 7.447147104764348, 7.5099933422074345, 7.572318007057021, 7.634133873596926, 7.695453203028396, 7.756287771866127, 7.816648898345122, 7.8765474670060875, 7.935993951610599, 7.994998436522675, 8.053570636680355, 8.1117199162693, 8.16945530620004, 8.226785520481254, 8.283718971573094, 8.340263784797218, 8.396427811873334, 8.452218643646177, 8.507643622061282, 8.56270985144306, 8.61742420912421, 8.671793355471522, 8.725823743349393, 8.77952162705919, 8.832893070789435, 8.885943956609225, 8.938679992034618, 8.99110671719561, 9.043229511629129, 9.09505360072166, 9.1465840618233, 9.197825830053535, 9.248783703817493, 9.299462350050137, 9.349866309204641, 9.4, 9.44986772394196, 9.499473669630335, 9.548821916864929, 9.597916440561463, 9.646761114488118, 9.695359714832659, 9.743715923609434], [0.0, 0.9746794344808963, 1.378404875209022, 1.6881943016134133, 1.9493588689617927, 2.179449471770337, 2.3874672772626644, 2.578759391645525, 2.756809750418044, 2.9240383034426887, 3.082207001484488, 3.2326459750489227, 3.3763886032268267, 3.5142566781611158, 3.6469165057620936, 3.7749172176353745, 3.8987177379235853, 4.018706259482023, 4.135214625627066, 4.2485291572496005, 4.358898943540674, 4.466542286825459, 4.571651780264984, 4.674398357008098, 4.774934554525329, 4.873397172404482, 4.969909455915671, 5.06458290484024, 5.15751878329105, 5.2488093888042835, 5.338539126015655, 5.426785420486054, 5.513619500836088, 5.599107071667768, 5.683308895353129, 5.766281297335397, 5.848076606885377, 5.928743543112655, 6.008327554319921, 6.08687111741328, 6.164414002968976, 6.24099351065197, 6.316644678941503, 6.3914004725099165, 6.465291950097845, 6.53834841531101, 6.6105975524153635, 6.682065548915245, 6.752777206453653, 6.822756041366274, 6.892024376045111, 6.960603422117942, 7.0285133563222315, 7.095773389842717, 7.162401831787993, 7.2284161474004796, 7.293833011524187, 7.358668357794092, 7.4229374239582535, 7.486654793697916, 7.549834435270749, 7.6124897372673015, 7.674633541739956, 7.736278174936576, 7.797435475847171, 7.858116822750854, 7.918333157931661, 7.978095010715276, 8.037412518964047, 8.096295449154509, 8.154753215150045, 8.212794895770866, 8.270429251254132, 8.327664738688751, 8.384509526501832, 8.440971508067065, 8.497058314499201, 8.55277732669336, 8.608135686662937, 8.663140308225419, 8.717797887081348, 8.772114910328067, 8.826097665446492, 8.879752248796134, 8.933084573650918, 8.986100377805714, 9.038805230781334, 9.091204540653564, 9.143303560529969, 9.195107394696377, 9.246621004453464, 9.297849213662264, 9.348796714016196, 9.39946807005588, 9.44986772394196, 9.499999999999998, 9.549869109050658, 9.599479152537391, 9.648834126463154, 9.697937925146768, 9.746794344808963, 9.795407086997457], [0.0, 0.9797958971132713, 1.3856406460551018, 1.6970562748477143, 1.9595917942265426, 2.1908902300206647, 2.4000000000000004, 2.5922962793631443, 2.7712812921102037, 2.939387691339814, 3.0983866769659336, 3.2496153618543846, 3.3941125496954285, 3.532704346531139, 3.666060555964672, 3.794733192202055, 3.9191835884530852, 4.039801975344831, 4.156921938165306, 4.270831300812525, 4.3817804600413295, 4.48998886412873, 4.595650117230424, 4.698936049788292, 4.800000000000001, 4.898979485566357, 4.9959983987187195, 5.091168824543143, 5.184592558726289, 5.276362383309168, 5.366563145999495, 5.455272678794342, 5.542562584220407, 5.628498911788117, 5.713142742834281, 5.796550698475776, 5.878775382679628, 5.959865770300536, 6.0398675482166, 6.118823416311343, 6.196773353931867, 6.27375485654325, 6.349803146555018, 6.424951361683604, 6.499230723708769, 6.572670690061993, 6.64529909033446, 6.717142249498666, 6.788225099390857, 6.858571279792899, 6.92820323027551, 6.997142273814362, 7.065408693062278, 7.1330218000508046, 7.2, 7.266360849833981, 7.332121111929344, 7.397296803562772, 7.4619032424710525, 7.525955088890711, 7.58946638440411, 7.652450587883597, 7.714920608794364, 7.776888838089433, 7.8383671769061705, 7.899367063252599, 7.95989949685296, 8.019975062305368, 8.079603950689663, 8.138795979750322, 8.19756061276768, 8.255906976220118, 8.313843876330612, 8.37137981458254, 8.42852300228219, 8.485281374238571, 8.54166260162505, 8.597674104081872, 8.653323061113575, 8.708616422830897, 8.763560920082659, 8.818163074019441, 8.872429205127535, 8.926365441768558, 8.97997772825746, 9.033271832508973, 9.086253353280439, 9.138927727036691, 9.191300234460847, 9.243376006633074, 9.2951600308978, 9.346657156438338, 9.397872099576585, 9.448809448814174, 9.499473669630335, 9.549869109050658, 9.600000000000001, 9.649870465451857, 9.699484522385713, 9.748846085563153, 9.797958971132713, 9.846826900072939], [0.0, 0.9848857801796106, 1.392838827718412, 1.7058722109231985, 1.9697715603592212, 2.2022715545545246, 2.412467616362964, 2.6057628441590768, 2.785677655436824, 2.9546573405388314, 3.1144823004794877, 3.2664965942122155, 3.411744421846397, 3.5510561809129415, 3.685105154537656, 3.8144462245521304, 3.9395431207184424, 4.060788100849391, 4.178516483155236, 4.293017586733137, 4.404543109109049, 4.513313638558704, 4.61952378498044, 4.723346271447818, 4.824935232725928, 4.924428900898053, 5.021951811795889, 5.117616632769595, 5.2115256883181535, 5.3037722424704485, 5.394441583704471, 5.483611948342078, 5.571355310873648, 5.657738063926256, 5.742821606144492, 5.826662852782887, 5.909314681077663, 5.990826320300065, 6.071243694664217, 6.150609725872713, 6.228964600958975, 6.306346010171025, 6.38278935889318, 6.458327956987009, 6.532993188424431, 6.606814663663572, 6.679820356865895, 6.7520367297579185, 6.823488843692794, 6.894200461257274, 6.9641941385920605, 7.033491309442276, 7.102112361825883, 7.170076708097342, 7.237402849088892, 7.30410843293006, 7.370210309075312, 7.4357245780085215, 7.5006666370396715, 7.565051222562872, 7.628892449104261, 7.692203845452876, 7.754998388136519, 7.817288532477231, 7.879086241436885, 7.940403012442127, 8.001249902359007, 8.061637550770936, 8.121576201698781, 8.18107572388864, 8.240145629781066, 8.298795093265047, 8.357032966310472, 8.414867794564572, 8.472307831990054, 8.529361054615991, 8.586035173466273, 8.64233764672499, 8.698275691193055, 8.753856293085923, 8.809086218218098, 8.863972021616496, 8.918520056601322, 8.972736483370054, 9.026627277117408, 9.080198235721511, 9.133454987024352, 9.186402995732335, 9.23904756996088, 9.291393867445294, 9.343446901438464, 9.395211546314432, 9.446692542895637, 9.497894503520243, 9.548821916864929, 9.599479152537391, 9.649870465451857, 9.700000000000003, 9.749871794028884, 9.799489782636646, 9.848857801796106, 9.897979591815698], [0.0, 0.9899494936611666, 1.4, 1.7146428199482249, 1.9798989873223332, 2.2135943621178655, 2.4248711305964283, 2.619160170741759, 2.8, 2.9698484809834995, 3.1304951684997055, 3.283291031876401, 3.4292856398964497, 3.5693136595149495, 3.704051835490427, 3.8340579025361623, 3.9597979746446663, 4.08166632639171, 4.2, 4.315089802078284, 4.427188724235731, 4.536518488885503, 4.64327470649756, 4.747630988187688, 4.849742261192857, 4.949747468305833, 5.047771785649585, 5.143928459844674, 5.238320341483518, 5.331041174104736, 5.422176684690383, 5.511805511808268, 5.6, 5.686826883245173, 5.772347875864725, 5.856620185738529, 5.939696961966999, 6.021627686929839, 6.102458520956943, 6.182232606429493, 6.260990336999411, 6.338769596696192, 6.4156059729381765, 6.491532946846992, 6.566582063752802, 6.640783086353596, 6.714164132637808, 6.786751800382861, 6.8585712797928995, 6.929646455628165, 7.0, 7.069653456853455, 7.138627319029899, 7.206941098690901, 7.274613391789285, 7.341661937191061, 7.408103670980854, 7.473954776421918, 7.539230729988306, 7.603946343840151, 7.668115805072325, 7.731752712031082, 7.79487010796203, 7.857480512225277, 7.919595949289333, 7.981227975693965, 8.04238770515324, 8.103085831953157, 8.16333265278342, 8.223138087129511, 8.282511696339462, 8.341462701469089, 8.4, 8.4581321815162, 8.515867542417507, 8.573214099741124, 8.630179604156568, 8.6867715521936, 8.742997197757758, 8.798863562983575, 8.854377448471462, 8.909545442950499, 8.964373932405989, 9.018869108707587, 9.073036977771006, 9.126883367283709, 9.180413934022802, 9.233634170791044, 9.28654941299512, 9.339164844888433, 9.391485505499116, 9.443516294262428, 9.495261976375376, 9.5467271878901, 9.597916440561463, 9.648834126463154, 9.699484522385713, 9.749871794028884, 9.8, 9.849873095629203, 9.899494936611665, 9.948869282486328], [0.0, 0.9949874371066201, 1.407124727947029, 1.7233687939614089, 1.9899748742132402, 2.224859546128699, 2.4372115213907883, 2.632489316217637, 2.814249455894058, 2.98496231131986, 3.146426544510455, 3.3000000000000007, 3.4467375879228177, 3.58747822293042, 3.722902093797257, 3.853569773599539, 3.9799497484264803, 4.102438299353203, 4.221374183841087, 4.337049688440289, 4.449719092257398, 4.559605246071199, 4.666904755831214, 4.77179211617606, 4.874423042781577, 4.974937185533101, 5.073460357586329, 5.170106381884226, 5.264978632435274, 5.358171329847527, 5.449770637375485, 5.539855593785817, 5.628498911788116, 5.715767664977296, 5.801723881744115, 5.886425061104576, 5.96992462263972, 6.052272300549605, 6.133514490078262, 6.213694553162394, 6.29285308902091, 6.3710281744785915, 6.448255578061405, 6.524568951279464, 6.600000000000001, 6.674578638386096, 6.748333127521196, 6.821290200541244, 6.893475175845635, 6.96491205974634, 7.035623639735145, 7.105631569396208, 7.17495644586084, 7.243617880589783, 7.3116345641723655, 7.379024325749307, 7.445804187594514, 7.5119904153293495, 7.577598564189055, 7.642643521714199, 7.707139547199078, 7.771100308193172, 7.834538914320357, 7.897467948652911, 7.959899496852961, 8.021845174272563, 8.083316151184489, 8.144323176298936, 8.204876598706406, 8.264986388373547, 8.324662155306966, 8.383913167489272, 8.442748367682174, 8.501176389182852, 8.559205570612264, 8.616843969807043, 8.674099376880578, 8.73097932651315, 8.787491109526087, 8.843641783790206, 8.899438184514796, 8.95488693395958, 9.009994450608726, 9.064766957842878, 9.119210492142399, 9.173330910852394, 9.22713389953782, 9.280624978954814, 9.333809511662428, 9.38669270829721, 9.439279633531365, 9.491575211733826, 9.54358423235212, 9.595311355031686, 9.646761114488118, 9.697937925146768, 9.748846085563153, 9.799489782636646, 9.849873095629203, 9.900000000000002, 9.949874371066201, 9.999499987499377], [0.0, 1.0, 1.4142135623730951, 1.7320508075688776, 2.0, 2.23606797749979, 2.4494897427831783, 2.6457513110645907, 2.8284271247461903, 3.0, 3.1622776601683795, 3.3166247903554003, 3.4641016151377553, 3.6055512754639896, 3.7416573867739413, 3.8729833462074166, 4.0, 4.123105625617661, 4.242640687119286, 4.358898943540674, 4.47213595499958, 4.582575694955841, 4.69041575982343, 4.79583152331272, 4.898979485566357, 5.000000000000001, 5.099019513592785, 5.196152422706633, 5.291502622129181, 5.385164807134505, 5.477225575051661, 5.567764362830022, 5.656854249492381, 5.7445626465380295, 5.830951894845301, 5.916079783099616, 6.0, 6.08276253029822, 6.164414002968977, 6.244997998398399, 6.324555320336759, 6.403124237432849, 6.480740698407861, 6.557438524302, 6.6332495807108005, 6.7082039324993685, 6.782329983125269, 6.855654600401045, 6.9282032302755105, 7.0, 7.071067811865476, 7.141428428542851, 7.211102550927979, 7.28010988928052, 7.348469228349535, 7.416198487095664, 7.483314773547883, 7.54983443527075, 7.6157731058639095, 7.681145747868608, 7.745966692414833, 7.810249675906655, 7.874007874011811, 7.937253933193772, 8.0, 8.06225774829855, 8.12403840463596, 8.18535277187245, 8.246211251235321, 8.306623862918075, 8.366600265340756, 8.426149773176359, 8.485281374238571, 8.544003745317532, 8.602325267042627, 8.660254037844387, 8.717797887081348, 8.774964387392123, 8.831760866327848, 8.88819441731559, 8.94427190999916, 9.000000000000002, 9.055385138137417, 9.1104335791443, 9.165151389911681, 9.219544457292889, 9.273618495495704, 9.327379053088816, 9.38083151964686, 9.433981132056603, 9.486832980505138, 9.539392014169458, 9.59166304662544, 9.643650760992957, 9.695359714832659, 9.746794344808963, 9.797958971132713, 9.848857801796106, 9.899494936611665, 9.949874371066201, 10.000000000000002, 10.049875621120892], [0.0, 1.0049875621120892, 1.4212670403551897, 1.7406895185529214, 2.0099751242241783, 2.2472205054244236, 2.4617067250182347, 2.6589471600616665, 2.8425340807103794, 3.0149626863362675, 3.178049716414141, 3.333166662499792, 3.481379037105843, 3.6235341863986883, 3.7603191353926335, 3.892300091205713, 4.019950248448357, 4.1436698710201325, 4.263801121065569, 4.380639222761903, 4.494441010848847, 4.605431575867782, 4.713809499757071, 4.819751030914357, 4.9234134500364695, 5.024937810560446, 5.1244511901275835, 5.222068555658764, 5.317894320123333, 5.412023651093924, 5.504543577809154, 5.595533933415113, 5.685068161420759, 5.773214009544425, 5.860034129593445, 5.9455865984779, 6.029925372672535, 6.113100686231171, 6.1951594006934165, 6.276145313805283, 6.356099432828282, 6.435060217278469, 6.5130637951735135, 6.590144156238162, 6.666333324999584, 6.74166151627327, 6.81615727518079, 6.889847603539574, 6.962758074211686, 7.034912934784624, 7.1063352017759485, 7.177046746399247, 7.247068372797377, 7.31641988953614, 7.385120175054704, 7.4531872376856345, 7.520638270785267, 7.587489703452652, 7.653757247260983, 7.719455939378112, 7.784600182411426, 7.849203781276163, 7.913279977354524, 7.976841480185, 8.039900496896713, 8.10246875958186, 8.16455755078008, 8.226177727231525, 8.287339742040265, 8.34805366537614, 8.408329203831164, 8.468175718535841, 8.527602242131138, 8.586617494683225, 8.645229898620395, 8.703447592764606, 8.761278445523805, 8.81873006730561, 8.875809822207776, 8.932524839036274, 8.988882021697695, 9.044888059008803, 9.100549433962767, 9.155872432488342, 9.210863151735564, 9.265527507918803, 9.319871243745807, 9.373899935459095, 9.427618999514142, 9.481033698917013, 9.534149149242424, 9.586970324351693, 9.639502061828715, 9.691749068150704, 9.743715923609434, 9.795407086997457, 9.846826900072939, 9.897979591815698, 9.948869282486328, 9.999499987499377, 10.049875621120892, 10.100000000000001]]}],\n",
       "                        {\"autosize\": false, \"height\": 500, \"margin\": {\"b\": 65, \"l\": 65, \"r\": 50, \"t\": 90}, \"scene\": {\"xaxis\": {\"title\": {\"text\": \"K\"}}, \"yaxis\": {\"title\": {\"text\": \"L\"}}, \"zaxis\": {\"title\": {\"text\": \"Y\"}}}, \"template\": {\"data\": {\"bar\": [{\"error_x\": {\"color\": \"#2a3f5f\"}, \"error_y\": {\"color\": \"#2a3f5f\"}, \"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"bar\"}], \"barpolar\": [{\"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"barpolar\"}], \"carpet\": [{\"aaxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"baxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"type\": \"carpet\"}], \"choropleth\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"choropleth\"}], \"contour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"contour\"}], \"contourcarpet\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"contourcarpet\"}], \"heatmap\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmap\"}], \"heatmapgl\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmapgl\"}], \"histogram\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"histogram\"}], \"histogram2d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2d\"}], \"histogram2dcontour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2dcontour\"}], \"mesh3d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"mesh3d\"}], \"parcoords\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"parcoords\"}], \"scatter\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter\"}], \"scatter3d\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter3d\"}], \"scattercarpet\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattercarpet\"}], \"scattergeo\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergeo\"}], \"scattergl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergl\"}], \"scattermapbox\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattermapbox\"}], \"scatterpolar\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolar\"}], \"scatterpolargl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolargl\"}], \"scatterternary\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterternary\"}], \"surface\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"surface\"}], \"table\": [{\"cells\": {\"fill\": {\"color\": \"#EBF0F8\"}, \"line\": {\"color\": \"white\"}}, \"header\": {\"fill\": {\"color\": \"#C8D4E3\"}, \"line\": {\"color\": \"white\"}}, \"type\": \"table\"}]}, \"layout\": {\"annotationdefaults\": {\"arrowcolor\": \"#2a3f5f\", \"arrowhead\": 0, \"arrowwidth\": 1}, \"colorscale\": {\"diverging\": [[0, \"#8e0152\"], [0.1, \"#c51b7d\"], [0.2, \"#de77ae\"], [0.3, \"#f1b6da\"], [0.4, \"#fde0ef\"], [0.5, \"#f7f7f7\"], [0.6, \"#e6f5d0\"], [0.7, \"#b8e186\"], [0.8, \"#7fbc41\"], [0.9, \"#4d9221\"], [1, \"#276419\"]], \"sequential\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"sequentialminus\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]]}, \"colorway\": [\"#636efa\", \"#EF553B\", \"#00cc96\", \"#ab63fa\", \"#FFA15A\", \"#19d3f3\", \"#FF6692\", \"#B6E880\", \"#FF97FF\", \"#FECB52\"], \"font\": {\"color\": \"#2a3f5f\"}, \"geo\": {\"bgcolor\": \"white\", \"lakecolor\": \"white\", \"landcolor\": \"#E5ECF6\", \"showlakes\": true, \"showland\": true, \"subunitcolor\": \"white\"}, \"hoverlabel\": {\"align\": \"left\"}, \"hovermode\": \"closest\", \"mapbox\": {\"style\": \"light\"}, \"paper_bgcolor\": \"white\", \"plot_bgcolor\": \"#E5ECF6\", \"polar\": {\"angularaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"radialaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"scene\": {\"xaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"yaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"zaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}}, \"shapedefaults\": {\"line\": {\"color\": \"#2a3f5f\"}}, \"ternary\": {\"aaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"baxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"caxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"title\": {\"x\": 0.05}, \"xaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}, \"yaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}}}, \"title\": {\"text\": \"Cobb-Douglas Production Function\"}, \"width\": 500},\n",
       "                        {\"responsive\": true}\n",
       "                    )\n",
       "                };\n",
       "                \n",
       "            </script>\n",
       "        </div>\n",
       "</body>\n",
       "</html>"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "change_alpha(0.3, filename=\"fig3.html\")\n",
    "display(HTML(\"fig3.html\"))"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Below is an interactive plot with a slider to change $\\alpha$. Try out different values and see how the shape of the production function changes."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 16,
   "metadata": {
    "tags": [
     "remove_input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<html>\n",
       "<head><meta charset=\"utf-8\" /></head>\n",
       "<body>\n",
       "    <div>\n",
       "            <script src=\"https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.5/MathJax.js?config=TeX-AMS-MML_SVG\"></script><script type=\"text/javascript\">if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}</script>\n",
       "                <script type=\"text/javascript\">window.PlotlyConfig = {MathJaxConfig: 'local'};</script>\n",
       "        <script type=\"text/javascript\">/**\n",
       "* plotly.js v1.49.1\n",
       "* Copyright 2012-2019, Plotly, Inc.\n",
       "* All rights reserved.\n",
       "* Licensed under the MIT license\n",
       "*/\n",
       "!function(t){if(\"object\"==typeof exports&&\"undefined\"!=typeof module)module.exports=t();else if(\"function\"==typeof define&&define.amd)define([],t);else{(\"undefined\"!=typeof window?window:\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:this).Plotly=t()}}(function(){return function(){return function t(e,r,n){function i(o,s){if(!r[o]){if(!e[o]){var l=\"function\"==typeof require&&require;if(!s&&l)return l(o,!0);if(a)return a(o,!0);var c=new Error(\"Cannot find module '\"+o+\"'\");throw c.code=\"MODULE_NOT_FOUND\",c}var u=r[o]={exports:{}};e[o][0].call(u.exports,function(t){return i(e[o][1][t]||t)},u,u.exports,t,e,r,n)}return r[o].exports}for(var a=\"function\"==typeof require&&require,o=0;o<n.length;o++)i(n[o]);return i}}()({1:[function(t,e,r){\"use strict\";var n=t(\"../src/lib\"),i={\"X,X div\":\"direction:ltr;font-family:'Open Sans', verdana, arial, sans-serif;margin:0;padding:0;\",\"X input,X button\":\"font-family:'Open Sans', verdana, arial, sans-serif;\",\"X input:focus,X button:focus\":\"outline:none;\",\"X a\":\"text-decoration:none;\",\"X a:hover\":\"text-decoration:none;\",\"X .crisp\":\"shape-rendering:crispEdges;\",\"X .user-select-none\":\"-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;\",\"X svg\":\"overflow:hidden;\",\"X svg a\":\"fill:#447adb;\",\"X svg a:hover\":\"fill:#3c6dc5;\",\"X .main-svg\":\"position:absolute;top:0;left:0;pointer-events:none;\",\"X .main-svg .draglayer\":\"pointer-events:all;\",\"X .cursor-default\":\"cursor:default;\",\"X .cursor-pointer\":\"cursor:pointer;\",\"X .cursor-crosshair\":\"cursor:crosshair;\",\"X .cursor-move\":\"cursor:move;\",\"X .cursor-col-resize\":\"cursor:col-resize;\",\"X .cursor-row-resize\":\"cursor:row-resize;\",\"X .cursor-ns-resize\":\"cursor:ns-resize;\",\"X .cursor-ew-resize\":\"cursor:ew-resize;\",\"X .cursor-sw-resize\":\"cursor:sw-resize;\",\"X .cursor-s-resize\":\"cursor:s-resize;\",\"X .cursor-se-resize\":\"cursor:se-resize;\",\"X .cursor-w-resize\":\"cursor:w-resize;\",\"X .cursor-e-resize\":\"cursor:e-resize;\",\"X .cursor-nw-resize\":\"cursor:nw-resize;\",\"X .cursor-n-resize\":\"cursor:n-resize;\",\"X .cursor-ne-resize\":\"cursor:ne-resize;\",\"X .cursor-grab\":\"cursor:-webkit-grab;cursor:grab;\",\"X .modebar\":\"position:absolute;top:2px;right:2px;\",\"X .ease-bg\":\"-webkit-transition:background-color 0.3s ease 0s;-moz-transition:background-color 0.3s ease 0s;-ms-transition:background-color 0.3s ease 0s;-o-transition:background-color 0.3s ease 0s;transition:background-color 0.3s ease 0s;\",\"X .modebar--hover>:not(.watermark)\":\"opacity:0;-webkit-transition:opacity 0.3s ease 0s;-moz-transition:opacity 0.3s ease 0s;-ms-transition:opacity 0.3s ease 0s;-o-transition:opacity 0.3s ease 0s;transition:opacity 0.3s ease 0s;\",\"X:hover .modebar--hover .modebar-group\":\"opacity:1;\",\"X .modebar-group\":\"float:left;display:inline-block;box-sizing:border-box;padding-left:8px;position:relative;vertical-align:middle;white-space:nowrap;\",\"X .modebar-btn\":\"position:relative;font-size:16px;padding:3px 4px;height:22px;cursor:pointer;line-height:normal;box-sizing:border-box;\",\"X .modebar-btn svg\":\"position:relative;top:2px;\",\"X .modebar.vertical\":\"display:flex;flex-direction:column;flex-wrap:wrap;align-content:flex-end;max-height:100%;\",\"X .modebar.vertical svg\":\"top:-1px;\",\"X .modebar.vertical .modebar-group\":\"display:block;float:none;padding-left:0px;padding-bottom:8px;\",\"X .modebar.vertical .modebar-group .modebar-btn\":\"display:block;text-align:center;\",\"X [data-title]:before,X [data-title]:after\":\"position:absolute;-webkit-transform:translate3d(0, 0, 0);-moz-transform:translate3d(0, 0, 0);-ms-transform:translate3d(0, 0, 0);-o-transform:translate3d(0, 0, 0);transform:translate3d(0, 0, 0);display:none;opacity:0;z-index:1001;pointer-events:none;top:110%;right:50%;\",\"X [data-title]:hover:before,X [data-title]:hover:after\":\"display:block;opacity:1;\",\"X [data-title]:before\":\"content:'';position:absolute;background:transparent;border:6px solid transparent;z-index:1002;margin-top:-12px;border-bottom-color:#69738a;margin-right:-6px;\",\"X [data-title]:after\":\"content:attr(data-title);background:#69738a;color:white;padding:8px 10px;font-size:12px;line-height:12px;white-space:nowrap;margin-right:-18px;border-radius:2px;\",\"X .vertical [data-title]:before,X .vertical [data-title]:after\":\"top:0%;right:200%;\",\"X .vertical [data-title]:before\":\"border:6px solid transparent;border-left-color:#69738a;margin-top:8px;margin-right:-30px;\",\"X .select-outline\":\"fill:none;stroke-width:1;shape-rendering:crispEdges;\",\"X .select-outline-1\":\"stroke:white;\",\"X .select-outline-2\":\"stroke:black;stroke-dasharray:2px 2px;\",Y:\"font-family:'Open Sans';position:fixed;top:50px;right:20px;z-index:10000;font-size:10pt;max-width:180px;\",\"Y p\":\"margin:0;\",\"Y .notifier-note\":\"min-width:180px;max-width:250px;border:1px solid #fff;z-index:3000;margin:0;background-color:#8c97af;background-color:rgba(140,151,175,0.9);color:#fff;padding:10px;overflow-wrap:break-word;word-wrap:break-word;-ms-hyphens:auto;-webkit-hyphens:auto;hyphens:auto;\",\"Y .notifier-close\":\"color:#fff;opacity:0.8;float:right;padding:0 5px;background:none;border:none;font-size:20px;font-weight:bold;line-height:20px;\",\"Y .notifier-close:hover\":\"color:#444;text-decoration:none;cursor:pointer;\"};for(var a in i){var o=a.replace(/^,/,\" ,\").replace(/X/g,\".js-plotly-plot .plotly\").replace(/Y/g,\".plotly-notifier\");n.addStyleRule(o,i[a])}},{\"../src/lib\":719}],2:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/aggregate\")},{\"../src/transforms/aggregate\":1265}],3:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/bar\")},{\"../src/traces/bar\":864}],4:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/barpolar\")},{\"../src/traces/barpolar\":876}],5:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/box\")},{\"../src/traces/box\":886}],6:[function(t,e,r){\"use strict\";e.exports=t(\"../src/components/calendars\")},{\"../src/components/calendars\":591}],7:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/candlestick\")},{\"../src/traces/candlestick\":895}],8:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/carpet\")},{\"../src/traces/carpet\":914}],9:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choropleth\")},{\"../src/traces/choropleth\":928}],10:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choroplethmapbox\")},{\"../src/traces/choroplethmapbox\":935}],11:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/cone\")},{\"../src/traces/cone\":941}],12:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contour\")},{\"../src/traces/contour\":956}],13:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contourcarpet\")},{\"../src/traces/contourcarpet\":967}],14:[function(t,e,r){\"use strict\";e.exports=t(\"../src/core\")},{\"../src/core\":697}],15:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/densitymapbox\")},{\"../src/traces/densitymapbox\":977}],16:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/filter\")},{\"../src/transforms/filter\":1266}],17:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnel\")},{\"../src/traces/funnel\":987}],18:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnelarea\")},{\"../src/traces/funnelarea\":996}],19:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/groupby\")},{\"../src/transforms/groupby\":1267}],20:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmap\")},{\"../src/traces/heatmap\":1009}],21:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmapgl\")},{\"../src/traces/heatmapgl\":1018}],22:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram\")},{\"../src/traces/histogram\":1030}],23:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2d\")},{\"../src/traces/histogram2d\":1036}],24:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2dcontour\")},{\"../src/traces/histogram2dcontour\":1040}],25:[function(t,e,r){\"use strict\";var n=t(\"./core\");n.register([t(\"./bar\"),t(\"./box\"),t(\"./heatmap\"),t(\"./histogram\"),t(\"./histogram2d\"),t(\"./histogram2dcontour\"),t(\"./contour\"),t(\"./scatterternary\"),t(\"./violin\"),t(\"./funnel\"),t(\"./waterfall\"),t(\"./pie\"),t(\"./sunburst\"),t(\"./funnelarea\"),t(\"./scatter3d\"),t(\"./surface\"),t(\"./isosurface\"),t(\"./volume\"),t(\"./mesh3d\"),t(\"./cone\"),t(\"./streamtube\"),t(\"./scattergeo\"),t(\"./choropleth\"),t(\"./scattergl\"),t(\"./splom\"),t(\"./pointcloud\"),t(\"./heatmapgl\"),t(\"./parcoords\"),t(\"./parcats\"),t(\"./scattermapbox\"),t(\"./choroplethmapbox\"),t(\"./densitymapbox\"),t(\"./sankey\"),t(\"./indicator\"),t(\"./table\"),t(\"./carpet\"),t(\"./scattercarpet\"),t(\"./contourcarpet\"),t(\"./ohlc\"),t(\"./candlestick\"),t(\"./scatterpolar\"),t(\"./scatterpolargl\"),t(\"./barpolar\")]),n.register([t(\"./aggregate\"),t(\"./filter\"),t(\"./groupby\"),t(\"./sort\")]),n.register([t(\"./calendars\")]),e.exports=n},{\"./aggregate\":2,\"./bar\":3,\"./barpolar\":4,\"./box\":5,\"./calendars\":6,\"./candlestick\":7,\"./carpet\":8,\"./choropleth\":9,\"./choroplethmapbox\":10,\"./cone\":11,\"./contour\":12,\"./contourcarpet\":13,\"./core\":14,\"./densitymapbox\":15,\"./filter\":16,\"./funnel\":17,\"./funnelarea\":18,\"./groupby\":19,\"./heatmap\":20,\"./heatmapgl\":21,\"./histogram\":22,\"./histogram2d\":23,\"./histogram2dcontour\":24,\"./indicator\":26,\"./isosurface\":27,\"./mesh3d\":28,\"./ohlc\":29,\"./parcats\":30,\"./parcoords\":31,\"./pie\":32,\"./pointcloud\":33,\"./sankey\":34,\"./scatter3d\":35,\"./scattercarpet\":36,\"./scattergeo\":37,\"./scattergl\":38,\"./scattermapbox\":39,\"./scatterpolar\":40,\"./scatterpolargl\":41,\"./scatterternary\":42,\"./sort\":43,\"./splom\":44,\"./streamtube\":45,\"./sunburst\":46,\"./surface\":47,\"./table\":48,\"./violin\":49,\"./volume\":50,\"./waterfall\":51}],26:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/indicator\")},{\"../src/traces/indicator\":1046}],27:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/isosurface\")},{\"../src/traces/isosurface\":1052}],28:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/mesh3d\")},{\"../src/traces/mesh3d\":1057}],29:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/ohlc\")},{\"../src/traces/ohlc\":1062}],30:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcats\")},{\"../src/traces/parcats\":1071}],31:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcoords\")},{\"../src/traces/parcoords\":1081}],32:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pie\")},{\"../src/traces/pie\":1092}],33:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pointcloud\")},{\"../src/traces/pointcloud\":1101}],34:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sankey\")},{\"../src/traces/sankey\":1107}],35:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatter3d\")},{\"../src/traces/scatter3d\":1143}],36:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattercarpet\")},{\"../src/traces/scattercarpet\":1149}],37:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergeo\")},{\"../src/traces/scattergeo\":1156}],38:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergl\")},{\"../src/traces/scattergl\":1167}],39:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattermapbox\")},{\"../src/traces/scattermapbox\":1176}],40:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolar\")},{\"../src/traces/scatterpolar\":1183}],41:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolargl\")},{\"../src/traces/scatterpolargl\":1189}],42:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterternary\")},{\"../src/traces/scatterternary\":1196}],43:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/sort\")},{\"../src/transforms/sort\":1269}],44:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/splom\")},{\"../src/traces/splom\":1205}],45:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/streamtube\")},{\"../src/traces/streamtube\":1213}],46:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sunburst\")},{\"../src/traces/sunburst\":1219}],47:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/surface\")},{\"../src/traces/surface\":1228}],48:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/table\")},{\"../src/traces/table\":1236}],49:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/violin\")},{\"../src/traces/violin\":1244}],50:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/volume\")},{\"../src/traces/volume\":1252}],51:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/waterfall\")},{\"../src/traces/waterfall\":1260}],52:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).eye||[0,0,1],r=t.center||[0,0,0],s=t.up||[0,1,0],l=t.distanceLimits||[0,1/0],c=t.mode||\"turntable\",u=n(),h=i(),f=a();return u.setDistanceLimits(l[0],l[1]),u.lookAt(0,e,r,s),h.setDistanceLimits(l[0],l[1]),h.lookAt(0,e,r,s),f.setDistanceLimits(l[0],l[1]),f.lookAt(0,e,r,s),new o({turntable:u,orbit:h,matrix:f},c)};var n=t(\"turntable-camera-controller\"),i=t(\"orbit-camera-controller\"),a=t(\"matrix-camera-controller\");function o(t,e){this._controllerNames=Object.keys(t),this._controllerList=this._controllerNames.map(function(e){return t[e]}),this._mode=e,this._active=t[e],this._active||(this._mode=\"turntable\",this._active=t.turntable),this.modes=this._controllerNames,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}var s=o.prototype;[[\"flush\",1],[\"idle\",1],[\"lookAt\",4],[\"rotate\",4],[\"pan\",4],[\"translate\",4],[\"setMatrix\",2],[\"setDistanceLimits\",2],[\"setDistance\",2]].forEach(function(t){for(var e=t[0],r=[],n=0;n<t[1];++n)r.push(\"a\"+n);var i=\"var cc=this._controllerList;for(var i=0;i<cc.length;++i){cc[i].\"+t[0]+\"(\"+r.join()+\")}\";s[e]=Function.apply(null,r.concat(i))}),s.recalcMatrix=function(t){this._active.recalcMatrix(t)},s.getDistance=function(t){return this._active.getDistance(t)},s.getDistanceLimits=function(t){return this._active.getDistanceLimits(t)},s.lastT=function(){return this._active.lastT()},s.setMode=function(t){if(t!==this._mode){var e=this._controllerNames.indexOf(t);if(!(e<0)){var r=this._active,n=this._controllerList[e],i=Math.max(r.lastT(),n.lastT());r.recalcMatrix(i),n.setMatrix(i,r.computedMatrix),this._active=n,this._mode=t,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}}},s.getMode=function(){return this._mode}},{\"matrix-camera-controller\":433,\"orbit-camera-controller\":456,\"turntable-camera-controller\":542}],53:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n,i){\"use strict\";function a(t){return t.target.depth}function o(t,e){return t.sourceLinks.length?t.depth:e-1}function s(t){return function(){return t}}i=i&&i.hasOwnProperty(\"default\")?i.default:i;var l=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&\"function\"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?\"symbol\":typeof t};function c(t,e){return h(t.source,e.source)||t.index-e.index}function u(t,e){return h(t.target,e.target)||t.index-e.index}function h(t,e){return t.partOfCycle===e.partOfCycle?t.y0-e.y0:\"top\"===t.circularLinkType||\"bottom\"===e.circularLinkType?-1:1}function f(t){return t.value}function p(t){return(t.y0+t.y1)/2}function d(t){return p(t.source)}function g(t){return p(t.target)}function v(t){return t.index}function m(t){return t.nodes}function y(t){return t.links}function x(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function b(t,e){return e(t)}var _=25,w=10,k=.3;function T(t,e){var r=0,n=0;t.links.forEach(function(i){i.circular&&(i.source.circularLinkType||i.target.circularLinkType?i.circularLinkType=i.source.circularLinkType?i.source.circularLinkType:i.target.circularLinkType:i.circularLinkType=r<n?\"top\":\"bottom\",\"top\"==i.circularLinkType?r+=1:n+=1,t.nodes.forEach(function(t){b(t,e)!=b(i.source,e)&&b(t,e)!=b(i.target,e)||(t.circularLinkType=i.circularLinkType)}))}),t.links.forEach(function(t){t.circular&&(t.source.circularLinkType==t.target.circularLinkType&&(t.circularLinkType=t.source.circularLinkType),Y(t,e)&&(t.circularLinkType=t.source.circularLinkType))})}function A(t){var e=Math.abs(t.y1-t.y0),r=Math.abs(t.target.x0-t.source.x1);return Math.atan(r/e)}function M(t,e){var r=0;t.sourceLinks.forEach(function(t){r=t.circular&&!Y(t,e)?r+1:r});var n=0;return t.targetLinks.forEach(function(t){n=t.circular&&!Y(t,e)?n+1:n}),r+n}function S(t){var e=t.source.sourceLinks,r=0;e.forEach(function(t){r=t.circular?r+1:r});var n=t.target.targetLinks,i=0;return n.forEach(function(t){i=t.circular?i+1:i}),!(r>1||i>1)}function E(t,e,r){return t.sort(L),t.forEach(function(n,i){var a,o,s=0;if(Y(n,r)&&S(n))n.circularPathData.verticalBuffer=s+n.width/2;else{for(var l=0;l<i;l++)if(a=t[i],o=t[l],!(a.source.column<o.target.column||a.target.column>o.source.column)){var c=t[l].circularPathData.verticalBuffer+t[l].width/2+e;s=c>s?c:s}n.circularPathData.verticalBuffer=s+n.width/2}}),t}function C(t,r,i,a){var o=e.min(t.links,function(t){return t.source.y0});t.links.forEach(function(t){t.circular&&(t.circularPathData={})}),E(t.links.filter(function(t){return\"top\"==t.circularLinkType}),r,a),E(t.links.filter(function(t){return\"bottom\"==t.circularLinkType}),r,a),t.links.forEach(function(e){if(e.circular){if(e.circularPathData.arcRadius=e.width+w,e.circularPathData.leftNodeBuffer=5,e.circularPathData.rightNodeBuffer=5,e.circularPathData.sourceWidth=e.source.x1-e.source.x0,e.circularPathData.sourceX=e.source.x0+e.circularPathData.sourceWidth,e.circularPathData.targetX=e.target.x0,e.circularPathData.sourceY=e.y0,e.circularPathData.targetY=e.y1,Y(e,a)&&S(e))e.circularPathData.leftSmallArcRadius=w+e.width/2,e.circularPathData.leftLargeArcRadius=w+e.width/2,e.circularPathData.rightSmallArcRadius=w+e.width/2,e.circularPathData.rightLargeArcRadius=w+e.width/2,\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=e.source.y1+_+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=e.source.y0-_-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius);else{var s=e.source.column,l=e.circularLinkType,c=t.links.filter(function(t){return t.source.column==s&&t.circularLinkType==l});\"bottom\"==e.circularLinkType?c.sort(O):c.sort(P);var u=0;c.forEach(function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.leftSmallArcRadius=w+e.width/2+u,e.circularPathData.leftLargeArcRadius=w+e.width/2+n*r+u),u+=t.width}),s=e.target.column,c=t.links.filter(function(t){return t.target.column==s&&t.circularLinkType==l}),\"bottom\"==e.circularLinkType?c.sort(I):c.sort(z),u=0,c.forEach(function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.rightSmallArcRadius=w+e.width/2+u,e.circularPathData.rightLargeArcRadius=w+e.width/2+n*r+u),u+=t.width}),\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=Math.max(i,e.source.y1,e.target.y1)+_+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=o-_-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius)}e.circularPathData.leftInnerExtent=e.circularPathData.sourceX+e.circularPathData.leftNodeBuffer,e.circularPathData.rightInnerExtent=e.circularPathData.targetX-e.circularPathData.rightNodeBuffer,e.circularPathData.leftFullExtent=e.circularPathData.sourceX+e.circularPathData.leftLargeArcRadius+e.circularPathData.leftNodeBuffer,e.circularPathData.rightFullExtent=e.circularPathData.targetX-e.circularPathData.rightLargeArcRadius-e.circularPathData.rightNodeBuffer}if(e.circular)e.path=function(t){var e=\"\";e=\"top\"==t.circularLinkType?\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 0 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY-t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 0 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 0 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY-t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 0 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY:\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 1 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY+t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 1 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 1 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY+t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 1 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY;return e}(e);else{var h=n.linkHorizontal().source(function(t){return[t.source.x0+(t.source.x1-t.source.x0),t.y0]}).target(function(t){return[t.target.x0,t.y1]});e.path=h(e)}})}function L(t,e){return D(t)==D(e)?\"bottom\"==t.circularLinkType?O(t,e):P(t,e):D(e)-D(t)}function P(t,e){return t.y0-e.y0}function O(t,e){return e.y0-t.y0}function z(t,e){return t.y1-e.y1}function I(t,e){return e.y1-t.y1}function D(t){return t.target.column-t.source.column}function R(t){return t.target.x0-t.source.x1}function F(t,e){var r=A(t),n=R(e)/Math.tan(r);return\"up\"==G(t)?t.y1+n:t.y1-n}function B(t,e){var r=A(t),n=R(e)/Math.tan(r);return\"up\"==G(t)?t.y1-n:t.y1+n}function N(t,e,r,n){t.links.forEach(function(i){if(!i.circular&&i.target.column-i.source.column>1){var a=i.source.column+1,o=i.target.column-1,s=1,l=o-a+1;for(s=1;a<=o;a++,s++)t.nodes.forEach(function(o){if(o.column==a){var c,u=s/(l+1),h=Math.pow(1-u,3),f=3*u*Math.pow(1-u,2),p=3*Math.pow(u,2)*(1-u),d=Math.pow(u,3),g=h*i.y0+f*i.y0+p*i.y1+d*i.y1,v=g-i.width/2,m=g+i.width/2;v>o.y0&&v<o.y1?(c=o.y1-v+10,c=\"bottom\"==o.circularLinkType?c:-c,o=U(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&j(o,t)&&U(t,c,e,r)})):m>o.y0&&m<o.y1?(c=m-o.y0+10,o=U(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&U(t,c,e,r)})):v<o.y0&&m>o.y1&&(c=m-o.y0+10,o=U(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&U(t,c,e,r)}))}})}})}function j(t,e){return t.y0>e.y0&&t.y0<e.y1||(t.y1>e.y0&&t.y1<e.y1||t.y0<e.y0&&t.y1>e.y1)}function U(t,e,r,n){return t.y0+e>=r&&t.y1+e<=n&&(t.y0=t.y0+e,t.y1=t.y1+e,t.targetLinks.forEach(function(t){t.y1=t.y1+e}),t.sourceLinks.forEach(function(t){t.y0=t.y0+e})),t}function V(t,e,r,n){t.nodes.forEach(function(i){n&&i.y+(i.y1-i.y0)>e&&(i.y=i.y-(i.y+(i.y1-i.y0)-e));var a=t.links.filter(function(t){return b(t.source,r)==b(i,r)}),o=a.length;o>1&&a.sort(function(t,e){if(!t.circular&&!e.circular){if(t.target.column==e.target.column)return t.y1-e.y1;if(!H(t,e))return t.y1-e.y1;if(t.target.column>e.target.column){var r=B(e,t);return t.y1-r}if(e.target.column>t.target.column)return B(t,e)-e.y1}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.target.column===e.target.column?t.target.y1-e.target.y1:e.target.column-t.target.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.target.column===e.target.column?e.target.y1-t.target.y1:t.target.column-e.target.column:\"top\"==t.circularLinkType?-1:1:void 0});var s=i.y0;a.forEach(function(t){t.y0=s+t.width/2,s+=t.width}),a.forEach(function(t,e){if(\"bottom\"==t.circularLinkType){for(var r=e+1,n=0;r<o;r++)n+=a[r].width;t.y0=i.y1-n-t.width/2}})})}function q(t,e,r){t.nodes.forEach(function(e){var n=t.links.filter(function(t){return b(t.target,r)==b(e,r)}),i=n.length;i>1&&n.sort(function(t,e){if(!t.circular&&!e.circular){if(t.source.column==e.source.column)return t.y0-e.y0;if(!H(t,e))return t.y0-e.y0;if(e.source.column<t.source.column){var r=F(e,t);return t.y0-r}if(t.source.column<e.source.column)return F(t,e)-e.y0}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:t.source.column-e.source.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:e.source.column-t.source.column:\"top\"==t.circularLinkType?-1:1:void 0});var a=e.y0;n.forEach(function(t){t.y1=a+t.width/2,a+=t.width}),n.forEach(function(t,r){if(\"bottom\"==t.circularLinkType){for(var a=r+1,o=0;a<i;a++)o+=n[a].width;t.y1=e.y1-o-t.width/2}})})}function H(t,e){return G(t)==G(e)}function G(t){return t.y0-t.y1>0?\"up\":\"down\"}function Y(t,e){return b(t.source,e)==b(t.target,e)}t.sankeyCircular=function(){var t,n,a=0,b=0,A=1,S=1,E=24,L=v,P=o,O=m,z=y,I=32,D=2,R=null;function F(){var o={nodes:O.apply(null,arguments),links:z.apply(null,arguments)};!function(t){t.nodes.forEach(function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]});var e=r.map(t.nodes,L);t.links.forEach(function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!==(\"undefined\"==typeof n?\"undefined\":l(n))&&(n=t.source=x(e,n)),\"object\"!==(\"undefined\"==typeof i?\"undefined\":l(i))&&(i=t.target=x(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)})}(o),function(t,e,r){var n=0;if(null===r){for(var a=[],o=0;o<t.links.length;o++){var s=t.links[o],l=s.source.index,c=s.target.index;a[l]||(a[l]=[]),a[c]||(a[c]=[]),-1===a[l].indexOf(c)&&a[l].push(c)}var u=i(a);u.sort(function(t,e){return t.length-e.length});var h={};for(o=0;o<u.length;o++){var f=u[o],p=f.slice(-2);h[p[0]]||(h[p[0]]={}),h[p[0]][p[1]]=!0}t.links.forEach(function(t){var e=t.target.index,r=t.source.index;e===r||h[r]&&h[r][e]?(t.circular=!0,t.circularLinkID=n,n+=1):t.circular=!1})}else t.links.forEach(function(t){t.source[r]<t.target[r]?t.circular=!1:(t.circular=!0,t.circularLinkID=n,n+=1)})}(o,0,R),function(t){t.nodes.forEach(function(t){t.partOfCycle=!1,t.value=Math.max(e.sum(t.sourceLinks,f),e.sum(t.targetLinks,f)),t.sourceLinks.forEach(function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)}),t.targetLinks.forEach(function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)})})}(o),function(t){var e,r,n;for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach(function(t){t.depth=n,t.sourceLinks.forEach(function(t){r.indexOf(t.target)<0&&!t.circular&&r.push(t.target)})});for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach(function(t){t.height=n,t.targetLinks.forEach(function(t){r.indexOf(t.source)<0&&!t.circular&&r.push(t.source)})});t.nodes.forEach(function(t){t.column=Math.floor(P.call(null,t,n))})}(o),T(o,L),function(i,o,s){var l=r.nest().key(function(t){return t.column}).sortKeys(e.ascending).entries(i.nodes).map(function(t){return t.values});(function(r){if(n){var o=1/0;l.forEach(function(t){var e=S*n/(t.length+1);o=e<o?e:o}),t=o}var s=e.min(l,function(r){return(S-b-(r.length-1)*t)/e.sum(r,f)});s*=k,i.links.forEach(function(t){t.width=t.value*s});var c=function(t){var r=0,n=0,i=0,a=0,o=e.max(t.nodes,function(t){return t.column});return t.links.forEach(function(t){t.circular&&(\"top\"==t.circularLinkType?r+=t.width:n+=t.width,0==t.target.column&&(a+=t.width),t.source.column==o&&(i+=t.width))}),{top:r=r>0?r+_+w:r,bottom:n=n>0?n+_+w:n,left:a=a>0?a+_+w:a,right:i=i>0?i+_+w:i}}(i),u=function(t,r){var n=e.max(t.nodes,function(t){return t.column}),i=A-a,o=S-b,s=i+r.right+r.left,l=o+r.top+r.bottom,c=i/s,u=o/l;return a=a*c+r.left,A=0==r.right?A:A*c,b=b*u+r.top,S*=u,t.nodes.forEach(function(t){t.x0=a+t.column*((A-a-E)/n),t.x1=t.x0+E}),u}(i,c);s*=u,i.links.forEach(function(t){t.width=t.value*s}),l.forEach(function(t){var e=t.length;t.forEach(function(t,n){t.depth==l.length-1&&1==e?(t.y0=S/2-t.value*s,t.y1=t.y0+t.value*s):0==t.depth&&1==e?(t.y0=S/2-t.value*s,t.y1=t.y0+t.value*s):t.partOfCycle?0==M(t,r)?(t.y0=S/2+n,t.y1=t.y0+t.value*s):\"top\"==t.circularLinkType?(t.y0=b+n,t.y1=t.y0+t.value*s):(t.y0=S-t.value*s-n,t.y1=t.y0+t.value*s):0==c.top||0==c.bottom?(t.y0=(S-b)/e*n,t.y1=t.y0+t.value*s):(t.y0=(S-b)/2-e/2+n,t.y1=t.y0+t.value*s)})})})(s),m();for(var c=1,u=o;u>0;--u)v(c*=.99,s),m();function v(t,r){var n=l.length;l.forEach(function(i){var a=i.length,o=i[0].depth;i.forEach(function(i){var s;if(i.sourceLinks.length||i.targetLinks.length)if(i.partOfCycle&&M(i,r)>0);else if(0==o&&1==a)s=i.y1-i.y0,i.y0=S/2-s/2,i.y1=S/2+s/2;else if(o==n-1&&1==a)s=i.y1-i.y0,i.y0=S/2-s/2,i.y1=S/2+s/2;else{var l=e.mean(i.sourceLinks,g),c=e.mean(i.targetLinks,d),u=((l&&c?(l+c)/2:l||c)-p(i))*t;i.y0+=u,i.y1+=u}})})}function m(){l.forEach(function(e){var r,n,i,a=b,o=e.length;for(e.sort(h),i=0;i<o;++i)r=e[i],(n=a-r.y0)>0&&(r.y0+=n,r.y1+=n),a=r.y1+t;if((n=a-t-S)>0)for(a=r.y0-=n,r.y1-=n,i=o-2;i>=0;--i)r=e[i],(n=r.y1+t-a)>0&&(r.y0-=n,r.y1-=n),a=r.y0})}}(o,I,L),B(o);for(var s=0;s<4;s++)V(o,S,L),q(o,0,L),N(o,b,S,L),V(o,S,L),q(o,0,L);return function(t,r,n){var i=t.nodes,a=t.links,o=!1,s=!1;if(a.forEach(function(t){\"top\"==t.circularLinkType?o=!0:\"bottom\"==t.circularLinkType&&(s=!0)}),0==o||0==s){var l=e.min(i,function(t){return t.y0}),c=e.max(i,function(t){return t.y1}),u=c-l,h=n-r,f=h/u;i.forEach(function(t){var e=(t.y1-t.y0)*f;t.y0=(t.y0-l)*f,t.y1=t.y0+e}),a.forEach(function(t){t.y0=(t.y0-l)*f,t.y1=(t.y1-l)*f,t.width=t.width*f})}}(o,b,S),C(o,D,S,L),o}function B(t){t.nodes.forEach(function(t){t.sourceLinks.sort(u),t.targetLinks.sort(c)}),t.nodes.forEach(function(t){var e=t.y0,r=e,n=t.y1,i=n;t.sourceLinks.forEach(function(t){t.circular?(t.y0=n-t.width/2,n-=t.width):(t.y0=e+t.width/2,e+=t.width)}),t.targetLinks.forEach(function(t){t.circular?(t.y1=i-t.width/2,i-=t.width):(t.y1=r+t.width/2,r+=t.width)})})}return F.nodeId=function(t){return arguments.length?(L=\"function\"==typeof t?t:s(t),F):L},F.nodeAlign=function(t){return arguments.length?(P=\"function\"==typeof t?t:s(t),F):P},F.nodeWidth=function(t){return arguments.length?(E=+t,F):E},F.nodePadding=function(e){return arguments.length?(t=+e,F):t},F.nodes=function(t){return arguments.length?(O=\"function\"==typeof t?t:s(t),F):O},F.links=function(t){return arguments.length?(z=\"function\"==typeof t?t:s(t),F):z},F.size=function(t){return arguments.length?(a=b=0,A=+t[0],S=+t[1],F):[A-a,S-b]},F.extent=function(t){return arguments.length?(a=+t[0][0],A=+t[1][0],b=+t[0][1],S=+t[1][1],F):[[a,b],[A,S]]},F.iterations=function(t){return arguments.length?(I=+t,F):I},F.circularLinkGap=function(t){return arguments.length?(D=+t,F):D},F.nodePaddingRatio=function(t){return arguments.length?(n=+t,F):n},F.sortNodes=function(t){return arguments.length?(R=t,F):R},F.update=function(t){return T(t,L),B(t),t.links.forEach(function(t){t.circular&&(t.circularLinkType=t.y0+t.y1<S?\"top\":\"bottom\",t.source.circularLinkType=t.circularLinkType,t.target.circularLinkType=t.circularLinkType)}),V(t,S,L,!1),q(t,0,L),C(t,D,S,L),t},F},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,a)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=o,Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\"),t(\"elementary-circuits-directed-graph\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,null)},{\"d3-array\":152,\"d3-collection\":153,\"d3-shape\":161,\"elementary-circuits-directed-graph\":172}],54:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n){\"use strict\";function i(t){return t.target.depth}function a(t,e){return t.sourceLinks.length?t.depth:e-1}function o(t){return function(){return t}}function s(t,e){return c(t.source,e.source)||t.index-e.index}function l(t,e){return c(t.target,e.target)||t.index-e.index}function c(t,e){return t.y0-e.y0}function u(t){return t.value}function h(t){return(t.y0+t.y1)/2}function f(t){return h(t.source)*t.value}function p(t){return h(t.target)*t.value}function d(t){return t.index}function g(t){return t.nodes}function v(t){return t.links}function m(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function y(t){return[t.source.x1,t.y0]}function x(t){return[t.target.x0,t.y1]}t.sankey=function(){var t=0,n=0,i=1,y=1,x=24,b=8,_=d,w=a,k=g,T=v,A=32,M=2/3;function S(){var a={nodes:k.apply(null,arguments),links:T.apply(null,arguments)};return function(t){t.nodes.forEach(function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]});var e=r.map(t.nodes,_);t.links.forEach(function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!=typeof n&&(n=t.source=m(e,n)),\"object\"!=typeof i&&(i=t.target=m(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)})}(a),function(t){t.nodes.forEach(function(t){t.value=Math.max(e.sum(t.sourceLinks,u),e.sum(t.targetLinks,u))})}(a),function(e){var r,n,a;for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach(function(t){t.depth=a,t.sourceLinks.forEach(function(t){n.indexOf(t.target)<0&&n.push(t.target)})});for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach(function(t){t.height=a,t.targetLinks.forEach(function(t){n.indexOf(t.source)<0&&n.push(t.source)})});var o=(i-t-x)/(a-1);e.nodes.forEach(function(e){e.x1=(e.x0=t+Math.max(0,Math.min(a-1,Math.floor(w.call(null,e,a))))*o)+x})}(a),function(t){var i=r.nest().key(function(t){return t.x0}).sortKeys(e.ascending).entries(t.nodes).map(function(t){return t.values});(function(){var r=e.max(i,function(t){return t.length}),a=M*(y-n)/(r-1);b>a&&(b=a);var o=e.min(i,function(t){return(y-n-(t.length-1)*b)/e.sum(t,u)});i.forEach(function(t){t.forEach(function(t,e){t.y1=(t.y0=e)+t.value*o})}),t.links.forEach(function(t){t.width=t.value*o})})(),d();for(var a=1,o=A;o>0;--o)l(a*=.99),d(),s(a),d();function s(t){i.forEach(function(r){r.forEach(function(r){if(r.targetLinks.length){var n=(e.sum(r.targetLinks,f)/e.sum(r.targetLinks,u)-h(r))*t;r.y0+=n,r.y1+=n}})})}function l(t){i.slice().reverse().forEach(function(r){r.forEach(function(r){if(r.sourceLinks.length){var n=(e.sum(r.sourceLinks,p)/e.sum(r.sourceLinks,u)-h(r))*t;r.y0+=n,r.y1+=n}})})}function d(){i.forEach(function(t){var e,r,i,a=n,o=t.length;for(t.sort(c),i=0;i<o;++i)e=t[i],(r=a-e.y0)>0&&(e.y0+=r,e.y1+=r),a=e.y1+b;if((r=a-b-y)>0)for(a=e.y0-=r,e.y1-=r,i=o-2;i>=0;--i)e=t[i],(r=e.y1+b-a)>0&&(e.y0-=r,e.y1-=r),a=e.y0})}}(a),E(a),a}function E(t){t.nodes.forEach(function(t){t.sourceLinks.sort(l),t.targetLinks.sort(s)}),t.nodes.forEach(function(t){var e=t.y0,r=e;t.sourceLinks.forEach(function(t){t.y0=e+t.width/2,e+=t.width}),t.targetLinks.forEach(function(t){t.y1=r+t.width/2,r+=t.width})})}return S.update=function(t){return E(t),t},S.nodeId=function(t){return arguments.length?(_=\"function\"==typeof t?t:o(t),S):_},S.nodeAlign=function(t){return arguments.length?(w=\"function\"==typeof t?t:o(t),S):w},S.nodeWidth=function(t){return arguments.length?(x=+t,S):x},S.nodePadding=function(t){return arguments.length?(b=+t,S):b},S.nodes=function(t){return arguments.length?(k=\"function\"==typeof t?t:o(t),S):k},S.links=function(t){return arguments.length?(T=\"function\"==typeof t?t:o(t),S):T},S.size=function(e){return arguments.length?(t=n=0,i=+e[0],y=+e[1],S):[i-t,y-n]},S.extent=function(e){return arguments.length?(t=+e[0][0],i=+e[1][0],n=+e[0][1],y=+e[1][1],S):[[t,n],[i,y]]},S.iterations=function(t){return arguments.length?(A=+t,S):A},S},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,i)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=a,t.sankeyLinkHorizontal=function(){return n.linkHorizontal().source(y).target(x)},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3)},{\"d3-array\":152,\"d3-collection\":153,\"d3-shape\":161}],55:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\"),i=6378137;function a(t){var e=0;if(t&&t.length>0){e+=Math.abs(o(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(o(t[r]))}return e}function o(t){var e,r,n,a,o,l,c=0,u=t.length;if(u>2){for(l=0;l<u;l++)l===u-2?(n=u-2,a=u-1,o=0):l===u-1?(n=u-1,a=0,o=1):(n=l,a=l+1,o=l+2),e=t[n],r=t[a],c+=(s(t[o][0])-s(e[0]))*Math.sin(s(r[1]));c=c*i*i/2}return c}function s(t){return t*Math.PI/180}r.default=function(t){return n.geomReduce(t,function(t,e){return t+function(t){var e,r=0;switch(t.type){case\"Polygon\":return a(t.coordinates);case\"MultiPolygon\":for(e=0;e<t.coordinates.length;e++)r+=a(t.coordinates[e]);return r;case\"Point\":case\"MultiPoint\":case\"LineString\":case\"MultiLineString\":return 0}return 0}(e)},0)}},{\"@turf/meta\":58}],56:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\"),i=t(\"@turf/helpers\");r.default=function(t,e){void 0===e&&(e={});var r=0,a=0,o=0;return n.coordEach(t,function(t){r+=t[0],a+=t[1],o++}),i.point([r/o,a/o],e.properties)}},{\"@turf/helpers\":57,\"@turf/meta\":58}],57:[function(t,e,r){\"use strict\";function n(t,e,r){void 0===r&&(r={});var n={type:\"Feature\"};return(0===r.id||r.id)&&(n.id=r.id),r.bbox&&(n.bbox=r.bbox),n.properties=e||{},n.geometry=t,n}function i(t,e,r){return void 0===r&&(r={}),n({type:\"Point\",coordinates:t},e,r)}function a(t,e,r){void 0===r&&(r={});for(var i=0,a=t;i<a.length;i++){var o=a[i];if(o.length<4)throw new Error(\"Each LinearRing of a Polygon must have 4 or more Positions.\");for(var s=0;s<o[o.length-1].length;s++)if(o[o.length-1][s]!==o[0][s])throw new Error(\"First and last Position are not equivalent.\")}return n({type:\"Polygon\",coordinates:t},e,r)}function o(t,e,r){if(void 0===r&&(r={}),t.length<2)throw new Error(\"coordinates must be an array of two or more positions\");return n({type:\"LineString\",coordinates:t},e,r)}function s(t,e){void 0===e&&(e={});var r={type:\"FeatureCollection\"};return e.id&&(r.id=e.id),e.bbox&&(r.bbox=e.bbox),r.features=t,r}function l(t,e,r){return void 0===r&&(r={}),n({type:\"MultiLineString\",coordinates:t},e,r)}function c(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPoint\",coordinates:t},e,r)}function u(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPolygon\",coordinates:t},e,r)}function h(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t*n}function f(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t/n}function p(t){return 180*(t%(2*Math.PI))/Math.PI}function d(t){return!isNaN(t)&&null!==t&&!Array.isArray(t)&&!/^\\s*$/.test(t)}Object.defineProperty(r,\"__esModule\",{value:!0}),r.earthRadius=6371008.8,r.factors={centimeters:100*r.earthRadius,centimetres:100*r.earthRadius,degrees:r.earthRadius/111325,feet:3.28084*r.earthRadius,inches:39.37*r.earthRadius,kilometers:r.earthRadius/1e3,kilometres:r.earthRadius/1e3,meters:r.earthRadius,metres:r.earthRadius,miles:r.earthRadius/1609.344,millimeters:1e3*r.earthRadius,millimetres:1e3*r.earthRadius,nauticalmiles:r.earthRadius/1852,radians:1,yards:r.earthRadius/1.0936},r.unitsFactors={centimeters:100,centimetres:100,degrees:1/111325,feet:3.28084,inches:39.37,kilometers:.001,kilometres:.001,meters:1,metres:1,miles:1/1609.344,millimeters:1e3,millimetres:1e3,nauticalmiles:1/1852,radians:1/r.earthRadius,yards:1/1.0936},r.areaFactors={acres:247105e-9,centimeters:1e4,centimetres:1e4,feet:10.763910417,inches:1550.003100006,kilometers:1e-6,kilometres:1e-6,meters:1,metres:1,miles:3.86e-7,millimeters:1e6,millimetres:1e6,yards:1.195990046},r.feature=n,r.geometry=function(t,e,r){switch(void 0===r&&(r={}),t){case\"Point\":return i(e).geometry;case\"LineString\":return o(e).geometry;case\"Polygon\":return a(e).geometry;case\"MultiPoint\":return c(e).geometry;case\"MultiLineString\":return l(e).geometry;case\"MultiPolygon\":return u(e).geometry;default:throw new Error(t+\" is invalid\")}},r.point=i,r.points=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return i(t,e)}),r)},r.polygon=a,r.polygons=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return a(t,e)}),r)},r.lineString=o,r.lineStrings=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return o(t,e)}),r)},r.featureCollection=s,r.multiLineString=l,r.multiPoint=c,r.multiPolygon=u,r.geometryCollection=function(t,e,r){return void 0===r&&(r={}),n({type:\"GeometryCollection\",geometries:t},e,r)},r.round=function(t,e){if(void 0===e&&(e=0),e&&!(e>=0))throw new Error(\"precision must be a positive number\");var r=Math.pow(10,e||0);return Math.round(t*r)/r},r.radiansToLength=h,r.lengthToRadians=f,r.lengthToDegrees=function(t,e){return p(f(t,e))},r.bearingToAzimuth=function(t){var e=t%360;return e<0&&(e+=360),e},r.radiansToDegrees=p,r.degreesToRadians=function(t){return t%360*Math.PI/180},r.convertLength=function(t,e,r){if(void 0===e&&(e=\"kilometers\"),void 0===r&&(r=\"kilometers\"),!(t>=0))throw new Error(\"length must be a positive number\");return h(f(t,e),r)},r.convertArea=function(t,e,n){if(void 0===e&&(e=\"meters\"),void 0===n&&(n=\"kilometers\"),!(t>=0))throw new Error(\"area must be a positive number\");var i=r.areaFactors[e];if(!i)throw new Error(\"invalid original units\");var a=r.areaFactors[n];if(!a)throw new Error(\"invalid final units\");return t/i*a},r.isNumber=d,r.isObject=function(t){return!!t&&t.constructor===Object},r.validateBBox=function(t){if(!t)throw new Error(\"bbox is required\");if(!Array.isArray(t))throw new Error(\"bbox must be an Array\");if(4!==t.length&&6!==t.length)throw new Error(\"bbox must be an Array of 4 or 6 numbers\");t.forEach(function(t){if(!d(t))throw new Error(\"bbox must only contain numbers\")})},r.validateId=function(t){if(!t)throw new Error(\"id is required\");if(-1===[\"string\",\"number\"].indexOf(typeof t))throw new Error(\"id must be a number or a string\")},r.radians2degrees=function(){throw new Error(\"method has been renamed to `radiansToDegrees`\")},r.degrees2radians=function(){throw new Error(\"method has been renamed to `degreesToRadians`\")},r.distanceToDegrees=function(){throw new Error(\"method has been renamed to `lengthToDegrees`\")},r.distanceToRadians=function(){throw new Error(\"method has been renamed to `lengthToRadians`\")},r.radiansToDistance=function(){throw new Error(\"method has been renamed to `radiansToLength`\")},r.bearingToAngle=function(){throw new Error(\"method has been renamed to `bearingToAzimuth`\")},r.convertDistance=function(){throw new Error(\"method has been renamed to `convertLength`\")}},{}],58:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/helpers\");function i(t,e,r){if(null!==t)for(var n,a,o,s,l,c,u,h,f=0,p=0,d=t.type,g=\"FeatureCollection\"===d,v=\"Feature\"===d,m=g?t.features.length:1,y=0;y<m;y++){l=(h=!!(u=g?t.features[y].geometry:v?t.geometry:t)&&\"GeometryCollection\"===u.type)?u.geometries.length:1;for(var x=0;x<l;x++){var b=0,_=0;if(null!==(s=h?u.geometries[x]:u)){c=s.coordinates;var w=s.type;switch(f=!r||\"Polygon\"!==w&&\"MultiPolygon\"!==w?0:1,w){case null:break;case\"Point\":if(!1===e(c,p,y,b,_))return!1;p++,b++;break;case\"LineString\":case\"MultiPoint\":for(n=0;n<c.length;n++){if(!1===e(c[n],p,y,b,_))return!1;p++,\"MultiPoint\"===w&&b++}\"LineString\"===w&&b++;break;case\"Polygon\":case\"MultiLineString\":for(n=0;n<c.length;n++){for(a=0;a<c[n].length-f;a++){if(!1===e(c[n][a],p,y,b,_))return!1;p++}\"MultiLineString\"===w&&b++,\"Polygon\"===w&&_++}\"Polygon\"===w&&b++;break;case\"MultiPolygon\":for(n=0;n<c.length;n++){for(_=0,a=0;a<c[n].length;a++){for(o=0;o<c[n][a].length-f;o++){if(!1===e(c[n][a][o],p,y,b,_))return!1;p++}_++}b++}break;case\"GeometryCollection\":for(n=0;n<s.geometries.length;n++)if(!1===i(s.geometries[n],e,r))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}}}}}function a(t,e){var r;switch(t.type){case\"FeatureCollection\":for(r=0;r<t.features.length&&!1!==e(t.features[r].properties,r);r++);break;case\"Feature\":e(t.properties,0)}}function o(t,e){if(\"Feature\"===t.type)e(t,0);else if(\"FeatureCollection\"===t.type)for(var r=0;r<t.features.length&&!1!==e(t.features[r],r);r++);}function s(t,e){var r,n,i,a,o,s,l,c,u,h,f=0,p=\"FeatureCollection\"===t.type,d=\"Feature\"===t.type,g=p?t.features.length:1;for(r=0;r<g;r++){for(s=p?t.features[r].geometry:d?t.geometry:t,c=p?t.features[r].properties:d?t.properties:{},u=p?t.features[r].bbox:d?t.bbox:void 0,h=p?t.features[r].id:d?t.id:void 0,o=(l=!!s&&\"GeometryCollection\"===s.type)?s.geometries.length:1,i=0;i<o;i++)if(null!==(a=l?s.geometries[i]:s))switch(a.type){case\"Point\":case\"LineString\":case\"MultiPoint\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":if(!1===e(a,f,c,u,h))return!1;break;case\"GeometryCollection\":for(n=0;n<a.geometries.length;n++)if(!1===e(a.geometries[n],f,c,u,h))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}else if(!1===e(null,f,c,u,h))return!1;f++}}function l(t,e){s(t,function(t,r,i,a,o){var s,l=null===t?null:t.type;switch(l){case null:case\"Point\":case\"LineString\":case\"Polygon\":return!1!==e(n.feature(t,i,{bbox:a,id:o}),r,0)&&void 0}switch(l){case\"MultiPoint\":s=\"Point\";break;case\"MultiLineString\":s=\"LineString\";break;case\"MultiPolygon\":s=\"Polygon\"}for(var c=0;c<t.coordinates.length;c++){var u={type:s,coordinates:t.coordinates[c]};if(!1===e(n.feature(u,i),r,c))return!1}})}function c(t,e){l(t,function(t,r,a){var o=0;if(t.geometry){var s=t.geometry.type;if(\"Point\"!==s&&\"MultiPoint\"!==s){var l,c=0,u=0,h=0;return!1!==i(t,function(i,s,f,p,d){if(void 0===l||r>c||p>u||d>h)return l=i,c=r,u=p,h=d,void(o=0);var g=n.lineString([l,i],t.properties);if(!1===e(g,r,a,d,o))return!1;o++,l=i})&&void 0}}})}function u(t,e){if(!t)throw new Error(\"geojson is required\");l(t,function(t,r,i){if(null!==t.geometry){var a=t.geometry.type,o=t.geometry.coordinates;switch(a){case\"LineString\":if(!1===e(t,r,i,0,0))return!1;break;case\"Polygon\":for(var s=0;s<o.length;s++)if(!1===e(n.lineString(o[s],t.properties),r,i,s))return!1}}})}r.coordEach=i,r.coordReduce=function(t,e,r,n){var a=r;return i(t,function(t,n,i,o,s){a=0===n&&void 0===r?t:e(a,t,n,i,o,s)},n),a},r.propEach=a,r.propReduce=function(t,e,r){var n=r;return a(t,function(t,i){n=0===i&&void 0===r?t:e(n,t,i)}),n},r.featureEach=o,r.featureReduce=function(t,e,r){var n=r;return o(t,function(t,i){n=0===i&&void 0===r?t:e(n,t,i)}),n},r.coordAll=function(t){var e=[];return i(t,function(t){e.push(t)}),e},r.geomEach=s,r.geomReduce=function(t,e,r){var n=r;return s(t,function(t,i,a,o,s){n=0===i&&void 0===r?t:e(n,t,i,a,o,s)}),n},r.flattenEach=l,r.flattenReduce=function(t,e,r){var n=r;return l(t,function(t,i,a){n=0===i&&0===a&&void 0===r?t:e(n,t,i,a)}),n},r.segmentEach=c,r.segmentReduce=function(t,e,r){var n=r,i=!1;return c(t,function(t,a,o,s,l){n=!1===i&&void 0===r?t:e(n,t,a,o,s,l),i=!0}),n},r.lineEach=u,r.lineReduce=function(t,e,r){var n=r;return u(t,function(t,i,a,o){n=0===i&&void 0===r?t:e(n,t,i,a,o)}),n},r.findSegment=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.segmentIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":case\"MultiPoint\":return null;case\"LineString\":return s<0&&(s=c.length+s-1),n.lineString([c[s],c[s+1]],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s-1),n.lineString([c[o][s],c[o][s+1]],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s-1),n.lineString([c[a][s],c[a][s+1]],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s-1),n.lineString([c[a][o][s],c[a][o][s+1]],l,e)}throw new Error(\"geojson is invalid\")},r.findPoint=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.coordIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":return n.point(c,l,e);case\"MultiPoint\":return a<0&&(a=c.length+a),n.point(c[a],l,e);case\"LineString\":return s<0&&(s=c.length+s),n.point(c[s],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s),n.point(c[o][s],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s),n.point(c[a][s],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s),n.point(c[a][o][s],l,e)}throw new Error(\"geojson is invalid\")}},{\"@turf/helpers\":57}],59:[function(t,e,r){\"use strict\";var n=\"undefined\"==typeof WeakMap?t(\"weak-map\"):WeakMap,i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=new n;e.exports=function(t){var e=o.get(t),r=e&&(e._triangleBuffer.handle||e._triangleBuffer.buffer);if(!r||!t.isBuffer(r)){var n=i(t,new Float32Array([-1,-1,-1,4,4,-1]));(e=a(t,[{buffer:n,type:t.FLOAT,size:2}]))._triangleBuffer=n,o.set(t,e)}e.bind(),t.drawArrays(t.TRIANGLES,0,3),e.unbind()}},{\"gl-buffer\":241,\"gl-vao\":327,\"weak-map\":552}],60:[function(t,e,r){e.exports=function(t){var e=0,r=0,n=0,i=0;return t.map(function(t){var a=(t=t.slice())[0],o=a.toUpperCase();if(a!=o)switch(t[0]=o,a){case\"a\":t[6]+=n,t[7]+=i;break;case\"v\":t[1]+=i;break;case\"h\":t[1]+=n;break;default:for(var s=1;s<t.length;)t[s++]+=n,t[s++]+=i}switch(o){case\"Z\":n=e,i=r;break;case\"H\":n=t[1];break;case\"V\":i=t[1];break;case\"M\":n=e=t[1],i=r=t[2];break;default:n=t[t.length-2],i=t[t.length-1]}return t})}},{}],61:[function(t,e,r){var n=t(\"pad-left\");e.exports=function(t,e,r){e=\"number\"==typeof e?e:1,r=r||\": \";var i=t.split(/\\r?\\n/),a=String(i.length+e-1).length;return i.map(function(t,i){var o=i+e,s=String(o).length,l=n(o,a-s);return l+r+t}).join(\"\\n\")}},{\"pad-left\":457}],62:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[0];for(var r=t[0].length,n=[t[0]],a=[0],o=1;o<e;++o)if(n.push(t[o]),i(n,r)){if(a.push(o),a.length===r+1)return a}else n.pop();return a};var n=t(\"robust-orientation\");function i(t,e){for(var r=new Array(e+1),i=0;i<t.length;++i)r[i]=t[i];for(i=0;i<=t.length;++i){for(var a=t.length;a<=e;++a){for(var o=new Array(e),s=0;s<e;++s)o[s]=Math.pow(a+1-i,s);r[a]=o}if(n.apply(void 0,r))return!0}return!1}},{\"robust-orientation\":510}],63:[function(t,e,r){\"use strict\";e.exports=function(t,e){return n(e).filter(function(r){for(var n=new Array(r.length),a=0;a<r.length;++a)n[a]=e[r[a]];return i(n)*t<1})};var n=t(\"delaunay-triangulate\"),i=t(\"circumradius\")},{circumradius:114,\"delaunay-triangulate\":165}],64:[function(t,e,r){e.exports=function(t,e){return i(n(t,e))};var n=t(\"alpha-complex\"),i=t(\"simplicial-complex-boundary\")},{\"alpha-complex\":63,\"simplicial-complex-boundary\":517}],65:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(!t||null==t.length)throw Error(\"Argument should be an array\");e=null==e?1:Math.floor(e);for(var r=Array(2*e),n=0;n<e;n++){for(var i=-1/0,a=1/0,o=n,s=t.length;o<s;o+=e)t[o]>i&&(i=t[o]),t[o]<a&&(a=t[o]);r[n]=a,r[e+n]=i}return r}},{}],66:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\");e.exports=function(t,e,r){if(!t||null==t.length)throw Error(\"Argument should be an array\");null==e&&(e=1);null==r&&(r=n(t,e));for(var i=0;i<e;i++){var a=r[e+i],o=r[i],s=i,l=t.length;if(a===1/0&&o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:t[s]===o?0:.5;else if(a===1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:0;else if(o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===o?0:1;else{var c=a-o;for(s=i;s<l;s+=e)t[s]=0===c?.5:(t[s]-o)/c}}return t}},{\"array-bounds\":65}],67:[function(t,e,r){e.exports=function(t,e){var r=\"number\"==typeof t,n=\"number\"==typeof e;r&&!n?(e=t,t=0):r||n||(t=0,e=0);var i=(e|=0)-(t|=0);if(i<0)throw new Error(\"array length must be positive\");for(var a=new Array(i),o=0,s=t;o<i;o++,s++)a[o]=s;return a}},{}],68:[function(t,e,r){(function(r){\"use strict\";var n=t(\"object-assign\");function i(t,e){if(t===e)return 0;for(var r=t.length,n=e.length,i=0,a=Math.min(r,n);i<a;++i)if(t[i]!==e[i]){r=t[i],n=e[i];break}return r<n?-1:n<r?1:0}function a(t){return r.Buffer&&\"function\"==typeof r.Buffer.isBuffer?r.Buffer.isBuffer(t):!(null==t||!t._isBuffer)}var o=t(\"util/\"),s=Object.prototype.hasOwnProperty,l=Array.prototype.slice,c=\"foo\"===function(){}.name;function u(t){return Object.prototype.toString.call(t)}function h(t){return!a(t)&&(\"function\"==typeof r.ArrayBuffer&&(\"function\"==typeof ArrayBuffer.isView?ArrayBuffer.isView(t):!!t&&(t instanceof DataView||!!(t.buffer&&t.buffer instanceof ArrayBuffer))))}var f=e.exports=y,p=/\\s*function\\s+([^\\(\\s]*)\\s*/;function d(t){if(o.isFunction(t)){if(c)return t.name;var e=t.toString().match(p);return e&&e[1]}}function g(t,e){return\"string\"==typeof t?t.length<e?t:t.slice(0,e):t}function v(t){if(c||!o.isFunction(t))return o.inspect(t);var e=d(t);return\"[Function\"+(e?\": \"+e:\"\")+\"]\"}function m(t,e,r,n,i){throw new f.AssertionError({message:r,actual:t,expected:e,operator:n,stackStartFunction:i})}function y(t,e){t||m(t,!0,e,\"==\",f.ok)}function x(t,e,r,n){if(t===e)return!0;if(a(t)&&a(e))return 0===i(t,e);if(o.isDate(t)&&o.isDate(e))return t.getTime()===e.getTime();if(o.isRegExp(t)&&o.isRegExp(e))return t.source===e.source&&t.global===e.global&&t.multiline===e.multiline&&t.lastIndex===e.lastIndex&&t.ignoreCase===e.ignoreCase;if(null!==t&&\"object\"==typeof t||null!==e&&\"object\"==typeof e){if(h(t)&&h(e)&&u(t)===u(e)&&!(t instanceof Float32Array||t instanceof Float64Array))return 0===i(new Uint8Array(t.buffer),new Uint8Array(e.buffer));if(a(t)!==a(e))return!1;var s=(n=n||{actual:[],expected:[]}).actual.indexOf(t);return-1!==s&&s===n.expected.indexOf(e)||(n.actual.push(t),n.expected.push(e),function(t,e,r,n){if(null==t||null==e)return!1;if(o.isPrimitive(t)||o.isPrimitive(e))return t===e;if(r&&Object.getPrototypeOf(t)!==Object.getPrototypeOf(e))return!1;var i=b(t),a=b(e);if(i&&!a||!i&&a)return!1;if(i)return t=l.call(t),e=l.call(e),x(t,e,r);var s,c,u=k(t),h=k(e);if(u.length!==h.length)return!1;for(u.sort(),h.sort(),c=u.length-1;c>=0;c--)if(u[c]!==h[c])return!1;for(c=u.length-1;c>=0;c--)if(s=u[c],!x(t[s],e[s],r,n))return!1;return!0}(t,e,r,n))}return r?t===e:t==e}function b(t){return\"[object Arguments]\"==Object.prototype.toString.call(t)}function _(t,e){if(!t||!e)return!1;if(\"[object RegExp]\"==Object.prototype.toString.call(e))return e.test(t);try{if(t instanceof e)return!0}catch(t){}return!Error.isPrototypeOf(e)&&!0===e.call({},t)}function w(t,e,r,n){var i;if(\"function\"!=typeof e)throw new TypeError('\"block\" argument must be a function');\"string\"==typeof r&&(n=r,r=null),i=function(t){var e;try{t()}catch(t){e=t}return e}(e),n=(r&&r.name?\" (\"+r.name+\").\":\".\")+(n?\" \"+n:\".\"),t&&!i&&m(i,r,\"Missing expected exception\"+n);var a=\"string\"==typeof n,s=!t&&i&&!r;if((!t&&o.isError(i)&&a&&_(i,r)||s)&&m(i,r,\"Got unwanted exception\"+n),t&&i&&r&&!_(i,r)||!t&&i)throw i}f.AssertionError=function(t){var e;this.name=\"AssertionError\",this.actual=t.actual,this.expected=t.expected,this.operator=t.operator,t.message?(this.message=t.message,this.generatedMessage=!1):(this.message=g(v((e=this).actual),128)+\" \"+e.operator+\" \"+g(v(e.expected),128),this.generatedMessage=!0);var r=t.stackStartFunction||m;if(Error.captureStackTrace)Error.captureStackTrace(this,r);else{var n=new Error;if(n.stack){var i=n.stack,a=d(r),o=i.indexOf(\"\\n\"+a);if(o>=0){var s=i.indexOf(\"\\n\",o+1);i=i.substring(s+1)}this.stack=i}}},o.inherits(f.AssertionError,Error),f.fail=m,f.ok=y,f.equal=function(t,e,r){t!=e&&m(t,e,r,\"==\",f.equal)},f.notEqual=function(t,e,r){t==e&&m(t,e,r,\"!=\",f.notEqual)},f.deepEqual=function(t,e,r){x(t,e,!1)||m(t,e,r,\"deepEqual\",f.deepEqual)},f.deepStrictEqual=function(t,e,r){x(t,e,!0)||m(t,e,r,\"deepStrictEqual\",f.deepStrictEqual)},f.notDeepEqual=function(t,e,r){x(t,e,!1)&&m(t,e,r,\"notDeepEqual\",f.notDeepEqual)},f.notDeepStrictEqual=function t(e,r,n){x(e,r,!0)&&m(e,r,n,\"notDeepStrictEqual\",t)},f.strictEqual=function(t,e,r){t!==e&&m(t,e,r,\"===\",f.strictEqual)},f.notStrictEqual=function(t,e,r){t===e&&m(t,e,r,\"!==\",f.notStrictEqual)},f.throws=function(t,e,r){w(!0,t,e,r)},f.doesNotThrow=function(t,e,r){w(!1,t,e,r)},f.ifError=function(t){if(t)throw t},f.strict=n(function t(e,r){e||m(e,!0,r,\"==\",t)},f,{equal:f.strictEqual,deepEqual:f.deepStrictEqual,notEqual:f.notStrictEqual,notDeepEqual:f.notDeepStrictEqual}),f.strict.strict=f.strict;var k=Object.keys||function(t){var e=[];for(var r in t)s.call(t,r)&&e.push(r);return e}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"object-assign\":454,\"util/\":71}],69:[function(t,e,r){\"function\"==typeof Object.create?e.exports=function(t,e){t.super_=e,t.prototype=Object.create(e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}})}:e.exports=function(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}},{}],70:[function(t,e,r){e.exports=function(t){return t&&\"object\"==typeof t&&\"function\"==typeof t.copy&&\"function\"==typeof t.fill&&\"function\"==typeof t.readUInt8}},{}],71:[function(t,e,r){(function(e,n){var i=/%[sdj%]/g;r.format=function(t){if(!m(t)){for(var e=[],r=0;r<arguments.length;r++)e.push(s(arguments[r]));return e.join(\" \")}r=1;for(var n=arguments,a=n.length,o=String(t).replace(i,function(t){if(\"%%\"===t)return\"%\";if(r>=a)return t;switch(t){case\"%s\":return String(n[r++]);case\"%d\":return Number(n[r++]);case\"%j\":try{return JSON.stringify(n[r++])}catch(t){return\"[Circular]\"}default:return t}}),l=n[r];r<a;l=n[++r])g(l)||!b(l)?o+=\" \"+l:o+=\" \"+s(l);return o},r.deprecate=function(t,i){if(y(n.process))return function(){return r.deprecate(t,i).apply(this,arguments)};if(!0===e.noDeprecation)return t;var a=!1;return function(){if(!a){if(e.throwDeprecation)throw new Error(i);e.traceDeprecation?console.trace(i):console.error(i),a=!0}return t.apply(this,arguments)}};var a,o={};function s(t,e){var n={seen:[],stylize:c};return arguments.length>=3&&(n.depth=arguments[2]),arguments.length>=4&&(n.colors=arguments[3]),d(e)?n.showHidden=e:e&&r._extend(n,e),y(n.showHidden)&&(n.showHidden=!1),y(n.depth)&&(n.depth=2),y(n.colors)&&(n.colors=!1),y(n.customInspect)&&(n.customInspect=!0),n.colors&&(n.stylize=l),u(n,t,n.depth)}function l(t,e){var r=s.styles[e];return r?\"\\x1b[\"+s.colors[r][0]+\"m\"+t+\"\\x1b[\"+s.colors[r][1]+\"m\":t}function c(t,e){return t}function u(t,e,n){if(t.customInspect&&e&&k(e.inspect)&&e.inspect!==r.inspect&&(!e.constructor||e.constructor.prototype!==e)){var i=e.inspect(n,t);return m(i)||(i=u(t,i,n)),i}var a=function(t,e){if(y(e))return t.stylize(\"undefined\",\"undefined\");if(m(e)){var r=\"'\"+JSON.stringify(e).replace(/^\"|\"$/g,\"\").replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"')+\"'\";return t.stylize(r,\"string\")}if(v(e))return t.stylize(\"\"+e,\"number\");if(d(e))return t.stylize(\"\"+e,\"boolean\");if(g(e))return t.stylize(\"null\",\"null\")}(t,e);if(a)return a;var o=Object.keys(e),s=function(t){var e={};return t.forEach(function(t,r){e[t]=!0}),e}(o);if(t.showHidden&&(o=Object.getOwnPropertyNames(e)),w(e)&&(o.indexOf(\"message\")>=0||o.indexOf(\"description\")>=0))return h(e);if(0===o.length){if(k(e)){var l=e.name?\": \"+e.name:\"\";return t.stylize(\"[Function\"+l+\"]\",\"special\")}if(x(e))return t.stylize(RegExp.prototype.toString.call(e),\"regexp\");if(_(e))return t.stylize(Date.prototype.toString.call(e),\"date\");if(w(e))return h(e)}var c,b=\"\",T=!1,A=[\"{\",\"}\"];(p(e)&&(T=!0,A=[\"[\",\"]\"]),k(e))&&(b=\" [Function\"+(e.name?\": \"+e.name:\"\")+\"]\");return x(e)&&(b=\" \"+RegExp.prototype.toString.call(e)),_(e)&&(b=\" \"+Date.prototype.toUTCString.call(e)),w(e)&&(b=\" \"+h(e)),0!==o.length||T&&0!=e.length?n<0?x(e)?t.stylize(RegExp.prototype.toString.call(e),\"regexp\"):t.stylize(\"[Object]\",\"special\"):(t.seen.push(e),c=T?function(t,e,r,n,i){for(var a=[],o=0,s=e.length;o<s;++o)S(e,String(o))?a.push(f(t,e,r,n,String(o),!0)):a.push(\"\");return i.forEach(function(i){i.match(/^\\d+$/)||a.push(f(t,e,r,n,i,!0))}),a}(t,e,n,s,o):o.map(function(r){return f(t,e,n,s,r,T)}),t.seen.pop(),function(t,e,r){if(t.reduce(function(t,e){return 0,e.indexOf(\"\\n\")>=0&&0,t+e.replace(/\\u001b\\[\\d\\d?m/g,\"\").length+1},0)>60)return r[0]+(\"\"===e?\"\":e+\"\\n \")+\" \"+t.join(\",\\n  \")+\" \"+r[1];return r[0]+e+\" \"+t.join(\", \")+\" \"+r[1]}(c,b,A)):A[0]+b+A[1]}function h(t){return\"[\"+Error.prototype.toString.call(t)+\"]\"}function f(t,e,r,n,i,a){var o,s,l;if((l=Object.getOwnPropertyDescriptor(e,i)||{value:e[i]}).get?s=l.set?t.stylize(\"[Getter/Setter]\",\"special\"):t.stylize(\"[Getter]\",\"special\"):l.set&&(s=t.stylize(\"[Setter]\",\"special\")),S(n,i)||(o=\"[\"+i+\"]\"),s||(t.seen.indexOf(l.value)<0?(s=g(r)?u(t,l.value,null):u(t,l.value,r-1)).indexOf(\"\\n\")>-1&&(s=a?s.split(\"\\n\").map(function(t){return\"  \"+t}).join(\"\\n\").substr(2):\"\\n\"+s.split(\"\\n\").map(function(t){return\"   \"+t}).join(\"\\n\")):s=t.stylize(\"[Circular]\",\"special\")),y(o)){if(a&&i.match(/^\\d+$/))return s;(o=JSON.stringify(\"\"+i)).match(/^\"([a-zA-Z_][a-zA-Z_0-9]*)\"$/)?(o=o.substr(1,o.length-2),o=t.stylize(o,\"name\")):(o=o.replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"').replace(/(^\"|\"$)/g,\"'\"),o=t.stylize(o,\"string\"))}return o+\": \"+s}function p(t){return Array.isArray(t)}function d(t){return\"boolean\"==typeof t}function g(t){return null===t}function v(t){return\"number\"==typeof t}function m(t){return\"string\"==typeof t}function y(t){return void 0===t}function x(t){return b(t)&&\"[object RegExp]\"===T(t)}function b(t){return\"object\"==typeof t&&null!==t}function _(t){return b(t)&&\"[object Date]\"===T(t)}function w(t){return b(t)&&(\"[object Error]\"===T(t)||t instanceof Error)}function k(t){return\"function\"==typeof t}function T(t){return Object.prototype.toString.call(t)}function A(t){return t<10?\"0\"+t.toString(10):t.toString(10)}r.debuglog=function(t){if(y(a)&&(a=e.env.NODE_DEBUG||\"\"),t=t.toUpperCase(),!o[t])if(new RegExp(\"\\\\b\"+t+\"\\\\b\",\"i\").test(a)){var n=e.pid;o[t]=function(){var e=r.format.apply(r,arguments);console.error(\"%s %d: %s\",t,n,e)}}else o[t]=function(){};return o[t]},r.inspect=s,s.colors={bold:[1,22],italic:[3,23],underline:[4,24],inverse:[7,27],white:[37,39],grey:[90,39],black:[30,39],blue:[34,39],cyan:[36,39],green:[32,39],magenta:[35,39],red:[31,39],yellow:[33,39]},s.styles={special:\"cyan\",number:\"yellow\",boolean:\"yellow\",undefined:\"grey\",null:\"bold\",string:\"green\",date:\"magenta\",regexp:\"red\"},r.isArray=p,r.isBoolean=d,r.isNull=g,r.isNullOrUndefined=function(t){return null==t},r.isNumber=v,r.isString=m,r.isSymbol=function(t){return\"symbol\"==typeof t},r.isUndefined=y,r.isRegExp=x,r.isObject=b,r.isDate=_,r.isError=w,r.isFunction=k,r.isPrimitive=function(t){return null===t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||\"symbol\"==typeof t||\"undefined\"==typeof t},r.isBuffer=t(\"./support/isBuffer\");var M=[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"];function S(t,e){return Object.prototype.hasOwnProperty.call(t,e)}r.log=function(){var t,e;console.log(\"%s - %s\",(t=new Date,e=[A(t.getHours()),A(t.getMinutes()),A(t.getSeconds())].join(\":\"),[t.getDate(),M[t.getMonth()],e].join(\" \")),r.format.apply(r,arguments))},r.inherits=t(\"inherits\"),r._extend=function(t,e){if(!e||!b(e))return t;for(var r=Object.keys(e),n=r.length;n--;)t[r[n]]=e[r[n]];return t}}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./support/isBuffer\":70,_process:482,inherits:69}],72:[function(t,e,r){e.exports=function(t){return atob(t)}},{}],73:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=e.length,a=new Array(r+1),o=0;o<r;++o){for(var s=new Array(r+1),l=0;l<=r;++l)s[l]=t[l][o];a[o]=s}a[r]=new Array(r+1);for(var o=0;o<=r;++o)a[r][o]=1;for(var c=new Array(r+1),o=0;o<r;++o)c[o]=e[o];c[r]=1;var u=n(a,c),h=i(u[r+1]);0===h&&(h=1);for(var f=new Array(r+1),o=0;o<=r;++o)f[o]=i(u[o])/h;return f};var n=t(\"robust-linear-solve\");function i(t){for(var e=0,r=0;r<t.length;++r)e+=t[r];return e}},{\"robust-linear-solve\":509}],74:[function(t,e,r){\"use strict\";r.byteLength=function(t){var e=c(t),r=e[0],n=e[1];return 3*(r+n)/4-n},r.toByteArray=function(t){for(var e,r=c(t),n=r[0],o=r[1],s=new a(function(t,e,r){return 3*(e+r)/4-r}(0,n,o)),l=0,u=o>0?n-4:n,h=0;h<u;h+=4)e=i[t.charCodeAt(h)]<<18|i[t.charCodeAt(h+1)]<<12|i[t.charCodeAt(h+2)]<<6|i[t.charCodeAt(h+3)],s[l++]=e>>16&255,s[l++]=e>>8&255,s[l++]=255&e;2===o&&(e=i[t.charCodeAt(h)]<<2|i[t.charCodeAt(h+1)]>>4,s[l++]=255&e);1===o&&(e=i[t.charCodeAt(h)]<<10|i[t.charCodeAt(h+1)]<<4|i[t.charCodeAt(h+2)]>>2,s[l++]=e>>8&255,s[l++]=255&e);return s},r.fromByteArray=function(t){for(var e,r=t.length,i=r%3,a=[],o=0,s=r-i;o<s;o+=16383)a.push(u(t,o,o+16383>s?s:o+16383));1===i?(e=t[r-1],a.push(n[e>>2]+n[e<<4&63]+\"==\")):2===i&&(e=(t[r-2]<<8)+t[r-1],a.push(n[e>>10]+n[e>>4&63]+n[e<<2&63]+\"=\"));return a.join(\"\")};for(var n=[],i=[],a=\"undefined\"!=typeof Uint8Array?Uint8Array:Array,o=\"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/\",s=0,l=o.length;s<l;++s)n[s]=o[s],i[o.charCodeAt(s)]=s;function c(t){var e=t.length;if(e%4>0)throw new Error(\"Invalid string. Length must be a multiple of 4\");var r=t.indexOf(\"=\");return-1===r&&(r=e),[r,r===e?0:4-r%4]}function u(t,e,r){for(var i,a,o=[],s=e;s<r;s+=3)i=(t[s]<<16&16711680)+(t[s+1]<<8&65280)+(255&t[s+2]),o.push(n[(a=i)>>18&63]+n[a>>12&63]+n[a>>6&63]+n[63&a]);return o.join(\"\")}i[\"-\".charCodeAt(0)]=62,i[\"_\".charCodeAt(0)]=63},{}],75:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).add(e[0].mul(t[1])),t[1].mul(e[1]))}},{\"./lib/rationalize\":85}],76:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t[0].mul(e[1]).cmp(e[0].mul(t[1]))}},{}],77:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]),t[1].mul(e[0]))}},{\"./lib/rationalize\":85}],78:[function(t,e,r){\"use strict\";var n=t(\"./is-rat\"),i=t(\"./lib/is-bn\"),a=t(\"./lib/num-to-bn\"),o=t(\"./lib/str-to-bn\"),s=t(\"./lib/rationalize\"),l=t(\"./div\");e.exports=function t(e,r){if(n(e))return r?l(e,t(r)):[e[0].clone(),e[1].clone()];var c=0;var u,h;if(i(e))u=e.clone();else if(\"string\"==typeof e)u=o(e);else{if(0===e)return[a(0),a(1)];if(e===Math.floor(e))u=a(e);else{for(;e!==Math.floor(e);)e*=Math.pow(2,256),c-=256;u=a(e)}}if(n(r))u.mul(r[1]),h=r[0].clone();else if(i(r))h=r.clone();else if(\"string\"==typeof r)h=o(r);else if(r)if(r===Math.floor(r))h=a(r);else{for(;r!==Math.floor(r);)r*=Math.pow(2,256),c+=256;h=a(r)}else h=a(1);c>0?u=u.ushln(c):c<0&&(h=h.ushln(-c));return s(u,h)}},{\"./div\":77,\"./is-rat\":79,\"./lib/is-bn\":83,\"./lib/num-to-bn\":84,\"./lib/rationalize\":85,\"./lib/str-to-bn\":86}],79:[function(t,e,r){\"use strict\";var n=t(\"./lib/is-bn\");e.exports=function(t){return Array.isArray(t)&&2===t.length&&n(t[0])&&n(t[1])}},{\"./lib/is-bn\":83}],80:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return t.cmp(new n(0))}},{\"bn.js\":94}],81:[function(t,e,r){\"use strict\";var n=t(\"./bn-sign\");e.exports=function(t){var e=t.length,r=t.words,i=0;if(1===e)i=r[0];else if(2===e)i=r[0]+67108864*r[1];else for(var a=0;a<e;a++){var o=r[a];i+=o*Math.pow(67108864,a)}return n(t)*i}},{\"./bn-sign\":80}],82:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=t(\"bit-twiddle\").countTrailingZeros;e.exports=function(t){var e=i(n.lo(t));if(e<32)return e;var r=i(n.hi(t));if(r>20)return 52;return r+32}},{\"bit-twiddle\":92,\"double-bits\":167}],83:[function(t,e,r){\"use strict\";t(\"bn.js\");e.exports=function(t){return t&&\"object\"==typeof t&&Boolean(t.words)}},{\"bn.js\":94}],84:[function(t,e,r){\"use strict\";var n=t(\"bn.js\"),i=t(\"double-bits\");e.exports=function(t){var e=i.exponent(t);return e<52?new n(t):new n(t*Math.pow(2,52-e)).ushln(e-52)}},{\"bn.js\":94,\"double-bits\":167}],85:[function(t,e,r){\"use strict\";var n=t(\"./num-to-bn\"),i=t(\"./bn-sign\");e.exports=function(t,e){var r=i(t),a=i(e);if(0===r)return[n(0),n(1)];if(0===a)return[n(0),n(0)];a<0&&(t=t.neg(),e=e.neg());var o=t.gcd(e);if(o.cmpn(1))return[t.div(o),e.div(o)];return[t,e]}},{\"./bn-sign\":80,\"./num-to-bn\":84}],86:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return new n(t)}},{\"bn.js\":94}],87:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[0]),t[1].mul(e[1]))}},{\"./lib/rationalize\":85}],88:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-sign\");e.exports=function(t){return n(t[0])*n(t[1])}},{\"./lib/bn-sign\":80}],89:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).sub(t[1].mul(e[0])),t[1].mul(e[1]))}},{\"./lib/rationalize\":85}],90:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-to-num\"),i=t(\"./lib/ctz\");e.exports=function(t){var e=t[0],r=t[1];if(0===e.cmpn(0))return 0;var a=e.abs().divmod(r.abs()),o=a.div,s=n(o),l=a.mod,c=e.negative!==r.negative?-1:1;if(0===l.cmpn(0))return c*s;if(s){var u=i(s)+4,h=n(l.ushln(u).divRound(r));return c*(s+h*Math.pow(2,-u))}var f=r.bitLength()-l.bitLength()+53,h=n(l.ushln(f).divRound(r));return f<1023?c*h*Math.pow(2,-f):(h*=Math.pow(2,-1023),c*h*Math.pow(2,1023-f))}},{\"./lib/bn-to-num\":81,\"./lib/ctz\":82}],91:[function(t,e,r){\"use strict\";function n(t,e,r,n,i,a){var o=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",a?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a\",i?\".get(m)\":\"[m]\"];return a?e.indexOf(\"c\")<0?o.push(\";if(x===y){return m}else if(x<=y){\"):o.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):o.push(\";if(\",e,\"){i=m;\"),r?o.push(\"l=m+1}else{h=m-1}\"):o.push(\"h=m-1}else{l=m+1}\"),o.push(\"}\"),a?o.push(\"return -1};\"):o.push(\"return i};\"),o.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],!1,i),n(\"B\",\"x\"+t+\"y\",e,[\"y\"],!0,i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!1,i),n(\"Q\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!0,i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(a.shape){if(typeof(c)==='function'){return Q(a,(l===undefined)?0:l|0,(h===undefined)?a.shape[0]-1:h|0,y,c)}else{return B(a,(c===undefined)?0:c|0,(l===undefined)?a.shape[0]-1:l|0,y)}}else{if(typeof(c)==='function'){return P(a,(l===undefined)?0:l|0,(h===undefined)?a.length-1:h|0,y,c)}else{return A(a,(c===undefined)?0:c|0,(l===undefined)?a.length-1:l|0,y)}}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],92:[function(t,e,r){\"use strict\";function n(t){var e=32;return(t&=-t)&&e--,65535&t&&(e-=16),16711935&t&&(e-=8),252645135&t&&(e-=4),858993459&t&&(e-=2),1431655765&t&&(e-=1),e}r.INT_BITS=32,r.INT_MAX=2147483647,r.INT_MIN=-1<<31,r.sign=function(t){return(t>0)-(t<0)},r.abs=function(t){var e=t>>31;return(t^e)-e},r.min=function(t,e){return e^(t^e)&-(t<e)},r.max=function(t,e){return t^(t^e)&-(t<e)},r.isPow2=function(t){return!(t&t-1||!t)},r.log2=function(t){var e,r;return e=(t>65535)<<4,e|=r=((t>>>=e)>255)<<3,e|=r=((t>>>=r)>15)<<2,(e|=r=((t>>>=r)>3)<<1)|(t>>>=r)>>1},r.log10=function(t){return t>=1e9?9:t>=1e8?8:t>=1e7?7:t>=1e6?6:t>=1e5?5:t>=1e4?4:t>=1e3?3:t>=100?2:t>=10?1:0},r.popCount=function(t){return 16843009*((t=(858993459&(t-=t>>>1&1431655765))+(t>>>2&858993459))+(t>>>4)&252645135)>>>24},r.countTrailingZeros=n,r.nextPow2=function(t){return t+=0===t,--t,t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)+1},r.prevPow2=function(t){return t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)-(t>>>1)},r.parity=function(t){return t^=t>>>16,t^=t>>>8,t^=t>>>4,27030>>>(t&=15)&1};var i=new Array(256);!function(t){for(var e=0;e<256;++e){var r=e,n=e,i=7;for(r>>>=1;r;r>>>=1)n<<=1,n|=1&r,--i;t[e]=n<<i&255}}(i),r.reverse=function(t){return i[255&t]<<24|i[t>>>8&255]<<16|i[t>>>16&255]<<8|i[t>>>24&255]},r.interleave2=function(t,e){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t&=65535)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e&=65535)|e<<8))|e<<4))|e<<2))|e<<1))<<1},r.deinterleave2=function(t,e){return(t=65535&((t=16711935&((t=252645135&((t=858993459&((t=t>>>e&1431655765)|t>>>1))|t>>>2))|t>>>4))|t>>>16))<<16>>16},r.interleave3=function(t,e,r){return t=1227133513&((t=3272356035&((t=251719695&((t=4278190335&((t&=1023)|t<<16))|t<<8))|t<<4))|t<<2),(t|=(e=1227133513&((e=3272356035&((e=251719695&((e=4278190335&((e&=1023)|e<<16))|e<<8))|e<<4))|e<<2))<<1)|(r=1227133513&((r=3272356035&((r=251719695&((r=4278190335&((r&=1023)|r<<16))|r<<8))|r<<4))|r<<2))<<2},r.deinterleave3=function(t,e){return(t=1023&((t=4278190335&((t=251719695&((t=3272356035&((t=t>>>e&1227133513)|t>>>2))|t>>>4))|t>>>8))|t>>>16))<<22>>22},r.nextCombination=function(t){var e=t|t-1;return e+1|(~e&-~e)-1>>>n(t)+1}},{}],93:[function(t,e,r){\"use strict\";var n=t(\"clamp\");e.exports=function(t,e){e||(e={});var r,o,s,l,c,u,h,f,p,d,g,v=null==e.cutoff?.25:e.cutoff,m=null==e.radius?8:e.radius,y=e.channel||0;if(ArrayBuffer.isView(t)||Array.isArray(t)){if(!e.width||!e.height)throw Error(\"For raw data width and height should be provided by options\");r=e.width,o=e.height,l=t,u=e.stride?e.stride:Math.floor(t.length/r/o)}else window.HTMLCanvasElement&&t instanceof window.HTMLCanvasElement?(h=(f=t).getContext(\"2d\"),r=f.width,o=f.height,p=h.getImageData(0,0,r,o),l=p.data,u=4):window.CanvasRenderingContext2D&&t instanceof window.CanvasRenderingContext2D?(f=t.canvas,h=t,r=f.width,o=f.height,p=h.getImageData(0,0,r,o),l=p.data,u=4):window.ImageData&&t instanceof window.ImageData&&(p=t,r=t.width,o=t.height,l=p.data,u=4);if(s=Math.max(r,o),window.Uint8ClampedArray&&l instanceof window.Uint8ClampedArray||window.Uint8Array&&l instanceof window.Uint8Array)for(c=l,l=Array(r*o),d=0,g=c.length;d<g;d++)l[d]=c[d*u+y]/255;else if(1!==u)throw Error(\"Raw data can have only 1 value per pixel\");var x=Array(r*o),b=Array(r*o),_=Array(s),w=Array(s),k=Array(s+1),T=Array(s);for(d=0,g=r*o;d<g;d++){var A=l[d];x[d]=1===A?0:0===A?i:Math.pow(Math.max(0,.5-A),2),b[d]=1===A?i:0===A?0:Math.pow(Math.max(0,A-.5),2)}a(x,r,o,_,w,T,k),a(b,r,o,_,w,T,k);var M=window.Float32Array?new Float32Array(r*o):new Array(r*o);for(d=0,g=r*o;d<g;d++)M[d]=n(1-((x[d]-b[d])/m+v),0,1);return M};var i=1e20;function a(t,e,r,n,i,a,s){for(var l=0;l<e;l++){for(var c=0;c<r;c++)n[c]=t[c*e+l];for(o(n,i,a,s,r),c=0;c<r;c++)t[c*e+l]=i[c]}for(c=0;c<r;c++){for(l=0;l<e;l++)n[l]=t[c*e+l];for(o(n,i,a,s,e),l=0;l<e;l++)t[c*e+l]=Math.sqrt(i[l])}}function o(t,e,r,n,a){r[0]=0,n[0]=-i,n[1]=+i;for(var o=1,s=0;o<a;o++){for(var l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);l<=n[s];)s--,l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);r[++s]=o,n[s]=l,n[s+1]=+i}for(o=0,s=0;o<a;o++){for(;n[s+1]<o;)s++;e[o]=(o-r[s])*(o-r[s])+t[r[s]]}}},{clamp:115}],94:[function(t,e,r){!function(e,r){\"use strict\";function n(t,e){if(!t)throw new Error(e||\"Assertion failed\")}function i(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}function a(t,e,r){if(a.isBN(t))return t;this.negative=0,this.words=null,this.length=0,this.red=null,null!==t&&(\"le\"!==e&&\"be\"!==e||(r=e,e=10),this._init(t||0,e||10,r||\"be\"))}var o;\"object\"==typeof e?e.exports=a:r.BN=a,a.BN=a,a.wordSize=26;try{o=t(\"buffer\").Buffer}catch(t){}function s(t,e,r){for(var n=0,i=Math.min(t.length,r),a=e;a<i;a++){var o=t.charCodeAt(a)-48;n<<=4,n|=o>=49&&o<=54?o-49+10:o>=17&&o<=22?o-17+10:15&o}return n}function l(t,e,r,n){for(var i=0,a=Math.min(t.length,r),o=e;o<a;o++){var s=t.charCodeAt(o)-48;i*=n,i+=s>=49?s-49+10:s>=17?s-17+10:s}return i}a.isBN=function(t){return t instanceof a||null!==t&&\"object\"==typeof t&&t.constructor.wordSize===a.wordSize&&Array.isArray(t.words)},a.max=function(t,e){return t.cmp(e)>0?t:e},a.min=function(t,e){return t.cmp(e)<0?t:e},a.prototype._init=function(t,e,r){if(\"number\"==typeof t)return this._initNumber(t,e,r);if(\"object\"==typeof t)return this._initArray(t,e,r);\"hex\"===e&&(e=16),n(e===(0|e)&&e>=2&&e<=36);var i=0;\"-\"===(t=t.toString().replace(/\\s+/g,\"\"))[0]&&i++,16===e?this._parseHex(t,i):this._parseBase(t,e,i),\"-\"===t[0]&&(this.negative=1),this.strip(),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initNumber=function(t,e,r){t<0&&(this.negative=1,t=-t),t<67108864?(this.words=[67108863&t],this.length=1):t<4503599627370496?(this.words=[67108863&t,t/67108864&67108863],this.length=2):(n(t<9007199254740992),this.words=[67108863&t,t/67108864&67108863,1],this.length=3),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initArray=function(t,e,r){if(n(\"number\"==typeof t.length),t.length<=0)return this.words=[0],this.length=1,this;this.length=Math.ceil(t.length/3),this.words=new Array(this.length);for(var i=0;i<this.length;i++)this.words[i]=0;var a,o,s=0;if(\"be\"===r)for(i=t.length-1,a=0;i>=0;i-=3)o=t[i]|t[i-1]<<8|t[i-2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);else if(\"le\"===r)for(i=0,a=0;i<t.length;i+=3)o=t[i]|t[i+1]<<8|t[i+2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);return this.strip()},a.prototype._parseHex=function(t,e){this.length=Math.ceil((t.length-e)/6),this.words=new Array(this.length);for(var r=0;r<this.length;r++)this.words[r]=0;var n,i,a=0;for(r=t.length-6,n=0;r>=e;r-=6)i=s(t,r,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303,(a+=24)>=26&&(a-=26,n++);r+6!==e&&(i=s(t,e,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303),this.strip()},a.prototype._parseBase=function(t,e,r){this.words=[0],this.length=1;for(var n=0,i=1;i<=67108863;i*=e)n++;n--,i=i/e|0;for(var a=t.length-r,o=a%n,s=Math.min(a,a-o)+r,c=0,u=r;u<s;u+=n)c=l(t,u,u+n,e),this.imuln(i),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c);if(0!==o){var h=1;for(c=l(t,u,t.length,e),u=0;u<o;u++)h*=e;this.imuln(h),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c)}},a.prototype.copy=function(t){t.words=new Array(this.length);for(var e=0;e<this.length;e++)t.words[e]=this.words[e];t.length=this.length,t.negative=this.negative,t.red=this.red},a.prototype.clone=function(){var t=new a(null);return this.copy(t),t},a.prototype._expand=function(t){for(;this.length<t;)this.words[this.length++]=0;return this},a.prototype.strip=function(){for(;this.length>1&&0===this.words[this.length-1];)this.length--;return this._normSign()},a.prototype._normSign=function(){return 1===this.length&&0===this.words[0]&&(this.negative=0),this},a.prototype.inspect=function(){return(this.red?\"<BN-R: \":\"<BN: \")+this.toString(16)+\">\"};var c=[\"\",\"0\",\"00\",\"000\",\"0000\",\"00000\",\"000000\",\"0000000\",\"00000000\",\"000000000\",\"0000000000\",\"00000000000\",\"000000000000\",\"0000000000000\",\"00000000000000\",\"000000000000000\",\"0000000000000000\",\"00000000000000000\",\"000000000000000000\",\"0000000000000000000\",\"00000000000000000000\",\"000000000000000000000\",\"0000000000000000000000\",\"00000000000000000000000\",\"000000000000000000000000\",\"0000000000000000000000000\"],u=[0,0,25,16,12,11,10,9,8,8,7,7,7,7,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5],h=[0,0,33554432,43046721,16777216,48828125,60466176,40353607,16777216,43046721,1e7,19487171,35831808,62748517,7529536,11390625,16777216,24137569,34012224,47045881,64e6,4084101,5153632,6436343,7962624,9765625,11881376,14348907,17210368,20511149,243e5,28629151,33554432,39135393,45435424,52521875,60466176];function f(t,e,r){r.negative=e.negative^t.negative;var n=t.length+e.length|0;r.length=n,n=n-1|0;var i=0|t.words[0],a=0|e.words[0],o=i*a,s=67108863&o,l=o/67108864|0;r.words[0]=s;for(var c=1;c<n;c++){for(var u=l>>>26,h=67108863&l,f=Math.min(c,e.length-1),p=Math.max(0,c-t.length+1);p<=f;p++){var d=c-p|0;u+=(o=(i=0|t.words[d])*(a=0|e.words[p])+h)/67108864|0,h=67108863&o}r.words[c]=0|h,l=0|u}return 0!==l?r.words[c]=0|l:r.length--,r.strip()}a.prototype.toString=function(t,e){var r;if(e=0|e||1,16===(t=t||10)||\"hex\"===t){r=\"\";for(var i=0,a=0,o=0;o<this.length;o++){var s=this.words[o],l=(16777215&(s<<i|a)).toString(16);r=0!==(a=s>>>24-i&16777215)||o!==this.length-1?c[6-l.length]+l+r:l+r,(i+=2)>=26&&(i-=26,o--)}for(0!==a&&(r=a.toString(16)+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}if(t===(0|t)&&t>=2&&t<=36){var f=u[t],p=h[t];r=\"\";var d=this.clone();for(d.negative=0;!d.isZero();){var g=d.modn(p).toString(t);r=(d=d.idivn(p)).isZero()?g+r:c[f-g.length]+g+r}for(this.isZero()&&(r=\"0\"+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}n(!1,\"Base should be between 2 and 36\")},a.prototype.toNumber=function(){var t=this.words[0];return 2===this.length?t+=67108864*this.words[1]:3===this.length&&1===this.words[2]?t+=4503599627370496+67108864*this.words[1]:this.length>2&&n(!1,\"Number can only safely store up to 53 bits\"),0!==this.negative?-t:t},a.prototype.toJSON=function(){return this.toString(16)},a.prototype.toBuffer=function(t,e){return n(\"undefined\"!=typeof o),this.toArrayLike(o,t,e)},a.prototype.toArray=function(t,e){return this.toArrayLike(Array,t,e)},a.prototype.toArrayLike=function(t,e,r){var i=this.byteLength(),a=r||Math.max(1,i);n(i<=a,\"byte array longer than desired length\"),n(a>0,\"Requested array length <= 0\"),this.strip();var o,s,l=\"le\"===e,c=new t(a),u=this.clone();if(l){for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[s]=o;for(;s<a;s++)c[s]=0}else{for(s=0;s<a-i;s++)c[s]=0;for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[a-s-1]=o}return c},Math.clz32?a.prototype._countBits=function(t){return 32-Math.clz32(t)}:a.prototype._countBits=function(t){var e=t,r=0;return e>=4096&&(r+=13,e>>>=13),e>=64&&(r+=7,e>>>=7),e>=8&&(r+=4,e>>>=4),e>=2&&(r+=2,e>>>=2),r+e},a.prototype._zeroBits=function(t){if(0===t)return 26;var e=t,r=0;return 0==(8191&e)&&(r+=13,e>>>=13),0==(127&e)&&(r+=7,e>>>=7),0==(15&e)&&(r+=4,e>>>=4),0==(3&e)&&(r+=2,e>>>=2),0==(1&e)&&r++,r},a.prototype.bitLength=function(){var t=this.words[this.length-1],e=this._countBits(t);return 26*(this.length-1)+e},a.prototype.zeroBits=function(){if(this.isZero())return 0;for(var t=0,e=0;e<this.length;e++){var r=this._zeroBits(this.words[e]);if(t+=r,26!==r)break}return t},a.prototype.byteLength=function(){return Math.ceil(this.bitLength()/8)},a.prototype.toTwos=function(t){return 0!==this.negative?this.abs().inotn(t).iaddn(1):this.clone()},a.prototype.fromTwos=function(t){return this.testn(t-1)?this.notn(t).iaddn(1).ineg():this.clone()},a.prototype.isNeg=function(){return 0!==this.negative},a.prototype.neg=function(){return this.clone().ineg()},a.prototype.ineg=function(){return this.isZero()||(this.negative^=1),this},a.prototype.iuor=function(t){for(;this.length<t.length;)this.words[this.length++]=0;for(var e=0;e<t.length;e++)this.words[e]=this.words[e]|t.words[e];return this.strip()},a.prototype.ior=function(t){return n(0==(this.negative|t.negative)),this.iuor(t)},a.prototype.or=function(t){return this.length>t.length?this.clone().ior(t):t.clone().ior(this)},a.prototype.uor=function(t){return this.length>t.length?this.clone().iuor(t):t.clone().iuor(this)},a.prototype.iuand=function(t){var e;e=this.length>t.length?t:this;for(var r=0;r<e.length;r++)this.words[r]=this.words[r]&t.words[r];return this.length=e.length,this.strip()},a.prototype.iand=function(t){return n(0==(this.negative|t.negative)),this.iuand(t)},a.prototype.and=function(t){return this.length>t.length?this.clone().iand(t):t.clone().iand(this)},a.prototype.uand=function(t){return this.length>t.length?this.clone().iuand(t):t.clone().iuand(this)},a.prototype.iuxor=function(t){var e,r;this.length>t.length?(e=this,r=t):(e=t,r=this);for(var n=0;n<r.length;n++)this.words[n]=e.words[n]^r.words[n];if(this!==e)for(;n<e.length;n++)this.words[n]=e.words[n];return this.length=e.length,this.strip()},a.prototype.ixor=function(t){return n(0==(this.negative|t.negative)),this.iuxor(t)},a.prototype.xor=function(t){return this.length>t.length?this.clone().ixor(t):t.clone().ixor(this)},a.prototype.uxor=function(t){return this.length>t.length?this.clone().iuxor(t):t.clone().iuxor(this)},a.prototype.inotn=function(t){n(\"number\"==typeof t&&t>=0);var e=0|Math.ceil(t/26),r=t%26;this._expand(e),r>0&&e--;for(var i=0;i<e;i++)this.words[i]=67108863&~this.words[i];return r>0&&(this.words[i]=~this.words[i]&67108863>>26-r),this.strip()},a.prototype.notn=function(t){return this.clone().inotn(t)},a.prototype.setn=function(t,e){n(\"number\"==typeof t&&t>=0);var r=t/26|0,i=t%26;return this._expand(r+1),this.words[r]=e?this.words[r]|1<<i:this.words[r]&~(1<<i),this.strip()},a.prototype.iadd=function(t){var e,r,n;if(0!==this.negative&&0===t.negative)return this.negative=0,e=this.isub(t),this.negative^=1,this._normSign();if(0===this.negative&&0!==t.negative)return t.negative=0,e=this.isub(t),t.negative=1,e._normSign();this.length>t.length?(r=this,n=t):(r=t,n=this);for(var i=0,a=0;a<n.length;a++)e=(0|r.words[a])+(0|n.words[a])+i,this.words[a]=67108863&e,i=e>>>26;for(;0!==i&&a<r.length;a++)e=(0|r.words[a])+i,this.words[a]=67108863&e,i=e>>>26;if(this.length=r.length,0!==i)this.words[this.length]=i,this.length++;else if(r!==this)for(;a<r.length;a++)this.words[a]=r.words[a];return this},a.prototype.add=function(t){var e;return 0!==t.negative&&0===this.negative?(t.negative=0,e=this.sub(t),t.negative^=1,e):0===t.negative&&0!==this.negative?(this.negative=0,e=t.sub(this),this.negative=1,e):this.length>t.length?this.clone().iadd(t):t.clone().iadd(this)},a.prototype.isub=function(t){if(0!==t.negative){t.negative=0;var e=this.iadd(t);return t.negative=1,e._normSign()}if(0!==this.negative)return this.negative=0,this.iadd(t),this.negative=1,this._normSign();var r,n,i=this.cmp(t);if(0===i)return this.negative=0,this.length=1,this.words[0]=0,this;i>0?(r=this,n=t):(r=t,n=this);for(var a=0,o=0;o<n.length;o++)a=(e=(0|r.words[o])-(0|n.words[o])+a)>>26,this.words[o]=67108863&e;for(;0!==a&&o<r.length;o++)a=(e=(0|r.words[o])+a)>>26,this.words[o]=67108863&e;if(0===a&&o<r.length&&r!==this)for(;o<r.length;o++)this.words[o]=r.words[o];return this.length=Math.max(this.length,o),r!==this&&(this.negative=1),this.strip()},a.prototype.sub=function(t){return this.clone().isub(t)};var p=function(t,e,r){var n,i,a,o=t.words,s=e.words,l=r.words,c=0,u=0|o[0],h=8191&u,f=u>>>13,p=0|o[1],d=8191&p,g=p>>>13,v=0|o[2],m=8191&v,y=v>>>13,x=0|o[3],b=8191&x,_=x>>>13,w=0|o[4],k=8191&w,T=w>>>13,A=0|o[5],M=8191&A,S=A>>>13,E=0|o[6],C=8191&E,L=E>>>13,P=0|o[7],O=8191&P,z=P>>>13,I=0|o[8],D=8191&I,R=I>>>13,F=0|o[9],B=8191&F,N=F>>>13,j=0|s[0],U=8191&j,V=j>>>13,q=0|s[1],H=8191&q,G=q>>>13,Y=0|s[2],W=8191&Y,X=Y>>>13,Z=0|s[3],J=8191&Z,K=Z>>>13,$=0|s[4],Q=8191&$,tt=$>>>13,et=0|s[5],rt=8191&et,nt=et>>>13,it=0|s[6],at=8191&it,ot=it>>>13,st=0|s[7],lt=8191&st,ct=st>>>13,ut=0|s[8],ht=8191&ut,ft=ut>>>13,pt=0|s[9],dt=8191&pt,gt=pt>>>13;r.negative=t.negative^e.negative,r.length=19;var vt=(c+(n=Math.imul(h,U))|0)+((8191&(i=(i=Math.imul(h,V))+Math.imul(f,U)|0))<<13)|0;c=((a=Math.imul(f,V))+(i>>>13)|0)+(vt>>>26)|0,vt&=67108863,n=Math.imul(d,U),i=(i=Math.imul(d,V))+Math.imul(g,U)|0,a=Math.imul(g,V);var mt=(c+(n=n+Math.imul(h,H)|0)|0)+((8191&(i=(i=i+Math.imul(h,G)|0)+Math.imul(f,H)|0))<<13)|0;c=((a=a+Math.imul(f,G)|0)+(i>>>13)|0)+(mt>>>26)|0,mt&=67108863,n=Math.imul(m,U),i=(i=Math.imul(m,V))+Math.imul(y,U)|0,a=Math.imul(y,V),n=n+Math.imul(d,H)|0,i=(i=i+Math.imul(d,G)|0)+Math.imul(g,H)|0,a=a+Math.imul(g,G)|0;var yt=(c+(n=n+Math.imul(h,W)|0)|0)+((8191&(i=(i=i+Math.imul(h,X)|0)+Math.imul(f,W)|0))<<13)|0;c=((a=a+Math.imul(f,X)|0)+(i>>>13)|0)+(yt>>>26)|0,yt&=67108863,n=Math.imul(b,U),i=(i=Math.imul(b,V))+Math.imul(_,U)|0,a=Math.imul(_,V),n=n+Math.imul(m,H)|0,i=(i=i+Math.imul(m,G)|0)+Math.imul(y,H)|0,a=a+Math.imul(y,G)|0,n=n+Math.imul(d,W)|0,i=(i=i+Math.imul(d,X)|0)+Math.imul(g,W)|0,a=a+Math.imul(g,X)|0;var xt=(c+(n=n+Math.imul(h,J)|0)|0)+((8191&(i=(i=i+Math.imul(h,K)|0)+Math.imul(f,J)|0))<<13)|0;c=((a=a+Math.imul(f,K)|0)+(i>>>13)|0)+(xt>>>26)|0,xt&=67108863,n=Math.imul(k,U),i=(i=Math.imul(k,V))+Math.imul(T,U)|0,a=Math.imul(T,V),n=n+Math.imul(b,H)|0,i=(i=i+Math.imul(b,G)|0)+Math.imul(_,H)|0,a=a+Math.imul(_,G)|0,n=n+Math.imul(m,W)|0,i=(i=i+Math.imul(m,X)|0)+Math.imul(y,W)|0,a=a+Math.imul(y,X)|0,n=n+Math.imul(d,J)|0,i=(i=i+Math.imul(d,K)|0)+Math.imul(g,J)|0,a=a+Math.imul(g,K)|0;var bt=(c+(n=n+Math.imul(h,Q)|0)|0)+((8191&(i=(i=i+Math.imul(h,tt)|0)+Math.imul(f,Q)|0))<<13)|0;c=((a=a+Math.imul(f,tt)|0)+(i>>>13)|0)+(bt>>>26)|0,bt&=67108863,n=Math.imul(M,U),i=(i=Math.imul(M,V))+Math.imul(S,U)|0,a=Math.imul(S,V),n=n+Math.imul(k,H)|0,i=(i=i+Math.imul(k,G)|0)+Math.imul(T,H)|0,a=a+Math.imul(T,G)|0,n=n+Math.imul(b,W)|0,i=(i=i+Math.imul(b,X)|0)+Math.imul(_,W)|0,a=a+Math.imul(_,X)|0,n=n+Math.imul(m,J)|0,i=(i=i+Math.imul(m,K)|0)+Math.imul(y,J)|0,a=a+Math.imul(y,K)|0,n=n+Math.imul(d,Q)|0,i=(i=i+Math.imul(d,tt)|0)+Math.imul(g,Q)|0,a=a+Math.imul(g,tt)|0;var _t=(c+(n=n+Math.imul(h,rt)|0)|0)+((8191&(i=(i=i+Math.imul(h,nt)|0)+Math.imul(f,rt)|0))<<13)|0;c=((a=a+Math.imul(f,nt)|0)+(i>>>13)|0)+(_t>>>26)|0,_t&=67108863,n=Math.imul(C,U),i=(i=Math.imul(C,V))+Math.imul(L,U)|0,a=Math.imul(L,V),n=n+Math.imul(M,H)|0,i=(i=i+Math.imul(M,G)|0)+Math.imul(S,H)|0,a=a+Math.imul(S,G)|0,n=n+Math.imul(k,W)|0,i=(i=i+Math.imul(k,X)|0)+Math.imul(T,W)|0,a=a+Math.imul(T,X)|0,n=n+Math.imul(b,J)|0,i=(i=i+Math.imul(b,K)|0)+Math.imul(_,J)|0,a=a+Math.imul(_,K)|0,n=n+Math.imul(m,Q)|0,i=(i=i+Math.imul(m,tt)|0)+Math.imul(y,Q)|0,a=a+Math.imul(y,tt)|0,n=n+Math.imul(d,rt)|0,i=(i=i+Math.imul(d,nt)|0)+Math.imul(g,rt)|0,a=a+Math.imul(g,nt)|0;var wt=(c+(n=n+Math.imul(h,at)|0)|0)+((8191&(i=(i=i+Math.imul(h,ot)|0)+Math.imul(f,at)|0))<<13)|0;c=((a=a+Math.imul(f,ot)|0)+(i>>>13)|0)+(wt>>>26)|0,wt&=67108863,n=Math.imul(O,U),i=(i=Math.imul(O,V))+Math.imul(z,U)|0,a=Math.imul(z,V),n=n+Math.imul(C,H)|0,i=(i=i+Math.imul(C,G)|0)+Math.imul(L,H)|0,a=a+Math.imul(L,G)|0,n=n+Math.imul(M,W)|0,i=(i=i+Math.imul(M,X)|0)+Math.imul(S,W)|0,a=a+Math.imul(S,X)|0,n=n+Math.imul(k,J)|0,i=(i=i+Math.imul(k,K)|0)+Math.imul(T,J)|0,a=a+Math.imul(T,K)|0,n=n+Math.imul(b,Q)|0,i=(i=i+Math.imul(b,tt)|0)+Math.imul(_,Q)|0,a=a+Math.imul(_,tt)|0,n=n+Math.imul(m,rt)|0,i=(i=i+Math.imul(m,nt)|0)+Math.imul(y,rt)|0,a=a+Math.imul(y,nt)|0,n=n+Math.imul(d,at)|0,i=(i=i+Math.imul(d,ot)|0)+Math.imul(g,at)|0,a=a+Math.imul(g,ot)|0;var kt=(c+(n=n+Math.imul(h,lt)|0)|0)+((8191&(i=(i=i+Math.imul(h,ct)|0)+Math.imul(f,lt)|0))<<13)|0;c=((a=a+Math.imul(f,ct)|0)+(i>>>13)|0)+(kt>>>26)|0,kt&=67108863,n=Math.imul(D,U),i=(i=Math.imul(D,V))+Math.imul(R,U)|0,a=Math.imul(R,V),n=n+Math.imul(O,H)|0,i=(i=i+Math.imul(O,G)|0)+Math.imul(z,H)|0,a=a+Math.imul(z,G)|0,n=n+Math.imul(C,W)|0,i=(i=i+Math.imul(C,X)|0)+Math.imul(L,W)|0,a=a+Math.imul(L,X)|0,n=n+Math.imul(M,J)|0,i=(i=i+Math.imul(M,K)|0)+Math.imul(S,J)|0,a=a+Math.imul(S,K)|0,n=n+Math.imul(k,Q)|0,i=(i=i+Math.imul(k,tt)|0)+Math.imul(T,Q)|0,a=a+Math.imul(T,tt)|0,n=n+Math.imul(b,rt)|0,i=(i=i+Math.imul(b,nt)|0)+Math.imul(_,rt)|0,a=a+Math.imul(_,nt)|0,n=n+Math.imul(m,at)|0,i=(i=i+Math.imul(m,ot)|0)+Math.imul(y,at)|0,a=a+Math.imul(y,ot)|0,n=n+Math.imul(d,lt)|0,i=(i=i+Math.imul(d,ct)|0)+Math.imul(g,lt)|0,a=a+Math.imul(g,ct)|0;var Tt=(c+(n=n+Math.imul(h,ht)|0)|0)+((8191&(i=(i=i+Math.imul(h,ft)|0)+Math.imul(f,ht)|0))<<13)|0;c=((a=a+Math.imul(f,ft)|0)+(i>>>13)|0)+(Tt>>>26)|0,Tt&=67108863,n=Math.imul(B,U),i=(i=Math.imul(B,V))+Math.imul(N,U)|0,a=Math.imul(N,V),n=n+Math.imul(D,H)|0,i=(i=i+Math.imul(D,G)|0)+Math.imul(R,H)|0,a=a+Math.imul(R,G)|0,n=n+Math.imul(O,W)|0,i=(i=i+Math.imul(O,X)|0)+Math.imul(z,W)|0,a=a+Math.imul(z,X)|0,n=n+Math.imul(C,J)|0,i=(i=i+Math.imul(C,K)|0)+Math.imul(L,J)|0,a=a+Math.imul(L,K)|0,n=n+Math.imul(M,Q)|0,i=(i=i+Math.imul(M,tt)|0)+Math.imul(S,Q)|0,a=a+Math.imul(S,tt)|0,n=n+Math.imul(k,rt)|0,i=(i=i+Math.imul(k,nt)|0)+Math.imul(T,rt)|0,a=a+Math.imul(T,nt)|0,n=n+Math.imul(b,at)|0,i=(i=i+Math.imul(b,ot)|0)+Math.imul(_,at)|0,a=a+Math.imul(_,ot)|0,n=n+Math.imul(m,lt)|0,i=(i=i+Math.imul(m,ct)|0)+Math.imul(y,lt)|0,a=a+Math.imul(y,ct)|0,n=n+Math.imul(d,ht)|0,i=(i=i+Math.imul(d,ft)|0)+Math.imul(g,ht)|0,a=a+Math.imul(g,ft)|0;var At=(c+(n=n+Math.imul(h,dt)|0)|0)+((8191&(i=(i=i+Math.imul(h,gt)|0)+Math.imul(f,dt)|0))<<13)|0;c=((a=a+Math.imul(f,gt)|0)+(i>>>13)|0)+(At>>>26)|0,At&=67108863,n=Math.imul(B,H),i=(i=Math.imul(B,G))+Math.imul(N,H)|0,a=Math.imul(N,G),n=n+Math.imul(D,W)|0,i=(i=i+Math.imul(D,X)|0)+Math.imul(R,W)|0,a=a+Math.imul(R,X)|0,n=n+Math.imul(O,J)|0,i=(i=i+Math.imul(O,K)|0)+Math.imul(z,J)|0,a=a+Math.imul(z,K)|0,n=n+Math.imul(C,Q)|0,i=(i=i+Math.imul(C,tt)|0)+Math.imul(L,Q)|0,a=a+Math.imul(L,tt)|0,n=n+Math.imul(M,rt)|0,i=(i=i+Math.imul(M,nt)|0)+Math.imul(S,rt)|0,a=a+Math.imul(S,nt)|0,n=n+Math.imul(k,at)|0,i=(i=i+Math.imul(k,ot)|0)+Math.imul(T,at)|0,a=a+Math.imul(T,ot)|0,n=n+Math.imul(b,lt)|0,i=(i=i+Math.imul(b,ct)|0)+Math.imul(_,lt)|0,a=a+Math.imul(_,ct)|0,n=n+Math.imul(m,ht)|0,i=(i=i+Math.imul(m,ft)|0)+Math.imul(y,ht)|0,a=a+Math.imul(y,ft)|0;var Mt=(c+(n=n+Math.imul(d,dt)|0)|0)+((8191&(i=(i=i+Math.imul(d,gt)|0)+Math.imul(g,dt)|0))<<13)|0;c=((a=a+Math.imul(g,gt)|0)+(i>>>13)|0)+(Mt>>>26)|0,Mt&=67108863,n=Math.imul(B,W),i=(i=Math.imul(B,X))+Math.imul(N,W)|0,a=Math.imul(N,X),n=n+Math.imul(D,J)|0,i=(i=i+Math.imul(D,K)|0)+Math.imul(R,J)|0,a=a+Math.imul(R,K)|0,n=n+Math.imul(O,Q)|0,i=(i=i+Math.imul(O,tt)|0)+Math.imul(z,Q)|0,a=a+Math.imul(z,tt)|0,n=n+Math.imul(C,rt)|0,i=(i=i+Math.imul(C,nt)|0)+Math.imul(L,rt)|0,a=a+Math.imul(L,nt)|0,n=n+Math.imul(M,at)|0,i=(i=i+Math.imul(M,ot)|0)+Math.imul(S,at)|0,a=a+Math.imul(S,ot)|0,n=n+Math.imul(k,lt)|0,i=(i=i+Math.imul(k,ct)|0)+Math.imul(T,lt)|0,a=a+Math.imul(T,ct)|0,n=n+Math.imul(b,ht)|0,i=(i=i+Math.imul(b,ft)|0)+Math.imul(_,ht)|0,a=a+Math.imul(_,ft)|0;var St=(c+(n=n+Math.imul(m,dt)|0)|0)+((8191&(i=(i=i+Math.imul(m,gt)|0)+Math.imul(y,dt)|0))<<13)|0;c=((a=a+Math.imul(y,gt)|0)+(i>>>13)|0)+(St>>>26)|0,St&=67108863,n=Math.imul(B,J),i=(i=Math.imul(B,K))+Math.imul(N,J)|0,a=Math.imul(N,K),n=n+Math.imul(D,Q)|0,i=(i=i+Math.imul(D,tt)|0)+Math.imul(R,Q)|0,a=a+Math.imul(R,tt)|0,n=n+Math.imul(O,rt)|0,i=(i=i+Math.imul(O,nt)|0)+Math.imul(z,rt)|0,a=a+Math.imul(z,nt)|0,n=n+Math.imul(C,at)|0,i=(i=i+Math.imul(C,ot)|0)+Math.imul(L,at)|0,a=a+Math.imul(L,ot)|0,n=n+Math.imul(M,lt)|0,i=(i=i+Math.imul(M,ct)|0)+Math.imul(S,lt)|0,a=a+Math.imul(S,ct)|0,n=n+Math.imul(k,ht)|0,i=(i=i+Math.imul(k,ft)|0)+Math.imul(T,ht)|0,a=a+Math.imul(T,ft)|0;var Et=(c+(n=n+Math.imul(b,dt)|0)|0)+((8191&(i=(i=i+Math.imul(b,gt)|0)+Math.imul(_,dt)|0))<<13)|0;c=((a=a+Math.imul(_,gt)|0)+(i>>>13)|0)+(Et>>>26)|0,Et&=67108863,n=Math.imul(B,Q),i=(i=Math.imul(B,tt))+Math.imul(N,Q)|0,a=Math.imul(N,tt),n=n+Math.imul(D,rt)|0,i=(i=i+Math.imul(D,nt)|0)+Math.imul(R,rt)|0,a=a+Math.imul(R,nt)|0,n=n+Math.imul(O,at)|0,i=(i=i+Math.imul(O,ot)|0)+Math.imul(z,at)|0,a=a+Math.imul(z,ot)|0,n=n+Math.imul(C,lt)|0,i=(i=i+Math.imul(C,ct)|0)+Math.imul(L,lt)|0,a=a+Math.imul(L,ct)|0,n=n+Math.imul(M,ht)|0,i=(i=i+Math.imul(M,ft)|0)+Math.imul(S,ht)|0,a=a+Math.imul(S,ft)|0;var Ct=(c+(n=n+Math.imul(k,dt)|0)|0)+((8191&(i=(i=i+Math.imul(k,gt)|0)+Math.imul(T,dt)|0))<<13)|0;c=((a=a+Math.imul(T,gt)|0)+(i>>>13)|0)+(Ct>>>26)|0,Ct&=67108863,n=Math.imul(B,rt),i=(i=Math.imul(B,nt))+Math.imul(N,rt)|0,a=Math.imul(N,nt),n=n+Math.imul(D,at)|0,i=(i=i+Math.imul(D,ot)|0)+Math.imul(R,at)|0,a=a+Math.imul(R,ot)|0,n=n+Math.imul(O,lt)|0,i=(i=i+Math.imul(O,ct)|0)+Math.imul(z,lt)|0,a=a+Math.imul(z,ct)|0,n=n+Math.imul(C,ht)|0,i=(i=i+Math.imul(C,ft)|0)+Math.imul(L,ht)|0,a=a+Math.imul(L,ft)|0;var Lt=(c+(n=n+Math.imul(M,dt)|0)|0)+((8191&(i=(i=i+Math.imul(M,gt)|0)+Math.imul(S,dt)|0))<<13)|0;c=((a=a+Math.imul(S,gt)|0)+(i>>>13)|0)+(Lt>>>26)|0,Lt&=67108863,n=Math.imul(B,at),i=(i=Math.imul(B,ot))+Math.imul(N,at)|0,a=Math.imul(N,ot),n=n+Math.imul(D,lt)|0,i=(i=i+Math.imul(D,ct)|0)+Math.imul(R,lt)|0,a=a+Math.imul(R,ct)|0,n=n+Math.imul(O,ht)|0,i=(i=i+Math.imul(O,ft)|0)+Math.imul(z,ht)|0,a=a+Math.imul(z,ft)|0;var Pt=(c+(n=n+Math.imul(C,dt)|0)|0)+((8191&(i=(i=i+Math.imul(C,gt)|0)+Math.imul(L,dt)|0))<<13)|0;c=((a=a+Math.imul(L,gt)|0)+(i>>>13)|0)+(Pt>>>26)|0,Pt&=67108863,n=Math.imul(B,lt),i=(i=Math.imul(B,ct))+Math.imul(N,lt)|0,a=Math.imul(N,ct),n=n+Math.imul(D,ht)|0,i=(i=i+Math.imul(D,ft)|0)+Math.imul(R,ht)|0,a=a+Math.imul(R,ft)|0;var Ot=(c+(n=n+Math.imul(O,dt)|0)|0)+((8191&(i=(i=i+Math.imul(O,gt)|0)+Math.imul(z,dt)|0))<<13)|0;c=((a=a+Math.imul(z,gt)|0)+(i>>>13)|0)+(Ot>>>26)|0,Ot&=67108863,n=Math.imul(B,ht),i=(i=Math.imul(B,ft))+Math.imul(N,ht)|0,a=Math.imul(N,ft);var zt=(c+(n=n+Math.imul(D,dt)|0)|0)+((8191&(i=(i=i+Math.imul(D,gt)|0)+Math.imul(R,dt)|0))<<13)|0;c=((a=a+Math.imul(R,gt)|0)+(i>>>13)|0)+(zt>>>26)|0,zt&=67108863;var It=(c+(n=Math.imul(B,dt))|0)+((8191&(i=(i=Math.imul(B,gt))+Math.imul(N,dt)|0))<<13)|0;return c=((a=Math.imul(N,gt))+(i>>>13)|0)+(It>>>26)|0,It&=67108863,l[0]=vt,l[1]=mt,l[2]=yt,l[3]=xt,l[4]=bt,l[5]=_t,l[6]=wt,l[7]=kt,l[8]=Tt,l[9]=At,l[10]=Mt,l[11]=St,l[12]=Et,l[13]=Ct,l[14]=Lt,l[15]=Pt,l[16]=Ot,l[17]=zt,l[18]=It,0!==c&&(l[19]=c,r.length++),r};function d(t,e,r){return(new g).mulp(t,e,r)}function g(t,e){this.x=t,this.y=e}Math.imul||(p=f),a.prototype.mulTo=function(t,e){var r=this.length+t.length;return 10===this.length&&10===t.length?p(this,t,e):r<63?f(this,t,e):r<1024?function(t,e,r){r.negative=e.negative^t.negative,r.length=t.length+e.length;for(var n=0,i=0,a=0;a<r.length-1;a++){var o=i;i=0;for(var s=67108863&n,l=Math.min(a,e.length-1),c=Math.max(0,a-t.length+1);c<=l;c++){var u=a-c,h=(0|t.words[u])*(0|e.words[c]),f=67108863&h;s=67108863&(f=f+s|0),i+=(o=(o=o+(h/67108864|0)|0)+(f>>>26)|0)>>>26,o&=67108863}r.words[a]=s,n=o,o=i}return 0!==n?r.words[a]=n:r.length--,r.strip()}(this,t,e):d(this,t,e)},g.prototype.makeRBT=function(t){for(var e=new Array(t),r=a.prototype._countBits(t)-1,n=0;n<t;n++)e[n]=this.revBin(n,r,t);return e},g.prototype.revBin=function(t,e,r){if(0===t||t===r-1)return t;for(var n=0,i=0;i<e;i++)n|=(1&t)<<e-i-1,t>>=1;return n},g.prototype.permute=function(t,e,r,n,i,a){for(var o=0;o<a;o++)n[o]=e[t[o]],i[o]=r[t[o]]},g.prototype.transform=function(t,e,r,n,i,a){this.permute(a,t,e,r,n,i);for(var o=1;o<i;o<<=1)for(var s=o<<1,l=Math.cos(2*Math.PI/s),c=Math.sin(2*Math.PI/s),u=0;u<i;u+=s)for(var h=l,f=c,p=0;p<o;p++){var d=r[u+p],g=n[u+p],v=r[u+p+o],m=n[u+p+o],y=h*v-f*m;m=h*m+f*v,v=y,r[u+p]=d+v,n[u+p]=g+m,r[u+p+o]=d-v,n[u+p+o]=g-m,p!==s&&(y=l*h-c*f,f=l*f+c*h,h=y)}},g.prototype.guessLen13b=function(t,e){var r=1|Math.max(e,t),n=1&r,i=0;for(r=r/2|0;r;r>>>=1)i++;return 1<<i+1+n},g.prototype.conjugate=function(t,e,r){if(!(r<=1))for(var n=0;n<r/2;n++){var i=t[n];t[n]=t[r-n-1],t[r-n-1]=i,i=e[n],e[n]=-e[r-n-1],e[r-n-1]=-i}},g.prototype.normalize13b=function(t,e){for(var r=0,n=0;n<e/2;n++){var i=8192*Math.round(t[2*n+1]/e)+Math.round(t[2*n]/e)+r;t[n]=67108863&i,r=i<67108864?0:i/67108864|0}return t},g.prototype.convert13b=function(t,e,r,i){for(var a=0,o=0;o<e;o++)a+=0|t[o],r[2*o]=8191&a,a>>>=13,r[2*o+1]=8191&a,a>>>=13;for(o=2*e;o<i;++o)r[o]=0;n(0===a),n(0==(-8192&a))},g.prototype.stub=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=0;return e},g.prototype.mulp=function(t,e,r){var n=2*this.guessLen13b(t.length,e.length),i=this.makeRBT(n),a=this.stub(n),o=new Array(n),s=new Array(n),l=new Array(n),c=new Array(n),u=new Array(n),h=new Array(n),f=r.words;f.length=n,this.convert13b(t.words,t.length,o,n),this.convert13b(e.words,e.length,c,n),this.transform(o,a,s,l,n,i),this.transform(c,a,u,h,n,i);for(var p=0;p<n;p++){var d=s[p]*u[p]-l[p]*h[p];l[p]=s[p]*h[p]+l[p]*u[p],s[p]=d}return this.conjugate(s,l,n),this.transform(s,l,f,a,n,i),this.conjugate(f,a,n),this.normalize13b(f,n),r.negative=t.negative^e.negative,r.length=t.length+e.length,r.strip()},a.prototype.mul=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),this.mulTo(t,e)},a.prototype.mulf=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),d(this,t,e)},a.prototype.imul=function(t){return this.clone().mulTo(t,this)},a.prototype.imuln=function(t){n(\"number\"==typeof t),n(t<67108864);for(var e=0,r=0;r<this.length;r++){var i=(0|this.words[r])*t,a=(67108863&i)+(67108863&e);e>>=26,e+=i/67108864|0,e+=a>>>26,this.words[r]=67108863&a}return 0!==e&&(this.words[r]=e,this.length++),this},a.prototype.muln=function(t){return this.clone().imuln(t)},a.prototype.sqr=function(){return this.mul(this)},a.prototype.isqr=function(){return this.imul(this.clone())},a.prototype.pow=function(t){var e=function(t){for(var e=new Array(t.bitLength()),r=0;r<e.length;r++){var n=r/26|0,i=r%26;e[r]=(t.words[n]&1<<i)>>>i}return e}(t);if(0===e.length)return new a(1);for(var r=this,n=0;n<e.length&&0===e[n];n++,r=r.sqr());if(++n<e.length)for(var i=r.sqr();n<e.length;n++,i=i.sqr())0!==e[n]&&(r=r.mul(i));return r},a.prototype.iushln=function(t){n(\"number\"==typeof t&&t>=0);var e,r=t%26,i=(t-r)/26,a=67108863>>>26-r<<26-r;if(0!==r){var o=0;for(e=0;e<this.length;e++){var s=this.words[e]&a,l=(0|this.words[e])-s<<r;this.words[e]=l|o,o=s>>>26-r}o&&(this.words[e]=o,this.length++)}if(0!==i){for(e=this.length-1;e>=0;e--)this.words[e+i]=this.words[e];for(e=0;e<i;e++)this.words[e]=0;this.length+=i}return this.strip()},a.prototype.ishln=function(t){return n(0===this.negative),this.iushln(t)},a.prototype.iushrn=function(t,e,r){var i;n(\"number\"==typeof t&&t>=0),i=e?(e-e%26)/26:0;var a=t%26,o=Math.min((t-a)/26,this.length),s=67108863^67108863>>>a<<a,l=r;if(i-=o,i=Math.max(0,i),l){for(var c=0;c<o;c++)l.words[c]=this.words[c];l.length=o}if(0===o);else if(this.length>o)for(this.length-=o,c=0;c<this.length;c++)this.words[c]=this.words[c+o];else this.words[0]=0,this.length=1;var u=0;for(c=this.length-1;c>=0&&(0!==u||c>=i);c--){var h=0|this.words[c];this.words[c]=u<<26-a|h>>>a,u=h&s}return l&&0!==u&&(l.words[l.length++]=u),0===this.length&&(this.words[0]=0,this.length=1),this.strip()},a.prototype.ishrn=function(t,e,r){return n(0===this.negative),this.iushrn(t,e,r)},a.prototype.shln=function(t){return this.clone().ishln(t)},a.prototype.ushln=function(t){return this.clone().iushln(t)},a.prototype.shrn=function(t){return this.clone().ishrn(t)},a.prototype.ushrn=function(t){return this.clone().iushrn(t)},a.prototype.testn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26,i=1<<e;return!(this.length<=r)&&!!(this.words[r]&i)},a.prototype.imaskn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26;if(n(0===this.negative,\"imaskn works only with positive numbers\"),this.length<=r)return this;if(0!==e&&r++,this.length=Math.min(r,this.length),0!==e){var i=67108863^67108863>>>e<<e;this.words[this.length-1]&=i}return this.strip()},a.prototype.maskn=function(t){return this.clone().imaskn(t)},a.prototype.iaddn=function(t){return n(\"number\"==typeof t),n(t<67108864),t<0?this.isubn(-t):0!==this.negative?1===this.length&&(0|this.words[0])<t?(this.words[0]=t-(0|this.words[0]),this.negative=0,this):(this.negative=0,this.isubn(t),this.negative=1,this):this._iaddn(t)},a.prototype._iaddn=function(t){this.words[0]+=t;for(var e=0;e<this.length&&this.words[e]>=67108864;e++)this.words[e]-=67108864,e===this.length-1?this.words[e+1]=1:this.words[e+1]++;return this.length=Math.max(this.length,e+1),this},a.prototype.isubn=function(t){if(n(\"number\"==typeof t),n(t<67108864),t<0)return this.iaddn(-t);if(0!==this.negative)return this.negative=0,this.iaddn(t),this.negative=1,this;if(this.words[0]-=t,1===this.length&&this.words[0]<0)this.words[0]=-this.words[0],this.negative=1;else for(var e=0;e<this.length&&this.words[e]<0;e++)this.words[e]+=67108864,this.words[e+1]-=1;return this.strip()},a.prototype.addn=function(t){return this.clone().iaddn(t)},a.prototype.subn=function(t){return this.clone().isubn(t)},a.prototype.iabs=function(){return this.negative=0,this},a.prototype.abs=function(){return this.clone().iabs()},a.prototype._ishlnsubmul=function(t,e,r){var i,a,o=t.length+r;this._expand(o);var s=0;for(i=0;i<t.length;i++){a=(0|this.words[i+r])+s;var l=(0|t.words[i])*e;s=((a-=67108863&l)>>26)-(l/67108864|0),this.words[i+r]=67108863&a}for(;i<this.length-r;i++)s=(a=(0|this.words[i+r])+s)>>26,this.words[i+r]=67108863&a;if(0===s)return this.strip();for(n(-1===s),s=0,i=0;i<this.length;i++)s=(a=-(0|this.words[i])+s)>>26,this.words[i]=67108863&a;return this.negative=1,this.strip()},a.prototype._wordDiv=function(t,e){var r=(this.length,t.length),n=this.clone(),i=t,o=0|i.words[i.length-1];0!==(r=26-this._countBits(o))&&(i=i.ushln(r),n.iushln(r),o=0|i.words[i.length-1]);var s,l=n.length-i.length;if(\"mod\"!==e){(s=new a(null)).length=l+1,s.words=new Array(s.length);for(var c=0;c<s.length;c++)s.words[c]=0}var u=n.clone()._ishlnsubmul(i,1,l);0===u.negative&&(n=u,s&&(s.words[l]=1));for(var h=l-1;h>=0;h--){var f=67108864*(0|n.words[i.length+h])+(0|n.words[i.length+h-1]);for(f=Math.min(f/o|0,67108863),n._ishlnsubmul(i,f,h);0!==n.negative;)f--,n.negative=0,n._ishlnsubmul(i,1,h),n.isZero()||(n.negative^=1);s&&(s.words[h]=f)}return s&&s.strip(),n.strip(),\"div\"!==e&&0!==r&&n.iushrn(r),{div:s||null,mod:n}},a.prototype.divmod=function(t,e,r){return n(!t.isZero()),this.isZero()?{div:new a(0),mod:new a(0)}:0!==this.negative&&0===t.negative?(s=this.neg().divmod(t,e),\"mod\"!==e&&(i=s.div.neg()),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.iadd(t)),{div:i,mod:o}):0===this.negative&&0!==t.negative?(s=this.divmod(t.neg(),e),\"mod\"!==e&&(i=s.div.neg()),{div:i,mod:s.mod}):0!=(this.negative&t.negative)?(s=this.neg().divmod(t.neg(),e),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.isub(t)),{div:s.div,mod:o}):t.length>this.length||this.cmp(t)<0?{div:new a(0),mod:this}:1===t.length?\"div\"===e?{div:this.divn(t.words[0]),mod:null}:\"mod\"===e?{div:null,mod:new a(this.modn(t.words[0]))}:{div:this.divn(t.words[0]),mod:new a(this.modn(t.words[0]))}:this._wordDiv(t,e);var i,o,s},a.prototype.div=function(t){return this.divmod(t,\"div\",!1).div},a.prototype.mod=function(t){return this.divmod(t,\"mod\",!1).mod},a.prototype.umod=function(t){return this.divmod(t,\"mod\",!0).mod},a.prototype.divRound=function(t){var e=this.divmod(t);if(e.mod.isZero())return e.div;var r=0!==e.div.negative?e.mod.isub(t):e.mod,n=t.ushrn(1),i=t.andln(1),a=r.cmp(n);return a<0||1===i&&0===a?e.div:0!==e.div.negative?e.div.isubn(1):e.div.iaddn(1)},a.prototype.modn=function(t){n(t<=67108863);for(var e=(1<<26)%t,r=0,i=this.length-1;i>=0;i--)r=(e*r+(0|this.words[i]))%t;return r},a.prototype.idivn=function(t){n(t<=67108863);for(var e=0,r=this.length-1;r>=0;r--){var i=(0|this.words[r])+67108864*e;this.words[r]=i/t|0,e=i%t}return this.strip()},a.prototype.divn=function(t){return this.clone().idivn(t)},a.prototype.egcd=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i=new a(1),o=new a(0),s=new a(0),l=new a(1),c=0;e.isEven()&&r.isEven();)e.iushrn(1),r.iushrn(1),++c;for(var u=r.clone(),h=e.clone();!e.isZero();){for(var f=0,p=1;0==(e.words[0]&p)&&f<26;++f,p<<=1);if(f>0)for(e.iushrn(f);f-- >0;)(i.isOdd()||o.isOdd())&&(i.iadd(u),o.isub(h)),i.iushrn(1),o.iushrn(1);for(var d=0,g=1;0==(r.words[0]&g)&&d<26;++d,g<<=1);if(d>0)for(r.iushrn(d);d-- >0;)(s.isOdd()||l.isOdd())&&(s.iadd(u),l.isub(h)),s.iushrn(1),l.iushrn(1);e.cmp(r)>=0?(e.isub(r),i.isub(s),o.isub(l)):(r.isub(e),s.isub(i),l.isub(o))}return{a:s,b:l,gcd:r.iushln(c)}},a.prototype._invmp=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i,o=new a(1),s=new a(0),l=r.clone();e.cmpn(1)>0&&r.cmpn(1)>0;){for(var c=0,u=1;0==(e.words[0]&u)&&c<26;++c,u<<=1);if(c>0)for(e.iushrn(c);c-- >0;)o.isOdd()&&o.iadd(l),o.iushrn(1);for(var h=0,f=1;0==(r.words[0]&f)&&h<26;++h,f<<=1);if(h>0)for(r.iushrn(h);h-- >0;)s.isOdd()&&s.iadd(l),s.iushrn(1);e.cmp(r)>=0?(e.isub(r),o.isub(s)):(r.isub(e),s.isub(o))}return(i=0===e.cmpn(1)?o:s).cmpn(0)<0&&i.iadd(t),i},a.prototype.gcd=function(t){if(this.isZero())return t.abs();if(t.isZero())return this.abs();var e=this.clone(),r=t.clone();e.negative=0,r.negative=0;for(var n=0;e.isEven()&&r.isEven();n++)e.iushrn(1),r.iushrn(1);for(;;){for(;e.isEven();)e.iushrn(1);for(;r.isEven();)r.iushrn(1);var i=e.cmp(r);if(i<0){var a=e;e=r,r=a}else if(0===i||0===r.cmpn(1))break;e.isub(r)}return r.iushln(n)},a.prototype.invm=function(t){return this.egcd(t).a.umod(t)},a.prototype.isEven=function(){return 0==(1&this.words[0])},a.prototype.isOdd=function(){return 1==(1&this.words[0])},a.prototype.andln=function(t){return this.words[0]&t},a.prototype.bincn=function(t){n(\"number\"==typeof t);var e=t%26,r=(t-e)/26,i=1<<e;if(this.length<=r)return this._expand(r+1),this.words[r]|=i,this;for(var a=i,o=r;0!==a&&o<this.length;o++){var s=0|this.words[o];a=(s+=a)>>>26,s&=67108863,this.words[o]=s}return 0!==a&&(this.words[o]=a,this.length++),this},a.prototype.isZero=function(){return 1===this.length&&0===this.words[0]},a.prototype.cmpn=function(t){var e,r=t<0;if(0!==this.negative&&!r)return-1;if(0===this.negative&&r)return 1;if(this.strip(),this.length>1)e=1;else{r&&(t=-t),n(t<=67108863,\"Number is too big\");var i=0|this.words[0];e=i===t?0:i<t?-1:1}return 0!==this.negative?0|-e:e},a.prototype.cmp=function(t){if(0!==this.negative&&0===t.negative)return-1;if(0===this.negative&&0!==t.negative)return 1;var e=this.ucmp(t);return 0!==this.negative?0|-e:e},a.prototype.ucmp=function(t){if(this.length>t.length)return 1;if(this.length<t.length)return-1;for(var e=0,r=this.length-1;r>=0;r--){var n=0|this.words[r],i=0|t.words[r];if(n!==i){n<i?e=-1:n>i&&(e=1);break}}return e},a.prototype.gtn=function(t){return 1===this.cmpn(t)},a.prototype.gt=function(t){return 1===this.cmp(t)},a.prototype.gten=function(t){return this.cmpn(t)>=0},a.prototype.gte=function(t){return this.cmp(t)>=0},a.prototype.ltn=function(t){return-1===this.cmpn(t)},a.prototype.lt=function(t){return-1===this.cmp(t)},a.prototype.lten=function(t){return this.cmpn(t)<=0},a.prototype.lte=function(t){return this.cmp(t)<=0},a.prototype.eqn=function(t){return 0===this.cmpn(t)},a.prototype.eq=function(t){return 0===this.cmp(t)},a.red=function(t){return new w(t)},a.prototype.toRed=function(t){return n(!this.red,\"Already a number in reduction context\"),n(0===this.negative,\"red works only with positives\"),t.convertTo(this)._forceRed(t)},a.prototype.fromRed=function(){return n(this.red,\"fromRed works only with numbers in reduction context\"),this.red.convertFrom(this)},a.prototype._forceRed=function(t){return this.red=t,this},a.prototype.forceRed=function(t){return n(!this.red,\"Already a number in reduction context\"),this._forceRed(t)},a.prototype.redAdd=function(t){return n(this.red,\"redAdd works only with red numbers\"),this.red.add(this,t)},a.prototype.redIAdd=function(t){return n(this.red,\"redIAdd works only with red numbers\"),this.red.iadd(this,t)},a.prototype.redSub=function(t){return n(this.red,\"redSub works only with red numbers\"),this.red.sub(this,t)},a.prototype.redISub=function(t){return n(this.red,\"redISub works only with red numbers\"),this.red.isub(this,t)},a.prototype.redShl=function(t){return n(this.red,\"redShl works only with red numbers\"),this.red.shl(this,t)},a.prototype.redMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.mul(this,t)},a.prototype.redIMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.imul(this,t)},a.prototype.redSqr=function(){return n(this.red,\"redSqr works only with red numbers\"),this.red._verify1(this),this.red.sqr(this)},a.prototype.redISqr=function(){return n(this.red,\"redISqr works only with red numbers\"),this.red._verify1(this),this.red.isqr(this)},a.prototype.redSqrt=function(){return n(this.red,\"redSqrt works only with red numbers\"),this.red._verify1(this),this.red.sqrt(this)},a.prototype.redInvm=function(){return n(this.red,\"redInvm works only with red numbers\"),this.red._verify1(this),this.red.invm(this)},a.prototype.redNeg=function(){return n(this.red,\"redNeg works only with red numbers\"),this.red._verify1(this),this.red.neg(this)},a.prototype.redPow=function(t){return n(this.red&&!t.red,\"redPow(normalNum)\"),this.red._verify1(this),this.red.pow(this,t)};var v={k256:null,p224:null,p192:null,p25519:null};function m(t,e){this.name=t,this.p=new a(e,16),this.n=this.p.bitLength(),this.k=new a(1).iushln(this.n).isub(this.p),this.tmp=this._tmp()}function y(){m.call(this,\"k256\",\"ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffe fffffc2f\")}function x(){m.call(this,\"p224\",\"ffffffff ffffffff ffffffff ffffffff 00000000 00000000 00000001\")}function b(){m.call(this,\"p192\",\"ffffffff ffffffff ffffffff fffffffe ffffffff ffffffff\")}function _(){m.call(this,\"25519\",\"7fffffffffffffff ffffffffffffffff ffffffffffffffff ffffffffffffffed\")}function w(t){if(\"string\"==typeof t){var e=a._prime(t);this.m=e.p,this.prime=e}else n(t.gtn(1),\"modulus must be greater than 1\"),this.m=t,this.prime=null}function k(t){w.call(this,t),this.shift=this.m.bitLength(),this.shift%26!=0&&(this.shift+=26-this.shift%26),this.r=new a(1).iushln(this.shift),this.r2=this.imod(this.r.sqr()),this.rinv=this.r._invmp(this.m),this.minv=this.rinv.mul(this.r).isubn(1).div(this.m),this.minv=this.minv.umod(this.r),this.minv=this.r.sub(this.minv)}m.prototype._tmp=function(){var t=new a(null);return t.words=new Array(Math.ceil(this.n/13)),t},m.prototype.ireduce=function(t){var e,r=t;do{this.split(r,this.tmp),e=(r=(r=this.imulK(r)).iadd(this.tmp)).bitLength()}while(e>this.n);var n=e<this.n?-1:r.ucmp(this.p);return 0===n?(r.words[0]=0,r.length=1):n>0?r.isub(this.p):r.strip(),r},m.prototype.split=function(t,e){t.iushrn(this.n,0,e)},m.prototype.imulK=function(t){return t.imul(this.k)},i(y,m),y.prototype.split=function(t,e){for(var r=Math.min(t.length,9),n=0;n<r;n++)e.words[n]=t.words[n];if(e.length=r,t.length<=9)return t.words[0]=0,void(t.length=1);var i=t.words[9];for(e.words[e.length++]=4194303&i,n=10;n<t.length;n++){var a=0|t.words[n];t.words[n-10]=(4194303&a)<<4|i>>>22,i=a}i>>>=22,t.words[n-10]=i,0===i&&t.length>10?t.length-=10:t.length-=9},y.prototype.imulK=function(t){t.words[t.length]=0,t.words[t.length+1]=0,t.length+=2;for(var e=0,r=0;r<t.length;r++){var n=0|t.words[r];e+=977*n,t.words[r]=67108863&e,e=64*n+(e/67108864|0)}return 0===t.words[t.length-1]&&(t.length--,0===t.words[t.length-1]&&t.length--),t},i(x,m),i(b,m),i(_,m),_.prototype.imulK=function(t){for(var e=0,r=0;r<t.length;r++){var n=19*(0|t.words[r])+e,i=67108863&n;n>>>=26,t.words[r]=i,e=n}return 0!==e&&(t.words[t.length++]=e),t},a._prime=function(t){if(v[t])return v[t];var e;if(\"k256\"===t)e=new y;else if(\"p224\"===t)e=new x;else if(\"p192\"===t)e=new b;else{if(\"p25519\"!==t)throw new Error(\"Unknown prime \"+t);e=new _}return v[t]=e,e},w.prototype._verify1=function(t){n(0===t.negative,\"red works only with positives\"),n(t.red,\"red works only with red numbers\")},w.prototype._verify2=function(t,e){n(0==(t.negative|e.negative),\"red works only with positives\"),n(t.red&&t.red===e.red,\"red works only with red numbers\")},w.prototype.imod=function(t){return this.prime?this.prime.ireduce(t)._forceRed(this):t.umod(this.m)._forceRed(this)},w.prototype.neg=function(t){return t.isZero()?t.clone():this.m.sub(t)._forceRed(this)},w.prototype.add=function(t,e){this._verify2(t,e);var r=t.add(e);return r.cmp(this.m)>=0&&r.isub(this.m),r._forceRed(this)},w.prototype.iadd=function(t,e){this._verify2(t,e);var r=t.iadd(e);return r.cmp(this.m)>=0&&r.isub(this.m),r},w.prototype.sub=function(t,e){this._verify2(t,e);var r=t.sub(e);return r.cmpn(0)<0&&r.iadd(this.m),r._forceRed(this)},w.prototype.isub=function(t,e){this._verify2(t,e);var r=t.isub(e);return r.cmpn(0)<0&&r.iadd(this.m),r},w.prototype.shl=function(t,e){return this._verify1(t),this.imod(t.ushln(e))},w.prototype.imul=function(t,e){return this._verify2(t,e),this.imod(t.imul(e))},w.prototype.mul=function(t,e){return this._verify2(t,e),this.imod(t.mul(e))},w.prototype.isqr=function(t){return this.imul(t,t.clone())},w.prototype.sqr=function(t){return this.mul(t,t)},w.prototype.sqrt=function(t){if(t.isZero())return t.clone();var e=this.m.andln(3);if(n(e%2==1),3===e){var r=this.m.add(new a(1)).iushrn(2);return this.pow(t,r)}for(var i=this.m.subn(1),o=0;!i.isZero()&&0===i.andln(1);)o++,i.iushrn(1);n(!i.isZero());var s=new a(1).toRed(this),l=s.redNeg(),c=this.m.subn(1).iushrn(1),u=this.m.bitLength();for(u=new a(2*u*u).toRed(this);0!==this.pow(u,c).cmp(l);)u.redIAdd(l);for(var h=this.pow(u,i),f=this.pow(t,i.addn(1).iushrn(1)),p=this.pow(t,i),d=o;0!==p.cmp(s);){for(var g=p,v=0;0!==g.cmp(s);v++)g=g.redSqr();n(v<d);var m=this.pow(h,new a(1).iushln(d-v-1));f=f.redMul(m),h=m.redSqr(),p=p.redMul(h),d=v}return f},w.prototype.invm=function(t){var e=t._invmp(this.m);return 0!==e.negative?(e.negative=0,this.imod(e).redNeg()):this.imod(e)},w.prototype.pow=function(t,e){if(e.isZero())return new a(1).toRed(this);if(0===e.cmpn(1))return t.clone();var r=new Array(16);r[0]=new a(1).toRed(this),r[1]=t;for(var n=2;n<r.length;n++)r[n]=this.mul(r[n-1],t);var i=r[0],o=0,s=0,l=e.bitLength()%26;for(0===l&&(l=26),n=e.length-1;n>=0;n--){for(var c=e.words[n],u=l-1;u>=0;u--){var h=c>>u&1;i!==r[0]&&(i=this.sqr(i)),0!==h||0!==o?(o<<=1,o|=h,(4===++s||0===n&&0===u)&&(i=this.mul(i,r[o]),s=0,o=0)):s=0}l=26}return i},w.prototype.convertTo=function(t){var e=t.umod(this.m);return e===t?e.clone():e},w.prototype.convertFrom=function(t){var e=t.clone();return e.red=null,e},a.mont=function(t){return new k(t)},i(k,w),k.prototype.convertTo=function(t){return this.imod(t.ushln(this.shift))},k.prototype.convertFrom=function(t){var e=this.imod(t.mul(this.rinv));return e.red=null,e},k.prototype.imul=function(t,e){if(t.isZero()||e.isZero())return t.words[0]=0,t.length=1,t;var r=t.imul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),a=i;return i.cmp(this.m)>=0?a=i.isub(this.m):i.cmpn(0)<0&&(a=i.iadd(this.m)),a._forceRed(this)},k.prototype.mul=function(t,e){if(t.isZero()||e.isZero())return new a(0)._forceRed(this);var r=t.mul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),o=i;return i.cmp(this.m)>=0?o=i.isub(this.m):i.cmpn(0)<0&&(o=i.iadd(this.m)),o._forceRed(this)},k.prototype.invm=function(t){return this.imod(t._invmp(this.m).mul(this.r2))._forceRed(this)}}(\"undefined\"==typeof e||e,this)},{buffer:103}],95:[function(t,e,r){\"use strict\";e.exports=function(t){var e,r,n,i=t.length,a=0;for(e=0;e<i;++e)a+=t[e].length;var o=new Array(a),s=0;for(e=0;e<i;++e){var l=t[e],c=l.length;for(r=0;r<c;++r){var u=o[s++]=new Array(c-1),h=0;for(n=0;n<c;++n)n!==r&&(u[h++]=l[n]);if(1&r){var f=u[1];u[1]=u[0],u[0]=f}}}return o}},{}],96:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 1:return n=[],c(i=t,i,u,!0),n;case 2:return\"function\"==typeof e?c(t,t,e,!0):function(t,e){return n=[],c(t,e,u,!1),n}(t,e);case 3:return c(t,e,r,!1);default:throw new Error(\"box-intersect: Invalid arguments\")}var i};var n,i=t(\"typedarray-pool\"),a=t(\"./lib/sweep\"),o=t(\"./lib/intersect\");function s(t,e){for(var r=0;r<t;++r)if(!(e[r]<=e[r+t]))return!0;return!1}function l(t,e,r,n){for(var i=0,a=0,o=0,l=t.length;o<l;++o){var c=t[o];if(!s(e,c)){for(var u=0;u<2*e;++u)r[i++]=c[u];n[a++]=o}}return a}function c(t,e,r,n){var s=t.length,c=e.length;if(!(s<=0||c<=0)){var u=t[0].length>>>1;if(!(u<=0)){var h,f=i.mallocDouble(2*u*s),p=i.mallocInt32(s);if((s=l(t,u,f,p))>0){if(1===u&&n)a.init(s),h=a.sweepComplete(u,r,0,s,f,p,0,s,f,p);else{var d=i.mallocDouble(2*u*c),g=i.mallocInt32(c);(c=l(e,u,d,g))>0&&(a.init(s+c),h=1===u?a.sweepBipartite(u,r,0,s,f,p,0,c,d,g):o(u,r,n,s,f,p,c,d,g),i.free(d),i.free(g))}i.free(f),i.free(p)}return h}}}function u(t,e){n.push([t,e])}},{\"./lib/intersect\":98,\"./lib/sweep\":102,\"typedarray-pool\":545}],97:[function(t,e,r){\"use strict\";var n=\"d\",i=\"ax\",a=\"vv\",o=\"fp\",s=\"es\",l=\"rs\",c=\"re\",u=\"rb\",h=\"ri\",f=\"rp\",p=\"bs\",d=\"be\",g=\"bb\",v=\"bi\",m=\"bp\",y=\"rv\",x=\"Q\",b=[n,i,a,l,c,u,h,p,d,g,v];function _(t){var e=\"bruteForce\"+(t?\"Full\":\"Partial\"),r=[],_=b.slice();t||_.splice(3,0,o);var w=[\"function \"+e+\"(\"+_.join()+\"){\"];function k(e,o){var _=function(t,e,r){var o=\"bruteForce\"+(t?\"Red\":\"Blue\")+(e?\"Flip\":\"\")+(r?\"Full\":\"\"),_=[\"function \",o,\"(\",b.join(),\"){\",\"var \",s,\"=2*\",n,\";\"],w=\"for(var i=\"+l+\",\"+f+\"=\"+s+\"*\"+l+\";i<\"+c+\";++i,\"+f+\"+=\"+s+\"){var x0=\"+u+\"[\"+i+\"+\"+f+\"],x1=\"+u+\"[\"+i+\"+\"+f+\"+\"+n+\"],xi=\"+h+\"[i];\",k=\"for(var j=\"+p+\",\"+m+\"=\"+s+\"*\"+p+\";j<\"+d+\";++j,\"+m+\"+=\"+s+\"){var y0=\"+g+\"[\"+i+\"+\"+m+\"],\"+(r?\"y1=\"+g+\"[\"+i+\"+\"+m+\"+\"+n+\"],\":\"\")+\"yi=\"+v+\"[j];\";return t?_.push(w,x,\":\",k):_.push(k,x,\":\",w),r?_.push(\"if(y1<x0||x1<y0)continue;\"):e?_.push(\"if(y0<=x0||x1<y0)continue;\"):_.push(\"if(y0<x0||x1<y0)continue;\"),_.push(\"for(var k=\"+i+\"+1;k<\"+n+\";++k){var r0=\"+u+\"[k+\"+f+\"],r1=\"+u+\"[k+\"+n+\"+\"+f+\"],b0=\"+g+\"[k+\"+m+\"],b1=\"+g+\"[k+\"+n+\"+\"+m+\"];if(r1<b0||b1<r0)continue \"+x+\";}var \"+y+\"=\"+a+\"(\"),e?_.push(\"yi,xi\"):_.push(\"xi,yi\"),_.push(\");if(\"+y+\"!==void 0)return \"+y+\";}}}\"),{name:o,code:_.join(\"\")}}(e,o,t);r.push(_.code),w.push(\"return \"+_.name+\"(\"+b.join()+\");\")}w.push(\"if(\"+c+\"-\"+l+\">\"+d+\"-\"+p+\"){\"),t?(k(!0,!1),w.push(\"}else{\"),k(!1,!1)):(w.push(\"if(\"+o+\"){\"),k(!0,!0),w.push(\"}else{\"),k(!0,!1),w.push(\"}}else{if(\"+o+\"){\"),k(!1,!0),w.push(\"}else{\"),k(!1,!1),w.push(\"}\")),w.push(\"}}return \"+e);var T=r.join(\"\")+w.join(\"\");return new Function(T)()}r.partial=_(!1),r.full=_(!0)},{}],98:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,u,S,E,C,L){!function(t,e){var r=8*i.log2(e+1)*(t+1)|0,a=i.nextPow2(b*r);w.length<a&&(n.free(w),w=n.mallocInt32(a));var o=i.nextPow2(_*r);k<o&&(n.free(k),k=n.mallocDouble(o))}(t,a+E);var P,O=0,z=2*t;T(O++,0,0,a,0,E,r?16:0,-1/0,1/0),r||T(O++,0,0,E,0,a,1,-1/0,1/0);for(;O>0;){var I=(O-=1)*b,D=w[I],R=w[I+1],F=w[I+2],B=w[I+3],N=w[I+4],j=w[I+5],U=O*_,V=k[U],q=k[U+1],H=1&j,G=!!(16&j),Y=u,W=S,X=C,Z=L;if(H&&(Y=C,W=L,X=u,Z=S),!(2&j&&(F=v(t,D,R,F,Y,W,q),R>=F)||4&j&&(R=m(t,D,R,F,Y,W,V))>=F)){var J=F-R,K=N-B;if(G){if(t*J*(J+K)<p){if(void 0!==(P=l.scanComplete(t,D,e,R,F,Y,W,B,N,X,Z)))return P;continue}}else{if(t*Math.min(J,K)<h){if(void 0!==(P=o(t,D,e,H,R,F,Y,W,B,N,X,Z)))return P;continue}if(t*J*K<f){if(void 0!==(P=l.scanBipartite(t,D,e,H,R,F,Y,W,B,N,X,Z)))return P;continue}}var $=d(t,D,R,F,Y,W,V,q);if(R<$)if(t*($-R)<h){if(void 0!==(P=s(t,D+1,e,R,$,Y,W,B,N,X,Z)))return P}else if(D===t-2){if(void 0!==(P=H?l.sweepBipartite(t,e,B,N,X,Z,R,$,Y,W):l.sweepBipartite(t,e,R,$,Y,W,B,N,X,Z)))return P}else T(O++,D+1,R,$,B,N,H,-1/0,1/0),T(O++,D+1,B,N,R,$,1^H,-1/0,1/0);if($<F){var Q=c(t,D,B,N,X,Z),tt=X[z*Q+D],et=g(t,D,Q,N,X,Z,tt);if(et<N&&T(O++,D,$,F,et,N,(4|H)+(G?16:0),tt,q),B<Q&&T(O++,D,$,F,B,Q,(2|H)+(G?16:0),V,tt),Q+1===et){if(void 0!==(P=G?M(t,D,e,$,F,Y,W,Q,X,Z[Q]):A(t,D,e,H,$,F,Y,W,Q,X,Z[Q])))return P}else if(Q<et){var rt;if(G){if(rt=y(t,D,$,F,Y,W,tt),$<rt){var nt=g(t,D,$,rt,Y,W,tt);if(D===t-2){if($<nt&&void 0!==(P=l.sweepComplete(t,e,$,nt,Y,W,Q,et,X,Z)))return P;if(nt<rt&&void 0!==(P=l.sweepBipartite(t,e,nt,rt,Y,W,Q,et,X,Z)))return P}else $<nt&&T(O++,D+1,$,nt,Q,et,16,-1/0,1/0),nt<rt&&(T(O++,D+1,nt,rt,Q,et,0,-1/0,1/0),T(O++,D+1,Q,et,nt,rt,1,-1/0,1/0))}}else rt=H?x(t,D,$,F,Y,W,tt):y(t,D,$,F,Y,W,tt),$<rt&&(D===t-2?P=H?l.sweepBipartite(t,e,Q,et,X,Z,$,rt,Y,W):l.sweepBipartite(t,e,$,rt,Y,W,Q,et,X,Z):(T(O++,D+1,$,rt,Q,et,H,-1/0,1/0),T(O++,D+1,Q,et,$,rt,1^H,-1/0,1/0)))}}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./brute\"),o=a.partial,s=a.full,l=t(\"./sweep\"),c=t(\"./median\"),u=t(\"./partition\"),h=128,f=1<<22,p=1<<22,d=u(\"!(lo>=p0)&&!(p1>=hi)\",[\"p0\",\"p1\"]),g=u(\"lo===p0\",[\"p0\"]),v=u(\"lo<p0\",[\"p0\"]),m=u(\"hi<=p0\",[\"p0\"]),y=u(\"lo<=p0&&p0<=hi\",[\"p0\"]),x=u(\"lo<p0&&p0<=hi\",[\"p0\"]),b=6,_=2,w=n.mallocInt32(1024),k=n.mallocDouble(1024);function T(t,e,r,n,i,a,o,s,l){var c=b*t;w[c]=e,w[c+1]=r,w[c+2]=n,w[c+3]=i,w[c+4]=a,w[c+5]=o;var u=_*t;k[u]=s,k[u+1]=l}function A(t,e,r,n,i,a,o,s,l,c,u){var h=2*t,f=l*h,p=c[f+e];t:for(var d=i,g=i*h;d<a;++d,g+=h){var v=o[g+e],m=o[g+e+t];if(!(p<v||m<p)&&(!n||p!==v)){for(var y,x=s[d],b=e+1;b<t;++b){v=o[g+b],m=o[g+b+t];var _=c[f+b],w=c[f+b+t];if(m<_||w<v)continue t}if(void 0!==(y=n?r(u,x):r(x,u)))return y}}}function M(t,e,r,n,i,a,o,s,l,c){var u=2*t,h=s*u,f=l[h+e];t:for(var p=n,d=n*u;p<i;++p,d+=u){var g=o[p];if(g!==c){var v=a[d+e],m=a[d+e+t];if(!(f<v||m<f)){for(var y=e+1;y<t;++y){v=a[d+y],m=a[d+y+t];var x=l[h+y],b=l[h+y+t];if(m<x||b<v)continue t}var _=r(g,c);if(void 0!==_)return _}}}}},{\"./brute\":97,\"./median\":99,\"./partition\":100,\"./sweep\":102,\"bit-twiddle\":92,\"typedarray-pool\":545}],99:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,o,s,l){if(o<=r+1)return r;var c=r,u=o,h=o+r>>>1,f=2*t,p=h,d=s[f*h+e];for(;c<u;){if(u-c<i){a(t,e,c,u,s,l),d=s[f*h+e];break}var g=u-c,v=Math.random()*g+c|0,m=s[f*v+e],y=Math.random()*g+c|0,x=s[f*y+e],b=Math.random()*g+c|0,_=s[f*b+e];m<=x?_>=x?(p=y,d=x):m>=_?(p=v,d=m):(p=b,d=_):x>=_?(p=y,d=x):_>=m?(p=v,d=m):(p=b,d=_);for(var w=f*(u-1),k=f*p,T=0;T<f;++T,++w,++k){var A=s[w];s[w]=s[k],s[k]=A}var M=l[u-1];l[u-1]=l[p],l[p]=M,p=n(t,e,c,u-1,s,l,d);for(var w=f*(u-1),k=f*p,T=0;T<f;++T,++w,++k){var A=s[w];s[w]=s[k],s[k]=A}var M=l[u-1];if(l[u-1]=l[p],l[p]=M,h<p){for(u=p-1;c<u&&s[f*(u-1)+e]===d;)u-=1;u+=1}else{if(!(p<h))break;for(c=p+1;c<u&&s[f*c+e]===d;)c+=1}}return n(t,e,r,h,s,l,s[f*h+e])};var n=t(\"./partition\")(\"lo<p0\",[\"p0\"]),i=8;function a(t,e,r,n,i,a){for(var o=2*t,s=o*(r+1)+e,l=r+1;l<n;++l,s+=o)for(var c=i[s],u=l,h=o*(l-1);u>r&&i[h+e]>c;--u,h-=o){for(var f=h,p=h+o,d=0;d<o;++d,++f,++p){var g=i[f];i[f]=i[p],i[p]=g}var v=a[u];a[u]=a[u-1],a[u-1]=v}}},{\"./partition\":100}],100:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=\"abcdef\".split(\"\").concat(e),i=[];t.indexOf(\"lo\")>=0&&i.push(\"lo=e[k+n]\");t.indexOf(\"hi\")>=0&&i.push(\"hi=e[k+o]\");return r.push(n.replace(\"_\",i.join()).replace(\"$\",t)),Function.apply(void 0,r)};var n=\"for(var j=2*a,k=j*c,l=k,m=c,n=b,o=a+b,p=c;d>p;++p,k+=j){var _;if($)if(m===p)m+=1,l+=j;else{for(var s=0;j>s;++s){var t=e[k+s];e[k+s]=e[l],e[l++]=t}var u=f[p];f[p]=f[m],f[m++]=u}}return m\"},{}],101:[function(t,e,r){\"use strict\";e.exports=function(t,e){e<=4*n?i(0,e-1,t):function t(e,r,h){var f=(r-e+1)/6|0,p=e+f,d=r-f,g=e+r>>1,v=g-f,m=g+f,y=p,x=v,b=g,_=m,w=d,k=e+1,T=r-1,A=0;c(y,x,h)&&(A=y,y=x,x=A);c(_,w,h)&&(A=_,_=w,w=A);c(y,b,h)&&(A=y,y=b,b=A);c(x,b,h)&&(A=x,x=b,b=A);c(y,_,h)&&(A=y,y=_,_=A);c(b,_,h)&&(A=b,b=_,_=A);c(x,w,h)&&(A=x,x=w,w=A);c(x,b,h)&&(A=x,x=b,b=A);c(_,w,h)&&(A=_,_=w,w=A);var M=h[2*x];var S=h[2*x+1];var E=h[2*_];var C=h[2*_+1];var L=2*y;var P=2*b;var O=2*w;var z=2*p;var I=2*g;var D=2*d;for(var R=0;R<2;++R){var F=h[L+R],B=h[P+R],N=h[O+R];h[z+R]=F,h[I+R]=B,h[D+R]=N}o(v,e,h);o(m,r,h);for(var j=k;j<=T;++j)if(u(j,M,S,h))j!==k&&a(j,k,h),++k;else if(!u(j,E,C,h))for(;;){if(u(T,E,C,h)){u(T,M,S,h)?(s(j,k,T,h),++k,--T):(a(j,T,h),--T);break}if(--T<j)break}l(e,k-1,M,S,h);l(r,T+1,E,C,h);k-2-e<=n?i(e,k-2,h):t(e,k-2,h);r-(T+2)<=n?i(T+2,r,h):t(T+2,r,h);T-k<=n?i(k,T,h):t(k,T,h)}(0,e-1,t)};var n=32;function i(t,e,r){for(var n=2*(t+1),i=t+1;i<=e;++i){for(var a=r[n++],o=r[n++],s=i,l=n-2;s-- >t;){var c=r[l-2],u=r[l-1];if(c<a)break;if(c===a&&u<o)break;r[l]=c,r[l+1]=u,l-=2}r[l]=a,r[l+1]=o}}function a(t,e,r){e*=2;var n=r[t*=2],i=r[t+1];r[t]=r[e],r[t+1]=r[e+1],r[e]=n,r[e+1]=i}function o(t,e,r){e*=2,r[t*=2]=r[e],r[t+1]=r[e+1]}function s(t,e,r,n){e*=2,r*=2;var i=n[t*=2],a=n[t+1];n[t]=n[e],n[t+1]=n[e+1],n[e]=n[r],n[e+1]=n[r+1],n[r]=i,n[r+1]=a}function l(t,e,r,n,i){e*=2,i[t*=2]=i[e],i[e]=r,i[t+1]=i[e+1],i[e+1]=n}function c(t,e,r){e*=2;var n=r[t*=2],i=r[e];return!(n<i)&&(n!==i||r[t+1]>r[e+1])}function u(t,e,r,n){var i=n[t*=2];return i<e||i===e&&n[t+1]<r}},{}],102:[function(t,e,r){\"use strict\";e.exports={init:function(t){var e=i.nextPow2(t);s.length<e&&(n.free(s),s=n.mallocInt32(e));l.length<e&&(n.free(l),l=n.mallocInt32(e));c.length<e&&(n.free(c),c=n.mallocInt32(e));u.length<e&&(n.free(u),u=n.mallocInt32(e));h.length<e&&(n.free(h),h=n.mallocInt32(e));f.length<e&&(n.free(f),f=n.mallocInt32(e));var r=8*e;p.length<r&&(n.free(p),p=n.mallocDouble(r))},sweepBipartite:function(t,e,r,n,i,h,f,v,m,y){for(var x=0,b=2*t,_=t-1,w=b-1,k=r;k<n;++k){var T=h[k],A=b*k;p[x++]=i[A+_],p[x++]=-(T+1),p[x++]=i[A+w],p[x++]=T}for(var k=f;k<v;++k){var T=y[k]+o,M=b*k;p[x++]=m[M+_],p[x++]=-T,p[x++]=m[M+w],p[x++]=T}var S=x>>>1;a(p,S);for(var E=0,C=0,k=0;k<S;++k){var L=0|p[2*k+1];if(L>=o)d(c,u,C--,L=L-o|0);else if(L>=0)d(s,l,E--,L);else if(L<=-o){L=-L-o|0;for(var P=0;P<E;++P){var O=e(s[P],L);if(void 0!==O)return O}g(c,u,C++,L)}else{L=-L-1|0;for(var P=0;P<C;++P){var O=e(L,c[P]);if(void 0!==O)return O}g(s,l,E++,L)}}},sweepComplete:function(t,e,r,n,i,o,v,m,y,x){for(var b=0,_=2*t,w=t-1,k=_-1,T=r;T<n;++T){var A=o[T]+1<<1,M=_*T;p[b++]=i[M+w],p[b++]=-A,p[b++]=i[M+k],p[b++]=A}for(var T=v;T<m;++T){var A=x[T]+1<<1,S=_*T;p[b++]=y[S+w],p[b++]=1|-A,p[b++]=y[S+k],p[b++]=1|A}var E=b>>>1;a(p,E);for(var C=0,L=0,P=0,T=0;T<E;++T){var O=0|p[2*T+1],z=1&O;if(T<E-1&&O>>1==p[2*T+3]>>1&&(z=2,T+=1),O<0){for(var I=-(O>>1)-1,D=0;D<P;++D){var R=e(h[D],I);if(void 0!==R)return R}if(0!==z)for(var D=0;D<C;++D){var R=e(s[D],I);if(void 0!==R)return R}if(1!==z)for(var D=0;D<L;++D){var R=e(c[D],I);if(void 0!==R)return R}0===z?g(s,l,C++,I):1===z?g(c,u,L++,I):2===z&&g(h,f,P++,I)}else{var I=(O>>1)-1;0===z?d(s,l,C--,I):1===z?d(c,u,L--,I):2===z&&d(h,f,P--,I)}}},scanBipartite:function(t,e,r,n,i,c,u,h,f,v,m,y){var x=0,b=2*t,_=e,w=e+t,k=1,T=1;n?T=o:k=o;for(var A=i;A<c;++A){var M=A+k,S=b*A;p[x++]=u[S+_],p[x++]=-M,p[x++]=u[S+w],p[x++]=M}for(var A=f;A<v;++A){var M=A+T,E=b*A;p[x++]=m[E+_],p[x++]=-M}var C=x>>>1;a(p,C);for(var L=0,A=0;A<C;++A){var P=0|p[2*A+1];if(P<0){var M=-P,O=!1;if(M>=o?(O=!n,M-=o):(O=!!n,M-=1),O)g(s,l,L++,M);else{var z=y[M],I=b*M,D=m[I+e+1],R=m[I+e+1+t];t:for(var F=0;F<L;++F){var B=s[F],N=b*B;if(!(R<u[N+e+1]||u[N+e+1+t]<D)){for(var j=e+2;j<t;++j)if(m[I+j+t]<u[N+j]||u[N+j+t]<m[I+j])continue t;var U,V=h[B];if(void 0!==(U=n?r(z,V):r(V,z)))return U}}}}else d(s,l,L--,P-k)}},scanComplete:function(t,e,r,n,i,l,c,u,h,f,d){for(var g=0,v=2*t,m=e,y=e+t,x=n;x<i;++x){var b=x+o,_=v*x;p[g++]=l[_+m],p[g++]=-b,p[g++]=l[_+y],p[g++]=b}for(var x=u;x<h;++x){var b=x+1,w=v*x;p[g++]=f[w+m],p[g++]=-b}var k=g>>>1;a(p,k);for(var T=0,x=0;x<k;++x){var A=0|p[2*x+1];if(A<0){var b=-A;if(b>=o)s[T++]=b-o;else{var M=d[b-=1],S=v*b,E=f[S+e+1],C=f[S+e+1+t];t:for(var L=0;L<T;++L){var P=s[L],O=c[P];if(O===M)break;var z=v*P;if(!(C<l[z+e+1]||l[z+e+1+t]<E)){for(var I=e+2;I<t;++I)if(f[S+I+t]<l[z+I]||l[z+I+t]<f[S+I])continue t;var D=r(O,M);if(void 0!==D)return D}}}}else{for(var b=A-o,L=T-1;L>=0;--L)if(s[L]===b){for(var I=L+1;I<T;++I)s[I-1]=s[I];break}--T}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./sort\"),o=1<<28,s=n.mallocInt32(1024),l=n.mallocInt32(1024),c=n.mallocInt32(1024),u=n.mallocInt32(1024),h=n.mallocInt32(1024),f=n.mallocInt32(1024),p=n.mallocDouble(8192);function d(t,e,r,n){var i=e[n],a=t[r-1];t[i]=a,e[a]=i}function g(t,e,r,n){t[r]=n,e[n]=r}},{\"./sort\":101,\"bit-twiddle\":92,\"typedarray-pool\":545}],103:[function(t,e,r){},{}],104:[function(t,e,r){var n=Object.create||function(t){var e=function(){};return e.prototype=t,new e},i=Object.keys||function(t){var e=[];for(var r in t)Object.prototype.hasOwnProperty.call(t,r)&&e.push(r);return r},a=Function.prototype.bind||function(t){var e=this;return function(){return e.apply(t,arguments)}};function o(){this._events&&Object.prototype.hasOwnProperty.call(this,\"_events\")||(this._events=n(null),this._eventsCount=0),this._maxListeners=this._maxListeners||void 0}e.exports=o,o.EventEmitter=o,o.prototype._events=void 0,o.prototype._maxListeners=void 0;var s,l=10;try{var c={};Object.defineProperty&&Object.defineProperty(c,\"x\",{value:0}),s=0===c.x}catch(t){s=!1}function u(t){return void 0===t._maxListeners?o.defaultMaxListeners:t._maxListeners}function h(t,e,r,i){var a,o,s;if(\"function\"!=typeof r)throw new TypeError('\"listener\" argument must be a function');if((o=t._events)?(o.newListener&&(t.emit(\"newListener\",e,r.listener?r.listener:r),o=t._events),s=o[e]):(o=t._events=n(null),t._eventsCount=0),s){if(\"function\"==typeof s?s=o[e]=i?[r,s]:[s,r]:i?s.unshift(r):s.push(r),!s.warned&&(a=u(t))&&a>0&&s.length>a){s.warned=!0;var l=new Error(\"Possible EventEmitter memory leak detected. \"+s.length+' \"'+String(e)+'\" listeners added. Use emitter.setMaxListeners() to increase limit.');l.name=\"MaxListenersExceededWarning\",l.emitter=t,l.type=e,l.count=s.length,\"object\"==typeof console&&console.warn&&console.warn(\"%s: %s\",l.name,l.message)}}else s=o[e]=r,++t._eventsCount;return t}function f(){if(!this.fired)switch(this.target.removeListener(this.type,this.wrapFn),this.fired=!0,arguments.length){case 0:return this.listener.call(this.target);case 1:return this.listener.call(this.target,arguments[0]);case 2:return this.listener.call(this.target,arguments[0],arguments[1]);case 3:return this.listener.call(this.target,arguments[0],arguments[1],arguments[2]);default:for(var t=new Array(arguments.length),e=0;e<t.length;++e)t[e]=arguments[e];this.listener.apply(this.target,t)}}function p(t,e,r){var n={fired:!1,wrapFn:void 0,target:t,type:e,listener:r},i=a.call(f,n);return i.listener=r,n.wrapFn=i,i}function d(t,e,r){var n=t._events;if(!n)return[];var i=n[e];return i?\"function\"==typeof i?r?[i.listener||i]:[i]:r?function(t){for(var e=new Array(t.length),r=0;r<e.length;++r)e[r]=t[r].listener||t[r];return e}(i):v(i,i.length):[]}function g(t){var e=this._events;if(e){var r=e[t];if(\"function\"==typeof r)return 1;if(r)return r.length}return 0}function v(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t[n];return r}s?Object.defineProperty(o,\"defaultMaxListeners\",{enumerable:!0,get:function(){return l},set:function(t){if(\"number\"!=typeof t||t<0||t!=t)throw new TypeError('\"defaultMaxListeners\" must be a positive number');l=t}}):o.defaultMaxListeners=l,o.prototype.setMaxListeners=function(t){if(\"number\"!=typeof t||t<0||isNaN(t))throw new TypeError('\"n\" argument must be a positive number');return this._maxListeners=t,this},o.prototype.getMaxListeners=function(){return u(this)},o.prototype.emit=function(t){var e,r,n,i,a,o,s=\"error\"===t;if(o=this._events)s=s&&null==o.error;else if(!s)return!1;if(s){if(arguments.length>1&&(e=arguments[1]),e instanceof Error)throw e;var l=new Error('Unhandled \"error\" event. ('+e+\")\");throw l.context=e,l}if(!(r=o[t]))return!1;var c=\"function\"==typeof r;switch(n=arguments.length){case 1:!function(t,e,r){if(e)t.call(r);else for(var n=t.length,i=v(t,n),a=0;a<n;++a)i[a].call(r)}(r,c,this);break;case 2:!function(t,e,r,n){if(e)t.call(r,n);else for(var i=t.length,a=v(t,i),o=0;o<i;++o)a[o].call(r,n)}(r,c,this,arguments[1]);break;case 3:!function(t,e,r,n,i){if(e)t.call(r,n,i);else for(var a=t.length,o=v(t,a),s=0;s<a;++s)o[s].call(r,n,i)}(r,c,this,arguments[1],arguments[2]);break;case 4:!function(t,e,r,n,i,a){if(e)t.call(r,n,i,a);else for(var o=t.length,s=v(t,o),l=0;l<o;++l)s[l].call(r,n,i,a)}(r,c,this,arguments[1],arguments[2],arguments[3]);break;default:for(i=new Array(n-1),a=1;a<n;a++)i[a-1]=arguments[a];!function(t,e,r,n){if(e)t.apply(r,n);else for(var i=t.length,a=v(t,i),o=0;o<i;++o)a[o].apply(r,n)}(r,c,this,i)}return!0},o.prototype.addListener=function(t,e){return h(this,t,e,!1)},o.prototype.on=o.prototype.addListener,o.prototype.prependListener=function(t,e){return h(this,t,e,!0)},o.prototype.once=function(t,e){if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');return this.on(t,p(this,t,e)),this},o.prototype.prependOnceListener=function(t,e){if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');return this.prependListener(t,p(this,t,e)),this},o.prototype.removeListener=function(t,e){var r,i,a,o,s;if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');if(!(i=this._events))return this;if(!(r=i[t]))return this;if(r===e||r.listener===e)0==--this._eventsCount?this._events=n(null):(delete i[t],i.removeListener&&this.emit(\"removeListener\",t,r.listener||e));else if(\"function\"!=typeof r){for(a=-1,o=r.length-1;o>=0;o--)if(r[o]===e||r[o].listener===e){s=r[o].listener,a=o;break}if(a<0)return this;0===a?r.shift():function(t,e){for(var r=e,n=r+1,i=t.length;n<i;r+=1,n+=1)t[r]=t[n];t.pop()}(r,a),1===r.length&&(i[t]=r[0]),i.removeListener&&this.emit(\"removeListener\",t,s||e)}return this},o.prototype.removeAllListeners=function(t){var e,r,a;if(!(r=this._events))return this;if(!r.removeListener)return 0===arguments.length?(this._events=n(null),this._eventsCount=0):r[t]&&(0==--this._eventsCount?this._events=n(null):delete r[t]),this;if(0===arguments.length){var o,s=i(r);for(a=0;a<s.length;++a)\"removeListener\"!==(o=s[a])&&this.removeAllListeners(o);return this.removeAllListeners(\"removeListener\"),this._events=n(null),this._eventsCount=0,this}if(\"function\"==typeof(e=r[t]))this.removeListener(t,e);else if(e)for(a=e.length-1;a>=0;a--)this.removeListener(t,e[a]);return this},o.prototype.listeners=function(t){return d(this,t,!0)},o.prototype.rawListeners=function(t){return d(this,t,!1)},o.listenerCount=function(t,e){return\"function\"==typeof t.listenerCount?t.listenerCount(e):g.call(t,e)},o.prototype.listenerCount=g,o.prototype.eventNames=function(){return this._eventsCount>0?Reflect.ownKeys(this._events):[]}},{}],105:[function(t,e,r){(function(e){\"use strict\";var n=t(\"base64-js\"),i=t(\"ieee754\");r.Buffer=e,r.SlowBuffer=function(t){+t!=t&&(t=0);return e.alloc(+t)},r.INSPECT_MAX_BYTES=50;var a=2147483647;function o(t){if(t>a)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"');var r=new Uint8Array(t);return r.__proto__=e.prototype,r}function e(t,e,r){if(\"number\"==typeof t){if(\"string\"==typeof e)throw new TypeError('The \"string\" argument must be of type string. Received type number');return c(t)}return s(t,e,r)}function s(t,r,n){if(\"string\"==typeof t)return function(t,r){\"string\"==typeof r&&\"\"!==r||(r=\"utf8\");if(!e.isEncoding(r))throw new TypeError(\"Unknown encoding: \"+r);var n=0|f(t,r),i=o(n),a=i.write(t,r);a!==n&&(i=i.slice(0,a));return i}(t,r);if(ArrayBuffer.isView(t))return u(t);if(null==t)throw TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t);if(N(t,ArrayBuffer)||t&&N(t.buffer,ArrayBuffer))return function(t,r,n){if(r<0||t.byteLength<r)throw new RangeError('\"offset\" is outside of buffer bounds');if(t.byteLength<r+(n||0))throw new RangeError('\"length\" is outside of buffer bounds');var i;i=void 0===r&&void 0===n?new Uint8Array(t):void 0===n?new Uint8Array(t,r):new Uint8Array(t,r,n);return i.__proto__=e.prototype,i}(t,r,n);if(\"number\"==typeof t)throw new TypeError('The \"value\" argument must not be of type number. Received type number');var i=t.valueOf&&t.valueOf();if(null!=i&&i!==t)return e.from(i,r,n);var a=function(t){if(e.isBuffer(t)){var r=0|h(t.length),n=o(r);return 0===n.length?n:(t.copy(n,0,0,r),n)}if(void 0!==t.length)return\"number\"!=typeof t.length||j(t.length)?o(0):u(t);if(\"Buffer\"===t.type&&Array.isArray(t.data))return u(t.data)}(t);if(a)return a;if(\"undefined\"!=typeof Symbol&&null!=Symbol.toPrimitive&&\"function\"==typeof t[Symbol.toPrimitive])return e.from(t[Symbol.toPrimitive](\"string\"),r,n);throw new TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t)}function l(t){if(\"number\"!=typeof t)throw new TypeError('\"size\" argument must be of type number');if(t<0)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"')}function c(t){return l(t),o(t<0?0:0|h(t))}function u(t){for(var e=t.length<0?0:0|h(t.length),r=o(e),n=0;n<e;n+=1)r[n]=255&t[n];return r}function h(t){if(t>=a)throw new RangeError(\"Attempt to allocate Buffer larger than maximum size: 0x\"+a.toString(16)+\" bytes\");return 0|t}function f(t,r){if(e.isBuffer(t))return t.length;if(ArrayBuffer.isView(t)||N(t,ArrayBuffer))return t.byteLength;if(\"string\"!=typeof t)throw new TypeError('The \"string\" argument must be one of type string, Buffer, or ArrayBuffer. Received type '+typeof t);var n=t.length,i=arguments.length>2&&!0===arguments[2];if(!i&&0===n)return 0;for(var a=!1;;)switch(r){case\"ascii\":case\"latin1\":case\"binary\":return n;case\"utf8\":case\"utf-8\":return R(t).length;case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return 2*n;case\"hex\":return n>>>1;case\"base64\":return F(t).length;default:if(a)return i?-1:R(t).length;r=(\"\"+r).toLowerCase(),a=!0}}function p(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function d(t,r,n,i,a){if(0===t.length)return-1;if(\"string\"==typeof n?(i=n,n=0):n>2147483647?n=2147483647:n<-2147483648&&(n=-2147483648),j(n=+n)&&(n=a?0:t.length-1),n<0&&(n=t.length+n),n>=t.length){if(a)return-1;n=t.length-1}else if(n<0){if(!a)return-1;n=0}if(\"string\"==typeof r&&(r=e.from(r,i)),e.isBuffer(r))return 0===r.length?-1:g(t,r,n,i,a);if(\"number\"==typeof r)return r&=255,\"function\"==typeof Uint8Array.prototype.indexOf?a?Uint8Array.prototype.indexOf.call(t,r,n):Uint8Array.prototype.lastIndexOf.call(t,r,n):g(t,[r],n,i,a);throw new TypeError(\"val must be string, number or Buffer\")}function g(t,e,r,n,i){var a,o=1,s=t.length,l=e.length;if(void 0!==n&&(\"ucs2\"===(n=String(n).toLowerCase())||\"ucs-2\"===n||\"utf16le\"===n||\"utf-16le\"===n)){if(t.length<2||e.length<2)return-1;o=2,s/=2,l/=2,r/=2}function c(t,e){return 1===o?t[e]:t.readUInt16BE(e*o)}if(i){var u=-1;for(a=r;a<s;a++)if(c(t,a)===c(e,-1===u?0:a-u)){if(-1===u&&(u=a),a-u+1===l)return u*o}else-1!==u&&(a-=a-u),u=-1}else for(r+l>s&&(r=s-l),a=r;a>=0;a--){for(var h=!0,f=0;f<l;f++)if(c(t,a+f)!==c(e,f)){h=!1;break}if(h)return a}return-1}function v(t,e,r,n){r=Number(r)||0;var i=t.length-r;n?(n=Number(n))>i&&(n=i):n=i;var a=e.length;n>a/2&&(n=a/2);for(var o=0;o<n;++o){var s=parseInt(e.substr(2*o,2),16);if(j(s))return o;t[r+o]=s}return o}function m(t,e,r,n){return B(R(e,t.length-r),t,r,n)}function y(t,e,r,n){return B(function(t){for(var e=[],r=0;r<t.length;++r)e.push(255&t.charCodeAt(r));return e}(e),t,r,n)}function x(t,e,r,n){return y(t,e,r,n)}function b(t,e,r,n){return B(F(e),t,r,n)}function _(t,e,r,n){return B(function(t,e){for(var r,n,i,a=[],o=0;o<t.length&&!((e-=2)<0);++o)r=t.charCodeAt(o),n=r>>8,i=r%256,a.push(i),a.push(n);return a}(e,t.length-r),t,r,n)}function w(t,e,r){return 0===e&&r===t.length?n.fromByteArray(t):n.fromByteArray(t.slice(e,r))}function k(t,e,r){r=Math.min(t.length,r);for(var n=[],i=e;i<r;){var a,o,s,l,c=t[i],u=null,h=c>239?4:c>223?3:c>191?2:1;if(i+h<=r)switch(h){case 1:c<128&&(u=c);break;case 2:128==(192&(a=t[i+1]))&&(l=(31&c)<<6|63&a)>127&&(u=l);break;case 3:a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&(l=(15&c)<<12|(63&a)<<6|63&o)>2047&&(l<55296||l>57343)&&(u=l);break;case 4:a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&(l=(15&c)<<18|(63&a)<<12|(63&o)<<6|63&s)>65535&&l<1114112&&(u=l)}null===u?(u=65533,h=1):u>65535&&(u-=65536,n.push(u>>>10&1023|55296),u=56320|1023&u),n.push(u),i+=h}return function(t){var e=t.length;if(e<=T)return String.fromCharCode.apply(String,t);var r=\"\",n=0;for(;n<e;)r+=String.fromCharCode.apply(String,t.slice(n,n+=T));return r}(n)}r.kMaxLength=a,e.TYPED_ARRAY_SUPPORT=function(){try{var t=new Uint8Array(1);return t.__proto__={__proto__:Uint8Array.prototype,foo:function(){return 42}},42===t.foo()}catch(t){return!1}}(),e.TYPED_ARRAY_SUPPORT||\"undefined\"==typeof console||\"function\"!=typeof console.error||console.error(\"This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support.\"),Object.defineProperty(e.prototype,\"parent\",{enumerable:!0,get:function(){if(e.isBuffer(this))return this.buffer}}),Object.defineProperty(e.prototype,\"offset\",{enumerable:!0,get:function(){if(e.isBuffer(this))return this.byteOffset}}),\"undefined\"!=typeof Symbol&&null!=Symbol.species&&e[Symbol.species]===e&&Object.defineProperty(e,Symbol.species,{value:null,configurable:!0,enumerable:!1,writable:!1}),e.poolSize=8192,e.from=function(t,e,r){return s(t,e,r)},e.prototype.__proto__=Uint8Array.prototype,e.__proto__=Uint8Array,e.alloc=function(t,e,r){return function(t,e,r){return l(t),t<=0?o(t):void 0!==e?\"string\"==typeof r?o(t).fill(e,r):o(t).fill(e):o(t)}(t,e,r)},e.allocUnsafe=function(t){return c(t)},e.allocUnsafeSlow=function(t){return c(t)},e.isBuffer=function(t){return null!=t&&!0===t._isBuffer&&t!==e.prototype},e.compare=function(t,r){if(N(t,Uint8Array)&&(t=e.from(t,t.offset,t.byteLength)),N(r,Uint8Array)&&(r=e.from(r,r.offset,r.byteLength)),!e.isBuffer(t)||!e.isBuffer(r))throw new TypeError('The \"buf1\", \"buf2\" arguments must be one of type Buffer or Uint8Array');if(t===r)return 0;for(var n=t.length,i=r.length,a=0,o=Math.min(n,i);a<o;++a)if(t[a]!==r[a]){n=t[a],i=r[a];break}return n<i?-1:i<n?1:0},e.isEncoding=function(t){switch(String(t).toLowerCase()){case\"hex\":case\"utf8\":case\"utf-8\":case\"ascii\":case\"latin1\":case\"binary\":case\"base64\":case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return!0;default:return!1}},e.concat=function(t,r){if(!Array.isArray(t))throw new TypeError('\"list\" argument must be an Array of Buffers');if(0===t.length)return e.alloc(0);var n;if(void 0===r)for(r=0,n=0;n<t.length;++n)r+=t[n].length;var i=e.allocUnsafe(r),a=0;for(n=0;n<t.length;++n){var o=t[n];if(N(o,Uint8Array)&&(o=e.from(o)),!e.isBuffer(o))throw new TypeError('\"list\" argument must be an Array of Buffers');o.copy(i,a),a+=o.length}return i},e.byteLength=f,e.prototype._isBuffer=!0,e.prototype.swap16=function(){var t=this.length;if(t%2!=0)throw new RangeError(\"Buffer size must be a multiple of 16-bits\");for(var e=0;e<t;e+=2)p(this,e,e+1);return this},e.prototype.swap32=function(){var t=this.length;if(t%4!=0)throw new RangeError(\"Buffer size must be a multiple of 32-bits\");for(var e=0;e<t;e+=4)p(this,e,e+3),p(this,e+1,e+2);return this},e.prototype.swap64=function(){var t=this.length;if(t%8!=0)throw new RangeError(\"Buffer size must be a multiple of 64-bits\");for(var e=0;e<t;e+=8)p(this,e,e+7),p(this,e+1,e+6),p(this,e+2,e+5),p(this,e+3,e+4);return this},e.prototype.toString=function(){var t=this.length;return 0===t?\"\":0===arguments.length?k(this,0,t):function(t,e,r){var n=!1;if((void 0===e||e<0)&&(e=0),e>this.length)return\"\";if((void 0===r||r>this.length)&&(r=this.length),r<=0)return\"\";if((r>>>=0)<=(e>>>=0))return\"\";for(t||(t=\"utf8\");;)switch(t){case\"hex\":return S(this,e,r);case\"utf8\":case\"utf-8\":return k(this,e,r);case\"ascii\":return A(this,e,r);case\"latin1\":case\"binary\":return M(this,e,r);case\"base64\":return w(this,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return E(this,e,r);default:if(n)throw new TypeError(\"Unknown encoding: \"+t);t=(t+\"\").toLowerCase(),n=!0}}.apply(this,arguments)},e.prototype.toLocaleString=e.prototype.toString,e.prototype.equals=function(t){if(!e.isBuffer(t))throw new TypeError(\"Argument must be a Buffer\");return this===t||0===e.compare(this,t)},e.prototype.inspect=function(){var t=\"\",e=r.INSPECT_MAX_BYTES;return t=this.toString(\"hex\",0,e).replace(/(.{2})/g,\"$1 \").trim(),this.length>e&&(t+=\" ... \"),\"<Buffer \"+t+\">\"},e.prototype.compare=function(t,r,n,i,a){if(N(t,Uint8Array)&&(t=e.from(t,t.offset,t.byteLength)),!e.isBuffer(t))throw new TypeError('The \"target\" argument must be one of type Buffer or Uint8Array. Received type '+typeof t);if(void 0===r&&(r=0),void 0===n&&(n=t?t.length:0),void 0===i&&(i=0),void 0===a&&(a=this.length),r<0||n>t.length||i<0||a>this.length)throw new RangeError(\"out of range index\");if(i>=a&&r>=n)return 0;if(i>=a)return-1;if(r>=n)return 1;if(this===t)return 0;for(var o=(a>>>=0)-(i>>>=0),s=(n>>>=0)-(r>>>=0),l=Math.min(o,s),c=this.slice(i,a),u=t.slice(r,n),h=0;h<l;++h)if(c[h]!==u[h]){o=c[h],s=u[h];break}return o<s?-1:s<o?1:0},e.prototype.includes=function(t,e,r){return-1!==this.indexOf(t,e,r)},e.prototype.indexOf=function(t,e,r){return d(this,t,e,r,!0)},e.prototype.lastIndexOf=function(t,e,r){return d(this,t,e,r,!1)},e.prototype.write=function(t,e,r,n){if(void 0===e)n=\"utf8\",r=this.length,e=0;else if(void 0===r&&\"string\"==typeof e)n=e,r=this.length,e=0;else{if(!isFinite(e))throw new Error(\"Buffer.write(string, encoding, offset[, length]) is no longer supported\");e>>>=0,isFinite(r)?(r>>>=0,void 0===n&&(n=\"utf8\")):(n=r,r=void 0)}var i=this.length-e;if((void 0===r||r>i)&&(r=i),t.length>0&&(r<0||e<0)||e>this.length)throw new RangeError(\"Attempt to write outside buffer bounds\");n||(n=\"utf8\");for(var a=!1;;)switch(n){case\"hex\":return v(this,t,e,r);case\"utf8\":case\"utf-8\":return m(this,t,e,r);case\"ascii\":return y(this,t,e,r);case\"latin1\":case\"binary\":return x(this,t,e,r);case\"base64\":return b(this,t,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return _(this,t,e,r);default:if(a)throw new TypeError(\"Unknown encoding: \"+n);n=(\"\"+n).toLowerCase(),a=!0}},e.prototype.toJSON=function(){return{type:\"Buffer\",data:Array.prototype.slice.call(this._arr||this,0)}};var T=4096;function A(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(127&t[i]);return n}function M(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(t[i]);return n}function S(t,e,r){var n=t.length;(!e||e<0)&&(e=0),(!r||r<0||r>n)&&(r=n);for(var i=\"\",a=e;a<r;++a)i+=D(t[a]);return i}function E(t,e,r){for(var n=t.slice(e,r),i=\"\",a=0;a<n.length;a+=2)i+=String.fromCharCode(n[a]+256*n[a+1]);return i}function C(t,e,r){if(t%1!=0||t<0)throw new RangeError(\"offset is not uint\");if(t+e>r)throw new RangeError(\"Trying to access beyond buffer length\")}function L(t,r,n,i,a,o){if(!e.isBuffer(t))throw new TypeError('\"buffer\" argument must be a Buffer instance');if(r>a||r<o)throw new RangeError('\"value\" argument is out of bounds');if(n+i>t.length)throw new RangeError(\"Index out of range\")}function P(t,e,r,n,i,a){if(r+n>t.length)throw new RangeError(\"Index out of range\");if(r<0)throw new RangeError(\"Index out of range\")}function O(t,e,r,n,a){return e=+e,r>>>=0,a||P(t,0,r,4),i.write(t,e,r,n,23,4),r+4}function z(t,e,r,n,a){return e=+e,r>>>=0,a||P(t,0,r,8),i.write(t,e,r,n,52,8),r+8}e.prototype.slice=function(t,r){var n=this.length;(t=~~t)<0?(t+=n)<0&&(t=0):t>n&&(t=n),(r=void 0===r?n:~~r)<0?(r+=n)<0&&(r=0):r>n&&(r=n),r<t&&(r=t);var i=this.subarray(t,r);return i.__proto__=e.prototype,i},e.prototype.readUIntLE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n},e.prototype.readUIntBE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t+--e],i=1;e>0&&(i*=256);)n+=this[t+--e]*i;return n},e.prototype.readUInt8=function(t,e){return t>>>=0,e||C(t,1,this.length),this[t]},e.prototype.readUInt16LE=function(t,e){return t>>>=0,e||C(t,2,this.length),this[t]|this[t+1]<<8},e.prototype.readUInt16BE=function(t,e){return t>>>=0,e||C(t,2,this.length),this[t]<<8|this[t+1]},e.prototype.readUInt32LE=function(t,e){return t>>>=0,e||C(t,4,this.length),(this[t]|this[t+1]<<8|this[t+2]<<16)+16777216*this[t+3]},e.prototype.readUInt32BE=function(t,e){return t>>>=0,e||C(t,4,this.length),16777216*this[t]+(this[t+1]<<16|this[t+2]<<8|this[t+3])},e.prototype.readIntLE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n>=(i*=128)&&(n-=Math.pow(2,8*e)),n},e.prototype.readIntBE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=e,i=1,a=this[t+--n];n>0&&(i*=256);)a+=this[t+--n]*i;return a>=(i*=128)&&(a-=Math.pow(2,8*e)),a},e.prototype.readInt8=function(t,e){return t>>>=0,e||C(t,1,this.length),128&this[t]?-1*(255-this[t]+1):this[t]},e.prototype.readInt16LE=function(t,e){t>>>=0,e||C(t,2,this.length);var r=this[t]|this[t+1]<<8;return 32768&r?4294901760|r:r},e.prototype.readInt16BE=function(t,e){t>>>=0,e||C(t,2,this.length);var r=this[t+1]|this[t]<<8;return 32768&r?4294901760|r:r},e.prototype.readInt32LE=function(t,e){return t>>>=0,e||C(t,4,this.length),this[t]|this[t+1]<<8|this[t+2]<<16|this[t+3]<<24},e.prototype.readInt32BE=function(t,e){return t>>>=0,e||C(t,4,this.length),this[t]<<24|this[t+1]<<16|this[t+2]<<8|this[t+3]},e.prototype.readFloatLE=function(t,e){return t>>>=0,e||C(t,4,this.length),i.read(this,t,!0,23,4)},e.prototype.readFloatBE=function(t,e){return t>>>=0,e||C(t,4,this.length),i.read(this,t,!1,23,4)},e.prototype.readDoubleLE=function(t,e){return t>>>=0,e||C(t,8,this.length),i.read(this,t,!0,52,8)},e.prototype.readDoubleBE=function(t,e){return t>>>=0,e||C(t,8,this.length),i.read(this,t,!1,52,8)},e.prototype.writeUIntLE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||L(this,t,e,r,Math.pow(2,8*r)-1,0);var i=1,a=0;for(this[e]=255&t;++a<r&&(i*=256);)this[e+a]=t/i&255;return e+r},e.prototype.writeUIntBE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||L(this,t,e,r,Math.pow(2,8*r)-1,0);var i=r-1,a=1;for(this[e+i]=255&t;--i>=0&&(a*=256);)this[e+i]=t/a&255;return e+r},e.prototype.writeUInt8=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,1,255,0),this[e]=255&t,e+1},e.prototype.writeUInt16LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,65535,0),this[e]=255&t,this[e+1]=t>>>8,e+2},e.prototype.writeUInt16BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,65535,0),this[e]=t>>>8,this[e+1]=255&t,e+2},e.prototype.writeUInt32LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,4294967295,0),this[e+3]=t>>>24,this[e+2]=t>>>16,this[e+1]=t>>>8,this[e]=255&t,e+4},e.prototype.writeUInt32BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,4294967295,0),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},e.prototype.writeIntLE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);L(this,t,e,r,i-1,-i)}var a=0,o=1,s=0;for(this[e]=255&t;++a<r&&(o*=256);)t<0&&0===s&&0!==this[e+a-1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},e.prototype.writeIntBE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);L(this,t,e,r,i-1,-i)}var a=r-1,o=1,s=0;for(this[e+a]=255&t;--a>=0&&(o*=256);)t<0&&0===s&&0!==this[e+a+1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},e.prototype.writeInt8=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,1,127,-128),t<0&&(t=255+t+1),this[e]=255&t,e+1},e.prototype.writeInt16LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,32767,-32768),this[e]=255&t,this[e+1]=t>>>8,e+2},e.prototype.writeInt16BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,32767,-32768),this[e]=t>>>8,this[e+1]=255&t,e+2},e.prototype.writeInt32LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,2147483647,-2147483648),this[e]=255&t,this[e+1]=t>>>8,this[e+2]=t>>>16,this[e+3]=t>>>24,e+4},e.prototype.writeInt32BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,2147483647,-2147483648),t<0&&(t=4294967295+t+1),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},e.prototype.writeFloatLE=function(t,e,r){return O(this,t,e,!0,r)},e.prototype.writeFloatBE=function(t,e,r){return O(this,t,e,!1,r)},e.prototype.writeDoubleLE=function(t,e,r){return z(this,t,e,!0,r)},e.prototype.writeDoubleBE=function(t,e,r){return z(this,t,e,!1,r)},e.prototype.copy=function(t,r,n,i){if(!e.isBuffer(t))throw new TypeError(\"argument should be a Buffer\");if(n||(n=0),i||0===i||(i=this.length),r>=t.length&&(r=t.length),r||(r=0),i>0&&i<n&&(i=n),i===n)return 0;if(0===t.length||0===this.length)return 0;if(r<0)throw new RangeError(\"targetStart out of bounds\");if(n<0||n>=this.length)throw new RangeError(\"Index out of range\");if(i<0)throw new RangeError(\"sourceEnd out of bounds\");i>this.length&&(i=this.length),t.length-r<i-n&&(i=t.length-r+n);var a=i-n;if(this===t&&\"function\"==typeof Uint8Array.prototype.copyWithin)this.copyWithin(r,n,i);else if(this===t&&n<r&&r<i)for(var o=a-1;o>=0;--o)t[o+r]=this[o+n];else Uint8Array.prototype.set.call(t,this.subarray(n,i),r);return a},e.prototype.fill=function(t,r,n,i){if(\"string\"==typeof t){if(\"string\"==typeof r?(i=r,r=0,n=this.length):\"string\"==typeof n&&(i=n,n=this.length),void 0!==i&&\"string\"!=typeof i)throw new TypeError(\"encoding must be a string\");if(\"string\"==typeof i&&!e.isEncoding(i))throw new TypeError(\"Unknown encoding: \"+i);if(1===t.length){var a=t.charCodeAt(0);(\"utf8\"===i&&a<128||\"latin1\"===i)&&(t=a)}}else\"number\"==typeof t&&(t&=255);if(r<0||this.length<r||this.length<n)throw new RangeError(\"Out of range index\");if(n<=r)return this;var o;if(r>>>=0,n=void 0===n?this.length:n>>>0,t||(t=0),\"number\"==typeof t)for(o=r;o<n;++o)this[o]=t;else{var s=e.isBuffer(t)?t:e.from(t,i),l=s.length;if(0===l)throw new TypeError('The value \"'+t+'\" is invalid for argument \"value\"');for(o=0;o<n-r;++o)this[o+r]=s[o%l]}return this};var I=/[^+\\/0-9A-Za-z-_]/g;function D(t){return t<16?\"0\"+t.toString(16):t.toString(16)}function R(t,e){var r;e=e||1/0;for(var n=t.length,i=null,a=[],o=0;o<n;++o){if((r=t.charCodeAt(o))>55295&&r<57344){if(!i){if(r>56319){(e-=3)>-1&&a.push(239,191,189);continue}if(o+1===n){(e-=3)>-1&&a.push(239,191,189);continue}i=r;continue}if(r<56320){(e-=3)>-1&&a.push(239,191,189),i=r;continue}r=65536+(i-55296<<10|r-56320)}else i&&(e-=3)>-1&&a.push(239,191,189);if(i=null,r<128){if((e-=1)<0)break;a.push(r)}else if(r<2048){if((e-=2)<0)break;a.push(r>>6|192,63&r|128)}else if(r<65536){if((e-=3)<0)break;a.push(r>>12|224,r>>6&63|128,63&r|128)}else{if(!(r<1114112))throw new Error(\"Invalid code point\");if((e-=4)<0)break;a.push(r>>18|240,r>>12&63|128,r>>6&63|128,63&r|128)}}return a}function F(t){return n.toByteArray(function(t){if((t=(t=t.split(\"=\")[0]).trim().replace(I,\"\")).length<2)return\"\";for(;t.length%4!=0;)t+=\"=\";return t}(t))}function B(t,e,r,n){for(var i=0;i<n&&!(i+r>=e.length||i>=t.length);++i)e[i+r]=t[i];return i}function N(t,e){return t instanceof e||null!=t&&null!=t.constructor&&null!=t.constructor.name&&t.constructor.name===e.name}function j(t){return t!=t}}).call(this,t(\"buffer\").Buffer)},{\"base64-js\":74,buffer:105,ieee754:412}],106:[function(t,e,r){\"use strict\";var n=t(\"./lib/monotone\"),i=t(\"./lib/triangulation\"),a=t(\"./lib/delaunay\"),o=t(\"./lib/filter\");function s(t){return[Math.min(t[0],t[1]),Math.max(t[0],t[1])]}function l(t,e){return t[0]-e[0]||t[1]-e[1]}function c(t,e,r){return e in t?t[e]:r}e.exports=function(t,e,r){Array.isArray(e)?(r=r||{},e=e||[]):(r=e||{},e=[]);var u=!!c(r,\"delaunay\",!0),h=!!c(r,\"interior\",!0),f=!!c(r,\"exterior\",!0),p=!!c(r,\"infinity\",!1);if(!h&&!f||0===t.length)return[];var d=n(t,e);if(u||h!==f||p){for(var g=i(t.length,function(t){return t.map(s).sort(l)}(e)),v=0;v<d.length;++v){var m=d[v];g.addTriangle(m[0],m[1],m[2])}return u&&a(t,g),f?h?p?o(g,0,p):g.cells():o(g,1,p):o(g,-1)}return d}},{\"./lib/delaunay\":107,\"./lib/filter\":108,\"./lib/monotone\":109,\"./lib/triangulation\":110}],107:[function(t,e,r){\"use strict\";var n=t(\"robust-in-sphere\")[4];t(\"binary-search-bounds\");function i(t,e,r,i,a,o){var s=e.opposite(i,a);if(!(s<0)){if(a<i){var l=i;i=a,a=l,l=o,o=s,s=l}e.isConstraint(i,a)||n(t[i],t[a],t[o],t[s])<0&&r.push(i,a)}}e.exports=function(t,e){for(var r=[],a=t.length,o=e.stars,s=0;s<a;++s)for(var l=o[s],c=1;c<l.length;c+=2){var u=l[c];if(!(u<s)&&!e.isConstraint(s,u)){for(var h=l[c-1],f=-1,p=1;p<l.length;p+=2)if(l[p-1]===u){f=l[p];break}f<0||n(t[s],t[u],t[h],t[f])<0&&r.push(s,u)}}for(;r.length>0;){for(var u=r.pop(),s=r.pop(),h=-1,f=-1,l=o[s],d=1;d<l.length;d+=2){var g=l[d-1],v=l[d];g===u?f=v:v===u&&(h=g)}h<0||f<0||(n(t[s],t[u],t[h],t[f])>=0||(e.flip(s,u),i(t,e,r,h,s,f),i(t,e,r,s,f,h),i(t,e,r,f,u,h),i(t,e,r,u,h,f)))}}},{\"binary-search-bounds\":111,\"robust-in-sphere\":508}],108:[function(t,e,r){\"use strict\";var n,i=t(\"binary-search-bounds\");function a(t,e,r,n,i,a,o){this.cells=t,this.neighbor=e,this.flags=n,this.constraint=r,this.active=i,this.next=a,this.boundary=o}function o(t,e){return t[0]-e[0]||t[1]-e[1]||t[2]-e[2]}e.exports=function(t,e,r){var n=function(t,e){for(var r=t.cells(),n=r.length,i=0;i<n;++i){var s=r[i],l=s[0],c=s[1],u=s[2];c<u?c<l&&(s[0]=c,s[1]=u,s[2]=l):u<l&&(s[0]=u,s[1]=l,s[2]=c)}r.sort(o);for(var h=new Array(n),i=0;i<h.length;++i)h[i]=0;var f=[],p=[],d=new Array(3*n),g=new Array(3*n),v=null;e&&(v=[]);for(var m=new a(r,d,g,h,f,p,v),i=0;i<n;++i)for(var s=r[i],y=0;y<3;++y){var l=s[y],c=s[(y+1)%3],x=d[3*i+y]=m.locate(c,l,t.opposite(c,l)),b=g[3*i+y]=t.isConstraint(l,c);x<0&&(b?p.push(i):(f.push(i),h[i]=1),e&&v.push([c,l,-1]))}return m}(t,r);if(0===e)return r?n.cells.concat(n.boundary):n.cells;var i=1,s=n.active,l=n.next,c=n.flags,u=n.cells,h=n.constraint,f=n.neighbor;for(;s.length>0||l.length>0;){for(;s.length>0;){var p=s.pop();if(c[p]!==-i){c[p]=i;u[p];for(var d=0;d<3;++d){var g=f[3*p+d];g>=0&&0===c[g]&&(h[3*p+d]?l.push(g):(s.push(g),c[g]=i))}}}var v=l;l=s,s=v,l.length=0,i=-i}var m=function(t,e,r){for(var n=0,i=0;i<t.length;++i)e[i]===r&&(t[n++]=t[i]);return t.length=n,t}(u,c,e);if(r)return m.concat(n.boundary);return m},a.prototype.locate=(n=[0,0,0],function(t,e,r){var a=t,s=e,l=r;return e<r?e<t&&(a=e,s=r,l=t):r<t&&(a=r,s=t,l=e),a<0?-1:(n[0]=a,n[1]=s,n[2]=l,i.eq(this.cells,n,o))})},{\"binary-search-bounds\":111}],109:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"robust-orientation\")[3],a=0,o=1,s=2;function l(t,e,r,n,i){this.a=t,this.b=e,this.idx=r,this.lowerIds=n,this.upperIds=i}function c(t,e,r,n){this.a=t,this.b=e,this.type=r,this.idx=n}function u(t,e){var r=t.a[0]-e.a[0]||t.a[1]-e.a[1]||t.type-e.type;return r||(t.type!==a&&(r=i(t.a,t.b,e.b))?r:t.idx-e.idx)}function h(t,e){return i(t.a,t.b,e)}function f(t,e,r,a,o){for(var s=n.lt(e,a,h),l=n.gt(e,a,h),c=s;c<l;++c){for(var u=e[c],f=u.lowerIds,p=f.length;p>1&&i(r[f[p-2]],r[f[p-1]],a)>0;)t.push([f[p-1],f[p-2],o]),p-=1;f.length=p,f.push(o);var d=u.upperIds;for(p=d.length;p>1&&i(r[d[p-2]],r[d[p-1]],a)<0;)t.push([d[p-2],d[p-1],o]),p-=1;d.length=p,d.push(o)}}function p(t,e){var r;return(r=t.a[0]<e.a[0]?i(t.a,t.b,e.a):i(e.b,e.a,t.a))?r:(r=e.b[0]<t.b[0]?i(t.a,t.b,e.b):i(e.b,e.a,t.b))||t.idx-e.idx}function d(t,e,r){var i=n.le(t,r,p),a=t[i],o=a.upperIds,s=o[o.length-1];a.upperIds=[s],t.splice(i+1,0,new l(r.a,r.b,r.idx,[s],o))}function g(t,e,r){var i=r.a;r.a=r.b,r.b=i;var a=n.eq(t,r,p),o=t[a];t[a-1].upperIds=o.upperIds,t.splice(a,1)}e.exports=function(t,e){for(var r=t.length,n=e.length,i=[],h=0;h<r;++h)i.push(new c(t[h],null,a,h));for(var h=0;h<n;++h){var p=e[h],v=t[p[0]],m=t[p[1]];v[0]<m[0]?i.push(new c(v,m,s,h),new c(m,v,o,h)):v[0]>m[0]&&i.push(new c(m,v,s,h),new c(v,m,o,h))}i.sort(u);for(var y=i[0].a[0]-(1+Math.abs(i[0].a[0]))*Math.pow(2,-52),x=[new l([y,1],[y,0],-1,[],[],[],[])],b=[],h=0,_=i.length;h<_;++h){var w=i[h],k=w.type;k===a?f(b,x,t,w.a,w.idx):k===s?d(x,t,w):g(x,t,w)}return b}},{\"binary-search-bounds\":111,\"robust-orientation\":510}],110:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\");function i(t,e){this.stars=t,this.edges=e}e.exports=function(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=[];return new i(r,e)};var a=i.prototype;function o(t,e,r){for(var n=1,i=t.length;n<i;n+=2)if(t[n-1]===e&&t[n]===r)return t[n-1]=t[i-2],t[n]=t[i-1],void(t.length=i-2)}a.isConstraint=function(){var t=[0,0];function e(t,e){return t[0]-e[0]||t[1]-e[1]}return function(r,i){return t[0]=Math.min(r,i),t[1]=Math.max(r,i),n.eq(this.edges,t,e)>=0}}(),a.removeTriangle=function(t,e,r){var n=this.stars;o(n[t],e,r),o(n[e],r,t),o(n[r],t,e)},a.addTriangle=function(t,e,r){var n=this.stars;n[t].push(e,r),n[e].push(r,t),n[r].push(t,e)},a.opposite=function(t,e){for(var r=this.stars[e],n=1,i=r.length;n<i;n+=2)if(r[n]===t)return r[n-1];return-1},a.flip=function(t,e){var r=this.opposite(t,e),n=this.opposite(e,t);this.removeTriangle(t,e,r),this.removeTriangle(e,t,n),this.addTriangle(t,n,r),this.addTriangle(e,r,n)},a.edges=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2)e.push([i[a],i[a+1]]);return e},a.cells=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2){var s=i[a],l=i[a+1];r<Math.min(s,l)&&e.push([r,s,l])}return e}},{\"binary-search-bounds\":111}],111:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",i?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a[m]\"];return i?e.indexOf(\"c\")<0?a.push(\";if(x===y){return m}else if(x<=y){\"):a.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):a.push(\";if(\",e,\"){i=m;\"),r?a.push(\"l=m+1}else{h=m-1}\"):a.push(\"h=m-1}else{l=m+1}\"),a.push(\"}\"),i?a.push(\"return -1};\"):a.push(\"return i};\"),a.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(typeof(c)==='function'){return P(a,(l===void 0)?0:l|0,(h===void 0)?a.length-1:h|0,y,c)}else{return A(a,(c===void 0)?0:c|0,(l===void 0)?a.length-1:l|0,y)}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],112:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1,r=1;r<t.length;++r)for(var n=0;n<r;++n)if(t[r]<t[n])e=-e;else if(t[n]===t[r])return 0;return e}},{}],113:[function(t,e,r){\"use strict\";var n=t(\"dup\"),i=t(\"robust-linear-solve\");function a(t,e){for(var r=0,n=t.length,i=0;i<n;++i)r+=t[i]*e[i];return r}function o(t){var e=t.length;if(0===e)return[];t[0].length;var r=n([t.length+1,t.length+1],1),o=n([t.length+1],1);r[e][e]=0;for(var s=0;s<e;++s){for(var l=0;l<=s;++l)r[l][s]=r[s][l]=2*a(t[s],t[l]);o[s]=a(t[s],t[s])}var c=i(r,o),u=0,h=c[e+1];for(s=0;s<h.length;++s)u+=h[s];var f=new Array(e);for(s=0;s<e;++s){h=c[s];var p=0;for(l=0;l<h.length;++l)p+=h[l];f[s]=p/u}return f}function s(t){if(0===t.length)return[];for(var e=t[0].length,r=n([e]),i=o(t),a=0;a<t.length;++a)for(var s=0;s<e;++s)r[s]+=t[a][s]*i[a];return r}s.barycenetric=o,e.exports=s},{dup:170,\"robust-linear-solve\":509}],114:[function(t,e,r){e.exports=function(t){for(var e=n(t),r=0,i=0;i<t.length;++i)for(var a=t[i],o=0;o<e.length;++o)r+=Math.pow(a[o]-e[o],2);return Math.sqrt(r/t.length)};var n=t(\"circumcenter\")},{circumcenter:113}],115:[function(t,e,r){e.exports=function(t,e,r){return e<r?t<e?e:t>r?r:t:t<r?r:t>e?e:t}},{}],116:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n;if(r){n=e;for(var i=new Array(e.length),a=0;a<e.length;++a){var o=e[a];i[a]=[o[0],o[1],r[a]]}e=i}var s=function(t,e,r){var n=d(t,[],p(t));return m(e,n,r),!!n}(t,e,!!r);for(;y(t,e,!!r);)s=!0;if(r&&s){n.length=0,r.length=0;for(var a=0;a<e.length;++a){var o=e[a];n.push([o[0],o[1]]),r.push(o[2])}}return s};var n=t(\"union-find\"),i=t(\"box-intersect\"),a=t(\"robust-segment-intersect\"),o=t(\"big-rat\"),s=t(\"big-rat/cmp\"),l=t(\"big-rat/to-float\"),c=t(\"rat-vec\"),u=t(\"nextafter\"),h=t(\"./lib/rat-seg-intersect\");function f(t){var e=l(t);return[u(e,-1/0),u(e,1/0)]}function p(t){for(var e=new Array(t.length),r=0;r<t.length;++r){var n=t[r];e[r]=[u(n[0],-1/0),u(n[1],-1/0),u(n[0],1/0),u(n[1],1/0)]}return e}function d(t,e,r){for(var a=e.length,o=new n(a),s=[],l=0;l<e.length;++l){var c=e[l],h=f(c[0]),p=f(c[1]);s.push([u(h[0],-1/0),u(p[0],-1/0),u(h[1],1/0),u(p[1],1/0)])}i(s,function(t,e){o.link(t,e)});var d=!0,g=new Array(a);for(l=0;l<a;++l){(m=o.find(l))!==l&&(d=!1,t[m]=[Math.min(t[l][0],t[m][0]),Math.min(t[l][1],t[m][1])])}if(d)return null;var v=0;for(l=0;l<a;++l){var m;(m=o.find(l))===l?(g[l]=v,t[v++]=t[l]):g[l]=-1}t.length=v;for(l=0;l<a;++l)g[l]<0&&(g[l]=g[o.find(l)]);return g}function g(t,e){return t[0]-e[0]||t[1]-e[1]}function v(t,e){var r=t[0]-e[0]||t[1]-e[1];return r||(t[2]<e[2]?-1:t[2]>e[2]?1:0)}function m(t,e,r){if(0!==t.length){if(e)for(var n=0;n<t.length;++n){var i=e[(o=t[n])[0]],a=e[o[1]];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}else for(n=0;n<t.length;++n){var o;i=(o=t[n])[0],a=o[1];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}r?t.sort(v):t.sort(g);var s=1;for(n=1;n<t.length;++n){var l=t[n-1],c=t[n];(c[0]!==l[0]||c[1]!==l[1]||r&&c[2]!==l[2])&&(t[s++]=c)}t.length=s}}function y(t,e,r){var n=function(t,e){for(var r=new Array(e.length),n=0;n<e.length;++n){var i=e[n],a=t[i[0]],o=t[i[1]];r[n]=[u(Math.min(a[0],o[0]),-1/0),u(Math.min(a[1],o[1]),-1/0),u(Math.max(a[0],o[0]),1/0),u(Math.max(a[1],o[1]),1/0)]}return r}(t,e),f=function(t,e,r){var n=[];return i(r,function(r,i){var o=e[r],s=e[i];if(o[0]!==s[0]&&o[0]!==s[1]&&o[1]!==s[0]&&o[1]!==s[1]){var l=t[o[0]],c=t[o[1]],u=t[s[0]],h=t[s[1]];a(l,c,u,h)&&n.push([r,i])}}),n}(t,e,n),g=p(t),v=function(t,e,r,n){var o=[];return i(r,n,function(r,n){var i=e[r];if(i[0]!==n&&i[1]!==n){var s=t[n],l=t[i[0]],c=t[i[1]];a(l,c,s,s)&&o.push([r,n])}}),o}(t,e,n,g),y=d(t,function(t,e,r,n,i){var a,u,f=t.map(function(t){return[o(t[0]),o(t[1])]});for(a=0;a<r.length;++a){var p=r[a];u=p[0];var d=p[1],g=e[u],v=e[d],m=h(c(t[g[0]]),c(t[g[1]]),c(t[v[0]]),c(t[v[1]]));if(m){var y=t.length;t.push([l(m[0]),l(m[1])]),f.push(m),n.push([u,y],[d,y])}}for(n.sort(function(t,e){if(t[0]!==e[0])return t[0]-e[0];var r=f[t[1]],n=f[e[1]];return s(r[0],n[0])||s(r[1],n[1])}),a=n.length-1;a>=0;--a){var x=e[u=(S=n[a])[0]],b=x[0],_=x[1],w=t[b],k=t[_];if((w[0]-k[0]||w[1]-k[1])<0){var T=b;b=_,_=T}x[0]=b;var A,M=x[1]=S[1];for(i&&(A=x[2]);a>0&&n[a-1][0]===u;){var S,E=(S=n[--a])[1];i?e.push([M,E,A]):e.push([M,E]),M=E}i?e.push([M,_,A]):e.push([M,_])}return f}(t,e,f,v,r));return m(e,y,r),!!y||(f.length>0||v.length>0)}},{\"./lib/rat-seg-intersect\":117,\"big-rat\":78,\"big-rat/cmp\":76,\"big-rat/to-float\":90,\"box-intersect\":96,nextafter:451,\"rat-vec\":486,\"robust-segment-intersect\":513,\"union-find\":546}],117:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var a=s(e,t),h=s(n,r),f=u(a,h);if(0===o(f))return null;var p=s(t,r),d=u(h,p),g=i(d,f),v=c(a,g);return l(t,v)};var n=t(\"big-rat/mul\"),i=t(\"big-rat/div\"),a=t(\"big-rat/sub\"),o=t(\"big-rat/sign\"),s=t(\"rat-vec/sub\"),l=t(\"rat-vec/add\"),c=t(\"rat-vec/muls\");function u(t,e){return a(n(t[0],e[1]),n(t[1],e[0]))}},{\"big-rat/div\":77,\"big-rat/mul\":87,\"big-rat/sign\":88,\"big-rat/sub\":89,\"rat-vec/add\":485,\"rat-vec/muls\":487,\"rat-vec/sub\":488}],118:[function(t,e,r){\"use strict\";var n=t(\"clamp\");function i(t,e){null==e&&(e=!0);var r=t[0],i=t[1],a=t[2],o=t[3];return null==o&&(o=e?1:255),e&&(r*=255,i*=255,a*=255,o*=255),16777216*(r=255&n(r,0,255))+((i=255&n(i,0,255))<<16)+((a=255&n(a,0,255))<<8)+(o=255&n(o,0,255))}e.exports=i,e.exports.to=i,e.exports.from=function(t,e){var r=(t=+t)>>>24,n=(16711680&t)>>>16,i=(65280&t)>>>8,a=255&t;return!1===e?[r,n,i,a]:[r/255,n/255,i/255,a/255]}},{clamp:115}],119:[function(t,e,r){\"use strict\";e.exports={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]}},{}],120:[function(t,e,r){\"use strict\";var n=t(\"color-rgba\"),i=t(\"clamp\"),a=t(\"dtype\");e.exports=function(t,e){\"float\"!==e&&e||(e=\"array\"),\"uint\"===e&&(e=\"uint8\"),\"uint_clamped\"===e&&(e=\"uint8_clamped\");var r=new(a(e))(4),o=\"uint8\"!==e&&\"uint8_clamped\"!==e;return t.length&&\"string\"!=typeof t||((t=n(t))[0]/=255,t[1]/=255,t[2]/=255),function(t){return t instanceof Uint8Array||t instanceof Uint8ClampedArray||!!(Array.isArray(t)&&(t[0]>1||0===t[0])&&(t[1]>1||0===t[1])&&(t[2]>1||0===t[2])&&(!t[3]||t[3]>1))}(t)?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:255,o&&(r[0]/=255,r[1]/=255,r[2]/=255,r[3]/=255),r):(o?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:1):(r[0]=i(Math.floor(255*t[0]),0,255),r[1]=i(Math.floor(255*t[1]),0,255),r[2]=i(Math.floor(255*t[2]),0,255),r[3]=null==t[3]?255:i(Math.floor(255*t[3]),0,255)),r)}},{clamp:115,\"color-rgba\":122,dtype:169}],121:[function(t,e,r){(function(r){\"use strict\";var n=t(\"color-name\"),i=t(\"is-plain-obj\"),a=t(\"defined\");e.exports=function(t){var e,s,l=[],c=1;if(\"string\"==typeof t)if(n[t])l=n[t].slice(),s=\"rgb\";else if(\"transparent\"===t)c=0,s=\"rgb\",l=[0,0,0];else if(/^#[A-Fa-f0-9]+$/.test(t)){var u=t.slice(1),h=u.length,f=h<=4;c=1,f?(l=[parseInt(u[0]+u[0],16),parseInt(u[1]+u[1],16),parseInt(u[2]+u[2],16)],4===h&&(c=parseInt(u[3]+u[3],16)/255)):(l=[parseInt(u[0]+u[1],16),parseInt(u[2]+u[3],16),parseInt(u[4]+u[5],16)],8===h&&(c=parseInt(u[6]+u[7],16)/255)),l[0]||(l[0]=0),l[1]||(l[1]=0),l[2]||(l[2]=0),s=\"rgb\"}else if(e=/^((?:rgb|hs[lvb]|hwb|cmyk?|xy[zy]|gray|lab|lchu?v?|[ly]uv|lms)a?)\\s*\\(([^\\)]*)\\)/.exec(t)){var p=e[1],d=\"rgb\"===p,u=p.replace(/a$/,\"\");s=u;var h=\"cmyk\"===u?4:\"gray\"===u?1:3;l=e[2].trim().split(/\\s*,\\s*/).map(function(t,e){if(/%$/.test(t))return e===h?parseFloat(t)/100:\"rgb\"===u?255*parseFloat(t)/100:parseFloat(t);if(\"h\"===u[e]){if(/deg$/.test(t))return parseFloat(t);if(void 0!==o[t])return o[t]}return parseFloat(t)}),p===u&&l.push(1),c=d?1:void 0===l[h]?1:l[h],l=l.slice(0,h)}else t.length>10&&/[0-9](?:\\s|\\/)/.test(t)&&(l=t.match(/([0-9]+)/g).map(function(t){return parseFloat(t)}),s=t.match(/([a-z])/gi).join(\"\").toLowerCase());else if(isNaN(t))if(i(t)){var g=a(t.r,t.red,t.R,null);null!==g?(s=\"rgb\",l=[g,a(t.g,t.green,t.G),a(t.b,t.blue,t.B)]):(s=\"hsl\",l=[a(t.h,t.hue,t.H),a(t.s,t.saturation,t.S),a(t.l,t.lightness,t.L,t.b,t.brightness)]),c=a(t.a,t.alpha,t.opacity,1),null!=t.opacity&&(c/=100)}else(Array.isArray(t)||r.ArrayBuffer&&ArrayBuffer.isView&&ArrayBuffer.isView(t))&&(l=[t[0],t[1],t[2]],s=\"rgb\",c=4===t.length?t[3]:1);else s=\"rgb\",l=[t>>>16,(65280&t)>>>8,255&t];return{space:s,values:l,alpha:c}};var o={red:0,orange:60,yellow:120,green:180,blue:240,purple:300}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"color-name\":119,defined:164,\"is-plain-obj\":422}],122:[function(t,e,r){\"use strict\";var n=t(\"color-parse\"),i=t(\"color-space/hsl\"),a=t(\"clamp\");e.exports=function(t){var e,r=n(t);return r.space?((e=Array(3))[0]=a(r.values[0],0,255),e[1]=a(r.values[1],0,255),e[2]=a(r.values[2],0,255),\"h\"===r.space[0]&&(e=i.rgb(e)),e.push(a(r.alpha,0,1)),e):[]}},{clamp:115,\"color-parse\":121,\"color-space/hsl\":123}],123:[function(t,e,r){\"use strict\";var n=t(\"./rgb\");e.exports={name:\"hsl\",min:[0,0,0],max:[360,100,100],channel:[\"hue\",\"saturation\",\"lightness\"],alias:[\"HSL\"],rgb:function(t){var e,r,n,i,a,o=t[0]/360,s=t[1]/100,l=t[2]/100;if(0===s)return[a=255*l,a,a];e=2*l-(r=l<.5?l*(1+s):l+s-l*s),i=[0,0,0];for(var c=0;c<3;c++)(n=o+1/3*-(c-1))<0?n++:n>1&&n--,a=6*n<1?e+6*(r-e)*n:2*n<1?r:3*n<2?e+(r-e)*(2/3-n)*6:e,i[c]=255*a;return i}},n.hsl=function(t){var e,r,n=t[0]/255,i=t[1]/255,a=t[2]/255,o=Math.min(n,i,a),s=Math.max(n,i,a),l=s-o;return s===o?e=0:n===s?e=(i-a)/l:i===s?e=2+(a-n)/l:a===s&&(e=4+(n-i)/l),(e=Math.min(60*e,360))<0&&(e+=360),r=(o+s)/2,[e,100*(s===o?0:r<=.5?l/(s+o):l/(2-s-o)),100*r]}},{\"./rgb\":124}],124:[function(t,e,r){\"use strict\";e.exports={name:\"rgb\",min:[0,0,0],max:[255,255,255],channel:[\"red\",\"green\",\"blue\"],alias:[\"RGB\"]}},{}],125:[function(t,e,r){e.exports={jet:[{index:0,rgb:[0,0,131]},{index:.125,rgb:[0,60,170]},{index:.375,rgb:[5,255,255]},{index:.625,rgb:[255,255,0]},{index:.875,rgb:[250,0,0]},{index:1,rgb:[128,0,0]}],hsv:[{index:0,rgb:[255,0,0]},{index:.169,rgb:[253,255,2]},{index:.173,rgb:[247,255,2]},{index:.337,rgb:[0,252,4]},{index:.341,rgb:[0,252,10]},{index:.506,rgb:[1,249,255]},{index:.671,rgb:[2,0,253]},{index:.675,rgb:[8,0,253]},{index:.839,rgb:[255,0,251]},{index:.843,rgb:[255,0,245]},{index:1,rgb:[255,0,6]}],hot:[{index:0,rgb:[0,0,0]},{index:.3,rgb:[230,0,0]},{index:.6,rgb:[255,210,0]},{index:1,rgb:[255,255,255]}],cool:[{index:0,rgb:[0,255,255]},{index:1,rgb:[255,0,255]}],spring:[{index:0,rgb:[255,0,255]},{index:1,rgb:[255,255,0]}],summer:[{index:0,rgb:[0,128,102]},{index:1,rgb:[255,255,102]}],autumn:[{index:0,rgb:[255,0,0]},{index:1,rgb:[255,255,0]}],winter:[{index:0,rgb:[0,0,255]},{index:1,rgb:[0,255,128]}],bone:[{index:0,rgb:[0,0,0]},{index:.376,rgb:[84,84,116]},{index:.753,rgb:[169,200,200]},{index:1,rgb:[255,255,255]}],copper:[{index:0,rgb:[0,0,0]},{index:.804,rgb:[255,160,102]},{index:1,rgb:[255,199,127]}],greys:[{index:0,rgb:[0,0,0]},{index:1,rgb:[255,255,255]}],yignbu:[{index:0,rgb:[8,29,88]},{index:.125,rgb:[37,52,148]},{index:.25,rgb:[34,94,168]},{index:.375,rgb:[29,145,192]},{index:.5,rgb:[65,182,196]},{index:.625,rgb:[127,205,187]},{index:.75,rgb:[199,233,180]},{index:.875,rgb:[237,248,217]},{index:1,rgb:[255,255,217]}],greens:[{index:0,rgb:[0,68,27]},{index:.125,rgb:[0,109,44]},{index:.25,rgb:[35,139,69]},{index:.375,rgb:[65,171,93]},{index:.5,rgb:[116,196,118]},{index:.625,rgb:[161,217,155]},{index:.75,rgb:[199,233,192]},{index:.875,rgb:[229,245,224]},{index:1,rgb:[247,252,245]}],yiorrd:[{index:0,rgb:[128,0,38]},{index:.125,rgb:[189,0,38]},{index:.25,rgb:[227,26,28]},{index:.375,rgb:[252,78,42]},{index:.5,rgb:[253,141,60]},{index:.625,rgb:[254,178,76]},{index:.75,rgb:[254,217,118]},{index:.875,rgb:[255,237,160]},{index:1,rgb:[255,255,204]}],bluered:[{index:0,rgb:[0,0,255]},{index:1,rgb:[255,0,0]}],rdbu:[{index:0,rgb:[5,10,172]},{index:.35,rgb:[106,137,247]},{index:.5,rgb:[190,190,190]},{index:.6,rgb:[220,170,132]},{index:.7,rgb:[230,145,90]},{index:1,rgb:[178,10,28]}],picnic:[{index:0,rgb:[0,0,255]},{index:.1,rgb:[51,153,255]},{index:.2,rgb:[102,204,255]},{index:.3,rgb:[153,204,255]},{index:.4,rgb:[204,204,255]},{index:.5,rgb:[255,255,255]},{index:.6,rgb:[255,204,255]},{index:.7,rgb:[255,153,255]},{index:.8,rgb:[255,102,204]},{index:.9,rgb:[255,102,102]},{index:1,rgb:[255,0,0]}],rainbow:[{index:0,rgb:[150,0,90]},{index:.125,rgb:[0,0,200]},{index:.25,rgb:[0,25,255]},{index:.375,rgb:[0,152,255]},{index:.5,rgb:[44,255,150]},{index:.625,rgb:[151,255,0]},{index:.75,rgb:[255,234,0]},{index:.875,rgb:[255,111,0]},{index:1,rgb:[255,0,0]}],portland:[{index:0,rgb:[12,51,131]},{index:.25,rgb:[10,136,186]},{index:.5,rgb:[242,211,56]},{index:.75,rgb:[242,143,56]},{index:1,rgb:[217,30,30]}],blackbody:[{index:0,rgb:[0,0,0]},{index:.2,rgb:[230,0,0]},{index:.4,rgb:[230,210,0]},{index:.7,rgb:[255,255,255]},{index:1,rgb:[160,200,255]}],earth:[{index:0,rgb:[0,0,130]},{index:.1,rgb:[0,180,180]},{index:.2,rgb:[40,210,40]},{index:.4,rgb:[230,230,50]},{index:.6,rgb:[120,70,20]},{index:1,rgb:[255,255,255]}],electric:[{index:0,rgb:[0,0,0]},{index:.15,rgb:[30,0,100]},{index:.4,rgb:[120,0,100]},{index:.6,rgb:[160,90,0]},{index:.8,rgb:[230,200,0]},{index:1,rgb:[255,250,220]}],alpha:[{index:0,rgb:[255,255,255,0]},{index:1,rgb:[255,255,255,1]}],viridis:[{index:0,rgb:[68,1,84]},{index:.13,rgb:[71,44,122]},{index:.25,rgb:[59,81,139]},{index:.38,rgb:[44,113,142]},{index:.5,rgb:[33,144,141]},{index:.63,rgb:[39,173,129]},{index:.75,rgb:[92,200,99]},{index:.88,rgb:[170,220,50]},{index:1,rgb:[253,231,37]}],inferno:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[31,12,72]},{index:.25,rgb:[85,15,109]},{index:.38,rgb:[136,34,106]},{index:.5,rgb:[186,54,85]},{index:.63,rgb:[227,89,51]},{index:.75,rgb:[249,140,10]},{index:.88,rgb:[249,201,50]},{index:1,rgb:[252,255,164]}],magma:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[28,16,68]},{index:.25,rgb:[79,18,123]},{index:.38,rgb:[129,37,129]},{index:.5,rgb:[181,54,122]},{index:.63,rgb:[229,80,100]},{index:.75,rgb:[251,135,97]},{index:.88,rgb:[254,194,135]},{index:1,rgb:[252,253,191]}],plasma:[{index:0,rgb:[13,8,135]},{index:.13,rgb:[75,3,161]},{index:.25,rgb:[125,3,168]},{index:.38,rgb:[168,34,150]},{index:.5,rgb:[203,70,121]},{index:.63,rgb:[229,107,93]},{index:.75,rgb:[248,148,65]},{index:.88,rgb:[253,195,40]},{index:1,rgb:[240,249,33]}],warm:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[172,0,187]},{index:.25,rgb:[219,0,170]},{index:.38,rgb:[255,0,130]},{index:.5,rgb:[255,63,74]},{index:.63,rgb:[255,123,0]},{index:.75,rgb:[234,176,0]},{index:.88,rgb:[190,228,0]},{index:1,rgb:[147,255,0]}],cool:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[116,0,218]},{index:.25,rgb:[98,74,237]},{index:.38,rgb:[68,146,231]},{index:.5,rgb:[0,204,197]},{index:.63,rgb:[0,247,146]},{index:.75,rgb:[0,255,88]},{index:.88,rgb:[40,255,8]},{index:1,rgb:[147,255,0]}],\"rainbow-soft\":[{index:0,rgb:[125,0,179]},{index:.1,rgb:[199,0,180]},{index:.2,rgb:[255,0,121]},{index:.3,rgb:[255,108,0]},{index:.4,rgb:[222,194,0]},{index:.5,rgb:[150,255,0]},{index:.6,rgb:[0,255,55]},{index:.7,rgb:[0,246,150]},{index:.8,rgb:[50,167,222]},{index:.9,rgb:[103,51,235]},{index:1,rgb:[124,0,186]}],bathymetry:[{index:0,rgb:[40,26,44]},{index:.13,rgb:[59,49,90]},{index:.25,rgb:[64,76,139]},{index:.38,rgb:[63,110,151]},{index:.5,rgb:[72,142,158]},{index:.63,rgb:[85,174,163]},{index:.75,rgb:[120,206,163]},{index:.88,rgb:[187,230,172]},{index:1,rgb:[253,254,204]}],cdom:[{index:0,rgb:[47,15,62]},{index:.13,rgb:[87,23,86]},{index:.25,rgb:[130,28,99]},{index:.38,rgb:[171,41,96]},{index:.5,rgb:[206,67,86]},{index:.63,rgb:[230,106,84]},{index:.75,rgb:[242,149,103]},{index:.88,rgb:[249,193,135]},{index:1,rgb:[254,237,176]}],chlorophyll:[{index:0,rgb:[18,36,20]},{index:.13,rgb:[25,63,41]},{index:.25,rgb:[24,91,59]},{index:.38,rgb:[13,119,72]},{index:.5,rgb:[18,148,80]},{index:.63,rgb:[80,173,89]},{index:.75,rgb:[132,196,122]},{index:.88,rgb:[175,221,162]},{index:1,rgb:[215,249,208]}],density:[{index:0,rgb:[54,14,36]},{index:.13,rgb:[89,23,80]},{index:.25,rgb:[110,45,132]},{index:.38,rgb:[120,77,178]},{index:.5,rgb:[120,113,213]},{index:.63,rgb:[115,151,228]},{index:.75,rgb:[134,185,227]},{index:.88,rgb:[177,214,227]},{index:1,rgb:[230,241,241]}],\"freesurface-blue\":[{index:0,rgb:[30,4,110]},{index:.13,rgb:[47,14,176]},{index:.25,rgb:[41,45,236]},{index:.38,rgb:[25,99,212]},{index:.5,rgb:[68,131,200]},{index:.63,rgb:[114,156,197]},{index:.75,rgb:[157,181,203]},{index:.88,rgb:[200,208,216]},{index:1,rgb:[241,237,236]}],\"freesurface-red\":[{index:0,rgb:[60,9,18]},{index:.13,rgb:[100,17,27]},{index:.25,rgb:[142,20,29]},{index:.38,rgb:[177,43,27]},{index:.5,rgb:[192,87,63]},{index:.63,rgb:[205,125,105]},{index:.75,rgb:[216,162,148]},{index:.88,rgb:[227,199,193]},{index:1,rgb:[241,237,236]}],oxygen:[{index:0,rgb:[64,5,5]},{index:.13,rgb:[106,6,15]},{index:.25,rgb:[144,26,7]},{index:.38,rgb:[168,64,3]},{index:.5,rgb:[188,100,4]},{index:.63,rgb:[206,136,11]},{index:.75,rgb:[220,174,25]},{index:.88,rgb:[231,215,44]},{index:1,rgb:[248,254,105]}],par:[{index:0,rgb:[51,20,24]},{index:.13,rgb:[90,32,35]},{index:.25,rgb:[129,44,34]},{index:.38,rgb:[159,68,25]},{index:.5,rgb:[182,99,19]},{index:.63,rgb:[199,134,22]},{index:.75,rgb:[212,171,35]},{index:.88,rgb:[221,210,54]},{index:1,rgb:[225,253,75]}],phase:[{index:0,rgb:[145,105,18]},{index:.13,rgb:[184,71,38]},{index:.25,rgb:[186,58,115]},{index:.38,rgb:[160,71,185]},{index:.5,rgb:[110,97,218]},{index:.63,rgb:[50,123,164]},{index:.75,rgb:[31,131,110]},{index:.88,rgb:[77,129,34]},{index:1,rgb:[145,105,18]}],salinity:[{index:0,rgb:[42,24,108]},{index:.13,rgb:[33,50,162]},{index:.25,rgb:[15,90,145]},{index:.38,rgb:[40,118,137]},{index:.5,rgb:[59,146,135]},{index:.63,rgb:[79,175,126]},{index:.75,rgb:[120,203,104]},{index:.88,rgb:[193,221,100]},{index:1,rgb:[253,239,154]}],temperature:[{index:0,rgb:[4,35,51]},{index:.13,rgb:[23,51,122]},{index:.25,rgb:[85,59,157]},{index:.38,rgb:[129,79,143]},{index:.5,rgb:[175,95,130]},{index:.63,rgb:[222,112,101]},{index:.75,rgb:[249,146,66]},{index:.88,rgb:[249,196,65]},{index:1,rgb:[232,250,91]}],turbidity:[{index:0,rgb:[34,31,27]},{index:.13,rgb:[65,50,41]},{index:.25,rgb:[98,69,52]},{index:.38,rgb:[131,89,57]},{index:.5,rgb:[161,112,59]},{index:.63,rgb:[185,140,66]},{index:.75,rgb:[202,174,88]},{index:.88,rgb:[216,209,126]},{index:1,rgb:[233,246,171]}],\"velocity-blue\":[{index:0,rgb:[17,32,64]},{index:.13,rgb:[35,52,116]},{index:.25,rgb:[29,81,156]},{index:.38,rgb:[31,113,162]},{index:.5,rgb:[50,144,169]},{index:.63,rgb:[87,173,176]},{index:.75,rgb:[149,196,189]},{index:.88,rgb:[203,221,211]},{index:1,rgb:[254,251,230]}],\"velocity-green\":[{index:0,rgb:[23,35,19]},{index:.13,rgb:[24,64,38]},{index:.25,rgb:[11,95,45]},{index:.38,rgb:[39,123,35]},{index:.5,rgb:[95,146,12]},{index:.63,rgb:[152,165,18]},{index:.75,rgb:[201,186,69]},{index:.88,rgb:[233,216,137]},{index:1,rgb:[255,253,205]}],cubehelix:[{index:0,rgb:[0,0,0]},{index:.07,rgb:[22,5,59]},{index:.13,rgb:[60,4,105]},{index:.2,rgb:[109,1,135]},{index:.27,rgb:[161,0,147]},{index:.33,rgb:[210,2,142]},{index:.4,rgb:[251,11,123]},{index:.47,rgb:[255,29,97]},{index:.53,rgb:[255,54,69]},{index:.6,rgb:[255,85,46]},{index:.67,rgb:[255,120,34]},{index:.73,rgb:[255,157,37]},{index:.8,rgb:[241,191,57]},{index:.87,rgb:[224,220,93]},{index:.93,rgb:[218,241,142]},{index:1,rgb:[227,253,198]}]}},{}],126:[function(t,e,r){\"use strict\";var n=t(\"./colorScale\"),i=t(\"lerp\");function a(t){return[t[0]/255,t[1]/255,t[2]/255,t[3]]}function o(t){for(var e,r=\"#\",n=0;n<3;++n)r+=(\"00\"+(e=(e=t[n]).toString(16))).substr(e.length);return r}function s(t){return\"rgba(\"+t.join(\",\")+\")\"}e.exports=function(t){var e,r,l,c,u,h,f,p,d,g;t||(t={});p=(t.nshades||72)-1,f=t.format||\"hex\",(h=t.colormap)||(h=\"jet\");if(\"string\"==typeof h){if(h=h.toLowerCase(),!n[h])throw Error(h+\" not a supported colorscale\");u=n[h]}else{if(!Array.isArray(h))throw Error(\"unsupported colormap option\",h);u=h.slice()}if(u.length>p+1)throw new Error(h+\" map requires nshades to be at least size \"+u.length);d=Array.isArray(t.alpha)?2!==t.alpha.length?[1,1]:t.alpha.slice():\"number\"==typeof t.alpha?[t.alpha,t.alpha]:[1,1];e=u.map(function(t){return Math.round(t.index*p)}),d[0]=Math.min(Math.max(d[0],0),1),d[1]=Math.min(Math.max(d[1],0),1);var v=u.map(function(t,e){var r=u[e].index,n=u[e].rgb.slice();return 4===n.length&&n[3]>=0&&n[3]<=1?n:(n[3]=d[0]+(d[1]-d[0])*r,n)}),m=[];for(g=0;g<e.length-1;++g){c=e[g+1]-e[g],r=v[g],l=v[g+1];for(var y=0;y<c;y++){var x=y/c;m.push([Math.round(i(r[0],l[0],x)),Math.round(i(r[1],l[1],x)),Math.round(i(r[2],l[2],x)),i(r[3],l[3],x)])}}m.push(u[u.length-1].rgb.concat(d[1])),\"hex\"===f?m=m.map(o):\"rgbaString\"===f?m=m.map(s):\"float\"===f&&(m=m.map(a));return m}},{\"./colorScale\":125,lerp:425}],127:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a){var o=n(e,r,a);if(0===o){var s=i(n(t,e,r)),c=i(n(t,e,a));if(s===c){if(0===s){var u=l(t,e,r),h=l(t,e,a);return u===h?0:u?1:-1}return 0}return 0===c?s>0?-1:l(t,e,a)?-1:1:0===s?c>0?1:l(t,e,r)?1:-1:i(c-s)}var f=n(t,e,r);if(f>0)return o>0&&n(t,e,a)>0?1:-1;if(f<0)return o>0||n(t,e,a)>0?1:-1;var p=n(t,e,a);return p>0?1:l(t,e,r)?1:-1};var n=t(\"robust-orientation\"),i=t(\"signum\"),a=t(\"two-sum\"),o=t(\"robust-product\"),s=t(\"robust-sum\");function l(t,e,r){var n=a(t[0],-e[0]),i=a(t[1],-e[1]),l=a(r[0],-e[0]),c=a(r[1],-e[1]),u=s(o(n,l),o(i,c));return u[u.length-1]>=0}},{\"robust-orientation\":510,\"robust-product\":511,\"robust-sum\":515,signum:516,\"two-sum\":544}],128:[function(t,e,r){e.exports=function(t,e){var r=t.length,a=t.length-e.length;if(a)return a;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return t[0]+t[1]-e[0]-e[1]||n(t[0],t[1])-n(e[0],e[1]);case 3:var o=t[0]+t[1],s=e[0]+e[1];if(a=o+t[2]-(s+e[2]))return a;var l=n(t[0],t[1]),c=n(e[0],e[1]);return n(l,t[2])-n(c,e[2])||n(l+t[2],o)-n(c+e[2],s);case 4:var u=t[0],h=t[1],f=t[2],p=t[3],d=e[0],g=e[1],v=e[2],m=e[3];return u+h+f+p-(d+g+v+m)||n(u,h,f,p)-n(d,g,v,m,d)||n(u+h,u+f,u+p,h+f,h+p,f+p)-n(d+g,d+v,d+m,g+v,g+m,v+m)||n(u+h+f,u+h+p,u+f+p,h+f+p)-n(d+g+v,d+g+m,d+v+m,g+v+m);default:for(var y=t.slice().sort(i),x=e.slice().sort(i),b=0;b<r;++b)if(a=y[b]-x[b])return a;return 0}};var n=Math.min;function i(t,e){return t-e}},{}],129:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"cell-orientation\");e.exports=function(t,e){return n(t,e)||i(t)-i(e)}},{\"cell-orientation\":112,\"compare-cell\":128}],130:[function(t,e,r){\"use strict\";var n=t(\"./lib/ch1d\"),i=t(\"./lib/ch2d\"),a=t(\"./lib/chnd\");e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[[0]];var r=t[0].length;if(0===r)return[];if(1===r)return n(t);if(2===r)return i(t);return a(t,r)}},{\"./lib/ch1d\":131,\"./lib/ch2d\":132,\"./lib/chnd\":133}],131:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0,r=0,n=1;n<t.length;++n)t[n][0]<t[e][0]&&(e=n),t[n][0]>t[r][0]&&(r=n);return e<r?[[e],[r]]:e>r?[[r],[e]]:[[e]]}},{}],132:[function(t,e,r){\"use strict\";e.exports=function(t){var e=n(t),r=e.length;if(r<=2)return[];for(var i=new Array(r),a=e[r-1],o=0;o<r;++o){var s=e[o];i[o]=[a,s],a=s}return i};var n=t(\"monotone-convex-hull-2d\")},{\"monotone-convex-hull-2d\":434}],133:[function(t,e,r){\"use strict\";e.exports=function(t,e){try{return n(t,!0)}catch(s){var r=i(t);if(r.length<=e)return[];var a=function(t,e){for(var r=t.length,n=new Array(r),i=0;i<e.length;++i)n[i]=t[e[i]];for(var a=e.length,i=0;i<r;++i)e.indexOf(i)<0&&(n[a++]=t[i]);return n}(t,r),o=n(a,!0);return function(t,e){for(var r=t.length,n=e.length,i=0;i<r;++i)for(var a=t[i],o=0;o<a.length;++o){var s=a[o];if(s<n)a[o]=e[s];else{s-=n;for(var l=0;l<n;++l)s>=e[l]&&(s+=1);a[o]=s}}return t}(o,r)}};var n=t(\"incremental-convex-hull\"),i=t(\"affine-hull\")},{\"affine-hull\":62,\"incremental-convex-hull\":413}],134:[function(t,e,r){e.exports={AFG:\"afghan\",ALA:\"\\\\b\\\\wland\",ALB:\"albania\",DZA:\"algeria\",ASM:\"^(?=.*americ).*samoa\",AND:\"andorra\",AGO:\"angola\",AIA:\"anguill?a\",ATA:\"antarctica\",ATG:\"antigua\",ARG:\"argentin\",ARM:\"armenia\",ABW:\"^(?!.*bonaire).*\\\\baruba\",AUS:\"australia\",AUT:\"^(?!.*hungary).*austria|\\\\baustri.*\\\\bemp\",AZE:\"azerbaijan\",BHS:\"bahamas\",BHR:\"bahrain\",BGD:\"bangladesh|^(?=.*east).*paki?stan\",BRB:\"barbados\",BLR:\"belarus|byelo\",BEL:\"^(?!.*luxem).*belgium\",BLZ:\"belize|^(?=.*british).*honduras\",BEN:\"benin|dahome\",BMU:\"bermuda\",BTN:\"bhutan\",BOL:\"bolivia\",BES:\"^(?=.*bonaire).*eustatius|^(?=.*carib).*netherlands|\\\\bbes.?islands\",BIH:\"herzegovina|bosnia\",BWA:\"botswana|bechuana\",BVT:\"bouvet\",BRA:\"brazil\",IOT:\"british.?indian.?ocean\",BRN:\"brunei\",BGR:\"bulgaria\",BFA:\"burkina|\\\\bfaso|upper.?volta\",BDI:\"burundi\",CPV:\"verde\",KHM:\"cambodia|kampuchea|khmer\",CMR:\"cameroon\",CAN:\"canada\",CYM:\"cayman\",CAF:\"\\\\bcentral.african.republic\",TCD:\"\\\\bchad\",CHL:\"\\\\bchile\",CHN:\"^(?!.*\\\\bmac)(?!.*\\\\bhong)(?!.*\\\\btai)(?!.*\\\\brep).*china|^(?=.*peo)(?=.*rep).*china\",CXR:\"christmas\",CCK:\"\\\\bcocos|keeling\",COL:\"colombia\",COM:\"comoro\",COG:\"^(?!.*\\\\bdem)(?!.*\\\\bd[\\\\.]?r)(?!.*kinshasa)(?!.*zaire)(?!.*belg)(?!.*l.opoldville)(?!.*free).*\\\\bcongo\",COK:\"\\\\bcook\",CRI:\"costa.?rica\",CIV:\"ivoire|ivory\",HRV:\"croatia\",CUB:\"\\\\bcuba\",CUW:\"^(?!.*bonaire).*\\\\bcura(c|\\xe7)ao\",CYP:\"cyprus\",CSK:\"czechoslovakia\",CZE:\"^(?=.*rep).*czech|czechia|bohemia\",COD:\"\\\\bdem.*congo|congo.*\\\\bdem|congo.*\\\\bd[\\\\.]?r|\\\\bd[\\\\.]?r.*congo|belgian.?congo|congo.?free.?state|kinshasa|zaire|l.opoldville|drc|droc|rdc\",DNK:\"denmark\",DJI:\"djibouti\",DMA:\"dominica(?!n)\",DOM:\"dominican.rep\",ECU:\"ecuador\",EGY:\"egypt\",SLV:\"el.?salvador\",GNQ:\"guine.*eq|eq.*guine|^(?=.*span).*guinea\",ERI:\"eritrea\",EST:\"estonia\",ETH:\"ethiopia|abyssinia\",FLK:\"falkland|malvinas\",FRO:\"faroe|faeroe\",FJI:\"fiji\",FIN:\"finland\",FRA:\"^(?!.*\\\\bdep)(?!.*martinique).*france|french.?republic|\\\\bgaul\",GUF:\"^(?=.*french).*guiana\",PYF:\"french.?polynesia|tahiti\",ATF:\"french.?southern\",GAB:\"gabon\",GMB:\"gambia\",GEO:\"^(?!.*south).*georgia\",DDR:\"german.?democratic.?republic|democratic.?republic.*germany|east.germany\",DEU:\"^(?!.*east).*germany|^(?=.*\\\\bfed.*\\\\brep).*german\",GHA:\"ghana|gold.?coast\",GIB:\"gibraltar\",GRC:\"greece|hellenic|hellas\",GRL:\"greenland\",GRD:\"grenada\",GLP:\"guadeloupe\",GUM:\"\\\\bguam\",GTM:\"guatemala\",GGY:\"guernsey\",GIN:\"^(?!.*eq)(?!.*span)(?!.*bissau)(?!.*portu)(?!.*new).*guinea\",GNB:\"bissau|^(?=.*portu).*guinea\",GUY:\"guyana|british.?guiana\",HTI:\"haiti\",HMD:\"heard.*mcdonald\",VAT:\"holy.?see|vatican|papal.?st\",HND:\"^(?!.*brit).*honduras\",HKG:\"hong.?kong\",HUN:\"^(?!.*austr).*hungary\",ISL:\"iceland\",IND:\"india(?!.*ocea)\",IDN:\"indonesia\",IRN:\"\\\\biran|persia\",IRQ:\"\\\\biraq|mesopotamia\",IRL:\"(^ireland)|(^republic.*ireland)\",IMN:\"^(?=.*isle).*\\\\bman\",ISR:\"israel\",ITA:\"italy\",JAM:\"jamaica\",JPN:\"japan\",JEY:\"jersey\",JOR:\"jordan\",KAZ:\"kazak\",KEN:\"kenya|british.?east.?africa|east.?africa.?prot\",KIR:\"kiribati\",PRK:\"^(?=.*democrat|people|north|d.*p.*.r).*\\\\bkorea|dprk|korea.*(d.*p.*r)\",KWT:\"kuwait\",KGZ:\"kyrgyz|kirghiz\",LAO:\"\\\\blaos?\\\\b\",LVA:\"latvia\",LBN:\"lebanon\",LSO:\"lesotho|basuto\",LBR:\"liberia\",LBY:\"libya\",LIE:\"liechtenstein\",LTU:\"lithuania\",LUX:\"^(?!.*belg).*luxem\",MAC:\"maca(o|u)\",MDG:\"madagascar|malagasy\",MWI:\"malawi|nyasa\",MYS:\"malaysia\",MDV:\"maldive\",MLI:\"\\\\bmali\\\\b\",MLT:\"\\\\bmalta\",MHL:\"marshall\",MTQ:\"martinique\",MRT:\"mauritania\",MUS:\"mauritius\",MYT:\"\\\\bmayotte\",MEX:\"\\\\bmexic\",FSM:\"fed.*micronesia|micronesia.*fed\",MCO:\"monaco\",MNG:\"mongolia\",MNE:\"^(?!.*serbia).*montenegro\",MSR:\"montserrat\",MAR:\"morocco|\\\\bmaroc\",MOZ:\"mozambique\",MMR:\"myanmar|burma\",NAM:\"namibia\",NRU:\"nauru\",NPL:\"nepal\",NLD:\"^(?!.*\\\\bant)(?!.*\\\\bcarib).*netherlands\",ANT:\"^(?=.*\\\\bant).*(nether|dutch)\",NCL:\"new.?caledonia\",NZL:\"new.?zealand\",NIC:\"nicaragua\",NER:\"\\\\bniger(?!ia)\",NGA:\"nigeria\",NIU:\"niue\",NFK:\"norfolk\",MNP:\"mariana\",NOR:\"norway\",OMN:\"\\\\boman|trucial\",PAK:\"^(?!.*east).*paki?stan\",PLW:\"palau\",PSE:\"palestin|\\\\bgaza|west.?bank\",PAN:\"panama\",PNG:\"papua|new.?guinea\",PRY:\"paraguay\",PER:\"peru\",PHL:\"philippines\",PCN:\"pitcairn\",POL:\"poland\",PRT:\"portugal\",PRI:\"puerto.?rico\",QAT:\"qatar\",KOR:\"^(?!.*d.*p.*r)(?!.*democrat)(?!.*people)(?!.*north).*\\\\bkorea(?!.*d.*p.*r)\",MDA:\"moldov|b(a|e)ssarabia\",REU:\"r(e|\\xe9)union\",ROU:\"r(o|u|ou)mania\",RUS:\"\\\\brussia|soviet.?union|u\\\\.?s\\\\.?s\\\\.?r|socialist.?republics\",RWA:\"rwanda\",BLM:\"barth(e|\\xe9)lemy\",SHN:\"helena\",KNA:\"kitts|\\\\bnevis\",LCA:\"\\\\blucia\",MAF:\"^(?=.*collectivity).*martin|^(?=.*france).*martin(?!ique)|^(?=.*french).*martin(?!ique)\",SPM:\"miquelon\",VCT:\"vincent\",WSM:\"^(?!.*amer).*samoa\",SMR:\"san.?marino\",STP:\"\\\\bs(a|\\xe3)o.?tom(e|\\xe9)\",SAU:\"\\\\bsa\\\\w*.?arabia\",SEN:\"senegal\",SRB:\"^(?!.*monte).*serbia\",SYC:\"seychell\",SLE:\"sierra\",SGP:\"singapore\",SXM:\"^(?!.*martin)(?!.*saba).*maarten\",SVK:\"^(?!.*cze).*slovak\",SVN:\"slovenia\",SLB:\"solomon\",SOM:\"somali\",ZAF:\"south.africa|s\\\\\\\\..?africa\",SGS:\"south.?georgia|sandwich\",SSD:\"\\\\bs\\\\w*.?sudan\",ESP:\"spain\",LKA:\"sri.?lanka|ceylon\",SDN:\"^(?!.*\\\\bs(?!u)).*sudan\",SUR:\"surinam|dutch.?guiana\",SJM:\"svalbard\",SWZ:\"swaziland\",SWE:\"sweden\",CHE:\"switz|swiss\",SYR:\"syria\",TWN:\"taiwan|taipei|formosa|^(?!.*peo)(?=.*rep).*china\",TJK:\"tajik\",THA:\"thailand|\\\\bsiam\",MKD:\"macedonia|fyrom\",TLS:\"^(?=.*leste).*timor|^(?=.*east).*timor\",TGO:\"togo\",TKL:\"tokelau\",TON:\"tonga\",TTO:\"trinidad|tobago\",TUN:\"tunisia\",TUR:\"turkey\",TKM:\"turkmen\",TCA:\"turks\",TUV:\"tuvalu\",UGA:\"uganda\",UKR:\"ukrain\",ARE:\"emirates|^u\\\\.?a\\\\.?e\\\\.?$|united.?arab.?em\",GBR:\"united.?kingdom|britain|^u\\\\.?k\\\\.?$\",TZA:\"tanzania\",USA:\"united.?states\\\\b(?!.*islands)|\\\\bu\\\\.?s\\\\.?a\\\\.?\\\\b|^\\\\s*u\\\\.?s\\\\.?\\\\b(?!.*islands)\",UMI:\"minor.?outlying.?is\",URY:\"uruguay\",UZB:\"uzbek\",VUT:\"vanuatu|new.?hebrides\",VEN:\"venezuela\",VNM:\"^(?!.*republic).*viet.?nam|^(?=.*socialist).*viet.?nam\",VGB:\"^(?=.*\\\\bu\\\\.?\\\\s?k).*virgin|^(?=.*brit).*virgin|^(?=.*kingdom).*virgin\",VIR:\"^(?=.*\\\\bu\\\\.?\\\\s?s).*virgin|^(?=.*states).*virgin\",WLF:\"futuna|wallis\",ESH:\"western.sahara\",YEM:\"^(?!.*arab)(?!.*north)(?!.*sana)(?!.*peo)(?!.*dem)(?!.*south)(?!.*aden)(?!.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YMD:\"^(?=.*peo).*yemen|^(?!.*rep)(?=.*dem).*yemen|^(?=.*south).*yemen|^(?=.*aden).*yemen|^(?=.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YUG:\"yugoslavia\",ZMB:\"zambia|northern.?rhodesia\",EAZ:\"zanzibar\",ZWE:\"zimbabwe|^(?!.*northern).*rhodesia\"}},{}],135:[function(t,e,r){e.exports=[\"xx-small\",\"x-small\",\"small\",\"medium\",\"large\",\"x-large\",\"xx-large\",\"larger\",\"smaller\"]},{}],136:[function(t,e,r){e.exports=[\"normal\",\"condensed\",\"semi-condensed\",\"extra-condensed\",\"ultra-condensed\",\"expanded\",\"semi-expanded\",\"extra-expanded\",\"ultra-expanded\"]},{}],137:[function(t,e,r){e.exports=[\"normal\",\"italic\",\"oblique\"]},{}],138:[function(t,e,r){e.exports=[\"normal\",\"bold\",\"bolder\",\"lighter\",\"100\",\"200\",\"300\",\"400\",\"500\",\"600\",\"700\",\"800\",\"900\"]},{}],139:[function(t,e,r){\"use strict\";e.exports={parse:t(\"./parse\"),stringify:t(\"./stringify\")}},{\"./parse\":141,\"./stringify\":142}],140:[function(t,e,r){\"use strict\";var n=t(\"css-font-size-keywords\");e.exports={isSize:function(t){return/^[\\d\\.]/.test(t)||-1!==t.indexOf(\"/\")||-1!==n.indexOf(t)}}},{\"css-font-size-keywords\":135}],141:[function(t,e,r){\"use strict\";var n=t(\"unquote\"),i=t(\"css-global-keywords\"),a=t(\"css-system-font-keywords\"),o=t(\"css-font-weight-keywords\"),s=t(\"css-font-style-keywords\"),l=t(\"css-font-stretch-keywords\"),c=t(\"string-split-by\"),u=t(\"./lib/util\").isSize;e.exports=f;var h=f.cache={};function f(t){if(\"string\"!=typeof t)throw new Error(\"Font argument must be a string.\");if(h[t])return h[t];if(\"\"===t)throw new Error(\"Cannot parse an empty string.\");if(-1!==a.indexOf(t))return h[t]={system:t};for(var e,r={style:\"normal\",variant:\"normal\",weight:\"normal\",stretch:\"normal\",lineHeight:\"normal\",size:\"1rem\",family:[\"serif\"]},f=c(t,/\\s+/);e=f.shift();){if(-1!==i.indexOf(e))return[\"style\",\"variant\",\"weight\",\"stretch\"].forEach(function(t){r[t]=e}),h[t]=r;if(-1===s.indexOf(e))if(\"normal\"!==e&&\"small-caps\"!==e)if(-1===l.indexOf(e)){if(-1===o.indexOf(e)){if(u(e)){var d=c(e,\"/\");if(r.size=d[0],null!=d[1]?r.lineHeight=p(d[1]):\"/\"===f[0]&&(f.shift(),r.lineHeight=p(f.shift())),!f.length)throw new Error(\"Missing required font-family.\");return r.family=c(f.join(\" \"),/\\s*,\\s*/).map(n),h[t]=r}throw new Error(\"Unknown or unsupported font token: \"+e)}r.weight=e}else r.stretch=e;else r.variant=e;else r.style=e}throw new Error(\"Missing required font-size.\")}function p(t){var e=parseFloat(t);return e.toString()===t?e:t}},{\"./lib/util\":140,\"css-font-stretch-keywords\":136,\"css-font-style-keywords\":137,\"css-font-weight-keywords\":138,\"css-global-keywords\":143,\"css-system-font-keywords\":144,\"string-split-by\":529,unquote:548}],142:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\"),i=t(\"./lib/util\").isSize,a=g(t(\"css-global-keywords\")),o=g(t(\"css-system-font-keywords\")),s=g(t(\"css-font-weight-keywords\")),l=g(t(\"css-font-style-keywords\")),c=g(t(\"css-font-stretch-keywords\")),u={normal:1,\"small-caps\":1},h={serif:1,\"sans-serif\":1,monospace:1,cursive:1,fantasy:1,\"system-ui\":1},f=\"1rem\",p=\"serif\";function d(t,e){if(t&&!e[t]&&!a[t])throw Error(\"Unknown keyword `\"+t+\"`\");return t}function g(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=1;return e}e.exports=function(t){if((t=n(t,{style:\"style fontstyle fontStyle font-style slope distinction\",variant:\"variant font-variant fontVariant fontvariant var capitalization\",weight:\"weight w font-weight fontWeight fontweight\",stretch:\"stretch font-stretch fontStretch fontstretch width\",size:\"size s font-size fontSize fontsize height em emSize\",lineHeight:\"lh line-height lineHeight lineheight leading\",family:\"font family fontFamily font-family fontfamily type typeface face\",system:\"system reserved default global\"})).system)return t.system&&d(t.system,o),t.system;if(d(t.style,l),d(t.variant,u),d(t.weight,s),d(t.stretch,c),null==t.size&&(t.size=f),\"number\"==typeof t.size&&(t.size+=\"px\"),!i)throw Error(\"Bad size value `\"+t.size+\"`\");t.family||(t.family=p),Array.isArray(t.family)&&(t.family.length||(t.family=[p]),t.family=t.family.map(function(t){return h[t]?t:'\"'+t+'\"'}).join(\", \"));var e=[];return e.push(t.style),t.variant!==t.style&&e.push(t.variant),t.weight!==t.variant&&t.weight!==t.style&&e.push(t.weight),t.stretch!==t.weight&&t.stretch!==t.variant&&t.stretch!==t.style&&e.push(t.stretch),e.push(t.size+(null==t.lineHeight||\"normal\"===t.lineHeight||t.lineHeight+\"\"==\"1\"?\"\":\"/\"+t.lineHeight)),e.push(t.family),e.filter(Boolean).join(\" \")}},{\"./lib/util\":140,\"css-font-stretch-keywords\":136,\"css-font-style-keywords\":137,\"css-font-weight-keywords\":138,\"css-global-keywords\":143,\"css-system-font-keywords\":144,\"pick-by-alias\":465}],143:[function(t,e,r){e.exports=[\"inherit\",\"initial\",\"unset\"]},{}],144:[function(t,e,r){e.exports=[\"caption\",\"icon\",\"menu\",\"message-box\",\"small-caption\",\"status-bar\"]},{}],145:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i-1,s=i*i,l=o*o,c=(1+2*i)*l,u=i*l,h=s*(3-2*i),f=s*o;if(t.length){a||(a=new Array(t.length));for(var p=t.length-1;p>=0;--p)a[p]=c*t[p]+u*e[p]+h*r[p]+f*n[p];return a}return c*t+u*e+h*r+f*n},e.exports.derivative=function(t,e,r,n,i,a){var o=6*i*i-6*i,s=3*i*i-4*i+1,l=-6*i*i+6*i,c=3*i*i-2*i;if(t.length){a||(a=new Array(t.length));for(var u=t.length-1;u>=0;--u)a[u]=o*t[u]+s*e[u]+l*r[u]+c*n[u];return a}return o*t+s*e+l*r[u]+c*n}},{}],146:[function(t,e,r){\"use strict\";var n=t(\"./lib/thunk.js\");function i(){this.argTypes=[],this.shimArgs=[],this.arrayArgs=[],this.arrayBlockIndices=[],this.scalarArgs=[],this.offsetArgs=[],this.offsetArgIndex=[],this.indexArgs=[],this.shapeArgs=[],this.funcName=\"\",this.pre=null,this.body=null,this.post=null,this.debug=!1}e.exports=function(t){var e=new i;e.pre=t.pre,e.body=t.body,e.post=t.post;var r=t.args.slice(0);e.argTypes=r;for(var a=0;a<r.length;++a){var o=r[a];if(\"array\"===o||\"object\"==typeof o&&o.blockIndices){if(e.argTypes[a]=\"array\",e.arrayArgs.push(a),e.arrayBlockIndices.push(o.blockIndices?o.blockIndices:0),e.shimArgs.push(\"array\"+a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array args\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array args\")}else if(\"scalar\"===o)e.scalarArgs.push(a),e.shimArgs.push(\"scalar\"+a);else if(\"index\"===o){if(e.indexArgs.push(a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array index\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array index\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array index\")}else if(\"shape\"===o){if(e.shapeArgs.push(a),a<e.pre.args.length&&e.pre.args[a].lvalue)throw new Error(\"cwise: pre() block may not write to array shape\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array shape\");if(a<e.post.args.length&&e.post.args[a].lvalue)throw new Error(\"cwise: post() block may not write to array shape\")}else{if(\"object\"!=typeof o||!o.offset)throw new Error(\"cwise: Unknown argument type \"+r[a]);e.argTypes[a]=\"offset\",e.offsetArgs.push({array:o.array,offset:o.offset}),e.offsetArgIndex.push(a)}}if(e.arrayArgs.length<=0)throw new Error(\"cwise: No array arguments specified\");if(e.pre.args.length>r.length)throw new Error(\"cwise: Too many arguments in pre() block\");if(e.body.args.length>r.length)throw new Error(\"cwise: Too many arguments in body() block\");if(e.post.args.length>r.length)throw new Error(\"cwise: Too many arguments in post() block\");return e.debug=!!t.printCode||!!t.debug,e.funcName=t.funcName||\"cwise\",e.blockSize=t.blockSize||64,n(e)}},{\"./lib/thunk.js\":148}],147:[function(t,e,r){\"use strict\";var n=t(\"uniq\");function i(t,e,r){var n,i,a=t.length,o=e.arrayArgs.length,s=e.indexArgs.length>0,l=[],c=[],u=0,h=0;for(n=0;n<a;++n)c.push([\"i\",n,\"=0\"].join(\"\"));for(i=0;i<o;++i)for(n=0;n<a;++n)h=u,u=t[n],0===n?c.push([\"d\",i,\"s\",n,\"=t\",i,\"p\",u].join(\"\")):c.push([\"d\",i,\"s\",n,\"=(t\",i,\"p\",u,\"-s\",h,\"*t\",i,\"p\",h,\")\"].join(\"\"));for(c.length>0&&l.push(\"var \"+c.join(\",\")),n=a-1;n>=0;--n)u=t[n],l.push([\"for(i\",n,\"=0;i\",n,\"<s\",u,\";++i\",n,\"){\"].join(\"\"));for(l.push(r),n=0;n<a;++n){for(h=u,u=t[n],i=0;i<o;++i)l.push([\"p\",i,\"+=d\",i,\"s\",n].join(\"\"));s&&(n>0&&l.push([\"index[\",h,\"]-=s\",h].join(\"\")),l.push([\"++index[\",u,\"]\"].join(\"\"))),l.push(\"}\")}return l.join(\"\\n\")}function a(t,e,r){for(var n=t.body,i=[],a=[],o=0;o<t.args.length;++o){var s=t.args[o];if(!(s.count<=0)){var l=new RegExp(s.name,\"g\"),c=\"\",u=e.arrayArgs.indexOf(o);switch(e.argTypes[o]){case\"offset\":var h=e.offsetArgIndex.indexOf(o);u=e.offsetArgs[h].array,c=\"+q\"+h;case\"array\":c=\"p\"+u+c;var f=\"l\"+o,p=\"a\"+u;if(0===e.arrayBlockIndices[u])1===s.count?\"generic\"===r[u]?s.lvalue?(i.push([\"var \",f,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,f),a.push([p,\".set(\",c,\",\",f,\")\"].join(\"\"))):n=n.replace(l,[p,\".get(\",c,\")\"].join(\"\")):n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\")):\"generic\"===r[u]?(i.push([\"var \",f,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,f),s.lvalue&&a.push([p,\".set(\",c,\",\",f,\")\"].join(\"\"))):(i.push([\"var \",f,\"=\",p,\"[\",c,\"]\"].join(\"\")),n=n.replace(l,f),s.lvalue&&a.push([p,\"[\",c,\"]=\",f].join(\"\")));else{for(var d=[s.name],g=[c],v=0;v<Math.abs(e.arrayBlockIndices[u]);v++)d.push(\"\\\\s*\\\\[([^\\\\]]+)\\\\]\"),g.push(\"$\"+(v+1)+\"*t\"+u+\"b\"+v);if(l=new RegExp(d.join(\"\"),\"g\"),c=g.join(\"+\"),\"generic\"===r[u])throw new Error(\"cwise: Generic arrays not supported in combination with blocks!\");n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\"))}break;case\"scalar\":n=n.replace(l,\"Y\"+e.scalarArgs.indexOf(o));break;case\"index\":n=n.replace(l,\"index\");break;case\"shape\":n=n.replace(l,\"shape\")}}}return[i.join(\"\\n\"),n,a.join(\"\\n\")].join(\"\\n\").trim()}e.exports=function(t,e){for(var r=e[1].length-Math.abs(t.arrayBlockIndices[0])|0,o=new Array(t.arrayArgs.length),s=new Array(t.arrayArgs.length),l=0;l<t.arrayArgs.length;++l)s[l]=e[2*l],o[l]=e[2*l+1];var c=[],u=[],h=[],f=[],p=[];for(l=0;l<t.arrayArgs.length;++l){t.arrayBlockIndices[l]<0?(h.push(0),f.push(r),c.push(r),u.push(r+t.arrayBlockIndices[l])):(h.push(t.arrayBlockIndices[l]),f.push(t.arrayBlockIndices[l]+r),c.push(0),u.push(t.arrayBlockIndices[l]));for(var d=[],g=0;g<o[l].length;g++)h[l]<=o[l][g]&&o[l][g]<f[l]&&d.push(o[l][g]-h[l]);p.push(d)}var v=[\"SS\"],m=[\"'use strict'\"],y=[];for(g=0;g<r;++g)y.push([\"s\",g,\"=SS[\",g,\"]\"].join(\"\"));for(l=0;l<t.arrayArgs.length;++l){for(v.push(\"a\"+l),v.push(\"t\"+l),v.push(\"p\"+l),g=0;g<r;++g)y.push([\"t\",l,\"p\",g,\"=t\",l,\"[\",h[l]+g,\"]\"].join(\"\"));for(g=0;g<Math.abs(t.arrayBlockIndices[l]);++g)y.push([\"t\",l,\"b\",g,\"=t\",l,\"[\",c[l]+g,\"]\"].join(\"\"))}for(l=0;l<t.scalarArgs.length;++l)v.push(\"Y\"+l);if(t.shapeArgs.length>0&&y.push(\"shape=SS.slice(0)\"),t.indexArgs.length>0){var x=new Array(r);for(l=0;l<r;++l)x[l]=\"0\";y.push([\"index=[\",x.join(\",\"),\"]\"].join(\"\"))}for(l=0;l<t.offsetArgs.length;++l){var b=t.offsetArgs[l],_=[];for(g=0;g<b.offset.length;++g)0!==b.offset[g]&&(1===b.offset[g]?_.push([\"t\",b.array,\"p\",g].join(\"\")):_.push([b.offset[g],\"*t\",b.array,\"p\",g].join(\"\")));0===_.length?y.push(\"q\"+l+\"=0\"):y.push([\"q\",l,\"=\",_.join(\"+\")].join(\"\"))}var w=n([].concat(t.pre.thisVars).concat(t.body.thisVars).concat(t.post.thisVars));for((y=y.concat(w)).length>0&&m.push(\"var \"+y.join(\",\")),l=0;l<t.arrayArgs.length;++l)m.push(\"p\"+l+\"|=0\");t.pre.body.length>3&&m.push(a(t.pre,t,s));var k=a(t.body,t,s),T=function(t){for(var e=0,r=t[0].length;e<r;){for(var n=1;n<t.length;++n)if(t[n][e]!==t[0][e])return e;++e}return e}(p);T<r?m.push(function(t,e,r,n){for(var a=e.length,o=r.arrayArgs.length,s=r.blockSize,l=r.indexArgs.length>0,c=[],u=0;u<o;++u)c.push([\"var offset\",u,\"=p\",u].join(\"\"));for(u=t;u<a;++u)c.push([\"for(var j\"+u+\"=SS[\",e[u],\"]|0;j\",u,\">0;){\"].join(\"\")),c.push([\"if(j\",u,\"<\",s,\"){\"].join(\"\")),c.push([\"s\",e[u],\"=j\",u].join(\"\")),c.push([\"j\",u,\"=0\"].join(\"\")),c.push([\"}else{s\",e[u],\"=\",s].join(\"\")),c.push([\"j\",u,\"-=\",s,\"}\"].join(\"\")),l&&c.push([\"index[\",e[u],\"]=j\",u].join(\"\"));for(u=0;u<o;++u){for(var h=[\"offset\"+u],f=t;f<a;++f)h.push([\"j\",f,\"*t\",u,\"p\",e[f]].join(\"\"));c.push([\"p\",u,\"=(\",h.join(\"+\"),\")\"].join(\"\"))}for(c.push(i(e,r,n)),u=t;u<a;++u)c.push(\"}\");return c.join(\"\\n\")}(T,p[0],t,k)):m.push(i(p[0],t,k)),t.post.body.length>3&&m.push(a(t.post,t,s)),t.debug&&console.log(\"-----Generated cwise routine for \",e,\":\\n\"+m.join(\"\\n\")+\"\\n----------\");var A=[t.funcName||\"unnamed\",\"_cwise_loop_\",o[0].join(\"s\"),\"m\",T,function(t){for(var e=new Array(t.length),r=!0,n=0;n<t.length;++n){var i=t[n],a=i.match(/\\d+/);a=a?a[0]:\"\",0===i.charAt(0)?e[n]=\"u\"+i.charAt(1)+a:e[n]=i.charAt(0)+a,n>0&&(r=r&&e[n]===e[n-1])}return r?e[0]:e.join(\"\")}(s)].join(\"\");return new Function([\"function \",A,\"(\",v.join(\",\"),\"){\",m.join(\"\\n\"),\"} return \",A].join(\"\"))()}},{uniq:547}],148:[function(t,e,r){\"use strict\";var n=t(\"./compile.js\");e.exports=function(t){var e=[\"'use strict'\",\"var CACHED={}\"],r=[],i=t.funcName+\"_cwise_thunk\";e.push([\"return function \",i,\"(\",t.shimArgs.join(\",\"),\"){\"].join(\"\"));for(var a=[],o=[],s=[[\"array\",t.arrayArgs[0],\".shape.slice(\",Math.max(0,t.arrayBlockIndices[0]),t.arrayBlockIndices[0]<0?\",\"+t.arrayBlockIndices[0]+\")\":\")\"].join(\"\")],l=[],c=[],u=0;u<t.arrayArgs.length;++u){var h=t.arrayArgs[u];r.push([\"t\",h,\"=array\",h,\".dtype,\",\"r\",h,\"=array\",h,\".order\"].join(\"\")),a.push(\"t\"+h),a.push(\"r\"+h),o.push(\"t\"+h),o.push(\"r\"+h+\".join()\"),s.push(\"array\"+h+\".data\"),s.push(\"array\"+h+\".stride\"),s.push(\"array\"+h+\".offset|0\"),u>0&&(l.push(\"array\"+t.arrayArgs[0]+\".shape.length===array\"+h+\".shape.length+\"+(Math.abs(t.arrayBlockIndices[0])-Math.abs(t.arrayBlockIndices[u]))),c.push(\"array\"+t.arrayArgs[0]+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[0])+\"]===array\"+h+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[u])+\"]\"))}for(t.arrayArgs.length>1&&(e.push(\"if (!(\"+l.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same dimensionality!')\"),e.push(\"for(var shapeIndex=array\"+t.arrayArgs[0]+\".shape.length-\"+Math.abs(t.arrayBlockIndices[0])+\"; shapeIndex--\\x3e0;) {\"),e.push(\"if (!(\"+c.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same shape!')\"),e.push(\"}\")),u=0;u<t.scalarArgs.length;++u)s.push(\"scalar\"+t.scalarArgs[u]);return r.push([\"type=[\",o.join(\",\"),\"].join()\"].join(\"\")),r.push(\"proc=CACHED[type]\"),e.push(\"var \"+r.join(\",\")),e.push([\"if(!proc){\",\"CACHED[type]=proc=compile([\",a.join(\",\"),\"])}\",\"return proc(\",s.join(\",\"),\")}\"].join(\"\")),t.debug&&console.log(\"-----Generated thunk:\\n\"+e.join(\"\\n\")+\"\\n----------\"),new Function(\"compile\",e.join(\"\\n\"))(n.bind(void 0,t))}},{\"./compile.js\":147}],149:[function(t,e,r){e.exports=t(\"cwise-compiler\")},{\"cwise-compiler\":146}],150:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/copy\"),a=t(\"es5-ext/object/normalize-options\"),o=t(\"es5-ext/object/valid-callable\"),s=t(\"es5-ext/object/map\"),l=t(\"es5-ext/object/valid-callable\"),c=t(\"es5-ext/object/valid-value\"),u=Function.prototype.bind,h=Object.defineProperty,f=Object.prototype.hasOwnProperty;n=function(t,e,r){var n,a=c(e)&&l(e.value);return delete(n=i(e)).writable,delete n.value,n.get=function(){return!r.overwriteDefinition&&f.call(this,t)?a:(e.value=u.call(a,r.resolveContext?r.resolveContext(this):this),h(this,t,e),this[t])},n},e.exports=function(t){var e=a(arguments[1]);return null!=e.resolveContext&&o(e.resolveContext),s(t,function(t,r){return n(r,t,e)})}},{\"es5-ext/object/copy\":189,\"es5-ext/object/map\":198,\"es5-ext/object/normalize-options\":199,\"es5-ext/object/valid-callable\":203,\"es5-ext/object/valid-value\":205}],151:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/object/assign\"),i=t(\"es5-ext/object/normalize-options\"),a=t(\"es5-ext/object/is-callable\"),o=t(\"es5-ext/string/#/contains\");(e.exports=function(t,e){var r,a,s,l,c;return arguments.length<2||\"string\"!=typeof t?(l=e,e=t,t=null):l=arguments[2],null==t?(r=s=!0,a=!1):(r=o.call(t,\"c\"),a=o.call(t,\"e\"),s=o.call(t,\"w\")),c={value:e,configurable:r,enumerable:a,writable:s},l?n(i(l),c):c}).gs=function(t,e,r){var s,l,c,u;return\"string\"!=typeof t?(c=r,r=e,e=t,t=null):c=arguments[3],null==e?e=void 0:a(e)?null==r?r=void 0:a(r)||(c=r,r=void 0):(c=e,e=r=void 0),null==t?(s=!0,l=!1):(s=o.call(t,\"c\"),l=o.call(t,\"e\")),u={get:e,set:r,configurable:s,enumerable:l},c?n(i(c),u):u}},{\"es5-ext/object/assign\":186,\"es5-ext/object/is-callable\":192,\"es5-ext/object/normalize-options\":199,\"es5-ext/string/#/contains\":206}],152:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function r(t){var r;return 1===t.length&&(r=t,t=function(t,n){return e(r(t),n)}),{left:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}var n=r(e),i=n.right,a=n.left;function o(t,e){return[t,e]}function s(t){return null===t?NaN:+t}function l(t,e){var r,n,i=t.length,a=0,o=-1,l=0,c=0;if(null==e)for(;++o<i;)isNaN(r=s(t[o]))||(c+=(n=r-l)*(r-(l+=n/++a)));else for(;++o<i;)isNaN(r=s(e(t[o],o,t)))||(c+=(n=r-l)*(r-(l+=n/++a)));if(a>1)return c/(a-1)}function c(t,e){var r=l(t,e);return r?Math.sqrt(r):r}function u(t,e){var r,n,i,a=t.length,o=-1;if(null==e){for(;++o<a;)if(null!=(r=t[o])&&r>=r)for(n=i=r;++o<a;)null!=(r=t[o])&&(n>r&&(n=r),i<r&&(i=r))}else for(;++o<a;)if(null!=(r=e(t[o],o,t))&&r>=r)for(n=i=r;++o<a;)null!=(r=e(t[o],o,t))&&(n>r&&(n=r),i<r&&(i=r));return[n,i]}var h=Array.prototype,f=h.slice,p=h.map;function d(t){return function(){return t}}function g(t){return t}function v(t,e,r){t=+t,e=+e,r=(i=arguments.length)<2?(e=t,t=0,1):i<3?1:+r;for(var n=-1,i=0|Math.max(0,Math.ceil((e-t)/r)),a=new Array(i);++n<i;)a[n]=t+n*r;return a}var m=Math.sqrt(50),y=Math.sqrt(10),x=Math.sqrt(2);function b(t,e,r){var n=(e-t)/Math.max(0,r),i=Math.floor(Math.log(n)/Math.LN10),a=n/Math.pow(10,i);return i>=0?(a>=m?10:a>=y?5:a>=x?2:1)*Math.pow(10,i):-Math.pow(10,-i)/(a>=m?10:a>=y?5:a>=x?2:1)}function _(t,e,r){var n=Math.abs(e-t)/Math.max(0,r),i=Math.pow(10,Math.floor(Math.log(n)/Math.LN10)),a=n/i;return a>=m?i*=10:a>=y?i*=5:a>=x&&(i*=2),e<t?-i:i}function w(t){return Math.ceil(Math.log(t.length)/Math.LN2)+1}function k(t,e,r){if(null==r&&(r=s),n=t.length){if((e=+e)<=0||n<2)return+r(t[0],0,t);if(e>=1)return+r(t[n-1],n-1,t);var n,i=(n-1)*e,a=Math.floor(i),o=+r(t[a],a,t);return o+(+r(t[a+1],a+1,t)-o)*(i-a)}}function T(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&n>r&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&n>r&&(n=r);return n}function A(t){if(!(i=t.length))return[];for(var e=-1,r=T(t,M),n=new Array(r);++e<r;)for(var i,a=-1,o=n[e]=new Array(i);++a<i;)o[a]=t[a][e];return n}function M(t){return t.length}t.bisect=i,t.bisectRight=i,t.bisectLeft=a,t.ascending=e,t.bisector=r,t.cross=function(t,e,r){var n,i,a,s,l=t.length,c=e.length,u=new Array(l*c);for(null==r&&(r=o),n=a=0;n<l;++n)for(s=t[n],i=0;i<c;++i,++a)u[a]=r(s,e[i]);return u},t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.deviation=c,t.extent=u,t.histogram=function(){var t=g,e=u,r=w;function n(n){var a,o,s=n.length,l=new Array(s);for(a=0;a<s;++a)l[a]=t(n[a],a,n);var c=e(l),u=c[0],h=c[1],f=r(l,u,h);Array.isArray(f)||(f=_(u,h,f),f=v(Math.ceil(u/f)*f,h,f));for(var p=f.length;f[0]<=u;)f.shift(),--p;for(;f[p-1]>h;)f.pop(),--p;var d,g=new Array(p+1);for(a=0;a<=p;++a)(d=g[a]=[]).x0=a>0?f[a-1]:u,d.x1=a<p?f[a]:h;for(a=0;a<s;++a)u<=(o=l[a])&&o<=h&&g[i(f,o,0,p)].push(n[a]);return g}return n.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:d(e),n):t},n.domain=function(t){return arguments.length?(e=\"function\"==typeof t?t:d([t[0],t[1]]),n):e},n.thresholds=function(t){return arguments.length?(r=\"function\"==typeof t?t:Array.isArray(t)?d(f.call(t)):d(t),n):r},n},t.thresholdFreedmanDiaconis=function(t,r,n){return t=p.call(t,s).sort(e),Math.ceil((n-r)/(2*(k(t,.75)-k(t,.25))*Math.pow(t.length,-1/3)))},t.thresholdScott=function(t,e,r){return Math.ceil((r-e)/(3.5*c(t)*Math.pow(t.length,-1/3)))},t.thresholdSturges=w,t.max=function(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&r>n&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&r>n&&(n=r);return n},t.mean=function(t,e){var r,n=t.length,i=n,a=-1,o=0;if(null==e)for(;++a<n;)isNaN(r=s(t[a]))?--i:o+=r;else for(;++a<n;)isNaN(r=s(e(t[a],a,t)))?--i:o+=r;if(i)return o/i},t.median=function(t,r){var n,i=t.length,a=-1,o=[];if(null==r)for(;++a<i;)isNaN(n=s(t[a]))||o.push(n);else for(;++a<i;)isNaN(n=s(r(t[a],a,t)))||o.push(n);return k(o.sort(e),.5)},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r},t.min=T,t.pairs=function(t,e){null==e&&(e=o);for(var r=0,n=t.length-1,i=t[0],a=new Array(n<0?0:n);r<n;)a[r]=e(i,i=t[++r]);return a},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.quantile=k,t.range=v,t.scan=function(t,r){if(n=t.length){var n,i,a=0,o=0,s=t[o];for(null==r&&(r=e);++a<n;)(r(i=t[a],s)<0||0!==r(s,s))&&(s=i,o=a);return 0===r(s,s)?o:void 0}},t.shuffle=function(t,e,r){for(var n,i,a=(null==r?t.length:r)-(e=null==e?0:+e);a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.sum=function(t,e){var r,n=t.length,i=-1,a=0;if(null==e)for(;++i<n;)(r=+t[i])&&(a+=r);else for(;++i<n;)(r=+e(t[i],i,t))&&(a+=r);return a},t.ticks=function(t,e,r){var n,i,a,o,s=-1;if(r=+r,(t=+t)==(e=+e)&&r>0)return[t];if((n=e<t)&&(i=t,t=e,e=i),0===(o=b(t,e,r))||!isFinite(o))return[];if(o>0)for(t=Math.ceil(t/o),e=Math.floor(e/o),a=new Array(i=Math.ceil(e-t+1));++s<i;)a[s]=(t+s)*o;else for(t=Math.floor(t*o),e=Math.ceil(e*o),a=new Array(i=Math.ceil(t-e+1));++s<i;)a[s]=(t-s)/o;return n&&a.reverse(),a},t.tickIncrement=b,t.tickStep=_,t.transpose=A,t.variance=l,t.zip=function(){return A(arguments)},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],153:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(){}function r(t,r){var n=new e;if(t instanceof e)t.each(function(t,e){n.set(e,t)});else if(Array.isArray(t)){var i,a=-1,o=t.length;if(null==r)for(;++a<o;)n.set(a,t[a]);else for(;++a<o;)n.set(r(i=t[a],a,t),i)}else if(t)for(var s in t)n.set(s,t[s]);return n}e.prototype=r.prototype={constructor:e,has:function(t){return\"$\"+t in this},get:function(t){return this[\"$\"+t]},set:function(t,e){return this[\"$\"+t]=e,this},remove:function(t){var e=\"$\"+t;return e in this&&delete this[e]},clear:function(){for(var t in this)\"$\"===t[0]&&delete this[t]},keys:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(e.slice(1));return t},values:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(this[e]);return t},entries:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push({key:e.slice(1),value:this[e]});return t},size:function(){var t=0;for(var e in this)\"$\"===e[0]&&++t;return t},empty:function(){for(var t in this)if(\"$\"===t[0])return!1;return!0},each:function(t){for(var e in this)\"$\"===e[0]&&t(this[e],e.slice(1),this)}};function n(){return{}}function i(t,e,r){t[e]=r}function a(){return r()}function o(t,e,r){t.set(e,r)}function s(){}var l=r.prototype;function c(t,e){var r=new s;if(t instanceof s)t.each(function(t){r.add(t)});else if(t){var n=-1,i=t.length;if(null==e)for(;++n<i;)r.add(t[n]);else for(;++n<i;)r.add(e(t[n],n,t))}return r}s.prototype=c.prototype={constructor:s,has:l.has,add:function(t){return this[\"$\"+(t+=\"\")]=t,this},remove:l.remove,clear:l.clear,values:l.keys,size:l.size,empty:l.empty,each:l.each};t.nest=function(){var t,e,s,l=[],c=[];function u(n,i,a,o){if(i>=l.length)return null!=t&&n.sort(t),null!=e?e(n):n;for(var s,c,h,f=-1,p=n.length,d=l[i++],g=r(),v=a();++f<p;)(h=g.get(s=d(c=n[f])+\"\"))?h.push(c):g.set(s,[c]);return g.each(function(t,e){o(v,e,u(t,i,a,o))}),v}return s={object:function(t){return u(t,0,n,i)},map:function(t){return u(t,0,a,o)},entries:function(t){return function t(r,n){if(++n>l.length)return r;var i,a=c[n-1];return null!=e&&n>=l.length?i=r.entries():(i=[],r.each(function(e,r){i.push({key:r,values:t(e,n)})})),null!=a?i.sort(function(t,e){return a(t.key,e.key)}):i}(u(t,0,a,o),0)},key:function(t){return l.push(t),s},sortKeys:function(t){return c[l.length-1]=t,s},sortValues:function(e){return t=e,s},rollup:function(t){return e=t,s}}},t.set=c,t.map=r,t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],154:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e,r){t.prototype=e.prototype=r,r.constructor=t}function r(t,e){var r=Object.create(t.prototype);for(var n in e)r[n]=e[n];return r}function n(){}var i=\"\\\\s*([+-]?\\\\d+)\\\\s*\",a=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)\\\\s*\",o=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)%\\\\s*\",s=/^#([0-9a-f]{3})$/,l=/^#([0-9a-f]{6})$/,c=new RegExp(\"^rgb\\\\(\"+[i,i,i]+\"\\\\)$\"),u=new RegExp(\"^rgb\\\\(\"+[o,o,o]+\"\\\\)$\"),h=new RegExp(\"^rgba\\\\(\"+[i,i,i,a]+\"\\\\)$\"),f=new RegExp(\"^rgba\\\\(\"+[o,o,o,a]+\"\\\\)$\"),p=new RegExp(\"^hsl\\\\(\"+[a,o,o]+\"\\\\)$\"),d=new RegExp(\"^hsla\\\\(\"+[a,o,o,a]+\"\\\\)$\"),g={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};function v(t){var e;return t=(t+\"\").trim().toLowerCase(),(e=s.exec(t))?new _((e=parseInt(e[1],16))>>8&15|e>>4&240,e>>4&15|240&e,(15&e)<<4|15&e,1):(e=l.exec(t))?m(parseInt(e[1],16)):(e=c.exec(t))?new _(e[1],e[2],e[3],1):(e=u.exec(t))?new _(255*e[1]/100,255*e[2]/100,255*e[3]/100,1):(e=h.exec(t))?y(e[1],e[2],e[3],e[4]):(e=f.exec(t))?y(255*e[1]/100,255*e[2]/100,255*e[3]/100,e[4]):(e=p.exec(t))?k(e[1],e[2]/100,e[3]/100,1):(e=d.exec(t))?k(e[1],e[2]/100,e[3]/100,e[4]):g.hasOwnProperty(t)?m(g[t]):\"transparent\"===t?new _(NaN,NaN,NaN,0):null}function m(t){return new _(t>>16&255,t>>8&255,255&t,1)}function y(t,e,r,n){return n<=0&&(t=e=r=NaN),new _(t,e,r,n)}function x(t){return t instanceof n||(t=v(t)),t?new _((t=t.rgb()).r,t.g,t.b,t.opacity):new _}function b(t,e,r,n){return 1===arguments.length?x(t):new _(t,e,r,null==n?1:n)}function _(t,e,r,n){this.r=+t,this.g=+e,this.b=+r,this.opacity=+n}function w(t){return((t=Math.max(0,Math.min(255,Math.round(t)||0)))<16?\"0\":\"\")+t.toString(16)}function k(t,e,r,n){return n<=0?t=e=r=NaN:r<=0||r>=1?t=e=NaN:e<=0&&(t=NaN),new A(t,e,r,n)}function T(t,e,r,i){return 1===arguments.length?function(t){if(t instanceof A)return new A(t.h,t.s,t.l,t.opacity);if(t instanceof n||(t=v(t)),!t)return new A;if(t instanceof A)return t;var e=(t=t.rgb()).r/255,r=t.g/255,i=t.b/255,a=Math.min(e,r,i),o=Math.max(e,r,i),s=NaN,l=o-a,c=(o+a)/2;return l?(s=e===o?(r-i)/l+6*(r<i):r===o?(i-e)/l+2:(e-r)/l+4,l/=c<.5?o+a:2-o-a,s*=60):l=c>0&&c<1?0:s,new A(s,l,c,t.opacity)}(t):new A(t,e,r,null==i?1:i)}function A(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}function M(t,e,r){return 255*(t<60?e+(r-e)*t/60:t<180?r:t<240?e+(r-e)*(240-t)/60:e)}e(n,v,{displayable:function(){return this.rgb().displayable()},hex:function(){return this.rgb().hex()},toString:function(){return this.rgb()+\"\"}}),e(_,b,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new _(this.r*t,this.g*t,this.b*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new _(this.r*t,this.g*t,this.b*t,this.opacity)},rgb:function(){return this},displayable:function(){return 0<=this.r&&this.r<=255&&0<=this.g&&this.g<=255&&0<=this.b&&this.b<=255&&0<=this.opacity&&this.opacity<=1},hex:function(){return\"#\"+w(this.r)+w(this.g)+w(this.b)},toString:function(){var t=this.opacity;return(1===(t=isNaN(t)?1:Math.max(0,Math.min(1,t)))?\"rgb(\":\"rgba(\")+Math.max(0,Math.min(255,Math.round(this.r)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.g)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.b)||0))+(1===t?\")\":\", \"+t+\")\")}})),e(A,T,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new A(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new A(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=this.h%360+360*(this.h<0),e=isNaN(t)||isNaN(this.s)?0:this.s,r=this.l,n=r+(r<.5?r:1-r)*e,i=2*r-n;return new _(M(t>=240?t-240:t+120,i,n),M(t,i,n),M(t<120?t+240:t-120,i,n),this.opacity)},displayable:function(){return(0<=this.s&&this.s<=1||isNaN(this.s))&&0<=this.l&&this.l<=1&&0<=this.opacity&&this.opacity<=1}}));var S=Math.PI/180,E=180/Math.PI,C=.96422,L=1,P=.82521,O=4/29,z=6/29,I=3*z*z,D=z*z*z;function R(t){if(t instanceof B)return new B(t.l,t.a,t.b,t.opacity);if(t instanceof G){if(isNaN(t.h))return new B(t.l,0,0,t.opacity);var e=t.h*S;return new B(t.l,Math.cos(e)*t.c,Math.sin(e)*t.c,t.opacity)}t instanceof _||(t=x(t));var r,n,i=V(t.r),a=V(t.g),o=V(t.b),s=N((.2225045*i+.7168786*a+.0606169*o)/L);return i===a&&a===o?r=n=s:(r=N((.4360747*i+.3850649*a+.1430804*o)/C),n=N((.0139322*i+.0971045*a+.7141733*o)/P)),new B(116*s-16,500*(r-s),200*(s-n),t.opacity)}function F(t,e,r,n){return 1===arguments.length?R(t):new B(t,e,r,null==n?1:n)}function B(t,e,r,n){this.l=+t,this.a=+e,this.b=+r,this.opacity=+n}function N(t){return t>D?Math.pow(t,1/3):t/I+O}function j(t){return t>z?t*t*t:I*(t-O)}function U(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function V(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function q(t){if(t instanceof G)return new G(t.h,t.c,t.l,t.opacity);if(t instanceof B||(t=R(t)),0===t.a&&0===t.b)return new G(NaN,0,t.l,t.opacity);var e=Math.atan2(t.b,t.a)*E;return new G(e<0?e+360:e,Math.sqrt(t.a*t.a+t.b*t.b),t.l,t.opacity)}function H(t,e,r,n){return 1===arguments.length?q(t):new G(t,e,r,null==n?1:n)}function G(t,e,r,n){this.h=+t,this.c=+e,this.l=+r,this.opacity=+n}e(B,F,r(n,{brighter:function(t){return new B(this.l+18*(null==t?1:t),this.a,this.b,this.opacity)},darker:function(t){return new B(this.l-18*(null==t?1:t),this.a,this.b,this.opacity)},rgb:function(){var t=(this.l+16)/116,e=isNaN(this.a)?t:t+this.a/500,r=isNaN(this.b)?t:t-this.b/200;return new _(U(3.1338561*(e=C*j(e))-1.6168667*(t=L*j(t))-.4906146*(r=P*j(r))),U(-.9787684*e+1.9161415*t+.033454*r),U(.0719453*e-.2289914*t+1.4052427*r),this.opacity)}})),e(G,H,r(n,{brighter:function(t){return new G(this.h,this.c,this.l+18*(null==t?1:t),this.opacity)},darker:function(t){return new G(this.h,this.c,this.l-18*(null==t?1:t),this.opacity)},rgb:function(){return R(this).rgb()}}));var Y=-.14861,W=1.78277,X=-.29227,Z=-.90649,J=1.97294,K=J*Z,$=J*W,Q=W*X-Z*Y;function tt(t,e,r,n){return 1===arguments.length?function(t){if(t instanceof et)return new et(t.h,t.s,t.l,t.opacity);t instanceof _||(t=x(t));var e=t.r/255,r=t.g/255,n=t.b/255,i=(Q*n+K*e-$*r)/(Q+K-$),a=n-i,o=(J*(r-i)-X*a)/Z,s=Math.sqrt(o*o+a*a)/(J*i*(1-i)),l=s?Math.atan2(o,a)*E-120:NaN;return new et(l<0?l+360:l,s,i,t.opacity)}(t):new et(t,e,r,null==n?1:n)}function et(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}e(et,tt,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new et(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new et(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=isNaN(this.h)?0:(this.h+120)*S,e=+this.l,r=isNaN(this.s)?0:this.s*e*(1-e),n=Math.cos(t),i=Math.sin(t);return new _(255*(e+r*(Y*n+W*i)),255*(e+r*(X*n+Z*i)),255*(e+r*(J*n)),this.opacity)}})),t.color=v,t.rgb=b,t.hsl=T,t.lab=F,t.hcl=H,t.lch=function(t,e,r,n){return 1===arguments.length?q(t):new G(r,e,t,null==n?1:n)},t.gray=function(t,e){return new B(t,0,0,null==e?1:e)},t.cubehelix=tt,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],155:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e={value:function(){}};function r(){for(var t,e=0,r=arguments.length,i={};e<r;++e){if(!(t=arguments[e]+\"\")||t in i)throw new Error(\"illegal type: \"+t);i[t]=[]}return new n(i)}function n(t){this._=t}function i(t,e){for(var r,n=0,i=t.length;n<i;++n)if((r=t[n]).name===e)return r.value}function a(t,r,n){for(var i=0,a=t.length;i<a;++i)if(t[i].name===r){t[i]=e,t=t.slice(0,i).concat(t.slice(i+1));break}return null!=n&&t.push({name:r,value:n}),t}n.prototype=r.prototype={constructor:n,on:function(t,e){var r,n,o=this._,s=(n=o,(t+\"\").trim().split(/^|\\s+/).map(function(t){var e=\"\",r=t.indexOf(\".\");if(r>=0&&(e=t.slice(r+1),t=t.slice(0,r)),t&&!n.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);return{type:t,name:e}})),l=-1,c=s.length;if(!(arguments.length<2)){if(null!=e&&\"function\"!=typeof e)throw new Error(\"invalid callback: \"+e);for(;++l<c;)if(r=(t=s[l]).type)o[r]=a(o[r],t.name,e);else if(null==e)for(r in o)o[r]=a(o[r],t.name,null);return this}for(;++l<c;)if((r=(t=s[l]).type)&&(r=i(o[r],t.name)))return r},copy:function(){var t={},e=this._;for(var r in e)t[r]=e[r].slice();return new n(t)},call:function(t,e){if((r=arguments.length-2)>0)for(var r,n,i=new Array(r),a=0;a<r;++a)i[a]=arguments[a+2];if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(a=0,r=(n=this._[t]).length;a<r;++a)n[a].value.apply(e,i)},apply:function(t,e,r){if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(var n=this._[t],i=0,a=n.length;i<a;++i)n[i].value.apply(e,r)}},t.dispatch=r,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],156:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n,i){\"use strict\";var a=function(t){return function(){return t}},o=function(){return 1e-6*(Math.random()-.5)};function s(t){return t.x+t.vx}function l(t){return t.y+t.vy}function c(t){return t.index}function u(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function h(t){return t.x}function f(t){return t.y}var p=10,d=Math.PI*(3-Math.sqrt(5));t.forceCenter=function(t,e){var r;function n(){var n,i,a=r.length,o=0,s=0;for(n=0;n<a;++n)o+=(i=r[n]).x,s+=i.y;for(o=o/a-t,s=s/a-e,n=0;n<a;++n)(i=r[n]).x-=o,i.y-=s}return null==t&&(t=0),null==e&&(e=0),n.initialize=function(t){r=t},n.x=function(e){return arguments.length?(t=+e,n):t},n.y=function(t){return arguments.length?(e=+t,n):e},n},t.forceCollide=function(t){var r,n,i=1,c=1;function u(){for(var t,a,u,f,p,d,g,v=r.length,m=0;m<c;++m)for(a=e.quadtree(r,s,l).visitAfter(h),t=0;t<v;++t)u=r[t],d=n[u.index],g=d*d,f=u.x+u.vx,p=u.y+u.vy,a.visit(y);function y(t,e,r,n,a){var s=t.data,l=t.r,c=d+l;if(!s)return e>f+c||n<f-c||r>p+c||a<p-c;if(s.index>u.index){var h=f-s.x-s.vx,v=p-s.y-s.vy,m=h*h+v*v;m<c*c&&(0===h&&(m+=(h=o())*h),0===v&&(m+=(v=o())*v),m=(c-(m=Math.sqrt(m)))/m*i,u.vx+=(h*=m)*(c=(l*=l)/(g+l)),u.vy+=(v*=m)*c,s.vx-=h*(c=1-c),s.vy-=v*c)}}}function h(t){if(t.data)return t.r=n[t.data.index];for(var e=t.r=0;e<4;++e)t[e]&&t[e].r>t.r&&(t.r=t[e].r)}function f(){if(r){var e,i,a=r.length;for(n=new Array(a),e=0;e<a;++e)i=r[e],n[i.index]=+t(i,e,r)}}return\"function\"!=typeof t&&(t=a(null==t?1:+t)),u.initialize=function(t){r=t,f()},u.iterations=function(t){return arguments.length?(c=+t,u):c},u.strength=function(t){return arguments.length?(i=+t,u):i},u.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),f(),u):t},u},t.forceLink=function(t){var e,n,i,s,l,h=c,f=function(t){return 1/Math.min(s[t.source.index],s[t.target.index])},p=a(30),d=1;function g(r){for(var i=0,a=t.length;i<d;++i)for(var s,c,u,h,f,p,g,v=0;v<a;++v)c=(s=t[v]).source,h=(u=s.target).x+u.vx-c.x-c.vx||o(),f=u.y+u.vy-c.y-c.vy||o(),h*=p=((p=Math.sqrt(h*h+f*f))-n[v])/p*r*e[v],f*=p,u.vx-=h*(g=l[v]),u.vy-=f*g,c.vx+=h*(g=1-g),c.vy+=f*g}function v(){if(i){var a,o,c=i.length,f=t.length,p=r.map(i,h);for(a=0,s=new Array(c);a<f;++a)(o=t[a]).index=a,\"object\"!=typeof o.source&&(o.source=u(p,o.source)),\"object\"!=typeof o.target&&(o.target=u(p,o.target)),s[o.source.index]=(s[o.source.index]||0)+1,s[o.target.index]=(s[o.target.index]||0)+1;for(a=0,l=new Array(f);a<f;++a)o=t[a],l[a]=s[o.source.index]/(s[o.source.index]+s[o.target.index]);e=new Array(f),m(),n=new Array(f),y()}}function m(){if(i)for(var r=0,n=t.length;r<n;++r)e[r]=+f(t[r],r,t)}function y(){if(i)for(var e=0,r=t.length;e<r;++e)n[e]=+p(t[e],e,t)}return null==t&&(t=[]),g.initialize=function(t){i=t,v()},g.links=function(e){return arguments.length?(t=e,v(),g):t},g.id=function(t){return arguments.length?(h=t,g):h},g.iterations=function(t){return arguments.length?(d=+t,g):d},g.strength=function(t){return arguments.length?(f=\"function\"==typeof t?t:a(+t),m(),g):f},g.distance=function(t){return arguments.length?(p=\"function\"==typeof t?t:a(+t),y(),g):p},g},t.forceManyBody=function(){var t,r,n,i,s=a(-30),l=1,c=1/0,u=.81;function p(i){var a,o=t.length,s=e.quadtree(t,h,f).visitAfter(g);for(n=i,a=0;a<o;++a)r=t[a],s.visit(v)}function d(){if(t){var e,r,n=t.length;for(i=new Array(n),e=0;e<n;++e)r=t[e],i[r.index]=+s(r,e,t)}}function g(t){var e,r,n,a,o,s=0,l=0;if(t.length){for(n=a=o=0;o<4;++o)(e=t[o])&&(r=Math.abs(e.value))&&(s+=e.value,l+=r,n+=r*e.x,a+=r*e.y);t.x=n/l,t.y=a/l}else{(e=t).x=e.data.x,e.y=e.data.y;do{s+=i[e.data.index]}while(e=e.next)}t.value=s}function v(t,e,a,s){if(!t.value)return!0;var h=t.x-r.x,f=t.y-r.y,p=s-e,d=h*h+f*f;if(p*p/u<d)return d<c&&(0===h&&(d+=(h=o())*h),0===f&&(d+=(f=o())*f),d<l&&(d=Math.sqrt(l*d)),r.vx+=h*t.value*n/d,r.vy+=f*t.value*n/d),!0;if(!(t.length||d>=c)){(t.data!==r||t.next)&&(0===h&&(d+=(h=o())*h),0===f&&(d+=(f=o())*f),d<l&&(d=Math.sqrt(l*d)));do{t.data!==r&&(p=i[t.data.index]*n/d,r.vx+=h*p,r.vy+=f*p)}while(t=t.next)}}return p.initialize=function(e){t=e,d()},p.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),d(),p):s},p.distanceMin=function(t){return arguments.length?(l=t*t,p):Math.sqrt(l)},p.distanceMax=function(t){return arguments.length?(c=t*t,p):Math.sqrt(c)},p.theta=function(t){return arguments.length?(u=t*t,p):Math.sqrt(u)},p},t.forceRadial=function(t,e,r){var n,i,o,s=a(.1);function l(t){for(var a=0,s=n.length;a<s;++a){var l=n[a],c=l.x-e||1e-6,u=l.y-r||1e-6,h=Math.sqrt(c*c+u*u),f=(o[a]-h)*i[a]*t/h;l.vx+=c*f,l.vy+=u*f}}function c(){if(n){var e,r=n.length;for(i=new Array(r),o=new Array(r),e=0;e<r;++e)o[e]=+t(n[e],e,n),i[e]=isNaN(o[e])?0:+s(n[e],e,n)}}return\"function\"!=typeof t&&(t=a(+t)),null==e&&(e=0),null==r&&(r=0),l.initialize=function(t){n=t,c()},l.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),c(),l):s},l.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),c(),l):t},l.x=function(t){return arguments.length?(e=+t,l):e},l.y=function(t){return arguments.length?(r=+t,l):r},l},t.forceSimulation=function(t){var e,a=1,o=.001,s=1-Math.pow(o,1/300),l=0,c=.6,u=r.map(),h=i.timer(g),f=n.dispatch(\"tick\",\"end\");function g(){v(),f.call(\"tick\",e),a<o&&(h.stop(),f.call(\"end\",e))}function v(){var e,r,n=t.length;for(a+=(l-a)*s,u.each(function(t){t(a)}),e=0;e<n;++e)null==(r=t[e]).fx?r.x+=r.vx*=c:(r.x=r.fx,r.vx=0),null==r.fy?r.y+=r.vy*=c:(r.y=r.fy,r.vy=0)}function m(){for(var e,r=0,n=t.length;r<n;++r){if((e=t[r]).index=r,isNaN(e.x)||isNaN(e.y)){var i=p*Math.sqrt(r),a=r*d;e.x=i*Math.cos(a),e.y=i*Math.sin(a)}(isNaN(e.vx)||isNaN(e.vy))&&(e.vx=e.vy=0)}}function y(e){return e.initialize&&e.initialize(t),e}return null==t&&(t=[]),m(),e={tick:v,restart:function(){return h.restart(g),e},stop:function(){return h.stop(),e},nodes:function(r){return arguments.length?(t=r,m(),u.each(y),e):t},alpha:function(t){return arguments.length?(a=+t,e):a},alphaMin:function(t){return arguments.length?(o=+t,e):o},alphaDecay:function(t){return arguments.length?(s=+t,e):+s},alphaTarget:function(t){return arguments.length?(l=+t,e):l},velocityDecay:function(t){return arguments.length?(c=1-t,e):1-c},force:function(t,r){return arguments.length>1?(null==r?u.remove(t):u.set(t,y(r)),e):u.get(t)},find:function(e,r,n){var i,a,o,s,l,c=0,u=t.length;for(null==n?n=1/0:n*=n,c=0;c<u;++c)(o=(i=e-(s=t[c]).x)*i+(a=r-s.y)*a)<n&&(l=s,n=o);return l},on:function(t,r){return arguments.length>1?(f.on(t,r),e):f.on(t)}}},t.forceX=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vx+=(n[a]-i.x)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},t.forceY=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vy+=(n[a]-i.y)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.y=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-quadtree\"),t(\"d3-collection\"),t(\"d3-dispatch\"),t(\"d3-timer\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,n.d3)},{\"d3-collection\":153,\"d3-dispatch\":155,\"d3-quadtree\":160,\"d3-timer\":162}],157:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e){return t.parent===e.parent?1:2}function r(t,e){return t+e.x}function n(t,e){return Math.max(t,e.y)}function i(t){var e=0,r=t.children,n=r&&r.length;if(n)for(;--n>=0;)e+=r[n].value;else e=1;t.value=e}function a(t,e){var r,n,i,a,s,u=new c(t),h=+t.value&&(u.value=t.value),f=[u];for(null==e&&(e=o);r=f.pop();)if(h&&(r.value=+r.data.value),(i=e(r.data))&&(s=i.length))for(r.children=new Array(s),a=s-1;a>=0;--a)f.push(n=r.children[a]=new c(i[a])),n.parent=r,n.depth=r.depth+1;return u.eachBefore(l)}function o(t){return t.children}function s(t){t.data=t.data.data}function l(t){var e=0;do{t.height=e}while((t=t.parent)&&t.height<++e)}function c(t){this.data=t,this.depth=this.height=0,this.parent=null}c.prototype=a.prototype={constructor:c,count:function(){return this.eachAfter(i)},each:function(t){var e,r,n,i,a=this,o=[a];do{for(e=o.reverse(),o=[];a=e.pop();)if(t(a),r=a.children)for(n=0,i=r.length;n<i;++n)o.push(r[n])}while(o.length);return this},eachAfter:function(t){for(var e,r,n,i=this,a=[i],o=[];i=a.pop();)if(o.push(i),e=i.children)for(r=0,n=e.length;r<n;++r)a.push(e[r]);for(;i=o.pop();)t(i);return this},eachBefore:function(t){for(var e,r,n=this,i=[n];n=i.pop();)if(t(n),e=n.children)for(r=e.length-1;r>=0;--r)i.push(e[r]);return this},sum:function(t){return this.eachAfter(function(e){for(var r=+t(e.data)||0,n=e.children,i=n&&n.length;--i>=0;)r+=n[i].value;e.value=r})},sort:function(t){return this.eachBefore(function(e){e.children&&e.children.sort(t)})},path:function(t){for(var e=this,r=function(t,e){if(t===e)return t;var r=t.ancestors(),n=e.ancestors(),i=null;for(t=r.pop(),e=n.pop();t===e;)i=t,t=r.pop(),e=n.pop();return i}(e,t),n=[e];e!==r;)e=e.parent,n.push(e);for(var i=n.length;t!==r;)n.splice(i,0,t),t=t.parent;return n},ancestors:function(){for(var t=this,e=[t];t=t.parent;)e.push(t);return e},descendants:function(){var t=[];return this.each(function(e){t.push(e)}),t},leaves:function(){var t=[];return this.eachBefore(function(e){e.children||t.push(e)}),t},links:function(){var t=this,e=[];return t.each(function(r){r!==t&&e.push({source:r.parent,target:r})}),e},copy:function(){return a(this).eachBefore(s)}};var u=Array.prototype.slice;function h(t){for(var e,r,n=0,i=(t=function(t){for(var e,r,n=t.length;n;)r=Math.random()*n--|0,e=t[n],t[n]=t[r],t[r]=e;return t}(u.call(t))).length,a=[];n<i;)e=t[n],r&&d(r,e)?++n:(r=v(a=f(a,e)),n=0);return r}function f(t,e){var r,n;if(g(e,t))return[e];for(r=0;r<t.length;++r)if(p(e,t[r])&&g(m(t[r],e),t))return[t[r],e];for(r=0;r<t.length-1;++r)for(n=r+1;n<t.length;++n)if(p(m(t[r],t[n]),e)&&p(m(t[r],e),t[n])&&p(m(t[n],e),t[r])&&g(y(t[r],t[n],e),t))return[t[r],t[n],e];throw new Error}function p(t,e){var r=t.r-e.r,n=e.x-t.x,i=e.y-t.y;return r<0||r*r<n*n+i*i}function d(t,e){var r=t.r-e.r+1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function g(t,e){for(var r=0;r<e.length;++r)if(!d(t,e[r]))return!1;return!0}function v(t){switch(t.length){case 1:return{x:(e=t[0]).x,y:e.y,r:e.r};case 2:return m(t[0],t[1]);case 3:return y(t[0],t[1],t[2])}var e}function m(t,e){var r=t.x,n=t.y,i=t.r,a=e.x,o=e.y,s=e.r,l=a-r,c=o-n,u=s-i,h=Math.sqrt(l*l+c*c);return{x:(r+a+l/h*u)/2,y:(n+o+c/h*u)/2,r:(h+i+s)/2}}function y(t,e,r){var n=t.x,i=t.y,a=t.r,o=e.x,s=e.y,l=e.r,c=r.x,u=r.y,h=r.r,f=n-o,p=n-c,d=i-s,g=i-u,v=l-a,m=h-a,y=n*n+i*i-a*a,x=y-o*o-s*s+l*l,b=y-c*c-u*u+h*h,_=p*d-f*g,w=(d*b-g*x)/(2*_)-n,k=(g*v-d*m)/_,T=(p*x-f*b)/(2*_)-i,A=(f*m-p*v)/_,M=k*k+A*A-1,S=2*(a+w*k+T*A),E=w*w+T*T-a*a,C=-(M?(S+Math.sqrt(S*S-4*M*E))/(2*M):E/S);return{x:n+w+k*C,y:i+T+A*C,r:C}}function x(t,e,r){var n,i,a,o,s=t.x-e.x,l=t.y-e.y,c=s*s+l*l;c?(i=e.r+r.r,i*=i,o=t.r+r.r,i>(o*=o)?(n=(c+o-i)/(2*c),a=Math.sqrt(Math.max(0,o/c-n*n)),r.x=t.x-n*s-a*l,r.y=t.y-n*l+a*s):(n=(c+i-o)/(2*c),a=Math.sqrt(Math.max(0,i/c-n*n)),r.x=e.x+n*s-a*l,r.y=e.y+n*l+a*s)):(r.x=e.x+r.r,r.y=e.y)}function b(t,e){var r=t.r+e.r-1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function _(t){var e=t._,r=t.next._,n=e.r+r.r,i=(e.x*r.r+r.x*e.r)/n,a=(e.y*r.r+r.y*e.r)/n;return i*i+a*a}function w(t){this._=t,this.next=null,this.previous=null}function k(t){if(!(i=t.length))return 0;var e,r,n,i,a,o,s,l,c,u,f;if((e=t[0]).x=0,e.y=0,!(i>1))return e.r;if(r=t[1],e.x=-r.r,r.x=e.r,r.y=0,!(i>2))return e.r+r.r;x(r,e,n=t[2]),e=new w(e),r=new w(r),n=new w(n),e.next=n.previous=r,r.next=e.previous=n,n.next=r.previous=e;t:for(s=3;s<i;++s){x(e._,r._,n=t[s]),n=new w(n),l=r.next,c=e.previous,u=r._.r,f=e._.r;do{if(u<=f){if(b(l._,n._)){r=l,e.next=r,r.previous=e,--s;continue t}u+=l._.r,l=l.next}else{if(b(c._,n._)){(e=c).next=r,r.previous=e,--s;continue t}f+=c._.r,c=c.previous}}while(l!==c.next);for(n.previous=e,n.next=r,e.next=r.previous=r=n,a=_(e);(n=n.next)!==r;)(o=_(n))<a&&(e=n,a=o);r=e.next}for(e=[r._],n=r;(n=n.next)!==r;)e.push(n._);for(n=h(e),s=0;s<i;++s)(e=t[s]).x-=n.x,e.y-=n.y;return n.r}function T(t){if(\"function\"!=typeof t)throw new Error;return t}function A(){return 0}function M(t){return function(){return t}}function S(t){return Math.sqrt(t.value)}function E(t){return function(e){e.children||(e.r=Math.max(0,+t(e)||0))}}function C(t,e){return function(r){if(n=r.children){var n,i,a,o=n.length,s=t(r)*e||0;if(s)for(i=0;i<o;++i)n[i].r+=s;if(a=k(n),s)for(i=0;i<o;++i)n[i].r-=s;r.r=a+s}}}function L(t){return function(e){var r=e.parent;e.r*=t,r&&(e.x=r.x+t*e.x,e.y=r.y+t*e.y)}}function P(t){t.x0=Math.round(t.x0),t.y0=Math.round(t.y0),t.x1=Math.round(t.x1),t.y1=Math.round(t.y1)}function O(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(n-e)/t.value;++s<l;)(a=o[s]).y0=r,a.y1=i,a.x0=e,a.x1=e+=a.value*c}var z=\"$\",I={depth:-1},D={};function R(t){return t.id}function F(t){return t.parentId}function B(t,e){return t.parent===e.parent?1:2}function N(t){var e=t.children;return e?e[0]:t.t}function j(t){var e=t.children;return e?e[e.length-1]:t.t}function U(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function V(t,e,r){return t.a.parent===e.parent?t.a:r}function q(t,e){this._=t,this.parent=null,this.children=null,this.A=null,this.a=this,this.z=0,this.m=0,this.c=0,this.s=0,this.t=null,this.i=e}function H(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(i-r)/t.value;++s<l;)(a=o[s]).x0=e,a.x1=n,a.y0=r,a.y1=r+=a.value*c}q.prototype=Object.create(c.prototype);var G=(1+Math.sqrt(5))/2;function Y(t,e,r,n,i,a){for(var o,s,l,c,u,h,f,p,d,g,v,m=[],y=e.children,x=0,b=0,_=y.length,w=e.value;x<_;){l=i-r,c=a-n;do{u=y[b++].value}while(!u&&b<_);for(h=f=u,v=u*u*(g=Math.max(c/l,l/c)/(w*t)),d=Math.max(f/v,v/h);b<_;++b){if(u+=s=y[b].value,s<h&&(h=s),s>f&&(f=s),v=u*u*g,(p=Math.max(f/v,v/h))>d){u-=s;break}d=p}m.push(o={value:u,dice:l<c,children:y.slice(x,b)}),o.dice?O(o,r,n,i,w?n+=c*u/w:a):H(o,r,n,w?r+=l*u/w:i,a),w-=u,x=b}return m}var W=function t(e){function r(t,r,n,i,a){Y(e,t,r,n,i,a)}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);var X=function t(e){function r(t,r,n,i,a){if((o=t._squarify)&&o.ratio===e)for(var o,s,l,c,u,h=-1,f=o.length,p=t.value;++h<f;){for(l=(s=o[h]).children,c=s.value=0,u=l.length;c<u;++c)s.value+=l[c].value;s.dice?O(s,r,n,i,n+=(a-n)*s.value/p):H(s,r,n,r+=(i-r)*s.value/p,a),p-=s.value}else t._squarify=o=Y(e,t,r,n,i,a),o.ratio=e}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);t.cluster=function(){var t=e,i=1,a=1,o=!1;function s(e){var s,l=0;e.eachAfter(function(e){var i=e.children;i?(e.x=function(t){return t.reduce(r,0)/t.length}(i),e.y=function(t){return 1+t.reduce(n,0)}(i)):(e.x=s?l+=t(e,s):0,e.y=0,s=e)});var c=function(t){for(var e;e=t.children;)t=e[0];return t}(e),u=function(t){for(var e;e=t.children;)t=e[e.length-1];return t}(e),h=c.x-t(c,u)/2,f=u.x+t(u,c)/2;return e.eachAfter(o?function(t){t.x=(t.x-e.x)*i,t.y=(e.y-t.y)*a}:function(t){t.x=(t.x-h)/(f-h)*i,t.y=(1-(e.y?t.y/e.y:1))*a})}return s.separation=function(e){return arguments.length?(t=e,s):t},s.size=function(t){return arguments.length?(o=!1,i=+t[0],a=+t[1],s):o?null:[i,a]},s.nodeSize=function(t){return arguments.length?(o=!0,i=+t[0],a=+t[1],s):o?[i,a]:null},s},t.hierarchy=a,t.pack=function(){var t=null,e=1,r=1,n=A;function i(i){return i.x=e/2,i.y=r/2,t?i.eachBefore(E(t)).eachAfter(C(n,.5)).eachBefore(L(1)):i.eachBefore(E(S)).eachAfter(C(A,1)).eachAfter(C(n,i.r/Math.min(e,r))).eachBefore(L(Math.min(e,r)/(2*i.r))),i}return i.radius=function(e){return arguments.length?(t=null==(r=e)?null:T(r),i):t;var r},i.size=function(t){return arguments.length?(e=+t[0],r=+t[1],i):[e,r]},i.padding=function(t){return arguments.length?(n=\"function\"==typeof t?t:M(+t),i):n},i},t.packSiblings=function(t){return k(t),t},t.packEnclose=h,t.partition=function(){var t=1,e=1,r=0,n=!1;function i(i){var a=i.height+1;return i.x0=i.y0=r,i.x1=t,i.y1=e/a,i.eachBefore(function(t,e){return function(n){n.children&&O(n,n.x0,t*(n.depth+1)/e,n.x1,t*(n.depth+2)/e);var i=n.x0,a=n.y0,o=n.x1-r,s=n.y1-r;o<i&&(i=o=(i+o)/2),s<a&&(a=s=(a+s)/2),n.x0=i,n.y0=a,n.x1=o,n.y1=s}}(e,a)),n&&i.eachBefore(P),i}return i.round=function(t){return arguments.length?(n=!!t,i):n},i.size=function(r){return arguments.length?(t=+r[0],e=+r[1],i):[t,e]},i.padding=function(t){return arguments.length?(r=+t,i):r},i},t.stratify=function(){var t=R,e=F;function r(r){var n,i,a,o,s,u,h,f=r.length,p=new Array(f),d={};for(i=0;i<f;++i)n=r[i],s=p[i]=new c(n),null!=(u=t(n,i,r))&&(u+=\"\")&&(d[h=z+(s.id=u)]=h in d?D:s);for(i=0;i<f;++i)if(s=p[i],null!=(u=e(r[i],i,r))&&(u+=\"\")){if(!(o=d[z+u]))throw new Error(\"missing: \"+u);if(o===D)throw new Error(\"ambiguous: \"+u);o.children?o.children.push(s):o.children=[s],s.parent=o}else{if(a)throw new Error(\"multiple roots\");a=s}if(!a)throw new Error(\"no root\");if(a.parent=I,a.eachBefore(function(t){t.depth=t.parent.depth+1,--f}).eachBefore(l),a.parent=null,f>0)throw new Error(\"cycle\");return a}return r.id=function(e){return arguments.length?(t=T(e),r):t},r.parentId=function(t){return arguments.length?(e=T(t),r):e},r},t.tree=function(){var t=B,e=1,r=1,n=null;function i(i){var l=function(t){for(var e,r,n,i,a,o=new q(t,0),s=[o];e=s.pop();)if(n=e._.children)for(e.children=new Array(a=n.length),i=a-1;i>=0;--i)s.push(r=e.children[i]=new q(n[i],i)),r.parent=e;return(o.parent=new q(null,0)).children=[o],o}(i);if(l.eachAfter(a),l.parent.m=-l.z,l.eachBefore(o),n)i.eachBefore(s);else{var c=i,u=i,h=i;i.eachBefore(function(t){t.x<c.x&&(c=t),t.x>u.x&&(u=t),t.depth>h.depth&&(h=t)});var f=c===u?1:t(c,u)/2,p=f-c.x,d=e/(u.x+f+p),g=r/(h.depth||1);i.eachBefore(function(t){t.x=(t.x+p)*d,t.y=t.depth*g})}return i}function a(e){var r=e.children,n=e.parent.children,i=e.i?n[e.i-1]:null;if(r){!function(t){for(var e,r=0,n=0,i=t.children,a=i.length;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(e);var a=(r[0].z+r[r.length-1].z)/2;i?(e.z=i.z+t(e._,i._),e.m=e.z-a):e.z=a}else i&&(e.z=i.z+t(e._,i._));e.parent.A=function(e,r,n){if(r){for(var i,a=e,o=e,s=r,l=a.parent.children[0],c=a.m,u=o.m,h=s.m,f=l.m;s=j(s),a=N(a),s&&a;)l=N(l),(o=j(o)).a=e,(i=s.z+h-a.z-c+t(s._,a._))>0&&(U(V(s,e,n),e,i),c+=i,u+=i),h+=s.m,c+=a.m,f+=l.m,u+=o.m;s&&!j(o)&&(o.t=s,o.m+=h-u),a&&!N(l)&&(l.t=a,l.m+=c-f,n=e)}return n}(e,i,e.parent.A||n[0])}function o(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function s(t){t.x*=e,t.y=t.depth*r}return i.separation=function(e){return arguments.length?(t=e,i):t},i.size=function(t){return arguments.length?(n=!1,e=+t[0],r=+t[1],i):n?null:[e,r]},i.nodeSize=function(t){return arguments.length?(n=!0,e=+t[0],r=+t[1],i):n?[e,r]:null},i},t.treemap=function(){var t=W,e=!1,r=1,n=1,i=[0],a=A,o=A,s=A,l=A,c=A;function u(t){return t.x0=t.y0=0,t.x1=r,t.y1=n,t.eachBefore(h),i=[0],e&&t.eachBefore(P),t}function h(e){var r=i[e.depth],n=e.x0+r,u=e.y0+r,h=e.x1-r,f=e.y1-r;h<n&&(n=h=(n+h)/2),f<u&&(u=f=(u+f)/2),e.x0=n,e.y0=u,e.x1=h,e.y1=f,e.children&&(r=i[e.depth+1]=a(e)/2,n+=c(e)-r,u+=o(e)-r,(h-=s(e)-r)<n&&(n=h=(n+h)/2),(f-=l(e)-r)<u&&(u=f=(u+f)/2),t(e,n,u,h,f))}return u.round=function(t){return arguments.length?(e=!!t,u):e},u.size=function(t){return arguments.length?(r=+t[0],n=+t[1],u):[r,n]},u.tile=function(e){return arguments.length?(t=T(e),u):t},u.padding=function(t){return arguments.length?u.paddingInner(t).paddingOuter(t):u.paddingInner()},u.paddingInner=function(t){return arguments.length?(a=\"function\"==typeof t?t:M(+t),u):a},u.paddingOuter=function(t){return arguments.length?u.paddingTop(t).paddingRight(t).paddingBottom(t).paddingLeft(t):u.paddingTop()},u.paddingTop=function(t){return arguments.length?(o=\"function\"==typeof t?t:M(+t),u):o},u.paddingRight=function(t){return arguments.length?(s=\"function\"==typeof t?t:M(+t),u):s},u.paddingBottom=function(t){return arguments.length?(l=\"function\"==typeof t?t:M(+t),u):l},u.paddingLeft=function(t){return arguments.length?(c=\"function\"==typeof t?t:M(+t),u):c},u},t.treemapBinary=function(t,e,r,n,i){var a,o,s=t.children,l=s.length,c=new Array(l+1);for(c[0]=o=a=0;a<l;++a)c[a+1]=o+=s[a].value;!function t(e,r,n,i,a,o,l){if(e>=r-1){var u=s[e];return u.x0=i,u.y0=a,u.x1=o,void(u.y1=l)}for(var h=c[e],f=n/2+h,p=e+1,d=r-1;p<d;){var g=p+d>>>1;c[g]<f?p=g+1:d=g}f-c[p-1]<c[p]-f&&e+1<p&&--p;var v=c[p]-h,m=n-v;if(o-i>l-a){var y=(i*m+o*v)/n;t(e,p,v,i,a,y,l),t(p,r,m,y,a,o,l)}else{var x=(a*m+l*v)/n;t(e,p,v,i,a,o,x),t(p,r,m,i,x,o,l)}}(0,l,t.value,e,r,n,i)},t.treemapDice=O,t.treemapSlice=H,t.treemapSliceDice=function(t,e,r,n,i){(1&t.depth?H:O)(t,e,r,n,i)},t.treemapSquarify=W,t.treemapResquarify=X,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],158:[function(t,e,r){var n,i;n=this,i=function(t,e){\"use strict\";function r(t,e,r,n,i){var a=t*t,o=a*t;return((1-3*t+3*a-o)*e+(4-6*a+3*o)*r+(1+3*t+3*a-3*o)*n+o*i)/6}function n(t){var e=t.length-1;return function(n){var i=n<=0?n=0:n>=1?(n=1,e-1):Math.floor(n*e),a=t[i],o=t[i+1],s=i>0?t[i-1]:2*a-o,l=i<e-1?t[i+2]:2*o-a;return r((n-i/e)*e,s,a,o,l)}}function i(t){var e=t.length;return function(n){var i=Math.floor(((n%=1)<0?++n:n)*e),a=t[(i+e-1)%e],o=t[i%e],s=t[(i+1)%e],l=t[(i+2)%e];return r((n-i/e)*e,a,o,s,l)}}function a(t){return function(){return t}}function o(t,e){return function(r){return t+r*e}}function s(t,e){var r=e-t;return r?o(t,r>180||r<-180?r-360*Math.round(r/360):r):a(isNaN(t)?e:t)}function l(t){return 1==(t=+t)?c:function(e,r){return r-e?function(t,e,r){return t=Math.pow(t,r),e=Math.pow(e,r)-t,r=1/r,function(n){return Math.pow(t+n*e,r)}}(e,r,t):a(isNaN(e)?r:e)}}function c(t,e){var r=e-t;return r?o(t,r):a(isNaN(t)?e:t)}var u=function t(r){var n=l(r);function i(t,r){var i=n((t=e.rgb(t)).r,(r=e.rgb(r)).r),a=n(t.g,r.g),o=n(t.b,r.b),s=c(t.opacity,r.opacity);return function(e){return t.r=i(e),t.g=a(e),t.b=o(e),t.opacity=s(e),t+\"\"}}return i.gamma=t,i}(1);function h(t){return function(r){var n,i,a=r.length,o=new Array(a),s=new Array(a),l=new Array(a);for(n=0;n<a;++n)i=e.rgb(r[n]),o[n]=i.r||0,s[n]=i.g||0,l[n]=i.b||0;return o=t(o),s=t(s),l=t(l),i.opacity=1,function(t){return i.r=o(t),i.g=s(t),i.b=l(t),i+\"\"}}}var f=h(n),p=h(i);function d(t,e){var r,n=e?e.length:0,i=t?Math.min(n,t.length):0,a=new Array(i),o=new Array(n);for(r=0;r<i;++r)a[r]=_(t[r],e[r]);for(;r<n;++r)o[r]=e[r];return function(t){for(r=0;r<i;++r)o[r]=a[r](t);return o}}function g(t,e){var r=new Date;return e-=t=+t,function(n){return r.setTime(t+e*n),r}}function v(t,e){return e-=t=+t,function(r){return t+e*r}}function m(t,e){var r,n={},i={};for(r in null!==t&&\"object\"==typeof t||(t={}),null!==e&&\"object\"==typeof e||(e={}),e)r in t?n[r]=_(t[r],e[r]):i[r]=e[r];return function(t){for(r in n)i[r]=n[r](t);return i}}var y=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,x=new RegExp(y.source,\"g\");function b(t,e){var r,n,i,a=y.lastIndex=x.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=y.exec(t))&&(n=x.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:v(r,n)})),a=x.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?function(t){return function(e){return t(e)+\"\"}}(l[0].x):function(t){return function(){return t}}(e):(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}function _(t,r){var n,i=typeof r;return null==r||\"boolean\"===i?a(r):(\"number\"===i?v:\"string\"===i?(n=e.color(r))?(r=n,u):b:r instanceof e.color?u:r instanceof Date?g:Array.isArray(r)?d:\"function\"!=typeof r.valueOf&&\"function\"!=typeof r.toString||isNaN(r)?m:v)(t,r)}var w,k,T,A,M=180/Math.PI,S={translateX:0,translateY:0,rotate:0,skewX:0,scaleX:1,scaleY:1};function E(t,e,r,n,i,a){var o,s,l;return(o=Math.sqrt(t*t+e*e))&&(t/=o,e/=o),(l=t*r+e*n)&&(r-=t*l,n-=e*l),(s=Math.sqrt(r*r+n*n))&&(r/=s,n/=s,l/=s),t*n<e*r&&(t=-t,e=-e,l=-l,o=-o),{translateX:i,translateY:a,rotate:Math.atan2(e,t)*M,skewX:Math.atan(l)*M,scaleX:o,scaleY:s}}function C(t,e,r,n){function i(t){return t.length?t.pop()+\" \":\"\"}return function(a,o){var s=[],l=[];return a=t(a),o=t(o),function(t,n,i,a,o,s){if(t!==i||n!==a){var l=o.push(\"translate(\",null,e,null,r);s.push({i:l-4,x:v(t,i)},{i:l-2,x:v(n,a)})}else(i||a)&&o.push(\"translate(\"+i+e+a+r)}(a.translateX,a.translateY,o.translateX,o.translateY,s,l),function(t,e,r,a){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),a.push({i:r.push(i(r)+\"rotate(\",null,n)-2,x:v(t,e)})):e&&r.push(i(r)+\"rotate(\"+e+n)}(a.rotate,o.rotate,s,l),function(t,e,r,a){t!==e?a.push({i:r.push(i(r)+\"skewX(\",null,n)-2,x:v(t,e)}):e&&r.push(i(r)+\"skewX(\"+e+n)}(a.skewX,o.skewX,s,l),function(t,e,r,n,a,o){if(t!==r||e!==n){var s=a.push(i(a)+\"scale(\",null,\",\",null,\")\");o.push({i:s-4,x:v(t,r)},{i:s-2,x:v(e,n)})}else 1===r&&1===n||a.push(i(a)+\"scale(\"+r+\",\"+n+\")\")}(a.scaleX,a.scaleY,o.scaleX,o.scaleY,s,l),a=o=null,function(t){for(var e,r=-1,n=l.length;++r<n;)s[(e=l[r]).i]=e.x(t);return s.join(\"\")}}}var L=C(function(t){return\"none\"===t?S:(w||(w=document.createElement(\"DIV\"),k=document.documentElement,T=document.defaultView),w.style.transform=t,t=T.getComputedStyle(k.appendChild(w),null).getPropertyValue(\"transform\"),k.removeChild(w),E(+(t=t.slice(7,-1).split(\",\"))[0],+t[1],+t[2],+t[3],+t[4],+t[5]))},\"px, \",\"px)\",\"deg)\"),P=C(function(t){return null==t?S:(A||(A=document.createElementNS(\"http://www.w3.org/2000/svg\",\"g\")),A.setAttribute(\"transform\",t),(t=A.transform.baseVal.consolidate())?E((t=t.matrix).a,t.b,t.c,t.d,t.e,t.f):S)},\", \",\")\",\")\"),O=Math.SQRT2,z=2,I=4,D=1e-12;function R(t){return((t=Math.exp(t))+1/t)/2}function F(t){return function(r,n){var i=t((r=e.hsl(r)).h,(n=e.hsl(n)).h),a=c(r.s,n.s),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.s=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var B=F(s),N=F(c);function j(t){return function(r,n){var i=t((r=e.hcl(r)).h,(n=e.hcl(n)).h),a=c(r.c,n.c),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.c=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var U=j(s),V=j(c);function q(t){return function r(n){function i(r,i){var a=t((r=e.cubehelix(r)).h,(i=e.cubehelix(i)).h),o=c(r.s,i.s),s=c(r.l,i.l),l=c(r.opacity,i.opacity);return function(t){return r.h=a(t),r.s=o(t),r.l=s(Math.pow(t,n)),r.opacity=l(t),r+\"\"}}return n=+n,i.gamma=r,i}(1)}var H=q(s),G=q(c);t.interpolate=_,t.interpolateArray=d,t.interpolateBasis=n,t.interpolateBasisClosed=i,t.interpolateDate=g,t.interpolateDiscrete=function(t){var e=t.length;return function(r){return t[Math.max(0,Math.min(e-1,Math.floor(r*e)))]}},t.interpolateHue=function(t,e){var r=s(+t,+e);return function(t){var e=r(t);return e-360*Math.floor(e/360)}},t.interpolateNumber=v,t.interpolateObject=m,t.interpolateRound=function(t,e){return e-=t=+t,function(r){return Math.round(t+e*r)}},t.interpolateString=b,t.interpolateTransformCss=L,t.interpolateTransformSvg=P,t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,h=l-a,f=u*u+h*h;if(f<D)n=Math.log(c/o)/O,r=function(t){return[i+t*u,a+t*h,o*Math.exp(O*t*n)]};else{var p=Math.sqrt(f),d=(c*c-o*o+I*f)/(2*o*z*p),g=(c*c-o*o-I*f)/(2*c*z*p),v=Math.log(Math.sqrt(d*d+1)-d),m=Math.log(Math.sqrt(g*g+1)-g);n=(m-v)/O,r=function(t){var e,r=t*n,s=R(v),l=o/(z*p)*(s*(e=O*r+v,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(v));return[i+l*u,a+l*h,o*s/R(O*r+v)]}}return r.duration=1e3*n,r},t.interpolateRgb=u,t.interpolateRgbBasis=f,t.interpolateRgbBasisClosed=p,t.interpolateHsl=B,t.interpolateHslLong=N,t.interpolateLab=function(t,r){var n=c((t=e.lab(t)).l,(r=e.lab(r)).l),i=c(t.a,r.a),a=c(t.b,r.b),o=c(t.opacity,r.opacity);return function(e){return t.l=n(e),t.a=i(e),t.b=a(e),t.opacity=o(e),t+\"\"}},t.interpolateHcl=U,t.interpolateHclLong=V,t.interpolateCubehelix=H,t.interpolateCubehelixLong=G,t.piecewise=function(t,e){for(var r=0,n=e.length-1,i=e[0],a=new Array(n<0?0:n);r<n;)a[r]=t(i,i=e[++r]);return function(t){var e=Math.max(0,Math.min(n-1,Math.floor(t*=n)));return a[e](t-e)}},t.quantize=function(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t(n/(e-1));return r},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-color\")):i(n.d3=n.d3||{},n.d3)},{\"d3-color\":154}],159:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e=Math.PI,r=2*e,n=r-1e-6;function i(){this._x0=this._y0=this._x1=this._y1=null,this._=\"\"}function a(){return new i}i.prototype=a.prototype={constructor:i,moveTo:function(t,e){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)},closePath:function(){null!==this._x1&&(this._x1=this._x0,this._y1=this._y0,this._+=\"Z\")},lineTo:function(t,e){this._+=\"L\"+(this._x1=+t)+\",\"+(this._y1=+e)},quadraticCurveTo:function(t,e,r,n){this._+=\"Q\"+ +t+\",\"+ +e+\",\"+(this._x1=+r)+\",\"+(this._y1=+n)},bezierCurveTo:function(t,e,r,n,i,a){this._+=\"C\"+ +t+\",\"+ +e+\",\"+ +r+\",\"+ +n+\",\"+(this._x1=+i)+\",\"+(this._y1=+a)},arcTo:function(t,r,n,i,a){t=+t,r=+r,n=+n,i=+i,a=+a;var o=this._x1,s=this._y1,l=n-t,c=i-r,u=o-t,h=s-r,f=u*u+h*h;if(a<0)throw new Error(\"negative radius: \"+a);if(null===this._x1)this._+=\"M\"+(this._x1=t)+\",\"+(this._y1=r);else if(f>1e-6)if(Math.abs(h*l-c*u)>1e-6&&a){var p=n-o,d=i-s,g=l*l+c*c,v=p*p+d*d,m=Math.sqrt(g),y=Math.sqrt(f),x=a*Math.tan((e-Math.acos((g+f-v)/(2*m*y)))/2),b=x/y,_=x/m;Math.abs(b-1)>1e-6&&(this._+=\"L\"+(t+b*u)+\",\"+(r+b*h)),this._+=\"A\"+a+\",\"+a+\",0,0,\"+ +(h*p>u*d)+\",\"+(this._x1=t+_*l)+\",\"+(this._y1=r+_*c)}else this._+=\"L\"+(this._x1=t)+\",\"+(this._y1=r);else;},arc:function(t,i,a,o,s,l){t=+t,i=+i;var c=(a=+a)*Math.cos(o),u=a*Math.sin(o),h=t+c,f=i+u,p=1^l,d=l?o-s:s-o;if(a<0)throw new Error(\"negative radius: \"+a);null===this._x1?this._+=\"M\"+h+\",\"+f:(Math.abs(this._x1-h)>1e-6||Math.abs(this._y1-f)>1e-6)&&(this._+=\"L\"+h+\",\"+f),a&&(d<0&&(d=d%r+r),d>n?this._+=\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(t-c)+\",\"+(i-u)+\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(this._x1=h)+\",\"+(this._y1=f):d>1e-6&&(this._+=\"A\"+a+\",\"+a+\",0,\"+ +(d>=e)+\",\"+p+\",\"+(this._x1=t+a*Math.cos(s))+\",\"+(this._y1=i+a*Math.sin(s))))},rect:function(t,e,r,n){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)+\"h\"+ +r+\"v\"+ +n+\"h\"+-r+\"Z\"},toString:function(){return this._}},t.path=a,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],160:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e,r,n){if(isNaN(e)||isNaN(r))return t;var i,a,o,s,l,c,u,h,f,p=t._root,d={data:n},g=t._x0,v=t._y0,m=t._x1,y=t._y1;if(!p)return t._root=d,t;for(;p.length;)if((c=e>=(a=(g+m)/2))?g=a:m=a,(u=r>=(o=(v+y)/2))?v=o:y=o,i=p,!(p=p[h=u<<1|c]))return i[h]=d,t;if(s=+t._x.call(null,p.data),l=+t._y.call(null,p.data),e===s&&r===l)return d.next=p,i?i[h]=d:t._root=d,t;do{i=i?i[h]=new Array(4):t._root=new Array(4),(c=e>=(a=(g+m)/2))?g=a:m=a,(u=r>=(o=(v+y)/2))?v=o:y=o}while((h=u<<1|c)==(f=(l>=o)<<1|s>=a));return i[f]=p,i[h]=d,t}var r=function(t,e,r,n,i){this.node=t,this.x0=e,this.y0=r,this.x1=n,this.y1=i};function n(t){return t[0]}function i(t){return t[1]}function a(t,e,r){var a=new o(null==e?n:e,null==r?i:r,NaN,NaN,NaN,NaN);return null==t?a:a.addAll(t)}function o(t,e,r,n,i,a){this._x=t,this._y=e,this._x0=r,this._y0=n,this._x1=i,this._y1=a,this._root=void 0}function s(t){for(var e={data:t.data},r=e;t=t.next;)r=r.next={data:t.data};return e}var l=a.prototype=o.prototype;l.copy=function(){var t,e,r=new o(this._x,this._y,this._x0,this._y0,this._x1,this._y1),n=this._root;if(!n)return r;if(!n.length)return r._root=s(n),r;for(t=[{source:n,target:r._root=new Array(4)}];n=t.pop();)for(var i=0;i<4;++i)(e=n.source[i])&&(e.length?t.push({source:e,target:n.target[i]=new Array(4)}):n.target[i]=s(e));return r},l.add=function(t){var r=+this._x.call(null,t),n=+this._y.call(null,t);return e(this.cover(r,n),r,n,t)},l.addAll=function(t){var r,n,i,a,o=t.length,s=new Array(o),l=new Array(o),c=1/0,u=1/0,h=-1/0,f=-1/0;for(n=0;n<o;++n)isNaN(i=+this._x.call(null,r=t[n]))||isNaN(a=+this._y.call(null,r))||(s[n]=i,l[n]=a,i<c&&(c=i),i>h&&(h=i),a<u&&(u=a),a>f&&(f=a));for(h<c&&(c=this._x0,h=this._x1),f<u&&(u=this._y0,f=this._y1),this.cover(c,u).cover(h,f),n=0;n<o;++n)e(this,s[n],l[n],t[n]);return this},l.cover=function(t,e){if(isNaN(t=+t)||isNaN(e=+e))return this;var r=this._x0,n=this._y0,i=this._x1,a=this._y1;if(isNaN(r))i=(r=Math.floor(t))+1,a=(n=Math.floor(e))+1;else{if(!(r>t||t>i||n>e||e>a))return this;var o,s,l=i-r,c=this._root;switch(s=(e<(n+a)/2)<<1|t<(r+i)/2){case 0:do{(o=new Array(4))[s]=c,c=o}while(a=n+(l*=2),t>(i=r+l)||e>a);break;case 1:do{(o=new Array(4))[s]=c,c=o}while(a=n+(l*=2),(r=i-l)>t||e>a);break;case 2:do{(o=new Array(4))[s]=c,c=o}while(n=a-(l*=2),t>(i=r+l)||n>e);break;case 3:do{(o=new Array(4))[s]=c,c=o}while(n=a-(l*=2),(r=i-l)>t||n>e)}this._root&&this._root.length&&(this._root=c)}return this._x0=r,this._y0=n,this._x1=i,this._y1=a,this},l.data=function(){var t=[];return this.visit(function(e){if(!e.length)do{t.push(e.data)}while(e=e.next)}),t},l.extent=function(t){return arguments.length?this.cover(+t[0][0],+t[0][1]).cover(+t[1][0],+t[1][1]):isNaN(this._x0)?void 0:[[this._x0,this._y0],[this._x1,this._y1]]},l.find=function(t,e,n){var i,a,o,s,l,c,u,h=this._x0,f=this._y0,p=this._x1,d=this._y1,g=[],v=this._root;for(v&&g.push(new r(v,h,f,p,d)),null==n?n=1/0:(h=t-n,f=e-n,p=t+n,d=e+n,n*=n);c=g.pop();)if(!(!(v=c.node)||(a=c.x0)>p||(o=c.y0)>d||(s=c.x1)<h||(l=c.y1)<f))if(v.length){var m=(a+s)/2,y=(o+l)/2;g.push(new r(v[3],m,y,s,l),new r(v[2],a,y,m,l),new r(v[1],m,o,s,y),new r(v[0],a,o,m,y)),(u=(e>=y)<<1|t>=m)&&(c=g[g.length-1],g[g.length-1]=g[g.length-1-u],g[g.length-1-u]=c)}else{var x=t-+this._x.call(null,v.data),b=e-+this._y.call(null,v.data),_=x*x+b*b;if(_<n){var w=Math.sqrt(n=_);h=t-w,f=e-w,p=t+w,d=e+w,i=v.data}}return i},l.remove=function(t){if(isNaN(a=+this._x.call(null,t))||isNaN(o=+this._y.call(null,t)))return this;var e,r,n,i,a,o,s,l,c,u,h,f,p=this._root,d=this._x0,g=this._y0,v=this._x1,m=this._y1;if(!p)return this;if(p.length)for(;;){if((c=a>=(s=(d+v)/2))?d=s:v=s,(u=o>=(l=(g+m)/2))?g=l:m=l,e=p,!(p=p[h=u<<1|c]))return this;if(!p.length)break;(e[h+1&3]||e[h+2&3]||e[h+3&3])&&(r=e,f=h)}for(;p.data!==t;)if(n=p,!(p=p.next))return this;return(i=p.next)&&delete p.next,n?(i?n.next=i:delete n.next,this):e?(i?e[h]=i:delete e[h],(p=e[0]||e[1]||e[2]||e[3])&&p===(e[3]||e[2]||e[1]||e[0])&&!p.length&&(r?r[f]=p:this._root=p),this):(this._root=i,this)},l.removeAll=function(t){for(var e=0,r=t.length;e<r;++e)this.remove(t[e]);return this},l.root=function(){return this._root},l.size=function(){var t=0;return this.visit(function(e){if(!e.length)do{++t}while(e=e.next)}),t},l.visit=function(t){var e,n,i,a,o,s,l=[],c=this._root;for(c&&l.push(new r(c,this._x0,this._y0,this._x1,this._y1));e=l.pop();)if(!t(c=e.node,i=e.x0,a=e.y0,o=e.x1,s=e.y1)&&c.length){var u=(i+o)/2,h=(a+s)/2;(n=c[3])&&l.push(new r(n,u,h,o,s)),(n=c[2])&&l.push(new r(n,i,h,u,s)),(n=c[1])&&l.push(new r(n,u,a,o,h)),(n=c[0])&&l.push(new r(n,i,a,u,h))}return this},l.visitAfter=function(t){var e,n=[],i=[];for(this._root&&n.push(new r(this._root,this._x0,this._y0,this._x1,this._y1));e=n.pop();){var a=e.node;if(a.length){var o,s=e.x0,l=e.y0,c=e.x1,u=e.y1,h=(s+c)/2,f=(l+u)/2;(o=a[0])&&n.push(new r(o,s,l,h,f)),(o=a[1])&&n.push(new r(o,h,l,c,f)),(o=a[2])&&n.push(new r(o,s,f,h,u)),(o=a[3])&&n.push(new r(o,h,f,c,u))}i.push(e)}for(;e=i.pop();)t(e.node,e.x0,e.y0,e.x1,e.y1);return this},l.x=function(t){return arguments.length?(this._x=t,this):this._x},l.y=function(t){return arguments.length?(this._y=t,this):this._y},t.quadtree=a,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],161:[function(t,e,r){var n,i;n=this,i=function(t,e){\"use strict\";function r(t){return function(){return t}}var n=Math.abs,i=Math.atan2,a=Math.cos,o=Math.max,s=Math.min,l=Math.sin,c=Math.sqrt,u=1e-12,h=Math.PI,f=h/2,p=2*h;function d(t){return t>=1?f:t<=-1?-f:Math.asin(t)}function g(t){return t.innerRadius}function v(t){return t.outerRadius}function m(t){return t.startAngle}function y(t){return t.endAngle}function x(t){return t&&t.padAngle}function b(t,e,r,n,i,a,s){var l=t-r,u=e-n,h=(s?a:-a)/c(l*l+u*u),f=h*u,p=-h*l,d=t+f,g=e+p,v=r+f,m=n+p,y=(d+v)/2,x=(g+m)/2,b=v-d,_=m-g,w=b*b+_*_,k=i-a,T=d*m-v*g,A=(_<0?-1:1)*c(o(0,k*k*w-T*T)),M=(T*_-b*A)/w,S=(-T*b-_*A)/w,E=(T*_+b*A)/w,C=(-T*b+_*A)/w,L=M-y,P=S-x,O=E-y,z=C-x;return L*L+P*P>O*O+z*z&&(M=E,S=C),{cx:M,cy:S,x01:-f,y01:-p,x11:M*(i/k-1),y11:S*(i/k-1)}}function _(t){this._context=t}function w(t){return new _(t)}function k(t){return t[0]}function T(t){return t[1]}function A(){var t=k,n=T,i=r(!0),a=null,o=w,s=null;function l(r){var l,c,u,h=r.length,f=!1;for(null==a&&(s=o(u=e.path())),l=0;l<=h;++l)!(l<h&&i(c=r[l],l,r))===f&&((f=!f)?s.lineStart():s.lineEnd()),f&&s.point(+t(c,l,r),+n(c,l,r));if(u)return s=null,u+\"\"||null}return l.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),l):t},l.y=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),l):n},l.defined=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(!!t),l):i},l.curve=function(t){return arguments.length?(o=t,null!=a&&(s=o(a)),l):o},l.context=function(t){return arguments.length?(null==t?a=s=null:s=o(a=t),l):a},l}function M(){var t=k,n=null,i=r(0),a=T,o=r(!0),s=null,l=w,c=null;function u(r){var u,h,f,p,d,g=r.length,v=!1,m=new Array(g),y=new Array(g);for(null==s&&(c=l(d=e.path())),u=0;u<=g;++u){if(!(u<g&&o(p=r[u],u,r))===v)if(v=!v)h=u,c.areaStart(),c.lineStart();else{for(c.lineEnd(),c.lineStart(),f=u-1;f>=h;--f)c.point(m[f],y[f]);c.lineEnd(),c.areaEnd()}v&&(m[u]=+t(p,u,r),y[u]=+i(p,u,r),c.point(n?+n(p,u,r):m[u],a?+a(p,u,r):y[u]))}if(d)return c=null,d+\"\"||null}function h(){return A().defined(o).curve(l).context(s)}return u.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),n=null,u):t},u.x0=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),u):t},u.x1=function(t){return arguments.length?(n=null==t?null:\"function\"==typeof t?t:r(+t),u):n},u.y=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a=null,u):i},u.y0=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),u):i},u.y1=function(t){return arguments.length?(a=null==t?null:\"function\"==typeof t?t:r(+t),u):a},u.lineX0=u.lineY0=function(){return h().x(t).y(i)},u.lineY1=function(){return h().x(t).y(a)},u.lineX1=function(){return h().x(n).y(i)},u.defined=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(!!t),u):o},u.curve=function(t){return arguments.length?(l=t,null!=s&&(c=l(s)),u):l},u.context=function(t){return arguments.length?(null==t?s=c=null:c=l(s=t),u):s},u}function S(t,e){return e<t?-1:e>t?1:e>=t?0:NaN}function E(t){return t}_.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._point=0},lineEnd:function(){(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:this._context.lineTo(t,e)}}};var C=P(w);function L(t){this._curve=t}function P(t){function e(e){return new L(t(e))}return e._curve=t,e}function O(t){var e=t.curve;return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function z(){return O(A().curve(C))}function I(){var t=M().curve(C),e=t.curve,r=t.lineX0,n=t.lineX1,i=t.lineY0,a=t.lineY1;return t.angle=t.x,delete t.x,t.startAngle=t.x0,delete t.x0,t.endAngle=t.x1,delete t.x1,t.radius=t.y,delete t.y,t.innerRadius=t.y0,delete t.y0,t.outerRadius=t.y1,delete t.y1,t.lineStartAngle=function(){return O(r())},delete t.lineX0,t.lineEndAngle=function(){return O(n())},delete t.lineX1,t.lineInnerRadius=function(){return O(i())},delete t.lineY0,t.lineOuterRadius=function(){return O(a())},delete t.lineY1,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function D(t,e){return[(e=+e)*Math.cos(t-=Math.PI/2),e*Math.sin(t)]}L.prototype={areaStart:function(){this._curve.areaStart()},areaEnd:function(){this._curve.areaEnd()},lineStart:function(){this._curve.lineStart()},lineEnd:function(){this._curve.lineEnd()},point:function(t,e){this._curve.point(e*Math.sin(t),e*-Math.cos(t))}};var R=Array.prototype.slice;function F(t){return t.source}function B(t){return t.target}function N(t){var n=F,i=B,a=k,o=T,s=null;function l(){var r,l=R.call(arguments),c=n.apply(this,l),u=i.apply(this,l);if(s||(s=r=e.path()),t(s,+a.apply(this,(l[0]=c,l)),+o.apply(this,l),+a.apply(this,(l[0]=u,l)),+o.apply(this,l)),r)return s=null,r+\"\"||null}return l.source=function(t){return arguments.length?(n=t,l):n},l.target=function(t){return arguments.length?(i=t,l):i},l.x=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),l):a},l.y=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),l):o},l.context=function(t){return arguments.length?(s=null==t?null:t,l):s},l}function j(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e=(e+n)/2,r,e,i,n,i)}function U(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e,r=(r+i)/2,n,r,n,i)}function V(t,e,r,n,i){var a=D(e,r),o=D(e,r=(r+i)/2),s=D(n,r),l=D(n,i);t.moveTo(a[0],a[1]),t.bezierCurveTo(o[0],o[1],s[0],s[1],l[0],l[1])}var q={draw:function(t,e){var r=Math.sqrt(e/h);t.moveTo(r,0),t.arc(0,0,r,0,p)}},H={draw:function(t,e){var r=Math.sqrt(e/5)/2;t.moveTo(-3*r,-r),t.lineTo(-r,-r),t.lineTo(-r,-3*r),t.lineTo(r,-3*r),t.lineTo(r,-r),t.lineTo(3*r,-r),t.lineTo(3*r,r),t.lineTo(r,r),t.lineTo(r,3*r),t.lineTo(-r,3*r),t.lineTo(-r,r),t.lineTo(-3*r,r),t.closePath()}},G=Math.sqrt(1/3),Y=2*G,W={draw:function(t,e){var r=Math.sqrt(e/Y),n=r*G;t.moveTo(0,-r),t.lineTo(n,0),t.lineTo(0,r),t.lineTo(-n,0),t.closePath()}},X=Math.sin(h/10)/Math.sin(7*h/10),Z=Math.sin(p/10)*X,J=-Math.cos(p/10)*X,K={draw:function(t,e){var r=Math.sqrt(.8908130915292852*e),n=Z*r,i=J*r;t.moveTo(0,-r),t.lineTo(n,i);for(var a=1;a<5;++a){var o=p*a/5,s=Math.cos(o),l=Math.sin(o);t.lineTo(l*r,-s*r),t.lineTo(s*n-l*i,l*n+s*i)}t.closePath()}},$={draw:function(t,e){var r=Math.sqrt(e),n=-r/2;t.rect(n,n,r,r)}},Q=Math.sqrt(3),tt={draw:function(t,e){var r=-Math.sqrt(e/(3*Q));t.moveTo(0,2*r),t.lineTo(-Q*r,-r),t.lineTo(Q*r,-r),t.closePath()}},et=-.5,rt=Math.sqrt(3)/2,nt=1/Math.sqrt(12),it=3*(nt/2+1),at={draw:function(t,e){var r=Math.sqrt(e/it),n=r/2,i=r*nt,a=n,o=r*nt+r,s=-a,l=o;t.moveTo(n,i),t.lineTo(a,o),t.lineTo(s,l),t.lineTo(et*n-rt*i,rt*n+et*i),t.lineTo(et*a-rt*o,rt*a+et*o),t.lineTo(et*s-rt*l,rt*s+et*l),t.lineTo(et*n+rt*i,et*i-rt*n),t.lineTo(et*a+rt*o,et*o-rt*a),t.lineTo(et*s+rt*l,et*l-rt*s),t.closePath()}},ot=[q,H,W,$,K,tt,at];function st(){}function lt(t,e,r){t._context.bezierCurveTo((2*t._x0+t._x1)/3,(2*t._y0+t._y1)/3,(t._x0+2*t._x1)/3,(t._y0+2*t._y1)/3,(t._x0+4*t._x1+e)/6,(t._y0+4*t._y1+r)/6)}function ct(t){this._context=t}function ut(t){this._context=t}function ht(t){this._context=t}function ft(t,e){this._basis=new ct(t),this._beta=e}ct.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){switch(this._point){case 3:lt(this,this._x1,this._y1);case 2:this._context.lineTo(this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,this._context.lineTo((5*this._x0+this._x1)/6,(5*this._y0+this._y1)/6);default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ut.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._y0=this._y1=this._y2=this._y3=this._y4=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x2,this._y2),this._context.closePath();break;case 2:this._context.moveTo((this._x2+2*this._x3)/3,(this._y2+2*this._y3)/3),this._context.lineTo((this._x3+2*this._x2)/3,(this._y3+2*this._y2)/3),this._context.closePath();break;case 3:this.point(this._x2,this._y2),this.point(this._x3,this._y3),this.point(this._x4,this._y4)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x2=t,this._y2=e;break;case 1:this._point=2,this._x3=t,this._y3=e;break;case 2:this._point=3,this._x4=t,this._y4=e,this._context.moveTo((this._x0+4*this._x1+t)/6,(this._y0+4*this._y1+e)/6);break;default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ht.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3;var r=(this._x0+4*this._x1+t)/6,n=(this._y0+4*this._y1+e)/6;this._line?this._context.lineTo(r,n):this._context.moveTo(r,n);break;case 3:this._point=4;default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ft.prototype={lineStart:function(){this._x=[],this._y=[],this._basis.lineStart()},lineEnd:function(){var t=this._x,e=this._y,r=t.length-1;if(r>0)for(var n,i=t[0],a=e[0],o=t[r]-i,s=e[r]-a,l=-1;++l<=r;)n=l/r,this._basis.point(this._beta*t[l]+(1-this._beta)*(i+n*o),this._beta*e[l]+(1-this._beta)*(a+n*s));this._x=this._y=null,this._basis.lineEnd()},point:function(t,e){this._x.push(+t),this._y.push(+e)}};var pt=function t(e){function r(t){return 1===e?new ct(t):new ft(t,e)}return r.beta=function(e){return t(+e)},r}(.85);function dt(t,e,r){t._context.bezierCurveTo(t._x1+t._k*(t._x2-t._x0),t._y1+t._k*(t._y2-t._y0),t._x2+t._k*(t._x1-e),t._y2+t._k*(t._y1-r),t._x2,t._y2)}function gt(t,e){this._context=t,this._k=(1-e)/6}gt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:dt(this,this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2,this._x1=t,this._y1=e;break;case 2:this._point=3;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var vt=function t(e){function r(t){return new gt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function mt(t,e){this._context=t,this._k=(1-e)/6}mt.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var yt=function t(e){function r(t){return new mt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function xt(t,e){this._context=t,this._k=(1-e)/6}xt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var bt=function t(e){function r(t){return new xt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function _t(t,e,r){var n=t._x1,i=t._y1,a=t._x2,o=t._y2;if(t._l01_a>u){var s=2*t._l01_2a+3*t._l01_a*t._l12_a+t._l12_2a,l=3*t._l01_a*(t._l01_a+t._l12_a);n=(n*s-t._x0*t._l12_2a+t._x2*t._l01_2a)/l,i=(i*s-t._y0*t._l12_2a+t._y2*t._l01_2a)/l}if(t._l23_a>u){var c=2*t._l23_2a+3*t._l23_a*t._l12_a+t._l12_2a,h=3*t._l23_a*(t._l23_a+t._l12_a);a=(a*c+t._x1*t._l23_2a-e*t._l12_2a)/h,o=(o*c+t._y1*t._l23_2a-r*t._l12_2a)/h}t._context.bezierCurveTo(n,i,a,o,t._x2,t._y2)}function wt(t,e){this._context=t,this._alpha=e}wt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:this.point(this._x2,this._y2)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var kt=function t(e){function r(t){return e?new wt(t,e):new gt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Tt(t,e){this._context=t,this._alpha=e}Tt.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var At=function t(e){function r(t){return e?new Tt(t,e):new mt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Mt(t,e){this._context=t,this._alpha=e}Mt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var St=function t(e){function r(t){return e?new Mt(t,e):new xt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Et(t){this._context=t}function Ct(t){return t<0?-1:1}function Lt(t,e,r){var n=t._x1-t._x0,i=e-t._x1,a=(t._y1-t._y0)/(n||i<0&&-0),o=(r-t._y1)/(i||n<0&&-0),s=(a*i+o*n)/(n+i);return(Ct(a)+Ct(o))*Math.min(Math.abs(a),Math.abs(o),.5*Math.abs(s))||0}function Pt(t,e){var r=t._x1-t._x0;return r?(3*(t._y1-t._y0)/r-e)/2:e}function Ot(t,e,r){var n=t._x0,i=t._y0,a=t._x1,o=t._y1,s=(a-n)/3;t._context.bezierCurveTo(n+s,i+s*e,a-s,o-s*r,a,o)}function zt(t){this._context=t}function It(t){this._context=new Dt(t)}function Dt(t){this._context=t}function Rt(t){this._context=t}function Ft(t){var e,r,n=t.length-1,i=new Array(n),a=new Array(n),o=new Array(n);for(i[0]=0,a[0]=2,o[0]=t[0]+2*t[1],e=1;e<n-1;++e)i[e]=1,a[e]=4,o[e]=4*t[e]+2*t[e+1];for(i[n-1]=2,a[n-1]=7,o[n-1]=8*t[n-1]+t[n],e=1;e<n;++e)r=i[e]/a[e-1],a[e]-=r,o[e]-=r*o[e-1];for(i[n-1]=o[n-1]/a[n-1],e=n-2;e>=0;--e)i[e]=(o[e]-i[e+1])/a[e];for(a[n-1]=(t[n]+i[n-1])/2,e=0;e<n-1;++e)a[e]=2*t[e+1]-i[e+1];return[i,a]}function Bt(t,e){this._context=t,this._t=e}function Nt(t,e){if((i=t.length)>1)for(var r,n,i,a=1,o=t[e[0]],s=o.length;a<i;++a)for(n=o,o=t[e[a]],r=0;r<s;++r)o[r][1]+=o[r][0]=isNaN(n[r][1])?n[r][0]:n[r][1]}function jt(t){for(var e=t.length,r=new Array(e);--e>=0;)r[e]=e;return r}function Ut(t,e){return t[e]}function Vt(t){var e=t.map(qt);return jt(t).sort(function(t,r){return e[t]-e[r]})}function qt(t){for(var e,r=-1,n=0,i=t.length,a=-1/0;++r<i;)(e=+t[r][1])>a&&(a=e,n=r);return n}function Ht(t){var e=t.map(Gt);return jt(t).sort(function(t,r){return e[t]-e[r]})}function Gt(t){for(var e,r=0,n=-1,i=t.length;++n<i;)(e=+t[n][1])&&(r+=e);return r}Et.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._point=0},lineEnd:function(){this._point&&this._context.closePath()},point:function(t,e){t=+t,e=+e,this._point?this._context.lineTo(t,e):(this._point=1,this._context.moveTo(t,e))}},zt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=this._t0=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x1,this._y1);break;case 3:Ot(this,this._t0,Pt(this,this._t0))}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){var r=NaN;if(e=+e,(t=+t)!==this._x1||e!==this._y1){switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,Ot(this,Pt(this,r=Lt(this,t,e)),r);break;default:Ot(this,this._t0,r=Lt(this,t,e))}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e,this._t0=r}}},(It.prototype=Object.create(zt.prototype)).point=function(t,e){zt.prototype.point.call(this,e,t)},Dt.prototype={moveTo:function(t,e){this._context.moveTo(e,t)},closePath:function(){this._context.closePath()},lineTo:function(t,e){this._context.lineTo(e,t)},bezierCurveTo:function(t,e,r,n,i,a){this._context.bezierCurveTo(e,t,n,r,a,i)}},Rt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=[],this._y=[]},lineEnd:function(){var t=this._x,e=this._y,r=t.length;if(r)if(this._line?this._context.lineTo(t[0],e[0]):this._context.moveTo(t[0],e[0]),2===r)this._context.lineTo(t[1],e[1]);else for(var n=Ft(t),i=Ft(e),a=0,o=1;o<r;++a,++o)this._context.bezierCurveTo(n[0][a],i[0][a],n[1][a],i[1][a],t[o],e[o]);(this._line||0!==this._line&&1===r)&&this._context.closePath(),this._line=1-this._line,this._x=this._y=null},point:function(t,e){this._x.push(+t),this._y.push(+e)}},Bt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=this._y=NaN,this._point=0},lineEnd:function(){0<this._t&&this._t<1&&2===this._point&&this._context.lineTo(this._x,this._y),(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line>=0&&(this._t=1-this._t,this._line=1-this._line)},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:if(this._t<=0)this._context.lineTo(this._x,e),this._context.lineTo(t,e);else{var r=this._x*(1-this._t)+t*this._t;this._context.lineTo(r,this._y),this._context.lineTo(r,e)}}this._x=t,this._y=e}},t.arc=function(){var t=g,o=v,_=r(0),w=null,k=m,T=y,A=x,M=null;function S(){var r,g,v,m=+t.apply(this,arguments),y=+o.apply(this,arguments),x=k.apply(this,arguments)-f,S=T.apply(this,arguments)-f,E=n(S-x),C=S>x;if(M||(M=r=e.path()),y<m&&(g=y,y=m,m=g),y>u)if(E>p-u)M.moveTo(y*a(x),y*l(x)),M.arc(0,0,y,x,S,!C),m>u&&(M.moveTo(m*a(S),m*l(S)),M.arc(0,0,m,S,x,C));else{var L,P,O=x,z=S,I=x,D=S,R=E,F=E,B=A.apply(this,arguments)/2,N=B>u&&(w?+w.apply(this,arguments):c(m*m+y*y)),j=s(n(y-m)/2,+_.apply(this,arguments)),U=j,V=j;if(N>u){var q=d(N/m*l(B)),H=d(N/y*l(B));(R-=2*q)>u?(I+=q*=C?1:-1,D-=q):(R=0,I=D=(x+S)/2),(F-=2*H)>u?(O+=H*=C?1:-1,z-=H):(F=0,O=z=(x+S)/2)}var G=y*a(O),Y=y*l(O),W=m*a(D),X=m*l(D);if(j>u){var Z,J=y*a(z),K=y*l(z),$=m*a(I),Q=m*l(I);if(E<h&&(Z=function(t,e,r,n,i,a,o,s){var l=r-t,c=n-e,h=o-i,f=s-a,p=f*l-h*c;if(!(p*p<u))return[t+(p=(h*(e-a)-f*(t-i))/p)*l,e+p*c]}(G,Y,$,Q,J,K,W,X))){var tt=G-Z[0],et=Y-Z[1],rt=J-Z[0],nt=K-Z[1],it=1/l(((v=(tt*rt+et*nt)/(c(tt*tt+et*et)*c(rt*rt+nt*nt)))>1?0:v<-1?h:Math.acos(v))/2),at=c(Z[0]*Z[0]+Z[1]*Z[1]);U=s(j,(m-at)/(it-1)),V=s(j,(y-at)/(it+1))}}F>u?V>u?(L=b($,Q,G,Y,y,V,C),P=b(J,K,W,X,y,V,C),M.moveTo(L.cx+L.x01,L.cy+L.y01),V<j?M.arc(L.cx,L.cy,V,i(L.y01,L.x01),i(P.y01,P.x01),!C):(M.arc(L.cx,L.cy,V,i(L.y01,L.x01),i(L.y11,L.x11),!C),M.arc(0,0,y,i(L.cy+L.y11,L.cx+L.x11),i(P.cy+P.y11,P.cx+P.x11),!C),M.arc(P.cx,P.cy,V,i(P.y11,P.x11),i(P.y01,P.x01),!C))):(M.moveTo(G,Y),M.arc(0,0,y,O,z,!C)):M.moveTo(G,Y),m>u&&R>u?U>u?(L=b(W,X,J,K,m,-U,C),P=b(G,Y,$,Q,m,-U,C),M.lineTo(L.cx+L.x01,L.cy+L.y01),U<j?M.arc(L.cx,L.cy,U,i(L.y01,L.x01),i(P.y01,P.x01),!C):(M.arc(L.cx,L.cy,U,i(L.y01,L.x01),i(L.y11,L.x11),!C),M.arc(0,0,m,i(L.cy+L.y11,L.cx+L.x11),i(P.cy+P.y11,P.cx+P.x11),C),M.arc(P.cx,P.cy,U,i(P.y11,P.x11),i(P.y01,P.x01),!C))):M.arc(0,0,m,D,I,C):M.lineTo(W,X)}else M.moveTo(0,0);if(M.closePath(),r)return M=null,r+\"\"||null}return S.centroid=function(){var e=(+t.apply(this,arguments)+ +o.apply(this,arguments))/2,r=(+k.apply(this,arguments)+ +T.apply(this,arguments))/2-h/2;return[a(r)*e,l(r)*e]},S.innerRadius=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),S):t},S.outerRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),S):o},S.cornerRadius=function(t){return arguments.length?(_=\"function\"==typeof t?t:r(+t),S):_},S.padRadius=function(t){return arguments.length?(w=null==t?null:\"function\"==typeof t?t:r(+t),S):w},S.startAngle=function(t){return arguments.length?(k=\"function\"==typeof t?t:r(+t),S):k},S.endAngle=function(t){return arguments.length?(T=\"function\"==typeof t?t:r(+t),S):T},S.padAngle=function(t){return arguments.length?(A=\"function\"==typeof t?t:r(+t),S):A},S.context=function(t){return arguments.length?(M=null==t?null:t,S):M},S},t.area=M,t.line=A,t.pie=function(){var t=E,e=S,n=null,i=r(0),a=r(p),o=r(0);function s(r){var s,l,c,u,h,f=r.length,d=0,g=new Array(f),v=new Array(f),m=+i.apply(this,arguments),y=Math.min(p,Math.max(-p,a.apply(this,arguments)-m)),x=Math.min(Math.abs(y)/f,o.apply(this,arguments)),b=x*(y<0?-1:1);for(s=0;s<f;++s)(h=v[g[s]=s]=+t(r[s],s,r))>0&&(d+=h);for(null!=e?g.sort(function(t,r){return e(v[t],v[r])}):null!=n&&g.sort(function(t,e){return n(r[t],r[e])}),s=0,c=d?(y-f*b)/d:0;s<f;++s,m=u)l=g[s],u=m+((h=v[l])>0?h*c:0)+b,v[l]={data:r[l],index:s,value:h,startAngle:m,endAngle:u,padAngle:x};return v}return s.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),s):t},s.sortValues=function(t){return arguments.length?(e=t,n=null,s):e},s.sort=function(t){return arguments.length?(n=t,e=null,s):n},s.startAngle=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),s):i},s.endAngle=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),s):a},s.padAngle=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),s):o},s},t.areaRadial=I,t.radialArea=I,t.lineRadial=z,t.radialLine=z,t.pointRadial=D,t.linkHorizontal=function(){return N(j)},t.linkVertical=function(){return N(U)},t.linkRadial=function(){var t=N(V);return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t},t.symbol=function(){var t=r(q),n=r(64),i=null;function a(){var r;if(i||(i=r=e.path()),t.apply(this,arguments).draw(i,+n.apply(this,arguments)),r)return i=null,r+\"\"||null}return a.type=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(e),a):t},a.size=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),a):n},a.context=function(t){return arguments.length?(i=null==t?null:t,a):i},a},t.symbols=ot,t.symbolCircle=q,t.symbolCross=H,t.symbolDiamond=W,t.symbolSquare=$,t.symbolStar=K,t.symbolTriangle=tt,t.symbolWye=at,t.curveBasisClosed=function(t){return new ut(t)},t.curveBasisOpen=function(t){return new ht(t)},t.curveBasis=function(t){return new ct(t)},t.curveBundle=pt,t.curveCardinalClosed=yt,t.curveCardinalOpen=bt,t.curveCardinal=vt,t.curveCatmullRomClosed=At,t.curveCatmullRomOpen=St,t.curveCatmullRom=kt,t.curveLinearClosed=function(t){return new Et(t)},t.curveLinear=w,t.curveMonotoneX=function(t){return new zt(t)},t.curveMonotoneY=function(t){return new It(t)},t.curveNatural=function(t){return new Rt(t)},t.curveStep=function(t){return new Bt(t,.5)},t.curveStepAfter=function(t){return new Bt(t,1)},t.curveStepBefore=function(t){return new Bt(t,0)},t.stack=function(){var t=r([]),e=jt,n=Nt,i=Ut;function a(r){var a,o,s=t.apply(this,arguments),l=r.length,c=s.length,u=new Array(c);for(a=0;a<c;++a){for(var h,f=s[a],p=u[a]=new Array(l),d=0;d<l;++d)p[d]=h=[0,+i(r[d],f,d,r)],h.data=r[d];p.key=f}for(a=0,o=e(u);a<c;++a)u[o[a]].index=a;return n(u,o),u}return a.keys=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(R.call(e)),a):t},a.value=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a):i},a.order=function(t){return arguments.length?(e=null==t?jt:\"function\"==typeof t?t:r(R.call(t)),a):e},a.offset=function(t){return arguments.length?(n=null==t?Nt:t,a):n},a},t.stackOffsetExpand=function(t,e){if((n=t.length)>0){for(var r,n,i,a=0,o=t[0].length;a<o;++a){for(i=r=0;r<n;++r)i+=t[r][a][1]||0;if(i)for(r=0;r<n;++r)t[r][a][1]/=i}Nt(t,e)}},t.stackOffsetDiverging=function(t,e){if((s=t.length)>1)for(var r,n,i,a,o,s,l=0,c=t[e[0]].length;l<c;++l)for(a=o=0,r=0;r<s;++r)(i=(n=t[e[r]][l])[1]-n[0])>=0?(n[0]=a,n[1]=a+=i):i<0?(n[1]=o,n[0]=o+=i):n[0]=a},t.stackOffsetNone=Nt,t.stackOffsetSilhouette=function(t,e){if((r=t.length)>0){for(var r,n=0,i=t[e[0]],a=i.length;n<a;++n){for(var o=0,s=0;o<r;++o)s+=t[o][n][1]||0;i[n][1]+=i[n][0]=-s/2}Nt(t,e)}},t.stackOffsetWiggle=function(t,e){if((i=t.length)>0&&(n=(r=t[e[0]]).length)>0){for(var r,n,i,a=0,o=1;o<n;++o){for(var s=0,l=0,c=0;s<i;++s){for(var u=t[e[s]],h=u[o][1]||0,f=(h-(u[o-1][1]||0))/2,p=0;p<s;++p){var d=t[e[p]];f+=(d[o][1]||0)-(d[o-1][1]||0)}l+=h,c+=f*h}r[o-1][1]+=r[o-1][0]=a,l&&(a-=c/l)}r[o-1][1]+=r[o-1][0]=a,Nt(t,e)}},t.stackOrderAppearance=Vt,t.stackOrderAscending=Ht,t.stackOrderDescending=function(t){return Ht(t).reverse()},t.stackOrderInsideOut=function(t){var e,r,n=t.length,i=t.map(Gt),a=Vt(t),o=0,s=0,l=[],c=[];for(e=0;e<n;++e)r=a[e],o<s?(o+=i[r],l.push(r)):(s+=i[r],c.push(r));return c.reverse().concat(l)},t.stackOrderNone=jt,t.stackOrderReverse=function(t){return jt(t).reverse()},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-path\")):i(n.d3=n.d3||{},n.d3)},{\"d3-path\":159}],162:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e,r,n=0,i=0,a=0,o=1e3,s=0,l=0,c=0,u=\"object\"==typeof performance&&performance.now?performance:Date,h=\"object\"==typeof window&&window.requestAnimationFrame?window.requestAnimationFrame.bind(window):function(t){setTimeout(t,17)};function f(){return l||(h(p),l=u.now()+c)}function p(){l=0}function d(){this._call=this._time=this._next=null}function g(t,e,r){var n=new d;return n.restart(t,e,r),n}function v(){f(),++n;for(var t,r=e;r;)(t=l-r._time)>=0&&r._call.call(null,t),r=r._next;--n}function m(){l=(s=u.now())+c,n=i=0;try{v()}finally{n=0,function(){var t,n,i=e,a=1/0;for(;i;)i._call?(a>i._time&&(a=i._time),t=i,i=i._next):(n=i._next,i._next=null,i=t?t._next=n:e=n);r=t,x(a)}(),l=0}}function y(){var t=u.now(),e=t-s;e>o&&(c-=e,s=t)}function x(t){n||(i&&(i=clearTimeout(i)),t-l>24?(t<1/0&&(i=setTimeout(m,t-u.now()-c)),a&&(a=clearInterval(a))):(a||(s=u.now(),a=setInterval(y,o)),n=1,h(m)))}d.prototype=g.prototype={constructor:d,restart:function(t,n,i){if(\"function\"!=typeof t)throw new TypeError(\"callback is not a function\");i=(null==i?f():+i)+(null==n?0:+n),this._next||r===this||(r?r._next=this:e=this,r=this),this._call=t,this._time=i,x()},stop:function(){this._call&&(this._call=null,this._time=1/0,x())}};t.now=f,t.timer=g,t.timerFlush=v,t.timeout=function(t,e,r){var n=new d;return e=null==e?0:+e,n.restart(function(r){n.stop(),t(r+e)},e,r),n},t.interval=function(t,e,r){var n=new d,i=e;return null==e?(n.restart(t,e,r),n):(e=+e,r=null==r?f():+r,n.restart(function a(o){o+=i,n.restart(a,i+=e,r),t(o)},e,r),n)},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],163:[function(t,e,r){!function(){var t={version:\"3.5.17\"},r=[].slice,n=function(t){return r.call(t)},i=this.document;function a(t){return t&&(t.ownerDocument||t.document||t).documentElement}function o(t){return t&&(t.ownerDocument&&t.ownerDocument.defaultView||t.document&&t||t.defaultView)}if(i)try{n(i.documentElement.childNodes)[0].nodeType}catch(t){n=function(t){for(var e=t.length,r=new Array(e);e--;)r[e]=t[e];return r}}if(Date.now||(Date.now=function(){return+new Date}),i)try{i.createElement(\"DIV\").style.setProperty(\"opacity\",0,\"\")}catch(t){var s=this.Element.prototype,l=s.setAttribute,c=s.setAttributeNS,u=this.CSSStyleDeclaration.prototype,h=u.setProperty;s.setAttribute=function(t,e){l.call(this,t,e+\"\")},s.setAttributeNS=function(t,e,r){c.call(this,t,e,r+\"\")},u.setProperty=function(t,e,r){h.call(this,t,e+\"\",r)}}function f(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function p(t){return null===t?NaN:+t}function d(t){return!isNaN(t)}function g(t){return{left:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}t.ascending=f,t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.min=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&r>n&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&r>n&&(r=n)}return r},t.max=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&n>r&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&n>r&&(r=n)}return r},t.extent=function(t,e){var r,n,i,a=-1,o=t.length;if(1===arguments.length){for(;++a<o;)if(null!=(n=t[a])&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=t[a])&&(r>n&&(r=n),i<n&&(i=n))}else{for(;++a<o;)if(null!=(n=e.call(t,t[a],a))&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=e.call(t,t[a],a))&&(r>n&&(r=n),i<n&&(i=n))}return[r,i]},t.sum=function(t,e){var r,n=0,i=t.length,a=-1;if(1===arguments.length)for(;++a<i;)d(r=+t[a])&&(n+=r);else for(;++a<i;)d(r=+e.call(t,t[a],a))&&(n+=r);return n},t.mean=function(t,e){var r,n=0,i=t.length,a=-1,o=i;if(1===arguments.length)for(;++a<i;)d(r=p(t[a]))?n+=r:--o;else for(;++a<i;)d(r=p(e.call(t,t[a],a)))?n+=r:--o;if(o)return n/o},t.quantile=function(t,e){var r=(t.length-1)*e+1,n=Math.floor(r),i=+t[n-1],a=r-n;return a?i+a*(t[n]-i):i},t.median=function(e,r){var n,i=[],a=e.length,o=-1;if(1===arguments.length)for(;++o<a;)d(n=p(e[o]))&&i.push(n);else for(;++o<a;)d(n=p(r.call(e,e[o],o)))&&i.push(n);if(i.length)return t.quantile(i.sort(f),.5)},t.variance=function(t,e){var r,n,i=t.length,a=0,o=0,s=-1,l=0;if(1===arguments.length)for(;++s<i;)d(r=p(t[s]))&&(o+=(n=r-a)*(r-(a+=n/++l)));else for(;++s<i;)d(r=p(e.call(t,t[s],s)))&&(o+=(n=r-a)*(r-(a+=n/++l)));if(l>1)return o/(l-1)},t.deviation=function(){var e=t.variance.apply(this,arguments);return e?Math.sqrt(e):e};var v=g(f);function m(t){return t.length}t.bisectLeft=v.left,t.bisect=t.bisectRight=v.right,t.bisector=function(t){return g(1===t.length?function(e,r){return f(t(e),r)}:t)},t.shuffle=function(t,e,r){(a=arguments.length)<3&&(r=t.length,a<2&&(e=0));for(var n,i,a=r-e;a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.pairs=function(t){for(var e=0,r=t.length-1,n=t[0],i=new Array(r<0?0:r);e<r;)i[e]=[n,n=t[++e]];return i},t.transpose=function(e){if(!(a=e.length))return[];for(var r=-1,n=t.min(e,m),i=new Array(n);++r<n;)for(var a,o=-1,s=i[r]=new Array(a);++o<a;)s[o]=e[o][r];return i},t.zip=function(){return t.transpose(arguments)},t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r};var y=Math.abs;function x(t,e){for(var r in e)Object.defineProperty(t.prototype,r,{value:e[r],enumerable:!1})}function b(){this._=Object.create(null)}t.range=function(t,e,r){if(arguments.length<3&&(r=1,arguments.length<2&&(e=t,t=0)),(e-t)/r==1/0)throw new Error(\"infinite range\");var n,i=[],a=function(t){var e=1;for(;t*e%1;)e*=10;return e}(y(r)),o=-1;if(t*=a,e*=a,(r*=a)<0)for(;(n=t+r*++o)>e;)i.push(n/a);else for(;(n=t+r*++o)<e;)i.push(n/a);return i},t.map=function(t,e){var r=new b;if(t instanceof b)t.forEach(function(t,e){r.set(t,e)});else if(Array.isArray(t)){var n,i=-1,a=t.length;if(1===arguments.length)for(;++i<a;)r.set(i,t[i]);else for(;++i<a;)r.set(e.call(t,n=t[i],i),n)}else for(var o in t)r.set(o,t[o]);return r};var _=\"__proto__\",w=\"\\0\";function k(t){return(t+=\"\")===_||t[0]===w?w+t:t}function T(t){return(t+=\"\")[0]===w?t.slice(1):t}function A(t){return k(t)in this._}function M(t){return(t=k(t))in this._&&delete this._[t]}function S(){var t=[];for(var e in this._)t.push(T(e));return t}function E(){var t=0;for(var e in this._)++t;return t}function C(){for(var t in this._)return!1;return!0}function L(){this._=Object.create(null)}function P(t){return t}function O(t,e,r){return function(){var n=r.apply(e,arguments);return n===e?t:n}}function z(t,e){if(e in t)return e;e=e.charAt(0).toUpperCase()+e.slice(1);for(var r=0,n=I.length;r<n;++r){var i=I[r]+e;if(i in t)return i}}x(b,{has:A,get:function(t){return this._[k(t)]},set:function(t,e){return this._[k(t)]=e},remove:M,keys:S,values:function(){var t=[];for(var e in this._)t.push(this._[e]);return t},entries:function(){var t=[];for(var e in this._)t.push({key:T(e),value:this._[e]});return t},size:E,empty:C,forEach:function(t){for(var e in this._)t.call(this,T(e),this._[e])}}),t.nest=function(){var e,r,n={},i=[],a=[];function o(t,a,s){if(s>=i.length)return r?r.call(n,a):e?a.sort(e):a;for(var l,c,u,h,f=-1,p=a.length,d=i[s++],g=new b;++f<p;)(h=g.get(l=d(c=a[f])))?h.push(c):g.set(l,[c]);return t?(c=t(),u=function(e,r){c.set(e,o(t,r,s))}):(c={},u=function(e,r){c[e]=o(t,r,s)}),g.forEach(u),c}return n.map=function(t,e){return o(e,t,0)},n.entries=function(e){return function t(e,r){if(r>=i.length)return e;var n=[],o=a[r++];return e.forEach(function(e,i){n.push({key:e,values:t(i,r)})}),o?n.sort(function(t,e){return o(t.key,e.key)}):n}(o(t.map,e,0),0)},n.key=function(t){return i.push(t),n},n.sortKeys=function(t){return a[i.length-1]=t,n},n.sortValues=function(t){return e=t,n},n.rollup=function(t){return r=t,n},n},t.set=function(t){var e=new L;if(t)for(var r=0,n=t.length;r<n;++r)e.add(t[r]);return e},x(L,{has:A,add:function(t){return this._[k(t+=\"\")]=!0,t},remove:M,values:S,size:E,empty:C,forEach:function(t){for(var e in this._)t.call(this,T(e))}}),t.behavior={},t.rebind=function(t,e){for(var r,n=1,i=arguments.length;++n<i;)t[r=arguments[n]]=O(t,e,e[r]);return t};var I=[\"webkit\",\"ms\",\"moz\",\"Moz\",\"o\",\"O\"];function D(){}function R(){}function F(t){var e=[],r=new b;function n(){for(var r,n=e,i=-1,a=n.length;++i<a;)(r=n[i].on)&&r.apply(this,arguments);return t}return n.on=function(n,i){var a,o=r.get(n);return arguments.length<2?o&&o.on:(o&&(o.on=null,e=e.slice(0,a=e.indexOf(o)).concat(e.slice(a+1)),r.remove(n)),i&&e.push(r.set(n,{on:i})),t)},n}function B(){t.event.preventDefault()}function N(){for(var e,r=t.event;e=r.sourceEvent;)r=e;return r}function j(e){for(var r=new R,n=0,i=arguments.length;++n<i;)r[arguments[n]]=F(r);return r.of=function(n,i){return function(a){try{var o=a.sourceEvent=t.event;a.target=e,t.event=a,r[a.type].apply(n,i)}finally{t.event=o}}},r}t.dispatch=function(){for(var t=new R,e=-1,r=arguments.length;++e<r;)t[arguments[e]]=F(t);return t},R.prototype.on=function(t,e){var r=t.indexOf(\".\"),n=\"\";if(r>=0&&(n=t.slice(r+1),t=t.slice(0,r)),t)return arguments.length<2?this[t].on(n):this[t].on(n,e);if(2===arguments.length){if(null==e)for(t in this)this.hasOwnProperty(t)&&this[t].on(n,null);return this}},t.event=null,t.requote=function(t){return t.replace(U,\"\\\\$&\")};var U=/[\\\\\\^\\$\\*\\+\\?\\|\\[\\]\\(\\)\\.\\{\\}]/g,V={}.__proto__?function(t,e){t.__proto__=e}:function(t,e){for(var r in e)t[r]=e[r]};function q(t){return V(t,W),t}var H=function(t,e){return e.querySelector(t)},G=function(t,e){return e.querySelectorAll(t)},Y=function(t,e){var r=t.matches||t[z(t,\"matchesSelector\")];return(Y=function(t,e){return r.call(t,e)})(t,e)};\"function\"==typeof Sizzle&&(H=function(t,e){return Sizzle(t,e)[0]||null},G=Sizzle,Y=Sizzle.matchesSelector),t.selection=function(){return t.select(i.documentElement)};var W=t.selection.prototype=[];function X(t){return\"function\"==typeof t?t:function(){return H(t,this)}}function Z(t){return\"function\"==typeof t?t:function(){return G(t,this)}}W.select=function(t){var e,r,n,i,a=[];t=X(t);for(var o=-1,s=this.length;++o<s;){a.push(e=[]),e.parentNode=(n=this[o]).parentNode;for(var l=-1,c=n.length;++l<c;)(i=n[l])?(e.push(r=t.call(i,i.__data__,l,o)),r&&\"__data__\"in i&&(r.__data__=i.__data__)):e.push(null)}return q(a)},W.selectAll=function(t){var e,r,i=[];t=Z(t);for(var a=-1,o=this.length;++a<o;)for(var s=this[a],l=-1,c=s.length;++l<c;)(r=s[l])&&(i.push(e=n(t.call(r,r.__data__,l,a))),e.parentNode=r);return q(i)};var J=\"http://www.w3.org/1999/xhtml\",K={svg:\"http://www.w3.org/2000/svg\",xhtml:J,xlink:\"http://www.w3.org/1999/xlink\",xml:\"http://www.w3.org/XML/1998/namespace\",xmlns:\"http://www.w3.org/2000/xmlns/\"};function $(e,r){return e=t.ns.qualify(e),null==r?e.local?function(){this.removeAttributeNS(e.space,e.local)}:function(){this.removeAttribute(e)}:\"function\"==typeof r?e.local?function(){var t=r.apply(this,arguments);null==t?this.removeAttributeNS(e.space,e.local):this.setAttributeNS(e.space,e.local,t)}:function(){var t=r.apply(this,arguments);null==t?this.removeAttribute(e):this.setAttribute(e,t)}:e.local?function(){this.setAttributeNS(e.space,e.local,r)}:function(){this.setAttribute(e,r)}}function Q(t){return t.trim().replace(/\\s+/g,\" \")}function tt(e){return new RegExp(\"(?:^|\\\\s+)\"+t.requote(e)+\"(?:\\\\s+|$)\",\"g\")}function et(t){return(t+\"\").trim().split(/^|\\s+/)}function rt(t,e){var r=(t=et(t).map(nt)).length;return\"function\"==typeof e?function(){for(var n=-1,i=e.apply(this,arguments);++n<r;)t[n](this,i)}:function(){for(var n=-1;++n<r;)t[n](this,e)}}function nt(t){var e=tt(t);return function(r,n){if(i=r.classList)return n?i.add(t):i.remove(t);var i=r.getAttribute(\"class\")||\"\";n?(e.lastIndex=0,e.test(i)||r.setAttribute(\"class\",Q(i+\" \"+t))):r.setAttribute(\"class\",Q(i.replace(e,\" \")))}}function it(t,e,r){return null==e?function(){this.style.removeProperty(t)}:\"function\"==typeof e?function(){var n=e.apply(this,arguments);null==n?this.style.removeProperty(t):this.style.setProperty(t,n,r)}:function(){this.style.setProperty(t,e,r)}}function at(t,e){return null==e?function(){delete this[t]}:\"function\"==typeof e?function(){var r=e.apply(this,arguments);null==r?delete this[t]:this[t]=r}:function(){this[t]=e}}function ot(e){return\"function\"==typeof e?e:(e=t.ns.qualify(e)).local?function(){return this.ownerDocument.createElementNS(e.space,e.local)}:function(){var t=this.ownerDocument,r=this.namespaceURI;return r===J&&t.documentElement.namespaceURI===J?t.createElement(e):t.createElementNS(r,e)}}function st(){var t=this.parentNode;t&&t.removeChild(this)}function lt(t){return{__data__:t}}function ct(t){return function(){return Y(this,t)}}function ut(t,e){for(var r=0,n=t.length;r<n;r++)for(var i,a=t[r],o=0,s=a.length;o<s;o++)(i=a[o])&&e(i,o,r);return t}function ht(t){return V(t,ft),t}t.ns={prefix:K,qualify:function(t){var e=t.indexOf(\":\"),r=t;return e>=0&&\"xmlns\"!==(r=t.slice(0,e))&&(t=t.slice(e+1)),K.hasOwnProperty(r)?{space:K[r],local:t}:t}},W.attr=function(e,r){if(arguments.length<2){if(\"string\"==typeof e){var n=this.node();return(e=t.ns.qualify(e)).local?n.getAttributeNS(e.space,e.local):n.getAttribute(e)}for(r in e)this.each($(r,e[r]));return this}return this.each($(e,r))},W.classed=function(t,e){if(arguments.length<2){if(\"string\"==typeof t){var r=this.node(),n=(t=et(t)).length,i=-1;if(e=r.classList){for(;++i<n;)if(!e.contains(t[i]))return!1}else for(e=r.getAttribute(\"class\");++i<n;)if(!tt(t[i]).test(e))return!1;return!0}for(e in t)this.each(rt(e,t[e]));return this}return this.each(rt(t,e))},W.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.each(it(r,t[r],e));return this}if(n<2){var i=this.node();return o(i).getComputedStyle(i,null).getPropertyValue(t)}r=\"\"}return this.each(it(t,e,r))},W.property=function(t,e){if(arguments.length<2){if(\"string\"==typeof t)return this.node()[t];for(e in t)this.each(at(e,t[e]));return this}return this.each(at(t,e))},W.text=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.textContent=null==e?\"\":e}:null==t?function(){this.textContent=\"\"}:function(){this.textContent=t}):this.node().textContent},W.html=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.innerHTML=null==e?\"\":e}:null==t?function(){this.innerHTML=\"\"}:function(){this.innerHTML=t}):this.node().innerHTML},W.append=function(t){return t=ot(t),this.select(function(){return this.appendChild(t.apply(this,arguments))})},W.insert=function(t,e){return t=ot(t),e=X(e),this.select(function(){return this.insertBefore(t.apply(this,arguments),e.apply(this,arguments)||null)})},W.remove=function(){return this.each(st)},W.data=function(t,e){var r,n,i=-1,a=this.length;if(!arguments.length){for(t=new Array(a=(r=this[0]).length);++i<a;)(n=r[i])&&(t[i]=n.__data__);return t}function o(t,r){var n,i,a,o=t.length,u=r.length,h=Math.min(o,u),f=new Array(u),p=new Array(u),d=new Array(o);if(e){var g,v=new b,m=new Array(o);for(n=-1;++n<o;)(i=t[n])&&(v.has(g=e.call(i,i.__data__,n))?d[n]=i:v.set(g,i),m[n]=g);for(n=-1;++n<u;)(i=v.get(g=e.call(r,a=r[n],n)))?!0!==i&&(f[n]=i,i.__data__=a):p[n]=lt(a),v.set(g,!0);for(n=-1;++n<o;)n in m&&!0!==v.get(m[n])&&(d[n]=t[n])}else{for(n=-1;++n<h;)i=t[n],a=r[n],i?(i.__data__=a,f[n]=i):p[n]=lt(a);for(;n<u;++n)p[n]=lt(r[n]);for(;n<o;++n)d[n]=t[n]}p.update=f,p.parentNode=f.parentNode=d.parentNode=t.parentNode,s.push(p),l.push(f),c.push(d)}var s=ht([]),l=q([]),c=q([]);if(\"function\"==typeof t)for(;++i<a;)o(r=this[i],t.call(r,r.parentNode.__data__,i));else for(;++i<a;)o(r=this[i],t);return l.enter=function(){return s},l.exit=function(){return c},l},W.datum=function(t){return arguments.length?this.property(\"__data__\",t):this.property(\"__data__\")},W.filter=function(t){var e,r,n,i=[];\"function\"!=typeof t&&(t=ct(t));for(var a=0,o=this.length;a<o;a++){i.push(e=[]),e.parentNode=(r=this[a]).parentNode;for(var s=0,l=r.length;s<l;s++)(n=r[s])&&t.call(n,n.__data__,s,a)&&e.push(n)}return q(i)},W.order=function(){for(var t=-1,e=this.length;++t<e;)for(var r,n=this[t],i=n.length-1,a=n[i];--i>=0;)(r=n[i])&&(a&&a!==r.nextSibling&&a.parentNode.insertBefore(r,a),a=r);return this},W.sort=function(t){t=function(t){arguments.length||(t=f);return function(e,r){return e&&r?t(e.__data__,r.__data__):!e-!r}}.apply(this,arguments);for(var e=-1,r=this.length;++e<r;)this[e].sort(t);return this.order()},W.each=function(t){return ut(this,function(e,r,n){t.call(e,e.__data__,r,n)})},W.call=function(t){var e=n(arguments);return t.apply(e[0]=this,e),this},W.empty=function(){return!this.node()},W.node=function(){for(var t=0,e=this.length;t<e;t++)for(var r=this[t],n=0,i=r.length;n<i;n++){var a=r[n];if(a)return a}return null},W.size=function(){var t=0;return ut(this,function(){++t}),t};var ft=[];function pt(e,r,i){var a=\"__on\"+e,o=e.indexOf(\".\"),s=gt;o>0&&(e=e.slice(0,o));var l=dt.get(e);function c(){var t=this[a];t&&(this.removeEventListener(e,t,t.$),delete this[a])}return l&&(e=l,s=vt),o?r?function(){var t=s(r,n(arguments));c.call(this),this.addEventListener(e,this[a]=t,t.$=i),t._=r}:c:r?D:function(){var r,n=new RegExp(\"^__on([^.]+)\"+t.requote(e)+\"$\");for(var i in this)if(r=i.match(n)){var a=this[i];this.removeEventListener(r[1],a,a.$),delete this[i]}}}t.selection.enter=ht,t.selection.enter.prototype=ft,ft.append=W.append,ft.empty=W.empty,ft.node=W.node,ft.call=W.call,ft.size=W.size,ft.select=function(t){for(var e,r,n,i,a,o=[],s=-1,l=this.length;++s<l;){n=(i=this[s]).update,o.push(e=[]),e.parentNode=i.parentNode;for(var c=-1,u=i.length;++c<u;)(a=i[c])?(e.push(n[c]=r=t.call(i.parentNode,a.__data__,c,s)),r.__data__=a.__data__):e.push(null)}return q(o)},ft.insert=function(t,e){var r,n,i;return arguments.length<2&&(r=this,e=function(t,e,a){var o,s=r[a].update,l=s.length;for(a!=i&&(i=a,n=0),e>=n&&(n=e+1);!(o=s[n])&&++n<l;);return o}),W.insert.call(this,t,e)},t.select=function(t){var e;return\"string\"==typeof t?(e=[H(t,i)]).parentNode=i.documentElement:(e=[t]).parentNode=a(t),q([e])},t.selectAll=function(t){var e;return\"string\"==typeof t?(e=n(G(t,i))).parentNode=i.documentElement:(e=n(t)).parentNode=null,q([e])},W.on=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=!1),t)this.each(pt(r,t[r],e));return this}if(n<2)return(n=this.node()[\"__on\"+t])&&n._;r=!1}return this.each(pt(t,e,r))};var dt=t.map({mouseenter:\"mouseover\",mouseleave:\"mouseout\"});function gt(e,r){return function(n){var i=t.event;t.event=n,r[0]=this.__data__;try{e.apply(this,r)}finally{t.event=i}}}function vt(t,e){var r=gt(t,e);return function(t){var e=t.relatedTarget;e&&(e===this||8&e.compareDocumentPosition(this))||r.call(this,t)}}i&&dt.forEach(function(t){\"on\"+t in i&&dt.remove(t)});var mt,yt=0;function xt(e){var r=\".dragsuppress-\"+ ++yt,n=\"click\"+r,i=t.select(o(e)).on(\"touchmove\"+r,B).on(\"dragstart\"+r,B).on(\"selectstart\"+r,B);if(null==mt&&(mt=!(\"onselectstart\"in e)&&z(e.style,\"userSelect\")),mt){var s=a(e).style,l=s[mt];s[mt]=\"none\"}return function(t){if(i.on(r,null),mt&&(s[mt]=l),t){var e=function(){i.on(n,null)};i.on(n,function(){B(),e()},!0),setTimeout(e,0)}}}t.mouse=function(t){return _t(t,N())};var bt=this.navigator&&/WebKit/.test(this.navigator.userAgent)?-1:0;function _t(e,r){r.changedTouches&&(r=r.changedTouches[0]);var n=e.ownerSVGElement||e;if(n.createSVGPoint){var i=n.createSVGPoint();if(bt<0){var a=o(e);if(a.scrollX||a.scrollY){var s=(n=t.select(\"body\").append(\"svg\").style({position:\"absolute\",top:0,left:0,margin:0,padding:0,border:\"none\"},\"important\"))[0][0].getScreenCTM();bt=!(s.f||s.e),n.remove()}}return bt?(i.x=r.pageX,i.y=r.pageY):(i.x=r.clientX,i.y=r.clientY),[(i=i.matrixTransform(e.getScreenCTM().inverse())).x,i.y]}var l=e.getBoundingClientRect();return[r.clientX-l.left-e.clientLeft,r.clientY-l.top-e.clientTop]}function wt(){return t.event.changedTouches[0].identifier}t.touch=function(t,e,r){if(arguments.length<3&&(r=e,e=N().changedTouches),e)for(var n,i=0,a=e.length;i<a;++i)if((n=e[i]).identifier===r)return _t(t,n)},t.behavior.drag=function(){var e=j(a,\"drag\",\"dragstart\",\"dragend\"),r=null,n=s(D,t.mouse,o,\"mousemove\",\"mouseup\"),i=s(wt,t.touch,P,\"touchmove\",\"touchend\");function a(){this.on(\"mousedown.drag\",n).on(\"touchstart.drag\",i)}function s(n,i,a,o,s){return function(){var l,c=t.event.target.correspondingElement||t.event.target,u=this.parentNode,h=e.of(this,arguments),f=0,p=n(),d=\".drag\"+(null==p?\"\":\"-\"+p),g=t.select(a(c)).on(o+d,function(){var t,e,r=i(u,p);if(!r)return;t=r[0]-m[0],e=r[1]-m[1],f|=t|e,m=r,h({type:\"drag\",x:r[0]+l[0],y:r[1]+l[1],dx:t,dy:e})}).on(s+d,function(){if(!i(u,p))return;g.on(o+d,null).on(s+d,null),v(f),h({type:\"dragend\"})}),v=xt(c),m=i(u,p);l=r?[(l=r.apply(this,arguments)).x-m[0],l.y-m[1]]:[0,0],h({type:\"dragstart\"})}}return a.origin=function(t){return arguments.length?(r=t,a):r},t.rebind(a,e,\"on\")},t.touches=function(t,e){return arguments.length<2&&(e=N().touches),e?n(e).map(function(e){var r=_t(t,e);return r.identifier=e.identifier,r}):[]};var kt=1e-6,Tt=kt*kt,At=Math.PI,Mt=2*At,St=Mt-kt,Et=At/2,Ct=At/180,Lt=180/At;function Pt(t){return t>0?1:t<0?-1:0}function Ot(t,e,r){return(e[0]-t[0])*(r[1]-t[1])-(e[1]-t[1])*(r[0]-t[0])}function zt(t){return t>1?0:t<-1?At:Math.acos(t)}function It(t){return t>1?Et:t<-1?-Et:Math.asin(t)}function Dt(t){return((t=Math.exp(t))+1/t)/2}function Rt(t){return(t=Math.sin(t/2))*t}var Ft=Math.SQRT2;t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,h=l-a,f=u*u+h*h;if(f<Tt)n=Math.log(c/o)/Ft,r=function(t){return[i+t*u,a+t*h,o*Math.exp(Ft*t*n)]};else{var p=Math.sqrt(f),d=(c*c-o*o+4*f)/(2*o*2*p),g=(c*c-o*o-4*f)/(2*c*2*p),v=Math.log(Math.sqrt(d*d+1)-d),m=Math.log(Math.sqrt(g*g+1)-g);n=(m-v)/Ft,r=function(t){var e,r=t*n,s=Dt(v),l=o/(2*p)*(s*(e=Ft*r+v,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(v));return[i+l*u,a+l*h,o*s/Dt(Ft*r+v)]}}return r.duration=1e3*n,r},t.behavior.zoom=function(){var e,r,n,a,s,l,c,u,h,f={x:0,y:0,k:1},p=[960,500],d=jt,g=250,v=0,m=\"mousedown.zoom\",y=\"mousemove.zoom\",x=\"mouseup.zoom\",b=\"touchstart.zoom\",_=j(w,\"zoomstart\",\"zoom\",\"zoomend\");function w(t){t.on(m,P).on(Nt+\".zoom\",z).on(\"dblclick.zoom\",I).on(b,O)}function k(t){return[(t[0]-f.x)/f.k,(t[1]-f.y)/f.k]}function T(t){f.k=Math.max(d[0],Math.min(d[1],t))}function A(t,e){e=function(t){return[t[0]*f.k+f.x,t[1]*f.k+f.y]}(e),f.x+=t[0]-e[0],f.y+=t[1]-e[1]}function M(e,n,i,a){e.__chart__={x:f.x,y:f.y,k:f.k},T(Math.pow(2,a)),A(r=n,i),e=t.select(e),g>0&&(e=e.transition().duration(g)),e.call(w.event)}function S(){c&&c.domain(l.range().map(function(t){return(t-f.x)/f.k}).map(l.invert)),h&&h.domain(u.range().map(function(t){return(t-f.y)/f.k}).map(u.invert))}function E(t){v++||t({type:\"zoomstart\"})}function C(t){S(),t({type:\"zoom\",scale:f.k,translate:[f.x,f.y]})}function L(t){--v||(t({type:\"zoomend\"}),r=null)}function P(){var e=this,r=_.of(e,arguments),n=0,i=t.select(o(e)).on(y,function(){n=1,A(t.mouse(e),a),C(r)}).on(x,function(){i.on(y,null).on(x,null),s(n),L(r)}),a=k(t.mouse(e)),s=xt(e);hs.call(e),E(r)}function O(){var e,r=this,n=_.of(r,arguments),i={},a=0,o=\".zoom-\"+t.event.changedTouches[0].identifier,l=\"touchmove\"+o,c=\"touchend\"+o,u=[],h=t.select(r),p=xt(r);function d(){var n=t.touches(r);return e=f.k,n.forEach(function(t){t.identifier in i&&(i[t.identifier]=k(t))}),n}function g(){var e=t.event.target;t.select(e).on(l,v).on(c,y),u.push(e);for(var n=t.event.changedTouches,o=0,h=n.length;o<h;++o)i[n[o].identifier]=null;var p=d(),g=Date.now();if(1===p.length){if(g-s<500){var m=p[0];M(r,m,i[m.identifier],Math.floor(Math.log(f.k)/Math.LN2)+1),B()}s=g}else if(p.length>1){m=p[0];var x=p[1],b=m[0]-x[0],_=m[1]-x[1];a=b*b+_*_}}function v(){var o,l,c,u,h=t.touches(r);hs.call(r);for(var f=0,p=h.length;f<p;++f,u=null)if(c=h[f],u=i[c.identifier]){if(l)break;o=c,l=u}if(u){var d=(d=c[0]-o[0])*d+(d=c[1]-o[1])*d,g=a&&Math.sqrt(d/a);o=[(o[0]+c[0])/2,(o[1]+c[1])/2],l=[(l[0]+u[0])/2,(l[1]+u[1])/2],T(g*e)}s=null,A(o,l),C(n)}function y(){if(t.event.touches.length){for(var e=t.event.changedTouches,r=0,a=e.length;r<a;++r)delete i[e[r].identifier];for(var s in i)return void d()}t.selectAll(u).on(o,null),h.on(m,P).on(b,O),p(),L(n)}g(),E(n),h.on(m,null).on(b,g)}function z(){var i=_.of(this,arguments);a?clearTimeout(a):(hs.call(this),e=k(r=n||t.mouse(this)),E(i)),a=setTimeout(function(){a=null,L(i)},50),B(),T(Math.pow(2,.002*Bt())*f.k),A(r,e),C(i)}function I(){var e=t.mouse(this),r=Math.log(f.k)/Math.LN2;M(this,e,k(e),t.event.shiftKey?Math.ceil(r)-1:Math.floor(r)+1)}return Nt||(Nt=\"onwheel\"in i?(Bt=function(){return-t.event.deltaY*(t.event.deltaMode?120:1)},\"wheel\"):\"onmousewheel\"in i?(Bt=function(){return t.event.wheelDelta},\"mousewheel\"):(Bt=function(){return-t.event.detail},\"MozMousePixelScroll\")),w.event=function(e){e.each(function(){var e=_.of(this,arguments),n=f;ds?t.select(this).transition().each(\"start.zoom\",function(){f=this.__chart__||{x:0,y:0,k:1},E(e)}).tween(\"zoom:zoom\",function(){var i=p[0],a=p[1],o=r?r[0]:i/2,s=r?r[1]:a/2,l=t.interpolateZoom([(o-f.x)/f.k,(s-f.y)/f.k,i/f.k],[(o-n.x)/n.k,(s-n.y)/n.k,i/n.k]);return function(t){var r=l(t),n=i/r[2];this.__chart__=f={x:o-r[0]*n,y:s-r[1]*n,k:n},C(e)}}).each(\"interrupt.zoom\",function(){L(e)}).each(\"end.zoom\",function(){L(e)}):(this.__chart__=f,E(e),C(e),L(e))})},w.translate=function(t){return arguments.length?(f={x:+t[0],y:+t[1],k:f.k},S(),w):[f.x,f.y]},w.scale=function(t){return arguments.length?(f={x:f.x,y:f.y,k:null},T(+t),S(),w):f.k},w.scaleExtent=function(t){return arguments.length?(d=null==t?jt:[+t[0],+t[1]],w):d},w.center=function(t){return arguments.length?(n=t&&[+t[0],+t[1]],w):n},w.size=function(t){return arguments.length?(p=t&&[+t[0],+t[1]],w):p},w.duration=function(t){return arguments.length?(g=+t,w):g},w.x=function(t){return arguments.length?(c=t,l=t.copy(),f={x:0,y:0,k:1},w):c},w.y=function(t){return arguments.length?(h=t,u=t.copy(),f={x:0,y:0,k:1},w):h},t.rebind(w,_,\"on\")};var Bt,Nt,jt=[0,1/0];function Ut(){}function Vt(t,e,r){return this instanceof Vt?(this.h=+t,this.s=+e,void(this.l=+r)):arguments.length<2?t instanceof Vt?new Vt(t.h,t.s,t.l):ue(\"\"+t,he,Vt):new Vt(t,e,r)}t.color=Ut,Ut.prototype.toString=function(){return this.rgb()+\"\"},t.hsl=Vt;var qt=Vt.prototype=new Ut;function Ht(t,e,r){var n,i;function a(t){return Math.round(255*function(t){return t>360?t-=360:t<0&&(t+=360),t<60?n+(i-n)*t/60:t<180?i:t<240?n+(i-n)*(240-t)/60:n}(t))}return t=isNaN(t)?0:(t%=360)<0?t+360:t,e=isNaN(e)?0:e<0?0:e>1?1:e,n=2*(r=r<0?0:r>1?1:r)-(i=r<=.5?r*(1+e):r+e-r*e),new ae(a(t+120),a(t),a(t-120))}function Gt(e,r,n){return this instanceof Gt?(this.h=+e,this.c=+r,void(this.l=+n)):arguments.length<2?e instanceof Gt?new Gt(e.h,e.c,e.l):ee(e instanceof Xt?e.l:(e=fe((e=t.rgb(e)).r,e.g,e.b)).l,e.a,e.b):new Gt(e,r,n)}qt.brighter=function(t){return t=Math.pow(.7,arguments.length?t:1),new Vt(this.h,this.s,this.l/t)},qt.darker=function(t){return t=Math.pow(.7,arguments.length?t:1),new Vt(this.h,this.s,t*this.l)},qt.rgb=function(){return Ht(this.h,this.s,this.l)},t.hcl=Gt;var Yt=Gt.prototype=new Ut;function Wt(t,e,r){return isNaN(t)&&(t=0),isNaN(e)&&(e=0),new Xt(r,Math.cos(t*=Ct)*e,Math.sin(t)*e)}function Xt(t,e,r){return this instanceof Xt?(this.l=+t,this.a=+e,void(this.b=+r)):arguments.length<2?t instanceof Xt?new Xt(t.l,t.a,t.b):t instanceof Gt?Wt(t.h,t.c,t.l):fe((t=ae(t)).r,t.g,t.b):new Xt(t,e,r)}Yt.brighter=function(t){return new Gt(this.h,this.c,Math.min(100,this.l+Zt*(arguments.length?t:1)))},Yt.darker=function(t){return new Gt(this.h,this.c,Math.max(0,this.l-Zt*(arguments.length?t:1)))},Yt.rgb=function(){return Wt(this.h,this.c,this.l).rgb()},t.lab=Xt;var Zt=18,Jt=.95047,Kt=1,$t=1.08883,Qt=Xt.prototype=new Ut;function te(t,e,r){var n=(t+16)/116,i=n+e/500,a=n-r/200;return new ae(ie(3.2404542*(i=re(i)*Jt)-1.5371385*(n=re(n)*Kt)-.4985314*(a=re(a)*$t)),ie(-.969266*i+1.8760108*n+.041556*a),ie(.0556434*i-.2040259*n+1.0572252*a))}function ee(t,e,r){return t>0?new Gt(Math.atan2(r,e)*Lt,Math.sqrt(e*e+r*r),t):new Gt(NaN,NaN,t)}function re(t){return t>.206893034?t*t*t:(t-4/29)/7.787037}function ne(t){return t>.008856?Math.pow(t,1/3):7.787037*t+4/29}function ie(t){return Math.round(255*(t<=.00304?12.92*t:1.055*Math.pow(t,1/2.4)-.055))}function ae(t,e,r){return this instanceof ae?(this.r=~~t,this.g=~~e,void(this.b=~~r)):arguments.length<2?t instanceof ae?new ae(t.r,t.g,t.b):ue(\"\"+t,ae,Ht):new ae(t,e,r)}function oe(t){return new ae(t>>16,t>>8&255,255&t)}function se(t){return oe(t)+\"\"}Qt.brighter=function(t){return new Xt(Math.min(100,this.l+Zt*(arguments.length?t:1)),this.a,this.b)},Qt.darker=function(t){return new Xt(Math.max(0,this.l-Zt*(arguments.length?t:1)),this.a,this.b)},Qt.rgb=function(){return te(this.l,this.a,this.b)},t.rgb=ae;var le=ae.prototype=new Ut;function ce(t){return t<16?\"0\"+Math.max(0,t).toString(16):Math.min(255,t).toString(16)}function ue(t,e,r){var n,i,a,o=0,s=0,l=0;if(n=/([a-z]+)\\((.*)\\)/.exec(t=t.toLowerCase()))switch(i=n[2].split(\",\"),n[1]){case\"hsl\":return r(parseFloat(i[0]),parseFloat(i[1])/100,parseFloat(i[2])/100);case\"rgb\":return e(de(i[0]),de(i[1]),de(i[2]))}return(a=ge.get(t))?e(a.r,a.g,a.b):(null==t||\"#\"!==t.charAt(0)||isNaN(a=parseInt(t.slice(1),16))||(4===t.length?(o=(3840&a)>>4,o|=o>>4,s=240&a,s|=s>>4,l=15&a,l|=l<<4):7===t.length&&(o=(16711680&a)>>16,s=(65280&a)>>8,l=255&a)),e(o,s,l))}function he(t,e,r){var n,i,a=Math.min(t/=255,e/=255,r/=255),o=Math.max(t,e,r),s=o-a,l=(o+a)/2;return s?(i=l<.5?s/(o+a):s/(2-o-a),n=t==o?(e-r)/s+(e<r?6:0):e==o?(r-t)/s+2:(t-e)/s+4,n*=60):(n=NaN,i=l>0&&l<1?0:n),new Vt(n,i,l)}function fe(t,e,r){var n=ne((.4124564*(t=pe(t))+.3575761*(e=pe(e))+.1804375*(r=pe(r)))/Jt),i=ne((.2126729*t+.7151522*e+.072175*r)/Kt);return Xt(116*i-16,500*(n-i),200*(i-ne((.0193339*t+.119192*e+.9503041*r)/$t)))}function pe(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function de(t){var e=parseFloat(t);return\"%\"===t.charAt(t.length-1)?Math.round(2.55*e):e}le.brighter=function(t){t=Math.pow(.7,arguments.length?t:1);var e=this.r,r=this.g,n=this.b,i=30;return e||r||n?(e&&e<i&&(e=i),r&&r<i&&(r=i),n&&n<i&&(n=i),new ae(Math.min(255,e/t),Math.min(255,r/t),Math.min(255,n/t))):new ae(i,i,i)},le.darker=function(t){return new ae((t=Math.pow(.7,arguments.length?t:1))*this.r,t*this.g,t*this.b)},le.hsl=function(){return he(this.r,this.g,this.b)},le.toString=function(){return\"#\"+ce(this.r)+ce(this.g)+ce(this.b)};var ge=t.map({aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074});function ve(t){return\"function\"==typeof t?t:function(){return t}}function me(t){return function(e,r,n){return 2===arguments.length&&\"function\"==typeof r&&(n=r,r=null),ye(e,r,t,n)}}function ye(e,r,i,a){var o={},s=t.dispatch(\"beforesend\",\"progress\",\"load\",\"error\"),l={},c=new XMLHttpRequest,u=null;function h(){var t,e=c.status;if(!e&&function(t){var e=t.responseType;return e&&\"text\"!==e?t.response:t.responseText}(c)||e>=200&&e<300||304===e){try{t=i.call(o,c)}catch(t){return void s.error.call(o,t)}s.load.call(o,t)}else s.error.call(o,c)}return!this.XDomainRequest||\"withCredentials\"in c||!/^(http(s)?:)?\\/\\//.test(e)||(c=new XDomainRequest),\"onload\"in c?c.onload=c.onerror=h:c.onreadystatechange=function(){c.readyState>3&&h()},c.onprogress=function(e){var r=t.event;t.event=e;try{s.progress.call(o,c)}finally{t.event=r}},o.header=function(t,e){return t=(t+\"\").toLowerCase(),arguments.length<2?l[t]:(null==e?delete l[t]:l[t]=e+\"\",o)},o.mimeType=function(t){return arguments.length?(r=null==t?null:t+\"\",o):r},o.responseType=function(t){return arguments.length?(u=t,o):u},o.response=function(t){return i=t,o},[\"get\",\"post\"].forEach(function(t){o[t]=function(){return o.send.apply(o,[t].concat(n(arguments)))}}),o.send=function(t,n,i){if(2===arguments.length&&\"function\"==typeof n&&(i=n,n=null),c.open(t,e,!0),null==r||\"accept\"in l||(l.accept=r+\",*/*\"),c.setRequestHeader)for(var a in l)c.setRequestHeader(a,l[a]);return null!=r&&c.overrideMimeType&&c.overrideMimeType(r),null!=u&&(c.responseType=u),null!=i&&o.on(\"error\",i).on(\"load\",function(t){i(null,t)}),s.beforesend.call(o,c),c.send(null==n?null:n),o},o.abort=function(){return c.abort(),o},t.rebind(o,s,\"on\"),null==a?o:o.get(function(t){return 1===t.length?function(e,r){t(null==e?r:null)}:t}(a))}ge.forEach(function(t,e){ge.set(t,oe(e))}),t.functor=ve,t.xhr=me(P),t.dsv=function(t,e){var r=new RegExp('[\"'+t+\"\\n]\"),n=t.charCodeAt(0);function i(t,r,n){arguments.length<3&&(n=r,r=null);var i=ye(t,e,null==r?a:o(r),n);return i.row=function(t){return arguments.length?i.response(null==(r=t)?a:o(t)):r},i}function a(t){return i.parse(t.responseText)}function o(t){return function(e){return i.parse(e.responseText,t)}}function s(e){return e.map(l).join(t)}function l(t){return r.test(t)?'\"'+t.replace(/\\\"/g,'\"\"')+'\"':t}return i.parse=function(t,e){var r;return i.parseRows(t,function(t,n){if(r)return r(t,n-1);var i=new Function(\"d\",\"return {\"+t.map(function(t,e){return JSON.stringify(t)+\": d[\"+e+\"]\"}).join(\",\")+\"}\");r=e?function(t,r){return e(i(t),r)}:i})},i.parseRows=function(t,e){var r,i,a={},o={},s=[],l=t.length,c=0,u=0;function h(){if(c>=l)return o;if(i)return i=!1,a;var e=c;if(34===t.charCodeAt(e)){for(var r=e;r++<l;)if(34===t.charCodeAt(r)){if(34!==t.charCodeAt(r+1))break;++r}return c=r+2,13===(s=t.charCodeAt(r+1))?(i=!0,10===t.charCodeAt(r+2)&&++c):10===s&&(i=!0),t.slice(e+1,r).replace(/\"\"/g,'\"')}for(;c<l;){var s,u=1;if(10===(s=t.charCodeAt(c++)))i=!0;else if(13===s)i=!0,10===t.charCodeAt(c)&&(++c,++u);else if(s!==n)continue;return t.slice(e,c-u)}return t.slice(e)}for(;(r=h())!==o;){for(var f=[];r!==a&&r!==o;)f.push(r),r=h();e&&null==(f=e(f,u++))||s.push(f)}return s},i.format=function(e){if(Array.isArray(e[0]))return i.formatRows(e);var r=new L,n=[];return e.forEach(function(t){for(var e in t)r.has(e)||n.push(r.add(e))}),[n.map(l).join(t)].concat(e.map(function(e){return n.map(function(t){return l(e[t])}).join(t)})).join(\"\\n\")},i.formatRows=function(t){return t.map(s).join(\"\\n\")},i},t.csv=t.dsv(\",\",\"text/csv\"),t.tsv=t.dsv(\"\\t\",\"text/tab-separated-values\");var xe,be,_e,we,ke=this[z(this,\"requestAnimationFrame\")]||function(t){setTimeout(t,17)};function Te(t,e,r){var n=arguments.length;n<2&&(e=0),n<3&&(r=Date.now());var i={c:t,t:r+e,n:null};return be?be.n=i:xe=i,be=i,_e||(we=clearTimeout(we),_e=1,ke(Ae)),i}function Ae(){var t=Me(),e=Se()-t;e>24?(isFinite(e)&&(clearTimeout(we),we=setTimeout(Ae,e)),_e=0):(_e=1,ke(Ae))}function Me(){for(var t=Date.now(),e=xe;e;)t>=e.t&&e.c(t-e.t)&&(e.c=null),e=e.n;return t}function Se(){for(var t,e=xe,r=1/0;e;)e.c?(e.t<r&&(r=e.t),e=(t=e).n):e=t?t.n=e.n:xe=e.n;return be=t,r}function Ee(t,e){return e-(t?Math.ceil(Math.log(t)/Math.LN10):1)}t.timer=function(){Te.apply(this,arguments)},t.timer.flush=function(){Me(),Se()},t.round=function(t,e){return e?Math.round(t*(e=Math.pow(10,e)))/e:Math.round(t)};var Ce=[\"y\",\"z\",\"a\",\"f\",\"p\",\"n\",\"\\xb5\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\",\"P\",\"E\",\"Z\",\"Y\"].map(function(t,e){var r=Math.pow(10,3*y(8-e));return{scale:e>8?function(t){return t/r}:function(t){return t*r},symbol:t}});t.formatPrefix=function(e,r){var n=0;return(e=+e)&&(e<0&&(e*=-1),r&&(e=t.round(e,Ee(e,r))),n=1+Math.floor(1e-12+Math.log(e)/Math.LN10),n=Math.max(-24,Math.min(24,3*Math.floor((n-1)/3)))),Ce[8+n/3]};var Le=/(?:([^{])?([<>=^]))?([+\\- ])?([$#])?(0)?(\\d+)?(,)?(\\.-?\\d+)?([a-z%])?/i,Pe=t.map({b:function(t){return t.toString(2)},c:function(t){return String.fromCharCode(t)},o:function(t){return t.toString(8)},x:function(t){return t.toString(16)},X:function(t){return t.toString(16).toUpperCase()},g:function(t,e){return t.toPrecision(e)},e:function(t,e){return t.toExponential(e)},f:function(t,e){return t.toFixed(e)},r:function(e,r){return(e=t.round(e,Ee(e,r))).toFixed(Math.max(0,Math.min(20,Ee(e*(1+1e-15),r))))}});function Oe(t){return t+\"\"}var ze=t.time={},Ie=Date;function De(){this._=new Date(arguments.length>1?Date.UTC.apply(this,arguments):arguments[0])}De.prototype={getDate:function(){return this._.getUTCDate()},getDay:function(){return this._.getUTCDay()},getFullYear:function(){return this._.getUTCFullYear()},getHours:function(){return this._.getUTCHours()},getMilliseconds:function(){return this._.getUTCMilliseconds()},getMinutes:function(){return this._.getUTCMinutes()},getMonth:function(){return this._.getUTCMonth()},getSeconds:function(){return this._.getUTCSeconds()},getTime:function(){return this._.getTime()},getTimezoneOffset:function(){return 0},valueOf:function(){return this._.valueOf()},setDate:function(){Re.setUTCDate.apply(this._,arguments)},setDay:function(){Re.setUTCDay.apply(this._,arguments)},setFullYear:function(){Re.setUTCFullYear.apply(this._,arguments)},setHours:function(){Re.setUTCHours.apply(this._,arguments)},setMilliseconds:function(){Re.setUTCMilliseconds.apply(this._,arguments)},setMinutes:function(){Re.setUTCMinutes.apply(this._,arguments)},setMonth:function(){Re.setUTCMonth.apply(this._,arguments)},setSeconds:function(){Re.setUTCSeconds.apply(this._,arguments)},setTime:function(){Re.setTime.apply(this._,arguments)}};var Re=Date.prototype;function Fe(t,e,r){function n(e){var r=t(e),n=a(r,1);return e-r<n-e?r:n}function i(r){return e(r=t(new Ie(r-1)),1),r}function a(t,r){return e(t=new Ie(+t),r),t}function o(t,n,a){var o=i(t),s=[];if(a>1)for(;o<n;)r(o)%a||s.push(new Date(+o)),e(o,1);else for(;o<n;)s.push(new Date(+o)),e(o,1);return s}t.floor=t,t.round=n,t.ceil=i,t.offset=a,t.range=o;var s=t.utc=Be(t);return s.floor=s,s.round=Be(n),s.ceil=Be(i),s.offset=Be(a),s.range=function(t,e,r){try{Ie=De;var n=new De;return n._=t,o(n,e,r)}finally{Ie=Date}},t}function Be(t){return function(e,r){try{Ie=De;var n=new De;return n._=e,t(n,r)._}finally{Ie=Date}}}ze.year=Fe(function(t){return(t=ze.day(t)).setMonth(0,1),t},function(t,e){t.setFullYear(t.getFullYear()+e)},function(t){return t.getFullYear()}),ze.years=ze.year.range,ze.years.utc=ze.year.utc.range,ze.day=Fe(function(t){var e=new Ie(2e3,0);return e.setFullYear(t.getFullYear(),t.getMonth(),t.getDate()),e},function(t,e){t.setDate(t.getDate()+e)},function(t){return t.getDate()-1}),ze.days=ze.day.range,ze.days.utc=ze.day.utc.range,ze.dayOfYear=function(t){var e=ze.year(t);return Math.floor((t-e-6e4*(t.getTimezoneOffset()-e.getTimezoneOffset()))/864e5)},[\"sunday\",\"monday\",\"tuesday\",\"wednesday\",\"thursday\",\"friday\",\"saturday\"].forEach(function(t,e){e=7-e;var r=ze[t]=Fe(function(t){return(t=ze.day(t)).setDate(t.getDate()-(t.getDay()+e)%7),t},function(t,e){t.setDate(t.getDate()+7*Math.floor(e))},function(t){var r=ze.year(t).getDay();return Math.floor((ze.dayOfYear(t)+(r+e)%7)/7)-(r!==e)});ze[t+\"s\"]=r.range,ze[t+\"s\"].utc=r.utc.range,ze[t+\"OfYear\"]=function(t){var r=ze.year(t).getDay();return Math.floor((ze.dayOfYear(t)+(r+e)%7)/7)}}),ze.week=ze.sunday,ze.weeks=ze.sunday.range,ze.weeks.utc=ze.sunday.utc.range,ze.weekOfYear=ze.sundayOfYear;var Ne={\"-\":\"\",_:\" \",0:\"0\"},je=/^\\s*\\d+/,Ue=/^%/;function Ve(t,e,r){var n=t<0?\"-\":\"\",i=(n?-t:t)+\"\",a=i.length;return n+(a<r?new Array(r-a+1).join(e)+i:i)}function qe(e){return new RegExp(\"^(?:\"+e.map(t.requote).join(\"|\")+\")\",\"i\")}function He(t){for(var e=new b,r=-1,n=t.length;++r<n;)e.set(t[r].toLowerCase(),r);return e}function Ge(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+1));return n?(t.w=+n[0],r+n[0].length):-1}function Ye(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.U=+n[0],r+n[0].length):-1}function We(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.W=+n[0],r+n[0].length):-1}function Xe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+4));return n?(t.y=+n[0],r+n[0].length):-1}function Ze(t,e,r){je.lastIndex=0;var n,i=je.exec(e.slice(r,r+2));return i?(t.y=(n=+i[0])+(n>68?1900:2e3),r+i[0].length):-1}function Je(t,e,r){return/^[+-]\\d{4}$/.test(e=e.slice(r,r+5))?(t.Z=-e,r+5):-1}function Ke(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.m=n[0]-1,r+n[0].length):-1}function $e(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.d=+n[0],r+n[0].length):-1}function Qe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.j=+n[0],r+n[0].length):-1}function tr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.H=+n[0],r+n[0].length):-1}function er(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.M=+n[0],r+n[0].length):-1}function rr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.S=+n[0],r+n[0].length):-1}function nr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.L=+n[0],r+n[0].length):-1}function ir(t){var e=t.getTimezoneOffset(),r=e>0?\"-\":\"+\",n=y(e)/60|0,i=y(e)%60;return r+Ve(n,\"0\",2)+Ve(i,\"0\",2)}function ar(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r,r+1));return n?r+n[0].length:-1}function or(t){for(var e=t.length,r=-1;++r<e;)t[r][0]=this(t[r][0]);return function(e){for(var r=0,n=t[r];!n[1](e);)n=t[++r];return n[0](e)}}t.locale=function(e){return{numberFormat:function(e){var r=e.decimal,n=e.thousands,i=e.grouping,a=e.currency,o=i&&n?function(t,e){for(var r=t.length,a=[],o=0,s=i[0],l=0;r>0&&s>0&&(l+s+1>e&&(s=Math.max(1,e-l)),a.push(t.substring(r-=s,r+s)),!((l+=s+1)>e));)s=i[o=(o+1)%i.length];return a.reverse().join(n)}:P;return function(e){var n=Le.exec(e),i=n[1]||\" \",s=n[2]||\">\",l=n[3]||\"-\",c=n[4]||\"\",u=n[5],h=+n[6],f=n[7],p=n[8],d=n[9],g=1,v=\"\",m=\"\",y=!1,x=!0;switch(p&&(p=+p.substring(1)),(u||\"0\"===i&&\"=\"===s)&&(u=i=\"0\",s=\"=\"),d){case\"n\":f=!0,d=\"g\";break;case\"%\":g=100,m=\"%\",d=\"f\";break;case\"p\":g=100,m=\"%\",d=\"r\";break;case\"b\":case\"o\":case\"x\":case\"X\":\"#\"===c&&(v=\"0\"+d.toLowerCase());case\"c\":x=!1;case\"d\":y=!0,p=0;break;case\"s\":g=-1,d=\"r\"}\"$\"===c&&(v=a[0],m=a[1]),\"r\"!=d||p||(d=\"g\"),null!=p&&(\"g\"==d?p=Math.max(1,Math.min(21,p)):\"e\"!=d&&\"f\"!=d||(p=Math.max(0,Math.min(20,p)))),d=Pe.get(d)||Oe;var b=u&&f;return function(e){var n=m;if(y&&e%1)return\"\";var a=e<0||0===e&&1/e<0?(e=-e,\"-\"):\"-\"===l?\"\":l;if(g<0){var c=t.formatPrefix(e,p);e=c.scale(e),n=c.symbol+m}else e*=g;var _,w,k=(e=d(e,p)).lastIndexOf(\".\");if(k<0){var T=x?e.lastIndexOf(\"e\"):-1;T<0?(_=e,w=\"\"):(_=e.substring(0,T),w=e.substring(T))}else _=e.substring(0,k),w=r+e.substring(k+1);!u&&f&&(_=o(_,1/0));var A=v.length+_.length+w.length+(b?0:a.length),M=A<h?new Array(A=h-A+1).join(i):\"\";return b&&(_=o(M+_,M.length?h-w.length:1/0)),a+=v,e=_+w,(\"<\"===s?a+e+M:\">\"===s?M+a+e:\"^\"===s?M.substring(0,A>>=1)+a+e+M.substring(A):a+(b?e:M+e))+n}}}(e),timeFormat:function(e){var r=e.dateTime,n=e.date,i=e.time,a=e.periods,o=e.days,s=e.shortDays,l=e.months,c=e.shortMonths;function u(t){var e=t.length;function r(r){for(var n,i,a,o=[],s=-1,l=0;++s<e;)37===t.charCodeAt(s)&&(o.push(t.slice(l,s)),null!=(i=Ne[n=t.charAt(++s)])&&(n=t.charAt(++s)),(a=_[n])&&(n=a(r,null==i?\"e\"===n?\" \":\"0\":i)),o.push(n),l=s+1);return o.push(t.slice(l,s)),o.join(\"\")}return r.parse=function(e){var r={y:1900,m:0,d:1,H:0,M:0,S:0,L:0,Z:null};if(h(r,t,e,0)!=e.length)return null;\"p\"in r&&(r.H=r.H%12+12*r.p);var n=null!=r.Z&&Ie!==De,i=new(n?De:Ie);return\"j\"in r?i.setFullYear(r.y,0,r.j):\"W\"in r||\"U\"in r?(\"w\"in r||(r.w=\"W\"in r?1:0),i.setFullYear(r.y,0,1),i.setFullYear(r.y,0,\"W\"in r?(r.w+6)%7+7*r.W-(i.getDay()+5)%7:r.w+7*r.U-(i.getDay()+6)%7)):i.setFullYear(r.y,r.m,r.d),i.setHours(r.H+(r.Z/100|0),r.M+r.Z%100,r.S,r.L),n?i._:i},r.toString=function(){return t},r}function h(t,e,r,n){for(var i,a,o,s=0,l=e.length,c=r.length;s<l;){if(n>=c)return-1;if(37===(i=e.charCodeAt(s++))){if(o=e.charAt(s++),!(a=w[o in Ne?e.charAt(s++):o])||(n=a(t,r,n))<0)return-1}else if(i!=r.charCodeAt(n++))return-1}return n}u.utc=function(t){var e=u(t);function r(t){try{var r=new(Ie=De);return r._=t,e(r)}finally{Ie=Date}}return r.parse=function(t){try{Ie=De;var r=e.parse(t);return r&&r._}finally{Ie=Date}},r.toString=e.toString,r},u.multi=u.utc.multi=or;var f=t.map(),p=qe(o),d=He(o),g=qe(s),v=He(s),m=qe(l),y=He(l),x=qe(c),b=He(c);a.forEach(function(t,e){f.set(t.toLowerCase(),e)});var _={a:function(t){return s[t.getDay()]},A:function(t){return o[t.getDay()]},b:function(t){return c[t.getMonth()]},B:function(t){return l[t.getMonth()]},c:u(r),d:function(t,e){return Ve(t.getDate(),e,2)},e:function(t,e){return Ve(t.getDate(),e,2)},H:function(t,e){return Ve(t.getHours(),e,2)},I:function(t,e){return Ve(t.getHours()%12||12,e,2)},j:function(t,e){return Ve(1+ze.dayOfYear(t),e,3)},L:function(t,e){return Ve(t.getMilliseconds(),e,3)},m:function(t,e){return Ve(t.getMonth()+1,e,2)},M:function(t,e){return Ve(t.getMinutes(),e,2)},p:function(t){return a[+(t.getHours()>=12)]},S:function(t,e){return Ve(t.getSeconds(),e,2)},U:function(t,e){return Ve(ze.sundayOfYear(t),e,2)},w:function(t){return t.getDay()},W:function(t,e){return Ve(ze.mondayOfYear(t),e,2)},x:u(n),X:u(i),y:function(t,e){return Ve(t.getFullYear()%100,e,2)},Y:function(t,e){return Ve(t.getFullYear()%1e4,e,4)},Z:ir,\"%\":function(){return\"%\"}},w={a:function(t,e,r){g.lastIndex=0;var n=g.exec(e.slice(r));return n?(t.w=v.get(n[0].toLowerCase()),r+n[0].length):-1},A:function(t,e,r){p.lastIndex=0;var n=p.exec(e.slice(r));return n?(t.w=d.get(n[0].toLowerCase()),r+n[0].length):-1},b:function(t,e,r){x.lastIndex=0;var n=x.exec(e.slice(r));return n?(t.m=b.get(n[0].toLowerCase()),r+n[0].length):-1},B:function(t,e,r){m.lastIndex=0;var n=m.exec(e.slice(r));return n?(t.m=y.get(n[0].toLowerCase()),r+n[0].length):-1},c:function(t,e,r){return h(t,_.c.toString(),e,r)},d:$e,e:$e,H:tr,I:tr,j:Qe,L:nr,m:Ke,M:er,p:function(t,e,r){var n=f.get(e.slice(r,r+=2).toLowerCase());return null==n?-1:(t.p=n,r)},S:rr,U:Ye,w:Ge,W:We,x:function(t,e,r){return h(t,_.x.toString(),e,r)},X:function(t,e,r){return h(t,_.X.toString(),e,r)},y:Ze,Y:Xe,Z:Je,\"%\":ar};return u}(e)}};var sr=t.locale({decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],dateTime:\"%a %b %e %X %Y\",date:\"%m/%d/%Y\",time:\"%H:%M:%S\",periods:[\"AM\",\"PM\"],days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"]});function lr(){}t.format=sr.numberFormat,t.geo={},lr.prototype={s:0,t:0,add:function(t){ur(t,this.t,cr),ur(cr.s,this.s,this),this.s?this.t+=cr.t:this.s=cr.t},reset:function(){this.s=this.t=0},valueOf:function(){return this.s}};var cr=new lr;function ur(t,e,r){var n=r.s=t+e,i=n-t,a=n-i;r.t=t-a+(e-i)}function hr(t,e){t&&pr.hasOwnProperty(t.type)&&pr[t.type](t,e)}t.geo.stream=function(t,e){t&&fr.hasOwnProperty(t.type)?fr[t.type](t,e):hr(t,e)};var fr={Feature:function(t,e){hr(t.geometry,e)},FeatureCollection:function(t,e){for(var r=t.features,n=-1,i=r.length;++n<i;)hr(r[n].geometry,e)}},pr={Sphere:function(t,e){e.sphere()},Point:function(t,e){t=t.coordinates,e.point(t[0],t[1],t[2])},MultiPoint:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)t=r[n],e.point(t[0],t[1],t[2])},LineString:function(t,e){dr(t.coordinates,e,0)},MultiLineString:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)dr(r[n],e,0)},Polygon:function(t,e){gr(t.coordinates,e)},MultiPolygon:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)gr(r[n],e)},GeometryCollection:function(t,e){for(var r=t.geometries,n=-1,i=r.length;++n<i;)hr(r[n],e)}};function dr(t,e,r){var n,i=-1,a=t.length-r;for(e.lineStart();++i<a;)n=t[i],e.point(n[0],n[1],n[2]);e.lineEnd()}function gr(t,e){var r=-1,n=t.length;for(e.polygonStart();++r<n;)dr(t[r],e,1);e.polygonEnd()}t.geo.area=function(e){return vr=0,t.geo.stream(e,Cr),vr};var vr,mr,yr,xr,br,_r,wr,kr,Tr,Ar,Mr,Sr,Er=new lr,Cr={sphere:function(){vr+=4*At},point:D,lineStart:D,lineEnd:D,polygonStart:function(){Er.reset(),Cr.lineStart=Lr},polygonEnd:function(){var t=2*Er;vr+=t<0?4*At+t:t,Cr.lineStart=Cr.lineEnd=Cr.point=D}};function Lr(){var t,e,r,n,i;function a(t,e){e=e*Ct/2+At/4;var a=(t*=Ct)-r,o=a>=0?1:-1,s=o*a,l=Math.cos(e),c=Math.sin(e),u=i*c,h=n*l+u*Math.cos(s),f=u*o*Math.sin(s);Er.add(Math.atan2(f,h)),r=t,n=l,i=c}Cr.point=function(o,s){Cr.point=a,r=(t=o)*Ct,n=Math.cos(s=(e=s)*Ct/2+At/4),i=Math.sin(s)},Cr.lineEnd=function(){a(t,e)}}function Pr(t){var e=t[0],r=t[1],n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}function Or(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}function zr(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}function Ir(t,e){t[0]+=e[0],t[1]+=e[1],t[2]+=e[2]}function Dr(t,e){return[t[0]*e,t[1]*e,t[2]*e]}function Rr(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]+t[2]*t[2]);t[0]/=e,t[1]/=e,t[2]/=e}function Fr(t){return[Math.atan2(t[1],t[0]),It(t[2])]}function Br(t,e){return y(t[0]-e[0])<kt&&y(t[1]-e[1])<kt}t.geo.bounds=function(){var e,r,n,i,a,o,s,l,c,u,h,f={point:p,lineStart:g,lineEnd:v,polygonStart:function(){f.point=m,f.lineStart=x,f.lineEnd=b,c=0,Cr.polygonStart()},polygonEnd:function(){Cr.polygonEnd(),f.point=p,f.lineStart=g,f.lineEnd=v,Er<0?(e=-(n=180),r=-(i=90)):c>kt?i=90:c<-kt&&(r=-90),h[0]=e,h[1]=n}};function p(t,a){u.push(h=[e=t,n=t]),a<r&&(r=a),a>i&&(i=a)}function d(t,o){var s=Pr([t*Ct,o*Ct]);if(l){var c=zr(l,s),u=zr([c[1],-c[0],0],c);Rr(u),u=Fr(u);var h=t-a,f=h>0?1:-1,d=u[0]*Lt*f,g=y(h)>180;if(g^(f*a<d&&d<f*t))(v=u[1]*Lt)>i&&(i=v);else if(g^(f*a<(d=(d+360)%360-180)&&d<f*t)){var v;(v=-u[1]*Lt)<r&&(r=v)}else o<r&&(r=o),o>i&&(i=o);g?t<a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t):n>=e?(t<e&&(e=t),t>n&&(n=t)):t>a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t)}else p(t,o);l=s,a=t}function g(){f.point=d}function v(){h[0]=e,h[1]=n,f.point=p,l=null}function m(t,e){if(l){var r=t-a;c+=y(r)>180?r+(r>0?360:-360):r}else o=t,s=e;Cr.point(t,e),d(t,e)}function x(){Cr.lineStart()}function b(){m(o,s),Cr.lineEnd(),y(c)>kt&&(e=-(n=180)),h[0]=e,h[1]=n,l=null}function _(t,e){return(e-=t)<0?e+360:e}function w(t,e){return t[0]-e[0]}function k(t,e){return e[0]<=e[1]?e[0]<=t&&t<=e[1]:t<e[0]||e[1]<t}return function(a){if(i=n=-(e=r=1/0),u=[],t.geo.stream(a,f),c=u.length){u.sort(w);for(var o=1,s=[g=u[0]];o<c;++o)k((p=u[o])[0],g)||k(p[1],g)?(_(g[0],p[1])>_(g[0],g[1])&&(g[1]=p[1]),_(p[0],g[1])>_(g[0],g[1])&&(g[0]=p[0])):s.push(g=p);for(var l,c,p,d=-1/0,g=(o=0,s[c=s.length-1]);o<=c;g=p,++o)p=s[o],(l=_(g[1],p[0]))>d&&(d=l,e=p[0],n=g[1])}return u=h=null,e===1/0||r===1/0?[[NaN,NaN],[NaN,NaN]]:[[e,r],[n,i]]}}(),t.geo.centroid=function(e){mr=yr=xr=br=_r=wr=kr=Tr=Ar=Mr=Sr=0,t.geo.stream(e,Nr);var r=Ar,n=Mr,i=Sr,a=r*r+n*n+i*i;return a<Tt&&(r=wr,n=kr,i=Tr,yr<kt&&(r=xr,n=br,i=_r),(a=r*r+n*n+i*i)<Tt)?[NaN,NaN]:[Math.atan2(n,r)*Lt,It(i/Math.sqrt(a))*Lt]};var Nr={sphere:D,point:jr,lineStart:Vr,lineEnd:qr,polygonStart:function(){Nr.lineStart=Hr},polygonEnd:function(){Nr.lineStart=Vr}};function jr(t,e){t*=Ct;var r=Math.cos(e*=Ct);Ur(r*Math.cos(t),r*Math.sin(t),Math.sin(e))}function Ur(t,e,r){xr+=(t-xr)/++mr,br+=(e-br)/mr,_r+=(r-_r)/mr}function Vr(){var t,e,r;function n(n,i){n*=Ct;var a=Math.cos(i*=Ct),o=a*Math.cos(n),s=a*Math.sin(n),l=Math.sin(i),c=Math.atan2(Math.sqrt((c=e*l-r*s)*c+(c=r*o-t*l)*c+(c=t*s-e*o)*c),t*o+e*s+r*l);yr+=c,wr+=c*(t+(t=o)),kr+=c*(e+(e=s)),Tr+=c*(r+(r=l)),Ur(t,e,r)}Nr.point=function(i,a){i*=Ct;var o=Math.cos(a*=Ct);t=o*Math.cos(i),e=o*Math.sin(i),r=Math.sin(a),Nr.point=n,Ur(t,e,r)}}function qr(){Nr.point=jr}function Hr(){var t,e,r,n,i;function a(t,e){t*=Ct;var a=Math.cos(e*=Ct),o=a*Math.cos(t),s=a*Math.sin(t),l=Math.sin(e),c=n*l-i*s,u=i*o-r*l,h=r*s-n*o,f=Math.sqrt(c*c+u*u+h*h),p=r*o+n*s+i*l,d=f&&-zt(p)/f,g=Math.atan2(f,p);Ar+=d*c,Mr+=d*u,Sr+=d*h,yr+=g,wr+=g*(r+(r=o)),kr+=g*(n+(n=s)),Tr+=g*(i+(i=l)),Ur(r,n,i)}Nr.point=function(o,s){t=o,e=s,Nr.point=a,o*=Ct;var l=Math.cos(s*=Ct);r=l*Math.cos(o),n=l*Math.sin(o),i=Math.sin(s),Ur(r,n,i)},Nr.lineEnd=function(){a(t,e),Nr.lineEnd=qr,Nr.point=jr}}function Gr(t,e){function r(r,n){return r=t(r,n),e(r[0],r[1])}return t.invert&&e.invert&&(r.invert=function(r,n){return(r=e.invert(r,n))&&t.invert(r[0],r[1])}),r}function Yr(){return!0}function Wr(t,e,r,n,i){var a=[],o=[];if(t.forEach(function(t){if(!((e=t.length-1)<=0)){var e,r=t[0],n=t[e];if(Br(r,n)){i.lineStart();for(var s=0;s<e;++s)i.point((r=t[s])[0],r[1]);i.lineEnd()}else{var l=new Zr(r,t,null,!0),c=new Zr(r,null,l,!1);l.o=c,a.push(l),o.push(c),l=new Zr(n,t,null,!1),c=new Zr(n,null,l,!0),l.o=c,a.push(l),o.push(c)}}}),o.sort(e),Xr(a),Xr(o),a.length){for(var s=0,l=r,c=o.length;s<c;++s)o[s].e=l=!l;for(var u,h,f=a[0];;){for(var p=f,d=!0;p.v;)if((p=p.n)===f)return;u=p.z,i.lineStart();do{if(p.v=p.o.v=!0,p.e){if(d)for(s=0,c=u.length;s<c;++s)i.point((h=u[s])[0],h[1]);else n(p.x,p.n.x,1,i);p=p.n}else{if(d)for(s=(u=p.p.z).length-1;s>=0;--s)i.point((h=u[s])[0],h[1]);else n(p.x,p.p.x,-1,i);p=p.p}u=(p=p.o).z,d=!d}while(!p.v);i.lineEnd()}}}function Xr(t){if(e=t.length){for(var e,r,n=0,i=t[0];++n<e;)i.n=r=t[n],r.p=i,i=r;i.n=r=t[0],r.p=i}}function Zr(t,e,r,n){this.x=t,this.z=e,this.o=r,this.e=n,this.v=!1,this.n=this.p=null}function Jr(e,r,n,i){return function(a,o){var s,l=r(o),c=a.invert(i[0],i[1]),u={point:h,lineStart:p,lineEnd:d,polygonStart:function(){u.point=b,u.lineStart=_,u.lineEnd=w,s=[],g=[]},polygonEnd:function(){u.point=h,u.lineStart=p,u.lineEnd=d,s=t.merge(s);var e=function(t,e){var r=t[0],n=t[1],i=[Math.sin(r),-Math.cos(r),0],a=0,o=0;Er.reset();for(var s=0,l=e.length;s<l;++s){var c=e[s],u=c.length;if(u)for(var h=c[0],f=h[0],p=h[1]/2+At/4,d=Math.sin(p),g=Math.cos(p),v=1;;){v===u&&(v=0);var m=(t=c[v])[0],y=t[1]/2+At/4,x=Math.sin(y),b=Math.cos(y),_=m-f,w=_>=0?1:-1,k=w*_,T=k>At,A=d*x;if(Er.add(Math.atan2(A*w*Math.sin(k),g*b+A*Math.cos(k))),a+=T?_+w*Mt:_,T^f>=r^m>=r){var M=zr(Pr(h),Pr(t));Rr(M);var S=zr(i,M);Rr(S);var E=(T^_>=0?-1:1)*It(S[2]);(n>E||n===E&&(M[0]||M[1]))&&(o+=T^_>=0?1:-1)}if(!v++)break;f=m,d=x,g=b,h=t}}return(a<-kt||a<kt&&Er<-kt)^1&o}(c,g);s.length?(x||(o.polygonStart(),x=!0),Wr(s,Qr,e,n,o)):e&&(x||(o.polygonStart(),x=!0),o.lineStart(),n(null,null,1,o),o.lineEnd()),x&&(o.polygonEnd(),x=!1),s=g=null},sphere:function(){o.polygonStart(),o.lineStart(),n(null,null,1,o),o.lineEnd(),o.polygonEnd()}};function h(t,r){var n=a(t,r);e(t=n[0],r=n[1])&&o.point(t,r)}function f(t,e){var r=a(t,e);l.point(r[0],r[1])}function p(){u.point=f,l.lineStart()}function d(){u.point=h,l.lineEnd()}var g,v,m=$r(),y=r(m),x=!1;function b(t,e){v.push([t,e]);var r=a(t,e);y.point(r[0],r[1])}function _(){y.lineStart(),v=[]}function w(){b(v[0][0],v[0][1]),y.lineEnd();var t,e=y.clean(),r=m.buffer(),n=r.length;if(v.pop(),g.push(v),v=null,n)if(1&e){var i,a=-1;if((n=(t=r[0]).length-1)>0){for(x||(o.polygonStart(),x=!0),o.lineStart();++a<n;)o.point((i=t[a])[0],i[1]);o.lineEnd()}}else n>1&&2&e&&r.push(r.pop().concat(r.shift())),s.push(r.filter(Kr))}return u}}function Kr(t){return t.length>1}function $r(){var t,e=[];return{lineStart:function(){e.push(t=[])},point:function(e,r){t.push([e,r])},lineEnd:D,buffer:function(){var r=e;return e=[],t=null,r},rejoin:function(){e.length>1&&e.push(e.pop().concat(e.shift()))}}}function Qr(t,e){return((t=t.x)[0]<0?t[1]-Et-kt:Et-t[1])-((e=e.x)[0]<0?e[1]-Et-kt:Et-e[1])}var tn=Jr(Yr,function(t){var e,r=NaN,n=NaN,i=NaN;return{lineStart:function(){t.lineStart(),e=1},point:function(a,o){var s=a>0?At:-At,l=y(a-r);y(l-At)<kt?(t.point(r,n=(n+o)/2>0?Et:-Et),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),t.point(a,n),e=0):i!==s&&l>=At&&(y(r-i)<kt&&(r-=i*kt),y(a-s)<kt&&(a-=s*kt),n=function(t,e,r,n){var i,a,o=Math.sin(t-r);return y(o)>kt?Math.atan((Math.sin(e)*(a=Math.cos(n))*Math.sin(r)-Math.sin(n)*(i=Math.cos(e))*Math.sin(t))/(i*a*o)):(e+n)/2}(r,n,a,o),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),e=0),t.point(r=a,n=o),i=s},lineEnd:function(){t.lineEnd(),r=n=NaN},clean:function(){return 2-e}}},function(t,e,r,n){var i;if(null==t)i=r*Et,n.point(-At,i),n.point(0,i),n.point(At,i),n.point(At,0),n.point(At,-i),n.point(0,-i),n.point(-At,-i),n.point(-At,0),n.point(-At,i);else if(y(t[0]-e[0])>kt){var a=t[0]<e[0]?At:-At;i=r*a/2,n.point(-a,i),n.point(0,i),n.point(a,i)}else n.point(e[0],e[1])},[-At,-At/2]);function en(t,e,r,n){return function(i){var a,o=i.a,s=i.b,l=o.x,c=o.y,u=0,h=1,f=s.x-l,p=s.y-c;if(a=t-l,f||!(a>0)){if(a/=f,f<0){if(a<u)return;a<h&&(h=a)}else if(f>0){if(a>h)return;a>u&&(u=a)}if(a=r-l,f||!(a<0)){if(a/=f,f<0){if(a>h)return;a>u&&(u=a)}else if(f>0){if(a<u)return;a<h&&(h=a)}if(a=e-c,p||!(a>0)){if(a/=p,p<0){if(a<u)return;a<h&&(h=a)}else if(p>0){if(a>h)return;a>u&&(u=a)}if(a=n-c,p||!(a<0)){if(a/=p,p<0){if(a>h)return;a>u&&(u=a)}else if(p>0){if(a<u)return;a<h&&(h=a)}return u>0&&(i.a={x:l+u*f,y:c+u*p}),h<1&&(i.b={x:l+h*f,y:c+h*p}),i}}}}}}var rn=1e9;function nn(e,r,n,i){return function(l){var c,u,h,f,p,d,g,v,m,y,x,b=l,_=$r(),w=en(e,r,n,i),k={point:M,lineStart:function(){k.point=S,u&&u.push(h=[]);y=!0,m=!1,g=v=NaN},lineEnd:function(){c&&(S(f,p),d&&m&&_.rejoin(),c.push(_.buffer()));k.point=M,m&&l.lineEnd()},polygonStart:function(){l=_,c=[],u=[],x=!0},polygonEnd:function(){l=b,c=t.merge(c);var r=function(t){for(var e=0,r=u.length,n=t[1],i=0;i<r;++i)for(var a,o=1,s=u[i],l=s.length,c=s[0];o<l;++o)a=s[o],c[1]<=n?a[1]>n&&Ot(c,a,t)>0&&++e:a[1]<=n&&Ot(c,a,t)<0&&--e,c=a;return 0!==e}([e,i]),n=x&&r,a=c.length;(n||a)&&(l.polygonStart(),n&&(l.lineStart(),T(null,null,1,l),l.lineEnd()),a&&Wr(c,o,r,T,l),l.polygonEnd()),c=u=h=null}};function T(t,o,l,c){var u=0,h=0;if(null==t||(u=a(t,l))!==(h=a(o,l))||s(t,o)<0^l>0)do{c.point(0===u||3===u?e:n,u>1?i:r)}while((u=(u+l+4)%4)!==h);else c.point(o[0],o[1])}function A(t,a){return e<=t&&t<=n&&r<=a&&a<=i}function M(t,e){A(t,e)&&l.point(t,e)}function S(t,e){var r=A(t=Math.max(-rn,Math.min(rn,t)),e=Math.max(-rn,Math.min(rn,e)));if(u&&h.push([t,e]),y)f=t,p=e,d=r,y=!1,r&&(l.lineStart(),l.point(t,e));else if(r&&m)l.point(t,e);else{var n={a:{x:g,y:v},b:{x:t,y:e}};w(n)?(m||(l.lineStart(),l.point(n.a.x,n.a.y)),l.point(n.b.x,n.b.y),r||l.lineEnd(),x=!1):r&&(l.lineStart(),l.point(t,e),x=!1)}g=t,v=e,m=r}return k};function a(t,i){return y(t[0]-e)<kt?i>0?0:3:y(t[0]-n)<kt?i>0?2:1:y(t[1]-r)<kt?i>0?1:0:i>0?3:2}function o(t,e){return s(t.x,e.x)}function s(t,e){var r=a(t,1),n=a(e,1);return r!==n?r-n:0===r?e[1]-t[1]:1===r?t[0]-e[0]:2===r?t[1]-e[1]:e[0]-t[0]}}function an(t){var e=0,r=At/3,n=Cn(t),i=n(e,r);return i.parallels=function(t){return arguments.length?n(e=t[0]*At/180,r=t[1]*At/180):[e/At*180,r/At*180]},i}function on(t,e){var r=Math.sin(t),n=(r+Math.sin(e))/2,i=1+r*(2*n-r),a=Math.sqrt(i)/n;function o(t,e){var r=Math.sqrt(i-2*n*Math.sin(e))/n;return[r*Math.sin(t*=n),a-r*Math.cos(t)]}return o.invert=function(t,e){var r=a-e;return[Math.atan2(t,r)/n,It((i-(t*t+r*r)*n*n)/(2*n))]},o}t.geo.clipExtent=function(){var t,e,r,n,i,a,o={stream:function(t){return i&&(i.valid=!1),(i=a(t)).valid=!0,i},extent:function(s){return arguments.length?(a=nn(t=+s[0][0],e=+s[0][1],r=+s[1][0],n=+s[1][1]),i&&(i.valid=!1,i=null),o):[[t,e],[r,n]]}};return o.extent([[0,0],[960,500]])},(t.geo.conicEqualArea=function(){return an(on)}).raw=on,t.geo.albers=function(){return t.geo.conicEqualArea().rotate([96,0]).center([-.6,38.7]).parallels([29.5,45.5]).scale(1070)},t.geo.albersUsa=function(){var e,r,n,i,a=t.geo.albers(),o=t.geo.conicEqualArea().rotate([154,0]).center([-2,58.5]).parallels([55,65]),s=t.geo.conicEqualArea().rotate([157,0]).center([-3,19.9]).parallels([8,18]),l={point:function(t,r){e=[t,r]}};function c(t){var a=t[0],o=t[1];return e=null,r(a,o),e||(n(a,o),e)||i(a,o),e}return c.invert=function(t){var e=a.scale(),r=a.translate(),n=(t[0]-r[0])/e,i=(t[1]-r[1])/e;return(i>=.12&&i<.234&&n>=-.425&&n<-.214?o:i>=.166&&i<.234&&n>=-.214&&n<-.115?s:a).invert(t)},c.stream=function(t){var e=a.stream(t),r=o.stream(t),n=s.stream(t);return{point:function(t,i){e.point(t,i),r.point(t,i),n.point(t,i)},sphere:function(){e.sphere(),r.sphere(),n.sphere()},lineStart:function(){e.lineStart(),r.lineStart(),n.lineStart()},lineEnd:function(){e.lineEnd(),r.lineEnd(),n.lineEnd()},polygonStart:function(){e.polygonStart(),r.polygonStart(),n.polygonStart()},polygonEnd:function(){e.polygonEnd(),r.polygonEnd(),n.polygonEnd()}}},c.precision=function(t){return arguments.length?(a.precision(t),o.precision(t),s.precision(t),c):a.precision()},c.scale=function(t){return arguments.length?(a.scale(t),o.scale(.35*t),s.scale(t),c.translate(a.translate())):a.scale()},c.translate=function(t){if(!arguments.length)return a.translate();var e=a.scale(),u=+t[0],h=+t[1];return r=a.translate(t).clipExtent([[u-.455*e,h-.238*e],[u+.455*e,h+.238*e]]).stream(l).point,n=o.translate([u-.307*e,h+.201*e]).clipExtent([[u-.425*e+kt,h+.12*e+kt],[u-.214*e-kt,h+.234*e-kt]]).stream(l).point,i=s.translate([u-.205*e,h+.212*e]).clipExtent([[u-.214*e+kt,h+.166*e+kt],[u-.115*e-kt,h+.234*e-kt]]).stream(l).point,c},c.scale(1070)};var sn,ln,cn,un,hn,fn,pn={point:D,lineStart:D,lineEnd:D,polygonStart:function(){ln=0,pn.lineStart=dn},polygonEnd:function(){pn.lineStart=pn.lineEnd=pn.point=D,sn+=y(ln/2)}};function dn(){var t,e,r,n;function i(t,e){ln+=n*t-r*e,r=t,n=e}pn.point=function(a,o){pn.point=i,t=r=a,e=n=o},pn.lineEnd=function(){i(t,e)}}var gn={point:function(t,e){t<cn&&(cn=t);t>hn&&(hn=t);e<un&&(un=e);e>fn&&(fn=e)},lineStart:D,lineEnd:D,polygonStart:D,polygonEnd:D};function vn(){var t=mn(4.5),e=[],r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(e){return t=mn(e),r},result:function(){if(e.length){var t=e.join(\"\");return e=[],t}}};function n(r,n){e.push(\"M\",r,\",\",n,t)}function i(t,n){e.push(\"M\",t,\",\",n),r.point=a}function a(t,r){e.push(\"L\",t,\",\",r)}function o(){r.point=n}function s(){e.push(\"Z\")}return r}function mn(t){return\"m0,\"+t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+-2*t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+2*t+\"z\"}var yn,xn={point:bn,lineStart:_n,lineEnd:wn,polygonStart:function(){xn.lineStart=kn},polygonEnd:function(){xn.point=bn,xn.lineStart=_n,xn.lineEnd=wn}};function bn(t,e){xr+=t,br+=e,++_r}function _n(){var t,e;function r(r,n){var i=r-t,a=n-e,o=Math.sqrt(i*i+a*a);wr+=o*(t+r)/2,kr+=o*(e+n)/2,Tr+=o,bn(t=r,e=n)}xn.point=function(n,i){xn.point=r,bn(t=n,e=i)}}function wn(){xn.point=bn}function kn(){var t,e,r,n;function i(t,e){var i=t-r,a=e-n,o=Math.sqrt(i*i+a*a);wr+=o*(r+t)/2,kr+=o*(n+e)/2,Tr+=o,Ar+=(o=n*t-r*e)*(r+t),Mr+=o*(n+e),Sr+=3*o,bn(r=t,n=e)}xn.point=function(a,o){xn.point=i,bn(t=r=a,e=n=o)},xn.lineEnd=function(){i(t,e)}}function Tn(t){var e=4.5,r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(t){return e=t,r},result:D};function n(r,n){t.moveTo(r+e,n),t.arc(r,n,e,0,Mt)}function i(e,n){t.moveTo(e,n),r.point=a}function a(e,r){t.lineTo(e,r)}function o(){r.point=n}function s(){t.closePath()}return r}function An(t){var e=.5,r=Math.cos(30*Ct),n=16;function i(e){return(n?function(e){var r,i,o,s,l,c,u,h,f,p,d,g,v={point:m,lineStart:y,lineEnd:b,polygonStart:function(){e.polygonStart(),v.lineStart=_},polygonEnd:function(){e.polygonEnd(),v.lineStart=y}};function m(r,n){r=t(r,n),e.point(r[0],r[1])}function y(){h=NaN,v.point=x,e.lineStart()}function x(r,i){var o=Pr([r,i]),s=t(r,i);a(h,f,u,p,d,g,h=s[0],f=s[1],u=r,p=o[0],d=o[1],g=o[2],n,e),e.point(h,f)}function b(){v.point=m,e.lineEnd()}function _(){y(),v.point=w,v.lineEnd=k}function w(t,e){x(r=t,e),i=h,o=f,s=p,l=d,c=g,v.point=x}function k(){a(h,f,u,p,d,g,i,o,r,s,l,c,n,e),v.lineEnd=b,b()}return v}:function(e){return Sn(e,function(r,n){r=t(r,n),e.point(r[0],r[1])})})(e)}function a(n,i,o,s,l,c,u,h,f,p,d,g,v,m){var x=u-n,b=h-i,_=x*x+b*b;if(_>4*e&&v--){var w=s+p,k=l+d,T=c+g,A=Math.sqrt(w*w+k*k+T*T),M=Math.asin(T/=A),S=y(y(T)-1)<kt||y(o-f)<kt?(o+f)/2:Math.atan2(k,w),E=t(S,M),C=E[0],L=E[1],P=C-n,O=L-i,z=b*P-x*O;(z*z/_>e||y((x*P+b*O)/_-.5)>.3||s*p+l*d+c*g<r)&&(a(n,i,o,s,l,c,C,L,S,w/=A,k/=A,T,v,m),m.point(C,L),a(C,L,S,w,k,T,u,h,f,p,d,g,v,m))}}return i.precision=function(t){return arguments.length?(n=(e=t*t)>0&&16,i):Math.sqrt(e)},i}function Mn(t){this.stream=t}function Sn(t,e){return{point:e,sphere:function(){t.sphere()},lineStart:function(){t.lineStart()},lineEnd:function(){t.lineEnd()},polygonStart:function(){t.polygonStart()},polygonEnd:function(){t.polygonEnd()}}}function En(t){return Cn(function(){return t})()}function Cn(e){var r,n,i,a,o,s,l=An(function(t,e){return[(t=r(t,e))[0]*c+a,o-t[1]*c]}),c=150,u=480,h=250,f=0,p=0,d=0,g=0,v=0,m=tn,x=P,b=null,_=null;function w(t){return[(t=i(t[0]*Ct,t[1]*Ct))[0]*c+a,o-t[1]*c]}function k(t){return(t=i.invert((t[0]-a)/c,(o-t[1])/c))&&[t[0]*Lt,t[1]*Lt]}function T(){i=Gr(n=zn(d,g,v),r);var t=r(f,p);return a=u-t[0]*c,o=h+t[1]*c,A()}function A(){return s&&(s.valid=!1,s=null),w}return w.stream=function(t){return s&&(s.valid=!1),(s=Ln(m(n,l(x(t))))).valid=!0,s},w.clipAngle=function(t){return arguments.length?(m=null==t?(b=t,tn):function(t){var e=Math.cos(t),r=e>0,n=y(e)>kt;return Jr(i,function(t){var e,s,l,c,u;return{lineStart:function(){c=l=!1,u=1},point:function(h,f){var p,d=[h,f],g=i(h,f),v=r?g?0:o(h,f):g?o(h+(h<0?At:-At),f):0;if(!e&&(c=l=g)&&t.lineStart(),g!==l&&(p=a(e,d),(Br(e,p)||Br(d,p))&&(d[0]+=kt,d[1]+=kt,g=i(d[0],d[1]))),g!==l)u=0,g?(t.lineStart(),p=a(d,e),t.point(p[0],p[1])):(p=a(e,d),t.point(p[0],p[1]),t.lineEnd()),e=p;else if(n&&e&&r^g){var m;v&s||!(m=a(d,e,!0))||(u=0,r?(t.lineStart(),t.point(m[0][0],m[0][1]),t.point(m[1][0],m[1][1]),t.lineEnd()):(t.point(m[1][0],m[1][1]),t.lineEnd(),t.lineStart(),t.point(m[0][0],m[0][1])))}!g||e&&Br(e,d)||t.point(d[0],d[1]),e=d,l=g,s=v},lineEnd:function(){l&&t.lineEnd(),e=null},clean:function(){return u|(c&&l)<<1}}},Fn(t,6*Ct),r?[0,-t]:[-At,t-At]);function i(t,r){return Math.cos(t)*Math.cos(r)>e}function a(t,r,n){var i=[1,0,0],a=zr(Pr(t),Pr(r)),o=Or(a,a),s=a[0],l=o-s*s;if(!l)return!n&&t;var c=e*o/l,u=-e*s/l,h=zr(i,a),f=Dr(i,c);Ir(f,Dr(a,u));var p=h,d=Or(f,p),g=Or(p,p),v=d*d-g*(Or(f,f)-1);if(!(v<0)){var m=Math.sqrt(v),x=Dr(p,(-d-m)/g);if(Ir(x,f),x=Fr(x),!n)return x;var b,_=t[0],w=r[0],k=t[1],T=r[1];w<_&&(b=_,_=w,w=b);var A=w-_,M=y(A-At)<kt;if(!M&&T<k&&(b=k,k=T,T=b),M||A<kt?M?k+T>0^x[1]<(y(x[0]-_)<kt?k:T):k<=x[1]&&x[1]<=T:A>At^(_<=x[0]&&x[0]<=w)){var S=Dr(p,(-d+m)/g);return Ir(S,f),[x,Fr(S)]}}}function o(e,n){var i=r?t:At-t,a=0;return e<-i?a|=1:e>i&&(a|=2),n<-i?a|=4:n>i&&(a|=8),a}}((b=+t)*Ct),A()):b},w.clipExtent=function(t){return arguments.length?(_=t,x=t?nn(t[0][0],t[0][1],t[1][0],t[1][1]):P,A()):_},w.scale=function(t){return arguments.length?(c=+t,T()):c},w.translate=function(t){return arguments.length?(u=+t[0],h=+t[1],T()):[u,h]},w.center=function(t){return arguments.length?(f=t[0]%360*Ct,p=t[1]%360*Ct,T()):[f*Lt,p*Lt]},w.rotate=function(t){return arguments.length?(d=t[0]%360*Ct,g=t[1]%360*Ct,v=t.length>2?t[2]%360*Ct:0,T()):[d*Lt,g*Lt,v*Lt]},t.rebind(w,l,\"precision\"),function(){return r=e.apply(this,arguments),w.invert=r.invert&&k,T()}}function Ln(t){return Sn(t,function(e,r){t.point(e*Ct,r*Ct)})}function Pn(t,e){return[t,e]}function On(t,e){return[t>At?t-Mt:t<-At?t+Mt:t,e]}function zn(t,e,r){return t?e||r?Gr(Dn(t),Rn(e,r)):Dn(t):e||r?Rn(e,r):On}function In(t){return function(e,r){return[(e+=t)>At?e-Mt:e<-At?e+Mt:e,r]}}function Dn(t){var e=In(t);return e.invert=In(-t),e}function Rn(t,e){var r=Math.cos(t),n=Math.sin(t),i=Math.cos(e),a=Math.sin(e);function o(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*r+s*n;return[Math.atan2(l*i-u*a,s*r-c*n),It(u*i+l*a)]}return o.invert=function(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*i-l*a;return[Math.atan2(l*i+c*a,s*r+u*n),It(u*r-s*n)]},o}function Fn(t,e){var r=Math.cos(t),n=Math.sin(t);return function(i,a,o,s){var l=o*e;null!=i?(i=Bn(r,i),a=Bn(r,a),(o>0?i<a:i>a)&&(i+=o*Mt)):(i=t+o*Mt,a=t-.5*l);for(var c,u=i;o>0?u>a:u<a;u-=l)s.point((c=Fr([r,-n*Math.cos(u),-n*Math.sin(u)]))[0],c[1])}}function Bn(t,e){var r=Pr(e);r[0]-=t,Rr(r);var n=zt(-r[1]);return((-r[2]<0?-n:n)+2*Math.PI-kt)%(2*Math.PI)}function Nn(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map(function(e){return[t,e]})}}function jn(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map(function(e){return[e,t]})}}function Un(t){return t.source}function Vn(t){return t.target}t.geo.path=function(){var e,r,n,i,a,o=4.5;function s(e){return e&&(\"function\"==typeof o&&i.pointRadius(+o.apply(this,arguments)),a&&a.valid||(a=n(i)),t.geo.stream(e,a)),i.result()}function l(){return a=null,s}return s.area=function(e){return sn=0,t.geo.stream(e,n(pn)),sn},s.centroid=function(e){return xr=br=_r=wr=kr=Tr=Ar=Mr=Sr=0,t.geo.stream(e,n(xn)),Sr?[Ar/Sr,Mr/Sr]:Tr?[wr/Tr,kr/Tr]:_r?[xr/_r,br/_r]:[NaN,NaN]},s.bounds=function(e){return hn=fn=-(cn=un=1/0),t.geo.stream(e,n(gn)),[[cn,un],[hn,fn]]},s.projection=function(t){return arguments.length?(n=(e=t)?t.stream||(r=t,i=An(function(t,e){return r([t*Lt,e*Lt])}),function(t){return Ln(i(t))}):P,l()):e;var r,i},s.context=function(t){return arguments.length?(i=null==(r=t)?new vn:new Tn(t),\"function\"!=typeof o&&i.pointRadius(o),l()):r},s.pointRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:(i.pointRadius(+t),+t),s):o},s.projection(t.geo.albersUsa()).context(null)},t.geo.transform=function(t){return{stream:function(e){var r=new Mn(e);for(var n in t)r[n]=t[n];return r}}},Mn.prototype={point:function(t,e){this.stream.point(t,e)},sphere:function(){this.stream.sphere()},lineStart:function(){this.stream.lineStart()},lineEnd:function(){this.stream.lineEnd()},polygonStart:function(){this.stream.polygonStart()},polygonEnd:function(){this.stream.polygonEnd()}},t.geo.projection=En,t.geo.projectionMutator=Cn,(t.geo.equirectangular=function(){return En(Pn)}).raw=Pn.invert=Pn,t.geo.rotation=function(t){function e(e){return(e=t(e[0]*Ct,e[1]*Ct))[0]*=Lt,e[1]*=Lt,e}return t=zn(t[0]%360*Ct,t[1]*Ct,t.length>2?t[2]*Ct:0),e.invert=function(e){return(e=t.invert(e[0]*Ct,e[1]*Ct))[0]*=Lt,e[1]*=Lt,e},e},On.invert=Pn,t.geo.circle=function(){var t,e,r=[0,0],n=6;function i(){var t=\"function\"==typeof r?r.apply(this,arguments):r,n=zn(-t[0]*Ct,-t[1]*Ct,0).invert,i=[];return e(null,null,1,{point:function(t,e){i.push(t=n(t,e)),t[0]*=Lt,t[1]*=Lt}}),{type:\"Polygon\",coordinates:[i]}}return i.origin=function(t){return arguments.length?(r=t,i):r},i.angle=function(r){return arguments.length?(e=Fn((t=+r)*Ct,n*Ct),i):t},i.precision=function(r){return arguments.length?(e=Fn(t*Ct,(n=+r)*Ct),i):n},i.angle(90)},t.geo.distance=function(t,e){var r,n=(e[0]-t[0])*Ct,i=t[1]*Ct,a=e[1]*Ct,o=Math.sin(n),s=Math.cos(n),l=Math.sin(i),c=Math.cos(i),u=Math.sin(a),h=Math.cos(a);return Math.atan2(Math.sqrt((r=h*o)*r+(r=c*u-l*h*s)*r),l*u+c*h*s)},t.geo.graticule=function(){var e,r,n,i,a,o,s,l,c,u,h,f,p=10,d=p,g=90,v=360,m=2.5;function x(){return{type:\"MultiLineString\",coordinates:b()}}function b(){return t.range(Math.ceil(i/g)*g,n,g).map(h).concat(t.range(Math.ceil(l/v)*v,s,v).map(f)).concat(t.range(Math.ceil(r/p)*p,e,p).filter(function(t){return y(t%g)>kt}).map(c)).concat(t.range(Math.ceil(o/d)*d,a,d).filter(function(t){return y(t%v)>kt}).map(u))}return x.lines=function(){return b().map(function(t){return{type:\"LineString\",coordinates:t}})},x.outline=function(){return{type:\"Polygon\",coordinates:[h(i).concat(f(s).slice(1),h(n).reverse().slice(1),f(l).reverse().slice(1))]}},x.extent=function(t){return arguments.length?x.majorExtent(t).minorExtent(t):x.minorExtent()},x.majorExtent=function(t){return arguments.length?(i=+t[0][0],n=+t[1][0],l=+t[0][1],s=+t[1][1],i>n&&(t=i,i=n,n=t),l>s&&(t=l,l=s,s=t),x.precision(m)):[[i,l],[n,s]]},x.minorExtent=function(t){return arguments.length?(r=+t[0][0],e=+t[1][0],o=+t[0][1],a=+t[1][1],r>e&&(t=r,r=e,e=t),o>a&&(t=o,o=a,a=t),x.precision(m)):[[r,o],[e,a]]},x.step=function(t){return arguments.length?x.majorStep(t).minorStep(t):x.minorStep()},x.majorStep=function(t){return arguments.length?(g=+t[0],v=+t[1],x):[g,v]},x.minorStep=function(t){return arguments.length?(p=+t[0],d=+t[1],x):[p,d]},x.precision=function(t){return arguments.length?(m=+t,c=Nn(o,a,90),u=jn(r,e,m),h=Nn(l,s,90),f=jn(i,n,m),x):m},x.majorExtent([[-180,-90+kt],[180,90-kt]]).minorExtent([[-180,-80-kt],[180,80+kt]])},t.geo.greatArc=function(){var e,r,n=Un,i=Vn;function a(){return{type:\"LineString\",coordinates:[e||n.apply(this,arguments),r||i.apply(this,arguments)]}}return a.distance=function(){return t.geo.distance(e||n.apply(this,arguments),r||i.apply(this,arguments))},a.source=function(t){return arguments.length?(n=t,e=\"function\"==typeof t?null:t,a):n},a.target=function(t){return arguments.length?(i=t,r=\"function\"==typeof t?null:t,a):i},a.precision=function(){return arguments.length?a:0},a},t.geo.interpolate=function(t,e){return r=t[0]*Ct,n=t[1]*Ct,i=e[0]*Ct,a=e[1]*Ct,o=Math.cos(n),s=Math.sin(n),l=Math.cos(a),c=Math.sin(a),u=o*Math.cos(r),h=o*Math.sin(r),f=l*Math.cos(i),p=l*Math.sin(i),d=2*Math.asin(Math.sqrt(Rt(a-n)+o*l*Rt(i-r))),g=1/Math.sin(d),(v=d?function(t){var e=Math.sin(t*=d)*g,r=Math.sin(d-t)*g,n=r*u+e*f,i=r*h+e*p,a=r*s+e*c;return[Math.atan2(i,n)*Lt,Math.atan2(a,Math.sqrt(n*n+i*i))*Lt]}:function(){return[r*Lt,n*Lt]}).distance=d,v;var r,n,i,a,o,s,l,c,u,h,f,p,d,g,v},t.geo.length=function(e){return yn=0,t.geo.stream(e,qn),yn};var qn={sphere:D,point:D,lineStart:function(){var t,e,r;function n(n,i){var a=Math.sin(i*=Ct),o=Math.cos(i),s=y((n*=Ct)-t),l=Math.cos(s);yn+=Math.atan2(Math.sqrt((s=o*Math.sin(s))*s+(s=r*a-e*o*l)*s),e*a+r*o*l),t=n,e=a,r=o}qn.point=function(i,a){t=i*Ct,e=Math.sin(a*=Ct),r=Math.cos(a),qn.point=n},qn.lineEnd=function(){qn.point=qn.lineEnd=D}},lineEnd:D,polygonStart:D,polygonEnd:D};function Hn(t,e){function r(e,r){var n=Math.cos(e),i=Math.cos(r),a=t(n*i);return[a*i*Math.sin(e),a*Math.sin(r)]}return r.invert=function(t,r){var n=Math.sqrt(t*t+r*r),i=e(n),a=Math.sin(i),o=Math.cos(i);return[Math.atan2(t*a,n*o),Math.asin(n&&r*a/n)]},r}var Gn=Hn(function(t){return Math.sqrt(2/(1+t))},function(t){return 2*Math.asin(t/2)});(t.geo.azimuthalEqualArea=function(){return En(Gn)}).raw=Gn;var Yn=Hn(function(t){var e=Math.acos(t);return e&&e/Math.sin(e)},P);function Wn(t,e){var r=Math.cos(t),n=function(t){return Math.tan(At/4+t/2)},i=t===e?Math.sin(t):Math.log(r/Math.cos(e))/Math.log(n(e)/n(t)),a=r*Math.pow(n(t),i)/i;if(!i)return Jn;function o(t,e){a>0?e<-Et+kt&&(e=-Et+kt):e>Et-kt&&(e=Et-kt);var r=a/Math.pow(n(e),i);return[r*Math.sin(i*t),a-r*Math.cos(i*t)]}return o.invert=function(t,e){var r=a-e,n=Pt(i)*Math.sqrt(t*t+r*r);return[Math.atan2(t,r)/i,2*Math.atan(Math.pow(a/n,1/i))-Et]},o}function Xn(t,e){var r=Math.cos(t),n=t===e?Math.sin(t):(r-Math.cos(e))/(e-t),i=r/n+t;if(y(n)<kt)return Pn;function a(t,e){var r=i-e;return[r*Math.sin(n*t),i-r*Math.cos(n*t)]}return a.invert=function(t,e){var r=i-e;return[Math.atan2(t,r)/n,i-Pt(n)*Math.sqrt(t*t+r*r)]},a}(t.geo.azimuthalEquidistant=function(){return En(Yn)}).raw=Yn,(t.geo.conicConformal=function(){return an(Wn)}).raw=Wn,(t.geo.conicEquidistant=function(){return an(Xn)}).raw=Xn;var Zn=Hn(function(t){return 1/t},Math.atan);function Jn(t,e){return[t,Math.log(Math.tan(At/4+e/2))]}function Kn(t){var e,r=En(t),n=r.scale,i=r.translate,a=r.clipExtent;return r.scale=function(){var t=n.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.translate=function(){var t=i.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.clipExtent=function(t){var o=a.apply(r,arguments);if(o===r){if(e=null==t){var s=At*n(),l=i();a([[l[0]-s,l[1]-s],[l[0]+s,l[1]+s]])}}else e&&(o=null);return o},r.clipExtent(null)}(t.geo.gnomonic=function(){return En(Zn)}).raw=Zn,Jn.invert=function(t,e){return[t,2*Math.atan(Math.exp(e))-Et]},(t.geo.mercator=function(){return Kn(Jn)}).raw=Jn;var $n=Hn(function(){return 1},Math.asin);(t.geo.orthographic=function(){return En($n)}).raw=$n;var Qn=Hn(function(t){return 1/(1+t)},function(t){return 2*Math.atan(t)});function ti(t,e){return[Math.log(Math.tan(At/4+e/2)),-t]}function ei(t){return t[0]}function ri(t){return t[1]}function ni(t){for(var e=t.length,r=[0,1],n=2,i=2;i<e;i++){for(;n>1&&Ot(t[r[n-2]],t[r[n-1]],t[i])<=0;)--n;r[n++]=i}return r.slice(0,n)}function ii(t,e){return t[0]-e[0]||t[1]-e[1]}(t.geo.stereographic=function(){return En(Qn)}).raw=Qn,ti.invert=function(t,e){return[-e,2*Math.atan(Math.exp(t))-Et]},(t.geo.transverseMercator=function(){var t=Kn(ti),e=t.center,r=t.rotate;return t.center=function(t){return t?e([-t[1],t[0]]):[(t=e())[1],-t[0]]},t.rotate=function(t){return t?r([t[0],t[1],t.length>2?t[2]+90:90]):[(t=r())[0],t[1],t[2]-90]},r([0,0,90])}).raw=ti,t.geom={},t.geom.hull=function(t){var e=ei,r=ri;if(arguments.length)return n(t);function n(t){if(t.length<3)return[];var n,i=ve(e),a=ve(r),o=t.length,s=[],l=[];for(n=0;n<o;n++)s.push([+i.call(this,t[n],n),+a.call(this,t[n],n),n]);for(s.sort(ii),n=0;n<o;n++)l.push([s[n][0],-s[n][1]]);var c=ni(s),u=ni(l),h=u[0]===c[0],f=u[u.length-1]===c[c.length-1],p=[];for(n=c.length-1;n>=0;--n)p.push(t[s[c[n]][2]]);for(n=+h;n<u.length-f;++n)p.push(t[s[u[n]][2]]);return p}return n.x=function(t){return arguments.length?(e=t,n):e},n.y=function(t){return arguments.length?(r=t,n):r},n},t.geom.polygon=function(t){return V(t,ai),t};var ai=t.geom.polygon.prototype=[];function oi(t,e,r){return(r[0]-e[0])*(t[1]-e[1])<(r[1]-e[1])*(t[0]-e[0])}function si(t,e,r,n){var i=t[0],a=r[0],o=e[0]-i,s=n[0]-a,l=t[1],c=r[1],u=e[1]-l,h=n[1]-c,f=(s*(l-c)-h*(i-a))/(h*o-s*u);return[i+f*o,l+f*u]}function li(t){var e=t[0],r=t[t.length-1];return!(e[0]-r[0]||e[1]-r[1])}ai.area=function(){for(var t,e=-1,r=this.length,n=this[r-1],i=0;++e<r;)t=n,n=this[e],i+=t[1]*n[0]-t[0]*n[1];return.5*i},ai.centroid=function(t){var e,r,n=-1,i=this.length,a=0,o=0,s=this[i-1];for(arguments.length||(t=-1/(6*this.area()));++n<i;)e=s,s=this[n],r=e[0]*s[1]-s[0]*e[1],a+=(e[0]+s[0])*r,o+=(e[1]+s[1])*r;return[a*t,o*t]},ai.clip=function(t){for(var e,r,n,i,a,o,s=li(t),l=-1,c=this.length-li(this),u=this[c-1];++l<c;){for(e=t.slice(),t.length=0,i=this[l],a=e[(n=e.length-s)-1],r=-1;++r<n;)oi(o=e[r],u,i)?(oi(a,u,i)||t.push(si(a,o,u,i)),t.push(o)):oi(a,u,i)&&t.push(si(a,o,u,i)),a=o;s&&t.push(t[0]),u=i}return t};var ci,ui,hi,fi,pi,di=[],gi=[];function vi(){Ii(this),this.edge=this.site=this.circle=null}function mi(t){var e=di.pop()||new vi;return e.site=t,e}function yi(t){Si(t),hi.remove(t),di.push(t),Ii(t)}function xi(t){var e=t.circle,r=e.x,n=e.cy,i={x:r,y:n},a=t.P,o=t.N,s=[t];yi(t);for(var l=a;l.circle&&y(r-l.circle.x)<kt&&y(n-l.circle.cy)<kt;)a=l.P,s.unshift(l),yi(l),l=a;s.unshift(l),Si(l);for(var c=o;c.circle&&y(r-c.circle.x)<kt&&y(n-c.circle.cy)<kt;)o=c.N,s.push(c),yi(c),c=o;s.push(c),Si(c);var u,h=s.length;for(u=1;u<h;++u)c=s[u],l=s[u-1],Pi(c.edge,l.site,c.site,i);l=s[0],(c=s[h-1]).edge=Li(l.site,c.site,null,i),Mi(l),Mi(c)}function bi(t){for(var e,r,n,i,a=t.x,o=t.y,s=hi._;s;)if((n=_i(s,o)-a)>kt)s=s.L;else{if(!((i=a-wi(s,o))>kt)){n>-kt?(e=s.P,r=s):i>-kt?(e=s,r=s.N):e=r=s;break}if(!s.R){e=s;break}s=s.R}var l=mi(t);if(hi.insert(e,l),e||r){if(e===r)return Si(e),r=mi(e.site),hi.insert(l,r),l.edge=r.edge=Li(e.site,l.site),Mi(e),void Mi(r);if(r){Si(e),Si(r);var c=e.site,u=c.x,h=c.y,f=t.x-u,p=t.y-h,d=r.site,g=d.x-u,v=d.y-h,m=2*(f*v-p*g),y=f*f+p*p,x=g*g+v*v,b={x:(v*y-p*x)/m+u,y:(f*x-g*y)/m+h};Pi(r.edge,c,d,b),l.edge=Li(c,t,null,b),r.edge=Li(t,d,null,b),Mi(e),Mi(r)}else l.edge=Li(e.site,l.site)}}function _i(t,e){var r=t.site,n=r.x,i=r.y,a=i-e;if(!a)return n;var o=t.P;if(!o)return-1/0;var s=(r=o.site).x,l=r.y,c=l-e;if(!c)return s;var u=s-n,h=1/a-1/c,f=u/c;return h?(-f+Math.sqrt(f*f-2*h*(u*u/(-2*c)-l+c/2+i-a/2)))/h+n:(n+s)/2}function wi(t,e){var r=t.N;if(r)return _i(r,e);var n=t.site;return n.y===e?n.x:1/0}function ki(t){this.site=t,this.edges=[]}function Ti(t,e){return e.angle-t.angle}function Ai(){Ii(this),this.x=this.y=this.arc=this.site=this.cy=null}function Mi(t){var e=t.P,r=t.N;if(e&&r){var n=e.site,i=t.site,a=r.site;if(n!==a){var o=i.x,s=i.y,l=n.x-o,c=n.y-s,u=a.x-o,h=2*(l*(v=a.y-s)-c*u);if(!(h>=-Tt)){var f=l*l+c*c,p=u*u+v*v,d=(v*f-c*p)/h,g=(l*p-u*f)/h,v=g+s,m=gi.pop()||new Ai;m.arc=t,m.site=i,m.x=d+o,m.y=v+Math.sqrt(d*d+g*g),m.cy=v,t.circle=m;for(var y=null,x=pi._;x;)if(m.y<x.y||m.y===x.y&&m.x<=x.x){if(!x.L){y=x.P;break}x=x.L}else{if(!x.R){y=x;break}x=x.R}pi.insert(y,m),y||(fi=m)}}}}function Si(t){var e=t.circle;e&&(e.P||(fi=e.N),pi.remove(e),gi.push(e),Ii(e),t.circle=null)}function Ei(t,e){var r=t.b;if(r)return!0;var n,i,a=t.a,o=e[0][0],s=e[1][0],l=e[0][1],c=e[1][1],u=t.l,h=t.r,f=u.x,p=u.y,d=h.x,g=h.y,v=(f+d)/2,m=(p+g)/2;if(g===p){if(v<o||v>=s)return;if(f>d){if(a){if(a.y>=c)return}else a={x:v,y:l};r={x:v,y:c}}else{if(a){if(a.y<l)return}else a={x:v,y:c};r={x:v,y:l}}}else if(i=m-(n=(f-d)/(g-p))*v,n<-1||n>1)if(f>d){if(a){if(a.y>=c)return}else a={x:(l-i)/n,y:l};r={x:(c-i)/n,y:c}}else{if(a){if(a.y<l)return}else a={x:(c-i)/n,y:c};r={x:(l-i)/n,y:l}}else if(p<g){if(a){if(a.x>=s)return}else a={x:o,y:n*o+i};r={x:s,y:n*s+i}}else{if(a){if(a.x<o)return}else a={x:s,y:n*s+i};r={x:o,y:n*o+i}}return t.a=a,t.b=r,!0}function Ci(t,e){this.l=t,this.r=e,this.a=this.b=null}function Li(t,e,r,n){var i=new Ci(t,e);return ci.push(i),r&&Pi(i,t,e,r),n&&Pi(i,e,t,n),ui[t.i].edges.push(new Oi(i,t,e)),ui[e.i].edges.push(new Oi(i,e,t)),i}function Pi(t,e,r,n){t.a||t.b?t.l===r?t.b=n:t.a=n:(t.a=n,t.l=e,t.r=r)}function Oi(t,e,r){var n=t.a,i=t.b;this.edge=t,this.site=e,this.angle=r?Math.atan2(r.y-e.y,r.x-e.x):t.l===e?Math.atan2(i.x-n.x,n.y-i.y):Math.atan2(n.x-i.x,i.y-n.y)}function zi(){this._=null}function Ii(t){t.U=t.C=t.L=t.R=t.P=t.N=null}function Di(t,e){var r=e,n=e.R,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.R=n.L,r.R&&(r.R.U=r),n.L=r}function Ri(t,e){var r=e,n=e.L,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.L=n.R,r.L&&(r.L.U=r),n.R=r}function Fi(t){for(;t.L;)t=t.L;return t}function Bi(t,e){var r,n,i,a=t.sort(Ni).pop();for(ci=[],ui=new Array(t.length),hi=new zi,pi=new zi;;)if(i=fi,a&&(!i||a.y<i.y||a.y===i.y&&a.x<i.x))a.x===r&&a.y===n||(ui[a.i]=new ki(a),bi(a),r=a.x,n=a.y),a=t.pop();else{if(!i)break;xi(i.arc)}e&&(function(t){for(var e,r=ci,n=en(t[0][0],t[0][1],t[1][0],t[1][1]),i=r.length;i--;)(!Ei(e=r[i],t)||!n(e)||y(e.a.x-e.b.x)<kt&&y(e.a.y-e.b.y)<kt)&&(e.a=e.b=null,r.splice(i,1))}(e),function(t){for(var e,r,n,i,a,o,s,l,c,u,h=t[0][0],f=t[1][0],p=t[0][1],d=t[1][1],g=ui,v=g.length;v--;)if((a=g[v])&&a.prepare())for(l=(s=a.edges).length,o=0;o<l;)n=(u=s[o].end()).x,i=u.y,e=(c=s[++o%l].start()).x,r=c.y,(y(n-e)>kt||y(i-r)>kt)&&(s.splice(o,0,new Oi((m=a.site,x=u,b=y(n-h)<kt&&d-i>kt?{x:h,y:y(e-h)<kt?r:d}:y(i-d)<kt&&f-n>kt?{x:y(r-d)<kt?e:f,y:d}:y(n-f)<kt&&i-p>kt?{x:f,y:y(e-f)<kt?r:p}:y(i-p)<kt&&n-h>kt?{x:y(r-p)<kt?e:h,y:p}:null,_=void 0,_=new Ci(m,null),_.a=x,_.b=b,ci.push(_),_),a.site,null)),++l);var m,x,b,_}(e));var o={cells:ui,edges:ci};return hi=pi=ci=ui=null,o}function Ni(t,e){return e.y-t.y||e.x-t.x}ki.prototype.prepare=function(){for(var t,e=this.edges,r=e.length;r--;)(t=e[r].edge).b&&t.a||e.splice(r,1);return e.sort(Ti),e.length},Oi.prototype={start:function(){return this.edge.l===this.site?this.edge.a:this.edge.b},end:function(){return this.edge.l===this.site?this.edge.b:this.edge.a}},zi.prototype={insert:function(t,e){var r,n,i;if(t){if(e.P=t,e.N=t.N,t.N&&(t.N.P=e),t.N=e,t.R){for(t=t.R;t.L;)t=t.L;t.L=e}else t.R=e;r=t}else this._?(t=Fi(this._),e.P=null,e.N=t,t.P=t.L=e,r=t):(e.P=e.N=null,this._=e,r=null);for(e.L=e.R=null,e.U=r,e.C=!0,t=e;r&&r.C;)r===(n=r.U).L?(i=n.R)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.R&&(Di(this,r),r=(t=r).U),r.C=!1,n.C=!0,Ri(this,n)):(i=n.L)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.L&&(Ri(this,r),r=(t=r).U),r.C=!1,n.C=!0,Di(this,n)),r=t.U;this._.C=!1},remove:function(t){t.N&&(t.N.P=t.P),t.P&&(t.P.N=t.N),t.N=t.P=null;var e,r,n,i=t.U,a=t.L,o=t.R;if(r=a?o?Fi(o):a:o,i?i.L===t?i.L=r:i.R=r:this._=r,a&&o?(n=r.C,r.C=t.C,r.L=a,a.U=r,r!==o?(i=r.U,r.U=t.U,t=r.R,i.L=t,r.R=o,o.U=r):(r.U=i,i=r,t=r.R)):(n=t.C,t=r),t&&(t.U=i),!n)if(t&&t.C)t.C=!1;else{do{if(t===this._)break;if(t===i.L){if((e=i.R).C&&(e.C=!1,i.C=!0,Di(this,i),e=i.R),e.L&&e.L.C||e.R&&e.R.C){e.R&&e.R.C||(e.L.C=!1,e.C=!0,Ri(this,e),e=i.R),e.C=i.C,i.C=e.R.C=!1,Di(this,i),t=this._;break}}else if((e=i.L).C&&(e.C=!1,i.C=!0,Ri(this,i),e=i.L),e.L&&e.L.C||e.R&&e.R.C){e.L&&e.L.C||(e.R.C=!1,e.C=!0,Di(this,e),e=i.L),e.C=i.C,i.C=e.L.C=!1,Ri(this,i),t=this._;break}e.C=!0,t=i,i=i.U}while(!t.C);t&&(t.C=!1)}}},t.geom.voronoi=function(t){var e=ei,r=ri,n=e,i=r,a=ji;if(t)return o(t);function o(t){var e=new Array(t.length),r=a[0][0],n=a[0][1],i=a[1][0],o=a[1][1];return Bi(s(t),a).cells.forEach(function(a,s){var l=a.edges,c=a.site;(e[s]=l.length?l.map(function(t){var e=t.start();return[e.x,e.y]}):c.x>=r&&c.x<=i&&c.y>=n&&c.y<=o?[[r,o],[i,o],[i,n],[r,n]]:[]).point=t[s]}),e}function s(t){return t.map(function(t,e){return{x:Math.round(n(t,e)/kt)*kt,y:Math.round(i(t,e)/kt)*kt,i:e}})}return o.links=function(t){return Bi(s(t)).edges.filter(function(t){return t.l&&t.r}).map(function(e){return{source:t[e.l.i],target:t[e.r.i]}})},o.triangles=function(t){var e=[];return Bi(s(t)).cells.forEach(function(r,n){for(var i,a,o,s,l=r.site,c=r.edges.sort(Ti),u=-1,h=c.length,f=c[h-1].edge,p=f.l===l?f.r:f.l;++u<h;)f,i=p,p=(f=c[u].edge).l===l?f.r:f.l,n<i.i&&n<p.i&&(o=i,s=p,((a=l).x-s.x)*(o.y-a.y)-(a.x-o.x)*(s.y-a.y)<0)&&e.push([t[n],t[i.i],t[p.i]])}),e},o.x=function(t){return arguments.length?(n=ve(e=t),o):e},o.y=function(t){return arguments.length?(i=ve(r=t),o):r},o.clipExtent=function(t){return arguments.length?(a=null==t?ji:t,o):a===ji?null:a},o.size=function(t){return arguments.length?o.clipExtent(t&&[[0,0],t]):a===ji?null:a&&a[1]},o};var ji=[[-1e6,-1e6],[1e6,1e6]];function Ui(t){return t.x}function Vi(t){return t.y}function qi(e,r){e=t.rgb(e),r=t.rgb(r);var n=e.r,i=e.g,a=e.b,o=r.r-n,s=r.g-i,l=r.b-a;return function(t){return\"#\"+ce(Math.round(n+o*t))+ce(Math.round(i+s*t))+ce(Math.round(a+l*t))}}function Hi(t,e){var r,n={},i={};for(r in t)r in e?n[r]=Zi(t[r],e[r]):i[r]=t[r];for(r in e)r in t||(i[r]=e[r]);return function(t){for(r in n)i[r]=n[r](t);return i}}function Gi(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function Yi(t,e){var r,n,i,a=Wi.lastIndex=Xi.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=Wi.exec(t))&&(n=Xi.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:Gi(r,n)})),a=Xi.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?(e=l[0].x,function(t){return e(t)+\"\"}):function(){return e}:(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}t.geom.delaunay=function(e){return t.geom.voronoi().triangles(e)},t.geom.quadtree=function(t,e,r,n,i){var a,o=ei,s=ri;if(a=arguments.length)return o=Ui,s=Vi,3===a&&(i=r,n=e,r=e=0),l(t);function l(t){var l,c,u,h,f,p,d,g,v,m=ve(o),x=ve(s);if(null!=e)p=e,d=r,g=n,v=i;else if(g=v=-(p=d=1/0),c=[],u=[],f=t.length,a)for(h=0;h<f;++h)(l=t[h]).x<p&&(p=l.x),l.y<d&&(d=l.y),l.x>g&&(g=l.x),l.y>v&&(v=l.y),c.push(l.x),u.push(l.y);else for(h=0;h<f;++h){var b=+m(l=t[h],h),_=+x(l,h);b<p&&(p=b),_<d&&(d=_),b>g&&(g=b),_>v&&(v=_),c.push(b),u.push(_)}var w=g-p,k=v-d;function T(t,e,r,n,i,a,o,s){if(!isNaN(r)&&!isNaN(n))if(t.leaf){var l=t.x,c=t.y;if(null!=l)if(y(l-r)+y(c-n)<.01)A(t,e,r,n,i,a,o,s);else{var u=t.point;t.x=t.y=t.point=null,A(t,u,l,c,i,a,o,s),A(t,e,r,n,i,a,o,s)}else t.x=r,t.y=n,t.point=e}else A(t,e,r,n,i,a,o,s)}function A(t,e,r,n,i,a,o,s){var l=.5*(i+o),c=.5*(a+s),u=r>=l,h=n>=c,f=h<<1|u;t.leaf=!1,u?i=l:o=l,h?a=c:s=c,T(t=t.nodes[f]||(t.nodes[f]={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){T(M,t,+m(t,++h),+x(t,h),p,d,g,v)}}),e,r,n,i,a,o,s)}w>k?v=d+w:g=p+k;var M={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){T(M,t,+m(t,++h),+x(t,h),p,d,g,v)}};if(M.visit=function(t){!function t(e,r,n,i,a,o){if(!e(r,n,i,a,o)){var s=.5*(n+a),l=.5*(i+o),c=r.nodes;c[0]&&t(e,c[0],n,i,s,l),c[1]&&t(e,c[1],s,i,a,l),c[2]&&t(e,c[2],n,l,s,o),c[3]&&t(e,c[3],s,l,a,o)}}(t,M,p,d,g,v)},M.find=function(t){return function(t,e,r,n,i,a,o){var s,l=1/0;return function t(c,u,h,f,p){if(!(u>a||h>o||f<n||p<i)){if(d=c.point){var d,g=e-c.x,v=r-c.y,m=g*g+v*v;if(m<l){var y=Math.sqrt(l=m);n=e-y,i=r-y,a=e+y,o=r+y,s=d}}for(var x=c.nodes,b=.5*(u+f),_=.5*(h+p),w=(r>=_)<<1|e>=b,k=w+4;w<k;++w)if(c=x[3&w])switch(3&w){case 0:t(c,u,h,b,_);break;case 1:t(c,b,h,f,_);break;case 2:t(c,u,_,b,p);break;case 3:t(c,b,_,f,p)}}}(t,n,i,a,o),s}(M,t[0],t[1],p,d,g,v)},h=-1,null==e){for(;++h<f;)T(M,t[h],c[h],u[h],p,d,g,v);--h}else t.forEach(M.add);return c=u=t=l=null,M}return l.x=function(t){return arguments.length?(o=t,l):o},l.y=function(t){return arguments.length?(s=t,l):s},l.extent=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=+t[0][0],r=+t[0][1],n=+t[1][0],i=+t[1][1]),l):null==e?null:[[e,r],[n,i]]},l.size=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=r=0,n=+t[0],i=+t[1]),l):null==e?null:[n-e,i-r]},l},t.interpolateRgb=qi,t.interpolateObject=Hi,t.interpolateNumber=Gi,t.interpolateString=Yi;var Wi=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,Xi=new RegExp(Wi.source,\"g\");function Zi(e,r){for(var n,i=t.interpolators.length;--i>=0&&!(n=t.interpolators[i](e,r)););return n}function Ji(t,e){var r,n=[],i=[],a=t.length,o=e.length,s=Math.min(t.length,e.length);for(r=0;r<s;++r)n.push(Zi(t[r],e[r]));for(;r<a;++r)i[r]=t[r];for(;r<o;++r)i[r]=e[r];return function(t){for(r=0;r<s;++r)i[r]=n[r](t);return i}}t.interpolate=Zi,t.interpolators=[function(t,e){var r=typeof e;return(\"string\"===r?ge.has(e.toLowerCase())||/^(#|rgb\\(|hsl\\()/i.test(e)?qi:Yi:e instanceof Ut?qi:Array.isArray(e)?Ji:\"object\"===r&&isNaN(e)?Hi:Gi)(t,e)}],t.interpolateArray=Ji;var Ki=function(){return P},$i=t.map({linear:Ki,poly:function(t){return function(e){return Math.pow(e,t)}},quad:function(){return ra},cubic:function(){return na},sin:function(){return aa},exp:function(){return oa},circle:function(){return sa},elastic:function(t,e){var r;arguments.length<2&&(e=.45);arguments.length?r=e/Mt*Math.asin(1/t):(t=1,r=e/4);return function(n){return 1+t*Math.pow(2,-10*n)*Math.sin((n-r)*Mt/e)}},back:function(t){t||(t=1.70158);return function(e){return e*e*((t+1)*e-t)}},bounce:function(){return la}}),Qi=t.map({in:P,out:ta,\"in-out\":ea,\"out-in\":function(t){return ea(ta(t))}});function ta(t){return function(e){return 1-t(1-e)}}function ea(t){return function(e){return.5*(e<.5?t(2*e):2-t(2-2*e))}}function ra(t){return t*t}function na(t){return t*t*t}function ia(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}function aa(t){return 1-Math.cos(t*Et)}function oa(t){return Math.pow(2,10*(t-1))}function sa(t){return 1-Math.sqrt(1-t*t)}function la(t){return t<1/2.75?7.5625*t*t:t<2/2.75?7.5625*(t-=1.5/2.75)*t+.75:t<2.5/2.75?7.5625*(t-=2.25/2.75)*t+.9375:7.5625*(t-=2.625/2.75)*t+.984375}function ca(t,e){return e-=t,function(r){return Math.round(t+e*r)}}function ua(t){var e,r,n,i=[t.a,t.b],a=[t.c,t.d],o=fa(i),s=ha(i,a),l=fa(((e=a)[0]+=(n=-s)*(r=i)[0],e[1]+=n*r[1],e))||0;i[0]*a[1]<a[0]*i[1]&&(i[0]*=-1,i[1]*=-1,o*=-1,s*=-1),this.rotate=(o?Math.atan2(i[1],i[0]):Math.atan2(-a[0],a[1]))*Lt,this.translate=[t.e,t.f],this.scale=[o,l],this.skew=l?Math.atan2(s,l)*Lt:0}function ha(t,e){return t[0]*e[0]+t[1]*e[1]}function fa(t){var e=Math.sqrt(ha(t,t));return e&&(t[0]/=e,t[1]/=e),e}t.ease=function(t){var e,n=t.indexOf(\"-\"),i=n>=0?t.slice(0,n):t,a=n>=0?t.slice(n+1):\"in\";return i=$i.get(i)||Ki,a=Qi.get(a)||P,e=a(i.apply(null,r.call(arguments,1))),function(t){return t<=0?0:t>=1?1:e(t)}},t.interpolateHcl=function(e,r){e=t.hcl(e),r=t.hcl(r);var n=e.h,i=e.c,a=e.l,o=r.h-n,s=r.c-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.c:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Wt(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateHsl=function(e,r){e=t.hsl(e),r=t.hsl(r);var n=e.h,i=e.s,a=e.l,o=r.h-n,s=r.s-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.s:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Ht(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateLab=function(e,r){e=t.lab(e),r=t.lab(r);var n=e.l,i=e.a,a=e.b,o=r.l-n,s=r.a-i,l=r.b-a;return function(t){return te(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateRound=ca,t.transform=function(e){var r=i.createElementNS(t.ns.prefix.svg,\"g\");return(t.transform=function(t){if(null!=t){r.setAttribute(\"transform\",t);var e=r.transform.baseVal.consolidate()}return new ua(e?e.matrix:pa)})(e)},ua.prototype.toString=function(){return\"translate(\"+this.translate+\")rotate(\"+this.rotate+\")skewX(\"+this.skew+\")scale(\"+this.scale+\")\"};var pa={a:1,b:0,c:0,d:1,e:0,f:0};function da(t){return t.length?t.pop()+\",\":\"\"}function ga(e,r){var n=[],i=[];return e=t.transform(e),r=t.transform(r),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(\"translate(\",null,\",\",null,\")\");n.push({i:i-4,x:Gi(t[0],e[0])},{i:i-2,x:Gi(t[1],e[1])})}else(e[0]||e[1])&&r.push(\"translate(\"+e+\")\")}(e.translate,r.translate,n,i),function(t,e,r,n){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),n.push({i:r.push(da(r)+\"rotate(\",null,\")\")-2,x:Gi(t,e)})):e&&r.push(da(r)+\"rotate(\"+e+\")\")}(e.rotate,r.rotate,n,i),function(t,e,r,n){t!==e?n.push({i:r.push(da(r)+\"skewX(\",null,\")\")-2,x:Gi(t,e)}):e&&r.push(da(r)+\"skewX(\"+e+\")\")}(e.skew,r.skew,n,i),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(da(r)+\"scale(\",null,\",\",null,\")\");n.push({i:i-4,x:Gi(t[0],e[0])},{i:i-2,x:Gi(t[1],e[1])})}else 1===e[0]&&1===e[1]||r.push(da(r)+\"scale(\"+e+\")\")}(e.scale,r.scale,n,i),e=r=null,function(t){for(var e,r=-1,a=i.length;++r<a;)n[(e=i[r]).i]=e.x(t);return n.join(\"\")}}function va(t,e){return e=(e-=t=+t)||1/e,function(r){return(r-t)/e}}function ma(t,e){return e=(e-=t=+t)||1/e,function(r){return Math.max(0,Math.min(1,(r-t)/e))}}function ya(t){for(var e=t.source,r=t.target,n=function(t,e){if(t===e)return t;var r=xa(t),n=xa(e),i=r.pop(),a=n.pop(),o=null;for(;i===a;)o=i,i=r.pop(),a=n.pop();return o}(e,r),i=[e];e!==n;)e=e.parent,i.push(e);for(var a=i.length;r!==n;)i.splice(a,0,r),r=r.parent;return i}function xa(t){for(var e=[],r=t.parent;null!=r;)e.push(t),t=r,r=r.parent;return e.push(t),e}function ba(t){t.fixed|=2}function _a(t){t.fixed&=-7}function wa(t){t.fixed|=4,t.px=t.x,t.py=t.y}function ka(t){t.fixed&=-5}t.interpolateTransform=ga,t.layout={},t.layout.bundle=function(){return function(t){for(var e=[],r=-1,n=t.length;++r<n;)e.push(ya(t[r]));return e}},t.layout.chord=function(){var e,r,n,i,a,o,s,l={},c=0;function u(){var l,u,f,p,d,g={},v=[],m=t.range(i),y=[];for(e=[],r=[],l=0,p=-1;++p<i;){for(u=0,d=-1;++d<i;)u+=n[p][d];v.push(u),y.push(t.range(i)),l+=u}for(a&&m.sort(function(t,e){return a(v[t],v[e])}),o&&y.forEach(function(t,e){t.sort(function(t,r){return o(n[e][t],n[e][r])})}),l=(Mt-c*i)/l,u=0,p=-1;++p<i;){for(f=u,d=-1;++d<i;){var x=m[p],b=y[x][d],_=n[x][b],w=u,k=u+=_*l;g[x+\"-\"+b]={index:x,subindex:b,startAngle:w,endAngle:k,value:_}}r[x]={index:x,startAngle:f,endAngle:u,value:v[x]},u+=c}for(p=-1;++p<i;)for(d=p-1;++d<i;){var T=g[p+\"-\"+d],A=g[d+\"-\"+p];(T.value||A.value)&&e.push(T.value<A.value?{source:A,target:T}:{source:T,target:A})}s&&h()}function h(){e.sort(function(t,e){return s((t.source.value+t.target.value)/2,(e.source.value+e.target.value)/2)})}return l.matrix=function(t){return arguments.length?(i=(n=t)&&n.length,e=r=null,l):n},l.padding=function(t){return arguments.length?(c=t,e=r=null,l):c},l.sortGroups=function(t){return arguments.length?(a=t,e=r=null,l):a},l.sortSubgroups=function(t){return arguments.length?(o=t,e=null,l):o},l.sortChords=function(t){return arguments.length?(s=t,e&&h(),l):s},l.chords=function(){return e||u(),e},l.groups=function(){return r||u(),r},l},t.layout.force=function(){var e,r,n,i,a,o,s={},l=t.dispatch(\"start\",\"tick\",\"end\"),c=[1,1],u=.9,h=Ta,f=Aa,p=-30,d=Ma,g=.1,v=.64,m=[],y=[];function x(t){return function(e,r,n,i){if(e.point!==t){var a=e.cx-t.x,o=e.cy-t.y,s=i-r,l=a*a+o*o;if(s*s/v<l){if(l<d){var c=e.charge/l;t.px-=a*c,t.py-=o*c}return!0}if(e.point&&l&&l<d){c=e.pointCharge/l;t.px-=a*c,t.py-=o*c}}return!e.charge}}function b(e){e.px=t.event.x,e.py=t.event.y,s.resume()}return s.tick=function(){if((n*=.99)<.005)return e=null,l.end({type:\"end\",alpha:n=0}),!0;var r,s,h,f,d,v,b,_,w,k=m.length,T=y.length;for(s=0;s<T;++s)f=(h=y[s]).source,(v=(_=(d=h.target).x-f.x)*_+(w=d.y-f.y)*w)&&(_*=v=n*a[s]*((v=Math.sqrt(v))-i[s])/v,w*=v,d.x-=_*(b=f.weight+d.weight?f.weight/(f.weight+d.weight):.5),d.y-=w*b,f.x+=_*(b=1-b),f.y+=w*b);if((b=n*g)&&(_=c[0]/2,w=c[1]/2,s=-1,b))for(;++s<k;)(h=m[s]).x+=(_-h.x)*b,h.y+=(w-h.y)*b;if(p)for(!function t(e,r,n){var i=0,a=0;e.charge=0;if(!e.leaf)for(var o,s=e.nodes,l=s.length,c=-1;++c<l;)null!=(o=s[c])&&(t(o,r,n),e.charge+=o.charge,i+=o.charge*o.cx,a+=o.charge*o.cy);if(e.point){e.leaf||(e.point.x+=Math.random()-.5,e.point.y+=Math.random()-.5);var u=r*n[e.point.index];e.charge+=e.pointCharge=u,i+=u*e.point.x,a+=u*e.point.y}e.cx=i/e.charge;e.cy=a/e.charge}(r=t.geom.quadtree(m),n,o),s=-1;++s<k;)(h=m[s]).fixed||r.visit(x(h));for(s=-1;++s<k;)(h=m[s]).fixed?(h.x=h.px,h.y=h.py):(h.x-=(h.px-(h.px=h.x))*u,h.y-=(h.py-(h.py=h.y))*u);l.tick({type:\"tick\",alpha:n})},s.nodes=function(t){return arguments.length?(m=t,s):m},s.links=function(t){return arguments.length?(y=t,s):y},s.size=function(t){return arguments.length?(c=t,s):c},s.linkDistance=function(t){return arguments.length?(h=\"function\"==typeof t?t:+t,s):h},s.distance=s.linkDistance,s.linkStrength=function(t){return arguments.length?(f=\"function\"==typeof t?t:+t,s):f},s.friction=function(t){return arguments.length?(u=+t,s):u},s.charge=function(t){return arguments.length?(p=\"function\"==typeof t?t:+t,s):p},s.chargeDistance=function(t){return arguments.length?(d=t*t,s):Math.sqrt(d)},s.gravity=function(t){return arguments.length?(g=+t,s):g},s.theta=function(t){return arguments.length?(v=t*t,s):Math.sqrt(v)},s.alpha=function(t){return arguments.length?(t=+t,n?t>0?n=t:(e.c=null,e.t=NaN,e=null,l.end({type:\"end\",alpha:n=0})):t>0&&(l.start({type:\"start\",alpha:n=t}),e=Te(s.tick)),s):n},s.start=function(){var t,e,r,n=m.length,l=y.length,u=c[0],d=c[1];for(t=0;t<n;++t)(r=m[t]).index=t,r.weight=0;for(t=0;t<l;++t)\"number\"==typeof(r=y[t]).source&&(r.source=m[r.source]),\"number\"==typeof r.target&&(r.target=m[r.target]),++r.source.weight,++r.target.weight;for(t=0;t<n;++t)r=m[t],isNaN(r.x)&&(r.x=g(\"x\",u)),isNaN(r.y)&&(r.y=g(\"y\",d)),isNaN(r.px)&&(r.px=r.x),isNaN(r.py)&&(r.py=r.y);if(i=[],\"function\"==typeof h)for(t=0;t<l;++t)i[t]=+h.call(this,y[t],t);else for(t=0;t<l;++t)i[t]=h;if(a=[],\"function\"==typeof f)for(t=0;t<l;++t)a[t]=+f.call(this,y[t],t);else for(t=0;t<l;++t)a[t]=f;if(o=[],\"function\"==typeof p)for(t=0;t<n;++t)o[t]=+p.call(this,m[t],t);else for(t=0;t<n;++t)o[t]=p;function g(r,i){if(!e){for(e=new Array(n),c=0;c<n;++c)e[c]=[];for(c=0;c<l;++c){var a=y[c];e[a.source.index].push(a.target),e[a.target.index].push(a.source)}}for(var o,s=e[t],c=-1,u=s.length;++c<u;)if(!isNaN(o=s[c][r]))return o;return Math.random()*i}return s.resume()},s.resume=function(){return s.alpha(.1)},s.stop=function(){return s.alpha(0)},s.drag=function(){if(r||(r=t.behavior.drag().origin(P).on(\"dragstart.force\",ba).on(\"drag.force\",b).on(\"dragend.force\",_a)),!arguments.length)return r;this.on(\"mouseover.force\",wa).on(\"mouseout.force\",ka).call(r)},t.rebind(s,l,\"on\")};var Ta=20,Aa=1,Ma=1/0;function Sa(e,r){return t.rebind(e,r,\"sort\",\"children\",\"value\"),e.nodes=e,e.links=za,e}function Ea(t,e){for(var r=[t];null!=(t=r.pop());)if(e(t),(i=t.children)&&(n=i.length))for(var n,i;--n>=0;)r.push(i[n])}function Ca(t,e){for(var r=[t],n=[];null!=(t=r.pop());)if(n.push(t),(a=t.children)&&(i=a.length))for(var i,a,o=-1;++o<i;)r.push(a[o]);for(;null!=(t=n.pop());)e(t)}function La(t){return t.children}function Pa(t){return t.value}function Oa(t,e){return e.value-t.value}function za(e){return t.merge(e.map(function(t){return(t.children||[]).map(function(e){return{source:t,target:e}})}))}t.layout.hierarchy=function(){var t=Oa,e=La,r=Pa;function n(i){var a,o=[i],s=[];for(i.depth=0;null!=(a=o.pop());)if(s.push(a),(c=e.call(n,a,a.depth))&&(l=c.length)){for(var l,c,u;--l>=0;)o.push(u=c[l]),u.parent=a,u.depth=a.depth+1;r&&(a.value=0),a.children=c}else r&&(a.value=+r.call(n,a,a.depth)||0),delete a.children;return Ca(i,function(e){var n,i;t&&(n=e.children)&&n.sort(t),r&&(i=e.parent)&&(i.value+=e.value)}),s}return n.sort=function(e){return arguments.length?(t=e,n):t},n.children=function(t){return arguments.length?(e=t,n):e},n.value=function(t){return arguments.length?(r=t,n):r},n.revalue=function(t){return r&&(Ea(t,function(t){t.children&&(t.value=0)}),Ca(t,function(t){var e;t.children||(t.value=+r.call(n,t,t.depth)||0),(e=t.parent)&&(e.value+=t.value)})),t},n},t.layout.partition=function(){var e=t.layout.hierarchy(),r=[1,1];function n(t,n){var i=e.call(this,t,n);return function t(e,r,n,i){var a=e.children;if(e.x=r,e.y=e.depth*i,e.dx=n,e.dy=i,a&&(o=a.length)){var o,s,l,c=-1;for(n=e.value?n/e.value:0;++c<o;)t(s=a[c],r,l=s.value*n,i),r+=l}}(i[0],0,r[0],r[1]/function t(e){var r=e.children,n=0;if(r&&(i=r.length))for(var i,a=-1;++a<i;)n=Math.max(n,t(r[a]));return 1+n}(i[0])),i}return n.size=function(t){return arguments.length?(r=t,n):r},Sa(n,e)},t.layout.pie=function(){var e=Number,r=Ia,n=0,i=Mt,a=0;function o(s){var l,c=s.length,u=s.map(function(t,r){return+e.call(o,t,r)}),h=+(\"function\"==typeof n?n.apply(this,arguments):n),f=(\"function\"==typeof i?i.apply(this,arguments):i)-h,p=Math.min(Math.abs(f)/c,+(\"function\"==typeof a?a.apply(this,arguments):a)),d=p*(f<0?-1:1),g=t.sum(u),v=g?(f-c*d)/g:0,m=t.range(c),y=[];return null!=r&&m.sort(r===Ia?function(t,e){return u[e]-u[t]}:function(t,e){return r(s[t],s[e])}),m.forEach(function(t){y[t]={data:s[t],value:l=u[t],startAngle:h,endAngle:h+=l*v+d,padAngle:p}}),y}return o.value=function(t){return arguments.length?(e=t,o):e},o.sort=function(t){return arguments.length?(r=t,o):r},o.startAngle=function(t){return arguments.length?(n=t,o):n},o.endAngle=function(t){return arguments.length?(i=t,o):i},o.padAngle=function(t){return arguments.length?(a=t,o):a},o};var Ia={};function Da(t){return t.x}function Ra(t){return t.y}function Fa(t,e,r){t.y0=e,t.y=r}t.layout.stack=function(){var e=P,r=ja,n=Ua,i=Fa,a=Da,o=Ra;function s(l,c){if(!(p=l.length))return l;var u=l.map(function(t,r){return e.call(s,t,r)}),h=u.map(function(t){return t.map(function(t,e){return[a.call(s,t,e),o.call(s,t,e)]})}),f=r.call(s,h,c);u=t.permute(u,f),h=t.permute(h,f);var p,d,g,v,m=n.call(s,h,c),y=u[0].length;for(g=0;g<y;++g)for(i.call(s,u[0][g],v=m[g],h[0][g][1]),d=1;d<p;++d)i.call(s,u[d][g],v+=h[d-1][g][1],h[d][g][1]);return l}return s.values=function(t){return arguments.length?(e=t,s):e},s.order=function(t){return arguments.length?(r=\"function\"==typeof t?t:Ba.get(t)||ja,s):r},s.offset=function(t){return arguments.length?(n=\"function\"==typeof t?t:Na.get(t)||Ua,s):n},s.x=function(t){return arguments.length?(a=t,s):a},s.y=function(t){return arguments.length?(o=t,s):o},s.out=function(t){return arguments.length?(i=t,s):i},s};var Ba=t.map({\"inside-out\":function(e){var r,n,i=e.length,a=e.map(Va),o=e.map(qa),s=t.range(i).sort(function(t,e){return a[t]-a[e]}),l=0,c=0,u=[],h=[];for(r=0;r<i;++r)n=s[r],l<c?(l+=o[n],u.push(n)):(c+=o[n],h.push(n));return h.reverse().concat(u)},reverse:function(e){return t.range(e.length).reverse()},default:ja}),Na=t.map({silhouette:function(t){var e,r,n,i=t.length,a=t[0].length,o=[],s=0,l=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];n>s&&(s=n),o.push(n)}for(r=0;r<a;++r)l[r]=(s-o[r])/2;return l},wiggle:function(t){var e,r,n,i,a,o,s,l,c,u=t.length,h=t[0],f=h.length,p=[];for(p[0]=l=c=0,r=1;r<f;++r){for(e=0,i=0;e<u;++e)i+=t[e][r][1];for(e=0,a=0,s=h[r][0]-h[r-1][0];e<u;++e){for(n=0,o=(t[e][r][1]-t[e][r-1][1])/(2*s);n<e;++n)o+=(t[n][r][1]-t[n][r-1][1])/s;a+=o*t[e][r][1]}p[r]=l-=i?a/i*s:0,l<c&&(c=l)}for(r=0;r<f;++r)p[r]-=c;return p},expand:function(t){var e,r,n,i=t.length,a=t[0].length,o=1/i,s=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];if(n)for(e=0;e<i;e++)t[e][r][1]/=n;else for(e=0;e<i;e++)t[e][r][1]=o}for(r=0;r<a;++r)s[r]=0;return s},zero:Ua});function ja(e){return t.range(e.length)}function Ua(t){for(var e=-1,r=t[0].length,n=[];++e<r;)n[e]=0;return n}function Va(t){for(var e,r=1,n=0,i=t[0][1],a=t.length;r<a;++r)(e=t[r][1])>i&&(n=r,i=e);return n}function qa(t){return t.reduce(Ha,0)}function Ha(t,e){return t+e[1]}function Ga(t,e){return Ya(t,Math.ceil(Math.log(e.length)/Math.LN2+1))}function Ya(t,e){for(var r=-1,n=+t[0],i=(t[1]-n)/e,a=[];++r<=e;)a[r]=i*r+n;return a}function Wa(e){return[t.min(e),t.max(e)]}function Xa(t,e){return t.value-e.value}function Za(t,e){var r=t._pack_next;t._pack_next=e,e._pack_prev=t,e._pack_next=r,r._pack_prev=e}function Ja(t,e){t._pack_next=e,e._pack_prev=t}function Ka(t,e){var r=e.x-t.x,n=e.y-t.y,i=t.r+e.r;return.999*i*i>r*r+n*n}function $a(t){if((e=t.children)&&(l=e.length)){var e,r,n,i,a,o,s,l,c=1/0,u=-1/0,h=1/0,f=-1/0;if(e.forEach(Qa),(r=e[0]).x=-r.r,r.y=0,x(r),l>1&&((n=e[1]).x=n.r,n.y=0,x(n),l>2))for(eo(r,n,i=e[2]),x(i),Za(r,i),r._pack_prev=i,Za(i,n),n=r._pack_next,a=3;a<l;a++){eo(r,n,i=e[a]);var p=0,d=1,g=1;for(o=n._pack_next;o!==n;o=o._pack_next,d++)if(Ka(o,i)){p=1;break}if(1==p)for(s=r._pack_prev;s!==o._pack_prev&&!Ka(s,i);s=s._pack_prev,g++);p?(d<g||d==g&&n.r<r.r?Ja(r,n=o):Ja(r=s,n),a--):(Za(r,i),n=i,x(i))}var v=(c+u)/2,m=(h+f)/2,y=0;for(a=0;a<l;a++)(i=e[a]).x-=v,i.y-=m,y=Math.max(y,i.r+Math.sqrt(i.x*i.x+i.y*i.y));t.r=y,e.forEach(to)}function x(t){c=Math.min(t.x-t.r,c),u=Math.max(t.x+t.r,u),h=Math.min(t.y-t.r,h),f=Math.max(t.y+t.r,f)}}function Qa(t){t._pack_next=t._pack_prev=t}function to(t){delete t._pack_next,delete t._pack_prev}function eo(t,e,r){var n=t.r+r.r,i=e.x-t.x,a=e.y-t.y;if(n&&(i||a)){var o=e.r+r.r,s=i*i+a*a,l=.5+((n*=n)-(o*=o))/(2*s),c=Math.sqrt(Math.max(0,2*o*(n+s)-(n-=s)*n-o*o))/(2*s);r.x=t.x+l*i+c*a,r.y=t.y+l*a-c*i}else r.x=t.x+n,r.y=t.y}function ro(t,e){return t.parent==e.parent?1:2}function no(t){var e=t.children;return e.length?e[0]:t.t}function io(t){var e,r=t.children;return(e=r.length)?r[e-1]:t.t}function ao(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function oo(t,e,r){return t.a.parent===e.parent?t.a:r}function so(t){return{x:t.x,y:t.y,dx:t.dx,dy:t.dy}}function lo(t,e){var r=t.x+e[3],n=t.y+e[0],i=t.dx-e[1]-e[3],a=t.dy-e[0]-e[2];return i<0&&(r+=i/2,i=0),a<0&&(n+=a/2,a=0),{x:r,y:n,dx:i,dy:a}}function co(t){var e=t[0],r=t[t.length-1];return e<r?[e,r]:[r,e]}function uo(t){return t.rangeExtent?t.rangeExtent():co(t.range())}function ho(t,e,r,n){var i=r(t[0],t[1]),a=n(e[0],e[1]);return function(t){return a(i(t))}}function fo(t,e){var r,n=0,i=t.length-1,a=t[n],o=t[i];return o<a&&(r=n,n=i,i=r,r=a,a=o,o=r),t[n]=e.floor(a),t[i]=e.ceil(o),t}function po(t){return t?{floor:function(e){return Math.floor(e/t)*t},ceil:function(e){return Math.ceil(e/t)*t}}:go}t.layout.histogram=function(){var e=!0,r=Number,n=Wa,i=Ga;function a(a,o){for(var s,l,c=[],u=a.map(r,this),h=n.call(this,u,o),f=i.call(this,h,u,o),p=(o=-1,u.length),d=f.length-1,g=e?1:1/p;++o<d;)(s=c[o]=[]).dx=f[o+1]-(s.x=f[o]),s.y=0;if(d>0)for(o=-1;++o<p;)(l=u[o])>=h[0]&&l<=h[1]&&((s=c[t.bisect(f,l,1,d)-1]).y+=g,s.push(a[o]));return c}return a.value=function(t){return arguments.length?(r=t,a):r},a.range=function(t){return arguments.length?(n=ve(t),a):n},a.bins=function(t){return arguments.length?(i=\"number\"==typeof t?function(e){return Ya(e,t)}:ve(t),a):i},a.frequency=function(t){return arguments.length?(e=!!t,a):e},a},t.layout.pack=function(){var e,r=t.layout.hierarchy().sort(Xa),n=0,i=[1,1];function a(t,a){var o=r.call(this,t,a),s=o[0],l=i[0],c=i[1],u=null==e?Math.sqrt:\"function\"==typeof e?e:function(){return e};if(s.x=s.y=0,Ca(s,function(t){t.r=+u(t.value)}),Ca(s,$a),n){var h=n*(e?1:Math.max(2*s.r/l,2*s.r/c))/2;Ca(s,function(t){t.r+=h}),Ca(s,$a),Ca(s,function(t){t.r-=h})}return function t(e,r,n,i){var a=e.children;e.x=r+=i*e.x;e.y=n+=i*e.y;e.r*=i;if(a)for(var o=-1,s=a.length;++o<s;)t(a[o],r,n,i)}(s,l/2,c/2,e?1:1/Math.max(2*s.r/l,2*s.r/c)),o}return a.size=function(t){return arguments.length?(i=t,a):i},a.radius=function(t){return arguments.length?(e=null==t||\"function\"==typeof t?t:+t,a):e},a.padding=function(t){return arguments.length?(n=+t,a):n},Sa(a,r)},t.layout.tree=function(){var e=t.layout.hierarchy().sort(null).value(null),r=ro,n=[1,1],i=null;function a(t,a){var c=e.call(this,t,a),u=c[0],h=function(t){var e,r={A:null,children:[t]},n=[r];for(;null!=(e=n.pop());)for(var i,a=e.children,o=0,s=a.length;o<s;++o)n.push((a[o]=i={_:a[o],parent:e,children:(i=a[o].children)&&i.slice()||[],A:null,a:null,z:0,m:0,c:0,s:0,t:null,i:o}).a=i);return r.children[0]}(u);if(Ca(h,o),h.parent.m=-h.z,Ea(h,s),i)Ea(u,l);else{var f=u,p=u,d=u;Ea(u,function(t){t.x<f.x&&(f=t),t.x>p.x&&(p=t),t.depth>d.depth&&(d=t)});var g=r(f,p)/2-f.x,v=n[0]/(p.x+r(p,f)/2+g),m=n[1]/(d.depth||1);Ea(u,function(t){t.x=(t.x+g)*v,t.y=t.depth*m})}return c}function o(t){var e=t.children,n=t.parent.children,i=t.i?n[t.i-1]:null;if(e.length){!function(t){var e,r=0,n=0,i=t.children,a=i.length;for(;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(t);var a=(e[0].z+e[e.length-1].z)/2;i?(t.z=i.z+r(t._,i._),t.m=t.z-a):t.z=a}else i&&(t.z=i.z+r(t._,i._));t.parent.A=function(t,e,n){if(e){for(var i,a=t,o=t,s=e,l=a.parent.children[0],c=a.m,u=o.m,h=s.m,f=l.m;s=io(s),a=no(a),s&&a;)l=no(l),(o=io(o)).a=t,(i=s.z+h-a.z-c+r(s._,a._))>0&&(ao(oo(s,t,n),t,i),c+=i,u+=i),h+=s.m,c+=a.m,f+=l.m,u+=o.m;s&&!io(o)&&(o.t=s,o.m+=h-u),a&&!no(l)&&(l.t=a,l.m+=c-f,n=t)}return n}(t,i,t.parent.A||n[0])}function s(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function l(t){t.x*=n[0],t.y=t.depth*n[1]}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t)?l:null,a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null==(n=t)?null:l,a):i?n:null},Sa(a,e)},t.layout.cluster=function(){var e=t.layout.hierarchy().sort(null).value(null),r=ro,n=[1,1],i=!1;function a(a,o){var s,l=e.call(this,a,o),c=l[0],u=0;Ca(c,function(e){var n=e.children;n&&n.length?(e.x=function(t){return t.reduce(function(t,e){return t+e.x},0)/t.length}(n),e.y=function(e){return 1+t.max(e,function(t){return t.y})}(n)):(e.x=s?u+=r(e,s):0,e.y=0,s=e)});var h=function t(e){var r=e.children;return r&&r.length?t(r[0]):e}(c),f=function t(e){var r,n=e.children;return n&&(r=n.length)?t(n[r-1]):e}(c),p=h.x-r(h,f)/2,d=f.x+r(f,h)/2;return Ca(c,i?function(t){t.x=(t.x-c.x)*n[0],t.y=(c.y-t.y)*n[1]}:function(t){t.x=(t.x-p)/(d-p)*n[0],t.y=(1-(c.y?t.y/c.y:1))*n[1]}),l}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t),a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null!=(n=t),a):i?n:null},Sa(a,e)},t.layout.treemap=function(){var e,r=t.layout.hierarchy(),n=Math.round,i=[1,1],a=null,o=so,s=!1,l=\"squarify\",c=.5*(1+Math.sqrt(5));function u(t,e){for(var r,n,i=-1,a=t.length;++i<a;)n=(r=t[i]).value*(e<0?0:e),r.area=isNaN(n)||n<=0?0:n}function h(t){var e=t.children;if(e&&e.length){var r,n,i,a=o(t),s=[],c=e.slice(),f=1/0,g=\"slice\"===l?a.dx:\"dice\"===l?a.dy:\"slice-dice\"===l?1&t.depth?a.dy:a.dx:Math.min(a.dx,a.dy);for(u(c,a.dx*a.dy/t.value),s.area=0;(i=c.length)>0;)s.push(r=c[i-1]),s.area+=r.area,\"squarify\"!==l||(n=p(s,g))<=f?(c.pop(),f=n):(s.area-=s.pop().area,d(s,g,a,!1),g=Math.min(a.dx,a.dy),s.length=s.area=0,f=1/0);s.length&&(d(s,g,a,!0),s.length=s.area=0),e.forEach(h)}}function f(t){var e=t.children;if(e&&e.length){var r,n=o(t),i=e.slice(),a=[];for(u(i,n.dx*n.dy/t.value),a.area=0;r=i.pop();)a.push(r),a.area+=r.area,null!=r.z&&(d(a,r.z?n.dx:n.dy,n,!i.length),a.length=a.area=0);e.forEach(f)}}function p(t,e){for(var r,n=t.area,i=0,a=1/0,o=-1,s=t.length;++o<s;)(r=t[o].area)&&(r<a&&(a=r),r>i&&(i=r));return e*=e,(n*=n)?Math.max(e*i*c/n,n/(e*a*c)):1/0}function d(t,e,r,i){var a,o=-1,s=t.length,l=r.x,c=r.y,u=e?n(t.area/e):0;if(e==r.dx){for((i||u>r.dy)&&(u=r.dy);++o<s;)(a=t[o]).x=l,a.y=c,a.dy=u,l+=a.dx=Math.min(r.x+r.dx-l,u?n(a.area/u):0);a.z=!0,a.dx+=r.x+r.dx-l,r.y+=u,r.dy-=u}else{for((i||u>r.dx)&&(u=r.dx);++o<s;)(a=t[o]).x=l,a.y=c,a.dx=u,c+=a.dy=Math.min(r.y+r.dy-c,u?n(a.area/u):0);a.z=!1,a.dy+=r.y+r.dy-c,r.x+=u,r.dx-=u}}function g(t){var n=e||r(t),a=n[0];return a.x=a.y=0,a.value?(a.dx=i[0],a.dy=i[1]):a.dx=a.dy=0,e&&r.revalue(a),u([a],a.dx*a.dy/a.value),(e?f:h)(a),s&&(e=n),n}return g.size=function(t){return arguments.length?(i=t,g):i},g.padding=function(t){if(!arguments.length)return a;function e(e){return lo(e,t)}var r;return o=null==(a=t)?so:\"function\"==(r=typeof t)?function(e){var r=t.call(g,e,e.depth);return null==r?so(e):lo(e,\"number\"==typeof r?[r,r,r,r]:r)}:\"number\"===r?(t=[t,t,t,t],e):e,g},g.round=function(t){return arguments.length?(n=t?Math.round:Number,g):n!=Number},g.sticky=function(t){return arguments.length?(s=t,e=null,g):s},g.ratio=function(t){return arguments.length?(c=t,g):c},g.mode=function(t){return arguments.length?(l=t+\"\",g):l},Sa(g,r)},t.random={normal:function(t,e){var r=arguments.length;return r<2&&(e=1),r<1&&(t=0),function(){var r,n,i;do{i=(r=2*Math.random()-1)*r+(n=2*Math.random()-1)*n}while(!i||i>1);return t+e*r*Math.sqrt(-2*Math.log(i)/i)}},logNormal:function(){var e=t.random.normal.apply(t,arguments);return function(){return Math.exp(e())}},bates:function(e){var r=t.random.irwinHall(e);return function(){return r()/e}},irwinHall:function(t){return function(){for(var e=0,r=0;r<t;r++)e+=Math.random();return e}}},t.scale={};var go={floor:P,ceil:P};function vo(e,r,n,i){var a=[],o=[],s=0,l=Math.min(e.length,r.length)-1;for(e[l]<e[0]&&(e=e.slice().reverse(),r=r.slice().reverse());++s<=l;)a.push(n(e[s-1],e[s])),o.push(i(r[s-1],r[s]));return function(r){var n=t.bisect(e,r,1,l)-1;return o[n](a[n](r))}}function mo(e,r){return t.rebind(e,r,\"range\",\"rangeRound\",\"interpolate\",\"clamp\")}function yo(t,e){return fo(t,po(xo(t,e)[2])),fo(t,po(xo(t,e)[2])),t}function xo(t,e){null==e&&(e=10);var r=co(t),n=r[1]-r[0],i=Math.pow(10,Math.floor(Math.log(n/e)/Math.LN10)),a=e/n*i;return a<=.15?i*=10:a<=.35?i*=5:a<=.75&&(i*=2),r[0]=Math.ceil(r[0]/i)*i,r[1]=Math.floor(r[1]/i)*i+.5*i,r[2]=i,r}function bo(e,r){return t.range.apply(t,xo(e,r))}function _o(e,r,n){var i=xo(e,r);if(n){var a=Le.exec(n);if(a.shift(),\"s\"===a[8]){var o=t.formatPrefix(Math.max(y(i[0]),y(i[1])));return a[7]||(a[7]=\".\"+ko(o.scale(i[2]))),a[8]=\"f\",n=t.format(a.join(\"\")),function(t){return n(o.scale(t))+o.symbol}}a[7]||(a[7]=\".\"+function(t,e){var r=ko(e[2]);return t in wo?Math.abs(r-ko(Math.max(y(e[0]),y(e[1]))))+ +(\"e\"!==t):r-2*(\"%\"===t)}(a[8],i)),n=a.join(\"\")}else n=\",.\"+ko(i[2])+\"f\";return t.format(n)}t.scale.linear=function(){return function t(e,r,n,i){var a,o;function s(){var t=Math.min(e.length,r.length)>2?vo:ho,s=i?ma:va;return a=t(e,r,s,n),o=t(r,e,s,Zi),l}function l(t){return a(t)}l.invert=function(t){return o(t)};l.domain=function(t){return arguments.length?(e=t.map(Number),s()):e};l.range=function(t){return arguments.length?(r=t,s()):r};l.rangeRound=function(t){return l.range(t).interpolate(ca)};l.clamp=function(t){return arguments.length?(i=t,s()):i};l.interpolate=function(t){return arguments.length?(n=t,s()):n};l.ticks=function(t){return bo(e,t)};l.tickFormat=function(t,r){return _o(e,t,r)};l.nice=function(t){return yo(e,t),s()};l.copy=function(){return t(e,r,n,i)};return s()}([0,1],[0,1],Zi,!1)};var wo={s:1,g:1,p:1,r:1,e:1};function ko(t){return-Math.floor(Math.log(t)/Math.LN10+.01)}t.scale.log=function(){return function e(r,n,i,a){function o(t){return(i?Math.log(t<0?0:t):-Math.log(t>0?0:-t))/Math.log(n)}function s(t){return i?Math.pow(n,t):-Math.pow(n,-t)}function l(t){return r(o(t))}l.invert=function(t){return s(r.invert(t))};l.domain=function(t){return arguments.length?(i=t[0]>=0,r.domain((a=t.map(Number)).map(o)),l):a};l.base=function(t){return arguments.length?(n=+t,r.domain(a.map(o)),l):n};l.nice=function(){var t=fo(a.map(o),i?Math:Ao);return r.domain(t),a=t.map(s),l};l.ticks=function(){var t=co(a),e=[],r=t[0],l=t[1],c=Math.floor(o(r)),u=Math.ceil(o(l)),h=n%1?2:n;if(isFinite(u-c)){if(i){for(;c<u;c++)for(var f=1;f<h;f++)e.push(s(c)*f);e.push(s(c))}else for(e.push(s(c));c++<u;)for(var f=h-1;f>0;f--)e.push(s(c)*f);for(c=0;e[c]<r;c++);for(u=e.length;e[u-1]>l;u--);e=e.slice(c,u)}return e};l.tickFormat=function(e,r){if(!arguments.length)return To;arguments.length<2?r=To:\"function\"!=typeof r&&(r=t.format(r));var i=Math.max(1,n*e/l.ticks().length);return function(t){var e=t/s(Math.round(o(t)));return e*n<n-.5&&(e*=n),e<=i?r(t):\"\"}};l.copy=function(){return e(r.copy(),n,i,a)};return mo(l,r)}(t.scale.linear().domain([0,1]),10,!0,[1,10])};var To=t.format(\".0e\"),Ao={floor:function(t){return-Math.ceil(-t)},ceil:function(t){return-Math.floor(-t)}};function Mo(t){return function(e){return e<0?-Math.pow(-e,t):Math.pow(e,t)}}t.scale.pow=function(){return function t(e,r,n){var i=Mo(r),a=Mo(1/r);function o(t){return e(i(t))}o.invert=function(t){return a(e.invert(t))};o.domain=function(t){return arguments.length?(e.domain((n=t.map(Number)).map(i)),o):n};o.ticks=function(t){return bo(n,t)};o.tickFormat=function(t,e){return _o(n,t,e)};o.nice=function(t){return o.domain(yo(n,t))};o.exponent=function(t){return arguments.length?(i=Mo(r=t),a=Mo(1/r),e.domain(n.map(i)),o):r};o.copy=function(){return t(e.copy(),r,n)};return mo(o,e)}(t.scale.linear(),1,[0,1])},t.scale.sqrt=function(){return t.scale.pow().exponent(.5)},t.scale.ordinal=function(){return function e(r,n){var i,a,o;function s(t){return a[((i.get(t)||(\"range\"===n.t?i.set(t,r.push(t)):NaN))-1)%a.length]}function l(e,n){return t.range(r.length).map(function(t){return e+n*t})}s.domain=function(t){if(!arguments.length)return r;r=[],i=new b;for(var e,a=-1,o=t.length;++a<o;)i.has(e=t[a])||i.set(e,r.push(e));return s[n.t].apply(s,n.a)};s.range=function(t){return arguments.length?(a=t,o=0,n={t:\"range\",a:arguments},s):a};s.rangePoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=(i+c)/2,0):(c-i)/(r.length-1+e);return a=l(i+u*e/2,u),o=0,n={t:\"rangePoints\",a:arguments},s};s.rangeRoundPoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=c=Math.round((i+c)/2),0):(c-i)/(r.length-1+e)|0;return a=l(i+Math.round(u*e/2+(c-i-(r.length-1+e)*u)/2),u),o=0,n={t:\"rangeRoundPoints\",a:arguments},s};s.rangeBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],h=t[1-c],f=(h-u)/(r.length-e+2*i);return a=l(u+f*i,f),c&&a.reverse(),o=f*(1-e),n={t:\"rangeBands\",a:arguments},s};s.rangeRoundBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],h=t[1-c],f=Math.floor((h-u)/(r.length-e+2*i));return a=l(u+Math.round((h-u-(r.length-e)*f)/2),f),c&&a.reverse(),o=Math.round(f*(1-e)),n={t:\"rangeRoundBands\",a:arguments},s};s.rangeBand=function(){return o};s.rangeExtent=function(){return co(n.a[0])};s.copy=function(){return e(r,n)};return s.domain(r)}([],{t:\"range\",a:[[]]})},t.scale.category10=function(){return t.scale.ordinal().range(So)},t.scale.category20=function(){return t.scale.ordinal().range(Eo)},t.scale.category20b=function(){return t.scale.ordinal().range(Co)},t.scale.category20c=function(){return t.scale.ordinal().range(Lo)};var So=[2062260,16744206,2924588,14034728,9725885,9197131,14907330,8355711,12369186,1556175].map(se),Eo=[2062260,11454440,16744206,16759672,2924588,10018698,14034728,16750742,9725885,12955861,9197131,12885140,14907330,16234194,8355711,13092807,12369186,14408589,1556175,10410725].map(se),Co=[3750777,5395619,7040719,10264286,6519097,9216594,11915115,13556636,9202993,12426809,15186514,15190932,8666169,11356490,14049643,15177372,8077683,10834324,13528509,14589654].map(se),Lo=[3244733,7057110,10406625,13032431,15095053,16616764,16625259,16634018,3253076,7652470,10607003,13101504,7695281,10394312,12369372,14342891,6513507,9868950,12434877,14277081].map(se);function Po(){return 0}t.scale.quantile=function(){return function e(r,n){var i;function a(){var e=0,a=n.length;for(i=[];++e<a;)i[e-1]=t.quantile(r,e/a);return o}function o(e){if(!isNaN(e=+e))return n[t.bisect(i,e)]}o.domain=function(t){return arguments.length?(r=t.map(p).filter(d).sort(f),a()):r};o.range=function(t){return arguments.length?(n=t,a()):n};o.quantiles=function(){return i};o.invertExtent=function(t){return(t=n.indexOf(t))<0?[NaN,NaN]:[t>0?i[t-1]:r[0],t<i.length?i[t]:r[r.length-1]]};o.copy=function(){return e(r,n)};return a()}([],[])},t.scale.quantize=function(){return function t(e,r,n){var i,a;function o(t){return n[Math.max(0,Math.min(a,Math.floor(i*(t-e))))]}function s(){return i=n.length/(r-e),a=n.length-1,o}o.domain=function(t){return arguments.length?(e=+t[0],r=+t[t.length-1],s()):[e,r]};o.range=function(t){return arguments.length?(n=t,s()):n};o.invertExtent=function(t){return[t=(t=n.indexOf(t))<0?NaN:t/i+e,t+1/i]};o.copy=function(){return t(e,r,n)};return s()}(0,1,[0,1])},t.scale.threshold=function(){return function e(r,n){function i(e){if(e<=e)return n[t.bisect(r,e)]}i.domain=function(t){return arguments.length?(r=t,i):r};i.range=function(t){return arguments.length?(n=t,i):n};i.invertExtent=function(t){return t=n.indexOf(t),[r[t-1],r[t]]};i.copy=function(){return e(r,n)};return i}([.5],[0,1])},t.scale.identity=function(){return function t(e){function r(t){return+t}r.invert=r;r.domain=r.range=function(t){return arguments.length?(e=t.map(r),r):e};r.ticks=function(t){return bo(e,t)};r.tickFormat=function(t,r){return _o(e,t,r)};r.copy=function(){return t(e)};return r}([0,1])},t.svg={},t.svg.arc=function(){var t=zo,e=Io,r=Po,n=Oo,i=Do,a=Ro,o=Fo;function s(){var s=Math.max(0,+t.apply(this,arguments)),c=Math.max(0,+e.apply(this,arguments)),u=i.apply(this,arguments)-Et,h=a.apply(this,arguments)-Et,f=Math.abs(h-u),p=u>h?0:1;if(c<s&&(d=c,c=s,s=d),f>=St)return l(c,p)+(s?l(s,1-p):\"\")+\"Z\";var d,g,v,m,y,x,b,_,w,k,T,A,M=0,S=0,E=[];if((m=(+o.apply(this,arguments)||0)/2)&&(v=n===Oo?Math.sqrt(s*s+c*c):+n.apply(this,arguments),p||(S*=-1),c&&(S=It(v/c*Math.sin(m))),s&&(M=It(v/s*Math.sin(m)))),c){y=c*Math.cos(u+S),x=c*Math.sin(u+S),b=c*Math.cos(h-S),_=c*Math.sin(h-S);var C=Math.abs(h-u-2*S)<=At?0:1;if(S&&Bo(y,x,b,_)===p^C){var L=(u+h)/2;y=c*Math.cos(L),x=c*Math.sin(L),b=_=null}}else y=x=0;if(s){w=s*Math.cos(h-M),k=s*Math.sin(h-M),T=s*Math.cos(u+M),A=s*Math.sin(u+M);var P=Math.abs(u-h+2*M)<=At?0:1;if(M&&Bo(w,k,T,A)===1-p^P){var O=(u+h)/2;w=s*Math.cos(O),k=s*Math.sin(O),T=A=null}}else w=k=0;if(f>kt&&(d=Math.min(Math.abs(c-s)/2,+r.apply(this,arguments)))>.001){g=s<c^p?0:1;var z=d,I=d;if(f<At){var D=null==T?[w,k]:null==b?[y,x]:si([y,x],[T,A],[b,_],[w,k]),R=y-D[0],F=x-D[1],B=b-D[0],N=_-D[1],j=1/Math.sin(Math.acos((R*B+F*N)/(Math.sqrt(R*R+F*F)*Math.sqrt(B*B+N*N)))/2),U=Math.sqrt(D[0]*D[0]+D[1]*D[1]);I=Math.min(d,(s-U)/(j-1)),z=Math.min(d,(c-U)/(j+1))}if(null!=b){var V=No(null==T?[w,k]:[T,A],[y,x],c,z,p),q=No([b,_],[w,k],c,z,p);d===z?E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 0,\",g,\" \",V[1],\"A\",c,\",\",c,\" 0 \",1-p^Bo(V[1][0],V[1][1],q[1][0],q[1][1]),\",\",p,\" \",q[1],\"A\",z,\",\",z,\" 0 0,\",g,\" \",q[0]):E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 1,\",g,\" \",q[0])}else E.push(\"M\",y,\",\",x);if(null!=T){var H=No([y,x],[T,A],s,-I,p),G=No([w,k],null==b?[y,x]:[b,_],s,-I,p);d===I?E.push(\"L\",G[0],\"A\",I,\",\",I,\" 0 0,\",g,\" \",G[1],\"A\",s,\",\",s,\" 0 \",p^Bo(G[1][0],G[1][1],H[1][0],H[1][1]),\",\",1-p,\" \",H[1],\"A\",I,\",\",I,\" 0 0,\",g,\" \",H[0]):E.push(\"L\",G[0],\"A\",I,\",\",I,\" 0 0,\",g,\" \",H[0])}else E.push(\"L\",w,\",\",k)}else E.push(\"M\",y,\",\",x),null!=b&&E.push(\"A\",c,\",\",c,\" 0 \",C,\",\",p,\" \",b,\",\",_),E.push(\"L\",w,\",\",k),null!=T&&E.push(\"A\",s,\",\",s,\" 0 \",P,\",\",1-p,\" \",T,\",\",A);return E.push(\"Z\"),E.join(\"\")}function l(t,e){return\"M0,\"+t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+-t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+t}return s.innerRadius=function(e){return arguments.length?(t=ve(e),s):t},s.outerRadius=function(t){return arguments.length?(e=ve(t),s):e},s.cornerRadius=function(t){return arguments.length?(r=ve(t),s):r},s.padRadius=function(t){return arguments.length?(n=t==Oo?Oo:ve(t),s):n},s.startAngle=function(t){return arguments.length?(i=ve(t),s):i},s.endAngle=function(t){return arguments.length?(a=ve(t),s):a},s.padAngle=function(t){return arguments.length?(o=ve(t),s):o},s.centroid=function(){var r=(+t.apply(this,arguments)+ +e.apply(this,arguments))/2,n=(+i.apply(this,arguments)+ +a.apply(this,arguments))/2-Et;return[Math.cos(n)*r,Math.sin(n)*r]},s};var Oo=\"auto\";function zo(t){return t.innerRadius}function Io(t){return t.outerRadius}function Do(t){return t.startAngle}function Ro(t){return t.endAngle}function Fo(t){return t&&t.padAngle}function Bo(t,e,r,n){return(t-r)*e-(e-n)*t>0?0:1}function No(t,e,r,n,i){var a=t[0]-e[0],o=t[1]-e[1],s=(i?n:-n)/Math.sqrt(a*a+o*o),l=s*o,c=-s*a,u=t[0]+l,h=t[1]+c,f=e[0]+l,p=e[1]+c,d=(u+f)/2,g=(h+p)/2,v=f-u,m=p-h,y=v*v+m*m,x=r-n,b=u*p-f*h,_=(m<0?-1:1)*Math.sqrt(Math.max(0,x*x*y-b*b)),w=(b*m-v*_)/y,k=(-b*v-m*_)/y,T=(b*m+v*_)/y,A=(-b*v+m*_)/y,M=w-d,S=k-g,E=T-d,C=A-g;return M*M+S*S>E*E+C*C&&(w=T,k=A),[[w-l,k-c],[w*r/x,k*r/x]]}function jo(t){var e=ei,r=ri,n=Yr,i=Vo,a=i.key,o=.7;function s(a){var s,l=[],c=[],u=-1,h=a.length,f=ve(e),p=ve(r);function d(){l.push(\"M\",i(t(c),o))}for(;++u<h;)n.call(this,s=a[u],u)?c.push([+f.call(this,s,u),+p.call(this,s,u)]):c.length&&(d(),c=[]);return c.length&&d(),l.length?l.join(\"\"):null}return s.x=function(t){return arguments.length?(e=t,s):e},s.y=function(t){return arguments.length?(r=t,s):r},s.defined=function(t){return arguments.length?(n=t,s):n},s.interpolate=function(t){return arguments.length?(a=\"function\"==typeof t?i=t:(i=Uo.get(t)||Vo).key,s):a},s.tension=function(t){return arguments.length?(o=t,s):o},s}t.svg.line=function(){return jo(P)};var Uo=t.map({linear:Vo,\"linear-closed\":qo,step:function(t){var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];for(;++e<r;)i.push(\"H\",(n[0]+(n=t[e])[0])/2,\"V\",n[1]);r>1&&i.push(\"H\",n[0]);return i.join(\"\")},\"step-before\":Ho,\"step-after\":Go,basis:Xo,\"basis-open\":function(t){if(t.length<4)return Vo(t);var e,r=[],n=-1,i=t.length,a=[0],o=[0];for(;++n<3;)e=t[n],a.push(e[0]),o.push(e[1]);r.push(Zo($o,a)+\",\"+Zo($o,o)),--n;for(;++n<i;)e=t[n],a.shift(),a.push(e[0]),o.shift(),o.push(e[1]),Qo(r,a,o);return r.join(\"\")},\"basis-closed\":function(t){var e,r,n=-1,i=t.length,a=i+4,o=[],s=[];for(;++n<4;)r=t[n%i],o.push(r[0]),s.push(r[1]);e=[Zo($o,o),\",\",Zo($o,s)],--n;for(;++n<a;)r=t[n%i],o.shift(),o.push(r[0]),s.shift(),s.push(r[1]),Qo(e,o,s);return e.join(\"\")},bundle:function(t,e){var r=t.length-1;if(r)for(var n,i,a=t[0][0],o=t[0][1],s=t[r][0]-a,l=t[r][1]-o,c=-1;++c<=r;)n=t[c],i=c/r,n[0]=e*n[0]+(1-e)*(a+i*s),n[1]=e*n[1]+(1-e)*(o+i*l);return Xo(t)},cardinal:function(t,e){return t.length<3?Vo(t):t[0]+Yo(t,Wo(t,e))},\"cardinal-open\":function(t,e){return t.length<4?Vo(t):t[1]+Yo(t.slice(1,-1),Wo(t,e))},\"cardinal-closed\":function(t,e){return t.length<3?qo(t):t[0]+Yo((t.push(t[0]),t),Wo([t[t.length-2]].concat(t,[t[1]]),e))},monotone:function(t){return t.length<3?Vo(t):t[0]+Yo(t,function(t){var e,r,n,i,a=[],o=function(t){var e=0,r=t.length-1,n=[],i=t[0],a=t[1],o=n[0]=ts(i,a);for(;++e<r;)n[e]=(o+(o=ts(i=a,a=t[e+1])))/2;return n[e]=o,n}(t),s=-1,l=t.length-1;for(;++s<l;)e=ts(t[s],t[s+1]),y(e)<kt?o[s]=o[s+1]=0:(r=o[s]/e,n=o[s+1]/e,(i=r*r+n*n)>9&&(i=3*e/Math.sqrt(i),o[s]=i*r,o[s+1]=i*n));s=-1;for(;++s<=l;)i=(t[Math.min(l,s+1)][0]-t[Math.max(0,s-1)][0])/(6*(1+o[s]*o[s])),a.push([i||0,o[s]*i||0]);return a}(t))}});function Vo(t){return t.length>1?t.join(\"L\"):t+\"Z\"}function qo(t){return t.join(\"L\")+\"Z\"}function Ho(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"V\",(n=t[e])[1],\"H\",n[0]);return i.join(\"\")}function Go(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"H\",(n=t[e])[0],\"V\",n[1]);return i.join(\"\")}function Yo(t,e){if(e.length<1||t.length!=e.length&&t.length!=e.length+2)return Vo(t);var r=t.length!=e.length,n=\"\",i=t[0],a=t[1],o=e[0],s=o,l=1;if(r&&(n+=\"Q\"+(a[0]-2*o[0]/3)+\",\"+(a[1]-2*o[1]/3)+\",\"+a[0]+\",\"+a[1],i=t[1],l=2),e.length>1){s=e[1],a=t[l],l++,n+=\"C\"+(i[0]+o[0])+\",\"+(i[1]+o[1])+\",\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1];for(var c=2;c<e.length;c++,l++)a=t[l],s=e[c],n+=\"S\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1]}if(r){var u=t[l];n+=\"Q\"+(a[0]+2*s[0]/3)+\",\"+(a[1]+2*s[1]/3)+\",\"+u[0]+\",\"+u[1]}return n}function Wo(t,e){for(var r,n=[],i=(1-e)/2,a=t[0],o=t[1],s=1,l=t.length;++s<l;)r=a,a=o,o=t[s],n.push([i*(o[0]-r[0]),i*(o[1]-r[1])]);return n}function Xo(t){if(t.length<3)return Vo(t);var e=1,r=t.length,n=t[0],i=n[0],a=n[1],o=[i,i,i,(n=t[1])[0]],s=[a,a,a,n[1]],l=[i,\",\",a,\"L\",Zo($o,o),\",\",Zo($o,s)];for(t.push(t[r-1]);++e<=r;)n=t[e],o.shift(),o.push(n[0]),s.shift(),s.push(n[1]),Qo(l,o,s);return t.pop(),l.push(\"L\",n),l.join(\"\")}function Zo(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}Uo.forEach(function(t,e){e.key=t,e.closed=/-closed$/.test(t)});var Jo=[0,2/3,1/3,0],Ko=[0,1/3,2/3,0],$o=[0,1/6,2/3,1/6];function Qo(t,e,r){t.push(\"C\",Zo(Jo,e),\",\",Zo(Jo,r),\",\",Zo(Ko,e),\",\",Zo(Ko,r),\",\",Zo($o,e),\",\",Zo($o,r))}function ts(t,e){return(e[1]-t[1])/(e[0]-t[0])}function es(t){for(var e,r,n,i=-1,a=t.length;++i<a;)r=(e=t[i])[0],n=e[1]-Et,e[0]=r*Math.cos(n),e[1]=r*Math.sin(n);return t}function rs(t){var e=ei,r=ei,n=0,i=ri,a=Yr,o=Vo,s=o.key,l=o,c=\"L\",u=.7;function h(s){var h,f,p,d=[],g=[],v=[],m=-1,y=s.length,x=ve(e),b=ve(n),_=e===r?function(){return f}:ve(r),w=n===i?function(){return p}:ve(i);function k(){d.push(\"M\",o(t(v),u),c,l(t(g.reverse()),u),\"Z\")}for(;++m<y;)a.call(this,h=s[m],m)?(g.push([f=+x.call(this,h,m),p=+b.call(this,h,m)]),v.push([+_.call(this,h,m),+w.call(this,h,m)])):g.length&&(k(),g=[],v=[]);return g.length&&k(),d.length?d.join(\"\"):null}return h.x=function(t){return arguments.length?(e=r=t,h):r},h.x0=function(t){return arguments.length?(e=t,h):e},h.x1=function(t){return arguments.length?(r=t,h):r},h.y=function(t){return arguments.length?(n=i=t,h):i},h.y0=function(t){return arguments.length?(n=t,h):n},h.y1=function(t){return arguments.length?(i=t,h):i},h.defined=function(t){return arguments.length?(a=t,h):a},h.interpolate=function(t){return arguments.length?(s=\"function\"==typeof t?o=t:(o=Uo.get(t)||Vo).key,l=o.reverse||o,c=o.closed?\"M\":\"L\",h):s},h.tension=function(t){return arguments.length?(u=t,h):u},h}function ns(t){return t.radius}function is(t){return[t.x,t.y]}function as(){return 64}function os(){return\"circle\"}function ss(t){var e=Math.sqrt(t/At);return\"M0,\"+e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+-e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+e+\"Z\"}t.svg.line.radial=function(){var t=jo(es);return t.radius=t.x,delete t.x,t.angle=t.y,delete t.y,t},Ho.reverse=Go,Go.reverse=Ho,t.svg.area=function(){return rs(P)},t.svg.area.radial=function(){var t=rs(es);return t.radius=t.x,delete t.x,t.innerRadius=t.x0,delete t.x0,t.outerRadius=t.x1,delete t.x1,t.angle=t.y,delete t.y,t.startAngle=t.y0,delete t.y0,t.endAngle=t.y1,delete t.y1,t},t.svg.chord=function(){var t=Un,e=Vn,r=ns,n=Do,i=Ro;function a(r,n){var i,a,c=o(this,t,r,n),u=o(this,e,r,n);return\"M\"+c.p0+s(c.r,c.p1,c.a1-c.a0)+(a=u,(i=c).a0==a.a0&&i.a1==a.a1?l(c.r,c.p1,c.r,c.p0):l(c.r,c.p1,u.r,u.p0)+s(u.r,u.p1,u.a1-u.a0)+l(u.r,u.p1,c.r,c.p0))+\"Z\"}function o(t,e,a,o){var s=e.call(t,a,o),l=r.call(t,s,o),c=n.call(t,s,o)-Et,u=i.call(t,s,o)-Et;return{r:l,a0:c,a1:u,p0:[l*Math.cos(c),l*Math.sin(c)],p1:[l*Math.cos(u),l*Math.sin(u)]}}function s(t,e,r){return\"A\"+t+\",\"+t+\" 0 \"+ +(r>At)+\",1 \"+e}function l(t,e,r,n){return\"Q 0,0 \"+n}return a.radius=function(t){return arguments.length?(r=ve(t),a):r},a.source=function(e){return arguments.length?(t=ve(e),a):t},a.target=function(t){return arguments.length?(e=ve(t),a):e},a.startAngle=function(t){return arguments.length?(n=ve(t),a):n},a.endAngle=function(t){return arguments.length?(i=ve(t),a):i},a},t.svg.diagonal=function(){var t=Un,e=Vn,r=is;function n(n,i){var a=t.call(this,n,i),o=e.call(this,n,i),s=(a.y+o.y)/2,l=[a,{x:a.x,y:s},{x:o.x,y:s},o];return\"M\"+(l=l.map(r))[0]+\"C\"+l[1]+\" \"+l[2]+\" \"+l[3]}return n.source=function(e){return arguments.length?(t=ve(e),n):t},n.target=function(t){return arguments.length?(e=ve(t),n):e},n.projection=function(t){return arguments.length?(r=t,n):r},n},t.svg.diagonal.radial=function(){var e=t.svg.diagonal(),r=is,n=e.projection;return e.projection=function(t){return arguments.length?n(function(t){return function(){var e=t.apply(this,arguments),r=e[0],n=e[1]-Et;return[r*Math.cos(n),r*Math.sin(n)]}}(r=t)):r},e},t.svg.symbol=function(){var t=os,e=as;function r(r,n){return(ls.get(t.call(this,r,n))||ss)(e.call(this,r,n))}return r.type=function(e){return arguments.length?(t=ve(e),r):t},r.size=function(t){return arguments.length?(e=ve(t),r):e},r};var ls=t.map({circle:ss,cross:function(t){var e=Math.sqrt(t/5)/2;return\"M\"+-3*e+\",\"+-e+\"H\"+-e+\"V\"+-3*e+\"H\"+e+\"V\"+-e+\"H\"+3*e+\"V\"+e+\"H\"+e+\"V\"+3*e+\"H\"+-e+\"V\"+e+\"H\"+-3*e+\"Z\"},diamond:function(t){var e=Math.sqrt(t/(2*us)),r=e*us;return\"M0,\"+-e+\"L\"+r+\",0 0,\"+e+\" \"+-r+\",0Z\"},square:function(t){var e=Math.sqrt(t)/2;return\"M\"+-e+\",\"+-e+\"L\"+e+\",\"+-e+\" \"+e+\",\"+e+\" \"+-e+\",\"+e+\"Z\"},\"triangle-down\":function(t){var e=Math.sqrt(t/cs),r=e*cs/2;return\"M0,\"+r+\"L\"+e+\",\"+-r+\" \"+-e+\",\"+-r+\"Z\"},\"triangle-up\":function(t){var e=Math.sqrt(t/cs),r=e*cs/2;return\"M0,\"+-r+\"L\"+e+\",\"+r+\" \"+-e+\",\"+r+\"Z\"}});t.svg.symbolTypes=ls.keys();var cs=Math.sqrt(3),us=Math.tan(30*Ct);W.transition=function(t){for(var e,r,n=ds||++ms,i=bs(t),a=[],o=gs||{time:Date.now(),ease:ia,delay:0,duration:250},s=-1,l=this.length;++s<l;){a.push(e=[]);for(var c=this[s],u=-1,h=c.length;++u<h;)(r=c[u])&&_s(r,u,i,n,o),e.push(r)}return ps(a,i,n)},W.interrupt=function(t){return this.each(null==t?hs:fs(bs(t)))};var hs=fs(bs());function fs(t){return function(){var e,r,n;(e=this[t])&&(n=e[r=e.active])&&(n.timer.c=null,n.timer.t=NaN,--e.count?delete e[r]:delete this[t],e.active+=.5,n.event&&n.event.interrupt.call(this,this.__data__,n.index))}}function ps(t,e,r){return V(t,vs),t.namespace=e,t.id=r,t}var ds,gs,vs=[],ms=0;function ys(t,e,r,n){var i=t.id,a=t.namespace;return ut(t,\"function\"==typeof r?function(t,o,s){t[a][i].tween.set(e,n(r.call(t,t.__data__,o,s)))}:(r=n(r),function(t){t[a][i].tween.set(e,r)}))}function xs(t){return null==t&&(t=\"\"),function(){this.textContent=t}}function bs(t){return null==t?\"__transition__\":\"__transition_\"+t+\"__\"}function _s(t,e,r,n,i){var a,o,s,l,c,u=t[r]||(t[r]={active:0,count:0}),h=u[n];function f(r){var i=u.active,f=u[i];for(var d in f&&(f.timer.c=null,f.timer.t=NaN,--u.count,delete u[i],f.event&&f.event.interrupt.call(t,t.__data__,f.index)),u)if(+d<n){var g=u[d];g.timer.c=null,g.timer.t=NaN,--u.count,delete u[d]}o.c=p,Te(function(){return o.c&&p(r||1)&&(o.c=null,o.t=NaN),1},0,a),u.active=n,h.event&&h.event.start.call(t,t.__data__,e),c=[],h.tween.forEach(function(r,n){(n=n.call(t,t.__data__,e))&&c.push(n)}),l=h.ease,s=h.duration}function p(i){for(var a=i/s,o=l(a),f=c.length;f>0;)c[--f].call(t,o);if(a>=1)return h.event&&h.event.end.call(t,t.__data__,e),--u.count?delete u[n]:delete t[r],1}h||(a=i.time,o=Te(function(t){var e=h.delay;if(o.t=e+a,e<=t)return f(t-e);o.c=f},0,a),h=u[n]={tween:new b,time:a,timer:o,delay:i.delay,duration:i.duration,ease:i.ease,index:e},i=null,++u.count)}vs.call=W.call,vs.empty=W.empty,vs.node=W.node,vs.size=W.size,t.transition=function(e,r){return e&&e.transition?ds?e.transition(r):e:t.selection().transition(e)},t.transition.prototype=vs,vs.select=function(t){var e,r,n,i=this.id,a=this.namespace,o=[];t=X(t);for(var s=-1,l=this.length;++s<l;){o.push(e=[]);for(var c=this[s],u=-1,h=c.length;++u<h;)(n=c[u])&&(r=t.call(n,n.__data__,u,s))?(\"__data__\"in n&&(r.__data__=n.__data__),_s(r,u,a,i,n[a][i]),e.push(r)):e.push(null)}return ps(o,a,i)},vs.selectAll=function(t){var e,r,n,i,a,o=this.id,s=this.namespace,l=[];t=Z(t);for(var c=-1,u=this.length;++c<u;)for(var h=this[c],f=-1,p=h.length;++f<p;)if(n=h[f]){a=n[s][o],r=t.call(n,n.__data__,f,c),l.push(e=[]);for(var d=-1,g=r.length;++d<g;)(i=r[d])&&_s(i,d,s,o,a),e.push(i)}return ps(l,s,o)},vs.filter=function(t){var e,r,n=[];\"function\"!=typeof t&&(t=ct(t));for(var i=0,a=this.length;i<a;i++){n.push(e=[]);for(var o,s=0,l=(o=this[i]).length;s<l;s++)(r=o[s])&&t.call(r,r.__data__,s,i)&&e.push(r)}return ps(n,this.namespace,this.id)},vs.tween=function(t,e){var r=this.id,n=this.namespace;return arguments.length<2?this.node()[n][r].tween.get(t):ut(this,null==e?function(e){e[n][r].tween.remove(t)}:function(i){i[n][r].tween.set(t,e)})},vs.attr=function(e,r){if(arguments.length<2){for(r in e)this.attr(r,e[r]);return this}var n=\"transform\"==e?ga:Zi,i=t.ns.qualify(e);function a(){this.removeAttribute(i)}function o(){this.removeAttributeNS(i.space,i.local)}return ys(this,\"attr.\"+e,r,i.local?function(t){return null==t?o:(t+=\"\",function(){var e,r=this.getAttributeNS(i.space,i.local);return r!==t&&(e=n(r,t),function(t){this.setAttributeNS(i.space,i.local,e(t))})})}:function(t){return null==t?a:(t+=\"\",function(){var e,r=this.getAttribute(i);return r!==t&&(e=n(r,t),function(t){this.setAttribute(i,e(t))})})})},vs.attrTween=function(e,r){var n=t.ns.qualify(e);return this.tween(\"attr.\"+e,n.local?function(t,e){var i=r.call(this,t,e,this.getAttributeNS(n.space,n.local));return i&&function(t){this.setAttributeNS(n.space,n.local,i(t))}}:function(t,e){var i=r.call(this,t,e,this.getAttribute(n));return i&&function(t){this.setAttribute(n,i(t))}})},vs.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.style(r,t[r],e);return this}r=\"\"}function i(){this.style.removeProperty(t)}return ys(this,\"style.\"+t,e,function(e){return null==e?i:(e+=\"\",function(){var n,i=o(this).getComputedStyle(this,null).getPropertyValue(t);return i!==e&&(n=Zi(i,e),function(e){this.style.setProperty(t,n(e),r)})})})},vs.styleTween=function(t,e,r){return arguments.length<3&&(r=\"\"),this.tween(\"style.\"+t,function(n,i){var a=e.call(this,n,i,o(this).getComputedStyle(this,null).getPropertyValue(t));return a&&function(e){this.style.setProperty(t,a(e),r)}})},vs.text=function(t){return ys(this,\"text\",t,xs)},vs.remove=function(){var t=this.namespace;return this.each(\"end.transition\",function(){var e;this[t].count<2&&(e=this.parentNode)&&e.removeChild(this)})},vs.ease=function(e){var r=this.id,n=this.namespace;return arguments.length<1?this.node()[n][r].ease:(\"function\"!=typeof e&&(e=t.ease.apply(t,arguments)),ut(this,function(t){t[n][r].ease=e}))},vs.delay=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].delay:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].delay=+t.call(n,n.__data__,i,a)}:(t=+t,function(n){n[r][e].delay=t}))},vs.duration=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].duration:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].duration=Math.max(1,t.call(n,n.__data__,i,a))}:(t=Math.max(1,t),function(n){n[r][e].duration=t}))},vs.each=function(e,r){var n=this.id,i=this.namespace;if(arguments.length<2){var a=gs,o=ds;try{ds=n,ut(this,function(t,r,a){gs=t[i][n],e.call(t,t.__data__,r,a)})}finally{gs=a,ds=o}}else ut(this,function(a){var o=a[i][n];(o.event||(o.event=t.dispatch(\"start\",\"end\",\"interrupt\"))).on(e,r)});return this},vs.transition=function(){for(var t,e,r,n=this.id,i=++ms,a=this.namespace,o=[],s=0,l=this.length;s<l;s++){o.push(t=[]);for(var c,u=0,h=(c=this[s]).length;u<h;u++)(e=c[u])&&_s(e,u,a,i,{time:(r=e[a][n]).time,ease:r.ease,delay:r.delay+r.duration,duration:r.duration}),t.push(e)}return ps(o,a,i)},t.svg.axis=function(){var e,r=t.scale.linear(),i=ws,a=6,o=6,s=3,l=[10],c=null;function u(n){n.each(function(){var n,u=t.select(this),h=this.__chart__||r,f=this.__chart__=r.copy(),p=null==c?f.ticks?f.ticks.apply(f,l):f.domain():c,d=null==e?f.tickFormat?f.tickFormat.apply(f,l):P:e,g=u.selectAll(\".tick\").data(p,f),v=g.enter().insert(\"g\",\".domain\").attr(\"class\",\"tick\").style(\"opacity\",kt),m=t.transition(g.exit()).style(\"opacity\",kt).remove(),y=t.transition(g.order()).style(\"opacity\",1),x=Math.max(a,0)+s,b=uo(f),_=u.selectAll(\".domain\").data([0]),w=(_.enter().append(\"path\").attr(\"class\",\"domain\"),t.transition(_));v.append(\"line\"),v.append(\"text\");var k,T,A,M,S=v.select(\"line\"),E=y.select(\"line\"),C=g.select(\"text\").text(d),L=v.select(\"text\"),O=y.select(\"text\"),z=\"top\"===i||\"left\"===i?-1:1;if(\"bottom\"===i||\"top\"===i?(n=Ts,k=\"x\",A=\"y\",T=\"x2\",M=\"y2\",C.attr(\"dy\",z<0?\"0em\":\".71em\").style(\"text-anchor\",\"middle\"),w.attr(\"d\",\"M\"+b[0]+\",\"+z*o+\"V0H\"+b[1]+\"V\"+z*o)):(n=As,k=\"y\",A=\"x\",T=\"y2\",M=\"x2\",C.attr(\"dy\",\".32em\").style(\"text-anchor\",z<0?\"end\":\"start\"),w.attr(\"d\",\"M\"+z*o+\",\"+b[0]+\"H0V\"+b[1]+\"H\"+z*o)),S.attr(M,z*a),L.attr(A,z*x),E.attr(T,0).attr(M,z*a),O.attr(k,0).attr(A,z*x),f.rangeBand){var I=f,D=I.rangeBand()/2;h=f=function(t){return I(t)+D}}else h.rangeBand?h=f:m.call(n,f,h);v.call(n,h,f),y.call(n,f,f)})}return u.scale=function(t){return arguments.length?(r=t,u):r},u.orient=function(t){return arguments.length?(i=t in ks?t+\"\":ws,u):i},u.ticks=function(){return arguments.length?(l=n(arguments),u):l},u.tickValues=function(t){return arguments.length?(c=t,u):c},u.tickFormat=function(t){return arguments.length?(e=t,u):e},u.tickSize=function(t){var e=arguments.length;return e?(a=+t,o=+arguments[e-1],u):a},u.innerTickSize=function(t){return arguments.length?(a=+t,u):a},u.outerTickSize=function(t){return arguments.length?(o=+t,u):o},u.tickPadding=function(t){return arguments.length?(s=+t,u):s},u.tickSubdivide=function(){return arguments.length&&u},u};var ws=\"bottom\",ks={top:1,right:1,bottom:1,left:1};function Ts(t,e,r){t.attr(\"transform\",function(t){var n=e(t);return\"translate(\"+(isFinite(n)?n:r(t))+\",0)\"})}function As(t,e,r){t.attr(\"transform\",function(t){var n=e(t);return\"translate(0,\"+(isFinite(n)?n:r(t))+\")\"})}t.svg.brush=function(){var e,r,n=j(f,\"brushstart\",\"brush\",\"brushend\"),i=null,a=null,s=[0,0],l=[0,0],c=!0,u=!0,h=Ss[0];function f(e){e.each(function(){var e=t.select(this).style(\"pointer-events\",\"all\").style(\"-webkit-tap-highlight-color\",\"rgba(0,0,0,0)\").on(\"mousedown.brush\",v).on(\"touchstart.brush\",v),r=e.selectAll(\".background\").data([0]);r.enter().append(\"rect\").attr(\"class\",\"background\").style(\"visibility\",\"hidden\").style(\"cursor\",\"crosshair\"),e.selectAll(\".extent\").data([0]).enter().append(\"rect\").attr(\"class\",\"extent\").style(\"cursor\",\"move\");var n=e.selectAll(\".resize\").data(h,P);n.exit().remove(),n.enter().append(\"g\").attr(\"class\",function(t){return\"resize \"+t}).style(\"cursor\",function(t){return Ms[t]}).append(\"rect\").attr(\"x\",function(t){return/[ew]$/.test(t)?-3:null}).attr(\"y\",function(t){return/^[ns]/.test(t)?-3:null}).attr(\"width\",6).attr(\"height\",6).style(\"visibility\",\"hidden\"),n.style(\"display\",f.empty()?\"none\":null);var o,s=t.transition(e),l=t.transition(r);i&&(o=uo(i),l.attr(\"x\",o[0]).attr(\"width\",o[1]-o[0]),d(s)),a&&(o=uo(a),l.attr(\"y\",o[0]).attr(\"height\",o[1]-o[0]),g(s)),p(s)})}function p(t){t.selectAll(\".resize\").attr(\"transform\",function(t){return\"translate(\"+s[+/e$/.test(t)]+\",\"+l[+/^s/.test(t)]+\")\"})}function d(t){t.select(\".extent\").attr(\"x\",s[0]),t.selectAll(\".extent,.n>rect,.s>rect\").attr(\"width\",s[1]-s[0])}function g(t){t.select(\".extent\").attr(\"y\",l[0]),t.selectAll(\".extent,.e>rect,.w>rect\").attr(\"height\",l[1]-l[0])}function v(){var h,v,m=this,y=t.select(t.event.target),x=n.of(m,arguments),b=t.select(m),_=y.datum(),w=!/^(n|s)$/.test(_)&&i,k=!/^(e|w)$/.test(_)&&a,T=y.classed(\"extent\"),A=xt(m),M=t.mouse(m),S=t.select(o(m)).on(\"keydown.brush\",function(){32==t.event.keyCode&&(T||(h=null,M[0]-=s[1],M[1]-=l[1],T=2),B())}).on(\"keyup.brush\",function(){32==t.event.keyCode&&2==T&&(M[0]+=s[1],M[1]+=l[1],T=0,B())});if(t.event.changedTouches?S.on(\"touchmove.brush\",L).on(\"touchend.brush\",O):S.on(\"mousemove.brush\",L).on(\"mouseup.brush\",O),b.interrupt().selectAll(\"*\").interrupt(),T)M[0]=s[0]-M[0],M[1]=l[0]-M[1];else if(_){var E=+/w$/.test(_),C=+/^n/.test(_);v=[s[1-E]-M[0],l[1-C]-M[1]],M[0]=s[E],M[1]=l[C]}else t.event.altKey&&(h=M.slice());function L(){var e=t.mouse(m),r=!1;v&&(e[0]+=v[0],e[1]+=v[1]),T||(t.event.altKey?(h||(h=[(s[0]+s[1])/2,(l[0]+l[1])/2]),M[0]=s[+(e[0]<h[0])],M[1]=l[+(e[1]<h[1])]):h=null),w&&P(e,i,0)&&(d(b),r=!0),k&&P(e,a,1)&&(g(b),r=!0),r&&(p(b),x({type:\"brush\",mode:T?\"move\":\"resize\"}))}function P(t,n,i){var a,o,f=uo(n),p=f[0],d=f[1],g=M[i],v=i?l:s,m=v[1]-v[0];if(T&&(p-=g,d-=m+g),a=(i?u:c)?Math.max(p,Math.min(d,t[i])):t[i],T?o=(a+=g)+m:(h&&(g=Math.max(p,Math.min(d,2*h[i]-a))),g<a?(o=a,a=g):o=g),v[0]!=a||v[1]!=o)return i?r=null:e=null,v[0]=a,v[1]=o,!0}function O(){L(),b.style(\"pointer-events\",\"all\").selectAll(\".resize\").style(\"display\",f.empty()?\"none\":null),t.select(\"body\").style(\"cursor\",null),S.on(\"mousemove.brush\",null).on(\"mouseup.brush\",null).on(\"touchmove.brush\",null).on(\"touchend.brush\",null).on(\"keydown.brush\",null).on(\"keyup.brush\",null),A(),x({type:\"brushend\"})}b.style(\"pointer-events\",\"none\").selectAll(\".resize\").style(\"display\",null),t.select(\"body\").style(\"cursor\",y.style(\"cursor\")),x({type:\"brushstart\"}),L()}return f.event=function(i){i.each(function(){var i=n.of(this,arguments),a={x:s,y:l,i:e,j:r},o=this.__chart__||a;this.__chart__=a,ds?t.select(this).transition().each(\"start.brush\",function(){e=o.i,r=o.j,s=o.x,l=o.y,i({type:\"brushstart\"})}).tween(\"brush:brush\",function(){var t=Ji(s,a.x),n=Ji(l,a.y);return e=r=null,function(e){s=a.x=t(e),l=a.y=n(e),i({type:\"brush\",mode:\"resize\"})}}).each(\"end.brush\",function(){e=a.i,r=a.j,i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"})}):(i({type:\"brushstart\"}),i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"}))})},f.x=function(t){return arguments.length?(h=Ss[!(i=t)<<1|!a],f):i},f.y=function(t){return arguments.length?(h=Ss[!i<<1|!(a=t)],f):a},f.clamp=function(t){return arguments.length?(i&&a?(c=!!t[0],u=!!t[1]):i?c=!!t:a&&(u=!!t),f):i&&a?[c,u]:i?c:a?u:null},f.extent=function(t){var n,o,c,u,h;return arguments.length?(i&&(n=t[0],o=t[1],a&&(n=n[0],o=o[0]),e=[n,o],i.invert&&(n=i(n),o=i(o)),o<n&&(h=n,n=o,o=h),n==s[0]&&o==s[1]||(s=[n,o])),a&&(c=t[0],u=t[1],i&&(c=c[1],u=u[1]),r=[c,u],a.invert&&(c=a(c),u=a(u)),u<c&&(h=c,c=u,u=h),c==l[0]&&u==l[1]||(l=[c,u])),f):(i&&(e?(n=e[0],o=e[1]):(n=s[0],o=s[1],i.invert&&(n=i.invert(n),o=i.invert(o)),o<n&&(h=n,n=o,o=h))),a&&(r?(c=r[0],u=r[1]):(c=l[0],u=l[1],a.invert&&(c=a.invert(c),u=a.invert(u)),u<c&&(h=c,c=u,u=h))),i&&a?[[n,c],[o,u]]:i?[n,o]:a&&[c,u])},f.clear=function(){return f.empty()||(s=[0,0],l=[0,0],e=r=null),f},f.empty=function(){return!!i&&s[0]==s[1]||!!a&&l[0]==l[1]},t.rebind(f,n,\"on\")};var Ms={n:\"ns-resize\",e:\"ew-resize\",s:\"ns-resize\",w:\"ew-resize\",nw:\"nwse-resize\",ne:\"nesw-resize\",se:\"nwse-resize\",sw:\"nesw-resize\"},Ss=[[\"n\",\"e\",\"s\",\"w\",\"nw\",\"ne\",\"se\",\"sw\"],[\"e\",\"w\"],[\"n\",\"s\"],[]],Es=ze.format=sr.timeFormat,Cs=Es.utc,Ls=Cs(\"%Y-%m-%dT%H:%M:%S.%LZ\");function Ps(t){return t.toISOString()}function Os(e,r,n){function i(t){return e(t)}function a(e,n){var i=(e[1]-e[0])/n,a=t.bisect(Is,i);return a==Is.length?[r.year,xo(e.map(function(t){return t/31536e6}),n)[2]]:a?r[i/Is[a-1]<Is[a]/i?a-1:a]:[Fs,xo(e,n)[2]]}return i.invert=function(t){return zs(e.invert(t))},i.domain=function(t){return arguments.length?(e.domain(t),i):e.domain().map(zs)},i.nice=function(t,e){var r=i.domain(),n=co(r),o=null==t?a(n,10):\"number\"==typeof t&&a(n,t);function s(r){return!isNaN(r)&&!t.range(r,zs(+r+1),e).length}return o&&(t=o[0],e=o[1]),i.domain(fo(r,e>1?{floor:function(e){for(;s(e=t.floor(e));)e=zs(e-1);return e},ceil:function(e){for(;s(e=t.ceil(e));)e=zs(+e+1);return e}}:t))},i.ticks=function(t,e){var r=co(i.domain()),n=null==t?a(r,10):\"number\"==typeof t?a(r,t):!t.range&&[{range:t},e];return n&&(t=n[0],e=n[1]),t.range(r[0],zs(+r[1]+1),e<1?1:e)},i.tickFormat=function(){return n},i.copy=function(){return Os(e.copy(),r,n)},mo(i,e)}function zs(t){return new Date(t)}Es.iso=Date.prototype.toISOString&&+new Date(\"2000-01-01T00:00:00.000Z\")?Ps:Ls,Ps.parse=function(t){var e=new Date(t);return isNaN(e)?null:e},Ps.toString=Ls.toString,ze.second=Fe(function(t){return new Ie(1e3*Math.floor(t/1e3))},function(t,e){t.setTime(t.getTime()+1e3*Math.floor(e))},function(t){return t.getSeconds()}),ze.seconds=ze.second.range,ze.seconds.utc=ze.second.utc.range,ze.minute=Fe(function(t){return new Ie(6e4*Math.floor(t/6e4))},function(t,e){t.setTime(t.getTime()+6e4*Math.floor(e))},function(t){return t.getMinutes()}),ze.minutes=ze.minute.range,ze.minutes.utc=ze.minute.utc.range,ze.hour=Fe(function(t){var e=t.getTimezoneOffset()/60;return new Ie(36e5*(Math.floor(t/36e5-e)+e))},function(t,e){t.setTime(t.getTime()+36e5*Math.floor(e))},function(t){return t.getHours()}),ze.hours=ze.hour.range,ze.hours.utc=ze.hour.utc.range,ze.month=Fe(function(t){return(t=ze.day(t)).setDate(1),t},function(t,e){t.setMonth(t.getMonth()+e)},function(t){return t.getMonth()}),ze.months=ze.month.range,ze.months.utc=ze.month.utc.range;var Is=[1e3,5e3,15e3,3e4,6e4,3e5,9e5,18e5,36e5,108e5,216e5,432e5,864e5,1728e5,6048e5,2592e6,7776e6,31536e6],Ds=[[ze.second,1],[ze.second,5],[ze.second,15],[ze.second,30],[ze.minute,1],[ze.minute,5],[ze.minute,15],[ze.minute,30],[ze.hour,1],[ze.hour,3],[ze.hour,6],[ze.hour,12],[ze.day,1],[ze.day,2],[ze.week,1],[ze.month,1],[ze.month,3],[ze.year,1]],Rs=Es.multi([[\".%L\",function(t){return t.getMilliseconds()}],[\":%S\",function(t){return t.getSeconds()}],[\"%I:%M\",function(t){return t.getMinutes()}],[\"%I %p\",function(t){return t.getHours()}],[\"%a %d\",function(t){return t.getDay()&&1!=t.getDate()}],[\"%b %d\",function(t){return 1!=t.getDate()}],[\"%B\",function(t){return t.getMonth()}],[\"%Y\",Yr]]),Fs={range:function(e,r,n){return t.range(Math.ceil(e/n)*n,+r,n).map(zs)},floor:P,ceil:P};Ds.year=ze.year,ze.scale=function(){return Os(t.scale.linear(),Ds,Rs)};var Bs=Ds.map(function(t){return[t[0].utc,t[1]]}),Ns=Cs.multi([[\".%L\",function(t){return t.getUTCMilliseconds()}],[\":%S\",function(t){return t.getUTCSeconds()}],[\"%I:%M\",function(t){return t.getUTCMinutes()}],[\"%I %p\",function(t){return t.getUTCHours()}],[\"%a %d\",function(t){return t.getUTCDay()&&1!=t.getUTCDate()}],[\"%b %d\",function(t){return 1!=t.getUTCDate()}],[\"%B\",function(t){return t.getUTCMonth()}],[\"%Y\",Yr]]);function js(t){return JSON.parse(t.responseText)}function Us(t){var e=i.createRange();return e.selectNode(i.body),e.createContextualFragment(t.responseText)}Bs.year=ze.year.utc,ze.scale.utc=function(){return Os(t.scale.linear(),Bs,Ns)},t.text=me(function(t){return t.responseText}),t.json=function(t,e){return ye(t,\"application/json\",js,e)},t.html=function(t,e){return ye(t,\"text/html\",Us,e)},t.xml=me(function(t){return t.responseXML}),\"object\"==typeof e&&e.exports?e.exports=t:this.d3=t}()},{}],164:[function(t,e,r){e.exports=function(){for(var t=0;t<arguments.length;t++)if(void 0!==arguments[t])return arguments[t]}},{}],165:[function(t,e,r){\"use strict\";var n=t(\"incremental-convex-hull\"),i=t(\"uniq\");function a(t,e){this.point=t,this.index=e}function o(t,e){for(var r=t.point,n=e.point,i=r.length,a=0;a<i;++a){var o=n[a]-r[a];if(o)return o}return 0}e.exports=function(t,e){var r=t.length;if(0===r)return[];var s=t[0].length;if(s<1)return[];if(1===s)return function(t,e,r){if(1===t)return r?[[-1,0]]:[];var n=e.map(function(t,e){return[t[0],e]});n.sort(function(t,e){return t[0]-e[0]});for(var i=new Array(t-1),a=1;a<t;++a){var o=n[a-1],s=n[a];i[a-1]=[o[1],s[1]]}r&&i.push([-1,i[0][1]],[i[t-1][1],-1]);return i}(r,t,e);for(var l=new Array(r),c=1,u=0;u<r;++u){for(var h=t[u],f=new Array(s+1),p=0,d=0;d<s;++d){var g=h[d];f[d]=g,p+=g*g}f[s]=p,l[u]=new a(f,u),c=Math.max(p,c)}i(l,o),r=l.length;for(var v=new Array(r+s+1),m=new Array(r+s+1),y=(s+1)*(s+1)*c,x=new Array(s+1),u=0;u<=s;++u)x[u]=0;x[s]=y,v[0]=x.slice(),m[0]=-1;for(var u=0;u<=s;++u){var f=x.slice();f[u]=1,v[u+1]=f,m[u+1]=-1}for(var u=0;u<r;++u){var b=l[u];v[u+s+1]=b.point,m[u+s+1]=b.index}var _=n(v,!1);_=e?_.filter(function(t){for(var e=0,r=0;r<=s;++r){var n=m[t[r]];if(n<0&&++e>=2)return!1;t[r]=n}return!0}):_.filter(function(t){for(var e=0;e<=s;++e){var r=m[t[e]];if(r<0)return!1;t[e]=r}return!0});if(1&s)for(var u=0;u<_.length;++u){var b=_[u],f=b[0];b[0]=b[1],b[1]=f}return _}},{\"incremental-convex-hull\":413,uniq:547}],166:[function(t,e,r){\"use strict\";e.exports=a;var n=(a.canvas=document.createElement(\"canvas\")).getContext(\"2d\"),i=o([32,126]);function a(t,e){Array.isArray(t)&&(t=t.join(\", \"));var r,a={},s=16,l=.05;e&&(2===e.length&&\"number\"==typeof e[0]?r=o(e):Array.isArray(e)?r=e:(e.o?r=o(e.o):e.pairs&&(r=e.pairs),e.fontSize&&(s=e.fontSize),null!=e.threshold&&(l=e.threshold))),r||(r=i),n.font=s+\"px \"+t;for(var c=0;c<r.length;c++){var u=r[c],h=n.measureText(u[0]).width+n.measureText(u[1]).width,f=n.measureText(u).width;if(Math.abs(h-f)>s*l){var p=(f-h)/s;a[u]=1e3*p}}return a}function o(t){for(var e=[],r=t[0];r<=t[1];r++)for(var n=String.fromCharCode(r),i=t[0];i<t[1];i++){var a=n+String.fromCharCode(i);e.push(a)}return e}a.createPairs=o,a.ascii=i},{}],167:[function(t,e,r){(function(t){var r=!1;if(\"undefined\"!=typeof Float64Array){var n=new Float64Array(1),i=new Uint32Array(n.buffer);if(n[0]=1,r=!0,1072693248===i[1]){e.exports=function(t){return n[0]=t,[i[0],i[1]]},e.exports.pack=function(t,e){return i[0]=t,i[1]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[0]},e.exports.hi=function(t){return n[0]=t,i[1]}}else if(1072693248===i[0]){e.exports=function(t){return n[0]=t,[i[1],i[0]]},e.exports.pack=function(t,e){return i[1]=t,i[0]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[1]},e.exports.hi=function(t){return n[0]=t,i[0]}}else r=!1}if(!r){var a=new t(8);e.exports=function(t){return a.writeDoubleLE(t,0,!0),[a.readUInt32LE(0,!0),a.readUInt32LE(4,!0)]},e.exports.pack=function(t,e){return a.writeUInt32LE(t,0,!0),a.writeUInt32LE(e,4,!0),a.readDoubleLE(0,!0)},e.exports.lo=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(0,!0)},e.exports.hi=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(4,!0)}}e.exports.sign=function(t){return e.exports.hi(t)>>>31},e.exports.exponent=function(t){return(e.exports.hi(t)<<1>>>21)-1023},e.exports.fraction=function(t){var r=e.exports.lo(t),n=e.exports.hi(t),i=1048575&n;return 2146435072&n&&(i+=1<<20),[r,i]},e.exports.denormalized=function(t){return!(2146435072&e.exports.hi(t))}}).call(this,t(\"buffer\").Buffer)},{buffer:105}],168:[function(t,e,r){var n=t(\"abs-svg-path\"),i=t(\"normalize-svg-path\"),a={M:\"moveTo\",C:\"bezierCurveTo\"};e.exports=function(t,e){t.beginPath(),i(n(e)).forEach(function(e){var r=e[0],n=e.slice(1);t[a[r]].apply(t,n)}),t.closePath()}},{\"abs-svg-path\":60,\"normalize-svg-path\":452}],169:[function(t,e,r){e.exports=function(t){switch(t){case\"int8\":return Int8Array;case\"int16\":return Int16Array;case\"int32\":return Int32Array;case\"uint8\":return Uint8Array;case\"uint16\":return Uint16Array;case\"uint32\":return Uint32Array;case\"float32\":return Float32Array;case\"float64\":return Float64Array;case\"array\":return Array;case\"uint8_clamped\":return Uint8ClampedArray}}},{}],170:[function(t,e,r){\"use strict\";e.exports=function(t,e){switch(\"undefined\"==typeof e&&(e=0),typeof t){case\"number\":if(t>0)return function(t,e){var r,n;for(r=new Array(t),n=0;n<t;++n)r[n]=e;return r}(0|t,e);break;case\"object\":if(\"number\"==typeof t.length)return function t(e,r,n){var i=0|e[n];if(i<=0)return[];var a,o=new Array(i);if(n===e.length-1)for(a=0;a<i;++a)o[a]=r;else for(a=0;a<i;++a)o[a]=t(e,r,n+1);return o}(t,e,0)}return[]}},{}],171:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(\"number\"!=typeof e){e=0;for(var i=0;i<r;++i){var a=t[i];e=Math.max(e,a[0],a[1])}e=1+(0|e)}e|=0;for(var o=new Array(e),i=0;i<e;++i)o[i]=[];for(var i=0;i<r;++i){var a=t[i];o[a[0]].push(a[1]),o[a[1]].push(a[0])}for(var s=0;s<e;++s)n(o[s],function(t,e){return t-e});return o};var n=t(\"uniq\")},{uniq:547}],172:[function(t,e,r){var n=t(\"strongly-connected-components\");e.exports=function(t){var e,r=[],i=[],a=[],o={},s=[];function l(t){var r,n,u=!1;for(i.push(t),a[t]=!0,r=0;r<s[t].length;r++)(n=s[t][r])===e?(c(e,i),u=!0):a[n]||(u=l(n));if(u)!function t(e){a[e]=!1,o.hasOwnProperty(e)&&Object.keys(o[e]).forEach(function(r){delete o[e][r],a[r]&&t(r)})}(t);else for(r=0;r<s[t].length;r++){n=s[t][r];var h=o[n];h||(h={},o[n]=h),h[n]=!0}return i.pop(),u}function c(t,e){var n=[].concat(e).concat(t);r.push(n)}function u(e){!function(e){for(var r=0;r<t.length;r++)r<e&&(t[r]=[]),t[r]=t[r].filter(function(t){return t>=e})}(e);for(var r,i=n(t).components.filter(function(t){return t.length>1}),a=1/0,o=0;o<i.length;o++)for(var s=0;s<i[o].length;s++)i[o][s]<a&&(a=i[o][s],r=o);var l=i[r];return!!l&&{leastVertex:a,adjList:t.map(function(t,e){return-1===l.indexOf(e)?[]:t.filter(function(t){return-1!==l.indexOf(t)})})}}e=0;for(var h=t.length;e<h;){var f=u(e);if(e=f.leastVertex,s=f.adjList){for(var p=0;p<s.length;p++)for(var d=0;d<s[p].length;d++){var g=s[p][d];a[+g]=!1,o[g]={}}l(e),e+=1}else e=h}return r}},{\"strongly-connected-components\":530}],173:[function(t,e,r){\"use strict\";var n=t(\"../../object/valid-value\");e.exports=function(){return n(this).length=0,this}},{\"../../object/valid-value\":205}],174:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Array.from:t(\"./shim\")},{\"./is-implemented\":175,\"./shim\":176}],175:[function(t,e,r){\"use strict\";e.exports=function(){var t,e,r=Array.from;return\"function\"==typeof r&&(e=r(t=[\"raz\",\"dwa\"]),Boolean(e&&e!==t&&\"dwa\"===e[1]))}},{}],176:[function(t,e,r){\"use strict\";var n=t(\"es6-symbol\").iterator,i=t(\"../../function/is-arguments\"),a=t(\"../../function/is-function\"),o=t(\"../../number/to-pos-integer\"),s=t(\"../../object/valid-callable\"),l=t(\"../../object/valid-value\"),c=t(\"../../object/is-value\"),u=t(\"../../string/is-string\"),h=Array.isArray,f=Function.prototype.call,p={configurable:!0,enumerable:!0,writable:!0,value:null},d=Object.defineProperty;e.exports=function(t){var e,r,g,v,m,y,x,b,_,w,k=arguments[1],T=arguments[2];if(t=Object(l(t)),c(k)&&s(k),this&&this!==Array&&a(this))e=this;else{if(!k){if(i(t))return 1!==(m=t.length)?Array.apply(null,t):((v=new Array(1))[0]=t[0],v);if(h(t)){for(v=new Array(m=t.length),r=0;r<m;++r)v[r]=t[r];return v}}v=[]}if(!h(t))if(void 0!==(_=t[n])){for(x=s(_).call(t),e&&(v=new e),b=x.next(),r=0;!b.done;)w=k?f.call(k,T,b.value,r):b.value,e?(p.value=w,d(v,r,p)):v[r]=w,b=x.next(),++r;m=r}else if(u(t)){for(m=t.length,e&&(v=new e),r=0,g=0;r<m;++r)w=t[r],r+1<m&&(y=w.charCodeAt(0))>=55296&&y<=56319&&(w+=t[++r]),w=k?f.call(k,T,w,g):w,e?(p.value=w,d(v,g,p)):v[g]=w,++g;m=g}if(void 0===m)for(m=o(t.length),e&&(v=new e(m)),r=0;r<m;++r)w=k?f.call(k,T,t[r],r):t[r],e?(p.value=w,d(v,r,p)):v[r]=w;return e&&(p.value=null,v.length=m),v}},{\"../../function/is-arguments\":177,\"../../function/is-function\":178,\"../../number/to-pos-integer\":184,\"../../object/is-value\":194,\"../../object/valid-callable\":203,\"../../object/valid-value\":205,\"../../string/is-string\":209,\"es6-symbol\":219}],177:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(function(){return arguments}());e.exports=function(t){return n.call(t)===i}},{}],178:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(t(\"./noop\"));e.exports=function(t){return\"function\"==typeof t&&n.call(t)===i}},{\"./noop\":179}],179:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],180:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Math.sign:t(\"./shim\")},{\"./is-implemented\":181,\"./shim\":182}],181:[function(t,e,r){\"use strict\";e.exports=function(){var t=Math.sign;return\"function\"==typeof t&&(1===t(10)&&-1===t(-20))}},{}],182:[function(t,e,r){\"use strict\";e.exports=function(t){return t=Number(t),isNaN(t)||0===t?t:t>0?1:-1}},{}],183:[function(t,e,r){\"use strict\";var n=t(\"../math/sign\"),i=Math.abs,a=Math.floor;e.exports=function(t){return isNaN(t)?0:0!==(t=Number(t))&&isFinite(t)?n(t)*a(i(t)):t}},{\"../math/sign\":180}],184:[function(t,e,r){\"use strict\";var n=t(\"./to-integer\"),i=Math.max;e.exports=function(t){return i(0,n(t))}},{\"./to-integer\":183}],185:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./valid-value\"),a=Function.prototype.bind,o=Function.prototype.call,s=Object.keys,l=Object.prototype.propertyIsEnumerable;e.exports=function(t,e){return function(r,c){var u,h=arguments[2],f=arguments[3];return r=Object(i(r)),n(c),u=s(r),f&&u.sort(\"function\"==typeof f?a.call(f,r):void 0),\"function\"!=typeof t&&(t=u[t]),o.call(t,u,function(t,n){return l.call(r,t)?o.call(c,h,r[t],t,r,n):e})}}},{\"./valid-callable\":203,\"./valid-value\":205}],186:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.assign:t(\"./shim\")},{\"./is-implemented\":187,\"./shim\":188}],187:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=Object.assign;return\"function\"==typeof e&&(e(t={foo:\"raz\"},{bar:\"dwa\"},{trzy:\"trzy\"}),t.foo+t.bar+t.trzy===\"razdwatrzy\")}},{}],188:[function(t,e,r){\"use strict\";var n=t(\"../keys\"),i=t(\"../valid-value\"),a=Math.max;e.exports=function(t,e){var r,o,s,l=a(arguments.length,2);for(t=Object(i(t)),s=function(n){try{t[n]=e[n]}catch(t){r||(r=t)}},o=1;o<l;++o)e=arguments[o],n(e).forEach(s);if(void 0!==r)throw r;return t}},{\"../keys\":195,\"../valid-value\":205}],189:[function(t,e,r){\"use strict\";var n=t(\"../array/from\"),i=t(\"./assign\"),a=t(\"./valid-value\");e.exports=function(t){var e=Object(a(t)),r=arguments[1],o=Object(arguments[2]);if(e!==t&&!r)return e;var s={};return r?n(r,function(e){(o.ensure||e in t)&&(s[e]=t[e])}):i(s,t),s}},{\"../array/from\":174,\"./assign\":186,\"./valid-value\":205}],190:[function(t,e,r){\"use strict\";var n,i,a,o,s=Object.create;t(\"./set-prototype-of/is-implemented\")()||(n=t(\"./set-prototype-of/shim\")),e.exports=n?1!==n.level?s:(i={},a={},o={configurable:!1,enumerable:!1,writable:!0,value:void 0},Object.getOwnPropertyNames(Object.prototype).forEach(function(t){a[t]=\"__proto__\"!==t?o:{configurable:!0,enumerable:!1,writable:!0,value:void 0}}),Object.defineProperties(i,a),Object.defineProperty(n,\"nullPolyfill\",{configurable:!1,enumerable:!1,writable:!1,value:i}),function(t,e){return s(null===t?i:t,e)}):s},{\"./set-prototype-of/is-implemented\":201,\"./set-prototype-of/shim\":202}],191:[function(t,e,r){\"use strict\";e.exports=t(\"./_iterate\")(\"forEach\")},{\"./_iterate\":185}],192:[function(t,e,r){\"use strict\";e.exports=function(t){return\"function\"==typeof t}},{}],193:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i={function:!0,object:!0};e.exports=function(t){return n(t)&&i[typeof t]||!1}},{\"./is-value\":194}],194:[function(t,e,r){\"use strict\";var n=t(\"../function/noop\")();e.exports=function(t){return t!==n&&null!==t}},{\"../function/noop\":179}],195:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.keys:t(\"./shim\")},{\"./is-implemented\":196,\"./shim\":197}],196:[function(t,e,r){\"use strict\";e.exports=function(){try{return Object.keys(\"primitive\"),!0}catch(t){return!1}}},{}],197:[function(t,e,r){\"use strict\";var n=t(\"../is-value\"),i=Object.keys;e.exports=function(t){return i(n(t)?Object(t):t)}},{\"../is-value\":194}],198:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./for-each\"),a=Function.prototype.call;e.exports=function(t,e){var r={},o=arguments[2];return n(e),i(t,function(t,n,i,s){r[n]=a.call(e,o,t,n,i,s)}),r}},{\"./for-each\":191,\"./valid-callable\":203}],199:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i=Array.prototype.forEach,a=Object.create;e.exports=function(t){var e=a(null);return i.call(arguments,function(t){n(t)&&function(t,e){var r;for(r in t)e[r]=t[r]}(Object(t),e)}),e}},{\"./is-value\":194}],200:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.setPrototypeOf:t(\"./shim\")},{\"./is-implemented\":201,\"./shim\":202}],201:[function(t,e,r){\"use strict\";var n=Object.create,i=Object.getPrototypeOf,a={};e.exports=function(){var t=Object.setPrototypeOf,e=arguments[0]||n;return\"function\"==typeof t&&i(t(e(null),a))===a}},{}],202:[function(t,e,r){\"use strict\";var n,i,a,o,s=t(\"../is-object\"),l=t(\"../valid-value\"),c=Object.prototype.isPrototypeOf,u=Object.defineProperty,h={configurable:!0,enumerable:!1,writable:!0,value:void 0};n=function(t,e){if(l(t),null===e||s(e))return t;throw new TypeError(\"Prototype must be null or an object\")},e.exports=(i=function(){var t,e=Object.create(null),r={},n=Object.getOwnPropertyDescriptor(Object.prototype,\"__proto__\");if(n){try{(t=n.set).call(e,r)}catch(t){}if(Object.getPrototypeOf(e)===r)return{set:t,level:2}}return e.__proto__=r,Object.getPrototypeOf(e)===r?{level:2}:((e={}).__proto__=r,Object.getPrototypeOf(e)===r&&{level:1})}())?(2===i.level?i.set?(o=i.set,a=function(t,e){return o.call(n(t,e),e),t}):a=function(t,e){return n(t,e).__proto__=e,t}:a=function t(e,r){var i;return n(e,r),(i=c.call(t.nullPolyfill,e))&&delete t.nullPolyfill.__proto__,null===r&&(r=t.nullPolyfill),e.__proto__=r,i&&u(t.nullPolyfill,\"__proto__\",h),e},Object.defineProperty(a,\"level\",{configurable:!1,enumerable:!1,writable:!1,value:i.level})):null,t(\"../create\")},{\"../create\":190,\"../is-object\":193,\"../valid-value\":205}],203:[function(t,e,r){\"use strict\";e.exports=function(t){if(\"function\"!=typeof t)throw new TypeError(t+\" is not a function\");return t}},{}],204:[function(t,e,r){\"use strict\";var n=t(\"./is-object\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not an Object\");return t}},{\"./is-object\":193}],205:[function(t,e,r){\"use strict\";var n=t(\"./is-value\");e.exports=function(t){if(!n(t))throw new TypeError(\"Cannot use null or undefined\");return t}},{\"./is-value\":194}],206:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?String.prototype.contains:t(\"./shim\")},{\"./is-implemented\":207,\"./shim\":208}],207:[function(t,e,r){\"use strict\";var n=\"razdwatrzy\";e.exports=function(){return\"function\"==typeof n.contains&&(!0===n.contains(\"dwa\")&&!1===n.contains(\"foo\"))}},{}],208:[function(t,e,r){\"use strict\";var n=String.prototype.indexOf;e.exports=function(t){return n.call(this,t,arguments[1])>-1}},{}],209:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(\"\");e.exports=function(t){return\"string\"==typeof t||t&&\"object\"==typeof t&&(t instanceof String||n.call(t)===i)||!1}},{}],210:[function(t,e,r){\"use strict\";var n=Object.create(null),i=Math.random;e.exports=function(){var t;do{t=i().toString(36).slice(2)}while(n[t]);return t}},{}],211:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"es5-ext/string/#/contains\"),o=t(\"d\"),s=t(\"es6-symbol\"),l=t(\"./\"),c=Object.defineProperty;n=e.exports=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");l.call(this,t),e=e?a.call(e,\"key+value\")?\"key+value\":a.call(e,\"key\")?\"key\":\"value\":\"value\",c(this,\"__kind__\",o(\"\",e))},i&&i(n,l),delete n.prototype.constructor,n.prototype=Object.create(l.prototype,{_resolve:o(function(t){return\"value\"===this.__kind__?this.__list__[t]:\"key+value\"===this.__kind__?[t,this.__list__[t]]:t})}),c(n.prototype,s.toStringTag,o(\"c\",\"Array Iterator\"))},{\"./\":214,d:151,\"es5-ext/object/set-prototype-of\":200,\"es5-ext/string/#/contains\":206,\"es6-symbol\":219}],212:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/valid-callable\"),a=t(\"es5-ext/string/is-string\"),o=t(\"./get\"),s=Array.isArray,l=Function.prototype.call,c=Array.prototype.some;e.exports=function(t,e){var r,u,h,f,p,d,g,v,m=arguments[2];if(s(t)||n(t)?r=\"array\":a(t)?r=\"string\":t=o(t),i(e),h=function(){f=!0},\"array\"!==r)if(\"string\"!==r)for(u=t.next();!u.done;){if(l.call(e,m,u.value,h),f)return;u=t.next()}else for(d=t.length,p=0;p<d&&(g=t[p],p+1<d&&(v=g.charCodeAt(0))>=55296&&v<=56319&&(g+=t[++p]),l.call(e,m,g,h),!f);++p);else c.call(t,function(t){return l.call(e,m,t,h),f})}},{\"./get\":213,\"es5-ext/function/is-arguments\":177,\"es5-ext/object/valid-callable\":203,\"es5-ext/string/is-string\":209}],213:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/string/is-string\"),a=t(\"./array\"),o=t(\"./string\"),s=t(\"./valid-iterable\"),l=t(\"es6-symbol\").iterator;e.exports=function(t){return\"function\"==typeof s(t)[l]?t[l]():n(t)?new a(t):i(t)?new o(t):new a(t)}},{\"./array\":211,\"./string\":216,\"./valid-iterable\":217,\"es5-ext/function/is-arguments\":177,\"es5-ext/string/is-string\":209,\"es6-symbol\":219}],214:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/array/#/clear\"),a=t(\"es5-ext/object/assign\"),o=t(\"es5-ext/object/valid-callable\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"d\"),c=t(\"d/auto-bind\"),u=t(\"es6-symbol\"),h=Object.defineProperty,f=Object.defineProperties;e.exports=n=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");f(this,{__list__:l(\"w\",s(t)),__context__:l(\"w\",e),__nextIndex__:l(\"w\",0)}),e&&(o(e.on),e.on(\"_add\",this._onAdd),e.on(\"_delete\",this._onDelete),e.on(\"_clear\",this._onClear))},delete n.prototype.constructor,f(n.prototype,a({_next:l(function(){var t;if(this.__list__)return this.__redo__&&void 0!==(t=this.__redo__.shift())?t:this.__nextIndex__<this.__list__.length?this.__nextIndex__++:void this._unBind()}),next:l(function(){return this._createResult(this._next())}),_createResult:l(function(t){return void 0===t?{done:!0,value:void 0}:{done:!1,value:this._resolve(t)}}),_resolve:l(function(t){return this.__list__[t]}),_unBind:l(function(){this.__list__=null,delete this.__redo__,this.__context__&&(this.__context__.off(\"_add\",this._onAdd),this.__context__.off(\"_delete\",this._onDelete),this.__context__.off(\"_clear\",this._onClear),this.__context__=null)}),toString:l(function(){return\"[object \"+(this[u.toStringTag]||\"Object\")+\"]\"})},c({_onAdd:l(function(t){t>=this.__nextIndex__||(++this.__nextIndex__,this.__redo__?(this.__redo__.forEach(function(e,r){e>=t&&(this.__redo__[r]=++e)},this),this.__redo__.push(t)):h(this,\"__redo__\",l(\"c\",[t])))}),_onDelete:l(function(t){var e;t>=this.__nextIndex__||(--this.__nextIndex__,this.__redo__&&(-1!==(e=this.__redo__.indexOf(t))&&this.__redo__.splice(e,1),this.__redo__.forEach(function(e,r){e>t&&(this.__redo__[r]=--e)},this)))}),_onClear:l(function(){this.__redo__&&i.call(this.__redo__),this.__nextIndex__=0})}))),h(n.prototype,u.iterator,l(function(){return this}))},{d:151,\"d/auto-bind\":150,\"es5-ext/array/#/clear\":173,\"es5-ext/object/assign\":186,\"es5-ext/object/valid-callable\":203,\"es5-ext/object/valid-value\":205,\"es6-symbol\":219}],215:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/string/is-string\"),o=t(\"es6-symbol\").iterator,s=Array.isArray;e.exports=function(t){return!!i(t)&&(!!s(t)||(!!a(t)||(!!n(t)||\"function\"==typeof t[o])))}},{\"es5-ext/function/is-arguments\":177,\"es5-ext/object/is-value\":194,\"es5-ext/string/is-string\":209,\"es6-symbol\":219}],216:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"d\"),o=t(\"es6-symbol\"),s=t(\"./\"),l=Object.defineProperty;n=e.exports=function(t){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");t=String(t),s.call(this,t),l(this,\"__length__\",a(\"\",t.length))},i&&i(n,s),delete n.prototype.constructor,n.prototype=Object.create(s.prototype,{_next:a(function(){if(this.__list__)return this.__nextIndex__<this.__length__?this.__nextIndex__++:void this._unBind()}),_resolve:a(function(t){var e,r=this.__list__[t];return this.__nextIndex__===this.__length__?r:(e=r.charCodeAt(0))>=55296&&e<=56319?r+this.__list__[this.__nextIndex__++]:r})}),l(n.prototype,o.toStringTag,a(\"c\",\"String Iterator\"))},{\"./\":214,d:151,\"es5-ext/object/set-prototype-of\":200,\"es6-symbol\":219}],217:[function(t,e,r){\"use strict\";var n=t(\"./is-iterable\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not iterable\");return t}},{\"./is-iterable\":215}],218:[function(t,e,r){(function(n,i){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():t.ES6Promise=n()}(this,function(){\"use strict\";function e(t){return\"function\"==typeof t}var r=Array.isArray?Array.isArray:function(t){return\"[object Array]\"===Object.prototype.toString.call(t)},a=0,o=void 0,s=void 0,l=function(t,e){g[a]=t,g[a+1]=e,2===(a+=2)&&(s?s(v):_())};var c=\"undefined\"!=typeof window?window:void 0,u=c||{},h=u.MutationObserver||u.WebKitMutationObserver,f=\"undefined\"==typeof self&&\"undefined\"!=typeof n&&\"[object process]\"==={}.toString.call(n),p=\"undefined\"!=typeof Uint8ClampedArray&&\"undefined\"!=typeof importScripts&&\"undefined\"!=typeof MessageChannel;function d(){var t=setTimeout;return function(){return t(v,1)}}var g=new Array(1e3);function v(){for(var t=0;t<a;t+=2){(0,g[t])(g[t+1]),g[t]=void 0,g[t+1]=void 0}a=0}var m,y,x,b,_=void 0;function w(t,e){var r=arguments,n=this,i=new this.constructor(A);void 0===i[T]&&V(i);var a,o=n._state;return o?(a=r[o-1],l(function(){return j(o,i,a,n._result)})):R(n,i,t,e),i}function k(t){if(t&&\"object\"==typeof t&&t.constructor===this)return t;var e=new this(A);return O(e,t),e}f?_=function(){return n.nextTick(v)}:h?(y=0,x=new h(v),b=document.createTextNode(\"\"),x.observe(b,{characterData:!0}),_=function(){b.data=y=++y%2}):p?((m=new MessageChannel).port1.onmessage=v,_=function(){return m.port2.postMessage(0)}):_=void 0===c&&\"function\"==typeof t?function(){try{var e=t(\"vertx\");return o=e.runOnLoop||e.runOnContext,function(){o(v)}}catch(t){return d()}}():d();var T=Math.random().toString(36).substring(16);function A(){}var M=void 0,S=1,E=2,C=new B;function L(t){try{return t.then}catch(t){return C.error=t,C}}function P(t,r,n){r.constructor===t.constructor&&n===w&&r.constructor.resolve===k?function(t,e){e._state===S?I(t,e._result):e._state===E?D(t,e._result):R(e,void 0,function(e){return O(t,e)},function(e){return D(t,e)})}(t,r):n===C?D(t,C.error):void 0===n?I(t,r):e(n)?function(t,e,r){l(function(t){var n=!1,i=function(t,e,r,n){try{t.call(e,r,n)}catch(t){return t}}(r,e,function(r){n||(n=!0,e!==r?O(t,r):I(t,r))},function(e){n||(n=!0,D(t,e))},t._label);!n&&i&&(n=!0,D(t,i))},t)}(t,r,n):I(t,r)}function O(t,e){var r;t===e?D(t,new TypeError(\"You cannot resolve a promise with itself\")):\"function\"==typeof(r=e)||\"object\"==typeof r&&null!==r?P(t,e,L(e)):I(t,e)}function z(t){t._onerror&&t._onerror(t._result),F(t)}function I(t,e){t._state===M&&(t._result=e,t._state=S,0!==t._subscribers.length&&l(F,t))}function D(t,e){t._state===M&&(t._state=E,t._result=e,l(z,t))}function R(t,e,r,n){var i=t._subscribers,a=i.length;t._onerror=null,i[a]=e,i[a+S]=r,i[a+E]=n,0===a&&t._state&&l(F,t)}function F(t){var e=t._subscribers,r=t._state;if(0!==e.length){for(var n=void 0,i=void 0,a=t._result,o=0;o<e.length;o+=3)n=e[o],i=e[o+r],n?j(r,n,i,a):i(a);t._subscribers.length=0}}function B(){this.error=null}var N=new B;function j(t,r,n,i){var a=e(n),o=void 0,s=void 0,l=void 0,c=void 0;if(a){if((o=function(t,e){try{return t(e)}catch(t){return N.error=t,N}}(n,i))===N?(c=!0,s=o.error,o=null):l=!0,r===o)return void D(r,new TypeError(\"A promises callback cannot return that same promise.\"))}else o=i,l=!0;r._state!==M||(a&&l?O(r,o):c?D(r,s):t===S?I(r,o):t===E&&D(r,o))}var U=0;function V(t){t[T]=U++,t._state=void 0,t._result=void 0,t._subscribers=[]}function q(t,e){this._instanceConstructor=t,this.promise=new t(A),this.promise[T]||V(this.promise),r(e)?(this._input=e,this.length=e.length,this._remaining=e.length,this._result=new Array(this.length),0===this.length?I(this.promise,this._result):(this.length=this.length||0,this._enumerate(),0===this._remaining&&I(this.promise,this._result))):D(this.promise,new Error(\"Array Methods must be provided an Array\"))}function H(t){this[T]=U++,this._result=this._state=void 0,this._subscribers=[],A!==t&&(\"function\"!=typeof t&&function(){throw new TypeError(\"You must pass a resolver function as the first argument to the promise constructor\")}(),this instanceof H?function(t,e){try{e(function(e){O(t,e)},function(e){D(t,e)})}catch(e){D(t,e)}}(this,t):function(){throw new TypeError(\"Failed to construct 'Promise': Please use the 'new' operator, this object constructor cannot be called as a function.\")}())}function G(){var t=void 0;if(\"undefined\"!=typeof i)t=i;else if(\"undefined\"!=typeof self)t=self;else try{t=Function(\"return this\")()}catch(t){throw new Error(\"polyfill failed because global object is unavailable in this environment\")}var e=t.Promise;if(e){var r=null;try{r=Object.prototype.toString.call(e.resolve())}catch(t){}if(\"[object Promise]\"===r&&!e.cast)return}t.Promise=H}return q.prototype._enumerate=function(){for(var t=this.length,e=this._input,r=0;this._state===M&&r<t;r++)this._eachEntry(e[r],r)},q.prototype._eachEntry=function(t,e){var r=this._instanceConstructor,n=r.resolve;if(n===k){var i=L(t);if(i===w&&t._state!==M)this._settledAt(t._state,e,t._result);else if(\"function\"!=typeof i)this._remaining--,this._result[e]=t;else if(r===H){var a=new r(A);P(a,t,i),this._willSettleAt(a,e)}else this._willSettleAt(new r(function(e){return e(t)}),e)}else this._willSettleAt(n(t),e)},q.prototype._settledAt=function(t,e,r){var n=this.promise;n._state===M&&(this._remaining--,t===E?D(n,r):this._result[e]=r),0===this._remaining&&I(n,this._result)},q.prototype._willSettleAt=function(t,e){var r=this;R(t,void 0,function(t){return r._settledAt(S,e,t)},function(t){return r._settledAt(E,e,t)})},H.all=function(t){return new q(this,t).promise},H.race=function(t){var e=this;return r(t)?new e(function(r,n){for(var i=t.length,a=0;a<i;a++)e.resolve(t[a]).then(r,n)}):new e(function(t,e){return e(new TypeError(\"You must pass an array to race.\"))})},H.resolve=k,H.reject=function(t){var e=new this(A);return D(e,t),e},H._setScheduler=function(t){s=t},H._setAsap=function(t){l=t},H._asap=l,H.prototype={constructor:H,then:w,catch:function(t){return this.then(null,t)}},G(),H.polyfill=G,H.Promise=H,H})}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{_process:482}],219:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Symbol:t(\"./polyfill\")},{\"./is-implemented\":220,\"./polyfill\":222}],220:[function(t,e,r){\"use strict\";var n={object:!0,symbol:!0};e.exports=function(){var t;if(\"function\"!=typeof Symbol)return!1;t=Symbol(\"test symbol\");try{String(t)}catch(t){return!1}return!!n[typeof Symbol.iterator]&&(!!n[typeof Symbol.toPrimitive]&&!!n[typeof Symbol.toStringTag])}},{}],221:[function(t,e,r){\"use strict\";e.exports=function(t){return!!t&&(\"symbol\"==typeof t||!!t.constructor&&(\"Symbol\"===t.constructor.name&&\"Symbol\"===t[t.constructor.toStringTag]))}},{}],222:[function(t,e,r){\"use strict\";var n,i,a,o,s=t(\"d\"),l=t(\"./validate-symbol\"),c=Object.create,u=Object.defineProperties,h=Object.defineProperty,f=Object.prototype,p=c(null);if(\"function\"==typeof Symbol){n=Symbol;try{String(n()),o=!0}catch(t){}}var d,g=(d=c(null),function(t){for(var e,r,n=0;d[t+(n||\"\")];)++n;return d[t+=n||\"\"]=!0,h(f,e=\"@@\"+t,s.gs(null,function(t){r||(r=!0,h(this,e,s(t)),r=!1)})),e});a=function(t){if(this instanceof a)throw new TypeError(\"Symbol is not a constructor\");return i(t)},e.exports=i=function t(e){var r;if(this instanceof t)throw new TypeError(\"Symbol is not a constructor\");return o?n(e):(r=c(a.prototype),e=void 0===e?\"\":String(e),u(r,{__description__:s(\"\",e),__name__:s(\"\",g(e))}))},u(i,{for:s(function(t){return p[t]?p[t]:p[t]=i(String(t))}),keyFor:s(function(t){var e;for(e in l(t),p)if(p[e]===t)return e}),hasInstance:s(\"\",n&&n.hasInstance||i(\"hasInstance\")),isConcatSpreadable:s(\"\",n&&n.isConcatSpreadable||i(\"isConcatSpreadable\")),iterator:s(\"\",n&&n.iterator||i(\"iterator\")),match:s(\"\",n&&n.match||i(\"match\")),replace:s(\"\",n&&n.replace||i(\"replace\")),search:s(\"\",n&&n.search||i(\"search\")),species:s(\"\",n&&n.species||i(\"species\")),split:s(\"\",n&&n.split||i(\"split\")),toPrimitive:s(\"\",n&&n.toPrimitive||i(\"toPrimitive\")),toStringTag:s(\"\",n&&n.toStringTag||i(\"toStringTag\")),unscopables:s(\"\",n&&n.unscopables||i(\"unscopables\"))}),u(a.prototype,{constructor:s(i),toString:s(\"\",function(){return this.__name__})}),u(i.prototype,{toString:s(function(){return\"Symbol (\"+l(this).__description__+\")\"}),valueOf:s(function(){return l(this)})}),h(i.prototype,i.toPrimitive,s(\"\",function(){var t=l(this);return\"symbol\"==typeof t?t:t.toString()})),h(i.prototype,i.toStringTag,s(\"c\",\"Symbol\")),h(a.prototype,i.toStringTag,s(\"c\",i.prototype[i.toStringTag])),h(a.prototype,i.toPrimitive,s(\"c\",i.prototype[i.toPrimitive]))},{\"./validate-symbol\":223,d:151}],223:[function(t,e,r){\"use strict\";var n=t(\"./is-symbol\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not a symbol\");return t}},{\"./is-symbol\":221}],224:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=e||0,i=r||1;return[[t[12]+t[0],t[13]+t[1],t[14]+t[2],t[15]+t[3]],[t[12]-t[0],t[13]-t[1],t[14]-t[2],t[15]-t[3]],[t[12]+t[4],t[13]+t[5],t[14]+t[6],t[15]+t[7]],[t[12]-t[4],t[13]-t[5],t[14]-t[6],t[15]-t[7]],[n*t[12]+t[8],n*t[13]+t[9],n*t[14]+t[10],n*t[15]+t[11]],[i*t[12]-t[8],i*t[13]-t[9],i*t[14]-t[10],i*t[15]-t[11]]]}},{}],225:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\");e.exports=function(t){var e=typeof t;if(\"string\"===e){var r=t;if(0===(t=+t)&&n(r))return!1}else if(\"number\"!==e)return!1;return t-t<1}},{\"is-string-blank\":423}],226:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 0:return new o([0],[0],0);case 1:if(\"number\"==typeof t){var n=l(t);return new o(n,n,0)}return new o(t,l(t.length),0);case 2:if(\"number\"==typeof e){var n=l(t.length);return new o(t,n,+e)}r=0;case 3:if(t.length!==e.length)throw new Error(\"state and velocity lengths must match\");return new o(t,e,r)}};var n=t(\"cubic-hermite\"),i=t(\"binary-search-bounds\");function a(t,e,r){return Math.min(e,Math.max(t,r))}function o(t,e,r){this.dimension=t.length,this.bounds=[new Array(this.dimension),new Array(this.dimension)];for(var n=0;n<this.dimension;++n)this.bounds[0][n]=-1/0,this.bounds[1][n]=1/0;this._state=t.slice().reverse(),this._velocity=e.slice().reverse(),this._time=[r],this._scratch=[t.slice(),t.slice(),t.slice(),t.slice(),t.slice()]}var s=o.prototype;function l(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=0;return e}s.flush=function(t){var e=i.gt(this._time,t)-1;e<=0||(this._time.splice(0,e),this._state.splice(0,e*this.dimension),this._velocity.splice(0,e*this.dimension))},s.curve=function(t){var e=this._time,r=e.length,o=i.le(e,t),s=this._scratch[0],l=this._state,c=this._velocity,u=this.dimension,h=this.bounds;if(o<0)for(var f=u-1,p=0;p<u;++p,--f)s[p]=l[f];else if(o>=r-1){f=l.length-1;var d=t-e[r-1];for(p=0;p<u;++p,--f)s[p]=l[f]+d*c[f]}else{f=u*(o+1)-1;var g=e[o],v=e[o+1]-g||1,m=this._scratch[1],y=this._scratch[2],x=this._scratch[3],b=this._scratch[4],_=!0;for(p=0;p<u;++p,--f)m[p]=l[f],x[p]=c[f]*v,y[p]=l[f+u],b[p]=c[f+u]*v,_=_&&m[p]===y[p]&&x[p]===b[p]&&0===x[p];if(_)for(p=0;p<u;++p)s[p]=m[p];else n(m,x,y,b,(t-g)/v,s)}var w=h[0],k=h[1];for(p=0;p<u;++p)s[p]=a(w[p],k[p],s[p]);return s},s.dcurve=function(t){var e=this._time,r=e.length,a=i.le(e,t),o=this._scratch[0],s=this._state,l=this._velocity,c=this.dimension;if(a>=r-1)for(var u=s.length-1,h=(e[r-1],0);h<c;++h,--u)o[h]=l[u];else{u=c*(a+1)-1;var f=e[a],p=e[a+1]-f||1,d=this._scratch[1],g=this._scratch[2],v=this._scratch[3],m=this._scratch[4],y=!0;for(h=0;h<c;++h,--u)d[h]=s[u],v[h]=l[u]*p,g[h]=s[u+c],m[h]=l[u+c]*p,y=y&&d[h]===g[h]&&v[h]===m[h]&&0===v[h];if(y)for(h=0;h<c;++h)o[h]=0;else{n.derivative(d,v,g,m,(t-f)/p,o);for(h=0;h<c;++h)o[h]/=p}}return o},s.lastT=function(){var t=this._time;return t[t.length-1]},s.stable=function(){for(var t=this._velocity,e=t.length,r=this.dimension-1;r>=0;--r)if(t[--e])return!1;return!0},s.jump=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1];this._time.push(e,t);for(var u=0;u<2;++u)for(var h=0;h<r;++h)n.push(n[o++]),i.push(0);this._time.push(t);for(h=r;h>0;--h)n.push(a(l[h-1],c[h-1],arguments[h])),i.push(0)}},s.push=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=t-e,l=this.bounds,c=l[0],u=l[1],h=s>1e-6?1/s:0;this._time.push(t);for(var f=r;f>0;--f){var p=a(c[f-1],u[f-1],arguments[f]);n.push(p),i.push((p-n[o++])*h)}}},s.set=function(t){var e=this.dimension;if(!(t<this.lastT()||arguments.length!==e+1)){var r=this._state,n=this._velocity,i=this.bounds,o=i[0],s=i[1];this._time.push(t);for(var l=e;l>0;--l)r.push(a(o[l-1],s[l-1],arguments[l])),n.push(0)}},s.move=function(t){var e=this.lastT(),r=this.dimension;if(!(t<=e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1],u=t-e,h=u>1e-6?1/u:0;this._time.push(t);for(var f=r;f>0;--f){var p=arguments[f];n.push(a(l[f-1],c[f-1],n[o++]+p)),i.push(p*h)}}},s.idle=function(t){var e=this.lastT();if(!(t<e)){var r=this.dimension,n=this._state,i=this._velocity,o=n.length-r,s=this.bounds,l=s[0],c=s[1],u=t-e;this._time.push(t);for(var h=r-1;h>=0;--h)n.push(a(l[h],c[h],n[o]+u*i[o])),i.push(0),o+=1}}},{\"binary-search-bounds\":91,\"cubic-hermite\":145}],227:[function(t,e,r){var n=t(\"dtype\");e.exports=function(t,e,r){if(!t)throw new TypeError(\"must specify data as first parameter\");if(r=0|+(r||0),Array.isArray(t)&&t[0]&&\"number\"==typeof t[0][0]){var i,a,o,s,l=t[0].length,c=t.length*l;e&&\"string\"!=typeof e||(e=new(n(e||\"float32\"))(c+r));var u=e.length-r;if(c!==u)throw new Error(\"source length \"+c+\" (\"+l+\"x\"+t.length+\") does not match destination length \"+u);for(i=0,o=r;i<t.length;i++)for(a=0;a<l;a++)e[o++]=null===t[i][a]?NaN:t[i][a]}else if(e&&\"string\"!=typeof e)e.set(t,r);else{var h=n(e||\"float32\");if(Array.isArray(t)||\"array\"===e)for(e=new h(t.length+r),i=0,o=r,s=e.length;o<s;o++,i++)e[o]=null===t[i]?NaN:t[i];else 0===r?e=new h(t):(e=new h(t.length+r)).set(t,r)}return e}},{dtype:169}],228:[function(t,e,r){\"use strict\";var n=t(\"css-font/stringify\"),i=[32,126];e.exports=function(t){var e=(t=t||{}).shape?t.shape:t.canvas?[t.canvas.width,t.canvas.height]:[512,512],r=t.canvas||document.createElement(\"canvas\"),a=t.font,o=\"number\"==typeof t.step?[t.step,t.step]:t.step||[32,32],s=t.chars||i;a&&\"string\"!=typeof a&&(a=n(a));if(Array.isArray(s)){if(2===s.length&&\"number\"==typeof s[0]&&\"number\"==typeof s[1]){for(var l=[],c=s[0],u=0;c<=s[1];c++)l[u++]=String.fromCharCode(c);s=l}}else s=String(s).split(\"\");e=e.slice(),r.width=e[0],r.height=e[1];var h=r.getContext(\"2d\");h.fillStyle=\"#000\",h.fillRect(0,0,r.width,r.height),h.font=a,h.textAlign=\"center\",h.textBaseline=\"middle\",h.fillStyle=\"#fff\";for(var f=o[0]/2,p=o[1]/2,c=0;c<s.length;c++)h.fillText(s[c],f,p),(f+=o[0])>e[0]-o[0]/2&&(f=o[0]/2,p+=o[1]);return r}},{\"css-font/stringify\":142}],229:[function(t,e,r){\"use strict\";function n(t,e){e||(e={}),(\"string\"==typeof t||Array.isArray(t))&&(e.family=t);var r=Array.isArray(e.family)?e.family.join(\", \"):e.family;if(!r)throw Error(\"`family` must be defined\");var s=e.size||e.fontSize||e.em||48,l=e.weight||e.fontWeight||\"\",c=(t=[e.style||e.fontStyle||\"\",l,s].join(\" \")+\"px \"+r,e.origin||\"top\");if(n.cache[r]&&s<=n.cache[r].em)return i(n.cache[r],c);var u=e.canvas||n.canvas,h=u.getContext(\"2d\"),f={upper:void 0!==e.upper?e.upper:\"H\",lower:void 0!==e.lower?e.lower:\"x\",descent:void 0!==e.descent?e.descent:\"p\",ascent:void 0!==e.ascent?e.ascent:\"h\",tittle:void 0!==e.tittle?e.tittle:\"i\",overshoot:void 0!==e.overshoot?e.overshoot:\"O\"},p=Math.ceil(1.5*s);u.height=p,u.width=.5*p,h.font=t;var d={top:0};h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillStyle=\"black\",h.fillText(\"H\",0,0);var g=a(h.getImageData(0,0,p,p));h.clearRect(0,0,p,p),h.textBaseline=\"bottom\",h.fillText(\"H\",0,p);var v=a(h.getImageData(0,0,p,p));d.lineHeight=d.bottom=p-v+g,h.clearRect(0,0,p,p),h.textBaseline=\"alphabetic\",h.fillText(\"H\",0,p);var m=p-a(h.getImageData(0,0,p,p))-1+g;d.baseline=d.alphabetic=m,h.clearRect(0,0,p,p),h.textBaseline=\"middle\",h.fillText(\"H\",0,.5*p);var y=a(h.getImageData(0,0,p,p));d.median=d.middle=p-y-1+g-.5*p,h.clearRect(0,0,p,p),h.textBaseline=\"hanging\",h.fillText(\"H\",0,.5*p);var x=a(h.getImageData(0,0,p,p));d.hanging=p-x-1+g-.5*p,h.clearRect(0,0,p,p),h.textBaseline=\"ideographic\",h.fillText(\"H\",0,p);var b=a(h.getImageData(0,0,p,p));if(d.ideographic=p-b-1+g,f.upper&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.upper,0,0),d.upper=a(h.getImageData(0,0,p,p)),d.capHeight=d.baseline-d.upper),f.lower&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.lower,0,0),d.lower=a(h.getImageData(0,0,p,p)),d.xHeight=d.baseline-d.lower),f.tittle&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.tittle,0,0),d.tittle=a(h.getImageData(0,0,p,p))),f.ascent&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.ascent,0,0),d.ascent=a(h.getImageData(0,0,p,p))),f.descent&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.descent,0,0),d.descent=o(h.getImageData(0,0,p,p))),f.overshoot){h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.overshoot,0,0);var _=o(h.getImageData(0,0,p,p));d.overshoot=_-m}for(var w in d)d[w]/=s;return d.em=s,n.cache[r]=d,i(d,c)}function i(t,e){var r={};for(var n in\"string\"==typeof e&&(e=t[e]),t)\"em\"!==n&&(r[n]=t[n]-e);return r}function a(t){for(var e=t.height,r=t.data,n=3;n<r.length;n+=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}function o(t){for(var e=t.height,r=t.data,n=r.length-1;n>0;n-=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}e.exports=n,n.canvas=document.createElement(\"canvas\"),n.cache={}},{}],230:[function(t,e,r){\"use strict\";e.exports=function(t){return new c(t||d,null)};var n=0,i=1;function a(t,e,r,n,i,a){this._color=t,this.key=e,this.value=r,this.left=n,this.right=i,this._count=a}function o(t){return new a(t._color,t.key,t.value,t.left,t.right,t._count)}function s(t,e){return new a(t,e.key,e.value,e.left,e.right,e._count)}function l(t){t._count=1+(t.left?t.left._count:0)+(t.right?t.right._count:0)}function c(t,e){this._compare=t,this.root=e}var u=c.prototype;function h(t,e){this.tree=t,this._stack=e}Object.defineProperty(u,\"keys\",{get:function(){var t=[];return this.forEach(function(e,r){t.push(e)}),t}}),Object.defineProperty(u,\"values\",{get:function(){var t=[];return this.forEach(function(e,r){t.push(r)}),t}}),Object.defineProperty(u,\"length\",{get:function(){return this.root?this.root._count:0}}),u.insert=function(t,e){for(var r=this._compare,o=this.root,u=[],h=[];o;){var f=r(t,o.key);u.push(o),h.push(f),o=f<=0?o.left:o.right}u.push(new a(n,t,e,null,null,1));for(var p=u.length-2;p>=0;--p){o=u[p];h[p]<=0?u[p]=new a(o._color,o.key,o.value,u[p+1],o.right,o._count+1):u[p]=new a(o._color,o.key,o.value,o.left,u[p+1],o._count+1)}for(p=u.length-1;p>1;--p){var d=u[p-1];o=u[p];if(d._color===i||o._color===i)break;var g=u[p-2];if(g.left===d)if(d.left===o){if(!(v=g.right)||v._color!==n){if(g._color=n,g.left=d.right,d._color=i,d.right=g,u[p-2]=d,u[p-1]=o,l(g),l(d),p>=3)(m=u[p-3]).left===g?m.left=d:m.right=d;break}d._color=i,g.right=s(i,v),g._color=n,p-=1}else{if(!(v=g.right)||v._color!==n){if(d.right=o.left,g._color=n,g.left=o.right,o._color=i,o.left=d,o.right=g,u[p-2]=o,u[p-1]=d,l(g),l(d),l(o),p>=3)(m=u[p-3]).left===g?m.left=o:m.right=o;break}d._color=i,g.right=s(i,v),g._color=n,p-=1}else if(d.right===o){if(!(v=g.left)||v._color!==n){if(g._color=n,g.right=d.left,d._color=i,d.left=g,u[p-2]=d,u[p-1]=o,l(g),l(d),p>=3)(m=u[p-3]).right===g?m.right=d:m.left=d;break}d._color=i,g.left=s(i,v),g._color=n,p-=1}else{var v;if(!(v=g.left)||v._color!==n){var m;if(d.left=o.right,g._color=n,g.right=o.left,o._color=i,o.right=d,o.left=g,u[p-2]=o,u[p-1]=d,l(g),l(d),l(o),p>=3)(m=u[p-3]).right===g?m.right=o:m.left=o;break}d._color=i,g.left=s(i,v),g._color=n,p-=1}}return u[0]._color=i,new c(r,u[0])},u.forEach=function(t,e,r){if(this.root)switch(arguments.length){case 1:return function t(e,r){var n;if(r.left&&(n=t(e,r.left)))return n;return(n=e(r.key,r.value))||(r.right?t(e,r.right):void 0)}(t,this.root);case 2:return function t(e,r,n,i){if(r(e,i.key)<=0){var a;if(i.left&&(a=t(e,r,n,i.left)))return a;if(a=n(i.key,i.value))return a}if(i.right)return t(e,r,n,i.right)}(e,this._compare,t,this.root);case 3:if(this._compare(e,r)>=0)return;return function t(e,r,n,i,a){var o,s=n(e,a.key),l=n(r,a.key);if(s<=0){if(a.left&&(o=t(e,r,n,i,a.left)))return o;if(l>0&&(o=i(a.key,a.value)))return o}if(l>0&&a.right)return t(e,r,n,i,a.right)}(e,r,this._compare,t,this.root)}},Object.defineProperty(u,\"begin\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.left;return new h(this,t)}}),Object.defineProperty(u,\"end\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.right;return new h(this,t)}}),u.at=function(t){if(t<0)return new h(this,[]);for(var e=this.root,r=[];;){if(r.push(e),e.left){if(t<e.left._count){e=e.left;continue}t-=e.left._count}if(!t)return new h(this,r);if(t-=1,!e.right)break;if(t>=e.right._count)break;e=e.right}return new h(this,[])},u.ge=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<=0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},u.gt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},u.lt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},u.le=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>=0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},u.find=function(t){for(var e=this._compare,r=this.root,n=[];r;){var i=e(t,r.key);if(n.push(r),0===i)return new h(this,n);r=i<=0?r.left:r.right}return new h(this,[])},u.remove=function(t){var e=this.find(t);return e?e.remove():this},u.get=function(t){for(var e=this._compare,r=this.root;r;){var n=e(t,r.key);if(0===n)return r.value;r=n<=0?r.left:r.right}};var f=h.prototype;function p(t,e){t.key=e.key,t.value=e.value,t.left=e.left,t.right=e.right,t._color=e._color,t._count=e._count}function d(t,e){return t<e?-1:t>e?1:0}Object.defineProperty(f,\"valid\",{get:function(){return this._stack.length>0}}),Object.defineProperty(f,\"node\",{get:function(){return this._stack.length>0?this._stack[this._stack.length-1]:null},enumerable:!0}),f.clone=function(){return new h(this.tree,this._stack.slice())},f.remove=function(){var t=this._stack;if(0===t.length)return this.tree;var e=new Array(t.length),r=t[t.length-1];e[e.length-1]=new a(r._color,r.key,r.value,r.left,r.right,r._count);for(var u=t.length-2;u>=0;--u){(r=t[u]).left===t[u+1]?e[u]=new a(r._color,r.key,r.value,e[u+1],r.right,r._count):e[u]=new a(r._color,r.key,r.value,r.left,e[u+1],r._count)}if((r=e[e.length-1]).left&&r.right){var h=e.length;for(r=r.left;r.right;)e.push(r),r=r.right;var f=e[h-1];e.push(new a(r._color,f.key,f.value,r.left,r.right,r._count)),e[h-1].key=r.key,e[h-1].value=r.value;for(u=e.length-2;u>=h;--u)r=e[u],e[u]=new a(r._color,r.key,r.value,r.left,e[u+1],r._count);e[h-1].left=e[h]}if((r=e[e.length-1])._color===n){var d=e[e.length-2];d.left===r?d.left=null:d.right===r&&(d.right=null),e.pop();for(u=0;u<e.length;++u)e[u]._count--;return new c(this.tree._compare,e[0])}if(r.left||r.right){r.left?p(r,r.left):r.right&&p(r,r.right),r._color=i;for(u=0;u<e.length-1;++u)e[u]._count--;return new c(this.tree._compare,e[0])}if(1===e.length)return new c(this.tree._compare,null);for(u=0;u<e.length;++u)e[u]._count--;var g=e[e.length-2];return function(t){for(var e,r,a,c,u=t.length-1;u>=0;--u){if(e=t[u],0===u)return void(e._color=i);if((r=t[u-1]).left===e){if((a=r.right).right&&a.right._color===n)return c=(a=r.right=o(a)).right=o(a.right),r.right=a.left,a.left=r,a.right=c,a._color=r._color,e._color=i,r._color=i,c._color=i,l(r),l(a),u>1&&((h=t[u-2]).left===r?h.left=a:h.right=a),void(t[u-1]=a);if(a.left&&a.left._color===n)return c=(a=r.right=o(a)).left=o(a.left),r.right=c.left,a.left=c.right,c.left=r,c.right=a,c._color=r._color,r._color=i,a._color=i,e._color=i,l(r),l(a),l(c),u>1&&((h=t[u-2]).left===r?h.left=c:h.right=c),void(t[u-1]=c);if(a._color===i){if(r._color===n)return r._color=i,void(r.right=s(n,a));r.right=s(n,a);continue}a=o(a),r.right=a.left,a.left=r,a._color=r._color,r._color=n,l(r),l(a),u>1&&((h=t[u-2]).left===r?h.left=a:h.right=a),t[u-1]=a,t[u]=r,u+1<t.length?t[u+1]=e:t.push(e),u+=2}else{if((a=r.left).left&&a.left._color===n)return c=(a=r.left=o(a)).left=o(a.left),r.left=a.right,a.right=r,a.left=c,a._color=r._color,e._color=i,r._color=i,c._color=i,l(r),l(a),u>1&&((h=t[u-2]).right===r?h.right=a:h.left=a),void(t[u-1]=a);if(a.right&&a.right._color===n)return c=(a=r.left=o(a)).right=o(a.right),r.left=c.right,a.right=c.left,c.right=r,c.left=a,c._color=r._color,r._color=i,a._color=i,e._color=i,l(r),l(a),l(c),u>1&&((h=t[u-2]).right===r?h.right=c:h.left=c),void(t[u-1]=c);if(a._color===i){if(r._color===n)return r._color=i,void(r.left=s(n,a));r.left=s(n,a);continue}var h;a=o(a),r.left=a.right,a.right=r,a._color=r._color,r._color=n,l(r),l(a),u>1&&((h=t[u-2]).right===r?h.right=a:h.left=a),t[u-1]=a,t[u]=r,u+1<t.length?t[u+1]=e:t.push(e),u+=2}}}(e),g.left===r?g.left=null:g.right=null,new c(this.tree._compare,e[0])},Object.defineProperty(f,\"key\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].key},enumerable:!0}),Object.defineProperty(f,\"value\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].value},enumerable:!0}),Object.defineProperty(f,\"index\",{get:function(){var t=0,e=this._stack;if(0===e.length){var r=this.tree.root;return r?r._count:0}e[e.length-1].left&&(t=e[e.length-1].left._count);for(var n=e.length-2;n>=0;--n)e[n+1]===e[n].right&&(++t,e[n].left&&(t+=e[n].left._count));return t},enumerable:!0}),f.next=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.right)for(e=e.right;e;)t.push(e),e=e.left;else for(t.pop();t.length>0&&t[t.length-1].right===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(f,\"hasNext\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].right)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].left===t[e])return!0;return!1}}),f.update=function(t){var e=this._stack;if(0===e.length)throw new Error(\"Can't update empty node!\");var r=new Array(e.length),n=e[e.length-1];r[r.length-1]=new a(n._color,n.key,t,n.left,n.right,n._count);for(var i=e.length-2;i>=0;--i)(n=e[i]).left===e[i+1]?r[i]=new a(n._color,n.key,n.value,r[i+1],n.right,n._count):r[i]=new a(n._color,n.key,n.value,n.left,r[i+1],n._count);return new c(this.tree._compare,r[0])},f.prev=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.left)for(e=e.left;e;)t.push(e),e=e.right;else for(t.pop();t.length>0&&t[t.length-1].left===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(f,\"hasPrev\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].left)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].right===t[e])return!0;return!1}})},{}],231:[function(t,e,r){var n=[.9999999999998099,676.5203681218851,-1259.1392167224028,771.3234287776531,-176.6150291621406,12.507343278686905,-.13857109526572012,9984369578019572e-21,1.5056327351493116e-7],i=607/128,a=[.9999999999999971,57.15623566586292,-59.59796035547549,14.136097974741746,-.4919138160976202,3399464998481189e-20,4652362892704858e-20,-9837447530487956e-20,.0001580887032249125,-.00021026444172410488,.00021743961811521265,-.0001643181065367639,8441822398385275e-20,-26190838401581408e-21,36899182659531625e-22];function o(t){if(t<0)return Number(\"0/0\");for(var e=a[0],r=a.length-1;r>0;--r)e+=a[r]/(t+r);var n=t+i+.5;return.5*Math.log(2*Math.PI)+(t+.5)*Math.log(n)-n+Math.log(e)-Math.log(t)}e.exports=function t(e){if(e<.5)return Math.PI/(Math.sin(Math.PI*e)*t(1-e));if(e>100)return Math.exp(o(e));e-=1;for(var r=n[0],i=1;i<9;i++)r+=n[i]/(e+i);var a=e+7+.5;return Math.sqrt(2*Math.PI)*Math.pow(a,e+.5)*Math.exp(-a)*r},e.exports.log=o},{}],232:[function(t,e,r){e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"must specify type string\");if(e=e||{},\"undefined\"==typeof document&&!e.canvas)return null;var r=e.canvas||document.createElement(\"canvas\");\"number\"==typeof e.width&&(r.width=e.width);\"number\"==typeof e.height&&(r.height=e.height);var n,i=e;try{var a=[t];0===t.indexOf(\"webgl\")&&a.push(\"experimental-\"+t);for(var o=0;o<a.length;o++)if(n=r.getContext(a[o],i))return n}catch(t){n=null}return n||null}},{}],233:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=new u(t);return r.update(e),r};var n=t(\"./lib/text.js\"),i=t(\"./lib/lines.js\"),a=t(\"./lib/background.js\"),o=t(\"./lib/cube.js\"),s=t(\"./lib/ticks.js\"),l=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]);function c(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function u(t){this.gl=t,this.pixelRatio=1,this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.autoTicks=!0,this.tickSpacing=[1,1,1],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickAlign=[\"auto\",\"auto\",\"auto\"],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[10,10,10],this.lastCubeProps={cubeEdges:[0,0,0],axis:[0,0,0]},this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=\"sans-serif\",this.labelSize=[20,20,20],this.labelAngle=[0,0,0],this.labelAlign=[\"auto\",\"auto\",\"auto\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[10,10,10],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[0,0,0],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!1,!1,!1],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._firstInit=!0,this._text=null,this._lines=null,this._background=a(t)}var h=u.prototype;function f(){this.primalOffset=[0,0,0],this.primalMinor=[0,0,0],this.mirrorOffset=[0,0,0],this.mirrorMinor=[0,0,0]}h.update=function(t){function e(e,r,n){if(n in t){var i,a=t[n],o=this[n];(e?Array.isArray(a)&&Array.isArray(a[0]):Array.isArray(a))?this[n]=i=[r(a[0]),r(a[1]),r(a[2])]:this[n]=i=[r(a),r(a),r(a)];for(var s=0;s<3;++s)if(i[s]!==o[s])return!0}return!1}t=t||{};var r,a=e.bind(this,!1,Number),o=e.bind(this,!1,Boolean),l=e.bind(this,!1,String),c=e.bind(this,!0,function(t){if(Array.isArray(t)){if(3===t.length)return[+t[0],+t[1],+t[2],1];if(4===t.length)return[+t[0],+t[1],+t[2],+t[3]]}return[0,0,0,1]}),u=!1,h=!1;if(\"bounds\"in t)for(var f=t.bounds,p=0;p<2;++p)for(var d=0;d<3;++d)f[p][d]!==this.bounds[p][d]&&(h=!0),this.bounds[p][d]=f[p][d];if(\"ticks\"in t){r=t.ticks,u=!0,this.autoTicks=!1;for(p=0;p<3;++p)this.tickSpacing[p]=0}else a(\"tickSpacing\")&&(this.autoTicks=!0,h=!0);if(this._firstInit&&(\"ticks\"in t||\"tickSpacing\"in t||(this.autoTicks=!0),h=!0,u=!0,this._firstInit=!1),h&&this.autoTicks&&(r=s.create(this.bounds,this.tickSpacing),u=!0),u){for(p=0;p<3;++p)r[p].sort(function(t,e){return t.x-e.x});s.equal(r,this.ticks)?u=!1:this.ticks=r}o(\"tickEnable\"),l(\"tickFont\")&&(u=!0),a(\"tickSize\"),a(\"tickAngle\"),a(\"tickPad\"),c(\"tickColor\");var g=l(\"labels\");l(\"labelFont\")&&(g=!0),o(\"labelEnable\"),a(\"labelSize\"),a(\"labelPad\"),c(\"labelColor\"),o(\"lineEnable\"),o(\"lineMirror\"),a(\"lineWidth\"),c(\"lineColor\"),o(\"lineTickEnable\"),o(\"lineTickMirror\"),a(\"lineTickLength\"),a(\"lineTickWidth\"),c(\"lineTickColor\"),o(\"gridEnable\"),a(\"gridWidth\"),c(\"gridColor\"),o(\"zeroEnable\"),c(\"zeroLineColor\"),a(\"zeroLineWidth\"),o(\"backgroundEnable\"),c(\"backgroundColor\"),this._text?this._text&&(g||u)&&this._text.update(this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont):this._text=n(this.gl,this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont),this._lines&&u&&(this._lines.dispose(),this._lines=null),this._lines||(this._lines=i(this.gl,this.bounds,this.ticks))};var p=[new f,new f,new f];function d(t,e,r,n,i){for(var a=t.primalOffset,o=t.primalMinor,s=t.mirrorOffset,l=t.mirrorMinor,c=n[e],u=0;u<3;++u)if(e!==u){var h=a,f=s,p=o,d=l;c&1<<u&&(h=s,f=a,p=l,d=o),h[u]=r[0][u],f[u]=r[1][u],i[u]>0?(p[u]=-1,d[u]=0):(p[u]=0,d[u]=1)}}var g=[0,0,0],v={model:l,view:l,projection:l,_ortho:!1};h.isOpaque=function(){return!0},h.isTransparent=function(){return!1},h.drawTransparent=function(t){};var m=[0,0,0],y=[0,0,0],x=[0,0,0];h.draw=function(t){t=t||v;for(var e=this.gl,r=t.model||l,n=t.view||l,i=t.projection||l,a=this.bounds,s=t._ortho||!1,u=o(r,n,i,a,s),h=u.cubeEdges,f=u.axis,b=n[12],_=n[13],w=n[14],k=n[15],T=(s?2:1)*this.pixelRatio*(i[3]*b+i[7]*_+i[11]*w+i[15]*k)/e.drawingBufferHeight,A=0;A<3;++A)this.lastCubeProps.cubeEdges[A]=h[A],this.lastCubeProps.axis[A]=f[A];var M=p;for(A=0;A<3;++A)d(p[A],A,this.bounds,h,f);e=this.gl;var S,E=g;for(A=0;A<3;++A)this.backgroundEnable[A]?E[A]=f[A]:E[A]=0;this._background.draw(r,n,i,a,E,this.backgroundColor),this._lines.bind(r,n,i,this);for(A=0;A<3;++A){var C=[0,0,0];f[A]>0?C[A]=a[1][A]:C[A]=a[0][A];for(var L=0;L<2;++L){var P=(A+1+L)%3,O=(A+1+(1^L))%3;this.gridEnable[P]&&this._lines.drawGrid(P,O,this.bounds,C,this.gridColor[P],this.gridWidth[P]*this.pixelRatio)}for(L=0;L<2;++L){P=(A+1+L)%3,O=(A+1+(1^L))%3;this.zeroEnable[O]&&Math.min(a[0][O],a[1][O])<=0&&Math.max(a[0][O],a[1][O])>=0&&this._lines.drawZero(P,O,this.bounds,C,this.zeroLineColor[O],this.zeroLineWidth[O]*this.pixelRatio)}}for(A=0;A<3;++A){this.lineEnable[A]&&this._lines.drawAxisLine(A,this.bounds,M[A].primalOffset,this.lineColor[A],this.lineWidth[A]*this.pixelRatio),this.lineMirror[A]&&this._lines.drawAxisLine(A,this.bounds,M[A].mirrorOffset,this.lineColor[A],this.lineWidth[A]*this.pixelRatio);var z=c(m,M[A].primalMinor),I=c(y,M[A].mirrorMinor),D=this.lineTickLength;for(L=0;L<3;++L){var R=T/r[5*L];z[L]*=D[L]*R,I[L]*=D[L]*R}this.lineTickEnable[A]&&this._lines.drawAxisTicks(A,M[A].primalOffset,z,this.lineTickColor[A],this.lineTickWidth[A]*this.pixelRatio),this.lineTickMirror[A]&&this._lines.drawAxisTicks(A,M[A].mirrorOffset,I,this.lineTickColor[A],this.lineTickWidth[A]*this.pixelRatio)}this._lines.unbind(),this._text.bind(r,n,i,this.pixelRatio);var F,B;function N(t){(B=[0,0,0])[t]=1}function j(t,e,r){var n=(t+1)%3,i=(t+2)%3,a=e[n],o=e[i],s=r[n],l=r[i];a>0&&l>0?N(n):a>0&&l<0?N(n):a<0&&l>0?N(n):a<0&&l<0?N(n):o>0&&s>0?N(i):o>0&&s<0?N(i):o<0&&s>0?N(i):o<0&&s<0&&N(i)}for(A=0;A<3;++A){var U=M[A].primalMinor,V=M[A].mirrorMinor,q=c(x,M[A].primalOffset);for(L=0;L<3;++L)this.lineTickEnable[A]&&(q[L]+=T*U[L]*Math.max(this.lineTickLength[L],0)/r[5*L]);var H=[0,0,0];if(H[A]=1,this.tickEnable[A]){-3600===this.tickAngle[A]?(this.tickAngle[A]=0,this.tickAlign[A]=\"auto\"):this.tickAlign[A]=-1,F=1,\"auto\"===(S=[this.tickAlign[A],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]),B=[0,0,0],j(A,U,V);for(L=0;L<3;++L)q[L]+=T*U[L]*this.tickPad[L]/r[5*L];this._text.drawTicks(A,this.tickSize[A],this.tickAngle[A],q,this.tickColor[A],H,B,S)}if(this.labelEnable[A]){F=0,B=[0,0,0],this.labels[A].length>4&&(N(A),F=1),\"auto\"===(S=[this.labelAlign[A],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]);for(L=0;L<3;++L)q[L]+=T*U[L]*this.labelPad[L]/r[5*L];q[A]+=.5*(a[0][A]+a[1][A]),this._text.drawLabel(A,this.labelSize[A],this.labelAngle[A],q,this.labelColor[A],[0,0,0],B,S)}}this._text.unbind()},h.dispose=function(){this._text.dispose(),this._lines.dispose(),this._background.dispose(),this._lines=null,this._text=null,this._background=null,this.gl=null}},{\"./lib/background.js\":234,\"./lib/cube.js\":235,\"./lib/lines.js\":236,\"./lib/text.js\":238,\"./lib/ticks.js\":239}],234:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=[],r=[],s=0,l=0;l<3;++l)for(var c=(l+1)%3,u=(l+2)%3,h=[0,0,0],f=[0,0,0],p=-1;p<=1;p+=2){r.push(s,s+2,s+1,s+1,s+2,s+3),h[l]=p,f[l]=p;for(var d=-1;d<=1;d+=2){h[c]=d;for(var g=-1;g<=1;g+=2)h[u]=g,e.push(h[0],h[1],h[2],f[0],f[1],f[2]),s+=1}var v=c;c=u,u=v}var m=n(t,new Float32Array(e)),y=n(t,new Uint16Array(r),t.ELEMENT_ARRAY_BUFFER),x=i(t,[{buffer:m,type:t.FLOAT,size:3,offset:0,stride:24},{buffer:m,type:t.FLOAT,size:3,offset:12,stride:24}],y),b=a(t);return b.attributes.position.location=0,b.attributes.normal.location=1,new o(t,m,x,b)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").bg;function o(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n}var s=o.prototype;s.draw=function(t,e,r,n,i,a){for(var o=!1,s=0;s<3;++s)o=o||i[s];if(o){var l=this.gl;l.enable(l.POLYGON_OFFSET_FILL),l.polygonOffset(1,2),this.shader.bind(),this.shader.uniforms={model:t,view:e,projection:r,bounds:n,enable:i,colors:a},this.vao.bind(),this.vao.draw(this.gl.TRIANGLES,36),this.vao.unbind(),l.disable(l.POLYGON_OFFSET_FILL)}},s.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders\":237,\"gl-buffer\":241,\"gl-vao\":327}],235:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,p){i(s,e,t),i(s,r,s);for(var y=0,x=0;x<2;++x){u[2]=a[x][2];for(var b=0;b<2;++b){u[1]=a[b][1];for(var _=0;_<2;++_)u[0]=a[_][0],f(l[y],u,s),y+=1}}for(var w=-1,x=0;x<8;++x){for(var k=l[x][3],T=0;T<3;++T)c[x][T]=l[x][T]/k;p&&(c[x][2]*=-1),k<0&&(w<0?w=x:c[x][2]<c[w][2]&&(w=x))}if(w<0){w=0;for(var A=0;A<3;++A){for(var M=(A+2)%3,S=(A+1)%3,E=-1,C=-1,L=0;L<2;++L){var P=L<<A,O=P+(L<<M)+(1-L<<S),z=P+(1-L<<M)+(L<<S);o(c[P],c[O],c[z],h)<0||(L?E=1:C=1)}if(E<0||C<0)C>E&&(w|=1<<A);else{for(var L=0;L<2;++L){var P=L<<A,O=P+(L<<M)+(1-L<<S),z=P+(1-L<<M)+(L<<S),I=d([l[P],l[O],l[z],l[P+(1<<M)+(1<<S)]]);L?E=I:C=I}C>E&&(w|=1<<A)}}}for(var D=7^w,R=-1,x=0;x<8;++x)x!==w&&x!==D&&(R<0?R=x:c[R][1]>c[x][1]&&(R=x));for(var F=-1,x=0;x<3;++x){var B=R^1<<x;if(B!==w&&B!==D){F<0&&(F=B);var S=c[B];S[0]<c[F][0]&&(F=B)}}for(var N=-1,x=0;x<3;++x){var B=R^1<<x;if(B!==w&&B!==D&&B!==F){N<0&&(N=B);var S=c[B];S[0]>c[N][0]&&(N=B)}}var j=g;j[0]=j[1]=j[2]=0,j[n.log2(F^R)]=R&F,j[n.log2(R^N)]=R&N;var U=7^N;U===w||U===D?(U=7^F,j[n.log2(N^U)]=U&N):j[n.log2(F^U)]=U&F;for(var V=v,q=w,A=0;A<3;++A)V[A]=q&1<<A?-1:1;return m};var n=t(\"bit-twiddle\"),i=t(\"gl-mat4/multiply\"),a=t(\"split-polygon\"),o=t(\"robust-orientation\"),s=new Array(16),l=new Array(8),c=new Array(8),u=new Array(3),h=[0,0,0];function f(t,e,r){for(var n=0;n<4;++n){t[n]=r[12+n];for(var i=0;i<3;++i)t[n]+=e[i]*r[4*i+n]}}!function(){for(var t=0;t<8;++t)l[t]=[1,1,1,1],c[t]=[1,1,1]}();var p=[[0,0,1,0,0],[0,0,-1,1,0],[0,-1,0,1,0],[0,1,0,1,0],[-1,0,0,1,0],[1,0,0,1,0]];function d(t){for(var e=0;e<p.length;++e)if((t=a.positive(t,p[e])).length<3)return 0;var r=t[0],n=r[0]/r[3],i=r[1]/r[3],o=0;for(e=1;e+1<t.length;++e){var s=t[e],l=t[e+1],c=s[0]/s[3]-n,u=s[1]/s[3]-i,h=l[0]/l[3]-n,f=l[1]/l[3]-i;o+=Math.abs(c*f-u*h)}return o}var g=[1,1,1],v=[0,0,0],m={cubeEdges:g,axis:v}},{\"bit-twiddle\":92,\"gl-mat4/multiply\":267,\"robust-orientation\":510,\"split-polygon\":527}],236:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var o=[],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[0,0,0];o.push(0,0,1,0,1,1,0,0,-1,0,0,-1,0,1,1,0,1,-1);for(var h=0;h<3;++h){for(var f=o.length/3|0,d=0;d<r[h].length;++d){var g=+r[h][d].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var v=o.length/3|0;s[h]=f,l[h]=v-f;for(var f=o.length/3|0,m=0;m<r[h].length;++m){var g=+r[h][m].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var v=o.length/3|0;c[h]=f,u[h]=v-f}var y=n(t,new Float32Array(o)),x=i(t,[{buffer:y,type:t.FLOAT,size:3,stride:0,offset:0}]),b=a(t);return b.attributes.position.location=0,new p(t,y,x,b,l,s,u,c)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").line,o=[0,0,0],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[1,1];function h(t){return t[0]=t[1]=t[2]=0,t}function f(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function p(t,e,r,n,i,a,o,s){this.gl=t,this.vertBuffer=e,this.vao=r,this.shader=n,this.tickCount=i,this.tickOffset=a,this.gridCount=o,this.gridOffset=s}var d=p.prototype;d.bind=function(t,e,r){this.shader.bind(),this.shader.uniforms.model=t,this.shader.uniforms.view=e,this.shader.uniforms.projection=r,u[0]=this.gl.drawingBufferWidth,u[1]=this.gl.drawingBufferHeight,this.shader.uniforms.screenShape=u,this.vao.bind()},d.unbind=function(){this.vao.unbind()},d.drawAxisLine=function(t,e,r,n,i){var a=h(s);this.shader.uniforms.majorAxis=s,a[t]=e[1][t]-e[0][t],this.shader.uniforms.minorAxis=a;var o,u=f(c,r);u[t]+=e[0][t],this.shader.uniforms.offset=u,this.shader.uniforms.lineWidth=i,this.shader.uniforms.color=n,(o=h(l))[(t+2)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6),(o=h(l))[(t+1)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6)},d.drawAxisTicks=function(t,e,r,n,i){if(this.tickCount[t]){var a=h(o);a[t]=1,this.shader.uniforms.majorAxis=a,this.shader.uniforms.offset=e,this.shader.uniforms.minorAxis=r,this.shader.uniforms.color=n,this.shader.uniforms.lineWidth=i;var s=h(l);s[t]=1,this.shader.uniforms.screenAxis=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t])}},d.drawGrid=function(t,e,r,n,i,a){if(this.gridCount[t]){var u=h(s);u[e]=r[1][e]-r[0][e],this.shader.uniforms.minorAxis=u;var p=f(c,n);p[e]+=r[0][e],this.shader.uniforms.offset=p;var d=h(o);d[t]=1,this.shader.uniforms.majorAxis=d;var g=h(l);g[t]=1,this.shader.uniforms.screenAxis=g,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,this.gridCount[t],this.gridOffset[t])}},d.drawZero=function(t,e,r,n,i,a){var o=h(s);this.shader.uniforms.majorAxis=o,o[t]=r[1][t]-r[0][t],this.shader.uniforms.minorAxis=o;var u=f(c,n);u[t]+=r[0][t],this.shader.uniforms.offset=u;var p=h(l);p[e]=1,this.shader.uniforms.screenAxis=p,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,6)},d.dispose=function(){this.vao.dispose(),this.vertBuffer.dispose(),this.shader.dispose()}},{\"./shaders\":237,\"gl-buffer\":241,\"gl-vao\":327}],237:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, majorAxis, minorAxis, screenAxis;\\nuniform float lineWidth;\\nuniform vec2 screenShape;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nvoid main() {\\n  vec3 major = position.x * majorAxis;\\n  vec3 minor = position.y * minorAxis;\\n\\n  vec3 vPosition = major + minor + offset;\\n  vec3 pPosition = project(vPosition);\\n  vec3 offset = project(vPosition + screenAxis * position.z);\\n\\n  vec2 screen = normalize((offset - pPosition).xy * screenShape) / screenShape;\\n\\n  gl_Position = vec4(pPosition + vec3(0.5 * screen * lineWidth, 0), 1.0);\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.line=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"}])};var s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, axis, alignDir, alignOpt;\\nuniform float scale, angle, pixelScale;\\nuniform vec2 resolution;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nfloat computeViewAngle(vec3 a, vec3 b) {\\n  vec3 A = project(a);\\n  vec3 B = project(b);\\n\\n  return atan(\\n    (B.y - A.y) * resolution.y,\\n    (B.x - A.x) * resolution.x\\n  );\\n}\\n\\nconst float PI = 3.141592;\\nconst float TWO_PI = 2.0 * PI;\\nconst float HALF_PI = 0.5 * PI;\\nconst float ONE_AND_HALF_PI = 1.5 * PI;\\n\\nint option = int(floor(alignOpt.x + 0.001));\\nfloat hv_ratio =       alignOpt.y;\\nbool enableAlign =    (alignOpt.z != 0.0);\\n\\nfloat mod_angle(float a) {\\n  return mod(a, PI);\\n}\\n\\nfloat positive_angle(float a) {\\n  return mod_angle((a < 0.0) ?\\n    a + TWO_PI :\\n    a\\n  );\\n}\\n\\nfloat look_upwards(float a) {\\n  float b = positive_angle(a);\\n  return ((b > HALF_PI) && (b <= ONE_AND_HALF_PI)) ?\\n    b - PI :\\n    b;\\n}\\n\\nfloat look_horizontal_or_vertical(float a, float ratio) {\\n  // ratio controls the ratio between being horizontal to (vertical + horizontal)\\n  // if ratio is set to 0.5 then it is 50%, 50%.\\n  // when using a higher ratio e.g. 0.75 the result would\\n  // likely be more horizontal than vertical.\\n\\n  float b = positive_angle(a);\\n\\n  return\\n    (b < (      ratio) * HALF_PI) ? 0.0 :\\n    (b < (2.0 - ratio) * HALF_PI) ? -HALF_PI :\\n    (b < (2.0 + ratio) * HALF_PI) ? 0.0 :\\n    (b < (4.0 - ratio) * HALF_PI) ? HALF_PI :\\n                                    0.0;\\n}\\n\\nfloat roundTo(float a, float b) {\\n  return float(b * floor((a + 0.5 * b) / b));\\n}\\n\\nfloat look_round_n_directions(float a, int n) {\\n  float b = positive_angle(a);\\n  float div = TWO_PI / float(n);\\n  float c = roundTo(b, div);\\n  return look_upwards(c);\\n}\\n\\nfloat applyAlignOption(float rawAngle, float delta) {\\n  return\\n    (option >  2) ? look_round_n_directions(rawAngle + delta, option) :       // option 3-n: round to n directions\\n    (option == 2) ? look_horizontal_or_vertical(rawAngle + delta, hv_ratio) : // horizontal or vertical\\n    (option == 1) ? rawAngle + delta :       // use free angle, and flip to align with one direction of the axis\\n    (option == 0) ? look_upwards(rawAngle) : // use free angle, and stay upwards\\n    (option ==-1) ? 0.0 :                    // useful for backward compatibility, all texts remains horizontal\\n                    rawAngle;                // otherwise return back raw input angle\\n}\\n\\nbool isAxisTitle = (axis.x == 0.0) &&\\n                   (axis.y == 0.0) &&\\n                   (axis.z == 0.0);\\n\\nvoid main() {\\n  //Compute world offset\\n  float axisDistance = position.z;\\n  vec3 dataPosition = axisDistance * axis + offset;\\n\\n  float beta = angle; // i.e. user defined attributes for each tick\\n\\n  float axisAngle;\\n  float clipAngle;\\n  float flip;\\n\\n  if (enableAlign) {\\n    axisAngle = (isAxisTitle) ? HALF_PI :\\n                      computeViewAngle(dataPosition, dataPosition + axis);\\n    clipAngle = computeViewAngle(dataPosition, dataPosition + alignDir);\\n\\n    axisAngle += (sin(axisAngle) < 0.0) ? PI : 0.0;\\n    clipAngle += (sin(clipAngle) < 0.0) ? PI : 0.0;\\n\\n    flip = (dot(vec2(cos(axisAngle), sin(axisAngle)),\\n                vec2(sin(clipAngle),-cos(clipAngle))) > 0.0) ? 1.0 : 0.0;\\n\\n    beta += applyAlignOption(clipAngle, flip * PI);\\n  }\\n\\n  //Compute plane offset\\n  vec2 planeCoord = position.xy * pixelScale;\\n\\n  mat2 planeXform = scale * mat2(\\n     cos(beta), sin(beta),\\n    -sin(beta), cos(beta)\\n  );\\n\\n  vec2 viewOffset = 2.0 * planeXform * planeCoord / resolution;\\n\\n  //Compute clip position\\n  vec3 clipPosition = project(dataPosition);\\n\\n  //Apply text offset in clip coordinates\\n  clipPosition += vec3(viewOffset, 0.0);\\n\\n  //Done\\n  gl_Position = vec4(clipPosition, 1.0);\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.text=function(t){return i(t,s,l,null,[{name:\"position\",type:\"vec3\"}])};var c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec3 normal;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 enable;\\nuniform vec3 bounds[2];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n\\n  vec3 signAxis = sign(bounds[1] - bounds[0]);\\n\\n  vec3 realNormal = signAxis * normal;\\n\\n  if(dot(realNormal, enable) > 0.0) {\\n    vec3 minRange = min(bounds[0], bounds[1]);\\n    vec3 maxRange = max(bounds[0], bounds[1]);\\n    vec3 nPosition = mix(minRange, maxRange, 0.5 * (position + 1.0));\\n    gl_Position = projection * view * model * vec4(nPosition, 1.0);\\n  } else {\\n    gl_Position = vec4(0,0,0,0);\\n  }\\n\\n  colorChannel = abs(realNormal);\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 colors[3];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n  gl_FragColor = colorChannel.x * colors[0] +\\n                 colorChannel.y * colors[1] +\\n                 colorChannel.z * colors[2];\\n}\"]);r.bg=function(t){return i(t,c,u,null,[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}])}},{\"gl-shader\":301,glslify:409}],238:[function(t,e,r){(function(r){\"use strict\";e.exports=function(t,e,r,a,s,l){var u=n(t),h=i(t,[{buffer:u,size:3}]),f=o(t);f.attributes.position.location=0;var p=new c(t,f,u,h);return p.update(e,r,a,s,l),p};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"vectorize-text\"),o=t(\"./shaders\").text,s=window||r.global||{},l=s.__TEXT_CACHE||{};s.__TEXT_CACHE={};function c(t,e,r,n){this.gl=t,this.shader=e,this.buffer=r,this.vao=n,this.tickOffset=this.tickCount=this.labelOffset=this.labelCount=null}var u=c.prototype,h=[0,0];u.bind=function(t,e,r,n){this.vao.bind(),this.shader.bind();var i=this.shader.uniforms;i.model=t,i.view=e,i.projection=r,i.pixelScale=n,h[0]=this.gl.drawingBufferWidth,h[1]=this.gl.drawingBufferHeight,this.shader.uniforms.resolution=h},u.unbind=function(){this.vao.unbind()},u.update=function(t,e,r,n,i){var o=[];function s(t,e,r,n,i,s){var c=l[r];c||(c=l[r]={});var u=c[e];u||(u=c[e]=function(t,e){try{return a(t,e)}catch(e){return console.warn('error vectorizing text:\"'+t+'\" error:',e),{cells:[],positions:[]}}}(e,{triangles:!0,font:r,textAlign:\"center\",textBaseline:\"middle\",lineSpacing:i,styletags:s}));for(var h=(n||12)/12,f=u.positions,p=u.cells,d=0,g=p.length;d<g;++d)for(var v=p[d],m=2;m>=0;--m){var y=f[v[m]];o.push(h*y[0],-h*y[1],t)}}for(var c=[0,0,0],u=[0,0,0],h=[0,0,0],f=[0,0,0],p={breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},d=0;d<3;++d){h[d]=o.length/3|0,s(.5*(t[0][d]+t[1][d]),e[d],r[d],12,1.25,p),f[d]=(o.length/3|0)-h[d],c[d]=o.length/3|0;for(var g=0;g<n[d].length;++g)n[d][g].text&&s(n[d][g].x,n[d][g].text,n[d][g].font||i,n[d][g].fontSize||12,1.25,p);u[d]=(o.length/3|0)-c[d]}this.buffer.update(o),this.tickOffset=c,this.tickCount=u,this.labelOffset=h,this.labelCount=f},u.drawTicks=function(t,e,r,n,i,a,o,s){this.tickCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t]))},u.drawLabel=function(t,e,r,n,i,a,o,s){this.labelCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.labelCount[t],this.labelOffset[t]))},u.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()}}).call(this,t(\"_process\"))},{\"./shaders\":237,_process:482,\"gl-buffer\":241,\"gl-vao\":327,\"vectorize-text\":550}],239:[function(t,e,r){\"use strict\";function n(t,e){var r=t+\"\",n=r.indexOf(\".\"),i=0;n>=0&&(i=r.length-n-1);var a=Math.pow(10,i),o=Math.round(t*e*a),s=o+\"\";if(s.indexOf(\"e\")>=0)return s;var l=o/a,c=o%a;o<0?(l=0|-Math.ceil(l),c=0|-c):(l=0|Math.floor(l),c|=0);var u=\"\"+l;if(o<0&&(u=\"-\"+u),i){for(var h=\"\"+c;h.length<i;)h=\"0\"+h;return u+\".\"+h}return u}r.create=function(t,e){for(var r=[],i=0;i<3;++i){for(var a=[],o=(t[0][i],t[1][i],0);o*e[i]<=t[1][i];++o)a.push({x:o*e[i],text:n(e[i],o)});for(var o=-1;o*e[i]>=t[0][i];--o)a.push({x:o*e[i],text:n(e[i],o)});r.push(a)}return r},r.equal=function(t,e){for(var r=0;r<3;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;++n){var i=t[r][n],a=e[r][n];if(i.x!==a.x||i.text!==a.text||i.font!==a.font||i.fontColor!==a.fontColor||i.fontSize!==a.fontSize||i.dx!==a.dx||i.dy!==a.dy)return!1}}return!0}},{}],240:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,l,h){var f=e.model||c,p=e.view||c,m=e.projection||c,y=e._ortho||!1,x=t.bounds,b=(h=h||a(f,p,m,x,y)).axis;o(u,p,f),o(u,m,u);for(var _=g,w=0;w<3;++w)_[w].lo=1/0,_[w].hi=-1/0,_[w].pixelsPerDataUnit=1/0;var k=n(s(u,u));s(u,u);for(var T=0;T<3;++T){var A=(T+1)%3,M=(T+2)%3,S=v;t:for(var w=0;w<2;++w){var E=[];if(b[T]<0!=!!w){S[T]=x[w][T];for(var C=0;C<2;++C){S[A]=x[C^w][A];for(var L=0;L<2;++L)S[M]=x[L^C^w][M],E.push(S.slice())}for(var P=y?5:4,C=P;C===P;++C){if(0===E.length)continue t;E=i.positive(E,k[C])}for(var C=0;C<E.length;++C)for(var M=E[C],O=d(v,u,M,r,l),L=0;L<3;++L)_[L].lo=Math.min(_[L].lo,M[L]),_[L].hi=Math.max(_[L].hi,M[L]),L!==T&&(_[L].pixelsPerDataUnit=Math.min(_[L].pixelsPerDataUnit,Math.abs(O[L])))}}}return _};var n=t(\"extract-frustum-planes\"),i=t(\"split-polygon\"),a=t(\"./lib/cube.js\"),o=t(\"gl-mat4/multiply\"),s=t(\"gl-mat4/transpose\"),l=t(\"gl-vec4/transformMat4\"),c=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]),u=new Float32Array(16);function h(t,e,r){this.lo=t,this.hi=e,this.pixelsPerDataUnit=r}var f=[0,0,0,1],p=[0,0,0,1];function d(t,e,r,n,i){for(var a=0;a<3;++a){for(var o=f,s=p,c=0;c<3;++c)s[c]=o[c]=r[c];s[3]=o[3]=1,s[a]+=1,l(s,s,e),s[3]<0&&(t[a]=1/0),o[a]-=1,l(o,o,e),o[3]<0&&(t[a]=1/0);var u=(o[0]/o[3]-s[0]/s[3])*n,h=(o[1]/o[3]-s[1]/s[3])*i;t[a]=.25*Math.sqrt(u*u+h*h)}return t}var g=[new h(1/0,-1/0,1/0),new h(1/0,-1/0,1/0),new h(1/0,-1/0,1/0)],v=[0,0,0]},{\"./lib/cube.js\":235,\"extract-frustum-planes\":224,\"gl-mat4/multiply\":267,\"gl-mat4/transpose\":276,\"gl-vec4/transformMat4\":398,\"split-polygon\":527}],241:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"ndarray-ops\"),a=t(\"ndarray\"),o=[\"uint8\",\"uint8_clamped\",\"uint16\",\"uint32\",\"int8\",\"int16\",\"int32\",\"float32\"];function s(t,e,r,n,i){this.gl=t,this.type=e,this.handle=r,this.length=n,this.usage=i}var l=s.prototype;function c(t,e,r,n,i,a){var o=i.length*i.BYTES_PER_ELEMENT;if(a<0)return t.bufferData(e,i,n),o;if(o+a>r)throw new Error(\"gl-buffer: If resizing buffer, must not specify offset\");return t.bufferSubData(e,a,i),r}function u(t,e){for(var r=n.malloc(t.length,e),i=t.length,a=0;a<i;++a)r[a]=t[a];return r}l.bind=function(){this.gl.bindBuffer(this.type,this.handle)},l.unbind=function(){this.gl.bindBuffer(this.type,null)},l.dispose=function(){this.gl.deleteBuffer(this.handle)},l.update=function(t,e){if(\"number\"!=typeof e&&(e=-1),this.bind(),\"object\"==typeof t&&\"undefined\"!=typeof t.shape){var r=t.dtype;if(o.indexOf(r)<0&&(r=\"float32\"),this.type===this.gl.ELEMENT_ARRAY_BUFFER)r=gl.getExtension(\"OES_element_index_uint\")&&\"uint16\"!==r?\"uint32\":\"uint16\";if(r===t.dtype&&function(t,e){for(var r=1,n=e.length-1;n>=0;--n){if(e[n]!==r)return!1;r*=t[n]}return!0}(t.shape,t.stride))0===t.offset&&t.data.length===t.shape[0]?this.length=c(this.gl,this.type,this.length,this.usage,t.data,e):this.length=c(this.gl,this.type,this.length,this.usage,t.data.subarray(t.offset,t.shape[0]),e);else{var s=n.malloc(t.size,r),l=a(s,t.shape);i.assign(l,t),this.length=c(this.gl,this.type,this.length,this.usage,e<0?s:s.subarray(0,t.size),e),n.free(s)}}else if(Array.isArray(t)){var h;h=this.type===this.gl.ELEMENT_ARRAY_BUFFER?u(t,\"uint16\"):u(t,\"float32\"),this.length=c(this.gl,this.type,this.length,this.usage,e<0?h:h.subarray(0,t.length),e),n.free(h)}else if(\"object\"==typeof t&&\"number\"==typeof t.length)this.length=c(this.gl,this.type,this.length,this.usage,t,e);else{if(\"number\"!=typeof t&&void 0!==t)throw new Error(\"gl-buffer: Invalid data type\");if(e>=0)throw new Error(\"gl-buffer: Cannot specify offset when resizing buffer\");(t|=0)<=0&&(t=1),this.gl.bufferData(this.type,0|t,this.usage),this.length=t}},e.exports=function(t,e,r,n){if(r=r||t.ARRAY_BUFFER,n=n||t.DYNAMIC_DRAW,r!==t.ARRAY_BUFFER&&r!==t.ELEMENT_ARRAY_BUFFER)throw new Error(\"gl-buffer: Invalid type for webgl buffer, must be either gl.ARRAY_BUFFER or gl.ELEMENT_ARRAY_BUFFER\");if(n!==t.DYNAMIC_DRAW&&n!==t.STATIC_DRAW&&n!==t.STREAM_DRAW)throw new Error(\"gl-buffer: Invalid usage for buffer, must be either gl.DYNAMIC_DRAW, gl.STATIC_DRAW or gl.STREAM_DRAW\");var i=t.createBuffer(),a=new s(t,r,i,0,n);return a.update(e),a}},{ndarray:450,\"ndarray-ops\":444,\"typedarray-pool\":545}],242:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\"),i=function(t,e){for(var r=0;r<t.length;r++)if(t[r]>=e)return r-1;return r},a=n.create(),o=n.create(),s=function(t,e,r){return t<e?e:t>r?r:t},l=function(t,e,r,l){var c=t[0],u=t[1],h=t[2],f=r[0].length,p=r[1].length,d=r[2].length,g=i(r[0],c),v=i(r[1],u),m=i(r[2],h),y=g+1,x=v+1,b=m+1;if(l&&(g=s(g,0,f-1),y=s(y,0,f-1),v=s(v,0,p-1),x=s(x,0,p-1),m=s(m,0,d-1),b=s(b,0,d-1)),g<0||v<0||m<0||y>=f||x>=p||b>=d)return n.create();var _=(c-r[0][g])/(r[0][y]-r[0][g]),w=(u-r[1][v])/(r[1][x]-r[1][v]),k=(h-r[2][m])/(r[2][b]-r[2][m]);(_<0||_>1||isNaN(_))&&(_=0),(w<0||w>1||isNaN(w))&&(w=0),(k<0||k>1||isNaN(k))&&(k=0);var T=m*f*p,A=b*f*p,M=v*f,S=x*f,E=g,C=y,L=e[M+T+E],P=e[M+T+C],O=e[S+T+E],z=e[S+T+C],I=e[M+A+E],D=e[M+A+C],R=e[S+A+E],F=e[S+A+C],B=n.create();return n.lerp(B,L,P,_),n.lerp(a,O,z,_),n.lerp(B,B,a,w),n.lerp(a,I,D,_),n.lerp(o,R,F,_),n.lerp(a,a,o,w),n.lerp(B,B,a,k),B};e.exports=function(t,e){var r;r=t.positions?t.positions:function(t){for(var e=t[0],r=t[1],n=t[2],i=[],a=0;a<n.length;a++)for(var o=0;o<r.length;o++)for(var s=0;s<e.length;s++)i.push([n[a],r[o],e[s]]);return i}(t.meshgrid);var i=t.meshgrid,a=t.vectors,o={positions:[],vertexIntensity:[],vertexIntensityBounds:t.vertexIntensityBounds,vertexNormals:[],vectors:[],cells:[],coneOffset:t.coneOffset,colormap:t.colormap};if(0===t.positions.length)return e&&(e[0]=[0,0,0],e[1]=[0,0,0]),o;for(var s=0,c=1/0,u=-1/0,h=1/0,f=-1/0,p=1/0,d=-1/0,g=null,v=null,m=[],y=1/0,x=0;x<r.length;x++){var b,_=r[x];c=Math.min(_[0],c),u=Math.max(_[0],u),h=Math.min(_[1],h),f=Math.max(_[1],f),p=Math.min(_[2],p),d=Math.max(_[2],d),b=i?l(_,a,i,!0):a[x],n.length(b)>s&&(s=n.length(b)),x&&(y=Math.min(y,2*n.distance(g,_)/(n.length(v)+n.length(b)))),g=_,v=b,m.push(b)}var w=[c,h,p],k=[u,f,d];e&&(e[0]=w,e[1]=k),0===s&&(s=1);var T=1/s;isFinite(y)&&!isNaN(y)||(y=1),o.vectorScale=y;var A=function(t,e,r){var i=n.create();return void 0!==t&&n.set(i,t,e,r),i}(0,1,0),M=t.coneSize||.5;t.absoluteConeSize&&(M=t.absoluteConeSize*T),o.coneScale=M;x=0;for(var S=0;x<r.length;x++)for(var E=(_=r[x])[0],C=_[1],L=_[2],P=m[x],O=n.length(P)*T,z=0;z<8;z++){o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vertexIntensity.push(O,O,O),o.vertexIntensity.push(O,O,O),o.vertexNormals.push(A,A,A),o.vertexNormals.push(A,A,A);var I=o.positions.length;o.cells.push([I-6,I-5,I-4],[I-3,I-2,I-1])}return o},e.exports.createConeMesh=t(\"./lib/conemesh\")},{\"./lib/conemesh\":243,\"gl-vec3\":346}],243:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./shaders\"),g=d.meshShader,v=d.pickShader,m=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function y(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,y,x,b,_,w,k,T){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=i,this.triangleVectors=a,this.triangleColors=s,this.triangleNormals=c,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=u,this.triangleCount=0,this.lineWidth=1,this.edgePositions=h,this.edgeColors=p,this.edgeUVs=d,this.edgeIds=f,this.edgeVAO=g,this.edgeCount=0,this.pointPositions=v,this.pointColors=x,this.pointUVs=b,this.pointSizes=_,this.pointIds=y,this.pointVAO=w,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=k,this.contourVAO=T,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.coneScale=2,this.vectorScale=1,this.coneOffset=.25,this._model=m,this._view=m,this._projection=m,this._resolution=[1,1]}var x=y.prototype;function b(t){var e=n(t,v.vertex,v.fragment,null,v.attributes);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.vector.location=5,e}x.isOpaque=function(){return this.opacity>=1},x.isTransparent=function(){return this.opacity<1},x.pickSlots=1,x.setPickBase=function(t){this.pickId=t},x.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=i[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},x.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),void 0!==t.vectorScale&&(this.vectorScale=t.vectorScale),void 0!==t.coneScale&&(this.coneScale=t.coneScale),void 0!==t.coneOffset&&(this.coneOffset=t.coneOffset),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=h({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return u(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,i=t.vectors;if(n&&r&&i){var a=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[],w=[],k=[];this.cells=r,this.positions=n;var T=t.vertexNormals,A=t.cellNormals,M=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,S=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!A&&(A=s.faceNormals(r,n,S)),A||T||(T=s.vertexNormals(r,n,M));var E=t.vertexColors,C=t.cellColors,L=t.meshColor||[1,1,1,1],P=t.vertexUVs,O=t.vertexIntensity,z=t.cellUVs,I=t.cellIntensity,D=1/0,R=-1/0;if(!P&&!z)if(O)if(t.vertexIntensityBounds)D=+t.vertexIntensityBounds[0],R=+t.vertexIntensityBounds[1];else for(var F=0;F<O.length;++F){var B=O[F];D=Math.min(D,B),R=Math.max(R,B)}else if(I)for(F=0;F<I.length;++F){B=I[F];D=Math.min(D,B),R=Math.max(R,B)}else for(F=0;F<n.length;++F){B=n[F][2];D=Math.min(D,B),R=Math.max(R,B)}this.intensity=O||(I?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,I):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var N=t.pointSizes,j=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(F=0;F<n.length;++F)for(var U=n[F],V=0;V<3;++V)!isNaN(U[V])&&isFinite(U[V])&&(this.bounds[0][V]=Math.min(this.bounds[0][V],U[V]),this.bounds[1][V]=Math.max(this.bounds[1][V],U[V]));var q=0,H=0,G=0;t:for(F=0;F<r.length;++F){var Y=r[F];switch(Y.length){case 1:for(U=n[X=Y[0]],V=0;V<3;++V)if(isNaN(U[V])||!isFinite(U[V]))continue t;x.push(U[0],U[1],U[2],U[3]),3===(Z=E?E[X]:C?C[F]:L).length?b.push(Z[0],Z[1],Z[2],1):b.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],_.push(J[0],J[1]),N?w.push(N[X]):w.push(j),k.push(F),G+=1;break;case 2:for(V=0;V<2;++V){U=n[X=Y[V]];for(var W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t}for(V=0;V<2;++V){U=n[X=Y[V]];g.push(U[0],U[1],U[2]),3===(Z=E?E[X]:C?C[F]:L).length?v.push(Z[0],Z[1],Z[2],1):v.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],m.push(J[0],J[1]),y.push(F)}H+=1;break;case 3:for(V=0;V<3;++V)for(U=n[X=Y[V]],W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t;for(V=0;V<3;++V){var X;U=n[X=Y[2-V]];a.push(U[0],U[1],U[2],U[3]);var Z,J,K,$=i[X];l.push($[0],$[1],$[2]),3===(Z=E?E[X]:C?C[F]:L).length?c.push(Z[0],Z[1],Z[2],1):c.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],p.push(J[0],J[1]),K=T?T[X]:A[F],f.push(K[0],K[1],K[2]),d.push(F)}q+=1}}this.pointCount=G,this.edgeCount=H,this.triangleCount=q,this.pointPositions.update(x),this.pointColors.update(b),this.pointUVs.update(_),this.pointSizes.update(w),this.pointIds.update(new Uint32Array(k)),this.edgePositions.update(g),this.edgeColors.update(v),this.edgeUVs.update(m),this.edgeIds.update(new Uint32Array(y)),this.trianglePositions.update(a),this.triangleVectors.update(l),this.triangleColors.update(c),this.triangleUVs.update(p),this.triangleNormals.update(f),this.triangleIds.update(new Uint32Array(d))}},x.drawTransparent=x.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:m.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var f=u[12+o],p=0;p<3;++p)f+=u[4*p+o]*this.lightPosition[p];s.lightPosition[o]=f/h}if(this.triangleCount>0){var d=this.triShader;d.bind(),d.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},x.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:i,clipBounds:a,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind())},x.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3);return{index:Math.floor(r[1]/48),position:n,dataCoordinate:n}},x.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose()},e.exports=function(t,e){1===arguments.length&&(t=(e=t).gl);var r=e.triShader||function(t){var e=n(t,g.vertex,g.fragment,null,g.attributes);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.vector.location=5,e}(t),s=b(t),l=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));l.generateMipmap(),l.minFilter=t.LINEAR_MIPMAP_LINEAR,l.magFilter=t.LINEAR;var c=i(t),h=i(t),f=i(t),p=i(t),d=i(t),v=i(t),m=a(t,[{buffer:c,type:t.FLOAT,size:4},{buffer:v,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:f,type:t.FLOAT,size:4},{buffer:p,type:t.FLOAT,size:2},{buffer:d,type:t.FLOAT,size:3},{buffer:h,type:t.FLOAT,size:3}]),x=i(t),_=i(t),w=i(t),k=i(t),T=a(t,[{buffer:x,type:t.FLOAT,size:3},{buffer:k,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:_,type:t.FLOAT,size:4},{buffer:w,type:t.FLOAT,size:2}]),A=i(t),M=i(t),S=i(t),E=i(t),C=i(t),L=a(t,[{buffer:A,type:t.FLOAT,size:3},{buffer:C,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:M,type:t.FLOAT,size:4},{buffer:S,type:t.FLOAT,size:2},{buffer:E,type:t.FLOAT,size:1}]),P=i(t),O=new y(t,l,r,s,c,h,v,f,p,d,m,x,k,_,w,T,A,C,M,S,E,L,P,a(t,[{buffer:P,type:t.FLOAT,size:3}]));return O.update(e),O}},{\"./shaders\":244,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-shader\":301,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,normals:453,\"simplicial-complex-contour\":518,\"typedarray-pool\":545}],244:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\nuniform float vectorScale;\\nuniform float coneScale;\\n\\nuniform float coneOffset;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * conePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal,0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(conePosition, 1.0);\\n  vec4 t_position  = view * conePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = conePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular\\n            , opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nuniform float vectorScale;\\nuniform float coneScale;\\nuniform float coneOffset;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n  gl_Position = projection * view * conePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec3\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec3\"}]}},{glslify:409}],245:[function(t,e,r){e.exports={0:\"NONE\",1:\"ONE\",2:\"LINE_LOOP\",3:\"LINE_STRIP\",4:\"TRIANGLES\",5:\"TRIANGLE_STRIP\",6:\"TRIANGLE_FAN\",256:\"DEPTH_BUFFER_BIT\",512:\"NEVER\",513:\"LESS\",514:\"EQUAL\",515:\"LEQUAL\",516:\"GREATER\",517:\"NOTEQUAL\",518:\"GEQUAL\",519:\"ALWAYS\",768:\"SRC_COLOR\",769:\"ONE_MINUS_SRC_COLOR\",770:\"SRC_ALPHA\",771:\"ONE_MINUS_SRC_ALPHA\",772:\"DST_ALPHA\",773:\"ONE_MINUS_DST_ALPHA\",774:\"DST_COLOR\",775:\"ONE_MINUS_DST_COLOR\",776:\"SRC_ALPHA_SATURATE\",1024:\"STENCIL_BUFFER_BIT\",1028:\"FRONT\",1029:\"BACK\",1032:\"FRONT_AND_BACK\",1280:\"INVALID_ENUM\",1281:\"INVALID_VALUE\",1282:\"INVALID_OPERATION\",1285:\"OUT_OF_MEMORY\",1286:\"INVALID_FRAMEBUFFER_OPERATION\",2304:\"CW\",2305:\"CCW\",2849:\"LINE_WIDTH\",2884:\"CULL_FACE\",2885:\"CULL_FACE_MODE\",2886:\"FRONT_FACE\",2928:\"DEPTH_RANGE\",2929:\"DEPTH_TEST\",2930:\"DEPTH_WRITEMASK\",2931:\"DEPTH_CLEAR_VALUE\",2932:\"DEPTH_FUNC\",2960:\"STENCIL_TEST\",2961:\"STENCIL_CLEAR_VALUE\",2962:\"STENCIL_FUNC\",2963:\"STENCIL_VALUE_MASK\",2964:\"STENCIL_FAIL\",2965:\"STENCIL_PASS_DEPTH_FAIL\",2966:\"STENCIL_PASS_DEPTH_PASS\",2967:\"STENCIL_REF\",2968:\"STENCIL_WRITEMASK\",2978:\"VIEWPORT\",3024:\"DITHER\",3042:\"BLEND\",3088:\"SCISSOR_BOX\",3089:\"SCISSOR_TEST\",3106:\"COLOR_CLEAR_VALUE\",3107:\"COLOR_WRITEMASK\",3317:\"UNPACK_ALIGNMENT\",3333:\"PACK_ALIGNMENT\",3379:\"MAX_TEXTURE_SIZE\",3386:\"MAX_VIEWPORT_DIMS\",3408:\"SUBPIXEL_BITS\",3410:\"RED_BITS\",3411:\"GREEN_BITS\",3412:\"BLUE_BITS\",3413:\"ALPHA_BITS\",3414:\"DEPTH_BITS\",3415:\"STENCIL_BITS\",3553:\"TEXTURE_2D\",4352:\"DONT_CARE\",4353:\"FASTEST\",4354:\"NICEST\",5120:\"BYTE\",5121:\"UNSIGNED_BYTE\",5122:\"SHORT\",5123:\"UNSIGNED_SHORT\",5124:\"INT\",5125:\"UNSIGNED_INT\",5126:\"FLOAT\",5386:\"INVERT\",5890:\"TEXTURE\",6401:\"STENCIL_INDEX\",6402:\"DEPTH_COMPONENT\",6406:\"ALPHA\",6407:\"RGB\",6408:\"RGBA\",6409:\"LUMINANCE\",6410:\"LUMINANCE_ALPHA\",7680:\"KEEP\",7681:\"REPLACE\",7682:\"INCR\",7683:\"DECR\",7936:\"VENDOR\",7937:\"RENDERER\",7938:\"VERSION\",9728:\"NEAREST\",9729:\"LINEAR\",9984:\"NEAREST_MIPMAP_NEAREST\",9985:\"LINEAR_MIPMAP_NEAREST\",9986:\"NEAREST_MIPMAP_LINEAR\",9987:\"LINEAR_MIPMAP_LINEAR\",10240:\"TEXTURE_MAG_FILTER\",10241:\"TEXTURE_MIN_FILTER\",10242:\"TEXTURE_WRAP_S\",10243:\"TEXTURE_WRAP_T\",10497:\"REPEAT\",10752:\"POLYGON_OFFSET_UNITS\",16384:\"COLOR_BUFFER_BIT\",32769:\"CONSTANT_COLOR\",32770:\"ONE_MINUS_CONSTANT_COLOR\",32771:\"CONSTANT_ALPHA\",32772:\"ONE_MINUS_CONSTANT_ALPHA\",32773:\"BLEND_COLOR\",32774:\"FUNC_ADD\",32777:\"BLEND_EQUATION_RGB\",32778:\"FUNC_SUBTRACT\",32779:\"FUNC_REVERSE_SUBTRACT\",32819:\"UNSIGNED_SHORT_4_4_4_4\",32820:\"UNSIGNED_SHORT_5_5_5_1\",32823:\"POLYGON_OFFSET_FILL\",32824:\"POLYGON_OFFSET_FACTOR\",32854:\"RGBA4\",32855:\"RGB5_A1\",32873:\"TEXTURE_BINDING_2D\",32926:\"SAMPLE_ALPHA_TO_COVERAGE\",32928:\"SAMPLE_COVERAGE\",32936:\"SAMPLE_BUFFERS\",32937:\"SAMPLES\",32938:\"SAMPLE_COVERAGE_VALUE\",32939:\"SAMPLE_COVERAGE_INVERT\",32968:\"BLEND_DST_RGB\",32969:\"BLEND_SRC_RGB\",32970:\"BLEND_DST_ALPHA\",32971:\"BLEND_SRC_ALPHA\",33071:\"CLAMP_TO_EDGE\",33170:\"GENERATE_MIPMAP_HINT\",33189:\"DEPTH_COMPONENT16\",33306:\"DEPTH_STENCIL_ATTACHMENT\",33635:\"UNSIGNED_SHORT_5_6_5\",33648:\"MIRRORED_REPEAT\",33901:\"ALIASED_POINT_SIZE_RANGE\",33902:\"ALIASED_LINE_WIDTH_RANGE\",33984:\"TEXTURE0\",33985:\"TEXTURE1\",33986:\"TEXTURE2\",33987:\"TEXTURE3\",33988:\"TEXTURE4\",33989:\"TEXTURE5\",33990:\"TEXTURE6\",33991:\"TEXTURE7\",33992:\"TEXTURE8\",33993:\"TEXTURE9\",33994:\"TEXTURE10\",33995:\"TEXTURE11\",33996:\"TEXTURE12\",33997:\"TEXTURE13\",33998:\"TEXTURE14\",33999:\"TEXTURE15\",34000:\"TEXTURE16\",34001:\"TEXTURE17\",34002:\"TEXTURE18\",34003:\"TEXTURE19\",34004:\"TEXTURE20\",34005:\"TEXTURE21\",34006:\"TEXTURE22\",34007:\"TEXTURE23\",34008:\"TEXTURE24\",34009:\"TEXTURE25\",34010:\"TEXTURE26\",34011:\"TEXTURE27\",34012:\"TEXTURE28\",34013:\"TEXTURE29\",34014:\"TEXTURE30\",34015:\"TEXTURE31\",34016:\"ACTIVE_TEXTURE\",34024:\"MAX_RENDERBUFFER_SIZE\",34041:\"DEPTH_STENCIL\",34055:\"INCR_WRAP\",34056:\"DECR_WRAP\",34067:\"TEXTURE_CUBE_MAP\",34068:\"TEXTURE_BINDING_CUBE_MAP\",34069:\"TEXTURE_CUBE_MAP_POSITIVE_X\",34070:\"TEXTURE_CUBE_MAP_NEGATIVE_X\",34071:\"TEXTURE_CUBE_MAP_POSITIVE_Y\",34072:\"TEXTURE_CUBE_MAP_NEGATIVE_Y\",34073:\"TEXTURE_CUBE_MAP_POSITIVE_Z\",34074:\"TEXTURE_CUBE_MAP_NEGATIVE_Z\",34076:\"MAX_CUBE_MAP_TEXTURE_SIZE\",34338:\"VERTEX_ATTRIB_ARRAY_ENABLED\",34339:\"VERTEX_ATTRIB_ARRAY_SIZE\",34340:\"VERTEX_ATTRIB_ARRAY_STRIDE\",34341:\"VERTEX_ATTRIB_ARRAY_TYPE\",34342:\"CURRENT_VERTEX_ATTRIB\",34373:\"VERTEX_ATTRIB_ARRAY_POINTER\",34466:\"NUM_COMPRESSED_TEXTURE_FORMATS\",34467:\"COMPRESSED_TEXTURE_FORMATS\",34660:\"BUFFER_SIZE\",34661:\"BUFFER_USAGE\",34816:\"STENCIL_BACK_FUNC\",34817:\"STENCIL_BACK_FAIL\",34818:\"STENCIL_BACK_PASS_DEPTH_FAIL\",34819:\"STENCIL_BACK_PASS_DEPTH_PASS\",34877:\"BLEND_EQUATION_ALPHA\",34921:\"MAX_VERTEX_ATTRIBS\",34922:\"VERTEX_ATTRIB_ARRAY_NORMALIZED\",34930:\"MAX_TEXTURE_IMAGE_UNITS\",34962:\"ARRAY_BUFFER\",34963:\"ELEMENT_ARRAY_BUFFER\",34964:\"ARRAY_BUFFER_BINDING\",34965:\"ELEMENT_ARRAY_BUFFER_BINDING\",34975:\"VERTEX_ATTRIB_ARRAY_BUFFER_BINDING\",35040:\"STREAM_DRAW\",35044:\"STATIC_DRAW\",35048:\"DYNAMIC_DRAW\",35632:\"FRAGMENT_SHADER\",35633:\"VERTEX_SHADER\",35660:\"MAX_VERTEX_TEXTURE_IMAGE_UNITS\",35661:\"MAX_COMBINED_TEXTURE_IMAGE_UNITS\",35663:\"SHADER_TYPE\",35664:\"FLOAT_VEC2\",35665:\"FLOAT_VEC3\",35666:\"FLOAT_VEC4\",35667:\"INT_VEC2\",35668:\"INT_VEC3\",35669:\"INT_VEC4\",35670:\"BOOL\",35671:\"BOOL_VEC2\",35672:\"BOOL_VEC3\",35673:\"BOOL_VEC4\",35674:\"FLOAT_MAT2\",35675:\"FLOAT_MAT3\",35676:\"FLOAT_MAT4\",35678:\"SAMPLER_2D\",35680:\"SAMPLER_CUBE\",35712:\"DELETE_STATUS\",35713:\"COMPILE_STATUS\",35714:\"LINK_STATUS\",35715:\"VALIDATE_STATUS\",35716:\"INFO_LOG_LENGTH\",35717:\"ATTACHED_SHADERS\",35718:\"ACTIVE_UNIFORMS\",35719:\"ACTIVE_UNIFORM_MAX_LENGTH\",35720:\"SHADER_SOURCE_LENGTH\",35721:\"ACTIVE_ATTRIBUTES\",35722:\"ACTIVE_ATTRIBUTE_MAX_LENGTH\",35724:\"SHADING_LANGUAGE_VERSION\",35725:\"CURRENT_PROGRAM\",36003:\"STENCIL_BACK_REF\",36004:\"STENCIL_BACK_VALUE_MASK\",36005:\"STENCIL_BACK_WRITEMASK\",36006:\"FRAMEBUFFER_BINDING\",36007:\"RENDERBUFFER_BINDING\",36048:\"FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE\",36049:\"FRAMEBUFFER_ATTACHMENT_OBJECT_NAME\",36050:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL\",36051:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE\",36053:\"FRAMEBUFFER_COMPLETE\",36054:\"FRAMEBUFFER_INCOMPLETE_ATTACHMENT\",36055:\"FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT\",36057:\"FRAMEBUFFER_INCOMPLETE_DIMENSIONS\",36061:\"FRAMEBUFFER_UNSUPPORTED\",36064:\"COLOR_ATTACHMENT0\",36096:\"DEPTH_ATTACHMENT\",36128:\"STENCIL_ATTACHMENT\",36160:\"FRAMEBUFFER\",36161:\"RENDERBUFFER\",36162:\"RENDERBUFFER_WIDTH\",36163:\"RENDERBUFFER_HEIGHT\",36164:\"RENDERBUFFER_INTERNAL_FORMAT\",36168:\"STENCIL_INDEX8\",36176:\"RENDERBUFFER_RED_SIZE\",36177:\"RENDERBUFFER_GREEN_SIZE\",36178:\"RENDERBUFFER_BLUE_SIZE\",36179:\"RENDERBUFFER_ALPHA_SIZE\",36180:\"RENDERBUFFER_DEPTH_SIZE\",36181:\"RENDERBUFFER_STENCIL_SIZE\",36194:\"RGB565\",36336:\"LOW_FLOAT\",36337:\"MEDIUM_FLOAT\",36338:\"HIGH_FLOAT\",36339:\"LOW_INT\",36340:\"MEDIUM_INT\",36341:\"HIGH_INT\",36346:\"SHADER_COMPILER\",36347:\"MAX_VERTEX_UNIFORM_VECTORS\",36348:\"MAX_VARYING_VECTORS\",36349:\"MAX_FRAGMENT_UNIFORM_VECTORS\",37440:\"UNPACK_FLIP_Y_WEBGL\",37441:\"UNPACK_PREMULTIPLY_ALPHA_WEBGL\",37442:\"CONTEXT_LOST_WEBGL\",37443:\"UNPACK_COLORSPACE_CONVERSION_WEBGL\",37444:\"BROWSER_DEFAULT_WEBGL\"}},{}],246:[function(t,e,r){var n=t(\"./1.0/numbers\");e.exports=function(t){return n[t]}},{\"./1.0/numbers\":245}],247:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),o=i(e,[{buffer:r,type:e.FLOAT,size:3,offset:0,stride:40},{buffer:r,type:e.FLOAT,size:4,offset:12,stride:40},{buffer:r,type:e.FLOAT,size:3,offset:28,stride:40}]),l=a(e);l.attributes.position.location=0,l.attributes.color.location=1,l.attributes.offset.location=2;var c=new s(e,r,o,l);return c.update(t),c};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\"),o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.shader=n,this.buffer=e,this.vao=r,this.pixelRatio=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lineWidth=[1,1,1],this.capSize=[10,10,10],this.lineCount=[0,0,0],this.lineOffset=[0,0,0],this.opacity=1,this.hasAlpha=!1}var l=s.prototype;function c(t,e){for(var r=0;r<3;++r)t[0][r]=Math.min(t[0][r],e[r]),t[1][r]=Math.max(t[1][r],e[r])}l.isOpaque=function(){return!this.hasAlpha},l.isTransparent=function(){return this.hasAlpha},l.drawTransparent=l.draw=function(t){var e=this.gl,r=this.shader.uniforms;this.shader.bind();var n=r.view=t.view||o,i=r.projection=t.projection||o;r.model=t.model||o,r.clipBounds=this.clipBounds,r.opacity=this.opacity;var a=n[12],s=n[13],l=n[14],c=n[15],u=(t._ortho||!1?2:1)*this.pixelRatio*(i[3]*a+i[7]*s+i[11]*l+i[15]*c)/e.drawingBufferHeight;this.vao.bind();for(var h=0;h<3;++h)e.lineWidth(this.lineWidth[h]*this.pixelRatio),r.capSize=this.capSize[h]*u,this.lineCount[h]&&e.drawArrays(e.LINES,this.lineOffset[h],this.lineCount[h]);this.vao.unbind()};var u=function(){for(var t=new Array(3),e=0;e<3;++e){for(var r=[],n=1;n<=2;++n)for(var i=-1;i<=1;i+=2){var a=[0,0,0];a[(n+e)%3]=i,r.push(a)}t[e]=r}return t}();function h(t,e,r,n){for(var i=u[n],a=0;a<i.length;++a){var o=i[a];t.push(e[0],e[1],e[2],r[0],r[1],r[2],r[3],o[0],o[1],o[2])}return i.length}l.update=function(t){\"lineWidth\"in(t=t||{})&&(this.lineWidth=t.lineWidth,Array.isArray(this.lineWidth)||(this.lineWidth=[this.lineWidth,this.lineWidth,this.lineWidth])),\"capSize\"in t&&(this.capSize=t.capSize,Array.isArray(this.capSize)||(this.capSize=[this.capSize,this.capSize,this.capSize])),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var e=t.color||[[0,0,0],[0,0,0],[0,0,0]],r=t.position,n=t.error;if(Array.isArray(e[0])||(e=[e,e,e]),r&&n){var i=[],a=r.length,o=0;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.lineCount=[0,0,0];for(var s=0;s<3;++s){this.lineOffset[s]=o;t:for(var l=0;l<a;++l){for(var u=r[l],f=0;f<3;++f)if(isNaN(u[f])||!isFinite(u[f]))continue t;var p=n[l],d=e[s];if(Array.isArray(d[0])&&(d=e[l]),3===d.length?d=[d[0],d[1],d[2],1]:4===d.length&&(d=[d[0],d[1],d[2],d[3]],!this.hasAlpha&&d[3]<1&&(this.hasAlpha=!0)),!isNaN(p[0][s])&&!isNaN(p[1][s])){var g;if(p[0][s]<0)(g=u.slice())[s]+=p[0][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+h(i,g,d,s);if(p[1][s]>0)(g=u.slice())[s]+=p[1][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+h(i,g,d,s)}}this.lineCount[s]=o-this.lineOffset[s]}this.buffer.update(i)}},l.dispose=function(){this.shader.dispose(),this.buffer.dispose(),this.vao.dispose()}},{\"./shaders/index\":248,\"gl-buffer\":241,\"gl-vao\":327}],248:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, offset;\\nattribute vec4 color;\\nuniform mat4 model, view, projection;\\nuniform float capSize;\\nvarying vec4 fragColor;\\nvarying vec3 fragPosition;\\n\\nvoid main() {\\n  vec4 worldPosition  = model * vec4(position, 1.0);\\n  worldPosition       = (worldPosition / worldPosition.w) + vec4(capSize * offset, 0.0);\\n  gl_Position         = projection * view * worldPosition;\\n  fragColor           = color;\\n  fragPosition        = position;\\n}\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float opacity;\\nvarying vec3 fragPosition;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], fragPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  gl_FragColor = opacity * fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"offset\",type:\"vec3\"}])}},{\"gl-shader\":301,glslify:409}],249:[function(t,e,r){\"use strict\";var n=t(\"gl-texture2d\");e.exports=function(t,e,r,n){i||(i=t.FRAMEBUFFER_UNSUPPORTED,a=t.FRAMEBUFFER_INCOMPLETE_ATTACHMENT,o=t.FRAMEBUFFER_INCOMPLETE_DIMENSIONS,s=t.FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT);var c=t.getExtension(\"WEBGL_draw_buffers\");!l&&c&&function(t,e){var r=t.getParameter(e.MAX_COLOR_ATTACHMENTS_WEBGL);l=new Array(r+1);for(var n=0;n<=r;++n){for(var i=new Array(r),a=0;a<n;++a)i[a]=t.COLOR_ATTACHMENT0+a;for(var a=n;a<r;++a)i[a]=t.NONE;l[n]=i}}(t,c);Array.isArray(e)&&(n=r,r=0|e[1],e=0|e[0]);if(\"number\"!=typeof e)throw new Error(\"gl-fbo: Missing shape parameter\");var u=t.getParameter(t.MAX_RENDERBUFFER_SIZE);if(e<0||e>u||r<0||r>u)throw new Error(\"gl-fbo: Parameters are too large for FBO\");var h=1;if(\"color\"in(n=n||{})){if((h=Math.max(0|n.color,0))<0)throw new Error(\"gl-fbo: Must specify a nonnegative number of colors\");if(h>1){if(!c)throw new Error(\"gl-fbo: Multiple draw buffer extension not supported\");if(h>t.getParameter(c.MAX_COLOR_ATTACHMENTS_WEBGL))throw new Error(\"gl-fbo: Context does not support \"+h+\" draw buffers\")}}var f=t.UNSIGNED_BYTE,p=t.getExtension(\"OES_texture_float\");if(n.float&&h>0){if(!p)throw new Error(\"gl-fbo: Context does not support floating point textures\");f=t.FLOAT}else n.preferFloat&&h>0&&p&&(f=t.FLOAT);var g=!0;\"depth\"in n&&(g=!!n.depth);var v=!1;\"stencil\"in n&&(v=!!n.stencil);return new d(t,e,r,f,h,g,v,c)};var i,a,o,s,l=null;function c(t){return[t.getParameter(t.FRAMEBUFFER_BINDING),t.getParameter(t.RENDERBUFFER_BINDING),t.getParameter(t.TEXTURE_BINDING_2D)]}function u(t,e){t.bindFramebuffer(t.FRAMEBUFFER,e[0]),t.bindRenderbuffer(t.RENDERBUFFER,e[1]),t.bindTexture(t.TEXTURE_2D,e[2])}function h(t){switch(t){case i:throw new Error(\"gl-fbo: Framebuffer unsupported\");case a:throw new Error(\"gl-fbo: Framebuffer incomplete attachment\");case o:throw new Error(\"gl-fbo: Framebuffer incomplete dimensions\");case s:throw new Error(\"gl-fbo: Framebuffer incomplete missing attachment\");default:throw new Error(\"gl-fbo: Framebuffer failed for unspecified reason\")}}function f(t,e,r,i,a,o){if(!i)return null;var s=n(t,e,r,a,i);return s.magFilter=t.NEAREST,s.minFilter=t.NEAREST,s.mipSamples=1,s.bind(),t.framebufferTexture2D(t.FRAMEBUFFER,o,t.TEXTURE_2D,s.handle,0),s}function p(t,e,r,n,i){var a=t.createRenderbuffer();return t.bindRenderbuffer(t.RENDERBUFFER,a),t.renderbufferStorage(t.RENDERBUFFER,n,e,r),t.framebufferRenderbuffer(t.FRAMEBUFFER,i,t.RENDERBUFFER,a),a}function d(t,e,r,n,i,a,o,s){this.gl=t,this._shape=[0|e,0|r],this._destroyed=!1,this._ext=s,this.color=new Array(i);for(var d=0;d<i;++d)this.color[d]=null;this._color_rb=null,this.depth=null,this._depth_rb=null,this._colorType=n,this._useDepth=a,this._useStencil=o;var g=this,v=[0|e,0|r];Object.defineProperties(v,{0:{get:function(){return g._shape[0]},set:function(t){return g.width=t}},1:{get:function(){return g._shape[1]},set:function(t){return g.height=t}}}),this._shapeVector=v,function(t){var e=c(t.gl),r=t.gl,n=t.handle=r.createFramebuffer(),i=t._shape[0],a=t._shape[1],o=t.color.length,s=t._ext,d=t._useStencil,g=t._useDepth,v=t._colorType;r.bindFramebuffer(r.FRAMEBUFFER,n);for(var m=0;m<o;++m)t.color[m]=f(r,i,a,v,r.RGBA,r.COLOR_ATTACHMENT0+m);0===o?(t._color_rb=p(r,i,a,r.RGBA4,r.COLOR_ATTACHMENT0),s&&s.drawBuffersWEBGL(l[0])):o>1&&s.drawBuffersWEBGL(l[o]);var y=r.getExtension(\"WEBGL_depth_texture\");y?d?t.depth=f(r,i,a,y.UNSIGNED_INT_24_8_WEBGL,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g&&(t.depth=f(r,i,a,r.UNSIGNED_SHORT,r.DEPTH_COMPONENT,r.DEPTH_ATTACHMENT)):g&&d?t._depth_rb=p(r,i,a,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g?t._depth_rb=p(r,i,a,r.DEPTH_COMPONENT16,r.DEPTH_ATTACHMENT):d&&(t._depth_rb=p(r,i,a,r.STENCIL_INDEX,r.STENCIL_ATTACHMENT));var x=r.checkFramebufferStatus(r.FRAMEBUFFER);if(x!==r.FRAMEBUFFER_COMPLETE){for(t._destroyed=!0,r.bindFramebuffer(r.FRAMEBUFFER,null),r.deleteFramebuffer(t.handle),t.handle=null,t.depth&&(t.depth.dispose(),t.depth=null),t._depth_rb&&(r.deleteRenderbuffer(t._depth_rb),t._depth_rb=null),m=0;m<t.color.length;++m)t.color[m].dispose(),t.color[m]=null;t._color_rb&&(r.deleteRenderbuffer(t._color_rb),t._color_rb=null),u(r,e),h(x)}u(r,e)}(this)}var g=d.prototype;function v(t,e,r){if(t._destroyed)throw new Error(\"gl-fbo: Can't resize destroyed FBO\");if(t._shape[0]!==e||t._shape[1]!==r){var n=t.gl,i=n.getParameter(n.MAX_RENDERBUFFER_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-fbo: Can't resize FBO, invalid dimensions\");t._shape[0]=e,t._shape[1]=r;for(var a=c(n),o=0;o<t.color.length;++o)t.color[o].shape=t._shape;t._color_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._color_rb),n.renderbufferStorage(n.RENDERBUFFER,n.RGBA4,t._shape[0],t._shape[1])),t.depth&&(t.depth.shape=t._shape),t._depth_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._depth_rb),t._useDepth&&t._useStencil?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_STENCIL,t._shape[0],t._shape[1]):t._useDepth?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_COMPONENT16,t._shape[0],t._shape[1]):t._useStencil&&n.renderbufferStorage(n.RENDERBUFFER,n.STENCIL_INDEX,t._shape[0],t._shape[1])),n.bindFramebuffer(n.FRAMEBUFFER,t.handle);var s=n.checkFramebufferStatus(n.FRAMEBUFFER);s!==n.FRAMEBUFFER_COMPLETE&&(t.dispose(),u(n,a),h(s)),u(n,a)}}Object.defineProperties(g,{shape:{get:function(){return this._destroyed?[0,0]:this._shapeVector},set:function(t){if(Array.isArray(t)||(t=[0|t,0|t]),2!==t.length)throw new Error(\"gl-fbo: Shape vector must be length 2\");var e=0|t[0],r=0|t[1];return v(this,e,r),[e,r]},enumerable:!1},width:{get:function(){return this._destroyed?0:this._shape[0]},set:function(t){return v(this,t|=0,this._shape[1]),t},enumerable:!1},height:{get:function(){return this._destroyed?0:this._shape[1]},set:function(t){return t|=0,v(this,this._shape[0],t),t},enumerable:!1}}),g.bind=function(){if(!this._destroyed){var t=this.gl;t.bindFramebuffer(t.FRAMEBUFFER,this.handle),t.viewport(0,0,this._shape[0],this._shape[1])}},g.dispose=function(){if(!this._destroyed){this._destroyed=!0;var t=this.gl;t.deleteFramebuffer(this.handle),this.handle=null,this.depth&&(this.depth.dispose(),this.depth=null),this._depth_rb&&(t.deleteRenderbuffer(this._depth_rb),this._depth_rb=null);for(var e=0;e<this.color.length;++e)this.color[e].dispose(),this.color[e]=null;this._color_rb&&(t.deleteRenderbuffer(this._color_rb),this._color_rb=null)}}},{\"gl-texture2d\":322}],250:[function(t,e,r){var n=t(\"sprintf-js\").sprintf,i=t(\"gl-constants/lookup\"),a=t(\"glsl-shader-name\"),o=t(\"add-line-numbers\");e.exports=function(t,e,r){\"use strict\";var s=a(e)||\"of unknown name (see npm glsl-shader-name)\",l=\"unknown type\";void 0!==r&&(l=r===i.FRAGMENT_SHADER?\"fragment\":\"vertex\");for(var c=n(\"Error compiling %s shader %s:\\n\",l,s),u=n(\"%s%s\",c,t),h=t.split(\"\\n\"),f={},p=0;p<h.length;p++){var d=h[p];if(\"\"!==d&&\"\\0\"!==d){var g=parseInt(d.split(\":\")[2]);if(isNaN(g))throw new Error(n(\"Could not parse error: %s\",d));f[g]=d}}for(var v=o(e).split(\"\\n\"),p=0;p<v.length;p++)if(f[p+3]||f[p+2]||f[p+1]){var m=v[p];if(c+=m+\"\\n\",f[p+1]){var y=f[p+1];y=y.substr(y.split(\":\",3).join(\":\").length+1).trim(),c+=n(\"^^^ %s\\n\\n\",y)}}return{long:c.trim(),short:u.trim()}}},{\"add-line-numbers\":61,\"gl-constants/lookup\":246,\"glsl-shader-name\":401,\"sprintf-js\":528}],251:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.gl,n=o(r,l.vertex,l.fragment),i=o(r,l.pickVertex,l.pickFragment),a=s(r),u=s(r),h=s(r),f=s(r),p=new c(t,n,i,a,u,h,f);return p.update(e),t.addObject(p),p};var n=t(\"binary-search-bounds\"),i=t(\"iota-array\"),a=t(\"typedarray-pool\"),o=t(\"gl-shader\"),s=t(\"gl-buffer\"),l=t(\"./lib/shaders\");function c(t,e,r,n,i,a,o){this.plot=t,this.shader=e,this.pickShader=r,this.positionBuffer=n,this.weightBuffer=i,this.colorBuffer=a,this.idBuffer=o,this.xData=[],this.yData=[],this.shape=[0,0],this.bounds=[1/0,1/0,-1/0,-1/0],this.pickOffset=0}var u,h=c.prototype,f=[0,0,1,0,0,1,1,0,1,1,0,1];h.draw=(u=[1,0,0,0,1,0,0,0,1],function(){var t=this.plot,e=this.shader,r=this.bounds,n=this.numVertices;if(!(n<=0)){var i=t.gl,a=t.dataBox,o=r[2]-r[0],s=r[3]-r[1],l=a[2]-a[0],c=a[3]-a[1];u[0]=2*o/l,u[4]=2*s/c,u[6]=2*(r[0]-a[0])/l-1,u[7]=2*(r[1]-a[1])/c-1,e.bind();var h=e.uniforms;h.viewTransform=u,h.shape=this.shape;var f=e.attributes;this.positionBuffer.bind(),f.position.pointer(),this.weightBuffer.bind(),f.weight.pointer(i.UNSIGNED_BYTE,!1),this.colorBuffer.bind(),f.color.pointer(i.UNSIGNED_BYTE,!0),i.drawArrays(i.TRIANGLES,0,n)}}),h.drawPick=function(){var t=[1,0,0,0,1,0,0,0,1],e=[0,0,0,0];return function(r){var n=this.plot,i=this.pickShader,a=this.bounds,o=this.numVertices;if(!(o<=0)){var s=n.gl,l=n.dataBox,c=a[2]-a[0],u=a[3]-a[1],h=l[2]-l[0],f=l[3]-l[1];t[0]=2*c/h,t[4]=2*u/f,t[6]=2*(a[0]-l[0])/h-1,t[7]=2*(a[1]-l[1])/f-1;for(var p=0;p<4;++p)e[p]=r>>8*p&255;this.pickOffset=r,i.bind();var d=i.uniforms;d.viewTransform=t,d.pickOffset=e,d.shape=this.shape;var g=i.attributes;return this.positionBuffer.bind(),g.position.pointer(),this.weightBuffer.bind(),g.weight.pointer(s.UNSIGNED_BYTE,!1),this.idBuffer.bind(),g.pickId.pointer(s.UNSIGNED_BYTE,!1),s.drawArrays(s.TRIANGLES,0,o),r+this.shape[0]*this.shape[1]}}}(),h.pick=function(t,e,r){var n=this.pickOffset,i=this.shape[0]*this.shape[1];if(r<n||r>=n+i)return null;var a=r-n,o=this.xData,s=this.yData;return{object:this,pointId:a,dataCoord:[o[a%this.shape[0]],s[a/this.shape[0]|0]]}},h.update=function(t){var e=(t=t||{}).shape||[0,0],r=t.x||i(e[0]),o=t.y||i(e[1]),s=t.z||new Float32Array(e[0]*e[1]);this.xData=r,this.yData=o;var l=t.colorLevels||[0],c=t.colorValues||[0,0,0,1],u=l.length,h=this.bounds,p=h[0]=r[0],d=h[1]=o[0],g=1/((h[2]=r[r.length-1])-p),v=1/((h[3]=o[o.length-1])-d),m=e[0],y=e[1];this.shape=[m,y];var x=(m-1)*(y-1)*(f.length>>>1);this.numVertices=x;for(var b=a.mallocUint8(4*x),_=a.mallocFloat32(2*x),w=a.mallocUint8(2*x),k=a.mallocUint32(x),T=0,A=0;A<y-1;++A)for(var M=v*(o[A]-d),S=v*(o[A+1]-d),E=0;E<m-1;++E)for(var C=g*(r[E]-p),L=g*(r[E+1]-p),P=0;P<f.length;P+=2){var O,z,I,D,R=f[P],F=f[P+1],B=s[(A+F)*m+(E+R)],N=n.le(l,B);if(N<0)O=c[0],z=c[1],I=c[2],D=c[3];else if(N===u-1)O=c[4*u-4],z=c[4*u-3],I=c[4*u-2],D=c[4*u-1];else{var j=(B-l[N])/(l[N+1]-l[N]),U=1-j,V=4*N,q=4*(N+1);O=U*c[V]+j*c[q],z=U*c[V+1]+j*c[q+1],I=U*c[V+2]+j*c[q+2],D=U*c[V+3]+j*c[q+3]}b[4*T]=255*O,b[4*T+1]=255*z,b[4*T+2]=255*I,b[4*T+3]=255*D,_[2*T]=.5*C+.5*L,_[2*T+1]=.5*M+.5*S,w[2*T]=R,w[2*T+1]=F,k[T]=A*m+E,T+=1}this.positionBuffer.update(_),this.weightBuffer.update(w),this.colorBuffer.update(b),this.idBuffer.update(k),a.free(_),a.free(b),a.free(w),a.free(k)},h.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.positionBuffer.dispose(),this.weightBuffer.dispose(),this.colorBuffer.dispose(),this.idBuffer.dispose(),this.plot.removeObject(this)}},{\"./lib/shaders\":252,\"binary-search-bounds\":253,\"gl-buffer\":241,\"gl-shader\":301,\"iota-array\":416,\"typedarray-pool\":545}],252:[function(t,e,r){\"use strict\";var n=t(\"glslify\");e.exports={fragment:n([\"precision lowp float;\\n#define GLSLIFY 1\\nvarying vec4 fragColor;\\nvoid main() {\\n  gl_FragColor = vec4(fragColor.rgb * fragColor.a, fragColor.a);\\n}\\n\"]),vertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 color;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  fragColor = color;\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"]),pickFragment:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nuniform vec2 shape;\\nuniform vec4 pickOffset;\\n\\nvoid main() {\\n  vec2 d = step(.5, vWeight);\\n  vec4 id = fragId + pickOffset;\\n  id.x += d.x + d.y*shape.x;\\n\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  gl_FragColor = id/255.;\\n}\\n\"]),pickVertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nvoid main() {\\n  vWeight = weight;\\n\\n  fragId = pickId;\\n\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"])}},{glslify:409}],253:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],254:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, nextPosition;\\nattribute float arcLength, lineWidth;\\nattribute vec4 color;\\n\\nuniform vec2 screenShape;\\nuniform float pixelRatio;\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 fragColor;\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  vec4 startPoint = project(position);\\n  vec4 endPoint   = project(nextPosition);\\n\\n  vec2 A = startPoint.xy / startPoint.w;\\n  vec2 B =   endPoint.xy /   endPoint.w;\\n\\n  float clipAngle = atan(\\n    (B.y - A.y) * screenShape.y,\\n    (B.x - A.x) * screenShape.x\\n  );\\n\\n  vec2 offset = 0.5 * pixelRatio * lineWidth * vec2(\\n    sin(clipAngle),\\n    -cos(clipAngle)\\n  ) / screenShape;\\n\\n  gl_Position = vec4(startPoint.xy + startPoint.w * offset, startPoint.zw);\\n\\n  worldPosition = position;\\n  pixelArcLength = arcLength;\\n  fragColor = color;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3      clipBounds[2];\\nuniform sampler2D dashTexture;\\nuniform float     dashScale;\\nuniform float     opacity;\\n\\nvarying vec3    worldPosition;\\nvarying float   pixelArcLength;\\nvarying vec4    fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], worldPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  float dashWeight = texture2D(dashTexture, vec2(dashScale * pixelArcLength, 0)).r;\\n  if(dashWeight < 0.5) {\\n    discard;\\n  }\\n  gl_FragColor = fragColor * opacity;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\n#define FLOAT_MAX  1.70141184e38\\n#define FLOAT_MIN  1.17549435e-38\\n\\nlowp vec4 encode_float_1540259130(highp float v) {\\n  highp float av = abs(v);\\n\\n  //Handle special cases\\n  if(av < FLOAT_MIN) {\\n    return vec4(0.0, 0.0, 0.0, 0.0);\\n  } else if(v > FLOAT_MAX) {\\n    return vec4(127.0, 128.0, 0.0, 0.0) / 255.0;\\n  } else if(v < -FLOAT_MAX) {\\n    return vec4(255.0, 128.0, 0.0, 0.0) / 255.0;\\n  }\\n\\n  highp vec4 c = vec4(0,0,0,0);\\n\\n  //Compute exponent and mantissa\\n  highp float e = floor(log2(av));\\n  highp float m = av * pow(2.0, -e) - 1.0;\\n  \\n  //Unpack mantissa\\n  c[1] = floor(128.0 * m);\\n  m -= c[1] / 128.0;\\n  c[2] = floor(32768.0 * m);\\n  m -= c[2] / 32768.0;\\n  c[3] = floor(8388608.0 * m);\\n  \\n  //Unpack exponent\\n  highp float ebias = e + 127.0;\\n  c[0] = floor(ebias / 2.0);\\n  ebias -= c[0] * 2.0;\\n  c[1] += floor(ebias) * 128.0; \\n\\n  //Unpack sign bit\\n  c[0] += 128.0 * step(0.0, -v);\\n\\n  //Scale back to range\\n  return c / 255.0;\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform float pickId;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], worldPosition)) discard;\\n\\n  gl_FragColor = vec4(pickId/255.0, encode_float_1540259130(pixelArcLength).xyz);\\n}\"]),l=[{name:\"position\",type:\"vec3\"},{name:\"nextPosition\",type:\"vec3\"},{name:\"arcLength\",type:\"float\"},{name:\"lineWidth\",type:\"float\"},{name:\"color\",type:\"vec4\"}];r.createShader=function(t){return i(t,a,o,null,l)},r.createPickShader=function(t){return i(t,a,s,null,l)}},{\"gl-shader\":301,glslify:409}],255:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl||t.scene&&t.scene.gl,r=u(e);r.attributes.position.location=0,r.attributes.nextPosition.location=1,r.attributes.arcLength.location=2,r.attributes.lineWidth.location=3,r.attributes.color.location=4;var o=h(e);o.attributes.position.location=0,o.attributes.nextPosition.location=1,o.attributes.arcLength.location=2,o.attributes.lineWidth.location=3,o.attributes.color.location=4;for(var s=n(e),c=i(e,[{buffer:s,size:3,offset:0,stride:48},{buffer:s,size:3,offset:12,stride:48},{buffer:s,size:1,offset:24,stride:48},{buffer:s,size:1,offset:28,stride:48},{buffer:s,size:4,offset:32,stride:48}]),f=l(new Array(1024),[256,1,4]),p=0;p<1024;++p)f.data[p]=255;var d=a(e,f);d.wrap=e.REPEAT;var g=new v(e,r,o,s,c,d);return g.update(t),g};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"gl-texture2d\"),o=t(\"glsl-read-float\"),s=t(\"binary-search-bounds\"),l=t(\"ndarray\"),c=t(\"./lib/shaders\"),u=c.createShader,h=c.createPickShader,f=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function p(t,e){for(var r=0,n=0;n<3;++n){var i=t[n]-e[n];r+=i*i}return Math.sqrt(r)}function d(t){for(var e=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],r=0;r<3;++r)e[0][r]=Math.max(t[0][r],e[0][r]),e[1][r]=Math.min(t[1][r],e[1][r]);return e}function g(t,e,r,n){this.arcLength=t,this.position=e,this.index=r,this.dataCoordinate=n}function v(t,e,r,n,i,a){this.gl=t,this.shader=e,this.pickShader=r,this.buffer=n,this.vao=i,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.points=[],this.arcLength=[],this.vertexCount=0,this.bounds=[[0,0,0],[0,0,0]],this.pickId=0,this.lineWidth=1,this.texture=a,this.dashScale=1,this.opacity=1,this.hasAlpha=!1,this.dirty=!0,this.pixelRatio=1}var m=v.prototype;m.isTransparent=function(){return this.hasAlpha},m.isOpaque=function(){return!this.hasAlpha},m.pickSlots=1,m.setPickBase=function(t){this.pickId=t},m.drawTransparent=m.draw=function(t){if(this.vertexCount){var e=this.gl,r=this.shader,n=this.vao;r.bind(),r.uniforms={model:t.model||f,view:t.view||f,projection:t.projection||f,clipBounds:d(this.clipBounds),dashTexture:this.texture.bind(),dashScale:this.dashScale/this.arcLength[this.arcLength.length-1],opacity:this.opacity,screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},m.drawPick=function(t){if(this.vertexCount){var e=this.gl,r=this.pickShader,n=this.vao;r.bind(),r.uniforms={model:t.model||f,view:t.view||f,projection:t.projection||f,pickId:this.pickId,clipBounds:d(this.clipBounds),screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},m.update=function(t){var e,r;this.dirty=!0;var n=!!t.connectGaps;\"dashScale\"in t&&(this.dashScale=t.dashScale),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var i=[],a=[],o=[],c=0,u=0,h=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],f=t.position||t.positions;if(f){var d=t.color||t.colors||[0,0,0,1],g=t.lineWidth||1,v=!1;t:for(e=1;e<f.length;++e){var m,y,x,b=f[e-1],_=f[e];for(a.push(c),o.push(b.slice()),r=0;r<3;++r){if(isNaN(b[r])||isNaN(_[r])||!isFinite(b[r])||!isFinite(_[r])){if(!n&&i.length>0){for(var w=0;w<24;++w)i.push(i[i.length-12]);u+=2,v=!0}continue t}h[0][r]=Math.min(h[0][r],b[r],_[r]),h[1][r]=Math.max(h[1][r],b[r],_[r])}Array.isArray(d[0])?(m=d.length>e-1?d[e-1]:d.length>0?d[d.length-1]:[0,0,0,1],y=d.length>e?d[e]:d.length>0?d[d.length-1]:[0,0,0,1]):m=y=d,3===m.length&&(m=[m[0],m[1],m[2],1]),3===y.length&&(y=[y[0],y[1],y[2],1]),!this.hasAlpha&&m[3]<1&&(this.hasAlpha=!0),x=Array.isArray(g)?g.length>e-1?g[e-1]:g.length>0?g[g.length-1]:[0,0,0,1]:g;var k=c;if(c+=p(b,_),v){for(r=0;r<2;++r)i.push(b[0],b[1],b[2],_[0],_[1],_[2],k,x,m[0],m[1],m[2],m[3]);u+=2,v=!1}i.push(b[0],b[1],b[2],_[0],_[1],_[2],k,x,m[0],m[1],m[2],m[3],b[0],b[1],b[2],_[0],_[1],_[2],k,-x,m[0],m[1],m[2],m[3],_[0],_[1],_[2],b[0],b[1],b[2],c,-x,y[0],y[1],y[2],y[3],_[0],_[1],_[2],b[0],b[1],b[2],c,x,y[0],y[1],y[2],y[3]),u+=4}}if(this.buffer.update(i),a.push(c),o.push(f[f.length-1].slice()),this.bounds=h,this.vertexCount=u,this.points=o,this.arcLength=a,\"dashes\"in t){var T=t.dashes.slice();for(T.unshift(0),e=1;e<T.length;++e)T[e]=T[e-1]+T[e];var A=l(new Array(1024),[256,1,4]);for(e=0;e<256;++e){for(r=0;r<4;++r)A.set(e,0,r,0);1&s.le(T,T[T.length-1]*e/255)?A.set(e,0,0,0):A.set(e,0,0,255)}this.texture.setPixels(A)}},m.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()},m.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=o(t.value[0],t.value[1],t.value[2],0),r=s.le(this.arcLength,e);if(r<0)return null;if(r===this.arcLength.length-1)return new g(this.arcLength[this.arcLength.length-1],this.points[this.points.length-1].slice(),r);for(var n=this.points[r],i=this.points[Math.min(r+1,this.points.length-1)],a=(e-this.arcLength[r])/(this.arcLength[r+1]-this.arcLength[r]),l=1-a,c=[0,0,0],u=0;u<3;++u)c[u]=l*n[u]+a*i[u];var h=Math.min(a<.5?r:r+1,this.points.length-1);return new g(e,c,h,this.points[h])}},{\"./lib/shaders\":254,\"binary-search-bounds\":256,\"gl-buffer\":241,\"gl-texture2d\":322,\"gl-vao\":327,\"glsl-read-float\":400,ndarray:450}],256:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],257:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r*a-i*n;return o?(o=1/o,t[0]=a*o,t[1]=-n*o,t[2]=-i*o,t[3]=r*o,t):null}},{}],258:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=u*o-s*c,f=-u*a+s*l,p=c*a-o*l,d=r*h+n*f+i*p;return d?(d=1/d,t[0]=h*d,t[1]=(-u*n+i*c)*d,t[2]=(s*n-i*o)*d,t[3]=f*d,t[4]=(u*r-i*l)*d,t[5]=(-s*r+i*a)*d,t[6]=p*d,t[7]=(-c*r+n*l)*d,t[8]=(o*r-n*a)*d,t):null}},{}],259:[function(t,e,r){e.exports=function(t){var e=new Float32Array(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e}},{}],260:[function(t,e,r){e.exports=function(){var t=new Float32Array(16);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],261:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3],a=t[4],o=t[5],s=t[6],l=t[7],c=t[8],u=t[9],h=t[10],f=t[11],p=t[12],d=t[13],g=t[14],v=t[15];return(e*o-r*a)*(h*v-f*g)-(e*s-n*a)*(u*v-f*d)+(e*l-i*a)*(u*g-h*d)+(r*s-n*o)*(c*v-f*p)-(r*l-i*o)*(c*g-h*p)+(n*l-i*s)*(c*d-u*p)}},{}],262:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r+r,s=n+n,l=i+i,c=r*o,u=n*o,h=n*s,f=i*o,p=i*s,d=i*l,g=a*o,v=a*s,m=a*l;return t[0]=1-h-d,t[1]=u+m,t[2]=f-v,t[3]=0,t[4]=u-m,t[5]=1-c-d,t[6]=p+g,t[7]=0,t[8]=f+v,t[9]=p-g,t[10]=1-c-h,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],263:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=n+n,l=i+i,c=a+a,u=n*s,h=n*l,f=n*c,p=i*l,d=i*c,g=a*c,v=o*s,m=o*l,y=o*c;return t[0]=1-(p+g),t[1]=h+y,t[2]=f-m,t[3]=0,t[4]=h-y,t[5]=1-(u+g),t[6]=d+v,t[7]=0,t[8]=f+m,t[9]=d-v,t[10]=1-(u+p),t[11]=0,t[12]=r[0],t[13]=r[1],t[14]=r[2],t[15]=1,t}},{}],264:[function(t,e,r){e.exports=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],265:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],g=e[13],v=e[14],m=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,k=i*c-a*l,T=u*g-h*d,A=u*v-f*d,M=u*m-p*d,S=h*v-f*g,E=h*m-p*g,C=f*m-p*v,L=y*C-x*E+b*S+_*M-w*A+k*T;if(!L)return null;return L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(i*E-n*C-a*S)*L,t[2]=(g*k-v*w+m*_)*L,t[3]=(f*w-h*k-p*_)*L,t[4]=(l*M-o*C-c*A)*L,t[5]=(r*C-i*M+a*A)*L,t[6]=(v*b-d*k-m*x)*L,t[7]=(u*k-f*b+p*x)*L,t[8]=(o*E-s*M+c*T)*L,t[9]=(n*M-r*E-a*T)*L,t[10]=(d*w-g*b+m*y)*L,t[11]=(h*b-u*w-p*y)*L,t[12]=(s*A-o*S-l*T)*L,t[13]=(r*S-n*A+i*T)*L,t[14]=(g*x-d*_-v*y)*L,t[15]=(u*_-h*x+f*y)*L,t}},{}],266:[function(t,e,r){var n=t(\"./identity\");e.exports=function(t,e,r,i){var a,o,s,l,c,u,h,f,p,d,g=e[0],v=e[1],m=e[2],y=i[0],x=i[1],b=i[2],_=r[0],w=r[1],k=r[2];if(Math.abs(g-_)<1e-6&&Math.abs(v-w)<1e-6&&Math.abs(m-k)<1e-6)return n(t);h=g-_,f=v-w,p=m-k,d=1/Math.sqrt(h*h+f*f+p*p),a=x*(p*=d)-b*(f*=d),o=b*(h*=d)-y*p,s=y*f-x*h,(d=Math.sqrt(a*a+o*o+s*s))?(a*=d=1/d,o*=d,s*=d):(a=0,o=0,s=0);l=f*s-p*o,c=p*a-h*s,u=h*o-f*a,(d=Math.sqrt(l*l+c*c+u*u))?(l*=d=1/d,c*=d,u*=d):(l=0,c=0,u=0);return t[0]=a,t[1]=l,t[2]=h,t[3]=0,t[4]=o,t[5]=c,t[6]=f,t[7]=0,t[8]=s,t[9]=u,t[10]=p,t[11]=0,t[12]=-(a*g+o*v+s*m),t[13]=-(l*g+c*v+u*m),t[14]=-(h*g+f*v+p*m),t[15]=1,t}},{\"./identity\":264}],267:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],g=e[12],v=e[13],m=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*h+w*g,t[1]=x*i+b*l+_*f+w*v,t[2]=x*a+b*c+_*p+w*m,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*h+w*g,t[5]=x*i+b*l+_*f+w*v,t[6]=x*a+b*c+_*p+w*m,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*h+w*g,t[9]=x*i+b*l+_*f+w*v,t[10]=x*a+b*c+_*p+w*m,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*h+w*g,t[13]=x*i+b*l+_*f+w*v,t[14]=x*a+b*c+_*p+w*m,t[15]=x*o+b*u+_*d+w*y,t}},{}],268:[function(t,e,r){e.exports=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t}},{}],269:[function(t,e,r){e.exports=function(t,e,r,n,i){var a=1/Math.tan(e/2),o=1/(n-i);return t[0]=a/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=a,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=(i+n)*o,t[11]=-1,t[12]=0,t[13]=0,t[14]=2*i*n*o,t[15]=0,t}},{}],270:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_,w,k,T,A,M,S,E=n[0],C=n[1],L=n[2],P=Math.sqrt(E*E+C*C+L*L);if(Math.abs(P)<1e-6)return null;E*=P=1/P,C*=P,L*=P,i=Math.sin(r),a=Math.cos(r),o=1-a,s=e[0],l=e[1],c=e[2],u=e[3],h=e[4],f=e[5],p=e[6],d=e[7],g=e[8],v=e[9],m=e[10],y=e[11],x=E*E*o+a,b=C*E*o+L*i,_=L*E*o-C*i,w=E*C*o-L*i,k=C*C*o+a,T=L*C*o+E*i,A=E*L*o+C*i,M=C*L*o-E*i,S=L*L*o+a,t[0]=s*x+h*b+g*_,t[1]=l*x+f*b+v*_,t[2]=c*x+p*b+m*_,t[3]=u*x+d*b+y*_,t[4]=s*w+h*k+g*T,t[5]=l*w+f*k+v*T,t[6]=c*w+p*k+m*T,t[7]=u*w+d*k+y*T,t[8]=s*A+h*M+g*S,t[9]=l*A+f*M+v*S,t[10]=c*A+p*M+m*S,t[11]=u*A+d*M+y*S,e!==t&&(t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t}},{}],271:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+h*n,t[7]=l*i+f*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=h*i-s*n,t[11]=f*i-l*n,t}},{}],272:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[8],u=e[9],h=e[10],f=e[11];e!==t&&(t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i-c*n,t[1]=o*i-u*n,t[2]=s*i-h*n,t[3]=l*i-f*n,t[8]=a*n+c*i,t[9]=o*n+u*i,t[10]=s*n+h*i,t[11]=l*n+f*i,t}},{}],273:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+h*n,t[3]=l*i+f*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=h*i-s*n,t[7]=f*i-l*n,t}},{}],274:[function(t,e,r){e.exports=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},{}],275:[function(t,e,r){e.exports=function(t,e,r){var n,i,a,o,s,l,c,u,h,f,p,d,g=r[0],v=r[1],m=r[2];e===t?(t[12]=e[0]*g+e[4]*v+e[8]*m+e[12],t[13]=e[1]*g+e[5]*v+e[9]*m+e[13],t[14]=e[2]*g+e[6]*v+e[10]*m+e[14],t[15]=e[3]*g+e[7]*v+e[11]*m+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*g+s*v+h*m+e[12],t[13]=i*g+l*v+f*m+e[13],t[14]=a*g+c*v+p*m+e[14],t[15]=o*g+u*v+d*m+e[15]);return t}},{}],276:[function(t,e,r){e.exports=function(t,e){if(t===e){var r=e[1],n=e[2],i=e[3],a=e[6],o=e[7],s=e[11];t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=r,t[6]=e[9],t[7]=e[13],t[8]=n,t[9]=a,t[11]=e[14],t[12]=i,t[13]=o,t[14]=s}else t[0]=e[0],t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=e[1],t[5]=e[5],t[6]=e[9],t[7]=e[13],t[8]=e[2],t[9]=e[6],t[10]=e[10],t[11]=e[14],t[12]=e[3],t[13]=e[7],t[14]=e[11],t[15]=e[15];return t}},{}],277:[function(t,e,r){\"use strict\";e.exports=function(t,e){switch(e.length){case 0:break;case 1:t[0]=1/e[0];break;case 4:n(t,e);break;case 9:i(t,e);break;case 16:a(t,e);break;default:throw new Error(\"currently supports matrices up to 4x4\")}return t};var n=t(\"gl-mat2/invert\"),i=t(\"gl-mat3/invert\"),a=t(\"gl-mat4/invert\")},{\"gl-mat2/invert\":257,\"gl-mat3/invert\":258,\"gl-mat4/invert\":265}],278:[function(t,e,r){\"use strict\";var n=t(\"barycentric\"),i=t(\"polytope-closest-point/lib/closest_point_2d.js\");function a(t,e){for(var r=[0,0,0,0],n=0;n<4;++n)for(var i=0;i<4;++i)r[i]+=t[4*n+i]*e[n];return r}function o(t,e,r,n,i){for(var o=a(n,a(r,a(e,[t[0],t[1],t[2],1]))),s=0;s<3;++s)o[s]/=o[3];return[.5*i[0]*(1+o[0]),.5*i[1]*(1-o[1])]}e.exports=function(t,e,r,a,s,l){if(1===t.length)return[0,t[0].slice()];for(var c=new Array(t.length),u=0;u<t.length;++u)c[u]=o(t[u],r,a,s,l);for(var h=0,f=1/0,u=0;u<c.length;++u){for(var p=0,d=0;d<2;++d)p+=Math.pow(c[u][d]-e[d],2);p<f&&(f=p,h=u)}for(var g=function(t,e){if(2===t.length){for(var r=0,a=0,o=0;o<2;++o)r+=Math.pow(e[o]-t[0][o],2),a+=Math.pow(e[o]-t[1][o],2);return r=Math.sqrt(r),a=Math.sqrt(a),r+a<1e-6?[1,0]:[a/(r+a),r/(a+r)]}if(3===t.length){var s=[0,0];return i(t[0],t[1],t[2],e,s),n(t,s)}return[]}(c,e),v=0,u=0;u<3;++u){if(g[u]<-.001||g[u]>1.0001)return null;v+=g[u]}if(Math.abs(v-1)>.001)return null;return[h,function(t,e){for(var r=[0,0,0],n=0;n<t.length;++n)for(var i=t[n],a=e[n],o=0;o<3;++o)r[o]+=a*i[o];return r}(t,g),g]}},{barycentric:73,\"polytope-closest-point/lib/closest_point_2d.js\":481}],279:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, normal;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  gl_Position      = project(position);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * vec4(position , 1.0);\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal  = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  f_color          = color;\\n  f_data           = position;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\n//#pragma glslify: beckmann = require(glsl-specular-beckmann) // used in gl-surface3d\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (f_color.a == 0.0 ||\\n    outOfRange(clipBounds[0], clipBounds[1], f_data)\\n  ) discard;\\n\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  //float specular = max(0.0, beckmann(L, V, N, roughness)); // used in gl-surface3d\\n\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = vec4(f_color.rgb, 1.0) * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * f_color.a;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_color = color;\\n  f_data  = position;\\n  f_uv    = uv;\\n}\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_data)) discard;\\n\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\nattribute float pointSize;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0 ,0.0 ,0.0);\\n  } else {\\n    gl_Position = projection * view * model * vec4(position, 1.0);\\n  }\\n  gl_PointSize = pointSize;\\n  f_color = color;\\n  f_uv = uv;\\n}\"]),c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  vec2 pointR = gl_PointCoord.xy - vec2(0.5, 0.5);\\n  if(dot(pointR, pointR) > 0.25) {\\n    discard;\\n  }\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_id        = id;\\n  f_position  = position;\\n}\"]),h=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]),f=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3  position;\\nattribute float pointSize;\\nattribute vec4  id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0, 0.0, 0.0);\\n  } else {\\n    gl_Position  = projection * view * model * vec4(position, 1.0);\\n    gl_PointSize = pointSize;\\n  }\\n  f_id         = id;\\n  f_position   = position;\\n}\"]),p=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n}\"]),d=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec3 contourColor;\\n\\nvoid main() {\\n  gl_FragColor = vec4(contourColor, 1.0);\\n}\\n\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.wireShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.pointShader={vertex:l,fragment:c,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"pointSize\",type:\"float\"}]},r.pickShader={vertex:u,fragment:h,attributes:[{name:\"position\",type:\"vec3\"},{name:\"id\",type:\"vec4\"}]},r.pointPickShader={vertex:f,fragment:h,attributes:[{name:\"position\",type:\"vec3\"},{name:\"pointSize\",type:\"float\"},{name:\"id\",type:\"vec4\"}]},r.contourShader={vertex:p,fragment:d,attributes:[{name:\"position\",type:\"vec3\"}]}},{glslify:409}],280:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./lib/shaders\"),g=t(\"./lib/closest-point\"),v=d.meshShader,m=d.wireShader,y=d.pointShader,x=d.pickShader,b=d.pointPickShader,_=d.contourShader,w=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function k(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_,k,T,A,M,S){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.lineShader=n,this.pointShader=i,this.pickShader=a,this.pointPickShader=o,this.contourShader=s,this.trianglePositions=l,this.triangleColors=u,this.triangleNormals=f,this.triangleUVs=h,this.triangleIds=c,this.triangleVAO=p,this.triangleCount=0,this.lineWidth=1,this.edgePositions=d,this.edgeColors=v,this.edgeUVs=m,this.edgeIds=g,this.edgeVAO=y,this.edgeCount=0,this.pointPositions=x,this.pointColors=_,this.pointUVs=k,this.pointSizes=T,this.pointIds=b,this.pointVAO=A,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=M,this.contourVAO=S,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.hasAlpha=!1,this.opacityscale=!1,this._model=w,this._view=w,this._projection=w,this._resolution=[1,1]}var T=k.prototype;function A(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}function M(t){var e=n(t,y.vertex,y.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.pointSize.location=4,e}function S(t){var e=n(t,x.vertex,x.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e}function E(t){var e=n(t,b.vertex,b.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.pointSize.location=4,e}function C(t){var e=n(t,_.vertex,_.fragment);return e.attributes.position.location=0,e}T.isOpaque=function(){return!this.hasAlpha},T.isTransparent=function(){return this.hasAlpha},T.pickSlots=1,T.setPickBase=function(t){this.pickId=t},T.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=i[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},T.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=t.opacity,this.opacity<1&&(this.hasAlpha=!0)),\"opacityscale\"in t&&(this.opacityscale=t.opacityscale,this.hasAlpha=!0),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t,e){for(var r=h({colormap:t,nshades:256,format:\"rgba\"}),n=new Uint8Array(1024),i=0;i<256;++i){for(var a=r[i],o=0;o<3;++o)n[4*i+o]=a[o];n[4*i+3]=e?255*A(i/255,e):255*a[3]}return u(n,[256,256,4],[4,0,1])}(t.colormap,this.opacityscale)),this.texture.generateMipmap());var r=t.cells,n=t.positions;if(n&&r){var i=[],a=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[];this.cells=r,this.positions=n;var w=t.vertexNormals,k=t.cellNormals,T=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,M=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!k&&(k=s.faceNormals(r,n,M)),k||w||(w=s.vertexNormals(r,n,T));var S=t.vertexColors,E=t.cellColors,C=t.meshColor||[1,1,1,1],L=t.vertexUVs,P=t.vertexIntensity,O=t.cellUVs,z=t.cellIntensity,I=1/0,D=-1/0;if(!L&&!O)if(P)if(t.vertexIntensityBounds)I=+t.vertexIntensityBounds[0],D=+t.vertexIntensityBounds[1];else for(var R=0;R<P.length;++R){var F=P[R];I=Math.min(I,F),D=Math.max(D,F)}else if(z)for(R=0;R<z.length;++R){F=z[R];I=Math.min(I,F),D=Math.max(D,F)}else for(R=0;R<n.length;++R){F=n[R][2];I=Math.min(I,F),D=Math.max(D,F)}this.intensity=P||(z?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,z):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var B=t.pointSizes,N=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(R=0;R<n.length;++R)for(var j=n[R],U=0;U<3;++U)!isNaN(j[U])&&isFinite(j[U])&&(this.bounds[0][U]=Math.min(this.bounds[0][U],j[U]),this.bounds[1][U]=Math.max(this.bounds[1][U],j[U]));var V=0,q=0,H=0;t:for(R=0;R<r.length;++R){var G=r[R];switch(G.length){case 1:for(j=n[W=G[0]],U=0;U<3;++U)if(isNaN(j[U])||!isFinite(j[U]))continue t;m.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?y.push(X[0],X[1],X[2],this.opacity):(y.push(X[0],X[1],X[2],X[3]*this.opacity),!this.hasAlpha&&X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],x.push(Z[0],Z[1]),B?b.push(B[W]):b.push(N),_.push(R),H+=1;break;case 2:for(U=0;U<2;++U){j=n[W=G[U]];for(var Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t}for(U=0;U<2;++U){j=n[W=G[U]];p.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?d.push(X[0],X[1],X[2],this.opacity):(d.push(X[0],X[1],X[2],X[3]*this.opacity),!this.hasAlpha&&X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],g.push(Z[0],Z[1]),v.push(R)}q+=1;break;case 3:for(U=0;U<3;++U)for(j=n[W=G[U]],Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t;for(U=0;U<3;++U){var W,X,Z,J;j=n[W=G[2-U]];i.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?a.push(X[0],X[1],X[2],this.opacity):(a.push(X[0],X[1],X[2],X[3]*this.opacity),!this.hasAlpha&&X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],c.push(Z[0],Z[1]),J=w?w[W]:k[R],l.push(J[0],J[1],J[2]),f.push(R)}V+=1}}this.pointCount=H,this.edgeCount=q,this.triangleCount=V,this.pointPositions.update(m),this.pointColors.update(y),this.pointUVs.update(x),this.pointSizes.update(b),this.pointIds.update(new Uint32Array(_)),this.edgePositions.update(p),this.edgeColors.update(d),this.edgeUVs.update(g),this.edgeIds.update(new Uint32Array(v)),this.trianglePositions.update(i),this.triangleColors.update(a),this.triangleUVs.update(c),this.triangleNormals.update(l),this.triangleIds.update(new Uint32Array(f))}},T.drawTransparent=T.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:w.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h,f=u[15];for(o=0;o<3;++o)f+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];s.lightPosition[o]=p/f}this.triangleCount>0&&((h=this.triShader).bind(),h.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind());this.edgeCount>0&&this.lineWidth>0&&((h=this.lineShader).bind(),h.uniforms=s,this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind());this.pointCount>0&&((h=this.pointShader).bind(),h.uniforms=s,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind());this.contourEnable&&this.contourCount>0&&this.contourLineWidth>0&&((h=this.contourShader).bind(),h.uniforms=s,this.contourVAO.bind(),e.drawArrays(e.LINES,0,this.contourCount),this.contourVAO.unbind())},T.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s,l={model:r,view:n,projection:i,clipBounds:a,pickId:this.pickId/255};((s=this.pickShader).bind(),s.uniforms=l,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind()),this.pointCount>0)&&((s=this.pointPickShader).bind(),s.uniforms=l,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind())},T.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;for(var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions,i=new Array(r.length),a=0;a<r.length;++a)i[a]=n[r[a]];var o=g(i,[t.coord[0],this._resolution[1]-t.coord[1]],this._model,this._view,this._projection,this._resolution);if(!o)return null;var s=o[2],l=0;for(a=0;a<r.length;++a)l+=s[a]*this.intensity[r[a]];return{position:o[1],index:r[o[0]],cell:r,cellId:e,intensity:l,dataCoordinate:this.positions[r[o[0]]]}},T.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.lineShader.dispose(),this.pointShader.dispose(),this.pickShader.dispose(),this.pointPickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose(),this.contourShader.dispose()},e.exports=function(t,e){if(1===arguments.length&&(t=(e=t).gl),!(t.getExtension(\"OES_standard_derivatives\")||t.getExtension(\"MOZ_OES_standard_derivatives\")||t.getExtension(\"WEBKIT_OES_standard_derivatives\")))throw new Error(\"derivatives not supported\");var r=function(t){var e=n(t,v.vertex,v.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.normal.location=4,e}(t),s=function(t){var e=n(t,m.vertex,m.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e}(t),l=M(t),c=S(t),h=E(t),f=C(t),p=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));p.generateMipmap(),p.minFilter=t.LINEAR_MIPMAP_LINEAR,p.magFilter=t.LINEAR;var d=i(t),g=i(t),y=i(t),x=i(t),b=i(t),_=a(t,[{buffer:d,type:t.FLOAT,size:3},{buffer:b,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:g,type:t.FLOAT,size:4},{buffer:y,type:t.FLOAT,size:2},{buffer:x,type:t.FLOAT,size:3}]),w=i(t),T=i(t),A=i(t),L=i(t),P=a(t,[{buffer:w,type:t.FLOAT,size:3},{buffer:L,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:T,type:t.FLOAT,size:4},{buffer:A,type:t.FLOAT,size:2}]),O=i(t),z=i(t),I=i(t),D=i(t),R=i(t),F=a(t,[{buffer:O,type:t.FLOAT,size:3},{buffer:R,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:z,type:t.FLOAT,size:4},{buffer:I,type:t.FLOAT,size:2},{buffer:D,type:t.FLOAT,size:1}]),B=i(t),N=new k(t,p,r,s,l,c,h,f,d,b,g,y,x,_,w,L,T,A,P,O,R,z,I,D,F,B,a(t,[{buffer:B,type:t.FLOAT,size:3}]));return N.update(e),N}},{\"./lib/closest-point\":278,\"./lib/shaders\":279,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-shader\":301,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,normals:453,\"simplicial-complex-contour\":518,\"typedarray-pool\":545}],281:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[0,0,0,1,1,0,1,1]),s=i(e,a.boxVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawBox=(s=[0,0],l=[0,0],function(t,e,r,n,i){var a=this.plot,o=this.shader,c=a.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,o.uniforms.lo=s,o.uniforms.hi=l,o.uniforms.color=i,c.drawArrays(c.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":284,\"gl-buffer\":241,\"gl-shader\":301}],282:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,o.gridVert,o.gridFrag),l=i(e,o.tickVert,o.gridFrag);return new s(t,r,a,l)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"binary-search-bounds\"),o=t(\"./shaders\");function s(t,e,r,n){this.plot=t,this.vbo=e,this.shader=r,this.tickShader=n,this.ticks=[[],[]]}function l(t,e){return t-e}var c,u,h,f,p,d=s.prototype;d.draw=(c=[0,0],u=[0,0],h=[0,0],function(){for(var t=this.plot,e=this.vbo,r=this.shader,n=this.ticks,i=t.gl,a=t._tickBounds,o=t.dataBox,s=t.viewBox,l=t.gridLineWidth,f=t.gridLineColor,p=t.gridLineEnable,d=t.pixelRatio,g=0;g<2;++g){var v=a[g],m=a[g+2]-v,y=.5*(o[g+2]+o[g]),x=o[g+2]-o[g];u[g]=2*m/x,c[g]=2*(v-y)/x}r.bind(),e.bind(),r.attributes.dataCoord.pointer(),r.uniforms.dataShift=c,r.uniforms.dataScale=u;var b=0;for(g=0;g<2;++g){h[0]=h[1]=0,h[g]=1,r.uniforms.dataAxis=h,r.uniforms.lineWidth=l[g]/(s[g+2]-s[g])*d,r.uniforms.color=f[g];var _=6*n[g].length;p[g]&&_&&i.drawArrays(i.TRIANGLES,b,_),b+=_}}),d.drawTickMarks=function(){var t=[0,0],e=[0,0],r=[1,0],n=[0,1],i=[0,0],o=[0,0];return function(){for(var s=this.plot,c=this.vbo,u=this.tickShader,h=this.ticks,f=s.gl,p=s._tickBounds,d=s.dataBox,g=s.viewBox,v=s.pixelRatio,m=s.screenBox,y=m[2]-m[0],x=m[3]-m[1],b=g[2]-g[0],_=g[3]-g[1],w=0;w<2;++w){var k=p[w],T=p[w+2]-k,A=.5*(d[w+2]+d[w]),M=d[w+2]-d[w];e[w]=2*T/M,t[w]=2*(k-A)/M}e[0]*=b/y,t[0]*=b/y,e[1]*=_/x,t[1]*=_/x,u.bind(),c.bind(),u.attributes.dataCoord.pointer();var S=u.uniforms;S.dataShift=t,S.dataScale=e;var E=s.tickMarkLength,C=s.tickMarkWidth,L=s.tickMarkColor,P=6*h[0].length,O=Math.min(a.ge(h[0],(d[0]-p[0])/(p[2]-p[0]),l),h[0].length),z=Math.min(a.gt(h[0],(d[2]-p[0])/(p[2]-p[0]),l),h[0].length),I=0+6*O,D=6*Math.max(0,z-O),R=Math.min(a.ge(h[1],(d[1]-p[1])/(p[3]-p[1]),l),h[1].length),F=Math.min(a.gt(h[1],(d[3]-p[1])/(p[3]-p[1]),l),h[1].length),B=P+6*R,N=6*Math.max(0,F-R);i[0]=2*(g[0]-E[1])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=E[1]*v/y,o[1]=C[1]*v/x,N&&(S.color=L[1],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,f.drawArrays(f.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[1]-E[0])/x-1,o[0]=C[0]*v/y,o[1]=E[0]*v/x,D&&(S.color=L[0],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,f.drawArrays(f.TRIANGLES,I,D)),i[0]=2*(g[2]+E[3])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=E[3]*v/y,o[1]=C[3]*v/x,N&&(S.color=L[3],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,f.drawArrays(f.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[3]+E[2])/x-1,o[0]=C[2]*v/y,o[1]=E[2]*v/x,D&&(S.color=L[2],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,f.drawArrays(f.TRIANGLES,I,D))}}(),d.update=(f=[1,1,-1,-1,1,-1],p=[1,-1,1,1,-1,-1],function(t){for(var e=t.ticks,r=t.bounds,n=new Float32Array(18*(e[0].length+e[1].length)),i=(this.plot.zeroLineEnable,0),a=[[],[]],o=0;o<2;++o)for(var s=a[o],l=e[o],c=r[o],u=r[o+2],h=0;h<l.length;++h){var d=(l[h].x-c)/(u-c);s.push(d);for(var g=0;g<6;++g)n[i++]=d,n[i++]=f[g],n[i++]=p[g]}this.ticks=a,this.vbo.update(n)}),d.dispose=function(){this.vbo.dispose(),this.shader.dispose(),this.tickShader.dispose()}},{\"./shaders\":284,\"binary-search-bounds\":286,\"gl-buffer\":241,\"gl-shader\":301}],283:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[-1,-1,-1,1,1,-1,1,1]),s=i(e,a.lineVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawLine=(s=[0,0],l=[0,0],function(t,e,r,n,i,a){var o=this.plot,c=this.shader,u=o.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,c.uniforms.start=s,c.uniforms.end=l,c.uniforms.width=i*o.pixelRatio,c.uniforms.color=a,u.drawArrays(u.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":284,\"gl-buffer\":241,\"gl-shader\":301}],284:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision lowp float;\\n#define GLSLIFY 1\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = vec4(color.xyz * color.w, color.w);\\n}\\n\"]);e.exports={lineVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 start, end;\\nuniform float width;\\n\\nvec2 perp(vec2 v) {\\n  return vec2(v.y, -v.x);\\n}\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  vec2 delta = normalize(perp(start - end));\\n  vec2 offset = mix(start, end, 0.5 * (coord.y+1.0));\\n  gl_Position = vec4(screen(offset + 0.5 * width * delta * coord.x), 0, 1);\\n}\\n\"]),lineFrag:i,textVert:n([\"#define GLSLIFY 1\\nattribute vec3 textCoordinate;\\n\\nuniform vec2 dataScale, dataShift, dataAxis, screenOffset, textScale;\\nuniform float angle;\\n\\nvoid main() {\\n  float dataOffset  = textCoordinate.z;\\n  vec2 glyphOffset  = textCoordinate.xy;\\n  mat2 glyphMatrix = mat2(cos(angle), sin(angle), -sin(angle), cos(angle));\\n  vec2 screenCoordinate = dataAxis * (dataScale * dataOffset + dataShift) +\\n    glyphMatrix * glyphOffset * textScale + screenOffset;\\n  gl_Position = vec4(screenCoordinate, 0, 1);\\n}\\n\"]),textFrag:i,gridVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale;\\nuniform float lineWidth;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  pos += 10.0 * dataCoord.y * vec2(dataAxis.y, -dataAxis.x) + dataCoord.z * lineWidth;\\n  gl_Position = vec4(pos, 0, 1);\\n}\\n\"]),gridFrag:i,boxVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 lo, hi;\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  gl_Position = vec4(screen(mix(lo, hi, coord)), 0, 1);\\n}\\n\"]),tickVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale, screenOffset, tickScale;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  gl_Position = vec4(pos + tickScale*dataCoord.yz + screenOffset, 0, 1);\\n}\\n\"])}},{glslify:409}],285:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,s.textVert,s.textFrag);return new l(t,r,a)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"text-cache\"),o=t(\"binary-search-bounds\"),s=t(\"./shaders\");function l(t,e,r){this.plot=t,this.vbo=e,this.shader=r,this.tickOffset=[[],[]],this.tickX=[[],[]],this.labelOffset=[0,0],this.labelCount=[0,0]}var c,u,h,f,p,d,g=l.prototype;g.drawTicks=(c=[0,0],u=[0,0],h=[0,0],function(t){var e=this.plot,r=this.shader,n=this.tickX[t],i=this.tickOffset[t],a=e.gl,s=e.viewBox,l=e.dataBox,f=e.screenBox,p=e.pixelRatio,d=e.tickEnable,g=e.tickPad,v=e.tickColor,m=e.tickAngle,y=e.labelEnable,x=e.labelPad,b=e.labelColor,_=e.labelAngle,w=this.labelOffset[t],k=this.labelCount[t],T=o.lt(n,l[t]),A=o.le(n,l[t+2]);c[0]=c[1]=0,c[t]=1,u[t]=(s[2+t]+s[t])/(f[2+t]-f[t])-1;var M=2/f[2+(1^t)]-f[1^t];u[1^t]=M*s[1^t]-1,d[t]&&(u[1^t]-=M*p*g[t],T<A&&i[A]>i[T]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=v[t],r.uniforms.angle=m[t],a.drawArrays(a.TRIANGLES,i[T],i[A]-i[T]))),y[t]&&k&&(u[1^t]-=M*p*x[t],r.uniforms.dataAxis=h,r.uniforms.screenOffset=u,r.uniforms.color=b[t],r.uniforms.angle=_[t],a.drawArrays(a.TRIANGLES,w,k)),u[1^t]=M*s[2+(1^t)]-1,d[t+2]&&(u[1^t]+=M*p*g[t+2],T<A&&i[A]>i[T]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=v[t+2],r.uniforms.angle=m[t+2],a.drawArrays(a.TRIANGLES,i[T],i[A]-i[T]))),y[t+2]&&k&&(u[1^t]+=M*p*x[t+2],r.uniforms.dataAxis=h,r.uniforms.screenOffset=u,r.uniforms.color=b[t+2],r.uniforms.angle=_[t+2],a.drawArrays(a.TRIANGLES,w,k))}),g.drawTitle=function(){var t=[0,0],e=[0,0];return function(){var r=this.plot,n=this.shader,i=r.gl,a=r.screenBox,o=r.titleCenter,s=r.titleAngle,l=r.titleColor,c=r.pixelRatio;if(this.titleCount){for(var u=0;u<2;++u)e[u]=2*(o[u]*c-a[u])/(a[2+u]-a[u])-1;n.bind(),n.uniforms.dataAxis=t,n.uniforms.screenOffset=e,n.uniforms.angle=s,n.uniforms.color=l,i.drawArrays(i.TRIANGLES,this.titleOffset,this.titleCount)}}}(),g.bind=(f=[0,0],p=[0,0],d=[0,0],function(){var t=this.plot,e=this.shader,r=t._tickBounds,n=t.dataBox,i=t.screenBox,a=t.viewBox;e.bind();for(var o=0;o<2;++o){var s=r[o],l=r[o+2]-s,c=.5*(n[o+2]+n[o]),u=n[o+2]-n[o],h=a[o],g=a[o+2]-h,v=i[o],m=i[o+2]-v;p[o]=2*l/u*g/m,f[o]=2*(s-c)/u*g/m}d[1]=2*t.pixelRatio/(i[3]-i[1]),d[0]=d[1]*(i[3]-i[1])/(i[2]-i[0]),e.uniforms.dataScale=p,e.uniforms.dataShift=f,e.uniforms.textScale=d,this.vbo.bind(),e.attributes.textCoordinate.pointer()}),g.update=function(t){var e,r,n,i,o,s=[],l=t.ticks,c=t.bounds;for(o=0;o<2;++o){var u=[Math.floor(s.length/3)],h=[-1/0],f=l[o];for(e=0;e<f.length;++e){var p=f[e],d=p.x,g=p.text,v=p.font||\"sans-serif\";i=p.fontSize||12;for(var m=1/(c[o+2]-c[o]),y=c[o],x=g.split(\"\\n\"),b=0;b<x.length;b++)for(n=a(v,x[b]).data,r=0;r<n.length;r+=2)s.push(n[r]*i,-n[r+1]*i-b*i*1.2,(d-y)*m);u.push(Math.floor(s.length/3)),h.push(d)}this.tickOffset[o]=u,this.tickX[o]=h}for(o=0;o<2;++o){for(this.labelOffset[o]=Math.floor(s.length/3),n=a(t.labelFont[o],t.labels[o],{textAlign:\"center\"}).data,i=t.labelSize[o],e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.labelCount[o]=Math.floor(s.length/3)-this.labelOffset[o]}for(this.titleOffset=Math.floor(s.length/3),n=a(t.titleFont,t.title).data,i=t.titleSize,e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.titleCount=Math.floor(s.length/3)-this.titleOffset,this.vbo.update(s)},g.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":284,\"binary-search-bounds\":286,\"gl-buffer\":241,\"gl-shader\":301,\"text-cache\":536}],286:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],287:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[e.drawingBufferWidth,e.drawingBufferHeight]),c=new l(e,r);return c.grid=i(c),c.text=a(c),c.line=o(c),c.box=s(c),c.update(t),c};var n=t(\"gl-select-static\"),i=t(\"./lib/grid\"),a=t(\"./lib/text\"),o=t(\"./lib/line\"),s=t(\"./lib/box\");function l(t,e){this.gl=t,this.pickBuffer=e,this.screenBox=[0,0,t.drawingBufferWidth,t.drawingBufferHeight],this.viewBox=[0,0,0,0],this.dataBox=[-10,-10,10,10],this.gridLineEnable=[!0,!0],this.gridLineWidth=[1,1],this.gridLineColor=[[0,0,0,1],[0,0,0,1]],this.pixelRatio=1,this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickEnable=[!0,!0,!0,!0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[15,15,15,15],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelEnable=[!0,!0,!0,!0],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.titleCenter=[0,0],this.titleEnable=!0,this.titleAngle=0,this.titleColor=[0,0,0,1],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[4,4],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderLineEnable=[!0,!0,!0,!0],this.borderLineWidth=[2,2,2,2],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.grid=null,this.text=null,this.line=null,this.box=null,this.objects=[],this.overlays=[],this._tickBounds=[1/0,1/0,-1/0,-1/0],this.static=!1,this.dirty=!1,this.pickDirty=!1,this.pickDelay=120,this.pickRadius=10,this._pickTimeout=null,this._drawPick=this.drawPick.bind(this),this._depthCounter=0}var c=l.prototype;function u(t){for(var e=t.slice(),r=0;r<e.length;++r)e[r]=e[r].slice();return e}function h(t,e){return t.x-e.x}c.setDirty=function(){this.dirty=this.pickDirty=!0},c.setOverlayDirty=function(){this.dirty=!0},c.nextDepthValue=function(){return this._depthCounter++/65536},c.draw=function(){var t=this.gl,e=this.screenBox,r=this.viewBox,n=this.dataBox,i=this.pixelRatio,a=this.grid,o=this.line,s=this.text,l=this.objects;if(this._depthCounter=0,this.pickDirty&&(this._pickTimeout&&clearTimeout(this._pickTimeout),this.pickDirty=!1,this._pickTimeout=setTimeout(this._drawPick,this.pickDelay)),this.dirty){if(this.dirty=!1,t.bindFramebuffer(t.FRAMEBUFFER,null),t.enable(t.SCISSOR_TEST),t.disable(t.DEPTH_TEST),t.depthFunc(t.LESS),t.depthMask(!1),t.enable(t.BLEND),t.blendEquation(t.FUNC_ADD,t.FUNC_ADD),t.blendFunc(t.ONE,t.ONE_MINUS_SRC_ALPHA),this.borderColor){t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]);var c=this.borderColor;t.clearColor(c[0]*c[3],c[1]*c[3],c[2]*c[3],c[3]),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT)}t.scissor(r[0],r[1],r[2]-r[0],r[3]-r[1]),t.viewport(r[0],r[1],r[2]-r[0],r[3]-r[1]);var u=this.backgroundColor;t.clearColor(u[0]*u[3],u[1]*u[3],u[2]*u[3],u[3]),t.clear(t.COLOR_BUFFER_BIT),a.draw();var h=this.zeroLineEnable,f=this.zeroLineColor,p=this.zeroLineWidth;if(h[0]||h[1]){o.bind();for(var d=0;d<2;++d)if(h[d]&&n[d]<=0&&n[d+2]>=0){var g=e[d]-n[d]*(e[d+2]-e[d])/(n[d+2]-n[d]);0===d?o.drawLine(g,e[1],g,e[3],p[d],f[d]):o.drawLine(e[0],g,e[2],g,p[d],f[d])}}for(d=0;d<l.length;++d)l[d].draw();t.viewport(e[0],e[1],e[2]-e[0],e[3]-e[1]),t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]),this.grid.drawTickMarks(),o.bind();var v=this.borderLineEnable,m=this.borderLineWidth,y=this.borderLineColor;for(v[1]&&o.drawLine(r[0],r[1]-.5*m[1]*i,r[0],r[3]+.5*m[3]*i,m[1],y[1]),v[0]&&o.drawLine(r[0]-.5*m[0]*i,r[1],r[2]+.5*m[2]*i,r[1],m[0],y[0]),v[3]&&o.drawLine(r[2],r[1]-.5*m[1]*i,r[2],r[3]+.5*m[3]*i,m[3],y[3]),v[2]&&o.drawLine(r[0]-.5*m[0]*i,r[3],r[2]+.5*m[2]*i,r[3],m[2],y[2]),s.bind(),d=0;d<2;++d)s.drawTicks(d);this.titleEnable&&s.drawTitle();var x=this.overlays;for(d=0;d<x.length;++d)x[d].draw();t.disable(t.SCISSOR_TEST),t.disable(t.BLEND),t.depthMask(!0)}},c.drawPick=function(){if(!this.static){var t=this.pickBuffer;this.gl;this._pickTimeout=null,t.begin();for(var e=1,r=this.objects,n=0;n<r.length;++n)e=r[n].drawPick(e);t.end()}},c.pick=function(t,e){if(!this.static){var r=this.pixelRatio,n=this.pickPixelRatio,i=this.viewBox,a=0|Math.round((t-i[0]/r)*n),o=0|Math.round((e-i[1]/r)*n),s=this.pickBuffer.query(a,o,this.pickRadius);if(!s)return null;for(var l=s.id+(s.value[0]<<8)+(s.value[1]<<16)+(s.value[2]<<24),c=this.objects,u=0;u<c.length;++u){var h=c[u].pick(a,o,l);if(h)return h}return null}},c.setScreenBox=function(t){var e=this.screenBox,r=this.pixelRatio;e[0]=0|Math.round(t[0]*r),e[1]=0|Math.round(t[1]*r),e[2]=0|Math.round(t[2]*r),e[3]=0|Math.round(t[3]*r),this.setDirty()},c.setDataBox=function(t){var e=this.dataBox;(e[0]!==t[0]||e[1]!==t[1]||e[2]!==t[2]||e[3]!==t[3])&&(e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],this.setDirty())},c.setViewBox=function(t){var e=this.pixelRatio,r=this.viewBox;r[0]=0|Math.round(t[0]*e),r[1]=0|Math.round(t[1]*e),r[2]=0|Math.round(t[2]*e),r[3]=0|Math.round(t[3]*e);var n=this.pickPixelRatio;this.pickBuffer.shape=[0|Math.round((t[2]-t[0])*n),0|Math.round((t[3]-t[1])*n)],this.setDirty()},c.update=function(t){t=t||{};var e=this.gl;this.pixelRatio=t.pixelRatio||1;var r=this.pixelRatio;this.pickPixelRatio=Math.max(r,1),this.setScreenBox(t.screenBox||[0,0,e.drawingBufferWidth/r,e.drawingBufferHeight/r]);this.screenBox;this.setViewBox(t.viewBox||[.125*(this.screenBox[2]-this.screenBox[0])/r,.125*(this.screenBox[3]-this.screenBox[1])/r,.875*(this.screenBox[2]-this.screenBox[0])/r,.875*(this.screenBox[3]-this.screenBox[1])/r]);var n=this.viewBox,i=(n[2]-n[0])/(n[3]-n[1]);this.setDataBox(t.dataBox||[-10,-10/i,10,10/i]),this.borderColor=!1!==t.borderColor&&(t.borderColor||[0,0,0,0]).slice(),this.backgroundColor=(t.backgroundColor||[0,0,0,0]).slice(),this.gridLineEnable=(t.gridLineEnable||[!0,!0]).slice(),this.gridLineWidth=(t.gridLineWidth||[1,1]).slice(),this.gridLineColor=u(t.gridLineColor||[[.5,.5,.5,1],[.5,.5,.5,1]]),this.zeroLineEnable=(t.zeroLineEnable||[!0,!0]).slice(),this.zeroLineWidth=(t.zeroLineWidth||[4,4]).slice(),this.zeroLineColor=u(t.zeroLineColor||[[0,0,0,1],[0,0,0,1]]),this.tickMarkLength=(t.tickMarkLength||[0,0,0,0]).slice(),this.tickMarkWidth=(t.tickMarkWidth||[0,0,0,0]).slice(),this.tickMarkColor=u(t.tickMarkColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.titleCenter=(t.titleCenter||[.5*(n[0]+n[2])/r,(n[3]+120)/r]).slice(),this.titleEnable=!(\"titleEnable\"in t&&!t.titleEnable),this.titleAngle=t.titleAngle||0,this.titleColor=(t.titleColor||[0,0,0,1]).slice(),this.labelPad=(t.labelPad||[15,15,15,15]).slice(),this.labelAngle=(t.labelAngle||[0,Math.PI/2,0,3*Math.PI/2]).slice(),this.labelEnable=(t.labelEnable||[!0,!0,!0,!0]).slice(),this.labelColor=u(t.labelColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.tickPad=(t.tickPad||[15,15,15,15]).slice(),this.tickAngle=(t.tickAngle||[0,0,0,0]).slice(),this.tickEnable=(t.tickEnable||[!0,!0,!0,!0]).slice(),this.tickColor=u(t.tickColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.borderLineEnable=(t.borderLineEnable||[!0,!0,!0,!0]).slice(),this.borderLineWidth=(t.borderLineWidth||[2,2,2,2]).slice(),this.borderLineColor=u(t.borderLineColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]);var a=t.ticks||[[],[]],o=this._tickBounds;o[0]=o[1]=1/0,o[2]=o[3]=-1/0;for(var s=0;s<2;++s){var l=a[s].slice(0);0!==l.length&&(l.sort(h),o[s]=Math.min(o[s],l[0].x),o[s+2]=Math.max(o[s+2],l[l.length-1].x))}this.grid.update({bounds:o,ticks:a}),this.text.update({bounds:o,ticks:a,labels:t.labels||[\"x\",\"y\"],labelSize:t.labelSize||[12,12],labelFont:t.labelFont||[\"sans-serif\",\"sans-serif\"],title:t.title||\"\",titleSize:t.titleSize||18,titleFont:t.titleFont||\"sans-serif\"}),this.static=!!t.static,this.setDirty()},c.dispose=function(){this.box.dispose(),this.grid.dispose(),this.text.dispose(),this.line.dispose();for(var t=this.objects.length-1;t>=0;--t)this.objects[t].dispose();this.objects.length=0;for(t=this.overlays.length-1;t>=0;--t)this.overlays[t].dispose();this.overlays.length=0,this.gl=null},c.addObject=function(t){this.objects.indexOf(t)<0&&(this.objects.push(t),this.setDirty())},c.removeObject=function(t){for(var e=this.objects,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setDirty();break}},c.addOverlay=function(t){this.overlays.indexOf(t)<0&&(this.overlays.push(t),this.setOverlayDirty())},c.removeOverlay=function(t){for(var e=this.overlays,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setOverlayDirty();break}}},{\"./lib/box\":281,\"./lib/grid\":282,\"./lib/line\":283,\"./lib/text\":285,\"gl-select-static\":300}],288:[function(t,e,r){\"use strict\";e.exports=function(t,e){t=t||document.body,e=e||{};var r=[.01,1/0];\"distanceLimits\"in e&&(r[0]=e.distanceLimits[0],r[1]=e.distanceLimits[1]);\"zoomMin\"in e&&(r[0]=e.zoomMin);\"zoomMax\"in e&&(r[1]=e.zoomMax);var c=i({center:e.center||[0,0,0],up:e.up||[0,1,0],eye:e.eye||[0,0,10],mode:e.mode||\"orbit\",distanceLimits:r}),u=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],h=0,f=t.clientWidth,p=t.clientHeight,d={keyBindingMode:\"rotate\",enableWheel:!0,view:c,element:t,delay:e.delay||16,rotateSpeed:e.rotateSpeed||1,zoomSpeed:e.zoomSpeed||1,translateSpeed:e.translateSpeed||1,flipX:!!e.flipX,flipY:!!e.flipY,modes:c.modes,_ortho:e._ortho||e.projection&&\"orthographic\"===e.projection.type||!1,tick:function(){var e=n(),r=this.delay,i=e-2*r;c.idle(e-r),c.recalcMatrix(i),c.flush(e-(100+2*r));for(var a=!0,o=c.computedMatrix,s=0;s<16;++s)a=a&&u[s]===o[s],u[s]=o[s];var l=t.clientWidth===f&&t.clientHeight===p;return f=t.clientWidth,p=t.clientHeight,a?!l:(h=Math.exp(c.computedRadius[0]),!0)},lookAt:function(t,e,r){c.lookAt(c.lastT(),t,e,r)},rotate:function(t,e,r){c.rotate(c.lastT(),t,e,r)},pan:function(t,e,r){c.pan(c.lastT(),t,e,r)},translate:function(t,e,r){c.translate(c.lastT(),t,e,r)}};return Object.defineProperties(d,{matrix:{get:function(){return c.computedMatrix},set:function(t){return c.setMatrix(c.lastT(),t),c.computedMatrix},enumerable:!0},mode:{get:function(){return c.getMode()},set:function(t){var e=c.computedUp.slice(),r=c.computedEye.slice(),i=c.computedCenter.slice();if(c.setMode(t),\"turntable\"===t){var a=n();c._active.lookAt(a,r,i,e),c._active.lookAt(a+500,r,i,[0,0,1]),c._active.flush(a)}return c.getMode()},enumerable:!0},center:{get:function(){return c.computedCenter},set:function(t){return c.lookAt(c.lastT(),null,t),c.computedCenter},enumerable:!0},eye:{get:function(){return c.computedEye},set:function(t){return c.lookAt(c.lastT(),t),c.computedEye},enumerable:!0},up:{get:function(){return c.computedUp},set:function(t){return c.lookAt(c.lastT(),null,null,t),c.computedUp},enumerable:!0},distance:{get:function(){return h},set:function(t){return c.setDistance(c.lastT(),t),t},enumerable:!0},distanceLimits:{get:function(){return c.getDistanceLimits(r)},set:function(t){return c.setDistanceLimits(t),t},enumerable:!0}}),t.addEventListener(\"contextmenu\",function(t){return t.preventDefault(),!1}),d._lastX=-1,d._lastY=-1,d._lastMods={shift:!1,control:!1,alt:!1,meta:!1},d.enableMouseListeners=function(){function e(e,r,i,a){var o=d.keyBindingMode;if(!1!==o){var s=\"rotate\"===o,l=\"pan\"===o,u=\"zoom\"===o,f=!!a.control,p=!!a.alt,g=!!a.shift,v=!!(1&e),m=!!(2&e),y=!!(4&e),x=1/t.clientHeight,b=x*(r-d._lastX),_=x*(i-d._lastY),w=d.flipX?1:-1,k=d.flipY?1:-1,T=Math.PI*d.rotateSpeed,A=n();if(-1!==d._lastX&&-1!==d._lastY&&((s&&v&&!f&&!p&&!g||v&&!f&&!p&&g)&&c.rotate(A,w*T*b,-k*T*_,0),(l&&v&&!f&&!p&&!g||m||v&&f&&!p&&!g)&&c.pan(A,-d.translateSpeed*b*h,d.translateSpeed*_*h,0),u&&v&&!f&&!p&&!g||y||v&&!f&&p&&!g)){var M=-d.zoomSpeed*_/window.innerHeight*(A-c.lastT())*100;c.pan(A,0,0,h*(Math.exp(M)-1))}return d._lastX=r,d._lastY=i,d._lastMods=a,!0}}d.mouseListener=a(t,e),t.addEventListener(\"touchstart\",function(r){var n=s(r.changedTouches[0],t);e(0,n[0],n[1],d._lastMods),e(1,n[0],n[1],d._lastMods),r.preventDefault()},!!l&&{passive:!1}),t.addEventListener(\"touchmove\",function(r){var n=s(r.changedTouches[0],t);e(1,n[0],n[1],d._lastMods),r.preventDefault()},!!l&&{passive:!1}),t.addEventListener(\"touchend\",function(t){e(0,d._lastX,d._lastY,d._lastMods),t.preventDefault()},!!l&&{passive:!1}),d.wheelListener=o(t,function(t,e){if(!1!==d.keyBindingMode&&d.enableWheel){var r=d.flipX?1:-1,i=d.flipY?1:-1,a=n();if(Math.abs(t)>Math.abs(e))c.rotate(a,0,0,-t*r*Math.PI*d.rotateSpeed/window.innerWidth);else if(!d._ortho){var o=-d.zoomSpeed*i*e/window.innerHeight*(a-c.lastT())/20;c.pan(a,0,0,h*(Math.exp(o)-1))}}},!0)},d.enableMouseListeners(),d};var n=t(\"right-now\"),i=t(\"3d-view\"),a=t(\"mouse-change\"),o=t(\"mouse-wheel\"),s=t(\"mouse-event-offset\"),l=t(\"has-passive-events\")},{\"3d-view\":52,\"has-passive-events\":411,\"mouse-change\":435,\"mouse-event-offset\":436,\"mouse-wheel\":438,\"right-now\":504}],289:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\nattribute vec2 position;\\nvarying vec2 uv;\\nvoid main() {\\n  uv = position;\\n  gl_Position = vec4(position, 0, 1);\\n}\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D accumBuffer;\\nvarying vec2 uv;\\n\\nvoid main() {\\n  vec4 accum = texture2D(accumBuffer, 0.5 * (uv + 1.0));\\n  gl_FragColor = min(vec4(1,1,1,1), accum);\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec2\"}])}},{\"gl-shader\":301,glslify:409}],290:[function(t,e,r){\"use strict\";var n=t(\"./camera.js\"),i=t(\"gl-axes3d\"),a=t(\"gl-axes3d/properties\"),o=t(\"gl-spikes3d\"),s=t(\"gl-select-static\"),l=t(\"gl-fbo\"),c=t(\"a-big-triangle\"),u=t(\"mouse-change\"),h=t(\"mouse-wheel\"),f=t(\"gl-mat4/perspective\"),p=t(\"gl-mat4/ortho\"),d=t(\"./lib/shader\"),g=t(\"is-mobile\")({tablet:!0});function v(){this.mouse=[-1,-1],this.screen=null,this.distance=1/0,this.index=null,this.dataCoordinate=null,this.dataPosition=null,this.object=null,this.data=null}function m(t){var e=Math.round(Math.log(Math.abs(t))/Math.log(10));if(e<0){var r=Math.round(Math.pow(10,-e));return Math.ceil(t*r)/r}if(e>0){r=Math.round(Math.pow(10,e));return Math.ceil(t/r)*r}return Math.ceil(t)}function y(t){return\"boolean\"!=typeof t||t}e.exports={createScene:function(t){(t=t||{}).camera=t.camera||{};var e=t.canvas;if(!e)if(e=document.createElement(\"canvas\"),t.container){var r=t.container;r.appendChild(e)}else document.body.appendChild(e);var x=t.gl;x||(x=function(t,e){var r=null;try{(r=t.getContext(\"webgl\",e))||(r=t.getContext(\"experimental-webgl\",e))}catch(t){return null}return r}(e,t.glOptions||{premultipliedAlpha:!0,antialias:!0,preserveDrawingBuffer:g}));if(!x)throw new Error(\"webgl not supported\");var b=t.bounds||[[-10,-10,-10],[10,10,10]],_=new v,w=l(x,[x.drawingBufferWidth,x.drawingBufferHeight],{preferFloat:!g}),k=d(x),T=t.cameraObject&&!0===t.cameraObject._ortho||t.camera.projection&&\"orthographic\"===t.camera.projection.type||!1,A={eye:t.camera.eye||[2,0,0],center:t.camera.center||[0,0,0],up:t.camera.up||[0,1,0],zoomMin:t.camera.zoomMax||.1,zoomMax:t.camera.zoomMin||100,mode:t.camera.mode||\"turntable\",_ortho:T},M=t.axes||{},S=i(x,M);S.enable=!M.disable;var E=t.spikes||{},C=o(x,E),L=[],P=[],O=[],z=[],I=!0,D=!0,R=new Array(16),F=new Array(16),B={view:null,projection:R,model:F,_ortho:!1},D=!0,N=[x.drawingBufferWidth,x.drawingBufferHeight],j=t.cameraObject||n(e,A),U={gl:x,contextLost:!1,pixelRatio:t.pixelRatio||1,canvas:e,selection:_,camera:j,axes:S,axesPixels:null,spikes:C,bounds:b,objects:L,shape:N,aspect:t.aspectRatio||[1,1,1],pickRadius:t.pickRadius||10,zNear:t.zNear||.01,zFar:t.zFar||1e3,fovy:t.fovy||Math.PI/4,clearColor:t.clearColor||[0,0,0,0],autoResize:y(t.autoResize),autoBounds:y(t.autoBounds),autoScale:!!t.autoScale,autoCenter:y(t.autoCenter),clipToBounds:y(t.clipToBounds),snapToData:!!t.snapToData,onselect:t.onselect||null,onrender:t.onrender||null,onclick:t.onclick||null,cameraParams:B,oncontextloss:null,mouseListener:null,_stopped:!1},V=[x.drawingBufferWidth/U.pixelRatio|0,x.drawingBufferHeight/U.pixelRatio|0];function q(){if(!U._stopped&&U.autoResize){var t=e.parentNode,r=1,n=1;t&&t!==document.body?(r=t.clientWidth,n=t.clientHeight):(r=window.innerWidth,n=window.innerHeight);var i=0|Math.ceil(r*U.pixelRatio),a=0|Math.ceil(n*U.pixelRatio);if(i!==e.width||a!==e.height){e.width=i,e.height=a;var o=e.style;o.position=o.position||\"absolute\",o.left=\"0px\",o.top=\"0px\",o.width=r+\"px\",o.height=n+\"px\",I=!0}}}U.autoResize&&q();function H(){for(var t=L.length,e=z.length,r=0;r<e;++r)O[r]=0;t:for(var r=0;r<t;++r){var n=L[r],i=n.pickSlots;if(i){for(var a=0;a<e;++a)if(O[a]+i<255){P[r]=a,n.setPickBase(O[a]+1),O[a]+=i;continue t}var o=s(x,N);P[r]=e,z.push(o),O.push(i),n.setPickBase(1),e+=1}else P[r]=-1}for(;e>0&&0===O[e-1];)O.pop(),z.pop().dispose()}function G(){if(U.contextLost)return!0;x.isContextLost()&&(U.contextLost=!0,U.mouseListener.enabled=!1,U.selection.object=null,U.oncontextloss&&U.oncontextloss())}window.addEventListener(\"resize\",q),U.update=function(t){U._stopped||(t=t||{},I=!0,D=!0)},U.add=function(t){U._stopped||(t.axes=S,L.push(t),P.push(-1),I=!0,D=!0,H())},U.remove=function(t){if(!U._stopped){var e=L.indexOf(t);e<0||(L.splice(e,1),P.pop(),I=!0,D=!0,H())}},U.dispose=function(){if(!U._stopped&&(U._stopped=!0,window.removeEventListener(\"resize\",q),e.removeEventListener(\"webglcontextlost\",G),U.mouseListener.enabled=!1,!U.contextLost)){S.dispose(),C.dispose();for(var t=0;t<L.length;++t)L[t].dispose();w.dispose();for(var t=0;t<z.length;++t)z[t].dispose();k.dispose(),x=null,S=null,C=null,L=[]}},U.wheelListener=h(e,function(t,e){if(!1!==j.keyBindingMode&&j.enableWheel&&j._ortho){var r=t>e?1.1:1/1.1;U.aspect[0]*=r,U.aspect[1]*=r,U.aspect[2]*=r,U.redraw()}},!0),U._mouseRotating=!1,U._prevButtons=0,U.enableMouseListeners=function(){U.mouseListener=u(e,function(t,e,r){if(!U._stopped){var n=z.length,i=L.length,a=_.object;_.distance=1/0,_.mouse[0]=e,_.mouse[1]=r,_.object=null,_.screen=null,_.dataCoordinate=_.dataPosition=null;var o=!1;if(t&&U._prevButtons)U._mouseRotating=!0;else{U._mouseRotating&&(D=!0),U._mouseRotating=!1;for(var s=0;s<n;++s){var l=z[s].query(e,V[1]-r-1,U.pickRadius);if(l){if(l.distance>_.distance)continue;for(var c=0;c<i;++c){var u=L[c];if(P[c]===s){var h=u.pick(l);h&&(_.buttons=t,_.screen=l.coord,_.distance=l.distance,_.object=u,_.index=h.distance,_.dataPosition=h.position,_.dataCoordinate=h.dataCoordinate,_.data=h,o=!0)}}}}}a&&a!==_.object&&(a.highlight&&a.highlight(null),I=!0),_.object&&(_.object.highlight&&_.object.highlight(_.data),I=!0),(o=o||_.object!==a)&&U.onselect&&U.onselect(_),1&t&&!(1&U._prevButtons)&&U.onclick&&U.onclick(_),U._prevButtons=t}})},e.addEventListener(\"webglcontextlost\",G);var Y=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],W=[Y[0].slice(),Y[1].slice()];function X(){if(!G()){q();var t=U.camera.tick();B.view=U.camera.matrix,I=I||t,D=D||t,S.pixelRatio=U.pixelRatio,C.pixelRatio=U.pixelRatio;var e=L.length,r=Y[0],n=Y[1];r[0]=r[1]=r[2]=1/0,n[0]=n[1]=n[2]=-1/0;for(var i=0;i<e;++i){var o=L[i];o.pixelRatio=U.pixelRatio,o.axes=U.axes,I=I||!!o.dirty,D=D||!!o.dirty;var s=o.bounds;if(s)for(var l=s[0],u=s[1],h=0;h<3;++h)r[h]=Math.min(r[h],l[h]),n[h]=Math.max(n[h],u[h])}var d=U.bounds;if(U.autoBounds)for(var h=0;h<3;++h){if(n[h]<r[h])r[h]=-1,n[h]=1;else{r[h]===n[h]&&(r[h]-=1,n[h]+=1);var g=.05*(n[h]-r[h]);r[h]=r[h]-g,n[h]=n[h]+g}d[0][h]=r[h],d[1][h]=n[h]}for(var v=!1,h=0;h<3;++h)v=v||W[0][h]!==d[0][h]||W[1][h]!==d[1][h],W[0][h]=d[0][h],W[1][h]=d[1][h];if(D=D||v,I=I||v){if(v){for(var y=[0,0,0],i=0;i<3;++i)y[i]=m((d[1][i]-d[0][i])/10);S.autoTicks?S.update({bounds:d,tickSpacing:y}):S.update({bounds:d})}var b=x.drawingBufferWidth,A=x.drawingBufferHeight;N[0]=b,N[1]=A,V[0]=0|Math.max(b/U.pixelRatio,1),V[1]=0|Math.max(A/U.pixelRatio,1),T?(p(R,-b/A,b/A,-1,1,U.zNear,U.zFar),B._ortho=!0):(f(R,U.fovy,b/A,U.zNear,U.zFar),B._ortho=!1);for(var i=0;i<16;++i)F[i]=0;F[15]=1;for(var M=0,i=0;i<3;++i)M=Math.max(M,d[1][i]-d[0][i]);for(var i=0;i<3;++i)U.autoScale?F[5*i]=U.aspect[i]/(d[1][i]-d[0][i]):F[5*i]=1/M,U.autoCenter&&(F[12+i]=.5*-F[5*i]*(d[0][i]+d[1][i]));for(var i=0;i<e;++i){var o=L[i];o.axesBounds=d,U.clipToBounds&&(o.clipBounds=d)}_.object&&(U.snapToData?C.position=_.dataCoordinate:C.position=_.dataPosition,C.bounds=d),D&&(D=!1,function(){if(G())return;x.colorMask(!0,!0,!0,!0),x.depthMask(!0),x.disable(x.BLEND),x.enable(x.DEPTH_TEST);for(var t=L.length,e=z.length,r=0;r<e;++r){var n=z[r];n.shape=V,n.begin();for(var i=0;i<t;++i)if(P[i]===r){var a=L[i];a.drawPick&&(a.pixelRatio=1,a.drawPick(B))}n.end()}}()),U.axesPixels=a(U.axes,B,b,A),U.onrender&&U.onrender(),x.bindFramebuffer(x.FRAMEBUFFER,null),x.viewport(0,0,b,A);var E=U.clearColor;x.clearColor(E[0],E[1],E[2],E[3]),x.clear(x.COLOR_BUFFER_BIT|x.DEPTH_BUFFER_BIT),x.depthMask(!0),x.colorMask(!0,!0,!0,!0),x.enable(x.DEPTH_TEST),x.depthFunc(x.LEQUAL),x.disable(x.BLEND),x.disable(x.CULL_FACE);var O=!1;S.enable&&(O=O||S.isTransparent(),S.draw(B)),C.axes=S,_.object&&C.draw(B),x.disable(x.CULL_FACE);for(var i=0;i<e;++i){var o=L[i];o.axes=S,o.pixelRatio=U.pixelRatio,o.isOpaque&&o.isOpaque()&&o.draw(B),o.isTransparent&&o.isTransparent()&&(O=!0)}if(O){w.shape=N,w.bind(),x.clear(x.DEPTH_BUFFER_BIT),x.colorMask(!1,!1,!1,!1),x.depthMask(!0),x.depthFunc(x.LESS),S.enable&&S.isTransparent()&&S.drawTransparent(B);for(var i=0;i<e;++i){var o=L[i];o.isOpaque&&o.isOpaque()&&o.draw(B)}x.enable(x.BLEND),x.blendEquation(x.FUNC_ADD),x.blendFunc(x.ONE,x.ONE_MINUS_SRC_ALPHA),x.colorMask(!0,!0,!0,!0),x.depthMask(!1),x.clearColor(0,0,0,0),x.clear(x.COLOR_BUFFER_BIT),S.isTransparent()&&S.drawTransparent(B);for(var i=0;i<e;++i){var o=L[i];o.isTransparent&&o.isTransparent()&&o.drawTransparent(B)}x.bindFramebuffer(x.FRAMEBUFFER,null),x.blendFunc(x.ONE,x.ONE_MINUS_SRC_ALPHA),x.disable(x.DEPTH_TEST),k.bind(),w.color[0].bind(0),k.uniforms.accumBuffer=0,c(x),x.disable(x.BLEND)}I=!1;for(var i=0;i<e;++i)L[i].dirty=!1}}}return U.enableMouseListeners(),function t(){U._stopped||U.contextLost||(X(),requestAnimationFrame(t))}(),U.redraw=function(){U._stopped||(I=!0,X())},U},createCamera:n}},{\"./camera.js\":288,\"./lib/shader\":289,\"a-big-triangle\":59,\"gl-axes3d\":233,\"gl-axes3d/properties\":240,\"gl-fbo\":249,\"gl-mat4/ortho\":268,\"gl-mat4/perspective\":269,\"gl-select-static\":300,\"gl-spikes3d\":310,\"is-mobile\":420,\"mouse-change\":435,\"mouse-wheel\":438}],291:[function(t,e,r){var n=t(\"glslify\");r.pointVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform float pointCloud;\\n\\nhighp float rand(vec2 co) {\\n  highp float a = 12.9898;\\n  highp float b = 78.233;\\n  highp float c = 43758.5453;\\n  highp float d = dot(co.xy, vec2(a, b));\\n  highp float e = mod(d, 3.14);\\n  return fract(sin(e) * c);\\n}\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n    // if we don't jitter the point size a bit, overall point cloud\\n    // saturation 'jumps' on zooming, which is disturbing and confusing\\n  gl_PointSize = pointSize * ((19.5 + rand(position)) / 20.0);\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    // get the same square surface as circle would be\\n    gl_PointSize *= 0.886;\\n  }\\n}\"]),r.pointFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color, borderColor;\\nuniform float centerFraction;\\nuniform float pointCloud;\\n\\nvoid main() {\\n  float radius;\\n  vec4 baseColor;\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    if(centerFraction == 1.0) {\\n      gl_FragColor = color;\\n    } else {\\n      gl_FragColor = mix(borderColor, color, centerFraction);\\n    }\\n  } else {\\n    radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n    if(radius > 1.0) {\\n      discard;\\n    }\\n    baseColor = mix(borderColor, color, step(radius, centerFraction));\\n    gl_FragColor = vec4(baseColor.rgb * baseColor.a, baseColor.a);\\n  }\\n}\\n\"]),r.pickVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform vec4 pickOffset;\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n  gl_PointSize = pointSize;\\n\\n  vec4 id = pickId + pickOffset;\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  fragId = id;\\n}\\n\"]),r.pickFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  float radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n  if(radius > 1.0) {\\n    discard;\\n  }\\n  gl_FragColor = fragId / 255.0;\\n}\\n\"])},{glslify:409}],292:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"typedarray-pool\"),o=t(\"./lib/shader\");function s(t,e,r,n,i){this.plot=t,this.offsetBuffer=e,this.pickBuffer=r,this.shader=n,this.pickShader=i,this.sizeMin=.5,this.sizeMinCap=2,this.sizeMax=20,this.areaRatio=1,this.pointCount=0,this.color=[1,0,0,1],this.borderColor=[0,0,0,1],this.blend=!1,this.pickOffset=0,this.points=null}e.exports=function(t,e){var r=t.gl,a=i(r),l=i(r),c=n(r,o.pointVertex,o.pointFragment),u=n(r,o.pickVertex,o.pickFragment),h=new s(t,a,l,c,u);return h.update(e),t.addObject(h),h};var l,c,u=s.prototype;u.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.offsetBuffer.dispose(),this.pickBuffer.dispose(),this.plot.removeObject(this)},u.update=function(t){var e;function r(e,r){return e in t?t[e]:r}t=t||{},this.sizeMin=r(\"sizeMin\",.5),this.sizeMax=r(\"sizeMax\",20),this.color=r(\"color\",[1,0,0,1]).slice(),this.areaRatio=r(\"areaRatio\",1),this.borderColor=r(\"borderColor\",[0,0,0,1]).slice(),this.blend=r(\"blend\",!1);var n=t.positions.length>>>1,i=t.positions instanceof Float32Array,o=t.idToIndex instanceof Int32Array&&t.idToIndex.length>=n,s=t.positions,l=i?s:a.mallocFloat32(s.length),c=o?t.idToIndex:a.mallocInt32(n);if(i||l.set(s),!o)for(l.set(s),e=0;e<n;e++)c[e]=e;this.points=s,this.offsetBuffer.update(l),this.pickBuffer.update(c),i||a.free(l),o||a.free(c),this.pointCount=n,this.pickOffset=0},u.unifiedDraw=(l=[1,0,0,0,1,0,0,0,1],c=[0,0,0,0],function(t){var e=void 0!==t,r=e?this.pickShader:this.shader,n=this.plot.gl,i=this.plot.dataBox;if(0===this.pointCount)return t;var a=i[2]-i[0],o=i[3]-i[1],s=function(t,e){var r,n=0,i=t.length>>>1;for(r=0;r<i;r++){var a=t[2*r],o=t[2*r+1];a>=e[0]&&a<=e[2]&&o>=e[1]&&o<=e[3]&&n++}return n}(this.points,i),u=this.plot.pickPixelRatio*Math.max(Math.min(this.sizeMinCap,this.sizeMin),Math.min(this.sizeMax,this.sizeMax/Math.pow(s,.33333)));l[0]=2/a,l[4]=2/o,l[6]=-2*i[0]/a-1,l[7]=-2*i[1]/o-1,this.offsetBuffer.bind(),r.bind(),r.attributes.position.pointer(),r.uniforms.matrix=l,r.uniforms.color=this.color,r.uniforms.borderColor=this.borderColor,r.uniforms.pointCloud=u<5,r.uniforms.pointSize=u,r.uniforms.centerFraction=Math.min(1,Math.max(0,Math.sqrt(1-this.areaRatio))),e&&(c[0]=255&t,c[1]=t>>8&255,c[2]=t>>16&255,c[3]=t>>24&255,this.pickBuffer.bind(),r.attributes.pickId.pointer(n.UNSIGNED_BYTE),r.uniforms.pickOffset=c,this.pickOffset=t);var h=n.getParameter(n.BLEND),f=n.getParameter(n.DITHER);return h&&!this.blend&&n.disable(n.BLEND),f&&n.disable(n.DITHER),n.drawArrays(n.POINTS,0,this.pointCount),h&&!this.blend&&n.enable(n.BLEND),f&&n.enable(n.DITHER),t+this.pointCount}),u.draw=u.unifiedDraw,u.drawPick=u.unifiedDraw,u.pick=function(t,e,r){var n=this.pickOffset,i=this.pointCount;if(r<n||r>=n+i)return null;var a=r-n,o=this.points;return{object:this,pointId:a,dataCoord:[o[2*a],o[2*a+1]]}}},{\"./lib/shader\":291,\"gl-buffer\":241,\"gl-shader\":301,\"typedarray-pool\":545}],293:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c=e[0],u=e[1],h=e[2],f=e[3],p=r[0],d=r[1],g=r[2],v=r[3];(a=c*p+u*d+h*g+f*v)<0&&(a=-a,p=-p,d=-d,g=-g,v=-v);1-a>1e-6?(i=Math.acos(a),o=Math.sin(i),s=Math.sin((1-n)*i)/o,l=Math.sin(n*i)/o):(s=1-n,l=n);return t[0]=s*c+l*p,t[1]=s*u+l*d,t[2]=s*h+l*g,t[3]=s*f+l*v,t}},{}],294:[function(t,e,r){\"use strict\";e.exports=function(t){return t||0===t?t.toString():\"\"}},{}],295:[function(t,e,r){\"use strict\";var n=t(\"vectorize-text\");e.exports=function(t,e,r){var a=i[e];a||(a=i[e]={});if(t in a)return a[t];var o={textAlign:\"center\",textBaseline:\"middle\",lineHeight:1,font:e,lineSpacing:1.25,styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},triangles:!0},s=n(t,o);o.triangles=!1;var l,c,u=n(t,o);if(r&&1!==r){for(l=0;l<s.positions.length;++l)for(c=0;c<s.positions[l].length;++c)s.positions[l][c]/=r;for(l=0;l<u.positions.length;++l)for(c=0;c<u.positions[l].length;++c)u.positions[l][c]/=r}var h=[[1/0,1/0],[-1/0,-1/0]],f=u.positions.length;for(l=0;l<f;++l){var p=u.positions[l];for(c=0;c<2;++c)h[0][c]=Math.min(h[0][c],p[c]),h[1][c]=Math.max(h[1][c],p[c])}return a[t]=[s,u,h]};var i={}},{\"vectorize-text\":550}],296:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform vec4 highlightId;\\nuniform float highlightScale;\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = 1.0;\\n    if(distance(highlightId, id) < 0.0001) {\\n      scale = highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1);\\n    vec4 viewPosition = view * worldPosition;\\n    viewPosition = viewPosition / viewPosition.w;\\n    vec4 clipPosition = projection * (viewPosition + scale * vec4(glyph.x, -glyph.y, 0, 0));\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float highlightScale, pixelRatio;\\nuniform vec4 highlightId;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = pixelRatio;\\n    if(distance(highlightId.bgr, id.bgr) < 0.001) {\\n      scale *= highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1.0);\\n    vec4 viewPosition = view * worldPosition;\\n    vec4 clipPosition = projection * viewPosition;\\n    clipPosition /= clipPosition.w;\\n\\n    gl_Position = clipPosition + vec4(screenSize * scale * vec2(glyph.x, -glyph.y), 0.0, 0.0);\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform float highlightScale;\\nuniform vec4 highlightId;\\nuniform vec3 axes[2];\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float scale, pixelRatio;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float lscale = pixelRatio * scale;\\n    if(distance(highlightId, id) < 0.0001) {\\n      lscale *= highlightScale;\\n    }\\n\\n    vec4 clipCenter   = projection * view * model * vec4(position, 1);\\n    vec3 dataPosition = position + 0.5*lscale*(axes[0] * glyph.x + axes[1] * glyph.y) * clipCenter.w * screenSize.y;\\n    vec4 clipPosition = projection * view * model * vec4(dataPosition, 1);\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = dataPosition;\\n  }\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float opacity;\\n\\nvarying vec4 interpColor;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (\\n    outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate) ||\\n    interpColor.a * opacity == 0.\\n  ) discard;\\n  gl_FragColor = interpColor * opacity;\\n}\\n\"]),c=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float pickGroup;\\n\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate)) discard;\\n\\n  gl_FragColor = vec4(pickGroup, pickId.bgr);\\n}\"]),u=[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"glyph\",type:\"vec2\"},{name:\"id\",type:\"vec4\"}],h={vertex:a,fragment:l,attributes:u},f={vertex:o,fragment:l,attributes:u},p={vertex:s,fragment:l,attributes:u},d={vertex:a,fragment:c,attributes:u},g={vertex:o,fragment:c,attributes:u},v={vertex:s,fragment:c,attributes:u};function m(t,e){var r=n(t,e),i=r.attributes;return i.position.location=0,i.color.location=1,i.glyph.location=2,i.id.location=3,r}r.createPerspective=function(t){return m(t,h)},r.createOrtho=function(t){return m(t,f)},r.createProject=function(t){return m(t,p)},r.createPickPerspective=function(t){return m(t,d)},r.createPickOrtho=function(t){return m(t,g)},r.createPickProject=function(t){return m(t,v)}},{\"gl-shader\":301,glslify:409}],297:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"typedarray-pool\"),s=t(\"gl-mat4/multiply\"),l=t(\"./lib/shaders\"),c=t(\"./lib/glyphs\"),u=t(\"./lib/get-simple-string\"),h=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function f(t,e){var r=t[0],n=t[1],i=t[2],a=t[3];return t[0]=e[0]*r+e[4]*n+e[8]*i+e[12]*a,t[1]=e[1]*r+e[5]*n+e[9]*i+e[13]*a,t[2]=e[2]*r+e[6]*n+e[10]*i+e[14]*a,t[3]=e[3]*r+e[7]*n+e[11]*i+e[15]*a,t}function p(t,e,r,n){return f(n,n),f(n,n),f(n,n)}function d(t,e){this.index=t,this.dataCoordinate=this.position=e}function g(t){return!0===t?1:t>1?1:t}function v(t,e,r,n,i,a,o,s,l,c,u,h){this.gl=t,this.pixelRatio=1,this.shader=e,this.orthoShader=r,this.projectShader=n,this.pointBuffer=i,this.colorBuffer=a,this.glyphBuffer=o,this.idBuffer=s,this.vao=l,this.vertexCount=0,this.lineVertexCount=0,this.opacity=1,this.hasAlpha=!1,this.lineWidth=0,this.projectScale=[2/3,2/3,2/3],this.projectOpacity=[1,1,1],this.projectHasAlpha=!1,this.pickId=0,this.pickPerspectiveShader=c,this.pickOrthoShader=u,this.pickProjectShader=h,this.points=[],this._selectResult=new d(0,[0,0,0]),this.useOrtho=!0,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.axesProject=[!0,!0,!0],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.highlightId=[1,1,1,1],this.highlightScale=2,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.dirty=!0}e.exports=function(t){var e=t.gl,r=l.createPerspective(e),n=l.createOrtho(e),o=l.createProject(e),s=l.createPickPerspective(e),c=l.createPickOrtho(e),u=l.createPickProject(e),h=i(e),f=i(e),p=i(e),d=i(e),g=a(e,[{buffer:h,size:3,type:e.FLOAT},{buffer:f,size:4,type:e.FLOAT},{buffer:p,size:2,type:e.FLOAT},{buffer:d,size:4,type:e.UNSIGNED_BYTE,normalized:!0}]),m=new v(e,r,n,o,h,f,p,d,g,s,c,u);return m.update(t),m};var m=v.prototype;m.pickSlots=1,m.setPickBase=function(t){this.pickId=t},m.isTransparent=function(){if(this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&this.projectHasAlpha)return!0;return!1},m.isOpaque=function(){if(!this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&!this.projectHasAlpha)return!0;return!1};var y=[0,0],x=[0,0,0],b=[0,0,0],_=[0,0,0,1],w=[0,0,0,1],k=h.slice(),T=[0,0,0],A=[[0,0,0],[0,0,0]];function M(t){return t[0]=t[1]=t[2]=0,t}function S(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=1,t}function E(t,e,r,n){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[r]=n,t}function C(t,e,r,n){var i,a=e.axesProject,o=e.gl,l=t.uniforms,c=r.model||h,u=r.view||h,f=r.projection||h,d=e.axesBounds,g=function(t){for(var e=A,r=0;r<2;++r)for(var n=0;n<3;++n)e[r][n]=Math.max(Math.min(t[r][n],1e8),-1e8);return e}(e.clipBounds);i=e.axes&&e.axes.lastCubeProps?e.axes.lastCubeProps.axis:[1,1,1],y[0]=2/o.drawingBufferWidth,y[1]=2/o.drawingBufferHeight,t.bind(),l.view=u,l.projection=f,l.screenSize=y,l.highlightId=e.highlightId,l.highlightScale=e.highlightScale,l.clipBounds=g,l.pickGroup=e.pickId/255,l.pixelRatio=n;for(var v=0;v<3;++v)if(a[v]){l.scale=e.projectScale[v],l.opacity=e.projectOpacity[v];for(var m=k,C=0;C<16;++C)m[C]=0;for(C=0;C<4;++C)m[5*C]=1;m[5*v]=0,i[v]<0?m[12+v]=d[0][v]:m[12+v]=d[1][v],s(m,c,m),l.model=m;var L=(v+1)%3,P=(v+2)%3,O=M(x),z=M(b);O[L]=1,z[P]=1;var I=p(0,0,0,S(_,O)),D=p(0,0,0,S(w,z));if(Math.abs(I[1])>Math.abs(D[1])){var R=I;I=D,D=R,R=O,O=z,z=R;var F=L;L=P,P=F}I[0]<0&&(O[L]=-1),D[1]>0&&(z[P]=-1);var B=0,N=0;for(C=0;C<4;++C)B+=Math.pow(c[4*L+C],2),N+=Math.pow(c[4*P+C],2);O[L]/=Math.sqrt(B),z[P]/=Math.sqrt(N),l.axes[0]=O,l.axes[1]=z,l.fragClipBounds[0]=E(T,g[0],v,-1e8),l.fragClipBounds[1]=E(T,g[1],v,1e8),e.vao.bind(),e.vao.draw(o.TRIANGLES,e.vertexCount),e.lineWidth>0&&(o.lineWidth(e.lineWidth*n),e.vao.draw(o.LINES,e.lineVertexCount,e.vertexCount)),e.vao.unbind()}}var L=[[-1e8,-1e8,-1e8],[1e8,1e8,1e8]];function P(t,e,r,n,i,a,o){var s=r.gl;if((a===r.projectHasAlpha||o)&&C(e,r,n,i),a===r.hasAlpha||o){t.bind();var l=t.uniforms;l.model=n.model||h,l.view=n.view||h,l.projection=n.projection||h,y[0]=2/s.drawingBufferWidth,y[1]=2/s.drawingBufferHeight,l.screenSize=y,l.highlightId=r.highlightId,l.highlightScale=r.highlightScale,l.fragClipBounds=L,l.clipBounds=r.axes.bounds,l.opacity=r.opacity,l.pickGroup=r.pickId/255,l.pixelRatio=i,r.vao.bind(),r.vao.draw(s.TRIANGLES,r.vertexCount),r.lineWidth>0&&(s.lineWidth(r.lineWidth*i),r.vao.draw(s.LINES,r.lineVertexCount,r.vertexCount)),r.vao.unbind()}}function O(t,e,r,i){var a;a=Array.isArray(t)?e<t.length?t[e]:void 0:t,a=u(a);var o=!0;n(a)&&(a=\"\\u25bc\",o=!1);var s=c(a,r,i);return{mesh:s[0],lines:s[1],bounds:s[2],visible:o}}m.draw=function(t){P(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!1,!1)},m.drawTransparent=function(t){P(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!0,!1)},m.drawPick=function(t){P(this.useOrtho?this.pickOrthoShader:this.pickPerspectiveShader,this.pickProjectShader,this,t,1,!0,!0)},m.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[2]+(t.value[1]<<8)+(t.value[0]<<16);if(e>=this.pointCount||e<0)return null;var r=this.points[e],n=this._selectResult;n.index=e;for(var i=0;i<3;++i)n.position[i]=n.dataCoordinate[i]=r[i];return n},m.highlight=function(t){if(t){var e=t.index,r=255&e,n=e>>8&255,i=e>>16&255;this.highlightId=[r/255,n/255,i/255,0]}else this.highlightId=[1,1,1,1]},m.update=function(t){if(\"perspective\"in(t=t||{})&&(this.useOrtho=!t.perspective),\"orthographic\"in t&&(this.useOrtho=!!t.orthographic),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"project\"in t)if(Array.isArray(t.project))this.axesProject=t.project;else{var e=!!t.project;this.axesProject=[e,e,e]}if(\"projectScale\"in t)if(Array.isArray(t.projectScale))this.projectScale=t.projectScale.slice();else{var r=+t.projectScale;this.projectScale=[r,r,r]}if(this.projectHasAlpha=!1,\"projectOpacity\"in t){if(Array.isArray(t.projectOpacity))this.projectOpacity=t.projectOpacity.slice();else{r=+t.projectOpacity;this.projectOpacity=[r,r,r]}for(var n=0;n<3;++n)this.projectOpacity[n]=g(this.projectOpacity[n]),this.projectOpacity[n]<1&&(this.projectHasAlpha=!0)}this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=g(t.opacity),this.opacity<1&&(this.hasAlpha=!0)),this.dirty=!0;var i,a,s=t.position,l=t.font||\"normal\",c=t.alignment||[0,0];if(2===c.length)i=c[0],a=c[1];else{i=[],a=[];for(n=0;n<c.length;++n)i[n]=c[n][0],a[n]=c[n][1]}var u=[1/0,1/0,1/0],h=[-1/0,-1/0,-1/0],f=t.glyph,p=t.color,d=t.size,v=t.angle,m=t.lineColor,y=-1,x=0,b=0,_=0;if(s.length){_=s.length;t:for(n=0;n<_;++n){for(var w=s[n],k=0;k<3;++k)if(isNaN(w[k])||!isFinite(w[k]))continue t;var T=(N=O(f,n,l,this.pixelRatio)).mesh,A=N.lines,M=N.bounds;x+=3*T.cells.length,b+=2*A.edges.length}}var S=x+b,E=o.mallocFloat(3*S),C=o.mallocFloat(4*S),L=o.mallocFloat(2*S),P=o.mallocUint32(S);if(S>0){var z=0,I=x,D=[0,0,0,1],R=[0,0,0,1],F=Array.isArray(p)&&Array.isArray(p[0]),B=Array.isArray(m)&&Array.isArray(m[0]);t:for(n=0;n<_;++n){y+=1;for(w=s[n],k=0;k<3;++k){if(isNaN(w[k])||!isFinite(w[k]))continue t;h[k]=Math.max(h[k],w[k]),u[k]=Math.min(u[k],w[k])}T=(N=O(f,n,l,this.pixelRatio)).mesh,A=N.lines,M=N.bounds;var N,j=N.visible;if(j)if(Array.isArray(p)){if(3===(U=F?n<p.length?p[n]:[0,0,0,0]:p).length){for(k=0;k<3;++k)D[k]=U[k];D[3]=1}else if(4===U.length){for(k=0;k<4;++k)D[k]=U[k];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else D[0]=D[1]=D[2]=0,D[3]=1;else D=[1,1,1,0];if(j)if(Array.isArray(m)){var U;if(3===(U=B?n<m.length?m[n]:[0,0,0,0]:m).length){for(k=0;k<3;++k)R[k]=U[k];R[k]=1}else if(4===U.length){for(k=0;k<4;++k)R[k]=U[k];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else R[0]=R[1]=R[2]=0,R[3]=1;else R=[1,1,1,0];var V=.5;j?Array.isArray(d)?V=n<d.length?+d[n]:12:d?V=+d:this.useOrtho&&(V=12):V=0;var q=0;Array.isArray(v)?q=n<v.length?+v[n]:0:v&&(q=+v);var H=Math.cos(q),G=Math.sin(q);for(w=s[n],k=0;k<3;++k)h[k]=Math.max(h[k],w[k]),u[k]=Math.min(u[k],w[k]);var Y=i,W=a;Y=0;Array.isArray(i)?Y=n<i.length?i[n]:0:i&&(Y=i);W=0;Array.isArray(a)?W=n<a.length?a[n]:0:a&&(W=a);var X=[Y*=Y>0?1-M[0][0]:Y<0?1+M[1][0]:1,W*=W>0?1-M[0][1]:W<0?1+M[1][1]:1],Z=T.cells||[],J=T.positions||[];for(k=0;k<Z.length;++k)for(var K=Z[k],$=0;$<3;++$){for(var Q=0;Q<3;++Q)E[3*z+Q]=w[Q];for(Q=0;Q<4;++Q)C[4*z+Q]=D[Q];P[z]=y;var tt=J[K[$]];L[2*z]=V*(H*tt[0]-G*tt[1]+X[0]),L[2*z+1]=V*(G*tt[0]+H*tt[1]+X[1]),z+=1}for(Z=A.edges,J=A.positions,k=0;k<Z.length;++k)for(K=Z[k],$=0;$<2;++$){for(Q=0;Q<3;++Q)E[3*I+Q]=w[Q];for(Q=0;Q<4;++Q)C[4*I+Q]=R[Q];P[I]=y;tt=J[K[$]];L[2*I]=V*(H*tt[0]-G*tt[1]+X[0]),L[2*I+1]=V*(G*tt[0]+H*tt[1]+X[1]),I+=1}}}this.bounds=[u,h],this.points=s,this.pointCount=s.length,this.vertexCount=x,this.lineVertexCount=b,this.pointBuffer.update(E),this.colorBuffer.update(C),this.glyphBuffer.update(L),this.idBuffer.update(P),o.free(E),o.free(C),o.free(L),o.free(P)},m.dispose=function(){this.shader.dispose(),this.orthoShader.dispose(),this.pickPerspectiveShader.dispose(),this.pickOrthoShader.dispose(),this.vao.dispose(),this.pointBuffer.dispose(),this.colorBuffer.dispose(),this.glyphBuffer.dispose(),this.idBuffer.dispose()}},{\"./lib/get-simple-string\":294,\"./lib/glyphs\":295,\"./lib/shaders\":296,\"gl-buffer\":241,\"gl-mat4/multiply\":267,\"gl-vao\":327,\"is-string-blank\":423,\"typedarray-pool\":545}],298:[function(t,e,r){\"use strict\";var n=t(\"glslify\");r.boxVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 vertex;\\n\\nuniform vec2 cornerA, cornerB;\\n\\nvoid main() {\\n  gl_Position = vec4(mix(cornerA, cornerB, vertex), 0, 1);\\n}\\n\"]),r.boxFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\n\\nvoid main() {\\n  gl_FragColor = color;\\n}\\n\"])},{glslify:409}],299:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"./lib/shaders\");function o(t,e,r){this.plot=t,this.boxBuffer=e,this.boxShader=r,this.enabled=!0,this.selectBox=[1/0,1/0,-1/0,-1/0],this.borderColor=[0,0,0,1],this.innerFill=!1,this.innerColor=[0,0,0,.25],this.outerFill=!0,this.outerColor=[0,0,0,.5],this.borderWidth=10}e.exports=function(t,e){var r=t.gl,s=i(r,[0,0,0,1,1,0,1,1]),l=n(r,a.boxVertex,a.boxFragment),c=new o(t,s,l);return c.update(e),t.addOverlay(c),c};var s=o.prototype;s.draw=function(){if(this.enabled){var t=this.plot,e=this.selectBox,r=this.borderWidth,n=(this.innerFill,this.innerColor),i=(this.outerFill,this.outerColor),a=this.borderColor,o=t.box,s=t.screenBox,l=t.dataBox,c=t.viewBox,u=t.pixelRatio,h=(e[0]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],f=(e[1]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1],p=(e[2]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],d=(e[3]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1];if(h=Math.max(h,c[0]),f=Math.max(f,c[1]),p=Math.min(p,c[2]),d=Math.min(d,c[3]),!(p<h||d<f)){o.bind();var g=s[2]-s[0],v=s[3]-s[1];if(this.outerFill&&(o.drawBox(0,0,g,f,i),o.drawBox(0,f,h,d,i),o.drawBox(0,d,g,v,i),o.drawBox(p,f,g,d,i)),this.innerFill&&o.drawBox(h,f,p,d,n),r>0){var m=r*u;o.drawBox(h-m,f-m,p+m,f+m,a),o.drawBox(h-m,d-m,p+m,d+m,a),o.drawBox(h-m,f-m,h+m,d+m,a),o.drawBox(p-m,f-m,p+m,d+m,a)}}}},s.update=function(t){t=t||{},this.innerFill=!!t.innerFill,this.outerFill=!!t.outerFill,this.innerColor=(t.innerColor||[0,0,0,.5]).slice(),this.outerColor=(t.outerColor||[0,0,0,.5]).slice(),this.borderColor=(t.borderColor||[0,0,0,1]).slice(),this.borderWidth=t.borderWidth||0,this.selectBox=(t.selectBox||this.selectBox).slice()},s.dispose=function(){this.boxBuffer.dispose(),this.boxShader.dispose(),this.plot.removeOverlay(this)}},{\"./lib/shaders\":298,\"gl-buffer\":241,\"gl-shader\":301}],300:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=n(t,e),a=i.mallocUint8(e[0]*e[1]*4);return new c(t,r,a)};var n=t(\"gl-fbo\"),i=t(\"typedarray-pool\"),a=t(\"ndarray\"),o=t(\"bit-twiddle\").nextPow2,s=t(\"cwise/lib/wrapper\")({args:[\"array\",{offset:[0,0,1],array:0},{offset:[0,0,2],array:0},{offset:[0,0,3],array:0},\"scalar\",\"scalar\",\"index\"],pre:{body:\"{this_closestD2=1e8,this_closestX=-1,this_closestY=-1}\",args:[],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[]},body:{body:\"{if(_inline_16_arg0_<255||_inline_16_arg1_<255||_inline_16_arg2_<255||_inline_16_arg3_<255){var _inline_16_l=_inline_16_arg4_-_inline_16_arg6_[0],_inline_16_a=_inline_16_arg5_-_inline_16_arg6_[1],_inline_16_f=_inline_16_l*_inline_16_l+_inline_16_a*_inline_16_a;_inline_16_f<this_closestD2&&(this_closestD2=_inline_16_f,this_closestX=_inline_16_arg6_[0],this_closestY=_inline_16_arg6_[1])}}\",args:[{name:\"_inline_16_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg4_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg5_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg6_\",lvalue:!1,rvalue:!0,count:4}],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[\"_inline_16_a\",\"_inline_16_f\",\"_inline_16_l\"]},post:{body:\"{return[this_closestX,this_closestY,this_closestD2]}\",args:[],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[]},debug:!1,funcName:\"cwise\",blockSize:64});function l(t,e,r,n,i){this.coord=[t,e],this.id=r,this.value=n,this.distance=i}function c(t,e,r){this.gl=t,this.fbo=e,this.buffer=r,this._readTimeout=null;var n=this;this._readCallback=function(){n.gl&&(e.bind(),t.readPixels(0,0,e.shape[0],e.shape[1],t.RGBA,t.UNSIGNED_BYTE,n.buffer),n._readTimeout=null)}}var u=c.prototype;Object.defineProperty(u,\"shape\",{get:function(){return this.gl?this.fbo.shape.slice():[0,0]},set:function(t){if(this.gl){this.fbo.shape=t;var e=this.fbo.shape[0],r=this.fbo.shape[1];if(r*e*4>this.buffer.length){i.free(this.buffer);for(var n=this.buffer=i.mallocUint8(o(r*e*4)),a=0;a<r*e*4;++a)n[a]=255}return t}}}),u.begin=function(){var t=this.gl;this.shape;t&&(this.fbo.bind(),t.clearColor(1,1,1,1),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT))},u.end=function(){var t=this.gl;t&&(t.bindFramebuffer(t.FRAMEBUFFER,null),this._readTimeout||clearTimeout(this._readTimeout),this._readTimeout=setTimeout(this._readCallback,1))},u.query=function(t,e,r){if(!this.gl)return null;var n=this.fbo.shape.slice();t|=0,e|=0,\"number\"!=typeof r&&(r=1);var i=0|Math.min(Math.max(t-r,0),n[0]),o=0|Math.min(Math.max(t+r,0),n[0]),c=0|Math.min(Math.max(e-r,0),n[1]),u=0|Math.min(Math.max(e+r,0),n[1]);if(o<=i||u<=c)return null;var h=[o-i,u-c],f=a(this.buffer,[h[0],h[1],4],[4,4*n[0],1],4*(i+n[0]*c)),p=s(f.hi(h[0],h[1],1),r,r),d=p[0],g=p[1];return d<0||Math.pow(this.radius,2)<p[2]?null:new l(d+i|0,g+c|0,f.get(d,g,0),[f.get(d,g,1),f.get(d,g,2),f.get(d,g,3)],Math.sqrt(p[2]))},u.dispose=function(){this.gl&&(this.fbo.dispose(),i.free(this.buffer),this.gl=null,this._readTimeout&&clearTimeout(this._readTimeout))}},{\"bit-twiddle\":92,\"cwise/lib/wrapper\":149,\"gl-fbo\":249,ndarray:450,\"typedarray-pool\":545}],301:[function(t,e,r){\"use strict\";var n=t(\"./lib/create-uniforms\"),i=t(\"./lib/create-attributes\"),a=t(\"./lib/reflect\"),o=t(\"./lib/shader-cache\"),s=t(\"./lib/runtime-reflect\"),l=t(\"./lib/GLError\");function c(t){this.gl=t,this.gl.lastAttribCount=0,this._vref=this._fref=this._relink=this.vertShader=this.fragShader=this.program=this.attributes=this.uniforms=this.types=null}var u=c.prototype;function h(t,e){return t.name<e.name?-1:1}u.bind=function(){var t;this.program||this._relink();var e=this.gl.getProgramParameter(this.program,this.gl.ACTIVE_ATTRIBUTES),r=this.gl.lastAttribCount;if(e>r)for(t=r;t<e;t++)this.gl.enableVertexAttribArray(t);else if(r>e)for(t=e;t<r;t++)this.gl.disableVertexAttribArray(t);this.gl.lastAttribCount=e,this.gl.useProgram(this.program)},u.dispose=function(){for(var t=this.gl.lastAttribCount,e=0;e<t;e++)this.gl.disableVertexAttribArray(e);this.gl.lastAttribCount=0,this._fref&&this._fref.dispose(),this._vref&&this._vref.dispose(),this.attributes=this.types=this.vertShader=this.fragShader=this.program=this._relink=this._fref=this._vref=null},u.update=function(t,e,r,c){if(!e||1===arguments.length){var u=t;t=u.vertex,e=u.fragment,r=u.uniforms,c=u.attributes}var f=this,p=f.gl,d=f._vref;f._vref=o.shader(p,p.VERTEX_SHADER,t),d&&d.dispose(),f.vertShader=f._vref.shader;var g=this._fref;if(f._fref=o.shader(p,p.FRAGMENT_SHADER,e),g&&g.dispose(),f.fragShader=f._fref.shader,!r||!c){var v=p.createProgram();if(p.attachShader(v,f.fragShader),p.attachShader(v,f.vertShader),p.linkProgram(v),!p.getProgramParameter(v,p.LINK_STATUS)){var m=p.getProgramInfoLog(v);throw new l(m,\"Error linking program:\"+m)}r=r||s.uniforms(p,v),c=c||s.attributes(p,v),p.deleteProgram(v)}(c=c.slice()).sort(h);var y,x=[],b=[],_=[];for(y=0;y<c.length;++y){var w=c[y];if(w.type.indexOf(\"mat\")>=0){for(var k=0|w.type.charAt(w.type.length-1),T=new Array(k),A=0;A<k;++A)T[A]=_.length,b.push(w.name+\"[\"+A+\"]\"),\"number\"==typeof w.location?_.push(w.location+A):Array.isArray(w.location)&&w.location.length===k&&\"number\"==typeof w.location[A]?_.push(0|w.location[A]):_.push(-1);x.push({name:w.name,type:w.type,locations:T})}else x.push({name:w.name,type:w.type,locations:[_.length]}),b.push(w.name),\"number\"==typeof w.location?_.push(0|w.location):_.push(-1)}var M=0;for(y=0;y<_.length;++y)if(_[y]<0){for(;_.indexOf(M)>=0;)M+=1;_[y]=M}var S=new Array(r.length);function E(){f.program=o.program(p,f._vref,f._fref,b,_);for(var t=0;t<r.length;++t)S[t]=p.getUniformLocation(f.program,r[t].name)}E(),f._relink=E,f.types={uniforms:a(r),attributes:a(c)},f.attributes=i(p,f,x,_),Object.defineProperty(f,\"uniforms\",n(p,f,r,S))},e.exports=function(t,e,r,n,i){var a=new c(t);return a.update(e,r,n,i),a}},{\"./lib/GLError\":302,\"./lib/create-attributes\":303,\"./lib/create-uniforms\":304,\"./lib/reflect\":305,\"./lib/runtime-reflect\":306,\"./lib/shader-cache\":307}],302:[function(t,e,r){function n(t,e,r){this.shortMessage=e||\"\",this.longMessage=r||\"\",this.rawError=t||\"\",this.message=\"gl-shader: \"+(e||t||\"\")+(r?\"\\n\"+r:\"\"),this.stack=(new Error).stack}n.prototype=new Error,n.prototype.name=\"GLError\",n.prototype.constructor=n,e.exports=n},{}],303:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){for(var a={},l=0,c=r.length;l<c;++l){var u=r[l],h=u.name,f=u.type,p=u.locations;switch(f){case\"bool\":case\"int\":case\"float\":o(t,e,p[0],i,1,a,h);break;default:if(f.indexOf(\"vec\")>=0){var d=f.charCodeAt(f.length-1)-48;if(d<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+h+\": \"+f);o(t,e,p[0],i,d,a,h)}else{if(!(f.indexOf(\"mat\")>=0))throw new n(\"\",\"Unknown data type for attribute \"+h+\": \"+f);var d=f.charCodeAt(f.length-1)-48;if(d<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+h+\": \"+f);s(t,e,p,i,d,a,h)}}}return a};var n=t(\"./GLError\");function i(t,e,r,n,i,a){this._gl=t,this._wrapper=e,this._index=r,this._locations=n,this._dimension=i,this._constFunc=a}var a=i.prototype;function o(t,e,r,n,a,o,s){for(var l=[\"gl\",\"v\"],c=[],u=0;u<a;++u)l.push(\"x\"+u),c.push(\"x\"+u);l.push(\"if(x0.length===void 0){return gl.vertexAttrib\"+a+\"f(v,\"+c.join()+\")}else{return gl.vertexAttrib\"+a+\"fv(v,x0)}\");var h=Function.apply(null,l),f=new i(t,e,r,n,a,h);Object.defineProperty(o,s,{set:function(e){return t.disableVertexAttribArray(n[r]),h(t,n[r],e),e},get:function(){return f},enumerable:!0})}function s(t,e,r,n,i,a,s){for(var l=new Array(i),c=new Array(i),u=0;u<i;++u)o(t,e,r[u],n,i,l,u),c[u]=l[u];Object.defineProperty(l,\"location\",{set:function(t){if(Array.isArray(t))for(var e=0;e<i;++e)c[e].location=t[e];else for(e=0;e<i;++e)c[e].location=t+e;return t},get:function(){for(var t=new Array(i),e=0;e<i;++e)t[e]=n[r[e]];return t},enumerable:!0}),l.pointer=function(e,a,o,s){e=e||t.FLOAT,a=!!a,o=o||i*i,s=s||0;for(var l=0;l<i;++l){var c=n[r[l]];t.vertexAttribPointer(c,i,e,a,o,s+l*i),t.enableVertexAttribArray(c)}};var h=new Array(i),f=t[\"vertexAttrib\"+i+\"fv\"];Object.defineProperty(a,s,{set:function(e){for(var a=0;a<i;++a){var o=n[r[a]];if(t.disableVertexAttribArray(o),Array.isArray(e[0]))f.call(t,o,e[a]);else{for(var s=0;s<i;++s)h[s]=e[i*a+s];f.call(t,o,h)}}return e},get:function(){return l},enumerable:!0})}a.pointer=function(t,e,r,n){var i=this._gl,a=this._locations[this._index];i.vertexAttribPointer(a,this._dimension,t||i.FLOAT,!!e,r||0,n||0),i.enableVertexAttribArray(a)},a.set=function(t,e,r,n){return this._constFunc(this._locations[this._index],t,e,r,n)},Object.defineProperty(a,\"location\",{get:function(){return this._locations[this._index]},set:function(t){return t!==this._locations[this._index]&&(this._locations[this._index]=0|t,this._wrapper.program=null),0|t}})},{\"./GLError\":302}],304:[function(t,e,r){\"use strict\";var n=t(\"./reflect\"),i=t(\"./GLError\");function a(t){return new Function(\"y\",\"return function(){return y}\")(t)}function o(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}e.exports=function(t,e,r,s){function l(t,e,r){switch(r){case\"bool\":case\"int\":case\"sampler2D\":case\"samplerCube\":return\"gl.uniform1i(locations[\"+e+\"],obj\"+t+\")\";case\"float\":return\"gl.uniform1f(locations[\"+e+\"],obj\"+t+\")\";default:var n=r.indexOf(\"vec\");if(!(0<=n&&n<=1&&r.length===4+n)){if(0===r.indexOf(\"mat\")&&4===r.length){var a=r.charCodeAt(r.length-1)-48;if(a<2||a>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+r);return\"gl.uniformMatrix\"+a+\"fv(locations[\"+e+\"],false,obj\"+t+\")\"}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+r)}var a=r.charCodeAt(r.length-1)-48;if(a<2||a>4)throw new i(\"\",\"Invalid data type\");switch(r.charAt(0)){case\"b\":case\"i\":return\"gl.uniform\"+a+\"iv(locations[\"+e+\"],obj\"+t+\")\";case\"v\":return\"gl.uniform\"+a+\"fv(locations[\"+e+\"],obj\"+t+\")\";default:throw new i(\"\",\"Unrecognized data type for vector \"+name+\": \"+r)}}}function c(e){for(var n=[\"return function updateProperty(obj){\"],i=function t(e,r){if(\"object\"!=typeof r)return[[e,r]];var n=[];for(var i in r){var a=r[i],o=e;parseInt(i)+\"\"===i?o+=\"[\"+i+\"]\":o+=\".\"+i,\"object\"==typeof a?n.push.apply(n,t(o,a)):n.push([o,a])}return n}(\"\",e),a=0;a<i.length;++a){var o=i[a],c=o[0],u=o[1];s[u]&&n.push(l(c,u,r[u].type))}n.push(\"return obj}\");var h=new Function(\"gl\",\"locations\",n.join(\"\\n\"));return h(t,s)}function u(n,l,u){if(\"object\"==typeof u){var f=h(u);Object.defineProperty(n,l,{get:a(f),set:c(u),enumerable:!0,configurable:!1})}else s[u]?Object.defineProperty(n,l,{get:(p=u,new Function(\"gl\",\"wrapper\",\"locations\",\"return function(){return gl.getUniform(wrapper.program,locations[\"+p+\"])}\")(t,e,s)),set:c(u),enumerable:!0,configurable:!1}):n[l]=function(t){switch(t){case\"bool\":return!1;case\"int\":case\"sampler2D\":case\"samplerCube\":case\"float\":return 0;default:var e=t.indexOf(\"vec\");if(0<=e&&e<=1&&t.length===4+e){var r=t.charCodeAt(t.length-1)-48;if(r<2||r>4)throw new i(\"\",\"Invalid data type\");return\"b\"===t.charAt(0)?o(r,!1):o(r,0)}if(0===t.indexOf(\"mat\")&&4===t.length){var r=t.charCodeAt(t.length-1)-48;if(r<2||r>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+t);return o(r*r,0)}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+t)}}(r[u].type);var p}function h(t){var e;if(Array.isArray(t)){e=new Array(t.length);for(var r=0;r<t.length;++r)u(e,r,t[r])}else for(var n in e={},t)u(e,n,t[n]);return e}var f=n(r,!0);return{get:a(h(f)),set:c(f),enumerable:!0,configurable:!0}}},{\"./GLError\":302,\"./reflect\":305}],305:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r={},n=0;n<t.length;++n)for(var i=t[n].name,a=i.split(\".\"),o=r,s=0;s<a.length;++s){var l=a[s].split(\"[\");if(l.length>1){l[0]in o||(o[l[0]]=[]),o=o[l[0]];for(var c=1;c<l.length;++c){var u=parseInt(l[c]);c<l.length-1||s<a.length-1?(u in o||(c<l.length-1?o[u]=[]:o[u]={}),o=o[u]):o[u]=e?n:t[n].type}}else s<a.length-1?(l[0]in o||(o[l[0]]={}),o=o[l[0]]):o[l[0]]=e?n:t[n].type}return r}},{}],306:[function(t,e,r){\"use strict\";r.uniforms=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_UNIFORMS),n=[],i=0;i<r;++i){var o=t.getActiveUniform(e,i);if(o){var s=a(t,o.type);if(o.size>1)for(var l=0;l<o.size;++l)n.push({name:o.name.replace(\"[0]\",\"[\"+l+\"]\"),type:s});else n.push({name:o.name,type:s})}}return n},r.attributes=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_ATTRIBUTES),n=[],i=0;i<r;++i){var o=t.getActiveAttrib(e,i);o&&n.push({name:o.name,type:a(t,o.type)})}return n};var n={FLOAT:\"float\",FLOAT_VEC2:\"vec2\",FLOAT_VEC3:\"vec3\",FLOAT_VEC4:\"vec4\",INT:\"int\",INT_VEC2:\"ivec2\",INT_VEC3:\"ivec3\",INT_VEC4:\"ivec4\",BOOL:\"bool\",BOOL_VEC2:\"bvec2\",BOOL_VEC3:\"bvec3\",BOOL_VEC4:\"bvec4\",FLOAT_MAT2:\"mat2\",FLOAT_MAT3:\"mat3\",FLOAT_MAT4:\"mat4\",SAMPLER_2D:\"sampler2D\",SAMPLER_CUBE:\"samplerCube\"},i=null;function a(t,e){if(!i){var r=Object.keys(n);i={};for(var a=0;a<r.length;++a){var o=r[a];i[t[o]]=n[o]}}return i[e]}},{}],307:[function(t,e,r){\"use strict\";r.shader=function(t,e,r){return u(t).getShaderReference(e,r)},r.program=function(t,e,r,n,i){return u(t).getProgram(e,r,n,i)};var n=t(\"./GLError\"),i=t(\"gl-format-compiler-error\"),a=new(\"undefined\"==typeof WeakMap?t(\"weakmap-shim\"):WeakMap),o=0;function s(t,e,r,n,i,a,o){this.id=t,this.src=e,this.type=r,this.shader=n,this.count=a,this.programs=[],this.cache=o}function l(t){this.gl=t,this.shaders=[{},{}],this.programs={}}s.prototype.dispose=function(){if(0==--this.count){for(var t=this.cache,e=t.gl,r=this.programs,n=0,i=r.length;n<i;++n){var a=t.programs[r[n]];a&&(delete t.programs[n],e.deleteProgram(a))}e.deleteShader(this.shader),delete t.shaders[this.type===e.FRAGMENT_SHADER|0][this.src]}};var c=l.prototype;function u(t){var e=a.get(t);return e||(e=new l(t),a.set(t,e)),e}c.getShaderReference=function(t,e){var r=this.gl,a=this.shaders[t===r.FRAGMENT_SHADER|0],l=a[e];if(l&&r.isShader(l.shader))l.count+=1;else{var c=function(t,e,r){var a=t.createShader(e);if(t.shaderSource(a,r),t.compileShader(a),!t.getShaderParameter(a,t.COMPILE_STATUS)){var o=t.getShaderInfoLog(a);try{var s=i(o,r,e)}catch(t){throw console.warn(\"Failed to format compiler error: \"+t),new n(o,\"Error compiling shader:\\n\"+o)}throw new n(o,s.short,s.long)}return a}(r,t,e);l=a[e]=new s(o++,e,t,c,[],1,this)}return l},c.getProgram=function(t,e,r,i){var a=[t.id,e.id,r.join(\":\"),i.join(\":\")].join(\"@\"),o=this.programs[a];return o&&this.gl.isProgram(o)||(this.programs[a]=o=function(t,e,r,i,a){var o=t.createProgram();t.attachShader(o,e),t.attachShader(o,r);for(var s=0;s<i.length;++s)t.bindAttribLocation(o,a[s],i[s]);if(t.linkProgram(o),!t.getProgramParameter(o,t.LINK_STATUS)){var l=t.getProgramInfoLog(o);throw new n(l,\"Error linking program: \"+l)}return o}(this.gl,t.shader,e.shader,r,i),t.programs.push(a),e.programs.push(a)),o}},{\"./GLError\":302,\"gl-format-compiler-error\":250,\"weakmap-shim\":555}],308:[function(t,e,r){\"use strict\";function n(t){this.plot=t,this.enable=[!0,!0,!1,!1],this.width=[1,1,1,1],this.color=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.center=[1/0,1/0]}e.exports=function(t,e){var r=new n(t);return r.update(e),t.addOverlay(r),r};var i=n.prototype;i.update=function(t){t=t||{},this.enable=(t.enable||[!0,!0,!1,!1]).slice(),this.width=(t.width||[1,1,1,1]).slice(),this.color=(t.color||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]).map(function(t){return t.slice()}),this.center=(t.center||[1/0,1/0]).slice(),this.plot.setOverlayDirty()},i.draw=function(){var t=this.enable,e=this.width,r=this.color,n=this.center,i=this.plot,a=i.line,o=i.dataBox,s=i.viewBox;if(a.bind(),o[0]<=n[0]&&n[0]<=o[2]&&o[1]<=n[1]&&n[1]<=o[3]){var l=s[0]+(n[0]-o[0])/(o[2]-o[0])*(s[2]-s[0]),c=s[1]+(n[1]-o[1])/(o[3]-o[1])*(s[3]-s[1]);t[0]&&a.drawLine(l,c,s[0],c,e[0],r[0]),t[1]&&a.drawLine(l,c,l,s[1],e[1],r[1]),t[2]&&a.drawLine(l,c,s[2],c,e[2],r[2]),t[3]&&a.drawLine(l,c,l,s[3],e[3],r[3])}},i.dispose=function(){this.plot.removeOverlay(this)}},{}],309:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, color;\\nattribute float weight;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 coordinates[3];\\nuniform vec4 colors[3];\\nuniform vec2 screenShape;\\nuniform float lineWidth;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vertexPosition = mix(coordinates[0],\\n    mix(coordinates[2], coordinates[1], 0.5 * (position + 1.0)), abs(position));\\n\\n  vec4 clipPos = projection * view * model * vec4(vertexPosition, 1.0);\\n  vec2 clipOffset = (projection * view * model * vec4(color, 0.0)).xy;\\n  vec2 delta = weight * clipOffset * screenShape;\\n  vec2 lineOffset = normalize(vec2(delta.y, -delta.x)) / screenShape;\\n\\n  gl_Position   = vec4(clipPos.xy + clipPos.w * 0.5 * lineWidth * lineOffset, clipPos.z, clipPos.w);\\n  fragColor     = color.x * colors[0] + color.y * colors[1] + color.z * colors[2];\\n}\\n\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  gl_FragColor = fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec3\"},{name:\"weight\",type:\"float\"}])}},{\"gl-shader\":301,glslify:409}],310:[function(t,e,r){\"use strict\";var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\");e.exports=function(t,e){var r=[];function o(t,e,n,i,a,o){var s=[t,e,n,0,0,0,1];s[i+3]=1,s[i]=a,r.push.apply(r,s),s[6]=-1,r.push.apply(r,s),s[i]=o,r.push.apply(r,s),r.push.apply(r,s),s[6]=1,r.push.apply(r,s),s[i]=a,r.push.apply(r,s)}o(0,0,0,0,0,1),o(0,0,0,1,0,1),o(0,0,0,2,0,1),o(1,0,0,1,-1,1),o(1,0,0,2,-1,1),o(0,1,0,0,-1,1),o(0,1,0,2,-1,1),o(0,0,1,0,-1,1),o(0,0,1,1,-1,1);var l=n(t,r),c=i(t,[{type:t.FLOAT,buffer:l,size:3,offset:0,stride:28},{type:t.FLOAT,buffer:l,size:3,offset:12,stride:28},{type:t.FLOAT,buffer:l,size:1,offset:24,stride:28}]),u=a(t);u.attributes.position.location=0,u.attributes.color.location=1,u.attributes.weight.location=2;var h=new s(t,l,c,u);return h.update(e),h};var o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n,this.pixelRatio=1,this.bounds=[[-1e3,-1e3,-1e3],[1e3,1e3,1e3]],this.position=[0,0,0],this.lineWidth=[2,2,2],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.enabled=[!0,!0,!0],this.drawSides=[!0,!0,!0],this.axes=null}var l=s.prototype,c=[0,0,0],u=[0,0,0],h=[0,0];l.isTransparent=function(){return!1},l.drawTransparent=function(t){},l.draw=function(t){var e=this.gl,r=this.vao,n=this.shader;r.bind(),n.bind();var i,a=t.model||o,s=t.view||o,l=t.projection||o;this.axes&&(i=this.axes.lastCubeProps.axis);for(var f=c,p=u,d=0;d<3;++d)i&&i[d]<0?(f[d]=this.bounds[0][d],p[d]=this.bounds[1][d]):(f[d]=this.bounds[1][d],p[d]=this.bounds[0][d]);h[0]=e.drawingBufferWidth,h[1]=e.drawingBufferHeight,n.uniforms.model=a,n.uniforms.view=s,n.uniforms.projection=l,n.uniforms.coordinates=[this.position,f,p],n.uniforms.colors=this.colors,n.uniforms.screenShape=h;for(d=0;d<3;++d)n.uniforms.lineWidth=this.lineWidth[d]*this.pixelRatio,this.enabled[d]&&(r.draw(e.TRIANGLES,6,6*d),this.drawSides[d]&&r.draw(e.TRIANGLES,12,18+12*d));r.unbind()},l.update=function(t){t&&(\"bounds\"in t&&(this.bounds=t.bounds),\"position\"in t&&(this.position=t.position),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"colors\"in t&&(this.colors=t.colors),\"enabled\"in t&&(this.enabled=t.enabled),\"drawSides\"in t&&(this.drawSides=t.drawSides))},l.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders/index\":309,\"gl-buffer\":241,\"gl-vao\":327}],311:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\nuniform float vectorScale;\\nuniform float tubeScale;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * tubePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal,0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(tubePosition, 1.0);\\n  vec4 t_position  = view * tubePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = tubePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular\\n            , opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform float tubeScale;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  gl_Position = projection * view * tubePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec4\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec4\"}]}},{glslify:409}],312:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./shaders\"),g=d.meshShader,v=d.pickShader,m=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function y(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,y,x,b,_,w,k,T){this.gl=t,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=i,this.triangleVectors=a,this.triangleColors=s,this.triangleNormals=c,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=u,this.triangleCount=0,this.lineWidth=1,this.edgePositions=h,this.edgeColors=p,this.edgeUVs=d,this.edgeIds=f,this.edgeVAO=g,this.edgeCount=0,this.pointPositions=v,this.pointColors=x,this.pointUVs=b,this.pointSizes=_,this.pointIds=y,this.pointVAO=w,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=k,this.contourVAO=T,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!1,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.tubeScale=1,this._model=m,this._view=m,this._projection=m,this._resolution=[1,1],this.pixelRatio=1}var x=y.prototype;function b(t){var e=n(t,v.vertex,v.fragment,null,v.attributes);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.vector.location=5,e}x.isOpaque=function(){return this.opacity>=1},x.isTransparent=function(){return this.opacity<1},x.pickSlots=1,x.setPickBase=function(t){this.pickId=t},x.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=i[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},x.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=h({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return u(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,i=t.vectors;if(n&&r&&i){void 0!==t.tubeScale&&(this.tubeScale=t.tubeScale);var a=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[],w=[],k=[];this.cells=r,this.positions=n,this.vectors=i;var T=t.vertexNormals,A=t.cellNormals,M=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,S=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!A&&(A=s.faceNormals(r,n,S)),A||T||(T=s.vertexNormals(r,n,M));var E=t.vertexColors,C=t.cellColors,L=t.meshColor||[1,1,1,1],P=t.vertexUVs,O=t.vertexIntensity,z=t.cellUVs,I=t.cellIntensity,D=1/0,R=-1/0;if(!P&&!z)if(O)if(t.vertexIntensityBounds)D=+t.vertexIntensityBounds[0],R=+t.vertexIntensityBounds[1];else for(var F=0;F<O.length;++F){var B=O[F];D=Math.min(D,B),R=Math.max(R,B)}else if(I)for(F=0;F<I.length;++F){B=I[F];D=Math.min(D,B),R=Math.max(R,B)}else for(F=0;F<n.length;++F){B=n[F][2];D=Math.min(D,B),R=Math.max(R,B)}this.intensity=O||(I?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,I):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var N=t.pointSizes,j=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(F=0;F<n.length;++F)for(var U=n[F],V=0;V<3;++V)!isNaN(U[V])&&isFinite(U[V])&&(this.bounds[0][V]=Math.min(this.bounds[0][V],U[V]),this.bounds[1][V]=Math.max(this.bounds[1][V],U[V]));var q=0,H=0,G=0;t:for(F=0;F<r.length;++F){var Y=r[F];switch(Y.length){case 1:for(U=n[X=Y[0]],V=0;V<3;++V)if(isNaN(U[V])||!isFinite(U[V]))continue t;x.push(U[0],U[1],U[2],U[3]),3===(Z=E?E[X]:C?C[F]:L).length?b.push(Z[0],Z[1],Z[2],1):b.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],_.push(J[0],J[1]),N?w.push(N[X]):w.push(j),k.push(F),G+=1;break;case 2:for(V=0;V<2;++V){U=n[X=Y[V]];for(var W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t}for(V=0;V<2;++V){U=n[X=Y[V]];g.push(U[0],U[1],U[2]),3===(Z=E?E[X]:C?C[F]:L).length?v.push(Z[0],Z[1],Z[2],1):v.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],m.push(J[0],J[1]),y.push(F)}H+=1;break;case 3:for(V=0;V<3;++V)for(U=n[X=Y[V]],W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t;for(V=0;V<3;++V){var X;U=n[X=Y[2-V]];a.push(U[0],U[1],U[2],U[3]);var Z,J,K,$=i[X];l.push($[0],$[1],$[2],$[3]),3===(Z=E?E[X]:C?C[F]:L).length?c.push(Z[0],Z[1],Z[2],1):c.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],p.push(J[0],J[1]),K=T?T[X]:A[F],f.push(K[0],K[1],K[2]),d.push(F)}q+=1}}this.pointCount=G,this.edgeCount=H,this.triangleCount=q,this.pointPositions.update(x),this.pointColors.update(b),this.pointUVs.update(_),this.pointSizes.update(w),this.pointIds.update(new Uint32Array(k)),this.edgePositions.update(g),this.edgeColors.update(v),this.edgeUVs.update(m),this.edgeIds.update(new Uint32Array(y)),this.trianglePositions.update(a),this.triangleVectors.update(l),this.triangleColors.update(c),this.triangleUVs.update(p),this.triangleNormals.update(f),this.triangleIds.update(new Uint32Array(d))}},x.drawTransparent=x.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:m.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,tubeScale:this.tubeScale,contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var f=u[12+o],p=0;p<3;++p)f+=u[4*p+o]*this.lightPosition[p];s.lightPosition[o]=f/h}if(this.triangleCount>0){var d=this.triShader;d.bind(),d.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},x.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:i,clipBounds:a,tubeScale:this.tubeScale,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind())},x.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3);return{index:e,position:n,intensity:this.intensity[r[1]],velocity:this.vectors[r[1]].slice(0,3),divergence:this.vectors[r[1]][3],dataCoordinate:n}},x.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose()},e.exports=function(t,e){1===arguments.length&&(t=(e=t).gl);var r=e.triShader||function(t){var e=n(t,g.vertex,g.fragment,null,g.attributes);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.vector.location=5,e}(t),s=b(t),l=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));l.generateMipmap(),l.minFilter=t.LINEAR_MIPMAP_LINEAR,l.magFilter=t.LINEAR;var c=i(t),h=i(t),f=i(t),p=i(t),d=i(t),v=i(t),m=a(t,[{buffer:c,type:t.FLOAT,size:4},{buffer:v,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:f,type:t.FLOAT,size:4},{buffer:p,type:t.FLOAT,size:2},{buffer:d,type:t.FLOAT,size:3},{buffer:h,type:t.FLOAT,size:4}]),x=i(t),_=i(t),w=i(t),k=i(t),T=a(t,[{buffer:x,type:t.FLOAT,size:3},{buffer:k,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:_,type:t.FLOAT,size:4},{buffer:w,type:t.FLOAT,size:2}]),A=i(t),M=i(t),S=i(t),E=i(t),C=i(t),L=a(t,[{buffer:A,type:t.FLOAT,size:3},{buffer:C,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:M,type:t.FLOAT,size:4},{buffer:S,type:t.FLOAT,size:2},{buffer:E,type:t.FLOAT,size:1}]),P=i(t),O=new y(t,l,r,s,c,h,v,f,p,d,m,x,k,_,w,T,A,C,M,S,E,L,P,a(t,[{buffer:P,type:t.FLOAT,size:3}]));return O.update(e),O}},{\"./shaders\":311,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-shader\":301,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,normals:453,\"simplicial-complex-contour\":518,\"typedarray-pool\":545}],313:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\"),i=t(\"gl-vec4\"),a=function(t,e,r,a){for(var o=0,s=0;s<t.length;s++)for(var l=t[s].velocities,c=0;c<l.length;c++){var u=n.length(l[c]);u>o&&(o=u)}var h=t.map(function(t){return function(t,e,r,a){var o,s,l,c=t.points,u=t.velocities,h=t.divergences;n.set(n.create(),0,1,0),n.create(),n.create();n.create();for(var f=[],p=[],d=[],g=[],v=[],m=[],y=0,x=0,b=i.create(),_=i.create(),w=0;w<c.length;w++){o=c[w],s=u[w],l=h[w],0===e&&(l=.05*r),x=n.length(s)/a,b=i.create(),n.copy(b,s),b[3]=l;for(var k=0;k<8;k++)v[k]=[o[0],o[1],o[2],k];if(g.length>0)for(k=0;k<8;k++){var T=(k+1)%8;f.push(g[k],v[k],v[T],v[T],g[T],g[k]),d.push(_,b,b,b,_,_),m.push(y,x,x,x,y,y),p.push([f.length-6,f.length-5,f.length-4],[f.length-3,f.length-2,f.length-1])}var A=g;g=v,v=A,A=_,_=b,b=A,A=y,y=x,x=A}return{positions:f,cells:p,vectors:d,vertexIntensity:m}}(t,r,a,o)}),f=[],p=[],d=[],g=[];for(s=0;s<h.length;s++){var v=h[s],m=f.length;f=f.concat(v.positions),d=d.concat(v.vectors),g=g.concat(v.vertexIntensity);for(c=0;c<v.cells.length;c++){var y=v.cells[c],x=[];p.push(x);for(var b=0;b<y.length;b++)x.push(y[b]+m)}}return{positions:f,cells:p,vectors:d,vertexIntensity:g,colormap:e}},o=function(t,e){var r=n.create(),i=1e-4;n.add(r,t,[i,0,0]);var a=this.getVelocity(r);n.subtract(a,a,e),n.scale(a,a,1e4),n.add(r,t,[0,i,0]);var o=this.getVelocity(r);n.subtract(o,o,e),n.scale(o,o,1e4),n.add(r,t,[0,0,i]);var s=this.getVelocity(r);return n.subtract(s,s,e),n.scale(s,s,1e4),n.add(r,a,o),n.add(r,r,s),r},s=function(t){return f(t,this.vectors,this.meshgrid,this.clampBorders)},l=function(t,e){for(var r=0;r<t.length;r++){var n=t[r];if(n===e)return r;if(n>e)return r-1}return r},c=n.create(),u=n.create(),h=function(t,e,r){return t<e?e:t>r?r:t},f=function(t,e,r,i){var a=t[0],o=t[1],s=t[2],f=r[0].length,p=r[1].length,d=r[2].length,g=l(r[0],a),v=l(r[1],o),m=l(r[2],s),y=g+1,x=v+1,b=m+1;if(r[0][g]===a&&(y=g),r[1][v]===o&&(x=v),r[2][m]===s&&(b=m),i&&(g=h(g,0,f-1),y=h(y,0,f-1),v=h(v,0,p-1),x=h(x,0,p-1),m=h(m,0,d-1),b=h(b,0,d-1)),g<0||v<0||m<0||y>=f||x>=p||b>=d)return n.create();var _=(a-r[0][g])/(r[0][y]-r[0][g]),w=(o-r[1][v])/(r[1][x]-r[1][v]),k=(s-r[2][m])/(r[2][b]-r[2][m]);(_<0||_>1||isNaN(_))&&(_=0),(w<0||w>1||isNaN(w))&&(w=0),(k<0||k>1||isNaN(k))&&(k=0);var T=m*f*p,A=b*f*p,M=v*f,S=x*f,E=g,C=y,L=e[M+T+E],P=e[M+T+C],O=e[S+T+E],z=e[S+T+C],I=e[M+A+E],D=e[M+A+C],R=e[S+A+E],F=e[S+A+C],B=n.create();return n.lerp(B,L,P,_),n.lerp(c,O,z,_),n.lerp(B,B,c,w),n.lerp(c,I,D,_),n.lerp(u,R,F,_),n.lerp(c,c,u,w),n.lerp(B,B,c,k),B},p=function(t){var e=1/0;t.sort(function(t,e){return t-e});for(var r=1;r<t.length;r++){var n=Math.abs(t[r]-t[r-1]);n<e&&(e=n)}return e};e.exports=function(t,e){var r=t.startingPositions,i=t.maxLength||1e3,l=t.tubeSize||1,c=t.absoluteTubeSize;t.getDivergence||(t.getDivergence=o),t.getVelocity||(t.getVelocity=s),void 0===t.clampBorders&&(t.clampBorders=!0);var u=[],h=e[0][0],f=e[0][1],d=e[0][2],g=e[1][0],v=e[1][1],m=e[1][2],y=function(t,e){var r=e[0],n=e[1],i=e[2];return r>=h&&r<=g&&n>=f&&n<=v&&i>=d&&i<=m},x=10*n.distance(e[0],e[1])/i,b=x*x,_=1,w=0;n.create();r.length>=2&&(_=function(t){for(var e=[],r=[],n=[],i={},a={},o={},s=0;s<t.length;s++){var l=t[s],c=l[0],u=l[1],h=l[2];i[c]||(e.push(c),i[c]=!0),a[u]||(r.push(u),a[u]=!0),o[h]||(n.push(h),o[h]=!0)}var f=p(e),d=p(r),g=p(n),v=Math.min(f,d,g);return isFinite(v)?v:1}(r));for(var k=0;k<r.length;k++){var T=n.create();n.copy(T,r[k]);var A=[T],M=[],S=t.getVelocity(T),E=T;M.push(S);var C=[],L=t.getDivergence(T,S);(I=n.length(L))>w&&!isNaN(I)&&isFinite(I)&&(w=I),C.push(I),u.push({points:A,velocities:M,divergences:C});for(var P=0;P<100*i&&A.length<i&&y(0,T);){P++;var O=n.clone(S),z=n.squaredLength(O);if(0===z)break;if(z>b&&n.scale(O,O,x/Math.sqrt(z)),n.add(O,O,T),S=t.getVelocity(O),n.squaredDistance(E,O)-b>-1e-4*b){A.push(O),E=O,M.push(S);L=t.getDivergence(O,S);(I=n.length(L))>w&&!isNaN(I)&&isFinite(I)&&(w=I),C.push(I)}T=O}}for(k=0;k<C.length;k++){var I=C[k];!isNaN(I)&&isFinite(I)||(C[k]=w)}var D=a(u,t.colormap,w,_);return c?D.tubeScale=c:(0===w&&(w=1),D.tubeScale=.5*l*_/w),D},e.exports.createTubeMesh=t(\"./lib/tubemesh\")},{\"./lib/tubemesh\":312,\"gl-vec3\":346,\"gl-vec4\":382}],314:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute vec3 f;\\nattribute vec3 normal;\\n\\nuniform vec3 objectOffset;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 lightPosition, eyePosition;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 localCoordinate = vec3(uv.zw, f.x);\\n  worldCoordinate = objectOffset + localCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n  vec4 clipPosition = projection * view * worldPosition;\\n  gl_Position = clipPosition;\\n  kill = f.y;\\n  value = f.z;\\n  planeCoordinate = uv.xy;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * worldPosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  lightDirection = lightPosition - cameraCoordinate.xyz;\\n  eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  surfaceNormal  = normalize((vec4(normal,0) * inverseModel).xyz);\\n}\\n\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat beckmannSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness) {\\n  return beckmannDistribution(dot(surfaceNormal, normalize(lightDirection + viewDirection)), roughness);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 lowerBound, upperBound;\\nuniform float contourTint;\\nuniform vec4 contourColor;\\nuniform sampler2D colormap;\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform float vertexColor;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec3 N = normalize(surfaceNormal);\\n  vec3 V = normalize(eyeDirection);\\n  vec3 L = normalize(lightDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = max(beckmannSpecular(L, V, N, roughness), 0.);\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  //decide how to interpolate color \\u2014 in vertex or in fragment\\n  vec4 surfaceColor =\\n    step(vertexColor, .5) * texture2D(colormap, vec2(value, value)) +\\n    step(.5, vertexColor) * vColor;\\n\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = mix(litColor, contourColor, contourTint) * opacity;\\n}\\n\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute float f;\\n\\nuniform vec3 objectOffset;\\nuniform mat3 permutation;\\nuniform mat4 model, view, projection;\\nuniform float height, zOffset;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 dataCoordinate = permutation * vec3(uv.xy, height);\\n  worldCoordinate = objectOffset + dataCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n\\n  vec4 clipPosition = projection * view * worldPosition;\\n  clipPosition.z += zOffset;\\n\\n  gl_Position = clipPosition;\\n  value = f + objectOffset.z;\\n  kill = -1.0;\\n  planeCoordinate = uv.zw;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Don't do lighting for contours\\n  surfaceNormal   = vec3(1,0,0);\\n  eyeDirection    = vec3(0,1,0);\\n  lightDirection  = vec3(0,0,1);\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec2 shape;\\nuniform vec3 clipBounds[2];\\nuniform float pickId;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 surfaceNormal;\\n\\nvec2 splitFloat(float v) {\\n  float vh = 255.0 * v;\\n  float upper = floor(vh);\\n  float lower = fract(vh);\\n  return vec2(upper / 255.0, floor(lower * 16.0) / 16.0);\\n}\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec2 ux = splitFloat(planeCoordinate.x / shape.x);\\n  vec2 uy = splitFloat(planeCoordinate.y / shape.y);\\n  gl_FragColor = vec4(pickId, ux.x, uy.x, ux.y + (uy.y/16.0));\\n}\\n\"]);r.createShader=function(t){var e=n(t,a,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createPickShader=function(t){var e=n(t,a,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createContourShader=function(t){var e=n(t,s,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e},r.createPickContourShader=function(t){var e=n(t,s,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e}},{\"gl-shader\":301,glslify:409}],315:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],316:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=y(e),n=b(e),s=x(e),l=_(e),c=i(e),u=a(e,[{buffer:c,size:4,stride:w,offset:0},{buffer:c,size:3,stride:w,offset:16},{buffer:c,size:3,stride:w,offset:28}]),h=i(e),f=a(e,[{buffer:h,size:4,stride:20,offset:0},{buffer:h,size:1,stride:20,offset:16}]),p=i(e),d=a(e,[{buffer:p,size:2,type:e.FLOAT}]),g=o(e,1,S,e.RGBA,e.UNSIGNED_BYTE);g.minFilter=e.LINEAR,g.magFilter=e.LINEAR;var v=new E(e,[0,0],[[0,0,0],[0,0,0]],r,n,c,u,g,s,l,h,f,p,d,[0,0,0]),m={levels:[[],[],[]]};for(var k in t)m[k]=t[k];return m.colormap=m.colormap||\"jet\",v.update(m),v};var n=t(\"bit-twiddle\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"typedarray-pool\"),l=t(\"colormap\"),c=t(\"ndarray-ops\"),u=t(\"ndarray-pack\"),h=t(\"ndarray\"),f=t(\"surface-nets\"),p=t(\"gl-mat4/multiply\"),d=t(\"gl-mat4/invert\"),g=t(\"binary-search-bounds\"),v=t(\"ndarray-gradient\"),m=t(\"./lib/shaders\"),y=m.createShader,x=m.createContourShader,b=m.createPickShader,_=m.createPickContourShader,w=40,k=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1],T=[[0,0],[0,1],[1,0],[1,1],[1,0],[0,1]],A=[[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0]];function M(t,e,r,n,i){this.position=t,this.index=e,this.uv=r,this.level=n,this.dataCoordinate=i}!function(){for(var t=0;t<3;++t){var e=A[t],r=(t+2)%3;e[(t+1)%3+0]=1,e[r+3]=1,e[t+6]=1}}();var S=256;function E(t,e,r,n,i,a,o,l,c,u,f,p,d,g,v){this.gl=t,this.shape=e,this.bounds=r,this.objectOffset=v,this.intensityBounds=[],this._shader=n,this._pickShader=i,this._coordinateBuffer=a,this._vao=o,this._colorMap=l,this._contourShader=c,this._contourPickShader=u,this._contourBuffer=f,this._contourVAO=p,this._contourOffsets=[[],[],[]],this._contourCounts=[[],[],[]],this._vertexCount=0,this._pickResult=new M([0,0,0],[0,0],[0,0],[0,0,0],[0,0,0]),this._dynamicBuffer=d,this._dynamicVAO=g,this._dynamicOffsets=[0,0,0],this._dynamicCounts=[0,0,0],this.contourWidth=[1,1,1],this.contourLevels=[[1],[1],[1]],this.contourTint=[0,0,0],this.contourColor=[[.5,.5,.5,1],[.5,.5,.5,1],[.5,.5,.5,1]],this.showContour=!0,this.showSurface=!0,this.enableHighlight=[!0,!0,!0],this.highlightColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.highlightTint=[1,1,1],this.highlightLevel=[-1,-1,-1],this.enableDynamic=[!0,!0,!0],this.dynamicLevel=[NaN,NaN,NaN],this.dynamicColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.dynamicTint=[1,1,1],this.dynamicWidth=[1,1,1],this.axesBounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.surfaceProject=[!1,!1,!1],this.contourProject=[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],this.colorBounds=[!1,!1],this._field=[h(s.mallocFloat(1024),[0,0]),h(s.mallocFloat(1024),[0,0]),h(s.mallocFloat(1024),[0,0])],this.pickId=1,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.snapToData=!1,this.pixelRatio=1,this.opacity=1,this.lightPosition=[10,1e4,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.vertexColor=0,this.dirty=!0}var C=E.prototype;C.isTransparent=function(){return this.opacity<1},C.isOpaque=function(){if(this.opacity>=1)return!0;for(var t=0;t<3;++t)if(this._contourCounts[t].length>0||this._dynamicCounts[t]>0)return!0;return!1},C.pickSlots=1,C.setPickBase=function(t){this.pickId=t};var L=[0,0,0],P={showSurface:!1,showContour:!1,projections:[k.slice(),k.slice(),k.slice()],clipBounds:[[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]]]};function O(t,e){var r,n,i,a=e.axes&&e.axes.lastCubeProps.axis||L,o=e.showSurface,s=e.showContour;for(r=0;r<3;++r)for(o=o||e.surfaceProject[r],n=0;n<3;++n)s=s||e.contourProject[r][n];for(r=0;r<3;++r){var l=P.projections[r];for(n=0;n<16;++n)l[n]=0;for(n=0;n<4;++n)l[5*n]=1;l[5*r]=0,l[12+r]=e.axesBounds[+(a[r]>0)][r],p(l,t.model,l);var c=P.clipBounds[r];for(i=0;i<2;++i)for(n=0;n<3;++n)c[i][n]=t.clipBounds[i][n];c[0][r]=-1e8,c[1][r]=1e8}return P.showSurface=o,P.showContour=s,P}var z={model:k,view:k,projection:k,inverseModel:k.slice(),lowerBound:[0,0,0],upperBound:[0,0,0],colorMap:0,clipBounds:[[0,0,0],[0,0,0]],height:0,contourTint:0,contourColor:[0,0,0,1],permutation:[1,0,0,0,1,0,0,0,1],zOffset:-1e-4,objectOffset:[0,0,0],kambient:1,kdiffuse:1,kspecular:1,lightPosition:[1e3,1e3,1e3],eyePosition:[0,0,0],roughness:1,fresnel:1,opacity:1,vertexColor:0},I=k.slice(),D=[1,0,0,0,1,0,0,0,1];function R(t,e){t=t||{};var r=this.gl;r.disable(r.CULL_FACE),this._colorMap.bind(0);var n=z;n.model=t.model||k,n.view=t.view||k,n.projection=t.projection||k,n.lowerBound=[this.bounds[0][0],this.bounds[0][1],this.colorBounds[0]||this.bounds[0][2]],n.upperBound=[this.bounds[1][0],this.bounds[1][1],this.colorBounds[1]||this.bounds[1][2]],n.objectOffset=this.objectOffset,n.contourColor=this.contourColor[0],n.inverseModel=d(n.inverseModel,n.model);for(var i=0;i<2;++i)for(var a=n.clipBounds[i],o=0;o<3;++o)a[o]=Math.min(Math.max(this.clipBounds[i][o],-1e8),1e8);n.kambient=this.ambientLight,n.kdiffuse=this.diffuseLight,n.kspecular=this.specularLight,n.roughness=this.roughness,n.fresnel=this.fresnel,n.opacity=this.opacity,n.height=0,n.permutation=D,n.vertexColor=this.vertexColor;var s=I;for(p(s,n.view,n.model),p(s,n.projection,s),d(s,s),i=0;i<3;++i)n.eyePosition[i]=s[12+i]/s[15];var l=s[15];for(i=0;i<3;++i)l+=this.lightPosition[i]*s[4*i+3];for(i=0;i<3;++i){var c=s[12+i];for(o=0;o<3;++o)c+=s[4*o+i]*this.lightPosition[o];n.lightPosition[i]=c/l}var u=O(n,this);if(u.showSurface&&e===this.opacity<1){for(this._shader.bind(),this._shader.uniforms=n,this._vao.bind(),this.showSurface&&this._vertexCount&&this._vao.draw(r.TRIANGLES,this._vertexCount),i=0;i<3;++i)this.surfaceProject[i]&&this.vertexCount&&(this._shader.uniforms.model=u.projections[i],this._shader.uniforms.clipBounds=u.clipBounds[i],this._vao.draw(r.TRIANGLES,this._vertexCount));this._vao.unbind()}if(u.showContour&&!e){var h=this._contourShader;n.kambient=1,n.kdiffuse=0,n.kspecular=0,n.opacity=1,h.bind(),h.uniforms=n;var f=this._contourVAO;for(f.bind(),i=0;i<3;++i)for(h.uniforms.permutation=A[i],r.lineWidth(this.contourWidth[i]*this.pixelRatio),o=0;o<this.contourLevels[i].length;++o)o===this.highlightLevel[i]?(h.uniforms.contourColor=this.highlightColor[i],h.uniforms.contourTint=this.highlightTint[i]):0!==o&&o-1!==this.highlightLevel[i]||(h.uniforms.contourColor=this.contourColor[i],h.uniforms.contourTint=this.contourTint[i]),this._contourCounts[i][o]&&(h.uniforms.height=this.contourLevels[i][o],f.draw(r.LINES,this._contourCounts[i][o],this._contourOffsets[i][o]));for(i=0;i<3;++i)for(h.uniforms.model=u.projections[i],h.uniforms.clipBounds=u.clipBounds[i],o=0;o<3;++o)if(this.contourProject[i][o]){h.uniforms.permutation=A[o],r.lineWidth(this.contourWidth[o]*this.pixelRatio);for(var g=0;g<this.contourLevels[o].length;++g)g===this.highlightLevel[o]?(h.uniforms.contourColor=this.highlightColor[o],h.uniforms.contourTint=this.highlightTint[o]):0!==g&&g-1!==this.highlightLevel[o]||(h.uniforms.contourColor=this.contourColor[o],h.uniforms.contourTint=this.contourTint[o]),this._contourCounts[o][g]&&(h.uniforms.height=this.contourLevels[o][g],f.draw(r.LINES,this._contourCounts[o][g],this._contourOffsets[o][g]))}for(f.unbind(),(f=this._dynamicVAO).bind(),i=0;i<3;++i)if(0!==this._dynamicCounts[i])for(h.uniforms.model=n.model,h.uniforms.clipBounds=n.clipBounds,h.uniforms.permutation=A[i],r.lineWidth(this.dynamicWidth[i]*this.pixelRatio),h.uniforms.contourColor=this.dynamicColor[i],h.uniforms.contourTint=this.dynamicTint[i],h.uniforms.height=this.dynamicLevel[i],f.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]),o=0;o<3;++o)this.contourProject[o][i]&&(h.uniforms.model=u.projections[o],h.uniforms.clipBounds=u.clipBounds[o],f.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]));f.unbind()}}C.draw=function(t){return R.call(this,t,!1)},C.drawTransparent=function(t){return R.call(this,t,!0)};var F={model:k,view:k,projection:k,inverseModel:k,clipBounds:[[0,0,0],[0,0,0]],height:0,shape:[0,0],pickId:0,lowerBound:[0,0,0],upperBound:[0,0,0],zOffset:0,objectOffset:[0,0,0],permutation:[1,0,0,0,1,0,0,0,1],lightPosition:[0,0,0],eyePosition:[0,0,0]};function B(t,e){return Array.isArray(t)?[e(t[0]),e(t[1]),e(t[2])]:[e(t),e(t),e(t)]}function N(t){return Array.isArray(t)?3===t.length?[t[0],t[1],t[2],1]:[t[0],t[1],t[2],t[3]]:[0,0,0,1]}function j(t){if(Array.isArray(t)){if(Array.isArray(t))return[N(t[0]),N(t[1]),N(t[2])];var e=N(t);return[e.slice(),e.slice(),e.slice()]}}C.drawPick=function(t){t=t||{};var e=this.gl;e.disable(e.CULL_FACE);var r=F;r.model=t.model||k,r.view=t.view||k,r.projection=t.projection||k,r.shape=this._field[2].shape,r.pickId=this.pickId/255,r.lowerBound=this.bounds[0],r.upperBound=this.bounds[1],r.objectOffset=this.objectOffset,r.permutation=D;for(var n=0;n<2;++n)for(var i=r.clipBounds[n],a=0;a<3;++a)i[a]=Math.min(Math.max(this.clipBounds[n][a],-1e8),1e8);var o=O(r,this);if(o.showSurface){for(this._pickShader.bind(),this._pickShader.uniforms=r,this._vao.bind(),this._vao.draw(e.TRIANGLES,this._vertexCount),n=0;n<3;++n)this.surfaceProject[n]&&(this._pickShader.uniforms.model=o.projections[n],this._pickShader.uniforms.clipBounds=o.clipBounds[n],this._vao.draw(e.TRIANGLES,this._vertexCount));this._vao.unbind()}if(o.showContour){var s=this._contourPickShader;s.bind(),s.uniforms=r;var l=this._contourVAO;for(l.bind(),a=0;a<3;++a)for(e.lineWidth(this.contourWidth[a]*this.pixelRatio),s.uniforms.permutation=A[a],n=0;n<this.contourLevels[a].length;++n)this._contourCounts[a][n]&&(s.uniforms.height=this.contourLevels[a][n],l.draw(e.LINES,this._contourCounts[a][n],this._contourOffsets[a][n]));for(n=0;n<3;++n)for(s.uniforms.model=o.projections[n],s.uniforms.clipBounds=o.clipBounds[n],a=0;a<3;++a)if(this.contourProject[n][a]){s.uniforms.permutation=A[a],e.lineWidth(this.contourWidth[a]*this.pixelRatio);for(var c=0;c<this.contourLevels[a].length;++c)this._contourCounts[a][c]&&(s.uniforms.height=this.contourLevels[a][c],l.draw(e.LINES,this._contourCounts[a][c],this._contourOffsets[a][c]))}l.unbind()}},C.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=this._field[2].shape,r=this._pickResult,n=e[0]*(t.value[0]+(t.value[2]>>4)/16)/255,i=Math.floor(n),a=n-i,o=e[1]*(t.value[1]+(15&t.value[2])/16)/255,s=Math.floor(o),l=o-s;i+=1,s+=1;var c=r.position;c[0]=c[1]=c[2]=0;for(var u=0;u<2;++u)for(var h=u?a:1-a,f=0;f<2;++f)for(var p=i+u,d=s+f,v=h*(f?l:1-l),m=0;m<3;++m)c[m]+=this._field[m].get(p,d)*v;for(var y=this._pickResult.level,x=0;x<3;++x)if(y[x]=g.le(this.contourLevels[x],c[x]),y[x]<0)this.contourLevels[x].length>0&&(y[x]=0);else if(y[x]<this.contourLevels[x].length-1){var b=this.contourLevels[x][y[x]],_=this.contourLevels[x][y[x]+1];Math.abs(b-c[x])>Math.abs(_-c[x])&&(y[x]+=1)}for(r.index[0]=a<.5?i:i+1,r.index[1]=l<.5?s:s+1,r.uv[0]=n/e[0],r.uv[1]=o/e[1],m=0;m<3;++m)r.dataCoordinate[m]=this._field[m].get(r.index[0],r.index[1]);return r},C.padField=function(t,e){var r=e.shape.slice(),n=t.shape.slice();c.assign(t.lo(1,1).hi(r[0],r[1]),e),c.assign(t.lo(1).hi(r[0],1),e.hi(r[0],1)),c.assign(t.lo(1,n[1]-1).hi(r[0],1),e.lo(0,r[1]-1).hi(r[0],1)),c.assign(t.lo(0,1).hi(1,r[1]),e.hi(1)),c.assign(t.lo(n[0]-1,1).hi(1,r[1]),e.lo(r[0]-1)),t.set(0,0,e.get(0,0)),t.set(0,n[1]-1,e.get(0,r[1]-1)),t.set(n[0]-1,0,e.get(r[0]-1,0)),t.set(n[0]-1,n[1]-1,e.get(r[0]-1,r[1]-1))},C.update=function(t){t=t||{},this.objectOffset=t.objectOffset||this.objectOffset,this.dirty=!0,\"contourWidth\"in t&&(this.contourWidth=B(t.contourWidth,Number)),\"showContour\"in t&&(this.showContour=B(t.showContour,Boolean)),\"showSurface\"in t&&(this.showSurface=!!t.showSurface),\"contourTint\"in t&&(this.contourTint=B(t.contourTint,Boolean)),\"contourColor\"in t&&(this.contourColor=j(t.contourColor)),\"contourProject\"in t&&(this.contourProject=B(t.contourProject,function(t){return B(t,Boolean)})),\"surfaceProject\"in t&&(this.surfaceProject=t.surfaceProject),\"dynamicColor\"in t&&(this.dynamicColor=j(t.dynamicColor)),\"dynamicTint\"in t&&(this.dynamicTint=B(t.dynamicTint,Number)),\"dynamicWidth\"in t&&(this.dynamicWidth=B(t.dynamicWidth,Number)),\"opacity\"in t&&(this.opacity=t.opacity),\"colorBounds\"in t&&(this.colorBounds=t.colorBounds),\"vertexColor\"in t&&(this.vertexColor=t.vertexColor?1:0);var e=t.field||t.coords&&t.coords[2]||null,r=!1;if(e||(e=this._field[2].shape[0]||this._field[2].shape[2]?this._field[2].lo(1,1).hi(this._field[2].shape[0]-2,this._field[2].shape[1]-2):this._field[2].hi(0,0)),\"field\"in t||\"coords\"in t){var i=(e.shape[0]+2)*(e.shape[1]+2);i>this._field[2].data.length&&(s.freeFloat(this._field[2].data),this._field[2].data=s.mallocFloat(n.nextPow2(i))),this._field[2]=h(this._field[2].data,[e.shape[0]+2,e.shape[1]+2]),this.padField(this._field[2],e),this.shape=e.shape.slice();for(var a=this.shape,o=0;o<2;++o)this._field[2].size>this._field[o].data.length&&(s.freeFloat(this._field[o].data),this._field[o].data=s.mallocFloat(this._field[2].size)),this._field[o]=h(this._field[o].data,[a[0]+2,a[1]+2]);if(t.coords){var p=t.coords;if(!Array.isArray(p)||3!==p.length)throw new Error(\"gl-surface: invalid coordinates for x/y\");for(o=0;o<2;++o){var d=p[o];for(b=0;b<2;++b)if(d.shape[b]!==a[b])throw new Error(\"gl-surface: coords have incorrect shape\");this.padField(this._field[o],d)}}else if(t.ticks){var g=t.ticks;if(!Array.isArray(g)||2!==g.length)throw new Error(\"gl-surface: invalid ticks\");for(o=0;o<2;++o){var m=g[o];if((Array.isArray(m)||m.length)&&(m=h(m)),m.shape[0]!==a[o])throw new Error(\"gl-surface: invalid tick length\");var y=h(m.data,a);y.stride[o]=m.stride[0],y.stride[1^o]=0,this.padField(this._field[o],y)}}else{for(o=0;o<2;++o){var x=[0,0];x[o]=1,this._field[o]=h(this._field[o].data,[a[0]+2,a[1]+2],x,0)}this._field[0].set(0,0,0);for(var b=0;b<a[0];++b)this._field[0].set(b+1,0,b);for(this._field[0].set(a[0]+1,0,a[0]-1),this._field[1].set(0,0,0),b=0;b<a[1];++b)this._field[1].set(0,b+1,b);this._field[1].set(0,a[1]+1,a[1]-1)}var _=this._field,w=h(s.mallocFloat(3*_[2].size*2),[3,a[0]+2,a[1]+2,2]);for(o=0;o<3;++o)v(w.pick(o),_[o],\"mirror\");var k=h(s.mallocFloat(3*_[2].size),[a[0]+2,a[1]+2,3]);for(o=0;o<a[0]+2;++o)for(b=0;b<a[1]+2;++b){var A=w.get(0,o,b,0),M=w.get(0,o,b,1),E=w.get(1,o,b,0),C=w.get(1,o,b,1),L=w.get(2,o,b,0),P=w.get(2,o,b,1),O=E*P-C*L,z=L*M-P*A,I=A*C-M*E,D=Math.sqrt(O*O+z*z+I*I);D<1e-8?(D=Math.max(Math.abs(O),Math.abs(z),Math.abs(I)))<1e-8?(I=1,z=O=0,D=1):D=1/D:D=1/Math.sqrt(D),k.set(o,b,0,O*D),k.set(o,b,1,z*D),k.set(o,b,2,I*D)}s.free(w.data);var R=[1/0,1/0,1/0],F=[-1/0,-1/0,-1/0],N=1/0,U=-1/0,V=(a[0]-1)*(a[1]-1)*6,q=s.mallocFloat(n.nextPow2(10*V)),H=0,G=0;for(o=0;o<a[0]-1;++o)t:for(b=0;b<a[1]-1;++b){for(var Y=0;Y<2;++Y)for(var W=0;W<2;++W)for(var X=0;X<3;++X){var Z=this._field[X].get(1+o+Y,1+b+W);if(isNaN(Z)||!isFinite(Z))continue t}for(X=0;X<6;++X){var J=o+T[X][0],K=b+T[X][1],$=this._field[0].get(J+1,K+1),Q=this._field[1].get(J+1,K+1);Z=this._field[2].get(J+1,K+1),O=k.get(J+1,K+1,0),z=k.get(J+1,K+1,1),I=k.get(J+1,K+1,2),t.intensity&&(tt=t.intensity.get(J,K));var tt=t.intensity?t.intensity.get(J,K):Z+this.objectOffset[2];q[H++]=J,q[H++]=K,q[H++]=$,q[H++]=Q,q[H++]=Z,q[H++]=0,q[H++]=tt,q[H++]=O,q[H++]=z,q[H++]=I,R[0]=Math.min(R[0],$+this.objectOffset[0]),R[1]=Math.min(R[1],Q+this.objectOffset[1]),R[2]=Math.min(R[2],Z+this.objectOffset[2]),N=Math.min(N,tt),F[0]=Math.max(F[0],$+this.objectOffset[0]),F[1]=Math.max(F[1],Q+this.objectOffset[1]),F[2]=Math.max(F[2],Z+this.objectOffset[2]),U=Math.max(U,tt),G+=1}}for(t.intensityBounds&&(N=+t.intensityBounds[0],U=+t.intensityBounds[1]),o=6;o<H;o+=10)q[o]=(q[o]-N)/(U-N);this._vertexCount=G,this._coordinateBuffer.update(q.subarray(0,H)),s.freeFloat(q),s.free(k.data),this.bounds=[R,F],this.intensity=t.intensity||this._field[2],this.intensityBounds[0]===N&&this.intensityBounds[1]===U||(r=!0),this.intensityBounds=[N,U]}if(\"levels\"in t){var et=t.levels;for(et=Array.isArray(et[0])?et.slice():[[],[],et],o=0;o<3;++o)et[o]=et[o].slice(),et[o].sort(function(t,e){return t-e});for(o=0;o<3;++o)for(b=0;b<et[o].length;++b)et[o][b]-=this.objectOffset[o];t:for(o=0;o<3;++o){if(et[o].length!==this.contourLevels[o].length){r=!0;break}for(b=0;b<et[o].length;++b)if(et[o][b]!==this.contourLevels[o][b]){r=!0;break t}}this.contourLevels=et}if(r){_=this._field,a=this.shape;for(var rt=[],nt=0;nt<3;++nt){var it=this.contourLevels[nt],at=[],ot=[],st=[0,0,0];for(o=0;o<it.length;++o){var lt=f(this._field[nt],it[o]);at.push(rt.length/5|0),G=0;t:for(b=0;b<lt.cells.length;++b){var ct=lt.cells[b];for(X=0;X<2;++X){var ut=lt.positions[ct[X]],ht=ut[0],ft=0|Math.floor(ht),pt=ht-ft,dt=ut[1],gt=0|Math.floor(dt),vt=dt-gt,mt=!1;e:for(var yt=0;yt<3;++yt){st[yt]=0;var xt=(nt+yt+1)%3;for(Y=0;Y<2;++Y){var bt=Y?pt:1-pt;for(J=0|Math.min(Math.max(ft+Y,0),a[0]),W=0;W<2;++W){var _t=W?vt:1-vt;if(K=0|Math.min(Math.max(gt+W,0),a[1]),Z=yt<2?this._field[xt].get(J,K):(this.intensity.get(J,K)-this.intensityBounds[0])/(this.intensityBounds[1]-this.intensityBounds[0]),!isFinite(Z)||isNaN(Z)){mt=!0;break e}var wt=bt*_t;st[yt]+=wt*Z}}}if(mt){if(X>0){for(var kt=0;kt<5;++kt)rt.pop();G-=1}continue t}rt.push(st[0],st[1],ut[0],ut[1],st[2]),G+=1}}ot.push(G)}this._contourOffsets[nt]=at,this._contourCounts[nt]=ot}var Tt=s.mallocFloat(rt.length);for(o=0;o<rt.length;++o)Tt[o]=rt[o];this._contourBuffer.update(Tt),s.freeFloat(Tt)}t.colormap&&this._colorMap.setPixels(function(t){var e=u([l({colormap:t,nshades:S,format:\"rgba\"}).map(function(t){return[t[0],t[1],t[2],255*t[3]]})]);return c.divseq(e,255),e}(t.colormap))},C.dispose=function(){this._shader.dispose(),this._vao.dispose(),this._coordinateBuffer.dispose(),this._colorMap.dispose(),this._contourBuffer.dispose(),this._contourVAO.dispose(),this._contourShader.dispose(),this._contourPickShader.dispose(),this._dynamicBuffer.dispose(),this._dynamicVAO.dispose();for(var t=0;t<3;++t)s.freeFloat(this._field[t].data)},C.highlight=function(t){var e,r;if(!t)return this._dynamicCounts=[0,0,0],this.dyanamicLevel=[NaN,NaN,NaN],void(this.highlightLevel=[-1,-1,-1]);for(e=0;e<3;++e)this.enableHighlight[e]?this.highlightLevel[e]=t.level[e]:this.highlightLevel[e]=-1;for(r=this.snapToData?t.dataCoordinate:t.position,e=0;e<3;++e)r[e]-=this.objectOffset[e];if(this.enableDynamic[0]&&r[0]!==this.dynamicLevel[0]||this.enableDynamic[1]&&r[1]!==this.dynamicLevel[1]||this.enableDynamic[2]&&r[2]!==this.dynamicLevel[2]){for(var n=0,i=this.shape,a=s.mallocFloat(12*i[0]*i[1]),o=0;o<3;++o)if(this.enableDynamic[o]){this.dynamicLevel[o]=r[o];var l=(o+1)%3,c=(o+2)%3,u=this._field[o],h=this._field[l],p=this._field[c],d=f(u,r[o]),g=d.cells,v=d.positions;for(this._dynamicOffsets[o]=n,e=0;e<g.length;++e)for(var m=g[e],y=0;y<2;++y){var x=v[m[y]],b=+x[0],_=0|b,w=0|Math.min(_+1,i[0]),k=b-_,T=1-k,A=+x[1],M=0|A,S=0|Math.min(M+1,i[1]),E=A-M,C=1-E,L=T*C,P=T*E,O=k*C,z=k*E,I=L*h.get(_,M)+P*h.get(_,S)+O*h.get(w,M)+z*h.get(w,S),D=L*p.get(_,M)+P*p.get(_,S)+O*p.get(w,M)+z*p.get(w,S);if(isNaN(I)||isNaN(D)){y&&(n-=1);break}a[2*n+0]=I,a[2*n+1]=D,n+=1}this._dynamicCounts[o]=n-this._dynamicOffsets[o]}else this.dynamicLevel[o]=NaN,this._dynamicCounts[o]=0;this._dynamicBuffer.update(a.subarray(0,2*n)),s.freeFloat(a)}}},{\"./lib/shaders\":314,\"binary-search-bounds\":315,\"bit-twiddle\":92,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,\"ndarray-gradient\":441,\"ndarray-ops\":444,\"ndarray-pack\":445,\"surface-nets\":531,\"typedarray-pool\":545}],317:[function(t,e,r){\"use strict\";var n=t(\"css-font\"),i=t(\"pick-by-alias\"),a=t(\"regl\"),o=t(\"gl-util/context\"),s=t(\"es6-weak-map\"),l=t(\"color-normalize\"),c=t(\"font-atlas\"),u=t(\"typedarray-pool\"),h=t(\"parse-rect\"),f=t(\"is-plain-obj\"),p=t(\"parse-unit\"),d=t(\"to-px\"),g=t(\"detect-kerning\"),v=t(\"object-assign\"),m=t(\"font-measure\"),y=t(\"flatten-vertex-data\"),x=t(\"bit-twiddle\").nextPow2,b=new s,_=!1;if(document.body){var w=document.body.appendChild(document.createElement(\"div\"));w.style.font=\"italic small-caps bold condensed 16px/2 cursive\",getComputedStyle(w).fontStretch&&(_=!0),document.body.removeChild(w)}var k=function(t){!function(t){return\"function\"==typeof t&&t._gl&&t.prop&&t.texture&&t.buffer}(t)?this.gl=o(t):(t={regl:t},this.gl=t.regl._gl),this.shader=b.get(this.gl),this.shader?this.regl=this.shader.regl:this.regl=t.regl||a({gl:this.gl}),this.charBuffer=this.regl.buffer({type:\"uint8\",usage:\"stream\"}),this.sizeBuffer=this.regl.buffer({type:\"float\",usage:\"stream\"}),this.shader||(this.shader=this.createShader(),b.set(this.gl,this.shader)),this.batch=[],this.fontSize=[],this.font=[],this.fontAtlas=[],this.draw=this.shader.draw.bind(this),this.render=function(){this.regl._refresh(),this.draw(this.batch)},this.canvas=this.gl.canvas,this.update(f(t)?t:{})};k.prototype.createShader=function(){var t=this.regl,e=t({blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},stencil:{enable:!1},depth:{enable:!1},count:t.prop(\"count\"),offset:t.prop(\"offset\"),attributes:{charOffset:{offset:4,stride:8,buffer:t.this(\"sizeBuffer\")},width:{offset:0,stride:8,buffer:t.this(\"sizeBuffer\")},char:t.this(\"charBuffer\"),position:t.this(\"position\")},uniforms:{atlasSize:function(t,e){return[e.atlas.width,e.atlas.height]},atlasDim:function(t,e){return[e.atlas.cols,e.atlas.rows]},atlas:function(t,e){return e.atlas.texture},charStep:function(t,e){return e.atlas.step},em:function(t,e){return e.atlas.em},color:t.prop(\"color\"),opacity:t.prop(\"opacity\"),viewport:t.this(\"viewportArray\"),scale:t.this(\"scale\"),align:t.prop(\"align\"),baseline:t.prop(\"baseline\"),translate:t.this(\"translate\"),positionOffset:t.prop(\"positionOffset\")},primitive:\"points\",viewport:t.this(\"viewport\"),vert:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tattribute float width, charOffset, char;\\n\\t\\t\\tattribute vec2 position;\\n\\t\\t\\tuniform float fontSize, charStep, em, align, baseline;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tuniform vec4 color;\\n\\t\\t\\tuniform vec2 atlasSize, atlasDim, scale, translate, positionOffset;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\t\"+(k.normalViewport?\"\":\"vec2 positionOffset = vec2(positionOffset.x,- positionOffset.y);\")+\"\\n\\n\\t\\t\\t\\tvec2 offset = floor(em * (vec2(align + charOffset, baseline)\\n\\t\\t\\t\\t\\t+ positionOffset))\\n\\t\\t\\t\\t\\t/ (viewport.zw * scale.xy);\\n\\n\\t\\t\\t\\tvec2 position = (position + translate) * scale;\\n\\t\\t\\t\\tposition += offset * scale;\\n\\n\\t\\t\\t\\t\"+(k.normalViewport?\"position.y = 1. - position.y;\":\"\")+\"\\n\\n\\t\\t\\t\\tcharCoord = position * viewport.zw + viewport.xy;\\n\\n\\t\\t\\t\\tgl_Position = vec4(position * 2. - 1., 0, 1);\\n\\n\\t\\t\\t\\tgl_PointSize = charStep;\\n\\n\\t\\t\\t\\tcharId.x = mod(char, atlasDim.x);\\n\\t\\t\\t\\tcharId.y = floor(char / atlasDim.x);\\n\\n\\t\\t\\t\\tcharWidth = width * em;\\n\\n\\t\\t\\t\\tfontColor = color / 255.;\\n\\t\\t\\t}\",frag:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tuniform sampler2D atlas;\\n\\t\\t\\tuniform float fontSize, charStep, opacity;\\n\\t\\t\\tuniform vec2 atlasSize;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\n\\t\\t\\tfloat lightness(vec4 color) {\\n\\t\\t\\t\\treturn color.r * 0.299 + color.g * 0.587 + color.b * 0.114;\\n\\t\\t\\t}\\n\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\tvec2 uv = gl_FragCoord.xy - charCoord + charStep * .5;\\n\\t\\t\\t\\tfloat halfCharStep = floor(charStep * .5 + .5);\\n\\n\\t\\t\\t\\t// invert y and shift by 1px (FF expecially needs that)\\n\\t\\t\\t\\tuv.y = charStep - uv.y;\\n\\n\\t\\t\\t\\t// ignore points outside of character bounding box\\n\\t\\t\\t\\tfloat halfCharWidth = ceil(charWidth * .5);\\n\\t\\t\\t\\tif (floor(uv.x) > halfCharStep + halfCharWidth ||\\n\\t\\t\\t\\t\\tfloor(uv.x) < halfCharStep - halfCharWidth) return;\\n\\n\\t\\t\\t\\tuv += charId * charStep;\\n\\t\\t\\t\\tuv = uv / atlasSize;\\n\\n\\t\\t\\t\\tvec4 color = fontColor;\\n\\t\\t\\t\\tvec4 mask = texture2D(atlas, uv);\\n\\n\\t\\t\\t\\tfloat maskY = lightness(mask);\\n\\t\\t\\t\\t// float colorY = lightness(color);\\n\\t\\t\\t\\tcolor.a *= maskY;\\n\\t\\t\\t\\tcolor.a *= opacity;\\n\\n\\t\\t\\t\\t// color.a += .1;\\n\\n\\t\\t\\t\\t// antialiasing, see yiq color space y-channel formula\\n\\t\\t\\t\\t// color.rgb += (1. - color.rgb) * (1. - mask.rgb);\\n\\n\\t\\t\\t\\tgl_FragColor = color;\\n\\t\\t\\t}\"});return{regl:t,draw:e,atlas:{}}},k.prototype.update=function(t){var e=this;if(\"string\"==typeof t)t={text:t};else if(!t)return;null!=(t=i(t,{position:\"position positions coord coords coordinates\",font:\"font fontFace fontface typeface cssFont css-font family fontFamily\",fontSize:\"fontSize fontsize size font-size\",text:\"text texts chars characters value values symbols\",align:\"align alignment textAlign textbaseline\",baseline:\"baseline textBaseline textbaseline\",direction:\"dir direction textDirection\",color:\"color colour fill fill-color fillColor textColor textcolor\",kerning:\"kerning kern\",range:\"range dataBox\",viewport:\"vp viewport viewBox viewbox viewPort\",opacity:\"opacity alpha transparency visible visibility opaque\",offset:\"offset positionOffset padding shift indent indentation\"},!0)).opacity&&(Array.isArray(t.opacity)?this.opacity=t.opacity.map(function(t){return parseFloat(t)}):this.opacity=parseFloat(t.opacity)),null!=t.viewport&&(this.viewport=h(t.viewport),k.normalViewport&&(this.viewport.y=this.canvas.height-this.viewport.y-this.viewport.height),this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null==this.viewport&&(this.viewport={x:0,y:0,width:this.gl.drawingBufferWidth,height:this.gl.drawingBufferHeight},this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null!=t.kerning&&(this.kerning=t.kerning),null!=t.offset&&(\"number\"==typeof t.offset&&(t.offset=[t.offset,0]),this.positionOffset=y(t.offset)),t.direction&&(this.direction=t.direction),t.range&&(this.range=t.range,this.scale=[1/(t.range[2]-t.range[0]),1/(t.range[3]-t.range[1])],this.translate=[-t.range[0],-t.range[1]]),t.scale&&(this.scale=t.scale),t.translate&&(this.translate=t.translate),this.scale||(this.scale=[1/this.viewport.width,1/this.viewport.height]),this.translate||(this.translate=[0,0]),this.font.length||t.font||(t.font=k.baseFontSize+\"px sans-serif\");var r,a=!1,o=!1;if(t.font&&(Array.isArray(t.font)?t.font:[t.font]).forEach(function(t,r){if(\"string\"==typeof t)try{t=n.parse(t)}catch(e){t=n.parse(k.baseFontSize+\"px \"+t)}else t=n.parse(n.stringify(t));var i=n.stringify({size:k.baseFontSize,family:t.family,stretch:_?t.stretch:void 0,variant:t.variant,weight:t.weight,style:t.style}),s=p(t.size),l=Math.round(s[0]*d(s[1]));if(l!==e.fontSize[r]&&(o=!0,e.fontSize[r]=l),!(e.font[r]&&i==e.font[r].baseString||(a=!0,e.font[r]=k.fonts[i],e.font[r]))){var c=t.family.join(\", \"),u=[t.style];t.style!=t.variant&&u.push(t.variant),t.variant!=t.weight&&u.push(t.weight),_&&t.weight!=t.stretch&&u.push(t.stretch),e.font[r]={baseString:i,family:c,weight:t.weight,stretch:t.stretch,style:t.style,variant:t.variant,width:{},kerning:{},metrics:m(c,{origin:\"top\",fontSize:k.baseFontSize,fontStyle:u.join(\" \")})},k.fonts[i]=e.font[r]}}),(a||o)&&this.font.forEach(function(r,i){var a=n.stringify({size:e.fontSize[i],family:r.family,stretch:_?r.stretch:void 0,variant:r.variant,weight:r.weight,style:r.style});if(e.fontAtlas[i]=e.shader.atlas[a],!e.fontAtlas[i]){var o=r.metrics;e.shader.atlas[a]=e.fontAtlas[i]={fontString:a,step:2*Math.ceil(e.fontSize[i]*o.bottom*.5),em:e.fontSize[i],cols:0,rows:0,height:0,width:0,chars:[],ids:{},texture:e.regl.texture()}}null==t.text&&(t.text=e.text)}),\"string\"==typeof t.text&&t.position&&t.position.length>2){for(var s=Array(.5*t.position.length),f=0;f<s.length;f++)s[f]=t.text;t.text=s}if(null!=t.text||a){if(this.textOffsets=[0],Array.isArray(t.text)){this.count=t.text[0].length,this.counts=[this.count];for(var b=1;b<t.text.length;b++)this.textOffsets[b]=this.textOffsets[b-1]+t.text[b-1].length,this.count+=t.text[b].length,this.counts.push(t.text[b].length);this.text=t.text.join(\"\")}else this.text=t.text,this.count=this.text.length,this.counts=[this.count];r=[],this.font.forEach(function(t,n){k.atlasContext.font=t.baseString;for(var i=e.fontAtlas[n],a=0;a<e.text.length;a++){var o=e.text.charAt(a);if(null==i.ids[o]&&(i.ids[o]=i.chars.length,i.chars.push(o),r.push(o)),null==t.width[o]&&(t.width[o]=k.atlasContext.measureText(o).width/k.baseFontSize,e.kerning)){var s=[];for(var l in t.width)s.push(l+o,o+l);v(t.kerning,g(t.family,{pairs:s}))}}})}if(t.position)if(t.position.length>2){for(var w=!t.position[0].length,T=u.mallocFloat(2*this.count),A=0,M=0;A<this.counts.length;A++){var S=this.counts[A];if(w)for(var E=0;E<S;E++)T[M++]=t.position[2*A],T[M++]=t.position[2*A+1];else for(var C=0;C<S;C++)T[M++]=t.position[A][0],T[M++]=t.position[A][1]}this.position.call?this.position({type:\"float\",data:T}):this.position=this.regl.buffer({type:\"float\",data:T}),u.freeFloat(T)}else this.position.destroy&&this.position.destroy(),this.position={constant:t.position};if(t.text||a){var L=u.mallocUint8(this.count),P=u.mallocFloat(2*this.count);this.textWidth=[];for(var O=0,z=0;O<this.counts.length;O++){for(var I=this.counts[O],D=this.font[O]||this.font[0],R=this.fontAtlas[O]||this.fontAtlas[0],F=0;F<I;F++){var B=this.text.charAt(z),N=this.text.charAt(z-1);if(L[z]=R.ids[B],P[2*z]=D.width[B],F){var j=P[2*z-2],U=P[2*z],V=P[2*z-1]+.5*j+.5*U;if(this.kerning){var q=D.kerning[N+B];q&&(V+=.001*q)}P[2*z+1]=V}else P[2*z+1]=.5*P[2*z];z++}this.textWidth.push(P.length?.5*P[2*z-2]+P[2*z-1]:0)}t.align||(t.align=this.align),this.charBuffer({data:L,type:\"uint8\",usage:\"stream\"}),this.sizeBuffer({data:P,type:\"float\",usage:\"stream\"}),u.freeUint8(L),u.freeFloat(P),r.length&&this.font.forEach(function(t,r){var n=e.fontAtlas[r],i=n.step,a=Math.floor(k.maxAtlasSize/i),o=Math.min(a,n.chars.length),s=Math.ceil(n.chars.length/o),l=x(o*i),u=x(s*i);n.width=l,n.height=u,n.rows=s,n.cols=o,n.em&&n.texture({data:c({canvas:k.atlasCanvas,font:n.fontString,chars:n.chars,shape:[l,u],step:[i,i]})})})}if(t.align&&(this.align=t.align,this.alignOffset=this.textWidth.map(function(t,r){var n=Array.isArray(e.align)?e.align.length>1?e.align[r]:e.align[0]:e.align;if(\"number\"==typeof n)return n;switch(n){case\"right\":case\"end\":return-t;case\"center\":case\"centre\":case\"middle\":return.5*-t}return 0})),null==this.baseline&&null==t.baseline&&(t.baseline=0),null!=t.baseline&&(this.baseline=t.baseline,Array.isArray(this.baseline)||(this.baseline=[this.baseline]),this.baselineOffset=this.baseline.map(function(t,r){var n=(e.font[r]||e.font[0]).metrics,i=0;return i+=.5*n.bottom,i+=\"number\"==typeof t?t-n.baseline:-n[t],k.normalViewport||(i*=-1),i})),null!=t.color)if(t.color||(t.color=\"transparent\"),\"string\"!=typeof t.color&&isNaN(t.color)){var H;if(\"number\"==typeof t.color[0]&&t.color.length>this.counts.length){var G=t.color.length;H=u.mallocUint8(G);for(var Y=(t.color.subarray||t.color.slice).bind(t.color),W=0;W<G;W+=4)H.set(l(Y(W,W+4),\"uint8\"),W)}else{var X=t.color.length;H=u.mallocUint8(4*X);for(var Z=0;Z<X;Z++)H.set(l(t.color[Z]||0,\"uint8\"),4*Z)}this.color=H}else this.color=l(t.color,\"uint8\");if(t.position||t.text||t.color||t.baseline||t.align||t.font||t.offset||t.opacity)if(this.color.length>4||this.baselineOffset.length>1||this.align&&this.align.length>1||this.fontAtlas.length>1||this.positionOffset.length>2){var J=Math.max(.5*this.position.length||0,.25*this.color.length||0,this.baselineOffset.length||0,this.alignOffset.length||0,this.font.length||0,this.opacity.length||0,.5*this.positionOffset.length||0);this.batch=Array(J);for(var K=0;K<this.batch.length;K++)this.batch[K]={count:this.counts.length>1?this.counts[K]:this.counts[0],offset:this.textOffsets.length>1?this.textOffsets[K]:this.textOffsets[0],color:this.color?this.color.length<=4?this.color:this.color.subarray(4*K,4*K+4):[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[K]:this.opacity,baseline:null!=this.baselineOffset[K]?this.baselineOffset[K]:this.baselineOffset[0],align:this.align?null!=this.alignOffset[K]?this.alignOffset[K]:this.alignOffset[0]:0,atlas:this.fontAtlas[K]||this.fontAtlas[0],positionOffset:this.positionOffset.length>2?this.positionOffset.subarray(2*K,2*K+2):this.positionOffset}}else this.count?this.batch=[{count:this.count,offset:0,color:this.color||[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[0]:this.opacity,baseline:this.baselineOffset[0],align:this.alignOffset?this.alignOffset[0]:0,atlas:this.fontAtlas[0],positionOffset:this.positionOffset}]:this.batch=[]},k.prototype.destroy=function(){},k.prototype.kerning=!0,k.prototype.position={constant:new Float32Array(2)},k.prototype.translate=null,k.prototype.scale=null,k.prototype.font=null,k.prototype.text=\"\",k.prototype.positionOffset=[0,0],k.prototype.opacity=1,k.prototype.color=new Uint8Array([0,0,0,255]),k.prototype.alignOffset=[0,0],k.normalViewport=!1,k.maxAtlasSize=1024,k.atlasCanvas=document.createElement(\"canvas\"),k.atlasContext=k.atlasCanvas.getContext(\"2d\",{alpha:!1}),k.baseFontSize=64,k.fonts={},e.exports=k},{\"bit-twiddle\":92,\"color-normalize\":120,\"css-font\":139,\"detect-kerning\":166,\"es6-weak-map\":318,\"flatten-vertex-data\":227,\"font-atlas\":228,\"font-measure\":229,\"gl-util/context\":323,\"is-plain-obj\":422,\"object-assign\":454,\"parse-rect\":459,\"parse-unit\":461,\"pick-by-alias\":465,regl:502,\"to-px\":539,\"typedarray-pool\":545}],318:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?WeakMap:t(\"./polyfill\")},{\"./is-implemented\":319,\"./polyfill\":321}],319:[function(t,e,r){\"use strict\";e.exports=function(){var t,e;if(\"function\"!=typeof WeakMap)return!1;try{t=new WeakMap([[e={},\"one\"],[{},\"two\"],[{},\"three\"]])}catch(t){return!1}return\"[object WeakMap]\"===String(t)&&(\"function\"==typeof t.set&&(t.set({},1)===t&&(\"function\"==typeof t.delete&&(\"function\"==typeof t.has&&\"one\"===t.get(e)))))}},{}],320:[function(t,e,r){\"use strict\";e.exports=\"function\"==typeof WeakMap&&\"[object WeakMap]\"===Object.prototype.toString.call(new WeakMap)},{}],321:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/object/set-prototype-of\"),o=t(\"es5-ext/object/valid-object\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"es5-ext/string/random-uniq\"),c=t(\"d\"),u=t(\"es6-iterator/get\"),h=t(\"es6-iterator/for-of\"),f=t(\"es6-symbol\").toStringTag,p=t(\"./is-native-implemented\"),d=Array.isArray,g=Object.defineProperty,v=Object.prototype.hasOwnProperty,m=Object.getPrototypeOf;e.exports=n=function(){var t,e=arguments[0];if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");return t=p&&a&&WeakMap!==n?a(new WeakMap,m(this)):this,i(e)&&(d(e)||(e=u(e))),g(t,\"__weakMapData__\",c(\"c\",\"$weakMap$\"+l())),e?(h(e,function(e){s(e),t.set(e[0],e[1])}),t):t},p&&(a&&a(n,WeakMap),n.prototype=Object.create(WeakMap.prototype,{constructor:c(n)})),Object.defineProperties(n.prototype,{delete:c(function(t){return!!v.call(o(t),this.__weakMapData__)&&(delete t[this.__weakMapData__],!0)}),get:c(function(t){if(v.call(o(t),this.__weakMapData__))return t[this.__weakMapData__]}),has:c(function(t){return v.call(o(t),this.__weakMapData__)}),set:c(function(t,e){return g(o(t),this.__weakMapData__,c(\"c\",e)),this}),toString:c(function(){return\"[object WeakMap]\"})}),g(n.prototype,f,c(\"c\",\"WeakMap\"))},{\"./is-native-implemented\":320,d:151,\"es5-ext/object/is-value\":194,\"es5-ext/object/set-prototype-of\":200,\"es5-ext/object/valid-object\":204,\"es5-ext/object/valid-value\":205,\"es5-ext/string/random-uniq\":210,\"es6-iterator/for-of\":212,\"es6-iterator/get\":213,\"es6-symbol\":219}],322:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"ndarray-ops\"),a=t(\"typedarray-pool\");e.exports=function(t){if(arguments.length<=1)throw new Error(\"gl-texture2d: Missing arguments for texture2d constructor\");o||function(t){o=[t.LINEAR,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_NEAREST],s=[t.NEAREST,t.LINEAR,t.NEAREST_MIPMAP_NEAREST,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_LINEAR],l=[t.REPEAT,t.CLAMP_TO_EDGE,t.MIRRORED_REPEAT]}(t);if(\"number\"==typeof arguments[1])return v(t,arguments[1],arguments[2],arguments[3]||t.RGBA,arguments[4]||t.UNSIGNED_BYTE);if(Array.isArray(arguments[1]))return v(t,0|arguments[1][0],0|arguments[1][1],arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(\"object\"==typeof arguments[1]){var e=arguments[1],r=c(e)?e:e.raw;if(r)return function(t,e,r,n,i,a){var o=g(t);return t.texImage2D(t.TEXTURE_2D,0,i,i,a,e),new f(t,o,r,n,i,a)}(t,r,0|e.width,0|e.height,arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(e.shape&&e.data&&e.stride)return function(t,e){var r=e.dtype,o=e.shape.slice(),s=t.getParameter(t.MAX_TEXTURE_SIZE);if(o[0]<0||o[0]>s||o[1]<0||o[1]>s)throw new Error(\"gl-texture2d: Invalid texture size\");var l=d(o,e.stride.slice()),c=0;\"float32\"===r?c=t.FLOAT:\"float64\"===r?(c=t.FLOAT,l=!1,r=\"float32\"):\"uint8\"===r?c=t.UNSIGNED_BYTE:(c=t.UNSIGNED_BYTE,l=!1,r=\"uint8\");var h,p,v=0;if(2===o.length)v=t.LUMINANCE,o=[o[0],o[1],1],e=n(e.data,o,[e.stride[0],e.stride[1],1],e.offset);else{if(3!==o.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===o[2])v=t.ALPHA;else if(2===o[2])v=t.LUMINANCE_ALPHA;else if(3===o[2])v=t.RGB;else{if(4!==o[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");v=t.RGBA}}c!==t.FLOAT||t.getExtension(\"OES_texture_float\")||(c=t.UNSIGNED_BYTE,l=!1);var m=e.size;if(l)h=0===e.offset&&e.data.length===m?e.data:e.data.subarray(e.offset,e.offset+m);else{var y=[o[2],o[2]*o[0],1];p=a.malloc(m,r);var x=n(p,o,y,0);\"float32\"!==r&&\"float64\"!==r||c!==t.UNSIGNED_BYTE?i.assign(x,e):u(x,e),h=p.subarray(0,m)}var b=g(t);t.texImage2D(t.TEXTURE_2D,0,v,o[0],o[1],0,v,c,h),l||a.free(p);return new f(t,b,o[0],o[1],v,c)}(t,e)}throw new Error(\"gl-texture2d: Invalid arguments for texture2d constructor\")};var o=null,s=null,l=null;function c(t){return\"undefined\"!=typeof HTMLCanvasElement&&t instanceof HTMLCanvasElement||\"undefined\"!=typeof HTMLImageElement&&t instanceof HTMLImageElement||\"undefined\"!=typeof HTMLVideoElement&&t instanceof HTMLVideoElement||\"undefined\"!=typeof ImageData&&t instanceof ImageData}var u=function(t,e){i.muls(t,e,255)};function h(t,e,r){var n=t.gl,i=n.getParameter(n.MAX_TEXTURE_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-texture2d: Invalid texture size\");return t._shape=[e,r],t.bind(),n.texImage2D(n.TEXTURE_2D,0,t.format,e,r,0,t.format,t.type,null),t._mipLevels=[0],t}function f(t,e,r,n,i,a){this.gl=t,this.handle=e,this.format=i,this.type=a,this._shape=[r,n],this._mipLevels=[0],this._magFilter=t.NEAREST,this._minFilter=t.NEAREST,this._wrapS=t.CLAMP_TO_EDGE,this._wrapT=t.CLAMP_TO_EDGE,this._anisoSamples=1;var o=this,s=[this._wrapS,this._wrapT];Object.defineProperties(s,[{get:function(){return o._wrapS},set:function(t){return o.wrapS=t}},{get:function(){return o._wrapT},set:function(t){return o.wrapT=t}}]),this._wrapVector=s;var l=[this._shape[0],this._shape[1]];Object.defineProperties(l,[{get:function(){return o._shape[0]},set:function(t){return o.width=t}},{get:function(){return o._shape[1]},set:function(t){return o.height=t}}]),this._shapeVector=l}var p=f.prototype;function d(t,e){return 3===t.length?1===e[2]&&e[1]===t[0]*t[2]&&e[0]===t[2]:1===e[0]&&e[1]===t[0]}function g(t){var e=t.createTexture();return t.bindTexture(t.TEXTURE_2D,e),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MIN_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MAG_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_S,t.CLAMP_TO_EDGE),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_T,t.CLAMP_TO_EDGE),e}function v(t,e,r,n,i){var a=t.getParameter(t.MAX_TEXTURE_SIZE);if(e<0||e>a||r<0||r>a)throw new Error(\"gl-texture2d: Invalid texture shape\");if(i===t.FLOAT&&!t.getExtension(\"OES_texture_float\"))throw new Error(\"gl-texture2d: Floating point textures not supported on this platform\");var o=g(t);return t.texImage2D(t.TEXTURE_2D,0,n,e,r,0,n,i,null),new f(t,o,e,r,n,i)}Object.defineProperties(p,{minFilter:{get:function(){return this._minFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,t),this._minFilter=t}},magFilter:{get:function(){return this._magFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,t),this._magFilter=t}},mipSamples:{get:function(){return this._anisoSamples},set:function(t){var e=this._anisoSamples;if(this._anisoSamples=0|Math.max(t,1),e!==this._anisoSamples){var r=this.gl.getExtension(\"EXT_texture_filter_anisotropic\");r&&this.gl.texParameterf(this.gl.TEXTURE_2D,r.TEXTURE_MAX_ANISOTROPY_EXT,this._anisoSamples)}return this._anisoSamples}},wrapS:{get:function(){return this._wrapS},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_S,t),this._wrapS=t}},wrapT:{get:function(){return this._wrapT},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_T,t),this._wrapT=t}},wrap:{get:function(){return this._wrapVector},set:function(t){if(Array.isArray(t)||(t=[t,t]),2!==t.length)throw new Error(\"gl-texture2d: Must specify wrap mode for rows and columns\");for(var e=0;e<2;++e)if(l.indexOf(t[e])<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);this._wrapS=t[0],this._wrapT=t[1];var r=this.gl;return this.bind(),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_S,this._wrapS),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_T,this._wrapT),t}},shape:{get:function(){return this._shapeVector},set:function(t){if(Array.isArray(t)){if(2!==t.length)throw new Error(\"gl-texture2d: Invalid texture shape\")}else t=[0|t,0|t];return h(this,0|t[0],0|t[1]),[0|t[0],0|t[1]]}},width:{get:function(){return this._shape[0]},set:function(t){return h(this,t|=0,this._shape[1]),t}},height:{get:function(){return this._shape[1]},set:function(t){return t|=0,h(this,this._shape[0],t),t}}}),p.bind=function(t){var e=this.gl;return void 0!==t&&e.activeTexture(e.TEXTURE0+(0|t)),e.bindTexture(e.TEXTURE_2D,this.handle),void 0!==t?0|t:e.getParameter(e.ACTIVE_TEXTURE)-e.TEXTURE0},p.dispose=function(){this.gl.deleteTexture(this.handle)},p.generateMipmap=function(){this.bind(),this.gl.generateMipmap(this.gl.TEXTURE_2D);for(var t=Math.min(this._shape[0],this._shape[1]),e=0;t>0;++e,t>>>=1)this._mipLevels.indexOf(e)<0&&this._mipLevels.push(e)},p.setPixels=function(t,e,r,o){var s=this.gl;this.bind(),Array.isArray(e)?(o=r,r=0|e[1],e=0|e[0]):(e=e||0,r=r||0),o=o||0;var l=c(t)?t:t.raw;if(l){this._mipLevels.indexOf(o)<0?(s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,this.type,l),this._mipLevels.push(o)):s.texSubImage2D(s.TEXTURE_2D,o,e,r,this.format,this.type,l)}else{if(!(t.shape&&t.stride&&t.data))throw new Error(\"gl-texture2d: Unsupported data type\");if(t.shape.length<2||e+t.shape[1]>this._shape[1]>>>o||r+t.shape[0]>this._shape[0]>>>o||e<0||r<0)throw new Error(\"gl-texture2d: Texture dimensions are out of bounds\");!function(t,e,r,o,s,l,c,h){var f=h.dtype,p=h.shape.slice();if(p.length<2||p.length>3)throw new Error(\"gl-texture2d: Invalid ndarray, must be 2d or 3d\");var g=0,v=0,m=d(p,h.stride.slice());\"float32\"===f?g=t.FLOAT:\"float64\"===f?(g=t.FLOAT,m=!1,f=\"float32\"):\"uint8\"===f?g=t.UNSIGNED_BYTE:(g=t.UNSIGNED_BYTE,m=!1,f=\"uint8\");if(2===p.length)v=t.LUMINANCE,p=[p[0],p[1],1],h=n(h.data,p,[h.stride[0],h.stride[1],1],h.offset);else{if(3!==p.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===p[2])v=t.ALPHA;else if(2===p[2])v=t.LUMINANCE_ALPHA;else if(3===p[2])v=t.RGB;else{if(4!==p[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");v=t.RGBA}p[2]}v!==t.LUMINANCE&&v!==t.ALPHA||s!==t.LUMINANCE&&s!==t.ALPHA||(v=s);if(v!==s)throw new Error(\"gl-texture2d: Incompatible texture format for setPixels\");var y=h.size,x=c.indexOf(o)<0;x&&c.push(o);if(g===l&&m)0===h.offset&&h.data.length===y?x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,h.data):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,h.data):x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,h.data.subarray(h.offset,h.offset+y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,h.data.subarray(h.offset,h.offset+y));else{var b;b=l===t.FLOAT?a.mallocFloat32(y):a.mallocUint8(y);var _=n(b,p,[p[2],p[2]*p[0],1]);g===t.FLOAT&&l===t.UNSIGNED_BYTE?u(_,h):i.assign(_,h),x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,b.subarray(0,y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,b.subarray(0,y)),l===t.FLOAT?a.freeFloat32(b):a.freeUint8(b)}}(s,e,r,o,this.format,this.type,this._mipLevels,t)}}},{ndarray:450,\"ndarray-ops\":444,\"typedarray-pool\":545}],323:[function(t,e,r){(function(r){\"use strict\";var n=t(\"pick-by-alias\");function i(t){if(t.container)if(t.container==document.body)document.body.style.width||(t.canvas.width=t.width||t.pixelRatio*r.innerWidth),document.body.style.height||(t.canvas.height=t.height||t.pixelRatio*r.innerHeight);else{var e=t.container.getBoundingClientRect();t.canvas.width=t.width||e.right-e.left,t.canvas.height=t.height||e.bottom-e.top}}function a(t){return\"function\"==typeof t.getContext&&\"width\"in t&&\"height\"in t}function o(){var t=document.createElement(\"canvas\");return t.style.position=\"absolute\",t.style.top=0,t.style.left=0,t}e.exports=function(t){var e;if(t?\"string\"==typeof t&&(t={container:t}):t={},a(t)?t={container:t}:t=\"string\"==typeof(e=t).nodeName&&\"function\"==typeof e.appendChild&&\"function\"==typeof e.getBoundingClientRect?{container:t}:function(t){return\"function\"==typeof t.drawArrays||\"function\"==typeof t.drawElements}(t)?{gl:t}:n(t,{container:\"container target element el canvas holder parent parentNode wrapper use ref root node\",gl:\"gl context webgl glContext\",attrs:\"attributes attrs contextAttributes\",pixelRatio:\"pixelRatio pxRatio px ratio pxratio pixelratio\",width:\"w width\",height:\"h height\"},!0),t.pixelRatio||(t.pixelRatio=r.pixelRatio||1),t.gl)return t.gl;if(t.canvas&&(t.container=t.canvas.parentNode),t.container){if(\"string\"==typeof t.container){var s=document.querySelector(t.container);if(!s)throw Error(\"Element \"+t.container+\" is not found\");t.container=s}a(t.container)?(t.canvas=t.container,t.container=t.canvas.parentNode):t.canvas||(t.canvas=o(),t.container.appendChild(t.canvas),i(t))}else if(!t.canvas){if(\"undefined\"==typeof document)throw Error(\"Not DOM environment. Use headless-gl.\");t.container=document.body||document.documentElement,t.canvas=o(),t.container.appendChild(t.canvas),i(t)}if(!t.gl)try{t.gl=t.canvas.getContext(\"webgl\",t.attrs)}catch(e){try{t.gl=t.canvas.getContext(\"experimental-webgl\",t.attrs)}catch(e){t.gl=t.canvas.getContext(\"webgl-experimental\",t.attrs)}}return t.gl}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"pick-by-alias\":465}],324:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){e?e.bind():t.bindBuffer(t.ELEMENT_ARRAY_BUFFER,null);var n=0|t.getParameter(t.MAX_VERTEX_ATTRIBS);if(r){if(r.length>n)throw new Error(\"gl-vao: Too many vertex attributes\");for(var i=0;i<r.length;++i){var a=r[i];if(a.buffer){var o=a.buffer,s=a.size||4,l=a.type||t.FLOAT,c=!!a.normalized,u=a.stride||0,h=a.offset||0;o.bind(),t.enableVertexAttribArray(i),t.vertexAttribPointer(i,s,l,c,u,h)}else{if(\"number\"==typeof a)t.vertexAttrib1f(i,a);else if(1===a.length)t.vertexAttrib1f(i,a[0]);else if(2===a.length)t.vertexAttrib2f(i,a[0],a[1]);else if(3===a.length)t.vertexAttrib3f(i,a[0],a[1],a[2]);else{if(4!==a.length)throw new Error(\"gl-vao: Invalid vertex attribute\");t.vertexAttrib4f(i,a[0],a[1],a[2],a[3])}t.disableVertexAttribArray(i)}}for(;i<n;++i)t.disableVertexAttribArray(i)}else for(t.bindBuffer(t.ARRAY_BUFFER,null),i=0;i<n;++i)t.disableVertexAttribArray(i)}},{}],325:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t){this.gl=t,this._elements=null,this._attributes=null,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(){n(this.gl,this._elements,this._attributes)},i.prototype.update=function(t,e,r){this._elements=e,this._attributes=t,this._elementsType=r||this.gl.UNSIGNED_SHORT},i.prototype.dispose=function(){},i.prototype.unbind=function(){},i.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._elements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t){return new i(t)}},{\"./do-bind.js\":324}],326:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t,e,r,n,i,a){this.location=t,this.dimension=e,this.a=r,this.b=n,this.c=i,this.d=a}function a(t,e,r){this.gl=t,this._ext=e,this.handle=r,this._attribs=[],this._useElements=!1,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(t){switch(this.dimension){case 1:t.vertexAttrib1f(this.location,this.a);break;case 2:t.vertexAttrib2f(this.location,this.a,this.b);break;case 3:t.vertexAttrib3f(this.location,this.a,this.b,this.c);break;case 4:t.vertexAttrib4f(this.location,this.a,this.b,this.c,this.d)}},a.prototype.bind=function(){this._ext.bindVertexArrayOES(this.handle);for(var t=0;t<this._attribs.length;++t)this._attribs[t].bind(this.gl)},a.prototype.unbind=function(){this._ext.bindVertexArrayOES(null)},a.prototype.dispose=function(){this._ext.deleteVertexArrayOES(this.handle)},a.prototype.update=function(t,e,r){if(this.bind(),n(this.gl,e,t),this.unbind(),this._attribs.length=0,t)for(var a=0;a<t.length;++a){var o=t[a];\"number\"==typeof o?this._attribs.push(new i(a,1,o)):Array.isArray(o)&&this._attribs.push(new i(a,o.length,o[0],o[1],o[2],o[3]))}this._useElements=!!e,this._elementsType=r||this.gl.UNSIGNED_SHORT},a.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._useElements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t,e){return new a(t,e,e.createVertexArrayOES())}},{\"./do-bind.js\":324}],327:[function(t,e,r){\"use strict\";var n=t(\"./lib/vao-native.js\"),i=t(\"./lib/vao-emulated.js\");function a(t){this.bindVertexArrayOES=t.bindVertexArray.bind(t),this.createVertexArrayOES=t.createVertexArray.bind(t),this.deleteVertexArrayOES=t.deleteVertexArray.bind(t)}e.exports=function(t,e,r,o){var s,l=t.createVertexArray?new a(t):t.getExtension(\"OES_vertex_array_object\");return(s=l?n(t,l):i(t)).update(e,r,o),s}},{\"./lib/vao-emulated.js\":325,\"./lib/vao-native.js\":326}],328:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t}},{}],329:[function(t,e,r){e.exports=function(t,e){var r=n(t[0],t[1],t[2]),o=n(e[0],e[1],e[2]);i(r,r),i(o,o);var s=a(r,o);return s>1?0:Math.acos(s)};var n=t(\"./fromValues\"),i=t(\"./normalize\"),a=t(\"./dot\")},{\"./dot\":339,\"./fromValues\":345,\"./normalize\":356}],330:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.ceil(e[0]),t[1]=Math.ceil(e[1]),t[2]=Math.ceil(e[2]),t}},{}],331:[function(t,e,r){e.exports=function(t){var e=new Float32Array(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e}},{}],332:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}},{}],333:[function(t,e,r){e.exports=function(){var t=new Float32Array(3);return t[0]=0,t[1]=0,t[2]=0,t}},{}],334:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2];return t[0]=i*l-a*s,t[1]=a*o-n*l,t[2]=n*s-i*o,t}},{}],335:[function(t,e,r){e.exports=t(\"./distance\")},{\"./distance\":336}],336:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return Math.sqrt(r*r+n*n+i*i)}},{}],337:[function(t,e,r){e.exports=t(\"./divide\")},{\"./divide\":338}],338:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t}},{}],339:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}},{}],340:[function(t,e,r){e.exports=1e-6},{}],341:[function(t,e,r){e.exports=function(t,e){var r=t[0],i=t[1],a=t[2],o=e[0],s=e[1],l=e[2];return Math.abs(r-o)<=n*Math.max(1,Math.abs(r),Math.abs(o))&&Math.abs(i-s)<=n*Math.max(1,Math.abs(i),Math.abs(s))&&Math.abs(a-l)<=n*Math.max(1,Math.abs(a),Math.abs(l))};var n=t(\"./epsilon\")},{\"./epsilon\":340}],342:[function(t,e,r){e.exports=function(t,e){return t[0]===e[0]&&t[1]===e[1]&&t[2]===e[2]}},{}],343:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.floor(e[0]),t[1]=Math.floor(e[1]),t[2]=Math.floor(e[2]),t}},{}],344:[function(t,e,r){e.exports=function(t,e,r,i,a,o){var s,l;e||(e=3);r||(r=0);l=i?Math.min(i*e+r,t.length):t.length;for(s=r;s<l;s+=e)n[0]=t[s],n[1]=t[s+1],n[2]=t[s+2],a(n,n,o),t[s]=n[0],t[s+1]=n[1],t[s+2]=n[2];return t};var n=t(\"./create\")()},{\"./create\":333}],345:[function(t,e,r){e.exports=function(t,e,r){var n=new Float32Array(3);return n[0]=t,n[1]=e,n[2]=r,n}},{}],346:[function(t,e,r){e.exports={EPSILON:t(\"./epsilon\"),create:t(\"./create\"),clone:t(\"./clone\"),angle:t(\"./angle\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),equals:t(\"./equals\"),exactEquals:t(\"./exactEquals\"),add:t(\"./add\"),subtract:t(\"./subtract\"),sub:t(\"./sub\"),multiply:t(\"./multiply\"),mul:t(\"./mul\"),divide:t(\"./divide\"),div:t(\"./div\"),min:t(\"./min\"),max:t(\"./max\"),floor:t(\"./floor\"),ceil:t(\"./ceil\"),round:t(\"./round\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),dist:t(\"./dist\"),squaredDistance:t(\"./squaredDistance\"),sqrDist:t(\"./sqrDist\"),length:t(\"./length\"),len:t(\"./len\"),squaredLength:t(\"./squaredLength\"),sqrLen:t(\"./sqrLen\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),cross:t(\"./cross\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformMat3:t(\"./transformMat3\"),transformQuat:t(\"./transformQuat\"),rotateX:t(\"./rotateX\"),rotateY:t(\"./rotateY\"),rotateZ:t(\"./rotateZ\"),forEach:t(\"./forEach\")}},{\"./add\":328,\"./angle\":329,\"./ceil\":330,\"./clone\":331,\"./copy\":332,\"./create\":333,\"./cross\":334,\"./dist\":335,\"./distance\":336,\"./div\":337,\"./divide\":338,\"./dot\":339,\"./epsilon\":340,\"./equals\":341,\"./exactEquals\":342,\"./floor\":343,\"./forEach\":344,\"./fromValues\":345,\"./inverse\":347,\"./len\":348,\"./length\":349,\"./lerp\":350,\"./max\":351,\"./min\":352,\"./mul\":353,\"./multiply\":354,\"./negate\":355,\"./normalize\":356,\"./random\":357,\"./rotateX\":358,\"./rotateY\":359,\"./rotateZ\":360,\"./round\":361,\"./scale\":362,\"./scaleAndAdd\":363,\"./set\":364,\"./sqrDist\":365,\"./sqrLen\":366,\"./squaredDistance\":367,\"./squaredLength\":368,\"./sub\":369,\"./subtract\":370,\"./transformMat3\":371,\"./transformMat4\":372,\"./transformQuat\":373}],347:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t}},{}],348:[function(t,e,r){e.exports=t(\"./length\")},{\"./length\":349}],349:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return Math.sqrt(e*e+r*r+n*n)}},{}],350:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t}},{}],351:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t}},{}],352:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t}},{}],353:[function(t,e,r){e.exports=t(\"./multiply\")},{\"./multiply\":354}],354:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t}},{}],355:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t}},{}],356:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=r*r+n*n+i*i;a>0&&(a=1/Math.sqrt(a),t[0]=e[0]*a,t[1]=e[1]*a,t[2]=e[2]*a);return t}},{}],357:[function(t,e,r){e.exports=function(t,e){e=e||1;var r=2*Math.random()*Math.PI,n=2*Math.random()-1,i=Math.sqrt(1-n*n)*e;return t[0]=Math.cos(r)*i,t[1]=Math.sin(r)*i,t[2]=n*e,t}},{}],358:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[1],a=r[2],o=e[1]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=e[0],t[1]=i+o*c-s*l,t[2]=a+o*l+s*c,t}},{}],359:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[2],o=e[0]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+s*l+o*c,t[1]=e[1],t[2]=a+s*c-o*l,t}},{}],360:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[1],o=e[0]-i,s=e[1]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+o*c-s*l,t[1]=a+o*l+s*c,t[2]=e[2],t}},{}],361:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.round(e[0]),t[1]=Math.round(e[1]),t[2]=Math.round(e[2]),t}},{}],362:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t}},{}],363:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t}},{}],364:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e,t[1]=r,t[2]=n,t}},{}],365:[function(t,e,r){e.exports=t(\"./squaredDistance\")},{\"./squaredDistance\":367}],366:[function(t,e,r){e.exports=t(\"./squaredLength\")},{\"./squaredLength\":368}],367:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return r*r+n*n+i*i}},{}],368:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return e*e+r*r+n*n}},{}],369:[function(t,e,r){e.exports=t(\"./subtract\")},{\"./subtract\":370}],370:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t}},{}],371:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t}},{}],372:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[3]*n+r[7]*i+r[11]*a+r[15];return o=o||1,t[0]=(r[0]*n+r[4]*i+r[8]*a+r[12])/o,t[1]=(r[1]*n+r[5]*i+r[9]*a+r[13])/o,t[2]=(r[2]*n+r[6]*i+r[10]*a+r[14])/o,t}},{}],373:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,h=c*i+l*n-o*a,f=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+h*-l-f*-s,t[1]=h*c+p*-s+f*-o-u*-l,t[2]=f*c+p*-l+u*-s-h*-o,t}},{}],374:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t[3]=e[3]+r[3],t}},{}],375:[function(t,e,r){e.exports=function(t){var e=new Float32Array(4);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e}},{}],376:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t}},{}],377:[function(t,e,r){e.exports=function(){var t=new Float32Array(4);return t[0]=0,t[1]=0,t[2]=0,t[3]=0,t}},{}],378:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return Math.sqrt(r*r+n*n+i*i+a*a)}},{}],379:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t[3]=e[3]/r[3],t}},{}],380:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}},{}],381:[function(t,e,r){e.exports=function(t,e,r,n){var i=new Float32Array(4);return i[0]=t,i[1]=e,i[2]=r,i[3]=n,i}},{}],382:[function(t,e,r){e.exports={create:t(\"./create\"),clone:t(\"./clone\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),add:t(\"./add\"),subtract:t(\"./subtract\"),multiply:t(\"./multiply\"),divide:t(\"./divide\"),min:t(\"./min\"),max:t(\"./max\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),squaredDistance:t(\"./squaredDistance\"),length:t(\"./length\"),squaredLength:t(\"./squaredLength\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformQuat:t(\"./transformQuat\")}},{\"./add\":374,\"./clone\":375,\"./copy\":376,\"./create\":377,\"./distance\":378,\"./divide\":379,\"./dot\":380,\"./fromValues\":381,\"./inverse\":383,\"./length\":384,\"./lerp\":385,\"./max\":386,\"./min\":387,\"./multiply\":388,\"./negate\":389,\"./normalize\":390,\"./random\":391,\"./scale\":392,\"./scaleAndAdd\":393,\"./set\":394,\"./squaredDistance\":395,\"./squaredLength\":396,\"./subtract\":397,\"./transformMat4\":398,\"./transformQuat\":399}],383:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t[3]=1/e[3],t}},{}],384:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return Math.sqrt(e*e+r*r+n*n+i*i)}},{}],385:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2],s=e[3];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t[3]=s+n*(r[3]-s),t}},{}],386:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t[3]=Math.max(e[3],r[3]),t}},{}],387:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t[3]=Math.min(e[3],r[3]),t}},{}],388:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t[3]=e[3]*r[3],t}},{}],389:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t[3]=-e[3],t}},{}],390:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r*r+n*n+i*i+a*a;o>0&&(o=1/Math.sqrt(o),t[0]=r*o,t[1]=n*o,t[2]=i*o,t[3]=a*o);return t}},{}],391:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"./scale\");e.exports=function(t,e){return e=e||1,t[0]=Math.random(),t[1]=Math.random(),t[2]=Math.random(),t[3]=Math.random(),n(t,t),i(t,t,e),t}},{\"./normalize\":390,\"./scale\":392}],392:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t}},{}],393:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t[3]=e[3]+r[3]*n,t}},{}],394:[function(t,e,r){e.exports=function(t,e,r,n,i){return t[0]=e,t[1]=r,t[2]=n,t[3]=i,t}},{}],395:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return r*r+n*n+i*i+a*a}},{}],396:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return e*e+r*r+n*n+i*i}},{}],397:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t[3]=e[3]-r[3],t}},{}],398:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}},{}],399:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,h=c*i+l*n-o*a,f=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+h*-l-f*-s,t[1]=h*c+p*-s+f*-o-u*-l,t[2]=f*c+p*-l+u*-s-h*-o,t[3]=e[3],t}},{}],400:[function(t,e,r){e.exports=function(t,e,r,a){return n[0]=a,n[1]=r,n[2]=e,n[3]=t,i[0]};var n=new Uint8Array(4),i=new Float32Array(n.buffer)},{}],401:[function(t,e,r){var n=t(\"glsl-tokenizer\"),i=t(\"atob-lite\");e.exports=function(t){for(var e=Array.isArray(t)?t:n(t),r=0;r<e.length;r++){var a=e[r];if(\"preprocessor\"===a.type){var o=a.data.match(/\\#define\\s+SHADER_NAME(_B64)?\\s+(.+)$/);if(o&&o[2]){var s=o[1],l=o[2];return(s?i(l):l).trim()}}}}},{\"atob-lite\":72,\"glsl-tokenizer\":408}],402:[function(t,e,r){e.exports=function(t){var e,r,k,T=0,A=0,M=l,S=[],E=[],C=1,L=0,P=0,O=!1,z=!1,I=\"\",D=a,R=n;\"300 es\"===(t=t||{}).version&&(D=s,R=o);return function(t){return E=[],null!==t?function(t){var r;T=0,k=(I+=t).length;for(;e=I[T],T<k;){switch(r=T,M){case u:T=U();break;case h:case f:T=j();break;case p:T=V();break;case d:T=G();break;case _:T=H();break;case g:T=Y();break;case c:T=W();break;case x:T=N();break;case l:T=B()}if(r!==T)switch(I[r]){case\"\\n\":L=0,++C;break;default:++L}}return A+=T,I=I.slice(T),E}(t.replace?t.replace(/\\r\\n/g,\"\\n\"):t):function(t){S.length&&F(S.join(\"\"));return M=b,F(\"(eof)\"),E}()};function F(t){t.length&&E.push({type:w[M],data:t,position:P,line:C,column:L})}function B(){return S=S.length?[]:S,\"/\"===r&&\"*\"===e?(P=A+T-1,M=u,r=e,T+1):\"/\"===r&&\"/\"===e?(P=A+T-1,M=h,r=e,T+1):\"#\"===e?(M=f,P=A+T,T):/\\s/.test(e)?(M=x,P=A+T,T):(O=/\\d/.test(e),z=/[^\\w_]/.test(e),P=A+T,M=O?d:z?p:c,T)}function N(){return/[^\\s]/g.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function j(){return\"\\r\"!==e&&\"\\n\"!==e||\"\\\\\"===r?(S.push(e),r=e,T+1):(F(S.join(\"\")),M=l,T)}function U(){return\"/\"===e&&\"*\"===r?(S.push(e),F(S.join(\"\")),M=l,T+1):(S.push(e),r=e,T+1)}function V(){if(\".\"===r&&/\\d/.test(e))return M=g,T;if(\"/\"===r&&\"*\"===e)return M=u,T;if(\"/\"===r&&\"/\"===e)return M=h,T;if(\".\"===e&&S.length){for(;q(S););return M=g,T}if(\";\"===e||\")\"===e||\"(\"===e){if(S.length)for(;q(S););return F(e),M=l,T+1}var t=2===S.length&&\"=\"!==e;if(/[\\w_\\d\\s]/.test(e)||t){for(;q(S););return M=l,T}return S.push(e),r=e,T+1}function q(t){for(var e,r,n=0;;){if(e=i.indexOf(t.slice(0,t.length+n).join(\"\")),r=i[e],-1===e){if(n--+t.length>0)continue;r=t.slice(0,1).join(\"\")}return F(r),P+=r.length,(S=S.slice(r.length)).length}}function H(){return/[^a-fA-F0-9]/.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function G(){return\".\"===e?(S.push(e),M=g,r=e,T+1):/[eE]/.test(e)?(S.push(e),M=g,r=e,T+1):\"x\"===e&&1===S.length&&\"0\"===S[0]?(M=_,S.push(e),r=e,T+1):/[^\\d]/.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function Y(){return\"f\"===e&&(S.push(e),r=e,T+=1),/[eE]/.test(e)?(S.push(e),r=e,T+1):\"-\"===e&&/[eE]/.test(r)?(S.push(e),r=e,T+1):/[^\\d]/.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function W(){if(/[^\\d\\w_]/.test(e)){var t=S.join(\"\");return M=R.indexOf(t)>-1?y:D.indexOf(t)>-1?m:v,F(S.join(\"\")),M=l,T}return S.push(e),r=e,T+1}};var n=t(\"./lib/literals\"),i=t(\"./lib/operators\"),a=t(\"./lib/builtins\"),o=t(\"./lib/literals-300es\"),s=t(\"./lib/builtins-300es\"),l=999,c=9999,u=0,h=1,f=2,p=3,d=4,g=5,v=6,m=7,y=8,x=9,b=10,_=11,w=[\"block-comment\",\"line-comment\",\"preprocessor\",\"operator\",\"integer\",\"float\",\"ident\",\"builtin\",\"keyword\",\"whitespace\",\"eof\",\"integer\"]},{\"./lib/builtins\":404,\"./lib/builtins-300es\":403,\"./lib/literals\":406,\"./lib/literals-300es\":405,\"./lib/operators\":407}],403:[function(t,e,r){var n=t(\"./builtins\");n=n.slice().filter(function(t){return!/^(gl\\_|texture)/.test(t)}),e.exports=n.concat([\"gl_VertexID\",\"gl_InstanceID\",\"gl_Position\",\"gl_PointSize\",\"gl_FragCoord\",\"gl_FrontFacing\",\"gl_FragDepth\",\"gl_PointCoord\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexUniformVectors\",\"gl_MaxVertexOutputVectors\",\"gl_MaxFragmentInputVectors\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxTextureImageUnits\",\"gl_MaxFragmentUniformVectors\",\"gl_MaxDrawBuffers\",\"gl_MinProgramTexelOffset\",\"gl_MaxProgramTexelOffset\",\"gl_DepthRangeParameters\",\"gl_DepthRange\",\"trunc\",\"round\",\"roundEven\",\"isnan\",\"isinf\",\"floatBitsToInt\",\"floatBitsToUint\",\"intBitsToFloat\",\"uintBitsToFloat\",\"packSnorm2x16\",\"unpackSnorm2x16\",\"packUnorm2x16\",\"unpackUnorm2x16\",\"packHalf2x16\",\"unpackHalf2x16\",\"outerProduct\",\"transpose\",\"determinant\",\"inverse\",\"texture\",\"textureSize\",\"textureProj\",\"textureLod\",\"textureOffset\",\"texelFetch\",\"texelFetchOffset\",\"textureProjOffset\",\"textureLodOffset\",\"textureProjLod\",\"textureProjLodOffset\",\"textureGrad\",\"textureGradOffset\",\"textureProjGrad\",\"textureProjGradOffset\"])},{\"./builtins\":404}],404:[function(t,e,r){e.exports=[\"abs\",\"acos\",\"all\",\"any\",\"asin\",\"atan\",\"ceil\",\"clamp\",\"cos\",\"cross\",\"dFdx\",\"dFdy\",\"degrees\",\"distance\",\"dot\",\"equal\",\"exp\",\"exp2\",\"faceforward\",\"floor\",\"fract\",\"gl_BackColor\",\"gl_BackLightModelProduct\",\"gl_BackLightProduct\",\"gl_BackMaterial\",\"gl_BackSecondaryColor\",\"gl_ClipPlane\",\"gl_ClipVertex\",\"gl_Color\",\"gl_DepthRange\",\"gl_DepthRangeParameters\",\"gl_EyePlaneQ\",\"gl_EyePlaneR\",\"gl_EyePlaneS\",\"gl_EyePlaneT\",\"gl_Fog\",\"gl_FogCoord\",\"gl_FogFragCoord\",\"gl_FogParameters\",\"gl_FragColor\",\"gl_FragCoord\",\"gl_FragData\",\"gl_FragDepth\",\"gl_FragDepthEXT\",\"gl_FrontColor\",\"gl_FrontFacing\",\"gl_FrontLightModelProduct\",\"gl_FrontLightProduct\",\"gl_FrontMaterial\",\"gl_FrontSecondaryColor\",\"gl_LightModel\",\"gl_LightModelParameters\",\"gl_LightModelProducts\",\"gl_LightProducts\",\"gl_LightSource\",\"gl_LightSourceParameters\",\"gl_MaterialParameters\",\"gl_MaxClipPlanes\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxDrawBuffers\",\"gl_MaxFragmentUniformComponents\",\"gl_MaxLights\",\"gl_MaxTextureCoords\",\"gl_MaxTextureImageUnits\",\"gl_MaxTextureUnits\",\"gl_MaxVaryingFloats\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxVertexUniformComponents\",\"gl_ModelViewMatrix\",\"gl_ModelViewMatrixInverse\",\"gl_ModelViewMatrixInverseTranspose\",\"gl_ModelViewMatrixTranspose\",\"gl_ModelViewProjectionMatrix\",\"gl_ModelViewProjectionMatrixInverse\",\"gl_ModelViewProjectionMatrixInverseTranspose\",\"gl_ModelViewProjectionMatrixTranspose\",\"gl_MultiTexCoord0\",\"gl_MultiTexCoord1\",\"gl_MultiTexCoord2\",\"gl_MultiTexCoord3\",\"gl_MultiTexCoord4\",\"gl_MultiTexCoord5\",\"gl_MultiTexCoord6\",\"gl_MultiTexCoord7\",\"gl_Normal\",\"gl_NormalMatrix\",\"gl_NormalScale\",\"gl_ObjectPlaneQ\",\"gl_ObjectPlaneR\",\"gl_ObjectPlaneS\",\"gl_ObjectPlaneT\",\"gl_Point\",\"gl_PointCoord\",\"gl_PointParameters\",\"gl_PointSize\",\"gl_Position\",\"gl_ProjectionMatrix\",\"gl_ProjectionMatrixInverse\",\"gl_ProjectionMatrixInverseTranspose\",\"gl_ProjectionMatrixTranspose\",\"gl_SecondaryColor\",\"gl_TexCoord\",\"gl_TextureEnvColor\",\"gl_TextureMatrix\",\"gl_TextureMatrixInverse\",\"gl_TextureMatrixInverseTranspose\",\"gl_TextureMatrixTranspose\",\"gl_Vertex\",\"greaterThan\",\"greaterThanEqual\",\"inversesqrt\",\"length\",\"lessThan\",\"lessThanEqual\",\"log\",\"log2\",\"matrixCompMult\",\"max\",\"min\",\"mix\",\"mod\",\"normalize\",\"not\",\"notEqual\",\"pow\",\"radians\",\"reflect\",\"refract\",\"sign\",\"sin\",\"smoothstep\",\"sqrt\",\"step\",\"tan\",\"texture2D\",\"texture2DLod\",\"texture2DProj\",\"texture2DProjLod\",\"textureCube\",\"textureCubeLod\",\"texture2DLodEXT\",\"texture2DProjLodEXT\",\"textureCubeLodEXT\",\"texture2DGradEXT\",\"texture2DProjGradEXT\",\"textureCubeGradEXT\"]},{}],405:[function(t,e,r){var n=t(\"./literals\");e.exports=n.slice().concat([\"layout\",\"centroid\",\"smooth\",\"case\",\"mat2x2\",\"mat2x3\",\"mat2x4\",\"mat3x2\",\"mat3x3\",\"mat3x4\",\"mat4x2\",\"mat4x3\",\"mat4x4\",\"uint\",\"uvec2\",\"uvec3\",\"uvec4\",\"samplerCubeShadow\",\"sampler2DArray\",\"sampler2DArrayShadow\",\"isampler2D\",\"isampler3D\",\"isamplerCube\",\"isampler2DArray\",\"usampler2D\",\"usampler3D\",\"usamplerCube\",\"usampler2DArray\",\"coherent\",\"restrict\",\"readonly\",\"writeonly\",\"resource\",\"atomic_uint\",\"noperspective\",\"patch\",\"sample\",\"subroutine\",\"common\",\"partition\",\"active\",\"filter\",\"image1D\",\"image2D\",\"image3D\",\"imageCube\",\"iimage1D\",\"iimage2D\",\"iimage3D\",\"iimageCube\",\"uimage1D\",\"uimage2D\",\"uimage3D\",\"uimageCube\",\"image1DArray\",\"image2DArray\",\"iimage1DArray\",\"iimage2DArray\",\"uimage1DArray\",\"uimage2DArray\",\"image1DShadow\",\"image2DShadow\",\"image1DArrayShadow\",\"image2DArrayShadow\",\"imageBuffer\",\"iimageBuffer\",\"uimageBuffer\",\"sampler1DArray\",\"sampler1DArrayShadow\",\"isampler1D\",\"isampler1DArray\",\"usampler1D\",\"usampler1DArray\",\"isampler2DRect\",\"usampler2DRect\",\"samplerBuffer\",\"isamplerBuffer\",\"usamplerBuffer\",\"sampler2DMS\",\"isampler2DMS\",\"usampler2DMS\",\"sampler2DMSArray\",\"isampler2DMSArray\",\"usampler2DMSArray\"])},{\"./literals\":406}],406:[function(t,e,r){e.exports=[\"precision\",\"highp\",\"mediump\",\"lowp\",\"attribute\",\"const\",\"uniform\",\"varying\",\"break\",\"continue\",\"do\",\"for\",\"while\",\"if\",\"else\",\"in\",\"out\",\"inout\",\"float\",\"int\",\"void\",\"bool\",\"true\",\"false\",\"discard\",\"return\",\"mat2\",\"mat3\",\"mat4\",\"vec2\",\"vec3\",\"vec4\",\"ivec2\",\"ivec3\",\"ivec4\",\"bvec2\",\"bvec3\",\"bvec4\",\"sampler1D\",\"sampler2D\",\"sampler3D\",\"samplerCube\",\"sampler1DShadow\",\"sampler2DShadow\",\"struct\",\"asm\",\"class\",\"union\",\"enum\",\"typedef\",\"template\",\"this\",\"packed\",\"goto\",\"switch\",\"default\",\"inline\",\"noinline\",\"volatile\",\"public\",\"static\",\"extern\",\"external\",\"interface\",\"long\",\"short\",\"double\",\"half\",\"fixed\",\"unsigned\",\"input\",\"output\",\"hvec2\",\"hvec3\",\"hvec4\",\"dvec2\",\"dvec3\",\"dvec4\",\"fvec2\",\"fvec3\",\"fvec4\",\"sampler2DRect\",\"sampler3DRect\",\"sampler2DRectShadow\",\"sizeof\",\"cast\",\"namespace\",\"using\"]},{}],407:[function(t,e,r){e.exports=[\"<<=\",\">>=\",\"++\",\"--\",\"<<\",\">>\",\"<=\",\">=\",\"==\",\"!=\",\"&&\",\"||\",\"+=\",\"-=\",\"*=\",\"/=\",\"%=\",\"&=\",\"^^\",\"^=\",\"|=\",\"(\",\")\",\"[\",\"]\",\".\",\"!\",\"~\",\"*\",\"/\",\"%\",\"+\",\"-\",\"<\",\">\",\"&\",\"^\",\"|\",\"?\",\":\",\"=\",\",\",\";\",\"{\",\"}\"]},{}],408:[function(t,e,r){var n=t(\"./index\");e.exports=function(t,e){var r=n(e),i=[];return i=(i=i.concat(r(t))).concat(r(null))}},{\"./index\":402}],409:[function(t,e,r){e.exports=function(t){\"string\"==typeof t&&(t=[t]);for(var e=[].slice.call(arguments,1),r=[],n=0;n<t.length-1;n++)r.push(t[n],e[n]||\"\");return r.push(t[n]),r.join(\"\")}},{}],410:[function(t,e,r){(function(r){\"use strict\";var n,i=t(\"is-browser\");n=\"function\"==typeof r.matchMedia?!r.matchMedia(\"(hover: none)\").matches:i,e.exports=n}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"is-browser\":417}],411:[function(t,e,r){\"use strict\";var n=t(\"is-browser\");e.exports=n&&function(){var t=!1;try{var e=Object.defineProperty({},\"passive\",{get:function(){t=!0}});window.addEventListener(\"test\",null,e),window.removeEventListener(\"test\",null,e)}catch(e){t=!1}return t}()},{\"is-browser\":417}],412:[function(t,e,r){r.read=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?i-1:0,f=r?-1:1,p=t[e+h];for(h+=f,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+h],h+=f,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},r.write=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,h=u>>1,f=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,i),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g}},{}],413:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(0===r)throw new Error(\"Must have at least d+1 points\");var i=t[0].length;if(r<=i)throw new Error(\"Must input at least d+1 points\");var o=t.slice(0,i+1),s=n.apply(void 0,o);if(0===s)throw new Error(\"Input not in general position\");for(var l=new Array(i+1),u=0;u<=i;++u)l[u]=u;s<0&&(l[0]=1,l[1]=0);for(var h=new a(l,new Array(i+1),!1),f=h.adjacent,p=new Array(i+2),u=0;u<=i;++u){for(var d=l.slice(),g=0;g<=i;++g)g===u&&(d[g]=-1);var v=d[0];d[0]=d[1],d[1]=v;var m=new a(d,new Array(i+1),!0);f[u]=m,p[u]=m}p[i+1]=h;for(var u=0;u<=i;++u)for(var d=f[u].vertices,y=f[u].adjacent,g=0;g<=i;++g){var x=d[g];if(x<0)y[g]=h;else for(var b=0;b<=i;++b)f[b].vertices.indexOf(x)<0&&(y[g]=f[b])}for(var _=new c(i,o,p),w=!!e,u=i+1;u<r;++u)_.insert(t[u],w);return _.boundary()};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\").compareCells;function a(t,e,r){this.vertices=t,this.adjacent=e,this.boundary=r,this.lastVisited=-1}function o(t,e,r){this.vertices=t,this.cell=e,this.index=r}function s(t,e){return i(t.vertices,e.vertices)}a.prototype.flip=function(){var t=this.vertices[0];this.vertices[0]=this.vertices[1],this.vertices[1]=t;var e=this.adjacent[0];this.adjacent[0]=this.adjacent[1],this.adjacent[1]=e};var l=[];function c(t,e,r){this.dimension=t,this.vertices=e,this.simplices=r,this.interior=r.filter(function(t){return!t.boundary}),this.tuple=new Array(t+1);for(var i=0;i<=t;++i)this.tuple[i]=this.vertices[i];var a=l[t];a||(a=l[t]=function(t){for(var e=[\"function orient(){var tuple=this.tuple;return test(\"],r=0;r<=t;++r)r>0&&e.push(\",\"),e.push(\"tuple[\",r,\"]\");e.push(\")}return orient\");var i=new Function(\"test\",e.join(\"\")),a=n[t+1];return a||(a=n),i(a)}(t)),this.orient=a}var u=c.prototype;u.handleBoundaryDegeneracy=function(t,e){var r=this.dimension,n=this.vertices.length-1,i=this.tuple,a=this.vertices,o=[t];for(t.lastVisited=-n;o.length>0;){(t=o.pop()).vertices;for(var s=t.adjacent,l=0;l<=r;++l){var c=s[l];if(c.boundary&&!(c.lastVisited<=-n)){for(var u=c.vertices,h=0;h<=r;++h){var f=u[h];i[h]=f<0?e:a[f]}var p=this.orient();if(p>0)return c;c.lastVisited=-n,0===p&&o.push(c)}}}return null},u.walk=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,a=this.tuple,o=e?this.interior.length*Math.random()|0:this.interior.length-1,s=this.interior[o];t:for(;!s.boundary;){for(var l=s.vertices,c=s.adjacent,u=0;u<=n;++u)a[u]=i[l[u]];s.lastVisited=r;for(u=0;u<=n;++u){var h=c[u];if(!(h.lastVisited>=r)){var f=a[u];a[u]=t;var p=this.orient();if(a[u]=f,p<0){s=h;continue t}h.boundary?h.lastVisited=-r:h.lastVisited=r}}return}return s},u.addPeaks=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,l=this.tuple,c=this.interior,u=this.simplices,h=[e];e.lastVisited=r,e.vertices[e.vertices.indexOf(-1)]=r,e.boundary=!1,c.push(e);for(var f=[];h.length>0;){var p=(e=h.pop()).vertices,d=e.adjacent,g=p.indexOf(r);if(!(g<0))for(var v=0;v<=n;++v)if(v!==g){var m=d[v];if(m.boundary&&!(m.lastVisited>=r)){var y=m.vertices;if(m.lastVisited!==-r){for(var x=0,b=0;b<=n;++b)y[b]<0?(x=b,l[b]=t):l[b]=i[y[b]];if(this.orient()>0){y[x]=r,m.boundary=!1,c.push(m),h.push(m),m.lastVisited=r;continue}m.lastVisited=-r}var _=m.adjacent,w=p.slice(),k=d.slice(),T=new a(w,k,!0);u.push(T);var A=_.indexOf(e);if(!(A<0)){_[A]=T,k[g]=m,w[v]=-1,k[v]=e,d[v]=T,T.flip();for(b=0;b<=n;++b){var M=w[b];if(!(M<0||M===r)){for(var S=new Array(n-1),E=0,C=0;C<=n;++C){var L=w[C];L<0||C===b||(S[E++]=L)}f.push(new o(S,T,b))}}}}}}f.sort(s);for(v=0;v+1<f.length;v+=2){var P=f[v],O=f[v+1],z=P.index,I=O.index;z<0||I<0||(P.cell.adjacent[P.index]=O.cell,O.cell.adjacent[O.index]=P.cell)}},u.insert=function(t,e){var r=this.vertices;r.push(t);var n=this.walk(t,e);if(n){for(var i=this.dimension,a=this.tuple,o=0;o<=i;++o){var s=n.vertices[o];a[o]=s<0?t:r[s]}var l=this.orient(a);l<0||(0!==l||(n=this.handleBoundaryDegeneracy(n,t)))&&this.addPeaks(t,n)}},u.boundary=function(){for(var t=this.dimension,e=[],r=this.simplices,n=r.length,i=0;i<n;++i){var a=r[i];if(a.boundary){for(var o=new Array(t),s=a.vertices,l=0,c=0,u=0;u<=t;++u)s[u]>=0?o[l++]=s[u]:c=1&u;if(c===(1&t)){var h=o[0];o[0]=o[1],o[1]=h}e.push(o)}}return e}},{\"robust-orientation\":510,\"simplicial-complex\":520}],414:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=0,a=1;function o(t,e,r,n,i){this.mid=t,this.left=e,this.right=r,this.leftPoints=n,this.rightPoints=i,this.count=(e?e.count:0)+(r?r.count:0)+n.length}e.exports=function(t){if(!t||0===t.length)return new x(null);return new x(y(t))};var s=o.prototype;function l(t,e){t.mid=e.mid,t.left=e.left,t.right=e.right,t.leftPoints=e.leftPoints,t.rightPoints=e.rightPoints,t.count=e.count}function c(t,e){var r=y(e);t.mid=r.mid,t.left=r.left,t.right=r.right,t.leftPoints=r.leftPoints,t.rightPoints=r.rightPoints,t.count=r.count}function u(t,e){var r=t.intervals([]);r.push(e),c(t,r)}function h(t,e){var r=t.intervals([]),n=r.indexOf(e);return n<0?i:(r.splice(n,1),c(t,r),a)}function f(t,e,r){for(var n=0;n<t.length&&t[n][0]<=e;++n){var i=r(t[n]);if(i)return i}}function p(t,e,r){for(var n=t.length-1;n>=0&&t[n][1]>=e;--n){var i=r(t[n]);if(i)return i}}function d(t,e){for(var r=0;r<t.length;++r){var n=e(t[r]);if(n)return n}}function g(t,e){return t-e}function v(t,e){var r=t[0]-e[0];return r||t[1]-e[1]}function m(t,e){var r=t[1]-e[1];return r||t[0]-e[0]}function y(t){if(0===t.length)return null;for(var e=[],r=0;r<t.length;++r)e.push(t[r][0],t[r][1]);e.sort(g);var n=e[e.length>>1],i=[],a=[],s=[];for(r=0;r<t.length;++r){var l=t[r];l[1]<n?i.push(l):n<l[0]?a.push(l):s.push(l)}var c=s,u=s.slice();return c.sort(v),u.sort(m),new o(n,y(i),y(a),c,u)}function x(t){this.root=t}s.intervals=function(t){return t.push.apply(t,this.leftPoints),this.left&&this.left.intervals(t),this.right&&this.right.intervals(t),t},s.insert=function(t){var e=this.count-this.leftPoints.length;if(this.count+=1,t[1]<this.mid)this.left?4*(this.left.count+1)>3*(e+1)?u(this,t):this.left.insert(t):this.left=y([t]);else if(t[0]>this.mid)this.right?4*(this.right.count+1)>3*(e+1)?u(this,t):this.right.insert(t):this.right=y([t]);else{var r=n.ge(this.leftPoints,t,v),i=n.ge(this.rightPoints,t,m);this.leftPoints.splice(r,0,t),this.rightPoints.splice(i,0,t)}},s.remove=function(t){var e=this.count-this.leftPoints;if(t[1]<this.mid)return this.left?4*(this.right?this.right.count:0)>3*(e-1)?h(this,t):2===(c=this.left.remove(t))?(this.left=null,this.count-=1,a):(c===a&&(this.count-=1),c):i;if(t[0]>this.mid)return this.right?4*(this.left?this.left.count:0)>3*(e-1)?h(this,t):2===(c=this.right.remove(t))?(this.right=null,this.count-=1,a):(c===a&&(this.count-=1),c):i;if(1===this.count)return this.leftPoints[0]===t?2:i;if(1===this.leftPoints.length&&this.leftPoints[0]===t){if(this.left&&this.right){for(var r=this,o=this.left;o.right;)r=o,o=o.right;if(r===this)o.right=this.right;else{var s=this.left,c=this.right;r.count-=o.count,r.right=o.left,o.left=s,o.right=c}l(this,o),this.count=(this.left?this.left.count:0)+(this.right?this.right.count:0)+this.leftPoints.length}else this.left?l(this,this.left):l(this,this.right);return a}for(s=n.ge(this.leftPoints,t,v);s<this.leftPoints.length&&this.leftPoints[s][0]===t[0];++s)if(this.leftPoints[s]===t){this.count-=1,this.leftPoints.splice(s,1);for(c=n.ge(this.rightPoints,t,m);c<this.rightPoints.length&&this.rightPoints[c][1]===t[1];++c)if(this.rightPoints[c]===t)return this.rightPoints.splice(c,1),a}return i},s.queryPoint=function(t,e){if(t<this.mid){if(this.left)if(r=this.left.queryPoint(t,e))return r;return f(this.leftPoints,t,e)}if(t>this.mid){var r;if(this.right)if(r=this.right.queryPoint(t,e))return r;return p(this.rightPoints,t,e)}return d(this.leftPoints,e)},s.queryInterval=function(t,e,r){var n;if(t<this.mid&&this.left&&(n=this.left.queryInterval(t,e,r)))return n;if(e>this.mid&&this.right&&(n=this.right.queryInterval(t,e,r)))return n;return e<this.mid?f(this.leftPoints,e,r):t>this.mid?p(this.rightPoints,t,r):d(this.leftPoints,r)};var b=x.prototype;b.insert=function(t){this.root?this.root.insert(t):this.root=new o(t[0],null,null,[t],[t])},b.remove=function(t){if(this.root){var e=this.root.remove(t);return 2===e&&(this.root=null),e!==i}return!1},b.queryPoint=function(t,e){if(this.root)return this.root.queryPoint(t,e)},b.queryInterval=function(t,e,r){if(t<=e&&this.root)return this.root.queryInterval(t,e,r)},Object.defineProperty(b,\"count\",{get:function(){return this.root?this.root.count:0}}),Object.defineProperty(b,\"intervals\",{get:function(){return this.root?this.root.intervals([]):[]}})},{\"binary-search-bounds\":91}],415:[function(t,e,r){\"use strict\";e.exports=function(t,e){e=e||new Array(t.length);for(var r=0;r<t.length;++r)e[t[r]]=r;return e}},{}],416:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=r;return e}},{}],417:[function(t,e,r){e.exports=!0},{}],418:[function(t,e,r){function n(t){return!!t.constructor&&\"function\"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}e.exports=function(t){return null!=t&&(n(t)||function(t){return\"function\"==typeof t.readFloatLE&&\"function\"==typeof t.slice&&n(t.slice(0,0))}(t)||!!t._isBuffer)}},{}],419:[function(t,e,r){\"use strict\";e.exports=\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion))},{}],420:[function(t,e,r){\"use strict\";e.exports=a,e.exports.isMobile=a;var n=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i,i=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino|android|ipad|playbook|silk/i;function a(t){t||(t={});var e=t.ua;return e||\"undefined\"==typeof navigator||(e=navigator.userAgent),e&&e.headers&&\"string\"==typeof e.headers[\"user-agent\"]&&(e=e.headers[\"user-agent\"]),\"string\"==typeof e&&(t.tablet?i.test(e):n.test(e))}},{}],421:[function(t,e,r){\"use strict\";e.exports=function(t){var e=typeof t;return null!==t&&(\"object\"===e||\"function\"===e)}},{}],422:[function(t,e,r){\"use strict\";var n=Object.prototype.toString;e.exports=function(t){var e;return\"[object Object]\"===n.call(t)&&(null===(e=Object.getPrototypeOf(t))||e===Object.getPrototypeOf({}))}},{}],423:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=t.length,n=0;n<r;n++)if(((e=t.charCodeAt(n))<9||e>13)&&32!==e&&133!==e&&160!==e&&5760!==e&&6158!==e&&(e<8192||e>8205)&&8232!==e&&8233!==e&&8239!==e&&8287!==e&&8288!==e&&12288!==e&&65279!==e)return!1;return!0}},{}],424:[function(t,e,r){\"use strict\";e.exports=function(t){return\"string\"==typeof t&&(t=t.trim(),!!(/^[mzlhvcsqta]\\s*[-+.0-9][^mlhvzcsqta]+/i.test(t)&&/[\\dz]$/i.test(t)&&t.length>4))}},{}],425:[function(t,e,r){e.exports=function(t,e,r){return t*(1-r)+e*r}},{}],426:[function(t,e,r){var n,i;n=this,i=function(){\"use strict\";var t,e,r;function n(n,i){if(t)if(e){var a=\"var sharedChunk = {}; (\"+t+\")(sharedChunk); (\"+e+\")(sharedChunk);\",o={};t(o),(r=i(o)).workerUrl=window.URL.createObjectURL(new Blob([a],{type:\"text/javascript\"}))}else e=i;else t=i}return n(0,function(t){function e(t,e){return t(e={exports:{}},e.exports),e.exports}var r=n;function n(t,e,r,n){this.cx=3*t,this.bx=3*(r-t)-this.cx,this.ax=1-this.cx-this.bx,this.cy=3*e,this.by=3*(n-e)-this.cy,this.ay=1-this.cy-this.by,this.p1x=t,this.p1y=n,this.p2x=r,this.p2y=n}n.prototype.sampleCurveX=function(t){return((this.ax*t+this.bx)*t+this.cx)*t},n.prototype.sampleCurveY=function(t){return((this.ay*t+this.by)*t+this.cy)*t},n.prototype.sampleCurveDerivativeX=function(t){return(3*this.ax*t+2*this.bx)*t+this.cx},n.prototype.solveCurveX=function(t,e){var r,n,i,a,o;for(void 0===e&&(e=1e-6),i=t,o=0;o<8;o++){if(a=this.sampleCurveX(i)-t,Math.abs(a)<e)return i;var s=this.sampleCurveDerivativeX(i);if(Math.abs(s)<1e-6)break;i-=a/s}if((i=t)<(r=0))return r;if(i>(n=1))return n;for(;r<n;){if(a=this.sampleCurveX(i),Math.abs(a-t)<e)return i;t>a?r=i:n=i,i=.5*(n-r)+r}return i},n.prototype.solve=function(t,e){return this.sampleCurveY(this.solveCurveX(t,e))};var i=a;function a(t,e){this.x=t,this.y=e}function o(t,e){if(Array.isArray(t)){if(!Array.isArray(e)||t.length!==e.length)return!1;for(var r=0;r<t.length;r++)if(!o(t[r],e[r]))return!1;return!0}if(\"object\"==typeof t&&null!==t&&null!==e){if(\"object\"!=typeof e)return!1;if(Object.keys(t).length!==Object.keys(e).length)return!1;for(var n in t)if(!o(t[n],e[n]))return!1;return!0}return t===e}function s(t,e,n,i){var a=new r(t,e,n,i);return function(t){return a.solve(t)}}a.prototype={clone:function(){return new a(this.x,this.y)},add:function(t){return this.clone()._add(t)},sub:function(t){return this.clone()._sub(t)},multByPoint:function(t){return this.clone()._multByPoint(t)},divByPoint:function(t){return this.clone()._divByPoint(t)},mult:function(t){return this.clone()._mult(t)},div:function(t){return this.clone()._div(t)},rotate:function(t){return this.clone()._rotate(t)},rotateAround:function(t,e){return this.clone()._rotateAround(t,e)},matMult:function(t){return this.clone()._matMult(t)},unit:function(){return this.clone()._unit()},perp:function(){return this.clone()._perp()},round:function(){return this.clone()._round()},mag:function(){return Math.sqrt(this.x*this.x+this.y*this.y)},equals:function(t){return this.x===t.x&&this.y===t.y},dist:function(t){return Math.sqrt(this.distSqr(t))},distSqr:function(t){var e=t.x-this.x,r=t.y-this.y;return e*e+r*r},angle:function(){return Math.atan2(this.y,this.x)},angleTo:function(t){return Math.atan2(this.y-t.y,this.x-t.x)},angleWith:function(t){return this.angleWithSep(t.x,t.y)},angleWithSep:function(t,e){return Math.atan2(this.x*e-this.y*t,this.x*t+this.y*e)},_matMult:function(t){var e=t[0]*this.x+t[1]*this.y,r=t[2]*this.x+t[3]*this.y;return this.x=e,this.y=r,this},_add:function(t){return this.x+=t.x,this.y+=t.y,this},_sub:function(t){return this.x-=t.x,this.y-=t.y,this},_mult:function(t){return this.x*=t,this.y*=t,this},_div:function(t){return this.x/=t,this.y/=t,this},_multByPoint:function(t){return this.x*=t.x,this.y*=t.y,this},_divByPoint:function(t){return this.x/=t.x,this.y/=t.y,this},_unit:function(){return this._div(this.mag()),this},_perp:function(){var t=this.y;return this.y=this.x,this.x=-t,this},_rotate:function(t){var e=Math.cos(t),r=Math.sin(t),n=e*this.x-r*this.y,i=r*this.x+e*this.y;return this.x=n,this.y=i,this},_rotateAround:function(t,e){var r=Math.cos(t),n=Math.sin(t),i=e.x+r*(this.x-e.x)-n*(this.y-e.y),a=e.y+n*(this.x-e.x)+r*(this.y-e.y);return this.x=i,this.y=a,this},_round:function(){return this.x=Math.round(this.x),this.y=Math.round(this.y),this}},a.convert=function(t){return t instanceof a?t:Array.isArray(t)?new a(t[0],t[1]):t};var l=s(.25,.1,.25,1);function c(t,e,r){return Math.min(r,Math.max(e,t))}function u(t,e,r){var n=r-e,i=((t-e)%n+n)%n+e;return i===e?r:i}function h(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}var f=1;function p(){return f++}function d(){return function t(e){return e?(e^16*Math.random()>>e/4).toString(16):([1e7]+-[1e3]+-4e3+-8e3+-1e11).replace(/[018]/g,t)}()}function g(t){return!!t&&/^[0-9a-f]{8}-[0-9a-f]{4}-[4][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$/i.test(t)}function v(t,e){t.forEach(function(t){e[t]&&(e[t]=e[t].bind(e))})}function m(t,e){return-1!==t.indexOf(e,t.length-e.length)}function y(t,e,r){var n={};for(var i in t)n[i]=e.call(r||this,t[i],i,t);return n}function x(t,e,r){var n={};for(var i in t)e.call(r||this,t[i],i,t)&&(n[i]=t[i]);return n}function b(t){return Array.isArray(t)?t.map(b):\"object\"==typeof t&&t?y(t,b):t}var _={};function w(t){_[t]||(\"undefined\"!=typeof console&&console.warn(t),_[t]=!0)}function k(t,e,r){return(r.y-t.y)*(e.x-t.x)>(e.y-t.y)*(r.x-t.x)}function T(t){for(var e=0,r=0,n=t.length,i=n-1,a=void 0,o=void 0;r<n;i=r++)a=t[r],e+=((o=t[i]).x-a.x)*(a.y+o.y);return e}function A(t){var e={};if(t.replace(/(?:^|(?:\\s*\\,\\s*))([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)(?:\\=(?:([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)|(?:\\\"((?:[^\"\\\\]|\\\\.)*)\\\")))?/g,function(t,r,n,i){var a=n||i;return e[r]=!a||a.toLowerCase(),\"\"}),e[\"max-age\"]){var r=parseInt(e[\"max-age\"],10);isNaN(r)?delete e[\"max-age\"]:e[\"max-age\"]=r}return e}function M(t){try{var e=self[t];return e.setItem(\"_mapbox_test_\",1),e.removeItem(\"_mapbox_test_\"),!0}catch(t){return!1}}var S,E,C,L=self.performance&&self.performance.now?self.performance.now.bind(self.performance):Date.now.bind(Date),P=self.requestAnimationFrame||self.mozRequestAnimationFrame||self.webkitRequestAnimationFrame||self.msRequestAnimationFrame,O=self.cancelAnimationFrame||self.mozCancelAnimationFrame||self.webkitCancelAnimationFrame||self.msCancelAnimationFrame,z={now:L,frame:function(t){var e=P(t);return{cancel:function(){return O(e)}}},getImageData:function(t){var e=self.document.createElement(\"canvas\"),r=e.getContext(\"2d\");if(!r)throw new Error(\"failed to create canvas 2d context\");return e.width=t.width,e.height=t.height,r.drawImage(t,0,0,t.width,t.height),r.getImageData(0,0,t.width,t.height)},resolveURL:function(t){return S||(S=self.document.createElement(\"a\")),S.href=t,S.href},hardwareConcurrency:self.navigator.hardwareConcurrency||4,get devicePixelRatio(){return self.devicePixelRatio}},I={API_URL:\"https://api.mapbox.com\",get EVENTS_URL(){return this.API_URL?0===this.API_URL.indexOf(\"https://api.mapbox.cn\")?\"https://events.mapbox.cn/events/v2\":0===this.API_URL.indexOf(\"https://api.mapbox.com\")?\"https://events.mapbox.com/events/v2\":null:null},FEEDBACK_URL:\"https://apps.mapbox.com/feedback\",REQUIRE_ACCESS_TOKEN:!0,ACCESS_TOKEN:null,MAX_PARALLEL_IMAGE_REQUESTS:16},D={supported:!1,testSupport:function(t){!R&&C&&(F?B(t):E=t)}},R=!1,F=!1;function B(t){var e=t.createTexture();t.bindTexture(t.TEXTURE_2D,e);try{if(t.texImage2D(t.TEXTURE_2D,0,t.RGBA,t.RGBA,t.UNSIGNED_BYTE,C),t.isContextLost())return;D.supported=!0}catch(t){}t.deleteTexture(e),R=!0}self.document&&((C=self.document.createElement(\"img\")).onload=function(){E&&B(E),E=null,F=!0},C.onerror=function(){R=!0,E=null},C.src=\"data:image/webp;base64,UklGRh4AAABXRUJQVlA4TBEAAAAvAQAAAAfQ//73v/+BiOh/AAA=\");var N=\"01\",j=function(t){this._transformRequestFn=t,this._createSkuToken()};j.prototype._createSkuToken=function(){var t=function(){for(var t=\"\",e=0;e<10;e++)t+=\"0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ\"[Math.floor(62*Math.random())];return{token:[\"1\",N,t].join(\"\"),tokenExpiresAt:Date.now()+432e5}}();this._skuToken=t.token,this._skuTokenExpiresAt=t.tokenExpiresAt},j.prototype._isSkuTokenExpired=function(){return Date.now()>this._skuTokenExpiresAt},j.prototype.transformRequest=function(t,e){return this._transformRequestFn&&this._transformRequestFn(t,e)||{url:t}},j.prototype.normalizeStyleURL=function(t,e){return Y(t,e)},j.prototype.normalizeGlyphsURL=function(t,e){return W(t,e)},j.prototype.normalizeSourceURL=function(t,e){return X(t,e)},j.prototype.normalizeSpriteURL=function(t,e,r,n){return Z(t,e,r,n)},j.prototype.normalizeTileURL=function(t,e,r){return this._isSkuTokenExpired()&&this._createSkuToken(),K(t,e,r,this._skuToken)},j.prototype.canonicalizeTileURL=function(t){return Q(t)},j.prototype.canonicalizeTileset=function(t,e){return tt(t,e)};var U=\"See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\";function V(t,e){var r=rt(I.API_URL);if(t.protocol=r.protocol,t.authority=r.authority,\"/\"!==r.path&&(t.path=\"\"+r.path+t.path),!I.REQUIRE_ACCESS_TOKEN)return nt(t);if(!(e=e||I.ACCESS_TOKEN))throw new Error(\"An API access token is required to use Mapbox GL. \"+U);if(\"s\"===e[0])throw new Error(\"Use a public access token (pk.*) with Mapbox GL, not a secret access token (sk.*). \"+U);return t.params.push(\"access_token=\"+e),nt(t)}function q(t){return 0===t.indexOf(\"mapbox:\")}var H=/^((https?:)?\\/\\/)?([^\\/]+\\.)?mapbox\\.c(n|om)(\\/|\\?|$)/i;function G(t){return H.test(t)}var Y=function(t,e){if(!q(t))return t;var r=rt(t);return r.path=\"/styles/v1\"+r.path,V(r,e)},W=function(t,e){if(!q(t))return t;var r=rt(t);return r.path=\"/fonts/v1\"+r.path,V(r,e)},X=function(t,e){if(!q(t))return t;var r=rt(t);return r.path=\"/v4/\"+r.authority+\".json\",r.params.push(\"secure\"),V(r,e)},Z=function(t,e,r,n){var i=rt(t);return q(t)?(i.path=\"/styles/v1\"+i.path+\"/sprite\"+e+r,V(i,n)):(i.path+=\"\"+e+r,nt(i))},J=/(\\.(png|jpg)\\d*)(?=$)/,K=function(t,e,r,n){if(!e||!q(e))return t;var i=rt(t),a=z.devicePixelRatio>=2||512===r?\"@2x\":\"\",o=D.supported?\".webp\":\"$1\";return i.path=i.path.replace(J,\"\"+a+o),i.path=\"/v4\"+i.path,I.REQUIRE_ACCESS_TOKEN&&I.ACCESS_TOKEN&&n&&i.params.push(\"sku=\"+n),V(i)},$=/\\.[\\w]+$/,Q=function(t){var e=rt(t);if(!e.path.match(/(^\\/v4\\/)/)||!e.path.match($))return t;var r=\"mapbox://tiles/\";r+=e.path.replace(\"/v4/\",\"\");var n=e.params.filter(function(t){return!t.match(/^access_token=/)});return n.length&&(r+=\"?\"+n.join(\"&\")),r},tt=function(t,e){if(!q(e))return t.tiles||[];for(var r=[],n=0,i=t.tiles;n<i.length;n+=1){var a=i[n],o=Q(a);r.push(o)}return r},et=/^(\\w+):\\/\\/([^\\/?]*)(\\/[^?]+)?\\??(.+)?/;function rt(t){var e=t.match(et);if(!e)throw new Error(\"Unable to parse URL object\");return{protocol:e[1],authority:e[2],path:e[3]||\"/\",params:e[4]?e[4].split(\"&\"):[]}}function nt(t){var e=t.params.length?\"?\"+t.params.join(\"&\"):\"\";return t.protocol+\"://\"+t.authority+t.path+e}function it(t){if(!t)return null;var e,r=t.split(\".\");if(!r||3!==r.length)return null;try{return JSON.parse((e=r[1],decodeURIComponent(self.atob(e).split(\"\").map(function(t){return\"%\"+(\"00\"+t.charCodeAt(0).toString(16)).slice(-2)}).join(\"\"))))}catch(t){return null}}var at=function(t){this.type=t,this.anonId=null,this.eventData={},this.queue=[],this.pendingRequest=null};at.prototype.getStorageKey=function(t){var e,r=it(I.ACCESS_TOKEN),n=\"\";return r&&r.u?(e=r.u,n=self.btoa(encodeURIComponent(e).replace(/%([0-9A-F]{2})/g,function(t,e){return String.fromCharCode(Number(\"0x\"+e))}))):n=I.ACCESS_TOKEN||\"\",t?\"mapbox.eventData.\"+t+\":\"+n:\"mapbox.eventData:\"+n},at.prototype.fetchEventData=function(){var t=M(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{var n=self.localStorage.getItem(e);n&&(this.eventData=JSON.parse(n));var i=self.localStorage.getItem(r);i&&(this.anonId=i)}catch(t){w(\"Unable to read from LocalStorage\")}},at.prototype.saveEventData=function(){var t=M(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{self.localStorage.setItem(r,this.anonId),Object.keys(this.eventData).length>=1&&self.localStorage.setItem(e,JSON.stringify(this.eventData))}catch(t){w(\"Unable to write to LocalStorage\")}},at.prototype.processRequests=function(){},at.prototype.postEvent=function(t,e,r){var n=this;if(I.EVENTS_URL){var i=rt(I.EVENTS_URL);i.params.push(\"access_token=\"+(I.ACCESS_TOKEN||\"\"));var a={event:this.type,created:new Date(t).toISOString(),sdkIdentifier:\"mapbox-gl-js\",sdkVersion:\"1.1.1\",skuId:N,userId:this.anonId},o=e?h(a,e):a,s={url:nt(i),headers:{\"Content-Type\":\"text/plain\"},body:JSON.stringify([o])};this.pendingRequest=St(s,function(t){n.pendingRequest=null,r(t),n.saveEventData(),n.processRequests()})}},at.prototype.queueRequest=function(t){this.queue.push(t),this.processRequests()};var ot,st=function(t){function e(){t.call(this,\"map.load\"),this.success={},this.skuToken=\"\"}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.postMapLoadEvent=function(t,e,r){this.skuToken=r,I.EVENTS_URL&&I.ACCESS_TOKEN&&Array.isArray(t)&&t.some(function(t){return q(t)||G(t)})&&this.queueRequest({id:e,timestamp:Date.now()})},e.prototype.processRequests=function(){var t=this;if(!this.pendingRequest&&0!==this.queue.length){var e=this.queue.shift(),r=e.id,n=e.timestamp;r&&this.success[r]||(this.anonId||this.fetchEventData(),g(this.anonId)||(this.anonId=d()),this.postEvent(n,{skuToken:this.skuToken},function(e){e||r&&(t.success[r]=!0)}))}},e}(at),lt=new(function(t){function e(){t.call(this,\"appUserTurnstile\")}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.postTurnstileEvent=function(t){I.EVENTS_URL&&I.ACCESS_TOKEN&&Array.isArray(t)&&t.some(function(t){return q(t)||G(t)})&&this.queueRequest(Date.now())},e.prototype.processRequests=function(){var t=this;if(!this.pendingRequest&&0!==this.queue.length){this.anonId&&this.eventData.lastSuccess&&this.eventData.tokenU||this.fetchEventData();var e=it(I.ACCESS_TOKEN),r=e?e.u:I.ACCESS_TOKEN,n=r!==this.eventData.tokenU;g(this.anonId)||(this.anonId=d(),n=!0);var i=this.queue.shift();if(this.eventData.lastSuccess){var a=new Date(this.eventData.lastSuccess),o=new Date(i),s=(i-this.eventData.lastSuccess)/864e5;n=n||s>=1||s<-1||a.getDate()!==o.getDate()}else n=!0;if(!n)return this.processRequests();this.postEvent(i,{\"enabled.telemetry\":!1},function(e){e||(t.eventData.lastSuccess=i,t.eventData.tokenU=r)})}},e}(at)),ct=lt.postTurnstileEvent.bind(lt),ut=new st,ht=ut.postMapLoadEvent.bind(ut),ft=\"mapbox-tiles\",pt=500,dt=50,gt=42e4;function vt(t){var e=t.indexOf(\"?\");return e<0?t:t.slice(0,e)}var mt=1/0,yt={Unknown:\"Unknown\",Style:\"Style\",Source:\"Source\",Tile:\"Tile\",Glyphs:\"Glyphs\",SpriteImage:\"SpriteImage\",SpriteJSON:\"SpriteJSON\",Image:\"Image\"};\"function\"==typeof Object.freeze&&Object.freeze(yt);var xt=function(t){function e(e,r,n){401===r&&G(n)&&(e+=\": you may have provided an invalid Mapbox access token. See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\"),t.call(this,e),this.status=r,this.url=n,this.name=this.constructor.name,this.message=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.toString=function(){return this.name+\": \"+this.message+\" (\"+this.status+\"): \"+this.url},e}(Error);function bt(){return\"undefined\"!=typeof WorkerGlobalScope&&\"undefined\"!=typeof self&&self instanceof WorkerGlobalScope}var _t=bt()?function(){return self.worker&&self.worker.referrer}:function(){var t=self.location.origin;if(t&&\"null\"!==t&&\"file://\"!==t)return t+self.location.pathname};function wt(t,e){var r,n=new self.AbortController,i=new self.Request(t.url,{method:t.method||\"GET\",body:t.body,credentials:t.credentials,headers:t.headers,referrer:_t(),signal:n.signal}),a=!1,o=!1,s=(r=i.url).indexOf(\"sku=\")>0&&G(r);\"json\"===t.type&&i.headers.set(\"Accept\",\"application/json\");var l=function(r,n,a){if(!o){if(r&&\"SecurityError\"!==r.message&&w(r),n&&a)return c(n);var l=Date.now();self.fetch(i).then(function(r){if(r.ok){var n=s?r.clone():null;return c(r,n,l)}return e(new xt(r.statusText,r.status,t.url))}).catch(function(t){20!==t.code&&e(new Error(t.message))})}},c=function(r,n,s){(\"arrayBuffer\"===t.type?r.arrayBuffer():\"json\"===t.type?r.json():r.text()).then(function(t){o||(n&&s&&function(t,e,r){if(self.caches){var n={status:e.status,statusText:e.statusText,headers:new self.Headers};e.headers.forEach(function(t,e){return n.headers.set(e,t)});var i=A(e.headers.get(\"Cache-Control\")||\"\");i[\"no-store\"]||(i[\"max-age\"]&&n.headers.set(\"Expires\",new Date(r+1e3*i[\"max-age\"]).toUTCString()),new Date(n.headers.get(\"Expires\")).getTime()-r<gt||function(t,e){if(void 0===ot)try{new Response(new ReadableStream),ot=!0}catch(t){ot=!1}ot?e(t.body):t.blob().then(e)}(e,function(e){var r=new self.Response(e,n);self.caches.open(ft).then(function(e){return e.put(vt(t.url),r)})}))}}(i,n,s),a=!0,e(null,t,r.headers.get(\"Cache-Control\"),r.headers.get(\"Expires\")))}).catch(function(t){return e(new Error(t.message))})};return s?function(t,e){if(!self.caches)return e(null);var r=vt(t.url);self.caches.open(ft).catch(e).then(function(t){t.match(r).catch(e).then(function(n){var i=function(t){if(!t)return!1;var e=new Date(t.headers.get(\"Expires\")),r=A(t.headers.get(\"Cache-Control\")||\"\");return e>Date.now()&&!r[\"no-cache\"]}(n);t.delete(r),i&&t.put(r,n.clone()),e(null,n,i)})})}(i,l):l(null,null),{cancel:function(){o=!0,a||n.abort()}}}var kt,Tt,At=function(t,e){if(!/^file:/.test(t.url)){if(self.fetch&&self.Request&&self.AbortController&&self.Request.prototype.hasOwnProperty(\"signal\"))return wt(t,e);if(bt()&&self.worker&&self.worker.actor)return self.worker.actor.send(\"getResource\",t,e)}return function(t,e){var r=new self.XMLHttpRequest;for(var n in r.open(t.method||\"GET\",t.url,!0),\"arrayBuffer\"===t.type&&(r.responseType=\"arraybuffer\"),t.headers)r.setRequestHeader(n,t.headers[n]);return\"json\"===t.type&&r.setRequestHeader(\"Accept\",\"application/json\"),r.withCredentials=\"include\"===t.credentials,r.onerror=function(){e(new Error(r.statusText))},r.onload=function(){if((r.status>=200&&r.status<300||0===r.status)&&null!==r.response){var n=r.response;if(\"json\"===t.type)try{n=JSON.parse(r.response)}catch(t){return e(t)}e(null,n,r.getResponseHeader(\"Cache-Control\"),r.getResponseHeader(\"Expires\"))}else e(new xt(r.statusText,r.status,t.url))},r.send(t.body),{cancel:function(){return r.abort()}}}(t,e)},Mt=function(t,e){return At(h(t,{type:\"arrayBuffer\"}),e)},St=function(t,e){return At(h(t,{method:\"POST\"}),e)};kt=[],Tt=0;var Et=function(t,e){if(Tt>=I.MAX_PARALLEL_IMAGE_REQUESTS){var r={requestParameters:t,callback:e,cancelled:!1,cancel:function(){this.cancelled=!0}};return kt.push(r),r}Tt++;var n=!1,i=function(){if(!n)for(n=!0,Tt--;kt.length&&Tt<I.MAX_PARALLEL_IMAGE_REQUESTS;){var t=kt.shift(),e=t.requestParameters,r=t.callback;t.cancelled||(t.cancel=Et(e,r).cancel)}},a=Mt(t,function(t,r,n,a){if(i(),t)e(t);else if(r){var o=new self.Image,s=self.URL||self.webkitURL;o.onload=function(){e(null,o),s.revokeObjectURL(o.src)},o.onerror=function(){return e(new Error(\"Could not load image. Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.\"))};var l=new self.Blob([new Uint8Array(r)],{type:\"image/png\"});o.cacheControl=n,o.expires=a,o.src=r.byteLength?s.createObjectURL(l):\"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAC0lEQVQYV2NgAAIAAAUAAarVyFEAAAAASUVORK5CYII=\"}});return{cancel:function(){a.cancel(),i()}}};function Ct(t,e,r){r[t]&&-1!==r[t].indexOf(e)||(r[t]=r[t]||[],r[t].push(e))}function Lt(t,e,r){if(r&&r[t]){var n=r[t].indexOf(e);-1!==n&&r[t].splice(n,1)}}var Pt=function(t,e){void 0===e&&(e={}),h(this,e),this.type=t},Ot=function(t){function e(e,r){void 0===r&&(r={}),t.call(this,\"error\",h({error:e},r))}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Pt),zt=function(){};zt.prototype.on=function(t,e){return this._listeners=this._listeners||{},Ct(t,e,this._listeners),this},zt.prototype.off=function(t,e){return Lt(t,e,this._listeners),Lt(t,e,this._oneTimeListeners),this},zt.prototype.once=function(t,e){return this._oneTimeListeners=this._oneTimeListeners||{},Ct(t,e,this._oneTimeListeners),this},zt.prototype.fire=function(t,e){\"string\"==typeof t&&(t=new Pt(t,e||{}));var r=t.type;if(this.listens(r)){t.target=this;for(var n=0,i=this._listeners&&this._listeners[r]?this._listeners[r].slice():[];n<i.length;n+=1)i[n].call(this,t);for(var a=0,o=this._oneTimeListeners&&this._oneTimeListeners[r]?this._oneTimeListeners[r].slice():[];a<o.length;a+=1){var s=o[a];Lt(r,s,this._oneTimeListeners),s.call(this,t)}var l=this._eventedParent;l&&(h(t,\"function\"==typeof this._eventedParentData?this._eventedParentData():this._eventedParentData),l.fire(t))}else t instanceof Ot&&console.error(t.error);return this},zt.prototype.listens=function(t){return this._listeners&&this._listeners[t]&&this._listeners[t].length>0||this._oneTimeListeners&&this._oneTimeListeners[t]&&this._oneTimeListeners[t].length>0||this._eventedParent&&this._eventedParent.listens(t)},zt.prototype.setEventedParent=function(t,e){return this._eventedParent=t,this._eventedParentData=e,this};var It={$version:8,$root:{version:{required:!0,type:\"enum\",values:[8]},name:{type:\"string\"},metadata:{type:\"*\"},center:{type:\"array\",value:\"number\"},zoom:{type:\"number\"},bearing:{type:\"number\",default:0,period:360,units:\"degrees\"},pitch:{type:\"number\",default:0,units:\"degrees\"},light:{type:\"light\"},sources:{required:!0,type:\"sources\"},sprite:{type:\"string\"},glyphs:{type:\"string\"},transition:{type:\"transition\"},layers:{required:!0,type:\"array\",value:\"layer\"}},sources:{\"*\":{type:\"source\"}},source:[\"source_vector\",\"source_raster\",\"source_raster_dem\",\"source_geojson\",\"source_video\",\"source_image\"],source_vector:{type:{required:!0,type:\"enum\",values:{vector:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},attribution:{type:\"string\"},\"*\":{type:\"*\"}},source_raster:{type:{required:!0,type:\"enum\",values:{raster:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},attribution:{type:\"string\"},\"*\":{type:\"*\"}},source_raster_dem:{type:{required:!0,type:\"enum\",values:{\"raster-dem\":{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},attribution:{type:\"string\"},encoding:{type:\"enum\",values:{terrarium:{},mapbox:{}},default:\"mapbox\"},\"*\":{type:\"*\"}},source_geojson:{type:{required:!0,type:\"enum\",values:{geojson:{}}},data:{type:\"*\"},maxzoom:{type:\"number\",default:18},attribution:{type:\"string\"},buffer:{type:\"number\",default:128,maximum:512,minimum:0},tolerance:{type:\"number\",default:.375},cluster:{type:\"boolean\",default:!1},clusterRadius:{type:\"number\",default:50,minimum:0},clusterMaxZoom:{type:\"number\"},clusterProperties:{type:\"*\"},lineMetrics:{type:\"boolean\",default:!1},generateId:{type:\"boolean\",default:!1}},source_video:{type:{required:!0,type:\"enum\",values:{video:{}}},urls:{required:!0,type:\"array\",value:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},source_image:{type:{required:!0,type:\"enum\",values:{image:{}}},url:{required:!0,type:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},layer:{id:{type:\"string\",required:!0},type:{type:\"enum\",values:{fill:{},line:{},symbol:{},circle:{},heatmap:{},\"fill-extrusion\":{},raster:{},hillshade:{},background:{}},required:!0},metadata:{type:\"*\"},source:{type:\"string\"},\"source-layer\":{type:\"string\"},minzoom:{type:\"number\",minimum:0,maximum:24},maxzoom:{type:\"number\",minimum:0,maximum:24},filter:{type:\"filter\"},layout:{type:\"layout\"},paint:{type:\"paint\"}},layout:[\"layout_fill\",\"layout_line\",\"layout_circle\",\"layout_heatmap\",\"layout_fill-extrusion\",\"layout_symbol\",\"layout_raster\",\"layout_hillshade\",\"layout_background\"],layout_background:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_fill:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_circle:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_heatmap:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},\"layout_fill-extrusion\":{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_line:{\"line-cap\":{type:\"enum\",values:{butt:{},round:{},square:{}},default:\"butt\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-join\":{type:\"enum\",values:{bevel:{},round:{},miter:{}},default:\"miter\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"line-miter-limit\":{type:\"number\",default:2,requires:[{\"line-join\":\"miter\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-round-limit\":{type:\"number\",default:1.05,requires:[{\"line-join\":\"round\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_symbol:{\"symbol-placement\":{type:\"enum\",values:{point:{},line:{},\"line-center\":{}},default:\"point\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-spacing\":{type:\"number\",default:250,minimum:1,units:\"pixels\",requires:[{\"symbol-placement\":\"line\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-avoid-edges\":{type:\"boolean\",default:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"symbol-z-order\":{type:\"enum\",values:{auto:{},\"viewport-y\":{},source:{}},default:\"auto\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-optional\":{type:\"boolean\",default:!1,requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-size\":{type:\"number\",default:1,minimum:0,units:\"factor of the original icon size\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-text-fit\":{type:\"enum\",values:{none:{},width:{},height:{},both:{}},default:\"none\",requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-text-fit-padding\":{type:\"array\",value:\"number\",length:4,default:[0,0,0,0],units:\"pixels\",requires:[\"icon-image\",\"text-field\",{\"icon-text-fit\":[\"both\",\"width\",\"height\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-image\":{type:\"string\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-keep-upright\":{type:\"boolean\",default:!1,requires:[\"icon-image\",{\"icon-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-offset\":{type:\"array\",value:\"number\",length:2,default:[0,0],requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-anchor\":{type:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-field\":{type:\"formatted\",default:\"\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-font\":{type:\"array\",value:\"string\",default:[\"Open Sans Regular\",\"Arial Unicode MS Regular\"],requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-size\":{type:\"number\",default:16,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-width\":{type:\"number\",default:10,minimum:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-line-height\":{type:\"number\",default:1.2,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-letter-spacing\":{type:\"number\",default:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-justify\":{type:\"enum\",values:{auto:{},left:{},center:{},right:{}},default:\"center\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-radial-offset\":{type:\"number\",units:\"ems\",default:0,requires:[{\"!\":\"text-offset\"}],\"property-type\":\"data-driven\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]}},\"text-variable-anchor\":{type:\"array\",value:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},requires:[{\"!\":\"text-anchor\"},{\"!\":\"text-offset\"},{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-anchor\":{type:\"enum\",requires:[\"text-field\"],values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-angle\":{type:\"number\",default:45,units:\"degrees\",requires:[\"text-field\",{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-keep-upright\":{type:\"boolean\",default:!0,requires:[\"text-field\",{\"text-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-transform\":{type:\"enum\",values:{none:{},uppercase:{},lowercase:{}},default:\"none\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-offset\":{type:\"array\",value:\"number\",units:\"ems\",length:2,default:[0,0],requires:[\"text-field\",{\"!\":\"text-radial-offset\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-optional\":{type:\"boolean\",default:!1,requires:[\"text-field\",\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_raster:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_hillshade:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},filter:{type:\"array\",value:\"*\"},filter_operator:{type:\"enum\",values:{\"==\":{},\"!=\":{},\">\":{},\">=\":{},\"<\":{},\"<=\":{},in:{},\"!in\":{},all:{},any:{},none:{},has:{},\"!has\":{}}},geometry_type:{type:\"enum\",values:{Point:{},LineString:{},Polygon:{}}},function:{expression:{type:\"expression\"},stops:{type:\"array\",value:\"function_stop\"},base:{type:\"number\",default:1,minimum:0},property:{type:\"string\",default:\"$zoom\"},type:{type:\"enum\",values:{identity:{},exponential:{},interval:{},categorical:{}},default:\"exponential\"},colorSpace:{type:\"enum\",values:{rgb:{},lab:{},hcl:{}},default:\"rgb\"},default:{type:\"*\",required:!1}},function_stop:{type:\"array\",minimum:0,maximum:22,value:[\"number\",\"color\"],length:2},expression:{type:\"array\",value:\"*\",minimum:1},expression_name:{type:\"enum\",values:{let:{group:\"Variable binding\"},var:{group:\"Variable binding\"},literal:{group:\"Types\"},array:{group:\"Types\"},at:{group:\"Lookup\"},case:{group:\"Decision\"},match:{group:\"Decision\"},coalesce:{group:\"Decision\"},step:{group:\"Ramps, scales, curves\"},interpolate:{group:\"Ramps, scales, curves\"},\"interpolate-hcl\":{group:\"Ramps, scales, curves\"},\"interpolate-lab\":{group:\"Ramps, scales, curves\"},ln2:{group:\"Math\"},pi:{group:\"Math\"},e:{group:\"Math\"},typeof:{group:\"Types\"},string:{group:\"Types\"},number:{group:\"Types\"},boolean:{group:\"Types\"},object:{group:\"Types\"},collator:{group:\"Types\"},format:{group:\"Types\"},\"number-format\":{group:\"Types\"},\"to-string\":{group:\"Types\"},\"to-number\":{group:\"Types\"},\"to-boolean\":{group:\"Types\"},\"to-rgba\":{group:\"Color\"},\"to-color\":{group:\"Types\"},rgb:{group:\"Color\"},rgba:{group:\"Color\"},get:{group:\"Lookup\"},has:{group:\"Lookup\"},length:{group:\"Lookup\"},properties:{group:\"Feature data\"},\"feature-state\":{group:\"Feature data\"},\"geometry-type\":{group:\"Feature data\"},id:{group:\"Feature data\"},zoom:{group:\"Zoom\"},\"heatmap-density\":{group:\"Heatmap\"},\"line-progress\":{group:\"Feature data\"},accumulated:{group:\"Feature data\"},\"+\":{group:\"Math\"},\"*\":{group:\"Math\"},\"-\":{group:\"Math\"},\"/\":{group:\"Math\"},\"%\":{group:\"Math\"},\"^\":{group:\"Math\"},sqrt:{group:\"Math\"},log10:{group:\"Math\"},ln:{group:\"Math\"},log2:{group:\"Math\"},sin:{group:\"Math\"},cos:{group:\"Math\"},tan:{group:\"Math\"},asin:{group:\"Math\"},acos:{group:\"Math\"},atan:{group:\"Math\"},min:{group:\"Math\"},max:{group:\"Math\"},round:{group:\"Math\"},abs:{group:\"Math\"},ceil:{group:\"Math\"},floor:{group:\"Math\"},\"==\":{group:\"Decision\"},\"!=\":{group:\"Decision\"},\">\":{group:\"Decision\"},\"<\":{group:\"Decision\"},\">=\":{group:\"Decision\"},\"<=\":{group:\"Decision\"},all:{group:\"Decision\"},any:{group:\"Decision\"},\"!\":{group:\"Decision\"},\"is-supported-script\":{group:\"String\"},upcase:{group:\"String\"},downcase:{group:\"String\"},concat:{group:\"String\"},\"resolved-locale\":{group:\"String\"}}},light:{anchor:{type:\"enum\",default:\"viewport\",values:{map:{},viewport:{}},\"property-type\":\"data-constant\",transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]}},position:{type:\"array\",default:[1.15,210,30],length:3,value:\"number\",\"property-type\":\"data-constant\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]}},color:{type:\"color\",\"property-type\":\"data-constant\",default:\"#ffffff\",expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0},intensity:{type:\"number\",\"property-type\":\"data-constant\",default:.5,minimum:0,maximum:1,expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0}},paint:[\"paint_fill\",\"paint_line\",\"paint_circle\",\"paint_heatmap\",\"paint_fill-extrusion\",\"paint_symbol\",\"paint_raster\",\"paint_hillshade\",\"paint_background\"],paint_fill:{\"fill-antialias\":{type:\"boolean\",default:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-outline-color\":{type:\"color\",transition:!0,requires:[{\"!\":\"fill-pattern\"},{\"fill-antialias\":!0}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"}},\"paint_fill-extrusion\":{\"fill-extrusion-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-extrusion-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-extrusion-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"fill-extrusion-height\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-base\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,requires:[\"fill-extrusion-height\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-vertical-gradient\":{type:\"boolean\",default:!0,transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_line:{\"line-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"line-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-width\":{type:\"number\",default:1,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-gap-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-offset\":{type:\"number\",default:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-dasharray\":{type:\"array\",value:\"number\",minimum:0,transition:!0,units:\"line widths\",requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"line-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"line-gradient\":{type:\"color\",transition:!1,requires:[{\"!\":\"line-dasharray\"},{\"!\":\"line-pattern\"},{source:\"geojson\",has:{lineMetrics:!0}}],expression:{interpolated:!0,parameters:[\"line-progress\"]},\"property-type\":\"color-ramp\"}},paint_circle:{\"circle-radius\":{type:\"number\",default:5,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-blur\":{type:\"number\",default:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"circle-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-scale\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-stroke-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"}},paint_heatmap:{\"heatmap-radius\":{type:\"number\",default:30,minimum:1,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-weight\":{type:\"number\",default:1,minimum:0,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-intensity\":{type:\"number\",default:1,minimum:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"heatmap-color\":{type:\"color\",default:[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,\"rgba(0, 0, 255, 0)\",.1,\"royalblue\",.3,\"cyan\",.5,\"lime\",.7,\"yellow\",1,\"red\"],transition:!1,expression:{interpolated:!0,parameters:[\"heatmap-density\"]},\"property-type\":\"color-ramp\"},\"heatmap-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_symbol:{\"icon-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"icon-image\",\"icon-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"text-field\",\"text-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_raster:{\"raster-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-hue-rotate\":{type:\"number\",default:0,period:360,transition:!0,units:\"degrees\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-min\":{type:\"number\",default:0,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-max\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-saturation\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-contrast\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-resampling\":{type:\"enum\",values:{linear:{},nearest:{}},default:\"linear\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-fade-duration\":{type:\"number\",default:300,minimum:0,transition:!1,units:\"milliseconds\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_hillshade:{\"hillshade-illumination-direction\":{type:\"number\",default:335,minimum:0,maximum:359,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-illumination-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-exaggeration\":{type:\"number\",default:.5,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-shadow-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-highlight-color\":{type:\"color\",default:\"#FFFFFF\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-accent-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_background:{\"background-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"background-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"background-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"background-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},transition:{duration:{type:\"number\",default:300,minimum:0,units:\"milliseconds\"},delay:{type:\"number\",default:0,minimum:0,units:\"milliseconds\"}},\"property-type\":{\"data-driven\":{type:\"property-type\"},\"cross-faded\":{type:\"property-type\"},\"cross-faded-data-driven\":{type:\"property-type\"},\"color-ramp\":{type:\"property-type\"},\"data-constant\":{type:\"property-type\"},constant:{type:\"property-type\"}}},Dt=function(t,e,r,n){this.message=(t?t+\": \":\"\")+r,n&&(this.identifier=n),null!=e&&e.__line__&&(this.line=e.__line__)};function Rt(t){var e=t.key,r=t.value;return r?[new Dt(e,r,\"constants have been deprecated as of v8\")]:[]}function Ft(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}function Bt(t){return t instanceof Number||t instanceof String||t instanceof Boolean}function Nt(t){return Bt(t)?t.valueOf():t}function jt(t){if(Array.isArray(t))return t.map(jt);if(t instanceof Object&&!Bt(t)){var e={};for(var r in t)e[r]=jt(t[r]);return e}return Nt(t)}var Ut=function(t){function e(e,r){t.call(this,r),this.message=r,this.key=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Error),Vt=function(t,e){void 0===e&&(e=[]),this.parent=t,this.bindings={};for(var r=0,n=e;r<n.length;r+=1){var i=n[r],a=i[0],o=i[1];this.bindings[a]=o}};Vt.prototype.concat=function(t){return new Vt(this,t)},Vt.prototype.get=function(t){if(this.bindings[t])return this.bindings[t];if(this.parent)return this.parent.get(t);throw new Error(t+\" not found in scope.\")},Vt.prototype.has=function(t){return!!this.bindings[t]||!!this.parent&&this.parent.has(t)};var qt={kind:\"null\"},Ht={kind:\"number\"},Gt={kind:\"string\"},Yt={kind:\"boolean\"},Wt={kind:\"color\"},Xt={kind:\"object\"},Zt={kind:\"value\"},Jt={kind:\"collator\"},Kt={kind:\"formatted\"};function $t(t,e){return{kind:\"array\",itemType:t,N:e}}function Qt(t){if(\"array\"===t.kind){var e=Qt(t.itemType);return\"number\"==typeof t.N?\"array<\"+e+\", \"+t.N+\">\":\"value\"===t.itemType.kind?\"array\":\"array<\"+e+\">\"}return t.kind}var te=[qt,Ht,Gt,Yt,Wt,Kt,Xt,$t(Zt)];function ee(t,e){if(\"error\"===e.kind)return null;if(\"array\"===t.kind){if(\"array\"===e.kind&&(0===e.N&&\"value\"===e.itemType.kind||!ee(t.itemType,e.itemType))&&(\"number\"!=typeof t.N||t.N===e.N))return null}else{if(t.kind===e.kind)return null;if(\"value\"===t.kind)for(var r=0,n=te;r<n.length;r+=1)if(!ee(n[r],e))return null}return\"Expected \"+Qt(t)+\" but found \"+Qt(e)+\" instead.\"}var re=e(function(t,e){var r={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],rebeccapurple:[102,51,153,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function n(t){return(t=Math.round(t))<0?0:t>255?255:t}function i(t){return t<0?0:t>1?1:t}function a(t){return\"%\"===t[t.length-1]?n(parseFloat(t)/100*255):n(parseInt(t))}function o(t){return\"%\"===t[t.length-1]?i(parseFloat(t)/100):i(parseFloat(t))}function s(t,e,r){return r<0?r+=1:r>1&&(r-=1),6*r<1?t+(e-t)*r*6:2*r<1?e:3*r<2?t+(e-t)*(2/3-r)*6:t}try{e.parseCSSColor=function(t){var e,i=t.replace(/ /g,\"\").toLowerCase();if(i in r)return r[i].slice();if(\"#\"===i[0])return 4===i.length?(e=parseInt(i.substr(1),16))>=0&&e<=4095?[(3840&e)>>4|(3840&e)>>8,240&e|(240&e)>>4,15&e|(15&e)<<4,1]:null:7===i.length&&(e=parseInt(i.substr(1),16))>=0&&e<=16777215?[(16711680&e)>>16,(65280&e)>>8,255&e,1]:null;var l=i.indexOf(\"(\"),c=i.indexOf(\")\");if(-1!==l&&c+1===i.length){var u=i.substr(0,l),h=i.substr(l+1,c-(l+1)).split(\",\"),f=1;switch(u){case\"rgba\":if(4!==h.length)return null;f=o(h.pop());case\"rgb\":return 3!==h.length?null:[a(h[0]),a(h[1]),a(h[2]),f];case\"hsla\":if(4!==h.length)return null;f=o(h.pop());case\"hsl\":if(3!==h.length)return null;var p=(parseFloat(h[0])%360+360)%360/360,d=o(h[1]),g=o(h[2]),v=g<=.5?g*(d+1):g+d-g*d,m=2*g-v;return[n(255*s(m,v,p+1/3)),n(255*s(m,v,p)),n(255*s(m,v,p-1/3)),f];default:return null}}return null}}catch(t){}}).parseCSSColor,ne=function(t,e,r,n){void 0===n&&(n=1),this.r=t,this.g=e,this.b=r,this.a=n};ne.parse=function(t){if(t){if(t instanceof ne)return t;if(\"string\"==typeof t){var e=re(t);if(e)return new ne(e[0]/255*e[3],e[1]/255*e[3],e[2]/255*e[3],e[3])}}},ne.prototype.toString=function(){var t=this.toArray(),e=t[0],r=t[1],n=t[2],i=t[3];return\"rgba(\"+Math.round(e)+\",\"+Math.round(r)+\",\"+Math.round(n)+\",\"+i+\")\"},ne.prototype.toArray=function(){var t=this.r,e=this.g,r=this.b,n=this.a;return 0===n?[0,0,0,0]:[255*t/n,255*e/n,255*r/n,n]},ne.black=new ne(0,0,0,1),ne.white=new ne(1,1,1,1),ne.transparent=new ne(0,0,0,0),ne.red=new ne(1,0,0,1);var ie=function(t,e,r){this.sensitivity=t?e?\"variant\":\"case\":e?\"accent\":\"base\",this.locale=r,this.collator=new Intl.Collator(this.locale?this.locale:[],{sensitivity:this.sensitivity,usage:\"search\"})};ie.prototype.compare=function(t,e){return this.collator.compare(t,e)},ie.prototype.resolvedLocale=function(){return new Intl.Collator(this.locale?this.locale:[]).resolvedOptions().locale};var ae=function(t,e,r){this.text=t,this.scale=e,this.fontStack=r},oe=function(t){this.sections=t};function se(t,e,r,n){return\"number\"==typeof t&&t>=0&&t<=255&&\"number\"==typeof e&&e>=0&&e<=255&&\"number\"==typeof r&&r>=0&&r<=255?void 0===n||\"number\"==typeof n&&n>=0&&n<=1?null:\"Invalid rgba value [\"+[t,e,r,n].join(\", \")+\"]: 'a' must be between 0 and 1.\":\"Invalid rgba value [\"+(\"number\"==typeof n?[t,e,r,n]:[t,e,r]).join(\", \")+\"]: 'r', 'g', and 'b' must be between 0 and 255.\"}function le(t){if(null===t)return qt;if(\"string\"==typeof t)return Gt;if(\"boolean\"==typeof t)return Yt;if(\"number\"==typeof t)return Ht;if(t instanceof ne)return Wt;if(t instanceof ie)return Jt;if(t instanceof oe)return Kt;if(Array.isArray(t)){for(var e,r=t.length,n=0,i=t;n<i.length;n+=1){var a=le(i[n]);if(e){if(e===a)continue;e=Zt;break}e=a}return $t(e||Zt,r)}return Xt}function ce(t){var e=typeof t;return null===t?\"\":\"string\"===e||\"number\"===e||\"boolean\"===e?String(t):t instanceof ne||t instanceof oe?t.toString():JSON.stringify(t)}oe.fromString=function(t){return new oe([new ae(t,null,null)])},oe.prototype.toString=function(){return this.sections.map(function(t){return t.text}).join(\"\")},oe.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.text);var i={};n.fontStack&&(i[\"text-font\"]=[\"literal\",n.fontStack.split(\",\")]),n.scale&&(i[\"font-scale\"]=n.scale),t.push(i)}return t};var ue=function(t,e){this.type=t,this.value=e};ue.parse=function(t,e){if(2!==t.length)return e.error(\"'literal' expression requires exactly one argument, but found \"+(t.length-1)+\" instead.\");if(!function t(e){if(null===e)return!0;if(\"string\"==typeof e)return!0;if(\"boolean\"==typeof e)return!0;if(\"number\"==typeof e)return!0;if(e instanceof ne)return!0;if(e instanceof ie)return!0;if(e instanceof oe)return!0;if(Array.isArray(e)){for(var r=0,n=e;r<n.length;r+=1)if(!t(n[r]))return!1;return!0}if(\"object\"==typeof e){for(var i in e)if(!t(e[i]))return!1;return!0}return!1}(t[1]))return e.error(\"invalid value\");var r=t[1],n=le(r),i=e.expectedType;return\"array\"!==n.kind||0!==n.N||!i||\"array\"!==i.kind||\"number\"==typeof i.N&&0!==i.N||(n=i),new ue(n,r)},ue.prototype.evaluate=function(){return this.value},ue.prototype.eachChild=function(){},ue.prototype.possibleOutputs=function(){return[this.value]},ue.prototype.serialize=function(){return\"array\"===this.type.kind||\"object\"===this.type.kind?[\"literal\",this.value]:this.value instanceof ne?[\"rgba\"].concat(this.value.toArray()):this.value instanceof oe?this.value.serialize():this.value};var he=function(t){this.name=\"ExpressionEvaluationError\",this.message=t};he.prototype.toJSON=function(){return this.message};var fe={string:Gt,number:Ht,boolean:Yt,object:Xt},pe=function(t,e){this.type=t,this.args=e};pe.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r,n=1,i=t[0];if(\"array\"===i){var a,o;if(t.length>2){var s=t[1];if(\"string\"!=typeof s||!(s in fe)||\"object\"===s)return e.error('The item type argument of \"array\" must be one of string, number, boolean',1);a=fe[s],n++}else a=Zt;if(t.length>3){if(null!==t[2]&&(\"number\"!=typeof t[2]||t[2]<0||t[2]!==Math.floor(t[2])))return e.error('The length argument to \"array\" must be a positive integer literal',2);o=t[2],n++}r=$t(a,o)}else r=fe[i];for(var l=[];n<t.length;n++){var c=e.parse(t[n],n,Zt);if(!c)return null;l.push(c)}return new pe(r,l)},pe.prototype.evaluate=function(t){for(var e=0;e<this.args.length;e++){var r=this.args[e].evaluate(t);if(!ee(this.type,le(r)))return r;if(e===this.args.length-1)throw new he(\"Expected value to be of type \"+Qt(this.type)+\", but found \"+Qt(le(r))+\" instead.\")}return null},pe.prototype.eachChild=function(t){this.args.forEach(t)},pe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},pe.prototype.serialize=function(){var t=this.type,e=[t.kind];if(\"array\"===t.kind){var r=t.itemType;if(\"string\"===r.kind||\"number\"===r.kind||\"boolean\"===r.kind){e.push(r.kind);var n=t.N;(\"number\"==typeof n||this.args.length>1)&&e.push(n)}}return e.concat(this.args.map(function(t){return t.serialize()}))};var de=function(t){this.type=Kt,this.sections=t};de.parse=function(t,e){if(t.length<3)return e.error(\"Expected at least two arguments.\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");for(var r=[],n=1;n<t.length-1;n+=2){var i=e.parse(t[n],1,Zt);if(!i)return null;var a=i.type.kind;if(\"string\"!==a&&\"value\"!==a&&\"null\"!==a)return e.error(\"Formatted text type must be 'string', 'value', or 'null'.\");var o=t[n+1];if(\"object\"!=typeof o||Array.isArray(o))return e.error(\"Format options argument must be an object.\");var s=null;if(o[\"font-scale\"]&&!(s=e.parse(o[\"font-scale\"],1,Ht)))return null;var l=null;if(o[\"text-font\"]&&!(l=e.parse(o[\"text-font\"],1,$t(Gt))))return null;r.push({text:i,scale:s,font:l})}return new de(r)},de.prototype.evaluate=function(t){return new oe(this.sections.map(function(e){return new ae(ce(e.text.evaluate(t)),e.scale?e.scale.evaluate(t):null,e.font?e.font.evaluate(t).join(\",\"):null)}))},de.prototype.eachChild=function(t){for(var e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t(n.text),n.scale&&t(n.scale),n.font&&t(n.font)}},de.prototype.possibleOutputs=function(){return[void 0]},de.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.text.serialize());var i={};n.scale&&(i[\"font-scale\"]=n.scale.serialize()),n.font&&(i[\"text-font\"]=n.font.serialize()),t.push(i)}return t};var ge={\"to-boolean\":Yt,\"to-color\":Wt,\"to-number\":Ht,\"to-string\":Gt},ve=function(t,e){this.type=t,this.args=e};ve.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r=t[0];if((\"to-boolean\"===r||\"to-string\"===r)&&2!==t.length)return e.error(\"Expected one argument.\");for(var n=ge[r],i=[],a=1;a<t.length;a++){var o=e.parse(t[a],a,Zt);if(!o)return null;i.push(o)}return new ve(n,i)},ve.prototype.evaluate=function(t){if(\"boolean\"===this.type.kind)return Boolean(this.args[0].evaluate(t));if(\"color\"===this.type.kind){for(var e,r,n=0,i=this.args;n<i.length;n+=1){if(r=null,(e=i[n].evaluate(t))instanceof ne)return e;if(\"string\"==typeof e){var a=t.parseColor(e);if(a)return a}else if(Array.isArray(e)&&!(r=e.length<3||e.length>4?\"Invalid rbga value \"+JSON.stringify(e)+\": expected an array containing either three or four numeric values.\":se(e[0],e[1],e[2],e[3])))return new ne(e[0]/255,e[1]/255,e[2]/255,e[3])}throw new he(r||\"Could not parse color from value '\"+(\"string\"==typeof e?e:String(JSON.stringify(e)))+\"'\")}if(\"number\"===this.type.kind){for(var o=null,s=0,l=this.args;s<l.length;s+=1){if(null===(o=l[s].evaluate(t)))return 0;var c=Number(o);if(!isNaN(c))return c}throw new he(\"Could not convert \"+JSON.stringify(o)+\" to number.\")}return\"formatted\"===this.type.kind?oe.fromString(ce(this.args[0].evaluate(t))):ce(this.args[0].evaluate(t))},ve.prototype.eachChild=function(t){this.args.forEach(t)},ve.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},ve.prototype.serialize=function(){if(\"formatted\"===this.type.kind)return new de([{text:this.args[0],scale:null,font:null}]).serialize();var t=[\"to-\"+this.type.kind];return this.eachChild(function(e){t.push(e.serialize())}),t};var me=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],ye=function(){this.globals=null,this.feature=null,this.featureState=null,this._parseColorCache={}};ye.prototype.id=function(){return this.feature&&\"id\"in this.feature?this.feature.id:null},ye.prototype.geometryType=function(){return this.feature?\"number\"==typeof this.feature.type?me[this.feature.type]:this.feature.type:null},ye.prototype.properties=function(){return this.feature&&this.feature.properties||{}},ye.prototype.parseColor=function(t){var e=this._parseColorCache[t];return e||(e=this._parseColorCache[t]=ne.parse(t)),e};var xe=function(t,e,r,n){this.name=t,this.type=e,this._evaluate=r,this.args=n};xe.prototype.evaluate=function(t){return this._evaluate(t,this.args)},xe.prototype.eachChild=function(t){this.args.forEach(t)},xe.prototype.possibleOutputs=function(){return[void 0]},xe.prototype.serialize=function(){return[this.name].concat(this.args.map(function(t){return t.serialize()}))},xe.parse=function(t,e){var r,n=t[0],i=xe.definitions[n];if(!i)return e.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0);for(var a=Array.isArray(i)?i[0]:i.type,o=Array.isArray(i)?[[i[1],i[2]]]:i.overloads,s=o.filter(function(e){var r=e[0];return!Array.isArray(r)||r.length===t.length-1}),l=null,c=0,u=s;c<u.length;c+=1){var h=u[c],f=h[0],p=h[1];l=new Ae(e.registry,e.path,null,e.scope);for(var d=[],g=!1,v=1;v<t.length;v++){var m=t[v],y=Array.isArray(f)?f[v-1]:f.type,x=l.parse(m,1+d.length,y);if(!x){g=!0;break}d.push(x)}if(!g)if(Array.isArray(f)&&f.length!==d.length)l.error(\"Expected \"+f.length+\" arguments, but found \"+d.length+\" instead.\");else{for(var b=0;b<d.length;b++){var _=Array.isArray(f)?f[b]:f.type,w=d[b];l.concat(b+1).checkSubtype(_,w.type)}if(0===l.errors.length)return new xe(n,a,p,d)}}if(1===s.length)(r=e.errors).push.apply(r,l.errors);else{for(var k=(s.length?s:o).map(function(t){var e;return e=t[0],Array.isArray(e)?\"(\"+e.map(Qt).join(\", \")+\")\":\"(\"+Qt(e.type)+\"...)\"}).join(\" | \"),T=[],A=1;A<t.length;A++){var M=e.parse(t[A],1+T.length);if(!M)return null;T.push(Qt(M.type))}e.error(\"Expected arguments of type \"+k+\", but found (\"+T.join(\", \")+\") instead.\")}return null},xe.register=function(t,e){for(var r in xe.definitions=e,e)t[r]=xe};var be=function(t,e,r){this.type=Jt,this.locale=r,this.caseSensitive=t,this.diacriticSensitive=e};function _e(t){if(t instanceof xe){if(\"get\"===t.name&&1===t.args.length)return!1;if(\"feature-state\"===t.name)return!1;if(\"has\"===t.name&&1===t.args.length)return!1;if(\"properties\"===t.name||\"geometry-type\"===t.name||\"id\"===t.name)return!1;if(/^filter-/.test(t.name))return!1}var e=!0;return t.eachChild(function(t){e&&!_e(t)&&(e=!1)}),e}function we(t){if(t instanceof xe&&\"feature-state\"===t.name)return!1;var e=!0;return t.eachChild(function(t){e&&!we(t)&&(e=!1)}),e}function ke(t,e){if(t instanceof xe&&e.indexOf(t.name)>=0)return!1;var r=!0;return t.eachChild(function(t){r&&!ke(t,e)&&(r=!1)}),r}be.parse=function(t,e){if(2!==t.length)return e.error(\"Expected one argument.\");var r=t[1];if(\"object\"!=typeof r||Array.isArray(r))return e.error(\"Collator options argument must be an object.\");var n=e.parse(void 0!==r[\"case-sensitive\"]&&r[\"case-sensitive\"],1,Yt);if(!n)return null;var i=e.parse(void 0!==r[\"diacritic-sensitive\"]&&r[\"diacritic-sensitive\"],1,Yt);if(!i)return null;var a=null;return r.locale&&!(a=e.parse(r.locale,1,Gt))?null:new be(n,i,a)},be.prototype.evaluate=function(t){return new ie(this.caseSensitive.evaluate(t),this.diacriticSensitive.evaluate(t),this.locale?this.locale.evaluate(t):null)},be.prototype.eachChild=function(t){t(this.caseSensitive),t(this.diacriticSensitive),this.locale&&t(this.locale)},be.prototype.possibleOutputs=function(){return[void 0]},be.prototype.serialize=function(){var t={};return t[\"case-sensitive\"]=this.caseSensitive.serialize(),t[\"diacritic-sensitive\"]=this.diacriticSensitive.serialize(),this.locale&&(t.locale=this.locale.serialize()),[\"collator\",t]};var Te=function(t,e){this.type=e.type,this.name=t,this.boundExpression=e};Te.parse=function(t,e){if(2!==t.length||\"string\"!=typeof t[1])return e.error(\"'var' expression requires exactly one string literal argument.\");var r=t[1];return e.scope.has(r)?new Te(r,e.scope.get(r)):e.error('Unknown variable \"'+r+'\". Make sure \"'+r+'\" has been bound in an enclosing \"let\" expression before using it.',1)},Te.prototype.evaluate=function(t){return this.boundExpression.evaluate(t)},Te.prototype.eachChild=function(){},Te.prototype.possibleOutputs=function(){return[void 0]},Te.prototype.serialize=function(){return[\"var\",this.name]};var Ae=function(t,e,r,n,i){void 0===e&&(e=[]),void 0===n&&(n=new Vt),void 0===i&&(i=[]),this.registry=t,this.path=e,this.key=e.map(function(t){return\"[\"+t+\"]\"}).join(\"\"),this.scope=n,this.errors=i,this.expectedType=r};function Me(t,e){for(var r,n,i=t.length-1,a=0,o=i,s=0;a<=o;)if(r=t[s=Math.floor((a+o)/2)],n=t[s+1],r<=e){if(s===i||e<n)return s;a=s+1}else{if(!(r>e))throw new he(\"Input is not a number.\");o=s-1}return 0}Ae.prototype.parse=function(t,e,r,n,i){return void 0===i&&(i={}),e?this.concat(e,r,n)._parse(t,i):this._parse(t,i)},Ae.prototype._parse=function(t,e){function r(t,e,r){return\"assert\"===r?new pe(e,[t]):\"coerce\"===r?new ve(e,[t]):t}if(null!==t&&\"string\"!=typeof t&&\"boolean\"!=typeof t&&\"number\"!=typeof t||(t=[\"literal\",t]),Array.isArray(t)){if(0===t.length)return this.error('Expected an array with at least one element. If you wanted a literal array, use [\"literal\", []].');var n=t[0];if(\"string\"!=typeof n)return this.error(\"Expression name must be a string, but found \"+typeof n+' instead. If you wanted a literal array, use [\"literal\", [...]].',0),null;var i=this.registry[n];if(i){var a=i.parse(t,this);if(!a)return null;if(this.expectedType){var o=this.expectedType,s=a.type;if(\"string\"!==o.kind&&\"number\"!==o.kind&&\"boolean\"!==o.kind&&\"object\"!==o.kind&&\"array\"!==o.kind||\"value\"!==s.kind)if(\"color\"!==o.kind&&\"formatted\"!==o.kind||\"value\"!==s.kind&&\"string\"!==s.kind){if(this.checkSubtype(o,s))return null}else a=r(a,o,e.typeAnnotation||\"coerce\");else a=r(a,o,e.typeAnnotation||\"assert\")}if(!(a instanceof ue)&&function t(e){if(e instanceof Te)return t(e.boundExpression);if(e instanceof xe&&\"error\"===e.name)return!1;if(e instanceof be)return!1;var r=e instanceof ve||e instanceof pe,n=!0;return e.eachChild(function(e){n=r?n&&t(e):n&&e instanceof ue}),!!n&&(_e(e)&&ke(e,[\"zoom\",\"heatmap-density\",\"line-progress\",\"accumulated\",\"is-supported-script\"]))}(a)){var l=new ye;try{a=new ue(a.type,a.evaluate(l))}catch(t){return this.error(t.message),null}}return a}return this.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0)}return void 0===t?this.error(\"'undefined' value invalid. Use null instead.\"):\"object\"==typeof t?this.error('Bare objects invalid. Use [\"literal\", {...}] instead.'):this.error(\"Expected an array, but found \"+typeof t+\" instead.\")},Ae.prototype.concat=function(t,e,r){var n=\"number\"==typeof t?this.path.concat(t):this.path,i=r?this.scope.concat(r):this.scope;return new Ae(this.registry,n,e||null,i,this.errors)},Ae.prototype.error=function(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];var n=\"\"+this.key+e.map(function(t){return\"[\"+t+\"]\"}).join(\"\");this.errors.push(new Ut(n,t))},Ae.prototype.checkSubtype=function(t,e){var r=ee(t,e);return r&&this.error(r),r};var Se=function(t,e,r){this.type=t,this.input=e,this.labels=[],this.outputs=[];for(var n=0,i=r;n<i.length;n+=1){var a=i[n],o=a[0],s=a[1];this.labels.push(o),this.outputs.push(s)}};function Ee(t,e,r){return t*(1-r)+e*r}Se.parse=function(t,e){if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");var r=e.parse(t[1],1,Ht);if(!r)return null;var n=[],i=null;e.expectedType&&\"value\"!==e.expectedType.kind&&(i=e.expectedType);for(var a=1;a<t.length;a+=2){var o=1===a?-1/0:t[a],s=t[a+1],l=a,c=a+1;if(\"number\"!=typeof o)return e.error('Input/output pairs for \"step\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',l);if(n.length&&n[n.length-1][0]>=o)return e.error('Input/output pairs for \"step\" expressions must be arranged with input values in strictly ascending order.',l);var u=e.parse(s,c,i);if(!u)return null;i=i||u.type,n.push([o,u])}return new Se(i,r,n)},Se.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;return n>=e[i-1]?r[i-1].evaluate(t):r[Me(e,n)].evaluate(t)},Se.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},Se.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()}))},Se.prototype.serialize=function(){for(var t=[\"step\",this.input.serialize()],e=0;e<this.labels.length;e++)e>0&&t.push(this.labels[e]),t.push(this.outputs[e].serialize());return t};var Ce=Object.freeze({number:Ee,color:function(t,e,r){return new ne(Ee(t.r,e.r,r),Ee(t.g,e.g,r),Ee(t.b,e.b,r),Ee(t.a,e.a,r))},array:function(t,e,r){return t.map(function(t,n){return Ee(t,e[n],r)})}}),Le=.95047,Pe=1,Oe=1.08883,ze=4/29,Ie=6/29,De=3*Ie*Ie,Re=Ie*Ie*Ie,Fe=Math.PI/180,Be=180/Math.PI;function Ne(t){return t>Re?Math.pow(t,1/3):t/De+ze}function je(t){return t>Ie?t*t*t:De*(t-ze)}function Ue(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function Ve(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function qe(t){var e=Ve(t.r),r=Ve(t.g),n=Ve(t.b),i=Ne((.4124564*e+.3575761*r+.1804375*n)/Le),a=Ne((.2126729*e+.7151522*r+.072175*n)/Pe);return{l:116*a-16,a:500*(i-a),b:200*(a-Ne((.0193339*e+.119192*r+.9503041*n)/Oe)),alpha:t.a}}function He(t){var e=(t.l+16)/116,r=isNaN(t.a)?e:e+t.a/500,n=isNaN(t.b)?e:e-t.b/200;return e=Pe*je(e),r=Le*je(r),n=Oe*je(n),new ne(Ue(3.2404542*r-1.5371385*e-.4985314*n),Ue(-.969266*r+1.8760108*e+.041556*n),Ue(.0556434*r-.2040259*e+1.0572252*n),t.alpha)}var Ge={forward:qe,reverse:He,interpolate:function(t,e,r){return{l:Ee(t.l,e.l,r),a:Ee(t.a,e.a,r),b:Ee(t.b,e.b,r),alpha:Ee(t.alpha,e.alpha,r)}}},Ye={forward:function(t){var e=qe(t),r=e.l,n=e.a,i=e.b,a=Math.atan2(i,n)*Be;return{h:a<0?a+360:a,c:Math.sqrt(n*n+i*i),l:r,alpha:t.a}},reverse:function(t){var e=t.h*Fe,r=t.c;return He({l:t.l,a:Math.cos(e)*r,b:Math.sin(e)*r,alpha:t.alpha})},interpolate:function(t,e,r){return{h:function(t,e,r){var n=e-t;return t+r*(n>180||n<-180?n-360*Math.round(n/360):n)}(t.h,e.h,r),c:Ee(t.c,e.c,r),l:Ee(t.l,e.l,r),alpha:Ee(t.alpha,e.alpha,r)}}},We=Object.freeze({lab:Ge,hcl:Ye}),Xe=function(t,e,r,n,i){this.type=t,this.operator=e,this.interpolation=r,this.input=n,this.labels=[],this.outputs=[];for(var a=0,o=i;a<o.length;a+=1){var s=o[a],l=s[0],c=s[1];this.labels.push(l),this.outputs.push(c)}};function Ze(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}Xe.interpolationFactor=function(t,e,n,i){var a=0;if(\"exponential\"===t.name)a=Ze(e,t.base,n,i);else if(\"linear\"===t.name)a=Ze(e,1,n,i);else if(\"cubic-bezier\"===t.name){var o=t.controlPoints;a=new r(o[0],o[1],o[2],o[3]).solve(Ze(e,1,n,i))}return a},Xe.parse=function(t,e){var r=t[0],n=t[1],i=t[2],a=t.slice(3);if(!Array.isArray(n)||0===n.length)return e.error(\"Expected an interpolation type expression.\",1);if(\"linear\"===n[0])n={name:\"linear\"};else if(\"exponential\"===n[0]){var o=n[1];if(\"number\"!=typeof o)return e.error(\"Exponential interpolation requires a numeric base.\",1,1);n={name:\"exponential\",base:o}}else{if(\"cubic-bezier\"!==n[0])return e.error(\"Unknown interpolation type \"+String(n[0]),1,0);var s=n.slice(1);if(4!==s.length||s.some(function(t){return\"number\"!=typeof t||t<0||t>1}))return e.error(\"Cubic bezier interpolation requires four numeric arguments with values between 0 and 1.\",1);n={name:\"cubic-bezier\",controlPoints:s}}if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");if(!(i=e.parse(i,2,Ht)))return null;var l=[],c=null;\"interpolate-hcl\"===r||\"interpolate-lab\"===r?c=Wt:e.expectedType&&\"value\"!==e.expectedType.kind&&(c=e.expectedType);for(var u=0;u<a.length;u+=2){var h=a[u],f=a[u+1],p=u+3,d=u+4;if(\"number\"!=typeof h)return e.error('Input/output pairs for \"interpolate\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',p);if(l.length&&l[l.length-1][0]>=h)return e.error('Input/output pairs for \"interpolate\" expressions must be arranged with input values in strictly ascending order.',p);var g=e.parse(f,d,c);if(!g)return null;c=c||g.type,l.push([h,g])}return\"number\"===c.kind||\"color\"===c.kind||\"array\"===c.kind&&\"number\"===c.itemType.kind&&\"number\"==typeof c.N?new Xe(c,r,n,i,l):e.error(\"Type \"+Qt(c)+\" is not interpolatable.\")},Xe.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;if(n>=e[i-1])return r[i-1].evaluate(t);var a=Me(e,n),o=e[a],s=e[a+1],l=Xe.interpolationFactor(this.interpolation,n,o,s),c=r[a].evaluate(t),u=r[a+1].evaluate(t);return\"interpolate\"===this.operator?Ce[this.type.kind.toLowerCase()](c,u,l):\"interpolate-hcl\"===this.operator?Ye.reverse(Ye.interpolate(Ye.forward(c),Ye.forward(u),l)):Ge.reverse(Ge.interpolate(Ge.forward(c),Ge.forward(u),l))},Xe.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},Xe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()}))},Xe.prototype.serialize=function(){var t;t=\"linear\"===this.interpolation.name?[\"linear\"]:\"exponential\"===this.interpolation.name?1===this.interpolation.base?[\"linear\"]:[\"exponential\",this.interpolation.base]:[\"cubic-bezier\"].concat(this.interpolation.controlPoints);for(var e=[this.operator,t,this.input.serialize()],r=0;r<this.labels.length;r++)e.push(this.labels[r],this.outputs[r].serialize());return e};var Je=function(t,e){this.type=t,this.args=e};Je.parse=function(t,e){if(t.length<2)return e.error(\"Expectected at least one argument.\");var r=null,n=e.expectedType;n&&\"value\"!==n.kind&&(r=n);for(var i=[],a=0,o=t.slice(1);a<o.length;a+=1){var s=o[a],l=e.parse(s,1+i.length,r,void 0,{typeAnnotation:\"omit\"});if(!l)return null;r=r||l.type,i.push(l)}var c=n&&i.some(function(t){return ee(n,t.type)});return new Je(c?Zt:r,i)},Je.prototype.evaluate=function(t){for(var e=null,r=0,n=this.args;r<n.length&&null===(e=n[r].evaluate(t));r+=1);return e},Je.prototype.eachChild=function(t){this.args.forEach(t)},Je.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},Je.prototype.serialize=function(){var t=[\"coalesce\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var Ke=function(t,e){this.type=e.type,this.bindings=[].concat(t),this.result=e};Ke.prototype.evaluate=function(t){return this.result.evaluate(t)},Ke.prototype.eachChild=function(t){for(var e=0,r=this.bindings;e<r.length;e+=1)t(r[e][1]);t(this.result)},Ke.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found \"+(t.length-1)+\" instead.\");for(var r=[],n=1;n<t.length-1;n+=2){var i=t[n];if(\"string\"!=typeof i)return e.error(\"Expected string, but found \"+typeof i+\" instead.\",n);if(/[^a-zA-Z0-9_]/.test(i))return e.error(\"Variable names must contain only alphanumeric characters or '_'.\",n);var a=e.parse(t[n+1],n+1);if(!a)return null;r.push([i,a])}var o=e.parse(t[t.length-1],t.length-1,e.expectedType,r);return o?new Ke(r,o):null},Ke.prototype.possibleOutputs=function(){return this.result.possibleOutputs()},Ke.prototype.serialize=function(){for(var t=[\"let\"],e=0,r=this.bindings;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];t.push(i,a.serialize())}return t.push(this.result.serialize()),t};var $e=function(t,e,r){this.type=t,this.index=e,this.input=r};$e.parse=function(t,e){if(3!==t.length)return e.error(\"Expected 2 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,Ht),n=e.parse(t[2],2,$t(e.expectedType||Zt));if(!r||!n)return null;var i=n.type;return new $e(i.itemType,r,n)},$e.prototype.evaluate=function(t){var e=this.index.evaluate(t),r=this.input.evaluate(t);if(e<0)throw new he(\"Array index out of bounds: \"+e+\" < 0.\");if(e>=r.length)throw new he(\"Array index out of bounds: \"+e+\" > \"+(r.length-1)+\".\");if(e!==Math.floor(e))throw new he(\"Array index must be an integer, but found \"+e+\" instead.\");return r[e]},$e.prototype.eachChild=function(t){t(this.index),t(this.input)},$e.prototype.possibleOutputs=function(){return[void 0]},$e.prototype.serialize=function(){return[\"at\",this.index.serialize(),this.input.serialize()]};var Qe=function(t,e,r,n,i,a){this.inputType=t,this.type=e,this.input=r,this.cases=n,this.outputs=i,this.otherwise=a};Qe.parse=function(t,e){if(t.length<5)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=1)return e.error(\"Expected an even number of arguments.\");var r,n;e.expectedType&&\"value\"!==e.expectedType.kind&&(n=e.expectedType);for(var i={},a=[],o=2;o<t.length-1;o+=2){var s=t[o],l=t[o+1];Array.isArray(s)||(s=[s]);var c=e.concat(o);if(0===s.length)return c.error(\"Expected at least one branch label.\");for(var u=0,h=s;u<h.length;u+=1){var f=h[u];if(\"number\"!=typeof f&&\"string\"!=typeof f)return c.error(\"Branch labels must be numbers or strings.\");if(\"number\"==typeof f&&Math.abs(f)>Number.MAX_SAFE_INTEGER)return c.error(\"Branch labels must be integers no larger than \"+Number.MAX_SAFE_INTEGER+\".\");if(\"number\"==typeof f&&Math.floor(f)!==f)return c.error(\"Numeric branch labels must be integer values.\");if(r){if(c.checkSubtype(r,le(f)))return null}else r=le(f);if(void 0!==i[String(f)])return c.error(\"Branch labels must be unique.\");i[String(f)]=a.length}var p=e.parse(l,o,n);if(!p)return null;n=n||p.type,a.push(p)}var d=e.parse(t[1],1,Zt);if(!d)return null;var g=e.parse(t[t.length-1],t.length-1,n);return g?\"value\"!==d.type.kind&&e.concat(1).checkSubtype(r,d.type)?null:new Qe(r,n,d,i,a,g):null},Qe.prototype.evaluate=function(t){var e=this.input.evaluate(t);return(le(e)===this.inputType&&this.outputs[this.cases[e]]||this.otherwise).evaluate(t)},Qe.prototype.eachChild=function(t){t(this.input),this.outputs.forEach(t),t(this.otherwise)},Qe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()})).concat(this.otherwise.possibleOutputs())},Qe.prototype.serialize=function(){for(var t=this,e=[\"match\",this.input.serialize()],r=[],n={},i=0,a=Object.keys(this.cases).sort();i<a.length;i+=1){var o=a[i];void 0===(h=n[this.cases[o]])?(n[this.cases[o]]=r.length,r.push([this.cases[o],[o]])):r[h][1].push(o)}for(var s=function(e){return\"number\"===t.inputType.kind?Number(e):e},l=0,c=r;l<c.length;l+=1){var u=c[l],h=u[0],f=u[1];1===f.length?e.push(s(f[0])):e.push(f.map(s)),e.push(this.outputs[outputIndex$1].serialize())}return e.push(this.otherwise.serialize()),e};var tr=function(t,e,r){this.type=t,this.branches=e,this.otherwise=r};function er(t,e){return\"==\"===t||\"!=\"===t?\"boolean\"===e.kind||\"string\"===e.kind||\"number\"===e.kind||\"null\"===e.kind||\"value\"===e.kind:\"string\"===e.kind||\"number\"===e.kind||\"value\"===e.kind}function rr(t,e,r,n){return 0===n.compare(e,r)}function nr(t,e,r){var n=\"==\"!==t&&\"!=\"!==t;return function(){function i(t,e,r){this.type=Yt,this.lhs=t,this.rhs=e,this.collator=r,this.hasUntypedArgument=\"value\"===t.type.kind||\"value\"===e.type.kind}return i.parse=function(t,e){if(3!==t.length&&4!==t.length)return e.error(\"Expected two or three arguments.\");var r=t[0],a=e.parse(t[1],1,Zt);if(!a)return null;if(!er(r,a.type))return e.concat(1).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Qt(a.type)+\"'.\");var o=e.parse(t[2],2,Zt);if(!o)return null;if(!er(r,o.type))return e.concat(2).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Qt(o.type)+\"'.\");if(a.type.kind!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot compare types '\"+Qt(a.type)+\"' and '\"+Qt(o.type)+\"'.\");n&&(\"value\"===a.type.kind&&\"value\"!==o.type.kind?a=new pe(o.type,[a]):\"value\"!==a.type.kind&&\"value\"===o.type.kind&&(o=new pe(a.type,[o])));var s=null;if(4===t.length){if(\"string\"!==a.type.kind&&\"string\"!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot use collator to compare non-string types.\");if(!(s=e.parse(t[3],3,Jt)))return null}return new i(a,o,s)},i.prototype.evaluate=function(i){var a=this.lhs.evaluate(i),o=this.rhs.evaluate(i);if(n&&this.hasUntypedArgument){var s=le(a),l=le(o);if(s.kind!==l.kind||\"string\"!==s.kind&&\"number\"!==s.kind)throw new he('Expected arguments for \"'+t+'\" to be (string, string) or (number, number), but found ('+s.kind+\", \"+l.kind+\") instead.\")}if(this.collator&&!n&&this.hasUntypedArgument){var c=le(a),u=le(o);if(\"string\"!==c.kind||\"string\"!==u.kind)return e(i,a,o)}return this.collator?r(i,a,o,this.collator.evaluate(i)):e(i,a,o)},i.prototype.eachChild=function(t){t(this.lhs),t(this.rhs),this.collator&&t(this.collator)},i.prototype.possibleOutputs=function(){return[!0,!1]},i.prototype.serialize=function(){var e=[t];return this.eachChild(function(t){e.push(t.serialize())}),e},i}()}tr.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=0)return e.error(\"Expected an odd number of arguments.\");var r;e.expectedType&&\"value\"!==e.expectedType.kind&&(r=e.expectedType);for(var n=[],i=1;i<t.length-1;i+=2){var a=e.parse(t[i],i,Yt);if(!a)return null;var o=e.parse(t[i+1],i+1,r);if(!o)return null;n.push([a,o]),r=r||o.type}var s=e.parse(t[t.length-1],t.length-1,r);return s?new tr(r,n,s):null},tr.prototype.evaluate=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];if(i.evaluate(t))return a.evaluate(t)}return this.otherwise.evaluate(t)},tr.prototype.eachChild=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];t(i),t(a)}t(this.otherwise)},tr.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.branches.map(function(t){return t[0],t[1].possibleOutputs()})).concat(this.otherwise.possibleOutputs())},tr.prototype.serialize=function(){var t=[\"case\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var ir=nr(\"==\",function(t,e,r){return e===r},rr),ar=nr(\"!=\",function(t,e,r){return e!==r},function(t,e,r,n){return!rr(0,e,r,n)}),or=nr(\"<\",function(t,e,r){return e<r},function(t,e,r,n){return n.compare(e,r)<0}),sr=nr(\">\",function(t,e,r){return e>r},function(t,e,r,n){return n.compare(e,r)>0}),lr=nr(\"<=\",function(t,e,r){return e<=r},function(t,e,r,n){return n.compare(e,r)<=0}),cr=nr(\">=\",function(t,e,r){return e>=r},function(t,e,r,n){return n.compare(e,r)>=0}),ur=function(t,e,r,n,i){this.type=Gt,this.number=t,this.locale=e,this.currency=r,this.minFractionDigits=n,this.maxFractionDigits=i};ur.parse=function(t,e){if(3!==t.length)return e.error(\"Expected two arguments.\");var r=e.parse(t[1],1,Ht);if(!r)return null;var n=t[2];if(\"object\"!=typeof n||Array.isArray(n))return e.error(\"NumberFormat options argument must be an object.\");var i=null;if(n.locale&&!(i=e.parse(n.locale,1,Gt)))return null;var a=null;if(n.currency&&!(a=e.parse(n.currency,1,Gt)))return null;var o=null;if(n[\"min-fraction-digits\"]&&!(o=e.parse(n[\"min-fraction-digits\"],1,Ht)))return null;var s=null;return n[\"max-fraction-digits\"]&&!(s=e.parse(n[\"max-fraction-digits\"],1,Ht))?null:new ur(r,i,a,o,s)},ur.prototype.evaluate=function(t){return new Intl.NumberFormat(this.locale?this.locale.evaluate(t):[],{style:this.currency?\"currency\":\"decimal\",currency:this.currency?this.currency.evaluate(t):void 0,minimumFractionDigits:this.minFractionDigits?this.minFractionDigits.evaluate(t):void 0,maximumFractionDigits:this.maxFractionDigits?this.maxFractionDigits.evaluate(t):void 0}).format(this.number.evaluate(t))},ur.prototype.eachChild=function(t){t(this.number),this.locale&&t(this.locale),this.currency&&t(this.currency),this.minFractionDigits&&t(this.minFractionDigits),this.maxFractionDigits&&t(this.maxFractionDigits)},ur.prototype.possibleOutputs=function(){return[void 0]},ur.prototype.serialize=function(){var t={};return this.locale&&(t.locale=this.locale.serialize()),this.currency&&(t.currency=this.currency.serialize()),this.minFractionDigits&&(t[\"min-fraction-digits\"]=this.minFractionDigits.serialize()),this.maxFractionDigits&&(t[\"max-fraction-digits\"]=this.maxFractionDigits.serialize()),[\"number-format\",this.number.serialize(),t]};var hr=function(t){this.type=Ht,this.input=t};hr.parse=function(t,e){if(2!==t.length)return e.error(\"Expected 1 argument, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1);return r?\"array\"!==r.type.kind&&\"string\"!==r.type.kind&&\"value\"!==r.type.kind?e.error(\"Expected argument of type string or array, but found \"+Qt(r.type)+\" instead.\"):new hr(r):null},hr.prototype.evaluate=function(t){var e=this.input.evaluate(t);if(\"string\"==typeof e)return e.length;if(Array.isArray(e))return e.length;throw new he(\"Expected value to be of type string or array, but found \"+Qt(le(e))+\" instead.\")},hr.prototype.eachChild=function(t){t(this.input)},hr.prototype.possibleOutputs=function(){return[void 0]},hr.prototype.serialize=function(){var t=[\"length\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var fr={\"==\":ir,\"!=\":ar,\">\":sr,\"<\":or,\">=\":cr,\"<=\":lr,array:pe,at:$e,boolean:pe,case:tr,coalesce:Je,collator:be,format:de,interpolate:Xe,\"interpolate-hcl\":Xe,\"interpolate-lab\":Xe,length:hr,let:Ke,literal:ue,match:Qe,number:pe,\"number-format\":ur,object:pe,step:Se,string:pe,\"to-boolean\":ve,\"to-color\":ve,\"to-number\":ve,\"to-string\":ve,var:Te};function pr(t,e){var r=e[0],n=e[1],i=e[2],a=e[3];r=r.evaluate(t),n=n.evaluate(t),i=i.evaluate(t);var o=a?a.evaluate(t):1,s=se(r,n,i,o);if(s)throw new he(s);return new ne(r/255*o,n/255*o,i/255*o,o)}function dr(t,e){return t in e}function gr(t,e){var r=e[t];return void 0===r?null:r}function vr(t){return{type:t}}function mr(t){return{result:\"success\",value:t}}function yr(t){return{result:\"error\",value:t}}function xr(t){return\"data-driven\"===t[\"property-type\"]||\"cross-faded-data-driven\"===t[\"property-type\"]}function br(t){return!!t.expression&&t.expression.parameters.indexOf(\"zoom\")>-1}function _r(t){return!!t.expression&&t.expression.interpolated}function wr(t){return t instanceof Number?\"number\":t instanceof String?\"string\":t instanceof Boolean?\"boolean\":Array.isArray(t)?\"array\":null===t?\"null\":typeof t}function kr(t){return\"object\"==typeof t&&null!==t&&!Array.isArray(t)}function Tr(t){return t}function Ar(t,e,r){return void 0!==t?t:void 0!==e?e:void 0!==r?r:void 0}function Mr(t,e,r,n,i){return Ar(typeof r===i?n[r]:void 0,t.default,e.default)}function Sr(t,e,r){if(\"number\"!==wr(r))return Ar(t.default,e.default);var n=t.stops.length;if(1===n)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[n-1][0])return t.stops[n-1][1];var i=Me(t.stops.map(function(t){return t[0]}),r);return t.stops[i][1]}function Er(t,e,r){var n=void 0!==t.base?t.base:1;if(\"number\"!==wr(r))return Ar(t.default,e.default);var i=t.stops.length;if(1===i)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[i-1][0])return t.stops[i-1][1];var a=Me(t.stops.map(function(t){return t[0]}),r),o=function(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}(r,n,t.stops[a][0],t.stops[a+1][0]),s=t.stops[a][1],l=t.stops[a+1][1],c=Ce[e.type]||Tr;if(t.colorSpace&&\"rgb\"!==t.colorSpace){var u=We[t.colorSpace];c=function(t,e){return u.reverse(u.interpolate(u.forward(t),u.forward(e),o))}}return\"function\"==typeof s.evaluate?{evaluate:function(){for(var t=[],e=arguments.length;e--;)t[e]=arguments[e];var r=s.evaluate.apply(void 0,t),n=l.evaluate.apply(void 0,t);if(void 0!==r&&void 0!==n)return c(r,n,o)}}:c(s,l,o)}function Cr(t,e,r){return\"color\"===e.type?r=ne.parse(r):\"formatted\"===e.type?r=oe.fromString(r.toString()):wr(r)===e.type||\"enum\"===e.type&&e.values[r]||(r=void 0),Ar(r,t.default,e.default)}xe.register(fr,{error:[{kind:\"error\"},[Gt],function(t,e){var r=e[0];throw new he(r.evaluate(t))}],typeof:[Gt,[Zt],function(t,e){return Qt(le(e[0].evaluate(t)))}],\"to-rgba\":[$t(Ht,4),[Wt],function(t,e){return e[0].evaluate(t).toArray()}],rgb:[Wt,[Ht,Ht,Ht],pr],rgba:[Wt,[Ht,Ht,Ht,Ht],pr],has:{type:Yt,overloads:[[[Gt],function(t,e){return dr(e[0].evaluate(t),t.properties())}],[[Gt,Xt],function(t,e){var r=e[0],n=e[1];return dr(r.evaluate(t),n.evaluate(t))}]]},get:{type:Zt,overloads:[[[Gt],function(t,e){return gr(e[0].evaluate(t),t.properties())}],[[Gt,Xt],function(t,e){var r=e[0],n=e[1];return gr(r.evaluate(t),n.evaluate(t))}]]},\"feature-state\":[Zt,[Gt],function(t,e){return gr(e[0].evaluate(t),t.featureState||{})}],properties:[Xt,[],function(t){return t.properties()}],\"geometry-type\":[Gt,[],function(t){return t.geometryType()}],id:[Zt,[],function(t){return t.id()}],zoom:[Ht,[],function(t){return t.globals.zoom}],\"heatmap-density\":[Ht,[],function(t){return t.globals.heatmapDensity||0}],\"line-progress\":[Ht,[],function(t){return t.globals.lineProgress||0}],accumulated:[Zt,[],function(t){return void 0===t.globals.accumulated?null:t.globals.accumulated}],\"+\":[Ht,vr(Ht),function(t,e){for(var r=0,n=0,i=e;n<i.length;n+=1)r+=i[n].evaluate(t);return r}],\"*\":[Ht,vr(Ht),function(t,e){for(var r=1,n=0,i=e;n<i.length;n+=1)r*=i[n].evaluate(t);return r}],\"-\":{type:Ht,overloads:[[[Ht,Ht],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)-n.evaluate(t)}],[[Ht],function(t,e){return-e[0].evaluate(t)}]]},\"/\":[Ht,[Ht,Ht],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)/n.evaluate(t)}],\"%\":[Ht,[Ht,Ht],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)%n.evaluate(t)}],ln2:[Ht,[],function(){return Math.LN2}],pi:[Ht,[],function(){return Math.PI}],e:[Ht,[],function(){return Math.E}],\"^\":[Ht,[Ht,Ht],function(t,e){var r=e[0],n=e[1];return Math.pow(r.evaluate(t),n.evaluate(t))}],sqrt:[Ht,[Ht],function(t,e){var r=e[0];return Math.sqrt(r.evaluate(t))}],log10:[Ht,[Ht],function(t,e){var r=e[0];return Math.log(r.evaluate(t))/Math.LN10}],ln:[Ht,[Ht],function(t,e){var r=e[0];return Math.log(r.evaluate(t))}],log2:[Ht,[Ht],function(t,e){var r=e[0];return Math.log(r.evaluate(t))/Math.LN2}],sin:[Ht,[Ht],function(t,e){var r=e[0];return Math.sin(r.evaluate(t))}],cos:[Ht,[Ht],function(t,e){var r=e[0];return Math.cos(r.evaluate(t))}],tan:[Ht,[Ht],function(t,e){var r=e[0];return Math.tan(r.evaluate(t))}],asin:[Ht,[Ht],function(t,e){var r=e[0];return Math.asin(r.evaluate(t))}],acos:[Ht,[Ht],function(t,e){var r=e[0];return Math.acos(r.evaluate(t))}],atan:[Ht,[Ht],function(t,e){var r=e[0];return Math.atan(r.evaluate(t))}],min:[Ht,vr(Ht),function(t,e){return Math.min.apply(Math,e.map(function(e){return e.evaluate(t)}))}],max:[Ht,vr(Ht),function(t,e){return Math.max.apply(Math,e.map(function(e){return e.evaluate(t)}))}],abs:[Ht,[Ht],function(t,e){var r=e[0];return Math.abs(r.evaluate(t))}],round:[Ht,[Ht],function(t,e){var r=e[0].evaluate(t);return r<0?-Math.round(-r):Math.round(r)}],floor:[Ht,[Ht],function(t,e){var r=e[0];return Math.floor(r.evaluate(t))}],ceil:[Ht,[Ht],function(t,e){var r=e[0];return Math.ceil(r.evaluate(t))}],\"filter-==\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1];return t.properties()[r.value]===n.value}],\"filter-id-==\":[Yt,[Zt],function(t,e){var r=e[0];return t.id()===r.value}],\"filter-type-==\":[Yt,[Gt],function(t,e){var r=e[0];return t.geometryType()===r.value}],\"filter-<\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<a}],\"filter-id-<\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<i}],\"filter->\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>a}],\"filter-id->\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>i}],\"filter-<=\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<=a}],\"filter-id-<=\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<=i}],\"filter->=\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>=a}],\"filter-id->=\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>=i}],\"filter-has\":[Yt,[Zt],function(t,e){return e[0].value in t.properties()}],\"filter-has-id\":[Yt,[],function(t){return null!==t.id()}],\"filter-type-in\":[Yt,[$t(Gt)],function(t,e){return e[0].value.indexOf(t.geometryType())>=0}],\"filter-id-in\":[Yt,[$t(Zt)],function(t,e){return e[0].value.indexOf(t.id())>=0}],\"filter-in-small\":[Yt,[Gt,$t(Zt)],function(t,e){var r=e[0];return e[1].value.indexOf(t.properties()[r.value])>=0}],\"filter-in-large\":[Yt,[Gt,$t(Zt)],function(t,e){var r=e[0],n=e[1];return function(t,e,r,n){for(;r<=n;){var i=r+n>>1;if(e[i]===t)return!0;e[i]>t?n=i-1:r=i+1}return!1}(t.properties()[r.value],n.value,0,n.value.length-1)}],all:{type:Yt,overloads:[[[Yt,Yt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)&&n.evaluate(t)}],[vr(Yt),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(!n[r].evaluate(t))return!1;return!0}]]},any:{type:Yt,overloads:[[[Yt,Yt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)||n.evaluate(t)}],[vr(Yt),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(n[r].evaluate(t))return!0;return!1}]]},\"!\":[Yt,[Yt],function(t,e){return!e[0].evaluate(t)}],\"is-supported-script\":[Yt,[Gt],function(t,e){var r=e[0],n=t.globals&&t.globals.isSupportedScript;return!n||n(r.evaluate(t))}],upcase:[Gt,[Gt],function(t,e){return e[0].evaluate(t).toUpperCase()}],downcase:[Gt,[Gt],function(t,e){return e[0].evaluate(t).toLowerCase()}],concat:[Gt,vr(Zt),function(t,e){return e.map(function(e){return ce(e.evaluate(t))}).join(\"\")}],\"resolved-locale\":[Gt,[Jt],function(t,e){return e[0].evaluate(t).resolvedLocale()}]});var Lr=function(t,e){var r;this.expression=t,this._warningHistory={},this._evaluator=new ye,this._defaultValue=e?\"color\"===(r=e).type&&kr(r.default)?new ne(0,0,0,0):\"color\"===r.type?ne.parse(r.default)||null:void 0===r.default?null:r.default:null,this._enumValues=e&&\"enum\"===e.type?e.values:null};function Pr(t){return Array.isArray(t)&&t.length>0&&\"string\"==typeof t[0]&&t[0]in fr}function Or(t,e){var r=new Ae(fr,[],e?function(t){var e={color:Wt,string:Gt,number:Ht,enum:Gt,boolean:Yt,formatted:Kt};return\"array\"===t.type?$t(e[t.value]||Zt,t.length):e[t.type]}(e):void 0),n=r.parse(t,void 0,void 0,void 0,e&&\"string\"===e.type?{typeAnnotation:\"coerce\"}:void 0);return n?mr(new Lr(n,e)):yr(r.errors)}Lr.prototype.evaluateWithoutErrorHandling=function(t,e,r){return this._evaluator.globals=t,this._evaluator.feature=e,this._evaluator.featureState=r,this.expression.evaluate(this._evaluator)},Lr.prototype.evaluate=function(t,e,r){this._evaluator.globals=t,this._evaluator.feature=e||null,this._evaluator.featureState=r||null;try{var n=this.expression.evaluate(this._evaluator);if(null==n)return this._defaultValue;if(this._enumValues&&!(n in this._enumValues))throw new he(\"Expected value to be one of \"+Object.keys(this._enumValues).map(function(t){return JSON.stringify(t)}).join(\", \")+\", but found \"+JSON.stringify(n)+\" instead.\");return n}catch(t){return this._warningHistory[t.message]||(this._warningHistory[t.message]=!0,\"undefined\"!=typeof console&&console.warn(t.message)),this._defaultValue}};var zr=function(t,e){this.kind=t,this._styleExpression=e,this.isStateDependent=\"constant\"!==t&&!we(e.expression)};zr.prototype.evaluateWithoutErrorHandling=function(t,e,r){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r)},zr.prototype.evaluate=function(t,e,r){return this._styleExpression.evaluate(t,e,r)};var Ir=function(t,e,r){this.kind=t,this.zoomStops=r.labels,this._styleExpression=e,this.isStateDependent=\"camera\"!==t&&!we(e.expression),r instanceof Xe&&(this.interpolationType=r.interpolation)};function Dr(t,e){if(\"error\"===(t=Or(t,e)).result)return t;var r=t.value.expression,n=_e(r);if(!n&&!xr(e))return yr([new Ut(\"\",\"data expressions not supported\")]);var i=ke(r,[\"zoom\"]);if(!i&&!br(e))return yr([new Ut(\"\",\"zoom expressions not supported\")]);var a=function t(e){var r=null;if(e instanceof Ke)r=t(e.result);else if(e instanceof Je)for(var n=0,i=e.args;n<i.length;n+=1){var a=i[n];if(r=t(a))break}else(e instanceof Se||e instanceof Xe)&&e.input instanceof xe&&\"zoom\"===e.input.name&&(r=e);return r instanceof Ut?r:(e.eachChild(function(e){var n=t(e);n instanceof Ut?r=n:!r&&n?r=new Ut(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.'):r&&n&&r!==n&&(r=new Ut(\"\",'Only one zoom-based \"step\" or \"interpolate\" subexpression may be used in an expression.'))}),r)}(r);return a||i?a instanceof Ut?yr([a]):a instanceof Xe&&!_r(e)?yr([new Ut(\"\",'\"interpolate\" expressions cannot be used with this property')]):mr(a?new Ir(n?\"camera\":\"composite\",t.value,a):new zr(n?\"constant\":\"source\",t.value)):yr([new Ut(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.')])}Ir.prototype.evaluateWithoutErrorHandling=function(t,e,r){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r)},Ir.prototype.evaluate=function(t,e,r){return this._styleExpression.evaluate(t,e,r)},Ir.prototype.interpolationFactor=function(t,e,r){return this.interpolationType?Xe.interpolationFactor(this.interpolationType,t,e,r):0};var Rr=function(t,e){this._parameters=t,this._specification=e,Ft(this,function t(e,r){var n,i,a,o=\"color\"===r.type,s=e.stops&&\"object\"==typeof e.stops[0][0],l=s||void 0!==e.property,c=s||!l,u=e.type||(_r(r)?\"exponential\":\"interval\");if(o&&((e=Ft({},e)).stops&&(e.stops=e.stops.map(function(t){return[t[0],ne.parse(t[1])]})),e.default?e.default=ne.parse(e.default):e.default=ne.parse(r.default)),e.colorSpace&&\"rgb\"!==e.colorSpace&&!We[e.colorSpace])throw new Error(\"Unknown color space: \"+e.colorSpace);if(\"exponential\"===u)n=Er;else if(\"interval\"===u)n=Sr;else if(\"categorical\"===u){n=Mr,i=Object.create(null);for(var h=0,f=e.stops;h<f.length;h+=1){var p=f[h];i[p[0]]=p[1]}a=typeof e.stops[0][0]}else{if(\"identity\"!==u)throw new Error('Unknown function type \"'+u+'\"');n=Cr}if(s){for(var d={},g=[],v=0;v<e.stops.length;v++){var m=e.stops[v],y=m[0].zoom;void 0===d[y]&&(d[y]={zoom:y,type:e.type,property:e.property,default:e.default,stops:[]},g.push(y)),d[y].stops.push([m[0].value,m[1]])}for(var x=[],b=0,_=g;b<_.length;b+=1){var w=_[b];x.push([d[w].zoom,t(d[w],r)])}var k={name:\"linear\"};return{kind:\"composite\",interpolationType:k,interpolationFactor:Xe.interpolationFactor.bind(void 0,k),zoomStops:x.map(function(t){return t[0]}),evaluate:function(t,n){var i=t.zoom;return Er({stops:x,base:e.base},r,i).evaluate(i,n)}}}if(c){var T=\"exponential\"===u?{name:\"exponential\",base:void 0!==e.base?e.base:1}:null;return{kind:\"camera\",interpolationType:T,interpolationFactor:Xe.interpolationFactor.bind(void 0,T),zoomStops:e.stops.map(function(t){return t[0]}),evaluate:function(t){var o=t.zoom;return n(e,r,o,i,a)}}}return{kind:\"source\",evaluate:function(t,o){var s=o&&o.properties?o.properties[e.property]:void 0;return void 0===s?Ar(e.default,r.default):n(e,r,s,i,a)}}}(this._parameters,this._specification))};function Fr(t){var e=t.key,r=t.value,n=t.valueSpec||{},i=t.objectElementValidators||{},a=t.style,o=t.styleSpec,s=[],l=wr(r);if(\"object\"!==l)return[new Dt(e,r,\"object expected, \"+l+\" found\")];for(var c in r){var u=c.split(\".\")[0],h=n[u]||n[\"*\"],f=void 0;if(i[u])f=i[u];else if(n[u])f=ln;else if(i[\"*\"])f=i[\"*\"];else{if(!n[\"*\"]){s.push(new Dt(e,r[c],'unknown property \"'+c+'\"'));continue}f=ln}s=s.concat(f({key:(e?e+\".\":e)+c,value:r[c],valueSpec:h,style:a,styleSpec:o,object:r,objectKey:c},r))}for(var p in n)i[p]||n[p].required&&void 0===n[p].default&&void 0===r[p]&&s.push(new Dt(e,r,'missing required property \"'+p+'\"'));return s}function Br(t){var e=t.value,r=t.valueSpec,n=t.style,i=t.styleSpec,a=t.key,o=t.arrayElementValidator||ln;if(\"array\"!==wr(e))return[new Dt(a,e,\"array expected, \"+wr(e)+\" found\")];if(r.length&&e.length!==r.length)return[new Dt(a,e,\"array length \"+r.length+\" expected, length \"+e.length+\" found\")];if(r[\"min-length\"]&&e.length<r[\"min-length\"])return[new Dt(a,e,\"array length at least \"+r[\"min-length\"]+\" expected, length \"+e.length+\" found\")];var s={type:r.value,values:r.values};i.$version<7&&(s.function=r.function),\"object\"===wr(r.value)&&(s=r.value);for(var l=[],c=0;c<e.length;c++)l=l.concat(o({array:e,arrayIndex:c,value:e[c],valueSpec:s,style:n,styleSpec:i,key:a+\"[\"+c+\"]\"}));return l}function Nr(t){var e=t.key,r=t.value,n=t.valueSpec,i=wr(r);return\"number\"!==i?[new Dt(e,r,\"number expected, \"+i+\" found\")]:\"minimum\"in n&&r<n.minimum?[new Dt(e,r,r+\" is less than the minimum value \"+n.minimum)]:\"maximum\"in n&&r>n.maximum?[new Dt(e,r,r+\" is greater than the maximum value \"+n.maximum)]:[]}function jr(t){var e,r,n,i=t.valueSpec,a=Nt(t.value.type),o={},s=\"categorical\"!==a&&void 0===t.value.property,l=!s,c=\"array\"===wr(t.value.stops)&&\"array\"===wr(t.value.stops[0])&&\"object\"===wr(t.value.stops[0][0]),u=Fr({key:t.key,value:t.value,valueSpec:t.styleSpec.function,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{stops:function(t){if(\"identity\"===a)return[new Dt(t.key,t.value,'identity function may not have a \"stops\" property')];var e=[],r=t.value;return e=e.concat(Br({key:t.key,value:r,valueSpec:t.valueSpec,style:t.style,styleSpec:t.styleSpec,arrayElementValidator:h})),\"array\"===wr(r)&&0===r.length&&e.push(new Dt(t.key,r,\"array must have at least one stop\")),e},default:function(t){return ln({key:t.key,value:t.value,valueSpec:i,style:t.style,styleSpec:t.styleSpec})}}});return\"identity\"===a&&s&&u.push(new Dt(t.key,t.value,'missing required property \"property\"')),\"identity\"===a||t.value.stops||u.push(new Dt(t.key,t.value,'missing required property \"stops\"')),\"exponential\"===a&&t.valueSpec.expression&&!_r(t.valueSpec)&&u.push(new Dt(t.key,t.value,\"exponential functions not supported\")),t.styleSpec.$version>=8&&(l&&!xr(t.valueSpec)?u.push(new Dt(t.key,t.value,\"property functions not supported\")):s&&!br(t.valueSpec)&&u.push(new Dt(t.key,t.value,\"zoom functions not supported\"))),\"categorical\"!==a&&!c||void 0!==t.value.property||u.push(new Dt(t.key,t.value,'\"property\" property is required')),u;function h(t){var e=[],a=t.value,s=t.key;if(\"array\"!==wr(a))return[new Dt(s,a,\"array expected, \"+wr(a)+\" found\")];if(2!==a.length)return[new Dt(s,a,\"array length 2 expected, length \"+a.length+\" found\")];if(c){if(\"object\"!==wr(a[0]))return[new Dt(s,a,\"object expected, \"+wr(a[0])+\" found\")];if(void 0===a[0].zoom)return[new Dt(s,a,\"object stop key must have zoom\")];if(void 0===a[0].value)return[new Dt(s,a,\"object stop key must have value\")];if(n&&n>Nt(a[0].zoom))return[new Dt(s,a[0].zoom,\"stop zoom values must appear in ascending order\")];Nt(a[0].zoom)!==n&&(n=Nt(a[0].zoom),r=void 0,o={}),e=e.concat(Fr({key:s+\"[0]\",value:a[0],valueSpec:{zoom:{}},style:t.style,styleSpec:t.styleSpec,objectElementValidators:{zoom:Nr,value:f}}))}else e=e.concat(f({key:s+\"[0]\",value:a[0],valueSpec:{},style:t.style,styleSpec:t.styleSpec},a));return Pr(jt(a[1]))?e.concat([new Dt(s+\"[1]\",a[1],\"expressions are not allowed in function stops.\")]):e.concat(ln({key:s+\"[1]\",value:a[1],valueSpec:i,style:t.style,styleSpec:t.styleSpec}))}function f(t,n){var s=wr(t.value),l=Nt(t.value),c=null!==t.value?t.value:n;if(e){if(s!==e)return[new Dt(t.key,c,s+\" stop domain type must match previous stop domain type \"+e)]}else e=s;if(\"number\"!==s&&\"string\"!==s&&\"boolean\"!==s)return[new Dt(t.key,c,\"stop domain value must be a number, string, or boolean\")];if(\"number\"!==s&&\"categorical\"!==a){var u=\"number expected, \"+s+\" found\";return xr(i)&&void 0===a&&(u+='\\nIf you intended to use a categorical function, specify `\"type\": \"categorical\"`.'),[new Dt(t.key,c,u)]}return\"categorical\"!==a||\"number\"!==s||isFinite(l)&&Math.floor(l)===l?\"categorical\"!==a&&\"number\"===s&&void 0!==r&&l<r?[new Dt(t.key,c,\"stop domain values must appear in ascending order\")]:(r=l,\"categorical\"===a&&l in o?[new Dt(t.key,c,\"stop domain values must be unique\")]:(o[l]=!0,[])):[new Dt(t.key,c,\"integer expected, found \"+l)]}}function Ur(t){var e=(\"property\"===t.expressionContext?Dr:Or)(jt(t.value),t.valueSpec);if(\"error\"===e.result)return e.value.map(function(e){return new Dt(\"\"+t.key+e.key,t.value,e.message)});var r=e.value.expression||e.value._styleExpression.expression;if(\"property\"===t.expressionContext&&\"text-font\"===t.propertyKey&&-1!==r.possibleOutputs().indexOf(void 0))return[new Dt(t.key,t.value,'Invalid data expression for \"'+t.propertyKey+'\". Output values must be contained as literals within the expression.')];if(\"property\"===t.expressionContext&&\"layout\"===t.propertyType&&!we(r))return[new Dt(t.key,t.value,'\"feature-state\" data expressions are not supported with layout properties.')];if(\"filter\"===t.expressionContext&&!we(r))return[new Dt(t.key,t.value,'\"feature-state\" data expressions are not supported with filters.')];if(t.expressionContext&&0===t.expressionContext.indexOf(\"cluster\")){if(!ke(r,[\"zoom\",\"feature-state\"]))return[new Dt(t.key,t.value,'\"zoom\" and \"feature-state\" expressions are not supported with cluster properties.')];if(\"cluster-initial\"===t.expressionContext&&!_e(r))return[new Dt(t.key,t.value,\"Feature data expressions are not supported with initial expression part of cluster properties.\")]}return[]}function Vr(t){var e=t.key,r=t.value,n=t.valueSpec,i=[];return Array.isArray(n.values)?-1===n.values.indexOf(Nt(r))&&i.push(new Dt(e,r,\"expected one of [\"+n.values.join(\", \")+\"], \"+JSON.stringify(r)+\" found\")):-1===Object.keys(n.values).indexOf(Nt(r))&&i.push(new Dt(e,r,\"expected one of [\"+Object.keys(n.values).join(\", \")+\"], \"+JSON.stringify(r)+\" found\")),i}function qr(t){if(!0===t||!1===t)return!0;if(!Array.isArray(t)||0===t.length)return!1;switch(t[0]){case\"has\":return t.length>=2&&\"$id\"!==t[1]&&\"$type\"!==t[1];case\"in\":case\"!in\":case\"!has\":case\"none\":return!1;case\"==\":case\"!=\":case\">\":case\">=\":case\"<\":case\"<=\":return 3!==t.length||Array.isArray(t[1])||Array.isArray(t[2]);case\"any\":case\"all\":for(var e=0,r=t.slice(1);e<r.length;e+=1){var n=r[e];if(!qr(n)&&\"boolean\"!=typeof n)return!1}return!0;default:return!0}}Rr.deserialize=function(t){return new Rr(t._parameters,t._specification)},Rr.serialize=function(t){return{_parameters:t._parameters,_specification:t._specification}};var Hr={type:\"boolean\",default:!1,transition:!1,\"property-type\":\"data-driven\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]}};function Gr(t){if(null==t)return function(){return!0};qr(t)||(t=Wr(t));var e=Or(t,Hr);if(\"error\"===e.result)throw new Error(e.value.map(function(t){return t.key+\": \"+t.message}).join(\", \"));return function(t,r){return e.value.evaluate(t,r)}}function Yr(t,e){return t<e?-1:t>e?1:0}function Wr(t){if(!t)return!0;var e,r=t[0];return t.length<=1?\"any\"!==r:\"==\"===r?Xr(t[1],t[2],\"==\"):\"!=\"===r?Kr(Xr(t[1],t[2],\"==\")):\"<\"===r||\">\"===r||\"<=\"===r||\">=\"===r?Xr(t[1],t[2],r):\"any\"===r?(e=t.slice(1),[\"any\"].concat(e.map(Wr))):\"all\"===r?[\"all\"].concat(t.slice(1).map(Wr)):\"none\"===r?[\"all\"].concat(t.slice(1).map(Wr).map(Kr)):\"in\"===r?Zr(t[1],t.slice(2)):\"!in\"===r?Kr(Zr(t[1],t.slice(2))):\"has\"===r?Jr(t[1]):\"!has\"!==r||Kr(Jr(t[1]))}function Xr(t,e,r){switch(t){case\"$type\":return[\"filter-type-\"+r,e];case\"$id\":return[\"filter-id-\"+r,e];default:return[\"filter-\"+r,t,e]}}function Zr(t,e){if(0===e.length)return!1;switch(t){case\"$type\":return[\"filter-type-in\",[\"literal\",e]];case\"$id\":return[\"filter-id-in\",[\"literal\",e]];default:return e.length>200&&!e.some(function(t){return typeof t!=typeof e[0]})?[\"filter-in-large\",t,[\"literal\",e.sort(Yr)]]:[\"filter-in-small\",t,[\"literal\",e]]}}function Jr(t){switch(t){case\"$type\":return!0;case\"$id\":return[\"filter-has-id\"];default:return[\"filter-has\",t]}}function Kr(t){return[\"!\",t]}function $r(t){return qr(jt(t.value))?Ur(Ft({},t,{expressionContext:\"filter\",valueSpec:{value:\"boolean\"}})):function t(e){var r=e.value,n=e.key;if(\"array\"!==wr(r))return[new Dt(n,r,\"array expected, \"+wr(r)+\" found\")];var i,a=e.styleSpec,o=[];if(r.length<1)return[new Dt(n,r,\"filter array must have at least 1 element\")];switch(o=o.concat(Vr({key:n+\"[0]\",value:r[0],valueSpec:a.filter_operator,style:e.style,styleSpec:e.styleSpec})),Nt(r[0])){case\"<\":case\"<=\":case\">\":case\">=\":r.length>=2&&\"$type\"===Nt(r[1])&&o.push(new Dt(n,r,'\"$type\" cannot be use with operator \"'+r[0]+'\"'));case\"==\":case\"!=\":3!==r.length&&o.push(new Dt(n,r,'filter array for operator \"'+r[0]+'\" must have 3 elements'));case\"in\":case\"!in\":r.length>=2&&\"string\"!==(i=wr(r[1]))&&o.push(new Dt(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"));for(var s=2;s<r.length;s++)i=wr(r[s]),\"$type\"===Nt(r[1])?o=o.concat(Vr({key:n+\"[\"+s+\"]\",value:r[s],valueSpec:a.geometry_type,style:e.style,styleSpec:e.styleSpec})):\"string\"!==i&&\"number\"!==i&&\"boolean\"!==i&&o.push(new Dt(n+\"[\"+s+\"]\",r[s],\"string, number, or boolean expected, \"+i+\" found\"));break;case\"any\":case\"all\":case\"none\":for(var l=1;l<r.length;l++)o=o.concat(t({key:n+\"[\"+l+\"]\",value:r[l],style:e.style,styleSpec:e.styleSpec}));break;case\"has\":case\"!has\":i=wr(r[1]),2!==r.length?o.push(new Dt(n,r,'filter array for \"'+r[0]+'\" operator must have 2 elements')):\"string\"!==i&&o.push(new Dt(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"))}return o}(t)}function Qr(t,e){var r=t.key,n=t.style,i=t.styleSpec,a=t.value,o=t.objectKey,s=i[e+\"_\"+t.layerType];if(!s)return[];var l=o.match(/^(.*)-transition$/);if(\"paint\"===e&&l&&s[l[1]]&&s[l[1]].transition)return ln({key:r,value:a,valueSpec:i.transition,style:n,styleSpec:i});var c,u=t.valueSpec||s[o];if(!u)return[new Dt(r,a,'unknown property \"'+o+'\"')];if(\"string\"===wr(a)&&xr(u)&&!u.tokens&&(c=/^{([^}]+)}$/.exec(a)))return[new Dt(r,a,'\"'+o+'\" does not support interpolation syntax\\nUse an identity property function instead: `{ \"type\": \"identity\", \"property\": '+JSON.stringify(c[1])+\" }`.\")];var h=[];return\"symbol\"===t.layerType&&(\"text-field\"===o&&n&&!n.glyphs&&h.push(new Dt(r,a,'use of \"text-field\" requires a style \"glyphs\" property')),\"text-font\"===o&&kr(jt(a))&&\"identity\"===Nt(a.type)&&h.push(new Dt(r,a,'\"text-font\" does not support identity functions'))),h.concat(ln({key:t.key,value:a,valueSpec:u,style:n,styleSpec:i,expressionContext:\"property\",propertyType:e,propertyKey:o}))}function tn(t){return Qr(t,\"paint\")}function en(t){return Qr(t,\"layout\")}function rn(t){var e=[],r=t.value,n=t.key,i=t.style,a=t.styleSpec;r.type||r.ref||e.push(new Dt(n,r,'either \"type\" or \"ref\" is required'));var o,s=Nt(r.type),l=Nt(r.ref);if(r.id)for(var c=Nt(r.id),u=0;u<t.arrayIndex;u++){var h=i.layers[u];Nt(h.id)===c&&e.push(new Dt(n,r.id,'duplicate layer id \"'+r.id+'\", previously used at line '+h.id.__line__))}if(\"ref\"in r)[\"type\",\"source\",\"source-layer\",\"filter\",\"layout\"].forEach(function(t){t in r&&e.push(new Dt(n,r[t],'\"'+t+'\" is prohibited for ref layers'))}),i.layers.forEach(function(t){Nt(t.id)===l&&(o=t)}),o?o.ref?e.push(new Dt(n,r.ref,\"ref cannot reference another ref layer\")):s=Nt(o.type):e.push(new Dt(n,r.ref,'ref layer \"'+l+'\" not found'));else if(\"background\"!==s)if(r.source){var f=i.sources&&i.sources[r.source],p=f&&Nt(f.type);f?\"vector\"===p&&\"raster\"===s?e.push(new Dt(n,r.source,'layer \"'+r.id+'\" requires a raster source')):\"raster\"===p&&\"raster\"!==s?e.push(new Dt(n,r.source,'layer \"'+r.id+'\" requires a vector source')):\"vector\"!==p||r[\"source-layer\"]?\"raster-dem\"===p&&\"hillshade\"!==s?e.push(new Dt(n,r.source,\"raster-dem source can only be used with layer type 'hillshade'.\")):\"line\"!==s||!r.paint||!r.paint[\"line-gradient\"]||\"geojson\"===p&&f.lineMetrics||e.push(new Dt(n,r,'layer \"'+r.id+'\" specifies a line-gradient, which requires a GeoJSON source with `lineMetrics` enabled.')):e.push(new Dt(n,r,'layer \"'+r.id+'\" must specify a \"source-layer\"')):e.push(new Dt(n,r.source,'source \"'+r.source+'\" not found'))}else e.push(new Dt(n,r,'missing required property \"source\"'));return e=e.concat(Fr({key:n,value:r,valueSpec:a.layer,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(){return[]},type:function(){return ln({key:n+\".type\",value:r.type,valueSpec:a.layer.type,style:t.style,styleSpec:t.styleSpec,object:r,objectKey:\"type\"})},filter:$r,layout:function(t){return Fr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return en(Ft({layerType:s},t))}}})},paint:function(t){return Fr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return tn(Ft({layerType:s},t))}}})}}}))}function nn(t){var e=t.value,r=t.key,n=t.styleSpec,i=t.style;if(!e.type)return[new Dt(r,e,'\"type\" is required')];var a,o=Nt(e.type);switch(o){case\"vector\":case\"raster\":case\"raster-dem\":if(a=Fr({key:r,value:e,valueSpec:n[\"source_\"+o.replace(\"-\",\"_\")],style:t.style,styleSpec:n}),\"url\"in e)for(var s in e)[\"type\",\"url\",\"tileSize\"].indexOf(s)<0&&a.push(new Dt(r+\".\"+s,e[s],'a source with a \"url\" property may not include a \"'+s+'\" property'));return a;case\"geojson\":if(a=Fr({key:r,value:e,valueSpec:n.source_geojson,style:i,styleSpec:n}),e.cluster)for(var l in e.clusterProperties){var c=e.clusterProperties[l],u=c[0],h=c[1],f=\"string\"==typeof u?[u,[\"accumulated\"],[\"get\",l]]:u;a.push.apply(a,Ur({key:r+\".\"+l+\".map\",value:h,expressionContext:\"cluster-map\"})),a.push.apply(a,Ur({key:r+\".\"+l+\".reduce\",value:f,expressionContext:\"cluster-reduce\"}))}return a;case\"video\":return Fr({key:r,value:e,valueSpec:n.source_video,style:i,styleSpec:n});case\"image\":return Fr({key:r,value:e,valueSpec:n.source_image,style:i,styleSpec:n});case\"canvas\":return[new Dt(r,null,\"Please use runtime APIs to add canvas sources, rather than including them in stylesheets.\",\"source.canvas\")];default:return Vr({key:r+\".type\",value:e.type,valueSpec:{values:[\"vector\",\"raster\",\"raster-dem\",\"geojson\",\"video\",\"image\"]},style:i,styleSpec:n})}}function an(t){var e=t.value,r=t.styleSpec,n=r.light,i=t.style,a=[],o=wr(e);if(void 0===e)return a;if(\"object\"!==o)return a.concat([new Dt(\"light\",e,\"object expected, \"+o+\" found\")]);for(var s in e){var l=s.match(/^(.*)-transition$/);a=l&&n[l[1]]&&n[l[1]].transition?a.concat(ln({key:s,value:e[s],valueSpec:r.transition,style:i,styleSpec:r})):n[s]?a.concat(ln({key:s,value:e[s],valueSpec:n[s],style:i,styleSpec:r})):a.concat([new Dt(s,e[s],'unknown property \"'+s+'\"')])}return a}function on(t){var e=t.value,r=t.key,n=wr(e);return\"string\"!==n?[new Dt(r,e,\"string expected, \"+n+\" found\")]:[]}var sn={\"*\":function(){return[]},array:Br,boolean:function(t){var e=t.value,r=t.key,n=wr(e);return\"boolean\"!==n?[new Dt(r,e,\"boolean expected, \"+n+\" found\")]:[]},number:Nr,color:function(t){var e=t.key,r=t.value,n=wr(r);return\"string\"!==n?[new Dt(e,r,\"color expected, \"+n+\" found\")]:null===re(r)?[new Dt(e,r,'color expected, \"'+r+'\" found')]:[]},constants:Rt,enum:Vr,filter:$r,function:jr,layer:rn,object:Fr,source:nn,light:an,string:on,formatted:function(t){return 0===on(t).length?[]:Ur(t)}};function ln(t){var e=t.value,r=t.valueSpec,n=t.styleSpec;return r.expression&&kr(Nt(e))?jr(t):r.expression&&Pr(jt(e))?Ur(t):r.type&&sn[r.type]?sn[r.type](t):Fr(Ft({},t,{valueSpec:r.type?n[r.type]:r}))}function cn(t){var e=t.value,r=t.key,n=on(t);return n.length?n:(-1===e.indexOf(\"{fontstack}\")&&n.push(new Dt(r,e,'\"glyphs\" url must include a \"{fontstack}\" token')),-1===e.indexOf(\"{range}\")&&n.push(new Dt(r,e,'\"glyphs\" url must include a \"{range}\" token')),n)}function un(t,e){e=e||It;var r=[];return r=r.concat(ln({key:\"\",value:t,valueSpec:e.$root,styleSpec:e,style:t,objectElementValidators:{glyphs:cn,\"*\":function(){return[]}}})),t.constants&&(r=r.concat(Rt({key:\"constants\",value:t.constants,style:t,styleSpec:e}))),hn(r)}function hn(t){return[].concat(t).sort(function(t,e){return t.line-e.line})}function fn(t){return function(){for(var e=[],r=arguments.length;r--;)e[r]=arguments[r];return hn(t.apply(this,e))}}un.source=fn(nn),un.light=fn(an),un.layer=fn(rn),un.filter=fn($r),un.paintProperty=fn(tn),un.layoutProperty=fn(en);var pn=un,dn=pn.light,gn=pn.paintProperty,vn=pn.layoutProperty;function mn(t,e){var r=!1;if(e&&e.length)for(var n=0,i=e;n<i.length;n+=1){var a=i[n];t.fire(new Ot(new Error(a.message))),r=!0}return r}var yn=bn,xn=3;function bn(t,e,r){var n=this.cells=[];if(t instanceof ArrayBuffer){this.arrayBuffer=t;var i=new Int32Array(this.arrayBuffer);t=i[0],e=i[1],r=i[2],this.d=e+2*r;for(var a=0;a<this.d*this.d;a++){var o=i[xn+a],s=i[xn+a+1];n.push(o===s?null:i.subarray(o,s))}var l=i[xn+n.length],c=i[xn+n.length+1];this.keys=i.subarray(l,c),this.bboxes=i.subarray(c),this.insert=this._insertReadonly}else{this.d=e+2*r;for(var u=0;u<this.d*this.d;u++)n.push([]);this.keys=[],this.bboxes=[]}this.n=e,this.extent=t,this.padding=r,this.scale=e/t,this.uid=0;var h=r/e*t;this.min=-h,this.max=t+h}bn.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertCell,this.uid++),this.keys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},bn.prototype._insertReadonly=function(){throw\"Cannot insert into a GridIndex created from an ArrayBuffer.\"},bn.prototype._insertCell=function(t,e,r,n,i,a){this.cells[i].push(a)},bn.prototype.query=function(t,e,r,n,i){var a=this.min,o=this.max;if(t<=a&&e<=a&&o<=r&&o<=n&&!i)return Array.prototype.slice.call(this.keys);var s=[];return this._forEachCell(t,e,r,n,this._queryCell,s,{},i),s},bn.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=this.cells[i];if(null!==l)for(var c=this.keys,u=this.bboxes,h=0;h<l.length;h++){var f=l[h];if(void 0===o[f]){var p=4*f;(s?s(u[p+0],u[p+1],u[p+2],u[p+3]):t<=u[p+2]&&e<=u[p+3]&&r>=u[p+0]&&n>=u[p+1])?(o[f]=!0,a.push(c[f])):o[f]=!1}}},bn.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToCellCoord(t),c=this._convertToCellCoord(e),u=this._convertToCellCoord(r),h=this._convertToCellCoord(n),f=l;f<=u;f++)for(var p=c;p<=h;p++){var d=this.d*p+f;if((!s||s(this._convertFromCellCoord(f),this._convertFromCellCoord(p),this._convertFromCellCoord(f+1),this._convertFromCellCoord(p+1)))&&i.call(this,t,e,r,n,d,a,o,s))return}},bn.prototype._convertFromCellCoord=function(t){return(t-this.padding)/this.scale},bn.prototype._convertToCellCoord=function(t){return Math.max(0,Math.min(this.d-1,Math.floor(t*this.scale)+this.padding))},bn.prototype.toArrayBuffer=function(){if(this.arrayBuffer)return this.arrayBuffer;for(var t=this.cells,e=xn+this.cells.length+1+1,r=0,n=0;n<this.cells.length;n++)r+=this.cells[n].length;var i=new Int32Array(e+r+this.keys.length+this.bboxes.length);i[0]=this.extent,i[1]=this.n,i[2]=this.padding;for(var a=e,o=0;o<t.length;o++){var s=t[o];i[xn+o]=a,i.set(s,a),a+=s.length}return i[xn+t.length]=a,i.set(this.keys,a),a+=this.keys.length,i[xn+t.length+1]=a,i.set(this.bboxes,a),a+=this.bboxes.length,i.buffer};var _n=self.ImageData,wn={};function kn(t,e,r){void 0===r&&(r={}),Object.defineProperty(e,\"_classRegistryKey\",{value:t,writeable:!1}),wn[t]={klass:e,omit:r.omit||[],shallow:r.shallow||[]}}for(var Tn in kn(\"Object\",Object),yn.serialize=function(t,e){var r=t.toArrayBuffer();return e&&e.push(r),{buffer:r}},yn.deserialize=function(t){return new yn(t.buffer)},kn(\"Grid\",yn),kn(\"Color\",ne),kn(\"Error\",Error),kn(\"StylePropertyFunction\",Rr),kn(\"StyleExpression\",Lr,{omit:[\"_evaluator\"]}),kn(\"ZoomDependentExpression\",Ir),kn(\"ZoomConstantExpression\",zr),kn(\"CompoundExpression\",xe,{omit:[\"_evaluate\"]}),fr)fr[Tn]._classRegistryKey||kn(\"Expression_\"+Tn,fr[Tn]);function An(t,e){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp)return t;if(t instanceof ArrayBuffer)return e&&e.push(t),t;if(ArrayBuffer.isView(t)){var r=t;return e&&e.push(r.buffer),r}if(t instanceof _n)return e&&e.push(t.data.buffer),t;if(Array.isArray(t)){for(var n=[],i=0,a=t;i<a.length;i+=1){var o=a[i];n.push(An(o,e))}return n}if(\"object\"==typeof t){var s=t.constructor,l=s._classRegistryKey;if(!l)throw new Error(\"can't serialize object of unregistered class\");var c=s.serialize?s.serialize(t,e):{};if(!s.serialize){for(var u in t)if(t.hasOwnProperty(u)&&!(wn[l].omit.indexOf(u)>=0)){var h=t[u];c[u]=wn[l].shallow.indexOf(u)>=0?h:An(h,e)}t instanceof Error&&(c.message=t.message)}if(c.$name)throw new Error(\"$name property is reserved for worker serialization logic.\");return\"Object\"!==l&&(c.$name=l),c}throw new Error(\"can't serialize object of type \"+typeof t)}function Mn(t){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp||t instanceof ArrayBuffer||ArrayBuffer.isView(t)||t instanceof _n)return t;if(Array.isArray(t))return t.map(Mn);if(\"object\"==typeof t){var e=t.$name||\"Object\",r=wn[e].klass;if(!r)throw new Error(\"can't deserialize unregistered class \"+e);if(r.deserialize)return r.deserialize(t);for(var n=Object.create(r.prototype),i=0,a=Object.keys(t);i<a.length;i+=1){var o=a[i];if(\"$name\"!==o){var s=t[o];n[o]=wn[e].shallow.indexOf(o)>=0?s:Mn(s)}}return n}throw new Error(\"can't deserialize object of type \"+typeof t)}var Sn=function(){this.first=!0};Sn.prototype.update=function(t,e){var r=Math.floor(t);return this.first?(this.first=!1,this.lastIntegerZoom=r,this.lastIntegerZoomTime=0,this.lastZoom=t,this.lastFloorZoom=r,!0):(this.lastFloorZoom>r?(this.lastIntegerZoom=r+1,this.lastIntegerZoomTime=e):this.lastFloorZoom<r&&(this.lastIntegerZoom=r,this.lastIntegerZoomTime=e),t!==this.lastZoom&&(this.lastZoom=t,this.lastFloorZoom=r,!0))};var En={\"Latin-1 Supplement\":function(t){return t>=128&&t<=255},Arabic:function(t){return t>=1536&&t<=1791},\"Arabic Supplement\":function(t){return t>=1872&&t<=1919},\"Arabic Extended-A\":function(t){return t>=2208&&t<=2303},\"Hangul Jamo\":function(t){return t>=4352&&t<=4607},\"Unified Canadian Aboriginal Syllabics\":function(t){return t>=5120&&t<=5759},Khmer:function(t){return t>=6016&&t<=6143},\"Unified Canadian Aboriginal Syllabics Extended\":function(t){return t>=6320&&t<=6399},\"General Punctuation\":function(t){return t>=8192&&t<=8303},\"Letterlike Symbols\":function(t){return t>=8448&&t<=8527},\"Number Forms\":function(t){return t>=8528&&t<=8591},\"Miscellaneous Technical\":function(t){return t>=8960&&t<=9215},\"Control Pictures\":function(t){return t>=9216&&t<=9279},\"Optical Character Recognition\":function(t){return t>=9280&&t<=9311},\"Enclosed Alphanumerics\":function(t){return t>=9312&&t<=9471},\"Geometric Shapes\":function(t){return t>=9632&&t<=9727},\"Miscellaneous Symbols\":function(t){return t>=9728&&t<=9983},\"Miscellaneous Symbols and Arrows\":function(t){return t>=11008&&t<=11263},\"CJK Radicals Supplement\":function(t){return t>=11904&&t<=12031},\"Kangxi Radicals\":function(t){return t>=12032&&t<=12255},\"Ideographic Description Characters\":function(t){return t>=12272&&t<=12287},\"CJK Symbols and Punctuation\":function(t){return t>=12288&&t<=12351},Hiragana:function(t){return t>=12352&&t<=12447},Katakana:function(t){return t>=12448&&t<=12543},Bopomofo:function(t){return t>=12544&&t<=12591},\"Hangul Compatibility Jamo\":function(t){return t>=12592&&t<=12687},Kanbun:function(t){return t>=12688&&t<=12703},\"Bopomofo Extended\":function(t){return t>=12704&&t<=12735},\"CJK Strokes\":function(t){return t>=12736&&t<=12783},\"Katakana Phonetic Extensions\":function(t){return t>=12784&&t<=12799},\"Enclosed CJK Letters and Months\":function(t){return t>=12800&&t<=13055},\"CJK Compatibility\":function(t){return t>=13056&&t<=13311},\"CJK Unified Ideographs Extension A\":function(t){return t>=13312&&t<=19903},\"Yijing Hexagram Symbols\":function(t){return t>=19904&&t<=19967},\"CJK Unified Ideographs\":function(t){return t>=19968&&t<=40959},\"Yi Syllables\":function(t){return t>=40960&&t<=42127},\"Yi Radicals\":function(t){return t>=42128&&t<=42191},\"Hangul Jamo Extended-A\":function(t){return t>=43360&&t<=43391},\"Hangul Syllables\":function(t){return t>=44032&&t<=55215},\"Hangul Jamo Extended-B\":function(t){return t>=55216&&t<=55295},\"Private Use Area\":function(t){return t>=57344&&t<=63743},\"CJK Compatibility Ideographs\":function(t){return t>=63744&&t<=64255},\"Arabic Presentation Forms-A\":function(t){return t>=64336&&t<=65023},\"Vertical Forms\":function(t){return t>=65040&&t<=65055},\"CJK Compatibility Forms\":function(t){return t>=65072&&t<=65103},\"Small Form Variants\":function(t){return t>=65104&&t<=65135},\"Arabic Presentation Forms-B\":function(t){return t>=65136&&t<=65279},\"Halfwidth and Fullwidth Forms\":function(t){return t>=65280&&t<=65519}};function Cn(t){for(var e=0,r=t;e<r.length;e+=1)if(On(r[e].charCodeAt(0)))return!0;return!1}function Ln(t){for(var e=0,r=t;e<r.length;e+=1)if(!Pn(r[e].charCodeAt(0)))return!1;return!0}function Pn(t){return!(En.Arabic(t)||En[\"Arabic Supplement\"](t)||En[\"Arabic Extended-A\"](t)||En[\"Arabic Presentation Forms-A\"](t)||En[\"Arabic Presentation Forms-B\"](t))}function On(t){return!!(746===t||747===t||!(t<4352)&&(En[\"Bopomofo Extended\"](t)||En.Bopomofo(t)||En[\"CJK Compatibility Forms\"](t)&&!(t>=65097&&t<=65103)||En[\"CJK Compatibility Ideographs\"](t)||En[\"CJK Compatibility\"](t)||En[\"CJK Radicals Supplement\"](t)||En[\"CJK Strokes\"](t)||!(!En[\"CJK Symbols and Punctuation\"](t)||t>=12296&&t<=12305||t>=12308&&t<=12319||12336===t)||En[\"CJK Unified Ideographs Extension A\"](t)||En[\"CJK Unified Ideographs\"](t)||En[\"Enclosed CJK Letters and Months\"](t)||En[\"Hangul Compatibility Jamo\"](t)||En[\"Hangul Jamo Extended-A\"](t)||En[\"Hangul Jamo Extended-B\"](t)||En[\"Hangul Jamo\"](t)||En[\"Hangul Syllables\"](t)||En.Hiragana(t)||En[\"Ideographic Description Characters\"](t)||En.Kanbun(t)||En[\"Kangxi Radicals\"](t)||En[\"Katakana Phonetic Extensions\"](t)||En.Katakana(t)&&12540!==t||!(!En[\"Halfwidth and Fullwidth Forms\"](t)||65288===t||65289===t||65293===t||t>=65306&&t<=65310||65339===t||65341===t||65343===t||t>=65371&&t<=65503||65507===t||t>=65512&&t<=65519)||!(!En[\"Small Form Variants\"](t)||t>=65112&&t<=65118||t>=65123&&t<=65126)||En[\"Unified Canadian Aboriginal Syllabics\"](t)||En[\"Unified Canadian Aboriginal Syllabics Extended\"](t)||En[\"Vertical Forms\"](t)||En[\"Yijing Hexagram Symbols\"](t)||En[\"Yi Syllables\"](t)||En[\"Yi Radicals\"](t)))}function zn(t){return!(On(t)||function(t){return!!(En[\"Latin-1 Supplement\"](t)&&(167===t||169===t||174===t||177===t||188===t||189===t||190===t||215===t||247===t)||En[\"General Punctuation\"](t)&&(8214===t||8224===t||8225===t||8240===t||8241===t||8251===t||8252===t||8258===t||8263===t||8264===t||8265===t||8273===t)||En[\"Letterlike Symbols\"](t)||En[\"Number Forms\"](t)||En[\"Miscellaneous Technical\"](t)&&(t>=8960&&t<=8967||t>=8972&&t<=8991||t>=8996&&t<=9e3||9003===t||t>=9085&&t<=9114||t>=9150&&t<=9165||9167===t||t>=9169&&t<=9179||t>=9186&&t<=9215)||En[\"Control Pictures\"](t)&&9251!==t||En[\"Optical Character Recognition\"](t)||En[\"Enclosed Alphanumerics\"](t)||En[\"Geometric Shapes\"](t)||En[\"Miscellaneous Symbols\"](t)&&!(t>=9754&&t<=9759)||En[\"Miscellaneous Symbols and Arrows\"](t)&&(t>=11026&&t<=11055||t>=11088&&t<=11097||t>=11192&&t<=11243)||En[\"CJK Symbols and Punctuation\"](t)||En.Katakana(t)||En[\"Private Use Area\"](t)||En[\"CJK Compatibility Forms\"](t)||En[\"Small Form Variants\"](t)||En[\"Halfwidth and Fullwidth Forms\"](t)||8734===t||8756===t||8757===t||t>=9984&&t<=10087||t>=10102&&t<=10131||65532===t||65533===t)}(t))}function In(t,e){return!(!e&&(t>=1424&&t<=2303||En[\"Arabic Presentation Forms-A\"](t)||En[\"Arabic Presentation Forms-B\"](t))||t>=2304&&t<=3583||t>=3840&&t<=4255||En.Khmer(t))}var Dn,Rn=!1,Fn=null,Bn=!1,Nn=new zt,jn={applyArabicShaping:null,processBidirectionalText:null,processStyledBidirectionalText:null,isLoaded:function(){return Bn||null!=jn.applyArabicShaping}},Un=function(t,e){this.zoom=t,e?(this.now=e.now,this.fadeDuration=e.fadeDuration,this.zoomHistory=e.zoomHistory,this.transition=e.transition):(this.now=0,this.fadeDuration=0,this.zoomHistory=new Sn,this.transition={})};Un.prototype.isSupportedScript=function(t){return function(t,e){for(var r=0,n=t;r<n.length;r+=1)if(!In(n[r].charCodeAt(0),e))return!1;return!0}(t,jn.isLoaded())},Un.prototype.crossFadingFactor=function(){return 0===this.fadeDuration?1:Math.min((this.now-this.zoomHistory.lastIntegerZoomTime)/this.fadeDuration,1)},Un.prototype.getCrossfadeParameters=function(){var t=this.zoom,e=t-Math.floor(t),r=this.crossFadingFactor();return t>this.zoomHistory.lastIntegerZoom?{fromScale:2,toScale:1,t:e+(1-e)*r}:{fromScale:.5,toScale:1,t:1-(1-r)*e}};var Vn=function(t,e){this.property=t,this.value=e,this.expression=function(t,e){if(kr(t))return new Rr(t,e);if(Pr(t)){var r=Dr(t,e);if(\"error\"===r.result)throw new Error(r.value.map(function(t){return t.key+\": \"+t.message}).join(\", \"));return r.value}var n=t;return\"string\"==typeof t&&\"color\"===e.type&&(n=ne.parse(t)),{kind:\"constant\",evaluate:function(){return n}}}(void 0===e?t.specification.default:e,t.specification)};Vn.prototype.isDataDriven=function(){return\"source\"===this.expression.kind||\"composite\"===this.expression.kind},Vn.prototype.possiblyEvaluate=function(t){return this.property.possiblyEvaluate(this,t)};var qn=function(t){this.property=t,this.value=new Vn(t,void 0)};qn.prototype.transitioned=function(t,e){return new Gn(this.property,this.value,e,h({},t.transition,this.transition),t.now)},qn.prototype.untransitioned=function(){return new Gn(this.property,this.value,null,{},0)};var Hn=function(t){this._properties=t,this._values=Object.create(t.defaultTransitionablePropertyValues)};Hn.prototype.getValue=function(t){return b(this._values[t].value.value)},Hn.prototype.setValue=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new qn(this._values[t].property)),this._values[t].value=new Vn(this._values[t].property,null===e?void 0:b(e))},Hn.prototype.getTransition=function(t){return b(this._values[t].transition)},Hn.prototype.setTransition=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new qn(this._values[t].property)),this._values[t].transition=b(e)||void 0},Hn.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i);var a=this.getTransition(n);void 0!==a&&(t[n+\"-transition\"]=a)}return t},Hn.prototype.transitioned=function(t,e){for(var r=new Yn(this._properties),n=0,i=Object.keys(this._values);n<i.length;n+=1){var a=i[n];r._values[a]=this._values[a].transitioned(t,e._values[a])}return r},Hn.prototype.untransitioned=function(){for(var t=new Yn(this._properties),e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e];t._values[n]=this._values[n].untransitioned()}return t};var Gn=function(t,e,r,n,i){this.property=t,this.value=e,this.begin=i+n.delay||0,this.end=this.begin+n.duration||0,t.specification.transition&&(n.delay||n.duration)&&(this.prior=r)};Gn.prototype.possiblyEvaluate=function(t){var e=t.now||0,r=this.value.possiblyEvaluate(t),n=this.prior;if(n){if(e>this.end)return this.prior=null,r;if(this.value.isDataDriven())return this.prior=null,r;if(e<this.begin)return n.possiblyEvaluate(t);var i=(e-this.begin)/(this.end-this.begin);return this.property.interpolate(n.possiblyEvaluate(t),r,function(t){if(i<=0)return 0;if(i>=1)return 1;var e=i*i,r=e*i;return 4*(i<.5?r:3*(i-e)+r-.75)}())}return r};var Yn=function(t){this._properties=t,this._values=Object.create(t.defaultTransitioningPropertyValues)};Yn.prototype.possiblyEvaluate=function(t){for(var e=new Zn(this._properties),r=0,n=Object.keys(this._values);r<n.length;r+=1){var i=n[r];e._values[i]=this._values[i].possiblyEvaluate(t)}return e},Yn.prototype.hasTransition=function(){for(var t=0,e=Object.keys(this._values);t<e.length;t+=1){var r=e[t];if(this._values[r].prior)return!0}return!1};var Wn=function(t){this._properties=t,this._values=Object.create(t.defaultPropertyValues)};Wn.prototype.getValue=function(t){return b(this._values[t].value)},Wn.prototype.setValue=function(t,e){this._values[t]=new Vn(this._values[t].property,null===e?void 0:b(e))},Wn.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i)}return t},Wn.prototype.possiblyEvaluate=function(t){for(var e=new Zn(this._properties),r=0,n=Object.keys(this._values);r<n.length;r+=1){var i=n[r];e._values[i]=this._values[i].possiblyEvaluate(t)}return e};var Xn=function(t,e,r){this.property=t,this.value=e,this.parameters=r};Xn.prototype.isConstant=function(){return\"constant\"===this.value.kind},Xn.prototype.constantOr=function(t){return\"constant\"===this.value.kind?this.value.value:t},Xn.prototype.evaluate=function(t,e){return this.property.evaluate(this.value,this.parameters,t,e)};var Zn=function(t){this._properties=t,this._values=Object.create(t.defaultPossiblyEvaluatedValues)};Zn.prototype.get=function(t){return this._values[t]};var Jn=function(t){this.specification=t};Jn.prototype.possiblyEvaluate=function(t,e){return t.expression.evaluate(e)},Jn.prototype.interpolate=function(t,e,r){var n=Ce[this.specification.type];return n?n(t,e,r):t};var Kn=function(t){this.specification=t};Kn.prototype.possiblyEvaluate=function(t,e){return\"constant\"===t.expression.kind||\"camera\"===t.expression.kind?new Xn(this,{kind:\"constant\",value:t.expression.evaluate(e)},e):new Xn(this,t.expression,e)},Kn.prototype.interpolate=function(t,e,r){if(\"constant\"!==t.value.kind||\"constant\"!==e.value.kind)return t;if(void 0===t.value.value||void 0===e.value.value)return new Xn(this,{kind:\"constant\",value:void 0},t.parameters);var n=Ce[this.specification.type];return n?new Xn(this,{kind:\"constant\",value:n(t.value.value,e.value.value,r)},t.parameters):t},Kn.prototype.evaluate=function(t,e,r,n){return\"constant\"===t.kind?t.value:t.evaluate(e,r,n)};var $n=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(t,e){if(void 0===t.value)return new Xn(this,{kind:\"constant\",value:void 0},e);if(\"constant\"===t.expression.kind){var r=t.expression.evaluate(e),n=this._calculate(r,r,r,e);return new Xn(this,{kind:\"constant\",value:n},e)}if(\"camera\"===t.expression.kind){var i=this._calculate(t.expression.evaluate({zoom:e.zoom-1}),t.expression.evaluate({zoom:e.zoom}),t.expression.evaluate({zoom:e.zoom+1}),e);return new Xn(this,{kind:\"constant\",value:i},e)}return new Xn(this,t.expression,e)},e.prototype.evaluate=function(t,e,r,n){if(\"source\"===t.kind){var i=t.evaluate(e,r,n);return this._calculate(i,i,i,e)}return\"composite\"===t.kind?this._calculate(t.evaluate({zoom:Math.floor(e.zoom)-1},r,n),t.evaluate({zoom:Math.floor(e.zoom)},r,n),t.evaluate({zoom:Math.floor(e.zoom)+1},r,n),e):t.value},e.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},e.prototype.interpolate=function(t){return t},e}(Kn),Qn=function(t){this.specification=t};Qn.prototype.possiblyEvaluate=function(t,e){if(void 0!==t.value){if(\"constant\"===t.expression.kind){var r=t.expression.evaluate(e);return this._calculate(r,r,r,e)}return this._calculate(t.expression.evaluate(new Un(Math.floor(e.zoom-1),e)),t.expression.evaluate(new Un(Math.floor(e.zoom),e)),t.expression.evaluate(new Un(Math.floor(e.zoom+1),e)),e)}},Qn.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},Qn.prototype.interpolate=function(t){return t};var ti=function(t){this.specification=t};ti.prototype.possiblyEvaluate=function(t,e){return!!t.expression.evaluate(e)},ti.prototype.interpolate=function(){return!1};var ei=function(t){for(var e in this.properties=t,this.defaultPropertyValues={},this.defaultTransitionablePropertyValues={},this.defaultTransitioningPropertyValues={},this.defaultPossiblyEvaluatedValues={},t){var r=t[e],n=this.defaultPropertyValues[e]=new Vn(r,void 0),i=this.defaultTransitionablePropertyValues[e]=new qn(r);this.defaultTransitioningPropertyValues[e]=i.untransitioned(),this.defaultPossiblyEvaluatedValues[e]=n.possiblyEvaluate({})}};kn(\"DataDrivenProperty\",Kn),kn(\"DataConstantProperty\",Jn),kn(\"CrossFadedDataDrivenProperty\",$n),kn(\"CrossFadedProperty\",Qn),kn(\"ColorRampProperty\",ti);var ri=function(t){function e(e,r){if(t.call(this),this.id=e.id,this.type=e.type,this._featureFilter=function(){return!0},\"custom\"!==e.type&&(e=e,this.metadata=e.metadata,this.minzoom=e.minzoom,this.maxzoom=e.maxzoom,\"background\"!==e.type&&(this.source=e.source,this.sourceLayer=e[\"source-layer\"],this.filter=e.filter),r.layout&&(this._unevaluatedLayout=new Wn(r.layout)),r.paint)){for(var n in this._transitionablePaint=new Hn(r.paint),e.paint)this.setPaintProperty(n,e.paint[n],{validate:!1});for(var i in e.layout)this.setLayoutProperty(i,e.layout[i],{validate:!1});this._transitioningPaint=this._transitionablePaint.untransitioned()}}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getCrossfadeParameters=function(){return this._crossfadeParameters},e.prototype.getLayoutProperty=function(t){return\"visibility\"===t?this.visibility:this._unevaluatedLayout.getValue(t)},e.prototype.setLayoutProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e){var n=\"layers.\"+this.id+\".layout.\"+t;if(this._validate(vn,n,t,e,r))return}\"visibility\"!==t?this._unevaluatedLayout.setValue(t,e):this.visibility=e},e.prototype.getPaintProperty=function(t){return m(t,\"-transition\")?this._transitionablePaint.getTransition(t.slice(0,-\"-transition\".length)):this._transitionablePaint.getValue(t)},e.prototype.setPaintProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e){var n=\"layers.\"+this.id+\".paint.\"+t;if(this._validate(gn,n,t,e,r))return!1}if(m(t,\"-transition\"))return this._transitionablePaint.setTransition(t.slice(0,-\"-transition\".length),e||void 0),!1;var i=this._transitionablePaint._values[t],a=\"cross-faded-data-driven\"===i.property.specification[\"property-type\"],o=i.value.isDataDriven();return this._transitionablePaint.setValue(t,e),this._handleSpecialPaintPropertyUpdate(t),this._transitionablePaint._values[t].value.isDataDriven()||o||a},e.prototype._handleSpecialPaintPropertyUpdate=function(t){},e.prototype.isHidden=function(t){return!!(this.minzoom&&t<this.minzoom)||!!(this.maxzoom&&t>=this.maxzoom)||\"none\"===this.visibility},e.prototype.updateTransitions=function(t){this._transitioningPaint=this._transitionablePaint.transitioned(t,this._transitioningPaint)},e.prototype.hasTransition=function(){return this._transitioningPaint.hasTransition()},e.prototype.recalculate=function(t){t.getCrossfadeParameters&&(this._crossfadeParameters=t.getCrossfadeParameters()),this._unevaluatedLayout&&(this.layout=this._unevaluatedLayout.possiblyEvaluate(t)),this.paint=this._transitioningPaint.possiblyEvaluate(t)},e.prototype.serialize=function(){var t={id:this.id,type:this.type,source:this.source,\"source-layer\":this.sourceLayer,metadata:this.metadata,minzoom:this.minzoom,maxzoom:this.maxzoom,filter:this.filter,layout:this._unevaluatedLayout&&this._unevaluatedLayout.serialize(),paint:this._transitionablePaint&&this._transitionablePaint.serialize()};return this.visibility&&(t.layout=t.layout||{},t.layout.visibility=this.visibility),x(t,function(t,e){return!(void 0===t||\"layout\"===e&&!Object.keys(t).length||\"paint\"===e&&!Object.keys(t).length)})},e.prototype._validate=function(t,e,r,n,i){return void 0===i&&(i={}),(!i||!1!==i.validate)&&mn(this,t.call(pn,{key:e,layerType:this.type,objectKey:r,value:n,styleSpec:It,style:{glyphs:!0,sprite:!0}}))},e.prototype.is3D=function(){return!1},e.prototype.isTileClipped=function(){return!1},e.prototype.hasOffscreenPass=function(){return!1},e.prototype.resize=function(){},e.prototype.isStateDependent=function(){for(var t in this.paint._values){var e=this.paint.get(t);if(e instanceof Xn&&xr(e.property.specification)&&(\"source\"===e.value.kind||\"composite\"===e.value.kind)&&e.value.isStateDependent)return!0}return!1},e}(zt),ni={Int8:Int8Array,Uint8:Uint8Array,Int16:Int16Array,Uint16:Uint16Array,Int32:Int32Array,Uint32:Uint32Array,Float32:Float32Array},ii=function(t,e){this._structArray=t,this._pos1=e*this.size,this._pos2=this._pos1/2,this._pos4=this._pos1/4,this._pos8=this._pos1/8},ai=function(){this.isTransferred=!1,this.capacity=-1,this.resize(0)};function oi(t,e){void 0===e&&(e=1);var r=0,n=0;return{members:t.map(function(t){var i,a=(i=t.type,ni[i].BYTES_PER_ELEMENT),o=r=si(r,Math.max(e,a)),s=t.components||1;return n=Math.max(n,a),r+=a*s,{name:t.name,type:t.type,components:s,offset:o}}),size:si(r,Math.max(n,e)),alignment:e}}function si(t,e){return Math.ceil(t/e)*e}ai.serialize=function(t,e){return t._trim(),e&&(t.isTransferred=!0,e.push(t.arrayBuffer)),{length:t.length,arrayBuffer:t.arrayBuffer}},ai.deserialize=function(t){var e=Object.create(this.prototype);return e.arrayBuffer=t.arrayBuffer,e.length=t.length,e.capacity=t.arrayBuffer.byteLength/e.bytesPerElement,e._refreshViews(),e},ai.prototype._trim=function(){this.length!==this.capacity&&(this.capacity=this.length,this.arrayBuffer=this.arrayBuffer.slice(0,this.length*this.bytesPerElement),this._refreshViews())},ai.prototype.clear=function(){this.length=0},ai.prototype.resize=function(t){this.reserve(t),this.length=t},ai.prototype.reserve=function(t){if(t>this.capacity){this.capacity=Math.max(t,Math.floor(5*this.capacity),128),this.arrayBuffer=new ArrayBuffer(this.capacity*this.bytesPerElement);var e=this.uint8;this._refreshViews(),e&&this.uint8.set(e)}},ai.prototype._refreshViews=function(){throw new Error(\"_refreshViews() must be implemented by each concrete StructArray layout\")};var li=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.int16[n+0]=e,this.int16[n+1]=r,t},e}(ai);li.prototype.bytesPerElement=4,kn(\"StructArrayLayout2i4\",li);var ci=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.int16[a+0]=e,this.int16[a+1]=r,this.int16[a+2]=n,this.int16[a+3]=i,t},e}(ai);ci.prototype.bytesPerElement=8,kn(\"StructArrayLayout4i8\",ci);var ui=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(ai);ui.prototype.bytesPerElement=12,kn(\"StructArrayLayout2i4i12\",ui);var hi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=4*t,l=8*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.uint8[l+4]=n,this.uint8[l+5]=i,this.uint8[l+6]=a,this.uint8[l+7]=o,t},e}(ai);hi.prototype.bytesPerElement=8,kn(\"StructArrayLayout2i4ub8\",hi);var fi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s){var l=this.length;return this.resize(l+1),this.emplace(l,t,e,r,n,i,a,o,s)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l){var c=8*t;return this.uint16[c+0]=e,this.uint16[c+1]=r,this.uint16[c+2]=n,this.uint16[c+3]=i,this.uint16[c+4]=a,this.uint16[c+5]=o,this.uint16[c+6]=s,this.uint16[c+7]=l,t},e}(ai);fi.prototype.bytesPerElement=16,kn(\"StructArrayLayout8ui16\",fi);var pi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s){var l=this.length;return this.resize(l+1),this.emplace(l,t,e,r,n,i,a,o,s)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l){var c=8*t;return this.int16[c+0]=e,this.int16[c+1]=r,this.int16[c+2]=n,this.int16[c+3]=i,this.uint16[c+4]=a,this.uint16[c+5]=o,this.uint16[c+6]=s,this.uint16[c+7]=l,t},e}(ai);pi.prototype.bytesPerElement=16,kn(\"StructArrayLayout4i4ui16\",pi);var di=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.float32[i+0]=e,this.float32[i+1]=r,this.float32[i+2]=n,t},e}(ai);di.prototype.bytesPerElement=12,kn(\"StructArrayLayout3f12\",di);var gi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.uint32[r+0]=e,t},e}(ai);gi.prototype.bytesPerElement=4,kn(\"StructArrayLayout1ul4\",gi);var vi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u){var h=this.length;return this.resize(h+1),this.emplace(h,t,e,r,n,i,a,o,s,l,c,u)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h){var f=12*t,p=6*t;return this.int16[f+0]=e,this.int16[f+1]=r,this.int16[f+2]=n,this.int16[f+3]=i,this.int16[f+4]=a,this.int16[f+5]=o,this.uint32[p+3]=s,this.uint16[f+8]=l,this.uint16[f+9]=c,this.int16[f+10]=u,this.int16[f+11]=h,t},e}(ai);vi.prototype.bytesPerElement=24,kn(\"StructArrayLayout6i1ul2ui2i24\",vi);var mi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(ai);mi.prototype.bytesPerElement=12,kn(\"StructArrayLayout2i2i2i12\",mi);var yi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=12*t,o=3*t;return this.uint8[a+0]=e,this.uint8[a+1]=r,this.float32[o+1]=n,this.float32[o+2]=i,t},e}(ai);yi.prototype.bytesPerElement=12,kn(\"StructArrayLayout2ub2f12\",yi);var xi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d){var g=this.length;return this.resize(g+1),this.emplace(g,t,e,r,n,i,a,o,s,l,c,u,h,f,p,d)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g){var v=22*t,m=11*t,y=44*t;return this.int16[v+0]=e,this.int16[v+1]=r,this.uint16[v+2]=n,this.uint16[v+3]=i,this.uint32[m+2]=a,this.uint32[m+3]=o,this.uint32[m+4]=s,this.uint16[v+10]=l,this.uint16[v+11]=c,this.uint16[v+12]=u,this.float32[m+7]=h,this.float32[m+8]=f,this.uint8[y+36]=p,this.uint8[y+37]=d,this.uint32[m+10]=g,t},e}(ai);xi.prototype.bytesPerElement=44,kn(\"StructArrayLayout2i2ui3ul3ui2f2ub1ul44\",xi);var bi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m){var y=this.length;return this.resize(y+1),this.emplace(y,t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m,y){var x=22*t,b=11*t;return this.int16[x+0]=e,this.int16[x+1]=r,this.int16[x+2]=n,this.int16[x+3]=i,this.int16[x+4]=a,this.int16[x+5]=o,this.uint16[x+6]=s,this.uint16[x+7]=l,this.uint16[x+8]=c,this.uint16[x+9]=u,this.uint16[x+10]=h,this.uint16[x+11]=f,this.uint16[x+12]=p,this.uint16[x+13]=d,this.uint16[x+14]=g,this.uint32[b+8]=v,this.float32[b+9]=m,this.float32[b+10]=y,t},e}(ai);bi.prototype.bytesPerElement=44,kn(\"StructArrayLayout6i9ui1ul2f44\",bi);var _i=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.float32[r+0]=e,t},e}(ai);_i.prototype.bytesPerElement=4,kn(\"StructArrayLayout1f4\",_i);var wi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.int16[i+0]=e,this.int16[i+1]=r,this.int16[i+2]=n,t},e}(ai);wi.prototype.bytesPerElement=6,kn(\"StructArrayLayout3i6\",wi);var ki=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=2*t,a=4*t;return this.uint32[i+0]=e,this.uint16[a+2]=r,this.uint16[a+3]=n,t},e}(ai);ki.prototype.bytesPerElement=8,kn(\"StructArrayLayout1ul2ui8\",ki);var Ti=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.uint16[i+0]=e,this.uint16[i+1]=r,this.uint16[i+2]=n,t},e}(ai);Ti.prototype.bytesPerElement=6,kn(\"StructArrayLayout3ui6\",Ti);var Ai=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.uint16[n+0]=e,this.uint16[n+1]=r,t},e}(ai);Ai.prototype.bytesPerElement=4,kn(\"StructArrayLayout2ui4\",Ai);var Mi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.uint16[r+0]=e,t},e}(ai);Mi.prototype.bytesPerElement=2,kn(\"StructArrayLayout1ui2\",Mi);var Si=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.float32[n+0]=e,this.float32[n+1]=r,t},e}(ai);Si.prototype.bytesPerElement=8,kn(\"StructArrayLayout2f8\",Si);var Ei=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.float32[a+0]=e,this.float32[a+1]=r,this.float32[a+2]=n,this.float32[a+3]=i,t},e}(ai);Ei.prototype.bytesPerElement=16,kn(\"StructArrayLayout4f16\",Ei);var Ci=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorPointX:{configurable:!0},anchorPointY:{configurable:!0},x1:{configurable:!0},y1:{configurable:!0},x2:{configurable:!0},y2:{configurable:!0},featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0},radius:{configurable:!0},signedDistanceFromAnchor:{configurable:!0},anchorPoint:{configurable:!0}};return r.anchorPointX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorPointX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorPointY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorPointY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.x1.get=function(){return this._structArray.int16[this._pos2+2]},r.x1.set=function(t){this._structArray.int16[this._pos2+2]=t},r.y1.get=function(){return this._structArray.int16[this._pos2+3]},r.y1.set=function(t){this._structArray.int16[this._pos2+3]=t},r.x2.get=function(){return this._structArray.int16[this._pos2+4]},r.x2.set=function(t){this._structArray.int16[this._pos2+4]=t},r.y2.get=function(){return this._structArray.int16[this._pos2+5]},r.y2.set=function(t){this._structArray.int16[this._pos2+5]=t},r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.featureIndex.set=function(t){this._structArray.uint32[this._pos4+3]=t},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.sourceLayerIndex.set=function(t){this._structArray.uint16[this._pos2+8]=t},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.bucketIndex.set=function(t){this._structArray.uint16[this._pos2+9]=t},r.radius.get=function(){return this._structArray.int16[this._pos2+10]},r.radius.set=function(t){this._structArray.int16[this._pos2+10]=t},r.signedDistanceFromAnchor.get=function(){return this._structArray.int16[this._pos2+11]},r.signedDistanceFromAnchor.set=function(t){this._structArray.int16[this._pos2+11]=t},r.anchorPoint.get=function(){return new i(this.anchorPointX,this.anchorPointY)},Object.defineProperties(e.prototype,r),e}(ii);Ci.prototype.size=24;var Li=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Ci(this,t)},e}(vi);kn(\"CollisionBoxArray\",Li);var Pi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},glyphStartIndex:{configurable:!0},numGlyphs:{configurable:!0},vertexStartIndex:{configurable:!0},lineStartIndex:{configurable:!0},lineLength:{configurable:!0},segment:{configurable:!0},lowerSize:{configurable:!0},upperSize:{configurable:!0},lineOffsetX:{configurable:!0},lineOffsetY:{configurable:!0},writingMode:{configurable:!0},hidden:{configurable:!0},crossTileID:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.glyphStartIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.glyphStartIndex.set=function(t){this._structArray.uint16[this._pos2+2]=t},r.numGlyphs.get=function(){return this._structArray.uint16[this._pos2+3]},r.numGlyphs.set=function(t){this._structArray.uint16[this._pos2+3]=t},r.vertexStartIndex.get=function(){return this._structArray.uint32[this._pos4+2]},r.vertexStartIndex.set=function(t){this._structArray.uint32[this._pos4+2]=t},r.lineStartIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.lineStartIndex.set=function(t){this._structArray.uint32[this._pos4+3]=t},r.lineLength.get=function(){return this._structArray.uint32[this._pos4+4]},r.lineLength.set=function(t){this._structArray.uint32[this._pos4+4]=t},r.segment.get=function(){return this._structArray.uint16[this._pos2+10]},r.segment.set=function(t){this._structArray.uint16[this._pos2+10]=t},r.lowerSize.get=function(){return this._structArray.uint16[this._pos2+11]},r.lowerSize.set=function(t){this._structArray.uint16[this._pos2+11]=t},r.upperSize.get=function(){return this._structArray.uint16[this._pos2+12]},r.upperSize.set=function(t){this._structArray.uint16[this._pos2+12]=t},r.lineOffsetX.get=function(){return this._structArray.float32[this._pos4+7]},r.lineOffsetX.set=function(t){this._structArray.float32[this._pos4+7]=t},r.lineOffsetY.get=function(){return this._structArray.float32[this._pos4+8]},r.lineOffsetY.set=function(t){this._structArray.float32[this._pos4+8]=t},r.writingMode.get=function(){return this._structArray.uint8[this._pos1+36]},r.writingMode.set=function(t){this._structArray.uint8[this._pos1+36]=t},r.hidden.get=function(){return this._structArray.uint8[this._pos1+37]},r.hidden.set=function(t){this._structArray.uint8[this._pos1+37]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+10]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+10]=t},Object.defineProperties(e.prototype,r),e}(ii);Pi.prototype.size=44;var Oi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Pi(this,t)},e}(xi);kn(\"PlacedSymbolArray\",Oi);var zi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},rightJustifiedTextSymbolIndex:{configurable:!0},centerJustifiedTextSymbolIndex:{configurable:!0},leftJustifiedTextSymbolIndex:{configurable:!0},verticalPlacedTextSymbolIndex:{configurable:!0},key:{configurable:!0},textBoxStartIndex:{configurable:!0},textBoxEndIndex:{configurable:!0},iconBoxStartIndex:{configurable:!0},iconBoxEndIndex:{configurable:!0},featureIndex:{configurable:!0},numHorizontalGlyphVertices:{configurable:!0},numVerticalGlyphVertices:{configurable:!0},numIconVertices:{configurable:!0},crossTileID:{configurable:!0},textBoxScale:{configurable:!0},radialTextOffset:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.rightJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+2]},r.rightJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+2]=t},r.centerJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+3]},r.centerJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+3]=t},r.leftJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+4]},r.leftJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+4]=t},r.verticalPlacedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+5]},r.verticalPlacedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+5]=t},r.key.get=function(){return this._structArray.uint16[this._pos2+6]},r.key.set=function(t){this._structArray.uint16[this._pos2+6]=t},r.textBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+7]},r.textBoxStartIndex.set=function(t){this._structArray.uint16[this._pos2+7]=t},r.textBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.textBoxEndIndex.set=function(t){this._structArray.uint16[this._pos2+8]=t},r.iconBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.iconBoxStartIndex.set=function(t){this._structArray.uint16[this._pos2+9]=t},r.iconBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+10]},r.iconBoxEndIndex.set=function(t){this._structArray.uint16[this._pos2+10]=t},r.featureIndex.get=function(){return this._structArray.uint16[this._pos2+11]},r.featureIndex.set=function(t){this._structArray.uint16[this._pos2+11]=t},r.numHorizontalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+12]},r.numHorizontalGlyphVertices.set=function(t){this._structArray.uint16[this._pos2+12]=t},r.numVerticalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+13]},r.numVerticalGlyphVertices.set=function(t){this._structArray.uint16[this._pos2+13]=t},r.numIconVertices.get=function(){return this._structArray.uint16[this._pos2+14]},r.numIconVertices.set=function(t){this._structArray.uint16[this._pos2+14]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+8]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+8]=t},r.textBoxScale.get=function(){return this._structArray.float32[this._pos4+9]},r.textBoxScale.set=function(t){this._structArray.float32[this._pos4+9]=t},r.radialTextOffset.get=function(){return this._structArray.float32[this._pos4+10]},r.radialTextOffset.set=function(t){this._structArray.float32[this._pos4+10]=t},Object.defineProperties(e.prototype,r),e}(ii);zi.prototype.size=44;var Ii=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new zi(this,t)},e}(bi);kn(\"SymbolInstanceArray\",Ii);var Di=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={offsetX:{configurable:!0}};return r.offsetX.get=function(){return this._structArray.float32[this._pos4+0]},r.offsetX.set=function(t){this._structArray.float32[this._pos4+0]=t},Object.defineProperties(e.prototype,r),e}(ii);Di.prototype.size=4;var Ri=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getoffsetX=function(t){return this.float32[1*t+0]},e.prototype.get=function(t){return new Di(this,t)},e}(_i);kn(\"GlyphOffsetArray\",Ri);var Fi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={x:{configurable:!0},y:{configurable:!0},tileUnitDistanceFromAnchor:{configurable:!0}};return r.x.get=function(){return this._structArray.int16[this._pos2+0]},r.x.set=function(t){this._structArray.int16[this._pos2+0]=t},r.y.get=function(){return this._structArray.int16[this._pos2+1]},r.y.set=function(t){this._structArray.int16[this._pos2+1]=t},r.tileUnitDistanceFromAnchor.get=function(){return this._structArray.int16[this._pos2+2]},r.tileUnitDistanceFromAnchor.set=function(t){this._structArray.int16[this._pos2+2]=t},Object.defineProperties(e.prototype,r),e}(ii);Fi.prototype.size=6;var Bi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getx=function(t){return this.int16[3*t+0]},e.prototype.gety=function(t){return this.int16[3*t+1]},e.prototype.gettileUnitDistanceFromAnchor=function(t){return this.int16[3*t+2]},e.prototype.get=function(t){return new Fi(this,t)},e}(wi);kn(\"SymbolLineVertexArray\",Bi);var Ni=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0}};return r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+0]},r.featureIndex.set=function(t){this._structArray.uint32[this._pos4+0]=t},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.sourceLayerIndex.set=function(t){this._structArray.uint16[this._pos2+2]=t},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+3]},r.bucketIndex.set=function(t){this._structArray.uint16[this._pos2+3]=t},Object.defineProperties(e.prototype,r),e}(ii);Ni.prototype.size=8;var ji=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Ni(this,t)},e}(ki);kn(\"FeatureIndexArray\",ji);var Ui=oi([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,Vi=function(t){void 0===t&&(t=[]),this.segments=t};function qi(t,e){return 256*(t=c(Math.floor(t),0,255))+c(Math.floor(e),0,255)}Vi.prototype.prepareSegment=function(t,e,r,n){var i=this.segments[this.segments.length-1];return t>Vi.MAX_VERTEX_ARRAY_LENGTH&&w(\"Max vertices per segment is \"+Vi.MAX_VERTEX_ARRAY_LENGTH+\": bucket requested \"+t),(!i||i.vertexLength+t>Vi.MAX_VERTEX_ARRAY_LENGTH||i.sortKey!==n)&&(i={vertexOffset:e.length,primitiveOffset:r.length,vertexLength:0,primitiveLength:0},void 0!==n&&(i.sortKey=n),this.segments.push(i)),i},Vi.prototype.get=function(){return this.segments},Vi.prototype.destroy=function(){for(var t=0,e=this.segments;t<e.length;t+=1){var r=e[t];for(var n in r.vaos)r.vaos[n].destroy()}},Vi.simpleSegment=function(t,e,r,n){return new Vi([{vertexOffset:t,primitiveOffset:e,vertexLength:r,primitiveLength:n,vaos:{},sortKey:0}])},Vi.MAX_VERTEX_ARRAY_LENGTH=Math.pow(2,16)-1,kn(\"SegmentVector\",Vi);var Hi=function(){this.ids=[],this.positions=[],this.indexed=!1};function Gi(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}Hi.prototype.add=function(t,e,r,n){this.ids.push(t),this.positions.push(e,r,n)},Hi.prototype.getPositions=function(t){for(var e=0,r=this.ids.length-1;e<r;){var n=e+r>>1;this.ids[n]>=t?r=n:e=n+1}for(var i=[];this.ids[e]===t;){var a=this.positions[3*e],o=this.positions[3*e+1],s=this.positions[3*e+2];i.push({index:a,start:o,end:s}),e++}return i},Hi.serialize=function(t,e){var r=new Float64Array(t.ids),n=new Uint32Array(t.positions);return function t(e,r,n,i){if(!(n>=i)){for(var a=e[n+i>>1],o=n-1,s=i+1;;){do{o++}while(e[o]<a);do{s--}while(e[s]>a);if(o>=s)break;Gi(e,o,s),Gi(r,3*o,3*s),Gi(r,3*o+1,3*s+1),Gi(r,3*o+2,3*s+2)}t(e,r,n,s),t(e,r,s+1,i)}}(r,n,0,r.length-1),e.push(r.buffer,n.buffer),{ids:r,positions:n}},Hi.deserialize=function(t){var e=new Hi;return e.ids=t.ids,e.positions=t.positions,e.indexed=!0,e},kn(\"FeaturePositionMap\",Hi);var Yi=function(t,e){this.gl=t.gl,this.location=e},Wi=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1i(this.location,t))},e}(Yi),Xi=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1f(this.location,t))},e}(Yi),Zi=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]||(this.current=t,this.gl.uniform2f(this.location,t[0],t[1]))},e}(Yi),Ji=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]||(this.current=t,this.gl.uniform3f(this.location,t[0],t[1],t[2]))},e}(Yi),Ki=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]&&t[3]===this.current[3]||(this.current=t,this.gl.uniform4f(this.location,t[0],t[1],t[2],t[3]))},e}(Yi),$i=function(t){function e(e,r){t.call(this,e,r),this.current=ne.transparent}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t.r===this.current.r&&t.g===this.current.g&&t.b===this.current.b&&t.a===this.current.a||(this.current=t,this.gl.uniform4f(this.location,t.r,t.g,t.b,t.a))},e}(Yi),Qi=new Float32Array(16),ta=function(t){function e(e,r){t.call(this,e,r),this.current=Qi}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(t[12]!==this.current[12]||t[0]!==this.current[0])return this.current=t,void this.gl.uniformMatrix4fv(this.location,!1,t);for(var e=1;e<16;e++)if(t[e]!==this.current[e]){this.current=t,this.gl.uniformMatrix4fv(this.location,!1,t);break}},e}(Yi);function ea(t){return[qi(255*t.r,255*t.g),qi(255*t.b,255*t.a)]}var ra=function(t,e,r){this.value=t,this.names=e,this.uniformNames=this.names.map(function(t){return\"u_\"+t}),this.type=r,this.maxValue=-1/0};ra.prototype.defines=function(){return this.names.map(function(t){return\"#define HAS_UNIFORM_u_\"+t})},ra.prototype.setConstantPatternPositions=function(){},ra.prototype.populatePaintArray=function(){},ra.prototype.updatePaintArray=function(){},ra.prototype.upload=function(){},ra.prototype.destroy=function(){},ra.prototype.setUniforms=function(t,e,r,n){e.set(n.constantOr(this.value))},ra.prototype.getBinding=function(t,e){return\"color\"===this.type?new $i(t,e):new Xi(t,e)},ra.serialize=function(t){var e=t.value,r=t.names,n=t.type;return{value:An(e),names:r,type:n}},ra.deserialize=function(t){var e=t.value,r=t.names,n=t.type;return new ra(Mn(e),r,n)};var na=function(t,e,r){this.value=t,this.names=e,this.uniformNames=this.names.map(function(t){return\"u_\"+t}),this.type=r,this.maxValue=-1/0,this.patternPositions={patternTo:null,patternFrom:null}};na.prototype.defines=function(){return this.names.map(function(t){return\"#define HAS_UNIFORM_u_\"+t})},na.prototype.populatePaintArray=function(){},na.prototype.updatePaintArray=function(){},na.prototype.upload=function(){},na.prototype.destroy=function(){},na.prototype.setConstantPatternPositions=function(t,e){this.patternPositions.patternTo=t.tlbr,this.patternPositions.patternFrom=e.tlbr},na.prototype.setUniforms=function(t,e,r,n,i){var a=this.patternPositions;\"u_pattern_to\"===i&&a.patternTo&&e.set(a.patternTo),\"u_pattern_from\"===i&&a.patternFrom&&e.set(a.patternFrom)},na.prototype.getBinding=function(t,e){return new Ki(t,e)};var ia=function(t,e,r,n){this.expression=t,this.names=e,this.type=r,this.uniformNames=this.names.map(function(t){return\"a_\"+t}),this.maxValue=-1/0,this.paintVertexAttributes=e.map(function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?2:1,offset:0}}),this.paintVertexArray=new n};ia.prototype.defines=function(){return[]},ia.prototype.setConstantPatternPositions=function(){},ia.prototype.populatePaintArray=function(t,e){var r=this.paintVertexArray,n=r.length;r.reserve(t);var i=this.expression.evaluate(new Un(0),e,{});if(\"color\"===this.type)for(var a=ea(i),o=n;o<t;o++)r.emplaceBack(a[0],a[1]);else{for(var s=n;s<t;s++)r.emplaceBack(i);this.maxValue=Math.max(this.maxValue,i)}},ia.prototype.updatePaintArray=function(t,e,r,n){var i=this.paintVertexArray,a=this.expression.evaluate({zoom:0},r,n);if(\"color\"===this.type)for(var o=ea(a),s=t;s<e;s++)i.emplace(s,o[0],o[1]);else{for(var l=t;l<e;l++)i.emplace(l,a);this.maxValue=Math.max(this.maxValue,a)}},ia.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},ia.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},ia.prototype.setUniforms=function(t,e){e.set(0)},ia.prototype.getBinding=function(t,e){return new Xi(t,e)};var aa=function(t,e,r,n,i,a){this.expression=t,this.names=e,this.uniformNames=this.names.map(function(t){return\"u_\"+t+\"_t\"}),this.type=r,this.useIntegerZoom=n,this.zoom=i,this.maxValue=-1/0;var o=a;this.paintVertexAttributes=e.map(function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?4:2,offset:0}}),this.paintVertexArray=new o};aa.prototype.defines=function(){return[]},aa.prototype.setConstantPatternPositions=function(){},aa.prototype.populatePaintArray=function(t,e){var r=this.paintVertexArray,n=r.length;r.reserve(t);var i=this.expression.evaluate(new Un(this.zoom),e,{}),a=this.expression.evaluate(new Un(this.zoom+1),e,{});if(\"color\"===this.type)for(var o=ea(i),s=ea(a),l=n;l<t;l++)r.emplaceBack(o[0],o[1],s[0],s[1]);else{for(var c=n;c<t;c++)r.emplaceBack(i,a);this.maxValue=Math.max(this.maxValue,i,a)}},aa.prototype.updatePaintArray=function(t,e,r,n){var i=this.paintVertexArray,a=this.expression.evaluate({zoom:this.zoom},r,n),o=this.expression.evaluate({zoom:this.zoom+1},r,n);if(\"color\"===this.type)for(var s=ea(a),l=ea(o),c=t;c<e;c++)i.emplace(c,s[0],s[1],l[0],l[1]);else{for(var u=t;u<e;u++)i.emplace(u,a,o);this.maxValue=Math.max(this.maxValue,a,o)}},aa.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},aa.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},aa.prototype.interpolationFactor=function(t){return this.useIntegerZoom?this.expression.interpolationFactor(Math.floor(t),this.zoom,this.zoom+1):this.expression.interpolationFactor(t,this.zoom,this.zoom+1)},aa.prototype.setUniforms=function(t,e,r){e.set(this.interpolationFactor(r.zoom))},aa.prototype.getBinding=function(t,e){return new Xi(t,e)};var oa=function(t,e,r,n,i,a,o){this.expression=t,this.names=e,this.type=r,this.uniformNames=this.names.map(function(t){return\"u_\"+t+\"_t\"}),this.useIntegerZoom=n,this.zoom=i,this.maxValue=-1/0,this.layerId=o,this.paintVertexAttributes=e.map(function(t){return{name:\"a_\"+t,type:\"Uint16\",components:4,offset:0}}),this.zoomInPaintVertexArray=new a,this.zoomOutPaintVertexArray=new a};oa.prototype.defines=function(){return[]},oa.prototype.setConstantPatternPositions=function(){},oa.prototype.populatePaintArray=function(t,e,r){var n=this.zoomInPaintVertexArray,i=this.zoomOutPaintVertexArray,a=this.layerId,o=n.length;if(n.reserve(t),i.reserve(t),r&&e.patterns&&e.patterns[a]){var s=e.patterns[a],l=s.min,c=s.mid,u=s.max,h=r[l],f=r[c],p=r[u];if(!h||!f||!p)return;for(var d=o;d<t;d++)n.emplaceBack(f.tl[0],f.tl[1],f.br[0],f.br[1],h.tl[0],h.tl[1],h.br[0],h.br[1]),i.emplaceBack(f.tl[0],f.tl[1],f.br[0],f.br[1],p.tl[0],p.tl[1],p.br[0],p.br[1])}},oa.prototype.updatePaintArray=function(t,e,r,n,i){var a=this.zoomInPaintVertexArray,o=this.zoomOutPaintVertexArray,s=this.layerId;if(i&&r.patterns&&r.patterns[s]){var l=r.patterns[s],c=l.min,u=l.mid,h=l.max,f=i[c],p=i[u],d=i[h];if(!f||!p||!d)return;for(var g=t;g<e;g++)a.emplace(g,p.tl[0],p.tl[1],p.br[0],p.br[1],f.tl[0],f.tl[1],f.br[0],f.br[1]),o.emplace(g,p.tl[0],p.tl[1],p.br[0],p.br[1],d.tl[0],d.tl[1],d.br[0],d.br[1])}},oa.prototype.upload=function(t){this.zoomInPaintVertexArray&&this.zoomInPaintVertexArray.arrayBuffer&&this.zoomOutPaintVertexArray&&this.zoomOutPaintVertexArray.arrayBuffer&&(this.zoomInPaintVertexBuffer=t.createVertexBuffer(this.zoomInPaintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent),this.zoomOutPaintVertexBuffer=t.createVertexBuffer(this.zoomOutPaintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},oa.prototype.destroy=function(){this.zoomOutPaintVertexBuffer&&this.zoomOutPaintVertexBuffer.destroy(),this.zoomInPaintVertexBuffer&&this.zoomInPaintVertexBuffer.destroy()},oa.prototype.setUniforms=function(t,e){e.set(0)},oa.prototype.getBinding=function(t,e){return new Xi(t,e)};var sa=function(){this.binders={},this.cacheKey=\"\",this._buffers=[],this._featureMap=new Hi,this._bufferOffset=0};sa.createDynamic=function(t,e,r){var n=new sa,i=[];for(var a in t.paint._values)if(r(a)){var o=t.paint.get(a);if(o instanceof Xn&&xr(o.property.specification)){var s=ca(a,t.type),l=o.property.specification.type,c=o.property.useIntegerZoom;if(\"cross-faded\"===o.property.specification[\"property-type\"]||\"cross-faded-data-driven\"===o.property.specification[\"property-type\"])if(\"constant\"===o.value.kind)n.binders[a]=new na(o.value.value,s,l),i.push(\"/u_\"+a);else{var u=ua(a,l,\"source\");n.binders[a]=new oa(o.value,s,l,c,e,u,t.id),i.push(\"/a_\"+a)}else if(\"constant\"===o.value.kind)n.binders[a]=new ra(o.value.value,s,l),i.push(\"/u_\"+a);else if(\"source\"===o.value.kind){var h=ua(a,l,\"source\");n.binders[a]=new ia(o.value,s,l,h),i.push(\"/a_\"+a)}else{var f=ua(a,l,\"composite\");n.binders[a]=new aa(o.value,s,l,c,e,f),i.push(\"/z_\"+a)}}}return n.cacheKey=i.sort().join(\"\"),n},sa.prototype.populatePaintArrays=function(t,e,r,n){for(var i in this.binders)this.binders[i].populatePaintArray(t,e,n);void 0!==e.id&&this._featureMap.add(+e.id,r,this._bufferOffset,t),this._bufferOffset=t},sa.prototype.setConstantPatternPositions=function(t,e){for(var r in this.binders)this.binders[r].setConstantPatternPositions(t,e)},sa.prototype.updatePaintArrays=function(t,e,r,n){var i=!1;for(var a in t)for(var o=0,s=this._featureMap.getPositions(+a);o<s.length;o+=1){var l=s[o],c=e.feature(l.index);for(var u in this.binders){var h=this.binders[u];if(!(h instanceof ra||h instanceof na)&&!0===h.expression.isStateDependent){var f=r.paint.get(u);h.expression=f.value,h.updatePaintArray(l.start,l.end,c,t[a],n),i=!0}}}return i},sa.prototype.defines=function(){var t=[];for(var e in this.binders)t.push.apply(t,this.binders[e].defines());return t},sa.prototype.getPaintVertexBuffers=function(){return this._buffers},sa.prototype.getUniforms=function(t,e){var r=[];for(var n in this.binders)for(var i=this.binders[n],a=0,o=i.uniformNames;a<o.length;a+=1){var s=o[a];if(e[s]){var l=i.getBinding(t,e[s]);r.push({name:s,property:n,binding:l})}}return r},sa.prototype.setUniforms=function(t,e,r,n){for(var i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.name,l=o.property,c=o.binding;this.binders[l].setUniforms(t,c,n,r.get(l),s)}},sa.prototype.updatePatternPaintBuffers=function(t){var e=[];for(var r in this.binders){var n=this.binders[r];if(n instanceof oa){var i=2===t.fromScale?n.zoomInPaintVertexBuffer:n.zoomOutPaintVertexBuffer;i&&e.push(i)}else(n instanceof ia||n instanceof aa)&&n.paintVertexBuffer&&e.push(n.paintVertexBuffer)}this._buffers=e},sa.prototype.upload=function(t){for(var e in this.binders)this.binders[e].upload(t);var r=[];for(var n in this.binders){var i=this.binders[n];(i instanceof ia||i instanceof aa)&&i.paintVertexBuffer&&r.push(i.paintVertexBuffer)}this._buffers=r},sa.prototype.destroy=function(){for(var t in this.binders)this.binders[t].destroy()};var la=function(t,e,r,n){void 0===n&&(n=function(){return!0}),this.programConfigurations={};for(var i=0,a=e;i<a.length;i+=1){var o=a[i];this.programConfigurations[o.id]=sa.createDynamic(o,r,n),this.programConfigurations[o.id].layoutAttributes=t}this.needsUpload=!1};function ca(t,e){return{\"text-opacity\":[\"opacity\"],\"icon-opacity\":[\"opacity\"],\"text-color\":[\"fill_color\"],\"icon-color\":[\"fill_color\"],\"text-halo-color\":[\"halo_color\"],\"icon-halo-color\":[\"halo_color\"],\"text-halo-blur\":[\"halo_blur\"],\"icon-halo-blur\":[\"halo_blur\"],\"text-halo-width\":[\"halo_width\"],\"icon-halo-width\":[\"halo_width\"],\"line-gap-width\":[\"gapwidth\"],\"line-pattern\":[\"pattern_to\",\"pattern_from\"],\"fill-pattern\":[\"pattern_to\",\"pattern_from\"],\"fill-extrusion-pattern\":[\"pattern_to\",\"pattern_from\"]}[t]||[t.replace(e+\"-\",\"\").replace(/-/g,\"_\")]}function ua(t,e,r){var n={color:{source:Si,composite:Ei},number:{source:_i,composite:Si}},i=function(t){return{\"line-pattern\":{source:fi,composite:fi},\"fill-pattern\":{source:fi,composite:fi},\"fill-extrusion-pattern\":{source:fi,composite:fi}}[t]}(t);return i&&i[r]||n[e][r]}la.prototype.populatePaintArrays=function(t,e,r,n){for(var i in this.programConfigurations)this.programConfigurations[i].populatePaintArrays(t,e,r,n);this.needsUpload=!0},la.prototype.updatePaintArrays=function(t,e,r,n){for(var i=0,a=r;i<a.length;i+=1){var o=a[i];this.needsUpload=this.programConfigurations[o.id].updatePaintArrays(t,e,o,n)||this.needsUpload}},la.prototype.get=function(t){return this.programConfigurations[t]},la.prototype.upload=function(t){if(this.needsUpload){for(var e in this.programConfigurations)this.programConfigurations[e].upload(t);this.needsUpload=!1}},la.prototype.destroy=function(){for(var t in this.programConfigurations)this.programConfigurations[t].destroy()},kn(\"ConstantBinder\",ra),kn(\"CrossFadedConstantBinder\",na),kn(\"SourceExpressionBinder\",ia),kn(\"CrossFadedCompositeBinder\",oa),kn(\"CompositeExpressionBinder\",aa),kn(\"ProgramConfiguration\",sa,{omit:[\"_buffers\"]}),kn(\"ProgramConfigurationSet\",la);var ha=8192,fa=(16,{min:-1*Math.pow(2,15),max:Math.pow(2,15)-1});function pa(t){for(var e=ha/t.extent,r=t.loadGeometry(),n=0;n<r.length;n++)for(var i=r[n],a=0;a<i.length;a++){var o=i[a];o.x=Math.round(o.x*e),o.y=Math.round(o.y*e),(o.x<fa.min||o.x>fa.max||o.y<fa.min||o.y>fa.max)&&w(\"Geometry exceeds allowed extent, reduce your vector tile buffer size\")}return r}function da(t,e,r,n,i){t.emplaceBack(2*e+(n+1)/2,2*r+(i+1)/2)}var ga=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new li,this.indexArray=new Ti,this.segments=new Vi,this.programConfigurations=new la(Ui,t.layers,t.zoom),this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function va(t,e){for(var r=0;r<t.length;r++)if(Aa(e,t[r]))return!0;for(var n=0;n<e.length;n++)if(Aa(t,e[n]))return!0;return!!ba(t,e)}function ma(t,e,r){return!!Aa(t,e)||!!wa(e,t,r)}function ya(t,e){if(1===t.length)return Ta(e,t[0]);for(var r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++)if(Aa(t,n[i]))return!0;for(var a=0;a<t.length;a++)if(Ta(e,t[a]))return!0;for(var o=0;o<e.length;o++)if(ba(t,e[o]))return!0;return!1}function xa(t,e,r){if(t.length>1){if(ba(t,e))return!0;for(var n=0;n<e.length;n++)if(wa(e[n],t,r))return!0}for(var i=0;i<t.length;i++)if(wa(t[i],e,r))return!0;return!1}function ba(t,e){if(0===t.length||0===e.length)return!1;for(var r=0;r<t.length-1;r++)for(var n=t[r],i=t[r+1],a=0;a<e.length-1;a++)if(_a(n,i,e[a],e[a+1]))return!0;return!1}function _a(t,e,r,n){return k(t,r,n)!==k(e,r,n)&&k(t,e,r)!==k(t,e,n)}function wa(t,e,r){var n=r*r;if(1===e.length)return t.distSqr(e[0])<n;for(var i=1;i<e.length;i++)if(ka(t,e[i-1],e[i])<n)return!0;return!1}function ka(t,e,r){var n=e.distSqr(r);if(0===n)return t.distSqr(e);var i=((t.x-e.x)*(r.x-e.x)+(t.y-e.y)*(r.y-e.y))/n;return i<0?t.distSqr(e):i>1?t.distSqr(r):t.distSqr(r.sub(e)._mult(i)._add(e))}function Ta(t,e){for(var r,n,i,a=!1,o=0;o<t.length;o++)for(var s=0,l=(r=t[o]).length-1;s<r.length;l=s++)n=r[s],i=r[l],n.y>e.y!=i.y>e.y&&e.x<(i.x-n.x)*(e.y-n.y)/(i.y-n.y)+n.x&&(a=!a);return a}function Aa(t,e){for(var r=!1,n=0,i=t.length-1;n<t.length;i=n++){var a=t[n],o=t[i];a.y>e.y!=o.y>e.y&&e.x<(o.x-a.x)*(e.y-a.y)/(o.y-a.y)+a.x&&(r=!r)}return r}function Ma(t,e,r){var n=r[0],i=r[2];if(t.x<n.x&&e.x<n.x||t.x>i.x&&e.x>i.x||t.y<n.y&&e.y<n.y||t.y>i.y&&e.y>i.y)return!1;var a=k(t,e,r[0]);return a!==k(t,e,r[1])||a!==k(t,e,r[2])||a!==k(t,e,r[3])}function Sa(t,e,r){var n=e.paint.get(t).value;return\"constant\"===n.kind?n.value:r.programConfigurations.get(e.id).binders[t].maxValue}function Ea(t){return Math.sqrt(t[0]*t[0]+t[1]*t[1])}function Ca(t,e,r,n,a){if(!e[0]&&!e[1])return t;var o=i.convert(e)._mult(a);\"viewport\"===r&&o._rotate(-n);for(var s=[],l=0;l<t.length;l++){var c=t[l];s.push(c.sub(o))}return s}ga.prototype.populate=function(t,e){for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a);this.addFeature(a,l,o),e.featureIndex.insert(a,l,o,s,this.index)}}},ga.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},ga.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},ga.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},ga.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ui),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},ga.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},ga.prototype.addFeature=function(t,e,r){for(var n=0,i=e;n<i.length;n+=1)for(var a=0,o=i[n];a<o.length;a+=1){var s=o[a],l=s.x,c=s.y;if(!(l<0||l>=ha||c<0||c>=ha)){var u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),h=u.vertexLength;da(this.layoutVertexArray,l,c,-1,-1),da(this.layoutVertexArray,l,c,1,-1),da(this.layoutVertexArray,l,c,1,1),da(this.layoutVertexArray,l,c,-1,1),this.indexArray.emplaceBack(h,h+1,h+2),this.indexArray.emplaceBack(h,h+3,h+2),u.vertexLength+=4,u.primitiveLength+=2}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,{})},kn(\"CircleBucket\",ga,{omit:[\"layers\"]});var La={paint:new ei({\"circle-radius\":new Kn(It.paint_circle[\"circle-radius\"]),\"circle-color\":new Kn(It.paint_circle[\"circle-color\"]),\"circle-blur\":new Kn(It.paint_circle[\"circle-blur\"]),\"circle-opacity\":new Kn(It.paint_circle[\"circle-opacity\"]),\"circle-translate\":new Jn(It.paint_circle[\"circle-translate\"]),\"circle-translate-anchor\":new Jn(It.paint_circle[\"circle-translate-anchor\"]),\"circle-pitch-scale\":new Jn(It.paint_circle[\"circle-pitch-scale\"]),\"circle-pitch-alignment\":new Jn(It.paint_circle[\"circle-pitch-alignment\"]),\"circle-stroke-width\":new Kn(It.paint_circle[\"circle-stroke-width\"]),\"circle-stroke-color\":new Kn(It.paint_circle[\"circle-stroke-color\"]),\"circle-stroke-opacity\":new Kn(It.paint_circle[\"circle-stroke-opacity\"])})},Pa=\"undefined\"!=typeof Float32Array?Float32Array:Array;function Oa(){var t=new Pa(9);return Pa!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[5]=0,t[6]=0,t[7]=0),t[0]=1,t[4]=1,t[8]=1,t}function za(){var t=new Pa(3);return Pa!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0),t}function Ia(t,e,r){var n=new Pa(3);return n[0]=t,n[1]=e,n[2]=r,n}Math.PI;function Da(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}function Ra(){var t=new Pa(4);return Pa!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0),t[3]=1,t}za(),function(){var t;t=new Pa(4),Pa!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0,t[3]=0)}();za(),Ia(1,0,0),Ia(0,1,0),Ra(),Ra(),Oa(),function(){var t;t=new Pa(2),Pa!=Float32Array&&(t[0]=0,t[1]=0)}();var Fa=function(t){function e(e){t.call(this,e,La)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new ga(t)},e.prototype.queryRadius=function(t){var e=t;return Sa(\"circle-radius\",this,e)+Sa(\"circle-stroke-width\",this,e)+Ea(this.paint.get(\"circle-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o,s){for(var l=Ca(t,this.paint.get(\"circle-translate\"),this.paint.get(\"circle-translate-anchor\"),a.angle,o),c=this.paint.get(\"circle-radius\").evaluate(e,r)+this.paint.get(\"circle-stroke-width\").evaluate(e,r),u=\"map\"===this.paint.get(\"circle-pitch-alignment\"),h=u?l:function(t,e){return l.map(function(t){return Ba(t,e)})}(0,s),f=u?c*o:c,p=0,d=n;p<d.length;p+=1)for(var g=0,v=d[p];g<v.length;g+=1){var m=v[g],y=u?m:Ba(m,s),x=f,b=Da([],[m.x,m.y,0,1],s);if(\"viewport\"===this.paint.get(\"circle-pitch-scale\")&&\"map\"===this.paint.get(\"circle-pitch-alignment\")?x*=b[3]/a.cameraToCenterDistance:\"map\"===this.paint.get(\"circle-pitch-scale\")&&\"viewport\"===this.paint.get(\"circle-pitch-alignment\")&&(x*=a.cameraToCenterDistance/b[3]),ma(h,y,x))return!0}return!1},e}(ri);function Ba(t,e){var r=Da([],[t.x,t.y,0,1],e);return new i(r[0]/r[3],r[1]/r[3])}var Na=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ga);function ja(t,e,r,n){var i=e.width,a=e.height;if(n){if(n instanceof Uint8ClampedArray)n=new Uint8Array(n.buffer);else if(n.length!==i*a*r)throw new RangeError(\"mismatched image size\")}else n=new Uint8Array(i*a*r);return t.width=i,t.height=a,t.data=n,t}function Ua(t,e,r){var n=e.width,i=e.height;if(n!==t.width||i!==t.height){var a=ja({},{width:n,height:i},r);Va(t,a,{x:0,y:0},{x:0,y:0},{width:Math.min(t.width,n),height:Math.min(t.height,i)},r),t.width=n,t.height=i,t.data=a.data}}function Va(t,e,r,n,i,a){if(0===i.width||0===i.height)return e;if(i.width>t.width||i.height>t.height||r.x>t.width-i.width||r.y>t.height-i.height)throw new RangeError(\"out of range source coordinates for image copy\");if(i.width>e.width||i.height>e.height||n.x>e.width-i.width||n.y>e.height-i.height)throw new RangeError(\"out of range destination coordinates for image copy\");for(var o=t.data,s=e.data,l=0;l<i.height;l++)for(var c=((r.y+l)*t.width+r.x)*a,u=((n.y+l)*e.width+n.x)*a,h=0;h<i.width*a;h++)s[u+h]=o[c+h];return e}kn(\"HeatmapBucket\",Na,{omit:[\"layers\"]});var qa=function(t,e){ja(this,t,1,e)};qa.prototype.resize=function(t){Ua(this,t,1)},qa.prototype.clone=function(){return new qa({width:this.width,height:this.height},new Uint8Array(this.data))},qa.copy=function(t,e,r,n,i){Va(t,e,r,n,i,1)};var Ha=function(t,e){ja(this,t,4,e)};Ha.prototype.resize=function(t){Ua(this,t,4)},Ha.prototype.replace=function(t,e){e?this.data.set(t):t instanceof Uint8ClampedArray?this.data=new Uint8Array(t.buffer):this.data=t},Ha.prototype.clone=function(){return new Ha({width:this.width,height:this.height},new Uint8Array(this.data))},Ha.copy=function(t,e,r,n,i){Va(t,e,r,n,i,4)},kn(\"AlphaImage\",qa),kn(\"RGBAImage\",Ha);var Ga={paint:new ei({\"heatmap-radius\":new Kn(It.paint_heatmap[\"heatmap-radius\"]),\"heatmap-weight\":new Kn(It.paint_heatmap[\"heatmap-weight\"]),\"heatmap-intensity\":new Jn(It.paint_heatmap[\"heatmap-intensity\"]),\"heatmap-color\":new ti(It.paint_heatmap[\"heatmap-color\"]),\"heatmap-opacity\":new Jn(It.paint_heatmap[\"heatmap-opacity\"])})};function Ya(t,e){for(var r=new Uint8Array(1024),n={},i=0,a=0;i<256;i++,a+=4){n[e]=i/255;var o=t.evaluate(n);r[a+0]=Math.floor(255*o.r/o.a),r[a+1]=Math.floor(255*o.g/o.a),r[a+2]=Math.floor(255*o.b/o.a),r[a+3]=Math.floor(255*o.a)}return new Ha({width:256,height:1},r)}var Wa=function(t){function e(e){t.call(this,e,Ga),this._updateColorRamp()}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new Na(t)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"heatmap-color\"===t&&this._updateColorRamp()},e.prototype._updateColorRamp=function(){var t=this._transitionablePaint._values[\"heatmap-color\"].value.expression;this.colorRamp=Ya(t,\"heatmapDensity\"),this.colorRampTexture=null},e.prototype.resize=function(){this.heatmapFbo&&(this.heatmapFbo.destroy(),this.heatmapFbo=null)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"heatmap-opacity\")&&\"none\"!==this.visibility},e}(ri),Xa={paint:new ei({\"hillshade-illumination-direction\":new Jn(It.paint_hillshade[\"hillshade-illumination-direction\"]),\"hillshade-illumination-anchor\":new Jn(It.paint_hillshade[\"hillshade-illumination-anchor\"]),\"hillshade-exaggeration\":new Jn(It.paint_hillshade[\"hillshade-exaggeration\"]),\"hillshade-shadow-color\":new Jn(It.paint_hillshade[\"hillshade-shadow-color\"]),\"hillshade-highlight-color\":new Jn(It.paint_hillshade[\"hillshade-highlight-color\"]),\"hillshade-accent-color\":new Jn(It.paint_hillshade[\"hillshade-accent-color\"])})},Za=function(t){function e(e){t.call(this,e,Xa)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"hillshade-exaggeration\")&&\"none\"!==this.visibility},e}(ri),Ja=oi([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,Ka=Qa,$a=Qa;function Qa(t,e,r){r=r||2;var n,i,a,o,s,l,c,u=e&&e.length,h=u?e[0]*r:t.length,f=to(t,0,h,r,!0),p=[];if(!f||f.next===f.prev)return p;if(u&&(f=function(t,e,r,n){var i,a,o,s=[];for(i=0,a=e.length;i<a;i++)(o=to(t,e[i]*n,i<a-1?e[i+1]*n:t.length,n,!1))===o.next&&(o.steiner=!0),s.push(uo(o));for(s.sort(so),i=0;i<s.length;i++)lo(s[i],r),r=eo(r,r.next);return r}(t,e,f,r)),t.length>80*r){n=a=t[0],i=o=t[1];for(var d=r;d<h;d+=r)(s=t[d])<n&&(n=s),(l=t[d+1])<i&&(i=l),s>a&&(a=s),l>o&&(o=l);c=0!==(c=Math.max(a-n,o-i))?1/c:0}return ro(f,p,r,n,i,c),p}function to(t,e,r,n,i){var a,o;if(i===wo(t,e,r,n)>0)for(a=e;a<r;a+=n)o=xo(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=xo(a,t[a],t[a+1],o);return o&&go(o,o.next)&&(bo(o),o=o.next),o}function eo(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!go(n,n.next)&&0!==po(n.prev,n,n.next))n=n.next;else{if(bo(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function ro(t,e,r,n,i,a,o){if(t){!o&&a&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=co(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,a);for(var s,l,c=t;t.prev!==t.next;)if(s=t.prev,l=t.next,a?io(t,n,i,a):no(t))e.push(s.i/r),e.push(t.i/r),e.push(l.i/r),bo(t),t=l.next,c=l.next;else if((t=l)===c){o?1===o?ro(t=ao(t,e,r),e,r,n,i,a,2):2===o&&oo(t,e,r,n,i,a):ro(eo(t),e,r,n,i,a,1);break}}}function no(t){var e=t.prev,r=t,n=t.next;if(po(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(ho(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&po(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function io(t,e,r,n){var i=t.prev,a=t,o=t.next;if(po(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,h=co(s,l,e,r,n),f=co(c,u,e,r,n),p=t.prevZ,d=t.nextZ;p&&p.z>=h&&d&&d.z<=f;){if(p!==t.prev&&p!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&po(p.prev,p,p.next)>=0)return!1;if(p=p.prevZ,d!==t.prev&&d!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&po(d.prev,d,d.next)>=0)return!1;d=d.nextZ}for(;p&&p.z>=h;){if(p!==t.prev&&p!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&po(p.prev,p,p.next)>=0)return!1;p=p.prevZ}for(;d&&d.z<=f;){if(d!==t.prev&&d!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&po(d.prev,d,d.next)>=0)return!1;d=d.nextZ}return!0}function ao(t,e,r){var n=t;do{var i=n.prev,a=n.next.next;!go(i,a)&&vo(i,n,n.next,a)&&mo(i,a)&&mo(a,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(a.i/r),bo(n),bo(n.next),n=t=a),n=n.next}while(n!==t);return n}function oo(t,e,r,n,i,a){var o=t;do{for(var s=o.next.next;s!==o.prev;){if(o.i!==s.i&&fo(o,s)){var l=yo(o,s);return o=eo(o,o.next),l=eo(l,l.next),ro(o,e,r,n,i,a),void ro(l,e,r,n,i,a)}s=s.next}o=o.next}while(o!==t)}function so(t,e){return t.x-e.x}function lo(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r.prev;var l,c=r,u=r.x,h=r.y,f=1/0;for(n=r.next;n!==c;)i>=n.x&&n.x>=u&&i!==n.x&&ho(a<h?i:o,a,u,h,a<h?o:i,a,n.x,n.y)&&((l=Math.abs(a-n.y)/(i-n.x))<f||l===f&&n.x>r.x)&&mo(n,t)&&(r=n,f=l),n=n.next;return r}(t,e)){var r=yo(e,t);eo(r,r.next)}}function co(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function uo(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function ho(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function fo(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&vo(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&mo(t,e)&&mo(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)}function po(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function go(t,e){return t.x===e.x&&t.y===e.y}function vo(t,e,r,n){return!!(go(t,e)&&go(r,n)||go(t,n)&&go(r,e))||po(t,e,r)>0!=po(t,e,n)>0&&po(r,n,t)>0!=po(r,n,e)>0}function mo(t,e){return po(t.prev,t,t.next)<0?po(t,e,t.next)>=0&&po(t,t.prev,e)>=0:po(t,e,t.prev)<0||po(t,t.next,e)<0}function yo(t,e){var r=new _o(t.i,t.x,t.y),n=new _o(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function xo(t,e,r,n){var i=new _o(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function bo(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function _o(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function wo(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}function ko(t,e,r,n,i){!function t(e,r,n,i,a){for(;i>n;){if(i-n>600){var o=i-n+1,s=r-n+1,l=Math.log(o),c=.5*Math.exp(2*l/3),u=.5*Math.sqrt(l*c*(o-c)/o)*(s-o/2<0?-1:1);t(e,r,Math.max(n,Math.floor(r-s*c/o+u)),Math.min(i,Math.floor(r+(o-s)*c/o+u)),a)}var h=e[r],f=n,p=i;for(To(e,n,r),a(e[i],h)>0&&To(e,n,i);f<p;){for(To(e,f,p),f++,p--;a(e[f],h)<0;)f++;for(;a(e[p],h)>0;)p--}0===a(e[n],h)?To(e,n,p):To(e,++p,i),p<=r&&(n=p+1),r<=p&&(i=p-1)}}(t,e,r||0,n||t.length-1,i||Ao)}function To(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function Ao(t,e){return t<e?-1:t>e?1:0}function Mo(t,e){var r=t.length;if(r<=1)return[t];for(var n,i,a=[],o=0;o<r;o++){var s=T(t[o]);0!==s&&(t[o].area=Math.abs(s),void 0===i&&(i=s<0),i===s<0?(n&&a.push(n),n=[t[o]]):n.push(t[o]))}if(n&&a.push(n),e>1)for(var l=0;l<a.length;l++)a[l].length<=e||(ko(a[l],e,1,a[l].length-1,So),a[l]=a[l].slice(0,e));return a}function So(t,e){return e.area-t.area}function Eo(t,e,r){for(var n=r.patternDependencies,i=!1,a=0,o=e;a<o.length;a+=1){var s=o[a].paint.get(t+\"-pattern\");s.isConstant()||(i=!0);var l=s.constantOr(null);l&&(i=!0,n[l.to]=!0,n[l.from]=!0)}return i}function Co(t,e,r,n,i){for(var a=i.patternDependencies,o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.paint.get(t+\"-pattern\").value;if(\"constant\"!==c.kind){var u=c.evaluate({zoom:n-1},r,{}),h=c.evaluate({zoom:n},r,{}),f=c.evaluate({zoom:n+1},r,{});a[u]=!0,a[h]=!0,a[f]=!0,r.patterns[l.id]={min:u,mid:h,max:f}}}return r}Qa.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(wo(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(wo(t,c,u,r))}var h=0;for(s=0;s<n.length;s+=3){var f=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;h+=Math.abs((t[f]-t[d])*(t[p+1]-t[f+1])-(t[f]-t[p])*(t[d+1]-t[f+1]))}return 0===o&&0===h?0:Math.abs((h-o)/o)},Qa.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r},Ka.default=$a;var Lo=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new li,this.indexArray=new Ti,this.indexArray2=new Ai,this.programConfigurations=new la(Ja,t.layers,t.zoom),this.segments=new Vi,this.segments2=new Vi,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};Lo.prototype.populate=function(t,e){this.features=[],this.hasPattern=Eo(\"fill\",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a),c={sourceLayerIndex:s,index:o,geometry:l,properties:a.properties,type:a.type,patterns:{}};void 0!==a.id&&(c.id=a.id),this.hasPattern?this.features.push(Co(\"fill\",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(a,l,o,s,this.index)}}},Lo.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Lo.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var i=n[r],a=i.geometry;this.addFeature(i,a,i.index,e)}},Lo.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Lo.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Lo.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ja),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.indexBuffer2=t.createIndexBuffer(this.indexArray2)),this.programConfigurations.upload(t),this.uploaded=!0},Lo.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.indexBuffer2.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.segments2.destroy())},Lo.prototype.addFeature=function(t,e,r,n){for(var i=0,a=Mo(e,500);i<a.length;i+=1){for(var o=a[i],s=0,l=0,c=o;l<c.length;l+=1)s+=c[l].length;for(var u=this.segments.prepareSegment(s,this.layoutVertexArray,this.indexArray),h=u.vertexLength,f=[],p=[],d=0,g=o;d<g.length;d+=1){var v=g[d];if(0!==v.length){v!==o[0]&&p.push(f.length/2);var m=this.segments2.prepareSegment(v.length,this.layoutVertexArray,this.indexArray2),y=m.vertexLength;this.layoutVertexArray.emplaceBack(v[0].x,v[0].y),this.indexArray2.emplaceBack(y+v.length-1,y),f.push(v[0].x),f.push(v[0].y);for(var x=1;x<v.length;x++)this.layoutVertexArray.emplaceBack(v[x].x,v[x].y),this.indexArray2.emplaceBack(y+x-1,y+x),f.push(v[x].x),f.push(v[x].y);m.vertexLength+=v.length,m.primitiveLength+=v.length}}for(var b=Ka(f,p),_=0;_<b.length;_+=3)this.indexArray.emplaceBack(h+b[_],h+b[_+1],h+b[_+2]);u.vertexLength+=s,u.primitiveLength+=b.length/3}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,n)},kn(\"FillBucket\",Lo,{omit:[\"layers\",\"features\"]});var Po={paint:new ei({\"fill-antialias\":new Jn(It.paint_fill[\"fill-antialias\"]),\"fill-opacity\":new Kn(It.paint_fill[\"fill-opacity\"]),\"fill-color\":new Kn(It.paint_fill[\"fill-color\"]),\"fill-outline-color\":new Kn(It.paint_fill[\"fill-outline-color\"]),\"fill-translate\":new Jn(It.paint_fill[\"fill-translate\"]),\"fill-translate-anchor\":new Jn(It.paint_fill[\"fill-translate-anchor\"]),\"fill-pattern\":new $n(It.paint_fill[\"fill-pattern\"])})},Oo=function(t){function e(e){t.call(this,e,Po)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e);var r=this.paint._values[\"fill-outline-color\"];\"constant\"===r.value.kind&&void 0===r.value.value&&(this.paint._values[\"fill-outline-color\"]=this.paint._values[\"fill-color\"])},e.prototype.createBucket=function(t){return new Lo(t)},e.prototype.queryRadius=function(){return Ea(this.paint.get(\"fill-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o){return ya(Ca(t,this.paint.get(\"fill-translate\"),this.paint.get(\"fill-translate-anchor\"),a.angle,o),n)},e.prototype.isTileClipped=function(){return!0},e}(ri),zo=oi([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_normal_ed\",components:4,type:\"Int16\"}],4).members,Io=Do;function Do(t,e,r,n,i){this.properties={},this.extent=r,this.type=0,this._pbf=t,this._geometry=-1,this._keys=n,this._values=i,t.readFields(Ro,this,e)}function Ro(t,e,r){1==t?e.id=r.readVarint():2==t?function(t,e){for(var r=t.readVarint()+t.pos;t.pos<r;){var n=e._keys[t.readVarint()],i=e._values[t.readVarint()];e.properties[n]=i}}(r,e):3==t?e.type=r.readVarint():4==t&&(e._geometry=r.pos)}function Fo(t){for(var e,r,n=0,i=0,a=t.length,o=a-1;i<a;o=i++)e=t[i],n+=((r=t[o]).x-e.x)*(e.y+r.y);return n}Do.types=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],Do.prototype.loadGeometry=function(){var t=this._pbf;t.pos=this._geometry;for(var e,r=t.readVarint()+t.pos,n=1,a=0,o=0,s=0,l=[];t.pos<r;){if(a<=0){var c=t.readVarint();n=7&c,a=c>>3}if(a--,1===n||2===n)o+=t.readSVarint(),s+=t.readSVarint(),1===n&&(e&&l.push(e),e=[]),e.push(new i(o,s));else{if(7!==n)throw new Error(\"unknown command \"+n);e&&e.push(e[0].clone())}}return e&&l.push(e),l},Do.prototype.bbox=function(){var t=this._pbf;t.pos=this._geometry;for(var e=t.readVarint()+t.pos,r=1,n=0,i=0,a=0,o=1/0,s=-1/0,l=1/0,c=-1/0;t.pos<e;){if(n<=0){var u=t.readVarint();r=7&u,n=u>>3}if(n--,1===r||2===r)(i+=t.readSVarint())<o&&(o=i),i>s&&(s=i),(a+=t.readSVarint())<l&&(l=a),a>c&&(c=a);else if(7!==r)throw new Error(\"unknown command \"+r)}return[o,l,s,c]},Do.prototype.toGeoJSON=function(t,e,r){var n,i,a=this.extent*Math.pow(2,r),o=this.extent*t,s=this.extent*e,l=this.loadGeometry(),c=Do.types[this.type];function u(t){for(var e=0;e<t.length;e++){var r=t[e],n=180-360*(r.y+s)/a;t[e]=[360*(r.x+o)/a-180,360/Math.PI*Math.atan(Math.exp(n*Math.PI/180))-90]}}switch(this.type){case 1:var h=[];for(n=0;n<l.length;n++)h[n]=l[n][0];u(l=h);break;case 2:for(n=0;n<l.length;n++)u(l[n]);break;case 3:for(l=function(t){var e=t.length;if(e<=1)return[t];for(var r,n,i=[],a=0;a<e;a++){var o=Fo(t[a]);0!==o&&(void 0===n&&(n=o<0),n===o<0?(r&&i.push(r),r=[t[a]]):r.push(t[a]))}return r&&i.push(r),i}(l),n=0;n<l.length;n++)for(i=0;i<l[n].length;i++)u(l[n][i])}1===l.length?l=l[0]:c=\"Multi\"+c;var f={type:\"Feature\",geometry:{type:c,coordinates:l},properties:this.properties};return\"id\"in this&&(f.id=this.id),f};var Bo=No;function No(t,e){this.version=1,this.name=null,this.extent=4096,this.length=0,this._pbf=t,this._keys=[],this._values=[],this._features=[],t.readFields(jo,this,e),this.length=this._features.length}function jo(t,e,r){15===t?e.version=r.readVarint():1===t?e.name=r.readString():5===t?e.extent=r.readVarint():2===t?e._features.push(r.pos):3===t?e._keys.push(r.readString()):4===t&&e._values.push(function(t){for(var e=null,r=t.readVarint()+t.pos;t.pos<r;){var n=t.readVarint()>>3;e=1===n?t.readString():2===n?t.readFloat():3===n?t.readDouble():4===n?t.readVarint64():5===n?t.readVarint():6===n?t.readSVarint():7===n?t.readBoolean():null}return e}(r))}function Uo(t,e,r){if(3===t){var n=new Bo(r,r.readVarint()+r.pos);n.length&&(e[n.name]=n)}}No.prototype.feature=function(t){if(t<0||t>=this._features.length)throw new Error(\"feature index out of bounds\");this._pbf.pos=this._features[t];var e=this._pbf.readVarint()+this._pbf.pos;return new Io(this._pbf,e,this.extent,this._keys,this._values)};var Vo={VectorTile:function(t,e){this.layers=t.readFields(Uo,{},e)},VectorTileFeature:Io,VectorTileLayer:Bo},qo=Vo.VectorTileFeature.types,Ho=Math.pow(2,13);function Go(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,2*Math.floor(n*Ho)+o,i*Ho*2,a*Ho*2,Math.round(s))}var Yo=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new ui,this.indexArray=new Ti,this.programConfigurations=new la(zo,t.layers,t.zoom),this.segments=new Vi,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function Wo(t,e){return t.x===e.x&&(t.x<0||t.x>ha)||t.y===e.y&&(t.y<0||t.y>ha)}function Xo(t){return t.every(function(t){return t.x<0})||t.every(function(t){return t.x>ha})||t.every(function(t){return t.y<0})||t.every(function(t){return t.y>ha})}Yo.prototype.populate=function(t,e){this.features=[],this.hasPattern=Eo(\"fill-extrusion\",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a),c={sourceLayerIndex:s,index:o,geometry:l,properties:a.properties,type:a.type,patterns:{}};void 0!==a.id&&(c.id=a.id),this.hasPattern?this.features.push(Co(\"fill-extrusion\",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(a,l,o,s,this.index,!0)}}},Yo.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var i=n[r],a=i.geometry;this.addFeature(i,a,i.index,e)}},Yo.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Yo.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Yo.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Yo.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,zo),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Yo.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Yo.prototype.addFeature=function(t,e,r,n){for(var i=0,a=Mo(e,500);i<a.length;i+=1){for(var o=a[i],s=0,l=0,c=o;l<c.length;l+=1)s+=c[l].length;for(var u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),h=0,f=o;h<f.length;h+=1){var p=f[h];if(0!==p.length&&!Xo(p))for(var d=0,g=0;g<p.length;g++){var v=p[g];if(g>=1){var m=p[g-1];if(!Wo(v,m)){u.vertexLength+4>Vi.MAX_VERTEX_ARRAY_LENGTH&&(u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray));var y=v.sub(m)._perp()._unit(),x=m.dist(v);d+x>32768&&(d=0),Go(this.layoutVertexArray,v.x,v.y,y.x,y.y,0,0,d),Go(this.layoutVertexArray,v.x,v.y,y.x,y.y,0,1,d),d+=x,Go(this.layoutVertexArray,m.x,m.y,y.x,y.y,0,0,d),Go(this.layoutVertexArray,m.x,m.y,y.x,y.y,0,1,d);var b=u.vertexLength;this.indexArray.emplaceBack(b,b+2,b+1),this.indexArray.emplaceBack(b+1,b+2,b+3),u.vertexLength+=4,u.primitiveLength+=2}}}}if(u.vertexLength+s>Vi.MAX_VERTEX_ARRAY_LENGTH&&(u=this.segments.prepareSegment(s,this.layoutVertexArray,this.indexArray)),\"Polygon\"===qo[t.type]){for(var _=[],w=[],k=u.vertexLength,T=0,A=o;T<A.length;T+=1){var M=A[T];if(0!==M.length){M!==o[0]&&w.push(_.length/2);for(var S=0;S<M.length;S++){var E=M[S];Go(this.layoutVertexArray,E.x,E.y,0,0,1,1,0),_.push(E.x),_.push(E.y)}}}for(var C=Ka(_,w),L=0;L<C.length;L+=3)this.indexArray.emplaceBack(k+C[L],k+C[L+2],k+C[L+1]);u.primitiveLength+=C.length/3,u.vertexLength+=s}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,n)},kn(\"FillExtrusionBucket\",Yo,{omit:[\"layers\",\"features\"]});var Zo={paint:new ei({\"fill-extrusion-opacity\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-opacity\"]),\"fill-extrusion-color\":new Kn(It[\"paint_fill-extrusion\"][\"fill-extrusion-color\"]),\"fill-extrusion-translate\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-translate\"]),\"fill-extrusion-translate-anchor\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-translate-anchor\"]),\"fill-extrusion-pattern\":new $n(It[\"paint_fill-extrusion\"][\"fill-extrusion-pattern\"]),\"fill-extrusion-height\":new Kn(It[\"paint_fill-extrusion\"][\"fill-extrusion-height\"]),\"fill-extrusion-base\":new Kn(It[\"paint_fill-extrusion\"][\"fill-extrusion-base\"]),\"fill-extrusion-vertical-gradient\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-vertical-gradient\"])})},Jo=function(t){function e(e){t.call(this,e,Zo)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new Yo(t)},e.prototype.queryRadius=function(){return Ea(this.paint.get(\"fill-extrusion-translate\"))},e.prototype.is3D=function(){return!0},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s,l){var c=Ca(t,this.paint.get(\"fill-extrusion-translate\"),this.paint.get(\"fill-extrusion-translate-anchor\"),o.angle,s),u=this.paint.get(\"fill-extrusion-height\").evaluate(e,r),h=this.paint.get(\"fill-extrusion-base\").evaluate(e,r),f=function(t,e,r,n){for(var a=[],o=0,s=t;o<s.length;o+=1){var l=s[o],c=[l.x,l.y,0,1];Da(c,c,e),a.push(new i(c[0]/c[3],c[1]/c[3]))}return a}(c,l),p=function(t,e,r,n){for(var a=[],o=[],s=n[8]*e,l=n[9]*e,c=n[10]*e,u=n[11]*e,h=n[8]*r,f=n[9]*r,p=n[10]*r,d=n[11]*r,g=0,v=t;g<v.length;g+=1){for(var m=[],y=[],x=0,b=v[g];x<b.length;x+=1){var _=b[x],w=_.x,k=_.y,T=n[0]*w+n[4]*k+n[12],A=n[1]*w+n[5]*k+n[13],M=n[2]*w+n[6]*k+n[14],S=n[3]*w+n[7]*k+n[15],E=M+c,C=S+u,L=T+h,P=A+f,O=M+p,z=S+d,I=new i((T+s)/C,(A+l)/C);I.z=E/C,m.push(I);var D=new i(L/z,P/z);D.z=O/z,y.push(D)}a.push(m),o.push(y)}return[a,o]}(n,h,u,l);return function(t,e,r){var n=1/0;ya(r,e)&&(n=$o(r,e[0]));for(var i=0;i<e.length;i++)for(var a=e[i],o=t[i],s=0;s<a.length-1;s++){var l=a[s],c=a[s+1],u=o[s],h=[l,c,o[s+1],u,l];va(r,h)&&(n=Math.min(n,$o(r,h)))}return n!==1/0&&n}(p[0],p[1],f)},e}(ri);function Ko(t,e){return t.x*e.x+t.y*e.y}function $o(t,e){if(1===t.length){var r=e[0],n=e[1],i=e[3],a=t[0],o=n.sub(r),s=i.sub(r),l=a.sub(r),c=Ko(o,o),u=Ko(o,s),h=Ko(s,s),f=Ko(l,o),p=Ko(l,s),d=c*h-u*u,g=(h*f-u*p)/d,v=(c*p-u*f)/d,m=1-g-v;return r.z*m+n.z*g+i.z*v}for(var y=1/0,x=0,b=e;x<b.length;x+=1){var _=b[x];y=Math.min(y,_.z)}return y}var Qo=oi([{name:\"a_pos_normal\",components:2,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint8\"}],4).members,ts=Vo.VectorTileFeature.types,es=63,rs=Math.cos(Math.PI/180*37.5),ns=.5,is=Math.pow(2,14)/ns;function as(t,e,r,n,i,a,o){t.emplaceBack((e.x<<1)+(n?1:0),(e.y<<1)+(i?1:0),Math.round(es*r.x)+128,Math.round(es*r.y)+128,1+(0===a?0:a<0?-1:1)|(o*ns&63)<<2,o*ns>>6)}var os=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.features=[],this.hasPattern=!1,this.layoutVertexArray=new hi,this.indexArray=new Ti,this.programConfigurations=new la(Qo,t.layers,t.zoom),this.segments=new Vi,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function ss(t,e){return(t/e.tileTotal*(e.end-e.start)+e.start)*(is-1)}os.prototype.populate=function(t,e){this.features=[],this.hasPattern=Eo(\"line\",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a),c={sourceLayerIndex:s,index:o,geometry:l,properties:a.properties,type:a.type,patterns:{}};void 0!==a.id&&(c.id=a.id),this.hasPattern?this.features.push(Co(\"line\",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(a,l,o,s,this.index)}}},os.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},os.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var i=n[r],a=i.geometry;this.addFeature(i,a,i.index,e)}},os.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},os.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},os.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Qo),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},os.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},os.prototype.addFeature=function(t,e,r,n){for(var i=this.layers[0].layout,a=i.get(\"line-join\").evaluate(t,{}),o=i.get(\"line-cap\"),s=i.get(\"line-miter-limit\"),l=i.get(\"line-round-limit\"),c=0,u=e;c<u.length;c+=1){var h=u[c];this.addLine(h,t,a,o,s,l,r,n)}},os.prototype.addLine=function(t,e,r,n,i,a,o,s){var l=null;e.properties&&e.properties.hasOwnProperty(\"mapbox_clip_start\")&&e.properties.hasOwnProperty(\"mapbox_clip_end\")&&(l={start:e.properties.mapbox_clip_start,end:e.properties.mapbox_clip_end,tileTotal:void 0});for(var c=\"Polygon\"===ts[e.type],u=t.length;u>=2&&t[u-1].equals(t[u-2]);)u--;for(var h=0;h<u-1&&t[h].equals(t[h+1]);)h++;if(!(u<(c?3:2))){l&&(l.tileTotal=function(t,e,r){for(var n,i,a=0,o=h;o<r-1;o++)n=t[o],i=t[o+1],a+=n.dist(i);return a}(t,0,u)),\"bevel\"===r&&(i=1.05);var f=ha/(512*this.overscaling)*15,p=t[h],d=this.segments.prepareSegment(10*u,this.layoutVertexArray,this.indexArray);this.distance=0;var g,v,m,y=n,x=c?\"butt\":n,b=!0,_=void 0,w=void 0,k=void 0,T=void 0;this.e1=this.e2=this.e3=-1,c&&(g=t[u-2],T=p.sub(g)._unit()._perp());for(var A=h;A<u;A++)if(!(w=c&&A===u-1?t[h+1]:t[A+1])||!t[A].equals(w)){T&&(k=T),g&&(_=g),g=t[A],T=w?w.sub(g)._unit()._perp():k;var M=(k=k||T).add(T);0===M.x&&0===M.y||M._unit();var S=M.x*T.x+M.y*T.y,E=0!==S?1/S:1/0,C=S<rs&&_&&w;if(C&&A>h){var L=g.dist(_);if(L>2*f){var P=g.sub(g.sub(_)._mult(f/L)._round());this.distance+=P.dist(_),this.addCurrentVertex(P,this.distance,k.mult(1),0,0,!1,d,l),_=P}}var O=_&&w,z=O?r:w?y:x;if(O&&\"round\"===z&&(E<a?z=\"miter\":E<=2&&(z=\"fakeround\")),\"miter\"===z&&E>i&&(z=\"bevel\"),\"bevel\"===z&&(E>2&&(z=\"flipbevel\"),E<i&&(z=\"miter\")),_&&(this.distance+=g.dist(_)),\"miter\"===z)M._mult(E),this.addCurrentVertex(g,this.distance,M,0,0,!1,d,l);else if(\"flipbevel\"===z){if(E>100)M=T.clone().mult(-1);else{var I=k.x*T.y-k.y*T.x>0?-1:1,D=E*k.add(T).mag()/k.sub(T).mag();M._perp()._mult(D*I)}this.addCurrentVertex(g,this.distance,M,0,0,!1,d,l),this.addCurrentVertex(g,this.distance,M.mult(-1),0,0,!1,d,l)}else if(\"bevel\"===z||\"fakeround\"===z){var R=k.x*T.y-k.y*T.x>0,F=-Math.sqrt(E*E-1);if(R?(m=0,v=F):(v=0,m=F),b||this.addCurrentVertex(g,this.distance,k,v,m,!1,d,l),\"fakeround\"===z){for(var B=Math.floor(8*(.5-(S-.5))),N=void 0,j=0;j<B;j++)N=T.mult((j+1)/(B+1))._add(k)._unit(),this.addPieSliceVertex(g,this.distance,N,R,d,l);this.addPieSliceVertex(g,this.distance,M,R,d,l);for(var U=B-1;U>=0;U--)N=k.mult((U+1)/(B+1))._add(T)._unit(),this.addPieSliceVertex(g,this.distance,N,R,d,l)}w&&this.addCurrentVertex(g,this.distance,T,-v,-m,!1,d,l)}else\"butt\"===z?(b||this.addCurrentVertex(g,this.distance,k,0,0,!1,d,l),w&&this.addCurrentVertex(g,this.distance,T,0,0,!1,d,l)):\"square\"===z?(b||(this.addCurrentVertex(g,this.distance,k,1,1,!1,d,l),this.e1=this.e2=-1),w&&this.addCurrentVertex(g,this.distance,T,-1,-1,!1,d,l)):\"round\"===z&&(b||(this.addCurrentVertex(g,this.distance,k,0,0,!1,d,l),this.addCurrentVertex(g,this.distance,k,1,1,!0,d,l),this.e1=this.e2=-1),w&&(this.addCurrentVertex(g,this.distance,T,-1,-1,!0,d,l),this.addCurrentVertex(g,this.distance,T,0,0,!1,d,l)));if(C&&A<u-1){var V=g.dist(w);if(V>2*f){var q=g.add(w.sub(g)._mult(f/V)._round());this.distance+=q.dist(g),this.addCurrentVertex(q,this.distance,T.mult(1),0,0,!1,d,l),g=q}}b=!1}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,e,o,s)}},os.prototype.addCurrentVertex=function(t,e,r,n,i,a,o,s){var l,c=this.layoutVertexArray,u=this.indexArray;s&&(e=ss(e,s)),l=r.clone(),n&&l._sub(r.perp()._mult(n)),as(c,t,l,a,!1,n,e),this.e3=o.vertexLength++,this.e1>=0&&this.e2>=0&&(u.emplaceBack(this.e1,this.e2,this.e3),o.primitiveLength++),this.e1=this.e2,this.e2=this.e3,l=r.mult(-1),i&&l._sub(r.perp()._mult(i)),as(c,t,l,a,!0,-i,e),this.e3=o.vertexLength++,this.e1>=0&&this.e2>=0&&(u.emplaceBack(this.e1,this.e2,this.e3),o.primitiveLength++),this.e1=this.e2,this.e2=this.e3,e>is/2&&!s&&(this.distance=0,this.addCurrentVertex(t,this.distance,r,n,i,a,o))},os.prototype.addPieSliceVertex=function(t,e,r,n,i,a){r=r.mult(n?-1:1);var o=this.layoutVertexArray,s=this.indexArray;a&&(e=ss(e,a)),as(o,t,r,!1,n,0,e),this.e3=i.vertexLength++,this.e1>=0&&this.e2>=0&&(s.emplaceBack(this.e1,this.e2,this.e3),i.primitiveLength++),n?this.e2=this.e3:this.e1=this.e3},kn(\"LineBucket\",os,{omit:[\"layers\",\"features\"]});var ls=new ei({\"line-cap\":new Jn(It.layout_line[\"line-cap\"]),\"line-join\":new Kn(It.layout_line[\"line-join\"]),\"line-miter-limit\":new Jn(It.layout_line[\"line-miter-limit\"]),\"line-round-limit\":new Jn(It.layout_line[\"line-round-limit\"])}),cs={paint:new ei({\"line-opacity\":new Kn(It.paint_line[\"line-opacity\"]),\"line-color\":new Kn(It.paint_line[\"line-color\"]),\"line-translate\":new Jn(It.paint_line[\"line-translate\"]),\"line-translate-anchor\":new Jn(It.paint_line[\"line-translate-anchor\"]),\"line-width\":new Kn(It.paint_line[\"line-width\"]),\"line-gap-width\":new Kn(It.paint_line[\"line-gap-width\"]),\"line-offset\":new Kn(It.paint_line[\"line-offset\"]),\"line-blur\":new Kn(It.paint_line[\"line-blur\"]),\"line-dasharray\":new Qn(It.paint_line[\"line-dasharray\"]),\"line-pattern\":new $n(It.paint_line[\"line-pattern\"]),\"line-gradient\":new ti(It.paint_line[\"line-gradient\"])}),layout:ls},us=new(function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(e,r){return r=new Un(Math.floor(r.zoom),{now:r.now,fadeDuration:r.fadeDuration,zoomHistory:r.zoomHistory,transition:r.transition}),t.prototype.possiblyEvaluate.call(this,e,r)},e.prototype.evaluate=function(e,r,n,i){return r=h({},r,{zoom:Math.floor(r.zoom)}),t.prototype.evaluate.call(this,e,r,n,i)},e}(Kn))(cs.paint.properties[\"line-width\"].specification);us.useIntegerZoom=!0;var hs=function(t){function e(e){t.call(this,e,cs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"line-gradient\"===t&&this._updateGradient()},e.prototype._updateGradient=function(){var t=this._transitionablePaint._values[\"line-gradient\"].value.expression;this.gradient=Ya(t,\"lineProgress\"),this.gradientTexture=null},e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e),this.paint._values[\"line-floorwidth\"]=us.possiblyEvaluate(this._transitioningPaint._values[\"line-width\"].value,e)},e.prototype.createBucket=function(t){return new os(t)},e.prototype.queryRadius=function(t){var e=t,r=fs(Sa(\"line-width\",this,e),Sa(\"line-gap-width\",this,e)),n=Sa(\"line-offset\",this,e);return r/2+Math.abs(n)+Ea(this.paint.get(\"line-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s){var l=Ca(t,this.paint.get(\"line-translate\"),this.paint.get(\"line-translate-anchor\"),o.angle,s),c=s/2*fs(this.paint.get(\"line-width\").evaluate(e,r),this.paint.get(\"line-gap-width\").evaluate(e,r)),u=this.paint.get(\"line-offset\").evaluate(e,r);return u&&(n=function(t,e){for(var r=[],n=new i(0,0),a=0;a<t.length;a++){for(var o=t[a],s=[],l=0;l<o.length;l++){var c=o[l-1],u=o[l],h=o[l+1],f=0===l?n:u.sub(c)._unit()._perp(),p=l===o.length-1?n:h.sub(u)._unit()._perp(),d=f._add(p)._unit(),g=d.x*p.x+d.y*p.y;d._mult(1/g),s.push(d._mult(e)._add(u))}r.push(s)}return r}(n,u*s)),function(t,e,r){for(var n=0;n<e.length;n++){var i=e[n];if(t.length>=3)for(var a=0;a<i.length;a++)if(Aa(t,i[a]))return!0;if(xa(t,i,r))return!0}return!1}(l,n,c)},e.prototype.isTileClipped=function(){return!0},e}(ri);function fs(t,e){return e>0?e+2*t:t}var ps=oi([{name:\"a_pos_offset\",components:4,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint16\"}]),ds=oi([{name:\"a_projected_pos\",components:3,type:\"Float32\"}],4),gs=(oi([{name:\"a_fade_opacity\",components:1,type:\"Uint32\"}],4),oi([{name:\"a_placed\",components:2,type:\"Uint8\"},{name:\"a_shift\",components:2,type:\"Float32\"}])),vs=(oi([{type:\"Int16\",name:\"anchorPointX\"},{type:\"Int16\",name:\"anchorPointY\"},{type:\"Int16\",name:\"x1\"},{type:\"Int16\",name:\"y1\"},{type:\"Int16\",name:\"x2\"},{type:\"Int16\",name:\"y2\"},{type:\"Uint32\",name:\"featureIndex\"},{type:\"Uint16\",name:\"sourceLayerIndex\"},{type:\"Uint16\",name:\"bucketIndex\"},{type:\"Int16\",name:\"radius\"},{type:\"Int16\",name:\"signedDistanceFromAnchor\"}]),oi([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4)),ms=oi([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4);function ys(t,e,r){return t.sections.forEach(function(t){t.text=function(t,e,r){var n=e.layout.get(\"text-transform\").evaluate(r,{});return\"uppercase\"===n?t=t.toLocaleUpperCase():\"lowercase\"===n&&(t=t.toLocaleLowerCase()),jn.applyArabicShaping&&(t=jn.applyArabicShaping(t)),t}(t.text,e,r)}),t}oi([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Uint16\",name:\"glyphStartIndex\"},{type:\"Uint16\",name:\"numGlyphs\"},{type:\"Uint32\",name:\"vertexStartIndex\"},{type:\"Uint32\",name:\"lineStartIndex\"},{type:\"Uint32\",name:\"lineLength\"},{type:\"Uint16\",name:\"segment\"},{type:\"Uint16\",name:\"lowerSize\"},{type:\"Uint16\",name:\"upperSize\"},{type:\"Float32\",name:\"lineOffsetX\"},{type:\"Float32\",name:\"lineOffsetY\"},{type:\"Uint8\",name:\"writingMode\"},{type:\"Uint8\",name:\"hidden\"},{type:\"Uint32\",name:\"crossTileID\"}]),oi([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Int16\",name:\"rightJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"centerJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"leftJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"verticalPlacedTextSymbolIndex\"},{type:\"Uint16\",name:\"key\"},{type:\"Uint16\",name:\"textBoxStartIndex\"},{type:\"Uint16\",name:\"textBoxEndIndex\"},{type:\"Uint16\",name:\"iconBoxStartIndex\"},{type:\"Uint16\",name:\"iconBoxEndIndex\"},{type:\"Uint16\",name:\"featureIndex\"},{type:\"Uint16\",name:\"numHorizontalGlyphVertices\"},{type:\"Uint16\",name:\"numVerticalGlyphVertices\"},{type:\"Uint16\",name:\"numIconVertices\"},{type:\"Uint32\",name:\"crossTileID\"},{type:\"Float32\",name:\"textBoxScale\"},{type:\"Float32\",name:\"radialTextOffset\"}]),oi([{type:\"Float32\",name:\"offsetX\"}]),oi([{type:\"Int16\",name:\"x\"},{type:\"Int16\",name:\"y\"},{type:\"Int16\",name:\"tileUnitDistanceFromAnchor\"}]);var xs={\"!\":\"\\ufe15\",\"#\":\"\\uff03\",$:\"\\uff04\",\"%\":\"\\uff05\",\"&\":\"\\uff06\",\"(\":\"\\ufe35\",\")\":\"\\ufe36\",\"*\":\"\\uff0a\",\"+\":\"\\uff0b\",\",\":\"\\ufe10\",\"-\":\"\\ufe32\",\".\":\"\\u30fb\",\"/\":\"\\uff0f\",\":\":\"\\ufe13\",\";\":\"\\ufe14\",\"<\":\"\\ufe3f\",\"=\":\"\\uff1d\",\">\":\"\\ufe40\",\"?\":\"\\ufe16\",\"@\":\"\\uff20\",\"[\":\"\\ufe47\",\"\\\\\":\"\\uff3c\",\"]\":\"\\ufe48\",\"^\":\"\\uff3e\",_:\"\\ufe33\",\"`\":\"\\uff40\",\"{\":\"\\ufe37\",\"|\":\"\\u2015\",\"}\":\"\\ufe38\",\"~\":\"\\uff5e\",\"\\xa2\":\"\\uffe0\",\"\\xa3\":\"\\uffe1\",\"\\xa5\":\"\\uffe5\",\"\\xa6\":\"\\uffe4\",\"\\xac\":\"\\uffe2\",\"\\xaf\":\"\\uffe3\",\"\\u2013\":\"\\ufe32\",\"\\u2014\":\"\\ufe31\",\"\\u2018\":\"\\ufe43\",\"\\u2019\":\"\\ufe44\",\"\\u201c\":\"\\ufe41\",\"\\u201d\":\"\\ufe42\",\"\\u2026\":\"\\ufe19\",\"\\u2027\":\"\\u30fb\",\"\\u20a9\":\"\\uffe6\",\"\\u3001\":\"\\ufe11\",\"\\u3002\":\"\\ufe12\",\"\\u3008\":\"\\ufe3f\",\"\\u3009\":\"\\ufe40\",\"\\u300a\":\"\\ufe3d\",\"\\u300b\":\"\\ufe3e\",\"\\u300c\":\"\\ufe41\",\"\\u300d\":\"\\ufe42\",\"\\u300e\":\"\\ufe43\",\"\\u300f\":\"\\ufe44\",\"\\u3010\":\"\\ufe3b\",\"\\u3011\":\"\\ufe3c\",\"\\u3014\":\"\\ufe39\",\"\\u3015\":\"\\ufe3a\",\"\\u3016\":\"\\ufe17\",\"\\u3017\":\"\\ufe18\",\"\\uff01\":\"\\ufe15\",\"\\uff08\":\"\\ufe35\",\"\\uff09\":\"\\ufe36\",\"\\uff0c\":\"\\ufe10\",\"\\uff0d\":\"\\ufe32\",\"\\uff0e\":\"\\u30fb\",\"\\uff1a\":\"\\ufe13\",\"\\uff1b\":\"\\ufe14\",\"\\uff1c\":\"\\ufe3f\",\"\\uff1e\":\"\\ufe40\",\"\\uff1f\":\"\\ufe16\",\"\\uff3b\":\"\\ufe47\",\"\\uff3d\":\"\\ufe48\",\"\\uff3f\":\"\\ufe33\",\"\\uff5b\":\"\\ufe37\",\"\\uff5c\":\"\\u2015\",\"\\uff5d\":\"\\ufe38\",\"\\uff5f\":\"\\ufe35\",\"\\uff60\":\"\\ufe36\",\"\\uff61\":\"\\ufe12\",\"\\uff62\":\"\\ufe41\",\"\\uff63\":\"\\ufe42\"},bs=function(t){function e(e,r,n,i){t.call(this,e,r),this.angle=n,void 0!==i&&(this.segment=i)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.clone=function(){return new e(this.x,this.y,this.angle,this.segment)},e}(i);kn(\"Anchor\",bs);var _s=256;function ws(t,e){var r=e.expression;if(\"constant\"===r.kind)return{kind:\"constant\",layoutSize:r.evaluate(new Un(t+1))};if(\"source\"===r.kind)return{kind:\"source\"};for(var n=r.zoomStops,i=r.interpolationType,a=0;a<n.length&&n[a]<=t;)a++;for(var o=a=Math.max(0,a-1);o<n.length&&n[o]<t+1;)o++;o=Math.min(n.length-1,o);var s=n[a],l=n[o];return\"composite\"===r.kind?{kind:\"composite\",minZoom:s,maxZoom:l,interpolationType:i}:{kind:\"camera\",minZoom:s,maxZoom:l,minSize:r.evaluate(new Un(s)),maxSize:r.evaluate(new Un(l)),interpolationType:i}}function ks(t,e,r){var n=e.uSize,i=e.uSizeT,a=r.lowerSize,o=r.upperSize;return\"source\"===t.kind?a/_s:\"composite\"===t.kind?Ee(a/_s,o/_s,i):n}function Ts(t,e){var r=0,n=0;if(\"constant\"===t.kind)n=t.layoutSize;else if(\"source\"!==t.kind){var i=t.interpolationType,a=t.minZoom,o=t.maxZoom,s=i?c(Xe.interpolationFactor(i,e,a,o),0,1):0;\"camera\"===t.kind?n=Ee(t.minSize,t.maxSize,s):r=s}return{uSizeT:r,uSize:n}}var As=Object.freeze({getSizeData:ws,evaluateSizeForFeature:ks,evaluateSizeForZoom:Ts,SIZE_PACK_FACTOR:_s}),Ms=Vo.VectorTileFeature.types,Ss=[{name:\"a_fade_opacity\",components:1,type:\"Uint8\",offset:0}];function Es(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,Math.round(32*n),Math.round(32*i),a,o,s?s[0]:0,s?s[1]:0)}function Cs(t,e,r){t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r)}var Ls=function(t){this.layoutVertexArray=new pi,this.indexArray=new Ti,this.programConfigurations=t,this.segments=new Vi,this.dynamicLayoutVertexArray=new di,this.opacityVertexArray=new gi,this.placedSymbolArray=new Oi};Ls.prototype.upload=function(t,e,r,n){r&&(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,ps.members),this.indexBuffer=t.createIndexBuffer(this.indexArray,e),this.dynamicLayoutVertexBuffer=t.createVertexBuffer(this.dynamicLayoutVertexArray,ds.members,!0),this.opacityVertexBuffer=t.createVertexBuffer(this.opacityVertexArray,Ss,!0),this.opacityVertexBuffer.itemSize=1),(r||n)&&this.programConfigurations.upload(t)},Ls.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.dynamicLayoutVertexBuffer.destroy(),this.opacityVertexBuffer.destroy())},kn(\"SymbolBuffers\",Ls);var Ps=function(t,e,r){this.layoutVertexArray=new t,this.layoutAttributes=e,this.indexArray=new r,this.segments=new Vi,this.collisionVertexArray=new yi};Ps.prototype.upload=function(t){this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,this.layoutAttributes),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.collisionVertexBuffer=t.createVertexBuffer(this.collisionVertexArray,gs.members,!0)},Ps.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.segments.destroy(),this.collisionVertexBuffer.destroy())},kn(\"CollisionBuffers\",Ps);var Os=function(t){this.collisionBoxArray=t.collisionBoxArray,this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.pixelRatio=t.pixelRatio,this.sourceLayerIndex=t.sourceLayerIndex,this.hasPattern=!1;var e=this.layers[0]._unevaluatedLayout._values;this.textSizeData=ws(this.zoom,e[\"text-size\"]),this.iconSizeData=ws(this.zoom,e[\"icon-size\"]);var r=this.layers[0].layout,n=r.get(\"symbol-sort-key\"),i=r.get(\"symbol-z-order\");this.sortFeaturesByKey=\"viewport-y\"!==i&&void 0!==n.constantOr(1);var a=\"viewport-y\"===i||\"auto\"===i&&!this.sortFeaturesByKey;this.sortFeaturesByY=a&&(r.get(\"text-allow-overlap\")||r.get(\"icon-allow-overlap\")||r.get(\"text-ignore-placement\")||r.get(\"icon-ignore-placement\")),this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id}),this.sourceID=t.sourceID};Os.prototype.createArrays=function(){this.text=new Ls(new la(ps.members,this.layers,this.zoom,function(t){return/^text/.test(t)})),this.icon=new Ls(new la(ps.members,this.layers,this.zoom,function(t){return/^icon/.test(t)})),this.collisionBox=new Ps(mi,vs.members,Ai),this.collisionCircle=new Ps(mi,ms.members,Ti),this.glyphOffsetArray=new Ri,this.lineVertexArray=new Bi,this.symbolInstances=new Ii},Os.prototype.calculateGlyphDependencies=function(t,e,r,n){for(var i=0;i<t.length;i++)if(e[t.charCodeAt(i)]=!0,r&&n){var a=xs[t.charAt(i)];a&&(e[a.charCodeAt(0)]=!0)}},Os.prototype.populate=function(t,e){var r=this.layers[0],n=r.layout,i=n.get(\"text-font\"),a=n.get(\"text-field\"),o=n.get(\"icon-image\"),s=(\"constant\"!==a.value.kind||a.value.value.toString().length>0)&&(\"constant\"!==i.value.kind||i.value.value.length>0),l=\"constant\"!==o.value.kind||o.value.value&&o.value.value.length>0,c=n.get(\"symbol-sort-key\");if(this.features=[],s||l){for(var u=e.iconDependencies,h=e.glyphDependencies,f=new Un(this.zoom),p=0,d=t;p<d.length;p+=1){var g=d[p],v=g.feature,m=g.index,y=g.sourceLayerIndex;if(r._featureFilter(f,v)){var x=void 0;if(s){var b=r.getValueAndResolveTokens(\"text-field\",v);x=ys(b instanceof oe?b:oe.fromString(b),r,v)}var _=void 0;if(l&&(_=r.getValueAndResolveTokens(\"icon-image\",v)),x||_){var w=this.sortFeaturesByKey?c.evaluate(v,{}):void 0,k={text:x,icon:_,index:m,sourceLayerIndex:y,geometry:pa(v),properties:v.properties,type:Ms[v.type],sortKey:w};if(void 0!==v.id&&(k.id=v.id),this.features.push(k),_&&(u[_]=!0),x)for(var T=i.evaluate(v,{}).join(\",\"),A=\"map\"===n.get(\"text-rotation-alignment\")&&\"point\"!==n.get(\"symbol-placement\"),M=0,S=x.sections;M<S.length;M+=1){var E=S[M],C=Cn(x.toString()),L=E.fontStack||T,P=h[L]=h[L]||{};this.calculateGlyphDependencies(E.text,P,A,C)}}}}\"line\"===n.get(\"symbol-placement\")&&(this.features=function(t){var e={},r={},n=[],i=0;function a(e){n.push(t[e]),i++}function o(t,e,i){var a=r[t];return delete r[t],r[e]=a,n[a].geometry[0].pop(),n[a].geometry[0]=n[a].geometry[0].concat(i[0]),a}function s(t,r,i){var a=e[r];return delete e[r],e[t]=a,n[a].geometry[0].shift(),n[a].geometry[0]=i[0].concat(n[a].geometry[0]),a}function l(t,e,r){var n=r?e[0][e[0].length-1]:e[0][0];return t+\":\"+n.x+\":\"+n.y}for(var c=0;c<t.length;c++){var u=t[c],h=u.geometry,f=u.text?u.text.toString():null;if(f){var p=l(f,h),d=l(f,h,!0);if(p in r&&d in e&&r[p]!==e[d]){var g=s(p,d,h),v=o(p,d,n[g].geometry);delete e[p],delete r[d],r[l(f,n[v].geometry,!0)]=v,n[g].geometry=null}else p in r?o(p,d,h):d in e?s(p,d,h):(a(c),e[p]=i-1,r[d]=i-1)}else a(c)}return n.filter(function(t){return t.geometry})}(this.features)),this.sortFeaturesByKey&&this.features.sort(function(t,e){return t.sortKey-e.sortKey})}},Os.prototype.update=function(t,e,r){this.stateDependentLayers.length&&(this.text.programConfigurations.updatePaintArrays(t,e,this.layers,r),this.icon.programConfigurations.updatePaintArrays(t,e,this.layers,r))},Os.prototype.isEmpty=function(){return 0===this.symbolInstances.length},Os.prototype.uploadPending=function(){return!this.uploaded||this.text.programConfigurations.needsUpload||this.icon.programConfigurations.needsUpload},Os.prototype.upload=function(t){this.uploaded||(this.collisionBox.upload(t),this.collisionCircle.upload(t)),this.text.upload(t,this.sortFeaturesByY,!this.uploaded,this.text.programConfigurations.needsUpload),this.icon.upload(t,this.sortFeaturesByY,!this.uploaded,this.icon.programConfigurations.needsUpload),this.uploaded=!0},Os.prototype.destroy=function(){this.text.destroy(),this.icon.destroy(),this.collisionBox.destroy(),this.collisionCircle.destroy()},Os.prototype.addToLineVertexArray=function(t,e){var r=this.lineVertexArray.length;if(void 0!==t.segment){for(var n=t.dist(e[t.segment+1]),i=t.dist(e[t.segment]),a={},o=t.segment+1;o<e.length;o++)a[o]={x:e[o].x,y:e[o].y,tileUnitDistanceFromAnchor:n},o<e.length-1&&(n+=e[o+1].dist(e[o]));for(var s=t.segment||0;s>=0;s--)a[s]={x:e[s].x,y:e[s].y,tileUnitDistanceFromAnchor:i},s>0&&(i+=e[s-1].dist(e[s]));for(var l=0;l<e.length;l++){var c=a[l];this.lineVertexArray.emplaceBack(c.x,c.y,c.tileUnitDistanceFromAnchor)}}return{lineStartIndex:r,lineLength:this.lineVertexArray.length-r}},Os.prototype.addSymbols=function(t,e,r,n,i,a,o,s,l,c){for(var u=t.indexArray,h=t.layoutVertexArray,f=t.dynamicLayoutVertexArray,p=t.segments.prepareSegment(4*e.length,t.layoutVertexArray,t.indexArray,a.sortKey),d=this.glyphOffsetArray.length,g=p.vertexLength,v=0,m=e;v<m.length;v+=1){var y=m[v],x=y.tl,b=y.tr,_=y.bl,w=y.br,k=y.tex,T=p.vertexLength,A=y.glyphOffset[1];Es(h,s.x,s.y,x.x,A+x.y,k.x,k.y,r),Es(h,s.x,s.y,b.x,A+b.y,k.x+k.w,k.y,r),Es(h,s.x,s.y,_.x,A+_.y,k.x,k.y+k.h,r),Es(h,s.x,s.y,w.x,A+w.y,k.x+k.w,k.y+k.h,r),Cs(f,s,0),u.emplaceBack(T,T+1,T+2),u.emplaceBack(T+1,T+2,T+3),p.vertexLength+=4,p.primitiveLength+=2,this.glyphOffsetArray.emplaceBack(y.glyphOffset[0])}t.placedSymbolArray.emplaceBack(s.x,s.y,d,this.glyphOffsetArray.length-d,g,l,c,s.segment,r?r[0]:0,r?r[1]:0,n[0],n[1],o,!1,0),t.programConfigurations.populatePaintArrays(t.layoutVertexArray.length,a,a.index,{})},Os.prototype._addCollisionDebugVertex=function(t,e,r,n,i,a){return e.emplaceBack(0,0),t.emplaceBack(r.x,r.y,n,i,Math.round(a.x),Math.round(a.y))},Os.prototype.addCollisionDebugVertices=function(t,e,r,n,a,o,s,l){var c=a.segments.prepareSegment(4,a.layoutVertexArray,a.indexArray),u=c.vertexLength,h=a.layoutVertexArray,f=a.collisionVertexArray,p=s.anchorX,d=s.anchorY;if(this._addCollisionDebugVertex(h,f,o,p,d,new i(t,e)),this._addCollisionDebugVertex(h,f,o,p,d,new i(r,e)),this._addCollisionDebugVertex(h,f,o,p,d,new i(r,n)),this._addCollisionDebugVertex(h,f,o,p,d,new i(t,n)),c.vertexLength+=4,l){var g=a.indexArray;g.emplaceBack(u,u+1,u+2),g.emplaceBack(u,u+2,u+3),c.primitiveLength+=2}else{var v=a.indexArray;v.emplaceBack(u,u+1),v.emplaceBack(u+1,u+2),v.emplaceBack(u+2,u+3),v.emplaceBack(u+3,u),c.primitiveLength+=4}},Os.prototype.addDebugCollisionBoxes=function(t,e,r){for(var n=t;n<e;n++){var i=this.collisionBoxArray.get(n),a=i.x1,o=i.y1,s=i.x2,l=i.y2,c=i.radius>0;this.addCollisionDebugVertices(a,o,s,l,c?this.collisionCircle:this.collisionBox,i.anchorPoint,r,c)}},Os.prototype.generateCollisionDebugBuffers=function(){for(var t=0;t<this.symbolInstances.length;t++){var e=this.symbolInstances.get(t);this.addDebugCollisionBoxes(e.textBoxStartIndex,e.textBoxEndIndex,e),this.addDebugCollisionBoxes(e.iconBoxStartIndex,e.iconBoxEndIndex,e)}},Os.prototype._deserializeCollisionBoxesForSymbol=function(t,e,r,n,i){for(var a={},o=e;o<r;o++){var s=t.get(o);if(0===s.radius){a.textBox={x1:s.x1,y1:s.y1,x2:s.x2,y2:s.y2,anchorPointX:s.anchorPointX,anchorPointY:s.anchorPointY},a.textFeatureIndex=s.featureIndex;break}a.textCircles||(a.textCircles=[],a.textFeatureIndex=s.featureIndex),a.textCircles.push(s.anchorPointX,s.anchorPointY,s.radius,s.signedDistanceFromAnchor,1)}for(var l=n;l<i;l++){var c=t.get(l);if(0===c.radius){a.iconBox={x1:c.x1,y1:c.y1,x2:c.x2,y2:c.y2,anchorPointX:c.anchorPointX,anchorPointY:c.anchorPointY},a.iconFeatureIndex=c.featureIndex;break}}return a},Os.prototype.deserializeCollisionBoxes=function(t){this.collisionArrays=[];for(var e=0;e<this.symbolInstances.length;e++){var r=this.symbolInstances.get(e);this.collisionArrays.push(this._deserializeCollisionBoxesForSymbol(t,r.textBoxStartIndex,r.textBoxEndIndex,r.iconBoxStartIndex,r.iconBoxEndIndex))}},Os.prototype.hasTextData=function(){return this.text.segments.get().length>0},Os.prototype.hasIconData=function(){return this.icon.segments.get().length>0},Os.prototype.hasCollisionBoxData=function(){return this.collisionBox.segments.get().length>0},Os.prototype.hasCollisionCircleData=function(){return this.collisionCircle.segments.get().length>0},Os.prototype.addIndicesForPlacedTextSymbol=function(t){for(var e=this.text.placedSymbolArray.get(t),r=e.vertexStartIndex+4*e.numGlyphs,n=e.vertexStartIndex;n<r;n+=4)this.text.indexArray.emplaceBack(n,n+1,n+2),this.text.indexArray.emplaceBack(n+1,n+2,n+3)},Os.prototype.getSortedSymbolIndexes=function(t){if(this.sortedAngle===t&&void 0!==this.symbolInstanceIndexes)return this.symbolInstanceIndexes;for(var e=Math.sin(t),r=Math.cos(t),n=[],i=[],a=[],o=0;o<this.symbolInstances.length;++o){a.push(o);var s=this.symbolInstances.get(o);n.push(0|Math.round(e*s.anchorX+r*s.anchorY)),i.push(s.featureIndex)}return a.sort(function(t,e){return n[t]-n[e]||i[e]-i[t]}),a},Os.prototype.sortFeatures=function(t){var e=this;if(this.sortFeaturesByY&&this.sortedAngle!==t&&!(this.text.segments.get().length>1||this.icon.segments.get().length>1)){this.symbolInstanceIndexes=this.getSortedSymbolIndexes(t),this.sortedAngle=t,this.text.indexArray.clear(),this.icon.indexArray.clear(),this.featureSortOrder=[];for(var r=0,n=this.symbolInstanceIndexes;r<n.length;r+=1){var i=n[r],a=this.symbolInstances.get(i);this.featureSortOrder.push(a.featureIndex),[a.rightJustifiedTextSymbolIndex,a.centerJustifiedTextSymbolIndex,a.leftJustifiedTextSymbolIndex].forEach(function(t,r,n){t>=0&&n.indexOf(t)===r&&e.addIndicesForPlacedTextSymbol(t)}),a.verticalPlacedTextSymbolIndex>=0&&this.addIndicesForPlacedTextSymbol(a.verticalPlacedTextSymbolIndex);var o=this.icon.placedSymbolArray.get(i);if(o.numGlyphs){var s=o.vertexStartIndex;this.icon.indexArray.emplaceBack(s,s+1,s+2),this.icon.indexArray.emplaceBack(s+1,s+2,s+3)}}this.text.indexBuffer&&this.text.indexBuffer.updateData(this.text.indexArray),this.icon.indexBuffer&&this.icon.indexBuffer.updateData(this.icon.indexArray)}},kn(\"SymbolBucket\",Os,{omit:[\"layers\",\"collisionBoxArray\",\"features\",\"compareText\"]}),Os.MAX_GLYPHS=65535,Os.addDynamicAttributes=Cs;var zs=new ei({\"symbol-placement\":new Jn(It.layout_symbol[\"symbol-placement\"]),\"symbol-spacing\":new Jn(It.layout_symbol[\"symbol-spacing\"]),\"symbol-avoid-edges\":new Jn(It.layout_symbol[\"symbol-avoid-edges\"]),\"symbol-sort-key\":new Kn(It.layout_symbol[\"symbol-sort-key\"]),\"symbol-z-order\":new Jn(It.layout_symbol[\"symbol-z-order\"]),\"icon-allow-overlap\":new Jn(It.layout_symbol[\"icon-allow-overlap\"]),\"icon-ignore-placement\":new Jn(It.layout_symbol[\"icon-ignore-placement\"]),\"icon-optional\":new Jn(It.layout_symbol[\"icon-optional\"]),\"icon-rotation-alignment\":new Jn(It.layout_symbol[\"icon-rotation-alignment\"]),\"icon-size\":new Kn(It.layout_symbol[\"icon-size\"]),\"icon-text-fit\":new Jn(It.layout_symbol[\"icon-text-fit\"]),\"icon-text-fit-padding\":new Jn(It.layout_symbol[\"icon-text-fit-padding\"]),\"icon-image\":new Kn(It.layout_symbol[\"icon-image\"]),\"icon-rotate\":new Kn(It.layout_symbol[\"icon-rotate\"]),\"icon-padding\":new Jn(It.layout_symbol[\"icon-padding\"]),\"icon-keep-upright\":new Jn(It.layout_symbol[\"icon-keep-upright\"]),\"icon-offset\":new Kn(It.layout_symbol[\"icon-offset\"]),\"icon-anchor\":new Kn(It.layout_symbol[\"icon-anchor\"]),\"icon-pitch-alignment\":new Jn(It.layout_symbol[\"icon-pitch-alignment\"]),\"text-pitch-alignment\":new Jn(It.layout_symbol[\"text-pitch-alignment\"]),\"text-rotation-alignment\":new Jn(It.layout_symbol[\"text-rotation-alignment\"]),\"text-field\":new Kn(It.layout_symbol[\"text-field\"]),\"text-font\":new Kn(It.layout_symbol[\"text-font\"]),\"text-size\":new Kn(It.layout_symbol[\"text-size\"]),\"text-max-width\":new Kn(It.layout_symbol[\"text-max-width\"]),\"text-line-height\":new Jn(It.layout_symbol[\"text-line-height\"]),\"text-letter-spacing\":new Kn(It.layout_symbol[\"text-letter-spacing\"]),\"text-justify\":new Kn(It.layout_symbol[\"text-justify\"]),\"text-radial-offset\":new Kn(It.layout_symbol[\"text-radial-offset\"]),\"text-variable-anchor\":new Jn(It.layout_symbol[\"text-variable-anchor\"]),\"text-anchor\":new Kn(It.layout_symbol[\"text-anchor\"]),\"text-max-angle\":new Jn(It.layout_symbol[\"text-max-angle\"]),\"text-rotate\":new Kn(It.layout_symbol[\"text-rotate\"]),\"text-padding\":new Jn(It.layout_symbol[\"text-padding\"]),\"text-keep-upright\":new Jn(It.layout_symbol[\"text-keep-upright\"]),\"text-transform\":new Kn(It.layout_symbol[\"text-transform\"]),\"text-offset\":new Kn(It.layout_symbol[\"text-offset\"]),\"text-allow-overlap\":new Jn(It.layout_symbol[\"text-allow-overlap\"]),\"text-ignore-placement\":new Jn(It.layout_symbol[\"text-ignore-placement\"]),\"text-optional\":new Jn(It.layout_symbol[\"text-optional\"])}),Is={paint:new ei({\"icon-opacity\":new Kn(It.paint_symbol[\"icon-opacity\"]),\"icon-color\":new Kn(It.paint_symbol[\"icon-color\"]),\"icon-halo-color\":new Kn(It.paint_symbol[\"icon-halo-color\"]),\"icon-halo-width\":new Kn(It.paint_symbol[\"icon-halo-width\"]),\"icon-halo-blur\":new Kn(It.paint_symbol[\"icon-halo-blur\"]),\"icon-translate\":new Jn(It.paint_symbol[\"icon-translate\"]),\"icon-translate-anchor\":new Jn(It.paint_symbol[\"icon-translate-anchor\"]),\"text-opacity\":new Kn(It.paint_symbol[\"text-opacity\"]),\"text-color\":new Kn(It.paint_symbol[\"text-color\"]),\"text-halo-color\":new Kn(It.paint_symbol[\"text-halo-color\"]),\"text-halo-width\":new Kn(It.paint_symbol[\"text-halo-width\"]),\"text-halo-blur\":new Kn(It.paint_symbol[\"text-halo-blur\"]),\"text-translate\":new Jn(It.paint_symbol[\"text-translate\"]),\"text-translate-anchor\":new Jn(It.paint_symbol[\"text-translate-anchor\"])}),layout:zs},Ds=function(t){function e(e){t.call(this,e,Is)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e),\"auto\"===this.layout.get(\"icon-rotation-alignment\")&&(\"point\"!==this.layout.get(\"symbol-placement\")?this.layout._values[\"icon-rotation-alignment\"]=\"map\":this.layout._values[\"icon-rotation-alignment\"]=\"viewport\"),\"auto\"===this.layout.get(\"text-rotation-alignment\")&&(\"point\"!==this.layout.get(\"symbol-placement\")?this.layout._values[\"text-rotation-alignment\"]=\"map\":this.layout._values[\"text-rotation-alignment\"]=\"viewport\"),\"auto\"===this.layout.get(\"text-pitch-alignment\")&&(this.layout._values[\"text-pitch-alignment\"]=this.layout.get(\"text-rotation-alignment\")),\"auto\"===this.layout.get(\"icon-pitch-alignment\")&&(this.layout._values[\"icon-pitch-alignment\"]=this.layout.get(\"icon-rotation-alignment\"))},e.prototype.getValueAndResolveTokens=function(t,e){var r,n=this.layout.get(t).evaluate(e,{}),i=this._unevaluatedLayout._values[t];return i.isDataDriven()||Pr(i.value)?n:(r=e.properties,n.replace(/{([^{}]+)}/g,function(t,e){return e in r?String(r[e]):\"\"}))},e.prototype.createBucket=function(t){return new Os(t)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e}(ri),Rs={paint:new ei({\"background-color\":new Jn(It.paint_background[\"background-color\"]),\"background-pattern\":new Qn(It.paint_background[\"background-pattern\"]),\"background-opacity\":new Jn(It.paint_background[\"background-opacity\"])})},Fs=function(t){function e(e){t.call(this,e,Rs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ri),Bs={paint:new ei({\"raster-opacity\":new Jn(It.paint_raster[\"raster-opacity\"]),\"raster-hue-rotate\":new Jn(It.paint_raster[\"raster-hue-rotate\"]),\"raster-brightness-min\":new Jn(It.paint_raster[\"raster-brightness-min\"]),\"raster-brightness-max\":new Jn(It.paint_raster[\"raster-brightness-max\"]),\"raster-saturation\":new Jn(It.paint_raster[\"raster-saturation\"]),\"raster-contrast\":new Jn(It.paint_raster[\"raster-contrast\"]),\"raster-resampling\":new Jn(It.paint_raster[\"raster-resampling\"]),\"raster-fade-duration\":new Jn(It.paint_raster[\"raster-fade-duration\"])})},Ns=function(t){function e(e){t.call(this,e,Bs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ri),js=function(t){function e(e){t.call(this,e,{}),this.implementation=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.is3D=function(){return\"3d\"===this.implementation.renderingMode},e.prototype.hasOffscreenPass=function(){return void 0!==this.implementation.prerender},e.prototype.recalculate=function(){},e.prototype.updateTransitions=function(){},e.prototype.hasTransition=function(){},e.prototype.serialize=function(){},e.prototype.onAdd=function(t){this.implementation.onAdd&&this.implementation.onAdd(t,t.painter.context.gl)},e.prototype.onRemove=function(t){this.implementation.onRemove&&this.implementation.onRemove(t,t.painter.context.gl)},e}(ri),Us={circle:Fa,heatmap:Wa,hillshade:Za,fill:Oo,\"fill-extrusion\":Jo,line:hs,symbol:Ds,background:Fs,raster:Ns};function Vs(t){for(var e=0,r=0,n=0,i=t;n<i.length;n+=1){var a=i[n];e+=a.w*a.h,r=Math.max(r,a.w)}t.sort(function(t,e){return e.h-t.h});for(var o=[{x:0,y:0,w:Math.max(Math.ceil(Math.sqrt(e/.95)),r),h:1/0}],s=0,l=0,c=0,u=t;c<u.length;c+=1)for(var h=u[c],f=o.length-1;f>=0;f--){var p=o[f];if(!(h.w>p.w||h.h>p.h)){if(h.x=p.x,h.y=p.y,l=Math.max(l,h.y+h.h),s=Math.max(s,h.x+h.w),h.w===p.w&&h.h===p.h){var d=o.pop();f<o.length&&(o[f]=d)}else h.h===p.h?(p.x+=h.w,p.w-=h.w):h.w===p.w?(p.y+=h.h,p.h-=h.h):(o.push({x:p.x+h.w,y:p.y,w:p.w-h.w,h:h.h}),p.y+=h.h,p.h-=h.h);break}}return{w:s,h:l,fill:e/(s*l)||0}}var qs=function(t,e){var r=e.pixelRatio,n=e.version;this.paddedRect=t,this.pixelRatio=r,this.version=n},Hs={tl:{configurable:!0},br:{configurable:!0},tlbr:{configurable:!0},displaySize:{configurable:!0}};Hs.tl.get=function(){return[this.paddedRect.x+1,this.paddedRect.y+1]},Hs.br.get=function(){return[this.paddedRect.x+this.paddedRect.w-1,this.paddedRect.y+this.paddedRect.h-1]},Hs.tlbr.get=function(){return this.tl.concat(this.br)},Hs.displaySize.get=function(){return[(this.paddedRect.w-2)/this.pixelRatio,(this.paddedRect.h-2)/this.pixelRatio]},Object.defineProperties(qs.prototype,Hs);var Gs=function(t,e){var r={},n={};this.haveRenderCallbacks=[];var i=[];this.addImages(t,r,i),this.addImages(e,n,i);var a=Vs(i),o=a.w,s=a.h,l=new Ha({width:o||1,height:s||1});for(var c in t){var u=t[c],h=r[c].paddedRect;Ha.copy(u.data,l,{x:0,y:0},{x:h.x+1,y:h.y+1},u.data)}for(var f in e){var p=e[f],d=n[f].paddedRect,g=d.x+1,v=d.y+1,m=p.data.width,y=p.data.height;Ha.copy(p.data,l,{x:0,y:0},{x:g,y:v},p.data),Ha.copy(p.data,l,{x:0,y:y-1},{x:g,y:v-1},{width:m,height:1}),Ha.copy(p.data,l,{x:0,y:0},{x:g,y:v+y},{width:m,height:1}),Ha.copy(p.data,l,{x:m-1,y:0},{x:g-1,y:v},{width:1,height:y}),Ha.copy(p.data,l,{x:0,y:0},{x:g+m,y:v},{width:1,height:y})}this.image=l,this.iconPositions=r,this.patternPositions=n};Gs.prototype.addImages=function(t,e,r){for(var n in t){var i=t[n],a={x:0,y:0,w:i.data.width+2,h:i.data.height+2};r.push(a),e[n]=new qs(a,i),i.hasRenderCallback&&this.haveRenderCallbacks.push(n)}},Gs.prototype.patchUpdatedImages=function(t,e){for(var r in t.dispatchRenderCallbacks(this.haveRenderCallbacks),t.updatedImages)this.patchUpdatedImage(this.iconPositions[r],t.getImage(r),e),this.patchUpdatedImage(this.patternPositions[r],t.getImage(r),e)},Gs.prototype.patchUpdatedImage=function(t,e,r){if(t&&e&&t.version!==e.version){t.version=e.version;var n=t.tl,i=n[0],a=n[1];r.update(e.data,void 0,{x:i,y:a})}},kn(\"ImagePosition\",qs),kn(\"ImageAtlas\",Gs);var Ys=self.HTMLImageElement,Ws=self.HTMLCanvasElement,Xs=self.HTMLVideoElement,Zs=self.ImageData,Js=function(t,e,r,n){this.context=t,this.format=r,this.texture=t.gl.createTexture(),this.update(e,n)};Js.prototype.update=function(t,e,r){var n=t.width,i=t.height,a=!(this.size&&this.size[0]===n&&this.size[1]===i||r),o=this.context,s=o.gl;if(this.useMipmap=Boolean(e&&e.useMipmap),s.bindTexture(s.TEXTURE_2D,this.texture),o.pixelStoreUnpackFlipY.set(!1),o.pixelStoreUnpack.set(1),o.pixelStoreUnpackPremultiplyAlpha.set(this.format===s.RGBA&&(!e||!1!==e.premultiply)),a)this.size=[n,i],t instanceof Ys||t instanceof Ws||t instanceof Xs||t instanceof Zs?s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,s.UNSIGNED_BYTE,t):s.texImage2D(s.TEXTURE_2D,0,this.format,n,i,0,this.format,s.UNSIGNED_BYTE,t.data);else{var l=r||{x:0,y:0},c=l.x,u=l.y;t instanceof Ys||t instanceof Ws||t instanceof Xs||t instanceof Zs?s.texSubImage2D(s.TEXTURE_2D,0,c,u,s.RGBA,s.UNSIGNED_BYTE,t):s.texSubImage2D(s.TEXTURE_2D,0,c,u,n,i,s.RGBA,s.UNSIGNED_BYTE,t.data)}this.useMipmap&&this.isSizePowerOfTwo()&&s.generateMipmap(s.TEXTURE_2D)},Js.prototype.bind=function(t,e,r){var n=this.context.gl;n.bindTexture(n.TEXTURE_2D,this.texture),r!==n.LINEAR_MIPMAP_NEAREST||this.isSizePowerOfTwo()||(r=n.LINEAR),t!==this.filter&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,t),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,r||t),this.filter=t),e!==this.wrap&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,e),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,e),this.wrap=e)},Js.prototype.isSizePowerOfTwo=function(){return this.size[0]===this.size[1]&&Math.log(this.size[0])/Math.LN2%1==0},Js.prototype.destroy=function(){this.context.gl.deleteTexture(this.texture),this.texture=null};var Ks=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?i-1:0,f=r?-1:1,p=t[e+h];for(h+=f,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+h],h+=f,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},$s=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,h=u>>1,f=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,i),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g},Qs=tl;function tl(t){this.buf=ArrayBuffer.isView&&ArrayBuffer.isView(t)?t:new Uint8Array(t||0),this.pos=0,this.type=0,this.length=this.buf.length}function el(t){return t.type===tl.Bytes?t.readVarint()+t.pos:t.pos+1}function rl(t,e,r){return r?4294967296*e+(t>>>0):4294967296*(e>>>0)+(t>>>0)}function nl(t,e,r){var n=e<=16383?1:e<=2097151?2:e<=268435455?3:Math.floor(Math.log(e)/(7*Math.LN2));r.realloc(n);for(var i=r.pos-1;i>=t;i--)r.buf[i+n]=r.buf[i]}function il(t,e){for(var r=0;r<t.length;r++)e.writeVarint(t[r])}function al(t,e){for(var r=0;r<t.length;r++)e.writeSVarint(t[r])}function ol(t,e){for(var r=0;r<t.length;r++)e.writeFloat(t[r])}function sl(t,e){for(var r=0;r<t.length;r++)e.writeDouble(t[r])}function ll(t,e){for(var r=0;r<t.length;r++)e.writeBoolean(t[r])}function cl(t,e){for(var r=0;r<t.length;r++)e.writeFixed32(t[r])}function ul(t,e){for(var r=0;r<t.length;r++)e.writeSFixed32(t[r])}function hl(t,e){for(var r=0;r<t.length;r++)e.writeFixed64(t[r])}function fl(t,e){for(var r=0;r<t.length;r++)e.writeSFixed64(t[r])}function pl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+16777216*t[e+3]}function dl(t,e,r){t[r]=e,t[r+1]=e>>>8,t[r+2]=e>>>16,t[r+3]=e>>>24}function gl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+(t[e+3]<<24)}tl.Varint=0,tl.Fixed64=1,tl.Bytes=2,tl.Fixed32=5,tl.prototype={destroy:function(){this.buf=null},readFields:function(t,e,r){for(r=r||this.length;this.pos<r;){var n=this.readVarint(),i=n>>3,a=this.pos;this.type=7&n,t(i,e,this),this.pos===a&&this.skip(n)}return e},readMessage:function(t,e){return this.readFields(t,e,this.readVarint()+this.pos)},readFixed32:function(){var t=pl(this.buf,this.pos);return this.pos+=4,t},readSFixed32:function(){var t=gl(this.buf,this.pos);return this.pos+=4,t},readFixed64:function(){var t=pl(this.buf,this.pos)+4294967296*pl(this.buf,this.pos+4);return this.pos+=8,t},readSFixed64:function(){var t=pl(this.buf,this.pos)+4294967296*gl(this.buf,this.pos+4);return this.pos+=8,t},readFloat:function(){var t=Ks(this.buf,this.pos,!0,23,4);return this.pos+=4,t},readDouble:function(){var t=Ks(this.buf,this.pos,!0,52,8);return this.pos+=8,t},readVarint:function(t){var e,r,n=this.buf;return e=127&(r=n[this.pos++]),r<128?e:(e|=(127&(r=n[this.pos++]))<<7,r<128?e:(e|=(127&(r=n[this.pos++]))<<14,r<128?e:(e|=(127&(r=n[this.pos++]))<<21,r<128?e:function(t,e,r){var n,i,a=r.buf;if(n=(112&(i=a[r.pos++]))>>4,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<3,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<10,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<17,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<24,i<128)return rl(t,n,e);if(n|=(1&(i=a[r.pos++]))<<31,i<128)return rl(t,n,e);throw new Error(\"Expected varint not more than 10 bytes\")}(e|=(15&(r=n[this.pos]))<<28,t,this))))},readVarint64:function(){return this.readVarint(!0)},readSVarint:function(){var t=this.readVarint();return t%2==1?(t+1)/-2:t/2},readBoolean:function(){return Boolean(this.readVarint())},readString:function(){var t=this.readVarint()+this.pos,e=function(t,e,r){for(var n=\"\",i=e;i<r;){var a,o,s,l=t[i],c=null,u=l>239?4:l>223?3:l>191?2:1;if(i+u>r)break;1===u?l<128&&(c=l):2===u?128==(192&(a=t[i+1]))&&(c=(31&l)<<6|63&a)<=127&&(c=null):3===u?(a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&((c=(15&l)<<12|(63&a)<<6|63&o)<=2047||c>=55296&&c<=57343)&&(c=null)):4===u&&(a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&((c=(15&l)<<18|(63&a)<<12|(63&o)<<6|63&s)<=65535||c>=1114112)&&(c=null)),null===c?(c=65533,u=1):c>65535&&(c-=65536,n+=String.fromCharCode(c>>>10&1023|55296),c=56320|1023&c),n+=String.fromCharCode(c),i+=u}return n}(this.buf,this.pos,t);return this.pos=t,e},readBytes:function(){var t=this.readVarint()+this.pos,e=this.buf.subarray(this.pos,t);return this.pos=t,e},readPackedVarint:function(t,e){if(this.type!==tl.Bytes)return t.push(this.readVarint(e));var r=el(this);for(t=t||[];this.pos<r;)t.push(this.readVarint(e));return t},readPackedSVarint:function(t){if(this.type!==tl.Bytes)return t.push(this.readSVarint());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSVarint());return t},readPackedBoolean:function(t){if(this.type!==tl.Bytes)return t.push(this.readBoolean());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readBoolean());return t},readPackedFloat:function(t){if(this.type!==tl.Bytes)return t.push(this.readFloat());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFloat());return t},readPackedDouble:function(t){if(this.type!==tl.Bytes)return t.push(this.readDouble());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readDouble());return t},readPackedFixed32:function(t){if(this.type!==tl.Bytes)return t.push(this.readFixed32());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFixed32());return t},readPackedSFixed32:function(t){if(this.type!==tl.Bytes)return t.push(this.readSFixed32());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed32());return t},readPackedFixed64:function(t){if(this.type!==tl.Bytes)return t.push(this.readFixed64());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFixed64());return t},readPackedSFixed64:function(t){if(this.type!==tl.Bytes)return t.push(this.readSFixed64());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed64());return t},skip:function(t){var e=7&t;if(e===tl.Varint)for(;this.buf[this.pos++]>127;);else if(e===tl.Bytes)this.pos=this.readVarint()+this.pos;else if(e===tl.Fixed32)this.pos+=4;else{if(e!==tl.Fixed64)throw new Error(\"Unimplemented type: \"+e);this.pos+=8}},writeTag:function(t,e){this.writeVarint(t<<3|e)},realloc:function(t){for(var e=this.length||16;e<this.pos+t;)e*=2;if(e!==this.length){var r=new Uint8Array(e);r.set(this.buf),this.buf=r,this.length=e}},finish:function(){return this.length=this.pos,this.pos=0,this.buf.subarray(0,this.length)},writeFixed32:function(t){this.realloc(4),dl(this.buf,t,this.pos),this.pos+=4},writeSFixed32:function(t){this.realloc(4),dl(this.buf,t,this.pos),this.pos+=4},writeFixed64:function(t){this.realloc(8),dl(this.buf,-1&t,this.pos),dl(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeSFixed64:function(t){this.realloc(8),dl(this.buf,-1&t,this.pos),dl(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeVarint:function(t){(t=+t||0)>268435455||t<0?function(t,e){var r,n;if(t>=0?(r=t%4294967296|0,n=t/4294967296|0):(n=~(-t/4294967296),4294967295^(r=~(-t%4294967296))?r=r+1|0:(r=0,n=n+1|0)),t>=0x10000000000000000||t<-0x10000000000000000)throw new Error(\"Given varint doesn't fit into 10 bytes\");e.realloc(10),function(t,e,r){r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos]=127&t}(r,0,e),function(t,e){var r=(7&t)<<4;e.buf[e.pos++]|=r|((t>>>=3)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t)))))}(n,e)}(t,this):(this.realloc(4),this.buf[this.pos++]=127&t|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=t>>>7&127))))},writeSVarint:function(t){this.writeVarint(t<0?2*-t-1:2*t)},writeBoolean:function(t){this.writeVarint(Boolean(t))},writeString:function(t){t=String(t),this.realloc(4*t.length),this.pos++;var e=this.pos;this.pos=function(t,e,r){for(var n,i,a=0;a<e.length;a++){if((n=e.charCodeAt(a))>55295&&n<57344){if(!i){n>56319||a+1===e.length?(t[r++]=239,t[r++]=191,t[r++]=189):i=n;continue}if(n<56320){t[r++]=239,t[r++]=191,t[r++]=189,i=n;continue}n=i-55296<<10|n-56320|65536,i=null}else i&&(t[r++]=239,t[r++]=191,t[r++]=189,i=null);n<128?t[r++]=n:(n<2048?t[r++]=n>>6|192:(n<65536?t[r++]=n>>12|224:(t[r++]=n>>18|240,t[r++]=n>>12&63|128),t[r++]=n>>6&63|128),t[r++]=63&n|128)}return r}(this.buf,t,this.pos);var r=this.pos-e;r>=128&&nl(e,r,this),this.pos=e-1,this.writeVarint(r),this.pos+=r},writeFloat:function(t){this.realloc(4),$s(this.buf,t,this.pos,!0,23,4),this.pos+=4},writeDouble:function(t){this.realloc(8),$s(this.buf,t,this.pos,!0,52,8),this.pos+=8},writeBytes:function(t){var e=t.length;this.writeVarint(e),this.realloc(e);for(var r=0;r<e;r++)this.buf[this.pos++]=t[r]},writeRawMessage:function(t,e){this.pos++;var r=this.pos;t(e,this);var n=this.pos-r;n>=128&&nl(r,n,this),this.pos=r-1,this.writeVarint(n),this.pos+=n},writeMessage:function(t,e,r){this.writeTag(t,tl.Bytes),this.writeRawMessage(e,r)},writePackedVarint:function(t,e){e.length&&this.writeMessage(t,il,e)},writePackedSVarint:function(t,e){e.length&&this.writeMessage(t,al,e)},writePackedBoolean:function(t,e){e.length&&this.writeMessage(t,ll,e)},writePackedFloat:function(t,e){e.length&&this.writeMessage(t,ol,e)},writePackedDouble:function(t,e){e.length&&this.writeMessage(t,sl,e)},writePackedFixed32:function(t,e){e.length&&this.writeMessage(t,cl,e)},writePackedSFixed32:function(t,e){e.length&&this.writeMessage(t,ul,e)},writePackedFixed64:function(t,e){e.length&&this.writeMessage(t,hl,e)},writePackedSFixed64:function(t,e){e.length&&this.writeMessage(t,fl,e)},writeBytesField:function(t,e){this.writeTag(t,tl.Bytes),this.writeBytes(e)},writeFixed32Field:function(t,e){this.writeTag(t,tl.Fixed32),this.writeFixed32(e)},writeSFixed32Field:function(t,e){this.writeTag(t,tl.Fixed32),this.writeSFixed32(e)},writeFixed64Field:function(t,e){this.writeTag(t,tl.Fixed64),this.writeFixed64(e)},writeSFixed64Field:function(t,e){this.writeTag(t,tl.Fixed64),this.writeSFixed64(e)},writeVarintField:function(t,e){this.writeTag(t,tl.Varint),this.writeVarint(e)},writeSVarintField:function(t,e){this.writeTag(t,tl.Varint),this.writeSVarint(e)},writeStringField:function(t,e){this.writeTag(t,tl.Bytes),this.writeString(e)},writeFloatField:function(t,e){this.writeTag(t,tl.Fixed32),this.writeFloat(e)},writeDoubleField:function(t,e){this.writeTag(t,tl.Fixed64),this.writeDouble(e)},writeBooleanField:function(t,e){this.writeVarintField(t,Boolean(e))}};var vl=3;function ml(t,e,r){1===t&&r.readMessage(yl,e)}function yl(t,e,r){if(3===t){var n=r.readMessage(xl,{}),i=n.id,a=n.bitmap,o=n.width,s=n.height,l=n.left,c=n.top,u=n.advance;e.push({id:i,bitmap:new qa({width:o+2*vl,height:s+2*vl},a),metrics:{width:o,height:s,left:l,top:c,advance:u}})}}function xl(t,e,r){1===t?e.id=r.readVarint():2===t?e.bitmap=r.readBytes():3===t?e.width=r.readVarint():4===t?e.height=r.readVarint():5===t?e.left=r.readSVarint():6===t?e.top=r.readSVarint():7===t&&(e.advance=r.readVarint())}var bl=vl,_l=function(t,e,r){this.target=t,this.parent=e,this.mapId=r,this.callbacks={},this.callbackID=0,v([\"receive\"],this),this.target.addEventListener(\"message\",this.receive,!1)};function wl(t,e,r){var n=2*Math.PI*6378137/256/Math.pow(2,r);return[t*n-2*Math.PI*6378137/2,e*n-2*Math.PI*6378137/2]}_l.prototype.send=function(t,e,r,n){var i=this,a=r?this.mapId+\":\"+this.callbackID++:null;r&&(this.callbacks[a]=r);var o=[];if(this.target.postMessage({targetMapId:n,sourceMapId:this.mapId,type:t,id:String(a),data:An(e,o)},o),r)return{cancel:function(){i.callbacks[a]=null,i.target.postMessage({targetMapId:n,sourceMapId:i.mapId,type:\"<cancel>\",id:String(a)})}}},_l.prototype.receive=function(t){var e,r=this,n=t.data,i=n.id;if(!n.targetMapId||this.mapId===n.targetMapId){var a=function(t,e){delete r.callbacks[i];var n=[];r.target.postMessage({sourceMapId:r.mapId,type:\"<response>\",id:String(i),error:t?An(t):null,data:An(e,n)},n)};if(\"<response>\"===n.type||\"<cancel>\"===n.type)e=this.callbacks[n.id],delete this.callbacks[n.id],e&&n.error?e(Mn(n.error)):e&&e(null,Mn(n.data));else if(void 0!==n.id&&this.parent[n.type]){this.callbacks[n.id]=null;var o=this.parent[n.type](n.sourceMapId,Mn(n.data),a);o&&null===this.callbacks[n.id]&&(this.callbacks[n.id]=o.cancel)}else if(void 0!==n.id&&this.parent.getWorkerSource){var s=n.type.split(\".\"),l=Mn(n.data);this.parent.getWorkerSource(n.sourceMapId,s[0],l.source)[s[1]](l,a)}else this.parent[n.type](Mn(n.data))}},_l.prototype.remove=function(){this.target.removeEventListener(\"message\",this.receive,!1)};var kl=function(t,e){t&&(e?this.setSouthWest(t).setNorthEast(e):4===t.length?this.setSouthWest([t[0],t[1]]).setNorthEast([t[2],t[3]]):this.setSouthWest(t[0]).setNorthEast(t[1]))};kl.prototype.setNorthEast=function(t){return this._ne=t instanceof Tl?new Tl(t.lng,t.lat):Tl.convert(t),this},kl.prototype.setSouthWest=function(t){return this._sw=t instanceof Tl?new Tl(t.lng,t.lat):Tl.convert(t),this},kl.prototype.extend=function(t){var e,r,n=this._sw,i=this._ne;if(t instanceof Tl)e=t,r=t;else{if(!(t instanceof kl))return Array.isArray(t)?t.every(Array.isArray)?this.extend(kl.convert(t)):this.extend(Tl.convert(t)):this;if(e=t._sw,r=t._ne,!e||!r)return this}return n||i?(n.lng=Math.min(e.lng,n.lng),n.lat=Math.min(e.lat,n.lat),i.lng=Math.max(r.lng,i.lng),i.lat=Math.max(r.lat,i.lat)):(this._sw=new Tl(e.lng,e.lat),this._ne=new Tl(r.lng,r.lat)),this},kl.prototype.getCenter=function(){return new Tl((this._sw.lng+this._ne.lng)/2,(this._sw.lat+this._ne.lat)/2)},kl.prototype.getSouthWest=function(){return this._sw},kl.prototype.getNorthEast=function(){return this._ne},kl.prototype.getNorthWest=function(){return new Tl(this.getWest(),this.getNorth())},kl.prototype.getSouthEast=function(){return new Tl(this.getEast(),this.getSouth())},kl.prototype.getWest=function(){return this._sw.lng},kl.prototype.getSouth=function(){return this._sw.lat},kl.prototype.getEast=function(){return this._ne.lng},kl.prototype.getNorth=function(){return this._ne.lat},kl.prototype.toArray=function(){return[this._sw.toArray(),this._ne.toArray()]},kl.prototype.toString=function(){return\"LngLatBounds(\"+this._sw.toString()+\", \"+this._ne.toString()+\")\"},kl.prototype.isEmpty=function(){return!(this._sw&&this._ne)},kl.convert=function(t){return!t||t instanceof kl?t:new kl(t)};var Tl=function(t,e){if(isNaN(t)||isNaN(e))throw new Error(\"Invalid LngLat object: (\"+t+\", \"+e+\")\");if(this.lng=+t,this.lat=+e,this.lat>90||this.lat<-90)throw new Error(\"Invalid LngLat latitude value: must be between -90 and 90\")};function Al(t){return 2*Math.PI*6378137*Math.cos(t*Math.PI/180)}function Ml(t){return(180+t)/360}function Sl(t){return(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+t*Math.PI/360)))/360}function El(t,e){return t/Al(e)}function Cl(t){var e=180-360*t;return 360/Math.PI*Math.atan(Math.exp(e*Math.PI/180))-90}Tl.prototype.wrap=function(){return new Tl(u(this.lng,-180,180),this.lat)},Tl.prototype.toArray=function(){return[this.lng,this.lat]},Tl.prototype.toString=function(){return\"LngLat(\"+this.lng+\", \"+this.lat+\")\"},Tl.prototype.toBounds=function(t){void 0===t&&(t=0);var e=360*t/40075017,r=e/Math.cos(Math.PI/180*this.lat);return new kl(new Tl(this.lng-r,this.lat-e),new Tl(this.lng+r,this.lat+e))},Tl.convert=function(t){if(t instanceof Tl)return t;if(Array.isArray(t)&&(2===t.length||3===t.length))return new Tl(Number(t[0]),Number(t[1]));if(!Array.isArray(t)&&\"object\"==typeof t&&null!==t)return new Tl(Number(\"lng\"in t?t.lng:t.lon),Number(t.lat));throw new Error(\"`LngLatLike` argument must be specified as a LngLat instance, an object {lng: <lng>, lat: <lat>}, an object {lon: <lng>, lat: <lat>}, or an array of [<lng>, <lat>]\")};var Ll=function(t,e,r){void 0===r&&(r=0),this.x=+t,this.y=+e,this.z=+r};Ll.fromLngLat=function(t,e){void 0===e&&(e=0);var r=Tl.convert(t);return new Ll(Ml(r.lng),Sl(r.lat),El(e,r.lat))},Ll.prototype.toLngLat=function(){return new Tl(360*this.x-180,Cl(this.y))},Ll.prototype.toAltitude=function(){return this.z*Al(Cl(this.y))};var Pl=function(t,e,r){this.z=t,this.x=e,this.y=r,this.key=Il(0,t,e,r)};Pl.prototype.equals=function(t){return this.z===t.z&&this.x===t.x&&this.y===t.y},Pl.prototype.url=function(t,e){var r,n,i,a,o,s=(r=this.x,n=this.y,i=this.z,a=wl(256*r,256*(n=Math.pow(2,i)-n-1),i),o=wl(256*(r+1),256*(n+1),i),a[0]+\",\"+a[1]+\",\"+o[0]+\",\"+o[1]),l=function(t,e,r){for(var n,i=\"\",a=t;a>0;a--)i+=(e&(n=1<<a-1)?1:0)+(r&n?2:0);return i}(this.z,this.x,this.y);return t[(this.x+this.y)%t.length].replace(\"{prefix}\",(this.x%16).toString(16)+(this.y%16).toString(16)).replace(\"{z}\",String(this.z)).replace(\"{x}\",String(this.x)).replace(\"{y}\",String(\"tms\"===e?Math.pow(2,this.z)-this.y-1:this.y)).replace(\"{quadkey}\",l).replace(\"{bbox-epsg-3857}\",s)},Pl.prototype.getTilePoint=function(t){var e=Math.pow(2,this.z);return new i((t.x*e-this.x)*ha,(t.y*e-this.y)*ha)};var Ol=function(t,e){this.wrap=t,this.canonical=e,this.key=Il(t,e.z,e.x,e.y)},zl=function(t,e,r,n,i){this.overscaledZ=t,this.wrap=e,this.canonical=new Pl(r,+n,+i),this.key=Il(e,t,n,i)};function Il(t,e,r,n){(t*=2)<0&&(t=-1*t-1);var i=1<<e;return 32*(i*i*t+i*n+r)+e}zl.prototype.equals=function(t){return this.overscaledZ===t.overscaledZ&&this.wrap===t.wrap&&this.canonical.equals(t.canonical)},zl.prototype.scaledTo=function(t){var e=this.canonical.z-t;return t>this.canonical.z?new zl(t,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y):new zl(t,this.wrap,t,this.canonical.x>>e,this.canonical.y>>e)},zl.prototype.isChildOf=function(t){if(t.wrap!==this.wrap)return!1;var e=this.canonical.z-t.canonical.z;return 0===t.overscaledZ||t.overscaledZ<this.overscaledZ&&t.canonical.x===this.canonical.x>>e&&t.canonical.y===this.canonical.y>>e},zl.prototype.children=function(t){if(this.overscaledZ>=t)return[new zl(this.overscaledZ+1,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y)];var e=this.canonical.z+1,r=2*this.canonical.x,n=2*this.canonical.y;return[new zl(e,this.wrap,e,r,n),new zl(e,this.wrap,e,r+1,n),new zl(e,this.wrap,e,r,n+1),new zl(e,this.wrap,e,r+1,n+1)]},zl.prototype.isLessThan=function(t){return this.wrap<t.wrap||!(this.wrap>t.wrap)&&(this.overscaledZ<t.overscaledZ||!(this.overscaledZ>t.overscaledZ)&&(this.canonical.x<t.canonical.x||!(this.canonical.x>t.canonical.x)&&this.canonical.y<t.canonical.y))},zl.prototype.wrapped=function(){return new zl(this.overscaledZ,0,this.canonical.z,this.canonical.x,this.canonical.y)},zl.prototype.unwrapTo=function(t){return new zl(this.overscaledZ,t,this.canonical.z,this.canonical.x,this.canonical.y)},zl.prototype.overscaleFactor=function(){return Math.pow(2,this.overscaledZ-this.canonical.z)},zl.prototype.toUnwrapped=function(){return new Ol(this.wrap,this.canonical)},zl.prototype.toString=function(){return this.overscaledZ+\"/\"+this.canonical.x+\"/\"+this.canonical.y},zl.prototype.getTilePoint=function(t){return this.canonical.getTilePoint(new Ll(t.x-this.wrap,t.y))},kn(\"CanonicalTileID\",Pl),kn(\"OverscaledTileID\",zl,{omit:[\"posMatrix\"]});var Dl=function(t,e,r){if(this.uid=t,e.height!==e.width)throw new RangeError(\"DEM tiles must be square\");if(r&&\"mapbox\"!==r&&\"terrarium\"!==r)return w('\"'+r+'\" is not a valid encoding type. Valid types include \"mapbox\" and \"terrarium\".');var n=this.dim=e.height;this.stride=this.dim+2,this.data=new Int32Array(this.stride*this.stride);for(var i=e.data,a=\"terrarium\"===r?this._unpackTerrarium:this._unpackMapbox,o=0;o<n;o++)for(var s=0;s<n;s++){var l=4*(o*n+s);this.set(s,o,a(i[l],i[l+1],i[l+2]))}for(var c=0;c<n;c++)this.set(-1,c,this.get(0,c)),this.set(n,c,this.get(n-1,c)),this.set(c,-1,this.get(c,0)),this.set(c,n,this.get(c,n-1));this.set(-1,-1,this.get(0,0)),this.set(n,-1,this.get(n-1,0)),this.set(-1,n,this.get(0,n-1)),this.set(n,n,this.get(n-1,n-1))};Dl.prototype.set=function(t,e,r){this.data[this._idx(t,e)]=r+65536},Dl.prototype.get=function(t,e){return this.data[this._idx(t,e)]-65536},Dl.prototype._idx=function(t,e){if(t<-1||t>=this.dim+1||e<-1||e>=this.dim+1)throw new RangeError(\"out of range source coordinates for DEM data\");return(e+1)*this.stride+(t+1)},Dl.prototype._unpackMapbox=function(t,e,r){return(256*t*256+256*e+r)/10-1e4},Dl.prototype._unpackTerrarium=function(t,e,r){return 256*t+e+r/256-32768},Dl.prototype.getPixels=function(){return new Ha({width:this.stride,height:this.stride},new Uint8Array(this.data.buffer))},Dl.prototype.backfillBorder=function(t,e,r){if(this.dim!==t.dim)throw new Error(\"dem dimension mismatch\");var n=e*this.dim,i=e*this.dim+this.dim,a=r*this.dim,o=r*this.dim+this.dim;switch(e){case-1:n=i-1;break;case 1:i=n+1}switch(r){case-1:a=o-1;break;case 1:o=a+1}for(var s=-e*this.dim,l=-r*this.dim,c=a;c<o;c++)for(var u=n;u<i;u++)this.set(u,c,t.get(u+s,c+l))},kn(\"DEMData\",Dl);var Rl=oi([{name:\"a_pos\",type:\"Int16\",components:2},{name:\"a_texture_pos\",type:\"Int16\",components:2}]),Fl=function(t){this._stringToNumber={},this._numberToString=[];for(var e=0;e<t.length;e++){var r=t[e];this._stringToNumber[r]=e,this._numberToString[e]=r}};Fl.prototype.encode=function(t){return this._stringToNumber[t]},Fl.prototype.decode=function(t){return this._numberToString[t]};var Bl=function(t,e,r,n){this.type=\"Feature\",this._vectorTileFeature=t,t._z=e,t._x=r,t._y=n,this.properties=t.properties,null!=t.id&&(this.id=t.id)},Nl={geometry:{configurable:!0}};Nl.geometry.get=function(){return void 0===this._geometry&&(this._geometry=this._vectorTileFeature.toGeoJSON(this._vectorTileFeature._x,this._vectorTileFeature._y,this._vectorTileFeature._z).geometry),this._geometry},Nl.geometry.set=function(t){this._geometry=t},Bl.prototype.toJSON=function(){var t={geometry:this.geometry};for(var e in this)\"_geometry\"!==e&&\"_vectorTileFeature\"!==e&&(t[e]=this[e]);return t},Object.defineProperties(Bl.prototype,Nl);var jl=function(){this.state={},this.stateChanges={},this.deletedStates={}};jl.prototype.updateState=function(t,e,r){var n=String(e);if(this.stateChanges[t]=this.stateChanges[t]||{},this.stateChanges[t][n]=this.stateChanges[t][n]||{},h(this.stateChanges[t][n],r),null===this.deletedStates[t])for(var i in this.deletedStates[t]={},this.state[t])i!==n&&(this.deletedStates[t][i]=null);else if(this.deletedStates[t]&&null===this.deletedStates[t][n])for(var a in this.deletedStates[t][n]={},this.state[t][n])r[a]||(this.deletedStates[t][n][a]=null);else for(var o in r)this.deletedStates[t]&&this.deletedStates[t][n]&&null===this.deletedStates[t][n][o]&&delete this.deletedStates[t][n][o]},jl.prototype.removeFeatureState=function(t,e,r){if(null!==this.deletedStates[t]){var n=String(e);if(this.deletedStates[t]=this.deletedStates[t]||{},r&&void 0!==e&&e>=0)null!==this.deletedStates[t][n]&&(this.deletedStates[t][n]=this.deletedStates[t][n]||{},this.deletedStates[t][n][r]=null);else if(void 0!==e&&e>=0)if(this.stateChanges[t]&&this.stateChanges[t][n])for(r in this.deletedStates[t][n]={},this.stateChanges[t][n])this.deletedStates[t][n][r]=null;else this.deletedStates[t][n]=null;else this.deletedStates[t]=null}},jl.prototype.getState=function(t,e){var r=String(e),n=this.state[t]||{},i=this.stateChanges[t]||{},a=h({},n[r],i[r]);if(null===this.deletedStates[t])return{};if(this.deletedStates[t]){var o=this.deletedStates[t][e];if(null===o)return{};for(var s in o)delete a[s]}return a},jl.prototype.initializeTileState=function(t,e){t.setFeatureState(this.state,e)},jl.prototype.coalesceChanges=function(t,e){var r={};for(var n in this.stateChanges){this.state[n]=this.state[n]||{};var i={};for(var a in this.stateChanges[n])this.state[n][a]||(this.state[n][a]={}),h(this.state[n][a],this.stateChanges[n][a]),i[a]=this.state[n][a];r[n]=i}for(var o in this.deletedStates){this.state[o]=this.state[o]||{};var s={};if(null===this.deletedStates[o])for(var l in this.state[o])s[l]={},this.state[o][l]={};else for(var c in this.deletedStates[o]){if(null===this.deletedStates[o][c])this.state[o][c]={};else for(var u=0,f=Object.keys(this.deletedStates[o][c]);u<f.length;u+=1){var p=f[u];delete this.state[o][c][p]}s[c]=this.state[o][c]}r[o]=r[o]||{},h(r[o],s)}if(this.stateChanges={},this.deletedStates={},0!==Object.keys(r).length)for(var d in t)t[d].setFeatureState(r,e)};var Ul=function(t,e,r){this.tileID=t,this.x=t.canonical.x,this.y=t.canonical.y,this.z=t.canonical.z,this.grid=e||new yn(ha,16,0),this.grid3D=new yn(ha,16,0),this.featureIndexArray=r||new ji};function Vl(t){for(var e=1/0,r=1/0,n=-1/0,i=-1/0,a=0,o=t;a<o.length;a+=1){var s=o[a];e=Math.min(e,s.x),r=Math.min(r,s.y),n=Math.max(n,s.x),i=Math.max(i,s.y)}return{minX:e,minY:r,maxX:n,maxY:i}}function ql(t,e){return e-t}Ul.prototype.insert=function(t,e,r,n,i,a){var o=this.featureIndexArray.length;this.featureIndexArray.emplaceBack(r,n,i);for(var s=a?this.grid3D:this.grid,l=0;l<e.length;l++){for(var c=e[l],u=[1/0,1/0,-1/0,-1/0],h=0;h<c.length;h++){var f=c[h];u[0]=Math.min(u[0],f.x),u[1]=Math.min(u[1],f.y),u[2]=Math.max(u[2],f.x),u[3]=Math.max(u[3],f.y)}u[0]<ha&&u[1]<ha&&u[2]>=0&&u[3]>=0&&s.insert(o,u[0],u[1],u[2],u[3])}},Ul.prototype.loadVTLayers=function(){return this.vtLayers||(this.vtLayers=new Vo.VectorTile(new Qs(this.rawTileData)).layers,this.sourceLayerCoder=new Fl(this.vtLayers?Object.keys(this.vtLayers).sort():[\"_geojsonTileLayer\"])),this.vtLayers},Ul.prototype.query=function(t,e,r){var n=this;this.loadVTLayers();for(var a=t.params||{},o=ha/t.tileSize/t.scale,s=Gr(a.filter),l=t.queryGeometry,c=t.queryPadding*o,u=Vl(l),h=this.grid.query(u.minX-c,u.minY-c,u.maxX+c,u.maxY+c),f=Vl(t.cameraQueryGeometry),p=0,d=this.grid3D.query(f.minX-c,f.minY-c,f.maxX+c,f.maxY+c,function(e,r,n,a){return function(t,e,r,n,a){for(var o=0,s=t;o<s.length;o+=1){var l=s[o];if(e<=l.x&&r<=l.y&&n>=l.x&&a>=l.y)return!0}var c=[new i(e,r),new i(e,a),new i(n,a),new i(n,r)];if(t.length>2)for(var u=0,h=c;u<h.length;u+=1)if(Aa(t,h[u]))return!0;for(var f=0;f<t.length-1;f++)if(Ma(t[f],t[f+1],c))return!0;return!1}(t.cameraQueryGeometry,e-c,r-c,n+c,a+c)});p<d.length;p+=1){var g=d[p];h.push(g)}h.sort(ql);for(var v,m={},y=function(i){var c=h[i];if(c!==v){v=c;var u=n.featureIndexArray.get(c),f=null;n.loadMatchingFeature(m,u.bucketIndex,u.sourceLayerIndex,u.featureIndex,s,a.layers,e,function(e,i){f||(f=pa(e));var a={};return e.id&&(a=r.getState(i.sourceLayer||\"_geojsonTileLayer\",e.id)),i.queryIntersectsFeature(l,e,a,f,n.z,t.transform,o,t.pixelPosMatrix)})}},x=0;x<h.length;x++)y(x);return m},Ul.prototype.loadMatchingFeature=function(t,e,r,n,i,a,o,s){var l=this.bucketLayerIDs[e];if(!a||function(t,e){for(var r=0;r<t.length;r++)if(e.indexOf(t[r])>=0)return!0;return!1}(a,l)){var c=this.sourceLayerCoder.decode(r),u=this.vtLayers[c].feature(n);if(i(new Un(this.tileID.overscaledZ),u))for(var h=0;h<l.length;h++){var f=l[h];if(!(a&&a.indexOf(f)<0)){var p=o[f];if(p){var d=!s||s(u,p);if(d){var g=new Bl(u,this.z,this.x,this.y);g.layer=p.serialize();var v=t[f];void 0===v&&(v=t[f]=[]),v.push({featureIndex:n,feature:g,intersectionZ:d})}}}}}},Ul.prototype.lookupSymbolFeatures=function(t,e,r,n,i,a){var o={};this.loadVTLayers();for(var s=Gr(n),l=0,c=t;l<c.length;l+=1){var u=c[l];this.loadMatchingFeature(o,e,r,u,s,i,a)}return o},Ul.prototype.hasLayer=function(t){for(var e=0,r=this.bucketLayerIDs;e<r.length;e+=1)for(var n=0,i=r[e];n<i.length;n+=1)if(t===i[n])return!0;return!1},kn(\"FeatureIndex\",Ul,{omit:[\"rawTileData\",\"sourceLayerCoder\"]});var Hl=function(t,e){this.tileID=t,this.uid=p(),this.uses=0,this.tileSize=e,this.buckets={},this.expirationTime=null,this.queryPadding=0,this.hasSymbolBuckets=!1,this.expiredRequestCount=0,this.state=\"loading\"};Hl.prototype.registerFadeDuration=function(t){var e=t+this.timeAdded;e<z.now()||this.fadeEndTime&&e<this.fadeEndTime||(this.fadeEndTime=e)},Hl.prototype.wasRequested=function(){return\"errored\"===this.state||\"loaded\"===this.state||\"reloading\"===this.state},Hl.prototype.loadVectorData=function(t,e,r){if(this.hasData()&&this.unloadVectorData(),this.state=\"loaded\",t){for(var n in t.featureIndex&&(this.latestFeatureIndex=t.featureIndex,t.rawTileData?(this.latestRawTileData=t.rawTileData,this.latestFeatureIndex.rawTileData=t.rawTileData):this.latestRawTileData&&(this.latestFeatureIndex.rawTileData=this.latestRawTileData)),this.collisionBoxArray=t.collisionBoxArray,this.buckets=function(t,e){var r={};if(!e)return r;for(var n=function(){var t=a[i],n=t.layerIds.map(function(t){return e.getLayer(t)}).filter(Boolean);if(0!==n.length){t.layers=n,t.stateDependentLayerIds&&(t.stateDependentLayers=t.stateDependentLayerIds.map(function(t){return n.filter(function(e){return e.id===t})[0]}));for(var o=0,s=n;o<s.length;o+=1){var l=s[o];r[l.id]=t}}},i=0,a=t;i<a.length;i+=1)n();return r}(t.buckets,e.style),this.hasSymbolBuckets=!1,this.buckets){var i=this.buckets[n];if(i instanceof Os){if(this.hasSymbolBuckets=!0,!r)break;i.justReloaded=!0}}for(var a in this.queryPadding=0,this.buckets){var o=this.buckets[a];this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(a).queryRadius(o))}t.imageAtlas&&(this.imageAtlas=t.imageAtlas),t.glyphAtlasImage&&(this.glyphAtlasImage=t.glyphAtlasImage)}else this.collisionBoxArray=new Li},Hl.prototype.unloadVectorData=function(){for(var t in this.buckets)this.buckets[t].destroy();this.buckets={},this.imageAtlasTexture&&this.imageAtlasTexture.destroy(),this.imageAtlas&&(this.imageAtlas=null),this.glyphAtlasTexture&&this.glyphAtlasTexture.destroy(),this.latestFeatureIndex=null,this.state=\"unloaded\"},Hl.prototype.unloadDEMData=function(){this.dem=null,this.neighboringTiles=null,this.state=\"unloaded\"},Hl.prototype.getBucket=function(t){return this.buckets[t.id]},Hl.prototype.upload=function(t){for(var e in this.buckets){var r=this.buckets[e];r.uploadPending()&&r.upload(t)}var n=t.gl;this.imageAtlas&&!this.imageAtlas.uploaded&&(this.imageAtlasTexture=new Js(t,this.imageAtlas.image,n.RGBA),this.imageAtlas.uploaded=!0),this.glyphAtlasImage&&(this.glyphAtlasTexture=new Js(t,this.glyphAtlasImage,n.ALPHA),this.glyphAtlasImage=null)},Hl.prototype.prepare=function(t){this.imageAtlas&&this.imageAtlas.patchUpdatedImages(t,this.imageAtlasTexture)},Hl.prototype.queryRenderedFeatures=function(t,e,r,n,i,a,o,s,l){return this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData?this.latestFeatureIndex.query({queryGeometry:r,cameraQueryGeometry:n,scale:i,tileSize:this.tileSize,pixelPosMatrix:l,transform:o,params:a,queryPadding:this.queryPadding*s},t,e):{}},Hl.prototype.querySourceFeatures=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData){var r=this.latestFeatureIndex.loadVTLayers(),n=e?e.sourceLayer:\"\",i=r._geojsonTileLayer||r[n];if(i)for(var a=Gr(e&&e.filter),o=this.tileID.canonical,s=o.z,l=o.x,c=o.y,u={z:s,x:l,y:c},h=0;h<i.length;h++){var f=i.feature(h);if(a(new Un(this.tileID.overscaledZ),f)){var p=new Bl(f,s,l,c);p.tile=u,t.push(p)}}}},Hl.prototype.clearMask=function(){this.segments&&(this.segments.destroy(),delete this.segments),this.maskedBoundsBuffer&&(this.maskedBoundsBuffer.destroy(),delete this.maskedBoundsBuffer),this.maskedIndexBuffer&&(this.maskedIndexBuffer.destroy(),delete this.maskedIndexBuffer)},Hl.prototype.setMask=function(t,e){if(!o(this.mask,t)&&(this.mask=t,this.clearMask(),!o(t,{0:!0}))){var r=new ci,n=new Ti;this.segments=new Vi,this.segments.prepareSegment(0,r,n);for(var a=Object.keys(t),s=0;s<a.length;s++){var l=t[+a[s]],c=ha>>l.z,u=new i(l.x*c,l.y*c),h=new i(u.x+c,u.y+c),f=this.segments.prepareSegment(4,r,n);r.emplaceBack(u.x,u.y,u.x,u.y),r.emplaceBack(h.x,u.y,h.x,u.y),r.emplaceBack(u.x,h.y,u.x,h.y),r.emplaceBack(h.x,h.y,h.x,h.y);var p=f.vertexLength;n.emplaceBack(p,p+1,p+2),n.emplaceBack(p+1,p+2,p+3),f.vertexLength+=4,f.primitiveLength+=2}this.maskedBoundsBuffer=e.createVertexBuffer(r,Rl.members),this.maskedIndexBuffer=e.createIndexBuffer(n)}},Hl.prototype.hasData=function(){return\"loaded\"===this.state||\"reloading\"===this.state||\"expired\"===this.state},Hl.prototype.patternsLoaded=function(){return this.imageAtlas&&!!Object.keys(this.imageAtlas.patternPositions).length},Hl.prototype.setExpiryData=function(t){var e=this.expirationTime;if(t.cacheControl){var r=A(t.cacheControl);r[\"max-age\"]&&(this.expirationTime=Date.now()+1e3*r[\"max-age\"])}else t.expires&&(this.expirationTime=new Date(t.expires).getTime());if(this.expirationTime){var n=Date.now(),i=!1;if(this.expirationTime>n)i=!1;else if(e)if(this.expirationTime<e)i=!0;else{var a=this.expirationTime-e;a?this.expirationTime=n+Math.max(a,3e4):i=!0}else i=!0;i?(this.expiredRequestCount++,this.state=\"expired\"):this.expiredRequestCount=0}},Hl.prototype.getExpiryTimeout=function(){if(this.expirationTime)return this.expiredRequestCount?1e3*(1<<Math.min(this.expiredRequestCount-1,31)):Math.min(this.expirationTime-(new Date).getTime(),Math.pow(2,31)-1)},Hl.prototype.setFeatureState=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData&&0!==Object.keys(t).length){var r=this.latestFeatureIndex.loadVTLayers();for(var n in this.buckets){var i=this.buckets[n],a=i.layers[0].sourceLayer||\"_geojsonTileLayer\",o=r[a],s=t[a];o&&s&&0!==Object.keys(s).length&&(i.update(s,o,this.imageAtlas&&this.imageAtlas.patternPositions||{}),e&&e.style&&(this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(n).queryRadius(i))))}}},Hl.prototype.holdingForFade=function(){return void 0!==this.symbolFadeHoldUntil},Hl.prototype.symbolFadeFinished=function(){return!this.symbolFadeHoldUntil||this.symbolFadeHoldUntil<z.now()},Hl.prototype.clearFadeHold=function(){this.symbolFadeHoldUntil=void 0},Hl.prototype.setHoldDuration=function(t){this.symbolFadeHoldUntil=z.now()+t};var Gl=24,Yl={horizontal:1,vertical:2,horizontalOnly:3},Wl=function(){this.text=\"\",this.sectionIndex=[],this.sections=[]};function Xl(t,e,r,n,i,a,o,s,l,c){var u,h=Wl.fromFeature(t,r);c===Yl.vertical&&h.verticalizePunctuation();var f=jn.processBidirectionalText,p=jn.processStyledBidirectionalText;if(f&&1===h.sections.length){u=[];for(var d=0,g=f(h.toString(),tc(h,s,n,e));d<g.length;d+=1){var v=g[d],m=new Wl;m.text=v,m.sections=h.sections;for(var y=0;y<v.length;y++)m.sectionIndex.push(0);u.push(m)}}else if(p){u=[];for(var x=0,b=p(h.text,h.sectionIndex,tc(h,s,n,e));x<b.length;x+=1){var _=b[x],w=new Wl;w.text=_[0],w.sectionIndex=_[1],w.sections=h.sections,u.push(w)}}else u=function(t,e){for(var r=[],n=t.text,i=0,a=0,o=e;a<o.length;a+=1){var s=o[a];r.push(t.substring(i,s)),i=s}return i<n.length&&r.push(t.substring(i,n.length)),r}(h,tc(h,s,n,e));var k=[],T={positionedGlyphs:k,text:h.toString(),top:l[1],bottom:l[1],left:l[0],right:l[0],writingMode:c,lineCount:u.length};return function(t,e,r,n,i,a,o,s){for(var l=0,c=-17,u=0,h=t.positionedGlyphs,f=\"right\"===a?1:\"left\"===a?0:.5,p=0,d=r;p<d.length;p+=1){var g=d[p];g.trim();var v=g.getMaxScale();if(g.length()){for(var m=h.length,y=0;y<g.length();y++){var x=g.getSection(y),b=g.getCharCode(y),_=24*(v-x.scale),w=e[x.fontStack],k=w&&w[b];k&&(On(b)&&o!==Yl.horizontal?(h.push({glyph:b,x:l,y:_,vertical:!0,scale:x.scale,fontStack:x.fontStack}),l+=Gl*x.scale+s):(h.push({glyph:b,x:l,y:c+_,vertical:!1,scale:x.scale,fontStack:x.fontStack}),l+=k.metrics.advance*x.scale+s))}if(h.length!==m){var T=l-s;u=Math.max(T,u),rc(h,e,m,h.length-1,f)}l=0,c+=n*v}else c+=n}var A=ec(i),M=A.horizontalAlign,S=A.verticalAlign;!function(t,e,r,n,i,a,o){for(var s=(e-r)*i,l=(-n*o+.5)*a,c=0;c<t.length;c++)t[c].x+=s,t[c].y+=l}(h,f,M,S,u,n,r.length);var E=c- -17;t.top+=-S*E,t.bottom=t.top+E,t.left+=-M*u,t.right=t.left+u}(T,e,u,i,a,o,c,s),!!k.length&&T}Wl.fromFeature=function(t,e){for(var r=new Wl,n=0;n<t.sections.length;n++){var i=t.sections[n];r.sections.push({scale:i.scale||1,fontStack:i.fontStack||e}),r.text+=i.text;for(var a=0;a<i.text.length;a++)r.sectionIndex.push(n)}return r},Wl.prototype.length=function(){return this.text.length},Wl.prototype.getSection=function(t){return this.sections[this.sectionIndex[t]]},Wl.prototype.getCharCode=function(t){return this.text.charCodeAt(t)},Wl.prototype.verticalizePunctuation=function(){this.text=function(t){for(var e=\"\",r=0;r<t.length;r++){var n=t.charCodeAt(r+1)||null,i=t.charCodeAt(r-1)||null;n&&zn(n)&&!xs[t[r+1]]||i&&zn(i)&&!xs[t[r-1]]||!xs[t[r]]?e+=t[r]:e+=xs[t[r]]}return e}(this.text)},Wl.prototype.trim=function(){for(var t=0,e=0;e<this.text.length&&Zl[this.text.charCodeAt(e)];e++)t++;for(var r=this.text.length,n=this.text.length-1;n>=0&&n>=t&&Zl[this.text.charCodeAt(n)];n--)r--;this.text=this.text.substring(t,r),this.sectionIndex=this.sectionIndex.slice(t,r)},Wl.prototype.substring=function(t,e){var r=new Wl;return r.text=this.text.substring(t,e),r.sectionIndex=this.sectionIndex.slice(t,e),r.sections=this.sections,r},Wl.prototype.toString=function(){return this.text},Wl.prototype.getMaxScale=function(){var t=this;return this.sectionIndex.reduce(function(e,r){return Math.max(e,t.sections[r].scale)},0)};var Zl={9:!0,10:!0,11:!0,12:!0,13:!0,32:!0},Jl={};function Kl(t,e,r,n){var i=Math.pow(t-e,2);return n?t<e?i/2:2*i:i+Math.abs(r)*r}function $l(t,e,r){var n=0;return 10===t&&(n-=1e4),r&&(n+=150),40!==t&&65288!==t||(n+=50),41!==e&&65289!==e||(n+=50),n}function Ql(t,e,r,n,i,a){for(var o=null,s=Kl(e,r,i,a),l=0,c=n;l<c.length;l+=1){var u=c[l],h=Kl(e-u.x,r,i,a)+u.badness;h<=s&&(o=u,s=h)}return{index:t,x:e,priorBreak:o,badness:s}}function tc(t,e,r,n){if(!r)return[];if(!t)return[];for(var i,a=[],o=function(t,e,r,n){for(var i=0,a=0;a<t.length();a++){var o=t.getSection(a),s=n[o.fontStack],l=s&&s[t.getCharCode(a)];l&&(i+=l.metrics.advance*o.scale+e)}return i/Math.max(1,Math.ceil(i/r))}(t,e,r,n),s=t.text.indexOf(\"\\u200b\")>=0,l=0,c=0;c<t.length();c++){var u=t.getSection(c),h=t.getCharCode(c),f=n[u.fontStack],p=f&&f[h];if(p&&!Zl[h]&&(l+=p.metrics.advance*u.scale+e),c<t.length()-1){var d=!((i=h)<11904||!(En[\"Bopomofo Extended\"](i)||En.Bopomofo(i)||En[\"CJK Compatibility Forms\"](i)||En[\"CJK Compatibility Ideographs\"](i)||En[\"CJK Compatibility\"](i)||En[\"CJK Radicals Supplement\"](i)||En[\"CJK Strokes\"](i)||En[\"CJK Symbols and Punctuation\"](i)||En[\"CJK Unified Ideographs Extension A\"](i)||En[\"CJK Unified Ideographs\"](i)||En[\"Enclosed CJK Letters and Months\"](i)||En[\"Halfwidth and Fullwidth Forms\"](i)||En.Hiragana(i)||En[\"Ideographic Description Characters\"](i)||En[\"Kangxi Radicals\"](i)||En[\"Katakana Phonetic Extensions\"](i)||En.Katakana(i)||En[\"Vertical Forms\"](i)||En[\"Yi Radicals\"](i)||En[\"Yi Syllables\"](i)));(Jl[h]||d)&&a.push(Ql(c+1,l,o,a,$l(h,t.getCharCode(c+1),d&&s),!1))}}return function t(e){return e?t(e.priorBreak).concat(e.index):[]}(Ql(t.length(),l,o,a,0,!0))}function ec(t){var e=.5,r=.5;switch(t){case\"right\":case\"top-right\":case\"bottom-right\":e=1;break;case\"left\":case\"top-left\":case\"bottom-left\":e=0}switch(t){case\"bottom\":case\"bottom-right\":case\"bottom-left\":r=1;break;case\"top\":case\"top-right\":case\"top-left\":r=0}return{horizontalAlign:e,verticalAlign:r}}function rc(t,e,r,n,i){if(i){var a=t[n],o=e[a.fontStack],s=o&&o[a.glyph];if(s)for(var l=s.metrics.advance*a.scale,c=(t[n].x+l)*i,u=r;u<=n;u++)t[u].x-=c}}function nc(t,e,r){var n=ec(r),i=n.horizontalAlign,a=n.verticalAlign,o=e[0],s=e[1],l=o-t.displaySize[0]*i,c=l+t.displaySize[0],u=s-t.displaySize[1]*a;return{image:t,top:u,bottom:u+t.displaySize[1],left:l,right:c}}function ic(t,e,r,n,i){if(void 0===e.segment)return!0;for(var a=e,o=e.segment+1,s=0;s>-r/2;){if(--o<0)return!1;s-=t[o].dist(a),a=t[o]}s+=t[o].dist(t[o+1]),o++;for(var l=[],c=0;s<r/2;){var u=t[o-1],h=t[o],f=t[o+1];if(!f)return!1;var p=u.angleTo(h)-h.angleTo(f);for(p=Math.abs((p+3*Math.PI)%(2*Math.PI)-Math.PI),l.push({distance:s,angleDelta:p}),c+=p;s-l[0].distance>n;)c-=l.shift().angleDelta;if(c>i)return!1;o++,s+=h.dist(f)}return!0}function ac(t){for(var e=0,r=0;r<t.length-1;r++)e+=t[r].dist(t[r+1]);return e}function oc(t,e,r){return t?.6*e*r:0}function sc(t,e){return Math.max(t?t.right-t.left:0,e?e.right-e.left:0)}function lc(t,e,r,n,i,a){for(var o=oc(r,i,a),s=sc(r,n)*a,l=0,c=ac(t)/2,u=0;u<t.length-1;u++){var h=t[u],f=t[u+1],p=h.dist(f);if(l+p>c){var d=(c-l)/p,g=Ee(h.x,f.x,d),v=Ee(h.y,f.y,d),m=new bs(g,v,f.angleTo(h),u);return m._round(),!o||ic(t,m,s,o,e)?m:void 0}l+=p}}function cc(t,e,r,n,i,a,o,s,l){var c=oc(n,a,o),u=sc(n,i),h=u*o,f=0===t[0].x||t[0].x===l||0===t[0].y||t[0].y===l;return e-h<e/4&&(e=h+e/4),function t(e,r,n,i,a,o,s,l,c){for(var u=o/2,h=ac(e),f=0,p=r-n,d=[],g=0;g<e.length-1;g++){for(var v=e[g],m=e[g+1],y=v.dist(m),x=m.angleTo(v);p+n<f+y;){var b=((p+=n)-f)/y,_=Ee(v.x,m.x,b),w=Ee(v.y,m.y,b);if(_>=0&&_<c&&w>=0&&w<c&&p-u>=0&&p+u<=h){var k=new bs(_,w,x,g);k._round(),i&&!ic(e,k,o,i,a)||d.push(k)}}f+=y}return l||d.length||s||(d=t(e,f/2,n,i,a,o,s,!0,c)),d}(t,f?e/2*s%e:(u/2+2*a)*o*s%e,e,c,r,h,f,!1,l)}Jl[10]=!0,Jl[32]=!0,Jl[38]=!0,Jl[40]=!0,Jl[41]=!0,Jl[43]=!0,Jl[45]=!0,Jl[47]=!0,Jl[173]=!0,Jl[183]=!0,Jl[8203]=!0,Jl[8208]=!0,Jl[8211]=!0,Jl[8231]=!0;var uc=function(t,e,r,n,a,o,s,l,c,u,h,f){var p=s.top*l-c,d=s.bottom*l+c,g=s.left*l-c,v=s.right*l+c;if(this.boxStartIndex=t.length,u){var m=d-p,y=v-g;m>0&&(m=Math.max(10*l,m),this._addLineCollisionCircles(t,e,r,r.segment,y,m,n,a,o,h))}else{if(f){var x=new i(g,p),b=new i(v,p),_=new i(g,d),w=new i(v,d),k=f*Math.PI/180;x._rotate(k),b._rotate(k),_._rotate(k),w._rotate(k),g=Math.min(x.x,b.x,_.x,w.x),v=Math.max(x.x,b.x,_.x,w.x),p=Math.min(x.y,b.y,_.y,w.y),d=Math.max(x.y,b.y,_.y,w.y)}t.emplaceBack(r.x,r.y,g,p,v,d,n,a,o,0,0)}this.boxEndIndex=t.length};uc.prototype._addLineCollisionCircles=function(t,e,r,n,i,a,o,s,l,c){var u=a/2,h=Math.floor(i/u)||1,f=1+.4*Math.log(c)/Math.LN2,p=Math.floor(h*f/2),d=-a/2,g=r,v=n+1,m=d,y=-i/2,x=y-i/4;do{if(--v<0){if(m>y)return;v=0;break}m-=e[v].dist(g),g=e[v]}while(m>x);for(var b=e[v].dist(e[v+1]),_=-p;_<h+p;_++){var w=_*u,k=y+w;if(w<0&&(k+=w),w>i&&(k+=w-i),!(k<m)){for(;m+b<k;){if(m+=b,++v+1>=e.length)return;b=e[v].dist(e[v+1])}var T=k-m,A=e[v],M=e[v+1].sub(A)._unit()._mult(T)._add(A)._round(),S=Math.abs(k-d)<u?0:.8*(k-d);t.emplaceBack(M.x,M.y,-a/2,-a/2,a/2,a/2,o,s,l,a/2,S)}}};var hc=function(t,e){if(void 0===t&&(t=[]),void 0===e&&(e=fc),this.data=t,this.length=this.data.length,this.compare=e,this.length>0)for(var r=(this.length>>1)-1;r>=0;r--)this._down(r)};function fc(t,e){return t<e?-1:t>e?1:0}function pc(t,e,r){void 0===e&&(e=1),void 0===r&&(r=!1);for(var n=1/0,a=1/0,o=-1/0,s=-1/0,l=t[0],c=0;c<l.length;c++){var u=l[c];(!c||u.x<n)&&(n=u.x),(!c||u.y<a)&&(a=u.y),(!c||u.x>o)&&(o=u.x),(!c||u.y>s)&&(s=u.y)}var h=o-n,f=s-a,p=Math.min(h,f),d=p/2,g=new hc([],dc);if(0===p)return new i(n,a);for(var v=n;v<o;v+=p)for(var m=a;m<s;m+=p)g.push(new gc(v+d,m+d,d,t));for(var y=function(t){for(var e=0,r=0,n=0,i=t[0],a=0,o=i.length,s=o-1;a<o;s=a++){var l=i[a],c=i[s],u=l.x*c.y-c.x*l.y;r+=(l.x+c.x)*u,n+=(l.y+c.y)*u,e+=3*u}return new gc(r/e,n/e,0,t)}(t),x=g.length;g.length;){var b=g.pop();(b.d>y.d||!y.d)&&(y=b,r&&console.log(\"found best %d after %d probes\",Math.round(1e4*b.d)/1e4,x)),b.max-y.d<=e||(d=b.h/2,g.push(new gc(b.p.x-d,b.p.y-d,d,t)),g.push(new gc(b.p.x+d,b.p.y-d,d,t)),g.push(new gc(b.p.x-d,b.p.y+d,d,t)),g.push(new gc(b.p.x+d,b.p.y+d,d,t)),x+=4)}return r&&(console.log(\"num probes: \"+x),console.log(\"best distance: \"+y.d)),y.p}function dc(t,e){return e.max-t.max}function gc(t,e,r,n){this.p=new i(t,e),this.h=r,this.d=function(t,e){for(var r=!1,n=1/0,i=0;i<e.length;i++)for(var a=e[i],o=0,s=a.length,l=s-1;o<s;l=o++){var c=a[o],u=a[l];c.y>t.y!=u.y>t.y&&t.x<(u.x-c.x)*(t.y-c.y)/(u.y-c.y)+c.x&&(r=!r),n=Math.min(n,ka(t,c,u))}return(r?1:-1)*Math.sqrt(n)}(this.p,n),this.max=this.d+this.h*Math.SQRT2}hc.prototype.push=function(t){this.data.push(t),this.length++,this._up(this.length-1)},hc.prototype.pop=function(){if(0!==this.length){var t=this.data[0];return this.length--,this.length>0&&(this.data[0]=this.data[this.length],this._down(0)),this.data.pop(),t}},hc.prototype.peek=function(){return this.data[0]},hc.prototype._up=function(t){for(var e=this.data,r=this.compare,n=e[t];t>0;){var i=t-1>>1,a=e[i];if(r(n,a)>=0)break;e[t]=a,t=i}e[t]=n},hc.prototype._down=function(t){for(var e=this.data,r=this.compare,n=this.length>>1,i=e[t];t<n;){var a=1+(t<<1),o=e[a],s=a+1;if(s<this.length&&r(e[s],o)<0&&(a=s,o=e[s]),r(o,i)>=0)break;e[t]=o,t=a}e[t]=i};var vc=e(function(t){t.exports=function(t,e){var r,n,i,a,o,s,l,c;for(r=3&t.length,n=t.length-r,i=e,o=3432918353,s=461845907,c=0;c<n;)l=255&t.charCodeAt(c)|(255&t.charCodeAt(++c))<<8|(255&t.charCodeAt(++c))<<16|(255&t.charCodeAt(++c))<<24,++c,i=27492+(65535&(a=5*(65535&(i=(i^=l=(65535&(l=(l=(65535&l)*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295)<<13|i>>>19))+((5*(i>>>16)&65535)<<16)&4294967295))+((58964+(a>>>16)&65535)<<16);switch(l=0,r){case 3:l^=(255&t.charCodeAt(c+2))<<16;case 2:l^=(255&t.charCodeAt(c+1))<<8;case 1:i^=l=(65535&(l=(l=(65535&(l^=255&t.charCodeAt(c)))*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295}return i^=t.length,i=2246822507*(65535&(i^=i>>>16))+((2246822507*(i>>>16)&65535)<<16)&4294967295,i=3266489909*(65535&(i^=i>>>13))+((3266489909*(i>>>16)&65535)<<16)&4294967295,(i^=i>>>16)>>>0}}),mc=e(function(t){t.exports=function(t,e){for(var r,n=t.length,i=e^n,a=0;n>=4;)r=1540483477*(65535&(r=255&t.charCodeAt(a)|(255&t.charCodeAt(++a))<<8|(255&t.charCodeAt(++a))<<16|(255&t.charCodeAt(++a))<<24))+((1540483477*(r>>>16)&65535)<<16),i=1540483477*(65535&i)+((1540483477*(i>>>16)&65535)<<16)^(r=1540483477*(65535&(r^=r>>>24))+((1540483477*(r>>>16)&65535)<<16)),n-=4,++a;switch(n){case 3:i^=(255&t.charCodeAt(a+2))<<16;case 2:i^=(255&t.charCodeAt(a+1))<<8;case 1:i=1540483477*(65535&(i^=255&t.charCodeAt(a)))+((1540483477*(i>>>16)&65535)<<16)}return i=1540483477*(65535&(i^=i>>>13))+((1540483477*(i>>>16)&65535)<<16),(i^=i>>>15)>>>0}}),yc=vc,xc=vc,bc=mc;yc.murmur3=xc,yc.murmur2=bc;var _c=7;function wc(t,e){var r=0,n=0,i=e/Math.sqrt(2);switch(t){case\"top-right\":case\"top-left\":n=i-_c;break;case\"bottom-right\":case\"bottom-left\":n=-i+_c;break;case\"bottom\":n=-e+_c;break;case\"top\":n=e-_c}switch(t){case\"top-right\":case\"bottom-right\":r=-i;break;case\"top-left\":case\"bottom-left\":r=i;break;case\"left\":r=e;break;case\"right\":r=-e}return[r,n]}function kc(t){switch(t){case\"right\":case\"top-right\":case\"bottom-right\":return\"right\";case\"left\":case\"top-left\":case\"bottom-left\":return\"left\"}return\"center\"}function Tc(t,e,r,n,a,o,s){var l=o.layoutTextSize.evaluate(e,{}),c=o.layoutIconSize.evaluate(e,{}),u=o.textMaxSize.evaluate(e,{});void 0===u&&(u=l);var h=t.layers[0].layout,f=h.get(\"icon-offset\").evaluate(e,{}),p=Sc(r.horizontal),d=l/24,g=t.tilePixelRatio*d,v=t.tilePixelRatio*u/24,m=t.tilePixelRatio*c,y=t.tilePixelRatio*h.get(\"symbol-spacing\"),x=h.get(\"text-padding\")*t.tilePixelRatio,b=h.get(\"icon-padding\")*t.tilePixelRatio,_=h.get(\"text-max-angle\")/180*Math.PI,k=\"map\"===h.get(\"text-rotation-alignment\")&&\"point\"!==h.get(\"symbol-placement\"),T=\"map\"===h.get(\"icon-rotation-alignment\")&&\"point\"!==h.get(\"symbol-placement\"),A=h.get(\"symbol-placement\"),M=y/2,S=function(l,c){c.x<0||c.x>=ha||c.y<0||c.y>=ha||function(t,e,r,n,a,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_){var k,T,A=t.addToLineVertexArray(e,r),M=0,S=0,E=0,C={},L=yc(\"\"),P=(o.layout.get(\"text-radial-offset\").evaluate(x,{})||0)*Gl;for(var O in n.horizontal){var z=n.horizontal[O];if(!k){L=yc(z.text);var I=o.layout.get(\"text-rotate\").evaluate(x,{});k=new uc(s,r,e,l,c,u,z,h,f,p,t.overscaling,I)}var D=1===z.lineCount;if(S+=Mc(t,e,z,o,p,x,d,A,n.vertical?Yl.horizontal:Yl.horizontalOnly,D?Object.keys(n.horizontal):[O],C,b,_),D)break}n.vertical&&(E+=Mc(t,e,n.vertical,o,p,x,d,A,Yl.vertical,[\"vertical\"],C,b,_));var R=k?k.boxStartIndex:t.collisionBoxArray.length,F=k?k.boxEndIndex:t.collisionBoxArray.length;if(a){var B=function(t,e,r,n,a,o){var s,l,c,u,h=e.image,f=r.layout,p=e.top-1/h.pixelRatio,d=e.left-1/h.pixelRatio,g=e.bottom+1/h.pixelRatio,v=e.right+1/h.pixelRatio;if(\"none\"!==f.get(\"icon-text-fit\")&&a){var m=v-d,y=g-p,x=f.get(\"text-size\").evaluate(o,{})/24,b=a.left*x,_=a.right*x,w=a.top*x,k=_-b,T=a.bottom*x-w,A=f.get(\"icon-text-fit-padding\")[0],M=f.get(\"icon-text-fit-padding\")[1],S=f.get(\"icon-text-fit-padding\")[2],E=f.get(\"icon-text-fit-padding\")[3],C=\"width\"===f.get(\"icon-text-fit\")?.5*(T-y):0,L=\"height\"===f.get(\"icon-text-fit\")?.5*(k-m):0,P=\"width\"===f.get(\"icon-text-fit\")||\"both\"===f.get(\"icon-text-fit\")?k:m,O=\"height\"===f.get(\"icon-text-fit\")||\"both\"===f.get(\"icon-text-fit\")?T:y;s=new i(b+L-E,w+C-A),l=new i(b+L+M+P,w+C-A),c=new i(b+L+M+P,w+C+S+O),u=new i(b+L-E,w+C+S+O)}else s=new i(d,p),l=new i(v,p),c=new i(v,g),u=new i(d,g);var z=r.layout.get(\"icon-rotate\").evaluate(o,{})*Math.PI/180;if(z){var I=Math.sin(z),D=Math.cos(z),R=[D,-I,I,D];s._matMult(R),l._matMult(R),u._matMult(R),c._matMult(R)}return[{tl:s,tr:l,bl:u,br:c,tex:h.paddedRect,writingMode:void 0,glyphOffset:[0,0]}]}(0,a,o,0,Sc(n.horizontal),x),N=o.layout.get(\"icon-rotate\").evaluate(x,{});T=new uc(s,r,e,l,c,u,a,g,v,!1,t.overscaling,N),M=4*B.length;var j=t.iconSizeData,U=null;\"source\"===j.kind?(U=[_s*o.layout.get(\"icon-size\").evaluate(x,{})])[0]>Ac&&w(t.layerIds[0]+': Value for \"icon-size\" is >= 256. Reduce your \"icon-size\".'):\"composite\"===j.kind&&((U=[_s*_.compositeIconSizes[0].evaluate(x,{}),_s*_.compositeIconSizes[1].evaluate(x,{})])[0]>Ac||U[1]>Ac)&&w(t.layerIds[0]+': Value for \"icon-size\" is >= 256. Reduce your \"icon-size\".'),t.addSymbols(t.icon,B,U,y,m,x,!1,e,A.lineStartIndex,A.lineLength)}var V=T?T.boxStartIndex:t.collisionBoxArray.length,q=T?T.boxEndIndex:t.collisionBoxArray.length;t.glyphOffsetArray.length>=Os.MAX_GLYPHS&&w(\"Too many glyphs being rendered in a tile. See https://github.com/mapbox/mapbox-gl-js/issues/2907\"),t.symbolInstances.emplaceBack(e.x,e.y,C.right>=0?C.right:-1,C.center>=0?C.center:-1,C.left>=0?C.left:-1,C.vertical||-1,L,R,F,V,q,l,S,E,M,0,h,P)}(t,c,l,r,n,t.layers[0],t.collisionBoxArray,e.index,e.sourceLayerIndex,t.index,g,x,k,s,m,b,T,f,e,a,o)};if(\"line\"===A)for(var E=0,C=function(t,e,r,n,a){for(var o=[],s=0;s<t.length;s++)for(var l=t[s],c=void 0,u=0;u<l.length-1;u++){var h=l[u],f=l[u+1];h.x<0&&f.x<0||(h.x<0?h=new i(0,h.y+(f.y-h.y)*((0-h.x)/(f.x-h.x)))._round():f.x<0&&(f=new i(0,h.y+(f.y-h.y)*((0-h.x)/(f.x-h.x)))._round()),h.y<0&&f.y<0||(h.y<0?h=new i(h.x+(f.x-h.x)*((0-h.y)/(f.y-h.y)),0)._round():f.y<0&&(f=new i(h.x+(f.x-h.x)*((0-h.y)/(f.y-h.y)),0)._round()),h.x>=n&&f.x>=n||(h.x>=n?h=new i(n,h.y+(f.y-h.y)*((n-h.x)/(f.x-h.x)))._round():f.x>=n&&(f=new i(n,h.y+(f.y-h.y)*((n-h.x)/(f.x-h.x)))._round()),h.y>=a&&f.y>=a||(h.y>=a?h=new i(h.x+(f.x-h.x)*((a-h.y)/(f.y-h.y)),a)._round():f.y>=a&&(f=new i(h.x+(f.x-h.x)*((a-h.y)/(f.y-h.y)),a)._round()),c&&h.equals(c[c.length-1])||(c=[h],o.push(c)),c.push(f)))))}return o}(e.geometry,0,0,ha,ha);E<C.length;E+=1)for(var L=C[E],P=0,O=cc(L,y,_,r.vertical||p,n,24,v,t.overscaling,ha);P<O.length;P+=1){var z=O[P];p&&Ec(t,p.text,M,z)||S(L,z)}else if(\"line-center\"===A)for(var I=0,D=e.geometry;I<D.length;I+=1){var R=D[I];if(R.length>1){var F=lc(R,_,r.vertical||p,n,24,v);F&&S(R,F)}}else if(\"Polygon\"===e.type)for(var B=0,N=Mo(e.geometry,0);B<N.length;B+=1){var j=N[B],U=pc(j,16);S(j[0],new bs(U.x,U.y,0))}else if(\"LineString\"===e.type)for(var V=0,q=e.geometry;V<q.length;V+=1){var H=q[V];S(H,new bs(H[0].x,H[0].y,0))}else if(\"Point\"===e.type)for(var G=0,Y=e.geometry;G<Y.length;G+=1)for(var W=0,X=Y[G];W<X.length;W+=1){var Z=X[W];S([Z],new bs(Z.x,Z.y,0))}}var Ac=65535;function Mc(t,e,r,n,a,o,s,l,c,u,h,f,p){var d=function(t,e,r,n,a,o,s){for(var l=n.layout.get(\"text-rotate\").evaluate(o,{})*Math.PI/180,c=e.positionedGlyphs,u=[],h=0;h<c.length;h++){var f=c[h],p=s[f.fontStack],d=p&&p[f.glyph];if(d){var g=d.rect;if(g){var v=bl+1,m=d.metrics.advance*f.scale/2,y=a?[f.x+m,f.y]:[0,0],x=a?[0,0]:[f.x+m+r[0],f.y+r[1]],b=(d.metrics.left-v)*f.scale-m+x[0],_=(-d.metrics.top-v)*f.scale+x[1],w=b+g.w*f.scale,k=_+g.h*f.scale,T=new i(b,_),A=new i(w,_),M=new i(b,k),S=new i(w,k);if(a&&f.vertical){var E=new i(-m,m),C=-Math.PI/2,L=new i(5,0);T._rotateAround(C,E)._add(L),A._rotateAround(C,E)._add(L),M._rotateAround(C,E)._add(L),S._rotateAround(C,E)._add(L)}if(l){var P=Math.sin(l),O=Math.cos(l),z=[O,-P,P,O];T._matMult(z),A._matMult(z),M._matMult(z),S._matMult(z)}u.push({tl:T,tr:A,bl:M,br:S,tex:g,writingMode:e.writingMode,glyphOffset:y})}}}return u}(0,r,s,n,a,o,f),g=t.textSizeData,v=null;\"source\"===g.kind?(v=[_s*n.layout.get(\"text-size\").evaluate(o,{})])[0]>Ac&&w(t.layerIds[0]+': Value for \"text-size\" is >= 256. Reduce your \"text-size\".'):\"composite\"===g.kind&&((v=[_s*p.compositeTextSizes[0].evaluate(o,{}),_s*p.compositeTextSizes[1].evaluate(o,{})])[0]>Ac||v[1]>Ac)&&w(t.layerIds[0]+': Value for \"text-size\" is >= 256. Reduce your \"text-size\".'),t.addSymbols(t.text,d,v,s,a,o,c,e,l.lineStartIndex,l.lineLength);for(var m=0,y=u;m<y.length;m+=1)h[y[m]]=t.text.placedSymbolArray.length-1;return 4*d.length}function Sc(t){for(var e in t)return t[e];return null}function Ec(t,e,r,n){var i=t.compareText;if(e in i){for(var a=i[e],o=a.length-1;o>=0;o--)if(n.dist(a[o])<r)return!0}else i[e]=[];return i[e].push(n),!1}t.Actor=_l,t.AlphaImage=qa,t.CanonicalTileID=Pl,t.CollisionBoxArray=Li,t.Color=ne,t.DEMData=Dl,t.DataConstantProperty=Jn,t.DictionaryCoder=Fl,t.EXTENT=ha,t.ErrorEvent=Ot,t.EvaluationParameters=Un,t.Event=Pt,t.Evented=zt,t.FeatureIndex=Ul,t.FillBucket=Lo,t.FillExtrusionBucket=Yo,t.ImageAtlas=Gs,t.ImagePosition=qs,t.LineBucket=os,t.LngLat=Tl,t.LngLatBounds=kl,t.MercatorCoordinate=Ll,t.ONE_EM=Gl,t.OverscaledTileID=zl,t.Point=i,t.Point$1=i,t.ProgramConfiguration=sa,t.Properties=ei,t.Protobuf=Qs,t.RGBAImage=Ha,t.RequestManager=j,t.ResourceType=yt,t.SegmentVector=Vi,t.SourceFeatureState=jl,t.StructArrayLayout1ui2=Mi,t.StructArrayLayout2i4=li,t.StructArrayLayout2ui4=Ai,t.StructArrayLayout3ui6=Ti,t.StructArrayLayout4i8=ci,t.SymbolBucket=Os,t.Texture=Js,t.Tile=Hl,t.Transitionable=Hn,t.Uniform1f=Xi,t.Uniform1i=Wi,t.Uniform2f=Zi,t.Uniform3f=Ji,t.Uniform4f=Ki,t.UniformColor=$i,t.UniformMatrix4f=ta,t.UnwrappedTileID=Ol,t.ValidationError=Dt,t.WritingMode=Yl,t.ZoomHistory=Sn,t.addDynamicAttributes=Cs,t.asyncAll=function(t,e,r){if(!t.length)return r(null,[]);var n=t.length,i=new Array(t.length),a=null;t.forEach(function(t,o){e(t,function(t,e){t&&(a=t),i[o]=e,0==--n&&r(a,i)})})},t.bezier=s,t.bindAll=v,t.browser=z,t.cacheEntryPossiblyAdded=function(t){++mt>dt&&(t.send(\"enforceCacheSizeLimit\",pt),mt=0)},t.clamp=c,t.clearTileCache=function(t){var e=self.caches.delete(ft);t&&e.catch(t).then(function(){return t()})},t.clone=function(t){var e=new Pa(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e},t.clone$1=b,t.config=I,t.create=function(){var t=new Pa(16);return Pa!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=0,t[12]=0,t[13]=0,t[14]=0),t[0]=1,t[5]=1,t[10]=1,t[15]=1,t},t.create$1=Oa,t.create$2=function(){var t=new Pa(4);return Pa!=Float32Array&&(t[1]=0,t[2]=0),t[0]=1,t[3]=1,t},t.createCommonjsModule=e,t.createExpression=Or,t.createLayout=oi,t.createStyleLayer=function(t){return\"custom\"===t.type?new js(t):new Us[t.type](t)},t.deepEqual=o,t.ease=l,t.emitValidationErrors=mn,t.endsWith=m,t.enforceCacheSizeLimit=function(t){self.caches&&self.caches.open(ft).then(function(e){e.keys().then(function(r){for(var n=0;n<r.length-t;n++)e.delete(r[n])})})},t.evaluateRadialOffset=wc,t.evaluateSizeForFeature=ks,t.evaluateSizeForZoom=Ts,t.evented=Nn,t.extend=h,t.featureFilter=Gr,t.filterObject=x,t.fromRotation=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=r,t[2]=0,t[3]=-r,t[4]=n,t[5]=0,t[6]=0,t[7]=0,t[8]=1,t},t.getAnchorAlignment=ec,t.getAnchorJustification=kc,t.getArrayBuffer=Mt,t.getImage=Et,t.getJSON=function(t,e){return At(h(t,{type:\"json\"}),e)},t.getReferrer=_t,t.getVideo=function(t,e){var r,n,i=self.document.createElement(\"video\");i.muted=!0,i.onloadstart=function(){e(null,i)};for(var a=0;a<t.length;a++){var o=self.document.createElement(\"source\");r=t[a],n=void 0,(n=self.document.createElement(\"a\")).href=r,(n.protocol!==self.document.location.protocol||n.host!==self.document.location.host)&&(i.crossOrigin=\"Anonymous\"),o.src=t[a],i.appendChild(o)}return{cancel:function(){}}},t.identity=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t},t.invert=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],g=e[13],v=e[14],m=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,k=i*c-a*l,T=u*g-h*d,A=u*v-f*d,M=u*m-p*d,S=h*v-f*g,E=h*m-p*g,C=f*m-p*v,L=y*C-x*E+b*S+_*M-w*A+k*T;return L?(L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(i*E-n*C-a*S)*L,t[2]=(g*k-v*w+m*_)*L,t[3]=(f*w-h*k-p*_)*L,t[4]=(l*M-o*C-c*A)*L,t[5]=(r*C-i*M+a*A)*L,t[6]=(v*b-d*k-m*x)*L,t[7]=(u*k-f*b+p*x)*L,t[8]=(o*E-s*M+c*T)*L,t[9]=(n*M-r*E-a*T)*L,t[10]=(d*w-g*b+m*y)*L,t[11]=(h*b-u*w-p*y)*L,t[12]=(s*A-o*S-l*T)*L,t[13]=(r*S-n*A+i*T)*L,t[14]=(g*x-d*_-v*y)*L,t[15]=(u*_-h*x+f*y)*L,t):null},t.isChar=En,t.isMapboxURL=q,t.keysDifference=function(t,e){var r=[];for(var n in t)n in e||r.push(n);return r},t.makeRequest=At,t.mapObject=y,t.mercatorXfromLng=Ml,t.mercatorYfromLat=Sl,t.mercatorZfromAltitude=El,t.multiply=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],g=e[12],v=e[13],m=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*h+w*g,t[1]=x*i+b*l+_*f+w*v,t[2]=x*a+b*c+_*p+w*m,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*h+w*g,t[5]=x*i+b*l+_*f+w*v,t[6]=x*a+b*c+_*p+w*m,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*h+w*g,t[9]=x*i+b*l+_*f+w*v,t[10]=x*a+b*c+_*p+w*m,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*h+w*g,t[13]=x*i+b*l+_*f+w*v,t[14]=x*a+b*c+_*p+w*m,t[15]=x*o+b*u+_*d+w*y,t},t.mvt=Vo,t.number=Ee,t.ortho=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t},t.parseGlyphPBF=function(t){return new Qs(t).readFields(ml,[])},t.pbf=Qs,t.performSymbolLayout=function(t,e,r,n,i,a){t.createArrays();var o=512*t.overscaling;t.tilePixelRatio=ha/o,t.compareText={},t.iconsNeedLinear=!1;var s=t.layers[0].layout,l=t.layers[0]._unevaluatedLayout._values,c={};if(\"composite\"===t.textSizeData.kind){var u=t.textSizeData,h=u.minZoom,f=u.maxZoom;c.compositeTextSizes=[l[\"text-size\"].possiblyEvaluate(new Un(h)),l[\"text-size\"].possiblyEvaluate(new Un(f))]}if(\"composite\"===t.iconSizeData.kind){var p=t.iconSizeData,d=p.minZoom,g=p.maxZoom;c.compositeIconSizes=[l[\"icon-size\"].possiblyEvaluate(new Un(d)),l[\"icon-size\"].possiblyEvaluate(new Un(g))]}c.layoutTextSize=l[\"text-size\"].possiblyEvaluate(new Un(t.zoom+1)),c.layoutIconSize=l[\"icon-size\"].possiblyEvaluate(new Un(t.zoom+1)),c.textMaxSize=l[\"text-size\"].possiblyEvaluate(new Un(18));for(var v=s.get(\"text-line-height\")*Gl,m=\"map\"===s.get(\"text-rotation-alignment\")&&\"point\"!==s.get(\"symbol-placement\"),y=s.get(\"text-keep-upright\"),x=0,b=t.features;x<b.length;x+=1){var _=b[x],k=s.get(\"text-font\").evaluate(_,{}).join(\",\"),T=r,A={horizontal:{},vertical:void 0},M=_.text,S=[0,0];if(M){var E=M.toString(),C=s.get(\"text-letter-spacing\").evaluate(_,{})*Gl,L=Ln(E)?C:0,P=s.get(\"text-anchor\").evaluate(_,{}),O=s.get(\"text-variable-anchor\"),z=s.get(\"text-radial-offset\").evaluate(_,{});O||(S=z?wc(P,z*Gl):s.get(\"text-offset\").evaluate(_,{}).map(function(t){return t*Gl}));var I=m?\"center\":s.get(\"text-justify\").evaluate(_,{}),D=\"point\"===s.get(\"symbol-placement\")?s.get(\"text-max-width\").evaluate(_,{})*Gl:0;if(!m&&O)for(var R=\"auto\"===I?O.map(function(t){return kc(t)}):[I],F=!1,B=0;B<R.length;B++){var N=R[B];if(!A.horizontal[N])if(F)A.horizontal[N]=A.horizontal[0];else{var j=Xl(M,e,k,D,v,\"center\",N,L,S,Yl.horizontal);j&&(A.horizontal[N]=j,F=1===j.lineCount)}}else{\"auto\"===I&&(I=kc(P));var U=Xl(M,e,k,D,v,P,I,L,S,Yl.horizontal);U&&(A.horizontal[I]=U),Cn(E)&&m&&y&&(A.vertical=Xl(M,e,k,D,v,P,I,L,S,Yl.vertical))}}var V=void 0;if(_.icon){var q=n[_.icon];q&&(V=nc(i[_.icon],s.get(\"icon-offset\").evaluate(_,{}),s.get(\"icon-anchor\").evaluate(_,{})),void 0===t.sdfIcons?t.sdfIcons=q.sdf:t.sdfIcons!==q.sdf&&w(\"Style sheet warning: Cannot mix SDF and non-SDF icons in one buffer\"),q.pixelRatio!==t.pixelRatio?t.iconsNeedLinear=!0:0!==s.get(\"icon-rotate\").constantOr(1)&&(t.iconsNeedLinear=!0))}(Object.keys(A.horizontal).length||V)&&Tc(t,_,A,V,T,c,S)}a&&t.generateCollisionDebugBuffers()},t.perspective=function(t,e,r,n,i){var a,o=1/Math.tan(e/2);return t[0]=o/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=o,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=-1,t[12]=0,t[13]=0,t[15]=0,null!=i&&i!==1/0?(a=1/(n-i),t[10]=(i+n)*a,t[14]=2*i*n*a):(t[10]=-1,t[14]=-2*n),t},t.pick=function(t,e){for(var r={},n=0;n<e.length;n++){var i=e[n];i in t&&(r[i]=t[i])}return r},t.plugin=jn,t.polygonIntersectsPolygon=va,t.postMapLoadEvent=ht,t.postTurnstileEvent=ct,t.potpack=Vs,t.rasterBoundsAttributes=Rl,t.refProperties=[\"type\",\"source\",\"source-layer\",\"minzoom\",\"maxzoom\",\"filter\",\"layout\"],t.register=kn,t.registerForPluginAvailability=function(t){return Fn?t({pluginURL:Fn,completionCallback:Dn}):Nn.once(\"pluginAvailable\",t),t},t.rotate=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=Math.sin(r),l=Math.cos(r);return t[0]=n*l+a*s,t[1]=i*l+o*s,t[2]=n*-s+a*l,t[3]=i*-s+o*l,t},t.rotateX=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];return e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+h*n,t[7]=l*i+f*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=h*i-s*n,t[11]=f*i-l*n,t},t.rotateZ=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];return e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+h*n,t[3]=l*i+f*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=h*i-s*n,t[7]=f*i-l*n,t},t.scale=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t},t.setCacheLimits=function(t,e){pt=t,dt=e},t.setRTLTextPlugin=function(t,e){if(Rn)throw new Error(\"setRTLTextPlugin cannot be called multiple times.\");Rn=!0,Fn=z.resolveURL(t),Dn=function(t){t?(Rn=!1,Fn=null,e&&e(t)):Bn=!0},Nn.fire(new Pt(\"pluginAvailable\",{pluginURL:Fn,completionCallback:Dn}))},t.sphericalToCartesian=function(t){var e=t[0],r=t[1],n=t[2];return r+=90,r*=Math.PI/180,n*=Math.PI/180,{x:e*Math.cos(r)*Math.sin(n),y:e*Math.sin(r)*Math.sin(n),z:e*Math.cos(n)}},t.styleSpec=It,t.symbolSize=As,t.transformMat3=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t},t.transformMat4=Da,t.translate=function(t,e,r){var n,i,a,o,s,l,c,u,h,f,p,d,g=r[0],v=r[1],m=r[2];return e===t?(t[12]=e[0]*g+e[4]*v+e[8]*m+e[12],t[13]=e[1]*g+e[5]*v+e[9]*m+e[13],t[14]=e[2]*g+e[6]*v+e[10]*m+e[14],t[15]=e[3]*g+e[7]*v+e[11]*m+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*g+s*v+h*m+e[12],t[13]=i*g+l*v+f*m+e[13],t[14]=a*g+c*v+p*m+e[14],t[15]=o*g+u*v+d*m+e[15]),t},t.uniqueId=p,t.validateCustomStyleLayer=function(t){var e=[],r=t.id;return void 0===r&&e.push({message:\"layers.\"+r+': missing required property \"id\"'}),void 0===t.render&&e.push({message:\"layers.\"+r+': missing required method \"render\"'}),t.renderingMode&&\"2d\"!==t.renderingMode&&\"3d\"!==t.renderingMode&&e.push({message:\"layers.\"+r+': property \"renderingMode\" must be either \"2d\" or \"3d\"'}),e},t.validateLight=dn,t.validateStyle=pn,t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.vectorTile=Vo,t.version=\"1.1.1\",t.warnOnce=w,t.webpSupported=D,t.window=self,t.wrap=u}),n(0,function(t){function e(t){var r=typeof t;if(\"number\"===r||\"boolean\"===r||\"string\"===r||null==t)return JSON.stringify(t);if(Array.isArray(t)){for(var n=\"[\",i=0,a=t;i<a.length;i+=1)n+=e(a[i])+\",\";return n+\"]\"}for(var o=Object.keys(t).sort(),s=\"{\",l=0;l<o.length;l++)s+=JSON.stringify(o[l])+\":\"+e(t[o[l]])+\",\";return s+\"}\"}function r(r){for(var n=\"\",i=0,a=t.refProperties;i<a.length;i+=1)n+=\"/\"+e(r[a[i]]);return n}var n=function(t){this.keyCache={},t&&this.replace(t)};n.prototype.replace=function(t){this._layerConfigs={},this._layers={},this.update(t,[])},n.prototype.update=function(e,n){for(var i=this,a=0,o=e;a<o.length;a+=1){var s=o[a];this._layerConfigs[s.id]=s;var l=this._layers[s.id]=t.createStyleLayer(s);l._featureFilter=t.featureFilter(l.filter),this.keyCache[s.id]&&delete this.keyCache[s.id]}for(var c=0,u=n;c<u.length;c+=1){var h=u[c];delete this.keyCache[h],delete this._layerConfigs[h],delete this._layers[h]}this.familiesBySource={};for(var f=0,p=function(t,e){for(var n={},i=0;i<t.length;i++){var a=e&&e[t[i].id]||r(t[i]);e&&(e[t[i].id]=a);var o=n[a];o||(o=n[a]=[]),o.push(t[i])}var s=[];for(var l in n)s.push(n[l]);return s}(t.values(this._layerConfigs),this.keyCache);f<p.length;f+=1){var d=p[f].map(function(t){return i._layers[t.id]}),g=d[0];if(\"none\"!==g.visibility){var v=g.source||\"\",m=this.familiesBySource[v];m||(m=this.familiesBySource[v]={});var y=g.sourceLayer||\"_geojsonTileLayer\",x=m[y];x||(x=m[y]=[]),x.push(d)}}};var i=function(e){var r={},n=[];for(var i in e){var a=e[i],o=r[i]={};for(var s in a){var l=a[+s];if(l&&0!==l.bitmap.width&&0!==l.bitmap.height){var c={x:0,y:0,w:l.bitmap.width+2,h:l.bitmap.height+2};n.push(c),o[s]={rect:c,metrics:l.metrics}}}}var u=t.potpack(n),h=u.w,f=u.h,p=new t.AlphaImage({width:h||1,height:f||1});for(var d in e){var g=e[d];for(var v in g){var m=g[+v];if(m&&0!==m.bitmap.width&&0!==m.bitmap.height){var y=r[d][v].rect;t.AlphaImage.copy(m.bitmap,p,{x:0,y:0},{x:y.x+1,y:y.y+1},m.bitmap)}}}this.image=p,this.positions=r};t.register(\"GlyphAtlas\",i);var a=function(e){this.tileID=new t.OverscaledTileID(e.tileID.overscaledZ,e.tileID.wrap,e.tileID.canonical.z,e.tileID.canonical.x,e.tileID.canonical.y),this.uid=e.uid,this.zoom=e.zoom,this.pixelRatio=e.pixelRatio,this.tileSize=e.tileSize,this.source=e.source,this.overscaling=this.tileID.overscaleFactor(),this.showCollisionBoxes=e.showCollisionBoxes,this.collectResourceTiming=!!e.collectResourceTiming,this.returnDependencies=!!e.returnDependencies};function o(e,r){for(var n=new t.EvaluationParameters(r),i=0,a=e;i<a.length;i+=1)a[i].recalculate(n)}a.prototype.parse=function(e,r,n,a){var s=this;this.status=\"parsing\",this.data=e,this.collisionBoxArray=new t.CollisionBoxArray;var l=new t.DictionaryCoder(Object.keys(e.layers).sort()),c=new t.FeatureIndex(this.tileID);c.bucketLayerIDs=[];var u,h,f,p,d={},g={featureIndex:c,iconDependencies:{},patternDependencies:{},glyphDependencies:{}},v=r.familiesBySource[this.source];for(var m in v){var y=e.layers[m];if(y){1===y.version&&t.warnOnce('Vector tile source \"'+this.source+'\" layer \"'+m+'\" does not use vector tile spec v2 and therefore may have some rendering errors.');for(var x=l.encode(m),b=[],_=0;_<y.length;_++){var w=y.feature(_);b.push({feature:w,index:_,sourceLayerIndex:x})}for(var k=0,T=v[m];k<T.length;k+=1){var A=T[k],M=A[0];M.minzoom&&this.zoom<Math.floor(M.minzoom)||M.maxzoom&&this.zoom>=M.maxzoom||\"none\"!==M.visibility&&(o(A,this.zoom),(d[M.id]=M.createBucket({index:c.bucketLayerIDs.length,layers:A,zoom:this.zoom,pixelRatio:this.pixelRatio,overscaling:this.overscaling,collisionBoxArray:this.collisionBoxArray,sourceLayerIndex:x,sourceID:this.source})).populate(b,g),c.bucketLayerIDs.push(A.map(function(t){return t.id})))}}}var S=t.mapObject(g.glyphDependencies,function(t){return Object.keys(t).map(Number)});Object.keys(S).length?n.send(\"getGlyphs\",{uid:this.uid,stacks:S},function(t,e){u||(u=t,h=e,L.call(s))}):h={};var E=Object.keys(g.iconDependencies);E.length?n.send(\"getImages\",{icons:E},function(t,e){u||(u=t,f=e,L.call(s))}):f={};var C=Object.keys(g.patternDependencies);function L(){if(u)return a(u);if(h&&f&&p){var e=new i(h),r=new t.ImageAtlas(f,p);for(var n in d){var s=d[n];s instanceof t.SymbolBucket?(o(s.layers,this.zoom),t.performSymbolLayout(s,h,e.positions,f,r.iconPositions,this.showCollisionBoxes)):s.hasPattern&&(s instanceof t.LineBucket||s instanceof t.FillBucket||s instanceof t.FillExtrusionBucket)&&(o(s.layers,this.zoom),s.addFeatures(g,r.patternPositions))}this.status=\"done\",a(null,{buckets:t.values(d).filter(function(t){return!t.isEmpty()}),featureIndex:c,collisionBoxArray:this.collisionBoxArray,glyphAtlasImage:e.image,imageAtlas:r,glyphMap:this.returnDependencies?h:null,iconMap:this.returnDependencies?f:null,glyphPositions:this.returnDependencies?e.positions:null})}}C.length?n.send(\"getImages\",{icons:C},function(t,e){u||(u=t,p=e,L.call(s))}):p={},L.call(this)};var s=\"undefined\"!=typeof performance,l={getEntriesByName:function(t){return!!(s&&performance&&performance.getEntriesByName)&&performance.getEntriesByName(t)},mark:function(t){return!!(s&&performance&&performance.mark)&&performance.mark(t)},measure:function(t,e,r){return!!(s&&performance&&performance.measure)&&performance.measure(t,e,r)},clearMarks:function(t){return!!(s&&performance&&performance.clearMarks)&&performance.clearMarks(t)},clearMeasures:function(t){return!!(s&&performance&&performance.clearMeasures)&&performance.clearMeasures(t)}},c=function(t){this._marks={start:[t.url,\"start\"].join(\"#\"),end:[t.url,\"end\"].join(\"#\"),measure:t.url.toString()},l.mark(this._marks.start)};function u(e,r){var n=t.getArrayBuffer(e.request,function(e,n,i,a){e?r(e):n&&r(null,{vectorTile:new t.vectorTile.VectorTile(new t.pbf(n)),rawData:n,cacheControl:i,expires:a})});return function(){n.cancel(),r()}}c.prototype.finish=function(){l.mark(this._marks.end);var t=l.getEntriesByName(this._marks.measure);return 0===t.length&&(l.measure(this._marks.measure,this._marks.start,this._marks.end),t=l.getEntriesByName(this._marks.measure),l.clearMarks(this._marks.start),l.clearMarks(this._marks.end),l.clearMeasures(this._marks.measure)),t},l.Performance=c;var h=function(t,e,r){this.actor=t,this.layerIndex=e,this.loadVectorData=r||u,this.loading={},this.loaded={}};h.prototype.loadTile=function(e,r){var n=this,i=e.uid;this.loading||(this.loading={});var o=!!(e&&e.request&&e.request.collectResourceTiming)&&new l.Performance(e.request),s=this.loading[i]=new a(e);s.abort=this.loadVectorData(e,function(e,a){if(delete n.loading[i],e||!a)return s.status=\"done\",n.loaded[i]=s,r(e);var l=a.rawData,c={};a.expires&&(c.expires=a.expires),a.cacheControl&&(c.cacheControl=a.cacheControl);var u={};if(o){var h=o.finish();h&&(u.resourceTiming=JSON.parse(JSON.stringify(h)))}s.vectorTile=a.vectorTile,s.parse(a.vectorTile,n.layerIndex,n.actor,function(e,n){if(e||!n)return r(e);r(null,t.extend({rawTileData:l.slice(0)},n,c,u))}),n.loaded=n.loaded||{},n.loaded[i]=s})},h.prototype.reloadTile=function(t,e){var r=this.loaded,n=t.uid,i=this;if(r&&r[n]){var a=r[n];a.showCollisionBoxes=t.showCollisionBoxes;var o=function(t,r){var n=a.reloadCallback;n&&(delete a.reloadCallback,a.parse(a.vectorTile,i.layerIndex,i.actor,n)),e(t,r)};\"parsing\"===a.status?a.reloadCallback=o:\"done\"===a.status&&(a.vectorTile?a.parse(a.vectorTile,this.layerIndex,this.actor,o):o())}},h.prototype.abortTile=function(t,e){var r=this.loading,n=t.uid;r&&r[n]&&r[n].abort&&(r[n].abort(),delete r[n]),e()},h.prototype.removeTile=function(t,e){var r=this.loaded,n=t.uid;r&&r[n]&&delete r[n],e()};var f=function(){this.loaded={}};f.prototype.loadTile=function(e,r){var n=e.uid,i=e.encoding,a=e.rawImageData,o=new t.DEMData(n,a,i);this.loaded=this.loaded||{},this.loaded[n]=o,r(null,o)},f.prototype.removeTile=function(t){var e=this.loaded,r=t.uid;e&&e[r]&&delete e[r]};var p={RADIUS:6378137,FLATTENING:1/298.257223563,POLAR_RADIUS:6356752.3142};function d(t){var e=0;if(t&&t.length>0){e+=Math.abs(g(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(g(t[r]))}return e}function g(t){var e,r,n,i,a,o,s=0,l=t.length;if(l>2){for(o=0;o<l;o++)o===l-2?(n=l-2,i=l-1,a=0):o===l-1?(n=l-1,i=0,a=1):(n=o,i=o+1,a=o+2),e=t[n],r=t[i],s+=(v(t[a][0])-v(e[0]))*Math.sin(v(r[1]));s=s*p.RADIUS*p.RADIUS/2}return s}function v(t){return t*Math.PI/180}var m={geometry:function t(e){var r,n=0;switch(e.type){case\"Polygon\":return d(e.coordinates);case\"MultiPolygon\":for(r=0;r<e.coordinates.length;r++)n+=d(e.coordinates[r]);return n;case\"Point\":case\"MultiPoint\":case\"LineString\":case\"MultiLineString\":return 0;case\"GeometryCollection\":for(r=0;r<e.geometries.length;r++)n+=t(e.geometries[r]);return n}},ring:g};function y(t,e){return function(r){return t(r,e)}}function x(t,e){e=!!e,t[0]=b(t[0],e);for(var r=1;r<t.length;r++)t[r]=b(t[r],!e);return t}function b(t,e){return function(t){return m.ring(t)>=0}(t)===e?t:t.reverse()}var _=t.vectorTile.VectorTileFeature.prototype.toGeoJSON,w=function(e){this._feature=e,this.extent=t.EXTENT,this.type=e.type,this.properties=e.tags,\"id\"in e&&!isNaN(e.id)&&(this.id=parseInt(e.id,10))};w.prototype.loadGeometry=function(){if(1===this._feature.type){for(var e=[],r=0,n=this._feature.geometry;r<n.length;r+=1){var i=n[r];e.push([new t.Point$1(i[0],i[1])])}return e}for(var a=[],o=0,s=this._feature.geometry;o<s.length;o+=1){for(var l=[],c=0,u=s[o];c<u.length;c+=1){var h=u[c];l.push(new t.Point$1(h[0],h[1]))}a.push(l)}return a},w.prototype.toGeoJSON=function(t,e,r){return _.call(this,t,e,r)};var k=function(e){this.layers={_geojsonTileLayer:this},this.name=\"_geojsonTileLayer\",this.extent=t.EXTENT,this.length=e.length,this._features=e};k.prototype.feature=function(t){return new w(this._features[t])};var T=t.vectorTile.VectorTileFeature,A=M;function M(t,e){this.options=e||{},this.features=t,this.length=t.length}function S(t,e){this.id=\"number\"==typeof t.id?t.id:void 0,this.type=t.type,this.rawGeometry=1===t.type?[t.geometry]:t.geometry,this.properties=t.tags,this.extent=e||4096}M.prototype.feature=function(t){return new S(this.features[t],this.options.extent)},S.prototype.loadGeometry=function(){var e=this.rawGeometry;this.geometry=[];for(var r=0;r<e.length;r++){for(var n=e[r],i=[],a=0;a<n.length;a++)i.push(new t.Point$1(n[a][0],n[a][1]));this.geometry.push(i)}return this.geometry},S.prototype.bbox=function(){this.geometry||this.loadGeometry();for(var t=this.geometry,e=1/0,r=-1/0,n=1/0,i=-1/0,a=0;a<t.length;a++)for(var o=t[a],s=0;s<o.length;s++){var l=o[s];e=Math.min(e,l.x),r=Math.max(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.y)}return[e,n,r,i]},S.prototype.toGeoJSON=T.prototype.toGeoJSON;var E=P,C=P,L=A;function P(e){var r=new t.pbf;return function(t,e){for(var r in t.layers)e.writeMessage(3,O,t.layers[r])}(e,r),r.finish()}function O(t,e){var r;e.writeVarintField(15,t.version||1),e.writeStringField(1,t.name||\"\"),e.writeVarintField(5,t.extent||4096);var n={keys:[],values:[],keycache:{},valuecache:{}};for(r=0;r<t.length;r++)n.feature=t.feature(r),e.writeMessage(2,z,n);var i=n.keys;for(r=0;r<i.length;r++)e.writeStringField(3,i[r]);var a=n.values;for(r=0;r<a.length;r++)e.writeMessage(4,B,a[r])}function z(t,e){var r=t.feature;void 0!==r.id&&e.writeVarintField(1,r.id),e.writeMessage(2,I,t),e.writeVarintField(3,r.type),e.writeMessage(4,F,r)}function I(t,e){var r=t.feature,n=t.keys,i=t.values,a=t.keycache,o=t.valuecache;for(var s in r.properties){var l=a[s];void 0===l&&(n.push(s),l=n.length-1,a[s]=l),e.writeVarint(l);var c=r.properties[s],u=typeof c;\"string\"!==u&&\"boolean\"!==u&&\"number\"!==u&&(c=JSON.stringify(c));var h=u+\":\"+c,f=o[h];void 0===f&&(i.push(c),f=i.length-1,o[h]=f),e.writeVarint(f)}}function D(t,e){return(e<<3)+(7&t)}function R(t){return t<<1^t>>31}function F(t,e){for(var r=t.loadGeometry(),n=t.type,i=0,a=0,o=r.length,s=0;s<o;s++){var l=r[s],c=1;1===n&&(c=l.length),e.writeVarint(D(1,c));for(var u=3===n?l.length-1:l.length,h=0;h<u;h++){1===h&&1!==n&&e.writeVarint(D(2,u-1));var f=l[h].x-i,p=l[h].y-a;e.writeVarint(R(f)),e.writeVarint(R(p)),i+=f,a+=p}3===n&&e.writeVarint(D(7,1))}}function B(t,e){var r=typeof t;\"string\"===r?e.writeStringField(1,t):\"boolean\"===r?e.writeBooleanField(7,t):\"number\"===r&&(t%1!=0?e.writeDoubleField(3,t):t<0?e.writeSVarintField(6,t):e.writeVarintField(5,t))}function N(t,e,r,n){j(t,r,n),j(e,2*r,2*n),j(e,2*r+1,2*n+1)}function j(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function U(t,e,r,n){var i=t-r,a=e-n;return i*i+a*a}E.fromVectorTileJs=C,E.fromGeojsonVt=function(t,e){e=e||{};var r={};for(var n in t)r[n]=new A(t[n].features,e),r[n].name=n,r[n].version=e.version,r[n].extent=e.extent;return P({layers:r})},E.GeoJSONWrapper=L;var V=function(t){return t[0]},q=function(t){return t[1]},H=function(t,e,r,n,i){void 0===e&&(e=V),void 0===r&&(r=q),void 0===n&&(n=64),void 0===i&&(i=Float64Array),this.nodeSize=n,this.points=t;for(var a=t.length<65536?Uint16Array:Uint32Array,o=this.ids=new a(t.length),s=this.coords=new i(2*t.length),l=0;l<t.length;l++)o[l]=l,s[2*l]=e(t[l]),s[2*l+1]=r(t[l]);!function t(e,r,n,i,a,o){if(!(a-i<=n)){var s=i+a>>1;!function t(e,r,n,i,a,o){for(;a>i;){if(a-i>600){var s=a-i+1,l=n-i+1,c=Math.log(s),u=.5*Math.exp(2*c/3),h=.5*Math.sqrt(c*u*(s-u)/s)*(l-s/2<0?-1:1);t(e,r,n,Math.max(i,Math.floor(n-l*u/s+h)),Math.min(a,Math.floor(n+(s-l)*u/s+h)),o)}var f=r[2*n+o],p=i,d=a;for(N(e,r,i,n),r[2*a+o]>f&&N(e,r,i,a);p<d;){for(N(e,r,p,d),p++,d--;r[2*p+o]<f;)p++;for(;r[2*d+o]>f;)d--}r[2*i+o]===f?N(e,r,i,d):N(e,r,++d,a),d<=n&&(i=d+1),n<=d&&(a=d-1)}}(e,r,s,i,a,o%2),t(e,r,n,i,s-1,o+1),t(e,r,n,s+1,a,o+1)}}(o,s,n,0,o.length-1,0)};H.prototype.range=function(t,e,r,n){return function(t,e,r,n,i,a,o){for(var s,l,c=[0,t.length-1,0],u=[];c.length;){var h=c.pop(),f=c.pop(),p=c.pop();if(f-p<=o)for(var d=p;d<=f;d++)s=e[2*d],l=e[2*d+1],s>=r&&s<=i&&l>=n&&l<=a&&u.push(t[d]);else{var g=Math.floor((p+f)/2);s=e[2*g],l=e[2*g+1],s>=r&&s<=i&&l>=n&&l<=a&&u.push(t[g]);var v=(h+1)%2;(0===h?r<=s:n<=l)&&(c.push(p),c.push(g-1),c.push(v)),(0===h?i>=s:a>=l)&&(c.push(g+1),c.push(f),c.push(v))}}return u}(this.ids,this.coords,t,e,r,n,this.nodeSize)},H.prototype.within=function(t,e,r){return function(t,e,r,n,i,a){for(var o=[0,t.length-1,0],s=[],l=i*i;o.length;){var c=o.pop(),u=o.pop(),h=o.pop();if(u-h<=a)for(var f=h;f<=u;f++)U(e[2*f],e[2*f+1],r,n)<=l&&s.push(t[f]);else{var p=Math.floor((h+u)/2),d=e[2*p],g=e[2*p+1];U(d,g,r,n)<=l&&s.push(t[p]);var v=(c+1)%2;(0===c?r-i<=d:n-i<=g)&&(o.push(h),o.push(p-1),o.push(v)),(0===c?r+i>=d:n+i>=g)&&(o.push(p+1),o.push(u),o.push(v))}}return s}(this.ids,this.coords,t,e,r,this.nodeSize)};var G={minZoom:0,maxZoom:16,radius:40,extent:512,nodeSize:64,log:!1,reduce:null,map:function(t){return t}},Y=function(t){this.options=Q(Object.create(G),t),this.trees=new Array(this.options.maxZoom+1)};function W(t,e,r,n,i){return{x:t,y:e,zoom:1/0,id:r,parentId:-1,numPoints:n,properties:i}}function X(t,e){var r=t.geometry.coordinates,n=r[0],i=r[1];return{x:K(n),y:$(i),zoom:1/0,index:e,parentId:-1}}function Z(t){return{type:\"Feature\",id:t.id,properties:J(t),geometry:{type:\"Point\",coordinates:[(n=t.x,360*(n-.5)),(e=t.y,r=(180-360*e)*Math.PI/180,360*Math.atan(Math.exp(r))/Math.PI-90)]}};var e,r,n}function J(t){var e=t.numPoints,r=e>=1e4?Math.round(e/1e3)+\"k\":e>=1e3?Math.round(e/100)/10+\"k\":e;return Q(Q({},t.properties),{cluster:!0,cluster_id:t.id,point_count:e,point_count_abbreviated:r})}function K(t){return t/360+.5}function $(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function Q(t,e){for(var r in e)t[r]=e[r];return t}function tt(t){return t.x}function et(t){return t.y}function rt(t,e,r,n,i,a){var o=i-r,s=a-n;if(0!==o||0!==s){var l=((t-r)*o+(e-n)*s)/(o*o+s*s);l>1?(r=i,n=a):l>0&&(r+=o*l,n+=s*l)}return(o=t-r)*o+(s=e-n)*s}function nt(t,e,r,n){var i={id:void 0===t?null:t,type:e,geometry:r,tags:n,minX:1/0,minY:1/0,maxX:-1/0,maxY:-1/0};return function(t){var e=t.geometry,r=t.type;if(\"Point\"===r||\"MultiPoint\"===r||\"LineString\"===r)it(t,e);else if(\"Polygon\"===r||\"MultiLineString\"===r)for(var n=0;n<e.length;n++)it(t,e[n]);else if(\"MultiPolygon\"===r)for(n=0;n<e.length;n++)for(var i=0;i<e[n].length;i++)it(t,e[n][i])}(i),i}function it(t,e){for(var r=0;r<e.length;r+=3)t.minX=Math.min(t.minX,e[r]),t.minY=Math.min(t.minY,e[r+1]),t.maxX=Math.max(t.maxX,e[r]),t.maxY=Math.max(t.maxY,e[r+1])}function at(t,e,r,n){if(e.geometry){var i=e.geometry.coordinates,a=e.geometry.type,o=Math.pow(r.tolerance/((1<<r.maxZoom)*r.extent),2),s=[],l=e.id;if(r.promoteId?l=e.properties[r.promoteId]:r.generateId&&(l=n||0),\"Point\"===a)ot(i,s);else if(\"MultiPoint\"===a)for(var c=0;c<i.length;c++)ot(i[c],s);else if(\"LineString\"===a)st(i,s,o,!1);else if(\"MultiLineString\"===a){if(r.lineMetrics){for(c=0;c<i.length;c++)s=[],st(i[c],s,o,!1),t.push(nt(l,\"LineString\",s,e.properties));return}lt(i,s,o,!1)}else if(\"Polygon\"===a)lt(i,s,o,!0);else{if(\"MultiPolygon\"!==a){if(\"GeometryCollection\"===a){for(c=0;c<e.geometry.geometries.length;c++)at(t,{id:l,geometry:e.geometry.geometries[c],properties:e.properties},r,n);return}throw new Error(\"Input data is not a valid GeoJSON object.\")}for(c=0;c<i.length;c++){var u=[];lt(i[c],u,o,!0),s.push(u)}}t.push(nt(l,a,s,e.properties))}}function ot(t,e){e.push(ct(t[0])),e.push(ut(t[1])),e.push(0)}function st(t,e,r,n){for(var i,a,o=0,s=0;s<t.length;s++){var l=ct(t[s][0]),c=ut(t[s][1]);e.push(l),e.push(c),e.push(0),s>0&&(o+=n?(i*c-l*a)/2:Math.sqrt(Math.pow(l-i,2)+Math.pow(c-a,2))),i=l,a=c}var u=e.length-3;e[2]=1,function t(e,r,n,i){for(var a,o=i,s=n-r>>1,l=n-r,c=e[r],u=e[r+1],h=e[n],f=e[n+1],p=r+3;p<n;p+=3){var d=rt(e[p],e[p+1],c,u,h,f);if(d>o)a=p,o=d;else if(d===o){var g=Math.abs(p-s);g<l&&(a=p,l=g)}}o>i&&(a-r>3&&t(e,r,a,i),e[a+2]=o,n-a>3&&t(e,a,n,i))}(e,0,u,r),e[u+2]=1,e.size=Math.abs(o),e.start=0,e.end=e.size}function lt(t,e,r,n){for(var i=0;i<t.length;i++){var a=[];st(t[i],a,r,n),e.push(a)}}function ct(t){return t/360+.5}function ut(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function ht(t,e,r,n,i,a,o,s){if(n/=e,a>=(r/=e)&&o<n)return t;if(o<r||a>=n)return null;for(var l=[],c=0;c<t.length;c++){var u=t[c],h=u.geometry,f=u.type,p=0===i?u.minX:u.minY,d=0===i?u.maxX:u.maxY;if(p>=r&&d<n)l.push(u);else if(!(d<r||p>=n)){var g=[];if(\"Point\"===f||\"MultiPoint\"===f)ft(h,g,r,n,i);else if(\"LineString\"===f)pt(h,g,r,n,i,!1,s.lineMetrics);else if(\"MultiLineString\"===f)gt(h,g,r,n,i,!1);else if(\"Polygon\"===f)gt(h,g,r,n,i,!0);else if(\"MultiPolygon\"===f)for(var v=0;v<h.length;v++){var m=[];gt(h[v],m,r,n,i,!0),m.length&&g.push(m)}if(g.length){if(s.lineMetrics&&\"LineString\"===f){for(v=0;v<g.length;v++)l.push(nt(u.id,f,g[v],u.tags));continue}\"LineString\"!==f&&\"MultiLineString\"!==f||(1===g.length?(f=\"LineString\",g=g[0]):f=\"MultiLineString\"),\"Point\"!==f&&\"MultiPoint\"!==f||(f=3===g.length?\"Point\":\"MultiPoint\"),l.push(nt(u.id,f,g,u.tags))}}}return l.length?l:null}function ft(t,e,r,n,i){for(var a=0;a<t.length;a+=3){var o=t[a+i];o>=r&&o<=n&&(e.push(t[a]),e.push(t[a+1]),e.push(t[a+2]))}}function pt(t,e,r,n,i,a,o){for(var s,l,c=dt(t),u=0===i?mt:yt,h=t.start,f=0;f<t.length-3;f+=3){var p=t[f],d=t[f+1],g=t[f+2],v=t[f+3],m=t[f+4],y=0===i?p:d,x=0===i?v:m,b=!1;o&&(s=Math.sqrt(Math.pow(p-v,2)+Math.pow(d-m,2))),y<r?x>r&&(l=u(c,p,d,v,m,r),o&&(c.start=h+s*l)):y>n?x<n&&(l=u(c,p,d,v,m,n),o&&(c.start=h+s*l)):vt(c,p,d,g),x<r&&y>=r&&(l=u(c,p,d,v,m,r),b=!0),x>n&&y<=n&&(l=u(c,p,d,v,m,n),b=!0),!a&&b&&(o&&(c.end=h+s*l),e.push(c),c=dt(t)),o&&(h+=s)}var _=t.length-3;p=t[_],d=t[_+1],g=t[_+2],(y=0===i?p:d)>=r&&y<=n&&vt(c,p,d,g),_=c.length-3,a&&_>=3&&(c[_]!==c[0]||c[_+1]!==c[1])&&vt(c,c[0],c[1],c[2]),c.length&&e.push(c)}function dt(t){var e=[];return e.size=t.size,e.start=t.start,e.end=t.end,e}function gt(t,e,r,n,i,a){for(var o=0;o<t.length;o++)pt(t[o],e,r,n,i,a,!1)}function vt(t,e,r,n){t.push(e),t.push(r),t.push(n)}function mt(t,e,r,n,i,a){var o=(a-e)/(n-e);return t.push(a),t.push(r+(i-r)*o),t.push(1),o}function yt(t,e,r,n,i,a){var o=(a-r)/(i-r);return t.push(e+(n-e)*o),t.push(a),t.push(1),o}function xt(t,e){for(var r=[],n=0;n<t.length;n++){var i,a=t[n],o=a.type;if(\"Point\"===o||\"MultiPoint\"===o||\"LineString\"===o)i=bt(a.geometry,e);else if(\"MultiLineString\"===o||\"Polygon\"===o){i=[];for(var s=0;s<a.geometry.length;s++)i.push(bt(a.geometry[s],e))}else if(\"MultiPolygon\"===o)for(i=[],s=0;s<a.geometry.length;s++){for(var l=[],c=0;c<a.geometry[s].length;c++)l.push(bt(a.geometry[s][c],e));i.push(l)}r.push(nt(a.id,o,i,a.tags))}return r}function bt(t,e){var r=[];r.size=t.size,void 0!==t.start&&(r.start=t.start,r.end=t.end);for(var n=0;n<t.length;n+=3)r.push(t[n]+e,t[n+1],t[n+2]);return r}function _t(t,e){if(t.transformed)return t;var r,n,i,a=1<<t.z,o=t.x,s=t.y;for(r=0;r<t.features.length;r++){var l=t.features[r],c=l.geometry,u=l.type;if(l.geometry=[],1===u)for(n=0;n<c.length;n+=2)l.geometry.push(wt(c[n],c[n+1],e,a,o,s));else for(n=0;n<c.length;n++){var h=[];for(i=0;i<c[n].length;i+=2)h.push(wt(c[n][i],c[n][i+1],e,a,o,s));l.geometry.push(h)}}return t.transformed=!0,t}function wt(t,e,r,n,i,a){return[Math.round(r*(t*n-i)),Math.round(r*(e*n-a))]}function kt(t,e,r,n,i){for(var a=e===i.maxZoom?0:i.tolerance/((1<<e)*i.extent),o={features:[],numPoints:0,numSimplified:0,numFeatures:0,source:null,x:r,y:n,z:e,transformed:!1,minX:2,minY:1,maxX:-1,maxY:0},s=0;s<t.length;s++){o.numFeatures++,Tt(o,t[s],a,i);var l=t[s].minX,c=t[s].minY,u=t[s].maxX,h=t[s].maxY;l<o.minX&&(o.minX=l),c<o.minY&&(o.minY=c),u>o.maxX&&(o.maxX=u),h>o.maxY&&(o.maxY=h)}return o}function Tt(t,e,r,n){var i=e.geometry,a=e.type,o=[];if(\"Point\"===a||\"MultiPoint\"===a)for(var s=0;s<i.length;s+=3)o.push(i[s]),o.push(i[s+1]),t.numPoints++,t.numSimplified++;else if(\"LineString\"===a)At(o,i,t,r,!1,!1);else if(\"MultiLineString\"===a||\"Polygon\"===a)for(s=0;s<i.length;s++)At(o,i[s],t,r,\"Polygon\"===a,0===s);else if(\"MultiPolygon\"===a)for(var l=0;l<i.length;l++){var c=i[l];for(s=0;s<c.length;s++)At(o,c[s],t,r,!0,0===s)}if(o.length){var u=e.tags||null;if(\"LineString\"===a&&n.lineMetrics){for(var h in u={},e.tags)u[h]=e.tags[h];u.mapbox_clip_start=i.start/i.size,u.mapbox_clip_end=i.end/i.size}var f={geometry:o,type:\"Polygon\"===a||\"MultiPolygon\"===a?3:\"LineString\"===a||\"MultiLineString\"===a?2:1,tags:u};null!==e.id&&(f.id=e.id),t.features.push(f)}}function At(t,e,r,n,i,a){var o=n*n;if(n>0&&e.size<(i?o:n))r.numPoints+=e.length/3;else{for(var s=[],l=0;l<e.length;l+=3)(0===n||e[l+2]>o)&&(r.numSimplified++,s.push(e[l]),s.push(e[l+1])),r.numPoints++;i&&function(t,e){for(var r=0,n=0,i=t.length,a=i-2;n<i;a=n,n+=2)r+=(t[n]-t[a])*(t[n+1]+t[a+1]);if(r>0===e)for(n=0,i=t.length;n<i/2;n+=2){var o=t[n],s=t[n+1];t[n]=t[i-2-n],t[n+1]=t[i-1-n],t[i-2-n]=o,t[i-1-n]=s}}(s,a),t.push(s)}}function Mt(t,e){var r=(e=this.options=function(t,e){for(var r in e)t[r]=e[r];return t}(Object.create(this.options),e)).debug;if(r&&console.time(\"preprocess data\"),e.maxZoom<0||e.maxZoom>24)throw new Error(\"maxZoom should be in the 0-24 range\");if(e.promoteId&&e.generateId)throw new Error(\"promoteId and generateId cannot be used together.\");var n=function(t,e){var r=[];if(\"FeatureCollection\"===t.type)for(var n=0;n<t.features.length;n++)at(r,t.features[n],e,n);else\"Feature\"===t.type?at(r,t,e):at(r,{geometry:t},e);return r}(t,e);this.tiles={},this.tileCoords=[],r&&(console.timeEnd(\"preprocess data\"),console.log(\"index: maxZoom: %d, maxPoints: %d\",e.indexMaxZoom,e.indexMaxPoints),console.time(\"generate tiles\"),this.stats={},this.total=0),(n=function(t,e){var r=e.buffer/e.extent,n=t,i=ht(t,1,-1-r,r,0,-1,2,e),a=ht(t,1,1-r,2+r,0,-1,2,e);return(i||a)&&(n=ht(t,1,-r,1+r,0,-1,2,e)||[],i&&(n=xt(i,1).concat(n)),a&&(n=n.concat(xt(a,-1)))),n}(n,e)).length&&this.splitTile(n,0,0,0),r&&(n.length&&console.log(\"features: %d, points: %d\",this.tiles[0].numFeatures,this.tiles[0].numPoints),console.timeEnd(\"generate tiles\"),console.log(\"tiles generated:\",this.total,JSON.stringify(this.stats)))}function St(t,e,r){return 32*((1<<t)*r+e)+t}function Et(t,e){var r=t.tileID.canonical;if(!this._geoJSONIndex)return e(null,null);var n=this._geoJSONIndex.getTile(r.z,r.x,r.y);if(!n)return e(null,null);var i=new k(n.features),a=E(i);0===a.byteOffset&&a.byteLength===a.buffer.byteLength||(a=new Uint8Array(a)),e(null,{vectorTile:i,rawData:a.buffer})}Y.prototype.load=function(t){var e=this.options,r=e.log,n=e.minZoom,i=e.maxZoom,a=e.nodeSize;r&&console.time(\"total time\");var o=\"prepare \"+t.length+\" points\";r&&console.time(o),this.points=t;for(var s=[],l=0;l<t.length;l++)t[l].geometry&&s.push(X(t[l],l));this.trees[i+1]=new H(s,tt,et,a,Float32Array),r&&console.timeEnd(o);for(var c=i;c>=n;c--){var u=+Date.now();s=this._cluster(s,c),this.trees[c]=new H(s,tt,et,a,Float32Array),r&&console.log(\"z%d: %d clusters in %dms\",c,s.length,+Date.now()-u)}return r&&console.timeEnd(\"total time\"),this},Y.prototype.getClusters=function(t,e){var r=((t[0]+180)%360+360)%360-180,n=Math.max(-90,Math.min(90,t[1])),i=180===t[2]?180:((t[2]+180)%360+360)%360-180,a=Math.max(-90,Math.min(90,t[3]));if(t[2]-t[0]>=360)r=-180,i=180;else if(r>i){var o=this.getClusters([r,n,180,a],e),s=this.getClusters([-180,n,i,a],e);return o.concat(s)}for(var l=this.trees[this._limitZoom(e)],c=[],u=0,h=l.range(K(r),$(a),K(i),$(n));u<h.length;u+=1){var f=h[u],p=l.points[f];c.push(p.numPoints?Z(p):this.points[p.index])}return c},Y.prototype.getChildren=function(t){var e=t>>5,r=t%32,n=\"No cluster with the specified id.\",i=this.trees[r];if(!i)throw new Error(n);var a=i.points[e];if(!a)throw new Error(n);for(var o=this.options.radius/(this.options.extent*Math.pow(2,r-1)),s=[],l=0,c=i.within(a.x,a.y,o);l<c.length;l+=1){var u=c[l],h=i.points[u];h.parentId===t&&s.push(h.numPoints?Z(h):this.points[h.index])}if(0===s.length)throw new Error(n);return s},Y.prototype.getLeaves=function(t,e,r){e=e||10,r=r||0;var n=[];return this._appendLeaves(n,t,e,r,0),n},Y.prototype.getTile=function(t,e,r){var n=this.trees[this._limitZoom(t)],i=Math.pow(2,t),a=this.options,o=a.extent,s=a.radius/o,l=(r-s)/i,c=(r+1+s)/i,u={features:[]};return this._addTileFeatures(n.range((e-s)/i,l,(e+1+s)/i,c),n.points,e,r,i,u),0===e&&this._addTileFeatures(n.range(1-s/i,l,1,c),n.points,i,r,i,u),e===i-1&&this._addTileFeatures(n.range(0,l,s/i,c),n.points,-1,r,i,u),u.features.length?u:null},Y.prototype.getClusterExpansionZoom=function(t){for(var e=t%32-1;e<=this.options.maxZoom;){var r=this.getChildren(t);if(e++,1!==r.length)break;t=r[0].properties.cluster_id}return e},Y.prototype._appendLeaves=function(t,e,r,n,i){for(var a=0,o=this.getChildren(e);a<o.length;a+=1){var s=o[a],l=s.properties;if(l&&l.cluster?i+l.point_count<=n?i+=l.point_count:i=this._appendLeaves(t,l.cluster_id,r,n,i):i<n?i++:t.push(s),t.length===r)break}return i},Y.prototype._addTileFeatures=function(t,e,r,n,i,a){for(var o=0,s=t;o<s.length;o+=1){var l=e[s[o]],c={type:1,geometry:[[Math.round(this.options.extent*(l.x*i-r)),Math.round(this.options.extent*(l.y*i-n))]],tags:l.numPoints?J(l):this.points[l.index].properties},u=l.numPoints?l.id:this.points[l.index].id;void 0!==u&&(c.id=u),a.features.push(c)}},Y.prototype._limitZoom=function(t){return Math.max(this.options.minZoom,Math.min(t,this.options.maxZoom+1))},Y.prototype._cluster=function(t,e){for(var r=[],n=this.options,i=n.radius,a=n.extent,o=n.reduce,s=i/(a*Math.pow(2,e)),l=0;l<t.length;l++){var c=t[l];if(!(c.zoom<=e)){c.zoom=e;for(var u=this.trees[e+1],h=u.within(c.x,c.y,s),f=c.numPoints||1,p=c.x*f,d=c.y*f,g=o?this._map(c,!0):null,v=(l<<5)+(e+1),m=0,y=h;m<y.length;m+=1){var x=y[m],b=u.points[x];if(!(b.zoom<=e)){b.zoom=e;var _=b.numPoints||1;p+=b.x*_,d+=b.y*_,f+=_,b.parentId=v,o&&o(g,this._map(b))}}1===f?r.push(c):(c.parentId=v,r.push(W(p/f,d/f,v,f,g)))}}return r},Y.prototype._map=function(t,e){if(t.numPoints)return e?Q({},t.properties):t.properties;var r=this.points[t.index].properties,n=this.options.map(r);return e&&n===r?Q({},n):n},Mt.prototype.options={maxZoom:14,indexMaxZoom:5,indexMaxPoints:1e5,tolerance:3,extent:4096,buffer:64,lineMetrics:!1,promoteId:null,generateId:!1,debug:0},Mt.prototype.splitTile=function(t,e,r,n,i,a,o){for(var s=[t,e,r,n],l=this.options,c=l.debug;s.length;){n=s.pop(),r=s.pop(),e=s.pop(),t=s.pop();var u=1<<e,h=St(e,r,n),f=this.tiles[h];if(!f&&(c>1&&console.time(\"creation\"),f=this.tiles[h]=kt(t,e,r,n,l),this.tileCoords.push({z:e,x:r,y:n}),c)){c>1&&(console.log(\"tile z%d-%d-%d (features: %d, points: %d, simplified: %d)\",e,r,n,f.numFeatures,f.numPoints,f.numSimplified),console.timeEnd(\"creation\"));var p=\"z\"+e;this.stats[p]=(this.stats[p]||0)+1,this.total++}if(f.source=t,i){if(e===l.maxZoom||e===i)continue;var d=1<<i-e;if(r!==Math.floor(a/d)||n!==Math.floor(o/d))continue}else if(e===l.indexMaxZoom||f.numPoints<=l.indexMaxPoints)continue;if(f.source=null,0!==t.length){c>1&&console.time(\"clipping\");var g,v,m,y,x,b,_=.5*l.buffer/l.extent,w=.5-_,k=.5+_,T=1+_;g=v=m=y=null,x=ht(t,u,r-_,r+k,0,f.minX,f.maxX,l),b=ht(t,u,r+w,r+T,0,f.minX,f.maxX,l),t=null,x&&(g=ht(x,u,n-_,n+k,1,f.minY,f.maxY,l),v=ht(x,u,n+w,n+T,1,f.minY,f.maxY,l),x=null),b&&(m=ht(b,u,n-_,n+k,1,f.minY,f.maxY,l),y=ht(b,u,n+w,n+T,1,f.minY,f.maxY,l),b=null),c>1&&console.timeEnd(\"clipping\"),s.push(g||[],e+1,2*r,2*n),s.push(v||[],e+1,2*r,2*n+1),s.push(m||[],e+1,2*r+1,2*n),s.push(y||[],e+1,2*r+1,2*n+1)}}},Mt.prototype.getTile=function(t,e,r){var n=this.options,i=n.extent,a=n.debug;if(t<0||t>24)return null;var o=1<<t,s=St(t,e=(e%o+o)%o,r);if(this.tiles[s])return _t(this.tiles[s],i);a>1&&console.log(\"drilling down to z%d-%d-%d\",t,e,r);for(var l,c=t,u=e,h=r;!l&&c>0;)c--,u=Math.floor(u/2),h=Math.floor(h/2),l=this.tiles[St(c,u,h)];return l&&l.source?(a>1&&console.log(\"found parent tile z%d-%d-%d\",c,u,h),a>1&&console.time(\"drilling down\"),this.splitTile(l.source,c,u,h,t,e,r),a>1&&console.timeEnd(\"drilling down\"),this.tiles[s]?_t(this.tiles[s],i):null):null};var Ct=function(e){function r(t,r,n){e.call(this,t,r,Et),n&&(this.loadGeoJSON=n)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadData=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),this._pendingCallback=e,this._pendingLoadDataParams=t,this._state&&\"Idle\"!==this._state?this._state=\"NeedsLoadData\":(this._state=\"Coalescing\",this._loadData())},r.prototype._loadData=function(){var e=this;if(this._pendingCallback&&this._pendingLoadDataParams){var r=this._pendingCallback,n=this._pendingLoadDataParams;delete this._pendingCallback,delete this._pendingLoadDataParams;var i=!!(n&&n.request&&n.request.collectResourceTiming)&&new l.Performance(n.request);this.loadGeoJSON(n,function(a,o){if(a||!o)return r(a);if(\"object\"!=typeof o)return r(new Error(\"Input data given to '\"+n.source+\"' is not a valid GeoJSON object.\"));!function t(e,r){switch(e&&e.type||null){case\"FeatureCollection\":return e.features=e.features.map(y(t,r)),e;case\"GeometryCollection\":return e.geometries=e.geometries.map(y(t,r)),e;case\"Feature\":return e.geometry=t(e.geometry,r),e;case\"Polygon\":case\"MultiPolygon\":return function(t,e){return\"Polygon\"===t.type?t.coordinates=x(t.coordinates,e):\"MultiPolygon\"===t.type&&(t.coordinates=t.coordinates.map(y(x,e))),t}(e,r);default:return e}}(o,!0);try{e._geoJSONIndex=n.cluster?new Y(function(e){var r=e.superclusterOptions,n=e.clusterProperties;if(!n||!r)return r;for(var i={},a={},o={accumulated:null,zoom:0},s={properties:null},l=Object.keys(n),c=0,u=l;c<u.length;c+=1){var h=u[c],f=n[h],p=f[0],d=f[1],g=t.createExpression(d),v=t.createExpression(\"string\"==typeof p?[p,[\"accumulated\"],[\"get\",h]]:p);i[h]=g.value,a[h]=v.value}return r.map=function(t){s.properties=t;for(var e={},r=0,n=l;r<n.length;r+=1){var a=n[r];e[a]=i[a].evaluate(o,s)}return e},r.reduce=function(t,e){s.properties=e;for(var r=0,n=l;r<n.length;r+=1){var i=n[r];o.accumulated=t[i],t[i]=a[i].evaluate(o,s)}},r}(n)).load(o.features):new Mt(o,n.geojsonVtOptions)}catch(a){return r(a)}e.loaded={};var s={};if(i){var l=i.finish();l&&(s.resourceTiming={},s.resourceTiming[n.source]=JSON.parse(JSON.stringify(l)))}r(null,s)})}},r.prototype.coalesce=function(){\"Coalescing\"===this._state?this._state=\"Idle\":\"NeedsLoadData\"===this._state&&(this._state=\"Coalescing\",this._loadData())},r.prototype.reloadTile=function(t,r){var n=this.loaded,i=t.uid;return n&&n[i]?e.prototype.reloadTile.call(this,t,r):this.loadTile(t,r)},r.prototype.loadGeoJSON=function(e,r){if(e.request)t.getJSON(e.request,r);else{if(\"string\"!=typeof e.data)return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"));try{return r(null,JSON.parse(e.data))}catch(t){return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"))}}},r.prototype.removeSource=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),e()},r.prototype.getClusterExpansionZoom=function(t,e){e(null,this._geoJSONIndex.getClusterExpansionZoom(t.clusterId))},r.prototype.getClusterChildren=function(t,e){e(null,this._geoJSONIndex.getChildren(t.clusterId))},r.prototype.getClusterLeaves=function(t,e){e(null,this._geoJSONIndex.getLeaves(t.clusterId,t.limit,t.offset))},r}(h),Lt=function(e){var r=this;this.self=e,this.actor=new t.Actor(e,this),this.layerIndexes={},this.workerSourceTypes={vector:h,geojson:Ct},this.workerSources={},this.demWorkerSources={},this.self.registerWorkerSource=function(t,e){if(r.workerSourceTypes[t])throw new Error('Worker source with name \"'+t+'\" already registered.');r.workerSourceTypes[t]=e},this.self.registerRTLTextPlugin=function(e){if(t.plugin.isLoaded())throw new Error(\"RTL text plugin already registered.\");t.plugin.applyArabicShaping=e.applyArabicShaping,t.plugin.processBidirectionalText=e.processBidirectionalText,t.plugin.processStyledBidirectionalText=e.processStyledBidirectionalText}};return Lt.prototype.setReferrer=function(t,e){this.referrer=e},Lt.prototype.setLayers=function(t,e,r){this.getLayerIndex(t).replace(e),r()},Lt.prototype.updateLayers=function(t,e,r){this.getLayerIndex(t).update(e.layers,e.removedIds),r()},Lt.prototype.loadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).loadTile(e,r)},Lt.prototype.loadDEMTile=function(t,e,r){this.getDEMWorkerSource(t,e.source).loadTile(e,r)},Lt.prototype.reloadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).reloadTile(e,r)},Lt.prototype.abortTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).abortTile(e,r)},Lt.prototype.removeTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).removeTile(e,r)},Lt.prototype.removeDEMTile=function(t,e){this.getDEMWorkerSource(t,e.source).removeTile(e)},Lt.prototype.removeSource=function(t,e,r){if(this.workerSources[t]&&this.workerSources[t][e.type]&&this.workerSources[t][e.type][e.source]){var n=this.workerSources[t][e.type][e.source];delete this.workerSources[t][e.type][e.source],void 0!==n.removeSource?n.removeSource(e,r):r()}},Lt.prototype.loadWorkerSource=function(t,e,r){try{this.self.importScripts(e.url),r()}catch(t){r(t.toString())}},Lt.prototype.loadRTLTextPlugin=function(e,r,n){try{t.plugin.isLoaded()||(this.self.importScripts(r),n(t.plugin.isLoaded()?null:new Error(\"RTL Text Plugin failed to import scripts from \"+r)))}catch(t){n(t.toString())}},Lt.prototype.getLayerIndex=function(t){var e=this.layerIndexes[t];return e||(e=this.layerIndexes[t]=new n),e},Lt.prototype.getWorkerSource=function(t,e,r){var n=this;if(this.workerSources[t]||(this.workerSources[t]={}),this.workerSources[t][e]||(this.workerSources[t][e]={}),!this.workerSources[t][e][r]){var i={send:function(e,r,i){n.actor.send(e,r,i,t)}};this.workerSources[t][e][r]=new this.workerSourceTypes[e](i,this.getLayerIndex(t))}return this.workerSources[t][e][r]},Lt.prototype.getDEMWorkerSource=function(t,e){return this.demWorkerSources[t]||(this.demWorkerSources[t]={}),this.demWorkerSources[t][e]||(this.demWorkerSources[t][e]=new f),this.demWorkerSources[t][e]},Lt.prototype.enforceCacheSizeLimit=function(e,r){t.enforceCacheSizeLimit(r)},\"undefined\"!=typeof WorkerGlobalScope&&void 0!==t.window&&t.window instanceof WorkerGlobalScope&&(t.window.worker=new Lt(t.window)),Lt}),n(0,function(t){var e=t.createCommonjsModule(function(t){function e(t){return!!(\"undefined\"!=typeof window&&\"undefined\"!=typeof document&&Array.prototype&&Array.prototype.every&&Array.prototype.filter&&Array.prototype.forEach&&Array.prototype.indexOf&&Array.prototype.lastIndexOf&&Array.prototype.map&&Array.prototype.some&&Array.prototype.reduce&&Array.prototype.reduceRight&&Array.isArray&&Function.prototype&&Function.prototype.bind&&Object.keys&&Object.create&&Object.getPrototypeOf&&Object.getOwnPropertyNames&&Object.isSealed&&Object.isFrozen&&Object.isExtensible&&Object.getOwnPropertyDescriptor&&Object.defineProperty&&Object.defineProperties&&Object.seal&&Object.freeze&&Object.preventExtensions&&\"JSON\"in window&&\"parse\"in JSON&&\"stringify\"in JSON&&function(){if(!(\"Worker\"in window&&\"Blob\"in window&&\"URL\"in window))return!1;var t,e,r=new Blob([\"\"],{type:\"text/javascript\"}),n=URL.createObjectURL(r);try{e=new Worker(n),t=!0}catch(e){t=!1}return e&&e.terminate(),URL.revokeObjectURL(n),t}()&&\"Uint8ClampedArray\"in window&&ArrayBuffer.isView&&function(t){return void 0===r[t]&&(r[t]=function(t){var r=document.createElement(\"canvas\"),n=Object.create(e.webGLContextAttributes);return n.failIfMajorPerformanceCaveat=t,r.probablySupportsContext?r.probablySupportsContext(\"webgl\",n)||r.probablySupportsContext(\"experimental-webgl\",n):r.supportsContext?r.supportsContext(\"webgl\",n)||r.supportsContext(\"experimental-webgl\",n):r.getContext(\"webgl\",n)||r.getContext(\"experimental-webgl\",n)}(t)),r[t]}(t&&t.failIfMajorPerformanceCaveat))}t.exports?t.exports=e:window&&(window.mapboxgl=window.mapboxgl||{},window.mapboxgl.supported=e);var r={};e.webGLContextAttributes={antialias:!1,alpha:!0,stencil:!0,depth:!0}}),r={create:function(e,r,n){var i=t.window.document.createElement(e);return void 0!==r&&(i.className=r),n&&n.appendChild(i),i},createNS:function(e,r){return t.window.document.createElementNS(e,r)}},n=t.window.document.documentElement.style;function i(t){if(!n)return t[0];for(var e=0;e<t.length;e++)if(t[e]in n)return t[e];return t[0]}var a,o=i([\"userSelect\",\"MozUserSelect\",\"WebkitUserSelect\",\"msUserSelect\"]);r.disableDrag=function(){n&&o&&(a=n[o],n[o]=\"none\")},r.enableDrag=function(){n&&o&&(n[o]=a)};var s=i([\"transform\",\"WebkitTransform\"]);r.setTransform=function(t,e){t.style[s]=e};var l=!1;try{var c=Object.defineProperty({},\"passive\",{get:function(){l=!0}});t.window.addEventListener(\"test\",c,c),t.window.removeEventListener(\"test\",c,c)}catch(t){l=!1}r.addEventListener=function(t,e,r,n){void 0===n&&(n={}),\"passive\"in n&&l?t.addEventListener(e,r,n):t.addEventListener(e,r,n.capture)},r.removeEventListener=function(t,e,r,n){void 0===n&&(n={}),\"passive\"in n&&l?t.removeEventListener(e,r,n):t.removeEventListener(e,r,n.capture)};var u=function(e){e.preventDefault(),e.stopPropagation(),t.window.removeEventListener(\"click\",u,!0)};function h(t){var e=t.userImage;return!!(e&&e.render&&e.render())&&(t.data.replace(new Uint8Array(e.data.buffer)),!0)}r.suppressClick=function(){t.window.addEventListener(\"click\",u,!0),t.window.setTimeout(function(){t.window.removeEventListener(\"click\",u,!0)},0)},r.mousePos=function(e,r){var n=e.getBoundingClientRect(),i=t.window.TouchEvent&&r instanceof t.window.TouchEvent?r.touches[0]:r;return new t.Point(i.clientX-n.left-e.clientLeft,i.clientY-n.top-e.clientTop)},r.touchPos=function(e,r){for(var n=e.getBoundingClientRect(),i=[],a=\"touchend\"===r.type?r.changedTouches:r.touches,o=0;o<a.length;o++)i.push(new t.Point(a[o].clientX-n.left-e.clientLeft,a[o].clientY-n.top-e.clientTop));return i},r.mouseButton=function(e){return void 0!==t.window.InstallTrigger&&2===e.button&&e.ctrlKey&&t.window.navigator.platform.toUpperCase().indexOf(\"MAC\")>=0?0:e.button},r.remove=function(t){t.parentNode&&t.parentNode.removeChild(t)};var f=function(e){function r(){e.call(this),this.images={},this.updatedImages={},this.callbackDispatchedThisFrame={},this.loaded=!1,this.requestors=[],this.patterns={},this.atlasImage=new t.RGBAImage({width:1,height:1}),this.dirty=!0}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.isLoaded=function(){return this.loaded},r.prototype.setLoaded=function(t){if(this.loaded!==t&&(this.loaded=t,t)){for(var e=0,r=this.requestors;e<r.length;e+=1){var n=r[e],i=n.ids,a=n.callback;this._notify(i,a)}this.requestors=[]}},r.prototype.getImage=function(t){return this.images[t]},r.prototype.addImage=function(t,e){this.images[t]=e},r.prototype.updateImage=function(t,e){var r=this.images[t];e.version=r.version+1,this.images[t]=e,this.updatedImages[t]=!0},r.prototype.removeImage=function(t){var e=this.images[t];delete this.images[t],delete this.patterns[t],e.userImage&&e.userImage.onRemove&&e.userImage.onRemove()},r.prototype.listImages=function(){return Object.keys(this.images)},r.prototype.getImages=function(t,e){var r=!0;if(!this.isLoaded())for(var n=0,i=t;n<i.length;n+=1){var a=i[n];this.images[a]||(r=!1)}this.isLoaded()||r?this._notify(t,e):this.requestors.push({ids:t,callback:e})},r.prototype._notify=function(e,r){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i];this.images[o]||this.fire(new t.Event(\"styleimagemissing\",{id:o}));var s=this.images[o];s?n[o]={data:s.data.clone(),pixelRatio:s.pixelRatio,sdf:s.sdf,version:s.version,hasRenderCallback:Boolean(s.userImage&&s.userImage.render)}:t.warnOnce('Image \"'+o+'\" could not be loaded. Please make sure you have added the image with map.addImage() or a \"sprite\" property in your style. You can provide missing images by listening for the \"styleimagemissing\" map event.')}r(null,n)},r.prototype.getPixelSize=function(){var t=this.atlasImage;return{width:t.width,height:t.height}},r.prototype.getPattern=function(e){var r=this.patterns[e],n=this.getImage(e);if(!n)return null;if(r&&r.position.version===n.version)return r.position;if(r)r.position.version=n.version;else{var i={w:n.data.width+2,h:n.data.height+2,x:0,y:0},a=new t.ImagePosition(i,n);this.patterns[e]={bin:i,position:a}}return this._updatePatternAtlas(),this.patterns[e].position},r.prototype.bind=function(e){var r=e.gl;this.atlasTexture?this.dirty&&(this.atlasTexture.update(this.atlasImage),this.dirty=!1):this.atlasTexture=new t.Texture(e,this.atlasImage,r.RGBA),this.atlasTexture.bind(r.LINEAR,r.CLAMP_TO_EDGE)},r.prototype._updatePatternAtlas=function(){var e=[];for(var r in this.patterns)e.push(this.patterns[r].bin);var n=t.potpack(e),i=n.w,a=n.h,o=this.atlasImage;for(var s in o.resize({width:i||1,height:a||1}),this.patterns){var l=this.patterns[s].bin,c=l.x+1,u=l.y+1,h=this.images[s].data,f=h.width,p=h.height;t.RGBAImage.copy(h,o,{x:0,y:0},{x:c,y:u},{width:f,height:p}),t.RGBAImage.copy(h,o,{x:0,y:p-1},{x:c,y:u-1},{width:f,height:1}),t.RGBAImage.copy(h,o,{x:0,y:0},{x:c,y:u+p},{width:f,height:1}),t.RGBAImage.copy(h,o,{x:f-1,y:0},{x:c-1,y:u},{width:1,height:p}),t.RGBAImage.copy(h,o,{x:0,y:0},{x:c+f,y:u},{width:1,height:p})}this.dirty=!0},r.prototype.beginFrame=function(){this.callbackDispatchedThisFrame={}},r.prototype.dispatchRenderCallbacks=function(t){for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!this.callbackDispatchedThisFrame[n]){this.callbackDispatchedThisFrame[n]=!0;var i=this.images[n];h(i)&&this.updateImage(n,i)}}},r}(t.Evented),p=g,d=1e20;function g(t,e,r,n,i,a){this.fontSize=t||24,this.buffer=void 0===e?3:e,this.cutoff=n||.25,this.fontFamily=i||\"sans-serif\",this.fontWeight=a||\"normal\",this.radius=r||8;var o=this.size=this.fontSize+2*this.buffer;this.canvas=document.createElement(\"canvas\"),this.canvas.width=this.canvas.height=o,this.ctx=this.canvas.getContext(\"2d\"),this.ctx.font=this.fontWeight+\" \"+this.fontSize+\"px \"+this.fontFamily,this.ctx.textBaseline=\"middle\",this.ctx.fillStyle=\"black\",this.gridOuter=new Float64Array(o*o),this.gridInner=new Float64Array(o*o),this.f=new Float64Array(o),this.d=new Float64Array(o),this.z=new Float64Array(o+1),this.v=new Int16Array(o),this.middle=Math.round(o/2*(navigator.userAgent.indexOf(\"Gecko/\")>=0?1.2:1))}function v(t,e,r,n,i,a,o){for(var s=0;s<e;s++){for(var l=0;l<r;l++)n[l]=t[l*e+s];for(m(n,i,a,o,r),l=0;l<r;l++)t[l*e+s]=i[l]}for(l=0;l<r;l++){for(s=0;s<e;s++)n[s]=t[l*e+s];for(m(n,i,a,o,e),s=0;s<e;s++)t[l*e+s]=Math.sqrt(i[s])}}function m(t,e,r,n,i){r[0]=0,n[0]=-d,n[1]=+d;for(var a=1,o=0;a<i;a++){for(var s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);s<=n[o];)o--,s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);r[++o]=a,n[o]=s,n[o+1]=+d}for(a=0,o=0;a<i;a++){for(;n[o+1]<a;)o++;e[a]=(a-r[o])*(a-r[o])+t[r[o]]}}g.prototype.draw=function(t){this.ctx.clearRect(0,0,this.size,this.size),this.ctx.fillText(t,this.buffer,this.middle);for(var e=this.ctx.getImageData(0,0,this.size,this.size),r=new Uint8ClampedArray(this.size*this.size),n=0;n<this.size*this.size;n++){var i=e.data[4*n+3]/255;this.gridOuter[n]=1===i?0:0===i?d:Math.pow(Math.max(0,.5-i),2),this.gridInner[n]=1===i?d:0===i?0:Math.pow(Math.max(0,i-.5),2)}for(v(this.gridOuter,this.size,this.size,this.f,this.d,this.v,this.z),v(this.gridInner,this.size,this.size,this.f,this.d,this.v,this.z),n=0;n<this.size*this.size;n++){var a=this.gridOuter[n]-this.gridInner[n];r[n]=Math.max(0,Math.min(255,Math.round(255-255*(a/this.radius+this.cutoff))))}return r};var y=function(t,e){this.requestManager=t,this.localIdeographFontFamily=e,this.entries={}};y.prototype.setURL=function(t){this.url=t},y.prototype.getGlyphs=function(e,r){var n=this,i=[];for(var a in e)for(var o=0,s=e[a];o<s.length;o+=1){var l=s[o];i.push({stack:a,id:l})}t.asyncAll(i,function(t,e){var r=t.stack,i=t.id,a=n.entries[r];a||(a=n.entries[r]={glyphs:{},requests:{}});var o=a.glyphs[i];if(void 0===o)if(o=n._tinySDF(a,r,i))e(null,{stack:r,id:i,glyph:o});else{var s=Math.floor(i/256);if(256*s>65535)e(new Error(\"glyphs > 65535 not supported\"));else{var l=a.requests[s];l||(l=a.requests[s]=[],y.loadGlyphRange(r,s,n.url,n.requestManager,function(t,e){if(e)for(var r in e)a.glyphs[+r]=e[+r];for(var n=0,i=l;n<i.length;n+=1)(0,i[n])(t,e);delete a.requests[s]})),l.push(function(t,n){t?e(t):n&&e(null,{stack:r,id:i,glyph:n[i]||null})})}}else e(null,{stack:r,id:i,glyph:o})},function(t,e){if(t)r(t);else if(e){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.stack,l=o.id,c=o.glyph;(n[s]||(n[s]={}))[l]=c&&{id:c.id,bitmap:c.bitmap.clone(),metrics:c.metrics}}r(null,n)}})},y.prototype._tinySDF=function(e,r,n){var i=this.localIdeographFontFamily;if(i&&(t.isChar[\"CJK Unified Ideographs\"](n)||t.isChar[\"Hangul Syllables\"](n)||t.isChar.Hiragana(n)||t.isChar.Katakana(n))){var a=e.tinySDF;if(!a){var o=\"400\";/bold/i.test(r)?o=\"900\":/medium/i.test(r)?o=\"500\":/light/i.test(r)&&(o=\"200\"),a=e.tinySDF=new y.TinySDF(24,3,8,.25,i,o)}return{id:n,bitmap:new t.AlphaImage({width:30,height:30},a.draw(String.fromCharCode(n))),metrics:{width:24,height:24,left:0,top:-8,advance:24}}}},y.loadGlyphRange=function(e,r,n,i,a){var o=256*r,s=o+255,l=i.transformRequest(i.normalizeGlyphsURL(n).replace(\"{fontstack}\",e).replace(\"{range}\",o+\"-\"+s),t.ResourceType.Glyphs);t.getArrayBuffer(l,function(e,r){if(e)a(e);else if(r){for(var n={},i=0,o=t.parseGlyphPBF(r);i<o.length;i+=1){var s=o[i];n[s.id]=s}a(null,n)}})},y.TinySDF=p;var x=function(){this.specification=t.styleSpec.light.position};x.prototype.possiblyEvaluate=function(e,r){return t.sphericalToCartesian(e.expression.evaluate(r))},x.prototype.interpolate=function(e,r,n){return{x:t.number(e.x,r.x,n),y:t.number(e.y,r.y,n),z:t.number(e.z,r.z,n)}};var b=new t.Properties({anchor:new t.DataConstantProperty(t.styleSpec.light.anchor),position:new x,color:new t.DataConstantProperty(t.styleSpec.light.color),intensity:new t.DataConstantProperty(t.styleSpec.light.intensity)}),_=function(e){function r(r){e.call(this),this._transitionable=new t.Transitionable(b),this.setLight(r),this._transitioning=this._transitionable.untransitioned()}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getLight=function(){return this._transitionable.serialize()},r.prototype.setLight=function(e,r){if(void 0===r&&(r={}),!this._validate(t.validateLight,e,r))for(var n in e){var i=e[n];t.endsWith(n,\"-transition\")?this._transitionable.setTransition(n.slice(0,-\"-transition\".length),i):this._transitionable.setValue(n,i)}},r.prototype.updateTransitions=function(t){this._transitioning=this._transitionable.transitioned(t,this._transitioning)},r.prototype.hasTransition=function(){return this._transitioning.hasTransition()},r.prototype.recalculate=function(t){this.properties=this._transitioning.possiblyEvaluate(t)},r.prototype._validate=function(e,r,n){return(!n||!1!==n.validate)&&t.emitValidationErrors(this,e.call(t.validateStyle,t.extend({value:r,style:{glyphs:!0,sprite:!0},styleSpec:t.styleSpec})))},r}(t.Evented),w=function(t,e){this.width=t,this.height=e,this.nextRow=0,this.bytes=4,this.data=new Uint8Array(this.width*this.height*this.bytes),this.positions={}};w.prototype.getDash=function(t,e){var r=t.join(\",\")+String(e);return this.positions[r]||(this.positions[r]=this.addDash(t,e)),this.positions[r]},w.prototype.addDash=function(e,r){var n=r?7:0,i=2*n+1;if(this.nextRow+i>this.height)return t.warnOnce(\"LineAtlas out of space\"),null;for(var a=0,o=0;o<e.length;o++)a+=e[o];for(var s=this.width/a,l=s/2,c=e.length%2==1,u=-n;u<=n;u++)for(var h=this.nextRow+n+u,f=this.width*h,p=c?-e[e.length-1]:0,d=e[0],g=1,v=0;v<this.width;v++){for(;d<v/s;)p=d,d+=e[g],c&&g===e.length-1&&(d+=e[0]),g++;var m=Math.abs(v-p*s),y=Math.abs(v-d*s),x=Math.min(m,y),b=g%2==1,_=void 0;if(r){var w=n?u/n*(l+1):0;if(b){var k=l-Math.abs(w);_=Math.sqrt(x*x+k*k)}else _=l-Math.sqrt(x*x+w*w)}else _=(b?1:-1)*x;this.data[3+4*(f+v)]=Math.max(0,Math.min(255,_+128))}var T={y:(this.nextRow+n+.5)/this.height,height:2*n/this.height,width:a};return this.nextRow+=i,this.dirty=!0,T},w.prototype.bind=function(t){var e=t.gl;this.texture?(e.bindTexture(e.TEXTURE_2D,this.texture),this.dirty&&(this.dirty=!1,e.texSubImage2D(e.TEXTURE_2D,0,0,0,this.width,this.height,e.RGBA,e.UNSIGNED_BYTE,this.data))):(this.texture=e.createTexture(),e.bindTexture(e.TEXTURE_2D,this.texture),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_S,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_T,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,e.LINEAR),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,e.LINEAR),e.texImage2D(e.TEXTURE_2D,0,e.RGBA,this.width,this.height,0,e.RGBA,e.UNSIGNED_BYTE,this.data))};var k=function e(r,n){this.workerPool=r,this.actors=[],this.currentActor=0,this.id=t.uniqueId();for(var i=this.workerPool.acquire(this.id),a=0;a<i.length;a++){var o=i[a],s=new e.Actor(o,n,this.id);s.name=\"Worker \"+a,this.actors.push(s)}};function T(e,r,n){var i=function(i,a){if(i)return n(i);if(a){var o=t.pick(a,[\"tiles\",\"minzoom\",\"maxzoom\",\"attribution\",\"mapbox_logo\",\"bounds\"]);a.vector_layers&&(o.vectorLayers=a.vector_layers,o.vectorLayerIds=o.vectorLayers.map(function(t){return t.id})),e.url&&(o.tiles=r.canonicalizeTileset(o,e.url)),n(null,o)}};return e.url?t.getJSON(r.transformRequest(r.normalizeSourceURL(e.url),t.ResourceType.Source),i):t.browser.frame(function(){return i(null,e)})}k.prototype.broadcast=function(e,r,n){n=n||function(){},t.asyncAll(this.actors,function(t,n){t.send(e,r,n)},n)},k.prototype.send=function(t,e,r,n){return(\"number\"!=typeof n||isNaN(n))&&(n=this.currentActor=(this.currentActor+1)%this.actors.length),this.actors[n].send(t,e,r),n},k.prototype.remove=function(){this.actors.forEach(function(t){t.remove()}),this.actors=[],this.workerPool.release(this.id)},k.Actor=t.Actor;var A=function(e,r,n){this.bounds=t.LngLatBounds.convert(this.validateBounds(e)),this.minzoom=r||0,this.maxzoom=n||24};A.prototype.validateBounds=function(t){return Array.isArray(t)&&4===t.length?[Math.max(-180,t[0]),Math.max(-90,t[1]),Math.min(180,t[2]),Math.min(90,t[3])]:[-180,-90,180,90]},A.prototype.contains=function(e){var r=Math.pow(2,e.z),n=Math.floor(t.mercatorXfromLng(this.bounds.getWest())*r),i=Math.floor(t.mercatorYfromLat(this.bounds.getNorth())*r),a=Math.ceil(t.mercatorXfromLng(this.bounds.getEast())*r),o=Math.ceil(t.mercatorYfromLat(this.bounds.getSouth())*r);return e.x>=n&&e.x<a&&e.y>=i&&e.y<o};var M=function(e){function r(r,n,i,a){if(e.call(this),this.id=r,this.dispatcher=i,this.type=\"vector\",this.minzoom=0,this.maxzoom=22,this.scheme=\"xyz\",this.tileSize=512,this.reparseOverscaled=!0,this.isTileClipped=!0,t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"])),this._options=t.extend({type:\"vector\"},n),this._collectResourceTiming=n.collectResourceTiming,512!==this.tileSize)throw new Error(\"vector tile sources must have a tileSize of 512\");this.setEventedParent(a)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=T(this._options,this.map._requestManager,function(r,n){e._tileJSONRequest=null,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))})},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,null),i={request:this.map._requestManager.transformRequest(n,t.ResourceType.Tile),uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,tileSize:this.tileSize*e.tileID.overscaleFactor(),type:this.type,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes};function a(n,i){return e.aborted?r(null):n&&404!==n.status?r(n):(i&&i.resourceTiming&&(e.resourceTiming=i.resourceTiming),this.map._refreshExpiredTiles&&i&&e.setExpiryData(i),e.loadVectorData(i,this.map.painter),t.cacheEntryPossiblyAdded(this.dispatcher),r(null),void(e.reloadCallback&&(this.loadTile(e,e.reloadCallback),e.reloadCallback=null)))}i.request.collectResourceTiming=this._collectResourceTiming,void 0===e.workerID||\"expired\"===e.state?e.workerID=this.dispatcher.send(\"loadTile\",i,a.bind(this)):\"loading\"===e.state?e.reloadCallback=r:this.dispatcher.send(\"reloadTile\",i,a.bind(this),e.workerID)},r.prototype.abortTile=function(t){this.dispatcher.send(\"abortTile\",{uid:t.uid,type:this.type,source:this.id},void 0,t.workerID)},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.dispatcher.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},void 0,t.workerID)},r.prototype.hasTransition=function(){return!1},r}(t.Evented),S=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.dispatcher=i,this.setEventedParent(a),this.type=\"raster\",this.minzoom=0,this.maxzoom=22,this.roundZoom=!0,this.scheme=\"xyz\",this.tileSize=512,this._loaded=!1,this._options=t.extend({},n),t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"]))}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=T(this._options,this.map._requestManager,function(r,n){e._tileJSONRequest=null,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))})},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.loadTile=function(e,r){var n=this,i=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(i,t.ResourceType.Tile),function(i,a){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(i)e.state=\"errored\",r(i);else if(a){n.map._refreshExpiredTiles&&e.setExpiryData(a),delete a.cacheControl,delete a.expires;var o=n.map.painter.context,s=o.gl;e.texture=n.map.painter.getTileTexture(a.width),e.texture?e.texture.update(a,{useMipmap:!0}):(e.texture=new t.Texture(o,a,s.RGBA,{useMipmap:!0}),e.texture.bind(s.LINEAR,s.CLAMP_TO_EDGE,s.LINEAR_MIPMAP_NEAREST),o.extTextureFilterAnisotropic&&s.texParameterf(s.TEXTURE_2D,o.extTextureFilterAnisotropic.TEXTURE_MAX_ANISOTROPY_EXT,o.extTextureFilterAnisotropicMax)),e.state=\"loaded\",t.cacheEntryPossiblyAdded(n.dispatcher),r(null)}})},r.prototype.abortTile=function(t,e){t.request&&(t.request.cancel(),delete t.request),e()},r.prototype.unloadTile=function(t,e){t.texture&&this.map.painter.saveTileTexture(t.texture),e()},r.prototype.hasTransition=function(){return!1},r}(t.Evented),E=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),this.type=\"raster-dem\",this.maxzoom=22,this._options=t.extend({},n),this.encoding=n.encoding||\"mapbox\"}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.serialize=function(){return{type:\"raster-dem\",url:this.url,tileSize:this.tileSize,tiles:this.tiles,bounds:this.bounds,encoding:this.encoding}},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(n,t.ResourceType.Tile),function(n,i){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(n)e.state=\"errored\",r(n);else if(i){this.map._refreshExpiredTiles&&e.setExpiryData(i),delete i.cacheControl,delete i.expires;var a=t.browser.getImageData(i),o={uid:e.uid,coord:e.tileID,source:this.id,rawImageData:a,encoding:this.encoding};e.workerID&&\"expired\"!==e.state||(e.workerID=this.dispatcher.send(\"loadDEMTile\",o,function(t,n){t&&(e.state=\"errored\",r(t)),n&&(e.dem=n,e.needsHillshadePrepare=!0,e.state=\"loaded\",r(null))}.bind(this)))}}.bind(this)),e.neighboringTiles=this._getNeighboringTiles(e.tileID)},r.prototype._getNeighboringTiles=function(e){var r=e.canonical,n=Math.pow(2,r.z),i=(r.x-1+n)%n,a=0===r.x?e.wrap-1:e.wrap,o=(r.x+1+n)%n,s=r.x+1===n?e.wrap+1:e.wrap,l={};return l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y).key]={backfilled:!1},r.y>0&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y-1).key]={backfilled:!1}),r.y+1<n&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y+1).key]={backfilled:!1}),l},r.prototype.unloadTile=function(t){t.demTexture&&this.map.painter.saveTileTexture(t.demTexture),t.fbo&&(t.fbo.destroy(),delete t.fbo),t.dem&&delete t.dem,delete t.neighboringTiles,t.state=\"unloaded\",this.dispatcher.send(\"removeDEMTile\",{uid:t.uid,source:this.id},void 0,t.workerID)},r}(S),C=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.type=\"geojson\",this.minzoom=0,this.maxzoom=18,this.tileSize=512,this.isTileClipped=!0,this.reparseOverscaled=!0,this._removed=!1,this.dispatcher=i,this.setEventedParent(a),this._data=n.data,this._options=t.extend({},n),this._collectResourceTiming=n.collectResourceTiming,this._resourceTiming=[],void 0!==n.maxzoom&&(this.maxzoom=n.maxzoom),n.type&&(this.type=n.type),n.attribution&&(this.attribution=n.attribution);var o=t.EXTENT/this.tileSize;this.workerOptions=t.extend({source:this.id,cluster:n.cluster||!1,geojsonVtOptions:{buffer:(void 0!==n.buffer?n.buffer:128)*o,tolerance:(void 0!==n.tolerance?n.tolerance:.375)*o,extent:t.EXTENT,maxZoom:this.maxzoom,lineMetrics:n.lineMetrics||!1,generateId:n.generateId||!1},superclusterOptions:{maxZoom:void 0!==n.clusterMaxZoom?Math.min(n.clusterMaxZoom,this.maxzoom-1):this.maxzoom-1,extent:t.EXTENT,radius:(n.clusterRadius||50)*o,log:!1},clusterProperties:n.clusterProperties},n.workerOptions)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData(function(r){if(r)e.fire(new t.ErrorEvent(r));else{var n={dataType:\"source\",sourceDataType:\"metadata\"};e._collectResourceTiming&&e._resourceTiming&&e._resourceTiming.length>0&&(n.resourceTiming=e._resourceTiming,e._resourceTiming=[]),e.fire(new t.Event(\"data\",n))}})},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setData=function(e){var r=this;return this._data=e,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData(function(e){if(e)r.fire(new t.ErrorEvent(e));else{var n={dataType:\"source\",sourceDataType:\"content\"};r._collectResourceTiming&&r._resourceTiming&&r._resourceTiming.length>0&&(n.resourceTiming=r._resourceTiming,r._resourceTiming=[]),r.fire(new t.Event(\"data\",n))}}),this},r.prototype.getClusterExpansionZoom=function(t,e){return this.dispatcher.send(\"geojson.getClusterExpansionZoom\",{clusterId:t,source:this.id},e,this.workerID),this},r.prototype.getClusterChildren=function(t,e){return this.dispatcher.send(\"geojson.getClusterChildren\",{clusterId:t,source:this.id},e,this.workerID),this},r.prototype.getClusterLeaves=function(t,e,r,n){return this.dispatcher.send(\"geojson.getClusterLeaves\",{source:this.id,clusterId:t,limit:e,offset:r},n,this.workerID),this},r.prototype._updateWorkerData=function(e){var r=this,n=t.extend({},this.workerOptions),i=this._data;\"string\"==typeof i?(n.request=this.map._requestManager.transformRequest(t.browser.resolveURL(i),t.ResourceType.Source),n.request.collectResourceTiming=this._collectResourceTiming):n.data=JSON.stringify(i),this.workerID=this.dispatcher.send(this.type+\".loadData\",n,function(t,i){r._removed||i&&i.abandoned||(r._loaded=!0,i&&i.resourceTiming&&i.resourceTiming[r.id]&&(r._resourceTiming=i.resourceTiming[r.id].slice(0)),r.dispatcher.send(r.type+\".coalesce\",{source:n.source},null,r.workerID),e(t))},this.workerID)},r.prototype.loadTile=function(e,r){var n=this,i=void 0===e.workerID?\"loadTile\":\"reloadTile\",a={type:this.type,uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,maxZoom:this.maxzoom,tileSize:this.tileSize,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes};e.workerID=this.dispatcher.send(i,a,function(t,a){return e.unloadVectorData(),e.aborted?r(null):t?r(t):(e.loadVectorData(a,n.map.painter,\"reloadTile\"===i),r(null))},this.workerID)},r.prototype.abortTile=function(t){t.aborted=!0},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.dispatcher.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},null,t.workerID)},r.prototype.onRemove=function(){this._removed=!0,this.dispatcher.send(\"removeSource\",{type:this.type,source:this.id},null,this.workerID)},r.prototype.serialize=function(){return t.extend({},this._options,{type:this.type,data:this._data})},r.prototype.hasTransition=function(){return!1},r}(t.Evented),L=function(e){function r(t,r,n,i){e.call(this),this.id=t,this.dispatcher=n,this.coordinates=r.coordinates,this.type=\"image\",this.minzoom=0,this.maxzoom=22,this.tileSize=512,this.tiles={},this.setEventedParent(i),this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(e,r){var n=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this.url=this.options.url,t.getImage(this.map._requestManager.transformRequest(this.url,t.ResourceType.Image),function(i,a){i?n.fire(new t.ErrorEvent(i)):a&&(n.image=a,e&&(n.coordinates=e),r&&r(),n._finishLoading())})},r.prototype.updateImage=function(t){var e=this;return this.image&&t.url?(this.options.url=t.url,this.load(t.coordinates,function(){e.texture=null}),this):this},r.prototype._finishLoading=function(){this.map&&(this.setCoordinates(this.coordinates),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setCoordinates=function(e){var r=this;this.coordinates=e;var n=e.map(t.MercatorCoordinate.fromLngLat);this.tileID=function(e){for(var r=1/0,n=1/0,i=-1/0,a=-1/0,o=0,s=e;o<s.length;o+=1){var l=s[o];r=Math.min(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.x),a=Math.max(a,l.y)}var c=i-r,u=a-n,h=Math.max(c,u),f=Math.max(0,Math.floor(-Math.log(h)/Math.LN2)),p=Math.pow(2,f);return new t.CanonicalTileID(f,Math.floor((r+i)/2*p),Math.floor((n+a)/2*p))}(n),this.minzoom=this.maxzoom=this.tileID.z;var i=n.map(function(t){return r.tileID.getTilePoint(t)._round()});return this._boundsArray=new t.StructArrayLayout4i8,this._boundsArray.emplaceBack(i[0].x,i[0].y,0,0),this._boundsArray.emplaceBack(i[1].x,i[1].y,t.EXTENT,0),this._boundsArray.emplaceBack(i[3].x,i[3].y,0,t.EXTENT),this._boundsArray.emplaceBack(i[2].x,i[2].y,t.EXTENT,t.EXTENT),this.boundsBuffer&&(this.boundsBuffer.destroy(),delete this.boundsBuffer),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})),this},r.prototype.prepare=function(){if(0!==Object.keys(this.tiles).length&&this.image){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture||(this.texture=new t.Texture(e,this.image,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.loadTile=function(t,e){this.tileID&&this.tileID.equals(t.tileID.canonical)?(this.tiles[String(t.tileID.wrap)]=t,t.buckets={},e(null)):(t.state=\"errored\",e(null))},r.prototype.serialize=function(){return{type:\"image\",url:this.options.url,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return!1},r}(t.Evented),P=function(e){function r(t,r,n,i){e.call(this,t,r,n,i),this.roundZoom=!0,this.type=\"video\",this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this,r=this.options;this.urls=[];for(var n=0,i=r.urls;n<i.length;n+=1){var a=i[n];this.urls.push(this.map._requestManager.transformRequest(a,t.ResourceType.Source).url)}t.getVideo(this.urls,function(r,n){r?e.fire(new t.ErrorEvent(r)):n&&(e.video=n,e.video.loop=!0,e.video.addEventListener(\"playing\",function(){e.map.triggerRepaint()}),e.map&&e.video.play(),e._finishLoading())})},r.prototype.getVideo=function(){return this.video},r.prototype.onAdd=function(t){this.map||(this.map=t,this.load(),this.video&&(this.video.play(),this.setCoordinates(this.coordinates)))},r.prototype.prepare=function(){if(!(0===Object.keys(this.tiles).length||this.video.readyState<2)){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?this.video.paused||(this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE),r.texSubImage2D(r.TEXTURE_2D,0,0,0,r.RGBA,r.UNSIGNED_BYTE,this.video)):(this.texture=new t.Texture(e,this.video,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"video\",urls:this.urls,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this.video&&!this.video.paused},r}(L),O=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),n.coordinates?Array.isArray(n.coordinates)&&4===n.coordinates.length&&!n.coordinates.some(function(t){return!Array.isArray(t)||2!==t.length||t.some(function(t){return\"number\"!=typeof t})})||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"coordinates\" property must be an array of 4 longitude/latitude array pairs'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"coordinates\"'))),n.animate&&\"boolean\"!=typeof n.animate&&this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'optional \"animate\" property must be a boolean value'))),n.canvas?\"string\"==typeof n.canvas||n.canvas instanceof t.window.HTMLCanvasElement||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"canvas\" must be either a string representing the ID of the canvas element from which to read, or an HTMLCanvasElement instance'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"canvas\"'))),this.options=n,this.animate=void 0===n.animate||n.animate}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){this.canvas||(this.canvas=this.options.canvas instanceof t.window.HTMLCanvasElement?this.options.canvas:t.window.document.getElementById(this.options.canvas)),this.width=this.canvas.width,this.height=this.canvas.height,this._hasInvalidDimensions()?this.fire(new t.ErrorEvent(new Error(\"Canvas dimensions cannot be less than or equal to zero.\"))):(this.play=function(){this._playing=!0,this.map.triggerRepaint()},this.pause=function(){this._playing&&(this.prepare(),this._playing=!1)},this._finishLoading())},r.prototype.getCanvas=function(){return this.canvas},r.prototype.onAdd=function(t){this.map=t,this.load(),this.canvas&&this.animate&&this.play()},r.prototype.onRemove=function(){this.pause()},r.prototype.prepare=function(){var e=!1;if(this.canvas.width!==this.width&&(this.width=this.canvas.width,e=!0),this.canvas.height!==this.height&&(this.height=this.canvas.height,e=!0),!this._hasInvalidDimensions()&&0!==Object.keys(this.tiles).length){var r=this.map.painter.context,n=r.gl;for(var i in this.boundsBuffer||(this.boundsBuffer=r.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?(e||this._playing)&&this.texture.update(this.canvas,{premultiply:!0}):this.texture=new t.Texture(r,this.canvas,n.RGBA,{premultiply:!0}),this.tiles){var a=this.tiles[i];\"loaded\"!==a.state&&(a.state=\"loaded\",a.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"canvas\",coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this._playing},r.prototype._hasInvalidDimensions=function(){for(var t=0,e=[this.canvas.width,this.canvas.height];t<e.length;t+=1){var r=e[t];if(isNaN(r)||r<=0)return!0}return!1},r}(L),z={vector:M,raster:S,\"raster-dem\":E,geojson:C,video:P,image:L,canvas:O},I=function(e,r,n,i){var a=new z[r.type](e,r,n,i);if(a.id!==e)throw new Error(\"Expected Source id to be \"+e+\" instead of \"+a.id);return t.bindAll([\"load\",\"abort\",\"unload\",\"serialize\",\"prepare\"],a),a};function D(e,r){var n=t.identity([]);return t.translate(n,n,[1,1,0]),t.scale(n,n,[.5*e.width,.5*e.height,1]),t.multiply(n,n,e.calculatePosMatrix(r.toUnwrapped()))}function R(t,e,r,n,i){var a=function(t,e,r){if(t)for(var n=0,i=t;n<i.length;n+=1){var a=e[i[n]];if(a&&a.source===r&&\"fill-extrusion\"===a.type)return!0}else for(var o in e){var s=e[o];if(s.source===r&&\"fill-extrusion\"===s.type)return!0}return!1}(n&&n.layers,e,t.id),o=i.maxPitchScaleFactor(),s=t.tilesIn(r,o,a);s.sort(F);for(var l=[],c=0,u=s;c<u.length;c+=1){var h=u[c];l.push({wrappedTileID:h.tileID.wrapped().key,queryResults:h.tile.queryRenderedFeatures(e,t._state,h.queryGeometry,h.cameraQueryGeometry,h.scale,n,i,o,D(t.transform,h.tileID))})}var f=function(t){for(var e={},r={},n=0,i=t;n<i.length;n+=1){var a=i[n],o=a.queryResults,s=a.wrappedTileID,l=r[s]=r[s]||{};for(var c in o)for(var u=o[c],h=l[c]=l[c]||{},f=e[c]=e[c]||[],p=0,d=u;p<d.length;p+=1){var g=d[p];h[g.featureIndex]||(h[g.featureIndex]=!0,f.push(g))}}return e}(l);for(var p in f)f[p].forEach(function(e){var r=e.feature,n=t.getFeatureState(r.layer[\"source-layer\"],r.id);r.source=r.layer.source,r.layer[\"source-layer\"]&&(r.sourceLayer=r.layer[\"source-layer\"]),r.state=n});return f}function F(t,e){var r=t.tileID,n=e.tileID;return r.overscaledZ-n.overscaledZ||r.canonical.y-n.canonical.y||r.wrap-n.wrap||r.canonical.x-n.canonical.x}var B=function(t,e){this.max=t,this.onRemove=e,this.reset()};B.prototype.reset=function(){for(var t in this.data)for(var e=0,r=this.data[t];e<r.length;e+=1){var n=r[e];n.timeout&&clearTimeout(n.timeout),this.onRemove(n.value)}return this.data={},this.order=[],this},B.prototype.add=function(t,e,r){var n=this,i=t.wrapped().key;void 0===this.data[i]&&(this.data[i]=[]);var a={value:e,timeout:void 0};if(void 0!==r&&(a.timeout=setTimeout(function(){n.remove(t,a)},r)),this.data[i].push(a),this.order.push(i),this.order.length>this.max){var o=this._getAndRemoveByKey(this.order[0]);o&&this.onRemove(o)}return this},B.prototype.has=function(t){return t.wrapped().key in this.data},B.prototype.getAndRemove=function(t){return this.has(t)?this._getAndRemoveByKey(t.wrapped().key):null},B.prototype._getAndRemoveByKey=function(t){var e=this.data[t].shift();return e.timeout&&clearTimeout(e.timeout),0===this.data[t].length&&delete this.data[t],this.order.splice(this.order.indexOf(t),1),e.value},B.prototype.get=function(t){return this.has(t)?this.data[t.wrapped().key][0].value:null},B.prototype.remove=function(t,e){if(!this.has(t))return this;var r=t.wrapped().key,n=void 0===e?0:this.data[r].indexOf(e),i=this.data[r][n];return this.data[r].splice(n,1),i.timeout&&clearTimeout(i.timeout),0===this.data[r].length&&delete this.data[r],this.onRemove(i.value),this.order.splice(this.order.indexOf(r),1),this},B.prototype.setMaxSize=function(t){for(this.max=t;this.order.length>this.max;){var e=this._getAndRemoveByKey(this.order[0]);e&&this.onRemove(e)}return this};var N=function(t,e,r){this.context=t;var n=t.gl;this.buffer=n.createBuffer(),this.dynamicDraw=Boolean(r),this.context.unbindVAO(),t.bindElementBuffer.set(this.buffer),n.bufferData(n.ELEMENT_ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?n.DYNAMIC_DRAW:n.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};N.prototype.bind=function(){this.context.bindElementBuffer.set(this.buffer)},N.prototype.updateData=function(t){var e=this.context.gl;this.context.unbindVAO(),this.bind(),e.bufferSubData(e.ELEMENT_ARRAY_BUFFER,0,t.arrayBuffer)},N.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var j={Int8:\"BYTE\",Uint8:\"UNSIGNED_BYTE\",Int16:\"SHORT\",Uint16:\"UNSIGNED_SHORT\",Int32:\"INT\",Uint32:\"UNSIGNED_INT\",Float32:\"FLOAT\"},U=function(t,e,r,n){this.length=e.length,this.attributes=r,this.itemSize=e.bytesPerElement,this.dynamicDraw=n,this.context=t;var i=t.gl;this.buffer=i.createBuffer(),t.bindVertexBuffer.set(this.buffer),i.bufferData(i.ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?i.DYNAMIC_DRAW:i.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};U.prototype.bind=function(){this.context.bindVertexBuffer.set(this.buffer)},U.prototype.updateData=function(t){var e=this.context.gl;this.bind(),e.bufferSubData(e.ARRAY_BUFFER,0,t.arrayBuffer)},U.prototype.enableAttributes=function(t,e){for(var r=0;r<this.attributes.length;r++){var n=this.attributes[r],i=e.attributes[n.name];void 0!==i&&t.enableVertexAttribArray(i)}},U.prototype.setVertexAttribPointers=function(t,e,r){for(var n=0;n<this.attributes.length;n++){var i=this.attributes[n],a=e.attributes[i.name];void 0!==a&&t.vertexAttribPointer(a,i.components,t[j[i.type]],!1,this.itemSize,i.offset+this.itemSize*(r||0))}},U.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var V=function(t){this.gl=t.gl,this.default=this.getDefault(),this.current=this.default,this.dirty=!1};V.prototype.get=function(){return this.current},V.prototype.set=function(t){},V.prototype.getDefault=function(){return this.default},V.prototype.setDefault=function(){this.set(this.default)};var q=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.clearColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(V),H=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 1},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearDepth(t),this.current=t,this.dirty=!1)},e}(V),G=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearStencil(t),this.current=t,this.dirty=!1)},e}(V),Y=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return[!0,!0,!0,!0]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.colorMask(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(V),W=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthMask(t),this.current=t,this.dirty=!1)},e}(V),X=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 255},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.stencilMask(t),this.current=t,this.dirty=!1)},e}(V),Z=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return{func:this.gl.ALWAYS,ref:0,mask:255}},e.prototype.set=function(t){var e=this.current;(t.func!==e.func||t.ref!==e.ref||t.mask!==e.mask||this.dirty)&&(this.gl.stencilFunc(t.func,t.ref,t.mask),this.current=t,this.dirty=!1)},e}(V),J=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.KEEP,t.KEEP,t.KEEP]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||this.dirty)&&(this.gl.stencilOp(t[0],t[1],t[2]),this.current=t,this.dirty=!1)},e}(V),K=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.STENCIL_TEST):e.disable(e.STENCIL_TEST),this.current=t,this.dirty=!1}},e}(V),$=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return[0,1]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.depthRange(t[0],t[1]),this.current=t,this.dirty=!1)},e}(V),Q=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.DEPTH_TEST):e.disable(e.DEPTH_TEST),this.current=t,this.dirty=!1}},e}(V),tt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.LESS},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthFunc(t),this.current=t,this.dirty=!1)},e}(V),et=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.BLEND):e.disable(e.BLEND),this.current=t,this.dirty=!1}},e}(V),rt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.ONE,t.ZERO]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.blendFunc(t[0],t[1]),this.current=t,this.dirty=!1)},e}(V),nt=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.blendColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(V),it=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.FUNC_ADD},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.blendEquation(t),this.current=t,this.dirty=!1)},e}(V),at=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.CULL_FACE):e.disable(e.CULL_FACE),this.current=t,this.dirty=!1}},e}(V),ot=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.BACK},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.cullFace(t),this.current=t,this.dirty=!1)},e}(V),st=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.CCW},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.frontFace(t),this.current=t,this.dirty=!1)},e}(V),lt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.useProgram(t),this.current=t,this.dirty=!1)},e}(V),ct=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.TEXTURE0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.activeTexture(t),this.current=t,this.dirty=!1)},e}(V),ut=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[0,0,t.drawingBufferWidth,t.drawingBufferHeight]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.viewport(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(V),ht=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindFramebuffer(e.FRAMEBUFFER,t),this.current=t,this.dirty=!1}},e}(V),ft=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindRenderbuffer(e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(V),pt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindTexture(e.TEXTURE_2D,t),this.current=t,this.dirty=!1}},e}(V),dt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindBuffer(e.ARRAY_BUFFER,t),this.current=t,this.dirty=!1}},e}(V),gt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){var e=this.gl;e.bindBuffer(e.ELEMENT_ARRAY_BUFFER,t),this.current=t,this.dirty=!1},e}(V),vt=function(t){function e(e){t.call(this,e),this.vao=e.extVertexArrayObject}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){this.vao&&(t!==this.current||this.dirty)&&(this.vao.bindVertexArrayOES(t),this.current=t,this.dirty=!1)},e}(V),mt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 4},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_ALIGNMENT,t),this.current=t,this.dirty=!1}},e}(V),yt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_PREMULTIPLY_ALPHA_WEBGL,t),this.current=t,this.dirty=!1}},e}(V),xt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_FLIP_Y_WEBGL,t),this.current=t,this.dirty=!1}},e}(V),bt=function(t){function e(e,r){t.call(this,e),this.context=e,this.parent=r}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e}(V),_t=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.setDirty=function(){this.dirty=!0},e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferTexture2D(e.FRAMEBUFFER,e.COLOR_ATTACHMENT0,e.TEXTURE_2D,t,0),this.current=t,this.dirty=!1}},e}(bt),wt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferRenderbuffer(e.FRAMEBUFFER,e.DEPTH_ATTACHMENT,e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(bt),kt=function(t,e,r){this.context=t,this.width=e,this.height=r;var n=t.gl,i=this.framebuffer=n.createFramebuffer();this.colorAttachment=new _t(t,i),this.depthAttachment=new wt(t,i)};kt.prototype.destroy=function(){var t=this.context.gl,e=this.colorAttachment.get();e&&t.deleteTexture(e);var r=this.depthAttachment.get();r&&t.deleteRenderbuffer(r),t.deleteFramebuffer(this.framebuffer)};var Tt=function(t,e,r){this.func=t,this.mask=e,this.range=r};Tt.ReadOnly=!1,Tt.ReadWrite=!0,Tt.disabled=new Tt(519,Tt.ReadOnly,[0,1]);var At=function(t,e,r,n,i,a){this.test=t,this.ref=e,this.mask=r,this.fail=n,this.depthFail=i,this.pass=a};At.disabled=new At({func:519,mask:0},0,0,7680,7680,7680);var Mt=function(t,e,r){this.blendFunction=t,this.blendColor=e,this.mask=r};Mt.disabled=new Mt(Mt.Replace=[1,0],t.Color.transparent,[!1,!1,!1,!1]),Mt.unblended=new Mt(Mt.Replace,t.Color.transparent,[!0,!0,!0,!0]),Mt.alphaBlended=new Mt([1,771],t.Color.transparent,[!0,!0,!0,!0]);var St=function(t,e,r){this.enable=t,this.mode=e,this.frontFace=r};St.disabled=new St(!1,1029,2305),St.backCCW=new St(!0,1029,2305);var Et=function(t){this.gl=t,this.extVertexArrayObject=this.gl.getExtension(\"OES_vertex_array_object\"),this.clearColor=new q(this),this.clearDepth=new H(this),this.clearStencil=new G(this),this.colorMask=new Y(this),this.depthMask=new W(this),this.stencilMask=new X(this),this.stencilFunc=new Z(this),this.stencilOp=new J(this),this.stencilTest=new K(this),this.depthRange=new $(this),this.depthTest=new Q(this),this.depthFunc=new tt(this),this.blend=new et(this),this.blendFunc=new rt(this),this.blendColor=new nt(this),this.blendEquation=new it(this),this.cullFace=new at(this),this.cullFaceSide=new ot(this),this.frontFace=new st(this),this.program=new lt(this),this.activeTexture=new ct(this),this.viewport=new ut(this),this.bindFramebuffer=new ht(this),this.bindRenderbuffer=new ft(this),this.bindTexture=new pt(this),this.bindVertexBuffer=new dt(this),this.bindElementBuffer=new gt(this),this.bindVertexArrayOES=this.extVertexArrayObject&&new vt(this),this.pixelStoreUnpack=new mt(this),this.pixelStoreUnpackPremultiplyAlpha=new yt(this),this.pixelStoreUnpackFlipY=new xt(this),this.extTextureFilterAnisotropic=t.getExtension(\"EXT_texture_filter_anisotropic\")||t.getExtension(\"MOZ_EXT_texture_filter_anisotropic\")||t.getExtension(\"WEBKIT_EXT_texture_filter_anisotropic\"),this.extTextureFilterAnisotropic&&(this.extTextureFilterAnisotropicMax=t.getParameter(this.extTextureFilterAnisotropic.MAX_TEXTURE_MAX_ANISOTROPY_EXT)),this.extTextureHalfFloat=t.getExtension(\"OES_texture_half_float\"),this.extTextureHalfFloat&&t.getExtension(\"OES_texture_half_float_linear\")};Et.prototype.setDefault=function(){this.unbindVAO(),this.clearColor.setDefault(),this.clearDepth.setDefault(),this.clearStencil.setDefault(),this.colorMask.setDefault(),this.depthMask.setDefault(),this.stencilMask.setDefault(),this.stencilFunc.setDefault(),this.stencilOp.setDefault(),this.stencilTest.setDefault(),this.depthRange.setDefault(),this.depthTest.setDefault(),this.depthFunc.setDefault(),this.blend.setDefault(),this.blendFunc.setDefault(),this.blendColor.setDefault(),this.blendEquation.setDefault(),this.cullFace.setDefault(),this.cullFaceSide.setDefault(),this.frontFace.setDefault(),this.program.setDefault(),this.activeTexture.setDefault(),this.bindFramebuffer.setDefault(),this.pixelStoreUnpack.setDefault(),this.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.pixelStoreUnpackFlipY.setDefault()},Et.prototype.setDirty=function(){this.clearColor.dirty=!0,this.clearDepth.dirty=!0,this.clearStencil.dirty=!0,this.colorMask.dirty=!0,this.depthMask.dirty=!0,this.stencilMask.dirty=!0,this.stencilFunc.dirty=!0,this.stencilOp.dirty=!0,this.stencilTest.dirty=!0,this.depthRange.dirty=!0,this.depthTest.dirty=!0,this.depthFunc.dirty=!0,this.blend.dirty=!0,this.blendFunc.dirty=!0,this.blendColor.dirty=!0,this.blendEquation.dirty=!0,this.cullFace.dirty=!0,this.cullFaceSide.dirty=!0,this.frontFace.dirty=!0,this.program.dirty=!0,this.activeTexture.dirty=!0,this.viewport.dirty=!0,this.bindFramebuffer.dirty=!0,this.bindRenderbuffer.dirty=!0,this.bindTexture.dirty=!0,this.bindVertexBuffer.dirty=!0,this.bindElementBuffer.dirty=!0,this.extVertexArrayObject&&(this.bindVertexArrayOES.dirty=!0),this.pixelStoreUnpack.dirty=!0,this.pixelStoreUnpackPremultiplyAlpha.dirty=!0,this.pixelStoreUnpackFlipY.dirty=!0},Et.prototype.createIndexBuffer=function(t,e){return new N(this,t,e)},Et.prototype.createVertexBuffer=function(t,e,r){return new U(this,t,e,r)},Et.prototype.createRenderbuffer=function(t,e,r){var n=this.gl,i=n.createRenderbuffer();return this.bindRenderbuffer.set(i),n.renderbufferStorage(n.RENDERBUFFER,t,e,r),this.bindRenderbuffer.set(null),i},Et.prototype.createFramebuffer=function(t,e){return new kt(this,t,e)},Et.prototype.clear=function(t){var e=t.color,r=t.depth,n=this.gl,i=0;e&&(i|=n.COLOR_BUFFER_BIT,this.clearColor.set(e),this.colorMask.set([!0,!0,!0,!0])),void 0!==r&&(i|=n.DEPTH_BUFFER_BIT,this.depthRange.set([0,1]),this.clearDepth.set(r),this.depthMask.set(!0)),n.clear(i)},Et.prototype.setCullFace=function(t){!1===t.enable?this.cullFace.set(!1):(this.cullFace.set(!0),this.cullFaceSide.set(t.mode),this.frontFace.set(t.frontFace))},Et.prototype.setDepthMode=function(t){t.func!==this.gl.ALWAYS||t.mask?(this.depthTest.set(!0),this.depthFunc.set(t.func),this.depthMask.set(t.mask),this.depthRange.set(t.range)):this.depthTest.set(!1)},Et.prototype.setStencilMode=function(t){t.test.func!==this.gl.ALWAYS||t.mask?(this.stencilTest.set(!0),this.stencilMask.set(t.mask),this.stencilOp.set([t.fail,t.depthFail,t.pass]),this.stencilFunc.set({func:t.test.func,ref:t.ref,mask:t.test.mask})):this.stencilTest.set(!1)},Et.prototype.setColorMode=function(e){t.deepEqual(e.blendFunction,Mt.Replace)?this.blend.set(!1):(this.blend.set(!0),this.blendFunc.set(e.blendFunction),this.blendColor.set(e.blendColor)),this.colorMask.set(e.mask)},Et.prototype.unbindVAO=function(){this.extVertexArrayObject&&this.bindVertexArrayOES.set(null)};var Ct=function(e){function r(r,n,i){var a=this;e.call(this),this.id=r,this.dispatcher=i,this.on(\"data\",function(t){\"source\"===t.dataType&&\"metadata\"===t.sourceDataType&&(a._sourceLoaded=!0),a._sourceLoaded&&!a._paused&&\"source\"===t.dataType&&\"content\"===t.sourceDataType&&(a.reload(),a.transform&&a.update(a.transform))}),this.on(\"error\",function(){a._sourceErrored=!0}),this._source=I(r,n,i,this),this._tiles={},this._cache=new B(0,this._unloadTile.bind(this)),this._timers={},this._cacheTimers={},this._maxTileCacheSize=null,this._coveredTiles={},this._state=new t.SourceFeatureState}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.onAdd=function(t){this.map=t,this._maxTileCacheSize=t?t._maxTileCacheSize:null,this._source&&this._source.onAdd&&this._source.onAdd(t)},r.prototype.onRemove=function(t){this._source&&this._source.onRemove&&this._source.onRemove(t)},r.prototype.loaded=function(){if(this._sourceErrored)return!0;if(!this._sourceLoaded)return!1;for(var t in this._tiles){var e=this._tiles[t];if(\"loaded\"!==e.state&&\"errored\"!==e.state)return!1}return!0},r.prototype.getSource=function(){return this._source},r.prototype.pause=function(){this._paused=!0},r.prototype.resume=function(){if(this._paused){var t=this._shouldReloadOnResume;this._paused=!1,this._shouldReloadOnResume=!1,t&&this.reload(),this.transform&&this.update(this.transform)}},r.prototype._loadTile=function(t,e){return this._source.loadTile(t,e)},r.prototype._unloadTile=function(t){if(this._source.unloadTile)return this._source.unloadTile(t,function(){})},r.prototype._abortTile=function(t){if(this._source.abortTile)return this._source.abortTile(t,function(){})},r.prototype.serialize=function(){return this._source.serialize()},r.prototype.prepare=function(t){for(var e in this._source.prepare&&this._source.prepare(),this._state.coalesceChanges(this._tiles,this.map?this.map.painter:null),this._tiles){var r=this._tiles[e];r.upload(t),r.prepare(this.map.style.imageManager)}},r.prototype.getIds=function(){return Object.keys(this._tiles).map(Number).sort(Lt)},r.prototype.getRenderableIds=function(e){var r=this,n=[];for(var i in this._tiles)this._isIdRenderable(+i,e)&&n.push(+i);return e?n.sort(function(e,n){var i=r._tiles[e].tileID,a=r._tiles[n].tileID,o=new t.Point(i.canonical.x,i.canonical.y)._rotate(r.transform.angle),s=new t.Point(a.canonical.x,a.canonical.y)._rotate(r.transform.angle);return i.overscaledZ-a.overscaledZ||s.y-o.y||s.x-o.x}):n.sort(Lt)},r.prototype.hasRenderableParent=function(t){var e=this.findLoadedParent(t,0);return!!e&&this._isIdRenderable(e.tileID.key)},r.prototype._isIdRenderable=function(t,e){return this._tiles[t]&&this._tiles[t].hasData()&&!this._coveredTiles[t]&&(e||!this._tiles[t].holdingForFade())},r.prototype.reload=function(){if(this._paused)this._shouldReloadOnResume=!0;else for(var t in this._cache.reset(),this._tiles)\"errored\"!==this._tiles[t].state&&this._reloadTile(t,\"reloading\")},r.prototype._reloadTile=function(t,e){var r=this._tiles[t];r&&(\"loading\"!==r.state&&(r.state=e),this._loadTile(r,this._tileLoaded.bind(this,r,t,e)))},r.prototype._tileLoaded=function(e,r,n,i){if(i)return e.state=\"errored\",void(404!==i.status?this._source.fire(new t.ErrorEvent(i,{tile:e})):this.update(this.transform));e.timeAdded=t.browser.now(),\"expired\"===n&&(e.refreshedUponExpiration=!0),this._setTileReloadTimer(r,e),\"raster-dem\"===this.getSource().type&&e.dem&&this._backfillDEM(e),this._state.initializeTileState(e,this.map?this.map.painter:null),this._source.fire(new t.Event(\"data\",{dataType:\"source\",tile:e,coord:e.tileID}))},r.prototype._backfillDEM=function(t){for(var e=this.getRenderableIds(),r=0;r<e.length;r++){var n=e[r];if(t.neighboringTiles&&t.neighboringTiles[n]){var i=this.getTileByID(n);a(t,i),a(i,t)}}function a(t,e){t.needsHillshadePrepare=!0;var r=e.tileID.canonical.x-t.tileID.canonical.x,n=e.tileID.canonical.y-t.tileID.canonical.y,i=Math.pow(2,t.tileID.canonical.z),a=e.tileID.key;0===r&&0===n||Math.abs(n)>1||(Math.abs(r)>1&&(1===Math.abs(r+i)?r+=i:1===Math.abs(r-i)&&(r-=i)),e.dem&&t.dem&&(t.dem.backfillBorder(e.dem,r,n),t.neighboringTiles&&t.neighboringTiles[a]&&(t.neighboringTiles[a].backfilled=!0)))}},r.prototype.getTile=function(t){return this.getTileByID(t.key)},r.prototype.getTileByID=function(t){return this._tiles[t]},r.prototype.getZoom=function(t){return t.zoom+t.scaleZoom(t.tileSize/this._source.tileSize)},r.prototype._retainLoadedChildren=function(t,e,r,n){for(var i in this._tiles){var a=this._tiles[i];if(!(n[i]||!a.hasData()||a.tileID.overscaledZ<=e||a.tileID.overscaledZ>r)){for(var o=a.tileID;a&&a.tileID.overscaledZ>e+1;){var s=a.tileID.scaledTo(a.tileID.overscaledZ-1);(a=this._tiles[s.key])&&a.hasData()&&(o=s)}for(var l=o;l.overscaledZ>e;)if(t[(l=l.scaledTo(l.overscaledZ-1)).key]){n[o.key]=o;break}}}},r.prototype.findLoadedParent=function(t,e){for(var r=t.overscaledZ-1;r>=e;r--){var n=t.scaledTo(r);if(!n)return;var i=String(n.key),a=this._tiles[i];if(a&&a.hasData())return a;if(this._cache.has(n))return this._cache.get(n)}},r.prototype.updateCacheSize=function(t){var e=(Math.ceil(t.width/this._source.tileSize)+1)*(Math.ceil(t.height/this._source.tileSize)+1),r=Math.floor(5*e),n=\"number\"==typeof this._maxTileCacheSize?Math.min(this._maxTileCacheSize,r):r;this._cache.setMaxSize(n)},r.prototype.handleWrapJump=function(t){var e=(t-(void 0===this._prevLng?t:this._prevLng))/360,r=Math.round(e);if(this._prevLng=t,r){var n={};for(var i in this._tiles){var a=this._tiles[i];a.tileID=a.tileID.unwrapTo(a.tileID.wrap+r),n[a.tileID.key]=a}for(var o in this._tiles=n,this._timers)clearTimeout(this._timers[o]),delete this._timers[o];for(var s in this._tiles){var l=this._tiles[s];this._setTileReloadTimer(s,l)}}},r.prototype.update=function(e){var n=this;if(this.transform=e,this._sourceLoaded&&!this._paused){var i;this.updateCacheSize(e),this.handleWrapJump(this.transform.center.lng),this._coveredTiles={},this.used?this._source.tileID?i=e.getVisibleUnwrappedCoordinates(this._source.tileID).map(function(e){return new t.OverscaledTileID(e.canonical.z,e.wrap,e.canonical.z,e.canonical.x,e.canonical.y)}):(i=e.coveringTiles({tileSize:this._source.tileSize,minzoom:this._source.minzoom,maxzoom:this._source.maxzoom,roundZoom:this._source.roundZoom,reparseOverscaled:this._source.reparseOverscaled}),this._source.hasTile&&(i=i.filter(function(t){return n._source.hasTile(t)}))):i=[];var a=(this._source.roundZoom?Math.round:Math.floor)(this.getZoom(e)),o=Math.max(a-r.maxOverzooming,this._source.minzoom),s=Math.max(a+r.maxUnderzooming,this._source.minzoom),l=this._updateRetainedTiles(i,a);if(Pt(this._source.type)){for(var c={},u={},h=0,f=Object.keys(l);h<f.length;h+=1){var p=f[h],d=l[p],g=this._tiles[p];if(g&&!(g.fadeEndTime&&g.fadeEndTime<=t.browser.now())){var v=this.findLoadedParent(d,o);v&&(this._addTile(v.tileID),c[v.tileID.key]=v.tileID),u[p]=d}}for(var m in this._retainLoadedChildren(u,a,s,l),c)l[m]||(this._coveredTiles[m]=!0,l[m]=c[m])}for(var y in l)this._tiles[y].clearFadeHold();for(var x=0,b=t.keysDifference(this._tiles,l);x<b.length;x+=1){var _=b[x],w=this._tiles[_];w.hasSymbolBuckets&&!w.holdingForFade()?w.setHoldDuration(this.map._fadeDuration):w.hasSymbolBuckets&&!w.symbolFadeFinished()||this._removeTile(_)}}},r.prototype.releaseSymbolFadeTiles=function(){for(var t in this._tiles)this._tiles[t].holdingForFade()&&this._removeTile(t)},r.prototype._updateRetainedTiles=function(t,e){for(var n={},i={},a=Math.max(e-r.maxOverzooming,this._source.minzoom),o=Math.max(e+r.maxUnderzooming,this._source.minzoom),s={},l=0,c=t;l<c.length;l+=1){var u=c[l],h=this._addTile(u);n[u.key]=u,h.hasData()||e<this._source.maxzoom&&(s[u.key]=u)}this._retainLoadedChildren(s,e,o,n);for(var f=0,p=t;f<p.length;f+=1){var d=p[f],g=this._tiles[d.key];if(!g.hasData()){if(e+1>this._source.maxzoom){var v=d.children(this._source.maxzoom)[0],m=this.getTile(v);if(m&&m.hasData()){n[v.key]=v;continue}}else{var y=d.children(this._source.maxzoom);if(n[y[0].key]&&n[y[1].key]&&n[y[2].key]&&n[y[3].key])continue}for(var x=g.wasRequested(),b=d.overscaledZ-1;b>=a;--b){var _=d.scaledTo(b);if(i[_.key])break;if(i[_.key]=!0,!(g=this.getTile(_))&&x&&(g=this._addTile(_)),g&&(n[_.key]=_,x=g.wasRequested(),g.hasData()))break}}}return n},r.prototype._addTile=function(e){var r=this._tiles[e.key];if(r)return r;(r=this._cache.getAndRemove(e))&&(this._setTileReloadTimer(e.key,r),r.tileID=e,this._state.initializeTileState(r,this.map?this.map.painter:null),this._cacheTimers[e.key]&&(clearTimeout(this._cacheTimers[e.key]),delete this._cacheTimers[e.key],this._setTileReloadTimer(e.key,r)));var n=Boolean(r);return n||(r=new t.Tile(e,this._source.tileSize*e.overscaleFactor()),this._loadTile(r,this._tileLoaded.bind(this,r,e.key,r.state))),r?(r.uses++,this._tiles[e.key]=r,n||this._source.fire(new t.Event(\"dataloading\",{tile:r,coord:r.tileID,dataType:\"source\"})),r):null},r.prototype._setTileReloadTimer=function(t,e){var r=this;t in this._timers&&(clearTimeout(this._timers[t]),delete this._timers[t]);var n=e.getExpiryTimeout();n&&(this._timers[t]=setTimeout(function(){r._reloadTile(t,\"expired\"),delete r._timers[t]},n))},r.prototype._removeTile=function(t){var e=this._tiles[t];e&&(e.uses--,delete this._tiles[t],this._timers[t]&&(clearTimeout(this._timers[t]),delete this._timers[t]),e.uses>0||(e.hasData()?this._cache.add(e.tileID,e,e.getExpiryTimeout()):(e.aborted=!0,this._abortTile(e),this._unloadTile(e))))},r.prototype.clearTiles=function(){for(var t in this._shouldReloadOnResume=!1,this._paused=!1,this._tiles)this._removeTile(t);this._cache.reset()},r.prototype.tilesIn=function(e,r,n){var i=this,a=[],o=this.transform;if(!o)return a;for(var s=n?o.getCameraQueryGeometry(e):e,l=e.map(function(t){return o.pointCoordinate(t)}),c=s.map(function(t){return o.pointCoordinate(t)}),u=this.getIds(),h=1/0,f=1/0,p=-1/0,d=-1/0,g=0,v=c;g<v.length;g+=1){var m=v[g];h=Math.min(h,m.x),f=Math.min(f,m.y),p=Math.max(p,m.x),d=Math.max(d,m.y)}for(var y=function(e){var n=i._tiles[u[e]];if(!n.holdingForFade()){var s=n.tileID,g=Math.pow(2,o.zoom-n.tileID.overscaledZ),v=r*n.queryPadding*t.EXTENT/n.tileSize/g,m=[s.getTilePoint(new t.MercatorCoordinate(h,f)),s.getTilePoint(new t.MercatorCoordinate(p,d))];if(m[0].x-v<t.EXTENT&&m[0].y-v<t.EXTENT&&m[1].x+v>=0&&m[1].y+v>=0){var y=l.map(function(t){return s.getTilePoint(t)}),x=c.map(function(t){return s.getTilePoint(t)});a.push({tile:n,tileID:s,queryGeometry:y,cameraQueryGeometry:x,scale:g})}}},x=0;x<u.length;x++)y(x);return a},r.prototype.getVisibleCoordinates=function(t){for(var e=this,r=this.getRenderableIds(t).map(function(t){return e._tiles[t].tileID}),n=0,i=r;n<i.length;n+=1){var a=i[n];a.posMatrix=this.transform.calculatePosMatrix(a.toUnwrapped())}return r},r.prototype.hasTransition=function(){if(this._source.hasTransition())return!0;if(Pt(this._source.type))for(var e in this._tiles){var r=this._tiles[e];if(void 0!==r.fadeEndTime&&r.fadeEndTime>=t.browser.now())return!0}return!1},r.prototype.setFeatureState=function(t,e,r){t=t||\"_geojsonTileLayer\",this._state.updateState(t,e,r)},r.prototype.removeFeatureState=function(t,e,r){t=t||\"_geojsonTileLayer\",this._state.removeFeatureState(t,e,r)},r.prototype.getFeatureState=function(t,e){return t=t||\"_geojsonTileLayer\",this._state.getState(t,e)},r}(t.Evented);function Lt(t,e){return t%32-e%32||e-t}function Pt(t){return\"raster\"===t||\"image\"===t||\"video\"===t}function Ot(){return new t.window.Worker(Jn.workerUrl)}Ct.maxOverzooming=10,Ct.maxUnderzooming=3;var zt=function(){this.active={}};zt.prototype.acquire=function(t){if(!this.workers)for(this.workers=[];this.workers.length<zt.workerCount;)this.workers.push(new Ot);return this.active[t]=!0,this.workers.slice()},zt.prototype.release=function(t){delete this.active[t],0===Object.keys(this.active).length&&(this.workers.forEach(function(t){t.terminate()}),this.workers=null)};var It,Dt=Math.floor(t.browser.hardwareConcurrency/2);function Rt(e,r){var n={};for(var i in e)\"ref\"!==i&&(n[i]=e[i]);return t.refProperties.forEach(function(t){t in r&&(n[t]=r[t])}),n}function Ft(t){t=t.slice();for(var e=Object.create(null),r=0;r<t.length;r++)e[t[r].id]=t[r];for(var n=0;n<t.length;n++)\"ref\"in t[n]&&(t[n]=Rt(t[n],e[t[n].ref]));return t}zt.workerCount=Math.max(Math.min(Dt,6),1);var Bt={setStyle:\"setStyle\",addLayer:\"addLayer\",removeLayer:\"removeLayer\",setPaintProperty:\"setPaintProperty\",setLayoutProperty:\"setLayoutProperty\",setFilter:\"setFilter\",addSource:\"addSource\",removeSource:\"removeSource\",setGeoJSONSourceData:\"setGeoJSONSourceData\",setLayerZoomRange:\"setLayerZoomRange\",setLayerProperty:\"setLayerProperty\",setCenter:\"setCenter\",setZoom:\"setZoom\",setBearing:\"setBearing\",setPitch:\"setPitch\",setSprite:\"setSprite\",setGlyphs:\"setGlyphs\",setTransition:\"setTransition\",setLight:\"setLight\"};function Nt(t,e,r){r.push({command:Bt.addSource,args:[t,e[t]]})}function jt(t,e,r){e.push({command:Bt.removeSource,args:[t]}),r[t]=!0}function Ut(t,e,r,n){jt(t,r,n),Nt(t,e,r)}function Vt(e,r,n){var i;for(i in e[n])if(e[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;for(i in r[n])if(r[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;return!0}function qt(e,r,n,i,a,o){var s;for(s in r=r||{},e=e||{})e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}));for(s in r)r.hasOwnProperty(s)&&!e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}))}function Ht(t){return t.id}function Gt(t,e){return t[e.id]=e,t}var Yt=function(t,e,r){var n=this.boxCells=[],i=this.circleCells=[];this.xCellCount=Math.ceil(t/r),this.yCellCount=Math.ceil(e/r);for(var a=0;a<this.xCellCount*this.yCellCount;a++)n.push([]),i.push([]);this.circleKeys=[],this.boxKeys=[],this.bboxes=[],this.circles=[],this.width=t,this.height=e,this.xScale=this.xCellCount/t,this.yScale=this.yCellCount/e,this.boxUid=0,this.circleUid=0};function Wt(e,r,n,i,a){var o=t.create();return r?(t.scale(o,o,[1/a,1/a,1]),n||t.rotateZ(o,o,i.angle)):t.multiply(o,i.labelPlaneMatrix,e),o}function Xt(e,r,n,i,a){if(r){var o=t.clone(e);return t.scale(o,o,[a,a,1]),n||t.rotateZ(o,o,-i.angle),o}return i.glCoordMatrix}function Zt(e,r){var n=[e.x,e.y,0,1];ae(n,n,r);var i=n[3];return{point:new t.Point(n[0]/i,n[1]/i),signedDistanceFromCamera:i}}function Jt(t,e){var r=t[0]/t[3],n=t[1]/t[3];return r>=-e[0]&&r<=e[0]&&n>=-e[1]&&n<=e[1]}function Kt(e,r,n,i,a,o,s,l){var c=i?e.textSizeData:e.iconSizeData,u=t.evaluateSizeForZoom(c,n.transform.zoom),h=[256/n.width*2+1,256/n.height*2+1],f=i?e.text.dynamicLayoutVertexArray:e.icon.dynamicLayoutVertexArray;f.clear();for(var p=e.lineVertexArray,d=i?e.text.placedSymbolArray:e.icon.placedSymbolArray,g=n.transform.width/n.transform.height,v=!1,m=0;m<d.length;m++){var y=d.get(m);if(y.hidden||y.writingMode===t.WritingMode.vertical&&!v)ie(y.numGlyphs,f);else{v=!1;var x=[y.anchorX,y.anchorY,0,1];if(t.transformMat4(x,x,r),Jt(x,h)){var b=.5+x[3]/n.transform.cameraToCenterDistance*.5,_=t.evaluateSizeForFeature(c,u,y),w=s?_*b:_/b,k=new t.Point(y.anchorX,y.anchorY),T=Zt(k,a).point,A={},M=te(y,w,!1,l,r,a,o,e.glyphOffsetArray,p,f,T,k,A,g);v=M.useVertical,(M.notEnoughRoom||v||M.needsFlipping&&te(y,w,!0,l,r,a,o,e.glyphOffsetArray,p,f,T,k,A,g).notEnoughRoom)&&ie(y.numGlyphs,f)}else ie(y.numGlyphs,f)}}i?e.text.dynamicLayoutVertexBuffer.updateData(f):e.icon.dynamicLayoutVertexBuffer.updateData(f)}function $t(t,e,r,n,i,a,o,s,l,c,u,h){var f=s.glyphStartIndex+s.numGlyphs,p=s.lineStartIndex,d=s.lineStartIndex+s.lineLength,g=e.getoffsetX(s.glyphStartIndex),v=e.getoffsetX(f-1),m=re(t*g,r,n,i,a,o,s.segment,p,d,l,c,u,h);if(!m)return null;var y=re(t*v,r,n,i,a,o,s.segment,p,d,l,c,u,h);return y?{first:m,last:y}:null}function Qt(e,r,n,i){return e===t.WritingMode.horizontal&&Math.abs(n.y-r.y)>Math.abs(n.x-r.x)*i?{useVertical:!0}:(e===t.WritingMode.vertical?r.y<n.y:r.x>n.x)?{needsFlipping:!0}:null}function te(e,r,n,i,a,o,s,l,c,u,h,f,p,d){var g,v=r/24,m=e.lineOffsetX*v,y=e.lineOffsetY*v;if(e.numGlyphs>1){var x=e.glyphStartIndex+e.numGlyphs,b=e.lineStartIndex,_=e.lineStartIndex+e.lineLength,w=$t(v,l,m,y,n,h,f,e,c,o,p,!1);if(!w)return{notEnoughRoom:!0};var k=Zt(w.first.point,s).point,T=Zt(w.last.point,s).point;if(i&&!n){var A=Qt(e.writingMode,k,T,d);if(A)return A}g=[w.first];for(var M=e.glyphStartIndex+1;M<x-1;M++)g.push(re(v*l.getoffsetX(M),m,y,n,h,f,e.segment,b,_,c,o,p,!1));g.push(w.last)}else{if(i&&!n){var S=Zt(f,a).point,E=e.lineStartIndex+e.segment+1,C=new t.Point(c.getx(E),c.gety(E)),L=Zt(C,a),P=L.signedDistanceFromCamera>0?L.point:ee(f,C,S,1,a),O=Qt(e.writingMode,S,P,d);if(O)return O}var z=re(v*l.getoffsetX(e.glyphStartIndex),m,y,n,h,f,e.segment,e.lineStartIndex,e.lineStartIndex+e.lineLength,c,o,p,!1);if(!z)return{notEnoughRoom:!0};g=[z]}for(var I=0,D=g;I<D.length;I+=1){var R=D[I];t.addDynamicAttributes(u,R.point,R.angle)}return{}}function ee(t,e,r,n,i){var a=Zt(t.add(t.sub(e)._unit()),i).point,o=r.sub(a);return r.add(o._mult(n/o.mag()))}function re(e,r,n,i,a,o,s,l,c,u,h,f,p){var d=i?e-r:e+r,g=d>0?1:-1,v=0;i&&(g*=-1,v=Math.PI),g<0&&(v+=Math.PI);for(var m=g>0?l+s:l+s+1,y=m,x=a,b=a,_=0,w=0,k=Math.abs(d);_+w<=k;){if((m+=g)<l||m>=c)return null;if(b=x,void 0===(x=f[m])){var T=new t.Point(u.getx(m),u.gety(m)),A=Zt(T,h);if(A.signedDistanceFromCamera>0)x=f[m]=A.point;else{var M=m-g;x=ee(0===_?o:new t.Point(u.getx(M),u.gety(M)),T,b,k-_+1,h)}}_+=w,w=b.dist(x)}var S=(k-_)/w,E=x.sub(b),C=E.mult(S)._add(b);return C._add(E._unit()._perp()._mult(n*g)),{point:C,angle:v+Math.atan2(x.y-b.y,x.x-b.x),tileDistance:p?{prevTileDistance:m-g===y?0:u.gettileUnitDistanceFromAnchor(m-g),lastSegmentViewportDistance:k-_}:null}}Yt.prototype.keysLength=function(){return this.boxKeys.length+this.circleKeys.length},Yt.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertBoxCell,this.boxUid++),this.boxKeys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},Yt.prototype.insertCircle=function(t,e,r,n){this._forEachCell(e-n,r-n,e+n,r+n,this._insertCircleCell,this.circleUid++),this.circleKeys.push(t),this.circles.push(e),this.circles.push(r),this.circles.push(n)},Yt.prototype._insertBoxCell=function(t,e,r,n,i,a){this.boxCells[i].push(a)},Yt.prototype._insertCircleCell=function(t,e,r,n,i,a){this.circleCells[i].push(a)},Yt.prototype._query=function(t,e,r,n,i,a){if(r<0||t>this.width||n<0||e>this.height)return!i&&[];var o=[];if(t<=0&&e<=0&&this.width<=r&&this.height<=n){if(i)return!0;for(var s=0;s<this.boxKeys.length;s++)o.push({key:this.boxKeys[s],x1:this.bboxes[4*s],y1:this.bboxes[4*s+1],x2:this.bboxes[4*s+2],y2:this.bboxes[4*s+3]});for(var l=0;l<this.circleKeys.length;l++){var c=this.circles[3*l],u=this.circles[3*l+1],h=this.circles[3*l+2];o.push({key:this.circleKeys[l],x1:c-h,y1:u-h,x2:c+h,y2:u+h})}return a?o.filter(a):o}var f={hitTest:i,seenUids:{box:{},circle:{}}};return this._forEachCell(t,e,r,n,this._queryCell,o,f,a),i?o.length>0:o},Yt.prototype._queryCircle=function(t,e,r,n,i){var a=t-r,o=t+r,s=e-r,l=e+r;if(o<0||a>this.width||l<0||s>this.height)return!n&&[];var c=[],u={hitTest:n,circle:{x:t,y:e,radius:r},seenUids:{box:{},circle:{}}};return this._forEachCell(a,s,o,l,this._queryCellCircle,c,u,i),n?c.length>0:c},Yt.prototype.query=function(t,e,r,n,i){return this._query(t,e,r,n,!1,i)},Yt.prototype.hitTest=function(t,e,r,n,i){return this._query(t,e,r,n,!0,i)},Yt.prototype.hitTestCircle=function(t,e,r,n){return this._queryCircle(t,e,r,!0,n)},Yt.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=o.seenUids,c=this.boxCells[i];if(null!==c)for(var u=this.bboxes,h=0,f=c;h<f.length;h+=1){var p=f[h];if(!l.box[p]){l.box[p]=!0;var d=4*p;if(t<=u[d+2]&&e<=u[d+3]&&r>=u[d+0]&&n>=u[d+1]&&(!s||s(this.boxKeys[p]))){if(o.hitTest)return a.push(!0),!0;a.push({key:this.boxKeys[p],x1:u[d],y1:u[d+1],x2:u[d+2],y2:u[d+3]})}}}var g=this.circleCells[i];if(null!==g)for(var v=this.circles,m=0,y=g;m<y.length;m+=1){var x=y[m];if(!l.circle[x]){l.circle[x]=!0;var b=3*x;if(this._circleAndRectCollide(v[b],v[b+1],v[b+2],t,e,r,n)&&(!s||s(this.circleKeys[x]))){if(o.hitTest)return a.push(!0),!0;var _=v[b],w=v[b+1],k=v[b+2];a.push({key:this.circleKeys[x],x1:_-k,y1:w-k,x2:_+k,y2:w+k})}}}},Yt.prototype._queryCellCircle=function(t,e,r,n,i,a,o,s){var l=o.circle,c=o.seenUids,u=this.boxCells[i];if(null!==u)for(var h=this.bboxes,f=0,p=u;f<p.length;f+=1){var d=p[f];if(!c.box[d]){c.box[d]=!0;var g=4*d;if(this._circleAndRectCollide(l.x,l.y,l.radius,h[g+0],h[g+1],h[g+2],h[g+3])&&(!s||s(this.boxKeys[d])))return a.push(!0),!0}}var v=this.circleCells[i];if(null!==v)for(var m=this.circles,y=0,x=v;y<x.length;y+=1){var b=x[y];if(!c.circle[b]){c.circle[b]=!0;var _=3*b;if(this._circlesCollide(m[_],m[_+1],m[_+2],l.x,l.y,l.radius)&&(!s||s(this.circleKeys[b])))return a.push(!0),!0}}},Yt.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToXCellCoord(t),c=this._convertToYCellCoord(e),u=this._convertToXCellCoord(r),h=this._convertToYCellCoord(n),f=l;f<=u;f++)for(var p=c;p<=h;p++){var d=this.xCellCount*p+f;if(i.call(this,t,e,r,n,d,a,o,s))return}},Yt.prototype._convertToXCellCoord=function(t){return Math.max(0,Math.min(this.xCellCount-1,Math.floor(t*this.xScale)))},Yt.prototype._convertToYCellCoord=function(t){return Math.max(0,Math.min(this.yCellCount-1,Math.floor(t*this.yScale)))},Yt.prototype._circlesCollide=function(t,e,r,n,i,a){var o=n-t,s=i-e,l=r+a;return l*l>o*o+s*s},Yt.prototype._circleAndRectCollide=function(t,e,r,n,i,a,o){var s=(a-n)/2,l=Math.abs(t-(n+s));if(l>s+r)return!1;var c=(o-i)/2,u=Math.abs(e-(i+c));if(u>c+r)return!1;if(l<=s||u<=c)return!0;var h=l-s,f=u-c;return h*h+f*f<=r*r};var ne=new Float32Array([-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0]);function ie(t,e){for(var r=0;r<t;r++){var n=e.length;e.resize(n+4),e.float32.set(ne,3*n)}}function ae(t,e,r){var n=e[0],i=e[1];return t[0]=r[0]*n+r[4]*i+r[12],t[1]=r[1]*n+r[5]*i+r[13],t[3]=r[3]*n+r[7]*i+r[15],t}var oe=function(t,e,r){void 0===e&&(e=new Yt(t.width+200,t.height+200,25)),void 0===r&&(r=new Yt(t.width+200,t.height+200,25)),this.transform=t,this.grid=e,this.ignoredGrid=r,this.pitchfactor=Math.cos(t._pitch)*t.cameraToCenterDistance,this.screenRightBoundary=t.width+100,this.screenBottomBoundary=t.height+100,this.gridRightBoundary=t.width+200,this.gridBottomBoundary=t.height+200};function se(t,e,r){t[e+4]=r?1:0}function le(e,r,n){return r*(t.EXTENT/(e.tileSize*Math.pow(2,n-e.tileID.overscaledZ)))}oe.prototype.placeCollisionBox=function(t,e,r,n,i){var a=this.projectAndGetPerspectiveRatio(n,t.anchorPointX,t.anchorPointY),o=r*a.perspectiveRatio,s=t.x1*o+a.point.x,l=t.y1*o+a.point.y,c=t.x2*o+a.point.x,u=t.y2*o+a.point.y;return!this.isInsideGrid(s,l,c,u)||!e&&this.grid.hitTest(s,l,c,u,i)?{box:[],offscreen:!1}:{box:[s,l,c,u],offscreen:this.isOffscreen(s,l,c,u)}},oe.prototype.approximateTileDistance=function(t,e,r,n,i){var a=i?1:n/this.pitchfactor,o=t.lastSegmentViewportDistance*r;return t.prevTileDistance+o+(a-1)*o*Math.abs(Math.sin(e))},oe.prototype.placeCollisionCircles=function(e,r,n,i,a,o,s,l,c,u,h,f,p){var d=[],g=this.projectAnchor(c,a.anchorX,a.anchorY),v=l/24,m=a.lineOffsetX*l,y=a.lineOffsetY*l,x=new t.Point(a.anchorX,a.anchorY),b=$t(v,s,m,y,!1,Zt(x,u).point,x,a,o,u,{},!0),_=!1,w=!1,k=!0,T=g.perspectiveRatio*i,A=1/(i*n),M=0,S=0;b&&(M=this.approximateTileDistance(b.first.tileDistance,b.first.angle,A,g.cameraDistance,f),S=this.approximateTileDistance(b.last.tileDistance,b.last.angle,A,g.cameraDistance,f));for(var E=0;E<e.length;E+=5){var C=e[E],L=e[E+1],P=e[E+2],O=e[E+3];if(!b||O<-M||O>S)se(e,E,!1);else{var z=this.projectPoint(c,C,L),I=P*T;if(d.length>0){var D=z.x-d[d.length-4],R=z.y-d[d.length-3];if(I*I*2>D*D+R*R&&E+8<e.length){var F=e[E+8];if(F>-M&&F<S){se(e,E,!1);continue}}}var B=E/5;d.push(z.x,z.y,I,B),se(e,E,!0);var N=z.x-I,j=z.y-I,U=z.x+I,V=z.y+I;if(k=k&&this.isOffscreen(N,j,U,V),w=w||this.isInsideGrid(N,j,U,V),!r&&this.grid.hitTestCircle(z.x,z.y,I,p)){if(!h)return{circles:[],offscreen:!1};_=!0}}}return{circles:_||!w?[]:d,offscreen:k}},oe.prototype.queryRenderedSymbols=function(e){if(0===e.length||0===this.grid.keysLength()&&0===this.ignoredGrid.keysLength())return{};for(var r=[],n=1/0,i=1/0,a=-1/0,o=-1/0,s=0,l=e;s<l.length;s+=1){var c=l[s],u=new t.Point(c.x+100,c.y+100);n=Math.min(n,u.x),i=Math.min(i,u.y),a=Math.max(a,u.x),o=Math.max(o,u.y),r.push(u)}for(var h={},f={},p=0,d=this.grid.query(n,i,a,o).concat(this.ignoredGrid.query(n,i,a,o));p<d.length;p+=1){var g=d[p],v=g.key;if(void 0===h[v.bucketInstanceId]&&(h[v.bucketInstanceId]={}),!h[v.bucketInstanceId][v.featureIndex]){var m=[new t.Point(g.x1,g.y1),new t.Point(g.x2,g.y1),new t.Point(g.x2,g.y2),new t.Point(g.x1,g.y2)];t.polygonIntersectsPolygon(r,m)&&(h[v.bucketInstanceId][v.featureIndex]=!0,void 0===f[v.bucketInstanceId]&&(f[v.bucketInstanceId]=[]),f[v.bucketInstanceId].push(v.featureIndex))}}return f},oe.prototype.insertCollisionBox=function(t,e,r,n,i){var a={bucketInstanceId:r,featureIndex:n,collisionGroupID:i};(e?this.ignoredGrid:this.grid).insert(a,t[0],t[1],t[2],t[3])},oe.prototype.insertCollisionCircles=function(t,e,r,n,i){for(var a=e?this.ignoredGrid:this.grid,o={bucketInstanceId:r,featureIndex:n,collisionGroupID:i},s=0;s<t.length;s+=4)a.insertCircle(o,t[s],t[s+1],t[s+2])},oe.prototype.projectAnchor=function(t,e,r){var n=[e,r,0,1];return ae(n,n,t),{perspectiveRatio:.5+this.transform.cameraToCenterDistance/n[3]*.5,cameraDistance:n[3]}},oe.prototype.projectPoint=function(e,r,n){var i=[r,n,0,1];return ae(i,i,e),new t.Point((i[0]/i[3]+1)/2*this.transform.width+100,(-i[1]/i[3]+1)/2*this.transform.height+100)},oe.prototype.projectAndGetPerspectiveRatio=function(e,r,n){var i=[r,n,0,1];return ae(i,i,e),{point:new t.Point((i[0]/i[3]+1)/2*this.transform.width+100,(-i[1]/i[3]+1)/2*this.transform.height+100),perspectiveRatio:.5+this.transform.cameraToCenterDistance/i[3]*.5}},oe.prototype.isOffscreen=function(t,e,r,n){return r<100||t>=this.screenRightBoundary||n<100||e>this.screenBottomBoundary},oe.prototype.isInsideGrid=function(t,e,r,n){return r>=0&&t<this.gridRightBoundary&&n>=0&&e<this.gridBottomBoundary};var ce=function(t,e,r,n){this.opacity=t?Math.max(0,Math.min(1,t.opacity+(t.placed?e:-e))):n&&r?1:0,this.placed=r};ce.prototype.isHidden=function(){return 0===this.opacity&&!this.placed};var ue=function(t,e,r,n,i){this.text=new ce(t?t.text:null,e,r,i),this.icon=new ce(t?t.icon:null,e,n,i)};ue.prototype.isHidden=function(){return this.text.isHidden()&&this.icon.isHidden()};var he=function(t,e,r){this.text=t,this.icon=e,this.skipFade=r},fe=function(t,e,r,n,i){this.bucketInstanceId=t,this.featureIndex=e,this.sourceLayerIndex=r,this.bucketIndex=n,this.tileID=i},pe=function(t){this.crossSourceCollisions=t,this.maxGroupID=0,this.collisionGroups={}};function de(e,r,n,i,a){var o=t.getAnchorAlignment(e),s=-(o.horizontalAlign-.5)*r,l=-(o.verticalAlign-.5)*n,c=t.evaluateRadialOffset(e,i);return new t.Point(s+c[0]*a,l+c[1]*a)}pe.prototype.get=function(t){if(this.crossSourceCollisions)return{ID:0,predicate:null};if(!this.collisionGroups[t]){var e=++this.maxGroupID;this.collisionGroups[t]={ID:e,predicate:function(t){return t.collisionGroupID===e}}}return this.collisionGroups[t]};var ge=function(t,e,r,n){this.transform=t.clone(),this.collisionIndex=new oe(this.transform),this.placements={},this.opacities={},this.variableOffsets={},this.stale=!1,this.commitTime=0,this.fadeDuration=e,this.retainedQueryData={},this.collisionGroups=new pe(r),this.prevPlacement=n,n&&(n.prevPlacement=void 0)};function ve(t,e,r,n,i){t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0)}ge.prototype.placeLayerTile=function(e,r,n,i){var a=r.getBucket(e),o=r.latestFeatureIndex;if(a&&o&&e.id===a.layerIds[0]){var s=r.collisionBoxArray,l=a.layers[0].layout,c=Math.pow(2,this.transform.zoom-r.tileID.overscaledZ),u=r.tileSize/t.EXTENT,h=this.transform.calculatePosMatrix(r.tileID.toUnwrapped()),f=Wt(h,\"map\"===l.get(\"text-pitch-alignment\"),\"map\"===l.get(\"text-rotation-alignment\"),this.transform,le(r,1,this.transform.zoom)),p=Wt(h,\"map\"===l.get(\"icon-pitch-alignment\"),\"map\"===l.get(\"icon-rotation-alignment\"),this.transform,le(r,1,this.transform.zoom));this.retainedQueryData[a.bucketInstanceId]=new fe(a.bucketInstanceId,o,a.sourceLayerIndex,a.index,r.tileID),this.placeLayerBucket(a,h,f,p,c,u,n,r.holdingForFade(),i,s)}},ge.prototype.attemptAnchorPlacement=function(e,r,n,i,a,o,s,l,c,u,h,f,p,d){var g,v=de(e,n,i,a,o),m=this.collisionIndex.placeCollisionBox(function(e,r,n,i,a,o){var s=e.x1,l=e.x2,c=e.y1,u=e.y2,h=e.anchorPointX,f=e.anchorPointY,p=new t.Point(r,n);return i&&p._rotate(a?o:-o),{x1:s+p.x,y1:c+p.y,x2:l+p.x,y2:u+p.y,anchorPointX:h,anchorPointY:f}}(r,v.x,v.y,s,l,this.transform.angle),f,c,u,h.predicate);if(m.box.length>0)return this.prevPlacement&&this.prevPlacement.variableOffsets[p.crossTileID]&&this.prevPlacement.placements[p.crossTileID]&&this.prevPlacement.placements[p.crossTileID].text&&(g=this.prevPlacement.variableOffsets[p.crossTileID].anchor),this.variableOffsets[p.crossTileID]={radialOffset:a,width:n,height:i,anchor:e,textBoxScale:o,prevAnchor:g},this.markUsedJustification(d,e,p),m},ge.prototype.placeLayerBucket=function(e,r,n,i,a,o,s,l,c,u){var h=this,f=e.layers[0].layout,p=t.evaluateSizeForZoom(e.textSizeData,this.transform.zoom),d=f.get(\"text-optional\"),g=f.get(\"icon-optional\"),v=f.get(\"text-allow-overlap\"),m=f.get(\"icon-allow-overlap\"),y=v&&(m||!e.hasIconData()||g),x=m&&(v||!e.hasTextData()||d),b=this.collisionGroups.get(e.sourceID),_=\"map\"===f.get(\"text-rotation-alignment\"),w=\"map\"===f.get(\"text-pitch-alignment\"),k=\"viewport-y\"===f.get(\"symbol-z-order\");!e.collisionArrays&&u&&e.deserializeCollisionBoxes(u);var T=function(i,u){if(!c[i.crossTileID])if(l)h.placements[i.crossTileID]=new he(!1,!1,!1);else{var m=!1,k=!1,T=!0,A=null,M=null,S=null,E=0,C=0;u.textFeatureIndex&&(E=u.textFeatureIndex);var L=u.textBox;if(L)if(f.get(\"text-variable-anchor\")){var P=L.x2-L.x1,O=L.y2-L.y1,z=i.textBoxScale,I=f.get(\"text-variable-anchor\");if(h.prevPlacement&&h.prevPlacement.variableOffsets[i.crossTileID]){var D=h.prevPlacement.variableOffsets[i.crossTileID];I[0]!==D.anchor&&(I=I.filter(function(t){return t!==D.anchor})).unshift(D.anchor)}for(var R=0,F=I;R<F.length;R+=1){var B=F[R];if(A=h.attemptAnchorPlacement(B,L,P,O,i.radialTextOffset,z,_,w,o,r,b,v,i,e)){m=!0;break}}if(!h.variableOffsets[i.crossTileID]&&h.prevPlacement){var N=h.prevPlacement.variableOffsets[i.crossTileID];N&&(h.variableOffsets[i.crossTileID]=N,h.markUsedJustification(e,N.anchor,i))}}else m=(A=h.collisionIndex.placeCollisionBox(L,f.get(\"text-allow-overlap\"),o,r,b.predicate)).box.length>0;T=A&&A.offscreen;var j=u.textCircles;if(j){var U=e.text.placedSymbolArray.get(i.centerJustifiedTextSymbolIndex),V=t.evaluateSizeForFeature(e.textSizeData,p,U);M=h.collisionIndex.placeCollisionCircles(j,f.get(\"text-allow-overlap\"),a,o,U,e.lineVertexArray,e.glyphOffsetArray,V,r,n,s,w,b.predicate),m=f.get(\"text-allow-overlap\")||M.circles.length>0,T=T&&M.offscreen}u.iconFeatureIndex&&(C=u.iconFeatureIndex),u.iconBox&&(k=(S=h.collisionIndex.placeCollisionBox(u.iconBox,f.get(\"icon-allow-overlap\"),o,r,b.predicate)).box.length>0,T=T&&S.offscreen);var q=d||0===i.numHorizontalGlyphVertices&&0===i.numVerticalGlyphVertices,H=g||0===i.numIconVertices;q||H?H?q||(k=k&&m):m=k&&m:k=m=k&&m,m&&A&&h.collisionIndex.insertCollisionBox(A.box,f.get(\"text-ignore-placement\"),e.bucketInstanceId,E,b.ID),k&&S&&h.collisionIndex.insertCollisionBox(S.box,f.get(\"icon-ignore-placement\"),e.bucketInstanceId,C,b.ID),m&&M&&h.collisionIndex.insertCollisionCircles(M.circles,f.get(\"text-ignore-placement\"),e.bucketInstanceId,E,b.ID),h.placements[i.crossTileID]=new he(m||y,k||x,T||e.justReloaded),c[i.crossTileID]=!0}};if(k)for(var A=e.getSortedSymbolIndexes(this.transform.angle),M=A.length-1;M>=0;--M){var S=A[M];T(e.symbolInstances.get(S),e.collisionArrays[S])}else for(var E=0;E<e.symbolInstances.length;++E)T(e.symbolInstances.get(E),e.collisionArrays[E]);e.justReloaded=!1},ge.prototype.markUsedJustification=function(e,r,n){var i={left:n.leftJustifiedTextSymbolIndex,center:n.centerJustifiedTextSymbolIndex,right:n.rightJustifiedTextSymbolIndex},a=i[t.getAnchorJustification(r)];for(var o in i){var s=i[o];s>=0&&(e.text.placedSymbolArray.get(s).crossTileID=a>=0&&s!==a?0:n.crossTileID)}},ge.prototype.commit=function(t){this.commitTime=t;var e=this.prevPlacement,r=!1,n=e&&0!==this.fadeDuration?(this.commitTime-e.commitTime)/this.fadeDuration:1,i=e?e.opacities:{},a=e?e.variableOffsets:{};for(var o in this.placements){var s=this.placements[o],l=i[o];l?(this.opacities[o]=new ue(l,n,s.text,s.icon),r=r||s.text!==l.text.placed||s.icon!==l.icon.placed):(this.opacities[o]=new ue(null,n,s.text,s.icon,s.skipFade),r=r||s.text||s.icon)}for(var c in i){var u=i[c];if(!this.opacities[c]){var h=new ue(u,n,!1,!1);h.isHidden()||(this.opacities[c]=h,r=r||u.text.placed||u.icon.placed)}}for(var f in a)this.variableOffsets[f]||!this.opacities[f]||this.opacities[f].isHidden()||(this.variableOffsets[f]=a[f]);r?this.lastPlacementChangeTime=t:\"number\"!=typeof this.lastPlacementChangeTime&&(this.lastPlacementChangeTime=e?e.lastPlacementChangeTime:t)},ge.prototype.updateLayerOpacities=function(t,e){for(var r={},n=0,i=e;n<i.length;n+=1){var a=i[n],o=a.getBucket(t);o&&a.latestFeatureIndex&&t.id===o.layerIds[0]&&this.updateBucketOpacities(o,r,a.collisionBoxArray)}},ge.prototype.updateBucketOpacities=function(e,r,n){e.hasTextData()&&e.text.opacityVertexArray.clear(),e.hasIconData()&&e.icon.opacityVertexArray.clear(),e.hasCollisionBoxData()&&e.collisionBox.collisionVertexArray.clear(),e.hasCollisionCircleData()&&e.collisionCircle.collisionVertexArray.clear();var i=e.layers[0].layout,a=new ue(null,0,!1,!1,!0),o=i.get(\"text-allow-overlap\"),s=i.get(\"icon-allow-overlap\"),l=i.get(\"text-variable-anchor\"),c=\"map\"===i.get(\"text-rotation-alignment\"),u=\"map\"===i.get(\"text-pitch-alignment\"),h=new ue(null,0,o&&(s||!e.hasIconData()||i.get(\"icon-optional\")),s&&(o||!e.hasTextData()||i.get(\"text-optional\")),!0);!e.collisionArrays&&n&&(e.hasCollisionBoxData()||e.hasCollisionCircleData())&&e.deserializeCollisionBoxes(n);for(var f=0;f<e.symbolInstances.length;f++){var p=e.symbolInstances.get(f),d=p.numHorizontalGlyphVertices,g=p.numVerticalGlyphVertices,v=p.crossTileID,m=r[v],y=this.opacities[v];m?y=a:y||(y=h,this.opacities[v]=y),r[v]=!0;var x=d>0||g>0,b=p.numIconVertices>0;if(x){for(var _=Te(y.text),w=(d+g)/4,k=0;k<w;k++)e.text.opacityVertexArray.emplaceBack(_);var T=y.text.isHidden()?1:0;[p.rightJustifiedTextSymbolIndex,p.centerJustifiedTextSymbolIndex,p.leftJustifiedTextSymbolIndex,p.verticalPlacedTextSymbolIndex].forEach(function(t){t>=0&&(e.text.placedSymbolArray.get(t).hidden=T)});var A=this.variableOffsets[p.crossTileID];A&&this.markUsedJustification(e,A.anchor,p)}if(b){for(var M=Te(y.icon),S=0;S<p.numIconVertices/4;S++)e.icon.opacityVertexArray.emplaceBack(M);e.icon.placedSymbolArray.get(f).hidden=y.icon.isHidden()}if(e.hasCollisionBoxData()||e.hasCollisionCircleData()){var E=e.collisionArrays[f];if(E){if(E.textBox){var C=new t.Point(0,0),L=!0;if(l){var P=this.variableOffsets[v];P?(C=de(P.anchor,P.width,P.height,P.radialOffset,P.textBoxScale),c&&C._rotate(u?this.transform.angle:-this.transform.angle)):L=!1}ve(e.collisionBox.collisionVertexArray,y.text.placed,!L,C.x,C.y)}E.iconBox&&ve(e.collisionBox.collisionVertexArray,y.icon.placed,!1);var O=E.textCircles;if(O&&e.hasCollisionCircleData())for(var z=0;z<O.length;z+=5){var I=m||0===O[z+4];ve(e.collisionCircle.collisionVertexArray,y.text.placed,I)}}}}e.sortFeatures(this.transform.angle),this.retainedQueryData[e.bucketInstanceId]&&(this.retainedQueryData[e.bucketInstanceId].featureSortOrder=e.featureSortOrder),e.hasTextData()&&e.text.opacityVertexBuffer&&e.text.opacityVertexBuffer.updateData(e.text.opacityVertexArray),e.hasIconData()&&e.icon.opacityVertexBuffer&&e.icon.opacityVertexBuffer.updateData(e.icon.opacityVertexArray),e.hasCollisionBoxData()&&e.collisionBox.collisionVertexBuffer&&e.collisionBox.collisionVertexBuffer.updateData(e.collisionBox.collisionVertexArray),e.hasCollisionCircleData()&&e.collisionCircle.collisionVertexBuffer&&e.collisionCircle.collisionVertexBuffer.updateData(e.collisionCircle.collisionVertexArray)},ge.prototype.symbolFadeChange=function(t){return 0===this.fadeDuration?1:(t-this.commitTime)/this.fadeDuration},ge.prototype.hasTransitions=function(t){return this.stale||t-this.lastPlacementChangeTime<this.fadeDuration},ge.prototype.stillRecent=function(t){return this.commitTime+this.fadeDuration>t},ge.prototype.setStale=function(){this.stale=!0};var me=Math.pow(2,25),ye=Math.pow(2,24),xe=Math.pow(2,17),be=Math.pow(2,16),_e=Math.pow(2,9),we=Math.pow(2,8),ke=Math.pow(2,1);function Te(t){if(0===t.opacity&&!t.placed)return 0;if(1===t.opacity&&t.placed)return 4294967295;var e=t.placed?1:0,r=Math.floor(127*t.opacity);return r*me+e*ye+r*xe+e*be+r*_e+e*we+r*ke+e}var Ae=function(){this._currentTileIndex=0,this._seenCrossTileIDs={}};Ae.prototype.continuePlacement=function(t,e,r,n,i){for(;this._currentTileIndex<t.length;){var a=t[this._currentTileIndex];if(e.placeLayerTile(n,a,r,this._seenCrossTileIDs),this._currentTileIndex++,i())return!0}};var Me=function(t,e,r,n,i,a,o){this.placement=new ge(t,i,a,o),this._currentPlacementIndex=e.length-1,this._forceFullPlacement=r,this._showCollisionBoxes=n,this._done=!1};Me.prototype.isDone=function(){return this._done},Me.prototype.continuePlacement=function(e,r,n){for(var i=this,a=t.browser.now(),o=function(){var e=t.browser.now()-a;return!i._forceFullPlacement&&e>2};this._currentPlacementIndex>=0;){var s=r[e[this._currentPlacementIndex]],l=this.placement.collisionIndex.transform.zoom;if(\"symbol\"===s.type&&(!s.minzoom||s.minzoom<=l)&&(!s.maxzoom||s.maxzoom>l)){if(this._inProgressLayer||(this._inProgressLayer=new Ae),this._inProgressLayer.continuePlacement(n[s.source],this.placement,this._showCollisionBoxes,s,o))return;delete this._inProgressLayer}this._currentPlacementIndex--}this._done=!0},Me.prototype.commit=function(t){return this.placement.commit(t),this.placement};var Se=512/t.EXTENT/2,Ee=function(t,e,r){this.tileID=t,this.indexedSymbolInstances={},this.bucketInstanceId=r;for(var n=0;n<e.length;n++){var i=e.get(n),a=i.key;this.indexedSymbolInstances[a]||(this.indexedSymbolInstances[a]=[]),this.indexedSymbolInstances[a].push({crossTileID:i.crossTileID,coord:this.getScaledCoordinates(i,t)})}};Ee.prototype.getScaledCoordinates=function(e,r){var n=r.canonical.z-this.tileID.canonical.z,i=Se/Math.pow(2,n);return{x:Math.floor((r.canonical.x*t.EXTENT+e.anchorX)*i),y:Math.floor((r.canonical.y*t.EXTENT+e.anchorY)*i)}},Ee.prototype.findMatches=function(t,e,r){for(var n=this.tileID.canonical.z<e.canonical.z?1:Math.pow(2,this.tileID.canonical.z-e.canonical.z),i=0;i<t.length;i++){var a=t.get(i);if(!a.crossTileID){var o=this.indexedSymbolInstances[a.key];if(o)for(var s=this.getScaledCoordinates(a,e),l=0,c=o;l<c.length;l+=1){var u=c[l];if(Math.abs(u.coord.x-s.x)<=n&&Math.abs(u.coord.y-s.y)<=n&&!r[u.crossTileID]){r[u.crossTileID]=!0,a.crossTileID=u.crossTileID;break}}}}};var Ce=function(){this.maxCrossTileID=0};Ce.prototype.generate=function(){return++this.maxCrossTileID};var Le=function(){this.indexes={},this.usedCrossTileIDs={},this.lng=0};Le.prototype.handleWrapJump=function(t){var e=Math.round((t-this.lng)/360);if(0!==e)for(var r in this.indexes){var n=this.indexes[r],i={};for(var a in n){var o=n[a];o.tileID=o.tileID.unwrapTo(o.tileID.wrap+e),i[o.tileID.key]=o}this.indexes[r]=i}this.lng=t},Le.prototype.addBucket=function(t,e,r){if(this.indexes[t.overscaledZ]&&this.indexes[t.overscaledZ][t.key]){if(this.indexes[t.overscaledZ][t.key].bucketInstanceId===e.bucketInstanceId)return!1;this.removeBucketCrossTileIDs(t.overscaledZ,this.indexes[t.overscaledZ][t.key])}for(var n=0;n<e.symbolInstances.length;n++)e.symbolInstances.get(n).crossTileID=0;this.usedCrossTileIDs[t.overscaledZ]||(this.usedCrossTileIDs[t.overscaledZ]={});var i=this.usedCrossTileIDs[t.overscaledZ];for(var a in this.indexes){var o=this.indexes[a];if(Number(a)>t.overscaledZ)for(var s in o){var l=o[s];l.tileID.isChildOf(t)&&l.findMatches(e.symbolInstances,t,i)}else{var c=o[t.scaledTo(Number(a)).key];c&&c.findMatches(e.symbolInstances,t,i)}}for(var u=0;u<e.symbolInstances.length;u++){var h=e.symbolInstances.get(u);h.crossTileID||(h.crossTileID=r.generate(),i[h.crossTileID]=!0)}return void 0===this.indexes[t.overscaledZ]&&(this.indexes[t.overscaledZ]={}),this.indexes[t.overscaledZ][t.key]=new Ee(t,e.symbolInstances,e.bucketInstanceId),!0},Le.prototype.removeBucketCrossTileIDs=function(t,e){for(var r in e.indexedSymbolInstances)for(var n=0,i=e.indexedSymbolInstances[r];n<i.length;n+=1){var a=i[n];delete this.usedCrossTileIDs[t][a.crossTileID]}},Le.prototype.removeStaleBuckets=function(t){var e=!1;for(var r in this.indexes){var n=this.indexes[r];for(var i in n)t[n[i].bucketInstanceId]||(this.removeBucketCrossTileIDs(r,n[i]),delete n[i],e=!0)}return e};var Pe=function(){this.layerIndexes={},this.crossTileIDs=new Ce,this.maxBucketInstanceId=0,this.bucketsInCurrentPlacement={}};Pe.prototype.addLayer=function(t,e,r){var n=this.layerIndexes[t.id];void 0===n&&(n=this.layerIndexes[t.id]=new Le);var i=!1,a={};n.handleWrapJump(r);for(var o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.getBucket(t);c&&t.id===c.layerIds[0]&&(c.bucketInstanceId||(c.bucketInstanceId=++this.maxBucketInstanceId),n.addBucket(l.tileID,c,this.crossTileIDs)&&(i=!0),a[c.bucketInstanceId]=!0)}return n.removeStaleBuckets(a)&&(i=!0),i},Pe.prototype.pruneUnusedLayers=function(t){var e={};for(var r in t.forEach(function(t){e[t]=!0}),this.layerIndexes)e[r]||delete this.layerIndexes[r]};var Oe=function(e,r){return t.emitValidationErrors(e,r&&r.filter(function(t){return\"source.canvas\"!==t.identifier}))},ze=t.pick(Bt,[\"addLayer\",\"removeLayer\",\"setPaintProperty\",\"setLayoutProperty\",\"setFilter\",\"addSource\",\"removeSource\",\"setLayerZoomRange\",\"setLight\",\"setTransition\",\"setGeoJSONSourceData\"]),Ie=t.pick(Bt,[\"setCenter\",\"setZoom\",\"setBearing\",\"setPitch\"]),De=function(e){function r(n,i){var a=this;void 0===i&&(i={}),e.call(this),this.map=n,this.dispatcher=new k((It||(It=new zt),It),this),this.imageManager=new f,this.imageManager.setEventedParent(this),this.glyphManager=new y(n._requestManager,i.localIdeographFontFamily),this.lineAtlas=new w(256,512),this.crossTileSymbolIndex=new Pe,this._layers={},this._order=[],this.sourceCaches={},this.zoomHistory=new t.ZoomHistory,this._loaded=!1,this._resetUpdates(),this.dispatcher.broadcast(\"setReferrer\",t.getReferrer());var o=this;this._rtlTextPluginCallback=r.registerForPluginAvailability(function(t){for(var e in o.dispatcher.broadcast(\"loadRTLTextPlugin\",t.pluginURL,t.completionCallback),o.sourceCaches)o.sourceCaches[e].reload()}),this.on(\"data\",function(t){if(\"source\"===t.dataType&&\"metadata\"===t.sourceDataType){var e=a.sourceCaches[t.sourceId];if(e){var r=e.getSource();if(r&&r.vectorLayerIds)for(var n in a._layers){var i=a._layers[n];i.source===r.id&&a._validateLayer(i)}}}})}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadURL=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"}));var i=\"boolean\"==typeof r.validate?r.validate:!t.isMapboxURL(e);e=this.map._requestManager.normalizeStyleURL(e,r.accessToken);var a=this.map._requestManager.transformRequest(e,t.ResourceType.Style);this._request=t.getJSON(a,function(e,r){n._request=null,e?n.fire(new t.ErrorEvent(e)):r&&n._load(r,i)})},r.prototype.loadJSON=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"})),this._request=t.browser.frame(function(){n._request=null,n._load(e,!1!==r.validate)})},r.prototype._load=function(e,r){var n=this;if(!r||!Oe(this,t.validateStyle(e))){for(var i in this._loaded=!0,this.stylesheet=e,e.sources)this.addSource(i,e.sources[i],{validate:!1});e.sprite?this._spriteRequest=function(e,r,n){var i,a,o,s=t.browser.devicePixelRatio>1?\"@2x\":\"\",l=t.getJSON(r.transformRequest(r.normalizeSpriteURL(e,s,\".json\"),t.ResourceType.SpriteJSON),function(t,e){l=null,o||(o=t,i=e,u())}),c=t.getImage(r.transformRequest(r.normalizeSpriteURL(e,s,\".png\"),t.ResourceType.SpriteImage),function(t,e){c=null,o||(o=t,a=e,u())});function u(){if(o)n(o);else if(i&&a){var e=t.browser.getImageData(a),r={};for(var s in i){var l=i[s],c=l.width,u=l.height,h=l.x,f=l.y,p=l.sdf,d=l.pixelRatio,g=new t.RGBAImage({width:c,height:u});t.RGBAImage.copy(e,g,{x:h,y:f},{x:0,y:0},{width:c,height:u}),r[s]={data:g,pixelRatio:d,sdf:p}}n(null,r)}}return{cancel:function(){l&&(l.cancel(),l=null),c&&(c.cancel(),c=null)}}}(e.sprite,this.map._requestManager,function(e,r){if(n._spriteRequest=null,e)n.fire(new t.ErrorEvent(e));else if(r)for(var i in r)n.imageManager.addImage(i,r[i]);n.imageManager.setLoaded(!0),n.fire(new t.Event(\"data\",{dataType:\"style\"}))}):this.imageManager.setLoaded(!0),this.glyphManager.setURL(e.glyphs);var a=Ft(this.stylesheet.layers);this._order=a.map(function(t){return t.id}),this._layers={};for(var o=0,s=a;o<s.length;o+=1){var l=s[o];(l=t.createStyleLayer(l)).setEventedParent(this,{layer:{id:l.id}}),this._layers[l.id]=l}this.dispatcher.broadcast(\"setLayers\",this._serializeLayers(this._order)),this.light=new _(this.stylesheet.light),this.fire(new t.Event(\"data\",{dataType:\"style\"})),this.fire(new t.Event(\"style.load\"))}},r.prototype._validateLayer=function(e){var r=this.sourceCaches[e.source];if(r){var n=e.sourceLayer;if(n){var i=r.getSource();(\"geojson\"===i.type||i.vectorLayerIds&&-1===i.vectorLayerIds.indexOf(n))&&this.fire(new t.ErrorEvent(new Error('Source layer \"'+n+'\" does not exist on source \"'+i.id+'\" as specified by style layer \"'+e.id+'\"')))}}},r.prototype.loaded=function(){if(!this._loaded)return!1;if(Object.keys(this._updatedSources).length)return!1;for(var t in this.sourceCaches)if(!this.sourceCaches[t].loaded())return!1;return!!this.imageManager.isLoaded()},r.prototype._serializeLayers=function(t){for(var e=[],r=0,n=t;r<n.length;r+=1){var i=n[r],a=this._layers[i];\"custom\"!==a.type&&e.push(a.serialize())}return e},r.prototype.hasTransitions=function(){if(this.light&&this.light.hasTransition())return!0;for(var t in this.sourceCaches)if(this.sourceCaches[t].hasTransition())return!0;for(var e in this._layers)if(this._layers[e].hasTransition())return!0;return!1},r.prototype._checkLoaded=function(){if(!this._loaded)throw new Error(\"Style is not done loading\")},r.prototype.update=function(e){if(this._loaded){var r=this._changed;if(this._changed){var n=Object.keys(this._updatedLayers),i=Object.keys(this._removedLayers);for(var a in(n.length||i.length)&&this._updateWorkerLayers(n,i),this._updatedSources){var o=this._updatedSources[a];\"reload\"===o?this._reloadSource(a):\"clear\"===o&&this._clearSource(a)}for(var s in this._updatedPaintProps)this._layers[s].updateTransitions(e);this.light.updateTransitions(e),this._resetUpdates()}for(var l in this.sourceCaches)this.sourceCaches[l].used=!1;for(var c=0,u=this._order;c<u.length;c+=1){var h=u[c],f=this._layers[h];f.recalculate(e),!f.isHidden(e.zoom)&&f.source&&(this.sourceCaches[f.source].used=!0)}this.light.recalculate(e),this.z=e.zoom,r&&this.fire(new t.Event(\"data\",{dataType:\"style\"}))}},r.prototype._updateWorkerLayers=function(t,e){this.dispatcher.broadcast(\"updateLayers\",{layers:this._serializeLayers(t),removedIds:e})},r.prototype._resetUpdates=function(){this._changed=!1,this._updatedLayers={},this._removedLayers={},this._updatedSources={},this._updatedPaintProps={}},r.prototype.setState=function(e){var r=this;if(this._checkLoaded(),Oe(this,t.validateStyle(e)))return!1;(e=t.clone$1(e)).layers=Ft(e.layers);var n=function(e,r){if(!e)return[{command:Bt.setStyle,args:[r]}];var n=[];try{if(!t.deepEqual(e.version,r.version))return[{command:Bt.setStyle,args:[r]}];t.deepEqual(e.center,r.center)||n.push({command:Bt.setCenter,args:[r.center]}),t.deepEqual(e.zoom,r.zoom)||n.push({command:Bt.setZoom,args:[r.zoom]}),t.deepEqual(e.bearing,r.bearing)||n.push({command:Bt.setBearing,args:[r.bearing]}),t.deepEqual(e.pitch,r.pitch)||n.push({command:Bt.setPitch,args:[r.pitch]}),t.deepEqual(e.sprite,r.sprite)||n.push({command:Bt.setSprite,args:[r.sprite]}),t.deepEqual(e.glyphs,r.glyphs)||n.push({command:Bt.setGlyphs,args:[r.glyphs]}),t.deepEqual(e.transition,r.transition)||n.push({command:Bt.setTransition,args:[r.transition]}),t.deepEqual(e.light,r.light)||n.push({command:Bt.setLight,args:[r.light]});var i={},a=[];!function(e,r,n,i){var a;for(a in r=r||{},e=e||{})e.hasOwnProperty(a)&&(r.hasOwnProperty(a)||jt(a,n,i));for(a in r)r.hasOwnProperty(a)&&(e.hasOwnProperty(a)?t.deepEqual(e[a],r[a])||(\"geojson\"===e[a].type&&\"geojson\"===r[a].type&&Vt(e,r,a)?n.push({command:Bt.setGeoJSONSourceData,args:[a,r[a].data]}):Ut(a,r,n,i)):Nt(a,r,n))}(e.sources,r.sources,a,i);var o=[];e.layers&&e.layers.forEach(function(t){i[t.source]?n.push({command:Bt.removeLayer,args:[t.id]}):o.push(t)}),n=n.concat(a),function(e,r,n){r=r||[];var i,a,o,s,l,c,u,h=(e=e||[]).map(Ht),f=r.map(Ht),p=e.reduce(Gt,{}),d=r.reduce(Gt,{}),g=h.slice(),v=Object.create(null);for(i=0,a=0;i<h.length;i++)o=h[i],d.hasOwnProperty(o)?a++:(n.push({command:Bt.removeLayer,args:[o]}),g.splice(g.indexOf(o,a),1));for(i=0,a=0;i<f.length;i++)o=f[f.length-1-i],g[g.length-1-i]!==o&&(p.hasOwnProperty(o)?(n.push({command:Bt.removeLayer,args:[o]}),g.splice(g.lastIndexOf(o,g.length-a),1)):a++,c=g[g.length-i],n.push({command:Bt.addLayer,args:[d[o],c]}),g.splice(g.length-i,0,o),v[o]=!0);for(i=0;i<f.length;i++)if(s=p[o=f[i]],l=d[o],!v[o]&&!t.deepEqual(s,l))if(t.deepEqual(s.source,l.source)&&t.deepEqual(s[\"source-layer\"],l[\"source-layer\"])&&t.deepEqual(s.type,l.type)){for(u in qt(s.layout,l.layout,n,o,null,Bt.setLayoutProperty),qt(s.paint,l.paint,n,o,null,Bt.setPaintProperty),t.deepEqual(s.filter,l.filter)||n.push({command:Bt.setFilter,args:[o,l.filter]}),t.deepEqual(s.minzoom,l.minzoom)&&t.deepEqual(s.maxzoom,l.maxzoom)||n.push({command:Bt.setLayerZoomRange,args:[o,l.minzoom,l.maxzoom]}),s)s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?qt(s[u],l[u],n,o,u.slice(6),Bt.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Bt.setLayerProperty,args:[o,u,l[u]]}));for(u in l)l.hasOwnProperty(u)&&!s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?qt(s[u],l[u],n,o,u.slice(6),Bt.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Bt.setLayerProperty,args:[o,u,l[u]]}))}else n.push({command:Bt.removeLayer,args:[o]}),c=g[g.lastIndexOf(o)+1],n.push({command:Bt.addLayer,args:[l,c]})}(o,r.layers,n)}catch(t){console.warn(\"Unable to compute style diff:\",t),n=[{command:Bt.setStyle,args:[r]}]}return n}(this.serialize(),e).filter(function(t){return!(t.command in Ie)});if(0===n.length)return!1;var i=n.filter(function(t){return!(t.command in ze)});if(i.length>0)throw new Error(\"Unimplemented: \"+i.map(function(t){return t.command}).join(\", \")+\".\");return n.forEach(function(t){\"setTransition\"!==t.command&&r[t.command].apply(r,t.args)}),this.stylesheet=e,!0},r.prototype.addImage=function(e,r){if(this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"An image with this name already exists.\")));this.imageManager.addImage(e,r),this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.updateImage=function(t,e){this.imageManager.updateImage(t,e)},r.prototype.getImage=function(t){return this.imageManager.getImage(t)},r.prototype.removeImage=function(e){if(!this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"No image with this name exists.\")));this.imageManager.removeImage(e),this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.listImages=function(){return this._checkLoaded(),this.imageManager.listImages()},r.prototype.addSource=function(e,r,n){var i=this;if(void 0===n&&(n={}),this._checkLoaded(),void 0!==this.sourceCaches[e])throw new Error(\"There is already a source with this ID\");if(!r.type)throw new Error(\"The type property must be defined, but the only the following properties were given: \"+Object.keys(r).join(\", \")+\".\");if(!([\"vector\",\"raster\",\"geojson\",\"video\",\"image\"].indexOf(r.type)>=0&&this._validate(t.validateStyle.source,\"sources.\"+e,r,null,n))){this.map&&this.map._collectResourceTiming&&(r.collectResourceTiming=!0);var a=this.sourceCaches[e]=new Ct(e,r,this.dispatcher);a.style=this,a.setEventedParent(this,function(){return{isSourceLoaded:i.loaded(),source:a.serialize(),sourceId:e}}),a.onAdd(this.map),this._changed=!0}},r.prototype.removeSource=function(e){if(this._checkLoaded(),void 0===this.sourceCaches[e])throw new Error(\"There is no source with this ID\");for(var r in this._layers)if(this._layers[r].source===e)return this.fire(new t.ErrorEvent(new Error('Source \"'+e+'\" cannot be removed while layer \"'+r+'\" is using it.')));var n=this.sourceCaches[e];delete this.sourceCaches[e],delete this._updatedSources[e],n.fire(new t.Event(\"data\",{sourceDataType:\"metadata\",dataType:\"source\",sourceId:e})),n.setEventedParent(null),n.clearTiles(),n.onRemove&&n.onRemove(this.map),this._changed=!0},r.prototype.setGeoJSONSourceData=function(t,e){this._checkLoaded(),this.sourceCaches[t].getSource().setData(e),this._changed=!0},r.prototype.getSource=function(t){return this.sourceCaches[t]&&this.sourceCaches[t].getSource()},r.prototype.addLayer=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=e.id;if(this.getLayer(i))this.fire(new t.ErrorEvent(new Error('Layer with id \"'+i+'\" already exists on this map')));else{var a;if(\"custom\"===e.type){if(Oe(this,t.validateCustomStyleLayer(e)))return;a=t.createStyleLayer(e)}else{if(\"object\"==typeof e.source&&(this.addSource(i,e.source),e=t.clone$1(e),e=t.extend(e,{source:i})),this._validate(t.validateStyle.layer,\"layers.\"+i,e,{arrayIndex:-1},n))return;a=t.createStyleLayer(e),this._validateLayer(a),a.setEventedParent(this,{layer:{id:i}})}var o=r?this._order.indexOf(r):this._order.length;if(r&&-1===o)this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.')));else{if(this._order.splice(o,0,i),this._layerOrderChanged=!0,this._layers[i]=a,this._removedLayers[i]&&a.source&&\"custom\"!==a.type){var s=this._removedLayers[i];delete this._removedLayers[i],s.type!==a.type?this._updatedSources[a.source]=\"clear\":(this._updatedSources[a.source]=\"reload\",this.sourceCaches[a.source].pause())}this._updateLayer(a),a.onAdd&&a.onAdd(this.map)}}},r.prototype.moveLayer=function(e,r){if(this._checkLoaded(),this._changed=!0,this._layers[e]){if(e!==r){var n=this._order.indexOf(e);this._order.splice(n,1);var i=r?this._order.indexOf(r):this._order.length;r&&-1===i?this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.'))):(this._order.splice(i,0,e),this._layerOrderChanged=!0)}}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be moved.\")))},r.prototype.removeLayer=function(e){this._checkLoaded();var r=this._layers[e];if(r){r.setEventedParent(null);var n=this._order.indexOf(e);this._order.splice(n,1),this._layerOrderChanged=!0,this._changed=!0,this._removedLayers[e]=r,delete this._layers[e],delete this._updatedLayers[e],delete this._updatedPaintProps[e],r.onRemove&&r.onRemove(this.map)}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be removed.\")))},r.prototype.getLayer=function(t){return this._layers[t]},r.prototype.setLayerZoomRange=function(e,r,n){this._checkLoaded();var i=this.getLayer(e);i?i.minzoom===r&&i.maxzoom===n||(null!=r&&(i.minzoom=r),null!=n&&(i.maxzoom=n),this._updateLayer(i)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot have zoom extent.\")))},r.prototype.setFilter=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=this.getLayer(e);if(i){if(!t.deepEqual(i.filter,r))return null==r?(i.filter=void 0,void this._updateLayer(i)):void(this._validate(t.validateStyle.filter,\"layers.\"+i.id+\".filter\",r,null,n)||(i.filter=t.clone$1(r),this._updateLayer(i)))}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be filtered.\")))},r.prototype.getFilter=function(e){return t.clone$1(this.getLayer(e).filter)},r.prototype.setLayoutProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getLayoutProperty(r),n)||(a.setLayoutProperty(r,n,i),this._updateLayer(a)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getLayoutProperty=function(e,r){var n=this.getLayer(e);if(n)return n.getLayoutProperty(r);this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style.\")))},r.prototype.setPaintProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getPaintProperty(r),n)||(a.setPaintProperty(r,n,i)&&this._updateLayer(a),this._changed=!0,this._updatedPaintProps[e]=!0):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getPaintProperty=function(t,e){return this.getLayer(t).getPaintProperty(e)},r.prototype.setFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=e.sourceLayer,a=this.sourceCaches[n],o=parseInt(e.id,10);if(void 0!==a){var s=a.getSource().type;\"geojson\"===s&&i?this.fire(new t.ErrorEvent(new Error(\"GeoJSON sources cannot have a sourceLayer parameter.\"))):\"vector\"!==s||i?isNaN(o)||o<0?this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided and non-negative.\"))):a.setFeatureState(i,o,r):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.removeFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=this.sourceCaches[n];if(void 0!==i){var a=i.getSource().type,o=\"vector\"===a?e.sourceLayer:void 0,s=parseInt(e.id,10);\"vector\"!==a||o?void 0!==e.id&&isNaN(s)||s<0?this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be non-negative.\"))):r&&\"string\"!=typeof e.id&&\"number\"!=typeof e.id?this.fire(new t.ErrorEvent(new Error(\"A feature id is requred to remove its specific state property.\"))):i.removeFeatureState(o,s,r):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.getFeatureState=function(e){this._checkLoaded();var r=e.source,n=e.sourceLayer,i=this.sourceCaches[r],a=parseInt(e.id,10);if(void 0!==i)if(\"vector\"!==i.getSource().type||n){if(!(isNaN(a)||a<0))return i.getFeatureState(n,a);this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided and non-negative.\")))}else this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")));else this.fire(new t.ErrorEvent(new Error(\"The source '\"+r+\"' does not exist in the map's style.\")))},r.prototype.getTransition=function(){return t.extend({duration:300,delay:0},this.stylesheet&&this.stylesheet.transition)},r.prototype.serialize=function(){return t.filterObject({version:this.stylesheet.version,name:this.stylesheet.name,metadata:this.stylesheet.metadata,light:this.stylesheet.light,center:this.stylesheet.center,zoom:this.stylesheet.zoom,bearing:this.stylesheet.bearing,pitch:this.stylesheet.pitch,sprite:this.stylesheet.sprite,glyphs:this.stylesheet.glyphs,transition:this.stylesheet.transition,sources:t.mapObject(this.sourceCaches,function(t){return t.serialize()}),layers:this._serializeLayers(this._order)},function(t){return void 0!==t})},r.prototype._updateLayer=function(t){this._updatedLayers[t.id]=!0,t.source&&!this._updatedSources[t.source]&&(this._updatedSources[t.source]=\"reload\",this.sourceCaches[t.source].pause()),this._changed=!0},r.prototype._flattenAndSortRenderedFeatures=function(t){for(var e=this,r=function(t){return\"fill-extrusion\"===e._layers[t].type},n={},i=[],a=this._order.length-1;a>=0;a--){var o=this._order[a];if(r(o)){n[o]=a;for(var s=0,l=t;s<l.length;s+=1){var c=l[s][o];if(c)for(var u=0,h=c;u<h.length;u+=1){var f=h[u];i.push(f)}}}}i.sort(function(t,e){return e.intersectionZ-t.intersectionZ});for(var p=[],d=this._order.length-1;d>=0;d--){var g=this._order[d];if(r(g))for(var v=i.length-1;v>=0;v--){var m=i[v].feature;if(n[m.layer.id]<d)break;p.push(m),i.pop()}else for(var y=0,x=t;y<x.length;y+=1){var b=x[y][g];if(b)for(var _=0,w=b;_<w.length;_+=1){var k=w[_];p.push(k.feature)}}}return p},r.prototype.queryRenderedFeatures=function(e,r,n){r&&r.filter&&this._validate(t.validateStyle.filter,\"queryRenderedFeatures.filter\",r.filter,null,r);var i={};if(r&&r.layers){if(!Array.isArray(r.layers))return this.fire(new t.ErrorEvent(new Error(\"parameters.layers must be an Array.\"))),[];for(var a=0,o=r.layers;a<o.length;a+=1){var s=o[a],l=this._layers[s];if(!l)return this.fire(new t.ErrorEvent(new Error(\"The layer '\"+s+\"' does not exist in the map's style and cannot be queried for features.\"))),[];i[l.source]=!0}}var c=[];for(var u in this.sourceCaches)r.layers&&!i[u]||c.push(R(this.sourceCaches[u],this._layers,e,r,n));return this.placement&&c.push(function(t,e,r,n,i,a){for(var o={},s=i.queryRenderedSymbols(r),l=[],c=0,u=Object.keys(s).map(Number);c<u.length;c+=1){var h=u[c];l.push(a[h])}l.sort(F);for(var f=function(){var e=d[p],r=e.featureIndex.lookupSymbolFeatures(s[e.bucketInstanceId],e.bucketIndex,e.sourceLayerIndex,n.filter,n.layers,t);for(var i in r){var a=o[i]=o[i]||[],l=r[i];l.sort(function(t,r){var n=e.featureSortOrder;if(n){var i=n.indexOf(t.featureIndex);return n.indexOf(r.featureIndex)-i}return r.featureIndex-t.featureIndex});for(var c=0,u=l;c<u.length;c+=1){var h=u[c];a.push(h)}}},p=0,d=l;p<d.length;p+=1)f();var g=function(r){o[r].forEach(function(n){var i=n.feature,a=t[r],o=e[a.source].getFeatureState(i.layer[\"source-layer\"],i.id);i.source=i.layer.source,i.layer[\"source-layer\"]&&(i.sourceLayer=i.layer[\"source-layer\"]),i.state=o})};for(var v in o)g(v);return o}(this._layers,this.sourceCaches,e,r,this.placement.collisionIndex,this.placement.retainedQueryData)),this._flattenAndSortRenderedFeatures(c)},r.prototype.querySourceFeatures=function(e,r){r&&r.filter&&this._validate(t.validateStyle.filter,\"querySourceFeatures.filter\",r.filter,null,r);var n=this.sourceCaches[e];return n?function(t,e){for(var r=t.getRenderableIds().map(function(e){return t.getTileByID(e)}),n=[],i={},a=0;a<r.length;a++){var o=r[a],s=o.tileID.canonical.key;i[s]||(i[s]=!0,o.querySourceFeatures(n,e))}return n}(n,r):[]},r.prototype.addSourceType=function(t,e,n){return r.getSourceType(t)?n(new Error('A source type called \"'+t+'\" already exists.')):(r.setSourceType(t,e),e.workerSourceURL?void this.dispatcher.broadcast(\"loadWorkerSource\",{name:t,url:e.workerSourceURL},n):n(null,null))},r.prototype.getLight=function(){return this.light.getLight()},r.prototype.setLight=function(e,r){void 0===r&&(r={}),this._checkLoaded();var n=this.light.getLight(),i=!1;for(var a in e)if(!t.deepEqual(e[a],n[a])){i=!0;break}if(i){var o={now:t.browser.now(),transition:t.extend({duration:300,delay:0},this.stylesheet.transition)};this.light.setLight(e,r),this.light.updateTransitions(o)}},r.prototype._validate=function(e,r,n,i,a){return void 0===a&&(a={}),(!a||!1!==a.validate)&&Oe(this,e.call(t.validateStyle,t.extend({key:r,style:this.serialize(),value:n,styleSpec:t.styleSpec},i)))},r.prototype._remove=function(){for(var e in this._request&&(this._request.cancel(),this._request=null),this._spriteRequest&&(this._spriteRequest.cancel(),this._spriteRequest=null),t.evented.off(\"pluginAvailable\",this._rtlTextPluginCallback),this.sourceCaches)this.sourceCaches[e].clearTiles();this.dispatcher.remove()},r.prototype._clearSource=function(t){this.sourceCaches[t].clearTiles()},r.prototype._reloadSource=function(t){this.sourceCaches[t].resume(),this.sourceCaches[t].reload()},r.prototype._updateSources=function(t){for(var e in this.sourceCaches)this.sourceCaches[e].update(t)},r.prototype._generateCollisionBoxes=function(){for(var t in this.sourceCaches)this._reloadSource(t)},r.prototype._updatePlacement=function(e,r,n,i){for(var a=!1,o=!1,s={},l=0,c=this._order;l<c.length;l+=1){var u=c[l],h=this._layers[u];if(\"symbol\"===h.type){if(!s[h.source]){var f=this.sourceCaches[h.source];s[h.source]=f.getRenderableIds(!0).map(function(t){return f.getTileByID(t)}).sort(function(t,e){return e.tileID.overscaledZ-t.tileID.overscaledZ||(t.tileID.isLessThan(e.tileID)?-1:1)})}var p=this.crossTileSymbolIndex.addLayer(h,s[h.source],e.center.lng);a=a||p}}this.crossTileSymbolIndex.pruneUnusedLayers(this._order);var d=this._layerOrderChanged||0===n;if((d||!this.pauseablePlacement||this.pauseablePlacement.isDone()&&!this.placement.stillRecent(t.browser.now()))&&(this.pauseablePlacement=new Me(e,this._order,d,r,n,i,this.placement),this._layerOrderChanged=!1),this.pauseablePlacement.isDone()?this.placement.setStale():(this.pauseablePlacement.continuePlacement(this._order,this._layers,s),this.pauseablePlacement.isDone()&&(this.placement=this.pauseablePlacement.commit(t.browser.now()),o=!0),a&&this.pauseablePlacement.placement.setStale()),o||a)for(var g=0,v=this._order;g<v.length;g+=1){var m=v[g],y=this._layers[m];\"symbol\"===y.type&&this.placement.updateLayerOpacities(y,s[y.source])}return!this.pauseablePlacement.isDone()||this.placement.hasTransitions(t.browser.now())},r.prototype._releaseSymbolFadeTiles=function(){for(var t in this.sourceCaches)this.sourceCaches[t].releaseSymbolFadeTiles()},r.prototype.getImages=function(t,e,r){this.imageManager.getImages(e.icons,r)},r.prototype.getGlyphs=function(t,e,r){this.glyphManager.getGlyphs(e.stacks,r)},r.prototype.getResource=function(e,r,n){return t.makeRequest(r,n)},r}(t.Evented);De.getSourceType=function(t){return z[t]},De.setSourceType=function(t,e){z[t]=e},De.registerForPluginAvailability=t.registerForPluginAvailability;var Re=t.createLayout([{name:\"a_pos\",type:\"Int16\",components:2}]),Fe=lr(\"#ifdef GL_ES\\nprecision mediump float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\",\"#ifdef GL_ES\\nprecision highp float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\\nvec2 unpack_float(const float packedValue) {int packedIntValue=int(packedValue);int v0=packedIntValue/256;return vec2(v0,packedIntValue-v0*256);}vec2 unpack_opacity(const float packedOpacity) {int intOpacity=int(packedOpacity)/2;return vec2(float(intOpacity)/127.0,mod(packedOpacity,2.0));}vec4 decode_color(const vec2 encodedColor) {return vec4(unpack_float(encodedColor[0])/255.0,unpack_float(encodedColor[1])/255.0\\n);}float unpack_mix_vec2(const vec2 packedValue,const float t) {return mix(packedValue[0],packedValue[1],t);}vec4 unpack_mix_color(const vec4 packedColors,const float t) {vec4 minColor=decode_color(vec2(packedColors[0],packedColors[1]));vec4 maxColor=decode_color(vec2(packedColors[2],packedColors[3]));return mix(minColor,maxColor,t);}vec2 get_pattern_pos(const vec2 pixel_coord_upper,const vec2 pixel_coord_lower,const vec2 pattern_size,const float tile_units_to_pixels,const vec2 pos) {vec2 offset=mod(mod(mod(pixel_coord_upper,pattern_size)*256.0,pattern_size)*256.0+pixel_coord_lower,pattern_size);return (tile_units_to_pixels*pos+offset)/pattern_size;}\"),Be=lr(\"uniform vec4 u_color;uniform float u_opacity;void main() {gl_FragColor=u_color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),Ne=lr(\"uniform vec2 u_pattern_tl_a;uniform vec2 u_pattern_br_a;uniform vec2 u_pattern_tl_b;uniform vec2 u_pattern_br_b;uniform vec2 u_texsize;uniform float u_mix;uniform float u_opacity;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(u_pattern_tl_a/u_texsize,u_pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(u_pattern_tl_b/u_texsize,u_pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_mix)*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pattern_size_a;uniform vec2 u_pattern_size_b;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_scale_a;uniform float u_scale_b;uniform float u_tile_units_to_pixels;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_a*u_pattern_size_a,u_tile_units_to_pixels,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_b*u_pattern_size_b,u_tile_units_to_pixels,a_pos);}\"),je=lr(\"varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=v_data.xy;float extrude_length=length(extrude);lowp float antialiasblur=v_data.z;float antialiased_blur=-max(blur,antialiasblur);float opacity_t=smoothstep(0.0,antialiased_blur,extrude_length-1.0);float color_t=stroke_width < 0.01 ? 0.0 : smoothstep(antialiased_blur,0.0,extrude_length-radius/(radius+stroke_width));gl_FragColor=opacity_t*mix(color*opacity,stroke_color*stroke_opacity,color_t);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform bool u_scale_with_map;uniform bool u_pitch_with_map;uniform vec2 u_extrude_scale;uniform lowp float u_device_pixel_ratio;uniform highp float u_camera_to_center_distance;attribute vec2 a_pos;varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main(void) {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=vec2(mod(a_pos,2.0)*2.0-1.0);vec2 circle_center=floor(a_pos*0.5);if (u_pitch_with_map) {vec2 corner_position=circle_center;if (u_scale_with_map) {corner_position+=extrude*(radius+stroke_width)*u_extrude_scale;} else {vec4 projected_center=u_matrix*vec4(circle_center,0,1);corner_position+=extrude*(radius+stroke_width)*u_extrude_scale*(projected_center.w/u_camera_to_center_distance);}gl_Position=u_matrix*vec4(corner_position,0,1);} else {gl_Position=u_matrix*vec4(circle_center,0,1);if (u_scale_with_map) {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*u_camera_to_center_distance;} else {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*gl_Position.w;}}lowp float antialiasblur=1.0/u_device_pixel_ratio/(radius+stroke_width);v_data=vec3(extrude.x,extrude.y,antialiasblur);}\"),Ue=lr(\"void main() {gl_FragColor=vec4(1.0);}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),Ve=lr(\"uniform highp float u_intensity;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main() {\\n#pragma mapbox: initialize highp float weight\\nfloat d=-0.5*3.0*3.0*dot(v_extrude,v_extrude);float val=weight*u_intensity*GAUSS_COEF*exp(d);gl_FragColor=vec4(val,1.0,1.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform float u_extrude_scale;uniform float u_opacity;uniform float u_intensity;attribute vec2 a_pos;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#pragma mapbox: define mediump float radius\\nconst highp float ZERO=1.0/255.0/16.0;\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main(void) {\\n#pragma mapbox: initialize highp float weight\\n#pragma mapbox: initialize mediump float radius\\nvec2 unscaled_extrude=vec2(mod(a_pos,2.0)*2.0-1.0);float S=sqrt(-2.0*log(ZERO/weight/u_intensity/GAUSS_COEF))/3.0;v_extrude=S*unscaled_extrude;vec2 extrude=v_extrude*radius*u_extrude_scale;vec4 pos=vec4(floor(a_pos*0.5)+extrude,0,1);gl_Position=u_matrix*pos;}\"),qe=lr(\"uniform sampler2D u_image;uniform sampler2D u_color_ramp;uniform float u_opacity;varying vec2 v_pos;void main() {float t=texture2D(u_image,v_pos).r;vec4 color=texture2D(u_color_ramp,vec2(t,0.5));gl_FragColor=color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(0.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;attribute vec2 a_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos*u_world,0,1);v_pos.x=a_pos.x;v_pos.y=1.0-a_pos.y;}\"),He=lr(\"varying float v_placed;varying float v_notUsed;void main() {float alpha=0.5;gl_FragColor=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {gl_FragColor=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {gl_FragColor*=.1;}}\",\"attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;attribute vec2 a_shift;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);gl_Position.xy+=(a_extrude+a_shift)*u_extrude_scale*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;}\"),Ge=lr(\"uniform float u_overscale_factor;varying float v_placed;varying float v_notUsed;varying float v_radius;varying vec2 v_extrude;varying vec2 v_extrude_scale;void main() {float alpha=0.5;vec4 color=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {color=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {color*=.2;}float extrude_scale_length=length(v_extrude_scale);float extrude_length=length(v_extrude)*extrude_scale_length;float stroke_width=15.0*extrude_scale_length/u_overscale_factor;float radius=v_radius*extrude_scale_length;float distance_to_edge=abs(extrude_length-radius);float opacity_t=smoothstep(-stroke_width,0.0,-distance_to_edge);gl_FragColor=opacity_t*color;}\",\"attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;varying float v_radius;varying vec2 v_extrude;varying vec2 v_extrude_scale;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);highp float padding_factor=1.2;gl_Position.xy+=a_extrude*u_extrude_scale*padding_factor*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;v_radius=abs(a_extrude.y);v_extrude=a_extrude*padding_factor;v_extrude_scale=u_extrude_scale*u_camera_to_center_distance*collision_perspective_ratio;}\"),Ye=lr(\"uniform highp vec4 u_color;void main() {gl_FragColor=u_color;}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),We=lr(\"#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_FragColor=color*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);}\"),Xe=lr(\"varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=outline_color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;uniform vec2 u_world;varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),Ze=lr(\"uniform vec2 u_texsize;uniform sampler2D u_image;uniform float u_fade;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);float dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=mix(color1,color2,u_fade)*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec4 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;gl_Position=u_matrix*vec4(a_pos,0,1);vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,a_pos);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),Je=lr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_fade)*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec4 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileZoomRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileZoomRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileZoomRatio,a_pos);}\"),Ke=lr(\"varying vec4 v_color;void main() {gl_FragColor=v_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;uniform float u_vertical_gradient;uniform lowp float u_opacity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec4 v_color;\\n#pragma mapbox: define highp float base\\n#pragma mapbox: define highp float height\\n#pragma mapbox: define highp vec4 color\\nvoid main() {\\n#pragma mapbox: initialize highp float base\\n#pragma mapbox: initialize highp float height\\n#pragma mapbox: initialize highp vec4 color\\nvec3 normal=a_normal_ed.xyz;base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);gl_Position=u_matrix*vec4(a_pos,t > 0.0 ? height : base,1);float colorvalue=color.r*0.2126+color.g*0.7152+color.b*0.0722;v_color=vec4(0.0,0.0,0.0,1.0);vec4 ambientlight=vec4(0.03,0.03,0.03,1.0);color+=ambientlight;float directional=clamp(dot(normal/16384.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((1.0-colorvalue+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_color.r+=clamp(color.r*directional*u_lightcolor.r,mix(0.0,0.3,1.0-u_lightcolor.r),1.0);v_color.g+=clamp(color.g*directional*u_lightcolor.g,mix(0.0,0.3,1.0-u_lightcolor.g),1.0);v_color.b+=clamp(color.b*directional*u_lightcolor.b,mix(0.0,0.3,1.0-u_lightcolor.b),1.0);v_color*=u_opacity;}\"),$e=lr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);vec4 mixedColor=mix(color1,color2,u_fade);gl_FragColor=mixedColor*v_lighting;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_height_factor;uniform vec4 u_scale;uniform float u_vertical_gradient;uniform lowp float u_opacity;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec3 normal=a_normal_ed.xyz;float edgedistance=a_normal_ed.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);float z=t > 0.0 ? height : base;gl_Position=u_matrix*vec4(a_pos,z,1);vec2 pos=normal.x==1.0 && normal.y==0.0 && normal.z==16384.0\\n? a_pos\\n: vec2(edgedistance,z*u_height_factor);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,pos);v_lighting=vec4(0.0,0.0,0.0,1.0);float directional=clamp(dot(normal/16383.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((0.5+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_lighting.rgb+=clamp(directional*u_lightcolor,mix(vec3(0.0),vec3(0.3),1.0-u_lightcolor),vec3(1.0));v_lighting*=u_opacity;}\"),Qe=lr(\"#ifdef GL_ES\\nprecision highp float;\\n#endif\\nuniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_dimension;uniform float u_zoom;uniform float u_maxzoom;float getElevation(vec2 coord,float bias) {vec4 data=texture2D(u_image,coord)*255.0;return (data.r+data.g*256.0+data.b*256.0*256.0)/4.0;}void main() {vec2 epsilon=1.0/u_dimension;float a=getElevation(v_pos+vec2(-epsilon.x,-epsilon.y),0.0);float b=getElevation(v_pos+vec2(0,-epsilon.y),0.0);float c=getElevation(v_pos+vec2(epsilon.x,-epsilon.y),0.0);float d=getElevation(v_pos+vec2(-epsilon.x,0),0.0);float e=getElevation(v_pos,0.0);float f=getElevation(v_pos+vec2(epsilon.x,0),0.0);float g=getElevation(v_pos+vec2(-epsilon.x,epsilon.y),0.0);float h=getElevation(v_pos+vec2(0,epsilon.y),0.0);float i=getElevation(v_pos+vec2(epsilon.x,epsilon.y),0.0);float exaggeration=u_zoom < 2.0 ? 0.4 : u_zoom < 4.5 ? 0.35 : 0.3;vec2 deriv=vec2((c+f+f+i)-(a+d+d+g),(g+h+h+i)-(a+b+b+c))/ pow(2.0,(u_zoom-u_maxzoom)*exaggeration+19.2562-u_zoom);gl_FragColor=clamp(vec4(deriv.x/2.0+0.5,deriv.y/2.0+0.5,1.0,1.0),0.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_dimension;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);highp vec2 epsilon=1.0/u_dimension;float scale=(u_dimension.x-2.0)/u_dimension.x;v_pos=(a_texture_pos/8192.0)*scale+epsilon;}\"),tr=lr(\"uniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_latrange;uniform vec2 u_light;uniform vec4 u_shadow;uniform vec4 u_highlight;uniform vec4 u_accent;\\n#define PI 3.141592653589793\\nvoid main() {vec4 pixel=texture2D(u_image,v_pos);vec2 deriv=((pixel.rg*2.0)-1.0);float scaleFactor=cos(radians((u_latrange[0]-u_latrange[1])*(1.0-v_pos.y)+u_latrange[1]));float slope=atan(1.25*length(deriv)/scaleFactor);float aspect=deriv.x !=0.0 ? atan(deriv.y,-deriv.x) : PI/2.0*(deriv.y > 0.0 ? 1.0 :-1.0);float intensity=u_light.x;float azimuth=u_light.y+PI;float base=1.875-intensity*1.75;float maxValue=0.5*PI;float scaledSlope=intensity !=0.5 ? ((pow(base,slope)-1.0)/(pow(base,maxValue)-1.0))*maxValue : slope;float accent=cos(scaledSlope);vec4 accent_color=(1.0-accent)*u_accent*clamp(intensity*2.0,0.0,1.0);float shade=abs(mod((aspect+azimuth)/PI+0.5,2.0)-1.0);vec4 shade_color=mix(u_shadow,u_highlight,shade)*sin(scaledSlope)*clamp(intensity*2.0,0.0,1.0);gl_FragColor=accent_color*(1.0-shade_color.a)+shade_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos=a_texture_pos/8192.0;}\"),er=lr(\"uniform lowp float u_device_pixel_ratio;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform vec2 u_units_to_pixels;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_linesofar;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),rr=lr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);vec4 color=texture2D(u_image,vec2(v_lineprogress,0.5));gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define MAX_LINE_DISTANCE 32767.0\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_lineprogress=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0/MAX_LINE_DISTANCE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),nr=lr(\"uniform lowp float u_device_pixel_ratio;uniform vec2 u_texsize;uniform float u_fade;uniform mediump vec4 u_scale;uniform sampler2D u_image;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileZoomRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);vec2 pattern_size_a=vec2(display_size_a.x*fromScale/tileZoomRatio,display_size_a.y);vec2 pattern_size_b=vec2(display_size_b.x*toScale/tileZoomRatio,display_size_b.y);float dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float x_a=mod(v_linesofar/pattern_size_a.x,1.0);float x_b=mod(v_linesofar/pattern_size_b.x,1.0);float y_a=0.5+(v_normal.y*clamp(v_width2.s,0.0,(pattern_size_a.y+2.0)/2.0)/pattern_size_a.y);float y_b=0.5+(v_normal.y*clamp(v_width2.s,0.0,(pattern_size_b.y+2.0)/2.0)/pattern_size_b.y);vec2 pos_a=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,vec2(x_a,y_a));vec2 pos_b=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,vec2(x_b,y_b));vec4 color=mix(texture2D(u_image,pos_a),texture2D(u_image,pos_b),u_fade);gl_FragColor=color*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform vec2 u_units_to_pixels;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_linesofar=a_linesofar;v_width2=vec2(outset,inset);}\"),ir=lr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;uniform float u_sdfgamma;uniform float u_mix;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float sdfdist_a=texture2D(u_image,v_tex_a).a;float sdfdist_b=texture2D(u_image,v_tex_b).a;float sdfdist=mix(sdfdist_a,sdfdist_b,u_mix);alpha*=smoothstep(0.5-u_sdfgamma/floorwidth,0.5+u_sdfgamma/floorwidth,sdfdist);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_patternscale_a;uniform float u_tex_y_a;uniform vec2 u_patternscale_b;uniform float u_tex_y_b;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_tex_a=vec2(a_linesofar*u_patternscale_a.x/floorwidth,normal.y*u_patternscale_a.y+u_tex_y_a);v_tex_b=vec2(a_linesofar*u_patternscale_b.x/floorwidth,normal.y*u_patternscale_b.y+u_tex_y_b);v_width2=vec2(outset,inset);}\"),ar=lr(\"uniform float u_fade_t;uniform float u_opacity;uniform sampler2D u_image0;uniform sampler2D u_image1;varying vec2 v_pos0;varying vec2 v_pos1;uniform float u_brightness_low;uniform float u_brightness_high;uniform float u_saturation_factor;uniform float u_contrast_factor;uniform vec3 u_spin_weights;void main() {vec4 color0=texture2D(u_image0,v_pos0);vec4 color1=texture2D(u_image1,v_pos1);if (color0.a > 0.0) {color0.rgb=color0.rgb/color0.a;}if (color1.a > 0.0) {color1.rgb=color1.rgb/color1.a;}vec4 color=mix(color0,color1,u_fade_t);color.a*=u_opacity;vec3 rgb=color.rgb;rgb=vec3(dot(rgb,u_spin_weights.xyz),dot(rgb,u_spin_weights.zxy),dot(rgb,u_spin_weights.yzx));float average=(color.r+color.g+color.b)/3.0;rgb+=(average-rgb)*u_saturation_factor;rgb=(rgb-0.5)*u_contrast_factor+0.5;vec3 u_high_vec=vec3(u_brightness_low,u_brightness_low,u_brightness_low);vec3 u_low_vec=vec3(u_brightness_high,u_brightness_high,u_brightness_high);gl_FragColor=vec4(mix(u_high_vec,u_low_vec,rgb)*color.a,color.a);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_tl_parent;uniform float u_scale_parent;uniform float u_buffer_scale;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos0;varying vec2 v_pos1;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos0=(((a_texture_pos/8192.0)-0.5)/u_buffer_scale )+0.5;v_pos1=(v_pos0*u_scale_parent)+u_tl_parent;}\"),or=lr(\"uniform sampler2D u_texture;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nlowp float alpha=opacity*v_fade_opacity;gl_FragColor=texture2D(u_texture,v_tex)*alpha;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform highp float u_camera_to_center_distance;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform float u_fade_change;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform vec2 u_texsize;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size[0],a_size[1],u_size_t)/256.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size[0]/256.0;} else if (!u_is_size_zoom_constant && u_is_size_feature_constant) {size=u_size;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);v_tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;v_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));}\"),sr=lr(\"#define SDF_PX 8.0\\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;uniform bool u_is_text;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nfloat EDGE_GAMMA=0.105/u_device_pixel_ratio;vec2 tex=v_data0.xy;float gamma_scale=v_data1.x;float size=v_data1.y;float fade_opacity=v_data1[2];float fontScale=u_is_text ? size/24.0 : size;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size[0],a_size[1],u_size_t)/256.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size[0]/256.0;} else if (!u_is_size_zoom_constant && u_is_size_feature_constant) {size=u_size;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);float gamma_scale=gl_Position.w;vec2 tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));v_data0=vec2(tex.x,tex.y);v_data1=vec3(gamma_scale,size,interpolated_fade_opacity);}\");function lr(t,e){var r=/#pragma mapbox: ([\\w]+) ([\\w]+) ([\\w]+) ([\\w]+)/g,n={};return{fragmentSource:t=t.replace(r,function(t,e,r,i,a){return n[a]=!0,\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"\\n#ifdef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"}),vertexSource:e=e.replace(r,function(t,e,r,i,a){var o=\"float\"===i?\"vec2\":\"vec4\",s=a.match(/color/)?\"color\":o;return n[a]?\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"})}}var cr=Object.freeze({prelude:Fe,background:Be,backgroundPattern:Ne,circle:je,clippingMask:Ue,heatmap:Ve,heatmapTexture:qe,collisionBox:He,collisionCircle:Ge,debug:Ye,fill:We,fillOutline:Xe,fillOutlinePattern:Ze,fillPattern:Je,fillExtrusion:Ke,fillExtrusionPattern:$e,hillshadePrepare:Qe,hillshade:tr,line:er,lineGradient:rr,linePattern:nr,lineSDF:ir,raster:ar,symbolIcon:or,symbolSDF:sr}),ur=function(){this.boundProgram=null,this.boundLayoutVertexBuffer=null,this.boundPaintVertexBuffers=[],this.boundIndexBuffer=null,this.boundVertexOffset=null,this.boundDynamicVertexBuffer=null,this.vao=null};ur.prototype.bind=function(t,e,r,n,i,a,o,s){this.context=t;for(var l=this.boundPaintVertexBuffers.length!==n.length,c=0;!l&&c<n.length;c++)this.boundPaintVertexBuffers[c]!==n[c]&&(l=!0);var u=!this.vao||this.boundProgram!==e||this.boundLayoutVertexBuffer!==r||l||this.boundIndexBuffer!==i||this.boundVertexOffset!==a||this.boundDynamicVertexBuffer!==o||this.boundDynamicVertexBuffer2!==s;!t.extVertexArrayObject||u?this.freshBind(e,r,n,i,a,o,s):(t.bindVertexArrayOES.set(this.vao),o&&o.bind(),i&&i.dynamicDraw&&i.bind(),s&&s.bind())},ur.prototype.freshBind=function(t,e,r,n,i,a,o){var s,l=t.numAttributes,c=this.context,u=c.gl;if(c.extVertexArrayObject)this.vao&&this.destroy(),this.vao=c.extVertexArrayObject.createVertexArrayOES(),c.bindVertexArrayOES.set(this.vao),s=0,this.boundProgram=t,this.boundLayoutVertexBuffer=e,this.boundPaintVertexBuffers=r,this.boundIndexBuffer=n,this.boundVertexOffset=i,this.boundDynamicVertexBuffer=a,this.boundDynamicVertexBuffer2=o;else{s=c.currentNumAttributes||0;for(var h=l;h<s;h++)u.disableVertexAttribArray(h)}e.enableAttributes(u,t);for(var f=0,p=r;f<p.length;f+=1)p[f].enableAttributes(u,t);a&&a.enableAttributes(u,t),o&&o.enableAttributes(u,t),e.bind(),e.setVertexAttribPointers(u,t,i);for(var d=0,g=r;d<g.length;d+=1){var v=g[d];v.bind(),v.setVertexAttribPointers(u,t,i)}a&&(a.bind(),a.setVertexAttribPointers(u,t,i)),n&&n.bind(),o&&(o.bind(),o.setVertexAttribPointers(u,t,i)),c.currentNumAttributes=l},ur.prototype.destroy=function(){this.vao&&(this.context.extVertexArrayObject.deleteVertexArrayOES(this.vao),this.vao=null)};var hr=function(t,e,r,n,i){var a=t.gl;this.program=a.createProgram();var o=r.defines();i&&o.push(\"#define OVERDRAW_INSPECTOR;\");var s=o.concat(Fe.fragmentSource,e.fragmentSource).join(\"\\n\"),l=o.concat(Fe.vertexSource,e.vertexSource).join(\"\\n\"),c=a.createShader(a.FRAGMENT_SHADER);a.shaderSource(c,s),a.compileShader(c),a.attachShader(this.program,c);var u=a.createShader(a.VERTEX_SHADER);a.shaderSource(u,l),a.compileShader(u),a.attachShader(this.program,u);for(var h=r.layoutAttributes||[],f=0;f<h.length;f++)a.bindAttribLocation(this.program,f,h[f].name);a.linkProgram(this.program),this.numAttributes=a.getProgramParameter(this.program,a.ACTIVE_ATTRIBUTES),this.attributes={};for(var p={},d=0;d<this.numAttributes;d++){var g=a.getActiveAttrib(this.program,d);g&&(this.attributes[g.name]=a.getAttribLocation(this.program,g.name))}for(var v=a.getProgramParameter(this.program,a.ACTIVE_UNIFORMS),m=0;m<v;m++){var y=a.getActiveUniform(this.program,m);y&&(p[y.name]=a.getUniformLocation(this.program,y.name))}this.fixedUniforms=n(t,p),this.binderUniforms=r.getUniforms(t,p)};function fr(e,r,n){var i=1/le(n,1,r.transform.tileZoom),a=Math.pow(2,n.tileID.overscaledZ),o=n.tileSize*Math.pow(2,r.transform.tileZoom)/a,s=o*(n.tileID.canonical.x+n.tileID.wrap*a),l=o*n.tileID.canonical.y;return{u_image:0,u_texsize:n.imageAtlasTexture.size,u_scale:[t.browser.devicePixelRatio,i,e.fromScale,e.toScale],u_fade:e.t,u_pixel_coord_upper:[s>>16,l>>16],u_pixel_coord_lower:[65535&s,65535&l]}}hr.prototype.draw=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g){var v,m=t.gl;for(var y in t.program.set(this.program),t.setDepthMode(r),t.setStencilMode(n),t.setColorMode(i),t.setCullFace(a),this.fixedUniforms)this.fixedUniforms[y].set(o[y]);p&&p.setUniforms(t,this.binderUniforms,h,{zoom:f});for(var x=(v={},v[m.LINES]=2,v[m.TRIANGLES]=3,v[m.LINE_STRIP]=1,v)[e],b=0,_=u.get();b<_.length;b+=1){var w=_[b],k=w.vaos||(w.vaos={});(k[s]||(k[s]=new ur)).bind(t,this,l,p?p.getPaintVertexBuffers():[],c,w.vertexOffset,d,g),m.drawElements(e,w.primitiveLength*x,m.UNSIGNED_SHORT,w.primitiveOffset*x*2)}};var pr=function(e,r,n,i){var a=r.style.light,o=a.properties.get(\"position\"),s=[o.x,o.y,o.z],l=t.create$1();\"viewport\"===a.properties.get(\"anchor\")&&t.fromRotation(l,-r.transform.angle),t.transformMat3(s,s,l);var c=a.properties.get(\"color\");return{u_matrix:e,u_lightpos:s,u_lightintensity:a.properties.get(\"intensity\"),u_lightcolor:[c.r,c.g,c.b],u_vertical_gradient:+n,u_opacity:i}},dr=function(e,r,n,i,a,o,s){return t.extend(pr(e,r,n,i),fr(o,r,s),{u_height_factor:-Math.pow(2,a.overscaledZ)/s.tileSize/8})},gr=function(t){return{u_matrix:t}},vr=function(e,r,n,i){return t.extend(gr(e),fr(n,r,i))},mr=function(t,e){return{u_matrix:t,u_world:e}},yr=function(e,r,n,i,a){return t.extend(vr(e,r,n,i),{u_world:a})},xr=function(e,r,n,i){var a,o,s=e.transform;if(\"map\"===i.paint.get(\"circle-pitch-alignment\")){var l=le(n,1,s.zoom);a=!0,o=[l,l]}else a=!1,o=s.pixelsToGLUnits;return{u_camera_to_center_distance:s.cameraToCenterDistance,u_scale_with_map:+(\"map\"===i.paint.get(\"circle-pitch-scale\")),u_matrix:e.translatePosMatrix(r.posMatrix,n,i.paint.get(\"circle-translate\"),i.paint.get(\"circle-translate-anchor\")),u_pitch_with_map:+a,u_device_pixel_ratio:t.browser.devicePixelRatio,u_extrude_scale:o}},br=function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pixels_to_tile_units:new t.Uniform1f(e,r.u_pixels_to_tile_units),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_overscale_factor:new t.Uniform1f(e,r.u_overscale_factor)}},_r=function(t,e,r){var n=le(r,1,e.zoom),i=Math.pow(2,e.zoom-r.tileID.overscaledZ),a=r.tileID.overscaleFactor();return{u_matrix:t,u_camera_to_center_distance:e.cameraToCenterDistance,u_pixels_to_tile_units:n,u_extrude_scale:[e.pixelsToGLUnits[0]/(n*i),e.pixelsToGLUnits[1]/(n*i)],u_overscale_factor:a}},wr=function(t,e){return{u_matrix:t,u_color:e}},kr=function(t){return{u_matrix:t}},Tr=function(t,e,r,n){return{u_matrix:t,u_extrude_scale:le(e,1,r),u_intensity:n}},Ar=function(t,e,r){var n=r.paint.get(\"hillshade-shadow-color\"),i=r.paint.get(\"hillshade-highlight-color\"),a=r.paint.get(\"hillshade-accent-color\"),o=r.paint.get(\"hillshade-illumination-direction\")*(Math.PI/180);\"viewport\"===r.paint.get(\"hillshade-illumination-anchor\")&&(o-=t.transform.angle);var s=!t.options.moving;return{u_matrix:t.transform.calculatePosMatrix(e.tileID.toUnwrapped(),s),u_image:0,u_latrange:Sr(t,e.tileID),u_light:[r.paint.get(\"hillshade-exaggeration\"),o],u_shadow:n,u_highlight:i,u_accent:a}},Mr=function(e,r){var n=e.dem.stride,i=t.create();return t.ortho(i,0,t.EXTENT,-t.EXTENT,0,0,1),t.translate(i,i,[0,-t.EXTENT,0]),{u_matrix:i,u_image:1,u_dimension:[n,n],u_zoom:e.tileID.overscaledZ,u_maxzoom:r}};function Sr(e,r){var n=Math.pow(2,r.canonical.z),i=r.canonical.y;return[new t.MercatorCoordinate(0,i/n).toLngLat().lat,new t.MercatorCoordinate(0,(i+1)/n).toLngLat().lat]}var Er=function(e,r,n){var i=e.transform;return{u_matrix:zr(e,r,n),u_ratio:1/le(r,1,i.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_units_to_pixels:[1/i.pixelsToGLUnits[0],1/i.pixelsToGLUnits[1]]}},Cr=function(e,r,n){return t.extend(Er(e,r,n),{u_image:0})},Lr=function(e,r,n,i){var a=e.transform,o=Or(r,a);return{u_matrix:zr(e,r,n),u_texsize:r.imageAtlasTexture.size,u_ratio:1/le(r,1,a.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_image:0,u_scale:[t.browser.devicePixelRatio,o,i.fromScale,i.toScale],u_fade:i.t,u_units_to_pixels:[1/a.pixelsToGLUnits[0],1/a.pixelsToGLUnits[1]]}},Pr=function(e,r,n,i,a){var o=e.transform,s=e.lineAtlas,l=Or(r,o),c=\"round\"===n.layout.get(\"line-cap\"),u=s.getDash(i.from,c),h=s.getDash(i.to,c),f=u.width*a.fromScale,p=h.width*a.toScale;return t.extend(Er(e,r,n),{u_patternscale_a:[l/f,-u.height/2],u_patternscale_b:[l/p,-h.height/2],u_sdfgamma:s.width/(256*Math.min(f,p)*t.browser.devicePixelRatio)/2,u_image:0,u_tex_y_a:u.y,u_tex_y_b:h.y,u_mix:a.t})};function Or(t,e){return 1/le(t,1,e.tileZoom)}function zr(t,e,r){return t.translatePosMatrix(e.tileID.posMatrix,e,r.paint.get(\"line-translate\"),r.paint.get(\"line-translate-anchor\"))}var Ir=function(t,e,r,n,i){return{u_matrix:t,u_tl_parent:e,u_scale_parent:r,u_buffer_scale:1,u_fade_t:n.mix,u_opacity:n.opacity*i.paint.get(\"raster-opacity\"),u_image0:0,u_image1:1,u_brightness_low:i.paint.get(\"raster-brightness-min\"),u_brightness_high:i.paint.get(\"raster-brightness-max\"),u_saturation_factor:(o=i.paint.get(\"raster-saturation\"),o>0?1-1/(1.001-o):-o),u_contrast_factor:(a=i.paint.get(\"raster-contrast\"),a>0?1/(1-a):1+a),u_spin_weights:function(t){t*=Math.PI/180;var e=Math.sin(t),r=Math.cos(t);return[(2*r+1)/3,(-Math.sqrt(3)*e-r+1)/3,(Math.sqrt(3)*e-r+1)/3]}(i.paint.get(\"raster-hue-rotate\"))};var a,o};var Dr=function(t,e,r,n,i,a,o,s,l,c){var u=i.transform;return{u_is_size_zoom_constant:+(\"constant\"===t||\"source\"===t),u_is_size_feature_constant:+(\"constant\"===t||\"camera\"===t),u_size_t:e?e.uSizeT:0,u_size:e?e.uSize:0,u_camera_to_center_distance:u.cameraToCenterDistance,u_pitch:u.pitch/360*2*Math.PI,u_rotate_symbol:+r,u_aspect_ratio:u.width/u.height,u_fade_change:i.options.fadeDuration?i.symbolFadeChange:1,u_matrix:a,u_label_plane_matrix:o,u_coord_matrix:s,u_is_text:+l,u_pitch_with_map:+n,u_texsize:c,u_texture:0}},Rr=function(e,r,n,i,a,o,s,l,c,u,h){var f=a.transform;return t.extend(Dr(e,r,n,i,a,o,s,l,c,u),{u_gamma_scale:i?Math.cos(f._pitch)*f.cameraToCenterDistance:1,u_device_pixel_ratio:t.browser.devicePixelRatio,u_is_halo:+h})},Fr=function(t,e,r){return{u_matrix:t,u_opacity:e,u_color:r}},Br=function(e,r,n,i,a,o){return t.extend(function(t,e,r,n){var i=r.imageManager.getPattern(t.from),a=r.imageManager.getPattern(t.to),o=r.imageManager.getPixelSize(),s=o.width,l=o.height,c=Math.pow(2,n.tileID.overscaledZ),u=n.tileSize*Math.pow(2,r.transform.tileZoom)/c,h=u*(n.tileID.canonical.x+n.tileID.wrap*c),f=u*n.tileID.canonical.y;return{u_image:0,u_pattern_tl_a:i.tl,u_pattern_br_a:i.br,u_pattern_tl_b:a.tl,u_pattern_br_b:a.br,u_texsize:[s,l],u_mix:e.t,u_pattern_size_a:i.displaySize,u_pattern_size_b:a.displaySize,u_scale_a:e.fromScale,u_scale_b:e.toScale,u_tile_units_to_pixels:1/le(n,1,r.transform.tileZoom),u_pixel_coord_upper:[h>>16,f>>16],u_pixel_coord_lower:[65535&h,65535&f]}}(i,o,n,a),{u_matrix:e,u_opacity:r})},Nr={fillExtrusion:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fillExtrusionPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_height_factor:new t.Uniform1f(e,r.u_height_factor),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fill:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},fillPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},fillOutline:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world)}},fillOutlinePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},circle:function(e,r){return{u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_scale_with_map:new t.Uniform1i(e,r.u_scale_with_map),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},collisionBox:br,collisionCircle:br,debug:function(e,r){return{u_color:new t.UniformColor(e,r.u_color),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},clippingMask:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmap:function(e,r){return{u_extrude_scale:new t.Uniform1f(e,r.u_extrude_scale),u_intensity:new t.Uniform1f(e,r.u_intensity),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmapTexture:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_color_ramp:new t.Uniform1i(e,r.u_color_ramp),u_opacity:new t.Uniform1f(e,r.u_opacity)}},hillshade:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_latrange:new t.Uniform2f(e,r.u_latrange),u_light:new t.Uniform2f(e,r.u_light),u_shadow:new t.UniformColor(e,r.u_shadow),u_highlight:new t.UniformColor(e,r.u_highlight),u_accent:new t.UniformColor(e,r.u_accent)}},hillshadePrepare:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_dimension:new t.Uniform2f(e,r.u_dimension),u_zoom:new t.Uniform1f(e,r.u_zoom),u_maxzoom:new t.Uniform1f(e,r.u_maxzoom)}},line:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels)}},lineGradient:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_image:new t.Uniform1i(e,r.u_image)}},linePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_texsize:new t.Uniform2f(e,r.u_texsize),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_image:new t.Uniform1i(e,r.u_image),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},lineSDF:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_patternscale_a:new t.Uniform2f(e,r.u_patternscale_a),u_patternscale_b:new t.Uniform2f(e,r.u_patternscale_b),u_sdfgamma:new t.Uniform1f(e,r.u_sdfgamma),u_image:new t.Uniform1i(e,r.u_image),u_tex_y_a:new t.Uniform1f(e,r.u_tex_y_a),u_tex_y_b:new t.Uniform1f(e,r.u_tex_y_b),u_mix:new t.Uniform1f(e,r.u_mix)}},raster:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_tl_parent:new t.Uniform2f(e,r.u_tl_parent),u_scale_parent:new t.Uniform1f(e,r.u_scale_parent),u_buffer_scale:new t.Uniform1f(e,r.u_buffer_scale),u_fade_t:new t.Uniform1f(e,r.u_fade_t),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image0:new t.Uniform1i(e,r.u_image0),u_image1:new t.Uniform1i(e,r.u_image1),u_brightness_low:new t.Uniform1f(e,r.u_brightness_low),u_brightness_high:new t.Uniform1f(e,r.u_brightness_high),u_saturation_factor:new t.Uniform1f(e,r.u_saturation_factor),u_contrast_factor:new t.Uniform1f(e,r.u_contrast_factor),u_spin_weights:new t.Uniform3f(e,r.u_spin_weights)}},symbolIcon:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1f(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture)}},symbolSDF:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1f(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture),u_gamma_scale:new t.Uniform1f(e,r.u_gamma_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_is_halo:new t.Uniform1f(e,r.u_is_halo)}},background:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_color:new t.UniformColor(e,r.u_color)}},backgroundPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image:new t.Uniform1i(e,r.u_image),u_pattern_tl_a:new t.Uniform2f(e,r.u_pattern_tl_a),u_pattern_br_a:new t.Uniform2f(e,r.u_pattern_br_a),u_pattern_tl_b:new t.Uniform2f(e,r.u_pattern_tl_b),u_pattern_br_b:new t.Uniform2f(e,r.u_pattern_br_b),u_texsize:new t.Uniform2f(e,r.u_texsize),u_mix:new t.Uniform1f(e,r.u_mix),u_pattern_size_a:new t.Uniform2f(e,r.u_pattern_size_a),u_pattern_size_b:new t.Uniform2f(e,r.u_pattern_size_b),u_scale_a:new t.Uniform1f(e,r.u_scale_a),u_scale_b:new t.Uniform1f(e,r.u_scale_b),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_tile_units_to_pixels:new t.Uniform1f(e,r.u_tile_units_to_pixels)}}};function jr(e,r){for(var n=e.sort(function(t,e){return t.tileID.isLessThan(e.tileID)?-1:e.tileID.isLessThan(t.tileID)?1:0}),i=0;i<n.length;i++){var a={},o=n[i],s=n.slice(i+1);Ur(o.tileID.wrapped(),o.tileID,s,new t.OverscaledTileID(0,o.tileID.wrap+1,0,0,0),a),o.setMask(a,r)}}function Ur(e,r,n,i,a){for(var o=0;o<n.length;o++){var s=n[o];if(i.isLessThan(s.tileID))break;if(r.key===s.tileID.key)return;if(s.tileID.isChildOf(r)){for(var l=r.children(1/0),c=0;c<l.length;c++)Ur(e,l[c],n.slice(o),i,a);return}}var u=r.overscaledZ-e.overscaledZ,h=new t.CanonicalTileID(u,r.canonical.x-(e.canonical.x<<u),r.canonical.y-(e.canonical.y<<u));a[h.key]=a[h.key]||h}function Vr(t,e,r,n,i){for(var a=t.context,o=a.gl,s=i?t.useProgram(\"collisionCircle\"):t.useProgram(\"collisionBox\"),l=0;l<n.length;l++){var c=n[l],u=e.getTile(c),h=u.getBucket(r);if(h){var f=i?h.collisionCircle:h.collisionBox;f&&s.draw(a,i?o.TRIANGLES:o.LINES,Tt.disabled,At.disabled,t.colorModeForRenderPass(),St.disabled,_r(c.posMatrix,t.transform,u),r.id,f.layoutVertexBuffer,f.indexBuffer,f.segments,null,t.transform.zoom,null,null,f.collisionVertexBuffer)}}}var qr=t.identity(new Float32Array(16));function Hr(e,r,n,i,a,o){var s=t.getAnchorAlignment(e),l=-(s.horizontalAlign-.5)*r,c=-(s.verticalAlign-.5)*n,u=t.evaluateRadialOffset(e,i);return new t.Point((l/a+u[0])*o,(c/a+u[1])*o)}function Gr(e,r,n,i,a,o,s,l,c,u){var h=e.text.placedSymbolArray,f=e.text.dynamicLayoutVertexArray;f.clear();for(var p=0;p<h.length;p++){var d=h.get(p),g=!d.hidden&&d.crossTileID?i[d.crossTileID]:null;if(g){var v=new t.Point(d.anchorX,d.anchorY),m=Zt(v,n?l:s),y=.5+o.cameraToCenterDistance/m.signedDistanceFromCamera*.5,x=a.evaluateSizeForFeature(e.textSizeData,u,d)*y/t.ONE_EM;n&&(x*=e.tilePixelRatio/c);for(var b=g.width,_=g.height,w=g.radialOffset,k=g.textBoxScale,T=Hr(g.anchor,b,_,w,k,x),A=n?Zt(v.add(T),s).point:m.point.add(r?T.rotate(-o.angle):T),M=0;M<d.numGlyphs;M++)t.addDynamicAttributes(f,A,0)}else ie(d.numGlyphs,f)}e.text.dynamicLayoutVertexBuffer.updateData(f)}function Yr(e,r,n,i,a,o,s,l,c,u,h,f,p){for(var d,g,v=e.context,m=v.gl,y=e.transform,x=\"map\"===l,b=\"map\"===c,_=x&&\"point\"!==n.layout.get(\"symbol-placement\"),w=x&&!b&&!_,k=void 0!==n.layout.get(\"symbol-sort-key\").constantOr(1),T=e.depthModeForSublayer(0,Tt.ReadOnly),A=n.layout.get(\"text-variable-anchor\"),M=[],S=0,E=i;S<E.length;S+=1){var C=E[S],L=r.getTile(C),P=L.getBucket(n);if(P){var O=a?P.text:P.icon;if(O&&O.segments.get().length){var z=O.programConfigurations.get(n.id),I=a||P.sdfIcons,D=a?P.textSizeData:P.iconSizeData;d||(d=e.useProgram(I?\"symbolSDF\":\"symbolIcon\",z),g=t.evaluateSizeForZoom(D,y.zoom)),v.activeTexture.set(m.TEXTURE0);var R=void 0,F=void 0,B=void 0;if(a)F=L.glyphAtlasTexture,B=m.LINEAR,R=L.glyphAtlasTexture.size;else{var N=1!==n.layout.get(\"icon-size\").constantOr(0)||P.iconsNeedLinear,j=b||0!==y.pitch;F=L.imageAtlasTexture,B=I||e.options.rotating||e.options.zooming||N||j?m.LINEAR:m.NEAREST,R=L.imageAtlasTexture.size}var U=le(L,1,e.transform.zoom),V=Wt(C.posMatrix,b,x,e.transform,U),q=Xt(C.posMatrix,b,x,e.transform,U);if(_)Kt(P,C.posMatrix,e,a,V,q,b,u);else if(a&&g&&A){var H=Math.pow(2,y.zoom-L.tileID.overscaledZ);Gr(P,x,b,p,t.symbolSize,y,V,C.posMatrix,H,g)}var G=e.translatePosMatrix(C.posMatrix,L,o,s),Y=_||a&&A?qr:V,W=e.translatePosMatrix(q,L,o,s,!0),X=I&&0!==n.paint.get(a?\"text-halo-width\":\"icon-halo-width\").constantOr(1),Z={program:d,buffers:O,uniformValues:I?Rr(D.kind,g,w,b,e,G,Y,W,a,R,!0):Dr(D.kind,g,w,b,e,G,Y,W,a,R),atlasTexture:F,atlasInterpolation:B,isSDF:I,hasHalo:X};if(k)for(var J=0,K=O.segments.get();J<K.length;J+=1){var $=K[J];M.push({segments:new t.SegmentVector([$]),sortKey:$.sortKey,state:Z})}else M.push({segments:O.segments,sortKey:0,state:Z})}}}k&&M.sort(function(t,e){return t.sortKey-e.sortKey});for(var Q=0,tt=M;Q<tt.length;Q+=1){var et=tt[Q],rt=et.state;if(rt.atlasTexture.bind(rt.atlasInterpolation,m.CLAMP_TO_EDGE),rt.isSDF){var nt=rt.uniformValues;rt.hasHalo&&(nt.u_is_halo=1,Wr(rt.buffers,et.segments,n,e,rt.program,T,h,f,nt)),nt.u_is_halo=0}Wr(rt.buffers,et.segments,n,e,rt.program,T,h,f,rt.uniformValues)}}function Wr(t,e,r,n,i,a,o,s,l){var c=n.context,u=c.gl;i.draw(c,u.TRIANGLES,a,o,s,St.disabled,l,r.id,t.layoutVertexBuffer,t.indexBuffer,e,r.paint,n.transform.zoom,t.programConfigurations.get(r.id),t.dynamicLayoutVertexBuffer,t.opacityVertexBuffer)}function Xr(t,e,r,n,i,a,o){var s,l,c,u,h,f=t.context.gl,p=r.paint.get(\"fill-pattern\"),d=p&&p.constantOr(1),g=r.getCrossfadeParameters();o?(l=d&&!r.getPaintProperty(\"fill-outline-color\")?\"fillOutlinePattern\":\"fillOutline\",s=f.LINES):(l=d?\"fillPattern\":\"fill\",s=f.TRIANGLES);for(var v=0,m=n;v<m.length;v+=1){var y=m[v],x=e.getTile(y);if(!d||x.patternsLoaded()){var b=x.getBucket(r);if(b){var _=b.programConfigurations.get(r.id),w=t.useProgram(l,_);d&&(t.context.activeTexture.set(f.TEXTURE0),x.imageAtlasTexture.bind(f.LINEAR,f.CLAMP_TO_EDGE),_.updatePatternPaintBuffers(g));var k=p.constantOr(null);if(k&&x.imageAtlas){var T=x.imageAtlas.patternPositions[k.to],A=x.imageAtlas.patternPositions[k.from];T&&A&&_.setConstantPatternPositions(T,A)}var M=t.translatePosMatrix(y.posMatrix,x,r.paint.get(\"fill-translate\"),r.paint.get(\"fill-translate-anchor\"));if(o){u=b.indexBuffer2,h=b.segments2;var S=[f.drawingBufferWidth,f.drawingBufferHeight];c=\"fillOutlinePattern\"===l&&d?yr(M,t,g,x,S):mr(M,S)}else u=b.indexBuffer,h=b.segments,c=d?vr(M,t,g,x):gr(M);w.draw(t.context,s,i,t.stencilModeForClipping(y),a,St.disabled,c,r.id,b.layoutVertexBuffer,u,h,r.paint,t.transform.zoom,_)}}}}function Zr(t,e,r,n,i,a,o){for(var s=t.context,l=s.gl,c=r.paint.get(\"fill-extrusion-pattern\"),u=c.constantOr(1),h=r.getCrossfadeParameters(),f=r.paint.get(\"fill-extrusion-opacity\"),p=0,d=n;p<d.length;p+=1){var g=d[p],v=e.getTile(g),m=v.getBucket(r);if(m){var y=m.programConfigurations.get(r.id),x=t.useProgram(u?\"fillExtrusionPattern\":\"fillExtrusion\",y);u&&(t.context.activeTexture.set(l.TEXTURE0),v.imageAtlasTexture.bind(l.LINEAR,l.CLAMP_TO_EDGE),y.updatePatternPaintBuffers(h));var b=c.constantOr(null);if(b&&v.imageAtlas){var _=v.imageAtlas.patternPositions[b.to],w=v.imageAtlas.patternPositions[b.from];_&&w&&y.setConstantPatternPositions(_,w)}var k=t.translatePosMatrix(g.posMatrix,v,r.paint.get(\"fill-extrusion-translate\"),r.paint.get(\"fill-extrusion-translate-anchor\")),T=r.paint.get(\"fill-extrusion-vertical-gradient\"),A=u?dr(k,t,T,f,g,h,v):pr(k,t,T,f);x.draw(s,s.gl.TRIANGLES,i,a,o,St.backCCW,A,r.id,m.layoutVertexBuffer,m.indexBuffer,m.segments,r.paint,t.transform.zoom,y)}}}function Jr(t,e,r,n,i,a){var o=t.context,s=o.gl,l=e.fbo;if(l){var c=t.useProgram(\"hillshade\");o.activeTexture.set(s.TEXTURE0),s.bindTexture(s.TEXTURE_2D,l.colorAttachment.get());var u=Ar(t,e,r);e.maskedBoundsBuffer&&e.maskedIndexBuffer&&e.segments?c.draw(o,s.TRIANGLES,n,i,a,St.disabled,u,r.id,e.maskedBoundsBuffer,e.maskedIndexBuffer,e.segments):c.draw(o,s.TRIANGLES,n,i,a,St.disabled,u,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}}function Kr(e,r,n,i,a,o,s){var l=e.context,c=l.gl;if(r.dem&&r.dem.data){var u=r.dem.dim,h=r.dem.stride,f=r.dem.getPixels();if(l.activeTexture.set(c.TEXTURE1),l.pixelStoreUnpackPremultiplyAlpha.set(!1),r.demTexture=r.demTexture||e.getTileTexture(h),r.demTexture){var p=r.demTexture;p.update(f,{premultiply:!1}),p.bind(c.NEAREST,c.CLAMP_TO_EDGE)}else r.demTexture=new t.Texture(l,f,c.RGBA,{premultiply:!1}),r.demTexture.bind(c.NEAREST,c.CLAMP_TO_EDGE);l.activeTexture.set(c.TEXTURE0);var d=r.fbo;if(!d){var g=new t.Texture(l,{width:u,height:u,data:null},c.RGBA);g.bind(c.LINEAR,c.CLAMP_TO_EDGE),(d=r.fbo=l.createFramebuffer(u,u)).colorAttachment.set(g.texture)}l.bindFramebuffer.set(d.framebuffer),l.viewport.set([0,0,u,u]),e.useProgram(\"hillshadePrepare\").draw(l,c.TRIANGLES,a,o,s,St.disabled,Mr(r,i),n.id,e.rasterBoundsBuffer,e.quadTriangleIndexBuffer,e.rasterBoundsSegments),r.needsHillshadePrepare=!1}}function $r(e,r,n,i,a){var o=i.paint.get(\"raster-fade-duration\");if(o>0){var s=t.browser.now(),l=(s-e.timeAdded)/o,c=r?(s-r.timeAdded)/o:-1,u=n.getSource(),h=a.coveringZoomLevel({tileSize:u.tileSize,roundZoom:u.roundZoom}),f=!r||Math.abs(r.tileID.overscaledZ-h)>Math.abs(e.tileID.overscaledZ-h),p=f&&e.refreshedUponExpiration?1:t.clamp(f?l:1-c,0,1);return e.refreshedUponExpiration&&l>=1&&(e.refreshedUponExpiration=!1),r?{opacity:1,mix:1-p}:{opacity:p,mix:0}}return{opacity:1,mix:0}}function Qr(e,r,n){var i=e.context,a=i.gl,o=n.posMatrix,s=e.useProgram(\"debug\"),l=Tt.disabled,c=At.disabled,u=e.colorModeForRenderPass(),h=\"$debug\";s.draw(i,a.LINE_STRIP,l,c,u,St.disabled,wr(o,t.Color.red),h,e.debugBuffer,e.tileBorderIndexBuffer,e.debugSegments);for(var f=r.getTileByID(n.key).latestRawTileData,p=f&&f.byteLength||0,d=Math.floor(p/1024),g=function(t,e,r,n){n=n||1;var i,a,o,s,l,c,u,h,f=[];for(i=0,a=t.length;i<a;i++)if(l=tn[t[i]]){for(h=null,o=0,s=l[1].length;o<s;o+=2)-1===l[1][o]&&-1===l[1][o+1]?h=null:(c=e+l[1][o]*n,u=200-l[1][o+1]*n,h&&f.push(h.x,h.y,c,u),h={x:c,y:u});e+=l[0]*n}return f}(n.toString()+\" \"+d+\"kb\",50,0,5),v=new t.StructArrayLayout2i4,m=new t.StructArrayLayout2ui4,y=0;y<g.length;y+=2)v.emplaceBack(g[y],g[y+1]),m.emplaceBack(y,y+1);for(var x=i.createVertexBuffer(v,Re.members),b=i.createIndexBuffer(m),_=t.SegmentVector.simpleSegment(0,0,v.length/2,v.length/2),w=r.getTile(n).tileSize,k=t.EXTENT/(Math.pow(2,e.transform.zoom-n.overscaledZ)*w),T=[[-1,-1],[-1,1],[1,-1],[1,1]],A=0;A<T.length;A++){var M=T[A];s.draw(i,a.LINES,l,c,u,St.disabled,wr(t.translate([],o,[k*M[0],k*M[1],0]),t.Color.white),h,x,b,_)}s.draw(i,a.LINES,l,c,u,St.disabled,wr(o,t.Color.black),h,x,b,_)}var tn={\" \":[16,[]],\"!\":[10,[5,21,5,7,-1,-1,5,2,4,1,5,0,6,1,5,2]],'\"':[16,[4,21,4,14,-1,-1,12,21,12,14]],\"#\":[21,[11,25,4,-7,-1,-1,17,25,10,-7,-1,-1,4,12,18,12,-1,-1,3,6,17,6]],$:[20,[8,25,8,-4,-1,-1,12,25,12,-4,-1,-1,17,18,15,20,12,21,8,21,5,20,3,18,3,16,4,14,5,13,7,12,13,10,15,9,16,8,17,6,17,3,15,1,12,0,8,0,5,1,3,3]],\"%\":[24,[21,21,3,0,-1,-1,8,21,10,19,10,17,9,15,7,14,5,14,3,16,3,18,4,20,6,21,8,21,10,20,13,19,16,19,19,20,21,21,-1,-1,17,7,15,6,14,4,14,2,16,0,18,0,20,1,21,3,21,5,19,7,17,7]],\"&\":[26,[23,12,23,13,22,14,21,14,20,13,19,11,17,6,15,3,13,1,11,0,7,0,5,1,4,2,3,4,3,6,4,8,5,9,12,13,13,14,14,16,14,18,13,20,11,21,9,20,8,18,8,16,9,13,11,10,16,3,18,1,20,0,22,0,23,1,23,2]],\"'\":[10,[5,19,4,20,5,21,6,20,6,18,5,16,4,15]],\"(\":[14,[11,25,9,23,7,20,5,16,4,11,4,7,5,2,7,-2,9,-5,11,-7]],\")\":[14,[3,25,5,23,7,20,9,16,10,11,10,7,9,2,7,-2,5,-5,3,-7]],\"*\":[16,[8,21,8,9,-1,-1,3,18,13,12,-1,-1,13,18,3,12]],\"+\":[26,[13,18,13,0,-1,-1,4,9,22,9]],\",\":[10,[6,1,5,0,4,1,5,2,6,1,6,-1,5,-3,4,-4]],\"-\":[26,[4,9,22,9]],\".\":[10,[5,2,4,1,5,0,6,1,5,2]],\"/\":[22,[20,25,2,-7]],0:[20,[9,21,6,20,4,17,3,12,3,9,4,4,6,1,9,0,11,0,14,1,16,4,17,9,17,12,16,17,14,20,11,21,9,21]],1:[20,[6,17,8,18,11,21,11,0]],2:[20,[4,16,4,17,5,19,6,20,8,21,12,21,14,20,15,19,16,17,16,15,15,13,13,10,3,0,17,0]],3:[20,[5,21,16,21,10,13,13,13,15,12,16,11,17,8,17,6,16,3,14,1,11,0,8,0,5,1,4,2,3,4]],4:[20,[13,21,3,7,18,7,-1,-1,13,21,13,0]],5:[20,[15,21,5,21,4,12,5,13,8,14,11,14,14,13,16,11,17,8,17,6,16,3,14,1,11,0,8,0,5,1,4,2,3,4]],6:[20,[16,18,15,20,12,21,10,21,7,20,5,17,4,12,4,7,5,3,7,1,10,0,11,0,14,1,16,3,17,6,17,7,16,10,14,12,11,13,10,13,7,12,5,10,4,7]],7:[20,[17,21,7,0,-1,-1,3,21,17,21]],8:[20,[8,21,5,20,4,18,4,16,5,14,7,13,11,12,14,11,16,9,17,7,17,4,16,2,15,1,12,0,8,0,5,1,4,2,3,4,3,7,4,9,6,11,9,12,13,13,15,14,16,16,16,18,15,20,12,21,8,21]],9:[20,[16,14,15,11,13,9,10,8,9,8,6,9,4,11,3,14,3,15,4,18,6,20,9,21,10,21,13,20,15,18,16,14,16,9,15,4,13,1,10,0,8,0,5,1,4,3]],\":\":[10,[5,14,4,13,5,12,6,13,5,14,-1,-1,5,2,4,1,5,0,6,1,5,2]],\";\":[10,[5,14,4,13,5,12,6,13,5,14,-1,-1,6,1,5,0,4,1,5,2,6,1,6,-1,5,-3,4,-4]],\"<\":[24,[20,18,4,9,20,0]],\"=\":[26,[4,12,22,12,-1,-1,4,6,22,6]],\">\":[24,[4,18,20,9,4,0]],\"?\":[18,[3,16,3,17,4,19,5,20,7,21,11,21,13,20,14,19,15,17,15,15,14,13,13,12,9,10,9,7,-1,-1,9,2,8,1,9,0,10,1,9,2]],\"@\":[27,[18,13,17,15,15,16,12,16,10,15,9,14,8,11,8,8,9,6,11,5,14,5,16,6,17,8,-1,-1,12,16,10,14,9,11,9,8,10,6,11,5,-1,-1,18,16,17,8,17,6,19,5,21,5,23,7,24,10,24,12,23,15,22,17,20,19,18,20,15,21,12,21,9,20,7,19,5,17,4,15,3,12,3,9,4,6,5,4,7,2,9,1,12,0,15,0,18,1,20,2,21,3,-1,-1,19,16,18,8,18,6,19,5]],A:[18,[9,21,1,0,-1,-1,9,21,17,0,-1,-1,4,7,14,7]],B:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,15,17,13,16,12,13,11,-1,-1,4,11,13,11,16,10,17,9,18,7,18,4,17,2,16,1,13,0,4,0]],C:[21,[18,16,17,18,15,20,13,21,9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5]],D:[21,[4,21,4,0,-1,-1,4,21,11,21,14,20,16,18,17,16,18,13,18,8,17,5,16,3,14,1,11,0,4,0]],E:[19,[4,21,4,0,-1,-1,4,21,17,21,-1,-1,4,11,12,11,-1,-1,4,0,17,0]],F:[18,[4,21,4,0,-1,-1,4,21,17,21,-1,-1,4,11,12,11]],G:[21,[18,16,17,18,15,20,13,21,9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,18,8,-1,-1,13,8,18,8]],H:[22,[4,21,4,0,-1,-1,18,21,18,0,-1,-1,4,11,18,11]],I:[8,[4,21,4,0]],J:[16,[12,21,12,5,11,2,10,1,8,0,6,0,4,1,3,2,2,5,2,7]],K:[21,[4,21,4,0,-1,-1,18,21,4,7,-1,-1,9,12,18,0]],L:[17,[4,21,4,0,-1,-1,4,0,16,0]],M:[24,[4,21,4,0,-1,-1,4,21,12,0,-1,-1,20,21,12,0,-1,-1,20,21,20,0]],N:[22,[4,21,4,0,-1,-1,4,21,18,0,-1,-1,18,21,18,0]],O:[22,[9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,19,8,19,13,18,16,17,18,15,20,13,21,9,21]],P:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,14,17,12,16,11,13,10,4,10]],Q:[22,[9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,19,8,19,13,18,16,17,18,15,20,13,21,9,21,-1,-1,12,4,18,-2]],R:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,15,17,13,16,12,13,11,4,11,-1,-1,11,11,18,0]],S:[20,[17,18,15,20,12,21,8,21,5,20,3,18,3,16,4,14,5,13,7,12,13,10,15,9,16,8,17,6,17,3,15,1,12,0,8,0,5,1,3,3]],T:[16,[8,21,8,0,-1,-1,1,21,15,21]],U:[22,[4,21,4,6,5,3,7,1,10,0,12,0,15,1,17,3,18,6,18,21]],V:[18,[1,21,9,0,-1,-1,17,21,9,0]],W:[24,[2,21,7,0,-1,-1,12,21,7,0,-1,-1,12,21,17,0,-1,-1,22,21,17,0]],X:[20,[3,21,17,0,-1,-1,17,21,3,0]],Y:[18,[1,21,9,11,9,0,-1,-1,17,21,9,11]],Z:[20,[17,21,3,0,-1,-1,3,21,17,21,-1,-1,3,0,17,0]],\"[\":[14,[4,25,4,-7,-1,-1,5,25,5,-7,-1,-1,4,25,11,25,-1,-1,4,-7,11,-7]],\"\\\\\":[14,[0,21,14,-3]],\"]\":[14,[9,25,9,-7,-1,-1,10,25,10,-7,-1,-1,3,25,10,25,-1,-1,3,-7,10,-7]],\"^\":[16,[6,15,8,18,10,15,-1,-1,3,12,8,17,13,12,-1,-1,8,17,8,0]],_:[16,[0,-2,16,-2]],\"`\":[10,[6,21,5,20,4,18,4,16,5,15,6,16,5,17]],a:[19,[15,14,15,0,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],b:[19,[4,21,4,0,-1,-1,4,11,6,13,8,14,11,14,13,13,15,11,16,8,16,6,15,3,13,1,11,0,8,0,6,1,4,3]],c:[18,[15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],d:[19,[15,21,15,0,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],e:[18,[3,8,15,8,15,10,14,12,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],f:[12,[10,21,8,21,6,20,5,17,5,0,-1,-1,2,14,9,14]],g:[19,[15,14,15,-2,14,-5,13,-6,11,-7,8,-7,6,-6,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],h:[19,[4,21,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0]],i:[8,[3,21,4,20,5,21,4,22,3,21,-1,-1,4,14,4,0]],j:[10,[5,21,6,20,7,21,6,22,5,21,-1,-1,6,14,6,-3,5,-6,3,-7,1,-7]],k:[17,[4,21,4,0,-1,-1,14,14,4,4,-1,-1,8,8,15,0]],l:[8,[4,21,4,0]],m:[30,[4,14,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0,-1,-1,15,10,18,13,20,14,23,14,25,13,26,10,26,0]],n:[19,[4,14,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0]],o:[19,[8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3,16,6,16,8,15,11,13,13,11,14,8,14]],p:[19,[4,14,4,-7,-1,-1,4,11,6,13,8,14,11,14,13,13,15,11,16,8,16,6,15,3,13,1,11,0,8,0,6,1,4,3]],q:[19,[15,14,15,-7,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],r:[13,[4,14,4,0,-1,-1,4,8,5,11,7,13,9,14,12,14]],s:[17,[14,11,13,13,10,14,7,14,4,13,3,11,4,9,6,8,11,7,13,6,14,4,14,3,13,1,10,0,7,0,4,1,3,3]],t:[12,[5,21,5,4,6,1,8,0,10,0,-1,-1,2,14,9,14]],u:[19,[4,14,4,4,5,1,7,0,10,0,12,1,15,4,-1,-1,15,14,15,0]],v:[16,[2,14,8,0,-1,-1,14,14,8,0]],w:[22,[3,14,7,0,-1,-1,11,14,7,0,-1,-1,11,14,15,0,-1,-1,19,14,15,0]],x:[17,[3,14,14,0,-1,-1,14,14,3,0]],y:[16,[2,14,8,0,-1,-1,14,14,8,0,6,-4,4,-6,2,-7,1,-7]],z:[17,[14,14,3,0,-1,-1,3,14,14,14,-1,-1,3,0,14,0]],\"{\":[14,[9,25,7,24,6,23,5,21,5,19,6,17,7,16,8,14,8,12,6,10,-1,-1,7,24,6,22,6,20,7,18,8,17,9,15,9,13,8,11,4,9,8,7,9,5,9,3,8,1,7,0,6,-2,6,-4,7,-6,-1,-1,6,8,8,6,8,4,7,2,6,1,5,-1,5,-3,6,-5,7,-6,9,-7]],\"|\":[8,[4,25,4,-7]],\"}\":[14,[5,25,7,24,8,23,9,21,9,19,8,17,7,16,6,14,6,12,8,10,-1,-1,7,24,8,22,8,20,7,18,6,17,5,15,5,13,6,11,10,9,6,7,5,5,5,3,6,1,7,0,8,-2,8,-4,7,-6,-1,-1,8,8,6,6,6,4,7,2,8,1,9,-1,9,-3,8,-5,7,-6,5,-7]],\"~\":[24,[3,6,3,8,4,11,6,12,8,12,10,11,14,8,16,7,18,7,20,8,21,10,-1,-1,3,8,4,10,6,11,8,11,10,10,14,7,16,6,18,6,20,7,21,10,21,12]]},en={symbol:function(t,e,r,n,i){if(\"translucent\"===t.renderPass){var a=At.disabled,o=t.colorModeForRenderPass();0!==r.paint.get(\"icon-opacity\").constantOr(1)&&Yr(t,e,r,n,!1,r.paint.get(\"icon-translate\"),r.paint.get(\"icon-translate-anchor\"),r.layout.get(\"icon-rotation-alignment\"),r.layout.get(\"icon-pitch-alignment\"),r.layout.get(\"icon-keep-upright\"),a,o,i),0!==r.paint.get(\"text-opacity\").constantOr(1)&&Yr(t,e,r,n,!0,r.paint.get(\"text-translate\"),r.paint.get(\"text-translate-anchor\"),r.layout.get(\"text-rotation-alignment\"),r.layout.get(\"text-pitch-alignment\"),r.layout.get(\"text-keep-upright\"),a,o,i),e.map.showCollisionBoxes&&function(t,e,r,n){Vr(t,e,r,n,!1),Vr(t,e,r,n,!0)}(t,e,r,n)}},circle:function(t,e,r,n){if(\"translucent\"===t.renderPass){var i=r.paint.get(\"circle-opacity\"),a=r.paint.get(\"circle-stroke-width\"),o=r.paint.get(\"circle-stroke-opacity\");if(0!==i.constantOr(1)||0!==a.constantOr(1)&&0!==o.constantOr(1))for(var s=t.context,l=s.gl,c=t.depthModeForSublayer(0,Tt.ReadOnly),u=At.disabled,h=t.colorModeForRenderPass(),f=0;f<n.length;f++){var p=n[f],d=e.getTile(p),g=d.getBucket(r);if(g){var v=g.programConfigurations.get(r.id);t.useProgram(\"circle\",v).draw(s,l.TRIANGLES,c,u,h,St.disabled,xr(t,p,d,r),r.id,g.layoutVertexBuffer,g.indexBuffer,g.segments,r.paint,t.transform.zoom,v)}}}},heatmap:function(e,r,n,i){if(0!==n.paint.get(\"heatmap-opacity\"))if(\"offscreen\"===e.renderPass){var a=e.context,o=a.gl,s=e.depthModeForSublayer(0,Tt.ReadOnly),l=At.disabled,c=new Mt([o.ONE,o.ONE],t.Color.transparent,[!0,!0,!0,!0]);!function(t,e,r){var n=t.gl;t.activeTexture.set(n.TEXTURE1),t.viewport.set([0,0,e.width/4,e.height/4]);var i=r.heatmapFbo;if(i)n.bindTexture(n.TEXTURE_2D,i.colorAttachment.get()),t.bindFramebuffer.set(i.framebuffer);else{var a=n.createTexture();n.bindTexture(n.TEXTURE_2D,a),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,n.LINEAR),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,n.LINEAR),i=r.heatmapFbo=t.createFramebuffer(e.width/4,e.height/4),function t(e,r,n,i){var a=e.gl;a.texImage2D(a.TEXTURE_2D,0,a.RGBA,r.width/4,r.height/4,0,a.RGBA,e.extTextureHalfFloat?e.extTextureHalfFloat.HALF_FLOAT_OES:a.UNSIGNED_BYTE,null),i.colorAttachment.set(n),e.extTextureHalfFloat&&a.checkFramebufferStatus(a.FRAMEBUFFER)!==a.FRAMEBUFFER_COMPLETE&&(e.extTextureHalfFloat=null,i.colorAttachment.setDirty(),t(e,r,n,i))}(t,e,a,i)}}(a,e,n),a.clear({color:t.Color.transparent});for(var u=0;u<i.length;u++){var h=i[u];if(!r.hasRenderableParent(h)){var f=r.getTile(h),p=f.getBucket(n);if(p){var d=p.programConfigurations.get(n.id),g=e.useProgram(\"heatmap\",d),v=e.transform.zoom;g.draw(a,o.TRIANGLES,s,l,c,St.disabled,Tr(h.posMatrix,f,v,n.paint.get(\"heatmap-intensity\")),n.id,p.layoutVertexBuffer,p.indexBuffer,p.segments,n.paint,e.transform.zoom,d)}}}a.viewport.set([0,0,e.width,e.height])}else\"translucent\"===e.renderPass&&(e.context.setColorMode(e.colorModeForRenderPass()),function(e,r){var n=e.context,i=n.gl,a=r.heatmapFbo;if(a){n.activeTexture.set(i.TEXTURE0),i.bindTexture(i.TEXTURE_2D,a.colorAttachment.get()),n.activeTexture.set(i.TEXTURE1);var o=r.colorRampTexture;o||(o=r.colorRampTexture=new t.Texture(n,r.colorRamp,i.RGBA)),o.bind(i.LINEAR,i.CLAMP_TO_EDGE),e.useProgram(\"heatmapTexture\").draw(n,i.TRIANGLES,Tt.disabled,At.disabled,e.colorModeForRenderPass(),St.disabled,function(e,r,n,i){var a=t.create();t.ortho(a,0,e.width,e.height,0,0,1);var o=e.context.gl;return{u_matrix:a,u_world:[o.drawingBufferWidth,o.drawingBufferHeight],u_image:n,u_color_ramp:i,u_opacity:r.paint.get(\"heatmap-opacity\")}}(e,r,0,1),r.id,e.viewportBuffer,e.quadTriangleIndexBuffer,e.viewportSegments,r.paint,e.transform.zoom)}}(e,n))},line:function(e,r,n,i){if(\"translucent\"===e.renderPass){var a=n.paint.get(\"line-opacity\"),o=n.paint.get(\"line-width\");if(0!==a.constantOr(1)&&0!==o.constantOr(1)){var s=e.depthModeForSublayer(0,Tt.ReadOnly),l=e.colorModeForRenderPass(),c=n.paint.get(\"line-dasharray\"),u=n.paint.get(\"line-pattern\"),h=u.constantOr(1),f=n.paint.get(\"line-gradient\"),p=n.getCrossfadeParameters(),d=c?\"lineSDF\":h?\"linePattern\":f?\"lineGradient\":\"line\",g=e.context,v=g.gl,m=!0;if(f){g.activeTexture.set(v.TEXTURE0);var y=n.gradientTexture;if(!n.gradient)return;y||(y=n.gradientTexture=new t.Texture(g,n.gradient,v.RGBA)),y.bind(v.LINEAR,v.CLAMP_TO_EDGE)}for(var x=0,b=i;x<b.length;x+=1){var _=b[x],w=r.getTile(_);if(!h||w.patternsLoaded()){var k=w.getBucket(n);if(k){var T=k.programConfigurations.get(n.id),A=e.context.program.get(),M=e.useProgram(d,T),S=m||M.program!==A,E=u.constantOr(null);if(E&&w.imageAtlas){var C=w.imageAtlas.patternPositions[E.to],L=w.imageAtlas.patternPositions[E.from];C&&L&&T.setConstantPatternPositions(C,L)}var P=c?Pr(e,w,n,c,p):h?Lr(e,w,n,p):f?Cr(e,w,n):Er(e,w,n);c&&(S||e.lineAtlas.dirty)?(g.activeTexture.set(v.TEXTURE0),e.lineAtlas.bind(g)):h&&(g.activeTexture.set(v.TEXTURE0),w.imageAtlasTexture.bind(v.LINEAR,v.CLAMP_TO_EDGE),T.updatePatternPaintBuffers(p)),M.draw(g,v.TRIANGLES,s,e.stencilModeForClipping(_),l,St.disabled,P,n.id,k.layoutVertexBuffer,k.indexBuffer,k.segments,n.paint,e.transform.zoom,T),m=!1}}}}}},fill:function(e,r,n,i){var a=n.paint.get(\"fill-color\"),o=n.paint.get(\"fill-opacity\");if(0!==o.constantOr(1)){var s=e.colorModeForRenderPass(),l=n.paint.get(\"fill-pattern\"),c=e.opaquePassEnabledForLayer()&&!l.constantOr(1)&&1===a.constantOr(t.Color.transparent).a&&1===o.constantOr(0)?\"opaque\":\"translucent\";if(e.renderPass===c){var u=e.depthModeForSublayer(1,\"opaque\"===e.renderPass?Tt.ReadWrite:Tt.ReadOnly);Xr(e,r,n,i,u,s,!1)}if(\"translucent\"===e.renderPass&&n.paint.get(\"fill-antialias\")){var h=e.depthModeForSublayer(n.getPaintProperty(\"fill-outline-color\")?2:0,Tt.ReadOnly);Xr(e,r,n,i,h,s,!0)}}},\"fill-extrusion\":function(t,e,r,n){var i=r.paint.get(\"fill-extrusion-opacity\");if(0!==i&&\"translucent\"===t.renderPass){var a=new Tt(t.context.gl.LEQUAL,Tt.ReadWrite,t.depthRangeFor3D);if(1!==i||r.paint.get(\"fill-extrusion-pattern\").constantOr(1))Zr(t,e,r,n,a,At.disabled,Mt.disabled),Zr(t,e,r,n,a,t.stencilModeFor3D(),t.colorModeForRenderPass());else{var o=t.colorModeForRenderPass();Zr(t,e,r,n,a,At.disabled,o)}}},hillshade:function(t,e,r,n){if(\"offscreen\"===t.renderPass||\"translucent\"===t.renderPass){for(var i=t.context,a=e.getSource().maxzoom,o=t.depthModeForSublayer(0,Tt.ReadOnly),s=At.disabled,l=t.colorModeForRenderPass(),c=0,u=n;c<u.length;c+=1){var h=u[c],f=e.getTile(h);f.needsHillshadePrepare&&\"offscreen\"===t.renderPass?Kr(t,f,r,a,o,s,l):\"translucent\"===t.renderPass&&Jr(t,f,r,o,s,l)}i.viewport.set([0,0,t.width,t.height])}},raster:function(t,e,r,n){if(\"translucent\"===t.renderPass&&0!==r.paint.get(\"raster-opacity\"))for(var i=t.context,a=i.gl,o=e.getSource(),s=t.useProgram(\"raster\"),l=At.disabled,c=t.colorModeForRenderPass(),u=n.length&&n[0].overscaledZ,h=!t.options.moving,f=0,p=n;f<p.length;f+=1){var d=p[f],g=t.depthModeForSublayer(d.overscaledZ-u,1===r.paint.get(\"raster-opacity\")?Tt.ReadWrite:Tt.ReadOnly,a.LESS),v=e.getTile(d),m=t.transform.calculatePosMatrix(d.toUnwrapped(),h);v.registerFadeDuration(r.paint.get(\"raster-fade-duration\"));var y=e.findLoadedParent(d,0),x=$r(v,y,e,r,t.transform),b=void 0,_=void 0,w=\"nearest\"===r.paint.get(\"raster-resampling\")?a.NEAREST:a.LINEAR;i.activeTexture.set(a.TEXTURE0),v.texture.bind(w,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),i.activeTexture.set(a.TEXTURE1),y?(y.texture.bind(w,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),b=Math.pow(2,y.tileID.overscaledZ-v.tileID.overscaledZ),_=[v.tileID.canonical.x*b%1,v.tileID.canonical.y*b%1]):v.texture.bind(w,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST);var k=Ir(m,_||[0,0],b||1,x,r);o instanceof L?s.draw(i,a.TRIANGLES,g,l,c,St.disabled,k,r.id,o.boundsBuffer,t.quadTriangleIndexBuffer,o.boundsSegments):v.maskedBoundsBuffer&&v.maskedIndexBuffer&&v.segments?s.draw(i,a.TRIANGLES,g,l,c,St.disabled,k,r.id,v.maskedBoundsBuffer,v.maskedIndexBuffer,v.segments,r.paint,t.transform.zoom):s.draw(i,a.TRIANGLES,g,l,c,St.disabled,k,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}},background:function(t,e,r){var n=r.paint.get(\"background-color\"),i=r.paint.get(\"background-opacity\");if(0!==i){var a=t.context,o=a.gl,s=t.transform,l=s.tileSize,c=r.paint.get(\"background-pattern\");if(!t.isPatternMissing(c)){var u=c||1!==n.a||1!==i?\"translucent\":\"opaque\";if(t.renderPass===u){var h=At.disabled,f=t.depthModeForSublayer(0,\"opaque\"===u?Tt.ReadWrite:Tt.ReadOnly),p=t.colorModeForRenderPass(),d=t.useProgram(c?\"backgroundPattern\":\"background\"),g=s.coveringTiles({tileSize:l});c&&(a.activeTexture.set(o.TEXTURE0),t.imageManager.bind(t.context));for(var v=r.getCrossfadeParameters(),m=0,y=g;m<y.length;m+=1){var x=y[m],b=t.transform.calculatePosMatrix(x.toUnwrapped()),_=c?Br(b,i,t,c,{tileID:x,tileSize:l},v):Fr(b,i,n);d.draw(a,o.TRIANGLES,f,h,p,St.disabled,_,r.id,t.tileExtentBuffer,t.quadTriangleIndexBuffer,t.tileExtentSegments)}}}}},debug:function(t,e,r){for(var n=0;n<r.length;n++)Qr(t,e,r[n])},custom:function(t,e,r){var n=t.context,i=r.implementation;if(\"offscreen\"===t.renderPass){var a=i.prerender;a&&(t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),a.call(i,n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState())}else if(\"translucent\"===t.renderPass){t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),n.setStencilMode(At.disabled);var o=\"3d\"===i.renderingMode?new Tt(t.context.gl.LEQUAL,Tt.ReadWrite,t.depthRangeFor3D):t.depthModeForSublayer(0,Tt.ReadOnly);n.setDepthMode(o),i.render(n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState(),n.bindFramebuffer.set(null)}}},rn=function(e,r){this.context=new Et(e),this.transform=r,this._tileTextures={},this.setup(),this.numSublayers=Ct.maxUnderzooming+Ct.maxOverzooming+1,this.depthEpsilon=1/Math.pow(2,16),this.depthRboNeedsClear=!0,this.emptyProgramConfiguration=new t.ProgramConfiguration,this.crossTileSymbolIndex=new Pe};function nn(t,e){if(t.y>e.y){var r=t;t=e,e=r}return{x0:t.x,y0:t.y,x1:e.x,y1:e.y,dx:e.x-t.x,dy:e.y-t.y}}function an(t,e,r,n,i){var a=Math.max(r,Math.floor(e.y0)),o=Math.min(n,Math.ceil(e.y1));if(t.x0===e.x0&&t.y0===e.y0?t.x0+e.dy/t.dy*t.dx<e.x1:t.x1-e.dy/t.dy*t.dx<e.x0){var s=t;t=e,e=s}for(var l=t.dx/t.dy,c=e.dx/e.dy,u=t.dx>0,h=e.dx<0,f=a;f<o;f++){var p=l*Math.max(0,Math.min(t.dy,f+u-t.y0))+t.x0,d=c*Math.max(0,Math.min(e.dy,f+h-e.y0))+e.x0;i(Math.floor(d),Math.ceil(p),f)}}function on(t,e,r,n,i,a){var o,s=nn(t,e),l=nn(e,r),c=nn(r,t);s.dy>l.dy&&(o=s,s=l,l=o),s.dy>c.dy&&(o=s,s=c,c=o),l.dy>c.dy&&(o=l,l=c,c=o),s.dy&&an(c,s,n,i,a),l.dy&&an(c,l,n,i,a)}rn.prototype.resize=function(e,r){var n=this.context.gl;if(this.width=e*t.browser.devicePixelRatio,this.height=r*t.browser.devicePixelRatio,this.context.viewport.set([0,0,this.width,this.height]),this.style)for(var i=0,a=this.style._order;i<a.length;i+=1){var o=a[i];this.style._layers[o].resize()}this.depthRbo&&(n.deleteRenderbuffer(this.depthRbo),this.depthRbo=null)},rn.prototype.setup=function(){var e=this.context,r=new t.StructArrayLayout2i4;r.emplaceBack(0,0),r.emplaceBack(t.EXTENT,0),r.emplaceBack(0,t.EXTENT),r.emplaceBack(t.EXTENT,t.EXTENT),this.tileExtentBuffer=e.createVertexBuffer(r,Re.members),this.tileExtentSegments=t.SegmentVector.simpleSegment(0,0,4,2);var n=new t.StructArrayLayout2i4;n.emplaceBack(0,0),n.emplaceBack(t.EXTENT,0),n.emplaceBack(0,t.EXTENT),n.emplaceBack(t.EXTENT,t.EXTENT),this.debugBuffer=e.createVertexBuffer(n,Re.members),this.debugSegments=t.SegmentVector.simpleSegment(0,0,4,5);var i=new t.StructArrayLayout4i8;i.emplaceBack(0,0,0,0),i.emplaceBack(t.EXTENT,0,t.EXTENT,0),i.emplaceBack(0,t.EXTENT,0,t.EXTENT),i.emplaceBack(t.EXTENT,t.EXTENT,t.EXTENT,t.EXTENT),this.rasterBoundsBuffer=e.createVertexBuffer(i,t.rasterBoundsAttributes.members),this.rasterBoundsSegments=t.SegmentVector.simpleSegment(0,0,4,2);var a=new t.StructArrayLayout2i4;a.emplaceBack(0,0),a.emplaceBack(1,0),a.emplaceBack(0,1),a.emplaceBack(1,1),this.viewportBuffer=e.createVertexBuffer(a,Re.members),this.viewportSegments=t.SegmentVector.simpleSegment(0,0,4,2);var o=new t.StructArrayLayout1ui2;o.emplaceBack(0),o.emplaceBack(1),o.emplaceBack(3),o.emplaceBack(2),o.emplaceBack(0),this.tileBorderIndexBuffer=e.createIndexBuffer(o);var s=new t.StructArrayLayout3ui6;s.emplaceBack(0,1,2),s.emplaceBack(2,1,3),this.quadTriangleIndexBuffer=e.createIndexBuffer(s);var l=this.context.gl;this.stencilClearMode=new At({func:l.ALWAYS,mask:0},0,255,l.ZERO,l.ZERO,l.ZERO)},rn.prototype.clearStencil=function(){var e=this.context,r=e.gl;this.nextStencilID=1,this.currentStencilSource=void 0;var n=t.create();t.ortho(n,0,this.width,this.height,0,0,1),t.scale(n,n,[r.drawingBufferWidth,r.drawingBufferHeight,0]),this.useProgram(\"clippingMask\").draw(e,r.TRIANGLES,Tt.disabled,this.stencilClearMode,Mt.disabled,St.disabled,kr(n),\"$clipping\",this.viewportBuffer,this.quadTriangleIndexBuffer,this.viewportSegments)},rn.prototype._renderTileClippingMasks=function(t,e){if(this.currentStencilSource!==t.source&&t.isTileClipped()&&e&&e.length){this.currentStencilSource=t.source;var r=this.context,n=r.gl;this.nextStencilID+e.length>256&&this.clearStencil(),r.setColorMode(Mt.disabled),r.setDepthMode(Tt.disabled);var i=this.useProgram(\"clippingMask\");this._tileClippingMaskIDs={};for(var a=0,o=e;a<o.length;a+=1){var s=o[a],l=this._tileClippingMaskIDs[s.key]=this.nextStencilID++;i.draw(r,n.TRIANGLES,Tt.disabled,new At({func:n.ALWAYS,mask:0},l,255,n.KEEP,n.KEEP,n.REPLACE),Mt.disabled,St.disabled,kr(s.posMatrix),\"$clipping\",this.tileExtentBuffer,this.quadTriangleIndexBuffer,this.tileExtentSegments)}}},rn.prototype.stencilModeFor3D=function(){this.nextStencilID+1>256&&this.clearStencil();var t=this.nextStencilID++,e=this.context.gl;return new At({func:e.NOTEQUAL,mask:255},t,255,e.KEEP,e.KEEP,e.REPLACE)},rn.prototype.stencilModeForClipping=function(t){var e=this.context.gl;return new At({func:e.EQUAL,mask:255},this._tileClippingMaskIDs[t.key],0,e.KEEP,e.KEEP,e.REPLACE)},rn.prototype.colorModeForRenderPass=function(){var e=this.context.gl;return this._showOverdrawInspector?new Mt([e.CONSTANT_COLOR,e.ONE],new t.Color(1/8,1/8,1/8,0),[!0,!0,!0,!0]):\"opaque\"===this.renderPass?Mt.unblended:Mt.alphaBlended},rn.prototype.depthModeForSublayer=function(t,e,r){if(!this.opaquePassEnabledForLayer())return Tt.disabled;var n=1-((1+this.currentLayer)*this.numSublayers+t)*this.depthEpsilon;return new Tt(r||this.context.gl.LEQUAL,e,[n,n])},rn.prototype.opaquePassEnabledForLayer=function(){return this.currentLayer<this.opaquePassCutoff},rn.prototype.render=function(e,r){this.style=e,this.options=r,this.lineAtlas=e.lineAtlas,this.imageManager=e.imageManager,this.glyphManager=e.glyphManager,this.symbolFadeChange=e.placement.symbolFadeChange(t.browser.now()),this.imageManager.beginFrame();var n=this.style._order,i=this.style.sourceCaches;for(var a in i){var o=i[a];o.used&&o.prepare(this.context)}var s={},l={},c={};for(var u in i){var h=i[u];s[u]=h.getVisibleCoordinates(),l[u]=s[u].slice().reverse(),c[u]=h.getVisibleCoordinates(!0).reverse()}for(var f in i){var p=i[f],d=p.getSource();if(\"raster\"===d.type||\"raster-dem\"===d.type){for(var g=[],v=0,m=s[f];v<m.length;v+=1){var y=m[v];g.push(p.getTile(y))}jr(g,this.context)}}this.opaquePassCutoff=1/0;for(var x=0;x<n.length;x++){var b=n[x];if(this.style._layers[b].is3D()){this.opaquePassCutoff=x;break}}this.renderPass=\"offscreen\",this.depthRboNeedsClear=!0;for(var _=0,w=n;_<w.length;_+=1){var k=w[_],T=this.style._layers[k];if(T.hasOffscreenPass()&&!T.isHidden(this.transform.zoom)){var A=l[T.source];(\"custom\"===T.type||A.length)&&this.renderLayer(this,i[T.source],T,A)}}for(this.context.bindFramebuffer.set(null),this.context.clear({color:r.showOverdrawInspector?t.Color.black:t.Color.transparent,depth:1}),this.clearStencil(),this._showOverdrawInspector=r.showOverdrawInspector,this.depthRangeFor3D=[0,1-(e._order.length+2)*this.numSublayers*this.depthEpsilon],this.renderPass=\"opaque\",this.currentLayer=n.length-1;this.currentLayer>=0;this.currentLayer--){var M=this.style._layers[n[this.currentLayer]],S=i[M.source],E=s[M.source];this._renderTileClippingMasks(M,E),this.renderLayer(this,S,M,E)}for(this.renderPass=\"translucent\",this.currentLayer=0;this.currentLayer<n.length;this.currentLayer++){var C=this.style._layers[n[this.currentLayer]],L=i[C.source],P=(\"symbol\"===C.type?c:l)[C.source];this._renderTileClippingMasks(C,s[C.source]),this.renderLayer(this,L,C,P)}if(this.options.showTileBoundaries)for(var O in i){en.debug(this,i[O],s[O]);break}this.context.setDefault()},rn.prototype.setupOffscreenDepthRenderbuffer=function(){var t=this.context;this.depthRbo||(this.depthRbo=t.createRenderbuffer(t.gl.DEPTH_COMPONENT16,this.width,this.height))},rn.prototype.renderLayer=function(t,e,r,n){r.isHidden(this.transform.zoom)||(\"background\"===r.type||\"custom\"===r.type||n.length)&&(this.id=r.id,en[r.type](t,e,r,n,this.style.placement.variableOffsets))},rn.prototype.translatePosMatrix=function(e,r,n,i,a){if(!n[0]&&!n[1])return e;var o=a?\"map\"===i?this.transform.angle:0:\"viewport\"===i?-this.transform.angle:0;if(o){var s=Math.sin(o),l=Math.cos(o);n=[n[0]*l-n[1]*s,n[0]*s+n[1]*l]}var c=[a?n[0]:le(r,n[0],this.transform.zoom),a?n[1]:le(r,n[1],this.transform.zoom),0],u=new Float32Array(16);return t.translate(u,e,c),u},rn.prototype.saveTileTexture=function(t){var e=this._tileTextures[t.size[0]];e?e.push(t):this._tileTextures[t.size[0]]=[t]},rn.prototype.getTileTexture=function(t){var e=this._tileTextures[t];return e&&e.length>0?e.pop():null},rn.prototype.isPatternMissing=function(t){if(!t)return!1;var e=this.imageManager.getPattern(t.from),r=this.imageManager.getPattern(t.to);return!e||!r},rn.prototype.useProgram=function(t,e){void 0===e&&(e=this.emptyProgramConfiguration),this.cache=this.cache||{};var r=\"\"+t+(e.cacheKey||\"\")+(this._showOverdrawInspector?\"/overdraw\":\"\");return this.cache[r]||(this.cache[r]=new hr(this.context,cr[t],e,Nr[t],this._showOverdrawInspector)),this.cache[r]},rn.prototype.setCustomLayerDefaults=function(){this.context.unbindVAO(),this.context.cullFace.setDefault(),this.context.activeTexture.setDefault(),this.context.pixelStoreUnpack.setDefault(),this.context.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.context.pixelStoreUnpackFlipY.setDefault()},rn.prototype.setBaseState=function(){var t=this.context.gl;this.context.cullFace.set(!1),this.context.viewport.set([0,0,this.width,this.height]),this.context.blendEquation.set(t.FUNC_ADD)};var sn=function(e,r,n){this.tileSize=512,this.maxValidLatitude=85.051129,this._renderWorldCopies=void 0===n||n,this._minZoom=e||0,this._maxZoom=r||22,this.setMaxBounds(),this.width=0,this.height=0,this._center=new t.LngLat(0,0),this.zoom=0,this.angle=0,this._fov=.6435011087932844,this._pitch=0,this._unmodified=!0,this._posMatrixCache={},this._alignedPosMatrixCache={}},ln={minZoom:{configurable:!0},maxZoom:{configurable:!0},renderWorldCopies:{configurable:!0},worldSize:{configurable:!0},centerPoint:{configurable:!0},size:{configurable:!0},bearing:{configurable:!0},pitch:{configurable:!0},fov:{configurable:!0},zoom:{configurable:!0},center:{configurable:!0},unmodified:{configurable:!0},point:{configurable:!0}};sn.prototype.clone=function(){var t=new sn(this._minZoom,this._maxZoom,this._renderWorldCopies);return t.tileSize=this.tileSize,t.latRange=this.latRange,t.width=this.width,t.height=this.height,t._center=this._center,t.zoom=this.zoom,t.angle=this.angle,t._fov=this._fov,t._pitch=this._pitch,t._unmodified=this._unmodified,t._calcMatrices(),t},ln.minZoom.get=function(){return this._minZoom},ln.minZoom.set=function(t){this._minZoom!==t&&(this._minZoom=t,this.zoom=Math.max(this.zoom,t))},ln.maxZoom.get=function(){return this._maxZoom},ln.maxZoom.set=function(t){this._maxZoom!==t&&(this._maxZoom=t,this.zoom=Math.min(this.zoom,t))},ln.renderWorldCopies.get=function(){return this._renderWorldCopies},ln.renderWorldCopies.set=function(t){void 0===t?t=!0:null===t&&(t=!1),this._renderWorldCopies=t},ln.worldSize.get=function(){return this.tileSize*this.scale},ln.centerPoint.get=function(){return this.size._div(2)},ln.size.get=function(){return new t.Point(this.width,this.height)},ln.bearing.get=function(){return-this.angle/Math.PI*180},ln.bearing.set=function(e){var r=-t.wrap(e,-180,180)*Math.PI/180;this.angle!==r&&(this._unmodified=!1,this.angle=r,this._calcMatrices(),this.rotationMatrix=t.create$2(),t.rotate(this.rotationMatrix,this.rotationMatrix,this.angle))},ln.pitch.get=function(){return this._pitch/Math.PI*180},ln.pitch.set=function(e){var r=t.clamp(e,0,60)/180*Math.PI;this._pitch!==r&&(this._unmodified=!1,this._pitch=r,this._calcMatrices())},ln.fov.get=function(){return this._fov/Math.PI*180},ln.fov.set=function(t){t=Math.max(.01,Math.min(60,t)),this._fov!==t&&(this._unmodified=!1,this._fov=t/180*Math.PI,this._calcMatrices())},ln.zoom.get=function(){return this._zoom},ln.zoom.set=function(t){var e=Math.min(Math.max(t,this.minZoom),this.maxZoom);this._zoom!==e&&(this._unmodified=!1,this._zoom=e,this.scale=this.zoomScale(e),this.tileZoom=Math.floor(e),this.zoomFraction=e-this.tileZoom,this._constrain(),this._calcMatrices())},ln.center.get=function(){return this._center},ln.center.set=function(t){t.lat===this._center.lat&&t.lng===this._center.lng||(this._unmodified=!1,this._center=t,this._constrain(),this._calcMatrices())},sn.prototype.coveringZoomLevel=function(t){return(t.roundZoom?Math.round:Math.floor)(this.zoom+this.scaleZoom(this.tileSize/t.tileSize))},sn.prototype.getVisibleUnwrappedCoordinates=function(e){var r=[new t.UnwrappedTileID(0,e)];if(this._renderWorldCopies)for(var n=this.pointCoordinate(new t.Point(0,0)),i=this.pointCoordinate(new t.Point(this.width,0)),a=this.pointCoordinate(new t.Point(this.width,this.height)),o=this.pointCoordinate(new t.Point(0,this.height)),s=Math.floor(Math.min(n.x,i.x,a.x,o.x)),l=Math.floor(Math.max(n.x,i.x,a.x,o.x)),c=s-1;c<=l+1;c++)0!==c&&r.push(new t.UnwrappedTileID(c,e));return r},sn.prototype.coveringTiles=function(e){var r=this.coveringZoomLevel(e),n=r;if(void 0!==e.minzoom&&r<e.minzoom)return[];void 0!==e.maxzoom&&r>e.maxzoom&&(r=e.maxzoom);var i=t.MercatorCoordinate.fromLngLat(this.center),a=Math.pow(2,r),o=new t.Point(a*i.x-.5,a*i.y-.5);return function(e,r,n,i){void 0===i&&(i=!0);var a=1<<e,o={};function s(r,s,l){var c,u,h,f;if(l>=0&&l<=a)for(c=r;c<s;c++)u=Math.floor(c/a),h=(c%a+a)%a,0!==u&&!0!==i||(f=new t.OverscaledTileID(n,u,e,h,l),o[f.key]=f)}var l=r.map(function(e){return new t.Point(e.x,e.y)._mult(a)});return on(l[0],l[1],l[2],0,a,s),on(l[2],l[3],l[0],0,a,s),Object.keys(o).map(function(t){return o[t]})}(r,[this.pointCoordinate(new t.Point(0,0)),this.pointCoordinate(new t.Point(this.width,0)),this.pointCoordinate(new t.Point(this.width,this.height)),this.pointCoordinate(new t.Point(0,this.height))],e.reparseOverscaled?n:r,this._renderWorldCopies).sort(function(t,e){return o.dist(t.canonical)-o.dist(e.canonical)})},sn.prototype.resize=function(t,e){this.width=t,this.height=e,this.pixelsToGLUnits=[2/t,-2/e],this._constrain(),this._calcMatrices()},ln.unmodified.get=function(){return this._unmodified},sn.prototype.zoomScale=function(t){return Math.pow(2,t)},sn.prototype.scaleZoom=function(t){return Math.log(t)/Math.LN2},sn.prototype.project=function(e){var r=t.clamp(e.lat,-this.maxValidLatitude,this.maxValidLatitude);return new t.Point(t.mercatorXfromLng(e.lng)*this.worldSize,t.mercatorYfromLat(r)*this.worldSize)},sn.prototype.unproject=function(e){return new t.MercatorCoordinate(e.x/this.worldSize,e.y/this.worldSize).toLngLat()},ln.point.get=function(){return this.project(this.center)},sn.prototype.setLocationAtPoint=function(e,r){var n=this.pointCoordinate(r),i=this.pointCoordinate(this.centerPoint),a=this.locationCoordinate(e),o=new t.MercatorCoordinate(a.x-(n.x-i.x),a.y-(n.y-i.y));this.center=this.coordinateLocation(o),this._renderWorldCopies&&(this.center=this.center.wrap())},sn.prototype.locationPoint=function(t){return this.coordinatePoint(this.locationCoordinate(t))},sn.prototype.pointLocation=function(t){return this.coordinateLocation(this.pointCoordinate(t))},sn.prototype.locationCoordinate=function(e){return t.MercatorCoordinate.fromLngLat(e)},sn.prototype.coordinateLocation=function(t){return t.toLngLat()},sn.prototype.pointCoordinate=function(e){var r=[e.x,e.y,0,1],n=[e.x,e.y,1,1];t.transformMat4(r,r,this.pixelMatrixInverse),t.transformMat4(n,n,this.pixelMatrixInverse);var i=r[3],a=n[3],o=r[0]/i,s=n[0]/a,l=r[1]/i,c=n[1]/a,u=r[2]/i,h=n[2]/a,f=u===h?0:(0-u)/(h-u);return new t.MercatorCoordinate(t.number(o,s,f)/this.worldSize,t.number(l,c,f)/this.worldSize)},sn.prototype.coordinatePoint=function(e){var r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix),new t.Point(r[0]/r[3],r[1]/r[3])},sn.prototype.getBounds=function(){return(new t.LngLatBounds).extend(this.pointLocation(new t.Point(0,0))).extend(this.pointLocation(new t.Point(this.width,0))).extend(this.pointLocation(new t.Point(this.width,this.height))).extend(this.pointLocation(new t.Point(0,this.height)))},sn.prototype.getMaxBounds=function(){return this.latRange&&2===this.latRange.length&&this.lngRange&&2===this.lngRange.length?new t.LngLatBounds([this.lngRange[0],this.latRange[0]],[this.lngRange[1],this.latRange[1]]):null},sn.prototype.setMaxBounds=function(t){t?(this.lngRange=[t.getWest(),t.getEast()],this.latRange=[t.getSouth(),t.getNorth()],this._constrain()):(this.lngRange=null,this.latRange=[-this.maxValidLatitude,this.maxValidLatitude])},sn.prototype.calculatePosMatrix=function(e,r){void 0===r&&(r=!1);var n=e.key,i=r?this._alignedPosMatrixCache:this._posMatrixCache;if(i[n])return i[n];var a=e.canonical,o=this.worldSize/this.zoomScale(a.z),s=a.x+Math.pow(2,a.z)*e.wrap,l=t.identity(new Float64Array(16));return t.translate(l,l,[s*o,a.y*o,0]),t.scale(l,l,[o/t.EXTENT,o/t.EXTENT,1]),t.multiply(l,r?this.alignedProjMatrix:this.projMatrix,l),i[n]=new Float32Array(l),i[n]},sn.prototype.customLayerMatrix=function(){return this.mercatorMatrix.slice()},sn.prototype._constrain=function(){if(this.center&&this.width&&this.height&&!this._constraining){this._constraining=!0;var e,r,n,i,a=-90,o=90,s=-180,l=180,c=this.size,u=this._unmodified;if(this.latRange){var h=this.latRange;a=t.mercatorYfromLat(h[1])*this.worldSize,e=(o=t.mercatorYfromLat(h[0])*this.worldSize)-a<c.y?c.y/(o-a):0}if(this.lngRange){var f=this.lngRange;s=t.mercatorXfromLng(f[0])*this.worldSize,r=(l=t.mercatorXfromLng(f[1])*this.worldSize)-s<c.x?c.x/(l-s):0}var p=this.point,d=Math.max(r||0,e||0);if(d)return this.center=this.unproject(new t.Point(r?(l+s)/2:p.x,e?(o+a)/2:p.y)),this.zoom+=this.scaleZoom(d),this._unmodified=u,void(this._constraining=!1);if(this.latRange){var g=p.y,v=c.y/2;g-v<a&&(i=a+v),g+v>o&&(i=o-v)}if(this.lngRange){var m=p.x,y=c.x/2;m-y<s&&(n=s+y),m+y>l&&(n=l-y)}void 0===n&&void 0===i||(this.center=this.unproject(new t.Point(void 0!==n?n:p.x,void 0!==i?i:p.y))),this._unmodified=u,this._constraining=!1}},sn.prototype._calcMatrices=function(){if(this.height){this.cameraToCenterDistance=.5/Math.tan(this._fov/2)*this.height;var e=this._fov/2,r=Math.PI/2+this._pitch,n=Math.sin(e)*this.cameraToCenterDistance/Math.sin(Math.PI-r-e),i=this.point,a=i.x,o=i.y,s=1.01*(Math.cos(Math.PI/2-this._pitch)*n+this.cameraToCenterDistance),l=new Float64Array(16);t.perspective(l,this._fov,this.width/this.height,1,s),t.scale(l,l,[1,-1,1]),t.translate(l,l,[0,0,-this.cameraToCenterDistance]),t.rotateX(l,l,this._pitch),t.rotateZ(l,l,this.angle),t.translate(l,l,[-a,-o,0]),this.mercatorMatrix=t.scale([],l,[this.worldSize,this.worldSize,this.worldSize]),t.scale(l,l,[1,1,t.mercatorZfromAltitude(1,this.center.lat)*this.worldSize,1]),this.projMatrix=l;var c=this.width%2/2,u=this.height%2/2,h=Math.cos(this.angle),f=Math.sin(this.angle),p=a-Math.round(a)+h*c+f*u,d=o-Math.round(o)+h*u+f*c,g=new Float64Array(l);if(t.translate(g,g,[p>.5?p-1:p,d>.5?d-1:d,0]),this.alignedProjMatrix=g,l=t.create(),t.scale(l,l,[this.width/2,-this.height/2,1]),t.translate(l,l,[1,-1,0]),this.labelPlaneMatrix=l,l=t.create(),t.scale(l,l,[1,-1,1]),t.translate(l,l,[-1,-1,0]),t.scale(l,l,[2/this.width,2/this.height,1]),this.glCoordMatrix=l,this.pixelMatrix=t.multiply(new Float64Array(16),this.labelPlaneMatrix,this.projMatrix),!(l=t.invert(new Float64Array(16),this.pixelMatrix)))throw new Error(\"failed to invert matrix\");this.pixelMatrixInverse=l,this._posMatrixCache={},this._alignedPosMatrixCache={}}},sn.prototype.maxPitchScaleFactor=function(){if(!this.pixelMatrixInverse)return 1;var e=this.pointCoordinate(new t.Point(0,0)),r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix)[3]/this.cameraToCenterDistance},sn.prototype.getCameraPoint=function(){var e=this._pitch,r=Math.tan(e)*(this.cameraToCenterDistance||1);return this.centerPoint.add(new t.Point(0,r))},sn.prototype.getCameraQueryGeometry=function(e){var r=this.getCameraPoint();if(1===e.length)return[e[0],r];for(var n=r.x,i=r.y,a=r.x,o=r.y,s=0,l=e;s<l.length;s+=1){var c=l[s];n=Math.min(n,c.x),i=Math.min(i,c.y),a=Math.max(a,c.x),o=Math.max(o,c.y)}return[new t.Point(n,i),new t.Point(a,i),new t.Point(a,o),new t.Point(n,o),new t.Point(n,i)]},Object.defineProperties(sn.prototype,ln);var cn=function(){var e,r,n,i;t.bindAll([\"_onHashChange\",\"_updateHash\"],this),this._updateHash=(e=this._updateHashUnthrottled.bind(this),300,r=!1,n=null,i=function(){n=null,r&&(e(),n=setTimeout(i,300),r=!1)},function(){return r=!0,n||i(),n})};cn.prototype.addTo=function(e){return this._map=e,t.window.addEventListener(\"hashchange\",this._onHashChange,!1),this._map.on(\"moveend\",this._updateHash),this},cn.prototype.remove=function(){return t.window.removeEventListener(\"hashchange\",this._onHashChange,!1),this._map.off(\"moveend\",this._updateHash),clearTimeout(this._updateHash()),delete this._map,this},cn.prototype.getHashString=function(t){var e=this._map.getCenter(),r=Math.round(100*this._map.getZoom())/100,n=Math.ceil((r*Math.LN2+Math.log(512/360/.5))/Math.LN10),i=Math.pow(10,n),a=Math.round(e.lng*i)/i,o=Math.round(e.lat*i)/i,s=this._map.getBearing(),l=this._map.getPitch(),c=\"\";return c+=t?\"#/\"+a+\"/\"+o+\"/\"+r:\"#\"+r+\"/\"+o+\"/\"+a,(s||l)&&(c+=\"/\"+Math.round(10*s)/10),l&&(c+=\"/\"+Math.round(l)),c},cn.prototype._onHashChange=function(){var e=t.window.location.hash.replace(\"#\",\"\").split(\"/\");return e.length>=3&&(this._map.jumpTo({center:[+e[2],+e[1]],zoom:+e[0],bearing:+(e[3]||0),pitch:+(e[4]||0)}),!0)},cn.prototype._updateHashUnthrottled=function(){var e=this.getHashString();try{t.window.history.replaceState(t.window.history.state,\"\",e)}catch(t){}};var un=function(e){function n(n,i,a,o){void 0===o&&(o={});var s=r.mousePos(i.getCanvasContainer(),a),l=i.unproject(s);e.call(this,n,t.extend({point:s,lngLat:l,originalEvent:a},o)),this._defaultPrevented=!1,this.target=i}e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),hn=function(e){function n(n,i,a){var o=r.touchPos(i.getCanvasContainer(),a),s=o.map(function(t){return i.unproject(t)}),l=o.reduce(function(t,e,r,n){return t.add(e.div(n.length))},new t.Point(0,0)),c=i.unproject(l);e.call(this,n,{points:o,point:l,lngLats:s,lngLat:c,originalEvent:a}),this._defaultPrevented=!1}e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),fn=function(t){function e(e,r,n){t.call(this,e,{originalEvent:n}),this._defaultPrevented=!1}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={defaultPrevented:{configurable:!0}};return e.prototype.preventDefault=function(){this._defaultPrevented=!0},r.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(e.prototype,r),e}(t.Event),pn=function(e){this._map=e,this._el=e.getCanvasContainer(),this._delta=0,this._defaultZoomRate=.01,this._wheelZoomRate=1/450,t.bindAll([\"_onWheel\",\"_onTimeout\",\"_onScrollFrame\",\"_onScrollFinished\"],this)};pn.prototype.setZoomRate=function(t){this._defaultZoomRate=t},pn.prototype.setWheelZoomRate=function(t){this._wheelZoomRate=t},pn.prototype.isEnabled=function(){return!!this._enabled},pn.prototype.isActive=function(){return!!this._active},pn.prototype.isZooming=function(){return!!this._zooming},pn.prototype.enable=function(t){this.isEnabled()||(this._enabled=!0,this._aroundCenter=t&&\"center\"===t.around)},pn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},pn.prototype.onWheel=function(e){if(this.isEnabled()){var r=e.deltaMode===t.window.WheelEvent.DOM_DELTA_LINE?40*e.deltaY:e.deltaY,n=t.browser.now(),i=n-(this._lastWheelEventTime||0);this._lastWheelEventTime=n,0!==r&&r%4.000244140625==0?this._type=\"wheel\":0!==r&&Math.abs(r)<4?this._type=\"trackpad\":i>400?(this._type=null,this._lastValue=r,this._timeout=setTimeout(this._onTimeout,40,e)):this._type||(this._type=Math.abs(i*r)<200?\"trackpad\":\"wheel\",this._timeout&&(clearTimeout(this._timeout),this._timeout=null,r+=this._lastValue)),e.shiftKey&&r&&(r/=4),this._type&&(this._lastWheelEvent=e,this._delta-=r,this.isActive()||this._start(e)),e.preventDefault()}},pn.prototype._onTimeout=function(t){this._type=\"wheel\",this._delta-=this._lastValue,this.isActive()||this._start(t)},pn.prototype._start=function(e){if(this._delta){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),this._active=!0,this.isZooming()||(this._zooming=!0,this._map.fire(new t.Event(\"movestart\",{originalEvent:e})),this._map.fire(new t.Event(\"zoomstart\",{originalEvent:e}))),this._finishTimeout&&clearTimeout(this._finishTimeout);var n=r.mousePos(this._el,e);this._around=t.LngLat.convert(this._aroundCenter?this._map.getCenter():this._map.unproject(n)),this._aroundPoint=this._map.transform.locationPoint(this._around),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onScrollFrame))}},pn.prototype._onScrollFrame=function(){var e=this;if(this._frameId=null,this.isActive()){var r=this._map.transform;if(0!==this._delta){var n=\"wheel\"===this._type&&Math.abs(this._delta)>4.000244140625?this._wheelZoomRate:this._defaultZoomRate,i=2/(1+Math.exp(-Math.abs(this._delta*n)));this._delta<0&&0!==i&&(i=1/i);var a=\"number\"==typeof this._targetZoom?r.zoomScale(this._targetZoom):r.scale;this._targetZoom=Math.min(r.maxZoom,Math.max(r.minZoom,r.scaleZoom(a*i))),\"wheel\"===this._type&&(this._startZoom=r.zoom,this._easing=this._smoothOutEasing(200)),this._delta=0}var o=\"number\"==typeof this._targetZoom?this._targetZoom:r.zoom,s=this._startZoom,l=this._easing,c=!1;if(\"wheel\"===this._type&&s&&l){var u=Math.min((t.browser.now()-this._lastWheelEventTime)/200,1),h=l(u);r.zoom=t.number(s,o,h),u<1?this._frameId||(this._frameId=this._map._requestRenderFrame(this._onScrollFrame)):c=!0}else r.zoom=o,c=!0;r.setLocationAtPoint(this._around,this._aroundPoint),this._map.fire(new t.Event(\"move\",{originalEvent:this._lastWheelEvent})),this._map.fire(new t.Event(\"zoom\",{originalEvent:this._lastWheelEvent})),c&&(this._active=!1,this._finishTimeout=setTimeout(function(){e._zooming=!1,e._map.fire(new t.Event(\"zoomend\",{originalEvent:e._lastWheelEvent})),e._map.fire(new t.Event(\"moveend\",{originalEvent:e._lastWheelEvent})),delete e._targetZoom},200))}},pn.prototype._smoothOutEasing=function(e){var r=t.ease;if(this._prevEase){var n=this._prevEase,i=(t.browser.now()-n.start)/n.duration,a=n.easing(i+.01)-n.easing(i),o=.27/Math.sqrt(a*a+1e-4)*.01,s=Math.sqrt(.0729-o*o);r=t.bezier(o,s,.25,1)}return this._prevEase={start:t.browser.now(),duration:e,easing:r},r};var dn=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._container=e.getContainer(),this._clickTolerance=r.clickTolerance||1,t.bindAll([\"_onMouseMove\",\"_onMouseUp\",\"_onKeyDown\"],this)};dn.prototype.isEnabled=function(){return!!this._enabled},dn.prototype.isActive=function(){return!!this._active},dn.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},dn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},dn.prototype.onMouseDown=function(e){this.isEnabled()&&e.shiftKey&&0===e.button&&(t.window.document.addEventListener(\"mousemove\",this._onMouseMove,!1),t.window.document.addEventListener(\"keydown\",this._onKeyDown,!1),t.window.document.addEventListener(\"mouseup\",this._onMouseUp,!1),r.disableDrag(),this._startPos=this._lastPos=r.mousePos(this._el,e),this._active=!0)},dn.prototype._onMouseMove=function(t){var e=r.mousePos(this._el,t);if(!(this._lastPos.equals(e)||!this._box&&e.dist(this._startPos)<this._clickTolerance)){var n=this._startPos;this._lastPos=e,this._box||(this._box=r.create(\"div\",\"mapboxgl-boxzoom\",this._container),this._container.classList.add(\"mapboxgl-crosshair\"),this._fireEvent(\"boxzoomstart\",t));var i=Math.min(n.x,e.x),a=Math.max(n.x,e.x),o=Math.min(n.y,e.y),s=Math.max(n.y,e.y);r.setTransform(this._box,\"translate(\"+i+\"px,\"+o+\"px)\"),this._box.style.width=a-i+\"px\",this._box.style.height=s-o+\"px\"}},dn.prototype._onMouseUp=function(e){if(0===e.button){var n=this._startPos,i=r.mousePos(this._el,e);this._finish(),r.suppressClick(),n.x===i.x&&n.y===i.y?this._fireEvent(\"boxzoomcancel\",e):this._map.fitScreenCoordinates(n,i,this._map.getBearing(),{linear:!0}).fire(new t.Event(\"boxzoomend\",{originalEvent:e}))}},dn.prototype._onKeyDown=function(t){27===t.keyCode&&(this._finish(),this._fireEvent(\"boxzoomcancel\",t))},dn.prototype._finish=function(){this._active=!1,t.window.document.removeEventListener(\"mousemove\",this._onMouseMove,!1),t.window.document.removeEventListener(\"keydown\",this._onKeyDown,!1),t.window.document.removeEventListener(\"mouseup\",this._onMouseUp,!1),this._container.classList.remove(\"mapboxgl-crosshair\"),this._box&&(r.remove(this._box),this._box=null),r.enableDrag(),delete this._startPos,delete this._lastPos},dn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,{originalEvent:r}))};var gn=t.bezier(0,0,.25,1),vn=function(e,r){this._map=e,this._el=r.element||e.getCanvasContainer(),this._state=\"disabled\",this._button=r.button||\"right\",this._bearingSnap=r.bearingSnap||0,this._pitchWithRotate=!1!==r.pitchWithRotate,t.bindAll([\"onMouseDown\",\"_onMouseMove\",\"_onMouseUp\",\"_onBlur\",\"_onDragFrame\"],this)};vn.prototype.isEnabled=function(){return\"disabled\"!==this._state},vn.prototype.isActive=function(){return\"active\"===this._state},vn.prototype.enable=function(){this.isEnabled()||(this._state=\"enabled\")},vn.prototype.disable=function(){if(this.isEnabled())switch(this._state){case\"active\":this._state=\"disabled\",this._unbind(),this._deactivate(),this._fireEvent(\"rotateend\"),this._pitchWithRotate&&this._fireEvent(\"pitchend\"),this._fireEvent(\"moveend\");break;case\"pending\":this._state=\"disabled\",this._unbind();break;default:this._state=\"disabled\"}},vn.prototype.onMouseDown=function(e){if(\"enabled\"===this._state){if(\"right\"===this._button){if(this._eventButton=r.mouseButton(e),this._eventButton!==(e.ctrlKey?0:2))return}else{if(e.ctrlKey||0!==r.mouseButton(e))return;this._eventButton=0}r.disableDrag(),t.window.document.addEventListener(\"mousemove\",this._onMouseMove,{capture:!0}),t.window.document.addEventListener(\"mouseup\",this._onMouseUp),t.window.addEventListener(\"blur\",this._onBlur),this._state=\"pending\",this._inertia=[[t.browser.now(),this._map.getBearing()]],this._startPos=this._lastPos=r.mousePos(this._el,e),this._center=this._map.transform.centerPoint,e.preventDefault()}},vn.prototype._onMouseMove=function(t){var e=r.mousePos(this._el,t);this._lastPos.equals(e)||(this._lastMoveEvent=t,this._lastPos=e,\"pending\"===this._state&&(this._state=\"active\",this._fireEvent(\"rotatestart\",t),this._fireEvent(\"movestart\",t),this._pitchWithRotate&&this._fireEvent(\"pitchstart\",t)),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onDragFrame)))},vn.prototype._onDragFrame=function(){this._frameId=null;var e=this._lastMoveEvent;if(e){var r=this._map.transform,n=this._startPos,i=this._lastPos,a=.8*(n.x-i.x),o=-.5*(n.y-i.y),s=r.bearing-a,l=r.pitch-o,c=this._inertia,u=c[c.length-1];this._drainInertiaBuffer(),c.push([t.browser.now(),this._map._normalizeBearing(s,u[1])]),r.bearing=s,this._pitchWithRotate&&(this._fireEvent(\"pitch\",e),r.pitch=l),this._fireEvent(\"rotate\",e),this._fireEvent(\"move\",e),delete this._lastMoveEvent,this._startPos=this._lastPos}},vn.prototype._onMouseUp=function(t){if(r.mouseButton(t)===this._eventButton)switch(this._state){case\"active\":this._state=\"enabled\",r.suppressClick(),this._unbind(),this._deactivate(),this._inertialRotate(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},vn.prototype._onBlur=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._fireEvent(\"rotateend\",t),this._pitchWithRotate&&this._fireEvent(\"pitchend\",t),this._fireEvent(\"moveend\",t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},vn.prototype._unbind=function(){t.window.document.removeEventListener(\"mousemove\",this._onMouseMove,{capture:!0}),t.window.document.removeEventListener(\"mouseup\",this._onMouseUp),t.window.removeEventListener(\"blur\",this._onBlur),r.enableDrag()},vn.prototype._deactivate=function(){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._lastMoveEvent,delete this._startPos,delete this._lastPos},vn.prototype._inertialRotate=function(t){var e=this;this._fireEvent(\"rotateend\",t),this._drainInertiaBuffer();var r=this._map,n=r.getBearing(),i=this._inertia,a=function(){Math.abs(n)<e._bearingSnap?r.resetNorth({noMoveStart:!0},{originalEvent:t}):e._fireEvent(\"moveend\",t),e._pitchWithRotate&&e._fireEvent(\"pitchend\",t)};if(i.length<2)a();else{var o=i[0],s=i[i.length-1],l=i[i.length-2],c=r._normalizeBearing(n,l[1]),u=s[1]-o[1],h=u<0?-1:1,f=(s[0]-o[0])/1e3;if(0!==u&&0!==f){var p=Math.abs(u*(.25/f));p>180&&(p=180);var d=p/180;c+=h*p*(d/2),Math.abs(r._normalizeBearing(c,0))<this._bearingSnap&&(c=r._normalizeBearing(0,c)),r.rotateTo(c,{duration:1e3*d,easing:gn,noMoveStart:!0},{originalEvent:t})}else a()}},vn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},vn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>0&&r-e[0][0]>160;)e.shift()};var mn=t.bezier(0,0,.3,1),yn=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._state=\"disabled\",this._clickTolerance=r.clickTolerance||1,t.bindAll([\"_onMove\",\"_onMouseUp\",\"_onTouchEnd\",\"_onBlur\",\"_onDragFrame\"],this)};yn.prototype.isEnabled=function(){return\"disabled\"!==this._state},yn.prototype.isActive=function(){return\"active\"===this._state},yn.prototype.enable=function(){this.isEnabled()||(this._el.classList.add(\"mapboxgl-touch-drag-pan\"),this._state=\"enabled\")},yn.prototype.disable=function(){if(this.isEnabled())switch(this._el.classList.remove(\"mapboxgl-touch-drag-pan\"),this._state){case\"active\":this._state=\"disabled\",this._unbind(),this._deactivate(),this._fireEvent(\"dragend\"),this._fireEvent(\"moveend\");break;case\"pending\":this._state=\"disabled\",this._unbind();break;default:this._state=\"disabled\"}},yn.prototype.onMouseDown=function(e){\"enabled\"===this._state&&(e.ctrlKey||0!==r.mouseButton(e)||(r.addEventListener(t.window.document,\"mousemove\",this._onMove,{capture:!0}),r.addEventListener(t.window.document,\"mouseup\",this._onMouseUp),this._start(e)))},yn.prototype.onTouchStart=function(e){\"enabled\"===this._state&&(e.touches.length>1||(r.addEventListener(t.window.document,\"touchmove\",this._onMove,{capture:!0,passive:!1}),r.addEventListener(t.window.document,\"touchend\",this._onTouchEnd),this._start(e)))},yn.prototype._start=function(e){t.window.addEventListener(\"blur\",this._onBlur),this._state=\"pending\",this._startPos=this._mouseDownPos=this._lastPos=r.mousePos(this._el,e),this._inertia=[[t.browser.now(),this._startPos]]},yn.prototype._onMove=function(e){e.preventDefault();var n=r.mousePos(this._el,e);this._lastPos.equals(n)||\"pending\"===this._state&&n.dist(this._mouseDownPos)<this._clickTolerance||(this._lastMoveEvent=e,this._lastPos=n,this._drainInertiaBuffer(),this._inertia.push([t.browser.now(),this._lastPos]),\"pending\"===this._state&&(this._state=\"active\",this._fireEvent(\"dragstart\",e),this._fireEvent(\"movestart\",e)),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onDragFrame)))},yn.prototype._onDragFrame=function(){this._frameId=null;var t=this._lastMoveEvent;if(t){var e=this._map.transform;e.setLocationAtPoint(e.pointLocation(this._startPos),this._lastPos),this._fireEvent(\"drag\",t),this._fireEvent(\"move\",t),this._startPos=this._lastPos,delete this._lastMoveEvent}},yn.prototype._onMouseUp=function(t){if(0===r.mouseButton(t))switch(this._state){case\"active\":this._state=\"enabled\",r.suppressClick(),this._unbind(),this._deactivate(),this._inertialPan(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},yn.prototype._onTouchEnd=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._inertialPan(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},yn.prototype._onBlur=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._fireEvent(\"dragend\",t),this._fireEvent(\"moveend\",t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},yn.prototype._unbind=function(){r.removeEventListener(t.window.document,\"touchmove\",this._onMove,{capture:!0,passive:!1}),r.removeEventListener(t.window.document,\"touchend\",this._onTouchEnd),r.removeEventListener(t.window.document,\"mousemove\",this._onMove,{capture:!0}),r.removeEventListener(t.window.document,\"mouseup\",this._onMouseUp),r.removeEventListener(t.window,\"blur\",this._onBlur)},yn.prototype._deactivate=function(){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._lastMoveEvent,delete this._startPos,delete this._mouseDownPos,delete this._lastPos},yn.prototype._inertialPan=function(t){this._fireEvent(\"dragend\",t),this._drainInertiaBuffer();var e=this._inertia;if(e.length<2)this._fireEvent(\"moveend\",t);else{var r=e[e.length-1],n=e[0],i=r[1].sub(n[1]),a=(r[0]-n[0])/1e3;if(0===a||r[1].equals(n[1]))this._fireEvent(\"moveend\",t);else{var o=i.mult(.3/a),s=o.mag();s>1400&&(s=1400,o._unit()._mult(s));var l=s/750,c=o.mult(-l/2);this._map.panBy(c,{duration:1e3*l,easing:mn,noMoveStart:!0},{originalEvent:t})}}},yn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},yn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>0&&r-e[0][0]>160;)e.shift()};var xn=function(e){this._map=e,this._el=e.getCanvasContainer(),t.bindAll([\"_onKeyDown\"],this)};function bn(t){return t*(2-t)}xn.prototype.isEnabled=function(){return!!this._enabled},xn.prototype.enable=function(){this.isEnabled()||(this._el.addEventListener(\"keydown\",this._onKeyDown,!1),this._enabled=!0)},xn.prototype.disable=function(){this.isEnabled()&&(this._el.removeEventListener(\"keydown\",this._onKeyDown),this._enabled=!1)},xn.prototype._onKeyDown=function(t){if(!(t.altKey||t.ctrlKey||t.metaKey)){var e=0,r=0,n=0,i=0,a=0;switch(t.keyCode){case 61:case 107:case 171:case 187:e=1;break;case 189:case 109:case 173:e=-1;break;case 37:t.shiftKey?r=-1:(t.preventDefault(),i=-1);break;case 39:t.shiftKey?r=1:(t.preventDefault(),i=1);break;case 38:t.shiftKey?n=1:(t.preventDefault(),a=-1);break;case 40:t.shiftKey?n=-1:(a=1,t.preventDefault());break;default:return}var o=this._map,s=o.getZoom(),l={duration:300,delayEndEvents:500,easing:bn,zoom:e?Math.round(s)+e*(t.shiftKey?2:1):s,bearing:o.getBearing()+15*r,pitch:o.getPitch()+10*n,offset:[100*-i,100*-a],center:o.getCenter()};o.easeTo(l,{originalEvent:t})}};var _n=function(e){this._map=e,t.bindAll([\"_onDblClick\",\"_onZoomEnd\"],this)};_n.prototype.isEnabled=function(){return!!this._enabled},_n.prototype.isActive=function(){return!!this._active},_n.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},_n.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},_n.prototype.onTouchStart=function(t){var e=this;if(this.isEnabled()&&!(t.points.length>1))if(this._tapped){var r=t.points[0],n=this._tappedPoint;if(n&&n.dist(r)<=30){t.originalEvent.preventDefault();var i=function(){e._tapped&&e._zoom(t),e._map.off(\"touchcancel\",a),e._resetTapped()},a=function(){e._map.off(\"touchend\",i),e._resetTapped()};this._map.once(\"touchend\",i),this._map.once(\"touchcancel\",a)}else this._resetTapped()}else this._tappedPoint=t.points[0],this._tapped=setTimeout(function(){e._tapped=null,e._tappedPoint=null},300)},_n.prototype._resetTapped=function(){clearTimeout(this._tapped),this._tapped=null,this._tappedPoint=null},_n.prototype.onDblClick=function(t){this.isEnabled()&&(t.originalEvent.preventDefault(),this._zoom(t))},_n.prototype._zoom=function(t){this._active=!0,this._map.on(\"zoomend\",this._onZoomEnd),this._map.zoomTo(this._map.getZoom()+(t.originalEvent.shiftKey?-1:1),{around:t.lngLat},t)},_n.prototype._onZoomEnd=function(){this._active=!1,this._map.off(\"zoomend\",this._onZoomEnd)};var wn=t.bezier(0,0,.15,1),kn=function(e){this._map=e,this._el=e.getCanvasContainer(),t.bindAll([\"_onMove\",\"_onEnd\",\"_onTouchFrame\"],this)};kn.prototype.isEnabled=function(){return!!this._enabled},kn.prototype.enable=function(t){this.isEnabled()||(this._el.classList.add(\"mapboxgl-touch-zoom-rotate\"),this._enabled=!0,this._aroundCenter=!!t&&\"center\"===t.around)},kn.prototype.disable=function(){this.isEnabled()&&(this._el.classList.remove(\"mapboxgl-touch-zoom-rotate\"),this._enabled=!1)},kn.prototype.disableRotation=function(){this._rotationDisabled=!0},kn.prototype.enableRotation=function(){this._rotationDisabled=!1},kn.prototype.onStart=function(e){if(this.isEnabled()&&2===e.touches.length){var n=r.mousePos(this._el,e.touches[0]),i=r.mousePos(this._el,e.touches[1]),a=n.add(i).div(2);this._startVec=n.sub(i),this._startAround=this._map.transform.pointLocation(a),this._gestureIntent=void 0,this._inertia=[],r.addEventListener(t.window.document,\"touchmove\",this._onMove,{passive:!1}),r.addEventListener(t.window.document,\"touchend\",this._onEnd)}},kn.prototype._getTouchEventData=function(t){var e=r.mousePos(this._el,t.touches[0]),n=r.mousePos(this._el,t.touches[1]),i=e.sub(n);return{vec:i,center:e.add(n).div(2),scale:i.mag()/this._startVec.mag(),bearing:this._rotationDisabled?0:180*i.angleWith(this._startVec)/Math.PI}},kn.prototype._onMove=function(e){if(2===e.touches.length){var r=this._getTouchEventData(e),n=r.vec,i=r.scale,a=r.bearing;if(!this._gestureIntent){var o=this._rotationDisabled&&1!==i||Math.abs(1-i)>.15;Math.abs(a)>10?this._gestureIntent=\"rotate\":o&&(this._gestureIntent=\"zoom\"),this._gestureIntent&&(this._map.fire(new t.Event(this._gestureIntent+\"start\",{originalEvent:e})),this._map.fire(new t.Event(\"movestart\",{originalEvent:e})),this._startVec=n)}this._lastTouchEvent=e,this._frameId||(this._frameId=this._map._requestRenderFrame(this._onTouchFrame)),e.preventDefault()}},kn.prototype._onTouchFrame=function(){this._frameId=null;var e=this._gestureIntent;if(e){var r=this._map.transform;this._startScale||(this._startScale=r.scale,this._startBearing=r.bearing);var n=this._getTouchEventData(this._lastTouchEvent),i=n.center,a=n.bearing,o=n.scale,s=r.pointLocation(i),l=r.locationPoint(s);\"rotate\"===e&&(r.bearing=this._startBearing+a),r.zoom=r.scaleZoom(this._startScale*o),r.setLocationAtPoint(this._startAround,l),this._map.fire(new t.Event(e,{originalEvent:this._lastTouchEvent})),this._map.fire(new t.Event(\"move\",{originalEvent:this._lastTouchEvent})),this._drainInertiaBuffer(),this._inertia.push([t.browser.now(),o,i])}},kn.prototype._onEnd=function(e){r.removeEventListener(t.window.document,\"touchmove\",this._onMove,{passive:!1}),r.removeEventListener(t.window.document,\"touchend\",this._onEnd);var n=this._gestureIntent,i=this._startScale;if(this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._gestureIntent,delete this._startScale,delete this._startBearing,delete this._lastTouchEvent,n){this._map.fire(new t.Event(n+\"end\",{originalEvent:e})),this._drainInertiaBuffer();var a=this._inertia,o=this._map;if(a.length<2)o.snapToNorth({},{originalEvent:e});else{var s=a[a.length-1],l=a[0],c=o.transform.scaleZoom(i*s[1]),u=o.transform.scaleZoom(i*l[1]),h=c-u,f=(s[0]-l[0])/1e3,p=s[2];if(0!==f&&c!==u){var d=.15*h/f;Math.abs(d)>2.5&&(d=d>0?2.5:-2.5);var g=1e3*Math.abs(d/(12*.15)),v=c+d*g/2e3;v<0&&(v=0),o.easeTo({zoom:v,duration:g,easing:wn,around:this._aroundCenter?o.getCenter():o.unproject(p),noMoveStart:!0},{originalEvent:e})}else o.snapToNorth({},{originalEvent:e})}}},kn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>2&&r-e[0][0]>160;)e.shift()};var Tn={scrollZoom:pn,boxZoom:dn,dragRotate:vn,dragPan:yn,keyboard:xn,doubleClickZoom:_n,touchZoomRotate:kn},An=function(e){function r(r,n){e.call(this),this._moving=!1,this._zooming=!1,this.transform=r,this._bearingSnap=n.bearingSnap,t.bindAll([\"_renderFrameCallback\"],this)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getCenter=function(){return new t.LngLat(this.transform.center.lng,this.transform.center.lat)},r.prototype.setCenter=function(t,e){return this.jumpTo({center:t},e)},r.prototype.panBy=function(e,r,n){return e=t.Point.convert(e).mult(-1),this.panTo(this.transform.center,t.extend({offset:e},r),n)},r.prototype.panTo=function(e,r,n){return this.easeTo(t.extend({center:e},r),n)},r.prototype.getZoom=function(){return this.transform.zoom},r.prototype.setZoom=function(t,e){return this.jumpTo({zoom:t},e),this},r.prototype.zoomTo=function(e,r,n){return this.easeTo(t.extend({zoom:e},r),n)},r.prototype.zoomIn=function(t,e){return this.zoomTo(this.getZoom()+1,t,e),this},r.prototype.zoomOut=function(t,e){return this.zoomTo(this.getZoom()-1,t,e),this},r.prototype.getBearing=function(){return this.transform.bearing},r.prototype.setBearing=function(t,e){return this.jumpTo({bearing:t},e),this},r.prototype.rotateTo=function(e,r,n){return this.easeTo(t.extend({bearing:e},r),n)},r.prototype.resetNorth=function(e,r){return this.rotateTo(0,t.extend({duration:1e3},e),r),this},r.prototype.snapToNorth=function(t,e){return Math.abs(this.getBearing())<this._bearingSnap?this.resetNorth(t,e):this},r.prototype.getPitch=function(){return this.transform.pitch},r.prototype.setPitch=function(t,e){return this.jumpTo({pitch:t},e),this},r.prototype.cameraForBounds=function(e,r){return e=t.LngLatBounds.convert(e),this._cameraForBoxAndBearing(e.getNorthWest(),e.getSouthEast(),0,r)},r.prototype._cameraForBoxAndBearing=function(e,r,n,i){if(\"number\"==typeof(i=t.extend({padding:{top:0,bottom:0,right:0,left:0},offset:[0,0],maxZoom:this.transform.maxZoom},i)).padding){var a=i.padding;i.padding={top:a,bottom:a,right:a,left:a}}if(t.deepEqual(Object.keys(i.padding).sort(function(t,e){return t<e?-1:t>e?1:0}),[\"bottom\",\"left\",\"right\",\"top\"])){var o=this.transform,s=o.project(t.LngLat.convert(e)),l=o.project(t.LngLat.convert(r)),c=s.rotate(-n*Math.PI/180),u=l.rotate(-n*Math.PI/180),h=new t.Point(Math.max(c.x,u.x),Math.max(c.y,u.y)),f=new t.Point(Math.min(c.x,u.x),Math.min(c.y,u.y)),p=h.sub(f),d=(o.width-i.padding.left-i.padding.right)/p.x,g=(o.height-i.padding.top-i.padding.bottom)/p.y;if(!(g<0||d<0)){var v=Math.min(o.scaleZoom(o.scale*Math.min(d,g)),i.maxZoom),m=t.Point.convert(i.offset),y=(i.padding.left-i.padding.right)/2,x=(i.padding.top-i.padding.bottom)/2,b=new t.Point(m.x+y,m.y+x).mult(o.scale/o.zoomScale(v));return{center:o.unproject(s.add(l).div(2).sub(b)),zoom:v,bearing:n}}t.warnOnce(\"Map cannot fit within canvas with the given bounds, padding, and/or offset.\")}else t.warnOnce(\"options.padding must be a positive number, or an Object with keys 'bottom', 'left', 'right', 'top'\")},r.prototype.fitBounds=function(t,e,r){return this._fitInternal(this.cameraForBounds(t,e),e,r)},r.prototype.fitScreenCoordinates=function(e,r,n,i,a){return this._fitInternal(this._cameraForBoxAndBearing(this.transform.pointLocation(t.Point.convert(e)),this.transform.pointLocation(t.Point.convert(r)),n,i),i,a)},r.prototype._fitInternal=function(e,r,n){return e?(r=t.extend(e,r)).linear?this.easeTo(r,n):this.flyTo(r,n):this},r.prototype.jumpTo=function(e,r){this.stop();var n=this.transform,i=!1,a=!1,o=!1;return\"zoom\"in e&&n.zoom!==+e.zoom&&(i=!0,n.zoom=+e.zoom),void 0!==e.center&&(n.center=t.LngLat.convert(e.center)),\"bearing\"in e&&n.bearing!==+e.bearing&&(a=!0,n.bearing=+e.bearing),\"pitch\"in e&&n.pitch!==+e.pitch&&(o=!0,n.pitch=+e.pitch),this.fire(new t.Event(\"movestart\",r)).fire(new t.Event(\"move\",r)),i&&this.fire(new t.Event(\"zoomstart\",r)).fire(new t.Event(\"zoom\",r)).fire(new t.Event(\"zoomend\",r)),a&&this.fire(new t.Event(\"rotatestart\",r)).fire(new t.Event(\"rotate\",r)).fire(new t.Event(\"rotateend\",r)),o&&this.fire(new t.Event(\"pitchstart\",r)).fire(new t.Event(\"pitch\",r)).fire(new t.Event(\"pitchend\",r)),this.fire(new t.Event(\"moveend\",r))},r.prototype.easeTo=function(e,r){var n=this;this.stop(),!1===(e=t.extend({offset:[0,0],duration:500,easing:t.ease},e)).animate&&(e.duration=0);var i=this.transform,a=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=\"zoom\"in e?+e.zoom:a,c=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,u=\"pitch\"in e?+e.pitch:s,h=i.centerPoint.add(t.Point.convert(e.offset)),f=i.pointLocation(h),p=t.LngLat.convert(e.center||f);this._normalizeCenter(p);var d,g,v=i.project(f),m=i.project(p).sub(v),y=i.zoomScale(l-a);return e.around&&(d=t.LngLat.convert(e.around),g=i.locationPoint(d)),this._zooming=l!==a,this._rotating=o!==c,this._pitching=u!==s,this._prepareEase(r,e.noMoveStart),clearTimeout(this._easeEndTimeoutID),this._ease(function(e){if(n._zooming&&(i.zoom=t.number(a,l,e)),n._rotating&&(i.bearing=t.number(o,c,e)),n._pitching&&(i.pitch=t.number(s,u,e)),d)i.setLocationAtPoint(d,g);else{var f=i.zoomScale(i.zoom-a),p=l>a?Math.min(2,y):Math.max(.5,y),x=Math.pow(p,1-e),b=i.unproject(v.add(m.mult(e*x)).mult(f));i.setLocationAtPoint(i.renderWorldCopies?b.wrap():b,h)}n._fireMoveEvents(r)},function(){e.delayEndEvents?n._easeEndTimeoutID=setTimeout(function(){return n._afterEase(r)},e.delayEndEvents):n._afterEase(r)},e),this},r.prototype._prepareEase=function(e,r){this._moving=!0,r||this.fire(new t.Event(\"movestart\",e)),this._zooming&&this.fire(new t.Event(\"zoomstart\",e)),this._rotating&&this.fire(new t.Event(\"rotatestart\",e)),this._pitching&&this.fire(new t.Event(\"pitchstart\",e))},r.prototype._fireMoveEvents=function(e){this.fire(new t.Event(\"move\",e)),this._zooming&&this.fire(new t.Event(\"zoom\",e)),this._rotating&&this.fire(new t.Event(\"rotate\",e)),this._pitching&&this.fire(new t.Event(\"pitch\",e))},r.prototype._afterEase=function(e){var r=this._zooming,n=this._rotating,i=this._pitching;this._moving=!1,this._zooming=!1,this._rotating=!1,this._pitching=!1,r&&this.fire(new t.Event(\"zoomend\",e)),n&&this.fire(new t.Event(\"rotateend\",e)),i&&this.fire(new t.Event(\"pitchend\",e)),this.fire(new t.Event(\"moveend\",e))},r.prototype.flyTo=function(e,r){var n=this;this.stop(),e=t.extend({offset:[0,0],speed:1.2,curve:1.42,easing:t.ease},e);var i=this.transform,a=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=\"zoom\"in e?t.clamp(+e.zoom,i.minZoom,i.maxZoom):a,c=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,u=\"pitch\"in e?+e.pitch:s,h=i.zoomScale(l-a),f=i.centerPoint.add(t.Point.convert(e.offset)),p=i.pointLocation(f),d=t.LngLat.convert(e.center||p);this._normalizeCenter(d);var g=i.project(p),v=i.project(d).sub(g),m=e.curve,y=Math.max(i.width,i.height),x=y/h,b=v.mag();if(\"minZoom\"in e){var _=t.clamp(Math.min(e.minZoom,a,l),i.minZoom,i.maxZoom),w=y/i.zoomScale(_-a);m=Math.sqrt(w/b*2)}var k=m*m;function T(t){var e=(x*x-y*y+(t?-1:1)*k*k*b*b)/(2*(t?x:y)*k*b);return Math.log(Math.sqrt(e*e+1)-e)}function A(t){return(Math.exp(t)-Math.exp(-t))/2}function M(t){return(Math.exp(t)+Math.exp(-t))/2}var S=T(0),E=function(t){return M(S)/M(S+m*t)},C=function(t){return y*((M(S)*(A(e=S+m*t)/M(e))-A(S))/k)/b;var e},L=(T(1)-S)/m;if(Math.abs(b)<1e-6||!isFinite(L)){if(Math.abs(y-x)<1e-6)return this.easeTo(e,r);var P=x<y?-1:1;L=Math.abs(Math.log(x/y))/m,C=function(){return 0},E=function(t){return Math.exp(P*m*t)}}if(\"duration\"in e)e.duration=+e.duration;else{var O=\"screenSpeed\"in e?+e.screenSpeed/m:+e.speed;e.duration=1e3*L/O}return e.maxDuration&&e.duration>e.maxDuration&&(e.duration=0),this._zooming=!0,this._rotating=o!==c,this._pitching=u!==s,this._prepareEase(r,!1),this._ease(function(e){var h=e*L,p=1/E(h);i.zoom=1===e?l:a+i.scaleZoom(p),n._rotating&&(i.bearing=t.number(o,c,e)),n._pitching&&(i.pitch=t.number(s,u,e));var m=1===e?d:i.unproject(g.add(v.mult(C(h))).mult(p));i.setLocationAtPoint(i.renderWorldCopies?m.wrap():m,f),n._fireMoveEvents(r)},function(){return n._afterEase(r)},e),this},r.prototype.isEasing=function(){return!!this._easeFrameId},r.prototype.stop=function(){if(this._easeFrameId&&(this._cancelRenderFrame(this._easeFrameId),delete this._easeFrameId,delete this._onEaseFrame),this._onEaseEnd){var t=this._onEaseEnd;delete this._onEaseEnd,t.call(this)}return this},r.prototype._ease=function(e,r,n){!1===n.animate||0===n.duration?(e(1),r()):(this._easeStart=t.browser.now(),this._easeOptions=n,this._onEaseFrame=e,this._onEaseEnd=r,this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback))},r.prototype._renderFrameCallback=function(){var e=Math.min((t.browser.now()-this._easeStart)/this._easeOptions.duration,1);this._onEaseFrame(this._easeOptions.easing(e)),e<1?this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback):this.stop()},r.prototype._normalizeBearing=function(e,r){e=t.wrap(e,-180,180);var n=Math.abs(e-r);return Math.abs(e-360-r)<n&&(e-=360),Math.abs(e+360-r)<n&&(e+=360),e},r.prototype._normalizeCenter=function(t){var e=this.transform;if(e.renderWorldCopies&&!e.lngRange){var r=t.lng-e.center.lng;t.lng+=r>180?-360:r<-180?360:0}},r}(t.Evented),Mn=function(e){void 0===e&&(e={}),this.options=e,t.bindAll([\"_updateEditLink\",\"_updateData\",\"_updateCompact\"],this)};Mn.prototype.getDefaultPosition=function(){return\"bottom-right\"},Mn.prototype.onAdd=function(t){var e=this.options&&this.options.compact;return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-attrib\"),this._innerContainer=r.create(\"div\",\"mapboxgl-ctrl-attrib-inner\",this._container),e&&this._container.classList.add(\"mapboxgl-compact\"),this._updateAttributions(),this._updateEditLink(),this._map.on(\"styledata\",this._updateData),this._map.on(\"sourcedata\",this._updateData),this._map.on(\"moveend\",this._updateEditLink),void 0===e&&(this._map.on(\"resize\",this._updateCompact),this._updateCompact()),this._container},Mn.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"styledata\",this._updateData),this._map.off(\"sourcedata\",this._updateData),this._map.off(\"moveend\",this._updateEditLink),this._map.off(\"resize\",this._updateCompact),this._map=void 0},Mn.prototype._updateEditLink=function(){var e=this._editLink;e||(e=this._editLink=this._container.querySelector(\".mapbox-improve-map\"));var r=[{key:\"owner\",value:this.styleOwner},{key:\"id\",value:this.styleId},{key:\"access_token\",value:t.config.ACCESS_TOKEN}];if(e){var n=r.reduce(function(t,e,n){return e.value&&(t+=e.key+\"=\"+e.value+(n<r.length-1?\"&\":\"\")),t},\"?\");e.href=t.config.FEEDBACK_URL+\"/\"+n+(this._map._hash?this._map._hash.getHashString(!0):\"\"),e.rel=\"noopener nofollow\"}},Mn.prototype._updateData=function(t){!t||\"metadata\"!==t.sourceDataType&&\"style\"!==t.dataType||(this._updateAttributions(),this._updateEditLink())},Mn.prototype._updateAttributions=function(){if(this._map.style){var t=[];if(this.options.customAttribution&&(Array.isArray(this.options.customAttribution)?t=t.concat(this.options.customAttribution.map(function(t){return\"string\"!=typeof t?\"\":t})):\"string\"==typeof this.options.customAttribution&&t.push(this.options.customAttribution)),this._map.style.stylesheet){var e=this._map.style.stylesheet;this.styleOwner=e.owner,this.styleId=e.id}var r=this._map.style.sourceCaches;for(var n in r){var i=r[n];if(i.used){var a=i.getSource();a.attribution&&t.indexOf(a.attribution)<0&&t.push(a.attribution)}}t.sort(function(t,e){return t.length-e.length});var o=(t=t.filter(function(e,r){for(var n=r+1;n<t.length;n++)if(t[n].indexOf(e)>=0)return!1;return!0})).join(\" | \");o!==this._attribHTML&&(this._attribHTML=o,t.length?(this._innerContainer.innerHTML=o,this._container.classList.remove(\"mapboxgl-attrib-empty\")):this._container.classList.add(\"mapboxgl-attrib-empty\"),this._editLink=null)}},Mn.prototype._updateCompact=function(){this._map.getCanvasContainer().offsetWidth<=640?this._container.classList.add(\"mapboxgl-compact\"):this._container.classList.remove(\"mapboxgl-compact\")};var Sn=function(){t.bindAll([\"_updateLogo\"],this),t.bindAll([\"_updateCompact\"],this)};Sn.prototype.onAdd=function(t){this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl\");var e=r.create(\"a\",\"mapboxgl-ctrl-logo\");return e.target=\"_blank\",e.rel=\"noopener nofollow\",e.href=\"https://www.mapbox.com/\",e.setAttribute(\"aria-label\",\"Mapbox logo\"),e.setAttribute(\"rel\",\"noopener nofollow\"),this._container.appendChild(e),this._container.style.display=\"none\",this._map.on(\"sourcedata\",this._updateLogo),this._updateLogo(),this._map.on(\"resize\",this._updateCompact),this._updateCompact(),this._container},Sn.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"sourcedata\",this._updateLogo),this._map.off(\"resize\",this._updateCompact)},Sn.prototype.getDefaultPosition=function(){return\"bottom-left\"},Sn.prototype._updateLogo=function(t){t&&\"metadata\"!==t.sourceDataType||(this._container.style.display=this._logoRequired()?\"block\":\"none\")},Sn.prototype._logoRequired=function(){if(this._map.style){var t=this._map.style.sourceCaches;for(var e in t)if(t[e].getSource().mapbox_logo)return!0;return!1}},Sn.prototype._updateCompact=function(){var t=this._container.children;if(t.length){var e=t[0];this._map.getCanvasContainer().offsetWidth<250?e.classList.add(\"mapboxgl-compact\"):e.classList.remove(\"mapboxgl-compact\")}};var En=function(){this._queue=[],this._id=0,this._cleared=!1,this._currentlyRunning=!1};En.prototype.add=function(t){var e=++this._id;return this._queue.push({callback:t,id:e,cancelled:!1}),e},En.prototype.remove=function(t){for(var e=this._currentlyRunning,r=0,n=e?this._queue.concat(e):this._queue;r<n.length;r+=1){var i=n[r];if(i.id===t)return void(i.cancelled=!0)}},En.prototype.run=function(){var t=this._currentlyRunning=this._queue;this._queue=[];for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!n.cancelled&&(n.callback(),this._cleared))break}this._cleared=!1,this._currentlyRunning=!1},En.prototype.clear=function(){this._currentlyRunning&&(this._cleared=!0),this._queue=[]};var Cn=t.window.HTMLImageElement,Ln=t.window.HTMLElement,Pn={center:[0,0],zoom:0,bearing:0,pitch:0,minZoom:0,maxZoom:22,interactive:!0,scrollZoom:!0,boxZoom:!0,dragRotate:!0,dragPan:!0,keyboard:!0,doubleClickZoom:!0,touchZoomRotate:!0,bearingSnap:7,clickTolerance:3,hash:!1,attributionControl:!0,failIfMajorPerformanceCaveat:!1,preserveDrawingBuffer:!1,trackResize:!0,renderWorldCopies:!0,refreshExpiredTiles:!0,maxTileCacheSize:null,localIdeographFontFamily:\"sans-serif\",transformRequest:null,fadeDuration:300,crossSourceCollisions:!0},On=function(n){function i(e){var i=this;if(null!=(e=t.extend({},Pn,e)).minZoom&&null!=e.maxZoom&&e.minZoom>e.maxZoom)throw new Error(\"maxZoom must be greater than minZoom\");var a=new sn(e.minZoom,e.maxZoom,e.renderWorldCopies);if(n.call(this,a,e),this._interactive=e.interactive,this._maxTileCacheSize=e.maxTileCacheSize,this._failIfMajorPerformanceCaveat=e.failIfMajorPerformanceCaveat,this._preserveDrawingBuffer=e.preserveDrawingBuffer,this._antialias=e.antialias,this._trackResize=e.trackResize,this._bearingSnap=e.bearingSnap,this._refreshExpiredTiles=e.refreshExpiredTiles,this._fadeDuration=e.fadeDuration,this._crossSourceCollisions=e.crossSourceCollisions,this._crossFadingFactor=1,this._collectResourceTiming=e.collectResourceTiming,this._renderTaskQueue=new En,this._controls=[],this._mapId=t.uniqueId(),this._requestManager=new t.RequestManager(e.transformRequest),\"string\"==typeof e.container){if(this._container=t.window.document.getElementById(e.container),!this._container)throw new Error(\"Container '\"+e.container+\"' not found.\")}else{if(!(e.container instanceof Ln))throw new Error(\"Invalid type: 'container' must be a String or HTMLElement.\");this._container=e.container}if(e.maxBounds&&this.setMaxBounds(e.maxBounds),t.bindAll([\"_onWindowOnline\",\"_onWindowResize\",\"_contextLost\",\"_contextRestored\"],this),this._setupContainer(),this._setupPainter(),void 0===this.painter)throw new Error(\"Failed to initialize WebGL.\");this.on(\"move\",function(){return i._update(!1)}),this.on(\"moveend\",function(){return i._update(!1)}),this.on(\"zoom\",function(){return i._update(!0)}),void 0!==t.window&&(t.window.addEventListener(\"online\",this._onWindowOnline,!1),t.window.addEventListener(\"resize\",this._onWindowResize,!1)),function(t,e){var n=t.getCanvasContainer(),i=null,a=!1,o=null;for(var s in Tn)t[s]=new Tn[s](t,e),e.interactive&&e[s]&&t[s].enable(e[s]);r.addEventListener(n,\"mouseout\",function(e){t.fire(new un(\"mouseout\",t,e))}),r.addEventListener(n,\"mousedown\",function(i){a=!0,o=r.mousePos(n,i);var s=new un(\"mousedown\",t,i);t.fire(s),s.defaultPrevented||(e.interactive&&!t.doubleClickZoom.isActive()&&t.stop(),t.boxZoom.onMouseDown(i),t.boxZoom.isActive()||t.dragPan.isActive()||t.dragRotate.onMouseDown(i),t.boxZoom.isActive()||t.dragRotate.isActive()||t.dragPan.onMouseDown(i))}),r.addEventListener(n,\"mouseup\",function(e){var r=t.dragRotate.isActive();i&&!r&&t.fire(new un(\"contextmenu\",t,i)),i=null,a=!1,t.fire(new un(\"mouseup\",t,e))}),r.addEventListener(n,\"mousemove\",function(e){if(!t.dragPan.isActive()&&!t.dragRotate.isActive()){for(var r=e.target;r&&r!==n;)r=r.parentNode;r===n&&t.fire(new un(\"mousemove\",t,e))}}),r.addEventListener(n,\"mouseover\",function(e){for(var r=e.target;r&&r!==n;)r=r.parentNode;r===n&&t.fire(new un(\"mouseover\",t,e))}),r.addEventListener(n,\"touchstart\",function(r){var n=new hn(\"touchstart\",t,r);t.fire(n),n.defaultPrevented||(e.interactive&&t.stop(),t.boxZoom.isActive()||t.dragRotate.isActive()||t.dragPan.onTouchStart(r),t.touchZoomRotate.onStart(r),t.doubleClickZoom.onTouchStart(n))},{passive:!1}),r.addEventListener(n,\"touchmove\",function(e){t.fire(new hn(\"touchmove\",t,e))},{passive:!1}),r.addEventListener(n,\"touchend\",function(e){t.fire(new hn(\"touchend\",t,e))}),r.addEventListener(n,\"touchcancel\",function(e){t.fire(new hn(\"touchcancel\",t,e))}),r.addEventListener(n,\"click\",function(i){var a=r.mousePos(n,i);(a.equals(o)||a.dist(o)<e.clickTolerance)&&t.fire(new un(\"click\",t,i))}),r.addEventListener(n,\"dblclick\",function(e){var r=new un(\"dblclick\",t,e);t.fire(r),r.defaultPrevented||t.doubleClickZoom.onDblClick(r)}),r.addEventListener(n,\"contextmenu\",function(e){var r=t.dragRotate.isActive();a||r?a&&(i=e):t.fire(new un(\"contextmenu\",t,e)),(t.dragRotate.isEnabled()||t.listens(\"contextmenu\"))&&e.preventDefault()}),r.addEventListener(n,\"wheel\",function(r){e.interactive&&t.stop();var n=new fn(\"wheel\",t,r);t.fire(n),n.defaultPrevented||t.scrollZoom.onWheel(r)},{passive:!1})}(this,e),this._hash=e.hash&&(new cn).addTo(this),this._hash&&this._hash._onHashChange()||(this.jumpTo({center:e.center,zoom:e.zoom,bearing:e.bearing,pitch:e.pitch}),e.bounds&&(this.resize(),this.fitBounds(e.bounds,t.extend({},e.fitBoundsOptions,{duration:0})))),this.resize(),this._localIdeographFontFamily=e.localIdeographFontFamily,e.style&&this.setStyle(e.style,{localIdeographFontFamily:e.localIdeographFontFamily}),e.attributionControl&&this.addControl(new Mn({customAttribution:e.customAttribution})),this.addControl(new Sn,e.logoPosition),this.on(\"style.load\",function(){i.transform.unmodified&&i.jumpTo(i.style.stylesheet)}),this.on(\"data\",function(e){i._update(\"style\"===e.dataType),i.fire(new t.Event(e.dataType+\"data\",e))}),this.on(\"dataloading\",function(e){i.fire(new t.Event(e.dataType+\"dataloading\",e))})}n&&(i.__proto__=n),i.prototype=Object.create(n&&n.prototype),i.prototype.constructor=i;var a={showTileBoundaries:{configurable:!0},showCollisionBoxes:{configurable:!0},showOverdrawInspector:{configurable:!0},repaint:{configurable:!0},vertices:{configurable:!0}};return i.prototype._getMapId=function(){return this._mapId},i.prototype.addControl=function(e,r){if(void 0===r&&e.getDefaultPosition&&(r=e.getDefaultPosition()),void 0===r&&(r=\"top-right\"),!e||!e.onAdd)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.addControl(). Argument must be a control with onAdd and onRemove methods.\")));var n=e.onAdd(this);this._controls.push(e);var i=this._controlPositions[r];return-1!==r.indexOf(\"bottom\")?i.insertBefore(n,i.firstChild):i.appendChild(n),this},i.prototype.removeControl=function(e){if(!e||!e.onRemove)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.removeControl(). Argument must be a control with onAdd and onRemove methods.\")));var r=this._controls.indexOf(e);return r>-1&&this._controls.splice(r,1),e.onRemove(this),this},i.prototype.resize=function(e){var r=this._containerDimensions(),n=r[0],i=r[1];return this._resizeCanvas(n,i),this.transform.resize(n,i),this.painter.resize(n,i),this.fire(new t.Event(\"movestart\",e)).fire(new t.Event(\"move\",e)).fire(new t.Event(\"resize\",e)).fire(new t.Event(\"moveend\",e)),this},i.prototype.getBounds=function(){return this.transform.getBounds()},i.prototype.getMaxBounds=function(){return this.transform.getMaxBounds()},i.prototype.setMaxBounds=function(e){return this.transform.setMaxBounds(t.LngLatBounds.convert(e)),this._update()},i.prototype.setMinZoom=function(t){if((t=null==t?0:t)>=0&&t<=this.transform.maxZoom)return this.transform.minZoom=t,this._update(),this.getZoom()<t&&this.setZoom(t),this;throw new Error(\"minZoom must be between 0 and the current maxZoom, inclusive\")},i.prototype.getMinZoom=function(){return this.transform.minZoom},i.prototype.setMaxZoom=function(t){if((t=null==t?22:t)>=this.transform.minZoom)return this.transform.maxZoom=t,this._update(),this.getZoom()>t&&this.setZoom(t),this;throw new Error(\"maxZoom must be greater than the current minZoom\")},i.prototype.getRenderWorldCopies=function(){return this.transform.renderWorldCopies},i.prototype.setRenderWorldCopies=function(t){return this.transform.renderWorldCopies=t,this._update()},i.prototype.getMaxZoom=function(){return this.transform.maxZoom},i.prototype.project=function(e){return this.transform.locationPoint(t.LngLat.convert(e))},i.prototype.unproject=function(e){return this.transform.pointLocation(t.Point.convert(e))},i.prototype.isMoving=function(){return this._moving||this.dragPan.isActive()||this.dragRotate.isActive()||this.scrollZoom.isActive()},i.prototype.isZooming=function(){return this._zooming||this.scrollZoom.isZooming()},i.prototype.isRotating=function(){return this._rotating||this.dragRotate.isActive()},i.prototype.on=function(t,e,r){var i=this;if(void 0===r)return n.prototype.on.call(this,t,e);var a=function(){var n;if(\"mouseenter\"===t||\"mouseover\"===t){var a=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){var o=i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[];o.length?a||(a=!0,r.call(i,new un(t,i,n.originalEvent,{features:o}))):a=!1},mouseout:function(){a=!1}}}}if(\"mouseleave\"===t||\"mouseout\"===t){var o=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){(i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[]).length?o=!0:o&&(o=!1,r.call(i,new un(t,i,n.originalEvent)))},mouseout:function(e){o&&(o=!1,r.call(i,new un(t,i,e.originalEvent)))}}}}return{layer:e,listener:r,delegates:(n={},n[t]=function(t){var n=i.getLayer(e)?i.queryRenderedFeatures(t.point,{layers:[e]}):[];n.length&&(t.features=n,r.call(i,t),delete t.features)},n)}}();for(var o in this._delegatedListeners=this._delegatedListeners||{},this._delegatedListeners[t]=this._delegatedListeners[t]||[],this._delegatedListeners[t].push(a),a.delegates)this.on(o,a.delegates[o]);return this},i.prototype.off=function(t,e,r){if(void 0===r)return n.prototype.off.call(this,t,e);if(this._delegatedListeners&&this._delegatedListeners[t])for(var i=this._delegatedListeners[t],a=0;a<i.length;a++){var o=i[a];if(o.layer===e&&o.listener===r){for(var s in o.delegates)this.off(s,o.delegates[s]);return i.splice(a,1),this}}return this},i.prototype.queryRenderedFeatures=function(e,r){if(!this.style)return[];var n;if(void 0!==r||void 0===e||e instanceof t.Point||Array.isArray(e)||(r=e,e=void 0),r=r||{},(e=e||[[0,0],[this.transform.width,this.transform.height]])instanceof t.Point||\"number\"==typeof e[0])n=[t.Point.convert(e)];else{var i=t.Point.convert(e[0]),a=t.Point.convert(e[1]);n=[i,new t.Point(a.x,i.y),a,new t.Point(i.x,a.y),i]}return this.style.queryRenderedFeatures(n,r,this.transform)},i.prototype.querySourceFeatures=function(t,e){return this.style.querySourceFeatures(t,e)},i.prototype.setStyle=function(e,r){return!1!==(r=t.extend({},{localIdeographFontFamily:Pn.localIdeographFontFamily},r)).diff&&r.localIdeographFontFamily===this._localIdeographFontFamily&&this.style&&e?(this._diffStyle(e,r),this):(this._localIdeographFontFamily=r.localIdeographFontFamily,this._updateStyle(e,r))},i.prototype._updateStyle=function(t,e){return this.style&&(this.style.setEventedParent(null),this.style._remove()),t?(this.style=new De(this,e||{}),this.style.setEventedParent(this,{style:this.style}),\"string\"==typeof t?this.style.loadURL(t):this.style.loadJSON(t),this):(delete this.style,this)},i.prototype._diffStyle=function(e,r){var n=this;if(\"string\"==typeof e){var i=this._requestManager.normalizeStyleURL(e),a=this._requestManager.transformRequest(i,t.ResourceType.Style);t.getJSON(a,function(e,i){e?n.fire(new t.ErrorEvent(e)):i&&n._updateDiff(i,r)})}else\"object\"==typeof e&&this._updateDiff(e,r)},i.prototype._updateDiff=function(e,r){try{this.style.setState(e)&&this._update(!0)}catch(n){t.warnOnce(\"Unable to perform style diff: \"+(n.message||n.error||n)+\".  Rebuilding the style from scratch.\"),this._updateStyle(e,r)}},i.prototype.getStyle=function(){if(this.style)return this.style.serialize()},i.prototype.isStyleLoaded=function(){return this.style?this.style.loaded():t.warnOnce(\"There is no style added to the map.\")},i.prototype.addSource=function(t,e){return this.style.addSource(t,e),this._update(!0)},i.prototype.isSourceLoaded=function(e){var r=this.style&&this.style.sourceCaches[e];if(void 0!==r)return r.loaded();this.fire(new t.ErrorEvent(new Error(\"There is no source with ID '\"+e+\"'\")))},i.prototype.areTilesLoaded=function(){var t=this.style&&this.style.sourceCaches;for(var e in t){var r=t[e]._tiles;for(var n in r){var i=r[n];if(\"loaded\"!==i.state&&\"errored\"!==i.state)return!1}}return!0},i.prototype.addSourceType=function(t,e,r){return this.style.addSourceType(t,e,r)},i.prototype.removeSource=function(t){return this.style.removeSource(t),this._update(!0)},i.prototype.getSource=function(t){return this.style.getSource(t)},i.prototype.addImage=function(e,r,n){void 0===n&&(n={});var i=n.pixelRatio;void 0===i&&(i=1);var a=n.sdf;if(void 0===a&&(a=!1),r instanceof Cn){var o=t.browser.getImageData(r),s=o.width,l=o.height,c=o.data;this.style.addImage(e,{data:new t.RGBAImage({width:s,height:l},c),pixelRatio:i,sdf:a,version:0})}else{if(void 0===r.width||void 0===r.height)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.addImage(). The second argument must be an `HTMLImageElement`, `ImageData`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));var u=r.width,h=r.height,f=r.data,p=r;this.style.addImage(e,{data:new t.RGBAImage({width:u,height:h},new Uint8Array(f)),pixelRatio:i,sdf:a,version:0,userImage:p}),p.onAdd&&p.onAdd(this,e)}},i.prototype.updateImage=function(e,r){var n=this.style.getImage(e);if(!n)return this.fire(new t.ErrorEvent(new Error(\"The map has no image with that id. If you are adding a new image use `map.addImage(...)` instead.\")));var i=r instanceof Cn?t.browser.getImageData(r):r,a=i.width,o=i.height,s=i.data;if(void 0===a||void 0===o)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.updateImage(). The second argument must be an `HTMLImageElement`, `ImageData`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));if(a!==n.data.width||o!==n.data.height)return this.fire(new t.ErrorEvent(new Error(\"The width and height of the updated image must be that same as the previous version of the image\")));var l=!(r instanceof Cn);n.data.replace(s,l),this.style.updateImage(e,n)},i.prototype.hasImage=function(e){return e?!!this.style.getImage(e):(this.fire(new t.ErrorEvent(new Error(\"Missing required image id\"))),!1)},i.prototype.removeImage=function(t){this.style.removeImage(t)},i.prototype.loadImage=function(e,r){t.getImage(this._requestManager.transformRequest(e,t.ResourceType.Image),r)},i.prototype.listImages=function(){return this.style.listImages()},i.prototype.addLayer=function(t,e){return this.style.addLayer(t,e),this._update(!0)},i.prototype.moveLayer=function(t,e){return this.style.moveLayer(t,e),this._update(!0)},i.prototype.removeLayer=function(t){return this.style.removeLayer(t),this._update(!0)},i.prototype.getLayer=function(t){return this.style.getLayer(t)},i.prototype.setFilter=function(t,e,r){return void 0===r&&(r={}),this.style.setFilter(t,e,r),this._update(!0)},i.prototype.setLayerZoomRange=function(t,e,r){return this.style.setLayerZoomRange(t,e,r),this._update(!0)},i.prototype.getFilter=function(t){return this.style.getFilter(t)},i.prototype.setPaintProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setPaintProperty(t,e,r,n),this._update(!0)},i.prototype.getPaintProperty=function(t,e){return this.style.getPaintProperty(t,e)},i.prototype.setLayoutProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setLayoutProperty(t,e,r,n),this._update(!0)},i.prototype.getLayoutProperty=function(t,e){return this.style.getLayoutProperty(t,e)},i.prototype.setLight=function(t,e){return void 0===e&&(e={}),this.style.setLight(t,e),this._update(!0)},i.prototype.getLight=function(){return this.style.getLight()},i.prototype.setFeatureState=function(t,e){return this.style.setFeatureState(t,e),this._update()},i.prototype.removeFeatureState=function(t,e){return this.style.removeFeatureState(t,e),this._update()},i.prototype.getFeatureState=function(t){return this.style.getFeatureState(t)},i.prototype.getContainer=function(){return this._container},i.prototype.getCanvasContainer=function(){return this._canvasContainer},i.prototype.getCanvas=function(){return this._canvas},i.prototype._containerDimensions=function(){var t=0,e=0;return this._container&&(t=this._container.clientWidth||400,e=this._container.clientHeight||300),[t,e]},i.prototype._detectMissingCSS=function(){\"rgb(250, 128, 114)\"!==t.window.getComputedStyle(this._missingCSSCanary).getPropertyValue(\"background-color\")&&t.warnOnce(\"This page appears to be missing CSS declarations for Mapbox GL JS, which may cause the map to display incorrectly. Please ensure your page includes mapbox-gl.css, as described in https://www.mapbox.com/mapbox-gl-js/api/.\")},i.prototype._setupContainer=function(){var t=this._container;t.classList.add(\"mapboxgl-map\"),(this._missingCSSCanary=r.create(\"div\",\"mapboxgl-canary\",t)).style.visibility=\"hidden\",this._detectMissingCSS();var e=this._canvasContainer=r.create(\"div\",\"mapboxgl-canvas-container\",t);this._interactive&&e.classList.add(\"mapboxgl-interactive\"),this._canvas=r.create(\"canvas\",\"mapboxgl-canvas\",e),this._canvas.style.position=\"absolute\",this._canvas.addEventListener(\"webglcontextlost\",this._contextLost,!1),this._canvas.addEventListener(\"webglcontextrestored\",this._contextRestored,!1),this._canvas.setAttribute(\"tabindex\",\"0\"),this._canvas.setAttribute(\"aria-label\",\"Map\");var n=this._containerDimensions();this._resizeCanvas(n[0],n[1]);var i=this._controlContainer=r.create(\"div\",\"mapboxgl-control-container\",t),a=this._controlPositions={};[\"top-left\",\"top-right\",\"bottom-left\",\"bottom-right\"].forEach(function(t){a[t]=r.create(\"div\",\"mapboxgl-ctrl-\"+t,i)})},i.prototype._resizeCanvas=function(e,r){var n=t.window.devicePixelRatio||1;this._canvas.width=n*e,this._canvas.height=n*r,this._canvas.style.width=e+\"px\",this._canvas.style.height=r+\"px\"},i.prototype._setupPainter=function(){var r=t.extend({},e.webGLContextAttributes,{failIfMajorPerformanceCaveat:this._failIfMajorPerformanceCaveat,preserveDrawingBuffer:this._preserveDrawingBuffer,antialias:this._antialias||!1}),n=this._canvas.getContext(\"webgl\",r)||this._canvas.getContext(\"experimental-webgl\",r);n?(this.painter=new rn(n,this.transform),t.webpSupported.testSupport(n)):this.fire(new t.ErrorEvent(new Error(\"Failed to initialize WebGL\")))},i.prototype._contextLost=function(e){e.preventDefault(),this._frame&&(this._frame.cancel(),this._frame=null),this.fire(new t.Event(\"webglcontextlost\",{originalEvent:e}))},i.prototype._contextRestored=function(e){this._setupPainter(),this.resize(),this._update(),this.fire(new t.Event(\"webglcontextrestored\",{originalEvent:e}))},i.prototype.loaded=function(){return!this._styleDirty&&!this._sourcesDirty&&!!this.style&&this.style.loaded()},i.prototype._update=function(t){return this.style?(this._styleDirty=this._styleDirty||t,this._sourcesDirty=!0,this.triggerRepaint(),this):this},i.prototype._requestRenderFrame=function(t){return this._update(),this._renderTaskQueue.add(t)},i.prototype._cancelRenderFrame=function(t){this._renderTaskQueue.remove(t)},i.prototype._render=function(){this.painter.context.setDirty(),this.painter.setBaseState(),this._renderTaskQueue.run();var e=!1;if(this.style&&this._styleDirty){this._styleDirty=!1;var r=this.transform.zoom,n=t.browser.now();this.style.zoomHistory.update(r,n);var i=new t.EvaluationParameters(r,{now:n,fadeDuration:this._fadeDuration,zoomHistory:this.style.zoomHistory,transition:this.style.getTransition()}),a=i.crossFadingFactor();1===a&&a===this._crossFadingFactor||(e=!0,this._crossFadingFactor=a),this.style.update(i)}return this.style&&this._sourcesDirty&&(this._sourcesDirty=!1,this.style._updateSources(this.transform)),this._placementDirty=this.style&&this.style._updatePlacement(this.painter.transform,this.showCollisionBoxes,this._fadeDuration,this._crossSourceCollisions),this.painter.render(this.style,{showTileBoundaries:this.showTileBoundaries,showOverdrawInspector:this._showOverdrawInspector,rotating:this.isRotating(),zooming:this.isZooming(),moving:this.isMoving(),fadeDuration:this._fadeDuration}),this.fire(new t.Event(\"render\")),this.loaded()&&!this._loaded&&(this._loaded=!0,this.fire(new t.Event(\"load\"))),this.style&&(this.style.hasTransitions()||e)&&(this._styleDirty=!0),this.style&&!this._placementDirty&&this.style._releaseSymbolFadeTiles(),this._sourcesDirty||this._repaint||this._styleDirty||this._placementDirty?this.triggerRepaint():!this.isMoving()&&this.loaded()&&this.fire(new t.Event(\"idle\")),this},i.prototype.remove=function(){this._hash&&this._hash.remove();for(var e=0,r=this._controls;e<r.length;e+=1)r[e].onRemove(this);this._controls=[],this._frame&&(this._frame.cancel(),this._frame=null),this._renderTaskQueue.clear(),this.setStyle(null),void 0!==t.window&&(t.window.removeEventListener(\"resize\",this._onWindowResize,!1),t.window.removeEventListener(\"online\",this._onWindowOnline,!1));var n=this.painter.context.gl.getExtension(\"WEBGL_lose_context\");n&&n.loseContext(),zn(this._canvasContainer),zn(this._controlContainer),zn(this._missingCSSCanary),this._container.classList.remove(\"mapboxgl-map\"),this.fire(new t.Event(\"remove\"))},i.prototype.triggerRepaint=function(){var e=this;this.style&&!this._frame&&(this._frame=t.browser.frame(function(){e._frame=null,e._render()}))},i.prototype._onWindowOnline=function(){this._update()},i.prototype._onWindowResize=function(){this._trackResize&&this.resize()._update()},a.showTileBoundaries.get=function(){return!!this._showTileBoundaries},a.showTileBoundaries.set=function(t){this._showTileBoundaries!==t&&(this._showTileBoundaries=t,this._update())},a.showCollisionBoxes.get=function(){return!!this._showCollisionBoxes},a.showCollisionBoxes.set=function(t){this._showCollisionBoxes!==t&&(this._showCollisionBoxes=t,t?this.style._generateCollisionBoxes():this._update())},a.showOverdrawInspector.get=function(){return!!this._showOverdrawInspector},a.showOverdrawInspector.set=function(t){this._showOverdrawInspector!==t&&(this._showOverdrawInspector=t,this._update())},a.repaint.get=function(){return!!this._repaint},a.repaint.set=function(t){this._repaint!==t&&(this._repaint=t,this.triggerRepaint())},a.vertices.get=function(){return!!this._vertices},a.vertices.set=function(t){this._vertices=t,this._update()},i.prototype._setCacheLimits=function(e,r){t.setCacheLimits(e,r)},Object.defineProperties(i.prototype,a),i}(An);function zn(t){t.parentNode&&t.parentNode.removeChild(t)}var In={showCompass:!0,showZoom:!0},Dn=function(e){var n=this;this.options=t.extend({},In,e),this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),this._container.addEventListener(\"contextmenu\",function(t){return t.preventDefault()}),this.options.showZoom&&(t.bindAll([\"_updateZoomButtons\"],this),this._zoomInButton=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-zoom-in\",\"Zoom in\",function(){return n._map.zoomIn()}),this._zoomOutButton=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-zoom-out\",\"Zoom out\",function(){return n._map.zoomOut()})),this.options.showCompass&&(t.bindAll([\"_rotateCompassArrow\"],this),this._compass=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-compass\",\"Reset bearing to north\",function(){return n._map.resetNorth()}),this._compassArrow=r.create(\"span\",\"mapboxgl-ctrl-compass-arrow\",this._compass))};function Rn(e,r,n){if(e=new t.LngLat(e.lng,e.lat),r){var i=new t.LngLat(e.lng-360,e.lat),a=new t.LngLat(e.lng+360,e.lat),o=n.locationPoint(e).distSqr(r);n.locationPoint(i).distSqr(r)<o?e=i:n.locationPoint(a).distSqr(r)<o&&(e=a)}for(;Math.abs(e.lng-n.center.lng)>180;){var s=n.locationPoint(e);if(s.x>=0&&s.y>=0&&s.x<=n.width&&s.y<=n.height)break;e.lng>n.center.lng?e.lng-=360:e.lng+=360}return e}Dn.prototype._updateZoomButtons=function(){var t=this._map.getZoom();this._zoomInButton.classList.toggle(\"mapboxgl-ctrl-icon-disabled\",t===this._map.getMaxZoom()),this._zoomOutButton.classList.toggle(\"mapboxgl-ctrl-icon-disabled\",t===this._map.getMinZoom())},Dn.prototype._rotateCompassArrow=function(){var t=\"rotate(\"+this._map.transform.angle*(180/Math.PI)+\"deg)\";this._compassArrow.style.transform=t},Dn.prototype.onAdd=function(t){return this._map=t,this.options.showZoom&&(this._map.on(\"zoom\",this._updateZoomButtons),this._updateZoomButtons()),this.options.showCompass&&(this._map.on(\"rotate\",this._rotateCompassArrow),this._rotateCompassArrow(),this._handler=new vn(t,{button:\"left\",element:this._compass}),r.addEventListener(this._compass,\"mousedown\",this._handler.onMouseDown),this._handler.enable()),this._container},Dn.prototype.onRemove=function(){r.remove(this._container),this.options.showZoom&&this._map.off(\"zoom\",this._updateZoomButtons),this.options.showCompass&&(this._map.off(\"rotate\",this._rotateCompassArrow),r.removeEventListener(this._compass,\"mousedown\",this._handler.onMouseDown),this._handler.disable(),delete this._handler),delete this._map},Dn.prototype._createButton=function(t,e,n){var i=r.create(\"button\",t,this._container);return i.type=\"button\",i.title=e,i.setAttribute(\"aria-label\",e),i.addEventListener(\"click\",n),i};var Fn={center:\"translate(-50%,-50%)\",top:\"translate(-50%,0)\",\"top-left\":\"translate(0,0)\",\"top-right\":\"translate(-100%,0)\",bottom:\"translate(-50%,-100%)\",\"bottom-left\":\"translate(0,-100%)\",\"bottom-right\":\"translate(-100%,-100%)\",left:\"translate(0,-50%)\",right:\"translate(-100%,-50%)\"};function Bn(t,e,r){var n=t.classList;for(var i in Fn)n.remove(\"mapboxgl-\"+r+\"-anchor-\"+i);n.add(\"mapboxgl-\"+r+\"-anchor-\"+e)}var Nn,jn=function(e){function n(n,i){if(e.call(this),(n instanceof t.window.HTMLElement||i)&&(n=t.extend({element:n},i)),t.bindAll([\"_update\",\"_onMove\",\"_onUp\",\"_addDragHandler\",\"_onMapClick\"],this),this._anchor=n&&n.anchor||\"center\",this._color=n&&n.color||\"#3FB1CE\",this._draggable=n&&n.draggable||!1,this._state=\"inactive\",n&&n.element)this._element=n.element,this._offset=t.Point.convert(n&&n.offset||[0,0]);else{this._defaultMarker=!0,this._element=r.create(\"div\");var a=r.createNS(\"http://www.w3.org/2000/svg\",\"svg\");a.setAttributeNS(null,\"display\",\"block\"),a.setAttributeNS(null,\"height\",\"41px\"),a.setAttributeNS(null,\"width\",\"27px\"),a.setAttributeNS(null,\"viewBox\",\"0 0 27 41\");var o=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");o.setAttributeNS(null,\"stroke\",\"none\"),o.setAttributeNS(null,\"stroke-width\",\"1\"),o.setAttributeNS(null,\"fill\",\"none\"),o.setAttributeNS(null,\"fill-rule\",\"evenodd\");var s=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");s.setAttributeNS(null,\"fill-rule\",\"nonzero\");var l=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");l.setAttributeNS(null,\"transform\",\"translate(3.0, 29.0)\"),l.setAttributeNS(null,\"fill\",\"#000000\");for(var c=0,u=[{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"9.5\",ry:\"4.77275007\"},{rx:\"8.5\",ry:\"4.29549936\"},{rx:\"7.5\",ry:\"3.81822308\"},{rx:\"6.5\",ry:\"3.34094679\"},{rx:\"5.5\",ry:\"2.86367051\"},{rx:\"4.5\",ry:\"2.38636864\"}];c<u.length;c+=1){var h=u[c],f=r.createNS(\"http://www.w3.org/2000/svg\",\"ellipse\");f.setAttributeNS(null,\"opacity\",\"0.04\"),f.setAttributeNS(null,\"cx\",\"10.5\"),f.setAttributeNS(null,\"cy\",\"5.80029008\"),f.setAttributeNS(null,\"rx\",h.rx),f.setAttributeNS(null,\"ry\",h.ry),l.appendChild(f)}var p=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");p.setAttributeNS(null,\"fill\",this._color);var d=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");d.setAttributeNS(null,\"d\",\"M27,13.5 C27,19.074644 20.250001,27.000002 14.75,34.500002 C14.016665,35.500004 12.983335,35.500004 12.25,34.500002 C6.7499993,27.000002 0,19.222562 0,13.5 C0,6.0441559 6.0441559,0 13.5,0 C20.955844,0 27,6.0441559 27,13.5 Z\"),p.appendChild(d);var g=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");g.setAttributeNS(null,\"opacity\",\"0.25\"),g.setAttributeNS(null,\"fill\",\"#000000\");var v=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");v.setAttributeNS(null,\"d\",\"M13.5,0 C6.0441559,0 0,6.0441559 0,13.5 C0,19.222562 6.7499993,27 12.25,34.5 C13,35.522727 14.016664,35.500004 14.75,34.5 C20.250001,27 27,19.074644 27,13.5 C27,6.0441559 20.955844,0 13.5,0 Z M13.5,1 C20.415404,1 26,6.584596 26,13.5 C26,15.898657 24.495584,19.181431 22.220703,22.738281 C19.945823,26.295132 16.705119,30.142167 13.943359,33.908203 C13.743445,34.180814 13.612715,34.322738 13.5,34.441406 C13.387285,34.322738 13.256555,34.180814 13.056641,33.908203 C10.284481,30.127985 7.4148684,26.314159 5.015625,22.773438 C2.6163816,19.232715 1,15.953538 1,13.5 C1,6.584596 6.584596,1 13.5,1 Z\"),g.appendChild(v);var m=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");m.setAttributeNS(null,\"transform\",\"translate(6.0, 7.0)\"),m.setAttributeNS(null,\"fill\",\"#FFFFFF\");var y=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");y.setAttributeNS(null,\"transform\",\"translate(8.0, 8.0)\");var x=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");x.setAttributeNS(null,\"fill\",\"#000000\"),x.setAttributeNS(null,\"opacity\",\"0.25\"),x.setAttributeNS(null,\"cx\",\"5.5\"),x.setAttributeNS(null,\"cy\",\"5.5\"),x.setAttributeNS(null,\"r\",\"5.4999962\");var b=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");b.setAttributeNS(null,\"fill\",\"#FFFFFF\"),b.setAttributeNS(null,\"cx\",\"5.5\"),b.setAttributeNS(null,\"cy\",\"5.5\"),b.setAttributeNS(null,\"r\",\"5.4999962\"),y.appendChild(x),y.appendChild(b),s.appendChild(l),s.appendChild(p),s.appendChild(g),s.appendChild(m),s.appendChild(y),a.appendChild(s),this._element.appendChild(a),this._offset=t.Point.convert(n&&n.offset||[0,-14])}this._element.classList.add(\"mapboxgl-marker\"),this._element.addEventListener(\"dragstart\",function(t){t.preventDefault()}),Bn(this._element,this._anchor,\"marker\"),this._popup=null}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.addTo=function(t){return this.remove(),this._map=t,t.getCanvasContainer().appendChild(this._element),t.on(\"move\",this._update),t.on(\"moveend\",this._update),this.setDraggable(this._draggable),this._update(),this._map.on(\"click\",this._onMapClick),this},n.prototype.remove=function(){return this._map&&(this._map.off(\"click\",this._onMapClick),this._map.off(\"move\",this._update),this._map.off(\"moveend\",this._update),this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler),this._map.off(\"mouseup\",this._onUp),this._map.off(\"touchend\",this._onUp),delete this._map),r.remove(this._element),this._popup&&this._popup.remove(),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._popup&&this._popup.setLngLat(this._lngLat),this._update(),this},n.prototype.getElement=function(){return this._element},n.prototype.setPopup=function(t){if(this._popup&&(this._popup.remove(),this._popup=null),t){if(!(\"offset\"in t.options)){var e=Math.sqrt(Math.pow(13.5,2)/2);t.options.offset=this._defaultMarker?{top:[0,0],\"top-left\":[0,0],\"top-right\":[0,0],bottom:[0,-38.1],\"bottom-left\":[e,-1*(24.6+e)],\"bottom-right\":[-e,-1*(24.6+e)],left:[13.5,-24.6],right:[-13.5,-24.6]}:this._offset}this._popup=t,this._lngLat&&this._popup.setLngLat(this._lngLat)}return this},n.prototype._onMapClick=function(t){var e=t.originalEvent.target,r=this._element;this._popup&&(e===r||r.contains(e))&&this.togglePopup()},n.prototype.getPopup=function(){return this._popup},n.prototype.togglePopup=function(){var t=this._popup;return t?(t.isOpen()?t.remove():t.addTo(this._map),this):this},n.prototype._update=function(t){this._map&&(this._map.transform.renderWorldCopies&&(this._lngLat=Rn(this._lngLat,this._pos,this._map.transform)),this._pos=this._map.project(this._lngLat)._add(this._offset),t&&\"moveend\"!==t.type||(this._pos=this._pos.round()),r.setTransform(this._element,Fn[this._anchor]+\" translate(\"+this._pos.x+\"px, \"+this._pos.y+\"px)\"))},n.prototype.getOffset=function(){return this._offset},n.prototype.setOffset=function(e){return this._offset=t.Point.convert(e),this._update(),this},n.prototype._onMove=function(e){this._pos=e.point.sub(this._positionDelta),this._lngLat=this._map.unproject(this._pos),this.setLngLat(this._lngLat),this._element.style.pointerEvents=\"none\",\"pending\"===this._state&&(this._state=\"active\",this.fire(new t.Event(\"dragstart\"))),this.fire(new t.Event(\"drag\"))},n.prototype._onUp=function(){this._element.style.pointerEvents=\"auto\",this._positionDelta=null,this._map.off(\"mousemove\",this._onMove),this._map.off(\"touchmove\",this._onMove),\"active\"===this._state&&this.fire(new t.Event(\"dragend\")),this._state=\"inactive\"},n.prototype._addDragHandler=function(t){this._element.contains(t.originalEvent.target)&&(t.preventDefault(),this._positionDelta=t.point.sub(this._pos).add(this._offset),this._state=\"pending\",this._map.on(\"mousemove\",this._onMove),this._map.on(\"touchmove\",this._onMove),this._map.once(\"mouseup\",this._onUp),this._map.once(\"touchend\",this._onUp))},n.prototype.setDraggable=function(t){return this._draggable=!!t,this._map&&(t?(this._map.on(\"mousedown\",this._addDragHandler),this._map.on(\"touchstart\",this._addDragHandler)):(this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler))),this},n.prototype.isDraggable=function(){return this._draggable},n}(t.Evented),Un={positionOptions:{enableHighAccuracy:!1,maximumAge:0,timeout:6e3},fitBoundsOptions:{maxZoom:15},trackUserLocation:!1,showUserLocation:!0},Vn=function(e){function n(r){e.call(this),this.options=t.extend({},Un,r),t.bindAll([\"_onSuccess\",\"_onError\",\"_finish\",\"_setupUI\",\"_updateCamera\",\"_updateMarker\"],this)}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.onAdd=function(e){var n;return this._map=e,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),n=this._setupUI,void 0!==Nn?n(Nn):void 0!==t.window.navigator.permissions?t.window.navigator.permissions.query({name:\"geolocation\"}).then(function(t){Nn=\"denied\"!==t.state,n(Nn)}):(Nn=!!t.window.navigator.geolocation,n(Nn)),this._container},n.prototype.onRemove=function(){void 0!==this._geolocationWatchID&&(t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0),this.options.showUserLocation&&this._userLocationDotMarker&&this._userLocationDotMarker.remove(),r.remove(this._container),this._map=void 0},n.prototype._onSuccess=function(e){if(this.options.trackUserLocation)switch(this._lastKnownPosition=e,this._watchState){case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"BACKGROUND\":case\"BACKGROUND_ERROR\":this._watchState=\"BACKGROUND\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\")}this.options.showUserLocation&&\"OFF\"!==this._watchState&&this._updateMarker(e),this.options.trackUserLocation&&\"ACTIVE_LOCK\"!==this._watchState||this._updateCamera(e),this.options.showUserLocation&&this._dotElement.classList.remove(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"geolocate\",e)),this._finish()},n.prototype._updateCamera=function(e){var r=new t.LngLat(e.coords.longitude,e.coords.latitude),n=e.coords.accuracy,i=this._map.getBearing(),a=t.extend({bearing:i},this.options.fitBoundsOptions);this._map.fitBounds(r.toBounds(n),a,{geolocateSource:!0})},n.prototype._updateMarker=function(t){t?this._userLocationDotMarker.setLngLat([t.coords.longitude,t.coords.latitude]).addTo(this._map):this._userLocationDotMarker.remove()},n.prototype._onError=function(e){if(this.options.trackUserLocation)if(1===e.code)this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),void 0!==this._geolocationWatchID&&this._clearWatch();else switch(this._watchState){case\"WAITING_ACTIVE\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"ACTIVE_LOCK\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\");break;case\"BACKGROUND\":this._watchState=\"BACKGROUND_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\")}\"OFF\"!==this._watchState&&this.options.showUserLocation&&this._dotElement.classList.add(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"error\",e)),this._finish()},n.prototype._finish=function(){this._timeoutId&&clearTimeout(this._timeoutId),this._timeoutId=void 0},n.prototype._setupUI=function(e){var n=this;!1!==e?(this._container.addEventListener(\"contextmenu\",function(t){return t.preventDefault()}),this._geolocateButton=r.create(\"button\",\"mapboxgl-ctrl-icon mapboxgl-ctrl-geolocate\",this._container),this._geolocateButton.type=\"button\",this._geolocateButton.setAttribute(\"aria-label\",\"Geolocate\"),this.options.trackUserLocation&&(this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this._watchState=\"OFF\"),this.options.showUserLocation&&(this._dotElement=r.create(\"div\",\"mapboxgl-user-location-dot\"),this._userLocationDotMarker=new jn(this._dotElement),this.options.trackUserLocation&&(this._watchState=\"OFF\")),this._geolocateButton.addEventListener(\"click\",this.trigger.bind(this)),this._setup=!0,this.options.trackUserLocation&&this._map.on(\"movestart\",function(e){e.geolocateSource||\"ACTIVE_LOCK\"!==n._watchState||(n._watchState=\"BACKGROUND\",n._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\"),n._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),n.fire(new t.Event(\"trackuserlocationend\")))})):t.warnOnce(\"Geolocation support is not available, the GeolocateControl will not be visible.\")},n.prototype.trigger=function(){if(!this._setup)return t.warnOnce(\"Geolocate control triggered before added to a map\"),!1;if(this.options.trackUserLocation){switch(this._watchState){case\"OFF\":this._watchState=\"WAITING_ACTIVE\",this.fire(new t.Event(\"trackuserlocationstart\"));break;case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":case\"BACKGROUND_ERROR\":this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this.fire(new t.Event(\"trackuserlocationend\"));break;case\"BACKGROUND\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._lastKnownPosition&&this._updateCamera(this._lastKnownPosition),this.fire(new t.Event(\"trackuserlocationstart\"))}switch(this._watchState){case\"WAITING_ACTIVE\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_LOCK\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"BACKGROUND\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\");break;case\"BACKGROUND_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\")}\"OFF\"===this._watchState&&void 0!==this._geolocationWatchID?this._clearWatch():void 0===this._geolocationWatchID&&(this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"true\"),this._geolocationWatchID=t.window.navigator.geolocation.watchPosition(this._onSuccess,this._onError,this.options.positionOptions))}else t.window.navigator.geolocation.getCurrentPosition(this._onSuccess,this._onError,this.options.positionOptions),this._timeoutId=setTimeout(this._finish,1e4);return!0},n.prototype._clearWatch=function(){t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0,this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this.options.showUserLocation&&this._updateMarker(null)},n}(t.Evented),qn={maxWidth:100,unit:\"metric\"},Hn=function(e){this.options=t.extend({},qn,e),t.bindAll([\"_onMove\",\"setUnit\"],this)};function Gn(t,e,r){var n,i,a,o,s,l,c=r&&r.maxWidth||100,u=t._container.clientHeight/2,h=(n=t.unproject([0,u]),i=t.unproject([c,u]),a=Math.PI/180,o=n.lat*a,s=i.lat*a,l=Math.sin(o)*Math.sin(s)+Math.cos(o)*Math.cos(s)*Math.cos((i.lng-n.lng)*a),6371e3*Math.acos(Math.min(l,1)));if(r&&\"imperial\"===r.unit){var f=3.2808*h;f>5280?Yn(e,c,f/5280,\"mi\"):Yn(e,c,f,\"ft\")}else r&&\"nautical\"===r.unit?Yn(e,c,h/1852,\"nm\"):Yn(e,c,h,\"m\")}function Yn(t,e,r,n){var i,a,o,s=(i=r,(a=Math.pow(10,(\"\"+Math.floor(i)).length-1))*(o=(o=i/a)>=10?10:o>=5?5:o>=3?3:o>=2?2:o>=1?1:function(t){var e=Math.pow(10,Math.ceil(-Math.log(t)/Math.LN10));return Math.round(t*e)/e}(o))),l=s/r;\"m\"===n&&s>=1e3&&(s/=1e3,n=\"km\"),t.style.width=e*l+\"px\",t.innerHTML=s+n}Hn.prototype.getDefaultPosition=function(){return\"bottom-left\"},Hn.prototype._onMove=function(){Gn(this._map,this._container,this.options)},Hn.prototype.onAdd=function(t){return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-scale\",t.getContainer()),this._map.on(\"move\",this._onMove),this._onMove(),this._container},Hn.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"move\",this._onMove),this._map=void 0},Hn.prototype.setUnit=function(t){this.options.unit=t,Gn(this._map,this._container,this.options)};var Wn=function(e){this._fullscreen=!1,e&&e.container&&(e.container instanceof t.window.HTMLElement?this._container=e.container:t.warnOnce(\"Full screen control 'container' must be a DOM element.\")),t.bindAll([\"_onClickFullscreen\",\"_changeIcon\"],this),\"onfullscreenchange\"in t.window.document?this._fullscreenchange=\"fullscreenchange\":\"onmozfullscreenchange\"in t.window.document?this._fullscreenchange=\"mozfullscreenchange\":\"onwebkitfullscreenchange\"in t.window.document?this._fullscreenchange=\"webkitfullscreenchange\":\"onmsfullscreenchange\"in t.window.document&&(this._fullscreenchange=\"MSFullscreenChange\"),this._className=\"mapboxgl-ctrl\"};Wn.prototype.onAdd=function(e){return this._map=e,this._container||(this._container=this._map.getContainer()),this._controlContainer=r.create(\"div\",this._className+\" mapboxgl-ctrl-group\"),this._checkFullscreenSupport()?this._setupUI():(this._controlContainer.style.display=\"none\",t.warnOnce(\"This device does not support fullscreen mode.\")),this._controlContainer},Wn.prototype.onRemove=function(){r.remove(this._controlContainer),this._map=null,t.window.document.removeEventListener(this._fullscreenchange,this._changeIcon)},Wn.prototype._checkFullscreenSupport=function(){return!!(t.window.document.fullscreenEnabled||t.window.document.mozFullScreenEnabled||t.window.document.msFullscreenEnabled||t.window.document.webkitFullscreenEnabled)},Wn.prototype._setupUI=function(){(this._fullscreenButton=r.create(\"button\",this._className+\"-icon \"+this._className+\"-fullscreen\",this._controlContainer)).type=\"button\",this._updateTitle(),this._fullscreenButton.addEventListener(\"click\",this._onClickFullscreen),t.window.document.addEventListener(this._fullscreenchange,this._changeIcon)},Wn.prototype._updateTitle=function(){var t=this._isFullscreen()?\"Exit fullscreen\":\"Enter fullscreen\";this._fullscreenButton.setAttribute(\"aria-label\",t),this._fullscreenButton.title=t},Wn.prototype._isFullscreen=function(){return this._fullscreen},Wn.prototype._changeIcon=function(){(t.window.document.fullscreenElement||t.window.document.mozFullScreenElement||t.window.document.webkitFullscreenElement||t.window.document.msFullscreenElement)===this._container!==this._fullscreen&&(this._fullscreen=!this._fullscreen,this._fullscreenButton.classList.toggle(this._className+\"-shrink\"),this._fullscreenButton.classList.toggle(this._className+\"-fullscreen\"),this._updateTitle())},Wn.prototype._onClickFullscreen=function(){this._isFullscreen()?t.window.document.exitFullscreen?t.window.document.exitFullscreen():t.window.document.mozCancelFullScreen?t.window.document.mozCancelFullScreen():t.window.document.msExitFullscreen?t.window.document.msExitFullscreen():t.window.document.webkitCancelFullScreen&&t.window.document.webkitCancelFullScreen():this._container.requestFullscreen?this._container.requestFullscreen():this._container.mozRequestFullScreen?this._container.mozRequestFullScreen():this._container.msRequestFullscreen?this._container.msRequestFullscreen():this._container.webkitRequestFullscreen&&this._container.webkitRequestFullscreen()};var Xn={closeButton:!0,closeOnClick:!0,className:\"\",maxWidth:\"240px\"},Zn=function(e){function n(r){e.call(this),this.options=t.extend(Object.create(Xn),r),t.bindAll([\"_update\",\"_onClickClose\",\"remove\"],this)}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.addTo=function(e){var r=this;return this._map=e,this.options.closeOnClick&&this._map.on(\"click\",this._onClickClose),this._map.on(\"remove\",this.remove),this._update(),this._trackPointer?(this._map.on(\"mousemove\",function(t){r._update(t.point)}),this._map.on(\"mouseup\",function(t){r._update(t.point)}),this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")):this._map.on(\"move\",this._update),this.fire(new t.Event(\"open\")),this},n.prototype.isOpen=function(){return!!this._map},n.prototype.remove=function(){return this._content&&r.remove(this._content),this._container&&(r.remove(this._container),delete this._container),this._map&&(this._map.off(\"move\",this._update),this._map.off(\"click\",this._onClickClose),this._map.off(\"remove\",this.remove),this._map.off(\"mousemove\"),delete this._map),this.fire(new t.Event(\"close\")),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._map&&(this._map.on(\"move\",this._update),this._map.off(\"mousemove\"),this._container.classList.remove(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.remove(\"mapboxgl-track-pointer\")),this._trackPointer=!1,this._update(),this},n.prototype.trackPointer=function(){var t=this;return this._trackPointer=!0,this._pos=null,this._map&&(this._map.off(\"move\",this._update),this._map.on(\"mousemove\",function(e){t._update(e.point)}),this._map.on(\"drag\",function(e){t._update(e.point)}),this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")),this},n.prototype.getElement=function(){return this._container},n.prototype.setText=function(e){return this.setDOMContent(t.window.document.createTextNode(e))},n.prototype.setHTML=function(e){var r,n=t.window.document.createDocumentFragment(),i=t.window.document.createElement(\"body\");for(i.innerHTML=e;r=i.firstChild;)n.appendChild(r);return this.setDOMContent(n)},n.prototype.getMaxWidth=function(){return this._container.style.maxWidth},n.prototype.setMaxWidth=function(t){return this.options.maxWidth=t,this._update(),this},n.prototype.setDOMContent=function(t){return this._createContent(),this._content.appendChild(t),this._update(),this},n.prototype._createContent=function(){this._content&&r.remove(this._content),this._content=r.create(\"div\",\"mapboxgl-popup-content\",this._container),this.options.closeButton&&(this._closeButton=r.create(\"button\",\"mapboxgl-popup-close-button\",this._content),this._closeButton.type=\"button\",this._closeButton.setAttribute(\"aria-label\",\"Close popup\"),this._closeButton.innerHTML=\"&#215;\",this._closeButton.addEventListener(\"click\",this._onClickClose))},n.prototype._update=function(e){var n=this,i=this._lngLat||this._trackPointer;if(this._map&&i&&this._content&&(this._container||(this._container=r.create(\"div\",\"mapboxgl-popup\",this._map.getContainer()),this._tip=r.create(\"div\",\"mapboxgl-popup-tip\",this._container),this._container.appendChild(this._content),this.options.className&&this.options.className.split(\" \").forEach(function(t){return n._container.classList.add(t)})),this.options.maxWidth&&this._container.style.maxWidth!==this.options.maxWidth&&(this._container.style.maxWidth=this.options.maxWidth),this._map.transform.renderWorldCopies&&!this._trackPointer&&(this._lngLat=Rn(this._lngLat,this._pos,this._map.transform)),!this._trackPointer||e)){var a=this._pos=this._trackPointer&&e?e:this._map.project(this._lngLat),o=this.options.anchor,s=function e(r){if(r){if(\"number\"==typeof r){var n=Math.round(Math.sqrt(.5*Math.pow(r,2)));return{center:new t.Point(0,0),top:new t.Point(0,r),\"top-left\":new t.Point(n,n),\"top-right\":new t.Point(-n,n),bottom:new t.Point(0,-r),\"bottom-left\":new t.Point(n,-n),\"bottom-right\":new t.Point(-n,-n),left:new t.Point(r,0),right:new t.Point(-r,0)}}if(r instanceof t.Point||Array.isArray(r)){var i=t.Point.convert(r);return{center:i,top:i,\"top-left\":i,\"top-right\":i,bottom:i,\"bottom-left\":i,\"bottom-right\":i,left:i,right:i}}return{center:t.Point.convert(r.center||[0,0]),top:t.Point.convert(r.top||[0,0]),\"top-left\":t.Point.convert(r[\"top-left\"]||[0,0]),\"top-right\":t.Point.convert(r[\"top-right\"]||[0,0]),bottom:t.Point.convert(r.bottom||[0,0]),\"bottom-left\":t.Point.convert(r[\"bottom-left\"]||[0,0]),\"bottom-right\":t.Point.convert(r[\"bottom-right\"]||[0,0]),left:t.Point.convert(r.left||[0,0]),right:t.Point.convert(r.right||[0,0])}}return e(new t.Point(0,0))}(this.options.offset);if(!o){var l,c=this._container.offsetWidth,u=this._container.offsetHeight;l=a.y+s.bottom.y<u?[\"top\"]:a.y>this._map.transform.height-u?[\"bottom\"]:[],a.x<c/2?l.push(\"left\"):a.x>this._map.transform.width-c/2&&l.push(\"right\"),o=0===l.length?\"bottom\":l.join(\"-\")}var h=a.add(s[o]).round();r.setTransform(this._container,Fn[o]+\" translate(\"+h.x+\"px,\"+h.y+\"px)\"),Bn(this._container,o,\"popup\")}},n.prototype._onClickClose=function(){this.remove()},n}(t.Evented),Jn={version:t.version,supported:e,setRTLTextPlugin:t.setRTLTextPlugin,Map:On,NavigationControl:Dn,GeolocateControl:Vn,AttributionControl:Mn,ScaleControl:Hn,FullscreenControl:Wn,Popup:Zn,Marker:jn,Style:De,LngLat:t.LngLat,LngLatBounds:t.LngLatBounds,Point:t.Point,MercatorCoordinate:t.MercatorCoordinate,Evented:t.Evented,config:t.config,get accessToken(){return t.config.ACCESS_TOKEN},set accessToken(e){t.config.ACCESS_TOKEN=e},get baseApiUrl(){return t.config.API_URL},set baseApiUrl(e){t.config.API_URL=e},get workerCount(){return zt.workerCount},set workerCount(t){zt.workerCount=t},get maxParallelImageRequests(){return t.config.MAX_PARALLEL_IMAGE_REQUESTS},set maxParallelImageRequests(e){t.config.MAX_PARALLEL_IMAGE_REQUESTS=e},clearStorage:function(e){t.clearTileCache(e)},workerUrl:\"\"};return Jn}),r},\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=i():(n=n||self).mapboxgl=i()},{}],427:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1<<t+1,r=new Array(e),n=0;n<e;++n)r[n]=a(t,n);return r};var n=t(\"convex-hull\");function i(t,e,r){for(var n=new Array(t),i=0;i<t;++i)n[i]=0,i===e&&(n[i]+=.5),i===r&&(n[i]+=.5);return n}function a(t,e){if(0===e||e===(1<<t+1)-1)return[];for(var r=[],a=[],o=0;o<=t;++o)if(e&1<<o){r.push(i(t,o-1,o-1)),a.push(null);for(var s=0;s<=t;++s)~e&1<<s&&(r.push(i(t,o-1,s-1)),a.push([o,s]))}var l=n(r),c=[];t:for(o=0;o<l.length;++o){var u=l[o],h=[];for(s=0;s<u.length;++s){if(!a[u[s]])continue t;h.push(a[u[s]].slice())}c.push(h)}return c}},{\"convex-hull\":130}],428:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"gl-mat4/create\"),a=t(\"gl-mat4/clone\"),o=t(\"gl-mat4/determinant\"),s=t(\"gl-mat4/invert\"),l=t(\"gl-mat4/transpose\"),c={length:t(\"gl-vec3/length\"),normalize:t(\"gl-vec3/normalize\"),dot:t(\"gl-vec3/dot\"),cross:t(\"gl-vec3/cross\")},u=i(),h=i(),f=[0,0,0,0],p=[[0,0,0],[0,0,0],[0,0,0]],d=[0,0,0];function g(t,e,r,n,i){t[0]=e[0]*n+r[0]*i,t[1]=e[1]*n+r[1]*i,t[2]=e[2]*n+r[2]*i}e.exports=function(t,e,r,i,v,m){if(e||(e=[0,0,0]),r||(r=[0,0,0]),i||(i=[0,0,0]),v||(v=[0,0,0,1]),m||(m=[0,0,0,1]),!n(u,t))return!1;if(a(h,u),h[3]=0,h[7]=0,h[11]=0,h[15]=1,Math.abs(o(h)<1e-8))return!1;var y,x,b,_,w,k,T,A=u[3],M=u[7],S=u[11],E=u[12],C=u[13],L=u[14],P=u[15];if(0!==A||0!==M||0!==S){if(f[0]=A,f[1]=M,f[2]=S,f[3]=P,!s(h,h))return!1;l(h,h),y=v,b=h,_=(x=f)[0],w=x[1],k=x[2],T=x[3],y[0]=b[0]*_+b[4]*w+b[8]*k+b[12]*T,y[1]=b[1]*_+b[5]*w+b[9]*k+b[13]*T,y[2]=b[2]*_+b[6]*w+b[10]*k+b[14]*T,y[3]=b[3]*_+b[7]*w+b[11]*k+b[15]*T}else v[0]=v[1]=v[2]=0,v[3]=1;if(e[0]=E,e[1]=C,e[2]=L,function(t,e){t[0][0]=e[0],t[0][1]=e[1],t[0][2]=e[2],t[1][0]=e[4],t[1][1]=e[5],t[1][2]=e[6],t[2][0]=e[8],t[2][1]=e[9],t[2][2]=e[10]}(p,u),r[0]=c.length(p[0]),c.normalize(p[0],p[0]),i[0]=c.dot(p[0],p[1]),g(p[1],p[1],p[0],1,-i[0]),r[1]=c.length(p[1]),c.normalize(p[1],p[1]),i[0]/=r[1],i[1]=c.dot(p[0],p[2]),g(p[2],p[2],p[0],1,-i[1]),i[2]=c.dot(p[1],p[2]),g(p[2],p[2],p[1],1,-i[2]),r[2]=c.length(p[2]),c.normalize(p[2],p[2]),i[1]/=r[2],i[2]/=r[2],c.cross(d,p[1],p[2]),c.dot(p[0],d)<0)for(var O=0;O<3;O++)r[O]*=-1,p[O][0]*=-1,p[O][1]*=-1,p[O][2]*=-1;return m[0]=.5*Math.sqrt(Math.max(1+p[0][0]-p[1][1]-p[2][2],0)),m[1]=.5*Math.sqrt(Math.max(1-p[0][0]+p[1][1]-p[2][2],0)),m[2]=.5*Math.sqrt(Math.max(1-p[0][0]-p[1][1]+p[2][2],0)),m[3]=.5*Math.sqrt(Math.max(1+p[0][0]+p[1][1]+p[2][2],0)),p[2][1]>p[1][2]&&(m[0]=-m[0]),p[0][2]>p[2][0]&&(m[1]=-m[1]),p[1][0]>p[0][1]&&(m[2]=-m[2]),!0}},{\"./normalize\":429,\"gl-mat4/clone\":259,\"gl-mat4/create\":260,\"gl-mat4/determinant\":261,\"gl-mat4/invert\":265,\"gl-mat4/transpose\":276,\"gl-vec3/cross\":334,\"gl-vec3/dot\":339,\"gl-vec3/length\":349,\"gl-vec3/normalize\":356}],429:[function(t,e,r){e.exports=function(t,e){var r=e[15];if(0===r)return!1;for(var n=1/r,i=0;i<16;i++)t[i]=e[i]*n;return!0}},{}],430:[function(t,e,r){var n=t(\"gl-vec3/lerp\"),i=t(\"mat4-recompose\"),a=t(\"mat4-decompose\"),o=t(\"gl-mat4/determinant\"),s=t(\"quat-slerp\"),l=h(),c=h(),u=h();function h(){return{translate:f(),scale:f(1),skew:f(),perspective:[0,0,0,1],quaternion:[0,0,0,1]}}function f(t){return[t||0,t||0,t||0]}e.exports=function(t,e,r,h){if(0===o(e)||0===o(r))return!1;var f=a(e,l.translate,l.scale,l.skew,l.perspective,l.quaternion),p=a(r,c.translate,c.scale,c.skew,c.perspective,c.quaternion);return!(!f||!p||(n(u.translate,l.translate,c.translate,h),n(u.skew,l.skew,c.skew,h),n(u.scale,l.scale,c.scale,h),n(u.perspective,l.perspective,c.perspective,h),s(u.quaternion,l.quaternion,c.quaternion,h),i(t,u.translate,u.scale,u.skew,u.perspective,u.quaternion),0))}},{\"gl-mat4/determinant\":261,\"gl-vec3/lerp\":350,\"mat4-decompose\":428,\"mat4-recompose\":431,\"quat-slerp\":483}],431:[function(t,e,r){var n={identity:t(\"gl-mat4/identity\"),translate:t(\"gl-mat4/translate\"),multiply:t(\"gl-mat4/multiply\"),create:t(\"gl-mat4/create\"),scale:t(\"gl-mat4/scale\"),fromRotationTranslation:t(\"gl-mat4/fromRotationTranslation\")},i=(n.create(),n.create());e.exports=function(t,e,r,a,o,s){return n.identity(t),n.fromRotationTranslation(t,s,e),t[3]=o[0],t[7]=o[1],t[11]=o[2],t[15]=o[3],n.identity(i),0!==a[2]&&(i[9]=a[2],n.multiply(t,t,i)),0!==a[1]&&(i[9]=0,i[8]=a[1],n.multiply(t,t,i)),0!==a[0]&&(i[8]=0,i[4]=a[0],n.multiply(t,t,i)),n.scale(t,t,r),t}},{\"gl-mat4/create\":260,\"gl-mat4/fromRotationTranslation\":263,\"gl-mat4/identity\":264,\"gl-mat4/multiply\":267,\"gl-mat4/scale\":274,\"gl-mat4/translate\":275}],432:[function(t,e,r){\"use strict\";e.exports=Math.log2||function(t){return Math.log(t)*Math.LOG2E}},{}],433:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"mat4-interpolate\"),a=t(\"gl-mat4/invert\"),o=t(\"gl-mat4/rotateX\"),s=t(\"gl-mat4/rotateY\"),l=t(\"gl-mat4/rotateZ\"),c=t(\"gl-mat4/lookAt\"),u=t(\"gl-mat4/translate\"),h=(t(\"gl-mat4/scale\"),t(\"gl-vec3/normalize\")),f=[0,0,0];function p(t){this._components=t.slice(),this._time=[0],this.prevMatrix=t.slice(),this.nextMatrix=t.slice(),this.computedMatrix=t.slice(),this.computedInverse=t.slice(),this.computedEye=[0,0,0],this.computedUp=[0,0,0],this.computedCenter=[0,0,0],this.computedRadius=[0],this._limits=[-1/0,1/0]}e.exports=function(t){return new p((t=t||{}).matrix||[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1])};var d=p.prototype;d.recalcMatrix=function(t){var e=this._time,r=n.le(e,t),o=this.computedMatrix;if(!(r<0)){var s=this._components;if(r===e.length-1)for(var l=16*r,c=0;c<16;++c)o[c]=s[l++];else{var u=e[r+1]-e[r],f=(l=16*r,this.prevMatrix),p=!0;for(c=0;c<16;++c)f[c]=s[l++];var d=this.nextMatrix;for(c=0;c<16;++c)d[c]=s[l++],p=p&&f[c]===d[c];if(u<1e-6||p)for(c=0;c<16;++c)o[c]=f[c];else i(o,f,d,(t-e[r])/u)}var g=this.computedUp;g[0]=o[1],g[1]=o[5],g[2]=o[9],h(g,g);var v=this.computedInverse;a(v,o);var m=this.computedEye,y=v[15];m[0]=v[12]/y,m[1]=v[13]/y,m[2]=v[14]/y;var x=this.computedCenter,b=Math.exp(this.computedRadius[0]);for(c=0;c<3;++c)x[c]=m[c]-o[2+4*c]*b}},d.idle=function(t){if(!(t<this.lastT())){for(var e=this._components,r=e.length-16,n=0;n<16;++n)e.push(e[r++]);this._time.push(t)}},d.flush=function(t){var e=n.gt(this._time,t)-2;e<0||(this._time.splice(0,e),this._components.splice(0,16*e))},d.lastT=function(){return this._time[this._time.length-1]},d.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||f,n=n||this.computedUp,this.setMatrix(t,c(this.computedMatrix,e,r,n));for(var i=0,a=0;a<3;++a)i+=Math.pow(r[a]-e[a],2);i=Math.log(Math.sqrt(i)),this.computedRadius[0]=i},d.rotate=function(t,e,r,n){this.recalcMatrix(t);var i=this.computedInverse;e&&s(i,i,e),r&&o(i,i,r),n&&l(i,i,n),this.setMatrix(t,a(this.computedMatrix,i))};var g=[0,0,0];d.pan=function(t,e,r,n){g[0]=-(e||0),g[1]=-(r||0),g[2]=-(n||0),this.recalcMatrix(t);var i=this.computedInverse;u(i,i,g),this.setMatrix(t,a(i,i))},d.translate=function(t,e,r,n){g[0]=e||0,g[1]=r||0,g[2]=n||0,this.recalcMatrix(t);var i=this.computedMatrix;u(i,i,g),this.setMatrix(t,i)},d.setMatrix=function(t,e){if(!(t<this.lastT())){this._time.push(t);for(var r=0;r<16;++r)this._components.push(e[r])}},d.setDistance=function(t,e){this.computedRadius[0]=e},d.setDistanceLimits=function(t,e){var r=this._limits;r[0]=t,r[1]=e},d.getDistanceLimits=function(t){var e=this._limits;return t?(t[0]=e[0],t[1]=e[1],t):e}},{\"binary-search-bounds\":91,\"gl-mat4/invert\":265,\"gl-mat4/lookAt\":266,\"gl-mat4/rotateX\":271,\"gl-mat4/rotateY\":272,\"gl-mat4/rotateZ\":273,\"gl-mat4/scale\":274,\"gl-mat4/translate\":275,\"gl-vec3/normalize\":356,\"mat4-interpolate\":430}],434:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<3){for(var r=new Array(e),i=0;i<e;++i)r[i]=i;return 2===e&&t[0][0]===t[1][0]&&t[0][1]===t[1][1]?[0]:r}for(var a=new Array(e),i=0;i<e;++i)a[i]=i;a.sort(function(e,r){var n=t[e][0]-t[r][0];return n||t[e][1]-t[r][1]});for(var o=[a[0],a[1]],s=[a[0],a[1]],i=2;i<e;++i){for(var l=a[i],c=t[l],u=o.length;u>1&&n(t[o[u-2]],t[o[u-1]],c)<=0;)u-=1,o.pop();for(o.push(l),u=s.length;u>1&&n(t[s[u-2]],t[s[u-1]],c)>=0;)u-=1,s.pop();s.push(l)}for(var r=new Array(s.length+o.length-2),h=0,i=0,f=o.length;i<f;++i)r[h++]=o[i];for(var p=s.length-2;p>0;--p)r[h++]=s[p];return r};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":510}],435:[function(t,e,r){\"use strict\";e.exports=function(t,e){e||(e=t,t=window);var r=0,i=0,a=0,o={shift:!1,alt:!1,control:!1,meta:!1},s=!1;function l(t){var e=!1;return\"altKey\"in t&&(e=e||t.altKey!==o.alt,o.alt=!!t.altKey),\"shiftKey\"in t&&(e=e||t.shiftKey!==o.shift,o.shift=!!t.shiftKey),\"ctrlKey\"in t&&(e=e||t.ctrlKey!==o.control,o.control=!!t.ctrlKey),\"metaKey\"in t&&(e=e||t.metaKey!==o.meta,o.meta=!!t.metaKey),e}function c(t,s){var c=n.x(s),u=n.y(s);\"buttons\"in s&&(t=0|s.buttons),(t!==r||c!==i||u!==a||l(s))&&(r=0|t,i=c||0,a=u||0,e&&e(r,i,a,o))}function u(t){c(0,t)}function h(){(r||i||a||o.shift||o.alt||o.meta||o.control)&&(i=a=0,r=0,o.shift=o.alt=o.control=o.meta=!1,e&&e(0,0,0,o))}function f(t){l(t)&&e&&e(r,i,a,o)}function p(t){0===n.buttons(t)?c(0,t):c(r,t)}function d(t){c(r|n.buttons(t),t)}function g(t){c(r&~n.buttons(t),t)}function v(){s||(s=!0,t.addEventListener(\"mousemove\",p),t.addEventListener(\"mousedown\",d),t.addEventListener(\"mouseup\",g),t.addEventListener(\"mouseleave\",u),t.addEventListener(\"mouseenter\",u),t.addEventListener(\"mouseout\",u),t.addEventListener(\"mouseover\",u),t.addEventListener(\"blur\",h),t.addEventListener(\"keyup\",f),t.addEventListener(\"keydown\",f),t.addEventListener(\"keypress\",f),t!==window&&(window.addEventListener(\"blur\",h),window.addEventListener(\"keyup\",f),window.addEventListener(\"keydown\",f),window.addEventListener(\"keypress\",f)))}v();var m={element:t};return Object.defineProperties(m,{enabled:{get:function(){return s},set:function(e){e?v():s&&(s=!1,t.removeEventListener(\"mousemove\",p),t.removeEventListener(\"mousedown\",d),t.removeEventListener(\"mouseup\",g),t.removeEventListener(\"mouseleave\",u),t.removeEventListener(\"mouseenter\",u),t.removeEventListener(\"mouseout\",u),t.removeEventListener(\"mouseover\",u),t.removeEventListener(\"blur\",h),t.removeEventListener(\"keyup\",f),t.removeEventListener(\"keydown\",f),t.removeEventListener(\"keypress\",f),t!==window&&(window.removeEventListener(\"blur\",h),window.removeEventListener(\"keyup\",f),window.removeEventListener(\"keydown\",f),window.removeEventListener(\"keypress\",f)))},enumerable:!0},buttons:{get:function(){return r},enumerable:!0},x:{get:function(){return i},enumerable:!0},y:{get:function(){return a},enumerable:!0},mods:{get:function(){return o},enumerable:!0}}),m};var n=t(\"mouse-event\")},{\"mouse-event\":437}],436:[function(t,e,r){var n={left:0,top:0};e.exports=function(t,e,r){e=e||t.currentTarget||t.srcElement,Array.isArray(r)||(r=[0,0]);var i=t.clientX||0,a=t.clientY||0,o=(s=e,s===window||s===document||s===document.body?n:s.getBoundingClientRect());var s;return r[0]=i-o.left,r[1]=a-o.top,r}},{}],437:[function(t,e,r){\"use strict\";function n(t){return t.target||t.srcElement||window}r.buttons=function(t){if(\"object\"==typeof t){if(\"buttons\"in t)return t.buttons;if(\"which\"in t){if(2===(e=t.which))return 4;if(3===e)return 2;if(e>0)return 1<<e-1}else if(\"button\"in t){var e;if(1===(e=t.button))return 4;if(2===e)return 2;if(e>=0)return 1<<e}}return 0},r.element=n,r.x=function(t){if(\"object\"==typeof t){if(\"offsetX\"in t)return t.offsetX;var e=n(t).getBoundingClientRect();return t.clientX-e.left}return 0},r.y=function(t){if(\"object\"==typeof t){if(\"offsetY\"in t)return t.offsetY;var e=n(t).getBoundingClientRect();return t.clientY-e.top}return 0}},{}],438:[function(t,e,r){\"use strict\";var n=t(\"to-px\");e.exports=function(t,e,r){\"function\"==typeof t&&(r=!!e,e=t,t=window);var i=n(\"ex\",t),a=function(t){r&&t.preventDefault();var n=t.deltaX||0,a=t.deltaY||0,o=t.deltaZ||0,s=t.deltaMode,l=1;switch(s){case 1:l=i;break;case 2:l=window.innerHeight}if(a*=l,o*=l,(n*=l)||a||o)return e(n,a,o,t)};return t.addEventListener(\"wheel\",a),a}},{\"to-px\":539}],439:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\");function i(t){return\"a\"+t}function a(t){return\"d\"+t}function o(t,e){return\"c\"+t+\"_\"+e}function s(t){return\"s\"+t}function l(t,e){return\"t\"+t+\"_\"+e}function c(t){return\"o\"+t}function u(t){return\"x\"+t}function h(t){return\"p\"+t}function f(t,e){return\"d\"+t+\"_\"+e}function p(t){return\"i\"+t}function d(t,e){return\"u\"+t+\"_\"+e}function g(t){return\"b\"+t}function v(t){return\"y\"+t}function m(t){return\"e\"+t}function y(t){return\"v\"+t}e.exports=function(t){function e(t){throw new Error(\"ndarray-extract-contour: \"+t)}\"object\"!=typeof t&&e(\"Must specify arguments\");var r=t.order;Array.isArray(r)||e(\"Must specify order\");var M=t.arrayArguments||1;M<1&&e(\"Must have at least one array argument\");var S=t.scalarArguments||0;S<0&&e(\"Scalar arg count must be > 0\");\"function\"!=typeof t.vertex&&e(\"Must specify vertex creation function\");\"function\"!=typeof t.cell&&e(\"Must specify cell creation function\");\"function\"!=typeof t.phase&&e(\"Must specify phase function\");for(var E=t.getters||[],C=new Array(M),L=0;L<M;++L)E.indexOf(L)>=0?C[L]=!0:C[L]=!1;return function(t,e,r,M,S,E){var C=E.length,L=S.length;if(L<2)throw new Error(\"ndarray-extract-contour: Dimension must be at least 2\");for(var P=\"extractContour\"+S.join(\"_\"),O=[],z=[],I=[],D=0;D<C;++D)I.push(i(D));for(var D=0;D<M;++D)I.push(u(D));for(var D=0;D<L;++D)z.push(s(D)+\"=\"+i(0)+\".shape[\"+D+\"]|0\");for(var D=0;D<C;++D){z.push(a(D)+\"=\"+i(D)+\".data\",c(D)+\"=\"+i(D)+\".offset|0\");for(var R=0;R<L;++R)z.push(l(D,R)+\"=\"+i(D)+\".stride[\"+R+\"]|0\")}for(var D=0;D<C;++D){z.push(h(D)+\"=\"+c(D)),z.push(o(D,0));for(var R=1;R<1<<L;++R){for(var F=[],B=0;B<L;++B)R&1<<B&&F.push(\"-\"+l(D,B));z.push(f(D,R)+\"=(\"+F.join(\"\")+\")|0\"),z.push(o(D,R)+\"=0\")}}for(var D=0;D<C;++D)for(var R=0;R<L;++R){var N=[l(D,S[R])];R>0&&N.push(l(D,S[R-1])+\"*\"+s(S[R-1])),z.push(d(D,S[R])+\"=(\"+N.join(\"-\")+\")|0\")}for(var D=0;D<L;++D)z.push(p(D)+\"=0\");z.push(_+\"=0\");for(var j=[\"2\"],D=L-2;D>=0;--D)j.push(s(S[D]));z.push(w+\"=(\"+j.join(\"*\")+\")|0\",b+\"=mallocUint32(\"+w+\")\",x+\"=mallocUint32(\"+w+\")\",k+\"=0\"),z.push(g(0)+\"=0\");for(var R=1;R<1<<L;++R){for(var U=[],V=[],B=0;B<L;++B)R&1<<B&&(0===V.length?U.push(\"1\"):U.unshift(V.join(\"*\"))),V.push(s(S[B]));var q=\"\";U[0].indexOf(s(S[L-2]))<0&&(q=\"-\");var H=A(L,R,S);z.push(m(H)+\"=(-\"+U.join(\"-\")+\")|0\",v(H)+\"=(\"+q+U.join(\"-\")+\")|0\",g(H)+\"=0\")}function G(t,e){O.push(\"for(\",p(S[t]),\"=\",e,\";\",p(S[t]),\"<\",s(S[t]),\";\",\"++\",p(S[t]),\"){\")}function Y(t){for(var e=0;e<C;++e)O.push(h(e),\"+=\",d(e,S[t]),\";\");O.push(\"}\")}function W(){for(var t=1;t<1<<L;++t)O.push(T,\"=\",m(t),\";\",m(t),\"=\",v(t),\";\",v(t),\"=\",T,\";\")}z.push(y(0)+\"=0\",T+\"=0\"),function t(e,r){if(e<0)return void function(t){for(var e=0;e<C;++e)E[e]?O.push(o(e,0),\"=\",a(e),\".get(\",h(e),\");\"):O.push(o(e,0),\"=\",a(e),\"[\",h(e),\"];\");for(var r=[],e=0;e<C;++e)r.push(o(e,0));for(var e=0;e<M;++e)r.push(u(e));O.push(g(0),\"=\",b,\"[\",k,\"]=phase(\",r.join(),\");\");for(var n=1;n<1<<L;++n)O.push(g(n),\"=\",b,\"[\",k,\"+\",m(n),\"];\");for(var i=[],n=1;n<1<<L;++n)i.push(\"(\"+g(0)+\"!==\"+g(n)+\")\");O.push(\"if(\",i.join(\"||\"),\"){\");for(var s=[],e=0;e<L;++e)s.push(p(e));for(var e=0;e<C;++e){s.push(o(e,0));for(var n=1;n<1<<L;++n)E[e]?O.push(o(e,n),\"=\",a(e),\".get(\",h(e),\"+\",f(e,n),\");\"):O.push(o(e,n),\"=\",a(e),\"[\",h(e),\"+\",f(e,n),\"];\"),s.push(o(e,n))}for(var e=0;e<1<<L;++e)s.push(g(e));for(var e=0;e<M;++e)s.push(u(e));O.push(\"vertex(\",s.join(),\");\",y(0),\"=\",x,\"[\",k,\"]=\",_,\"++;\");for(var l=(1<<L)-1,c=g(l),n=0;n<L;++n)if(0==(t&~(1<<n))){for(var d=l^1<<n,v=g(d),w=[],T=d;T>0;T=T-1&d)w.push(x+\"[\"+k+\"+\"+m(T)+\"]\");w.push(y(0));for(var T=0;T<C;++T)1&n?w.push(o(T,l),o(T,d)):w.push(o(T,d),o(T,l));1&n?w.push(c,v):w.push(v,c);for(var T=0;T<M;++T)w.push(u(T));O.push(\"if(\",c,\"!==\",v,\"){\",\"face(\",w.join(),\")}\")}O.push(\"}\",k,\"+=1;\")}(r);!function(t){for(var e=t-1;e>=0;--e)G(e,0);for(var r=[],e=0;e<C;++e)E[e]?r.push(a(e)+\".get(\"+h(e)+\")\"):r.push(a(e)+\"[\"+h(e)+\"]\");for(var e=0;e<M;++e)r.push(u(e));O.push(b,\"[\",k,\"++]=phase(\",r.join(),\");\");for(var e=0;e<t;++e)Y(e);for(var n=0;n<C;++n)O.push(h(n),\"+=\",d(n,S[t]),\";\")}(e);O.push(\"if(\",s(S[e]),\">0){\",p(S[e]),\"=1;\");t(e-1,r|1<<S[e]);for(var n=0;n<C;++n)O.push(h(n),\"+=\",d(n,S[e]),\";\");e===L-1&&(O.push(k,\"=0;\"),W());G(e,2);t(e-1,r);e===L-1&&(O.push(\"if(\",p(S[L-1]),\"&1){\",k,\"=0;}\"),W());Y(e);O.push(\"}\")}(L-1,0),O.push(\"freeUint32(\",x,\");freeUint32(\",b,\");\");var X=[\"'use strict';\",\"function \",P,\"(\",I.join(),\"){\",\"var \",z.join(),\";\",O.join(\"\"),\"}\",\"return \",P].join(\"\");return new Function(\"vertex\",\"face\",\"phase\",\"mallocUint32\",\"freeUint32\",X)(t,e,r,n.mallocUint32,n.freeUint32)}(t.vertex,t.cell,t.phase,S,r,C)};var x=\"V\",b=\"P\",_=\"N\",w=\"Q\",k=\"X\",T=\"T\";function A(t,e,r){for(var n=0,i=0;i<t;++i)e&1<<i&&(n|=1<<r[i]);return n}},{\"typedarray-pool\":545}],440:[function(t,e,r){\"use strict\";var n=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{_inline_1_arg1_=_inline_1_arg2_.apply(void 0,_inline_1_arg0_)}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"cwise\",blockSize:64});e.exports=function(t,e){return n(t,e),t}},{\"cwise/lib/wrapper\":149}],441:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(Array.isArray(r)){if(r.length!==e.dimension)throw new Error(\"ndarray-gradient: invalid boundary conditions\")}else r=n(e.dimension,\"string\"==typeof r?r:\"clamp\");if(t.dimension!==e.dimension+1)throw new Error(\"ndarray-gradient: output dimension must be +1 input dimension\");if(t.shape[e.dimension]!==e.dimension)throw new Error(\"ndarray-gradient: output shape must match input shape\");for(var i=0;i<e.dimension;++i)if(t.shape[i]!==e.shape[i])throw new Error(\"ndarray-gradient: shape mismatch\");if(0===e.size)return t;if(e.dimension<=0)return t.set(0),t;return function(t){var e=t.join();if(m=o[e])return m;var r=t.length,n=[\"function gradient(dst,src){var s=src.shape.slice();\"];function i(e){for(var i=r-e.length,a=[],o=[],s=[],l=0;l<r;++l)e.indexOf(l+1)>=0?s.push(\"0\"):e.indexOf(-(l+1))>=0?s.push(\"s[\"+l+\"]-1\"):(s.push(\"-1\"),a.push(\"1\"),o.push(\"s[\"+l+\"]-2\"));var c=\".lo(\"+a.join()+\").hi(\"+o.join()+\")\";if(0===a.length&&(c=\"\"),i>0){n.push(\"if(1\");for(var l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\"&&s[\",l,\"]>2\");n.push(\"){grad\",i,\"(src.pick(\",s.join(),\")\",c);for(var l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\",dst.pick(\",s.join(),\",\",l,\")\",c);n.push(\");\")}for(var l=0;l<e.length;++l){var u=Math.abs(e[l])-1,h=\"dst.pick(\"+s.join()+\",\"+u+\")\"+c;switch(t[u]){case\"clamp\":var f=s.slice(),p=s.slice();e[l]<0?f[u]=\"s[\"+u+\"]-2\":p[u]=\"1\",0===i?n.push(\"if(s[\",u,\"]>1){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",f.join(),\")-src.get(\",p.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>1){diff(\",h,\",src.pick(\",f.join(),\")\",c,\",src.pick(\",p.join(),\")\",c,\");}else{zero(\",h,\");};\");break;case\"mirror\":0===i?n.push(\"dst.set(\",s.join(),\",\",u,\",0);\"):n.push(\"zero(\",h,\");\");break;case\"wrap\":var d=s.slice(),g=s.slice();e[l]<0?(d[u]=\"s[\"+u+\"]-2\",g[u]=\"0\"):(d[u]=\"s[\"+u+\"]-1\",g[u]=\"1\"),0===i?n.push(\"if(s[\",u,\"]>2){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",d.join(),\")-src.get(\",g.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>2){diff(\",h,\",src.pick(\",d.join(),\")\",c,\",src.pick(\",g.join(),\")\",c,\");}else{zero(\",h,\");};\");break;default:throw new Error(\"ndarray-gradient: Invalid boundary condition\")}}i>0&&n.push(\"};\")}for(var s=0;s<1<<r;++s){for(var h=[],f=0;f<r;++f)s&1<<f&&h.push(f+1);for(var p=0;p<1<<h.length;++p){for(var d=h.slice(),f=0;f<h.length;++f)p&1<<f&&(d[f]=-d[f]);i(d)}}n.push(\"return dst;};return gradient\");for(var g=[\"diff\",\"zero\"],v=[l,c],s=1;s<=r;++s)g.push(\"grad\"+s),v.push(u(s));g.push(n.join(\"\"));var m=Function.apply(void 0,g).apply(void 0,v);return a[e]=m,m}(r)(t,e)};var n=t(\"dup\"),i=t(\"cwise-compiler\"),a={},o={},s={body:\"\",args:[],thisVars:[],localVars:[]},l=i({args:[\"array\",\"array\",\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1},{name:\"left\",lvalue:!1,rvalue:!0,count:1},{name:\"right\",lvalue:!1,rvalue:!0,count:1}],body:\"out=0.5*(left-right)\",thisVars:[],localVars:[]},funcName:\"cdiff\"}),c=i({args:[\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1}],body:\"out=0\",thisVars:[],localVars:[]},funcName:\"zero\"});function u(t){if(t in a)return a[t];for(var e=[],r=0;r<t;++r)e.push(\"out\",r,\"s=0.5*(inp\",r,\"l-inp\",r,\"r);\");var o=[\"array\"],l=[\"junk\"];for(r=0;r<t;++r){o.push(\"array\"),l.push(\"out\"+r+\"s\");var c=n(t);c[r]=-1,o.push({array:0,offset:c.slice()}),c[r]=1,o.push({array:0,offset:c.slice()}),l.push(\"inp\"+r+\"l\",\"inp\"+r+\"r\")}return a[t]=i({args:o,pre:s,post:s,body:{body:e.join(\"\"),args:l.map(function(t){return{name:t,lvalue:0===t.indexOf(\"out\"),rvalue:0===t.indexOf(\"inp\"),count:\"junk\"!==t|0}}),thisVars:[],localVars:[]},funcName:\"fdTemplate\"+t})}},{\"cwise-compiler\":146,dup:170}],442:[function(t,e,r){\"use strict\";var n=t(\"ndarray-warp\"),i=t(\"gl-matrix-invert\");e.exports=function(t,e,r){var a=e.dimension,o=i([],r);return n(t,e,function(t,e){for(var r=0;r<a;++r){t[r]=o[(a+1)*a+r];for(var n=0;n<a;++n)t[r]+=o[(a+1)*n+r]*e[n]}var i=o[(a+1)*(a+1)-1];for(n=0;n<a;++n)i+=o[(a+1)*n+a]*e[n];var s=1/i;for(r=0;r<a;++r)t[r]*=s;return t}),t}},{\"gl-matrix-invert\":277,\"ndarray-warp\":449}],443:[function(t,e,r){\"use strict\";function n(t,e){var r=Math.floor(e),n=e-r,i=0<=r&&r<t.shape[0],a=0<=r+1&&r+1<t.shape[0];return(1-n)*(i?+t.get(r):0)+n*(a?+t.get(r+1):0)}function i(t,e,r){var n=Math.floor(e),i=e-n,a=0<=n&&n<t.shape[0],o=0<=n+1&&n+1<t.shape[0],s=Math.floor(r),l=r-s,c=0<=s&&s<t.shape[1],u=0<=s+1&&s+1<t.shape[1],h=a&&c?t.get(n,s):0,f=a&&u?t.get(n,s+1):0;return(1-l)*((1-i)*h+i*(o&&c?t.get(n+1,s):0))+l*((1-i)*f+i*(o&&u?t.get(n+1,s+1):0))}function a(t,e,r,n){var i=Math.floor(e),a=e-i,o=0<=i&&i<t.shape[0],s=0<=i+1&&i+1<t.shape[0],l=Math.floor(r),c=r-l,u=0<=l&&l<t.shape[1],h=0<=l+1&&l+1<t.shape[1],f=Math.floor(n),p=n-f,d=0<=f&&f<t.shape[2],g=0<=f+1&&f+1<t.shape[2],v=o&&u&&d?t.get(i,l,f):0,m=o&&h&&d?t.get(i,l+1,f):0,y=s&&u&&d?t.get(i+1,l,f):0,x=s&&h&&d?t.get(i+1,l+1,f):0,b=o&&u&&g?t.get(i,l,f+1):0,_=o&&h&&g?t.get(i,l+1,f+1):0;return(1-p)*((1-c)*((1-a)*v+a*y)+c*((1-a)*m+a*x))+p*((1-c)*((1-a)*b+a*(s&&u&&g?t.get(i+1,l,f+1):0))+c*((1-a)*_+a*(s&&h&&g?t.get(i+1,l+1,f+1):0)))}e.exports=function(t,e,r,o){switch(t.shape.length){case 0:return 0;case 1:return n(t,e);case 2:return i(t,e,r);case 3:return a(t,e,r,o);default:return function(t){var e,r,n=0|t.shape.length,i=new Array(n),a=new Array(n),o=new Array(n),s=new Array(n);for(e=0;e<n;++e)r=+arguments[e+1],i[e]=Math.floor(r),a[e]=r-i[e],o[e]=0<=i[e]&&i[e]<t.shape[e],s[e]=0<=i[e]+1&&i[e]+1<t.shape[e];var l,c,u,h=0;t:for(e=0;e<1<<n;++e){for(c=1,u=t.offset,l=0;l<n;++l)if(e&1<<l){if(!s[l])continue t;c*=a[l],u+=t.stride[l]*(i[l]+1)}else{if(!o[l])continue t;c*=1-a[l],u+=t.stride[l]*i[l]}h+=c*t.data[u]}return h}.apply(void 0,arguments)}},e.exports.d1=n,e.exports.d2=i,e.exports.d3=a},{}],444:[function(t,e,r){\"use strict\";var n=t(\"cwise-compiler\"),i={body:\"\",args:[],thisVars:[],localVars:[]};function a(t){if(!t)return i;for(var e=0;e<t.args.length;++e){var r=t.args[e];t.args[e]=0===e?{name:r,lvalue:!0,rvalue:!!t.rvalue,count:t.count||1}:{name:r,lvalue:!1,rvalue:!0,count:1}}return t.thisVars||(t.thisVars=[]),t.localVars||(t.localVars=[]),t}function o(t){for(var e=[],r=0;r<t.args.length;++r)e.push(\"a\"+r);return new Function(\"P\",[\"return function \",t.funcName,\"_ndarrayops(\",e.join(\",\"),\") {P(\",e.join(\",\"),\");return a0}\"].join(\"\"))(function(t){return n({args:t.args,pre:a(t.pre),body:a(t.body),post:a(t.proc),funcName:t.funcName})}(t))}var s={add:\"+\",sub:\"-\",mul:\"*\",div:\"/\",mod:\"%\",band:\"&\",bor:\"|\",bxor:\"^\",lshift:\"<<\",rshift:\">>\",rrshift:\">>>\"};!function(){for(var t in s){var e=s[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a\"+e+\"=b\"},rvalue:!0,funcName:t+\"eq\"}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a\"+e+\"=s\"},rvalue:!0,funcName:t+\"seq\"})}}();var l={not:\"!\",bnot:\"~\",neg:\"-\",recip:\"1.0/\"};!function(){for(var t in l){var e=l[t];r[t]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=\"+e+\"b\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\"],body:{args:[\"a\"],body:\"a=\"+e+\"a\"},rvalue:!0,count:2,funcName:t+\"eq\"})}}();var c={and:\"&&\",or:\"||\",eq:\"===\",neq:\"!==\",lt:\"<\",gt:\">\",leq:\"<=\",geq:\">=\"};!function(){for(var t in c){var e=c[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=a\"+e+\"b\"},rvalue:!0,count:2,funcName:t+\"eq\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a=a\"+e+\"s\"},rvalue:!0,count:2,funcName:t+\"seq\"})}}();var u=[\"abs\",\"acos\",\"asin\",\"atan\",\"ceil\",\"cos\",\"exp\",\"floor\",\"log\",\"round\",\"sin\",\"sqrt\",\"tan\"];!function(){for(var t=0;t<u.length;++t){var e=u[t];r[e]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"eq\"]=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f(a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"})}}();var h=[\"max\",\"min\",\"atan2\",\"pow\"];!function(){for(var t=0;t<h.length;++t){var e=h[t];r[e]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e+\"s\"}),r[e+\"eq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"}),r[e+\"seq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"seq\"})}}();var f=[\"atan2\",\"pow\"];!function(){for(var t=0;t<f.length;++t){var e=f[t];r[e+\"op\"]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"op\"}),r[e+\"ops\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"ops\"}),r[e+\"opeq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opeq\"}),r[e+\"opseq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opseq\"})}}(),r.any=n({args:[\"array\"],pre:i,body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"if(a){return true}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return false\"},funcName:\"any\"}),r.all=n({args:[\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1}],body:\"if(!x){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"all\"}),r.sum=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s+=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"sum\"}),r.prod=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=1\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s*=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"prod\"}),r.norm2squared=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm2squared\"}),r.norm2=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return Math.sqrt(this_s)\"},funcName:\"norm2\"}),r.norminf=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:4}],body:\"if(-a>this_s){this_s=-a}else if(a>this_s){this_s=a}\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norminf\"}),r.norm1=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:3}],body:\"this_s+=a<0?-a:a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm1\"}),r.sup=n({args:[\"array\"],pre:{body:\"this_h=-Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_>this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.inf=n({args:[\"array\"],pre:{body:\"this_h=Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_<this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.argmin=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_<this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.argmax=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=-Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_>this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.random=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.random\",thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f()\",thisVars:[\"this_f\"]},funcName:\"random\"}),r.assign=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assign\"}),r.assigns=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assigns\"}),r.equals=n({args:[\"array\",\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1},{name:\"y\",lvalue:!1,rvalue:!0,count:1}],body:\"if(x!==y){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"equals\"})},{\"cwise-compiler\":146}],445:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"./doConvert.js\");e.exports=function(t,e){for(var r=[],a=t,o=1;Array.isArray(a);)r.push(a.length),o*=a.length,a=a[0];return 0===r.length?n():(e||(e=n(new Float64Array(o),r)),i(e,t),e)}},{\"./doConvert.js\":446,ndarray:450}],446:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\nvar _inline_1_v=_inline_1_arg1_,_inline_1_i\\nfor(_inline_1_i=0;_inline_1_i<_inline_1_arg2_.length-1;++_inline_1_i) {\\n_inline_1_v=_inline_1_v[_inline_1_arg2_[_inline_1_i]]\\n}\\n_inline_1_arg0_=_inline_1_v[_inline_1_arg2_[_inline_1_arg2_.length-1]]\\n}\",args:[{name:\"_inline_1_arg0_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:4}],thisVars:[],localVars:[\"_inline_1_i\",\"_inline_1_v\"]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},funcName:\"convert\",blockSize:64})},{\"cwise-compiler\":146}],447:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=32;function a(t){switch(t){case\"uint8\":return[n.mallocUint8,n.freeUint8];case\"uint16\":return[n.mallocUint16,n.freeUint16];case\"uint32\":return[n.mallocUint32,n.freeUint32];case\"int8\":return[n.mallocInt8,n.freeInt8];case\"int16\":return[n.mallocInt16,n.freeInt16];case\"int32\":return[n.mallocInt32,n.freeInt32];case\"float32\":return[n.mallocFloat,n.freeFloat];case\"float64\":return[n.mallocDouble,n.freeDouble];default:return null}}function o(t){for(var e=[],r=0;r<t;++r)e.push(\"s\"+r);for(r=0;r<t;++r)e.push(\"n\"+r);for(r=1;r<t;++r)e.push(\"d\"+r);for(r=1;r<t;++r)e.push(\"e\"+r);for(r=1;r<t;++r)e.push(\"f\"+r);return e}e.exports=function(t,e){var r=[\"'use strict'\"],n=[\"ndarraySortWrapper\",t.join(\"d\"),e].join(\"\");r.push([\"function \",n,\"(\",[\"array\"].join(\",\"),\"){\"].join(\"\"));for(var s=[\"data=array.data,offset=array.offset|0,shape=array.shape,stride=array.stride\"],l=0;l<t.length;++l)s.push([\"s\",l,\"=stride[\",l,\"]|0,n\",l,\"=shape[\",l,\"]|0\"].join(\"\"));var c=new Array(t.length),u=[];for(l=0;l<t.length;++l)0!==(p=t[l])&&(0===u.length?c[p]=\"1\":c[p]=u.join(\"*\"),u.push(\"n\"+p));var h=-1,f=-1;for(l=0;l<t.length;++l){var p,d=t[l];0!==d&&(h>0?s.push([\"d\",d,\"=s\",d,\"-d\",h,\"*n\",h].join(\"\")):s.push([\"d\",d,\"=s\",d].join(\"\")),h=d),0!=(p=t.length-1-l)&&(f>0?s.push([\"e\",p,\"=s\",p,\"-e\",f,\"*n\",f,\",f\",p,\"=\",c[p],\"-f\",f,\"*n\",f].join(\"\")):s.push([\"e\",p,\"=s\",p,\",f\",p,\"=\",c[p]].join(\"\")),f=p)}r.push(\"var \"+s.join(\",\"));var g=[\"0\",\"n0-1\",\"data\",\"offset\"].concat(o(t.length));r.push([\"if(n0<=\",i,\"){\",\"insertionSort(\",g.join(\",\"),\")}else{\",\"quickSort(\",g.join(\",\"),\")}\"].join(\"\")),r.push(\"}return \"+n);var v=new Function(\"insertionSort\",\"quickSort\",r.join(\"\\n\")),m=function(t,e){var r=[\"'use strict'\"],n=[\"ndarrayInsertionSort\",t.join(\"d\"),e].join(\"\"),i=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),s=a(e),l=[\"i,j,cptr,ptr=left*s0+offset\"];if(t.length>1){for(var c=[],u=1;u<t.length;++u)l.push(\"i\"+u),c.push(\"n\"+u);s?l.push(\"scratch=malloc(\"+c.join(\"*\")+\")\"):l.push(\"scratch=new Array(\"+c.join(\"*\")+\")\"),l.push(\"dptr\",\"sptr\",\"a\",\"b\")}else l.push(\"scratch\");function h(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function f(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}if(r.push([\"function \",n,\"(\",i.join(\",\"),\"){var \",l.join(\",\")].join(\"\"),\"for(i=left+1;i<=right;++i){\",\"j=i;ptr+=s0\",\"cptr=ptr\"),t.length>1){for(r.push(\"dptr=0;sptr=ptr\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(\"scratch[dptr++]=\",h(\"sptr\")),u=0;u<t.length;++u)0!==(p=t[u])&&r.push(\"sptr+=d\"+p,\"}\");for(r.push(\"__g:while(j--\\x3eleft){\",\"dptr=0\",\"sptr=cptr-s0\"),u=1;u<t.length;++u)1===u&&r.push(\"__l:\"),r.push([\"for(i\",u,\"=0;i\",u,\"<n\",u,\";++i\",u,\"){\"].join(\"\"));for(r.push([\"a=\",h(\"sptr\"),\"\\nb=scratch[dptr]\\nif(a<b){break __g}\\nif(a>b){break __l}\"].join(\"\")),u=t.length-1;u>=1;--u)r.push(\"sptr+=e\"+u,\"dptr+=f\"+u,\"}\");for(r.push(\"dptr=cptr;sptr=cptr-s0\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(f(\"dptr\",h(\"sptr\"))),u=0;u<t.length;++u)0!==(p=t[u])&&r.push([\"dptr+=d\",p,\";sptr+=d\",p].join(\"\"),\"}\");for(r.push(\"cptr-=s0\\n}\"),r.push(\"dptr=cptr;sptr=0\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(f(\"dptr\",\"scratch[sptr++]\")),u=0;u<t.length;++u){var p;0!==(p=t[u])&&r.push(\"dptr+=d\"+p,\"}\")}}else r.push(\"scratch=\"+h(\"ptr\"),\"while((j--\\x3eleft)&&(\"+h(\"cptr-s0\")+\">scratch)){\",f(\"cptr\",h(\"cptr-s0\")),\"cptr-=s0\",\"}\",f(\"cptr\",\"scratch\"));return r.push(\"}\"),t.length>1&&s&&r.push(\"free(scratch)\"),r.push(\"} return \"+n),s?new Function(\"malloc\",\"free\",r.join(\"\\n\"))(s[0],s[1]):new Function(r.join(\"\\n\"))()}(t,e),y=function(t,e,r){var n=[\"'use strict'\"],s=[\"ndarrayQuickSort\",t.join(\"d\"),e].join(\"\"),l=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),c=a(e),u=0;n.push([\"function \",s,\"(\",l.join(\",\"),\"){\"].join(\"\"));var h=[\"sixth=((right-left+1)/6)|0\",\"index1=left+sixth\",\"index5=right-sixth\",\"index3=(left+right)>>1\",\"index2=index3-sixth\",\"index4=index3+sixth\",\"el1=index1\",\"el2=index2\",\"el3=index3\",\"el4=index4\",\"el5=index5\",\"less=left+1\",\"great=right-1\",\"pivots_are_equal=true\",\"tmp\",\"tmp0\",\"x\",\"y\",\"z\",\"k\",\"ptr0\",\"ptr1\",\"ptr2\",\"comp_pivot1=0\",\"comp_pivot2=0\",\"comp=0\"];if(t.length>1){for(var f=[],p=1;p<t.length;++p)f.push(\"n\"+p),h.push(\"i\"+p);for(p=0;p<8;++p)h.push(\"b_ptr\"+p);h.push(\"ptr3\",\"ptr4\",\"ptr5\",\"ptr6\",\"ptr7\",\"pivot_ptr\",\"ptr_shift\",\"elementSize=\"+f.join(\"*\")),c?h.push(\"pivot1=malloc(elementSize)\",\"pivot2=malloc(elementSize)\"):h.push(\"pivot1=new Array(elementSize),pivot2=new Array(elementSize)\")}else h.push(\"pivot1\",\"pivot2\");function d(t){return[\"(offset+\",t,\"*s0)\"].join(\"\")}function g(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function v(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}function m(e,r,i){if(1===e.length)n.push(\"ptr0=\"+d(e[0]));else for(var a=0;a<e.length;++a)n.push([\"b_ptr\",a,\"=s0*\",e[a]].join(\"\"));for(r&&n.push(\"pivot_ptr=0\"),n.push(\"ptr_shift=offset\"),a=t.length-1;a>=0;--a)0!==(o=t[a])&&n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"));if(e.length>1)for(a=0;a<e.length;++a)n.push([\"ptr\",a,\"=b_ptr\",a,\"+ptr_shift\"].join(\"\"));for(n.push(i),r&&n.push(\"++pivot_ptr\"),a=0;a<t.length;++a){var o;0!==(o=t[a])&&(e.length>1?n.push(\"ptr_shift+=d\"+o):n.push(\"ptr0+=d\"+o),n.push(\"}\"))}}function y(e,r,i,a){if(1===r.length)n.push(\"ptr0=\"+d(r[0]));else{for(var o=0;o<r.length;++o)n.push([\"b_ptr\",o,\"=s0*\",r[o]].join(\"\"));n.push(\"ptr_shift=offset\")}for(i&&n.push(\"pivot_ptr=0\"),e&&n.push(e+\":\"),o=1;o<t.length;++o)n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"));if(r.length>1)for(o=0;o<r.length;++o)n.push([\"ptr\",o,\"=b_ptr\",o,\"+ptr_shift\"].join(\"\"));for(n.push(a),o=t.length-1;o>=1;--o)i&&n.push(\"pivot_ptr+=f\"+o),r.length>1?n.push(\"ptr_shift+=e\"+o):n.push(\"ptr0+=e\"+o),n.push(\"}\")}function x(){t.length>1&&c&&n.push(\"free(pivot1)\",\"free(pivot2)\")}function b(e,r){var i=\"el\"+e,a=\"el\"+r;if(t.length>1){var o=\"__l\"+ ++u;y(o,[i,a],!1,[\"comp=\",g(\"ptr0\"),\"-\",g(\"ptr1\"),\"\\n\",\"if(comp>0){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0;break \",o,\"}\\n\",\"if(comp<0){break \",o,\"}\"].join(\"\"))}else n.push([\"if(\",g(d(i)),\">\",g(d(a)),\"){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0}\"].join(\"\"))}function _(e,r){t.length>1?m([e,r],!1,v(\"ptr0\",g(\"ptr1\"))):n.push(v(d(e),g(d(r))))}function w(e,r,i){if(t.length>1){var a=\"__l\"+ ++u;y(a,[r],!0,[e,\"=\",g(\"ptr0\"),\"-pivot\",i,\"[pivot_ptr]\\n\",\"if(\",e,\"!==0){break \",a,\"}\"].join(\"\"))}else n.push([e,\"=\",g(d(r)),\"-pivot\",i].join(\"\"))}function k(e,r){t.length>1?m([e,r],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",\"tmp\")].join(\"\")):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",\"tmp\")].join(\"\"))}function T(e,r,i){t.length>1?(m([e,r,i],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",g(\"ptr2\")),\"\\n\",v(\"ptr2\",\"tmp\")].join(\"\")),n.push(\"++\"+r,\"--\"+i)):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"ptr2=\",d(i),\"\\n\",\"++\",r,\"\\n\",\"--\",i,\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",g(\"ptr2\")),\"\\n\",v(\"ptr2\",\"tmp\")].join(\"\"))}function A(t,e){k(t,e),n.push(\"--\"+e)}function M(e,r,i){t.length>1?m([e,r],!0,[v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",[\"pivot\",i,\"[pivot_ptr]\"].join(\"\"))].join(\"\")):n.push(v(d(e),g(d(r))),v(d(r),\"pivot\"+i))}function S(e,r){n.push([\"if((\",r,\"-\",e,\")<=\",i,\"){\\n\",\"insertionSort(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}else{\\n\",s,\"(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}\"].join(\"\"))}function E(e,r,i){t.length>1?(n.push([\"__l\",++u,\":while(true){\"].join(\"\")),m([e],!0,[\"if(\",g(\"ptr0\"),\"!==pivot\",r,\"[pivot_ptr]){break __l\",u,\"}\"].join(\"\")),n.push(i,\"}\")):n.push([\"while(\",g(d(e)),\"===pivot\",r,\"){\",i,\"}\"].join(\"\"))}return n.push(\"var \"+h.join(\",\")),b(1,2),b(4,5),b(1,3),b(2,3),b(1,4),b(3,4),b(2,5),b(2,3),b(4,5),t.length>1?m([\"el1\",\"el2\",\"el3\",\"el4\",\"el5\",\"index1\",\"index3\",\"index5\"],!0,[\"pivot1[pivot_ptr]=\",g(\"ptr1\"),\"\\n\",\"pivot2[pivot_ptr]=\",g(\"ptr3\"),\"\\n\",\"pivots_are_equal=pivots_are_equal&&(pivot1[pivot_ptr]===pivot2[pivot_ptr])\\n\",\"x=\",g(\"ptr0\"),\"\\n\",\"y=\",g(\"ptr2\"),\"\\n\",\"z=\",g(\"ptr4\"),\"\\n\",v(\"ptr5\",\"x\"),\"\\n\",v(\"ptr6\",\"y\"),\"\\n\",v(\"ptr7\",\"z\")].join(\"\")):n.push([\"pivot1=\",g(d(\"el2\")),\"\\n\",\"pivot2=\",g(d(\"el4\")),\"\\n\",\"pivots_are_equal=pivot1===pivot2\\n\",\"x=\",g(d(\"el1\")),\"\\n\",\"y=\",g(d(\"el3\")),\"\\n\",\"z=\",g(d(\"el5\")),\"\\n\",v(d(\"index1\"),\"x\"),\"\\n\",v(d(\"index3\"),\"y\"),\"\\n\",v(d(\"index5\"),\"z\")].join(\"\")),_(\"index2\",\"left\"),_(\"index4\",\"right\"),n.push(\"if(pivots_are_equal){\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp\",\"k\",1),n.push(\"if(comp===0){continue}\"),n.push(\"if(comp<0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),n.push(\"while(true){\"),w(\"comp\",\"great\",1),n.push(\"if(comp>0){\"),n.push(\"great--\"),n.push(\"}else if(comp<0){\"),T(\"k\",\"less\",\"great\"),n.push(\"break\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}else{\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1<0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2>0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp>0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),T(\"k\",\"less\",\"great\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),M(\"left\",\"(less-1)\",1),M(\"right\",\"(great+1)\",2),S(\"left\",\"(less-2)\"),S(\"(great+2)\",\"right\"),n.push(\"if(pivots_are_equal){\"),x(),n.push(\"return\"),n.push(\"}\"),n.push(\"if(less<index1&&great>index5){\"),E(\"less\",1,\"++less\"),E(\"great\",2,\"--great\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1===0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2===0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp===0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),T(\"k\",\"less\",\"great\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),x(),S(\"less\",\"great\"),n.push(\"}return \"+s),t.length>1&&c?new Function(\"insertionSort\",\"malloc\",\"free\",n.join(\"\\n\"))(r,c[0],c[1]):new Function(\"insertionSort\",n.join(\"\\n\"))(r)}(t,e,m);return v(m,y)}},{\"typedarray-pool\":545}],448:[function(t,e,r){\"use strict\";var n=t(\"./lib/compile_sort.js\"),i={};e.exports=function(t){var e=t.order,r=t.dtype,a=[e,r].join(\":\"),o=i[a];return o||(i[a]=o=n(e,r)),o(t),t}},{\"./lib/compile_sort.js\":447}],449:[function(t,e,r){\"use strict\";var n=t(\"ndarray-linear-interpolate\"),i=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=new Array(_inline_3_arg4_)}\",args:[{name:\"_inline_3_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg2_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg3_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_4_arg2_(this_warped,_inline_4_arg0_),_inline_4_arg1_=_inline_4_arg3_.apply(void 0,this_warped)}\",args:[{name:\"_inline_4_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_4_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg4_\",lvalue:!1,rvalue:!1,count:0}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warpND\",blockSize:64}),a=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_7_arg2_(this_warped,_inline_7_arg0_),_inline_7_arg1_=_inline_7_arg3_(_inline_7_arg4_,this_warped[0])}\",args:[{name:\"_inline_7_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_7_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp1D\",blockSize:64}),o=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0,0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_10_arg2_(this_warped,_inline_10_arg0_),_inline_10_arg1_=_inline_10_arg3_(_inline_10_arg4_,this_warped[0],this_warped[1])}\",args:[{name:\"_inline_10_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_10_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp2D\",blockSize:64}),s=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0,0,0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_13_arg2_(this_warped,_inline_13_arg0_),_inline_13_arg1_=_inline_13_arg3_(_inline_13_arg4_,this_warped[0],this_warped[1],this_warped[2])}\",args:[{name:\"_inline_13_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_13_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp3D\",blockSize:64});e.exports=function(t,e,r){switch(e.shape.length){case 1:a(t,r,n.d1,e);break;case 2:o(t,r,n.d2,e);break;case 3:s(t,r,n.d3,e);break;default:i(t,r,n.bind(void 0,e),e.shape.length)}return t}},{\"cwise/lib/wrapper\":149,\"ndarray-linear-interpolate\":443}],450:[function(t,e,r){var n=t(\"iota-array\"),i=t(\"is-buffer\"),a=\"undefined\"!=typeof Float64Array;function o(t,e){return t[0]-e[0]}function s(){var t,e=this.stride,r=new Array(e.length);for(t=0;t<r.length;++t)r[t]=[Math.abs(e[t]),t];r.sort(o);var n=new Array(r.length);for(t=0;t<n.length;++t)n[t]=r[t][1];return n}function l(t,e){var r=[\"View\",e,\"d\",t].join(\"\");e<0&&(r=\"View_Nil\"+t);var i=\"generic\"===t;if(-1===e){var a=\"function \"+r+\"(a){this.data=a;};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return -1};proto.size=0;proto.dimension=-1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function(){return new \"+r+\"(this.data);};proto.get=proto.set=function(){};proto.pick=function(){return null};return function construct_\"+r+\"(a){return new \"+r+\"(a);}\";return new Function(a)()}if(0===e){a=\"function \"+r+\"(a,d) {this.data = a;this.offset = d};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return this.offset};proto.dimension=0;proto.size=1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function \"+r+\"_copy() {return new \"+r+\"(this.data,this.offset)};proto.pick=function \"+r+\"_pick(){return TrivialArray(this.data);};proto.valueOf=proto.get=function \"+r+\"_get(){return \"+(i?\"this.data.get(this.offset)\":\"this.data[this.offset]\")+\"};proto.set=function \"+r+\"_set(v){return \"+(i?\"this.data.set(this.offset,v)\":\"this.data[this.offset]=v\")+\"};return function construct_\"+r+\"(a,b,c,d){return new \"+r+\"(a,d)}\";return new Function(\"TrivialArray\",a)(c[t][0])}a=[\"'use strict'\"];var o=n(e),l=o.map(function(t){return\"i\"+t}),u=\"this.offset+\"+o.map(function(t){return\"this.stride[\"+t+\"]*i\"+t}).join(\"+\"),h=o.map(function(t){return\"b\"+t}).join(\",\"),f=o.map(function(t){return\"c\"+t}).join(\",\");a.push(\"function \"+r+\"(a,\"+h+\",\"+f+\",d){this.data=a\",\"this.shape=[\"+h+\"]\",\"this.stride=[\"+f+\"]\",\"this.offset=d|0}\",\"var proto=\"+r+\".prototype\",\"proto.dtype='\"+t+\"'\",\"proto.dimension=\"+e),a.push(\"Object.defineProperty(proto,'size',{get:function \"+r+\"_size(){return \"+o.map(function(t){return\"this.shape[\"+t+\"]\"}).join(\"*\"),\"}})\"),1===e?a.push(\"proto.order=[0]\"):(a.push(\"Object.defineProperty(proto,'order',{get:\"),e<4?(a.push(\"function \"+r+\"_order(){\"),2===e?a.push(\"return (Math.abs(this.stride[0])>Math.abs(this.stride[1]))?[1,0]:[0,1]}})\"):3===e&&a.push(\"var s0=Math.abs(this.stride[0]),s1=Math.abs(this.stride[1]),s2=Math.abs(this.stride[2]);if(s0>s1){if(s1>s2){return [2,1,0];}else if(s0>s2){return [1,2,0];}else{return [1,0,2];}}else if(s0>s2){return [2,0,1];}else if(s2>s1){return [0,1,2];}else{return [0,2,1];}}})\")):a.push(\"ORDER})\")),a.push(\"proto.set=function \"+r+\"_set(\"+l.join(\",\")+\",v){\"),i?a.push(\"return this.data.set(\"+u+\",v)}\"):a.push(\"return this.data[\"+u+\"]=v}\"),a.push(\"proto.get=function \"+r+\"_get(\"+l.join(\",\")+\"){\"),i?a.push(\"return this.data.get(\"+u+\")}\"):a.push(\"return this.data[\"+u+\"]}\"),a.push(\"proto.index=function \"+r+\"_index(\",l.join(),\"){return \"+u+\"}\"),a.push(\"proto.hi=function \"+r+\"_hi(\"+l.join(\",\")+\"){return new \"+r+\"(this.data,\"+o.map(function(t){return[\"(typeof i\",t,\"!=='number'||i\",t,\"<0)?this.shape[\",t,\"]:i\",t,\"|0\"].join(\"\")}).join(\",\")+\",\"+o.map(function(t){return\"this.stride[\"+t+\"]\"}).join(\",\")+\",this.offset)}\");var p=o.map(function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"}),d=o.map(function(t){return\"c\"+t+\"=this.stride[\"+t+\"]\"});a.push(\"proto.lo=function \"+r+\"_lo(\"+l.join(\",\")+\"){var b=this.offset,d=0,\"+p.join(\",\")+\",\"+d.join(\",\"));for(var g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){d=i\"+g+\"|0;b+=c\"+g+\"*d;a\"+g+\"-=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map(function(t){return\"a\"+t}).join(\",\")+\",\"+o.map(function(t){return\"c\"+t}).join(\",\")+\",b)}\"),a.push(\"proto.step=function \"+r+\"_step(\"+l.join(\",\")+\"){var \"+o.map(function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"}).join(\",\")+\",\"+o.map(function(t){return\"b\"+t+\"=this.stride[\"+t+\"]\"}).join(\",\")+\",c=this.offset,d=0,ceil=Math.ceil\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'){d=i\"+g+\"|0;if(d<0){c+=b\"+g+\"*(a\"+g+\"-1);a\"+g+\"=ceil(-a\"+g+\"/d)}else{a\"+g+\"=ceil(a\"+g+\"/d)}b\"+g+\"*=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map(function(t){return\"a\"+t}).join(\",\")+\",\"+o.map(function(t){return\"b\"+t}).join(\",\")+\",c)}\");var v=new Array(e),m=new Array(e);for(g=0;g<e;++g)v[g]=\"a[i\"+g+\"]\",m[g]=\"b[i\"+g+\"]\";a.push(\"proto.transpose=function \"+r+\"_transpose(\"+l+\"){\"+l.map(function(t,e){return t+\"=(\"+t+\"===undefined?\"+e+\":\"+t+\"|0)\"}).join(\";\"),\"var a=this.shape,b=this.stride;return new \"+r+\"(this.data,\"+v.join(\",\")+\",\"+m.join(\",\")+\",this.offset)}\"),a.push(\"proto.pick=function \"+r+\"_pick(\"+l+\"){var a=[],b=[],c=this.offset\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){c=(c+this.stride[\"+g+\"]*i\"+g+\")|0}else{a.push(this.shape[\"+g+\"]);b.push(this.stride[\"+g+\"])}\");return a.push(\"var ctor=CTOR_LIST[a.length+1];return ctor(this.data,a,b,c)}\"),a.push(\"return function construct_\"+r+\"(data,shape,stride,offset){return new \"+r+\"(data,\"+o.map(function(t){return\"shape[\"+t+\"]\"}).join(\",\")+\",\"+o.map(function(t){return\"stride[\"+t+\"]\"}).join(\",\")+\",offset)}\"),new Function(\"CTOR_LIST\",\"ORDER\",a.join(\"\\n\"))(c[t],s)}var c={float32:[],float64:[],int8:[],int16:[],int32:[],uint8:[],uint16:[],uint32:[],array:[],uint8_clamped:[],buffer:[],generic:[]};e.exports=function(t,e,r,n){if(void 0===t)return(0,c.array[0])([]);\"number\"==typeof t&&(t=[t]),void 0===e&&(e=[t.length]);var o=e.length;if(void 0===r){r=new Array(o);for(var s=o-1,u=1;s>=0;--s)r[s]=u,u*=e[s]}if(void 0===n)for(n=0,s=0;s<o;++s)r[s]<0&&(n-=(e[s]-1)*r[s]);for(var h=function(t){if(i(t))return\"buffer\";if(a)switch(Object.prototype.toString.call(t)){case\"[object Float64Array]\":return\"float64\";case\"[object Float32Array]\":return\"float32\";case\"[object Int8Array]\":return\"int8\";case\"[object Int16Array]\":return\"int16\";case\"[object Int32Array]\":return\"int32\";case\"[object Uint8Array]\":return\"uint8\";case\"[object Uint16Array]\":return\"uint16\";case\"[object Uint32Array]\":return\"uint32\";case\"[object Uint8ClampedArray]\":return\"uint8_clamped\"}return Array.isArray(t)?\"array\":\"generic\"}(t),f=c[h];f.length<=o+1;)f.push(l(h,f.length-1));return(0,f[o+1])(t,e,r,n)}},{\"iota-array\":416,\"is-buffer\":418}],451:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=Math.pow(2,-1074),a=-1>>>0;e.exports=function(t,e){if(isNaN(t)||isNaN(e))return NaN;if(t===e)return t;if(0===t)return e<0?-i:i;var r=n.hi(t),o=n.lo(t);e>t==t>0?o===a?(r+=1,o=0):o+=1:0===o?(o=a,r-=1):o-=1;return n.pack(o,r)}},{\"double-bits\":167}],452:[function(t,e,r){var n=Math.PI,i=c(120);function a(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function o(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}function s(t,e,r,a,o,c,u,h,f,p){if(p)k=p[0],T=p[1],_=p[2],w=p[3];else{var d=l(t,e,-o);t=d.x,e=d.y;var g=(t-(h=(d=l(h,f,-o)).x))/2,v=(e-(f=d.y))/2,m=g*g/(r*r)+v*v/(a*a);m>1&&(r*=m=Math.sqrt(m),a*=m);var y=r*r,x=a*a,b=(c==u?-1:1)*Math.sqrt(Math.abs((y*x-y*v*v-x*g*g)/(y*v*v+x*g*g)));b==1/0&&(b=1);var _=b*r*v/a+(t+h)/2,w=b*-a*g/r+(e+f)/2,k=Math.asin(((e-w)/a).toFixed(9)),T=Math.asin(((f-w)/a).toFixed(9));(k=t<_?n-k:k)<0&&(k=2*n+k),(T=h<_?n-T:T)<0&&(T=2*n+T),u&&k>T&&(k-=2*n),!u&&T>k&&(T-=2*n)}if(Math.abs(T-k)>i){var A=T,M=h,S=f;T=k+i*(u&&T>k?1:-1);var E=s(h=_+r*Math.cos(T),f=w+a*Math.sin(T),r,a,o,0,u,M,S,[T,A,_,w])}var C=Math.tan((T-k)/4),L=4/3*r*C,P=4/3*a*C,O=[2*t-(t+L*Math.sin(k)),2*e-(e-P*Math.cos(k)),h+L*Math.sin(T),f-P*Math.cos(T),h,f];if(p)return O;E&&(O=O.concat(E));for(var z=0;z<O.length;){var I=l(O[z],O[z+1],o);O[z++]=I.x,O[z++]=I.y}return O}function l(t,e,r){return{x:t*Math.cos(r)-e*Math.sin(r),y:t*Math.sin(r)+e*Math.cos(r)}}function c(t){return t*(n/180)}e.exports=function(t){for(var e,r=[],n=0,i=0,l=0,u=0,h=null,f=null,p=0,d=0,g=0,v=t.length;g<v;g++){var m=t[g],y=m[0];switch(y){case\"M\":l=m[1],u=m[2];break;case\"A\":(m=s(p,d,m[1],m[2],c(m[3]),m[4],m[5],m[6],m[7])).unshift(\"C\"),m.length>7&&(r.push(m.splice(0,7)),m.unshift(\"C\"));break;case\"S\":var x=p,b=d;\"C\"!=e&&\"S\"!=e||(x+=x-n,b+=b-i),m=[\"C\",x,b,m[1],m[2],m[3],m[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(h=2*p-h,f=2*d-f):(h=p,f=d),m=o(p,d,h,f,m[1],m[2]);break;case\"Q\":h=m[1],f=m[2],m=o(p,d,m[1],m[2],m[3],m[4]);break;case\"L\":m=a(p,d,m[1],m[2]);break;case\"H\":m=a(p,d,m[1],d);break;case\"V\":m=a(p,d,p,m[1]);break;case\"Z\":m=a(p,d,l,u)}e=y,p=m[m.length-2],d=m[m.length-1],m.length>4?(n=m[m.length-4],i=m[m.length-3]):(n=p,i=d),r.push(m)}return r}},{}],453:[function(t,e,r){r.vertexNormals=function(t,e,r){for(var n=e.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o)i[o]=[0,0,0];for(o=0;o<t.length;++o)for(var s=t[o],l=0,c=s[s.length-1],u=s[0],h=0;h<s.length;++h){l=c,c=u,u=s[(h+1)%s.length];for(var f=e[l],p=e[c],d=e[u],g=new Array(3),v=0,m=new Array(3),y=0,x=0;x<3;++x)g[x]=f[x]-p[x],v+=g[x]*g[x],m[x]=d[x]-p[x],y+=m[x]*m[x];if(v*y>a){var b=i[c],_=1/Math.sqrt(v*y);for(x=0;x<3;++x){var w=(x+1)%3,k=(x+2)%3;b[x]+=_*(m[w]*g[k]-m[k]*g[w])}}}for(o=0;o<n;++o){b=i[o];var T=0;for(x=0;x<3;++x)T+=b[x]*b[x];if(T>a)for(_=1/Math.sqrt(T),x=0;x<3;++x)b[x]*=_;else for(x=0;x<3;++x)b[x]=0}return i},r.faceNormals=function(t,e,r){for(var n=t.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o){for(var s=t[o],l=new Array(3),c=0;c<3;++c)l[c]=e[s[c]];var u=new Array(3),h=new Array(3);for(c=0;c<3;++c)u[c]=l[1][c]-l[0][c],h[c]=l[2][c]-l[0][c];var f=new Array(3),p=0;for(c=0;c<3;++c){var d=(c+1)%3,g=(c+2)%3;f[c]=u[d]*h[g]-u[g]*h[d],p+=f[c]*f[c]}p=p>a?1/Math.sqrt(p):0;for(c=0;c<3;++c)f[c]*=p;i[o]=f}return i}},{}],454:[function(t,e,r){\"use strict\";var n=Object.getOwnPropertySymbols,i=Object.prototype.hasOwnProperty,a=Object.prototype.propertyIsEnumerable;e.exports=function(){try{if(!Object.assign)return!1;var t=new String(\"abc\");if(t[5]=\"de\",\"5\"===Object.getOwnPropertyNames(t)[0])return!1;for(var e={},r=0;r<10;r++)e[\"_\"+String.fromCharCode(r)]=r;if(\"0123456789\"!==Object.getOwnPropertyNames(e).map(function(t){return e[t]}).join(\"\"))return!1;var n={};return\"abcdefghijklmnopqrst\".split(\"\").forEach(function(t){n[t]=t}),\"abcdefghijklmnopqrst\"===Object.keys(Object.assign({},n)).join(\"\")}catch(t){return!1}}()?Object.assign:function(t,e){for(var r,o,s=function(t){if(null==t)throw new TypeError(\"Object.assign cannot be called with null or undefined\");return Object(t)}(t),l=1;l<arguments.length;l++){for(var c in r=Object(arguments[l]))i.call(r,c)&&(s[c]=r[c]);if(n){o=n(r);for(var u=0;u<o.length;u++)a.call(r,o[u])&&(s[o[u]]=r[o[u]])}}return s}},{}],455:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a,o,s,l,c){var u=e+a+c;if(h>0){var h=Math.sqrt(u+1);t[0]=.5*(o-l)/h,t[1]=.5*(s-n)/h,t[2]=.5*(r-a)/h,t[3]=.5*h}else{var f=Math.max(e,a,c),h=Math.sqrt(2*f-u+1);e>=f?(t[0]=.5*h,t[1]=.5*(i+r)/h,t[2]=.5*(s+n)/h,t[3]=.5*(o-l)/h):a>=f?(t[0]=.5*(r+i)/h,t[1]=.5*h,t[2]=.5*(l+o)/h,t[3]=.5*(s-n)/h):(t[0]=.5*(n+s)/h,t[1]=.5*(o+l)/h,t[2]=.5*h,t[3]=.5*(r-i)/h)}return t}},{}],456:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.rotation||[0,0,0,1],n=t.radius||1;e=[].slice.call(e,0,3),u(r=[].slice.call(r,0,4),r);var i=new h(r,e,Math.log(n));i.setDistanceLimits(t.zoomMin,t.zoomMax),(\"eye\"in t||\"up\"in t)&&i.lookAt(0,t.eye,t.center,t.up);return i};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/lookAt\"),a=t(\"gl-mat4/fromQuat\"),o=t(\"gl-mat4/invert\"),s=t(\"./lib/quatFromFrame\");function l(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function c(t,e,r,n){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2)+Math.pow(n,2))}function u(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=c(r,n,i,a);o>1e-6?(t[0]=r/o,t[1]=n/o,t[2]=i/o,t[3]=a/o):(t[0]=t[1]=t[2]=0,t[3]=1)}function h(t,e,r){this.radius=n([r]),this.center=n(e),this.rotation=n(t),this.computedRadius=this.radius.curve(0),this.computedCenter=this.center.curve(0),this.computedRotation=this.rotation.curve(0),this.computedUp=[.1,0,0],this.computedEye=[.1,0,0],this.computedMatrix=[.1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],this.recalcMatrix(0)}var f=h.prototype;f.lastT=function(){return Math.max(this.radius.lastT(),this.center.lastT(),this.rotation.lastT())},f.recalcMatrix=function(t){this.radius.curve(t),this.center.curve(t),this.rotation.curve(t);var e=this.computedRotation;u(e,e);var r=this.computedMatrix;a(r,e);var n=this.computedCenter,i=this.computedEye,o=this.computedUp,s=Math.exp(this.computedRadius[0]);i[0]=n[0]+s*r[2],i[1]=n[1]+s*r[6],i[2]=n[2]+s*r[10],o[0]=r[1],o[1]=r[5],o[2]=r[9];for(var l=0;l<3;++l){for(var c=0,h=0;h<3;++h)c+=r[l+4*h]*i[h];r[12+l]=-c}},f.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r},f.idle=function(t){this.center.idle(t),this.radius.idle(t),this.rotation.idle(t)},f.flush=function(t){this.center.flush(t),this.radius.flush(t),this.rotation.flush(t)},f.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=i[1],o=i[5],s=i[9],c=l(a,o,s);a/=c,o/=c,s/=c;var u=i[0],h=i[4],f=i[8],p=u*a+h*o+f*s,d=l(u-=a*p,h-=o*p,f-=s*p);u/=d,h/=d,f/=d;var g=i[2],v=i[6],m=i[10],y=g*a+v*o+m*s,x=g*u+v*h+m*f,b=l(g-=y*a+x*u,v-=y*o+x*h,m-=y*s+x*f);g/=b,v/=b,m/=b;var _=u*e+a*r,w=h*e+o*r,k=f*e+s*r;this.center.move(t,_,w,k);var T=Math.exp(this.computedRadius[0]);T=Math.max(1e-4,T+n),this.radius.set(t,Math.log(T))},f.rotate=function(t,e,r,n){this.recalcMatrix(t),e=e||0,r=r||0;var i=this.computedMatrix,a=i[0],o=i[4],s=i[8],u=i[1],h=i[5],f=i[9],p=i[2],d=i[6],g=i[10],v=e*a+r*u,m=e*o+r*h,y=e*s+r*f,x=-(d*y-g*m),b=-(g*v-p*y),_=-(p*m-d*v),w=Math.sqrt(Math.max(0,1-Math.pow(x,2)-Math.pow(b,2)-Math.pow(_,2))),k=c(x,b,_,w);k>1e-6?(x/=k,b/=k,_/=k,w/=k):(x=b=_=0,w=1);var T=this.computedRotation,A=T[0],M=T[1],S=T[2],E=T[3],C=A*w+E*x+M*_-S*b,L=M*w+E*b+S*x-A*_,P=S*w+E*_+A*b-M*x,O=E*w-A*x-M*b-S*_;if(n){x=p,b=d,_=g;var z=Math.sin(n)/l(x,b,_);x*=z,b*=z,_*=z,O=O*(w=Math.cos(e))-(C=C*w+O*x+L*_-P*b)*x-(L=L*w+O*b+P*x-C*_)*b-(P=P*w+O*_+C*b-L*x)*_}var I=c(C,L,P,O);I>1e-6?(C/=I,L/=I,P/=I,O/=I):(C=L=P=0,O=1),this.rotation.set(t,C,L,P,O)},f.lookAt=function(t,e,r,n){this.recalcMatrix(t),r=r||this.computedCenter,e=e||this.computedEye,n=n||this.computedUp;var a=this.computedMatrix;i(a,e,r,n);var o=this.computedRotation;s(o,a[0],a[1],a[2],a[4],a[5],a[6],a[8],a[9],a[10]),u(o,o),this.rotation.set(t,o[0],o[1],o[2],o[3]);for(var l=0,c=0;c<3;++c)l+=Math.pow(r[c]-e[c],2);this.radius.set(t,.5*Math.log(Math.max(l,1e-6))),this.center.set(t,r[0],r[1],r[2])},f.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},f.setMatrix=function(t,e){var r=this.computedRotation;s(r,e[0],e[1],e[2],e[4],e[5],e[6],e[8],e[9],e[10]),u(r,r),this.rotation.set(t,r[0],r[1],r[2],r[3]);var n=this.computedMatrix;o(n,e);var i=n[15];if(Math.abs(i)>1e-6){var a=n[12]/i,l=n[13]/i,c=n[14]/i;this.recalcMatrix(t);var h=Math.exp(this.computedRadius[0]);this.center.set(t,a-n[2]*h,l-n[6]*h,c-n[10]*h),this.radius.idle(t)}else this.center.idle(t),this.radius.idle(t)},f.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},f.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},f.getDistanceLimits=function(t){var e=this.radius.bounds;return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},f.toJSON=function(){return this.recalcMatrix(this.lastT()),{center:this.computedCenter.slice(),rotation:this.computedRotation.slice(),distance:Math.log(this.computedRadius[0]),zoomMin:this.radius.bounds[0][0],zoomMax:this.radius.bounds[1][0]}},f.fromJSON=function(t){var e=this.lastT(),r=t.center;r&&this.center.set(e,r[0],r[1],r[2]);var n=t.rotation;n&&this.rotation.set(e,n[0],n[1],n[2],n[3]);var i=t.distance;i&&i>0&&this.radius.set(e,Math.log(i)),this.setDistanceLimits(t.zoomMin,t.zoomMax)}},{\"./lib/quatFromFrame\":455,\"filtered-vector\":226,\"gl-mat4/fromQuat\":262,\"gl-mat4/invert\":265,\"gl-mat4/lookAt\":266}],457:[function(t,e,r){\"use strict\";var n=t(\"repeat-string\");e.exports=function(t,e,r){return n(r=\"undefined\"!=typeof r?r+\"\":\" \",e)+t}},{\"repeat-string\":503}],458:[function(t,e,r){\"use strict\";function n(t,e){if(\"string\"!=typeof t)return[t];var r=[t];\"string\"==typeof e||Array.isArray(e)?e={brackets:e}:e||(e={});var n=e.brackets?Array.isArray(e.brackets)?e.brackets:[e.brackets]:[\"{}\",\"[]\",\"()\"],i=e.escape||\"___\",a=!!e.flat;n.forEach(function(t){var e=new RegExp([\"\\\\\",t[0],\"[^\\\\\",t[0],\"\\\\\",t[1],\"]*\\\\\",t[1]].join(\"\")),n=[];function a(e,a,o){var s=r.push(e.slice(t[0].length,-t[1].length))-1;return n.push(s),i+s+i}r.forEach(function(t,n){for(var i,o=0;t!=i;)if(i=t,t=t.replace(e,a),o++>1e4)throw Error(\"References have circular dependency. Please, check them.\");r[n]=t}),n=n.reverse(),r=r.map(function(e){return n.forEach(function(r){e=e.replace(new RegExp(\"(\\\\\"+i+r+\"\\\\\"+i+\")\",\"g\"),t[0]+\"$1\"+t[1])}),e})});var o=new RegExp(\"\\\\\"+i+\"([0-9]+)\\\\\"+i);return a?r:function t(e,r,n){for(var i,a=[],s=0;i=o.exec(e);){if(s++>1e4)throw Error(\"Circular references in parenthesis\");a.push(e.slice(0,i.index)),a.push(t(r[i[1]],r)),e=e.slice(i.index+i[0].length)}return a.push(e),a}(r[0],r)}function i(t,e){if(e&&e.flat){var r,n=e&&e.escape||\"___\",i=t[0];if(!i)return\"\";for(var a=new RegExp(\"\\\\\"+n+\"([0-9]+)\\\\\"+n),o=0;i!=r;){if(o++>1e4)throw Error(\"Circular references in \"+t);r=i,i=i.replace(a,s)}return i}return t.reduce(function t(e,r){return Array.isArray(r)&&(r=r.reduce(t,\"\")),e+r},\"\");function s(e,r){if(null==t[r])throw Error(\"Reference \"+r+\"is undefined\");return t[r]}}function a(t,e){return Array.isArray(t)?i(t,e):n(t,e)}a.parse=n,a.stringify=i,e.exports=a},{}],459:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\");e.exports=function(t){var e;arguments.length>1&&(t=arguments);\"string\"==typeof t?t=t.split(/\\s/).map(parseFloat):\"number\"==typeof t&&(t=[t]);t.length&&\"number\"==typeof t[0]?e=1===t.length?{width:t[0],height:t[0],x:0,y:0}:2===t.length?{width:t[0],height:t[1],x:0,y:0}:{x:t[0],y:t[1],width:t[2]-t[0]||0,height:t[3]-t[1]||0}:t&&(t=n(t,{left:\"x l left Left\",top:\"y t top Top\",width:\"w width W Width\",height:\"h height W Width\",bottom:\"b bottom Bottom\",right:\"r right Right\"}),e={x:t.left||0,y:t.top||0},null==t.width?t.right?e.width=t.right-e.x:e.width=0:e.width=t.width,null==t.height?t.bottom?e.height=t.bottom-e.y:e.height=0:e.height=t.height);return e}},{\"pick-by-alias\":465}],460:[function(t,e,r){e.exports=function(t){var e=[];return t.replace(i,function(t,r,i){var o=r.toLowerCase();for(i=function(t){var e=t.match(a);return e?e.map(Number):[]}(i),\"m\"==o&&i.length>2&&(e.push([r].concat(i.splice(0,2))),o=\"l\",r=\"m\"==r?\"l\":\"L\");;){if(i.length==n[o])return i.unshift(r),e.push(i);if(i.length<n[o])throw new Error(\"malformed path data\");e.push([r].concat(i.splice(0,n[o])))}}),e};var n={a:7,c:6,h:1,l:2,m:2,q:4,s:4,t:2,v:1,z:0},i=/([astvzqmhlc])([^astvzqmhlc]*)/gi;var a=/-?[0-9]*\\.?[0-9]+(?:e[-+]?\\d+)?/gi},{}],461:[function(t,e,r){e.exports=function(t,e){e||(e=[0,\"\"]),t=String(t);var r=parseFloat(t,10);return e[0]=r,e[1]=t.match(/[\\d.\\-\\+]*\\s*(.*)/)[1]||\"\",e}},{}],462:[function(t,e,r){(function(t){(function(){var r,n,i,a,o,s;\"undefined\"!=typeof performance&&null!==performance&&performance.now?e.exports=function(){return performance.now()}:\"undefined\"!=typeof t&&null!==t&&t.hrtime?(e.exports=function(){return(r()-o)/1e6},n=t.hrtime,a=(r=function(){var t;return 1e9*(t=n())[0]+t[1]})(),s=1e9*t.uptime(),o=a-s):Date.now?(e.exports=function(){return Date.now()-i},i=Date.now()):(e.exports=function(){return(new Date).getTime()-i},i=(new Date).getTime())}).call(this)}).call(this,t(\"_process\"))},{_process:482}],463:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<n){for(var r=1,a=0;a<e;++a)for(var o=0;o<a;++o)if(t[a]<t[o])r=-r;else if(t[a]===t[o])return 0;return r}for(var s=i.mallocUint8(e),a=0;a<e;++a)s[a]=0;for(var r=1,a=0;a<e;++a)if(!s[a]){var l=1;s[a]=1;for(var o=t[a];o!==a;o=t[o]){if(s[o])return i.freeUint8(s),0;l+=1,s[o]=1}1&l||(r=-r)}return i.freeUint8(s),r};var n=32,i=t(\"typedarray-pool\")},{\"typedarray-pool\":545}],464:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"invert-permutation\");r.rank=function(t){var e=t.length;switch(e){case 0:case 1:return 0;case 2:return t[1]}var r,a,o,s=n.mallocUint32(e),l=n.mallocUint32(e),c=0;for(i(t,l),o=0;o<e;++o)s[o]=t[o];for(o=e-1;o>0;--o)a=l[o],r=s[o],s[o]=s[a],s[a]=r,l[o]=l[r],l[r]=a,c=(c+r)*o;return n.freeUint32(l),n.freeUint32(s),c},r.unrank=function(t,e,r){switch(t){case 0:return r||[];case 1:return r?(r[0]=0,r):[0];case 2:return r?(e?(r[0]=0,r[1]=1):(r[0]=1,r[1]=0),r):e?[0,1]:[1,0]}var n,i,a,o=1;for((r=r||new Array(t))[0]=0,a=1;a<t;++a)r[a]=a,o=o*a|0;for(a=t-1;a>0;--a)e=e-(n=e/o|0)*o|0,o=o/a|0,i=0|r[a],r[a]=0|r[n],r[n]=0|i;return r}},{\"invert-permutation\":415,\"typedarray-pool\":545}],465:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n,a,o={};if(\"string\"==typeof e&&(e=i(e)),Array.isArray(e)){var s={};for(a=0;a<e.length;a++)s[e[a]]=!0;e=s}for(n in e)e[n]=i(e[n]);var l={};for(n in e){var c=e[n];if(Array.isArray(c))for(a=0;a<c.length;a++){var u=c[a];if(r&&(l[u]=!0),u in t){if(o[n]=t[u],r)for(var h=a;h<c.length;h++)l[c[h]]=!0;break}}else n in t&&(e[n]&&(o[n]=t[n]),r&&(l[n]=!0))}if(r)for(n in t)l[n]||(o[n]=t[n]);return o};var n={};function i(t){return n[t]?n[t]:(\"string\"==typeof t&&(t=n[t]=t.split(/\\s*,\\s*|\\s+/)),t)}},{}],466:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=0|e.length,i=t.length,a=[new Array(r),new Array(r)],o=0;o<r;++o)a[0][o]=[],a[1][o]=[];for(var o=0;o<i;++o){var s=t[o];a[0][s[0]].push(s),a[1][s[1]].push(s)}for(var l=[],o=0;o<r;++o)a[0][o].length+a[1][o].length===0&&l.push([o]);function c(t,e){var r=a[e][t[e]];r.splice(r.indexOf(t),1)}function u(t,r,i){for(var o,s,l,u=0;u<2;++u)if(a[u][r].length>0){o=a[u][r][0],l=u;break}s=o[1^l];for(var h=0;h<2;++h)for(var f=a[h][r],p=0;p<f.length;++p){var d=f[p],g=d[1^h],v=n(e[t],e[r],e[s],e[g]);v>0&&(o=d,s=g,l=h)}return i?s:(o&&c(o,l),s)}function h(t,r){var i=a[r][t][0],o=[t];c(i,r);for(var s=i[1^r];;){for(;s!==t;)o.push(s),s=u(o[o.length-2],s,!1);if(a[0][t].length+a[1][t].length===0)break;var l=o[o.length-1],h=t,f=o[1],p=u(l,h,!0);if(n(e[l],e[h],e[f],e[p])<0)break;o.push(t),s=u(l,h)}return o}function f(t,e){return e[1]===e[e.length-1]}for(var o=0;o<r;++o)for(var p=0;p<2;++p){for(var d=[];a[p][o].length>0;){a[0][o].length;var g=h(o,p);f(d,g)?d.push.apply(d,g):(d.length>0&&l.push(d),d=g)}d.length>0&&l.push(d)}return l};var n=t(\"compare-angle\")},{\"compare-angle\":127}],467:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=n(t,e.length),i=new Array(e.length),a=new Array(e.length),o=[],s=0;s<e.length;++s){var l=r[s].length;a[s]=l,i[s]=!0,l<=1&&o.push(s)}for(;o.length>0;){var c=o.pop();i[c]=!1;for(var u=r[c],s=0;s<u.length;++s){var h=u[s];0==--a[h]&&o.push(h)}}for(var f=new Array(e.length),p=[],s=0;s<e.length;++s)if(i[s]){var c=p.length;f[s]=c,p.push(e[s])}else f[s]=-1;for(var d=[],s=0;s<t.length;++s){var g=t[s];i[g[0]]&&i[g[1]]&&d.push([f[g[0]],f[g[1]]])}return[d,p]};var n=t(\"edges-to-adjacency-list\")},{\"edges-to-adjacency-list\":171}],468:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=c(t,e);t=r[0];for(var h=(e=r[1]).length,f=(t.length,n(t,e.length)),p=0;p<h;++p)if(f[p].length%2==1)throw new Error(\"planar-graph-to-polyline: graph must be manifold\");var d=i(t,e);for(var g=(d=d.filter(function(t){for(var r=t.length,n=[0],i=0;i<r;++i){var a=e[t[i]],l=e[t[(i+1)%r]],c=o(-a[0],a[1]),u=o(-a[0],l[1]),h=o(l[0],a[1]),f=o(l[0],l[1]);n=s(n,s(s(c,u),s(h,f)))}return n[n.length-1]>0})).length,v=new Array(g),m=new Array(g),p=0;p<g;++p){v[p]=p;var y=new Array(g),x=d[p].map(function(t){return e[t]}),b=a([x]),_=0;t:for(var w=0;w<g;++w)if(y[w]=0,p!==w){for(var k=d[w],T=k.length,A=0;A<T;++A){var M=b(e[k[A]]);if(0!==M){M<0&&(y[w]=1,_+=1);continue t}}y[w]=1,_+=1}m[p]=[_,p,y]}m.sort(function(t,e){return e[0]-t[0]});for(var p=0;p<g;++p)for(var y=m[p],S=y[1],E=y[2],w=0;w<g;++w)E[w]&&(v[w]=S);for(var C=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=[];return e}(g),p=0;p<g;++p)C[p].push(v[p]),C[v[p]].push(p);for(var L={},P=u(h,!1),p=0;p<g;++p)for(var k=d[p],T=k.length,w=0;w<T;++w){var O=k[w],z=k[(w+1)%T],I=Math.min(O,z)+\":\"+Math.max(O,z);if(I in L){var D=L[I];C[D].push(p),C[p].push(D),P[O]=P[z]=!0}else L[I]=p}function R(t){for(var e=t.length,r=0;r<e;++r)if(!P[t[r]])return!1;return!0}for(var F=[],B=u(g,-1),p=0;p<g;++p)v[p]!==p||R(d[p])?B[p]=-1:(F.push(p),B[p]=0);var r=[];for(;F.length>0;){var N=F.pop(),j=C[N];l(j,function(t,e){return t-e});var U,V=j.length,q=B[N];if(0===q){var k=d[N];U=[k]}for(var p=0;p<V;++p){var H=j[p];if(!(B[H]>=0)&&(B[H]=1^q,F.push(H),0===q)){var k=d[H];R(k)||(k.reverse(),U.push(k))}}0===q&&r.push(U)}return r};var n=t(\"edges-to-adjacency-list\"),i=t(\"planar-dual\"),a=t(\"point-in-big-polygon\"),o=t(\"two-product\"),s=t(\"robust-sum\"),l=t(\"uniq\"),c=t(\"./lib/trim-leaves\");function u(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}},{\"./lib/trim-leaves\":467,\"edges-to-adjacency-list\":171,\"planar-dual\":466,\"point-in-big-polygon\":472,\"robust-sum\":515,\"two-product\":543,uniq:547}],469:[function(t,e,r){\"use strict\";e.exports=t(\"./quad\")},{\"./quad\":471}],470:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],471:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"clamp\"),a=t(\"parse-rect\"),o=t(\"array-bounds\"),s=t(\"pick-by-alias\"),l=t(\"defined\"),c=t(\"flatten-vertex-data\"),u=t(\"is-obj\"),h=t(\"dtype\"),f=t(\"math-log2\");function p(t,e){for(var r=e[0],n=e[1],a=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=i((t[2*l]-r)*a,0,1),s[2*l+1]=i((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,\"float64\"),e=s(e,{bounds:\"range bounds dataBox databox\",maxDepth:\"depth maxDepth maxdepth level maxLevel maxlevel levels\",dtype:\"type dtype format out dst output destination\"});var r=l(e.maxDepth,255),i=l(e.bounds,o(t,2));i[0]===i[2]&&i[2]++,i[1]===i[3]&&i[3]++;var d,g=p(t,i),v=t.length>>>1;e.dtype||(e.dtype=\"array\"),\"string\"==typeof e.dtype?d=new(h(e.dtype))(v):e.dtype&&(d=e.dtype,Array.isArray(d)&&(d.length=v));for(var m=0;m<v;++m)d[m]=m;var y=[],x=[],b=[],_=[];!function t(e,n,i,a,o,s){if(!a.length)return null;var l=y[o]||(y[o]=[]);var c=b[o]||(b[o]=[]);var u=x[o]||(x[o]=[]);var h=l.length;o++;if(o>r){for(var f=0;f<a.length;f++)l.push(a[f]),c.push(s),u.push(null,null,null,null);return h}l.push(a[0]);c.push(s);if(a.length<=1)return u.push(null,null,null,null),h;var p=.5*i;var d=e+p,v=n+p;var m=[],_=[],w=[],k=[];for(var T=1,A=a.length;T<A;T++){var M=a[T],S=g[2*M],E=g[2*M+1];S<d?E<v?m.push(M):_.push(M):E<v?w.push(M):k.push(M)}s<<=2;u.push(t(e,n,p,m,o,s),t(e,v,p,_,o,s+1),t(d,n,p,w,o,s+2),t(d,v,p,k,o,s+3));return h}(0,0,1,d,0,1);for(var w=0,k=0;k<y.length;k++){var T=y[k];if(d.set)d.set(T,w);else for(var A=0,M=T.length;A<M;A++)d[A+w]=T[A];var S=w+y[k].length;_[k]=[w,S],w=S}return d.range=function(){var e,r=[],o=arguments.length;for(;o--;)r[o]=arguments[o];if(u(r[r.length-1])){var c=r.pop();r.length||null==c.x&&null==c.l&&null==c.left||(r=[c],e={}),e=s(c,{level:\"level maxLevel\",d:\"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize\",lod:\"lod details ranges offsets\"})}else e={};r.length||(r=i);var h=a.apply(void 0,r),d=[Math.min(h.x,h.x+h.width),Math.min(h.y,h.y+h.height),Math.max(h.x,h.x+h.width),Math.max(h.y,h.y+h.height)],g=d[0],v=d[1],m=d[2],w=d[3],k=p([g,v,m,w],i),T=k[0],A=k[1],M=k[2],S=k[3],C=l(e.level,y.length);if(null!=e.d){var L;\"number\"==typeof e.d?L=[e.d,e.d]:e.d.length&&(L=e.d),C=Math.min(Math.max(Math.ceil(-f(Math.abs(L[0])/(i[2]-i[0]))),Math.ceil(-f(Math.abs(L[1])/(i[3]-i[1])))),C)}if(C=Math.min(C,y.length),e.lod)return function(t,e,r,i,a){for(var o=[],s=0;s<a;s++){var l=b[s],c=_[s][0],u=E(t,e,s),h=E(r,i,s),f=n.ge(l,u),p=n.gt(l,h,f,l.length-1);o[s]=[f+c,p+c]}return o}(T,A,M,S,C);var P=[];return function e(r,n,i,a,o,s){if(null!==o&&null!==s){var l=r+i,c=n+i;if(!(T>l||A>c||M<r||S<n||a>=C||o===s)){var u=y[a];void 0===s&&(s=u.length);for(var h=o;h<s;h++){var f=u[h],p=t[2*f],d=t[2*f+1];p>=g&&p<=m&&d>=v&&d<=w&&P.push(f)}var b=x[a],_=b[4*o+0],k=b[4*o+1],E=b[4*o+2],L=b[4*o+3],O=function(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}(b,o+1),z=.5*i,I=a+1;e(r,n,z,I,_,k||E||L||O),e(r,n+z,z,I,k,E||L||O),e(r+z,n,z,I,E,L||O),e(r+z,n+z,z,I,L,O)}}}(0,0,1,0,0,1),P},d;function E(t,e,r){for(var n=1,i=.5,a=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<i?e<a?0:1:e<a?2:3,o*=.5,i+=t<i?-o:o,a+=e<a?-o:o;return n}}},{\"array-bounds\":65,\"binary-search-bounds\":470,clamp:115,defined:164,dtype:169,\"flatten-vertex-data\":227,\"is-obj\":421,\"math-log2\":432,\"parse-rect\":459,\"pick-by-alias\":465}],472:[function(t,e,r){e.exports=function(t){for(var e=t.length,r=[],a=[],s=0;s<e;++s)for(var u=t[s],h=u.length,f=h-1,p=0;p<h;f=p++){var d=u[f],g=u[p];d[0]===g[0]?a.push([d,g]):r.push([d,g])}if(0===r.length)return 0===a.length?c:(v=l(a),function(t){return v(t[0],t[1])?0:1});var v;var m=i(r),y=function(t,e){return function(r){var i=o.le(e,r[0]);if(i<0)return 1;var a=t[i];if(!a){if(!(i>0&&e[i]===r[0]))return 1;a=t[i-1]}for(var s=1;a;){var l=a.key,c=n(r,l[0],l[1]);if(l[0][0]<l[1][0])if(c<0)a=a.left;else{if(!(c>0))return 0;s=-1,a=a.right}else if(c>0)a=a.left;else{if(!(c<0))return 0;s=1,a=a.right}}return s}}(m.slabs,m.coordinates);return 0===a.length?y:function(t,e){return function(r){return t(r[0],r[1])?0:e(r)}}(l(a),y)};var n=t(\"robust-orientation\")[3],i=t(\"slab-decomposition\"),a=t(\"interval-tree-1d\"),o=t(\"binary-search-bounds\");function s(){return!0}function l(t){for(var e={},r=0;r<t.length;++r){var n=t[r],i=n[0][0],o=n[0][1],l=n[1][1],c=[Math.min(o,l),Math.max(o,l)];i in e?e[i].push(c):e[i]=[c]}var u={},h=Object.keys(e);for(r=0;r<h.length;++r){var f=e[h[r]];u[h[r]]=a(f)}return function(t){return function(e,r){var n=t[e];return!!n&&!!n.queryPoint(r,s)}}(u)}function c(t){return 1}},{\"binary-search-bounds\":91,\"interval-tree-1d\":414,\"robust-orientation\":510,\"slab-decomposition\":526}],473:[function(t,e,r){var n,i=t(\"./lib/build-log\"),a=t(\"./lib/epsilon\"),o=t(\"./lib/intersecter\"),s=t(\"./lib/segment-chainer\"),l=t(\"./lib/segment-selector\"),c=t(\"./lib/geojson\"),u=!1,h=a();function f(t,e,r){var i=n.segments(t),a=n.segments(e),o=r(n.combine(i,a));return n.polygon(o)}n={buildLog:function(t){return!0===t?u=i():!1===t&&(u=!1),!1!==u&&u.list},epsilon:function(t){return h.epsilon(t)},segments:function(t){var e=o(!0,h,u);return t.regions.forEach(e.addRegion),{segments:e.calculate(t.inverted),inverted:t.inverted}},combine:function(t,e){return{combined:o(!1,h,u).calculate(t.segments,t.inverted,e.segments,e.inverted),inverted1:t.inverted,inverted2:e.inverted}},selectUnion:function(t){return{segments:l.union(t.combined,u),inverted:t.inverted1||t.inverted2}},selectIntersect:function(t){return{segments:l.intersect(t.combined,u),inverted:t.inverted1&&t.inverted2}},selectDifference:function(t){return{segments:l.difference(t.combined,u),inverted:t.inverted1&&!t.inverted2}},selectDifferenceRev:function(t){return{segments:l.differenceRev(t.combined,u),inverted:!t.inverted1&&t.inverted2}},selectXor:function(t){return{segments:l.xor(t.combined,u),inverted:t.inverted1!==t.inverted2}},polygon:function(t){return{regions:s(t.segments,h,u),inverted:t.inverted}},polygonFromGeoJSON:function(t){return c.toPolygon(n,t)},polygonToGeoJSON:function(t){return c.fromPolygon(n,h,t)},union:function(t,e){return f(t,e,n.selectUnion)},intersect:function(t,e){return f(t,e,n.selectIntersect)},difference:function(t,e){return f(t,e,n.selectDifference)},differenceRev:function(t,e){return f(t,e,n.selectDifferenceRev)},xor:function(t,e){return f(t,e,n.selectXor)}},\"object\"==typeof window&&(window.PolyBool=n),e.exports=n},{\"./lib/build-log\":474,\"./lib/epsilon\":475,\"./lib/geojson\":476,\"./lib/intersecter\":477,\"./lib/segment-chainer\":479,\"./lib/segment-selector\":480}],474:[function(t,e,r){e.exports=function(){var t,e=0,r=!1;function n(e,r){return t.list.push({type:e,data:r?JSON.parse(JSON.stringify(r)):void 0}),t}return t={list:[],segmentId:function(){return e++},checkIntersection:function(t,e){return n(\"check\",{seg1:t,seg2:e})},segmentChop:function(t,e){return n(\"div_seg\",{seg:t,pt:e}),n(\"chop\",{seg:t,pt:e})},statusRemove:function(t){return n(\"pop_seg\",{seg:t})},segmentUpdate:function(t){return n(\"seg_update\",{seg:t})},segmentNew:function(t,e){return n(\"new_seg\",{seg:t,primary:e})},segmentRemove:function(t){return n(\"rem_seg\",{seg:t})},tempStatus:function(t,e,r){return n(\"temp_status\",{seg:t,above:e,below:r})},rewind:function(t){return n(\"rewind\",{seg:t})},status:function(t,e,r){return n(\"status\",{seg:t,above:e,below:r})},vert:function(e){return e===r?t:(r=e,n(\"vert\",{x:e}))},log:function(t){return\"string\"!=typeof t&&(t=JSON.stringify(t,!1,\"  \")),n(\"log\",{txt:t})},reset:function(){return n(\"reset\")},selected:function(t){return n(\"selected\",{segs:t})},chainStart:function(t){return n(\"chain_start\",{seg:t})},chainRemoveHead:function(t,e){return n(\"chain_rem_head\",{index:t,pt:e})},chainRemoveTail:function(t,e){return n(\"chain_rem_tail\",{index:t,pt:e})},chainNew:function(t,e){return n(\"chain_new\",{pt1:t,pt2:e})},chainMatch:function(t){return n(\"chain_match\",{index:t})},chainClose:function(t){return n(\"chain_close\",{index:t})},chainAddHead:function(t,e){return n(\"chain_add_head\",{index:t,pt:e})},chainAddTail:function(t,e){return n(\"chain_add_tail\",{index:t,pt:e})},chainConnect:function(t,e){return n(\"chain_con\",{index1:t,index2:e})},chainReverse:function(t){return n(\"chain_rev\",{index:t})},chainJoin:function(t,e){return n(\"chain_join\",{index1:t,index2:e})},done:function(){return n(\"done\")}}}},{}],475:[function(t,e,r){e.exports=function(t){\"number\"!=typeof t&&(t=1e-10);var e={epsilon:function(e){return\"number\"==typeof e&&(t=e),t},pointAboveOrOnLine:function(e,r,n){var i=r[0],a=r[1],o=n[0],s=n[1],l=e[0];return(o-i)*(e[1]-a)-(s-a)*(l-i)>=-t},pointBetween:function(e,r,n){var i=e[1]-r[1],a=n[0]-r[0],o=e[0]-r[0],s=n[1]-r[1],l=o*a+i*s;return!(l<t||l-(a*a+s*s)>-t)},pointsSameX:function(e,r){return Math.abs(e[0]-r[0])<t},pointsSameY:function(e,r){return Math.abs(e[1]-r[1])<t},pointsSame:function(t,r){return e.pointsSameX(t,r)&&e.pointsSameY(t,r)},pointsCompare:function(t,r){return e.pointsSameX(t,r)?e.pointsSameY(t,r)?0:t[1]<r[1]?-1:1:t[0]<r[0]?-1:1},pointsCollinear:function(e,r,n){var i=e[0]-r[0],a=e[1]-r[1],o=r[0]-n[0],s=r[1]-n[1];return Math.abs(i*s-o*a)<t},linesIntersect:function(e,r,n,i){var a=r[0]-e[0],o=r[1]-e[1],s=i[0]-n[0],l=i[1]-n[1],c=a*l-o*s;if(Math.abs(c)<t)return!1;var u=e[0]-n[0],h=e[1]-n[1],f=(s*h-l*u)/c,p=(a*h-o*u)/c,d={alongA:0,alongB:0,pt:[e[0]+f*a,e[1]+f*o]};return d.alongA=f<=-t?-2:f<t?-1:f-1<=-t?0:f-1<t?1:2,d.alongB=p<=-t?-2:p<t?-1:p-1<=-t?0:p-1<t?1:2,d},pointInsideRegion:function(e,r){for(var n=e[0],i=e[1],a=r[r.length-1][0],o=r[r.length-1][1],s=!1,l=0;l<r.length;l++){var c=r[l][0],u=r[l][1];u-i>t!=o-i>t&&(a-c)*(i-u)/(o-u)+c-n>t&&(s=!s),a=c,o=u}return s}};return e}},{}],476:[function(t,e,r){var n={toPolygon:function(t,e){function r(e){if(e.length<=0)return t.segments({inverted:!1,regions:[]});function r(e){var r=e.slice(0,e.length-1);return t.segments({inverted:!1,regions:[r]})}for(var n=r(e[0]),i=1;i<e.length;i++)n=t.selectDifference(t.combine(n,r(e[i])));return n}if(\"Polygon\"===e.type)return t.polygon(r(e.coordinates));if(\"MultiPolygon\"===e.type){for(var n=t.segments({inverted:!1,regions:[]}),i=0;i<e.coordinates.length;i++)n=t.selectUnion(t.combine(n,r(e.coordinates[i])));return t.polygon(n)}throw new Error(\"PolyBool: Cannot convert GeoJSON object to PolyBool polygon\")},fromPolygon:function(t,e,r){function n(t,r){return e.pointInsideRegion([.5*(t[0][0]+t[1][0]),.5*(t[0][1]+t[1][1])],r)}function i(t){return{region:t,children:[]}}r=t.polygon(t.segments(r));var a=i(null);function o(t,e){for(var r=0;r<t.children.length;r++){if(n(e,(s=t.children[r]).region))return void o(s,e)}var a=i(e);for(r=0;r<t.children.length;r++){var s;n((s=t.children[r]).region,e)&&(a.children.push(s),t.children.splice(r,1),r--)}t.children.push(a)}for(var s=0;s<r.regions.length;s++){var l=r.regions[s];l.length<3||o(a,l)}function c(t,e){for(var r=0,n=t[t.length-1][0],i=t[t.length-1][1],a=[],o=0;o<t.length;o++){var s=t[o][0],l=t[o][1];a.push([s,l]),r+=l*n-s*i,n=s,i=l}return r<0!==e&&a.reverse(),a.push([a[0][0],a[0][1]]),a}var u=[];function h(t){var e=[c(t.region,!1)];u.push(e);for(var r=0;r<t.children.length;r++)e.push(f(t.children[r]))}function f(t){for(var e=0;e<t.children.length;e++)h(t.children[e]);return c(t.region,!0)}for(s=0;s<a.children.length;s++)h(a.children[s]);return u.length<=0?{type:\"Polygon\",coordinates:[]}:1==u.length?{type:\"Polygon\",coordinates:u[0]}:{type:\"MultiPolygon\",coordinates:u}}};e.exports=n},{}],477:[function(t,e,r){var n=t(\"./linked-list\");e.exports=function(t,e,r){function i(t,e,n){return{id:r?r.segmentId():-1,start:t,end:e,myFill:{above:n.myFill.above,below:n.myFill.below},otherFill:null}}var a=n.create();function o(t,r){a.insertBefore(t,function(n){return function(t,r,n,i,a,o){var s=e.pointsCompare(r,a);return 0!==s?s:e.pointsSame(n,o)?0:t!==i?t?1:-1:e.pointAboveOrOnLine(n,i?a:o,i?o:a)?1:-1}(t.isStart,t.pt,r,n.isStart,n.pt,n.other.pt)<0})}function s(t,e){var r=function(t,e){var r=n.node({isStart:!0,pt:t.start,seg:t,primary:e,other:null,status:null});return o(r,t.end),r}(t,e);return function(t,e,r){var i=n.node({isStart:!1,pt:e.end,seg:e,primary:r,other:t,status:null});t.other=i,o(i,t.pt)}(r,t,e),r}function l(t,e){var n=i(e,t.seg.end,t.seg);return function(t,e){r&&r.segmentChop(t.seg,e),t.other.remove(),t.seg.end=e,t.other.pt=e,o(t.other,t.pt)}(t,e),s(n,t.primary)}function c(i,o){var s=n.create();function c(t){return s.findTransition(function(r){var n,i,a,o,s,l;return n=t,i=r.ev,a=n.seg.start,o=n.seg.end,s=i.seg.start,l=i.seg.end,(e.pointsCollinear(a,s,l)?e.pointsCollinear(o,s,l)?1:e.pointAboveOrOnLine(o,s,l)?1:-1:e.pointAboveOrOnLine(a,s,l)?1:-1)>0})}function u(t,n){var i=t.seg,a=n.seg,o=i.start,s=i.end,c=a.start,u=a.end;r&&r.checkIntersection(i,a);var h=e.linesIntersect(o,s,c,u);if(!1===h){if(!e.pointsCollinear(o,s,c))return!1;if(e.pointsSame(o,u)||e.pointsSame(s,c))return!1;var f=e.pointsSame(o,c),p=e.pointsSame(s,u);if(f&&p)return n;var d=!f&&e.pointBetween(o,c,u),g=!p&&e.pointBetween(s,c,u);if(f)return g?l(n,s):l(t,u),n;d&&(p||(g?l(n,s):l(t,u)),l(n,o))}else 0===h.alongA&&(-1===h.alongB?l(t,c):0===h.alongB?l(t,h.pt):1===h.alongB&&l(t,u)),0===h.alongB&&(-1===h.alongA?l(n,o):0===h.alongA?l(n,h.pt):1===h.alongA&&l(n,s));return!1}for(var h=[];!a.isEmpty();){var f=a.getHead();if(r&&r.vert(f.pt[0]),f.isStart){r&&r.segmentNew(f.seg,f.primary);var p=c(f),d=p.before?p.before.ev:null,g=p.after?p.after.ev:null;function v(){if(d){var t=u(f,d);if(t)return t}return!!g&&u(f,g)}r&&r.tempStatus(f.seg,!!d&&d.seg,!!g&&g.seg);var m,y,x=v();if(x)t?(y=null===f.seg.myFill.below||f.seg.myFill.above!==f.seg.myFill.below)&&(x.seg.myFill.above=!x.seg.myFill.above):x.seg.otherFill=f.seg.myFill,r&&r.segmentUpdate(x.seg),f.other.remove(),f.remove();if(a.getHead()!==f){r&&r.rewind(f.seg);continue}t?(y=null===f.seg.myFill.below||f.seg.myFill.above!==f.seg.myFill.below,f.seg.myFill.below=g?g.seg.myFill.above:i,f.seg.myFill.above=y?!f.seg.myFill.below:f.seg.myFill.below):null===f.seg.otherFill&&(m=g?f.primary===g.primary?g.seg.otherFill.above:g.seg.myFill.above:f.primary?o:i,f.seg.otherFill={above:m,below:m}),r&&r.status(f.seg,!!d&&d.seg,!!g&&g.seg),f.other.status=p.insert(n.node({ev:f}))}else{var b=f.status;if(null===b)throw new Error(\"PolyBool: Zero-length segment detected; your epsilon is probably too small or too large\");if(s.exists(b.prev)&&s.exists(b.next)&&u(b.prev.ev,b.next.ev),r&&r.statusRemove(b.ev.seg),b.remove(),!f.primary){var _=f.seg.myFill;f.seg.myFill=f.seg.otherFill,f.seg.otherFill=_}h.push(f.seg)}a.getHead().remove()}return r&&r.done(),h}return t?{addRegion:function(t){for(var n,i,a,o=t[t.length-1],l=0;l<t.length;l++){n=o,o=t[l];var c=e.pointsCompare(n,o);0!==c&&s((i=c<0?n:o,a=c<0?o:n,{id:r?r.segmentId():-1,start:i,end:a,myFill:{above:null,below:null},otherFill:null}),!0)}},calculate:function(t){return c(t,!1)}}:{calculate:function(t,e,r,n){return t.forEach(function(t){s(i(t.start,t.end,t),!0)}),r.forEach(function(t){s(i(t.start,t.end,t),!1)}),c(e,n)}}}},{\"./linked-list\":478}],478:[function(t,e,r){e.exports={create:function(){var t={root:{root:!0,next:null},exists:function(e){return null!==e&&e!==t.root},isEmpty:function(){return null===t.root.next},getHead:function(){return t.root.next},insertBefore:function(e,r){for(var n=t.root,i=t.root.next;null!==i;){if(r(i))return e.prev=i.prev,e.next=i,i.prev.next=e,void(i.prev=e);n=i,i=i.next}n.next=e,e.prev=n,e.next=null},findTransition:function(e){for(var r=t.root,n=t.root.next;null!==n&&!e(n);)r=n,n=n.next;return{before:r===t.root?null:r,after:n,insert:function(t){return t.prev=r,t.next=n,r.next=t,null!==n&&(n.prev=t),t}}}};return t},node:function(t){return t.prev=null,t.next=null,t.remove=function(){t.prev.next=t.next,t.next&&(t.next.prev=t.prev),t.prev=null,t.next=null},t}}},{}],479:[function(t,e,r){e.exports=function(t,e,r){var n=[],i=[];return t.forEach(function(t){var a=t.start,o=t.end;if(e.pointsSame(a,o))console.warn(\"PolyBool: Warning: Zero-length segment detected; your epsilon is probably too small or too large\");else{r&&r.chainStart(t);for(var s={index:0,matches_head:!1,matches_pt1:!1},l={index:0,matches_head:!1,matches_pt1:!1},c=s,u=0;u<n.length;u++){var h=(v=n[u])[0],f=(v[1],v[v.length-1]);if(v[v.length-2],e.pointsSame(h,a)){if(T(u,!0,!0))break}else if(e.pointsSame(h,o)){if(T(u,!0,!1))break}else if(e.pointsSame(f,a)){if(T(u,!1,!0))break}else if(e.pointsSame(f,o)&&T(u,!1,!1))break}if(c===s)return n.push([a,o]),void(r&&r.chainNew(a,o));if(c===l){r&&r.chainMatch(s.index);var p=s.index,d=s.matches_pt1?o:a,g=s.matches_head,v=n[p],m=g?v[0]:v[v.length-1],y=g?v[1]:v[v.length-2],x=g?v[v.length-1]:v[0],b=g?v[v.length-2]:v[1];return e.pointsCollinear(y,m,d)&&(g?(r&&r.chainRemoveHead(s.index,d),v.shift()):(r&&r.chainRemoveTail(s.index,d),v.pop()),m=y),e.pointsSame(x,d)?(n.splice(p,1),e.pointsCollinear(b,x,m)&&(g?(r&&r.chainRemoveTail(s.index,m),v.pop()):(r&&r.chainRemoveHead(s.index,m),v.shift())),r&&r.chainClose(s.index),void i.push(v)):void(g?(r&&r.chainAddHead(s.index,d),v.unshift(d)):(r&&r.chainAddTail(s.index,d),v.push(d)))}var _=s.index,w=l.index;r&&r.chainConnect(_,w);var k=n[_].length<n[w].length;s.matches_head?l.matches_head?k?(A(_),M(_,w)):(A(w),M(w,_)):M(w,_):l.matches_head?M(_,w):k?(A(_),M(w,_)):(A(w),M(_,w))}function T(t,e,r){return c.index=t,c.matches_head=e,c.matches_pt1=r,c===s?(c=l,!1):(c=null,!0)}function A(t){r&&r.chainReverse(t),n[t].reverse()}function M(t,i){var a=n[t],o=n[i],s=a[a.length-1],l=a[a.length-2],c=o[0],u=o[1];e.pointsCollinear(l,s,c)&&(r&&r.chainRemoveTail(t,s),a.pop(),s=l),e.pointsCollinear(s,c,u)&&(r&&r.chainRemoveHead(i,c),o.shift()),r&&r.chainJoin(t,i),n[t]=a.concat(o),n.splice(i,1)}}),i}},{}],480:[function(t,e,r){function n(t,e,r){var n=[];return t.forEach(function(t){var i=(t.myFill.above?8:0)+(t.myFill.below?4:0)+(t.otherFill&&t.otherFill.above?2:0)+(t.otherFill&&t.otherFill.below?1:0);0!==e[i]&&n.push({id:r?r.segmentId():-1,start:t.start,end:t.end,myFill:{above:1===e[i],below:2===e[i]},otherFill:null})}),r&&r.selected(n),n}var i={union:function(t,e){return n(t,[0,2,1,0,2,2,0,0,1,0,1,0,0,0,0,0],e)},intersect:function(t,e){return n(t,[0,0,0,0,0,2,0,2,0,0,1,1,0,2,1,0],e)},difference:function(t,e){return n(t,[0,0,0,0,2,0,2,0,1,1,0,0,0,1,2,0],e)},differenceRev:function(t,e){return n(t,[0,2,1,0,0,0,1,1,0,2,0,2,0,0,0,0],e)},xor:function(t,e){return n(t,[0,2,1,0,2,0,0,1,1,0,0,2,0,1,2,0],e)}};e.exports=i},{}],481:[function(t,e,r){\"use strict\";var n=new Float64Array(4),i=new Float64Array(4),a=new Float64Array(4);e.exports=function(t,e,r,o,s){n.length<o.length&&(n=new Float64Array(o.length),i=new Float64Array(o.length),a=new Float64Array(o.length));for(var l=0;l<o.length;++l)n[l]=t[l]-o[l],i[l]=e[l]-t[l],a[l]=r[l]-t[l];var c=0,u=0,h=0,f=0,p=0,d=0;for(l=0;l<o.length;++l){var g=i[l],v=a[l],m=n[l];c+=g*g,u+=g*v,h+=v*v,f+=m*g,p+=m*v,d+=m*m}var y,x,b,_,w,k=Math.abs(c*h-u*u),T=u*p-h*f,A=u*f-c*p;if(T+A<=k)if(T<0)A<0&&f<0?(A=0,-f>=c?(T=1,y=c+2*f+d):y=f*(T=-f/c)+d):(T=0,p>=0?(A=0,y=d):-p>=h?(A=1,y=h+2*p+d):y=p*(A=-p/h)+d);else if(A<0)A=0,f>=0?(T=0,y=d):-f>=c?(T=1,y=c+2*f+d):y=f*(T=-f/c)+d;else{var M=1/k;y=(T*=M)*(c*T+u*(A*=M)+2*f)+A*(u*T+h*A+2*p)+d}else T<0?(b=h+p)>(x=u+f)?(_=b-x)>=(w=c-2*u+h)?(T=1,A=0,y=c+2*f+d):y=(T=_/w)*(c*T+u*(A=1-T)+2*f)+A*(u*T+h*A+2*p)+d:(T=0,b<=0?(A=1,y=h+2*p+d):p>=0?(A=0,y=d):y=p*(A=-p/h)+d):A<0?(b=c+f)>(x=u+p)?(_=b-x)>=(w=c-2*u+h)?(A=1,T=0,y=h+2*p+d):y=(T=1-(A=_/w))*(c*T+u*A+2*f)+A*(u*T+h*A+2*p)+d:(A=0,b<=0?(T=1,y=c+2*f+d):f>=0?(T=0,y=d):y=f*(T=-f/c)+d):(_=h+p-u-f)<=0?(T=0,A=1,y=h+2*p+d):_>=(w=c-2*u+h)?(T=1,A=0,y=c+2*f+d):y=(T=_/w)*(c*T+u*(A=1-T)+2*f)+A*(u*T+h*A+2*p)+d;var S=1-T-A;for(l=0;l<o.length;++l)s[l]=S*t[l]+T*e[l]+A*r[l];return y<0?0:y}},{}],482:[function(t,e,r){var n,i,a=e.exports={};function o(){throw new Error(\"setTimeout has not been defined\")}function s(){throw new Error(\"clearTimeout has not been defined\")}function l(t){if(n===setTimeout)return setTimeout(t,0);if((n===o||!n)&&setTimeout)return n=setTimeout,setTimeout(t,0);try{return n(t,0)}catch(e){try{return n.call(null,t,0)}catch(e){return n.call(this,t,0)}}}!function(){try{n=\"function\"==typeof setTimeout?setTimeout:o}catch(t){n=o}try{i=\"function\"==typeof clearTimeout?clearTimeout:s}catch(t){i=s}}();var c,u=[],h=!1,f=-1;function p(){h&&c&&(h=!1,c.length?u=c.concat(u):f=-1,u.length&&d())}function d(){if(!h){var t=l(p);h=!0;for(var e=u.length;e;){for(c=u,u=[];++f<e;)c&&c[f].run();f=-1,e=u.length}c=null,h=!1,function(t){if(i===clearTimeout)return clearTimeout(t);if((i===s||!i)&&clearTimeout)return i=clearTimeout,clearTimeout(t);try{i(t)}catch(e){try{return i.call(null,t)}catch(e){return i.call(this,t)}}}(t)}}function g(t,e){this.fun=t,this.array=e}function v(){}a.nextTick=function(t){var e=new Array(arguments.length-1);if(arguments.length>1)for(var r=1;r<arguments.length;r++)e[r-1]=arguments[r];u.push(new g(t,e)),1!==u.length||h||l(d)},g.prototype.run=function(){this.fun.apply(null,this.array)},a.title=\"browser\",a.browser=!0,a.env={},a.argv=[],a.version=\"\",a.versions={},a.on=v,a.addListener=v,a.once=v,a.off=v,a.removeListener=v,a.removeAllListeners=v,a.emit=v,a.prependListener=v,a.prependOnceListener=v,a.listeners=function(t){return[]},a.binding=function(t){throw new Error(\"process.binding is not supported\")},a.cwd=function(){return\"/\"},a.chdir=function(t){throw new Error(\"process.chdir is not supported\")},a.umask=function(){return 0}},{}],483:[function(t,e,r){e.exports=t(\"gl-quat/slerp\")},{\"gl-quat/slerp\":293}],484:[function(t,e,r){(function(r){for(var n=t(\"performance-now\"),i=\"undefined\"==typeof window?r:window,a=[\"moz\",\"webkit\"],o=\"AnimationFrame\",s=i[\"request\"+o],l=i[\"cancel\"+o]||i[\"cancelRequest\"+o],c=0;!s&&c<a.length;c++)s=i[a[c]+\"Request\"+o],l=i[a[c]+\"Cancel\"+o]||i[a[c]+\"CancelRequest\"+o];if(!s||!l){var u=0,h=0,f=[];s=function(t){if(0===f.length){var e=n(),r=Math.max(0,1e3/60-(e-u));u=r+e,setTimeout(function(){var t=f.slice(0);f.length=0;for(var e=0;e<t.length;e++)if(!t[e].cancelled)try{t[e].callback(u)}catch(t){setTimeout(function(){throw t},0)}},Math.round(r))}return f.push({handle:++h,callback:t,cancelled:!1}),h},l=function(t){for(var e=0;e<f.length;e++)f[e].handle===t&&(f[e].cancelled=!0)}}e.exports=function(t){return s.call(i,t)},e.exports.cancel=function(){l.apply(i,arguments)},e.exports.polyfill=function(t){t||(t=i),t.requestAnimationFrame=s,t.cancelAnimationFrame=l}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"performance-now\":462}],485:[function(t,e,r){\"use strict\";var n=t(\"big-rat/add\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/add\":75}],486:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t.length),r=0;r<t.length;++r)e[r]=n(t[r]);return e};var n=t(\"big-rat\")},{\"big-rat\":78}],487:[function(t,e,r){\"use strict\";var n=t(\"big-rat\"),i=t(\"big-rat/mul\");e.exports=function(t,e){for(var r=n(e),a=t.length,o=new Array(a),s=0;s<a;++s)o[s]=i(t[s],r);return o}},{\"big-rat\":78,\"big-rat/mul\":87}],488:[function(t,e,r){\"use strict\";var n=t(\"big-rat/sub\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/sub\":89}],489:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"compare-oriented-cell\"),a=t(\"cell-orientation\");e.exports=function(t){t.sort(i);for(var e=t.length,r=0,o=0;o<e;++o){var s=t[o],l=a(s);if(0!==l){if(r>0){var c=t[r-1];if(0===n(s,c)&&a(c)!==l){r-=1;continue}}t[r++]=s}}return t.length=r,t}},{\"cell-orientation\":112,\"compare-cell\":128,\"compare-oriented-cell\":129}],490:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\"),i=t(\"color-normalize\"),a=t(\"update-diff\"),o=t(\"pick-by-alias\"),s=t(\"object-assign\"),l=t(\"flatten-vertex-data\"),c=t(\"to-float32\"),u=c.float32,h=c.fract32;e.exports=function(t,e){\"function\"==typeof t?(e||(e={}),e.regl=t):e=t;e.length&&(e.positions=e);if(!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");var r,c,p,d,g,v,m=t._gl,y={color:\"black\",capSize:5,lineWidth:1,opacity:1,viewport:null,range:null,offset:0,count:0,bounds:null,positions:[],errors:[]},x=[];return d=t.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array(0)}),c=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),p=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),g=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),v=t.buffer({usage:\"static\",type:\"float\",data:f}),k(e),r=t({vert:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tattribute vec2 position, positionFract;\\n\\t\\tattribute vec4 error;\\n\\t\\tattribute vec4 color;\\n\\n\\t\\tattribute vec2 direction, lineOffset, capOffset;\\n\\n\\t\\tuniform vec4 viewport;\\n\\t\\tuniform float lineWidth, capSize;\\n\\t\\tuniform vec2 scale, scaleFract, translate, translateFract;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tfragColor = color / 255.;\\n\\n\\t\\t\\tvec2 pixelOffset = lineWidth * lineOffset + (capSize + lineWidth) * capOffset;\\n\\n\\t\\t\\tvec2 dxy = -step(.5, direction.xy) * error.xz + step(direction.xy, vec2(-.5)) * error.yw;\\n\\n\\t\\t\\tvec2 position = position + dxy;\\n\\n\\t\\t\\tvec2 pos = (position + translate) * scale\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scale\\n\\t\\t\\t\\t+ (position + translate) * scaleFract\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scaleFract;\\n\\n\\t\\t\\tpos += pixelOffset / viewport.zw;\\n\\n\\t\\t\\tgl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\t\\t}\\n\\t\\t\",frag:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tuniform float opacity;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tgl_FragColor = fragColor;\\n\\t\\t\\tgl_FragColor.a *= opacity;\\n\\t\\t}\\n\\t\\t\",uniforms:{range:t.prop(\"range\"),lineWidth:t.prop(\"lineWidth\"),capSize:t.prop(\"capSize\"),opacity:t.prop(\"opacity\"),scale:t.prop(\"scale\"),translate:t.prop(\"translate\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{color:{buffer:d,offset:function(t,e){return 4*e.offset},divisor:1},position:{buffer:c,offset:function(t,e){return 8*e.offset},divisor:1},positionFract:{buffer:p,offset:function(t,e){return 8*e.offset},divisor:1},error:{buffer:g,offset:function(t,e){return 16*e.offset},divisor:1},direction:{buffer:v,stride:24,offset:0},lineOffset:{buffer:v,stride:24,offset:8},capOffset:{buffer:v,stride:24,offset:16}},primitive:\"triangles\",blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:!1,instances:t.prop(\"count\"),count:f.length}),s(b,{update:k,draw:_,destroy:T,regl:t,gl:m,canvas:m.canvas,groups:x}),b;function b(t){t?k(t):null===t&&T(),_()}function _(e){if(\"number\"==typeof e)return w(e);e&&!Array.isArray(e)&&(e=[e]),t._refresh(),x.forEach(function(t,r){t&&(e&&(e[r]?t.draw=!0:t.draw=!1),t.draw?w(r):t.draw=!0)})}function w(t){\"number\"==typeof t&&(t=x[t]),null!=t&&t&&t.count&&t.color&&t.opacity&&t.positions&&t.positions.length>1&&(t.scaleRatio=[t.scale[0]*t.viewport.width,t.scale[1]*t.viewport.height],r(t),t.after&&t.after(t))}function k(t){if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var e=0,r=0;if(b.groups=x=t.map(function(t,c){var u=x[c];return t?(\"function\"==typeof t?t={after:t}:\"number\"==typeof t[0]&&(t={positions:t}),t=o(t,{color:\"color colors fill\",capSize:\"capSize cap capsize cap-size\",lineWidth:\"lineWidth line-width width line thickness\",opacity:\"opacity alpha\",range:\"range dataBox\",viewport:\"viewport viewBox\",errors:\"errors error\",positions:\"positions position data points\"}),u||(x[c]=u={id:c,scale:null,translate:null,scaleFract:null,translateFract:null,draw:!0},t=s({},y,t)),a(u,t,[{lineWidth:function(t){return.5*+t},capSize:function(t){return.5*+t},opacity:parseFloat,errors:function(t){return t=l(t),r+=t.length,t},positions:function(t,r){return t=l(t,\"float64\"),r.count=Math.floor(t.length/2),r.bounds=n(t,2),r.offset=e,e+=r.count,t}},{color:function(t,e){var r=e.count;if(t||(t=\"transparent\"),!Array.isArray(t)||\"number\"==typeof t[0]){var n=t;t=Array(r);for(var a=0;a<r;a++)t[a]=n}if(t.length<r)throw Error(\"Not enough colors\");for(var o=new Uint8Array(4*r),s=0;s<r;s++){var l=i(t[s],\"uint8\");o.set(l,4*s)}return o},range:function(t,e,r){var n=e.bounds;return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=h(e.scale),e.translateFract=h(e.translate),t},viewport:function(t){var e;return Array.isArray(t)?e={x:t[0],y:t[1],width:t[2]-t[0],height:t[3]-t[1]}:t?(e={x:t.x||t.left||0,y:t.y||t.top||0},t.right?e.width=t.right-e.x:e.width=t.w||t.width||0,t.bottom?e.height=t.bottom-e.y:e.height=t.h||t.height||0):e={x:0,y:0,width:m.drawingBufferWidth,height:m.drawingBufferHeight},e}}]),u):u}),e||r){var f=x.reduce(function(t,e,r){return t+(e?e.count:0)},0),v=new Float64Array(2*f),_=new Uint8Array(4*f),w=new Float32Array(4*f);x.forEach(function(t,e){if(t){var r=t.positions,n=t.count,i=t.offset,a=t.color,o=t.errors;n&&(_.set(a,4*i),w.set(o,4*i),v.set(r,2*i))}}),c(u(v)),p(h(v)),d(_),g(w)}}}function T(){c.destroy(),p.destroy(),d.destroy(),g.destroy(),v.destroy()}};var f=[[1,0,0,1,0,0],[1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,1,0,0],[1,0,0,1,0,0],[1,0,-1,0,0,1],[1,0,-1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,1],[1,0,-1,0,0,1],[-1,0,-1,0,0,1],[-1,0,-1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,1],[-1,0,-1,0,0,1],[0,1,1,0,0,0],[0,1,-1,0,0,0],[0,-1,-1,0,0,0],[0,-1,-1,0,0,0],[0,1,1,0,0,0],[0,-1,1,0,0,0],[0,1,0,-1,1,0],[0,1,0,-1,-1,0],[0,1,0,1,-1,0],[0,1,0,1,1,0],[0,1,0,-1,1,0],[0,1,0,1,-1,0],[0,-1,0,-1,1,0],[0,-1,0,-1,-1,0],[0,-1,0,1,-1,0],[0,-1,0,1,1,0],[0,-1,0,-1,1,0],[0,-1,0,1,-1,0]]},{\"array-bounds\":65,\"color-normalize\":120,\"flatten-vertex-data\":227,\"object-assign\":454,\"pick-by-alias\":465,\"to-float32\":538,\"update-diff\":549}],491:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\"),i=t(\"array-bounds\"),a=t(\"object-assign\"),o=t(\"glslify\"),s=t(\"pick-by-alias\"),l=t(\"flatten-vertex-data\"),c=t(\"earcut\"),u=t(\"array-normalize\"),h=t(\"to-float32\"),f=h.float32,p=h.fract32,d=t(\"es6-weak-map\"),g=t(\"parse-rect\");function v(t,e){if(!(this instanceof v))return new v(t,e);if(\"function\"==typeof t?(e||(e={}),e.regl=t):e=t,e.length&&(e.positions=e),!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");this.gl=t._gl,this.regl=t,this.passes=[],this.shaders=v.shaders.has(t)?v.shaders.get(t):v.shaders.set(t,v.createShaders(t)).get(t),this.update(e)}e.exports=v,v.dashMult=2,v.maxPatternLength=256,v.precisionThreshold=3e6,v.maxPoints=1e4,v.maxLines=2048,v.shaders=new d,v.createShaders=function(t){var e,r=t.buffer({usage:\"static\",type:\"float\",data:[0,1,0,0,1,1,1,0]}),n={primitive:\"triangle strip\",instances:t.prop(\"count\"),count:4,offset:0,uniforms:{miterMode:function(t,e){return\"round\"===e.join?2:1},miterLimit:t.prop(\"miterLimit\"),scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),thickness:t.prop(\"thickness\"),dashPattern:t.prop(\"dashTexture\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),dashSize:t.prop(\"dashLength\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]},depth:t.prop(\"depth\")},blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:function(t,e){return!e.overlay}},stencil:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\")},i=t(a({vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, aCoordFract, bCoordFract;\\nattribute vec4 color;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvec2 project(vec2 position, vec2 positionFract, vec2 scale, vec2 scaleFract, vec2 translate, vec2 translateFract) {\\n\\t// the order is important\\n\\treturn position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n}\\n\\nvoid main() {\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineOffset = lineTop * 2. - 1.;\\n\\n\\tvec2 diff = (bCoord + bCoordFract - aCoord - aCoordFract);\\n\\ttangent = normalize(diff * scale * viewport.zw);\\n\\tvec2 normal = vec2(-tangent.y, tangent.x);\\n\\n\\tvec2 position = project(aCoord, aCoordFract, scale, scaleFract, translate, translateFract) * lineStart\\n\\t\\t+ project(bCoord, bCoordFract, scale, scaleFract, translate, translateFract) * lineEnd\\n\\n\\t\\t+ thickness * normal * .5 * lineOffset / viewport.zw;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\n\\nuniform float dashSize, pixelRatio, thickness, opacity, id;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvoid main() {\\n\\tfloat alpha = 1.;\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},aCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8,divisor:1},bCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:16,divisor:1},color:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1}}},n));try{e=t(a({cull:{enable:!0,face:\"back\"},vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, nextCoord, prevCoord;\\nattribute vec4 aColor, bColor;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, translate;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\nuniform float miterLimit, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 tangent;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nconst float REVERSE_THRESHOLD = -.875;\\nconst float MIN_DIFF = 1e-6;\\n\\n// TODO: possible optimizations: avoid overcalculating all for vertices and calc just one instead\\n// TODO: precalculate dot products, normalize things beforehead etc.\\n// TODO: refactor to rectangular algorithm\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nbool isNaN( float val ){\\n  return ( val < 0.0 || 0.0 < val || val == 0.0 ) ? false : true;\\n}\\n\\nvoid main() {\\n\\tvec2 aCoord = aCoord, bCoord = bCoord, prevCoord = prevCoord, nextCoord = nextCoord;\\n\\n  vec2 adjustedScale;\\n  adjustedScale.x = (abs(scale.x) < MIN_DIFF) ? MIN_DIFF : scale.x;\\n  adjustedScale.y = (abs(scale.y) < MIN_DIFF) ? MIN_DIFF : scale.y;\\n\\n  vec2 scaleRatio = adjustedScale * viewport.zw;\\n\\tvec2 normalWidth = thickness / scaleRatio;\\n\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineBot = 1. - lineTop;\\n\\n\\tfragColor = (lineStart * aColor + lineEnd * bColor) / 255.;\\n\\n\\tif (isNaN(aCoord.x) || isNaN(aCoord.y) || isNaN(bCoord.x) || isNaN(bCoord.y)) return;\\n\\n\\tif (aCoord == prevCoord) prevCoord = aCoord + normalize(bCoord - aCoord);\\n\\tif (bCoord == nextCoord) nextCoord = bCoord - normalize(bCoord - aCoord);\\n\\n\\tvec2 prevDiff = aCoord - prevCoord;\\n\\tvec2 currDiff = bCoord - aCoord;\\n\\tvec2 nextDiff = nextCoord - bCoord;\\n\\n\\tvec2 prevTangent = normalize(prevDiff * scaleRatio);\\n\\tvec2 currTangent = normalize(currDiff * scaleRatio);\\n\\tvec2 nextTangent = normalize(nextDiff * scaleRatio);\\n\\n\\tvec2 prevNormal = vec2(-prevTangent.y, prevTangent.x);\\n\\tvec2 currNormal = vec2(-currTangent.y, currTangent.x);\\n\\tvec2 nextNormal = vec2(-nextTangent.y, nextTangent.x);\\n\\n\\tvec2 startJoinDirection = normalize(prevTangent - currTangent);\\n\\tvec2 endJoinDirection = normalize(currTangent - nextTangent);\\n\\n\\t// collapsed/unidirectional segment cases\\n\\t// FIXME: there should be more elegant solution\\n\\tvec2 prevTanDiff = abs(prevTangent - currTangent);\\n\\tvec2 nextTanDiff = abs(nextTangent - currTangent);\\n\\tif (max(prevTanDiff.x, prevTanDiff.y) < MIN_DIFF) {\\n\\t\\tstartJoinDirection = currNormal;\\n\\t}\\n\\tif (max(nextTanDiff.x, nextTanDiff.y) < MIN_DIFF) {\\n\\t\\tendJoinDirection = currNormal;\\n\\t}\\n\\tif (aCoord == bCoord) {\\n\\t\\tendJoinDirection = startJoinDirection;\\n\\t\\tcurrNormal = prevNormal;\\n\\t\\tcurrTangent = prevTangent;\\n\\t}\\n\\n\\ttangent = currTangent;\\n\\n\\t//calculate join shifts relative to normals\\n\\tfloat startJoinShift = dot(currNormal, startJoinDirection);\\n\\tfloat endJoinShift = dot(currNormal, endJoinDirection);\\n\\n\\tfloat startMiterRatio = abs(1. / startJoinShift);\\n\\tfloat endMiterRatio = abs(1. / endJoinShift);\\n\\n\\tvec2 startJoin = startJoinDirection * startMiterRatio;\\n\\tvec2 endJoin = endJoinDirection * endMiterRatio;\\n\\n\\tvec2 startTopJoin, startBotJoin, endTopJoin, endBotJoin;\\n\\tstartTopJoin = sign(startJoinShift) * startJoin * .5;\\n\\tstartBotJoin = -startTopJoin;\\n\\n\\tendTopJoin = sign(endJoinShift) * endJoin * .5;\\n\\tendBotJoin = -endTopJoin;\\n\\n\\tvec2 aTopCoord = aCoord + normalWidth * startTopJoin;\\n\\tvec2 bTopCoord = bCoord + normalWidth * endTopJoin;\\n\\tvec2 aBotCoord = aCoord + normalWidth * startBotJoin;\\n\\tvec2 bBotCoord = bCoord + normalWidth * endBotJoin;\\n\\n\\t//miter anti-clipping\\n\\tfloat baClipping = distToLine(bCoord, aCoord, aBotCoord) / dot(normalize(normalWidth * endBotJoin), normalize(normalWidth.yx * vec2(-startBotJoin.y, startBotJoin.x)));\\n\\tfloat abClipping = distToLine(aCoord, bCoord, bTopCoord) / dot(normalize(normalWidth * startBotJoin), normalize(normalWidth.yx * vec2(-endBotJoin.y, endBotJoin.x)));\\n\\n\\t//prevent close to reverse direction switch\\n\\tbool prevReverse = dot(currTangent, prevTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, prevNormal)) * min(length(prevDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\tbool nextReverse = dot(currTangent, nextTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, nextNormal)) * min(length(nextDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\n\\tif (prevReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * startJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / startMiterRatio, 1.);\\n\\t\\taBotCoord = aCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\taTopCoord = aCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!nextReverse && baClipping > 0. && baClipping < length(normalWidth * endBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\tbTopCoord -= normalWidth * endTopJoin;\\n\\t\\tbTopCoord += normalize(endTopJoin * normalWidth) * baClipping;\\n\\t}\\n\\n\\tif (nextReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * endJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / endMiterRatio, 1.);\\n\\t\\tbBotCoord = bCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\tbTopCoord = bCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!prevReverse && abClipping > 0. && abClipping < length(normalWidth * startBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\taBotCoord -= normalWidth * startBotJoin;\\n\\t\\taBotCoord += normalize(startBotJoin * normalWidth) * abClipping;\\n\\t}\\n\\n\\tvec2 aTopPosition = (aTopCoord) * adjustedScale + translate;\\n\\tvec2 aBotPosition = (aBotCoord) * adjustedScale + translate;\\n\\n\\tvec2 bTopPosition = (bTopCoord) * adjustedScale + translate;\\n\\tvec2 bBotPosition = (bBotCoord) * adjustedScale + translate;\\n\\n\\t//position is normalized 0..1 coord on the screen\\n\\tvec2 position = (aTopPosition * lineTop + aBotPosition * lineBot) * lineStart + (bTopPosition * lineTop + bBotPosition * lineBot) * lineEnd;\\n\\n\\tstartCoord = aCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\tendCoord = bCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\n\\tgl_Position = vec4(position  * 2.0 - 1.0, depth, 1);\\n\\n\\tenableStartMiter = step(dot(currTangent, prevTangent), .5);\\n\\tenableEndMiter = step(dot(currTangent, nextTangent), .5);\\n\\n\\t//bevel miter cutoffs\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n\\n\\t//round miter cutoffs\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * abs(dot(startJoinDirection, currNormal)) * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * abs(dot(endJoinDirection, currNormal)) * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\nuniform float dashSize, pixelRatio, thickness, opacity, id, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nvoid main() {\\n\\tfloat alpha = 1., distToStart, distToEnd;\\n\\tfloat cutoff = thickness * .5;\\n\\n\\t//bevel miter\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToStart + 1., 0.), 1.);\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToEnd + 1., 0.), 1.);\\n\\t\\t}\\n\\t}\\n\\n\\t// round miter\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - startCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - endCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\t}\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1},bColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:4,divisor:1},prevCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:0,divisor:1},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},nextCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:24,divisor:1}}},n))}catch(t){e=i}return{fill:t({primitive:\"triangle\",elements:function(t,e){return e.triangles},offset:0,vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position, positionFract;\\n\\nuniform vec4 color;\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio, id;\\nuniform vec4 viewport;\\nuniform float opacity;\\n\\nvarying vec4 fragColor;\\n\\nconst float MAX_LINES = 256.;\\n\\nvoid main() {\\n\\tfloat depth = (MAX_LINES - 4. - id) / (MAX_LINES);\\n\\n\\tvec2 position = position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n\\tfragColor.a *= opacity;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n\\tgl_FragColor = fragColor;\\n}\\n\"]),uniforms:{scale:t.prop(\"scale\"),color:t.prop(\"fill\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{position:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8},positionFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8}},blend:n.blend,depth:{enable:!1},scissor:n.scissor,stencil:n.stencil,viewport:n.viewport}),rect:i,miter:e}},v.defaults={dashes:null,join:\"miter\",miterLimit:1,thickness:10,cap:\"square\",color:\"black\",opacity:1,overlay:!1,viewport:null,range:null,close:!1,fill:null},v.prototype.render=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];e.length&&(t=this).update.apply(t,e),this.draw()},v.prototype.draw=function(){for(var t=this,e=[],r=arguments.length;r--;)e[r]=arguments[r];return(e.length?e:this.passes).forEach(function(e,r){var n;if(e&&Array.isArray(e))return(n=t).draw.apply(n,e);\"number\"==typeof e&&(e=t.passes[e]),e&&e.count>1&&e.opacity&&(t.regl._refresh(),e.fill&&e.triangles&&e.triangles.length>2&&t.shaders.fill(e),e.thickness&&(e.scale[0]*e.viewport.width>v.precisionThreshold||e.scale[1]*e.viewport.height>v.precisionThreshold?t.shaders.rect(e):\"rect\"===e.join||!e.join&&(e.thickness<=2||e.count>=v.maxPoints)?t.shaders.rect(e):t.shaders.miter(e)))}),this},v.prototype.update=function(t){var e=this;if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var r=this.regl,o=this.gl;if(t.forEach(function(t,h){var d=e.passes[h];if(void 0!==t)if(null!==t){if(\"number\"==typeof t[0]&&(t={positions:t}),t=s(t,{positions:\"positions points data coords\",thickness:\"thickness lineWidth lineWidths line-width linewidth width stroke-width strokewidth strokeWidth\",join:\"lineJoin linejoin join type mode\",miterLimit:\"miterlimit miterLimit\",dashes:\"dash dashes dasharray dash-array dashArray\",color:\"color colour stroke colors colours stroke-color strokeColor\",fill:\"fill fill-color fillColor\",opacity:\"alpha opacity\",overlay:\"overlay crease overlap intersect\",close:\"closed close closed-path closePath\",range:\"range dataBox\",viewport:\"viewport viewBox\",hole:\"holes hole hollow\"}),d||(e.passes[h]=d={id:h,scale:null,scaleFract:null,translate:null,translateFract:null,count:0,hole:[],depth:0,dashLength:1,dashTexture:r.texture({channels:1,data:new Uint8Array([255]),width:1,height:1,mag:\"linear\",min:\"linear\"}),colorBuffer:r.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array}),positionBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),positionFractBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array})},t=a({},v.defaults,t)),null!=t.thickness&&(d.thickness=parseFloat(t.thickness)),null!=t.opacity&&(d.opacity=parseFloat(t.opacity)),null!=t.miterLimit&&(d.miterLimit=parseFloat(t.miterLimit)),null!=t.overlay&&(d.overlay=!!t.overlay,h<v.maxLines&&(d.depth=2*(v.maxLines-1-h%v.maxLines)/v.maxLines-1)),null!=t.join&&(d.join=t.join),null!=t.hole&&(d.hole=t.hole),null!=t.fill&&(d.fill=t.fill?n(t.fill,\"uint8\"):null),null!=t.viewport&&(d.viewport=g(t.viewport)),d.viewport||(d.viewport=g([o.drawingBufferWidth,o.drawingBufferHeight])),null!=t.close&&(d.close=t.close),null===t.positions&&(t.positions=[]),t.positions){var m,y;if(t.positions.x&&t.positions.y){var x=t.positions.x,b=t.positions.y;y=d.count=Math.max(x.length,b.length),m=new Float64Array(2*y);for(var _=0;_<y;_++)m[2*_]=x[_],m[2*_+1]=b[_]}else m=l(t.positions,\"float64\"),y=d.count=Math.floor(m.length/2);var w=d.bounds=i(m,2);if(d.fill){for(var k=[],T={},A=0,M=0,S=0,E=d.count;M<E;M++){var C=m[2*M],L=m[2*M+1];isNaN(C)||isNaN(L)||null==C||null==L?(C=m[2*A],L=m[2*A+1],T[M]=A):A=M,k[S++]=C,k[S++]=L}for(var P=c(k,d.hole||[]),O=0,z=P.length;O<z;O++)null!=T[P[O]]&&(P[O]=T[P[O]]);d.triangles=P}var I=new Float64Array(m);u(I,2,w);var D=new Float64Array(2*y+6);d.close?m[0]===m[2*y-2]&&m[1]===m[2*y-1]?(D[0]=I[2*y-4],D[1]=I[2*y-3]):(D[0]=I[2*y-2],D[1]=I[2*y-1]):(D[0]=I[0],D[1]=I[1]),D.set(I,2),d.close?m[0]===m[2*y-2]&&m[1]===m[2*y-1]?(D[2*y+2]=I[2],D[2*y+3]=I[3],d.count-=1):(D[2*y+2]=I[0],D[2*y+3]=I[1],D[2*y+4]=I[2],D[2*y+5]=I[3]):(D[2*y+2]=I[2*y-2],D[2*y+3]=I[2*y-1],D[2*y+4]=I[2*y-2],D[2*y+5]=I[2*y-1]),d.positionBuffer(f(D)),d.positionFractBuffer(p(D))}if(t.range?d.range=t.range:d.range||(d.range=d.bounds),(t.range||t.positions)&&d.count){var R=d.bounds,F=R[2]-R[0],B=R[3]-R[1],N=d.range[2]-d.range[0],j=d.range[3]-d.range[1];d.scale=[F/N,B/j],d.translate=[-d.range[0]/N+R[0]/N||0,-d.range[1]/j+R[1]/j||0],d.scaleFract=p(d.scale),d.translateFract=p(d.translate)}if(t.dashes){var U,V=0;if(!t.dashes||t.dashes.length<2)V=1,U=new Uint8Array([255,255,255,255,255,255,255,255]);else{V=0;for(var q=0;q<t.dashes.length;++q)V+=t.dashes[q];U=new Uint8Array(V*v.dashMult);for(var H=0,G=255,Y=0;Y<2;Y++)for(var W=0;W<t.dashes.length;++W){for(var X=0,Z=t.dashes[W]*v.dashMult*.5;X<Z;++X)U[H++]=G;G^=255}}d.dashLength=V,d.dashTexture({channels:1,data:U,width:U.length,height:1,mag:\"linear\",min:\"linear\"},0,0)}if(t.color){var J=d.count,K=t.color;K||(K=\"transparent\");var $=new Uint8Array(4*J+4);if(Array.isArray(K)&&\"number\"!=typeof K[0]){for(var Q=0;Q<J;Q++){var tt=n(K[Q],\"uint8\");$.set(tt,4*Q)}$.set(n(K[0],\"uint8\"),4*J)}else for(var et=n(K,\"uint8\"),rt=0;rt<J+1;rt++)$.set(et,4*rt);d.colorBuffer({usage:\"dynamic\",type:\"uint8\",data:$})}}else e.passes[h]=null}),t.length<this.passes.length){for(var h=t.length;h<this.passes.length;h++){var d=e.passes[h];d&&(d.colorBuffer.destroy(),d.positionBuffer.destroy(),d.dashTexture.destroy())}this.passes.length=t.length}for(var m=[],y=0;y<this.passes.length;y++)null!==e.passes[y]&&m.push(e.passes[y]);return this.passes=m,this}},v.prototype.destroy=function(){return this.passes.forEach(function(t){t.colorBuffer.destroy(),t.positionBuffer.destroy(),t.dashTexture.destroy()}),this.passes.length=0,this}},{\"array-bounds\":65,\"array-normalize\":66,\"color-normalize\":120,earcut:492,\"es6-weak-map\":493,\"flatten-vertex-data\":227,glslify:409,\"object-assign\":454,\"parse-rect\":459,\"pick-by-alias\":465,\"to-float32\":538}],492:[function(t,e,r){\"use strict\";function n(t,e,r){r=r||2;var n,s,l,c,u,p,g,v=e&&e.length,m=v?e[0]*r:t.length,y=i(t,0,m,r,!0),x=[];if(!y||y.next===y.prev)return x;if(v&&(y=function(t,e,r,n){var o,s,l,c,u,p=[];for(o=0,s=e.length;o<s;o++)l=e[o]*n,c=o<s-1?e[o+1]*n:t.length,(u=i(t,l,c,n,!1))===u.next&&(u.steiner=!0),p.push(d(u));for(p.sort(h),o=0;o<p.length;o++)f(p[o],r),r=a(r,r.next);return r}(t,e,y,r)),t.length>80*r){n=l=t[0],s=c=t[1];for(var b=r;b<m;b+=r)(u=t[b])<n&&(n=u),(p=t[b+1])<s&&(s=p),u>l&&(l=u),p>c&&(c=p);g=0!==(g=Math.max(l-n,c-s))?1/g:0}return o(y,x,r,n,s,g),x}function i(t,e,r,n,i){var a,o;if(i===A(t,e,r,n)>0)for(a=e;a<r;a+=n)o=w(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=w(a,t[a],t[a+1],o);return o&&y(o,o.next)&&(k(o),o=o.next),o}function a(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!y(n,n.next)&&0!==m(n.prev,n,n.next))n=n.next;else{if(k(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function o(t,e,r,n,i,h,f){if(t){!f&&h&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=p(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,h);for(var d,g,v=t;t.prev!==t.next;)if(d=t.prev,g=t.next,h?l(t,n,i,h):s(t))e.push(d.i/r),e.push(t.i/r),e.push(g.i/r),k(t),t=g.next,v=g.next;else if((t=g)===v){f?1===f?o(t=c(t,e,r),e,r,n,i,h,2):2===f&&u(t,e,r,n,i,h):o(a(t),e,r,n,i,h,1);break}}}function s(t){var e=t.prev,r=t,n=t.next;if(m(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(g(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&m(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function l(t,e,r,n){var i=t.prev,a=t,o=t.next;if(m(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,h=p(s,l,e,r,n),f=p(c,u,e,r,n),d=t.prevZ,v=t.nextZ;d&&d.z>=h&&v&&v.z<=f;){if(d!==t.prev&&d!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&m(d.prev,d,d.next)>=0)return!1;if(d=d.prevZ,v!==t.prev&&v!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,v.x,v.y)&&m(v.prev,v,v.next)>=0)return!1;v=v.nextZ}for(;d&&d.z>=h;){if(d!==t.prev&&d!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&m(d.prev,d,d.next)>=0)return!1;d=d.prevZ}for(;v&&v.z<=f;){if(v!==t.prev&&v!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,v.x,v.y)&&m(v.prev,v,v.next)>=0)return!1;v=v.nextZ}return!0}function c(t,e,r){var n=t;do{var i=n.prev,a=n.next.next;!y(i,a)&&x(i,n,n.next,a)&&b(i,a)&&b(a,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(a.i/r),k(n),k(n.next),n=t=a),n=n.next}while(n!==t);return n}function u(t,e,r,n,i,s){var l=t;do{for(var c=l.next.next;c!==l.prev;){if(l.i!==c.i&&v(l,c)){var u=_(l,c);return l=a(l,l.next),u=a(u,u.next),o(l,e,r,n,i,s),void o(u,e,r,n,i,s)}c=c.next}l=l.next}while(l!==t)}function h(t,e){return t.x-e.x}function f(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r.prev;var l,c=r,u=r.x,h=r.y,f=1/0;n=r.next;for(;n!==c;)i>=n.x&&n.x>=u&&i!==n.x&&g(a<h?i:o,a,u,h,a<h?o:i,a,n.x,n.y)&&((l=Math.abs(a-n.y)/(i-n.x))<f||l===f&&n.x>r.x)&&b(n,t)&&(r=n,f=l),n=n.next;return r}(t,e)){var r=_(e,t);a(r,r.next)}}function p(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function d(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function g(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function v(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&x(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&b(t,e)&&b(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)}function m(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function y(t,e){return t.x===e.x&&t.y===e.y}function x(t,e,r,n){return!!(y(t,e)&&y(r,n)||y(t,n)&&y(r,e))||m(t,e,r)>0!=m(t,e,n)>0&&m(r,n,t)>0!=m(r,n,e)>0}function b(t,e){return m(t.prev,t,t.next)<0?m(t,e,t.next)>=0&&m(t,t.prev,e)>=0:m(t,e,t.prev)<0||m(t,t.next,e)<0}function _(t,e){var r=new T(t.i,t.x,t.y),n=new T(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function w(t,e,r,n){var i=new T(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function k(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function T(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function A(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}e.exports=n,e.exports.default=n,n.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(A(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(A(t,c,u,r))}var h=0;for(s=0;s<n.length;s+=3){var f=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;h+=Math.abs((t[f]-t[d])*(t[p+1]-t[f+1])-(t[f]-t[p])*(t[d+1]-t[f+1]))}return 0===o&&0===h?0:Math.abs((h-o)/o)},n.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r}},{}],493:[function(t,e,r){arguments[4][318][0].apply(r,arguments)},{\"./is-implemented\":494,\"./polyfill\":496,dup:318}],494:[function(t,e,r){arguments[4][319][0].apply(r,arguments)},{dup:319}],495:[function(t,e,r){arguments[4][320][0].apply(r,arguments)},{dup:320}],496:[function(t,e,r){arguments[4][321][0].apply(r,arguments)},{\"./is-native-implemented\":495,d:151,dup:321,\"es5-ext/object/is-value\":194,\"es5-ext/object/set-prototype-of\":200,\"es5-ext/object/valid-object\":204,\"es5-ext/object/valid-value\":205,\"es5-ext/string/random-uniq\":210,\"es6-iterator/for-of\":212,\"es6-iterator/get\":213,\"es6-symbol\":219}],497:[function(t,e,r){\"use strict\";function n(t,e){return function(t){if(Array.isArray(t))return t}(t)||function(t,e){var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{n||null==s.return||s.return()}finally{if(i)throw a}}return r}(t,e)||function(){throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")}()}function i(t){return function(t){if(Array.isArray(t)){for(var e=0,r=new Array(t.length);e<t.length;e++)r[e]=t[e];return r}}(t)||function(t){if(Symbol.iterator in Object(t)||\"[object Arguments]\"===Object.prototype.toString.call(t))return Array.from(t)}(t)||function(){throw new TypeError(\"Invalid attempt to spread non-iterable instance\")}()}var a=t(\"color-normalize\"),o=t(\"array-bounds\"),s=t(\"color-id\"),l=t(\"point-cluster\"),c=t(\"object-assign\"),u=t(\"glslify\"),h=t(\"pick-by-alias\"),f=t(\"update-diff\"),p=t(\"flatten-vertex-data\"),d=t(\"is-iexplorer\"),g=t(\"to-float32\"),v=t(\"parse-rect\"),m=y;function y(t,e){var r=this;if(!(this instanceof y))return new y(t,e);\"function\"==typeof t?(e||(e={}),e.regl=t):(e=t,t=null),e&&e.length&&(e.positions=e);var n,i=(t=e.regl)._gl,a=[];this.tooManyColors=d,n=t.texture({data:new Uint8Array(1020),width:255,height:1,type:\"uint8\",format:\"rgba\",wrapS:\"clamp\",wrapT:\"clamp\",mag:\"nearest\",min:\"nearest\"}),c(this,{regl:t,gl:i,groups:[],markerCache:[null],markerTextures:[null],palette:a,paletteIds:{},paletteTexture:n,maxColors:255,maxSize:100,canvas:i.canvas}),this.update(e);var o={uniforms:{pixelRatio:t.context(\"pixelRatio\"),palette:n,paletteSize:function(t,e){return[r.tooManyColors?0:255,n.height]},scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translate:t.prop(\"translate\"),translateFract:t.prop(\"translateFract\"),opacity:t.prop(\"opacity\"),marker:t.prop(\"markerTexture\")},attributes:{x:function(t,e){return e.xAttr||{buffer:e.positionBuffer,stride:8,offset:0}},y:function(t,e){return e.yAttr||{buffer:e.positionBuffer,stride:8,offset:4}},xFract:function(t,e){return e.xAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:0}},yFract:function(t,e){return e.yAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:4}},size:function(t,e){return e.size.length?{buffer:e.sizeBuffer,stride:2,offset:0}:{constant:[Math.round(255*e.size/r.maxSize)]}},borderSize:function(t,e){return e.borderSize.length?{buffer:e.sizeBuffer,stride:2,offset:1}:{constant:[Math.round(255*e.borderSize/r.maxSize)]}},colorId:function(t,e){return e.color.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:0}:{constant:r.tooManyColors?a.slice(4*e.color,4*e.color+4):[e.color]}},borderColorId:function(t,e){return e.borderColor.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:r.tooManyColors?4:2}:{constant:r.tooManyColors?a.slice(4*e.borderColor,4*e.borderColor+4):[e.borderColor]}},isActive:function(t,e){return!0===e.activation?{constant:[1]}:e.activation?e.activation:{constant:[0]}}},blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:{enable:!1},depth:{enable:!1},elements:t.prop(\"elements\"),count:t.prop(\"count\"),offset:t.prop(\"offset\"),primitive:\"points\"},s=c({},o);s.frag=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nuniform sampler2D marker;\\nuniform float pixelRatio, opacity;\\n\\nfloat smoothStep(float x, float y) {\\n  return 1.0 / (1.0 + exp(50.0*(x - y)));\\n}\\n\\nvoid main() {\\n  float dist = texture2D(marker, gl_PointCoord).r, delta = fragWidth;\\n\\n  // max-distance alpha\\n  if (dist < 0.003) discard;\\n\\n  // null-border case\\n  if (fragBorderColorLevel == fragColorLevel || fragBorderColor.a == 0.) {\\n    float colorAmt = smoothstep(.5 - delta, .5 + delta, dist);\\n    gl_FragColor = vec4(fragColor.rgb, colorAmt * fragColor.a * opacity);\\n  }\\n  else {\\n    float borderColorAmt = smoothstep(fragBorderColorLevel - delta, fragBorderColorLevel + delta, dist);\\n    float colorAmt = smoothstep(fragColorLevel - delta, fragColorLevel + delta, dist);\\n\\n    vec4 color = fragBorderColor;\\n    color.a *= borderColorAmt;\\n    color = mix(color, fragColor, colorAmt);\\n    color.a *= opacity;\\n\\n    gl_FragColor = color;\\n  }\\n\\n}\\n\"]),s.vert=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract, paletteSize;\\nuniform float pixelRatio;\\nuniform sampler2D palette;\\n\\nconst float maxSize = 100.;\\nconst float borderLevel = .5;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragPointSize, fragBorderRadius, fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = 2. * size * pixelRatio;\\n  fragPointSize = size * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\n  fragColor = color;\\n  fragBorderColor = borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n\\n  fragBorderColorLevel = clamp(borderLevel - borderLevel * borderSize / size, 0., 1.);\\n  fragColorLevel = clamp(borderLevel + (1. - borderLevel) * borderSize / size, 0., 1.);\\n}\"]),this.drawMarker=t(s);var l=c({},o);l.frag=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\n\\nuniform float opacity;\\nvarying float fragBorderRadius, fragWidth;\\n\\nfloat smoothStep(float edge0, float edge1, float x) {\\n\\tfloat t;\\n\\tt = clamp((x - edge0) / (edge1 - edge0), 0.0, 1.0);\\n\\treturn t * t * (3.0 - 2.0 * t);\\n}\\n\\nvoid main() {\\n\\tfloat radius, alpha = 1.0, delta = fragWidth;\\n\\n\\tradius = length(2.0 * gl_PointCoord.xy - 1.0);\\n\\n\\tif (radius > 1.0 + delta) {\\n\\t\\tdiscard;\\n\\t}\\n\\n\\talpha -= smoothstep(1.0 - delta, 1.0 + delta, radius);\\n\\n\\tfloat borderRadius = fragBorderRadius;\\n\\tfloat ratio = smoothstep(borderRadius - delta, borderRadius + delta, radius);\\n\\tvec4 color = mix(fragColor, fragBorderColor, ratio);\\n\\tcolor.a *= alpha * opacity;\\n\\tgl_FragColor = color;\\n}\\n\"]),l.vert=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio;\\nuniform sampler2D palette;\\nuniform vec2 paletteSize;\\n\\nconst float maxSize = 100.;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragBorderRadius, fragWidth;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  // ignore inactive points\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = (size + borderSize) * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\n  fragBorderRadius = 1. - 2. * borderSize / (size + borderSize);\\n  fragColor = color;\\n  fragBorderColor = borderColor.a == 0. || borderSize == 0. ? vec4(color.rgb, 0.) : borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n}\\n\"]),d&&(l.frag=l.frag.replace(\"smoothstep\",\"smoothStep\"),s.frag=s.frag.replace(\"smoothstep\",\"smoothStep\")),this.drawCircle=t(l)}y.defaults={color:\"black\",borderColor:\"transparent\",borderSize:0,size:12,opacity:1,marker:void 0,viewport:null,range:null,pixelSize:null,count:0,offset:0,bounds:null,positions:[],snap:1e4},y.prototype.render=function(){return arguments.length&&this.update.apply(this,arguments),this.draw(),this},y.prototype.draw=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var i=this.groups;if(1===r.length&&Array.isArray(r[0])&&(null===r[0][0]||Array.isArray(r[0][0]))&&(r=r[0]),this.regl._refresh(),r.length)for(var a=0;a<r.length;a++)this.drawItem(a,r[a]);else i.forEach(function(e,r){t.drawItem(r)});return this},y.prototype.drawItem=function(t,e){var r=this.groups,n=r[t];if(\"number\"==typeof e&&(t=e,n=r[e],e=null),n&&n.count&&n.opacity){n.activation[0]&&this.drawCircle(this.getMarkerDrawOptions(0,n,e));for(var a=[],o=1;o<n.activation.length;o++)n.activation[o]&&(!0===n.activation[o]||n.activation[o].data.length)&&a.push.apply(a,i(this.getMarkerDrawOptions(o,n,e)));a.length&&this.drawMarker(a)}},y.prototype.getMarkerDrawOptions=function(t,e,r){var i=e.range,a=e.tree,o=e.viewport,s=e.activation,l=e.selectionBuffer,u=e.count;this.regl;if(!a)return r?[c({},e,{markerTexture:this.markerTextures[t],activation:s[t],count:r.length,elements:r,offset:0})]:[c({},e,{markerTexture:this.markerTextures[t],activation:s[t],offset:0})];var h=[],f=a.range(i,{lod:!0,px:[(i[2]-i[0])/o.width,(i[3]-i[1])/o.height]});if(r){for(var p=s[t].data,d=new Uint8Array(u),g=0;g<r.length;g++){var v=r[g];d[v]=p?p[v]:1}l.subdata(d)}for(var m=f.length;m--;){var y=n(f[m],2),x=y[0],b=y[1];h.push(c({},e,{markerTexture:this.markerTextures[t],activation:r?l:s[t],offset:x,count:b-x}))}return h},y.prototype.update=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];if(r.length){1===r.length&&Array.isArray(r[0])&&(r=r[0]);var i=this.groups,a=this.gl,s=this.regl,u=this.maxSize,d=this.maxColors,m=this.palette;this.groups=i=r.map(function(e,r){var n=i[r];if(void 0===e)return n;null===e?e={positions:null}:\"function\"==typeof e?e={ondraw:e}:\"number\"==typeof e[0]&&(e={positions:e}),null===(e=h(e,{positions:\"positions data points\",snap:\"snap cluster lod tree\",size:\"sizes size radius\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",color:\"colors color fill fill-color fillColor\",borderColor:\"borderColors borderColor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range dataBox databox\",viewport:\"viewport viewPort viewBox viewbox\",opacity:\"opacity alpha transparency\",bounds:\"bound bounds boundaries limits\",tooManyColors:\"tooManyColors palette paletteMode optimizePalette enablePalette\"})).positions&&(e.positions=[]),null!=e.tooManyColors&&(t.tooManyColors=e.tooManyColors),n||(i[r]=n={id:r,scale:null,translate:null,scaleFract:null,translateFract:null,activation:[],selectionBuffer:s.buffer({data:new Uint8Array(0),usage:\"stream\",type:\"uint8\"}),sizeBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),colorBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),positionBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"}),positionFractBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"})},e=c({},y.defaults,e)),!e.positions||\"marker\"in e||(e.marker=n.marker,delete n.marker),!e.marker||\"positions\"in e||(e.positions=n.positions,delete n.positions);var x=0,b=0;if(f(n,e,[{snap:!0,size:function(t,e){return null==t&&(t=y.defaults.size),x+=t&&t.length?1:0,t},borderSize:function(t,e){return null==t&&(t=y.defaults.borderSize),x+=t&&t.length?1:0,t},opacity:parseFloat,color:function(e,r){return null==e&&(e=y.defaults.color),e=t.updateColor(e),b++,e},borderColor:function(e,r){return null==e&&(e=y.defaults.borderColor),e=t.updateColor(e),b++,e},bounds:function(t,e,r){return\"range\"in r||(r.range=null),t},positions:function(t,e,r){var n=e.snap,i=e.positionBuffer,a=e.positionFractBuffer,c=e.selectionBuffer;if(t.x||t.y)return t.x.length?e.xAttr={buffer:s.buffer(t.x),offset:0,stride:4,count:t.x.length}:e.xAttr={buffer:t.x.buffer,offset:4*t.x.offset||0,stride:4*(t.x.stride||1),count:t.x.count},t.y.length?e.yAttr={buffer:s.buffer(t.y),offset:0,stride:4,count:t.y.length}:e.yAttr={buffer:t.y.buffer,offset:4*t.y.offset||0,stride:4*(t.y.stride||1),count:t.y.count},e.count=Math.max(e.xAttr.count,e.yAttr.count),t;t=p(t,\"float64\");var u=e.count=Math.floor(t.length/2),h=e.bounds=u?o(t,2):null;if(r.range||e.range||(delete e.range,r.range=h),r.marker||e.marker||(delete e.marker,r.marker=null),n&&(!0===n||u>n)?e.tree=l(t,{bounds:h}):n&&n.length&&(e.tree=n),e.tree){var f={primitive:\"points\",usage:\"static\",data:e.tree,type:\"uint32\"};e.elements?e.elements(f):e.elements=s.elements(f)}return i({data:g.float(t),usage:\"dynamic\"}),a({data:g.fract(t),usage:\"dynamic\"}),c({data:new Uint8Array(u),type:\"uint8\",usage:\"stream\"}),t}},{marker:function(e,r,n){var i=r.activation;if(i.forEach(function(t){return t&&t.destroy&&t.destroy()}),i.length=0,e&&\"number\"!=typeof e[0]){for(var a=[],o=0,l=Math.min(e.length,r.count);o<l;o++){var c=t.addMarker(e[o]);a[c]||(a[c]=new Uint8Array(r.count)),a[c][o]=1}for(var u=0;u<a.length;u++)if(a[u]){var h={data:a[u],type:\"uint8\",usage:\"static\"};i[u]?i[u](h):i[u]=s.buffer(h),i[u].data=a[u]}}else{i[t.addMarker(e)]=!0}return e},range:function(t,e,r){var n=e.bounds;if(n)return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=g.fract(e.scale),e.translateFract=g.fract(e.translate),t},viewport:function(t){return v(t||[a.drawingBufferWidth,a.drawingBufferHeight])}}]),x){var _=n,w=_.count,k=_.size,T=_.borderSize,A=_.sizeBuffer,M=new Uint8Array(2*w);if(k.length||T.length)for(var S=0;S<w;S++)M[2*S]=Math.round(255*(null==k[S]?k:k[S])/u),M[2*S+1]=Math.round(255*(null==T[S]?T:T[S])/u);A({data:M,usage:\"dynamic\"})}if(b){var E,C=n,L=C.count,P=C.color,O=C.borderColor,z=C.colorBuffer;if(t.tooManyColors){if(P.length||O.length){E=new Uint8Array(8*L);for(var I=0;I<L;I++){var D=P[I];E[8*I]=m[4*D],E[8*I+1]=m[4*D+1],E[8*I+2]=m[4*D+2],E[8*I+3]=m[4*D+3];var R=O[I];E[8*I+4]=m[4*R],E[8*I+5]=m[4*R+1],E[8*I+6]=m[4*R+2],E[8*I+7]=m[4*R+3]}}}else if(P.length||O.length){E=new Uint8Array(4*L+2);for(var F=0;F<L;F++)null!=P[F]&&(E[4*F]=P[F]%d,E[4*F+1]=Math.floor(P[F]/d)),null!=O[F]&&(E[4*F+2]=O[F]%d,E[4*F+3]=Math.floor(O[F]/d))}z({data:E||new Uint8Array(0),type:\"uint8\",usage:\"dynamic\"})}return n})}},y.prototype.addMarker=function(t){var e,r=this.markerTextures,n=this.regl,i=this.markerCache,a=null==t?0:i.indexOf(t);if(a>=0)return a;if(t instanceof Uint8Array||t instanceof Uint8ClampedArray)e=t;else{e=new Uint8Array(t.length);for(var o=0,s=t.length;o<s;o++)e[o]=255*t[o]}var l=Math.floor(Math.sqrt(e.length));return a=r.length,i.push(t),r.push(n.texture({channels:1,data:e,radius:l,mag:\"linear\",min:\"linear\"})),a},y.prototype.updateColor=function(t){var e=this.paletteIds,r=this.palette,n=this.maxColors;Array.isArray(t)||(t=[t]);var i=[];if(\"number\"==typeof t[0]){var o=[];if(Array.isArray(t))for(var l=0;l<t.length;l+=4)o.push(t.slice(l,l+4));else for(var c=0;c<t.length;c+=4)o.push(t.subarray(c,c+4));t=o}for(var u=0;u<t.length;u++){var h=t[u];h=a(h,\"uint8\");var f=s(h,!1);if(null==e[f]){var p=r.length;e[f]=Math.floor(p/4),r[p]=h[0],r[p+1]=h[1],r[p+2]=h[2],r[p+3]=h[3]}i[u]=e[f]}return!this.tooManyColors&&r.length>4*n&&(this.tooManyColors=!0),this.updatePalette(r),1===i.length?i[0]:i},y.prototype.updatePalette=function(t){if(!this.tooManyColors){var e=this.maxColors,r=this.paletteTexture,n=Math.ceil(.25*t.length/e);if(n>1)for(var i=.25*(t=t.slice()).length%e;i<n*e;i++)t.push(0,0,0,0);r.height<n&&r.resize(e,n),r.subimage({width:Math.min(.25*t.length,e),height:n,data:t},0,0)}},y.prototype.destroy=function(){return this.groups.forEach(function(t){t.sizeBuffer.destroy(),t.positionBuffer.destroy(),t.positionFractBuffer.destroy(),t.colorBuffer.destroy(),t.activation.forEach(function(t){return t&&t.destroy&&t.destroy()}),t.selectionBuffer.destroy(),t.elements&&t.elements.destroy()}),this.groups.length=0,this.paletteTexture.destroy(),this.markerTextures.forEach(function(t){return t&&t.destroy&&t.destroy()}),this};var x=t(\"object-assign\");e.exports=function(t,e){var r=new m(t,e),n=r.render.bind(r);return x(n,{render:n,update:r.update.bind(r),draw:r.draw.bind(r),destroy:r.destroy.bind(r),regl:r.regl,gl:r.gl,canvas:r.gl.canvas,groups:r.groups,markers:r.markerCache,palette:r.palette}),n}},{\"array-bounds\":65,\"color-id\":118,\"color-normalize\":120,\"flatten-vertex-data\":227,glslify:409,\"is-iexplorer\":419,\"object-assign\":454,\"parse-rect\":459,\"pick-by-alias\":465,\"point-cluster\":499,\"to-float32\":538,\"update-diff\":549}],498:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],499:[function(t,e,r){\"use strict\";e.exports=t(\"./quad\")},{\"./quad\":500}],500:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"clamp\"),a=t(\"parse-rect\"),o=t(\"array-bounds\"),s=t(\"pick-by-alias\"),l=t(\"defined\"),c=t(\"flatten-vertex-data\"),u=t(\"is-obj\"),h=t(\"dtype\"),f=t(\"math-log2\"),p=1073741824;function d(t,e){for(var r=e[0],n=e[1],a=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=i((t[2*l]-r)*a,0,1),s[2*l+1]=i((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,\"float64\"),e=s(e,{bounds:\"range bounds dataBox databox\",maxDepth:\"depth maxDepth maxdepth level maxLevel maxlevel levels\",dtype:\"type dtype format out dst output destination\"});var r=l(e.maxDepth,255),i=l(e.bounds,o(t,2));i[0]===i[2]&&i[2]++,i[1]===i[3]&&i[3]++;var g,v=d(t,i),m=t.length>>>1;e.dtype||(e.dtype=\"array\"),\"string\"==typeof e.dtype?g=new(h(e.dtype))(m):e.dtype&&(g=e.dtype,Array.isArray(g)&&(g.length=m));for(var y=0;y<m;++y)g[y]=y;var x=[],b=[],_=[],w=[];!function t(e,n,i,a,o,s){if(!a.length)return null;var l=x[o]||(x[o]=[]);var c=_[o]||(_[o]=[]);var u=b[o]||(b[o]=[]);var h=l.length;o++;if(o>r||s>p){for(var f=0;f<a.length;f++)l.push(a[f]),c.push(s),u.push(null,null,null,null);return h}l.push(a[0]);c.push(s);if(a.length<=1)return u.push(null,null,null,null),h;var d=.5*i;var g=e+d,m=n+d;var y=[],w=[],k=[],T=[];for(var A=1,M=a.length;A<M;A++){var S=a[A],E=v[2*S],C=v[2*S+1];E<g?C<m?y.push(S):w.push(S):C<m?k.push(S):T.push(S)}s<<=2;u.push(t(e,n,d,y,o,s),t(e,m,d,w,o,s+1),t(g,n,d,k,o,s+2),t(g,m,d,T,o,s+3));return h}(0,0,1,g,0,1);for(var k=0,T=0;T<x.length;T++){var A=x[T];if(g.set)g.set(A,k);else for(var M=0,S=A.length;M<S;M++)g[M+k]=A[M];var E=k+x[T].length;w[T]=[k,E],k=E}return g.range=function(){var e,r=[],o=arguments.length;for(;o--;)r[o]=arguments[o];if(u(r[r.length-1])){var c=r.pop();r.length||null==c.x&&null==c.l&&null==c.left||(r=[c],e={}),e=s(c,{level:\"level maxLevel\",d:\"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize\",lod:\"lod details ranges offsets\"})}else e={};r.length||(r=i);var h=a.apply(void 0,r),p=[Math.min(h.x,h.x+h.width),Math.min(h.y,h.y+h.height),Math.max(h.x,h.x+h.width),Math.max(h.y,h.y+h.height)],g=p[0],v=p[1],m=p[2],y=p[3],k=d([g,v,m,y],i),T=k[0],A=k[1],M=k[2],S=k[3],E=l(e.level,x.length);if(null!=e.d){var L;\"number\"==typeof e.d?L=[e.d,e.d]:e.d.length&&(L=e.d),E=Math.min(Math.max(Math.ceil(-f(Math.abs(L[0])/(i[2]-i[0]))),Math.ceil(-f(Math.abs(L[1])/(i[3]-i[1])))),E)}if(E=Math.min(E,x.length),e.lod)return function(t,e,r,i,a){for(var o=[],s=0;s<a;s++){var l=_[s],c=w[s][0],u=C(t,e,s),h=C(r,i,s),f=n.ge(l,u),p=n.gt(l,h,f,l.length-1);o[s]=[f+c,p+c]}return o}(T,A,M,S,E);var P=[];return function e(r,n,i,a,o,s){if(null!==o&&null!==s){var l=r+i,c=n+i;if(!(T>l||A>c||M<r||S<n||a>=E||o===s)){var u=x[a];void 0===s&&(s=u.length);for(var h=o;h<s;h++){var f=u[h],p=t[2*f],d=t[2*f+1];p>=g&&p<=m&&d>=v&&d<=y&&P.push(f)}var _=b[a],w=_[4*o+0],k=_[4*o+1],C=_[4*o+2],L=_[4*o+3],O=function(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}(_,o+1),z=.5*i,I=a+1;e(r,n,z,I,w,k||C||L||O),e(r,n+z,z,I,k,C||L||O),e(r+z,n,z,I,C,L||O),e(r+z,n+z,z,I,L,O)}}}(0,0,1,0,0,1),P},g;function C(t,e,r){for(var n=1,i=.5,a=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<i?e<a?0:1:e<a?2:3,o*=.5,i+=t<i?-o:o,a+=e<a?-o:o;return n}}},{\"array-bounds\":65,\"binary-search-bounds\":498,clamp:115,defined:164,dtype:169,\"flatten-vertex-data\":227,\"is-obj\":421,\"math-log2\":432,\"parse-rect\":459,\"pick-by-alias\":465}],501:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"pick-by-alias\"),a=t(\"array-bounds\"),o=t(\"raf\"),s=t(\"array-range\"),l=t(\"parse-rect\"),c=t(\"flatten-vertex-data\");function u(t,e){if(!(this instanceof u))return new u(t,e);this.traces=[],this.passes={},this.regl=t,this.scatter=n(t),this.canvas=this.scatter.canvas}function h(t,e,r){return(null!=t.id?t.id:t)<<16|(255&e)<<8|255&r}function f(t,e,r){var n,i,a,o,s=t[e],l=t[r];return s.length>2?(s[0],s[2],n=s[1],i=s[3]):s.length?(n=s[0],i=s[1]):(s.x,n=s.y,s.x+s.width,i=s.y+s.height),l.length>2?(a=l[0],o=l[2],l[1],l[3]):l.length?(a=l[0],o=l[1]):(a=l.x,l.y,o=l.x+l.width,l.y+l.height),[a,n,o,i]}function p(t){if(\"number\"==typeof t)return[t,t,t,t];if(2===t.length)return[t[0],t[1],t[0],t[1]];var e=l(t);return[e.x,e.y,e.x+e.width,e.y+e.height]}e.exports=u,u.prototype.render=function(){for(var t,e=this,r=[],n=arguments.length;n--;)r[n]=arguments[n];return r.length&&(t=this).update.apply(t,r),this.regl.attributes.preserveDrawingBuffer?this.draw():(this.dirty?null==this.planned&&(this.planned=o(function(){e.draw(),e.dirty=!0,e.planned=null})):(this.draw(),this.dirty=!0,o(function(){e.dirty=!1})),this)},u.prototype.update=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=0;n<e.length;n++)this.updateItem(n,e[n]);this.traces=this.traces.filter(Boolean);for(var i=[],a=0,o=0;o<this.traces.length;o++){for(var s=this.traces[o],l=this.traces[o].passes,c=0;c<l.length;c++)i.push(this.passes[l[c]]);s.passOffset=a,a+=s.passes.length}return(t=this.scatter).update.apply(t,i),this}},u.prototype.updateItem=function(t,e){var r=this.regl;if(null===e)return this.traces[t]=null,this;if(!e)return this;var n,o=i(e,{data:\"data items columns rows values dimensions samples x\",snap:\"snap cluster\",size:\"sizes size radius\",color:\"colors color fill fill-color fillColor\",opacity:\"opacity alpha transparency opaque\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",borderColor:\"borderColors borderColor bordercolor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range ranges databox dataBox\",viewport:\"viewport viewBox viewbox\",domain:\"domain domains area areas\",padding:\"pad padding paddings pads margin margins\",transpose:\"transpose transposed\",diagonal:\"diagonal diag showDiagonal\",upper:\"upper up top upperhalf upperHalf showupperhalf showUpper showUpperHalf\",lower:\"lower low bottom lowerhalf lowerHalf showlowerhalf showLowerHalf showLower\"}),s=this.traces[t]||(this.traces[t]={id:t,buffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),color:\"black\",marker:null,size:12,borderColor:\"transparent\",borderSize:1,viewport:l([r._gl.drawingBufferWidth,r._gl.drawingBufferHeight]),padding:[0,0,0,0],opacity:1,diagonal:!0,upper:!0,lower:!0});if(null!=o.color&&(s.color=o.color),null!=o.size&&(s.size=o.size),null!=o.marker&&(s.marker=o.marker),null!=o.borderColor&&(s.borderColor=o.borderColor),null!=o.borderSize&&(s.borderSize=o.borderSize),null!=o.opacity&&(s.opacity=o.opacity),o.viewport&&(s.viewport=l(o.viewport)),null!=o.diagonal&&(s.diagonal=o.diagonal),null!=o.upper&&(s.upper=o.upper),null!=o.lower&&(s.lower=o.lower),o.data){s.buffer(c(o.data)),s.columns=o.data.length,s.count=o.data[0].length,s.bounds=[];for(var u=0;u<s.columns;u++)s.bounds[u]=a(o.data[u],1)}o.range&&(s.range=o.range,n=s.range&&\"number\"!=typeof s.range[0]),o.domain&&(s.domain=o.domain);var d=!1;null!=o.padding&&(Array.isArray(o.padding)&&o.padding.length===s.columns&&\"number\"==typeof o.padding[o.padding.length-1]?(s.padding=o.padding.map(p),d=!0):s.padding=p(o.padding));var g=s.columns,v=s.count,m=s.viewport.width,y=s.viewport.height,x=s.viewport.x,b=s.viewport.y,_=m/g,w=y/g;s.passes=[];for(var k=0;k<g;k++)for(var T=0;T<g;T++)if((s.diagonal||T!==k)&&(s.upper||!(k>T))&&(s.lower||!(k<T))){var A=h(s.id,k,T),M=this.passes[A]||(this.passes[A]={});if(o.data&&(o.transpose?M.positions={x:{buffer:s.buffer,offset:T,count:v,stride:g},y:{buffer:s.buffer,offset:k,count:v,stride:g}}:M.positions={x:{buffer:s.buffer,offset:T*v,count:v},y:{buffer:s.buffer,offset:k*v,count:v}},M.bounds=f(s.bounds,k,T)),o.domain||o.viewport||o.data){var S=d?f(s.padding,k,T):s.padding;if(s.domain){var E=f(s.domain,k,T),C=E[0],L=E[1],P=E[2],O=E[3];M.viewport=[x+C*m+S[0],b+L*y+S[1],x+P*m-S[2],b+O*y-S[3]]}else M.viewport=[x+T*_+_*S[0],b+k*w+w*S[1],x+(T+1)*_-_*S[2],b+(k+1)*w-w*S[3]]}o.color&&(M.color=s.color),o.size&&(M.size=s.size),o.marker&&(M.marker=s.marker),o.borderSize&&(M.borderSize=s.borderSize),o.borderColor&&(M.borderColor=s.borderColor),o.opacity&&(M.opacity=s.opacity),o.range&&(M.range=n?f(s.range,k,T):s.range||M.bounds),s.passes.push(A)}return this},u.prototype.draw=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=[],i=0;i<e.length;i++)if(\"number\"==typeof e[i]){var a=this.traces[e[i]],o=a.passes,l=a.passOffset;n.push.apply(n,s(l,l+o.length))}else if(e[i].length){var c=e[i],u=this.traces[i],h=u.passes,f=u.passOffset;h=h.map(function(t,e){n[f+e]=c})}(t=this.scatter).draw.apply(t,n)}else this.scatter.draw();return this},u.prototype.destroy=function(){return this.traces.forEach(function(t){t.buffer&&t.buffer.destroy&&t.buffer.destroy()}),this.traces=null,this.passes=null,this.scatter.destroy(),this}},{\"array-bounds\":65,\"array-range\":67,\"flatten-vertex-data\":227,\"parse-rect\":459,\"pick-by-alias\":465,raf:484,\"regl-scatter2d\":497}],502:[function(t,e,r){var n,i;n=this,i=function(){function t(t,e){this.id=U++,this.type=t,this.data=e}function e(t){return\"[\"+function t(e){if(0===e.length)return[];var r=e.charAt(0),n=e.charAt(e.length-1);if(1<e.length&&r===n&&('\"'===r||\"'\"===r))return['\"'+e.substr(1,e.length-2).replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];if(r=/\\[(false|true|null|\\d+|'[^']*'|\"[^\"]*\")\\]/.exec(e))return t(e.substr(0,r.index)).concat(t(r[1])).concat(t(e.substr(r.index+r[0].length)));if(1===(r=e.split(\".\")).length)return['\"'+e.replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];for(e=[],n=0;n<r.length;++n)e=e.concat(t(r[n]));return e}(t).join(\"][\")+\"]\"}function r(t){return\"string\"==typeof t?t.split():t}function n(t){return\"string\"==typeof t?document.querySelector(t):t}function i(t){var e,i,a,o,s=t||{};t={};var l=[],c=[],u=\"undefined\"==typeof window?1:window.devicePixelRatio,h=!1,f=function(t){},p=function(){};if(\"string\"==typeof s?e=document.querySelector(s):\"object\"==typeof s&&(\"string\"==typeof s.nodeName&&\"function\"==typeof s.appendChild&&\"function\"==typeof s.getBoundingClientRect?e=s:\"function\"==typeof s.drawArrays||\"function\"==typeof s.drawElements?a=(o=s).canvas:(\"gl\"in s?o=s.gl:\"canvas\"in s?a=n(s.canvas):\"container\"in s&&(i=n(s.container)),\"attributes\"in s&&(t=s.attributes),\"extensions\"in s&&(l=r(s.extensions)),\"optionalExtensions\"in s&&(c=r(s.optionalExtensions)),\"onDone\"in s&&(f=s.onDone),\"profile\"in s&&(h=!!s.profile),\"pixelRatio\"in s&&(u=+s.pixelRatio))),e&&(\"canvas\"===e.nodeName.toLowerCase()?a=e:i=e),!o){if(!a){if(!(e=function(t,e,r){function n(){var e=window.innerWidth,n=window.innerHeight;t!==document.body&&(e=(n=t.getBoundingClientRect()).right-n.left,n=n.bottom-n.top),i.width=r*e,i.height=r*n,j(i.style,{width:e+\"px\",height:n+\"px\"})}var i=document.createElement(\"canvas\");return j(i.style,{border:0,margin:0,padding:0,top:0,left:0}),t.appendChild(i),t===document.body&&(i.style.position=\"absolute\",j(t.style,{margin:0,padding:0})),window.addEventListener(\"resize\",n,!1),n(),{canvas:i,onDestroy:function(){window.removeEventListener(\"resize\",n),t.removeChild(i)}}}(i||document.body,0,u)))return null;a=e.canvas,p=e.onDestroy}o=function(t,e){function r(r){try{return t.getContext(r,e)}catch(t){return null}}return r(\"webgl\")||r(\"experimental-webgl\")||r(\"webgl-experimental\")}(a,t)}return o?{gl:o,canvas:a,container:i,extensions:l,optionalExtensions:c,pixelRatio:u,profile:h,onDone:f,onDestroy:p}:(p(),f(\"webgl not supported, try upgrading your browser or graphics drivers http://get.webgl.org\"),null)}function a(t,e){for(var r=Array(t),n=0;n<t;++n)r[n]=e(n);return r}function o(t){var e,r;return e=(65535<t)<<4,e|=r=(255<(t>>>=e))<<3,(e|=r=(15<(t>>>=r))<<2)|(r=(3<(t>>>=r))<<1)|t>>>r>>1}function s(){function t(t){t:{for(var e=16;268435456>=e;e*=16)if(t<=e){t=e;break t}t=0}return 0<(e=r[o(t)>>2]).length?e.pop():new ArrayBuffer(t)}function e(t){r[o(t.byteLength)>>2].push(t)}var r=a(8,function(){return[]});return{alloc:t,free:e,allocType:function(e,r){var n=null;switch(e){case 5120:n=new Int8Array(t(r),0,r);break;case 5121:n=new Uint8Array(t(r),0,r);break;case 5122:n=new Int16Array(t(2*r),0,r);break;case 5123:n=new Uint16Array(t(2*r),0,r);break;case 5124:n=new Int32Array(t(4*r),0,r);break;case 5125:n=new Uint32Array(t(4*r),0,r);break;case 5126:n=new Float32Array(t(4*r),0,r);break;default:return null}return n.length!==r?n.subarray(0,r):n},freeType:function(t){e(t.buffer)}}}function l(t){return!!t&&\"object\"==typeof t&&Array.isArray(t.shape)&&Array.isArray(t.stride)&&\"number\"==typeof t.offset&&t.shape.length===t.stride.length&&(Array.isArray(t.data)||W(t.data))}function c(t,e,r,n,i,a){for(var o=0;o<e;++o)for(var s=t[o],l=0;l<r;++l)for(var c=s[l],u=0;u<n;++u)i[a++]=c[u]}function u(t){return 0|J[Object.prototype.toString.call(t)]}function h(t,e){for(var r=0;r<e.length;++r)t[r]=e[r]}function f(t,e,r,n,i,a,o){for(var s=0,l=0;l<r;++l)for(var c=0;c<n;++c)t[s++]=e[i*l+a*c+o]}function p(t,e,r,n){function i(e){this.id=c++,this.buffer=t.createBuffer(),this.type=e,this.usage=35044,this.byteLength=0,this.dimension=1,this.dtype=5121,this.persistentData=null,r.profile&&(this.stats={size:0})}function a(e,r,n){e.byteLength=r.byteLength,t.bufferData(e.type,r,n)}function o(t,e,r,n,i,o){if(t.usage=r,Array.isArray(e)){if(t.dtype=n||5126,0<e.length)if(Array.isArray(e[0])){i=tt(e);for(var s=n=1;s<i.length;++s)n*=i[s];t.dimension=n,a(t,e=Q(e,i,t.dtype),r),o?t.persistentData=e:G.freeType(e)}else\"number\"==typeof e[0]?(t.dimension=i,h(i=G.allocType(t.dtype,e.length),e),a(t,i,r),o?t.persistentData=i:G.freeType(i)):W(e[0])&&(t.dimension=e[0].length,t.dtype=n||u(e[0])||5126,a(t,e=Q(e,[e.length,e[0].length],t.dtype),r),o?t.persistentData=e:G.freeType(e))}else if(W(e))t.dtype=n||u(e),t.dimension=i,a(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e.buffer)));else if(l(e)){i=e.shape;var c=e.stride,p=(s=e.offset,0),d=0,g=0,v=0;1===i.length?(p=i[0],d=1,g=c[0],v=0):2===i.length&&(p=i[0],d=i[1],g=c[0],v=c[1]),t.dtype=n||u(e.data)||5126,t.dimension=d,f(i=G.allocType(t.dtype,p*d),e.data,p,d,g,v,s),a(t,i,r),o?t.persistentData=i:G.freeType(i)}}function s(r){e.bufferCount--;for(var i=0;i<n.state.length;++i){var a=n.state[i];a.buffer===r&&(t.disableVertexAttribArray(i),a.buffer=null)}t.deleteBuffer(r.buffer),r.buffer=null,delete p[r.id]}var c=0,p={};i.prototype.bind=function(){t.bindBuffer(this.type,this.buffer)},i.prototype.destroy=function(){s(this)};var d=[];return r.profile&&(e.getTotalBufferSize=function(){var t=0;return Object.keys(p).forEach(function(e){t+=p[e].stats.size}),t}),{create:function(n,a,c,d){function g(e){var n=35044,i=null,a=0,s=0,c=1;return Array.isArray(e)||W(e)||l(e)?i=e:\"number\"==typeof e?a=0|e:e&&(\"data\"in e&&(i=e.data),\"usage\"in e&&(n=$[e.usage]),\"type\"in e&&(s=K[e.type]),\"dimension\"in e&&(c=0|e.dimension),\"length\"in e&&(a=0|e.length)),v.bind(),i?o(v,i,n,s,c,d):(a&&t.bufferData(v.type,a,n),v.dtype=s||5121,v.usage=n,v.dimension=c,v.byteLength=a),r.profile&&(v.stats.size=v.byteLength*et[v.dtype]),g}e.bufferCount++;var v=new i(a);return p[v.id]=v,c||g(n),g._reglType=\"buffer\",g._buffer=v,g.subdata=function(e,r){var n,i=0|(r||0);if(v.bind(),W(e))t.bufferSubData(v.type,i,e);else if(Array.isArray(e)){if(0<e.length)if(\"number\"==typeof e[0]){var a=G.allocType(v.dtype,e.length);h(a,e),t.bufferSubData(v.type,i,a),G.freeType(a)}else(Array.isArray(e[0])||W(e[0]))&&(n=tt(e),a=Q(e,n,v.dtype),t.bufferSubData(v.type,i,a),G.freeType(a))}else if(l(e)){n=e.shape;var o=e.stride,s=a=0,c=0,p=0;1===n.length?(a=n[0],s=1,c=o[0],p=0):2===n.length&&(a=n[0],s=n[1],c=o[0],p=o[1]),n=Array.isArray(e.data)?v.dtype:u(e.data),f(n=G.allocType(n,a*s),e.data,a,s,c,p,e.offset),t.bufferSubData(v.type,i,n),G.freeType(n)}return g},r.profile&&(g.stats=v.stats),g.destroy=function(){s(v)},g},createStream:function(t,e){var r=d.pop();return r||(r=new i(t)),r.bind(),o(r,e,35040,0,1,!1),r},destroyStream:function(t){d.push(t)},clear:function(){X(p).forEach(s),d.forEach(s)},getBuffer:function(t){return t&&t._buffer instanceof i?t._buffer:null},restore:function(){X(p).forEach(function(e){e.buffer=t.createBuffer(),t.bindBuffer(e.type,e.buffer),t.bufferData(e.type,e.persistentData||e.byteLength,e.usage)})},_initBuffer:o}}function d(t,e,r,n){function i(t){this.id=c++,s[this.id]=this,this.buffer=t,this.primType=4,this.type=this.vertCount=0}function a(n,i,a,o,s,c,u){if(n.buffer.bind(),i){var h=u;u||W(i)&&(!l(i)||W(i.data))||(h=e.oes_element_index_uint?5125:5123),r._initBuffer(n.buffer,i,a,h,3)}else t.bufferData(34963,c,a),n.buffer.dtype=h||5121,n.buffer.usage=a,n.buffer.dimension=3,n.buffer.byteLength=c;if(h=u,!u){switch(n.buffer.dtype){case 5121:case 5120:h=5121;break;case 5123:case 5122:h=5123;break;case 5125:case 5124:h=5125}n.buffer.dtype=h}n.type=h,0>(i=s)&&(i=n.buffer.byteLength,5123===h?i>>=1:5125===h&&(i>>=2)),n.vertCount=i,i=o,0>o&&(i=4,1===(o=n.buffer.dimension)&&(i=0),2===o&&(i=1),3===o&&(i=4)),n.primType=i}function o(t){n.elementsCount--,delete s[t.id],t.buffer.destroy(),t.buffer=null}var s={},c=0,u={uint8:5121,uint16:5123};e.oes_element_index_uint&&(u.uint32=5125),i.prototype.bind=function(){this.buffer.bind()};var h=[];return{create:function(t,e){function s(t){if(t)if(\"number\"==typeof t)c(t),h.primType=4,h.vertCount=0|t,h.type=5121;else{var e=null,r=35044,n=-1,i=-1,o=0,f=0;Array.isArray(t)||W(t)||l(t)?e=t:(\"data\"in t&&(e=t.data),\"usage\"in t&&(r=$[t.usage]),\"primitive\"in t&&(n=rt[t.primitive]),\"count\"in t&&(i=0|t.count),\"type\"in t&&(f=u[t.type]),\"length\"in t?o=0|t.length:(o=i,5123===f||5122===f?o*=2:5125!==f&&5124!==f||(o*=4))),a(h,e,r,n,i,o,f)}else c(),h.primType=4,h.vertCount=0,h.type=5121;return s}var c=r.create(null,34963,!0),h=new i(c._buffer);return n.elementsCount++,s(t),s._reglType=\"elements\",s._elements=h,s.subdata=function(t,e){return c.subdata(t,e),s},s.destroy=function(){o(h)},s},createStream:function(t){var e=h.pop();return e||(e=new i(r.create(null,34963,!0,!1)._buffer)),a(e,t,35040,-1,-1,0,0),e},destroyStream:function(t){h.push(t)},getElements:function(t){return\"function\"==typeof t&&t._elements instanceof i?t._elements:null},clear:function(){X(s).forEach(o)}}}function g(t){for(var e=G.allocType(5123,t.length),r=0;r<t.length;++r)if(isNaN(t[r]))e[r]=65535;else if(1/0===t[r])e[r]=31744;else if(-1/0===t[r])e[r]=64512;else{nt[0]=t[r];var n=(a=it[0])>>>31<<15,i=(a<<1>>>24)-127,a=a>>13&1023;e[r]=-24>i?n:-14>i?n+(a+1024>>-14-i):15<i?n+31744:n+(i+15<<10)+a}return e}function v(t){return Array.isArray(t)||W(t)}function m(t){return\"[object \"+t+\"]\"}function y(t){return Array.isArray(t)&&(0===t.length||\"number\"==typeof t[0])}function x(t){return!(!Array.isArray(t)||0===t.length||!v(t[0]))}function b(t){return Object.prototype.toString.call(t)}function _(t){if(!t)return!1;var e=b(t);return 0<=pt.indexOf(e)||(y(t)||x(t)||l(t))}function w(t,e){36193===t.type?(t.data=g(e),G.freeType(e)):t.data=e}function k(t,e,r,n,i,a){if(t=\"undefined\"!=typeof gt[t]?gt[t]:st[t]*dt[e],a&&(t*=6),i){for(n=0;1<=r;)n+=t*r*r,r/=2;return n}return t*r*n}function T(t,e,r,n,i,a,o){function s(){this.format=this.internalformat=6408,this.type=5121,this.flipY=this.premultiplyAlpha=this.compressed=!1,this.unpackAlignment=1,this.colorSpace=37444,this.channels=this.height=this.width=0}function c(t,e){t.internalformat=e.internalformat,t.format=e.format,t.type=e.type,t.compressed=e.compressed,t.premultiplyAlpha=e.premultiplyAlpha,t.flipY=e.flipY,t.unpackAlignment=e.unpackAlignment,t.colorSpace=e.colorSpace,t.width=e.width,t.height=e.height,t.channels=e.channels}function u(t,e){if(\"object\"==typeof e&&e){\"premultiplyAlpha\"in e&&(t.premultiplyAlpha=e.premultiplyAlpha),\"flipY\"in e&&(t.flipY=e.flipY),\"alignment\"in e&&(t.unpackAlignment=e.alignment),\"colorSpace\"in e&&(t.colorSpace=q[e.colorSpace]),\"type\"in e&&(t.type=H[e.type]);var r=t.width,n=t.height,i=t.channels,a=!1;\"shape\"in e?(r=e.shape[0],n=e.shape[1],3===e.shape.length&&(i=e.shape[2],a=!0)):(\"radius\"in e&&(r=n=e.radius),\"width\"in e&&(r=e.width),\"height\"in e&&(n=e.height),\"channels\"in e&&(i=e.channels,a=!0)),t.width=0|r,t.height=0|n,t.channels=0|i,r=!1,\"format\"in e&&(r=e.format,n=t.internalformat=Y[r],t.format=pt[n],r in H&&!(\"type\"in e)&&(t.type=H[r]),r in K&&(t.compressed=!0),r=!0),!a&&r?t.channels=st[t.format]:a&&!r&&t.channels!==ot[t.format]&&(t.format=t.internalformat=ot[t.channels])}}function h(e){t.pixelStorei(37440,e.flipY),t.pixelStorei(37441,e.premultiplyAlpha),t.pixelStorei(37443,e.colorSpace),t.pixelStorei(3317,e.unpackAlignment)}function f(){s.call(this),this.yOffset=this.xOffset=0,this.data=null,this.needsFree=!1,this.element=null,this.needsCopy=!1}function p(t,e){var r=null;if(_(e)?r=e:e&&(u(t,e),\"x\"in e&&(t.xOffset=0|e.x),\"y\"in e&&(t.yOffset=0|e.y),_(e.data)&&(r=e.data)),e.copy){var n=i.viewportWidth,a=i.viewportHeight;t.width=t.width||n-t.xOffset,t.height=t.height||a-t.yOffset,t.needsCopy=!0}else if(r){if(W(r))t.channels=t.channels||4,t.data=r,\"type\"in e||5121!==t.type||(t.type=0|J[Object.prototype.toString.call(r)]);else if(y(r)){switch(t.channels=t.channels||4,a=(n=r).length,t.type){case 5121:case 5123:case 5125:case 5126:(a=G.allocType(t.type,a)).set(n),t.data=a;break;case 36193:t.data=g(n)}t.alignment=1,t.needsFree=!0}else if(l(r)){n=r.data,Array.isArray(n)||5121!==t.type||(t.type=0|J[Object.prototype.toString.call(n)]);a=r.shape;var o,s,c,h,f=r.stride;3===a.length?(c=a[2],h=f[2]):h=c=1,o=a[0],s=a[1],a=f[0],f=f[1],t.alignment=1,t.width=o,t.height=s,t.channels=c,t.format=t.internalformat=ot[c],t.needsFree=!0,o=h,r=r.offset,c=t.width,h=t.height,s=t.channels;for(var p=G.allocType(36193===t.type?5126:t.type,c*h*s),d=0,m=0;m<h;++m)for(var k=0;k<c;++k)for(var T=0;T<s;++T)p[d++]=n[a*k+f*m+o*T+r];w(t,p)}else if(b(r)===lt||b(r)===ct)b(r)===lt?t.element=r:t.element=r.canvas,t.width=t.element.width,t.height=t.element.height,t.channels=4;else if(b(r)===ut)t.element=r,t.width=r.width,t.height=r.height,t.channels=4;else if(b(r)===ht)t.element=r,t.width=r.naturalWidth,t.height=r.naturalHeight,t.channels=4;else if(b(r)===ft)t.element=r,t.width=r.videoWidth,t.height=r.videoHeight,t.channels=4;else if(x(r)){for(n=t.width||r[0].length,a=t.height||r.length,f=t.channels,f=v(r[0][0])?f||r[0][0].length:f||1,o=Z.shape(r),c=1,h=0;h<o.length;++h)c*=o[h];c=G.allocType(36193===t.type?5126:t.type,c),Z.flatten(r,o,\"\",c),w(t,c),t.alignment=1,t.width=n,t.height=a,t.channels=f,t.format=t.internalformat=ot[f],t.needsFree=!0}}else t.width=t.width||1,t.height=t.height||1,t.channels=t.channels||4}function d(e,r,i,a,o){var s=e.element,l=e.data,c=e.internalformat,u=e.format,f=e.type,p=e.width,d=e.height;h(e),s?t.texSubImage2D(r,o,i,a,u,f,s):e.compressed?t.compressedTexSubImage2D(r,o,i,a,c,p,d,l):e.needsCopy?(n(),t.copyTexSubImage2D(r,o,i,a,e.xOffset,e.yOffset,p,d)):t.texSubImage2D(r,o,i,a,p,d,u,f,l)}function m(){return dt.pop()||new f}function T(t){t.needsFree&&G.freeType(t.data),f.call(t),dt.push(t)}function A(){s.call(this),this.genMipmaps=!1,this.mipmapHint=4352,this.mipmask=0,this.images=Array(16)}function M(t,e,r){var n=t.images[0]=m();t.mipmask=1,n.width=t.width=e,n.height=t.height=r,n.channels=t.channels=4}function S(t,e){var r=null;if(_(e))c(r=t.images[0]=m(),t),p(r,e),t.mipmask=1;else if(u(t,e),Array.isArray(e.mipmap))for(var n=e.mipmap,i=0;i<n.length;++i)c(r=t.images[i]=m(),t),r.width>>=i,r.height>>=i,p(r,n[i]),t.mipmask|=1<<i;else c(r=t.images[0]=m(),t),p(r,e),t.mipmask=1;c(t,t.images[0])}function E(e,r){for(var i=e.images,a=0;a<i.length&&i[a];++a){var o=i[a],s=r,l=a,c=o.element,u=o.data,f=o.internalformat,p=o.format,d=o.type,g=o.width,v=o.height,m=o.channels;h(o),c?t.texImage2D(s,l,p,p,d,c):o.compressed?t.compressedTexImage2D(s,l,f,g,v,0,u):o.needsCopy?(n(),t.copyTexImage2D(s,l,p,o.xOffset,o.yOffset,g,v,0)):((o=!u)&&(u=G.zero.allocType(d,g*v*m)),t.texImage2D(s,l,p,g,v,0,p,d,u),o&&u&&G.zero.freeType(u))}}function C(){var t=gt.pop()||new A;s.call(t);for(var e=t.mipmask=0;16>e;++e)t.images[e]=null;return t}function L(t){for(var e=t.images,r=0;r<e.length;++r)e[r]&&T(e[r]),e[r]=null;gt.push(t)}function P(){this.magFilter=this.minFilter=9728,this.wrapT=this.wrapS=33071,this.anisotropic=1,this.genMipmaps=!1,this.mipmapHint=4352}function O(t,e){\"min\"in e&&(t.minFilter=V[e.min],0<=at.indexOf(t.minFilter)&&!(\"faces\"in e)&&(t.genMipmaps=!0)),\"mag\"in e&&(t.magFilter=U[e.mag]);var r=t.wrapS,n=t.wrapT;if(\"wrap\"in e){var i=e.wrap;\"string\"==typeof i?r=n=N[i]:Array.isArray(i)&&(r=N[i[0]],n=N[i[1]])}else\"wrapS\"in e&&(r=N[e.wrapS]),\"wrapT\"in e&&(n=N[e.wrapT]);if(t.wrapS=r,t.wrapT=n,\"anisotropic\"in e&&(t.anisotropic=e.anisotropic),\"mipmap\"in e){switch(r=!1,typeof e.mipmap){case\"string\":t.mipmapHint=B[e.mipmap],r=t.genMipmaps=!0;break;case\"boolean\":r=t.genMipmaps=e.mipmap;break;case\"object\":t.genMipmaps=!1,r=!0}!r||\"min\"in e||(t.minFilter=9984)}}function z(r,n){t.texParameteri(n,10241,r.minFilter),t.texParameteri(n,10240,r.magFilter),t.texParameteri(n,10242,r.wrapS),t.texParameteri(n,10243,r.wrapT),e.ext_texture_filter_anisotropic&&t.texParameteri(n,34046,r.anisotropic),r.genMipmaps&&(t.hint(33170,r.mipmapHint),t.generateMipmap(n))}function I(e){s.call(this),this.mipmask=0,this.internalformat=6408,this.id=vt++,this.refCount=1,this.target=e,this.texture=t.createTexture(),this.unit=-1,this.bindCount=0,this.texInfo=new P,o.profile&&(this.stats={size:0})}function D(e){t.activeTexture(33984),t.bindTexture(e.target,e.texture)}function R(){var e=xt[0];e?t.bindTexture(e.target,e.texture):t.bindTexture(3553,null)}function F(e){var r=e.texture,n=e.unit,i=e.target;0<=n&&(t.activeTexture(33984+n),t.bindTexture(i,null),xt[n]=null),t.deleteTexture(r),e.texture=null,e.params=null,e.pixels=null,e.refCount=0,delete mt[e.id],a.textureCount--}var B={\"don't care\":4352,\"dont care\":4352,nice:4354,fast:4353},N={repeat:10497,clamp:33071,mirror:33648},U={nearest:9728,linear:9729},V=j({mipmap:9987,\"nearest mipmap nearest\":9984,\"linear mipmap nearest\":9985,\"nearest mipmap linear\":9986,\"linear mipmap linear\":9987},U),q={none:0,browser:37444},H={uint8:5121,rgba4:32819,rgb565:33635,\"rgb5 a1\":32820},Y={alpha:6406,luminance:6409,\"luminance alpha\":6410,rgb:6407,rgba:6408,rgba4:32854,\"rgb5 a1\":32855,rgb565:36194},K={};e.ext_srgb&&(Y.srgb=35904,Y.srgba=35906),e.oes_texture_float&&(H.float32=H.float=5126),e.oes_texture_half_float&&(H.float16=H[\"half float\"]=36193),e.webgl_depth_texture&&(j(Y,{depth:6402,\"depth stencil\":34041}),j(H,{uint16:5123,uint32:5125,\"depth stencil\":34042})),e.webgl_compressed_texture_s3tc&&j(K,{\"rgb s3tc dxt1\":33776,\"rgba s3tc dxt1\":33777,\"rgba s3tc dxt3\":33778,\"rgba s3tc dxt5\":33779}),e.webgl_compressed_texture_atc&&j(K,{\"rgb atc\":35986,\"rgba atc explicit alpha\":35987,\"rgba atc interpolated alpha\":34798}),e.webgl_compressed_texture_pvrtc&&j(K,{\"rgb pvrtc 4bppv1\":35840,\"rgb pvrtc 2bppv1\":35841,\"rgba pvrtc 4bppv1\":35842,\"rgba pvrtc 2bppv1\":35843}),e.webgl_compressed_texture_etc1&&(K[\"rgb etc1\"]=36196);var $=Array.prototype.slice.call(t.getParameter(34467));Object.keys(K).forEach(function(t){var e=K[t];0<=$.indexOf(e)&&(Y[t]=e)});var Q=Object.keys(Y);r.textureFormats=Q;var tt=[];Object.keys(Y).forEach(function(t){tt[Y[t]]=t});var et=[];Object.keys(H).forEach(function(t){et[H[t]]=t});var rt=[];Object.keys(U).forEach(function(t){rt[U[t]]=t});var nt=[];Object.keys(V).forEach(function(t){nt[V[t]]=t});var it=[];Object.keys(N).forEach(function(t){it[N[t]]=t});var pt=Q.reduce(function(t,e){var r=Y[e];return 6409===r||6406===r||6409===r||6410===r||6402===r||34041===r?t[r]=r:32855===r||0<=e.indexOf(\"rgba\")?t[r]=6408:t[r]=6407,t},{}),dt=[],gt=[],vt=0,mt={},yt=r.maxTextureUnits,xt=Array(yt).map(function(){return null});return j(I.prototype,{bind:function(){this.bindCount+=1;var e=this.unit;if(0>e){for(var r=0;r<yt;++r){var n=xt[r];if(n){if(0<n.bindCount)continue;n.unit=-1}xt[r]=this,e=r;break}o.profile&&a.maxTextureUnits<e+1&&(a.maxTextureUnits=e+1),this.unit=e,t.activeTexture(33984+e),t.bindTexture(this.target,this.texture)}return e},unbind:function(){--this.bindCount},decRef:function(){0>=--this.refCount&&F(this)}}),o.profile&&(a.getTotalTextureSize=function(){var t=0;return Object.keys(mt).forEach(function(e){t+=mt[e].stats.size}),t}),{create2D:function(e,r){function n(t,e){var r=i.texInfo;P.call(r);var a=C();return\"number\"==typeof t?M(a,0|t,\"number\"==typeof e?0|e:0|t):t?(O(r,t),S(a,t)):M(a,1,1),r.genMipmaps&&(a.mipmask=(a.width<<1)-1),i.mipmask=a.mipmask,c(i,a),i.internalformat=a.internalformat,n.width=a.width,n.height=a.height,D(i),E(a,3553),z(r,3553),R(),L(a),o.profile&&(i.stats.size=k(i.internalformat,i.type,a.width,a.height,r.genMipmaps,!1)),n.format=tt[i.internalformat],n.type=et[i.type],n.mag=rt[r.magFilter],n.min=nt[r.minFilter],n.wrapS=it[r.wrapS],n.wrapT=it[r.wrapT],n}var i=new I(3553);return mt[i.id]=i,a.textureCount++,n(e,r),n.subimage=function(t,e,r,a){e|=0,r|=0,a|=0;var o=m();return c(o,i),o.width=0,o.height=0,p(o,t),o.width=o.width||(i.width>>a)-e,o.height=o.height||(i.height>>a)-r,D(i),d(o,3553,e,r,a),R(),T(o),n},n.resize=function(e,r){var a=0|e,s=0|r||a;if(a===i.width&&s===i.height)return n;n.width=i.width=a,n.height=i.height=s,D(i);for(var l,c=i.channels,u=i.type,h=0;i.mipmask>>h;++h){var f=a>>h,p=s>>h;if(!f||!p)break;l=G.zero.allocType(u,f*p*c),t.texImage2D(3553,h,i.format,f,p,0,i.format,i.type,l),l&&G.zero.freeType(l)}return R(),o.profile&&(i.stats.size=k(i.internalformat,i.type,a,s,!1,!1)),n},n._reglType=\"texture2d\",n._texture=i,o.profile&&(n.stats=i.stats),n.destroy=function(){i.decRef()},n},createCube:function(e,r,n,i,s,l){function h(t,e,r,n,i,a){var s,l=f.texInfo;for(P.call(l),s=0;6>s;++s)g[s]=C();if(\"number\"!=typeof t&&t){if(\"object\"==typeof t)if(e)S(g[0],t),S(g[1],e),S(g[2],r),S(g[3],n),S(g[4],i),S(g[5],a);else if(O(l,t),u(f,t),\"faces\"in t)for(t=t.faces,s=0;6>s;++s)c(g[s],f),S(g[s],t[s]);else for(s=0;6>s;++s)S(g[s],t)}else for(t=0|t||1,s=0;6>s;++s)M(g[s],t,t);for(c(f,g[0]),f.mipmask=l.genMipmaps?(g[0].width<<1)-1:g[0].mipmask,f.internalformat=g[0].internalformat,h.width=g[0].width,h.height=g[0].height,D(f),s=0;6>s;++s)E(g[s],34069+s);for(z(l,34067),R(),o.profile&&(f.stats.size=k(f.internalformat,f.type,h.width,h.height,l.genMipmaps,!0)),h.format=tt[f.internalformat],h.type=et[f.type],h.mag=rt[l.magFilter],h.min=nt[l.minFilter],h.wrapS=it[l.wrapS],h.wrapT=it[l.wrapT],s=0;6>s;++s)L(g[s]);return h}var f=new I(34067);mt[f.id]=f,a.cubeCount++;var g=Array(6);return h(e,r,n,i,s,l),h.subimage=function(t,e,r,n,i){r|=0,n|=0,i|=0;var a=m();return c(a,f),a.width=0,a.height=0,p(a,e),a.width=a.width||(f.width>>i)-r,a.height=a.height||(f.height>>i)-n,D(f),d(a,34069+t,r,n,i),R(),T(a),h},h.resize=function(e){if((e|=0)!==f.width){h.width=f.width=e,h.height=f.height=e,D(f);for(var r=0;6>r;++r)for(var n=0;f.mipmask>>n;++n)t.texImage2D(34069+r,n,f.format,e>>n,e>>n,0,f.format,f.type,null);return R(),o.profile&&(f.stats.size=k(f.internalformat,f.type,h.width,h.height,!1,!0)),h}},h._reglType=\"textureCube\",h._texture=f,o.profile&&(h.stats=f.stats),h.destroy=function(){f.decRef()},h},clear:function(){for(var e=0;e<yt;++e)t.activeTexture(33984+e),t.bindTexture(3553,null),xt[e]=null;X(mt).forEach(F),a.cubeCount=0,a.textureCount=0},getTexture:function(t){return null},restore:function(){for(var e=0;e<yt;++e){var r=xt[e];r&&(r.bindCount=0,r.unit=-1,xt[e]=null)}X(mt).forEach(function(e){e.texture=t.createTexture(),t.bindTexture(e.target,e.texture);for(var r=0;32>r;++r)if(0!=(e.mipmask&1<<r))if(3553===e.target)t.texImage2D(3553,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);else for(var n=0;6>n;++n)t.texImage2D(34069+n,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);z(e.texInfo,e.target)})}}}function A(t,e,r,n,i,a){function o(t,e,r){this.target=t,this.texture=e,this.renderbuffer=r;var n=t=0;e?(t=e.width,n=e.height):r&&(t=r.width,n=r.height),this.width=t,this.height=n}function s(t){t&&(t.texture&&t.texture._texture.decRef(),t.renderbuffer&&t.renderbuffer._renderbuffer.decRef())}function l(t,e,r){t&&(t.texture?t.texture._texture.refCount+=1:t.renderbuffer._renderbuffer.refCount+=1)}function c(e,r){r&&(r.texture?t.framebufferTexture2D(36160,e,r.target,r.texture._texture.texture,0):t.framebufferRenderbuffer(36160,e,36161,r.renderbuffer._renderbuffer.renderbuffer))}function u(t){var e=3553,r=null,n=null,i=t;return\"object\"==typeof t&&(i=t.data,\"target\"in t&&(e=0|t.target)),\"texture2d\"===(t=i._reglType)?r=i:\"textureCube\"===t?r=i:\"renderbuffer\"===t&&(n=i,e=36161),new o(e,r,n)}function h(t,e,r,a,s){return r?((t=n.create2D({width:t,height:e,format:a,type:s}))._texture.refCount=0,new o(3553,t,null)):((t=i.create({width:t,height:e,format:a}))._renderbuffer.refCount=0,new o(36161,null,t))}function f(t){return t&&(t.texture||t.renderbuffer)}function p(t,e,r){t&&(t.texture?t.texture.resize(e,r):t.renderbuffer&&t.renderbuffer.resize(e,r),t.width=e,t.height=r)}function d(){this.id=k++,T[this.id]=this,this.framebuffer=t.createFramebuffer(),this.height=this.width=0,this.colorAttachments=[],this.depthStencilAttachment=this.stencilAttachment=this.depthAttachment=null}function g(t){t.colorAttachments.forEach(s),s(t.depthAttachment),s(t.stencilAttachment),s(t.depthStencilAttachment)}function v(e){t.deleteFramebuffer(e.framebuffer),e.framebuffer=null,a.framebufferCount--,delete T[e.id]}function m(e){var n;t.bindFramebuffer(36160,e.framebuffer);var i=e.colorAttachments;for(n=0;n<i.length;++n)c(36064+n,i[n]);for(n=i.length;n<r.maxColorAttachments;++n)t.framebufferTexture2D(36160,36064+n,3553,null,0);t.framebufferTexture2D(36160,33306,3553,null,0),t.framebufferTexture2D(36160,36096,3553,null,0),t.framebufferTexture2D(36160,36128,3553,null,0),c(36096,e.depthAttachment),c(36128,e.stencilAttachment),c(33306,e.depthStencilAttachment),t.checkFramebufferStatus(36160),t.isContextLost(),t.bindFramebuffer(36160,x.next?x.next.framebuffer:null),x.cur=x.next,t.getError()}function y(t,e){function r(t,e){var i,a=0,o=0,s=!0,c=!0;i=null;var p=!0,d=\"rgba\",v=\"uint8\",y=1,x=null,w=null,k=null,T=!1;\"number\"==typeof t?(a=0|t,o=0|e||a):t?(\"shape\"in t?(a=(o=t.shape)[0],o=o[1]):(\"radius\"in t&&(a=o=t.radius),\"width\"in t&&(a=t.width),\"height\"in t&&(o=t.height)),(\"color\"in t||\"colors\"in t)&&(i=t.color||t.colors,Array.isArray(i)),i||(\"colorCount\"in t&&(y=0|t.colorCount),\"colorTexture\"in t&&(p=!!t.colorTexture,d=\"rgba4\"),\"colorType\"in t&&(v=t.colorType,!p)&&(\"half float\"===v||\"float16\"===v?d=\"rgba16f\":\"float\"!==v&&\"float32\"!==v||(d=\"rgba32f\")),\"colorFormat\"in t&&(d=t.colorFormat,0<=b.indexOf(d)?p=!0:0<=_.indexOf(d)&&(p=!1))),(\"depthTexture\"in t||\"depthStencilTexture\"in t)&&(T=!(!t.depthTexture&&!t.depthStencilTexture)),\"depth\"in t&&(\"boolean\"==typeof t.depth?s=t.depth:(x=t.depth,c=!1)),\"stencil\"in t&&(\"boolean\"==typeof t.stencil?c=t.stencil:(w=t.stencil,s=!1)),\"depthStencil\"in t&&(\"boolean\"==typeof t.depthStencil?s=c=t.depthStencil:(k=t.depthStencil,c=s=!1))):a=o=1;var A=null,M=null,S=null,E=null;if(Array.isArray(i))A=i.map(u);else if(i)A=[u(i)];else for(A=Array(y),i=0;i<y;++i)A[i]=h(a,o,p,d,v);for(a=a||A[0].width,o=o||A[0].height,x?M=u(x):s&&!c&&(M=h(a,o,T,\"depth\",\"uint32\")),w?S=u(w):c&&!s&&(S=h(a,o,!1,\"stencil\",\"uint8\")),k?E=u(k):!x&&!w&&c&&s&&(E=h(a,o,T,\"depth stencil\",\"depth stencil\")),s=null,i=0;i<A.length;++i)l(A[i]),A[i]&&A[i].texture&&(c=yt[A[i].texture._texture.format]*xt[A[i].texture._texture.type],null===s&&(s=c));return l(M),l(S),l(E),g(n),n.width=a,n.height=o,n.colorAttachments=A,n.depthAttachment=M,n.stencilAttachment=S,n.depthStencilAttachment=E,r.color=A.map(f),r.depth=f(M),r.stencil=f(S),r.depthStencil=f(E),r.width=n.width,r.height=n.height,m(n),r}var n=new d;return a.framebufferCount++,r(t,e),j(r,{resize:function(t,e){var i=Math.max(0|t,1),a=Math.max(0|e||i,1);if(i===n.width&&a===n.height)return r;for(var o=n.colorAttachments,s=0;s<o.length;++s)p(o[s],i,a);return p(n.depthAttachment,i,a),p(n.stencilAttachment,i,a),p(n.depthStencilAttachment,i,a),n.width=r.width=i,n.height=r.height=a,m(n),r},_reglType:\"framebuffer\",_framebuffer:n,destroy:function(){v(n),g(n)},use:function(t){x.setFBO({framebuffer:r},t)}})}var x={cur:null,next:null,dirty:!1,setFBO:null},b=[\"rgba\"],_=[\"rgba4\",\"rgb565\",\"rgb5 a1\"];e.ext_srgb&&_.push(\"srgba\"),e.ext_color_buffer_half_float&&_.push(\"rgba16f\",\"rgb16f\"),e.webgl_color_buffer_float&&_.push(\"rgba32f\");var w=[\"uint8\"];e.oes_texture_half_float&&w.push(\"half float\",\"float16\"),e.oes_texture_float&&w.push(\"float\",\"float32\");var k=0,T={};return j(x,{getFramebuffer:function(t){return\"function\"==typeof t&&\"framebuffer\"===t._reglType&&(t=t._framebuffer)instanceof d?t:null},create:y,createCube:function(t){function e(t){var i,a={color:null},o=0,s=null;i=\"rgba\";var l=\"uint8\",c=1;if(\"number\"==typeof t?o=0|t:t?(\"shape\"in t?o=t.shape[0]:(\"radius\"in t&&(o=0|t.radius),\"width\"in t?o=0|t.width:\"height\"in t&&(o=0|t.height)),(\"color\"in t||\"colors\"in t)&&(s=t.color||t.colors,Array.isArray(s)),s||(\"colorCount\"in t&&(c=0|t.colorCount),\"colorType\"in t&&(l=t.colorType),\"colorFormat\"in t&&(i=t.colorFormat)),\"depth\"in t&&(a.depth=t.depth),\"stencil\"in t&&(a.stencil=t.stencil),\"depthStencil\"in t&&(a.depthStencil=t.depthStencil)):o=1,s)if(Array.isArray(s))for(t=[],i=0;i<s.length;++i)t[i]=s[i];else t=[s];else for(t=Array(c),s={radius:o,format:i,type:l},i=0;i<c;++i)t[i]=n.createCube(s);for(a.color=Array(t.length),i=0;i<t.length;++i)c=t[i],o=o||c.width,a.color[i]={target:34069,data:t[i]};for(i=0;6>i;++i){for(c=0;c<t.length;++c)a.color[c].target=34069+i;0<i&&(a.depth=r[0].depth,a.stencil=r[0].stencil,a.depthStencil=r[0].depthStencil),r[i]?r[i](a):r[i]=y(a)}return j(e,{width:o,height:o,color:t})}var r=Array(6);return e(t),j(e,{faces:r,resize:function(t){var n=0|t;if(n===e.width)return e;var i=e.color;for(t=0;t<i.length;++t)i[t].resize(n);for(t=0;6>t;++t)r[t].resize(n);return e.width=e.height=n,e},_reglType:\"framebufferCube\",destroy:function(){r.forEach(function(t){t.destroy()})}})},clear:function(){X(T).forEach(v)},restore:function(){x.cur=null,x.next=null,x.dirty=!0,X(T).forEach(function(e){e.framebuffer=t.createFramebuffer(),m(e)})}})}function M(){this.w=this.z=this.y=this.x=this.state=0,this.buffer=null,this.size=0,this.normalized=!1,this.type=5126,this.divisor=this.stride=this.offset=0}function S(t,e,r,n){function i(t,e,r,n){this.name=t,this.id=e,this.location=r,this.info=n}function a(t,e){for(var r=0;r<t.length;++r)if(t[r].id===e.id)return void(t[r].location=e.location);t.push(e)}function o(r,n,i){if(!(o=(i=35632===r?c:u)[n])){var a=e.str(n),o=t.createShader(r);t.shaderSource(o,a),t.compileShader(o),i[n]=o}return o}function s(t,e){this.id=p++,this.fragId=t,this.vertId=e,this.program=null,this.uniforms=[],this.attributes=[],n.profile&&(this.stats={uniformsCount:0,attributesCount:0})}function l(r,s){var l,c;l=o(35632,r.fragId),c=o(35633,r.vertId);var u=r.program=t.createProgram();t.attachShader(u,l),t.attachShader(u,c),t.linkProgram(u);var h=t.getProgramParameter(u,35718);n.profile&&(r.stats.uniformsCount=h);var f=r.uniforms;for(l=0;l<h;++l)if(c=t.getActiveUniform(u,l))if(1<c.size)for(var p=0;p<c.size;++p){var d=c.name.replace(\"[0]\",\"[\"+p+\"]\");a(f,new i(d,e.id(d),t.getUniformLocation(u,d),c))}else a(f,new i(c.name,e.id(c.name),t.getUniformLocation(u,c.name),c));for(h=t.getProgramParameter(u,35721),n.profile&&(r.stats.attributesCount=h),f=r.attributes,l=0;l<h;++l)(c=t.getActiveAttrib(u,l))&&a(f,new i(c.name,e.id(c.name),t.getAttribLocation(u,c.name),c))}var c={},u={},h={},f=[],p=0;return n.profile&&(r.getMaxUniformsCount=function(){var t=0;return f.forEach(function(e){e.stats.uniformsCount>t&&(t=e.stats.uniformsCount)}),t},r.getMaxAttributesCount=function(){var t=0;return f.forEach(function(e){e.stats.attributesCount>t&&(t=e.stats.attributesCount)}),t}),{clear:function(){var e=t.deleteShader.bind(t);X(c).forEach(e),c={},X(u).forEach(e),u={},f.forEach(function(e){t.deleteProgram(e.program)}),f.length=0,h={},r.shaderCount=0},program:function(t,e,n){var i=h[e];i||(i=h[e]={});var a=i[t];return a||(a=new s(e,t),r.shaderCount++,l(a),i[t]=a,f.push(a)),a},restore:function(){c={},u={};for(var t=0;t<f.length;++t)l(f[t])},shader:o,frag:-1,vert:-1}}function E(t,e,r,n,i,a,o){function s(i){var a;a=null===e.next?5121:e.next.colorAttachments[0].texture._texture.type;var o=0,s=0,l=n.framebufferWidth,c=n.framebufferHeight,u=null;return W(i)?u=i:i&&(o=0|i.x,s=0|i.y,l=0|(i.width||n.framebufferWidth-o),c=0|(i.height||n.framebufferHeight-s),u=i.data||null),r(),i=l*c*4,u||(5121===a?u=new Uint8Array(i):5126===a&&(u=u||new Float32Array(i))),t.pixelStorei(3333,4),t.readPixels(o,s,l,c,6408,a,u),u}return function(t){return t&&\"framebuffer\"in t?function(t){var r;return e.setFBO({framebuffer:t.framebuffer},function(){r=s(t)}),r}(t):s(t)}}function C(t){return Array.prototype.slice.call(t)}function L(t){return C(t).join(\"\")}function P(){function t(){var t=[],e=[];return j(function(){t.push.apply(t,C(arguments))},{def:function(){var n=\"v\"+r++;return e.push(n),0<arguments.length&&(t.push(n,\"=\"),t.push.apply(t,C(arguments)),t.push(\";\")),n},toString:function(){return L([0<e.length?\"var \"+e+\";\":\"\",L(t)])}})}function e(){function e(t,e){n(t,e,\"=\",r.def(t,e),\";\")}var r=t(),n=t(),i=r.toString,a=n.toString;return j(function(){r.apply(r,C(arguments))},{def:r.def,entry:r,exit:n,save:e,set:function(t,n,i){e(t,n),r(t,n,\"=\",i,\";\")},toString:function(){return i()+a()}})}var r=0,n=[],i=[],a=t(),o={};return{global:a,link:function(t){for(var e=0;e<i.length;++e)if(i[e]===t)return n[e];return e=\"g\"+r++,n.push(e),i.push(t),e},block:t,proc:function(t,r){function n(){var t=\"a\"+i.length;return i.push(t),t}var i=[];r=r||0;for(var a=0;a<r;++a)n();var s=(a=e()).toString;return o[t]=j(a,{arg:n,toString:function(){return L([\"function(\",i.join(),\"){\",s(),\"}\"])}})},scope:e,cond:function(){var t=L(arguments),r=e(),n=e(),i=r.toString,a=n.toString;return j(r,{then:function(){return r.apply(r,C(arguments)),this},else:function(){return n.apply(n,C(arguments)),this},toString:function(){var e=a();return e&&(e=\"else{\"+e+\"}\"),L([\"if(\",t,\"){\",i(),\"}\",e])}})},compile:function(){var t=['\"use strict\";',a,\"return {\"];Object.keys(o).forEach(function(e){t.push('\"',e,'\":',o[e].toString(),\",\")}),t.push(\"}\");var e=L(t).replace(/;/g,\";\\n\").replace(/}/g,\"}\\n\").replace(/{/g,\"{\\n\");return Function.apply(null,n.concat(e)).apply(null,i)}}}function O(t){return Array.isArray(t)||W(t)||l(t)}function z(t){return t.sort(function(t,e){return\"viewport\"===t?-1:\"viewport\"===e?1:t<e?-1:1})}function I(t,e,r,n){this.thisDep=t,this.contextDep=e,this.propDep=r,this.append=n}function D(t){return t&&!(t.thisDep||t.contextDep||t.propDep)}function R(t){return new I(!1,!1,!1,t)}function F(t,e){var r=t.type;return 0===r?new I(!0,1<=(r=t.data.length),2<=r,e):4===r?new I((r=t.data).thisDep,r.contextDep,r.propDep,e):new I(3===r,2===r,1===r,e)}function B(t,e,r,n,i,o,s,l,c,u,h,f,p,d,g){function m(t){return t.replace(\".\",\"_\")}function y(t,e,r){var n=m(t);nt.push(t),et[n]=tt[n]=!!r,it[n]=e}function x(t,e,r){var n=m(t);nt.push(t),Array.isArray(r)?(tt[n]=r.slice(),et[n]=r.slice()):tt[n]=et[n]=r,at[n]=e}function b(){var t=P(),r=t.link,n=t.global;t.id=lt++,t.batchId=\"0\";var i=r(ot),a=t.shared={props:\"a0\"};Object.keys(ot).forEach(function(t){a[t]=n.def(i,\".\",t)});var o=t.next={},s=t.current={};Object.keys(at).forEach(function(t){Array.isArray(tt[t])&&(o[t]=n.def(a.next,\".\",t),s[t]=n.def(a.current,\".\",t))});var l=t.constants={};Object.keys(st).forEach(function(t){l[t]=n.def(JSON.stringify(st[t]))}),t.invoke=function(e,n){switch(n.type){case 0:var i=[\"this\",a.context,a.props,t.batchId];return e.def(r(n.data),\".call(\",i.slice(0,Math.max(n.data.length+1,4)),\")\");case 1:return e.def(a.props,n.data);case 2:return e.def(a.context,n.data);case 3:return e.def(\"this\",n.data);case 4:return n.data.append(t,e),n.data.ref}},t.attribCache={};var c={};return t.scopeAttrib=function(t){if((t=e.id(t))in c)return c[t];var n=u.scope[t];return n||(n=u.scope[t]=new Z),c[t]=r(n)},t}function _(t,e){var r=t.static,n=t.dynamic;if(\"framebuffer\"in r){var i=r.framebuffer;return i?(i=l.getFramebuffer(i),R(function(t,e){var r=t.link(i),n=t.shared;return e.set(n.framebuffer,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\".width\"),e.set(n,\".framebufferHeight\",r+\".height\"),r})):R(function(t,e){var r=t.shared;return e.set(r.framebuffer,\".next\",\"null\"),r=r.context,e.set(r,\".framebufferWidth\",r+\".drawingBufferWidth\"),e.set(r,\".framebufferHeight\",r+\".drawingBufferHeight\"),\"null\"})}if(\"framebuffer\"in n){var a=n.framebuffer;return F(a,function(t,e){var r=t.invoke(e,a),n=t.shared,i=n.framebuffer;r=e.def(i,\".getFramebuffer(\",r,\")\");return e.set(i,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\"?\"+r+\".width:\"+n+\".drawingBufferWidth\"),e.set(n,\".framebufferHeight\",r+\"?\"+r+\".height:\"+n+\".drawingBufferHeight\"),r})}return null}function w(t){function r(t){if(t in n){var r=e.id(n[t]);return(t=R(function(){return r})).id=r,t}if(t in i){var a=i[t];return F(a,function(t,e){var r=t.invoke(e,a);return e.def(t.shared.strings,\".id(\",r,\")\")})}return null}var n=t.static,i=t.dynamic,a=r(\"frag\"),o=r(\"vert\"),s=null;return D(a)&&D(o)?(s=h.program(o.id,a.id),t=R(function(t,e){return t.link(s)})):t=new I(a&&a.thisDep||o&&o.thisDep,a&&a.contextDep||o&&o.contextDep,a&&a.propDep||o&&o.propDep,function(t,e){var r,n,i=t.shared.shader;return r=a?a.append(t,e):e.def(i,\".\",\"frag\"),n=o?o.append(t,e):e.def(i,\".\",\"vert\"),e.def(i+\".program(\"+n+\",\"+r+\")\")}),{frag:a,vert:o,progVar:t,program:s}}function k(t,e){function r(t,e){if(t in n){var r=0|n[t];return R(function(t,n){return e&&(t.OFFSET=r),r})}if(t in i){var o=i[t];return F(o,function(t,r){var n=t.invoke(r,o);return e&&(t.OFFSET=n),n})}return e&&a?R(function(t,e){return t.OFFSET=\"0\",0}):null}var n=t.static,i=t.dynamic,a=function(){if(\"elements\"in n){var t=n.elements;O(t)?t=o.getElements(o.create(t,!0)):t&&(t=o.getElements(t));var e=R(function(e,r){if(t){var n=e.link(t);return e.ELEMENTS=n}return e.ELEMENTS=null});return e.value=t,e}if(\"elements\"in i){var r=i.elements;return F(r,function(t,e){var n=(i=t.shared).isBufferArgs,i=i.elements,a=t.invoke(e,r),o=e.def(\"null\");n=e.def(n,\"(\",a,\")\"),a=t.cond(n).then(o,\"=\",i,\".createStream(\",a,\");\").else(o,\"=\",i,\".getElements(\",a,\");\");return e.entry(a),e.exit(t.cond(n).then(i,\".destroyStream(\",o,\");\")),t.ELEMENTS=o})}return null}(),s=r(\"offset\",!0);return{elements:a,primitive:function(){if(\"primitive\"in n){var t=n.primitive;return R(function(e,r){return rt[t]})}if(\"primitive\"in i){var e=i.primitive;return F(e,function(t,r){var n=t.constants.primTypes,i=t.invoke(r,e);return r.def(n,\"[\",i,\"]\")})}return a?D(a)?a.value?R(function(t,e){return e.def(t.ELEMENTS,\".primType\")}):R(function(){return 4}):new I(a.thisDep,a.contextDep,a.propDep,function(t,e){var r=t.ELEMENTS;return e.def(r,\"?\",r,\".primType:\",4)}):null}(),count:function(){if(\"count\"in n){var t=0|n.count;return R(function(){return t})}if(\"count\"in i){var e=i.count;return F(e,function(t,r){return t.invoke(r,e)})}return a?D(a)?a?s?new I(s.thisDep,s.contextDep,s.propDep,function(t,e){return e.def(t.ELEMENTS,\".vertCount-\",t.OFFSET)}):R(function(t,e){return e.def(t.ELEMENTS,\".vertCount\")}):R(function(){return-1}):new I(a.thisDep||s.thisDep,a.contextDep||s.contextDep,a.propDep||s.propDep,function(t,e){var r=t.ELEMENTS;return t.OFFSET?e.def(r,\"?\",r,\".vertCount-\",t.OFFSET,\":-1\"):e.def(r,\"?\",r,\".vertCount:-1\")}):null}(),instances:r(\"instances\",!1),offset:s}}function T(t,r){var n=t.static,a=t.dynamic,o={};return Object.keys(n).forEach(function(t){var r=n[t],a=e.id(t),s=new Z;if(O(r))s.state=1,s.buffer=i.getBuffer(i.create(r,34962,!1,!0)),s.type=0;else if(c=i.getBuffer(r))s.state=1,s.buffer=c,s.type=0;else if(\"constant\"in r){var l=r.constant;s.buffer=\"null\",s.state=2,\"number\"==typeof l?s.x=l:bt.forEach(function(t,e){e<l.length&&(s[t]=l[e])})}else{var c=O(r.buffer)?i.getBuffer(i.create(r.buffer,34962,!1,!0)):i.getBuffer(r.buffer),u=0|r.offset,h=0|r.stride,f=0|r.size,p=!!r.normalized,d=0;\"type\"in r&&(d=K[r.type]),r=0|r.divisor,s.buffer=c,s.state=1,s.size=f,s.normalized=p,s.type=d||c.dtype,s.offset=u,s.stride=h,s.divisor=r}o[t]=R(function(t,e){var r=t.attribCache;if(a in r)return r[a];var n={isStream:!1};return Object.keys(s).forEach(function(t){n[t]=s[t]}),s.buffer&&(n.buffer=t.link(s.buffer),n.type=n.type||n.buffer+\".dtype\"),r[a]=n})}),Object.keys(a).forEach(function(t){var e=a[t];o[t]=F(e,function(t,r){function n(t){r(l[t],\"=\",i,\".\",t,\"|0;\")}var i=t.invoke(r,e),a=t.shared,o=a.isBufferArgs,s=a.buffer,l={isStream:r.def(!1)},c=new Z;c.state=1,Object.keys(c).forEach(function(t){l[t]=r.def(\"\"+c[t])});var u=l.buffer,h=l.type;return r(\"if(\",o,\"(\",i,\")){\",l.isStream,\"=true;\",u,\"=\",s,\".createStream(\",34962,\",\",i,\");\",h,\"=\",u,\".dtype;\",\"}else{\",u,\"=\",s,\".getBuffer(\",i,\");\",\"if(\",u,\"){\",h,\"=\",u,\".dtype;\",'}else if(\"constant\" in ',i,\"){\",l.state,\"=\",2,\";\",\"if(typeof \"+i+'.constant === \"number\"){',l[bt[0]],\"=\",i,\".constant;\",bt.slice(1).map(function(t){return l[t]}).join(\"=\"),\"=0;\",\"}else{\",bt.map(function(t,e){return l[t]+\"=\"+i+\".constant.length>\"+e+\"?\"+i+\".constant[\"+e+\"]:0;\"}).join(\"\"),\"}}else{\",\"if(\",o,\"(\",i,\".buffer)){\",u,\"=\",s,\".createStream(\",34962,\",\",i,\".buffer);\",\"}else{\",u,\"=\",s,\".getBuffer(\",i,\".buffer);\",\"}\",h,'=\"type\" in ',i,\"?\",a.glTypes,\"[\",i,\".type]:\",u,\".dtype;\",l.normalized,\"=!!\",i,\".normalized;\"),n(\"size\"),n(\"offset\"),n(\"stride\"),n(\"divisor\"),r(\"}}\"),r.exit(\"if(\",l.isStream,\"){\",s,\".destroyStream(\",u,\");\",\"}\"),l})}),o}function A(t,e,r,n,i){var o=_(t),s=function(t,e,r){function n(t){if(t in i){var r=i[t];t=!0;var n,o,s=0|r.x,l=0|r.y;return\"width\"in r?n=0|r.width:t=!1,\"height\"in r?o=0|r.height:t=!1,new I(!t&&e&&e.thisDep,!t&&e&&e.contextDep,!t&&e&&e.propDep,function(t,e){var i=t.shared.context,a=n;\"width\"in r||(a=e.def(i,\".\",\"framebufferWidth\",\"-\",s));var c=o;return\"height\"in r||(c=e.def(i,\".\",\"framebufferHeight\",\"-\",l)),[s,l,a,c]})}if(t in a){var c=a[t];return t=F(c,function(t,e){var r=t.invoke(e,c),n=t.shared.context,i=e.def(r,\".x|0\"),a=e.def(r,\".y|0\");return[i,a,e.def('\"width\" in ',r,\"?\",r,\".width|0:\",\"(\",n,\".\",\"framebufferWidth\",\"-\",i,\")\"),r=e.def('\"height\" in ',r,\"?\",r,\".height|0:\",\"(\",n,\".\",\"framebufferHeight\",\"-\",a,\")\")]}),e&&(t.thisDep=t.thisDep||e.thisDep,t.contextDep=t.contextDep||e.contextDep,t.propDep=t.propDep||e.propDep),t}return e?new I(e.thisDep,e.contextDep,e.propDep,function(t,e){var r=t.shared.context;return[0,0,e.def(r,\".\",\"framebufferWidth\"),e.def(r,\".\",\"framebufferHeight\")]}):null}var i=t.static,a=t.dynamic;if(t=n(\"viewport\")){var o=t;t=new I(t.thisDep,t.contextDep,t.propDep,function(t,e){var r=o.append(t,e),n=t.shared.context;return e.set(n,\".viewportWidth\",r[2]),e.set(n,\".viewportHeight\",r[3]),r})}return{viewport:t,scissor_box:n(\"scissor.box\")}}(t,o),l=k(t),c=function(t,e){var r=t.static,n=t.dynamic,i={};return nt.forEach(function(t){function e(e,a){if(t in r){var s=e(r[t]);i[o]=R(function(){return s})}else if(t in n){var l=n[t];i[o]=F(l,function(t,e){return a(t,e,t.invoke(e,l))})}}var o=m(t);switch(t){case\"cull.enable\":case\"blend.enable\":case\"dither\":case\"stencil.enable\":case\"depth.enable\":case\"scissor.enable\":case\"polygonOffset.enable\":case\"sample.alpha\":case\"sample.enable\":case\"depth.mask\":return e(function(t){return t},function(t,e,r){return r});case\"depth.func\":return e(function(t){return kt[t]},function(t,e,r){return e.def(t.constants.compareFuncs,\"[\",r,\"]\")});case\"depth.range\":return e(function(t){return t},function(t,e,r){return[e.def(\"+\",r,\"[0]\"),e=e.def(\"+\",r,\"[1]\")]});case\"blend.func\":return e(function(t){return[wt[\"srcRGB\"in t?t.srcRGB:t.src],wt[\"dstRGB\"in t?t.dstRGB:t.dst],wt[\"srcAlpha\"in t?t.srcAlpha:t.src],wt[\"dstAlpha\"in t?t.dstAlpha:t.dst]]},function(t,e,r){function n(t,n){return e.def('\"',t,n,'\" in ',r,\"?\",r,\".\",t,n,\":\",r,\".\",t)}t=t.constants.blendFuncs;var i=n(\"src\",\"RGB\"),a=n(\"dst\",\"RGB\"),o=(i=e.def(t,\"[\",i,\"]\"),e.def(t,\"[\",n(\"src\",\"Alpha\"),\"]\"));return[i,a=e.def(t,\"[\",a,\"]\"),o,t=e.def(t,\"[\",n(\"dst\",\"Alpha\"),\"]\")]});case\"blend.equation\":return e(function(t){return\"string\"==typeof t?[J[t],J[t]]:\"object\"==typeof t?[J[t.rgb],J[t.alpha]]:void 0},function(t,e,r){var n=t.constants.blendEquations,i=e.def(),a=e.def();return(t=t.cond(\"typeof \",r,'===\"string\"')).then(i,\"=\",a,\"=\",n,\"[\",r,\"];\"),t.else(i,\"=\",n,\"[\",r,\".rgb];\",a,\"=\",n,\"[\",r,\".alpha];\"),e(t),[i,a]});case\"blend.color\":return e(function(t){return a(4,function(e){return+t[e]})},function(t,e,r){return a(4,function(t){return e.def(\"+\",r,\"[\",t,\"]\")})});case\"stencil.mask\":return e(function(t){return 0|t},function(t,e,r){return e.def(r,\"|0\")});case\"stencil.func\":return e(function(t){return[kt[t.cmp||\"keep\"],t.ref||0,\"mask\"in t?t.mask:-1]},function(t,e,r){return[t=e.def('\"cmp\" in ',r,\"?\",t.constants.compareFuncs,\"[\",r,\".cmp]\",\":\",7680),e.def(r,\".ref|0\"),e=e.def('\"mask\" in ',r,\"?\",r,\".mask|0:-1\")]});case\"stencil.opFront\":case\"stencil.opBack\":return e(function(e){return[\"stencil.opBack\"===t?1029:1028,Tt[e.fail||\"keep\"],Tt[e.zfail||\"keep\"],Tt[e.zpass||\"keep\"]]},function(e,r,n){function i(t){return r.def('\"',t,'\" in ',n,\"?\",a,\"[\",n,\".\",t,\"]:\",7680)}var a=e.constants.stencilOps;return[\"stencil.opBack\"===t?1029:1028,i(\"fail\"),i(\"zfail\"),i(\"zpass\")]});case\"polygonOffset.offset\":return e(function(t){return[0|t.factor,0|t.units]},function(t,e,r){return[e.def(r,\".factor|0\"),e=e.def(r,\".units|0\")]});case\"cull.face\":return e(function(t){var e=0;return\"front\"===t?e=1028:\"back\"===t&&(e=1029),e},function(t,e,r){return e.def(r,'===\"front\"?',1028,\":\",1029)});case\"lineWidth\":return e(function(t){return t},function(t,e,r){return r});case\"frontFace\":return e(function(t){return At[t]},function(t,e,r){return e.def(r+'===\"cw\"?2304:2305')});case\"colorMask\":return e(function(t){return t.map(function(t){return!!t})},function(t,e,r){return a(4,function(t){return\"!!\"+r+\"[\"+t+\"]\"})});case\"sample.coverage\":return e(function(t){return[\"value\"in t?t.value:1,!!t.invert]},function(t,e,r){return[e.def('\"value\" in ',r,\"?+\",r,\".value:1\"),e=e.def(\"!!\",r,\".invert\")]})}}),i}(t),u=w(t),h=s.viewport;return h&&(c.viewport=h),(s=s[h=m(\"scissor.box\")])&&(c[h]=s),(o={framebuffer:o,draw:l,shader:u,state:c,dirty:s=0<Object.keys(c).length}).profile=function(t){var e,r=t.static;if(t=t.dynamic,\"profile\"in r){var n=!!r.profile;(e=R(function(t,e){return n})).enable=n}else if(\"profile\"in t){var i=t.profile;e=F(i,function(t,e){return t.invoke(e,i)})}return e}(t),o.uniforms=function(t,e){var r=t.static,n=t.dynamic,i={};return Object.keys(r).forEach(function(t){var e,n=r[t];if(\"number\"==typeof n||\"boolean\"==typeof n)e=R(function(){return n});else if(\"function\"==typeof n){var o=n._reglType;\"texture2d\"===o||\"textureCube\"===o?e=R(function(t){return t.link(n)}):\"framebuffer\"!==o&&\"framebufferCube\"!==o||(e=R(function(t){return t.link(n.color[0])}))}else v(n)&&(e=R(function(t){return t.global.def(\"[\",a(n.length,function(t){return n[t]}),\"]\")}));e.value=n,i[t]=e}),Object.keys(n).forEach(function(t){var e=n[t];i[t]=F(e,function(t,r){return t.invoke(r,e)})}),i}(r),o.attributes=T(e),o.context=function(t){var e=t.static,r=t.dynamic,n={};return Object.keys(e).forEach(function(t){var r=e[t];n[t]=R(function(t,e){return\"number\"==typeof r||\"boolean\"==typeof r?\"\"+r:t.link(r)})}),Object.keys(r).forEach(function(t){var e=r[t];n[t]=F(e,function(t,r){return t.invoke(r,e)})}),n}(n),o}function M(t,e,r){var n=t.shared.context,i=t.scope();Object.keys(r).forEach(function(a){e.save(n,\".\"+a),i(n,\".\",a,\"=\",r[a].append(t,e),\";\")}),e(i)}function S(t,e,r,n){var i,a=(s=t.shared).gl,o=s.framebuffer;Q&&(i=e.def(s.extensions,\".webgl_draw_buffers\"));var s=(l=t.constants).drawBuffer,l=l.backBuffer;t=r?r.append(t,e):e.def(o,\".next\"),n||e(\"if(\",t,\"!==\",o,\".cur){\"),e(\"if(\",t,\"){\",a,\".bindFramebuffer(\",36160,\",\",t,\".framebuffer);\"),Q&&e(i,\".drawBuffersWEBGL(\",s,\"[\",t,\".colorAttachments.length]);\"),e(\"}else{\",a,\".bindFramebuffer(\",36160,\",null);\"),Q&&e(i,\".drawBuffersWEBGL(\",l,\");\"),e(\"}\",o,\".cur=\",t,\";\"),n||e(\"}\")}function E(t,e,r){var n=t.shared,i=n.gl,o=t.current,s=t.next,l=n.current,c=n.next,u=t.cond(l,\".dirty\");nt.forEach(function(e){var n,h;if(!((e=m(e))in r.state))if(e in s){n=s[e],h=o[e];var f=a(tt[e].length,function(t){return u.def(n,\"[\",t,\"]\")});u(t.cond(f.map(function(t,e){return t+\"!==\"+h+\"[\"+e+\"]\"}).join(\"||\")).then(i,\".\",at[e],\"(\",f,\");\",f.map(function(t,e){return h+\"[\"+e+\"]=\"+t}).join(\";\"),\";\"))}else n=u.def(c,\".\",e),f=t.cond(n,\"!==\",l,\".\",e),u(f),e in it?f(t.cond(n).then(i,\".enable(\",it[e],\");\").else(i,\".disable(\",it[e],\");\"),l,\".\",e,\"=\",n,\";\"):f(i,\".\",at[e],\"(\",n,\");\",l,\".\",e,\"=\",n,\";\")}),0===Object.keys(r.state).length&&u(l,\".dirty=false;\"),e(u)}function C(t,e,r,n){var i=t.shared,a=t.current,o=i.current,s=i.gl;z(Object.keys(r)).forEach(function(i){var l=r[i];if(!n||n(l)){var c=l.append(t,e);if(it[i]){var u=it[i];D(l)?e(s,c?\".enable(\":\".disable(\",u,\");\"):e(t.cond(c).then(s,\".enable(\",u,\");\").else(s,\".disable(\",u,\");\")),e(o,\".\",i,\"=\",c,\";\")}else if(v(c)){var h=a[i];e(s,\".\",at[i],\"(\",c,\");\",c.map(function(t,e){return h+\"[\"+e+\"]=\"+t}).join(\";\"),\";\")}else e(s,\".\",at[i],\"(\",c,\");\",o,\".\",i,\"=\",c,\";\")}})}function L(t,e){$&&(t.instancing=e.def(t.shared.extensions,\".angle_instanced_arrays\"))}function B(t,e,r,n,i){function a(){return\"undefined\"==typeof performance?\"Date.now()\":\"performance.now()\"}function o(t){t(c=e.def(),\"=\",a(),\";\"),\"string\"==typeof i?t(f,\".count+=\",i,\";\"):t(f,\".count++;\"),d&&(n?t(u=e.def(),\"=\",g,\".getNumPendingQueries();\"):t(g,\".beginQuery(\",f,\");\"))}function s(t){t(f,\".cpuTime+=\",a(),\"-\",c,\";\"),d&&(n?t(g,\".pushScopeStats(\",u,\",\",g,\".getNumPendingQueries(),\",f,\");\"):t(g,\".endQuery();\"))}function l(t){var r=e.def(p,\".profile\");e(p,\".profile=\",t,\";\"),e.exit(p,\".profile=\",r,\";\")}var c,u,h=t.shared,f=t.stats,p=h.current,g=h.timer;if(r=r.profile){if(D(r))return void(r.enable?(o(e),s(e.exit),l(\"true\")):l(\"false\"));l(r=r.append(t,e))}else r=e.def(p,\".profile\");o(h=t.block()),e(\"if(\",r,\"){\",h,\"}\"),s(t=t.block()),e.exit(\"if(\",r,\"){\",t,\"}\")}function N(t,e,r,n,i){function a(r,n,i){function a(){e(\"if(!\",u,\".buffer){\",l,\".enableVertexAttribArray(\",c,\");}\");var r,a=i.type;r=i.size?e.def(i.size,\"||\",n):n,e(\"if(\",u,\".type!==\",a,\"||\",u,\".size!==\",r,\"||\",p.map(function(t){return u+\".\"+t+\"!==\"+i[t]}).join(\"||\"),\"){\",l,\".bindBuffer(\",34962,\",\",h,\".buffer);\",l,\".vertexAttribPointer(\",[c,r,a,i.normalized,i.stride,i.offset],\");\",u,\".type=\",a,\";\",u,\".size=\",r,\";\",p.map(function(t){return u+\".\"+t+\"=\"+i[t]+\";\"}).join(\"\"),\"}\"),$&&(a=i.divisor,e(\"if(\",u,\".divisor!==\",a,\"){\",t.instancing,\".vertexAttribDivisorANGLE(\",[c,a],\");\",u,\".divisor=\",a,\";}\"))}function s(){e(\"if(\",u,\".buffer){\",l,\".disableVertexAttribArray(\",c,\");\",\"}if(\",bt.map(function(t,e){return u+\".\"+t+\"!==\"+f[e]}).join(\"||\"),\"){\",l,\".vertexAttrib4f(\",c,\",\",f,\");\",bt.map(function(t,e){return u+\".\"+t+\"=\"+f[e]+\";\"}).join(\"\"),\"}\")}var l=o.gl,c=e.def(r,\".location\"),u=e.def(o.attributes,\"[\",c,\"]\");r=i.state;var h=i.buffer,f=[i.x,i.y,i.z,i.w],p=[\"buffer\",\"normalized\",\"offset\",\"stride\"];1===r?a():2===r?s():(e(\"if(\",r,\"===\",1,\"){\"),a(),e(\"}else{\"),s(),e(\"}\"))}var o=t.shared;n.forEach(function(n){var o,s=n.name,l=r.attributes[s];if(l){if(!i(l))return;o=l.append(t,e)}else{if(!i(Mt))return;var c=t.scopeAttrib(s);o={},Object.keys(new Z).forEach(function(t){o[t]=e.def(c,\".\",t)})}a(t.link(n),function(t){switch(t){case 35664:case 35667:case 35671:return 2;case 35665:case 35668:case 35672:return 3;case 35666:case 35669:case 35673:return 4;default:return 1}}(n.info.type),o)})}function j(t,r,n,i,o){for(var s,l=t.shared,c=l.gl,u=0;u<i.length;++u){var h,f=(g=i[u]).name,p=g.info.type,d=n.uniforms[f],g=t.link(g)+\".location\";if(d){if(!o(d))continue;if(D(d)){if(f=d.value,35678===p||35680===p)r(c,\".uniform1i(\",g,\",\",(p=t.link(f._texture||f.color[0]._texture))+\".bind());\"),r.exit(p,\".unbind();\");else if(35674===p||35675===p||35676===p)d=2,35675===p?d=3:35676===p&&(d=4),r(c,\".uniformMatrix\",d,\"fv(\",g,\",false,\",f=t.global.def(\"new Float32Array([\"+Array.prototype.slice.call(f)+\"])\"),\");\");else{switch(p){case 5126:s=\"1f\";break;case 35664:s=\"2f\";break;case 35665:s=\"3f\";break;case 35666:s=\"4f\";break;case 35670:case 5124:s=\"1i\";break;case 35671:case 35667:s=\"2i\";break;case 35672:case 35668:s=\"3i\";break;case 35673:s=\"4i\";break;case 35669:s=\"4i\"}r(c,\".uniform\",s,\"(\",g,\",\",v(f)?Array.prototype.slice.call(f):f,\");\")}continue}h=d.append(t,r)}else{if(!o(Mt))continue;h=r.def(l.uniforms,\"[\",e.id(f),\"]\")}switch(35678===p?r(\"if(\",h,\"&&\",h,'._reglType===\"framebuffer\"){',h,\"=\",h,\".color[0];\",\"}\"):35680===p&&r(\"if(\",h,\"&&\",h,'._reglType===\"framebufferCube\"){',h,\"=\",h,\".color[0];\",\"}\"),f=1,p){case 35678:case 35680:p=r.def(h,\"._texture\"),r(c,\".uniform1i(\",g,\",\",p,\".bind());\"),r.exit(p,\".unbind();\");continue;case 5124:case 35670:s=\"1i\";break;case 35667:case 35671:s=\"2i\",f=2;break;case 35668:case 35672:s=\"3i\",f=3;break;case 35669:case 35673:s=\"4i\",f=4;break;case 5126:s=\"1f\";break;case 35664:s=\"2f\",f=2;break;case 35665:s=\"3f\",f=3;break;case 35666:s=\"4f\",f=4;break;case 35674:s=\"Matrix2fv\";break;case 35675:s=\"Matrix3fv\";break;case 35676:s=\"Matrix4fv\"}if(r(c,\".uniform\",s,\"(\",g,\",\"),\"M\"===s.charAt(0)){g=Math.pow(p-35674+2,2);var m=t.global.def(\"new Float32Array(\",g,\")\");r(\"false,(Array.isArray(\",h,\")||\",h,\" instanceof Float32Array)?\",h,\":(\",a(g,function(t){return m+\"[\"+t+\"]=\"+h+\"[\"+t+\"]\"}),\",\",m,\")\")}else r(1<f?a(f,function(t){return h+\"[\"+t+\"]\"}):h);r(\");\")}}function U(t,e,r,n){function i(i){var a=f[i];return a?a.contextDep&&n.contextDynamic||a.propDep?a.append(t,r):a.append(t,e):e.def(h,\".\",i)}function a(){function t(){r(l,\".drawElementsInstancedANGLE(\",[d,v,m,g+\"<<((\"+m+\"-5121)>>1)\",s],\");\")}function e(){r(l,\".drawArraysInstancedANGLE(\",[d,g,v,s],\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}function o(){function t(){r(u+\".drawElements(\"+[d,v,m,g+\"<<((\"+m+\"-5121)>>1)\"]+\");\")}function e(){r(u+\".drawArrays(\"+[d,g,v]+\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}var s,l,c=t.shared,u=c.gl,h=c.draw,f=n.draw,p=function(){var i=f.elements,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(h,\".\",\"elements\"),i&&a(\"if(\"+i+\")\"+u+\".bindBuffer(34963,\"+i+\".buffer.buffer);\"),i}(),d=i(\"primitive\"),g=i(\"offset\"),v=function(){var i=f.count,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(h,\".\",\"count\"),i}();if(\"number\"==typeof v){if(0===v)return}else r(\"if(\",v,\"){\"),r.exit(\"}\");$&&(s=i(\"instances\"),l=t.instancing);var m=p+\".type\",y=f.elements&&D(f.elements);$&&(\"number\"!=typeof s||0<=s)?\"string\"==typeof s?(r(\"if(\",s,\">0){\"),a(),r(\"}else if(\",s,\"<0){\"),o(),r(\"}\")):a():o()}function q(t,e,r,n,i){return i=(e=b()).proc(\"body\",i),$&&(e.instancing=i.def(e.shared.extensions,\".angle_instanced_arrays\")),t(e,i,r,n),e.compile().body}function H(t,e,r,n){L(t,e),N(t,e,r,n.attributes,function(){return!0}),j(t,e,r,n.uniforms,function(){return!0}),U(t,e,e,r)}function G(t,e,r,n){function i(){return!0}t.batchId=\"a1\",L(t,e),N(t,e,r,n.attributes,i),j(t,e,r,n.uniforms,i),U(t,e,e,r)}function Y(t,e,r,n){function i(t){return t.contextDep&&o||t.propDep}function a(t){return!i(t)}L(t,e);var o=r.contextDep,s=e.def(),l=e.def();t.shared.props=l,t.batchId=s;var c=t.scope(),u=t.scope();e(c.entry,\"for(\",s,\"=0;\",s,\"<\",\"a1\",\";++\",s,\"){\",l,\"=\",\"a0\",\"[\",s,\"];\",u,\"}\",c.exit),r.needsContext&&M(t,u,r.context),r.needsFramebuffer&&S(t,u,r.framebuffer),C(t,u,r.state,i),r.profile&&i(r.profile)&&B(t,u,r,!1,!0),n?(N(t,c,r,n.attributes,a),N(t,u,r,n.attributes,i),j(t,c,r,n.uniforms,a),j(t,u,r,n.uniforms,i),U(t,c,u,r)):(e=t.global.def(\"{}\"),n=r.shader.progVar.append(t,u),l=u.def(n,\".id\"),c=u.def(e,\"[\",l,\"]\"),u(t.shared.gl,\".useProgram(\",n,\".program);\",\"if(!\",c,\"){\",c,\"=\",e,\"[\",l,\"]=\",t.link(function(e){return q(G,t,r,e,2)}),\"(\",n,\");}\",c,\".call(this,a0[\",s,\"],\",s,\");\"))}function W(t,r){function n(e){var n=r.shader[e];n&&i.set(a.shader,\".\"+e,n.append(t,i))}var i=t.proc(\"scope\",3);t.batchId=\"a2\";var a=t.shared,o=a.current;M(t,i,r.context),r.framebuffer&&r.framebuffer.append(t,i),z(Object.keys(r.state)).forEach(function(e){var n=r.state[e].append(t,i);v(n)?n.forEach(function(r,n){i.set(t.next[e],\"[\"+n+\"]\",r)}):i.set(a.next,\".\"+e,n)}),B(t,i,r,!0,!0),[\"elements\",\"offset\",\"count\",\"instances\",\"primitive\"].forEach(function(e){var n=r.draw[e];n&&i.set(a.draw,\".\"+e,\"\"+n.append(t,i))}),Object.keys(r.uniforms).forEach(function(n){i.set(a.uniforms,\"[\"+e.id(n)+\"]\",r.uniforms[n].append(t,i))}),Object.keys(r.attributes).forEach(function(e){var n=r.attributes[e].append(t,i),a=t.scopeAttrib(e);Object.keys(new Z).forEach(function(t){i.set(a,\".\"+t,n[t])})}),n(\"vert\"),n(\"frag\"),0<Object.keys(r.state).length&&(i(o,\".dirty=true;\"),i.exit(o,\".dirty=true;\")),i(\"a1(\",t.shared.context,\",a0,\",t.batchId,\");\")}function X(t,e,r){var n=e.static[r];if(n&&function(t){if(\"object\"==typeof t&&!v(t)){for(var e=Object.keys(t),r=0;r<e.length;++r)if(V.isDynamic(t[e[r]]))return!0;return!1}}(n)){var i=t.global,a=Object.keys(n),o=!1,s=!1,l=!1,c=t.global.def(\"{}\");a.forEach(function(e){var r=n[e];if(V.isDynamic(r))\"function\"==typeof r&&(r=n[e]=V.unbox(r)),e=F(r,null),o=o||e.thisDep,l=l||e.propDep,s=s||e.contextDep;else{switch(i(c,\".\",e,\"=\"),typeof r){case\"number\":i(r);break;case\"string\":i('\"',r,'\"');break;case\"object\":Array.isArray(r)&&i(\"[\",r.join(),\"]\");break;default:i(t.link(r))}i(\";\")}}),e.dynamic[r]=new V.DynamicVariable(4,{thisDep:o,contextDep:s,propDep:l,ref:c,append:function(t,e){a.forEach(function(r){var i=n[r];V.isDynamic(i)&&(i=t.invoke(e,i),e(c,\".\",r,\"=\",i,\";\"))})}}),delete e.static[r]}}var Z=u.Record,J={add:32774,subtract:32778,\"reverse subtract\":32779};r.ext_blend_minmax&&(J.min=32775,J.max=32776);var $=r.angle_instanced_arrays,Q=r.webgl_draw_buffers,tt={dirty:!0,profile:g.profile},et={},nt=[],it={},at={};y(\"dither\",3024),y(\"blend.enable\",3042),x(\"blend.color\",\"blendColor\",[0,0,0,0]),x(\"blend.equation\",\"blendEquationSeparate\",[32774,32774]),x(\"blend.func\",\"blendFuncSeparate\",[1,0,1,0]),y(\"depth.enable\",2929,!0),x(\"depth.func\",\"depthFunc\",513),x(\"depth.range\",\"depthRange\",[0,1]),x(\"depth.mask\",\"depthMask\",!0),x(\"colorMask\",\"colorMask\",[!0,!0,!0,!0]),y(\"cull.enable\",2884),x(\"cull.face\",\"cullFace\",1029),x(\"frontFace\",\"frontFace\",2305),x(\"lineWidth\",\"lineWidth\",1),y(\"polygonOffset.enable\",32823),x(\"polygonOffset.offset\",\"polygonOffset\",[0,0]),y(\"sample.alpha\",32926),y(\"sample.enable\",32928),x(\"sample.coverage\",\"sampleCoverage\",[1,!1]),y(\"stencil.enable\",2960),x(\"stencil.mask\",\"stencilMask\",-1),x(\"stencil.func\",\"stencilFunc\",[519,0,-1]),x(\"stencil.opFront\",\"stencilOpSeparate\",[1028,7680,7680,7680]),x(\"stencil.opBack\",\"stencilOpSeparate\",[1029,7680,7680,7680]),y(\"scissor.enable\",3089),x(\"scissor.box\",\"scissor\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]),x(\"viewport\",\"viewport\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]);var ot={gl:t,context:p,strings:e,next:et,current:tt,draw:f,elements:o,buffer:i,shader:h,attributes:u.state,uniforms:c,framebuffer:l,extensions:r,timer:d,isBufferArgs:O},st={primTypes:rt,compareFuncs:kt,blendFuncs:wt,blendEquations:J,stencilOps:Tt,glTypes:K,orientationType:At};Q&&(st.backBuffer=[1029],st.drawBuffer=a(n.maxDrawbuffers,function(t){return 0===t?[0]:a(t,function(t){return 36064+t})}));var lt=0;return{next:et,current:tt,procs:function(){var t=b(),e=t.proc(\"poll\"),r=t.proc(\"refresh\"),i=t.block();e(i),r(i);var o,s=t.shared,l=s.gl,c=s.next,u=s.current;i(u,\".dirty=false;\"),S(t,e),S(t,r,null,!0),$&&(o=t.link($));for(var h=0;h<n.maxAttributes;++h){var f=r.def(s.attributes,\"[\",h,\"]\"),p=t.cond(f,\".buffer\");p.then(l,\".enableVertexAttribArray(\",h,\");\",l,\".bindBuffer(\",34962,\",\",f,\".buffer.buffer);\",l,\".vertexAttribPointer(\",h,\",\",f,\".size,\",f,\".type,\",f,\".normalized,\",f,\".stride,\",f,\".offset);\").else(l,\".disableVertexAttribArray(\",h,\");\",l,\".vertexAttrib4f(\",h,\",\",f,\".x,\",f,\".y,\",f,\".z,\",f,\".w);\",f,\".buffer=null;\"),r(p),$&&r(o,\".vertexAttribDivisorANGLE(\",h,\",\",f,\".divisor);\")}return Object.keys(it).forEach(function(n){var a=it[n],o=i.def(c,\".\",n),s=t.block();s(\"if(\",o,\"){\",l,\".enable(\",a,\")}else{\",l,\".disable(\",a,\")}\",u,\".\",n,\"=\",o,\";\"),r(s),e(\"if(\",o,\"!==\",u,\".\",n,\"){\",s,\"}\")}),Object.keys(at).forEach(function(n){var o,s,h=at[n],f=tt[n],p=t.block();p(l,\".\",h,\"(\"),v(f)?(h=f.length,o=t.global.def(c,\".\",n),s=t.global.def(u,\".\",n),p(a(h,function(t){return o+\"[\"+t+\"]\"}),\");\",a(h,function(t){return s+\"[\"+t+\"]=\"+o+\"[\"+t+\"];\"}).join(\"\")),e(\"if(\",a(h,function(t){return o+\"[\"+t+\"]!==\"+s+\"[\"+t+\"]\"}).join(\"||\"),\"){\",p,\"}\")):(o=i.def(c,\".\",n),s=i.def(u,\".\",n),p(o,\");\",u,\".\",n,\"=\",o,\";\"),e(\"if(\",o,\"!==\",s,\"){\",p,\"}\")),r(p)}),t.compile()}(),compile:function(t,e,r,n,i){var a=b();return a.stats=a.link(i),Object.keys(e.static).forEach(function(t){X(a,e,t)}),_t.forEach(function(e){X(a,t,e)}),r=A(t,e,r,n),function(t,e){var r=t.proc(\"draw\",1);L(t,r),M(t,r,e.context),S(t,r,e.framebuffer),E(t,r,e),C(t,r,e.state),B(t,r,e,!1,!0);var n=e.shader.progVar.append(t,r);if(r(t.shared.gl,\".useProgram(\",n,\".program);\"),e.shader.program)H(t,r,e,e.shader.program);else{var i=t.global.def(\"{}\"),a=r.def(n,\".id\"),o=r.def(i,\"[\",a,\"]\");r(t.cond(o).then(o,\".call(this,a0);\").else(o,\"=\",i,\"[\",a,\"]=\",t.link(function(r){return q(H,t,e,r,1)}),\"(\",n,\");\",o,\".call(this,a0);\"))}0<Object.keys(e.state).length&&r(t.shared.current,\".dirty=true;\")}(a,r),W(a,r),function(t,e){function r(t){return t.contextDep&&i||t.propDep}var n=t.proc(\"batch\",2);t.batchId=\"0\",L(t,n);var i=!1,a=!0;Object.keys(e.context).forEach(function(t){i=i||e.context[t].propDep}),i||(M(t,n,e.context),a=!1);var o=!1;if((s=e.framebuffer)?(s.propDep?i=o=!0:s.contextDep&&i&&(o=!0),o||S(t,n,s)):S(t,n,null),e.state.viewport&&e.state.viewport.propDep&&(i=!0),E(t,n,e),C(t,n,e.state,function(t){return!r(t)}),e.profile&&r(e.profile)||B(t,n,e,!1,\"a1\"),e.contextDep=i,e.needsContext=a,e.needsFramebuffer=o,(a=e.shader.progVar).contextDep&&i||a.propDep)Y(t,n,e,null);else if(a=a.append(t,n),n(t.shared.gl,\".useProgram(\",a,\".program);\"),e.shader.program)Y(t,n,e,e.shader.program);else{var s=t.global.def(\"{}\"),l=(o=n.def(a,\".id\"),n.def(s,\"[\",o,\"]\"));n(t.cond(l).then(l,\".call(this,a0,a1);\").else(l,\"=\",s,\"[\",o,\"]=\",t.link(function(r){return q(Y,t,e,r,2)}),\"(\",a,\");\",l,\".call(this,a0,a1);\"))}0<Object.keys(e.state).length&&n(t.shared.current,\".dirty=true;\")}(a,r),a.compile()}}}function N(t,e){for(var r=0;r<t.length;++r)if(t[r]===e)return r;return-1}var j=function(t,e){for(var r=Object.keys(e),n=0;n<r.length;++n)t[r[n]]=e[r[n]];return t},U=0,V={DynamicVariable:t,define:function(r,n){return new t(r,e(n+\"\"))},isDynamic:function(e){return\"function\"==typeof e&&!e._reglType||e instanceof t},unbox:function(e,r){return\"function\"==typeof e?new t(0,e):e},accessor:e},q={next:\"function\"==typeof requestAnimationFrame?function(t){return requestAnimationFrame(t)}:function(t){return setTimeout(t,16)},cancel:\"function\"==typeof cancelAnimationFrame?function(t){return cancelAnimationFrame(t)}:clearTimeout},H=\"undefined\"!=typeof performance&&performance.now?function(){return performance.now()}:function(){return+new Date},G=s();G.zero=s();var Y=function(t,e){var r=1;e.ext_texture_filter_anisotropic&&(r=t.getParameter(34047));var n=1,i=1;e.webgl_draw_buffers&&(n=t.getParameter(34852),i=t.getParameter(36063));var a=!!e.oes_texture_float;if(a){a=t.createTexture(),t.bindTexture(3553,a),t.texImage2D(3553,0,6408,1,1,0,6408,5126,null);var o=t.createFramebuffer();if(t.bindFramebuffer(36160,o),t.framebufferTexture2D(36160,36064,3553,a,0),t.bindTexture(3553,null),36053!==t.checkFramebufferStatus(36160))a=!1;else{t.viewport(0,0,1,1),t.clearColor(1,0,0,1),t.clear(16384);var s=G.allocType(5126,4);t.readPixels(0,0,1,1,6408,5126,s),t.getError()?a=!1:(t.deleteFramebuffer(o),t.deleteTexture(a),a=1===s[0]),G.freeType(s)}}return s=!0,\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion)||/Edge/.test(navigator.userAgent))||(s=t.createTexture(),o=G.allocType(5121,36),t.activeTexture(33984),t.bindTexture(34067,s),t.texImage2D(34069,0,6408,3,3,0,6408,5121,o),G.freeType(o),t.bindTexture(34067,null),t.deleteTexture(s),s=!t.getError()),{colorBits:[t.getParameter(3410),t.getParameter(3411),t.getParameter(3412),t.getParameter(3413)],depthBits:t.getParameter(3414),stencilBits:t.getParameter(3415),subpixelBits:t.getParameter(3408),extensions:Object.keys(e).filter(function(t){return!!e[t]}),maxAnisotropic:r,maxDrawbuffers:n,maxColorAttachments:i,pointSizeDims:t.getParameter(33901),lineWidthDims:t.getParameter(33902),maxViewportDims:t.getParameter(3386),maxCombinedTextureUnits:t.getParameter(35661),maxCubeMapSize:t.getParameter(34076),maxRenderbufferSize:t.getParameter(34024),maxTextureUnits:t.getParameter(34930),maxTextureSize:t.getParameter(3379),maxAttributes:t.getParameter(34921),maxVertexUniforms:t.getParameter(36347),maxVertexTextureUnits:t.getParameter(35660),maxVaryingVectors:t.getParameter(36348),maxFragmentUniforms:t.getParameter(36349),glsl:t.getParameter(35724),renderer:t.getParameter(7937),vendor:t.getParameter(7936),version:t.getParameter(7938),readFloat:a,npotTextureCube:s}},W=function(t){return t instanceof Uint8Array||t instanceof Uint16Array||t instanceof Uint32Array||t instanceof Int8Array||t instanceof Int16Array||t instanceof Int32Array||t instanceof Float32Array||t instanceof Float64Array||t instanceof Uint8ClampedArray},X=function(t){return Object.keys(t).map(function(e){return t[e]})},Z={shape:function(t){for(var e=[];t.length;t=t[0])e.push(t.length);return e},flatten:function(t,e,r,n){var i=1;if(e.length)for(var a=0;a<e.length;++a)i*=e[a];else i=0;switch(r=n||G.allocType(r,i),e.length){case 0:break;case 1:for(n=e[0],e=0;e<n;++e)r[e]=t[e];break;case 2:for(n=e[0],e=e[1],a=i=0;a<n;++a)for(var o=t[a],s=0;s<e;++s)r[i++]=o[s];break;case 3:c(t,e[0],e[1],e[2],r,0);break;default:!function t(e,r,n,i,a){for(var o=1,s=n+1;s<r.length;++s)o*=r[s];var l=r[n];if(4==r.length-n){var u=r[n+1],h=r[n+2];for(r=r[n+3],s=0;s<l;++s)c(e[s],u,h,r,i,a),a+=o}else for(s=0;s<l;++s)t(e[s],r,n+1,i,a),a+=o}(t,e,0,r,0)}return r}},J={\"[object Int8Array]\":5120,\"[object Int16Array]\":5122,\"[object Int32Array]\":5124,\"[object Uint8Array]\":5121,\"[object Uint8ClampedArray]\":5121,\"[object Uint16Array]\":5123,\"[object Uint32Array]\":5125,\"[object Float32Array]\":5126,\"[object Float64Array]\":5121,\"[object ArrayBuffer]\":5121},K={int8:5120,int16:5122,int32:5124,uint8:5121,uint16:5123,uint32:5125,float:5126,float32:5126},$={dynamic:35048,stream:35040,static:35044},Q=Z.flatten,tt=Z.shape,et=[];et[5120]=1,et[5122]=2,et[5124]=4,et[5121]=1,et[5123]=2,et[5125]=4,et[5126]=4;var rt={points:0,point:0,lines:1,line:1,triangles:4,triangle:4,\"line loop\":2,\"line strip\":3,\"triangle strip\":5,\"triangle fan\":6},nt=new Float32Array(1),it=new Uint32Array(nt.buffer),at=[9984,9986,9985,9987],ot=[0,6409,6410,6407,6408],st={};st[6409]=st[6406]=st[6402]=1,st[34041]=st[6410]=2,st[6407]=st[35904]=3,st[6408]=st[35906]=4;var lt=m(\"HTMLCanvasElement\"),ct=m(\"CanvasRenderingContext2D\"),ut=m(\"ImageBitmap\"),ht=m(\"HTMLImageElement\"),ft=m(\"HTMLVideoElement\"),pt=Object.keys(J).concat([lt,ct,ut,ht,ft]),dt=[];dt[5121]=1,dt[5126]=4,dt[36193]=2,dt[5123]=2,dt[5125]=4;var gt=[];gt[32854]=2,gt[32855]=2,gt[36194]=2,gt[34041]=4,gt[33776]=.5,gt[33777]=.5,gt[33778]=1,gt[33779]=1,gt[35986]=.5,gt[35987]=1,gt[34798]=1,gt[35840]=.5,gt[35841]=.25,gt[35842]=.5,gt[35843]=.25,gt[36196]=.5;var vt=[];vt[32854]=2,vt[32855]=2,vt[36194]=2,vt[33189]=2,vt[36168]=1,vt[34041]=4,vt[35907]=4,vt[34836]=16,vt[34842]=8,vt[34843]=6;var mt=function(t,e,r,n,i){function a(t){this.id=c++,this.refCount=1,this.renderbuffer=t,this.format=32854,this.height=this.width=0,i.profile&&(this.stats={size:0})}function o(e){var r=e.renderbuffer;t.bindRenderbuffer(36161,null),t.deleteRenderbuffer(r),e.renderbuffer=null,e.refCount=0,delete u[e.id],n.renderbufferCount--}var s={rgba4:32854,rgb565:36194,\"rgb5 a1\":32855,depth:33189,stencil:36168,\"depth stencil\":34041};e.ext_srgb&&(s.srgba=35907),e.ext_color_buffer_half_float&&(s.rgba16f=34842,s.rgb16f=34843),e.webgl_color_buffer_float&&(s.rgba32f=34836);var l=[];Object.keys(s).forEach(function(t){l[s[t]]=t});var c=0,u={};return a.prototype.decRef=function(){0>=--this.refCount&&o(this)},i.profile&&(n.getTotalRenderbufferSize=function(){var t=0;return Object.keys(u).forEach(function(e){t+=u[e].stats.size}),t}),{create:function(e,r){function o(e,r){var n=0,a=0,u=32854;if(\"object\"==typeof e&&e?(\"shape\"in e?(n=0|(a=e.shape)[0],a=0|a[1]):(\"radius\"in e&&(n=a=0|e.radius),\"width\"in e&&(n=0|e.width),\"height\"in e&&(a=0|e.height)),\"format\"in e&&(u=s[e.format])):\"number\"==typeof e?(n=0|e,a=\"number\"==typeof r?0|r:n):e||(n=a=1),n!==c.width||a!==c.height||u!==c.format)return o.width=c.width=n,o.height=c.height=a,c.format=u,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,u,n,a),i.profile&&(c.stats.size=vt[c.format]*c.width*c.height),o.format=l[c.format],o}var c=new a(t.createRenderbuffer());return u[c.id]=c,n.renderbufferCount++,o(e,r),o.resize=function(e,r){var n=0|e,a=0|r||n;return n===c.width&&a===c.height?o:(o.width=c.width=n,o.height=c.height=a,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,c.format,n,a),i.profile&&(c.stats.size=vt[c.format]*c.width*c.height),o)},o._reglType=\"renderbuffer\",o._renderbuffer=c,i.profile&&(o.stats=c.stats),o.destroy=function(){c.decRef()},o},clear:function(){X(u).forEach(o)},restore:function(){X(u).forEach(function(e){e.renderbuffer=t.createRenderbuffer(),t.bindRenderbuffer(36161,e.renderbuffer),t.renderbufferStorage(36161,e.format,e.width,e.height)}),t.bindRenderbuffer(36161,null)}}},yt=[];yt[6408]=4,yt[6407]=3;var xt=[];xt[5121]=1,xt[5126]=4,xt[36193]=2;var bt=[\"x\",\"y\",\"z\",\"w\"],_t=\"blend.func blend.equation stencil.func stencil.opFront stencil.opBack sample.coverage viewport scissor.box polygonOffset.offset\".split(\" \"),wt={0:0,1:1,zero:0,one:1,\"src color\":768,\"one minus src color\":769,\"src alpha\":770,\"one minus src alpha\":771,\"dst color\":774,\"one minus dst color\":775,\"dst alpha\":772,\"one minus dst alpha\":773,\"constant color\":32769,\"one minus constant color\":32770,\"constant alpha\":32771,\"one minus constant alpha\":32772,\"src alpha saturate\":776},kt={never:512,less:513,\"<\":513,equal:514,\"=\":514,\"==\":514,\"===\":514,lequal:515,\"<=\":515,greater:516,\">\":516,notequal:517,\"!=\":517,\"!==\":517,gequal:518,\">=\":518,always:519},Tt={0:0,zero:0,keep:7680,replace:7681,increment:7682,decrement:7683,\"increment wrap\":34055,\"decrement wrap\":34056,invert:5386},At={cw:2304,ccw:2305},Mt=new I(!1,!1,!1,function(){});return function(t){function e(){if(0===Z.length)w&&w.update(),Q=null;else{Q=q.next(e),h();for(var t=Z.length-1;0<=t;--t){var r=Z[t];r&&r(P,null,0)}v.flush(),w&&w.update()}}function r(){!Q&&0<Z.length&&(Q=q.next(e))}function n(){Q&&(q.cancel(e),Q=null)}function a(t){t.preventDefault(),n(),J.forEach(function(t){t()})}function o(t){v.getError(),y.restore(),D.restore(),z.restore(),R.restore(),F.restore(),U.restore(),w&&w.restore(),G.procs.refresh(),r(),K.forEach(function(t){t()})}function s(t){function e(t){var e={},r={};return Object.keys(t).forEach(function(n){var i=t[n];V.isDynamic(i)?r[n]=V.unbox(i,n):e[n]=i}),{dynamic:r,static:e}}var r=e(t.context||{}),n=e(t.uniforms||{}),i=e(t.attributes||{}),a=e(function(t){function e(t){if(t in r){var e=r[t];delete r[t],Object.keys(e).forEach(function(n){r[t+\".\"+n]=e[n]})}}var r=j({},t);return delete r.uniforms,delete r.attributes,delete r.context,\"stencil\"in r&&r.stencil.op&&(r.stencil.opBack=r.stencil.opFront=r.stencil.op,delete r.stencil.op),e(\"blend\"),e(\"depth\"),e(\"cull\"),e(\"stencil\"),e(\"polygonOffset\"),e(\"scissor\"),e(\"sample\"),r}(t));t={gpuTime:0,cpuTime:0,count:0};var o=(r=G.compile(a,i,n,r,t)).draw,s=r.batch,l=r.scope,c=[];return j(function(t,e){var r;if(\"function\"==typeof t)return l.call(this,null,t,0);if(\"function\"==typeof e)if(\"number\"==typeof t)for(r=0;r<t;++r)l.call(this,null,e,r);else{if(!Array.isArray(t))return l.call(this,t,e,0);for(r=0;r<t.length;++r)l.call(this,t[r],e,r)}else if(\"number\"==typeof t){if(0<t)return s.call(this,function(t){for(;c.length<t;)c.push(null);return c}(0|t),0|t)}else{if(!Array.isArray(t))return o.call(this,t);if(t.length)return s.call(this,t,t.length)}},{stats:t})}function l(t,e){var r=0;G.procs.poll();var n=e.color;n&&(v.clearColor(+n[0]||0,+n[1]||0,+n[2]||0,+n[3]||0),r|=16384),\"depth\"in e&&(v.clearDepth(+e.depth),r|=256),\"stencil\"in e&&(v.clearStencil(0|e.stencil),r|=1024),v.clear(r)}function c(t){return Z.push(t),r(),{cancel:function(){var e=N(Z,t);Z[e]=function t(){var e=N(Z,t);Z[e]=Z[Z.length-1],--Z.length,0>=Z.length&&n()}}}}function u(){var t=W.viewport,e=W.scissor_box;t[0]=t[1]=e[0]=e[1]=0,P.viewportWidth=P.framebufferWidth=P.drawingBufferWidth=t[2]=e[2]=v.drawingBufferWidth,P.viewportHeight=P.framebufferHeight=P.drawingBufferHeight=t[3]=e[3]=v.drawingBufferHeight}function h(){P.tick+=1,P.time=g(),u(),G.procs.poll()}function f(){u(),G.procs.refresh(),w&&w.update()}function g(){return(H()-k)/1e3}if(!(t=i(t)))return null;var v=t.gl,m=v.getContextAttributes();v.isContextLost();var y=function(t,e){function r(e){var r;e=e.toLowerCase();try{r=n[e]=t.getExtension(e)}catch(t){}return!!r}for(var n={},i=0;i<e.extensions.length;++i){var a=e.extensions[i];if(!r(a))return e.onDestroy(),e.onDone('\"'+a+'\" extension is not supported by the current WebGL context, try upgrading your system or a different browser'),null}return e.optionalExtensions.forEach(r),{extensions:n,restore:function(){Object.keys(n).forEach(function(t){if(n[t]&&!r(t))throw Error(\"(regl): error restoring extension \"+t)})}}}(v,t);if(!y)return null;var x=function(){var t={\"\":0},e=[\"\"];return{id:function(r){var n=t[r];return n||(n=t[r]=e.length,e.push(r),n)},str:function(t){return e[t]}}}(),b={bufferCount:0,elementsCount:0,framebufferCount:0,shaderCount:0,textureCount:0,cubeCount:0,renderbufferCount:0,maxTextureUnits:0},_=y.extensions,w=function(t,e){function r(){this.endQueryIndex=this.startQueryIndex=-1,this.sum=0,this.stats=null}function n(t,e,n){var i=o.pop()||new r;i.startQueryIndex=t,i.endQueryIndex=e,i.sum=0,i.stats=n,s.push(i)}if(!e.ext_disjoint_timer_query)return null;var i=[],a=[],o=[],s=[],l=[],c=[];return{beginQuery:function(t){var r=i.pop()||e.ext_disjoint_timer_query.createQueryEXT();e.ext_disjoint_timer_query.beginQueryEXT(35007,r),a.push(r),n(a.length-1,a.length,t)},endQuery:function(){e.ext_disjoint_timer_query.endQueryEXT(35007)},pushScopeStats:n,update:function(){var t,r;if(0!==(t=a.length)){c.length=Math.max(c.length,t+1),l.length=Math.max(l.length,t+1),l[0]=0;var n=c[0]=0;for(r=t=0;r<a.length;++r){var u=a[r];e.ext_disjoint_timer_query.getQueryObjectEXT(u,34919)?(n+=e.ext_disjoint_timer_query.getQueryObjectEXT(u,34918),i.push(u)):a[t++]=u,l[r+1]=n,c[r+1]=t}for(a.length=t,r=t=0;r<s.length;++r){var h=(n=s[r]).startQueryIndex;u=n.endQueryIndex,n.sum+=l[u]-l[h],h=c[h],(u=c[u])===h?(n.stats.gpuTime+=n.sum/1e6,o.push(n)):(n.startQueryIndex=h,n.endQueryIndex=u,s[t++]=n)}s.length=t}},getNumPendingQueries:function(){return a.length},clear:function(){i.push.apply(i,a);for(var t=0;t<i.length;t++)e.ext_disjoint_timer_query.deleteQueryEXT(i[t]);a.length=0,i.length=0},restore:function(){a.length=0,i.length=0}}}(0,_),k=H(),C=v.drawingBufferWidth,L=v.drawingBufferHeight,P={tick:0,time:0,viewportWidth:C,viewportHeight:L,framebufferWidth:C,framebufferHeight:L,drawingBufferWidth:C,drawingBufferHeight:L,pixelRatio:t.pixelRatio},O=Y(v,_),z=(C=function(t,e,r,n){for(t=r.maxAttributes,e=Array(t),r=0;r<t;++r)e[r]=new M;return{Record:M,scope:{},state:e}}(v,_,O),p(v,b,t,C)),I=d(v,_,z,b),D=S(v,x,b,t),R=T(v,_,O,function(){G.procs.poll()},P,b,t),F=mt(v,_,0,b,t),U=A(v,_,O,R,F,b),G=B(v,x,_,O,z,I,0,U,{},C,D,{elements:null,primitive:4,count:-1,offset:0,instances:-1},P,w,t),W=(x=E(v,U,G.procs.poll,P),G.next),X=v.canvas,Z=[],J=[],K=[],$=[t.onDestroy],Q=null;X&&(X.addEventListener(\"webglcontextlost\",a,!1),X.addEventListener(\"webglcontextrestored\",o,!1));var tt=U.setFBO=s({framebuffer:V.define.call(null,1,\"framebuffer\")});return f(),m=j(s,{clear:function(t){if(\"framebuffer\"in t)if(t.framebuffer&&\"framebufferCube\"===t.framebuffer_reglType)for(var e=0;6>e;++e)tt(j({framebuffer:t.framebuffer.faces[e]},t),l);else tt(t,l);else l(0,t)},prop:V.define.bind(null,1),context:V.define.bind(null,2),this:V.define.bind(null,3),draw:s({}),buffer:function(t){return z.create(t,34962,!1,!1)},elements:function(t){return I.create(t,!1)},texture:R.create2D,cube:R.createCube,renderbuffer:F.create,framebuffer:U.create,framebufferCube:U.createCube,attributes:m,frame:c,on:function(t,e){var r;switch(t){case\"frame\":return c(e);case\"lost\":r=J;break;case\"restore\":r=K;break;case\"destroy\":r=$}return r.push(e),{cancel:function(){for(var t=0;t<r.length;++t)if(r[t]===e){r[t]=r[r.length-1],r.pop();break}}}},limits:O,hasExtension:function(t){return 0<=O.extensions.indexOf(t.toLowerCase())},read:x,destroy:function(){Z.length=0,n(),X&&(X.removeEventListener(\"webglcontextlost\",a),X.removeEventListener(\"webglcontextrestored\",o)),D.clear(),U.clear(),F.clear(),R.clear(),I.clear(),z.clear(),w&&w.clear(),$.forEach(function(t){t()})},_gl:v,_refresh:f,poll:function(){h(),w&&w.update()},now:g,stats:b}),t.onDone(null,m),m}},\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=i():n.createREGL=i()},{}],503:[function(t,e,r){\"use strict\";var n,i=\"\";e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"expected a string\");if(1===e)return t;if(2===e)return t+t;var r=t.length*e;if(n!==t||\"undefined\"==typeof n)n=t,i=\"\";else if(i.length>=r)return i.substr(0,r);for(;r>i.length&&e>1;)1&e&&(i+=t),e>>=1,t+=t;return i=(i+=t).substr(0,r)}},{}],504:[function(t,e,r){(function(t){e.exports=t.performance&&t.performance.now?function(){return performance.now()}:Date.now||function(){return+new Date}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{}],505:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=t[t.length-1],n=e,i=e-2;i>=0;--i){var a=r,o=t[i],s=(r=a+o)-a,l=o-s;l&&(t[--n]=r,r=l)}for(var c=0,i=n;i<e;++i){var a=t[i],o=r,s=(r=a+o)-a,l=o-s;l&&(t[c++]=l)}return t[c++]=r,t.length=c,t}},{}],506:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-compress\"),s=6;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(2===t.length)return[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\");for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(l(t,r)),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return function t(e){if(1===e.length)return e[0];if(2===e.length)return[\"sum(\",e[0],\",\",e[1],\")\"].join(\"\");var r=e.length>>1;return[\"sum(\",t(e.slice(0,r)),\",\",t(e.slice(r)),\")\"].join(\"\")}(e);var n}function u(t){return new Function(\"sum\",\"scale\",\"prod\",\"compress\",[\"function robustDeterminant\",t,\"(m){return compress(\",c(function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m[\",r,\"][\",n,\"]\"].join(\"\")}return e}(t)),\")};return robustDeterminant\",t].join(\"\"))(i,a,n,o)}var h=[function(){return[0]},function(t){return[t[0][0]]}];!function(){for(;h.length<s;)h.push(u(h.length));for(var t=[],r=[\"function robustDeterminant(m){switch(m.length){\"],n=0;n<s;++n)t.push(\"det\"+n),r.push(\"case \",n,\":return det\",n,\"(m);\");r.push(\"}var det=CACHE[m.length];if(!det)det=CACHE[m.length]=gen(m.length);return det(m);}return robustDeterminant\"),t.push(\"CACHE\",\"gen\",r.join(\"\"));var i=Function.apply(void 0,t);for(e.exports=i.apply(void 0,h.concat([h,u])),n=0;n<h.length;++n)e.exports[n]=h[n]}()},{\"robust-compress\":505,\"robust-scale\":512,\"robust-sum\":515,\"two-product\":543}],507:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\");e.exports=function(t,e){for(var r=n(t[0],e[0]),a=1;a<t.length;++a)r=i(r,n(t[a],e[a]));return r}},{\"robust-sum\":515,\"two-product\":543}],508:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-subtract\"),o=t(\"robust-scale\"),s=6;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",c(t.slice(0,e)),\",\",c(t.slice(e)),\")\"].join(\"\")}function u(t,e){if(\"m\"===t.charAt(0)){if(\"w\"===e.charAt(0)){var r=t.split(\"[\");return[\"w\",e.substr(1),\"m\",r[0].substr(1)].join(\"\")}return[\"prod(\",t,\",\",e,\")\"].join(\"\")}return u(e,t)}function h(t){if(2===t.length)return[[\"diff(\",u(t[0][0],t[1][1]),\",\",u(t[1][0],t[0][1]),\")\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(h(l(t,r))),\",\",(n=r,!0&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function f(t,e){for(var r=[],n=0;n<e-2;++n)r.push([\"prod(m\",t,\"[\",n,\"],m\",t,\"[\",n,\"])\"].join(\"\"));return c(r)}function p(t){for(var e=[],r=[],s=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-2,\"]\"].join(\"\")}return e}(t),u=0;u<t;++u)s[0][u]=\"1\",s[t-1][u]=\"w\"+u;for(u=0;u<t;++u)0==(1&u)?e.push.apply(e,h(l(s,u))):r.push.apply(r,h(l(s,u)));var p=c(e),d=c(r),g=\"exactInSphere\"+t,v=[];for(u=0;u<t;++u)v.push(\"m\"+u);var m=[\"function \",g,\"(\",v.join(),\"){\"];for(u=0;u<t;++u){m.push(\"var w\",u,\"=\",f(u,t),\";\");for(var y=0;y<t;++y)y!==u&&m.push(\"var w\",u,\"m\",y,\"=scale(w\",u,\",m\",y,\"[0]);\")}return m.push(\"var p=\",p,\",n=\",d,\",d=diff(p,n);return d[d.length-1];}return \",g),new Function(\"sum\",\"diff\",\"prod\",\"scale\",m.join(\"\"))(i,a,n,o)}var d=[function(){return 0},function(){return 0},function(){return 0}];!function(){for(;d.length<=s;)d.push(p(d.length));for(var t=[],r=[\"slow\"],n=0;n<=s;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function testInSphere(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=s;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return testInSphere\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[function(t){var e=d[t.length];return e||(e=d[t.length]=p(t.length)),e.apply(void 0,t)}].concat(d)),n=0;n<=s;++n)e.exports[n]=d[n]}()},{\"robust-scale\":512,\"robust-subtract\":514,\"robust-sum\":515,\"two-product\":543}],509:[function(t,e,r){\"use strict\";var n=t(\"robust-determinant\"),i=6;function a(t){for(var e=\"robustLinearSolve\"+t+\"d\",r=[\"function \",e,\"(A,b){return [\"],i=0;i<t;++i){r.push(\"det([\");for(var a=0;a<t;++a){a>0&&r.push(\",\"),r.push(\"[\");for(var o=0;o<t;++o)o>0&&r.push(\",\"),o===i?r.push(\"+b[\",a,\"]\"):r.push(\"+A[\",a,\"][\",o,\"]\");r.push(\"]\")}r.push(\"]),\")}r.push(\"det(A)]}return \",e);var s=new Function(\"det\",r.join(\"\"));return s(t<6?n[t]:n)}var o=[function(){return[0]},function(t,e){return[[e[0]],[t[0][0]]]}];!function(){for(;o.length<i;)o.push(a(o.length));for(var t=[],r=[\"function dispatchLinearSolve(A,b){switch(A.length){\"],n=0;n<i;++n)t.push(\"s\"+n),r.push(\"case \",n,\":return s\",n,\"(A,b);\");r.push(\"}var s=CACHE[A.length];if(!s)s=CACHE[A.length]=g(A.length);return s(A,b)}return dispatchLinearSolve\"),t.push(\"CACHE\",\"g\",r.join(\"\"));var s=Function.apply(void 0,t);for(e.exports=s.apply(void 0,o.concat([o,a])),n=0;n<i;++n)e.exports[n]=o[n]}()},{\"robust-determinant\":506}],510:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-subtract\"),s=5;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",c(t.slice(0,e)),\",\",c(t.slice(e)),\")\"].join(\"\")}function u(t){if(2===t.length)return[[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(u(l(t,r))),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function h(t){for(var e=[],r=[],s=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-1,\"]\"].join(\"\")}return e}(t),h=[],f=0;f<t;++f)0==(1&f)?e.push.apply(e,u(l(s,f))):r.push.apply(r,u(l(s,f))),h.push(\"m\"+f);var p=c(e),d=c(r),g=\"orientation\"+t+\"Exact\",v=[\"function \",g,\"(\",h.join(),\"){var p=\",p,\",n=\",d,\",d=sub(p,n);return d[d.length-1];};return \",g].join(\"\");return new Function(\"sum\",\"prod\",\"scale\",\"sub\",v)(i,n,a,o)}var f=h(3),p=h(4),d=[function(){return 0},function(){return 0},function(t,e){return e[0]-t[0]},function(t,e,r){var n,i=(t[1]-r[1])*(e[0]-r[0]),a=(t[0]-r[0])*(e[1]-r[1]),o=i-a;if(i>0){if(a<=0)return o;n=i+a}else{if(!(i<0))return o;if(a>=0)return o;n=-(i+a)}var s=3.3306690738754716e-16*n;return o>=s||o<=-s?o:f(t,e,r)},function(t,e,r,n){var i=t[0]-n[0],a=e[0]-n[0],o=r[0]-n[0],s=t[1]-n[1],l=e[1]-n[1],c=r[1]-n[1],u=t[2]-n[2],h=e[2]-n[2],f=r[2]-n[2],d=a*c,g=o*l,v=o*s,m=i*c,y=i*l,x=a*s,b=u*(d-g)+h*(v-m)+f*(y-x),_=7.771561172376103e-16*((Math.abs(d)+Math.abs(g))*Math.abs(u)+(Math.abs(v)+Math.abs(m))*Math.abs(h)+(Math.abs(y)+Math.abs(x))*Math.abs(f));return b>_||-b>_?b:p(t,e,r,n)}];!function(){for(;d.length<=s;)d.push(h(d.length));for(var t=[],r=[\"slow\"],n=0;n<=s;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function getOrientation(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=s;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return getOrientation\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[function(t){var e=d[t.length];return e||(e=d[t.length]=h(t.length)),e.apply(void 0,t)}].concat(d)),n=0;n<=s;++n)e.exports[n]=d[n]}()},{\"robust-scale\":512,\"robust-subtract\":514,\"robust-sum\":515,\"two-product\":543}],511:[function(t,e,r){\"use strict\";var n=t(\"robust-sum\"),i=t(\"robust-scale\");e.exports=function(t,e){if(1===t.length)return i(e,t[0]);if(1===e.length)return i(t,e[0]);if(0===t.length||0===e.length)return[0];var r=[0];if(t.length<e.length)for(var a=0;a<t.length;++a)r=n(r,i(e,t[a]));else for(var a=0;a<e.length;++a)r=n(r,i(t,e[a]));return r}},{\"robust-scale\":512,\"robust-sum\":515}],512:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"two-sum\");e.exports=function(t,e){var r=t.length;if(1===r){var a=n(t[0],e);return a[0]?a:[a[1]]}var o=new Array(2*r),s=[.1,.1],l=[.1,.1],c=0;n(t[0],e,s),s[0]&&(o[c++]=s[0]);for(var u=1;u<r;++u){n(t[u],e,l);var h=s[1];i(h,l[0],s),s[0]&&(o[c++]=s[0]);var f=l[1],p=s[1],d=f+p,g=d-f,v=p-g;s[1]=d,v&&(o[c++]=v)}s[1]&&(o[c++]=s[1]);0===c&&(o[c++]=0);return o.length=c,o}},{\"two-product\":543,\"two-sum\":544}],513:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){var a=n(t,r,i),o=n(e,r,i);if(a>0&&o>0||a<0&&o<0)return!1;var s=n(r,t,e),l=n(i,t,e);if(s>0&&l>0||s<0&&l<0)return!1;if(0===a&&0===o&&0===s&&0===l)return function(t,e,r,n){for(var i=0;i<2;++i){var a=t[i],o=e[i],s=Math.min(a,o),l=Math.max(a,o),c=r[i],u=n[i],h=Math.min(c,u),f=Math.max(c,u);if(f<s||l<h)return!1}return!0}(t,e,r,i);return!0};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":510}],514:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],-e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,h=t[l],f=u(h),p=-e[c],d=u(p);f<d?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=-e[c],d=u(p)));l<r&&f<d||c>=n?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p)));var g,v,m=i+a,y=m-i,x=a-y,b=x,_=m;for(;l<r&&c<n;)f<d?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p))),(x=(a=b)-(y=(m=i+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g;for(;l<r;)(x=(a=b)-(y=(m=(i=h)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(l+=1)<r&&(h=t[l]);for(;c<n;)(x=(a=b)-(y=(m=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(c+=1)<n&&(p=-e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],515:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,h=t[l],f=u(h),p=e[c],d=u(p);f<d?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=e[c],d=u(p)));l<r&&f<d||c>=n?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=e[c],d=u(p)));var g,v,m=i+a,y=m-i,x=a-y,b=x,_=m;for(;l<r&&c<n;)f<d?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=e[c],d=u(p))),(x=(a=b)-(y=(m=i+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g;for(;l<r;)(x=(a=b)-(y=(m=(i=h)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(l+=1)<r&&(h=t[l]);for(;c<n;)(x=(a=b)-(y=(m=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(c+=1)<n&&(p=e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],516:[function(t,e,r){\"use strict\";e.exports=function(t){return t<0?-1:t>0?1:0}},{}],517:[function(t,e,r){\"use strict\";e.exports=function(t){return i(n(t))};var n=t(\"boundary-cells\"),i=t(\"reduce-simplicial-complex\")},{\"boundary-cells\":95,\"reduce-simplicial-complex\":489}],518:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,s){r=r||0,\"undefined\"==typeof s&&(s=function(t){for(var e=t.length,r=0,n=0;n<e;++n)r=0|Math.max(r,t[n].length);return r-1}(t));if(0===t.length||s<1)return{cells:[],vertexIds:[],vertexWeights:[]};var l=function(t,e){for(var r=t.length,n=i.mallocUint8(r),a=0;a<r;++a)n[a]=t[a]<e|0;return n}(e,+r),c=function(t,e){for(var r=t.length,o=e*(e+1)/2*r|0,s=i.mallocUint32(2*o),l=0,c=0;c<r;++c)for(var u=t[c],e=u.length,h=0;h<e;++h)for(var f=0;f<h;++f){var p=u[f],d=u[h];s[l++]=0|Math.min(p,d),s[l++]=0|Math.max(p,d)}a(n(s,[l/2|0,2]));for(var g=2,c=2;c<l;c+=2)s[c-2]===s[c]&&s[c-1]===s[c+1]||(s[g++]=s[c],s[g++]=s[c+1]);return n(s,[g/2|0,2])}(t,s),u=function(t,e,r,a){for(var o=t.data,s=t.shape[0],l=i.mallocDouble(s),c=0,u=0;u<s;++u){var h=o[2*u],f=o[2*u+1];if(r[h]!==r[f]){var p=e[h],d=e[f];o[2*c]=h,o[2*c+1]=f,l[c++]=(d-a)/(d-p)}}return t.shape[0]=c,n(l,[c])}(c,e,l,+r),h=function(t,e){var r=i.mallocInt32(2*e),n=t.shape[0],a=t.data;r[0]=0;for(var o=0,s=0;s<n;++s){var l=a[2*s];if(l!==o){for(r[2*o+1]=s;++o<l;)r[2*o]=s,r[2*o+1]=s;r[2*o]=s}}r[2*o+1]=n;for(;++o<e;)r[2*o]=r[2*o+1]=n;return r}(c,0|e.length),f=o(s)(t,c.data,h,l),p=function(t){for(var e=0|t.shape[0],r=t.data,n=new Array(e),i=0;i<e;++i)n[i]=[r[2*i],r[2*i+1]];return n}(c),d=[].slice.call(u.data,0,u.shape[0]);return i.free(l),i.free(c.data),i.free(u.data),i.free(h),{cells:f,vertexIds:p,vertexWeights:d}};var n=t(\"ndarray\"),i=t(\"typedarray-pool\"),a=t(\"ndarray-sort\"),o=t(\"./lib/codegen\")},{\"./lib/codegen\":519,ndarray:450,\"ndarray-sort\":448,\"typedarray-pool\":545}],519:[function(t,e,r){\"use strict\";e.exports=function(t){var e=a[t];e||(e=a[t]=function(t){var e=0,r=new Array(t+1);r[0]=[[]];for(var a=1;a<=t;++a)for(var o=r[a]=i(a),s=0;s<o.length;++s)e=Math.max(e,o[a].length);var l=[\"function B(C,E,i,j){\",\"var a=Math.min(i,j)|0,b=Math.max(i,j)|0,l=C[2*a],h=C[2*a+1];\",\"while(l<h){\",\"var m=(l+h)>>1,v=E[2*m+1];\",\"if(v===b){return m}\",\"if(b<v){h=m}else{l=m+1}\",\"}\",\"return l;\",\"};\",\"function getContour\",t,\"d(F,E,C,S){\",\"var n=F.length,R=[];\",\"for(var i=0;i<n;++i){var c=F[i],l=c.length;\"];function c(t){if(!(t.length<=0)){l.push(\"R.push(\");for(var e=0;e<t.length;++e){var r=t[e];e>0&&l.push(\",\"),l.push(\"[\");for(var n=0;n<r.length;++n){var i=r[n];n>0&&l.push(\",\"),l.push(\"B(C,E,c[\",i[0],\"],c[\",i[1],\"])\")}l.push(\"]\")}l.push(\");\")}}for(var a=t+1;a>1;--a){a<t+1&&l.push(\"else \"),l.push(\"if(l===\",a,\"){\");for(var u=[],s=0;s<a;++s)u.push(\"(S[c[\"+s+\"]]<<\"+s+\")\");l.push(\"var M=\",u.join(\"+\"),\";if(M===0||M===\",(1<<a)-1,\"){continue}switch(M){\");for(var o=r[a-1],s=0;s<o.length;++s)l.push(\"case \",s,\":\"),c(o[s]),l.push(\"break;\");l.push(\"}}\")}return l.push(\"}return R;};return getContour\",t,\"d\"),new Function(\"pool\",l.join(\"\"))(n)}(t));return e};var n=t(\"typedarray-pool\"),i=t(\"marching-simplex-table\"),a={}},{\"marching-simplex-table\":427,\"typedarray-pool\":545}],520:[function(t,e,r){\"use strict\";var n=t(\"bit-twiddle\"),i=t(\"union-find\");function a(t,e){var r=t.length,n=t.length-e.length,i=Math.min;if(n)return n;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return(s=t[0]+t[1]-e[0]-e[1])||i(t[0],t[1])-i(e[0],e[1]);case 3:var a=t[0]+t[1],o=e[0]+e[1];if(s=a+t[2]-(o+e[2]))return s;var s,l=i(t[0],t[1]),c=i(e[0],e[1]);return(s=i(l,t[2])-i(c,e[2]))||i(l+t[2],a)-i(c+e[2],o);default:var u=t.slice(0);u.sort();var h=e.slice(0);h.sort();for(var f=0;f<r;++f)if(n=u[f]-h[f])return n;return 0}}function o(t,e){return a(t[0],e[0])}function s(t,e){if(e){for(var r=t.length,n=new Array(r),i=0;i<r;++i)n[i]=[t[i],e[i]];n.sort(o);for(i=0;i<r;++i)t[i]=n[i][0],e[i]=n[i][1];return t}return t.sort(a),t}function l(t){if(0===t.length)return[];for(var e=1,r=t.length,n=1;n<r;++n){var i=t[n];if(a(i,t[n-1])){if(n===e){e++;continue}t[e++]=i}}return t.length=e,t}function c(t,e){for(var r=0,n=t.length-1,i=-1;r<=n;){var o=r+n>>1,s=a(t[o],e);s<=0?(0===s&&(i=o),r=o+1):s>0&&(n=o-1)}return i}function u(t,e){for(var r=new Array(t.length),i=0,o=r.length;i<o;++i)r[i]=[];for(var s=[],l=(i=0,e.length);i<l;++i)for(var u=e[i],h=u.length,f=1,p=1<<h;f<p;++f){s.length=n.popCount(f);for(var d=0,g=0;g<h;++g)f&1<<g&&(s[d++]=u[g]);var v=c(t,s);if(!(v<0))for(;r[v++].push(i),!(v>=t.length||0!==a(t[v],s)););}return r}function h(t,e){if(e<0)return[];for(var r=[],i=(1<<e+1)-1,a=0;a<t.length;++a)for(var o=t[a],l=i;l<1<<o.length;l=n.nextCombination(l)){for(var c=new Array(e+1),u=0,h=0;h<o.length;++h)l&1<<h&&(c[u++]=o[h]);r.push(c)}return s(r)}r.dimension=function(t){for(var e=0,r=Math.max,n=0,i=t.length;n<i;++n)e=r(e,t[n].length);return e-1},r.countVertices=function(t){for(var e=-1,r=Math.max,n=0,i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)e=r(e,a[o]);return e+1},r.cloneCells=function(t){for(var e=new Array(t.length),r=0,n=t.length;r<n;++r)e[r]=t[r].slice(0);return e},r.compareCells=a,r.normalize=s,r.unique=l,r.findCell=c,r.incidence=u,r.dual=function(t,e){if(!e)return u(l(h(t,0)),t);for(var r=new Array(e),n=0;n<e;++n)r[n]=[];n=0;for(var i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)r[a[o]].push(n);return r},r.explode=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0|i.length,o=1,l=1<<a;o<l;++o){for(var c=[],u=0;u<a;++u)o>>>u&1&&c.push(i[u]);e.push(c)}return s(e)},r.skeleton=h,r.boundary=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;++a){for(var l=new Array(i.length-1),c=0,u=0;c<o;++c)c!==a&&(l[u++]=i[c]);e.push(l)}return s(e)},r.connectedComponents=function(t,e){return e?function(t,e){for(var r=new i(e),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var s=o+1;s<a.length;++s)r.link(a[o],a[s]);var l=[],c=r.ranks;for(n=0;n<c.length;++n)c[n]=-1;for(n=0;n<t.length;++n){var u=r.find(t[n][0]);c[u]<0?(c[u]=l.length,l.push([t[n].slice(0)])):l[c[u]].push(t[n].slice(0))}return l}(t,e):function(t){for(var e=l(s(h(t,0))),r=new i(e.length),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var u=c(e,[a[o]]),f=o+1;f<a.length;++f)r.link(u,c(e,[a[f]]));var p=[],d=r.ranks;for(n=0;n<d.length;++n)d[n]=-1;for(n=0;n<t.length;++n){var g=r.find(c(e,[t[n][0]]));d[g]<0?(d[g]=p.length,p.push([t[n].slice(0)])):p[d[g]].push(t[n].slice(0))}return p}(t)}},{\"bit-twiddle\":92,\"union-find\":546}],521:[function(t,e,r){arguments[4][92][0].apply(r,arguments)},{dup:92}],522:[function(t,e,r){arguments[4][520][0].apply(r,arguments)},{\"bit-twiddle\":521,dup:520,\"union-find\":523}],523:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n,n.prototype.length=function(){return this.roots.length},n.prototype.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},n.prototype.find=function(t){for(var e=this.roots;e[t]!==t;){var r=e[t];e[t]=e[r],t=r}return t},n.prototype.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],524:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){for(var a=e.length,o=t.length,s=new Array(a),l=new Array(a),c=new Array(a),u=new Array(a),h=0;h<a;++h)s[h]=l[h]=-1,c[h]=1/0,u[h]=!1;for(var h=0;h<o;++h){var f=t[h];if(2!==f.length)throw new Error(\"Input must be a graph\");var p=f[1],d=f[0];-1!==l[d]?l[d]=-2:l[d]=p,-1!==s[p]?s[p]=-2:s[p]=d}function g(t){if(u[t])return 1/0;var r,i,a,o,c,h=s[t],f=l[t];return h<0||f<0?1/0:(r=e[t],i=e[h],a=e[f],o=Math.abs(n(r,i,a)),c=Math.sqrt(Math.pow(i[0]-a[0],2)+Math.pow(i[1]-a[1],2)),o/c)}function v(t,e){var r=T[t],n=T[e];T[t]=n,T[e]=r,A[r]=e,A[n]=t}function m(t){return c[T[t]]}function y(t){return 1&t?t-1>>1:(t>>1)-1}function x(t){for(var e=m(t);;){var r=e,n=2*t+1,i=2*(t+1),a=t;if(n<S){var o=m(n);o<r&&(a=n,r=o)}if(i<S){var s=m(i);s<r&&(a=i)}if(a===t)return t;v(t,a),t=a}}function b(t){for(var e=m(t);t>0;){var r=y(t);if(r>=0){var n=m(r);if(e<n){v(t,r),t=r;continue}}return t}}function _(){if(S>0){var t=T[0];return v(0,S-1),S-=1,x(0),t}return-1}function w(t,e){var r=T[t];return c[r]===e?t:(c[r]=-1/0,b(t),_(),c[r]=e,b((S+=1)-1))}function k(t){if(!u[t]){u[t]=!0;var e=s[t],r=l[t];s[r]>=0&&(s[r]=e),l[e]>=0&&(l[e]=r),A[e]>=0&&w(A[e],g(e)),A[r]>=0&&w(A[r],g(r))}}for(var T=[],A=new Array(a),h=0;h<a;++h){var M=c[h]=g(h);M<1/0?(A[h]=T.length,T.push(h)):A[h]=-1}for(var S=T.length,h=S>>1;h>=0;--h)x(h);for(;;){var E=_();if(E<0||c[E]>r)break;k(E)}for(var C=[],h=0;h<a;++h)u[h]||(A[h]=C.length,C.push(e[h].slice()));C.length;function L(t,e){if(t[e]<0)return e;var r=e,n=e;do{var i=t[n];if(!u[n]||i<0||i===n)break;if(i=t[n=i],!u[n]||i<0||i===n)break;n=i,r=t[r]}while(r!==n);for(var a=e;a!==n;a=t[a])t[a]=n;return n}var P=[];return t.forEach(function(t){var e=L(s,t[0]),r=L(l,t[1]);if(e>=0&&r>=0&&e!==r){var n=A[e],i=A[r];n!==i&&P.push([n,i])}}),i.unique(i.normalize(P)),{positions:C,edges:P}};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\")},{\"robust-orientation\":510,\"simplicial-complex\":522}],525:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,a,o,s;if(e[0][0]<e[1][0])r=e[0],a=e[1];else{if(!(e[0][0]>e[1][0]))return i(e,t);r=e[1],a=e[0]}if(t[0][0]<t[1][0])o=t[0],s=t[1];else{if(!(t[0][0]>t[1][0]))return-i(t,e);o=t[1],s=t[0]}var l=n(r,a,s),c=n(r,a,o);if(l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;if(l=n(s,o,a),c=n(s,o,r),l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;return a[0]-s[0]};var n=t(\"robust-orientation\");function i(t,e){var r,i,a,o;if(e[0][0]<e[1][0])r=e[0],i=e[1];else{if(!(e[0][0]>e[1][0])){var s=Math.min(t[0][1],t[1][1]),l=Math.max(t[0][1],t[1][1]),c=Math.min(e[0][1],e[1][1]),u=Math.max(e[0][1],e[1][1]);return l<c?l-c:s>u?s-u:l-u}r=e[1],i=e[0]}t[0][1]<t[1][1]?(a=t[0],o=t[1]):(a=t[1],o=t[0]);var h=n(i,r,a);return h||((h=n(i,r,o))||o-i)}},{\"robust-orientation\":510}],526:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=2*e,n=new Array(r),a=0;a<e;++a){var l=t[a],c=l[0][0]<l[1][0];n[2*a]=new h(l[0][0],l,c,a),n[2*a+1]=new h(l[1][0],l,!c,a)}n.sort(function(t,e){var r=t.x-e.x;return r||((r=t.create-e.create)||Math.min(t.segment[0][1],t.segment[1][1])-Math.min(e.segment[0][1],e.segment[1][1]))});for(var f=i(o),p=[],d=[],g=[],a=0;a<r;){for(var v=n[a].x,m=[];a<r;){var y=n[a];if(y.x!==v)break;a+=1,y.segment[0][0]===y.x&&y.segment[1][0]===y.x?y.create&&(y.segment[0][1]<y.segment[1][1]?(m.push(new u(y.segment[0][1],y.index,!0,!0)),m.push(new u(y.segment[1][1],y.index,!1,!1))):(m.push(new u(y.segment[1][1],y.index,!0,!1)),m.push(new u(y.segment[0][1],y.index,!1,!0)))):f=y.create?f.insert(y.segment,y.index):f.remove(y.segment)}p.push(f.root),d.push(v),g.push(m)}return new s(p,d,g)};var n=t(\"binary-search-bounds\"),i=t(\"functional-red-black-tree\"),a=t(\"robust-orientation\"),o=t(\"./lib/order-segments\");function s(t,e,r){this.slabs=t,this.coordinates=e,this.horizontal=r}function l(t,e){return t.y-e}function c(t,e){for(var r=null;t;){var n,i,o=t.key;o[0][0]<o[1][0]?(n=o[0],i=o[1]):(n=o[1],i=o[0]);var s=a(n,i,e);if(s<0)t=t.left;else if(s>0)if(e[0]!==o[1][0])r=t,t=t.right;else{if(l=c(t.right,e))return l;t=t.left}else{if(e[0]!==o[1][0])return t;var l;if(l=c(t.right,e))return l;t=t.left}}return r}function u(t,e,r,n){this.y=t,this.index=e,this.start=r,this.closed=n}function h(t,e,r,n){this.x=t,this.segment=e,this.create=r,this.index=n}s.prototype.castUp=function(t){var e=n.le(this.coordinates,t[0]);if(e<0)return-1;this.slabs[e];var r=c(this.slabs[e],t),i=-1;if(r&&(i=r.value),this.coordinates[e]===t[0]){var s=null;if(r&&(s=r.key),e>0){var u=c(this.slabs[e-1],t);u&&(s?o(u.key,s)>0&&(s=u.key,i=u.value):(i=u.value,s=u.key))}var h=this.horizontal[e];if(h.length>0){var f=n.ge(h,t[1],l);if(f<h.length){var p=h[f];if(t[1]===p.y){if(p.closed)return p.index;for(;f<h.length-1&&h[f+1].y===t[1];)if((p=h[f+=1]).closed)return p.index;if(p.y===t[1]&&!p.start){if((f+=1)>=h.length)return i;p=h[f]}}if(p.start)if(s){var d=a(s[0],s[1],[t[0],p.y]);s[0][0]>s[1][0]&&(d=-d),d>0&&(i=p.index)}else i=p.index;else p.y!==t[1]&&(i=p.index)}}}return i}},{\"./lib/order-segments\":525,\"binary-search-bounds\":91,\"functional-red-black-tree\":230,\"robust-orientation\":510}],527:[function(t,e,r){\"use strict\";var n=t(\"robust-dot-product\"),i=t(\"robust-sum\");function a(t,e){var r=i(n(t,e),[e[e.length-1]]);return r[r.length-1]}function o(t,e,r,n){var i=-e/(n-e);i<0?i=0:i>1&&(i=1);for(var a=1-i,o=t.length,s=new Array(o),l=0;l<o;++l)s[l]=i*t[l]+a*r[l];return s}e.exports=function(t,e){for(var r=[],n=[],i=a(t[t.length-1],e),s=t[t.length-1],l=t[0],c=0;c<t.length;++c,s=l){var u=a(l=t[c],e);if(i<0&&u>0||i>0&&u<0){var h=o(s,u,l,i);r.push(h),n.push(h.slice())}u<0?n.push(l.slice()):u>0?r.push(l.slice()):(r.push(l.slice()),n.push(l.slice())),i=u}return{positive:r,negative:n}},e.exports.positive=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c>=0&&r.push(s.slice()),n=c}return r},e.exports.negative=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c<=0&&r.push(s.slice()),n=c}return r}},{\"robust-dot-product\":507,\"robust-sum\":515}],528:[function(t,e,r){!function(){\"use strict\";var t={not_string:/[^s]/,not_bool:/[^t]/,not_type:/[^T]/,not_primitive:/[^v]/,number:/[diefg]/,numeric_arg:/[bcdiefguxX]/,json:/[j]/,not_json:/[^j]/,text:/^[^\\x25]+/,modulo:/^\\x25{2}/,placeholder:/^\\x25(?:([1-9]\\d*)\\$|\\(([^)]+)\\))?(\\+)?(0|'[^$])?(-)?(\\d+)?(?:\\.(\\d+))?([b-gijostTuvxX])/,key:/^([a-z_][a-z_\\d]*)/i,key_access:/^\\.([a-z_][a-z_\\d]*)/i,index_access:/^\\[(\\d+)\\]/,sign:/^[+-]/};function e(r){return function(r,n){var i,a,o,s,l,c,u,h,f,p=1,d=r.length,g=\"\";for(a=0;a<d;a++)if(\"string\"==typeof r[a])g+=r[a];else if(\"object\"==typeof r[a]){if((s=r[a]).keys)for(i=n[p],o=0;o<s.keys.length;o++){if(null==i)throw new Error(e('[sprintf] Cannot access property \"%s\" of undefined value \"%s\"',s.keys[o],s.keys[o-1]));i=i[s.keys[o]]}else i=s.param_no?n[s.param_no]:n[p++];if(t.not_type.test(s.type)&&t.not_primitive.test(s.type)&&i instanceof Function&&(i=i()),t.numeric_arg.test(s.type)&&\"number\"!=typeof i&&isNaN(i))throw new TypeError(e(\"[sprintf] expecting number but found %T\",i));switch(t.number.test(s.type)&&(h=i>=0),s.type){case\"b\":i=parseInt(i,10).toString(2);break;case\"c\":i=String.fromCharCode(parseInt(i,10));break;case\"d\":case\"i\":i=parseInt(i,10);break;case\"j\":i=JSON.stringify(i,null,s.width?parseInt(s.width):0);break;case\"e\":i=s.precision?parseFloat(i).toExponential(s.precision):parseFloat(i).toExponential();break;case\"f\":i=s.precision?parseFloat(i).toFixed(s.precision):parseFloat(i);break;case\"g\":i=s.precision?String(Number(i.toPrecision(s.precision))):parseFloat(i);break;case\"o\":i=(parseInt(i,10)>>>0).toString(8);break;case\"s\":i=String(i),i=s.precision?i.substring(0,s.precision):i;break;case\"t\":i=String(!!i),i=s.precision?i.substring(0,s.precision):i;break;case\"T\":i=Object.prototype.toString.call(i).slice(8,-1).toLowerCase(),i=s.precision?i.substring(0,s.precision):i;break;case\"u\":i=parseInt(i,10)>>>0;break;case\"v\":i=i.valueOf(),i=s.precision?i.substring(0,s.precision):i;break;case\"x\":i=(parseInt(i,10)>>>0).toString(16);break;case\"X\":i=(parseInt(i,10)>>>0).toString(16).toUpperCase()}t.json.test(s.type)?g+=i:(!t.number.test(s.type)||h&&!s.sign?f=\"\":(f=h?\"+\":\"-\",i=i.toString().replace(t.sign,\"\")),c=s.pad_char?\"0\"===s.pad_char?\"0\":s.pad_char.charAt(1):\" \",u=s.width-(f+i).length,l=s.width&&u>0?c.repeat(u):\"\",g+=s.align?f+i+l:\"0\"===c?f+l+i:l+f+i)}return g}(function(e){if(i[e])return i[e];var r,n=e,a=[],o=0;for(;n;){if(null!==(r=t.text.exec(n)))a.push(r[0]);else if(null!==(r=t.modulo.exec(n)))a.push(\"%\");else{if(null===(r=t.placeholder.exec(n)))throw new SyntaxError(\"[sprintf] unexpected placeholder\");if(r[2]){o|=1;var s=[],l=r[2],c=[];if(null===(c=t.key.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");for(s.push(c[1]);\"\"!==(l=l.substring(c[0].length));)if(null!==(c=t.key_access.exec(l)))s.push(c[1]);else{if(null===(c=t.index_access.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");s.push(c[1])}r[2]=s}else o|=2;if(3===o)throw new Error(\"[sprintf] mixing positional and named placeholders is not (yet) supported\");a.push({placeholder:r[0],param_no:r[1],keys:r[2],sign:r[3],pad_char:r[4],align:r[5],width:r[6],precision:r[7],type:r[8]})}n=n.substring(r[0].length)}return i[e]=a}(r),arguments)}function n(t,r){return e.apply(null,[t].concat(r||[]))}var i=Object.create(null);\"undefined\"!=typeof r&&(r.sprintf=e,r.vsprintf=n),\"undefined\"!=typeof window&&(window.sprintf=e,window.vsprintf=n)}()},{}],529:[function(t,e,r){\"use strict\";var n=t(\"parenthesis\");e.exports=function(t,e,r){if(null==t)throw Error(\"First argument should be a string\");if(null==e)throw Error(\"Separator should be a string or a RegExp\");r?(\"string\"==typeof r||Array.isArray(r))&&(r={ignore:r}):r={},null==r.escape&&(r.escape=!0),null==r.ignore?r.ignore=[\"[]\",\"()\",\"{}\",\"<>\",'\"\"',\"''\",\"``\",\"\\u201c\\u201d\",\"\\xab\\xbb\"]:(\"string\"==typeof r.ignore&&(r.ignore=[r.ignore]),r.ignore=r.ignore.map(function(t){return 1===t.length&&(t+=t),t}));var i=n.parse(t,{flat:!0,brackets:r.ignore}),a=i[0].split(e);if(r.escape){for(var o=[],s=0;s<a.length;s++){var l=a[s],c=a[s+1];\"\\\\\"===l[l.length-1]&&\"\\\\\"!==l[l.length-2]?(o.push(l+e+c),s++):o.push(l)}a=o}for(s=0;s<a.length;s++)i[0]=a[s],a[s]=n.stringify(i,{flat:!0});return a}},{parenthesis:458}],530:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=new Array(e),n=new Array(e),i=new Array(e),a=new Array(e),o=new Array(e),s=new Array(e),l=0;l<e;++l)r[l]=-1,n[l]=0,i[l]=!1,a[l]=0,o[l]=-1,s[l]=[];var c,u=0,h=[],f=[];function p(e){var l=[e],c=[e];for(r[e]=n[e]=u,i[e]=!0,u+=1;c.length>0;){e=c[c.length-1];var p=t[e];if(a[e]<p.length){for(var d=a[e];d<p.length;++d){var g=p[d];if(r[g]<0){r[g]=n[g]=u,i[g]=!0,u+=1,l.push(g),c.push(g);break}i[g]&&(n[e]=0|Math.min(n[e],n[g])),o[g]>=0&&s[e].push(o[g])}a[e]=d}else{if(n[e]===r[e]){for(var v=[],m=[],y=0,d=l.length-1;d>=0;--d){var x=l[d];if(i[x]=!1,v.push(x),m.push(s[x]),y+=s[x].length,o[x]=h.length,x===e){l.length=d;break}}h.push(v);for(var b=new Array(y),d=0;d<m.length;d++)for(var _=0;_<m[d].length;_++)b[--y]=m[d][_];f.push(b)}c.pop()}}}for(var l=0;l<e;++l)r[l]<0&&p(l);for(var l=0;l<f.length;l++){var d=f[l];if(0!==d.length){d.sort(function(t,e){return t-e}),c=[d[0]];for(var g=1;g<d.length;g++)d[g]!==d[g-1]&&c.push(d[g]);f[l]=c}}return{components:h,adjacencyList:f}}},{}],531:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(t.dimension<=0)return{positions:[],cells:[]};if(1===t.dimension)return function(t,e){for(var r=a(t,e),n=r.length,i=new Array(n),o=new Array(n),s=0;s<n;++s)i[s]=[r[s]],o[s]=[s];return{positions:i,cells:o}}(t,e);var r=t.order.join()+\"-\"+t.dtype,s=o[r],e=+e||0;s||(s=o[r]=function(t,e){var r=t.length,a=[\"'use strict';\"],o=\"surfaceNets\"+t.join(\"_\")+\"d\"+e;a.push(\"var contour=genContour({\",\"order:[\",t.join(),\"],\",\"scalarArguments: 3,\",\"phase:function phaseFunc(p,a,b,c) { return (p > c)|0 },\"),\"generic\"===e&&a.push(\"getters:[0],\");for(var s=[],l=[],c=0;c<r;++c)s.push(\"d\"+c),l.push(\"d\"+c);for(var c=0;c<1<<r;++c)s.push(\"v\"+c),l.push(\"v\"+c);for(var c=0;c<1<<r;++c)s.push(\"p\"+c),l.push(\"p\"+c);s.push(\"a\",\"b\",\"c\"),l.push(\"a\",\"c\"),a.push(\"vertex:function vertexFunc(\",s.join(),\"){\");for(var u=[],c=0;c<1<<r;++c)u.push(\"(p\"+c+\"<<\"+c+\")\");a.push(\"var m=(\",u.join(\"+\"),\")|0;if(m===0||m===\",(1<<(1<<r))-1,\"){return}\");var h=[],f=[];1<<(1<<r)<=128?(a.push(\"switch(m){\"),f=a):a.push(\"switch(m>>>7){\");for(var c=0;c<1<<(1<<r);++c){if(1<<(1<<r)>128&&c%128==0){h.length>0&&f.push(\"}}\");var p=\"vExtra\"+h.length;a.push(\"case \",c>>>7,\":\",p,\"(m&0x7f,\",l.join(),\");break;\"),f=[\"function \",p,\"(m,\",l.join(),\"){switch(m){\"],h.push(f)}f.push(\"case \",127&c,\":\");for(var d=new Array(r),g=new Array(r),v=new Array(r),m=new Array(r),y=0,x=0;x<r;++x)d[x]=[],g[x]=[],v[x]=0,m[x]=0;for(var x=0;x<1<<r;++x)for(var b=0;b<r;++b){var _=x^1<<b;if(!(_>x)&&!(c&1<<_)!=!(c&1<<x)){var w=1;c&1<<_?g[b].push(\"v\"+_+\"-v\"+x):(g[b].push(\"v\"+x+\"-v\"+_),w=-w),w<0?(d[b].push(\"-v\"+x+\"-v\"+_),v[b]+=2):(d[b].push(\"v\"+x+\"+v\"+_),v[b]-=2),y+=1;for(var k=0;k<r;++k)k!==b&&(_&1<<k?m[k]+=1:m[k]-=1)}}for(var T=[],b=0;b<r;++b)if(0===d[b].length)T.push(\"d\"+b+\"-0.5\");else{var A=\"\";v[b]<0?A=v[b]+\"*c\":v[b]>0&&(A=\"+\"+v[b]+\"*c\");var M=d[b].length/y*.5,S=.5+m[b]/y*.5;T.push(\"d\"+b+\"-\"+S+\"-\"+M+\"*(\"+d[b].join(\"+\")+A+\")/(\"+g[b].join(\"+\")+\")\")}f.push(\"a.push([\",T.join(),\"]);\",\"break;\")}a.push(\"}},\"),h.length>0&&f.push(\"}}\");for(var E=[],c=0;c<1<<r-1;++c)E.push(\"v\"+c);E.push(\"c0\",\"c1\",\"p0\",\"p1\",\"a\",\"b\",\"c\"),a.push(\"cell:function cellFunc(\",E.join(),\"){\");var C=i(r-1);a.push(\"if(p0){b.push(\",C.map(function(t){return\"[\"+t.map(function(t){return\"v\"+t})+\"]\"}).join(),\")}else{b.push(\",C.map(function(t){var e=t.slice();return e.reverse(),\"[\"+e.map(function(t){return\"v\"+t})+\"]\"}).join(),\")}}});function \",o,\"(array,level){var verts=[],cells=[];contour(array,verts,cells,level);return {positions:verts,cells:cells};} return \",o,\";\");for(var c=0;c<h.length;++c)a.push(h[c].join(\"\"));return new Function(\"genContour\",a.join(\"\"))(n)}(t.order,t.dtype));return s(t,e)};var n=t(\"ndarray-extract-contour\"),i=t(\"triangulate-hypercube\"),a=t(\"zero-crossings\");var o={}},{\"ndarray-extract-contour\":439,\"triangulate-hypercube\":541,\"zero-crossings\":574}],532:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=function(){return function(t,e){if(Array.isArray(t))return t;if(Symbol.iterator in Object(t))return function(t,e){var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{!n&&s.return&&s.return()}finally{if(i)throw a}}return r}(t,e);throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")}}(),i=2*Math.PI,a=function(t,e,r,n,i,a,o){var s=t.x,l=t.y;return{x:n*(s*=e)-i*(l*=r)+a,y:i*s+n*l+o}},o=function(t,e){var r=.551915024494*(e<0?-1:1),n=Math.cos(t),i=Math.sin(t),a=Math.cos(t+e),o=Math.sin(t+e);return[{x:n-i*r,y:i+n*r},{x:a+o*r,y:o-a*r},{x:a,y:o}]},s=function(t,e,r,n){var i=t*n-e*r<0?-1:1,a=(t*r+e*n)/(Math.sqrt(t*t+e*e)*Math.sqrt(t*t+e*e));return a>1&&(a=1),a<-1&&(a=-1),i*Math.acos(a)};r.default=function(t){var e=t.px,r=t.py,l=t.cx,c=t.cy,u=t.rx,h=t.ry,f=t.xAxisRotation,p=void 0===f?0:f,d=t.largeArcFlag,g=void 0===d?0:d,v=t.sweepFlag,m=void 0===v?0:v,y=[];if(0===u||0===h)return[];var x=Math.sin(p*i/360),b=Math.cos(p*i/360),_=b*(e-l)/2+x*(r-c)/2,w=-x*(e-l)/2+b*(r-c)/2;if(0===_&&0===w)return[];u=Math.abs(u),h=Math.abs(h);var k=Math.pow(_,2)/Math.pow(u,2)+Math.pow(w,2)/Math.pow(h,2);k>1&&(u*=Math.sqrt(k),h*=Math.sqrt(k));var T=function(t,e,r,n,a,o,l,c,u,h,f,p){var d=Math.pow(a,2),g=Math.pow(o,2),v=Math.pow(f,2),m=Math.pow(p,2),y=d*g-d*m-g*v;y<0&&(y=0),y/=d*m+g*v;var x=(y=Math.sqrt(y)*(l===c?-1:1))*a/o*p,b=y*-o/a*f,_=h*x-u*b+(t+r)/2,w=u*x+h*b+(e+n)/2,k=(f-x)/a,T=(p-b)/o,A=(-f-x)/a,M=(-p-b)/o,S=s(1,0,k,T),E=s(k,T,A,M);return 0===c&&E>0&&(E-=i),1===c&&E<0&&(E+=i),[_,w,S,E]}(e,r,l,c,u,h,g,m,x,b,_,w),A=n(T,4),M=A[0],S=A[1],E=A[2],C=A[3],L=Math.abs(C)/(i/4);Math.abs(1-L)<1e-7&&(L=1);var P=Math.max(Math.ceil(L),1);C/=P;for(var O=0;O<P;O++)y.push(o(E,C)),E+=C;return y.map(function(t){var e=a(t[0],u,h,b,x,M,S),r=e.x,n=e.y,i=a(t[1],u,h,b,x,M,S),o=i.x,s=i.y,l=a(t[2],u,h,b,x,M,S);return{x1:r,y1:n,x2:o,y2:s,x:l.x,y:l.y}})},e.exports=r.default},{}],533:[function(t,e,r){\"use strict\";var n=t(\"parse-svg-path\"),i=t(\"abs-svg-path\"),a=t(\"normalize-svg-path\"),o=t(\"is-svg-path\"),s=t(\"assert\");e.exports=function(t){Array.isArray(t)&&1===t.length&&\"string\"==typeof t[0]&&(t=t[0]);\"string\"==typeof t&&(s(o(t),\"String is not an SVG path.\"),t=n(t));if(s(Array.isArray(t),\"Argument should be a string or an array of path segments.\"),t=i(t),!(t=a(t)).length)return[0,0,0,0];for(var e=[1/0,1/0,-1/0,-1/0],r=0,l=t.length;r<l;r++)for(var c=t[r].slice(1),u=0;u<c.length;u+=2)c[u+0]<e[0]&&(e[0]=c[u+0]),c[u+1]<e[1]&&(e[1]=c[u+1]),c[u+0]>e[2]&&(e[2]=c[u+0]),c[u+1]>e[3]&&(e[3]=c[u+1]);return e}},{\"abs-svg-path\":60,assert:68,\"is-svg-path\":424,\"normalize-svg-path\":534,\"parse-svg-path\":460}],534:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=[],o=0,s=0,l=0,c=0,u=null,h=null,f=0,p=0,d=0,g=t.length;d<g;d++){var v=t[d],m=v[0];switch(m){case\"M\":l=v[1],c=v[2];break;case\"A\":var y=n({px:f,py:p,cx:v[6],cy:v[7],rx:v[1],ry:v[2],xAxisRotation:v[3],largeArcFlag:v[4],sweepFlag:v[5]});if(!y.length)continue;for(var x,b=0;b<y.length;b++)x=y[b],v=[\"C\",x.x1,x.y1,x.x2,x.y2,x.x,x.y],b<y.length-1&&r.push(v);break;case\"S\":var _=f,w=p;\"C\"!=e&&\"S\"!=e||(_+=_-o,w+=w-s),v=[\"C\",_,w,v[1],v[2],v[3],v[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(u=2*f-u,h=2*p-h):(u=f,h=p),v=a(f,p,u,h,v[1],v[2]);break;case\"Q\":u=v[1],h=v[2],v=a(f,p,v[1],v[2],v[3],v[4]);break;case\"L\":v=i(f,p,v[1],v[2]);break;case\"H\":v=i(f,p,v[1],p);break;case\"V\":v=i(f,p,f,v[1]);break;case\"Z\":v=i(f,p,l,c)}e=m,f=v[v.length-2],p=v[v.length-1],v.length>4?(o=v[v.length-4],s=v[v.length-3]):(o=f,s=p),r.push(v)}return r};var n=t(\"svg-arc-to-cubic-bezier\");function i(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function a(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}},{\"svg-arc-to-cubic-bezier\":532}],535:[function(t,e,r){\"use strict\";var n,i=t(\"svg-path-bounds\"),a=t(\"parse-svg-path\"),o=t(\"draw-svg-path\"),s=t(\"is-svg-path\"),l=t(\"bitmap-sdf\"),c=document.createElement(\"canvas\"),u=c.getContext(\"2d\");e.exports=function(t,e){if(!s(t))throw Error(\"Argument should be valid svg path string\");e||(e={});var r,h;e.shape?(r=e.shape[0],h=e.shape[1]):(r=c.width=e.w||e.width||200,h=c.height=e.h||e.height||200);var f=Math.min(r,h),p=e.stroke||0,d=e.viewbox||e.viewBox||i(t),g=[r/(d[2]-d[0]),h/(d[3]-d[1])],v=Math.min(g[0]||0,g[1]||0)/2;u.fillStyle=\"black\",u.fillRect(0,0,r,h),u.fillStyle=\"white\",p&&(\"number\"!=typeof p&&(p=1),u.strokeStyle=p>0?\"white\":\"black\",u.lineWidth=Math.abs(p));if(u.translate(.5*r,.5*h),u.scale(v,v),function(){if(null!=n)return n;var t=document.createElement(\"canvas\").getContext(\"2d\");if(t.canvas.width=t.canvas.height=1,!window.Path2D)return n=!1;var e=new Path2D(\"M0,0h1v1h-1v-1Z\");t.fillStyle=\"black\",t.fill(e);var r=t.getImageData(0,0,1,1);return n=r&&r.data&&255===r.data[3]}()){var m=new Path2D(t);u.fill(m),p&&u.stroke(m)}else{var y=a(t);o(u,y),u.fill(),p&&u.stroke()}return u.setTransform(1,0,0,1,0,0),l(u,{cutoff:null!=e.cutoff?e.cutoff:.5,radius:null!=e.radius?e.radius:.5*f})}},{\"bitmap-sdf\":93,\"draw-svg-path\":168,\"is-svg-path\":424,\"parse-svg-path\":460,\"svg-path-bounds\":533}],536:[function(t,e,r){(function(r){\"use strict\";e.exports=function t(e,r,i){var i=i||{};var o=a[e];o||(o=a[e]={\" \":{data:new Float32Array(0),shape:.2}});var s=o[r];if(!s)if(r.length<=1||!/\\d/.test(r))s=o[r]=function(t){for(var e=t.cells,r=t.positions,n=new Float32Array(6*e.length),i=0,a=0,o=0;o<e.length;++o)for(var s=e[o],l=0;l<3;++l){var c=r[s[l]];n[i++]=c[0],n[i++]=c[1]+1.4,a=Math.max(c[0],a)}return{data:n,shape:a}}(n(r,{triangles:!0,font:e,textAlign:i.textAlign||\"left\",textBaseline:\"alphabetic\",styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0}}));else{for(var l=r.split(/(\\d|\\s)/),c=new Array(l.length),u=0,h=0,f=0;f<l.length;++f)c[f]=t(e,l[f]),u+=c[f].data.length,h+=c[f].shape,f>0&&(h+=.02);for(var p=new Float32Array(u),d=0,g=-.5*h,f=0;f<c.length;++f){for(var v=c[f].data,m=0;m<v.length;m+=2)p[d++]=v[m]+g,p[d++]=v[m+1];g+=c[f].shape+.02}s=o[r]={data:p,shape:h}}return s};var n=t(\"vectorize-text\"),i=window||r.global||{},a=i.__TEXT_CACHE||{};i.__TEXT_CACHE={}}).call(this,t(\"_process\"))},{_process:482,\"vectorize-text\":550}],537:[function(t,e,r){!function(t){var r=/^\\s+/,n=/\\s+$/,i=0,a=t.round,o=t.min,s=t.max,l=t.random;function c(e,l){if(l=l||{},(e=e||\"\")instanceof c)return e;if(!(this instanceof c))return new c(e,l);var u=function(e){var i={r:0,g:0,b:0},a=1,l=null,c=null,u=null,h=!1,f=!1;\"string\"==typeof e&&(e=function(t){t=t.replace(r,\"\").replace(n,\"\").toLowerCase();var e,i=!1;if(S[t])t=S[t],i=!0;else if(\"transparent\"==t)return{r:0,g:0,b:0,a:0,format:\"name\"};if(e=j.rgb.exec(t))return{r:e[1],g:e[2],b:e[3]};if(e=j.rgba.exec(t))return{r:e[1],g:e[2],b:e[3],a:e[4]};if(e=j.hsl.exec(t))return{h:e[1],s:e[2],l:e[3]};if(e=j.hsla.exec(t))return{h:e[1],s:e[2],l:e[3],a:e[4]};if(e=j.hsv.exec(t))return{h:e[1],s:e[2],v:e[3]};if(e=j.hsva.exec(t))return{h:e[1],s:e[2],v:e[3],a:e[4]};if(e=j.hex8.exec(t))return{r:O(e[1]),g:O(e[2]),b:O(e[3]),a:R(e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex6.exec(t))return{r:O(e[1]),g:O(e[2]),b:O(e[3]),format:i?\"name\":\"hex\"};if(e=j.hex4.exec(t))return{r:O(e[1]+\"\"+e[1]),g:O(e[2]+\"\"+e[2]),b:O(e[3]+\"\"+e[3]),a:R(e[4]+\"\"+e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex3.exec(t))return{r:O(e[1]+\"\"+e[1]),g:O(e[2]+\"\"+e[2]),b:O(e[3]+\"\"+e[3]),format:i?\"name\":\"hex\"};return!1}(e));\"object\"==typeof e&&(U(e.r)&&U(e.g)&&U(e.b)?(p=e.r,d=e.g,g=e.b,i={r:255*L(p,255),g:255*L(d,255),b:255*L(g,255)},h=!0,f=\"%\"===String(e.r).substr(-1)?\"prgb\":\"rgb\"):U(e.h)&&U(e.s)&&U(e.v)?(l=I(e.s),c=I(e.v),i=function(e,r,n){e=6*L(e,360),r=L(r,100),n=L(n,100);var i=t.floor(e),a=e-i,o=n*(1-r),s=n*(1-a*r),l=n*(1-(1-a)*r),c=i%6;return{r:255*[n,s,o,o,l,n][c],g:255*[l,n,n,s,o,o][c],b:255*[o,o,l,n,n,s][c]}}(e.h,l,c),h=!0,f=\"hsv\"):U(e.h)&&U(e.s)&&U(e.l)&&(l=I(e.s),u=I(e.l),i=function(t,e,r){var n,i,a;function o(t,e,r){return r<0&&(r+=1),r>1&&(r-=1),r<1/6?t+6*(e-t)*r:r<.5?e:r<2/3?t+(e-t)*(2/3-r)*6:t}if(t=L(t,360),e=L(e,100),r=L(r,100),0===e)n=i=a=r;else{var s=r<.5?r*(1+e):r+e-r*e,l=2*r-s;n=o(l,s,t+1/3),i=o(l,s,t),a=o(l,s,t-1/3)}return{r:255*n,g:255*i,b:255*a}}(e.h,l,u),h=!0,f=\"hsl\"),e.hasOwnProperty(\"a\")&&(a=e.a));var p,d,g;return a=C(a),{ok:h,format:e.format||f,r:o(255,s(i.r,0)),g:o(255,s(i.g,0)),b:o(255,s(i.b,0)),a:a}}(e);this._originalInput=e,this._r=u.r,this._g=u.g,this._b=u.b,this._a=u.a,this._roundA=a(100*this._a)/100,this._format=l.format||u.format,this._gradientType=l.gradientType,this._r<1&&(this._r=a(this._r)),this._g<1&&(this._g=a(this._g)),this._b<1&&(this._b=a(this._b)),this._ok=u.ok,this._tc_id=i++}function u(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=(a+l)/2;if(a==l)n=i=0;else{var u=a-l;switch(i=c>.5?u/(2-a-l):u/(a+l),a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,l:c}}function h(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=a,u=a-l;if(i=0===a?0:u/a,a==l)n=0;else{switch(a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,v:c}}function f(t,e,r,n){var i=[z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16))];return n&&i[0].charAt(0)==i[0].charAt(1)&&i[1].charAt(0)==i[1].charAt(1)&&i[2].charAt(0)==i[2].charAt(1)?i[0].charAt(0)+i[1].charAt(0)+i[2].charAt(0):i.join(\"\")}function p(t,e,r,n){return[z(D(n)),z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16))].join(\"\")}function d(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s-=e/100,r.s=P(r.s),c(r)}function g(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s+=e/100,r.s=P(r.s),c(r)}function v(t){return c(t).desaturate(100)}function m(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l+=e/100,r.l=P(r.l),c(r)}function y(t,e){e=0===e?0:e||10;var r=c(t).toRgb();return r.r=s(0,o(255,r.r-a(-e/100*255))),r.g=s(0,o(255,r.g-a(-e/100*255))),r.b=s(0,o(255,r.b-a(-e/100*255))),c(r)}function x(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l-=e/100,r.l=P(r.l),c(r)}function b(t,e){var r=c(t).toHsl(),n=(r.h+e)%360;return r.h=n<0?360+n:n,c(r)}function _(t){var e=c(t).toHsl();return e.h=(e.h+180)%360,c(e)}function w(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+120)%360,s:e.s,l:e.l}),c({h:(r+240)%360,s:e.s,l:e.l})]}function k(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+90)%360,s:e.s,l:e.l}),c({h:(r+180)%360,s:e.s,l:e.l}),c({h:(r+270)%360,s:e.s,l:e.l})]}function T(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+72)%360,s:e.s,l:e.l}),c({h:(r+216)%360,s:e.s,l:e.l})]}function A(t,e,r){e=e||6,r=r||30;var n=c(t).toHsl(),i=360/r,a=[c(t)];for(n.h=(n.h-(i*e>>1)+720)%360;--e;)n.h=(n.h+i)%360,a.push(c(n));return a}function M(t,e){e=e||6;for(var r=c(t).toHsv(),n=r.h,i=r.s,a=r.v,o=[],s=1/e;e--;)o.push(c({h:n,s:i,v:a})),a=(a+s)%1;return o}c.prototype={isDark:function(){return this.getBrightness()<128},isLight:function(){return!this.isDark()},isValid:function(){return this._ok},getOriginalInput:function(){return this._originalInput},getFormat:function(){return this._format},getAlpha:function(){return this._a},getBrightness:function(){var t=this.toRgb();return(299*t.r+587*t.g+114*t.b)/1e3},getLuminance:function(){var e,r,n,i=this.toRgb();return e=i.r/255,r=i.g/255,n=i.b/255,.2126*(e<=.03928?e/12.92:t.pow((e+.055)/1.055,2.4))+.7152*(r<=.03928?r/12.92:t.pow((r+.055)/1.055,2.4))+.0722*(n<=.03928?n/12.92:t.pow((n+.055)/1.055,2.4))},setAlpha:function(t){return this._a=C(t),this._roundA=a(100*this._a)/100,this},toHsv:function(){var t=h(this._r,this._g,this._b);return{h:360*t.h,s:t.s,v:t.v,a:this._a}},toHsvString:function(){var t=h(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.v);return 1==this._a?\"hsv(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsva(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHsl:function(){var t=u(this._r,this._g,this._b);return{h:360*t.h,s:t.s,l:t.l,a:this._a}},toHslString:function(){var t=u(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.l);return 1==this._a?\"hsl(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsla(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHex:function(t){return f(this._r,this._g,this._b,t)},toHexString:function(t){return\"#\"+this.toHex(t)},toHex8:function(t){return function(t,e,r,n,i){var o=[z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16)),z(D(n))];if(i&&o[0].charAt(0)==o[0].charAt(1)&&o[1].charAt(0)==o[1].charAt(1)&&o[2].charAt(0)==o[2].charAt(1)&&o[3].charAt(0)==o[3].charAt(1))return o[0].charAt(0)+o[1].charAt(0)+o[2].charAt(0)+o[3].charAt(0);return o.join(\"\")}(this._r,this._g,this._b,this._a,t)},toHex8String:function(t){return\"#\"+this.toHex8(t)},toRgb:function(){return{r:a(this._r),g:a(this._g),b:a(this._b),a:this._a}},toRgbString:function(){return 1==this._a?\"rgb(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\")\":\"rgba(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\", \"+this._roundA+\")\"},toPercentageRgb:function(){return{r:a(100*L(this._r,255))+\"%\",g:a(100*L(this._g,255))+\"%\",b:a(100*L(this._b,255))+\"%\",a:this._a}},toPercentageRgbString:function(){return 1==this._a?\"rgb(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%)\":\"rgba(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%, \"+this._roundA+\")\"},toName:function(){return 0===this._a?\"transparent\":!(this._a<1)&&(E[f(this._r,this._g,this._b,!0)]||!1)},toFilter:function(t){var e=\"#\"+p(this._r,this._g,this._b,this._a),r=e,n=this._gradientType?\"GradientType = 1, \":\"\";if(t){var i=c(t);r=\"#\"+p(i._r,i._g,i._b,i._a)}return\"progid:DXImageTransform.Microsoft.gradient(\"+n+\"startColorstr=\"+e+\",endColorstr=\"+r+\")\"},toString:function(t){var e=!!t;t=t||this._format;var r=!1,n=this._a<1&&this._a>=0;return e||!n||\"hex\"!==t&&\"hex6\"!==t&&\"hex3\"!==t&&\"hex4\"!==t&&\"hex8\"!==t&&\"name\"!==t?(\"rgb\"===t&&(r=this.toRgbString()),\"prgb\"===t&&(r=this.toPercentageRgbString()),\"hex\"!==t&&\"hex6\"!==t||(r=this.toHexString()),\"hex3\"===t&&(r=this.toHexString(!0)),\"hex4\"===t&&(r=this.toHex8String(!0)),\"hex8\"===t&&(r=this.toHex8String()),\"name\"===t&&(r=this.toName()),\"hsl\"===t&&(r=this.toHslString()),\"hsv\"===t&&(r=this.toHsvString()),r||this.toHexString()):\"name\"===t&&0===this._a?this.toName():this.toRgbString()},clone:function(){return c(this.toString())},_applyModification:function(t,e){var r=t.apply(null,[this].concat([].slice.call(e)));return this._r=r._r,this._g=r._g,this._b=r._b,this.setAlpha(r._a),this},lighten:function(){return this._applyModification(m,arguments)},brighten:function(){return this._applyModification(y,arguments)},darken:function(){return this._applyModification(x,arguments)},desaturate:function(){return this._applyModification(d,arguments)},saturate:function(){return this._applyModification(g,arguments)},greyscale:function(){return this._applyModification(v,arguments)},spin:function(){return this._applyModification(b,arguments)},_applyCombination:function(t,e){return t.apply(null,[this].concat([].slice.call(e)))},analogous:function(){return this._applyCombination(A,arguments)},complement:function(){return this._applyCombination(_,arguments)},monochromatic:function(){return this._applyCombination(M,arguments)},splitcomplement:function(){return this._applyCombination(T,arguments)},triad:function(){return this._applyCombination(w,arguments)},tetrad:function(){return this._applyCombination(k,arguments)}},c.fromRatio=function(t,e){if(\"object\"==typeof t){var r={};for(var n in t)t.hasOwnProperty(n)&&(r[n]=\"a\"===n?t[n]:I(t[n]));t=r}return c(t,e)},c.equals=function(t,e){return!(!t||!e)&&c(t).toRgbString()==c(e).toRgbString()},c.random=function(){return c.fromRatio({r:l(),g:l(),b:l()})},c.mix=function(t,e,r){r=0===r?0:r||50;var n=c(t).toRgb(),i=c(e).toRgb(),a=r/100;return c({r:(i.r-n.r)*a+n.r,g:(i.g-n.g)*a+n.g,b:(i.b-n.b)*a+n.b,a:(i.a-n.a)*a+n.a})},c.readability=function(e,r){var n=c(e),i=c(r);return(t.max(n.getLuminance(),i.getLuminance())+.05)/(t.min(n.getLuminance(),i.getLuminance())+.05)},c.isReadable=function(t,e,r){var n,i,a=c.readability(t,e);switch(i=!1,(n=function(t){var e,r;e=((t=t||{level:\"AA\",size:\"small\"}).level||\"AA\").toUpperCase(),r=(t.size||\"small\").toLowerCase(),\"AA\"!==e&&\"AAA\"!==e&&(e=\"AA\");\"small\"!==r&&\"large\"!==r&&(r=\"small\");return{level:e,size:r}}(r)).level+n.size){case\"AAsmall\":case\"AAAlarge\":i=a>=4.5;break;case\"AAlarge\":i=a>=3;break;case\"AAAsmall\":i=a>=7}return i},c.mostReadable=function(t,e,r){var n,i,a,o,s=null,l=0;i=(r=r||{}).includeFallbackColors,a=r.level,o=r.size;for(var u=0;u<e.length;u++)(n=c.readability(t,e[u]))>l&&(l=n,s=c(e[u]));return c.isReadable(t,s,{level:a,size:o})||!i?s:(r.includeFallbackColors=!1,c.mostReadable(t,[\"#fff\",\"#000\"],r))};var S=c.names={aliceblue:\"f0f8ff\",antiquewhite:\"faebd7\",aqua:\"0ff\",aquamarine:\"7fffd4\",azure:\"f0ffff\",beige:\"f5f5dc\",bisque:\"ffe4c4\",black:\"000\",blanchedalmond:\"ffebcd\",blue:\"00f\",blueviolet:\"8a2be2\",brown:\"a52a2a\",burlywood:\"deb887\",burntsienna:\"ea7e5d\",cadetblue:\"5f9ea0\",chartreuse:\"7fff00\",chocolate:\"d2691e\",coral:\"ff7f50\",cornflowerblue:\"6495ed\",cornsilk:\"fff8dc\",crimson:\"dc143c\",cyan:\"0ff\",darkblue:\"00008b\",darkcyan:\"008b8b\",darkgoldenrod:\"b8860b\",darkgray:\"a9a9a9\",darkgreen:\"006400\",darkgrey:\"a9a9a9\",darkkhaki:\"bdb76b\",darkmagenta:\"8b008b\",darkolivegreen:\"556b2f\",darkorange:\"ff8c00\",darkorchid:\"9932cc\",darkred:\"8b0000\",darksalmon:\"e9967a\",darkseagreen:\"8fbc8f\",darkslateblue:\"483d8b\",darkslategray:\"2f4f4f\",darkslategrey:\"2f4f4f\",darkturquoise:\"00ced1\",darkviolet:\"9400d3\",deeppink:\"ff1493\",deepskyblue:\"00bfff\",dimgray:\"696969\",dimgrey:\"696969\",dodgerblue:\"1e90ff\",firebrick:\"b22222\",floralwhite:\"fffaf0\",forestgreen:\"228b22\",fuchsia:\"f0f\",gainsboro:\"dcdcdc\",ghostwhite:\"f8f8ff\",gold:\"ffd700\",goldenrod:\"daa520\",gray:\"808080\",green:\"008000\",greenyellow:\"adff2f\",grey:\"808080\",honeydew:\"f0fff0\",hotpink:\"ff69b4\",indianred:\"cd5c5c\",indigo:\"4b0082\",ivory:\"fffff0\",khaki:\"f0e68c\",lavender:\"e6e6fa\",lavenderblush:\"fff0f5\",lawngreen:\"7cfc00\",lemonchiffon:\"fffacd\",lightblue:\"add8e6\",lightcoral:\"f08080\",lightcyan:\"e0ffff\",lightgoldenrodyellow:\"fafad2\",lightgray:\"d3d3d3\",lightgreen:\"90ee90\",lightgrey:\"d3d3d3\",lightpink:\"ffb6c1\",lightsalmon:\"ffa07a\",lightseagreen:\"20b2aa\",lightskyblue:\"87cefa\",lightslategray:\"789\",lightslategrey:\"789\",lightsteelblue:\"b0c4de\",lightyellow:\"ffffe0\",lime:\"0f0\",limegreen:\"32cd32\",linen:\"faf0e6\",magenta:\"f0f\",maroon:\"800000\",mediumaquamarine:\"66cdaa\",mediumblue:\"0000cd\",mediumorchid:\"ba55d3\",mediumpurple:\"9370db\",mediumseagreen:\"3cb371\",mediumslateblue:\"7b68ee\",mediumspringgreen:\"00fa9a\",mediumturquoise:\"48d1cc\",mediumvioletred:\"c71585\",midnightblue:\"191970\",mintcream:\"f5fffa\",mistyrose:\"ffe4e1\",moccasin:\"ffe4b5\",navajowhite:\"ffdead\",navy:\"000080\",oldlace:\"fdf5e6\",olive:\"808000\",olivedrab:\"6b8e23\",orange:\"ffa500\",orangered:\"ff4500\",orchid:\"da70d6\",palegoldenrod:\"eee8aa\",palegreen:\"98fb98\",paleturquoise:\"afeeee\",palevioletred:\"db7093\",papayawhip:\"ffefd5\",peachpuff:\"ffdab9\",peru:\"cd853f\",pink:\"ffc0cb\",plum:\"dda0dd\",powderblue:\"b0e0e6\",purple:\"800080\",rebeccapurple:\"663399\",red:\"f00\",rosybrown:\"bc8f8f\",royalblue:\"4169e1\",saddlebrown:\"8b4513\",salmon:\"fa8072\",sandybrown:\"f4a460\",seagreen:\"2e8b57\",seashell:\"fff5ee\",sienna:\"a0522d\",silver:\"c0c0c0\",skyblue:\"87ceeb\",slateblue:\"6a5acd\",slategray:\"708090\",slategrey:\"708090\",snow:\"fffafa\",springgreen:\"00ff7f\",steelblue:\"4682b4\",tan:\"d2b48c\",teal:\"008080\",thistle:\"d8bfd8\",tomato:\"ff6347\",turquoise:\"40e0d0\",violet:\"ee82ee\",wheat:\"f5deb3\",white:\"fff\",whitesmoke:\"f5f5f5\",yellow:\"ff0\",yellowgreen:\"9acd32\"},E=c.hexNames=function(t){var e={};for(var r in t)t.hasOwnProperty(r)&&(e[t[r]]=r);return e}(S);function C(t){return t=parseFloat(t),(isNaN(t)||t<0||t>1)&&(t=1),t}function L(e,r){(function(t){return\"string\"==typeof t&&-1!=t.indexOf(\".\")&&1===parseFloat(t)})(e)&&(e=\"100%\");var n=function(t){return\"string\"==typeof t&&-1!=t.indexOf(\"%\")}(e);return e=o(r,s(0,parseFloat(e))),n&&(e=parseInt(e*r,10)/100),t.abs(e-r)<1e-6?1:e%r/parseFloat(r)}function P(t){return o(1,s(0,t))}function O(t){return parseInt(t,16)}function z(t){return 1==t.length?\"0\"+t:\"\"+t}function I(t){return t<=1&&(t=100*t+\"%\"),t}function D(e){return t.round(255*parseFloat(e)).toString(16)}function R(t){return O(t)/255}var F,B,N,j=(B=\"[\\\\s|\\\\(]+(\"+(F=\"(?:[-\\\\+]?\\\\d*\\\\.\\\\d+%?)|(?:[-\\\\+]?\\\\d+%?)\")+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",N=\"[\\\\s|\\\\(]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",{CSS_UNIT:new RegExp(F),rgb:new RegExp(\"rgb\"+B),rgba:new RegExp(\"rgba\"+N),hsl:new RegExp(\"hsl\"+B),hsla:new RegExp(\"hsla\"+N),hsv:new RegExp(\"hsv\"+B),hsva:new RegExp(\"hsva\"+N),hex3:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex6:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/,hex4:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex8:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/});function U(t){return!!j.CSS_UNIT.exec(t)}\"undefined\"!=typeof e&&e.exports?e.exports=c:window.tinycolor=c}(Math)},{}],538:[function(t,e,r){\"use strict\";e.exports=i,e.exports.float32=e.exports.float=i,e.exports.fract32=e.exports.fract=function(t){if(t.length){for(var e=i(t),r=0,n=e.length;r<n;r++)e[r]=t[r]-e[r];return e}return i(t-i(t))};var n=new Float32Array(1);function i(t){if(t.length){if(t instanceof Float32Array)return t;var e=new Float32Array(t);return e.set(t),e}return n[0]=t,n[0]}},{}],539:[function(t,e,r){\"use strict\";var n=t(\"parse-unit\");e.exports=o;var i=96;function a(t,e){var r=n(getComputedStyle(t).getPropertyValue(e));return r[0]*o(r[1],t)}function o(t,e){switch(e=e||document.body,t=(t||\"px\").trim().toLowerCase(),e!==window&&e!==document||(e=document.body),t){case\"%\":return e.clientHeight/100;case\"ch\":case\"ex\":return function(t,e){var r=document.createElement(\"div\");r.style[\"font-size\"]=\"128\"+t,e.appendChild(r);var n=a(r,\"font-size\")/128;return e.removeChild(r),n}(t,e);case\"em\":return a(e,\"font-size\");case\"rem\":return a(document.body,\"font-size\");case\"vw\":return window.innerWidth/100;case\"vh\":return window.innerHeight/100;case\"vmin\":return Math.min(window.innerWidth,window.innerHeight)/100;case\"vmax\":return Math.max(window.innerWidth,window.innerHeight)/100;case\"in\":return i;case\"cm\":return i/2.54;case\"mm\":return i/25.4;case\"pt\":return i/72;case\"pc\":return i/6}return 1}},{\"parse-unit\":461}],540:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e=function(t){return t},r=function(t){if(null==(r=t.transform))return e;var r,n,i,a=r.scale[0],o=r.scale[1],s=r.translate[0],l=r.translate[1];return function(t,e){return e||(n=i=0),t[0]=(n+=t[0])*a+s,t[1]=(i+=t[1])*o+l,t}},n=function(t){var e=t.bbox;function n(t){l[0]=t[0],l[1]=t[1],s(l),l[0]<c&&(c=l[0]),l[0]>h&&(h=l[0]),l[1]<u&&(u=l[1]),l[1]>f&&(f=l[1])}function i(t){switch(t.type){case\"GeometryCollection\":t.geometries.forEach(i);break;case\"Point\":n(t.coordinates);break;case\"MultiPoint\":t.coordinates.forEach(n)}}if(!e){var a,o,s=r(t),l=new Array(2),c=1/0,u=c,h=-c,f=-c;for(o in t.arcs.forEach(function(t){for(var e=-1,r=t.length;++e<r;)a=t[e],l[0]=a[0],l[1]=a[1],s(l,e),l[0]<c&&(c=l[0]),l[0]>h&&(h=l[0]),l[1]<u&&(u=l[1]),l[1]>f&&(f=l[1])}),t.objects)i(t.objects[o]);e=t.bbox=[c,u,h,f]}return e},i=function(t,e){for(var r,n=t.length,i=n-e;i<--n;)r=t[i],t[i++]=t[n],t[n]=r};function a(t,e){var r=e.id,n=e.bbox,i=null==e.properties?{}:e.properties,a=o(t,e);return null==r&&null==n?{type:\"Feature\",properties:i,geometry:a}:null==n?{type:\"Feature\",id:r,properties:i,geometry:a}:{type:\"Feature\",id:r,bbox:n,properties:i,geometry:a}}function o(t,e){var n=r(t),a=t.arcs;function o(t,e){e.length&&e.pop();for(var r=a[t<0?~t:t],o=0,s=r.length;o<s;++o)e.push(n(r[o].slice(),o));t<0&&i(e,s)}function s(t){return n(t.slice())}function l(t){for(var e=[],r=0,n=t.length;r<n;++r)o(t[r],e);return e.length<2&&e.push(e[0].slice()),e}function c(t){for(var e=l(t);e.length<4;)e.push(e[0].slice());return e}function u(t){return t.map(c)}return function t(e){var r,n=e.type;switch(n){case\"GeometryCollection\":return{type:n,geometries:e.geometries.map(t)};case\"Point\":r=s(e.coordinates);break;case\"MultiPoint\":r=e.coordinates.map(s);break;case\"LineString\":r=l(e.arcs);break;case\"MultiLineString\":r=e.arcs.map(l);break;case\"Polygon\":r=u(e.arcs);break;case\"MultiPolygon\":r=e.arcs.map(u);break;default:return null}return{type:n,coordinates:r}}(e)}var s=function(t,e){var r={},n={},i={},a=[],o=-1;function s(t,e){for(var n in t){var i=t[n];delete e[i.start],delete i.start,delete i.end,i.forEach(function(t){r[t<0?~t:t]=1}),a.push(i)}}return e.forEach(function(r,n){var i,a=t.arcs[r<0?~r:r];a.length<3&&!a[1][0]&&!a[1][1]&&(i=e[++o],e[o]=r,e[n]=i)}),e.forEach(function(e){var r,a,o=function(e){var r,n=t.arcs[e<0?~e:e],i=n[0];t.transform?(r=[0,0],n.forEach(function(t){r[0]+=t[0],r[1]+=t[1]})):r=n[n.length-1];return e<0?[r,i]:[i,r]}(e),s=o[0],l=o[1];if(r=i[s])if(delete i[r.end],r.push(e),r.end=l,a=n[l]){delete n[a.start];var c=a===r?r:r.concat(a);n[c.start=r.start]=i[c.end=a.end]=c}else n[r.start]=i[r.end]=r;else if(r=n[l])if(delete n[r.start],r.unshift(e),r.start=s,a=i[s]){delete i[a.end];var u=a===r?r:a.concat(r);n[u.start=a.start]=i[u.end=r.end]=u}else n[r.start]=i[r.end]=r;else n[(r=[e]).start=s]=i[r.end=l]=r}),s(i,n),s(n,i),e.forEach(function(t){r[t<0?~t:t]||a.push([t])}),a};function l(t,e,r){var n,i,a;if(arguments.length>1)n=function(t,e,r){var n,i=[],a=[];function o(t){var e=t<0?~t:t;(a[e]||(a[e]=[])).push({i:t,g:n})}function s(t){t.forEach(o)}function l(t){t.forEach(s)}return function t(e){switch(n=e,e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"LineString\":s(e.arcs);break;case\"MultiLineString\":case\"Polygon\":l(e.arcs);break;case\"MultiPolygon\":e.arcs.forEach(l)}}(e),a.forEach(null==r?function(t){i.push(t[0].i)}:function(t){r(t[0].g,t[t.length-1].g)&&i.push(t[0].i)}),i}(0,e,r);else for(i=0,n=new Array(a=t.arcs.length);i<a;++i)n[i]=i;return{type:\"MultiLineString\",arcs:s(t,n)}}function c(t,e){var r={},n=[],i=[];function a(t){t.forEach(function(e){e.forEach(function(e){(r[e=e<0?~e:e]||(r[e]=[])).push(t)})}),n.push(t)}function l(e){return function(t){for(var e,r=-1,n=t.length,i=t[n-1],a=0;++r<n;)e=i,i=t[r],a+=e[0]*i[1]-e[1]*i[0];return Math.abs(a)}(o(t,{type:\"Polygon\",arcs:[e]}).coordinates[0])}return e.forEach(function t(e){switch(e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"Polygon\":a(e.arcs);break;case\"MultiPolygon\":e.arcs.forEach(a)}}),n.forEach(function(t){if(!t._){var e=[],n=[t];for(t._=1,i.push(e);t=n.pop();)e.push(t),t.forEach(function(t){t.forEach(function(t){r[t<0?~t:t].forEach(function(t){t._||(t._=1,n.push(t))})})})}}),n.forEach(function(t){delete t._}),{type:\"MultiPolygon\",arcs:i.map(function(e){var n,i=[];if(e.forEach(function(t){t.forEach(function(t){t.forEach(function(t){r[t<0?~t:t].length<2&&i.push(t)})})}),(n=(i=s(t,i)).length)>1)for(var a,o,c=1,u=l(i[0]);c<n;++c)(a=l(i[c]))>u&&(o=i[0],i[0]=i[c],i[c]=o,u=a);return i})}}var u=function(t,e){for(var r=0,n=t.length;r<n;){var i=r+n>>>1;t[i]<e?r=i+1:n=i}return r};t.bbox=n,t.feature=function(t,e){return\"GeometryCollection\"===e.type?{type:\"FeatureCollection\",features:e.geometries.map(function(e){return a(t,e)})}:a(t,e)},t.mesh=function(t){return o(t,l.apply(this,arguments))},t.meshArcs=l,t.merge=function(t){return o(t,c.apply(this,arguments))},t.mergeArcs=c,t.neighbors=function(t){var e={},r=t.map(function(){return[]});function n(t,r){t.forEach(function(t){t<0&&(t=~t);var n=e[t];n?n.push(r):e[t]=[r]})}function i(t,e){t.forEach(function(t){n(t,e)})}var a={LineString:n,MultiLineString:i,Polygon:i,MultiPolygon:function(t,e){t.forEach(function(t){i(t,e)})}};for(var o in t.forEach(function t(e,r){\"GeometryCollection\"===e.type?e.geometries.forEach(function(e){t(e,r)}):e.type in a&&a[e.type](e.arcs,r)}),e)for(var s=e[o],l=s.length,c=0;c<l;++c)for(var h=c+1;h<l;++h){var f,p=s[c],d=s[h];(f=r[p])[o=u(f,d)]!==d&&f.splice(o,0,d),(f=r[d])[o=u(f,p)]!==p&&f.splice(o,0,p)}return r},t.quantize=function(t,e){if(!((e=Math.floor(e))>=2))throw new Error(\"n must be \\u22652\");if(t.transform)throw new Error(\"already quantized\");var r,i=n(t),a=i[0],o=(i[2]-a)/(e-1)||1,s=i[1],l=(i[3]-s)/(e-1)||1;function c(t){t[0]=Math.round((t[0]-a)/o),t[1]=Math.round((t[1]-s)/l)}function u(t){switch(t.type){case\"GeometryCollection\":t.geometries.forEach(u);break;case\"Point\":c(t.coordinates);break;case\"MultiPoint\":t.coordinates.forEach(c)}}for(r in t.arcs.forEach(function(t){for(var e,r,n,i=1,c=1,u=t.length,h=t[0],f=h[0]=Math.round((h[0]-a)/o),p=h[1]=Math.round((h[1]-s)/l);i<u;++i)h=t[i],r=Math.round((h[0]-a)/o),n=Math.round((h[1]-s)/l),r===f&&n===p||((e=t[c++])[0]=r-f,f=r,e[1]=n-p,p=n);c<2&&((e=t[c++])[0]=0,e[1]=0),t.length=c}),t.objects)u(t.objects[r]);return t.transform={scale:[o,l],translate:[a,s]},t},t.transform=r,t.untransform=function(t){if(null==(r=t.transform))return e;var r,n,i,a=r.scale[0],o=r.scale[1],s=r.translate[0],l=r.translate[1];return function(t,e){e||(n=i=0);var r=Math.round((t[0]-s)/a),c=Math.round((t[1]-l)/o);return t[0]=r-n,n=r,t[1]=c-i,i=c,t}},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.topojson=n.topojson||{})},{}],541:[function(t,e,r){\"use strict\";e.exports=function(t){if(t<0)return[];if(0===t)return[[0]];for(var e=0|Math.round(a(t+1)),r=[],o=0;o<e;++o){for(var s=n.unrank(t,o),l=[0],c=0,u=0;u<s.length;++u)c+=1<<s[u],l.push(c);i(s)<1&&(l[0]=c,l[t]=0),r.push(l)}return r};var n=t(\"permutation-rank\"),i=t(\"permutation-parity\"),a=t(\"gamma\")},{gamma:231,\"permutation-parity\":463,\"permutation-rank\":464}],542:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.up||[0,1,0],n=t.right||h(r),i=t.radius||1,a=t.theta||0,u=t.phi||0;if(e=[].slice.call(e,0,3),r=[].slice.call(r,0,3),s(r,r),n=[].slice.call(n,0,3),s(n,n),\"eye\"in t){var p=t.eye,d=[p[0]-e[0],p[1]-e[1],p[2]-e[2]];o(n,d,r),c(n[0],n[1],n[2])<1e-6?n=h(r):s(n,n),i=c(d[0],d[1],d[2]);var g=l(r,d)/i,v=l(n,d)/i;u=Math.acos(g),a=Math.acos(v)}return i=Math.log(i),new f(t.zoomMin,t.zoomMax,e,r,n,i,a,u)};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/invert\"),a=t(\"gl-mat4/rotate\"),o=t(\"gl-vec3/cross\"),s=t(\"gl-vec3/normalize\"),l=t(\"gl-vec3/dot\");function c(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function u(t){return Math.min(1,Math.max(-1,t))}function h(t){var e=Math.abs(t[0]),r=Math.abs(t[1]),n=Math.abs(t[2]),i=[0,0,0];e>Math.max(r,n)?i[2]=1:r>Math.max(e,n)?i[0]=1:i[1]=1;for(var a=0,o=0,l=0;l<3;++l)a+=t[l]*t[l],o+=i[l]*t[l];for(l=0;l<3;++l)i[l]-=o/a*t[l];return s(i,i),i}function f(t,e,r,i,a,o,s,l){this.center=n(r),this.up=n(i),this.right=n(a),this.radius=n([o]),this.angle=n([s,l]),this.angle.bounds=[[-1/0,-Math.PI/2],[1/0,Math.PI/2]],this.setDistanceLimits(t,e),this.computedCenter=this.center.curve(0),this.computedUp=this.up.curve(0),this.computedRight=this.right.curve(0),this.computedRadius=this.radius.curve(0),this.computedAngle=this.angle.curve(0),this.computedToward=[0,0,0],this.computedEye=[0,0,0],this.computedMatrix=new Array(16);for(var c=0;c<16;++c)this.computedMatrix[c]=.5;this.recalcMatrix(0)}var p=f.prototype;p.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},p.getDistanceLimits=function(t){var e=this.radius.bounds[0];return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},p.recalcMatrix=function(t){this.center.curve(t),this.up.curve(t),this.right.curve(t),this.radius.curve(t),this.angle.curve(t);for(var e=this.computedUp,r=this.computedRight,n=0,i=0,a=0;a<3;++a)i+=e[a]*r[a],n+=e[a]*e[a];var l=Math.sqrt(n),u=0;for(a=0;a<3;++a)r[a]-=e[a]*i/n,u+=r[a]*r[a],e[a]/=l;var h=Math.sqrt(u);for(a=0;a<3;++a)r[a]/=h;var f=this.computedToward;o(f,e,r),s(f,f);var p=Math.exp(this.computedRadius[0]),d=this.computedAngle[0],g=this.computedAngle[1],v=Math.cos(d),m=Math.sin(d),y=Math.cos(g),x=Math.sin(g),b=this.computedCenter,_=v*y,w=m*y,k=x,T=-v*x,A=-m*x,M=y,S=this.computedEye,E=this.computedMatrix;for(a=0;a<3;++a){var C=_*r[a]+w*f[a]+k*e[a];E[4*a+1]=T*r[a]+A*f[a]+M*e[a],E[4*a+2]=C,E[4*a+3]=0}var L=E[1],P=E[5],O=E[9],z=E[2],I=E[6],D=E[10],R=P*D-O*I,F=O*z-L*D,B=L*I-P*z,N=c(R,F,B);R/=N,F/=N,B/=N,E[0]=R,E[4]=F,E[8]=B;for(a=0;a<3;++a)S[a]=b[a]+E[2+4*a]*p;for(a=0;a<3;++a){u=0;for(var j=0;j<3;++j)u+=E[a+4*j]*S[j];E[12+a]=-u}E[15]=1},p.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r};var d=[0,0,0];p.rotate=function(t,e,r,n){if(this.angle.move(t,e,r),n){this.recalcMatrix(t);var i=this.computedMatrix;d[0]=i[2],d[1]=i[6],d[2]=i[10];for(var o=this.computedUp,s=this.computedRight,l=this.computedToward,c=0;c<3;++c)i[4*c]=o[c],i[4*c+1]=s[c],i[4*c+2]=l[c];a(i,i,n,d);for(c=0;c<3;++c)o[c]=i[4*c],s[c]=i[4*c+1];this.up.set(t,o[0],o[1],o[2]),this.right.set(t,s[0],s[1],s[2])}},p.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=(Math.exp(this.computedRadius[0]),i[1]),o=i[5],s=i[9],l=c(a,o,s);a/=l,o/=l,s/=l;var u=i[0],h=i[4],f=i[8],p=u*a+h*o+f*s,d=c(u-=a*p,h-=o*p,f-=s*p),g=(u/=d)*e+a*r,v=(h/=d)*e+o*r,m=(f/=d)*e+s*r;this.center.move(t,g,v,m);var y=Math.exp(this.computedRadius[0]);y=Math.max(1e-4,y+n),this.radius.set(t,Math.log(y))},p.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},p.setMatrix=function(t,e,r,n){var a=1;\"number\"==typeof r&&(a=0|r),(a<0||a>3)&&(a=1);var o=(a+2)%3;e||(this.recalcMatrix(t),e=this.computedMatrix);var s=e[a],l=e[a+4],h=e[a+8];if(n){var f=Math.abs(s),p=Math.abs(l),d=Math.abs(h),g=Math.max(f,p,d);f===g?(s=s<0?-1:1,l=h=0):d===g?(h=h<0?-1:1,s=l=0):(l=l<0?-1:1,s=h=0)}else{var v=c(s,l,h);s/=v,l/=v,h/=v}var m,y,x=e[o],b=e[o+4],_=e[o+8],w=x*s+b*l+_*h,k=c(x-=s*w,b-=l*w,_-=h*w),T=l*(_/=k)-h*(b/=k),A=h*(x/=k)-s*_,M=s*b-l*x,S=c(T,A,M);if(T/=S,A/=S,M/=S,this.center.jump(t,H,G,Y),this.radius.idle(t),this.up.jump(t,s,l,h),this.right.jump(t,x,b,_),2===a){var E=e[1],C=e[5],L=e[9],P=E*x+C*b+L*_,O=E*T+C*A+L*M;m=R<0?-Math.PI/2:Math.PI/2,y=Math.atan2(O,P)}else{var z=e[2],I=e[6],D=e[10],R=z*s+I*l+D*h,F=z*x+I*b+D*_,B=z*T+I*A+D*M;m=Math.asin(u(R)),y=Math.atan2(B,F)}this.angle.jump(t,y,m),this.recalcMatrix(t);var N=e[2],j=e[6],U=e[10],V=this.computedMatrix;i(V,e);var q=V[15],H=V[12]/q,G=V[13]/q,Y=V[14]/q,W=Math.exp(this.computedRadius[0]);this.center.jump(t,H-N*W,G-j*W,Y-U*W)},p.lastT=function(){return Math.max(this.center.lastT(),this.up.lastT(),this.right.lastT(),this.radius.lastT(),this.angle.lastT())},p.idle=function(t){this.center.idle(t),this.up.idle(t),this.right.idle(t),this.radius.idle(t),this.angle.idle(t)},p.flush=function(t){this.center.flush(t),this.up.flush(t),this.right.flush(t),this.radius.flush(t),this.angle.flush(t)},p.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},p.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||this.computedCenter;var i=(n=n||this.computedUp)[0],a=n[1],o=n[2],s=c(i,a,o);if(!(s<1e-6)){i/=s,a/=s,o/=s;var l=e[0]-r[0],h=e[1]-r[1],f=e[2]-r[2],p=c(l,h,f);if(!(p<1e-6)){l/=p,h/=p,f/=p;var d=this.computedRight,g=d[0],v=d[1],m=d[2],y=i*g+a*v+o*m,x=c(g-=y*i,v-=y*a,m-=y*o);if(!(x<.01&&(x=c(g=a*f-o*h,v=o*l-i*f,m=i*h-a*l))<1e-6)){g/=x,v/=x,m/=x,this.up.set(t,i,a,o),this.right.set(t,g,v,m),this.center.set(t,r[0],r[1],r[2]),this.radius.set(t,Math.log(p));var b=a*m-o*v,_=o*g-i*m,w=i*v-a*g,k=c(b,_,w),T=i*l+a*h+o*f,A=g*l+v*h+m*f,M=(b/=k)*l+(_/=k)*h+(w/=k)*f,S=Math.asin(u(T)),E=Math.atan2(M,A),C=this.angle._state,L=C[C.length-1],P=C[C.length-2];L%=2*Math.PI;var O=Math.abs(L+2*Math.PI-E),z=Math.abs(L-E),I=Math.abs(L-2*Math.PI-E);O<z&&(L+=2*Math.PI),I<z&&(L-=2*Math.PI),this.angle.jump(this.angle.lastT(),L,P),this.angle.set(t,E,S)}}}}},{\"filtered-vector\":226,\"gl-mat4/invert\":265,\"gl-mat4/rotate\":270,\"gl-vec3/cross\":334,\"gl-vec3/dot\":339,\"gl-vec3/normalize\":356}],543:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var i=t*e,a=n*t,o=a-(a-t),s=t-o,l=n*e,c=l-(l-e),u=e-c,h=s*u-(i-o*c-s*c-o*u);if(r)return r[0]=h,r[1]=i,r;return[h,i]};var n=+(Math.pow(2,27)+1)},{}],544:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=t+e,i=n-t,a=e-i,o=t-(n-i);if(r)return r[0]=o+a,r[1]=n,r;return[o+a,n]}},{}],545:[function(t,e,r){(function(e,n){\"use strict\";var i=t(\"bit-twiddle\"),a=t(\"dup\");e.__TYPEDARRAY_POOL||(e.__TYPEDARRAY_POOL={UINT8:a([32,0]),UINT16:a([32,0]),UINT32:a([32,0]),INT8:a([32,0]),INT16:a([32,0]),INT32:a([32,0]),FLOAT:a([32,0]),DOUBLE:a([32,0]),DATA:a([32,0]),UINT8C:a([32,0]),BUFFER:a([32,0])});var o=\"undefined\"!=typeof Uint8ClampedArray,s=e.__TYPEDARRAY_POOL;s.UINT8C||(s.UINT8C=a([32,0])),s.BUFFER||(s.BUFFER=a([32,0]));var l=s.DATA,c=s.BUFFER;function u(t){if(t){var e=t.length||t.byteLength,r=i.log2(e);l[r].push(t)}}function h(t){t=i.nextPow2(t);var e=i.log2(t),r=l[e];return r.length>0?r.pop():new ArrayBuffer(t)}function f(t){return new Uint8Array(h(t),0,t)}function p(t){return new Uint16Array(h(2*t),0,t)}function d(t){return new Uint32Array(h(4*t),0,t)}function g(t){return new Int8Array(h(t),0,t)}function v(t){return new Int16Array(h(2*t),0,t)}function m(t){return new Int32Array(h(4*t),0,t)}function y(t){return new Float32Array(h(4*t),0,t)}function x(t){return new Float64Array(h(8*t),0,t)}function b(t){return o?new Uint8ClampedArray(h(t),0,t):f(t)}function _(t){return new DataView(h(t),0,t)}function w(t){t=i.nextPow2(t);var e=i.log2(t),r=c[e];return r.length>0?r.pop():new n(t)}r.free=function(t){if(n.isBuffer(t))c[i.log2(t.length)].push(t);else{if(\"[object ArrayBuffer]\"!==Object.prototype.toString.call(t)&&(t=t.buffer),!t)return;var e=t.length||t.byteLength,r=0|i.log2(e);l[r].push(t)}},r.freeUint8=r.freeUint16=r.freeUint32=r.freeInt8=r.freeInt16=r.freeInt32=r.freeFloat32=r.freeFloat=r.freeFloat64=r.freeDouble=r.freeUint8Clamped=r.freeDataView=function(t){u(t.buffer)},r.freeArrayBuffer=u,r.freeBuffer=function(t){c[i.log2(t.length)].push(t)},r.malloc=function(t,e){if(void 0===e||\"arraybuffer\"===e)return h(t);switch(e){case\"uint8\":return f(t);case\"uint16\":return p(t);case\"uint32\":return d(t);case\"int8\":return g(t);case\"int16\":return v(t);case\"int32\":return m(t);case\"float\":case\"float32\":return y(t);case\"double\":case\"float64\":return x(t);case\"uint8_clamped\":return b(t);case\"buffer\":return w(t);case\"data\":case\"dataview\":return _(t);default:return null}return null},r.mallocArrayBuffer=h,r.mallocUint8=f,r.mallocUint16=p,r.mallocUint32=d,r.mallocInt8=g,r.mallocInt16=v,r.mallocInt32=m,r.mallocFloat32=r.mallocFloat=y,r.mallocFloat64=r.mallocDouble=x,r.mallocUint8Clamped=b,r.mallocDataView=_,r.mallocBuffer=w,r.clearCache=function(){for(var t=0;t<32;++t)s.UINT8[t].length=0,s.UINT16[t].length=0,s.UINT32[t].length=0,s.INT8[t].length=0,s.INT16[t].length=0,s.INT32[t].length=0,s.FLOAT[t].length=0,s.DOUBLE[t].length=0,s.UINT8C[t].length=0,l[t].length=0,c[t].length=0}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{},t(\"buffer\").Buffer)},{\"bit-twiddle\":92,buffer:105,dup:170}],546:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n;var i=n.prototype;Object.defineProperty(i,\"length\",{get:function(){return this.roots.length}}),i.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},i.find=function(t){for(var e=t,r=this.roots;r[t]!==t;)t=r[t];for(;r[e]!==t;){var n=r[e];r[e]=t,e=n}return t},i.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],547:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return 0===t.length?t:e?(r||t.sort(e),function(t,e){for(var r=1,n=t.length,i=t[0],a=t[0],o=1;o<n;++o)if(a=i,e(i=t[o],a)){if(o===r){r++;continue}t[r++]=i}return t.length=r,t}(t,e)):(r||t.sort(),function(t){for(var e=1,r=t.length,n=t[0],i=t[0],a=1;a<r;++a,i=n)if(i=n,(n=t[a])!==i){if(a===e){e++;continue}t[e++]=n}return t.length=e,t}(t))}},{}],548:[function(t,e,r){var n=/[\\'\\\"]/;e.exports=function(t){return t?(n.test(t.charAt(0))&&(t=t.substr(1)),n.test(t.charAt(t.length-1))&&(t=t.substr(0,t.length-1)),t):\"\"}},{}],549:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){Array.isArray(r)||(r=[].slice.call(arguments,2));for(var n=0,i=r.length;n<i;n++){var a=r[n];for(var o in a)if((void 0===e[o]||Array.isArray(e[o])||t[o]!==e[o])&&o in e){var s;if(!0===a[o])s=e[o];else{if(!1===a[o])continue;if(\"function\"==typeof a[o]&&void 0===(s=a[o](e[o],t,e)))continue}t[o]=s}}return t}},{}],550:[function(t,e,r){\"use strict\";e.exports=function(t,e){\"object\"==typeof e&&null!==e||(e={});return n(t,e.canvas||i,e.context||a,e)};var n=t(\"./lib/vtext\"),i=null,a=null;\"undefined\"!=typeof document&&((i=document.createElement(\"canvas\")).width=8192,i.height=1024,a=i.getContext(\"2d\"))},{\"./lib/vtext\":551}],551:[function(t,e,r){e.exports=function(t,e,r,n){var a=64,o=1.25,s={breaklines:!1,bolds:!1,italics:!1,subscripts:!1,superscripts:!1};n&&(n.size&&n.size>0&&(a=n.size),n.lineSpacing&&n.lineSpacing>0&&(o=n.lineSpacing),n.styletags&&n.styletags.breaklines&&(s.breaklines=!!n.styletags.breaklines),n.styletags&&n.styletags.bolds&&(s.bolds=!!n.styletags.bolds),n.styletags&&n.styletags.italics&&(s.italics=!!n.styletags.italics),n.styletags&&n.styletags.subscripts&&(s.subscripts=!!n.styletags.subscripts),n.styletags&&n.styletags.superscripts&&(s.superscripts=!!n.styletags.superscripts));return r.font=[n.fontStyle,n.fontVariant,n.fontWeight,a+\"px\",n.font].filter(function(t){return t}).join(\" \"),r.textAlign=\"start\",r.textBaseline=\"alphabetic\",r.direction=\"ltr\",w(function(t,e,r,n,a,o){r=r.replace(/\\n/g,\"\"),r=!0===o.breaklines?r.replace(/\\<br\\>/g,\"\\n\"):r.replace(/\\<br\\>/g,\" \");var s=\"\",l=[];for(k=0;k<r.length;++k)l[k]=s;!0===o.bolds&&(l=x(c,u,r,l)),!0===o.italics&&(l=x(h,f,r,l)),!0===o.superscripts&&(l=x(p,g,r,l)),!0===o.subscripts&&(l=x(v,y,r,l));var b=[],_=\"\";for(k=0;k<r.length;++k)null!==l[k]&&(_+=r[k],b.push(l[k]));var w,k,T,A,M,S=_.split(\"\\n\"),E=S.length,C=Math.round(a*n),L=n,P=2*n,O=0,z=E*C+P;t.height<z&&(t.height=z),e.fillStyle=\"#000\",e.fillRect(0,0,t.width,t.height),e.fillStyle=\"#fff\";var I=0,D=\"\";function R(){if(\"\"!==D){var t=e.measureText(D).width;e.fillText(D,L+T,P+A),T+=t}}function F(){return Math.round(M)+\"px \"}function B(t,r){var n=\"\"+e.font;if(!0===o.subscripts){var i=t.indexOf(m),a=r.indexOf(m),s=i>-1?parseInt(t[1+i]):0,l=a>-1?parseInt(r[1+a]):0;s!==l&&(n=n.replace(F(),\"?px \"),M*=Math.pow(.75,l-s),n=n.replace(\"?px \",F())),A+=.25*C*(l-s)}if(!0===o.superscripts){var c=t.indexOf(d),h=r.indexOf(d),p=c>-1?parseInt(t[1+c]):0,g=h>-1?parseInt(r[1+h]):0;p!==g&&(n=n.replace(F(),\"?px \"),M*=Math.pow(.75,g-p),n=n.replace(\"?px \",F())),A-=.25*C*(g-p)}if(!0===o.bolds){var v=t.indexOf(u)>-1,y=r.indexOf(u)>-1;!v&&y&&(n=x?n.replace(\"italic \",\"italic bold \"):\"bold \"+n),v&&!y&&(n=n.replace(\"bold \",\"\"))}if(!0===o.italics){var x=t.indexOf(f)>-1,b=r.indexOf(f)>-1;!x&&b&&(n=\"italic \"+n),x&&!b&&(n=n.replace(\"italic \",\"\"))}e.font=n}for(w=0;w<E;++w){var N=S[w]+\"\\n\";for(T=0,A=w*C,M=n,D=\"\",k=0;k<N.length;++k){var j=k+I<b.length?b[k+I]:b[b.length-1];s===j?D+=N[k]:(R(),D=N[k],void 0!==j&&(B(s,j),s=j))}R(),I+=N.length;var U=0|Math.round(T+2*L);O<U&&(O=U)}var V=O,q=P+C*E;return i(e.getImageData(0,0,V,q).data,[q,V,4]).pick(-1,-1,0).transpose(1,0)}(e,r,t,a,o,s),n,a)},e.exports.processPixels=w;var n=t(\"surface-nets\"),i=t(\"ndarray\"),a=t(\"simplify-planar-graph\"),o=t(\"clean-pslg\"),s=t(\"cdt2d\"),l=t(\"planar-graph-to-polyline\"),c=\"b\",u=\"b|\",h=\"i\",f=\"i|\",p=\"sup\",d=\"+\",g=\"+1\",v=\"sub\",m=\"-\",y=\"-1\";function x(t,e,r,n){for(var i=\"<\"+t+\">\",a=\"</\"+t+\">\",o=i.length,s=a.length,l=e[0]===d||e[0]===m,c=0,u=-s;c>-1&&-1!==(c=r.indexOf(i,c))&&-1!==(u=r.indexOf(a,c+o))&&!(u<=c);){for(var h=c;h<u+s;++h)if(h<c+o||h>=u)n[h]=null,r=r.substr(0,h)+\" \"+r.substr(h+1);else if(null!==n[h]){var f=n[h].indexOf(e[0]);-1===f?n[h]+=e:l&&(n[h]=n[h].substr(0,f+1)+(1+parseInt(n[h][f+1]))+n[h].substr(f+2))}var p=c+o,g=r.substr(p,u-p).indexOf(i);c=-1!==g?g:u+s}return n}function b(t,e){var r=n(t,128);return e?a(r.cells,r.positions,.25):{edges:r.cells,positions:r.positions}}function _(t,e,r,n){var i=b(t,n),a=function(t,e,r){for(var n=e.textAlign||\"start\",i=e.textBaseline||\"alphabetic\",a=[1<<30,1<<30],o=[0,0],s=t.length,l=0;l<s;++l)for(var c=t[l],u=0;u<2;++u)a[u]=0|Math.min(a[u],c[u]),o[u]=0|Math.max(o[u],c[u]);var h=0;switch(n){case\"center\":h=-.5*(a[0]+o[0]);break;case\"right\":case\"end\":h=-o[0];break;case\"left\":case\"start\":h=-a[0];break;default:throw new Error(\"vectorize-text: Unrecognized textAlign: '\"+n+\"'\")}var f=0;switch(i){case\"hanging\":case\"top\":f=-a[1];break;case\"middle\":f=-.5*(a[1]+o[1]);break;case\"alphabetic\":case\"ideographic\":f=-3*r;break;case\"bottom\":f=-o[1];break;default:throw new Error(\"vectorize-text: Unrecoginized textBaseline: '\"+i+\"'\")}var p=1/r;return\"lineHeight\"in e?p*=+e.lineHeight:\"width\"in e?p=e.width/(o[0]-a[0]):\"height\"in e&&(p=e.height/(o[1]-a[1])),t.map(function(t){return[p*(t[0]+h),p*(t[1]+f)]})}(i.positions,e,r),c=i.edges,u=\"ccw\"===e.orientation;if(o(a,c),e.polygons||e.polygon||e.polyline){for(var h=l(c,a),f=new Array(h.length),p=0;p<h.length;++p){for(var d=h[p],g=new Array(d.length),v=0;v<d.length;++v){for(var m=d[v],y=new Array(m.length),x=0;x<m.length;++x)y[x]=a[m[x]].slice();u&&y.reverse(),g[v]=y}f[p]=g}return f}return e.triangles||e.triangulate||e.triangle?{cells:s(a,c,{delaunay:!1,exterior:!1,interior:!0}),positions:a}:{edges:c,positions:a}}function w(t,e,r){try{return _(t,e,r,!0)}catch(t){}try{return _(t,e,r,!1)}catch(t){}return e.polygons||e.polyline||e.polygon?[]:e.triangles||e.triangulate||e.triangle?{cells:[],positions:[]}:{edges:[],positions:[]}}},{cdt2d:106,\"clean-pslg\":116,ndarray:450,\"planar-graph-to-polyline\":468,\"simplify-planar-graph\":524,\"surface-nets\":531}],552:[function(t,e,r){!function(){\"use strict\";if(\"undefined\"==typeof ses||!ses.ok||ses.ok()){\"undefined\"!=typeof ses&&(ses.weakMapPermitHostObjects=v);var t=!1;if(\"function\"==typeof WeakMap){var r=WeakMap;if(\"undefined\"!=typeof navigator&&/Firefox/.test(navigator.userAgent));else{var n=new r,i=Object.freeze({});if(n.set(i,1),1===n.get(i))return void(e.exports=WeakMap);t=!0}}Object.prototype.hasOwnProperty;var a=Object.getOwnPropertyNames,o=Object.defineProperty,s=Object.isExtensible,l=\"weakmap:\",c=l+\"ident:\"+Math.random()+\"___\";if(\"undefined\"!=typeof crypto&&\"function\"==typeof crypto.getRandomValues&&\"function\"==typeof ArrayBuffer&&\"function\"==typeof Uint8Array){var u=new ArrayBuffer(25),h=new Uint8Array(u);crypto.getRandomValues(h),c=l+\"rand:\"+Array.prototype.map.call(h,function(t){return(t%36).toString(36)}).join(\"\")+\"___\"}if(o(Object,\"getOwnPropertyNames\",{value:function(t){return a(t).filter(m)}}),\"getPropertyNames\"in Object){var f=Object.getPropertyNames;o(Object,\"getPropertyNames\",{value:function(t){return f(t).filter(m)}})}!function(){var t=Object.freeze;o(Object,\"freeze\",{value:function(e){return y(e),t(e)}});var e=Object.seal;o(Object,\"seal\",{value:function(t){return y(t),e(t)}});var r=Object.preventExtensions;o(Object,\"preventExtensions\",{value:function(t){return y(t),r(t)}})}();var p=!1,d=0,g=function(){this instanceof g||b();var t=[],e=[],r=d++;return Object.create(g.prototype,{get___:{value:x(function(n,i){var a,o=y(n);return o?r in o?o[r]:i:(a=t.indexOf(n))>=0?e[a]:i})},has___:{value:x(function(e){var n=y(e);return n?r in n:t.indexOf(e)>=0})},set___:{value:x(function(n,i){var a,o=y(n);return o?o[r]=i:(a=t.indexOf(n))>=0?e[a]=i:(a=t.length,e[a]=i,t[a]=n),this})},delete___:{value:x(function(n){var i,a,o=y(n);return o?r in o&&delete o[r]:!((i=t.indexOf(n))<0||(a=t.length-1,t[i]=void 0,e[i]=e[a],t[i]=t[a],t.length=a,e.length=a,0))})}})};g.prototype=Object.create(Object.prototype,{get:{value:function(t,e){return this.get___(t,e)},writable:!0,configurable:!0},has:{value:function(t){return this.has___(t)},writable:!0,configurable:!0},set:{value:function(t,e){return this.set___(t,e)},writable:!0,configurable:!0},delete:{value:function(t){return this.delete___(t)},writable:!0,configurable:!0}}),\"function\"==typeof r?function(){function n(){this instanceof g||b();var e,n=new r,i=void 0,a=!1;return e=t?function(t,e){return n.set(t,e),n.has(t)||(i||(i=new g),i.set(t,e)),this}:function(t,e){if(a)try{n.set(t,e)}catch(r){i||(i=new g),i.set___(t,e)}else n.set(t,e);return this},Object.create(g.prototype,{get___:{value:x(function(t,e){return i?n.has(t)?n.get(t):i.get___(t,e):n.get(t,e)})},has___:{value:x(function(t){return n.has(t)||!!i&&i.has___(t)})},set___:{value:x(e)},delete___:{value:x(function(t){var e=!!n.delete(t);return i&&i.delete___(t)||e})},permitHostObjects___:{value:x(function(t){if(t!==v)throw new Error(\"bogus call to permitHostObjects___\");a=!0})}})}t&&\"undefined\"!=typeof Proxy&&(Proxy=void 0),n.prototype=g.prototype,e.exports=n,Object.defineProperty(WeakMap.prototype,\"constructor\",{value:WeakMap,enumerable:!1,configurable:!0,writable:!0})}():(\"undefined\"!=typeof Proxy&&(Proxy=void 0),e.exports=g)}function v(t){t.permitHostObjects___&&t.permitHostObjects___(v)}function m(t){return!(t.substr(0,l.length)==l&&\"___\"===t.substr(t.length-3))}function y(t){if(t!==Object(t))throw new TypeError(\"Not an object: \"+t);var e=t[c];if(e&&e.key===t)return e;if(s(t)){e={key:t};try{return o(t,c,{value:e,writable:!1,enumerable:!1,configurable:!1}),e}catch(t){return}}}function x(t){return t.prototype=null,Object.freeze(t)}function b(){p||\"undefined\"==typeof console||(p=!0,console.warn(\"WeakMap should be invoked as new WeakMap(), not WeakMap(). This will be an error in the future.\"))}}()},{}],553:[function(t,e,r){var n=t(\"./hidden-store.js\");e.exports=function(){var t={};return function(e){if((\"object\"!=typeof e||null===e)&&\"function\"!=typeof e)throw new Error(\"Weakmap-shim: Key must be object\");var r=e.valueOf(t);return r&&r.identity===t?r:n(e,t)}}},{\"./hidden-store.js\":554}],554:[function(t,e,r){e.exports=function(t,e){var r={identity:e},n=t.valueOf;return Object.defineProperty(t,\"valueOf\",{value:function(t){return t!==e?n.apply(this,arguments):r},writable:!0}),r}},{}],555:[function(t,e,r){var n=t(\"./create-store.js\");e.exports=function(){var t=n();return{get:function(e,r){var n=t(e);return n.hasOwnProperty(\"value\")?n.value:r},set:function(e,r){return t(e).value=r,this},has:function(e){return\"value\"in t(e)},delete:function(e){return delete t(e).value}}}},{\"./create-store.js\":553}],556:[function(t,e,r){var n=t(\"get-canvas-context\");e.exports=function(t){return n(\"webgl\",t)}},{\"get-canvas-context\":232}],557:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Chinese\",jdEpoch:1721425.5,hasYearZero:!1,minMonth:0,firstMonth:0,minDay:1,regionalOptions:{\"\":{name:\"Chinese\",epochs:[\"BEC\",\"EC\"],monthNumbers:function(t,e){if(\"string\"==typeof t){var r=t.match(l);return r?r[0]:\"\"}var n=this._validateYear(t),i=t.month(),a=\"\"+this.toChineseMonth(n,i);return e&&a.length<2&&(a=\"0\"+a),this.isIntercalaryMonth(n,i)&&(a+=\"i\"),a},monthNames:function(t){if(\"string\"==typeof t){var e=t.match(c);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\\u6708\",\"\\u4e8c\\u6708\",\"\\u4e09\\u6708\",\"\\u56db\\u6708\",\"\\u4e94\\u6708\",\"\\u516d\\u6708\",\"\\u4e03\\u6708\",\"\\u516b\\u6708\",\"\\u4e5d\\u6708\",\"\\u5341\\u6708\",\"\\u5341\\u4e00\\u6708\",\"\\u5341\\u4e8c\\u6708\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},monthNamesShort:function(t){if(\"string\"==typeof t){var e=t.match(u);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},parseMonth:function(t,e){t=this._validateYear(t);var r,n=parseInt(e);if(isNaN(n))\"\\u95f0\"===e[0]&&(r=!0,e=e.substring(1)),\"\\u6708\"===e[e.length-1]&&(e=e.substring(0,e.length-1)),n=1+[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"].indexOf(e);else{var i=e[e.length-1];r=\"i\"===i||\"I\"===i}return this.toMonthIndex(t,n,r)},dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},_validateYear:function(t,e){if(t.year&&(t=t.year()),\"number\"!=typeof t||t<1888||t>2111)throw e.replace(/\\{0\\}/,this.local.name);return t},toMonthIndex:function(t,e,r){var i=this.intercalaryMonth(t);if(r&&e!==i||e<1||e>12)throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return i?!r&&e<=i?e-1:e:e-1},toChineseMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);if(e<0||e>(r?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r?e<r?e+1:e:e+1},intercalaryMonth:function(t){return t=this._validateYear(t),h[t-h[0]]>>13},isIntercalaryMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);return!!r&&r===e},leapYear:function(t){return 0!==this.intercalaryMonth(t)},weekOfYear:function(t,e,r){var i,o=this._validateYear(t,n.local.invalidyear),s=f[o-f[0]],l=s>>9&4095,c=s>>5&15,u=31&s;(i=a.newDate(l,c,u)).add(4-(i.dayOfWeek()||7),\"d\");var h=this.toJD(t,e,r)-i.toJD();return 1+Math.floor(h/7)},monthsInYear:function(t){return this.leapYear(t)?13:12},daysInMonth:function(t,e){t.year&&(e=t.month(),t=t.year()),t=this._validateYear(t);var r=h[t-h[0]];if(e>(r>>13?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r&1<<12-e?30:29},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,s,r,n.local.invalidDate);t=this._validateYear(i.year()),e=i.month(),r=i.day();var o=this.isIntercalaryMonth(t,e),s=this.toChineseMonth(t,e),l=function(t,e,r,n,i){var a,o,s;if(\"object\"==typeof t)o=t,a=e||{};else{var l=\"number\"==typeof t&&t>=1888&&t<=2111;if(!l)throw new Error(\"Lunar year outside range 1888-2111\");var c=\"number\"==typeof e&&e>=1&&e<=12;if(!c)throw new Error(\"Lunar month outside range 1 - 12\");var u,p=\"number\"==typeof r&&r>=1&&r<=30;if(!p)throw new Error(\"Lunar day outside range 1 - 30\");\"object\"==typeof n?(u=!1,a=n):(u=!!n,a=i||{}),o={year:t,month:e,day:r,isIntercalary:u}}s=o.day-1;var d,g=h[o.year-h[0]],v=g>>13;d=v?o.month>v?o.month:o.isIntercalary?o.month:o.month-1:o.month-1;for(var m=0;m<d;m++){var y=g&1<<12-m?30:29;s+=y}var x=f[o.year-f[0]],b=new Date(x>>9&4095,(x>>5&15)-1,(31&x)+s);return a.year=b.getFullYear(),a.month=1+b.getMonth(),a.day=b.getDate(),a}(t,s,r,o);return a.toJD(l.year,l.month,l.day)},fromJD:function(t){var e=a.fromJD(t),r=function(t,e,r,n){var i,a;if(\"object\"==typeof t)i=t,a=e||{};else{var o=\"number\"==typeof t&&t>=1888&&t<=2111;if(!o)throw new Error(\"Solar year outside range 1888-2111\");var s=\"number\"==typeof e&&e>=1&&e<=12;if(!s)throw new Error(\"Solar month outside range 1 - 12\");var l=\"number\"==typeof r&&r>=1&&r<=31;if(!l)throw new Error(\"Solar day outside range 1 - 31\");i={year:t,month:e,day:r},a=n||{}}var c=f[i.year-f[0]],u=i.year<<9|i.month<<5|i.day;a.year=u>=c?i.year:i.year-1,c=f[a.year-f[0]];var p,d=new Date(c>>9&4095,(c>>5&15)-1,31&c),g=new Date(i.year,i.month-1,i.day);p=Math.round((g-d)/864e5);var v,m=h[a.year-h[0]];for(v=0;v<13;v++){var y=m&1<<12-v?30:29;if(p<y)break;p-=y}var x=m>>13;!x||v<x?(a.isIntercalary=!1,a.month=1+v):v===x?(a.isIntercalary=!0,a.month=v):(a.isIntercalary=!1,a.month=v);return a.day=1+p,a}(e.year(),e.month(),e.day()),n=this.toMonthIndex(r.year,r.month,r.isIntercalary);return this.newDate(r.year,n,r.day)},fromString:function(t){var e=t.match(s),r=this._validateYear(+e[1]),n=+e[2],i=!!e[3],a=this.toMonthIndex(r,n,i),o=+e[4];return this.newDate(r,a,o)},add:function(t,e,r){var n=t.year(),i=t.month(),a=this.isIntercalaryMonth(n,i),s=this.toChineseMonth(n,i),l=Object.getPrototypeOf(o.prototype).add.call(this,t,e,r);if(\"y\"===r){var c=l.year(),u=l.month(),h=this.isIntercalaryMonth(c,s),f=a&&h?this.toMonthIndex(c,s,!0):this.toMonthIndex(c,s,!1);f!==u&&l.month(f)}return l}});var s=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)[-\\/](\\d?\\d)([iI]?)[-\\/](\\d?\\d)/m,l=/^\\d?\\d[iI]?/m,c=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?\\u6708/m,u=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?/m;n.calendars.chinese=o;var h=[1887,5780,5802,19157,2742,50359,1198,2646,46378,7466,3412,30122,5482,67949,2396,5294,43597,6732,6954,36181,2772,4954,18781,2396,54427,5274,6730,47781,5800,6868,21210,4790,59703,2350,5270,46667,3402,3496,38325,1388,4782,18735,2350,52374,6804,7498,44457,2906,1388,29294,4700,63789,6442,6804,56138,5802,2772,38235,1210,4698,22827,5418,63125,3476,5802,43701,2484,5302,27223,2646,70954,7466,3412,54698,5482,2412,38062,5294,2636,32038,6954,60245,2772,4826,43357,2394,5274,39501,6730,72357,5800,5844,53978,4790,2358,38039,5270,87627,3402,3496,54708,5484,4782,43311,2350,3222,27978,7498,68965,2904,5484,45677,4700,6444,39573,6804,6986,19285,2772,62811,1210,4698,47403,5418,5780,38570,5546,76469,2420,5302,51799,2646,5414,36501,3412,5546,18869,2412,54446,5276,6732,48422,6822,2900,28010,4826,92509,2394,5274,55883,6730,6820,47956,5812,2778,18779,2358,62615,5270,5450,46757,3492,5556,27318,4718,67887,2350,3222,52554,7498,3428,38252,5468,4700,31022,6444,64149,6804,6986,43861,2772,5338,35421,2650,70955,5418,5780,54954,5546,2740,38074,5302,2646,29991,3366,61011,3412,5546,43445,2412,5294,35406,6732,72998,6820,6996,52586,2778,2396,38045,5274,6698,23333,6820,64338,5812,2746,43355,2358,5270,39499,5450,79525,3492,5548],f=[1887,966732,967231,967733,968265,968766,969297,969798,970298,970829,971330,971830,972362,972863,973395,973896,974397,974928,975428,975929,976461,976962,977462,977994,978494,979026,979526,980026,980558,981059,981559,982091,982593,983124,983624,984124,984656,985157,985656,986189,986690,987191,987722,988222,988753,989254,989754,990286,990788,991288,991819,992319,992851,993352,993851,994383,994885,995385,995917,996418,996918,997450,997949,998481,998982,999483,1000014,1000515,1001016,1001548,1002047,1002578,1003080,1003580,1004111,1004613,1005113,1005645,1006146,1006645,1007177,1007678,1008209,1008710,1009211,1009743,1010243,1010743,1011275,1011775,1012306,1012807,1013308,1013840,1014341,1014841,1015373,1015874,1016404,1016905,1017405,1017937,1018438,1018939,1019471,1019972,1020471,1021002,1021503,1022035,1022535,1023036,1023568,1024069,1024568,1025100,1025601,1026102,1026633,1027133,1027666,1028167,1028666,1029198,1029699,1030199,1030730,1031231,1031763,1032264,1032764,1033296,1033797,1034297,1034828,1035329,1035830,1036362,1036861,1037393,1037894,1038394,1038925,1039427,1039927,1040459,1040959,1041491,1041992,1042492,1043023,1043524,1044024,1044556,1045057,1045558,1046090,1046590,1047121,1047622,1048122,1048654,1049154,1049655,1050187,1050689,1051219,1051720,1052220,1052751,1053252,1053752,1054284,1054786,1055285,1055817,1056317,1056849,1057349,1057850,1058382,1058883,1059383,1059915,1060415,1060947,1061447,1061947,1062479,1062981,1063480,1064012,1064514,1065014,1065545,1066045,1066577,1067078,1067578,1068110,1068611,1069112,1069642,1070142,1070674,1071175,1071675,1072207,1072709,1073209,1073740,1074241,1074741,1075273,1075773,1076305,1076807,1077308,1077839,1078340,1078840,1079372,1079871,1080403,1080904]},{\"../main\":571,\"object-assign\":454}],558:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Coptic\",jdEpoch:1825029.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Coptic\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Thout\",\"Paopi\",\"Hathor\",\"Koiak\",\"Tobi\",\"Meshir\",\"Paremhat\",\"Paremoude\",\"Pashons\",\"Paoni\",\"Epip\",\"Mesori\",\"Pi Kogi Enavot\"],monthNamesShort:[\"Tho\",\"Pao\",\"Hath\",\"Koi\",\"Tob\",\"Mesh\",\"Pat\",\"Pad\",\"Pash\",\"Pao\",\"Epi\",\"Meso\",\"PiK\"],dayNames:[\"Tkyriaka\",\"Pesnau\",\"Pshoment\",\"Peftoou\",\"Ptiou\",\"Psoou\",\"Psabbaton\"],dayNamesShort:[\"Tky\",\"Pes\",\"Psh\",\"Pef\",\"Pti\",\"Pso\",\"Psa\"],dayNamesMin:[\"Tk\",\"Pes\",\"Psh\",\"Pef\",\"Pt\",\"Pso\",\"Psa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.coptic=a},{\"../main\":571,\"object-assign\":454}],559:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Discworld\",jdEpoch:1721425.5,daysPerMonth:[16,32,32,32,32,32,32,32,32,32,32,32,32],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Discworld\",epochs:[\"BUC\",\"UC\"],monthNames:[\"Ick\",\"Offle\",\"February\",\"March\",\"April\",\"May\",\"June\",\"Grune\",\"August\",\"Spune\",\"Sektober\",\"Ember\",\"December\"],monthNamesShort:[\"Ick\",\"Off\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Gru\",\"Aug\",\"Spu\",\"Sek\",\"Emb\",\"Dec\"],dayNames:[\"Sunday\",\"Octeday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Oct\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Oc\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:2,isRTL:!1}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),13},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),400},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/8)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]},daysInWeek:function(){return 8},dayOfWeek:function(t,e,r){return(this._validate(t,e,r,n.local.invalidDate).day()+1)%8},weekDay:function(t,e,r){var n=this.dayOfWeek(t,e,r);return n>=2&&n<=6},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{century:o[Math.floor((i.year()-1)/100)+1]||\"\"}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year()+(i.year()<0?1:0),e=i.month(),(r=i.day())+(e>1?16:0)+(e>2?32*(e-2):0)+400*(t-1)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t+.5)-Math.floor(this.jdEpoch)-1;var e=Math.floor(t/400)+1;t-=400*(e-1),t+=t>15?16:0;var r=Math.floor(t/32)+1,n=t-32*(r-1)+1;return this.newDate(e<=0?e-1:e,r,n)}});var o={20:\"Fruitbat\",21:\"Anchovy\"};n.calendars.discworld=a},{\"../main\":571,\"object-assign\":454}],560:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Ethiopian\",jdEpoch:1724220.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Ethiopian\",epochs:[\"BEE\",\"EE\"],monthNames:[\"Meskerem\",\"Tikemet\",\"Hidar\",\"Tahesas\",\"Tir\",\"Yekatit\",\"Megabit\",\"Miazia\",\"Genbot\",\"Sene\",\"Hamle\",\"Nehase\",\"Pagume\"],monthNamesShort:[\"Mes\",\"Tik\",\"Hid\",\"Tah\",\"Tir\",\"Yek\",\"Meg\",\"Mia\",\"Gen\",\"Sen\",\"Ham\",\"Neh\",\"Pag\"],dayNames:[\"Ehud\",\"Segno\",\"Maksegno\",\"Irob\",\"Hamus\",\"Arb\",\"Kidame\"],dayNamesShort:[\"Ehu\",\"Seg\",\"Mak\",\"Iro\",\"Ham\",\"Arb\",\"Kid\"],dayNamesMin:[\"Eh\",\"Se\",\"Ma\",\"Ir\",\"Ha\",\"Ar\",\"Ki\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.ethiopian=a},{\"../main\":571,\"object-assign\":454}],561:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Hebrew\",jdEpoch:347995.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29,29],hasYearZero:!1,minMonth:1,firstMonth:7,minDay:1,regionalOptions:{\"\":{name:\"Hebrew\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Nisan\",\"Iyar\",\"Sivan\",\"Tammuz\",\"Av\",\"Elul\",\"Tishrei\",\"Cheshvan\",\"Kislev\",\"Tevet\",\"Shevat\",\"Adar\",\"Adar II\"],monthNamesShort:[\"Nis\",\"Iya\",\"Siv\",\"Tam\",\"Av\",\"Elu\",\"Tis\",\"Che\",\"Kis\",\"Tev\",\"She\",\"Ada\",\"Ad2\"],dayNames:[\"Yom Rishon\",\"Yom Sheni\",\"Yom Shlishi\",\"Yom Revi'i\",\"Yom Chamishi\",\"Yom Shishi\",\"Yom Shabbat\"],dayNamesShort:[\"Ris\",\"She\",\"Shl\",\"Rev\",\"Cha\",\"Shi\",\"Sha\"],dayNamesMin:[\"Ri\",\"She\",\"Shl\",\"Re\",\"Ch\",\"Shi\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return this._leapYear(e.year())},_leapYear:function(t){return o(7*(t=t<0?t+1:t)+1,19)<7},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),this._leapYear(t.year?t.year():t)?13:12},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),this.toJD(-1===t?1:t+1,7,1)-this.toJD(t,7,1)},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),12===e&&this.leapYear(t)?30:8===e&&5===o(this.daysInYear(t),10)?30:9===e&&3===o(this.daysInYear(t),10)?29:this.daysPerMonth[e-1]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{yearType:(this.leapYear(i)?\"embolismic\":\"common\")+\" \"+[\"deficient\",\"regular\",\"complete\"][this.daysInYear(i)%10-3]}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t<=0?t+1:t,o=this.jdEpoch+this._delay1(a)+this._delay2(a)+r+1;if(e<7){for(var s=7;s<=this.monthsInYear(t);s++)o+=this.daysInMonth(t,s);for(s=1;s<e;s++)o+=this.daysInMonth(t,s)}else for(s=7;s<e;s++)o+=this.daysInMonth(t,s);return o},_delay1:function(t){var e=Math.floor((235*t-234)/19),r=12084+13753*e,n=29*e+Math.floor(r/25920);return o(3*(n+1),7)<3&&n++,n},_delay2:function(t){var e=this._delay1(t-1),r=this._delay1(t);return this._delay1(t+1)-r==356?2:r-e==382?1:0},fromJD:function(t){t=Math.floor(t)+.5;for(var e=Math.floor(98496*(t-this.jdEpoch)/35975351)-1;t>=this.toJD(-1===e?1:e+1,7,1);)e++;for(var r=t<this.toJD(e,1,1)?7:1;t>this.toJD(e,r,this.daysInMonth(e,r));)r++;var n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.hebrew=a},{\"../main\":571,\"object-assign\":454}],562:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Islamic\",jdEpoch:1948439.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Islamic\",epochs:[\"BH\",\"AH\"],monthNames:[\"Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' al-thani\",\"Jumada al-awwal\",\"Jumada al-thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-ahad\",\"Yawm al-ithnayn\",\"Yawm ath-thulaathaa'\",\"Yawm al-arbi'aa'\",\"Yawm al-kham\\u012bs\",\"Yawm al-jum'a\",\"Yawm as-sabt\"],dayNamesShort:[\"Aha\",\"Ith\",\"Thu\",\"Arb\",\"Kha\",\"Jum\",\"Sab\"],dayNamesMin:[\"Ah\",\"It\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){return(11*this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year()+14)%30<11},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return this.leapYear(t)?355:354},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),t=t<=0?t+1:t,(r=i.day())+Math.ceil(29.5*(e-1))+354*(t-1)+Math.floor((3+11*t)/30)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t)+.5;var e=Math.floor((30*(t-this.jdEpoch)+10646)/10631);e=e<=0?e-1:e;var r=Math.min(12,Math.ceil((t-29-this.toJD(e,1,1))/29.5)+1),n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.islamic=a},{\"../main\":571,\"object-assign\":454}],563:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Julian\",jdEpoch:1721423.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Julian\",epochs:[\"BC\",\"AD\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()<0?e.year()+1:e.year())%4==0},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),r=i.day(),t<0&&t++,e<=2&&(t--,e+=12),Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r-1524.5},fromJD:function(t){var e=Math.floor(t+.5)+1524,r=Math.floor((e-122.1)/365.25),n=Math.floor(365.25*r),i=Math.floor((e-n)/30.6001),a=i-Math.floor(i<14?1:13),o=r-Math.floor(a>2?4716:4715),s=e-n-Math.floor(30.6001*i);return o<=0&&o--,this.newDate(o,a,s)}}),n.calendars.julian=a},{\"../main\":571,\"object-assign\":454}],564:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}function s(t,e){return o(t-1,e)+1}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Mayan\",jdEpoch:584282.5,hasYearZero:!0,minMonth:0,firstMonth:0,minDay:0,regionalOptions:{\"\":{name:\"Mayan\",epochs:[\"\",\"\"],monthNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],monthNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],dayNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesMin:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],digits:null,dateFormat:\"YYYY.m.d\",firstDay:0,isRTL:!1,haabMonths:[\"Pop\",\"Uo\",\"Zip\",\"Zotz\",\"Tzec\",\"Xul\",\"Yaxkin\",\"Mol\",\"Chen\",\"Yax\",\"Zac\",\"Ceh\",\"Mac\",\"Kankin\",\"Muan\",\"Pax\",\"Kayab\",\"Cumku\",\"Uayeb\"],tzolkinMonths:[\"Imix\",\"Ik\",\"Akbal\",\"Kan\",\"Chicchan\",\"Cimi\",\"Manik\",\"Lamat\",\"Muluc\",\"Oc\",\"Chuen\",\"Eb\",\"Ben\",\"Ix\",\"Men\",\"Cib\",\"Caban\",\"Etznab\",\"Cauac\",\"Ahau\"]}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},formatYear:function(t){t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year();var e=Math.floor(t/400);return t%=400,t+=t<0?400:0,e+\".\"+Math.floor(t/20)+\".\"+t%20},forYear:function(t){if((t=t.split(\".\")).length<3)throw\"Invalid Mayan year\";for(var e=0,r=0;r<t.length;r++){var n=parseInt(t[r],10);if(Math.abs(n)>19||r>0&&n<0)throw\"Invalid Mayan year\";e=20*e+n}return e},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),18},weekOfYear:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),0},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),360},daysInMonth:function(t,e){return this._validate(t,e,this.minDay,n.local.invalidMonth),20},daysInWeek:function(){return 5},dayOfWeek:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate).day()},weekDay:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),!0},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate).toJD(),a=this._toHaab(i),o=this._toTzolkin(i);return{haabMonthName:this.local.haabMonths[a[0]-1],haabMonth:a[0],haabDay:a[1],tzolkinDayName:this.local.tzolkinMonths[o[0]-1],tzolkinDay:o[0],tzolkinTrecena:o[1]}},_toHaab:function(t){var e=o((t-=this.jdEpoch)+8+340,365);return[Math.floor(e/20)+1,o(e,20)]},_toTzolkin:function(t){return[s((t-=this.jdEpoch)+20,20),s(t+4,13)]},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return i.day()+20*i.month()+360*i.year()+this.jdEpoch},fromJD:function(t){t=Math.floor(t)+.5-this.jdEpoch;var e=Math.floor(t/360);t%=360,t+=t<0?360:0;var r=Math.floor(t/20),n=t%20;return this.newDate(e,r,n)}}),n.calendars.mayan=a},{\"../main\":571,\"object-assign\":454}],565:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar;var o=n.instance(\"gregorian\");i(a.prototype,{name:\"Nanakshahi\",jdEpoch:2257673.5,daysPerMonth:[31,31,31,31,31,30,30,30,30,30,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Nanakshahi\",epochs:[\"BN\",\"AN\"],monthNames:[\"Chet\",\"Vaisakh\",\"Jeth\",\"Harh\",\"Sawan\",\"Bhadon\",\"Assu\",\"Katak\",\"Maghar\",\"Poh\",\"Magh\",\"Phagun\"],monthNamesShort:[\"Che\",\"Vai\",\"Jet\",\"Har\",\"Saw\",\"Bha\",\"Ass\",\"Kat\",\"Mgr\",\"Poh\",\"Mgh\",\"Pha\"],dayNames:[\"Somvaar\",\"Mangalvar\",\"Budhvaar\",\"Veervaar\",\"Shukarvaar\",\"Sanicharvaar\",\"Etvaar\"],dayNamesShort:[\"Som\",\"Mangal\",\"Budh\",\"Veer\",\"Shukar\",\"Sanichar\",\"Et\"],dayNamesMin:[\"So\",\"Ma\",\"Bu\",\"Ve\",\"Sh\",\"Sa\",\"Et\"],digits:null,dateFormat:\"dd-mm-yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear);return o.leapYear(e.year()+(e.year()<1?1:0)+1469)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(1-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidMonth);(t=i.year())<0&&t++;for(var a=i.day(),s=1;s<i.month();s++)a+=this.daysPerMonth[s-1];return a+o.toJD(t+1468,3,13)},fromJD:function(t){t=Math.floor(t+.5);for(var e=Math.floor((t-(this.jdEpoch-1))/366);t>=this.toJD(e+1,1,1);)e++;for(var r=t-Math.floor(this.toJD(e,1,1)+.5)+1,n=1;r>this.daysInMonth(e,n);)r-=this.daysInMonth(e,n),n++;return this.newDate(e,n,r)}}),n.calendars.nanakshahi=a},{\"../main\":571,\"object-assign\":454}],566:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Nepali\",jdEpoch:1700709.5,daysPerMonth:[31,31,32,32,31,30,30,29,30,29,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,daysPerYear:365,regionalOptions:{\"\":{name:\"Nepali\",epochs:[\"BBS\",\"ABS\"],monthNames:[\"Baisakh\",\"Jestha\",\"Ashadh\",\"Shrawan\",\"Bhadra\",\"Ashwin\",\"Kartik\",\"Mangsir\",\"Paush\",\"Mangh\",\"Falgun\",\"Chaitra\"],monthNamesShort:[\"Bai\",\"Je\",\"As\",\"Shra\",\"Bha\",\"Ash\",\"Kar\",\"Mang\",\"Pau\",\"Ma\",\"Fal\",\"Chai\"],dayNames:[\"Aaitabaar\",\"Sombaar\",\"Manglbaar\",\"Budhabaar\",\"Bihibaar\",\"Shukrabaar\",\"Shanibaar\"],dayNamesShort:[\"Aaita\",\"Som\",\"Mangl\",\"Budha\",\"Bihi\",\"Shukra\",\"Shani\"],dayNamesMin:[\"Aai\",\"So\",\"Man\",\"Bu\",\"Bi\",\"Shu\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:1,isRTL:!1}},leapYear:function(t){return this.daysInYear(t)!==this.daysPerYear},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){if(t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t])return this.daysPerYear;for(var e=0,r=this.minMonth;r<=12;r++)e+=this.NEPALI_CALENDAR_DATA[t][r];return e},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t]?this.daysPerMonth[e-1]:this.NEPALI_CALENDAR_DATA[t][e]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=n.instance(),o=0,s=e,l=t;this._createMissingCalendarData(t);var c=t-(s>9||9===s&&r>=this.NEPALI_CALENDAR_DATA[l][0]?56:57);for(9!==e&&(o=r,s--);9!==s;)s<=0&&(s=12,l--),o+=this.NEPALI_CALENDAR_DATA[l][s],s--;return 9===e?(o+=r-this.NEPALI_CALENDAR_DATA[l][0])<0&&(o+=a.daysInYear(c)):o+=this.NEPALI_CALENDAR_DATA[l][9]-this.NEPALI_CALENDAR_DATA[l][0],a.newDate(c,1,1).add(o,\"d\").toJD()},fromJD:function(t){var e=n.instance().fromJD(t),r=e.year(),i=e.dayOfYear(),a=r+56;this._createMissingCalendarData(a);for(var o=9,s=this.NEPALI_CALENDAR_DATA[a][0],l=this.NEPALI_CALENDAR_DATA[a][o]-s+1;i>l;)++o>12&&(o=1,a++),l+=this.NEPALI_CALENDAR_DATA[a][o];var c=this.NEPALI_CALENDAR_DATA[a][o]-(l-i);return this.newDate(a,o,c)},_createMissingCalendarData:function(t){var e=this.daysPerMonth.slice(0);e.unshift(17);for(var r=t-1;r<t+2;r++)\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[r]&&(this.NEPALI_CALENDAR_DATA[r]=e)},NEPALI_CALENDAR_DATA:{1970:[18,31,31,32,31,31,31,30,29,30,29,30,30],1971:[18,31,31,32,31,32,30,30,29,30,29,30,30],1972:[17,31,32,31,32,31,30,30,30,29,29,30,30],1973:[19,30,32,31,32,31,30,30,30,29,30,29,31],1974:[19,31,31,32,30,31,31,30,29,30,29,30,30],1975:[18,31,31,32,32,30,31,30,29,30,29,30,30],1976:[17,31,32,31,32,31,30,30,30,29,29,30,31],1977:[18,31,32,31,32,31,31,29,30,29,30,29,31],1978:[18,31,31,32,31,31,31,30,29,30,29,30,30],1979:[18,31,31,32,32,31,30,30,29,30,29,30,30],1980:[17,31,32,31,32,31,30,30,30,29,29,30,31],1981:[18,31,31,31,32,31,31,29,30,30,29,30,30],1982:[18,31,31,32,31,31,31,30,29,30,29,30,30],1983:[18,31,31,32,32,31,30,30,29,30,29,30,30],1984:[17,31,32,31,32,31,30,30,30,29,29,30,31],1985:[18,31,31,31,32,31,31,29,30,30,29,30,30],1986:[18,31,31,32,31,31,31,30,29,30,29,30,30],1987:[18,31,32,31,32,31,30,30,29,30,29,30,30],1988:[17,31,32,31,32,31,30,30,30,29,29,30,31],1989:[18,31,31,31,32,31,31,30,29,30,29,30,30],1990:[18,31,31,32,31,31,31,30,29,30,29,30,30],1991:[18,31,32,31,32,31,30,30,29,30,29,30,30],1992:[17,31,32,31,32,31,30,30,30,29,30,29,31],1993:[18,31,31,31,32,31,31,30,29,30,29,30,30],1994:[18,31,31,32,31,31,31,30,29,30,29,30,30],1995:[17,31,32,31,32,31,30,30,30,29,29,30,30],1996:[17,31,32,31,32,31,30,30,30,29,30,29,31],1997:[18,31,31,32,31,31,31,30,29,30,29,30,30],1998:[18,31,31,32,31,31,31,30,29,30,29,30,30],1999:[17,31,32,31,32,31,30,30,30,29,29,30,31],2000:[17,30,32,31,32,31,30,30,30,29,30,29,31],2001:[18,31,31,32,31,31,31,30,29,30,29,30,30],2002:[18,31,31,32,32,31,30,30,29,30,29,30,30],2003:[17,31,32,31,32,31,30,30,30,29,29,30,31],2004:[17,30,32,31,32,31,30,30,30,29,30,29,31],2005:[18,31,31,32,31,31,31,30,29,30,29,30,30],2006:[18,31,31,32,32,31,30,30,29,30,29,30,30],2007:[17,31,32,31,32,31,30,30,30,29,29,30,31],2008:[17,31,31,31,32,31,31,29,30,30,29,29,31],2009:[18,31,31,32,31,31,31,30,29,30,29,30,30],2010:[18,31,31,32,32,31,30,30,29,30,29,30,30],2011:[17,31,32,31,32,31,30,30,30,29,29,30,31],2012:[17,31,31,31,32,31,31,29,30,30,29,30,30],2013:[18,31,31,32,31,31,31,30,29,30,29,30,30],2014:[18,31,31,32,32,31,30,30,29,30,29,30,30],2015:[17,31,32,31,32,31,30,30,30,29,29,30,31],2016:[17,31,31,31,32,31,31,29,30,30,29,30,30],2017:[18,31,31,32,31,31,31,30,29,30,29,30,30],2018:[18,31,32,31,32,31,30,30,29,30,29,30,30],2019:[17,31,32,31,32,31,30,30,30,29,30,29,31],2020:[17,31,31,31,32,31,31,30,29,30,29,30,30],2021:[18,31,31,32,31,31,31,30,29,30,29,30,30],2022:[17,31,32,31,32,31,30,30,30,29,29,30,30],2023:[17,31,32,31,32,31,30,30,30,29,30,29,31],2024:[17,31,31,31,32,31,31,30,29,30,29,30,30],2025:[18,31,31,32,31,31,31,30,29,30,29,30,30],2026:[17,31,32,31,32,31,30,30,30,29,29,30,31],2027:[17,30,32,31,32,31,30,30,30,29,30,29,31],2028:[17,31,31,32,31,31,31,30,29,30,29,30,30],2029:[18,31,31,32,31,32,30,30,29,30,29,30,30],2030:[17,31,32,31,32,31,30,30,30,30,30,30,31],2031:[17,31,32,31,32,31,31,31,31,31,31,31,31],2032:[17,32,32,32,32,32,32,32,32,32,32,32,32],2033:[18,31,31,32,32,31,30,30,29,30,29,30,30],2034:[17,31,32,31,32,31,30,30,30,29,29,30,31],2035:[17,30,32,31,32,31,31,29,30,30,29,29,31],2036:[17,31,31,32,31,31,31,30,29,30,29,30,30],2037:[18,31,31,32,32,31,30,30,29,30,29,30,30],2038:[17,31,32,31,32,31,30,30,30,29,29,30,31],2039:[17,31,31,31,32,31,31,29,30,30,29,30,30],2040:[17,31,31,32,31,31,31,30,29,30,29,30,30],2041:[18,31,31,32,32,31,30,30,29,30,29,30,30],2042:[17,31,32,31,32,31,30,30,30,29,29,30,31],2043:[17,31,31,31,32,31,31,29,30,30,29,30,30],2044:[17,31,31,32,31,31,31,30,29,30,29,30,30],2045:[18,31,32,31,32,31,30,30,29,30,29,30,30],2046:[17,31,32,31,32,31,30,30,30,29,29,30,31],2047:[17,31,31,31,32,31,31,30,29,30,29,30,30],2048:[17,31,31,32,31,31,31,30,29,30,29,30,30],2049:[17,31,32,31,32,31,30,30,30,29,29,30,30],2050:[17,31,32,31,32,31,30,30,30,29,30,29,31],2051:[17,31,31,31,32,31,31,30,29,30,29,30,30],2052:[17,31,31,32,31,31,31,30,29,30,29,30,30],2053:[17,31,32,31,32,31,30,30,30,29,29,30,30],2054:[17,31,32,31,32,31,30,30,30,29,30,29,31],2055:[17,31,31,32,31,31,31,30,29,30,30,29,30],2056:[17,31,31,32,31,32,30,30,29,30,29,30,30],2057:[17,31,32,31,32,31,30,30,30,29,29,30,31],2058:[17,30,32,31,32,31,30,30,30,29,30,29,31],2059:[17,31,31,32,31,31,31,30,29,30,29,30,30],2060:[17,31,31,32,32,31,30,30,29,30,29,30,30],2061:[17,31,32,31,32,31,30,30,30,29,29,30,31],2062:[17,30,32,31,32,31,31,29,30,29,30,29,31],2063:[17,31,31,32,31,31,31,30,29,30,29,30,30],2064:[17,31,31,32,32,31,30,30,29,30,29,30,30],2065:[17,31,32,31,32,31,30,30,30,29,29,30,31],2066:[17,31,31,31,32,31,31,29,30,30,29,29,31],2067:[17,31,31,32,31,31,31,30,29,30,29,30,30],2068:[17,31,31,32,32,31,30,30,29,30,29,30,30],2069:[17,31,32,31,32,31,30,30,30,29,29,30,31],2070:[17,31,31,31,32,31,31,29,30,30,29,30,30],2071:[17,31,31,32,31,31,31,30,29,30,29,30,30],2072:[17,31,32,31,32,31,30,30,29,30,29,30,30],2073:[17,31,32,31,32,31,30,30,30,29,29,30,31],2074:[17,31,31,31,32,31,31,30,29,30,29,30,30],2075:[17,31,31,32,31,31,31,30,29,30,29,30,30],2076:[16,31,32,31,32,31,30,30,30,29,29,30,30],2077:[17,31,32,31,32,31,30,30,30,29,30,29,31],2078:[17,31,31,31,32,31,31,30,29,30,29,30,30],2079:[17,31,31,32,31,31,31,30,29,30,29,30,30],2080:[16,31,32,31,32,31,30,30,30,29,29,30,30],2081:[17,31,31,32,32,31,30,30,30,29,30,30,30],2082:[17,31,32,31,32,31,30,30,30,29,30,30,30],2083:[17,31,31,32,31,31,30,30,30,29,30,30,30],2084:[17,31,31,32,31,31,30,30,30,29,30,30,30],2085:[17,31,32,31,32,31,31,30,30,29,30,30,30],2086:[17,31,32,31,32,31,30,30,30,29,30,30,30],2087:[16,31,31,32,31,31,31,30,30,29,30,30,30],2088:[16,30,31,32,32,30,31,30,30,29,30,30,30],2089:[17,31,32,31,32,31,30,30,30,29,30,30,30],2090:[17,31,32,31,32,31,30,30,30,29,30,30,30],2091:[16,31,31,32,31,31,31,30,30,29,30,30,30],2092:[16,31,31,32,32,31,30,30,30,29,30,30,30],2093:[17,31,32,31,32,31,30,30,30,29,30,30,30],2094:[17,31,31,32,31,31,30,30,30,29,30,30,30],2095:[17,31,31,32,31,31,31,30,29,30,30,30,30],2096:[17,30,31,32,32,31,30,30,29,30,29,30,30],2097:[17,31,32,31,32,31,30,30,30,29,30,30,30],2098:[17,31,31,32,31,31,31,29,30,29,30,30,31],2099:[17,31,31,32,31,31,31,30,29,29,30,30,30],2100:[17,31,32,31,32,30,31,30,29,30,29,30,30]}}),n.calendars.nepali=a},{\"../main\":571,\"object-assign\":454}],567:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Persian\",jdEpoch:1948320.5,daysPerMonth:[31,31,31,31,31,31,30,30,30,30,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Persian\",epochs:[\"BP\",\"AP\"],monthNames:[\"Farvardin\",\"Ordibehesht\",\"Khordad\",\"Tir\",\"Mordad\",\"Shahrivar\",\"Mehr\",\"Aban\",\"Azar\",\"Day\",\"Bahman\",\"Esfand\"],monthNamesShort:[\"Far\",\"Ord\",\"Kho\",\"Tir\",\"Mor\",\"Sha\",\"Meh\",\"Aba\",\"Aza\",\"Day\",\"Bah\",\"Esf\"],dayNames:[\"Yekshambe\",\"Doshambe\",\"Seshambe\",\"Ch\\xe6harshambe\",\"Panjshambe\",\"Jom'e\",\"Shambe\"],dayNamesShort:[\"Yek\",\"Do\",\"Se\",\"Ch\\xe6\",\"Panj\",\"Jom\",\"Sha\"],dayNamesMin:[\"Ye\",\"Do\",\"Se\",\"Ch\",\"Pa\",\"Jo\",\"Sh\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 682*((e.year()-(e.year()>0?474:473))%2820+474+38)%2816<682},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-(n.dayOfWeek()+1)%7,\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t-(t>=0?474:473),s=474+o(a,2820);return r+(e<=7?31*(e-1):30*(e-1)+6)+Math.floor((682*s-110)/2816)+365*(s-1)+1029983*Math.floor(a/2820)+this.jdEpoch-1},fromJD:function(t){var e=(t=Math.floor(t)+.5)-this.toJD(475,1,1),r=Math.floor(e/1029983),n=o(e,1029983),i=2820;if(1029982!==n){var a=Math.floor(n/366),s=o(n,366);i=Math.floor((2134*a+2816*s+2815)/1028522)+a+1}var l=i+2820*r+474;l=l<=0?l-1:l;var c=t-this.toJD(l,1,1)+1,u=c<=186?Math.ceil(c/31):Math.ceil((c-6)/30),h=t-this.toJD(l,u,1)+1;return this.newDate(l,u,h)}}),n.calendars.persian=a,n.calendars.jalali=a},{\"../main\":571,\"object-assign\":454}],568:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Taiwan\",jdEpoch:2419402.5,yearsOffset:1911,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Taiwan\",epochs:[\"BROC\",\"ROC\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)},_g2tYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)}}),n.calendars.taiwan=o},{\"../main\":571,\"object-assign\":454}],569:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Thai\",jdEpoch:1523098.5,yearsOffset:543,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Thai\",epochs:[\"BBE\",\"BE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)},_g2tYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)}}),n.calendars.thai=o},{\"../main\":571,\"object-assign\":454}],570:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"UmmAlQura\",hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Umm al-Qura\",epochs:[\"BH\",\"AH\"],monthNames:[\"Al-Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' Al-Thani\",\"Jumada Al-Awwal\",\"Jumada Al-Thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-Ahad\",\"Yawm al-Ithnain\",\"Yawm al-Thal\\u0101th\\u0101\\u2019\",\"Yawm al-Arba\\u2018\\u0101\\u2019\",\"Yawm al-Kham\\u012bs\",\"Yawm al-Jum\\u2018a\",\"Yawm al-Sabt\"],dayNamesMin:[\"Ah\",\"Ith\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!0}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 355===this.daysInYear(e.year())},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){for(var e=0,r=1;r<=12;r++)e+=this.daysInMonth(t,r);return e},daysInMonth:function(t,e){for(var r=this._validate(t,e,this.minDay,n.local.invalidMonth).toJD()-24e5+.5,i=0,a=0;a<o.length;a++){if(o[a]>r)return o[i]-o[i-1];i++}return 30},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate),a=12*(i.year()-1)+i.month()-15292;return i.day()+o[a-1]-1+24e5-.5},fromJD:function(t){for(var e=t-24e5+.5,r=0,n=0;n<o.length&&!(o[n]>e);n++)r++;var i=r+15292,a=Math.floor((i-1)/12),s=a+1,l=i-12*a,c=e-o[r-1]+1;return this.newDate(s,l,c)},isValid:function(t,e,r){var i=n.baseCalendar.prototype.isValid.apply(this,arguments);return i&&(i=(t=null!=t.year?t.year:t)>=1276&&t<=1500),i},_validate:function(t,e,r,i){var a=n.baseCalendar.prototype._validate.apply(this,arguments);if(a.year<1276||a.year>1500)throw i.replace(/\\{0\\}/,this.local.name);return a}}),n.calendars.ummalqura=a;var o=[20,50,79,109,138,168,197,227,256,286,315,345,374,404,433,463,492,522,551,581,611,641,670,700,729,759,788,818,847,877,906,936,965,995,1024,1054,1083,1113,1142,1172,1201,1231,1260,1290,1320,1350,1379,1409,1438,1468,1497,1527,1556,1586,1615,1645,1674,1704,1733,1763,1792,1822,1851,1881,1910,1940,1969,1999,2028,2058,2087,2117,2146,2176,2205,2235,2264,2294,2323,2353,2383,2413,2442,2472,2501,2531,2560,2590,2619,2649,2678,2708,2737,2767,2796,2826,2855,2885,2914,2944,2973,3003,3032,3062,3091,3121,3150,3180,3209,3239,3268,3298,3327,3357,3386,3416,3446,3476,3505,3535,3564,3594,3623,3653,3682,3712,3741,3771,3800,3830,3859,3889,3918,3948,3977,4007,4036,4066,4095,4125,4155,4185,4214,4244,4273,4303,4332,4362,4391,4421,4450,4480,4509,4539,4568,4598,4627,4657,4686,4716,4745,4775,4804,4834,4863,4893,4922,4952,4981,5011,5040,5070,5099,5129,5158,5188,5218,5248,5277,5307,5336,5366,5395,5425,5454,5484,5513,5543,5572,5602,5631,5661,5690,5720,5749,5779,5808,5838,5867,5897,5926,5956,5985,6015,6044,6074,6103,6133,6162,6192,6221,6251,6281,6311,6340,6370,6399,6429,6458,6488,6517,6547,6576,6606,6635,6665,6694,6724,6753,6783,6812,6842,6871,6901,6930,6960,6989,7019,7048,7078,7107,7137,7166,7196,7225,7255,7284,7314,7344,7374,7403,7433,7462,7492,7521,7551,7580,7610,7639,7669,7698,7728,7757,7787,7816,7846,7875,7905,7934,7964,7993,8023,8053,8083,8112,8142,8171,8201,8230,8260,8289,8319,8348,8378,8407,8437,8466,8496,8525,8555,8584,8614,8643,8673,8702,8732,8761,8791,8821,8850,8880,8909,8938,8968,8997,9027,9056,9086,9115,9145,9175,9205,9234,9264,9293,9322,9352,9381,9410,9440,9470,9499,9529,9559,9589,9618,9648,9677,9706,9736,9765,9794,9824,9853,9883,9913,9943,9972,10002,10032,10061,10090,10120,10149,10178,10208,10237,10267,10297,10326,10356,10386,10415,10445,10474,10504,10533,10562,10592,10621,10651,10680,10710,10740,10770,10799,10829,10858,10888,10917,10947,10976,11005,11035,11064,11094,11124,11153,11183,11213,11242,11272,11301,11331,11360,11389,11419,11448,11478,11507,11537,11567,11596,11626,11655,11685,11715,11744,11774,11803,11832,11862,11891,11921,11950,11980,12010,12039,12069,12099,12128,12158,12187,12216,12246,12275,12304,12334,12364,12393,12423,12453,12483,12512,12542,12571,12600,12630,12659,12688,12718,12747,12777,12807,12837,12866,12896,12926,12955,12984,13014,13043,13072,13102,13131,13161,13191,13220,13250,13280,13310,13339,13368,13398,13427,13456,13486,13515,13545,13574,13604,13634,13664,13693,13723,13752,13782,13811,13840,13870,13899,13929,13958,13988,14018,14047,14077,14107,14136,14166,14195,14224,14254,14283,14313,14342,14372,14401,14431,14461,14490,14520,14550,14579,14609,14638,14667,14697,14726,14756,14785,14815,14844,14874,14904,14933,14963,14993,15021,15051,15081,15110,15140,15169,15199,15228,15258,15287,15317,15347,15377,15406,15436,15465,15494,15524,15553,15582,15612,15641,15671,15701,15731,15760,15790,15820,15849,15878,15908,15937,15966,15996,16025,16055,16085,16114,16144,16174,16204,16233,16262,16292,16321,16350,16380,16409,16439,16468,16498,16528,16558,16587,16617,16646,16676,16705,16734,16764,16793,16823,16852,16882,16912,16941,16971,17001,17030,17060,17089,17118,17148,17177,17207,17236,17266,17295,17325,17355,17384,17414,17444,17473,17502,17532,17561,17591,17620,17650,17679,17709,17738,17768,17798,17827,17857,17886,17916,17945,17975,18004,18034,18063,18093,18122,18152,18181,18211,18241,18270,18300,18330,18359,18388,18418,18447,18476,18506,18535,18565,18595,18625,18654,18684,18714,18743,18772,18802,18831,18860,18890,18919,18949,18979,19008,19038,19068,19098,19127,19156,19186,19215,19244,19274,19303,19333,19362,19392,19422,19452,19481,19511,19540,19570,19599,19628,19658,19687,19717,19746,19776,19806,19836,19865,19895,19924,19954,19983,20012,20042,20071,20101,20130,20160,20190,20219,20249,20279,20308,20338,20367,20396,20426,20455,20485,20514,20544,20573,20603,20633,20662,20692,20721,20751,20780,20810,20839,20869,20898,20928,20957,20987,21016,21046,21076,21105,21135,21164,21194,21223,21253,21282,21312,21341,21371,21400,21430,21459,21489,21519,21548,21578,21607,21637,21666,21696,21725,21754,21784,21813,21843,21873,21902,21932,21962,21991,22021,22050,22080,22109,22138,22168,22197,22227,22256,22286,22316,22346,22375,22405,22434,22464,22493,22522,22552,22581,22611,22640,22670,22700,22730,22759,22789,22818,22848,22877,22906,22936,22965,22994,23024,23054,23083,23113,23143,23173,23202,23232,23261,23290,23320,23349,23379,23408,23438,23467,23497,23527,23556,23586,23616,23645,23674,23704,23733,23763,23792,23822,23851,23881,23910,23940,23970,23999,24029,24058,24088,24117,24147,24176,24206,24235,24265,24294,24324,24353,24383,24413,24442,24472,24501,24531,24560,24590,24619,24648,24678,24707,24737,24767,24796,24826,24856,24885,24915,24944,24974,25003,25032,25062,25091,25121,25150,25180,25210,25240,25269,25299,25328,25358,25387,25416,25446,25475,25505,25534,25564,25594,25624,25653,25683,25712,25742,25771,25800,25830,25859,25888,25918,25948,25977,26007,26037,26067,26096,26126,26155,26184,26214,26243,26272,26302,26332,26361,26391,26421,26451,26480,26510,26539,26568,26598,26627,26656,26686,26715,26745,26775,26805,26834,26864,26893,26923,26952,26982,27011,27041,27070,27099,27129,27159,27188,27218,27248,27277,27307,27336,27366,27395,27425,27454,27484,27513,27542,27572,27602,27631,27661,27691,27720,27750,27779,27809,27838,27868,27897,27926,27956,27985,28015,28045,28074,28104,28134,28163,28193,28222,28252,28281,28310,28340,28369,28399,28428,28458,28488,28517,28547,28577,28607,28636,28665,28695,28724,28754,28783,28813,28843,28872,28901,28931,28960,28990,29019,29049,29078,29108,29137,29167,29196,29226,29255,29285,29315,29345,29375,29404,29434,29463,29492,29522,29551,29580,29610,29640,29669,29699,29729,29759,29788,29818,29847,29876,29906,29935,29964,29994,30023,30053,30082,30112,30141,30171,30200,30230,30259,30289,30318,30348,30378,30408,30437,30467,30496,30526,30555,30585,30614,30644,30673,30703,30732,30762,30791,30821,30850,30880,30909,30939,30968,30998,31027,31057,31086,31116,31145,31175,31204,31234,31263,31293,31322,31352,31381,31411,31441,31471,31500,31530,31559,31589,31618,31648,31676,31706,31736,31766,31795,31825,31854,31884,31913,31943,31972,32002,32031,32061,32090,32120,32150,32180,32209,32239,32268,32298,32327,32357,32386,32416,32445,32475,32504,32534,32563,32593,32622,32652,32681,32711,32740,32770,32799,32829,32858,32888,32917,32947,32976,33006,33035,33065,33094,33124,33153,33183,33213,33243,33272,33302,33331,33361,33390,33420,33450,33479,33509,33539,33568,33598,33627,33657,33686,33716,33745,33775,33804,33834,33863,33893,33922,33952,33981,34011,34040,34069,34099,34128,34158,34187,34217,34247,34277,34306,34336,34365,34395,34424,34454,34483,34512,34542,34571,34601,34631,34660,34690,34719,34749,34778,34808,34837,34867,34896,34926,34955,34985,35015,35044,35074,35103,35133,35162,35192,35222,35251,35280,35310,35340,35370,35399,35429,35458,35488,35517,35547,35576,35605,35635,35665,35694,35723,35753,35782,35811,35841,35871,35901,35930,35960,35989,36019,36048,36078,36107,36136,36166,36195,36225,36254,36284,36314,36343,36373,36403,36433,36462,36492,36521,36551,36580,36610,36639,36669,36698,36728,36757,36786,36816,36845,36875,36904,36934,36963,36993,37022,37052,37081,37111,37141,37170,37200,37229,37259,37288,37318,37347,37377,37406,37436,37465,37495,37524,37554,37584,37613,37643,37672,37701,37731,37760,37790,37819,37849,37878,37908,37938,37967,37997,38027,38056,38085,38115,38144,38174,38203,38233,38262,38292,38322,38351,38381,38410,38440,38469,38499,38528,38558,38587,38617,38646,38676,38705,38735,38764,38794,38823,38853,38882,38912,38941,38971,39001,39030,39059,39089,39118,39148,39178,39208,39237,39267,39297,39326,39355,39385,39414,39444,39473,39503,39532,39562,39592,39621,39650,39680,39709,39739,39768,39798,39827,39857,39886,39916,39946,39975,40005,40035,40064,40094,40123,40153,40182,40212,40241,40271,40300,40330,40359,40389,40418,40448,40477,40507,40536,40566,40595,40625,40655,40685,40714,40744,40773,40803,40832,40862,40892,40921,40951,40980,41009,41039,41068,41098,41127,41157,41186,41216,41245,41275,41304,41334,41364,41393,41422,41452,41481,41511,41540,41570,41599,41629,41658,41688,41718,41748,41777,41807,41836,41865,41894,41924,41953,41983,42012,42042,42072,42102,42131,42161,42190,42220,42249,42279,42308,42337,42367,42397,42426,42456,42485,42515,42545,42574,42604,42633,42662,42692,42721,42751,42780,42810,42839,42869,42899,42929,42958,42988,43017,43046,43076,43105,43135,43164,43194,43223,43253,43283,43312,43342,43371,43401,43430,43460,43489,43519,43548,43578,43607,43637,43666,43696,43726,43755,43785,43814,43844,43873,43903,43932,43962,43991,44021,44050,44080,44109,44139,44169,44198,44228,44258,44287,44317,44346,44375,44405,44434,44464,44493,44523,44553,44582,44612,44641,44671,44700,44730,44759,44788,44818,44847,44877,44906,44936,44966,44996,45025,45055,45084,45114,45143,45172,45202,45231,45261,45290,45320,45350,45380,45409,45439,45468,45498,45527,45556,45586,45615,45644,45674,45704,45733,45763,45793,45823,45852,45882,45911,45940,45970,45999,46028,46058,46088,46117,46147,46177,46206,46236,46265,46295,46324,46354,46383,46413,46442,46472,46501,46531,46560,46590,46620,46649,46679,46708,46738,46767,46797,46826,46856,46885,46915,46944,46974,47003,47033,47063,47092,47122,47151,47181,47210,47240,47269,47298,47328,47357,47387,47417,47446,47476,47506,47535,47565,47594,47624,47653,47682,47712,47741,47771,47800,47830,47860,47890,47919,47949,47978,48008,48037,48066,48096,48125,48155,48184,48214,48244,48273,48303,48333,48362,48392,48421,48450,48480,48509,48538,48568,48598,48627,48657,48687,48717,48746,48776,48805,48834,48864,48893,48922,48952,48982,49011,49041,49071,49100,49130,49160,49189,49218,49248,49277,49306,49336,49365,49395,49425,49455,49484,49514,49543,49573,49602,49632,49661,49690,49720,49749,49779,49809,49838,49868,49898,49927,49957,49986,50016,50045,50075,50104,50133,50163,50192,50222,50252,50281,50311,50340,50370,50400,50429,50459,50488,50518,50547,50576,50606,50635,50665,50694,50724,50754,50784,50813,50843,50872,50902,50931,50960,50990,51019,51049,51078,51108,51138,51167,51197,51227,51256,51286,51315,51345,51374,51403,51433,51462,51492,51522,51552,51582,51611,51641,51670,51699,51729,51758,51787,51816,51846,51876,51906,51936,51965,51995,52025,52054,52083,52113,52142,52171,52200,52230,52260,52290,52319,52349,52379,52408,52438,52467,52497,52526,52555,52585,52614,52644,52673,52703,52733,52762,52792,52822,52851,52881,52910,52939,52969,52998,53028,53057,53087,53116,53146,53176,53205,53235,53264,53294,53324,53353,53383,53412,53441,53471,53500,53530,53559,53589,53619,53648,53678,53708,53737,53767,53796,53825,53855,53884,53913,53943,53973,54003,54032,54062,54092,54121,54151,54180,54209,54239,54268,54297,54327,54357,54387,54416,54446,54476,54505,54535,54564,54593,54623,54652,54681,54711,54741,54770,54800,54830,54859,54889,54919,54948,54977,55007,55036,55066,55095,55125,55154,55184,55213,55243,55273,55302,55332,55361,55391,55420,55450,55479,55508,55538,55567,55597,55627,55657,55686,55716,55745,55775,55804,55834,55863,55892,55922,55951,55981,56011,56040,56070,56100,56129,56159,56188,56218,56247,56276,56306,56335,56365,56394,56424,56454,56483,56513,56543,56572,56601,56631,56660,56690,56719,56749,56778,56808,56837,56867,56897,56926,56956,56985,57015,57044,57074,57103,57133,57162,57192,57221,57251,57280,57310,57340,57369,57399,57429,57458,57487,57517,57546,57576,57605,57634,57664,57694,57723,57753,57783,57813,57842,57871,57901,57930,57959,57989,58018,58048,58077,58107,58137,58167,58196,58226,58255,58285,58314,58343,58373,58402,58432,58461,58491,58521,58551,58580,58610,58639,58669,58698,58727,58757,58786,58816,58845,58875,58905,58934,58964,58994,59023,59053,59082,59111,59141,59170,59200,59229,59259,59288,59318,59348,59377,59407,59436,59466,59495,59525,59554,59584,59613,59643,59672,59702,59731,59761,59791,59820,59850,59879,59909,59939,59968,59997,60027,60056,60086,60115,60145,60174,60204,60234,60264,60293,60323,60352,60381,60411,60440,60469,60499,60528,60558,60588,60618,60648,60677,60707,60736,60765,60795,60824,60853,60883,60912,60942,60972,61002,61031,61061,61090,61120,61149,61179,61208,61237,61267,61296,61326,61356,61385,61415,61445,61474,61504,61533,61563,61592,61621,61651,61680,61710,61739,61769,61799,61828,61858,61888,61917,61947,61976,62006,62035,62064,62094,62123,62153,62182,62212,62242,62271,62301,62331,62360,62390,62419,62448,62478,62507,62537,62566,62596,62625,62655,62685,62715,62744,62774,62803,62832,62862,62891,62921,62950,62980,63009,63039,63069,63099,63128,63157,63187,63216,63246,63275,63305,63334,63363,63393,63423,63453,63482,63512,63541,63571,63600,63630,63659,63689,63718,63747,63777,63807,63836,63866,63895,63925,63955,63984,64014,64043,64073,64102,64131,64161,64190,64220,64249,64279,64309,64339,64368,64398,64427,64457,64486,64515,64545,64574,64603,64633,64663,64692,64722,64752,64782,64811,64841,64870,64899,64929,64958,64987,65017,65047,65076,65106,65136,65166,65195,65225,65254,65283,65313,65342,65371,65401,65431,65460,65490,65520,65549,65579,65608,65638,65667,65697,65726,65755,65785,65815,65844,65874,65903,65933,65963,65992,66022,66051,66081,66110,66140,66169,66199,66228,66258,66287,66317,66346,66376,66405,66435,66465,66494,66524,66553,66583,66612,66641,66671,66700,66730,66760,66789,66819,66849,66878,66908,66937,66967,66996,67025,67055,67084,67114,67143,67173,67203,67233,67262,67292,67321,67351,67380,67409,67439,67468,67497,67527,67557,67587,67617,67646,67676,67705,67735,67764,67793,67823,67852,67882,67911,67941,67971,68e3,68030,68060,68089,68119,68148,68177,68207,68236,68266,68295,68325,68354,68384,68414,68443,68473,68502,68532,68561,68591,68620,68650,68679,68708,68738,68768,68797,68827,68857,68886,68916,68946,68975,69004,69034,69063,69092,69122,69152,69181,69211,69240,69270,69300,69330,69359,69388,69418,69447,69476,69506,69535,69565,69595,69624,69654,69684,69713,69743,69772,69802,69831,69861,69890,69919,69949,69978,70008,70038,70067,70097,70126,70156,70186,70215,70245,70274,70303,70333,70362,70392,70421,70451,70481,70510,70540,70570,70599,70629,70658,70687,70717,70746,70776,70805,70835,70864,70894,70924,70954,70983,71013,71042,71071,71101,71130,71159,71189,71218,71248,71278,71308,71337,71367,71397,71426,71455,71485,71514,71543,71573,71602,71632,71662,71691,71721,71751,71781,71810,71839,71869,71898,71927,71957,71986,72016,72046,72075,72105,72135,72164,72194,72223,72253,72282,72311,72341,72370,72400,72429,72459,72489,72518,72548,72577,72607,72637,72666,72695,72725,72754,72784,72813,72843,72872,72902,72931,72961,72991,73020,73050,73080,73109,73139,73168,73197,73227,73256,73286,73315,73345,73375,73404,73434,73464,73493,73523,73552,73581,73611,73640,73669,73699,73729,73758,73788,73818,73848,73877,73907,73936,73965,73995,74024,74053,74083,74113,74142,74172,74202,74231,74261,74291,74320,74349,74379,74408,74437,74467,74497,74526,74556,74586,74615,74645,74675,74704,74733,74763,74792,74822,74851,74881,74910,74940,74969,74999,75029,75058,75088,75117,75147,75176,75206,75235,75264,75294,75323,75353,75383,75412,75442,75472,75501,75531,75560,75590,75619,75648,75678,75707,75737,75766,75796,75826,75856,75885,75915,75944,75974,76003,76032,76062,76091,76121,76150,76180,76210,76239,76269,76299,76328,76358,76387,76416,76446,76475,76505,76534,76564,76593,76623,76653,76682,76712,76741,76771,76801,76830,76859,76889,76918,76948,76977,77007,77036,77066,77096,77125,77155,77185,77214,77243,77273,77302,77332,77361,77390,77420,77450,77479,77509,77539,77569,77598,77627,77657,77686,77715,77745,77774,77804,77833,77863,77893,77923,77952,77982,78011,78041,78070,78099,78129,78158,78188,78217,78247,78277,78307,78336,78366,78395,78425,78454,78483,78513,78542,78572,78601,78631,78661,78690,78720,78750,78779,78808,78838,78867,78897,78926,78956,78985,79015,79044,79074,79104,79133,79163,79192,79222,79251,79281,79310,79340,79369,79399,79428,79458,79487,79517,79546,79576,79606,79635,79665,79695,79724,79753,79783,79812,79841,79871,79900,79930,79960,79990]},{\"../main\":571,\"object-assign\":454}],571:[function(t,e,r){var n=t(\"object-assign\");function i(){this.regionalOptions=[],this.regionalOptions[\"\"]={invalidCalendar:\"Calendar {0} not found\",invalidDate:\"Invalid {0} date\",invalidMonth:\"Invalid {0} month\",invalidYear:\"Invalid {0} year\",differentCalendars:\"Cannot mix {0} and {1} dates\"},this.local=this.regionalOptions[\"\"],this.calendars={},this._localCals={}}function a(t,e,r,n){if(this._calendar=t,this._year=e,this._month=r,this._day=n,0===this._calendar._validateLevel&&!this._calendar.isValid(this._year,this._month,this._day))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name)}function o(t,e){return\"000000\".substring(0,e-(t=\"\"+t).length)+t}function s(){this.shortYearCutoff=\"+10\"}function l(t){this.local=this.regionalOptions[t]||this.regionalOptions[\"\"]}n(i.prototype,{instance:function(t,e){t=(t||\"gregorian\").toLowerCase(),e=e||\"\";var r=this._localCals[t+\"-\"+e];if(!r&&this.calendars[t]&&(r=new this.calendars[t](e),this._localCals[t+\"-\"+e]=r),!r)throw(this.local.invalidCalendar||this.regionalOptions[\"\"].invalidCalendar).replace(/\\{0\\}/,t);return r},newDate:function(t,e,r,n,i){return(n=(null!=t&&t.year?t.calendar():\"string\"==typeof n?this.instance(n,i):n)||this.instance()).newDate(t,e,r)},substituteDigits:function(t){return function(e){return(e+\"\").replace(/[0-9]/g,function(e){return t[e]})}},substituteChineseDigits:function(t,e){return function(r){for(var n=\"\",i=0;r>0;){var a=r%10;n=(0===a?\"\":t[a]+e[i])+n,i++,r=Math.floor(r/10)}return 0===n.indexOf(t[1]+e[1])&&(n=n.substr(1)),n||t[0]}}}),n(a.prototype,{newDate:function(t,e,r){return this._calendar.newDate(null==t?this:t,e,r)},year:function(t){return 0===arguments.length?this._year:this.set(t,\"y\")},month:function(t){return 0===arguments.length?this._month:this.set(t,\"m\")},day:function(t){return 0===arguments.length?this._day:this.set(t,\"d\")},date:function(t,e,r){if(!this._calendar.isValid(t,e,r))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name);return this._year=t,this._month=e,this._day=r,this},leapYear:function(){return this._calendar.leapYear(this)},epoch:function(){return this._calendar.epoch(this)},formatYear:function(){return this._calendar.formatYear(this)},monthOfYear:function(){return this._calendar.monthOfYear(this)},weekOfYear:function(){return this._calendar.weekOfYear(this)},daysInYear:function(){return this._calendar.daysInYear(this)},dayOfYear:function(){return this._calendar.dayOfYear(this)},daysInMonth:function(){return this._calendar.daysInMonth(this)},dayOfWeek:function(){return this._calendar.dayOfWeek(this)},weekDay:function(){return this._calendar.weekDay(this)},extraInfo:function(){return this._calendar.extraInfo(this)},add:function(t,e){return this._calendar.add(this,t,e)},set:function(t,e){return this._calendar.set(this,t,e)},compareTo:function(t){if(this._calendar.name!==t._calendar.name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this._calendar.local.name).replace(/\\{1\\}/,t._calendar.local.name);var e=this._year!==t._year?this._year-t._year:this._month!==t._month?this.monthOfYear()-t.monthOfYear():this._day-t._day;return 0===e?0:e<0?-1:1},calendar:function(){return this._calendar},toJD:function(){return this._calendar.toJD(this)},fromJD:function(t){return this._calendar.fromJD(t)},toJSDate:function(){return this._calendar.toJSDate(this)},fromJSDate:function(t){return this._calendar.fromJSDate(t)},toString:function(){return(this.year()<0?\"-\":\"\")+o(Math.abs(this.year()),4)+\"-\"+o(this.month(),2)+\"-\"+o(this.day(),2)}}),n(s.prototype,{_validateLevel:0,newDate:function(t,e,r){return null==t?this.today():(t.year&&(this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),r=t.day(),e=t.month(),t=t.year()),new a(this,t,e,r))},today:function(){return this.fromJSDate(new Date)},epoch:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear).year()<0?this.local.epochs[0]:this.local.epochs[1]},formatYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(e.year()<0?\"-\":\"\")+o(Math.abs(e.year()),4)},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear),12},monthOfYear:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return(r.month()+this.monthsInYear(r)-this.firstMonth)%this.monthsInYear(r)+this.minMonth},fromMonthOfYear:function(t,e){var r=(e+this.firstMonth-2*this.minMonth)%this.monthsInYear(t)+this.minMonth;return this._validate(t,r,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth),r},daysInYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return this.leapYear(e)?366:365},dayOfYear:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return n.toJD()-this.newDate(n.year(),this.fromMonthOfYear(n.year(),this.minMonth),this.minDay).toJD()+1},daysInWeek:function(){return 7},dayOfWeek:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return(Math.floor(this.toJD(n))+2)%this.daysInWeek()},extraInfo:function(t,e,r){return this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),{}},add:function(t,e,r){return this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),this._correctAdd(t,this._add(t,e,r),e,r)},_add:function(t,e,r){if(this._validateLevel++,\"d\"===r||\"w\"===r){var n=t.toJD()+e*(\"w\"===r?this.daysInWeek():1),i=t.calendar().fromJD(n);return this._validateLevel--,[i.year(),i.month(),i.day()]}try{var a=t.year()+(\"y\"===r?e:0),o=t.monthOfYear()+(\"m\"===r?e:0);i=t.day();\"y\"===r?(t.month()!==this.fromMonthOfYear(a,o)&&(o=this.newDate(a,t.month(),this.minDay).monthOfYear()),o=Math.min(o,this.monthsInYear(a)),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o)))):\"m\"===r&&(!function(t){for(;o<t.minMonth;)a--,o+=t.monthsInYear(a);for(var e=t.monthsInYear(a);o>e-1+t.minMonth;)a++,o-=e,e=t.monthsInYear(a)}(this),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o))));var s=[a,this.fromMonthOfYear(a,o),i];return this._validateLevel--,s}catch(t){throw this._validateLevel--,t}},_correctAdd:function(t,e,r,n){if(!(this.hasYearZero||\"y\"!==n&&\"m\"!==n||0!==e[0]&&t.year()>0==e[0]>0)){var i={y:[1,1,\"y\"],m:[1,this.monthsInYear(-1),\"m\"],w:[this.daysInWeek(),this.daysInYear(-1),\"d\"],d:[1,this.daysInYear(-1),\"d\"]}[n],a=r<0?-1:1;e=this._add(t,r*i[0]+a*i[1],i[2])}return t.date(e[0],e[1],e[2])},set:function(t,e,r){this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);var n=\"y\"===r?e:t.year(),i=\"m\"===r?e:t.month(),a=\"d\"===r?e:t.day();return\"y\"!==r&&\"m\"!==r||(a=Math.min(a,this.daysInMonth(n,i))),t.date(n,i,a)},isValid:function(t,e,r){this._validateLevel++;var n=this.hasYearZero||0!==t;if(n){var i=this.newDate(t,e,this.minDay);n=e>=this.minMonth&&e-this.minMonth<this.monthsInYear(i)&&r>=this.minDay&&r-this.minDay<this.daysInMonth(i)}return this._validateLevel--,n},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return c.instance().fromJD(this.toJD(n)).toJSDate()},fromJSDate:function(t){return this.fromJD(c.instance().fromJSDate(t).toJD())},_validate:function(t,e,r,n){if(t.year){if(0===this._validateLevel&&this.name!==t.calendar().name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this.local.name).replace(/\\{1\\}/,t.calendar().local.name);return t}try{if(this._validateLevel++,1===this._validateLevel&&!this.isValid(t,e,r))throw n.replace(/\\{0\\}/,this.local.name);var i=this.newDate(t,e,r);return this._validateLevel--,i}catch(t){throw this._validateLevel--,t}}}),l.prototype=new s,n(l.prototype,{name:\"Gregorian\",jdEpoch:1721425.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Gregorian\",epochs:[\"BCE\",\"CE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==0&&(t%100!=0||t%400==0)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);t=n.year(),e=n.month(),r=n.day(),t<0&&t++,e<3&&(e+=12,t--);var i=Math.floor(t/100),a=2-i+Math.floor(i/4);return Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r+a-1524.5},fromJD:function(t){var e=Math.floor(t+.5),r=Math.floor((e-1867216.25)/36524.25),n=(r=e+1+r-Math.floor(r/4))+1524,i=Math.floor((n-122.1)/365.25),a=Math.floor(365.25*i),o=Math.floor((n-a)/30.6001),s=n-a-Math.floor(30.6001*o),l=o-(o>13.5?13:1),c=i-(l>2.5?4716:4715);return c<=0&&c--,this.newDate(c,l,s)},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),i=new Date(n.year(),n.month()-1,n.day());return i.setHours(0),i.setMinutes(0),i.setSeconds(0),i.setMilliseconds(0),i.setHours(i.getHours()>12?i.getHours()+2:0),i},fromJSDate:function(t){return this.newDate(t.getFullYear(),t.getMonth()+1,t.getDate())}});var c=e.exports=new i;c.cdate=a,c.baseCalendar=s,c.calendars.gregorian=l},{\"object-assign\":454}],572:[function(t,e,r){var n=t(\"object-assign\"),i=t(\"./main\");n(i.regionalOptions[\"\"],{invalidArguments:\"Invalid arguments\",invalidFormat:\"Cannot format a date from another calendar\",missingNumberAt:\"Missing number at position {0}\",unknownNameAt:\"Unknown name at position {0}\",unexpectedLiteralAt:\"Unexpected literal at position {0}\",unexpectedText:\"Additional text found at end\"}),i.local=i.regionalOptions[\"\"],n(i.cdate.prototype,{formatDate:function(t,e){return\"string\"!=typeof t&&(e=t,t=\"\"),this._calendar.formatDate(t||\"\",this,e)}}),n(i.baseCalendar.prototype,{UNIX_EPOCH:i.instance().newDate(1970,1,1).toJD(),SECS_PER_DAY:86400,TICKS_EPOCH:i.instance().jdEpoch,TICKS_PER_DAY:864e9,ATOM:\"yyyy-mm-dd\",COOKIE:\"D, dd M yyyy\",FULL:\"DD, MM d, yyyy\",ISO_8601:\"yyyy-mm-dd\",JULIAN:\"J\",RFC_822:\"D, d M yy\",RFC_850:\"DD, dd-M-yy\",RFC_1036:\"D, d M yy\",RFC_1123:\"D, d M yyyy\",RFC_2822:\"D, d M yyyy\",RSS:\"D, d M yy\",TICKS:\"!\",TIMESTAMP:\"@\",W3C:\"yyyy-mm-dd\",formatDate:function(t,e,r){if(\"string\"!=typeof t&&(r=e,e=t,t=\"\"),!e)return\"\";if(e.calendar()!==this)throw i.local.invalidFormat||i.regionalOptions[\"\"].invalidFormat;t=t||this.local.dateFormat;for(var n,a,o,s,l=(r=r||{}).dayNamesShort||this.local.dayNamesShort,c=r.dayNames||this.local.dayNames,u=r.monthNumbers||this.local.monthNumbers,h=r.monthNamesShort||this.local.monthNamesShort,f=r.monthNames||this.local.monthNames,p=(r.calculateWeek||this.local.calculateWeek,function(e,r){for(var n=1;w+n<t.length&&t.charAt(w+n)===e;)n++;return w+=n-1,Math.floor(n/(r||1))>1}),d=function(t,e,r,n){var i=\"\"+e;if(p(t,n))for(;i.length<r;)i=\"0\"+i;return i},g=this,v=function(t){return\"function\"==typeof u?u.call(g,t,p(\"m\")):x(d(\"m\",t.month(),2))},m=function(t,e){return e?\"function\"==typeof f?f.call(g,t):f[t.month()-g.minMonth]:\"function\"==typeof h?h.call(g,t):h[t.month()-g.minMonth]},y=this.local.digits,x=function(t){return r.localNumbers&&y?y(t):t},b=\"\",_=!1,w=0;w<t.length;w++)if(_)\"'\"!==t.charAt(w)||p(\"'\")?b+=t.charAt(w):_=!1;else switch(t.charAt(w)){case\"d\":b+=x(d(\"d\",e.day(),2));break;case\"D\":b+=(n=\"D\",a=e.dayOfWeek(),o=l,s=c,p(n)?s[a]:o[a]);break;case\"o\":b+=d(\"o\",e.dayOfYear(),3);break;case\"w\":b+=d(\"w\",e.weekOfYear(),2);break;case\"m\":b+=v(e);break;case\"M\":b+=m(e,p(\"M\"));break;case\"y\":b+=p(\"y\",2)?e.year():(e.year()%100<10?\"0\":\"\")+e.year()%100;break;case\"Y\":p(\"Y\",2),b+=e.formatYear();break;case\"J\":b+=e.toJD();break;case\"@\":b+=(e.toJD()-this.UNIX_EPOCH)*this.SECS_PER_DAY;break;case\"!\":b+=(e.toJD()-this.TICKS_EPOCH)*this.TICKS_PER_DAY;break;case\"'\":p(\"'\")?b+=\"'\":_=!0;break;default:b+=t.charAt(w)}return b},parseDate:function(t,e,r){if(null==e)throw i.local.invalidArguments||i.regionalOptions[\"\"].invalidArguments;if(\"\"===(e=\"object\"==typeof e?e.toString():e+\"\"))return null;t=t||this.local.dateFormat;var n=(r=r||{}).shortYearCutoff||this.shortYearCutoff;n=\"string\"!=typeof n?n:this.today().year()%100+parseInt(n,10);for(var a=r.dayNamesShort||this.local.dayNamesShort,o=r.dayNames||this.local.dayNames,s=r.parseMonth||this.local.parseMonth,l=r.monthNumbers||this.local.monthNumbers,c=r.monthNamesShort||this.local.monthNamesShort,u=r.monthNames||this.local.monthNames,h=-1,f=-1,p=-1,d=-1,g=-1,v=!1,m=!1,y=function(e,r){for(var n=1;M+n<t.length&&t.charAt(M+n)===e;)n++;return M+=n-1,Math.floor(n/(r||1))>1},x=function(t,r){var n=y(t,r),a=[2,3,n?4:2,n?4:2,10,11,20][\"oyYJ@!\".indexOf(t)+1],o=new RegExp(\"^-?\\\\d{1,\"+a+\"}\"),s=e.substring(A).match(o);if(!s)throw(i.local.missingNumberAt||i.regionalOptions[\"\"].missingNumberAt).replace(/\\{0\\}/,A);return A+=s[0].length,parseInt(s[0],10)},b=this,_=function(){if(\"function\"==typeof l){y(\"m\");var t=l.call(b,e.substring(A));return A+=t.length,t}return x(\"m\")},w=function(t,r,n,a){for(var o=y(t,a)?n:r,s=0;s<o.length;s++)if(e.substr(A,o[s].length).toLowerCase()===o[s].toLowerCase())return A+=o[s].length,s+b.minMonth;throw(i.local.unknownNameAt||i.regionalOptions[\"\"].unknownNameAt).replace(/\\{0\\}/,A)},k=function(){if(\"function\"==typeof u){var t=y(\"M\")?u.call(b,e.substring(A)):c.call(b,e.substring(A));return A+=t.length,t}return w(\"M\",c,u)},T=function(){if(e.charAt(A)!==t.charAt(M))throw(i.local.unexpectedLiteralAt||i.regionalOptions[\"\"].unexpectedLiteralAt).replace(/\\{0\\}/,A);A++},A=0,M=0;M<t.length;M++)if(m)\"'\"!==t.charAt(M)||y(\"'\")?T():m=!1;else switch(t.charAt(M)){case\"d\":d=x(\"d\");break;case\"D\":w(\"D\",a,o);break;case\"o\":g=x(\"o\");break;case\"w\":x(\"w\");break;case\"m\":p=_();break;case\"M\":p=k();break;case\"y\":var S=M;v=!y(\"y\",2),M=S,f=x(\"y\",2);break;case\"Y\":f=x(\"Y\",2);break;case\"J\":h=x(\"J\")+.5,\".\"===e.charAt(A)&&(A++,x(\"J\"));break;case\"@\":h=x(\"@\")/this.SECS_PER_DAY+this.UNIX_EPOCH;break;case\"!\":h=x(\"!\")/this.TICKS_PER_DAY+this.TICKS_EPOCH;break;case\"*\":A=e.length;break;case\"'\":y(\"'\")?T():m=!0;break;default:T()}if(A<e.length)throw i.local.unexpectedText||i.regionalOptions[\"\"].unexpectedText;if(-1===f?f=this.today().year():f<100&&v&&(f+=-1===n?1900:this.today().year()-this.today().year()%100-(f<=n?0:100)),\"string\"==typeof p&&(p=s.call(this,f,p)),g>-1){p=1,d=g;for(var E=this.daysInMonth(f,p);d>E;E=this.daysInMonth(f,p))p++,d-=E}return h>-1?this.fromJD(h):this.newDate(f,p,d)},determineDate:function(t,e,r,n,i){r&&\"object\"!=typeof r&&(i=n,n=r,r=null),\"string\"!=typeof n&&(i=n,n=\"\");var a=this;return e=e?e.newDate():null,t=null==t?e:\"string\"==typeof t?function(t){try{return a.parseDate(n,t,i)}catch(t){}for(var e=((t=t.toLowerCase()).match(/^c/)&&r?r.newDate():null)||a.today(),o=/([+-]?[0-9]+)\\s*(d|w|m|y)?/g,s=o.exec(t);s;)e.add(parseInt(s[1],10),s[2]||\"d\"),s=o.exec(t);return e}(t):\"number\"==typeof t?isNaN(t)||t===1/0||t===-1/0?e:a.today().add(t,\"d\"):a.newDate(t)}})},{\"./main\":571,\"object-assign\":454}],573:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",{offset:[1],array:0},\"scalar\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\n        var _inline_1_da = _inline_1_arg0_ - _inline_1_arg3_\\n        var _inline_1_db = _inline_1_arg1_ - _inline_1_arg3_\\n        if((_inline_1_da >= 0) !== (_inline_1_db >= 0)) {\\n          _inline_1_arg2_.push(_inline_1_arg4_[0] + 0.5 + 0.5 * (_inline_1_da + _inline_1_db) / (_inline_1_da - _inline_1_db))\\n        }\\n      }\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg3_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[\"_inline_1_da\",\"_inline_1_db\"]},funcName:\"zeroCrossings\"})},{\"cwise-compiler\":146}],574:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=[];return e=+e||0,n(t.hi(t.shape[0]-1),r,e),r};var n=t(\"./lib/zc-core\")},{\"./lib/zc-core\":573}],575:[function(t,e,r){\"use strict\";e.exports=[{path:\"\",backoff:0},{path:\"M-2.4,-3V3L0.6,0Z\",backoff:.6},{path:\"M-3.7,-2.5V2.5L1.3,0Z\",backoff:1.3},{path:\"M-4.45,-3L-1.65,-0.2V0.2L-4.45,3L1.55,0Z\",backoff:1.55},{path:\"M-2.2,-2.2L-0.2,-0.2V0.2L-2.2,2.2L-1.4,3L1.6,0L-1.4,-3Z\",backoff:1.6},{path:\"M-4.4,-2.1L-0.6,-0.2V0.2L-4.4,2.1L-4,3L2,0L-4,-3Z\",backoff:2},{path:\"M2,0A2,2 0 1,1 0,-2A2,2 0 0,1 2,0Z\",backoff:0,noRotate:!0},{path:\"M2,2V-2H-2V2Z\",backoff:0,noRotate:!0}]},{}],576:[function(t,e,r){\"use strict\";var n=t(\"./arrow_paths\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../plots/cartesian/constants\"),o=t(\"../../plot_api/plot_template\").templatedArray;e.exports=o(\"annotation\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},text:{valType:\"string\",editType:\"calc+arraydraw\"},textangle:{valType:\"angle\",dflt:0,editType:\"calc+arraydraw\"},font:i({editType:\"calc+arraydraw\",colorEditType:\"arraydraw\"}),width:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},height:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"center\",editType:\"arraydraw\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"arraydraw\"},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},borderpad:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},showarrow:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},arrowcolor:{valType:\"color\",editType:\"arraydraw\"},arrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},startarrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},arrowside:{valType:\"flaglist\",flags:[\"end\",\"start\"],extras:[\"none\"],dflt:\"end\",editType:\"arraydraw\"},arrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},startarrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},arrowwidth:{valType:\"number\",min:.1,editType:\"calc+arraydraw\"},standoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},startstandoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},ax:{valType:\"any\",editType:\"calc+arraydraw\"},ay:{valType:\"any\",editType:\"calc+arraydraw\"},axref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.x.toString()],editType:\"calc\"},ayref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.y.toString()],editType:\"calc\"},xref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.x.toString()],editType:\"calc\"},x:{valType:\"any\",editType:\"calc+arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"auto\",editType:\"calc+arraydraw\"},xshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.y.toString()],editType:\"calc\"},y:{valType:\"any\",editType:\"calc+arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"calc+arraydraw\"},yshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},clicktoshow:{valType:\"enumerated\",values:[!1,\"onoff\",\"onout\"],dflt:!1,editType:\"arraydraw\"},xclick:{valType:\"any\",editType:\"arraydraw\"},yclick:{valType:\"any\",editType:\"arraydraw\"},hovertext:{valType:\"string\",editType:\"arraydraw\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",editType:\"arraydraw\"},font:i({editType:\"arraydraw\"}),editType:\"arraydraw\"},captureevents:{valType:\"boolean\",editType:\"arraydraw\"},editType:\"calc\",_deprecated:{ref:{valType:\"string\",editType:\"calc\"}}})},{\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773,\"../../plots/font_attributes\":793,\"./arrow_paths\":575}],577:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./draw\").draw;function o(t){var e=t._fullLayout;n.filterVisible(e.annotations).forEach(function(e){var r=i.getFromId(t,e.xref),n=i.getFromId(t,e.yref);e._extremes={},r&&s(e,r),n&&s(e,n)})}function s(t,e){var r,n=e._id,a=n.charAt(0),o=t[a],s=t[\"a\"+a],l=t[a+\"ref\"],c=t[\"a\"+a+\"ref\"],u=t[\"_\"+a+\"padplus\"],h=t[\"_\"+a+\"padminus\"],f={x:1,y:-1}[a]*t[a+\"shift\"],p=3*t.arrowsize*t.arrowwidth||0,d=p+f,g=p-f,v=3*t.startarrowsize*t.arrowwidth||0,m=v+f,y=v-f;if(c===l){var x=i.findExtremes(e,[e.r2c(o)],{ppadplus:d,ppadminus:g}),b=i.findExtremes(e,[e.r2c(s)],{ppadplus:Math.max(u,m),ppadminus:Math.max(h,y)});r={min:[x.min[0],b.min[0]],max:[x.max[0],b.max[0]]}}else m=s?m+s:m,y=s?y-s:y,r=i.findExtremes(e,[e.r2c(o)],{ppadplus:Math.max(u,d,m),ppadminus:Math.max(h,g,y)});t._extremes[n]=r}e.exports=function(t){var e=t._fullLayout;if(n.filterVisible(e.annotations).length&&t._fullData.length)return n.syncOrAsync([a,o],t)}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./draw\":582}],578:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../plot_api/plot_template\").arrayEditor;function o(t,e){var r,n,i,a,o,l,c,u=t._fullLayout.annotations,h=[],f=[],p=[],d=(e||[]).length;for(r=0;r<u.length;r++)if(a=(i=u[r]).clicktoshow){for(n=0;n<d;n++)if(l=(o=e[n]).xaxis,c=o.yaxis,l._id===i.xref&&c._id===i.yref&&l.d2r(o.x)===s(i._xclick,l)&&c.d2r(o.y)===s(i._yclick,c)){(i.visible?\"onout\"===a?f:p:h).push(r);break}n===d&&i.visible&&\"onout\"===a&&f.push(r)}return{on:h,off:f,explicitOff:p}}function s(t,e){return\"log\"===e.type?e.l2r(t):e.d2r(t)}e.exports={hasClickToShow:function(t,e){var r=o(t,e);return r.on.length>0||r.explicitOff.length>0},onClick:function(t,e){var r,s,l=o(t,e),c=l.on,u=l.off.concat(l.explicitOff),h={},f=t._fullLayout.annotations;if(!c.length&&!u.length)return;for(r=0;r<c.length;r++)(s=a(t.layout,\"annotations\",f[c[r]])).modifyItem(\"visible\",!0),n.extendFlat(h,s.getUpdateObj());for(r=0;r<u.length;r++)(s=a(t.layout,\"annotations\",f[u[r]])).modifyItem(\"visible\",!1),n.extendFlat(h,s.getUpdateObj());return i.call(\"update\",t,{},h)}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../registry\":847}],579:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\");e.exports=function(t,e,r,a){a(\"opacity\");var o=a(\"bgcolor\"),s=a(\"bordercolor\"),l=i.opacity(s);a(\"borderpad\");var c=a(\"borderwidth\"),u=a(\"showarrow\");if(a(\"text\",u?\" \":r._dfltTitle.annotation),a(\"textangle\"),n.coerceFont(a,\"font\",r.font),a(\"width\"),a(\"align\"),a(\"height\")&&a(\"valign\"),u){var h,f,p=a(\"arrowside\");-1!==p.indexOf(\"end\")&&(h=a(\"arrowhead\"),f=a(\"arrowsize\")),-1!==p.indexOf(\"start\")&&(a(\"startarrowhead\",h),a(\"startarrowsize\",f)),a(\"arrowcolor\",l?e.bordercolor:i.defaultLine),a(\"arrowwidth\",2*(l&&c||1)),a(\"standoff\"),a(\"startstandoff\")}var d=a(\"hovertext\"),g=r.hoverlabel||{};if(d){var v=a(\"hoverlabel.bgcolor\",g.bgcolor||(i.opacity(o)?i.rgb(o):i.defaultLine)),m=a(\"hoverlabel.bordercolor\",g.bordercolor||i.contrast(v));n.coerceFont(a,\"hoverlabel.font\",{family:g.font.family,size:g.font.size,color:g.font.color||m})}a(\"captureevents\",!!d)}},{\"../../lib\":719,\"../color\":593}],580:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.annotations,h=e._id.charAt(0),f=0;f<u.length;f++)l=u[f],c=\"annotations[\"+f+\"].\",l[h+\"ref\"]===e._id&&p(h),l[\"a\"+h+\"ref\"]===e._id&&p(\"a\"+h);function p(t){var r=l[t],s=null;s=o?i(r,e.range):Math.pow(10,r),n(s)||(s=null),a(c+t,s)}}},{\"../../lib/to_log_range\":745,\"fast-isnumeric\":225}],581:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./common_defaults\"),s=t(\"./attributes\");function l(t,e,r){function a(r,i){return n.coerce(t,e,s,r,i)}var l=a(\"visible\"),c=a(\"clicktoshow\");if(l||c){o(t,e,r,a);for(var u=e.showarrow,h=[\"x\",\"y\"],f=[-10,-30],p={_fullLayout:r},d=0;d<2;d++){var g=h[d],v=i.coerceRef(t,e,p,g,\"\",\"paper\");if(\"paper\"!==v)i.getFromId(p,v)._annIndices.push(e._index);if(i.coercePosition(e,p,a,v,g,.5),u){var m=\"a\"+g,y=i.coerceRef(t,e,p,m,\"pixel\");\"pixel\"!==y&&y!==v&&(y=e[m]=\"pixel\");var x=\"pixel\"===y?f[d]:.4;i.coercePosition(e,p,a,y,m,x)}a(g+\"anchor\"),a(g+\"shift\")}if(n.noneOrAll(t,e,[\"x\",\"y\"]),u&&n.noneOrAll(t,e,[\"ax\",\"ay\"]),c){var b=a(\"xclick\"),_=a(\"yclick\");e._xclick=void 0===b?e.x:i.cleanPosition(b,p,e.xref),e._yclick=void 0===_?e.y:i.cleanPosition(_,p,e.yref)}}}e.exports=function(t,e){a(t,e,{name:\"annotations\",handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"./attributes\":576,\"./common_defaults\":579}],582:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../color\"),c=t(\"../drawing\"),u=t(\"../fx\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"../../lib/setcursor\"),p=t(\"../dragelement\"),d=t(\"../../plot_api/plot_template\").arrayEditor,g=t(\"./draw_arrow_head\");function v(t,e){var r=t._fullLayout.annotations[e]||{},n=s.getFromId(t,r.xref),i=s.getFromId(t,r.yref);n&&n.setScale(),i&&i.setScale(),m(t,r,e,!1,n,i)}function m(t,e,r,a,s,v){var m,y,x=t._fullLayout,b=t._fullLayout._size,_=t._context.edits;a?(m=\"annotation-\"+a,y=a+\".annotations\"):(m=\"annotation\",y=\"annotations\");var w=d(t.layout,y,e),k=w.modifyBase,T=w.modifyItem,A=w.getUpdateObj;x._infolayer.selectAll(\".\"+m+'[data-index=\"'+r+'\"]').remove();var M=\"clip\"+x._uid+\"_ann\"+r;if(e._input&&!1!==e.visible){var S={x:{},y:{}},E=+e.textangle||0,C=x._infolayer.append(\"g\").classed(m,!0).attr(\"data-index\",String(r)).style(\"opacity\",e.opacity),L=C.append(\"g\").classed(\"annotation-text-g\",!0),P=_[e.showarrow?\"annotationTail\":\"annotationPosition\"],O=e.captureevents||_.annotationText||P,z=L.append(\"g\").style(\"pointer-events\",O?\"all\":null).call(f,\"pointer\").on(\"click\",function(){t._dragging=!1,t.emit(\"plotly_clickannotation\",q(n.event))});e.hovertext&&z.on(\"mouseover\",function(){var r=e.hoverlabel,n=r.font,i=this.getBoundingClientRect(),a=t.getBoundingClientRect();u.loneHover({x0:i.left-a.left,x1:i.right-a.left,y:(i.top+i.bottom)/2-a.top,text:e.hovertext,color:r.bgcolor,borderColor:r.bordercolor,fontFamily:n.family,fontSize:n.size,fontColor:n.color},{container:x._hoverlayer.node(),outerContainer:x._paper.node(),gd:t})}).on(\"mouseout\",function(){u.loneUnhover(x._hoverlayer.node())});var I=e.borderwidth,D=e.borderpad,R=I+D,F=z.append(\"rect\").attr(\"class\",\"bg\").style(\"stroke-width\",I+\"px\").call(l.stroke,e.bordercolor).call(l.fill,e.bgcolor),B=e.width||e.height,N=x._topclips.selectAll(\"#\"+M).data(B?[0]:[]);N.enter().append(\"clipPath\").classed(\"annclip\",!0).attr(\"id\",M).append(\"rect\"),N.exit().remove();var j=e.font,U=x._meta?o.templateString(e.text,x._meta):e.text,V=z.append(\"text\").classed(\"annotation-text\",!0).text(U);_.annotationText?V.call(h.makeEditable,{delegate:z,gd:t}).call(H).on(\"edit\",function(r){e.text=r,this.call(H),T(\"text\",r),s&&s.autorange&&k(s._name+\".autorange\",!0),v&&v.autorange&&k(v._name+\".autorange\",!0),i.call(\"_guiRelayout\",t,A())}):V.call(H)}else n.selectAll(\"#\"+M).remove();function q(t){var n={index:r,annotation:e._input,fullAnnotation:e,event:t};return a&&(n.subplotId=a),n}function H(r){return r.call(c.font,j).attr({\"text-anchor\":{left:\"start\",right:\"end\"}[e.align]||\"middle\"}),h.convertToTspans(r,t,G),r}function G(){var r=V.selectAll(\"a\");1===r.size()&&r.text()===V.text()&&z.insert(\"a\",\":first-child\").attr({\"xlink:xlink:href\":r.attr(\"xlink:href\"),\"xlink:xlink:show\":r.attr(\"xlink:show\")}).style({cursor:\"pointer\"}).node().appendChild(F.node());var n=z.select(\".annotation-text-math-group\"),u=!n.empty(),d=c.bBox((u?n:V).node()),m=d.width,y=d.height,w=e.width||m,O=e.height||y,D=Math.round(w+2*R),j=Math.round(O+2*R);function U(t,e){return\"auto\"===e&&(e=t<1/3?\"left\":t>2/3?\"right\":\"center\"),{center:0,middle:0,left:.5,bottom:-.5,right:-.5,top:.5}[e]}for(var H=!1,G=[\"x\",\"y\"],Y=0;Y<G.length;Y++){var W,X,Z,J,K,$=G[Y],Q=e[$+\"ref\"]||$,tt=e[\"a\"+$+\"ref\"],et={x:s,y:v}[$],rt=(E+(\"x\"===$?0:-90))*Math.PI/180,nt=D*Math.cos(rt),it=j*Math.sin(rt),at=Math.abs(nt)+Math.abs(it),ot=e[$+\"anchor\"],st=e[$+\"shift\"]*(\"x\"===$?1:-1),lt=S[$];if(et){var ct=et.r2fraction(e[$]);(ct<0||ct>1)&&(tt===Q?((ct=et.r2fraction(e[\"a\"+$]))<0||ct>1)&&(H=!0):H=!0),W=et._offset+et.r2p(e[$]),J=.5}else\"x\"===$?(Z=e[$],W=b.l+b.w*Z):(Z=1-e[$],W=b.t+b.h*Z),J=e.showarrow?.5:Z;if(e.showarrow){lt.head=W;var ut=e[\"a\"+$];K=nt*U(.5,e.xanchor)-it*U(.5,e.yanchor),tt===Q?(lt.tail=et._offset+et.r2p(ut),X=K):(lt.tail=W+ut,X=K+ut),lt.text=lt.tail+K;var ht=x[\"x\"===$?\"width\":\"height\"];if(\"paper\"===Q&&(lt.head=o.constrain(lt.head,1,ht-1)),\"pixel\"===tt){var ft=-Math.max(lt.tail-3,lt.text),pt=Math.min(lt.tail+3,lt.text)-ht;ft>0?(lt.tail+=ft,lt.text+=ft):pt>0&&(lt.tail-=pt,lt.text-=pt)}lt.tail+=st,lt.head+=st}else X=K=at*U(J,ot),lt.text=W+K;lt.text+=st,K+=st,X+=st,e[\"_\"+$+\"padplus\"]=at/2+X,e[\"_\"+$+\"padminus\"]=at/2-X,e[\"_\"+$+\"size\"]=at,e[\"_\"+$+\"shift\"]=K}if(t._dragging||!H){var dt=0,gt=0;if(\"left\"!==e.align&&(dt=(w-m)*(\"center\"===e.align?.5:1)),\"top\"!==e.valign&&(gt=(O-y)*(\"middle\"===e.valign?.5:1)),u)n.select(\"svg\").attr({x:R+dt-1,y:R+gt}).call(c.setClipUrl,B?M:null,t);else{var vt=R+gt-d.top,mt=R+dt-d.left;V.call(h.positionText,mt,vt).call(c.setClipUrl,B?M:null,t)}N.select(\"rect\").call(c.setRect,R,R,w,O),F.call(c.setRect,I/2,I/2,D-I,j-I),z.call(c.setTranslate,Math.round(S.x.text-D/2),Math.round(S.y.text-j/2)),L.attr({transform:\"rotate(\"+E+\",\"+S.x.text+\",\"+S.y.text+\")\"});var yt,xt=function(r,n){C.selectAll(\".annotation-arrow-g\").remove();var u=S.x.head,h=S.y.head,f=S.x.tail+r,d=S.y.tail+n,m=S.x.text+r,y=S.y.text+n,x=o.rotationXYMatrix(E,m,y),w=o.apply2DTransform(x),M=o.apply2DTransform2(x),P=+F.attr(\"width\"),O=+F.attr(\"height\"),I=m-.5*P,D=I+P,R=y-.5*O,B=R+O,N=[[I,R,I,B],[I,B,D,B],[D,B,D,R],[D,R,I,R]].map(M);if(!N.reduce(function(t,e){return t^!!o.segmentsIntersect(u,h,u+1e6,h+1e6,e[0],e[1],e[2],e[3])},!1)){N.forEach(function(t){var e=o.segmentsIntersect(f,d,u,h,t[0],t[1],t[2],t[3]);e&&(f=e.x,d=e.y)});var j=e.arrowwidth,U=e.arrowcolor,V=e.arrowside,q=C.append(\"g\").style({opacity:l.opacity(U)}).classed(\"annotation-arrow-g\",!0),H=q.append(\"path\").attr(\"d\",\"M\"+f+\",\"+d+\"L\"+u+\",\"+h).style(\"stroke-width\",j+\"px\").call(l.stroke,l.rgb(U));if(g(H,V,e),_.annotationPosition&&H.node().parentNode&&!a){var G=u,Y=h;if(e.standoff){var W=Math.sqrt(Math.pow(u-f,2)+Math.pow(h-d,2));G+=e.standoff*(f-u)/W,Y+=e.standoff*(d-h)/W}var X,Z,J=q.append(\"path\").classed(\"annotation-arrow\",!0).classed(\"anndrag\",!0).classed(\"cursor-move\",!0).attr({d:\"M3,3H-3V-3H3ZM0,0L\"+(f-G)+\",\"+(d-Y),transform:\"translate(\"+G+\",\"+Y+\")\"}).style(\"stroke-width\",j+6+\"px\").call(l.stroke,\"rgba(0,0,0,0)\").call(l.fill,\"rgba(0,0,0,0)\");p.init({element:J.node(),gd:t,prepFn:function(){var t=c.getTranslate(z);X=t.x,Z=t.y,s&&s.autorange&&k(s._name+\".autorange\",!0),v&&v.autorange&&k(v._name+\".autorange\",!0)},moveFn:function(t,r){var n=w(X,Z),i=n[0]+t,a=n[1]+r;z.call(c.setTranslate,i,a),T(\"x\",s?s.p2r(s.r2p(e.x)+t):e.x+t/b.w),T(\"y\",v?v.p2r(v.r2p(e.y)+r):e.y-r/b.h),e.axref===e.xref&&T(\"ax\",s.p2r(s.r2p(e.ax)+t)),e.ayref===e.yref&&T(\"ay\",v.p2r(v.r2p(e.ay)+r)),q.attr(\"transform\",\"translate(\"+t+\",\"+r+\")\"),L.attr({transform:\"rotate(\"+E+\",\"+i+\",\"+a+\")\"})},doneFn:function(){i.call(\"_guiRelayout\",t,A());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}}};if(e.showarrow&&xt(0,0),P)p.init({element:z.node(),gd:t,prepFn:function(){yt=L.attr(\"transform\")},moveFn:function(t,r){var n=\"pointer\";if(e.showarrow)e.axref===e.xref?T(\"ax\",s.p2r(s.r2p(e.ax)+t)):T(\"ax\",e.ax+t),e.ayref===e.yref?T(\"ay\",v.p2r(v.r2p(e.ay)+r)):T(\"ay\",e.ay+r),xt(t,r);else{if(a)return;var i,o;if(s)i=s.p2r(s.r2p(e.x)+t);else{var l=e._xsize/b.w,c=e.x+(e._xshift-e.xshift)/b.w-l/2;i=p.align(c+t/b.w,l,0,1,e.xanchor)}if(v)o=v.p2r(v.r2p(e.y)+r);else{var u=e._ysize/b.h,h=e.y-(e._yshift+e.yshift)/b.h-u/2;o=p.align(h-r/b.h,u,0,1,e.yanchor)}T(\"x\",i),T(\"y\",o),s&&v||(n=p.getCursor(s?.5:i,v?.5:o,e.xanchor,e.yanchor))}L.attr({transform:\"translate(\"+t+\",\"+r+\")\"+yt}),f(z,n)},clickFn:function(r,n){e.captureevents&&t.emit(\"plotly_clickannotation\",q(n))},doneFn:function(){f(z),i.call(\"_guiRelayout\",t,A());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}else z.remove()}}e.exports={draw:function(t){var e=t._fullLayout;e._infolayer.selectAll(\".annotation\").remove();for(var r=0;r<e.annotations.length;r++)e.annotations[r].visible&&v(t,r);return a.previousPromises(t)},drawOne:v,drawRaw:m}},{\"../../lib\":719,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/axes\":767,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"../fx\":632,\"./draw_arrow_head\":583,d3:163}],583:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\"),a=t(\"./arrow_paths\");e.exports=function(t,e,r){var o,s,l,c,u=t.node(),h=a[r.arrowhead||0],f=a[r.startarrowhead||0],p=(r.arrowwidth||1)*(r.arrowsize||1),d=(r.arrowwidth||1)*(r.startarrowsize||1),g=e.indexOf(\"start\")>=0,v=e.indexOf(\"end\")>=0,m=h.backoff*p+r.standoff,y=f.backoff*d+r.startstandoff;if(\"line\"===u.nodeName){o={x:+t.attr(\"x1\"),y:+t.attr(\"y1\")},s={x:+t.attr(\"x2\"),y:+t.attr(\"y2\")};var x=o.x-s.x,b=o.y-s.y;if(c=(l=Math.atan2(b,x))+Math.PI,m&&y&&m+y>Math.sqrt(x*x+b*b))return void P();if(m){if(m*m>x*x+b*b)return void P();var _=m*Math.cos(l),w=m*Math.sin(l);s.x+=_,s.y+=w,t.attr({x2:s.x,y2:s.y})}if(y){if(y*y>x*x+b*b)return void P();var k=y*Math.cos(l),T=y*Math.sin(l);o.x-=k,o.y-=T,t.attr({x1:o.x,y1:o.y})}}else if(\"path\"===u.nodeName){var A=u.getTotalLength(),M=\"\";if(A<m+y)return void P();var S=u.getPointAtLength(0),E=u.getPointAtLength(.1);l=Math.atan2(S.y-E.y,S.x-E.x),o=u.getPointAtLength(Math.min(y,A)),M=\"0px,\"+y+\"px,\";var C=u.getPointAtLength(A),L=u.getPointAtLength(A-.1);c=Math.atan2(C.y-L.y,C.x-L.x),s=u.getPointAtLength(Math.max(0,A-m)),M+=A-(M?y+m:m)+\"px,\"+A+\"px\",t.style(\"stroke-dasharray\",M)}function P(){t.style(\"stroke-dasharray\",\"0px,100px\")}function O(e,a,o,s){e.path&&(e.noRotate&&(o=0),n.select(u.parentNode).append(\"path\").attr({class:t.attr(\"class\"),d:e.path,transform:\"translate(\"+a.x+\",\"+a.y+\")\"+(o?\"rotate(\"+180*o/Math.PI+\")\":\"\")+\"scale(\"+s+\")\"}).style({fill:i.rgb(r.arrowcolor),\"stroke-width\":0}))}g&&O(f,o,l,d),v&&O(h,s,c,p)}},{\"../color\":593,\"./arrow_paths\":575,d3:163}],584:[function(t,e,r){\"use strict\";var n=t(\"./draw\"),i=t(\"./click\");e.exports={moduleType:\"component\",name:\"annotations\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"annotations\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne,drawRaw:n.drawRaw,hasClickToShow:i.hasClickToShow,onClick:i.onClick,convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":777,\"./attributes\":576,\"./calc_autorange\":577,\"./click\":578,\"./convert_coords\":580,\"./defaults\":581,\"./draw\":582}],585:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"../../plot_api/plot_template\").templatedArray;e.exports=i(a(\"annotation\",{visible:n.visible,x:{valType:\"any\"},y:{valType:\"any\"},z:{valType:\"any\"},ax:{valType:\"number\"},ay:{valType:\"number\"},xanchor:n.xanchor,xshift:n.xshift,yanchor:n.yanchor,yshift:n.yshift,text:n.text,textangle:n.textangle,font:n.font,width:n.width,height:n.height,opacity:n.opacity,align:n.align,valign:n.valign,bgcolor:n.bgcolor,bordercolor:n.bordercolor,borderpad:n.borderpad,borderwidth:n.borderwidth,showarrow:n.showarrow,arrowcolor:n.arrowcolor,arrowhead:n.arrowhead,startarrowhead:n.startarrowhead,arrowside:n.arrowside,arrowsize:n.arrowsize,startarrowsize:n.startarrowsize,arrowwidth:n.arrowwidth,standoff:n.standoff,startstandoff:n.startstandoff,hovertext:n.hovertext,hoverlabel:n.hoverlabel,captureevents:n.captureevents}),\"calc\",\"from-root\")},{\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../annotations/attributes\":576}],586:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\");function a(t,e){var r=e.fullSceneLayout.domain,a=e.fullLayout._size,o={pdata:null,type:\"linear\",autorange:!1,range:[-1/0,1/0]};t._xa={},n.extendFlat(t._xa,o),i.setConvert(t._xa),t._xa._offset=a.l+r.x[0]*a.w,t._xa.l2p=function(){return.5*(1+t._pdata[0]/t._pdata[3])*a.w*(r.x[1]-r.x[0])},t._ya={},n.extendFlat(t._ya,o),i.setConvert(t._ya),t._ya._offset=a.t+(1-r.y[1])*a.h,t._ya.l2p=function(){return.5*(1-t._pdata[1]/t._pdata[3])*a.h*(r.y[1]-r.y[0])}}e.exports=function(t){for(var e=t.fullSceneLayout.annotations,r=0;r<e.length;r++)a(e[r],t);t.fullLayout._infolayer.selectAll(\".annotation-\"+t.id).remove()}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767}],587:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"../annotations/common_defaults\"),s=t(\"./attributes\");function l(t,e,r,a){function l(r,i){return n.coerce(t,e,s,r,i)}function c(t){var n=t+\"axis\",a={_fullLayout:{}};return a._fullLayout[n]=r[n],i.coercePosition(e,a,l,t,t,.5)}l(\"visible\")&&(o(t,e,a.fullLayout,l),c(\"x\"),c(\"y\"),c(\"z\"),n.noneOrAll(t,e,[\"x\",\"y\",\"z\"]),e.xref=\"x\",e.yref=\"y\",e.zref=\"z\",l(\"xanchor\"),l(\"yanchor\"),l(\"xshift\"),l(\"yshift\"),e.showarrow&&(e.axref=\"pixel\",e.ayref=\"pixel\",l(\"ax\",-10),l(\"ay\",-30),n.noneOrAll(t,e,[\"ax\",\"ay\"])))}e.exports=function(t,e,r){a(t,e,{name:\"annotations\",handleItemDefaults:l,fullLayout:r.fullLayout})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"../annotations/common_defaults\":579,\"./attributes\":585}],588:[function(t,e,r){\"use strict\";var n=t(\"../annotations/draw\").drawRaw,i=t(\"../../plots/gl3d/project\"),a=[\"x\",\"y\",\"z\"];e.exports=function(t){for(var e=t.fullSceneLayout,r=t.dataScale,o=e.annotations,s=0;s<o.length;s++){for(var l=o[s],c=!1,u=0;u<3;u++){var h=a[u],f=l[h],p=e[h+\"axis\"].r2fraction(f);if(p<0||p>1){c=!0;break}}c?t.fullLayout._infolayer.select(\".annotation-\"+t.id+'[data-index=\"'+s+'\"]').remove():(l._pdata=i(t.glplot.cameraParams,[e.xaxis.r2l(l.x)*r[0],e.yaxis.r2l(l.y)*r[1],e.zaxis.r2l(l.z)*r[2]]),n(t.graphDiv,l,s,t.id,l._xa,l._ya))}}},{\"../../plots/gl3d/project\":816,\"../annotations/draw\":582}],589:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports={moduleType:\"component\",name:\"annotations3d\",schema:{subplots:{scene:{annotations:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),includeBasePlot:function(t,e){var r=n.subplotsRegistry.gl3d;if(!r)return;for(var a=r.attrRegex,o=Object.keys(t),s=0;s<o.length;s++){var l=o[s];a.test(l)&&(t[l].annotations||[]).length&&(i.pushUnique(e._basePlotModules,r),i.pushUnique(e._subplots.gl3d,l))}},convert:t(\"./convert\"),draw:t(\"./draw\")}},{\"../../lib\":719,\"../../registry\":847,\"./attributes\":585,\"./convert\":586,\"./defaults\":587,\"./draw\":588}],590:[function(t,e,r){\"use strict\";e.exports=t(\"world-calendars/dist/main\"),t(\"world-calendars/dist/plus\"),t(\"world-calendars/dist/calendars/chinese\"),t(\"world-calendars/dist/calendars/coptic\"),t(\"world-calendars/dist/calendars/discworld\"),t(\"world-calendars/dist/calendars/ethiopian\"),t(\"world-calendars/dist/calendars/hebrew\"),t(\"world-calendars/dist/calendars/islamic\"),t(\"world-calendars/dist/calendars/julian\"),t(\"world-calendars/dist/calendars/mayan\"),t(\"world-calendars/dist/calendars/nanakshahi\"),t(\"world-calendars/dist/calendars/nepali\"),t(\"world-calendars/dist/calendars/persian\"),t(\"world-calendars/dist/calendars/taiwan\"),t(\"world-calendars/dist/calendars/thai\"),t(\"world-calendars/dist/calendars/ummalqura\")},{\"world-calendars/dist/calendars/chinese\":557,\"world-calendars/dist/calendars/coptic\":558,\"world-calendars/dist/calendars/discworld\":559,\"world-calendars/dist/calendars/ethiopian\":560,\"world-calendars/dist/calendars/hebrew\":561,\"world-calendars/dist/calendars/islamic\":562,\"world-calendars/dist/calendars/julian\":563,\"world-calendars/dist/calendars/mayan\":564,\"world-calendars/dist/calendars/nanakshahi\":565,\"world-calendars/dist/calendars/nepali\":566,\"world-calendars/dist/calendars/persian\":567,\"world-calendars/dist/calendars/taiwan\":568,\"world-calendars/dist/calendars/thai\":569,\"world-calendars/dist/calendars/ummalqura\":570,\"world-calendars/dist/main\":571,\"world-calendars/dist/plus\":572}],591:[function(t,e,r){\"use strict\";var n=t(\"./calendars\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\"),o=a.EPOCHJD,s=a.ONEDAY,l={valType:\"enumerated\",values:Object.keys(n.calendars),editType:\"calc\",dflt:\"gregorian\"},c=function(t,e,r,n){var a={};return a[r]=l,i.coerce(t,e,a,r,n)},u=\"##\",h={d:{0:\"dd\",\"-\":\"d\"},e:{0:\"d\",\"-\":\"d\"},a:{0:\"D\",\"-\":\"D\"},A:{0:\"DD\",\"-\":\"DD\"},j:{0:\"oo\",\"-\":\"o\"},W:{0:\"ww\",\"-\":\"w\"},m:{0:\"mm\",\"-\":\"m\"},b:{0:\"M\",\"-\":\"M\"},B:{0:\"MM\",\"-\":\"MM\"},y:{0:\"yy\",\"-\":\"yy\"},Y:{0:\"yyyy\",\"-\":\"yyyy\"},U:u,w:u,c:{0:\"D M d %X yyyy\",\"-\":\"D M d %X yyyy\"},x:{0:\"mm/dd/yyyy\",\"-\":\"mm/dd/yyyy\"}};var f={};function p(t){var e=f[t];return e||(e=f[t]=n.instance(t))}function d(t){return i.extendFlat({},l,{description:t})}function g(t){return\"Sets the calendar system to use with `\"+t+\"` date data.\"}var v={xcalendar:d(g(\"x\"))},m=i.extendFlat({},v,{ycalendar:d(g(\"y\"))}),y=i.extendFlat({},m,{zcalendar:d(g(\"z\"))}),x=d([\"Sets the calendar system to use for `range` and `tick0`\",\"if this is a date axis. This does not set the calendar for\",\"interpreting data on this axis, that's specified in the trace\",\"or via the global `layout.calendar`\"].join(\" \"));e.exports={moduleType:\"component\",name:\"calendars\",schema:{traces:{scatter:m,bar:m,box:m,heatmap:m,contour:m,histogram:m,histogram2d:m,histogram2dcontour:m,scatter3d:y,surface:y,mesh3d:y,scattergl:m,ohlc:v,candlestick:v},layout:{calendar:d([\"Sets the default calendar system to use for interpreting and\",\"displaying dates throughout the plot.\"].join(\" \"))},subplots:{xaxis:{calendar:x},yaxis:{calendar:x},scene:{xaxis:{calendar:x},yaxis:{calendar:x},zaxis:{calendar:x}},polar:{radialaxis:{calendar:x}}},transforms:{filter:{valuecalendar:d([\"Sets the calendar system to use for `value`, if it is a date.\"].join(\" \")),targetcalendar:d([\"Sets the calendar system to use for `target`, if it is an\",\"array of dates. If `target` is a string (eg *x*) we use the\",\"corresponding trace attribute (eg `xcalendar`) if it exists,\",\"even if `targetcalendar` is provided.\"].join(\" \"))}}},layoutAttributes:l,handleDefaults:c,handleTraceDefaults:function(t,e,r,n){for(var i=0;i<r.length;i++)c(t,e,r[i]+\"calendar\",n.calendar)},CANONICAL_SUNDAY:{chinese:\"2000-01-02\",coptic:\"2000-01-03\",discworld:\"2000-01-03\",ethiopian:\"2000-01-05\",hebrew:\"5000-01-01\",islamic:\"1000-01-02\",julian:\"2000-01-03\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-05\",nepali:\"2000-01-05\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-04\",thai:\"2000-01-04\",ummalqura:\"1400-01-06\"},CANONICAL_TICK:{chinese:\"2000-01-01\",coptic:\"2000-01-01\",discworld:\"2000-01-01\",ethiopian:\"2000-01-01\",hebrew:\"5000-01-01\",islamic:\"1000-01-01\",julian:\"2000-01-01\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-01\",nepali:\"2000-01-01\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-01\",thai:\"2000-01-01\",ummalqura:\"1400-01-01\"},DFLTRANGE:{chinese:[\"2000-01-01\",\"2001-01-01\"],coptic:[\"1700-01-01\",\"1701-01-01\"],discworld:[\"1800-01-01\",\"1801-01-01\"],ethiopian:[\"2000-01-01\",\"2001-01-01\"],hebrew:[\"5700-01-01\",\"5701-01-01\"],islamic:[\"1400-01-01\",\"1401-01-01\"],julian:[\"2000-01-01\",\"2001-01-01\"],mayan:[\"5200-01-01\",\"5201-01-01\"],nanakshahi:[\"0500-01-01\",\"0501-01-01\"],nepali:[\"2000-01-01\",\"2001-01-01\"],persian:[\"1400-01-01\",\"1401-01-01\"],jalali:[\"1400-01-01\",\"1401-01-01\"],taiwan:[\"0100-01-01\",\"0101-01-01\"],thai:[\"2500-01-01\",\"2501-01-01\"],ummalqura:[\"1400-01-01\",\"1401-01-01\"]},getCal:p,worldCalFmt:function(t,e,r){for(var n,i,a,l,c,f=Math.floor((e+.05)/s)+o,d=p(r).fromJD(f),g=0;-1!==(g=t.indexOf(\"%\",g));)\"0\"===(n=t.charAt(g+1))||\"-\"===n||\"_\"===n?(a=3,i=t.charAt(g+2),\"_\"===n&&(n=\"-\")):(i=n,n=\"0\",a=2),(l=h[i])?(c=l===u?u:d.formatDate(l[n]),t=t.substr(0,g)+c+t.substr(g+a),g+=c.length):g+=a;return t}}},{\"../../constants/numerical\":695,\"../../lib\":719,\"./calendars\":590}],592:[function(t,e,r){\"use strict\";r.defaults=[\"#1f77b4\",\"#ff7f0e\",\"#2ca02c\",\"#d62728\",\"#9467bd\",\"#8c564b\",\"#e377c2\",\"#7f7f7f\",\"#bcbd22\",\"#17becf\"],r.defaultLine=\"#444\",r.lightLine=\"#eee\",r.background=\"#fff\",r.borderLine=\"#BEC8D9\",r.lightFraction=1e3/11},{}],593:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i=t(\"fast-isnumeric\"),a=e.exports={},o=t(\"./attributes\");a.defaults=o.defaults;var s=a.defaultLine=o.defaultLine;a.lightLine=o.lightLine;var l=a.background=o.background;function c(t){if(i(t)||\"string\"!=typeof t)return t;var e=t.trim();if(\"rgb\"!==e.substr(0,3))return t;var r=e.match(/^rgba?\\s*\\(([^()]*)\\)$/);if(!r)return t;var n=r[1].trim().split(/\\s*[\\s,]\\s*/),a=\"a\"===e.charAt(3)&&4===n.length;if(!a&&3!==n.length)return t;for(var o=0;o<n.length;o++){if(!n[o].length)return t;if(n[o]=Number(n[o]),!(n[o]>=0))return t;if(3===o)n[o]>1&&(n[o]=1);else if(n[o]>=1)return t}var s=Math.round(255*n[0])+\", \"+Math.round(255*n[1])+\", \"+Math.round(255*n[2]);return a?\"rgba(\"+s+\", \"+n[3]+\")\":\"rgb(\"+s+\")\"}a.tinyRGB=function(t){var e=t.toRgb();return\"rgb(\"+Math.round(e.r)+\", \"+Math.round(e.g)+\", \"+Math.round(e.b)+\")\"},a.rgb=function(t){return a.tinyRGB(n(t))},a.opacity=function(t){return t?n(t).getAlpha():0},a.addOpacity=function(t,e){var r=n(t).toRgb();return\"rgba(\"+Math.round(r.r)+\", \"+Math.round(r.g)+\", \"+Math.round(r.b)+\", \"+e+\")\"},a.combine=function(t,e){var r=n(t).toRgb();if(1===r.a)return n(t).toRgbString();var i=n(e||l).toRgb(),a=1===i.a?i:{r:255*(1-i.a)+i.r*i.a,g:255*(1-i.a)+i.g*i.a,b:255*(1-i.a)+i.b*i.a},o={r:a.r*(1-r.a)+r.r*r.a,g:a.g*(1-r.a)+r.g*r.a,b:a.b*(1-r.a)+r.b*r.a};return n(o).toRgbString()},a.contrast=function(t,e,r){var i=n(t);return 1!==i.getAlpha()&&(i=n(a.combine(t,l))),(i.isDark()?e?i.lighten(e):l:r?i.darken(r):s).toString()},a.stroke=function(t,e){var r=n(e);t.style({stroke:a.tinyRGB(r),\"stroke-opacity\":r.getAlpha()})},a.fill=function(t,e){var r=n(e);t.style({fill:a.tinyRGB(r),\"fill-opacity\":r.getAlpha()})},a.clean=function(t){if(t&&\"object\"==typeof t){var e,r,n,i,o=Object.keys(t);for(e=0;e<o.length;e++)if(i=t[n=o[e]],\"color\"===n.substr(n.length-5))if(Array.isArray(i))for(r=0;r<i.length;r++)i[r]=c(i[r]);else t[n]=c(i);else if(\"colorscale\"===n.substr(n.length-10)&&Array.isArray(i))for(r=0;r<i.length;r++)Array.isArray(i[r])&&(i[r][1]=c(i[r][1]));else if(Array.isArray(i)){var s=i[0];if(!Array.isArray(s)&&s&&\"object\"==typeof s)for(r=0;r<i.length;r++)a.clean(i[r])}else i&&\"object\"==typeof i&&a.clean(i)}}},{\"./attributes\":592,\"fast-isnumeric\":225,tinycolor2:537}],594:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/layout_attributes\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll;e.exports=o({thicknessmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"pixels\"},thickness:{valType:\"number\",min:0,dflt:30},lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",dflt:1.02,min:-2,max:3},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},xpad:{valType:\"number\",min:0,dflt:10},y:{valType:\"number\",dflt:.5,min:-2,max:3},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\"},ypad:{valType:\"number\",min:0,dflt:10},outlinecolor:n.linecolor,outlinewidth:n.linewidth,bordercolor:n.linecolor,borderwidth:{valType:\"number\",min:0,dflt:0},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\"},tickmode:n.tickmode,nticks:n.nticks,tick0:n.tick0,dtick:n.dtick,tickvals:n.tickvals,ticktext:n.ticktext,ticks:a({},n.ticks,{dflt:\"\"}),ticklen:n.ticklen,tickwidth:n.tickwidth,tickcolor:n.tickcolor,showticklabels:n.showticklabels,tickfont:i({}),tickangle:n.tickangle,tickformat:n.tickformat,tickformatstops:n.tickformatstops,tickprefix:n.tickprefix,showtickprefix:n.showtickprefix,ticksuffix:n.ticksuffix,showticksuffix:n.showticksuffix,separatethousands:n.separatethousands,exponentformat:n.exponentformat,showexponent:n.showexponent,title:{text:{valType:\"string\"},font:i({}),side:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}},_deprecated:{title:{valType:\"string\"},titlefont:i({}),titleside:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}}},\"colorbars\",\"from-root\")},{\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/font_attributes\":793}],595:[function(t,e,r){\"use strict\";e.exports={cn:{colorbar:\"colorbar\",cbbg:\"cbbg\",cbfill:\"cbfill\",cbfills:\"cbfills\",cbline:\"cbline\",cblines:\"cblines\",cbaxis:\"cbaxis\",cbtitleunshift:\"cbtitleunshift\",cbtitle:\"cbtitle\",cboutline:\"cboutline\",crisp:\"crisp\",jsPlaceholder:\"js-placeholder\"}}},{}],596:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/tick_value_defaults\"),o=t(\"../../plots/cartesian/tick_mark_defaults\"),s=t(\"../../plots/cartesian/tick_label_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r){var c=i.newContainer(e,\"colorbar\"),u=t.colorbar||{};function h(t,e){return n.coerce(u,c,l,t,e)}var f=h(\"thicknessmode\");h(\"thickness\",\"fraction\"===f?30/(r.width-r.margin.l-r.margin.r):30);var p=h(\"lenmode\");h(\"len\",\"fraction\"===p?1:r.height-r.margin.t-r.margin.b),h(\"x\"),h(\"xanchor\"),h(\"xpad\"),h(\"y\"),h(\"yanchor\"),h(\"ypad\"),n.noneOrAll(u,c,[\"x\",\"y\"]),h(\"outlinecolor\"),h(\"outlinewidth\"),h(\"bordercolor\"),h(\"borderwidth\"),h(\"bgcolor\"),a(u,c,h,\"linear\");var d={outerTicks:!1,font:r.font};s(u,c,h,\"linear\",d),o(u,c,h,\"linear\",d),h(\"title.text\",r._dfltTitle.colorbar),n.coerceFont(h,\"title.font\",r.font),h(\"title.side\")}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/tick_label_defaults\":786,\"../../plots/cartesian/tick_mark_defaults\":787,\"../../plots/cartesian/tick_value_defaults\":788,\"./attributes\":594}],597:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../dragelement\"),c=t(\"../../lib\"),u=t(\"../../lib/extend\").extendFlat,h=t(\"../../lib/setcursor\"),f=t(\"../drawing\"),p=t(\"../color\"),d=t(\"../titles\"),g=t(\"../../lib/svg_text_utils\"),v=t(\"../colorscale/helpers\").flipScale,m=t(\"../../plots/cartesian/axis_defaults\"),y=t(\"../../plots/cartesian/position_defaults\"),x=t(\"../../plots/cartesian/layout_attributes\"),b=t(\"../../constants/alignment\"),_=b.LINE_SPACING,w=b.FROM_TL,k=b.FROM_BR,T=t(\"./constants\").cn;e.exports={draw:function(t){var e=t._fullLayout._infolayer.selectAll(\"g.\"+T.colorbar).data(function(t){var e,r,n,i,a=t._fullLayout,o=t.calcdata,s=[];function l(t){return u(t,{_fillcolor:null,_line:{color:null,width:null,dash:null},_levels:{start:null,end:null,size:null},_filllevels:null,_fillgradient:null,_zrange:null})}function c(){\"function\"==typeof i.calc?i.calc(t,n,e):(e._fillgradient=r.reversescale?v(r.colorscale):r.colorscale,e._zrange=[r[i.min],r[i.max]])}for(var h=0;h<o.length;h++){var f=o[h],p=(n=f[0].trace)._module.colorbar;if(!0===n.visible&&p)for(var d=Array.isArray(p),g=d?p:[p],m=0;m<g.length;m++){var y=(i=g[m]).container;(r=y?n[y]:n)&&r.showscale&&((e=l(r.colorbar))._id=\"cb\"+n.uid+(d&&y?\"-\"+y:\"\"),e._traceIndex=n.index,e._propPrefix=(y?y+\".\":\"\")+\"colorbar.\",e._meta=n._meta,c(),s.push(e))}}for(var x in a._colorAxes)if((r=a[x]).showscale){var b=a._colorAxes[x];(e=l(r.colorbar))._id=\"cb\"+x,e._propPrefix=x+\".colorbar.\",e._meta=a._meta,i={min:\"cmin\",max:\"cmax\"},\"heatmap\"!==b[0]&&(n=b[1],i.calc=n._module.colorbar.calc),c(),s.push(e)}return s}(t),function(t){return t._id});e.enter().append(\"g\").attr(\"class\",function(t){return t._id}).classed(T.colorbar,!0),e.each(function(e){var r=n.select(this);c.ensureSingle(r,\"rect\",T.cbbg),c.ensureSingle(r,\"g\",T.cbfills),c.ensureSingle(r,\"g\",T.cblines),c.ensureSingle(r,\"g\",T.cbaxis,function(t){t.classed(T.crisp,!0)}),c.ensureSingle(r,\"g\",T.cbtitleunshift,function(t){t.append(\"g\").classed(T.cbtitle,!0)}),c.ensureSingle(r,\"rect\",T.cboutline);var v=function(t,e,r){var o=r._fullLayout,l=o._size,h=e._fillcolor,v=e._line,b=e.title,A=b.side,M=e._zrange||n.extent((\"function\"==typeof h?h:v.color).domain()),S=\"function\"==typeof v.color?v.color:function(){return v.color},E=\"function\"==typeof h?h:function(){return h},C=e._levels,L=function(t,e,r){var n,i,a=e._levels,o=[],s=[],l=a.end+a.size/100,c=a.size,u=1.001*r[0]-.001*r[1],h=1.001*r[1]-.001*r[0];for(i=0;i<1e5&&(n=a.start+i*c,!(c>0?n>=l:n<=l));i++)n>u&&n<h&&o.push(n);if(e._fillgradient)s=[0];else if(\"function\"==typeof e._fillcolor){var f=e._filllevels;if(f)for(l=f.end+f.size/100,c=f.size,i=0;i<1e5&&(n=f.start+i*c,!(c>0?n>=l:n<=l));i++)n>r[0]&&n<r[1]&&s.push(n);else(s=o.map(function(t){return t-a.size/2})).push(s[s.length-1]+a.size)}else e._fillcolor&&\"string\"==typeof e._fillcolor&&(s=[0]);return a.size<0&&(o.reverse(),s.reverse()),{line:o,fill:s}}(0,e,M),P=L.fill,O=L.line,z=Math.round(e.thickness*(\"fraction\"===e.thicknessmode?l.w:1)),I=z/l.w,D=Math.round(e.len*(\"fraction\"===e.lenmode?l.h:1)),R=D/l.h,F=e.xpad/l.w,B=(e.borderwidth+e.outlinewidth)/2,N=e.ypad/l.h,j=Math.round(e.x*l.w+e.xpad),U=e.x-I*({middle:.5,right:1}[e.xanchor]||0),V=e.y+R*(({top:-.5,bottom:.5}[e.yanchor]||0)-.5),q=Math.round(l.h*(1-V)),H=q-D;e._lenFrac=R,e._thickFrac=I,e._xLeftFrac=U,e._yBottomFrac=V;var G=function(t,e,r){var n=t._fullLayout,i={type:\"linear\",range:r,tickmode:e.tickmode,nticks:e.nticks,tick0:e.tick0,dtick:e.dtick,tickvals:e.tickvals,ticktext:e.ticktext,ticks:e.ticks,ticklen:e.ticklen,tickwidth:e.tickwidth,tickcolor:e.tickcolor,showticklabels:e.showticklabels,tickfont:e.tickfont,tickangle:e.tickangle,tickformat:e.tickformat,exponentformat:e.exponentformat,separatethousands:e.separatethousands,showexponent:e.showexponent,showtickprefix:e.showtickprefix,tickprefix:e.tickprefix,showticksuffix:e.showticksuffix,ticksuffix:e.ticksuffix,title:e.title,showline:!0,anchor:\"free\",side:\"right\",position:1},a={type:\"linear\",_id:\"y\"+e._id},o={letter:\"y\",font:n.font,noHover:!0,noTickson:!0,calendar:n.calendar};function s(t,e){return c.coerce(i,a,x,t,e)}return m(i,a,s,o,n),y(i,a,s,o),a}(r,e,M);if(G.position=e.x+F+I,-1!==[\"top\",\"bottom\"].indexOf(A)&&(G.title.side=A,G.titlex=e.x+F,G.titley=V+(\"top\"===b.side?R-N:N)),v.color&&\"auto\"===e.tickmode){G.tickmode=\"linear\",G.tick0=C.start;var Y=C.size,W=c.constrain((q-H)/50,4,15)+1,X=(M[1]-M[0])/((e.nticks||W)*Y);if(X>1){var Z=Math.pow(10,Math.floor(Math.log(X)/Math.LN10));Y*=Z*c.roundUp(X/Z,[2,5,10]),(Math.abs(C.start)/C.size+1e-6)%1<2e-6&&(G.tick0=0)}G.dtick=Y}G.domain=[V+N,V+R-N],G.setScale(),t.attr(\"transform\",\"translate(\"+Math.round(l.l)+\",\"+Math.round(l.t)+\")\");var J,K=t.select(\".\"+T.cbtitleunshift).attr(\"transform\",\"translate(-\"+Math.round(l.l)+\",-\"+Math.round(l.t)+\")\"),$=t.select(\".\"+T.cbaxis),Q=0;function tt(n,i){var a={propContainer:G,propName:e._propPrefix+\"title\",traceIndex:e._traceIndex,_meta:e._meta,placeholder:o._dfltTitle.colorbar,containerGroup:t.select(\".\"+T.cbtitle)},s=\"h\"===n.charAt(0)?n.substr(1):\"h\"+n;t.selectAll(\".\"+s+\",.\"+s+\"-math-group\").remove(),d.draw(r,n,u(a,i||{}))}return c.syncOrAsync([a.previousPromises,function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var t,r=l.l+(e.x+F)*l.w,n=G.title.font.size;t=\"top\"===A?(1-(V+R-N))*l.h+l.t+3+.75*n:(1-(V+N))*l.h+l.t-3-.25*n,tt(G._id+\"title\",{attributes:{x:r,y:t,\"text-anchor\":\"start\"}})}},function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var a=t.select(\".\"+T.cbtitle),o=a.select(\"text\"),u=[-e.outlinewidth/2,e.outlinewidth/2],h=a.select(\".h\"+G._id+\"title-math-group\").node(),p=15.6;if(o.node()&&(p=parseInt(o.node().style.fontSize,10)*_),h?(Q=f.bBox(h).height)>p&&(u[1]-=(Q-p)/2):o.node()&&!o.classed(T.jsPlaceholder)&&(Q=f.bBox(o.node()).height),Q){if(Q+=5,\"top\"===A)G.domain[1]-=Q/l.h,u[1]*=-1;else{G.domain[0]+=Q/l.h;var d=g.lineCount(o);u[1]+=(1-d)*p}a.attr(\"transform\",\"translate(\"+u+\")\"),G.setScale()}}t.selectAll(\".\"+T.cbfills+\",.\"+T.cblines).attr(\"transform\",\"translate(0,\"+Math.round(l.h*(1-G.domain[1]))+\")\"),$.attr(\"transform\",\"translate(0,\"+Math.round(-l.t)+\")\");var m=t.select(\".\"+T.cbfills).selectAll(\"rect.\"+T.cbfill).data(P);m.enter().append(\"rect\").classed(T.cbfill,!0).style(\"stroke\",\"none\"),m.exit().remove();var y=M.map(G.c2p).map(Math.round).sort(function(t,e){return t-e});m.each(function(t,a){var o=[0===a?M[0]:(P[a]+P[a-1])/2,a===P.length-1?M[1]:(P[a]+P[a+1])/2].map(G.c2p).map(Math.round);o[1]=c.constrain(o[1]+(o[1]>o[0])?1:-1,y[0],y[1]);var s=n.select(this).attr({x:j,width:Math.max(z,2),y:n.min(o),height:Math.max(n.max(o)-n.min(o),2)});if(e._fillgradient)f.gradient(s,r,e._id,\"vertical\",e._fillgradient,\"fill\");else{var l=E(t).replace(\"e-\",\"\");s.attr(\"fill\",i(l).toHexString())}});var x=t.select(\".\"+T.cblines).selectAll(\"path.\"+T.cbline).data(v.color&&v.width?O:[]);x.enter().append(\"path\").classed(T.cbline,!0),x.exit().remove(),x.each(function(t){n.select(this).attr(\"d\",\"M\"+j+\",\"+(Math.round(G.c2p(t))+v.width/2%1)+\"h\"+z).call(f.lineGroupStyle,v.width,S(t),v.dash)}),$.selectAll(\"g.\"+G._id+\"tick,path\").remove();var b=j+z+(e.outlinewidth||0)/2-(\"outside\"===e.ticks?1:0),w=s.calcTicks(G),k=s.makeTransFn(G),C=s.getTickSigns(G)[2];return s.drawTicks(r,G,{vals:\"inside\"===G.ticks?s.clipEnds(G,w):w,layer:$,path:s.makeTickPath(G,b,C),transFn:k}),s.drawLabels(r,G,{vals:w,layer:$,transFn:k,labelFns:s.makeLabelFns(G,b)})},function(){if(-1===[\"top\",\"bottom\"].indexOf(A)){var t=G.title.font.size,e=G._offset+G._length/2,i=l.l+(G.position||0)*l.w+(\"right\"===G.side?10+t*(G.showticklabels?1:.5):-10-t*(G.showticklabels?.5:0));tt(\"h\"+G._id+\"title\",{avoid:{selection:n.select(r).selectAll(\"g.\"+G._id+\"tick\"),side:A,offsetLeft:l.l,offsetTop:0,maxShift:o.width},attributes:{x:i,y:e,\"text-anchor\":\"middle\"},transform:{rotate:\"-90\",offset:0}})}},a.previousPromises,function(){var n=z+e.outlinewidth/2+f.bBox($.node()).width;if((J=K.select(\"text\")).node()&&!J.classed(T.jsPlaceholder)){var i,o=K.select(\".h\"+G._id+\"title-math-group\").node();i=o&&-1!==[\"top\",\"bottom\"].indexOf(A)?f.bBox(o).width:f.bBox(K.node()).right-j-l.l,n=Math.max(n,i)}var s=2*e.xpad+n+e.borderwidth+e.outlinewidth/2,c=q-H;t.select(\".\"+T.cbbg).attr({x:j-e.xpad-(e.borderwidth+e.outlinewidth)/2,y:H-B,width:Math.max(s,2),height:Math.max(c+2*B,2)}).call(p.fill,e.bgcolor).call(p.stroke,e.bordercolor).style(\"stroke-width\",e.borderwidth),t.selectAll(\".\"+T.cboutline).attr({x:j,y:H+e.ypad+(\"top\"===A?Q:0),width:Math.max(z,2),height:Math.max(c-2*e.ypad-Q,2)}).call(p.stroke,e.outlinecolor).style({fill:\"none\",\"stroke-width\":e.outlinewidth});var u=({center:.5,right:1}[e.xanchor]||0)*s;t.attr(\"transform\",\"translate(\"+(l.l-u)+\",\"+l.t+\")\");var h={},d=w[e.yanchor],g=k[e.yanchor];\"pixels\"===e.lenmode?(h.y=e.y,h.t=c*d,h.b=c*g):(h.t=h.b=0,h.yt=e.y+e.len*d,h.yb=e.y-e.len*g);var v=w[e.xanchor],m=k[e.xanchor];if(\"pixels\"===e.thicknessmode)h.x=e.x,h.l=s*v,h.r=s*m;else{var y=s-z;h.l=y*v,h.r=y*m,h.xl=e.x-e.thickness*v,h.xr=e.x+e.thickness*m}a.autoMargin(r,e._id,h)}],r)}(r,e,t);v&&v.then&&(t._promises||[]).push(v),t._context.edits.colorbarPosition&&function(t,e,r){var n,i,a,s=r._fullLayout._size;l.init({element:t.node(),gd:r,prepFn:function(){n=t.attr(\"transform\"),h(t)},moveFn:function(r,o){t.attr(\"transform\",n+\" translate(\"+r+\",\"+o+\")\"),i=l.align(e._xLeftFrac+r/s.w,e._thickFrac,0,1,e.xanchor),a=l.align(e._yBottomFrac-o/s.h,e._lenFrac,0,1,e.yanchor);var c=l.getCursor(i,a,e.xanchor,e.yanchor);h(t,c)},doneFn:function(){if(h(t),void 0!==i&&void 0!==a){var n={};n[e._propPrefix+\"x\"]=i,n[e._propPrefix+\"y\"]=a,void 0!==e._traceIndex?o.call(\"_guiRestyle\",r,n,e._traceIndex):o.call(\"_guiRelayout\",r,n)}}})}(r,e,t)}),e.exit().each(function(e){a.autoMargin(t,e._id)}).remove(),e.order()}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/extend\":710,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_defaults\":769,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/cartesian/position_defaults\":782,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../colorscale/helpers\":604,\"../dragelement\":611,\"../drawing\":614,\"../titles\":681,\"./constants\":595,d3:163,tinycolor2:537}],598:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t){return n.isPlainObject(t.colorbar)}},{\"../../lib\":719}],599:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"colorbar\",attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),draw:t(\"./draw\").draw,hasColorbar:t(\"./has_colorbar\")}},{\"./attributes\":594,\"./defaults\":596,\"./draw\":597,\"./has_colorbar\":598}],600:[function(t,e,r){\"use strict\";var n=t(\"../colorbar/attributes\"),i=t(\"../../lib/regex\").counter,a=t(\"./scales.js\").scales;Object.keys(a);function o(t){return\"`\"+t+\"`\"}e.exports=function(t,e){t=t||\"\";var r,s=(e=e||{}).cLetter||\"c\",l=(\"onlyIfNumerical\"in e?e.onlyIfNumerical:Boolean(t),\"noScale\"in e?e.noScale:\"marker.line\"===t),c=\"showScaleDflt\"in e?e.showScaleDflt:\"z\"===s,u=\"string\"==typeof e.colorscaleDflt?a[e.colorscaleDflt]:null,h=e.editTypeOverride||\"\",f=t?t+\".\":\"\";\"colorAttr\"in e?(r=e.colorAttr,e.colorAttr):o(f+(r={z:\"z\",c:\"color\"}[s]));var p=s+\"auto\",d=s+\"min\",g=s+\"max\",v=s+\"mid\",m=(o(f+p),o(f+d),o(f+g),{});m[d]=m[g]=void 0;var y={};y[p]=!1;var x={};return\"color\"===r&&(x.color={valType:\"color\",arrayOk:!0,editType:h||\"style\"},e.anim&&(x.color.anim=!0)),x[p]={valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:m},x[d]={valType:\"number\",dflt:null,editType:h||\"plot\",impliedEdits:y},x[g]={valType:\"number\",dflt:null,editType:h||\"plot\",impliedEdits:y},x[v]={valType:\"number\",dflt:null,editType:\"calc\",impliedEdits:m},x.colorscale={valType:\"colorscale\",editType:\"calc\",dflt:u,impliedEdits:{autocolorscale:!1}},x.autocolorscale={valType:\"boolean\",dflt:!1!==e.autoColorDflt,editType:\"calc\",impliedEdits:{colorscale:void 0}},x.reversescale={valType:\"boolean\",dflt:!1,editType:\"plot\"},l||(x.showscale={valType:\"boolean\",dflt:c,editType:\"calc\"},x.colorbar=n),e.noColorAxis||(x.coloraxis={valType:\"subplotid\",regex:i(\"coloraxis\"),dflt:null,editType:\"calc\"}),x}},{\"../../lib/regex\":735,\"../colorbar/attributes\":594,\"./scales.js\":608}],601:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"./helpers\").extractOpts;e.exports=function(t,e,r){var o,s=t._fullLayout,l=r.vals,c=r.containerStr,u=c?i.nestedProperty(e,c).get():e,h=a(u),f=!1!==h.auto,p=h.min,d=h.max,g=h.mid,v=function(){return i.aggNums(Math.min,null,l)},m=function(){return i.aggNums(Math.max,null,l)};(void 0===p?p=v():f&&(p=u._colorAx&&n(p)?Math.min(p,v()):v()),void 0===d?d=m():f&&(d=u._colorAx&&n(d)?Math.max(d,m()):m()),f&&void 0!==g&&(d-g>g-p?p=g-(d-g):d-g<g-p&&(d=g+(g-p))),p===d&&(p-=.5,d+=.5),h._sync(\"min\",p),h._sync(\"max\",d),h.autocolorscale)&&(o=p*d<0?s.colorscale.diverging:p>=0?s.colorscale.sequential:s.colorscale.sequentialminus,h._sync(\"colorscale\",o))}},{\"../../lib\":719,\"./helpers\":604,\"fast-isnumeric\":225}],602:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./helpers\").hasColorscale,a=t(\"./helpers\").extractOpts;e.exports=function(t,e){function r(t,e){var r=t[\"_\"+e];void 0!==r&&(t[e]=r)}function o(t,i){var o=i.container?n.nestedProperty(t,i.container).get():t;if(o)if(o.coloraxis)o._colorAx=e[o.coloraxis];else{var s=a(o),l=s.auto;(l||void 0===s.min)&&r(o,i.min),(l||void 0===s.max)&&r(o,i.max),s.autocolorscale&&r(o,\"colorscale\")}}for(var s=0;s<t.length;s++){var l=t[s],c=l._module.colorbar;if(c)if(Array.isArray(c))for(var u=0;u<c.length;u++)o(l,c[u]);else o(l,c);i(l,\"marker.line\")&&o(l,{container:\"marker.line\",min:\"cmin\",max:\"cmax\"})}for(var h in e._colorAxes)o(e[h],{min:\"cmin\",max:\"cmax\"})}},{\"../../lib\":719,\"./helpers\":604}],603:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../colorbar/has_colorbar\"),o=t(\"../colorbar/defaults\"),s=t(\"./scales\").isValid,l=t(\"../../registry\").traceIs;function c(t,e){var r=e.slice(0,e.length-1);return e?i.nestedProperty(t,r).get()||{}:t}e.exports=function t(e,r,u,h,f){var p=f.prefix,d=f.cLetter,g=\"_module\"in r,v=c(e,p),m=c(r,p),y=c(r._template||{},p)||{},x=function(){return delete e.coloraxis,delete r.coloraxis,t(e,r,u,h,f)};if(g){var b=u._colorAxes||{},_=h(p+\"coloraxis\");if(_){var w=l(r,\"contour\")&&i.nestedProperty(r,\"contours.coloring\").get()||\"heatmap\",k=b[_];return void(k?(k[2].push(x),k[0]!==w&&(k[0]=!1,i.warn([\"Ignoring coloraxis:\",_,\"setting\",\"as it is linked to incompatible colorscales.\"].join(\" \")))):b[_]=[w,r,[x]])}}var T=v[d+\"min\"],A=v[d+\"max\"],M=n(T)&&n(A)&&T<A;h(p+d+\"auto\",!M)?h(p+d+\"mid\"):(h(p+d+\"min\"),h(p+d+\"max\"));var S,E,C=v.colorscale,L=y.colorscale;(void 0!==C&&(S=!s(C)),void 0!==L&&(S=!s(L)),h(p+\"autocolorscale\",S),h(p+\"colorscale\"),h(p+\"reversescale\"),\"marker.line.\"!==p)&&(p&&g&&(E=a(v)),h(p+\"showscale\",E)&&o(v,m,u))}},{\"../../lib\":719,\"../../registry\":847,\"../colorbar/defaults\":596,\"../colorbar/has_colorbar\":598,\"./scales\":608,\"fast-isnumeric\":225}],604:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"fast-isnumeric\"),o=t(\"../../lib\"),s=t(\"../color\"),l=t(\"./scales\").isValid;var c=[\"showscale\",\"autocolorscale\",\"colorscale\",\"reversescale\",\"colorbar\"],u=[\"min\",\"max\",\"mid\",\"auto\"];function h(t){var e,r,n,i=t._colorAx,a=i||t,o={};for(r=0;r<c.length;r++)o[n=c[r]]=a[n];if(i)for(e=\"c\",r=0;r<u.length;r++)o[n=u[r]]=a[\"c\"+n];else{var s;for(r=0;r<u.length;r++)(s=\"c\"+(n=u[r]))in a?o[n]=a[s]:(s=\"z\"+n)in a&&(o[n]=a[s]);e=s.charAt(0)}return o._sync=function(t,r){var n=-1!==u.indexOf(t)?e+t:t;a[n]=a[\"_\"+n]=r},o}function f(t){for(var e=h(t),r=e.min,n=e.max,i=e.reversescale?p(e.colorscale):e.colorscale,a=i.length,o=new Array(a),s=new Array(a),l=0;l<a;l++){var c=i[l];o[l]=r+c[0]*(n-r),s[l]=c[1]}return{domain:o,range:s}}function p(t){for(var e=t.length,r=new Array(e),n=e-1,i=0;n>=0;n--,i++){var a=t[n];r[i]=[1-a[0],a[1]]}return r}function d(t,e){e=e||{};for(var r=t.domain,o=t.range,l=o.length,c=new Array(l),u=0;u<l;u++){var h=i(o[u]).toRgb();c[u]=[h.r,h.g,h.b,h.a]}var f,p=n.scale.linear().domain(r).range(c).clamp(!0),d=e.noNumericCheck,v=e.returnArray;return(f=d&&v?p:d?function(t){return g(p(t))}:v?function(t){return a(t)?p(t):i(t).isValid()?t:s.defaultLine}:function(t){return a(t)?g(p(t)):i(t).isValid()?t:s.defaultLine}).domain=p.domain,f.range=function(){return o},f}function g(t){var e={r:t[0],g:t[1],b:t[2],a:t[3]};return i(e).toRgbString()}e.exports={hasColorscale:function(t,e){var r=e?o.nestedProperty(t,e).get()||{}:t,n=r.color,i=!1;if(o.isArrayOrTypedArray(n))for(var s=0;s<n.length;s++)if(a(n[s])){i=!0;break}return o.isPlainObject(r)&&(i||!0===r.showscale||a(r.cmin)&&a(r.cmax)||l(r.colorscale)||o.isPlainObject(r.colorbar))},extractOpts:h,extractScale:f,flipScale:p,makeColorScaleFunc:d,makeColorScaleFuncFromTrace:function(t,e){return d(f(t),e)}}},{\"../../lib\":719,\"../color\":593,\"./scales\":608,d3:163,\"fast-isnumeric\":225,tinycolor2:537}],605:[function(t,e,r){\"use strict\";var n=t(\"./scales\"),i=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"colorscale\",attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),handleDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\"),scales:n.scales,defaultScale:n.defaultScale,getScale:n.get,isValidScale:n.isValid,hasColorscale:i.hasColorscale,extractOpts:i.extractOpts,extractScale:i.extractScale,flipScale:i.flipScale,makeColorScaleFunc:i.makeColorScaleFunc,makeColorScaleFuncFromTrace:i.makeColorScaleFuncFromTrace}},{\"./attributes\":600,\"./calc\":601,\"./cross_trace_defaults\":602,\"./defaults\":603,\"./helpers\":604,\"./layout_attributes\":606,\"./layout_defaults\":607,\"./scales\":608}],606:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"./attributes\"),a=t(\"./scales\").scales;e.exports={editType:\"calc\",colorscale:{editType:\"calc\",sequential:{valType:\"colorscale\",dflt:a.Reds,editType:\"calc\"},sequentialminus:{valType:\"colorscale\",dflt:a.Blues,editType:\"calc\"},diverging:{valType:\"colorscale\",dflt:a.RdBu,editType:\"calc\"}},coloraxis:n({_isSubplotObj:!0,editType:\"calc\"},i(\"\",{colorAttr:\"corresponding trace color array(s)\",noColorAxis:!0,showScaleDflt:!0}))}},{\"../../lib/extend\":710,\"./attributes\":600,\"./scales\":608}],607:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"./layout_attributes\"),o=t(\"./defaults\");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r(\"colorscale.sequential\"),r(\"colorscale.sequentialminus\"),r(\"colorscale.diverging\");var s,l,c=e._colorAxes;function u(t,e){return n.coerce(s,l,a.coloraxis,t,e)}for(var h in c){var f=c[h];if(f[0])s=t[h]||{},(l=i.newContainer(e,h,\"coloraxis\"))._name=h,o(s,l,e,u,{prefix:\"\",cLetter:\"c\"});else{for(var p=0;p<f[2].length;p++)f[2][p]();delete e._colorAxes[h]}}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"./defaults\":603,\"./layout_attributes\":606}],608:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i={Greys:[[0,\"rgb(0,0,0)\"],[1,\"rgb(255,255,255)\"]],YlGnBu:[[0,\"rgb(8,29,88)\"],[.125,\"rgb(37,52,148)\"],[.25,\"rgb(34,94,168)\"],[.375,\"rgb(29,145,192)\"],[.5,\"rgb(65,182,196)\"],[.625,\"rgb(127,205,187)\"],[.75,\"rgb(199,233,180)\"],[.875,\"rgb(237,248,217)\"],[1,\"rgb(255,255,217)\"]],Greens:[[0,\"rgb(0,68,27)\"],[.125,\"rgb(0,109,44)\"],[.25,\"rgb(35,139,69)\"],[.375,\"rgb(65,171,93)\"],[.5,\"rgb(116,196,118)\"],[.625,\"rgb(161,217,155)\"],[.75,\"rgb(199,233,192)\"],[.875,\"rgb(229,245,224)\"],[1,\"rgb(247,252,245)\"]],YlOrRd:[[0,\"rgb(128,0,38)\"],[.125,\"rgb(189,0,38)\"],[.25,\"rgb(227,26,28)\"],[.375,\"rgb(252,78,42)\"],[.5,\"rgb(253,141,60)\"],[.625,\"rgb(254,178,76)\"],[.75,\"rgb(254,217,118)\"],[.875,\"rgb(255,237,160)\"],[1,\"rgb(255,255,204)\"]],Bluered:[[0,\"rgb(0,0,255)\"],[1,\"rgb(255,0,0)\"]],RdBu:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(106,137,247)\"],[.5,\"rgb(190,190,190)\"],[.6,\"rgb(220,170,132)\"],[.7,\"rgb(230,145,90)\"],[1,\"rgb(178,10,28)\"]],Reds:[[0,\"rgb(220,220,220)\"],[.2,\"rgb(245,195,157)\"],[.4,\"rgb(245,160,105)\"],[1,\"rgb(178,10,28)\"]],Blues:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(40,60,190)\"],[.5,\"rgb(70,100,245)\"],[.6,\"rgb(90,120,245)\"],[.7,\"rgb(106,137,247)\"],[1,\"rgb(220,220,220)\"]],Picnic:[[0,\"rgb(0,0,255)\"],[.1,\"rgb(51,153,255)\"],[.2,\"rgb(102,204,255)\"],[.3,\"rgb(153,204,255)\"],[.4,\"rgb(204,204,255)\"],[.5,\"rgb(255,255,255)\"],[.6,\"rgb(255,204,255)\"],[.7,\"rgb(255,153,255)\"],[.8,\"rgb(255,102,204)\"],[.9,\"rgb(255,102,102)\"],[1,\"rgb(255,0,0)\"]],Rainbow:[[0,\"rgb(150,0,90)\"],[.125,\"rgb(0,0,200)\"],[.25,\"rgb(0,25,255)\"],[.375,\"rgb(0,152,255)\"],[.5,\"rgb(44,255,150)\"],[.625,\"rgb(151,255,0)\"],[.75,\"rgb(255,234,0)\"],[.875,\"rgb(255,111,0)\"],[1,\"rgb(255,0,0)\"]],Portland:[[0,\"rgb(12,51,131)\"],[.25,\"rgb(10,136,186)\"],[.5,\"rgb(242,211,56)\"],[.75,\"rgb(242,143,56)\"],[1,\"rgb(217,30,30)\"]],Jet:[[0,\"rgb(0,0,131)\"],[.125,\"rgb(0,60,170)\"],[.375,\"rgb(5,255,255)\"],[.625,\"rgb(255,255,0)\"],[.875,\"rgb(250,0,0)\"],[1,\"rgb(128,0,0)\"]],Hot:[[0,\"rgb(0,0,0)\"],[.3,\"rgb(230,0,0)\"],[.6,\"rgb(255,210,0)\"],[1,\"rgb(255,255,255)\"]],Blackbody:[[0,\"rgb(0,0,0)\"],[.2,\"rgb(230,0,0)\"],[.4,\"rgb(230,210,0)\"],[.7,\"rgb(255,255,255)\"],[1,\"rgb(160,200,255)\"]],Earth:[[0,\"rgb(0,0,130)\"],[.1,\"rgb(0,180,180)\"],[.2,\"rgb(40,210,40)\"],[.4,\"rgb(230,230,50)\"],[.6,\"rgb(120,70,20)\"],[1,\"rgb(255,255,255)\"]],Electric:[[0,\"rgb(0,0,0)\"],[.15,\"rgb(30,0,100)\"],[.4,\"rgb(120,0,100)\"],[.6,\"rgb(160,90,0)\"],[.8,\"rgb(230,200,0)\"],[1,\"rgb(255,250,220)\"]],Viridis:[[0,\"#440154\"],[.06274509803921569,\"#48186a\"],[.12549019607843137,\"#472d7b\"],[.18823529411764706,\"#424086\"],[.25098039215686274,\"#3b528b\"],[.3137254901960784,\"#33638d\"],[.3764705882352941,\"#2c728e\"],[.4392156862745098,\"#26828e\"],[.5019607843137255,\"#21918c\"],[.5647058823529412,\"#1fa088\"],[.6274509803921569,\"#28ae80\"],[.6901960784313725,\"#3fbc73\"],[.7529411764705882,\"#5ec962\"],[.8156862745098039,\"#84d44b\"],[.8784313725490196,\"#addc30\"],[.9411764705882353,\"#d8e219\"],[1,\"#fde725\"]],Cividis:[[0,\"rgb(0,32,76)\"],[.058824,\"rgb(0,42,102)\"],[.117647,\"rgb(0,52,110)\"],[.176471,\"rgb(39,63,108)\"],[.235294,\"rgb(60,74,107)\"],[.294118,\"rgb(76,85,107)\"],[.352941,\"rgb(91,95,109)\"],[.411765,\"rgb(104,106,112)\"],[.470588,\"rgb(117,117,117)\"],[.529412,\"rgb(131,129,120)\"],[.588235,\"rgb(146,140,120)\"],[.647059,\"rgb(161,152,118)\"],[.705882,\"rgb(176,165,114)\"],[.764706,\"rgb(192,177,109)\"],[.823529,\"rgb(209,191,102)\"],[.882353,\"rgb(225,204,92)\"],[.941176,\"rgb(243,219,79)\"],[1,\"rgb(255,233,69)\"]]},a=i.RdBu;function o(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var i=t[r];if(2!==i.length||+i[0]<e||!n(i[1]).isValid())return!1;e=+i[0]}return!0}e.exports={scales:i,defaultScale:a,get:function(t,e){if(e||(e=a),!t)return e;function r(){try{t=i[t]||JSON.parse(t)}catch(r){t=e}}return\"string\"==typeof t&&(r(),\"string\"==typeof t&&r()),o(t)?t:e},isValid:function(t){return void 0!==i[t]||o(t)}}},{tinycolor2:537}],609:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=(t-r)/(n-r),o=a+e/(n-r),s=(a+o)/2;return\"left\"===i||\"bottom\"===i?a:\"center\"===i||\"middle\"===i?s:\"right\"===i||\"top\"===i?o:a<2/3-s?a:o>4/3-s?o:s}},{}],610:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[\"sw-resize\",\"s-resize\",\"se-resize\"],[\"w-resize\",\"move\",\"e-resize\"],[\"nw-resize\",\"n-resize\",\"ne-resize\"]];e.exports=function(t,e,r,a){return t=\"left\"===r?0:\"center\"===r?1:\"right\"===r?2:n.constrain(Math.floor(3*t),0,2),e=\"bottom\"===a?0:\"middle\"===a?1:\"top\"===a?2:n.constrain(Math.floor(3*e),0,2),i[e][t]}},{\"../../lib\":719}],611:[function(t,e,r){\"use strict\";var n=t(\"mouse-event-offset\"),i=t(\"has-hover\"),a=t(\"has-passive-events\"),o=t(\"../../lib\").removeElement,s=t(\"../../plots/cartesian/constants\"),l=e.exports={};l.align=t(\"./align\"),l.getCursor=t(\"./cursor\");var c=t(\"./unhover\");function u(){var t=document.createElement(\"div\");t.className=\"dragcover\";var e=t.style;return e.position=\"fixed\",e.left=0,e.right=0,e.top=0,e.bottom=0,e.zIndex=999999999,e.background=\"none\",document.body.appendChild(t),t}function h(t){return n(t.changedTouches?t.changedTouches[0]:t,document.body)}l.unhover=c.wrapped,l.unhoverRaw=c.raw,l.init=function(t){var e,r,n,c,f,p,d,g,v=t.gd,m=1,y=v._context.doubleClickDelay,x=t.element;v._mouseDownTime||(v._mouseDownTime=0),x.style.pointerEvents=\"all\",x.onmousedown=_,a?(x._ontouchstart&&x.removeEventListener(\"touchstart\",x._ontouchstart),x._ontouchstart=_,x.addEventListener(\"touchstart\",_,{passive:!1})):x.ontouchstart=_;var b=t.clampFn||function(t,e,r){return Math.abs(t)<r&&(t=0),Math.abs(e)<r&&(e=0),[t,e]};function _(a){v._dragged=!1,v._dragging=!0;var o=h(a);e=o[0],r=o[1],d=a.target,p=a,g=2===a.buttons||a.ctrlKey,\"undefined\"==typeof a.clientX&&\"undefined\"==typeof a.clientY&&(a.clientX=e,a.clientY=r),(n=(new Date).getTime())-v._mouseDownTime<y?m+=1:(m=1,v._mouseDownTime=n),t.prepFn&&t.prepFn(a,e,r),i&&!g?(f=u()).style.cursor=window.getComputedStyle(x).cursor:i||(f=document,c=window.getComputedStyle(document.documentElement).cursor,document.documentElement.style.cursor=window.getComputedStyle(x).cursor),document.addEventListener(\"mouseup\",k),document.addEventListener(\"touchend\",k),!1!==t.dragmode&&(a.preventDefault(),document.addEventListener(\"mousemove\",w),document.addEventListener(\"touchmove\",w))}function w(n){n.preventDefault();var i=h(n),a=t.minDrag||s.MINDRAG,o=b(i[0]-e,i[1]-r,a),c=o[0],u=o[1];(c||u)&&(v._dragged=!0,l.unhover(v)),v._dragged&&t.moveFn&&!g&&(v._dragdata={element:x,dx:c,dy:u},t.moveFn(c,u))}function k(e){if(delete v._dragdata,!1!==t.dragmode&&(e.preventDefault(),document.removeEventListener(\"mousemove\",w),document.removeEventListener(\"touchmove\",w)),document.removeEventListener(\"mouseup\",k),document.removeEventListener(\"touchend\",k),i?o(f):c&&(f.documentElement.style.cursor=c,c=null),v._dragging){if(v._dragging=!1,(new Date).getTime()-v._mouseDownTime>y&&(m=Math.max(m-1,1)),v._dragged)t.doneFn&&t.doneFn();else if(t.clickFn&&t.clickFn(m,p),!g){var r;try{r=new MouseEvent(\"click\",e)}catch(t){var n=h(e);(r=document.createEvent(\"MouseEvents\")).initMouseEvent(\"click\",e.bubbles,e.cancelable,e.view,e.detail,e.screenX,e.screenY,n[0],n[1],e.ctrlKey,e.altKey,e.shiftKey,e.metaKey,e.button,e.relatedTarget)}d.dispatchEvent(r)}v._dragging=!1,v._dragged=!1}else v._dragged=!1}},l.coverSlip=u},{\"../../lib\":719,\"../../plots/cartesian/constants\":773,\"./align\":609,\"./cursor\":610,\"./unhover\":612,\"has-hover\":410,\"has-passive-events\":411,\"mouse-event-offset\":436}],612:[function(t,e,r){\"use strict\";var n=t(\"../../lib/events\"),i=t(\"../../lib/throttle\"),a=t(\"../../lib/dom\").getGraphDiv,o=t(\"../fx/constants\"),s=e.exports={};s.wrapped=function(t,e,r){(t=a(t))._fullLayout&&i.clear(t._fullLayout._uid+o.HOVERID),s.raw(t,e,r)},s.raw=function(t,e){var r=t._fullLayout,i=t._hoverdata;e||(e={}),e.target&&!1===n.triggerHandler(t,\"plotly_beforehover\",e)||(r._hoverlayer.selectAll(\"g\").remove(),r._hoverlayer.selectAll(\"line\").remove(),r._hoverlayer.selectAll(\"circle\").remove(),t._hoverdata=void 0,e.target&&i&&t.emit(\"plotly_unhover\",{event:e,points:i}))}},{\"../../lib/dom\":708,\"../../lib/events\":709,\"../../lib/throttle\":744,\"../fx/constants\":626}],613:[function(t,e,r){\"use strict\";r.dash={valType:\"string\",values:[\"solid\",\"dot\",\"dash\",\"longdash\",\"dashdot\",\"longdashdot\"],dflt:\"solid\",editType:\"style\"}},{}],614:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../registry\"),s=t(\"../color\"),l=t(\"../colorscale\"),c=t(\"../../lib\"),u=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/xmlns_namespaces\"),f=t(\"../../constants/alignment\").LINE_SPACING,p=t(\"../../constants/interactions\").DESELECTDIM,d=t(\"../../traces/scatter/subtypes\"),g=t(\"../../traces/scatter/make_bubble_size_func\"),v=e.exports={};v.font=function(t,e,r,n){c.isPlainObject(e)&&(n=e.color,r=e.size,e=e.family),e&&t.style(\"font-family\",e),r+1&&t.style(\"font-size\",r+\"px\"),n&&t.call(s.fill,n)},v.setPosition=function(t,e,r){t.attr(\"x\",e).attr(\"y\",r)},v.setSize=function(t,e,r){t.attr(\"width\",e).attr(\"height\",r)},v.setRect=function(t,e,r,n,i){t.call(v.setPosition,e,r).call(v.setSize,n,i)},v.translatePoint=function(t,e,r,n){var a=r.c2p(t.x),o=n.c2p(t.y);return!!(i(a)&&i(o)&&e.node())&&(\"text\"===e.node().nodeName?e.attr(\"x\",a).attr(\"y\",o):e.attr(\"transform\",\"translate(\"+a+\",\"+o+\")\"),!0)},v.translatePoints=function(t,e,r){t.each(function(t){var i=n.select(this);v.translatePoint(t,i,e,r)})},v.hideOutsideRangePoint=function(t,e,r,n,i,a){e.attr(\"display\",r.isPtWithinRange(t,i)&&n.isPtWithinRange(t,a)?null:\"none\")},v.hideOutsideRangePoints=function(t,e){if(e._hasClipOnAxisFalse){var r=e.xaxis,i=e.yaxis;t.each(function(e){var a=e[0].trace,s=a.xcalendar,l=a.ycalendar,c=o.traceIs(a,\"bar-like\")?\".bartext\":\".point,.textpoint\";t.selectAll(c).each(function(t){v.hideOutsideRangePoint(t,n.select(this),r,i,s,l)})})}},v.crispRound=function(t,e,r){return e&&i(e)?t._context.staticPlot?e:e<1?1:Math.round(e):r||0},v.singleLineStyle=function(t,e,r,n,i){e.style(\"fill\",\"none\");var a=(((t||[])[0]||{}).trace||{}).line||{},o=r||a.width||0,l=i||a.dash||\"\";s.stroke(e,n||a.color),v.dashLine(e,l,o)},v.lineGroupStyle=function(t,e,r,i){t.style(\"fill\",\"none\").each(function(t){var a=(((t||[])[0]||{}).trace||{}).line||{},o=e||a.width||0,l=i||a.dash||\"\";n.select(this).call(s.stroke,r||a.color).call(v.dashLine,l,o)})},v.dashLine=function(t,e,r){r=+r||0,e=v.dashStyle(e,r),t.style({\"stroke-dasharray\":e,\"stroke-width\":r+\"px\"})},v.dashStyle=function(t,e){e=+e||1;var r=Math.max(e,3);return\"solid\"===t?t=\"\":\"dot\"===t?t=r+\"px,\"+r+\"px\":\"dash\"===t?t=3*r+\"px,\"+3*r+\"px\":\"longdash\"===t?t=5*r+\"px,\"+5*r+\"px\":\"dashdot\"===t?t=3*r+\"px,\"+r+\"px,\"+r+\"px,\"+r+\"px\":\"longdashdot\"===t&&(t=5*r+\"px,\"+2*r+\"px,\"+r+\"px,\"+2*r+\"px\"),t},v.singleFillStyle=function(t){var e=(((n.select(t.node()).data()[0]||[])[0]||{}).trace||{}).fillcolor;e&&t.call(s.fill,e)},v.fillGroupStyle=function(t){t.style(\"stroke-width\",0).each(function(t){var e=n.select(this);t[0].trace&&e.call(s.fill,t[0].trace.fillcolor)})};var m=t(\"./symbol_defs\");v.symbolNames=[],v.symbolFuncs=[],v.symbolNeedLines={},v.symbolNoDot={},v.symbolNoFill={},v.symbolList=[],Object.keys(m).forEach(function(t){var e=m[t];v.symbolList=v.symbolList.concat([e.n,t,e.n+100,t+\"-open\"]),v.symbolNames[e.n]=t,v.symbolFuncs[e.n]=e.f,e.needLine&&(v.symbolNeedLines[e.n]=!0),e.noDot?v.symbolNoDot[e.n]=!0:v.symbolList=v.symbolList.concat([e.n+200,t+\"-dot\",e.n+300,t+\"-open-dot\"]),e.noFill&&(v.symbolNoFill[e.n]=!0)});var y=v.symbolNames.length,x=\"M0,0.5L0.5,0L0,-0.5L-0.5,0Z\";function b(t,e){var r=t%100;return v.symbolFuncs[r](e)+(t>=200?x:\"\")}v.symbolNumber=function(t){if(\"string\"==typeof t){var e=0;t.indexOf(\"-open\")>0&&(e=100,t=t.replace(\"-open\",\"\")),t.indexOf(\"-dot\")>0&&(e+=200,t=t.replace(\"-dot\",\"\")),(t=v.symbolNames.indexOf(t))>=0&&(t+=e)}return t%100>=y||t>=400?0:Math.floor(Math.max(t,0))};var _={x1:1,x2:0,y1:0,y2:0},w={x1:0,x2:0,y1:1,y2:0},k=n.format(\"~.1f\"),T={radial:{node:\"radialGradient\"},radialreversed:{node:\"radialGradient\",reversed:!0},horizontal:{node:\"linearGradient\",attrs:_},horizontalreversed:{node:\"linearGradient\",attrs:_,reversed:!0},vertical:{node:\"linearGradient\",attrs:w},verticalreversed:{node:\"linearGradient\",attrs:w,reversed:!0}};v.gradient=function(t,e,r,i,o,l){for(var u=o.length,h=T[i],f=new Array(u),p=0;p<u;p++)h.reversed?f[u-1-p]=[k(100*(1-o[p][0])),o[p][1]]:f[p]=[k(100*o[p][0]),o[p][1]];var d=\"g\"+e._fullLayout._uid+\"-\"+r,g=e._fullLayout._defs.select(\".gradients\").selectAll(\"#\"+d).data([i+f.join(\";\")],c.identity);g.exit().remove(),g.enter().append(h.node).each(function(){var t=n.select(this);h.attrs&&t.attr(h.attrs),t.attr(\"id\",d);var e=t.selectAll(\"stop\").data(f);e.exit().remove(),e.enter().append(\"stop\"),e.each(function(t){var e=a(t[1]);n.select(this).attr({offset:t[0]+\"%\",\"stop-color\":s.tinyRGB(e),\"stop-opacity\":e.getAlpha()})})}),t.style(l,I(d,e)).style(l+\"-opacity\",null)},v.initGradients=function(t){c.ensureSingle(t._fullLayout._defs,\"g\",\"gradients\").selectAll(\"linearGradient,radialGradient\").remove()},v.pointStyle=function(t,e,r){if(t.size()){var i=v.makePointStyleFns(e);t.each(function(t){v.singlePointStyle(t,n.select(this),e,i,r)})}},v.singlePointStyle=function(t,e,r,n,i){var a=r.marker,o=a.line;if(e.style(\"opacity\",n.selectedOpacityFn?n.selectedOpacityFn(t):void 0===t.mo?a.opacity:t.mo),n.ms2mrc){var l;l=\"various\"===t.ms||\"various\"===a.size?3:n.ms2mrc(t.ms),t.mrc=l,n.selectedSizeFn&&(l=t.mrc=n.selectedSizeFn(t));var u=v.symbolNumber(t.mx||a.symbol)||0;t.om=u%200>=100,e.attr(\"d\",b(u,l))}var h,f,p,d=!1;if(t.so)p=o.outlierwidth,f=o.outliercolor,h=a.outliercolor;else{var g=(o||{}).width;p=(t.mlw+1||g+1||(t.trace?(t.trace.marker.line||{}).width:0)+1)-1||0,f=\"mlc\"in t?t.mlcc=n.lineScale(t.mlc):c.isArrayOrTypedArray(o.color)?s.defaultLine:o.color,c.isArrayOrTypedArray(a.color)&&(h=s.defaultLine,d=!0),h=\"mc\"in t?t.mcc=n.markerScale(t.mc):a.color||\"rgba(0,0,0,0)\",n.selectedColorFn&&(h=n.selectedColorFn(t))}if(t.om)e.call(s.stroke,h).style({\"stroke-width\":(p||1)+\"px\",fill:\"none\"});else{e.style(\"stroke-width\",p+\"px\");var m=a.gradient,y=t.mgt;if(y?d=!0:y=m&&m.type,Array.isArray(y)&&(y=y[0],T[y]||(y=0)),y&&\"none\"!==y){var x=t.mgc;x?d=!0:x=m.color;var _=r.uid;d&&(_+=\"-\"+t.i),v.gradient(e,i,_,y,[[0,x],[1,h]],\"fill\")}else s.fill(e,h);p&&s.stroke(e,f)}},v.makePointStyleFns=function(t){var e={},r=t.marker;return e.markerScale=v.tryColorscale(r,\"\"),e.lineScale=v.tryColorscale(r,\"line\"),o.traceIs(t,\"symbols\")&&(e.ms2mrc=d.isBubble(t)?g(t):function(){return(r.size||6)/2}),t.selectedpoints&&c.extendFlat(e,v.makeSelectedPointStyleFns(t)),e},v.makeSelectedPointStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.marker||{},a=r.marker||{},s=n.marker||{},l=i.opacity,u=a.opacity,h=s.opacity,f=void 0!==u,d=void 0!==h;(c.isArrayOrTypedArray(l)||f||d)&&(e.selectedOpacityFn=function(t){var e=void 0===t.mo?i.opacity:t.mo;return t.selected?f?u:e:d?h:p*e});var g=i.color,v=a.color,m=s.color;(v||m)&&(e.selectedColorFn=function(t){var e=t.mcc||g;return t.selected?v||e:m||e});var y=i.size,x=a.size,b=s.size,_=void 0!==x,w=void 0!==b;return o.traceIs(t,\"symbols\")&&(_||w)&&(e.selectedSizeFn=function(t){var e=t.mrc||y/2;return t.selected?_?x/2:e:w?b/2:e}),e},v.makeSelectedTextStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.textfont||{},a=r.textfont||{},o=n.textfont||{},l=i.color,c=a.color,u=o.color;return e.selectedTextColorFn=function(t){var e=t.tc||l;return t.selected?c||e:u||(c?e:s.addOpacity(e,p))},e},v.selectedPointStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=v.makeSelectedPointStyleFns(e),i=e.marker||{},a=[];r.selectedOpacityFn&&a.push(function(t,e){t.style(\"opacity\",r.selectedOpacityFn(e))}),r.selectedColorFn&&a.push(function(t,e){s.fill(t,r.selectedColorFn(e))}),r.selectedSizeFn&&a.push(function(t,e){var n=e.mx||i.symbol||0,a=r.selectedSizeFn(e);t.attr(\"d\",b(v.symbolNumber(n),a)),e.mrc2=a}),a.length&&t.each(function(t){for(var e=n.select(this),r=0;r<a.length;r++)a[r](e,t)})}},v.tryColorscale=function(t,e){var r=e?c.nestedProperty(t,e).get():t;if(r){var n=r.color;if((r.colorscale||r._colorAx)&&c.isArrayOrTypedArray(n))return l.makeColorScaleFuncFromTrace(r)}return c.identity};var A={start:1,end:-1,middle:0,bottom:1,top:-1};function M(t,e,r,i){var a=n.select(t.node().parentNode),o=-1!==e.indexOf(\"top\")?\"top\":-1!==e.indexOf(\"bottom\")?\"bottom\":\"middle\",s=-1!==e.indexOf(\"left\")?\"end\":-1!==e.indexOf(\"right\")?\"start\":\"middle\",l=i?i/.8+1:0,c=(u.lineCount(t)-1)*f+1,h=A[s]*l,p=.75*r+A[o]*l+(A[o]-1)*c*r/2;t.attr(\"text-anchor\",s),a.attr(\"transform\",\"translate(\"+h+\",\"+p+\")\")}function S(t,e){var r=t.ts||e.textfont.size;return i(r)&&r>0?r:0}v.textPointStyle=function(t,e,r){if(t.size()){var i;if(e.selectedpoints){var a=v.makeSelectedTextStyleFns(e);i=a.selectedTextColorFn}t.each(function(t){var a=n.select(this),o=c.extractOption(t,e,\"tx\",\"text\");if(o||0===o){var s=t.tp||e.textposition,l=S(t,e),h=i?i(t):t.tc||e.textfont.color;a.call(v.font,t.tf||e.textfont.family,l,h).text(o).call(u.convertToTspans,r).call(M,s,l,t.mrc)}else a.remove()})}},v.selectedTextStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=v.makeSelectedTextStyleFns(e);t.each(function(t){var i=n.select(this),a=r.selectedTextColorFn(t),o=t.tp||e.textposition,l=S(t,e);s.fill(i,a),M(i,o,l,t.mrc2||t.mrc)})}};var E=.5;function C(t,e,r,i){var a=t[0]-e[0],o=t[1]-e[1],s=r[0]-e[0],l=r[1]-e[1],c=Math.pow(a*a+o*o,E/2),u=Math.pow(s*s+l*l,E/2),h=(u*u*a-c*c*s)*i,f=(u*u*o-c*c*l)*i,p=3*u*(c+u),d=3*c*(c+u);return[[n.round(e[0]+(p&&h/p),2),n.round(e[1]+(p&&f/p),2)],[n.round(e[0]-(d&&h/d),2),n.round(e[1]-(d&&f/d),2)]]}v.smoothopen=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\");var r,n=\"M\"+t[0],i=[];for(r=1;r<t.length-1;r++)i.push(C(t[r-1],t[r],t[r+1],e));for(n+=\"Q\"+i[0][0]+\" \"+t[1],r=2;r<t.length-1;r++)n+=\"C\"+i[r-2][1]+\" \"+i[r-1][0]+\" \"+t[r];return n+=\"Q\"+i[t.length-3][1]+\" \"+t[t.length-1]},v.smoothclosed=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\")+\"Z\";var r,n=\"M\"+t[0],i=t.length-1,a=[C(t[i],t[0],t[1],e)];for(r=1;r<i;r++)a.push(C(t[r-1],t[r],t[r+1],e));for(a.push(C(t[i-1],t[i],t[0],e)),r=1;r<=i;r++)n+=\"C\"+a[r-1][1]+\" \"+a[r][0]+\" \"+t[r];return n+=\"C\"+a[i][1]+\" \"+a[0][0]+\" \"+t[0]+\"Z\"};var L={hv:function(t,e){return\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)},vh:function(t,e){return\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},hvh:function(t,e){return\"H\"+n.round((t[0]+e[0])/2,2)+\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},vhv:function(t,e){return\"V\"+n.round((t[1]+e[1])/2,2)+\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)}},P=function(t,e){return\"L\"+n.round(e[0],2)+\",\"+n.round(e[1],2)};v.steps=function(t){var e=L[t]||P;return function(t){for(var r=\"M\"+n.round(t[0][0],2)+\",\"+n.round(t[0][1],2),i=1;i<t.length;i++)r+=e(t[i-1],t[i]);return r}},v.makeTester=function(){var t=c.ensureSingleById(n.select(\"body\"),\"svg\",\"js-plotly-tester\",function(t){t.attr(h.svgAttrs).style({position:\"absolute\",left:\"-10000px\",top:\"-10000px\",width:\"9000px\",height:\"9000px\",\"z-index\":\"1\"})}),e=c.ensureSingle(t,\"path\",\"js-reference-point\",function(t){t.attr(\"d\",\"M0,0H1V1H0Z\").style({\"stroke-width\":0,fill:\"black\"})});v.tester=t,v.testref=e},v.savedBBoxes={};var O=0;function z(t){var e=t.getAttribute(\"data-unformatted\");if(null!==e)return e+t.getAttribute(\"data-math\")+t.getAttribute(\"text-anchor\")+t.getAttribute(\"style\")}function I(t,e){if(!t)return null;var r=e._context;return\"url('\"+(r._exportedPlot?\"\":r._baseUrl||\"\")+\"#\"+t+\"')\"}v.bBox=function(t,e,r){var i,a,o;if(r||(r=z(t)),r){if(i=v.savedBBoxes[r])return c.extendFlat({},i)}else if(1===t.childNodes.length){var s=t.childNodes[0];if(r=z(s)){var l=+s.getAttribute(\"x\")||0,h=+s.getAttribute(\"y\")||0,f=s.getAttribute(\"transform\");if(!f){var p=v.bBox(s,!1,r);return l&&(p.left+=l,p.right+=l),h&&(p.top+=h,p.bottom+=h),p}if(r+=\"~\"+l+\"~\"+h+\"~\"+f,i=v.savedBBoxes[r])return c.extendFlat({},i)}}e?a=t:(o=v.tester.node(),a=t.cloneNode(!0),o.appendChild(a)),n.select(a).attr(\"transform\",null).call(u.positionText,0,0);var d=a.getBoundingClientRect(),g=v.testref.node().getBoundingClientRect();e||o.removeChild(a);var m={height:d.height,width:d.width,left:d.left-g.left,top:d.top-g.top,right:d.right-g.left,bottom:d.bottom-g.top};return O>=1e4&&(v.savedBBoxes={},O=0),r&&(v.savedBBoxes[r]=m),O++,c.extendFlat({},m)},v.setClipUrl=function(t,e,r){t.attr(\"clip-path\",I(e,r))},v.getTranslate=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\btranslate\\((-?\\d*\\.?\\d*)[^-\\d]*(-?\\d*\\.?\\d*)[^\\d].*/,function(t,e,r){return[e,r].join(\" \")}).split(\" \");return{x:+e[0]||0,y:+e[1]||0}},v.setTranslate=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||0,r=r||0,a=a.replace(/(\\btranslate\\(.*?\\);?)/,\"\").trim(),a=(a+=\" translate(\"+e+\", \"+r+\")\").trim(),t[i](\"transform\",a),a},v.getScale=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\bscale\\((\\d*\\.?\\d*)[^\\d]*(\\d*\\.?\\d*)[^\\d].*/,function(t,e,r){return[e,r].join(\" \")}).split(\" \");return{x:+e[0]||1,y:+e[1]||1}},v.setScale=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||1,r=r||1,a=a.replace(/(\\bscale\\(.*?\\);?)/,\"\").trim(),a=(a+=\" scale(\"+e+\", \"+r+\")\").trim(),t[i](\"transform\",a),a};var D=/\\s*sc.*/;v.setPointGroupScale=function(t,e,r){if(e=e||1,r=r||1,t){var n=1===e&&1===r?\"\":\" scale(\"+e+\",\"+r+\")\";t.each(function(){var t=(this.getAttribute(\"transform\")||\"\").replace(D,\"\");t=(t+=n).trim(),this.setAttribute(\"transform\",t)})}};var R=/translate\\([^)]*\\)\\s*$/;v.setTextPointsScale=function(t,e,r){t&&t.each(function(){var t,i=n.select(this),a=i.select(\"text\");if(a.node()){var o=parseFloat(a.attr(\"x\")||0),s=parseFloat(a.attr(\"y\")||0),l=(i.attr(\"transform\")||\"\").match(R);t=1===e&&1===r?[]:[\"translate(\"+o+\",\"+s+\")\",\"scale(\"+e+\",\"+r+\")\",\"translate(\"+-o+\",\"+-s+\")\"],l&&t.push(l),i.attr(\"transform\",t.join(\" \"))}})}},{\"../../constants/alignment\":688,\"../../constants/interactions\":694,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../registry\":847,\"../../traces/scatter/make_bubble_size_func\":1128,\"../../traces/scatter/subtypes\":1135,\"../color\":593,\"../colorscale\":605,\"./symbol_defs\":615,d3:163,\"fast-isnumeric\":225,tinycolor2:537}],615:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports={circle:{n:0,f:function(t){var e=n.round(t,2);return\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"}},square:{n:1,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"}},diamond:{n:2,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"Z\"}},cross:{n:3,f:function(t){var e=n.round(.4*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H\"+e+\"V\"+r+\"H-\"+e+\"V\"+e+\"H-\"+r+\"V-\"+e+\"H-\"+e+\"V-\"+r+\"H\"+e+\"V-\"+e+\"H\"+r+\"Z\"}},x:{n:4,f:function(t){var e=n.round(.8*t/Math.sqrt(2),2),r=\"l\"+e+\",\"+e,i=\"l\"+e+\",-\"+e,a=\"l-\"+e+\",-\"+e,o=\"l-\"+e+\",\"+e;return\"M0,\"+e+r+i+a+i+a+o+a+o+r+o+r+\"Z\"}},\"triangle-up\":{n:5,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",\"+n.round(t/2,2)+\"H\"+e+\"L0,-\"+n.round(t,2)+\"Z\"}},\"triangle-down\":{n:6,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",-\"+n.round(t/2,2)+\"H\"+e+\"L0,\"+n.round(t,2)+\"Z\"}},\"triangle-left\":{n:7,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L-\"+n.round(t,2)+\",0Z\"}},\"triangle-right\":{n:8,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L\"+n.round(t,2)+\",0Z\"}},\"triangle-ne\":{n:9,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+r+\",-\"+e+\"H\"+e+\"V\"+r+\"Z\"}},\"triangle-se\":{n:10,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+e+\",-\"+r+\"V\"+e+\"H-\"+r+\"Z\"}},\"triangle-sw\":{n:11,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H-\"+e+\"V-\"+r+\"Z\"}},\"triangle-nw\":{n:12,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+e+\",\"+r+\"V-\"+e+\"H\"+r+\"Z\"}},pentagon:{n:13,f:function(t){var e=n.round(.951*t,2),r=n.round(.588*t,2),i=n.round(-t,2),a=n.round(-.309*t,2);return\"M\"+e+\",\"+a+\"L\"+r+\",\"+n.round(.809*t,2)+\"H-\"+r+\"L-\"+e+\",\"+a+\"L0,\"+i+\"Z\"}},hexagon:{n:14,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M\"+i+\",-\"+r+\"V\"+r+\"L0,\"+e+\"L-\"+i+\",\"+r+\"V-\"+r+\"L0,-\"+e+\"Z\"}},hexagon2:{n:15,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M-\"+r+\",\"+i+\"H\"+r+\"L\"+e+\",0L\"+r+\",-\"+i+\"H-\"+r+\"L-\"+e+\",0Z\"}},octagon:{n:16,f:function(t){var e=n.round(.924*t,2),r=n.round(.383*t,2);return\"M-\"+r+\",-\"+e+\"H\"+r+\"L\"+e+\",-\"+r+\"V\"+r+\"L\"+r+\",\"+e+\"H-\"+r+\"L-\"+e+\",\"+r+\"V-\"+r+\"Z\"}},star:{n:17,f:function(t){var e=1.4*t,r=n.round(.225*e,2),i=n.round(.951*e,2),a=n.round(.363*e,2),o=n.round(.588*e,2),s=n.round(-e,2),l=n.round(-.309*e,2),c=n.round(.118*e,2),u=n.round(.809*e,2);return\"M\"+r+\",\"+l+\"H\"+i+\"L\"+a+\",\"+c+\"L\"+o+\",\"+u+\"L0,\"+n.round(.382*e,2)+\"L-\"+o+\",\"+u+\"L-\"+a+\",\"+c+\"L-\"+i+\",\"+l+\"H-\"+r+\"L0,\"+s+\"Z\"}},hexagram:{n:18,f:function(t){var e=n.round(.66*t,2),r=n.round(.38*t,2),i=n.round(.76*t,2);return\"M-\"+i+\",0l-\"+r+\",-\"+e+\"h\"+i+\"l\"+r+\",-\"+e+\"l\"+r+\",\"+e+\"h\"+i+\"l-\"+r+\",\"+e+\"l\"+r+\",\"+e+\"h-\"+i+\"l-\"+r+\",\"+e+\"l-\"+r+\",-\"+e+\"h-\"+i+\"Z\"}},\"star-triangle-up\":{n:19,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M-\"+e+\",\"+r+o+e+\",\"+r+o+\"0,-\"+i+o+\"-\"+e+\",\"+r+\"Z\"}},\"star-triangle-down\":{n:20,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M\"+e+\",-\"+r+o+\"-\"+e+\",-\"+r+o+\"0,\"+i+o+e+\",-\"+r+\"Z\"}},\"star-square\":{n:21,f:function(t){var e=n.round(1.1*t,2),r=n.round(2*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",-\"+e+i+\"-\"+e+\",\"+e+i+e+\",\"+e+i+e+\",-\"+e+i+\"-\"+e+\",-\"+e+\"Z\"}},\"star-diamond\":{n:22,f:function(t){var e=n.round(1.4*t,2),r=n.round(1.9*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",0\"+i+\"0,\"+e+i+e+\",0\"+i+\"0,-\"+e+i+\"-\"+e+\",0Z\"}},\"diamond-tall\":{n:23,f:function(t){var e=n.round(.7*t,2),r=n.round(1.4*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},\"diamond-wide\":{n:24,f:function(t){var e=n.round(1.4*t,2),r=n.round(.7*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},hourglass:{n:25,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"L\"+e+\",-\"+e+\"H-\"+e+\"Z\"},noDot:!0},bowtie:{n:26,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"V-\"+e+\"L-\"+e+\",\"+e+\"V-\"+e+\"Z\"},noDot:!0},\"circle-cross\":{n:27,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"circle-x\":{n:28,f:function(t){var e=n.round(t,2),r=n.round(t/Math.sqrt(2),2);return\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"square-cross\":{n:29,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"square-x\":{n:30,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"diamond-cross\":{n:31,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM0,-\"+e+\"V\"+e+\"M-\"+e+\",0H\"+e},needLine:!0,noDot:!0},\"diamond-x\":{n:32,f:function(t){var e=n.round(1.3*t,2),r=n.round(.65*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM-\"+r+\",-\"+r+\"L\"+r+\",\"+r+\"M-\"+r+\",\"+r+\"L\"+r+\",-\"+r},needLine:!0,noDot:!0},\"cross-thin\":{n:33,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"x-thin\":{n:34,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},asterisk:{n:35,f:function(t){var e=n.round(1.2*t,2),r=n.round(.85*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r},needLine:!0,noDot:!0,noFill:!0},hash:{n:36,f:function(t){var e=n.round(t/2,2),r=n.round(t,2);return\"M\"+e+\",\"+r+\"V-\"+r+\"m-\"+r+\",0V\"+r+\"M\"+r+\",\"+e+\"H-\"+r+\"m0,-\"+r+\"H\"+r},needLine:!0,noFill:!0},\"y-up\":{n:37,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",\"+i+\"L0,0M\"+e+\",\"+i+\"L0,0M0,-\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-down\":{n:38,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",-\"+i+\"L0,0M\"+e+\",-\"+i+\"L0,0M0,\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-left\":{n:39,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M\"+i+\",\"+e+\"L0,0M\"+i+\",-\"+e+\"L0,0M-\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-right\":{n:40,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+i+\",\"+e+\"L0,0M-\"+i+\",-\"+e+\"L0,0M\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"line-ew\":{n:41,f:function(t){var e=n.round(1.4*t,2);return\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ns\":{n:42,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ne\":{n:43,f:function(t){var e=n.round(t,2);return\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-nw\":{n:44,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e},needLine:!0,noDot:!0,noFill:!0}}},{d3:163}],616:[function(t,e,r){\"use strict\";e.exports={visible:{valType:\"boolean\",editType:\"calc\"},type:{valType:\"enumerated\",values:[\"percent\",\"constant\",\"sqrt\",\"data\"],editType:\"calc\"},symmetric:{valType:\"boolean\",editType:\"calc\"},array:{valType:\"data_array\",editType:\"calc\"},arrayminus:{valType:\"data_array\",editType:\"calc\"},value:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},valueminus:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},traceref:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},tracerefminus:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},copy_ystyle:{valType:\"boolean\",editType:\"plot\"},copy_zstyle:{valType:\"boolean\",editType:\"style\"},color:{valType:\"color\",editType:\"style\"},thickness:{valType:\"number\",min:0,dflt:2,editType:\"style\"},width:{valType:\"number\",min:0,editType:\"plot\"},editType:\"calc\",_deprecated:{opacity:{valType:\"number\",editType:\"style\"}}}},{}],617:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=t(\"./compute_error\");function l(t,e,r,i){var l=e[\"error_\"+i]||{},c=[];if(l.visible&&-1!==[\"linear\",\"log\"].indexOf(r.type)){for(var u=s(l),h=0;h<t.length;h++){var f=t[h],p=f.i;if(void 0===p)p=h;else if(null===p)continue;var d=f[i];if(n(r.c2l(d))){var g=u(d,p);if(n(g[0])&&n(g[1])){var v=f[i+\"s\"]=d-g[0],m=f[i+\"h\"]=d+g[1];c.push(v,m)}}}var y=r._id,x=e._extremes[y],b=a.findExtremes(r,c,o.extendFlat({tozero:x.opts.tozero},{padded:!0}));x.min=x.min.concat(b.min),x.max=x.max.concat(b.max)}}e.exports=function(t){for(var e=t.calcdata,r=0;r<e.length;r++){var n=e[r],o=n[0].trace;if(!0===o.visible&&i.traceIs(o,\"errorBarsOK\")){var s=a.getFromId(t,o.xaxis),c=a.getFromId(t,o.yaxis);l(n,o,s,\"x\"),l(n,o,c,\"y\")}}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./compute_error\":618,\"fast-isnumeric\":225}],618:[function(t,e,r){\"use strict\";function n(t,e){return\"percent\"===t?function(t){return Math.abs(t*e/100)}:\"constant\"===t?function(){return Math.abs(e)}:\"sqrt\"===t?function(t){return Math.sqrt(Math.abs(t))}:void 0}e.exports=function(t){var e=t.type,r=t.symmetric;if(\"data\"===e){var i=t.array||[];if(r)return function(t,e){var r=+i[e];return[r,r]};var a=t.arrayminus||[];return function(t,e){var r=+i[e],n=+a[e];return isNaN(r)&&isNaN(n)?[NaN,NaN]:[n||0,r||0]}}var o=n(e,t.value),s=n(e,t.valueminus);return r||void 0===t.valueminus?function(t){var e=o(t);return[e,e]}:function(t){return[s(t),o(t)]}}},{}],619:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../plot_api/plot_template\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){var c=\"error_\"+l.axis,u=o.newContainer(e,c),h=t[c]||{};function f(t,e){return a.coerce(h,u,s,t,e)}if(!1!==f(\"visible\",void 0!==h.array||void 0!==h.value||\"sqrt\"===h.type)){var p=f(\"type\",\"array\"in h?\"data\":\"percent\"),d=!0;\"sqrt\"!==p&&(d=f(\"symmetric\",!((\"data\"===p?\"arrayminus\":\"valueminus\")in h))),\"data\"===p?(f(\"array\"),f(\"traceref\"),d||(f(\"arrayminus\"),f(\"tracerefminus\"))):\"percent\"!==p&&\"constant\"!==p||(f(\"value\"),d||f(\"valueminus\"));var g=\"copy_\"+l.inherit+\"style\";if(l.inherit)(e[\"error_\"+l.inherit]||{}).visible&&f(g,!(h.color||n(h.thickness)||n(h.width)));l.inherit&&u[g]||(f(\"color\",r),f(\"thickness\"),f(\"width\",i.traceIs(e,\"gl3d\")?0:4))}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../registry\":847,\"./attributes\":616,\"fast-isnumeric\":225}],620:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"./attributes\"),o={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a)};delete o.error_x.copy_zstyle,delete o.error_y.copy_zstyle,delete o.error_y.copy_ystyle;var s={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a),error_z:n.extendFlat({},a)};delete s.error_x.copy_ystyle,delete s.error_y.copy_ystyle,delete s.error_z.copy_ystyle,delete s.error_z.copy_zstyle,e.exports={moduleType:\"component\",name:\"errorbars\",schema:{traces:{scatter:o,bar:o,histogram:o,scatter3d:i(s,\"calc\",\"nested\"),scattergl:i(o,\"calc\",\"nested\")}},supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),makeComputeError:t(\"./compute_error\"),plot:t(\"./plot\"),style:t(\"./style\"),hoverInfo:function(t,e,r){(e.error_y||{}).visible&&(r.yerr=t.yh-t.y,e.error_y.symmetric||(r.yerrneg=t.y-t.ys));(e.error_x||{}).visible&&(r.xerr=t.xh-t.x,e.error_x.symmetric||(r.xerrneg=t.x-t.xs))}}},{\"../../lib\":719,\"../../plot_api/edit_types\":750,\"./attributes\":616,\"./calc\":617,\"./compute_error\":618,\"./defaults\":619,\"./plot\":621,\"./style\":622}],621:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../drawing\"),o=t(\"../../traces/scatter/subtypes\");e.exports=function(t,e,r,s){var l=r.xaxis,c=r.yaxis,u=s&&s.duration>0;e.each(function(e){var h,f=e[0].trace,p=f.error_x||{},d=f.error_y||{};f.ids&&(h=function(t){return t.id});var g=o.hasMarkers(f)&&f.marker.maxdisplayed>0;d.visible||p.visible||(e=[]);var v=n.select(this).selectAll(\"g.errorbar\").data(e,h);if(v.exit().remove(),e.length){p.visible||v.selectAll(\"path.xerror\").remove(),d.visible||v.selectAll(\"path.yerror\").remove(),v.style(\"opacity\",1);var m=v.enter().append(\"g\").classed(\"errorbar\",!0);u&&m.style(\"opacity\",0).transition().duration(s.duration).style(\"opacity\",1),a.setClipUrl(v,r.layerClipId,t),v.each(function(t){var e=n.select(this),r=function(t,e,r){var n={x:e.c2p(t.x),y:r.c2p(t.y)};void 0!==t.yh&&(n.yh=r.c2p(t.yh),n.ys=r.c2p(t.ys),i(n.ys)||(n.noYS=!0,n.ys=r.c2p(t.ys,!0)));void 0!==t.xh&&(n.xh=e.c2p(t.xh),n.xs=e.c2p(t.xs),i(n.xs)||(n.noXS=!0,n.xs=e.c2p(t.xs,!0)));return n}(t,l,c);if(!g||t.vis){var a,o=e.select(\"path.yerror\");if(d.visible&&i(r.x)&&i(r.yh)&&i(r.ys)){var h=d.width;a=\"M\"+(r.x-h)+\",\"+r.yh+\"h\"+2*h+\"m-\"+h+\",0V\"+r.ys,r.noYS||(a+=\"m-\"+h+\",0h\"+2*h),!o.size()?o=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"yerror\",!0):u&&(o=o.transition().duration(s.duration).ease(s.easing)),o.attr(\"d\",a)}else o.remove();var f=e.select(\"path.xerror\");if(p.visible&&i(r.y)&&i(r.xh)&&i(r.xs)){var v=(p.copy_ystyle?d:p).width;a=\"M\"+r.xh+\",\"+(r.y-v)+\"v\"+2*v+\"m0,-\"+v+\"H\"+r.xs,r.noXS||(a+=\"m0,-\"+v+\"v\"+2*v),!f.size()?f=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"xerror\",!0):u&&(f=f.transition().duration(s.duration).ease(s.easing)),f.attr(\"d\",a)}else f.remove()}})}})}},{\"../../traces/scatter/subtypes\":1135,\"../drawing\":614,d3:163,\"fast-isnumeric\":225}],622:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\");e.exports=function(t){t.each(function(t){var e=t[0].trace,r=e.error_y||{},a=e.error_x||{},o=n.select(this);o.selectAll(\"path.yerror\").style(\"stroke-width\",r.thickness+\"px\").call(i.stroke,r.color),a.copy_ystyle&&(a=r),o.selectAll(\"path.xerror\").style(\"stroke-width\",a.thickness+\"px\").call(i.stroke,a.color)})}},{\"../color\":593,d3:163}],623:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./layout_attributes\").hoverlabel,a=t(\"../../lib/extend\").extendFlat;e.exports={hoverlabel:{bgcolor:a({},i.bgcolor,{arrayOk:!0}),bordercolor:a({},i.bordercolor,{arrayOk:!0}),font:n({arrayOk:!0,editType:\"none\"}),align:a({},i.align,{arrayOk:!0}),namelength:a({},i.namelength,{arrayOk:!0}),editType:\"none\"}}},{\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"./layout_attributes\":633}],624:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");function a(t,e,r,i){i=i||n.identity,Array.isArray(t)&&(e[0][r]=i(t))}e.exports=function(t){var e=t.calcdata,r=t._fullLayout;function o(t){return function(e){return n.coerceHoverinfo({hoverinfo:e},{_module:t._module},r)}}for(var s=0;s<e.length;s++){var l=e[s],c=l[0].trace;if(!i.traceIs(c,\"pie-like\")){var u=i.traceIs(c,\"2dMap\")?a:n.fillArray;u(c.hoverinfo,l,\"hi\",o(c)),c.hovertemplate&&u(c.hovertemplate,l,\"ht\"),c.hoverlabel&&(u(c.hoverlabel.bgcolor,l,\"hbg\"),u(c.hoverlabel.bordercolor,l,\"hbc\"),u(c.hoverlabel.font.size,l,\"hts\"),u(c.hoverlabel.font.color,l,\"htc\"),u(c.hoverlabel.font.family,l,\"htf\"),u(c.hoverlabel.namelength,l,\"hnl\"),u(c.hoverlabel.align,l,\"hta\"))}}}},{\"../../lib\":719,\"../../registry\":847}],625:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./hover\").hover;e.exports=function(t,e,r){var a=n.getComponentMethod(\"annotations\",\"onClick\")(t,t._hoverdata);function o(){t.emit(\"plotly_click\",{points:t._hoverdata,event:e})}void 0!==r&&i(t,e,r,!0),t._hoverdata&&e&&e.target&&(a&&a.then?a.then(o):o(),e.stopImmediatePropagation&&e.stopImmediatePropagation())}},{\"../../registry\":847,\"./hover\":629}],626:[function(t,e,r){\"use strict\";e.exports={YANGLE:60,HOVERARROWSIZE:6,HOVERTEXTPAD:3,HOVERFONTSIZE:13,HOVERFONT:\"Arial, sans-serif\",HOVERMINTIME:50,HOVERID:\"-hover\"}},{}],627:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./hoverlabel_defaults\");e.exports=function(t,e,r,o){var s=n.extendFlat({},o.hoverlabel);e.hovertemplate&&(s.namelength=-1),a(t,e,function(r,a){return n.coerce(t,e,i,r,a)},s)}},{\"../../lib\":719,\"./attributes\":623,\"./hoverlabel_defaults\":630}],628:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");r.getSubplot=function(t){return t.subplot||t.xaxis+t.yaxis||t.geo},r.isTraceInSubplots=function(t,e){if(\"splom\"===t.type){for(var n=t.xaxes||[],i=t.yaxes||[],a=0;a<n.length;a++)for(var o=0;o<i.length;o++)if(-1!==e.indexOf(n[a]+i[o]))return!0;return!1}return-1!==e.indexOf(r.getSubplot(t))},r.flat=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=e;return r},r.p2c=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=t[n].p2c(e);return r},r.getDistanceFunction=function(t,e,n,i){return\"closest\"===t?i||r.quadrature(e,n):\"x\"===t?e:n},r.getClosest=function(t,e,r){if(!1!==r.index)r.index>=0&&r.index<t.length?r.distance=0:r.index=!1;else for(var n=0;n<t.length;n++){var i=e(t[n]);i<=r.distance&&(r.index=n,r.distance=i)}return r},r.inbox=function(t,e,r){return t*e<0||0===t?r:1/0},r.quadrature=function(t,e){return function(r){var n=t(r),i=e(r);return Math.sqrt(n*n+i*i)}},r.makeEventData=function(t,e,n){var i=\"index\"in t?t.index:t.pointNumber,a={data:e._input,fullData:e,curveNumber:e.index,pointNumber:i};if(e._indexToPoints){var o=e._indexToPoints[i];1===o.length?a.pointIndex=o[0]:a.pointIndices=o}else a.pointIndex=i;return e._module.eventData?a=e._module.eventData(a,t,e,n,i):(\"xVal\"in t?a.x=t.xVal:\"x\"in t&&(a.x=t.x),\"yVal\"in t?a.y=t.yVal:\"y\"in t&&(a.y=t.y),t.xa&&(a.xaxis=t.xa),t.ya&&(a.yaxis=t.ya),void 0!==t.zLabelVal&&(a.z=t.zLabelVal)),r.appendArrayPointValue(a,e,i),a},r.appendArrayPointValue=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){var u=o(n.nestedProperty(e,l).get(),r);void 0!==u&&(t[c]=u)}}},r.appendArrayMultiPointValues=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){for(var u=n.nestedProperty(e,l).get(),h=new Array(r.length),f=0;f<r.length;f++)h[f]=o(u,r[f]);t[c]=h}}};var i={ids:\"id\",locations:\"location\",labels:\"label\",values:\"value\",\"marker.colors\":\"color\",parents:\"parent\"};function a(t){return i[t]||t}function o(t,e){return Array.isArray(e)?Array.isArray(t)&&Array.isArray(t[e[0]])?t[e[0]][e[1]]:void 0:t[e]}},{\"../../lib\":719}],629:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../lib\"),s=t(\"../../lib/events\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib/override_cursor\"),u=t(\"../drawing\"),h=t(\"../color\"),f=t(\"../dragelement\"),p=t(\"../../plots/cartesian/axes\"),d=t(\"../../registry\"),g=t(\"./helpers\"),v=t(\"./constants\"),m=v.YANGLE,y=Math.PI*m/180,x=1/Math.sin(y),b=Math.cos(y),_=Math.sin(y),w=v.HOVERARROWSIZE,k=v.HOVERTEXTPAD;r.hover=function(t,e,r,a){t=o.getGraphDiv(t),o.throttle(t._fullLayout._uid+v.HOVERID,v.HOVERMINTIME,function(){!function(t,e,r,a){r||(r=\"xy\");var l=Array.isArray(r)?r:[r],u=t._fullLayout,v=u._plots||[],m=v[r],y=u._has(\"cartesian\");if(m){var b=m.overlays.map(function(t){return t.id});l=l.concat(b)}for(var _=l.length,w=new Array(_),k=new Array(_),T=!1,L=0;L<_;L++){var P=l[L],O=v[P];if(O)T=!0,w[L]=p.getFromId(t,O.xaxis._id),k[L]=p.getFromId(t,O.yaxis._id);else{var z=u[P]._subplot;w[L]=z.xaxis,k[L]=z.yaxis}}var I=e.hovermode||u.hovermode;I&&!T&&(I=\"closest\");if(-1===[\"x\",\"y\",\"closest\"].indexOf(I)||!t.calcdata||t.querySelector(\".zoombox\")||t._dragging)return f.unhoverRaw(t,e);var D,R,F,B,N,j,U,V,q,H,G,Y,W,X=-1===u.hoverdistance?1/0:u.hoverdistance,Z=-1===u.spikedistance?1/0:u.spikedistance,J=[],K=[],$={hLinePoint:null,vLinePoint:null},Q=!1;if(Array.isArray(e))for(I=\"array\",F=0;F<e.length;F++)(N=t.calcdata[e[F].curveNumber||0])&&(j=N[0].trace,\"skip\"!==N[0].trace.hoverinfo&&(K.push(N),\"h\"===j.orientation&&(Q=!0)));else{for(B=0;B<t.calcdata.length;B++)N=t.calcdata[B],\"skip\"!==(j=N[0].trace).hoverinfo&&g.isTraceInSubplots(j,l)&&(K.push(N),\"h\"===j.orientation&&(Q=!0));var tt,et,rt=!e.target;if(rt)tt=\"xpx\"in e?e.xpx:w[0]._length/2,et=\"ypx\"in e?e.ypx:k[0]._length/2;else{if(!1===s.triggerHandler(t,\"plotly_beforehover\",e))return;var nt=e.target.getBoundingClientRect();if(tt=e.clientX-nt.left,et=e.clientY-nt.top,tt<0||tt>w[0]._length||et<0||et>k[0]._length)return f.unhoverRaw(t,e)}if(e.pointerX=tt+w[0]._offset,e.pointerY=et+k[0]._offset,D=\"xval\"in e?g.flat(l,e.xval):g.p2c(w,tt),R=\"yval\"in e?g.flat(l,e.yval):g.p2c(k,et),!i(D[0])||!i(R[0]))return o.warn(\"Fx.hover failed\",e,t),f.unhoverRaw(t,e)}var it=1/0;for(B=0;B<K.length;B++)if((N=K[B])&&N[0]&&N[0].trace&&!0===(j=N[0].trace).visible&&0!==j._length&&-1===[\"carpet\",\"contourcarpet\"].indexOf(j._module.name)){if(\"splom\"===j.type?U=l[V=0]:(U=g.getSubplot(j),V=l.indexOf(U)),q=I,Y={cd:N,trace:j,xa:w[V],ya:k[V],maxHoverDistance:X,maxSpikeDistance:Z,index:!1,distance:Math.min(it,X),spikeDistance:1/0,xSpike:void 0,ySpike:void 0,color:h.defaultLine,name:j.name,x0:void 0,x1:void 0,y0:void 0,y1:void 0,xLabelVal:void 0,yLabelVal:void 0,zLabelVal:void 0,text:void 0},u[U]&&(Y.subplot=u[U]._subplot),u._splomScenes&&u._splomScenes[j.uid]&&(Y.scene=u._splomScenes[j.uid]),W=J.length,\"array\"===q){var at=e[B];\"pointNumber\"in at?(Y.index=at.pointNumber,q=\"closest\"):(q=\"\",\"xval\"in at&&(H=at.xval,q=\"x\"),\"yval\"in at&&(G=at.yval,q=q?\"closest\":\"y\"))}else H=D[V],G=R[V];if(0!==X)if(j._module&&j._module.hoverPoints){var ot=j._module.hoverPoints(Y,H,G,q,u._hoverlayer);if(ot)for(var st,lt=0;lt<ot.length;lt++)st=ot[lt],i(st.x0)&&i(st.y0)&&J.push(S(st,I))}else o.log(\"Unrecognized trace type in hover:\",j);if(\"closest\"===I&&J.length>W&&(J.splice(0,W),it=J[0].distance),y&&0!==Z&&0===J.length){Y.distance=Z,Y.index=!1;var ct=j._module.hoverPoints(Y,H,G,\"closest\",u._hoverlayer);if(ct&&(ct=ct.filter(function(t){return t.spikeDistance<=Z})),ct&&ct.length){var ut,ht=ct.filter(function(t){return t.xa.showspikes});if(ht.length){var ft=ht[0];i(ft.x0)&&i(ft.y0)&&(ut=vt(ft),(!$.vLinePoint||$.vLinePoint.spikeDistance>ut.spikeDistance)&&($.vLinePoint=ut))}var pt=ct.filter(function(t){return t.ya.showspikes});if(pt.length){var dt=pt[0];i(dt.x0)&&i(dt.y0)&&(ut=vt(dt),(!$.hLinePoint||$.hLinePoint.spikeDistance>ut.spikeDistance)&&($.hLinePoint=ut))}}}}function gt(t,e){for(var r,n=null,i=1/0,a=0;a<t.length;a++)(r=t[a].spikeDistance)<i&&r<=e&&(n=t[a],i=r);return n}function vt(t){return t?{xa:t.xa,ya:t.ya,x:void 0!==t.xSpike?t.xSpike:(t.x0+t.x1)/2,y:void 0!==t.ySpike?t.ySpike:(t.y0+t.y1)/2,distance:t.distance,spikeDistance:t.spikeDistance,curveNumber:t.trace.index,color:t.color,pointNumber:t.index}:null}var mt={fullLayout:u,container:u._hoverlayer,outerContainer:u._paperdiv,event:e},yt=t._spikepoints,xt={vLinePoint:$.vLinePoint,hLinePoint:$.hLinePoint};if(t._spikepoints=xt,y&&0!==Z&&0!==J.length){var bt=J.filter(function(t){return t.ya.showspikes}),_t=gt(bt,Z);$.hLinePoint=vt(_t);var wt=J.filter(function(t){return t.xa.showspikes}),kt=gt(wt,Z);$.vLinePoint=vt(kt)}if(0===J.length){var Tt=f.unhoverRaw(t,e);return!y||null===$.hLinePoint&&null===$.vLinePoint||C(yt)&&E($,mt),Tt}y&&C(yt)&&E($,mt);J.sort(function(t,e){return t.distance-e.distance});var At=t._hoverdata,Mt=[];for(F=0;F<J.length;F++){var St=J[F],Et=g.makeEventData(St,St.trace,St.cd);if(!1!==St.hovertemplate){var Ct=!1;St.cd[St.index]&&St.cd[St.index].ht&&(Ct=St.cd[St.index].ht),St.hovertemplate=Ct||St.trace.hovertemplate||!1}St.eventData=[Et],Mt.push(Et)}t._hoverdata=Mt;var Lt=\"y\"===I&&(K.length>1||J.length>1)||\"closest\"===I&&Q&&J.length>1,Pt=h.combine(u.plot_bgcolor||h.background,u.paper_bgcolor),Ot={hovermode:I,rotateLabels:Lt,bgColor:Pt,container:u._hoverlayer,outerContainer:u._paperdiv,commonLabelOpts:u.hoverlabel,hoverdistance:u.hoverdistance},zt=A(J,Ot,t);if(function(t,e,r){var n,i,a,o,s,l,c,u=0,h=1,f=t.size(),p=new Array(f),d=0;function g(t){var e=t[0],r=t[t.length-1];if(i=e.pmin-e.pos-e.dp+e.size,a=r.pos+r.dp+r.size-e.pmax,i>.01){for(s=t.length-1;s>=0;s--)t[s].dp+=i;n=!1}if(!(a<.01)){if(i<-.01){for(s=t.length-1;s>=0;s--)t[s].dp-=a;n=!1}if(n){var c=0;for(o=0;o<t.length;o++)(l=t[o]).pos+l.dp+l.size>e.pmax&&c++;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos>e.pmax-1&&(l.del=!0,c--);for(o=0;o<t.length&&!(c<=0);o++)if((l=t[o]).pos<e.pmin+1)for(l.del=!0,c--,a=2*l.size,s=t.length-1;s>=0;s--)t[s].dp-=a;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos+l.dp+l.size>e.pmax&&(l.del=!0,c--)}}}for(t.each(function(t){var n=t[e],i=\"x\"===n._id.charAt(0),a=n.range;0===d&&a&&a[0]>a[1]!==i&&(h=-1),p[d++]=[{datum:t,traceIndex:t.trace.index,dp:0,pos:t.pos,posref:t.posref,size:t.by*(i?x:1)/2,pmin:0,pmax:i?r.width:r.height}]}),p.sort(function(t,e){return t[0].posref-e[0].posref||h*(e[0].traceIndex-t[0].traceIndex)});!n&&u<=f;){for(u++,n=!0,o=0;o<p.length-1;){var v=p[o],m=p[o+1],y=v[v.length-1],b=m[0];if((i=y.pos+y.dp+y.size-b.pos-b.dp+b.size)>.01&&y.pmin===b.pmin&&y.pmax===b.pmax){for(s=m.length-1;s>=0;s--)m[s].dp+=i;for(v.push.apply(v,m),p.splice(o+1,1),c=0,s=v.length-1;s>=0;s--)c+=v[s].dp;for(a=c/v.length,s=v.length-1;s>=0;s--)v[s].dp-=a;n=!1}else o++}p.forEach(g)}for(o=p.length-1;o>=0;o--){var _=p[o];for(s=_.length-1;s>=0;s--){var w=_[s],k=w.datum;k.offset=w.dp,k.del=w.del}}}(zt,Lt?\"xa\":\"ya\",u),M(zt,Lt),e.target&&e.target.tagName){var It=d.getComponentMethod(\"annotations\",\"hasClickToShow\")(t,Mt);c(n.select(e.target),It?\"pointer\":\"\")}if(!e.target||a||!function(t,e,r){if(!r||r.length!==t._hoverdata.length)return!0;for(var n=r.length-1;n>=0;n--){var i=r[n],a=t._hoverdata[n];if(i.curveNumber!==a.curveNumber||String(i.pointNumber)!==String(a.pointNumber)||String(i.pointNumbers)!==String(a.pointNumbers))return!0}return!1}(t,0,At))return;At&&t.emit(\"plotly_unhover\",{event:e,points:At});t.emit(\"plotly_hover\",{event:e,points:t._hoverdata,xaxes:w,yaxes:k,xvals:D,yvals:R})}(t,e,r,a)})},r.loneHover=function(t,e){var r=!0;Array.isArray(t)||(r=!1,t=[t]);var i=t.map(function(t){return{color:t.color||h.defaultLine,x0:t.x0||t.x||0,x1:t.x1||t.x||0,y0:t.y0||t.y||0,y1:t.y1||t.y||0,xLabel:t.xLabel,yLabel:t.yLabel,zLabel:t.zLabel,text:t.text,name:t.name,idealAlign:t.idealAlign,borderColor:t.borderColor,fontFamily:t.fontFamily,fontSize:t.fontSize,fontColor:t.fontColor,nameLength:t.nameLength,textAlign:t.textAlign,trace:t.trace||{index:0,hoverinfo:\"\"},xa:{_offset:0},ya:{_offset:0},index:0,hovertemplate:t.hovertemplate||!1,eventData:t.eventData||!1,hovertemplateLabels:t.hovertemplateLabels||!1}}),a=n.select(e.container),o=e.outerContainer?n.select(e.outerContainer):a,s={hovermode:\"closest\",rotateLabels:!1,bgColor:e.bgColor||h.background,container:a,outerContainer:o},l=A(i,s,e.gd),c=0,u=0;return l.sort(function(t,e){return t.y0-e.y0}).each(function(t,r){var n=t.y0-t.by/2;t.offset=n-5<c?c-n+5:0,c=n+t.by+t.offset,r===e.anchorIndex&&(u=t.offset)}).each(function(t){t.offset-=u}),M(l,s.rotateLabels),r?l:l.node()};var T=/<extra>([\\s\\S]*)<\\/extra>/;function A(t,e,r){var i=r._fullLayout,a=e.hovermode,s=e.rotateLabels,c=e.bgColor,f=e.container,p=e.outerContainer,d=e.commonLabelOpts||{},g=e.fontFamily||v.HOVERFONT,y=e.fontSize||v.HOVERFONTSIZE,x=t[0],b=x.xa,_=x.ya,A=\"y\"===a?\"yLabel\":\"xLabel\",M=x[A],S=(String(M)||\"\").split(\" \")[0],E=p.node().getBoundingClientRect(),C=E.top,P=E.width,O=E.height,z=void 0!==M&&x.distance<=e.hoverdistance&&(\"x\"===a||\"y\"===a);if(z){var I,D,R=!0;for(I=0;I<t.length;I++)if(R&&void 0===t[I].zLabel&&(R=!1),D=t[I].hoverinfo||t[I].trace.hoverinfo){var F=Array.isArray(D)?D:D.split(\"+\");if(-1===F.indexOf(\"all\")&&-1===F.indexOf(a)){z=!1;break}}R&&(z=!1)}var B=f.selectAll(\"g.axistext\").data(z?[0]:[]);B.enter().append(\"g\").classed(\"axistext\",!0),B.exit().remove(),B.each(function(){var e=n.select(this),i=o.ensureSingle(e,\"path\",\"\",function(t){t.style({\"stroke-width\":\"1px\"})}),s=o.ensureSingle(e,\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),c=d.bgcolor||h.defaultLine,f=d.bordercolor||h.contrast(c),p=h.contrast(c);i.style({fill:c,stroke:f}),s.text(M).call(u.font,d.font.family||g,d.font.size||y,d.font.color||p).call(l.positionText,0,0).call(l.convertToTspans,r),e.attr(\"transform\",\"\");var v=s.node().getBoundingClientRect();if(\"x\"===a){s.attr(\"text-anchor\",\"middle\").call(l.positionText,0,\"top\"===b.side?C-v.bottom-w-k:C-v.top+w+k);var m=\"top\"===b.side?\"-\":\"\";i.attr(\"d\",\"M0,0L\"+w+\",\"+m+w+\"H\"+(k+v.width/2)+\"v\"+m+(2*k+v.height)+\"H-\"+(k+v.width/2)+\"V\"+m+w+\"H-\"+w+\"Z\"),e.attr(\"transform\",\"translate(\"+(b._offset+(x.x0+x.x1)/2)+\",\"+(_._offset+(\"top\"===b.side?0:_._length))+\")\")}else{s.attr(\"text-anchor\",\"right\"===_.side?\"start\":\"end\").call(l.positionText,(\"right\"===_.side?1:-1)*(k+w),C-v.top-v.height/2);var T=\"right\"===_.side?\"\":\"-\";i.attr(\"d\",\"M0,0L\"+T+w+\",\"+w+\"V\"+(k+v.height/2)+\"h\"+T+(2*k+v.width)+\"V-\"+(k+v.height/2)+\"H\"+T+w+\"V-\"+w+\"Z\"),e.attr(\"transform\",\"translate(\"+(b._offset+(\"right\"===_.side?b._length:0))+\",\"+(_._offset+(x.y0+x.y1)/2)+\")\")}t=t.filter(function(t){return void 0!==t.zLabelVal||(t[A]||\"\").split(\" \")[0]===S})});var N=f.selectAll(\"g.hovertext\").data(t,function(t){return[t.trace.index,t.index,t.x0,t.y0,t.name,t.attr,t.xa,t.ya||\"\"].join(\",\")});return N.enter().append(\"g\").classed(\"hovertext\",!0).each(function(){var t=n.select(this);t.append(\"rect\").call(h.fill,h.addOpacity(c,.8)),t.append(\"text\").classed(\"name\",!0),t.append(\"path\").style(\"stroke-width\",\"1px\"),t.append(\"text\").classed(\"nums\",!0).call(u.font,g,y)}),N.exit().remove(),N.each(function(t){var e=n.select(this).attr(\"transform\",\"\"),f=\"\",p=\"\",d=t.bgcolor||t.color,v=h.combine(h.opacity(d)?d:h.defaultLine,c),x=h.combine(h.opacity(t.color)?t.color:h.defaultLine,c),b=t.borderColor||h.contrast(v);void 0!==t.nameOverride&&(t.name=t.nameOverride),t.name&&(t.trace._meta&&(t.name=o.templateString(t.name,t.trace._meta)),f=L(t.name,t.nameLength)),void 0!==t.zLabel?(void 0!==t.xLabel&&(p+=\"x: \"+t.xLabel+\"<br>\"),void 0!==t.yLabel&&(p+=\"y: \"+t.yLabel+\"<br>\"),\"choropleth\"!==t.trace.type&&\"choroplethmapbox\"!==t.trace.type&&(p+=(p?\"z: \":\"\")+t.zLabel)):z&&t[a+\"Label\"]===M?p=t[(\"x\"===a?\"y\":\"x\")+\"Label\"]||\"\":void 0===t.xLabel?void 0!==t.yLabel&&\"scattercarpet\"!==t.trace.type&&(p=t.yLabel):p=void 0===t.yLabel?t.xLabel:\"(\"+t.xLabel+\", \"+t.yLabel+\")\",!t.text&&0!==t.text||Array.isArray(t.text)||(p+=(p?\"<br>\":\"\")+t.text),void 0!==t.extraText&&(p+=(p?\"<br>\":\"\")+t.extraText),\"\"!==p||t.hovertemplate||(\"\"===f&&e.remove(),p=f);var _=i._d3locale,A=t.hovertemplate||!1,S=t.hovertemplateLabels||t,E=t.eventData[0]||{};A&&(p=(p=o.hovertemplateString(A,S,_,E,t.trace._meta)).replace(T,function(e,r){return f=L(r,t.nameLength),\"\"}));var I=e.select(\"text.nums\").call(u.font,t.fontFamily||g,t.fontSize||y,t.fontColor||b).text(p).attr(\"data-notex\",1).call(l.positionText,0,0).call(l.convertToTspans,r),D=e.select(\"text.name\"),R=0,F=0;if(f&&f!==p){D.call(u.font,t.fontFamily||g,t.fontSize||y,x).text(f).attr(\"data-notex\",1).call(l.positionText,0,0).call(l.convertToTspans,r);var B=D.node().getBoundingClientRect();R=B.width+2*k,F=B.height+2*k}else D.remove(),e.select(\"rect\").remove();e.select(\"path\").style({fill:v,stroke:b});var N,j,U=I.node().getBoundingClientRect(),V=t.xa._offset+(t.x0+t.x1)/2,q=t.ya._offset+(t.y0+t.y1)/2,H=Math.abs(t.x1-t.x0),G=Math.abs(t.y1-t.y0),Y=U.width+w+k+R;if(t.ty0=C-U.top,t.bx=U.width+2*k,t.by=Math.max(U.height+2*k,F),t.anchor=\"start\",t.txwidth=U.width,t.tx2width=R,t.offset=0,s)t.pos=V,N=q+G/2+Y<=O,j=q-G/2-Y>=0,\"top\"!==t.idealAlign&&N||!j?N?(q+=G/2,t.anchor=\"start\"):t.anchor=\"middle\":(q-=G/2,t.anchor=\"end\");else if(t.pos=q,N=V+H/2+Y<=P,j=V-H/2-Y>=0,\"left\"!==t.idealAlign&&N||!j)if(N)V+=H/2,t.anchor=\"start\";else{t.anchor=\"middle\";var W=Y/2,X=V+W-P,Z=V-W;X>0&&(V-=X),Z<0&&(V+=-Z)}else V-=H/2,t.anchor=\"end\";I.attr(\"text-anchor\",t.anchor),R&&D.attr(\"text-anchor\",t.anchor),e.attr(\"transform\",\"translate(\"+V+\",\"+q+\")\"+(s?\"rotate(\"+m+\")\":\"\"))}),N}function M(t,e){t.each(function(t){var r=n.select(this);if(t.del)return r.remove();var i=r.select(\"text.nums\"),a=t.anchor,o=\"end\"===a?-1:1,s={start:1,end:-1,middle:0}[a],c=s*(w+k),h=c+s*(t.txwidth+k),f=0,p=t.offset;\"middle\"===a&&(c-=t.tx2width/2,h+=t.txwidth/2+k),e&&(p*=-_,f=t.offset*b),r.select(\"path\").attr(\"d\",\"middle\"===a?\"M-\"+(t.bx/2+t.tx2width/2)+\",\"+(p-t.by/2)+\"h\"+t.bx+\"v\"+t.by+\"h-\"+t.bx+\"Z\":\"M0,0L\"+(o*w+f)+\",\"+(w+p)+\"v\"+(t.by/2-w)+\"h\"+o*t.bx+\"v-\"+t.by+\"H\"+(o*w+f)+\"V\"+(p-w)+\"Z\");var d=c+f,g=p+t.ty0-t.by/2+k,v=t.textAlign||\"auto\";\"auto\"!==v&&(\"left\"===v&&\"start\"!==a?(i.attr(\"text-anchor\",\"start\"),d=\"middle\"===a?-t.bx/2-t.tx2width/2+k:-t.bx-k):\"right\"===v&&\"end\"!==a&&(i.attr(\"text-anchor\",\"end\"),d=\"middle\"===a?t.bx/2-t.tx2width/2-k:t.bx+k)),i.call(l.positionText,d,g),t.tx2width&&(r.select(\"text.name\").call(l.positionText,h+s*k+f,p+t.ty0-t.by/2+k),r.select(\"rect\").call(u.setRect,h+(s-1)*t.tx2width/2+f,p-t.by/2-1,t.tx2width,t.by+2))})}function S(t,e){var r=t.index,n=t.trace||{},a=t.cd[0],s=t.cd[r]||{};function l(t){return t||i(t)&&0===t}var c=Array.isArray(r)?function(t,e){var i=o.castOption(a,r,t);return l(i)?i:o.extractOption({},n,\"\",e)}:function(t,e){return o.extractOption(s,n,t,e)};function u(e,r,n){var i=c(r,n);l(i)&&(t[e]=i)}if(u(\"hoverinfo\",\"hi\",\"hoverinfo\"),u(\"bgcolor\",\"hbg\",\"hoverlabel.bgcolor\"),u(\"borderColor\",\"hbc\",\"hoverlabel.bordercolor\"),u(\"fontFamily\",\"htf\",\"hoverlabel.font.family\"),u(\"fontSize\",\"hts\",\"hoverlabel.font.size\"),u(\"fontColor\",\"htc\",\"hoverlabel.font.color\"),u(\"nameLength\",\"hnl\",\"hoverlabel.namelength\"),u(\"textAlign\",\"hta\",\"hoverlabel.align\"),t.posref=\"y\"===e||\"closest\"===e&&\"h\"===n.orientation?t.xa._offset+(t.x0+t.x1)/2:t.ya._offset+(t.y0+t.y1)/2,t.x0=o.constrain(t.x0,0,t.xa._length),t.x1=o.constrain(t.x1,0,t.xa._length),t.y0=o.constrain(t.y0,0,t.ya._length),t.y1=o.constrain(t.y1,0,t.ya._length),void 0!==t.xLabelVal&&(t.xLabel=\"xLabel\"in t?t.xLabel:p.hoverLabelText(t.xa,t.xLabelVal),t.xVal=t.xa.c2d(t.xLabelVal)),void 0!==t.yLabelVal&&(t.yLabel=\"yLabel\"in t?t.yLabel:p.hoverLabelText(t.ya,t.yLabelVal),t.yVal=t.ya.c2d(t.yLabelVal)),void 0!==t.zLabelVal&&void 0===t.zLabel&&(t.zLabel=String(t.zLabelVal)),!(isNaN(t.xerr)||\"log\"===t.xa.type&&t.xerr<=0)){var h=p.tickText(t.xa,t.xa.c2l(t.xerr),\"hover\").text;void 0!==t.xerrneg?t.xLabel+=\" +\"+h+\" / -\"+p.tickText(t.xa,t.xa.c2l(t.xerrneg),\"hover\").text:t.xLabel+=\" \\xb1 \"+h,\"x\"===e&&(t.distance+=1)}if(!(isNaN(t.yerr)||\"log\"===t.ya.type&&t.yerr<=0)){var f=p.tickText(t.ya,t.ya.c2l(t.yerr),\"hover\").text;void 0!==t.yerrneg?t.yLabel+=\" +\"+f+\" / -\"+p.tickText(t.ya,t.ya.c2l(t.yerrneg),\"hover\").text:t.yLabel+=\" \\xb1 \"+f,\"y\"===e&&(t.distance+=1)}var d=t.hoverinfo||t.trace.hoverinfo;return d&&\"all\"!==d&&(-1===(d=Array.isArray(d)?d:d.split(\"+\")).indexOf(\"x\")&&(t.xLabel=void 0),-1===d.indexOf(\"y\")&&(t.yLabel=void 0),-1===d.indexOf(\"z\")&&(t.zLabel=void 0),-1===d.indexOf(\"text\")&&(t.text=void 0),-1===d.indexOf(\"name\")&&(t.name=void 0)),t}function E(t,e){var r,n,i=e.container,o=e.fullLayout,s=e.event,l=!!t.hLinePoint,c=!!t.vLinePoint;if(i.selectAll(\".spikeline\").remove(),c||l){var f=h.combine(o.plot_bgcolor,o.paper_bgcolor);if(l){var p,d,g=t.hLinePoint;r=g&&g.xa,\"cursor\"===(n=g&&g.ya).spikesnap?(p=s.pointerX,d=s.pointerY):(p=r._offset+g.x,d=n._offset+g.y);var v,m,y=a.readability(g.color,f)<1.5?h.contrast(f):g.color,x=n.spikemode,b=n.spikethickness,_=n.spikecolor||y,w=n._boundingBox,k=(w.left+w.right)/2<p?w.right:w.left;-1===x.indexOf(\"toaxis\")&&-1===x.indexOf(\"across\")||(-1!==x.indexOf(\"toaxis\")&&(v=k,m=p),-1!==x.indexOf(\"across\")&&(v=n._counterSpan[0],m=n._counterSpan[1]),i.insert(\"line\",\":first-child\").attr({x1:v,x2:m,y1:d,y2:d,\"stroke-width\":b,stroke:_,\"stroke-dasharray\":u.dashStyle(n.spikedash,b)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),i.insert(\"line\",\":first-child\").attr({x1:v,x2:m,y1:d,y2:d,\"stroke-width\":b+2,stroke:f}).classed(\"spikeline\",!0).classed(\"crisp\",!0)),-1!==x.indexOf(\"marker\")&&i.insert(\"circle\",\":first-child\").attr({cx:k+(\"right\"!==n.side?b:-b),cy:d,r:b,fill:_}).classed(\"spikeline\",!0)}if(c){var T,A,M=t.vLinePoint;r=M&&M.xa,n=M&&M.ya,\"cursor\"===r.spikesnap?(T=s.pointerX,A=s.pointerY):(T=r._offset+M.x,A=n._offset+M.y);var S,E,C=a.readability(M.color,f)<1.5?h.contrast(f):M.color,L=r.spikemode,P=r.spikethickness,O=r.spikecolor||C,z=r._boundingBox,I=(z.top+z.bottom)/2<A?z.bottom:z.top;-1===L.indexOf(\"toaxis\")&&-1===L.indexOf(\"across\")||(-1!==L.indexOf(\"toaxis\")&&(S=I,E=A),-1!==L.indexOf(\"across\")&&(S=r._counterSpan[0],E=r._counterSpan[1]),i.insert(\"line\",\":first-child\").attr({x1:T,x2:T,y1:S,y2:E,\"stroke-width\":P,stroke:O,\"stroke-dasharray\":u.dashStyle(r.spikedash,P)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),i.insert(\"line\",\":first-child\").attr({x1:T,x2:T,y1:S,y2:E,\"stroke-width\":P+2,stroke:f}).classed(\"spikeline\",!0).classed(\"crisp\",!0)),-1!==L.indexOf(\"marker\")&&i.insert(\"circle\",\":first-child\").attr({cx:T,cy:I-(\"top\"!==r.side?P:-P),r:P,fill:O}).classed(\"spikeline\",!0)}}}function C(t,e){return!e||(e.vLinePoint!==t._spikepoints.vLinePoint||e.hLinePoint!==t._spikepoints.hLinePoint)}function L(t,e){return l.plainText(t||\"\",{len:e,allowedTags:[\"br\",\"sub\",\"sup\",\"b\",\"i\",\"em\"]})}},{\"../../lib\":719,\"../../lib/events\":709,\"../../lib/override_cursor\":730,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"./constants\":626,\"./helpers\":628,d3:163,\"fast-isnumeric\":225,tinycolor2:537}],630:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i){r(\"hoverlabel.bgcolor\",(i=i||{}).bgcolor),r(\"hoverlabel.bordercolor\",i.bordercolor),r(\"hoverlabel.namelength\",i.namelength),n.coerceFont(r,\"hoverlabel.font\",i.font),r(\"hoverlabel.align\",i.align)}},{\"../../lib\":719}],631:[function(t,e,r){\"use strict\";t(\"../../constants/docs\").FORMAT_LINK;e.exports=function(t,e){t=t||{};(e=e||{}).description&&e.description;var r=e.keys||[];if(r.length>0){for(var n=[],i=0;i<r.length;i++)n[i]=\"`\"+r[i]+\"`\";\"Finally, the template string has access to \",1===r.length?\"variable \"+n[0]:\"variables \"+n.slice(0,-1).join(\", \")+\" and \"+n.slice(-1)+\".\"}var a={valType:\"string\",dflt:\"\",editType:t.editType||\"none\"};return!1!==t.arrayOk&&(a.arrayOk=!0),a}},{\"../../constants/docs\":690}],632:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../dragelement\"),o=t(\"./helpers\"),s=t(\"./layout_attributes\"),l=t(\"./hover\");e.exports={moduleType:\"component\",name:\"fx\",constants:t(\"./constants\"),schema:{layout:s},attributes:t(\"./attributes\"),layoutAttributes:s,supplyLayoutGlobalDefaults:t(\"./layout_global_defaults\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),getDistanceFunction:o.getDistanceFunction,getClosest:o.getClosest,inbox:o.inbox,quadrature:o.quadrature,appendArrayPointValue:o.appendArrayPointValue,castHoverOption:function(t,e,r){return i.castOption(t,e,\"hoverlabel.\"+r)},castHoverinfo:function(t,e,r){return i.castOption(t,r,\"hoverinfo\",function(r){return i.coerceHoverinfo({hoverinfo:r},{_module:t._module},e)})},hover:l.hover,unhover:a.unhover,loneHover:l.loneHover,loneUnhover:function(t){var e=i.isD3Selection(t)?t:n.select(t);e.selectAll(\"g.hovertext\").remove(),e.selectAll(\".spikeline\").remove()},click:t(\"./click\")}},{\"../../lib\":719,\"../dragelement\":611,\"./attributes\":623,\"./calc\":624,\"./click\":625,\"./constants\":626,\"./defaults\":627,\"./helpers\":628,\"./hover\":629,\"./layout_attributes\":633,\"./layout_defaults\":634,\"./layout_global_defaults\":635,d3:163}],633:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../plots/font_attributes\")({editType:\"none\"});i.family.dflt=n.HOVERFONT,i.size.dflt=n.HOVERFONTSIZE,e.exports={clickmode:{valType:\"flaglist\",flags:[\"event\",\"select\"],dflt:\"event\",editType:\"plot\",extras:[\"none\"]},dragmode:{valType:\"enumerated\",values:[\"zoom\",\"pan\",\"select\",\"lasso\",\"orbit\",\"turntable\",!1],dflt:\"zoom\",editType:\"modebar\"},hovermode:{valType:\"enumerated\",values:[\"x\",\"y\",\"closest\",!1],editType:\"modebar\"},hoverdistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},spikedistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"none\"},bordercolor:{valType:\"color\",editType:\"none\"},font:i,align:{valType:\"enumerated\",values:[\"left\",\"right\",\"auto\"],dflt:\"auto\",editType:\"none\"},namelength:{valType:\"integer\",min:-1,dflt:15,editType:\"none\"},editType:\"none\"},selectdirection:{valType:\"enumerated\",values:[\"h\",\"v\",\"d\",\"any\"],dflt:\"any\",editType:\"none\"}}},{\"../../plots/font_attributes\":793,\"./constants\":626}],634:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){function a(r,a){return n.coerce(t,e,i,r,a)}var o,s=a(\"clickmode\");\"select\"===a(\"dragmode\")&&a(\"selectdirection\"),e._has(\"cartesian\")?s.indexOf(\"select\")>-1?o=\"closest\":(e._isHoriz=function(t,e){for(var r=e._scatterStackOpts||{},n=0;n<t.length;n++){var i=t[n],a=i.xaxis+i.yaxis,o=r[a]||{},s=o[i.stackgroup]||{};if(\"h\"!==i.orientation&&\"h\"!==s.orientation)return!1}return!0}(r,e),o=e._isHoriz?\"y\":\"x\"):o=\"closest\",a(\"hovermode\",o)&&(a(\"hoverdistance\"),a(\"spikedistance\"));var l=e._has(\"mapbox\"),c=e._has(\"geo\"),u=e._basePlotModules.length;\"zoom\"===e.dragmode&&((l||c)&&1===u||l&&c&&2===u)&&(e.dragmode=\"pan\")}},{\"../../lib\":719,\"./layout_attributes\":633}],635:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./hoverlabel_defaults\"),a=t(\"./layout_attributes\");e.exports=function(t,e){i(t,e,function(r,i){return n.coerce(t,e,a,r,i)})}},{\"../../lib\":719,\"./hoverlabel_defaults\":630,\"./layout_attributes\":633}],636:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/regex\").counter,a=t(\"../../plots/domain\").attributes,o=t(\"../../plots/cartesian/constants\").idRegex,s=t(\"../../plot_api/plot_template\"),l={rows:{valType:\"integer\",min:1,editType:\"plot\"},roworder:{valType:\"enumerated\",values:[\"top to bottom\",\"bottom to top\"],dflt:\"top to bottom\",editType:\"plot\"},columns:{valType:\"integer\",min:1,editType:\"plot\"},subplots:{valType:\"info_array\",freeLength:!0,dimensions:2,items:{valType:\"enumerated\",values:[i(\"xy\").toString(),\"\"],editType:\"plot\"},editType:\"plot\"},xaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.x.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},yaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.y.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},pattern:{valType:\"enumerated\",values:[\"independent\",\"coupled\"],dflt:\"coupled\",editType:\"plot\"},xgap:{valType:\"number\",min:0,max:1,editType:\"plot\"},ygap:{valType:\"number\",min:0,max:1,editType:\"plot\"},domain:a({name:\"grid\",editType:\"plot\",noGridCell:!0},{}),xside:{valType:\"enumerated\",values:[\"bottom\",\"bottom plot\",\"top plot\",\"top\"],dflt:\"bottom plot\",editType:\"plot\"},yside:{valType:\"enumerated\",values:[\"left\",\"left plot\",\"right plot\",\"right\"],dflt:\"left plot\",editType:\"plot\"},editType:\"plot\"};function c(t,e,r){var n=e[r+\"axes\"],i=Object.keys((t._splomAxes||{})[r]||{});return Array.isArray(n)?n:i.length?i:void 0}function u(t,e,r,n,i,a){var o=e(t+\"gap\",r),s=e(\"domain.\"+t);e(t+\"side\",n);for(var l=new Array(i),c=s[0],u=(s[1]-c)/(i-o),h=u*(1-o),f=0;f<i;f++){var p=c+u*f;l[a?i-1-f:f]=[p,p+h]}return l}function h(t,e,r,n,i){var a,o=new Array(r);function s(t,r){-1!==e.indexOf(r)&&void 0===n[r]?(o[t]=r,n[r]=t):o[t]=\"\"}if(Array.isArray(t))for(a=0;a<r;a++)s(a,t[a]);else for(s(0,i),a=1;a<r;a++)s(a,i+(a+1));return o}e.exports={moduleType:\"component\",name:\"grid\",schema:{layout:{grid:l}},layoutAttributes:l,sizeDefaults:function(t,e){var r=t.grid||{},i=c(e,r,\"x\"),a=c(e,r,\"y\");if(t.grid||i||a){var o,h,f=Array.isArray(r.subplots)&&Array.isArray(r.subplots[0]),p=Array.isArray(i),d=Array.isArray(a),g=p&&i!==r.xaxes&&d&&a!==r.yaxes;f?(o=r.subplots.length,h=r.subplots[0].length):(d&&(o=a.length),p&&(h=i.length));var v=s.newContainer(e,\"grid\"),m=T(\"rows\",o),y=T(\"columns\",h);if(m*y>1){f||p||d||\"independent\"===T(\"pattern\")&&(f=!0),v._hasSubplotGrid=f;var x,b,_=\"top to bottom\"===T(\"roworder\"),w=f?.2:.1,k=f?.3:.1;g&&e._splomGridDflt&&(x=e._splomGridDflt.xside,b=e._splomGridDflt.yside),v._domains={x:u(\"x\",T,w,x,y),y:u(\"y\",T,k,b,m,_)}}else delete e.grid}function T(t,e){return n.coerce(r,v,l,t,e)}},contentDefaults:function(t,e){var r=e.grid;if(r&&r._domains){var n,i,a,o,s,l,u,f=t.grid||{},p=e._subplots,d=r._hasSubplotGrid,g=r.rows,v=r.columns,m=\"independent\"===r.pattern,y=r._axisMap={};if(d){var x=f.subplots||[];l=r.subplots=new Array(g);var b=1;for(n=0;n<g;n++){var _=l[n]=new Array(v),w=x[n]||[];for(i=0;i<v;i++)if(m?(s=1===b?\"xy\":\"x\"+b+\"y\"+b,b++):s=w[i],_[i]=\"\",-1!==p.cartesian.indexOf(s)){if(u=s.indexOf(\"y\"),a=s.slice(0,u),o=s.slice(u),void 0!==y[a]&&y[a]!==i||void 0!==y[o]&&y[o]!==n)continue;_[i]=s,y[a]=i,y[o]=n}}}else{var k=c(e,f,\"x\"),T=c(e,f,\"y\");r.xaxes=h(k,p.xaxis,v,y,\"x\"),r.yaxes=h(T,p.yaxis,g,y,\"y\")}var A=r._anchors={},M=\"top to bottom\"===r.roworder;for(var S in y){var E,C,L,P=S.charAt(0),O=r[P+\"side\"];if(O.length<8)A[S]=\"free\";else if(\"x\"===P){if(\"t\"===O.charAt(0)===M?(E=0,C=1,L=g):(E=g-1,C=-1,L=-1),d){var z=y[S];for(n=E;n!==L;n+=C)if((s=l[n][z])&&(u=s.indexOf(\"y\"),s.slice(0,u)===S)){A[S]=s.slice(u);break}}else for(n=E;n!==L;n+=C)if(o=r.yaxes[n],-1!==p.cartesian.indexOf(S+o)){A[S]=o;break}}else if(\"l\"===O.charAt(0)?(E=0,C=1,L=v):(E=v-1,C=-1,L=-1),d){var I=y[S];for(n=E;n!==L;n+=C)if((s=l[I][n])&&(u=s.indexOf(\"y\"),s.slice(u)===S)){A[S]=s.slice(0,u);break}}else for(n=E;n!==L;n+=C)if(a=r.xaxes[n],-1!==p.cartesian.indexOf(a+S)){A[S]=a;break}}}}}},{\"../../lib\":719,\"../../lib/regex\":735,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773,\"../../plots/domain\":792}],637:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/constants\"),i=t(\"../../plot_api/plot_template\").templatedArray;e.exports=i(\"image\",{visible:{valType:\"boolean\",dflt:!0,editType:\"arraydraw\"},source:{valType:\"string\",editType:\"arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},sizex:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizey:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizing:{valType:\"enumerated\",values:[\"fill\",\"contain\",\"stretch\"],dflt:\"contain\",editType:\"arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},x:{valType:\"any\",dflt:0,editType:\"arraydraw\"},y:{valType:\"any\",dflt:0,editType:\"arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"top\",editType:\"arraydraw\"},xref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.x.toString()],dflt:\"paper\",editType:\"arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.y.toString()],dflt:\"paper\",editType:\"arraydraw\"},editType:\"arraydraw\"})},{\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773}],638:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.images,h=e._id.charAt(0),f=0;f<u.length;f++)if(c=\"images[\"+f+\"].\",(l=u[f])[h+\"ref\"]===e._id){var p=l[h],d=l[\"size\"+h],g=null,v=null;if(o){g=i(p,e.range);var m=d/Math.pow(10,g)/2;v=2*Math.log(m+Math.sqrt(1+m*m))/Math.LN10}else v=(g=Math.pow(10,p))*(Math.pow(10,d/2)-Math.pow(10,-d/2));n(g)?n(v)||(v=null):(g=null,v=null),a(c+h,g),a(c+\"size\"+h,v)}}},{\"../../lib/to_log_range\":745,\"fast-isnumeric\":225}],639:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\");function s(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}var s=a(\"source\");if(!a(\"visible\",!!s))return e;a(\"layer\"),a(\"xanchor\"),a(\"yanchor\"),a(\"sizex\"),a(\"sizey\"),a(\"sizing\"),a(\"opacity\");for(var l={_fullLayout:r},c=[\"x\",\"y\"],u=0;u<2;u++){var h=c[u],f=i.coerceRef(t,e,l,h,\"paper\");if(\"paper\"!==f)i.getFromId(l,f)._imgIndices.push(e._index);i.coercePosition(e,l,a,f,h,0)}return e}e.exports=function(t,e){a(t,e,{name:\"images\",handleItemDefaults:s})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"./attributes\":637}],640:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../drawing\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/xmlns_namespaces\");e.exports=function(t){var e,r,s=t._fullLayout,l=[],c={},u=[];for(r=0;r<s.images.length;r++){var h=s.images[r];if(h.visible)if(\"below\"===h.layer&&\"paper\"!==h.xref&&\"paper\"!==h.yref){e=h.xref+h.yref;var f=s._plots[e];if(!f){u.push(h);continue}f.mainplot&&(e=f.mainplot.id),c[e]||(c[e]=[]),c[e].push(h)}else\"above\"===h.layer?l.push(h):u.push(h)}var p={x:{left:{sizing:\"xMin\",offset:0},center:{sizing:\"xMid\",offset:-.5},right:{sizing:\"xMax\",offset:-1}},y:{top:{sizing:\"YMin\",offset:0},middle:{sizing:\"YMid\",offset:-.5},bottom:{sizing:\"YMax\",offset:-1}}};function d(e){var r=n.select(this);if(!this.img||this.img.src!==e.source){r.attr(\"xmlns\",o.svg);var i=new Promise(function(t){var n=new Image;function i(){r.remove(),t()}this.img=n,n.setAttribute(\"crossOrigin\",\"anonymous\"),n.onerror=i,n.onload=function(){var e=document.createElement(\"canvas\");e.width=this.width,e.height=this.height,e.getContext(\"2d\").drawImage(this,0,0);var n=e.toDataURL(\"image/png\");r.attr(\"xlink:href\",n),t()},r.on(\"error\",i),n.src=e.source}.bind(this));t._promises.push(i)}}function g(e){var r=n.select(this),o=a.getFromId(t,e.xref),l=a.getFromId(t,e.yref),c=s._size,u=o?Math.abs(o.l2p(e.sizex)-o.l2p(0)):e.sizex*c.w,h=l?Math.abs(l.l2p(e.sizey)-l.l2p(0)):e.sizey*c.h,f=u*p.x[e.xanchor].offset,d=h*p.y[e.yanchor].offset,g=p.x[e.xanchor].sizing+p.y[e.yanchor].sizing,v=(o?o.r2p(e.x)+o._offset:e.x*c.w+c.l)+f,m=(l?l.r2p(e.y)+l._offset:c.h-e.y*c.h+c.t)+d;switch(e.sizing){case\"fill\":g+=\" slice\";break;case\"stretch\":g=\"none\"}r.attr({x:v,y:m,width:u,height:h,preserveAspectRatio:g,opacity:e.opacity});var y=(o?o._id:\"\")+(l?l._id:\"\");i.setClipUrl(r,y?\"clip\"+s._uid+y:null,t)}var v=s._imageLowerLayer.selectAll(\"image\").data(u),m=s._imageUpperLayer.selectAll(\"image\").data(l);v.enter().append(\"image\"),m.enter().append(\"image\"),v.exit().remove(),m.exit().remove(),v.each(function(t){d.bind(this)(t),g.bind(this)(t)}),m.each(function(t){d.bind(this)(t),g.bind(this)(t)});var y=Object.keys(s._plots);for(r=0;r<y.length;r++){e=y[r];var x=s._plots[e];if(x.imagelayer){var b=x.imagelayer.selectAll(\"image\").data(c[e]||[]);b.enter().append(\"image\"),b.exit().remove(),b.each(function(t){d.bind(this)(t),g.bind(this)(t)})}}}},{\"../../constants/xmlns_namespaces\":696,\"../../plots/cartesian/axes\":767,\"../drawing\":614,d3:163}],641:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"images\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"images\"),draw:t(\"./draw\"),convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":777,\"./attributes\":637,\"./convert_coords\":638,\"./defaults\":639,\"./draw\":640}],642:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",editType:\"legend\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"legend\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"legend\"},font:n({editType:\"legend\"}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"v\",editType:\"legend\"},traceorder:{valType:\"flaglist\",flags:[\"reversed\",\"grouped\"],extras:[\"normal\"],editType:\"legend\"},tracegroupgap:{valType:\"number\",min:0,dflt:10,editType:\"legend\"},itemsizing:{valType:\"enumerated\",values:[\"trace\",\"constant\"],dflt:\"trace\",editType:\"legend\"},itemclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggle\",editType:\"legend\"},itemdoubleclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggleothers\",editType:\"legend\"},x:{valType:\"number\",min:-2,max:3,dflt:1.02,editType:\"legend\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"legend\"},y:{valType:\"number\",min:-2,max:3,dflt:1,editType:\"legend\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"legend\"},uirevision:{valType:\"any\",editType:\"none\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"legend\"},editType:\"legend\"}},{\"../../plots/font_attributes\":793,\"../color/attributes\":592}],643:[function(t,e,r){\"use strict\";e.exports={scrollBarWidth:6,scrollBarMinHeight:20,scrollBarColor:\"#808BA4\",scrollBarMargin:4,textOffsetX:40}},{}],644:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plot_api/plot_template\"),o=t(\"./attributes\"),s=t(\"../../plots/layout_attributes\"),l=t(\"./helpers\");e.exports=function(t,e,r){for(var c,u,h,f,p=t.legend||{},d=0,g=!1,v=\"normal\",m=0;m<r.length;m++){var y=r[m];y.visible&&((y.showlegend||y._dfltShowLegend)&&(d++,y.showlegend&&(g=!0,(n.traceIs(y,\"pie-like\")||!0===y._input.showlegend)&&d++)),(n.traceIs(y,\"bar\")&&\"stack\"===e.barmode||-1!==[\"tonextx\",\"tonexty\"].indexOf(y.fill))&&(v=l.isGrouped({traceorder:v})?\"grouped+reversed\":\"reversed\"),void 0!==y.legendgroup&&\"\"!==y.legendgroup&&(v=l.isReversed({traceorder:v})?\"reversed+grouped\":\"grouped\"))}var x=i.coerce(t,e,s,\"showlegend\",g&&d>1);if(!1!==x||p.uirevision){var b=a.newContainer(e,\"legend\");if(w(\"uirevision\",e.uirevision),!1!==x){if(w(\"bgcolor\",e.paper_bgcolor),w(\"bordercolor\"),w(\"borderwidth\"),i.coerceFont(w,\"font\",e.font),w(\"orientation\"),\"h\"===b.orientation){var _=t.xaxis;n.getComponentMethod(\"rangeslider\",\"isVisible\")(_)?(c=0,h=\"left\",u=1.1,f=\"bottom\"):(c=0,h=\"left\",u=-.1,f=\"top\")}w(\"traceorder\",v),l.isGrouped(e.legend)&&w(\"tracegroupgap\"),w(\"itemsizing\"),w(\"itemclick\"),w(\"itemdoubleclick\"),w(\"x\",c),w(\"xanchor\",h),w(\"y\",u),w(\"yanchor\",f),w(\"valign\"),i.noneOrAll(p,b,[\"x\",\"y\"])}}function w(t,e){return i.coerce(p,b,o,t,e)}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/layout_attributes\":819,\"../../registry\":847,\"./attributes\":642,\"./helpers\":648}],645:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib/events\"),l=t(\"../dragelement\"),c=t(\"../drawing\"),u=t(\"../color\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"./handle_click\"),p=t(\"./constants\"),d=t(\"../../constants/alignment\"),g=d.LINE_SPACING,v=d.FROM_TL,m=d.FROM_BR,y=t(\"./get_legend_data\"),x=t(\"./style\"),b=t(\"./helpers\");function _(t,e,r,n,i){var a=r.data()[0][0].trace,l={event:i,node:r.node(),curveNumber:a.index,expandedIndex:a._expandedIndex,data:t.data,layout:t.layout,frames:t._transitionData._frames,config:t._context,fullData:t._fullData,fullLayout:t._fullLayout};if(a._group&&(l.group=a._group),o.traceIs(a,\"pie-like\")&&(l.label=r.datum()[0].label),!1!==s.triggerHandler(t,\"plotly_legendclick\",l))if(1===n)e._clickTimeout=setTimeout(function(){f(r,t,n)},t._context.doubleClickDelay);else if(2===n){e._clickTimeout&&clearTimeout(e._clickTimeout),t._legendMouseDownTime=0,!1!==s.triggerHandler(t,\"plotly_legenddoubleclick\",l)&&f(r,t,n)}}function w(t,e,r){var n=t.data()[0][0],a=e._fullLayout,s=n.trace,l=o.traceIs(s,\"pie-like\"),u=s.index,f=e._context.edits.legendText&&!l,d=l?n.label:s.name;s._meta&&(d=i.templateString(d,s._meta));var v=i.ensureSingle(t,\"text\",\"legendtext\");function m(r){h.convertToTspans(r,e,function(){!function(t,e){var r=t.data()[0][0];if(!r.trace.showlegend)return void t.remove();var n,i,a=t.select(\"g[class*=math-group]\"),o=a.node(),s=e._fullLayout.legend.font.size*g;if(o){var l=c.bBox(o);n=l.height,i=l.width,c.setTranslate(a,0,n/4)}else{var u=t.select(\".legendtext\"),f=h.lineCount(u),d=u.node();n=s*f,i=d?c.bBox(d).width:0;var v=s*(.3+(1-f)/2);h.positionText(u,p.textOffsetX,v)}r.lineHeight=s,r.height=Math.max(n,16)+3,r.width=i}(t,e)})}v.attr(\"text-anchor\",\"start\").classed(\"user-select-none\",!0).call(c.font,a.legend.font).text(f?k(d,r):d),h.positionText(v,p.textOffsetX,0),f?v.call(h.makeEditable,{gd:e,text:d}).call(m).on(\"edit\",function(t){this.text(k(t,r)).call(m);var a=n.trace._fullInput||{},s={};if(o.hasTransform(a,\"groupby\")){var l=o.getTransformIndices(a,\"groupby\"),c=l[l.length-1],h=i.keyedContainer(a,\"transforms[\"+c+\"].styles\",\"target\",\"value.name\");h.set(n.trace._group,t),s=h.constructUpdate()}else s.name=t;return o.call(\"_guiRestyle\",e,s,u)}):m(v)}function k(t,e){var r=Math.max(4,e);if(t&&t.trim().length>=r/2)return t;for(var n=r-(t=t||\"\").length;n>0;n--)t+=\" \";return t}function T(t,e){var r,a=e._context.doubleClickDelay,o=1,s=i.ensureSingle(t,\"rect\",\"legendtoggle\",function(t){t.style(\"cursor\",\"pointer\").attr(\"pointer-events\",\"all\").call(u.fill,\"rgba(0,0,0,0)\")});s.on(\"mousedown\",function(){(r=(new Date).getTime())-e._legendMouseDownTime<a?o+=1:(o=1,e._legendMouseDownTime=r)}),s.on(\"mouseup\",function(){if(!e._dragged&&!e._editing){var r=e._fullLayout.legend;(new Date).getTime()-e._legendMouseDownTime>a&&(o=Math.max(o-1,1)),_(e,r,t,o,n.event)}})}function A(t,e,r){var a=t._fullLayout,o=a.legend,s=o.borderwidth,l=b.isGrouped(o),u=0;if(o._width=0,o._height=0,b.isVertical(o))l&&e.each(function(t,e){c.setTranslate(this,0,e*o.tracegroupgap)}),r.each(function(t){var e=t[0],r=e.height,n=e.width;c.setTranslate(this,s,5+s+o._height+r/2),o._height+=r,o._width=Math.max(o._width,n)}),o._width+=45+2*s,o._height+=10+2*s,l&&(o._height+=(o._lgroupsLength-1)*o.tracegroupgap),u=40;else if(l){var h,f=0,p=0,d=e.data(),g=0;for(h=0;h<d.length;h++){var v=d[h],m=v.map(function(t){return t[0].width}),y=i.aggNums(Math.max,null,m),x=v.reduce(function(t,e){return t+e[0].height},0);p=Math.max(p,y),f=Math.max(f,x),g=Math.max(g,v.length)}p+=5,p+=40;var _=[o._width],w=[],k=0;for(h=0;h<d.length;h++){a._size.w<s+o._width+5+p?(_[_.length-1]=_[0],o._width=p,k++):o._width+=p+s;var T=k*f;T+=k>0?o.tracegroupgap:0,w.push(T),_.push(o._width)}e.each(function(t,e){c.setTranslate(this,_[e],w[e])}),e.each(function(){var t=n.select(this).selectAll(\"g.traces\"),e=0;t.each(function(t){var r=t[0].height;c.setTranslate(this,0,5+s+e+r/2),e+=r})});var A=w[w.length-1]+f;o._height=10+2*s+A;var M=Math.max.apply(null,_);o._width=M+p+40,o._width+=2*s}else{var S=0,E=0,C=0,L=0,P=0;r.each(function(t){C=Math.max(40+t[0].width,C),P+=40+t[0].width+5});var O=a._size.w>s+P-5;r.each(function(t){var e=t[0],r=O?40+t[0].width:C;s+L+5+r>a._size.w&&(L=0,S+=E,o._height+=E,E=0),c.setTranslate(this,s+L,5+s+e.height/2+S),o._width+=5+r,L+=5+r,E=Math.max(e.height,E)}),O?o._height=E:o._height+=E,o._width+=2*s,o._height+=10+2*s}o._width=Math.ceil(o._width),o._height=Math.ceil(o._height);var z=t._context.edits.legendText||t._context.edits.legendPosition;r.each(function(t){var e=t[0],r=n.select(this).select(\".legendtoggle\");c.setRect(r,0,-e.height/2,(z?0:o._width)+u,e.height)})}function M(t){var e=t._fullLayout.legend,r=\"left\";i.isRightAnchor(e)?r=\"right\":i.isCenterAnchor(e)&&(r=\"center\");var n=\"top\";i.isBottomAnchor(e)?n=\"bottom\":i.isMiddleAnchor(e)&&(n=\"middle\"),a.autoMargin(t,\"legend\",{x:e.x,y:e.y,l:e._width*v[r],r:e._width*m[r],b:e._height*m[n],t:e._height*v[n]})}e.exports=function(t){var e=t._fullLayout,r=\"legend\"+e._uid;if(e._infolayer&&t.calcdata){t._legendMouseDownTime||(t._legendMouseDownTime=0);var s=e.legend,h=e.showlegend&&y(t.calcdata,s),f=e.hiddenlabels||[];if(!e.showlegend||!h.length)return e._infolayer.selectAll(\".legend\").remove(),e._topdefs.select(\"#\"+r).remove(),void a.autoMargin(t,\"legend\");for(var d=0,g=0;g<h.length;g++)for(var b=0;b<h[g].length;b++){var k=h[g][b][0],S=k.trace,E=o.traceIs(S,\"pie-like\")?k.label:S.name;d=Math.max(d,E&&E.length||0)}var C=!1,L=i.ensureSingle(e._infolayer,\"g\",\"legend\",function(t){t.attr(\"pointer-events\",\"all\"),C=!0}),P=i.ensureSingleById(e._topdefs,\"clipPath\",r,function(t){t.append(\"rect\")}),O=i.ensureSingle(L,\"rect\",\"bg\",function(t){t.attr(\"shape-rendering\",\"crispEdges\")});O.call(u.stroke,s.bordercolor).call(u.fill,s.bgcolor).style(\"stroke-width\",s.borderwidth+\"px\");var z=i.ensureSingle(L,\"g\",\"scrollbox\"),I=i.ensureSingle(L,\"rect\",\"scrollbar\",function(t){t.attr({rx:20,ry:3,width:0,height:0}).call(u.fill,\"#808BA4\")}),D=z.selectAll(\"g.groups\").data(h);D.enter().append(\"g\").attr(\"class\",\"groups\"),D.exit().remove();var R=D.selectAll(\"g.traces\").data(i.identity);R.enter().append(\"g\").attr(\"class\",\"traces\"),R.exit().remove(),R.style(\"opacity\",function(t){var e=t[0].trace;return o.traceIs(e,\"pie-like\")?-1!==f.indexOf(t[0].label)?.5:1:\"legendonly\"===e.visible?.5:1}).each(function(){n.select(this).call(w,t,d)}).call(x,t).each(function(){n.select(this).call(T,t)}),i.syncOrAsync([a.previousPromises,function(){C&&(A(t,D,R),M(t));var u=e.width,h=e.height;A(t,D,R),s._height>h?function(t){var e=t._fullLayout.legend,r=\"left\";i.isRightAnchor(e)?r=\"right\":i.isCenterAnchor(e)&&(r=\"center\");a.autoMargin(t,\"legend\",{x:e.x,y:.5,l:e._width*v[r],r:e._width*m[r],b:0,t:0})}(t):M(t);var f=e._size,d=f.l+f.w*s.x,g=f.t+f.h*(1-s.y);i.isRightAnchor(s)?d-=s._width:i.isCenterAnchor(s)&&(d-=s._width/2),i.isBottomAnchor(s)?g-=s._height:i.isMiddleAnchor(s)&&(g-=s._height/2);var y=s._width,x=f.w;y>x?(d=f.l,y=x):(d+y>u&&(d=u-y),d<0&&(d=0),y=Math.min(u-d,s._width));var b,w,k,T,S=s._height,E=f.h;if(S>E?(g=f.t,S=E):(g+S>h&&(g=h-S),g<0&&(g=0),S=Math.min(h-g,s._height)),c.setTranslate(L,d,g),I.on(\".drag\",null),L.on(\"wheel\",null),s._height<=S||t._context.staticPlot)O.attr({width:y-s.borderwidth,height:S-s.borderwidth,x:s.borderwidth/2,y:s.borderwidth/2}),c.setTranslate(z,0,0),P.select(\"rect\").attr({width:y-2*s.borderwidth,height:S-2*s.borderwidth,x:s.borderwidth,y:s.borderwidth}),c.setClipUrl(z,r,t),c.setRect(I,0,0,0,0),delete s._scrollY;else{var F,B,N=Math.max(p.scrollBarMinHeight,S*S/s._height),j=S-N-2*p.scrollBarMargin,U=s._height-S,V=j/U,q=Math.min(s._scrollY||0,U);O.attr({width:y-2*s.borderwidth+p.scrollBarWidth+p.scrollBarMargin,height:S-s.borderwidth,x:s.borderwidth/2,y:s.borderwidth/2}),P.select(\"rect\").attr({width:y-2*s.borderwidth+p.scrollBarWidth+p.scrollBarMargin,height:S-2*s.borderwidth,x:s.borderwidth,y:s.borderwidth+q}),c.setClipUrl(z,r,t),G(q,N,V),L.on(\"wheel\",function(){G(q=i.constrain(s._scrollY+n.event.deltaY/j*U,0,U),N,V),0!==q&&q!==U&&n.event.preventDefault()});var H=n.behavior.drag().on(\"dragstart\",function(){F=n.event.sourceEvent.clientY,B=q}).on(\"drag\",function(){var t=n.event.sourceEvent;2===t.buttons||t.ctrlKey||G(q=i.constrain((t.clientY-F)/V+B,0,U),N,V)});I.call(H)}function G(e,r,n){s._scrollY=t._fullLayout.legend._scrollY=e,c.setTranslate(z,0,-e),c.setRect(I,y,p.scrollBarMargin+e*n,p.scrollBarWidth,r),P.select(\"rect\").attr({y:s.borderwidth+e})}t._context.edits.legendPosition&&(L.classed(\"cursor-move\",!0),l.init({element:L.node(),gd:t,prepFn:function(){var t=c.getTranslate(L);k=t.x,T=t.y},moveFn:function(t,e){var r=k+t,n=T+e;c.setTranslate(L,r,n),b=l.align(r,0,f.l,f.l+f.w,s.xanchor),w=l.align(n,0,f.t+f.h,f.t,s.yanchor)},doneFn:function(){void 0!==b&&void 0!==w&&o.call(\"_guiRelayout\",t,{\"legend.x\":b,\"legend.y\":w})},clickFn:function(r,n){var i=e._infolayer.selectAll(\"g.traces\").filter(function(){var t=this.getBoundingClientRect();return n.clientX>=t.left&&n.clientX<=t.right&&n.clientY>=t.top&&n.clientY<=t.bottom});i.size()>0&&_(t,L,i,r,n)}}))}],t)}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/events\":709,\"../../lib/svg_text_utils\":743,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"./constants\":643,\"./get_legend_data\":646,\"./handle_click\":647,\"./helpers\":648,\"./style\":650,d3:163}],646:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./helpers\");e.exports=function(t,e){var r,a,o={},s=[],l=!1,c={},u=0;function h(t,r){if(\"\"!==t&&i.isGrouped(e))-1===s.indexOf(t)?(s.push(t),l=!0,o[t]=[[r]]):o[t].push([r]);else{var n=\"~~i\"+u;s.push(n),o[n]=[[r]],u++}}for(r=0;r<t.length;r++){var f=t[r],p=f[0],d=p.trace,g=d.legendgroup;if(d.visible&&d.showlegend)if(n.traceIs(d,\"pie-like\"))for(c[g]||(c[g]={}),a=0;a<f.length;a++){var v=f[a].label;c[g][v]||(h(g,{label:v,color:f[a].color,i:f[a].i,trace:d,pts:f[a].pts}),c[g][v]=!0)}else h(g,p)}if(!s.length)return[];var m,y,x=s.length;if(l&&i.isGrouped(e))for(y=new Array(x),r=0;r<x;r++)m=o[s[r]],y[r]=i.isReversed(e)?m.reverse():m;else{for(y=[new Array(x)],r=0;r<x;r++)m=o[s[r]][0],y[0][i.isReversed(e)?x-r-1:r]=m;x=1}return e._lgroupsLength=x,y}},{\"../../registry\":847,\"./helpers\":648}],647:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=!0;e.exports=function(t,e,r){var o=e._fullLayout;if(!e._dragged&&!e._editing){var s,l=o.legend.itemclick,c=o.legend.itemdoubleclick;if(1===r&&\"toggle\"===l&&\"toggleothers\"===c&&a&&e.data&&e._context.showTips?(n.notifier(n._(e,\"Double-click on legend to isolate one trace\"),\"long\"),a=!1):a=!1,1===r?s=l:2===r&&(s=c),s){var u,h,f,p,d,g=o.hiddenlabels?o.hiddenlabels.slice():[],v=t.data()[0][0],m=e._fullData,y=v.trace,x=y.legendgroup,b={},_=[],w=[],k=[];if(i.traceIs(y,\"pie-like\")){var T=v.label,A=g.indexOf(T);\"toggle\"===s?-1===A?g.push(T):g.splice(A,1):\"toggleothers\"===s&&(g=[],e.calcdata[0].forEach(function(t){T!==t.label&&g.push(t.label)}),e._fullLayout.hiddenlabels&&e._fullLayout.hiddenlabels.length===g.length&&-1===A&&(g=[])),i.call(\"_guiRelayout\",e,\"hiddenlabels\",g)}else{var M,S=x&&x.length,E=[];if(S)for(u=0;u<m.length;u++)(M=m[u]).visible&&M.legendgroup===x&&E.push(u);if(\"toggle\"===s){var C;switch(y.visible){case!0:C=\"legendonly\";break;case!1:C=!1;break;case\"legendonly\":C=!0}if(S)for(u=0;u<m.length;u++)!1!==m[u].visible&&m[u].legendgroup===x&&R(m[u],C);else R(y,C)}else if(\"toggleothers\"===s){var L,P,O=!0;for(u=0;u<m.length;u++)if(!(m[u]===y)&&!(L=S&&m[u].legendgroup===x)&&!0===m[u].visible&&!i.traceIs(m[u],\"notLegendIsolatable\")){O=!1;break}for(u=0;u<m.length;u++)if(!1!==m[u].visible&&!i.traceIs(m[u],\"notLegendIsolatable\"))switch(y.visible){case\"legendonly\":R(m[u],!0);break;case!0:P=!!O||\"legendonly\",L=m[u]===y||S&&m[u].legendgroup===x,R(m[u],!!L||P)}}for(u=0;u<w.length;u++)if(f=w[u]){var z=f.constructUpdate(),I=Object.keys(z);for(h=0;h<I.length;h++)p=I[h],(b[p]=b[p]||[])[k[u]]=z[p]}for(d=Object.keys(b),u=0;u<d.length;u++)for(p=d[u],h=0;h<_.length;h++)b[p].hasOwnProperty(h)||(b[p][h]=void 0);i.call(\"_guiRestyle\",e,b,_)}}}function D(t,e,r){var n=_.indexOf(t),i=b[e];return i||(i=b[e]=[]),-1===_.indexOf(t)&&(_.push(t),n=_.length-1),i[n]=r,n}function R(t,e){var r=t._fullInput;if(i.hasTransform(r,\"groupby\")){var a=w[r.index];if(!a){var o=i.getTransformIndices(r,\"groupby\"),s=o[o.length-1];a=n.keyedContainer(r,\"transforms[\"+s+\"].styles\",\"target\",\"value.visible\"),w[r.index]=a}var l=a.get(t._group);void 0===l&&(l=!0),!1!==l&&a.set(t._group,e),k[r.index]=D(r.index,\"visible\",!1!==r.visible)}else{var c=!1!==r.visible&&e;D(r.index,\"visible\",c)}}}},{\"../../lib\":719,\"../../registry\":847}],648:[function(t,e,r){\"use strict\";r.isGrouped=function(t){return-1!==(t.traceorder||\"\").indexOf(\"grouped\")},r.isVertical=function(t){return\"h\"!==t.orientation},r.isReversed=function(t){return-1!==(t.traceorder||\"\").indexOf(\"reversed\")}},{}],649:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"legend\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\"),style:t(\"./style\")}},{\"./attributes\":642,\"./defaults\":644,\"./draw\":645,\"./style\":650}],650:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../drawing\"),s=t(\"../color\"),l=t(\"../../traces/scatter/subtypes\"),c=t(\"../../traces/pie/style_one\"),u=t(\"../../traces/pie/helpers\").castOption,h=12,f=5,p=2,d=10,g=5;e.exports=function(t,e){var r=e._fullLayout.legend,v=\"constant\"===r.itemsizing;function m(t,e,r,n){var i;if(t+1)i=t;else{if(!(e&&e.width>0))return 0;i=e.width}return v?n:Math.min(i,r)}function y(t,e,r){var a=t[0].trace,o=a.marker||{},l=o.line||{},c=r?a.type===r&&a.visible:i.traceIs(a,\"bar\"),u=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(c?[t]:[]);u.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),u.exit().remove(),u.each(function(t){var e=n.select(this),r=t[0],i=m(r.mlw,o.line,g,p);e.style(\"stroke-width\",i+\"px\").call(s.fill,r.mc||o.color),i&&s.stroke(e,r.mlc||l.color)})}function x(t,e,r){var o=t[0],s=o.trace,l=r?s.type===r&&s.visible:i.traceIs(s,r),h=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(l?[t]:[]);if(h.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),h.exit().remove(),h.size()){var f=(s.marker||{}).line,d=m(u(f.width,o.pts),f,g,p),v=a.minExtend(s,{marker:{line:{width:d}}});v.marker.line.color=f.color;var y=a.minExtend(o,{trace:v});c(h,y,v)}}t.each(function(t){var e=n.select(this),i=a.ensureSingle(e,\"g\",\"layers\");i.style(\"opacity\",t[0].trace.opacity);var o=r.valign,s=t[0].lineHeight,l=t[0].height;if(\"middle\"!==o&&s&&l){var c={top:1,bottom:-1}[o]*(.5*(s-l+3));i.attr(\"transform\",\"translate(0,\"+c+\")\")}else i.attr(\"transform\",null);i.selectAll(\"g.legendfill\").data([t]).enter().append(\"g\").classed(\"legendfill\",!0),i.selectAll(\"g.legendlines\").data([t]).enter().append(\"g\").classed(\"legendlines\",!0);var u=i.selectAll(\"g.legendsymbols\").data([t]);u.enter().append(\"g\").classed(\"legendsymbols\",!0),u.selectAll(\"g.legendpoints\").data([t]).enter().append(\"g\").classed(\"legendpoints\",!0)}).each(function(t){var e=t[0].trace,r=[];\"waterfall\"===e.type&&e.visible&&(r=t[0].hasTotals?[[\"increasing\",\"M-6,-6V6H0Z\"],[\"totals\",\"M6,6H0L-6,-6H-0Z\"],[\"decreasing\",\"M6,6V-6H0Z\"]]:[[\"increasing\",\"M-6,-6V6H6Z\"],[\"decreasing\",\"M6,6V-6H-6Z\"]]);var i=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendwaterfall\").data(r);i.enter().append(\"path\").classed(\"legendwaterfall\",!0).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),i.exit().remove(),i.each(function(t){var r=n.select(this),i=e[t[0]].marker,a=m(void 0,i.line,g,p);r.attr(\"d\",t[1]).style(\"stroke-width\",a+\"px\").call(s.fill,i.color),a&&r.call(s.stroke,i.line.color)})}).each(function(t){y(t,this,\"funnel\")}).each(function(t){y(t,this)}).each(function(t){var r=t[0].trace,l=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendbox\").data(i.traceIs(r,\"box-violin\")&&r.visible?[t]:[]);l.enter().append(\"path\").classed(\"legendbox\",!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),l.exit().remove(),l.each(function(){var t=n.select(this);if(\"all\"!==r.boxpoints&&\"all\"!==r.points||0!==s.opacity(r.fillcolor)||0!==s.opacity((r.line||{}).color)){var i=m(void 0,r.line,g,p);t.style(\"stroke-width\",i+\"px\").call(s.fill,r.fillcolor),i&&s.stroke(t,r.line.color)}else{var c=a.minExtend(r,{marker:{size:v?h:a.constrain(r.marker.size,2,16),sizeref:1,sizemin:1,sizemode:\"diameter\"}});l.call(o.pointStyle,c,e)}})}).each(function(t){x(t,this,\"funnelarea\")}).each(function(t){x(t,this,\"pie\")}).each(function(t){var r,i,s=t[0],c=s.trace,u=c.visible&&c.fill&&\"none\"!==c.fill,h=l.hasLines(c),p=c.contours,g=!1,v=!1;if(p){var y=p.coloring;\"lines\"===y?g=!0:h=\"none\"===y||\"heatmap\"===y||p.showlines,\"constraint\"===p.type?u=\"=\"!==p._operation:\"fill\"!==y&&\"heatmap\"!==y||(v=!0)}var x=l.hasMarkers(c)||l.hasText(c),b=u||v,_=h||g,w=x||!b?\"M5,0\":_?\"M5,-2\":\"M5,-3\",k=n.select(this),T=k.select(\".legendfill\").selectAll(\"path\").data(u||v?[t]:[]);if(T.enter().append(\"path\").classed(\"js-fill\",!0),T.exit().remove(),T.attr(\"d\",w+\"h30v6h-30z\").call(u?o.fillGroupStyle:function(t){if(t.size()){var r=\"legendfill-\"+c.uid;o.gradient(t,e,r,\"horizontalreversed\",c.colorscale,\"fill\")}}),h||g){var A=m(void 0,c.line,d,f);i=a.minExtend(c,{line:{width:A}}),r=[a.minExtend(s,{trace:i})]}var M=k.select(\".legendlines\").selectAll(\"path\").data(h||g?[r]:[]);M.enter().append(\"path\").classed(\"js-line\",!0),M.exit().remove(),M.attr(\"d\",w+(g?\"l30,0.0001\":\"h30\")).call(h?o.lineGroupStyle:function(t){if(t.size()){var r=\"legendline-\"+c.uid;o.lineGroupStyle(t),o.gradient(t,e,r,\"horizontalreversed\",c.colorscale,\"stroke\")}})}).each(function(t){var r,i,s=t[0],c=s.trace,u=l.hasMarkers(c),d=l.hasText(c),g=l.hasLines(c);function m(t,e,r,n){var i=a.nestedProperty(c,t).get(),o=a.isArrayOrTypedArray(i)&&e?e(i):i;if(v&&o&&void 0!==n&&(o=n),r){if(o<r[0])return r[0];if(o>r[1])return r[1]}return o}function y(t){return t[0]}if(u||d||g){var x={},b={};if(u){x.mc=m(\"marker.color\",y),x.mx=m(\"marker.symbol\",y),x.mo=m(\"marker.opacity\",a.mean,[.2,1]),x.mlc=m(\"marker.line.color\",y),x.mlw=m(\"marker.line.width\",a.mean,[0,5],p),b.marker={sizeref:1,sizemin:1,sizemode:\"diameter\"};var _=m(\"marker.size\",a.mean,[2,16],h);x.ms=_,b.marker.size=_}g&&(b.line={width:m(\"line.width\",y,[0,10],f)}),d&&(x.tx=\"Aa\",x.tp=m(\"textposition\",y),x.ts=10,x.tc=m(\"textfont.color\",y),x.tf=m(\"textfont.family\",y)),r=[a.minExtend(s,x)],(i=a.minExtend(c,b)).selectedpoints=null}var w=n.select(this).select(\"g.legendpoints\"),k=w.selectAll(\"path.scatterpts\").data(u?r:[]);k.enter().insert(\"path\",\":first-child\").classed(\"scatterpts\",!0).attr(\"transform\",\"translate(20,0)\"),k.exit().remove(),k.call(o.pointStyle,i,e),u&&(r[0].mrc=3);var T=w.selectAll(\"g.pointtext\").data(d?r:[]);T.enter().append(\"g\").classed(\"pointtext\",!0).append(\"text\").attr(\"transform\",\"translate(20,0)\"),T.exit().remove(),T.selectAll(\"text\").call(o.textPointStyle,i,e)}).each(function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendcandle\").data(\"candlestick\"===e.type&&e.visible?[t,t]:[]);r.enter().append(\"path\").classed(\"legendcandle\",!0).attr(\"d\",function(t,e){return e?\"M-15,0H-8M-8,6V-6H8Z\":\"M15,0H8M8,-6V6H-8Z\"}).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),r.exit().remove(),r.each(function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],o=m(void 0,a.line,g,p);i.style(\"stroke-width\",o+\"px\").call(s.fill,a.fillcolor),o&&s.stroke(i,a.line.color)})}).each(function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendohlc\").data(\"ohlc\"===e.type&&e.visible?[t,t]:[]);r.enter().append(\"path\").classed(\"legendohlc\",!0).attr(\"d\",function(t,e){return e?\"M-15,0H0M-8,-6V0\":\"M15,0H0M8,6V0\"}).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),r.exit().remove(),r.each(function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],l=m(void 0,a.line,g,p);i.style(\"fill\",\"none\").call(o.dashLine,a.line.dash,l),l&&s.stroke(i,a.line.color)})})}},{\"../../lib\":719,\"../../registry\":847,\"../../traces/pie/helpers\":1091,\"../../traces/pie/style_one\":1097,\"../../traces/scatter/subtypes\":1135,\"../color\":593,\"../drawing\":614,d3:163}],651:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/plots\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../lib\"),s=t(\"../../fonts/ploticon\"),l=o._,c=e.exports={};function u(t,e){var r,i,o=e.currentTarget,s=o.getAttribute(\"data-attr\"),l=o.getAttribute(\"data-val\")||!0,c=t._fullLayout,u={},h=a.list(t,null,!0),f=\"on\";if(\"zoom\"===s){var p,d=\"in\"===l?.5:2,g=(1+d)/2,v=(1-d)/2;for(i=0;i<h.length;i++)if(!(r=h[i]).fixedrange)if(p=r._name,\"auto\"===l)u[p+\".autorange\"]=!0;else if(\"reset\"===l){if(void 0===r._rangeInitial)u[p+\".autorange\"]=!0;else{var m=r._rangeInitial.slice();u[p+\".range[0]\"]=m[0],u[p+\".range[1]\"]=m[1]}void 0!==r._showSpikeInitial&&(u[p+\".showspikes\"]=r._showSpikeInitial,\"on\"!==f||r._showSpikeInitial||(f=\"off\"))}else{var y=[r.r2l(r.range[0]),r.r2l(r.range[1])],x=[g*y[0]+v*y[1],g*y[1]+v*y[0]];u[p+\".range[0]\"]=r.l2r(x[0]),u[p+\".range[1]\"]=r.l2r(x[1])}c._cartesianSpikesEnabled=f}else{if(\"hovermode\"!==s||\"x\"!==l&&\"y\"!==l){if(\"hovermode\"===s&&\"closest\"===l){for(i=0;i<h.length;i++)r=h[i],\"on\"!==f||r.showspikes||(f=\"off\");c._cartesianSpikesEnabled=f}}else l=c._isHoriz?\"y\":\"x\",o.setAttribute(\"data-val\",l);u[s]=l}n.call(\"_guiRelayout\",t,u)}function h(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout._subplots.gl3d,s={},l=i.split(\".\"),c=0;c<o.length;c++)s[o[c]+\".\"+l[1]]=a;var u=\"pan\"===a?a:\"zoom\";s.dragmode=u,n.call(\"_guiRelayout\",t,s)}function f(t,e){for(var r=e.currentTarget.getAttribute(\"data-attr\"),i=t._fullLayout,a=i._subplots.gl3d,o={},s=0;s<a.length;s++){var l=a[s],c=l+\".camera\",u=i[l]._scene;\"resetLastSave\"===r?(o[c+\".up\"]=u.viewInitial.up,o[c+\".eye\"]=u.viewInitial.eye,o[c+\".center\"]=u.viewInitial.center):\"resetDefault\"===r&&(o[c+\".up\"]=null,o[c+\".eye\"]=null,o[c+\".center\"]=null)}n.call(\"_guiRelayout\",t,o)}function p(t,e){var r=e.currentTarget,n=r._previousVal,i=t._fullLayout,a=i._subplots.gl3d,o=[\"xaxis\",\"yaxis\",\"zaxis\"],s={},l={};if(n)l=n,r._previousVal=null;else{for(var c=0;c<a.length;c++){var u=a[c],h=i[u],f=u+\".hovermode\";s[f]=h.hovermode,l[f]=!1;for(var p=0;p<3;p++){var d=o[p],g=u+\".\"+d+\".showspikes\";l[g]=!1,s[g]=h[d].showspikes}}r._previousVal=s}return l}function d(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout,s=o._subplots.geo,l=0;l<s.length;l++){var c=s[l],u=o[c];if(\"zoom\"===i){var h=u.projection.scale,f=\"in\"===a?2*h:.5*h;n.call(\"_guiRelayout\",t,c+\".projection.scale\",f)}else\"reset\"===i&&m(t,\"geo\")}}function g(t){var e=t._fullLayout;return!e.hovermode&&(e._has(\"cartesian\")?e._isHoriz?\"y\":\"x\":\"closest\")}function v(t){var e=g(t);n.call(\"_guiRelayout\",t,\"hovermode\",e)}function m(t,e){for(var r=t._fullLayout,i=r._subplots[e],a={},o=0;o<i.length;o++)for(var s=i[o],l=r[s]._subplot.viewInitial,c=Object.keys(l),u=0;u<c.length;u++){var h=c[u];a[s+\".\"+h]=l[h]}n.call(\"_guiRelayout\",t,a)}c.toImage={name:\"toImage\",title:function(t){var e=(t._context.toImageButtonOptions||{}).format||\"png\";return l(t,\"png\"===e?\"Download plot as a png\":\"Download plot\")},icon:s.camera,click:function(t){var e=t._context.toImageButtonOptions,r={format:e.format||\"png\"};o.notifier(l(t,\"Taking snapshot - this may take a few seconds\"),\"long\"),\"svg\"!==r.format&&o.isIE()&&(o.notifier(l(t,\"IE only supports svg.  Changing format to svg.\"),\"long\"),r.format=\"svg\"),[\"filename\",\"width\",\"height\",\"scale\"].forEach(function(t){t in e&&(r[t]=e[t])}),n.call(\"downloadImage\",t,r).then(function(e){o.notifier(l(t,\"Snapshot succeeded\")+\" - \"+e,\"long\")}).catch(function(){o.notifier(l(t,\"Sorry, there was a problem downloading your snapshot!\"),\"long\")})}},c.sendDataToCloud={name:\"sendDataToCloud\",title:function(t){return l(t,\"Edit in Chart Studio\")},icon:s.disk,click:function(t){i.sendDataToCloud(t)}},c.editInChartStudio={name:\"editInChartStudio\",title:function(t){return l(t,\"Edit in Chart Studio\")},icon:s.pencil,click:function(t){i.sendDataToCloud(t)}},c.zoom2d={name:\"zoom2d\",title:function(t){return l(t,\"Zoom\")},attr:\"dragmode\",val:\"zoom\",icon:s.zoombox,click:u},c.pan2d={name:\"pan2d\",title:function(t){return l(t,\"Pan\")},attr:\"dragmode\",val:\"pan\",icon:s.pan,click:u},c.select2d={name:\"select2d\",title:function(t){return l(t,\"Box Select\")},attr:\"dragmode\",val:\"select\",icon:s.selectbox,click:u},c.lasso2d={name:\"lasso2d\",title:function(t){return l(t,\"Lasso Select\")},attr:\"dragmode\",val:\"lasso\",icon:s.lasso,click:u},c.zoomIn2d={name:\"zoomIn2d\",title:function(t){return l(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:s.zoom_plus,click:u},c.zoomOut2d={name:\"zoomOut2d\",title:function(t){return l(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:s.zoom_minus,click:u},c.autoScale2d={name:\"autoScale2d\",title:function(t){return l(t,\"Autoscale\")},attr:\"zoom\",val:\"auto\",icon:s.autoscale,click:u},c.resetScale2d={name:\"resetScale2d\",title:function(t){return l(t,\"Reset axes\")},attr:\"zoom\",val:\"reset\",icon:s.home,click:u},c.hoverClosestCartesian={name:\"hoverClosestCartesian\",title:function(t){return l(t,\"Show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:s.tooltip_basic,gravity:\"ne\",click:u},c.hoverCompareCartesian={name:\"hoverCompareCartesian\",title:function(t){return l(t,\"Compare data on hover\")},attr:\"hovermode\",val:function(t){return t._fullLayout._isHoriz?\"y\":\"x\"},icon:s.tooltip_compare,gravity:\"ne\",click:u},c.zoom3d={name:\"zoom3d\",title:function(t){return l(t,\"Zoom\")},attr:\"scene.dragmode\",val:\"zoom\",icon:s.zoombox,click:h},c.pan3d={name:\"pan3d\",title:function(t){return l(t,\"Pan\")},attr:\"scene.dragmode\",val:\"pan\",icon:s.pan,click:h},c.orbitRotation={name:\"orbitRotation\",title:function(t){return l(t,\"Orbital rotation\")},attr:\"scene.dragmode\",val:\"orbit\",icon:s[\"3d_rotate\"],click:h},c.tableRotation={name:\"tableRotation\",title:function(t){return l(t,\"Turntable rotation\")},attr:\"scene.dragmode\",val:\"turntable\",icon:s[\"z-axis\"],click:h},c.resetCameraDefault3d={name:\"resetCameraDefault3d\",title:function(t){return l(t,\"Reset camera to default\")},attr:\"resetDefault\",icon:s.home,click:f},c.resetCameraLastSave3d={name:\"resetCameraLastSave3d\",title:function(t){return l(t,\"Reset camera to last save\")},attr:\"resetLastSave\",icon:s.movie,click:f},c.hoverClosest3d={name:\"hoverClosest3d\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=p(t,e);n.call(\"_guiRelayout\",t,r)}},c.zoomInGeo={name:\"zoomInGeo\",title:function(t){return l(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:s.zoom_plus,click:d},c.zoomOutGeo={name:\"zoomOutGeo\",title:function(t){return l(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:s.zoom_minus,click:d},c.resetGeo={name:\"resetGeo\",title:function(t){return l(t,\"Reset\")},attr:\"reset\",val:null,icon:s.autoscale,click:d},c.hoverClosestGeo={name:\"hoverClosestGeo\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:v},c.hoverClosestGl2d={name:\"hoverClosestGl2d\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:v},c.hoverClosestPie={name:\"hoverClosestPie\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:s.tooltip_basic,gravity:\"ne\",click:v},c.resetViewSankey={name:\"resetSankeyGroup\",title:function(t){return l(t,\"Reset view\")},icon:s.home,click:function(t){for(var e={\"node.groups\":[],\"node.x\":[],\"node.y\":[]},r=0;r<t._fullData.length;r++){var i=t._fullData[r]._viewInitial;e[\"node.groups\"].push(i.node.groups.slice()),e[\"node.x\"].push(i.node.x.slice()),e[\"node.y\"].push(i.node.y.slice())}n.call(\"restyle\",t,e)}},c.toggleHover={name:\"toggleHover\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=p(t,e);r.hovermode=g(t),n.call(\"_guiRelayout\",t,r)}},c.resetViews={name:\"resetViews\",title:function(t){return l(t,\"Reset views\")},icon:s.home,click:function(t,e){var r=e.currentTarget;r.setAttribute(\"data-attr\",\"zoom\"),r.setAttribute(\"data-val\",\"reset\"),u(t,e),r.setAttribute(\"data-attr\",\"resetLastSave\"),f(t,e),m(t,\"geo\"),m(t,\"mapbox\")}},c.toggleSpikelines={name:\"toggleSpikelines\",title:function(t){return l(t,\"Toggle Spike Lines\")},icon:s.spikeline,attr:\"_cartesianSpikesEnabled\",val:\"on\",click:function(t){var e=t._fullLayout;e._cartesianSpikesEnabled=\"on\"===e._cartesianSpikesEnabled?\"off\":\"on\";var r=function(t){for(var e,r,n=t._fullLayout,i=a.list(t,null,!0),o={},s=0;s<i.length;s++)e=i[s],r=e._name,o[r+\".showspikes\"]=\"on\"===n._cartesianSpikesEnabled||e._showSpikeInitial;return o}(t);n.call(\"_guiRelayout\",t,r)}},c.resetViewMapbox={name:\"resetViewMapbox\",title:function(t){return l(t,\"Reset view\")},attr:\"reset\",icon:s.home,click:function(t){m(t,\"mapbox\")}}},{\"../../fonts/ploticon\":699,\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../../plots/plots\":828,\"../../registry\":847}],652:[function(t,e,r){\"use strict\";r.manage=t(\"./manage\")},{\"./manage\":653}],653:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"../../traces/scatter/subtypes\"),a=t(\"../../registry\"),o=t(\"./modebar\"),s=t(\"./buttons\");e.exports=function(t){var e=t._fullLayout,r=t._context,l=e._modeBar;if(r.displayModeBar||r.watermark){if(!Array.isArray(r.modeBarButtonsToRemove))throw new Error([\"*modeBarButtonsToRemove* configuration options\",\"must be an array.\"].join(\" \"));if(!Array.isArray(r.modeBarButtonsToAdd))throw new Error([\"*modeBarButtonsToAdd* configuration options\",\"must be an array.\"].join(\" \"));var c,u=r.modeBarButtons;c=Array.isArray(u)&&u.length?function(t){for(var e=0;e<t.length;e++)for(var r=t[e],n=0;n<r.length;n++){var i=r[n];if(\"string\"==typeof i){if(void 0===s[i])throw new Error([\"*modeBarButtons* configuration options\",\"invalid button name\"].join(\" \"));t[e][n]=s[i]}}return t}(u):!r.displayModeBar&&r.watermark?[]:function(t){var e=t._fullLayout,r=t._fullData,o=t._context,l=o.modeBarButtonsToRemove,c=o.modeBarButtonsToAdd,u=e._has(\"cartesian\"),h=e._has(\"gl3d\"),f=e._has(\"geo\"),p=e._has(\"pie\"),d=e._has(\"funnelarea\"),g=e._has(\"gl2d\"),v=e._has(\"ternary\"),m=e._has(\"mapbox\"),y=e._has(\"polar\"),x=e._has(\"sankey\"),b=function(t){for(var e=n.list({_fullLayout:t},null,!0),r=0;r<e.length;r++)if(!e[r].fixedrange)return!1;return!0}(e),_=[];function w(t){if(t.length){for(var e=[],r=0;r<t.length;r++){var n=t[r];-1===l.indexOf(n)&&e.push(s[n])}_.push(e)}}var k=[\"toImage\"];o.showEditInChartStudio?k.push(\"editInChartStudio\"):o.showSendToCloud&&k.push(\"sendDataToCloud\");w(k);var T=[],A=[],M=[],S=[];(u||g||p||d||v)+f+h+m+y>1?(A=[\"toggleHover\"],M=[\"resetViews\"]):f?(T=[\"zoomInGeo\",\"zoomOutGeo\"],A=[\"hoverClosestGeo\"],M=[\"resetGeo\"]):h?(A=[\"hoverClosest3d\"],M=[\"resetCameraDefault3d\",\"resetCameraLastSave3d\"]):m?(A=[\"toggleHover\"],M=[\"resetViewMapbox\"]):g?A=[\"hoverClosestGl2d\"]:p?A=[\"hoverClosestPie\"]:x?(A=[\"hoverClosestCartesian\",\"hoverCompareCartesian\"],M=[\"resetViewSankey\"]):A=[\"toggleHover\"];u&&(A=[\"toggleSpikelines\",\"hoverClosestCartesian\",\"hoverCompareCartesian\"]);(function(t){for(var e=0;e<t.length;e++)if(!a.traceIs(t[e],\"noHover\"))return!1;return!0})(r)&&(A=[]);!u&&!g||b||(T=[\"zoomIn2d\",\"zoomOut2d\",\"autoScale2d\"],\"resetViews\"!==M[0]&&(M=[\"resetScale2d\"]));h?S=[\"zoom3d\",\"pan3d\",\"orbitRotation\",\"tableRotation\"]:(u||g)&&!b||v?S=[\"zoom2d\",\"pan2d\"]:m||f?S=[\"pan2d\"]:y&&(S=[\"zoom2d\"]);(function(t){for(var e=!1,r=0;r<t.length&&!e;r++){var n=t[r];n._module&&n._module.selectPoints&&(a.traceIs(n,\"scatter-like\")?(i.hasMarkers(n)||i.hasText(n))&&(e=!0):a.traceIs(n,\"box-violin\")&&\"all\"!==n.boxpoints&&\"all\"!==n.points||(e=!0))}return e})(r)&&S.push(\"select2d\",\"lasso2d\");return w(S),w(T.concat(M)),w(A),function(t,e){if(e.length)if(Array.isArray(e[0]))for(var r=0;r<e.length;r++)t.push(e[r]);else t.push(e);return t}(_,c)}(t),l?l.update(t,c):e._modeBar=o(t,c)}else l&&(l.destroy(),delete e._modeBar)}},{\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../../traces/scatter/subtypes\":1135,\"./buttons\":651,\"./modebar\":654}],654:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../fonts/ploticon\"),s=new DOMParser;function l(t){this.container=t.container,this.element=document.createElement(\"div\"),this.update(t.graphInfo,t.buttons),this.container.appendChild(this.element)}var c=l.prototype;c.update=function(t,e){this.graphInfo=t;var r=this.graphInfo._context,n=this.graphInfo._fullLayout,i=\"modebar-\"+n._uid;this.element.setAttribute(\"id\",i),this._uid=i,this.element.className=\"modebar\",\"hover\"===r.displayModeBar&&(this.element.className+=\" modebar--hover ease-bg\"),\"v\"===n.modebar.orientation&&(this.element.className+=\" vertical\",e=e.reverse());var o=n.modebar,s=\"hover\"===r.displayModeBar?\".js-plotly-plot .plotly:hover \":\"\";a.deleteRelatedStyleRule(i),a.addRelatedStyleRule(i,s+\"#\"+i+\" .modebar-group\",\"background-color: \"+o.bgcolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn .icon path\",\"fill: \"+o.color),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn:hover .icon path\",\"fill: \"+o.activecolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn.active .icon path\",\"fill: \"+o.activecolor);var l=!this.hasButtons(e),c=this.hasLogo!==r.displaylogo,u=this.locale!==r.locale;if(this.locale=r.locale,(l||c||u)&&(this.removeAllButtons(),this.updateButtons(e),r.watermark||r.displaylogo)){var h=this.getLogo();r.watermark&&(h.className=h.className+\" watermark\"),\"v\"===n.modebar.orientation?this.element.insertBefore(h,this.element.childNodes[0]):this.element.appendChild(h),this.hasLogo=!0}this.updateActiveButton()},c.updateButtons=function(t){var e=this;this.buttons=t,this.buttonElements=[],this.buttonsNames=[],this.buttons.forEach(function(t){var r=e.createGroup();t.forEach(function(t){var n=t.name;if(!n)throw new Error(\"must provide button 'name' in button config\");if(-1!==e.buttonsNames.indexOf(n))throw new Error(\"button name '\"+n+\"' is taken\");e.buttonsNames.push(n);var i=e.createButton(t);e.buttonElements.push(i),r.appendChild(i)}),e.element.appendChild(r)})},c.createGroup=function(){var t=document.createElement(\"div\");return t.className=\"modebar-group\",t},c.createButton=function(t){var e=this,r=document.createElement(\"a\");r.setAttribute(\"rel\",\"tooltip\"),r.className=\"modebar-btn\";var i=t.title;void 0===i?i=t.name:\"function\"==typeof i&&(i=i(this.graphInfo)),(i||0===i)&&r.setAttribute(\"data-title\",i),void 0!==t.attr&&r.setAttribute(\"data-attr\",t.attr);var a=t.val;if(void 0!==a&&(\"function\"==typeof a&&(a=a(this.graphInfo)),r.setAttribute(\"data-val\",a)),\"function\"!=typeof t.click)throw new Error(\"must provide button 'click' function in button config\");r.addEventListener(\"click\",function(r){t.click(e.graphInfo,r),e.updateActiveButton(r.currentTarget)}),r.setAttribute(\"data-toggle\",t.toggle||!1),t.toggle&&n.select(r).classed(\"active\",!0);var s=t.icon;return\"function\"==typeof s?r.appendChild(s()):r.appendChild(this.createIcon(s||o.question)),r.setAttribute(\"data-gravity\",t.gravity||\"n\"),r},c.createIcon=function(t){var e,r=i(t.height)?Number(t.height):t.ascent-t.descent,n=\"http://www.w3.org/2000/svg\";if(t.path){(e=document.createElementNS(n,\"svg\")).setAttribute(\"viewBox\",[0,0,t.width,r].join(\" \")),e.setAttribute(\"class\",\"icon\");var a=document.createElementNS(n,\"path\");a.setAttribute(\"d\",t.path),t.transform?a.setAttribute(\"transform\",t.transform):void 0!==t.ascent&&a.setAttribute(\"transform\",\"matrix(1 0 0 -1 0 \"+t.ascent+\")\"),e.appendChild(a)}t.svg&&(e=s.parseFromString(t.svg,\"application/xml\").childNodes[0]);return e.setAttribute(\"height\",\"1em\"),e.setAttribute(\"width\",\"1em\"),e},c.updateActiveButton=function(t){var e=this.graphInfo._fullLayout,r=void 0!==t?t.getAttribute(\"data-attr\"):null;this.buttonElements.forEach(function(t){var i=t.getAttribute(\"data-val\")||!0,o=t.getAttribute(\"data-attr\"),s=\"true\"===t.getAttribute(\"data-toggle\"),l=n.select(t);if(s)o===r&&l.classed(\"active\",!l.classed(\"active\"));else{var c=null===o?o:a.nestedProperty(e,o).get();l.classed(\"active\",c===i)}})},c.hasButtons=function(t){var e=this.buttons;if(!e)return!1;if(t.length!==e.length)return!1;for(var r=0;r<t.length;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;n++)if(t[r][n].name!==e[r][n].name)return!1}return!0},c.getLogo=function(){var t=this.createGroup(),e=document.createElement(\"a\");return e.href=\"https://plot.ly/\",e.target=\"_blank\",e.setAttribute(\"data-title\",a._(this.graphInfo,\"Produced with Plotly\")),e.className=\"modebar-btn plotlyjsicon modebar-btn--logo\",e.appendChild(this.createIcon(o.newplotlylogo)),t.appendChild(e),t},c.removeAllButtons=function(){for(;this.element.firstChild;)this.element.removeChild(this.element.firstChild);this.hasLogo=!1},c.destroy=function(){a.removeElement(this.container.querySelector(\".modebar\")),a.deleteRelatedStyleRule(this._uid)},e.exports=function(t,e){var r=t._fullLayout,i=new l({graphInfo:t,container:r._modebardiv.node(),buttons:e});return r._privateplot&&n.select(i.element).append(\"span\").classed(\"badge-private float--left\",!0).text(\"PRIVATE\"),i}},{\"../../fonts/ploticon\":699,\"../../lib\":719,d3:163,\"fast-isnumeric\":225}],655:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=(0,t(\"../../plot_api/plot_template\").templatedArray)(\"button\",{visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},step:{valType:\"enumerated\",values:[\"month\",\"year\",\"day\",\"hour\",\"minute\",\"second\",\"all\"],dflt:\"month\",editType:\"plot\"},stepmode:{valType:\"enumerated\",values:[\"backward\",\"todate\"],dflt:\"backward\",editType:\"plot\"},count:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},label:{valType:\"string\",editType:\"plot\"},editType:\"plot\"});e.exports={visible:{valType:\"boolean\",editType:\"plot\"},buttons:a,x:{valType:\"number\",min:-2,max:3,editType:\"plot\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"plot\"},y:{valType:\"number\",min:-2,max:3,editType:\"plot\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"bottom\",editType:\"plot\"},font:n({editType:\"plot\"}),bgcolor:{valType:\"color\",dflt:i.lightLine,editType:\"plot\"},activecolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"plot\"}},{\"../../plot_api/plot_template\":757,\"../../plots/font_attributes\":793,\"../color/attributes\":592}],656:[function(t,e,r){\"use strict\";e.exports={yPad:.02,minButtonWidth:30,rx:3,ry:3,lightAmount:25,darkAmount:10}},{}],657:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../../plots/array_container_defaults\"),s=t(\"./attributes\"),l=t(\"./constants\");function c(t,e,r,i){var a=i.calendar;function o(r,i){return n.coerce(t,e,s.buttons,r,i)}if(o(\"visible\")){var l=o(\"step\");\"all\"!==l&&(!a||\"gregorian\"===a||\"month\"!==l&&\"year\"!==l?o(\"stepmode\"):e.stepmode=\"backward\",o(\"count\")),o(\"label\")}}e.exports=function(t,e,r,u,h){var f=t.rangeselector||{},p=a.newContainer(e,\"rangeselector\");function d(t,e){return n.coerce(f,p,s,t,e)}if(d(\"visible\",o(f,p,{name:\"buttons\",handleItemDefaults:c,calendar:h}).length>0)){var g=function(t,e,r){for(var n=r.filter(function(r){return e[r].anchor===t._id}),i=0,a=0;a<n.length;a++){var o=e[n[a]].domain;o&&(i=Math.max(o[1],i))}return[t.domain[0],i+l.yPad]}(e,r,u);d(\"x\",g[0]),d(\"y\",g[1]),n.noneOrAll(t,e,[\"x\",\"y\"]),d(\"xanchor\"),d(\"yanchor\"),n.coerceFont(d,\"font\",r.font);var v=d(\"bgcolor\");d(\"activecolor\",i.contrast(v,l.lightAmount,l.darkAmount)),d(\"bordercolor\"),d(\"borderwidth\")}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/array_container_defaults\":763,\"../color\":593,\"./attributes\":655,\"./constants\":656}],658:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../color\"),s=t(\"../drawing\"),l=t(\"../../lib\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"../../plots/cartesian/axis_ids\"),h=t(\"../../constants/alignment\"),f=h.LINE_SPACING,p=h.FROM_TL,d=h.FROM_BR,g=t(\"./constants\"),v=t(\"./get_update_object\");function m(t){return t._id}function y(t,e,r){var n=l.ensureSingle(t,\"rect\",\"selector-rect\",function(t){t.attr(\"shape-rendering\",\"crispEdges\")});n.attr({rx:g.rx,ry:g.ry}),n.call(o.stroke,e.bordercolor).call(o.fill,function(t,e){return e._isActive||e._isHovered?t.activecolor:t.bgcolor}(e,r)).style(\"stroke-width\",e.borderwidth+\"px\")}function x(t,e,r,n){l.ensureSingle(t,\"text\",\"selector-text\",function(t){t.classed(\"user-select-none\",!0).attr(\"text-anchor\",\"middle\")}).call(s.font,e.font).text(function(t,e){if(t.label)return e?l.templateString(t.label,e):t.label;return\"all\"===t.step?\"all\":t.count+t.step.charAt(0)}(r,n._fullLayout._meta)).call(function(t){c.convertToTspans(t,n)})}e.exports=function(t){var e=t._fullLayout._infolayer.selectAll(\".rangeselector\").data(function(t){for(var e=u.list(t,\"x\",!0),r=[],n=0;n<e.length;n++){var i=e[n];i.rangeselector&&i.rangeselector.visible&&r.push(i)}return r}(t),m);e.enter().append(\"g\").classed(\"rangeselector\",!0),e.exit().remove(),e.style({cursor:\"pointer\",\"pointer-events\":\"all\"}),e.each(function(e){var r=n.select(this),o=e,u=o.rangeselector,h=r.selectAll(\"g.button\").data(l.filterVisible(u.buttons));h.enter().append(\"g\").classed(\"button\",!0),h.exit().remove(),h.each(function(e){var r=n.select(this),a=v(o,e);e._isActive=function(t,e,r){if(\"all\"===e.step)return!0===t.autorange;var n=Object.keys(r);return t.range[0]===r[n[0]]&&t.range[1]===r[n[1]]}(o,e,a),r.call(y,u,e),r.call(x,u,e,t),r.on(\"click\",function(){t._dragged||i.call(\"_guiRelayout\",t,a)}),r.on(\"mouseover\",function(){e._isHovered=!0,r.call(y,u,e)}),r.on(\"mouseout\",function(){e._isHovered=!1,r.call(y,u,e)})}),function(t,e,r,i,o){var u=0,h=0,v=r.borderwidth;e.each(function(){var t=n.select(this),e=t.select(\".selector-text\"),i=r.font.size*f,a=Math.max(i*c.lineCount(e),16)+3;h=Math.max(h,a)}),e.each(function(){var t=n.select(this),e=t.select(\".selector-rect\"),i=t.select(\".selector-text\"),a=i.node()&&s.bBox(i.node()).width,o=r.font.size*f,l=c.lineCount(i),p=Math.max(a+10,g.minButtonWidth);t.attr(\"transform\",\"translate(\"+(v+u)+\",\"+v+\")\"),e.attr({x:0,y:0,width:p,height:h}),c.positionText(i,p/2,h/2-(l-1)*o/2+3),u+=p+5});var m=t._fullLayout._size,y=m.l+m.w*r.x,x=m.t+m.h*(1-r.y),b=\"left\";l.isRightAnchor(r)&&(y-=u,b=\"right\");l.isCenterAnchor(r)&&(y-=u/2,b=\"center\");var _=\"top\";l.isBottomAnchor(r)&&(x-=h,_=\"bottom\");l.isMiddleAnchor(r)&&(x-=h/2,_=\"middle\");u=Math.ceil(u),h=Math.ceil(h),y=Math.round(y),x=Math.round(x),a.autoMargin(t,i+\"-range-selector\",{x:r.x,y:r.y,l:u*p[b],r:u*d[b],b:h*d[_],t:h*p[_]}),o.attr(\"transform\",\"translate(\"+y+\",\"+x+\")\")}(t,h,u,o._name,r)})}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axis_ids\":770,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../drawing\":614,\"./constants\":656,\"./get_update_object\":659,d3:163}],659:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e){var r=t._name,i={};if(\"all\"===e.step)i[r+\".autorange\"]=!0;else{var a=function(t,e){var r,i=t.range,a=new Date(t.r2l(i[1])),o=e.step,s=e.count;switch(e.stepmode){case\"backward\":r=t.l2r(+n.time[o].utc.offset(a,-s));break;case\"todate\":var l=n.time[o].utc.offset(a,-s);r=t.l2r(+n.time[o].utc.ceil(l))}var c=i[1];return[r,c]}(t,e);i[r+\".range[0]\"]=a[0],i[r+\".range[1]\"]=a[1]}return i}},{d3:163}],660:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"rangeselector\",schema:{subplots:{xaxis:{rangeselector:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":655,\"./defaults\":657,\"./draw\":658}],661:[function(t,e,r){\"use strict\";var n=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",dflt:n.background,editType:\"plot\"},bordercolor:{valType:\"color\",dflt:n.defaultLine,editType:\"plot\"},borderwidth:{valType:\"integer\",dflt:0,min:0,editType:\"plot\"},autorange:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}}],editType:\"calc\",impliedEdits:{autorange:!1}},thickness:{valType:\"number\",dflt:.15,min:0,max:1,editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"}},{\"../color/attributes\":592}],662:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\").list,i=t(\"../../plots/cartesian/autorange\").getAutoRange,a=t(\"./constants\");e.exports=function(t){for(var e=n(t,\"x\",!0),r=0;r<e.length;r++){var o=e[r],s=o[a.name];s&&s.visible&&s.autorange&&(s._input.autorange=!0,s._input.range=s.range=i(t,o))}}},{\"../../plots/cartesian/autorange\":766,\"../../plots/cartesian/axis_ids\":770,\"./constants\":663}],663:[function(t,e,r){\"use strict\";e.exports={name:\"rangeslider\",containerClassName:\"rangeslider-container\",bgClassName:\"rangeslider-bg\",rangePlotClassName:\"rangeslider-rangeplot\",maskMinClassName:\"rangeslider-mask-min\",maskMaxClassName:\"rangeslider-mask-max\",slideBoxClassName:\"rangeslider-slidebox\",grabberMinClassName:\"rangeslider-grabber-min\",grabAreaMinClassName:\"rangeslider-grabarea-min\",handleMinClassName:\"rangeslider-handle-min\",grabberMaxClassName:\"rangeslider-grabber-max\",grabAreaMaxClassName:\"rangeslider-grabarea-max\",handleMaxClassName:\"rangeslider-handle-max\",maskMinOppAxisClassName:\"rangeslider-mask-min-opp-axis\",maskMaxOppAxisClassName:\"rangeslider-mask-max-opp-axis\",maskColor:\"rgba(0,0,0,0.4)\",maskOppAxisColor:\"rgba(0,0,0,0.2)\",slideBoxFill:\"transparent\",slideBoxCursor:\"ew-resize\",grabAreaFill:\"transparent\",grabAreaCursor:\"col-resize\",grabAreaWidth:10,handleWidth:4,handleRadius:1,handleStrokeWidth:1,extraPad:15}},{}],664:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"./attributes\"),s=t(\"./oppaxis_attributes\");e.exports=function(t,e,r){var l=t[r],c=e[r];if(l.rangeslider||e._requestRangeslider[c._id]){n.isPlainObject(l.rangeslider)||(l.rangeslider={});var u,h,f=l.rangeslider,p=i.newContainer(c,\"rangeslider\");if(_(\"visible\")){_(\"bgcolor\",e.plot_bgcolor),_(\"bordercolor\"),_(\"borderwidth\"),_(\"thickness\"),_(\"autorange\",!c.isValidRange(f.range)),_(\"range\");var d=e._subplots;if(d)for(var g=d.cartesian.filter(function(t){return t.substr(0,t.indexOf(\"y\"))===a.name2id(r)}).map(function(t){return t.substr(t.indexOf(\"y\"),t.length)}),v=n.simpleMap(g,a.id2name),m=0;m<v.length;m++){var y=v[m];u=f[y]||{},h=i.newContainer(p,y,\"yaxis\");var x,b=e[y];u.range&&b.isValidRange(u.range)&&(x=\"fixed\"),\"match\"!==w(\"rangemode\",x)&&w(\"range\",b.range.slice())}p._input=f}}function _(t,e){return n.coerce(f,p,o,t,e)}function w(t,e){return n.coerce(u,h,s,t,e)}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/axis_ids\":770,\"./attributes\":661,\"./oppaxis_attributes\":668}],665:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=t(\"../drawing\"),l=t(\"../color\"),c=t(\"../titles\"),u=t(\"../../plots/cartesian\"),h=t(\"../../plots/cartesian/axis_ids\"),f=t(\"../dragelement\"),p=t(\"../../lib/setcursor\"),d=t(\"./constants\");function g(t,e,r,n){var i=o.ensureSingle(t,\"rect\",d.bgClassName,function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})}),a=n.borderwidth%2==0?n.borderwidth:n.borderwidth-1,l=-n._offsetShift,c=s.crispRound(e,n.borderwidth);i.attr({width:n._width+a,height:n._height+a,transform:\"translate(\"+l+\",\"+l+\")\",fill:n.bgcolor,stroke:n.bordercolor,\"stroke-width\":c})}function v(t,e,r,n){var i=e._fullLayout;o.ensureSingleById(i._topdefs,\"clipPath\",n._clipId,function(t){t.append(\"rect\").attr({x:0,y:0})}).select(\"rect\").attr({width:n._width,height:n._height})}function m(t,e,r,i){var l,c=e.calcdata,f=t.selectAll(\"g.\"+d.rangePlotClassName).data(r._subplotsWith,o.identity);f.enter().append(\"g\").attr(\"class\",function(t){return d.rangePlotClassName+\" \"+t}).call(s.setClipUrl,i._clipId,e),f.order(),f.exit().remove(),f.each(function(t,o){var s=n.select(this),f=0===o,p=h.getFromId(e,t,\"y\"),d=p._name,g=i[d],v={data:[],layout:{xaxis:{type:r.type,domain:[0,1],range:i.range.slice(),calendar:r.calendar},width:i._width,height:i._height,margin:{t:0,b:0,l:0,r:0}},_context:e._context};v.layout[d]={type:p.type,domain:[0,1],range:\"match\"!==g.rangemode?g.range.slice():p.range.slice(),calendar:p.calendar},a.supplyDefaults(v);var m=v._fullLayout.xaxis,y=v._fullLayout[d];m.clearCalc(),m.setScale(),y.clearCalc(),y.setScale();var x={id:t,plotgroup:s,xaxis:m,yaxis:y,isRangePlot:!0};f?l=x:(x.mainplot=\"xy\",x.mainplotinfo=l),u.rangePlot(e,x,function(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n],a=i[0].trace;a.xaxis+a.yaxis===e&&r.push(i)}return r}(c,t))})}function y(t,e,r,n,i){(o.ensureSingle(t,\"rect\",d.maskMinClassName,function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"height\",n._height).call(l.fill,d.maskColor),o.ensureSingle(t,\"rect\",d.maskMaxClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"height\",n._height).call(l.fill,d.maskColor),\"match\"!==i.rangemode)&&(o.ensureSingle(t,\"rect\",d.maskMinOppAxisClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"width\",n._width).call(l.fill,d.maskOppAxisColor),o.ensureSingle(t,\"rect\",d.maskMaxOppAxisClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"width\",n._width).style(\"border-top\",d.maskOppBorder).call(l.fill,d.maskOppAxisColor))}function x(t,e,r,n){e._context.staticPlot||o.ensureSingle(t,\"rect\",d.slideBoxClassName,function(t){t.attr({y:0,cursor:d.slideBoxCursor,\"shape-rendering\":\"crispEdges\"})}).attr({height:n._height,fill:d.slideBoxFill})}function b(t,e,r,n){var i=o.ensureSingle(t,\"g\",d.grabberMinClassName),a=o.ensureSingle(t,\"g\",d.grabberMaxClassName),s={x:0,width:d.handleWidth,rx:d.handleRadius,fill:l.background,stroke:l.defaultLine,\"stroke-width\":d.handleStrokeWidth,\"shape-rendering\":\"crispEdges\"},c={y:Math.round(n._height/4),height:Math.round(n._height/2)};if(o.ensureSingle(i,\"rect\",d.handleMinClassName,function(t){t.attr(s)}).attr(c),o.ensureSingle(a,\"rect\",d.handleMaxClassName,function(t){t.attr(s)}).attr(c),!e._context.staticPlot){var u={width:d.grabAreaWidth,x:0,y:0,fill:d.grabAreaFill,cursor:d.grabAreaCursor};o.ensureSingle(i,\"rect\",d.grabAreaMinClassName,function(t){t.attr(u)}).attr(\"height\",n._height),o.ensureSingle(a,\"rect\",d.grabAreaMaxClassName,function(t){t.attr(u)}).attr(\"height\",n._height)}}e.exports=function(t){for(var e=t._fullLayout,r=e._rangeSliderData,a=0;a<r.length;a++){var s=r[a][d.name];s._clipId=s._id+\"-\"+e._uid}var l=e._infolayer.selectAll(\"g.\"+d.containerClassName).data(r,function(t){return t._name});l.exit().each(function(t){var r=t[d.name];e._topdefs.select(\"#\"+r._clipId).remove()}).remove(),0!==r.length&&(l.enter().append(\"g\").classed(d.containerClassName,!0).attr(\"pointer-events\",\"all\"),l.each(function(r){var a=n.select(this),s=r[d.name],l=e[h.id2name(r.anchor)],u=s[h.id2name(r.anchor)];if(s.range){var _,w=o.simpleMap(s.range,r.r2l),k=o.simpleMap(r.range,r.r2l);_=k[0]<k[1]?[Math.min(w[0],k[0]),Math.max(w[1],k[1])]:[Math.max(w[0],k[0]),Math.min(w[1],k[1])],s.range=s._input.range=o.simpleMap(_,r.l2r)}r.cleanRange(\"rangeslider.range\");var T=e.margin,A=e._size,M=r.domain,S=s._tickHeight,E=s._oppBottom;s._width=A.w*(M[1]-M[0]);var C=Math.round(T.l+A.w*M[0]),L=Math.round(A.t+A.h*(1-E)+S+s._offsetShift+d.extraPad);a.attr(\"transform\",\"translate(\"+C+\",\"+L+\")\");var P=r.r2l(s.range[0]),O=r.r2l(s.range[1]),z=O-P;if(s.p2d=function(t){return t/s._width*z+P},s.d2p=function(t){return(t-P)/z*s._width},s._rl=[P,O],\"match\"!==u.rangemode){var I=l.r2l(u.range[0]),D=l.r2l(u.range[1])-I;s.d2pOppAxis=function(t){return(t-I)/D*s._height}}a.call(g,t,r,s).call(v,t,r,s).call(m,t,r,s).call(y,t,r,s,u).call(x,t,r,s).call(b,t,r,s),function(t,e,r,a){var s=t.select(\"rect.\"+d.slideBoxClassName).node(),l=t.select(\"rect.\"+d.grabAreaMinClassName).node(),c=t.select(\"rect.\"+d.grabAreaMaxClassName).node();t.on(\"mousedown\",function(){var u=n.event,h=u.target,d=u.clientX,g=d-t.node().getBoundingClientRect().left,v=a.d2p(r._rl[0]),m=a.d2p(r._rl[1]),y=f.coverSlip();function x(t){var u,f,x,b=+t.clientX-d;switch(h){case s:x=\"ew-resize\",u=v+b,f=m+b;break;case l:x=\"col-resize\",u=v+b,f=m;break;case c:x=\"col-resize\",u=v,f=m+b;break;default:x=\"ew-resize\",u=g,f=g+b}if(f<u){var _=f;f=u,u=_}a._pixelMin=u,a._pixelMax=f,p(n.select(y),x),function(t,e,r,n){function a(t){return r.l2r(o.constrain(t,n._rl[0],n._rl[1]))}var s=a(n.p2d(n._pixelMin)),l=a(n.p2d(n._pixelMax));window.requestAnimationFrame(function(){i.call(\"_guiRelayout\",e,r._name+\".range\",[s,l])})}(0,e,r,a)}y.addEventListener(\"mousemove\",x),y.addEventListener(\"mouseup\",function t(){y.removeEventListener(\"mousemove\",x);y.removeEventListener(\"mouseup\",t);o.removeElement(y)})})}(a,t,r,s),function(t,e,r,n,i,a){var s=d.handleWidth/2;function l(t){return o.constrain(t,0,n._width)}function c(t){return o.constrain(t,0,n._height)}function u(t){return o.constrain(t,-s,n._width+s)}var h=l(n.d2p(r._rl[0])),f=l(n.d2p(r._rl[1]));if(t.select(\"rect.\"+d.slideBoxClassName).attr(\"x\",h).attr(\"width\",f-h),t.select(\"rect.\"+d.maskMinClassName).attr(\"width\",h),t.select(\"rect.\"+d.maskMaxClassName).attr(\"x\",f).attr(\"width\",n._width-f),\"match\"!==a.rangemode){var p=n._height-c(n.d2pOppAxis(i._rl[1])),g=n._height-c(n.d2pOppAxis(i._rl[0]));t.select(\"rect.\"+d.maskMinOppAxisClassName).attr(\"x\",h).attr(\"height\",p).attr(\"width\",f-h),t.select(\"rect.\"+d.maskMaxOppAxisClassName).attr(\"x\",h).attr(\"y\",g).attr(\"height\",n._height-g).attr(\"width\",f-h),t.select(\"rect.\"+d.slideBoxClassName).attr(\"y\",p).attr(\"height\",g-p)}var v=Math.round(u(h-s))-.5,m=Math.round(u(f-s))+.5;t.select(\"g.\"+d.grabberMinClassName).attr(\"transform\",\"translate(\"+v+\",0.5)\"),t.select(\"g.\"+d.grabberMaxClassName).attr(\"transform\",\"translate(\"+m+\",0.5)\")}(a,0,r,s,l,u),\"bottom\"===r.side&&c.draw(t,r._id+\"title\",{propContainer:r,propName:r._name+\".title\",placeholder:e._dfltTitle.x,attributes:{x:r._offset+r._length/2,y:L+s._height+s._offsetShift+10+1.5*r.title.font.size,\"text-anchor\":\"middle\"}})}))}},{\"../../lib\":719,\"../../lib/setcursor\":739,\"../../plots/cartesian\":778,\"../../plots/cartesian/axis_ids\":770,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"../titles\":681,\"./constants\":663,d3:163}],666:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"./constants\"),a=i.name;function o(t){var e=t&&t[a];return e&&e.visible}r.isVisible=o,r.makeData=function(t){var e=n.list({_fullLayout:t},\"x\",!0),r=t.margin,i=[];if(!t._has(\"gl2d\"))for(var s=0;s<e.length;s++){var l=e[s];if(o(l)){i.push(l);var c=l[a];c._id=a+l._id,c._height=(t.height-r.b-r.t)*c.thickness,c._offsetShift=Math.floor(c.borderwidth/2)}}t._rangeSliderData=i},r.autoMarginOpts=function(t,e){for(var r=e[a],o=1/0,s=e._counterAxes,l=0;l<s.length;l++){var c=s[l],u=n.getFromId(t,c);o=Math.min(o,u.domain[0])}r._oppBottom=o;var h=\"bottom\"===e.side&&e._boundingBox.height||0;return r._tickHeight=h,{x:0,y:o,l:0,r:0,t:0,b:r._height+t._fullLayout.margin.b+h,pad:i.extraPad+2*r._offsetShift}}},{\"../../plots/cartesian/axis_ids\":770,\"./constants\":663}],667:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./oppaxis_attributes\"),o=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"rangeslider\",schema:{subplots:{xaxis:{rangeslider:n.extendFlat({},i,{yaxis:a})}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),calcAutorange:t(\"./calc_autorange\"),draw:t(\"./draw\"),isVisible:o.isVisible,makeData:o.makeData,autoMarginOpts:o.autoMarginOpts}},{\"../../lib\":719,\"./attributes\":661,\"./calc_autorange\":662,\"./defaults\":664,\"./draw\":665,\"./helpers\":666,\"./oppaxis_attributes\":668}],668:[function(t,e,r){\"use strict\";e.exports={_isSubplotObj:!0,rangemode:{valType:\"enumerated\",values:[\"auto\",\"fixed\",\"match\"],dflt:\"match\",editType:\"calc\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"plot\"},{valType:\"any\",editType:\"plot\"}],editType:\"plot\"},editType:\"calc\"}},{}],669:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../traces/scatter/attributes\").line,a=t(\"../drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray;e.exports=s(\"shape\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},type:{valType:\"enumerated\",values:[\"circle\",\"rect\",\"path\",\"line\"],editType:\"calc+arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},xref:o({},n.xref,{}),xsizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},xanchor:{valType:\"any\",editType:\"calc+arraydraw\"},x0:{valType:\"any\",editType:\"calc+arraydraw\"},x1:{valType:\"any\",editType:\"calc+arraydraw\"},yref:o({},n.yref,{}),ysizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},yanchor:{valType:\"any\",editType:\"calc+arraydraw\"},y0:{valType:\"any\",editType:\"calc+arraydraw\"},y1:{valType:\"any\",editType:\"calc+arraydraw\"},path:{valType:\"string\",editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},line:{color:o({},i.color,{editType:\"arraydraw\"}),width:o({},i.width,{editType:\"calc+arraydraw\"}),dash:o({},a,{editType:\"arraydraw\"}),editType:\"calc+arraydraw\"},fillcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},editType:\"arraydraw\"})},{\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../../traces/scatter/attributes\":1112,\"../annotations/attributes\":576,\"../drawing/attributes\":613}],670:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./constants\"),o=t(\"./helpers\");function s(t){return c(t.line.width,t.xsizemode,t.x0,t.x1,t.path,!1)}function l(t){return c(t.line.width,t.ysizemode,t.y0,t.y1,t.path,!0)}function c(t,e,r,i,s,l){var c=t/2,u=l;if(\"pixel\"===e){var h=s?o.extractPathCoords(s,l?a.paramIsY:a.paramIsX):[r,i],f=n.aggNums(Math.max,null,h),p=n.aggNums(Math.min,null,h),d=p<0?Math.abs(p)+c:c,g=f>0?f+c:c;return{ppad:c,ppadplus:u?d:g,ppadminus:u?g:d}}return{ppad:c}}function u(t,e,r,n,i){var s=\"category\"===t.type||\"multicategory\"===t.type?t.r2c:t.d2c;if(void 0!==e)return[s(e),s(r)];if(n){var l,c,u,h,f=1/0,p=-1/0,d=n.match(a.segmentRE);for(\"date\"===t.type&&(s=o.decodeDate(s)),l=0;l<d.length;l++)void 0!==(c=i[d[l].charAt(0)].drawn)&&(!(u=d[l].substr(1).match(a.paramRE))||u.length<c||((h=s(u[c]))<f&&(f=h),h>p&&(p=h)));return p>=f?[f,p]:void 0}}e.exports=function(t){var e=t._fullLayout,r=n.filterVisible(e.shapes);if(r.length&&t._fullData.length)for(var o=0;o<r.length;o++){var c,h,f=r[o];if(f._extremes={},\"paper\"!==f.xref){var p=\"pixel\"===f.xsizemode?f.xanchor:f.x0,d=\"pixel\"===f.xsizemode?f.xanchor:f.x1;(h=u(c=i.getFromId(t,f.xref),p,d,f.path,a.paramIsX))&&(f._extremes[c._id]=i.findExtremes(c,h,s(f)))}if(\"paper\"!==f.yref){var g=\"pixel\"===f.ysizemode?f.yanchor:f.y0,v=\"pixel\"===f.ysizemode?f.yanchor:f.y1;(h=u(c=i.getFromId(t,f.yref),g,v,f.path,a.paramIsY))&&(f._extremes[c._id]=i.findExtremes(c,h,l(f)))}}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./constants\":671,\"./helpers\":674}],671:[function(t,e,r){\"use strict\";e.exports={segmentRE:/[MLHVQCTSZ][^MLHVQCTSZ]*/g,paramRE:/[^\\s,]+/g,paramIsX:{M:{0:!0,drawn:0},L:{0:!0,drawn:0},H:{0:!0,drawn:0},V:{},Q:{0:!0,2:!0,drawn:2},C:{0:!0,2:!0,4:!0,drawn:4},T:{0:!0,drawn:0},S:{0:!0,2:!0,drawn:2},Z:{}},paramIsY:{M:{1:!0,drawn:1},L:{1:!0,drawn:1},H:{},V:{0:!0,drawn:0},Q:{1:!0,3:!0,drawn:3},C:{1:!0,3:!0,5:!0,drawn:5},T:{1:!0,drawn:1},S:{1:!0,3:!0,drawn:5},Z:{}},numParams:{M:2,L:2,H:1,V:1,Q:4,C:6,T:2,S:4,Z:0}}},{}],672:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\"),s=t(\"./helpers\");function l(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}if(a(\"visible\")){a(\"layer\"),a(\"opacity\"),a(\"fillcolor\"),a(\"line.color\"),a(\"line.width\"),a(\"line.dash\");for(var l=a(\"type\",t.path?\"path\":\"rect\"),c=a(\"xsizemode\"),u=a(\"ysizemode\"),h=[\"x\",\"y\"],f=0;f<2;f++){var p,d,g,v=h[f],m=v+\"anchor\",y=\"x\"===v?c:u,x={_fullLayout:r},b=i.coerceRef(t,e,x,v,\"\",\"paper\");if(\"paper\"!==b?((p=i.getFromId(x,b))._shapeIndices.push(e._index),g=s.rangeToShapePosition(p),d=s.shapePositionToRange(p)):d=g=n.identity,\"path\"!==l){var _=v+\"0\",w=v+\"1\",k=t[_],T=t[w];t[_]=d(t[_],!0),t[w]=d(t[w],!0),\"pixel\"===y?(a(_,0),a(w,10)):(i.coercePosition(e,x,a,b,_,.25),i.coercePosition(e,x,a,b,w,.75)),e[_]=g(e[_]),e[w]=g(e[w]),t[_]=k,t[w]=T}if(\"pixel\"===y){var A=t[m];t[m]=d(t[m],!0),i.coercePosition(e,x,a,b,m,.25),e[m]=g(e[m]),t[m]=A}}\"path\"===l?a(\"path\"):n.noneOrAll(t,e,[\"x0\",\"x1\",\"y0\",\"y1\"])}}e.exports=function(t,e){a(t,e,{name:\"shapes\",handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"./attributes\":669,\"./helpers\":674}],673:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../color\"),s=t(\"../drawing\"),l=t(\"../../plot_api/plot_template\").arrayEditor,c=t(\"../dragelement\"),u=t(\"../../lib/setcursor\"),h=t(\"./constants\"),f=t(\"./helpers\");function p(t,e){t._fullLayout._paperdiv.selectAll('.shapelayer [data-index=\"'+e+'\"]').remove();var r=t._fullLayout.shapes[e]||{};if(r._input&&!1!==r.visible)if(\"below\"!==r.layer)m(t._fullLayout._shapeUpperLayer);else if(\"paper\"===r.xref||\"paper\"===r.yref)m(t._fullLayout._shapeLowerLayer);else{var p=t._fullLayout._plots[r.xref+r.yref];if(p)m((p.mainplotinfo||p).shapelayer);else m(t._fullLayout._shapeLowerLayer)}function m(p){var m={\"data-index\":e,\"fill-rule\":\"evenodd\",d:g(t,r)},y=r.line.width?r.line.color:\"rgba(0,0,0,0)\",x=p.append(\"path\").attr(m).style(\"opacity\",r.opacity).call(o.stroke,y).call(o.fill,r.fillcolor).call(s.dashLine,r.line.dash,r.line.width);d(x,t,r),t._context.edits.shapePosition&&function(t,e,r,o,p){var m,y,x,b,_,w,k,T,A,M,S,E,C,L,P,O,z=10,I=10,D=\"pixel\"===r.xsizemode,R=\"pixel\"===r.ysizemode,F=\"line\"===r.type,B=\"path\"===r.type,N=l(t.layout,\"shapes\",r),j=N.modifyItem,U=a.getFromId(t,r.xref),V=a.getFromId(t,r.yref),q=f.getDataToPixel(t,U),H=f.getDataToPixel(t,V,!0),G=f.getPixelToData(t,U),Y=f.getPixelToData(t,V,!0),W=F?function(){var t=Math.max(r.line.width,10),n=p.append(\"g\").attr(\"data-index\",o);n.append(\"path\").attr(\"d\",e.attr(\"d\")).style({cursor:\"move\",\"stroke-width\":t,\"stroke-opacity\":\"0\"});var i={\"fill-opacity\":\"0\"},a=t/2>10?t/2:10;return n.append(\"circle\").attr({\"data-line-point\":\"start-point\",cx:D?q(r.xanchor)+r.x0:q(r.x0),cy:R?H(r.yanchor)-r.y0:H(r.y0),r:a}).style(i).classed(\"cursor-grab\",!0),n.append(\"circle\").attr({\"data-line-point\":\"end-point\",cx:D?q(r.xanchor)+r.x1:q(r.x1),cy:R?H(r.yanchor)-r.y1:H(r.y1),r:a}).style(i).classed(\"cursor-grab\",!0),n}():e,X={element:W.node(),gd:t,prepFn:function(n){D&&(_=q(r.xanchor));R&&(w=H(r.yanchor));\"path\"===r.type?P=r.path:(m=D?r.x0:q(r.x0),y=R?r.y0:H(r.y0),x=D?r.x1:q(r.x1),b=R?r.y1:H(r.y1));m<x?(A=m,C=\"x0\",M=x,L=\"x1\"):(A=x,C=\"x1\",M=m,L=\"x0\");!R&&y<b||R&&y>b?(k=y,S=\"y0\",T=b,E=\"y1\"):(k=b,S=\"y1\",T=y,E=\"y0\");Z(n),$(p,r),function(t,e,r){var n=e.xref,i=e.yref,o=a.getFromId(r,n),l=a.getFromId(r,i),c=\"\";\"paper\"===n||o.autorange||(c+=n);\"paper\"===i||l.autorange||(c+=i);s.setClipUrl(t,c?\"clip\"+r._fullLayout._uid+c:null,r)}(e,r,t),X.moveFn=\"move\"===O?J:K},doneFn:function(){u(e),Q(p),d(e,t,r),n.call(\"_guiRelayout\",t,N.getUpdateObj())},clickFn:function(){Q(p)}};function Z(t){if(F)O=\"path\"===t.target.tagName?\"move\":\"start-point\"===t.target.attributes[\"data-line-point\"].value?\"resize-over-start-point\":\"resize-over-end-point\";else{var r=X.element.getBoundingClientRect(),n=r.right-r.left,i=r.bottom-r.top,a=t.clientX-r.left,o=t.clientY-r.top,s=!B&&n>z&&i>I&&!t.shiftKey?c.getCursor(a/n,1-o/i):\"move\";u(e,s),O=s.split(\"-\")[0]}}function J(n,i){if(\"path\"===r.type){var a=function(t){return t},o=a,s=a;D?j(\"xanchor\",r.xanchor=G(_+n)):(o=function(t){return G(q(t)+n)},U&&\"date\"===U.type&&(o=f.encodeDate(o))),R?j(\"yanchor\",r.yanchor=Y(w+i)):(s=function(t){return Y(H(t)+i)},V&&\"date\"===V.type&&(s=f.encodeDate(s))),j(\"path\",r.path=v(P,o,s))}else D?j(\"xanchor\",r.xanchor=G(_+n)):(j(\"x0\",r.x0=G(m+n)),j(\"x1\",r.x1=G(x+n))),R?j(\"yanchor\",r.yanchor=Y(w+i)):(j(\"y0\",r.y0=Y(y+i)),j(\"y1\",r.y1=Y(b+i)));e.attr(\"d\",g(t,r)),$(p,r)}function K(n,i){if(B){var a=function(t){return t},o=a,s=a;D?j(\"xanchor\",r.xanchor=G(_+n)):(o=function(t){return G(q(t)+n)},U&&\"date\"===U.type&&(o=f.encodeDate(o))),R?j(\"yanchor\",r.yanchor=Y(w+i)):(s=function(t){return Y(H(t)+i)},V&&\"date\"===V.type&&(s=f.encodeDate(s))),j(\"path\",r.path=v(P,o,s))}else if(F){if(\"resize-over-start-point\"===O){var l=m+n,c=R?y-i:y+i;j(\"x0\",r.x0=D?l:G(l)),j(\"y0\",r.y0=R?c:Y(c))}else if(\"resize-over-end-point\"===O){var u=x+n,h=R?b-i:b+i;j(\"x1\",r.x1=D?u:G(u)),j(\"y1\",r.y1=R?h:Y(h))}}else{var d=~O.indexOf(\"n\")?k+i:k,N=~O.indexOf(\"s\")?T+i:T,W=~O.indexOf(\"w\")?A+n:A,X=~O.indexOf(\"e\")?M+n:M;~O.indexOf(\"n\")&&R&&(d=k-i),~O.indexOf(\"s\")&&R&&(N=T-i),(!R&&N-d>I||R&&d-N>I)&&(j(S,r[S]=R?d:Y(d)),j(E,r[E]=R?N:Y(N))),X-W>z&&(j(C,r[C]=D?W:G(W)),j(L,r[L]=D?X:G(X)))}e.attr(\"d\",g(t,r)),$(p,r)}function $(t,e){(D||R)&&function(){var r=\"path\"!==e.type,n=t.selectAll(\".visual-cue\").data([0]);n.enter().append(\"path\").attr({fill:\"#fff\",\"fill-rule\":\"evenodd\",stroke:\"#000\",\"stroke-width\":1}).classed(\"visual-cue\",!0);var a=q(D?e.xanchor:i.midRange(r?[e.x0,e.x1]:f.extractPathCoords(e.path,h.paramIsX))),o=H(R?e.yanchor:i.midRange(r?[e.y0,e.y1]:f.extractPathCoords(e.path,h.paramIsY)));if(a=f.roundPositionForSharpStrokeRendering(a,1),o=f.roundPositionForSharpStrokeRendering(o,1),D&&R){var s=\"M\"+(a-1-1)+\",\"+(o-1-1)+\"h-8v2h8 v8h2v-8 h8v-2h-8 v-8h-2 Z\";n.attr(\"d\",s)}else if(D){var l=\"M\"+(a-1-1)+\",\"+(o-9-1)+\"v18 h2 v-18 Z\";n.attr(\"d\",l)}else{var c=\"M\"+(a-9-1)+\",\"+(o-1-1)+\"h18 v2 h-18 Z\";n.attr(\"d\",c)}}()}function Q(t){t.selectAll(\".visual-cue\").remove()}c.init(X),W.node().onmousemove=Z}(t,x,r,e,p)}}function d(t,e,r){var n=(r.xref+r.yref).replace(/paper/g,\"\");s.setClipUrl(t,n?\"clip\"+e._fullLayout._uid+n:null,e)}function g(t,e){var r,n,o,s,l,c,u,p,d=e.type,g=a.getFromId(t,e.xref),v=a.getFromId(t,e.yref),m=t._fullLayout._size;if(g?(r=f.shapePositionToRange(g),n=function(t){return g._offset+g.r2p(r(t,!0))}):n=function(t){return m.l+m.w*t},v?(o=f.shapePositionToRange(v),s=function(t){return v._offset+v.r2p(o(t,!0))}):s=function(t){return m.t+m.h*(1-t)},\"path\"===d)return g&&\"date\"===g.type&&(n=f.decodeDate(n)),v&&\"date\"===v.type&&(s=f.decodeDate(s)),function(t,e,r){var n=t.path,a=t.xsizemode,o=t.ysizemode,s=t.xanchor,l=t.yanchor;return n.replace(h.segmentRE,function(t){var n=0,c=t.charAt(0),u=h.paramIsX[c],f=h.paramIsY[c],p=h.numParams[c],d=t.substr(1).replace(h.paramRE,function(t){return u[n]?t=\"pixel\"===a?e(s)+Number(t):e(t):f[n]&&(t=\"pixel\"===o?r(l)-Number(t):r(t)),++n>p&&(t=\"X\"),t});return n>p&&(d=d.replace(/[\\s,]*X.*/,\"\"),i.log(\"Ignoring extra params in segment \"+t)),c+d})}(e,n,s);if(\"pixel\"===e.xsizemode){var y=n(e.xanchor);l=y+e.x0,c=y+e.x1}else l=n(e.x0),c=n(e.x1);if(\"pixel\"===e.ysizemode){var x=s(e.yanchor);u=x-e.y0,p=x-e.y1}else u=s(e.y0),p=s(e.y1);if(\"line\"===d)return\"M\"+l+\",\"+u+\"L\"+c+\",\"+p;if(\"rect\"===d)return\"M\"+l+\",\"+u+\"H\"+c+\"V\"+p+\"H\"+l+\"Z\";var b=(l+c)/2,_=(u+p)/2,w=Math.abs(b-l),k=Math.abs(_-u),T=\"A\"+w+\",\"+k,A=b+w+\",\"+_;return\"M\"+A+T+\" 0 1,1 \"+(b+\",\"+(_-k))+T+\" 0 0,1 \"+A+\"Z\"}function v(t,e,r){return t.replace(h.segmentRE,function(t){var n=0,i=t.charAt(0),a=h.paramIsX[i],o=h.paramIsY[i],s=h.numParams[i];return i+t.substr(1).replace(h.paramRE,function(t){return n>=s?t:(a[n]?t=e(t):o[n]&&(t=r(t)),n++,t)})})}e.exports={draw:function(t){var e=t._fullLayout;for(var r in e._shapeUpperLayer.selectAll(\"path\").remove(),e._shapeLowerLayer.selectAll(\"path\").remove(),e._plots){var n=e._plots[r].shapelayer;n&&n.selectAll(\"path\").remove()}for(var i=0;i<e.shapes.length;i++)e.shapes[i].visible&&p(t,i)},drawOne:p}},{\"../../lib\":719,\"../../lib/setcursor\":739,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"./constants\":671,\"./helpers\":674}],674:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib\");r.rangeToShapePosition=function(t){return\"log\"===t.type?t.r2d:function(t){return t}},r.shapePositionToRange=function(t){return\"log\"===t.type?t.d2r:function(t){return t}},r.decodeDate=function(t){return function(e){return e.replace&&(e=e.replace(\"_\",\" \")),t(e)}},r.encodeDate=function(t){return function(e){return t(e).replace(\" \",\"_\")}},r.extractPathCoords=function(t,e){var r=[];return t.match(n.segmentRE).forEach(function(t){var a=e[t.charAt(0)].drawn;if(void 0!==a){var o=t.substr(1).match(n.paramRE);!o||o.length<a||r.push(i.cleanNumber(o[a]))}}),r},r.getDataToPixel=function(t,e,n){var i,a=t._fullLayout._size;if(e){var o=r.shapePositionToRange(e);i=function(t){return e._offset+e.r2p(o(t,!0))},\"date\"===e.type&&(i=r.decodeDate(i))}else i=n?function(t){return a.t+a.h*(1-t)}:function(t){return a.l+a.w*t};return i},r.getPixelToData=function(t,e,n){var i,a=t._fullLayout._size;if(e){var o=r.rangeToShapePosition(e);i=function(t){return o(e.p2r(t-e._offset))}}else i=n?function(t){return 1-(t-a.t)/a.h}:function(t){return(t-a.l)/a.w};return i},r.roundPositionForSharpStrokeRendering=function(t,e){var r=1===Math.round(e%2),n=Math.round(t);return r?n+.5:n}},{\"../../lib\":719,\"./constants\":671}],675:[function(t,e,r){\"use strict\";var n=t(\"./draw\");e.exports={moduleType:\"component\",name:\"shapes\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"shapes\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne}},{\"../../plots/cartesian/include_components\":777,\"./attributes\":669,\"./calc_autorange\":670,\"./defaults\":672,\"./draw\":673}],676:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/pad_attributes\"),a=t(\"../../lib/extend\").extendDeepAll,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/animation_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"./constants\"),u=l(\"step\",{visible:{valType:\"boolean\",dflt:!0},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\"},value:{valType:\"string\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"slider\",{visible:{valType:\"boolean\",dflt:!0},active:{valType:\"number\",min:0,dflt:0},steps:u,lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",min:-2,max:3,dflt:0},pad:a(i({editType:\"arraydraw\"}),{},{t:{dflt:20}}),xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\"},y:{valType:\"number\",min:-2,max:3,dflt:0},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},transition:{duration:{valType:\"number\",min:0,dflt:150},easing:{valType:\"enumerated\",values:s.transition.easing.values,dflt:\"cubic-in-out\"}},currentvalue:{visible:{valType:\"boolean\",dflt:!0},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},offset:{valType:\"number\",dflt:10},prefix:{valType:\"string\"},suffix:{valType:\"string\"},font:n({})},font:n({}),activebgcolor:{valType:\"color\",dflt:c.gripBgActiveColor},bgcolor:{valType:\"color\",dflt:c.railBgColor},bordercolor:{valType:\"color\",dflt:c.railBorderColor},borderwidth:{valType:\"number\",min:0,dflt:c.railBorderWidth},ticklen:{valType:\"number\",min:0,dflt:c.tickLength},tickcolor:{valType:\"color\",dflt:c.tickColor},tickwidth:{valType:\"number\",min:0,dflt:1},minorticklen:{valType:\"number\",min:0,dflt:c.minorTickLength}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/animation_attributes\":762,\"../../plots/font_attributes\":793,\"../../plots/pad_attributes\":827,\"./constants\":677}],677:[function(t,e,r){\"use strict\";e.exports={name:\"sliders\",containerClassName:\"slider-container\",groupClassName:\"slider-group\",inputAreaClass:\"slider-input-area\",railRectClass:\"slider-rail-rect\",railTouchRectClass:\"slider-rail-touch-rect\",gripRectClass:\"slider-grip-rect\",tickRectClass:\"slider-tick-rect\",inputProxyClass:\"slider-input-proxy\",labelsClass:\"slider-labels\",labelGroupClass:\"slider-label-group\",labelClass:\"slider-label\",currentValueClass:\"slider-current-value\",railHeight:5,menuIndexAttrName:\"slider-active-index\",autoMarginIdRoot:\"slider-\",minWidth:30,minHeight:30,textPadX:40,arrowOffsetX:4,railRadius:2,railWidth:5,railBorder:4,railBorderWidth:1,railBorderColor:\"#bec8d9\",railBgColor:\"#f8fafc\",railInset:8,stepInset:10,gripRadius:10,gripWidth:20,gripHeight:20,gripBorder:20,gripBorderWidth:1,gripBorderColor:\"#bec8d9\",gripBgColor:\"#f6f8fa\",gripBgActiveColor:\"#dbdde0\",labelPadding:8,labelOffset:0,tickWidth:1,tickColor:\"#333\",tickOffset:25,tickLength:7,minorTickOffset:25,minorTickColor:\"#333\",minorTickLength:4,currentValuePadding:8,currentValueInset:0}},{}],678:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.steps;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}for(var s=i(t,e,{name:\"steps\",handleItemDefaults:c}),l=0,u=0;u<s.length;u++)s[u].visible&&l++;if(l<2?e.visible=!1:o(\"visible\")){e._stepCount=l;var h=e._visibleSteps=n.filterVisible(s);(s[o(\"active\")]||{}).visible||(e.active=h[0]._index),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"len\"),o(\"lenmode\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"currentvalue.visible\")&&(o(\"currentvalue.xanchor\"),o(\"currentvalue.prefix\"),o(\"currentvalue.suffix\"),o(\"currentvalue.offset\"),n.coerceFont(o,\"currentvalue.font\",e.font)),o(\"transition.duration\"),o(\"transition.easing\"),o(\"bgcolor\"),o(\"activebgcolor\"),o(\"bordercolor\"),o(\"borderwidth\"),o(\"ticklen\"),o(\"tickwidth\"),o(\"tickcolor\"),o(\"minorticklen\")}}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}if(\"skip\"===t.method||Array.isArray(t.args)?r(\"visible\"):e.visible=!1){r(\"method\"),r(\"args\");var i=r(\"label\",\"step-\"+e._index);r(\"value\",i),r(\"execute\")}}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"./attributes\":676,\"./constants\":677}],679:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"./constants\"),h=t(\"../../constants/alignment\"),f=h.LINE_SPACING,p=h.FROM_TL,d=h.FROM_BR;function g(t){return u.autoMarginIdRoot+t._index}function v(t){return t._index}function m(t,e){var r=o.tester.selectAll(\"g.\"+u.labelGroupClass).data(e._visibleSteps);r.enter().append(\"g\").classed(u.labelGroupClass,!0);var a=0,c=0;r.each(function(t){var r=b(n.select(this),{step:t},e).node();if(r){var i=o.bBox(r);c=Math.max(c,i.height),a=Math.max(a,i.width)}}),r.remove();var h=e._dims={};h.inputAreaWidth=Math.max(u.railWidth,u.gripHeight);var f=t._fullLayout._size;h.lx=f.l+f.w*e.x,h.ly=f.t+f.h*(1-e.y),\"fraction\"===e.lenmode?h.outerLength=Math.round(f.w*e.len):h.outerLength=e.len,h.inputAreaStart=0,h.inputAreaLength=Math.round(h.outerLength-e.pad.l-e.pad.r);var v=(h.inputAreaLength-2*u.stepInset)/(e._stepCount-1),m=a+u.labelPadding;if(h.labelStride=Math.max(1,Math.ceil(m/v)),h.labelHeight=c,h.currentValueMaxWidth=0,h.currentValueHeight=0,h.currentValueTotalHeight=0,h.currentValueMaxLines=1,e.currentvalue.visible){var x=o.tester.append(\"g\");r.each(function(t){var r=y(x,e,t.label),n=r.node()&&o.bBox(r.node())||{width:0,height:0},i=l.lineCount(r);h.currentValueMaxWidth=Math.max(h.currentValueMaxWidth,Math.ceil(n.width)),h.currentValueHeight=Math.max(h.currentValueHeight,Math.ceil(n.height)),h.currentValueMaxLines=Math.max(h.currentValueMaxLines,i)}),h.currentValueTotalHeight=h.currentValueHeight+e.currentvalue.offset,x.remove()}h.height=h.currentValueTotalHeight+u.tickOffset+e.ticklen+u.labelOffset+h.labelHeight+e.pad.t+e.pad.b;var _=\"left\";s.isRightAnchor(e)&&(h.lx-=h.outerLength,_=\"right\"),s.isCenterAnchor(e)&&(h.lx-=h.outerLength/2,_=\"center\");var w=\"top\";s.isBottomAnchor(e)&&(h.ly-=h.height,w=\"bottom\"),s.isMiddleAnchor(e)&&(h.ly-=h.height/2,w=\"middle\"),h.outerLength=Math.ceil(h.outerLength),h.height=Math.ceil(h.height),h.lx=Math.round(h.lx),h.ly=Math.round(h.ly);var k={y:e.y,b:h.height*d[w],t:h.height*p[w]};\"fraction\"===e.lenmode?(k.l=0,k.xl=e.x-e.len*p[_],k.r=0,k.xr=e.x+e.len*d[_]):(k.x=e.x,k.l=h.outerLength*p[_],k.r=h.outerLength*d[_]),i.autoMargin(t,g(e),k)}function y(t,e,r){if(e.currentvalue.visible){var n,i,a=e._dims;switch(e.currentvalue.xanchor){case\"right\":n=a.inputAreaLength-u.currentValueInset-a.currentValueMaxWidth,i=\"left\";break;case\"center\":n=.5*a.inputAreaLength,i=\"middle\";break;default:n=u.currentValueInset,i=\"left\"}var c=s.ensureSingle(t,\"text\",u.labelClass,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":i,\"data-notex\":1})}),h=e.currentvalue.prefix?e.currentvalue.prefix:\"\";if(\"string\"==typeof r)h+=r;else{var p=e.steps[e.active].label,d=e._gd._fullLayout._meta;d&&(p=s.templateString(p,d)),h+=p}e.currentvalue.suffix&&(h+=e.currentvalue.suffix),c.call(o.font,e.currentvalue.font).text(h).call(l.convertToTspans,e._gd);var g=l.lineCount(c),v=(a.currentValueMaxLines+1-g)*e.currentvalue.font.size*f;return l.positionText(c,n,v),c}}function x(t,e,r){s.ensureSingle(t,\"rect\",u.gripRectClass,function(n){n.call(T,e,t,r).style(\"pointer-events\",\"all\")}).attr({width:u.gripWidth,height:u.gripHeight,rx:u.gripRadius,ry:u.gripRadius}).call(a.stroke,r.bordercolor).call(a.fill,r.bgcolor).style(\"stroke-width\",r.borderwidth+\"px\")}function b(t,e,r){var n=s.ensureSingle(t,\"text\",u.labelClass,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":\"middle\",\"data-notex\":1})}),i=e.step.label,a=r._gd._fullLayout._meta;return a&&(i=s.templateString(i,a)),n.call(o.font,r.font).text(i).call(l.convertToTspans,r._gd),n}function _(t,e){var r=s.ensureSingle(t,\"g\",u.labelsClass),i=e._dims,a=r.selectAll(\"g.\"+u.labelGroupClass).data(i.labelSteps);a.enter().append(\"g\").classed(u.labelGroupClass,!0),a.exit().remove(),a.each(function(t){var r=n.select(this);r.call(b,t,e),o.setTranslate(r,S(e,t.fraction),u.tickOffset+e.ticklen+e.font.size*f+u.labelOffset+i.currentValueTotalHeight)})}function w(t,e,r,n,i){var a=Math.round(n*(r._stepCount-1)),o=r._visibleSteps[a]._index;o!==r.active&&k(t,e,r,o,!0,i)}function k(t,e,r,n,a,o){var s=r.active;r.active=n,c(t.layout,u.name,r).applyUpdate(\"active\",n);var l=r.steps[r.active];e.call(M,r,o),e.call(y,r),t.emit(\"plotly_sliderchange\",{slider:r,step:r.steps[r.active],interaction:a,previousActive:s}),l&&l.method&&a&&(e._nextMethod?(e._nextMethod.step=l,e._nextMethod.doCallback=a,e._nextMethod.doTransition=o):(e._nextMethod={step:l,doCallback:a,doTransition:o},e._nextMethodRaf=window.requestAnimationFrame(function(){var r=e._nextMethod.step;r.method&&(r.execute&&i.executeAPICommand(t,r.method,r.args),e._nextMethod=null,e._nextMethodRaf=null)})))}function T(t,e,r){var i=r.node(),o=n.select(e);function s(){return r.data()[0]}t.on(\"mousedown\",function(){var t=s();e.emit(\"plotly_sliderstart\",{slider:t});var l=r.select(\".\"+u.gripRectClass);n.event.stopPropagation(),n.event.preventDefault(),l.call(a.fill,t.activebgcolor);var c=E(t,n.mouse(i)[0]);w(e,r,t,c,!0),t._dragging=!0,o.on(\"mousemove\",function(){var t=s(),a=E(t,n.mouse(i)[0]);w(e,r,t,a,!1)}),o.on(\"mouseup\",function(){var t=s();t._dragging=!1,l.call(a.fill,t.bgcolor),o.on(\"mouseup\",null),o.on(\"mousemove\",null),e.emit(\"plotly_sliderend\",{slider:t,step:t.steps[t.active]})})})}function A(t,e){var r=t.selectAll(\"rect.\"+u.tickRectClass).data(e._visibleSteps),i=e._dims;r.enter().append(\"rect\").classed(u.tickRectClass,!0),r.exit().remove(),r.attr({width:e.tickwidth+\"px\",\"shape-rendering\":\"crispEdges\"}),r.each(function(t,r){var s=r%i.labelStride==0,l=n.select(this);l.attr({height:s?e.ticklen:e.minorticklen}).call(a.fill,e.tickcolor),o.setTranslate(l,S(e,r/(e._stepCount-1))-.5*e.tickwidth,(s?u.tickOffset:u.minorTickOffset)+i.currentValueTotalHeight)})}function M(t,e,r){for(var n=t.select(\"rect.\"+u.gripRectClass),i=0,a=0;a<e._stepCount;a++)if(e._visibleSteps[a]._index===e.active){i=a;break}var o=S(e,i/(e._stepCount-1));if(!e._invokingCommand){var s=n;r&&e.transition.duration>0&&(s=s.transition().duration(e.transition.duration).ease(e.transition.easing)),s.attr(\"transform\",\"translate(\"+(o-.5*u.gripWidth)+\",\"+e._dims.currentValueTotalHeight+\")\")}}function S(t,e){var r=t._dims;return r.inputAreaStart+u.stepInset+(r.inputAreaLength-2*u.stepInset)*Math.min(1,Math.max(0,e))}function E(t,e){var r=t._dims;return Math.min(1,Math.max(0,(e-u.stepInset-r.inputAreaStart)/(r.inputAreaLength-2*u.stepInset-2*r.inputAreaStart)))}function C(t,e,r){var n=r._dims,i=s.ensureSingle(t,\"rect\",u.railTouchRectClass,function(n){n.call(T,e,t,r).style(\"pointer-events\",\"all\")});i.attr({width:n.inputAreaLength,height:Math.max(n.inputAreaWidth,u.tickOffset+r.ticklen+n.labelHeight)}).call(a.fill,r.bgcolor).attr(\"opacity\",0),o.setTranslate(i,0,n.currentValueTotalHeight)}function L(t,e){var r=e._dims,n=r.inputAreaLength-2*u.railInset,i=s.ensureSingle(t,\"rect\",u.railRectClass);i.attr({width:n,height:u.railWidth,rx:u.railRadius,ry:u.railRadius,\"shape-rendering\":\"crispEdges\"}).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\"),o.setTranslate(i,u.railInset,.5*(r.inputAreaWidth-u.railWidth)+r.currentValueTotalHeight)}e.exports=function(t){var e=t._fullLayout,r=function(t,e){for(var r=t[u.name],n=[],i=0;i<r.length;i++){var a=r[i];a.visible&&(a._gd=e,n.push(a))}return n}(e,t),a=e._infolayer.selectAll(\"g.\"+u.containerClassName).data(r.length>0?[0]:[]);function s(e){e._commandObserver&&(e._commandObserver.remove(),delete e._commandObserver),i.autoMargin(t,g(e))}if(a.enter().append(\"g\").classed(u.containerClassName,!0).style(\"cursor\",\"ew-resize\"),a.exit().each(function(){n.select(this).selectAll(\"g.\"+u.groupClassName).each(s)}).remove(),0!==r.length){var l=a.selectAll(\"g.\"+u.groupClassName).data(r,v);l.enter().append(\"g\").classed(u.groupClassName,!0),l.exit().each(s).remove();for(var c=0;c<r.length;c++){var h=r[c];m(t,h)}l.each(function(e){var r=n.select(this);!function(t){var e=t._dims;e.labelSteps=[];for(var r=t._stepCount,n=0;n<r;n+=e.labelStride)e.labelSteps.push({fraction:n/(r-1),step:t._visibleSteps[n]})}(e),i.manageCommandObserver(t,e,e._visibleSteps,function(e){var n=r.data()[0];n.active!==e.index&&(n._dragging||k(t,r,n,e.index,!1,!0))}),function(t,e,r){(r.steps[r.active]||{}).visible||(r.active=r._visibleSteps[0]._index);e.call(y,r).call(L,r).call(_,r).call(A,r).call(C,t,r).call(x,t,r);var n=r._dims;o.setTranslate(e,n.lx+r.pad.l,n.ly+r.pad.t),e.call(M,r,!1),e.call(y,r)}(t,n.select(this),e)})}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_template\":757,\"../../plots/plots\":828,\"../color\":593,\"../drawing\":614,\"./constants\":677,d3:163}],680:[function(t,e,r){\"use strict\";var n=t(\"./constants\");e.exports={moduleType:\"component\",name:n.name,layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":676,\"./constants\":677,\"./defaults\":678,\"./draw\":679}],681:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../drawing\"),c=t(\"../color\"),u=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/interactions\");e.exports={draw:function(t,e,r){var p,d=r.propContainer,g=r.propName,v=r.placeholder,m=r.traceIndex,y=r.avoid||{},x=r.attributes,b=r.transform,_=r.containerGroup,w=t._fullLayout,k=1,T=!1,A=d.title,M=(A&&A.text?A.text:\"\").trim(),S=A&&A.font?A.font:{},E=S.family,C=S.size,L=S.color;\"title.text\"===g?p=\"titleText\":-1!==g.indexOf(\"axis\")?p=\"axisTitleText\":g.indexOf(!0)&&(p=\"colorbarTitleText\");var P=t._context.edits[p];\"\"===M?k=0:M.replace(f,\" % \")===v.replace(f,\" % \")&&(k=.2,T=!0,P||(M=\"\"));r._meta?M=s.templateString(M,r._meta):w._meta&&(M=s.templateString(M,w._meta));var O=M||P;_||(_=s.ensureSingle(w._infolayer,\"g\",\"g-\"+e));var z=_.selectAll(\"text\").data(O?[0]:[]);if(z.enter().append(\"text\"),z.text(M).attr(\"class\",e),z.exit().remove(),!O)return _;function I(t){s.syncOrAsync([D,R],t)}function D(e){var r;return b?(r=\"\",b.rotate&&(r+=\"rotate(\"+[b.rotate,x.x,x.y]+\")\"),b.offset&&(r+=\"translate(0, \"+b.offset+\")\")):r=null,e.attr(\"transform\",r),e.style({\"font-family\":E,\"font-size\":n.round(C,2)+\"px\",fill:c.rgb(L),opacity:k*c.opacity(L),\"font-weight\":a.fontWeight}).attr(x).call(u.convertToTspans,t),a.previousPromises(t)}function R(t){var e=n.select(t.node().parentNode);if(y&&y.selection&&y.side&&M){e.attr(\"transform\",null);var r=0,a={left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}[y.side],o=-1!==[\"left\",\"top\"].indexOf(y.side)?-1:1,c=i(y.pad)?y.pad:2,u=l.bBox(e.node()),h={left:0,top:0,right:w.width,bottom:w.height},f=y.maxShift||(h[y.side]-u[y.side])*(\"left\"===y.side||\"top\"===y.side?-1:1);if(f<0)r=f;else{var p=y.offsetLeft||0,d=y.offsetTop||0;u.left-=p,u.right-=p,u.top-=d,u.bottom-=d,y.selection.each(function(){var t=l.bBox(this);s.bBoxIntersect(u,t,c)&&(r=Math.max(r,o*(t[y.side]-u[a])+c))}),r=Math.min(f,r)}if(r>0||f<0){var g={left:[-r,0],right:[r,0],top:[0,-r],bottom:[0,r]}[y.side];e.attr(\"transform\",\"translate(\"+g+\")\")}}}z.call(I),P&&(M?z.on(\".opacity\",null):(k=0,T=!0,z.text(v).on(\"mouseover.opacity\",function(){n.select(this).transition().duration(h.SHOW_PLACEHOLDER).style(\"opacity\",1)}).on(\"mouseout.opacity\",function(){n.select(this).transition().duration(h.HIDE_PLACEHOLDER).style(\"opacity\",0)})),z.call(u.makeEditable,{gd:t}).on(\"edit\",function(e){void 0!==m?o.call(\"_guiRestyle\",t,g,e,m):o.call(\"_guiRelayout\",t,g,e)}).on(\"cancel\",function(){this.text(this.attr(\"data-unformatted\")).call(I)}).on(\"input\",function(t){this.text(t||\" \").call(u.positionText,x.x,x.y)}));return z.classed(\"js-placeholder\",T),_}};var f=/ [XY][0-9]* /},{\"../../constants/interactions\":694,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../drawing\":614,d3:163,\"fast-isnumeric\":225}],682:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/pad_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=l(\"button\",{visible:{valType:\"boolean\"},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\",dflt:\"\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"updatemenu\",{_arrayAttrRegexps:[/^updatemenus\\[(0|[1-9][0-9]+)\\]\\.buttons/],visible:{valType:\"boolean\"},type:{valType:\"enumerated\",values:[\"dropdown\",\"buttons\"],dflt:\"dropdown\"},direction:{valType:\"enumerated\",values:[\"left\",\"right\",\"up\",\"down\"],dflt:\"down\"},active:{valType:\"integer\",min:-1,dflt:0},showactive:{valType:\"boolean\",dflt:!0},buttons:c,x:{valType:\"number\",min:-2,max:3,dflt:-.05},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"right\"},y:{valType:\"number\",min:-2,max:3,dflt:1},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},pad:a(s({editType:\"arraydraw\"}),{}),font:n({}),bgcolor:{valType:\"color\"},bordercolor:{valType:\"color\",dflt:i.borderLine},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"arraydraw\"}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/font_attributes\":793,\"../../plots/pad_attributes\":827,\"../color/attributes\":592}],683:[function(t,e,r){\"use strict\";e.exports={name:\"updatemenus\",containerClassName:\"updatemenu-container\",headerGroupClassName:\"updatemenu-header-group\",headerClassName:\"updatemenu-header\",headerArrowClassName:\"updatemenu-header-arrow\",dropdownButtonGroupClassName:\"updatemenu-dropdown-button-group\",dropdownButtonClassName:\"updatemenu-dropdown-button\",buttonClassName:\"updatemenu-button\",itemRectClassName:\"updatemenu-item-rect\",itemTextClassName:\"updatemenu-item-text\",menuIndexAttrName:\"updatemenu-active-index\",autoMarginIdRoot:\"updatemenu-\",blankHeaderOpts:{label:\"  \"},minWidth:30,minHeight:30,textPadX:24,arrowPadX:16,rx:2,ry:2,textOffsetX:12,textOffsetY:3,arrowOffsetX:4,gapButtonHeader:5,gapButton:2,activeColor:\"#F4FAFF\",hoverColor:\"#F4FAFF\",arrowSymbol:{left:\"\\u25c4\",right:\"\\u25ba\",up:\"\\u25b2\",down:\"\\u25bc\"}}},{}],684:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.buttons;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}o(\"visible\",i(t,e,{name:\"buttons\",handleItemDefaults:c}).length>0)&&(o(\"active\"),o(\"direction\"),o(\"type\"),o(\"showactive\"),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"bgcolor\",r.paper_bgcolor),o(\"bordercolor\"),o(\"borderwidth\"))}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}r(\"visible\",\"skip\"===t.method||Array.isArray(t.args))&&(r(\"method\"),r(\"args\"),r(\"label\"),r(\"execute\"))}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"./attributes\":682,\"./constants\":683}],685:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"../../constants/alignment\").LINE_SPACING,h=t(\"./constants\"),f=t(\"./scrollbox\");function p(t){return t._index}function d(t,e){return+t.attr(h.menuIndexAttrName)===e._index}function g(t,e,r,n,i,a,o,s){e.active=o,c(t.layout,h.name,e).applyUpdate(\"active\",o),\"buttons\"===e.type?m(t,n,null,null,e):\"dropdown\"===e.type&&(i.attr(h.menuIndexAttrName,\"-1\"),v(t,n,i,a,e),s||m(t,n,i,a,e))}function v(t,e,r,n,i){var a=s.ensureSingle(e,\"g\",h.headerClassName,function(t){t.style(\"pointer-events\",\"all\")}),l=i._dims,c=i.active,u=i.buttons[c]||h.blankHeaderOpts,f={y:i.pad.t,yPad:0,x:i.pad.l,xPad:0,index:0},p={width:l.headerWidth,height:l.headerHeight};a.call(y,i,u,t).call(M,i,f,p),s.ensureSingle(e,\"text\",h.headerArrowClassName,function(t){t.classed(\"user-select-none\",!0).attr(\"text-anchor\",\"end\").call(o.font,i.font).text(h.arrowSymbol[i.direction])}).attr({x:l.headerWidth-h.arrowOffsetX+i.pad.l,y:l.headerHeight/2+h.textOffsetY+i.pad.t}),a.on(\"click\",function(){r.call(S,String(d(r,i)?-1:i._index)),m(t,e,r,n,i)}),a.on(\"mouseover\",function(){a.call(w)}),a.on(\"mouseout\",function(){a.call(k,i)}),o.setTranslate(e,l.lx,l.ly)}function m(t,e,r,a,o){r||(r=e).attr(\"pointer-events\",\"all\");var l=function(t){return-1==+t.attr(h.menuIndexAttrName)}(r)&&\"buttons\"!==o.type?[]:o.buttons,c=\"dropdown\"===o.type?h.dropdownButtonClassName:h.buttonClassName,u=r.selectAll(\"g.\"+c).data(s.filterVisible(l)),f=u.enter().append(\"g\").classed(c,!0),p=u.exit();\"dropdown\"===o.type?(f.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\"),p.transition().attr(\"opacity\",\"0\").remove()):p.remove();var d=0,v=0,m=o._dims,x=-1!==[\"up\",\"down\"].indexOf(o.direction);\"dropdown\"===o.type&&(x?v=m.headerHeight+h.gapButtonHeader:d=m.headerWidth+h.gapButtonHeader),\"dropdown\"===o.type&&\"up\"===o.direction&&(v=-h.gapButtonHeader+h.gapButton-m.openHeight),\"dropdown\"===o.type&&\"left\"===o.direction&&(d=-h.gapButtonHeader+h.gapButton-m.openWidth);var b={x:m.lx+d+o.pad.l,y:m.ly+v+o.pad.t,yPad:h.gapButton,xPad:h.gapButton,index:0},T={l:b.x+o.borderwidth,t:b.y+o.borderwidth};u.each(function(s,l){var c=n.select(this);c.call(y,o,s,t).call(M,o,b),c.on(\"click\",function(){n.event.defaultPrevented||(g(t,o,0,e,r,a,l),s.execute&&i.executeAPICommand(t,s.method,s.args),t.emit(\"plotly_buttonclicked\",{menu:o,button:s,active:o.active}))}),c.on(\"mouseover\",function(){c.call(w)}),c.on(\"mouseout\",function(){c.call(k,o),u.call(_,o)})}),u.call(_,o),x?(T.w=Math.max(m.openWidth,m.headerWidth),T.h=b.y-T.t):(T.w=b.x-T.l,T.h=Math.max(m.openHeight,m.headerHeight)),T.direction=o.direction,a&&(u.size()?function(t,e,r,n,i,a){var o,s,l,c=i.direction,u=\"up\"===c||\"down\"===c,f=i._dims,p=i.active;if(u)for(s=0,l=0;l<p;l++)s+=f.heights[l]+h.gapButton;else for(o=0,l=0;l<p;l++)o+=f.widths[l]+h.gapButton;n.enable(a,o,s),n.hbar&&n.hbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\");n.vbar&&n.vbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\")}(0,0,0,a,o,T):function(t){var e=!!t.hbar,r=!!t.vbar;e&&t.hbar.transition().attr(\"opacity\",\"0\").each(\"end\",function(){e=!1,r||t.disable()});r&&t.vbar.transition().attr(\"opacity\",\"0\").each(\"end\",function(){r=!1,e||t.disable()})}(a))}function y(t,e,r,n){t.call(x,e).call(b,e,r,n)}function x(t,e){s.ensureSingle(t,\"rect\",h.itemRectClassName,function(t){t.attr({rx:h.rx,ry:h.ry,\"shape-rendering\":\"crispEdges\"})}).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\")}function b(t,e,r,n){var i=s.ensureSingle(t,\"text\",h.itemTextClassName,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":\"start\",\"data-notex\":1})}),a=r.label,c=n._fullLayout._meta;c&&(a=s.templateString(a,c)),i.call(o.font,e.font).text(a).call(l.convertToTspans,n)}function _(t,e){var r=e.active;t.each(function(t,i){var o=n.select(this);i===r&&e.showactive&&o.select(\"rect.\"+h.itemRectClassName).call(a.fill,h.activeColor)})}function w(t){t.select(\"rect.\"+h.itemRectClassName).call(a.fill,h.hoverColor)}function k(t,e){t.select(\"rect.\"+h.itemRectClassName).call(a.fill,e.bgcolor)}function T(t,e){var r=e._dims={width1:0,height1:0,heights:[],widths:[],totalWidth:0,totalHeight:0,openWidth:0,openHeight:0,lx:0,ly:0},a=o.tester.selectAll(\"g.\"+h.dropdownButtonClassName).data(s.filterVisible(e.buttons));a.enter().append(\"g\").classed(h.dropdownButtonClassName,!0);var c=-1!==[\"up\",\"down\"].indexOf(e.direction);a.each(function(i,a){var s=n.select(this);s.call(y,e,i,t);var f=s.select(\".\"+h.itemTextClassName),p=f.node()&&o.bBox(f.node()).width,d=Math.max(p+h.textPadX,h.minWidth),g=e.font.size*u,v=l.lineCount(f),m=Math.max(g*v,h.minHeight)+h.textOffsetY;m=Math.ceil(m),d=Math.ceil(d),r.widths[a]=d,r.heights[a]=m,r.height1=Math.max(r.height1,m),r.width1=Math.max(r.width1,d),c?(r.totalWidth=Math.max(r.totalWidth,d),r.openWidth=r.totalWidth,r.totalHeight+=m+h.gapButton,r.openHeight+=m+h.gapButton):(r.totalWidth+=d+h.gapButton,r.openWidth+=d+h.gapButton,r.totalHeight=Math.max(r.totalHeight,m),r.openHeight=r.totalHeight)}),c?r.totalHeight-=h.gapButton:r.totalWidth-=h.gapButton,r.headerWidth=r.width1+h.arrowPadX,r.headerHeight=r.height1,\"dropdown\"===e.type&&(c?(r.width1+=h.arrowPadX,r.totalHeight=r.height1):r.totalWidth=r.width1,r.totalWidth+=h.arrowPadX),a.remove();var f=r.totalWidth+e.pad.l+e.pad.r,p=r.totalHeight+e.pad.t+e.pad.b,d=t._fullLayout._size;r.lx=d.l+d.w*e.x,r.ly=d.t+d.h*(1-e.y);var g=\"left\";s.isRightAnchor(e)&&(r.lx-=f,g=\"right\"),s.isCenterAnchor(e)&&(r.lx-=f/2,g=\"center\");var v=\"top\";s.isBottomAnchor(e)&&(r.ly-=p,v=\"bottom\"),s.isMiddleAnchor(e)&&(r.ly-=p/2,v=\"middle\"),r.totalWidth=Math.ceil(r.totalWidth),r.totalHeight=Math.ceil(r.totalHeight),r.lx=Math.round(r.lx),r.ly=Math.round(r.ly),i.autoMargin(t,A(e),{x:e.x,y:e.y,l:f*({right:1,center:.5}[g]||0),r:f*({left:1,center:.5}[g]||0),b:p*({top:1,middle:.5}[v]||0),t:p*({bottom:1,middle:.5}[v]||0)})}function A(t){return h.autoMarginIdRoot+t._index}function M(t,e,r,n){n=n||{};var i=t.select(\".\"+h.itemRectClassName),a=t.select(\".\"+h.itemTextClassName),s=e.borderwidth,c=r.index,f=e._dims;o.setTranslate(t,s+r.x,s+r.y);var p=-1!==[\"up\",\"down\"].indexOf(e.direction),d=n.height||(p?f.heights[c]:f.height1);i.attr({x:0,y:0,width:n.width||(p?f.width1:f.widths[c]),height:d});var g=e.font.size*u,v=(l.lineCount(a)-1)*g/2;l.positionText(a,h.textOffsetX,d/2-v+h.textOffsetY),p?r.y+=f.heights[c]+r.yPad:r.x+=f.widths[c]+r.xPad,r.index++}function S(t,e){t.attr(h.menuIndexAttrName,e||\"-1\").selectAll(\"g.\"+h.dropdownButtonClassName).remove()}e.exports=function(t){var e=t._fullLayout,r=s.filterVisible(e[h.name]);function a(e){i.autoMargin(t,A(e))}var o=e._menulayer.selectAll(\"g.\"+h.containerClassName).data(r.length>0?[0]:[]);if(o.enter().append(\"g\").classed(h.containerClassName,!0).style(\"cursor\",\"pointer\"),o.exit().each(function(){n.select(this).selectAll(\"g.\"+h.headerGroupClassName).each(a)}).remove(),0!==r.length){var l=o.selectAll(\"g.\"+h.headerGroupClassName).data(r,p);l.enter().append(\"g\").classed(h.headerGroupClassName,!0);for(var c=s.ensureSingle(o,\"g\",h.dropdownButtonGroupClassName,function(t){t.style(\"pointer-events\",\"all\")}),u=0;u<r.length;u++){var y=r[u];T(t,y)}var x=\"updatemenus\"+e._uid,b=new f(t,c,x);l.enter().size()&&(c.node().parentNode.appendChild(c.node()),c.call(S)),l.exit().each(function(t){c.call(S),a(t)}).remove(),l.each(function(e){var r=n.select(this),a=\"dropdown\"===e.type?c:null;i.manageCommandObserver(t,e,e.buttons,function(n){g(t,e,e.buttons[n.index],r,a,b,n.index,!0)}),\"dropdown\"===e.type?(v(t,r,c,b,e),d(c,e)&&m(t,r,c,b,e)):m(t,r,null,null,e)})}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_template\":757,\"../../plots/plots\":828,\"../color\":593,\"../drawing\":614,\"./constants\":683,\"./scrollbox\":687,d3:163}],686:[function(t,e,r){arguments[4][680][0].apply(r,arguments)},{\"./attributes\":682,\"./constants\":683,\"./defaults\":684,\"./draw\":685,dup:680}],687:[function(t,e,r){\"use strict\";e.exports=s;var n=t(\"d3\"),i=t(\"../color\"),a=t(\"../drawing\"),o=t(\"../../lib\");function s(t,e,r){this.gd=t,this.container=e,this.id=r,this.position=null,this.translateX=null,this.translateY=null,this.hbar=null,this.vbar=null,this.bg=this.container.selectAll(\"rect.scrollbox-bg\").data([0]),this.bg.exit().on(\".drag\",null).on(\"wheel\",null).remove(),this.bg.enter().append(\"rect\").classed(\"scrollbox-bg\",!0).style(\"pointer-events\",\"all\").attr({opacity:0,x:0,y:0,width:0,height:0})}s.barWidth=2,s.barLength=20,s.barRadius=2,s.barPad=1,s.barColor=\"#808BA4\",s.prototype.enable=function(t,e,r){var o=this.gd._fullLayout,l=o.width,c=o.height;this.position=t;var u,h,f,p,d=this.position.l,g=this.position.w,v=this.position.t,m=this.position.h,y=this.position.direction,x=\"down\"===y,b=\"left\"===y,_=\"up\"===y,w=g,k=m;x||b||\"right\"===y||_||(this.position.direction=\"down\",x=!0),x||_?(h=(u=d)+w,x?(f=v,k=(p=Math.min(f+k,c))-f):k=(p=v+k)-(f=Math.max(p-k,0))):(p=(f=v)+k,b?w=(h=d+w)-(u=Math.max(h-w,0)):(u=d,w=(h=Math.min(u+w,l))-u)),this._box={l:u,t:f,w:w,h:k};var T=g>w,A=s.barLength+2*s.barPad,M=s.barWidth+2*s.barPad,S=d,E=v+m;E+M>c&&(E=c-M);var C=this.container.selectAll(\"rect.scrollbar-horizontal\").data(T?[0]:[]);C.exit().on(\".drag\",null).remove(),C.enter().append(\"rect\").classed(\"scrollbar-horizontal\",!0).call(i.fill,s.barColor),T?(this.hbar=C.attr({rx:s.barRadius,ry:s.barRadius,x:S,y:E,width:A,height:M}),this._hbarXMin=S+A/2,this._hbarTranslateMax=w-A):(delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax);var L=m>k,P=s.barWidth+2*s.barPad,O=s.barLength+2*s.barPad,z=d+g,I=v;z+P>l&&(z=l-P);var D=this.container.selectAll(\"rect.scrollbar-vertical\").data(L?[0]:[]);D.exit().on(\".drag\",null).remove(),D.enter().append(\"rect\").classed(\"scrollbar-vertical\",!0).call(i.fill,s.barColor),L?(this.vbar=D.attr({rx:s.barRadius,ry:s.barRadius,x:z,y:I,width:P,height:O}),this._vbarYMin=I+O/2,this._vbarTranslateMax=k-O):(delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax);var R=this.id,F=u-.5,B=L?h+P+.5:h+.5,N=f-.5,j=T?p+M+.5:p+.5,U=o._topdefs.selectAll(\"#\"+R).data(T||L?[0]:[]);if(U.exit().remove(),U.enter().append(\"clipPath\").attr(\"id\",R).append(\"rect\"),T||L?(this._clipRect=U.select(\"rect\").attr({x:Math.floor(F),y:Math.floor(N),width:Math.ceil(B)-Math.floor(F),height:Math.ceil(j)-Math.floor(N)}),this.container.call(a.setClipUrl,R,this.gd),this.bg.attr({x:d,y:v,width:g,height:m})):(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),T||L){var V=n.behavior.drag().on(\"dragstart\",function(){n.event.sourceEvent.preventDefault()}).on(\"drag\",this._onBoxDrag.bind(this));this.container.on(\"wheel\",null).on(\"wheel\",this._onBoxWheel.bind(this)).on(\".drag\",null).call(V);var q=n.behavior.drag().on(\"dragstart\",function(){n.event.sourceEvent.preventDefault(),n.event.sourceEvent.stopPropagation()}).on(\"drag\",this._onBarDrag.bind(this));T&&this.hbar.on(\".drag\",null).call(q),L&&this.vbar.on(\".drag\",null).call(q)}this.setTranslate(e,r)},s.prototype.disable=function(){(this.hbar||this.vbar)&&(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),this.hbar&&(this.hbar.on(\".drag\",null),this.hbar.remove(),delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax),this.vbar&&(this.vbar.on(\".drag\",null),this.vbar.remove(),delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax)},s.prototype._onBoxDrag=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t-=n.event.dx),this.vbar&&(e-=n.event.dy),this.setTranslate(t,e)},s.prototype._onBoxWheel=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t+=n.event.deltaY),this.vbar&&(e+=n.event.deltaY),this.setTranslate(t,e)},s.prototype._onBarDrag=function(){var t=this.translateX,e=this.translateY;if(this.hbar){var r=t+this._hbarXMin,i=r+this._hbarTranslateMax;t=(o.constrain(n.event.x,r,i)-r)/(i-r)*(this.position.w-this._box.w)}if(this.vbar){var a=e+this._vbarYMin,s=a+this._vbarTranslateMax;e=(o.constrain(n.event.y,a,s)-a)/(s-a)*(this.position.h-this._box.h)}this.setTranslate(t,e)},s.prototype.setTranslate=function(t,e){var r=this.position.w-this._box.w,n=this.position.h-this._box.h;if(t=o.constrain(t||0,0,r),e=o.constrain(e||0,0,n),this.translateX=t,this.translateY=e,this.container.call(a.setTranslate,this._box.l-this.position.l-t,this._box.t-this.position.t-e),this._clipRect&&this._clipRect.attr({x:Math.floor(this.position.l+t-.5),y:Math.floor(this.position.t+e-.5)}),this.hbar){var i=t/r;this.hbar.call(a.setTranslate,t+i*this._hbarTranslateMax,e)}if(this.vbar){var s=e/n;this.vbar.call(a.setTranslate,t,e+s*this._vbarTranslateMax)}}},{\"../../lib\":719,\"../color\":593,\"../drawing\":614,d3:163}],688:[function(t,e,r){\"use strict\";e.exports={FROM_BL:{left:0,center:.5,right:1,bottom:0,middle:.5,top:1},FROM_TL:{left:0,center:.5,right:1,bottom:1,middle:.5,top:0},FROM_BR:{left:1,center:.5,right:0,bottom:0,middle:.5,top:1},LINE_SPACING:1.3,CAP_SHIFT:.7,MID_SHIFT:.35,OPPOSITE_SIDE:{left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}}},{}],689:[function(t,e,r){\"use strict\";e.exports={INCREASING:{COLOR:\"#3D9970\",SYMBOL:\"\\u25b2\"},DECREASING:{COLOR:\"#FF4136\",SYMBOL:\"\\u25bc\"}}},{}],690:[function(t,e,r){\"use strict\";e.exports={FORMAT_LINK:\"https://github.com/d3/d3-3.x-api-reference/blob/master/Formatting.md#d3_format\",DATE_FORMAT_LINK:\"https://github.com/d3/d3-3.x-api-reference/blob/master/Time-Formatting.md#format\"}},{}],691:[function(t,e,r){\"use strict\";e.exports={COMPARISON_OPS:[\"=\",\"!=\",\"<\",\">=\",\">\",\"<=\"],COMPARISON_OPS2:[\"=\",\"<\",\">=\",\">\",\"<=\"],INTERVAL_OPS:[\"[]\",\"()\",\"[)\",\"(]\",\"][\",\")(\",\"](\",\")[\"],SET_OPS:[\"{}\",\"}{\"],CONSTRAINT_REDUCTION:{\"=\":\"=\",\"<\":\"<\",\"<=\":\"<\",\">\":\">\",\">=\":\">\",\"[]\":\"[]\",\"()\":\"[]\",\"[)\":\"[]\",\"(]\":\"[]\",\"][\":\"][\",\")(\":\"][\",\"](\":\"][\",\")[\":\"][\"}}},{}],692:[function(t,e,r){\"use strict\";e.exports={solid:[[],0],dot:[[.5,1],200],dash:[[.5,1],50],longdash:[[.5,1],10],dashdot:[[.5,.625,.875,1],50],longdashdot:[[.5,.7,.8,1],10]}},{}],693:[function(t,e,r){\"use strict\";e.exports={circle:\"\\u25cf\",\"circle-open\":\"\\u25cb\",square:\"\\u25a0\",\"square-open\":\"\\u25a1\",diamond:\"\\u25c6\",\"diamond-open\":\"\\u25c7\",cross:\"+\",x:\"\\u274c\"}},{}],694:[function(t,e,r){\"use strict\";e.exports={SHOW_PLACEHOLDER:100,HIDE_PLACEHOLDER:1e3,DESELECTDIM:.2}},{}],695:[function(t,e,r){\"use strict\";e.exports={BADNUM:void 0,FP_SAFE:Number.MAX_VALUE/1e4,ONEAVGYEAR:315576e5,ONEAVGMONTH:26298e5,ONEDAY:864e5,ONEHOUR:36e5,ONEMIN:6e4,ONESEC:1e3,EPOCHJD:2440587.5,ALMOST_EQUAL:1-1e-6,LOG_CLIP:10,MINUS_SIGN:\"\\u2212\"}},{}],696:[function(t,e,r){\"use strict\";r.xmlns=\"http://www.w3.org/2000/xmlns/\",r.svg=\"http://www.w3.org/2000/svg\",r.xlink=\"http://www.w3.org/1999/xlink\",r.svgAttrs={xmlns:r.svg,\"xmlns:xlink\":r.xlink}},{}],697:[function(t,e,r){\"use strict\";r.version=\"1.49.1\",t(\"es6-promise\").polyfill(),t(\"../build/plotcss\"),t(\"./fonts/mathjax_config\")();for(var n=t(\"./registry\"),i=r.register=n.register,a=t(\"./plot_api\"),o=Object.keys(a),s=0;s<o.length;s++){var l=o[s];\"_\"!==l.charAt(0)&&(r[l]=a[l]),i({moduleType:\"apiMethod\",name:l,fn:a[l]})}i(t(\"./traces/scatter\")),i([t(\"./components/fx\"),t(\"./components/legend\"),t(\"./components/annotations\"),t(\"./components/annotations3d\"),t(\"./components/shapes\"),t(\"./components/images\"),t(\"./components/updatemenus\"),t(\"./components/sliders\"),t(\"./components/rangeslider\"),t(\"./components/rangeselector\"),t(\"./components/grid\"),t(\"./components/errorbars\"),t(\"./components/colorscale\"),t(\"./components/colorbar\")]),i([t(\"./locale-en\"),t(\"./locale-en-us\")]),r.Icons=t(\"./fonts/ploticon\"),r.Plots=t(\"./plots/plots\"),r.Fx=t(\"./components/fx\"),r.Snapshot=t(\"./snapshot\"),r.PlotSchema=t(\"./plot_api/plot_schema\"),r.Queue=t(\"./lib/queue\"),r.d3=t(\"d3\")},{\"../build/plotcss\":1,\"./components/annotations\":584,\"./components/annotations3d\":589,\"./components/colorbar\":599,\"./components/colorscale\":605,\"./components/errorbars\":620,\"./components/fx\":632,\"./components/grid\":636,\"./components/images\":641,\"./components/legend\":649,\"./components/rangeselector\":660,\"./components/rangeslider\":667,\"./components/shapes\":675,\"./components/sliders\":680,\"./components/updatemenus\":686,\"./fonts/mathjax_config\":698,\"./fonts/ploticon\":699,\"./lib/queue\":734,\"./locale-en\":748,\"./locale-en-us\":747,\"./plot_api\":752,\"./plot_api/plot_schema\":756,\"./plots/plots\":828,\"./registry\":847,\"./snapshot\":852,\"./traces/scatter\":1123,d3:163,\"es6-promise\":218}],698:[function(t,e,r){\"use strict\";e.exports=function(){\"undefined\"!=typeof MathJax&&(\"local\"!==(window.PlotlyConfig||{}).MathJaxConfig&&(MathJax.Hub.Config({messageStyle:\"none\",skipStartupTypeset:!0,displayAlign:\"left\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]}}),MathJax.Hub.Configured()))}},{}],699:[function(t,e,r){\"use strict\";e.exports={undo:{width:857.1,height:1e3,path:\"m857 350q0-87-34-166t-91-137-137-92-166-34q-96 0-183 41t-147 114q-4 6-4 13t5 11l76 77q6 5 14 5 9-1 13-7 41-53 100-82t126-29q58 0 110 23t92 61 61 91 22 111-22 111-61 91-92 61-110 23q-55 0-105-20t-90-57l77-77q17-16 8-38-10-23-33-23h-250q-15 0-25 11t-11 25v250q0 24 22 33 22 10 39-8l72-72q60 57 137 88t159 31q87 0 166-34t137-92 91-137 34-166z\",transform:\"matrix(1 0 0 -1 0 850)\"},home:{width:928.6,height:1e3,path:\"m786 296v-267q0-15-11-26t-25-10h-214v214h-143v-214h-214q-15 0-25 10t-11 26v267q0 1 0 2t0 2l321 264 321-264q1-1 1-4z m124 39l-34-41q-5-5-12-6h-2q-7 0-12 3l-386 322-386-322q-7-4-13-4-7 2-12 7l-35 41q-4 5-3 13t6 12l401 334q18 15 42 15t43-15l136-114v109q0 8 5 13t13 5h107q8 0 13-5t5-13v-227l122-102q5-5 6-12t-4-13z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"camera-retro\":{width:1e3,height:1e3,path:\"m518 386q0 8-5 13t-13 5q-37 0-63-27t-26-63q0-8 5-13t13-5 12 5 5 13q0 23 16 38t38 16q8 0 13 5t5 13z m125-73q0-59-42-101t-101-42-101 42-42 101 42 101 101 42 101-42 42-101z m-572-320h858v71h-858v-71z m643 320q0 89-62 152t-152 62-151-62-63-152 63-151 151-63 152 63 62 151z m-571 358h214v72h-214v-72z m-72-107h858v143h-462l-36-71h-360v-72z m929 143v-714q0-30-21-51t-50-21h-858q-29 0-50 21t-21 51v714q0 30 21 51t50 21h858q29 0 50-21t21-51z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoombox:{width:1e3,height:1e3,path:\"m1000-25l-250 251c40 63 63 138 63 218 0 224-182 406-407 406-224 0-406-182-406-406s183-406 407-406c80 0 155 22 218 62l250-250 125 125z m-812 250l0 438 437 0 0-438-437 0z m62 375l313 0 0-312-313 0 0 312z\",transform:\"matrix(1 0 0 -1 0 850)\"},pan:{width:1e3,height:1e3,path:\"m1000 350l-187 188 0-125-250 0 0 250 125 0-188 187-187-187 125 0 0-250-250 0 0 125-188-188 186-187 0 125 252 0 0-250-125 0 187-188 188 188-125 0 0 250 250 0 0-126 187 188z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_plus:{width:875,height:1e3,path:\"m1 787l0-875 875 0 0 875-875 0z m687-500l-187 0 0-187-125 0 0 187-188 0 0 125 188 0 0 187 125 0 0-187 187 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_minus:{width:875,height:1e3,path:\"m0 788l0-876 875 0 0 876-875 0z m688-500l-500 0 0 125 500 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},autoscale:{width:1e3,height:1e3,path:\"m250 850l-187 0-63 0 0-62 0-188 63 0 0 188 187 0 0 62z m688 0l-188 0 0-62 188 0 0-188 62 0 0 188 0 62-62 0z m-875-938l0 188-63 0 0-188 0-62 63 0 187 0 0 62-187 0z m875 188l0-188-188 0 0-62 188 0 62 0 0 62 0 188-62 0z m-125 188l-1 0-93-94-156 156 156 156 92-93 2 0 0 250-250 0 0-2 93-92-156-156-156 156 94 92 0 2-250 0 0-250 0 0 93 93 157-156-157-156-93 94 0 0 0-250 250 0 0 0-94 93 156 157 156-157-93-93 0 0 250 0 0 250z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_basic:{width:1500,height:1e3,path:\"m375 725l0 0-375-375 375-374 0-1 1125 0 0 750-1125 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_compare:{width:1125,height:1e3,path:\"m187 786l0 2-187-188 188-187 0 0 937 0 0 373-938 0z m0-499l0 1-187-188 188-188 0 0 937 0 0 376-938-1z\",transform:\"matrix(1 0 0 -1 0 850)\"},plotlylogo:{width:1542,height:1e3,path:\"m0-10h182v-140h-182v140z m228 146h183v-286h-183v286z m225 714h182v-1000h-182v1000z m225-285h182v-715h-182v715z m225 142h183v-857h-183v857z m231-428h182v-429h-182v429z m225-291h183v-138h-183v138z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"z-axis\":{width:1e3,height:1e3,path:\"m833 5l-17 108v41l-130-65 130-66c0 0 0 38 0 39 0-1 36-14 39-25 4-15-6-22-16-30-15-12-39-16-56-20-90-22-187-23-279-23-261 0-341 34-353 59 3 60 228 110 228 110-140-8-351-35-351-116 0-120 293-142 474-142 155 0 477 22 477 142 0 50-74 79-163 96z m-374 94c-58-5-99-21-99-40 0-24 65-43 144-43 79 0 143 19 143 43 0 19-42 34-98 40v216h87l-132 135-133-135h88v-216z m167 515h-136v1c16 16 31 34 46 52l84 109v54h-230v-71h124v-1c-16-17-28-32-44-51l-89-114v-51h245v72z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"3d_rotate\":{width:1e3,height:1e3,path:\"m922 660c-5 4-9 7-14 11-359 263-580-31-580-31l-102 28 58-400c0 1 1 1 2 2 118 108 351 249 351 249s-62 27-100 42c88 83 222 183 347 122 16-8 30-17 44-27-2 1-4 2-6 4z m36-329c0 0 64 229-88 296-62 27-124 14-175-11 157-78 225-208 249-266 8-19 11-31 11-31 2 5 6 15 11 32-5-13-8-20-8-20z m-775-239c70-31 117-50 198-32-121 80-199 346-199 346l-96-15-58-12c0 0 55-226 155-287z m603 133l-317-139c0 0 4-4 19-14 7-5 24-15 24-15s-177-147-389 4c235-287 536-112 536-112l31-22 100 299-4-1z m-298-153c6-4 14-9 24-15 0 0-17 10-24 15z\",transform:\"matrix(1 0 0 -1 0 850)\"},camera:{width:1e3,height:1e3,path:\"m500 450c-83 0-150-67-150-150 0-83 67-150 150-150 83 0 150 67 150 150 0 83-67 150-150 150z m400 150h-120c-16 0-34 13-39 29l-31 93c-6 15-23 28-40 28h-340c-16 0-34-13-39-28l-31-94c-6-15-23-28-40-28h-120c-55 0-100-45-100-100v-450c0-55 45-100 100-100h800c55 0 100 45 100 100v450c0 55-45 100-100 100z m-400-550c-138 0-250 112-250 250 0 138 112 250 250 250 138 0 250-112 250-250 0-138-112-250-250-250z m365 380c-19 0-35 16-35 35 0 19 16 35 35 35 19 0 35-16 35-35 0-19-16-35-35-35z\",transform:\"matrix(1 0 0 -1 0 850)\"},movie:{width:1e3,height:1e3,path:\"m938 413l-188-125c0 37-17 71-44 94 64 38 107 107 107 187 0 121-98 219-219 219-121 0-219-98-219-219 0-61 25-117 66-156h-115c30 33 49 76 49 125 0 103-84 187-187 187s-188-84-188-187c0-57 26-107 65-141-38-22-65-62-65-109v-250c0-70 56-126 125-126h500c69 0 125 56 125 126l188-126c34 0 62 28 62 63v375c0 35-28 63-62 63z m-750 0c-69 0-125 56-125 125s56 125 125 125 125-56 125-125-56-125-125-125z m406-1c-87 0-157 70-157 157 0 86 70 156 157 156s156-70 156-156-70-157-156-157z\",transform:\"matrix(1 0 0 -1 0 850)\"},question:{width:857.1,height:1e3,path:\"m500 82v107q0 8-5 13t-13 5h-107q-8 0-13-5t-5-13v-107q0-8 5-13t13-5h107q8 0 13 5t5 13z m143 375q0 49-31 91t-77 65-95 23q-136 0-207-119-9-14 4-24l74-55q4-4 10-4 9 0 14 7 30 38 48 51 19 14 48 14 27 0 48-15t21-33q0-21-11-34t-38-25q-35-16-65-48t-29-70v-20q0-8 5-13t13-5h107q8 0 13 5t5 13q0 10 12 27t30 28q18 10 28 16t25 19 25 27 16 34 7 45z m214-107q0-117-57-215t-156-156-215-58-216 58-155 156-58 215 58 215 155 156 216 58 215-58 156-156 57-215z\",transform:\"matrix(1 0 0 -1 0 850)\"},disk:{width:857.1,height:1e3,path:\"m214-7h429v214h-429v-214z m500 0h72v500q0 8-6 21t-11 20l-157 156q-5 6-19 12t-22 5v-232q0-22-15-38t-38-16h-322q-22 0-37 16t-16 38v232h-72v-714h72v232q0 22 16 38t37 16h465q22 0 38-16t15-38v-232z m-214 518v178q0 8-5 13t-13 5h-107q-7 0-13-5t-5-13v-178q0-8 5-13t13-5h107q7 0 13 5t5 13z m357-18v-518q0-22-15-38t-38-16h-750q-23 0-38 16t-16 38v750q0 22 16 38t38 16h517q23 0 50-12t42-26l156-157q16-15 27-42t11-49z\",transform:\"matrix(1 0 0 -1 0 850)\"},lasso:{width:1031,height:1e3,path:\"m1018 538c-36 207-290 336-568 286-277-48-473-256-436-463 10-57 36-108 76-151-13-66 11-137 68-183 34-28 75-41 114-42l-55-70 0 0c-2-1-3-2-4-3-10-14-8-34 5-45 14-11 34-8 45 4 1 1 2 3 2 5l0 0 113 140c16 11 31 24 45 40 4 3 6 7 8 11 48-3 100 0 151 9 278 48 473 255 436 462z m-624-379c-80 14-149 48-197 96 42 42 109 47 156 9 33-26 47-66 41-105z m-187-74c-19 16-33 37-39 60 50-32 109-55 174-68-42-25-95-24-135 8z m360 75c-34-7-69-9-102-8 8 62-16 128-68 170-73 59-175 54-244-5-9 20-16 40-20 61-28 159 121 317 333 354s407-60 434-217c28-159-121-318-333-355z\",transform:\"matrix(1 0 0 -1 0 850)\"},selectbox:{width:1e3,height:1e3,path:\"m0 850l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-285l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},spikeline:{width:1e3,height:1e3,path:\"M512 409c0-57-46-104-103-104-57 0-104 47-104 104 0 57 47 103 104 103 57 0 103-46 103-103z m-327-39l92 0 0 92-92 0z m-185 0l92 0 0 92-92 0z m370-186l92 0 0 93-92 0z m0-184l92 0 0 92-92 0z\",transform:\"matrix(1.5 0 0 -1.5 0 850)\"},pencil:{width:1792,height:1792,path:\"M491 1536l91-91-235-235-91 91v107h128v128h107zm523-928q0-22-22-22-10 0-17 7l-542 542q-7 7-7 17 0 22 22 22 10 0 17-7l542-542q7-7 7-17zm-54-192l416 416-832 832h-416v-416zm683 96q0 53-37 90l-166 166-416-416 166-165q36-38 90-38 53 0 91 38l235 234q37 39 37 91z\",transform:\"matrix(1 0 0 1 0 1)\"},newplotlylogo:{name:\"newplotlylogo\",svg:\"<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 132 132'><defs><style>.cls-1 {fill: #119dff;} .cls-2 {fill: #25fefd;} .cls-3 {fill: #fff;}</style></defs><title>plotly-logomark</title><g id='symbol'><rect class='cls-1' width='132' height='132' rx='6' ry='6'/><circle class='cls-2' cx='78' cy='54' r='6'/><circle class='cls-2' cx='102' cy='30' r='6'/><circle class='cls-2' cx='78' cy='30' r='6'/><circle class='cls-2' cx='54' cy='30' r='6'/><circle class='cls-2' cx='30' cy='30' r='6'/><circle class='cls-2' cx='30' cy='54' r='6'/><path class='cls-3' d='M30,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,30,72Z'/><path class='cls-3' d='M78,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,78,72Z'/><path class='cls-3' d='M54,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,54,48Z'/><path class='cls-3' d='M102,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,102,48Z'/></g></svg>\"}}},{}],700:[function(t,e,r){\"use strict\";r.isLeftAnchor=function(t){return\"left\"===t.xanchor||\"auto\"===t.xanchor&&t.x<=1/3},r.isCenterAnchor=function(t){return\"center\"===t.xanchor||\"auto\"===t.xanchor&&t.x>1/3&&t.x<2/3},r.isRightAnchor=function(t){return\"right\"===t.xanchor||\"auto\"===t.xanchor&&t.x>=2/3},r.isTopAnchor=function(t){return\"top\"===t.yanchor||\"auto\"===t.yanchor&&t.y>=2/3},r.isMiddleAnchor=function(t){return\"middle\"===t.yanchor||\"auto\"===t.yanchor&&t.y>1/3&&t.y<2/3},r.isBottomAnchor=function(t){return\"bottom\"===t.yanchor||\"auto\"===t.yanchor&&t.y<=1/3}},{}],701:[function(t,e,r){\"use strict\";var n=t(\"./mod\"),i=n.mod,a=n.modHalf,o=Math.PI,s=2*o;function l(t){return Math.abs(t[1]-t[0])>s-1e-14}function c(t,e){return a(e-t,s)}function u(t,e){if(l(e))return!0;var r,n;e[0]<e[1]?(r=e[0],n=e[1]):(r=e[1],n=e[0]),(r=i(r,s))>(n=i(n,s))&&(n+=s);var a=i(t,s),o=a+s;return a>=r&&a<=n||o>=r&&o<=n}function h(t,e,r,n,i,a,c){i=i||0,a=a||0;var u,h,f,p,d,g=l([r,n]);function v(t,e){return[t*Math.cos(e)+i,a-t*Math.sin(e)]}g?(u=0,h=o,f=s):r<n?(u=r,f=n):(u=n,f=r),t<e?(p=t,d=e):(p=e,d=t);var m,y=Math.abs(f-u)<=o?0:1;function x(t,e,r){return\"A\"+[t,t]+\" \"+[0,y,r]+\" \"+v(t,e)}return g?m=null===p?\"M\"+v(d,u)+x(d,h,0)+x(d,f,0)+\"Z\":\"M\"+v(p,u)+x(p,h,0)+x(p,f,0)+\"ZM\"+v(d,u)+x(d,h,1)+x(d,f,1)+\"Z\":null===p?(m=\"M\"+v(d,u)+x(d,f,0),c&&(m+=\"L0,0Z\")):m=\"M\"+v(p,u)+\"L\"+v(d,u)+x(d,f,0)+\"L\"+v(p,f)+x(p,u,1)+\"Z\",m}e.exports={deg2rad:function(t){return t/180*o},rad2deg:function(t){return t/o*180},angleDelta:c,angleDist:function(t,e){return Math.abs(c(t,e))},isFullCircle:l,isAngleInsideSector:u,isPtInsideSector:function(t,e,r,n){return!!u(e,n)&&(r[0]<r[1]?(i=r[0],a=r[1]):(i=r[1],a=r[0]),t>=i&&t<=a);var i,a},pathArc:function(t,e,r,n,i){return h(null,t,e,r,n,i,0)},pathSector:function(t,e,r,n,i){return h(null,t,e,r,n,i,1)},pathAnnulus:function(t,e,r,n,i,a){return h(t,e,r,n,i,a,1)}}},{\"./mod\":726}],702:[function(t,e,r){\"use strict\";var n=Array.isArray,i=\"undefined\"!=typeof ArrayBuffer&&ArrayBuffer.isView?ArrayBuffer:{isView:function(){return!1}},a=\"undefined\"==typeof DataView?function(){}:DataView;function o(t){return i.isView(t)&&!(t instanceof a)}function s(t){return n(t)||o(t)}function l(t,e,r){if(s(t)){if(s(t[0])){for(var n=r,i=0;i<t.length;i++)n=e(n,t[i].length);return n}return t.length}return 0}r.isTypedArray=o,r.isArrayOrTypedArray=s,r.isArray1D=function(t){return!s(t[0])},r.ensureArray=function(t,e){return n(t)||(t=[]),t.length=e,t},r.concat=function(){var t,e,r,i,a,o,s,l,c=[],u=!0,h=0;for(r=0;r<arguments.length;r++)(o=(i=arguments[r]).length)&&(e?c.push(i):(e=i,a=o),n(i)?t=!1:(u=!1,h?t!==i.constructor&&(t=!1):t=i.constructor),h+=o);if(!h)return[];if(!c.length)return e;if(u)return e.concat.apply(e,c);if(t){for((s=new t(h)).set(e),r=0;r<c.length;r++)i=c[r],s.set(i,a),a+=i.length;return s}for(s=new Array(h),l=0;l<e.length;l++)s[l]=e[l];for(r=0;r<c.length;r++){for(i=c[r],l=0;l<i.length;l++)s[a+l]=i[l];a+=l}return s},r.maxRowLength=function(t){return l(t,Math.max,0)},r.minRowLength=function(t){return l(t,Math.min,1/0)}},{}],703:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../constants/numerical\").BADNUM,a=/^['\"%,$#\\s']+|[, ]|['\"%,$#\\s']+$/g;e.exports=function(t){return\"string\"==typeof t&&(t=t.replace(a,\"\")),n(t)?Number(t):i}},{\"../constants/numerical\":695,\"fast-isnumeric\":225}],704:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t._fullLayout;e._glcanvas&&e._glcanvas.size()&&e._glcanvas.each(function(t){t.regl&&t.regl.clear({color:!0,depth:!0})})}},{}],705:[function(t,e,r){\"use strict\";e.exports=function(t){t._responsiveChartHandler&&(window.removeEventListener(\"resize\",t._responsiveChartHandler),delete t._responsiveChartHandler)}},{}],706:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../plots/attributes\"),o=t(\"../components/colorscale/scales\"),s=t(\"../constants/interactions\").DESELECTDIM,l=t(\"./nested_property\"),c=t(\"./regex\").counter,u=t(\"./mod\").modHalf,h=t(\"./array\").isArrayOrTypedArray;function f(t,e){var n=r.valObjectMeta[e.valType];if(e.arrayOk&&h(t))return!0;if(n.validateFunction)return n.validateFunction(t,e);var i={},a=i,o={set:function(t){a=t}};return n.coerceFunction(t,o,i,e),a!==i}r.valObjectMeta={data_array:{coerceFunction:function(t,e,r){h(t)?e.set(t):void 0!==r&&e.set(r)}},enumerated:{coerceFunction:function(t,e,r,n){n.coerceNumber&&(t=+t),-1===n.values.indexOf(t)?e.set(r):e.set(t)},validateFunction:function(t,e){e.coerceNumber&&(t=+t);for(var r=e.values,n=0;n<r.length;n++){var i=String(r[n]);if(\"/\"===i.charAt(0)&&\"/\"===i.charAt(i.length-1)){if(new RegExp(i.substr(1,i.length-2)).test(t))return!0}else if(t===r[n])return!0}return!1}},boolean:{coerceFunction:function(t,e,r){!0===t||!1===t?e.set(t):e.set(r)}},number:{coerceFunction:function(t,e,r,i){!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},integer:{coerceFunction:function(t,e,r,i){t%1||!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},string:{coerceFunction:function(t,e,r,n){if(\"string\"!=typeof t){var i=\"number\"==typeof t;!0!==n.strict&&i?e.set(String(t)):e.set(r)}else n.noBlank&&!t?e.set(r):e.set(t)}},color:{coerceFunction:function(t,e,r){i(t).isValid()?e.set(t):e.set(r)}},colorlist:{coerceFunction:function(t,e,r){Array.isArray(t)&&t.length&&t.every(function(t){return i(t).isValid()})?e.set(t):e.set(r)}},colorscale:{coerceFunction:function(t,e,r){e.set(o.get(t,r))}},angle:{coerceFunction:function(t,e,r){\"auto\"===t?e.set(\"auto\"):n(t)?e.set(u(+t,360)):e.set(r)}},subplotid:{coerceFunction:function(t,e,r,n){var i=n.regex||c(r);\"string\"==typeof t&&i.test(t)?e.set(t):e.set(r)},validateFunction:function(t,e){var r=e.dflt;return t===r||\"string\"==typeof t&&!!c(r).test(t)}},flaglist:{coerceFunction:function(t,e,r,n){if(\"string\"==typeof t)if(-1===(n.extras||[]).indexOf(t)){for(var i=t.split(\"+\"),a=0;a<i.length;){var o=i[a];-1===n.flags.indexOf(o)||i.indexOf(o)<a?i.splice(a,1):a++}i.length?e.set(i.join(\"+\")):e.set(r)}else e.set(t);else e.set(r)}},any:{coerceFunction:function(t,e,r){void 0===t?e.set(r):e.set(t)}},info_array:{coerceFunction:function(t,e,n,i){function a(t,e,n){var i,a={set:function(t){i=t}};return void 0===n&&(n=e.dflt),r.valObjectMeta[e.valType].coerceFunction(t,a,n,e),i}var o=2===i.dimensions||\"1-2\"===i.dimensions&&Array.isArray(t)&&Array.isArray(t[0]);if(Array.isArray(t)){var s,l,c,u,h,f,p=i.items,d=[],g=Array.isArray(p),v=g&&o&&Array.isArray(p[0]),m=o&&g&&!v,y=g&&!m?p.length:t.length;if(n=Array.isArray(n)?n:[],o)for(s=0;s<y;s++)for(d[s]=[],c=Array.isArray(t[s])?t[s]:[],h=m?p.length:g?p[s].length:c.length,l=0;l<h;l++)u=m?p[l]:g?p[s][l]:p,void 0!==(f=a(c[l],u,(n[s]||[])[l]))&&(d[s][l]=f);else for(s=0;s<y;s++)void 0!==(f=a(t[s],g?p[s]:p,n[s]))&&(d[s]=f);e.set(d)}else e.set(n)},validateFunction:function(t,e){if(!Array.isArray(t))return!1;var r=e.items,n=Array.isArray(r),i=2===e.dimensions;if(!e.freeLength&&t.length!==r.length)return!1;for(var a=0;a<t.length;a++)if(i){if(!Array.isArray(t[a])||!e.freeLength&&t[a].length!==r[a].length)return!1;for(var o=0;o<t[a].length;o++)if(!f(t[a][o],n?r[a][o]:r))return!1}else if(!f(t[a],n?r[a]:r))return!1;return!0}}},r.coerce=function(t,e,n,i,a){var o=l(n,i).get(),s=l(t,i),c=l(e,i),u=s.get(),p=e._template;if(void 0===u&&p&&(u=l(p,i).get(),p=0),void 0===a&&(a=o.dflt),o.arrayOk&&h(u))return c.set(u),u;var d=r.valObjectMeta[o.valType].coerceFunction;d(u,c,a,o);var g=c.get();return p&&g===a&&!f(u,o)&&(d(u=l(p,i).get(),c,a,o),g=c.get()),g},r.coerce2=function(t,e,n,i,a){var o=l(t,i),s=r.coerce(t,e,n,i,a),c=o.get();return null!=c&&s},r.coerceFont=function(t,e,r){var n={};return r=r||{},n.family=t(e+\".family\",r.family),n.size=t(e+\".size\",r.size),n.color=t(e+\".color\",r.color),n},r.coerceHoverinfo=function(t,e,n){var i,o=e._module.attributes,s=o.hoverinfo?o:a,l=s.hoverinfo;if(1===n._dataLength){var c=\"all\"===l.dflt?l.flags.slice():l.dflt.split(\"+\");c.splice(c.indexOf(\"name\"),1),i=c.join(\"+\")}return r.coerce(t,e,s,\"hoverinfo\",i)},r.coerceSelectionMarkerOpacity=function(t,e){if(t.marker){var r,n,i=t.marker.opacity;if(void 0!==i)h(i)||t.selected||t.unselected||(r=i,n=s*i),e(\"selected.marker.opacity\",r),e(\"unselected.marker.opacity\",n)}},r.validate=f},{\"../components/colorscale/scales\":608,\"../constants/interactions\":694,\"../plots/attributes\":764,\"./array\":702,\"./mod\":726,\"./nested_property\":727,\"./regex\":735,\"fast-isnumeric\":225,tinycolor2:537}],707:[function(t,e,r){\"use strict\";var n,i,a=t(\"d3\"),o=t(\"fast-isnumeric\"),s=t(\"./loggers\"),l=t(\"./mod\").mod,c=t(\"../constants/numerical\"),u=c.BADNUM,h=c.ONEDAY,f=c.ONEHOUR,p=c.ONEMIN,d=c.ONESEC,g=c.EPOCHJD,v=t(\"../registry\"),m=a.time.format.utc,y=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\d)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d:?\\d\\d)?)?)?)?)?\\s*$/m,x=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\di?)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d:?\\d\\d)?)?)?)?)?\\s*$/m,b=(new Date).getFullYear()-70;function _(t){return t&&v.componentsRegistry.calendars&&\"string\"==typeof t&&\"gregorian\"!==t}function w(t,e){return String(t+Math.pow(10,e)).substr(1)}r.dateTick0=function(t,e){return _(t)?e?v.getComponentMethod(\"calendars\",\"CANONICAL_SUNDAY\")[t]:v.getComponentMethod(\"calendars\",\"CANONICAL_TICK\")[t]:e?\"2000-01-02\":\"2000-01-01\"},r.dfltRange=function(t){return _(t)?v.getComponentMethod(\"calendars\",\"DFLTRANGE\")[t]:[\"2000-01-01\",\"2001-01-01\"]},r.isJSDate=function(t){return\"object\"==typeof t&&null!==t&&\"function\"==typeof t.getTime},r.dateTime2ms=function(t,e){if(r.isJSDate(t)){var a=t.getTimezoneOffset()*p,o=(t.getUTCMinutes()-t.getMinutes())*p+(t.getUTCSeconds()-t.getSeconds())*d+(t.getUTCMilliseconds()-t.getMilliseconds());if(o){var s=3*p;a=a-s/2+l(o-a+s/2,s)}return(t=Number(t)-a)>=n&&t<=i?t:u}if(\"string\"!=typeof t&&\"number\"!=typeof t)return u;t=String(t);var c=_(e),m=t.charAt(0);!c||\"G\"!==m&&\"g\"!==m||(t=t.substr(1),e=\"\");var w=c&&\"chinese\"===e.substr(0,7),k=t.match(w?x:y);if(!k)return u;var T=k[1],A=k[3]||\"1\",M=Number(k[5]||1),S=Number(k[7]||0),E=Number(k[9]||0),C=Number(k[11]||0);if(c){if(2===T.length)return u;var L;T=Number(T);try{var P=v.getComponentMethod(\"calendars\",\"getCal\")(e);if(w){var O=\"i\"===A.charAt(A.length-1);A=parseInt(A,10),L=P.newDate(T,P.toMonthIndex(T,A,O),M)}else L=P.newDate(T,Number(A),M)}catch(t){return u}return L?(L.toJD()-g)*h+S*f+E*p+C*d:u}T=2===T.length?(Number(T)+2e3-b)%100+b:Number(T),A-=1;var z=new Date(Date.UTC(2e3,A,M,S,E));return z.setUTCFullYear(T),z.getUTCMonth()!==A?u:z.getUTCDate()!==M?u:z.getTime()+C*d},n=r.MIN_MS=r.dateTime2ms(\"-9999\"),i=r.MAX_MS=r.dateTime2ms(\"9999-12-31 23:59:59.9999\"),r.isDateTime=function(t,e){return r.dateTime2ms(t,e)!==u};var k=90*h,T=3*f,A=5*p;function M(t,e,r,n,i){if((e||r||n||i)&&(t+=\" \"+w(e,2)+\":\"+w(r,2),(n||i)&&(t+=\":\"+w(n,2),i))){for(var a=4;i%10==0;)a-=1,i/=10;t+=\".\"+w(i,a)}return t}r.ms2DateTime=function(t,e,r){if(\"number\"!=typeof t||!(t>=n&&t<=i))return u;e||(e=0);var a,o,s,c,y,x,b=Math.floor(10*l(t+.05,1)),w=Math.round(t-b/10);if(_(r)){var S=Math.floor(w/h)+g,E=Math.floor(l(t,h));try{a=v.getComponentMethod(\"calendars\",\"getCal\")(r).fromJD(S).formatDate(\"yyyy-mm-dd\")}catch(t){a=m(\"G%Y-%m-%d\")(new Date(w))}if(\"-\"===a.charAt(0))for(;a.length<11;)a=\"-0\"+a.substr(1);else for(;a.length<10;)a=\"0\"+a;o=e<k?Math.floor(E/f):0,s=e<k?Math.floor(E%f/p):0,c=e<T?Math.floor(E%p/d):0,y=e<A?E%d*10+b:0}else x=new Date(w),a=m(\"%Y-%m-%d\")(x),o=e<k?x.getUTCHours():0,s=e<k?x.getUTCMinutes():0,c=e<T?x.getUTCSeconds():0,y=e<A?10*x.getUTCMilliseconds()+b:0;return M(a,o,s,c,y)},r.ms2DateTimeLocal=function(t){if(!(t>=n+h&&t<=i-h))return u;var e=Math.floor(10*l(t+.05,1)),r=new Date(Math.round(t-e/10));return M(a.time.format(\"%Y-%m-%d\")(r),r.getHours(),r.getMinutes(),r.getSeconds(),10*r.getUTCMilliseconds()+e)},r.cleanDate=function(t,e,n){if(t===u)return e;if(r.isJSDate(t)||\"number\"==typeof t&&isFinite(t)){if(_(n))return s.error(\"JS Dates and milliseconds are incompatible with world calendars\",t),e;if(!(t=r.ms2DateTimeLocal(+t))&&void 0!==e)return e}else if(!r.isDateTime(t,n))return s.error(\"unrecognized date\",t),e;return t};var S=/%\\d?f/g;function E(t,e,r,n){t=t.replace(S,function(t){var r=Math.min(+t.charAt(1)||6,6);return(e/1e3%1+2).toFixed(r).substr(2).replace(/0+$/,\"\")||\"0\"});var i=new Date(Math.floor(e+.05));if(_(n))try{t=v.getComponentMethod(\"calendars\",\"worldCalFmt\")(t,e,n)}catch(t){return\"Invalid\"}return r(t)(i)}var C=[59,59.9,59.99,59.999,59.9999];r.formatDate=function(t,e,r,n,i,a){if(i=_(i)&&i,!e)if(\"y\"===r)e=a.year;else if(\"m\"===r)e=a.month;else{if(\"d\"!==r)return function(t,e){var r=l(t+.05,h),n=w(Math.floor(r/f),2)+\":\"+w(l(Math.floor(r/p),60),2);if(\"M\"!==e){o(e)||(e=0);var i=(100+Math.min(l(t/d,60),C[e])).toFixed(e).substr(1);e>0&&(i=i.replace(/0+$/,\"\").replace(/[\\.]$/,\"\")),n+=\":\"+i}return n}(t,r)+\"\\n\"+E(a.dayMonthYear,t,n,i);e=a.dayMonth+\"\\n\"+a.year}return E(e,t,n,i)};var L=3*h;r.incrementMonth=function(t,e,r){r=_(r)&&r;var n=l(t,h);if(t=Math.round(t-n),r)try{var i=Math.round(t/h)+g,a=v.getComponentMethod(\"calendars\",\"getCal\")(r),o=a.fromJD(i);return e%12?a.add(o,e,\"m\"):a.add(o,e/12,\"y\"),(o.toJD()-g)*h+n}catch(e){s.error(\"invalid ms \"+t+\" in calendar \"+r)}var c=new Date(t+L);return c.setUTCMonth(c.getUTCMonth()+e)+n-L},r.findExactDates=function(t,e){for(var r,n,i=0,a=0,s=0,l=0,c=_(e)&&v.getComponentMethod(\"calendars\",\"getCal\")(e),u=0;u<t.length;u++)if(n=t[u],o(n)){if(!(n%h))if(c)try{1===(r=c.fromJD(n/h+g)).day()?1===r.month()?i++:a++:s++}catch(t){}else 1===(r=new Date(n)).getUTCDate()?0===r.getUTCMonth()?i++:a++:s++}else l++;s+=a+=i;var f=t.length-l;return{exactYears:i/f,exactMonths:a/f,exactDays:s/f}}},{\"../constants/numerical\":695,\"../registry\":847,\"./loggers\":723,\"./mod\":726,d3:163,\"fast-isnumeric\":225}],708:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./loggers\");function a(t){var e=t&&t.parentNode;e&&e.removeChild(t)}function o(t,e,r){var n=\"plotly.js-style-\"+t,a=document.getElementById(n);a||((a=document.createElement(\"style\")).setAttribute(\"id\",n),a.appendChild(document.createTextNode(\"\")),document.head.appendChild(a));var o=a.sheet;o.insertRule?o.insertRule(e+\"{\"+r+\"}\",0):o.addRule?o.addRule(e,r,0):i.warn(\"addStyleRule failed\")}e.exports={getGraphDiv:function(t){var e;if(\"string\"==typeof t){if(null===(e=document.getElementById(t)))throw new Error(\"No DOM element with id '\"+t+\"' exists on the page.\");return e}if(null==t)throw new Error(\"DOM element provided is null or undefined\");return t},isPlotDiv:function(t){var e=n.select(t);return e.node()instanceof HTMLElement&&e.size()&&e.classed(\"js-plotly-plot\")},removeElement:a,addStyleRule:function(t,e){o(\"global\",t,e)},addRelatedStyleRule:o,deleteRelatedStyleRule:function(t){var e=\"plotly.js-style-\"+t,r=document.getElementById(e);r&&a(r)}}},{\"./loggers\":723,d3:163}],709:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i={init:function(t){if(t._ev instanceof n)return t;var e=new n,r=new n;return t._ev=e,t._internalEv=r,t.on=e.on.bind(e),t.once=e.once.bind(e),t.removeListener=e.removeListener.bind(e),t.removeAllListeners=e.removeAllListeners.bind(e),t._internalOn=r.on.bind(r),t._internalOnce=r.once.bind(r),t._removeInternalListener=r.removeListener.bind(r),t._removeAllInternalListeners=r.removeAllListeners.bind(r),t.emit=function(n,i){\"undefined\"!=typeof jQuery&&jQuery(t).trigger(n,i),e.emit(n,i),r.emit(n,i)},t},triggerHandler:function(t,e,r){var n,i;\"undefined\"!=typeof jQuery&&(n=jQuery(t).triggerHandler(e,r));var a=t._ev;if(!a)return n;var o,s=a._events[e];if(!s)return n;function l(t){return t.listener?(a.removeListener(e,t.listener),t.fired?void 0:(t.fired=!0,t.listener.apply(a,[r]))):t.apply(a,[r])}for(s=Array.isArray(s)?s:[s],o=0;o<s.length-1;o++)l(s[o]);return i=l(s[o]),void 0!==n?n:i},purge:function(t){return delete t._ev,delete t.on,delete t.once,delete t.removeListener,delete t.removeAllListeners,delete t.emit,delete t._ev,delete t._internalEv,delete t._internalOn,delete t._internalOnce,delete t._removeInternalListener,delete t._removeAllInternalListeners,t}};e.exports=i},{events:104}],710:[function(t,e,r){\"use strict\";var n=t(\"./is_plain_object.js\"),i=Array.isArray;function a(t,e,r,o){var s,l,c,u,h,f,p=t[0],d=t.length;if(2===d&&i(p)&&i(t[1])&&0===p.length){if(function(t,e){var r,n;for(r=0;r<t.length;r++){if(null!==(n=t[r])&&\"object\"==typeof n)return!1;void 0!==n&&(e[r]=n)}return!0}(t[1],p))return p;p.splice(0,p.length)}for(var g=1;g<d;g++)for(l in s=t[g])c=p[l],u=s[l],o&&i(u)?p[l]=u:e&&u&&(n(u)||(h=i(u)))?(h?(h=!1,f=c&&i(c)?c:[]):f=c&&n(c)?c:{},p[l]=a([f,u],e,r,o)):(\"undefined\"!=typeof u||r)&&(p[l]=u);return p}r.extendFlat=function(){return a(arguments,!1,!1,!1)},r.extendDeep=function(){return a(arguments,!0,!1,!1)},r.extendDeepAll=function(){return a(arguments,!0,!0,!1)},r.extendDeepNoArrays=function(){return a(arguments,!0,!1,!0)}},{\"./is_plain_object.js\":720}],711:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e={},r=[],n=0,i=0;i<t.length;i++){var a=t[i];1!==e[a]&&(e[a]=1,r[n++]=a)}return r}},{}],712:[function(t,e,r){\"use strict\";function n(t){return!0===t.visible}function i(t){var e=t[0].trace;return!0===e.visible&&0!==e._length}e.exports=function(t){for(var e,r=(e=t,Array.isArray(e)&&Array.isArray(e[0])&&e[0][0]&&e[0][0].trace?i:n),a=[],o=0;o<t.length;o++){var s=t[o];r(s)&&a.push(s)}return a}},{}],713:[function(t,e,r){\"use strict\";var n=t(\"country-regex\"),i=t(\"../lib\"),a=Object.keys(n),o={\"ISO-3\":i.identity,\"USA-states\":i.identity,\"country names\":function(t){for(var e=0;e<a.length;e++){var r=a[e],o=new RegExp(n[r]);if(o.test(t.trim().toLowerCase()))return r}return i.log(\"Unrecognized country name: \"+t+\".\"),!1}};e.exports={locationToFeature:function(t,e,r){if(!e||\"string\"!=typeof e)return!1;var n,a,s,l=o[t](e);if(l){if(\"USA-states\"===t)for(n=[],s=0;s<r.length;s++)(a=r[s]).properties&&a.properties.gu&&\"USA\"===a.properties.gu&&n.push(a);else n=r;for(s=0;s<n.length;s++)if((a=n[s]).id===l)return a;i.log([\"Location with id\",l,\"does not have a matching topojson feature at this resolution.\"].join(\" \"))}return!1}}},{\"../lib\":719,\"country-regex\":134}],714:[function(t,e,r){\"use strict\";var n=t(\"../constants/numerical\").BADNUM;r.calcTraceToLineCoords=function(t){for(var e=t[0].trace.connectgaps,r=[],i=[],a=0;a<t.length;a++){var o=t[a].lonlat;o[0]!==n?i.push(o):!e&&i.length>0&&(r.push(i),i=[])}return i.length>0&&r.push(i),r},r.makeLine=function(t){return 1===t.length?{type:\"LineString\",coordinates:t[0]}:{type:\"MultiLineString\",coordinates:t}},r.makePolygon=function(t){if(1===t.length)return{type:\"Polygon\",coordinates:t};for(var e=new Array(t.length),r=0;r<t.length;r++)e[r]=[t[r]];return{type:\"MultiPolygon\",coordinates:e}},r.makeBlank=function(){return{type:\"Point\",coordinates:[]}}},{\"../constants/numerical\":695}],715:[function(t,e,r){\"use strict\";var n,i,a,o=t(\"./mod\").mod;function s(t,e,r,n,i,a,o,s){var l=r-t,c=i-t,u=o-i,h=n-e,f=a-e,p=s-a,d=l*p-u*h;if(0===d)return null;var g=(c*p-u*f)/d,v=(c*h-l*f)/d;return v<0||v>1||g<0||g>1?null:{x:t+l*g,y:e+h*g}}function l(t,e,r,n,i){var a=n*t+i*e;if(a<0)return n*n+i*i;if(a>r){var o=n-t,s=i-e;return o*o+s*s}var l=n*e-i*t;return l*l/r}r.segmentsIntersect=s,r.segmentDistance=function(t,e,r,n,i,a,o,c){if(s(t,e,r,n,i,a,o,c))return 0;var u=r-t,h=n-e,f=o-i,p=c-a,d=u*u+h*h,g=f*f+p*p,v=Math.min(l(u,h,d,i-t,a-e),l(u,h,d,o-t,c-e),l(f,p,g,t-i,e-a),l(f,p,g,r-i,n-a));return Math.sqrt(v)},r.getTextLocation=function(t,e,r,s){if(t===i&&s===a||(n={},i=t,a=s),n[r])return n[r];var l=t.getPointAtLength(o(r-s/2,e)),c=t.getPointAtLength(o(r+s/2,e)),u=Math.atan((c.y-l.y)/(c.x-l.x)),h=t.getPointAtLength(o(r,e)),f={x:(4*h.x+l.x+c.x)/6,y:(4*h.y+l.y+c.y)/6,theta:u};return n[r]=f,f},r.clearLocationCache=function(){i=null},r.getVisibleSegment=function(t,e,r){var n,i,a=e.left,o=e.right,s=e.top,l=e.bottom,c=0,u=t.getTotalLength(),h=u;function f(e){var r=t.getPointAtLength(e);0===e?n=r:e===u&&(i=r);var c=r.x<a?a-r.x:r.x>o?r.x-o:0,h=r.y<s?s-r.y:r.y>l?r.y-l:0;return Math.sqrt(c*c+h*h)}for(var p=f(c);p;){if((c+=p+r)>h)return;p=f(c)}for(p=f(h);p;){if(c>(h-=p+r))return;p=f(h)}return{min:c,max:h,len:h-c,total:u,isClosed:0===c&&h===u&&Math.abs(n.x-i.x)<.1&&Math.abs(n.y-i.y)<.1}},r.findPointOnPath=function(t,e,r,n){for(var i,a,o,s=(n=n||{}).pathLength||t.getTotalLength(),l=n.tolerance||.001,c=n.iterationLimit||30,u=t.getPointAtLength(0)[r]>t.getPointAtLength(s)[r]?-1:1,h=0,f=0,p=s;h<c;){if(i=(f+p)/2,o=(a=t.getPointAtLength(i))[r]-e,Math.abs(o)<l)return a;u*o>0?p=i:f=i,h++}return a}},{\"./mod\":726}],716:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"color-normalize\"),o=t(\"../components/colorscale\"),s=t(\"../components/color/attributes\").defaultLine,l=t(\"./array\").isArrayOrTypedArray,c=a(s),u=1;function h(t,e){var r=t;return r[3]*=e,r}function f(t){if(n(t))return c;var e=a(t);return e.length?e:c}function p(t){return n(t)?t:u}e.exports={formatColor:function(t,e,r){var n,i,s,d,g,v=t.color,m=l(v),y=l(e),x=o.extractOpts(t),b=[];if(n=void 0!==x.colorscale?o.makeColorScaleFuncFromTrace(t):f,i=m?function(t,e){return void 0===t[e]?c:a(n(t[e]))}:f,s=y?function(t,e){return void 0===t[e]?u:p(t[e])}:p,m||y)for(var _=0;_<r;_++)d=i(v,_),g=s(e,_),b[_]=h(d,g);else b=h(a(v),e);return b},parseColorScale:function(t,e){void 0===e&&(e=1);var r=o.extractOpts(t);return(r.reversescale?o.flipScale(r.colorscale):r.colorscale).map(function(t){var r=t[0],n=i(t[1]).toRgb();return{index:r,rgb:[n.r,n.g,n.b,e]}})}}},{\"../components/color/attributes\":592,\"../components/colorscale\":605,\"./array\":702,\"color-normalize\":120,\"fast-isnumeric\":225,tinycolor2:537}],717:[function(t,e,r){\"use strict\";var n=t(\"./identity\");function i(t){return[t]}e.exports={keyFun:function(t){return t.key},repeat:i,descend:n,wrap:i,unwrap:function(t){return t[0]}}},{\"./identity\":718}],718:[function(t,e,r){\"use strict\";e.exports=function(t){return t}},{}],719:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../constants/numerical\"),o=a.FP_SAFE,s=a.BADNUM,l=e.exports={};l.nestedProperty=t(\"./nested_property\"),l.keyedContainer=t(\"./keyed_container\"),l.relativeAttr=t(\"./relative_attr\"),l.isPlainObject=t(\"./is_plain_object\"),l.toLogRange=t(\"./to_log_range\"),l.relinkPrivateKeys=t(\"./relink_private\");var c=t(\"./array\");l.isTypedArray=c.isTypedArray,l.isArrayOrTypedArray=c.isArrayOrTypedArray,l.isArray1D=c.isArray1D,l.ensureArray=c.ensureArray,l.concat=c.concat,l.maxRowLength=c.maxRowLength,l.minRowLength=c.minRowLength;var u=t(\"./mod\");l.mod=u.mod,l.modHalf=u.modHalf;var h=t(\"./coerce\");l.valObjectMeta=h.valObjectMeta,l.coerce=h.coerce,l.coerce2=h.coerce2,l.coerceFont=h.coerceFont,l.coerceHoverinfo=h.coerceHoverinfo,l.coerceSelectionMarkerOpacity=h.coerceSelectionMarkerOpacity,l.validate=h.validate;var f=t(\"./dates\");l.dateTime2ms=f.dateTime2ms,l.isDateTime=f.isDateTime,l.ms2DateTime=f.ms2DateTime,l.ms2DateTimeLocal=f.ms2DateTimeLocal,l.cleanDate=f.cleanDate,l.isJSDate=f.isJSDate,l.formatDate=f.formatDate,l.incrementMonth=f.incrementMonth,l.dateTick0=f.dateTick0,l.dfltRange=f.dfltRange,l.findExactDates=f.findExactDates,l.MIN_MS=f.MIN_MS,l.MAX_MS=f.MAX_MS;var p=t(\"./search\");l.findBin=p.findBin,l.sorterAsc=p.sorterAsc,l.sorterDes=p.sorterDes,l.distinctVals=p.distinctVals,l.roundUp=p.roundUp,l.sort=p.sort,l.findIndexOfMin=p.findIndexOfMin;var d=t(\"./stats\");l.aggNums=d.aggNums,l.len=d.len,l.mean=d.mean,l.median=d.median,l.midRange=d.midRange,l.variance=d.variance,l.stdev=d.stdev,l.interp=d.interp;var g=t(\"./matrix\");l.init2dArray=g.init2dArray,l.transposeRagged=g.transposeRagged,l.dot=g.dot,l.translationMatrix=g.translationMatrix,l.rotationMatrix=g.rotationMatrix,l.rotationXYMatrix=g.rotationXYMatrix,l.apply2DTransform=g.apply2DTransform,l.apply2DTransform2=g.apply2DTransform2;var v=t(\"./angles\");l.deg2rad=v.deg2rad,l.rad2deg=v.rad2deg,l.angleDelta=v.angleDelta,l.angleDist=v.angleDist,l.isFullCircle=v.isFullCircle,l.isAngleInsideSector=v.isAngleInsideSector,l.isPtInsideSector=v.isPtInsideSector,l.pathArc=v.pathArc,l.pathSector=v.pathSector,l.pathAnnulus=v.pathAnnulus;var m=t(\"./anchor_utils\");l.isLeftAnchor=m.isLeftAnchor,l.isCenterAnchor=m.isCenterAnchor,l.isRightAnchor=m.isRightAnchor,l.isTopAnchor=m.isTopAnchor,l.isMiddleAnchor=m.isMiddleAnchor,l.isBottomAnchor=m.isBottomAnchor;var y=t(\"./geometry2d\");l.segmentsIntersect=y.segmentsIntersect,l.segmentDistance=y.segmentDistance,l.getTextLocation=y.getTextLocation,l.clearLocationCache=y.clearLocationCache,l.getVisibleSegment=y.getVisibleSegment,l.findPointOnPath=y.findPointOnPath;var x=t(\"./extend\");l.extendFlat=x.extendFlat,l.extendDeep=x.extendDeep,l.extendDeepAll=x.extendDeepAll,l.extendDeepNoArrays=x.extendDeepNoArrays;var b=t(\"./loggers\");l.log=b.log,l.warn=b.warn,l.error=b.error;var _=t(\"./regex\");l.counterRegex=_.counter;var w=t(\"./throttle\");l.throttle=w.throttle,l.throttleDone=w.done,l.clearThrottle=w.clear;var k=t(\"./dom\");function T(t){var e={};for(var r in t)for(var n=t[r],i=0;i<n.length;i++)e[n[i]]=+r;return e}l.getGraphDiv=k.getGraphDiv,l.isPlotDiv=k.isPlotDiv,l.removeElement=k.removeElement,l.addStyleRule=k.addStyleRule,l.addRelatedStyleRule=k.addRelatedStyleRule,l.deleteRelatedStyleRule=k.deleteRelatedStyleRule,l.clearResponsive=t(\"./clear_responsive\"),l.makeTraceGroups=t(\"./make_trace_groups\"),l._=t(\"./localize\"),l.notifier=t(\"./notifier\"),l.filterUnique=t(\"./filter_unique\"),l.filterVisible=t(\"./filter_visible\"),l.pushUnique=t(\"./push_unique\"),l.cleanNumber=t(\"./clean_number\"),l.ensureNumber=function(t){return i(t)?(t=Number(t))<-o||t>o?s:i(t)?Number(t):s:s},l.isIndex=function(t,e){return!(void 0!==e&&t>=e)&&(i(t)&&t>=0&&t%1==0)},l.noop=t(\"./noop\"),l.identity=t(\"./identity\"),l.repeat=function(t,e){for(var r=new Array(e),n=0;n<e;n++)r[n]=t;return r},l.swapAttrs=function(t,e,r,n){r||(r=\"x\"),n||(n=\"y\");for(var i=0;i<e.length;i++){var a=e[i],o=l.nestedProperty(t,a.replace(\"?\",r)),s=l.nestedProperty(t,a.replace(\"?\",n)),c=o.get();o.set(s.get()),s.set(c)}},l.raiseToTop=function(t){t.parentNode.appendChild(t)},l.cancelTransition=function(t){return t.transition().duration(0)},l.constrain=function(t,e,r){return e>r?Math.max(r,Math.min(e,t)):Math.max(e,Math.min(r,t))},l.bBoxIntersect=function(t,e,r){return r=r||0,t.left<=e.right+r&&e.left<=t.right+r&&t.top<=e.bottom+r&&e.top<=t.bottom+r},l.simpleMap=function(t,e,r,n){for(var i=t.length,a=new Array(i),o=0;o<i;o++)a[o]=e(t[o],r,n);return a},l.randstr=function t(e,r,n,i){if(n||(n=16),void 0===r&&(r=24),r<=0)return\"0\";var a,o,s=Math.log(Math.pow(2,r))/Math.log(n),c=\"\";for(a=2;s===1/0;a*=2)s=Math.log(Math.pow(2,r/a))/Math.log(n)*a;var u=s-Math.floor(s);for(a=0;a<Math.floor(s);a++)c=Math.floor(Math.random()*n).toString(n)+c;u&&(o=Math.pow(n,u),c=Math.floor(Math.random()*o).toString(n)+c);var h=parseInt(c,n);return e&&e[c]||h!==1/0&&h>=Math.pow(2,r)?i>10?(l.warn(\"randstr failed uniqueness\"),c):t(e,r,n,(i||0)+1):c},l.OptionControl=function(t,e){t||(t={}),e||(e=\"opt\");var r={optionList:[],_newoption:function(n){n[e]=t,r[n.name]=n,r.optionList.push(n)}};return r[\"_\"+e]=t,r},l.smooth=function(t,e){if((e=Math.round(e)||0)<2)return t;var r,n,i,a,o=t.length,s=2*o,l=2*e-1,c=new Array(l),u=new Array(o);for(r=0;r<l;r++)c[r]=(1-Math.cos(Math.PI*(r+1)/e))/(2*e);for(r=0;r<o;r++){for(a=0,n=0;n<l;n++)(i=r+n+1-e)<-o?i-=s*Math.round(i/s):i>=s&&(i-=s*Math.floor(i/s)),i<0?i=-1-i:i>=o&&(i=s-1-i),a+=t[i]*c[n];u[r]=a}return u},l.syncOrAsync=function(t,e,r){var n;function i(){return l.syncOrAsync(t,e,r)}for(;t.length;)if((n=(0,t.splice(0,1)[0])(e))&&n.then)return n.then(i).then(void 0,l.promiseError);return r&&r(e)},l.stripTrailingSlash=function(t){return\"/\"===t.substr(-1)?t.substr(0,t.length-1):t},l.noneOrAll=function(t,e,r){if(t){var n,i=!1,a=!0;for(n=0;n<r.length;n++)null!=t[r[n]]?i=!0:a=!1;if(i&&!a)for(n=0;n<r.length;n++)t[r[n]]=e[r[n]]}},l.mergeArray=function(t,e,r,n){var i=\"function\"==typeof n;if(l.isArrayOrTypedArray(t))for(var a=Math.min(t.length,e.length),o=0;o<a;o++){var s=t[o];e[o][r]=i?n(s):s}},l.mergeArrayCastPositive=function(t,e,r){return l.mergeArray(t,e,r,function(t){var e=+t;return isFinite(e)&&e>0?e:0})},l.fillArray=function(t,e,r,n){if(n=n||l.identity,l.isArrayOrTypedArray(t))for(var i=0;i<e.length;i++)e[i][r]=n(t[i])},l.castOption=function(t,e,r,n){n=n||l.identity;var i=l.nestedProperty(t,r).get();return l.isArrayOrTypedArray(i)?Array.isArray(e)&&l.isArrayOrTypedArray(i[e[0]])?n(i[e[0]][e[1]]):n(i[e]):i},l.extractOption=function(t,e,r,n){if(r in t)return t[r];var i=l.nestedProperty(e,n).get();return Array.isArray(i)?void 0:i},l.tagSelected=function(t,e,r){var n,i,a=e.selectedpoints,o=e._indexToPoints;o&&(n=T(o));for(var s=0;s<a.length;s++){var c=a[s];if(l.isIndex(c)){var u=n?n[c]:c,h=r?r[u]:u;void 0!==(i=h)&&i<t.length&&(t[h].selected=1)}}},l.selIndices2selPoints=function(t){var e=t.selectedpoints,r=t._indexToPoints;if(r){for(var n=T(r),i=[],a=0;a<e.length;a++){var o=e[a];if(l.isIndex(o)){var s=n[o];l.isIndex(s)&&i.push(s)}}return i}return e},l.getTargetArray=function(t,e){var r=e.target;if(\"string\"==typeof r&&r){var n=l.nestedProperty(t,r).get();return!!Array.isArray(n)&&n}return!!Array.isArray(r)&&r},l.minExtend=function(t,e){var r={};\"object\"!=typeof e&&(e={});var n,i,a,o=Object.keys(t);for(n=0;n<o.length;n++)a=t[i=o[n]],\"_\"!==i.charAt(0)&&\"function\"!=typeof a&&(\"module\"===i?r[i]=a:Array.isArray(a)?r[i]=\"colorscale\"===i?a.slice():a.slice(0,3):r[i]=a&&\"object\"==typeof a?l.minExtend(t[i],e[i]):a);for(o=Object.keys(e),n=0;n<o.length;n++)\"object\"==typeof(a=e[i=o[n]])&&i in r&&\"object\"==typeof r[i]||(r[i]=a);return r},l.titleCase=function(t){return t.charAt(0).toUpperCase()+t.substr(1)},l.containsAny=function(t,e){for(var r=0;r<e.length;r++)if(-1!==t.indexOf(e[r]))return!0;return!1},l.isIE=function(){return\"undefined\"!=typeof window.navigator.msSaveBlob};var A=/MSIE [1-9]\\./;l.isIE9orBelow=function(){return l.isIE()&&A.test(window.navigator.userAgent)};var M=/Version\\/[\\d\\.]+.*Safari/;l.isSafari=function(){return M.test(window.navigator.userAgent)},l.isD3Selection=function(t){return t&&\"function\"==typeof t.classed},l.ensureSingle=function(t,e,r,n){var i=t.select(e+(r?\".\"+r:\"\"));if(i.size())return i;var a=t.append(e);return r&&a.classed(r,!0),n&&a.call(n),a},l.ensureSingleById=function(t,e,r,n){var i=t.select(e+\"#\"+r);if(i.size())return i;var a=t.append(e).attr(\"id\",r);return n&&a.call(n),a},l.objectFromPath=function(t,e){for(var r,n=t.split(\".\"),i=r={},a=0;a<n.length;a++){var o=n[a],s=null,l=n[a].match(/(.*)\\[([0-9]+)\\]/);l?(o=l[1],s=l[2],r=r[o]=[],a===n.length-1?r[s]=e:r[s]={},r=r[s]):(a===n.length-1?r[o]=e:r[o]={},r=r[o])}return i};var S=/^([^\\[\\.]+)\\.(.+)?/,E=/^([^\\.]+)\\[([0-9]+)\\](\\.)?(.+)?/;l.expandObjectPaths=function(t){var e,r,n,i,a,o,s;if(\"object\"==typeof t&&!Array.isArray(t))for(r in t)t.hasOwnProperty(r)&&((e=r.match(S))?(i=t[r],n=e[1],delete t[r],t[n]=l.extendDeepNoArrays(t[n]||{},l.objectFromPath(r,l.expandObjectPaths(i))[n])):(e=r.match(E))?(i=t[r],n=e[1],a=parseInt(e[2]),delete t[r],t[n]=t[n]||[],\".\"===e[3]?(s=e[4],o=t[n][a]=t[n][a]||{},l.extendDeepNoArrays(o,l.objectFromPath(s,l.expandObjectPaths(i)))):t[n][a]=l.expandObjectPaths(i)):t[r]=l.expandObjectPaths(t[r]));return t},l.numSeparate=function(t,e,r){if(r||(r=!1),\"string\"!=typeof e||0===e.length)throw new Error(\"Separator string required for formatting!\");\"number\"==typeof t&&(t=String(t));var n=/(\\d+)(\\d{3})/,i=e.charAt(0),a=e.charAt(1),o=t.split(\".\"),s=o[0],l=o.length>1?i+o[1]:\"\";if(a&&(o.length>1||s.length>4||r))for(;n.test(s);)s=s.replace(n,\"$1\"+a+\"$2\");return s+l},l.TEMPLATE_STRING_REGEX=/%{([^\\s%{}:]*)(:[^}]*)?}/g;var C=/^\\w*$/;l.templateString=function(t,e){var r={};return t.replace(l.TEMPLATE_STRING_REGEX,function(t,n){return C.test(n)?e[n]||\"\":(r[n]=r[n]||l.nestedProperty(e,n).get,r[n]()||\"\")})};var L=/^:/,P=0;l.hovertemplateString=function(t,e,r){var i=arguments,a={};return t.replace(l.TEMPLATE_STRING_REGEX,function(t,o,s){var c,u,h;for(h=3;h<i.length;h++){if((c=i[h]).hasOwnProperty(o)){u=c[o];break}if(C.test(o)||(u=a[o]||l.nestedProperty(c,o).get())&&(a[o]=u),void 0!==u)break}(void 0===u&&(P<10&&(l.warn(\"Variable '\"+o+\"' in hovertemplate could not be found!\"),u=t),10===P&&l.warn(\"Too many hovertemplate warnings - additional warnings will be suppressed\"),P++),s)?u=(r?r.numberFormat:n.format)(s.replace(L,\"\"))(u):e.hasOwnProperty(o+\"Label\")&&(u=e[o+\"Label\"]);return u})};l.subplotSort=function(t,e){for(var r=Math.min(t.length,e.length)+1,n=0,i=0,a=0;a<r;a++){var o=t.charCodeAt(a)||0,s=e.charCodeAt(a)||0,l=o>=48&&o<=57,c=s>=48&&s<=57;if(l&&(n=10*n+o-48),c&&(i=10*i+s-48),!l||!c){if(n!==i)return n-i;if(o!==s)return o-s}}return i-n};var O=2e9;l.seedPseudoRandom=function(){O=2e9},l.pseudoRandom=function(){var t=O;return O=(69069*O+1)%4294967296,Math.abs(O-t)<429496729?l.pseudoRandom():O/4294967296},l.fillText=function(t,e,r){var n=Array.isArray(r)?function(t){r.push(t)}:function(t){r.text=t},i=l.extractOption(t,e,\"htx\",\"hovertext\");if(l.isValidTextValue(i))return n(i);var a=l.extractOption(t,e,\"tx\",\"text\");return l.isValidTextValue(a)?n(a):void 0},l.isValidTextValue=function(t){return t||0===t},l.formatPercent=function(t,e){e=e||0;for(var r=(Math.round(100*t*Math.pow(10,e))*Math.pow(.1,e)).toFixed(e)+\"%\",n=0;n<e;n++)-1!==r.indexOf(\".\")&&(r=(r=r.replace(\"0%\",\"%\")).replace(\".%\",\"%\"));return r},l.isHidden=function(t){var e=window.getComputedStyle(t).display;return!e||\"none\"===e}},{\"../constants/numerical\":695,\"./anchor_utils\":700,\"./angles\":701,\"./array\":702,\"./clean_number\":703,\"./clear_responsive\":705,\"./coerce\":706,\"./dates\":707,\"./dom\":708,\"./extend\":710,\"./filter_unique\":711,\"./filter_visible\":712,\"./geometry2d\":715,\"./identity\":718,\"./is_plain_object\":720,\"./keyed_container\":721,\"./localize\":722,\"./loggers\":723,\"./make_trace_groups\":724,\"./matrix\":725,\"./mod\":726,\"./nested_property\":727,\"./noop\":728,\"./notifier\":729,\"./push_unique\":733,\"./regex\":735,\"./relative_attr\":736,\"./relink_private\":737,\"./search\":738,\"./stats\":741,\"./throttle\":744,\"./to_log_range\":745,d3:163,\"fast-isnumeric\":225}],720:[function(t,e,r){\"use strict\";e.exports=function(t){return window&&window.process&&window.process.versions?\"[object Object]\"===Object.prototype.toString.call(t):\"[object Object]\"===Object.prototype.toString.call(t)&&Object.getPrototypeOf(t)===Object.prototype}},{}],721:[function(t,e,r){\"use strict\";var n=t(\"./nested_property\"),i=/^\\w*$/;e.exports=function(t,e,r,a){var o,s,l;r=r||\"name\",a=a||\"value\";var c={};e&&e.length?(l=n(t,e),s=l.get()):s=t,e=e||\"\";var u={};if(s)for(o=0;o<s.length;o++)u[s[o][r]]=o;var h=i.test(a),f={set:function(t,e){var i=null===e?4:0;if(!s){if(!l||4===i)return;s=[],l.set(s)}var o=u[t];if(void 0===o){if(4===i)return;i|=3,o=s.length,u[t]=o}else e!==(h?s[o][a]:n(s[o],a).get())&&(i|=2);var p=s[o]=s[o]||{};return p[r]=t,h?p[a]=e:n(p,a).set(e),null!==e&&(i&=-5),c[o]=c[o]|i,f},get:function(t){if(s){var e=u[t];return void 0===e?void 0:h?s[e][a]:n(s[e],a).get()}},rename:function(t,e){var n=u[t];return void 0===n?f:(c[n]=1|c[n],u[e]=n,delete u[t],s[n][r]=e,f)},remove:function(t){var e=u[t];if(void 0===e)return f;var i=s[e];if(Object.keys(i).length>2)return c[e]=2|c[e],f.set(t,null);if(h){for(o=e;o<s.length;o++)c[o]=3|c[o];for(o=e;o<s.length;o++)u[s[o][r]]--;s.splice(e,1),delete u[t]}else n(i,a).set(null),c[e]=6|c[e];return f},constructUpdate:function(){for(var t,i,o={},l=Object.keys(c),u=0;u<l.length;u++)i=l[u],t=e+\"[\"+i+\"]\",s[i]?(1&c[i]&&(o[t+\".\"+r]=s[i][r]),2&c[i]&&(o[t+\".\"+a]=h?4&c[i]?null:s[i][a]:4&c[i]?null:n(s[i],a).get())):o[t]=null;return o}};return f}},{\"./nested_property\":727}],722:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t,e){for(var r=t._context.locale,i=0;i<2;i++){for(var a=t._context.locales,o=0;o<2;o++){var s=(a[r]||{}).dictionary;if(s){var l=s[e];if(l)return l}a=n.localeRegistry}var c=r.split(\"-\")[0];if(c===r)break;r=c}return e}},{\"../registry\":847}],723:[function(t,e,r){\"use strict\";var n=t(\"../plot_api/plot_config\").dfltConfig,i=e.exports={};function a(t,e){if(t&&t.apply)try{return void t.apply(console,e)}catch(t){}for(var r=0;r<e.length;r++)try{t(e[r])}catch(t){console.log(e[r])}}i.log=function(){if(n.logging>1){for(var t=[\"LOG:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.trace||console.log,t)}},i.warn=function(){if(n.logging>0){for(var t=[\"WARN:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.trace||console.log,t)}},i.error=function(){if(n.logging>0){for(var t=[\"ERROR:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.error,t)}}},{\"../plot_api/plot_config\":755}],724:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e,r){var i=t.selectAll(\"g.\"+r.replace(/\\s/g,\".\")).data(e,function(t){return t[0].trace.uid});i.exit().remove(),i.enter().append(\"g\").attr(\"class\",r),i.order();var a=t.classed(\"rangeplot\")?\"nodeRangePlot3\":\"node3\";return i.each(function(t){t[0][a]=n.select(this)}),i}},{d3:163}],725:[function(t,e,r){\"use strict\";r.init2dArray=function(t,e){for(var r=new Array(t),n=0;n<t;n++)r[n]=new Array(e);return r},r.transposeRagged=function(t){var e,r,n=0,i=t.length;for(e=0;e<i;e++)n=Math.max(n,t[e].length);var a=new Array(n);for(e=0;e<n;e++)for(a[e]=new Array(i),r=0;r<i;r++)a[e][r]=t[r][e];return a},r.dot=function(t,e){if(!t.length||!e.length||t.length!==e.length)return null;var n,i,a=t.length;if(t[0].length)for(n=new Array(a),i=0;i<a;i++)n[i]=r.dot(t[i],e);else if(e[0].length){var o=r.transposeRagged(e);for(n=new Array(o.length),i=0;i<o.length;i++)n[i]=r.dot(t,o[i])}else for(n=0,i=0;i<a;i++)n+=t[i]*e[i];return n},r.translationMatrix=function(t,e){return[[1,0,t],[0,1,e],[0,0,1]]},r.rotationMatrix=function(t){var e=t*Math.PI/180;return[[Math.cos(e),-Math.sin(e),0],[Math.sin(e),Math.cos(e),0],[0,0,1]]},r.rotationXYMatrix=function(t,e,n){return r.dot(r.dot(r.translationMatrix(e,n),r.rotationMatrix(t)),r.translationMatrix(-e,-n))},r.apply2DTransform=function(t){return function(){var e=arguments;3===e.length&&(e=e[0]);var n=1===arguments.length?e[0]:[e[0],e[1]];return r.dot(t,[n[0],n[1],1]).slice(0,2)}},r.apply2DTransform2=function(t){var e=r.apply2DTransform(t);return function(t){return e(t.slice(0,2)).concat(e(t.slice(2,4)))}}},{}],726:[function(t,e,r){\"use strict\";e.exports={mod:function(t,e){var r=t%e;return r<0?r+e:r},modHalf:function(t,e){return Math.abs(t)>e/2?t-Math.round(t/e)*e:t}}},{}],727:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;e.exports=function(t,e){if(n(e))e=String(e);else if(\"string\"!=typeof e||\"[-1]\"===e.substr(e.length-4))throw\"bad property string\";for(var r,a,o,l=0,c=e.split(\".\");l<c.length;){if(r=String(c[l]).match(/^([^\\[\\]]*)((\\[\\-?[0-9]*\\])+)$/)){if(r[1])c[l]=r[1];else{if(0!==l)throw\"bad property string\";c.splice(0,1)}for(a=r[2].substr(1,r[2].length-2).split(\"][\"),o=0;o<a.length;o++)l++,c.splice(l,0,Number(a[o]))}l++}return\"object\"!=typeof t?function(t,e,r){return{set:function(){throw\"bad container\"},get:function(){},astr:e,parts:r,obj:t}}(t,e,c):{set:s(t,c,e),get:function t(e,r){return function(){var n,a,o,s,l,c=e;for(s=0;s<r.length-1;s++){if(-1===(n=r[s])){for(a=!0,o=[],l=0;l<c.length;l++)o[l]=t(c[l],r.slice(s+1))(),o[l]!==o[0]&&(a=!1);return a?o[0]:o}if(\"number\"==typeof n&&!i(c))return;if(\"object\"!=typeof(c=c[n])||null===c)return}if(\"object\"==typeof c&&null!==c&&null!==(o=c[r[s]]))return o}}(t,c),astr:e,parts:c,obj:t}};var a=/(^|\\.)args\\[/;function o(t,e){return void 0===t||null===t&&!e.match(a)}function s(t,e,r){return function(n){var a,s,h=t,f=\"\",p=[[t,f]],d=o(n,r);for(s=0;s<e.length-1;s++){if(\"number\"==typeof(a=e[s])&&!i(h))throw\"array index but container is not an array\";if(-1===a){if(d=!c(h,e.slice(s+1),n,r))break;return}if(!u(h,a,e[s+1],d))break;if(\"object\"!=typeof(h=h[a])||null===h)throw\"container is not an object\";f=l(f,a),p.push([h,f])}if(d){if(s===e.length-1&&(delete h[e[s]],Array.isArray(h)&&+e[s]==h.length-1))for(;h.length&&void 0===h[h.length-1];)h.pop()}else h[e[s]]=n}}function l(t,e){var r=e;return n(e)?r=\"[\"+e+\"]\":t&&(r=\".\"+e),t+r}function c(t,e,r,n){var a,l=i(r),c=!0,h=r,f=n.replace(\"-1\",0),p=!l&&o(r,f),d=e[0];for(a=0;a<t.length;a++)f=n.replace(\"-1\",a),l&&(p=o(h=r[a%r.length],f)),p&&(c=!1),u(t,a,d,p)&&s(t[a],e,n.replace(\"-1\",a))(h);return c}function u(t,e,r,n){if(void 0===t[e]){if(n)return!1;t[e]=\"number\"==typeof r?[]:{}}return!0}},{\"./array\":702,\"fast-isnumeric\":225}],728:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],729:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=[];e.exports=function(t,e){if(-1===a.indexOf(t)){a.push(t);var r=1e3;i(e)?r=e:\"long\"===e&&(r=3e3);var o=n.select(\"body\").selectAll(\".plotly-notifier\").data([0]);o.enter().append(\"div\").classed(\"plotly-notifier\",!0),o.selectAll(\".notifier-note\").data(a).enter().append(\"div\").classed(\"notifier-note\",!0).style(\"opacity\",0).each(function(t){var e=n.select(this);e.append(\"button\").classed(\"notifier-close\",!0).html(\"&times;\").on(\"click\",function(){e.transition().call(s)});for(var i=e.append(\"p\"),a=t.split(/<br\\s*\\/?>/g),o=0;o<a.length;o++)o&&i.append(\"br\"),i.append(\"span\").text(a[o]);e.transition().duration(700).style(\"opacity\",1).transition().delay(r).call(s)})}function s(t){t.duration(700).style(\"opacity\",0).each(\"end\",function(t){var e=a.indexOf(t);-1!==e&&a.splice(e,1),n.select(this).remove()})}}},{d3:163,\"fast-isnumeric\":225}],730:[function(t,e,r){\"use strict\";var n=t(\"./setcursor\"),i=\"data-savedcursor\";e.exports=function(t,e){var r=t.attr(i);if(e){if(!r){for(var a=(t.attr(\"class\")||\"\").split(\" \"),o=0;o<a.length;o++){var s=a[o];0===s.indexOf(\"cursor-\")&&t.attr(i,s.substr(7)).classed(s,!1)}t.attr(i)||t.attr(i,\"!!\")}n(t,e)}else r&&(t.attr(i,null),\"!!\"===r?n(t):n(t,r))}},{\"./setcursor\":739}],731:[function(t,e,r){\"use strict\";var n=t(\"./matrix\").dot,i=t(\"../constants/numerical\").BADNUM,a=e.exports={};a.tester=function(t){var e,r=t.slice(),n=r[0][0],a=n,o=r[0][1],s=o;for(r.push(r[0]),e=1;e<r.length;e++)n=Math.min(n,r[e][0]),a=Math.max(a,r[e][0]),o=Math.min(o,r[e][1]),s=Math.max(s,r[e][1]);var l,c=!1;5===r.length&&(r[0][0]===r[1][0]?r[2][0]===r[3][0]&&r[0][1]===r[3][1]&&r[1][1]===r[2][1]&&(c=!0,l=function(t){return t[0]===r[0][0]}):r[0][1]===r[1][1]&&r[2][1]===r[3][1]&&r[0][0]===r[3][0]&&r[1][0]===r[2][0]&&(c=!0,l=function(t){return t[1]===r[0][1]}));var u=!0,h=r[0];for(e=1;e<r.length;e++)if(h[0]!==r[e][0]||h[1]!==r[e][1]){u=!1;break}return{xmin:n,xmax:a,ymin:o,ymax:s,pts:r,contains:c?function(t,e){var r=t[0],c=t[1];return!(r===i||r<n||r>a||c===i||c<o||c>s||e&&l(t))}:function(t,e){var l=t[0],c=t[1];if(l===i||l<n||l>a||c===i||c<o||c>s)return!1;var u,h,f,p,d,g=r.length,v=r[0][0],m=r[0][1],y=0;for(u=1;u<g;u++)if(h=v,f=m,v=r[u][0],m=r[u][1],!(l<(p=Math.min(h,v))||l>Math.max(h,v)||c>Math.max(f,m)))if(c<Math.min(f,m))l!==p&&y++;else{if(c===(d=v===h?c:f+(l-h)*(m-f)/(v-h)))return 1!==u||!e;c<=d&&l!==p&&y++}return y%2==1},isRect:c,degenerate:u}},a.isSegmentBent=function(t,e,r,i){var a,o,s,l=t[e],c=[t[r][0]-l[0],t[r][1]-l[1]],u=n(c,c),h=Math.sqrt(u),f=[-c[1]/h,c[0]/h];for(a=e+1;a<r;a++)if(o=[t[a][0]-l[0],t[a][1]-l[1]],(s=n(o,c))<0||s>u||Math.abs(n(o,f))>i)return!0;return!1},a.filter=function(t,e){var r=[t[0]],n=0,i=0;function o(o){t.push(o);var s=r.length,l=n;r.splice(i+1);for(var c=l+1;c<t.length;c++)(c===t.length-1||a.isSegmentBent(t,l,c+1,e))&&(r.push(t[c]),r.length<s-2&&(n=c,i=r.length-1),l=c)}t.length>1&&o(t.pop());return{addPt:o,raw:t,filtered:r}}},{\"../constants/numerical\":695,\"./matrix\":725}],732:[function(t,e,r){(function(r){\"use strict\";var n=t(\"./show_no_webgl_msg\"),i=t(\"regl\");e.exports=function(t,e){var a=t._fullLayout,o=!0;return a._glcanvas.each(function(n){if(!n.regl&&(!n.pick||a._has(\"parcoords\"))){try{n.regl=i({canvas:this,attributes:{antialias:!n.pick,preserveDrawingBuffer:!0},pixelRatio:t._context.plotGlPixelRatio||r.devicePixelRatio,extensions:e||[]})}catch(t){o=!1}o&&this.addEventListener(\"webglcontextlost\",function(e){t&&t.emit&&t.emit(\"plotly_webglcontextlost\",{event:e,layer:n.key})},!1)}}),o||n({container:a._glcontainer.node()}),o}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./show_no_webgl_msg\":740,regl:502}],733:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(e instanceof RegExp){for(var r=e.toString(),n=0;n<t.length;n++)if(t[n]instanceof RegExp&&t[n].toString()===r)return t;t.push(e)}else!e&&0!==e||-1!==t.indexOf(e)||t.push(e);return t}},{}],734:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_config\").dfltConfig;var a={add:function(t,e,r,n,a){var o,s;t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},s=t.undoQueue.index,t.autoplay?t.undoQueue.inSequence||(t.autoplay=!1):(!t.undoQueue.sequence||t.undoQueue.beginSequence?(o={undo:{calls:[],args:[]},redo:{calls:[],args:[]}},t.undoQueue.queue.splice(s,t.undoQueue.queue.length-s,o),t.undoQueue.index+=1):o=t.undoQueue.queue[s-1],t.undoQueue.beginSequence=!1,o&&(o.undo.calls.unshift(e),o.undo.args.unshift(r),o.redo.calls.push(n),o.redo.args.push(a)),t.undoQueue.queue.length>i.queueLength&&(t.undoQueue.queue.shift(),t.undoQueue.index--))},startSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!0,t.undoQueue.beginSequence=!0},stopSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!1,t.undoQueue.beginSequence=!1},undo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.undo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index<=0)){for(t.undoQueue.index--,e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.undo.calls.length;r++)a.plotDo(t,e.undo.calls[r],e.undo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1}},redo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.redo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index>=t.undoQueue.queue.length)){for(e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.redo.calls.length;r++)a.plotDo(t,e.redo.calls[r],e.redo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1,t.undoQueue.index++}}};a.plotDo=function(t,e,r){t.autoplay=!0,r=function(t,e){for(var r,i=[],a=0;a<e.length;a++)r=e[a],i[a]=r===t?r:\"object\"==typeof r?Array.isArray(r)?n.extendDeep([],r):n.extendDeepAll({},r):r;return i}(t,r),e.apply(null,r)},e.exports=a},{\"../lib\":719,\"../plot_api/plot_config\":755}],735:[function(t,e,r){\"use strict\";r.counter=function(t,e,r,n){var i=(e||\"\")+(r?\"\":\"$\"),a=!1===n?\"\":\"^\";return\"xy\"===t?new RegExp(a+\"x([2-9]|[1-9][0-9]+)?y([2-9]|[1-9][0-9]+)?\"+i):new RegExp(a+t+\"([2-9]|[1-9][0-9]+)?\"+i)}},{}],736:[function(t,e,r){\"use strict\";var n=/^(.*)(\\.[^\\.\\[\\]]+|\\[\\d\\])$/,i=/^[^\\.\\[\\]]+$/;e.exports=function(t,e){for(;e;){var r=t.match(n);if(r)t=r[1];else{if(!t.match(i))throw new Error(\"bad relativeAttr call:\"+[t,e]);t=\"\"}if(\"^\"!==e.charAt(0))break;e=e.slice(1)}return t&&\"[\"!==e.charAt(0)?t+\".\"+e:t+e}},{}],737:[function(t,e,r){\"use strict\";var n=t(\"./array\").isArrayOrTypedArray,i=t(\"./is_plain_object\");e.exports=function t(e,r){for(var a in r){var o=r[a],s=e[a];if(s!==o)if(\"_\"===a.charAt(0)||\"function\"==typeof o){if(a in e)continue;e[a]=o}else if(n(o)&&n(s)&&i(o[0])){if(\"customdata\"===a||\"ids\"===a)continue;for(var l=Math.min(o.length,s.length),c=0;c<l;c++)s[c]!==o[c]&&i(o[c])&&i(s[c])&&t(s[c],o[c])}else i(o)&&i(s)&&(t(s,o),Object.keys(s).length||delete e[a])}}},{\"./array\":702,\"./is_plain_object\":720}],738:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./loggers\"),a=t(\"./identity\");function o(t,e){return t<e}function s(t,e){return t<=e}function l(t,e){return t>e}function c(t,e){return t>=e}r.findBin=function(t,e,r){if(n(e.start))return r?Math.ceil((t-e.start)/e.size-1e-9)-1:Math.floor((t-e.start)/e.size+1e-9);var a,u,h=0,f=e.length,p=0,d=f>1?(e[f-1]-e[0])/(f-1):1;for(u=d>=0?r?o:s:r?c:l,t+=1e-9*d*(r?-1:1)*(d>=0?1:-1);h<f&&p++<100;)u(e[a=Math.floor((h+f)/2)],t)?h=a+1:f=a;return p>90&&i.log(\"Long binary search...\"),h-1},r.sorterAsc=function(t,e){return t-e},r.sorterDes=function(t,e){return e-t},r.distinctVals=function(t){var e=t.slice();e.sort(r.sorterAsc);for(var n=e.length-1,i=e[n]-e[0]||1,a=i/(n||1)/1e4,o=[e[0]],s=0;s<n;s++)e[s+1]>e[s]+a&&(i=Math.min(i,e[s+1]-e[s]),o.push(e[s+1]));return{vals:o,minDiff:i}},r.roundUp=function(t,e,r){for(var n,i=0,a=e.length-1,o=0,s=r?0:1,l=r?1:0,c=r?Math.ceil:Math.floor;i<a&&o++<100;)e[n=c((i+a)/2)]<=t?i=n+s:a=n-l;return e[i]},r.sort=function(t,e){for(var r=0,n=0,i=1;i<t.length;i++){var a=e(t[i],t[i-1]);if(a<0?r=1:a>0&&(n=1),r&&n)return t.sort(e)}return n?t:t.reverse()},r.findIndexOfMin=function(t,e){e=e||a;for(var r,n=1/0,i=0;i<t.length;i++){var o=e(t[i]);o<n&&(n=o,r=i)}return r}},{\"./identity\":718,\"./loggers\":723,\"fast-isnumeric\":225}],739:[function(t,e,r){\"use strict\";e.exports=function(t,e){(t.attr(\"class\")||\"\").split(\" \").forEach(function(e){0===e.indexOf(\"cursor-\")&&t.classed(e,!1)}),e&&t.classed(\"cursor-\"+e,!0)}},{}],740:[function(t,e,r){\"use strict\";var n=t(\"../components/color\"),i=function(){};e.exports=function(t){for(var e in t)\"function\"==typeof t[e]&&(t[e]=i);t.destroy=function(){t.container.parentNode.removeChild(t.container)};var r=document.createElement(\"div\");r.className=\"no-webgl\",r.style.cursor=\"pointer\",r.style.fontSize=\"24px\",r.style.color=n.defaults[0],r.style.position=\"absolute\",r.style.left=r.style.top=\"0px\",r.style.width=r.style.height=\"100%\",r.style[\"background-color\"]=n.lightLine,r.style[\"z-index\"]=30;var a=document.createElement(\"p\");return a.textContent=\"WebGL is not supported by your browser - visit https://get.webgl.org for more info\",a.style.position=\"relative\",a.style.top=\"50%\",a.style.left=\"50%\",a.style.height=\"30%\",a.style.width=\"50%\",a.style.margin=\"-15% 0 0 -25%\",r.appendChild(a),t.container.appendChild(r),t.container.style.background=\"#FFFFFF\",t.container.onclick=function(){window.open(\"https://get.webgl.org\")},!1}},{\"../components/color\":593}],741:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;r.aggNums=function(t,e,a,o){var s,l;if((!o||o>a.length)&&(o=a.length),n(e)||(e=!1),i(a[0])){for(l=new Array(o),s=0;s<o;s++)l[s]=r.aggNums(t,e,a[s]);a=l}for(s=0;s<o;s++)n(e)?n(a[s])&&(e=t(+e,+a[s])):e=a[s];return e},r.len=function(t){return r.aggNums(function(t){return t+1},0,t)},r.mean=function(t,e){return e||(e=r.len(t)),r.aggNums(function(t,e){return t+e},0,t)/e},r.midRange=function(t){if(void 0!==t&&0!==t.length)return(r.aggNums(Math.max,null,t)+r.aggNums(Math.min,null,t))/2},r.variance=function(t,e,i){return e||(e=r.len(t)),n(i)||(i=r.mean(t,e)),r.aggNums(function(t,e){return t+Math.pow(e-i,2)},0,t)/e},r.stdev=function(t,e,n){return Math.sqrt(r.variance(t,e,n))},r.median=function(t){var e=t.slice().sort();return r.interp(e,.5)},r.interp=function(t,e){if(!n(e))throw\"n should be a finite number\";if((e=e*t.length-.5)<0)return t[0];if(e>t.length-1)return t[t.length-1];var r=e%1;return r*t[Math.ceil(e)]+(1-r)*t[Math.floor(e)]}},{\"./array\":702,\"fast-isnumeric\":225}],742:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\");e.exports=function(t){return t?n(t):[0,0,0,1]}},{\"color-normalize\":120}],743:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=t(\"../constants/xmlns_namespaces\"),o=t(\"../constants/alignment\").LINE_SPACING;function s(t,e){return t.node().getBoundingClientRect()[e]}var l=/([^$]*)([$]+[^$]*[$]+)([^$]*)/;r.convertToTspans=function(t,e,M){var S=t.text(),C=!t.attr(\"data-notex\")&&\"undefined\"!=typeof MathJax&&S.match(l),L=n.select(t.node().parentNode);if(!L.empty()){var P=t.attr(\"class\")?t.attr(\"class\").split(\" \")[0]:\"text\";return P+=\"-math\",L.selectAll(\"svg.\"+P).remove(),L.selectAll(\"g.\"+P+\"-group\").remove(),t.style(\"display\",null).attr({\"data-unformatted\":S,\"data-math\":\"N\"}),C?(e&&e._promises||[]).push(new Promise(function(e){t.style(\"display\",\"none\");var r=parseInt(t.node().style.fontSize,10),a={fontSize:r};!function(t,e,r){var a,o,s,l;MathJax.Hub.Queue(function(){return o=i.extendDeepAll({},MathJax.Hub.config),s=MathJax.Hub.processSectionDelay,void 0!==MathJax.Hub.processSectionDelay&&(MathJax.Hub.processSectionDelay=0),MathJax.Hub.Config({messageStyle:\"none\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]},displayAlign:\"left\"})},function(){if(\"SVG\"!==(a=MathJax.Hub.config.menuSettings.renderer))return MathJax.Hub.setRenderer(\"SVG\")},function(){var r=\"math-output-\"+i.randstr({},64);return l=n.select(\"body\").append(\"div\").attr({id:r}).style({visibility:\"hidden\",position:\"absolute\"}).style({\"font-size\":e.fontSize+\"px\"}).text(t.replace(c,\"\\\\lt \").replace(u,\"\\\\gt \")),MathJax.Hub.Typeset(l.node())},function(){var e=n.select(\"body\").select(\"#MathJax_SVG_glyphs\");if(l.select(\".MathJax_SVG\").empty()||!l.select(\"svg\").node())i.log(\"There was an error in the tex syntax.\",t),r();else{var o=l.select(\"svg\").node().getBoundingClientRect();r(l.select(\".MathJax_SVG\"),e,o)}if(l.remove(),\"SVG\"!==a)return MathJax.Hub.setRenderer(a)},function(){return void 0!==s&&(MathJax.Hub.processSectionDelay=s),MathJax.Hub.Config(o)})}(C[2],a,function(n,i,a){L.selectAll(\"svg.\"+P).remove(),L.selectAll(\"g.\"+P+\"-group\").remove();var o=n&&n.select(\"svg\");if(!o||!o.node())return O(),void e();var l=L.append(\"g\").classed(P+\"-group\",!0).attr({\"pointer-events\":\"none\",\"data-unformatted\":S,\"data-math\":\"Y\"});l.node().appendChild(o.node()),i&&i.node()&&o.node().insertBefore(i.node().cloneNode(!0),o.node().firstChild),o.attr({class:P,height:a.height,preserveAspectRatio:\"xMinYMin meet\"}).style({overflow:\"visible\",\"pointer-events\":\"none\"});var c=t.node().style.fill||\"black\",u=o.select(\"g\");u.attr({fill:c,stroke:c});var h=s(u,\"width\"),f=s(u,\"height\"),p=+t.attr(\"x\")-h*{start:0,middle:.5,end:1}[t.attr(\"text-anchor\")||\"start\"],d=-(r||s(t,\"height\"))/4;\"y\"===P[0]?(l.attr({transform:\"rotate(\"+[-90,+t.attr(\"x\"),+t.attr(\"y\")]+\") translate(\"+[-h/2,d-f/2]+\")\"}),o.attr({x:+t.attr(\"x\"),y:+t.attr(\"y\")})):\"l\"===P[0]?o.attr({x:t.attr(\"x\"),y:d-f/2}):\"a\"===P[0]&&0!==P.indexOf(\"atitle\")?o.attr({x:0,y:d}):o.attr({x:p,y:+t.attr(\"y\")+d-f/2}),M&&M.call(t,l),e(l)})})):O(),t}function O(){L.empty()||(P=t.attr(\"class\")+\"-math\",L.select(\"svg.\"+P).remove()),t.text(\"\").style(\"white-space\",\"pre\"),function(t,e){e=e.replace(v,\" \");var r,s=!1,l=[],c=-1;function u(){c++;var e=document.createElementNS(a.svg,\"tspan\");n.select(e).attr({class:\"line\",dy:c*o+\"em\"}),t.appendChild(e),r=e;var i=l;if(l=[{node:e}],i.length>1)for(var s=1;s<i.length;s++)M(i[s])}function M(t){var e,i=t.type,o={};if(\"a\"===i){e=\"a\";var s=t.target,c=t.href,u=t.popup;c&&(o={\"xlink:xlink:show\":\"_blank\"===s||\"_\"!==s.charAt(0)?\"new\":\"replace\",target:s,\"xlink:xlink:href\":c},u&&(o.onclick='window.open(this.href.baseVal,this.target.baseVal,\"'+u+'\");return false;'))}else e=\"tspan\";t.style&&(o.style=t.style);var h=document.createElementNS(a.svg,e);if(\"sup\"===i||\"sub\"===i){S(r,d),r.appendChild(h);var g=document.createElementNS(a.svg,\"tspan\");S(g,d),n.select(g).attr(\"dy\",p[i]),o.dy=f[i],r.appendChild(h),r.appendChild(g)}else r.appendChild(h);n.select(h).attr(o),r=t.node=h,l.push(t)}function S(t,e){t.appendChild(document.createTextNode(e))}function C(t){if(1!==l.length){var n=l.pop();t!==n.type&&i.log(\"Start tag <\"+n.type+\"> doesnt match end tag <\"+t+\">. Pretending it did match.\",e),r=l[l.length-1].node}else i.log(\"Ignoring unexpected end tag </\"+t+\">.\",e)}x.test(e)?u():(r=t,l=[{node:t}]);for(var L=e.split(m),P=0;P<L.length;P++){var O=L[P],z=O.match(y),I=z&&z[2].toLowerCase(),D=h[I];if(\"br\"===I)u();else if(void 0===D)S(r,E(O));else if(z[1])C(I);else{var R=z[4],F={type:I},B=T(R,b);if(B?(B=B.replace(A,\"$1 fill:\"),D&&(B+=\";\"+D)):D&&(B=D),B&&(F.style=B),\"a\"===I){s=!0;var N=T(R,_);if(N){var j=document.createElement(\"a\");j.href=N,-1!==g.indexOf(j.protocol)&&(F.href=encodeURI(decodeURI(N)),F.target=T(R,w)||\"_blank\",F.popup=T(R,k))}}M(F)}}return s}(t.node(),S)&&t.style(\"pointer-events\",\"all\"),r.positionText(t),M&&M.call(t)}};var c=/(<|&lt;|&#60;)/g,u=/(>|&gt;|&#62;)/g;var h={sup:\"font-size:70%\",sub:\"font-size:70%\",b:\"font-weight:bold\",i:\"font-style:italic\",a:\"cursor:pointer\",span:\"\",em:\"font-style:italic;font-weight:bold\"},f={sub:\"0.3em\",sup:\"-0.6em\"},p={sub:\"-0.21em\",sup:\"0.42em\"},d=\"\\u200b\",g=[\"http:\",\"https:\",\"mailto:\",\"\",void 0,\":\"],v=/(\\r\\n?|\\n)/g,m=/(<[^<>]*>)/,y=/<(\\/?)([^ >]*)(\\s+(.*))?>/i,x=/<br(\\s+.*)?>/i,b=/(^|[\\s\"'])style\\s*=\\s*(\"([^\"]*);?\"|'([^']*);?')/i,_=/(^|[\\s\"'])href\\s*=\\s*(\"([^\"]*)\"|'([^']*)')/i,w=/(^|[\\s\"'])target\\s*=\\s*(\"([^\"\\s]*)\"|'([^'\\s]*)')/i,k=/(^|[\\s\"'])popup\\s*=\\s*(\"([\\w=,]*)\"|'([\\w=,]*)')/i;function T(t,e){if(!t)return null;var r=t.match(e),n=r&&(r[3]||r[4]);return n&&E(n)}var A=/(^|;)\\s*color:/;r.plainText=function(t,e){for(var r=void 0!==(e=e||{}).len&&-1!==e.len?e.len:1/0,n=void 0!==e.allowedTags?e.allowedTags:[\"br\"],i=\"...\".length,a=t.split(m),o=[],s=\"\",l=0,c=0;c<a.length;c++){var u=a[c],h=u.match(y),f=h&&h[2].toLowerCase();if(f)-1!==n.indexOf(f)&&(o.push(u),s=f);else{var p=u.length;if(l+p<r)o.push(u),l+=p;else if(l<r){var d=r-l;s&&(\"br\"!==s||d<=i||p<=i)&&o.pop(),r>i?o.push(u.substr(0,d-i)+\"...\"):o.push(u.substr(0,d));break}s=\"\"}}return o.join(\"\")};var M={mu:\"\\u03bc\",amp:\"&\",lt:\"<\",gt:\">\",nbsp:\"\\xa0\",times:\"\\xd7\",plusmn:\"\\xb1\",deg:\"\\xb0\"},S=/&(#\\d+|#x[\\da-fA-F]+|[a-z]+);/g;function E(t){return t.replace(S,function(t,e){return(\"#\"===e.charAt(0)?function(t){if(t>1114111)return;var e=String.fromCodePoint;if(e)return e(t);var r=String.fromCharCode;return t<=65535?r(t):r(55232+(t>>10),t%1024+56320)}(\"x\"===e.charAt(1)?parseInt(e.substr(2),16):parseInt(e.substr(1),10)):M[e])||t})}function C(t,e,r){var n,i,a,o=r.horizontalAlign,s=r.verticalAlign||\"top\",l=t.node().getBoundingClientRect(),c=e.node().getBoundingClientRect();return i=\"bottom\"===s?function(){return l.bottom-n.height}:\"middle\"===s?function(){return l.top+(l.height-n.height)/2}:function(){return l.top},a=\"right\"===o?function(){return l.right-n.width}:\"center\"===o?function(){return l.left+(l.width-n.width)/2}:function(){return l.left},function(){return n=this.node().getBoundingClientRect(),this.style({top:i()-c.top+\"px\",left:a()-c.left+\"px\",\"z-index\":1e3}),this}}r.convertEntities=E,r.lineCount=function(t){return t.selectAll(\"tspan.line\").size()||1},r.positionText=function(t,e,r){return t.each(function(){var t=n.select(this);function i(e,r){return void 0===r?null===(r=t.attr(e))&&(t.attr(e,0),r=0):t.attr(e,r),r}var a=i(\"x\",e),o=i(\"y\",r);\"text\"===this.nodeName&&t.selectAll(\"tspan.line\").attr({x:a,y:o})})},r.makeEditable=function(t,e){var r=e.gd,i=e.delegate,a=n.dispatch(\"edit\",\"input\",\"cancel\"),o=i||t;if(t.style({\"pointer-events\":i?\"none\":\"all\"}),1!==t.size())throw new Error(\"boo\");function s(){!function(){var i=n.select(r).select(\".svg-container\"),o=i.append(\"div\"),s=t.node().style,c=parseFloat(s.fontSize||12),u=e.text;void 0===u&&(u=t.attr(\"data-unformatted\"));o.classed(\"plugin-editable editable\",!0).style({position:\"absolute\",\"font-family\":s.fontFamily||\"Arial\",\"font-size\":c,color:e.fill||s.fill||\"black\",opacity:1,\"background-color\":e.background||\"transparent\",outline:\"#ffffff33 1px solid\",margin:[-c/8+1,0,0,-1].join(\"px \")+\"px\",padding:\"0\",\"box-sizing\":\"border-box\"}).attr({contenteditable:!0}).text(u).call(C(t,i,e)).on(\"blur\",function(){r._editing=!1,t.text(this.textContent).style({opacity:1});var e,i=n.select(this).attr(\"class\");(e=i?\".\"+i.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(e).style({opacity:0});var o=this.textContent;n.select(this).transition().duration(0).remove(),n.select(document).on(\"mouseup\",null),a.edit.call(t,o)}).on(\"focus\",function(){var t=this;r._editing=!0,n.select(document).on(\"mouseup\",function(){if(n.event.target===t)return!1;document.activeElement===o.node()&&o.node().blur()})}).on(\"keyup\",function(){27===n.event.which?(r._editing=!1,t.style({opacity:1}),n.select(this).style({opacity:0}).on(\"blur\",function(){return!1}).transition().remove(),a.cancel.call(t,this.textContent)):(a.input.call(t,this.textContent),n.select(this).call(C(t,i,e)))}).on(\"keydown\",function(){13===n.event.which&&this.blur()}).call(l)}(),t.style({opacity:0});var i,s=o.attr(\"class\");(i=s?\".\"+s.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(i).style({opacity:0})}function l(t){var e=t.node(),r=document.createRange();r.selectNodeContents(e);var n=window.getSelection();n.removeAllRanges(),n.addRange(r),e.focus()}return e.immediate?s():o.on(\"click\",s),n.rebind(t,a,\"on\")}},{\"../constants/alignment\":688,\"../constants/xmlns_namespaces\":696,\"../lib\":719,d3:163}],744:[function(t,e,r){\"use strict\";var n={};function i(t){t&&null!==t.timer&&(clearTimeout(t.timer),t.timer=null)}r.throttle=function(t,e,r){var a=n[t],o=Date.now();if(!a){for(var s in n)n[s].ts<o-6e4&&delete n[s];a=n[t]={ts:0,timer:null}}function l(){r(),a.ts=Date.now(),a.onDone&&(a.onDone(),a.onDone=null)}i(a),o>a.ts+e?l():a.timer=setTimeout(function(){l(),a.timer=null},e)},r.done=function(t){var e=n[t];return e&&e.timer?new Promise(function(t){var r=e.onDone;e.onDone=function(){r&&r(),t(),e.onDone=null}}):Promise.resolve()},r.clear=function(t){if(t)i(n[t]),delete n[t];else for(var e in n)r.clear(e)}},{}],745:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t,e){if(t>0)return Math.log(t)/Math.LN10;var r=Math.log(Math.min(e[0],e[1]))/Math.LN10;return n(r)||(r=Math.log(Math.max(e[0],e[1]))/Math.LN10-6),r}},{\"fast-isnumeric\":225}],746:[function(t,e,r){\"use strict\";var n=e.exports={},i=t(\"../plots/geo/constants\").locationmodeToLayer,a=t(\"topojson-client\").feature;n.getTopojsonName=function(t){return[t.scope.replace(/ /g,\"-\"),\"_\",t.resolution.toString(),\"m\"].join(\"\")},n.getTopojsonPath=function(t,e){return t+e+\".json\"},n.getTopojsonFeatures=function(t,e){var r=i[t.locationmode],n=e.objects[r];return a(e,n).features}},{\"../plots/geo/constants\":795,\"topojson-client\":540}],747:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en-US\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colorscale title\"},format:{date:\"%m/%d/%Y\"}}},{}],748:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colourscale title\"},format:{days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],periods:[\"AM\",\"PM\"],dateTime:\"%a %b %e %X %Y\",date:\"%d/%m/%Y\",time:\"%H:%M:%S\",decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],year:\"%Y\",month:\"%b %Y\",dayMonth:\"%b %-d\",dayMonthYear:\"%b %-d, %Y\"}}},{}],749:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t){for(var e,r,i=n.layoutArrayContainers,a=n.layoutArrayRegexes,o=t.split(\"[\")[0],s=0;s<a.length;s++)if((r=t.match(a[s]))&&0===r.index){e=r[0];break}if(e||(e=i[i.indexOf(o)]),!e)return!1;var l=t.substr(e.length);return l?!!(r=l.match(/^\\[(0|[1-9][0-9]*)\\](\\.(.+))?$/))&&{array:e,index:Number(r[1]),property:r[3]||\"\"}:{array:e,index:\"\",property:\"\"}}},{\"../registry\":847}],750:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.extendFlat,a=n.isPlainObject,o={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"clearAxisTypes\",\"plot\",\"style\",\"markerSize\",\"colorbars\"]},s={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"plot\",\"legend\",\"ticks\",\"axrange\",\"layoutstyle\",\"modebar\",\"camera\",\"arraydraw\",\"colorbars\"]},l=o.flags.slice().concat([\"fullReplot\"]),c=s.flags.slice().concat(\"layoutReplot\");function u(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=!1;return e}function h(t,e,r){var n=i({},t);for(var o in n){var s=n[o];a(s)&&(n[o]=f(s,e,r,o))}return\"from-root\"===r&&(n.editType=e),n}function f(t,e,r,n){if(t.valType){var a=i({},t);if(a.editType=e,Array.isArray(t.items)){a.items=new Array(t.items.length);for(var o=0;o<t.items.length;o++)a.items[o]=f(t.items[o],e,\"from-root\")}return a}return h(t,e,\"_\"===n.charAt(0)?\"nested\":\"from-root\")}e.exports={traces:o,layout:s,traceFlags:function(){return u(l)},layoutFlags:function(){return u(c)},update:function(t,e){var r=e.editType;if(r&&\"none\"!==r)for(var n=r.split(\"+\"),i=0;i<n.length;i++)t[n[i]]=!0},overrideAll:h}},{\"../lib\":719}],751:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"gl-mat4/fromQuat\"),a=t(\"../registry\"),o=t(\"../lib\"),s=t(\"../plots/plots\"),l=t(\"../plots/cartesian/axis_ids\"),c=t(\"../components/color\"),u=l.cleanId,h=l.getFromTrace,f=a.traceIs;function p(t,e){var r=t[e],n=e.charAt(0);r&&\"paper\"!==r&&(t[e]=u(r,n))}function d(t){function e(e,r){var n=t[e],i=t.title&&t.title[r];n&&!i&&(t.title||(t.title={}),t.title[r]=t[e],delete t[e])}t&&(\"string\"!=typeof t.title&&\"number\"!=typeof t.title||(t.title={text:t.title}),e(\"titlefont\",\"font\"),e(\"titleposition\",\"position\"),e(\"titleside\",\"side\"),e(\"titleoffset\",\"offset\"))}function g(t){if(!o.isPlainObject(t))return!1;var e=t.name;return delete t.name,delete t.showlegend,(\"string\"==typeof e||\"number\"==typeof e)&&String(e)}function v(t,e,r,n){if(r&&!n)return t;if(n&&!r)return e;if(!t.trim())return e;if(!e.trim())return t;var i,a=Math.min(t.length,e.length);for(i=0;i<a&&t.charAt(i)===e.charAt(i);i++);return t.substr(0,i).trim()}function m(t){var e=\"middle\",r=\"center\";return\"string\"==typeof t&&(-1!==t.indexOf(\"top\")?e=\"top\":-1!==t.indexOf(\"bottom\")&&(e=\"bottom\"),-1!==t.indexOf(\"left\")?r=\"left\":-1!==t.indexOf(\"right\")&&(r=\"right\")),e+\" \"+r}function y(t,e){return e in t&&\"object\"==typeof t[e]&&0===Object.keys(t[e]).length}r.clearPromiseQueue=function(t){Array.isArray(t._promises)&&t._promises.length>0&&o.log(\"Clearing previous rejected promises from queue.\"),t._promises=[]},r.cleanLayout=function(t){var e,n;t||(t={}),t.xaxis1&&(t.xaxis||(t.xaxis=t.xaxis1),delete t.xaxis1),t.yaxis1&&(t.yaxis||(t.yaxis=t.yaxis1),delete t.yaxis1),t.scene1&&(t.scene||(t.scene=t.scene1),delete t.scene1);var a=(s.subplotsRegistry.cartesian||{}).attrRegex,l=(s.subplotsRegistry.polar||{}).attrRegex,h=(s.subplotsRegistry.ternary||{}).attrRegex,f=(s.subplotsRegistry.gl3d||{}).attrRegex,g=Object.keys(t);for(e=0;e<g.length;e++){var v=g[e];if(a&&a.test(v)){var m=t[v];m.anchor&&\"free\"!==m.anchor&&(m.anchor=u(m.anchor)),m.overlaying&&(m.overlaying=u(m.overlaying)),m.type||(m.isdate?m.type=\"date\":m.islog?m.type=\"log\":!1===m.isdate&&!1===m.islog&&(m.type=\"linear\")),\"withzero\"!==m.autorange&&\"tozero\"!==m.autorange||(m.autorange=!0,m.rangemode=\"tozero\"),delete m.islog,delete m.isdate,delete m.categories,y(m,\"domain\")&&delete m.domain,void 0!==m.autotick&&(void 0===m.tickmode&&(m.tickmode=m.autotick?\"auto\":\"linear\"),delete m.autotick),d(m)}else if(l&&l.test(v)){d(t[v].radialaxis)}else if(h&&h.test(v)){var x=t[v];d(x.aaxis),d(x.baxis),d(x.caxis)}else if(f&&f.test(v)){var b=t[v],_=b.cameraposition;if(Array.isArray(_)&&4===_[0].length){var w=_[0],k=_[1],T=_[2],A=i([],w),M=[];for(n=0;n<3;++n)M[n]=k[n]+T*A[2+4*n];b.camera={eye:{x:M[0],y:M[1],z:M[2]},center:{x:k[0],y:k[1],z:k[2]},up:{x:0,y:0,z:1}},delete b.cameraposition}d(b.xaxis),d(b.yaxis),d(b.zaxis)}}var S=Array.isArray(t.annotations)?t.annotations.length:0;for(e=0;e<S;e++){var E=t.annotations[e];o.isPlainObject(E)&&(E.ref&&(\"paper\"===E.ref?(E.xref=\"paper\",E.yref=\"paper\"):\"data\"===E.ref&&(E.xref=\"x\",E.yref=\"y\"),delete E.ref),p(E,\"xref\"),p(E,\"yref\"))}var C=Array.isArray(t.shapes)?t.shapes.length:0;for(e=0;e<C;e++){var L=t.shapes[e];o.isPlainObject(L)&&(p(L,\"xref\"),p(L,\"yref\"))}var P=t.legend;return P&&(P.x>3?(P.x=1.02,P.xanchor=\"left\"):P.x<-2&&(P.x=-.02,P.xanchor=\"right\"),P.y>3?(P.y=1.02,P.yanchor=\"bottom\"):P.y<-2&&(P.y=-.02,P.yanchor=\"top\")),d(t),\"rotate\"===t.dragmode&&(t.dragmode=\"orbit\"),c.clean(t),t.template&&t.template.layout&&r.cleanLayout(t.template.layout),t},r.cleanData=function(t){for(var e=0;e<t.length;e++){var n,i=t[e];if(\"histogramy\"===i.type&&\"xbins\"in i&&!(\"ybins\"in i)&&(i.ybins=i.xbins,delete i.xbins),i.error_y&&\"opacity\"in i.error_y){var l=c.defaults,h=i.error_y.color||(f(i,\"bar\")?c.defaultLine:l[e%l.length]);i.error_y.color=c.addOpacity(c.rgb(h),c.opacity(h)*i.error_y.opacity),delete i.error_y.opacity}if(\"bardir\"in i&&(\"h\"!==i.bardir||!f(i,\"bar\")&&\"histogram\"!==i.type.substr(0,9)||(i.orientation=\"h\",r.swapXYData(i)),delete i.bardir),\"histogramy\"===i.type&&r.swapXYData(i),\"histogramx\"!==i.type&&\"histogramy\"!==i.type||(i.type=\"histogram\"),\"scl\"in i&&!(\"colorscale\"in i)&&(i.colorscale=i.scl,delete i.scl),\"reversescl\"in i&&!(\"reversescale\"in i)&&(i.reversescale=i.reversescl,delete i.reversescl),i.xaxis&&(i.xaxis=u(i.xaxis,\"x\")),i.yaxis&&(i.yaxis=u(i.yaxis,\"y\")),f(i,\"gl3d\")&&i.scene&&(i.scene=s.subplotsRegistry.gl3d.cleanId(i.scene)),!f(i,\"pie-like\")&&!f(i,\"bar-like\"))if(Array.isArray(i.textposition))for(n=0;n<i.textposition.length;n++)i.textposition[n]=m(i.textposition[n]);else i.textposition&&(i.textposition=m(i.textposition));var p=a.getModule(i);if(p&&p.colorbar){var x=p.colorbar.container,b=x?i[x]:i;b&&b.colorscale&&(\"YIGnBu\"===b.colorscale&&(b.colorscale=\"YlGnBu\"),\"YIOrRd\"===b.colorscale&&(b.colorscale=\"YlOrRd\"))}if(\"surface\"===i.type&&o.isPlainObject(i.contours)){var _=[\"x\",\"y\",\"z\"];for(n=0;n<_.length;n++){var w=i.contours[_[n]];o.isPlainObject(w)&&(w.highlightColor&&(w.highlightcolor=w.highlightColor,delete w.highlightColor),w.highlightWidth&&(w.highlightwidth=w.highlightWidth,delete w.highlightWidth))}}if(\"candlestick\"===i.type||\"ohlc\"===i.type){var k=!1!==(i.increasing||{}).showlegend,T=!1!==(i.decreasing||{}).showlegend,A=g(i.increasing),M=g(i.decreasing);if(!1!==A&&!1!==M){var S=v(A,M,k,T);S&&(i.name=S)}else!A&&!M||i.name||(i.name=A||M)}if(Array.isArray(i.transforms)){var E=i.transforms;for(n=0;n<E.length;n++){var C=E[n];if(o.isPlainObject(C))switch(C.type){case\"filter\":C.filtersrc&&(C.target=C.filtersrc,delete C.filtersrc),C.calendar&&(C.valuecalendar||(C.valuecalendar=C.calendar),delete C.calendar);break;case\"groupby\":if(C.styles=C.styles||C.style,C.styles&&!Array.isArray(C.styles)){var L=C.styles,P=Object.keys(L);C.styles=[];for(var O=0;O<P.length;O++)C.styles.push({target:P[O],value:L[P[O]]})}}}}y(i,\"line\")&&delete i.line,\"marker\"in i&&(y(i.marker,\"line\")&&delete i.marker.line,y(i,\"marker\")&&delete i.marker),c.clean(i),i.autobinx&&(delete i.autobinx,delete i.xbins),i.autobiny&&(delete i.autobiny,delete i.ybins),d(i),i.colorbar&&d(i.colorbar),i.marker&&i.marker.colorbar&&d(i.marker.colorbar),i.line&&i.line.colorbar&&d(i.line.colorbar),i.aaxis&&d(i.aaxis),i.baxis&&d(i.baxis)}},r.swapXYData=function(t){var e;if(o.swapAttrs(t,[\"?\",\"?0\",\"d?\",\"?bins\",\"nbins?\",\"autobin?\",\"?src\",\"error_?\"]),Array.isArray(t.z)&&Array.isArray(t.z[0])&&(t.transpose?delete t.transpose:t.transpose=!0),t.error_x&&t.error_y){var r=t.error_y,n=\"copy_ystyle\"in r?r.copy_ystyle:!(r.color||r.thickness||r.width);o.swapAttrs(t,[\"error_?.copy_ystyle\"]),n&&o.swapAttrs(t,[\"error_?.color\",\"error_?.thickness\",\"error_?.width\"])}if(\"string\"==typeof t.hoverinfo){var i=t.hoverinfo.split(\"+\");for(e=0;e<i.length;e++)\"x\"===i[e]?i[e]=\"y\":\"y\"===i[e]&&(i[e]=\"x\");t.hoverinfo=i.join(\"+\")}},r.coerceTraceIndices=function(t,e){if(n(e))return[e];if(!Array.isArray(e)||!e.length)return t.data.map(function(t,e){return e});if(Array.isArray(e)){for(var r=[],i=0;i<e.length;i++)o.isIndex(e[i],t.data.length)?r.push(e[i]):o.warn(\"trace index (\",e[i],\") is not a number or is out of bounds\");return r}return e},r.manageArrayContainers=function(t,e,r){var i=t.obj,a=t.parts,s=a.length,l=a[s-1],c=n(l);if(c&&null===e){var u=a.slice(0,s-1).join(\".\");o.nestedProperty(i,u).get().splice(l,1)}else c&&void 0===t.get()?(void 0===t.get()&&(r[t.astr]=null),t.set(e)):t.set(e)};var x=/(\\.[^\\[\\]\\.]+|\\[[^\\[\\]\\.]+\\])$/;function b(t){var e=t.search(x);if(e>0)return t.substr(0,e)}r.hasParent=function(t,e){for(var r=b(e);r;){if(r in t)return!0;r=b(r)}return!1};var _=[\"x\",\"y\",\"z\"];r.clearAxisTypes=function(t,e,r){for(var n=0;n<e.length;n++)for(var i=t._fullData[n],a=0;a<3;a++){var s=h(t,i,_[a]);if(s&&\"log\"!==s.type){var l=s._name,c=s._id.substr(1);if(\"scene\"===c.substr(0,5)){if(void 0!==r[c])continue;l=c+\".\"+l}var u=l+\".type\";void 0===r[l]&&void 0===r[u]&&o.nestedProperty(t.layout,u).set(null)}}}},{\"../components/color\":593,\"../lib\":719,\"../plots/cartesian/axis_ids\":770,\"../plots/plots\":828,\"../registry\":847,\"fast-isnumeric\":225,\"gl-mat4/fromQuat\":262}],752:[function(t,e,r){\"use strict\";var n=t(\"./plot_api\");r.plot=n.plot,r.newPlot=n.newPlot,r.restyle=n.restyle,r.relayout=n.relayout,r.redraw=n.redraw,r.update=n.update,r._guiRestyle=n._guiRestyle,r._guiRelayout=n._guiRelayout,r._guiUpdate=n._guiUpdate,r._storeDirectGUIEdit=n._storeDirectGUIEdit,r.react=n.react,r.extendTraces=n.extendTraces,r.prependTraces=n.prependTraces,r.addTraces=n.addTraces,r.deleteTraces=n.deleteTraces,r.moveTraces=n.moveTraces,r.purge=n.purge,r.addFrames=n.addFrames,r.deleteFrames=n.deleteFrames,r.animate=n.animate,r.setPlotConfig=n.setPlotConfig,r.toImage=t(\"./to_image\"),r.validate=t(\"./validate\"),r.downloadImage=t(\"../snapshot/download\");var i=t(\"./template_api\");r.makeTemplate=i.makeTemplate,r.validateTemplate=i.validateTemplate},{\"../snapshot/download\":849,\"./plot_api\":754,\"./template_api\":759,\"./to_image\":760,\"./validate\":761}],753:[function(t,e,r){\"use strict\";var n=t(\"../lib/is_plain_object\"),i=t(\"../lib/noop\"),a=t(\"../lib/loggers\"),o=t(\"../lib/search\").sorterAsc,s=t(\"../registry\");r.containerArrayMatch=t(\"./container_array_match\");var l=r.isAddVal=function(t){return\"add\"===t||n(t)},c=r.isRemoveVal=function(t){return null===t||\"remove\"===t};r.applyContainerArrayChanges=function(t,e,r,n,u){var h=e.astr,f=s.getComponentMethod(h,\"supplyLayoutDefaults\"),p=s.getComponentMethod(h,\"draw\"),d=s.getComponentMethod(h,\"drawOne\"),g=n.replot||n.recalc||f===i||p===i,v=t.layout,m=t._fullLayout;if(r[\"\"]){Object.keys(r).length>1&&a.warn(\"Full array edits are incompatible with other edits\",h);var y=r[\"\"][\"\"];if(c(y))e.set(null);else{if(!Array.isArray(y))return a.warn(\"Unrecognized full array edit value\",h,y),!0;e.set(y)}return!g&&(f(v,m),p(t),!0)}var x,b,_,w,k,T,A,M,S=Object.keys(r).map(Number).sort(o),E=e.get(),C=E||[],L=u(m,h).get(),P=[],O=-1,z=C.length;for(x=0;x<S.length;x++)if(w=r[_=S[x]],k=Object.keys(w),T=w[\"\"],A=l(T),_<0||_>C.length-(A?0:1))a.warn(\"index out of range\",h,_);else if(void 0!==T)k.length>1&&a.warn(\"Insertion & removal are incompatible with edits to the same index.\",h,_),c(T)?P.push(_):A?(\"add\"===T&&(T={}),C.splice(_,0,T),L&&L.splice(_,0,{})):a.warn(\"Unrecognized full object edit value\",h,_,T),-1===O&&(O=_);else for(b=0;b<k.length;b++)M=h+\"[\"+_+\"].\",u(C[_],k[b],M).set(w[k[b]]);for(x=P.length-1;x>=0;x--)C.splice(P[x],1),L&&L.splice(P[x],1);if(C.length?E||e.set(C):e.set(null),g)return!1;if(f(v,m),d!==i){var I;if(-1===O)I=S;else{for(z=Math.max(C.length,z),I=[],x=0;x<S.length&&!((_=S[x])>=O);x++)I.push(_);for(x=O;x<z;x++)I.push(x)}for(x=0;x<I.length;x++)d(t,I[x])}else p(t);return!0}},{\"../lib/is_plain_object\":720,\"../lib/loggers\":723,\"../lib/noop\":728,\"../lib/search\":738,\"../registry\":847,\"./container_array_match\":749}],754:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"has-hover\"),o=t(\"../lib\"),s=o.nestedProperty,l=t(\"../lib/events\"),c=t(\"../lib/queue\"),u=t(\"../registry\"),h=t(\"./plot_schema\"),f=t(\"../plots/plots\"),p=t(\"../plots/polar/legacy\"),d=t(\"../plots/cartesian/axes\"),g=t(\"../components/drawing\"),v=t(\"../components/color\"),m=t(\"../plots/cartesian/graph_interact\").initInteractions,y=t(\"../constants/xmlns_namespaces\"),x=t(\"../lib/svg_text_utils\"),b=t(\"../plots/cartesian/select\").clearSelect,_=t(\"./plot_config\").dfltConfig,w=t(\"./manage_arrays\"),k=t(\"./helpers\"),T=t(\"./subroutines\"),A=t(\"./edit_types\"),M=t(\"../plots/cartesian/constants\").AX_NAME_PATTERN,S=0,E=5;function C(t){var e=t._fullLayout;e._redrawFromAutoMarginCount?e._redrawFromAutoMarginCount--:t.emit(\"plotly_afterplot\")}function L(t,e){try{t._fullLayout._paper.style(\"background\",e)}catch(t){o.error(t)}}function P(t,e){L(t,v.combine(e,\"white\"))}function O(t,e){if(!t._context){t._context=o.extendDeep({},_);var r=n.select(\"base\");t._context._baseUrl=r.size()&&r.attr(\"href\")?window.location.href.split(\"#\")[0]:\"\"}var i,s,l,c=t._context;if(e){for(s=Object.keys(e),i=0;i<s.length;i++)\"editable\"!==(l=s[i])&&\"edits\"!==l&&l in c&&(\"setBackground\"===l&&\"opaque\"===e[l]?c[l]=P:c[l]=e[l]);e.plot3dPixelRatio&&!c.plotGlPixelRatio&&(c.plotGlPixelRatio=c.plot3dPixelRatio);var u=e.editable;if(void 0!==u)for(c.editable=u,s=Object.keys(c.edits),i=0;i<s.length;i++)c.edits[s[i]]=u;if(e.edits)for(s=Object.keys(e.edits),i=0;i<s.length;i++)(l=s[i])in c.edits&&(c.edits[l]=e.edits[l]);c._exportedPlot=e._exportedPlot}c.staticPlot&&(c.editable=!1,c.edits={},c.autosizable=!1,c.scrollZoom=!1,c.doubleClick=!1,c.showTips=!1,c.showLink=!1,c.displayModeBar=!1),\"hover\"!==c.displayModeBar||a||(c.displayModeBar=!0),\"transparent\"!==c.setBackground&&\"function\"==typeof c.setBackground||(c.setBackground=L),c._hasZeroHeight=c._hasZeroHeight||0===t.clientHeight,c._hasZeroWidth=c._hasZeroWidth||0===t.clientWidth;var h=c.scrollZoom,f=c._scrollZoom={};if(!0===h)f.cartesian=1,f.gl3d=1,f.geo=1,f.mapbox=1;else if(\"string\"==typeof h){var p=h.split(\"+\");for(i=0;i<p.length;i++)f[p[i]]=1}else!1!==h&&(f.gl3d=1,f.geo=1,f.mapbox=1)}function z(t,e){var r,n,i=e+1,a=[];for(r=0;r<t.length;r++)(n=t[r])<0?a.push(i+n):a.push(n);return a}function I(t,e,r){var n,i;for(n=0;n<e.length;n++){if((i=e[n])!==parseInt(i,10))throw new Error(\"all values in \"+r+\" must be integers\");if(i>=t.data.length||i<-t.data.length)throw new Error(r+\" must be valid indices for gd.data.\");if(e.indexOf(i,n+1)>-1||i>=0&&e.indexOf(-t.data.length+i)>-1||i<0&&e.indexOf(t.data.length+i)>-1)throw new Error(\"each index in \"+r+\" must be unique.\")}}function D(t,e,r){if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"currentIndices is a required argument.\");if(Array.isArray(e)||(e=[e]),I(t,e,\"currentIndices\"),\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&I(t,r,\"newIndices\"),\"undefined\"!=typeof r&&e.length!==r.length)throw new Error(\"current and new indices must be of equal length.\")}function R(t,e,r,n,a){!function(t,e,r,n){var i=o.isPlainObject(n);if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array\");if(!o.isPlainObject(e))throw new Error(\"update must be a key:value object\");if(\"undefined\"==typeof r)throw new Error(\"indices must be an integer or array of integers\");for(var a in I(t,r,\"indices\"),e){if(!Array.isArray(e[a])||e[a].length!==r.length)throw new Error(\"attribute \"+a+\" must be an array of length equal to indices array length\");if(i&&(!(a in n)||!Array.isArray(n[a])||n[a].length!==e[a].length))throw new Error(\"when maxPoints is set as a key:value object it must contain a 1:1 corrispondence with the keys and number of traces in the update object\")}}(t,e,r,n);for(var l=function(t,e,r,n){var a,l,c,u,h,f=o.isPlainObject(n),p=[];for(var d in Array.isArray(r)||(r=[r]),r=z(r,t.data.length-1),e)for(var g=0;g<r.length;g++){if(a=t.data[r[g]],l=(c=s(a,d)).get(),u=e[d][g],!o.isArrayOrTypedArray(u))throw new Error(\"attribute: \"+d+\" index: \"+g+\" must be an array\");if(!o.isArrayOrTypedArray(l))throw new Error(\"cannot extend missing or non-array attribute: \"+d);if(l.constructor!==u.constructor)throw new Error(\"cannot extend array with an array of a different type: \"+d);h=f?n[d][g]:n,i(h)||(h=-1),p.push({prop:c,target:l,insert:u,maxp:Math.floor(h)})}return p}(t,e,r,n),c={},u={},h=0;h<l.length;h++){var f=l[h].prop,p=l[h].maxp,d=a(l[h].target,l[h].insert,p);f.set(d[0]),Array.isArray(c[f.astr])||(c[f.astr]=[]),c[f.astr].push(d[1]),Array.isArray(u[f.astr])||(u[f.astr]=[]),u[f.astr].push(l[h].target.length)}return{update:c,maxPoints:u}}function F(t,e){var r=new t.constructor(t.length+e.length);return r.set(t),r.set(e,t.length),r}function B(t,e,n,i){t=o.getGraphDiv(t),k.clearPromiseQueue(t);var a={};if(\"string\"==typeof e)a[e]=n;else{if(!o.isPlainObject(e))return o.warn(\"Restyle fail.\",e,n,i),Promise.reject();a=o.extendFlat({},e),void 0===i&&(i=n)}Object.keys(a).length&&(t.changed=!0);var s=k.coerceTraceIndices(t,i),l=V(t,a,s),u=l.flags;u.calc&&(t.calcdata=void 0),u.clearAxisTypes&&k.clearAxisTypes(t,s,{});var h=[];u.fullReplot?h.push(r.plot):(h.push(f.previousPromises),f.supplyDefaults(t),u.markerSize&&(f.doCalcdata(t),Y(h)),u.style&&h.push(T.doTraceStyle),u.colorbars&&h.push(T.doColorBars),h.push(C)),h.push(f.rehover,f.redrag),c.add(t,B,[t,l.undoit,l.traces],B,[t,l.redoit,l.traces]);var p=o.syncOrAsync(h,t);return p&&p.then||(p=Promise.resolve()),p.then(function(){return t.emit(\"plotly_restyle\",l.eventData),t})}function N(t){return void 0===t?null:t}function j(t,e){return e?function(e,r,n){var i=s(e,r),a=i.set;return i.set=function(e){U((n||\"\")+r,i.get(),e,t),a(e)},i}:s}function U(t,e,r,n){if(Array.isArray(e)||Array.isArray(r))for(var i=Array.isArray(e)?e:[],a=Array.isArray(r)?r:[],s=Math.max(i.length,a.length),l=0;l<s;l++)U(t+\"[\"+l+\"]\",i[l],a[l],n);else if(o.isPlainObject(e)||o.isPlainObject(r)){var c=o.isPlainObject(e)?e:{},u=o.isPlainObject(r)?r:{},h=o.extendFlat({},c,u);for(var f in h)U(t+\".\"+f,c[f],u[f],n)}else void 0===n[t]&&(n[t]=N(e))}function V(t,e,r){var n,i=t._fullLayout,a=t._fullData,l=t.data,c=i._guiEditing,p=j(i._preGUI,c),g=o.extendDeepAll({},e);q(e);var v,m=A.traceFlags(),y={},x={};function b(){return r.map(function(){})}function _(t){var e=d.id2name(t);-1===v.indexOf(e)&&v.push(e)}function w(t){return\"LAYOUT\"+t+\".autorange\"}function T(t){return\"LAYOUT\"+t+\".range\"}function M(t){for(var e=t;e<a.length;e++)if(a[e]._input===l[t])return a[e]}function S(n,a,o){if(Array.isArray(n))n.forEach(function(t){S(t,a,o)});else if(!(n in e||k.hasParent(e,n))){var s;if(\"LAYOUT\"===n.substr(0,6))s=p(t.layout,n.replace(\"LAYOUT\",\"\"));else{var u=r[o];s=j(i._tracePreGUI[M(u)._fullInput.uid],c)(l[u],n)}n in x||(x[n]=b()),void 0===x[n][o]&&(x[n][o]=N(s.get())),void 0!==a&&s.set(a)}}function E(t){return function(e){return a[e][t]}}function C(t){return function(e,n){return!1===e?a[r[n]][t]:null}}for(var L in e){if(k.hasParent(e,L))throw new Error(\"cannot set \"+L+\" and a parent attribute simultaneously\");var P,O,z,I,D,R,F=e[L];if(\"autobinx\"!==L&&\"autobiny\"!==L||(L=L.charAt(L.length-1)+\"bins\",F=Array.isArray(F)?F.map(C(L)):!1===F?r.map(E(L)):null),y[L]=F,\"LAYOUT\"!==L.substr(0,6)){for(x[L]=b(),n=0;n<r.length;n++){if(P=l[r[n]],O=M(r[n]),I=(z=j(i._tracePreGUI[O._fullInput.uid],c)(P,L)).get(),void 0!==(D=Array.isArray(F)?F[n%F.length]:F)){var B=z.parts[z.parts.length-1],U=L.substr(0,L.length-B.length-1),V=U?U+\".\":\"\",H=U?s(O,U).get():O;if((R=h.getTraceValObject(O,z.parts))&&R.impliedEdits&&null!==D)for(var G in R.impliedEdits)S(o.relativeAttr(L,G),R.impliedEdits[G],n);else if(\"thicknessmode\"!==B&&\"lenmode\"!==B||I===D||\"fraction\"!==D&&\"pixels\"!==D||!H){if(\"type\"===L&&(\"pie\"===D!=(\"pie\"===I)||\"funnelarea\"===D!=(\"funnelarea\"===I))){var Y=\"x\",W=\"y\";\"bar\"!==D&&\"bar\"!==I||\"h\"!==P.orientation||(Y=\"y\",W=\"x\"),o.swapAttrs(P,[\"?\",\"?src\"],\"labels\",Y),o.swapAttrs(P,[\"d?\",\"?0\"],\"label\",Y),o.swapAttrs(P,[\"?\",\"?src\"],\"values\",W),\"pie\"===I||\"funnelarea\"===I?(s(P,\"marker.color\").set(s(P,\"marker.colors\").get()),i._pielayer.selectAll(\"g.trace\").remove()):u.traceIs(P,\"cartesian\")&&s(P,\"marker.colors\").set(s(P,\"marker.color\").get())}}else{var X=i._size,Z=H.orient,J=\"top\"===Z||\"bottom\"===Z;if(\"thicknessmode\"===B){var K=J?X.h:X.w;S(V+\"thickness\",H.thickness*(\"fraction\"===D?1/K:K),n)}else{var $=J?X.w:X.h;S(V+\"len\",H.len*(\"fraction\"===D?1/$:$),n)}}x[L][n]=N(I);if(-1!==[\"swapxy\",\"swapxyaxes\",\"orientation\",\"orientationaxes\"].indexOf(L)){if(\"orientation\"===L){z.set(D);var Q=P.x&&!P.y?\"h\":\"v\";if((z.get()||Q)===O.orientation)continue}else\"orientationaxes\"===L&&(P.orientation={v:\"h\",h:\"v\"}[O.orientation]);k.swapXYData(P),m.calc=m.clearAxisTypes=!0}else-1!==f.dataArrayContainers.indexOf(z.parts[0])?(k.manageArrayContainers(z,D,x),m.calc=!0):(R?R.arrayOk&&!u.traceIs(O,\"regl\")&&(o.isArrayOrTypedArray(D)||o.isArrayOrTypedArray(I))?m.calc=!0:A.update(m,R):m.calc=!0,z.set(D))}}if(-1!==[\"swapxyaxes\",\"orientationaxes\"].indexOf(L)&&d.swap(t,r),\"orientationaxes\"===L){var tt=s(t.layout,\"hovermode\");\"x\"===tt.get()?tt.set(\"y\"):\"y\"===tt.get()&&tt.set(\"x\")}if(-1!==[\"orientation\",\"type\"].indexOf(L)){for(v=[],n=0;n<r.length;n++){var et=l[r[n]];u.traceIs(et,\"cartesian\")&&(_(et.xaxis||\"x\"),_(et.yaxis||\"y\"))}S(v.map(w),!0,0),S(v.map(T),[0,1],0)}}else z=p(t.layout,L.replace(\"LAYOUT\",\"\")),x[L]=[N(z.get())],z.set(Array.isArray(F)?F[0]:F),m.calc=!0}return(m.calc||m.plot)&&(m.fullReplot=!0),{flags:m,undoit:x,redoit:y,traces:r,eventData:o.extendDeepNoArrays([],[g,r])}}function q(t){var e,r,n,i=o.counterRegex(\"axis\",\".title\",!1,!1),a=/colorbar\\.title$/,s=Object.keys(t);for(e=0;e<s.length;e++)r=s[e],n=t[r],\"title\"!==r&&!i.test(r)&&!a.test(r)||\"string\"!=typeof n&&\"number\"!=typeof n?r.indexOf(\"titlefont\")>-1?l(r,r.replace(\"titlefont\",\"title.font\")):r.indexOf(\"titleposition\")>-1?l(r,r.replace(\"titleposition\",\"title.position\")):r.indexOf(\"titleside\")>-1?l(r,r.replace(\"titleside\",\"title.side\")):r.indexOf(\"titleoffset\")>-1&&l(r,r.replace(\"titleoffset\",\"title.offset\")):l(r,r.replace(\"title\",\"title.text\"));function l(e,r){t[r]=t[e],delete t[e]}}function H(t,e,r){if(t=o.getGraphDiv(t),k.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);var n={};if(\"string\"==typeof e)n[e]=r;else{if(!o.isPlainObject(e))return o.warn(\"Relayout fail.\",e,r),Promise.reject();n=o.extendFlat({},e)}Object.keys(n).length&&(t.changed=!0);var i=J(t,n),a=i.flags;a.calc&&(t.calcdata=void 0);var s=[f.previousPromises];a.layoutReplot?s.push(T.layoutReplot):Object.keys(n).length&&(G(t,a,i)||f.supplyDefaults(t),a.legend&&s.push(T.doLegend),a.layoutstyle&&s.push(T.layoutStyles),a.axrange&&Y(s,i.rangesAltered),a.ticks&&s.push(T.doTicksRelayout),a.modebar&&s.push(T.doModeBar),a.camera&&s.push(T.doCamera),a.colorbars&&s.push(T.doColorBars),s.push(C)),s.push(f.rehover,f.redrag),c.add(t,H,[t,i.undoit],H,[t,i.redoit]);var l=o.syncOrAsync(s,t);return l&&l.then||(l=Promise.resolve(t)),l.then(function(){return t.emit(\"plotly_relayout\",i.eventData),t})}function G(t,e,r){var n=t._fullLayout;if(!e.axrange)return!1;for(var i in e)if(\"axrange\"!==i&&e[i])return!1;for(var a in r.rangesAltered){var o=d.id2name(a),s=t.layout[o],l=n[o];if(l.autorange=s.autorange,l.range=s.range.slice(),l.cleanRange(),l._matchGroup)for(var c in l._matchGroup)if(c!==a){var u=n[d.id2name(c)];u.autorange=l.autorange,u.range=l.range.slice(),u._input.range=l.range.slice()}}return!0}function Y(t,e){var r=e?function(t){var r=[],n=!0;for(var i in e){var a=d.getFromId(t,i);if(r.push(i),a._matchGroup)for(var o in a._matchGroup)e[o]||r.push(o);a.automargin&&(n=!1)}return d.draw(t,r,{skipTitle:n})}:function(t){return d.draw(t,\"redraw\")};t.push(b,T.doAutoRangeAndConstraints,r,T.drawData,T.finalDraw)}var W=/^[xyz]axis[0-9]*\\.range(\\[[0|1]\\])?$/,X=/^[xyz]axis[0-9]*\\.autorange$/,Z=/^[xyz]axis[0-9]*\\.domain(\\[[0|1]\\])?$/;function J(t,e){var r,n,i,a=t.layout,l=t._fullLayout,c=l._guiEditing,f=j(l._preGUI,c),p=Object.keys(e),g=d.list(t),v=o.extendDeepAll({},e),m={};for(q(e),p=Object.keys(e),n=0;n<p.length;n++)if(0===p[n].indexOf(\"allaxes\")){for(i=0;i<g.length;i++){var y=g[i]._id.substr(1),x=-1!==y.indexOf(\"scene\")?y+\".\":\"\",b=p[n].replace(\"allaxes\",x+g[i]._name);e[b]||(e[b]=e[p[n]])}delete e[p[n]]}var _=A.layoutFlags(),T={},S={};function E(t,r){if(Array.isArray(t))t.forEach(function(t){E(t,r)});else if(!(t in e||k.hasParent(e,t))){var n=f(a,t);t in S||(S[t]=N(n.get())),void 0!==r&&n.set(r)}}var C,L={};function P(t){var e=d.name2id(t.split(\".\")[0]);return L[e]=1,e}for(var O in e){if(k.hasParent(e,O))throw new Error(\"cannot set \"+O+\" and a parent attribute simultaneously\");for(var z=f(a,O),I=e[O],D=z.parts.length-1;D>0&&\"string\"!=typeof z.parts[D];)D--;var R=z.parts[D],F=z.parts[D-1]+\".\"+R,B=z.parts.slice(0,D).join(\".\"),U=s(t.layout,B).get(),V=s(l,B).get(),H=z.get();if(void 0!==I){T[O]=I,S[O]=\"reverse\"===R?I:N(H);var G=h.getLayoutValObject(l,z.parts);if(G&&G.impliedEdits&&null!==I)for(var Y in G.impliedEdits)E(o.relativeAttr(O,Y),G.impliedEdits[Y]);if(-1!==[\"width\",\"height\"].indexOf(O))if(I){E(\"autosize\",null);var J=\"height\"===O?\"width\":\"height\";E(J,l[J])}else l[O]=t._initialAutoSize[O];else if(\"autosize\"===O)E(\"width\",I?null:l.width),E(\"height\",I?null:l.height);else if(F.match(W))P(F),s(l,B+\"._inputRange\").set(null);else if(F.match(X)){P(F),s(l,B+\"._inputRange\").set(null);var $=s(l,B).get();$._inputDomain&&($._input.domain=$._inputDomain.slice())}else F.match(Z)&&s(l,B+\"._inputDomain\").set(null);if(\"type\"===R){var Q=U,tt=\"linear\"===V.type&&\"log\"===I,et=\"log\"===V.type&&\"linear\"===I;if(tt||et){if(Q&&Q.range)if(V.autorange)tt&&(Q.range=Q.range[1]>Q.range[0]?[1,2]:[2,1]);else{var rt=Q.range[0],nt=Q.range[1];tt?(rt<=0&&nt<=0&&E(B+\".autorange\",!0),rt<=0?rt=nt/1e6:nt<=0&&(nt=rt/1e6),E(B+\".range[0]\",Math.log(rt)/Math.LN10),E(B+\".range[1]\",Math.log(nt)/Math.LN10)):(E(B+\".range[0]\",Math.pow(10,rt)),E(B+\".range[1]\",Math.pow(10,nt)))}else E(B+\".autorange\",!0);Array.isArray(l._subplots.polar)&&l._subplots.polar.length&&l[z.parts[0]]&&\"radialaxis\"===z.parts[1]&&delete l[z.parts[0]]._subplot.viewInitial[\"radialaxis.range\"],u.getComponentMethod(\"annotations\",\"convertCoords\")(t,V,I,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,V,I,E)}else E(B+\".autorange\",!0),E(B+\".range\",null);s(l,B+\"._inputRange\").set(null)}else if(R.match(M)){var it=s(l,O).get(),at=(I||{}).type;at&&\"-\"!==at||(at=\"linear\"),u.getComponentMethod(\"annotations\",\"convertCoords\")(t,it,at,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,it,at,E)}var ot=w.containerArrayMatch(O);if(ot){r=ot.array,n=ot.index;var st=ot.property,lt=G||{editType:\"calc\"};\"\"!==n&&\"\"===st&&(w.isAddVal(I)?S[O]=null:w.isRemoveVal(I)?S[O]=(s(a,r).get()||[])[n]:o.warn(\"unrecognized full object value\",e)),A.update(_,lt),m[r]||(m[r]={});var ct=m[r][n];ct||(ct=m[r][n]={}),ct[st]=I,delete e[O]}else\"reverse\"===R?(U.range?U.range.reverse():(E(B+\".autorange\",!0),U.range=[1,0]),V.autorange?_.calc=!0:_.plot=!0):(l._has(\"scatter-like\")&&l._has(\"regl\")&&\"dragmode\"===O&&(\"lasso\"===I||\"select\"===I)&&\"lasso\"!==H&&\"select\"!==H?_.plot=!0:l._has(\"gl2d\")?_.plot=!0:G?A.update(_,G):_.calc=!0,z.set(I))}}for(r in m){w.applyContainerArrayChanges(t,f(a,r),m[r],_,f)||(_.plot=!0)}var ut=l._axisConstraintGroups||[];for(C in L)for(n=0;n<ut.length;n++){var ht=ut[n];if(ht[C])for(var ft in _.calc=!0,ht)L[ft]||(d.getFromId(t,ft)._constraintShrinkable=!0)}return(K(t)||e.height||e.width)&&(_.plot=!0),(_.plot||_.calc)&&(_.layoutReplot=!0),{flags:_,rangesAltered:L,undoit:S,redoit:T,eventData:v}}function K(t){var e=t._fullLayout,r=e.width,n=e.height;return t.layout.autosize&&f.plotAutoSize(t,t.layout,e),e.width!==r||e.height!==n}function $(t,e,n,i){if(t=o.getGraphDiv(t),k.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);o.isPlainObject(e)||(e={}),o.isPlainObject(n)||(n={}),Object.keys(e).length&&(t.changed=!0),Object.keys(n).length&&(t.changed=!0);var a=k.coerceTraceIndices(t,i),s=V(t,o.extendFlat({},e),a),l=s.flags,u=J(t,o.extendFlat({},n)),h=u.flags;(l.calc||h.calc)&&(t.calcdata=void 0),l.clearAxisTypes&&k.clearAxisTypes(t,a,n);var p=[];h.layoutReplot?p.push(T.layoutReplot):l.fullReplot?p.push(r.plot):(p.push(f.previousPromises),G(t,h,u)||f.supplyDefaults(t),l.style&&p.push(T.doTraceStyle),(l.colorbars||h.colorbars)&&p.push(T.doColorBars),h.legend&&p.push(T.doLegend),h.layoutstyle&&p.push(T.layoutStyles),h.axrange&&Y(p,u.rangesAltered),h.ticks&&p.push(T.doTicksRelayout),h.modebar&&p.push(T.doModeBar),h.camera&&p.push(T.doCamera),p.push(C)),p.push(f.rehover,f.redrag),c.add(t,$,[t,s.undoit,u.undoit,s.traces],$,[t,s.redoit,u.redoit,s.traces]);var d=o.syncOrAsync(p,t);return d&&d.then||(d=Promise.resolve(t)),d.then(function(){return t.emit(\"plotly_update\",{data:s.eventData,layout:u.eventData}),t})}function Q(t){return function(e){e._fullLayout._guiEditing=!0;var r=t.apply(null,arguments);return e._fullLayout._guiEditing=!1,r}}var tt=[{pattern:/^hiddenlabels/,attr:\"legend.uirevision\"},{pattern:/^((x|y)axis\\d*)\\.((auto)?range|title\\.text)/},{pattern:/axis\\d*\\.showspikes$/,attr:\"modebar.uirevision\"},{pattern:/(hover|drag)mode$/,attr:\"modebar.uirevision\"},{pattern:/^(scene\\d*)\\.camera/},{pattern:/^(geo\\d*)\\.(projection|center)/},{pattern:/^(ternary\\d*\\.[abc]axis)\\.(min|title\\.text)$/},{pattern:/^(polar\\d*\\.radialaxis)\\.((auto)?range|angle|title\\.text)/},{pattern:/^(polar\\d*\\.angularaxis)\\.rotation/},{pattern:/^(mapbox\\d*)\\.(center|zoom|bearing|pitch)/},{pattern:/^legend\\.(x|y)$/,attr:\"editrevision\"},{pattern:/^(shapes|annotations)/,attr:\"editrevision\"},{pattern:/^title\\.text$/,attr:\"editrevision\"}],et=[{pattern:/^selectedpoints$/,attr:\"selectionrevision\"},{pattern:/(^|value\\.)visible$/,attr:\"legend.uirevision\"},{pattern:/^dimensions\\[\\d+\\]\\.constraintrange/},{pattern:/^node\\.(x|y|groups)/},{pattern:/^level$/},{pattern:/(^|value\\.)name$/},{pattern:/colorbar\\.title\\.text$/},{pattern:/colorbar\\.(x|y)$/,attr:\"editrevision\"}];function rt(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=t.match(n.pattern);if(i)return{head:i[1],attr:n.attr}}}function nt(t,e){var r=s(e,t).get();if(void 0!==r)return r;var n=t.split(\".\");for(n.pop();n.length>1;)if(n.pop(),void 0!==(r=s(e,n.join(\".\")+\".uirevision\").get()))return r;return e.uirevision}function it(t,e){for(var r=0;r<e.length;r++)if(e[r]._fullInput.uid===t)return r;return-1}function at(t,e,r){for(var n=0;n<e.length;n++)if(e[n].uid===t)return n;return!e[r]||e[r].uid?-1:r}function ot(t,e){var r=o.isPlainObject(t),n=Array.isArray(t);return r||n?(r&&o.isPlainObject(e)||n&&Array.isArray(e))&&JSON.stringify(t)===JSON.stringify(e):t===e}function st(t,e,r,n){var i,a,l,c=n.getValObject,u=n.flags,h=n.immutable,f=n.inArray,p=n.arrayIndex;function d(){var t=i.editType;f&&-1!==t.indexOf(\"arraydraw\")?o.pushUnique(u.arrays[f],p):(A.update(u,i),\"none\"!==t&&u.nChanges++,n.transition&&i.anim&&u.nChangesAnim++,(W.test(l)||X.test(l))&&(u.rangesAltered[r[0]]=1),Z.test(l)&&s(e,\"_inputDomain\").set(null),\"datarevision\"===a&&(u.newDataRevision=1))}function g(t){return\"data_array\"===t.valType||t.arrayOk}for(a in t){if(u.calc&&!n.transition)return;var v=t[a],m=e[a],y=r.concat(a);if(l=y.join(\".\"),\"_\"!==a.charAt(0)&&\"function\"!=typeof v&&v!==m){if((\"tick0\"===a||\"dtick\"===a)&&\"geo\"!==r[0]){var x=e.tickmode;if(\"auto\"===x||\"array\"===x||!x)continue}if((\"range\"!==a||!e.autorange)&&(\"zmin\"!==a&&\"zmax\"!==a||\"contourcarpet\"!==e.type)&&(i=c(y))&&(!i._compareAsJSON||JSON.stringify(v)!==JSON.stringify(m))){var b,_=i.valType,w=g(i),k=Array.isArray(v),T=Array.isArray(m);if(k&&T){var M=\"_input_\"+a,S=t[M],E=e[M];if(Array.isArray(S)&&S===E)continue}if(void 0===m)w&&k?u.calc=!0:d();else if(i._isLinkedToArray){var C=[],L=!1;f||(u.arrays[a]=C);var P=Math.min(v.length,m.length),O=Math.max(v.length,m.length);if(P!==O){if(\"arraydraw\"!==i.editType){d();continue}L=!0}for(b=0;b<P;b++)st(v[b],m[b],y.concat(b),o.extendFlat({inArray:a,arrayIndex:b},n));if(L)for(b=P;b<O;b++)C.push(b)}else!_&&o.isPlainObject(v)?st(v,m,y,n):w?k&&T?(h&&(u.calc=!0),(h||n.newDataRevision)&&d()):k!==T?u.calc=!0:d():k&&T&&v.length===m.length&&String(v)===String(m)||d()}}}for(a in e)if(!(a in t||\"_\"===a.charAt(0)||\"function\"==typeof e[a])){if(g(i=c(r.concat(a)))&&Array.isArray(e[a]))return void(u.calc=!0);d()}}function lt(t){var e=n.select(t),r=t._fullLayout;if(r._container=e.selectAll(\".plot-container\").data([0]),r._container.enter().insert(\"div\",\":first-child\").classed(\"plot-container\",!0).classed(\"plotly\",!0),r._paperdiv=r._container.selectAll(\".svg-container\").data([0]),r._paperdiv.enter().append(\"div\").classed(\"svg-container\",!0).style(\"position\",\"relative\"),r._glcontainer=r._paperdiv.selectAll(\".gl-container\").data([{}]),r._glcontainer.enter().append(\"div\").classed(\"gl-container\",!0),r._paperdiv.selectAll(\".main-svg\").remove(),r._paperdiv.select(\".modebar-container\").remove(),r._paper=r._paperdiv.insert(\"svg\",\":first-child\").classed(\"main-svg\",!0),r._toppaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),r._modebardiv=r._paperdiv.append(\"div\"),r._hoverpaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),!r._uid){var i={};n.selectAll(\"defs\").each(function(){this.id&&(i[this.id.split(\"-\")[1]]=1)}),r._uid=o.randstr(i)}r._paperdiv.selectAll(\".main-svg\").attr(y.svgAttrs),r._defs=r._paper.append(\"defs\").attr(\"id\",\"defs-\"+r._uid),r._clips=r._defs.append(\"g\").classed(\"clips\",!0),r._topdefs=r._toppaper.append(\"defs\").attr(\"id\",\"topdefs-\"+r._uid),r._topclips=r._topdefs.append(\"g\").classed(\"clips\",!0),r._bgLayer=r._paper.append(\"g\").classed(\"bglayer\",!0),r._draggers=r._paper.append(\"g\").classed(\"draglayer\",!0);var a=r._paper.append(\"g\").classed(\"layer-below\",!0);r._imageLowerLayer=a.append(\"g\").classed(\"imagelayer\",!0),r._shapeLowerLayer=a.append(\"g\").classed(\"shapelayer\",!0),r._cartesianlayer=r._paper.append(\"g\").classed(\"cartesianlayer\",!0),r._polarlayer=r._paper.append(\"g\").classed(\"polarlayer\",!0),r._ternarylayer=r._paper.append(\"g\").classed(\"ternarylayer\",!0),r._geolayer=r._paper.append(\"g\").classed(\"geolayer\",!0),r._funnelarealayer=r._paper.append(\"g\").classed(\"funnelarealayer\",!0),r._pielayer=r._paper.append(\"g\").classed(\"pielayer\",!0),r._sunburstlayer=r._paper.append(\"g\").classed(\"sunburstlayer\",!0),r._indicatorlayer=r._toppaper.append(\"g\").classed(\"indicatorlayer\",!0),r._glimages=r._paper.append(\"g\").classed(\"glimages\",!0);var s=r._toppaper.append(\"g\").classed(\"layer-above\",!0);r._imageUpperLayer=s.append(\"g\").classed(\"imagelayer\",!0),r._shapeUpperLayer=s.append(\"g\").classed(\"shapelayer\",!0),r._infolayer=r._toppaper.append(\"g\").classed(\"infolayer\",!0),r._menulayer=r._toppaper.append(\"g\").classed(\"menulayer\",!0),r._zoomlayer=r._toppaper.append(\"g\").classed(\"zoomlayer\",!0),r._hoverlayer=r._hoverpaper.append(\"g\").classed(\"hoverlayer\",!0),r._modebardiv.classed(\"modebar-container\",!0).style(\"position\",\"absolute\").style(\"top\",\"0px\").style(\"right\",\"0px\"),t.emit(\"plotly_framework\")}r.animate=function(t,e,r){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before animating it. For more details, see https://plot.ly/javascript/animations/\");var n=t._transitionData;n._frameQueue||(n._frameQueue=[]);var i=(r=f.supplyAnimationDefaults(r)).transition,a=r.frame;function s(t){return Array.isArray(i)?t>=i.length?i[0]:i[t]:i}function l(t){return Array.isArray(a)?t>=a.length?a[0]:a[t]:a}function c(t,e){var r=0;return function(){if(t&&++r===e)return t()}}return void 0===n._frameWaitingCnt&&(n._frameWaitingCnt=0),new Promise(function(a,u){function h(){n._currentFrame&&n._currentFrame.onComplete&&n._currentFrame.onComplete();var e=n._currentFrame=n._frameQueue.shift();if(e){var r=e.name?e.name.toString():null;t._fullLayout._currentFrame=r,n._lastFrameAt=Date.now(),n._timeToNext=e.frameOpts.duration,f.transition(t,e.frame.data,e.frame.layout,k.coerceTraceIndices(t,e.frame.traces),e.frameOpts,e.transitionOpts).then(function(){e.onComplete&&e.onComplete()}),t.emit(\"plotly_animatingframe\",{name:r,frame:e.frame,animation:{frame:e.frameOpts,transition:e.transitionOpts}})}else t.emit(\"plotly_animated\"),window.cancelAnimationFrame(n._animationRaf),n._animationRaf=null}function p(){t.emit(\"plotly_animating\"),n._lastFrameAt=-1/0,n._timeToNext=0,n._runningTransitions=0,n._currentFrame=null;var e=function(){n._animationRaf=window.requestAnimationFrame(e),Date.now()-n._lastFrameAt>n._timeToNext&&h()};e()}var d,g,v=0;function m(t){return Array.isArray(i)?v>=i.length?t.transitionOpts=i[v]:t.transitionOpts=i[0]:t.transitionOpts=i,v++,t}var y=[],x=null==e,b=Array.isArray(e);if(x||b||!o.isPlainObject(e)){if(x||-1!==[\"string\",\"number\"].indexOf(typeof e))for(d=0;d<n._frames.length;d++)(g=n._frames[d])&&(x||String(g.group)===String(e))&&y.push({type:\"byname\",name:String(g.name),data:m({name:g.name})});else if(b)for(d=0;d<e.length;d++){var _=e[d];-1!==[\"number\",\"string\"].indexOf(typeof _)?(_=String(_),y.push({type:\"byname\",name:_,data:m({name:_})})):o.isPlainObject(_)&&y.push({type:\"object\",data:m(o.extendFlat({},_))})}}else y.push({type:\"object\",data:m(o.extendFlat({},e))});for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&!n._frameHash[g.data.name])return o.warn('animate failure: frame not found: \"'+g.data.name+'\"'),void u();-1!==[\"next\",\"immediate\"].indexOf(r.mode)&&function(){if(0!==n._frameQueue.length){for(;n._frameQueue.length;){var e=n._frameQueue.pop();e.onInterrupt&&e.onInterrupt()}t.emit(\"plotly_animationinterrupted\",[])}}(),\"reverse\"===r.direction&&y.reverse();var w=t._fullLayout._currentFrame;if(w&&r.fromcurrent){var T=-1;for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&g.name===w){T=d;break}if(T>0&&T<y.length-1){var A=[];for(d=0;d<y.length;d++)g=y[d],(\"byname\"!==y[d].type||d>T)&&A.push(g);y=A}}y.length>0?function(e){if(0!==e.length){for(var i=0;i<e.length;i++){var o;o=\"byname\"===e[i].type?f.computeFrame(t,e[i].name):e[i].data;var h=l(i),d=s(i);d.duration=Math.min(d.duration,h.duration);var g={frame:o,name:e[i].name,frameOpts:h,transitionOpts:d};i===e.length-1&&(g.onComplete=c(a,2),g.onInterrupt=u),n._frameQueue.push(g)}\"immediate\"===r.mode&&(n._lastFrameAt=-1/0),n._animationRaf||p()}}(y):(t.emit(\"plotly_animated\"),a())})},r.addFrames=function(t,e,r){if(t=o.getGraphDiv(t),null==e)return Promise.resolve();if(!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before adding frames. For more details, see https://plot.ly/javascript/animations/\");var n,i,a,s,l=t._transitionData._frames,u=t._transitionData._frameHash;if(!Array.isArray(e))throw new Error(\"addFrames failure: frameList must be an Array of frame definitions\"+e);var h=l.length+2*e.length,p=[],d={};for(n=e.length-1;n>=0;n--)if(o.isPlainObject(e[n])){var g=e[n].name,v=(u[g]||d[g]||{}).name,m=e[n].name,y=u[v]||d[v];v&&m&&\"number\"==typeof m&&y&&S<E&&(S++,o.warn('addFrames: overwriting frame \"'+(u[v]||d[v]).name+'\" with a frame whose name of type \"number\" also equates to \"'+v+'\". This is valid but may potentially lead to unexpected behavior since all plotly.js frame names are stored internally as strings.'),S===E&&o.warn(\"addFrames: This API call has yielded too many of these warnings. For the rest of this call, further warnings about numeric frame names will be suppressed.\")),d[g]={name:g},p.push({frame:f.supplyFrameDefaults(e[n]),index:r&&void 0!==r[n]&&null!==r[n]?r[n]:h+n})}p.sort(function(t,e){return t.index>e.index?-1:t.index<e.index?1:0});var x=[],b=[],_=l.length;for(n=p.length-1;n>=0;n--){if(\"number\"==typeof(i=p[n].frame).name&&o.warn(\"Warning: addFrames accepts frames with numeric names, but the numbers areimplicitly cast to strings\"),!i.name)for(;u[i.name=\"frame \"+t._transitionData._counter++];);if(u[i.name]){for(a=0;a<l.length&&(l[a]||{}).name!==i.name;a++);x.push({type:\"replace\",index:a,value:i}),b.unshift({type:\"replace\",index:a,value:l[a]})}else s=Math.max(0,Math.min(p[n].index,_)),x.push({type:\"insert\",index:s,value:i}),b.unshift({type:\"delete\",index:s}),_++}var w=f.modifyFrames,k=f.modifyFrames,T=[t,b],A=[t,x];return c&&c.add(t,w,T,k,A),f.modifyFrames(t,x)},r.deleteFrames=function(t,e){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);var r,n,i=t._transitionData._frames,a=[],s=[];if(!e)for(e=[],r=0;r<i.length;r++)e.push(r);for((e=e.slice()).sort(),r=e.length-1;r>=0;r--)n=e[r],a.push({type:\"delete\",index:n}),s.unshift({type:\"insert\",index:n,value:i[n]});var l=f.modifyFrames,u=f.modifyFrames,h=[t,s],p=[t,a];return c&&c.add(t,l,h,u,p),f.modifyFrames(t,a)},r.addTraces=function t(e,n,i){e=o.getGraphDiv(e);var a,s,l=[],u=r.deleteTraces,h=t,f=[e,l],p=[e,n];for(function(t,e,r){var n,i;if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"traces must be defined.\");for(Array.isArray(e)||(e=[e]),n=0;n<e.length;n++)if(\"object\"!=typeof(i=e[n])||Array.isArray(i)||null===i)throw new Error(\"all values in traces array must be non-array objects\");if(\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&r.length!==e.length)throw new Error(\"if indices is specified, traces.length must equal indices.length\")}(e,n,i),Array.isArray(n)||(n=[n]),n=n.map(function(t){return o.extendFlat({},t)}),k.cleanData(n),a=0;a<n.length;a++)e.data.push(n[a]);for(a=0;a<n.length;a++)l.push(-n.length+a);if(\"undefined\"==typeof i)return s=r.redraw(e),c.add(e,u,f,h,p),s;Array.isArray(i)||(i=[i]);try{D(e,l,i)}catch(t){throw e.data.splice(e.data.length-n.length,n.length),t}return c.startSequence(e),c.add(e,u,f,h,p),s=r.moveTraces(e,l,i),c.stopSequence(e),s},r.deleteTraces=function t(e,n){e=o.getGraphDiv(e);var i,a,s=[],l=r.addTraces,u=t,h=[e,s,n],f=[e,n];if(\"undefined\"==typeof n)throw new Error(\"indices must be an integer or array of integers.\");for(Array.isArray(n)||(n=[n]),I(e,n,\"indices\"),(n=z(n,e.data.length-1)).sort(o.sorterDes),i=0;i<n.length;i+=1)a=e.data.splice(n[i],1)[0],s.push(a);var p=r.redraw(e);return c.add(e,l,h,u,f),p},r.extendTraces=function t(e,n,i,a){var s=R(e=o.getGraphDiv(e),n,i,a,function(t,e,r){var n,i;if(o.isTypedArray(t))if(r<0){var a=new t.constructor(0),s=F(t,e);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(l)),i.set(t),i.set(e.subarray(0,l),t.length)}else{var c=r-e.length,u=t.length-c;n.set(t.subarray(u)),n.set(e,c),i.set(t.subarray(0,u))}else n=t.concat(e),i=r>=0&&r<n.length?n.splice(0,n.length-r):[];return[n,i]}),l=r.redraw(e),u=[e,s.update,i,s.maxPoints];return c.add(e,r.prependTraces,u,t,arguments),l},r.moveTraces=function t(e,n,i){var a,s=[],l=[],u=t,h=t,f=[e=o.getGraphDiv(e),i,n],p=[e,n,i];if(D(e,n,i),n=Array.isArray(n)?n:[n],\"undefined\"==typeof i)for(i=[],a=0;a<n.length;a++)i.push(-n.length+a);for(i=Array.isArray(i)?i:[i],n=z(n,e.data.length-1),i=z(i,e.data.length-1),a=0;a<e.data.length;a++)-1===n.indexOf(a)&&s.push(e.data[a]);for(a=0;a<n.length;a++)l.push({newIndex:i[a],trace:e.data[n[a]]});for(l.sort(function(t,e){return t.newIndex-e.newIndex}),a=0;a<l.length;a+=1)s.splice(l[a].newIndex,0,l[a].trace);e.data=s;var d=r.redraw(e);return c.add(e,u,f,h,p),d},r.prependTraces=function t(e,n,i,a){var s=R(e=o.getGraphDiv(e),n,i,a,function(t,e,r){var n,i;if(o.isTypedArray(t))if(r<=0){var a=new t.constructor(0),s=F(e,t);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(0,l)),i.set(e.subarray(l)),i.set(t,l)}else{var c=r-e.length;n.set(e),n.set(t.subarray(0,c),e.length),i.set(t.subarray(c))}else n=e.concat(t),i=r>=0&&r<n.length?n.splice(r,n.length):[];return[n,i]}),l=r.redraw(e),u=[e,s.update,i,s.maxPoints];return c.add(e,r.extendTraces,u,t,arguments),l},r.newPlot=function(t,e,n,i){return t=o.getGraphDiv(t),f.cleanPlot([],{},t._fullData||[],t._fullLayout||{}),f.purge(t),r.plot(t,e,n,i)},r.plot=function(t,e,i,a){var s;if(t=o.getGraphDiv(t),l.init(t),o.isPlainObject(e)){var c=e;e=c.data,i=c.layout,a=c.config,s=c.frames}if(!1===l.triggerHandler(t,\"plotly_beforeplot\",[e,i,a]))return Promise.reject();e||i||o.isPlotDiv(t)||o.warn(\"Calling Plotly.plot as if redrawing but this container doesn't yet have a plot.\",t),O(t,a),i||(i={}),n.select(t).classed(\"js-plotly-plot\",!0),g.makeTester(),Array.isArray(t._promises)||(t._promises=[]);var h=0===(t.data||[]).length&&Array.isArray(e);Array.isArray(e)&&(k.cleanData(e),h?t.data=e:t.data.push.apply(t.data,e),t.empty=!1),t.layout&&!h||(t.layout=k.cleanLayout(i)),f.supplyDefaults(t);var v=t._fullLayout,y=v._has(\"cartesian\");if(!v._has(\"polar\")&&e&&e[0]&&e[0].r)return o.log(\"Legacy polar charts are deprecated!\"),function(t,e,r){var i=n.select(t).selectAll(\".plot-container\").data([0]);i.enter().insert(\"div\",\":first-child\").classed(\"plot-container plotly\",!0);var a=i.selectAll(\".svg-container\").data([0]);a.enter().append(\"div\").classed(\"svg-container\",!0).style(\"position\",\"relative\"),a.html(\"\"),e&&(t.data=e),r&&(t.layout=r),p.manager.fillLayout(t),a.style({width:t._fullLayout.width+\"px\",height:t._fullLayout.height+\"px\"}),t.framework=p.manager.framework(t),t.framework({data:t.data,layout:t.layout},a.node()),t.framework.setUndoPoint();var s=t.framework.svg(),l=1,c=t._fullLayout.title?t._fullLayout.title.text:\"\";\"\"!==c&&c||(l=0);var u=function(){this.call(x.convertToTspans,t)},h=s.select(\".title-group text\").call(u);if(t._context.edits.titleText){var d=o._(t,\"Click to enter Plot title\");c&&c!==d||(l=.2,h.attr({\"data-unformatted\":d}).text(d).style({opacity:l}).on(\"mouseover.opacity\",function(){n.select(this).transition().duration(100).style(\"opacity\",1)}).on(\"mouseout.opacity\",function(){n.select(this).transition().duration(1e3).style(\"opacity\",0)}));var g=function(){this.call(x.makeEditable,{gd:t}).on(\"edit\",function(e){t.framework({layout:{title:{text:e}}}),this.text(e).call(u),this.call(g)}).on(\"cancel\",function(){var t=this.attr(\"data-unformatted\");this.text(t).call(u)})};h.call(g)}return t._context.setBackground(t,t._fullLayout.paper_bgcolor),f.addLinks(t),Promise.resolve()}(t,e,i);v._replotting=!0,h&&lt(t),t.framework!==lt&&(t.framework=lt,lt(t)),g.initGradients(t),h&&d.saveShowSpikeInitial(t);var b=!t.calcdata||t.calcdata.length!==(t._fullData||[]).length;b&&f.doCalcdata(t);for(var _=0;_<t.calcdata.length;_++)t.calcdata[_][0].trace=t._fullData[_];t._context.responsive?t._responsiveChartHandler||(t._responsiveChartHandler=function(){o.isHidden(t)||f.resize(t)},window.addEventListener(\"resize\",t._responsiveChartHandler)):o.clearResponsive(t);var w=o.extendFlat({},v._size),A=0;function M(){return f.clearAutoMarginIds(t),T.drawMarginPushers(t),d.allowAutoMargin(t),f.doAutoMargin(t),f.previousPromises(t)}function S(){t._transitioning||(T.doAutoRangeAndConstraints(t),h&&d.saveRangeInitial(t),u.getComponentMethod(\"rangeslider\",\"calcAutorange\")(t))}var E=[f.previousPromises,function(){if(s)return r.addFrames(t,s)},function e(){for(var r=v._basePlotModules,n=0;n<r.length;n++)r[n].drawFramework&&r[n].drawFramework(t);if(!v._glcanvas&&v._has(\"gl\")&&(v._glcanvas=v._glcontainer.selectAll(\".gl-canvas\").data([{key:\"contextLayer\",context:!0,pick:!1},{key:\"focusLayer\",context:!1,pick:!1},{key:\"pickLayer\",context:!1,pick:!0}],function(t){return t.key}),v._glcanvas.enter().append(\"canvas\").attr(\"class\",function(t){return\"gl-canvas gl-canvas-\"+t.key.replace(\"Layer\",\"\")}).style({position:\"absolute\",top:0,left:0,overflow:\"visible\",\"pointer-events\":\"none\"})),v._glcanvas){v._glcanvas.attr(\"width\",v.width).attr(\"height\",v.height);var i=v._glcanvas.data()[0].regl;if(i&&(Math.floor(v.width)!==i._gl.drawingBufferWidth||Math.floor(v.height)!==i._gl.drawingBufferHeight)){var a=\"WebGL context buffer and canvas dimensions do not match due to browser/WebGL bug.\";if(!A)return o.log(a+\" Clearing graph and plotting again.\"),f.cleanPlot([],{},t._fullData,v),f.supplyDefaults(t),v=t._fullLayout,f.doCalcdata(t),A++,e();o.error(a)}}return\"h\"===v.modebar.orientation?v._modebardiv.style(\"height\",null).style(\"width\",\"100%\"):v._modebardiv.style(\"width\",null).style(\"height\",v.height+\"px\"),f.previousPromises(t)},M,function(){if(f.didMarginChange(w,v._size))return o.syncOrAsync([M,T.layoutStyles],t)}];y&&E.push(function(){if(b)return o.syncOrAsync([u.getComponentMethod(\"shapes\",\"calcAutorange\"),u.getComponentMethod(\"annotations\",\"calcAutorange\"),S],t);S()}),E.push(T.layoutStyles),y&&E.push(function(){return d.draw(t,h?\"\":\"redraw\")}),E.push(T.drawData,T.finalDraw,m,f.addLinks,f.rehover,f.redrag,f.doAutoMargin,f.previousPromises);var L=o.syncOrAsync(E,t);return L&&L.then||(L=Promise.resolve()),L.then(function(){return C(t),t})},r.purge=function(t){var e=(t=o.getGraphDiv(t))._fullLayout||{},r=t._fullData||[];return f.cleanPlot([],{},r,e),f.purge(t),l.purge(t),e._container&&e._container.remove(),delete t._context,t},r.react=function(t,e,n,i){var a,l,c=(t=o.getGraphDiv(t))._fullData,p=t._fullLayout;if(o.isPlotDiv(t)&&c&&p){if(o.isPlainObject(e)){var d=e;e=d.data,n=d.layout,i=d.config,a=d.frames}var g=!1;if(i){var v=o.extendDeep({},t._context);t._context=void 0,O(t,i),g=function t(e,r){var n;for(n in e)if(\"_\"!==n.charAt(0)){var i=e[n],a=r[n];if(i!==a)if(o.isPlainObject(i)&&o.isPlainObject(a)){if(t(i,a))return!0}else{if(!Array.isArray(i)||!Array.isArray(a))return!0;if(i.length!==a.length)return!0;for(var s=0;s<i.length;s++)if(i[s]!==a[s]){if(!o.isPlainObject(i[s])||!o.isPlainObject(a[s]))return!0;if(t(i[s],a[s]))return!0}}}}(v,t._context)}t.data=e||[],k.cleanData(t.data),t.layout=n||{},k.cleanLayout(t.layout),function(t,e,r,n){var i,a,l,c,u,h,f,p,d=n._preGUI,g=[],v={};for(i in d){if(u=rt(i,tt)){if(a=u.attr||u.head+\".uirevision\",(c=(l=s(n,a).get())&&nt(a,e))&&c===l&&(null===(h=d[i])&&(h=void 0),ot(p=(f=s(e,i)).get(),h))){void 0===p&&\"autorange\"===i.substr(i.length-9)&&g.push(i.substr(0,i.length-10)),f.set(N(s(n,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i);delete d[i],\"range[\"===i.substr(i.length-8,6)&&(v[i.substr(0,i.length-9)]=1)}for(var m=0;m<g.length;m++){var y=g[m];if(v[y]){var x=s(e,y).get();x&&delete x.autorange}}var b=n._tracePreGUI;for(var _ in b){var w,k=b[_],T=null;for(i in k){if(!T){var A=it(_,r);if(A<0){delete b[_];break}var M=at(_,t,(w=r[A]._fullInput).index);if(M<0){delete b[_];break}T=t[M]}if(u=rt(i,et)){if(u.attr?c=(l=s(n,u.attr).get())&&nt(u.attr,e):(l=w.uirevision,void 0===(c=T.uirevision)&&(c=e.uirevision)),c&&c===l&&(null===(h=k[i])&&(h=void 0),ot(p=(f=s(T,i)).get(),h))){f.set(N(s(w,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i+\" in trace uid \"+_);delete k[i]}}}(t.data,t.layout,c,p),f.supplyDefaults(t,{skipUpdateCalc:!0});var m=t._fullData,y=t._fullLayout,x=void 0===y.datarevision,b=y.transition,_=function(t,e,r,n,i){var a=A.layoutFlags();return a.arrays={},a.rangesAltered={},a.nChanges=0,a.nChangesAnim=0,st(e,r,[],{getValObject:function(t){return h.getLayoutValObject(r,t)},flags:a,immutable:n,transition:i,gd:t}),(a.plot||a.calc)&&(a.layoutReplot=!0),i&&a.nChanges&&a.nChangesAnim&&(a.anim=a.nChanges===a.nChangesAnim?\"all\":\"some\"),a}(t,p,y,x,b),w=_.newDataRevision,M=function(t,e,r,n,i,a){var o=e.length===r.length;if(!i&&!o)return{fullReplot:!0,calc:!0};var s,l,c=A.traceFlags();c.arrays={},c.nChanges=0,c.nChangesAnim=0;var u={getValObject:function(t){var e=h.getTraceValObject(l,t);return!l._module.animatable&&e.anim&&(e.anim=!1),e},flags:c,immutable:n,transition:i,newDataRevision:a,gd:t},p={};for(s=0;s<e.length;s++)if(r[s]){if(l=r[s]._fullInput,f.hasMakesDataTransform(l)&&(l=r[s]),p[l.uid])continue;p[l.uid]=1,st(e[s]._fullInput,l,[],u)}return(c.calc||c.plot)&&(c.fullReplot=!0),i&&c.nChanges&&c.nChangesAnim&&(c.anim=c.nChanges===c.nChangesAnim&&o?\"all\":\"some\"),c}(t,c,m,x,b,w);K(t)&&(_.layoutReplot=!0),M.calc||_.calc?t.calcdata=void 0:f.supplyDefaultsUpdateCalc(t.calcdata,m);var S=[];if(a&&(t._transitionData={},f.createTransitionData(t),S.push(function(){return r.addFrames(t,a)})),y.transition&&!g&&(M.anim||_.anim))f.doCalcdata(t),T.doAutoRangeAndConstraints(t),S.push(function(){return f.transitionFromReact(t,M,_,p)});else if(M.fullReplot||_.layoutReplot||g)t._fullLayout._skipDefaults=!0,S.push(r.plot);else{for(var E in _.arrays){var L=_.arrays[E];if(L.length){var P=u.getComponentMethod(E,\"drawOne\");if(P!==o.noop)for(var z=0;z<L.length;z++)P(t,L[z]);else{var I=u.getComponentMethod(E,\"draw\");if(I===o.noop)throw new Error(\"cannot draw components: \"+E);I(t)}}}S.push(f.previousPromises),M.style&&S.push(T.doTraceStyle),(M.colorbars||_.colorbars)&&S.push(T.doColorBars),_.legend&&S.push(T.doLegend),_.layoutstyle&&S.push(T.layoutStyles),_.axrange&&Y(S),_.ticks&&S.push(T.doTicksRelayout),_.modebar&&S.push(T.doModeBar),_.camera&&S.push(T.doCamera),S.push(C)}S.push(f.rehover,f.redrag),(l=o.syncOrAsync(S,t))&&l.then||(l=Promise.resolve(t))}else l=r.newPlot(t,e,n,i);return l.then(function(){return t.emit(\"plotly_react\",{data:e,layout:n}),t})},r.redraw=function(t){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);return k.cleanData(t.data),k.cleanLayout(t.layout),t.calcdata=void 0,r.plot(t).then(function(){return t.emit(\"plotly_redraw\"),t})},r.relayout=H,r.restyle=B,r.setPlotConfig=function(t){return o.extendFlat(_,t)},r.update=$,r._guiRelayout=Q(H),r._guiRestyle=Q(B),r._guiUpdate=Q($),r._storeDirectGUIEdit=function(t,e,r){for(var n in r)U(n,s(t,n).get(),r[n],e)}},{\"../components/color\":593,\"../components/drawing\":614,\"../constants/xmlns_namespaces\":696,\"../lib\":719,\"../lib/events\":709,\"../lib/queue\":734,\"../lib/svg_text_utils\":743,\"../plots/cartesian/axes\":767,\"../plots/cartesian/constants\":773,\"../plots/cartesian/graph_interact\":776,\"../plots/cartesian/select\":784,\"../plots/plots\":828,\"../plots/polar/legacy\":836,\"../registry\":847,\"./edit_types\":750,\"./helpers\":751,\"./manage_arrays\":753,\"./plot_config\":755,\"./plot_schema\":756,\"./subroutines\":758,d3:163,\"fast-isnumeric\":225,\"has-hover\":410}],755:[function(t,e,r){\"use strict\";var n={staticPlot:{valType:\"boolean\",dflt:!1},plotlyServerURL:{valType:\"string\",dflt:\"https://plot.ly\"},editable:{valType:\"boolean\",dflt:!1},edits:{annotationPosition:{valType:\"boolean\",dflt:!1},annotationTail:{valType:\"boolean\",dflt:!1},annotationText:{valType:\"boolean\",dflt:!1},axisTitleText:{valType:\"boolean\",dflt:!1},colorbarPosition:{valType:\"boolean\",dflt:!1},colorbarTitleText:{valType:\"boolean\",dflt:!1},legendPosition:{valType:\"boolean\",dflt:!1},legendText:{valType:\"boolean\",dflt:!1},shapePosition:{valType:\"boolean\",dflt:!1},titleText:{valType:\"boolean\",dflt:!1}},autosizable:{valType:\"boolean\",dflt:!1},responsive:{valType:\"boolean\",dflt:!1},fillFrame:{valType:\"boolean\",dflt:!1},frameMargins:{valType:\"number\",dflt:0,min:0,max:.5},scrollZoom:{valType:\"flaglist\",flags:[\"cartesian\",\"gl3d\",\"geo\",\"mapbox\"],extras:[!0,!1],dflt:\"gl3d+geo+mapbox\"},doubleClick:{valType:\"enumerated\",values:[!1,\"reset\",\"autosize\",\"reset+autosize\"],dflt:\"reset+autosize\"},doubleClickDelay:{valType:\"number\",dflt:300,min:0},showAxisDragHandles:{valType:\"boolean\",dflt:!0},showAxisRangeEntryBoxes:{valType:\"boolean\",dflt:!0},showTips:{valType:\"boolean\",dflt:!0},showLink:{valType:\"boolean\",dflt:!1},linkText:{valType:\"string\",dflt:\"Edit chart\",noBlank:!0},sendData:{valType:\"boolean\",dflt:!0},showSources:{valType:\"any\",dflt:!1},displayModeBar:{valType:\"enumerated\",values:[\"hover\",!0,!1],dflt:\"hover\"},showSendToCloud:{valType:\"boolean\",dflt:!1},showEditInChartStudio:{valType:\"boolean\",dflt:!1},modeBarButtonsToRemove:{valType:\"any\",dflt:[]},modeBarButtonsToAdd:{valType:\"any\",dflt:[]},modeBarButtons:{valType:\"any\",dflt:!1},toImageButtonOptions:{valType:\"any\",dflt:{}},displaylogo:{valType:\"boolean\",dflt:!0},watermark:{valType:\"boolean\",dflt:!1},plotGlPixelRatio:{valType:\"number\",dflt:2,min:1,max:4},setBackground:{valType:\"any\",dflt:\"transparent\"},topojsonURL:{valType:\"string\",noBlank:!0,dflt:\"https://cdn.plot.ly/\"},mapboxAccessToken:{valType:\"string\",dflt:null},logging:{valType:\"boolean\",dflt:1},queueLength:{valType:\"integer\",min:0,dflt:0},globalTransforms:{valType:\"any\",dflt:[]},locale:{valType:\"string\",dflt:\"en-US\"},locales:{valType:\"any\",dflt:{}}},i={};!function t(e,r){for(var n in e){var i=e[n];i.valType?r[n]=i.dflt:(r[n]||(r[n]={}),t(i,r[n]))}}(n,i),e.exports={configAttributes:n,dfltConfig:i}},{}],756:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=t(\"../plots/attributes\"),o=t(\"../plots/layout_attributes\"),s=t(\"../plots/frame_attributes\"),l=t(\"../plots/animation_attributes\"),c=t(\"./plot_config\").configAttributes,u=t(\"../plots/polar/legacy/area_attributes\"),h=t(\"../plots/polar/legacy/axis_attributes\"),f=t(\"./edit_types\"),p=i.extendFlat,d=i.extendDeepAll,g=i.isPlainObject,v=i.isArrayOrTypedArray,m=i.nestedProperty,y=i.valObjectMeta,x=\"_isSubplotObj\",b=\"_isLinkedToArray\",_=[x,b,\"_arrayAttrRegexps\",\"_deprecated\"];function w(t,e,r){if(!t)return!1;if(t._isLinkedToArray)if(k(e[r]))r++;else if(r<e.length)return!1;for(;r<e.length;r++){var n=t[e[r]];if(!g(n))break;if(t=n,r===e.length-1)break;if(t._isLinkedToArray){if(!k(e[++r]))return!1}else if(\"info_array\"===t.valType){var i=e[++r];if(!k(i))return!1;var a=t.items;if(Array.isArray(a)){if(i>=a.length)return!1;if(2===t.dimensions){if(r++,e.length===r)return t;var o=e[r];if(!k(o))return!1;t=a[i][o]}else t=a[i]}else t=a}}return t}function k(t){return t===Math.round(t)&&t>=0}function T(t){return function(t){r.crawl(t,function(t,e,n){r.isValObject(t)?\"data_array\"===t.valType?(t.role=\"data\",n[e+\"src\"]={valType:\"string\",editType:\"none\"}):!0===t.arrayOk&&(n[e+\"src\"]={valType:\"string\",editType:\"none\"}):g(t)&&(t.role=\"object\")})}(t),function(t){r.crawl(t,function(t,e,r){if(!t)return;var n=t[b];if(!n)return;delete t[b],r[e]={items:{}},r[e].items[n]=t,r[e].role=\"object\"})}(t),function(t){!function t(e){for(var r in e)if(g(e[r]))t(e[r]);else if(Array.isArray(e[r]))for(var n=0;n<e[r].length;n++)t(e[r][n]);else e[r]instanceof RegExp&&(e[r]=e[r].toString())}(t)}(t),t}function A(t,e,r){var n=m(t,r),i=d({},e.layoutAttributes);i[x]=!0,n.set(i)}function M(t,e,r){var n=m(t,r);n.set(d(n.get()||{},e))}r.IS_SUBPLOT_OBJ=x,r.IS_LINKED_TO_ARRAY=b,r.DEPRECATED=\"_deprecated\",r.UNDERSCORE_ATTRS=_,r.get=function(){var t={};n.allTypes.concat(\"area\").forEach(function(e){t[e]=function(t){var e,i;\"area\"===t?(e={attributes:u},i={}):(e=n.modules[t]._module,i=e.basePlotModule);var o={type:null},s=d({},a),l=d({},e.attributes);r.crawl(l,function(t,e,r,n,i){m(s,i).set(void 0),void 0===t&&m(l,i).set(void 0)}),d(o,s),n.traceIs(t,\"noOpacity\")&&delete o.opacity;n.traceIs(t,\"showLegend\")||(delete o.showlegend,delete o.legendgroup);n.traceIs(t,\"noHover\")&&(delete o.hoverinfo,delete o.hoverlabel);e.selectPoints||delete o.selectedpoints;d(o,l),i.attributes&&d(o,i.attributes);o.type=t;var c={meta:e.meta||{},categories:e.categories||{},animatable:Boolean(e.animatable),type:t,attributes:T(o)};if(e.layoutAttributes){var h={};d(h,e.layoutAttributes),c.layoutAttributes=T(h)}e.animatable||r.crawl(c,function(t){r.isValObject(t)&&\"anim\"in t&&delete t.anim});return c}(e)});var e,i={};return Object.keys(n.transformsRegistry).forEach(function(t){i[t]=function(t){var e=n.transformsRegistry[t],r=d({},e.attributes);return Object.keys(n.componentsRegistry).forEach(function(e){var i=n.componentsRegistry[e];i.schema&&i.schema.transforms&&i.schema.transforms[t]&&Object.keys(i.schema.transforms[t]).forEach(function(e){M(r,i.schema.transforms[t][e],e)})}),{attributes:T(r)}}(t)}),{defs:{valObjects:y,metaKeys:_.concat([\"description\",\"role\",\"editType\",\"impliedEdits\"]),editType:{traces:f.traces,layout:f.layout},impliedEdits:{}},traces:t,layout:function(){var t,e,r={};for(t in d(r,o),n.subplotsRegistry)if((e=n.subplotsRegistry[t]).layoutAttributes)if(Array.isArray(e.attr))for(var i=0;i<e.attr.length;i++)A(r,e,e.attr[i]);else{var a=\"subplot\"===e.attr?e.name:e.attr;A(r,e,a)}for(t in r=function(t){return p(t,{radialaxis:h.radialaxis,angularaxis:h.angularaxis}),p(t,h.layout),t}(r),n.componentsRegistry){var s=(e=n.componentsRegistry[t]).schema;if(s&&(s.subplots||s.layout)){var l=s.subplots;if(l&&l.xaxis&&!l.yaxis)for(var c in l.xaxis)delete r.yaxis[c]}else\"colorscale\"===e.name?d(r,e.layoutAttributes):e.layoutAttributes&&M(r,e.layoutAttributes,e.name)}return{layoutAttributes:T(r)}}(),transforms:i,frames:(e={frames:d({},s)},T(e),e.frames),animation:T(l),config:T(c)}},r.crawl=function(t,e,n,i){var a=n||0;i=i||\"\",Object.keys(t).forEach(function(n){var o=t[n];if(-1===_.indexOf(n)){var s=(i?i+\".\":\"\")+n;e(o,n,t,a,s),r.isValObject(o)||g(o)&&\"impliedEdits\"!==n&&r.crawl(o,e,a+1,s)}})},r.isValObject=function(t){return t&&void 0!==t.valType},r.findArrayAttributes=function(t){var e,n,i=[],o=[],s=[];function l(t,r,a,l){o=o.slice(0,l).concat([r]),s=s.slice(0,l).concat([t&&t._isLinkedToArray]),t&&(\"data_array\"===t.valType||!0===t.arrayOk)&&!(\"colorbar\"===o[l-1]&&(\"ticktext\"===r||\"tickvals\"===r))&&function t(e,r,a){var l=e[o[r]];var c=a+o[r];if(r===o.length-1)v(l)&&i.push(n+c);else if(s[r]){if(Array.isArray(l))for(var u=0;u<l.length;u++)g(l[u])&&t(l[u],r+1,c+\"[\"+u+\"].\")}else g(l)&&t(l,r+1,c+\".\")}(e,0,\"\")}e=t,n=\"\",r.crawl(a,l),t._module&&t._module.attributes&&r.crawl(t._module.attributes,l);var c=t.transforms;if(c)for(var u=0;u<c.length;u++){var h=c[u],f=h._module;f&&(n=\"transforms[\"+u+\"].\",e=h,r.crawl(f.attributes,l))}return i},r.getTraceValObject=function(t,e){var r,i,o=e[0],s=1;if(\"transforms\"===o){if(1===e.length)return a.transforms;var l=t.transforms;if(!Array.isArray(l)||!l.length)return!1;var c=e[1];if(!k(c)||c>=l.length)return!1;i=(r=(n.transformsRegistry[l[c].type]||{}).attributes)&&r[e[2]],s=3}else if(\"area\"===t.type)i=u[o];else{var h=t._module;if(h||(h=(n.modules[t.type||a.type.dflt]||{})._module),!h)return!1;if(!(i=(r=h.attributes)&&r[o])){var f=h.basePlotModule;f&&f.attributes&&(i=f.attributes[o])}i||(i=a[o])}return w(i,e,s)},r.getLayoutValObject=function(t,e){return w(function(t,e){var r,i,a,s,l=t._basePlotModules;if(l){var c;for(r=0;r<l.length;r++){if((a=l[r]).attrRegex&&a.attrRegex.test(e)){if(a.layoutAttrOverrides)return a.layoutAttrOverrides;!c&&a.layoutAttributes&&(c=a.layoutAttributes)}var u=a.baseLayoutAttrOverrides;if(u&&e in u)return u[e]}if(c)return c}var f=t._modules;if(f)for(r=0;r<f.length;r++)if((s=f[r].layoutAttributes)&&e in s)return s[e];for(i in n.componentsRegistry){if(\"colorscale\"===(a=n.componentsRegistry[i]).name&&0===e.indexOf(\"coloraxis\"))return a.layoutAttributes[e];if(!a.schema&&e===a.name)return a.layoutAttributes}if(e in o)return o[e];if(\"radialaxis\"===e||\"angularaxis\"===e)return h[e];return h.layout[e]||!1}(t,e[0]),e,1)}},{\"../lib\":719,\"../plots/animation_attributes\":762,\"../plots/attributes\":764,\"../plots/frame_attributes\":794,\"../plots/layout_attributes\":819,\"../plots/polar/legacy/area_attributes\":834,\"../plots/polar/legacy/axis_attributes\":835,\"../registry\":847,\"./edit_types\":750,\"./plot_config\":755}],757:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/attributes\"),a=\"templateitemname\",o={name:{valType:\"string\",editType:\"none\"}};function s(t){return t&&\"string\"==typeof t}function l(t){var e=t.length-1;return\"s\"!==t.charAt(e)&&n.warn(\"bad argument to arrayDefaultKey: \"+t),t.substr(0,t.length-1)+\"defaults\"}o[a]={valType:\"string\",editType:\"calc\"},r.templatedArray=function(t,e){return e._isLinkedToArray=t,e.name=o.name,e[a]=o[a],e},r.traceTemplater=function(t){var e,r,a={};for(e in t)r=t[e],Array.isArray(r)&&r.length&&(a[e]=0);return{newTrace:function(o){var s={type:e=n.coerce(o,{},i,\"type\"),_template:null};if(e in a){r=t[e];var l=a[e]%r.length;a[e]++,s._template=r[l]}return s}}},r.newContainer=function(t,e,r){var i=t._template,a=i&&(i[e]||r&&i[r]);return n.isPlainObject(a)||(a=null),t[e]={_template:a}},r.arrayTemplater=function(t,e,r){var n=t._template,i=n&&n[l(e)],o=n&&n[e];Array.isArray(o)&&o.length||(o=[]);var c={};return{newItem:function(t){var e={name:t.name,_input:t},n=e[a]=t[a];if(!s(n))return e._template=i,e;for(var l=0;l<o.length;l++){var u=o[l];if(u.name===n)return c[n]=1,e._template=u,e}return e[r]=t[r]||!1,e._template=!1,e},defaultItems:function(){for(var t=[],e=0;e<o.length;e++){var r=o[e],n=r.name;if(s(n)&&!c[n]){var i={_template:r,name:n,_input:{_templateitemname:n}};i[a]=r[a],t.push(i),c[n]=1}}return t}}},r.arrayDefaultKey=l,r.arrayEditor=function(t,e,r){var i=(n.nestedProperty(t,e).get()||[]).length,o=r._index,s=o>=i&&(r._input||{})._templateitemname;s&&(o=i);var l,c=e+\"[\"+o+\"]\";function u(){l={},s&&(l[c]={},l[c][a]=s)}function h(t,e){s?n.nestedProperty(l[c],t).set(e):l[c+\".\"+t]=e}function f(){var t=l;return u(),t}return u(),{modifyBase:function(t,e){l[t]=e},modifyItem:h,getUpdateObj:f,applyUpdate:function(e,r){e&&h(e,r);var i=f();for(var a in i)n.nestedProperty(t,a).set(i[a])}}}},{\"../lib\":719,\"../plots/attributes\":764}],758:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../registry\"),a=t(\"../plots/plots\"),o=t(\"../lib\"),s=t(\"../lib/clear_gl_canvases\"),l=t(\"../components/color\"),c=t(\"../components/drawing\"),u=t(\"../components/titles\"),h=t(\"../components/modebar\"),f=t(\"../plots/cartesian/axes\"),p=t(\"../constants/alignment\"),d=t(\"../plots/cartesian/constraints\"),g=d.enforce,v=d.clean,m=t(\"../plots/cartesian/autorange\").doAutoRange,y=\"start\",x=\"middle\",b=\"end\";function _(t,e,r){for(var n=0;n<r.length;n++){var i=r[n][0],a=r[n][1];if(!(i[0]>=t[1]||i[1]<=t[0])&&(a[0]<e[1]&&a[1]>e[0]))return!0}return!1}function w(t){var e,i,a,s,u,d,g=t._fullLayout,v=g._size,m=v.p,y=f.list(t,\"\",!0);if(g._paperdiv.style({width:t._context.responsive&&g.autosize&&!t._context._hasZeroWidth&&!t.layout.width?\"100%\":g.width+\"px\",height:t._context.responsive&&g.autosize&&!t._context._hasZeroHeight&&!t.layout.height?\"100%\":g.height+\"px\"}).selectAll(\".main-svg\").call(c.setSize,g.width,g.height),t._context.setBackground(t,g.paper_bgcolor),r.drawMainTitle(t),h.manage(t),!g._has(\"cartesian\"))return t._promises.length&&Promise.all(t._promises);function x(t,e,r){var n=t._lw/2;return\"x\"===t._id.charAt(0)?e?\"top\"===r?e._offset-m-n:e._offset+e._length+m+n:v.t+v.h*(1-(t.position||0))+n%1:e?\"right\"===r?e._offset+e._length+m+n:e._offset-m-n:v.l+v.w*(t.position||0)+n%1}for(e=0;e<y.length;e++){var b=(s=y[e])._anchorAxis;s._linepositions={},s._lw=c.crispRound(t,s.linewidth,1),s._mainLinePosition=x(s,b,s.side),s._mainMirrorPosition=s.mirror&&b?x(s,b,p.OPPOSITE_SIDE[s.side]):null}var w=[],T=[],M=[],S=1===l.opacity(g.paper_bgcolor)&&1===l.opacity(g.plot_bgcolor)&&g.paper_bgcolor===g.plot_bgcolor;for(i in g._plots)if((a=g._plots[i]).mainplot)a.bg&&a.bg.remove(),a.bg=void 0;else{var E=a.xaxis.domain,C=a.yaxis.domain,L=a.plotgroup;if(_(E,C,M)){var P=L.node(),O=a.bg=o.ensureSingle(L,\"rect\",\"bg\");P.insertBefore(O.node(),P.childNodes[0]),T.push(i)}else L.select(\"rect.bg\").remove(),M.push([E,C]),S||(w.push(i),T.push(i))}var z,I,D,R,F,B,N,j,U,V,q,H,G,Y=g._bgLayer.selectAll(\".bg\").data(w);for(Y.enter().append(\"rect\").classed(\"bg\",!0),Y.exit().remove(),Y.each(function(t){g._plots[t].bg=n.select(this)}),e=0;e<T.length;e++)a=g._plots[T[e]],u=a.xaxis,d=a.yaxis,a.bg&&a.bg.call(c.setRect,u._offset-m,d._offset-m,u._length+2*m,d._length+2*m).call(l.fill,g.plot_bgcolor).style(\"stroke-width\",0);if(!g._hasOnlyLargeSploms)for(i in g._plots){a=g._plots[i],u=a.xaxis,d=a.yaxis;var W,X,Z=a.clipId=\"clip\"+g._uid+i+\"plot\",J=o.ensureSingleById(g._clips,\"clipPath\",Z,function(t){t.classed(\"plotclip\",!0).append(\"rect\")});a.clipRect=J.select(\"rect\").attr({width:u._length,height:d._length}),c.setTranslate(a.plot,u._offset,d._offset),a._hasClipOnAxisFalse?(W=null,X=Z):(W=Z,X=null),c.setClipUrl(a.plot,W,t),a.layerClipId=X}function K(t){return\"M\"+z+\",\"+t+\"H\"+I}function $(t){return\"M\"+u._offset+\",\"+t+\"h\"+u._length}function Q(t){return\"M\"+t+\",\"+j+\"V\"+N}function tt(t){return\"M\"+t+\",\"+d._offset+\"v\"+d._length}function et(t,e,r){if(!t.showline||i!==t._mainSubplot)return\"\";if(!t._anchorAxis)return r(t._mainLinePosition);var n=e(t._mainLinePosition);return t.mirror&&(n+=e(t._mainMirrorPosition)),n}for(i in g._plots){a=g._plots[i],u=a.xaxis,d=a.yaxis;var rt=\"M0,0\";k(u,i)&&(F=A(u,\"left\",d,y),z=u._offset-(F?m+F:0),B=A(u,\"right\",d,y),I=u._offset+u._length+(B?m+B:0),D=x(u,d,\"bottom\"),R=x(u,d,\"top\"),!(G=!u._anchorAxis||i!==u._mainSubplot)||\"allticks\"!==u.mirror&&\"all\"!==u.mirror||(u._linepositions[i]=[D,R]),rt=et(u,K,$),G&&u.showline&&(\"all\"===u.mirror||\"allticks\"===u.mirror)&&(rt+=K(D)+K(R)),a.xlines.style(\"stroke-width\",u._lw+\"px\").call(l.stroke,u.showline?u.linecolor:\"rgba(0,0,0,0)\")),a.xlines.attr(\"d\",rt);var nt=\"M0,0\";k(d,i)&&(q=A(d,\"bottom\",u,y),N=d._offset+d._length+(q?m:0),H=A(d,\"top\",u,y),j=d._offset-(H?m:0),U=x(d,u,\"left\"),V=x(d,u,\"right\"),!(G=!d._anchorAxis||i!==d._mainSubplot)||\"allticks\"!==d.mirror&&\"all\"!==d.mirror||(d._linepositions[i]=[U,V]),nt=et(d,Q,tt),G&&d.showline&&(\"all\"===d.mirror||\"allticks\"===d.mirror)&&(nt+=Q(U)+Q(V)),a.ylines.style(\"stroke-width\",d._lw+\"px\").call(l.stroke,d.showline?d.linecolor:\"rgba(0,0,0,0)\")),a.ylines.attr(\"d\",nt)}return f.makeClipPaths(t),t._promises.length&&Promise.all(t._promises)}function k(t,e){return(t.ticks||t.showline)&&(e===t._mainSubplot||\"all\"===t.mirror||\"allticks\"===t.mirror)}function T(t,e,r){if(!r.showline||!r._lw)return!1;if(\"all\"===r.mirror||\"allticks\"===r.mirror)return!0;var n=r._anchorAxis;if(!n)return!1;var i=p.FROM_BL[e];return r.side===e?n.domain[i]===t.domain[i]:r.mirror&&n.domain[1-i]===t.domain[1-i]}function A(t,e,r,n){if(T(t,e,r))return r._lw;for(var i=0;i<n.length;i++){var a=n[i];if(a._mainAxis===r._mainAxis&&T(t,e,a))return a._lw}return 0}r.layoutStyles=function(t){return o.syncOrAsync([a.doAutoMargin,w],t)},r.drawMainTitle=function(t){var e=t._fullLayout,r=function(t){var e=t.title,r=x;o.isRightAnchor(e)?r=b:o.isLeftAnchor(e)&&(r=y);return r}(e),n=function(t){var e=t.title,r=\"0em\";o.isTopAnchor(e)?r=p.CAP_SHIFT+\"em\":o.isMiddleAnchor(e)&&(r=p.MID_SHIFT+\"em\");return r}(e);u.draw(t,\"gtitle\",{propContainer:e,propName:\"title.text\",placeholder:e._dfltTitle.plot,attributes:{x:function(t,e){var r=t.title,n=t._size,i=0;e===y?i=r.pad.l:e===b&&(i=-r.pad.r);switch(r.xref){case\"paper\":return n.l+n.w*r.x+i;case\"container\":default:return t.width*r.x+i}}(e,r),y:function(t,e){var r=t.title,n=t._size,i=0;\"0em\"!==e&&e?e===p.CAP_SHIFT+\"em\"&&(i=r.pad.t):i=-r.pad.b;if(\"auto\"===r.y)return n.t/2;switch(r.yref){case\"paper\":return n.t+n.h-n.h*r.y+i;case\"container\":default:return t.height-t.height*r.y+i}}(e,n),\"text-anchor\":r,dy:n}})},r.doTraceStyle=function(t){var e,n=t.calcdata,o=[];for(e=0;e<n.length;e++){var l=n[e],c=l[0]||{},u=c.trace||{},h=u._module||{},f=h.arraysToCalcdata;f&&f(l,u);var p=h.editStyle;p&&o.push({fn:p,cd0:c})}if(o.length){for(e=0;e<o.length;e++){var d=o[e];d.fn(t,d.cd0)}s(t),r.redrawReglTraces(t)}return a.style(t),i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doColorBars=function(t){return i.getComponentMethod(\"colorbar\",\"draw\")(t),a.previousPromises(t)},r.layoutReplot=function(t){var e=t.layout;return t.layout=void 0,i.call(\"plot\",t,\"\",e)},r.doLegend=function(t){return i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doTicksRelayout=function(t){return f.draw(t,\"redraw\"),t._fullLayout._hasOnlyLargeSploms&&(i.subplotsRegistry.splom.updateGrid(t),s(t),r.redrawReglTraces(t)),r.drawMainTitle(t),a.previousPromises(t)},r.doModeBar=function(t){var e=t._fullLayout;h.manage(t);for(var r=0;r<e._basePlotModules.length;r++){var n=e._basePlotModules[r].updateFx;n&&n(t)}return a.previousPromises(t)},r.doCamera=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){var i=e[r[n]],a=i._scene,o=i.camera;a.setCamera(o)}},r.drawData=function(t){var e=t._fullLayout;s(t);for(var n=e._basePlotModules,o=0;o<n.length;o++)n[o].plot(t);return r.redrawReglTraces(t),a.style(t),i.getComponentMethod(\"shapes\",\"draw\")(t),i.getComponentMethod(\"annotations\",\"draw\")(t),e._replotting=!1,a.previousPromises(t)},r.redrawReglTraces=function(t){var e=t._fullLayout;if(e._has(\"regl\")){var r,n,i=t._fullData,a=[],s=[];for(e._hasOnlyLargeSploms&&e._splomGrid.draw(),r=0;r<i.length;r++){var l=i[r];!0===l.visible&&0!==l._length&&(\"splom\"===l.type?e._splomScenes[l.uid].draw():\"scattergl\"===l.type?o.pushUnique(a,l.xaxis+l.yaxis):\"scatterpolargl\"===l.type&&o.pushUnique(s,l.subplot))}for(r=0;r<a.length;r++)(n=e._plots[a[r]])._scene&&n._scene.draw();for(r=0;r<s.length;r++)(n=e[s[r]]._subplot)._scene&&n._scene.draw()}},r.doAutoRangeAndConstraints=function(t){for(var e,r,n=t._fullLayout,i=f.list(t,\"\",!0),a=n._axisMatchGroups||[],s=0;s<i.length;s++)e=i[s],v(t,e),m(t,e);g(t);t:for(var l=0;l<a.length;l++){var c,u=a[l],h=null;for(c in u){if(!1===(e=f.getFromId(t,c)).autorange)continue t;r=o.simpleMap(e.range,e.r2l),h?h[0]<h[1]?(h[0]=Math.min(h[0],r[0]),h[1]=Math.max(h[1],r[1])):(h[0]=Math.max(h[0],r[0]),h[1]=Math.min(h[1],r[1])):h=r}for(c in u)(e=f.getFromId(t,c)).range=o.simpleMap(h,e.l2r),e._input.range=e.range.slice(),e.setScale()}},r.finalDraw=function(t){i.getComponentMethod(\"shapes\",\"draw\")(t),i.getComponentMethod(\"images\",\"draw\")(t),i.getComponentMethod(\"annotations\",\"draw\")(t),i.getComponentMethod(\"rangeslider\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t)},r.drawMarginPushers=function(t){i.getComponentMethod(\"legend\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t),i.getComponentMethod(\"sliders\",\"draw\")(t),i.getComponentMethod(\"updatemenus\",\"draw\")(t),i.getComponentMethod(\"colorbar\",\"draw\")(t)}},{\"../components/color\":593,\"../components/drawing\":614,\"../components/modebar\":652,\"../components/titles\":681,\"../constants/alignment\":688,\"../lib\":719,\"../lib/clear_gl_canvases\":704,\"../plots/cartesian/autorange\":766,\"../plots/cartesian/axes\":767,\"../plots/cartesian/constraints\":774,\"../plots/plots\":828,\"../registry\":847,d3:163}],759:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.isPlainObject,a=t(\"./plot_schema\"),o=t(\"../plots/plots\"),s=t(\"../plots/attributes\"),l=t(\"./plot_template\"),c=t(\"./plot_config\").dfltConfig;function u(t,e){t=n.extendDeep({},t);var r,a,o=Object.keys(t).sort();function s(e,r,n){if(i(r)&&i(e))u(e,r);else if(Array.isArray(r)&&Array.isArray(e)){var o=l.arrayTemplater({_template:t},n);for(a=0;a<r.length;a++){var s=r[a],c=o.newItem(s)._template;c&&u(c,s)}var h=o.defaultItems();for(a=0;a<h.length;a++)r.push(h[a]._template);for(a=0;a<r.length;a++)delete r[a].templateitemname}}for(r=0;r<o.length;r++){var c=o[r],f=t[c];if(c in e?s(f,e[c],c):e[c]=f,h(c)===c)for(var p in e){var d=h(p);p===d||d!==c||p in t||s(f,e[p],c)}}}function h(t){return t.replace(/[0-9]+$/,\"\")}function f(t,e,r,a,o){var s=o&&r(o);for(var c in t){var u=t[c],d=p(t,c,a),g=p(t,c,o),v=r(g);if(!v){var m=h(c);m!==c&&(v=r(g=p(t,m,o)))}if((!s||s!==v)&&!(!v||v._noTemplating||\"data_array\"===v.valType||v.arrayOk&&Array.isArray(u)))if(!v.valType&&i(u))f(u,e,r,d,g);else if(v._isLinkedToArray&&Array.isArray(u))for(var y=!1,x=0,b={},_=0;_<u.length;_++){var w=u[_];if(i(w)){var k=w.name;if(k)b[k]||(f(w,e,r,p(u,x,d),p(u,x,g)),x++,b[k]=1);else if(!y){var T=p(t,l.arrayDefaultKey(c),a),A=p(u,x,d);f(w,e,r,A,p(u,x,g));var M=n.nestedProperty(e,A);n.nestedProperty(e,T).set(M.get()),M.set(null),y=!0}}}else{n.nestedProperty(e,d).set(u)}}}function p(t,e,r){return r?Array.isArray(t)?r+\"[\"+e+\"]\":r+\".\"+e:e}function d(t){for(var e=0;e<t.length;e++)if(i(t[e]))return!0}function g(t){var e;switch(t.code){case\"data\":e=\"The template has no key data.\";break;case\"layout\":e=\"The template has no key layout.\";break;case\"missing\":e=t.path?\"There are no templates for item \"+t.path+\" with name \"+t.templateitemname:\"There are no templates for trace \"+t.index+\", of type \"+t.traceType+\".\";break;case\"unused\":e=t.path?\"The template item at \"+t.path+\" was not used in constructing the plot.\":t.dataCount?\"Some of the templates of type \"+t.traceType+\" were not used. The template has \"+t.templateCount+\" traces, the data only has \"+t.dataCount+\" of this type.\":\"The template has \"+t.templateCount+\" traces of type \"+t.traceType+\" but there are none in the data.\";break;case\"reused\":e=\"Some of the templates of type \"+t.traceType+\" were used more than once. The template has \"+t.templateCount+\" traces, the data has \"+t.dataCount+\" of this type.\"}return t.msg=e,t}r.makeTemplate=function(t){t=n.isPlainObject(t)?t:n.getGraphDiv(t),t=n.extendDeep({_context:c},{data:t.data,layout:t.layout}),o.supplyDefaults(t);var e=t.data||[],r=t.layout||{};r._basePlotModules=t._fullLayout._basePlotModules,r._modules=t._fullLayout._modules;var l={data:{},layout:{}};e.forEach(function(t){var e={};f(t,e,function(t,e){return a.getTraceValObject(t,n.nestedProperty({},e).parts)}.bind(null,t));var r=n.coerce(t,{},s,\"type\"),i=l.data[r];i||(i=l.data[r]=[]),i.push(e)}),f(r,l.layout,function(t,e){return a.getLayoutValObject(t,n.nestedProperty({},e).parts)}.bind(null,r)),delete l.layout.template;var h=r.template;if(i(h)){var p,d,g,v,m,y,x=h.layout;i(x)&&u(x,l.layout);var b=h.data;if(i(b)){for(d in l.data)if(g=b[d],Array.isArray(g)){for(y=(m=l.data[d]).length,v=g.length,p=0;p<y;p++)u(g[p%v],m[p]);for(p=y;p<v;p++)m.push(n.extendDeep({},g[p]))}for(d in b)d in l.data||(l.data[d]=n.extendDeep([],b[d]))}}return l},r.validateTemplate=function(t,e){var r=n.extendDeep({},{_context:c,data:t.data,layout:t.layout}),a=r.layout||{};i(e)||(e=a.template||{});var s=e.layout,l=e.data,u=[];r.layout=a,r.layout.template=e,o.supplyDefaults(r);var f=r._fullLayout,v=r._fullData,m={};if(i(s)?(!function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)&&i(e[n])){var a,o=h(n),s=[];for(a=0;a<r.length;a++)s.push(p(e,n,r[a])),o!==n&&s.push(p(e,o,r[a]));for(a=0;a<s.length;a++)m[s[a]]=1;t(e[n],s)}}(f,[\"layout\"]),function t(e,r){for(var n in e)if(-1===n.indexOf(\"defaults\")&&i(e[n])){var a=p(e,n,r);m[a]?t(e[n],a):u.push({code:\"unused\",path:a})}}(s,\"layout\")):u.push({code:\"layout\"}),i(l)){for(var y,x={},b=0;b<v.length;b++){var _=v[b];x[y=_.type]=(x[y]||0)+1,_._fullInput._template||u.push({code:\"missing\",index:_._fullInput.index,traceType:y})}for(y in l){var w=l[y].length,k=x[y]||0;w>k?u.push({code:\"unused\",traceType:y,templateCount:w,dataCount:k}):k>w&&u.push({code:\"reused\",traceType:y,templateCount:w,dataCount:k})}}else u.push({code:\"data\"});if(function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)){var a=e[n],o=p(e,n,r);i(a)?(Array.isArray(e)&&!1===a._template&&a.templateitemname&&u.push({code:\"missing\",path:o,templateitemname:a.templateitemname}),t(a,o)):Array.isArray(a)&&d(a)&&t(a,o)}}({data:v,layout:f},\"\"),u.length)return u.map(g)}},{\"../lib\":719,\"../plots/attributes\":764,\"../plots/plots\":828,\"./plot_config\":755,\"./plot_schema\":756,\"./plot_template\":757}],760:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./plot_api\"),a=t(\"../lib\"),o=t(\"../snapshot/helpers\"),s=t(\"../snapshot/tosvg\"),l=t(\"../snapshot/svgtoimg\"),c={format:{valType:\"enumerated\",values:[\"png\",\"jpeg\",\"webp\",\"svg\"],dflt:\"png\"},width:{valType:\"number\",min:1},height:{valType:\"number\",min:1},scale:{valType:\"number\",min:0,dflt:1},setBackground:{valType:\"any\",dflt:!1},imageDataOnly:{valType:\"boolean\",dflt:!1}};e.exports=function(t,e){var r,u,h,f;function p(t){return!(t in e)||a.validate(e[t],c[t])}if(e=e||{},a.isPlainObject(t)?(r=t.data||[],u=t.layout||{},h=t.config||{},f={}):(t=a.getGraphDiv(t),r=a.extendDeep([],t.data),u=a.extendDeep({},t.layout),h=t._context,f=t._fullLayout||{}),!p(\"width\")&&null!==e.width||!p(\"height\")&&null!==e.height)throw new Error(\"Height and width should be pixel values.\");if(!p(\"format\"))throw new Error(\"Image format is not jpeg, png, svg or webp.\");var d={};function g(t,r){return a.coerce(e,d,c,t,r)}var v=g(\"format\"),m=g(\"width\"),y=g(\"height\"),x=g(\"scale\"),b=g(\"setBackground\"),_=g(\"imageDataOnly\"),w=document.createElement(\"div\");w.style.position=\"absolute\",w.style.left=\"-5000px\",document.body.appendChild(w);var k=a.extendFlat({},u);m?k.width=m:null===e.width&&n(f.width)&&(k.width=f.width),y?k.height=y:null===e.height&&n(f.height)&&(k.height=f.height);var T=a.extendFlat({},h,{_exportedPlot:!0,staticPlot:!0,setBackground:b}),A=o.getRedrawFunc(w);function M(){return new Promise(function(t){setTimeout(t,o.getDelay(w._fullLayout))})}function S(){return new Promise(function(t,e){var r=s(w,v,x),n=w._fullLayout.width,c=w._fullLayout.height;if(i.purge(w),document.body.removeChild(w),\"svg\"===v)return t(_?r:o.encodeSVG(r));var u=document.createElement(\"canvas\");u.id=a.randstr(),l({format:v,width:n,height:c,scale:x,canvas:u,svg:r,promise:!0}).then(t).catch(e)})}return new Promise(function(t,e){i.plot(w,r,k,T).then(A).then(M).then(S).then(function(e){t(function(t){return _?t.replace(o.IMAGE_URL_PREFIX,\"\"):t}(e))}).catch(function(t){e(t)})})}},{\"../lib\":719,\"../snapshot/helpers\":851,\"../snapshot/svgtoimg\":853,\"../snapshot/tosvg\":855,\"./plot_api\":754,\"fast-isnumeric\":225}],761:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/plots\"),a=t(\"./plot_schema\"),o=t(\"./plot_config\").dfltConfig,s=n.isPlainObject,l=Array.isArray,c=n.isArrayOrTypedArray;function u(t,e,r,i,a,o){o=o||[];for(var h=Object.keys(t),f=0;f<h.length;f++){var v=h[f];if(\"transforms\"!==v){var m=o.slice();m.push(v);var y=t[v],x=e[v],b=g(r,v),_=\"info_array\"===(b||{}).valType,w=\"colorscale\"===(b||{}).valType,k=(b||{}).items;if(d(r,v))if(s(y)&&s(x))u(y,x,b,i,a,m);else if(_&&l(y)){y.length>x.length&&i.push(p(\"unused\",a,m.concat(x.length)));var T,A,M,S,E,C=x.length,L=Array.isArray(k);if(L&&(C=Math.min(C,k.length)),2===b.dimensions)for(A=0;A<C;A++)if(l(y[A])){y[A].length>x[A].length&&i.push(p(\"unused\",a,m.concat(A,x[A].length)));var P=x[A].length;for(T=0;T<(L?Math.min(P,k[A].length):P);T++)M=L?k[A][T]:k,S=y[A][T],E=x[A][T],n.validate(S,M)?E!==S&&E!==+S&&i.push(p(\"dynamic\",a,m.concat(A,T),S,E)):i.push(p(\"value\",a,m.concat(A,T),S))}else i.push(p(\"array\",a,m.concat(A),y[A]));else for(A=0;A<C;A++)M=L?k[A]:k,S=y[A],E=x[A],n.validate(S,M)?E!==S&&E!==+S&&i.push(p(\"dynamic\",a,m.concat(A),S,E)):i.push(p(\"value\",a,m.concat(A),S))}else if(b.items&&!_&&l(y)){var O,z,I=k[Object.keys(k)[0]],D=[];for(O=0;O<x.length;O++){var R=x[O]._index||O;if((z=m.slice()).push(R),s(y[R])&&s(x[O])){D.push(R);var F=y[R],B=x[O];s(F)&&!1!==F.visible&&!1===B.visible?i.push(p(\"invisible\",a,z)):u(F,B,I,i,a,z)}}for(O=0;O<y.length;O++)(z=m.slice()).push(O),s(y[O])?-1===D.indexOf(O)&&i.push(p(\"unused\",a,z)):i.push(p(\"object\",a,z,y[O]))}else!s(y)&&s(x)?i.push(p(\"object\",a,m,y)):c(y)||!c(x)||_||w?v in e?n.validate(y,b)?\"enumerated\"===b.valType&&(b.coerceNumber&&y!==+x||y!==x)&&i.push(p(\"dynamic\",a,m,y,x)):i.push(p(\"value\",a,m,y)):i.push(p(\"unused\",a,m,y)):i.push(p(\"array\",a,m,y));else i.push(p(\"schema\",a,m))}}return i}e.exports=function(t,e){var r,c,h=a.get(),f=[],d={_context:n.extendFlat({},o)};l(t)?(d.data=n.extendDeep([],t),r=t):(d.data=[],r=[],f.push(p(\"array\",\"data\"))),s(e)?(d.layout=n.extendDeep({},e),c=e):(d.layout={},c={},arguments.length>1&&f.push(p(\"object\",\"layout\"))),i.supplyDefaults(d);for(var g=d._fullData,v=r.length,m=0;m<v;m++){var y=r[m],x=[\"data\",m];if(s(y)){var b=g[m],_=b.type,w=h.traces[_].attributes;w.type={valType:\"enumerated\",values:[_]},!1===b.visible&&!1!==y.visible&&f.push(p(\"invisible\",x)),u(y,b,w,f,x);var k=y.transforms,T=b.transforms;if(k){l(k)||f.push(p(\"array\",x,[\"transforms\"])),x.push(\"transforms\");for(var A=0;A<k.length;A++){var M=[\"transforms\",A],S=k[A].type;if(s(k[A])){var E=h.transforms[S]?h.transforms[S].attributes:{};E.type={valType:\"enumerated\",values:Object.keys(h.transforms)},u(k[A],T[A],E,f,x,M)}else f.push(p(\"object\",x,M))}}}else f.push(p(\"object\",x))}return u(c,d._fullLayout,function(t,e){for(var r=t.layout.layoutAttributes,i=0;i<e.length;i++){var a=e[i],o=t.traces[a.type],s=o.layoutAttributes;s&&(a.subplot?n.extendFlat(r[o.attributes.subplot.dflt],s):n.extendFlat(r,s))}return r}(h,g),f,\"layout\"),0===f.length?void 0:f};var h={object:function(t,e){return(\"layout\"===t&&\"\"===e?\"The layout argument\":\"data\"===t[0]&&\"\"===e?\"Trace \"+t[1]+\" in the data argument\":f(t)+\"key \"+e)+\" must be linked to an object container\"},array:function(t,e){return(\"data\"===t?\"The data argument\":f(t)+\"key \"+e)+\" must be linked to an array container\"},schema:function(t,e){return f(t)+\"key \"+e+\" is not part of the schema\"},unused:function(t,e,r){var n=s(r)?\"container\":\"key\";return f(t)+n+\" \"+e+\" did not get coerced\"},dynamic:function(t,e,r,n){return[f(t)+\"key\",e,\"(set to '\"+r+\"')\",\"got reset to\",\"'\"+n+\"'\",\"during defaults.\"].join(\" \")},invisible:function(t,e){return(e?f(t)+\"item \"+e:\"Trace \"+t[1])+\" got defaulted to be not visible\"},value:function(t,e,r){return[f(t)+\"key \"+e,\"is set to an invalid value (\"+r+\")\"].join(\" \")}};function f(t){return l(t)?\"In data trace \"+t[1]+\", \":\"In \"+t+\", \"}function p(t,e,r,i,a){var o,s;r=r||\"\",l(e)?(o=e[0],s=e[1]):(o=e,s=null);var c=function(t){if(!l(t))return String(t);for(var e=\"\",r=0;r<t.length;r++){var n=t[r];\"number\"==typeof n?e=e.substr(0,e.length-1)+\"[\"+n+\"]\":e+=n,r<t.length-1&&(e+=\".\")}return e}(r),u=h[t](e,c,i,a);return n.log(u),{code:t,container:o,trace:s,path:r,astr:c,msg:u}}function d(t,e){var r=m(e),n=r.keyMinusId,i=r.id;return!!(n in t&&t[n]._isSubplotObj&&i)||e in t}function g(t,e){return e in t?t[e]:t[m(e).keyMinusId]}var v=n.counterRegex(\"([a-z]+)\");function m(t){var e=t.match(v);return{keyMinusId:e&&e[1],id:e&&e[2]}}},{\"../lib\":719,\"../plots/plots\":828,\"./plot_config\":755,\"./plot_schema\":756}],762:[function(t,e,r){\"use strict\";e.exports={mode:{valType:\"enumerated\",dflt:\"afterall\",values:[\"immediate\",\"next\",\"afterall\"]},direction:{valType:\"enumerated\",values:[\"forward\",\"reverse\"],dflt:\"forward\"},fromcurrent:{valType:\"boolean\",dflt:!1},frame:{duration:{valType:\"number\",min:0,dflt:500},redraw:{valType:\"boolean\",dflt:!0}},transition:{duration:{valType:\"number\",min:0,dflt:500,editType:\"none\"},easing:{valType:\"enumerated\",dflt:\"cubic-in-out\",values:[\"linear\",\"quad\",\"cubic\",\"sin\",\"exp\",\"circle\",\"elastic\",\"back\",\"bounce\",\"linear-in\",\"quad-in\",\"cubic-in\",\"sin-in\",\"exp-in\",\"circle-in\",\"elastic-in\",\"back-in\",\"bounce-in\",\"linear-out\",\"quad-out\",\"cubic-out\",\"sin-out\",\"exp-out\",\"circle-out\",\"elastic-out\",\"back-out\",\"bounce-out\",\"linear-in-out\",\"quad-in-out\",\"cubic-in-out\",\"sin-in-out\",\"exp-in-out\",\"circle-in-out\",\"elastic-in-out\",\"back-in-out\",\"bounce-in-out\"],editType:\"none\"},ordering:{valType:\"enumerated\",values:[\"layout first\",\"traces first\"],dflt:\"layout first\",editType:\"none\"}}}},{}],763:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\");e.exports=function(t,e,r){var a,o,s=r.name,l=r.inclusionAttr||\"visible\",c=e[s],u=n.isArrayOrTypedArray(t[s])?t[s]:[],h=e[s]=[],f=i.arrayTemplater(e,s,l);for(a=0;a<u.length;a++){var p=u[a];n.isPlainObject(p)?o=f.newItem(p):(o=f.newItem({}))[l]=!1,o._index=a,!1!==o[l]&&r.handleItemDefaults(p,o,e,r),h.push(o)}var d=f.defaultItems();for(a=0;a<d.length;a++)(o=d[a])._index=h.length,r.handleItemDefaults({},o,e,r,{}),h.push(o);if(n.isArrayOrTypedArray(c)){var g=Math.min(c.length,h.length);for(a=0;a<g;a++)n.relinkPrivateKeys(h[a],c[a])}return h}},{\"../lib\":719,\"../plot_api/plot_template\":757}],764:[function(t,e,r){\"use strict\";var n=t(\"../components/fx/attributes\");e.exports={type:{valType:\"enumerated\",values:[],dflt:\"scatter\",editType:\"calc+clearAxisTypes\",_noTemplating:!0},visible:{valType:\"enumerated\",values:[!0,!1,\"legendonly\"],dflt:!0,editType:\"calc\"},showlegend:{valType:\"boolean\",dflt:!0,editType:\"style\"},legendgroup:{valType:\"string\",dflt:\"\",editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"style\"},name:{valType:\"string\",editType:\"style\"},uid:{valType:\"string\",editType:\"plot\",anim:!0},ids:{valType:\"data_array\",editType:\"calc\",anim:!0},customdata:{valType:\"data_array\",editType:\"calc\"},meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},selectedpoints:{valType:\"any\",editType:\"calc\"},hoverinfo:{valType:\"flaglist\",flags:[\"x\",\"y\",\"z\",\"text\",\"name\"],extras:[\"all\",\"none\",\"skip\"],arrayOk:!0,dflt:\"all\",editType:\"none\"},hoverlabel:n.hoverlabel,stream:{token:{valType:\"string\",noBlank:!0,strict:!0,editType:\"calc\"},maxpoints:{valType:\"number\",min:0,max:1e4,dflt:500,editType:\"calc\"},editType:\"calc\"},transforms:{_isLinkedToArray:\"transform\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"}}},{\"../components/fx/attributes\":623}],765:[function(t,e,r){\"use strict\";e.exports={xaxis:{valType:\"subplotid\",dflt:\"x\",editType:\"calc+clearAxisTypes\"},yaxis:{valType:\"subplotid\",dflt:\"y\",editType:\"calc+clearAxisTypes\"}}},{}],766:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").FP_SAFE,o=t(\"../../registry\");function s(t,e){var r,n,a=[],o=l(e),s=c(t,e),u=s.min,h=s.max;if(0===u.length||0===h.length)return i.simpleMap(e.range,e.r2l);var f=u[0].val,p=h[0].val;for(r=1;r<u.length&&f===p;r++)f=Math.min(f,u[r].val);for(r=1;r<h.length&&f===p;r++)p=Math.max(p,h[r].val);var d=!1;if(e.range){var g=i.simpleMap(e.range,e.r2l);d=g[1]<g[0]}\"reversed\"===e.autorange&&(d=!0,e.autorange=!0);var v,m,y,x,b,_,w=e.rangemode,k=\"tozero\"===w,T=\"nonnegative\"===w,A=e._length,M=A/10,S=0;for(r=0;r<u.length;r++)for(v=u[r],n=0;n<h.length;n++)(_=(m=h[n]).val-v.val)>0&&((b=A-o(v)-o(m))>M?_/b>S&&(y=v,x=m,S=_/b):_/A>S&&(y={val:v.val,pad:0},x={val:m.val,pad:0},S=_/A));if(f===p){var E=f-1,C=f+1;if(k)if(0===f)a=[0,1];else{var L=(f>0?h:u).reduce(function(t,e){return Math.max(t,o(e))},0),P=f/(1-Math.min(.5,L/A));a=f>0?[0,P]:[P,0]}else a=T?[Math.max(0,E),Math.max(1,C)]:[E,C]}else k?(y.val>=0&&(y={val:0,pad:0}),x.val<=0&&(x={val:0,pad:0})):T&&(y.val-S*o(y)<0&&(y={val:0,pad:0}),x.val<=0&&(x={val:1,pad:0})),S=(x.val-y.val)/(A-o(y)-o(x)),a=[y.val-S*o(y),x.val+S*o(x)];return d&&a.reverse(),i.simpleMap(a,e.l2r||Number)}function l(t){var e=t._length/20;return\"domain\"===t.constrain&&t._inputDomain&&(e*=(t._inputDomain[1]-t._inputDomain[0])/(t.domain[1]-t.domain[0])),function(t){return t.pad+(t.extrapad?e:0)}}function c(t,e){var r,n,i,a=e._id,o=t._fullData,s=t._fullLayout,l=[],c=[];function f(t,e){for(r=0;r<e.length;r++){var o=t[e[r]],s=(o._extremes||{})[a];if(!0===o.visible&&s){for(n=0;n<s.min.length;n++)i=s.min[n],u(l,i.val,i.pad,{extrapad:i.extrapad});for(n=0;n<s.max.length;n++)i=s.max[n],h(c,i.val,i.pad,{extrapad:i.extrapad})}}}return f(o,e._traceIndices),f(s.annotations||[],e._annIndices||[]),f(s.shapes||[],e._shapeIndices||[]),{min:l,max:c}}function u(t,e,r,n){f(t,e,r,n,d)}function h(t,e,r,n){f(t,e,r,n,g)}function f(t,e,r,n,i){for(var a=n.tozero,o=n.extrapad,s=!0,l=0;l<t.length&&s;l++){var c=t[l];if(i(c.val,e)&&c.pad>=r&&(c.extrapad||!o)){s=!1;break}i(e,c.val)&&c.pad<=r&&(o||!c.extrapad)&&(t.splice(l,1),l--)}if(s){var u=a&&0===e;t.push({val:e,pad:u?0:r,extrapad:!u&&o})}}function p(t){return n(t)&&Math.abs(t)<a}function d(t,e){return t<=e}function g(t,e){return t>=e}e.exports={getAutoRange:s,makePadFn:l,doAutoRange:function(t,e){if(e.setScale(),e.autorange){e.range=s(t,e),e._r=e.range.slice(),e._rl=i.simpleMap(e._r,e.r2l);var r=e._input,n={};n[e._attr+\".range\"]=e.range,n[e._attr+\".autorange\"]=e.autorange,o.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,n),r.range=e.range.slice(),r.autorange=e.autorange}var a=e._anchorAxis;if(a&&a.rangeslider){var l=a.rangeslider[e._name];l&&\"auto\"===l.rangemode&&(l.range=s(t,e)),a._input.rangeslider[e._name]=i.extendFlat({},l)}},findExtremes:function(t,e,r){r||(r={});t._m||t.setScale();var i,o,s,l,c,f,d,g,v,m=[],y=[],x=e.length,b=r.padded||!1,_=r.tozero&&(\"linear\"===t.type||\"-\"===t.type),w=\"log\"===t.type,k=!1;function T(t){if(Array.isArray(t))return k=!0,function(e){return Math.max(Number(t[e]||0),0)};var e=Math.max(Number(t||0),0);return function(){return e}}var A=T((t._m>0?r.ppadplus:r.ppadminus)||r.ppad||0),M=T((t._m>0?r.ppadminus:r.ppadplus)||r.ppad||0),S=T(r.vpadplus||r.vpad),E=T(r.vpadminus||r.vpad);if(!k){if(g=1/0,v=-1/0,w)for(i=0;i<x;i++)(o=e[i])<g&&o>0&&(g=o),o>v&&o<a&&(v=o);else for(i=0;i<x;i++)(o=e[i])<g&&o>-a&&(g=o),o>v&&o<a&&(v=o);e=[g,v],x=2}var C={tozero:_,extrapad:b};function L(r){s=e[r],n(s)&&(f=A(r),d=M(r),g=s-E(r),v=s+S(r),w&&g<v/10&&(g=v/10),l=t.c2l(g),c=t.c2l(v),_&&(l=Math.min(0,l),c=Math.max(0,c)),p(l)&&u(m,l,d,C),p(c)&&h(y,c,f,C))}var P=Math.min(6,x);for(i=0;i<P;i++)L(i);for(i=x-1;i>=P;i--)L(i);return{min:m,max:y,opts:r}},concatExtremes:c}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../registry\":847,\"fast-isnumeric\":225}],767:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../components/titles\"),u=t(\"../../components/color\"),h=t(\"../../components/drawing\"),f=t(\"./layout_attributes\"),p=t(\"./clean_ticks\"),d=t(\"../../constants/numerical\"),g=d.ONEAVGYEAR,v=d.ONEAVGMONTH,m=d.ONEDAY,y=d.ONEHOUR,x=d.ONEMIN,b=d.ONESEC,_=d.MINUS_SIGN,w=d.BADNUM,k=t(\"../../constants/alignment\").MID_SHIFT,T=t(\"../../constants/alignment\").LINE_SPACING,A=e.exports={};A.setConvert=t(\"./set_convert\");var M=t(\"./axis_autotype\"),S=t(\"./axis_ids\");A.id2name=S.id2name,A.name2id=S.name2id,A.cleanId=S.cleanId,A.list=S.list,A.listIds=S.listIds,A.getFromId=S.getFromId,A.getFromTrace=S.getFromTrace;var E=t(\"./autorange\");A.getAutoRange=E.getAutoRange,A.findExtremes=E.findExtremes,A.coerceRef=function(t,e,r,n,i,a){var o=n.charAt(n.length-1),l=r._fullLayout._subplots[o+\"axis\"],c=n+\"ref\",u={};return i||(i=l[0]||a),a||(a=i),u[c]={valType:\"enumerated\",values:l.concat(a?[a]:[]),dflt:i},s.coerce(t,e,u,c)},A.coercePosition=function(t,e,r,n,i,a){var o,l;if(\"paper\"===n||\"pixel\"===n)o=s.ensureNumber,l=r(i,a);else{var c=A.getFromId(e,n);l=r(i,a=c.fraction2r(a)),o=c.cleanPos}t[i]=o(l)},A.cleanPosition=function(t,e,r){return(\"paper\"===r||\"pixel\"===r?s.ensureNumber:A.getFromId(e,r).cleanPos)(t)},A.redrawComponents=function(t,e){e=e||A.listIds(t);var r=t._fullLayout;function n(n,i,a,s){for(var l=o.getComponentMethod(n,i),c={},u=0;u<e.length;u++)for(var h=r[A.id2name(e[u])][a],f=0;f<h.length;f++){var p=h[f];if(!c[p]&&(l(t,p),c[p]=1,s))return}}n(\"annotations\",\"drawOne\",\"_annIndices\"),n(\"shapes\",\"drawOne\",\"_shapeIndices\"),n(\"images\",\"draw\",\"_imgIndices\",!0)};var C=A.getDataConversions=function(t,e,r,n){var i,a=\"x\"===r||\"y\"===r||\"z\"===r?r:n;if(Array.isArray(a)){if(i={type:M(n),_categories:[]},A.setConvert(i),\"category\"===i.type)for(var o=0;o<n.length;o++)i.d2c(n[o])}else i=A.getFromTrace(t,e,a);return i?{d2c:i.d2c,c2d:i.c2d}:\"ids\"===a?{d2c:P,c2d:P}:{d2c:L,c2d:L}};function L(t){return+t}function P(t){return String(t)}A.getDataToCoordFunc=function(t,e,r,n){return C(t,e,r,n).d2c},A.counterLetter=function(t){var e=t.charAt(0);return\"x\"===e?\"y\":\"y\"===e?\"x\":void 0},A.minDtick=function(t,e,r,n){-1===[\"log\",\"category\",\"multicategory\"].indexOf(t.type)&&n?void 0===t._minDtick?(t._minDtick=e,t._forceTick0=r):t._minDtick&&((t._minDtick/e+1e-6)%1<2e-6&&((r-t._forceTick0)/e%1+1.000001)%1<2e-6?(t._minDtick=e,t._forceTick0=r):((e/t._minDtick+1e-6)%1>2e-6||((r-t._forceTick0)/t._minDtick%1+1.000001)%1>2e-6)&&(t._minDtick=0)):t._minDtick=0},A.saveRangeInitial=function(t,e){for(var r=A.list(t,\"\",!0),n=!1,i=0;i<r.length;i++){var a=r[i],o=void 0===a._rangeInitial,s=o||!(a.range[0]===a._rangeInitial[0]&&a.range[1]===a._rangeInitial[1]);(o&&!1===a.autorange||e&&s)&&(a._rangeInitial=a.range.slice(),n=!0)}return n},A.saveShowSpikeInitial=function(t,e){for(var r=A.list(t,\"\",!0),n=!1,i=\"on\",a=0;a<r.length;a++){var o=r[a],s=void 0===o._showSpikeInitial,l=s||!(o.showspikes===o._showspikes);(s||e&&l)&&(o._showSpikeInitial=o.showspikes,n=!0),\"on\"!==i||o.showspikes||(i=\"off\")}return t._fullLayout._cartesianSpikesEnabled=i,n},A.autoBin=function(t,e,r,n,a,o){var l,c=s.aggNums(Math.min,null,t),u=s.aggNums(Math.max,null,t);if(\"category\"===e.type||\"multicategory\"===e.type)return{start:c-.5,end:u+.5,size:Math.max(1,Math.round(o)||1),_dataSpan:u-c};if(a||(a=e.calendar),l=\"log\"===e.type?{type:\"linear\",range:[c,u]}:{type:e.type,range:s.simpleMap([c,u],e.c2r,0,a),calendar:a},A.setConvert(l),o=o&&p.dtick(o,l.type))l.dtick=o,l.tick0=p.tick0(void 0,l.type,a);else{var h;if(r)h=(u-c)/r;else{var f=s.distinctVals(t),d=Math.pow(10,Math.floor(Math.log(f.minDiff)/Math.LN10)),g=d*s.roundUp(f.minDiff/d,[.9,1.9,4.9,9.9],!0);h=Math.max(g,2*s.stdev(t)/Math.pow(t.length,n?.25:.4)),i(h)||(h=1)}A.autoTicks(l,h)}var v,y=l.dtick,x=A.tickIncrement(A.tickFirst(l),y,\"reverse\",a);if(\"number\"==typeof y)v=(x=function(t,e,r,n,a){var o=0,s=0,l=0,c=0;function u(e){return(1+100*(e-t)/r.dtick)%100<2}for(var h=0;h<e.length;h++)e[h]%1==0?l++:i(e[h])||c++,u(e[h])&&o++,u(e[h]+r.dtick/2)&&s++;var f=e.length-c;if(l===f&&\"date\"!==r.type)r.dtick<1?t=n-.5*r.dtick:(t-=.5)+r.dtick<n&&(t+=r.dtick);else if(s<.1*f&&(o>.3*f||u(n)||u(a))){var p=r.dtick/2;t+=t+p<n?p:-p}return t}(x,t,l,c,u))+(1+Math.floor((u-x)/y))*y;else for(\"M\"===l.dtick.charAt(0)&&(x=function(t,e,r,n,i){var a=s.findExactDates(e,i);if(a.exactDays>.8){var o=Number(r.substr(1));a.exactYears>.8&&o%12==0?t=A.tickIncrement(t,\"M6\",\"reverse\")+1.5*m:a.exactMonths>.8?t=A.tickIncrement(t,\"M1\",\"reverse\")+15.5*m:t-=m/2;var l=A.tickIncrement(t,r);if(l<=n)return l}return t}(x,t,y,c,a)),v=x,0;v<=u;)v=A.tickIncrement(v,y,!1,a),0;return{start:e.c2r(x,0,a),end:e.c2r(v,0,a),size:y,_dataSpan:u-c}},A.prepTicks=function(t){var e=s.simpleMap(t.range,t.r2l);if(\"auto\"===t.tickmode||!t.dtick){var r,n=t.nticks;n||(\"category\"===t.type||\"multicategory\"===t.type?(r=t.tickfont?1.2*(t.tickfont.size||12):15,n=t._length/r):(r=\"y\"===t._id.charAt(0)?40:80,n=s.constrain(t._length/r,4,9)+1),\"radialaxis\"===t._name&&(n*=2)),\"array\"===t.tickmode&&(n*=100),A.autoTicks(t,Math.abs(e[1]-e[0])/n),t._minDtick>0&&t.dtick<2*t._minDtick&&(t.dtick=t._minDtick,t.tick0=t.l2r(t._forceTick0))}t.tick0||(t.tick0=\"date\"===t.type?\"2000-01-01\":0),\"date\"===t.type&&t.dtick<.1&&(t.dtick=.1),j(t)},A.calcTicks=function(t){A.prepTicks(t);var e=s.simpleMap(t.range,t.r2l);if(\"array\"===t.tickmode)return function(t){var e=t.tickvals,r=t.ticktext,n=new Array(e.length),i=s.simpleMap(t.range,t.r2l),a=1.0001*i[0]-1e-4*i[1],o=1.0001*i[1]-1e-4*i[0],l=Math.min(a,o),c=Math.max(a,o),u=0;Array.isArray(r)||(r=[]);var h=\"category\"===t.type?t.d2l_noadd:t.d2l;\"log\"===t.type&&\"L\"!==String(t.dtick).charAt(0)&&(t.dtick=\"L\"+Math.pow(10,Math.floor(Math.min(t.range[0],t.range[1]))-1));for(var f=0;f<e.length;f++){var p=h(e[f]);p>l&&p<c&&(void 0===r[f]?n[u]=A.tickText(t,p):n[u]=U(t,p,String(r[f])),u++)}u<e.length&&n.splice(u,e.length-u);return n}(t);t._tmin=A.tickFirst(t);var r=1.0001*e[0]-1e-4*e[1],n=1.0001*e[1]-1e-4*e[0],a=e[1]<e[0];if(t._tmin<r!==a)return[];var o=[];\"category\"!==t.type&&\"multicategory\"!==t.type||(n=a?Math.max(-.5,n):Math.min(t._categories.length-.5,n));for(var l=\"log\"===t.type&&!(i(t.dtick)||\"L\"===t.dtick.charAt(0)),c=null,u=Math.max(1e3,t._length||0),h=t._tmin;(a?h>=n:h<=n)&&!(o.length>u||h===c);h=A.tickIncrement(h,t.dtick,a,t.calendar)){c=h;var f=!1;l&&h!==(0|h)&&(f=!0),o.push({minor:f,value:h})}rt(t)&&360===Math.abs(e[1]-e[0])&&o.pop(),t._tmax=(o[o.length-1]||{}).value,t._prevDateHead=\"\",t._inCalcTicks=!0;for(var p=new Array(o.length),d=0;d<o.length;d++)p[d]=A.tickText(t,o[d].value,!1,o[d].minor);return t._inCalcTicks=!1,p};var O=[2,5,10],z=[1,2,3,6,12],I=[1,2,5,10,15,30],D=[1,2,3,7,14],R=[-.046,0,.301,.477,.602,.699,.778,.845,.903,.954,1],F=[-.301,0,.301,.699,1],B=[15,30,45,90,180];function N(t,e,r){return e*s.roundUp(t/e,r)}function j(t){var e=t.dtick;if(t._tickexponent=0,i(e)||\"string\"==typeof e||(e=1),\"category\"!==t.type&&\"multicategory\"!==t.type||(t._tickround=null),\"date\"===t.type){var r=t.r2l(t.tick0),n=t.l2r(r).replace(/(^-|i)/g,\"\"),a=n.length;if(\"M\"===String(e).charAt(0))a>10||\"01-01\"!==n.substr(5)?t._tickround=\"d\":t._tickround=+e.substr(1)%12==0?\"y\":\"m\";else if(e>=m&&a<=10||e>=15*m)t._tickround=\"d\";else if(e>=x&&a<=16||e>=y)t._tickround=\"M\";else if(e>=b&&a<=19||e>=x)t._tickround=\"S\";else{var o=t.l2r(r+e).replace(/^-/,\"\").length;t._tickround=Math.max(a,o)-20,t._tickround<0&&(t._tickround=4)}}else if(i(e)||\"L\"===e.charAt(0)){var s=t.range.map(t.r2d||Number);i(e)||(e=Number(e.substr(1))),t._tickround=2-Math.floor(Math.log(e)/Math.LN10+.01);var l=Math.max(Math.abs(s[0]),Math.abs(s[1])),c=Math.floor(Math.log(l)/Math.LN10+.01);Math.abs(c)>3&&(q(t.exponentformat)&&!H(c)?t._tickexponent=3*Math.round((c-1)/3):t._tickexponent=c)}else t._tickround=null}function U(t,e,r){var n=t.tickfont||{};return{x:e,dx:0,dy:0,text:r||\"\",fontSize:n.size,font:n.family,fontColor:n.color}}A.autoTicks=function(t,e){var r;function n(t){return Math.pow(t,Math.floor(Math.log(e)/Math.LN10))}if(\"date\"===t.type){t.tick0=s.dateTick0(t.calendar);var a=2*e;a>g?(e/=g,r=n(10),t.dtick=\"M\"+12*N(e,r,O)):a>v?(e/=v,t.dtick=\"M\"+N(e,1,z)):a>m?(t.dtick=N(e,m,D),t.tick0=s.dateTick0(t.calendar,!0)):a>y?t.dtick=N(e,y,z):a>x?t.dtick=N(e,x,I):a>b?t.dtick=N(e,b,I):(r=n(10),t.dtick=N(e,r,O))}else if(\"log\"===t.type){t.tick0=0;var o=s.simpleMap(t.range,t.r2l);if(e>.7)t.dtick=Math.ceil(e);else if(Math.abs(o[1]-o[0])<1){var l=1.5*Math.abs((o[1]-o[0])/e);e=Math.abs(Math.pow(10,o[1])-Math.pow(10,o[0]))/l,r=n(10),t.dtick=\"L\"+N(e,r,O)}else t.dtick=e>.3?\"D2\":\"D1\"}else\"category\"===t.type||\"multicategory\"===t.type?(t.tick0=0,t.dtick=Math.ceil(Math.max(e,1))):rt(t)?(t.tick0=0,r=1,t.dtick=N(e,r,B)):(t.tick0=0,r=n(10),t.dtick=N(e,r,O));if(0===t.dtick&&(t.dtick=1),!i(t.dtick)&&\"string\"!=typeof t.dtick){var c=t.dtick;throw t.dtick=1,\"ax.dtick error: \"+String(c)}},A.tickIncrement=function(t,e,r,a){var o=r?-1:1;if(i(e))return t+o*e;var l=e.charAt(0),c=o*Number(e.substr(1));if(\"M\"===l)return s.incrementMonth(t,c,a);if(\"L\"===l)return Math.log(Math.pow(10,t)+c)/Math.LN10;if(\"D\"===l){var u=\"D2\"===e?F:R,h=t+.01*o,f=s.roundUp(s.mod(h,1),u,r);return Math.floor(h)+Math.log(n.round(Math.pow(10,f),1))/Math.LN10}throw\"unrecognized dtick \"+String(e)},A.tickFirst=function(t){var e=t.r2l||Number,r=s.simpleMap(t.range,e),a=r[1]<r[0],o=a?Math.floor:Math.ceil,l=1.0001*r[0]-1e-4*r[1],c=t.dtick,u=e(t.tick0);if(i(c)){var h=o((l-u)/c)*c+u;return\"category\"!==t.type&&\"multicategory\"!==t.type||(h=s.constrain(h,0,t._categories.length-1)),h}var f=c.charAt(0),p=Number(c.substr(1));if(\"M\"===f){for(var d,g,v,m=0,y=u;m<10;){if(((d=A.tickIncrement(y,c,a,t.calendar))-l)*(y-l)<=0)return a?Math.min(y,d):Math.max(y,d);g=(l-(y+d)/2)/(d-y),v=f+(Math.abs(Math.round(g))||1)*p,y=A.tickIncrement(y,v,g<0?!a:a,t.calendar),m++}return s.error(\"tickFirst did not converge\",t),y}if(\"L\"===f)return Math.log(o((Math.pow(10,l)-u)/p)*p+u)/Math.LN10;if(\"D\"===f){var x=\"D2\"===c?F:R,b=s.roundUp(s.mod(l,1),x,a);return Math.floor(l)+Math.log(n.round(Math.pow(10,b),1))/Math.LN10}throw\"unrecognized dtick \"+String(c)},A.tickText=function(t,e,r,n){var a,o=U(t,e),l=\"array\"===t.tickmode,c=r||l,u=t.type,h=\"category\"===u?t.d2l_noadd:t.d2l;if(l&&Array.isArray(t.ticktext)){var f=s.simpleMap(t.range,t.r2l),p=Math.abs(f[1]-f[0])/1e4;for(a=0;a<t.ticktext.length&&!(Math.abs(e-h(t.tickvals[a]))<p);a++);if(a<t.ticktext.length)return o.text=String(t.ticktext[a]),o}function d(n){if(void 0===n)return!0;if(r)return\"none\"===n;var i={first:t._tmin,last:t._tmax}[n];return\"all\"!==n&&e!==i}var g=r?\"never\":\"none\"!==t.exponentformat&&d(t.showexponent)?\"hide\":\"\";if(\"date\"===u?function(t,e,r,n){var a=t._tickround,o=r&&t.hoverformat||A.getTickFormat(t);n&&(a=i(a)?4:{y:\"m\",m:\"d\",d:\"M\",M:\"S\",S:4}[a]);var l,c=s.formatDate(e.x,o,a,t._dateFormat,t.calendar,t._extraFormat),u=c.indexOf(\"\\n\");-1!==u&&(l=c.substr(u+1),c=c.substr(0,u));n&&(\"00:00:00\"===c||\"00:00\"===c?(c=l,l=\"\"):8===c.length&&(c=c.replace(/:00$/,\"\")));l&&(r?\"d\"===a?c+=\", \"+l:c=l+(c?\", \"+c:\"\"):t._inCalcTicks&&l===t._prevDateHead||(c+=\"<br>\"+l,t._prevDateHead=l));e.text=c}(t,o,r,c):\"log\"===u?function(t,e,r,n,a){var o=t.dtick,l=e.x,c=t.tickformat,u=\"string\"==typeof o&&o.charAt(0);\"never\"===a&&(a=\"\");n&&\"L\"!==u&&(o=\"L3\",u=\"L\");if(c||\"L\"===u)e.text=G(Math.pow(10,l),t,a,n);else if(i(o)||\"D\"===u&&s.mod(l+.01,1)<.1){var h=Math.round(l),f=Math.abs(h),p=t.exponentformat;\"power\"===p||q(p)&&H(h)?(e.text=0===h?1:1===h?\"10\":\"10<sup>\"+(h>1?\"\":_)+f+\"</sup>\",e.fontSize*=1.25):(\"e\"===p||\"E\"===p)&&f>2?e.text=\"1\"+p+(h>0?\"+\":_)+f:(e.text=G(Math.pow(10,l),t,\"\",\"fakehover\"),\"D1\"===o&&\"y\"===t._id.charAt(0)&&(e.dy-=e.fontSize/6))}else{if(\"D\"!==u)throw\"unrecognized dtick \"+String(o);e.text=String(Math.round(Math.pow(10,s.mod(l,1)))),e.fontSize*=.75}if(\"D1\"===t.dtick){var d=String(e.text).charAt(0);\"0\"!==d&&\"1\"!==d||(\"y\"===t._id.charAt(0)?e.dx-=e.fontSize/4:(e.dy+=e.fontSize/2,e.dx+=(t.range[1]>t.range[0]?1:-1)*e.fontSize*(l<0?.5:.25)))}}(t,o,0,c,g):\"category\"===u?function(t,e){var r=t._categories[Math.round(e.x)];void 0===r&&(r=\"\");e.text=String(r)}(t,o):\"multicategory\"===u?function(t,e,r){var n=Math.round(e.x),i=t._categories[n]||[],a=void 0===i[1]?\"\":String(i[1]),o=void 0===i[0]?\"\":String(i[0]);r?e.text=o+\" - \"+a:(e.text=a,e.text2=o)}(t,o,r):rt(t)?function(t,e,r,n,i){if(\"radians\"!==t.thetaunit||r)e.text=G(e.x,t,i,n);else{var a=e.x/180;if(0===a)e.text=\"0\";else{var o=function(t){function e(t,e){return Math.abs(t-e)<=1e-6}var r=function(t){var r=1;for(;!e(Math.round(t*r)/r,t);)r*=10;return r}(t),n=t*r,i=Math.abs(function t(r,n){return e(n,0)?r:t(n,r%n)}(n,r));return[Math.round(n/i),Math.round(r/i)]}(a);if(o[1]>=100)e.text=G(s.deg2rad(e.x),t,i,n);else{var l=e.x<0;1===o[1]?1===o[0]?e.text=\"\\u03c0\":e.text=o[0]+\"\\u03c0\":e.text=[\"<sup>\",o[0],\"</sup>\",\"\\u2044\",\"<sub>\",o[1],\"</sub>\",\"\\u03c0\"].join(\"\"),l&&(e.text=_+e.text)}}}}(t,o,r,c,g):function(t,e,r,n,i){\"never\"===i?i=\"\":\"all\"===t.showexponent&&Math.abs(e.x/t.dtick)<1e-6&&(i=\"hide\");e.text=G(e.x,t,i,n)}(t,o,0,c,g),n||(t.tickprefix&&!d(t.showtickprefix)&&(o.text=t.tickprefix+o.text),t.ticksuffix&&!d(t.showticksuffix)&&(o.text+=t.ticksuffix)),\"boundaries\"===t.tickson||t.showdividers){var v=function(e){var r=t.l2p(e);return r>=0&&r<=t._length?e:null};o.xbnd=[v(o.x-.5),v(o.x+t.dtick-.5)]}return o},A.hoverLabelText=function(t,e,r){if(r!==w&&r!==e)return A.hoverLabelText(t,e)+\" - \"+A.hoverLabelText(t,r);var n=\"log\"===t.type&&e<=0,i=A.tickText(t,t.c2l(n?-e:e),\"hover\").text;return n?0===e?\"0\":_+i:i};var V=[\"f\",\"p\",\"n\",\"\\u03bc\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\"];function q(t){return\"SI\"===t||\"B\"===t}function H(t){return t>14||t<-15}function G(t,e,r,n){var a=t<0,o=e._tickround,l=r||e.exponentformat||\"B\",c=e._tickexponent,u=A.getTickFormat(e),h=e.separatethousands;if(n){var f={exponentformat:l,dtick:\"none\"===e.showexponent?e.dtick:i(t)&&Math.abs(t)||1,range:\"none\"===e.showexponent?e.range.map(e.r2d):[0,t||1]};j(f),o=(Number(f._tickround)||0)+4,c=f._tickexponent,e.hoverformat&&(u=e.hoverformat)}if(u)return e._numFormat(u)(t).replace(/-/g,_);var p,d=Math.pow(10,-o)/2;if(\"none\"===l&&(c=0),(t=Math.abs(t))<d)t=\"0\",a=!1;else{if(t+=d,c&&(t*=Math.pow(10,-c),o+=c),0===o)t=String(Math.floor(t));else if(o<0){t=(t=String(Math.round(t))).substr(0,t.length+o);for(var g=o;g<0;g++)t+=\"0\"}else{var v=(t=String(t)).indexOf(\".\")+1;v&&(t=t.substr(0,v+o).replace(/\\.?0+$/,\"\"))}t=s.numSeparate(t,e._separators,h)}c&&\"hide\"!==l&&(q(l)&&H(c)&&(l=\"power\"),p=c<0?_+-c:\"power\"!==l?\"+\"+c:String(c),\"e\"===l||\"E\"===l?t+=l+p:\"power\"===l?t+=\"\\xd710<sup>\"+p+\"</sup>\":\"B\"===l&&9===c?t+=\"B\":q(l)&&(t+=V[c/3+5]));return a?_+t:t}function Y(t,e){var r=t._id.charAt(0),n=t._tickAngles[e]||0,i=s.deg2rad(n),a=Math.sin(i),o=Math.cos(i),l=0,c=0;return t._selections[e].each(function(){var t=J(this),e=h.bBox(t.node()),r=e.width,n=e.height;l=Math.max(l,o*r,a*n),c=Math.max(c,a*r,o*n)}),{x:c,y:l}[r]}function W(t){return[t.text,t.x,t.axInfo,t.font,t.fontSize,t.fontColor].join(\"_\")}function X(t,e){var r,n=t._fullLayout._size,i=e._id.charAt(0),a=e.side;return\"free\"!==e.anchor?r=S.getFromId(t,e.anchor):\"x\"===i?r={_offset:n.t+(1-(e.position||0))*n.h,_length:0}:\"y\"===i&&(r={_offset:n.l+(e.position||0)*n.w,_length:0}),\"top\"===a||\"left\"===a?r._offset:\"bottom\"===a||\"right\"===a?r._offset+r._length:void 0}function Z(t,e){var r=t.l2p(e);return r>1&&r<t._length-1}function J(t){var e=n.select(t),r=e.select(\".text-math-group\");return r.empty()?e.select(\"text\"):r}function K(t){return t._id+\".automargin\"}function $(t){return t._id+\".rangeslider\"}function Q(t,e){for(var r=0;r<e.length;r++)-1===t.indexOf(e[r])&&t.push(e[r])}function tt(t,e,r){var n,i,a=[],o=[],l=t.layout;for(n=0;n<e.length;n++)a.push(A.getFromId(t,e[n]));for(n=0;n<r.length;n++)o.push(A.getFromId(t,r[n]));var c=Object.keys(f),u=[\"anchor\",\"domain\",\"overlaying\",\"position\",\"side\",\"tickangle\",\"editType\"],h=[\"linear\",\"log\"];for(n=0;n<c.length;n++){var p=c[n],d=a[0][p],g=o[0][p],v=!0,m=!1,y=!1;if(\"_\"!==p.charAt(0)&&\"function\"!=typeof d&&-1===u.indexOf(p)){for(i=1;i<a.length&&v;i++){var x=a[i][p];\"type\"===p&&-1!==h.indexOf(d)&&-1!==h.indexOf(x)&&d!==x?m=!0:x!==d&&(v=!1)}for(i=1;i<o.length&&v;i++){var b=o[i][p];\"type\"===p&&-1!==h.indexOf(g)&&-1!==h.indexOf(b)&&g!==b?y=!0:o[i][p]!==g&&(v=!1)}v&&(m&&(l[a[0]._name].type=\"linear\"),y&&(l[o[0]._name].type=\"linear\"),et(l,p,a,o,t._fullLayout._dfltTitle))}}for(n=0;n<t._fullLayout.annotations.length;n++){var _=t._fullLayout.annotations[n];-1!==e.indexOf(_.xref)&&-1!==r.indexOf(_.yref)&&s.swapAttrs(l.annotations[n],[\"?\"])}}function et(t,e,r,n,i){var a,o=s.nestedProperty,l=o(t[r[0]._name],e).get(),c=o(t[n[0]._name],e).get();for(\"title\"===e&&(l&&l.text===i.x&&(l.text=i.y),c&&c.text===i.y&&(c.text=i.x)),a=0;a<r.length;a++)o(t,r[a]._name+\".\"+e).set(c);for(a=0;a<n.length;a++)o(t,n[a]._name+\".\"+e).set(l)}function rt(t){return\"angularaxis\"===t._id}A.getTickFormat=function(t){var e,r,n,i,a,o,s,l;function c(t){return\"string\"!=typeof t?t:Number(t.replace(\"M\",\"\"))*v}function u(t,e){var r=[\"L\",\"D\"];if(typeof t==typeof e){if(\"number\"==typeof t)return t-e;var n=r.indexOf(t.charAt(0)),i=r.indexOf(e.charAt(0));return n===i?Number(t.replace(/(L|D)/g,\"\"))-Number(e.replace(/(L|D)/g,\"\")):n-i}return\"number\"==typeof t?1:-1}function h(t,e){var r=null===e[0],n=null===e[1],i=u(t,e[0])>=0,a=u(t,e[1])<=0;return(r||i)&&(n||a)}if(t.tickformatstops&&t.tickformatstops.length>0)switch(t.type){case\"date\":case\"linear\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&(i=t.dtick,a=n.dtickrange,o=void 0,void 0,void 0,o=c||function(t){return t},s=a[0],l=a[1],(!s&&\"number\"!=typeof s||o(s)<=o(i))&&(!l&&\"number\"!=typeof l||o(l)>=o(i)))){r=n;break}break;case\"log\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&h(t.dtick,n.dtickrange)){r=n;break}}return r?r.value:t.tickformat},A.getSubplots=function(t,e){var r=t._fullLayout._subplots,n=r.cartesian.concat(r.gl2d||[]),i=e?A.findSubplotsWithAxis(n,e):n;return i.sort(function(t,e){var r=t.substr(1).split(\"y\"),n=e.substr(1).split(\"y\");return r[0]===n[0]?+r[1]-+n[1]:+r[0]-+n[0]}),i},A.findSubplotsWithAxis=function(t,e){for(var r=new RegExp(\"x\"===e._id.charAt(0)?\"^\"+e._id+\"y\":e._id+\"$\"),n=[],i=0;i<t.length;i++){var a=t[i];r.test(a)&&n.push(a)}return n},A.makeClipPaths=function(t){var e=t._fullLayout;if(!e._hasOnlyLargeSploms){var r,i,a={_offset:0,_length:e.width,_id:\"\"},o={_offset:0,_length:e.height,_id:\"\"},s=A.list(t,\"x\",!0),l=A.list(t,\"y\",!0),c=[];for(r=0;r<s.length;r++)for(c.push({x:s[r],y:o}),i=0;i<l.length;i++)0===r&&c.push({x:a,y:l[i]}),c.push({x:s[r],y:l[i]});var u=e._clips.selectAll(\".axesclip\").data(c,function(t){return t.x._id+t.y._id});u.enter().append(\"clipPath\").classed(\"axesclip\",!0).attr(\"id\",function(t){return\"clip\"+e._uid+t.x._id+t.y._id}).append(\"rect\"),u.exit().remove(),u.each(function(t){n.select(this).select(\"rect\").attr({x:t.x._offset||0,y:t.y._offset||0,width:t.x._length||1,height:t.y._length||1})})}},A.draw=function(t,e,r){var n=t._fullLayout;\"redraw\"===e&&n._paper.selectAll(\"g.subplot\").each(function(t){var e=t[0],r=n._plots[e],i=r.xaxis,a=r.yaxis;r.xaxislayer.selectAll(\".\"+i._id+\"tick\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"tick2\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick2\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"divider\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"divider\").remove(),r.gridlayer&&r.gridlayer.selectAll(\"path\").remove(),r.zerolinelayer&&r.zerolinelayer.selectAll(\"path\").remove(),n._infolayer.select(\".g-\"+i._id+\"title\").remove(),n._infolayer.select(\".g-\"+a._id+\"title\").remove()});var i=e&&\"redraw\"!==e?e:A.listIds(t);return s.syncOrAsync(i.map(function(e){return function(){if(e){var n=A.getFromId(t,e),i=A.drawOne(t,n,r);return n._r=n.range.slice(),n._rl=s.simpleMap(n._r,n.r2l),i}}}))},A.drawOne=function(t,e,r){var n,i,l;r=r||{},e.setScale();var f=t._fullLayout,p=e._id,d=p.charAt(0),g=A.counterLetter(p),v=e._mainSubplot,m=e._mainLinePosition,y=e._mainMirrorPosition,x=f._plots[v][d+\"axislayer\"],b=e._subplotsWith,_=e._vals=A.calcTicks(e),w=[e.mirror,m,y].join(\"_\");for(n=0;n<_.length;n++)_[n].axInfo=w;if(e.visible){e._selections={},e._tickAngles={};var k,M,S=A.makeTransFn(e);if(\"boundaries\"===e.tickson){var E=function(t,e){var r,n=[],i=function(t,e){var r=t.xbnd[e];null!==r&&n.push(s.extendFlat({},t,{x:r}))};if(e.length){for(r=0;r<e.length;r++)i(e[r],0);i(e[r-1],1)}return n}(0,_);M=A.clipEnds(e,E),k=\"inside\"===e.ticks?M:E}else M=A.clipEnds(e,_),k=\"inside\"===e.ticks?M:_;var C=e._gridVals=M,L=function(t,e){var r,n,i=[],a=function(t,e){var r=t.xbnd[e];null!==r&&i.push(s.extendFlat({},t,{x:r}))};if(t.showdividers&&e.length){for(r=0;r<e.length;r++){var o=e[r];o.text2!==n&&a(o,0),n=o.text2}a(e[r-1],1)}return i}(e,_);if(!f._hasOnlyLargeSploms){var P={};for(n=0;n<b.length;n++){i=b[n];var O=(l=f._plots[i])[g+\"axis\"],z=O._mainAxis._id;if(!P[z]){P[z]=1;var I=\"x\"===d?\"M0,\"+O._offset+\"v\"+O._length:\"M\"+O._offset+\",0h\"+O._length;A.drawGrid(t,e,{vals:C,counterAxis:O,layer:l.gridlayer.select(\".\"+p),path:I,transFn:S}),A.drawZeroLine(t,e,{counterAxis:O,layer:l.zerolinelayer,path:I,transFn:S})}}}var D=A.getTickSigns(e),R=[];if(e.ticks){var F,B,N,j=A.makeTickPath(e,m,D[2]);if(e._anchorAxis&&e.mirror&&!0!==e.mirror?(F=A.makeTickPath(e,y,D[3]),B=j+F):(F=\"\",B=j),e.showdividers&&\"outside\"===e.ticks&&\"boundaries\"===e.tickson){var V={};for(n=0;n<L.length;n++)V[L[n].x]=1;N=function(t){return V[t.x]?F:B}}else N=B;A.drawTicks(t,e,{vals:k,layer:x,path:N,transFn:S}),R=Object.keys(e._linepositions||{})}for(n=0;n<R.length;n++){i=R[n],l=f._plots[i];var q=e._linepositions[i]||[],H=A.makeTickPath(e,q[0],D[0])+A.makeTickPath(e,q[1],D[1]);A.drawTicks(t,e,{vals:k,layer:l[d+\"axislayer\"],path:H,transFn:S})}var G=[];if(G.push(function(){return A.drawLabels(t,e,{vals:_,layer:x,transFn:S,labelFns:A.makeLabelFns(e,m)})}),\"multicategory\"===e.type){var Z=0,J={x:2,y:10}[d],Q=D[2]*(\"inside\"===e.ticks?-1:1);G.push(function(){return Z+=Y(e,p+\"tick\")+J,Z+=e._tickAngles[p+\"tick\"]?e.tickfont.size*T:0,A.drawLabels(t,e,{vals:function(t,e){for(var r=[],n={},i=0;i<e.length;i++){var a=e[i];n[a.text2]?n[a.text2].push(a.x):n[a.text2]=[a.x]}for(var o in n)r.push(U(t,s.interp(n[o],.5),o));return r}(e,_),layer:x,cls:p+\"tick2\",repositionOnUpdate:!0,secondary:!0,transFn:S,labelFns:A.makeLabelFns(e,m+Z*Q)})}),G.push(function(){return Z+=Y(e,p+\"tick2\"),e._labelLength=Z,function(t,e,r){var n=e._id+\"divider\",i=r.vals,a=r.layer.selectAll(\"path.\"+n).data(i,W);a.exit().remove(),a.enter().insert(\"path\",\":first-child\").classed(n,1).classed(\"crisp\",1).call(u.stroke,e.dividercolor).style(\"stroke-width\",h.crispRound(t,e.dividerwidth,1)+\"px\"),a.attr(\"transform\",r.transFn).attr(\"d\",r.path)}(t,e,{vals:L,layer:x,path:A.makeTickPath(e,m,Q,Z),transFn:S})})}var tt=o.getComponentMethod(\"rangeslider\",\"isVisible\")(e);return G.push(function(){if(e.showticklabels){var r=t.getBoundingClientRect(),n=x.node().getBoundingClientRect();e._boundingBox={width:n.width,height:n.height,left:n.left-r.left,right:n.right-r.left,top:n.top-r.top,bottom:n.bottom-r.top}}else{var i,a=f._size;\"x\"===d?(i=\"free\"===e.anchor?a.t+a.h*(1-e.position):a.t+a.h*(1-e._anchorAxis.domain[{bottom:0,top:1}[e.side]]),e._boundingBox={top:i,bottom:i,left:e._offset,right:e._offset+e._length,width:e._length,height:0}):(i=\"free\"===e.anchor?a.l+a.w*e.position:a.l+a.w*e._anchorAxis.domain[{left:0,right:1}[e.side]],e._boundingBox={left:i,right:i,bottom:e._offset+e._length,top:e._offset,height:e._length,width:0})}if(b){for(var o=e._counterSpan=[1/0,-1/0],s=0;s<b.length;s++){var l=f._plots[b[s]][\"x\"===d?\"yaxis\":\"xaxis\"];et(o,[l._offset,l._offset+l._length])}\"free\"===e.anchor&&et(o,\"x\"===d?[e._boundingBox.bottom,e._boundingBox.top]:[e._boundingBox.right,e._boundingBox.left])}},function(){var r,n,i=e.side.charAt(0);if(tt&&(n=o.getComponentMethod(\"rangeslider\",\"autoMarginOpts\")(t,e)),a.autoMargin(t,$(e),n),e.automargin&&(!tt||\"b\"!==i)){r={x:0,y:0,r:0,l:0,t:0,b:0};var s,l,c=e._boundingBox,u=X(t,e);switch(d+i){case\"xb\":s=0,l=c.top-u,r[i]=c.height;break;case\"xt\":s=1,l=u-c.bottom,r[i]=c.height;break;case\"yl\":s=0,l=u-c.right,r[i]=c.width;break;case\"yr\":s=1,l=c.left-u,r[i]=c.width}if(r[g]=\"free\"===e.anchor?e.position:e._anchorAxis.domain[s],r[i]>0&&(r[i]+=l),e.title.text!==f._dfltTitle[d]&&(r[i]+=e.title.font.size),\"x\"===d&&c.width>0){var h=c.right-(e._offset+e._length);h>0&&(r.x=1,r.r=h);var p=e._offset-c.left;p>0&&(r.x=0,r.l=p)}else if(\"y\"===d&&c.height>0){var v=c.bottom-(e._offset+e._length);v>0&&(r.y=0,r.b=v);var m=e._offset-c.top;m>0&&(r.y=1,r.t=m)}}a.autoMargin(t,K(e),r)}),r.skipTitle||tt&&e._boundingBox&&\"bottom\"===e.side||G.push(function(){return function(t,e){var r,n=t._fullLayout,i=e._id,a=i.charAt(0),o=e.title.font.size;if(\"multicategory\"===e.type)r=e._labelLength;else{r=10+1.5*o+(e.linewidth?e.linewidth-1:0)}var s,l,u,f,p=X(t,e);\"x\"===a?(l=e._offset+e._length/2,u=\"top\"===e.side?-r-o*(e.showticklabels?1:0):r+o*(e.showticklabels?1.5:.5),u+=p):(u=e._offset+e._length/2,l=\"right\"===e.side?r+o*(e.showticklabels?1:.5):-r-o*(e.showticklabels?.5:0),l+=p,s={rotate:\"-90\",offset:0});if(\"multicategory\"!==e.type){var d=e._selections[e._id+\"tick\"];if(f={selection:d,side:e.side},d&&d.node()&&d.node().parentNode){var g=h.getTranslate(d.node().parentNode);f.offsetLeft=g.x,f.offsetTop=g.y}}return c.draw(t,i+\"title\",{propContainer:e,propName:e._name+\".title.text\",placeholder:n._dfltTitle[a],avoid:f,transform:s,attributes:{x:l,y:u,\"text-anchor\":\"middle\"}})}(t,e)}),s.syncOrAsync(G)}function et(t,e){t[0]=Math.min(t[0],e[0]),t[1]=Math.max(t[1],e[1])}},A.getTickSigns=function(t){var e=t._id.charAt(0),r={x:\"top\",y:\"right\"}[e],n=t.side===r?1:-1,i=[-1,1,n,-n];return\"inside\"!==t.ticks==(\"x\"===e)&&(i=i.map(function(t){return-t})),i},A.makeTransFn=function(t){var e=t._id.charAt(0),r=t._offset;return\"x\"===e?function(e){return\"translate(\"+(r+t.l2p(e.x))+\",0)\"}:function(e){return\"translate(0,\"+(r+t.l2p(e.x))+\")\"}},A.makeTickPath=function(t,e,r,n){n=void 0!==n?n:t.ticklen;var i=t._id.charAt(0),a=(t.linewidth||1)/2;return\"x\"===i?\"M0,\"+(e+a*r)+\"v\"+n*r:\"M\"+(e+a*r)+\",0h\"+n*r},A.makeLabelFns=function(t,e,r){var n=t._id.charAt(0),a=\"boundaries\"!==t.tickson&&\"outside\"===t.ticks,o=0,l=0;if(a&&(o+=t.ticklen),r&&\"outside\"===t.ticks){var c=s.deg2rad(r);o=t.ticklen*Math.cos(c)+1,l=t.ticklen*Math.sin(c)}t.showticklabels&&(a||t.showline)&&(o+=.2*t.tickfont.size);var u,h,f,p,d={labelStandoff:o+=(t.linewidth||1)/2,labelShift:l};return\"x\"===n?(p=\"bottom\"===t.side?1:-1,u=l*p,h=e+o*p,f=\"bottom\"===t.side?1:-.2,d.xFn=function(t){return t.dx+u},d.yFn=function(t){return t.dy+h+t.fontSize*f},d.anchorFn=function(t,e){return i(e)&&0!==e&&180!==e?e*p<0?\"end\":\"start\":\"middle\"},d.heightFn=function(e,r,n){return r<-60||r>60?-.5*n:\"top\"===t.side?-n:0}):\"y\"===n&&(p=\"right\"===t.side?1:-1,u=o,h=-l*p,f=90===Math.abs(t.tickangle)?.5:0,d.xFn=function(t){return t.dx+e+(u+t.fontSize*f)*p},d.yFn=function(t){return t.dy+h+t.fontSize*k},d.anchorFn=function(e,r){return i(r)&&90===Math.abs(r)?\"middle\":\"right\"===t.side?\"start\":\"end\"},d.heightFn=function(e,r,n){return(r*=\"left\"===t.side?1:-1)<-30?-n:r<30?-.5*n:0}),d},A.drawTicks=function(t,e,r){r=r||{};var n=e._id+\"tick\",i=r.layer.selectAll(\"path.\"+n).data(e.ticks?r.vals:[],W);i.exit().remove(),i.enter().append(\"path\").classed(n,1).classed(\"ticks\",1).classed(\"crisp\",!1!==r.crisp).call(u.stroke,e.tickcolor).style(\"stroke-width\",h.crispRound(t,e.tickwidth,1)+\"px\").attr(\"d\",r.path),i.attr(\"transform\",r.transFn)},A.drawGrid=function(t,e,r){r=r||{};var n=e._id+\"grid\",i=r.vals,a=r.counterAxis;if(!1===e.showgrid)i=[];else if(a&&A.shouldShowZeroLine(t,e,a))for(var o=\"array\"===e.tickmode,s=0;s<i.length;s++){var l=i[s].x;if(o?!l:Math.abs(l)<e.dtick/100){if(i=i.slice(0,s).concat(i.slice(s+1)),!o)break;s--}}var c=r.layer.selectAll(\"path.\"+n).data(i,W);c.exit().remove(),c.enter().append(\"path\").classed(n,1).classed(\"crisp\",!1!==r.crisp),e._gw=h.crispRound(t,e.gridwidth,1),c.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(u.stroke,e.gridcolor||\"#ddd\").style(\"stroke-width\",e._gw+\"px\"),\"function\"==typeof r.path&&c.attr(\"d\",r.path)},A.drawZeroLine=function(t,e,r){r=r||r;var n=e._id+\"zl\",i=A.shouldShowZeroLine(t,e,r.counterAxis),a=r.layer.selectAll(\"path.\"+n).data(i?[{x:0,id:e._id}]:[]);a.exit().remove(),a.enter().append(\"path\").classed(n,1).classed(\"zl\",1).classed(\"crisp\",!1!==r.crisp).each(function(){r.layer.selectAll(\"path\").sort(function(t,e){return S.idSort(t.id,e.id)})}),a.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(u.stroke,e.zerolinecolor||u.defaultLine).style(\"stroke-width\",h.crispRound(t,e.zerolinewidth,e._gw||1)+\"px\")},A.drawLabels=function(t,e,r){r=r||{};var a=e._id,o=a.charAt(0),c=r.cls||a+\"tick\",u=r.vals,f=r.labelFns,p=r.secondary?0:e.tickangle,d=(e._tickAngles||{})[c],g=r.layer.selectAll(\"g.\"+c).data(e.showticklabels?u:[],W),v=[];function m(t,e){t.each(function(t){var a=n.select(this),o=a.select(\".text-math-group\"),s=f.anchorFn(t,e),c=r.transFn.call(a.node(),t)+(i(e)&&0!=+e?\" rotate(\"+e+\",\"+f.xFn(t)+\",\"+(f.yFn(t)-t.fontSize/2)+\")\":\"\"),u=l.lineCount(a),p=T*t.fontSize,d=f.heightFn(t,i(e)?+e:0,(u-1)*p);if(d&&(c+=\" translate(0, \"+d+\")\"),o.empty())a.select(\"text\").attr({transform:c,\"text-anchor\":s});else{var g=h.bBox(o.node()).width*{end:-.5,start:.5}[s];o.attr(\"transform\",c+(g?\"translate(\"+g+\",0)\":\"\"))}})}g.enter().append(\"g\").classed(c,1).append(\"text\").attr(\"text-anchor\",\"middle\").each(function(e){var r=n.select(this),i=t._promises.length;r.call(l.positionText,f.xFn(e),f.yFn(e)).call(h.font,e.font,e.fontSize,e.fontColor).text(e.text).call(l.convertToTspans,t),t._promises[i]?v.push(t._promises.pop().then(function(){m(r,p)})):m(r,p)}),g.exit().remove(),r.repositionOnUpdate&&g.each(function(t){n.select(this).select(\"text\").call(l.positionText,f.xFn(t),f.yFn(t))}),m(g,d||p),e._selections&&(e._selections[c]=g);var y=s.syncOrAsync([function(){return v.length&&Promise.all(v)},function(){m(g,p);var t=null;if(u.length&&\"x\"===o&&!i(p)&&(\"log\"!==e.type||\"D\"!==String(e.dtick).charAt(0))){t=0;var n,a=0,l=[];if(g.each(function(t){a=Math.max(a,t.fontSize);var r=e.l2p(t.x),n=J(this),i=h.bBox(n.node());l.push({top:0,bottom:10,height:10,left:r-i.width/2,right:r+i.width/2+2,width:i.width+2})}),\"boundaries\"!==e.tickson&&!e.showdividers||r.secondary){var f=u.length,d=Math.abs((u[f-1].x-u[0].x)*e._m)/(f-1)<2.5*a||\"multicategory\"===e.type;for(n=0;n<l.length-1;n++)if(s.bBoxIntersect(l[n],l[n+1])){t=d?90:30;break}}else{var v=2;for(e.ticks&&(v+=e.tickwidth/2),n=0;n<l.length;n++){var y=u[n].xbnd,x=l[n];if(null!==y[0]&&x.left-e.l2p(y[0])<v||null!==y[1]&&e.l2p(y[1])-x.right<v){t=90;break}}}t&&m(g,t)}e._tickAngles&&(e._tickAngles[c]=null===t?i(p)?p:0:t)}]);return y&&y.then&&t._promises.push(y),y},A.shouldShowZeroLine=function(t,e,r){var n=s.simpleMap(e.range,e.r2l);return n[0]*n[1]<=0&&e.zeroline&&(\"linear\"===e.type||\"-\"===e.type)&&e._gridVals.length&&(Z(e,0)||!function(t,e,r,n){var i=r._mainAxis;if(!i)return;var a=t._fullLayout,o=e._id.charAt(0),s=A.counterLetter(e._id),l=e._offset+(Math.abs(n[0])<Math.abs(n[1])==(\"x\"===o)?0:e._length);function c(t){if(!t.showline||!t.linewidth)return!1;var r=Math.max((t.linewidth+e.zerolinewidth)/2,1);function n(t){return\"number\"==typeof t&&Math.abs(t-l)<r}if(n(t._mainLinePosition)||n(t._mainMirrorPosition))return!0;var i=t._linepositions||{};for(var a in i)if(n(i[a][0])||n(i[a][1]))return!0}var u=a._plots[r._mainSubplot];if(!(u.mainplotinfo||u).overlays.length)return c(r);for(var h=A.list(t,s),f=0;f<h.length;f++){var p=h[f];if(p._mainAxis===i&&c(p))return!0}}(t,e,r,n)||function(t,e){for(var r=t._fullData,n=e._mainSubplot,i=e._id.charAt(0),a=0;a<r.length;a++){var s=r[a];if(!0===s.visible&&s.xaxis+s.yaxis===n){if(o.traceIs(s,\"bar-like\")&&s.orientation==={x:\"h\",y:\"v\"}[i])return!0;if(s.fill&&s.fill.charAt(s.fill.length-1)===i)return!0}}return!1}(t,e))},A.clipEnds=function(t,e){return e.filter(function(e){return Z(t,e.x)})},A.allowAutoMargin=function(t){for(var e=A.list(t,\"\",!0),r=0;r<e.length;r++){var n=e[r];n.automargin&&a.allowAutoMargin(t,K(n)),o.getComponentMethod(\"rangeslider\",\"isVisible\")(n)&&a.allowAutoMargin(t,$(n))}},A.swap=function(t,e){for(var r=function(t,e){var r,n,i=[];for(r=0;r<e.length;r++){var a=[],o=t._fullData[e[r]].xaxis,s=t._fullData[e[r]].yaxis;if(o&&s){for(n=0;n<i.length;n++)-1===i[n].x.indexOf(o)&&-1===i[n].y.indexOf(s)||a.push(n);if(a.length){var l,c=i[a[0]];if(a.length>1)for(n=1;n<a.length;n++)l=i[a[n]],Q(c.x,l.x),Q(c.y,l.y);Q(c.x,[o]),Q(c.y,[s])}else i.push({x:[o],y:[s]})}}return i}(t,e),n=0;n<r.length;n++)tt(t,r[n].x,r[n].y)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../components/titles\":681,\"../../constants/alignment\":688,\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/plots\":828,\"../../registry\":847,\"./autorange\":766,\"./axis_autotype\":768,\"./axis_ids\":770,\"./clean_ticks\":772,\"./layout_attributes\":779,\"./set_convert\":785,d3:163,\"fast-isnumeric\":225}],768:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){return!(r=r||{}).noMultiCategory&&(o=t,i.isArrayOrTypedArray(o[0])&&i.isArrayOrTypedArray(o[1]))?\"multicategory\":function(t,e){for(var r=Math.max(1,(t.length-1)/1e3),a=0,o=0,s={},l=0;l<t.length;l+=r){var c=t[Math.round(l)],u=String(c);s[u]||(s[u]=1,i.isDateTime(c,e)&&(a+=1),n(c)&&(o+=1))}return a>2*o}(t,e)?\"date\":function(t){for(var e=Math.max(1,(t.length-1)/1e3),r=0,n=0,o={},s=0;s<t.length;s+=e){var l=t[Math.round(s)],c=String(l);o[c]||(o[c]=1,\"boolean\"==typeof l?n++:i.cleanNumber(l)!==a?r++:\"string\"==typeof l&&n++)}return n>2*r}(t)?\"category\":function(t){if(!t)return!1;for(var e=0;e<t.length;e++)if(n(t[e]))return!0;return!1}(t)?\"linear\":\"-\";var o}},{\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],769:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./layout_attributes\"),o=t(\"./tick_value_defaults\"),s=t(\"./tick_mark_defaults\"),l=t(\"./tick_label_defaults\"),c=t(\"./category_order_defaults\"),u=t(\"./line_grid_defaults\"),h=t(\"./set_convert\");e.exports=function(t,e,r,f,p){var d=f.letter,g=f.font||{},v=f.splomStash||{},m=r(\"visible\",!f.visibleDflt),y=e.type;\"date\"===y&&n.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",f.calendar);h(e,p);var x=!e.isValidRange(t.range);x&&f.reverseDflt&&(x=\"reversed\"),!r(\"autorange\",x)||\"linear\"!==y&&\"-\"!==y||r(\"rangemode\"),r(\"range\"),e.cleanRange(),c(t,e,r,f),\"category\"===y||f.noHover||r(\"hoverformat\");var b=r(\"color\"),_=b!==a.color.dflt?b:g.color,w=v.label||p._dfltTitle[d];if(l(t,e,r,y,f,{pass:1}),!m)return e;r(\"title.text\",w),i.coerceFont(r,\"title.font\",{family:g.family,size:Math.round(1.2*g.size),color:_}),o(t,e,r,y),l(t,e,r,y,f,{pass:2}),s(t,e,r,f),u(t,e,r,{dfltColor:b,bgColor:f.bgColor,showGrid:f.showGrid,attributes:a}),(e.showline||e.ticks)&&r(\"mirror\"),f.automargin&&r(\"automargin\");var k,T=\"multicategory\"===e.type;f.noTickson||\"category\"!==e.type&&!T||!e.ticks&&!e.showgrid||(T&&(k=\"boundaries\"),r(\"tickson\",k));T&&(r(\"showdividers\")&&(r(\"dividercolor\"),r(\"dividerwidth\")));return e}},{\"../../lib\":719,\"../../registry\":847,\"./category_order_defaults\":771,\"./layout_attributes\":779,\"./line_grid_defaults\":781,\"./set_convert\":785,\"./tick_label_defaults\":786,\"./tick_mark_defaults\":787,\"./tick_value_defaults\":788}],770:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./constants\");r.id2name=function(t){if(\"string\"==typeof t&&t.match(i.AX_ID_PATTERN)){var e=t.substr(1);return\"1\"===e&&(e=\"\"),t.charAt(0)+\"axis\"+e}},r.name2id=function(t){if(t.match(i.AX_NAME_PATTERN)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),t.charAt(0)+e}},r.cleanId=function(t,e){if(t.match(i.AX_ID_PATTERN)&&(!e||t.charAt(0)===e)){var r=t.substr(1).replace(/^0+/,\"\");return\"1\"===r&&(r=\"\"),t.charAt(0)+r}},r.list=function(t,e,n){var i=t._fullLayout;if(!i)return[];var a,o=r.listIds(t,e),s=new Array(o.length);for(a=0;a<o.length;a++){var l=o[a];s[a]=i[l.charAt(0)+\"axis\"+l.substr(1)]}if(!n){var c=i._subplots.gl3d||[];for(a=0;a<c.length;a++){var u=i[c[a]];e?s.push(u[e+\"axis\"]):s.push(u.xaxis,u.yaxis,u.zaxis)}}return s},r.listIds=function(t,e){var r=t._fullLayout;if(!r)return[];var n=r._subplots;return e?n[e+\"axis\"]:n.xaxis.concat(n.yaxis)},r.getFromId=function(t,e,n){var i=t._fullLayout;return\"x\"===n?e=e.replace(/y[0-9]*/,\"\"):\"y\"===n&&(e=e.replace(/x[0-9]*/,\"\")),i[r.id2name(e)]},r.getFromTrace=function(t,e,i){var a=t._fullLayout,o=null;if(n.traceIs(e,\"gl3d\")){var s=e.scene;\"scene\"===s.substr(0,5)&&(o=a[s][i+\"axis\"])}else o=r.getFromId(t,e[i+\"axis\"]||i);return o},r.idSort=function(t,e){var r=t.charAt(0),n=e.charAt(0);return r!==n?r>n?1:-1:+(t.substr(1)||1)-+(e.substr(1)||1)},r.getAxisGroup=function(t,e){for(var r=t._axisMatchGroups,n=0;n<r.length;n++){if(r[n][e])return\"g\"+n}return e}},{\"../../registry\":847,\"./constants\":773}],771:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){if(\"category\"===e.type){var i,a=t.categoryarray,o=Array.isArray(a)&&a.length>0;o&&(i=\"array\");var s,l=r(\"categoryorder\",i);\"array\"===l&&(s=r(\"categoryarray\")),o||\"array\"!==l||(l=e.categoryorder=\"trace\"),\"trace\"===l?e._initialCategories=[]:\"array\"===l?e._initialCategories=s.slice():(s=function(t,e){var r,n,i,a=e.dataAttr||t._id.charAt(0),o={};if(e.axData)r=e.axData;else for(r=[],n=0;n<e.data.length;n++){var s=e.data[n];s[a+\"axis\"]===t._id&&r.push(s)}for(n=0;n<r.length;n++){var l=r[n][a];for(i=0;i<l.length;i++){var c=l[i];null!=c&&(o[c]=1)}}return Object.keys(o)}(e,n).sort(),\"category ascending\"===l?e._initialCategories=s:\"category descending\"===l&&(e._initialCategories=s.reverse()))}}},{}],772:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").ONEDAY;r.dtick=function(t,e){var r=\"log\"===e,i=\"date\"===e,o=\"category\"===e,s=i?a:1;if(!t)return s;if(n(t))return(t=Number(t))<=0?s:o?Math.max(1,Math.round(t)):i?Math.max(.1,t):t;if(\"string\"!=typeof t||!i&&!r)return s;var l=t.charAt(0),c=t.substr(1);return(c=n(c)?Number(c):0)<=0||!(i&&\"M\"===l&&c===Math.round(c)||r&&\"L\"===l||r&&\"D\"===l&&(1===c||2===c))?s:t},r.tick0=function(t,e,r,a){return\"date\"===e?i.cleanDate(t,i.dateTick0(r)):\"D1\"!==a&&\"D2\"!==a?n(t)?Number(t):0:void 0}},{\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],773:[function(t,e,r){\"use strict\";var n=t(\"../../lib/regex\").counter;e.exports={idRegex:{x:n(\"x\"),y:n(\"y\")},attrRegex:n(\"[xy]axis\"),xAxisMatch:n(\"xaxis\"),yAxisMatch:n(\"yaxis\"),AX_ID_PATTERN:/^[xyz][0-9]*$/,AX_NAME_PATTERN:/^[xyz]axis[0-9]*$/,SUBPLOT_PATTERN:/^x([0-9]*)y([0-9]*)$/,MINDRAG:8,MINSELECT:12,MINZOOM:20,DRAGGERSIZE:20,BENDPX:1.5,REDRAWDELAY:50,SELECTDELAY:100,SELECTID:\"-select\",DFLTRANGEX:[-1,6],DFLTRANGEY:[-1,4],traceLayerClasses:[\"heatmaplayer\",\"contourcarpetlayer\",\"contourlayer\",\"funnellayer\",\"waterfalllayer\",\"barlayer\",\"carpetlayer\",\"violinlayer\",\"boxlayer\",\"ohlclayer\",\"scattercarpetlayer\",\"scatterlayer\"],clipOnAxisFalseQuery:[\".scatterlayer\",\".barlayer\",\".funnellayer\",\".waterfalllayer\"],layerValue2layerClass:{\"above traces\":\"above\",\"below traces\":\"below\"}}},{\"../../lib/regex\":735}],774:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./axis_ids\").id2name,a=t(\"./scale_zoom\"),o=t(\"./autorange\").makePadFn,s=t(\"./autorange\").concatExtremes,l=t(\"../../constants/numerical\").ALMOST_EQUAL,c=t(\"../../constants/alignment\").FROM_BL;function u(t,e,r,n,a){var o,s,l,c,u=\"range\"!==a,h=n[i(e)].type,f=[];for(s=0;s<r.length;s++)if((l=r[s])!==e&&(c=n[i(l)]).type===h)if(c.fixedrange){if(u&&c.anchor){n[i(c.anchor)].fixedrange&&f.push(l)}}else f.push(l);for(o=0;o<t.length;o++)if(t[o][e]){var p=t[o],d=[];for(s=0;s<f.length;s++)p[l=f[s]]||d.push(l);return{linkableAxes:d,thisGroup:p}}return{linkableAxes:f,thisGroup:null}}function h(t,e,r,n,i){var a,o,s,l,c;null===e?((e={})[r]=1,c=t.length,t.push(e)):c=t.indexOf(e);var u=Object.keys(e);for(a=0;a<t.length;a++)if(s=t[a],a!==c&&s[n]){var h=s[n];for(o=0;o<u.length;o++)s[l=u[o]]=h*i*e[l];return void t.splice(c,1)}if(1!==i)for(o=0;o<u.length;o++)e[u[o]]*=i;e[n]=1}function f(t,e){var r=t._inputDomain,n=c[t.constraintoward],i=r[0]+(r[1]-r[0])*n;t.domain=t._input.domain=[i+(r[0]-i)/e,i+(r[1]-i)/e],t.setScale()}r.handleConstraintDefaults=function(t,e,r,i,a){var o,s,l,c,f=a._axisConstraintGroups,p=a._axisMatchGroups,d=e._id,g=d.charAt(0),v=((a._splomAxes||{})[g]||{})[d]||{},m=e._id,y=m.charAt(0),x=r(\"constrain\");if(n.coerce(t,e,{constraintoward:{valType:\"enumerated\",values:\"x\"===y?[\"left\",\"center\",\"right\"]:[\"bottom\",\"middle\",\"top\"],dflt:\"x\"===y?\"center\":\"middle\"}},\"constraintoward\"),!t.matches&&!v.matches||e.fixedrange||(s=u(p,m,i,a),o=n.coerce(t,e,{matches:{valType:\"enumerated\",values:s.linkableAxes||[],dflt:v.matches}},\"matches\")),o||!t.scaleanchor||e.fixedrange&&\"domain\"!==x||(c=u(f,m,i,a,x),l=n.coerce(t,e,{scaleanchor:{valType:\"enumerated\",values:c.linkableAxes||[]}},\"scaleanchor\")),o?(delete e.constrain,h(p,s.thisGroup,m,o,1)):-1!==i.indexOf(t.matches)&&n.warn(\"ignored \"+e._name+'.matches: \"'+t.matches+'\" to avoid either an infinite loop or because the target axis has fixed range.'),l){var b=r(\"scaleratio\");b||(b=e.scaleratio=1),h(f,c.thisGroup,m,l,b)}else-1!==i.indexOf(t.scaleanchor)&&n.warn(\"ignored \"+e._name+'.scaleanchor: \"'+t.scaleanchor+'\" to avoid either an infinite loop and possibly inconsistent scaleratios, or because the target axis has fixed range or this axis declares a *matches* constraint.')},r.enforce=function(t){var e,r,n,c,u,h,p,d=t._fullLayout,g=d._axisConstraintGroups||[];for(e=0;e<g.length;e++){var v=g[e],m=Object.keys(v),y=1/0,x=0,b=1/0,_={},w={},k=!1;for(r=0;r<m.length;r++)w[n=m[r]]=c=d[i(n)],c._inputDomain?c.domain=c._inputDomain.slice():c._inputDomain=c.domain.slice(),c._inputRange||(c._inputRange=c.range.slice()),c.setScale(),_[n]=u=Math.abs(c._m)/v[n],y=Math.min(y,u),\"domain\"!==c.constrain&&c._constraintShrinkable||(b=Math.min(b,u)),delete c._constraintShrinkable,x=Math.max(x,u),\"domain\"===c.constrain&&(k=!0);if(!(y>l*x)||k)for(r=0;r<m.length;r++)if(u=_[n=m[r]],h=(c=w[n]).constrain,u!==b||\"domain\"===h)if(p=u/b,\"range\"===h)a(c,p);else{var T=c._inputDomain,A=(c.domain[1]-c.domain[0])/(T[1]-T[0]),M=(c.r2l(c.range[1])-c.r2l(c.range[0]))/(c.r2l(c._inputRange[1])-c.r2l(c._inputRange[0]));if((p/=A)*M<1){c.domain=c._input.domain=T.slice(),a(c,p);continue}if(M<1&&(c.range=c._input.range=c._inputRange.slice(),p*=M),c.autorange){var S=c.r2l(c.range[0]),E=c.r2l(c.range[1]),C=(S+E)/2,L=C,P=C,O=Math.abs(E-C),z=C-O*p*1.0001,I=C+O*p*1.0001,D=o(c);f(c,p);var R,F,B=Math.abs(c._m),N=s(t,c),j=N.min,U=N.max;for(F=0;F<j.length;F++)(R=j[F].val-D(j[F])/B)>z&&R<L&&(L=R);for(F=0;F<U.length;F++)(R=U[F].val+D(U[F])/B)<I&&R>P&&(P=R);p/=(P-L)/(2*O),L=c.l2r(L),P=c.l2r(P),c.range=c._input.range=S<E?[L,P]:[P,L]}f(c,p)}}},r.clean=function(t,e){if(e._inputDomain){for(var r=!1,n=e._id,i=t._fullLayout._axisConstraintGroups,a=0;a<i.length;a++)if(i[a][n]){r=!0;break}r&&\"domain\"===e.constrain||(e._input.domain=e.domain=e._inputDomain,delete e._inputDomain)}}},{\"../../constants/alignment\":688,\"../../constants/numerical\":695,\"../../lib\":719,\"./autorange\":766,\"./axis_ids\":770,\"./scale_zoom\":783}],775:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"has-passive-events\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../components/color\"),u=t(\"../../components/drawing\"),h=t(\"../../components/fx\"),f=t(\"./axes\"),p=t(\"../../lib/setcursor\"),d=t(\"../../components/dragelement\"),g=t(\"../../constants/alignment\").FROM_TL,v=t(\"../../lib/clear_gl_canvases\"),m=t(\"../../plot_api/subroutines\").redrawReglTraces,y=t(\"../plots\"),x=t(\"./axis_ids\").getFromId,b=t(\"./select\").prepSelect,_=t(\"./select\").clearSelect,w=t(\"./select\").selectOnClick,k=t(\"./scale_zoom\"),T=t(\"./constants\"),A=T.MINDRAG,M=T.MINZOOM,S=!0;function E(t,e,r,n){var i=s.ensureSingle(t.draglayer,e,r,function(e){e.classed(\"drag\",!0).style({fill:\"transparent\",\"stroke-width\":0}).attr(\"data-subplot\",t.id)});return i.call(p,n),i.node()}function C(t,e,r,i,a,o,s){var l=E(t,\"rect\",e,r);return n.select(l).call(u.setRect,i,a,o,s),l}function L(t,e){for(var r=0;r<t.length;r++)if(!t[r].fixedrange)return e;return\"\"}function P(t,e,r,n,i){for(var a=0;a<t.length;a++){var o=t[a];if(!o.fixedrange){var s=o._rl[0],l=o._rl[1]-s;n[o._name+\".range[0]\"]=o.l2r(s+l*e),n[o._name+\".range[1]\"]=o.l2r(s+l*r)}}if(i&&i.length){var c=(e+(1-r))/2;P(i,c,1-c,n,[])}}function O(t,e){for(var r=0;r<t.length;r++){var n=t[r];n.fixedrange||(n.range=[n.l2r(n._rl[0]-e/n._m),n.l2r(n._rl[1]-e/n._m)])}}function z(t){return 1-(t>=0?Math.min(t,.9):1/(1/Math.max(t,-.3)+3.222))}function I(t,e,r,n,i){return t.append(\"path\").attr(\"class\",\"zoombox\").style({fill:e>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"transform\",\"translate(\"+r+\", \"+n+\")\").attr(\"d\",i+\"Z\")}function D(t,e,r){return t.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:c.background,stroke:c.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"transform\",\"translate(\"+e+\", \"+r+\")\").attr(\"d\",\"M0,0Z\")}function R(t,e,r,n,i,a){t.attr(\"d\",n+\"M\"+r.l+\",\"+r.t+\"v\"+r.h+\"h\"+r.w+\"v-\"+r.h+\"h-\"+r.w+\"Z\"),F(t,e,i,a)}function F(t,e,r,n){r||(t.transition().style(\"fill\",n>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),e.transition().style(\"opacity\",1).duration(200))}function B(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}function N(t){S&&t.data&&t._context.showTips&&(s.notifier(s._(t,\"Double-click to zoom back out\"),\"long\"),S=!1)}function j(t){return\"lasso\"===t||\"select\"===t}function U(t){var e=Math.floor(Math.min(t.b-t.t,t.r-t.l,M)/2);return\"M\"+(t.l-3.5)+\",\"+(t.t-.5+e)+\"h3v\"+-e+\"h\"+e+\"v-3h-\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.t-.5+e)+\"h-3v\"+-e+\"h\"+-e+\"v-3h\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.b+.5-e)+\"h-3v\"+e+\"h\"+-e+\"v3h\"+(e+3)+\"ZM\"+(t.l-3.5)+\",\"+(t.b+.5-e)+\"h3v\"+e+\"h\"+e+\"v3h-\"+(e+3)+\"Z\"}function V(t,e,r,n){for(var i,a,o,l,c=!1,u={},h={},f=0;f<e.length;f++){var p=e[f];for(i in r)if(p[i]){for(o in p)(\"x\"===o.charAt(0)?r:n)[o]||(u[o]=i);for(a in n)p[a]&&(c=!0)}for(a in n)if(p[a])for(l in p)(\"x\"===l.charAt(0)?r:n)[l]||(h[l]=a)}c&&(s.extendFlat(u,h),h={});var d={},g=[];for(o in u){var v=x(t,o);g.push(v),d[v._id]=v}var m={},y=[];for(l in h){var b=x(t,l);y.push(b),m[b._id]=b}return{xaHash:d,yaHash:m,xaxes:g,yaxes:y,xLinks:u,yLinks:h,isSubplotConstrained:c}}function q(t,e){if(a){var r=void 0!==t.onwheel?\"wheel\":\"mousewheel\";t._onwheel&&t.removeEventListener(r,t._onwheel),t._onwheel=e,t.addEventListener(r,e,{passive:!1})}else void 0!==t.onwheel?t.onwheel=e:void 0!==t.onmousewheel&&(t.onmousewheel=e)}function H(t){var e=[];for(var r in t)e.push(t[r]);return e}e.exports={makeDragBox:function(t,e,r,a,c,p,S,E){var F,G,Y,W,X,Z,J,K,$,Q,tt,et,rt,nt,it,at,ot,st,lt,ct,ut,ht=t._fullLayout._zoomlayer,ft=S+E===\"nsew\",pt=1===(S+E).length;function dt(){if(F=e.xaxis,G=e.yaxis,$=F._length,Q=G._length,J=F._offset,K=G._offset,(Y={})[F._id]=F,(W={})[G._id]=G,S&&E)for(var r=e.overlays,n=0;n<r.length;n++){var i=r[n].xaxis;Y[i._id]=i;var a=r[n].yaxis;W[a._id]=a}X=H(Y),Z=H(W),rt=L(X,E),nt=L(Z,S),it=!nt&&!rt,tt=V(t,t._fullLayout._axisConstraintGroups,Y,W),et=V(t,t._fullLayout._axisMatchGroups,Y,W),at=E||tt.isSubplotConstrained||et.isSubplotConstrained,ot=S||tt.isSubplotConstrained||et.isSubplotConstrained;var o=t._fullLayout;st=o._has(\"scattergl\"),lt=o._has(\"splom\"),ct=o._has(\"svg\")}dt();var gt=function(t,e,r){return t?\"nsew\"===t?r?\"\":\"pan\"===e?\"move\":\"crosshair\":t.toLowerCase()+\"-resize\":\"pointer\"}(nt+rt,t._fullLayout.dragmode,ft),vt=C(e,S+E+\"drag\",gt,r,a,c,p);if(it&&!ft)return vt.onmousedown=null,vt.style.pointerEvents=\"none\",vt;var mt,yt,xt,bt,_t,wt,kt,Tt,At,Mt,St={element:vt,gd:t,plotinfo:e};function Et(){St.plotinfo.selection=!1,_(t)}function Ct(r,i){var a=t._fullLayout.clickmode;if(B(t),2!==r||pt||function(){if(!t._transitioningWithDuration){var e=t._context.doubleClick,r=[];rt&&(r=r.concat(X)),nt&&(r=r.concat(Z)),et.xaxes&&(r=r.concat(et.xaxes)),et.yaxes&&(r=r.concat(et.yaxes));var n,i,a,s={};if(\"reset+autosize\"===e)for(e=\"autosize\",i=0;i<r.length;i++)if((n=r[i])._rangeInitial&&(n.range[0]!==n._rangeInitial[0]||n.range[1]!==n._rangeInitial[1])||!n._rangeInitial&&!n.autorange){e=\"reset\";break}if(\"autosize\"===e)for(i=0;i<r.length;i++)(n=r[i]).fixedrange||(s[n._name+\".autorange\"]=!0);else if(\"reset\"===e)for((rt||tt.isSubplotConstrained)&&(r=r.concat(tt.xaxes)),nt&&!tt.isSubplotConstrained&&(r=r.concat(tt.yaxes)),tt.isSubplotConstrained&&(rt?nt||(r=r.concat(Z)):r=r.concat(X)),i=0;i<r.length;i++)(n=r[i]).fixedrange||(n._rangeInitial?(a=n._rangeInitial,s[n._name+\".range[0]\"]=a[0],s[n._name+\".range[1]\"]=a[1]):s[n._name+\".autorange\"]=!0);t.emit(\"plotly_doubleclick\",null),o.call(\"_guiRelayout\",t,s)}}(),ft)a.indexOf(\"select\")>-1&&w(i,t,X,Z,e.id,St),a.indexOf(\"event\")>-1&&h.click(t,i,e.id);else if(1===r&&pt){var s=S?G:F,c=\"s\"===S||\"w\"===E?0:1,u=s._name+\".range[\"+c+\"]\",f=function(t,e){var r,i=t.range[e],a=Math.abs(i-t.range[1-e]);return\"date\"===t.type?i:\"log\"===t.type?(r=Math.ceil(Math.max(0,-Math.log(a)/Math.LN10))+3,n.format(\".\"+r+\"g\")(Math.pow(10,i))):(r=Math.floor(Math.log(Math.abs(i))/Math.LN10)-Math.floor(Math.log(a)/Math.LN10)+4,n.format(\".\"+String(r)+\"g\")(i))}(s,c),p=\"left\",d=\"middle\";if(s.fixedrange)return;S?(d=\"n\"===S?\"top\":\"bottom\",\"right\"===s.side&&(p=\"right\")):\"e\"===E&&(p=\"right\"),t._context.showAxisRangeEntryBoxes&&n.select(vt).call(l.makeEditable,{gd:t,immediate:!0,background:t._fullLayout.paper_bgcolor,text:String(f),fill:s.tickfont?s.tickfont.color:\"#444\",horizontalAlign:p,verticalAlign:d}).on(\"edit\",function(e){var r=s.d2r(e);void 0!==r&&o.call(\"_guiRelayout\",t,u,r)})}}function Lt(e,r){if(t._transitioningWithDuration)return!1;var n=Math.max(0,Math.min($,e+mt)),i=Math.max(0,Math.min(Q,r+yt)),a=Math.abs(n-mt),o=Math.abs(i-yt);function s(){kt=\"\",xt.r=xt.l,xt.t=xt.b,At.attr(\"d\",\"M0,0Z\")}if(xt.l=Math.min(mt,n),xt.r=Math.max(mt,n),xt.t=Math.min(yt,i),xt.b=Math.max(yt,i),tt.isSubplotConstrained)a>M||o>M?(kt=\"xy\",a/$>o/Q?(o=a*Q/$,yt>i?xt.t=yt-o:xt.b=yt+o):(a=o*$/Q,mt>n?xt.l=mt-a:xt.r=mt+a),At.attr(\"d\",U(xt))):s();else if(et.isSubplotConstrained)if(a>M||o>M){kt=\"xy\";var l=Math.min(xt.l/$,(Q-xt.b)/Q),c=Math.max(xt.r/$,(Q-xt.t)/Q);xt.l=l*$,xt.r=c*$,xt.b=(1-l)*Q,xt.t=(1-c)*Q,At.attr(\"d\",U(xt))}else s();else!nt||o<Math.min(Math.max(.6*a,A),M)?a<A||!rt?s():(xt.t=0,xt.b=Q,kt=\"x\",At.attr(\"d\",function(t,e){return\"M\"+(t.l-.5)+\",\"+(e-M-.5)+\"h-3v\"+(2*M+1)+\"h3ZM\"+(t.r+.5)+\",\"+(e-M-.5)+\"h3v\"+(2*M+1)+\"h-3Z\"}(xt,yt))):!rt||a<Math.min(.6*o,M)?(xt.l=0,xt.r=$,kt=\"y\",At.attr(\"d\",function(t,e){return\"M\"+(e-M-.5)+\",\"+(t.t-.5)+\"v-3h\"+(2*M+1)+\"v3ZM\"+(e-M-.5)+\",\"+(t.b+.5)+\"v3h\"+(2*M+1)+\"v-3Z\"}(xt,mt))):(kt=\"xy\",At.attr(\"d\",U(xt)));xt.w=xt.r-xt.l,xt.h=xt.b-xt.t,kt&&(Mt=!0),t._dragged=Mt,R(Tt,At,xt,_t,wt,bt),Pt(),t.emit(\"plotly_relayouting\",ut),wt=!0}function Pt(){ut={},\"xy\"!==kt&&\"x\"!==kt||(P(X,xt.l/$,xt.r/$,ut,tt.xaxes),Bt(\"x\",ut)),\"xy\"!==kt&&\"y\"!==kt||(P(Z,(Q-xt.b)/Q,(Q-xt.t)/Q,ut,tt.yaxes),Bt(\"y\",ut))}function Ot(){if(Math.min(xt.h,xt.w)<2*A)return B(t);Pt(),B(t),jt(),N(t)}St.prepFn=function(e,r,n){var a=St.dragmode,o=t._fullLayout.dragmode;o!==a&&(St.dragmode=o),dt(),it||(ft?e.shiftKey?\"pan\"===o?o=\"zoom\":j(o)||(o=\"pan\"):e.ctrlKey&&(o=\"pan\"):o=\"pan\"),St.minDrag=\"lasso\"===o?1:void 0,j(o)?(St.xaxes=X,St.yaxes=Z,b(e,r,n,St,o)):(St.clickFn=Ct,j(a)&&Et(),it||(\"zoom\"===o?(St.moveFn=Lt,St.doneFn=Ot,St.minDrag=1,function(e,r,n){var a=vt.getBoundingClientRect();mt=r-a.left,yt=n-a.top,xt={l:mt,r:mt,w:0,t:yt,b:yt,h:0},bt=t._hmpixcount?t._hmlumcount/t._hmpixcount:i(t._fullLayout.plot_bgcolor).getLuminance(),wt=!1,kt=\"xy\",Mt=!1,Tt=I(ht,bt,J,K,_t=\"M0,0H\"+$+\"V\"+Q+\"H0V0\"),At=D(ht,J,K)}(0,r,n)):\"pan\"===o&&(St.moveFn=Ft,St.doneFn=jt))),t._fullLayout._redrag=function(){var e=t._dragdata;e&&e.element===vt&&(j(t._fullLayout.dragmode)||(dt(),Ut([0,0,$,Q]),St.moveFn(e.dx,e.dy)))}},d.init(St);var zt=[0,0,$,Q],It=null,Dt=T.REDRAWDELAY,Rt=e.mainplot?t._fullLayout._plots[e.mainplot]:e;function Ft(e,r){if(!t._transitioningWithDuration){if(t._fullLayout._replotting=!0,\"ew\"===rt||\"ns\"===nt)return rt&&(O(X,e),Bt(\"x\")),nt&&(O(Z,r),Bt(\"y\")),Ut([rt?-e:0,nt?-r:0,$,Q]),Nt(),void t.emit(\"plotly_relayouting\",ut);if(tt.isSubplotConstrained&&rt&&nt){var n=\"w\"===rt==(\"n\"===nt)?1:-1,i=(e/$+n*r/Q)/2;e=i*$,r=n*i*Q}\"w\"===rt?e=l(X,0,e):\"e\"===rt?e=l(X,1,-e):rt||(e=0),\"n\"===nt?r=l(Z,1,r):\"s\"===nt?r=l(Z,0,-r):nt||(r=0);var a=\"w\"===rt?e:0,o=\"n\"===nt?r:0;if(tt.isSubplotConstrained){var s;if(!rt&&1===nt.length){for(s=0;s<X.length;s++)X[s].range=X[s]._r.slice(),k(X[s],1-r/Q);a=(e=r*$/Q)/2}if(!nt&&1===rt.length){for(s=0;s<Z.length;s++)Z[s].range=Z[s]._r.slice(),k(Z[s],1-e/$);o=(r=e*Q/$)/2}}Bt(\"x\"),Bt(\"y\"),Ut([a,o,$-e,Q-r]),Nt(),t.emit(\"plotly_relayouting\",ut)}function l(t,e,r){for(var n,i,a=1-e,o=0;o<t.length;o++){var s=t[o];if(!s.fixedrange){n=s,i=s._rl[a]+(s._rl[e]-s._rl[a])/z(r/s._length);var l=s.l2r(i);!1!==l&&void 0!==l&&(s.range[e]=l)}}return n._length*(n._rl[e]-i)/(n._rl[e]-n._rl[a])}}function Bt(t,e){for(var r=et.isSubplotConstrained?{x:Z,y:X}[t]:et[t+\"axes\"],n=et.isSubplotConstrained?{x:X,y:Z}[t]:[],i=0;i<r.length;i++){var a=r[i],o=a._id,s=et.xLinks[o]||et.yLinks[o],l=n[0]||Y[s]||W[s];l&&(e?(e[a._name+\".range[0]\"]=e[l._name+\".range[0]\"],e[a._name+\".range[1]\"]=e[l._name+\".range[1]\"]):a.range=l.range.slice())}}function Nt(){var e,r=[];function n(t){for(e=0;e<t.length;e++)t[e].fixedrange||r.push(t[e]._id)}for(at&&(n(X),n(tt.xaxes),n(et.xaxes)),ot&&(n(Z),n(tt.yaxes),n(et.yaxes)),ut={},e=0;e<r.length;e++){var i=r[e],a=x(t,i);f.drawOne(t,a,{skipTitle:!0}),ut[a._name+\".range[0]\"]=a.range[0],ut[a._name+\".range[1]\"]=a.range[1]}f.redrawComponents(t,r)}function jt(){Ut([0,0,$,Q]),s.syncOrAsync([y.previousPromises,function(){t._fullLayout._replotting=!1,o.call(\"_guiRelayout\",t,ut)}],t)}function Ut(e){var r,n,i,a,l=t._fullLayout,c=l._plots,h=l._subplots.cartesian;if(lt&&o.subplotsRegistry.splom.drag(t),st)for(r=0;r<h.length;r++)if(i=(n=c[h[r]]).xaxis,a=n.yaxis,n._scene){var f=s.simpleMap(i.range,i.r2l),p=s.simpleMap(a.range,a.r2l);n._scene.update({range:[f[0],p[0],f[1],p[1]]})}if((lt||st)&&(v(t),m(t)),ct){var d=e[2]/F._length,g=e[3]/G._length;for(r=0;r<h.length;r++){i=(n=c[h[r]]).xaxis,a=n.yaxis;var y,x,b,_,w=at&&!i.fixedrange&&Y[i._id],k=ot&&!a.fixedrange&&W[a._id];if(w?(y=d,b=E?e[0]:Ht(i,y)):et.xaHash[i._id]?(y=d,b=e[0]*i._length/F._length):et.yaHash[i._id]?(y=g,b=\"ns\"===nt?-e[1]*i._length/G._length:Ht(i,y,{n:\"top\",s:\"bottom\"}[nt])):b=qt(i,y=Vt(i,d,g)),k?(x=g,_=S?e[1]:Ht(a,x)):et.yaHash[a._id]?(x=g,_=e[1]*a._length/G._length):et.xaHash[a._id]?(x=d,_=\"ew\"===rt?-e[0]*a._length/F._length:Ht(a,x,{e:\"right\",w:\"left\"}[rt])):_=qt(a,x=Vt(a,d,g)),y||x){y||(y=1),x||(x=1);var T=i._offset-b/y,A=a._offset-_/x;n.clipRect.call(u.setTranslate,b,_).call(u.setScale,y,x),n.plot.call(u.setTranslate,T,A).call(u.setScale,1/y,1/x),y===n.xScaleFactor&&x===n.yScaleFactor||(u.setPointGroupScale(n.zoomScalePts,y,x),u.setTextPointsScale(n.zoomScaleTxt,y,x)),u.hideOutsideRangePoints(n.clipOnAxisFalseTraces,n),n.xScaleFactor=y,n.yScaleFactor=x}}}}function Vt(t,e,r){return t.fixedrange?0:at&&tt.xaHash[t._id]?e:ot&&(tt.isSubplotConstrained?tt.xaHash:tt.yaHash)[t._id]?r:0}function qt(t,e){return e?(t.range=t._r.slice(),k(t,e),Ht(t,e)):0}function Ht(t,e,r){return t._length*(1-e)*g[r||t.constraintoward||\"middle\"]}return S.length*E.length!=1&&q(vt,function(e){if(t._context._scrollZoom.cartesian||t._fullLayout._enablescrollzoom){if(Et(),t._transitioningWithDuration)return e.preventDefault(),void e.stopPropagation();dt(),clearTimeout(It);var r=-e.deltaY;if(isFinite(r)||(r=e.wheelDelta/10),isFinite(r)){var n,i=Math.exp(-Math.min(Math.max(r,-20),20)/200),a=Rt.draglayer.select(\".nsewdrag\").node().getBoundingClientRect(),o=(e.clientX-a.left)/a.width,l=(a.bottom-e.clientY)/a.height;if(at){for(E||(o=.5),n=0;n<X.length;n++)c(X[n],o,i);Bt(\"x\"),zt[2]*=i,zt[0]+=zt[2]*o*(1/i-1)}if(ot){for(S||(l=.5),n=0;n<Z.length;n++)c(Z[n],l,i);Bt(\"y\"),zt[3]*=i,zt[1]+=zt[3]*(1-l)*(1/i-1)}Ut(zt),Nt(),t.emit(\"plotly_relayouting\",ut),It=setTimeout(function(){zt=[0,0,$,Q],jt()},Dt),e.preventDefault()}else s.log(\"Did not find wheel motion attributes: \",e)}function c(t,e,r){if(!t.fixedrange){var n=s.simpleMap(t.range,t.r2l),i=n[0]+(n[1]-n[0])*e;t.range=n.map(function(e){return t.l2r(i+(e-i)*r)})}}}),vt},makeDragger:E,makeRectDragger:C,makeZoombox:I,makeCorners:D,updateZoombox:R,xyCorners:U,transitionZoombox:F,removeZoombox:B,showDoubleClickNotifier:N,attachWheelEventHandler:q}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/clear_gl_canvases\":704,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../plot_api/subroutines\":758,\"../../registry\":847,\"../plots\":828,\"./axes\":767,\"./axis_ids\":770,\"./constants\":773,\"./scale_zoom\":783,\"./select\":784,d3:163,\"has-passive-events\":411,tinycolor2:537}],776:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/fx\"),a=t(\"../../components/dragelement\"),o=t(\"../../lib/setcursor\"),s=t(\"./dragbox\").makeDragBox,l=t(\"./constants\").DRAGGERSIZE;r.initInteractions=function(t){var e=t._fullLayout;if(t._context.staticPlot)n.select(t).selectAll(\".drag\").remove();else if(e._has(\"cartesian\")||e._has(\"splom\")){Object.keys(e._plots||{}).sort(function(t,r){if((e._plots[t].mainplot&&!0)===(e._plots[r].mainplot&&!0)){var n=t.split(\"y\"),i=r.split(\"y\");return n[0]===i[0]?Number(n[1]||1)-Number(i[1]||1):Number(n[0]||1)-Number(i[0]||1)}return e._plots[t].mainplot?1:-1}).forEach(function(r){var n=e._plots[r],o=n.xaxis,c=n.yaxis;if(!n.mainplot){var u=s(t,n,o._offset,c._offset,o._length,c._length,\"ns\",\"ew\");u.onmousemove=function(e){t._fullLayout._rehover=function(){t._fullLayout._hoversubplot===r&&i.hover(t,e,r)},i.hover(t,e,r),t._fullLayout._lasthover=u,t._fullLayout._hoversubplot=r},u.onmouseout=function(e){t._dragging||(t._fullLayout._hoversubplot=null,a.unhover(t,e))},t._context.showAxisDragHandles&&(s(t,n,o._offset-l,c._offset-l,l,l,\"n\",\"w\"),s(t,n,o._offset+o._length,c._offset-l,l,l,\"n\",\"e\"),s(t,n,o._offset-l,c._offset+c._length,l,l,\"s\",\"w\"),s(t,n,o._offset+o._length,c._offset+c._length,l,l,\"s\",\"e\"))}if(t._context.showAxisDragHandles){if(r===o._mainSubplot){var h=o._mainLinePosition;\"top\"===o.side&&(h-=l),s(t,n,o._offset+.1*o._length,h,.8*o._length,l,\"\",\"ew\"),s(t,n,o._offset,h,.1*o._length,l,\"\",\"w\"),s(t,n,o._offset+.9*o._length,h,.1*o._length,l,\"\",\"e\")}if(r===c._mainSubplot){var f=c._mainLinePosition;\"right\"!==c.side&&(f-=l),s(t,n,f,c._offset+.1*c._length,l,.8*c._length,\"ns\",\"\"),s(t,n,f,c._offset+.9*c._length,l,.1*c._length,\"s\",\"\"),s(t,n,f,c._offset,l,.1*c._length,\"n\",\"\")}}});var o=e._hoverlayer.node();o.onmousemove=function(r){r.target=t._fullLayout._lasthover,i.hover(t,r,e._hoversubplot)},o.onclick=function(e){e.target=t._fullLayout._lasthover,i.click(t,e)},o.onmousedown=function(e){t._fullLayout._lasthover.onmousedown(e)},r.updateFx(t)}},r.updateFx=function(t){var e=t._fullLayout,r=\"pan\"===e.dragmode?\"move\":\"crosshair\";o(e._draggers,r)}},{\"../../components/dragelement\":611,\"../../components/fx\":632,\"../../lib/setcursor\":739,\"./constants\":773,\"./dragbox\":775,d3:163}],777:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t){return function(e,r){var a=e[t];if(Array.isArray(a))for(var o=n.subplotsRegistry.cartesian,s=o.idRegex,l=r._subplots,c=l.xaxis,u=l.yaxis,h=l.cartesian,f=r._has(\"cartesian\")||r._has(\"gl2d\"),p=0;p<a.length;p++){var d=a[p];if(i.isPlainObject(d)){var g=d.xref,v=d.yref,m=s.x.test(g),y=s.y.test(v);if(m||y){f||i.pushUnique(r._basePlotModules,o);var x=!1;m&&-1===c.indexOf(g)&&(c.push(g),x=!0),y&&-1===u.indexOf(v)&&(u.push(v),x=!0),x&&m&&y&&h.push(g+v)}}}}}},{\"../../lib\":719,\"../../registry\":847}],778:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../plots\"),s=t(\"../../components/drawing\"),l=t(\"../get_data\").getModuleCalcData,c=t(\"./axis_ids\"),u=t(\"./constants\"),h=t(\"../../constants/xmlns_namespaces\"),f=a.ensureSingle;function p(t,e,r){return a.ensureSingle(t,e,r,function(t){t.datum(r)})}function d(t,e,r,a,o){for(var c,h,f,p=u.traceLayerClasses,d=t._fullLayout,g=d._modules,v=[],m=[],y=0;y<g.length;y++){var x=(c=g[y]).name,b=i.modules[x].categories;if(b.svg){var _=c.layerName||x+\"layer\",w=c.plot;f=(h=l(r,w))[0],r=h[1],f.length&&v.push({i:p.indexOf(_),className:_,plotMethod:w,cdModule:f}),b.zoomScale&&m.push(\".\"+_)}}v.sort(function(t,e){return t.i-e.i});var k=e.plot.selectAll(\"g.mlayer\").data(v,function(t){return t.className});if(k.enter().append(\"g\").attr(\"class\",function(t){return t.className}).classed(\"mlayer\",!0).classed(\"rangeplot\",e.isRangePlot),k.exit().remove(),k.order(),k.each(function(r){var i=n.select(this),l=r.className;r.plotMethod(t,e,r.cdModule,i,a,o),-1===u.clipOnAxisFalseQuery.indexOf(\".\"+l)&&s.setClipUrl(i,e.layerClipId,t)}),d._has(\"scattergl\")&&(c=i.getModule(\"scattergl\"),f=l(r,c)[0],c.plot(t,e,f)),!t._context.staticPlot&&(e._hasClipOnAxisFalse&&(e.clipOnAxisFalseTraces=e.plot.selectAll(u.clipOnAxisFalseQuery.join(\",\")).selectAll(\".trace\")),m.length)){var T=e.plot.selectAll(m.join(\",\")).selectAll(\".trace\");e.zoomScalePts=T.selectAll(\"path.point\"),e.zoomScaleTxt=T.selectAll(\".textpoint\")}}function g(t,e){var r=e.plotgroup,n=e.id,i=u.layerValue2layerClass[e.xaxis.layer],a=u.layerValue2layerClass[e.yaxis.layer],o=t._fullLayout._hasOnlyLargeSploms;if(e.mainplot){var s=e.mainplotinfo,l=s.plotgroup,h=n+\"-x\",d=n+\"-y\";e.gridlayer=s.gridlayer,e.zerolinelayer=s.zerolinelayer,f(s.overlinesBelow,\"path\",h),f(s.overlinesBelow,\"path\",d),f(s.overaxesBelow,\"g\",h),f(s.overaxesBelow,\"g\",d),e.plot=f(s.overplot,\"g\",n),f(s.overlinesAbove,\"path\",h),f(s.overlinesAbove,\"path\",d),f(s.overaxesAbove,\"g\",h),f(s.overaxesAbove,\"g\",d),e.xlines=l.select(\".overlines-\"+i).select(\".\"+h),e.ylines=l.select(\".overlines-\"+a).select(\".\"+d),e.xaxislayer=l.select(\".overaxes-\"+i).select(\".\"+h),e.yaxislayer=l.select(\".overaxes-\"+a).select(\".\"+d)}else if(o)e.xlines=f(r,\"path\",\"xlines-above\"),e.ylines=f(r,\"path\",\"ylines-above\"),e.xaxislayer=f(r,\"g\",\"xaxislayer-above\"),e.yaxislayer=f(r,\"g\",\"yaxislayer-above\");else{var g=f(r,\"g\",\"layer-subplot\");e.shapelayer=f(g,\"g\",\"shapelayer\"),e.imagelayer=f(g,\"g\",\"imagelayer\"),e.gridlayer=f(r,\"g\",\"gridlayer\"),e.zerolinelayer=f(r,\"g\",\"zerolinelayer\"),f(r,\"path\",\"xlines-below\"),f(r,\"path\",\"ylines-below\"),e.overlinesBelow=f(r,\"g\",\"overlines-below\"),f(r,\"g\",\"xaxislayer-below\"),f(r,\"g\",\"yaxislayer-below\"),e.overaxesBelow=f(r,\"g\",\"overaxes-below\"),e.plot=f(r,\"g\",\"plot\"),e.overplot=f(r,\"g\",\"overplot\"),e.xlines=f(r,\"path\",\"xlines-above\"),e.ylines=f(r,\"path\",\"ylines-above\"),e.overlinesAbove=f(r,\"g\",\"overlines-above\"),f(r,\"g\",\"xaxislayer-above\"),f(r,\"g\",\"yaxislayer-above\"),e.overaxesAbove=f(r,\"g\",\"overaxes-above\"),e.xlines=r.select(\".xlines-\"+i),e.ylines=r.select(\".ylines-\"+a),e.xaxislayer=r.select(\".xaxislayer-\"+i),e.yaxislayer=r.select(\".yaxislayer-\"+a)}o||(p(e.gridlayer,\"g\",e.xaxis._id),p(e.gridlayer,\"g\",e.yaxis._id),e.gridlayer.selectAll(\"g\").map(function(t){return t[0]}).sort(c.idSort)),e.xlines.style(\"fill\",\"none\").classed(\"crisp\",!0),e.ylines.style(\"fill\",\"none\").classed(\"crisp\",!0)}function v(t,e){if(t){var r={};for(var i in t.each(function(t){var i=t[0];n.select(this).remove(),m(i,e),r[i]=!0}),e._plots)for(var a=e._plots[i].overlays||[],o=0;o<a.length;o++){var s=a[o];r[s.id]&&s.plot.selectAll(\".trace\").remove()}}}function m(t,e){e._draggers.selectAll(\"g.\"+t).remove(),e._defs.select(\"#clip\"+e._uid+t+\"plot\").remove()}r.name=\"cartesian\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=u.idRegex,r.attrRegex=u.attrRegex,r.attributes=t(\"./attributes\"),r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.transitionAxes=t(\"./transition_axes\"),r.finalizeSubplots=function(t,e){var r,n,i,o=e._subplots,s=o.xaxis,l=o.yaxis,h=o.cartesian,f=h.concat(o.gl2d||[]),p={},d={};for(r=0;r<f.length;r++){var g=f[r].split(\"y\");p[g[0]]=1,d[\"y\"+g[1]]=1}for(r=0;r<s.length;r++)p[n=s[r]]||(i=(t[c.id2name(n)]||{}).anchor,u.idRegex.y.test(i)||(i=\"y\"),h.push(n+i),f.push(n+i),d[i]||(d[i]=1,a.pushUnique(l,i)));for(r=0;r<l.length;r++)d[i=l[r]]||(n=(t[c.id2name(i)]||{}).anchor,u.idRegex.x.test(n)||(n=\"x\"),h.push(n+i),f.push(n+i),p[n]||(p[n]=1,a.pushUnique(s,n)));if(!f.length){for(var v in n=\"\",i=\"\",t){if(u.attrRegex.test(v))\"x\"===v.charAt(0)?(!n||+v.substr(5)<+n.substr(5))&&(n=v):(!i||+v.substr(5)<+i.substr(5))&&(i=v)}n=n?c.name2id(n):\"x\",i=i?c.name2id(i):\"y\",s.push(n),l.push(i),h.push(n+i)}},r.plot=function(t,e,r,n){var i,a=t._fullLayout,o=a._subplots.cartesian,s=t.calcdata;if(!Array.isArray(e))for(e=[],i=0;i<s.length;i++)e.push(i);for(i=0;i<o.length;i++){for(var l,c=o[i],u=a._plots[c],h=[],f=0;f<s.length;f++){var p=s[f],g=p[0].trace;g.xaxis+g.yaxis===c&&((-1!==e.indexOf(g.index)||g.carpet)&&(l&&l[0].trace.xaxis+l[0].trace.yaxis===c&&-1!==[\"tonextx\",\"tonexty\",\"tonext\"].indexOf(g.fill)&&-1===h.indexOf(l)&&h.push(l),h.push(p)),l=p)}d(t,u,h,r,n)}},r.clean=function(t,e,r,n){var i,a,o,s=n._plots||{},l=e._plots||{},u=n._subplots||{};if(n._hasOnlyLargeSploms&&!e._hasOnlyLargeSploms)for(o in s)(i=s[o]).plotgroup&&i.plotgroup.remove();var h=n._has&&n._has(\"gl\"),f=e._has&&e._has(\"gl\");if(h&&!f)for(o in s)(i=s[o])._scene&&i._scene.destroy();if(u.xaxis&&u.yaxis){var p=c.listIds({_fullLayout:n});for(a=0;a<p.length;a++){var d=p[a];e[c.id2name(d)]||n._infolayer.selectAll(\".g-\"+d+\"title\").remove()}}var g=n._has&&n._has(\"cartesian\"),y=e._has&&e._has(\"cartesian\");if(g&&!y)v(n._cartesianlayer.selectAll(\".subplot\"),n),n._defs.selectAll(\".axesclip\").remove(),delete n._axisConstraintGroups;else if(u.cartesian)for(a=0;a<u.cartesian.length;a++){var x=u.cartesian[a];if(!l[x]){var b=\".\"+x+\",.\"+x+\"-x,.\"+x+\"-y\";n._cartesianlayer.selectAll(b).remove(),m(x,n)}}},r.drawFramework=function(t){var e=t._fullLayout,r=function(t){var e,r,n,i,a,o,s=t._fullLayout,l=s._subplots.cartesian,c=l.length,u=[],h=[];for(e=0;e<c;e++){n=l[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var f=a._mainAxis,p=o._mainAxis,d=f._id+p._id,g=s._plots[d];i.overlays=[],d!==n&&g?(i.mainplot=d,i.mainplotinfo=g,h.push(n)):(i.mainplot=void 0,i.mainPlotinfo=void 0,u.push(n))}for(e=0;e<h.length;e++)n=h[e],(i=s._plots[n]).mainplotinfo.overlays.push(i);var v=u.concat(h),m=new Array(c);for(e=0;e<c;e++){n=v[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var y=[n,a.layer,o.layer,a.overlaying||\"\",o.overlaying||\"\"];for(r=0;r<i.overlays.length;r++)y.push(i.overlays[r].id);m[e]=y}return m}(t),i=e._cartesianlayer.selectAll(\".subplot\").data(r,String);i.enter().append(\"g\").attr(\"class\",function(t){return\"subplot \"+t[0]}),i.order(),i.exit().call(v,e),i.each(function(r){var i=r[0],a=e._plots[i];a.plotgroup=n.select(this),g(t,a),a.draglayer=f(e._draggers,\"g\",i)})},r.rangePlot=function(t,e,r){g(t,e),d(t,e,r),o.style(t)},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter(function(t,e){return e===r.size()-1}).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each(function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:h.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})})},r.updateFx=t(\"./graph_interact\").updateFx},{\"../../components/drawing\":614,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../registry\":847,\"../get_data\":802,\"../plots\":828,\"./attributes\":765,\"./axis_ids\":770,\"./constants\":773,\"./graph_interact\":776,\"./layout_attributes\":779,\"./layout_defaults\":780,\"./transition_axes\":789,d3:163}],779:[function(t,e,r){\"use strict\";var n=t(\"../font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray,l=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").DATE_FORMAT_LINK,t(\"./constants\"));e.exports={visible:{valType:\"boolean\",editType:\"plot\"},color:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},title:{text:{valType:\"string\",editType:\"ticks\"},font:n({editType:\"ticks\"}),editType:\"ticks\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"log\",\"date\",\"category\",\"multicategory\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"axrange\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0},{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0}],editType:\"axrange\",impliedEdits:{autorange:!1},anim:!0},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},scaleanchor:{valType:\"enumerated\",values:[l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},scaleratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},constrain:{valType:\"enumerated\",values:[\"range\",\"domain\"],dflt:\"range\",editType:\"plot\"},constraintoward:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\",\"top\",\"middle\",\"bottom\"],editType:\"plot\"},matches:{valType:\"enumerated\",values:[l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"calc\"},tickmode:{valType:\"enumerated\",values:[\"auto\",\"linear\",\"array\"],editType:\"ticks\",impliedEdits:{tick0:void 0,dtick:void 0}},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"ticks\"},tick0:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},dtick:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},tickvals:{valType:\"data_array\",editType:\"ticks\"},ticktext:{valType:\"data_array\",editType:\"ticks\"},ticks:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"\"],editType:\"ticks\"},tickson:{valType:\"enumerated\",values:[\"labels\",\"boundaries\"],dflt:\"labels\",editType:\"ticks\"},mirror:{valType:\"enumerated\",values:[!0,\"ticks\",!1,\"all\",\"allticks\"],dflt:!1,editType:\"ticks+layoutstyle\"},ticklen:{valType:\"number\",min:0,dflt:5,editType:\"ticks\"},tickwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},tickcolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},showticklabels:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},automargin:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},showspikes:{valType:\"boolean\",dflt:!1,editType:\"modebar\"},spikecolor:{valType:\"color\",dflt:null,editType:\"none\"},spikethickness:{valType:\"number\",dflt:3,editType:\"none\"},spikedash:o({},a,{dflt:\"dash\",editType:\"none\"}),spikemode:{valType:\"flaglist\",flags:[\"toaxis\",\"across\",\"marker\"],dflt:\"toaxis\",editType:\"none\"},spikesnap:{valType:\"enumerated\",values:[\"data\",\"cursor\"],dflt:\"data\",editType:\"none\"},tickfont:n({editType:\"ticks\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"ticks\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"ticks\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"ticks\"},tickformatstops:s(\"tickformatstop\",{enabled:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dtickrange:{valType:\"info_array\",items:[{valType:\"any\",editType:\"ticks\"},{valType:\"any\",editType:\"ticks\"}],editType:\"ticks\"},value:{valType:\"string\",dflt:\"\",editType:\"ticks\"},editType:\"ticks\"}),hoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},showline:{valType:\"boolean\",dflt:!1,editType:\"ticks+layoutstyle\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"layoutstyle\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks+layoutstyle\"},showgrid:{valType:\"boolean\",editType:\"ticks\"},gridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"ticks\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},zeroline:{valType:\"boolean\",editType:\"ticks\"},zerolinecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},zerolinewidth:{valType:\"number\",dflt:1,editType:\"ticks\"},showdividers:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dividercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},dividerwidth:{valType:\"number\",dflt:1,editType:\"ticks\"},anchor:{valType:\"enumerated\",values:[\"free\",l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},side:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],editType:\"plot\"},overlaying:{valType:\"enumerated\",values:[\"free\",l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},layer:{valType:\"enumerated\",values:[\"above traces\",\"below traces\"],dflt:\"above traces\",editType:\"plot\"},domain:{valType:\"info_array\",items:[{valType:\"number\",min:0,max:1,editType:\"plot\"},{valType:\"number\",min:0,max:1,editType:\"plot\"}],dflt:[0,1],editType:\"plot\"},position:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\",\"total ascending\",\"total descending\",\"min ascending\",\"min descending\",\"max ascending\",\"max descending\",\"sum ascending\",\"sum descending\",\"mean ascending\",\"mean descending\",\"median ascending\",\"median descending\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{autotick:{valType:\"boolean\",editType:\"ticks\"},title:{valType:\"string\",editType:\"ticks\"},titlefont:n({editType:\"ticks\"})}}},{\"../../components/color/attributes\":592,\"../../components/drawing/attributes\":613,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../font_attributes\":793,\"./constants\":773}],780:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../layout_attributes\"),s=t(\"./layout_attributes\"),l=t(\"./type_defaults\"),c=t(\"./axis_defaults\"),u=t(\"./constraints\").handleConstraintDefaults,h=t(\"./position_defaults\"),f=t(\"./axis_ids\"),p=f.id2name,d=f.name2id,g=t(\"../../registry\"),v=g.traceIs,m=g.getComponentMethod;function y(t,e,r){Array.isArray(t[e])?t[e].push(r):t[e]=[r]}e.exports=function(t,e,r){var f,g,x={},b={},_={},w={},k={},T={},A={},M={},S={};for(f=0;f<r.length;f++){var E=r[f];if(v(E,\"cartesian\")||v(E,\"gl2d\")){var C,L;if(E.xaxis)y(x,C=p(E.xaxis),E);else if(E.xaxes)for(g=0;g<E.xaxes.length;g++)y(x,p(E.xaxes[g]),E);if(E.yaxis)y(x,L=p(E.yaxis),E);else if(E.yaxes)for(g=0;g<E.yaxes.length;g++)y(x,p(E.yaxes[g]),E);if(\"funnel\"===E.type?\"h\"===E.orientation?(C&&(b[C]=!0),L&&(A[L]=!0)):L&&(_[L]=!0):(L&&(k[L]=!0,T[L]=!0),v(E,\"carpet\")&&(\"carpet\"!==E.type||E._cheater)||C&&(w[C]=!0)),\"carpet\"===E.type&&E._cheater&&C&&(b[C]=!0),v(E,\"2dMap\")&&(M[C]=!0,M[L]=!0),v(E,\"oriented\"))S[\"h\"===E.orientation?L:C]=!0}}var P=e._subplots,O=P.xaxis,z=P.yaxis,I=n.simpleMap(O,p),D=n.simpleMap(z,p),R=I.concat(D),F=i.background;O.length&&z.length&&(F=n.coerce(t,e,o,\"plot_bgcolor\"));var B,N,j,U,V=i.combine(F,e.paper_bgcolor);function q(t,e){return n.coerce(j,U,s,t,e)}function H(t,e){return n.coerce2(j,U,s,t,e)}function G(t){return\"x\"===t?z:O}var Y={x:G(\"x\"),y:G(\"y\")},W=Y.x.concat(Y.y);function X(e,r){for(var n=\"x\"===e?I:D,i=[],a=0;a<n.length;a++){var o=n[a];o===r||(t[o]||{}).overlaying||i.push(d(o))}return i}for(f=0;f<R.length;f++){N=(B=R[f]).charAt(0),n.isPlainObject(t[B])||(t[B]={}),j=t[B],U=a.newContainer(e,B,N+\"axis\");var Z=x[B]||[];U._traceIndices=Z.map(function(t){return t._expandedIndex}),U._annIndices=[],U._shapeIndices=[],U._imgIndices=[],U._subplotsWith=[],U._counterAxes=[],U._name=U._attr=B;var J=U._id=d(B),K=X(N,B),$=\"x\"===N&&!w[B]&&b[B]||\"y\"===N&&!k[B]&&_[B],Q=\"y\"===N&&!T[B]&&A[B],tt={letter:N,font:e.font,outerTicks:M[B],showGrid:!S[B],data:Z,bgColor:V,calendar:e.calendar,automargin:!0,visibleDflt:$,reverseDflt:Q,splomStash:((e._splomAxes||{})[N]||{})[J]};q(\"uirevision\",e.uirevision),l(j,U,q,tt),c(j,U,q,tt,e);var et=H(\"spikecolor\"),rt=H(\"spikethickness\"),nt=H(\"spikedash\"),it=H(\"spikemode\"),at=H(\"spikesnap\");q(\"showspikes\",!!(et||rt||nt||it||at))||(delete U.spikecolor,delete U.spikethickness,delete U.spikedash,delete U.spikemode,delete U.spikesnap),h(j,U,q,{letter:N,counterAxes:Y[N],overlayableAxes:K,grid:e.grid}),U._input=j}var ot=m(\"rangeslider\",\"handleDefaults\"),st=m(\"rangeselector\",\"handleDefaults\");for(f=0;f<I.length;f++)B=I[f],j=t[B],U=e[B],ot(t,e,B),\"date\"===U.type&&st(j,U,e,D,U.calendar),q(\"fixedrange\");for(f=0;f<D.length;f++){B=D[f],j=t[B],U=e[B];var lt=e[p(U.anchor)];q(\"fixedrange\",m(\"rangeslider\",\"isVisible\")(lt))}var ct=e._axisConstraintGroups=[],ut=e._axisMatchGroups=[];for(f=0;f<R.length;f++)N=(B=R[f]).charAt(0),j=t[B],U=e[B],u(j,U,q,W,e);for(f=0;f<ut.length;f++){var ht,ft=ut[f],pt=null,dt=null;for(ht in ft)(U=e[p(ht)]).matches||(pt=U.range,dt=U.autorange);if(null===pt||null===dt)for(ht in ft){pt=(U=e[p(ht)]).range,dt=U.autorange;break}for(ht in ft)(U=e[p(ht)]).matches&&(U.range=pt.slice(),U.autorange=dt),U._matchGroup=ft;if(ct.length)for(ht in ft)for(g=0;g<ct.length;g++){var gt=ct[g];for(var vt in gt)ht===vt&&(n.warn(\"Axis \"+vt+\" is set with both a *scaleanchor* and *matches* constraint; ignoring the scale constraint.\"),delete gt[vt],Object.keys(gt).length<2&&ct.splice(g,1))}}}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../registry\":847,\"../layout_attributes\":819,\"./axis_defaults\":769,\"./axis_ids\":770,\"./constraints\":774,\"./layout_attributes\":779,\"./position_defaults\":782,\"./type_defaults\":790}],781:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../components/color/attributes\").lightFraction,a=t(\"../../lib\");e.exports=function(t,e,r,o){var s=(o=o||{}).dfltColor;function l(r,n){return a.coerce2(t,e,o.attributes,r,n)}var c=l(\"linecolor\",s),u=l(\"linewidth\");r(\"showline\",o.showLine||!!c||!!u)||(delete e.linecolor,delete e.linewidth);var h=l(\"gridcolor\",n(s,o.bgColor,o.blend||i).toRgbString()),f=l(\"gridwidth\");if(r(\"showgrid\",o.showGrid||!!h||!!f)||(delete e.gridcolor,delete e.gridwidth),!o.noZeroLine){var p=l(\"zerolinecolor\",s),d=l(\"zerolinewidth\");r(\"zeroline\",o.showGrid||!!p||!!d)||(delete e.zerolinecolor,delete e.zerolinewidth)}}},{\"../../components/color/attributes\":592,\"../../lib\":719,tinycolor2:537}],782:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o,s,l,c,u=a.counterAxes||[],h=a.overlayableAxes||[],f=a.letter,p=a.grid;p&&(s=p._domains[f][p._axisMap[e._id]],o=p._anchors[e._id],s&&(l=p[f+\"side\"].split(\" \")[0],c=p.domain[f][\"right\"===l||\"top\"===l?1:0])),s=s||[0,1],o=o||(n(t.position)?\"free\":u[0]||\"free\"),l=l||(\"x\"===f?\"bottom\":\"left\"),c=c||0,\"free\"===i.coerce(t,e,{anchor:{valType:\"enumerated\",values:[\"free\"].concat(u),dflt:o}},\"anchor\")&&r(\"position\",c),i.coerce(t,e,{side:{valType:\"enumerated\",values:\"x\"===f?[\"bottom\",\"top\"]:[\"left\",\"right\"],dflt:l}},\"side\");var d=!1;if(h.length&&(d=i.coerce(t,e,{overlaying:{valType:\"enumerated\",values:[!1].concat(h),dflt:!1}},\"overlaying\")),!d){var g=r(\"domain\",s);g[0]>g[1]-1/4096&&(e.domain=s),i.noneOrAll(t.domain,e.domain,s)}return r(\"layer\"),e}},{\"../../lib\":719,\"fast-isnumeric\":225}],783:[function(t,e,r){\"use strict\";var n=t(\"../../constants/alignment\").FROM_BL;e.exports=function(t,e,r){void 0===r&&(r=n[t.constraintoward||\"center\"]);var i=[t.r2l(t.range[0]),t.r2l(t.range[1])],a=i[0]+(i[1]-i[0])*r;t.range=t._input.range=[t.l2r(a+(i[0]-a)*e),t.l2r(a+(i[1]-a)*e)]}},{\"../../constants/alignment\":688}],784:[function(t,e,r){\"use strict\";var n=t(\"polybooljs\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../../components/fx\"),s=t(\"../../lib\"),l=t(\"../../lib/polygon\"),c=t(\"../../lib/throttle\"),u=t(\"../../components/fx/helpers\").makeEventData,h=t(\"./axis_ids\").getFromId,f=t(\"../../lib/clear_gl_canvases\"),p=t(\"../../plot_api/subroutines\").redrawReglTraces,d=t(\"./constants\"),g=d.MINSELECT,v=l.filter,m=l.tester;function y(t){return t._id}function x(t,e,r,n,i,a,o){var s,l,c,u,h,f,p,d,g,v=e._hoverdata,m=e._fullLayout.clickmode.indexOf(\"event\")>-1,y=[];if(function(t){return t&&Array.isArray(t)&&!0!==t[0].hoverOnBox}(v)){k(t,e,a);var x=function(t,e){var r,n,i=t[0],a=-1,o=[];for(n=0;n<e.length;n++)if(r=e[n],i.fullData._expandedIndex===r.cd[0].trace._expandedIndex){if(!0===i.hoverOnBox)break;void 0!==i.pointNumber?a=i.pointNumber:void 0!==i.binNumber&&(a=i.binNumber,o=i.pointNumbers);break}return{pointNumber:a,pointNumbers:o,searchInfo:r}}(v,s=A(e,r,n,i));if(x.pointNumbers.length>0?function(t,e){var r,n,i,a=[];for(i=0;i<t.length;i++)(r=t[i]).cd[0].trace.selectedpoints&&r.cd[0].trace.selectedpoints.length>0&&a.push(r);if(1===a.length&&a[0]===e.searchInfo&&(n=e.searchInfo.cd[0].trace).selectedpoints.length===e.pointNumbers.length){for(i=0;i<e.pointNumbers.length;i++)if(n.selectedpoints.indexOf(e.pointNumbers[i])<0)return!1;return!0}return!1}(s,x):function(t){var e,r,n,i=0;for(n=0;n<t.length;n++)if(e=t[n],(r=e.cd[0].trace).selectedpoints){if(r.selectedpoints.length>1)return!1;if((i+=r.selectedpoints.length)>1)return!1}return 1===i}(s)&&(f=S(x))){for(o&&o.remove(),g=0;g<s.length;g++)(l=s[g])._module.selectPoints(l,!1);E(e,s),T(a),m&&e.emit(\"plotly_deselect\",null)}else{for(p=t.shiftKey&&(void 0!==f?f:S(x)),c=function(t,e,r){return{pointNumber:t,searchInfo:e,subtract:r}}(x.pointNumber,x.searchInfo,p),u=w(a.selectionDefs.concat([c])),g=0;g<s.length;g++)if(h=C(s[g]._module.selectPoints(s[g],u),s[g]),y.length)for(var b=0;b<h.length;b++)y.push(h[b]);else y=h;E(e,s,d={points:y}),c&&a&&a.selectionDefs.push(c),o&&M(a.mergedPolygons,o),m&&e.emit(\"plotly_selected\",d)}}}function b(t){return\"pointNumber\"in t&&\"searchInfo\"in t}function _(t){return{xmin:0,xmax:0,ymin:0,ymax:0,pts:[],contains:function(e,r,n,i){var a=t.searchInfo.cd[0].trace._expandedIndex;return i.cd[0].trace._expandedIndex===a&&n===t.pointNumber},isRect:!1,degenerate:!1,subtract:t.subtract}}function w(t){for(var e=[],r=b(t[0])?0:t[0][0][0],n=r,i=b(t[0])?0:t[0][0][1],a=i,o=0;o<t.length;o++)if(b(t[o]))e.push(_(t[o]));else{var s=l.tester(t[o]);s.subtract=t[o].subtract,e.push(s),r=Math.min(r,s.xmin),n=Math.max(n,s.xmax),i=Math.min(i,s.ymin),a=Math.max(a,s.ymax)}return{xmin:r,xmax:n,ymin:i,ymax:a,pts:[],contains:function(t,r,n,i){for(var a=!1,o=0;o<e.length;o++)e[o].contains(t,r,n,i)&&(a=!1===e[o].subtract);return a},isRect:!1,degenerate:!1}}function k(t,e,r){var n=e._fullLayout,i=r.plotinfo,a=n._lastSelectedSubplot&&n._lastSelectedSubplot===i.id,o=t.shiftKey||t.altKey;a&&o&&i.selection&&i.selection.selectionDefs&&!r.selectionDefs?(r.selectionDefs=i.selection.selectionDefs,r.mergedPolygons=i.selection.mergedPolygons):o&&i.selection||T(r),a||(L(e),n._lastSelectedSubplot=i.id)}function T(t){var e=t.plotinfo;e.selection={},e.selection.selectionDefs=t.selectionDefs=[],e.selection.mergedPolygons=t.mergedPolygons=[]}function A(t,e,r,n){var i,a,o,s=[],l=e.map(y),c=r.map(y);for(o=0;o<t.calcdata.length;o++)if(!0===(a=(i=t.calcdata[o])[0].trace).visible&&a._module&&a._module.selectPoints)if(!n||a.subplot!==n&&a.geo!==n)if(\"splom\"===a.type&&a._xaxes[l[0]]&&a._yaxes[c[0]]){var u=p(a._module,i,e[0],r[0]);u.scene=t._fullLayout._splomScenes[a.uid],s.push(u)}else if(\"sankey\"===a.type){var f=p(a._module,i,e[0],r[0]);s.push(f)}else{if(-1===l.indexOf(a.xaxis))continue;if(-1===c.indexOf(a.yaxis))continue;s.push(p(a._module,i,h(t,a.xaxis),h(t,a.yaxis)))}else s.push(p(a._module,i,e[0],r[0]));return s;function p(t,e,r,n){return{_module:t,cd:e,xaxis:r,yaxis:n}}}function M(t,e){var r,n,i=[];for(r=0;r<t.length;r++){var a=t[r];i.push(a.join(\"L\")+\"L\"+a[0])}n=t.length>0?\"M\"+i.join(\"M\")+\"Z\":\"M0,0Z\",e.attr(\"d\",n)}function S(t){var e=t.searchInfo.cd[0].trace,r=t.pointNumber,n=t.pointNumbers,i=n.length>0?n[0]:r;return!!e.selectedpoints&&e.selectedpoints.indexOf(i)>-1}function E(t,e,r){var n,a,o,s;for(n=0;n<e.length;n++){var l=e[n].cd[0].trace._fullInput,c=t._fullLayout._tracePreGUI[l.uid]||{};void 0===c.selectedpoints&&(c.selectedpoints=l._input.selectedpoints||null)}if(r){var u=r.points||[];for(n=0;n<e.length;n++)(s=e[n].cd[0].trace)._input.selectedpoints=s._fullInput.selectedpoints=[],s._fullInput!==s&&(s.selectedpoints=[]);for(n=0;n<u.length;n++){var h=u[n],d=h.data,g=h.fullData;h.pointIndices?([].push.apply(d.selectedpoints,h.pointIndices),s._fullInput!==s&&[].push.apply(g.selectedpoints,h.pointIndices)):(d.selectedpoints.push(h.pointIndex),s._fullInput!==s&&g.selectedpoints.push(h.pointIndex))}}else for(n=0;n<e.length;n++)delete(s=e[n].cd[0].trace).selectedpoints,delete s._input.selectedpoints,s._fullInput!==s&&delete s._fullInput.selectedpoints;var v=!1;for(n=0;n<e.length;n++){s=(o=(a=e[n]).cd)[0].trace,i.traceIs(s,\"regl\")&&(v=!0);var m=a._module,y=m.styleOnSelect||m.style;y&&(y(t,o,o[0].node3),o[0].nodeRangePlot3&&y(t,o,o[0].nodeRangePlot3))}v&&(f(t),p(t))}function C(t,e){if(Array.isArray(t))for(var r=e.cd,n=e.cd[0].trace,i=0;i<t.length;i++)t[i]=u(t[i],n,r);return t}function L(t){var e=(t._fullLayout||{})._zoomlayer;e&&e.selectAll(\".select-outline\").remove()}e.exports={prepSelect:function(t,e,r,i,l){var u,h,f,p,y,b,_,S=i.gd,L=S._fullLayout,P=L._zoomlayer,O=i.element.getBoundingClientRect(),z=i.plotinfo,I=z.xaxis._offset,D=z.yaxis._offset,R=e-O.left,F=r-O.top,B=R,N=F,j=\"M\"+R+\",\"+F,U=i.xaxes[0]._length,V=i.yaxes[0]._length,q=i.xaxes.concat(i.yaxes),H=t.altKey;k(t,S,i),\"lasso\"===l&&(u=v([[R,F]],d.BENDPX));var G=P.selectAll(\"path.select-outline-\"+z.id).data([1,2]);G.enter().append(\"path\").attr(\"class\",function(t){return\"select-outline select-outline-\"+t+\" select-outline-\"+z.id}).attr(\"transform\",\"translate(\"+I+\", \"+D+\")\").attr(\"d\",j+\"Z\");var Y,W=P.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:a.background,stroke:a.defaultLine,\"stroke-width\":1}).attr(\"transform\",\"translate(\"+I+\", \"+D+\")\").attr(\"d\",\"M0,0Z\"),X=L._uid+d.SELECTID,Z=[],J=A(S,i.xaxes,i.yaxes,i.subplot);function K(t,e){return\"log\"===t.type?t.p2d(e):t.p2r(e)}function $(t){var e=\"y\"===t._id.charAt(0)?1:0;return function(r){return K(t,r[e])}}function Q(t,e){return t-e}Y=z.fillRangeItems?z.fillRangeItems:\"select\"===l?function(t,e){var r=t.range={};for(y=0;y<q.length;y++){var n=q[y],i=n._id.charAt(0);r[n._id]=[K(n,e[i+\"min\"]),K(n,e[i+\"max\"])].sort(Q)}}:function(t,e,r){var n=t.lassoPoints={};for(y=0;y<q.length;y++){var i=q[y];n[i._id]=r.filtered.map($(i))}},i.moveFn=function(t,e){B=Math.max(0,Math.min(U,t+R)),N=Math.max(0,Math.min(V,e+F));var r=Math.abs(B-R),a=Math.abs(N-F);if(\"select\"===l){var o=L.selectdirection;\"h\"===(o=\"any\"===L.selectdirection?a<Math.min(.6*r,g)?\"h\":r<Math.min(.6*a,g)?\"v\":\"d\":L.selectdirection)?((p=[[R,0],[R,V],[B,V],[B,0]]).xmin=Math.min(R,B),p.xmax=Math.max(R,B),p.ymin=Math.min(0,V),p.ymax=Math.max(0,V),W.attr(\"d\",\"M\"+p.xmin+\",\"+(F-g)+\"h-4v\"+2*g+\"h4ZM\"+(p.xmax-1)+\",\"+(F-g)+\"h4v\"+2*g+\"h-4Z\")):\"v\"===o?((p=[[0,F],[0,N],[U,N],[U,F]]).xmin=Math.min(0,U),p.xmax=Math.max(0,U),p.ymin=Math.min(F,N),p.ymax=Math.max(F,N),W.attr(\"d\",\"M\"+(R-g)+\",\"+p.ymin+\"v-4h\"+2*g+\"v4ZM\"+(R-g)+\",\"+(p.ymax-1)+\"v4h\"+2*g+\"v-4Z\")):\"d\"===o&&((p=[[R,F],[R,N],[B,N],[B,F]]).xmin=Math.min(R,B),p.xmax=Math.max(R,B),p.ymin=Math.min(F,N),p.ymax=Math.max(F,N),W.attr(\"d\",\"M0,0Z\"))}else\"lasso\"===l&&(u.addPt([B,N]),p=u.filtered);i.selectionDefs&&i.selectionDefs.length?(f=function(t,e,r){return r?n.difference({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions:n.union({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions}(i.mergedPolygons,p,H),p.subtract=H,h=w(i.selectionDefs.concat([p]))):(f=[p],h=m(p)),M(f,G),c.throttle(X,d.SELECTDELAY,function(){var t;Z=[];var e,r=[];for(y=0;y<J.length;y++)if(e=(b=J[y])._module.selectPoints(b,h),r.push(e),t=C(e,b),Z.length)for(var n=0;n<t.length;n++)Z.push(t[n]);else Z=t;E(S,J,_={points:Z}),Y(_,p,u),i.gd.emit(\"plotly_selecting\",_)})},i.clickFn=function(t,e){var r=L.clickmode;W.remove(),c.done(X).then(function(){if(c.clear(X),2===t){for(G.remove(),y=0;y<J.length;y++)(b=J[y])._module.selectPoints(b,!1);E(S,J),T(i),S.emit(\"plotly_deselect\",null)}else r.indexOf(\"select\")>-1&&x(e,S,i.xaxes,i.yaxes,i.subplot,i,G),\"event\"===r&&S.emit(\"plotly_selected\",void 0);o.click(S,e)}).catch(s.error)},i.doneFn=function(){W.remove(),c.done(X).then(function(){c.clear(X),i.gd.emit(\"plotly_selected\",_),p&&i.selectionDefs&&(p.subtract=H,i.selectionDefs.push(p),i.mergedPolygons.length=0,[].push.apply(i.mergedPolygons,f)),i.doneFnCompleted&&i.doneFnCompleted(Z)}).catch(s.error)}},clearSelect:L,selectOnClick:x}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../components/fx/helpers\":628,\"../../lib\":719,\"../../lib/clear_gl_canvases\":704,\"../../lib/polygon\":731,\"../../lib/throttle\":744,\"../../plot_api/subroutines\":758,\"../../registry\":847,\"./axis_ids\":770,\"./constants\":773,polybooljs:473}],785:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=a.cleanNumber,s=a.ms2DateTime,l=a.dateTime2ms,c=a.ensureNumber,u=a.isArrayOrTypedArray,h=t(\"../../constants/numerical\"),f=h.FP_SAFE,p=h.BADNUM,d=h.LOG_CLIP,g=t(\"./constants\"),v=t(\"./axis_ids\");function m(t){return Math.pow(10,t)}function y(t){return null!=t}e.exports=function(t,e){e=e||{};var r=t._id||\"x\",h=r.charAt(0);function x(e,r){if(e>0)return Math.log(e)/Math.LN10;if(e<=0&&r&&t.range&&2===t.range.length){var n=t.range[0],i=t.range[1];return.5*(n+i-2*d*Math.abs(n-i))}return p}function b(e,r,n){var o=l(e,n||t.calendar);if(o===p){if(!i(e))return p;e=+e;var s=Math.floor(10*a.mod(e+.05,1)),c=Math.round(e-s/10);o=l(new Date(c))+s/10}return o}function _(e,r,n){return s(e,r,n||t.calendar)}function w(e){return t._categories[Math.round(e)]}function k(e){if(y(e)){if(void 0===t._categoriesMap&&(t._categoriesMap={}),void 0!==t._categoriesMap[e])return t._categoriesMap[e];t._categories.push(\"number\"==typeof e?String(e):e);var r=t._categories.length-1;return t._categoriesMap[e]=r,r}return p}function T(e){if(t._categoriesMap)return t._categoriesMap[e]}function A(t){var e=T(t);return void 0!==e?e:i(t)?+t:void 0}function M(e){return i(e)?n.round(t._b+t._m*e,2):p}function S(e){return(e-t._b)/t._m}t.c2l=\"log\"===t.type?x:c,t.l2c=\"log\"===t.type?m:c,t.l2p=M,t.p2l=S,t.c2p=\"log\"===t.type?function(t,e){return M(x(t,e))}:M,t.p2c=\"log\"===t.type?function(t){return m(S(t))}:S,-1!==[\"linear\",\"-\"].indexOf(t.type)?(t.d2r=t.r2d=t.d2c=t.r2c=t.d2l=t.r2l=o,t.c2d=t.c2r=t.l2d=t.l2r=c,t.d2p=t.r2p=function(e){return t.l2p(o(e))},t.p2d=t.p2r=S,t.cleanPos=c):\"log\"===t.type?(t.d2r=t.d2l=function(t,e){return x(o(t),e)},t.r2d=t.r2c=function(t){return m(o(t))},t.d2c=t.r2l=o,t.c2d=t.l2r=c,t.c2r=x,t.l2d=m,t.d2p=function(e,r){return t.l2p(t.d2r(e,r))},t.p2d=function(t){return m(S(t))},t.r2p=function(e){return t.l2p(o(e))},t.p2r=S,t.cleanPos=c):\"date\"===t.type?(t.d2r=t.r2d=a.identity,t.d2c=t.r2c=t.d2l=t.r2l=b,t.c2d=t.c2r=t.l2d=t.l2r=_,t.d2p=t.r2p=function(e,r,n){return t.l2p(b(e,0,n))},t.p2d=t.p2r=function(t,e,r){return _(S(t),e,r)},t.cleanPos=function(e){return a.cleanDate(e,p,t.calendar)}):\"category\"===t.type?(t.d2c=t.d2l=k,t.r2d=t.c2d=t.l2d=w,t.d2r=t.d2l_noadd=A,t.r2c=function(e){var r=A(e);return void 0!==r?r:t.fraction2r(.5)},t.l2r=t.c2r=c,t.r2l=A,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return w(S(t))},t.r2p=t.d2p,t.p2r=S,t.cleanPos=function(t){return\"string\"==typeof t&&\"\"!==t?t:c(t)}):\"multicategory\"===t.type&&(t.r2d=t.c2d=t.l2d=w,t.d2r=t.d2l_noadd=A,t.r2c=function(e){var r=A(e);return void 0!==r?r:t.fraction2r(.5)},t.r2c_just_indices=T,t.l2r=t.c2r=c,t.r2l=A,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return w(S(t))},t.r2p=t.d2p,t.p2r=S,t.cleanPos=function(t){return Array.isArray(t)||\"string\"==typeof t&&\"\"!==t?t:c(t)},t.setupMultiCategory=function(n){var i,o,s=t._traceIndices,l=e._axisMatchGroups;if(l&&l.length&&0===t._categories.length)for(i=0;i<l.length;i++){var c=l[i];if(c[r])for(var f in c)if(f!==r){var p=e[v.id2name(f)];s=s.concat(p._traceIndices)}}var d=[[0,{}],[0,{}]],g=[];for(i=0;i<s.length;i++){var m=n[s[i]];if(h in m){var x=m[h],b=m._length||a.minRowLength(x);if(u(x[0])&&u(x[1]))for(o=0;o<b;o++){var _=x[0][o],w=x[1][o];y(_)&&y(w)&&(g.push([_,w]),_ in d[0][1]||(d[0][1][_]=d[0][0]++),w in d[1][1]||(d[1][1][w]=d[1][0]++))}}}for(g.sort(function(t,e){var r=d[0][1],n=r[t[0]]-r[e[0]];if(n)return n;var i=d[1][1];return i[t[1]]-i[e[1]]}),i=0;i<g.length;i++)k(g[i])}),t.fraction2r=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return t.l2r(r+e*(n-r))},t.r2fraction=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return(t.r2l(e)-r)/(n-r)},t.cleanRange=function(e,r){r||(r={}),e||(e=\"range\");var n,o,s=a.nestedProperty(t,e).get();if(o=(o=\"date\"===t.type?a.dfltRange(t.calendar):\"y\"===h?g.DFLTRANGEY:r.dfltRange||g.DFLTRANGEX).slice(),s&&2===s.length)for(\"date\"!==t.type||t.autorange||(s[0]=a.cleanDate(s[0],p,t.calendar),s[1]=a.cleanDate(s[1],p,t.calendar)),n=0;n<2;n++)if(\"date\"===t.type){if(!a.isDateTime(s[n],t.calendar)){t[e]=o;break}if(t.r2l(s[0])===t.r2l(s[1])){var l=a.constrain(t.r2l(s[0]),a.MIN_MS+1e3,a.MAX_MS-1e3);s[0]=t.l2r(l-1e3),s[1]=t.l2r(l+1e3);break}}else{if(!i(s[n])){if(!i(s[1-n])){t[e]=o;break}s[n]=s[1-n]*(n?10:.1)}if(s[n]<-f?s[n]=-f:s[n]>f&&(s[n]=f),s[0]===s[1]){var c=Math.max(1,Math.abs(1e-6*s[0]));s[0]-=c,s[1]+=c}}else a.nestedProperty(t,e).set(o)},t.setScale=function(r){var n=e._size;if(t.overlaying){var i=v.getFromId({_fullLayout:e},t.overlaying);t.domain=i.domain}var a=r&&t._r?\"_r\":\"range\",o=t.calendar;t.cleanRange(a);var s=t.r2l(t[a][0],o),l=t.r2l(t[a][1],o);if(\"y\"===h?(t._offset=n.t+(1-t.domain[1])*n.h,t._length=n.h*(t.domain[1]-t.domain[0]),t._m=t._length/(s-l),t._b=-t._m*l):(t._offset=n.l+t.domain[0]*n.w,t._length=n.w*(t.domain[1]-t.domain[0]),t._m=t._length/(l-s),t._b=-t._m*s),!isFinite(t._m)||!isFinite(t._b)||t._length<0)throw e._replotting=!1,new Error(\"Something went wrong with axis scaling\")},t.makeCalcdata=function(e,r){var n,i,o,s,l=t.type,c=\"date\"===l&&e[r+\"calendar\"];if(r in e){if(n=e[r],s=e._length||a.minRowLength(n),a.isTypedArray(n)&&(\"linear\"===l||\"log\"===l)){if(s===n.length)return n;if(n.subarray)return n.subarray(0,s)}if(\"multicategory\"===l)return function(t,e){for(var r=new Array(e),n=0;n<e;n++){var i=(t[0]||[])[n],a=(t[1]||[])[n];r[n]=T([i,a])}return r}(n,s);for(i=new Array(s),o=0;o<s;o++)i[o]=t.d2c(n[o],0,c)}else{var u=r+\"0\"in e?t.d2c(e[r+\"0\"],0,c):0,h=e[\"d\"+r]?Number(e[\"d\"+r]):1;for(n=e[{x:\"y\",y:\"x\"}[r]],s=e._length||n.length,i=new Array(s),o=0;o<s;o++)i[o]=u+o*h}return i},t.isValidRange=function(e){return Array.isArray(e)&&2===e.length&&i(t.r2l(e[0]))&&i(t.r2l(e[1]))},t.isPtWithinRange=function(e,r){var n=t.c2l(e[h],null,r),i=t.r2l(t.range[0]),a=t.r2l(t.range[1]);return i<a?i<=n&&n<=a:a<=n&&n<=i},t.clearCalc=function(){var n=function(){t._categories=[],t._categoriesMap={}},i=e._axisMatchGroups;if(i&&i.length){for(var a=!1,o=0;o<i.length;o++){var s=i[o];if(s[r]){a=!0;var l=null,c=null;for(var u in s){var h=e[v.id2name(u)];if(h._categories){l=h._categories,c=h._categoriesMap;break}}l&&c?(t._categories=l,t._categoriesMap=c):n();break}}a||n()}else n();if(t._initialCategories)for(var f=0;f<t._initialCategories.length;f++)k(t._initialCategories[f])},t.sortByInitialCategories=function(){var n=[];if(t._categories=[],t._categoriesMap={},t._initialCategories)for(var i=0;i<t._initialCategories.length;i++)k(t._initialCategories[i]);n=n.concat(t._traceIndices);var a=t._matchGroup;for(var o in a)if(r!==o){var s=e[v.id2name(o)];s._categories=t._categories,s._categoriesMap=t._categoriesMap,n=n.concat(s._traceIndices)}return n};var E=e._d3locale;\"date\"===t.type&&(t._dateFormat=E?E.timeFormat.utc:n.time.format.utc,t._extraFormat=e._extraFormat),t._separators=e.separators,t._numFormat=E?E.numberFormat:n.format,delete t._minDtick,delete t._forceTick0}},{\"../../constants/numerical\":695,\"../../lib\":719,\"./axis_ids\":770,\"./constants\":773,d3:163,\"fast-isnumeric\":225}],786:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"../array_container_defaults\");function o(t){var e=[\"showexponent\",\"showtickprefix\",\"showticksuffix\"].filter(function(e){return void 0!==t[e]});if(e.every(function(r){return t[r]===t[e[0]]})||1===e.length)return t[e[0]]}function s(t,e){function r(r,a){return n.coerce(t,e,i.tickformatstops,r,a)}r(\"enabled\")&&(r(\"dtickrange\"),r(\"value\"))}e.exports=function(t,e,r,l,c,u){u&&1!==u.pass||function(t,e,r,n,i){var a=o(t);r(\"tickprefix\")&&r(\"showtickprefix\",a);r(\"ticksuffix\",i.tickSuffixDflt)&&r(\"showticksuffix\",a)}(t,0,r,0,c),u&&2!==u.pass||function(t,e,r,l,c){var u=o(t);r(\"tickprefix\")&&r(\"showtickprefix\",u);r(\"ticksuffix\",c.tickSuffixDflt)&&r(\"showticksuffix\",u);if(r(\"showticklabels\")){var h=c.font||{},f=e.color,p=f&&f!==i.color.dflt?f:h.color;if(n.coerceFont(r,\"tickfont\",{family:h.family,size:h.size,color:p}),r(\"tickangle\"),\"category\"!==l){var d=r(\"tickformat\"),g=t.tickformatstops;Array.isArray(g)&&g.length&&a(t,e,{name:\"tickformatstops\",inclusionAttr:\"enabled\",handleItemDefaults:s}),d||\"date\"===l||(r(\"showexponent\",u),r(\"exponentformat\"),r(\"separatethousands\"))}}}(t,e,r,l,c)}},{\"../../lib\":719,\"../array_container_defaults\":763,\"./layout_attributes\":779}],787:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r,a){var o=n.coerce2(t,e,i,\"ticklen\"),s=n.coerce2(t,e,i,\"tickwidth\"),l=n.coerce2(t,e,i,\"tickcolor\",e.color);r(\"ticks\",a.outerTicks||o||s||l?\"outside\":\"\")||(delete e.ticklen,delete e.tickwidth,delete e.tickcolor)}},{\"../../lib\":719,\"./layout_attributes\":779}],788:[function(t,e,r){\"use strict\";var n=t(\"./clean_ticks\");e.exports=function(t,e,r,i){var a;\"array\"!==t.tickmode||\"log\"!==i&&\"date\"!==i?a=r(\"tickmode\",Array.isArray(t.tickvals)?\"array\":t.dtick?\"linear\":\"auto\"):a=e.tickmode=\"auto\";if(\"auto\"===a)r(\"nticks\");else if(\"linear\"===a){var o=e.dtick=n.dtick(t.dtick,i);e.tick0=n.tick0(t.tick0,i,e.calendar,o)}else if(\"multicategory\"!==i){void 0===r(\"tickvals\")?e.tickmode=\"auto\":r(\"ticktext\")}}},{\"./clean_ticks\":772}],789:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../components/drawing\"),o=t(\"./axes\");e.exports=function(t,e,r,s){var l=t._fullLayout;if(0!==e.length){var c,u,h,f;s&&(c=s());var p=n.ease(r.easing);return t._transitionData._interruptCallbacks.push(function(){return window.cancelAnimationFrame(f),f=null,function(){for(var r={},n=0;n<e.length;n++){var a=e[n];a.xr0&&(r[a.plotinfo.xaxis._name+\".range\"]=a.xr0.slice()),a.yr0&&(r[a.plotinfo.yaxis._name+\".range\"]=a.yr0.slice())}return i.call(\"relayout\",t,r).then(function(){for(var t=0;t<e.length;t++)d(e[t].plotinfo)})}()}),u=Date.now(),f=window.requestAnimationFrame(function n(){h=Date.now();for(var a=Math.min(1,(h-u)/r.duration),o=p(a),s=0;s<e.length;s++)g(e[s],o);h-u>r.duration?(function(){for(var r={},n=0;n<e.length;n++){var a=e[n];a.xr1&&(r[a.plotinfo.xaxis._name+\".range\"]=a.xr1.slice()),a.yr1&&(r[a.plotinfo.yaxis._name+\".range\"]=a.yr1.slice())}c&&c(),i.call(\"relayout\",t,r).then(function(){for(var t=0;t<e.length;t++)d(e[t].plotinfo)})}(),f=window.cancelAnimationFrame(n)):f=window.requestAnimationFrame(n)}),Promise.resolve()}function d(t){var e=t.xaxis,r=t.yaxis;l._defs.select(\"#\"+t.clipId+\"> rect\").call(a.setTranslate,0,0).call(a.setScale,1,1),t.plot.call(a.setTranslate,e._offset,r._offset).call(a.setScale,1,1);var n=t.plot.selectAll(\".scatterlayer .trace\");n.selectAll(\".point\").call(a.setPointGroupScale,1,1),n.selectAll(\".textpoint\").call(a.setTextPointsScale,1,1),n.call(a.hideOutsideRangePoints,t)}function g(e,r){var n=e.plotinfo,i=n.xaxis,s=n.yaxis,l=e.xr0,c=e.xr1,u=i._length,h=e.yr0,f=e.yr1,p=s._length,d=!!c,g=!!f,v=[];if(d){var m=l[1]-l[0],y=c[1]-c[0];v[0]=(l[0]*(1-r)+r*c[0]-l[0])/(l[1]-l[0])*u,v[2]=u*(1-r+r*y/m),i.range[0]=l[0]*(1-r)+r*c[0],i.range[1]=l[1]*(1-r)+r*c[1]}else v[0]=0,v[2]=u;if(g){var x=h[1]-h[0],b=f[1]-f[0];v[1]=(h[1]*(1-r)+r*f[1]-h[1])/(h[0]-h[1])*p,v[3]=p*(1-r+r*b/x),s.range[0]=h[0]*(1-r)+r*f[0],s.range[1]=h[1]*(1-r)+r*f[1]}else v[1]=0,v[3]=p;o.drawOne(t,i,{skipTitle:!0}),o.drawOne(t,s,{skipTitle:!0}),o.redrawComponents(t,[i._id,s._id]);var _=d?u/v[2]:1,w=g?p/v[3]:1,k=d?v[0]:0,T=g?v[1]:0,A=d?v[0]/v[2]*u:0,M=g?v[1]/v[3]*p:0,S=i._offset-A,E=s._offset-M;n.clipRect.call(a.setTranslate,k,T).call(a.setScale,1/_,1/w),n.plot.call(a.setTranslate,S,E).call(a.setScale,_,w),a.setPointGroupScale(n.zoomScalePts,1/_,1/w),a.setTextPointsScale(n.zoomScaleTxt,1/_,1/w)}o.redrawComponents(t)}},{\"../../components/drawing\":614,\"../../registry\":847,\"./axes\":767,d3:163}],790:[function(t,e,r){\"use strict\";var n=t(\"../../registry\").traceIs,i=t(\"./axis_autotype\");function a(t){return{v:\"x\",h:\"y\"}[t.orientation||\"v\"]}function o(t,e){var r=a(t),i=n(t,\"box-violin\"),o=n(t._fullInput||{},\"candlestick\");return i&&!o&&e===r&&void 0===t[r]&&void 0===t[r+\"0\"]}e.exports=function(t,e,r,s){\"-\"===r(\"type\",(s.splomStash||{}).type)&&(!function(t,e){if(\"-\"!==t.type)return;var r=t._id,s=r.charAt(0);-1!==r.indexOf(\"scene\")&&(r=s);var l=function(t,e,r){for(var n=0;n<t.length;n++){var i=t[n];if(\"splom\"===i.type&&i._length>0&&(i[\"_\"+r+\"axes\"]||{})[e])return i;if((i[r+\"axis\"]||r)===e){if(o(i,r))return i;if((i[r]||[]).length||i[r+\"0\"])return i}}}(e,r,s);if(!l)return;if(\"histogram\"===l.type&&s==={v:\"y\",h:\"x\"}[l.orientation||\"v\"])return void(t.type=\"linear\");var c,u=s+\"calendar\",h=l[u],f={noMultiCategory:!n(l,\"cartesian\")||n(l,\"noMultiCategory\")};if(o(l,s)){var p=a(l),d=[];for(c=0;c<e.length;c++){var g=e[c];n(g,\"box-violin\")&&(g[s+\"axis\"]||s)===r&&(void 0!==g[p]?d.push(g[p][0]):void 0!==g.name?d.push(g.name):d.push(\"text\"),g[u]!==h&&(h=void 0))}t.type=i(d,h,f)}else if(\"splom\"===l.type){var v=l.dimensions,m=v[l._axesDim[r]];m.visible&&(t.type=i(m.values,h,f))}else t.type=i(l[s]||[l[s+\"0\"]],h,f)}(e,s.data),\"-\"===e.type?e.type=\"linear\":t.type=e.type)}},{\"../../registry\":847,\"./axis_autotype\":768}],791:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\");function a(t,e,r){var n,a,o,s=!1;if(\"data\"===e.type)n=t._fullData[null!==e.traces?e.traces[0]:0];else{if(\"layout\"!==e.type)return!1;n=t._fullLayout}return a=i.nestedProperty(n,e.prop).get(),(o=r[e.type]=r[e.type]||{}).hasOwnProperty(e.prop)&&o[e.prop]!==a&&(s=!0),o[e.prop]=a,{changed:s,value:a}}function o(t,e){var r=[],n=e[0],a={};if(\"string\"==typeof n)a[n]=e[1];else{if(!i.isPlainObject(n))return r;a=n}return l(a,function(t,e,n){r.push({type:\"layout\",prop:t,value:n})},\"\",0),r}function s(t,e){var r,n,a,o,s=[];if(n=e[0],a=e[1],r=e[2],o={},\"string\"==typeof n)o[n]=a;else{if(!i.isPlainObject(n))return s;o=n,void 0===r&&(r=a)}return void 0===r&&(r=null),l(o,function(e,n,i){var a,o;if(Array.isArray(i)){o=i.slice();var l=Math.min(o.length,t.data.length);r&&(l=Math.min(l,r.length)),a=[];for(var c=0;c<l;c++)a[c]=r?r[c]:c}else o=i,a=r?r.slice():null;if(null===a)Array.isArray(o)&&(o=o[0]);else if(Array.isArray(a)){if(!Array.isArray(o)){var u=o;o=[];for(var h=0;h<a.length;h++)o[h]=u}o.length=Math.min(a.length,o.length)}s.push({type:\"data\",prop:e,traces:a,value:o})},\"\",0),s}function l(t,e,r,n){Object.keys(t).forEach(function(a){var o=t[a];if(\"_\"!==a[0]){var s=r+(n>0?\".\":\"\")+a;i.isPlainObject(o)?l(o,e,s,n+1):e(s,a,o)}})}r.manageCommandObserver=function(t,e,n,o){var s={},l=!0;e&&e._commandObserver&&(s=e._commandObserver),s.cache||(s.cache={}),s.lookupTable={};var c=r.hasSimpleAPICommandBindings(t,n,s.lookupTable);if(e&&e._commandObserver){if(c)return s;if(e._commandObserver.remove)return e._commandObserver.remove(),e._commandObserver=null,s}if(c){a(t,c,s.cache),s.check=function(){if(l){var e=a(t,c,s.cache);return e.changed&&o&&void 0!==s.lookupTable[e.value]&&(s.disable(),Promise.resolve(o({value:e.value,type:c.type,prop:c.prop,traces:c.traces,index:s.lookupTable[e.value]})).then(s.enable,s.enable)),e.changed}};for(var u=[\"plotly_relayout\",\"plotly_redraw\",\"plotly_restyle\",\"plotly_update\",\"plotly_animatingframe\",\"plotly_afterplot\"],h=0;h<u.length;h++)t._internalOn(u[h],s.check);s.remove=function(){for(var e=0;e<u.length;e++)t._removeInternalListener(u[e],s.check)}}else i.log(\"Unable to automatically bind plot updates to API command\"),s.lookupTable={},s.remove=function(){};return s.disable=function(){l=!1},s.enable=function(){l=!0},e&&(e._commandObserver=s),s},r.hasSimpleAPICommandBindings=function(t,e,n){var i,a,o=e.length;for(i=0;i<o;i++){var s,l=e[i],c=l.method,u=l.args;if(Array.isArray(u)||(u=[]),!c)return!1;var h=r.computeAPICommandBindings(t,c,u);if(1!==h.length)return!1;if(a){if((s=h[0]).type!==a.type)return!1;if(s.prop!==a.prop)return!1;if(Array.isArray(a.traces)){if(!Array.isArray(s.traces))return!1;s.traces.sort();for(var f=0;f<a.traces.length;f++)if(a.traces[f]!==s.traces[f])return!1}else if(s.prop!==a.prop)return!1}else a=h[0],Array.isArray(a.traces)&&a.traces.sort();var p=(s=h[0]).value;if(Array.isArray(p)){if(1!==p.length)return!1;p=p[0]}n&&(n[p]=i)}return a},r.executeAPICommand=function(t,e,r){if(\"skip\"===e)return Promise.resolve();var a=n.apiMethodRegistry[e],o=[t];Array.isArray(r)||(r=[]);for(var s=0;s<r.length;s++)o.push(r[s]);return a.apply(null,o).catch(function(t){return i.warn(\"API call to Plotly.\"+e+\" rejected.\",t),Promise.reject(t)})},r.computeAPICommandBindings=function(t,e,r){var n;switch(Array.isArray(r)||(r=[]),e){case\"restyle\":n=s(t,r);break;case\"relayout\":n=o(t,r);break;case\"update\":n=s(t,[r[0],r[2]]).concat(o(t,[r[1]]));break;case\"animate\":n=function(t,e){return Array.isArray(e[0])&&1===e[0].length&&-1!==[\"string\",\"number\"].indexOf(typeof e[0][0])?[{type:\"layout\",prop:\"_currentFrame\",value:e[0][0].toString()}]:[]}(0,r);break;default:n=[]}return n}},{\"../lib\":719,\"../registry\":847}],792:[function(t,e,r){\"use strict\";var n=t(\"../lib/extend\").extendFlat;r.attributes=function(t,e){e=e||{};var r={valType:\"info_array\",editType:(t=t||{}).editType,items:[{valType:\"number\",min:0,max:1,editType:t.editType},{valType:\"number\",min:0,max:1,editType:t.editType}],dflt:[0,1]},i=(t.name&&t.name,t.trace,e.description&&e.description,{x:n({},r,{}),y:n({},r,{}),editType:t.editType});return t.noGridCell||(i.row={valType:\"integer\",min:0,dflt:0,editType:t.editType},i.column={valType:\"integer\",min:0,dflt:0,editType:t.editType}),i},r.defaults=function(t,e,r,n){var i=n&&n.x||[0,1],a=n&&n.y||[0,1],o=e.grid;if(o){var s=r(\"domain.column\");void 0!==s&&(s<o.columns?i=o._domains.x[s]:delete t.domain.column);var l=r(\"domain.row\");void 0!==l&&(l<o.rows?a=o._domains.y[l]:delete t.domain.row)}r(\"domain.x\",i),r(\"domain.y\",a)}},{\"../lib/extend\":710}],793:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType,r=t.colorEditType;void 0===r&&(r=e);var n={family:{valType:\"string\",noBlank:!0,strict:!0,editType:e},size:{valType:\"number\",min:1,editType:e},color:{valType:\"color\",editType:r},editType:e};return t.arrayOk&&(n.family.arrayOk=!0,n.size.arrayOk=!0,n.color.arrayOk=!0),n}},{}],794:[function(t,e,r){\"use strict\";e.exports={_isLinkedToArray:\"frames_entry\",group:{valType:\"string\"},name:{valType:\"string\"},traces:{valType:\"any\"},baseframe:{valType:\"string\"},data:{valType:\"any\"},layout:{valType:\"any\"}}},{}],795:[function(t,e,r){\"use strict\";r.projNames={equirectangular:\"equirectangular\",mercator:\"mercator\",orthographic:\"orthographic\",\"natural earth\":\"naturalEarth\",kavrayskiy7:\"kavrayskiy7\",miller:\"miller\",robinson:\"robinson\",eckert4:\"eckert4\",\"azimuthal equal area\":\"azimuthalEqualArea\",\"azimuthal equidistant\":\"azimuthalEquidistant\",\"conic equal area\":\"conicEqualArea\",\"conic conformal\":\"conicConformal\",\"conic equidistant\":\"conicEquidistant\",gnomonic:\"gnomonic\",stereographic:\"stereographic\",mollweide:\"mollweide\",hammer:\"hammer\",\"transverse mercator\":\"transverseMercator\",\"albers usa\":\"albersUsa\",\"winkel tripel\":\"winkel3\",aitoff:\"aitoff\",sinusoidal:\"sinusoidal\"},r.axesNames=[\"lonaxis\",\"lataxis\"],r.lonaxisSpan={orthographic:180,\"azimuthal equal area\":360,\"azimuthal equidistant\":360,\"conic conformal\":180,gnomonic:160,stereographic:180,\"transverse mercator\":180,\"*\":360},r.lataxisSpan={\"conic conformal\":150,stereographic:179.5,\"*\":180},r.scopeDefaults={world:{lonaxisRange:[-180,180],lataxisRange:[-90,90],projType:\"equirectangular\",projRotate:[0,0,0]},usa:{lonaxisRange:[-180,-50],lataxisRange:[15,80],projType:\"albers usa\"},europe:{lonaxisRange:[-30,60],lataxisRange:[30,85],projType:\"conic conformal\",projRotate:[15,0,0],projParallels:[0,60]},asia:{lonaxisRange:[22,160],lataxisRange:[-15,55],projType:\"mercator\",projRotate:[0,0,0]},africa:{lonaxisRange:[-30,60],lataxisRange:[-40,40],projType:\"mercator\",projRotate:[0,0,0]},\"north america\":{lonaxisRange:[-180,-45],lataxisRange:[5,85],projType:\"conic conformal\",projRotate:[-100,0,0],projParallels:[29.5,45.5]},\"south america\":{lonaxisRange:[-100,-30],lataxisRange:[-60,15],projType:\"mercator\",projRotate:[0,0,0]}},r.clipPad=.001,r.precision=.1,r.landColor=\"#F0DC82\",r.waterColor=\"#3399FF\",r.locationmodeToLayer={\"ISO-3\":\"countries\",\"USA-states\":\"subunits\",\"country names\":\"countries\"},r.sphereSVG={type:\"Sphere\"},r.fillLayers={ocean:1,land:1,lakes:1},r.lineLayers={subunits:1,countries:1,coastlines:1,rivers:1,frame:1},r.layers=[\"bg\",\"ocean\",\"land\",\"lakes\",\"subunits\",\"countries\",\"coastlines\",\"rivers\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"frontplot\"],r.layersForChoropleth=[\"bg\",\"ocean\",\"land\",\"subunits\",\"countries\",\"coastlines\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"rivers\",\"lakes\",\"frontplot\"],r.layerNameToAdjective={ocean:\"ocean\",land:\"land\",lakes:\"lake\",subunits:\"subunit\",countries:\"country\",coastlines:\"coastline\",rivers:\"river\",frame:\"frame\"}},{}],796:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"../../components/fx\"),c=t(\"../plots\"),u=t(\"../cartesian/axes\"),h=t(\"../../components/dragelement\"),f=t(\"../cartesian/select\").prepSelect,p=t(\"../cartesian/select\").selectOnClick,d=t(\"./zoom\"),g=t(\"./constants\"),v=t(\"../../lib/topojson_utils\"),m=t(\"topojson-client\").feature;function y(t){this.id=t.id,this.graphDiv=t.graphDiv,this.container=t.container,this.topojsonURL=t.topojsonURL,this.isStatic=t.staticPlot,this.topojsonName=null,this.topojson=null,this.projection=null,this.scope=null,this.viewInitial=null,this.fitScale=null,this.bounds=null,this.midPt=null,this.hasChoropleth=!1,this.traceHash={},this.layers={},this.basePaths={},this.dataPaths={},this.dataPoints={},this.clipDef=null,this.clipRect=null,this.bgRect=null,this.makeFramework()}t(\"./projections\")(n);var x=y.prototype;e.exports=function(t){return new y(t)},x.plot=function(t,e,r){var n=this,i=e[this.id],a=!1;for(var o in g.layerNameToAdjective)if(\"frame\"!==o&&i[\"show\"+o]){a=!0;break}for(var s=0;s<t.length;s++)if(t[0][0].trace.locationmode){a=!0;break}if(!a)return n.update(t,e);var l=v.getTopojsonName(i);null===n.topojson||l!==n.topojsonName?(n.topojsonName=l,void 0===PlotlyGeoAssets.topojson[n.topojsonName]?r.push(n.fetchTopojson().then(function(r){PlotlyGeoAssets.topojson[n.topojsonName]=r,n.topojson=r,n.update(t,e)})):(n.topojson=PlotlyGeoAssets.topojson[n.topojsonName],n.update(t,e))):n.update(t,e)},x.fetchTopojson=function(){var t=v.getTopojsonPath(this.topojsonURL,this.topojsonName);return new Promise(function(e,r){n.json(t,function(n,i){if(n)return 404===n.status?r(new Error([\"plotly.js could not find topojson file at\",t,\".\",\"Make sure the *topojsonURL* plot config option\",\"is set properly.\"].join(\" \"))):r(new Error([\"unexpected error while fetching topojson file at\",t].join(\" \")));e(i)})})},x.update=function(t,e){var r=e[this.id];if(!this.updateProjection(e,r)){this.hasChoropleth=!1;for(var n=0;n<t.length;n++)if(\"choropleth\"===t[n][0].trace.type){this.hasChoropleth=!0;break}this.viewInitial&&this.scope===r.scope||this.saveViewInitial(r),this.scope=r.scope,this.updateBaseLayers(e,r),this.updateDims(e,r),this.updateFx(e,r),c.generalUpdatePerTraceModule(this.graphDiv,this,t,r);var i=this.layers.frontplot.select(\".scatterlayer\");this.dataPoints.point=i.selectAll(\".point\"),this.dataPoints.text=i.selectAll(\"text\"),this.dataPaths.line=i.selectAll(\".js-line\");var a=this.layers.backplot.select(\".choroplethlayer\");this.dataPaths.choropleth=a.selectAll(\"path\"),this.render()}},x.updateProjection=function(t,e){var r=t._size,o=e.domain,s=e.projection,l=s.rotation||{},c=e.center||{},u=this.projection=function(t){for(var e=t.projection.type,r=n.geo[g.projNames[e]](),i=t._isClipped?g.lonaxisSpan[e]/2:null,a=[\"center\",\"rotate\",\"parallels\",\"clipExtent\"],o=function(t){return t?r:[]},s=0;s<a.length;s++){var l=a[s];\"function\"!=typeof r[l]&&(r[l]=o)}r.isLonLatOverEdges=function(t){if(null===r(t))return!0;if(i){var e=r.rotate();return n.geo.distance(t,[-e[0],-e[1]])>i*Math.PI/180}return!1},r.getPath=function(){return n.geo.path().projection(r)},r.getBounds=function(t){return r.getPath().bounds(t)},r.fitExtent=function(t,e){var n=t[1][0]-t[0][0],i=t[1][1]-t[0][1],a=r.clipExtent&&r.clipExtent();r.scale(150).translate([0,0]),a&&r.clipExtent(null);var o=r.getBounds(e),s=Math.min(n/(o[1][0]-o[0][0]),i/(o[1][1]-o[0][1])),l=+t[0][0]+(n-s*(o[1][0]+o[0][0]))/2,c=+t[0][1]+(i-s*(o[1][1]+o[0][1]))/2;return a&&r.clipExtent(a),r.scale(150*s).translate([l,c])},r.precision(g.precision),i&&r.clipAngle(i-g.clipPad);return r}(e);u.center([c.lon-l.lon,c.lat-l.lat]).rotate([-l.lon,-l.lat,l.roll]).parallels(s.parallels);var h=[[r.l+r.w*o.x[0],r.t+r.h*(1-o.y[1])],[r.l+r.w*o.x[1],r.t+r.h*(1-o.y[0])]],f=e.lonaxis,p=e.lataxis,d=function(t,e){var r=g.clipPad,n=t[0]+r,i=t[1]-r,a=e[0]+r,o=e[1]-r;n>0&&i<0&&(i+=360);var s=(i-n)/4;return{type:\"Polygon\",coordinates:[[[n,a],[n,o],[n+s,o],[n+2*s,o],[n+3*s,o],[i,o],[i,a],[i-s,a],[i-2*s,a],[i-3*s,a],[n,a]]]}}(f.range,p.range);u.fitExtent(h,d);var v=this.bounds=u.getBounds(d),m=this.fitScale=u.scale(),y=u.translate();if(!isFinite(v[0][0])||!isFinite(v[0][1])||!isFinite(v[1][0])||!isFinite(v[1][1])||isNaN(y[0])||isNaN(y[0])){for(var x=this.graphDiv,b=[\"projection.rotation\",\"center\",\"lonaxis.range\",\"lataxis.range\"],_=\"Invalid geo settings, relayout'ing to default view.\",w={},k=0;k<b.length;k++)w[this.id+\".\"+b[k]]=null;return this.viewInitial=null,a.warn(_),x._promises.push(i.call(\"relayout\",x,w)),_}var T=this.midPt=[(v[0][0]+v[1][0])/2,(v[0][1]+v[1][1])/2];if(u.scale(s.scale*m).translate([y[0]+(T[0]-y[0]),y[1]+(T[1]-y[1])]).clipExtent(v),e._isAlbersUsa){var A=u([c.lon,c.lat]),M=u.translate();u.translate([M[0]-(A[0]-M[0]),M[1]-(A[1]-M[1])])}},x.updateBaseLayers=function(t,e){var r=this,i=r.topojson,a=r.layers,l=r.basePaths;function c(t){return\"lonaxis\"===t||\"lataxis\"===t}function h(t){return Boolean(g.lineLayers[t])}function f(t){return Boolean(g.fillLayers[t])}var p=(this.hasChoropleth?g.layersForChoropleth:g.layers).filter(function(t){return h(t)||f(t)?e[\"show\"+t]:!c(t)||e[t].showgrid}),d=r.framework.selectAll(\".layer\").data(p,String);d.exit().each(function(t){delete a[t],delete l[t],n.select(this).remove()}),d.enter().append(\"g\").attr(\"class\",function(t){return\"layer \"+t}).each(function(t){var e=a[t]=n.select(this);\"bg\"===t?r.bgRect=e.append(\"rect\").style(\"pointer-events\",\"all\"):c(t)?l[t]=e.append(\"path\").style(\"fill\",\"none\"):\"backplot\"===t?e.append(\"g\").classed(\"choroplethlayer\",!0):\"frontplot\"===t?e.append(\"g\").classed(\"scatterlayer\",!0):h(t)?l[t]=e.append(\"path\").style(\"fill\",\"none\").style(\"stroke-miterlimit\",2):f(t)&&(l[t]=e.append(\"path\").style(\"stroke\",\"none\"))}),d.order(),d.each(function(r){var n=l[r],a=g.layerNameToAdjective[r];\"frame\"===r?n.datum(g.sphereSVG):h(r)||f(r)?n.datum(m(i,i.objects[r])):c(r)&&n.datum(function(t,e,r){var n,i,a,o=e[t],s=g.scopeDefaults[e.scope];\"lonaxis\"===t?(n=s.lonaxisRange,i=s.lataxisRange,a=function(t,e){return[t,e]}):\"lataxis\"===t&&(n=s.lataxisRange,i=s.lonaxisRange,a=function(t,e){return[e,t]});var l={type:\"linear\",range:[n[0],n[1]-1e-6],tick0:o.tick0,dtick:o.dtick};u.setConvert(l,r);var c=u.calcTicks(l);e.isScoped||\"lonaxis\"!==t||c.pop();for(var h=c.length,f=new Array(h),p=0;p<h;p++)for(var d=c[p].x,v=f[p]=[],m=i[0];m<i[1]+2.5;m+=2.5)v.push(a(d,m));return{type:\"MultiLineString\",coordinates:f}}(r,e,t)).call(o.stroke,e[r].gridcolor).call(s.dashLine,\"\",e[r].gridwidth),h(r)?n.call(o.stroke,e[a+\"color\"]).call(s.dashLine,\"\",e[a+\"width\"]):f(r)&&n.call(o.fill,e[a+\"color\"])})},x.updateDims=function(t,e){var r=this.bounds,n=(e.framewidth||0)/2,i=r[0][0]-n,a=r[0][1]-n,l=r[1][0]-i+n,c=r[1][1]-a+n;s.setRect(this.clipRect,i,a,l,c),this.bgRect.call(s.setRect,i,a,l,c).call(o.fill,e.bgcolor),this.xaxis._offset=i,this.xaxis._length=l,this.yaxis._offset=a,this.yaxis._length=c},x.updateFx=function(t,e){var r=this,a=r.graphDiv,o=r.bgRect,s=t.dragmode,c=t.clickmode;if(!r.isStatic){var u;\"select\"===s?u=function(t,e){(t.range={})[r.id]=[v([e.xmin,e.ymin]),v([e.xmax,e.ymax])]}:\"lasso\"===s&&(u=function(t,e,n){(t.lassoPoints={})[r.id]=n.filtered.map(v)});var g={element:r.bgRect.node(),gd:a,plotinfo:{id:r.id,xaxis:r.xaxis,yaxis:r.yaxis,fillRangeItems:u},xaxes:[r.xaxis],yaxes:[r.yaxis],subplot:r.id,clickFn:function(e){2===e&&t._zoomlayer.selectAll(\".select-outline\").remove()}};\"pan\"===s?(o.node().onmousedown=null,o.call(d(r,e)),o.on(\"dblclick.zoom\",function(){var t=r.viewInitial,e={};for(var n in t)e[r.id+\".\"+n]=t[n];i.call(\"_guiRelayout\",a,e),a.emit(\"plotly_doubleclick\",null)}),a._context._scrollZoom.geo||o.on(\"wheel.zoom\",null)):\"select\"!==s&&\"lasso\"!==s||(o.on(\".zoom\",null),g.prepFn=function(t,e,r){f(t,e,r,g,s)},h.init(g)),o.on(\"mousemove\",function(){var t=r.projection.invert(n.mouse(this));if(!t||isNaN(t[0])||isNaN(t[1]))return h.unhover(a,n.event);r.xaxis.p2c=function(){return t[0]},r.yaxis.p2c=function(){return t[1]},l.hover(a,n.event,r.id)}),o.on(\"mouseout\",function(){a._dragging||h.unhover(a,n.event)}),o.on(\"click\",function(){\"select\"!==s&&\"lasso\"!==s&&(c.indexOf(\"select\")>-1&&p(n.event,a,[r.xaxis],[r.yaxis],r.id,g),c.indexOf(\"event\")>-1&&l.click(a,n.event))})}function v(t){return r.projection.invert([t[0]+r.xaxis._offset,t[1]+r.yaxis._offset])}},x.makeFramework=function(){var t=this,e=t.graphDiv,r=e._fullLayout,i=\"clip\"+r._uid+t.id;t.clipDef=r._clips.append(\"clipPath\").attr(\"id\",i),t.clipRect=t.clipDef.append(\"rect\"),t.framework=n.select(t.container).append(\"g\").attr(\"class\",\"geo \"+t.id).call(s.setClipUrl,i,e),t.project=function(e){var r=t.projection(e);return r?[r[0]-t.xaxis._offset,r[1]-t.yaxis._offset]:[null,null]},t.xaxis={_id:\"x\",c2p:function(e){return t.project(e)[0]}},t.yaxis={_id:\"y\",c2p:function(e){return t.project(e)[1]}},t.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},u.setConvert(t.mockAxis,r)},x.saveViewInitial=function(t){var e=t.center||{},r=t.projection,n=r.rotation||{};t._isScoped?this.viewInitial={\"center.lon\":e.lon,\"center.lat\":e.lat,\"projection.scale\":r.scale}:t._isClipped?this.viewInitial={\"projection.scale\":r.scale,\"projection.rotation.lon\":n.lon,\"projection.rotation.lat\":n.lat}:this.viewInitial={\"center.lon\":e.lon,\"center.lat\":e.lat,\"projection.scale\":r.scale,\"projection.rotation.lon\":n.lon}},x.render=function(){var t,e=this.projection,r=e.getPath();function n(t){var r=e(t.lonlat);return r?\"translate(\"+r[0]+\",\"+r[1]+\")\":null}function i(t){return e.isLonLatOverEdges(t.lonlat)?\"none\":null}for(t in this.basePaths)this.basePaths[t].attr(\"d\",r);for(t in this.dataPaths)this.dataPaths[t].attr(\"d\",function(t){return r(t.geojson)});for(t in this.dataPoints)this.dataPoints[t].attr(\"display\",i).attr(\"transform\",n)}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../lib\":719,\"../../lib/topojson_utils\":746,\"../../registry\":847,\"../cartesian/axes\":767,\"../cartesian/select\":784,\"../plots\":828,\"./constants\":795,\"./projections\":800,\"./zoom\":801,d3:163,\"topojson-client\":540}],797:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./geo\"),o=\"geo\",s=i(o),l={};l[o]={valType:\"subplotid\",dflt:o,editType:\"calc\"},e.exports={attr:o,name:o,idRoot:o,idRegex:s,attrRegex:s,attributes:l,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[o],s=0;s<i.length;s++){var l=i[s],c=n(r,o,l),u=e[l]._subplot;u||(u=a({id:l,graphDiv:t,container:e._geolayer.node(),topojsonURL:t._context.topojsonURL,staticPlot:t._context.staticPlot}),e[l]._subplot=u),u.plot(c,e,t._promises)}},updateFx:function(t){for(var e=t._fullLayout,r=e._subplots[o],n=0;n<r.length;n++){var i=e[r[n]];i._subplot.updateFx(e,i)}},clean:function(t,e,r,n){for(var i=n._subplots[o]||[],a=0;a<i.length;a++){var s=i[a],l=n[s]._subplot;!e[s]&&l&&(l.framework.remove(),l.clipDef.remove())}}}},{\"../../lib\":719,\"../../plots/get_data\":802,\"./geo\":796,\"./layout_attributes\":798,\"./layout_defaults\":799}],798:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"./constants\"),o=t(\"../../plot_api/edit_types\").overrideAll,s={range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},showgrid:{valType:\"boolean\",dflt:!1},tick0:{valType:\"number\",dflt:0},dtick:{valType:\"number\"},gridcolor:{valType:\"color\",dflt:n.lightLine},gridwidth:{valType:\"number\",min:0,dflt:1}};(e.exports=o({domain:i({name:\"geo\"},{}),resolution:{valType:\"enumerated\",values:[110,50],dflt:110,coerceNumber:!0},scope:{valType:\"enumerated\",values:Object.keys(a.scopeDefaults),dflt:\"world\"},projection:{type:{valType:\"enumerated\",values:Object.keys(a.projNames)},rotation:{lon:{valType:\"number\"},lat:{valType:\"number\"},roll:{valType:\"number\"}},parallels:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},scale:{valType:\"number\",min:0,dflt:1}},center:{lon:{valType:\"number\"},lat:{valType:\"number\"}},showcoastlines:{valType:\"boolean\"},coastlinecolor:{valType:\"color\",dflt:n.defaultLine},coastlinewidth:{valType:\"number\",min:0,dflt:1},showland:{valType:\"boolean\",dflt:!1},landcolor:{valType:\"color\",dflt:a.landColor},showocean:{valType:\"boolean\",dflt:!1},oceancolor:{valType:\"color\",dflt:a.waterColor},showlakes:{valType:\"boolean\",dflt:!1},lakecolor:{valType:\"color\",dflt:a.waterColor},showrivers:{valType:\"boolean\",dflt:!1},rivercolor:{valType:\"color\",dflt:a.waterColor},riverwidth:{valType:\"number\",min:0,dflt:1},showcountries:{valType:\"boolean\"},countrycolor:{valType:\"color\",dflt:n.defaultLine},countrywidth:{valType:\"number\",min:0,dflt:1},showsubunits:{valType:\"boolean\"},subunitcolor:{valType:\"color\",dflt:n.defaultLine},subunitwidth:{valType:\"number\",min:0,dflt:1},showframe:{valType:\"boolean\"},framecolor:{valType:\"color\",dflt:n.defaultLine},framewidth:{valType:\"number\",min:0,dflt:1},bgcolor:{valType:\"color\",dflt:n.background},lonaxis:s,lataxis:s},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":592,\"../../plot_api/edit_types\":750,\"../domain\":792,\"./constants\":795}],799:[function(t,e,r){\"use strict\";var n=t(\"../subplot_defaults\"),i=t(\"./constants\"),a=t(\"./layout_attributes\"),o=i.axesNames;function s(t,e,r){var n=r(\"resolution\"),a=r(\"scope\"),s=i.scopeDefaults[a],l=r(\"projection.type\",s.projType),c=e._isAlbersUsa=\"albers usa\"===l;c&&(a=e.scope=\"usa\");var u=e._isScoped=\"world\"!==a,h=e._isConic=-1!==l.indexOf(\"conic\");e._isClipped=!!i.lonaxisSpan[l];for(var f=0;f<o.length;f++){var p,d=o[f],g=[30,10][f];if(u)p=s[d+\"Range\"];else{var v=i[d+\"Span\"],m=(v[l]||v[\"*\"])/2,y=r(\"projection.rotation.\"+d.substr(0,3),s.projRotate[f]);p=[y-m,y+m]}r(d+\".range\",p),r(d+\".tick0\"),r(d+\".dtick\",g),r(d+\".showgrid\")&&(r(d+\".gridcolor\"),r(d+\".gridwidth\"))}var x=e.lonaxis.range,b=e.lataxis.range,_=x[0],w=x[1];_>0&&w<0&&(w+=360);var k,T,A,M=(_+w)/2;if(!c){var S=u?s.projRotate:[M,0,0];k=r(\"projection.rotation.lon\",S[0]),r(\"projection.rotation.lat\",S[1]),r(\"projection.rotation.roll\",S[2]),r(\"showcoastlines\",!u)&&(r(\"coastlinecolor\"),r(\"coastlinewidth\")),r(\"showocean\")&&r(\"oceancolor\")}(c?(T=-96.6,A=38.7):(T=u?M:k,A=(b[0]+b[1])/2),r(\"center.lon\",T),r(\"center.lat\",A),h)&&r(\"projection.parallels\",s.projParallels||[0,60]);r(\"projection.scale\"),r(\"showland\")&&r(\"landcolor\"),r(\"showlakes\")&&r(\"lakecolor\"),r(\"showrivers\")&&(r(\"rivercolor\"),r(\"riverwidth\")),r(\"showcountries\",u&&\"usa\"!==a)&&(r(\"countrycolor\"),r(\"countrywidth\")),(\"usa\"===a||\"north america\"===a&&50===n)&&(r(\"showsubunits\",!0),r(\"subunitcolor\"),r(\"subunitwidth\")),u||r(\"showframe\",!0)&&(r(\"framecolor\"),r(\"framewidth\")),r(\"bgcolor\")}e.exports=function(t,e,r){n(t,e,r,{type:\"geo\",attributes:a,handleDefaults:s,partition:\"y\"})}},{\"../subplot_defaults\":842,\"./constants\":795,\"./layout_attributes\":798}],800:[function(t,e,r){\"use strict\";e.exports=function(t){function e(t,e){return{type:\"Feature\",id:t.id,properties:t.properties,geometry:r(t.geometry,e)}}function r(e,n){if(!e)return null;if(\"GeometryCollection\"===e.type)return{type:\"GeometryCollection\",geometries:object.geometries.map(function(t){return r(t,n)})};if(!c.hasOwnProperty(e.type))return null;var i=c[e.type];return t.geo.stream(e,n(i)),i.result()}t.geo.project=function(t,e){var i=e.stream;if(!i)throw new Error(\"not yet supported\");return(t&&n.hasOwnProperty(t.type)?n[t.type]:r)(t,i)};var n={Feature:e,FeatureCollection:function(t,r){return{type:\"FeatureCollection\",features:t.features.map(function(t){return e(t,r)})}}},i=[],a=[],o={point:function(t,e){i.push([t,e])},result:function(){var t=i.length?i.length<2?{type:\"Point\",coordinates:i[0]}:{type:\"MultiPoint\",coordinates:i}:null;return i=[],t}},s={lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){i.length&&(a.push(i),i=[])},result:function(){var t=a.length?a.length<2?{type:\"LineString\",coordinates:a[0]}:{type:\"MultiLineString\",coordinates:a}:null;return a=[],t}},l={polygonStart:u,lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){var t=i.length;if(t){do{i.push(i[0].slice())}while(++t<4);a.push(i),i=[]}},polygonEnd:u,result:function(){if(!a.length)return null;var t=[],e=[];return a.forEach(function(r){!function(t){if((e=t.length)<4)return!1;for(var e,r=0,n=t[e-1][1]*t[0][0]-t[e-1][0]*t[0][1];++r<e;)n+=t[r-1][1]*t[r][0]-t[r-1][0]*t[r][1];return n<=0}(r)?e.push(r):t.push([r])}),e.forEach(function(e){var r=e[0];t.some(function(t){if(function(t,e){for(var r=e[0],n=e[1],i=!1,a=0,o=t.length,s=o-1;a<o;s=a++){var l=t[a],c=l[0],u=l[1],h=t[s],f=h[0],p=h[1];u>n^p>n&&r<(f-c)*(n-u)/(p-u)+c&&(i=!i)}return i}(t[0],r))return t.push(e),!0})||t.push([e])}),a=[],t.length?t.length>1?{type:\"MultiPolygon\",coordinates:t}:{type:\"Polygon\",coordinates:t[0]}:null}},c={Point:o,MultiPoint:o,LineString:s,MultiLineString:s,Polygon:l,MultiPolygon:l,Sphere:l};function u(){}var h=1e-6,f=h*h,p=Math.PI,d=p/2,g=(Math.sqrt(p),p/180),v=180/p;function m(t){return t>1?d:t<-1?-d:Math.asin(t)}function y(t){return t>1?0:t<-1?p:Math.acos(t)}var x=t.geo.projection,b=t.geo.projectionMutator;function _(t,e){var r=(2+d)*Math.sin(e);e/=2;for(var n=0,i=1/0;n<10&&Math.abs(i)>h;n++){var a=Math.cos(e);e-=i=(e+Math.sin(e)*(a+2)-r)/(2*a*(1+a))}return[2/Math.sqrt(p*(4+p))*t*(1+Math.cos(e)),2*Math.sqrt(p/(4+p))*Math.sin(e)]}t.geo.interrupt=function(e){var r,n=[[[[-p,0],[0,d],[p,0]]],[[[-p,0],[0,-d],[p,0]]]];function i(t,r){for(var i=r<0?-1:1,a=n[+(r<0)],o=0,s=a.length-1;o<s&&t>a[o][2][0];++o);var l=e(t-a[o][1][0],r);return l[0]+=e(a[o][1][0],i*r>i*a[o][0][1]?a[o][0][1]:r)[0],l}e.invert&&(i.invert=function(t,a){for(var o=r[+(a<0)],s=n[+(a<0)],c=0,u=o.length;c<u;++c){var h=o[c];if(h[0][0]<=t&&t<h[1][0]&&h[0][1]<=a&&a<h[1][1]){var f=e.invert(t-e(s[c][1][0],0)[0],a);return f[0]+=s[c][1][0],l(i(f[0],f[1]),[t,a])?f:null}}});var a=t.geo.projection(i),o=a.stream;function s(t,e){for(var r,n,i,a=-1,o=t.length,s=t[0],l=[];++a<o;){n=((r=t[a])[0]-s[0])/e,i=(r[1]-s[1])/e;for(var c=0;c<e;++c)l.push([s[0]+c*n,s[1]+c*i]);s=r}return l.push(r),l}function l(t,e){return Math.abs(t[0]-e[0])<h&&Math.abs(t[1]-e[1])<h}return a.stream=function(e){var r=a.rotate(),i=o(e),l=(a.rotate([0,0]),o(e));return a.rotate(r),i.sphere=function(){t.geo.stream(function(){for(var e=1e-6,r=[],i=0,a=n[0].length;i<a;++i){var o=n[0][i],l=180*o[0][0]/p,c=180*o[0][1]/p,u=180*o[1][1]/p,h=180*o[2][0]/p,f=180*o[2][1]/p;r.push(s([[l+e,c+e],[l+e,u-e],[h-e,u-e],[h-e,f+e]],30))}for(var i=n[1].length-1;i>=0;--i){var o=n[1][i],l=180*o[0][0]/p,c=180*o[0][1]/p,u=180*o[1][1]/p,h=180*o[2][0]/p,f=180*o[2][1]/p;r.push(s([[h-e,f-e],[h-e,u+e],[l+e,u+e],[l+e,c-e]],30))}return{type:\"Polygon\",coordinates:[t.merge(r)]}}(),l)},i},a.lobes=function(t){return arguments.length?(n=t.map(function(t){return t.map(function(t){return[[t[0][0]*p/180,t[0][1]*p/180],[t[1][0]*p/180,t[1][1]*p/180],[t[2][0]*p/180,t[2][1]*p/180]]})}),r=n.map(function(t){return t.map(function(t){var r,n=e(t[0][0],t[0][1])[0],i=e(t[2][0],t[2][1])[0],a=e(t[1][0],t[0][1])[1],o=e(t[1][0],t[1][1])[1];return a>o&&(r=a,a=o,o=r),[[n,a],[i,o]]})}),a):n.map(function(t){return t.map(function(t){return[[180*t[0][0]/p,180*t[0][1]/p],[180*t[1][0]/p,180*t[1][1]/p],[180*t[2][0]/p,180*t[2][1]/p]]})})},a},_.invert=function(t,e){var r=.5*e*Math.sqrt((4+p)/p),n=m(r),i=Math.cos(n);return[t/(2/Math.sqrt(p*(4+p))*(1+i)),m((n+r*(i+2))/(2+d))]},(t.geo.eckert4=function(){return x(_)}).raw=_;var w=t.geo.azimuthalEqualArea.raw;function k(t,e){if(arguments.length<2&&(e=t),1===e)return w;if(e===1/0)return T;function r(r,n){var i=w(r/e,n);return i[0]*=t,i}return r.invert=function(r,n){var i=w.invert(r/t,n);return i[0]*=e,i},r}function T(t,e){return[t*Math.cos(e)/Math.cos(e/=2),2*Math.sin(e)]}function A(t,e){return[3*t/(2*p)*Math.sqrt(p*p/3-e*e),e]}function M(t,e){return[t,1.25*Math.log(Math.tan(p/4+.4*e))]}function S(t){return function(e){var r,n=t*Math.sin(e),i=30;do{e-=r=(e+Math.sin(e)-n)/(1+Math.cos(e))}while(Math.abs(r)>h&&--i>0);return e/2}}T.invert=function(t,e){var r=2*m(e/2);return[t*Math.cos(r/2)/Math.cos(r),r]},(t.geo.hammer=function(){var t=2,e=b(k),r=e(t);return r.coefficient=function(r){return arguments.length?e(t=+r):t},r}).raw=k,A.invert=function(t,e){return[2/3*p*t/Math.sqrt(p*p/3-e*e),e]},(t.geo.kavrayskiy7=function(){return x(A)}).raw=A,M.invert=function(t,e){return[t,2.5*Math.atan(Math.exp(.8*e))-.625*p]},(t.geo.miller=function(){return x(M)}).raw=M,S(p);var E=function(t,e,r){var n=S(r);function i(r,i){return[t*r*Math.cos(i=n(i)),e*Math.sin(i)]}return i.invert=function(n,i){var a=m(i/e);return[n/(t*Math.cos(a)),m((2*a+Math.sin(2*a))/r)]},i}(Math.SQRT2/d,Math.SQRT2,p);function C(t,e){var r=e*e,n=r*r;return[t*(.8707-.131979*r+n*(n*(.003971*r-.001529*n)-.013791)),e*(1.007226+r*(.015085+n*(.028874*r-.044475-.005916*n)))]}(t.geo.mollweide=function(){return x(E)}).raw=E,C.invert=function(t,e){var r,n=e,i=25;do{var a=n*n,o=a*a;n-=r=(n*(1.007226+a*(.015085+o*(.028874*a-.044475-.005916*o)))-e)/(1.007226+a*(.045255+o*(.259866*a-.311325-.005916*11*o)))}while(Math.abs(r)>h&&--i>0);return[t/(.8707+(a=n*n)*(a*(a*a*a*(.003971-.001529*a)-.013791)-.131979)),n]},(t.geo.naturalEarth=function(){return x(C)}).raw=C;var L=[[.9986,-.062],[1,0],[.9986,.062],[.9954,.124],[.99,.186],[.9822,.248],[.973,.31],[.96,.372],[.9427,.434],[.9216,.4958],[.8962,.5571],[.8679,.6176],[.835,.6769],[.7986,.7346],[.7597,.7903],[.7186,.8435],[.6732,.8936],[.6213,.9394],[.5722,.9761],[.5322,1]];function P(t,e){var r,n=Math.min(18,36*Math.abs(e)/p),i=Math.floor(n),a=n-i,o=(r=L[i])[0],s=r[1],l=(r=L[++i])[0],c=r[1],u=(r=L[Math.min(19,++i)])[0],h=r[1];return[t*(l+a*(u-o)/2+a*a*(u-2*l+o)/2),(e>0?d:-d)*(c+a*(h-s)/2+a*a*(h-2*c+s)/2)]}function O(t,e){return[t*Math.cos(e),e]}function z(t,e){var r,n=Math.cos(e),i=(r=y(n*Math.cos(t/=2)))?r/Math.sin(r):1;return[2*n*Math.sin(t)*i,Math.sin(e)*i]}function I(t,e){var r=z(t,e);return[(r[0]+t/d)/2,(r[1]+e)/2]}L.forEach(function(t){t[1]*=1.0144}),P.invert=function(t,e){var r=e/d,n=90*r,i=Math.min(18,Math.abs(n/5)),a=Math.max(0,Math.floor(i));do{var o=L[a][1],s=L[a+1][1],l=L[Math.min(19,a+2)][1],c=l-o,u=l-2*s+o,h=2*(Math.abs(r)-s)/c,p=u/c,m=h*(1-p*h*(1-2*p*h));if(m>=0||1===a){n=(e>=0?5:-5)*(m+i);var y,x=50;do{m=(i=Math.min(18,Math.abs(n)/5))-(a=Math.floor(i)),o=L[a][1],s=L[a+1][1],l=L[Math.min(19,a+2)][1],n-=(y=(e>=0?d:-d)*(s+m*(l-o)/2+m*m*(l-2*s+o)/2)-e)*v}while(Math.abs(y)>f&&--x>0);break}}while(--a>=0);var b=L[a][0],_=L[a+1][0],w=L[Math.min(19,a+2)][0];return[t/(_+m*(w-b)/2+m*m*(w-2*_+b)/2),n*g]},(t.geo.robinson=function(){return x(P)}).raw=P,O.invert=function(t,e){return[t/Math.cos(e),e]},(t.geo.sinusoidal=function(){return x(O)}).raw=O,z.invert=function(t,e){if(!(t*t+4*e*e>p*p+h)){var r=t,n=e,i=25;do{var a,o=Math.sin(r),s=Math.sin(r/2),l=Math.cos(r/2),c=Math.sin(n),u=Math.cos(n),f=Math.sin(2*n),d=c*c,g=u*u,v=s*s,m=1-g*l*l,x=m?y(u*l)*Math.sqrt(a=1/m):a=0,b=2*x*u*s-t,_=x*c-e,w=a*(g*v+x*u*l*d),k=a*(.5*o*f-2*x*c*s),T=.25*a*(f*s-x*c*g*o),A=a*(d*l+x*v*u),M=k*T-A*w;if(!M)break;var S=(_*k-b*A)/M,E=(b*T-_*w)/M;r-=S,n-=E}while((Math.abs(S)>h||Math.abs(E)>h)&&--i>0);return[r,n]}},(t.geo.aitoff=function(){return x(z)}).raw=z,I.invert=function(t,e){var r=t,n=e,i=25;do{var a,o=Math.cos(n),s=Math.sin(n),l=Math.sin(2*n),c=s*s,u=o*o,f=Math.sin(r),p=Math.cos(r/2),g=Math.sin(r/2),v=g*g,m=1-u*p*p,x=m?y(o*p)*Math.sqrt(a=1/m):a=0,b=.5*(2*x*o*g+r/d)-t,_=.5*(x*s+n)-e,w=.5*a*(u*v+x*o*p*c)+.5/d,k=a*(f*l/4-x*s*g),T=.125*a*(l*g-x*s*u*f),A=.5*a*(c*p+x*v*o)+.5,M=k*T-A*w,S=(_*k-b*A)/M,E=(b*T-_*w)/M;r-=S,n-=E}while((Math.abs(S)>h||Math.abs(E)>h)&&--i>0);return[r,n]},(t.geo.winkel3=function(){return x(I)}).raw=I}},{}],801:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=Math.PI/180,s=180/Math.PI,l={cursor:\"pointer\"},c={cursor:\"auto\"};function u(t,e){return n.behavior.zoom().translate(e.translate()).scale(e.scale())}function h(t,e,r){var n=t.id,o=t.graphDiv,s=o.layout,l=s[n],c=o._fullLayout,u=c[n],h={},f={};function p(t,e){h[n+\".\"+t]=i.nestedProperty(l,t).get(),a.call(\"_storeDirectGUIEdit\",s,c._preGUI,h);var r=i.nestedProperty(u,t);r.get()!==e&&(r.set(e),i.nestedProperty(l,t).set(e),f[n+\".\"+t]=e)}r(p),p(\"projection.scale\",e.scale()/t.fitScale),o.emit(\"plotly_relayout\",f)}function f(t,e){var r=u(0,e);function i(r){var n=e.invert(t.midPt);r(\"center.lon\",n[0]),r(\"center.lat\",n[1])}return r.on(\"zoomstart\",function(){n.select(this).style(l)}).on(\"zoom\",function(){e.scale(n.event.scale).translate(n.event.translate),t.render();var r=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":r[0],\"geo.center.lat\":r[1]})}).on(\"zoomend\",function(){n.select(this).style(c),h(t,e,i)}),r}function p(t,e){var r,i,a,o,s,f,p,d,g,v=u(0,e),m=2;function y(t){return e.invert(t)}function x(r){var n=e.rotate(),i=e.invert(t.midPt);r(\"projection.rotation.lon\",-n[0]),r(\"center.lon\",i[0]),r(\"center.lat\",i[1])}return v.on(\"zoomstart\",function(){n.select(this).style(l),r=n.mouse(this),i=e.rotate(),a=e.translate(),o=i,s=y(r)}).on(\"zoom\",function(){if(f=n.mouse(this),function(t){var r=y(t);if(!r)return!0;var n=e(r);return Math.abs(n[0]-t[0])>m||Math.abs(n[1]-t[1])>m}(r))return v.scale(e.scale()),void v.translate(e.translate());e.scale(n.event.scale),e.translate([a[0],n.event.translate[1]]),s?y(f)&&(d=y(f),p=[o[0]+(d[0]-s[0]),i[1],i[2]],e.rotate(p),o=p):s=y(r=f),g=!0,t.render();var l=e.rotate(),c=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":c[0],\"geo.center.lat\":c[1],\"geo.projection.rotation.lon\":-l[0]})}).on(\"zoomend\",function(){n.select(this).style(c),g&&h(t,e,x)}),v}function d(t,e){var r,i={r:e.rotate(),k:e.scale()},a=u(0,e),f=function(t){var e=0,r=arguments.length,i=[];for(;++e<r;)i.push(arguments[e]);var a=n.dispatch.apply(null,i);return a.of=function(e,r){return function(i){var o;try{o=i.sourceEvent=n.event,i.target=t,n.event=i,a[i.type].apply(e,r)}finally{n.event=o}}},a}(a,\"zoomstart\",\"zoom\",\"zoomend\"),p=0,d=a.on;function m(t){var r=e.rotate();t(\"projection.rotation.lon\",-r[0]),t(\"projection.rotation.lat\",-r[1])}return a.on(\"zoomstart\",function(){n.select(this).style(l);var t,c,u,h,m,b,_,w,k,T,A,M=n.mouse(this),S=e.rotate(),E=S,C=e.translate(),L=(c=.5*(t=S)[0]*o,u=.5*t[1]*o,h=.5*t[2]*o,m=Math.sin(c),b=Math.cos(c),_=Math.sin(u),w=Math.cos(u),k=Math.sin(h),T=Math.cos(h),[b*w*T+m*_*k,m*w*T-b*_*k,b*_*T+m*w*k,b*w*k-m*_*T]);r=g(e,M),d.call(a,\"zoom\",function(){var t,a,o,l,c,u,h,p,d,m,b=n.mouse(this);if(e.scale(i.k=n.event.scale),r){if(g(e,b)){e.rotate(S).translate(C);var _=g(e,b),w=function(t,e){if(!t||!e)return;var r=function(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}(t,e),n=Math.sqrt(x(r,r)),i=.5*Math.acos(Math.max(-1,Math.min(1,x(t,e)))),a=Math.sin(i)/n;return n&&[Math.cos(i),r[2]*a,-r[1]*a,r[0]*a]}(r,_),k=function(t){return[Math.atan2(2*(t[0]*t[1]+t[2]*t[3]),1-2*(t[1]*t[1]+t[2]*t[2]))*s,Math.asin(Math.max(-1,Math.min(1,2*(t[0]*t[2]-t[3]*t[1]))))*s,Math.atan2(2*(t[0]*t[3]+t[1]*t[2]),1-2*(t[2]*t[2]+t[3]*t[3]))*s]}((a=w,o=(t=L)[0],l=t[1],c=t[2],u=t[3],h=a[0],p=a[1],d=a[2],m=a[3],[o*h-l*p-c*d-u*m,o*p+l*h+c*m-u*d,o*d-l*m+c*h+u*p,o*m+l*d-c*p+u*h])),T=i.r=function(t,e,r){var n=y(e,2,t[0]);n=y(n,1,t[1]),n=y(n,0,t[2]-r[2]);var i,a,o=e[0],l=e[1],c=e[2],u=n[0],h=n[1],f=n[2],p=Math.atan2(l,o)*s,d=Math.sqrt(o*o+l*l);Math.abs(h)>d?(a=(h>0?90:-90)-p,i=0):(a=Math.asin(h/d)*s-p,i=Math.sqrt(d*d-h*h));var g=180-a-2*p,m=(Math.atan2(f,u)-Math.atan2(c,i))*s,x=(Math.atan2(f,u)-Math.atan2(c,-i))*s,b=v(r[0],r[1],a,m),_=v(r[0],r[1],g,x);return b<=_?[a,m,r[2]]:[g,x,r[2]]}(k,r,E);isFinite(T[0])&&isFinite(T[1])&&isFinite(T[2])||(T=E),e.rotate(T),E=T}}else r=g(e,M=b);f.of(this,arguments)({type:\"zoom\"})}),A=f.of(this,arguments),p++||A({type:\"zoomstart\"})}).on(\"zoomend\",function(){var r;n.select(this).style(c),d.call(a,\"zoom\",null),r=f.of(this,arguments),--p||r({type:\"zoomend\"}),h(t,e,m)}).on(\"zoom.redraw\",function(){t.render();var r=e.rotate();t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.projection.rotation.lon\":-r[0],\"geo.projection.rotation.lat\":-r[1]})}),n.rebind(a,f,\"on\")}function g(t,e){var r=t.invert(e);return r&&isFinite(r[0])&&isFinite(r[1])&&function(t){var e=t[0]*o,r=t[1]*o,n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}(r)}function v(t,e,r,n){var i=m(r-t),a=m(n-e);return Math.sqrt(i*i+a*a)}function m(t){return(t%360+540)%360-180}function y(t,e,r){var n=r*o,i=t.slice(),a=0===e?1:0,s=2===e?1:2,l=Math.cos(n),c=Math.sin(n);return i[a]=t[a]*l-t[s]*c,i[s]=t[s]*l+t[a]*c,i}function x(t,e){for(var r=0,n=0,i=t.length;n<i;++n)r+=t[n]*e[n];return r}e.exports=function(t,e){var r=t.projection;return(e._isScoped?f:e._isClipped?d:p)(t,r)}},{\"../../lib\":719,\"../../registry\":847,d3:163}],802:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"./cartesian/constants\").SUBPLOT_PATTERN;r.getSubplotCalcData=function(t,e,r){var i=n.subplotsRegistry[e];if(!i)return[];for(var a=i.attr,o=[],s=0;s<t.length;s++){var l=t[s];l[0].trace[a]===r&&o.push(l)}return o},r.getModuleCalcData=function(t,e){var r,i=[],a=[];if(!(r=\"string\"==typeof e?n.getModule(e).plot:\"function\"==typeof e?e:e.plot))return[i,t];for(var o=0;o<t.length;o++){var s=t[o],l=s[0].trace;!0===l.visible&&0!==l._length&&(l._module.plot===r?i.push(s):a.push(s))}return[i,a]},r.getSubplotData=function(t,e,r){if(!n.subplotsRegistry[e])return[];var a,o,s,l=n.subplotsRegistry[e].attr,c=[];if(\"gl2d\"===e){var u=r.match(i);o=\"x\"+u[1],s=\"y\"+u[2]}for(var h=0;h<t.length;h++)a=t[h],\"gl2d\"===e&&n.traceIs(a,\"gl2d\")?a[l[0]]===o&&a[l[1]]===s&&c.push(a):a[l]===r&&c.push(a);return c}},{\"../registry\":847,\"./cartesian/constants\":773}],803:[function(t,e,r){\"use strict\";var n=t(\"mouse-change\"),i=t(\"mouse-wheel\"),a=t(\"mouse-event-offset\"),o=t(\"../cartesian/constants\"),s=t(\"has-passive-events\");function l(t,e){this.element=t,this.plot=e,this.mouseListener=null,this.wheelListener=null,this.lastInputTime=Date.now(),this.lastPos=[0,0],this.boxEnabled=!1,this.boxInited=!1,this.boxStart=[0,0],this.boxEnd=[0,0],this.dragStart=[0,0]}e.exports=function(t){var e=t.mouseContainer,r=t.glplot,c=new l(e,r);function u(){t.xaxis.autorange=!1,t.yaxis.autorange=!1}function h(e,n,i){var a,s,l=t.calcDataBox(),h=r.viewBox,f=c.lastPos[0],p=c.lastPos[1],d=o.MINDRAG*r.pixelRatio,g=o.MINZOOM*r.pixelRatio;function v(e,r,n){var i=Math.min(r,n),a=Math.max(r,n);i!==a?(l[e]=i,l[e+2]=a,c.dataBox=l,t.setRanges(l)):(t.selectBox.selectBox=[0,0,1,1],t.glplot.setDirty())}switch(n*=r.pixelRatio,i*=r.pixelRatio,i=h[3]-h[1]-i,t.fullLayout.dragmode){case\"zoom\":if(e){var m=n/(h[2]-h[0])*(l[2]-l[0])+l[0],y=i/(h[3]-h[1])*(l[3]-l[1])+l[1];c.boxInited||(c.boxStart[0]=m,c.boxStart[1]=y,c.dragStart[0]=n,c.dragStart[1]=i),c.boxEnd[0]=m,c.boxEnd[1]=y,c.boxInited=!0,c.boxEnabled||c.boxStart[0]===c.boxEnd[0]&&c.boxStart[1]===c.boxEnd[1]||(c.boxEnabled=!0);var x=Math.abs(c.dragStart[0]-n)<g,b=Math.abs(c.dragStart[1]-i)<g;if(!function(){for(var e=t.graphDiv._fullLayout._axisConstraintGroups,r=t.xaxis._id,n=t.yaxis._id,i=0;i<e.length;i++)if(-1!==e[i][r]){if(-1!==e[i][n])return!0;break}return!1}()||x&&b)x&&(c.boxEnd[0]=c.boxStart[0]),b&&(c.boxEnd[1]=c.boxStart[1]);else{a=c.boxEnd[0]-c.boxStart[0],s=c.boxEnd[1]-c.boxStart[1];var _=(l[3]-l[1])/(l[2]-l[0]);Math.abs(a*_)>Math.abs(s)?(c.boxEnd[1]=c.boxStart[1]+Math.abs(a)*_*(s>=0?1:-1),c.boxEnd[1]<l[1]?(c.boxEnd[1]=l[1],c.boxEnd[0]=c.boxStart[0]+(l[1]-c.boxStart[1])/Math.abs(_)):c.boxEnd[1]>l[3]&&(c.boxEnd[1]=l[3],c.boxEnd[0]=c.boxStart[0]+(l[3]-c.boxStart[1])/Math.abs(_))):(c.boxEnd[0]=c.boxStart[0]+Math.abs(s)/_*(a>=0?1:-1),c.boxEnd[0]<l[0]?(c.boxEnd[0]=l[0],c.boxEnd[1]=c.boxStart[1]+(l[0]-c.boxStart[0])*Math.abs(_)):c.boxEnd[0]>l[2]&&(c.boxEnd[0]=l[2],c.boxEnd[1]=c.boxStart[1]+(l[2]-c.boxStart[0])*Math.abs(_)))}}else c.boxEnabled?(a=c.boxStart[0]!==c.boxEnd[0],s=c.boxStart[1]!==c.boxEnd[1],a||s?(a&&(v(0,c.boxStart[0],c.boxEnd[0]),t.xaxis.autorange=!1),s&&(v(1,c.boxStart[1],c.boxEnd[1]),t.yaxis.autorange=!1),t.relayoutCallback()):t.glplot.setDirty(),c.boxEnabled=!1,c.boxInited=!1):c.boxInited&&(c.boxInited=!1);break;case\"pan\":c.boxEnabled=!1,c.boxInited=!1,e?(c.panning||(c.dragStart[0]=n,c.dragStart[1]=i),Math.abs(c.dragStart[0]-n)<d&&(n=c.dragStart[0]),Math.abs(c.dragStart[1]-i)<d&&(i=c.dragStart[1]),a=(f-n)*(l[2]-l[0])/(r.viewBox[2]-r.viewBox[0]),s=(p-i)*(l[3]-l[1])/(r.viewBox[3]-r.viewBox[1]),l[0]+=a,l[2]+=a,l[1]+=s,l[3]+=s,t.setRanges(l),c.panning=!0,c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations()):c.panning&&(c.panning=!1,t.relayoutCallback())}c.lastPos[0]=n,c.lastPos[1]=i}return c.mouseListener=n(e,h),e.addEventListener(\"touchstart\",function(t){var r=a(t.changedTouches[0],e);h(0,r[0],r[1]),h(1,r[0],r[1]),t.preventDefault()},!!s&&{passive:!1}),e.addEventListener(\"touchmove\",function(t){t.preventDefault();var r=a(t.changedTouches[0],e);h(1,r[0],r[1]),t.preventDefault()},!!s&&{passive:!1}),e.addEventListener(\"touchend\",function(t){h(0,c.lastPos[0],c.lastPos[1]),t.preventDefault()},!!s&&{passive:!1}),c.wheelListener=i(e,function(e,n){if(!t.scrollZoom)return!1;var i=t.calcDataBox(),a=r.viewBox,o=c.lastPos[0],s=c.lastPos[1],l=Math.exp(5*n/(a[3]-a[1])),h=o/(a[2]-a[0])*(i[2]-i[0])+i[0],f=s/(a[3]-a[1])*(i[3]-i[1])+i[1];return i[0]=(i[0]-h)*l+h,i[2]=(i[2]-h)*l+h,i[1]=(i[1]-f)*l+f,i[3]=(i[3]-f)*l+f,t.setRanges(i),c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations(),t.relayoutCallback(),!0},!0),c}},{\"../cartesian/constants\":773,\"has-passive-events\":411,\"mouse-change\":435,\"mouse-event-offset\":436,\"mouse-wheel\":438}],804:[function(t,e,r){\"use strict\";var n=t(\"../cartesian/axes\"),i=t(\"../../lib/str2rgbarray\");function a(t){this.scene=t,this.gl=t.gl,this.pixelRatio=t.pixelRatio,this.screenBox=[0,0,1,1],this.viewBox=[0,0,1,1],this.dataBox=[-1,-1,1,1],this.borderLineEnable=[!1,!1,!1,!1],this.borderLineWidth=[1,1,1,1],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.ticks=[[],[]],this.tickEnable=[!0,!0,!1,!1],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labels=[\"x\",\"y\"],this.labelEnable=[!0,!0,!1,!1],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelPad=[15,15,15,15],this.labelSize=[12,12],this.labelFont=[\"sans-serif\",\"sans-serif\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.title=\"\",this.titleEnable=!0,this.titleCenter=[0,0,0,0],this.titleAngle=0,this.titleColor=[0,0,0,1],this.titleFont=\"sans-serif\",this.titleSize=18,this.gridLineEnable=[!0,!0],this.gridLineColor=[[0,0,0,.5],[0,0,0,.5]],this.gridLineWidth=[1,1],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[1,1],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.static=this.scene.staticPlot}var o=a.prototype,s=[\"xaxis\",\"yaxis\"];o.merge=function(t){var e,r,n,a,o,l,c,u,h,f,p;for(this.titleEnable=!1,this.backgroundColor=i(t.plot_bgcolor),f=0;f<2;++f){var d=(e=s[f]).charAt(0);for(n=(r=t[this.scene[e]._name]).title.text===this.scene.fullLayout._dfltTitle[d]?\"\":r.title.text,p=0;p<=2;p+=2)this.labelEnable[f+p]=!1,this.labels[f+p]=n,this.labelColor[f+p]=i(r.title.font.color),this.labelFont[f+p]=r.title.font.family,this.labelSize[f+p]=r.title.font.size,this.labelPad[f+p]=this.getLabelPad(e,r),this.tickEnable[f+p]=!1,this.tickColor[f+p]=i((r.tickfont||{}).color),this.tickAngle[f+p]=\"auto\"===r.tickangle?0:Math.PI*-r.tickangle/180,this.tickPad[f+p]=this.getTickPad(r),this.tickMarkLength[f+p]=0,this.tickMarkWidth[f+p]=r.tickwidth||0,this.tickMarkColor[f+p]=i(r.tickcolor),this.borderLineEnable[f+p]=!1,this.borderLineColor[f+p]=i(r.linecolor),this.borderLineWidth[f+p]=r.linewidth||0;c=this.hasSharedAxis(r),o=this.hasAxisInDfltPos(e,r)&&!c,l=this.hasAxisInAltrPos(e,r)&&!c,a=r.mirror||!1,u=c?-1!==String(a).indexOf(\"all\"):!!a,h=c?\"allticks\"===a:-1!==String(a).indexOf(\"ticks\"),o?this.labelEnable[f]=!0:l&&(this.labelEnable[f+2]=!0),o?this.tickEnable[f]=r.showticklabels:l&&(this.tickEnable[f+2]=r.showticklabels),(o||u)&&(this.borderLineEnable[f]=r.showline),(l||u)&&(this.borderLineEnable[f+2]=r.showline),(o||h)&&(this.tickMarkLength[f]=this.getTickMarkLength(r)),(l||h)&&(this.tickMarkLength[f+2]=this.getTickMarkLength(r)),this.gridLineEnable[f]=r.showgrid,this.gridLineColor[f]=i(r.gridcolor),this.gridLineWidth[f]=r.gridwidth,this.zeroLineEnable[f]=r.zeroline,this.zeroLineColor[f]=i(r.zerolinecolor),this.zeroLineWidth[f]=r.zerolinewidth}},o.hasSharedAxis=function(t){var e=this.scene,r=e.fullLayout._subplots.gl2d;return 0!==n.findSubplotsWithAxis(r,t).indexOf(e.id)},o.hasAxisInDfltPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"bottom\"===r:\"yaxis\"===t?\"left\"===r:void 0},o.hasAxisInAltrPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"top\"===r:\"yaxis\"===t?\"right\"===r:void 0},o.getLabelPad=function(t,e){var r=e.title.font.size,n=e.showticklabels;return\"xaxis\"===t?\"top\"===e.side?r*(1.5+(n?1:0))-10:r*(1.5+(n?.5:0))-10:\"yaxis\"===t?\"right\"===e.side?10+r*(1.5+(n?1:.5)):10+r*(1.5+(n?.5:0)):void 0},o.getTickPad=function(t){return\"outside\"===t.ticks?10+t.ticklen:15},o.getTickMarkLength=function(t){if(!t.ticks)return 0;var e=t.ticklen;return\"inside\"===t.ticks?-e:e},e.exports=function(t){return new a(t)}},{\"../../lib/str2rgbarray\":742,\"../cartesian/axes\":767}],805:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"./scene2d\"),a=t(\"../layout_attributes\"),o=t(\"../../constants/xmlns_namespaces\"),s=t(\"../cartesian/constants\"),l=t(\"../cartesian\"),c=t(\"../../components/fx/layout_attributes\"),u=t(\"../get_data\").getSubplotData;r.name=\"gl2d\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=s.idRegex,r.attrRegex=s.attrRegex,r.attributes=t(\"../cartesian/attributes\"),r.supplyLayoutDefaults=function(t,e,r){e._has(\"cartesian\")||l.supplyLayoutDefaults(t,e,r)},r.layoutAttrOverrides=n(l.layoutAttributes,\"plot\",\"from-root\"),r.baseLayoutAttrOverrides=n({plot_bgcolor:a.plot_bgcolor,hoverlabel:c.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl2d,a=0;a<n.length;a++){var o=n[a],s=e._plots[o],l=u(r,\"gl2d\",o),c=s._scene2d;void 0===c&&(c=new i({id:o,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio},e),s._scene2d=c),c.plot(l,t.calcdata,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl2d||[],a=0;a<i.length;a++){var o=i[a],s=n._plots[o];if(s._scene2d)0===u(t,\"gl2d\",o).length&&(s._scene2d.destroy(),delete n._plots[o])}l.clean.apply(this,arguments)},r.drawFramework=function(t){t._context.staticPlot||l.drawFramework(t)},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){var i=e._plots[r[n]]._scene2d,a=i.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":a,x:0,y:0,width:\"100%\",height:\"100%\",preserveAspectRatio:\"none\"}),i.destroy()}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){e._plots[r[n]]._scene2d.updateFx(e.dragmode)}}},{\"../../components/fx/layout_attributes\":633,\"../../constants/xmlns_namespaces\":696,\"../../plot_api/edit_types\":750,\"../cartesian\":778,\"../cartesian/attributes\":765,\"../cartesian/constants\":773,\"../get_data\":802,\"../layout_attributes\":819,\"./scene2d\":806}],806:[function(t,e,r){\"use strict\";var n,i,a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../../components/fx\"),l=t(\"gl-plot2d\"),c=t(\"gl-spikes2d\"),u=t(\"gl-select-box\"),h=t(\"webgl-context\"),f=t(\"./convert\"),p=t(\"./camera\"),d=t(\"../../lib/show_no_webgl_msg\"),g=t(\"../cartesian/constraints\"),v=g.enforce,m=g.clean,y=t(\"../cartesian/autorange\").doAutoRange,x=[\"xaxis\",\"yaxis\"],b=t(\"../cartesian/constants\").SUBPLOT_PATTERN;function _(t,e){this.container=t.container,this.graphDiv=t.graphDiv,this.pixelRatio=t.plotGlPixelRatio||window.devicePixelRatio,this.id=t.id,this.staticPlot=!!t.staticPlot,this.scrollZoom=this.graphDiv._context._scrollZoom.cartesian,this.fullData=null,this.updateRefs(e),this.makeFramework(),this.stopped||(this.glplotOptions=f(this),this.glplotOptions.merge(e),this.glplot=l(this.glplotOptions),this.camera=p(this),this.traces={},this.spikes=c(this.glplot),this.selectBox=u(this.glplot,{innerFill:!1,outerFill:!0}),this.lastButtonState=0,this.pickResult=null,this.isMouseOver=!0,this.stopped=!1,this.redraw=this.draw.bind(this),this.redraw())}e.exports=_;var w=_.prototype;w.makeFramework=function(){if(this.staticPlot){if(!(i||(n=document.createElement(\"canvas\"),i=h({canvas:n,preserveDrawingBuffer:!1,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"Error creating static canvas/context for image server\");this.canvas=n,this.gl=i}else{var t=this.container.querySelector(\".gl-canvas-focus\"),e=h({canvas:t,preserveDrawingBuffer:!0,premultipliedAlpha:!0});if(!e)return d(this),void(this.stopped=!0);this.canvas=t,this.gl=e}var r=this.canvas;r.style.width=\"100%\",r.style.height=\"100%\",r.style.position=\"absolute\",r.style.top=\"0px\",r.style.left=\"0px\",r.style[\"pointer-events\"]=\"none\",this.updateSize(r),r.className+=\" user-select-none\";var a=this.svgContainer=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");a.style.position=\"absolute\",a.style.top=a.style.left=\"0px\",a.style.width=a.style.height=\"100%\",a.style[\"z-index\"]=20,a.style[\"pointer-events\"]=\"none\";var o=this.mouseContainer=document.createElement(\"div\");o.style.position=\"absolute\",o.style[\"pointer-events\"]=\"auto\",this.pickCanvas=this.container.querySelector(\".gl-canvas-pick\");var s=this.container;s.appendChild(a),s.appendChild(o);var l=this;o.addEventListener(\"mouseout\",function(){l.isMouseOver=!1,l.unhover()}),o.addEventListener(\"mouseover\",function(){l.isMouseOver=!0})},w.toImage=function(t){t||(t=\"png\"),this.stopped=!0,this.staticPlot&&this.container.appendChild(n),this.updateSize(this.canvas);var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.clearColor(1,1,1,0),e.clear(e.COLOR_BUFFER_BIT|e.DEPTH_BUFFER_BIT),this.glplot.setDirty(),this.glplot.draw(),e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a);for(var o=0,s=i-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=a[4*(r*o+l)+c];a[4*(r*o+l)+c]=a[4*(r*s+l)+c],a[4*(r*s+l)+c]=u}var h=document.createElement(\"canvas\");h.width=r,h.height=i;var f,p=h.getContext(\"2d\"),d=p.createImageData(r,i);switch(d.data.set(a),p.putImageData(d,0,0),t){case\"jpeg\":f=h.toDataURL(\"image/jpeg\");break;case\"webp\":f=h.toDataURL(\"image/webp\");break;default:f=h.toDataURL(\"image/png\")}return this.staticPlot&&this.container.removeChild(n),f},w.updateSize=function(t){t||(t=this.canvas);var e=this.pixelRatio,r=this.fullLayout,n=r.width,i=r.height,a=0|Math.ceil(e*n),o=0|Math.ceil(e*i);return t.width===a&&t.height===o||(t.width=a,t.height=o),t},w.computeTickMarks=function(){this.xaxis.setScale(),this.yaxis.setScale();for(var t=[o.calcTicks(this.xaxis),o.calcTicks(this.yaxis)],e=0;e<2;++e)for(var r=0;r<t[e].length;++r)t[e][r].text=t[e][r].text+\"\";return t},w.updateRefs=function(t){this.fullLayout=t;var e=this.id.match(b),r=\"xaxis\"+e[1],n=\"yaxis\"+e[2];this.xaxis=this.fullLayout[r],this.yaxis=this.fullLayout[n]},w.relayoutCallback=function(){var t=this.graphDiv,e=this.xaxis,r=this.yaxis,n=t.layout,i={},o=i[e._name+\".range\"]=e.range.slice(),s=i[r._name+\".range\"]=r.range.slice();i[e._name+\".autorange\"]=e.autorange,i[r._name+\".autorange\"]=r.autorange,a.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,i);var l=n[e._name];l.range=o,l.autorange=e.autorange;var c=n[r._name];c.range=s,c.autorange=r.autorange,i.lastInputTime=this.camera.lastInputTime,t.emit(\"plotly_relayout\",i)},w.cameraChanged=function(){var t=this.camera;this.glplot.setDataBox(this.calcDataBox());var e=this.computeTickMarks();(function(t,e){for(var r=0;r<2;++r){var n=t[r],i=e[r];if(n.length!==i.length)return!0;for(var a=0;a<n.length;++a)if(n[a].x!==i[a].x)return!0}return!1})(e,this.glplotOptions.ticks)&&(this.glplotOptions.ticks=e,this.glplotOptions.dataBox=t.dataBox,this.glplot.update(this.glplotOptions),this.handleAnnotations())},w.handleAnnotations=function(){for(var t=this.graphDiv,e=this.fullLayout.annotations,r=0;r<e.length;r++){var n=e[r];n.xref===this.xaxis._id&&n.yref===this.yaxis._id&&a.getComponentMethod(\"annotations\",\"drawOne\")(t,r)}},w.destroy=function(){if(this.glplot){var t=this.traces;t&&Object.keys(t).map(function(e){t[e].dispose(),delete t[e]}),this.glplot.dispose(),this.container.removeChild(this.svgContainer),this.container.removeChild(this.mouseContainer),this.fullData=null,this.glplot=null,this.stopped=!0,this.camera.mouseListener.enabled=!1,this.mouseContainer.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=null}},w.plot=function(t,e,r){var n=this.glplot;this.updateRefs(r),this.xaxis.clearCalc(),this.yaxis.clearCalc(),this.updateTraces(t,e),this.updateFx(r.dragmode);var i=r.width,a=r.height;this.updateSize(this.canvas);var o=this.glplotOptions;o.merge(r),o.screenBox=[0,0,i,a];var s={_fullLayout:{_axisConstraintGroups:this.graphDiv._fullLayout._axisConstraintGroups,xaxis:this.xaxis,yaxis:this.yaxis}};m(s,this.xaxis),m(s,this.yaxis);var l,c,u=r._size,h=this.xaxis.domain,f=this.yaxis.domain;for(o.viewBox=[u.l+h[0]*u.w,u.b+f[0]*u.h,i-u.r-(1-h[1])*u.w,a-u.t-(1-f[1])*u.h],this.mouseContainer.style.width=u.w*(h[1]-h[0])+\"px\",this.mouseContainer.style.height=u.h*(f[1]-f[0])+\"px\",this.mouseContainer.height=u.h*(f[1]-f[0]),this.mouseContainer.style.left=u.l+h[0]*u.w+\"px\",this.mouseContainer.style.top=u.t+(1-f[1])*u.h+\"px\",c=0;c<2;++c)(l=this[x[c]])._length=o.viewBox[c+2]-o.viewBox[c],y(this.graphDiv,l),l.setScale();v(s),o.ticks=this.computeTickMarks(),o.dataBox=this.calcDataBox(),o.merge(r),n.update(o),this.glplot.draw()},w.calcDataBox=function(){var t=this.xaxis,e=this.yaxis,r=t.range,n=e.range,i=t.r2l,a=e.r2l;return[i(r[0]),a(n[0]),i(r[1]),a(n[1])]},w.setRanges=function(t){var e=this.xaxis,r=this.yaxis,n=e.l2r,i=r.l2r;e.range=[n(t[0]),n(t[2])],r.range=[i(t[1]),i(t[3])]},w.updateTraces=function(t,e){var r,n,i,a=Object.keys(this.traces);this.fullData=t;t:for(r=0;r<a.length;r++){var o=a[r],s=this.traces[o];for(n=0;n<t.length;n++)if((i=t[n]).uid===o&&i.type===s.type)continue t;s.dispose(),delete this.traces[o]}for(r=0;r<t.length;r++){i=t[r];var l=e[r],c=this.traces[i.uid];c?c.update(i,l):(c=i._module.plot(this,i,l),this.traces[i.uid]=c)}this.glplot.objects.sort(function(t,e){return t._trace.index-e._trace.index})},w.updateFx=function(t){\"lasso\"===t||\"select\"===t?(this.pickCanvas.style[\"pointer-events\"]=\"none\",this.mouseContainer.style[\"pointer-events\"]=\"none\"):(this.pickCanvas.style[\"pointer-events\"]=\"auto\",this.mouseContainer.style[\"pointer-events\"]=\"auto\"),this.mouseContainer.style.cursor=\"pan\"===t?\"move\":\"zoom\"===t?\"crosshair\":null},w.emitPointAction=function(t,e){for(var r,n=t.trace.uid,i=t.pointIndex,a=0;a<this.fullData.length;a++)this.fullData[a].uid===n&&(r=this.fullData[a]);var o={x:t.traceCoord[0],y:t.traceCoord[1],curveNumber:r.index,pointNumber:i,data:r._input,fullData:this.fullData,xaxis:this.xaxis,yaxis:this.yaxis};s.appendArrayPointValue(o,r,i),this.graphDiv.emit(e,{points:[o]})},w.draw=function(){if(!this.stopped){requestAnimationFrame(this.redraw);var t=this.glplot,e=this.camera,r=e.mouseListener,n=1===this.lastButtonState&&0===r.buttons,i=this.fullLayout;this.lastButtonState=r.buttons,this.cameraChanged();var a,o=r.x*t.pixelRatio,l=this.canvas.height-t.pixelRatio*r.y;if(e.boxEnabled&&\"zoom\"===i.dragmode){this.selectBox.enabled=!0;for(var c=this.selectBox.selectBox=[Math.min(e.boxStart[0],e.boxEnd[0]),Math.min(e.boxStart[1],e.boxEnd[1]),Math.max(e.boxStart[0],e.boxEnd[0]),Math.max(e.boxStart[1],e.boxEnd[1])],u=0;u<2;u++)e.boxStart[u]===e.boxEnd[u]&&(c[u]=t.dataBox[u],c[u+2]=t.dataBox[u+2]);t.setDirty()}else if(!e.panning&&this.isMouseOver){this.selectBox.enabled=!1;var h=i._size,f=this.xaxis.domain,p=this.yaxis.domain,d=(a=t.pick(o/t.pixelRatio+h.l+f[0]*h.w,l/t.pixelRatio-(h.t+(1-p[1])*h.h)))&&a.object._trace.handlePick(a);if(d&&n&&this.emitPointAction(d,\"plotly_click\"),a&&\"skip\"!==a.object._trace.hoverinfo&&i.hovermode&&d&&(!this.lastPickResult||this.lastPickResult.traceUid!==d.trace.uid||this.lastPickResult.dataCoord[0]!==d.dataCoord[0]||this.lastPickResult.dataCoord[1]!==d.dataCoord[1])){var g=d;this.lastPickResult={traceUid:d.trace?d.trace.uid:null,dataCoord:d.dataCoord.slice()},this.spikes.update({center:a.dataCoord}),g.screenCoord=[((t.viewBox[2]-t.viewBox[0])*(a.dataCoord[0]-t.dataBox[0])/(t.dataBox[2]-t.dataBox[0])+t.viewBox[0])/t.pixelRatio,(this.canvas.height-(t.viewBox[3]-t.viewBox[1])*(a.dataCoord[1]-t.dataBox[1])/(t.dataBox[3]-t.dataBox[1])-t.viewBox[1])/t.pixelRatio],this.emitPointAction(d,\"plotly_hover\");var v=this.fullData[g.trace.index]||{},m=g.pointIndex,y=s.castHoverinfo(v,i,m);if(y&&\"all\"!==y){var x=y.split(\"+\");-1===x.indexOf(\"x\")&&(g.traceCoord[0]=void 0),-1===x.indexOf(\"y\")&&(g.traceCoord[1]=void 0),-1===x.indexOf(\"z\")&&(g.traceCoord[2]=void 0),-1===x.indexOf(\"text\")&&(g.textLabel=void 0),-1===x.indexOf(\"name\")&&(g.name=void 0)}s.loneHover({x:g.screenCoord[0],y:g.screenCoord[1],xLabel:this.hoverFormatter(\"xaxis\",g.traceCoord[0]),yLabel:this.hoverFormatter(\"yaxis\",g.traceCoord[1]),zLabel:g.traceCoord[2],text:g.textLabel,name:g.name,color:s.castHoverOption(v,m,\"bgcolor\")||g.color,borderColor:s.castHoverOption(v,m,\"bordercolor\"),fontFamily:s.castHoverOption(v,m,\"font.family\"),fontSize:s.castHoverOption(v,m,\"font.size\"),fontColor:s.castHoverOption(v,m,\"font.color\"),nameLength:s.castHoverOption(v,m,\"namelength\"),textAlign:s.castHoverOption(v,m,\"align\")},{container:this.svgContainer,gd:this.graphDiv})}}a||this.unhover(),t.draw()}},w.unhover=function(){this.lastPickResult&&(this.spikes.update({}),this.lastPickResult=null,this.graphDiv.emit(\"plotly_unhover\"),s.loneUnhover(this.svgContainer))},w.hoverFormatter=function(t,e){if(void 0!==e){var r=this[t];return o.tickText(r,r.c2l(e),\"hover\").text}}},{\"../../components/fx\":632,\"../../lib/show_no_webgl_msg\":740,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../cartesian/autorange\":766,\"../cartesian/constants\":773,\"../cartesian/constraints\":774,\"./camera\":803,\"./convert\":804,\"gl-plot2d\":287,\"gl-select-box\":299,\"gl-spikes2d\":308,\"webgl-context\":556}],807:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../components/fx/layout_attributes\"),a=t(\"./scene\"),o=t(\"../get_data\").getSubplotData,s=t(\"../../lib\"),l=t(\"../../constants/xmlns_namespaces\");r.name=\"gl3d\",r.attr=\"scene\",r.idRoot=\"scene\",r.idRegex=r.attrRegex=s.counterRegex(\"scene\"),r.attributes=t(\"./layout/attributes\"),r.layoutAttributes=t(\"./layout/layout_attributes\"),r.baseLayoutAttrOverrides=n({hoverlabel:i.hoverlabel},\"plot\",\"nested\"),r.supplyLayoutDefaults=t(\"./layout/defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl3d,i=0;i<n.length;i++){var s=n[i],l=o(r,\"gl3d\",s),c=e[s],u=c.camera,h=c._scene;h||(h=new a({id:s,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio,camera:u},e),c._scene=h),h.viewInitial||(h.viewInitial={up:{x:u.up.x,y:u.up.y,z:u.up.z},eye:{x:u.eye.x,y:u.eye.y,z:u.eye.z},center:{x:u.center.x,y:u.center.y,z:u.center.z}}),h.plot(l,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl3d||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._scene&&(n[o]._scene.destroy(),n._infolayer&&n._infolayer.selectAll(\".annotation-\"+o).remove())}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=e._size,i=0;i<r.length;i++){var a=e[r[i]],o=a.domain,s=a._scene,c=s.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:l.svg,\"xlink:href\":c,x:n.l+n.w*o.x[0],y:n.t+n.h*(1-o.y[1]),width:n.w*(o.x[1]-o.x[0]),height:n.h*(o.y[1]-o.y[0]),preserveAspectRatio:\"none\"}),s.destroy()}},r.cleanId=function(t){if(t.match(/^scene[0-9]*$/)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),\"scene\"+e}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){e[r[n]]._scene.updateFx(e.dragmode,e.hovermode)}}},{\"../../components/fx/layout_attributes\":633,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../plot_api/edit_types\":750,\"../get_data\":802,\"./layout/attributes\":808,\"./layout/defaults\":812,\"./layout/layout_attributes\":813,\"./scene\":817}],808:[function(t,e,r){\"use strict\";e.exports={scene:{valType:\"subplotid\",dflt:\"scene\",editType:\"calc+clearAxisTypes\"}}},{}],809:[function(t,e,r){\"use strict\";var n=t(\"../../../components/color\"),i=t(\"../../cartesian/layout_attributes\"),a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../plot_api/edit_types\").overrideAll;e.exports=o({visible:i.visible,showspikes:{valType:\"boolean\",dflt:!0},spikesides:{valType:\"boolean\",dflt:!0},spikethickness:{valType:\"number\",min:0,dflt:2},spikecolor:{valType:\"color\",dflt:n.defaultLine},showbackground:{valType:\"boolean\",dflt:!1},backgroundcolor:{valType:\"color\",dflt:\"rgba(204, 204, 204, 0.5)\"},showaxeslabels:{valType:\"boolean\",dflt:!0},color:i.color,categoryorder:i.categoryorder,categoryarray:i.categoryarray,title:i.title,type:a({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autorange:i.autorange,rangemode:i.rangemode,range:a({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],anim:!1}),tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,mirror:i.mirror,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,tickfont:i.tickfont,tickangle:i.tickangle,tickprefix:i.tickprefix,showtickprefix:i.showtickprefix,ticksuffix:i.ticksuffix,showticksuffix:i.showticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,separatethousands:i.separatethousands,tickformat:i.tickformat,tickformatstops:i.tickformatstops,hoverformat:i.hoverformat,showline:i.showline,linecolor:i.linecolor,linewidth:i.linewidth,showgrid:i.showgrid,gridcolor:a({},i.gridcolor,{dflt:\"rgb(204, 204, 204)\"}),gridwidth:i.gridwidth,zeroline:i.zeroline,zerolinecolor:i.zerolinecolor,zerolinewidth:i.zerolinewidth,_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}},\"plot\",\"from-root\")},{\"../../../components/color\":593,\"../../../lib/extend\":710,\"../../../plot_api/edit_types\":750,\"../../cartesian/layout_attributes\":779}],810:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../../lib\"),a=t(\"../../../plot_api/plot_template\"),o=t(\"./axis_attributes\"),s=t(\"../../cartesian/type_defaults\"),l=t(\"../../cartesian/axis_defaults\"),c=[\"xaxis\",\"yaxis\",\"zaxis\"];e.exports=function(t,e,r){var u,h;function f(t,e){return i.coerce(u,h,o,t,e)}for(var p=0;p<c.length;p++){var d=c[p];u=t[d]||{},(h=a.newContainer(e,d))._id=d[0]+r.scene,h._name=d,s(u,h,f,r),l(u,h,f,{font:r.font,letter:d[0],data:r.data,showGrid:!0,noTickson:!0,bgColor:r.bgColor,calendar:r.calendar},r.fullLayout),f(\"gridcolor\",n(h.color,r.bgColor,13600/187).toRgbString()),f(\"title.text\",d[0]),h.setScale=i.noop,f(\"showspikes\")&&(f(\"spikesides\"),f(\"spikethickness\"),f(\"spikecolor\",h.color)),f(\"showaxeslabels\"),f(\"showbackground\")&&f(\"backgroundcolor\")}}},{\"../../../lib\":719,\"../../../plot_api/plot_template\":757,\"../../cartesian/axis_defaults\":769,\"../../cartesian/type_defaults\":790,\"./axis_attributes\":809,tinycolor2:537}],811:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"];function o(){this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[18,18,18],this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=[\"Open Sans\",\"Open Sans\",\"Open Sans\"],this.labelSize=[20,20,20],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[30,30,30],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[10,10,10],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!0,!0,!0],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._defaultTickPad=this.tickPad.slice(),this._defaultLabelPad=this.labelPad.slice(),this._defaultLineTickLength=this.lineTickLength.slice()}o.prototype.merge=function(t,e){for(var r=0;r<3;++r){var o=e[a[r]];o.visible?(this.labels[r]=t._meta?i.templateString(o.title.text,t._meta):o.title.text,\"font\"in o.title&&(o.title.font.color&&(this.labelColor[r]=n(o.title.font.color)),o.title.font.family&&(this.labelFont[r]=o.title.font.family),o.title.font.size&&(this.labelSize[r]=o.title.font.size)),\"showline\"in o&&(this.lineEnable[r]=o.showline),\"linecolor\"in o&&(this.lineColor[r]=n(o.linecolor)),\"linewidth\"in o&&(this.lineWidth[r]=o.linewidth),\"showgrid\"in o&&(this.gridEnable[r]=o.showgrid),\"gridcolor\"in o&&(this.gridColor[r]=n(o.gridcolor)),\"gridwidth\"in o&&(this.gridWidth[r]=o.gridwidth),\"log\"===o.type?this.zeroEnable[r]=!1:\"zeroline\"in o&&(this.zeroEnable[r]=o.zeroline),\"zerolinecolor\"in o&&(this.zeroLineColor[r]=n(o.zerolinecolor)),\"zerolinewidth\"in o&&(this.zeroLineWidth[r]=o.zerolinewidth),\"ticks\"in o&&o.ticks?this.lineTickEnable[r]=!0:this.lineTickEnable[r]=!1,\"ticklen\"in o&&(this.lineTickLength[r]=this._defaultLineTickLength[r]=o.ticklen),\"tickcolor\"in o&&(this.lineTickColor[r]=n(o.tickcolor)),\"tickwidth\"in o&&(this.lineTickWidth[r]=o.tickwidth),\"tickangle\"in o&&(this.tickAngle[r]=\"auto\"===o.tickangle?-3600:Math.PI*-o.tickangle/180),\"showticklabels\"in o&&(this.tickEnable[r]=o.showticklabels),\"tickfont\"in o&&(o.tickfont.color&&(this.tickColor[r]=n(o.tickfont.color)),o.tickfont.family&&(this.tickFont[r]=o.tickfont.family),o.tickfont.size&&(this.tickSize[r]=o.tickfont.size)),\"mirror\"in o?-1!==[\"ticks\",\"all\",\"allticks\"].indexOf(o.mirror)?(this.lineTickMirror[r]=!0,this.lineMirror[r]=!0):!0===o.mirror?(this.lineTickMirror[r]=!1,this.lineMirror[r]=!0):(this.lineTickMirror[r]=!1,this.lineMirror[r]=!1):this.lineMirror[r]=!1,\"showbackground\"in o&&!1!==o.showbackground?(this.backgroundEnable[r]=!0,this.backgroundColor[r]=n(o.backgroundcolor)):this.backgroundEnable[r]=!1):(this.tickEnable[r]=!1,this.labelEnable[r]=!1,this.lineEnable[r]=!1,this.lineTickEnable[r]=!1,this.gridEnable[r]=!1,this.zeroEnable[r]=!1,this.backgroundEnable[r]=!1)}},e.exports=function(t,e){var r=new o;return r.merge(t,e),r}},{\"../../../lib\":719,\"../../../lib/str2rgbarray\":742}],812:[function(t,e,r){\"use strict\";var n=t(\"../../../lib\"),i=t(\"../../../components/color\"),a=t(\"../../../registry\"),o=t(\"../../subplot_defaults\"),s=t(\"./axis_defaults\"),l=t(\"./layout_attributes\"),c=t(\"../../get_data\").getSubplotData,u=\"gl3d\";function h(t,e,r,n){for(var o=r(\"bgcolor\"),l=i.combine(o,n.paper_bgcolor),h=[\"up\",\"center\",\"eye\"],f=0;f<h.length;f++)r(\"camera.\"+h[f]+\".x\"),r(\"camera.\"+h[f]+\".y\"),r(\"camera.\"+h[f]+\".z\");r(\"camera.projection.type\");var p=!!r(\"aspectratio.x\")&&!!r(\"aspectratio.y\")&&!!r(\"aspectratio.z\"),d=r(\"aspectmode\",p?\"manual\":\"auto\");p||(t.aspectratio=e.aspectratio={x:1,y:1,z:1},\"manual\"===d&&(e.aspectmode=\"auto\"),t.aspectmode=e.aspectmode);var g=c(n.fullData,u,n.id);s(t,e,{font:n.font,scene:n.id,data:g,bgColor:l,calendar:n.calendar,fullLayout:n.fullLayout}),a.getComponentMethod(\"annotations3d\",\"handleDefaults\")(t,e,n);var v=n.getDfltFromLayout(\"dragmode\");if(!1!==v&&!v)if(v=\"orbit\",t.camera&&t.camera.up){var m=t.camera.up.x,y=t.camera.up.y,x=t.camera.up.z;0!==x&&(m&&y&&x?x/Math.sqrt(m*m+y*y+x*x)>.999&&(v=\"turntable\"):v=\"turntable\")}else v=\"turntable\";r(\"dragmode\",v),r(\"hovermode\",n.getDfltFromLayout(\"hovermode\"))}e.exports=function(t,e,r){var i=e._basePlotModules.length>1;o(t,e,r,{type:u,attributes:l,handleDefaults:h,fullLayout:e,font:e.font,fullData:r,getDfltFromLayout:function(e){if(!i)return n.validate(t[e],l[e])?t[e]:void 0},paper_bgcolor:e.paper_bgcolor,calendar:e.calendar})}},{\"../../../components/color\":593,\"../../../lib\":719,\"../../../registry\":847,\"../../get_data\":802,\"../../subplot_defaults\":842,\"./axis_defaults\":810,\"./layout_attributes\":813}],813:[function(t,e,r){\"use strict\";var n=t(\"./axis_attributes\"),i=t(\"../../domain\").attributes,a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../lib\").counterRegex;function s(t,e,r){return{x:{valType:\"number\",dflt:t,editType:\"camera\"},y:{valType:\"number\",dflt:e,editType:\"camera\"},z:{valType:\"number\",dflt:r,editType:\"camera\"},editType:\"camera\"}}e.exports={_arrayAttrRegexps:[o(\"scene\",\".annotations\",!0)],bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"plot\"},camera:{up:a(s(0,0,1),{}),center:a(s(0,0,0),{}),eye:a(s(1.25,1.25,1.25),{}),projection:{type:{valType:\"enumerated\",values:[\"perspective\",\"orthographic\"],dflt:\"perspective\",editType:\"calc\"},editType:\"calc\"},editType:\"camera\"},domain:i({name:\"scene\",editType:\"plot\"}),aspectmode:{valType:\"enumerated\",values:[\"auto\",\"cube\",\"data\",\"manual\"],dflt:\"auto\",editType:\"plot\",impliedEdits:{\"aspectratio.x\":void 0,\"aspectratio.y\":void 0,\"aspectratio.z\":void 0}},aspectratio:{x:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},y:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},z:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},editType:\"plot\",impliedEdits:{aspectmode:\"manual\"}},xaxis:n,yaxis:n,zaxis:n,dragmode:{valType:\"enumerated\",values:[\"orbit\",\"turntable\",\"zoom\",\"pan\",!1],editType:\"plot\"},hovermode:{valType:\"enumerated\",values:[\"closest\",!1],dflt:\"closest\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"plot\",_deprecated:{cameraposition:{valType:\"info_array\",editType:\"camera\"}}}},{\"../../../lib\":719,\"../../../lib/extend\":710,\"../../domain\":792,\"./axis_attributes\":809}],814:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=[\"xaxis\",\"yaxis\",\"zaxis\"];function a(){this.enabled=[!0,!0,!0],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.drawSides=[!0,!0,!0],this.lineWidth=[1,1,1]}a.prototype.merge=function(t){for(var e=0;e<3;++e){var r=t[i[e]];r.visible?(this.enabled[e]=r.showspikes,this.colors[e]=n(r.spikecolor),this.drawSides[e]=r.spikesides,this.lineWidth[e]=r.spikethickness):(this.enabled[e]=!1,this.drawSides[e]=!1)}},e.exports=function(t){var e=new a;return e.merge(t),e}},{\"../../../lib/str2rgbarray\":742}],815:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.axesOptions,r=t.glplot.axesPixels,s=t.fullSceneLayout,l=[[],[],[]],c=0;c<3;++c){var u=s[a[c]];if(u._length=(r[c].hi-r[c].lo)*r[c].pixelsPerDataUnit/t.dataScale[c],Math.abs(u._length)===1/0||isNaN(u._length))l[c]=[];else{u._input_range=u.range.slice(),u.range[0]=r[c].lo/t.dataScale[c],u.range[1]=r[c].hi/t.dataScale[c],u._m=1/(t.dataScale[c]*r[c].pixelsPerDataUnit),u.range[0]===u.range[1]&&(u.range[0]-=1,u.range[1]+=1);var h=u.tickmode;if(\"auto\"===u.tickmode){u.tickmode=\"linear\";var f=u.nticks||i.constrain(u._length/40,4,9);n.autoTicks(u,Math.abs(u.range[1]-u.range[0])/f)}for(var p=n.calcTicks(u),d=0;d<p.length;++d)p[d].x=p[d].x*t.dataScale[c],\"date\"===u.type&&(p[d].text=p[d].text.replace(/\\<br\\>/g,\" \"));l[c]=p,u.tickmode=h}}e.ticks=l;for(var c=0;c<3;++c){o[c]=.5*(t.glplot.bounds[0][c]+t.glplot.bounds[1][c]);for(var d=0;d<2;++d)e.bounds[d][c]=t.glplot.bounds[d][c]}t.contourLevels=function(t){for(var e=new Array(3),r=0;r<3;++r){for(var n=t[r],i=new Array(n.length),a=0;a<n.length;++a)i[a]=n[a].x;e[r]=i}return e}(l)};var n=t(\"../../cartesian/axes\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"],o=[0,0,0]},{\"../../../lib\":719,\"../../cartesian/axes\":767}],816:[function(t,e,r){\"use strict\";function n(t,e){var r,n,i=[0,0,0,0];for(r=0;r<4;++r)for(n=0;n<4;++n)i[n]+=t[4*r+n]*e[r];return i}e.exports=function(t,e){return n(t.projection,n(t.view,n(t.model,[e[0],e[1],e[2],1])))}},{}],817:[function(t,e,r){\"use strict\";var n,i,a=t(\"gl-plot3d\").createCamera,o=t(\"gl-plot3d\").createScene,s=t(\"webgl-context\"),l=t(\"has-passive-events\"),c=t(\"../../registry\"),u=t(\"../../lib\"),h=t(\"../../plots/cartesian/axes\"),f=t(\"../../components/fx\"),p=t(\"../../lib/str2rgbarray\"),d=t(\"../../lib/show_no_webgl_msg\"),g=t(\"./project\"),v=t(\"./layout/convert\"),m=t(\"./layout/spikes\"),y=t(\"./layout/tick_marks\");function x(t,e,r,a){if(t.initializeGLCamera(),!function(t,e,r,a,l){var c={canvas:a,gl:l,container:t.container,axes:t.axesOptions,spikes:t.spikeOptions,pickRadius:10,snapToData:!0,autoScale:!0,autoBounds:!1,cameraObject:e,pixelRatio:r};if(t.staticMode){if(!(i||(n=document.createElement(\"canvas\"),i=s({canvas:n,preserveDrawingBuffer:!0,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"error creating static canvas/context for image server\");c.pixelRatio=t.pixelRatio,c.gl=i,c.canvas=n}try{t.glplot=o(c)}catch(t){return!1}return!0}(t,t.camera,e,r,a))return d(t);var c=t.graphDiv,p=function(t){if(!1!==t.fullSceneLayout.dragmode){var e={};e[t.id+\".camera\"]=T(t.camera),t.saveCamera(c.layout),t.graphDiv.emit(\"plotly_relayout\",e)}};return t.glplot.canvas.addEventListener(\"mouseup\",function(){p(t)}),t.glplot.canvas.addEventListener(\"wheel\",function(){c._context._scrollZoom.gl3d&&p(t)},!!l&&{passive:!1}),t.glplot.canvas.addEventListener(\"mousemove\",function(){if(!1!==t.fullSceneLayout.dragmode&&0!==t.camera.mouseListener.buttons){var e={};e[t.id+\".camera\"]=T(t.camera),t.graphDiv.emit(\"plotly_relayouting\",e)}}),t.staticMode||t.glplot.canvas.addEventListener(\"webglcontextlost\",function(e){c&&c.emit&&c.emit(\"plotly_webglcontextlost\",{event:e,layer:t.id})},!1),t.glplot.camera=t.camera,t.glplot.oncontextloss=function(){t.recoverContext()},t.glplot.onrender=function(t){var e,r=t.graphDiv,n=t.svgContainer,i=t.container.getBoundingClientRect(),a=i.width,o=i.height;n.setAttributeNS(null,\"viewBox\",\"0 0 \"+a+\" \"+o),n.setAttributeNS(null,\"width\",a),n.setAttributeNS(null,\"height\",o),y(t),t.glplot.axes.update(t.axesOptions);for(var s,l=Object.keys(t.traces),c=null,p=t.glplot.selection,d=0;d<l.length;++d)\"skip\"!==(e=t.traces[l[d]]).data.hoverinfo&&e.handlePick(p)&&(c=e),e.setContourLevels&&e.setContourLevels();function v(e,r){var n=t.fullSceneLayout[e];return h.tickText(n,n.d2l(r),\"hover\").text}if(null!==c){var m=g(t.glplot.cameraParams,p.dataCoordinate);e=c.data;var x,b=r._fullData[e.index],_=p.index,w={xLabel:v(\"xaxis\",p.traceCoordinate[0]),yLabel:v(\"yaxis\",p.traceCoordinate[1]),zLabel:v(\"zaxis\",p.traceCoordinate[2])},k=f.castHoverinfo(b,t.fullLayout,_),T=(k||\"\").split(\"+\"),A=k&&\"all\"===k;b.hovertemplate||A||(-1===T.indexOf(\"x\")&&(w.xLabel=void 0),-1===T.indexOf(\"y\")&&(w.yLabel=void 0),-1===T.indexOf(\"z\")&&(w.zLabel=void 0),-1===T.indexOf(\"text\")&&(p.textLabel=void 0),-1===T.indexOf(\"name\")&&(c.name=void 0));var M=[];\"cone\"===e.type||\"streamtube\"===e.type?(w.uLabel=v(\"xaxis\",p.traceCoordinate[3]),(A||-1!==T.indexOf(\"u\"))&&M.push(\"u: \"+w.uLabel),w.vLabel=v(\"yaxis\",p.traceCoordinate[4]),(A||-1!==T.indexOf(\"v\"))&&M.push(\"v: \"+w.vLabel),w.wLabel=v(\"zaxis\",p.traceCoordinate[5]),(A||-1!==T.indexOf(\"w\"))&&M.push(\"w: \"+w.wLabel),w.normLabel=p.traceCoordinate[6].toPrecision(3),(A||-1!==T.indexOf(\"norm\"))&&M.push(\"norm: \"+w.normLabel),\"streamtube\"===e.type&&(w.divergenceLabel=p.traceCoordinate[7].toPrecision(3),(A||-1!==T.indexOf(\"divergence\"))&&M.push(\"divergence: \"+w.divergenceLabel)),p.textLabel&&M.push(p.textLabel),x=M.join(\"<br>\")):\"isosurface\"===e.type||\"volume\"===e.type?(w.valueLabel=h.tickText(t.mockAxis,t.mockAxis.d2l(p.traceCoordinate[3]),\"hover\").text,M.push(\"value: \"+w.valueLabel),p.textLabel&&M.push(p.textLabel),x=M.join(\"<br>\")):x=p.textLabel;var S={x:p.traceCoordinate[0],y:p.traceCoordinate[1],z:p.traceCoordinate[2],data:b._input,fullData:b,curveNumber:b.index,pointNumber:_};f.appendArrayPointValue(S,b,_),e._module.eventData&&(S=b._module.eventData(S,p,b,{},_));var E={points:[S]};t.fullSceneLayout.hovermode&&f.loneHover({trace:b,x:(.5+.5*m[0]/m[3])*a,y:(.5-.5*m[1]/m[3])*o,xLabel:w.xLabel,yLabel:w.yLabel,zLabel:w.zLabel,text:x,name:c.name,color:f.castHoverOption(b,_,\"bgcolor\")||c.color,borderColor:f.castHoverOption(b,_,\"bordercolor\"),fontFamily:f.castHoverOption(b,_,\"font.family\"),fontSize:f.castHoverOption(b,_,\"font.size\"),fontColor:f.castHoverOption(b,_,\"font.color\"),nameLength:f.castHoverOption(b,_,\"namelength\"),textAlign:f.castHoverOption(b,_,\"align\"),hovertemplate:u.castOption(b,_,\"hovertemplate\"),hovertemplateLabels:u.extendFlat({},S,w),eventData:[S]},{container:n,gd:r}),p.buttons&&p.distance<5?r.emit(\"plotly_click\",E):r.emit(\"plotly_hover\",E),s=E}else f.loneUnhover(n),r.emit(\"plotly_unhover\",s);t.drawAnnotations(t)}.bind(null,t),t.traces={},t.make4thDimension(),!0}function b(t,e){var r=document.createElement(\"div\"),n=t.container;this.graphDiv=t.graphDiv;var i=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");i.style.position=\"absolute\",i.style.top=i.style.left=\"0px\",i.style.width=i.style.height=\"100%\",i.style[\"z-index\"]=20,i.style[\"pointer-events\"]=\"none\",r.appendChild(i),this.svgContainer=i,r.id=t.id,r.style.position=\"absolute\",r.style.top=r.style.left=\"0px\",r.style.width=r.style.height=\"100%\",n.appendChild(r),this.fullLayout=e,this.id=t.id||\"scene\",this.fullSceneLayout=e[this.id],this.plotArgs=[[],{},{}],this.axesOptions=v(e,e[this.id]),this.spikeOptions=m(e[this.id]),this.container=r,this.staticMode=!!t.staticPlot,this.pixelRatio=this.pixelRatio||t.plotGlPixelRatio||2,this.dataScale=[1,1,1],this.contourLevels=[[],[],[]],this.convertAnnotations=c.getComponentMethod(\"annotations3d\",\"convert\"),this.drawAnnotations=c.getComponentMethod(\"annotations3d\",\"draw\"),x(this,this.pixelRatio)}var _=b.prototype;_.initializeGLCamera=function(){var t=this.fullSceneLayout.camera,e=\"orthographic\"===t.projection.type;this.camera=a(this.container,{center:[t.center.x,t.center.y,t.center.z],eye:[t.eye.x,t.eye.y,t.eye.z],up:[t.up.x,t.up.y,t.up.z],_ortho:e,zoomMin:.01,zoomMax:100,mode:\"orbit\"})},_.recoverContext=function(){var t=this,e=this.glplot.gl,r=this.glplot.canvas,n=this.glplot.camera,i=this.glplot.pixelRatio;this.glplot.dispose(),requestAnimationFrame(function a(){e.isContextLost()?requestAnimationFrame(a):x(t,n,i,r)?t.plot.apply(t,t.plotArgs):u.error(\"Catastrophic and unrecoverable WebGL error. Context lost.\")})};var w=[\"xaxis\",\"yaxis\",\"zaxis\"];function k(t,e,r){for(var n=t.fullSceneLayout,i=0;i<3;i++){var a=w[i],o=a.charAt(0),s=n[a],l=e[o],c=e[o+\"calendar\"],h=e[\"_\"+o+\"length\"];if(u.isArrayOrTypedArray(l))for(var f,p=0;p<(h||l.length);p++)if(u.isArrayOrTypedArray(l[p]))for(var d=0;d<l[p].length;++d)f=s.d2l(l[p][d],0,c),!isNaN(f)&&isFinite(f)&&(r[0][i]=Math.min(r[0][i],f),r[1][i]=Math.max(r[1][i],f));else f=s.d2l(l[p],0,c),!isNaN(f)&&isFinite(f)&&(r[0][i]=Math.min(r[0][i],f),r[1][i]=Math.max(r[1][i],f));else r[0][i]=Math.min(r[0][i],0),r[1][i]=Math.max(r[1][i],h-1)}}function T(t){return{up:{x:t.up[0],y:t.up[1],z:t.up[2]},center:{x:t.center[0],y:t.center[1],z:t.center[2]},eye:{x:t.eye[0],y:t.eye[1],z:t.eye[2]},projection:{type:!0===t._ortho?\"orthographic\":\"perspective\"}}}_.plot=function(t,e,r){if(this.plotArgs=[t,e,r],!this.glplot.contextLost){var n,i,a,o,s,l,c=e[this.id],u=r[this.id];c.bgcolor?this.glplot.clearColor=p(c.bgcolor):this.glplot.clearColor=[0,0,0,0],this.glplot.snapToData=!0,this.fullLayout=e,this.fullSceneLayout=c,this.glplotLayout=c,this.axesOptions.merge(e,c),this.spikeOptions.merge(c),this.setCamera(c.camera),this.updateFx(c.dragmode,c.hovermode),this.camera.enableWheel=this.graphDiv._context._scrollZoom.gl3d,this.glplot.update({}),this.setConvert(s),t?Array.isArray(t)||(t=[t]):t=[];var h=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&k(this,n,h);!function(t,e){for(var r=t.fullSceneLayout,n=r.annotations||[],i=0;i<3;i++)for(var a=w[i],o=a.charAt(0),s=r[a],l=0;l<n.length;l++){var c=n[l];if(c.visible){var u=s.r2l(c[o]);!isNaN(u)&&isFinite(u)&&(e[0][i]=Math.min(e[0][i],u),e[1][i]=Math.max(e[1][i],u))}}}(this,h);var f=[1,1,1];for(o=0;o<3;++o)h[1][o]===h[0][o]?f[o]=1:f[o]=1/(h[1][o]-h[0][o]);for(this.dataScale=f,this.convertAnnotations(this),a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&((i=this.traces[n.uid])?i.data.type===n.type?i.update(n):(i.dispose(),i=n._module.plot(this,n),this.traces[n.uid]=i):(i=n._module.plot(this,n),this.traces[n.uid]=i),i.name=n.name);var d=Object.keys(this.traces);t:for(a=0;a<d.length;++a){for(o=0;o<t.length;++o)if(t[o].uid===d[a]&&!0===t[o].visible&&0!==t[o]._length)continue t;(i=this.traces[d[a]]).dispose(),delete this.traces[d[a]]}this.glplot.objects.sort(function(t,e){return t._trace.data.index-e._trace.data.index});var g=[[0,0,0],[0,0,0]],v=[],m={};for(a=0;a<3;++a){if((l=(s=c[w[a]]).type)in m?(m[l].acc*=f[a],m[l].count+=1):m[l]={acc:f[a],count:1},s.autorange){g[0][a]=1/0,g[1][a]=-1/0;var y=this.glplot.objects,x=this.fullSceneLayout.annotations||[],b=s._name.charAt(0);for(o=0;o<y.length;o++){var _=y[o],T=_.bounds,A=_._trace.data._pad||0;\"ErrorBars\"===_.constructor.name&&s._lowerLogErrorBound?g[0][a]=Math.min(g[0][a],s._lowerLogErrorBound):g[0][a]=Math.min(g[0][a],T[0][a]/f[a]-A),g[1][a]=Math.max(g[1][a],T[1][a]/f[a]+A)}for(o=0;o<x.length;o++){var M=x[o];if(M.visible){var S=s.r2l(M[b]);g[0][a]=Math.min(g[0][a],S),g[1][a]=Math.max(g[1][a],S)}}if(\"rangemode\"in s&&\"tozero\"===s.rangemode&&(g[0][a]=Math.min(g[0][a],0),g[1][a]=Math.max(g[1][a],0)),g[0][a]>g[1][a])g[0][a]=-1,g[1][a]=1;else{var E=g[1][a]-g[0][a];g[0][a]-=E/32,g[1][a]+=E/32}if(\"reversed\"===s.autorange){var C=g[0][a];g[0][a]=g[1][a],g[1][a]=C}}else{var L=s.range;g[0][a]=s.r2l(L[0]),g[1][a]=s.r2l(L[1])}g[0][a]===g[1][a]&&(g[0][a]-=1,g[1][a]+=1),v[a]=g[1][a]-g[0][a],this.glplot.bounds[0][a]=g[0][a]*f[a],this.glplot.bounds[1][a]=g[1][a]*f[a]}var P=[1,1,1];for(a=0;a<3;++a){var O=m[l=(s=c[w[a]]).type];P[a]=Math.pow(O.acc,1/O.count)/f[a]}var z;if(\"auto\"===c.aspectmode)z=Math.max.apply(null,P)/Math.min.apply(null,P)<=4?P:[1,1,1];else if(\"cube\"===c.aspectmode)z=[1,1,1];else if(\"data\"===c.aspectmode)z=P;else{if(\"manual\"!==c.aspectmode)throw new Error(\"scene.js aspectRatio was not one of the enumerated types\");var I=c.aspectratio;z=[I.x,I.y,I.z]}c.aspectratio.x=u.aspectratio.x=z[0],c.aspectratio.y=u.aspectratio.y=z[1],c.aspectratio.z=u.aspectratio.z=z[2],this.glplot.aspect=z;var D=c.domain||null,R=e._size||null;if(D&&R){var F=this.container.style;F.position=\"absolute\",F.left=R.l+D.x[0]*R.w+\"px\",F.top=R.t+(1-D.y[1])*R.h+\"px\",F.width=R.w*(D.x[1]-D.x[0])+\"px\",F.height=R.h*(D.y[1]-D.y[0])+\"px\"}this.glplot.redraw()}},_.destroy=function(){this.glplot&&(this.camera.mouseListener.enabled=!1,this.container.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=this.glplot.camera=null,this.glplot.dispose(),this.container.parentNode.removeChild(this.container),this.glplot=null)},_.getCamera=function(){return this.glplot.camera.view.recalcMatrix(this.camera.view.lastT()),T(this.glplot.camera)},_.setCamera=function(t){var e;this.glplot.camera.lookAt.apply(this,[[(e=t).eye.x,e.eye.y,e.eye.z],[e.center.x,e.center.y,e.center.z],[e.up.x,e.up.y,e.up.z]]);var r=\"orthographic\"===t.projection.type;if(r!==this.glplot.camera._ortho){this.glplot.redraw();var n=this.glplot.pixelRatio,i=this.glplot.clearColor;this.glplot.gl.clearColor(i[0],i[1],i[2],i[3]),this.glplot.gl.clear(this.glplot.gl.DEPTH_BUFFER_BIT|this.glplot.gl.COLOR_BUFFER_BIT),this.glplot.dispose(),x(this,n),this.glplot.camera._ortho=r}},_.saveCamera=function(t){var e=this.fullLayout,r=this.getCamera(),n=u.nestedProperty(t,this.id+\".camera\"),i=n.get(),a=!1;function o(t,e,r,n){var i=[\"up\",\"center\",\"eye\"],a=[\"x\",\"y\",\"z\"];return e[i[r]]&&t[i[r]][a[n]]===e[i[r]][a[n]]}if(void 0===i)a=!0;else{for(var s=0;s<3;s++)for(var l=0;l<3;l++)if(!o(r,i,s,l)){a=!0;break}(!i.projection||r.projection&&r.projection.type!==i.projection.type)&&(a=!0)}if(a){var h={};h[this.id+\".camera\"]=i,c.call(\"_storeDirectGUIEdit\",t,e._preGUI,h),n.set(r),u.nestedProperty(e,this.id+\".camera\").set(r)}return a},_.updateFx=function(t,e){var r=this.camera;if(r)if(\"orbit\"===t)r.mode=\"orbit\",r.keyBindingMode=\"rotate\";else if(\"turntable\"===t){r.up=[0,0,1],r.mode=\"turntable\",r.keyBindingMode=\"rotate\";var n=this.graphDiv,i=n._fullLayout,a=this.fullSceneLayout.camera,o=a.up.x,s=a.up.y,l=a.up.z;if(l/Math.sqrt(o*o+s*s+l*l)<.999){var h=this.id+\".camera.up\",f={x:0,y:0,z:1},p={};p[h]=f;var d=n.layout;c.call(\"_storeDirectGUIEdit\",d,i._preGUI,p),a.up=f,u.nestedProperty(d,h).set(f)}}else r.keyBindingMode=t;this.fullSceneLayout.hovermode=e},_.toImage=function(t){t||(t=\"png\"),this.staticMode&&this.container.appendChild(n),this.glplot.redraw();var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a);for(var o=0,s=i-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=a[4*(r*o+l)+c];a[4*(r*o+l)+c]=a[4*(r*s+l)+c],a[4*(r*s+l)+c]=u}var h=document.createElement(\"canvas\");h.width=r,h.height=i;var f,p=h.getContext(\"2d\"),d=p.createImageData(r,i);switch(d.data.set(a),p.putImageData(d,0,0),t){case\"jpeg\":f=h.toDataURL(\"image/jpeg\");break;case\"webp\":f=h.toDataURL(\"image/webp\");break;default:f=h.toDataURL(\"image/png\")}return this.staticMode&&this.container.removeChild(n),f},_.setConvert=function(){for(var t=0;t<3;t++){var e=this.fullSceneLayout[w[t]];h.setConvert(e,this.fullLayout),e.setScale=u.noop}},_.make4thDimension=function(){var t=this.graphDiv._fullLayout;this.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},h.setConvert(this.mockAxis,t)},e.exports=b},{\"../../components/fx\":632,\"../../lib\":719,\"../../lib/show_no_webgl_msg\":740,\"../../lib/str2rgbarray\":742,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./layout/convert\":811,\"./layout/spikes\":814,\"./layout/tick_marks\":815,\"./project\":816,\"gl-plot3d\":290,\"has-passive-events\":411,\"webgl-context\":556}],818:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){n=n||t.length;for(var i=new Array(n),a=0;a<n;a++)i[a]=[t[a],e[a],r[a]];return i}},{}],819:[function(t,e,r){\"use strict\";var n=t(\"./font_attributes\"),i=t(\"./animation_attributes\"),a=t(\"../components/color/attributes\"),o=t(\"./pad_attributes\"),s=t(\"../lib/extend\").extendFlat,l=n({editType:\"calc\"});l.family.dflt='\"Open Sans\", verdana, arial, sans-serif',l.size.dflt=12,l.color.dflt=a.defaultLine,e.exports={font:l,title:{text:{valType:\"string\",editType:\"layoutstyle\"},font:n({editType:\"layoutstyle\"}),xref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},yref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},x:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"layoutstyle\"},y:{valType:\"number\",min:0,max:1,dflt:\"auto\",editType:\"layoutstyle\"},xanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"left\",\"center\",\"right\"],editType:\"layoutstyle\"},yanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],editType:\"layoutstyle\"},pad:s(o({editType:\"layoutstyle\"}),{}),editType:\"layoutstyle\"},autosize:{valType:\"boolean\",dflt:!1,editType:\"none\"},width:{valType:\"number\",min:10,dflt:700,editType:\"plot\"},height:{valType:\"number\",min:10,dflt:450,editType:\"plot\"},margin:{l:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},r:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},t:{valType:\"number\",min:0,dflt:100,editType:\"plot\"},b:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},pad:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},autoexpand:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},paper_bgcolor:{valType:\"color\",dflt:a.background,editType:\"plot\"},plot_bgcolor:{valType:\"color\",dflt:a.background,editType:\"layoutstyle\"},separators:{valType:\"string\",editType:\"plot\"},hidesources:{valType:\"boolean\",dflt:!1,editType:\"plot\"},showlegend:{valType:\"boolean\",editType:\"legend\"},colorway:{valType:\"colorlist\",dflt:a.defaults,editType:\"calc\"},datarevision:{valType:\"any\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editrevision:{valType:\"any\",editType:\"none\"},selectionrevision:{valType:\"any\",editType:\"none\"},template:{valType:\"any\",editType:\"calc\"},modebar:{orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\",editType:\"modebar\"},bgcolor:{valType:\"color\",editType:\"modebar\"},color:{valType:\"color\",editType:\"modebar\"},activecolor:{valType:\"color\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"modebar\"},meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},transition:s({},i.transition,{editType:\"none\"}),_deprecated:{title:{valType:\"string\",editType:\"layoutstyle\"},titlefont:n({editType:\"layoutstyle\"})}}},{\"../components/color/attributes\":592,\"../lib/extend\":710,\"./animation_attributes\":762,\"./font_attributes\":793,\"./pad_attributes\":827}],820:[function(t,e,r){\"use strict\";var n={\"open-street-map\":{id:\"osm\",version:8,sources:{\"plotly-osm-tiles\":{type:\"raster\",attribution:'<a href=\"http://www.openstreetmap.org/about/\" target=\"_blank\">\\xa9 OpenStreetMap</a>',tiles:[\"https://a.tile.openstreetmap.org/{z}/{x}/{y}.png\",\"https://b.tile.openstreetmap.org/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-osm-tiles\",type:\"raster\",source:\"plotly-osm-tiles\",minzoom:0,maxzoom:22}]},\"white-bg\":{id:\"white-bg\",version:8,sources:{},layers:[{id:\"white-bg\",type:\"background\",paint:{\"background-color\":\"#FFFFFF\"},minzoom:0,maxzoom:22}]},\"carto-positron\":{id:\"carto-positron\",version:8,sources:{\"plotly-carto-positron\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/light_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-positron\",type:\"raster\",source:\"plotly-carto-positron\",minzoom:0,maxzoom:22}]},\"carto-darkmatter\":{id:\"carto-darkmatter\",version:8,sources:{\"plotly-carto-darkmatter\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/dark_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-darkmatter\",type:\"raster\",source:\"plotly-carto-darkmatter\",minzoom:0,maxzoom:22}]},\"stamen-terrain\":{id:\"stamen-terrain\",version:8,sources:{\"plotly-stamen-terrain\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/terrain/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-terrain\",type:\"raster\",source:\"plotly-stamen-terrain\",minzoom:0,maxzoom:22}]},\"stamen-toner\":{id:\"stamen-toner\",version:8,sources:{\"plotly-stamen-toner\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/toner/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-toner\",type:\"raster\",source:\"plotly-stamen-toner\",minzoom:0,maxzoom:22}]},\"stamen-watercolor\":{id:\"stamen-watercolor\",version:8,sources:{\"plotly-stamen-watercolor\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://creativecommons.org/licenses/by-sa/3.0\">CC BY SA</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/watercolor/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-watercolor\",type:\"raster\",source:\"plotly-stamen-watercolor\",minzoom:0,maxzoom:22}]}},i=Object.keys(n);e.exports={requiredVersion:\"1.1.1\",styleUrlPrefix:\"mapbox://styles/mapbox/\",styleUrlSuffix:\"v9\",styleValuesMapbox:[\"basic\",\"streets\",\"outdoors\",\"light\",\"dark\",\"satellite\",\"satellite-streets\"],styleValueDflt:\"basic\",stylesNonMapbox:n,styleValuesNonMapbox:i,traceLayerPrefix:\"plotly-trace-layer-\",layoutLayerPrefix:\"plotly-layout-layer-\",wrongVersionErrorMsg:[\"Your custom plotly.js bundle is not using the correct mapbox-gl version\",\"Please install mapbox-gl@1.1.1.\"].join(\"\\n\"),noAccessTokenErrorMsg:[\"Missing Mapbox access token.\",\"Mapbox trace type require a Mapbox access token to be registered.\",\"For example:\",\"  Plotly.plot(gd, data, layout, { mapboxAccessToken: 'my-access-token' });\",\"More info here: https://www.mapbox.com/help/define-access-token/\"].join(\"\\n\"),missingStyleErrorMsg:[\"No valid mapbox style found, please set `mapbox.style` to one of:\",i.join(\", \"),\"or register a Mapbox access token to use a Mapbox-served style.\"].join(\"\\n\"),multipleTokensErrorMsg:[\"Set multiple mapbox access token across different mapbox subplot,\",\"using first token found as mapbox-gl does not allow multipleaccess tokens on the same page.\"].join(\"\\n\"),mapOnErrorMsg:\"Mapbox error.\",mapboxLogo:{path0:\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\",path1:\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\",path2:\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\",polygon:\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34\"},styleRules:{map:\"overflow:hidden;position:relative;\",\"missing-css\":\"display:none;\",canary:\"background-color:salmon;\",\"ctrl-bottom-left\":\"position: absolute; pointer-events: none; z-index: 2; bottom: 0; left: 0;\",\"ctrl-bottom-right\":\"position: absolute; pointer-events: none; z-index: 2; right: 0; bottom: 0;\",ctrl:\"clear: both; pointer-events: auto; transform: translate(0, 0);\",\"ctrl-attrib.mapboxgl-compact .mapboxgl-ctrl-attrib-inner\":\"display: none;\",\"ctrl-attrib.mapboxgl-compact:hover .mapboxgl-ctrl-attrib-inner\":\"display: block; margin-top:2px\",\"ctrl-attrib.mapboxgl-compact:hover\":\"padding: 2px 24px 2px 4px; visibility: visible; margin-top: 6px;\",\"ctrl-attrib.mapboxgl-compact::after\":'content: \"\"; cursor: pointer; position: absolute; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3Csvg viewBox=\"0 0 20 20\" xmlns=\"http://www.w3.org/2000/svg\"%3E %3Cpath fill=\"%23333333\" fill-rule=\"evenodd\" d=\"M4,10a6,6 0 1,0 12,0a6,6 0 1,0 -12,0 M9,7a1,1 0 1,0 2,0a1,1 0 1,0 -2,0 M9,10a1,1 0 1,1 2,0l0,3a1,1 0 1,1 -2,0\"/%3E %3C/svg%3E\\'); background-color: rgba(255, 255, 255, 0.5); width: 24px; height: 24px; box-sizing: border-box; border-radius: 12px;',\"ctrl-attrib.mapboxgl-compact\":\"min-height: 20px; padding: 0; margin: 10px; position: relative; background-color: #fff; border-radius: 3px 12px 12px 3px;\",\"ctrl-bottom-right > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; right: 0\",\"ctrl-bottom-left > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; left: 0\",\"ctrl-bottom-left .mapboxgl-ctrl\":\"margin: 0 0 10px 10px; float: left;\",\"ctrl-bottom-right .mapboxgl-ctrl\":\"margin: 0 10px 10px 0; float: right;\",\"ctrl-attrib\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a:hover\":\"color: inherit; text-decoration: underline;\",\"ctrl-attrib .mapbox-improve-map\":\"font-weight: bold; margin-left: 2px;\",\"attrib-empty\":\"display: none;\",\"ctrl-logo\":'display:block; width: 21px; height: 21px; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3C?xml version=\"1.0\" encoding=\"utf-8\"?%3E %3Csvg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\" viewBox=\"0 0 21 21\" style=\"enable-background:new 0 0 21 21;\" xml:space=\"preserve\"%3E%3Cg transform=\"translate(0,0.01)\"%3E%3Cpath d=\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3Cpath d=\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpath d=\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpolygon points=\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34 \" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3C/g%3E%3C/svg%3E\\')'}}},{}],821:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t.split(\" \"),i=r[0],a=r[1],o=n.isArrayOrTypedArray(e)?n.mean(e):e,s=.5+o/100,l=1.5+o/100,c=[\"\",\"\"],u=[0,0];switch(i){case\"top\":c[0]=\"top\",u[1]=-l;break;case\"bottom\":c[0]=\"bottom\",u[1]=l}switch(a){case\"left\":c[1]=\"right\",u[0]=-s;break;case\"right\":c[1]=\"left\",u[0]=s}return{anchor:c[0]&&c[1]?c.join(\"-\"):c[0]?c[0]:c[1]?c[1]:\"center\",offset:u}}},{\"../../lib\":719}],822:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"../../lib\"),a=t(\"../../plots/get_data\").getSubplotCalcData,o=t(\"../../constants/xmlns_namespaces\"),s=t(\"d3\"),l=t(\"../../components/drawing\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"./mapbox\"),h=r.constants=t(\"./constants\");function f(t){return\"string\"==typeof t&&-1!==h.styleValuesMapbox.indexOf(t)}r.name=\"mapbox\",r.attr=\"subplot\",r.idRoot=\"mapbox\",r.idRegex=r.attrRegex=i.counterRegex(\"mapbox\"),r.attributes={subplot:{valType:\"subplotid\",dflt:\"mapbox\",editType:\"calc\"}},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){var e=t._fullLayout,r=t.calcdata,o=e._subplots.mapbox;if(n.version!==h.requiredVersion)throw new Error(h.wrongVersionErrorMsg);var s=function(t,e){var r=t._fullLayout;if(\"\"===t._context.mapboxAccessToken)return\"\";for(var n=[],a=[],o=!1,s=!1,l=0;l<e.length;l++){var c=r[e[l]],u=c.accesstoken;f(c.style)&&(u?i.pushUnique(n,u):(f(c._input.style)&&(i.error(\"Uses Mapbox map style, but did not set an access token.\"),o=!0),s=!0)),u&&i.pushUnique(a,u)}if(s){var p=o?h.noAccessTokenErrorMsg:h.missingStyleErrorMsg;throw new Error(p)}return n.length?(n.length>1&&i.warn(h.multipleTokensErrorMsg),n[0]):(a.length&&i.log([\"Listed mapbox access token(s)\",a.join(\",\"),\"but did not use a Mapbox map style, ignoring token(s).\"].join(\" \")),\"\")}(t,o);n.accessToken=s;for(var l=0;l<o.length;l++){var c=o[l],p=a(r,\"mapbox\",c),d=e[c],g=d._subplot;g||(g=new u(t,c),e[c]._subplot=g),g.viewInitial||(g.viewInitial={center:i.extendFlat({},d.center),zoom:d.zoom,bearing:d.bearing,pitch:d.pitch}),g.plot(p,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.mapbox||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._subplot&&n[o]._subplot.destroy()}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=e._size,i=0;i<r.length;i++){var a=e[r[i]],u=a.domain,f=a._subplot.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":f,x:n.l+n.w*u.x[0],y:n.t+n.h*(1-u.y[1]),width:n.w*(u.x[1]-u.x[0]),height:n.h*(u.y[1]-u.y[0]),preserveAspectRatio:\"none\"});var p=s.select(a._subplot.div);if(!(null===p.select(\".mapboxgl-ctrl-logo\").node().offsetParent)){var d=e._glimages.append(\"g\");d.attr(\"transform\",\"translate(\"+(n.l+n.w*u.x[0]+10)+\", \"+(n.t+n.h*(1-u.y[0])-31)+\")\"),d.append(\"path\").attr(\"d\",h.mapboxLogo.path0).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"}),d.append(\"path\").attr(\"d\",h.mapboxLogo.path1).style(\"opacity\",.35).style(\"enable-background\",\"new\"),d.append(\"path\").attr(\"d\",h.mapboxLogo.path2).style(\"opacity\",.35).style(\"enable-background\",\"new\"),d.append(\"polygon\").attr(\"points\",h.mapboxLogo.polygon).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"})}var g=p.select(\".mapboxgl-ctrl-attrib\").text().replace(\"Improve this map\",\"\"),v=e._glimages.append(\"g\"),m=v.append(\"text\");m.text(g).classed(\"static-attribution\",!0).attr({\"font-size\":12,\"font-family\":\"Arial\",color:\"rgba(0, 0, 0, 0.75)\",\"text-anchor\":\"end\",\"data-unformatted\":g});var y=l.bBox(m.node()),x=n.w*(u.x[1]-u.x[0]);if(y.width>x/2){var b=g.split(\"|\").join(\"<br>\");m.text(b).attr(\"data-unformatted\",b).call(c.convertToTspans,t),y=l.bBox(m.node())}m.attr(\"transform\",\"translate(-3, \"+(8-y.height)+\")\"),v.insert(\"rect\",\".static-attribution\").attr({x:-y.width-6,y:-y.height-3,width:y.width+6,height:y.height+3,fill:\"rgba(255, 255, 255, 0.75)\"});var _=1;y.width+6>x&&(_=x/(y.width+6));var w=[n.l+n.w*u.x[1],n.t+n.h*(1-u.y[0])];v.attr(\"transform\",\"translate(\"+w[0]+\",\"+w[1]+\") scale(\"+_+\")\")}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=0;n<r.length;n++){e[r[n]]._subplot.updateFx(e)}}},{\"../../components/drawing\":614,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/get_data\":802,\"./constants\":820,\"./layout_attributes\":824,\"./layout_defaults\":825,\"./mapbox\":826,d3:163,\"mapbox-gl\":426}],823:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./convert_text_opts\"),a=t(\"./constants\");function o(t,e){this.subplot=t,this.uid=t.uid+\"-\"+e,this.index=e,this.idSource=\"source-\"+this.uid,this.idLayer=a.layoutLayerPrefix+this.uid,this.sourceType=null,this.source=null,this.layerType=null,this.below=null,this.visible=!1}var s=o.prototype;function l(t){var e=t.source;return t.visible&&(n.isPlainObject(e)||(\"string\"==typeof e||Array.isArray(e))&&e.length>0)}function c(t){var e={},r={};switch(t.type){case\"circle\":n.extendFlat(r,{\"circle-radius\":t.circle.radius,\"circle-color\":t.color,\"circle-opacity\":t.opacity});break;case\"line\":n.extendFlat(r,{\"line-width\":t.line.width,\"line-color\":t.color,\"line-opacity\":t.opacity,\"line-dasharray\":t.line.dash});break;case\"fill\":n.extendFlat(r,{\"fill-color\":t.color,\"fill-outline-color\":t.fill.outlinecolor,\"fill-opacity\":t.opacity});break;case\"symbol\":var a=t.symbol,o=i(a.textposition,a.iconsize);n.extendFlat(e,{\"icon-image\":a.icon+\"-15\",\"icon-size\":a.iconsize/10,\"text-field\":a.text,\"text-size\":a.textfont.size,\"text-anchor\":o.anchor,\"text-offset\":o.offset,\"symbol-placement\":a.placement}),n.extendFlat(r,{\"icon-color\":t.color,\"text-color\":a.textfont.color,\"text-opacity\":t.opacity})}return{layout:e,paint:r}}s.update=function(t){this.visible?this.needsNewSource(t)?(this.removeLayer(),this.updateSource(t),this.updateLayer(t)):this.needsNewLayer(t)?this.updateLayer(t):this.updateStyle(t):(this.updateSource(t),this.updateLayer(t)),this.visible=l(t)},s.needsNewSource=function(t){return this.sourceType!==t.sourcetype||this.source!==t.source||this.layerType!==t.type},s.needsNewLayer=function(t){return this.layerType!==t.type||this.below!==this.subplot.belowLookup[\"layout-\"+this.index]},s.updateSource=function(t){var e=this.subplot.map;if(e.getSource(this.idSource)&&e.removeSource(this.idSource),this.sourceType=t.sourcetype,this.source=t.source,l(t)){var r=function(t){var e,r=t.sourcetype,n=t.source,i={type:r};\"geojson\"===r?e=\"data\":\"vector\"===r?e=\"string\"==typeof n?\"url\":\"tiles\":\"raster\"===r?(e=\"tiles\",i.tileSize=256):\"image\"===r&&(e=\"url\",i.coordinates=t.coordinates);i[e]=n,t.sourceattribution&&(i.attribution=t.sourceattribution);return i}(t);e.addSource(this.idSource,r)}},s.updateLayer=function(t){var e,r=this.subplot,n=c(t),i=this.subplot.belowLookup[\"layout-\"+this.index];if(\"traces\"===i)for(var o=r.getMapLayers(),s=0;s<o.length;s++){var u=o[s].id;if(\"string\"==typeof u&&0===u.indexOf(a.traceLayerPrefix)){e=u;break}}else e=i;this.removeLayer(),l(t)&&r.addLayer({id:this.idLayer,source:this.idSource,\"source-layer\":t.sourcelayer||\"\",type:t.type,minzoom:t.minzoom,maxzoom:t.maxzoom,layout:n.layout,paint:n.paint},e),this.layerType=t.type,this.below=i},s.updateStyle=function(t){if(l(t)){var e=c(t);this.subplot.setOptions(this.idLayer,\"setLayoutProperty\",e.layout),this.subplot.setOptions(this.idLayer,\"setPaintProperty\",e.paint)}},s.removeLayer=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer)},s.dispose=function(){var t=this.subplot.map;t.removeLayer(this.idLayer),t.removeSource(this.idSource)},e.exports=function(t,e,r){var n=new o(t,e);return n.update(r),n}},{\"../../lib\":719,\"./constants\":820,\"./convert_text_opts\":821}],824:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\").defaultLine,a=t(\"../domain\").attributes,o=t(\"../font_attributes\"),s=t(\"../../traces/scatter/attributes\").textposition,l=t(\"../../plot_api/edit_types\").overrideAll,c=t(\"../../plot_api/plot_template\").templatedArray,u=t(\"./constants\"),h=o({});h.family.dflt=\"Open Sans Regular, Arial Unicode MS Regular\",(e.exports=l({_arrayAttrRegexps:[n.counterRegex(\"mapbox\",\".layers\",!0)],domain:a({name:\"mapbox\"}),accesstoken:{valType:\"string\",noBlank:!0,strict:!0},style:{valType:\"any\",values:u.styleValuesMapbox.concat(u.styleValuesNonMapbox),dflt:u.styleValueDflt},center:{lon:{valType:\"number\",dflt:0},lat:{valType:\"number\",dflt:0}},zoom:{valType:\"number\",dflt:1},bearing:{valType:\"number\",dflt:0},pitch:{valType:\"number\",dflt:0},layers:c(\"layer\",{visible:{valType:\"boolean\",dflt:!0},sourcetype:{valType:\"enumerated\",values:[\"geojson\",\"vector\",\"raster\",\"image\"],dflt:\"geojson\"},source:{valType:\"any\"},sourcelayer:{valType:\"string\",dflt:\"\"},sourceattribution:{valType:\"string\"},type:{valType:\"enumerated\",values:[\"circle\",\"line\",\"fill\",\"symbol\",\"raster\"],dflt:\"circle\"},coordinates:{valType:\"any\"},below:{valType:\"string\"},color:{valType:\"color\",dflt:i},opacity:{valType:\"number\",min:0,max:1,dflt:1},minzoom:{valType:\"number\",min:0,max:24,dflt:0},maxzoom:{valType:\"number\",min:0,max:24,dflt:24},circle:{radius:{valType:\"number\",dflt:15}},line:{width:{valType:\"number\",dflt:2},dash:{valType:\"data_array\"}},fill:{outlinecolor:{valType:\"color\",dflt:i}},symbol:{icon:{valType:\"string\",dflt:\"marker\"},iconsize:{valType:\"number\",dflt:10},text:{valType:\"string\",dflt:\"\"},placement:{valType:\"enumerated\",values:[\"point\",\"line\",\"line-center\"],dflt:\"point\"},textfont:h,textposition:n.extendFlat({},s,{arrayOk:!1})}})},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../traces/scatter/attributes\":1112,\"../domain\":792,\"../font_attributes\":793,\"./constants\":820}],825:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../subplot_defaults\"),a=t(\"../array_container_defaults\"),o=t(\"./layout_attributes\");function s(t,e,r,n){r(\"accesstoken\",n.accessToken),r(\"style\"),r(\"center.lon\"),r(\"center.lat\"),r(\"zoom\"),r(\"bearing\"),r(\"pitch\"),a(t,e,{name:\"layers\",handleItemDefaults:l}),e._input=t}function l(t,e){function r(r,i){return n.coerce(t,e,o.layers,r,i)}if(r(\"visible\")){var i,a=r(\"sourcetype\"),s=\"raster\"===a||\"image\"===a;r(\"source\"),r(\"sourceattribution\"),\"vector\"===a&&r(\"sourcelayer\"),\"image\"===a&&r(\"coordinates\"),s&&(i=\"raster\");var l=r(\"type\",i);s&&\"raster\"!==l&&(l=e.type=\"raster\",n.log(\"Source types *raster* and *image* must drawn *raster* layer type.\")),r(\"below\"),r(\"color\"),r(\"opacity\"),r(\"minzoom\"),r(\"maxzoom\"),\"circle\"===l&&r(\"circle.radius\"),\"line\"===l&&(r(\"line.width\"),r(\"line.dash\")),\"fill\"===l&&r(\"fill.outlinecolor\"),\"symbol\"===l&&(r(\"symbol.icon\"),r(\"symbol.iconsize\"),r(\"symbol.text\"),n.coerceFont(r,\"symbol.textfont\"),r(\"symbol.textposition\"),r(\"symbol.placement\"))}}e.exports=function(t,e,r){i(t,e,r,{type:\"mapbox\",attributes:o,handleDefaults:s,partition:\"y\",accessToken:e._mapboxAccessToken})}},{\"../../lib\":719,\"../array_container_defaults\":763,\"../subplot_defaults\":842,\"./layout_attributes\":824}],826:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"d3\"),a=t(\"../../components/fx\"),o=t(\"../../lib\"),s=t(\"../../registry\"),l=t(\"../cartesian/axes\"),c=t(\"../../components/dragelement\"),u=t(\"../cartesian/select\").prepSelect,h=t(\"../cartesian/select\").selectOnClick,f=t(\"./constants\"),p=t(\"./layers\");function d(t,e){this.id=e,this.gd=t;var r=t._fullLayout,n=t._context;this.container=r._glcontainer.node(),this.isStatic=n.staticPlot,this.uid=r._uid+\"-\"+this.id,this.div=null,this.xaxis=null,this.yaxis=null,this.createFramework(r),this.map=null,this.accessToken=null,this.styleObj=null,this.traceHash={},this.layerList=[],this.belowLookup={}}var g=d.prototype;g.plot=function(t,e,r){var n,i=this,a=e[i.id];i.map&&a.accesstoken!==i.accessToken&&(i.map.remove(),i.map=null,i.styleObj=null,i.traceHash=[],i.layerList={}),n=i.map?new Promise(function(r,n){i.updateMap(t,e,r,n)}):new Promise(function(r,n){i.createMap(t,e,r,n)}),r.push(n)},g.createMap=function(t,e,r,i){var a=this,o=e[a.id],s=a.styleObj=m(o.style);a.accessToken=o.accesstoken;var l=a.map=new n.Map({container:a.div,style:s.style,center:x(o.center),zoom:o.zoom,bearing:o.bearing,pitch:o.pitch,interactive:!a.isStatic,preserveDrawingBuffer:a.isStatic,doubleClickZoom:!1,boxZoom:!1,attributionControl:!1}).addControl(new n.AttributionControl({compact:!0}));l._canvas.style.left=\"0px\",l._canvas.style.top=\"0px\",a.rejectOnError(i),a.isStatic||a.initFx(t,e);var c=[];c.push(new Promise(function(t){l.once(\"load\",t)})),c=c.concat(a.fetchMapData(t,e)),Promise.all(c).then(function(){a.fillBelowLookup(t,e),a.updateData(t),a.updateLayout(e),a.resolveOnRender(r)}).catch(i)},g.fetchMapData=function(t){var e=[];function r(t){return new Promise(function(e,r){i.json(t,function(n,i){if(n){delete PlotlyGeoAssets[t];var a=404===n.status?'GeoJSON at URL \"'+t+'\" does not exist.':\"Unexpected error while fetching from \"+t;return r(new Error(a))}PlotlyGeoAssets[t]=i,e(i)})})}for(var n=0;n<t.length;n++){var a=t[n][0].trace.geojson;\"string\"!=typeof a||PlotlyGeoAssets[a]||(PlotlyGeoAssets[a]=\"pending\",e.push(r(a)))}return e},g.updateMap=function(t,e,r,n){var i=this,a=i.map,o=e[this.id];i.rejectOnError(n);var s=[],l=m(o.style);i.styleObj.id!==l.id&&(i.styleObj=l,a.setStyle(l.style),i.traceHash={},s.push(new Promise(function(t){a.once(\"styledata\",t)}))),s=s.concat(i.fetchMapData(t,e)),Promise.all(s).then(function(){i.fillBelowLookup(t,e),i.updateData(t),i.updateLayout(e),i.resolveOnRender(r)}).catch(n)},g.fillBelowLookup=function(t,e){var r,n,i=e[this.id].layers,a=this.belowLookup={},o=!1;for(r=0;r<t.length;r++){var s=t[r][0].trace,l=s._module;\"string\"==typeof s.below?n=s.below:l.getBelow&&(n=l.getBelow(s,this)),\"\"===n&&(o=!0),a[\"trace-\"+s.uid]=n||\"\"}for(r=0;r<i.length;r++){var c=i[r];n=\"string\"==typeof c.below?c.below:o?\"traces\":\"\",a[\"layout-\"+r]=n}var u,h,f={};for(u in a)f[n=a[u]]?f[n].push(u):f[n]=[u];for(n in f){var p=f[n];if(p.length>1)for(r=0;r<p.length;r++)0===(u=p[r]).indexOf(\"trace-\")?(h=u.split(\"trace-\")[1],this.traceHash[h]&&(this.traceHash[h].below=null)):0===u.indexOf(\"layout-\")&&(h=u.split(\"layout-\")[1],this.layerList[h]&&(this.layerList[h].below=null))}};var v={choroplethmapbox:0,densitymapbox:1,scattermapbox:2};function m(t){var e={};return o.isPlainObject(t)?(e.id=t.id,e.style=t):\"string\"==typeof t?(e.id=t,-1!==f.styleValuesMapbox.indexOf(t)?e.style=y(t):f.stylesNonMapbox[t]?e.style=f.stylesNonMapbox[t]:e.style=t):(e.id=f.styleValueDflt,e.style=y(f.styleValueDflt)),e.transition={duration:0,delay:0},e}function y(t){return f.styleUrlPrefix+t+\"-\"+f.styleUrlSuffix}function x(t){return[t.lon,t.lat]}g.updateData=function(t){var e,r,n,i,a=this.traceHash,o=t.slice().sort(function(t,e){return v[t[0].trace.type]-v[e[0].trace.type]});for(n=0;n<o.length;n++){var s=o[n];(e=a[(r=s[0].trace).uid])?e.update(s):r._module&&(a[r.uid]=r._module.plot(this,s))}var l=Object.keys(a);t:for(n=0;n<l.length;n++){var c=l[n];for(i=0;i<t.length;i++)if(c===(r=t[i][0].trace).uid)continue t;(e=a[c]).dispose(),delete a[c]}},g.updateLayout=function(t){var e=this.map,r=t[this.id];e.setCenter(x(r.center)),e.setZoom(r.zoom),e.setBearing(r.bearing),e.setPitch(r.pitch),this.updateLayers(t),this.updateFramework(t),this.updateFx(t),this.map.resize(),this.gd._context._scrollZoom.mapbox?e.scrollZoom.enable():e.scrollZoom.disable()},g.resolveOnRender=function(t){var e=this.map;e.on(\"render\",function r(){e.loaded()&&(e.off(\"render\",r),setTimeout(t,0))})},g.rejectOnError=function(t){var e=this.map;function r(){t(new Error(f.mapOnErrorMsg))}e.once(\"error\",r),e.once(\"style.error\",r),e.once(\"source.error\",r),e.once(\"tile.error\",r),e.once(\"layer.error\",r)},g.createFramework=function(t){var e=this,r=e.div=document.createElement(\"div\");r.id=e.uid,r.style.position=\"absolute\",e.container.appendChild(r),e.xaxis={_id:\"x\",c2p:function(t){return e.project(t).x}},e.yaxis={_id:\"y\",c2p:function(t){return e.project(t).y}},e.updateFramework(t),e.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},l.setConvert(e.mockAxis,t)},g.initFx=function(t,e){var r=this,n=r.gd,i=r.map,o=!1;function l(){a.loneUnhover(e._hoverlayer)}function c(){var t=r.getView();n.emit(\"plotly_relayouting\",r.getViewEdits(t))}i.on(\"moveend\",function(t){if(r.map){var e=n._fullLayout;if(t.originalEvent||o){var i=e[r.id];s.call(\"_storeDirectGUIEdit\",n.layout,e._preGUI,r.getViewEdits(i));var a=r.getView();i._input.center=i.center=a.center,i._input.zoom=i.zoom=a.zoom,i._input.bearing=i.bearing=a.bearing,i._input.pitch=i.pitch=a.pitch,n.emit(\"plotly_relayout\",r.getViewEdits(a))}o=!1,e._rehover&&e._rehover()}}),i.on(\"wheel\",function(){o=!0}),i.on(\"mousemove\",function(t){var e=r.div.getBoundingClientRect();t.clientX=t.point.x+e.left,t.clientY=t.point.y+e.top,t.target.getBoundingClientRect=function(){return e},r.xaxis.p2c=function(){return t.lngLat.lng},r.yaxis.p2c=function(){return t.lngLat.lat},n._fullLayout._rehover=function(){n._fullLayout._hoversubplot===r.id&&a.hover(n,t,r.id)},a.hover(n,t,r.id),n._fullLayout._hoversubplot=r.id}),i.on(\"dragstart\",l),i.on(\"zoomstart\",l),i.on(\"mouseout\",function(){n._fullLayout._hoversubplot=null}),i.on(\"drag\",c),i.on(\"zoom\",c),i.on(\"dblclick\",function(){var t=n._fullLayout[r.id];s.call(\"_storeDirectGUIEdit\",n.layout,n._fullLayout._preGUI,r.getViewEdits(t));var e=r.viewInitial;i.setCenter(x(e.center)),i.setZoom(e.zoom),i.setBearing(e.bearing),i.setPitch(e.pitch);var a=r.getView();t._input.center=t.center=a.center,t._input.zoom=t.zoom=a.zoom,t._input.bearing=t.bearing=a.bearing,t._input.pitch=t.pitch=a.pitch,n.emit(\"plotly_doubleclick\",null),n.emit(\"plotly_relayout\",r.getViewEdits(a))}),r.clearSelect=function(){n._fullLayout._zoomlayer.selectAll(\".select-outline\").remove()},r.onClickInPanFn=function(t){return function(e){var i=n._fullLayout.clickmode;i.indexOf(\"select\")>-1&&h(e.originalEvent,n,[r.xaxis],[r.yaxis],r.id,t),i.indexOf(\"event\")>-1&&a.click(n,e.originalEvent)}}},g.updateFx=function(t){var e=this,r=e.map,n=e.gd;if(!e.isStatic){var i,a=t.dragmode;i=\"select\"===a?function(t,r){(t.range={})[e.id]=[l([r.xmin,r.ymin]),l([r.xmax,r.ymax])]}:function(t,r,n){(t.lassoPoints={})[e.id]=n.filtered.map(l)};var s=e.dragOptions;e.dragOptions=o.extendDeep(s||{},{element:e.div,gd:n,plotinfo:{id:e.id,xaxis:e.xaxis,yaxis:e.yaxis,fillRangeItems:i},xaxes:[e.xaxis],yaxes:[e.yaxis],subplot:e.id}),r.off(\"click\",e.onClickInPanHandler),\"select\"===a||\"lasso\"===a?(r.dragPan.disable(),r.on(\"zoomstart\",e.clearSelect),e.dragOptions.prepFn=function(t,r,n){u(t,r,n,e.dragOptions,a)},c.init(e.dragOptions)):(r.dragPan.enable(),r.off(\"zoomstart\",e.clearSelect),e.div.onmousedown=null,e.onClickInPanHandler=e.onClickInPanFn(e.dragOptions),r.on(\"click\",e.onClickInPanHandler))}function l(t){var r=e.map.unproject(t);return[r.lng,r.lat]}},g.updateFramework=function(t){var e=t[this.id].domain,r=t._size,n=this.div.style;n.width=r.w*(e.x[1]-e.x[0])+\"px\",n.height=r.h*(e.y[1]-e.y[0])+\"px\",n.left=r.l+e.x[0]*r.w+\"px\",n.top=r.t+(1-e.y[1])*r.h+\"px\",this.xaxis._offset=r.l+e.x[0]*r.w,this.xaxis._length=r.w*(e.x[1]-e.x[0]),this.yaxis._offset=r.t+(1-e.y[1])*r.h,this.yaxis._length=r.h*(e.y[1]-e.y[0])},g.updateLayers=function(t){var e,r=t[this.id].layers,n=this.layerList;if(r.length!==n.length){for(e=0;e<n.length;e++)n[e].dispose();for(n=this.layerList=[],e=0;e<r.length;e++)n.push(p(this,e,r[e]))}else for(e=0;e<r.length;e++)n[e].update(r[e])},g.destroy=function(){this.map&&(this.map.remove(),this.map=null,this.container.removeChild(this.div))},g.toImage=function(){return this.map.stop(),this.map.getCanvas().toDataURL()},g.setOptions=function(t,e,r){for(var n in r)this.map[e](t,n,r[n])},g.getMapLayers=function(){return this.map.getStyle().layers},g.addLayer=function(t,e){var r=this.map;if(\"string\"==typeof e){if(\"\"===e)return void r.addLayer(t,e);for(var n=this.getMapLayers(),i=0;i<n.length;i++)if(e===n[i].id)return void r.addLayer(t,e);o.warn([\"Trying to add layer with *below* value\",e,\"referencing a layer that does not exist\",\"or that does not yet exist.\"].join(\" \"))}r.addLayer(t)},g.project=function(t){return this.map.project(new n.LngLat(t[0],t[1]))},g.getView=function(){var t=this.map,e=t.getCenter();return{center:{lon:e.lng,lat:e.lat},zoom:t.getZoom(),bearing:t.getBearing(),pitch:t.getPitch()}},g.getViewEdits=function(t){for(var e=this.id,r=[\"center\",\"zoom\",\"bearing\",\"pitch\"],n={},i=0;i<r.length;i++){var a=r[i];n[e+\".\"+a]=t[a]}return n},e.exports=d},{\"../../components/dragelement\":611,\"../../components/fx\":632,\"../../lib\":719,\"../../registry\":847,\"../cartesian/axes\":767,\"../cartesian/select\":784,\"./constants\":820,\"./layers\":823,d3:163,\"mapbox-gl\":426}],827:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType;return{t:{valType:\"number\",dflt:0,editType:e},r:{valType:\"number\",dflt:0,editType:e},b:{valType:\"number\",dflt:0,editType:e},l:{valType:\"number\",dflt:0,editType:e},editType:e}}},{}],828:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../registry\"),o=t(\"../plot_api/plot_schema\"),s=t(\"../plot_api/plot_template\"),l=t(\"../lib\"),c=t(\"../components/color\"),u=t(\"../constants/numerical\").BADNUM,h=t(\"./cartesian/axis_ids\"),f=t(\"./animation_attributes\"),p=t(\"./frame_attributes\"),d=l.relinkPrivateKeys,g=l._,v=e.exports={};l.extendFlat(v,a),v.attributes=t(\"./attributes\"),v.attributes.type.values=v.allTypes,v.fontAttrs=t(\"./font_attributes\"),v.layoutAttributes=t(\"./layout_attributes\"),v.fontWeight=\"normal\";var m=v.transformsRegistry,y=t(\"./command\");v.executeAPICommand=y.executeAPICommand,v.computeAPICommandBindings=y.computeAPICommandBindings,v.manageCommandObserver=y.manageCommandObserver,v.hasSimpleAPICommandBindings=y.hasSimpleAPICommandBindings,v.redrawText=function(t){var e=(t=l.getGraphDiv(t))._fullLayout||{};if(!(!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r))return new Promise(function(e){setTimeout(function(){a.getComponentMethod(\"annotations\",\"draw\")(t),a.getComponentMethod(\"legend\",\"draw\")(t),a.getComponentMethod(\"colorbar\",\"draw\")(t),e(v.previousPromises(t))},300)})},v.resize=function(t){return t=l.getGraphDiv(t),new Promise(function(e,r){t&&!l.isHidden(t)||r(new Error(\"Resize must be passed a displayed plot div element.\")),t._redrawTimer&&clearTimeout(t._redrawTimer),t._redrawTimer=setTimeout(function(){if(!t.layout||t.layout.width&&t.layout.height||l.isHidden(t))e(t);else{delete t.layout.width,delete t.layout.height;var r=t.changed;t.autoplay=!0,a.call(\"relayout\",t,{autosize:!0}).then(function(){t.changed=r,e(t)})}},100)})},v.previousPromises=function(t){if((t._promises||[]).length)return Promise.all(t._promises).then(function(){t._promises=[]})},v.addLinks=function(t){if(t._context.showLink||t._context.showSources){var e=t._fullLayout,r=l.ensureSingle(e._paper,\"text\",\"js-plot-link-container\",function(t){t.style({\"font-family\":'\"Open Sans\", Arial, sans-serif',\"font-size\":\"12px\",fill:c.defaultLine,\"pointer-events\":\"all\"}).each(function(){var t=n.select(this);t.append(\"tspan\").classed(\"js-link-to-tool\",!0),t.append(\"tspan\").classed(\"js-link-spacer\",!0),t.append(\"tspan\").classed(\"js-sourcelinks\",!0)})}),i=r.node(),a={y:e._paper.attr(\"height\")-9};document.body.contains(i)&&i.getComputedTextLength()>=e.width-20?(a[\"text-anchor\"]=\"start\",a.x=5):(a[\"text-anchor\"]=\"end\",a.x=e._paper.attr(\"width\")-7),r.attr(a);var o=r.select(\".js-link-to-tool\"),s=r.select(\".js-link-spacer\"),u=r.select(\".js-sourcelinks\");t._context.showSources&&t._context.showSources(t),t._context.showLink&&function(t,e){e.text(\"\");var r=e.append(\"a\").attr({\"xlink:xlink:href\":\"#\",class:\"link--impt link--embedview\",\"font-weight\":\"bold\"}).text(t._context.linkText+\" \"+String.fromCharCode(187));if(t._context.sendData)r.on(\"click\",function(){v.sendDataToCloud(t)});else{var n=window.location.pathname.split(\"/\"),i=window.location.search;r.attr({\"xlink:xlink:show\":\"new\",\"xlink:xlink:href\":\"/\"+n[2].split(\".\")[0]+\"/\"+n[1]+i})}}(t,o),s.text(o.text()&&u.text()?\" - \":\"\")}},v.sendDataToCloud=function(t){t.emit(\"plotly_beforeexport\");var e=(window.PLOTLYENV||{}).BASE_URL||t._context.plotlyServerURL,r=n.select(t).append(\"div\").attr(\"id\",\"hiddenform\").style(\"display\",\"none\"),i=r.append(\"form\").attr({action:e+\"/external\",method:\"post\",target:\"_blank\"});return i.append(\"input\").attr({type:\"text\",name:\"data\"}).node().value=v.graphJson(t,!1,\"keepdata\"),i.node().submit(),r.remove(),t.emit(\"plotly_afterexport\"),!1};var x=[\"days\",\"shortDays\",\"months\",\"shortMonths\",\"periods\",\"dateTime\",\"date\",\"time\",\"decimal\",\"thousands\",\"grouping\",\"currency\"],b=[\"year\",\"month\",\"dayMonth\",\"dayMonthYear\"];function _(t,e){var r=t._context.locale,n=!1,i={};function o(t){for(var r=!0,a=0;a<e.length;a++){var o=e[a];i[o]||(t[o]?i[o]=t[o]:r=!1)}r&&(n=!0)}for(var s=0;s<2;s++){for(var l=t._context.locales,c=0;c<2;c++){var u=(l[r]||{}).format;if(u&&(o(u),n))break;l=a.localeRegistry}var h=r.split(\"-\")[0];if(n||h===r)break;r=h}return n||o(a.localeRegistry.en.format),i}function w(t,e){var r={_fullLayout:e},n=\"x\"===t._id.charAt(0),i=t._mainAxis._anchorAxis,a=\"\",o=\"\",s=\"\";if(i&&(s=i._mainAxis._id,a=n?t._id+s:s+t._id),!a||!e._plots[a]){a=\"\";for(var l=t._counterAxes,c=0;c<l.length;c++){var u=l[c],f=n?t._id+u:u+t._id;o||(o=f);var p=h.getFromId(r,u);if(s&&p.overlaying===s){a=f;break}}}return a||o}function k(t){var e=t.transforms;if(Array.isArray(e)&&e.length)for(var r=0;r<e.length;r++){var n=e[r],i=n._module||m[n.type];if(i&&i.makesData)return!0}return!1}function T(t,e,r,n){for(var i=t.transforms,a=[t],o=0;o<i.length;o++){var s=i[o],l=m[s.type];l&&l.transform&&(a=l.transform(a,{transform:s,fullTrace:t,fullData:e,layout:r,fullLayout:n,transformIndex:o}))}return a}function A(t){var e=t.margin;if(!t._size){var r=t._size={l:Math.round(e.l),r:Math.round(e.r),t:Math.round(e.t),b:Math.round(e.b),p:Math.round(e.pad)};r.w=Math.round(t.width)-r.l-r.r,r.h=Math.round(t.height)-r.t-r.b}t._pushmargin||(t._pushmargin={}),t._pushmarginIds||(t._pushmarginIds={})}v.supplyDefaults=function(t,e){var r=e&&e.skipUpdateCalc,i=t._fullLayout||{};if(i._skipDefaults)delete i._skipDefaults;else{var o,s=t._fullLayout={},c=t.layout||{},u=t._fullData||[],h=t._fullData=[],f=t.data||[],p=t.calcdata||[],m=t._context||{};t._transitionData||v.createTransitionData(t),s._dfltTitle={plot:g(t,\"Click to enter Plot title\"),x:g(t,\"Click to enter X axis title\"),y:g(t,\"Click to enter Y axis title\"),colorbar:g(t,\"Click to enter Colorscale title\"),annotation:g(t,\"new text\")},s._traceWord=g(t,\"trace\");var y=_(t,x);if(s._mapboxAccessToken=m.mapboxAccessToken,i._initialAutoSizeIsDone){var w=i.width,k=i.height;v.supplyLayoutGlobalDefaults(c,s,y),c.width||(s.width=w),c.height||(s.height=k),v.sanitizeMargins(s)}else{v.supplyLayoutGlobalDefaults(c,s,y);var T=!c.width||!c.height,M=s.autosize,S=m.autosizable;T&&(M||S)?v.plotAutoSize(t,c,s):T&&v.sanitizeMargins(s),!M&&T&&(c.width=s.width,c.height=s.height)}s._d3locale=function(t,e){return t.decimal=e.charAt(0),t.thousands=e.charAt(1),n.locale(t)}(y,s.separators),s._extraFormat=_(t,b),s._initialAutoSizeIsDone=!0,s._dataLength=f.length,s._modules=[],s._visibleModules=[],s._basePlotModules=[];var E=s._subplots=function(){var t,e,r=a.collectableSubplotTypes,n={};if(!r){r=[];var i=a.subplotsRegistry;for(var o in i){var s=i[o],c=s.attr;if(c&&(r.push(o),Array.isArray(c)))for(e=0;e<c.length;e++)l.pushUnique(r,c[e])}}for(t=0;t<r.length;t++)n[r[t]]=[];return n}(),C=s._splomAxes={x:{},y:{}},L=s._splomSubplots={};s._splomGridDflt={},s._scatterStackOpts={},s._firstScatter={},s._alignmentOpts={},s._colorAxes={},s._requestRangeslider={},s._traceUids=function(t,e){var r,n,i=e.length,a=[];for(r=0;r<t.length;r++){var o=t[r]._fullInput;o!==n&&a.push(o),n=o}var s=a.length,c=new Array(i),u={};function h(t,e){c[e]=t,u[t]=1}function f(t,e){if(t&&\"string\"==typeof t&&!u[t])return h(t,e),!0}for(r=0;r<i;r++){var p=e[r].uid;\"number\"==typeof p&&(p=String(p)),f(p,r)||(r<s&&f(a[r].uid,r)||h(l.randstr(u),r))}return c}(u,f),s._globalTransforms=(t._context||{}).globalTransforms,v.supplyDataDefaults(f,h,c,s);var P=Object.keys(C.x),O=Object.keys(C.y);if(P.length>1&&O.length>1){for(a.getComponentMethod(\"grid\",\"sizeDefaults\")(c,s),o=0;o<P.length;o++)l.pushUnique(E.xaxis,P[o]);for(o=0;o<O.length;o++)l.pushUnique(E.yaxis,O[o]);for(var z in L)l.pushUnique(E.cartesian,z)}if(s._has=v._hasPlotType.bind(s),u.length===h.length)for(o=0;o<h.length;o++)d(h[o],u[o]);v.supplyLayoutModuleDefaults(c,s,h,t._transitionData);var I=s._visibleModules,D=[];for(o=0;o<I.length;o++){var R=I[o].crossTraceDefaults;R&&l.pushUnique(D,R)}for(o=0;o<D.length;o++)D[o](h,s);s._hasOnlyLargeSploms=1===s._basePlotModules.length&&\"splom\"===s._basePlotModules[0].name&&P.length>15&&O.length>15&&0===s.shapes.length&&0===s.images.length,s._hasCartesian=s._has(\"cartesian\"),s._hasGeo=s._has(\"geo\"),s._hasGL3D=s._has(\"gl3d\"),s._hasGL2D=s._has(\"gl2d\"),s._hasTernary=s._has(\"ternary\"),s._hasPie=s._has(\"pie\"),v.linkSubplots(h,s,u,i),v.cleanPlot(h,s,u,i),i._zoomlayer&&!t._dragging&&i._zoomlayer.selectAll(\".select-outline\").remove(),function(t,e){var r,n=[];e.meta&&(r=e._meta={meta:e.meta,layout:{meta:e.meta}});for(var i=0;i<t.length;i++){var a=t[i];a.meta?n[a.index]=a._meta={meta:a.meta}:e.meta&&(a._meta={meta:e.meta}),e.meta&&(a._meta.layout={meta:e.meta})}n.length&&(r||(r=e._meta={}),r.data=n)}(h,s),d(s,i),a.getComponentMethod(\"colorscale\",\"crossTraceDefaults\")(h,s),s._preGUI||(s._preGUI={}),s._tracePreGUI||(s._tracePreGUI={});var F,B=s._tracePreGUI,N={};for(F in B)N[F]=\"old\";for(o=0;o<h.length;o++)N[F=h[o]._fullInput.uid]||(B[F]={}),N[F]=\"new\";for(F in N)\"old\"===N[F]&&delete B[F];A(s),a.getComponentMethod(\"rangeslider\",\"makeData\")(s),r||p.length!==h.length||v.supplyDefaultsUpdateCalc(p,h)}},v.supplyDefaultsUpdateCalc=function(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=(t[r]||[])[0];if(i&&i.trace){var a=i.trace;if(a._hasCalcTransform){var o,s,c,u=a._arrayAttrs;for(o=0;o<u.length;o++)s=u[o],c=l.nestedProperty(a,s).get().slice(),l.nestedProperty(n,s).set(c)}i.trace=n}}},v.createTransitionData=function(t){t._transitionData||(t._transitionData={}),t._transitionData._frames||(t._transitionData._frames=[]),t._transitionData._frameHash||(t._transitionData._frameHash={}),t._transitionData._counter||(t._transitionData._counter=0),t._transitionData._interruptCallbacks||(t._transitionData._interruptCallbacks=[])},v._hasPlotType=function(t){var e,r=this._basePlotModules||[];for(e=0;e<r.length;e++)if(r[e].name===t)return!0;var n=this._modules||[];for(e=0;e<n.length;e++){var i=n[e].name;if(i===t)return!0;var o=a.modules[i];if(o&&o.categories[t])return!0}return!1},v.cleanPlot=function(t,e,r,n){var i,a,o=n._basePlotModules||[];for(i=0;i<o.length;i++){var s=o[i];s.clean&&s.clean(t,e,r,n)}var l=n._has&&n._has(\"gl\"),c=e._has&&e._has(\"gl\");l&&!c&&void 0!==n._glcontainer&&(n._glcontainer.selectAll(\".gl-canvas\").remove(),n._glcontainer.selectAll(\".no-webgl\").remove(),n._glcanvas=null);var u=!!n._infolayer;t:for(i=0;i<r.length;i++){var h=r[i].uid;for(a=0;a<t.length;a++){if(h===t[a].uid)continue t}u&&n._infolayer.select(\".cb\"+h).remove()}},v.linkSubplots=function(t,e,r,n){var i,a,o=n._plots||{},s=e._plots={},c=e._subplots,u={_fullData:t,_fullLayout:e},f=c.cartesian.concat(c.gl2d||[]);for(i=0;i<f.length;i++){var p,d=f[i],g=o[d],v=h.getFromId(u,d,\"x\"),m=h.getFromId(u,d,\"y\");for(g?p=s[d]=g:(p=s[d]={}).id=d,v._counterAxes.push(m._id),m._counterAxes.push(v._id),v._subplotsWith.push(d),m._subplotsWith.push(d),p.xaxis=v,p.yaxis=m,p._hasClipOnAxisFalse=!1,a=0;a<t.length;a++){var y=t[a];if(y.xaxis===p.xaxis._id&&y.yaxis===p.yaxis._id&&!1===y.cliponaxis){p._hasClipOnAxisFalse=!0;break}}}var x,b=h.list(u,null,!0);for(i=0;i<b.length;i++){var _=null;(x=b[i]).overlaying&&(_=h.getFromId(u,x.overlaying))&&_.overlaying&&(x.overlaying=!1,_=null),x._mainAxis=_||x,_&&(x.domain=_.domain.slice()),x._anchorAxis=\"free\"===x.anchor?null:h.getFromId(u,x.anchor)}for(i=0;i<b.length;i++)(x=b[i])._counterAxes.sort(h.idSort),x._subplotsWith.sort(l.subplotSort),x._mainSubplot=w(x,e)},v.clearExpandedTraceDefaultColors=function(t){var e,r,n;for(r=[],(e=t._module._colorAttrs)||(t._module._colorAttrs=e=[],o.crawl(t._module.attributes,function(t,n,i,a){r[a]=n,r.length=a+1,\"color\"===t.valType&&void 0===t.dflt&&e.push(r.join(\".\"))})),n=0;n<e.length;n++){l.nestedProperty(t,\"_input.\"+e[n]).get()||l.nestedProperty(t,e[n]).set(null)}},v.supplyDataDefaults=function(t,e,r,n){var i,o,c,u=n._modules,h=n._visibleModules,f=n._basePlotModules,p=0,g=0;function m(t){e.push(t);var r=t._module;r&&(l.pushUnique(u,r),!0===t.visible&&l.pushUnique(h,r),l.pushUnique(f,t._module.basePlotModule),p++,!1!==t._input.visible&&g++)}n._transformModules=[];var y={},x=[],b=(r.template||{}).data||{},_=s.traceTemplater(b);for(i=0;i<t.length;i++){if(c=t[i],(o=_.newTrace(c)).uid=n._traceUids[i],v.supplyTraceDefaults(c,o,g,n,i),o.index=i,o._input=c,o._expandedIndex=p,o.transforms&&o.transforms.length)for(var w=!1!==c.visible&&!1===o.visible,k=T(o,e,r,n),A=0;A<k.length;A++){var M=k[A],S={_template:o._template,type:o.type,uid:o.uid+A};w&&!1===M.visible&&delete M.visible,v.supplyTraceDefaults(M,S,p,n,i),d(S,M),S.index=i,S._input=c,S._fullInput=o,S._expandedIndex=p,S._expandedInput=M,m(S)}else o._fullInput=o,o._expandedInput=o,m(o);a.traceIs(o,\"carpetAxis\")&&(y[o.carpet]=o),a.traceIs(o,\"carpetDependent\")&&x.push(i)}for(i=0;i<x.length;i++)if((o=e[x[i]]).visible){var E=y[o.carpet];o._carpet=E,E&&E.visible?(o.xaxis=E.xaxis,o.yaxis=E.yaxis):o.visible=!1}},v.supplyAnimationDefaults=function(t){var e;t=t||{};var r={};function n(e,n){return l.coerce(t||{},r,f,e,n)}if(n(\"mode\"),n(\"direction\"),n(\"fromcurrent\"),Array.isArray(t.frame))for(r.frame=[],e=0;e<t.frame.length;e++)r.frame[e]=v.supplyAnimationFrameDefaults(t.frame[e]||{});else r.frame=v.supplyAnimationFrameDefaults(t.frame||{});if(Array.isArray(t.transition))for(r.transition=[],e=0;e<t.transition.length;e++)r.transition[e]=v.supplyAnimationTransitionDefaults(t.transition[e]||{});else r.transition=v.supplyAnimationTransitionDefaults(t.transition||{});return r},v.supplyAnimationFrameDefaults=function(t){var e={};function r(r,n){return l.coerce(t||{},e,f.frame,r,n)}return r(\"duration\"),r(\"redraw\"),e},v.supplyAnimationTransitionDefaults=function(t){var e={};function r(r,n){return l.coerce(t||{},e,f.transition,r,n)}return r(\"duration\"),r(\"easing\"),e},v.supplyFrameDefaults=function(t){var e={};function r(r,n){return l.coerce(t,e,p,r,n)}return r(\"group\"),r(\"name\"),r(\"traces\"),r(\"baseframe\"),r(\"data\"),r(\"layout\"),e},v.supplyTraceDefaults=function(t,e,r,n,i){var o,s=n.colorway||c.defaults,u=s[r%s.length];function h(r,n){return l.coerce(t,e,v.attributes,r,n)}var f=h(\"visible\");h(\"type\"),h(\"name\",n._traceWord+\" \"+i),h(\"uirevision\",n.uirevision);var p=v.getModule(e);if(e._module=p,p){var d=p.basePlotModule,g=d.attr,m=d.attributes;if(g&&m){var y=n._subplots,x=\"\";if(\"gl2d\"!==d.name||f){if(Array.isArray(g))for(o=0;o<g.length;o++){var b=g[o],_=l.coerce(t,e,m,b);y[b]&&l.pushUnique(y[b],_),x+=_}else x=l.coerce(t,e,m,g);y[d.name]&&l.pushUnique(y[d.name],x)}}}return f&&(h(\"customdata\"),h(\"ids\"),h(\"meta\"),a.traceIs(e,\"showLegend\")?(e._dfltShowLegend=!0,h(\"showlegend\"),h(\"legendgroup\")):e._dfltShowLegend=!1,p&&p.supplyDefaults(t,e,u,n),a.traceIs(e,\"noOpacity\")||h(\"opacity\"),a.traceIs(e,\"notLegendIsolatable\")&&(e.visible=!!e.visible),a.traceIs(e,\"noHover\")||(e.hovertemplate||l.coerceHoverinfo(t,e,n),\"parcats\"!==e.type&&a.getComponentMethod(\"fx\",\"supplyDefaults\")(t,e,u,n)),p&&p.selectPoints&&h(\"selectedpoints\"),v.supplyTransformDefaults(t,e,n)),e},v.hasMakesDataTransform=k,v.supplyTransformDefaults=function(t,e,r){if(e._length||k(t)){var n=r._globalTransforms||[],i=r._transformModules||[];if(Array.isArray(t.transforms)||0!==n.length)for(var a=t.transforms||[],o=n.concat(a),s=e.transforms=[],c=0;c<o.length;c++){var u,h=o[c],f=h.type,p=m[f],d=!(h._module&&h._module===p),g=p&&\"function\"==typeof p.transform;p||l.warn(\"Unrecognized transform type \"+f+\".\"),p&&p.supplyDefaults&&(d||g)?((u=p.supplyDefaults(h,e,r,t)).type=f,u._module=p,l.pushUnique(i,p)):u=l.extendFlat({},h),s.push(u)}}},v.supplyLayoutGlobalDefaults=function(t,e,r){function n(r,n){return l.coerce(t,e,v.layoutAttributes,r,n)}var i=t.template;l.isPlainObject(i)&&(e.template=i,e._template=i.layout,e._dataTemplate=i.data);var o=l.coerceFont(n,\"font\");n(\"title.text\",e._dfltTitle.plot),l.coerceFont(n,\"title.font\",{family:o.family,size:Math.round(1.4*o.size),color:o.color}),n(\"title.xref\"),n(\"title.yref\"),n(\"title.x\"),n(\"title.y\"),n(\"title.xanchor\"),n(\"title.yanchor\"),n(\"title.pad.t\"),n(\"title.pad.r\"),n(\"title.pad.b\"),n(\"title.pad.l\"),n(\"autosize\",!(t.width&&t.height)),n(\"width\"),n(\"height\"),n(\"margin.l\"),n(\"margin.r\"),n(\"margin.t\"),n(\"margin.b\"),n(\"margin.pad\"),n(\"margin.autoexpand\"),t.width&&t.height&&v.sanitizeMargins(e),a.getComponentMethod(\"grid\",\"sizeDefaults\")(t,e),n(\"paper_bgcolor\"),n(\"separators\",r.decimal+r.thousands),n(\"hidesources\"),n(\"colorway\"),n(\"datarevision\");var s=n(\"uirevision\");n(\"editrevision\",s),n(\"selectionrevision\",s),n(\"modebar.orientation\"),n(\"modebar.bgcolor\",c.addOpacity(e.paper_bgcolor,.5));var u=c.contrast(c.rgb(e.modebar.bgcolor));n(\"modebar.color\",c.addOpacity(u,.3)),n(\"modebar.activecolor\",c.addOpacity(u,.7)),n(\"modebar.uirevision\",s),n(\"meta\"),l.isPlainObject(t.transition)&&(n(\"transition.duration\"),n(\"transition.easing\"),n(\"transition.ordering\")),a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\"),a.getComponentMethod(\"fx\",\"supplyLayoutGlobalDefaults\")(t,e,n)},v.plotAutoSize=function(t,e,r){var n,a,o=t._context||{},s=o.frameMargins,c=l.isPlotDiv(t);if(c&&t.emit(\"plotly_autosize\"),o.fillFrame)n=window.innerWidth,a=window.innerHeight,document.body.style.overflow=\"hidden\";else{var u=c?window.getComputedStyle(t):{};if(n=parseFloat(u.width)||parseFloat(u.maxWidth)||r.width,a=parseFloat(u.height)||parseFloat(u.maxHeight)||r.height,i(s)&&s>0){var h=1-2*s;n=Math.round(h*n),a=Math.round(h*a)}}var f=v.layoutAttributes.width.min,p=v.layoutAttributes.height.min;n<f&&(n=f),a<p&&(a=p);var d=!e.width&&Math.abs(r.width-n)>1,g=!e.height&&Math.abs(r.height-a)>1;(g||d)&&(d&&(r.width=n),g&&(r.height=a)),t._initialAutoSize||(t._initialAutoSize={width:n,height:a}),v.sanitizeMargins(r)},v.supplyLayoutModuleDefaults=function(t,e,r,n){var i,o,s,c=a.componentsRegistry,u=e._basePlotModules,h=a.subplotsRegistry.cartesian;for(i in c)(s=c[i]).includeBasePlot&&s.includeBasePlot(t,e);for(var f in u.length||u.push(h),e._has(\"cartesian\")&&(a.getComponentMethod(\"grid\",\"contentDefaults\")(t,e),h.finalizeSubplots(t,e)),e._subplots)e._subplots[f].sort(l.subplotSort);for(o=0;o<u.length;o++)(s=u[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var p=e._modules;for(o=0;o<p.length;o++)(s=p[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var d=e._transformModules;for(o=0;o<d.length;o++)(s=d[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r,n);for(i in c)(s=c[i]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r)},v.purge=function(t){var e=t._fullLayout||{};void 0!==e._glcontainer&&(e._glcontainer.selectAll(\".gl-canvas\").remove(),e._glcontainer.remove(),e._glcanvas=null),void 0!==e._geocontainer&&e._geocontainer.remove(),e._modeBar&&e._modeBar.destroy(),t._transitionData&&(t._transitionData._interruptCallbacks&&(t._transitionData._interruptCallbacks.length=0),t._transitionData._animationRaf&&window.cancelAnimationFrame(t._transitionData._animationRaf)),l.clearThrottle(),l.clearResponsive(t),delete t.data,delete t.layout,delete t._fullData,delete t._fullLayout,delete t.calcdata,delete t.framework,delete t.empty,delete t.fid,delete t.undoqueue,delete t.undonum,delete t.autoplay,delete t.changed,delete t._promises,delete t._redrawTimer,delete t._hmlumcount,delete t._hmpixcount,delete t._transitionData,delete t._transitioning,delete t._initialAutoSize,delete t._transitioningWithDuration,delete t._dragging,delete t._dragged,delete t._dragdata,delete t._hoverdata,delete t._snapshotInProgress,delete t._editing,delete t._mouseDownTime,delete t._legendMouseDownTime,t.removeAllListeners&&t.removeAllListeners()},v.style=function(t){var e,r=t._fullLayout._visibleModules,n=[];for(e=0;e<r.length;e++){var i=r[e];i.style&&l.pushUnique(n,i.style)}for(e=0;e<n.length;e++)n[e](t)},v.sanitizeMargins=function(t){if(t&&t.margin){var e,r=t.width,n=t.height,i=t.margin,a=r-(i.l+i.r),o=n-(i.t+i.b);a<0&&(e=(r-1)/(i.l+i.r),i.l=Math.floor(e*i.l),i.r=Math.floor(e*i.r)),o<0&&(e=(n-1)/(i.t+i.b),i.t=Math.floor(e*i.t),i.b=Math.floor(e*i.b))}},v.clearAutoMarginIds=function(t){t._fullLayout._pushmarginIds={}},v.allowAutoMargin=function(t,e){t._fullLayout._pushmarginIds[e]=1},v.autoMargin=function(t,e,r){var n=t._fullLayout,i=n._pushmargin,a=n._pushmarginIds;if(!1!==n.margin.autoexpand){if(r){var o=r.pad;if(void 0===o){var s=n.margin;o=Math.min(12,s.l,s.r,s.t,s.b)}r.l+r.r>.5*n.width&&(r.l=r.r=0),r.b+r.t>.5*n.height&&(r.b=r.t=0);var l=void 0!==r.xl?r.xl:r.x,c=void 0!==r.xr?r.xr:r.x,u=void 0!==r.yt?r.yt:r.y,h=void 0!==r.yb?r.yb:r.y;i[e]={l:{val:l,size:r.l+o},r:{val:c,size:r.r+o},b:{val:h,size:r.b+o},t:{val:u,size:r.t+o}},a[e]=1}else delete i[e],delete a[e];n._replotting||v.doAutoMargin(t)}},v.doAutoMargin=function(t){var e=t._fullLayout;e._size||(e._size={}),A(e);var r=e._size,n=e.margin,o=l.extendFlat({},r),s=n.l,c=n.r,u=n.t,h=n.b,f=e.width,p=e.height,d=e._pushmargin,g=e._pushmarginIds;if(!1!==e.margin.autoexpand){for(var m in d)g[m]||delete d[m];for(var y in d.base={l:{val:0,size:s},r:{val:1,size:c},t:{val:1,size:u},b:{val:0,size:h}},d){var x=d[y].l||{},b=d[y].b||{},_=x.val,w=x.size,k=b.val,T=b.size;for(var M in d){if(i(w)&&d[M].r){var S=d[M].r.val,E=d[M].r.size;if(S>_){var C=(w*S+(E-f)*_)/(S-_),L=(E*(1-_)+(w-f)*(1-S))/(S-_);C>=0&&L>=0&&f-(C+L)>0&&C+L>s+c&&(s=C,c=L)}}if(i(T)&&d[M].t){var P=d[M].t.val,O=d[M].t.size;if(P>k){var z=(T*P+(O-p)*k)/(P-k),I=(O*(1-k)+(T-p)*(1-P))/(P-k);z>=0&&I>=0&&p-(I+z)>0&&z+I>h+u&&(h=z,u=I)}}}}}if(r.l=Math.round(s),r.r=Math.round(c),r.t=Math.round(u),r.b=Math.round(h),r.p=Math.round(n.pad),r.w=Math.round(f)-r.l-r.r,r.h=Math.round(p)-r.t-r.b,!e._replotting&&v.didMarginChange(o,r))return\"_redrawFromAutoMarginCount\"in e?e._redrawFromAutoMarginCount++:e._redrawFromAutoMarginCount=1,a.call(\"plot\",t)};var M=[\"l\",\"r\",\"t\",\"b\",\"p\",\"w\",\"h\"];function S(t,e,r){var n=!1;var i=[v.previousPromises,function(){if(t._transitionData)return t._transitioning=!1,function(t){var e=Promise.resolve();if(!t)return e;for(;t.length;)e=e.then(t.shift());return e}(t._transitionData._interruptCallbacks)},r.prepareFn,v.rehover,function(){return t.emit(\"plotly_transitioning\",[]),new Promise(function(i){t._transitioning=!0,e.duration>0&&(t._transitioningWithDuration=!0),t._transitionData._interruptCallbacks.push(function(){n=!0}),r.redraw&&t._transitionData._interruptCallbacks.push(function(){return a.call(\"redraw\",t)}),t._transitionData._interruptCallbacks.push(function(){t.emit(\"plotly_transitioninterrupted\",[])});var o=0,s=0;function l(){return o++,function(){var e;s++,n||s!==o||(e=i,t._transitionData&&(function(t){if(t)for(;t.length;)t.shift()}(t._transitionData._interruptCallbacks),Promise.resolve().then(function(){if(r.redraw)return a.call(\"redraw\",t)}).then(function(){t._transitioning=!1,t._transitioningWithDuration=!1,t.emit(\"plotly_transitioned\",[])}).then(e)))}}r.runFn(l),setTimeout(l())})}],o=l.syncOrAsync(i,t);return o&&o.then||(o=Promise.resolve()),o.then(function(){return t})}v.didMarginChange=function(t,e){for(var r=0;r<M.length;r++){var n=M[r],a=t[n],o=e[n];if(!i(a)||Math.abs(o-a)>1)return!0}return!1},v.graphJson=function(t,e,r,n,i){(i&&e&&!t._fullData||i&&!e&&!t._fullLayout)&&v.supplyDefaults(t);var a=i?t._fullData:t.data,o=i?t._fullLayout:t.layout,s=(t._transitionData||{})._frames;function c(t){if(\"function\"==typeof t)return null;if(l.isPlainObject(t)){var e,n,i={};for(e in t)if(\"function\"!=typeof t[e]&&-1===[\"_\",\"[\"].indexOf(e.charAt(0))){if(\"keepdata\"===r){if(\"src\"===e.substr(e.length-3))continue}else if(\"keepstream\"===r){if(\"string\"==typeof(n=t[e+\"src\"])&&n.indexOf(\":\")>0&&!l.isPlainObject(t.stream))continue}else if(\"keepall\"!==r&&\"string\"==typeof(n=t[e+\"src\"])&&n.indexOf(\":\")>0)continue;i[e]=c(t[e])}return i}return Array.isArray(t)?t.map(c):l.isTypedArray(t)?l.simpleMap(t,l.identity):l.isJSDate(t)?l.ms2DateTimeLocal(+t):t}var u={data:(a||[]).map(function(t){var r=c(t);return e&&delete r.fit,r})};return e||(u.layout=c(o)),t.framework&&t.framework.isPolar&&(u=t.framework.getConfig()),s&&(u.frames=c(s)),\"object\"===n?u:JSON.stringify(u)},v.modifyFrames=function(t,e){var r,n,i,a=t._transitionData._frames,o=t._transitionData._frameHash;for(r=0;r<e.length;r++)switch((n=e[r]).type){case\"replace\":i=n.value;var s=(a[n.index]||{}).name,l=i.name;a[n.index]=o[l]=i,l!==s&&(delete o[s],o[l]=i);break;case\"insert\":o[(i=n.value).name]=i,a.splice(n.index,0,i);break;case\"delete\":delete o[(i=a[n.index]).name],a.splice(n.index,1)}return Promise.resolve()},v.computeFrame=function(t,e){var r,n,i,a,o=t._transitionData._frameHash;if(!e)throw new Error(\"computeFrame must be given a string frame name\");var s=o[e.toString()];if(!s)return!1;for(var l=[s],c=[s.name];s.baseframe&&(s=o[s.baseframe.toString()])&&-1===c.indexOf(s.name);)l.push(s),c.push(s.name);for(var u={};s=l.pop();)if(s.layout&&(u.layout=v.extendLayout(u.layout,s.layout)),s.data){if(u.data||(u.data=[]),!(n=s.traces))for(n=[],r=0;r<s.data.length;r++)n[r]=r;for(u.traces||(u.traces=[]),r=0;r<s.data.length;r++)null!=(i=n[r])&&(-1===(a=u.traces.indexOf(i))&&(a=u.data.length,u.traces[a]=i),u.data[a]=v.extendTrace(u.data[a],s.data[r]))}return u},v.recomputeFrameHash=function(t){for(var e=t._transitionData._frameHash={},r=t._transitionData._frames,n=0;n<r.length;n++){var i=r[n];i&&i.name&&(e[i.name]=i)}},v.extendObjectWithContainers=function(t,e,r){var n,i,a,o,s,c,u,h=l.extendDeepNoArrays({},e||{}),f=l.expandObjectPaths(h),p={};if(r&&r.length)for(a=0;a<r.length;a++)void 0===(i=(n=l.nestedProperty(f,r[a])).get())?l.nestedProperty(p,r[a]).set(null):(n.set(null),l.nestedProperty(p,r[a]).set(i));if(t=l.extendDeepNoArrays(t||{},f),r&&r.length)for(a=0;a<r.length;a++)if(c=l.nestedProperty(p,r[a]).get()){for(u=(s=l.nestedProperty(t,r[a])).get(),Array.isArray(u)||(u=[],s.set(u)),o=0;o<c.length;o++){var d=c[o];u[o]=null===d?null:v.extendObjectWithContainers(u[o],d)}s.set(u)}return t},v.dataArrayContainers=[\"transforms\",\"dimensions\"],v.layoutArrayContainers=a.layoutArrayContainers,v.extendTrace=function(t,e){return v.extendObjectWithContainers(t,e,v.dataArrayContainers)},v.extendLayout=function(t,e){return v.extendObjectWithContainers(t,e,v.layoutArrayContainers)},v.transition=function(t,e,r,n,i,a){var o={redraw:i.redraw},s={},c=[];return o.prepareFn=function(){for(var i=Array.isArray(e)?e.length:0,a=n.slice(0,i),o=0;o<a.length;o++){var u=a[o],h=t._fullData[u]._module;if(h){if(h.animatable){var f=h.basePlotModule.name;s[f]||(s[f]=[]),s[f].push(u)}t.data[a[o]]=v.extendTrace(t.data[a[o]],e[o])}}var p=l.expandObjectPaths(l.extendDeepNoArrays({},r)),d=/^[xy]axis[0-9]*$/;for(var g in p)d.test(g)&&delete p[g].range;v.extendLayout(t.layout,p),delete t.calcdata,v.supplyDefaults(t),v.doCalcdata(t);var m=l.expandObjectPaths(r);if(m){var y=t._fullLayout._plots;for(var x in y){var b,_,w,k,T=y[x],A=T.xaxis,M=T.yaxis,S=A.range.slice(),E=M.range.slice();Array.isArray(m[A._name+\".range\"])?b=m[A._name+\".range\"].slice():Array.isArray((m[A._name]||{}).range)&&(b=m[A._name].range.slice()),Array.isArray(m[M._name+\".range\"])?_=m[M._name+\".range\"].slice():Array.isArray((m[M._name]||{}).range)&&(_=m[M._name].range.slice()),S&&b&&(S[0]!==b[0]||S[1]!==b[1])&&(w={xr0:S,xr1:b}),E&&_&&(E[0]!==_[0]||E[1]!==_[1])&&(k={yr0:E,yr1:_}),(w||k)&&c.push(l.extendFlat({plotinfo:T},w,k))}}return Promise.resolve()},o.runFn=function(e){var n,i,o=t._fullLayout._basePlotModules,u=c.length;if(r)for(i=0;i<o.length;i++)o[i].transitionAxes&&o[i].transitionAxes(t,c,a,e);for(var h in u?((n=l.extendFlat({},a)).duration=0,delete s.cartesian):n=a,s){var f=s[h];t._fullData[f[0]]._module.basePlotModule.plot(t,f,n,e)}},S(t,a,o)},v.transitionFromReact=function(t,e,r,n){var i=t._fullLayout,a=i.transition,o={},s=[];return o.prepareFn=function(){var t=i._plots;for(var a in o.redraw=!1,\"some\"===e.anim&&(o.redraw=!0),\"some\"===r.anim&&(o.redraw=!0),t){var c,u,h=t[a],f=h.xaxis,p=h.yaxis,d=n[f._name].range.slice(),g=n[p._name].range.slice(),v=f.range.slice(),m=p.range.slice();f.setScale(),p.setScale(),d[0]===v[0]&&d[1]===v[1]||(c={xr0:d,xr1:v}),g[0]===m[0]&&g[1]===m[1]||(u={yr0:g,yr1:m}),(c||u)&&s.push(l.extendFlat({plotinfo:h},c,u))}return Promise.resolve()},o.runFn=function(r){for(var n,i,o,c=t._fullData,u=t._fullLayout._basePlotModules,h=[],f=0;f<c.length;f++)h.push(f);function p(){for(var e=0;e<u.length;e++)u[e].transitionAxes&&u[e].transitionAxes(t,s,n,r)}function d(){for(var e=0;e<u.length;e++)u[e].plot(t,o,i,r)}s.length&&e.anim?\"traces first\"===a.ordering?(n=l.extendFlat({},a,{duration:0}),o=h,i=a,d(),setTimeout(p,a.duration)):(n=a,o=null,i=l.extendFlat({},a,{duration:0}),p(),d()):s.length?(n=a,p()):e.anim&&(o=h,i=a,d())},S(t,a,o)},v.doCalcdata=function(t,e){var r,n,i,s,c=h.list(t),f=t._fullData,p=t._fullLayout,d=new Array(f.length),g=(t.calcdata||[]).slice();for(t.calcdata=d,p._numBoxes=0,p._numViolins=0,p._violinScaleGroupStats={},t._hmpixcount=0,t._hmlumcount=0,p._piecolormap={},p._sunburstcolormap={},p._funnelareacolormap={},i=0;i<f.length;i++)Array.isArray(e)&&-1===e.indexOf(i)&&(d[i]=g[i]);for(i=0;i<f.length;i++)(r=f[i])._arrayAttrs=o.findArrayAttributes(r),r._extremes={};var v=p._subplots.polar||[];for(i=0;i<v.length;i++)c.push(p[v[i]].radialaxis,p[v[i]].angularaxis);var y=!1;function x(e){if(r=f[e],n=r._module,!0===r.visible&&r.transforms){if(n&&n.calc){var i=n.calc(t,r);i[0]&&i[0].t&&i[0].t._scene&&delete i[0].t._scene.dirty}for(s=0;s<r.transforms.length;s++){var a=r.transforms[s];(n=m[a.type])&&n.calcTransform&&(r._hasCalcTransform=!0,y=!0,n.calcTransform(t,r,a))}}}function b(e,i){if(r=f[e],!!(n=r._module).isContainer===i){var a=[];if(!0===r.visible&&0!==r._length){delete r._indexToPoints;var o=r.transforms||[];for(s=o.length-1;s>=0;s--)if(o[s].enabled){r._indexToPoints=o[s]._indexToPoints;break}n&&n.calc&&(a=n.calc(t,r))}Array.isArray(a)&&a[0]||(a=[{x:u,y:u}]),a[0].t||(a[0].t={}),a[0].trace=r,d[e]=a}}for(C(c,f),i=0;i<f.length;i++)b(i,!0);for(i=0;i<f.length;i++)x(i);for(y&&C(c,f),i=0;i<f.length;i++)b(i,!0);for(i=0;i<f.length;i++)b(i,!1);L(t);var _=function(t,e){var r,n,i,o,s,c=[];function u(t,r,n){var i=r._id.charAt(0);if(\"histogram2dcontour\"===t){var a=r._counterAxes[0],o=h.getFromId(e,a),s=\"x\"===i||\"x\"===a&&\"category\"===o.type,l=\"y\"===i||\"y\"===a&&\"category\"===o.type;return function(t,e){return 0===t||0===e?-1:s&&t===n[e].length-1?-1:l&&e===n.length-1?-1:(\"y\"===i?e:t)-1}}return function(t,e){return\"y\"===i?e:t}}var f={min:function(t){return l.aggNums(Math.min,null,t)},max:function(t){return l.aggNums(Math.max,null,t)},sum:function(t){return l.aggNums(function(t,e){return t+e},null,t)},total:function(t){return l.aggNums(function(t,e){return t+e},null,t)},mean:function(t){return l.mean(t)},median:function(t){return l.median(t)}};for(r=0;r<t.length;r++){var p=t[r];if(\"category\"===p.type){var d=p.categoryorder.match(E);if(d){var g=d[1],v=d[2],m=[];for(n=0;n<p._categories.length;n++)m.push([p._categories[n],[]]);for(n=0;n<p._traceIndices.length;n++){var y=p._traceIndices[n],x=e._fullData[y],b=p._id.charAt(0);if(!0===x.visible){var _=x.type;a.traceIs(x,\"histogram\")&&(delete x._xautoBinFinished,delete x._yautoBinFinished);var w=e.calcdata[y];for(i=0;i<w.length;i++){var k,T,A,M=w[i];if(\"splom\"===_){var S=x._axesDim[p._id];if(\"y\"===b){var C=x._diag[S][0];C&&(p=e._fullLayout[h.id2name(C)])}var L=M.trace.dimensions[S].values;for(o=0;o<L.length;o++)for(k=L[o],T=p._categoriesMap[k],s=0;s<M.trace.dimensions.length;s++)if(s!==S){var P=M.trace.dimensions[s];m[T][1].push(P.values[o])}}else if(\"scattergl\"===_){for(o=0;o<M.t.x.length;o++)\"x\"===b&&(k=M.t.x[o],T=k,A=M.t.y[o]),\"y\"===b&&(k=M.t.y[o],T=k,A=M.t.x[o]),m[T][1].push(A);M.t&&M.t._scene&&delete M.t._scene.dirty}else if(M.hasOwnProperty(\"z\")){A=M.z;var O=u(x.type,p,A);for(o=0;o<A.length;o++)for(s=0;s<A[o].length;s++)(T=O(s,o))+1&&m[T][1].push(A[o][s])}else for(\"x\"===b?(k=M.p+1?M.p:M.x,A=M.s||M.v||M.y):\"y\"===b&&(k=M.p+1?M.p:M.y,A=M.s||M.v||M.x),Array.isArray(A)||(A=[A]),o=0;o<A.length;o++)m[k][1].push(A[o])}}}p._categoriesValue=m;var z=[];for(n=0;n<m.length;n++)z.push([m[n][0],f[g](m[n][1])]);z.sort(function(t,e){return t[1]-e[1]}),p._categoriesAggregatedValue=z,p._initialCategories=z.map(function(t){return t[0]}),\"descending\"===v&&p._initialCategories.reverse(),c=c.concat(p.sortByInitialCategories())}}}return c}(c,t);if(_.length){for(p._numBoxes=0,p._numViolins=0,i=0;i<_.length;i++)b(_[i],!0);for(i=0;i<_.length;i++)b(_[i],!1);L(t)}a.getComponentMethod(\"fx\",\"calc\")(t),a.getComponentMethod(\"errorbars\",\"calc\")(t)};var E=/(total|sum|min|max|mean|median) (ascending|descending)/;function C(t,e){for(var r=0;r<t.length;r++){var n=t[r];n.clearCalc(),\"multicategory\"===n.type&&n.setupMultiCategory(e)}}function L(t){var e,r,n,i=t._fullLayout,a=i._visibleModules,o={};for(r=0;r<a.length;r++){var s=a[r],c=s.crossTraceCalc;if(c){var u=s.basePlotModule.name;o[u]?l.pushUnique(o[u],c):o[u]=[c]}}for(n in o){var h=o[n],f=i._subplots[n];if(Array.isArray(f))for(e=0;e<f.length;e++){var p=f[e],d=\"cartesian\"===n?i._plots[p]:i[p];for(r=0;r<h.length;r++)h[r](t,d,p)}else for(r=0;r<h.length;r++)h[r](t)}}v.rehover=function(t){t._fullLayout._rehover&&t._fullLayout._rehover()},v.redrag=function(t){t._fullLayout._redrag&&t._fullLayout._redrag()},v.generalUpdatePerTraceModule=function(t,e,r,n){var i,a=e.traceHash,o={};for(i=0;i<r.length;i++){var s=r[i],c=s[0].trace;c.visible&&(o[c.type]=o[c.type]||[],o[c.type].push(s))}for(var u in a)if(!o[u]){var h=a[u][0];h[0].trace.visible=!1,o[u]=[h]}for(var f in o){var p=o[f];p[0][0].trace._module.plot(t,e,l.filterVisible(p),n)}e.traceHash=o}},{\"../components/color\":593,\"../constants/numerical\":695,\"../lib\":719,\"../plot_api/plot_schema\":756,\"../plot_api/plot_template\":757,\"../registry\":847,\"./animation_attributes\":762,\"./attributes\":764,\"./cartesian/axis_ids\":770,\"./command\":791,\"./font_attributes\":793,\"./frame_attributes\":794,\"./layout_attributes\":819,d3:163,\"fast-isnumeric\":225}],829:[function(t,e,r){\"use strict\";e.exports={attr:\"subplot\",name:\"polar\",axisNames:[\"angularaxis\",\"radialaxis\"],axisName2dataArray:{angularaxis:\"theta\",radialaxis:\"r\"},layerNames:[\"draglayer\",\"plotbg\",\"backplot\",\"angular-grid\",\"radial-grid\",\"frontplot\",\"angular-line\",\"radial-line\",\"angular-axis\",\"radial-axis\"],radialDragBoxSize:50,angularDragBoxSize:30,cornerLen:25,cornerHalfWidth:2,MINDRAG:8,MINZOOM:20,OFFEDGE:20}},{}],830:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/polygon\").tester,a=n.findIndexOfMin,o=n.isAngleInsideSector,s=n.angleDelta,l=n.angleDist;function c(t,e,r,n){var i,a,o=n[0],s=n[1],l=h(Math.sin(e)-Math.sin(t)),c=h(Math.cos(e)-Math.cos(t)),u=Math.tan(r),f=h(1/u),p=l/c,d=s-p*o;return f?l&&c?a=u*(i=d/(u-p)):c?(i=s*f,a=s):(i=o,a=o*u):l&&c?(i=0,a=d):c?(i=0,a=s):i=a=NaN,[i,a]}function u(t,e,r,i){return n.isFullCircle([e,r])?function(t,e){var r,n=e.length,i=new Array(n+1);for(r=0;r<n;r++){var a=e[r];i[r]=[t*Math.cos(a),t*Math.sin(a)]}return i[r]=i[0].slice(),i}(t,i):function(t,e,r,i){var s,u,h=i.length,f=[];function p(e){return[t*Math.cos(e),t*Math.sin(e)]}function d(t,e,r){return c(t,e,r,p(t))}function g(t){return n.mod(t,h)}function v(t){return o(t,[e,r])}var m=a(i,function(t){return v(t)?l(t,e):1/0}),y=d(i[m],i[g(m-1)],e);for(f.push(y),s=m,u=0;u<h;s++,u++){var x=i[g(s)];if(!v(x))break;f.push(p(x))}var b=a(i,function(t){return v(t)?l(t,r):1/0}),_=d(i[b],i[g(b+1)],r);return f.push(_),f.push([0,0]),f.push(f[0].slice()),f}(t,e,r,i)}function h(t){return Math.abs(t)>1e-10?t:0}function f(t,e,r){e=e||0,r=r||0;for(var n=t.length,i=new Array(n),a=0;a<n;a++){var o=t[a];i[a]=[e+o[0],r-o[1]]}return i}e.exports={isPtInsidePolygon:function(t,e,r,n,a){if(!o(e,n))return!1;var s,l;r[0]<r[1]?(s=r[0],l=r[1]):(s=r[1],l=r[0]);var c=i(u(s,n[0],n[1],a)),h=i(u(l,n[0],n[1],a)),f=[t*Math.cos(e),t*Math.sin(e)];return h.contains(f)&&!c.contains(f)},findPolygonOffset:function(t,e,r,n){for(var i=1/0,a=1/0,o=u(t,e,r,n),s=0;s<o.length;s++){var l=o[s];i=Math.min(i,l[0]),a=Math.min(a,-l[1])}return[i,a]},findEnclosingVertexAngles:function(t,e){var r=a(e,function(e){var r=s(e,t);return r>0?r:1/0}),i=n.mod(r+1,e.length);return[e[r],e[i]]},findIntersectionXY:c,findXYatLength:function(t,e,r,n){var i=-e*r,a=e*e+1,o=2*(e*i-r),s=i*i+r*r-t*t,l=Math.sqrt(o*o-4*a*s),c=(-o+l)/(2*a),u=(-o-l)/(2*a);return[[c,e*c+i+n],[u,e*u+i+n]]},clampTiny:h,pathPolygon:function(t,e,r,n,i,a){return\"M\"+f(u(t,e,r,n),i,a).join(\"L\")},pathPolygonAnnulus:function(t,e,r,n,i,a,o){var s,l;t<e?(s=t,l=e):(s=e,l=t);var c=f(u(s,r,n,i),a,o);return\"M\"+f(u(l,r,n,i),a,o).reverse().join(\"L\")+\"M\"+c.join(\"L\")}}},{\"../../lib\":719,\"../../lib/polygon\":731}],831:[function(t,e,r){\"use strict\";var n=t(\"../get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./polar\"),o=t(\"./constants\"),s=o.attr,l=o.name,c=i(l),u={};u[s]={valType:\"subplotid\",dflt:l,editType:\"calc\"},e.exports={attr:s,name:l,idRoot:l,idRegex:c,attrRegex:c,attributes:u,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[l],o=0;o<i.length;o++){var s=i[o],c=n(r,l,s),u=e[s]._subplot;u||(u=a(t,s),e[s]._subplot=u),u.plot(c,e,t._promises)}},clean:function(t,e,r,n){for(var i=n._subplots[l]||[],a=n._has&&n._has(\"gl\"),o=e._has&&e._has(\"gl\"),s=a&&!o,c=0;c<i.length;c++){var u=i[c],h=n[u]._subplot;if(!e[u]&&h)for(var f in h.framework.remove(),h.layers[\"radial-axis-title\"].remove(),h.clipPaths)h.clipPaths[f].remove();s&&h._scene&&(h._scene.destroy(),h._scene=null)}},toSVG:t(\"../cartesian\").toSVG}},{\"../../lib\":719,\"../cartesian\":778,\"../get_data\":802,\"./constants\":829,\"./layout_attributes\":832,\"./layout_defaults\":833,\"./polar\":840}],832:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../cartesian/layout_attributes\"),a=t(\"../domain\").attributes,o=t(\"../../lib\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=s({color:i.color,showline:o({},i.showline,{dflt:!0}),linecolor:i.linecolor,linewidth:i.linewidth,showgrid:o({},i.showgrid,{dflt:!0}),gridcolor:i.gridcolor,gridwidth:i.gridwidth},\"plot\",\"from-root\"),c=s({tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,showtickprefix:i.showtickprefix,tickprefix:i.tickprefix,showticksuffix:i.showticksuffix,ticksuffix:i.ticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,separatethousands:i.separatethousands,tickfont:i.tickfont,tickangle:i.tickangle,tickformat:i.tickformat,tickformatstops:i.tickformatstops,layer:i.layer},\"plot\",\"from-root\"),u={visible:o({},i.visible,{dflt:!0}),type:o({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autorange:o({},i.autorange,{editType:\"plot\"}),rangemode:{valType:\"enumerated\",values:[\"tozero\",\"nonnegative\",\"normal\"],dflt:\"tozero\",editType:\"calc\"},range:o({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],editType:\"plot\"}),categoryorder:i.categoryorder,categoryarray:i.categoryarray,angle:{valType:\"angle\",editType:\"plot\"},side:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"clockwise\",editType:\"plot\"},title:s(i.title,\"plot\",\"from-root\"),hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}};u.title.text.dflt=\"\",o(u,l,c);var h={visible:o({},i.visible,{dflt:!0}),type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"category\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},categoryorder:i.categoryorder,categoryarray:i.categoryarray,thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\"],dflt:\"degrees\",editType:\"calc\"},period:{valType:\"number\",editType:\"calc\",min:0},direction:{valType:\"enumerated\",values:[\"counterclockwise\",\"clockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"angle\",editType:\"calc\"},hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"};o(h,l,c),e.exports={domain:a({name:\"polar\",editType:\"plot\"}),sector:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],dflt:[0,360],editType:\"plot\"},hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},bgcolor:{valType:\"color\",editType:\"plot\",dflt:n.background},radialaxis:u,angularaxis:h,gridshape:{valType:\"enumerated\",values:[\"circular\",\"linear\"],dflt:\"circular\",editType:\"plot\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"}},{\"../../components/color/attributes\":592,\"../../lib\":719,\"../../plot_api/edit_types\":750,\"../cartesian/layout_attributes\":779,\"../domain\":792}],833:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../subplot_defaults\"),s=t(\"../get_data\").getSubplotData,l=t(\"../cartesian/tick_value_defaults\"),c=t(\"../cartesian/tick_mark_defaults\"),u=t(\"../cartesian/tick_label_defaults\"),h=t(\"../cartesian/category_order_defaults\"),f=t(\"../cartesian/line_grid_defaults\"),p=t(\"../cartesian/axis_autotype\"),d=t(\"./layout_attributes\"),g=t(\"./set_convert\"),v=t(\"./constants\"),m=v.axisNames;function y(t,e,r,o){var p=r(\"bgcolor\");o.bgColor=i.combine(p,o.paper_bgcolor);var y=r(\"sector\");r(\"hole\");var b,_=s(o.fullData,v.name,o.id),w=o.layoutOut;function k(t,e){return r(b+\".\"+t,e)}for(var T=0;T<m.length;T++){b=m[T],n.isPlainObject(t[b])||(t[b]={});var A=t[b],M=a.newContainer(e,b);M._id=M._name=b,M._attr=o.id+\".\"+b,M._traceIndices=_.map(function(t){return t._expandedIndex});var S=v.axisName2dataArray[b],E=x(A,M,k,_,S);h(A,M,k,{axData:_,dataAttr:S});var C,L,P=k(\"visible\");switch(g(M,e,w),k(\"uirevision\",e.uirevision),P&&(L=(C=k(\"color\"))===A.color?C:o.font.color),M._m=1,b){case\"radialaxis\":var O=k(\"autorange\",!M.isValidRange(A.range));A.autorange=O,!O||\"linear\"!==E&&\"-\"!==E||k(\"rangemode\"),\"reversed\"===O&&(M._m=-1),k(\"range\"),M.cleanRange(\"range\",{dfltRange:[0,1]}),P&&(k(\"side\"),k(\"angle\",y[0]),k(\"title.text\"),n.coerceFont(k,\"title.font\",{family:o.font.family,size:Math.round(1.2*o.font.size),color:L}));break;case\"angularaxis\":if(\"date\"===E){n.log(\"Polar plots do not support date angular axes yet.\");for(var z=0;z<_.length;z++)_[z].visible=!1;E=A.type=M.type=\"linear\"}k(\"linear\"===E?\"thetaunit\":\"period\");var I=k(\"direction\");k(\"rotation\",{counterclockwise:0,clockwise:90}[I])}if(P)l(A,M,k,M.type),u(A,M,k,M.type,{tickSuffixDflt:\"degrees\"===M.thetaunit?\"\\xb0\":void 0}),c(A,M,k,{outerTicks:!0}),k(\"showticklabels\")&&(n.coerceFont(k,\"tickfont\",{family:o.font.family,size:o.font.size,color:L}),k(\"tickangle\"),k(\"tickformat\")),f(A,M,k,{dfltColor:C,bgColor:o.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:d[b]}),k(\"layer\");\"category\"!==E&&k(\"hoverformat\"),M._input=A}\"category\"===e.angularaxis.type&&r(\"gridshape\")}function x(t,e,r,n,i){if(\"-\"===r(\"type\")){for(var a,o=0;o<n.length;o++)if(n[o].visible){a=n[o];break}a&&a[i]&&(e.type=p(a[i],\"gregorian\")),\"-\"===e.type?e.type=\"linear\":t.type=e.type}return e.type}e.exports=function(t,e,r){o(t,e,r,{type:v.name,attributes:d,handleDefaults:y,font:e.font,paper_bgcolor:e.paper_bgcolor,fullData:r,layoutOut:e})}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../cartesian/axis_autotype\":768,\"../cartesian/category_order_defaults\":771,\"../cartesian/line_grid_defaults\":781,\"../cartesian/tick_label_defaults\":786,\"../cartesian/tick_mark_defaults\":787,\"../cartesian/tick_value_defaults\":788,\"../get_data\":802,\"../subplot_defaults\":842,\"./constants\":829,\"./layout_attributes\":832,\"./set_convert\":841}],834:[function(t,e,r){\"use strict\";var n=t(\"../../../traces/scatter/attributes\"),i=n.marker,a=t(\"../../../lib/extend\").extendFlat;[\"Area traces are deprecated!\",\"Please switch to the *barpolar* trace type.\"].join(\" \");e.exports={r:a({},n.r,{}),t:a({},n.t,{}),marker:{color:a({},i.color,{}),size:a({},i.size,{}),symbol:a({},i.symbol,{}),opacity:a({},i.opacity,{}),editType:\"calc\"}}},{\"../../../lib/extend\":710,\"../../../traces/scatter/attributes\":1112}],835:[function(t,e,r){\"use strict\";var n=t(\"../../cartesian/layout_attributes\"),i=t(\"../../../lib/extend\").extendFlat,a=t(\"../../../plot_api/edit_types\").overrideAll,o=[\"Legacy polar charts are deprecated!\",\"Please switch to *polar* subplots.\"].join(\" \"),s=i({},n.domain,{});function l(t,e){return i({},e,{showline:{valType:\"boolean\"},showticklabels:{valType:\"boolean\"},tickorientation:{valType:\"enumerated\",values:[\"horizontal\",\"vertical\"]},ticklen:{valType:\"number\",min:0},tickcolor:{valType:\"color\"},ticksuffix:{valType:\"string\"},endpadding:{valType:\"number\",description:o},visible:{valType:\"boolean\"}})}e.exports=a({radialaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},domain:s,orientation:{valType:\"number\"}}),angularaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\",dflt:0},{valType:\"number\",dflt:360}]},domain:s}),layout:{direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"]},orientation:{valType:\"angle\"}}},\"plot\",\"nested\")},{\"../../../lib/extend\":710,\"../../../plot_api/edit_types\":750,\"../../cartesian/layout_attributes\":779}],836:[function(t,e,r){\"use strict\";(e.exports=t(\"./micropolar\")).manager=t(\"./micropolar_manager\")},{\"./micropolar\":837,\"./micropolar_manager\":838}],837:[function(t,e,r){var n=t(\"d3\"),i=t(\"../../../lib\").extendDeepAll,a=t(\"../../../constants/alignment\").MID_SHIFT,o=e.exports={version:\"0.2.2\"};o.Axis=function(){var t,e,r,s,l={data:[],layout:{}},c={},u={},h=n.dispatch(\"hover\"),f={};return f.render=function(c){return function(c){e=c||e;var h=l.data,f=l.layout;(\"string\"==typeof e||e.nodeName)&&(e=n.select(e)),e.datum(h).each(function(e,l){var c=e.slice();u={data:o.util.cloneJson(c),layout:o.util.cloneJson(f)};var h=0;c.forEach(function(t,e){t.color||(t.color=f.defaultColorRange[h],h=(h+1)%f.defaultColorRange.length),t.strokeColor||(t.strokeColor=\"LinePlot\"===t.geometry?t.color:n.rgb(t.color).darker().toString()),u.data[e].color=t.color,u.data[e].strokeColor=t.strokeColor,u.data[e].strokeDash=t.strokeDash,u.data[e].strokeSize=t.strokeSize});var p=c.filter(function(t,e){var r=t.visible;return\"undefined\"==typeof r||!0===r}),d=!1,g=p.map(function(t,e){return d=d||\"undefined\"!=typeof t.groupId,t});if(d){var v=n.nest().key(function(t,e){return\"undefined\"!=typeof t.groupId?t.groupId:\"unstacked\"}).entries(g),m=[],y=v.map(function(t,e){if(\"unstacked\"===t.key)return t.values;var r=t.values[0].r.map(function(t,e){return 0});return t.values.forEach(function(t,e,n){t.yStack=[r],m.push(r),r=o.util.sumArrays(t.r,r)}),t.values});p=n.merge(y)}p.forEach(function(t,e){t.t=Array.isArray(t.t[0])?t.t:[t.t],t.r=Array.isArray(t.r[0])?t.r:[t.r]});var x=Math.min(f.width-f.margin.left-f.margin.right,f.height-f.margin.top-f.margin.bottom)/2;x=Math.max(10,x);var b,_=[f.margin.left+x,f.margin.top+x];b=d?[0,n.max(o.util.sumArrays(o.util.arrayLast(p).r[0],o.util.arrayLast(m)))]:n.extent(o.util.flattenArray(p.map(function(t,e){return t.r}))),f.radialAxis.domain!=o.DATAEXTENT&&(b[0]=0),r=n.scale.linear().domain(f.radialAxis.domain!=o.DATAEXTENT&&f.radialAxis.domain?f.radialAxis.domain:b).range([0,x]),u.layout.radialAxis.domain=r.domain();var w,k=o.util.flattenArray(p.map(function(t,e){return t.t})),T=\"string\"==typeof k[0];T&&(k=o.util.deduplicate(k),w=k.slice(),k=n.range(k.length),p=p.map(function(t,e){var r=t;return t.t=[k],d&&(r.yStack=t.yStack),r}));var A=p.filter(function(t,e){return\"LinePlot\"===t.geometry||\"DotPlot\"===t.geometry}).length===p.length,M=null===f.needsEndSpacing?T||!A:f.needsEndSpacing,S=f.angularAxis.domain&&f.angularAxis.domain!=o.DATAEXTENT&&!T&&f.angularAxis.domain[0]>=0?f.angularAxis.domain:n.extent(k),E=Math.abs(k[1]-k[0]);A&&!T&&(E=0);var C=S.slice();M&&T&&(C[1]+=E);var L=f.angularAxis.ticksCount||4;L>8&&(L=L/(L/8)+L%8),f.angularAxis.ticksStep&&(L=(C[1]-C[0])/L);var P=f.angularAxis.ticksStep||(C[1]-C[0])/(L*(f.minorTicks+1));w&&(P=Math.max(Math.round(P),1)),C[2]||(C[2]=P);var O=n.range.apply(this,C);if(O=O.map(function(t,e){return parseFloat(t.toPrecision(12))}),s=n.scale.linear().domain(C.slice(0,2)).range(\"clockwise\"===f.direction?[0,360]:[360,0]),u.layout.angularAxis.domain=s.domain(),u.layout.angularAxis.endPadding=M?E:0,\"undefined\"==typeof(t=n.select(this).select(\"svg.chart-root\"))||t.empty()){var z=(new DOMParser).parseFromString(\"<svg xmlns='http://www.w3.org/2000/svg' class='chart-root'>' + '<g class='outer-group'>' + '<g class='chart-group'>' + '<circle class='background-circle'></circle>' + '<g class='geometry-group'></g>' + '<g class='radial axis-group'>' + '<circle class='outside-circle'></circle>' + '</g>' + '<g class='angular axis-group'></g>' + '<g class='guides-group'><line></line><circle r='0'></circle></g>' + '</g>' + '<g class='legend-group'></g>' + '<g class='tooltips-group'></g>' + '<g class='title-group'><text></text></g>' + '</g>' + '</svg>\",\"application/xml\"),I=this.appendChild(this.ownerDocument.importNode(z.documentElement,!0));t=n.select(I)}t.select(\".guides-group\").style({\"pointer-events\":\"none\"}),t.select(\".angular.axis-group\").style({\"pointer-events\":\"none\"}),t.select(\".radial.axis-group\").style({\"pointer-events\":\"none\"});var D,R=t.select(\".chart-group\"),F={fill:\"none\",stroke:f.tickColor},B={\"font-size\":f.font.size,\"font-family\":f.font.family,fill:f.font.color,\"text-shadow\":[\"-1px 0px\",\"1px -1px\",\"-1px 1px\",\"1px 1px\"].map(function(t,e){return\" \"+t+\" 0 \"+f.font.outlineColor}).join(\",\")};if(f.showLegend){D=t.select(\".legend-group\").attr({transform:\"translate(\"+[x,f.margin.top]+\")\"}).style({display:\"block\"});var N=p.map(function(t,e){var r=o.util.cloneJson(t);return r.symbol=\"DotPlot\"===t.geometry?t.dotType||\"circle\":\"LinePlot\"!=t.geometry?\"square\":\"line\",r.visibleInLegend=\"undefined\"==typeof t.visibleInLegend||t.visibleInLegend,r.color=\"LinePlot\"===t.geometry?t.strokeColor:t.color,r});o.Legend().config({data:p.map(function(t,e){return t.name||\"Element\"+e}),legendConfig:i({},o.Legend.defaultConfig().legendConfig,{container:D,elements:N,reverseOrder:f.legend.reverseOrder})})();var j=D.node().getBBox();x=Math.min(f.width-j.width-f.margin.left-f.margin.right,f.height-f.margin.top-f.margin.bottom)/2,x=Math.max(10,x),_=[f.margin.left+x,f.margin.top+x],r.range([0,x]),u.layout.radialAxis.domain=r.domain(),D.attr(\"transform\",\"translate(\"+[_[0]+x,_[1]-x]+\")\")}else D=t.select(\".legend-group\").style({display:\"none\"});t.attr({width:f.width,height:f.height}).style({opacity:f.opacity}),R.attr(\"transform\",\"translate(\"+_+\")\").style({cursor:\"crosshair\"});var U=[(f.width-(f.margin.left+f.margin.right+2*x+(j?j.width:0)))/2,(f.height-(f.margin.top+f.margin.bottom+2*x))/2];if(U[0]=Math.max(0,U[0]),U[1]=Math.max(0,U[1]),t.select(\".outer-group\").attr(\"transform\",\"translate(\"+U+\")\"),f.title&&f.title.text){var V=t.select(\"g.title-group text\").style(B).text(f.title.text),q=V.node().getBBox();V.attr({x:_[0]-q.width/2,y:_[1]-x-20})}var H=t.select(\".radial.axis-group\");if(f.radialAxis.gridLinesVisible){var G=H.selectAll(\"circle.grid-circle\").data(r.ticks(5));G.enter().append(\"circle\").attr({class:\"grid-circle\"}).style(F),G.attr(\"r\",r),G.exit().remove()}H.select(\"circle.outside-circle\").attr({r:x}).style(F);var Y=t.select(\"circle.background-circle\").attr({r:x}).style({fill:f.backgroundColor,stroke:f.stroke});function W(t,e){return s(t)%360+f.orientation}if(f.radialAxis.visible){var X=n.svg.axis().scale(r).ticks(5).tickSize(5);H.call(X).attr({transform:\"rotate(\"+f.radialAxis.orientation+\")\"}),H.selectAll(\".domain\").style(F),H.selectAll(\"g>text\").text(function(t,e){return this.textContent+f.radialAxis.ticksSuffix}).style(B).style({\"text-anchor\":\"start\"}).attr({x:0,y:0,dx:0,dy:0,transform:function(t,e){return\"horizontal\"===f.radialAxis.tickOrientation?\"rotate(\"+-f.radialAxis.orientation+\") translate(\"+[0,B[\"font-size\"]]+\")\":\"translate(\"+[0,B[\"font-size\"]]+\")\"}}),H.selectAll(\"g>line\").style({stroke:\"black\"})}var Z=t.select(\".angular.axis-group\").selectAll(\"g.angular-tick\").data(O),J=Z.enter().append(\"g\").classed(\"angular-tick\",!0);Z.attr({transform:function(t,e){return\"rotate(\"+W(t)+\")\"}}).style({display:f.angularAxis.visible?\"block\":\"none\"}),Z.exit().remove(),J.append(\"line\").classed(\"grid-line\",!0).classed(\"major\",function(t,e){return e%(f.minorTicks+1)==0}).classed(\"minor\",function(t,e){return!(e%(f.minorTicks+1)==0)}).style(F),J.selectAll(\".minor\").style({stroke:f.minorTickColor}),Z.select(\"line.grid-line\").attr({x1:f.tickLength?x-f.tickLength:0,x2:x}).style({display:f.angularAxis.gridLinesVisible?\"block\":\"none\"}),J.append(\"text\").classed(\"axis-text\",!0).style(B);var K=Z.select(\"text.axis-text\").attr({x:x+f.labelOffset,dy:a+\"em\",transform:function(t,e){var r=W(t),n=x+f.labelOffset,i=f.angularAxis.tickOrientation;return\"horizontal\"==i?\"rotate(\"+-r+\" \"+n+\" 0)\":\"radial\"==i?r<270&&r>90?\"rotate(180 \"+n+\" 0)\":null:\"rotate(\"+(r<=180&&r>0?-90:90)+\" \"+n+\" 0)\"}}).style({\"text-anchor\":\"middle\",display:f.angularAxis.labelsVisible?\"block\":\"none\"}).text(function(t,e){return e%(f.minorTicks+1)!=0?\"\":w?w[t]+f.angularAxis.ticksSuffix:t+f.angularAxis.ticksSuffix}).style(B);f.angularAxis.rewriteTicks&&K.text(function(t,e){return e%(f.minorTicks+1)!=0?\"\":f.angularAxis.rewriteTicks(this.textContent,e)});var $=n.max(R.selectAll(\".angular-tick text\")[0].map(function(t,e){return t.getCTM().e+t.getBBox().width}));D.attr({transform:\"translate(\"+[x+$,f.margin.top]+\")\"});var Q=t.select(\"g.geometry-group\").selectAll(\"g\").size()>0,tt=t.select(\"g.geometry-group\").selectAll(\"g.geometry\").data(p);if(tt.enter().append(\"g\").attr({class:function(t,e){return\"geometry geometry\"+e}}),tt.exit().remove(),p[0]||Q){var et=[];p.forEach(function(t,e){var n={};n.radialScale=r,n.angularScale=s,n.container=tt.filter(function(t,r){return r==e}),n.geometry=t.geometry,n.orientation=f.orientation,n.direction=f.direction,n.index=e,et.push({data:t,geometryConfig:n})});var rt=n.nest().key(function(t,e){return\"undefined\"!=typeof t.data.groupId||\"unstacked\"}).entries(et),nt=[];rt.forEach(function(t,e){\"unstacked\"===t.key?nt=nt.concat(t.values.map(function(t,e){return[t]})):nt.push(t.values)}),nt.forEach(function(t,e){var r;r=Array.isArray(t)?t[0].geometryConfig.geometry:t.geometryConfig.geometry;var n=t.map(function(t,e){return i(o[r].defaultConfig(),t)});o[r]().config(n)()})}var it,at,ot=t.select(\".guides-group\"),st=t.select(\".tooltips-group\"),lt=o.tooltipPanel().config({container:st,fontSize:8})(),ct=o.tooltipPanel().config({container:st,fontSize:8})(),ut=o.tooltipPanel().config({container:st,hasTick:!0})();if(!T){var ht=ot.select(\"line\").attr({x1:0,y1:0,y2:0}).style({stroke:\"grey\",\"pointer-events\":\"none\"});R.on(\"mousemove.angular-guide\",function(t,e){var r=o.util.getMousePos(Y).angle;ht.attr({x2:-x,transform:\"rotate(\"+r+\")\"}).style({opacity:.5});var n=(r+180+360-f.orientation)%360;it=s.invert(n);var i=o.util.convertToCartesian(x+12,r+180);lt.text(o.util.round(it)).move([i[0]+_[0],i[1]+_[1]])}).on(\"mouseout.angular-guide\",function(t,e){ot.select(\"line\").style({opacity:0})})}var ft=ot.select(\"circle\").style({stroke:\"grey\",fill:\"none\"});R.on(\"mousemove.radial-guide\",function(t,e){var n=o.util.getMousePos(Y).radius;ft.attr({r:n}).style({opacity:.5}),at=r.invert(o.util.getMousePos(Y).radius);var i=o.util.convertToCartesian(n,f.radialAxis.orientation);ct.text(o.util.round(at)).move([i[0]+_[0],i[1]+_[1]])}).on(\"mouseout.radial-guide\",function(t,e){ft.style({opacity:0}),ut.hide(),lt.hide(),ct.hide()}),t.selectAll(\".geometry-group .mark\").on(\"mouseover.tooltip\",function(e,r){var i=n.select(this),a=this.style.fill,s=\"black\",l=this.style.opacity||1;if(i.attr({\"data-opacity\":l}),a&&\"none\"!==a){i.attr({\"data-fill\":a}),s=n.hsl(a).darker().toString(),i.style({fill:s,opacity:1});var c={t:o.util.round(e[0]),r:o.util.round(e[1])};T&&(c.t=w[e[0]]);var u=\"t: \"+c.t+\", r: \"+c.r,h=this.getBoundingClientRect(),f=t.node().getBoundingClientRect(),p=[h.left+h.width/2-U[0]-f.left,h.top+h.height/2-U[1]-f.top];ut.config({color:s}).text(u),ut.move(p)}else a=this.style.stroke||\"black\",i.attr({\"data-stroke\":a}),s=n.hsl(a).darker().toString(),i.style({stroke:s,opacity:1})}).on(\"mousemove.tooltip\",function(t,e){if(0!=n.event.which)return!1;n.select(this).attr(\"data-fill\")&&ut.show()}).on(\"mouseout.tooltip\",function(t,e){ut.hide();var r=n.select(this),i=r.attr(\"data-fill\");i?r.style({fill:i,opacity:r.attr(\"data-opacity\")}):r.style({stroke:r.attr(\"data-stroke\"),opacity:r.attr(\"data-opacity\")})})})}(c),this},f.config=function(t){if(!arguments.length)return l;var e=o.util.cloneJson(t);return e.data.forEach(function(t,e){l.data[e]||(l.data[e]={}),i(l.data[e],o.Axis.defaultConfig().data[0]),i(l.data[e],t)}),i(l.layout,o.Axis.defaultConfig().layout),i(l.layout,e.layout),this},f.getLiveConfig=function(){return u},f.getinputConfig=function(){return c},f.radialScale=function(t){return r},f.angularScale=function(t){return s},f.svg=function(){return t},n.rebind(f,h,\"on\"),f},o.Axis.defaultConfig=function(t,e){return{data:[{t:[1,2,3,4],r:[10,11,12,13],name:\"Line1\",geometry:\"LinePlot\",color:null,strokeDash:\"solid\",strokeColor:null,strokeSize:\"1\",visibleInLegend:!0,opacity:1}],layout:{defaultColorRange:n.scale.category10().range(),title:null,height:450,width:500,margin:{top:40,right:40,bottom:40,left:40},font:{size:12,color:\"gray\",outlineColor:\"white\",family:\"Tahoma, sans-serif\"},direction:\"clockwise\",orientation:0,labelOffset:10,radialAxis:{domain:null,orientation:-45,ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null},angularAxis:{domain:[0,360],ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,labelsVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null,ticksCount:null,ticksStep:null},minorTicks:0,tickLength:null,tickColor:\"silver\",minorTickColor:\"#eee\",backgroundColor:\"none\",needsEndSpacing:null,showLegend:!0,legend:{reverseOrder:!1},opacity:1}}},o.util={},o.DATAEXTENT=\"dataExtent\",o.AREA=\"AreaChart\",o.LINE=\"LinePlot\",o.DOT=\"DotPlot\",o.BAR=\"BarChart\",o.util._override=function(t,e){for(var r in t)r in e&&(e[r]=t[r])},o.util._extend=function(t,e){for(var r in t)e[r]=t[r]},o.util._rndSnd=function(){return 2*Math.random()-1+(2*Math.random()-1)+(2*Math.random()-1)},o.util.dataFromEquation2=function(t,e){var r=e||6;return n.range(0,360+r,r).map(function(e,r){var n=e*Math.PI/180;return[e,t(n)]})},o.util.dataFromEquation=function(t,e,r){var i=e||6,a=[],o=[];n.range(0,360+i,i).forEach(function(e,r){var n=e*Math.PI/180,i=t(n);a.push(e),o.push(i)});var s={t:a,r:o};return r&&(s.name=r),s},o.util.ensureArray=function(t,e){if(\"undefined\"==typeof t)return null;var r=[].concat(t);return n.range(e).map(function(t,e){return r[e]||r[0]})},o.util.fillArrays=function(t,e,r){return e.forEach(function(e,n){t[e]=o.util.ensureArray(t[e],r)}),t},o.util.cloneJson=function(t){return JSON.parse(JSON.stringify(t))},o.util.validateKeys=function(t,e){\"string\"==typeof e&&(e=e.split(\".\"));var r=e.shift();return t[r]&&(!e.length||objHasKeys(t[r],e))},o.util.sumArrays=function(t,e){return n.zip(t,e).map(function(t,e){return n.sum(t)})},o.util.arrayLast=function(t){return t[t.length-1]},o.util.arrayEqual=function(t,e){for(var r=Math.max(t.length,e.length,1);r-- >=0&&t[r]===e[r];);return-2===r},o.util.flattenArray=function(t){for(var e=[];!o.util.arrayEqual(e,t);)e=t,t=[].concat.apply([],t);return t},o.util.deduplicate=function(t){return t.filter(function(t,e,r){return r.indexOf(t)==e})},o.util.convertToCartesian=function(t,e){var r=e*Math.PI/180;return[t*Math.cos(r),t*Math.sin(r)]},o.util.round=function(t,e){var r=e||2,n=Math.pow(10,r);return Math.round(t*n)/n},o.util.getMousePos=function(t){var e=n.mouse(t.node()),r=e[0],i=e[1],a={};return a.x=r,a.y=i,a.pos=e,a.angle=180*(Math.atan2(i,r)+Math.PI)/Math.PI,a.radius=Math.sqrt(r*r+i*i),a},o.util.duplicatesCount=function(t){for(var e,r={},n={},i=0,a=t.length;i<a;i++)(e=t[i])in r?(r[e]++,n[e]=r[e]):r[e]=1;return n},o.util.duplicates=function(t){return Object.keys(o.util.duplicatesCount(t))},o.util.translator=function(t,e,r,n){if(n){var i=r.slice();r=e,e=i}var a=e.reduce(function(t,e){if(\"undefined\"!=typeof t)return t[e]},t);\"undefined\"!=typeof a&&(e.reduce(function(t,r,n){if(\"undefined\"!=typeof t)return n===e.length-1&&delete t[r],t[r]},t),r.reduce(function(t,e,n){return\"undefined\"==typeof t[e]&&(t[e]={}),n===r.length-1&&(t[e]=a),t[e]},t))},o.PolyChart=function(){var t=[o.PolyChart.defaultConfig()],e=n.dispatch(\"hover\"),r={solid:\"none\",dash:[5,2],dot:[2,5]};function a(){var e=t[0].geometryConfig,i=e.container;\"string\"==typeof i&&(i=n.select(i)),i.datum(t).each(function(t,i){var a=!!t[0].data.yStack,o=t.map(function(t,e){return a?n.zip(t.data.t[0],t.data.r[0],t.data.yStack[0]):n.zip(t.data.t[0],t.data.r[0])}),s=e.angularScale,l=e.radialScale.domain()[0],c={bar:function(r,i,a){var o=t[a].data,l=e.radialScale(r[1])-e.radialScale(0),c=e.radialScale(r[2]||0),u=o.barWidth;n.select(this).attr({class:\"mark bar\",d:\"M\"+[[l+c,-u/2],[l+c,u/2],[c,u/2],[c,-u/2]].join(\"L\")+\"Z\",transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0]))+\")\"}})}};c.dot=function(r,i,a){var o=r[2]?[r[0],r[1]+r[2]]:r,s=n.svg.symbol().size(t[a].data.dotSize).type(t[a].data.dotType)(r,i);n.select(this).attr({class:\"mark dot\",d:s,transform:function(t,r){var n,i,a,s=(n=function(t,r){var n=e.radialScale(t[1]),i=(e.angularScale(t[0])+e.orientation)*Math.PI/180;return{r:n,t:i}}(o),i=n.r*Math.cos(n.t),a=n.r*Math.sin(n.t),{x:i,y:a});return\"translate(\"+[s.x,s.y]+\")\"}})};var u=n.svg.line.radial().interpolate(t[0].data.lineInterpolation).radius(function(t){return e.radialScale(t[1])}).angle(function(t){return e.angularScale(t[0])*Math.PI/180});c.line=function(r,i,a){var s=r[2]?o[a].map(function(t,e){return[t[0],t[1]+t[2]]}):o[a];if(n.select(this).each(c.dot).style({opacity:function(e,r){return+t[a].data.dotVisible},fill:d.stroke(r,i,a)}).attr({class:\"mark dot\"}),!(i>0)){var l=n.select(this.parentNode).selectAll(\"path.line\").data([0]);l.enter().insert(\"path\"),l.attr({class:\"line\",d:u(s),transform:function(t,r){return\"rotate(\"+(e.orientation+90)+\")\"},\"pointer-events\":\"none\"}).style({fill:function(t,e){return d.fill(r,i,a)},\"fill-opacity\":0,stroke:function(t,e){return d.stroke(r,i,a)},\"stroke-width\":function(t,e){return d[\"stroke-width\"](r,i,a)},\"stroke-dasharray\":function(t,e){return d[\"stroke-dasharray\"](r,i,a)},opacity:function(t,e){return d.opacity(r,i,a)},display:function(t,e){return d.display(r,i,a)}})}};var h=e.angularScale.range(),f=Math.abs(h[1]-h[0])/o[0].length*Math.PI/180,p=n.svg.arc().startAngle(function(t){return-f/2}).endAngle(function(t){return f/2}).innerRadius(function(t){return e.radialScale(l+(t[2]||0))}).outerRadius(function(t){return e.radialScale(l+(t[2]||0))+e.radialScale(t[1])});c.arc=function(t,r,i){n.select(this).attr({class:\"mark arc\",d:p,transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0])+90)+\")\"}})};var d={fill:function(e,r,n){return t[n].data.color},stroke:function(e,r,n){return t[n].data.strokeColor},\"stroke-width\":function(e,r,n){return t[n].data.strokeSize+\"px\"},\"stroke-dasharray\":function(e,n,i){return r[t[i].data.strokeDash]},opacity:function(e,r,n){return t[n].data.opacity},display:function(e,r,n){return\"undefined\"==typeof t[n].data.visible||t[n].data.visible?\"block\":\"none\"}},g=n.select(this).selectAll(\"g.layer\").data(o);g.enter().append(\"g\").attr({class:\"layer\"});var v=g.selectAll(\"path.mark\").data(function(t,e){return t});v.enter().append(\"path\").attr({class:\"mark\"}),v.style(d).each(c[e.geometryType]),v.exit().remove(),g.exit().remove()})}return a.config=function(e){return arguments.length?(e.forEach(function(e,r){t[r]||(t[r]={}),i(t[r],o.PolyChart.defaultConfig()),i(t[r],e)}),this):t},a.getColorScale=function(){},n.rebind(a,e,\"on\"),a},o.PolyChart.defaultConfig=function(){return{data:{name:\"geom1\",t:[[1,2,3,4]],r:[[1,2,3,4]],dotType:\"circle\",dotSize:64,dotVisible:!1,barWidth:20,color:\"#ffa500\",strokeSize:1,strokeColor:\"silver\",strokeDash:\"solid\",opacity:1,index:0,visible:!0,visibleInLegend:!0},geometryConfig:{geometry:\"LinePlot\",geometryType:\"arc\",direction:\"clockwise\",orientation:0,container:\"body\",radialScale:null,angularScale:null,colorScale:n.scale.category20()}}},o.BarChart=function(){return o.PolyChart()},o.BarChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"bar\"}}},o.AreaChart=function(){return o.PolyChart()},o.AreaChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"arc\"}}},o.DotPlot=function(){return o.PolyChart()},o.DotPlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"dot\",dotType:\"circle\"}}},o.LinePlot=function(){return o.PolyChart()},o.LinePlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"line\"}}},o.Legend=function(){var t=o.Legend.defaultConfig(),e=n.dispatch(\"hover\");function r(){var e=t.legendConfig,a=t.data.map(function(t,r){return[].concat(t).map(function(t,n){var a=i({},e.elements[r]);return a.name=t,a.color=[].concat(e.elements[r].color)[n],a})}),o=n.merge(a);o=o.filter(function(t,r){return e.elements[r]&&(e.elements[r].visibleInLegend||\"undefined\"==typeof e.elements[r].visibleInLegend)}),e.reverseOrder&&(o=o.reverse());var s=e.container;(\"string\"==typeof s||s.nodeName)&&(s=n.select(s));var l=o.map(function(t,e){return t.color}),c=e.fontSize,u=null==e.isContinuous?\"number\"==typeof o[0]:e.isContinuous,h=u?e.height:c*o.length,f=s.classed(\"legend-group\",!0).selectAll(\"svg\").data([0]),p=f.enter().append(\"svg\").attr({width:300,height:h+c,xmlns:\"http://www.w3.org/2000/svg\",\"xmlns:xlink\":\"http://www.w3.org/1999/xlink\",version:\"1.1\"});p.append(\"g\").classed(\"legend-axis\",!0),p.append(\"g\").classed(\"legend-marks\",!0);var d=n.range(o.length),g=n.scale[u?\"linear\":\"ordinal\"]().domain(d).range(l),v=n.scale[u?\"linear\":\"ordinal\"]().domain(d)[u?\"range\":\"rangePoints\"]([0,h]);if(u){var m=f.select(\".legend-marks\").append(\"defs\").append(\"linearGradient\").attr({id:\"grad1\",x1:\"0%\",y1:\"0%\",x2:\"0%\",y2:\"100%\"}).selectAll(\"stop\").data(l);m.enter().append(\"stop\"),m.attr({offset:function(t,e){return e/(l.length-1)*100+\"%\"}}).style({\"stop-color\":function(t,e){return t}}),f.append(\"rect\").classed(\"legend-mark\",!0).attr({height:e.height,width:e.colorBandWidth,fill:\"url(#grad1)\"})}else{var y=f.select(\".legend-marks\").selectAll(\"path.legend-mark\").data(o);y.enter().append(\"path\").classed(\"legend-mark\",!0),y.attr({transform:function(t,e){return\"translate(\"+[c/2,v(e)+c/2]+\")\"},d:function(t,e){var r,i,a,o=t.symbol;return a=3*(i=c),\"line\"===(r=o)?\"M\"+[[-i/2,-i/12],[i/2,-i/12],[i/2,i/12],[-i/2,i/12]]+\"Z\":-1!=n.svg.symbolTypes.indexOf(r)?n.svg.symbol().type(r).size(a)():n.svg.symbol().type(\"square\").size(a)()},fill:function(t,e){return g(e)}}),y.exit().remove()}var x=n.svg.axis().scale(v).orient(\"right\"),b=f.select(\"g.legend-axis\").attr({transform:\"translate(\"+[u?e.colorBandWidth:c,c/2]+\")\"}).call(x);return b.selectAll(\".domain\").style({fill:\"none\",stroke:\"none\"}),b.selectAll(\"line\").style({fill:\"none\",stroke:u?e.textColor:\"none\"}),b.selectAll(\"text\").style({fill:e.textColor,\"font-size\":e.fontSize}).text(function(t,e){return o[e].name}),r}return r.config=function(e){return arguments.length?(i(t,e),this):t},n.rebind(r,e,\"on\"),r},o.Legend.defaultConfig=function(t,e){return{data:[\"a\",\"b\",\"c\"],legendConfig:{elements:[{symbol:\"line\",color:\"red\"},{symbol:\"square\",color:\"yellow\"},{symbol:\"diamond\",color:\"limegreen\"}],height:150,colorBandWidth:30,fontSize:12,container:\"body\",isContinuous:null,textColor:\"grey\",reverseOrder:!1}}},o.tooltipPanel=function(){var t,e,r,a={container:null,hasTick:!1,fontSize:12,color:\"white\",padding:5},s=\"tooltip-\"+o.tooltipPanel.uid++,l=10,c=function(){var n=(t=a.container.selectAll(\"g.\"+s).data([0])).enter().append(\"g\").classed(s,!0).style({\"pointer-events\":\"none\",display:\"none\"});return r=n.append(\"path\").style({fill:\"white\",\"fill-opacity\":.9}).attr({d:\"M0 0\"}),e=n.append(\"text\").attr({dx:a.padding+l,dy:.3*+a.fontSize}),c};return c.text=function(i){var o=n.hsl(a.color).l,s=o>=.5?\"#aaa\":\"white\",u=o>=.5?\"black\":\"white\",h=i||\"\";e.style({fill:u,\"font-size\":a.fontSize+\"px\"}).text(h);var f=a.padding,p=e.node().getBBox(),d={fill:a.color,stroke:s,\"stroke-width\":\"2px\"},g=p.width+2*f+l,v=p.height+2*f;return r.attr({d:\"M\"+[[l,-v/2],[l,-v/4],[a.hasTick?0:l,0],[l,v/4],[l,v/2],[g,v/2],[g,-v/2]].join(\"L\")+\"Z\"}).style(d),t.attr({transform:\"translate(\"+[l,-v/2+2*f]+\")\"}),t.style({display:\"block\"}),c},c.move=function(e){if(t)return t.attr({transform:\"translate(\"+[e[0],e[1]]+\")\"}).style({display:\"block\"}),c},c.hide=function(){if(t)return t.style({display:\"none\"}),c},c.show=function(){if(t)return t.style({display:\"block\"}),c},c.config=function(t){return i(a,t),c},c},o.tooltipPanel.uid=1,o.adapter={},o.adapter.plotly=function(){var t={convert:function(t,e){var r={};if(t.data&&(r.data=t.data.map(function(t,r){var n=i({},t);return[[n,[\"marker\",\"color\"],[\"color\"]],[n,[\"marker\",\"opacity\"],[\"opacity\"]],[n,[\"marker\",\"line\",\"color\"],[\"strokeColor\"]],[n,[\"marker\",\"line\",\"dash\"],[\"strokeDash\"]],[n,[\"marker\",\"line\",\"width\"],[\"strokeSize\"]],[n,[\"marker\",\"symbol\"],[\"dotType\"]],[n,[\"marker\",\"size\"],[\"dotSize\"]],[n,[\"marker\",\"barWidth\"],[\"barWidth\"]],[n,[\"line\",\"interpolation\"],[\"lineInterpolation\"]],[n,[\"showlegend\"],[\"visibleInLegend\"]]].forEach(function(t,r){o.util.translator.apply(null,t.concat(e))}),e||delete n.marker,e&&delete n.groupId,e?(\"LinePlot\"===n.geometry?(n.type=\"scatter\",!0===n.dotVisible?(delete n.dotVisible,n.mode=\"lines+markers\"):n.mode=\"lines\"):\"DotPlot\"===n.geometry?(n.type=\"scatter\",n.mode=\"markers\"):\"AreaChart\"===n.geometry?n.type=\"area\":\"BarChart\"===n.geometry&&(n.type=\"bar\"),delete n.geometry):(\"scatter\"===n.type?\"lines\"===n.mode?n.geometry=\"LinePlot\":\"markers\"===n.mode?n.geometry=\"DotPlot\":\"lines+markers\"===n.mode&&(n.geometry=\"LinePlot\",n.dotVisible=!0):\"area\"===n.type?n.geometry=\"AreaChart\":\"bar\"===n.type&&(n.geometry=\"BarChart\"),delete n.mode,delete n.type),n}),!e&&t.layout&&\"stack\"===t.layout.barmode)){var a=o.util.duplicates(r.data.map(function(t,e){return t.geometry}));r.data.forEach(function(t,e){var n=a.indexOf(t.geometry);-1!=n&&(r.data[e].groupId=n)})}if(t.layout){var s=i({},t.layout);if([[s,[\"plot_bgcolor\"],[\"backgroundColor\"]],[s,[\"showlegend\"],[\"showLegend\"]],[s,[\"radialaxis\"],[\"radialAxis\"]],[s,[\"angularaxis\"],[\"angularAxis\"]],[s.angularaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularaxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularaxis,[\"nticks\"],[\"ticksCount\"]],[s.angularaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularaxis,[\"range\"],[\"domain\"]],[s.angularaxis,[\"endpadding\"],[\"endPadding\"]],[s.radialaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialaxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularAxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularAxis,[\"nticks\"],[\"ticksCount\"]],[s.angularAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularAxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"endpadding\"],[\"endPadding\"]],[s.radialAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialAxis,[\"range\"],[\"domain\"]],[s.font,[\"outlinecolor\"],[\"outlineColor\"]],[s.legend,[\"traceorder\"],[\"reverseOrder\"]],[s,[\"labeloffset\"],[\"labelOffset\"]],[s,[\"defaultcolorrange\"],[\"defaultColorRange\"]]].forEach(function(t,r){o.util.translator.apply(null,t.concat(e))}),e?(\"undefined\"!=typeof s.tickLength&&(s.angularaxis.ticklen=s.tickLength,delete s.tickLength),s.tickColor&&(s.angularaxis.tickcolor=s.tickColor,delete s.tickColor)):(s.angularAxis&&\"undefined\"!=typeof s.angularAxis.ticklen&&(s.tickLength=s.angularAxis.ticklen),s.angularAxis&&\"undefined\"!=typeof s.angularAxis.tickcolor&&(s.tickColor=s.angularAxis.tickcolor)),s.legend&&\"boolean\"!=typeof s.legend.reverseOrder&&(s.legend.reverseOrder=\"normal\"!=s.legend.reverseOrder),s.legend&&\"boolean\"==typeof s.legend.traceorder&&(s.legend.traceorder=s.legend.traceorder?\"reversed\":\"normal\",delete s.legend.reverseOrder),s.margin&&\"undefined\"!=typeof s.margin.t){var l=[\"t\",\"r\",\"b\",\"l\",\"pad\"],c=[\"top\",\"right\",\"bottom\",\"left\",\"pad\"],u={};n.entries(s.margin).forEach(function(t,e){u[c[l.indexOf(t.key)]]=t.value}),s.margin=u}e&&(delete s.needsEndSpacing,delete s.minorTickColor,delete s.minorTicks,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksStep,delete s.angularaxis.rewriteTicks,delete s.angularaxis.nticks,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksStep,delete s.radialaxis.rewriteTicks,delete s.radialaxis.nticks),r.layout=s}return r}};return t}},{\"../../../constants/alignment\":688,\"../../../lib\":719,d3:163}],838:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../../lib\"),a=t(\"../../../components/color\"),o=t(\"./micropolar\"),s=t(\"./undo_manager\"),l=i.extendDeepAll,c=e.exports={};c.framework=function(t){var e,r,i,a,u,h=new s;function f(r,s){return s&&(u=s),n.select(n.select(u).node().parentNode).selectAll(\".svg-container>*:not(.chart-root)\").remove(),e=e?l(e,r):r,i||(i=o.Axis()),a=o.adapter.plotly().convert(e),i.config(a).render(u),t.data=e.data,t.layout=e.layout,c.fillLayout(t),e}return f.isPolar=!0,f.svg=function(){return i.svg()},f.getConfig=function(){return e},f.getLiveConfig=function(){return o.adapter.plotly().convert(i.getLiveConfig(),!0)},f.getLiveScales=function(){return{t:i.angularScale(),r:i.radialScale()}},f.setUndoPoint=function(){var t,n,i=this,a=o.util.cloneJson(e);t=a,n=r,h.add({undo:function(){n&&i(n)},redo:function(){i(t)}}),r=o.util.cloneJson(a)},f.undo=function(){h.undo()},f.redo=function(){h.redo()},f},c.fillLayout=function(t){var e=n.select(t).selectAll(\".plot-container\"),r=e.selectAll(\".svg-container\"),i=t.framework&&t.framework.svg&&t.framework.svg(),o={width:800,height:600,paper_bgcolor:a.background,_container:e,_paperdiv:r,_paper:i};t._fullLayout=l(o,t.layout)}},{\"../../../components/color\":593,\"../../../lib\":719,\"./micropolar\":837,\"./undo_manager\":839,d3:163}],839:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=[],r=-1,n=!1;function i(t,e){return t?(n=!0,t[e](),n=!1,this):this}return{add:function(t){return n?this:(e.splice(r+1,e.length-r),e.push(t),r=e.length-1,this)},setCallback:function(e){t=e},undo:function(){var n=e[r];return n?(i(n,\"undo\"),r-=1,t&&t(n.undo),this):this},redo:function(){var n=e[r+1];return n?(i(n,\"redo\"),r+=1,t&&t(n.redo),this):this},clear:function(){e=[],r=-1},hasUndo:function(){return-1!==r},hasRedo:function(){return r<e.length-1},getCommands:function(){return e},getPreviousCommand:function(){return e[r-1]},getIndex:function(){return r}}}},{}],840:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../plots\"),u=t(\"../../plots/cartesian/axes\"),h=t(\"../cartesian/set_convert\"),f=t(\"./set_convert\"),p=t(\"../cartesian/autorange\").doAutoRange,d=t(\"../cartesian/dragbox\"),g=t(\"../../components/dragelement\"),v=t(\"../../components/fx\"),m=t(\"../../components/titles\"),y=t(\"../cartesian/select\").prepSelect,x=t(\"../cartesian/select\").selectOnClick,b=t(\"../cartesian/select\").clearSelect,_=t(\"../../lib/setcursor\"),w=t(\"../../lib/clear_gl_canvases\"),k=t(\"../../plot_api/subroutines\").redrawReglTraces,T=t(\"../../constants/alignment\").MID_SHIFT,A=t(\"./constants\"),M=t(\"./helpers\"),S=o._,E=o.mod,C=o.deg2rad,L=o.rad2deg;function P(t,e){this.id=e,this.gd=t,this._hasClipOnAxisFalse=null,this.vangles=null,this.radialAxisAngle=null,this.traceHash={},this.layers={},this.clipPaths={},this.clipIds={},this.viewInitial={};var r=t._fullLayout,n=\"clip\"+r._uid+e;this.clipIds.forTraces=n+\"-for-traces\",this.clipPaths.forTraces=r._clips.append(\"clipPath\").attr(\"id\",this.clipIds.forTraces),this.clipPaths.forTraces.append(\"path\"),this.framework=r._polarlayer.append(\"g\").attr(\"class\",e),this.radialTickLayout=null,this.angularTickLayout=null}var O=P.prototype;function z(t){var e=t.ticks+String(t.ticklen)+String(t.showticklabels);return\"side\"in t&&(e+=t.side),e}function I(t,e){return e[o.findIndexOfMin(e,function(e){return o.angleDist(t,e)})]}function D(t,e,r){return e?(t.attr(\"display\",null),t.attr(r)):t&&t.attr(\"display\",\"none\"),t}function R(t,e){return\"translate(\"+t+\",\"+e+\")\"}function F(t){return\"rotate(\"+t+\")\"}e.exports=function(t,e){return new P(t,e)},O.plot=function(t,e){var r=e[this.id];this._hasClipOnAxisFalse=!1;for(var n=0;n<t.length;n++){if(!1===t[n][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(e,r),this.updateLayout(e,r),c.generalUpdatePerTraceModule(this.gd,this,t,r),this.updateFx(e,r)},O.updateLayers=function(t,e){var r=this.layers,i=e.radialaxis,a=e.angularaxis,o=A.layerNames,s=o.indexOf(\"frontplot\"),l=o.slice(0,s),c=\"below traces\"===a.layer,u=\"below traces\"===i.layer;c&&l.push(\"angular-line\"),u&&l.push(\"radial-line\"),c&&l.push(\"angular-axis\"),u&&l.push(\"radial-axis\"),l.push(\"frontplot\"),c||l.push(\"angular-line\"),u||l.push(\"radial-line\"),c||l.push(\"angular-axis\"),u||l.push(\"radial-axis\");var h=this.framework.selectAll(\".polarsublayer\").data(l,String);h.enter().append(\"g\").attr(\"class\",function(t){return\"polarsublayer \"+t}).each(function(t){var e=r[t]=n.select(this);switch(t){case\"frontplot\":e.append(\"g\").classed(\"barlayer\",!0),e.append(\"g\").classed(\"scatterlayer\",!0);break;case\"backplot\":e.append(\"g\").classed(\"maplayer\",!0);break;case\"plotbg\":r.bg=e.append(\"path\");break;case\"radial-grid\":case\"angular-grid\":e.style(\"fill\",\"none\");break;case\"radial-line\":e.append(\"line\").style(\"fill\",\"none\");break;case\"angular-line\":e.append(\"path\").style(\"fill\",\"none\")}}),h.order()},O.updateLayout=function(t,e){var r=this.layers,n=t._size,i=e.radialaxis,a=e.angularaxis,o=e.domain.x,c=e.domain.y;this.xOffset=n.l+n.w*o[0],this.yOffset=n.t+n.h*(1-c[1]);var u=this.xLength=n.w*(o[1]-o[0]),h=this.yLength=n.h*(c[1]-c[0]),f=e.sector;this.sectorInRad=f.map(C);var p,d,g,v,m,y=this.sectorBBox=function(t){var e,r,n,i,a=t[0],o=t[1]-a,s=E(a,360),l=s+o,c=Math.cos(C(s)),u=Math.sin(C(s)),h=Math.cos(C(l)),f=Math.sin(C(l));i=s<=90&&l>=90||s>90&&l>=450?1:u<=0&&f<=0?0:Math.max(u,f);e=s<=180&&l>=180||s>180&&l>=540?-1:c>=0&&h>=0?0:Math.min(c,h);r=s<=270&&l>=270||s>270&&l>=630?-1:u>=0&&f>=0?0:Math.min(u,f);n=l>=360?1:c<=0&&h<=0?0:Math.max(c,h);return[e,r,n,i]}(f),x=y[2]-y[0],b=y[3]-y[1],_=h/u,w=Math.abs(b/x);_>w?(p=u,m=(h-(d=u*w))/n.h/2,g=[o[0],o[1]],v=[c[0]+m,c[1]-m]):(d=h,m=(u-(p=h/w))/n.w/2,g=[o[0]+m,o[1]-m],v=[c[0],c[1]]),this.xLength2=p,this.yLength2=d,this.xDomain2=g,this.yDomain2=v;var k=this.xOffset2=n.l+n.w*g[0],T=this.yOffset2=n.t+n.h*(1-v[1]),A=this.radius=p/x,M=this.innerRadius=e.hole*A,S=this.cx=k-A*y[0],L=this.cy=T+A*y[3],P=this.cxx=S-k,O=this.cyy=L-T;this.radialAxis=this.mockAxis(t,e,i,{_id:\"x\",side:{counterclockwise:\"top\",clockwise:\"bottom\"}[i.side],domain:[M/n.w,A/n.w]}),this.angularAxis=this.mockAxis(t,e,a,{side:\"right\",domain:[0,Math.PI],autorange:!1}),this.doAutoRange(t,e),this.updateAngularAxis(t,e),this.updateRadialAxis(t,e),this.updateRadialAxisTitle(t,e),this.xaxis=this.mockCartesianAxis(t,e,{_id:\"x\",domain:g}),this.yaxis=this.mockCartesianAxis(t,e,{_id:\"y\",domain:v});var z=this.pathSubplot();this.clipPaths.forTraces.select(\"path\").attr(\"d\",z).attr(\"transform\",R(P,O)),r.frontplot.attr(\"transform\",R(k,T)).call(l.setClipUrl,this._hasClipOnAxisFalse?null:this.clipIds.forTraces,this.gd),r.bg.attr(\"d\",z).attr(\"transform\",R(S,L)).call(s.fill,e.bgcolor)},O.mockAxis=function(t,e,r,n){var i=o.extendFlat({anchor:\"free\",position:0},r,n);return f(i,e,t),i},O.mockCartesianAxis=function(t,e,r){var n=this,i=r._id,a=o.extendFlat({type:\"linear\"},r);h(a,t);var s={x:[0,2],y:[1,3]};return a.setRange=function(){var t=n.sectorBBox,r=s[i],o=n.radialAxis._rl,l=(o[1]-o[0])/(1-e.hole);a.range=[t[r[0]]*l,t[r[1]]*l]},a.isPtWithinRange=\"x\"===i?function(t){return n.isPtInside(t)}:function(){return!0},a.setRange(),a.setScale(),a},O.doAutoRange=function(t,e){var r=this.gd,n=this.radialAxis,i=e.radialaxis;n.setScale(),p(r,n);var a=n.range;i.range=a.slice(),i._input.range=a.slice(),n._rl=[n.r2l(a[0],null,\"gregorian\"),n.r2l(a[1],null,\"gregorian\")]},O.updateRadialAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,l=r.innerRadius,c=r.cx,h=r.cy,f=e.radialaxis,p=E(e.sector[0],360),d=r.radialAxis,g=l<a;r.fillViewInitialKey(\"radialaxis.angle\",f.angle),r.fillViewInitialKey(\"radialaxis.range\",d.range.slice()),d.setGeometry(),\"auto\"===d.tickangle&&p>90&&p<=270&&(d.tickangle=180);var v=function(t){return\"translate(\"+(d.l2p(t.x)+l)+\",0)\"},m=z(f);if(r.radialTickLayout!==m&&(i[\"radial-axis\"].selectAll(\".xtick\").remove(),r.radialTickLayout=m),g){d.setScale();var y=u.calcTicks(d),x=u.clipEnds(d,y),b=u.getTickSigns(d)[2];u.drawTicks(n,d,{vals:y,layer:i[\"radial-axis\"],path:u.makeTickPath(d,0,b),transFn:v,crisp:!1}),u.drawGrid(n,d,{vals:x,layer:i[\"radial-grid\"],path:function(t){return r.pathArc(d.r2p(t.x)+l)},transFn:o.noop,crisp:!1}),u.drawLabels(n,d,{vals:y,layer:i[\"radial-axis\"],transFn:v,labelFns:u.makeLabelFns(d,0)})}var _=r.radialAxisAngle=r.vangles?L(I(C(f.angle),r.vangles)):f.angle,w=R(c,h),k=w+F(-_);D(i[\"radial-axis\"],g&&(f.showticklabels||f.ticks),{transform:k}),D(i[\"radial-grid\"],g&&f.showgrid,{transform:w}),D(i[\"radial-line\"].select(\"line\"),g&&f.showline,{x1:l,y1:0,x2:a,y2:0,transform:k}).attr(\"stroke-width\",f.linewidth).call(s.stroke,f.linecolor)},O.updateRadialAxisTitle=function(t,e,r){var n=this.gd,i=this.radius,a=this.cx,o=this.cy,s=e.radialaxis,c=this.id+\"title\",u=void 0!==r?r:this.radialAxisAngle,h=C(u),f=Math.cos(h),p=Math.sin(h),d=0;if(s.title){var g=l.bBox(this.layers[\"radial-axis\"].node()).height,v=s.title.font.size;d=\"counterclockwise\"===s.side?-g-.4*v:g+.8*v}this.layers[\"radial-axis-title\"]=m.draw(n,c,{propContainer:s,propName:this.id+\".radialaxis.title\",placeholder:S(n,\"Click to enter radial axis title\"),attributes:{x:a+i/2*f+d*p,y:o-i/2*p+d*f,\"text-anchor\":\"middle\"},transform:{rotate:-u}})},O.updateAngularAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,l=r.innerRadius,c=r.cx,h=r.cy,f=e.angularaxis,p=r.angularAxis;r.fillViewInitialKey(\"angularaxis.rotation\",f.rotation),p.setGeometry(),p.setScale();var d=function(t){return p.t2g(t.x)};\"linear\"===p.type&&\"radians\"===p.thetaunit&&(p.tick0=L(p.tick0),p.dtick=L(p.dtick));var g=function(t){return R(c+a*Math.cos(t),h-a*Math.sin(t))},v=u.makeLabelFns(p,0).labelStandoff,m={xFn:function(t){var e=d(t);return Math.cos(e)*v},yFn:function(t){var e=d(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(v+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*T)},anchorFn:function(t){var e=d(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},heightFn:function(t,e,r){var n=d(t);return-.5*(1+Math.sin(n))*r}},y=z(f);r.angularTickLayout!==y&&(i[\"angular-axis\"].selectAll(\".\"+p._id+\"tick\").remove(),r.angularTickLayout=y);var x,b=u.calcTicks(p);if(\"linear\"===e.gridshape?(x=b.map(d),o.angleDelta(x[0],x[1])<0&&(x=x.slice().reverse())):x=null,r.vangles=x,\"category\"===p.type&&(b=b.filter(function(t){return o.isAngleInsideSector(d(t),r.sectorInRad)})),p.visible){var _=\"inside\"===p.ticks?-1:1,w=(p.linewidth||1)/2;u.drawTicks(n,p,{vals:b,layer:i[\"angular-axis\"],path:\"M\"+_*w+\",0h\"+_*p.ticklen,transFn:function(t){var e=d(t);return g(e)+F(-L(e))},crisp:!1}),u.drawGrid(n,p,{vals:b,layer:i[\"angular-grid\"],path:function(t){var e=d(t),r=Math.cos(e),n=Math.sin(e);return\"M\"+[c+l*r,h-l*n]+\"L\"+[c+a*r,h-a*n]},transFn:o.noop,crisp:!1}),u.drawLabels(n,p,{vals:b,layer:i[\"angular-axis\"],repositionOnUpdate:!0,transFn:function(t){return g(d(t))},labelFns:m})}D(i[\"angular-line\"].select(\"path\"),f.showline,{d:r.pathSubplot(),transform:R(c,h)}).attr(\"stroke-width\",f.linewidth).call(s.stroke,f.linecolor)},O.updateFx=function(t,e){this.gd._context.staticPlot||(this.updateAngularDrag(t),this.updateRadialDrag(t,e,0),this.updateRadialDrag(t,e,1),this.updateMainDrag(t))},O.updateMainDrag=function(t){var e=this,r=e.gd,o=e.layers,s=t._zoomlayer,l=A.MINZOOM,c=A.OFFEDGE,u=e.radius,h=e.innerRadius,f=e.cx,p=e.cy,m=e.cxx,_=e.cyy,w=e.sectorInRad,k=e.vangles,T=e.radialAxis,S=M.clampTiny,E=M.findXYatLength,C=M.findEnclosingVertexAngles,L=A.cornerHalfWidth,P=A.cornerLen/2,O=d.makeDragger(o,\"path\",\"maindrag\",\"crosshair\");n.select(O).attr(\"d\",e.pathSubplot()).attr(\"transform\",R(f,p));var z,I,D,F,B,N,j,U,V,q={element:O,gd:r,subplot:e.id,plotinfo:{id:e.id,xaxis:e.xaxis,yaxis:e.yaxis},xaxes:[e.xaxis],yaxes:[e.yaxis]};function H(t,e){return Math.sqrt(t*t+e*e)}function G(t,e){return H(t-m,e-_)}function Y(t,e){return Math.atan2(_-e,t-m)}function W(t,e){return[t*Math.cos(e),t*Math.sin(-e)]}function X(t,r){if(0===t)return e.pathSector(2*L);var n=P/t,i=r-n,a=r+n,o=Math.max(0,Math.min(t,u)),s=o-L,l=o+L;return\"M\"+W(s,i)+\"A\"+[s,s]+\" 0,0,0 \"+W(s,a)+\"L\"+W(l,a)+\"A\"+[l,l]+\" 0,0,1 \"+W(l,i)+\"Z\"}function Z(t,r,n){if(0===t)return e.pathSector(2*L);var i,a,o=W(t,r),s=W(t,n),l=S((o[0]+s[0])/2),c=S((o[1]+s[1])/2);if(l&&c){var u=c/l,h=-1/u,f=E(L,u,l,c);i=E(P,h,f[0][0],f[0][1]),a=E(P,h,f[1][0],f[1][1])}else{var p,d;c?(p=P,d=L):(p=L,d=P),i=[[l-p,c-d],[l+p,c-d]],a=[[l-p,c+d],[l+p,c+d]]}return\"M\"+i.join(\"L\")+\"L\"+a.reverse().join(\"L\")+\"Z\"}function J(t,e){return e=Math.max(Math.min(e,u),h),t<c?t=0:u-t<c?t=u:e<c?e=0:u-e<c&&(e=u),Math.abs(e-t)>l?(t<e?(D=t,F=e):(D=e,F=t),!0):(D=null,F=null,!1)}function K(t,e){t=t||B,e=e||\"M0,0Z\",U.attr(\"d\",t),V.attr(\"d\",e),d.transitionZoombox(U,V,N,j),N=!0;var n={};rt(n),r.emit(\"plotly_relayouting\",n)}function $(t,r){var n,i,a=z+t,o=I+r,s=G(z,I),l=Math.min(G(a,o),u),c=Y(z,I);J(s,l)&&(n=B+e.pathSector(F),D&&(n+=e.pathSector(D)),i=X(D,c)+X(F,c)),K(n,i)}function Q(t,e,r,n){var i=M.findIntersectionXY(r,n,r,[t-m,_-e]);return H(i[0],i[1])}function tt(t,r){var n,i,a=z+t,o=I+r,s=Y(z,I),l=Y(a,o),c=C(s,k),h=C(l,k);J(Q(z,I,c[0],c[1]),Math.min(Q(a,o,h[0],h[1]),u))&&(n=B+e.pathSector(F),D&&(n+=e.pathSector(D)),i=[Z(D,c[0],c[1]),Z(F,c[0],c[1])].join(\" \")),K(n,i)}function et(){if(d.removeZoombox(r),null!==D&&null!==F){var t={};rt(t),d.showDoubleClickNotifier(r),a.call(\"_guiRelayout\",r,t)}}function rt(t){var r=T._rl,n=(r[1]-r[0])/(1-h/u)/u,i=[r[0]+(D-h)*n,r[0]+(F-h)*n];t[e.id+\".radialaxis.range\"]=i}function nt(t,n){var i=r._fullLayout.clickmode;if(d.removeZoombox(r),2===t){var o={};for(var s in e.viewInitial)o[e.id+\".\"+s]=e.viewInitial[s];r.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",r,o)}i.indexOf(\"select\")>-1&&1===t&&x(n,r,[e.xaxis],[e.yaxis],e.id,q),i.indexOf(\"event\")>-1&&v.click(r,n,e.id)}q.prepFn=function(t,n,a){var o=r._fullLayout.dragmode,l=O.getBoundingClientRect();if(z=n-l.left,I=a-l.top,k){var c=M.findPolygonOffset(u,w[0],w[1],k);z+=m+c[0],I+=_+c[1]}switch(o){case\"zoom\":q.moveFn=k?tt:$,q.clickFn=nt,q.doneFn=et,function(){D=null,F=null,B=e.pathSubplot(),N=!1;var t=r._fullLayout[e.id];j=i(t.bgcolor).getLuminance(),(U=d.makeZoombox(s,j,f,p,B)).attr(\"fill-rule\",\"evenodd\"),V=d.makeCorners(s,f,p),b(r)}();break;case\"select\":case\"lasso\":y(t,n,a,q,o)}},O.onmousemove=function(t){v.hover(r,t,e.id),r._fullLayout._lasthover=O,r._fullLayout._hoversubplot=e.id},O.onmouseout=function(t){r._dragging||g.unhover(r,t)},g.init(q)},O.updateRadialDrag=function(t,e,r){var i=this,s=i.gd,l=i.layers,c=i.radius,u=i.innerRadius,h=i.cx,f=i.cy,p=i.radialAxis,v=A.radialDragBoxSize,m=v/2;if(p.visible){var y,x,_,T=C(i.radialAxisAngle),M=p._rl,S=M[0],E=M[1],P=M[r],O=.75*(M[1]-M[0])/(1-e.hole)/c;r?(y=h+(c+m)*Math.cos(T),x=f-(c+m)*Math.sin(T),_=\"radialdrag\"):(y=h+(u-m)*Math.cos(T),x=f-(u-m)*Math.sin(T),_=\"radialdrag-inner\");var z,B,N,j=d.makeRectDragger(l,_,\"crosshair\",-m,-m,v,v),U={element:j,gd:s};D(n.select(j),p.visible&&u<c,{transform:R(y,x)}),U.prepFn=function(){z=null,B=null,N=null,U.moveFn=V,U.doneFn=q,b(s)},U.clampFn=function(t,e){return Math.sqrt(t*t+e*e)<A.MINDRAG&&(t=0,e=0),[t,e]},g.init(U)}function V(t,e){if(z)z(t,e);else{var n=[t,-e],a=[Math.cos(T),Math.sin(T)],l=Math.abs(o.dot(n,a)/Math.sqrt(o.dot(n,n)));isNaN(l)||(z=l<.5?H:G)}var c={};!function(t){null!==B?t[i.id+\".radialaxis.angle\"]=B:null!==N&&(t[i.id+\".radialaxis.range[\"+r+\"]\"]=N)}(c),s.emit(\"plotly_relayouting\",c)}function q(){null!==B?a.call(\"_guiRelayout\",s,i.id+\".radialaxis.angle\",B):null!==N&&a.call(\"_guiRelayout\",s,i.id+\".radialaxis.range[\"+r+\"]\",N)}function H(t,e){if(0!==r){var n=y+t,a=x+e;B=Math.atan2(f-a,n-h),i.vangles&&(B=I(B,i.vangles)),B=L(B);var o=R(h,f)+F(-B);l[\"radial-axis\"].attr(\"transform\",o),l[\"radial-line\"].select(\"line\").attr(\"transform\",o);var s=i.gd._fullLayout,c=s[i.id];i.updateRadialAxisTitle(s,c,B)}}function G(t,e){var n=o.dot([t,-e],[Math.cos(T),Math.sin(T)]);if(N=P-O*n,O>0==(r?N>S:N<E)){var l=s._fullLayout,c=l[i.id];p.range[r]=N,p._rl[r]=N,i.updateRadialAxis(l,c),i.xaxis.setRange(),i.xaxis.setScale(),i.yaxis.setRange(),i.yaxis.setScale();var u=!1;for(var h in i.traceHash){var f=i.traceHash[h],d=o.filterVisible(f);f[0][0].trace._module.plot(s,i,d,c),a.traceIs(h,\"gl\")&&d.length&&(u=!0)}u&&(w(s),k(s))}else N=null}},O.updateAngularDrag=function(t){var e=this,r=e.gd,i=e.layers,s=e.radius,c=e.angularAxis,u=e.cx,h=e.cy,f=e.cxx,p=e.cyy,v=A.angularDragBoxSize,m=d.makeDragger(i,\"path\",\"angulardrag\",\"move\"),y={element:m,gd:r};function x(t,e){return Math.atan2(p+v-e,t-f-v)}n.select(m).attr(\"d\",e.pathAnnulus(s,s+v)).attr(\"transform\",R(u,h)).call(_,\"move\");var T,M,S,E,C,P,O=i.frontplot.select(\".scatterlayer\").selectAll(\".trace\"),z=O.selectAll(\".point\"),I=O.selectAll(\".textpoint\");function D(t,s){var d=e.gd._fullLayout,g=d[e.id],v=x(T+t,M+s),m=L(v-P);if(E=S+m,i.frontplot.attr(\"transform\",R(e.xOffset2,e.yOffset2)+F([-m,f,p])),e.vangles){C=e.radialAxisAngle+m;var y=R(u,h)+F(-m),b=R(u,h)+F(-C);i.bg.attr(\"transform\",y),i[\"radial-grid\"].attr(\"transform\",y),i[\"radial-axis\"].attr(\"transform\",b),i[\"radial-line\"].select(\"line\").attr(\"transform\",b),e.updateRadialAxisTitle(d,g,C)}else e.clipPaths.forTraces.select(\"path\").attr(\"transform\",R(f,p)+F(m));z.each(function(){var t=n.select(this),e=l.getTranslate(t);t.attr(\"transform\",R(e.x,e.y)+F([m]))}),I.each(function(){var t=n.select(this),e=t.select(\"text\"),r=l.getTranslate(t);t.attr(\"transform\",F([m,e.attr(\"x\"),e.attr(\"y\")])+R(r.x,r.y))}),c.rotation=o.modHalf(E,360),e.updateAngularAxis(d,g),e._hasClipOnAxisFalse&&!o.isFullCircle(e.sectorInRad)&&O.call(l.hideOutsideRangePoints,e);var _=!1;for(var A in e.traceHash)if(a.traceIs(A,\"gl\")){var D=e.traceHash[A],N=o.filterVisible(D);D[0][0].trace._module.plot(r,e,N,g),N.length&&(_=!0)}_&&(w(r),k(r));var j={};B(j),r.emit(\"plotly_relayouting\",j)}function B(t){t[e.id+\".angularaxis.rotation\"]=E,e.vangles&&(t[e.id+\".radialaxis.angle\"]=C)}function N(){I.select(\"text\").attr(\"transform\",null);var t={};B(t),a.call(\"_guiRelayout\",r,t)}y.prepFn=function(n,i,a){var o=t[e.id];S=o.angularaxis.rotation;var s=m.getBoundingClientRect();T=i-s.left,M=a-s.top,P=x(T,M),y.moveFn=D,y.doneFn=N,b(r)},e.vangles&&!o.isFullCircle(e.sectorInRad)&&(y.prepFn=o.noop,_(n.select(m),null)),g.init(y)},O.isPtInside=function(t){var e=this.sectorInRad,r=this.vangles,n=this.angularAxis.c2g(t.theta),i=this.radialAxis,a=i.c2l(t.r),s=i._rl;return(r?M.isPtInsidePolygon:o.isPtInsideSector)(a,n,s,e,r)},O.pathArc=function(t){var e=this.sectorInRad,r=this.vangles;return(r?M.pathPolygon:o.pathArc)(t,e[0],e[1],r)},O.pathSector=function(t){var e=this.sectorInRad,r=this.vangles;return(r?M.pathPolygon:o.pathSector)(t,e[0],e[1],r)},O.pathAnnulus=function(t,e){var r=this.sectorInRad,n=this.vangles;return(n?M.pathPolygonAnnulus:o.pathAnnulus)(t,e,r[0],r[1],n)},O.pathSubplot=function(){var t=this.innerRadius,e=this.radius;return t?this.pathAnnulus(t,e):this.pathSector(e)},O.fillViewInitialKey=function(t,e){t in this.viewInitial||(this.viewInitial[t]=e)}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../components/titles\":681,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/clear_gl_canvases\":704,\"../../lib/setcursor\":739,\"../../plot_api/subroutines\":758,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../cartesian/autorange\":766,\"../cartesian/dragbox\":775,\"../cartesian/select\":784,\"../cartesian/set_convert\":785,\"../plots\":828,\"./constants\":829,\"./helpers\":830,\"./set_convert\":841,d3:163,tinycolor2:537}],841:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../cartesian/set_convert\"),a=n.deg2rad,o=n.rad2deg;e.exports=function(t,e,r){switch(i(t,r),t._id){case\"x\":case\"radialaxis\":!function(t,e){var r=e._subplot;t.setGeometry=function(){var e=t._rl[0],n=t._rl[1],i=r.innerRadius,a=(r.radius-i)/(n-e),o=i/a,s=e>n?function(t){return t<=0}:function(t){return t>=0};t.c2g=function(r){var n=t.c2l(r)-e;return(s(n)?n:0)+o},t.g2c=function(r){return t.l2c(r+e-o)},t.g2p=function(t){return t*a},t.c2p=function(e){return t.g2p(t.c2g(e))}}}(t,e);break;case\"angularaxis\":!function(t,e){var r=t.type;if(\"linear\"===r){var i=t.d2c,s=t.c2d;t.d2c=function(t,e){return function(t,e){return\"degrees\"===e?a(t):t}(i(t),e)},t.c2d=function(t,e){return s(function(t,e){return\"degrees\"===e?o(t):t}(t,e))}}t.makeCalcdata=function(e,i){var a,o,s=e[i],l=e._length,c=function(r){return t.d2c(r,e.thetaunit)};if(s){if(n.isTypedArray(s)&&\"linear\"===r){if(l===s.length)return s;if(s.subarray)return s.subarray(0,l)}for(a=new Array(l),o=0;o<l;o++)a[o]=c(s[o])}else{var u=i+\"0\",h=\"d\"+i,f=u in e?c(e[u]):0,p=e[h]?c(e[h]):(t.period||2*Math.PI)/l;for(a=new Array(l),o=0;o<l;o++)a[o]=f+o*p}return a},t.setGeometry=function(){var i,s,l,c,u=e.sector,h=u.map(a),f={clockwise:-1,counterclockwise:1}[t.direction],p=a(t.rotation),d=function(t){return f*t+p},g=function(t){return(t-p)/f};switch(r){case\"linear\":s=i=n.identity,c=a,l=o,t.range=n.isFullCircle(h)?[u[0],u[0]+360]:h.map(g).map(o);break;case\"category\":var v=t._categories.length,m=t.period?Math.max(t.period,v):v;0===m&&(m=1),s=c=function(t){return 2*t*Math.PI/m},i=l=function(t){return t*m/Math.PI/2},t.range=[0,m]}t.c2g=function(t){return d(s(t))},t.g2c=function(t){return i(g(t))},t.t2g=function(t){return d(c(t))},t.g2t=function(t){return l(g(t))}}}(t,e)}}},{\"../../lib\":719,\"../cartesian/set_convert\":785}],842:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\"),a=t(\"./domain\").defaults;e.exports=function(t,e,r,o){var s,l,c=o.type,u=o.attributes,h=o.handleDefaults,f=o.partition||\"x\",p=e._subplots[c],d=p.length,g=d&&p[0].replace(/\\d+$/,\"\");function v(t,e){return n.coerce(s,l,u,t,e)}for(var m=0;m<d;m++){var y=p[m];s=t[y]?t[y]:t[y]={},l=i.newContainer(e,y,g),v(\"uirevision\",e.uirevision);var x={};x[f]=[m/d,(m+1)/d],a(l,e,v,x),o.id=y,h(s,l,v,o)}}},{\"../lib\":719,\"../plot_api/plot_template\":757,\"./domain\":792}],843:[function(t,e,r){\"use strict\";var n=t(\"./ternary\"),i=t(\"../../plots/get_data\").getSubplotCalcData,a=t(\"../../lib\").counterRegex;r.name=\"ternary\";var o=r.attr=\"subplot\";r.idRoot=\"ternary\",r.idRegex=r.attrRegex=a(\"ternary\"),(r.attributes={})[o]={valType:\"subplotid\",dflt:\"ternary\",editType:\"calc\"},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t.calcdata,a=e._subplots.ternary,o=0;o<a.length;o++){var s=a[o],l=i(r,\"ternary\",s),c=e[s]._subplot;c||(c=new n({id:s,graphDiv:t,container:e._ternarylayer.node()},e),e[s]._subplot=c),c.plot(l,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.ternary||[],a=0;a<i.length;a++){var o=i[a],s=n[o]._subplot;!e[o]&&s&&(s.plotContainer.remove(),s.clipDef.remove(),s.clipDefRelative.remove(),s.layers[\"a-title\"].remove(),s.layers[\"b-title\"].remove(),s.layers[\"c-title\"].remove())}}},{\"../../lib\":719,\"../../plots/get_data\":802,\"./layout_attributes\":844,\"./layout_defaults\":845,\"./ternary\":846}],844:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"../cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../lib/extend\").extendFlat,l={title:a.title,color:a.color,tickmode:a.tickmode,nticks:s({},a.nticks,{dflt:6,min:1}),tick0:a.tick0,dtick:a.dtick,tickvals:a.tickvals,ticktext:a.ticktext,ticks:a.ticks,ticklen:a.ticklen,tickwidth:a.tickwidth,tickcolor:a.tickcolor,showticklabels:a.showticklabels,showtickprefix:a.showtickprefix,tickprefix:a.tickprefix,showticksuffix:a.showticksuffix,ticksuffix:a.ticksuffix,showexponent:a.showexponent,exponentformat:a.exponentformat,separatethousands:a.separatethousands,tickfont:a.tickfont,tickangle:a.tickangle,tickformat:a.tickformat,tickformatstops:a.tickformatstops,hoverformat:a.hoverformat,showline:s({},a.showline,{dflt:!0}),linecolor:a.linecolor,linewidth:a.linewidth,showgrid:s({},a.showgrid,{dflt:!0}),gridcolor:a.gridcolor,gridwidth:a.gridwidth,layer:a.layer,min:{valType:\"number\",dflt:0,min:0},_deprecated:{title:a._deprecated.title,titlefont:a._deprecated.titlefont}},c=e.exports=o({domain:i({name:\"ternary\"}),bgcolor:{valType:\"color\",dflt:n.background},sum:{valType:\"number\",dflt:1,min:0},aaxis:l,baxis:l,caxis:l},\"plot\",\"from-root\");c.uirevision={valType:\"any\",editType:\"none\"},c.aaxis.uirevision=c.baxis.uirevision=c.caxis.uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":592,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../cartesian/layout_attributes\":779,\"../domain\":792}],845:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../lib\"),o=t(\"../subplot_defaults\"),s=t(\"../cartesian/tick_label_defaults\"),l=t(\"../cartesian/tick_mark_defaults\"),c=t(\"../cartesian/tick_value_defaults\"),u=t(\"../cartesian/line_grid_defaults\"),h=t(\"./layout_attributes\"),f=[\"aaxis\",\"baxis\",\"caxis\"];function p(t,e,r,a){var o,s,l,c=r(\"bgcolor\"),u=r(\"sum\");a.bgColor=n.combine(c,a.paper_bgcolor);for(var h=0;h<f.length;h++)s=t[o=f[h]]||{},(l=i.newContainer(e,o))._name=o,d(s,l,a,e);var p=e.aaxis,g=e.baxis,v=e.caxis;p.min+g.min+v.min>=u&&(p.min=0,g.min=0,v.min=0,t.aaxis&&delete t.aaxis.min,t.baxis&&delete t.baxis.min,t.caxis&&delete t.caxis.min)}function d(t,e,r,n){var i=h[e._name];function o(r,n){return a.coerce(t,e,i,r,n)}o(\"uirevision\",n.uirevision),e.type=\"linear\";var f=o(\"color\"),p=f!==i.color.dflt?f:r.font.color,d=e._name.charAt(0).toUpperCase(),g=\"Component \"+d,v=o(\"title.text\",g);e._hovertitle=v===g?v:d,a.coerceFont(o,\"title.font\",{family:r.font.family,size:Math.round(1.2*r.font.size),color:p}),o(\"min\"),c(t,e,o,\"linear\"),s(t,e,o,\"linear\",{}),l(t,e,o,{outerTicks:!0}),o(\"showticklabels\")&&(a.coerceFont(o,\"tickfont\",{family:r.font.family,size:r.font.size,color:p}),o(\"tickangle\"),o(\"tickformat\")),u(t,e,o,{dfltColor:f,bgColor:r.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:i}),o(\"hoverformat\"),o(\"layer\")}e.exports=function(t,e,r){o(t,e,r,{type:\"ternary\",attributes:h,handleDefaults:p,font:e.font,paper_bgcolor:e.paper_bgcolor})}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../cartesian/line_grid_defaults\":781,\"../cartesian/tick_label_defaults\":786,\"../cartesian/tick_mark_defaults\":787,\"../cartesian/tick_value_defaults\":788,\"../subplot_defaults\":842,\"./layout_attributes\":844}],846:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=o._,l=t(\"../../components/color\"),c=t(\"../../components/drawing\"),u=t(\"../cartesian/set_convert\"),h=t(\"../../lib/extend\").extendFlat,f=t(\"../plots\"),p=t(\"../cartesian/axes\"),d=t(\"../../components/dragelement\"),g=t(\"../../components/fx\"),v=t(\"../../components/titles\"),m=t(\"../cartesian/select\").prepSelect,y=t(\"../cartesian/select\").selectOnClick,x=t(\"../cartesian/select\").clearSelect,b=t(\"../cartesian/constants\");function _(t,e){this.id=t.id,this.graphDiv=t.graphDiv,this.init(e),this.makeFramework(e),this.aTickLayout=null,this.bTickLayout=null,this.cTickLayout=null}e.exports=_;var w=_.prototype;w.init=function(t){this.container=t._ternarylayer,this.defs=t._defs,this.layoutId=t._uid,this.traceHash={},this.layers={}},w.plot=function(t,e){var r=e[this.id],n=e._size;this._hasClipOnAxisFalse=!1;for(var i=0;i<t.length;i++){if(!1===t[i][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(r),this.adjustLayout(r,n),f.generalUpdatePerTraceModule(this.graphDiv,this,t,r),this.layers.plotbg.select(\"path\").call(l.fill,r.bgcolor)},w.makeFramework=function(t){var e=this.graphDiv,r=t[this.id],n=this.clipId=\"clip\"+this.layoutId+this.id,i=this.clipIdRelative=\"clip-relative\"+this.layoutId+this.id;this.clipDef=o.ensureSingleById(t._clips,\"clipPath\",n,function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")}),this.clipDefRelative=o.ensureSingleById(t._clips,\"clipPath\",i,function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")}),this.plotContainer=o.ensureSingle(this.container,\"g\",this.id),this.updateLayers(r),c.setClipUrl(this.layers.backplot,n,e),c.setClipUrl(this.layers.grids,n,e)},w.updateLayers=function(t){var e=this.layers,r=[\"draglayer\",\"plotbg\",\"backplot\",\"grids\"];\"below traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"below traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"below traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\"),r.push(\"frontplot\"),\"above traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"above traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"above traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\");var i=this.plotContainer.selectAll(\"g.toplevel\").data(r,String),a=[\"agrid\",\"bgrid\",\"cgrid\"];i.enter().append(\"g\").attr(\"class\",function(t){return\"toplevel \"+t}).each(function(t){var r=n.select(this);e[t]=r,\"frontplot\"===t?r.append(\"g\").classed(\"scatterlayer\",!0):\"backplot\"===t?r.append(\"g\").classed(\"maplayer\",!0):\"plotbg\"===t?r.append(\"path\").attr(\"d\",\"M0,0Z\"):\"aline\"===t||\"bline\"===t||\"cline\"===t?r.append(\"path\"):\"grids\"===t&&a.forEach(function(t){e[t]=r.append(\"g\").classed(\"grid \"+t,!0)})}),i.order()};var k=Math.sqrt(4/3);w.adjustLayout=function(t,e){var r,n,i,a,o,s,f=this,p=t.domain,d=(p.x[0]+p.x[1])/2,g=(p.y[0]+p.y[1])/2,v=p.x[1]-p.x[0],m=p.y[1]-p.y[0],y=v*e.w,x=m*e.h,b=t.sum,_=t.aaxis.min,w=t.baxis.min,T=t.caxis.min;y>k*x?i=(a=x)*k:a=(i=y)/k,o=v*i/y,s=m*a/x,r=e.l+e.w*d-i/2,n=e.t+e.h*(1-g)-a/2,f.x0=r,f.y0=n,f.w=i,f.h=a,f.sum=b,f.xaxis={type:\"linear\",range:[_+2*T-b,b-_-2*w],domain:[d-o/2,d+o/2],_id:\"x\"},u(f.xaxis,f.graphDiv._fullLayout),f.xaxis.setScale(),f.xaxis.isPtWithinRange=function(t){return t.a>=f.aaxis.range[0]&&t.a<=f.aaxis.range[1]&&t.b>=f.baxis.range[1]&&t.b<=f.baxis.range[0]&&t.c>=f.caxis.range[1]&&t.c<=f.caxis.range[0]},f.yaxis={type:\"linear\",range:[_,b-w-T],domain:[g-s/2,g+s/2],_id:\"y\"},u(f.yaxis,f.graphDiv._fullLayout),f.yaxis.setScale(),f.yaxis.isPtWithinRange=function(){return!0};var A=f.yaxis.domain[0],M=f.aaxis=h({},t.aaxis,{range:[_,b-w-T],side:\"left\",tickangle:(+t.aaxis.tickangle||0)-30,domain:[A,A+s*k],anchor:\"free\",position:0,_id:\"y\",_length:i});u(M,f.graphDiv._fullLayout),M.setScale();var S=f.baxis=h({},t.baxis,{range:[b-_-T,w],side:\"bottom\",domain:f.xaxis.domain,anchor:\"free\",position:0,_id:\"x\",_length:i});u(S,f.graphDiv._fullLayout),S.setScale();var E=f.caxis=h({},t.caxis,{range:[b-_-w,T],side:\"right\",tickangle:(+t.caxis.tickangle||0)+30,domain:[A,A+s*k],anchor:\"free\",position:0,_id:\"y\",_length:i});u(E,f.graphDiv._fullLayout),E.setScale();var C=\"M\"+r+\",\"+(n+a)+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";f.clipDef.select(\"path\").attr(\"d\",C),f.layers.plotbg.select(\"path\").attr(\"d\",C);var L=\"M0,\"+a+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";f.clipDefRelative.select(\"path\").attr(\"d\",L);var P=\"translate(\"+r+\",\"+n+\")\";f.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",P),f.clipDefRelative.select(\"path\").attr(\"transform\",null);var O=\"translate(\"+(r-S._offset)+\",\"+(n+a)+\")\";f.layers.baxis.attr(\"transform\",O),f.layers.bgrid.attr(\"transform\",O);var z=\"translate(\"+(r+i/2)+\",\"+n+\")rotate(30)translate(0,\"+-M._offset+\")\";f.layers.aaxis.attr(\"transform\",z),f.layers.agrid.attr(\"transform\",z);var I=\"translate(\"+(r+i/2)+\",\"+n+\")rotate(-30)translate(0,\"+-E._offset+\")\";f.layers.caxis.attr(\"transform\",I),f.layers.cgrid.attr(\"transform\",I),f.drawAxes(!0),f.layers.aline.select(\"path\").attr(\"d\",M.showline?\"M\"+r+\",\"+(n+a)+\"l\"+i/2+\",-\"+a:\"M0,0\").call(l.stroke,M.linecolor||\"#000\").style(\"stroke-width\",(M.linewidth||0)+\"px\"),f.layers.bline.select(\"path\").attr(\"d\",S.showline?\"M\"+r+\",\"+(n+a)+\"h\"+i:\"M0,0\").call(l.stroke,S.linecolor||\"#000\").style(\"stroke-width\",(S.linewidth||0)+\"px\"),f.layers.cline.select(\"path\").attr(\"d\",E.showline?\"M\"+(r+i/2)+\",\"+n+\"l\"+i/2+\",\"+a:\"M0,0\").call(l.stroke,E.linecolor||\"#000\").style(\"stroke-width\",(E.linewidth||0)+\"px\"),f.graphDiv._context.staticPlot||f.initInteractions(),c.setClipUrl(f.layers.frontplot,f._hasClipOnAxisFalse?null:f.clipId,f.graphDiv)},w.drawAxes=function(t){var e=this.graphDiv,r=this.id.substr(7)+\"title\",n=this.layers,i=this.aaxis,a=this.baxis,o=this.caxis;if(this.drawAx(i),this.drawAx(a),this.drawAx(o),t){var l=Math.max(i.showticklabels?i.tickfont.size/2:0,(o.showticklabels?.75*o.tickfont.size:0)+(\"outside\"===o.ticks?.87*o.ticklen:0)),c=(a.showticklabels?a.tickfont.size:0)+(\"outside\"===a.ticks?a.ticklen:0)+3;n[\"a-title\"]=v.draw(e,\"a\"+r,{propContainer:i,propName:this.id+\".aaxis.title\",placeholder:s(e,\"Click to enter Component A title\"),attributes:{x:this.x0+this.w/2,y:this.y0-i.title.font.size/3-l,\"text-anchor\":\"middle\"}}),n[\"b-title\"]=v.draw(e,\"b\"+r,{propContainer:a,propName:this.id+\".baxis.title\",placeholder:s(e,\"Click to enter Component B title\"),attributes:{x:this.x0-c,y:this.y0+this.h+.83*a.title.font.size+c,\"text-anchor\":\"middle\"}}),n[\"c-title\"]=v.draw(e,\"c\"+r,{propContainer:o,propName:this.id+\".caxis.title\",placeholder:s(e,\"Click to enter Component C title\"),attributes:{x:this.x0+this.w+c,y:this.y0+this.h+.83*o.title.font.size+c,\"text-anchor\":\"middle\"}})}},w.drawAx=function(t){var e,r=this.graphDiv,n=t._name,i=n.charAt(0),a=t._id,s=this.layers[n],l=i+\"tickLayout\",c=(e=t).ticks+String(e.ticklen)+String(e.showticklabels);this[l]!==c&&(s.selectAll(\".\"+a+\"tick\").remove(),this[l]=c),t.setScale();var u=p.calcTicks(t),h=p.clipEnds(t,u),f=p.makeTransFn(t),d=p.getTickSigns(t)[2],g=o.deg2rad(30),v=d*(t.linewidth||1)/2,m=d*t.ticklen,y=this.w,x=this.h,b=\"b\"===i?\"M0,\"+v+\"l\"+Math.sin(g)*m+\",\"+Math.cos(g)*m:\"M\"+v+\",0l\"+Math.cos(g)*m+\",\"+-Math.sin(g)*m,_={a:\"M0,0l\"+x+\",-\"+y/2,b:\"M0,0l-\"+y/2+\",-\"+x,c:\"M0,0l-\"+x+\",\"+y/2}[i];p.drawTicks(r,t,{vals:\"inside\"===t.ticks?h:u,layer:s,path:b,transFn:f,crisp:!1}),p.drawGrid(r,t,{vals:h,layer:this.layers[i+\"grid\"],path:_,transFn:f,crisp:!1}),p.drawLabels(r,t,{vals:u,layer:s,transFn:f,labelFns:p.makeLabelFns(t,0,30)})};var T=b.MINZOOM/2+.87,A=\"m-0.87,.5h\"+T+\"v3h-\"+(T+5.2)+\"l\"+(T/2+2.6)+\",-\"+(.87*T+4.5)+\"l2.6,1.5l-\"+T/2+\",\"+.87*T+\"Z\",M=\"m0.87,.5h-\"+T+\"v3h\"+(T+5.2)+\"l-\"+(T/2+2.6)+\",-\"+(.87*T+4.5)+\"l-2.6,1.5l\"+T/2+\",\"+.87*T+\"Z\",S=\"m0,1l\"+T/2+\",\"+.87*T+\"l2.6,-1.5l-\"+(T/2+2.6)+\",-\"+(.87*T+4.5)+\"l-\"+(T/2+2.6)+\",\"+(.87*T+4.5)+\"l2.6,1.5l\"+T/2+\",-\"+.87*T+\"Z\",E=\"m0.5,0.5h5v-2h-5v-5h-2v5h-5v2h5v5h2Z\",C=!0;function L(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}w.initInteractions=function(){var t,e,r,n,u,h,f,p,v,_,w=this,T=w.layers.plotbg.select(\"path\").node(),P=w.graphDiv,O=P._fullLayout._zoomlayer,z={element:T,gd:P,plotinfo:{id:w.id,xaxis:w.xaxis,yaxis:w.yaxis},subplot:w.id,prepFn:function(a,o,s){z.xaxes=[w.xaxis],z.yaxes=[w.yaxis];var c=P._fullLayout.dragmode;z.minDrag=\"lasso\"===c?1:void 0,\"zoom\"===c?(z.moveFn=N,z.clickFn=D,z.doneFn=j,function(a,o,s){var c=T.getBoundingClientRect();t=o-c.left,e=s-c.top,r={a:w.aaxis.range[0],b:w.baxis.range[1],c:w.caxis.range[1]},u=r,n=w.aaxis.range[1]-r.a,h=i(w.graphDiv._fullLayout[w.id].bgcolor).getLuminance(),f=\"M0,\"+w.h+\"L\"+w.w/2+\", 0L\"+w.w+\",\"+w.h+\"Z\",p=!1,v=O.append(\"path\").attr(\"class\",\"zoombox\").attr(\"transform\",\"translate(\"+w.x0+\", \"+w.y0+\")\").style({fill:h>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"d\",f),_=O.append(\"path\").attr(\"class\",\"zoombox-corners\").attr(\"transform\",\"translate(\"+w.x0+\", \"+w.y0+\")\").style({fill:l.background,stroke:l.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"d\",\"M0,0Z\"),x(P)}(0,o,s)):\"pan\"===c?(z.moveFn=U,z.clickFn=D,z.doneFn=V,r={a:w.aaxis.range[0],b:w.baxis.range[1],c:w.caxis.range[1]},u=r,x(P)):\"select\"!==c&&\"lasso\"!==c||m(a,o,s,z,c)}};function I(t){var e={};return e[w.id+\".aaxis.min\"]=t.a,e[w.id+\".baxis.min\"]=t.b,e[w.id+\".caxis.min\"]=t.c,e}function D(t,e){var r=P._fullLayout.clickmode;L(P),2===t&&(P.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",P,I({a:0,b:0,c:0}))),r.indexOf(\"select\")>-1&&1===t&&y(e,P,[w.xaxis],[w.yaxis],w.id,z),r.indexOf(\"event\")>-1&&g.click(P,e,w.id)}function R(t,e){return 1-e/w.h}function F(t,e){return 1-(t+(w.h-e)/Math.sqrt(3))/w.w}function B(t,e){return(t-(w.h-e)/Math.sqrt(3))/w.w}function N(i,a){var o=t+i,s=e+a,l=Math.max(0,Math.min(1,R(0,e),R(0,s))),c=Math.max(0,Math.min(1,F(t,e),F(o,s))),d=Math.max(0,Math.min(1,B(t,e),B(o,s))),g=(l/2+d)*w.w,m=(1-l/2-c)*w.w,y=(g+m)/2,x=m-g,T=(1-l)*w.h,C=T-x/k;x<b.MINZOOM?(u=r,v.attr(\"d\",f),_.attr(\"d\",\"M0,0Z\")):(u={a:r.a+l*n,b:r.b+c*n,c:r.c+d*n},v.attr(\"d\",f+\"M\"+g+\",\"+T+\"H\"+m+\"L\"+y+\",\"+C+\"L\"+g+\",\"+T+\"Z\"),_.attr(\"d\",\"M\"+t+\",\"+e+E+\"M\"+g+\",\"+T+A+\"M\"+m+\",\"+T+M+\"M\"+y+\",\"+C+S)),p||(v.transition().style(\"fill\",h>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),_.transition().style(\"opacity\",1).duration(200),p=!0),P.emit(\"plotly_relayouting\",I(u))}function j(){L(P),u!==r&&(a.call(\"_guiRelayout\",P,I(u)),C&&P.data&&P._context.showTips&&(o.notifier(s(P,\"Double-click to zoom back out\"),\"long\"),C=!1))}function U(t,e){var n=t/w.xaxis._m,i=e/w.yaxis._m,a=[(u={a:r.a-i,b:r.b+(n+i)/2,c:r.c-(n-i)/2}).a,u.b,u.c].sort(),o=a.indexOf(u.a),s=a.indexOf(u.b),l=a.indexOf(u.c);a[0]<0&&(a[1]+a[0]/2<0?(a[2]+=a[0]+a[1],a[0]=a[1]=0):(a[2]+=a[0]/2,a[1]+=a[0]/2,a[0]=0),u={a:a[o],b:a[s],c:a[l]},e=(r.a-u.a)*w.yaxis._m,t=(r.c-u.c-r.b+u.b)*w.xaxis._m);var h=\"translate(\"+(w.x0+t)+\",\"+(w.y0+e)+\")\";w.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",h);var f=\"translate(\"+-t+\",\"+-e+\")\";w.clipDefRelative.select(\"path\").attr(\"transform\",f),w.aaxis.range=[u.a,w.sum-u.b-u.c],w.baxis.range=[w.sum-u.a-u.c,u.b],w.caxis.range=[w.sum-u.a-u.b,u.c],w.drawAxes(!1),w._hasClipOnAxisFalse&&w.plotContainer.select(\".scatterlayer\").selectAll(\".trace\").call(c.hideOutsideRangePoints,w),P.emit(\"plotly_relayouting\",I(u))}function V(){a.call(\"_guiRelayout\",P,I(u))}T.onmousemove=function(t){g.hover(P,t,w.id),P._fullLayout._lasthover=T,P._fullLayout._hoversubplot=w.id},T.onmouseout=function(t){P._dragging||d.unhover(P,t)},d.init(z)}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../components/titles\":681,\"../../lib\":719,\"../../lib/extend\":710,\"../../registry\":847,\"../cartesian/axes\":767,\"../cartesian/constants\":773,\"../cartesian/select\":784,\"../cartesian/set_convert\":785,\"../plots\":828,d3:163,tinycolor2:537}],847:[function(t,e,r){\"use strict\";var n=t(\"./lib/loggers\"),i=t(\"./lib/noop\"),a=t(\"./lib/push_unique\"),o=t(\"./lib/is_plain_object\"),s=t(\"./lib/dom\").addStyleRule,l=t(\"./lib/extend\"),c=t(\"./plots/attributes\"),u=t(\"./plots/layout_attributes\"),h=l.extendFlat,f=l.extendDeepAll;function p(t){var e=t.name,i=t.categories,a=t.meta;if(r.modules[e])n.log(\"Type \"+e+\" already registered\");else{r.subplotsRegistry[t.basePlotModule.name]||function(t){var e=t.name;if(r.subplotsRegistry[e])return void n.log(\"Plot type \"+e+\" already registered.\");for(var i in m(t),r.subplotsRegistry[e]=t,r.componentsRegistry)b(i,t.name)}(t.basePlotModule);for(var o={},l=0;l<i.length;l++)o[i[l]]=!0,r.allCategories[i[l]]=!0;for(var c in r.modules[e]={_module:t,categories:o},a&&Object.keys(a).length&&(r.modules[e].meta=a),r.allTypes.push(e),r.componentsRegistry)y(c,e);t.layoutAttributes&&h(r.traceLayoutAttributes,t.layoutAttributes);var u=t.basePlotModule,f=u.name;if(\"mapbox\"===f){var p=u.constants.styleRules;for(var d in p)s(\".js-plotly-plot .plotly .mapboxgl-\"+d,p[d])}\"geo\"!==f&&\"mapbox\"!==f||void 0===typeof window||void 0!==window.PlotlyGeoAssets||(window.PlotlyGeoAssets={topojson:{}})}}function d(t){if(\"string\"!=typeof t.name)throw new Error(\"Component module *name* must be a string.\");var e=t.name;for(var n in r.componentsRegistry[e]=t,t.layoutAttributes&&(t.layoutAttributes._isLinkedToArray&&a(r.layoutArrayContainers,e),m(t)),r.modules)y(e,n);for(var i in r.subplotsRegistry)b(e,i);for(var o in r.transformsRegistry)x(e,o);t.schema&&t.schema.layout&&f(u,t.schema.layout)}function g(t){if(\"string\"!=typeof t.name)throw new Error(\"Transform module *name* must be a string.\");var e=\"Transform module \"+t.name,i=\"function\"==typeof t.transform,a=\"function\"==typeof t.calcTransform;if(!i&&!a)throw new Error(e+\" is missing a *transform* or *calcTransform* method.\");for(var s in i&&a&&n.log([e+\" has both a *transform* and *calcTransform* methods.\",\"Please note that all *transform* methods are executed\",\"before all *calcTransform* methods.\"].join(\" \")),o(t.attributes)||n.log(e+\" registered without an *attributes* object.\"),\"function\"!=typeof t.supplyDefaults&&n.log(e+\" registered without a *supplyDefaults* method.\"),r.transformsRegistry[t.name]=t,r.componentsRegistry)x(s,t.name)}function v(t){var e=t.name,n=e.split(\"-\")[0],i=t.dictionary,a=t.format,o=i&&Object.keys(i).length,s=a&&Object.keys(a).length,l=r.localeRegistry,c=l[e];if(c||(l[e]=c={}),n!==e){var u=l[n];u||(l[n]=u={}),o&&u.dictionary===c.dictionary&&(u.dictionary=i),s&&u.format===c.format&&(u.format=a)}o&&(c.dictionary=i),s&&(c.format=a)}function m(t){if(t.layoutAttributes){var e=t.layoutAttributes._arrayAttrRegexps;if(e)for(var n=0;n<e.length;n++)a(r.layoutArrayRegexes,e[n])}}function y(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.traces){var i=n.traces[e];i&&f(r.modules[e]._module.attributes,i)}}function x(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.transforms){var i=n.transforms[e];i&&f(r.transformsRegistry[e].attributes,i)}}function b(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.subplots){var i=r.subplotsRegistry[e],a=i.layoutAttributes,o=\"subplot\"===i.attr?i.name:i.attr;Array.isArray(o)&&(o=o[0]);var s=n.subplots[o];a&&s&&f(a,s)}}function _(t){return\"object\"==typeof t&&(t=t.type),t}r.modules={},r.allCategories={},r.allTypes=[],r.subplotsRegistry={},r.transformsRegistry={},r.componentsRegistry={},r.layoutArrayContainers=[],r.layoutArrayRegexes=[],r.traceLayoutAttributes={},r.localeRegistry={},r.apiMethodRegistry={},r.collectableSubplotTypes=null,r.register=function(t){if(r.collectableSubplotTypes=null,!t)throw new Error(\"No argument passed to Plotly.register.\");t&&!Array.isArray(t)&&(t=[t]);for(var e=0;e<t.length;e++){var n=t[e];if(!n)throw new Error(\"Invalid module was attempted to be registered!\");switch(n.moduleType){case\"trace\":p(n);break;case\"transform\":g(n);break;case\"component\":d(n);break;case\"locale\":v(n);break;case\"apiMethod\":var i=n.name;r.apiMethodRegistry[i]=n.fn;break;default:throw new Error(\"Invalid module was attempted to be registered!\")}}},r.getModule=function(t){var e=r.modules[_(t)];return!!e&&e._module},r.traceIs=function(t,e){if(\"various\"===(t=_(t)))return!1;var i=r.modules[t];return i||(t&&\"area\"!==t&&n.log(\"Unrecognized trace type \"+t+\".\"),i=r.modules[c.type.dflt]),!!i.categories[e]},r.getTransformIndices=function(t,e){for(var r=[],n=t.transforms||[],i=0;i<n.length;i++)n[i].type===e&&r.push(i);return r},r.hasTransform=function(t,e){for(var r=t.transforms||[],n=0;n<r.length;n++)if(r[n].type===e)return!0;return!1},r.getComponentMethod=function(t,e){var n=r.componentsRegistry[t];return n&&n[e]||i},r.call=function(){var t=arguments[0],e=[].slice.call(arguments,1);return r.apiMethodRegistry[t].apply(null,e)}},{\"./lib/dom\":708,\"./lib/extend\":710,\"./lib/is_plain_object\":720,\"./lib/loggers\":723,\"./lib/noop\":728,\"./lib/push_unique\":733,\"./plots/attributes\":764,\"./plots/layout_attributes\":819}],848:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=i.extendFlat,o=i.extendDeep;function s(t){var e;switch(t){case\"themes__thumb\":e={autosize:!0,width:150,height:150,title:{text:\"\"},showlegend:!1,margin:{l:5,r:5,t:5,b:5,pad:0},annotations:[]};break;case\"thumbnail\":e={title:{text:\"\"},hidesources:!0,showlegend:!1,borderwidth:0,bordercolor:\"\",margin:{l:1,r:1,t:1,b:1,pad:0},annotations:[]};break;default:e={}}return e}e.exports=function(t,e){var r;t.framework&&t.framework.isPolar&&(t=t.framework.getConfig());var i,l=t.data,c=t.layout,u=o([],l),h=o({},c,s(e.tileClass)),f=t._context||{};if(e.width&&(h.width=e.width),e.height&&(h.height=e.height),\"thumbnail\"===e.tileClass||\"themes__thumb\"===e.tileClass){h.annotations=[];var p=Object.keys(h);for(r=0;r<p.length;r++)i=p[r],[\"xaxis\",\"yaxis\",\"zaxis\"].indexOf(i.slice(0,5))>-1&&(h[p[r]].title={text:\"\"});for(r=0;r<u.length;r++){var d=u[r];d.showscale=!1,d.marker&&(d.marker.showscale=!1),n.traceIs(d,\"pie-like\")&&(d.textposition=\"none\")}}if(Array.isArray(e.annotations))for(r=0;r<e.annotations.length;r++)h.annotations.push(e.annotations[r]);var g=Object.keys(h).filter(function(t){return t.match(/^scene\\d*$/)});if(g.length){var v={};for(\"thumbnail\"===e.tileClass&&(v={title:{text:\"\"},showaxeslabels:!1,showticklabels:!1,linetickenable:!1}),r=0;r<g.length;r++){var m=h[g[r]];m.xaxis||(m.xaxis={}),m.yaxis||(m.yaxis={}),m.zaxis||(m.zaxis={}),a(m.xaxis,v),a(m.yaxis,v),a(m.zaxis,v),m._scene=null}}var y=document.createElement(\"div\");e.tileClass&&(y.className=e.tileClass);var x={gd:y,td:y,layout:h,data:u,config:{staticPlot:void 0===e.staticPlot||e.staticPlot,plotGlPixelRatio:void 0===e.plotGlPixelRatio?2:e.plotGlPixelRatio,displaylogo:e.displaylogo||!1,showLink:e.showLink||!1,showTips:e.showTips||!1,mapboxAccessToken:f.mapboxAccessToken}};return\"transparent\"!==e.setBackground&&(x.config.setBackground=e.setBackground||\"opaque\"),x.gd.defaultLayout=s(e.tileClass),x}},{\"../lib\":719,\"../registry\":847}],849:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/to_image\"),a=t(\"./filesaver\"),o=t(\"./helpers\");e.exports=function(t,e){var r;return n.isPlainObject(t)||(r=n.getGraphDiv(t)),(e=e||{}).format=e.format||\"png\",e.imageDataOnly=!0,new Promise(function(s,l){r&&r._snapshotInProgress&&l(new Error(\"Snapshotting already in progress.\")),n.isIE()&&\"svg\"!==e.format&&l(new Error(o.MSG_IE_BAD_FORMAT)),r&&(r._snapshotInProgress=!0);var c=i(t,e),u=e.filename||t.fn||\"newplot\";u+=\".\"+e.format,c.then(function(t){return r&&(r._snapshotInProgress=!1),a(t,u,e.format)}).then(function(t){s(t)}).catch(function(t){r&&(r._snapshotInProgress=!1),l(t)})})}},{\"../lib\":719,\"../plot_api/to_image\":760,\"./filesaver\":850,\"./helpers\":851}],850:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"./helpers\");e.exports=function(t,e,r){var a=document.createElement(\"a\"),o=\"download\"in a;return new Promise(function(s,l){var c,u;if(n.isIE9orBelow()&&l(new Error(\"IE < 10 unsupported\")),n.isSafari()){var h=\"svg\"===r?\",\":\";base64,\";return i.octetStream(h+encodeURIComponent(t)),s(e)}return n.isIE()?(c=i.createBlob(t,\"svg\"),window.navigator.msSaveBlob(c,e),c=null,s(e)):o?(c=i.createBlob(t,r),u=i.createObjectURL(c),a.href=u,a.download=e,document.body.appendChild(a),a.click(),document.body.removeChild(a),i.revokeObjectURL(u),c=null,s(e)):void l(new Error(\"download error\"))})}},{\"../lib\":719,\"./helpers\":851}],851:[function(t,e,r){\"use strict\";var n=t(\"../registry\");r.getDelay=function(t){return t._has&&(t._has(\"gl3d\")||t._has(\"gl2d\")||t._has(\"mapbox\"))?500:0},r.getRedrawFunc=function(t){return function(){var e=t._fullLayout||{};!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r||n.getComponentMethod(\"colorbar\",\"draw\")(t)}},r.encodeSVG=function(t){return\"data:image/svg+xml,\"+encodeURIComponent(t)};var i=window.URL||window.webkitURL;r.createObjectURL=function(t){return i.createObjectURL(t)},r.revokeObjectURL=function(t){return i.revokeObjectURL(t)},r.createBlob=function(t,e){if(\"svg\"===e)return new window.Blob([t],{type:\"image/svg+xml;charset=utf-8\"});var r=function(t){for(var e=t.length,r=new ArrayBuffer(e),n=new Uint8Array(r),i=0;i<e;i++)n[i]=t.charCodeAt(i);return r}(window.atob(t));return new window.Blob([r],{type:\"image/\"+e})},r.octetStream=function(t){document.location.href=\"data:application/octet-stream\"+t},r.IMAGE_URL_PREFIX=/^data:image\\/\\w+;base64,/,r.MSG_IE_BAD_FORMAT=\"Sorry IE does not support downloading from canvas. Try {format:'svg'} instead.\"},{\"../registry\":847}],852:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i={getDelay:n.getDelay,getRedrawFunc:n.getRedrawFunc,clone:t(\"./cloneplot\"),toSVG:t(\"./tosvg\"),svgToImg:t(\"./svgtoimg\"),toImage:t(\"./toimage\"),downloadImage:t(\"./download\")};e.exports=i},{\"./cloneplot\":848,\"./download\":849,\"./helpers\":851,\"./svgtoimg\":853,\"./toimage\":854,\"./tosvg\":855}],853:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"events\").EventEmitter,a=t(\"./helpers\");e.exports=function(t){var e=t.emitter||new i,r=new Promise(function(i,o){var s=window.Image,l=t.svg,c=t.format||\"png\";if(n.isIE()&&\"svg\"!==c){var u=new Error(a.MSG_IE_BAD_FORMAT);return o(u),t.promise?r:e.emit(\"error\",u)}var h,f,p=t.canvas,d=t.scale||1,g=t.width||300,v=t.height||150,m=d*g,y=d*v,x=p.getContext(\"2d\"),b=new s;\"svg\"===c||n.isIE9orBelow()||n.isSafari()?f=a.encodeSVG(l):(h=a.createBlob(l,\"svg\"),f=a.createObjectURL(h)),p.width=m,p.height=y,b.onload=function(){var r;switch(h=null,a.revokeObjectURL(f),\"svg\"!==c&&x.drawImage(b,0,0,m,y),c){case\"jpeg\":r=p.toDataURL(\"image/jpeg\");break;case\"png\":r=p.toDataURL(\"image/png\");break;case\"webp\":r=p.toDataURL(\"image/webp\");break;case\"svg\":r=f;break;default:var n=\"Image format is not jpeg, png, svg or webp.\";if(o(new Error(n)),!t.promise)return e.emit(\"error\",n)}i(r),t.promise||e.emit(\"success\",r)},b.onerror=function(r){if(h=null,a.revokeObjectURL(f),o(r),!t.promise)return e.emit(\"error\",r)},b.src=f});return t.promise?r:e}},{\"../lib\":719,\"./helpers\":851,events:104}],854:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i=t(\"../registry\"),a=t(\"../lib\"),o=t(\"./helpers\"),s=t(\"./cloneplot\"),l=t(\"./tosvg\"),c=t(\"./svgtoimg\");e.exports=function(t,e){var r=new n,u=s(t,{format:\"png\"}),h=u.gd;h.style.position=\"absolute\",h.style.left=\"-5000px\",document.body.appendChild(h);var f=o.getRedrawFunc(h);return i.call(\"plot\",h,u.data,u.layout,u.config).then(f).then(function(){var t=o.getDelay(h._fullLayout);setTimeout(function(){var t=l(h),n=document.createElement(\"canvas\");n.id=a.randstr(),(r=c({format:e.format,width:h._fullLayout.width,height:h._fullLayout.height,canvas:n,emitter:r,svg:t})).clean=function(){h&&document.body.removeChild(h)}},t)}).catch(function(t){r.emit(\"error\",t)}),r}},{\"../lib\":719,\"../registry\":847,\"./cloneplot\":848,\"./helpers\":851,\"./svgtoimg\":853,\"./tosvg\":855,events:104}],855:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=t(\"../components/drawing\"),o=t(\"../components/color\"),s=t(\"../constants/xmlns_namespaces\"),l=/\"/g,c=new RegExp('(\"TOBESTRIPPED)|(TOBESTRIPPED\")',\"g\");e.exports=function(t,e,r){var u,h=t._fullLayout,f=h._paper,p=h._toppaper,d=h.width,g=h.height;f.insert(\"rect\",\":first-child\").call(a.setRect,0,0,d,g).call(o.fill,h.paper_bgcolor);var v=h._basePlotModules||[];for(u=0;u<v.length;u++){var m=v[u];m.toSVG&&m.toSVG(t)}if(p){var y=p.node().childNodes,x=Array.prototype.slice.call(y);for(u=0;u<x.length;u++){var b=x[u];b.childNodes.length&&f.node().appendChild(b)}}h._draggers&&h._draggers.remove(),f.node().style.background=\"\",f.selectAll(\"text\").attr({\"data-unformatted\":null,\"data-math\":null}).each(function(){var t=n.select(this);if(\"hidden\"!==this.style.visibility&&\"none\"!==this.style.display){t.style({visibility:null,display:null});var e=this.style.fontFamily;e&&-1!==e.indexOf('\"')&&t.style(\"font-family\",e.replace(l,\"TOBESTRIPPED\"))}else t.remove()}),f.selectAll(\".point, .scatterpts, .legendfill>path, .legendlines>path, .cbfill\").each(function(){var t=n.select(this),e=this.style.fill;e&&-1!==e.indexOf(\"url(\")&&t.style(\"fill\",e.replace(l,\"TOBESTRIPPED\"));var r=this.style.stroke;r&&-1!==r.indexOf(\"url(\")&&t.style(\"stroke\",r.replace(l,\"TOBESTRIPPED\"))}),\"pdf\"!==e&&\"eps\"!==e||f.selectAll(\"#MathJax_SVG_glyphs path\").attr(\"stroke-width\",0),f.node().setAttributeNS(s.xmlns,\"xmlns\",s.svg),f.node().setAttributeNS(s.xmlns,\"xmlns:xlink\",s.xlink),\"svg\"===e&&r&&(f.attr(\"width\",r*d),f.attr(\"height\",r*g),f.attr(\"viewBox\",\"0 0 \"+d+\" \"+g));var _=(new window.XMLSerializer).serializeToString(f.node());return _=function(t){var e=n.select(\"body\").append(\"div\").style({display:\"none\"}).html(\"\"),r=t.replace(/(&[^;]*;)/gi,function(t){return\"&lt;\"===t?\"&#60;\":\"&rt;\"===t?\"&#62;\":-1!==t.indexOf(\"<\")||-1!==t.indexOf(\">\")?\"\":e.html(t).text()});return e.remove(),r}(_),_=(_=_.replace(/&(?!\\w+;|\\#[0-9]+;| \\#x[0-9A-F]+;)/g,\"&amp;\")).replace(c,\"'\"),i.isIE()&&(_=(_=(_=_.replace(/\"/gi,\"'\")).replace(/(\\('#)([^']*)('\\))/gi,'(\"#$2\")')).replace(/(\\\\')/gi,'\"')),_}},{\"../components/color\":593,\"../components/drawing\":614,\"../constants/xmlns_namespaces\":696,\"../lib\":719,d3:163}],856:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\",!0),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":719}],857:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/font_attributes\"),s=t(\"./constants.js\"),l=t(\"../../lib/extend\").extendFlat,c=o({editType:\"calc\",arrayOk:!0,colorEditType:\"style\"}),u=l({},n.marker.line.width,{dflt:0}),h=l({width:u,editType:\"calc\"},a(\"marker.line\")),f=l({line:h,editType:\"calc\"},a(\"marker\"),{opacity:{valType:\"number\",arrayOk:!0,dflt:1,min:0,max:1,editType:\"style\"}});e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,text:n.text,hovertext:n.hovertext,hovertemplate:i({},{keys:s.eventDataKeys}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"none\",arrayOk:!0,editType:\"calc\"},insidetextanchor:{valType:\"enumerated\",values:[\"end\",\"middle\",\"start\"],dflt:\"end\",editType:\"plot\"},textangle:{valType:\"angle\",dflt:\"auto\",editType:\"plot\"},textfont:l({},c,{}),insidetextfont:l({},c,{}),outsidetextfont:l({},c,{}),constraintext:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"both\",\"none\"],dflt:\"both\",editType:\"calc\"},cliponaxis:l({},n.cliponaxis,{}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},base:{valType:\"any\",dflt:null,arrayOk:!0,editType:\"calc\"},offset:{valType:\"number\",dflt:null,arrayOk:!0,editType:\"calc\"},width:{valType:\"number\",dflt:null,min:0,arrayOk:!0,editType:\"calc\"},marker:f,offsetgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},alignmentgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},selected:{marker:{opacity:n.selected.marker.opacity,color:n.selected.marker.color,editType:\"style\"},textfont:n.selected.textfont,editType:\"style\"},unselected:{marker:{opacity:n.unselected.marker.opacity,color:n.unselected.marker.color,editType:\"style\"},textfont:n.unselected.textfont,editType:\"style\"},r:n.r,t:n.t,_deprecated:{bardir:{valType:\"enumerated\",editType:\"calc\",values:[\"v\",\"h\"]}}}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"../scatter/attributes\":1112,\"./constants.js\":859}],858:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),o=t(\"./arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\");e.exports=function(t,e){var r,l,c=n.getFromId(t,e.xaxis||\"x\"),u=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=c.makeCalcdata(e,\"x\"),l=u.makeCalcdata(e,\"y\")):(r=u.makeCalcdata(e,\"y\"),l=c.makeCalcdata(e,\"x\"));for(var h=Math.min(l.length,r.length),f=new Array(h),p=0;p<h;p++)f[p]={p:l[p],s:r[p]},e.ids&&(f[p].id=String(e.ids[p]));return i(e,\"marker\")&&a(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),i(e,\"marker.line\")&&a(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),o(f,e),s(f,e),f}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"../../plots/cartesian/axes\":767,\"../scatter/calc_selection\":1114,\"./arrays_to_calcdata\":856}],859:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[]}},{}],860:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,c=t(\"./sieve.js\");function u(t,e,r,o,u){if(o.length){var b,_,w,k;switch(function(t,e){var r,a;for(r=0;r<e.length;r++){var o,s=e[r],l=s[0].trace,c=\"funnel\"===l.type?l._base:l.base,u=\"h\"===l.orientation?l.xcalendar:l.ycalendar,h=\"category\"===t.type||\"multicategory\"===t.type?function(){return null}:t.d2c;if(i(c)){for(a=0;a<Math.min(c.length,s.length);a++)o=h(c[a],0,u),n(o)?(s[a].b=+o,s[a].hasB=1):s[a].b=0;for(;a<s.length;a++)s[a].b=0}else{o=h(c,0,u);var f=n(o);for(o=f?o:0,a=0;a<s.length;a++)s[a].b=o,f&&(s[a].hasB=1)}}}(r,o),u.mode){case\"overlay\":h(e,r,o,u);break;case\"group\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(k=o[w])[0].trace.offset?_.push(k):b.push(k);_.length&&function(t,e,r,n,i){var o=new c(n,{sepNegVal:!1,overlapNoMerge:!i.norm});(function(t,e,r,n){for(var i=t._fullLayout,a=r.positions,o=r.distinctPositions,s=r.minDiff,c=r.traces,u=c.length,h=a.length!==o.length,f=s*(1-n.gap),v=l(i,e._id)+c[0][0].trace.orientation,m=i._alignmentOpts[v]||{},y=0;y<u;y++){var x,b,_=c[y],w=_[0].trace,k=m[w.alignmentgroup]||{},T=Object.keys(k.offsetGroups||{}).length,A=(x=T?f/T:h?f/u:f)*(1-(n.groupgap||0));b=T?((2*w._offsetIndex+1-T)*x-A)/2:h?((2*y+1-u)*x-A)/2:-A/2;var M=_[0].t;M.barwidth=A,M.poffset=b,M.bargroupwidth=f,M.bardelta=s}r.binWidth=c[0][0].t.barwidth/100,p(r),d(e,r),g(e,r,h)})(t,e,o,i),function(t){for(var e=t.traces,r=0;r<e.length;r++){var n=e[r],i=n[0].trace;if(void 0===i.base)for(var o=new c([n],{sepNegVal:!0,overlapNoMerge:!0}),s=0;s<n.length;s++){var l=n[s];if(l.p!==a){var u=o.put(l.p,l.b+l.s);u&&(l.b=u)}}}}(o),i.norm?(m(o),y(r,o,i)):v(r,o)}(t,e,r,_,u),b.length&&h(e,r,b,u);break;case\"stack\":case\"relative\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(k=o[w])[0].trace.base?_.push(k):b.push(k);_.length&&function(t,e,r,n,i){var o=new c(n,{sepNegVal:\"relative\"===i.mode,overlapNoMerge:!(i.norm||\"stack\"===i.mode||\"relative\"===i.mode)});f(e,o,i),function(t,e,r){var n,i,o,l,c,u,h=x(t),f=e.traces;for(l=0;l<f.length;l++)if(n=f[l],\"funnel\"===(i=n[0].trace).type)for(c=0;c<n.length;c++)(u=n[c]).s!==a&&e.put(u.p,-.5*u.s);for(l=0;l<f.length;l++){n=f[l],i=n[0].trace,o=\"funnel\"===i.type;var p=[];for(c=0;c<n.length;c++)if((u=n[c]).s!==a){var d;d=o?u.s:u.s+u.b;var g=e.put(u.p,d),v=g+d;u.b=g,u[h]=v,r.norm||(p.push(v),u.hasB&&p.push(g))}r.norm||(i._extremes[t._id]=s.findExtremes(t,p,{tozero:!0,padded:!0}))}}(r,o,i);for(var l=0;l<n.length;l++)for(var u=n[l],h=0;h<u.length;h++){var p=u[h];if(p.s!==a){var d=p.b+p.s===o.get(p.p,p.s);d&&(p._outmost=!0)}}i.norm&&y(r,o,i)}(0,e,r,_,u),b.length&&h(e,r,b,u)}!function(t,e){var r,i,a,o=x(e),s={},l=1/0,c=-1/0;for(r=0;r<t.length;r++)for(a=t[r],i=0;i<a.length;i++){var u=a[i].p;n(u)&&(l=Math.min(l,u),c=Math.max(c,u))}var h=1e4/(c-l),f=s.round=function(t){return String(Math.round(h*(t-l)))};for(r=0;r<t.length;r++){(a=t[r])[0].t.extents=s;var p=a[0].t.poffset,d=Array.isArray(p);for(i=0;i<a.length;i++){var g=a[i],v=g[o]-g.w/2;if(n(v)){var m=g[o]+g.w/2,y=f(g.p);s[y]?s[y]=[Math.min(v,s[y][0]),Math.max(m,s[y][1])]:s[y]=[v,m]}g.p0=g.p+(d?p[i]:p),g.p1=g.p0+g.w,g.s0=g.b,g.s1=g.s0+g.s}}}(o,e)}}function h(t,e,r,n){for(var i=0;i<r.length;i++){var a=r[i],o=new c([a],{sepNegVal:!1,overlapNoMerge:!n.norm});f(t,o,n),n.norm?(m(o),y(e,o,n)):v(e,o)}}function f(t,e,r){for(var n=e.minDiff,i=e.traces,a=n*(1-r.gap),o=a*(1-(r.groupgap||0)),s=-o/2,l=0;l<i.length;l++){var c=i[l][0].t;c.barwidth=o,c.poffset=s,c.bargroupwidth=a,c.bardelta=n}e.binWidth=i[0][0].t.barwidth/100,p(e),d(t,e),g(t,e)}function p(t){var e,r,a=t.traces;for(e=0;e<a.length;e++){var o,s=a[e],l=s[0],c=l.trace,u=l.t,h=c._offset||c.offset,f=u.poffset;if(i(h)){for(o=Array.prototype.slice.call(h,0,s.length),r=0;r<o.length;r++)n(o[r])||(o[r]=f);for(r=o.length;r<s.length;r++)o.push(f);u.poffset=o}else void 0!==h&&(u.poffset=h);var p=c._width||c.width,d=u.barwidth;if(i(p)){var g=Array.prototype.slice.call(p,0,s.length);for(r=0;r<g.length;r++)n(g[r])||(g[r]=d);for(r=g.length;r<s.length;r++)g.push(d);if(u.barwidth=g,void 0===h){for(o=[],r=0;r<s.length;r++)o.push(f+(d-g[r])/2);u.poffset=o}}else void 0!==p&&(u.barwidth=p,void 0===h&&(u.poffset=f+(d-p)/2))}}function d(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++)for(var a=r[i],o=a[0].t,s=o.poffset,l=Array.isArray(s),c=o.barwidth,u=Array.isArray(c),h=0;h<a.length;h++){var f=a[h],p=f.w=u?c[h]:c;f[n]=f.p+(l?s[h]:s)+p/2}}function g(t,e,r){var n=e.traces,i=e.minDiff/2;s.minDtick(t,e.minDiff,e.distinctPositions[0],r);for(var a=0;a<n.length;a++){var o,l,c,u,h=n[a],f=h[0],p=f.trace,d=[];for(u=0;u<h.length;u++)l=(o=h[u]).p-i,c=o.p+i,d.push(l,c);if(p.width||p.offset){var g=f.t,v=g.poffset,m=g.barwidth,y=Array.isArray(v),x=Array.isArray(m);for(u=0;u<h.length;u++){o=h[u];var b=y?v[u]:v,_=x?m[u]:m;c=(l=o.p+b)+_,d.push(l,c)}}p._extremes[t._id]=s.findExtremes(t,d,{padded:!1})}}function v(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++){for(var a=r[i],o=a[0].trace,l=[],c=!0,u=0;u<a.length;u++){var h=a[u],f=h.b,p=f+h.s;h[n]=p,l.push(p),h.hasB&&l.push(f),h.hasB&&h.b>0&&h.s>0||(c=!1)}o._extremes[t._id]=s.findExtremes(t,l,{tozero:!c,padded:!0})}}function m(t){for(var e=t.traces,r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++){var o=n[i];o.s!==a&&t.put(o.p,o.b+o.s)}}function y(t,e,r){var i=e.traces,o=x(t),l=\"fraction\"===r.norm?1:100,c=l/1e9,u=t.l2c(t.c2l(0)),h=\"stack\"===r.mode?l:u;function f(e){return n(t.c2l(e))&&(e<u-c||e>h+c||!n(u))}for(var p=0;p<i.length;p++){for(var d=i[p],g=d[0].trace,v=[],m=!0,y=!1,b=0;b<d.length;b++){var _=d[b];if(_.s!==a){var w=Math.abs(l/e.get(_.p,_.s));_.b*=w,_.s*=w;var k=_.b,T=k+_.s;_[o]=T,v.push(T),y=y||f(T),_.hasB&&(v.push(k),y=y||f(k)),_.hasB&&_.b>0&&_.s>0||(m=!1)}}g._extremes[t._id]=s.findExtremes(t,v,{tozero:!m,padded:y})}}function x(t){return t._id.charAt(0)}e.exports={crossTraceCalc:function(t,e){for(var r=e.xaxis,n=e.yaxis,i=t._fullLayout,a=t._fullData,s=t.calcdata,l=[],c=[],h=0;h<a.length;h++){var f=a[h];!0===f.visible&&o.traceIs(f,\"bar\")&&f.xaxis===r._id&&f.yaxis===n._id&&(\"h\"===f.orientation?l.push(s[h]):c.push(s[h]))}var p={mode:i.barmode,norm:i.barnorm,gap:i.bargap,groupgap:i.bargroupgap};u(t,r,n,c,p),u(t,n,r,l,p)},setGroupPositions:u}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"./sieve.js\":869,\"fast-isnumeric\":225}],861:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../registry\"),o=t(\"../scatter/xy_defaults\"),s=t(\"./style_defaults\"),l=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,c=t(\"./attributes\"),u=n.coerceFont;function h(t,e,r,n){var i=e.orientation,a=e[{v:\"x\",h:\"y\"}[i]+\"axis\"],o=l(r,a)+i,s=r._alignmentOpts||{},c=n(\"alignmentgroup\"),u=s[o];u||(u=s[o]={});var h=u[c];h?h.traces.push(e):h=u[c]={traces:[e],alignmentIndex:Object.keys(u).length,offsetGroups:{}};var f=n(\"offsetgroup\"),p=h.offsetGroups,d=p[f];f&&(d||(d=p[f]={offsetIndex:Object.keys(p).length}),e._offsetIndex=d.offsetIndex)}function f(t,e,r,i,a,o){var s=!(!1===(o=o||{}).moduleHasSelected),l=!(!1===o.moduleHasUnselected),c=!(!1===o.moduleHasConstrain),h=!(!1===o.moduleHasCliponaxis),f=!(!1===o.moduleHasTextangle),p=!(!1===o.moduleHasInsideanchor),d=Array.isArray(a)||\"auto\"===a,g=d||\"inside\"===a,v=d||\"outside\"===a;if(g||v){var m=u(i,\"textfont\",r.font),y=n.extendFlat({},m);!(t.textfont&&t.textfont.color)&&delete y.color,u(i,\"insidetextfont\",y),v&&u(i,\"outsidetextfont\",m),s&&i(\"selected.textfont.color\"),l&&i(\"unselected.textfont.color\"),c&&i(\"constraintext\"),h&&i(\"cliponaxis\"),f&&i(\"textangle\")}g&&p&&i(\"insidetextanchor\")}e.exports={supplyDefaults:function(t,e,r,l){function u(r,i){return n.coerce(t,e,c,r,i)}if(o(t,e,l,u)){u(\"orientation\",e.x&&!e.y?\"h\":\"v\"),u(\"base\"),u(\"offset\"),u(\"width\"),u(\"text\"),u(\"hovertext\"),u(\"hovertemplate\");var h=u(\"textposition\");f(t,0,l,u,h,{moduleHasSelected:!0,moduleHasUnselected:!0,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),s(t,e,u,r,l);var p=(e.marker.line||{}).color,d=a.getComponentMethod(\"errorbars\",\"supplyDefaults\");d(t,e,p||i.defaultLine,{axis:\"y\"}),d(t,e,p||i.defaultLine,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,u)}else e.visible=!1},crossTraceDefaults:function(t,e){var r;function i(t){return n.coerce(r._input,r,c,t)}if(\"group\"===e.barmode)for(var a=0;a<t.length;a++)\"bar\"===(r=t[a]).type&&(r._input,h(0,r,e,i))},handleGroupingDefaults:h,handleText:f}},{\"../../components/color\":593,\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../scatter/xy_defaults\":1137,\"./attributes\":857,\"./style_defaults\":871}],862:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../../lib\").isArrayOrTypedArray;r.coerceString=function(t,e,r){if(\"string\"==typeof e){if(e||!t.noBlank)return e}else if((\"number\"==typeof e||!0===e)&&!t.strict)return String(e);return void 0!==r?r:t.dflt},r.coerceNumber=function(t,e,r){if(n(e)){e=+e;var i=t.min,a=t.max;if(!(void 0!==i&&e<i||void 0!==a&&e>a))return e}return void 0!==r?r:t.dflt},r.coerceColor=function(t,e,r){return i(e).isValid()?e:void 0!==r?r:t.dflt},r.coerceEnumerated=function(t,e,r){return t.coerceNumber&&(e=+e),-1!==t.values.indexOf(e)?e:void 0!==r?r:t.dflt},r.getValue=function(t,e){var r;return Array.isArray(t)?e<t.length&&(r=t[e]):r=t,r},r.getLineWidth=function(t,e){return 0<e.mlw?e.mlw:a(t.marker.line.width)?0:t.marker.line.width}},{\"../../lib\":719,\"fast-isnumeric\":225,tinycolor2:537}],863:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../../lib\").fillText,s=t(\"./helpers\").getLineWidth;function l(t,e,r,i){var a,s,l,c,u,h,f,p=t.cd,d=p[0].trace,g=p[0].t,v=\"closest\"===i,m=\"waterfall\"===d.type,y=t.maxHoverDistance,x=t.maxSpikeDistance;function b(t){return t[l]-t.w/2}function _(t){return t[l]+t.w/2}var w=v?b:function(t){return Math.min(b(t),t.p-g.bardelta/2)},k=v?_:function(t){return Math.max(_(t),t.p+g.bardelta/2)};function T(t,e){return n.inbox(t-a,e-a,y+Math.min(1,Math.abs(e-t)/f)-1)}function A(t){return T(w(t),k(t))}function M(t){var e=s,r=t.b,i=t[c];return m&&(i+=Math.abs(t.rawS||0)),n.inbox(r-e,i-e,y+(i-e)/(i-r)-1)}\"h\"===d.orientation?(a=r,s=e,l=\"y\",c=\"x\",u=M,h=A):(a=e,s=r,l=\"x\",c=\"y\",h=M,u=A);var S=t[l+\"a\"],E=t[c+\"a\"];f=Math.abs(S.r2c(S.range[1])-S.r2c(S.range[0]));var C=n.getDistanceFunction(i,u,h,function(t){return(u(t)+h(t))/2});if(n.getClosest(p,C,t),!1!==t.index){v||(w=function(t){return Math.min(b(t),t.p-g.bargroupwidth/2)},k=function(t){return Math.max(_(t),t.p+g.bargroupwidth/2)});var L=p[t.index],P=d.base?L.b+L.s:L.s;t[c+\"0\"]=t[c+\"1\"]=E.c2p(L[c],!0),t[c+\"LabelVal\"]=P;var O=g.extents[g.extents.round(L.p)];return t[l+\"0\"]=S.c2p(v?w(L):O[0],!0),t[l+\"1\"]=S.c2p(v?k(L):O[1],!0),t[l+\"LabelVal\"]=L.p,t.spikeDistance=(M(L)+function(t){return T(b(t),_(t))}(L))/2+x-y,t[l+\"Spike\"]=S.c2p(L.p,!0),o(L,d,t),t.hovertemplate=d.hovertemplate,t}}function c(t,e){var r=e.mcc||t.marker.color,n=e.mlcc||t.marker.line.color,i=s(t,e);return a.opacity(r)?r:a.opacity(n)&&i?n:void 0}e.exports={hoverPoints:function(t,e,r,n){var a=l(t,e,r,n);if(a){var o=a.cd,s=o[0].trace,u=o[a.index];return a.color=c(s,u),i.getComponentMethod(\"errorbars\",\"hoverInfo\")(u,s,a),[a]}},hoverOnBars:l,getTraceColor:c}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"../../registry\":847,\"./helpers\":862}],864:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,colorbar:t(\"../scatter/marker_colorbar\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"bar\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"oriented\",\"errorBarsOK\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../scatter/marker_colorbar\":1129,\"./arrays_to_calcdata\":856,\"./attributes\":857,\"./calc\":858,\"./cross_trace_calc\":860,\"./defaults\":861,\"./hover\":863,\"./layout_attributes\":865,\"./layout_defaults\":866,\"./plot\":867,\"./select\":868,\"./style\":870}],865:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\",\"relative\"],dflt:\"group\",editType:\"calc\"},barnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},bargap:{valType:\"number\",min:0,max:1,editType:\"calc\"},bargroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],866:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\"),o=t(\"./layout_attributes\");e.exports=function(t,e,r){function s(r,n){return a.coerce(t,e,o,r,n)}for(var l=!1,c=!1,u=!1,h={},f=s(\"barmode\"),p=0;p<r.length;p++){var d=r[p];if(n.traceIs(d,\"bar\")&&d.visible){if(l=!0,\"group\"===f){var g=d.xaxis+d.yaxis;h[g]&&(u=!0),h[g]=!0}if(d.visible&&\"histogram\"===d.type)\"category\"!==i.getFromId({_fullLayout:e},d[\"v\"===d.orientation?\"xaxis\":\"yaxis\"]).type&&(c=!0)}}l?(\"overlay\"!==f&&s(\"barnorm\"),s(\"bargap\",c&&!u?0:.2),s(\"bargroupgap\")):delete e.barmode}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./layout_attributes\":865}],867:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../registry\"),u=t(\"../../plots/cartesian/axes\").tickText,h=t(\"./style\"),f=t(\"./helpers\"),p=t(\"./attributes\"),d=p.text,g=p.textposition,v=3;function m(t,e){return t<e?1:-1}function y(t){return\"auto\"===t?0:t}function x(t,e,r,n,i,a){var o=!!a.isHorizontal,s=!!a.constrained,l=a.angle||0,c=a.anchor||0,u=i.width,h=i.height,f=Math.abs(e-t),p=Math.abs(n-r),d=f>2*v&&p>2*v?v:0;f-=2*d,p-=2*d;var g=!1;if(!(\"auto\"===l)||u<=f&&h<=p||!(u>f||h>p)||(u>p||h>f)&&u<h==f<p||(g=!0),g){var x=p;p=f,f=x}var b=y(l),_=Math.abs(Math.sin(Math.PI/180*b)),w=Math.abs(Math.cos(Math.PI/180*b)),k=Math.max(f*w,p*_),T=Math.max(f*_,p*w),A=s?Math.min(k/u,T/h):Math.max(w,_);A=Math.min(1,A);var M=(t+e)/2,S=(r+n)/2;\"middle\"!==c&&(d+=.5*(A*(o!==g?h:u)*_+A*(o!==g?u:h)*w),o?(d*=m(t,e),M=\"start\"===c?t+d:e-d):(d*=m(r,n),S=\"start\"===c?r+d:n-d));return g&&(b+=90),{textX:(i.left+i.right)/2,textY:(i.top+i.bottom)/2,targetX:M,targetY:S,scale:A,rotate:b}}function b(t,e,r,n,i,a){var o,s=!!a.isHorizontal,l=!!a.constrained,c=a.angle||0,u=i.width,h=i.height,f=Math.abs(e-t),p=Math.abs(n-r);o=s?p>2*v?v:0:f>2*v?v:0;var d=1;l&&(d=s?Math.min(1,p/h):Math.min(1,f/u));var g=y(c);o+=.5*(d*(s?h:u)*Math.abs(Math.sin(Math.PI/180*g))+d*(s?u:h)*Math.abs(Math.cos(Math.PI/180*g)));var x=(t+e)/2,b=(r+n)/2;return s?x=e-o*m(e,t):b=n+o*m(r,n),{textX:(i.left+i.right)/2,textY:(i.top+i.bottom)/2,targetX:x,targetY:b,scale:d,rotate:g}}function _(t){var e,r=t.textX,n=t.textY,i=t.targetX,a=t.targetY,o=t.scale,s=t.rotate;return o<1?e=\"scale(\"+o+\") \":(o=1,e=\"\"),\"translate(\"+(i-o*r)+\" \"+(a-o*n)+\")\"+e+(s?\"rotate(\"+s+\" \"+r+\" \"+n+\") \":\"\")}e.exports={plot:function(t,e,r,p,y){var w=e.xaxis,k=e.yaxis,T=t._fullLayout;y||(y={mode:T.barmode,norm:T.barmode,gap:T.bargap,groupgap:T.bargroupgap});var A=a.makeTraceGroups(p,r,\"trace bars\").each(function(r){var c=n.select(this),p=r[0].trace,T=\"waterfall\"===p.type,A=\"funnel\"===p.type,M=\"bar\"===p.type||A,S=0;T&&p.connector.visible&&\"between\"===p.connector.mode&&(S=p.connector.line.width/2);var E=\"h\"===p.orientation,C=a.ensureSingle(c,\"g\",\"points\").selectAll(\"g.point\").data(a.identity);C.enter().append(\"g\").classed(\"point\",!0),C.exit().remove(),C.each(function(c,T){var A,C,L=n.select(this),P=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),n?[i,a]:[a,i]}(c,w,k,E),O=P[0][0],z=P[0][1],I=P[1][0],D=P[1][1],R=!(O!==z&&I!==D&&i(O)&&i(z)&&i(I)&&i(D));if(R&&M&&f.getLineWidth(p,c)&&(E?z-O==0:D-I==0)&&(R=!1),c.isBlank=R,S&&(E?(O-=m(O,z)*S,z+=m(O,z)*S):(I-=m(I,D)*S,D+=m(I,D)*S)),\"waterfall\"===p.type){if(!R){var F=p[c.dir].marker;A=F.line.width,C=F.color}}else A=f.getLineWidth(p,c),C=c.mc||p.marker.color;var B=n.round(A/2%1,2);function N(t){return 0===y.gap&&0===y.groupgap?n.round(Math.round(t)-B,2):t}if(!t._context.staticPlot){var j=s.opacity(C)<1||A>.01?N:function(t,e){return Math.abs(t-e)>=2?N(t):t>e?Math.ceil(t):Math.floor(t)};O=j(O,z),z=j(z,O),I=j(I,D),D=j(D,I)}a.ensureSingle(L,\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"d\",R?\"M0,0Z\":\"M\"+O+\",\"+I+\"V\"+D+\"H\"+z+\"V\"+I+\"Z\").call(l.setClipUrl,e.layerClipId,t),function(t,e,r,n,i,s,c,p,m,y){var w,k=e.xaxis,T=e.yaxis,A=t._fullLayout;function M(e,r,n){var i=a.ensureSingle(e,\"text\").text(r).attr({class:\"bartext bartext-\"+w,transform:\"\",\"text-anchor\":\"middle\",\"data-notex\":1}).call(l.font,n).call(o.convertToTspans,t);return i}var S=n[0].trace,E=\"h\"===S.orientation,C=function(t,e,r,n){var i,o=t[0].trace;return i=o.textinfo?function(t,e,r,n){var i=t[0].trace,o=\"h\"===i.orientation,s=\"waterfall\"===i.type,l=\"funnel\"===i.type;function c(t){var e=o?r:n;return u(e,+t,!0).text}var h,f,p=i.textinfo,d=t[e],g=p.split(\"+\"),v=[],m=function(t){return-1!==g.indexOf(t)};if(m(\"label\")&&v.push((f=t[e].p,u(o?n:r,f,!0).text)),m(\"text\")&&(0===(h=a.castOption(i,d.i,\"text\"))||h)&&v.push(h),s){var y=+d.rawS||d.s,x=d.v,b=x-y;m(\"initial\")&&v.push(c(b)),m(\"delta\")&&v.push(c(y)),m(\"final\")&&v.push(c(x))}if(l){m(\"value\")&&v.push(c(d.s));var _=0;m(\"percent initial\")&&_++,m(\"percent previous\")&&_++,m(\"percent total\")&&_++;var w=_>1;m(\"percent initial\")&&(h=a.formatPercent(d.begR),w&&(h+=\" of initial\"),v.push(h)),m(\"percent previous\")&&(h=a.formatPercent(d.difR),w&&(h+=\" of previous\"),v.push(h)),m(\"percent total\")&&(h=a.formatPercent(d.sumR),w&&(h+=\" of total\"),v.push(h))}return v.join(\"<br>\")}(t,e,r,n):f.getValue(o.text,e),f.coerceString(d,i)}(n,i,k,T);w=function(t,e){var r=f.getValue(t.textposition,e);return f.coerceEnumerated(g,r)}(S,i);var L=\"stack\"===y.mode||\"relative\"===y.mode,P=n[i],O=!L||P._outmost;if(C&&\"none\"!==w&&(!P.isBlank&&s!==c&&p!==m||\"auto\"!==w&&\"inside\"!==w)){var z=A.font,I=h.getBarColor(n[i],S),D=h.getInsideTextFont(S,i,z,I),R=h.getOutsideTextFont(S,i,z),F=r.datum();E?\"log\"===k.type&&F.s0<=0&&(s=k.range[0]<k.range[1]?0:k._length):\"log\"===T.type&&F.s0<=0&&(p=T.range[0]<T.range[1]?T._length:0);var B,N,j,U,V,q,H=Math.abs(c-s)-2*v,G=Math.abs(m-p)-2*v;if(\"outside\"===w&&(O||P.hasB||(w=\"inside\")),\"auto\"===w)if(O){w=\"inside\",B=M(r,C,D),N=l.bBox(B.node()),j=N.width,U=N.height;var Y=j>0&&U>0,W=j<=H&&U<=G,X=j<=G&&U<=H,Z=E?H>=j*(G/U):G>=U*(H/j);Y&&(W||X||Z)?w=\"inside\":(w=\"outside\",B.remove(),B=null)}else w=\"inside\";!B&&(B=M(r,C,\"outside\"===w?R:D),N=l.bBox(B.node()),j=N.width,U=N.height,j<=0||U<=0)?B.remove():(\"outside\"===w?(q=\"both\"===S.constraintext||\"outside\"===S.constraintext,V=_(b(s,c,p,m,N,{isHorizontal:E,constrained:q,angle:S.textangle}))):(q=\"both\"===S.constraintext||\"inside\"===S.constraintext,V=_(x(s,c,p,m,N,{isHorizontal:E,constrained:q,angle:S.textangle,anchor:S.insidetextanchor}))),B.attr(\"transform\",V))}else r.select(\"text\").remove()}(t,e,L,r,T,O,z,I,D,y),e.layerClipId&&l.hideOutsideRangePoint(c,L.select(\"text\"),w,k,p.xcalendar,p.ycalendar)});var L=!1===p.cliponaxis;l.setClipUrl(c,L?null:e.layerClipId,t)});c.getComponentMethod(\"errorbars\",\"plot\")(t,A,e)},getTransform:_,toMoveInsideBar:x,toMoveOutsideBar:b}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./attributes\":857,\"./helpers\":862,\"./style\":870,d3:163,\"fast-isnumeric\":225}],868:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=e.c2p(n?t.s0:t.p0,!0),o=e.c2p(n?t.s1:t.p1,!0),s=r.c2p(n?t.p0:t.s0,!0),l=r.c2p(n?t.p1:t.s1,!0);return i?[(a+o)/2,(s+l)/2]:n?[o,(s+l)/2]:[(a+o)/2,l]}e.exports=function(t,e){var r,i=t.cd,a=t.xaxis,o=t.yaxis,s=i[0].trace,l=\"funnel\"===s.type,c=\"h\"===s.orientation,u=[];if(!1===e)for(r=0;r<i.length;r++)i[r].selected=0;else for(r=0;r<i.length;r++){var h=i[r],f=\"ct\"in h?h.ct:n(h,a,o,c,l);e.contains(f,!1,r,t)?(u.push({pointNumber:r,x:a.c2d(h.x),y:o.c2d(h.y)}),h.selected=1):h.selected=0}return u}},{}],869:[function(t,e,r){\"use strict\";e.exports=a;var n=t(\"../../lib\").distinctVals,i=t(\"../../constants/numerical\").BADNUM;function a(t,e){this.traces=t,this.sepNegVal=e.sepNegVal,this.overlapNoMerge=e.overlapNoMerge;for(var r=1/0,a=[],o=0;o<t.length;o++){for(var s=t[o],l=0;l<s.length;l++){var c=s[l];c.p!==i&&a.push(c.p)}s[0]&&s[0].width1&&(r=Math.min(s[0].width1,r))}this.positions=a;var u=n(a);this.distinctPositions=u.vals,1===u.vals.length&&r!==1/0?this.minDiff=r:this.minDiff=Math.min(u.minDiff,r),this.binWidth=this.minDiff,this.bins={}}a.prototype.put=function(t,e){var r=this.getLabel(t,e),n=this.bins[r]||0;return this.bins[r]=n+e,n},a.prototype.get=function(t,e){var r=this.getLabel(t,e);return this.bins[r]||0},a.prototype.getLabel=function(t,e){return(e<0&&this.sepNegVal?\"v\":\"^\")+(this.overlapNoMerge?t:Math.round(t/this.binWidth))}},{\"../../constants/numerical\":695,\"../../lib\":719}],870:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../lib\"),s=t(\"../../registry\"),l=t(\"./attributes\"),c=l.textfont,u=l.insidetextfont,h=l.outsidetextfont,f=t(\"./helpers\");function p(t,e,r){a.pointStyle(t.selectAll(\"path\"),e,r),d(t,e,r)}function d(t,e,r){t.selectAll(\"text\").each(function(t){var i=n.select(this),o=g(i,t,e,r);a.font(i,o)})}function g(t,e,r,n){var i=n._fullLayout.font,a=r.textfont;if(t.classed(\"bartext-inside\")){var o=b(e,r);a=m(r,e.i,i,o)}else t.classed(\"bartext-outside\")&&(a=y(r,e.i,i));return a}function v(t,e,r){return x(c,t.textfont,e,r)}function m(t,e,r,n){var a=v(t,e,r);return(void 0===t._input.textfont||void 0===t._input.textfont.color||Array.isArray(t.textfont.color)&&void 0===t.textfont.color[e])&&(a={color:i.contrast(n),family:a.family,size:a.size}),x(u,t.insidetextfont,e,a)}function y(t,e,r){var n=v(t,e,r);return x(h,t.outsidetextfont,e,n)}function x(t,e,r,n){e=e||{};var i=f.getValue(e.family,r),a=f.getValue(e.size,r),o=f.getValue(e.color,r);return{family:f.coerceString(t.family,i,n.family),size:f.coerceNumber(t.size,a,n.size),color:f.coerceColor(t.color,o,n.color)}}function b(t,e){return\"waterfall\"===e.type?e[t.dir].marker.color:t.mc||e.marker.color}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.barlayer\").selectAll(\"g.trace\"),r=e.size(),i=t._fullLayout;e.style(\"opacity\",function(t){return t[0].trace.opacity}).each(function(t){(\"stack\"===i.barmode&&r>1||0===i.bargap&&0===i.bargroupgap&&!t[0].trace.marker.line.width)&&n.select(this).attr(\"shape-rendering\",\"crispEdges\")}),e.selectAll(\"g.points\").each(function(e){p(n.select(this),e[0].trace,t)}),s.getComponentMethod(\"errorbars\",\"style\")(e)},styleTextPoints:d,styleOnSelect:function(t,e,r){var i=e[0].trace;i.selectedpoints?function(t,e,r){a.selectedPointStyle(t.selectAll(\"path\"),e),function(t,e,r){t.each(function(t){var i,s=n.select(this);if(t.selected){i=o.extendFlat({},g(s,t,e,r));var l=e.selected.textfont&&e.selected.textfont.color;l&&(i.color=l),a.font(s,i)}else a.selectedTextStyle(s,e)})}(t.selectAll(\"text\"),e,r)}(r,i,t):(p(r,i,t),s.getComponentMethod(\"errorbars\",\"style\")(r))},getInsideTextFont:m,getOutsideTextFont:y,getBarColor:b}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../registry\":847,\"./attributes\":857,\"./helpers\":862,d3:163}],871:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s){r(\"marker.color\",o),i(t,\"marker\")&&a(t,e,s,r,{prefix:\"marker.\",cLetter:\"c\"}),r(\"marker.line.color\",n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,r,{prefix:\"marker.line.\",cLetter:\"c\"}),r(\"marker.line.width\"),r(\"marker.opacity\"),r(\"selected.marker.color\"),r(\"unselected.marker.color\")}},{\"../../components/color\":593,\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604}],872:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../scatterpolar/attributes\"),o=t(\"../bar/attributes\");e.exports={r:a.r,theta:a.theta,r0:a.r0,dr:a.dr,theta0:a.theta0,dtheta:a.dtheta,thetaunit:a.thetaunit,base:i({},o.base,{}),offset:i({},o.offset,{}),width:i({},o.width,{}),text:i({},o.text,{}),hovertext:i({},o.hovertext,{}),marker:o.marker,hoverinfo:a.hoverinfo,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../bar/attributes\":857,\"../scatterpolar/attributes\":1179}],873:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"../bar/arrays_to_calcdata\"),o=t(\"../bar/cross_trace_calc\").setGroupPositions,s=t(\"../scatter/calc_selection\"),l=t(\"../../registry\").traceIs,c=t(\"../../lib\").extendFlat;e.exports={calc:function(t,e){for(var r=t._fullLayout,o=e.subplot,l=r[o].radialaxis,c=r[o].angularaxis,u=l.makeCalcdata(e,\"r\"),h=c.makeCalcdata(e,\"theta\"),f=e._length,p=new Array(f),d=u,g=h,v=0;v<f;v++)p[v]={p:g[v],s:d[v]};function m(t){var r=e[t];void 0!==r&&(e[\"_\"+t]=Array.isArray(r)?c.makeCalcdata(e,t):c.d2c(r,e.thetaunit))}return\"linear\"===c.type&&(m(\"width\"),m(\"offset\")),n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),a(p,e),s(p,e),p},crossTraceCalc:function(t,e,r){for(var n=t.calcdata,i=[],a=0;a<n.length;a++){var s=n[a],u=s[0].trace;!0===u.visible&&l(u,\"bar\")&&u.subplot===r&&i.push(s)}var h=c({},e.radialaxis,{_id:\"x\"}),f=e.angularaxis;o(t,f,h,i,{mode:e.barmode,norm:e.barnorm,gap:e.bargap,groupgap:e.bargroupgap})}}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"../../lib\":719,\"../../registry\":847,\"../bar/arrays_to_calcdata\":856,\"../bar/cross_trace_calc\":860,\"../scatter/calc_selection\":1114}],874:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatterpolar/defaults\").handleRThetaDefaults,a=t(\"../bar/style_defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}i(t,e,s,l)?(l(\"thetaunit\"),l(\"base\"),l(\"offset\"),l(\"width\"),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),a(t,e,l,r,s),n.coerceSelectionMarkerOpacity(e,l)):e.visible=!1}},{\"../../lib\":719,\"../bar/style_defaults\":871,\"../scatterpolar/defaults\":1181,\"./attributes\":872}],875:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../bar/hover\").getTraceColor,o=i.fillText,s=t(\"../scatterpolar/hover\").makeHoverPointText,l=t(\"../../plots/polar/helpers\").isPtInsidePolygon;e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,h=t.subplot,f=h.radialAxis,p=h.angularAxis,d=h.vangles,g=d?l:i.isPtInsideSector,v=t.maxHoverDistance,m=p._period||2*Math.PI,y=Math.abs(f.g2p(Math.sqrt(e*e+r*r))),x=Math.atan2(r,e);f.range[0]>f.range[1]&&(x+=Math.PI);if(n.getClosest(c,function(t){return g(y,x,[t.rp0,t.rp1],[t.thetag0,t.thetag1],d)?v+Math.min(1,Math.abs(t.thetag1-t.thetag0)/m)-1+(t.rp1-y)/(t.rp1-t.rp0)-1:1/0},t),!1!==t.index){var b=c[t.index];t.x0=t.x1=b.ct[0],t.y0=t.y1=b.ct[1];var _=i.extendFlat({},b,{r:b.s,theta:b.p});return o(b,u,t),s(_,u,h,t),t.hovertemplate=u.hovertemplate,t.color=a(u,b),t.xLabelVal=t.yLabelVal=void 0,b.s<0&&(t.idealAlign=\"left\"),[t]}}},{\"../../components/fx\":632,\"../../lib\":719,\"../../plots/polar/helpers\":830,\"../bar/hover\":863,\"../scatterpolar/hover\":1182}],876:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"barpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"bar\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),colorbar:t(\"../scatter/marker_colorbar\"),style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),meta:{}}},{\"../../plots/polar\":831,\"../bar/select\":868,\"../bar/style\":870,\"../scatter/marker_colorbar\":1129,\"./attributes\":872,\"./calc\":873,\"./defaults\":874,\"./hover\":875,\"./layout_attributes\":877,\"./layout_defaults\":878,\"./plot\":879}],877:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},bargap:{valType:\"number\",dflt:.1,min:0,max:1,editType:\"calc\"}}},{}],878:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a,o={};function s(r,o){return n.coerce(t[a]||{},e[a],i,r,o)}for(var l=0;l<r.length;l++){var c=r[l];\"barpolar\"===c.type&&!0===c.visible&&(o[a=c.subplot]||(s(\"barmode\"),s(\"bargap\"),o[a]=1))}}},{\"../../lib\":719,\"./layout_attributes\":877}],879:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../components/drawing\"),s=t(\"../../plots/polar/helpers\");e.exports=function(t,e,r){var l=e.xaxis,c=e.yaxis,u=e.radialAxis,h=e.angularAxis,f=function(t){var e=t.cxx,r=t.cyy;if(t.vangles)return function(n,i,o,l){var c,u;a.angleDelta(o,l)>0?(c=o,u=l):(c=l,u=o);var h=s.findEnclosingVertexAngles(c,t.vangles)[0],f=s.findEnclosingVertexAngles(u,t.vangles)[1],p=[h,(c+u)/2,f];return s.pathPolygonAnnulus(n,i,c,u,p,e,r)};return function(t,n,i,o){return a.pathAnnulus(t,n,i,o,e,r)}}(e),p=e.layers.frontplot.select(\"g.barlayer\");a.makeTraceGroups(p,r,\"trace bars\").each(function(){var r=n.select(this),s=a.ensureSingle(r,\"g\",\"points\").selectAll(\"g.point\").data(a.identity);s.enter().append(\"g\").style(\"vector-effect\",\"non-scaling-stroke\").style(\"stroke-miterlimit\",2).classed(\"point\",!0),s.exit().remove(),s.each(function(t){var e,r=n.select(this),o=t.rp0=u.c2p(t.s0),s=t.rp1=u.c2p(t.s1),p=t.thetag0=h.c2g(t.p0),d=t.thetag1=h.c2g(t.p1);if(i(o)&&i(s)&&i(p)&&i(d)&&o!==s&&p!==d){var g=u.c2g(t.s1),v=(p+d)/2;t.ct=[l.c2p(g*Math.cos(v)),c.c2p(g*Math.sin(v))],e=f(o,s,p,d)}else e=\"M0,0Z\";a.ensureSingle(r,\"path\").attr(\"d\",e)}),o.setClipUrl(r,e._hasClipOnAxisFalse?e.clipIds.forTraces:null,t)})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../plots/polar/helpers\":830,d3:163,\"fast-isnumeric\":225}],880:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../bar/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../lib/extend\").extendFlat,l=n.marker,c=l.line;e.exports={y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},y0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},name:{valType:\"string\",editType:\"calc+clearAxisTypes\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),hovertemplate:o({}),whiskerwidth:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"calc\"},notched:{valType:\"boolean\",editType:\"calc\"},notchwidth:{valType:\"number\",min:0,max:.5,dflt:.25,editType:\"calc\"},boxpoints:{valType:\"enumerated\",values:[\"all\",\"outliers\",\"suspectedoutliers\",!1],dflt:\"outliers\",editType:\"calc\"},boxmean:{valType:\"enumerated\",values:[!0,\"sd\",!1],dflt:!1,editType:\"calc\"},jitter:{valType:\"number\",min:0,max:1,editType:\"calc\"},pointpos:{valType:\"number\",min:-2,max:2,editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},width:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},marker:{outliercolor:{valType:\"color\",dflt:\"rgba(0, 0, 0, 0)\",editType:\"style\"},symbol:s({},l.symbol,{arrayOk:!1,editType:\"plot\"}),opacity:s({},l.opacity,{arrayOk:!1,dflt:1,editType:\"style\"}),size:s({},l.size,{arrayOk:!1,editType:\"calc\"}),color:s({},l.color,{arrayOk:!1,editType:\"style\"}),line:{color:s({},c.color,{arrayOk:!1,dflt:a.defaultLine,editType:\"style\"}),width:s({},c.width,{arrayOk:!1,dflt:0,editType:\"style\"}),outliercolor:{valType:\"color\",editType:\"style\"},outlierwidth:{valType:\"number\",min:0,dflt:1,editType:\"style\"},editType:\"style\"},editType:\"plot\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,offsetgroup:i.offsetgroup,alignmentgroup:i.alignmentgroup,selected:{marker:n.selected.marker,editType:\"style\"},unselected:{marker:n.unselected.marker,editType:\"style\"},hoveron:{valType:\"flaglist\",flags:[\"boxes\",\"points\"],dflt:\"boxes+points\",editType:\"style\"}}},{\"../../components/color/attributes\":592,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../bar/attributes\":857,\"../scatter/attributes\":1112}],881:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=i._,o=t(\"../../plots/cartesian/axes\");function s(t,e,r){var n={text:\"tx\",hovertext:\"htx\"};for(var i in n)Array.isArray(e[i])&&(t[n[i]]=e[i][r])}function l(t,e){return t.v-e.v}function c(t){return t.v}e.exports=function(t,e){var r,u,h,f,p,d=t._fullLayout,g=o.getFromId(t,e.xaxis||\"x\"),v=o.getFromId(t,e.yaxis||\"y\"),m=[],y=\"violin\"===e.type?\"_numViolins\":\"_numBoxes\";\"h\"===e.orientation?(u=g,h=\"x\",f=v,p=\"y\"):(u=v,h=\"y\",f=g,p=\"x\");var x,b=u.makeCalcdata(e,h),_=function(t,e,r,a,o){if(e in t)return r.makeCalcdata(t,e);var s;s=e+\"0\"in t?t[e+\"0\"]:\"name\"in t&&(\"category\"===r.type||n(t.name)&&-1!==[\"linear\",\"log\"].indexOf(r.type)||i.isDateTime(t.name)&&\"date\"===r.type)?t.name:o;var l=\"multicategory\"===r.type?r.r2c_just_indices(s):r.d2c(s,0,t[e+\"calendar\"]);return a.map(function(){return l})}(e,p,f,b,d[y]),w=i.distinctVals(_),k=w.vals,T=w.minDiff/2,A=function(t,e){for(var r=t.length,n=new Array(r+1),i=0;i<r;i++)n[i]=t[i]-e;return n[r]=t[r-1]+e,n}(k,T),M=k.length,S=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=[];return e}(M);for(r=0;r<e._length;r++){var E=b[r];if(n(E)){var C=i.findBin(_[r],A);if(C>=0&&C<M){var L={v:E,i:r};s(L,e,r),S[C].push(L)}}}var P=\"all\"===(e.boxpoints||e.points)?i.identity:function(t){return t.v<x.lf||t.v>x.uf};for(r=0;r<M;r++)if(S[r].length>0){var O=S[r].sort(l),z=O.map(c),I=z.length;(x={}).pos=k[r],x.pts=O,x[p]=x.pos,x[h]=x.pts.map(function(t){return t.v}),x.min=z[0],x.max=z[I-1],x.mean=i.mean(z,I),x.sd=i.stdev(z,I,x.mean),x.q1=i.interp(z,.25),x.med=i.interp(z,.5),x.q3=i.interp(z,.75),x.lf=Math.min(x.q1,z[Math.min(i.findBin(2.5*x.q1-1.5*x.q3,z,!0)+1,I-1)]),x.uf=Math.max(x.q3,z[Math.max(i.findBin(2.5*x.q3-1.5*x.q1,z),0)]),x.lo=4*x.q1-3*x.q3,x.uo=4*x.q3-3*x.q1;var D=1.57*(x.q3-x.q1)/Math.sqrt(I);x.ln=x.med-D,x.un=x.med+D,x.pts2=O.filter(P),m.push(x)}!function(t,e){if(i.isArrayOrTypedArray(e.selectedpoints))for(var r=0;r<t.length;r++){for(var n=t[r].pts||[],a={},o=0;o<n.length;o++)a[n[o].i]=o;i.tagSelected(n,e,a)}}(m,e);var R=o.findExtremes(u,b,{padded:!0});return e._extremes[u._id]=R,m.length>0?(m[0].t={num:d[y],dPos:T,posLetter:p,valLetter:h,labels:{med:a(t,\"median:\"),min:a(t,\"min:\"),q1:a(t,\"q1:\"),q3:a(t,\"q3:\"),max:a(t,\"max:\"),mean:\"sd\"===e.boxmean?a(t,\"mean \\xb1 \\u03c3:\"):a(t,\"mean:\"),lf:a(t,\"lower fence:\"),uf:a(t,\"upper fence:\")}},d[y]++,m):[{t:{empty:!0}}]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"fast-isnumeric\":225}],882:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,o=[\"v\",\"h\"];function s(t,e,r,o){var s,l,c,u=e.calcdata,h=e._fullLayout,f=o._id,p=f.charAt(0),d=[],g=0;for(s=0;s<r.length;s++)for(c=u[r[s]],l=0;l<c.length;l++)d.push(c[l].pos),g+=(c[l].pts2||[]).length;if(d.length){var v=i.distinctVals(d),m=v.minDiff/2;n.minDtick(o,v.minDiff,v.vals[0],!0);var y=h[\"violin\"===t?\"_numViolins\":\"_numBoxes\"],x=\"group\"===h[t+\"mode\"]&&y>1,b=1-h[t+\"gap\"],_=1-h[t+\"groupgap\"];for(s=0;s<r.length;s++){var w,k,T,A,M,S,E=(c=u[r[s]])[0].trace,C=c[0].t,L=E.width,P=E.side;if(L)w=k=A=L/2,T=0;else if(w=m,x){var O=a(h,o._id)+E.orientation,z=(h._alignmentOpts[O]||{})[E.alignmentgroup]||{},I=Object.keys(z.offsetGroups||{}).length,D=I||y;k=w*b*_/D,T=2*w*(((I?E._offsetIndex:C.num)+.5)/D-.5)*b,A=w*b/D}else k=w*b*_,T=0,A=w;C.dPos=w,C.bPos=T,C.bdPos=k,C.wHover=A;var R,F,B,N,j,U,V=T+k,q=Boolean(L);if(\"positive\"===P?(M=w*(L?1:.5),R=V,S=R=T):\"negative\"===P?(M=R=T,S=w*(L?1:.5),F=V):(M=S=w,R=F=V),(E.boxpoints||E.points)&&g>0){var H=E.pointpos,G=E.jitter,Y=E.marker.size/2,W=0;H+G>=0&&((W=V*(H+G))>M?(q=!0,j=Y,B=W):W>R&&(j=Y,B=M)),W<=M&&(B=M);var X=0;H-G<=0&&((X=-V*(H-G))>S?(q=!0,U=Y,N=X):X>F&&(U=Y,N=S)),X<=S&&(N=S)}else B=M,N=S;var Z=new Array(c.length);for(l=0;l<c.length;l++)Z[l]=c[l].pos;E._extremes[f]=n.findExtremes(o,Z,{padded:q,vpadminus:N,vpadplus:B,ppadminus:{x:U,y:j}[p],ppadplus:{x:j,y:U}[p]})}}}e.exports={crossTraceCalc:function(t,e){for(var r=t.calcdata,n=e.xaxis,i=e.yaxis,a=0;a<o.length;a++){for(var l=o[a],c=\"h\"===l?i:n,u=[],h=0;h<r.length;h++){var f=r[h],p=f[0].t,d=f[0].trace;!0!==d.visible||\"box\"!==d.type&&\"candlestick\"!==d.type||p.empty||(d.orientation||\"v\")!==l||d.xaxis!==n._id||d.yaxis!==i._id||u.push(h)}s(\"box\",t,u,c)}},setPositionOffset:s}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_ids\":770}],883:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../bar/defaults\").handleGroupingDefaults,s=t(\"./attributes\");function l(t,e,r,a){var o,s,l=r(\"y\"),c=r(\"x\"),u=c&&c.length;if(l&&l.length)o=\"v\",u?s=Math.min(n.minRowLength(c),n.minRowLength(l)):(r(\"x0\"),s=n.minRowLength(l));else{if(!u)return void(e.visible=!1);o=\"h\",r(\"y0\"),s=n.minRowLength(c)}e._length=s,i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a),r(\"orientation\",o)}function c(t,e,r,i){var a=i.prefix,o=n.coerce2(t,e,s,\"marker.outliercolor\"),l=r(\"marker.line.outliercolor\"),c=r(a+\"points\",o||l?\"suspectedoutliers\":void 0);c?(r(\"jitter\",\"all\"===c?.3:0),r(\"pointpos\",\"all\"===c?-1.5:0),r(\"marker.symbol\"),r(\"marker.opacity\"),r(\"marker.size\"),r(\"marker.color\",e.line.color),r(\"marker.line.color\"),r(\"marker.line.width\"),\"suspectedoutliers\"===c&&(r(\"marker.line.outliercolor\",e.marker.color),r(\"marker.line.outlierwidth\")),r(\"selected.marker.color\"),r(\"unselected.marker.color\"),r(\"selected.marker.size\"),r(\"unselected.marker.size\"),r(\"text\"),r(\"hovertext\")):delete e.marker;var u=r(\"hoveron\");\"all\"!==u&&-1===u.indexOf(\"points\")||r(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,r)}e.exports={supplyDefaults:function(t,e,r,i){function o(r,i){return n.coerce(t,e,s,r,i)}l(t,e,o,i),!1!==e.visible&&(o(\"line.color\",(t.marker||{}).color||r),o(\"line.width\"),o(\"fillcolor\",a.addOpacity(e.line.color,.5)),o(\"whiskerwidth\"),o(\"boxmean\"),o(\"width\"),o(\"notched\",void 0!==t.notchwidth)&&o(\"notchwidth\"),c(t,e,o,{prefix:\"box\"}))},crossTraceDefaults:function(t,e){var r,i;function a(t){return n.coerce(i._input,i,s,t)}for(var l=0;l<t.length;l++){var c=(i=t[l]).type;\"box\"!==c&&\"violin\"!==c||(r=i._input,\"group\"===e[c+\"mode\"]&&o(r,i,e,a))}},handleSampleDefaults:l,handlePointsDefaults:c}},{\"../../components/color\":593,\"../../lib\":719,\"../../registry\":847,\"../bar/defaults\":861,\"./attributes\":880}],884:[function(t,e,r){\"use strict\";e.exports=function(t,e){return e.hoverOnBox&&(t.hoverOnBox=e.hoverOnBox),\"xVal\"in e&&(t.x=e.xVal),\"yVal\"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],885:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=i.fillText;function l(t,e,r,s){var l,c,u,h,f,p,d,g,v,m,y,x,b,_,w=t.cd,k=t.xa,T=t.ya,A=w[0].trace,M=w[0].t,S=\"violin\"===A.type,E=[],C=M.bdPos,L=M.wHover,P=function(t){return t.pos+M.bPos-p};S&&\"both\"!==A.side?(\"positive\"===A.side&&(v=function(t){var e=P(t);return a.inbox(e,e+L,m)},x=C,b=0),\"negative\"===A.side&&(v=function(t){var e=P(t);return a.inbox(e-L,e,m)},x=0,b=C)):(v=function(t){var e=P(t);return a.inbox(e-L,e+L,m)},x=b=C),_=S?function(t){return a.inbox(t.span[0]-f,t.span[1]-f,m)}:function(t){return a.inbox(t.min-f,t.max-f,m)},\"h\"===A.orientation?(f=e,p=r,d=_,g=v,l=\"y\",u=T,c=\"x\",h=k):(f=r,p=e,d=v,g=_,l=\"x\",u=k,c=\"y\",h=T);var O=Math.min(1,C/Math.abs(u.r2c(u.range[1])-u.r2c(u.range[0])));function z(t){return(d(t)+g(t))/2}m=t.maxHoverDistance-O,y=t.maxSpikeDistance-O;var I=a.getDistanceFunction(s,d,g,z);if(a.getClosest(w,I,t),!1===t.index)return[];var D=w[t.index],R=A.line.color,F=(A.marker||{}).color;o.opacity(R)&&A.line.width?t.color=R:o.opacity(F)&&A.boxpoints?t.color=F:t.color=A.fillcolor,t[l+\"0\"]=u.c2p(D.pos+M.bPos-b,!0),t[l+\"1\"]=u.c2p(D.pos+M.bPos+x,!0),t[l+\"LabelVal\"]=D.pos;var B=l+\"Spike\";t.spikeDistance=z(D)*y/m,t[B]=u.c2p(D.pos,!0);var N={},j=[\"med\",\"q1\",\"q3\",\"min\",\"max\"];(A.boxmean||(A.meanline||{}).visible)&&j.push(\"mean\"),(A.boxpoints||A.points)&&j.push(\"lf\",\"uf\");for(var U=0;U<j.length;U++){var V=j[U];if(V in D&&!(D[V]in N)){N[D[V]]=!0;var q=D[V],H=h.c2p(q,!0),G=i.extendFlat({},t);G.attr=V,G[c+\"0\"]=G[c+\"1\"]=H,G[c+\"LabelVal\"]=q,G[c+\"Label\"]=(M.labels?M.labels[V]+\" \":\"\")+n.hoverLabelText(h,q),G.hoverOnBox=!0,\"mean\"===V&&\"sd\"in D&&\"sd\"===A.boxmean&&(G[c+\"err\"]=D.sd),t.name=\"\",t.spikeDistance=void 0,t[B]=void 0,G.hovertemplate=!1,E.push(G)}}return E}function c(t,e,r){for(var n,o,l,c=t.cd,u=t.xa,h=t.ya,f=c[0].trace,p=u.c2p(e),d=h.c2p(r),g=a.quadrature(function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(u.c2p(t.x)-p)-e,1-3/e)},function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(h.c2p(t.y)-d)-e,1-3/e)}),v=!1,m=0;m<c.length;m++){o=c[m];for(var y=0;y<(o.pts||[]).length;y++){var x=g(l=o.pts[y]);x<=t.distance&&(t.distance=x,v=[m,y])}}if(!v)return!1;l=(o=c[v[0]]).pts[v[1]];var b,_=u.c2p(l.x,!0),w=h.c2p(l.y,!0),k=l.mrc||1;return n=i.extendFlat({},t,{index:l.i,color:(f.marker||{}).color,name:f.name,x0:_-k,x1:_+k,y0:w-k,y1:w+k,spikeDistance:t.distance,hovertemplate:f.hovertemplate}),\"h\"===f.orientation?(b=h,n.xLabelVal=l.x,n.yLabelVal=o.pos):(b=u,n.xLabelVal=o.pos,n.yLabelVal=l.y),n[b._id.charAt(0)+\"Spike\"]=b.c2p(o.pos,!0),s(l,f,n),n}e.exports={hoverPoints:function(t,e,r,n){var i,a=t.cd[0].trace.hoveron,o=[];return-1!==a.indexOf(\"boxes\")&&(o=o.concat(l(t,e,r,n))),-1!==a.indexOf(\"points\")&&(i=c(t,e,r)),\"closest\"===n?i?[i]:o:i?(o.push(i),o):o},hoverOnBoxes:l,hoverOnPoints:c}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],886:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\").supplyLayoutDefaults,calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"box\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"boxLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":880,\"./calc\":881,\"./cross_trace_calc\":882,\"./defaults\":883,\"./event_data\":884,\"./hover\":885,\"./layout_attributes\":887,\"./layout_defaults\":888,\"./plot\":889,\"./select\":890,\"./style\":891}],887:[function(t,e,r){\"use strict\";e.exports={boxmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"overlay\",editType:\"calc\"},boxgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"},boxgroupgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"}}},{}],888:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./layout_attributes\");function o(t,e,r,i,a){for(var o=a+\"Layout\",s=!1,l=0;l<r.length;l++){var c=r[l];if(n.traceIs(c,o)){s=!0;break}}s&&(i(a+\"mode\"),i(a+\"gap\"),i(a+\"groupgap\"))}e.exports={supplyLayoutDefaults:function(t,e,r){o(0,0,r,function(r,n){return i.coerce(t,e,a,r,n)},\"box\")},_supply:o}},{\"../../lib\":719,\"../../registry\":847,\"./layout_attributes\":887}],889:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=5,s=.01;function l(t,e,r,a){var o,s,l=e.pos,c=e.val,u=a.bPos,h=a.wdPos||0,f=a.bPosPxOffset||0,p=r.whiskerwidth||0,d=r.notched||!1,g=d?1-2*r.notchwidth:1;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var v=t.selectAll(\"path.box\").data(\"violin\"!==r.type||r.box.visible?i.identity:[]);v.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"box\"),v.exit().remove(),v.each(function(t){if(t.empty)return\"M0,0Z\";var e=t.pos,a=l.c2p(e+u,!0)+f,v=l.c2p(e+u-o,!0)+f,m=l.c2p(e+u+s,!0)+f,y=l.c2p(e+u-h,!0)+f,x=l.c2p(e+u+h,!0)+f,b=l.c2p(e+u-o*g,!0)+f,_=l.c2p(e+u+s*g,!0)+f,w=c.c2p(t.q1,!0),k=c.c2p(t.q3,!0),T=i.constrain(c.c2p(t.med,!0),Math.min(w,k)+1,Math.max(w,k)-1),A=void 0===t.lf||!1===r.boxpoints,M=c.c2p(A?t.min:t.lf,!0),S=c.c2p(A?t.max:t.uf,!0),E=c.c2p(t.ln,!0),C=c.c2p(t.un,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+T+\",\"+b+\"V\"+_+\"M\"+w+\",\"+v+\"V\"+m+(d?\"H\"+E+\"L\"+T+\",\"+_+\"L\"+C+\",\"+m:\"\")+\"H\"+k+\"V\"+v+(d?\"H\"+C+\"L\"+T+\",\"+b+\"L\"+E+\",\"+v:\"\")+\"ZM\"+w+\",\"+a+\"H\"+M+\"M\"+k+\",\"+a+\"H\"+S+(0===p?\"\":\"M\"+M+\",\"+y+\"V\"+x+\"M\"+S+\",\"+y+\"V\"+x)):n.select(this).attr(\"d\",\"M\"+b+\",\"+T+\"H\"+_+\"M\"+v+\",\"+w+\"H\"+m+(d?\"V\"+E+\"L\"+_+\",\"+T+\"L\"+m+\",\"+C:\"\")+\"V\"+k+\"H\"+v+(d?\"V\"+C+\"L\"+b+\",\"+T+\"L\"+v+\",\"+E:\"\")+\"ZM\"+a+\",\"+w+\"V\"+M+\"M\"+a+\",\"+k+\"V\"+S+(0===p?\"\":\"M\"+y+\",\"+M+\"H\"+x+\"M\"+y+\",\"+S+\"H\"+x))})}function c(t,e,r,n){var l=e.x,c=e.y,u=n.bdPos,h=n.bPos,f=r.boxpoints||r.points;i.seedPseudoRandom();var p=t.selectAll(\"g.points\").data(f?function(t){return t.forEach(function(t){t.t=n,t.trace=r}),t}:[]);p.enter().append(\"g\").attr(\"class\",\"points\"),p.exit().remove();var d=p.selectAll(\"path\").data(function(t){var e,n,a=t.pts2,l=Math.max((t.max-t.min)/10,t.q3-t.q1),c=1e-9*l,p=l*s,d=[],g=0;if(r.jitter){if(0===l)for(g=1,d=new Array(a.length),e=0;e<a.length;e++)d[e]=1;else for(e=0;e<a.length;e++){var v=Math.max(0,e-o),m=a[v].v,y=Math.min(a.length-1,e+o),x=a[y].v;\"all\"!==f&&(a[e].v<t.lf?x=Math.min(x,t.lf):m=Math.max(m,t.uf));var b=Math.sqrt(p*(y-v)/(x-m+c))||0;b=i.constrain(Math.abs(b),0,1),d.push(b),g=Math.max(b,g)}n=2*r.jitter/(g||1)}for(e=0;e<a.length;e++){var _=a[e],w=_.v,k=r.jitter?n*d[e]*(i.pseudoRandom()-.5):0,T=t.pos+h+u*(r.pointpos+k);\"h\"===r.orientation?(_.y=T,_.x=w):(_.x=T,_.y=w),\"suspectedoutliers\"===f&&w<t.uo&&w>t.lo&&(_.so=!0)}return a});d.enter().append(\"path\").classed(\"point\",!0),d.exit().remove(),d.call(a.translatePoints,l,c)}function u(t,e,r,a){var o,s,l=e.pos,c=e.val,u=a.bPos,h=a.bPosPxOffset||0,f=r.boxmean||(r.meanline||{}).visible;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var p=t.selectAll(\"path.mean\").data(\"box\"===r.type&&r.boxmean||\"violin\"===r.type&&r.box.visible&&r.meanline.visible?i.identity:[]);p.enter().append(\"path\").attr(\"class\",\"mean\").style({fill:\"none\",\"vector-effect\":\"non-scaling-stroke\"}),p.exit().remove(),p.each(function(t){var e=l.c2p(t.pos+u,!0)+h,i=l.c2p(t.pos+u-o,!0)+h,a=l.c2p(t.pos+u+s,!0)+h,p=c.c2p(t.mean,!0),d=c.c2p(t.mean-t.sd,!0),g=c.c2p(t.mean+t.sd,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+p+\",\"+i+\"V\"+a+(\"sd\"===f?\"m0,0L\"+d+\",\"+e+\"L\"+p+\",\"+i+\"L\"+g+\",\"+e+\"Z\":\"\")):n.select(this).attr(\"d\",\"M\"+i+\",\"+p+\"H\"+a+(\"sd\"===f?\"m0,0L\"+e+\",\"+d+\"L\"+i+\",\"+p+\"L\"+e+\",\"+g+\"Z\":\"\"))})}e.exports={plot:function(t,e,r,a){var o=e.xaxis,s=e.yaxis;i.makeTraceGroups(a,r,\"trace boxes\").each(function(t){var e,r,i=n.select(this),a=t[0],h=a.t,f=a.trace;h.wdPos=h.bdPos*f.whiskerwidth,!0!==f.visible||h.empty?i.remove():(\"h\"===f.orientation?(e=s,r=o):(e=o,r=s),l(i,{pos:e,val:r},f,h),c(i,{x:o,y:s},f,h),u(i,{pos:e,val:r},f,h))})},plotBoxAndWhiskers:l,plotPoints:c,plotBoxMean:u}},{\"../../components/drawing\":614,\"../../lib\":719,d3:163}],890:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i=t.cd,a=t.xaxis,o=t.yaxis,s=[];if(!1===e)for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++)i[r].pts[n].selected=0;else for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++){var l=i[r].pts[n],c=a.c2p(l.x),u=o.c2p(l.y);e.contains([c,u],null,l.i,t)?(s.push({pointNumber:l.i,x:a.c2d(l.x),y:o.c2d(l.y)}),l.selected=1):l.selected=0}return s}},{}],891:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\");e.exports={style:function(t,e,r){var o=r||n.select(t).selectAll(\"g.trace.boxes\");o.style(\"opacity\",function(t){return t[0].trace.opacity}),o.each(function(e){var r=n.select(this),o=e[0].trace,s=o.line.width;function l(t,e,r,n){t.style(\"stroke-width\",e+\"px\").call(i.stroke,r).call(i.fill,n)}var c=r.selectAll(\"path.box\");if(\"candlestick\"===o.type)c.each(function(t){if(!t.empty){var e=n.select(this),r=o[t.dir];l(e,r.line.width,r.line.color,r.fillcolor),e.style(\"opacity\",o.selectedpoints&&!t.selected?.3:1)}});else{l(c,s,o.line.color,o.fillcolor),r.selectAll(\"path.mean\").style({\"stroke-width\":s,\"stroke-dasharray\":2*s+\"px,\"+s+\"px\"}).call(i.stroke,o.line.color);var u=r.selectAll(\"path.point\");a.pointStyle(u,o,t)}})},styleOnSelect:function(t,e,r){var n=e[0].trace,i=r.selectAll(\"path.point\");n.selectedpoints?a.selectedPointStyle(i,n):a.pointStyle(i,n,t)}}},{\"../../components/color\":593,\"../../components/drawing\":614,d3:163}],892:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../ohlc/attributes\"),a=t(\"../box/attributes\");function o(t){return{line:{color:n({},a.line.color,{dflt:t}),width:a.line.width,editType:\"style\"},fillcolor:a.fillcolor,editType:\"style\"}}e.exports={x:i.x,open:i.open,high:i.high,low:i.low,close:i.close,line:{width:n({},a.line.width,{}),editType:\"style\"},increasing:o(i.increasing.line.color.dflt),decreasing:o(i.decreasing.line.color.dflt),text:i.text,hovertext:i.hovertext,whiskerwidth:n({},a.whiskerwidth,{dflt:0}),hoverlabel:i.hoverlabel}},{\"../../lib\":719,\"../box/attributes\":880,\"../ohlc/attributes\":1058}],893:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../ohlc/calc\").calcCommon;function o(t,e,r,n){return{min:r,q1:Math.min(t,n),med:n,q3:Math.max(t,n),max:e}}e.exports=function(t,e){var r=t._fullLayout,s=i.getFromId(t,e.xaxis),l=i.getFromId(t,e.yaxis),c=s.makeCalcdata(e,\"x\"),u=a(t,e,c,l,o);return u.length?(n.extendFlat(u[0].t,{num:r._numBoxes,dPos:n.distinctVals(c).minDiff/2,posLetter:\"x\",valLetter:\"y\"}),r._numBoxes++,u):[{t:{empty:!0}}]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../ohlc/calc\":1059}],894:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../ohlc/ohlc_defaults\"),o=t(\"./attributes\");function s(t,e,r,n){var a=r(n+\".line.color\");r(n+\".line.width\",e.line.width),r(n+\".fillcolor\",i.addOpacity(a,.5))}e.exports=function(t,e,r,i){function l(r,i){return n.coerce(t,e,o,r,i)}a(t,e,l,i)?(l(\"line.width\"),s(t,e,l,\"increasing\"),s(t,e,l,\"decreasing\"),l(\"text\"),l(\"hovertext\"),l(\"whiskerwidth\"),i._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../components/color\":593,\"../../lib\":719,\"../ohlc/ohlc_defaults\":1063,\"./attributes\":892}],895:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"candlestick\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\",\"candlestick\",\"boxLayout\"],meta:{},attributes:t(\"./attributes\"),layoutAttributes:t(\"../box/layout_attributes\"),supplyLayoutDefaults:t(\"../box/layout_defaults\").supplyLayoutDefaults,crossTraceCalc:t(\"../box/cross_trace_calc\").crossTraceCalc,supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"../box/plot\").plot,layerName:\"boxlayer\",style:t(\"../box/style\").style,hoverPoints:t(\"../ohlc/hover\").hoverPoints,selectPoints:t(\"../ohlc/select\")}},{\"../../plots/cartesian\":778,\"../box/cross_trace_calc\":882,\"../box/layout_attributes\":887,\"../box/layout_defaults\":888,\"../box/plot\":889,\"../box/style\":891,\"../ohlc/hover\":1061,\"../ohlc/select\":1065,\"./attributes\":892,\"./calc\":893,\"./defaults\":894}],896:[function(t,e,r){\"use strict\";var n=t(\"./axis_defaults\"),i=t(\"../../plot_api/plot_template\");e.exports=function(t,e,r,a,o){a(\"a\")||(a(\"da\"),a(\"a0\")),a(\"b\")||(a(\"db\"),a(\"b0\")),function(t,e,r,a){[\"aaxis\",\"baxis\"].forEach(function(o){var s=o.charAt(0),l=t[o]||{},c=i.newContainer(e,o),u={tickfont:\"x\",id:s+\"axis\",letter:s,font:e.font,name:o,data:t[s],calendar:e.calendar,dfltColor:a,bgColor:r.paper_bgcolor,fullLayout:r};n(l,c,u),c._categories=c._categories||[],t[o]||\"-\"===l.type||(t[o]={type:l.type})})}(t,e,r,o)}},{\"../../plot_api/plot_template\":757,\"./axis_defaults\":901}],897:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t){return function t(e,r){if(!n(e)||r>=10)return null;var i=1/0;var a=-1/0;var o=e.length;for(var s=0;s<o;s++){var l=e[s];if(n(l)){var c=t(l,r+1);c&&(i=Math.min(c[0],i),a=Math.max(c[1],a))}else i=Math.min(l,i),a=Math.max(l,a)}return[i,a]}(t,0)}},{\"../../lib\":719}],898:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./axis_attributes\"),a=t(\"../../components/color/attributes\"),o=n({editType:\"calc\"});o.family.dflt='\"Open Sans\", verdana, arial, sans-serif',o.size.dflt=12,o.color.dflt=a.defaultLine,e.exports={carpet:{valType:\"string\",editType:\"calc\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},a:{valType:\"data_array\",editType:\"calc\"},a0:{valType:\"number\",dflt:0,editType:\"calc\"},da:{valType:\"number\",dflt:1,editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},b0:{valType:\"number\",dflt:0,editType:\"calc\"},db:{valType:\"number\",dflt:1,editType:\"calc\"},cheaterslope:{valType:\"number\",dflt:1,editType:\"calc\"},aaxis:i,baxis:i,font:o,color:{valType:\"color\",dflt:a.defaultLine,editType:\"plot\"},transforms:void 0}},{\"../../components/color/attributes\":592,\"../../plots/font_attributes\":793,\"./axis_attributes\":900}],899:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,i){var a,o,s,l,c,u,h,f,p,d,g,v,m,y=n(r)?\"a\":\"b\",x=(\"a\"===y?t.aaxis:t.baxis).smoothing,b=\"a\"===y?t.a2i:t.b2j,_=\"a\"===y?r:i,w=\"a\"===y?i:r,k=\"a\"===y?e.a.length:e.b.length,T=\"a\"===y?e.b.length:e.a.length,A=Math.floor(\"a\"===y?t.b2j(w):t.a2i(w)),M=\"a\"===y?function(e){return t.evalxy([],e,A)}:function(e){return t.evalxy([],A,e)};x&&(s=Math.max(0,Math.min(T-2,A)),l=A-s,o=\"a\"===y?function(e,r){return t.dxydi([],e,s,r,l)}:function(e,r){return t.dxydj([],s,e,l,r)});var S=b(_[0]),E=b(_[1]),C=S<E?1:-1,L=1e-8*(E-S),P=C>0?Math.floor:Math.ceil,O=C>0?Math.ceil:Math.floor,z=C>0?Math.min:Math.max,I=C>0?Math.max:Math.min,D=P(S+L),R=O(E-L),F=[[h=M(S)]];for(a=D;a*C<R*C;a+=C)c=[],g=I(S,a),m=(v=z(E,a+C))-g,u=Math.max(0,Math.min(k-2,Math.floor(.5*(g+v)))),f=M(v),x&&(p=o(u,g-u),d=o(u,v-u),c.push([h[0]+p[0]/3*m,h[1]+p[1]/3*m]),c.push([f[0]-d[0]/3*m,f[1]-d[1]/3*m])),c.push(f),F.push(c),h=f;return F}},{\"../../lib\":719}],900:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../plots/cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").TIME_FORMAT_LINK;e.exports={color:{valType:\"color\",editType:\"calc\"},smoothing:{valType:\"number\",dflt:1,min:0,max:1.3,editType:\"calc\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"calc\"},font:n({editType:\"calc\"}),offset:{valType:\"number\",dflt:10,editType:\"calc\"},editType:\"calc\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"date\",\"category\"],dflt:\"-\",editType:\"calc\"},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"calc\"},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"calc\"},range:{valType:\"info_array\",editType:\"calc\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}]},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cheatertype:{valType:\"enumerated\",values:[\"index\",\"value\"],dflt:\"value\",editType:\"calc\"},tickmode:{valType:\"enumerated\",values:[\"linear\",\"array\"],dflt:\"array\",editType:\"calc\"},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},tickvals:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},showticklabels:{valType:\"enumerated\",values:[\"start\",\"end\",\"both\",\"none\"],dflt:\"start\",editType:\"calc\"},tickfont:n({editType:\"calc\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"calc\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"calc\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"calc\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"calc\"},tickformatstops:o(a.tickformatstops,\"calc\",\"from-root\"),categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},labelpadding:{valType:\"integer\",dflt:10,editType:\"calc\"},labelprefix:{valType:\"string\",editType:\"calc\"},labelsuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showline:{valType:\"boolean\",dflt:!1,editType:\"calc\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"calc\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},gridcolor:{valType:\"color\",editType:\"calc\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},showgrid:{valType:\"boolean\",dflt:!0,editType:\"calc\"},minorgridcount:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},minorgridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},minorgridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"calc\"},startline:{valType:\"boolean\",editType:\"calc\"},startlinecolor:{valType:\"color\",editType:\"calc\"},startlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endline:{valType:\"boolean\",editType:\"calc\"},endlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endlinecolor:{valType:\"color\",editType:\"calc\"},tick0:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},dtick:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},arraytick0:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},arraydtick:{valType:\"integer\",min:1,dflt:1,editType:\"calc\"},_deprecated:{title:{valType:\"string\",editType:\"calc\"},titlefont:n({editType:\"calc\"}),titleoffset:{valType:\"number\",dflt:10,editType:\"calc\"}},editType:\"calc\"}},{\"../../components/color/attributes\":592,\"../../constants/docs\":690,\"../../plot_api/edit_types\":750,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/font_attributes\":793}],901:[function(t,e,r){\"use strict\";var n=t(\"./attributes\"),i=t(\"../../components/color\").addOpacity,a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/tick_value_defaults\"),l=t(\"../../plots/cartesian/tick_label_defaults\"),c=t(\"../../plots/cartesian/category_order_defaults\"),u=t(\"../../plots/cartesian/set_convert\"),h=t(\"../../plots/cartesian/axis_autotype\");e.exports=function(t,e,r){var f=r.letter,p=r.font||{},d=n[f+\"axis\"];function g(r,n){return o.coerce(t,e,d,r,n)}function v(r,n){return o.coerce2(t,e,d,r,n)}r.name&&(e._name=r.name,e._id=r.name);var m=g(\"type\");(\"-\"===m&&(r.data&&function(t,e){if(\"-\"!==t.type)return;var r=t._id.charAt(0),n=t[r+\"calendar\"];t.type=h(e,n)}(e,r.data),\"-\"===e.type?e.type=\"linear\":m=t.type=e.type),g(\"smoothing\"),g(\"cheatertype\"),g(\"showticklabels\"),g(\"labelprefix\",f+\" = \"),g(\"labelsuffix\"),g(\"showtickprefix\"),g(\"showticksuffix\"),g(\"separatethousands\"),g(\"tickformat\"),g(\"exponentformat\"),g(\"showexponent\"),g(\"categoryorder\"),g(\"tickmode\"),g(\"tickvals\"),g(\"ticktext\"),g(\"tick0\"),g(\"dtick\"),\"array\"===e.tickmode&&(g(\"arraytick0\"),g(\"arraydtick\")),g(\"labelpadding\"),e._hovertitle=f,\"date\"===m)&&a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",r.calendar);u(e,r.fullLayout),e.c2p=o.identity;var y=g(\"color\",r.dfltColor),x=y===t.color?y:p.color;g(\"title.text\")&&(o.coerceFont(g,\"title.font\",{family:p.family,size:Math.round(1.2*p.size),color:x}),g(\"title.offset\")),g(\"tickangle\"),g(\"autorange\",!e.isValidRange(t.range))&&g(\"rangemode\"),g(\"range\"),e.cleanRange(),g(\"fixedrange\"),s(t,e,g,m),l(t,e,g,m,r),c(t,e,g,{data:r.data,dataAttr:f});var b=v(\"gridcolor\",i(y,.3)),_=v(\"gridwidth\"),w=g(\"showgrid\");w||(delete e.gridcolor,delete e.gridwidth);var k=v(\"startlinecolor\",y),T=v(\"startlinewidth\",_);g(\"startline\",e.showgrid||!!k||!!T)||(delete e.startlinecolor,delete e.startlinewidth);var A=v(\"endlinecolor\",y),M=v(\"endlinewidth\",_);return g(\"endline\",e.showgrid||!!A||!!M)||(delete e.endlinecolor,delete e.endlinewidth),w?(g(\"minorgridcount\"),g(\"minorgridwidth\",_),g(\"minorgridcolor\",i(b,.06)),e.minorgridcount||(delete e.minorgridwidth,delete e.minorgridcolor)):(delete e.gridcolor,delete e.gridWidth),\"none\"===e.showticklabels&&(delete e.tickfont,delete e.tickangle,delete e.showexponent,delete e.exponentformat,delete e.tickformat,delete e.showticksuffix,delete e.showtickprefix),e.showticksuffix||delete e.ticksuffix,e.showtickprefix||delete e.tickprefix,g(\"tickmode\"),e}},{\"../../components/color\":593,\"../../lib\":719,\"../../plots/cartesian/axis_autotype\":768,\"../../plots/cartesian/category_order_defaults\":771,\"../../plots/cartesian/set_convert\":785,\"../../plots/cartesian/tick_label_defaults\":786,\"../../plots/cartesian/tick_value_defaults\":788,\"../../registry\":847,\"./attributes\":898}],902:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\").isArray1D,a=t(\"./cheater_basis\"),o=t(\"./array_minmax\"),s=t(\"./calc_gridlines\"),l=t(\"./calc_labels\"),c=t(\"./calc_clippath\"),u=t(\"../heatmap/clean_2d_array\"),h=t(\"./smooth_fill_2d_array\"),f=t(\"../heatmap/convert_column_xyz\"),p=t(\"./set_convert\");e.exports=function(t,e){var r=n.getFromId(t,e.xaxis),d=n.getFromId(t,e.yaxis),g=e.aaxis,v=e.baxis,m=e.x,y=e.y,x=[];m&&i(m)&&x.push(\"x\"),y&&i(y)&&x.push(\"y\"),x.length&&f(e,g,v,\"a\",\"b\",x);var b=e._a=e._a||e.a,_=e._b=e._b||e.b;m=e._x||e.x,y=e._y||e.y;var w={};if(e._cheater){var k=\"index\"===g.cheatertype?b.length:b,T=\"index\"===v.cheatertype?_.length:_;m=a(k,T,e.cheaterslope)}e._x=m=u(m),e._y=y=u(y),h(m,b,_),h(y,b,_),p(e),e.setScale();var A=o(m),M=o(y),S=.5*(A[1]-A[0]),E=.5*(A[1]+A[0]),C=.5*(M[1]-M[0]),L=.5*(M[1]+M[0]);return A=[E-1.3*S,E+1.3*S],M=[L-1.3*C,L+1.3*C],e._extremes[r._id]=n.findExtremes(r,A,{padded:!0}),e._extremes[d._id]=n.findExtremes(d,M,{padded:!0}),s(e,\"a\",\"b\"),s(e,\"b\",\"a\"),l(e,g),l(e,v),w.clipsegments=c(e._xctrl,e._yctrl,g,v),w.x=m,w.y=y,w.a=b,w.b=_,[w]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../heatmap/clean_2d_array\":1003,\"../heatmap/convert_column_xyz\":1005,\"./array_minmax\":897,\"./calc_clippath\":903,\"./calc_gridlines\":904,\"./calc_labels\":905,\"./cheater_basis\":907,\"./set_convert\":920,\"./smooth_fill_2d_array\":921}],903:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a,o,s=[],l=!!r.smoothing,c=!!n.smoothing,u=t[0].length-1,h=t.length-1;for(i=0,a=[],o=[];i<=u;i++)a[i]=t[0][i],o[i]=e[0][i];for(s.push({x:a,y:o,bicubic:l}),i=0,a=[],o=[];i<=h;i++)a[i]=t[i][u],o[i]=e[i][u];for(s.push({x:a,y:o,bicubic:c}),i=u,a=[],o=[];i>=0;i--)a[u-i]=t[h][i],o[u-i]=e[h][i];for(s.push({x:a,y:o,bicubic:l}),i=h,a=[],o=[];i>=0;i--)a[h-i]=t[i][0],o[h-i]=e[i][0];return s.push({x:a,y:o,bicubic:c}),s}},{}],904:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e,r){var a,o,s,l,c,u,h,f,p,d,g,v,m,y,x=t[\"_\"+e],b=t[e+\"axis\"],_=b._gridlines=[],w=b._minorgridlines=[],k=b._boundarylines=[],T=t[\"_\"+r],A=t[r+\"axis\"];\"array\"===b.tickmode&&(b.tickvals=x.slice());var M=t._xctrl,S=t._yctrl,E=M[0].length,C=M.length,L=t._a.length,P=t._b.length;n.prepTicks(b),\"array\"===b.tickmode&&delete b.tickvals;var O=b.smoothing?3:1;function z(n){var i,a,o,s,l,c,u,h,p,d,g,v,m=[],y=[],x={};if(\"b\"===e)for(a=t.b2j(n),o=Math.floor(Math.max(0,Math.min(P-2,a))),s=a-o,x.length=P,x.crossLength=L,x.xy=function(e){return t.evalxy([],e,a)},x.dxy=function(e,r){return t.dxydi([],e,o,r,s)},i=0;i<L;i++)c=Math.min(L-2,i),u=i-c,h=t.evalxy([],i,a),A.smoothing&&i>0&&(p=t.dxydi([],i-1,o,0,s),m.push(l[0]+p[0]/3),y.push(l[1]+p[1]/3),d=t.dxydi([],i-1,o,1,s),m.push(h[0]-d[0]/3),y.push(h[1]-d[1]/3)),m.push(h[0]),y.push(h[1]),l=h;else for(i=t.a2i(n),c=Math.floor(Math.max(0,Math.min(L-2,i))),u=i-c,x.length=L,x.crossLength=P,x.xy=function(e){return t.evalxy([],i,e)},x.dxy=function(e,r){return t.dxydj([],c,e,u,r)},a=0;a<P;a++)o=Math.min(P-2,a),s=a-o,h=t.evalxy([],i,a),A.smoothing&&a>0&&(g=t.dxydj([],c,a-1,u,0),m.push(l[0]+g[0]/3),y.push(l[1]+g[1]/3),v=t.dxydj([],c,a-1,u,1),m.push(h[0]-v[0]/3),y.push(h[1]-v[1]/3)),m.push(h[0]),y.push(h[1]),l=h;return x.axisLetter=e,x.axis=b,x.crossAxis=A,x.value=n,x.constvar=r,x.index=f,x.x=m,x.y=y,x.smoothing=A.smoothing,x}function I(n){var i,a,o,s,l,c=[],u=[],h={};if(h.length=x.length,h.crossLength=T.length,\"b\"===e)for(o=Math.max(0,Math.min(P-2,n)),l=Math.min(1,Math.max(0,n-o)),h.xy=function(e){return t.evalxy([],e,n)},h.dxy=function(e,r){return t.dxydi([],e,o,r,l)},i=0;i<E;i++)c[i]=M[n*O][i],u[i]=S[n*O][i];else for(a=Math.max(0,Math.min(L-2,n)),s=Math.min(1,Math.max(0,n-a)),h.xy=function(e){return t.evalxy([],n,e)},h.dxy=function(e,r){return t.dxydj([],a,e,s,r)},i=0;i<C;i++)c[i]=M[i][n*O],u[i]=S[i][n*O];return h.axisLetter=e,h.axis=b,h.crossAxis=A,h.value=x[n],h.constvar=r,h.index=n,h.x=c,h.y=u,h.smoothing=A.smoothing,h}if(\"array\"===b.tickmode){for(l=5e-15,u=(c=[Math.floor((x.length-1-b.arraytick0)/b.arraydtick*(1+l)),Math.ceil(-b.arraytick0/b.arraydtick/(1+l))].sort(function(t,e){return t-e}))[0]-1,h=c[1]+1,f=u;f<h;f++)(o=b.arraytick0+b.arraydtick*f)<0||o>x.length-1||_.push(i(I(o),{color:b.gridcolor,width:b.gridwidth}));for(f=u;f<h;f++)if(s=b.arraytick0+b.arraydtick*f,g=Math.min(s+b.arraydtick,x.length-1),!(s<0||s>x.length-1||g<0||g>x.length-1))for(v=x[s],m=x[g],a=0;a<b.minorgridcount;a++)(y=g-s)<=0||(d=v+(m-v)*(a+1)/(b.minorgridcount+1)*(b.arraydtick/y))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&k.push(i(I(0),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&k.push(i(I(x.length-1),{color:b.endlinecolor,width:b.endlinewidth}))}else{for(l=5e-15,u=(c=[Math.floor((x[x.length-1]-b.tick0)/b.dtick*(1+l)),Math.ceil((x[0]-b.tick0)/b.dtick/(1+l))].sort(function(t,e){return t-e}))[0],h=c[1],f=u;f<=h;f++)p=b.tick0+b.dtick*f,_.push(i(z(p),{color:b.gridcolor,width:b.gridwidth}));for(f=u-1;f<h+1;f++)for(p=b.tick0+b.dtick*f,a=0;a<b.minorgridcount;a++)(d=p+b.dtick*(a+1)/(b.minorgridcount+1))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&k.push(i(z(x[0]),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&k.push(i(z(x[x.length-1]),{color:b.endlinecolor,width:b.endlinewidth}))}}},{\"../../lib/extend\":710,\"../../plots/cartesian/axes\":767}],905:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e){var r,a,o,s=e._labels=[],l=e._gridlines;for(r=0;r<l.length;r++)o=l[r],-1!==[\"start\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{prefix:void 0,suffix:void 0,endAnchor:!0,xy:o.xy(0),dxy:o.dxy(0,0),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a)),-1!==[\"end\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{endAnchor:!1,xy:o.xy(o.crossLength-1),dxy:o.dxy(o.crossLength-2,1),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a))}},{\"../../lib/extend\":710,\"../../plots/cartesian/axes\":767}],906:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=t[0]-e[0],a=t[1]-e[1],o=r[0]-e[0],s=r[1]-e[1],l=Math.pow(i*i+a*a,.25),c=Math.pow(o*o+s*s,.25),u=(c*c*i-l*l*o)*n,h=(c*c*a-l*l*s)*n,f=c*(l+c)*3,p=l*(l+c)*3;return[[e[0]+(f&&u/f),e[1]+(f&&h/f)],[e[0]-(p&&u/p),e[1]-(p&&h/p)]]}},{}],907:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i,a,o,s,l,c,u=[],h=n(t)?t.length:t,f=n(e)?e.length:e,p=n(t)?t:null,d=n(e)?e:null;p&&(o=(p.length-1)/(p[p.length-1]-p[0])/(h-1)),d&&(s=(d.length-1)/(d[d.length-1]-d[0])/(f-1));var g=1/0,v=-1/0;for(a=0;a<f;a++)for(u[a]=[],l=d?(d[a]-d[0])*s:a/(f-1),i=0;i<h;i++)c=(p?(p[i]-p[0])*o:i/(h-1))-l*r,g=Math.min(c,g),v=Math.max(c,v),u[a][i]=c;var m=1/(v-g),y=-g*m;for(a=0;a<f;a++)for(i=0;i<h;i++)u[a][i]=m*u[a][i]+y;return u}},{\"../../lib\":719}],908:[function(t,e,r){\"use strict\";var n=t(\"./catmull_rom\"),i=t(\"../../lib\").ensureArray;function a(t,e,r){var n=-.5*r[0]+1.5*e[0],i=-.5*r[1]+1.5*e[1];return[(2*n+t[0])/3,(2*i+t[1])/3]}e.exports=function(t,e,r,o,s,l){var c,u,h,f,p,d,g,v,m,y,x=r[0].length,b=r.length,_=s?3*x-2:x,w=l?3*b-2:b;for(t=i(t,w),e=i(e,w),h=0;h<w;h++)t[h]=i(t[h],_),e[h]=i(e[h],_);for(u=0,f=0;u<b;u++,f+=l?3:1)for(p=t[f],d=e[f],g=r[u],v=o[u],c=0,h=0;c<x;c++,h+=s?3:1)p[h]=g[c],d[h]=v[c];if(s)for(u=0,f=0;u<b;u++,f+=l?3:1){for(c=1,h=3;c<x-1;c++,h+=3)m=n([r[u][c-1],o[u][c-1]],[r[u][c],o[u][c]],[r[u][c+1],o[u][c+1]],s),t[f][h-1]=m[0][0],e[f][h-1]=m[0][1],t[f][h+1]=m[1][0],e[f][h+1]=m[1][1];y=a([t[f][0],e[f][0]],[t[f][2],e[f][2]],[t[f][3],e[f][3]]),t[f][1]=y[0],e[f][1]=y[1],y=a([t[f][_-1],e[f][_-1]],[t[f][_-3],e[f][_-3]],[t[f][_-4],e[f][_-4]]),t[f][_-2]=y[0],e[f][_-2]=y[1]}if(l)for(h=0;h<_;h++){for(f=3;f<w-3;f+=3)m=n([t[f-3][h],e[f-3][h]],[t[f][h],e[f][h]],[t[f+3][h],e[f+3][h]],l),t[f-1][h]=m[0][0],e[f-1][h]=m[0][1],t[f+1][h]=m[1][0],e[f+1][h]=m[1][1];y=a([t[0][h],e[0][h]],[t[2][h],e[2][h]],[t[3][h],e[3][h]]),t[1][h]=y[0],e[1][h]=y[1],y=a([t[w-1][h],e[w-1][h]],[t[w-3][h],e[w-3][h]],[t[w-4][h],e[w-4][h]]),t[w-2][h]=y[0],e[w-2][h]=y[1]}if(s&&l)for(f=1;f<w;f+=(f+1)%3==0?2:1){for(h=3;h<_-3;h+=3)m=n([t[f][h-3],e[f][h-3]],[t[f][h],e[f][h]],[t[f][h+3],e[f][h+3]],s),t[f][h-1]=.5*(t[f][h-1]+m[0][0]),e[f][h-1]=.5*(e[f][h-1]+m[0][1]),t[f][h+1]=.5*(t[f][h+1]+m[1][0]),e[f][h+1]=.5*(e[f][h+1]+m[1][1]);y=a([t[f][0],e[f][0]],[t[f][2],e[f][2]],[t[f][3],e[f][3]]),t[f][1]=.5*(t[f][1]+y[0]),e[f][1]=.5*(e[f][1]+y[1]),y=a([t[f][_-1],e[f][_-1]],[t[f][_-3],e[f][_-3]],[t[f][_-4],e[f][_-4]]),t[f][_-2]=.5*(t[f][_-2]+y[0]),e[f][_-2]=.5*(e[f][_-2]+y[1])}return[t,e]}},{\"../../lib\":719,\"./catmull_rom\":906}],909:[function(t,e,r){\"use strict\";e.exports={RELATIVE_CULL_TOLERANCE:1e-6}},{}],910:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3,n*=3;var f=i*i,p=1-i,d=p*p,g=p*i*2,v=-3*d,m=3*(d-g),y=3*(g-f),x=3*f,b=a*a,_=b*a,w=1-a,k=w*w,T=k*w;for(h=0;h<t.length;h++)o=v*(u=t[h])[n][r]+m*u[n][r+1]+y*u[n][r+2]+x*u[n][r+3],s=v*u[n+1][r]+m*u[n+1][r+1]+y*u[n+1][r+2]+x*u[n+1][r+3],l=v*u[n+2][r]+m*u[n+2][r+1]+y*u[n+2][r+2]+x*u[n+2][r+3],c=v*u[n+3][r]+m*u[n+3][r+1]+y*u[n+3][r+2]+x*u[n+3][r+3],e[h]=T*o+3*(k*a*s+w*b*l)+_*c;return e}:e?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),r*=3;var u=i*i,h=1-i,f=h*h,p=h*i*2,d=-3*f,g=3*(f-p),v=3*(p-u),m=3*u,y=1-a;for(l=0;l<t.length;l++)o=d*(c=t[l])[n][r]+g*c[n][r+1]+v*c[n][r+2]+m*c[n][r+3],s=d*c[n+1][r]+g*c[n+1][r+1]+v*c[n+1][r+2]+m*c[n+1][r+3],e[l]=y*o+a*s;return e}:r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),n*=3;var f=a*a,p=f*a,d=1-a,g=d*d,v=g*d;for(u=0;u<t.length;u++)o=(h=t[u])[n][r+1]-h[n][r],s=h[n+1][r+1]-h[n+1][r],l=h[n+2][r+1]-h[n+2][r],c=h[n+3][r+1]-h[n+3][r],e[u]=v*o+3*(g*a*s+d*f*l)+p*c;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-a;for(l=0;l<t.length;l++)o=(c=t[l])[n][r+1]-c[n][r],s=c[n+1][r+1]-c[n+1][r],e[l]=u*o+a*s;return e}}},{}],911:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3,n*=3;var f=i*i,p=f*i,d=1-i,g=d*d,v=g*d,m=a*a,y=1-a,x=y*y,b=y*a*2,_=-3*x,w=3*(x-b),k=3*(b-m),T=3*m;for(h=0;h<t.length;h++)o=_*(u=t[h])[n][r]+w*u[n+1][r]+k*u[n+2][r]+T*u[n+3][r],s=_*u[n][r+1]+w*u[n+1][r+1]+k*u[n+2][r+1]+T*u[n+3][r+1],l=_*u[n][r+2]+w*u[n+1][r+2]+k*u[n+2][r+2]+T*u[n+3][r+2],c=_*u[n][r+3]+w*u[n+1][r+3]+k*u[n+2][r+3]+T*u[n+3][r+3],e[h]=v*o+3*(g*i*s+d*f*l)+p*c;return e}:e?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3;var f=a*a,p=f*a,d=1-a,g=d*d,v=g*d;for(u=0;u<t.length;u++)o=(h=t[u])[n+1][r]-h[n][r],s=h[n+1][r+1]-h[n][r+1],l=h[n+1][r+2]-h[n][r+2],c=h[n+1][r+3]-h[n][r+3],e[u]=v*o+3*(g*a*s+d*f*l)+p*c;return e}:r?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),n*=3;var u=1-i,h=a*a,f=1-a,p=f*f,d=f*a*2,g=-3*p,v=3*(p-d),m=3*(d-h),y=3*h;for(l=0;l<t.length;l++)o=g*(c=t[l])[n][r]+v*c[n+1][r]+m*c[n+2][r]+y*c[n+3][r],s=g*c[n][r+1]+v*c[n+1][r+1]+m*c[n+2][r+1]+y*c[n+3][r+1],e[l]=u*o+i*s;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-i;for(l=0;l<t.length;l++)o=(c=t[l])[n+1][r]-c[n][r],s=c[n+1][r+1]-c[n][r+1],e[l]=u*o+i*s;return e}}},{}],912:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=e-2,o=r-2;return n&&i?function(e,r,n){var i,s,l,c,u,h;e||(e=[]);var f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));f*=3,p*=3;var v=d*d,m=v*d,y=1-d,x=y*y,b=x*y,_=g*g,w=_*g,k=1-g,T=k*k,A=T*k;for(h=0;h<t.length;h++)i=b*(u=t[h])[p][f]+3*(x*d*u[p][f+1]+y*v*u[p][f+2])+m*u[p][f+3],s=b*u[p+1][f]+3*(x*d*u[p+1][f+1]+y*v*u[p+1][f+2])+m*u[p+1][f+3],l=b*u[p+2][f]+3*(x*d*u[p+2][f+1]+y*v*u[p+2][f+2])+m*u[p+2][f+3],c=b*u[p+3][f]+3*(x*d*u[p+3][f+1]+y*v*u[p+3][f+2])+m*u[p+3][f+3],e[h]=A*i+3*(T*g*s+k*_*l)+w*c;return e}:n?function(e,r,n){e||(e=[]);var i,s,l,c,u,h,f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));f*=3;var v=d*d,m=v*d,y=1-d,x=y*y,b=x*y,_=1-g;for(u=0;u<t.length;u++)i=_*(h=t[u])[p][f]+g*h[p+1][f],s=_*h[p][f+1]+g*h[p+1][f+1],l=_*h[p][f+2]+g*h[p+1][f+1],c=_*h[p][f+3]+g*h[p+1][f+1],e[u]=b*i+3*(x*d*s+y*v*l)+m*c;return e}:i?function(e,r,n){e||(e=[]);var i,s,l,c,u,h,f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));p*=3;var v=g*g,m=v*g,y=1-g,x=y*y,b=x*y,_=1-d;for(u=0;u<t.length;u++)i=_*(h=t[u])[p][f]+d*h[p][f+1],s=_*h[p+1][f]+d*h[p+1][f+1],l=_*h[p+2][f]+d*h[p+2][f+1],c=_*h[p+3][f]+d*h[p+3][f+1],e[u]=b*i+3*(x*g*s+y*v*l)+m*c;return e}:function(e,r,n){e||(e=[]);var i,s,l,c,u=Math.max(0,Math.min(Math.floor(r),a)),h=Math.max(0,Math.min(Math.floor(n),o)),f=Math.max(0,Math.min(1,r-u)),p=Math.max(0,Math.min(1,n-h)),d=1-p,g=1-f;for(l=0;l<t.length;l++)i=g*(c=t[l])[h][u]+f*c[h][u+1],s=g*c[h+1][u]+f*c[h+1][u+1],e[l]=d*i+p*s;return e}}},{}],913:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xy_defaults\"),a=t(\"./ab_defaults\"),o=t(\"./attributes\"),s=t(\"../../components/color/attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,o,r,i)}e._clipPathId=\"clip\"+e.uid+\"carpet\";var u=c(\"color\",s.defaultLine);(n.coerceFont(c,\"font\"),c(\"carpet\"),a(t,e,l,c,u),e.a&&e.b)?(e.a.length<3&&(e.aaxis.smoothing=0),e.b.length<3&&(e.baxis.smoothing=0),i(t,e,c)||(e.visible=!1),e._cheater&&c(\"cheaterslope\")):e.visible=!1}},{\"../../components/color/attributes\":592,\"../../lib\":719,\"./ab_defaults\":896,\"./attributes\":898,\"./xy_defaults\":922}],914:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),plot:t(\"./plot\"),calc:t(\"./calc\"),animatable:!0,isContainer:!0,moduleType:\"trace\",name:\"carpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"carpetAxis\",\"notLegendIsolatable\",\"noMultiCategory\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":898,\"./calc\":902,\"./defaults\":913,\"./plot\":919}],915:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r,n=t._fullData.length,i=0;i<n;i++){var a=t._fullData[i];if(a.index!==e.index&&(\"carpet\"===a.type&&(r||(r=a),a.carpet===e.carpet)))return a}return r}},{}],916:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(0===t.length)return\"\";var n,i=[],a=r?3:1;for(n=0;n<t.length;n+=a)i.push(t[n]+\",\"+e[n]),r&&n<t.length-a&&(i.push(\"C\"),i.push([t[n+1]+\",\"+e[n+1],t[n+2]+\",\"+e[n+2]+\" \"].join(\" \")));return i.join(r?\"\":\"L\")}},{}],917:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i;for(n(t)?t.length>e.length&&(t=t.slice(0,e.length)):t=[],i=0;i<e.length;i++)t[i]=r(e[i]);return t}},{\"../../lib\":719}],918:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i[0]*t.dpdx(e),s=i[1]*t.dpdy(r),l=1,c=1;if(a){var u=Math.sqrt(i[0]*i[0]+i[1]*i[1]),h=Math.sqrt(a[0]*a[0]+a[1]*a[1]),f=(i[0]*a[0]+i[1]*a[1])/u/h;c=Math.max(0,f)}var p=180*Math.atan2(s,o)/Math.PI;return p<-90?(p+=180,l=-l):p>90&&(p-=180,l=-l),{angle:p,flip:l,p:t.c2p(n,e,r),offsetMultplier:c}}},{}],919:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"./map_1d_array\"),o=t(\"./makepath\"),s=t(\"./orient_text\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib\"),u=t(\"../../constants/alignment\");function h(t,e,r,i,s,l){var c=\"const-\"+s+\"-lines\",u=r.selectAll(\".\"+c).data(l);u.enter().append(\"path\").classed(c,!0).style(\"vector-effect\",\"non-scaling-stroke\"),u.each(function(r){var i=r,s=i.x,l=i.y,c=a([],s,t.c2p),u=a([],l,e.c2p),h=\"M\"+o(c,u,i.smoothing);n.select(this).attr(\"d\",h).style(\"stroke-width\",i.width).style(\"stroke\",i.color).style(\"fill\",\"none\")}),u.exit().remove()}function f(t,e,r,a,o,c,u,h){var f=c.selectAll(\"text.\"+h).data(u);f.enter().append(\"text\").classed(h,!0);var p=0,d={};return f.each(function(o,c){var u;if(\"auto\"===o.axis.tickangle)u=s(a,e,r,o.xy,o.dxy);else{var h=(o.axis.tickangle+180)*Math.PI/180;u=s(a,e,r,o.xy,[Math.cos(h),Math.sin(h)])}c||(d={angle:u.angle,flip:u.flip});var f=(o.endAnchor?-1:1)*u.flip,g=n.select(this).attr({\"text-anchor\":f>0?\"start\":\"end\",\"data-notex\":1}).call(i.font,o.font).text(o.text).call(l.convertToTspans,t),v=i.bBox(this);g.attr(\"transform\",\"translate(\"+u.p[0]+\",\"+u.p[1]+\") rotate(\"+u.angle+\")translate(\"+o.axis.labelpadding*f+\",\"+.3*v.height+\")\"),p=Math.max(p,v.width+o.axis.labelpadding)}),f.exit().remove(),d.maxExtent=p,d}e.exports=function(t,e,r,i){var l=e.xaxis,u=e.yaxis,p=t._fullLayout._clips;c.makeTraceGroups(i,r,\"trace\").each(function(e){var r=n.select(this),i=e[0],d=i.trace,v=d.aaxis,m=d.baxis,y=c.ensureSingle(r,\"g\",\"minorlayer\"),x=c.ensureSingle(r,\"g\",\"majorlayer\"),b=c.ensureSingle(r,\"g\",\"boundarylayer\"),_=c.ensureSingle(r,\"g\",\"labellayer\");r.style(\"opacity\",d.opacity),h(l,u,x,v,\"a\",v._gridlines),h(l,u,x,m,\"b\",m._gridlines),h(l,u,y,v,\"a\",v._minorgridlines),h(l,u,y,m,\"b\",m._minorgridlines),h(l,u,b,v,\"a-boundary\",v._boundarylines),h(l,u,b,m,\"b-boundary\",m._boundarylines);var w=f(t,l,u,d,i,_,v._labels,\"a-label\"),k=f(t,l,u,d,i,_,m._labels,\"b-label\");!function(t,e,r,n,i,a,o,l){var u,h,f,p,d=c.aggNums(Math.min,null,r.a),v=c.aggNums(Math.max,null,r.a),m=c.aggNums(Math.min,null,r.b),y=c.aggNums(Math.max,null,r.b);u=.5*(d+v),h=m,f=r.ab2xy(u,h,!0),p=r.dxyda_rough(u,h),void 0===o.angle&&c.extendFlat(o,s(r,i,a,f,r.dxydb_rough(u,h)));g(t,e,r,n,f,p,r.aaxis,i,a,o,\"a-title\"),u=d,h=.5*(m+y),f=r.ab2xy(u,h,!0),p=r.dxydb_rough(u,h),void 0===l.angle&&c.extendFlat(l,s(r,i,a,f,r.dxyda_rough(u,h)));g(t,e,r,n,f,p,r.baxis,i,a,l,\"b-title\")}(t,_,d,i,l,u,w,k),function(t,e,r,n,i){var s,l,u,h,f=r.select(\"#\"+t._clipPathId);f.size()||(f=r.append(\"clipPath\").classed(\"carpetclip\",!0));var p=c.ensureSingle(f,\"path\",\"carpetboundary\"),d=e.clipsegments,g=[];for(h=0;h<d.length;h++)s=d[h],l=a([],s.x,n.c2p),u=a([],s.y,i.c2p),g.push(o(l,u,s.bicubic));var v=\"M\"+g.join(\"L\")+\"Z\";f.attr(\"id\",t._clipPathId),p.attr(\"d\",v)}(d,i,p,l,u)})};var p=u.LINE_SPACING,d=(1-u.MID_SHIFT)/p+1;function g(t,e,r,a,o,c,u,h,f,g,v){var m=[];u.title.text&&m.push(u.title.text);var y=e.selectAll(\"text.\"+v).data(m),x=g.maxExtent;y.enter().append(\"text\").classed(v,!0),y.each(function(){var e=s(r,h,f,o,c);-1===[\"start\",\"both\"].indexOf(u.showticklabels)&&(x=0);var a=u.title.font.size;x+=a+u.title.offset;var v=(g.angle+(g.flip<0?180:0)-e.angle+450)%360,m=v>90&&v<270,y=n.select(this);y.text(u.title.text).call(l.convertToTspans,t),m&&(x=(-l.lineCount(y)+d)*p*a-x),y.attr(\"transform\",\"translate(\"+e.p[0]+\",\"+e.p[1]+\") rotate(\"+e.angle+\") translate(0,\"+x+\")\").classed(\"user-select-none\",!0).attr(\"text-anchor\",\"middle\").call(i.font,u.title.font)}),y.exit().remove()}},{\"../../components/drawing\":614,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"./makepath\":916,\"./map_1d_array\":917,\"./orient_text\":918,d3:163}],920:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/search\").findBin,a=t(\"./compute_control_points\"),o=t(\"./create_spline_evaluator\"),s=t(\"./create_i_derivative_evaluator\"),l=t(\"./create_j_derivative_evaluator\");e.exports=function(t){var e=t._a,r=t._b,c=e.length,u=r.length,h=t.aaxis,f=t.baxis,p=e[0],d=e[c-1],g=r[0],v=r[u-1],m=e[e.length-1]-e[0],y=r[r.length-1]-r[0],x=m*n.RELATIVE_CULL_TOLERANCE,b=y*n.RELATIVE_CULL_TOLERANCE;p-=x,d+=x,g-=b,v+=b,t.isVisible=function(t,e){return t>p&&t<d&&e>g&&e<v},t.isOccluded=function(t,e){return t<p||t>d||e<g||e>v},t.setScale=function(){var e=t._x,r=t._y,n=a(t._xctrl,t._yctrl,e,r,h.smoothing,f.smoothing);t._xctrl=n[0],t._yctrl=n[1],t.evalxy=o([t._xctrl,t._yctrl],c,u,h.smoothing,f.smoothing),t.dxydi=s([t._xctrl,t._yctrl],h.smoothing,f.smoothing),t.dxydj=l([t._xctrl,t._yctrl],h.smoothing,f.smoothing)},t.i2a=function(t){var r=Math.max(0,Math.floor(t[0]),c-2),n=t[0]-r;return(1-n)*e[r]+n*e[r+1]},t.j2b=function(t){var e=Math.max(0,Math.floor(t[1]),c-2),n=t[1]-e;return(1-n)*r[e]+n*r[e+1]},t.ij2ab=function(e){return[t.i2a(e[0]),t.j2b(e[1])]},t.a2i=function(t){var r=Math.max(0,Math.min(i(t,e),c-2)),n=e[r],a=e[r+1];return Math.max(0,Math.min(c-1,r+(t-n)/(a-n)))},t.b2j=function(t){var e=Math.max(0,Math.min(i(t,r),u-2)),n=r[e],a=r[e+1];return Math.max(0,Math.min(u-1,e+(t-n)/(a-n)))},t.ab2ij=function(e){return[t.a2i(e[0]),t.b2j(e[1])]},t.i2c=function(e,r){return t.evalxy([],e,r)},t.ab2xy=function(n,i,a){if(!a&&(n<e[0]||n>e[c-1]|i<r[0]||i>r[u-1]))return[!1,!1];var o=t.a2i(n),s=t.b2j(i),l=t.evalxy([],o,s);if(a){var h,f,p,d,g=0,v=0,m=[];n<e[0]?(h=0,f=0,g=(n-e[0])/(e[1]-e[0])):n>e[c-1]?(h=c-2,f=1,g=(n-e[c-1])/(e[c-1]-e[c-2])):f=o-(h=Math.max(0,Math.min(c-2,Math.floor(o)))),i<r[0]?(p=0,d=0,v=(i-r[0])/(r[1]-r[0])):i>r[u-1]?(p=u-2,d=1,v=(i-r[u-1])/(r[u-1]-r[u-2])):d=s-(p=Math.max(0,Math.min(u-2,Math.floor(s)))),g&&(t.dxydi(m,h,p,f,d),l[0]+=m[0]*g,l[1]+=m[1]*g),v&&(t.dxydj(m,h,p,f,d),l[0]+=m[0]*v,l[1]+=m[1]*v)}return l},t.c2p=function(t,e,r){return[e.c2p(t[0]),r.c2p(t[1])]},t.p2x=function(t,e,r){return[e.p2c(t[0]),r.p2c(t[1])]},t.dadi=function(t){var r=Math.max(0,Math.min(e.length-2,t));return e[r+1]-e[r]},t.dbdj=function(t){var e=Math.max(0,Math.min(r.length-2,t));return r[e+1]-r[e]},t.dxyda=function(e,r,n,i){var a=t.dxydi(null,e,r,n,i),o=t.dadi(e,n);return[a[0]/o,a[1]/o]},t.dxydb=function(e,r,n,i){var a=t.dxydj(null,e,r,n,i),o=t.dbdj(r,i);return[a[0]/o,a[1]/o]},t.dxyda_rough=function(e,r,n){var i=m*(n||.1),a=t.ab2xy(e+i,r,!0),o=t.ab2xy(e-i,r,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dxydb_rough=function(e,r,n){var i=y*(n||.1),a=t.ab2xy(e,r+i,!0),o=t.ab2xy(e,r-i,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dpdx=function(t){return t._m},t.dpdy=function(t){return t._m}}},{\"../../lib/search\":738,\"./compute_control_points\":908,\"./constants\":909,\"./create_i_derivative_evaluator\":910,\"./create_j_derivative_evaluator\":911,\"./create_spline_evaluator\":912}],921:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r){var i,a,o,s=[],l=[],c=t[0].length,u=t.length;function h(e,r){var n,i=0,a=0;return e>0&&void 0!==(n=t[r][e-1])&&(a++,i+=n),e<c-1&&void 0!==(n=t[r][e+1])&&(a++,i+=n),r>0&&void 0!==(n=t[r-1][e])&&(a++,i+=n),r<u-1&&void 0!==(n=t[r+1][e])&&(a++,i+=n),i/Math.max(1,a)}var f,p,d,g,v,m,y,x,b,_,w,k=0;for(i=0;i<c;i++)for(a=0;a<u;a++)void 0===t[a][i]&&(s.push(i),l.push(a),t[a][i]=h(i,a)),k=Math.max(k,Math.abs(t[a][i]));if(!s.length)return t;var T=0,A=0,M=s.length;do{for(T=0,o=0;o<M;o++){i=s[o],a=l[o];var S,E,C,L,P,O,z=0,I=0;0===i?(C=e[P=Math.min(c-1,2)],L=e[1],S=t[a][P],I+=(E=t[a][1])+(E-S)*(e[0]-L)/(L-C),z++):i===c-1&&(C=e[P=Math.max(0,c-3)],L=e[c-2],S=t[a][P],I+=(E=t[a][c-2])+(E-S)*(e[c-1]-L)/(L-C),z++),(0===i||i===c-1)&&a>0&&a<u-1&&(f=r[a+1]-r[a],I+=((p=r[a]-r[a-1])*t[a+1][i]+f*t[a-1][i])/(p+f),z++),0===a?(C=r[O=Math.min(u-1,2)],L=r[1],S=t[O][i],I+=(E=t[1][i])+(E-S)*(r[0]-L)/(L-C),z++):a===u-1&&(C=r[O=Math.max(0,u-3)],L=r[u-2],S=t[O][i],I+=(E=t[u-2][i])+(E-S)*(r[u-1]-L)/(L-C),z++),(0===a||a===u-1)&&i>0&&i<c-1&&(f=e[i+1]-e[i],I+=((p=e[i]-e[i-1])*t[a][i+1]+f*t[a][i-1])/(p+f),z++),z?I/=z:(d=e[i+1]-e[i],g=e[i]-e[i-1],x=(v=r[a+1]-r[a])*(m=r[a]-r[a-1])*(v+m),I=((y=d*g*(d+g))*(m*t[a+1][i]+v*t[a-1][i])+x*(g*t[a][i+1]+d*t[a][i-1]))/(x*(g+d)+y*(m+v))),T+=(_=(b=I-t[a][i])/k)*_,w=z?0:.85,t[a][i]+=b*(1+w)}T=Math.sqrt(T)}while(A++<100&&T>1e-5);return n.log(\"Smoother converged to\",T,\"after\",A,\"iterations\"),t}},{\"../../lib\":719}],922:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArray1D;e.exports=function(t,e,r){var i=r(\"x\"),a=i&&i.length,o=r(\"y\"),s=o&&o.length;if(!a&&!s)return!1;if(e._cheater=!i,a&&!n(i)||s&&!n(o))e._length=null;else{var l=a?i.length:1/0;s&&(l=Math.min(l,o.length)),e.a&&e.a.length&&(l=Math.min(l,e.a.length)),e.b&&e.b.length&&(l=Math.min(l,e.b.length)),e._length=l}return!0}},{\"../../lib\":719}],923:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scattergeo/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/color/attributes\").defaultLine,l=t(\"../../lib/extend\").extendFlat,c=i.marker.line;e.exports=l({locations:{valType:\"data_array\",editType:\"calc\"},locationmode:i.locationmode,z:{valType:\"data_array\",editType:\"calc\"},text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),marker:{line:{color:l({},c.color,{dflt:s}),width:l({},c.width,{dflt:1}),editType:\"calc\"},opacity:{valType:\"number\",arrayOk:!0,min:0,max:1,dflt:1,editType:\"style\"},editType:\"calc\"},selected:{marker:{opacity:i.selected.marker.opacity,editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:i.unselected.marker.opacity,editType:\"plot\"},editType:\"plot\"},hoverinfo:l({},o.hoverinfo,{editType:\"calc\",flags:[\"location\",\"z\",\"text\",\"name\"]}),hovertemplate:n()},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/color/attributes\":592,\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scattergeo/attributes\":1151}],924:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../components/colorscale/calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\");function l(t){return t&&\"string\"==typeof t}e.exports=function(t,e){var r,c=e._length,u=new Array(c);r=e.geojson?function(t){return l(t)||n(t)}:l;for(var h=0;h<c;h++){var f=u[h]={},p=e.locations[h],d=e.z[h];r(p)&&n(d)?(f.loc=p,f.z=d):(f.loc=null,f.z=i),f.index=h}return o(u,e),a(t,e,{vals:e.z,containerStr:\"\",cLetter:\"z\"}),s(u,e),u}},{\"../../components/colorscale/calc\":601,\"../../constants/numerical\":695,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc_selection\":1114,\"fast-isnumeric\":225}],925:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\");l&&l.length&&n.isArrayOrTypedArray(c)&&c.length?(e._length=Math.min(l.length,c.length),s(\"locationmode\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":923}],926:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){t.location=e.location,t.z=e.z;var a=n[i];return a.fIn&&(t.properties=a.fIn.properties),t}},{}],927:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"./attributes\"),a=t(\"../../lib\").fillText;e.exports=function(t,e,r){var o,s,l,c,u=t.cd,h=u[0].trace,f=t.subplot;for(s=0;s<u.length;s++)if(c=!1,(o=u[s])._polygons){for(l=0;l<o._polygons.length;l++)o._polygons[l].contains([e,r])&&(c=!c),o._polygons[l].contains([e+360,r])&&(c=!c);if(c)break}if(c&&o)return t.x0=t.x1=t.xa.c2p(o.ct),t.y0=t.y1=t.ya.c2p(o.ct),t.index=o.index,t.location=o.loc,t.z=o.z,t.zLabel=n.tickText(f.mockAxis,f.mockAxis.c2l(o.z),\"hover\").text,t.hovertemplate=o.hovertemplate,function(t,e,r){if(e.hovertemplate)return;var n=r.hi||e.hoverinfo,o=\"all\"===n?i.hoverinfo.flags:n.split(\"+\"),s=-1!==o.indexOf(\"name\"),l=-1!==o.indexOf(\"location\"),c=-1!==o.indexOf(\"z\"),u=-1!==o.indexOf(\"text\"),h=[];!s&&l?t.nameOverride=r.loc:(s&&(t.nameOverride=e.name),l&&h.push(r.loc));c&&h.push(t.zLabel);u&&a(r,e,h);t.extraText=h.join(\"<br>\")}(t,h,o,f.mockAxis),[t]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./attributes\":923}],928:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"choropleth\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"noOpacity\"],meta:{}}},{\"../../plots/geo\":797,\"../heatmap/colorbar\":1004,\"./attributes\":923,\"./calc\":924,\"./defaults\":925,\"./event_data\":926,\"./hover\":927,\"./plot\":929,\"./select\":930,\"./style\":931}],929:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../lib/polygon\"),o=t(\"../../lib/topojson_utils\").getTopojsonFeatures,s=t(\"../../lib/geo_location_utils\").locationToFeature,l=t(\"./style\").style;function c(t,e){for(var r=t[0].trace,n=t.length,i=o(r,e),a=0;a<n;a++){var l=t[a],c=s(r.locationmode,l.loc,i);c?(l.geojson=c,l.ct=c.properties.ct,l._polygons=u(c)):l.geojson=null}}function u(t){var e,r,n,i,o=t.geometry,s=o.coordinates,l=t.id,c=[];function u(t){for(var e=0;e<t.length-1;e++)if(t[e][0]>0&&t[e+1][0]<0)return e;return null}switch(e=\"RUS\"===l||\"FJI\"===l?function(t){var e;if(null===u(t))e=t;else for(e=new Array(t.length),i=0;i<t.length;i++)e[i]=[t[i][0]<0?t[i][0]+360:t[i][0],t[i][1]];c.push(a.tester(e))}:\"ATA\"===l?function(t){var e=u(t);if(null===e)return c.push(a.tester(t));var r=new Array(t.length+1),n=0;for(i=0;i<t.length;i++)i>e?r[n++]=[t[i][0]+360,t[i][1]]:i===e?(r[n++]=t[i],r[n++]=[t[i][0],-90]):r[n++]=t[i];var o=a.tester(r);o.pts.pop(),c.push(o)}:function(t){c.push(a.tester(t))},o.type){case\"MultiPolygon\":for(r=0;r<s.length;r++)for(n=0;n<s[r].length;n++)e(s[r][n]);break;case\"Polygon\":for(r=0;r<s.length;r++)e(s[r])}return c}e.exports={plot:function(t,e,r){for(var a=0;a<r.length;a++)c(r[a],e.topojson);var o=e.layers.backplot.select(\".choroplethlayer\");i.makeTraceGroups(o,r,\"trace choropleth\").each(function(e){var r=n.select(this).selectAll(\"path.choroplethlocation\").data(i.identity);r.enter().append(\"path\").classed(\"choroplethlocation\",!0),r.exit().remove(),l(t,e)})},feature2polygons:u}},{\"../../lib\":719,\"../../lib/geo_location_utils\":713,\"../../lib/polygon\":731,\"../../lib/topojson_utils\":746,\"./style\":931,d3:163}],930:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)(i=(n=s[r]).ct)&&(a=l.c2p(i),o=c.c2p(i),e.contains([a,o],null,r,t)?(u.push({pointNumber:r,lon:i[0],lat:i[1]}),n.selected=1):n.selected=0);return u}},{}],931:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../components/colorscale\");function s(t,e){var r=e[0].trace,s=e[0].node3.selectAll(\".choroplethlocation\"),l=r.marker||{},c=l.line||{},u=o.makeColorScaleFuncFromTrace(r);s.each(function(t){n.select(this).attr(\"fill\",u(t.z)).call(i.stroke,t.mlc||c.color).call(a.dashLine,\"\",t.mlw||c.width||0).style(\"opacity\",l.opacity)}),a.selectedPointStyle(s,r,t)}e.exports={style:function(t,e){e&&s(t,e)},styleOnSelect:function(t,e){var r=e[0].node3,n=e[0].trace;n.selectedpoints?a.selectedPointStyle(r.selectAll(\".choroplethlocation\"),n,t):s(t,e)}}},{\"../../components/color\":593,\"../../components/colorscale\":605,\"../../components/drawing\":614,d3:163}],932:[function(t,e,r){\"use strict\";var n=t(\"../choropleth/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../lib/extend\").extendFlat;e.exports=o({locations:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},geojson:{valType:\"any\",editType:\"calc\"},below:{valType:\"string\",editType:\"plot\"},text:n.text,hovertext:n.hovertext,marker:{line:{color:o({},n.marker.line.color,{editType:\"plot\"}),width:o({},n.marker.line.width,{editType:\"plot\"}),editType:\"calc\"},opacity:o({},n.marker.opacity,{editType:\"plot\"}),editType:\"calc\"},selected:{marker:{opacity:o({},n.selected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:o({},n.unselected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},hoverinfo:n.hoverinfo,hovertemplate:a({},{keys:[\"properties\"]})},i(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../choropleth/attributes\":923}],933:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"@turf/area\"),a=t(\"@turf/centroid\"),o=t(\"../../lib\"),s=t(\"../../components/colorscale\"),l=t(\"../../components/drawing\"),c=t(\"../../lib/geojson_utils\").makeBlank,u=t(\"../choropleth/plot\").feature2polygons;function h(t){var e,r=t[0].trace,n=r._opts;if(r.selectedpoints){for(var i=l.makeSelectedPointStyleFns(r),a=0;a<t.length;a++){var s=t[a];s.fOut&&(s.fOut.properties.mo2=i.selectedOpacityFn(s))}e={type:\"identity\",property:\"mo2\"}}else e=o.isArrayOrTypedArray(r.marker.opacity)?{type:\"identity\",property:\"mo\"}:r.marker.opacity;return o.extendFlat(n.fill.paint,{\"fill-opacity\":e}),o.extendFlat(n.line.paint,{\"line-opacity\":e}),n}e.exports={convert:function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,l={layout:{visibility:\"none\"},paint:{}},f={layout:{visibility:\"none\"},paint:{}},p=e._opts={fill:l,line:f,geojson:c()};if(!r)return p;var d=\"string\"==typeof e.geojson?(window.PlotlyGeoAssets||{})[e.geojson]:e.geojson;if(!o.isPlainObject(d))return o.error(\"Oops ... something when wrong when fetching \"+e.geojson),p;var g,v={},m=[];for(g=0;g<t.length;g++){var y=t[g];y.loc&&(v[y.loc]=y)}var x,b,_,w=s.makeColorScaleFuncFromTrace(e),k=e.marker,T=k.line||{};function A(t){var e=v[t.id];if(e){var r=t.geometry;if(\"Polygon\"===r.type||\"MultiPolygon\"===r.type){var n={fc:w(e.z)};x&&(n.mo=x(e)),b&&(n.mlc=b(e)),_&&(n.mlw=_(e));var s={type:\"Feature\",geometry:r,properties:n};e._polygons=u(s),e.ct=function(t){var e,r=t.geometry;if(\"MultiPolygon\"===r.type)for(var n=r.coordinates,o=0,s=0;s<n.length;s++){var l={type:\"Polygon\",coordinates:n[s]},c=i.default(l);c>o&&(o=c,e=l)}else e=r;return a.default(e).geometry.coordinates}(s),e.fIn=t,e.fOut=s,m.push(s)}else o.log([\"Location with id\",e.loc,\"does not have a valid GeoJSON geometry,\",\"choroplethmapbox traces only support *Polygon* and *MultiPolygon* geometries.\"].join(\" \"))}delete v[t.id]}switch(o.isArrayOrTypedArray(k.opacity)&&(x=function(t){var e=t.mo;return n(e)?+o.constrain(e,0,1):0}),o.isArrayOrTypedArray(T.color)&&(b=function(t){return t.mlc}),o.isArrayOrTypedArray(T.width)&&(_=function(t){return t.mlw}),d.type){case\"FeatureCollection\":var M=d.features;for(g=0;g<M.length;g++)A(M[g]);break;case\"Feature\":A(d);break;default:return o.warn([\"Invalid GeoJSON type\",(d.type||\"none\")+\",\",\"choroplethmapbox traces only support *FeatureCollection* and *Feature* types.\"].join(\" \")),p}for(var S in v)o.log(\"Location with id \"+S+\" does not have a matching feature\");var E=x?{type:\"identity\",property:\"mo\"}:k.opacity;return o.extendFlat(l.paint,{\"fill-color\":{type:\"identity\",property:\"fc\"},\"fill-opacity\":E}),o.extendFlat(f.paint,{\"line-color\":b?{type:\"identity\",property:\"mlc\"}:T.color,\"line-width\":_?{type:\"identity\",property:\"mlw\"}:T.width,\"line-opacity\":E}),l.layout.visibility=\"visible\",f.layout.visibility=\"visible\",p.geojson={type:\"FeatureCollection\",features:m},h(t),p},convertOnSelect:h}},{\"../../components/colorscale\":605,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/geojson_utils\":714,\"../choropleth/plot\":929,\"@turf/area\":55,\"@turf/centroid\":56,\"fast-isnumeric\":225}],934:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\"),u=s(\"geojson\");n.isArrayOrTypedArray(l)&&l.length&&n.isArrayOrTypedArray(c)&&c.length&&(\"string\"==typeof u&&\"\"!==u||n.isPlainObject(u))?(e._length=Math.min(l.length,c.length),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":932}],935:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../choropleth/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"../choropleth/hover\"),eventData:t(\"../choropleth/event_data\"),selectPoints:t(\"../choropleth/select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.updateOnSelect(e)},getBelow:function(t,e){for(var r=e.getMapLayers(),n=r.length-2;n>=0;n--){var i=r[n].id;if(\"string\"==typeof i&&0===i.indexOf(\"water\"))for(var a=n+1;a<r.length;a++)if(\"string\"==typeof(i=r[a].id)&&-1===i.indexOf(\"plotly-\"))return i}},moduleType:\"trace\",name:\"choroplethmapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"noOpacity\"],meta:{hr_name:\"choropleth_mapbox\"}}},{\"../../plots/mapbox\":822,\"../choropleth/calc\":924,\"../choropleth/event_data\":926,\"../choropleth/hover\":927,\"../choropleth/select\":930,\"../heatmap/colorbar\":1004,\"./attributes\":932,\"./defaults\":934,\"./plot\":936}],936:[function(t,e,r){\"use strict\";var n=t(\"./convert\").convert,i=t(\"./convert\").convertOnSelect,a=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function o(t,e){this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"fill\",a+e+\"-fill\"],[\"line\",a+e+\"-line\"]],this.below=null}var s=o.prototype;s.update=function(t){this._update(n(t))},s.updateOnSelect=function(t){this._update(i(t))},s._update=function(t){var e=this.subplot,r=this.layerList,n=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(t.geojson),n!==this.below&&(this._removeLayers(),this._addLayers(t,n),this.below=n);for(var i=0;i<r.length;i++){var a=r[i],o=a[0],s=a[1],l=t[o];e.setOptions(s,\"setLayoutProperty\",l.layout),\"visible\"===l.layout.visibility&&e.setOptions(s,\"setPaintProperty\",l.paint)}},s._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},s._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},s.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new o(t,r.uid),a=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(a,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":820,\"./convert\":933}],937:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"scaled\",\"absolute\"],editType:\"calc\",dflt:\"scaled\"},sizeref:{valType:\"number\",editType:\"calc\",min:0},anchor:{valType:\"enumerated\",editType:\"calc\",values:[\"tip\",\"tail\",\"cm\",\"center\"],dflt:\"cm\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:i({editType:\"calc\"},{keys:[\"norm\"]})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach(function(t){l[t]=a[t]}),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../mesh3d/attributes\":1053}],938:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){for(var r=e.u,i=e.v,a=e.w,o=Math.min(e.x.length,e.y.length,e.z.length,r.length,i.length,a.length),s=-1/0,l=1/0,c=0;c<o;c++){var u=r[c],h=i[c],f=a[c],p=Math.sqrt(u*u+h*h+f*f);s=Math.max(s,p),l=Math.min(l,p)}e._len=o,e._normMax=s,n(t,e,{vals:[l,s],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],939:[function(t,e,r){\"use strict\";var n=t(\"gl-cone3d\"),i=t(\"gl-cone3d\").createConeMesh,a=t(\"../../lib\").simpleMap,o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\");function c(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var u=c.prototype;u.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index,r=this.data.x[e],n=this.data.y[e],i=this.data.z[e],a=this.data.u[e],o=this.data.v[e],s=this.data.w[e];t.traceCoordinate=[r,n,i,a,o,s,Math.sqrt(a*a+o*o+s*s)];var l=this.data.hovertext||this.data.text;return Array.isArray(l)&&void 0!==l[e]?t.textLabel=l[e]:l&&(t.textLabel=l),!0}};var h={xaxis:0,yaxis:1,zaxis:2},f={tip:1,tail:0,cm:.25,center:.5},p={tip:1,tail:1,cm:.75,center:.5};function d(t,e){var r=t.fullSceneLayout,i=t.dataScale,c={};function u(t,e){var n=r[e],o=i[h[e]];return a(t,function(t){return n.d2l(t)*o})}c.vectors=l(u(e.u,\"xaxis\"),u(e.v,\"yaxis\"),u(e.w,\"zaxis\"),e._len),c.positions=l(u(e.x,\"xaxis\"),u(e.y,\"yaxis\"),u(e.z,\"zaxis\"),e._len);var d=s(e);c.colormap=o(e),c.vertexIntensityBounds=[d.min/e._normMax,d.max/e._normMax],c.coneOffset=f[e.anchor],\"scaled\"===e.sizemode?c.coneSize=e.sizeref||.5:c.coneSize=e.sizeref&&e._normMax?e.sizeref/e._normMax:.5;var g=n(c),v=e.lightposition;return g.lightPosition=[v.x,v.y,v.z],g.ambient=e.lighting.ambient,g.diffuse=e.lighting.diffuse,g.specular=e.lighting.specular,g.roughness=e.lighting.roughness,g.fresnel=e.lighting.fresnel,g.opacity=e.opacity,e._pad=p[e.anchor]*g.vectorScale*g.coneScale*e._normMax,g}u.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),a=i(r,n),o=new c(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../plots/gl3d/zip3\":818,\"gl-cone3d\":242}],940:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),h=s(\"x\"),f=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length&&p&&p.length?(s(\"sizeref\"),s(\"sizemode\"),s(\"anchor\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":937}],941:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"cone\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),eventData:function(t,e){return t.norm=e.traceCoordinate[6],t},meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":937,\"./calc\":938,\"./convert\":939,\"./defaults\":940}],942:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../components/drawing/attributes\").dash,s=t(\"../../plots/font_attributes\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../constants/filter_ops\"),u=c.COMPARISON_OPS2,h=c.INTERVAL_OPS,f=(t(\"../../constants/docs\").FORMAT_LINK,i.line);e.exports=l({z:n.z,x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,xtype:n.xtype,ytype:n.ytype,zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate,connectgaps:n.connectgaps,fillcolor:{valType:\"color\",editType:\"calc\"},autocontour:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"contours.start\":void 0,\"contours.end\":void 0,\"contours.size\":void 0}},ncontours:{valType:\"integer\",dflt:15,min:1,editType:\"calc\"},contours:{type:{valType:\"enumerated\",values:[\"levels\",\"constraint\"],dflt:\"levels\",editType:\"calc\"},start:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},end:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},coloring:{valType:\"enumerated\",values:[\"fill\",\"heatmap\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:{valType:\"boolean\",dflt:!0,editType:\"plot\"},showlabels:{valType:\"boolean\",dflt:!1,editType:\"plot\"},labelfont:s({editType:\"plot\",colorEditType:\"style\"}),labelformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},operation:{valType:\"enumerated\",values:[].concat(u).concat(h),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:l({},f.color,{editType:\"style+colorbars\"}),width:l({},f.width,{editType:\"style+colorbars\"}),dash:o,smoothing:l({},f.smoothing,{}),editType:\"plot\"}},a(\"\",{cLetter:\"z\",autoColorDflt:!1,editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../components/drawing/attributes\":613,\"../../constants/docs\":690,\"../../constants/filter_ops\":691,\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"../heatmap/attributes\":1001,\"../scatter/attributes\":1112}],943:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\"),i=t(\"../heatmap/calc\"),a=t(\"./set_contours\"),o=t(\"./end_plus\");e.exports=function(t,e){var r=i(t,e),s=r[0].z;a(e,s);var l,c=e.contours,u=n.extractOpts(e);if(\"heatmap\"===c.coloring&&u.auto&&!1===e.autocontour){var h=c.start,f=o(c),p=c.size||1,d=Math.floor((f-h)/p)+1;isFinite(p)||(p=1,d=1);var g=h-p/2;l=[g,g+d*p]}else l=s;return n.calc(t,e,{vals:l,cLetter:\"z\"}),r}},{\"../../components/colorscale\":605,\"../heatmap/calc\":1002,\"./end_plus\":953,\"./set_contours\":961}],944:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a,o,s=t[0],l=s.x.length,c=s.y.length,u=s.z,h=n.contours,f=-1/0,p=1/0;for(i=0;i<c;i++)p=Math.min(p,u[i][0]),p=Math.min(p,u[i][l-1]),f=Math.max(f,u[i][0]),f=Math.max(f,u[i][l-1]);for(i=1;i<l-1;i++)p=Math.min(p,u[0][i]),p=Math.min(p,u[c-1][i]),f=Math.max(f,u[0][i]),f=Math.max(f,u[c-1][i]);switch(s.prefixBoundary=!1,e){case\">\":h.value>f&&(s.prefixBoundary=!0);break;case\"<\":h.value<p&&(s.prefixBoundary=!0);break;case\"[]\":a=Math.min.apply(null,h.value),((o=Math.max.apply(null,h.value))<p||a>f)&&(s.prefixBoundary=!0);break;case\"][\":a=Math.min.apply(null,h.value),o=Math.max.apply(null,h.value),a<p&&o>f&&(s.prefixBoundary=!0)}}},{}],945:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\").extractOpts,i=t(\"./make_color_map\"),a=t(\"./end_plus\");e.exports={min:\"zmin\",max:\"zmax\",calc:function(t,e,r){var o=e.contours,s=e.line,l=o.size||1,c=o.coloring,u=i(e,{isColorbar:!0});if(\"heatmap\"===c){var h=n(e);r._fillgradient=e.colorscale,r._zrange=[h.min,h.max]}else\"fill\"===c&&(r._fillcolor=u);r._line={color:\"lines\"===c?u:s.color,width:!1!==o.showlines?s.width:0,dash:s.dash},r._levels={start:o.start,end:a(o),size:l}}}},{\"../../components/colorscale\":605,\"./end_plus\":953,\"./make_color_map\":958}],946:[function(t,e,r){\"use strict\";e.exports={BOTTOMSTART:[1,9,13,104,713],TOPSTART:[4,6,7,104,713],LEFTSTART:[8,12,14,208,1114],RIGHTSTART:[2,3,11,208,1114],NEWDELTA:[null,[-1,0],[0,-1],[-1,0],[1,0],null,[0,-1],[-1,0],[0,1],[0,1],null,[0,1],[1,0],[1,0],[0,-1]],CHOOSESADDLE:{104:[4,1],208:[2,8],713:[7,13],1114:[11,14]},SADDLEREMAINDER:{1:4,2:8,4:1,7:13,8:2,11:14,13:7,14:11},LABELDISTANCE:2,LABELINCREASE:10,LABELMIN:3,LABELMAX:10,LABELOPTIMIZER:{EDGECOST:1,ANGLECOST:1,NEIGHBORCOST:5,SAMELEVELFACTOR:10,SAMELEVELDISTANCE:5,MAXCOST:100,INITIALSEARCHPOINTS:10,ITERATIONS:5}}},{}],947:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./label_defaults\"),a=t(\"../../components/color\"),o=a.addOpacity,s=a.opacity,l=t(\"../../constants/filter_ops\"),c=l.CONSTRAINT_REDUCTION,u=l.COMPARISON_OPS2;e.exports=function(t,e,r,a,l,h){var f,p,d,g=e.contours,v=r(\"contours.operation\");(g._operation=c[v],function(t,e){var r;-1===u.indexOf(e.operation)?(t(\"contours.value\",[0,1]),Array.isArray(e.value)?e.value.length>2?e.value=e.value.slice(2):0===e.length?e.value=[0,1]:e.length<2?(r=parseFloat(e.value[0]),e.value=[r,r+1]):e.value=[parseFloat(e.value[0]),parseFloat(e.value[1])]:n(e.value)&&(r=parseFloat(e.value),e.value=[r,r+1])):(t(\"contours.value\",0),n(e.value)||(Array.isArray(e.value)?e.value=parseFloat(e.value[0]):e.value=0))}(r,g),\"=\"===v?f=g.showlines=!0:(f=r(\"contours.showlines\"),d=r(\"fillcolor\",o((t.line||{}).color||l,.5))),f)&&(p=r(\"line.color\",d&&s(d)?o(e.fillcolor,1):l),r(\"line.width\",2),r(\"line.dash\"));r(\"line.smoothing\"),i(r,a,p,h)}},{\"../../components/color\":593,\"../../constants/filter_ops\":691,\"./label_defaults\":957,\"fast-isnumeric\":225}],948:[function(t,e,r){\"use strict\";var n=t(\"../../constants/filter_ops\"),i=t(\"fast-isnumeric\");function a(t,e){var r,a=Array.isArray(e);function o(t){return i(t)?+t:null}return-1!==n.COMPARISON_OPS2.indexOf(t)?r=o(a?e[0]:e):-1!==n.INTERVAL_OPS.indexOf(t)?r=a?[o(e[0]),o(e[1])]:[o(e),o(e)]:-1!==n.SET_OPS.indexOf(t)&&(r=a?e.map(o):[o(e)]),r}function o(t){return function(e){e=a(t,e);var r=Math.min(e[0],e[1]),n=Math.max(e[0],e[1]);return{start:r,end:n,size:n-r}}}function s(t){return function(e){return{start:e=a(t,e),end:1/0,size:1/0}}}e.exports={\"[]\":o(\"[]\"),\"][\":o(\"][\"),\">\":s(\">\"),\"<\":s(\"<\"),\"=\":s(\"=\")}},{\"../../constants/filter_ops\":691,\"fast-isnumeric\":225}],949:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=n(\"contours.start\"),a=n(\"contours.end\"),o=!1===i||!1===a,s=r(\"contours.size\");!(o?e.autocontour=!0:r(\"autocontour\",!1))&&s||r(\"ncontours\")}},{}],950:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");function i(t){return n.extendFlat({},t,{edgepaths:n.extendDeep([],t.edgepaths),paths:n.extendDeep([],t.paths)})}e.exports=function(t,e){var r,a,o,s=function(t){return t.reverse()},l=function(t){return t};switch(e){case\"=\":case\"<\":return t;case\">\":for(1!==t.length&&n.warn(\"Contour data invalid for the specified inequality operation.\"),a=t[0],r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);return t;case\"][\":var c=s;s=l,l=c;case\"[]\":for(2!==t.length&&n.warn(\"Contour data invalid for the specified inequality range operation.\"),a=i(t[0]),o=i(t[1]),r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);for(;o.edgepaths.length;)a.edgepaths.push(l(o.edgepaths.shift()));for(;o.paths.length;)a.paths.push(l(o.paths.shift()));return[a]}}},{\"../../lib\":719}],951:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"./constraint_defaults\"),o=t(\"./contours_defaults\"),s=t(\"./style_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,l,r,i)}if(i(t,e,u,c)){u(\"text\"),u(\"hovertext\"),u(\"hovertemplate\");var h=\"constraint\"===u(\"contours.type\");u(\"connectgaps\",n.isArray1D(e.z)),h?a(t,e,u,c,r):(o(t,e,u,function(r){return n.coerce2(t,e,l,r)}),s(t,e,u,c))}else e.visible=!1}},{\"../../lib\":719,\"../heatmap/xyz_defaults\":1015,\"./attributes\":942,\"./constraint_defaults\":947,\"./contours_defaults\":949,\"./style_defaults\":963}],952:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constraint_mapping\"),a=t(\"./end_plus\");e.exports=function(t,e,r){for(var o=\"constraint\"===t.type?i[t._operation](t.value):t,s=o.size,l=[],c=a(o),u=r.trace._carpetTrace,h=u?{xaxis:u.aaxis,yaxis:u.baxis,x:r.a,y:r.b}:{xaxis:e.xaxis,yaxis:e.yaxis,x:r.x,y:r.y},f=o.start;f<c;f+=s)if(l.push(n.extendFlat({level:f,crossings:{},starts:[],edgepaths:[],paths:[],z:r.z,smoothing:r.trace.line.smoothing},h)),l.length>1e3){n.warn(\"Too many contours, clipping at 1000\",t);break}return l}},{\"../../lib\":719,\"./constraint_mapping\":948,\"./end_plus\":953}],953:[function(t,e,r){\"use strict\";e.exports=function(t){return t.end+t.size/1e6}},{}],954:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constants\");function a(t,e,r,n){return Math.abs(t[0]-e[0])<r&&Math.abs(t[1]-e[1])<n}function o(t,e,r,o,l){var c,u=e.join(\",\"),h=u,f=t.crossings[h],p=function(t,e,r){var n=0,a=0;t>20&&e?208===t||1114===t?n=0===r[0]?1:-1:a=0===r[1]?1:-1:-1!==i.BOTTOMSTART.indexOf(t)?a=1:-1!==i.LEFTSTART.indexOf(t)?n=1:-1!==i.TOPSTART.indexOf(t)?a=-1:n=-1;return[n,a]}(f,r,e),d=[s(t,e,[-p[0],-p[1]])],g=p.join(\",\"),v=t.z.length,m=t.z[0].length;for(c=0;c<1e4;c++){if(f>20?(f=i.CHOOSESADDLE[f][(p[0]||p[1])<0?0:1],t.crossings[h]=i.SADDLEREMAINDER[f]):delete t.crossings[h],!(p=i.NEWDELTA[f])){n.log(\"Found bad marching index:\",f,e,t.level);break}d.push(s(t,e,p)),e[0]+=p[0],e[1]+=p[1],a(d[d.length-1],d[d.length-2],o,l)&&d.pop(),h=e.join(\",\");var y=p[0]&&(e[0]<0||e[0]>m-2)||p[1]&&(e[1]<0||e[1]>v-2);if(h===u&&p.join(\",\")===g||r&&y)break;f=t.crossings[h]}1e4===c&&n.log(\"Infinite loop in contour?\");var x,b,_,w,k,T,A,M,S,E,C,L,P,O,z,I=a(d[0],d[d.length-1],o,l),D=0,R=.2*t.smoothing,F=[],B=0;for(c=1;c<d.length;c++)L=d[c],P=d[c-1],void 0,void 0,O=L[2]-P[2],z=L[3]-P[3],D+=A=Math.sqrt(O*O+z*z),F.push(A);var N=D/F.length*R;function j(t){return d[t%d.length]}for(c=d.length-2;c>=B;c--)if((x=F[c])<N){for(_=0,b=c-1;b>=B&&x+F[b]<N;b--)x+=F[b];if(I&&c===d.length-2)for(_=0;_<b&&x+F[_]<N;_++)x+=F[_];k=c-b+_+1,T=Math.floor((c+b+_+2)/2),w=I||c!==d.length-2?I||-1!==b?k%2?j(T):[(j(T)[0]+j(T+1)[0])/2,(j(T)[1]+j(T+1)[1])/2]:d[0]:d[d.length-1],d.splice(b+1,c-b+1,w),c=b+1,_&&(B=_),I&&(c===d.length-2?d[_]=d[d.length-1]:0===c&&(d[d.length-1]=d[0]))}for(d.splice(0,B),c=0;c<d.length;c++)d[c].length=2;if(!(d.length<2))if(I)d.pop(),t.paths.push(d);else{r||n.log(\"Unclosed interior contour?\",t.level,u,d.join(\"L\"));var U=!1;for(M=0;M<t.edgepaths.length;M++)if(E=t.edgepaths[M],!U&&a(E[0],d[d.length-1],o,l)){d.pop(),U=!0;var V=!1;for(S=0;S<t.edgepaths.length;S++)if(a((C=t.edgepaths[S])[C.length-1],d[0],o,l)){V=!0,d.shift(),t.edgepaths.splice(M,1),S===M?t.paths.push(d.concat(C)):(S>M&&S--,t.edgepaths[S]=C.concat(d,E));break}V||(t.edgepaths[M]=d.concat(E))}for(M=0;M<t.edgepaths.length&&!U;M++)a((E=t.edgepaths[M])[E.length-1],d[0],o,l)&&(d.shift(),t.edgepaths[M]=E.concat(d),U=!0);U||t.edgepaths.push(d)}}function s(t,e,r){var n=e[0]+Math.max(r[0],0),i=e[1]+Math.max(r[1],0),a=t.z[i][n],o=t.xaxis,s=t.yaxis;if(r[1]){var l=(t.level-a)/(t.z[i][n+1]-a);return[o.c2p((1-l)*t.x[n]+l*t.x[n+1],!0),s.c2p(t.y[i],!0),n+l,i]}var c=(t.level-a)/(t.z[i+1][n]-a);return[o.c2p(t.x[n],!0),s.c2p((1-c)*t.y[i]+c*t.y[i+1],!0),n,i+c]}e.exports=function(t,e,r){var i,a,s,l;for(e=e||.01,r=r||.01,a=0;a<t.length;a++){for(s=t[a],l=0;l<s.starts.length;l++)o(s,s.starts[l],\"edge\",e,r);for(i=0;Object.keys(s.crossings).length&&i<1e4;)i++,o(s,Object.keys(s.crossings)[0].split(\",\").map(Number),void 0,e,r);1e4===i&&n.log(\"Infinite loop in contour?\")}}},{\"../../lib\":719,\"./constants\":946}],955:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../heatmap/hover\");e.exports=function(t,e,r,a,o){var s=i(t,e,r,a,o,!0);return s&&s.forEach(function(t){var e=t.trace;\"constraint\"===e.contours.type&&(e.fillcolor&&n.opacity(e.fillcolor)?t.color=n.addOpacity(e.fillcolor,1):e.contours.showlines&&n.opacity(e.line.color)&&(t.color=n.addOpacity(e.line.color,1)))}),s}},{\"../../components/color\":593,\"../heatmap/hover\":1008}],956:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\").plot,style:t(\"./style\"),colorbar:t(\"./colorbar\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"contour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":942,\"./calc\":943,\"./colorbar\":945,\"./defaults\":951,\"./hover\":955,\"./plot\":960,\"./style\":962}],957:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i){if(i||(i={}),t(\"contours.showlabels\")){var a=e.font;n.coerceFont(t,\"contours.labelfont\",{family:a.family,size:a.size,color:r}),t(\"contours.labelformat\")}!1!==i.hasHover&&t(\"zhoverformat\")}},{\"../../lib\":719}],958:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/colorscale\"),a=t(\"./end_plus\");e.exports=function(t){var e=t.contours,r=e.start,o=a(e),s=e.size||1,l=Math.floor((o-r)/s)+1,c=\"lines\"===e.coloring?0:1,u=i.extractOpts(t);isFinite(s)||(s=1,l=1);var h,f,p=u.reversescale?i.flipScale(u.colorscale):u.colorscale,d=p.length,g=new Array(d),v=new Array(d);if(\"heatmap\"===e.coloring){var m=u.min,y=u.max;for(f=0;f<d;f++)h=p[f],g[f]=h[0]*(y-m)+m,v[f]=h[1];var x=n.extent([m,y,e.start,e.start+s*(l-1)]),b=x[m<y?0:1],_=x[m<y?1:0];b!==m&&(g.splice(0,0,b),v.splice(0,0,v[0])),_!==y&&(g.push(_),v.push(v[v.length-1]))}else for(f=0;f<d;f++)h=p[f],g[f]=(h[0]*(l+c-1)-c/2)*s+r,v[f]=h[1];return i.makeColorScaleFunc({domain:g,range:v},{noNumericCheck:!0})}},{\"../../components/colorscale\":605,\"./end_plus\":953,d3:163}],959:[function(t,e,r){\"use strict\";var n=t(\"./constants\");function i(t,e){var r=(e[0][0]>t?0:1)+(e[0][1]>t?0:2)+(e[1][1]>t?0:4)+(e[1][0]>t?0:8);return 5===r||10===r?t>(e[0][0]+e[0][1]+e[1][0]+e[1][1])/4?5===r?713:1114:5===r?104:208:15===r?0:r}e.exports=function(t){var e,r,a,o,s,l,c,u,h,f=t[0].z,p=f.length,d=f[0].length,g=2===p||2===d;for(r=0;r<p-1;r++)for(o=[],0===r&&(o=o.concat(n.BOTTOMSTART)),r===p-2&&(o=o.concat(n.TOPSTART)),e=0;e<d-1;e++)for(a=o.slice(),0===e&&(a=a.concat(n.LEFTSTART)),e===d-2&&(a=a.concat(n.RIGHTSTART)),s=e+\",\"+r,l=[[f[r][e],f[r][e+1]],[f[r+1][e],f[r+1][e+1]]],h=0;h<t.length;h++)(c=i((u=t[h]).level,l))&&(u.crossings[s]=c,-1!==a.indexOf(c)&&(u.starts.push([e,r]),g&&-1!==a.indexOf(c,a.indexOf(c)+1)&&u.starts.push([e,r])))}},{\"./constants\":946}],960:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../../plots/cartesian/set_convert\"),c=t(\"../heatmap/plot\"),u=t(\"./make_crossings\"),h=t(\"./find_all_paths\"),f=t(\"./empty_pathinfo\"),p=t(\"./convert_to_constraints\"),d=t(\"./close_boundaries\"),g=t(\"./constants\"),v=g.LABELOPTIMIZER;function m(t,e){var r,n,o,s,l,c,u,h=function(t,e){var r=t.prefixBoundary;if(void 0===r){var n=Math.min(t.z[0][0],t.z[0][1]);r=!t.edgepaths.length&&n>t.level}return r?\"M\"+e.join(\"L\")+\"Z\":\"\"}(t,e),f=0,p=t.edgepaths.map(function(t,e){return e}),d=!0;function g(t){return Math.abs(t[1]-e[2][1])<.01}function v(t){return Math.abs(t[0]-e[0][0])<.01}function m(t){return Math.abs(t[0]-e[2][0])<.01}for(;p.length;){for(c=a.smoothopen(t.edgepaths[f],t.smoothing),h+=d?c:c.replace(/^M/,\"L\"),p.splice(p.indexOf(f),1),r=t.edgepaths[f][t.edgepaths[f].length-1],s=-1,o=0;o<4;o++){if(!r){i.log(\"Missing end?\",f,t);break}for(u=r,Math.abs(u[1]-e[0][1])<.01&&!m(r)?n=e[1]:v(r)?n=e[0]:g(r)?n=e[3]:m(r)&&(n=e[2]),l=0;l<t.edgepaths.length;l++){var y=t.edgepaths[l][0];Math.abs(r[0]-n[0])<.01?Math.abs(r[0]-y[0])<.01&&(y[1]-r[1])*(n[1]-y[1])>=0&&(n=y,s=l):Math.abs(r[1]-n[1])<.01?Math.abs(r[1]-y[1])<.01&&(y[0]-r[0])*(n[0]-y[0])>=0&&(n=y,s=l):i.log(\"endpt to newendpt is not vert. or horz.\",r,n,y)}if(r=n,s>=0)break;h+=\"L\"+n}if(s===t.edgepaths.length){i.log(\"unclosed perimeter path\");break}f=s,(d=-1===p.indexOf(f))&&(f=p[0],h+=\"Z\")}for(f=0;f<t.paths.length;f++)h+=a.smoothclosed(t.paths[f],t.smoothing);return h}function y(t,e,r,n){var a=e.width/2,o=e.height/2,s=t.x,l=t.y,c=t.theta,u=Math.cos(c)*a,h=Math.sin(c)*a,f=(s>n.center?n.right-s:s-n.left)/(u+Math.abs(Math.sin(c)*o)),p=(l>n.middle?n.bottom-l:l-n.top)/(Math.abs(h)+Math.cos(c)*o);if(f<1||p<1)return 1/0;var d=v.EDGECOST*(1/(f-1)+1/(p-1));d+=v.ANGLECOST*c*c;for(var g=s-u,m=l-h,y=s+u,x=l+h,b=0;b<r.length;b++){var _=r[b],w=Math.cos(_.theta)*_.width/2,k=Math.sin(_.theta)*_.width/2,T=2*i.segmentDistance(g,m,y,x,_.x-w,_.y-k,_.x+w,_.y+k)/(e.height+_.height),A=_.level===e.level,M=A?v.SAMELEVELDISTANCE:1;if(T<=M)return 1/0;d+=v.NEIGHBORCOST*(A?v.SAMELEVELFACTOR:1)/(T-M)}return d}r.plot=function(t,e,o,s){var l=e.xaxis,v=e.yaxis;i.makeTraceGroups(s,o,\"contour\").each(function(o){var s=n.select(this),y=o[0],x=y.trace,b=y.x,_=y.y,w=x.contours,k=f(w,e,y),T=i.ensureSingle(s,\"g\",\"heatmapcoloring\"),A=[];\"heatmap\"===w.coloring&&(A=[o]),c(t,e,A,T),u(k),h(k);var M=l.c2p(b[0],!0),S=l.c2p(b[b.length-1],!0),E=v.c2p(_[0],!0),C=v.c2p(_[_.length-1],!0),L=[[M,C],[S,C],[S,E],[M,E]],P=k;\"constraint\"===w.type&&(P=p(k,w._operation),d(P,w._operation,L,x)),function(t,e,r){var n=i.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"===r.coloring?[0]:[]);n.enter().append(\"path\"),n.exit().remove(),n.attr(\"d\",\"M\"+e.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(s,L,w),function(t,e,r,a){var o=i.ensureSingle(t,\"g\",\"contourfill\").selectAll(\"path\").data(\"fill\"===a.coloring||\"constraint\"===a.type&&\"=\"!==a._operation?e:[]);o.enter().append(\"path\"),o.exit().remove(),o.each(function(t){var e=m(t,r);e?n.select(this).attr(\"d\",e).style(\"stroke\",\"none\"):n.select(this).remove()})}(s,P,L,w),function(t,e,o,s,l){var c=i.ensureSingle(t,\"g\",\"contourlines\"),u=!1!==l.showlines,h=l.showlabels,f=u&&h,p=r.createLines(c,u||h,e),d=r.createLineClip(c,f,o,s.trace.uid),v=t.selectAll(\"g.contourlabels\").data(h?[0]:[]);if(v.exit().remove(),v.enter().append(\"g\").classed(\"contourlabels\",!0),h){var m=[],y=[];i.clearLocationCache();var x=r.labelFormatter(l,s.t.cb,o._fullLayout),b=a.tester.append(\"text\").attr(\"data-notex\",1).call(a.font,l.labelfont),_=e[0].xaxis,w=e[0].yaxis,k=_._length,T=w._length,A=_.range,M=w.range,S=i.aggNums(Math.min,null,s.x),E=i.aggNums(Math.max,null,s.x),C=i.aggNums(Math.min,null,s.y),L=i.aggNums(Math.max,null,s.y),P=Math.max(_.c2p(S,!0),0),O=Math.min(_.c2p(E,!0),k),z=Math.max(w.c2p(L,!0),0),I=Math.min(w.c2p(C,!0),T),D={};A[0]<A[1]?(D.left=P,D.right=O):(D.left=O,D.right=P),M[0]<M[1]?(D.top=z,D.bottom=I):(D.top=I,D.bottom=z),D.middle=(D.top+D.bottom)/2,D.center=(D.left+D.right)/2,m.push([[D.left,D.top],[D.right,D.top],[D.right,D.bottom],[D.left,D.bottom]]);var R=Math.sqrt(k*k+T*T),F=g.LABELDISTANCE*R/Math.max(1,e.length/g.LABELINCREASE);p.each(function(t){var e=r.calcTextOpts(t.level,x,b,o);n.select(this).selectAll(\"path\").each(function(){var t=i.getVisibleSegment(this,D,e.height/2);if(t&&!(t.len<(e.width+e.height)*g.LABELMIN))for(var n=Math.min(Math.ceil(t.len/F),g.LABELMAX),a=0;a<n;a++){var o=r.findBestTextLocation(this,t,e,y,D);if(!o)break;r.addLabelData(o,e,y,m)}})}),b.remove(),r.drawLabels(v,y,o,d,f?m:null)}h&&!u&&p.remove()}(s,k,t,y,w),function(t,e,r,n,o){var s=r._fullLayout._clips,l=\"clip\"+n.trace.uid,c=s.selectAll(\"#\"+l).data(n.trace.connectgaps?[]:[0]);if(c.enter().append(\"clipPath\").classed(\"contourclip\",!0).attr(\"id\",l),c.exit().remove(),!1===n.trace.connectgaps){var f={level:.9,crossings:{},starts:[],edgepaths:[],paths:[],xaxis:e.xaxis,yaxis:e.yaxis,x:n.x,y:n.y,z:function(t){var e,r,n=t.trace._emptypoints,i=[],a=t.z.length,o=t.z[0].length,s=[];for(e=0;e<o;e++)s.push(1);for(e=0;e<a;e++)i.push(s.slice());for(e=0;e<n.length;e++)r=n[e],i[r[0]][r[1]]=0;return t.zmask=i,i}(n),smoothing:0};u([f]),h([f]);var p=m(f,o),d=i.ensureSingle(c,\"path\",\"\");d.attr(\"d\",p)}else l=null;a.setClipUrl(t,l,r)}(s,e,t,y,L)})},r.createLines=function(t,e,r){var n=r[0].smoothing,i=t.selectAll(\"g.contourlevel\").data(e?r:[]);if(i.exit().remove(),i.enter().append(\"g\").classed(\"contourlevel\",!0),e){var o=i.selectAll(\"path.openline\").data(function(t){return t.pedgepaths||t.edgepaths});o.exit().remove(),o.enter().append(\"path\").classed(\"openline\",!0),o.attr(\"d\",function(t){return a.smoothopen(t,n)}).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\");var s=i.selectAll(\"path.closedline\").data(function(t){return t.ppaths||t.paths});s.exit().remove(),s.enter().append(\"path\").classed(\"closedline\",!0),s.attr(\"d\",function(t){return a.smoothclosed(t,n)}).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\")}return i},r.createLineClip=function(t,e,r,n){var i=e?\"clipline\"+n:null,o=r._fullLayout._clips.selectAll(\"#\"+i).data(e?[0]:[]);return o.exit().remove(),o.enter().append(\"clipPath\").classed(\"contourlineclip\",!0).attr(\"id\",i),a.setClipUrl(t,i,r),o},r.labelFormatter=function(t,e,r){if(t.labelformat)return r._d3locale.numberFormat(t.labelformat);var n;if(e)n=e.axis;else{if(n={type:\"linear\",_id:\"ycontour\",showexponent:\"all\",exponentformat:\"B\"},\"constraint\"===t.type){var i=t.value;Array.isArray(i)?n.range=[i[0],i[i.length-1]]:n.range=[i,i]}else n.range=[t.start,t.end],n.nticks=(t.end-t.start)/t.size;n.range[0]===n.range[1]&&(n.range[1]+=n.range[0]||1),n.nticks||(n.nticks=1e3),l(n,r),s.prepTicks(n),n._tmin=null,n._tmax=null}return function(t){return s.tickText(n,t).text}},r.calcTextOpts=function(t,e,r,n){var i=e(t);r.text(i).call(o.convertToTspans,n);var s=a.bBox(r.node(),!0);return{text:i,width:s.width,height:s.height,level:t,dy:(s.top+s.bottom)/2}},r.findBestTextLocation=function(t,e,r,n,a){var o,s,l,c,u,h=r.width;e.isClosed?(s=e.len/v.INITIALSEARCHPOINTS,o=e.min+s/2,l=e.max):(s=(e.len-h)/(v.INITIALSEARCHPOINTS+1),o=e.min+s+h/2,l=e.max-(s+h)/2);for(var f=1/0,p=0;p<v.ITERATIONS;p++){for(var d=o;d<l;d+=s){var g=i.getTextLocation(t,e.total,d,h),m=y(g,r,n,a);m<f&&(f=m,u=g,c=d)}if(f>2*v.MAXCOST)break;p&&(s/=2),l=(o=c-s/2)+1.5*s}if(f<=v.MAXCOST)return u},r.addLabelData=function(t,e,r,n){var i=e.width/2,a=e.height/2,o=t.x,s=t.y,l=t.theta,c=Math.sin(l),u=Math.cos(l),h=i*u,f=a*c,p=i*c,d=-a*u,g=[[o-h-f,s-p-d],[o+h-f,s+p-d],[o+h+f,s+p+d],[o-h+f,s-p+d]];r.push({text:e.text,x:o,y:s,dy:e.dy,theta:l,level:e.level,width:e.width,height:e.height}),n.push(g)},r.drawLabels=function(t,e,r,a,s){var l=t.selectAll(\"text\").data(e,function(t){return t.text+\",\"+t.x+\",\"+t.y+\",\"+t.theta});if(l.exit().remove(),l.enter().append(\"text\").attr({\"data-notex\":1,\"text-anchor\":\"middle\"}).each(function(t){var e=t.x+Math.sin(t.theta)*t.dy,i=t.y-Math.cos(t.theta)*t.dy;n.select(this).text(t.text).attr({x:e,y:i,transform:\"rotate(\"+180*t.theta/Math.PI+\" \"+e+\" \"+i+\")\"}).call(o.convertToTspans,r)}),s){for(var c=\"\",u=0;u<s.length;u++)c+=\"M\"+s[u].join(\"L\")+\"Z\";i.ensureSingle(a,\"path\",\"\").attr(\"d\",c)}}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/set_convert\":785,\"../heatmap/plot\":1012,\"./close_boundaries\":944,\"./constants\":946,\"./convert_to_constraints\":950,\"./empty_pathinfo\":952,\"./find_all_paths\":954,\"./make_crossings\":959,d3:163}],961:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\");function a(t,e,r){var i={type:\"linear\",range:[t,e]};return n.autoTicks(i,(e-t)/(r||15)),i}e.exports=function(t,e){var r=t.contours;if(t.autocontour){var o=t.zmin,s=t.zmax;(t.zauto||void 0===o)&&(o=i.aggNums(Math.min,null,e)),(t.zauto||void 0===s)&&(s=i.aggNums(Math.max,null,e));var l=a(o,s,t.ncontours);r.size=l.dtick,r.start=n.tickFirst(l),l.range.reverse(),r.end=n.tickFirst(l),r.start===o&&(r.start+=r.size),r.end===s&&(r.end-=r.size),r.start>r.end&&(r.start=r.end=(r.start+r.end)/2),t._input.contours||(t._input.contours={}),i.extendFlat(t._input.contours,{start:r.start,end:r.end,size:r.size}),t._input.autocontour=!0}else if(\"constraint\"!==r.type){var c,u=r.start,h=r.end,f=t._input.contours;if(u>h&&(r.start=f.start=h,h=r.end=f.end=u,u=r.start),!(r.size>0))c=u===h?1:a(u,h,t.ncontours).dtick,f.size=r.size=c}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767}],962:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../heatmap/style\"),o=t(\"./make_color_map\");e.exports=function(t){var e=n.select(t).selectAll(\"g.contour\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.each(function(t){var e=n.select(this),r=t[0].trace,a=r.contours,s=r.line,l=a.size||1,c=a.start,u=\"constraint\"===a.type,h=!u&&\"lines\"===a.coloring,f=!u&&\"fill\"===a.coloring,p=h||f?o(r):null;e.selectAll(\"g.contourlevel\").each(function(t){n.select(this).selectAll(\"path\").call(i.lineGroupStyle,s.width,h?p(t.level):s.color,s.dash)});var d=a.labelfont;if(e.selectAll(\"g.contourlabels text\").each(function(t){i.font(n.select(this),{family:d.family,size:d.size,color:d.color||(h?p(t.level):s.color)})}),u)e.selectAll(\"g.contourfill path\").style(\"fill\",r.fillcolor);else if(f){var g;e.selectAll(\"g.contourfill path\").style(\"fill\",function(t){return void 0===g&&(g=t.level),p(t.level+.5*l)}),void 0===g&&(g=c),e.selectAll(\"g.contourbg path\").style(\"fill\",p(g-.5*l))}}),a(t)}},{\"../../components/drawing\":614,\"../heatmap/style\":1013,\"./make_color_map\":958,d3:163}],963:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/defaults\"),i=t(\"./label_defaults\");e.exports=function(t,e,r,a,o){var s,l=r(\"contours.coloring\"),c=\"\";\"fill\"===l&&(s=r(\"contours.showlines\")),!1!==s&&(\"lines\"!==l&&(c=r(\"line.color\",\"#000\")),r(\"line.width\",.5),r(\"line.dash\")),\"none\"!==l&&(!0!==t.showlegend&&(e.showlegend=!1),e._dfltShowLegend=!1,n(t,e,a,r,{prefix:\"\",cLetter:\"z\"})),r(\"line.smoothing\"),i(r,a,c,o)}},{\"../../components/colorscale/defaults\":603,\"./label_defaults\":957}],964:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../contour/attributes\"),a=i.contours,o=t(\"../scatter/attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../lib/extend\").extendFlat,c=o.line;e.exports=l({carpet:{valType:\"string\",editType:\"calc\"},z:n.z,a:n.x,a0:n.x0,da:n.dx,b:n.y,b0:n.y0,db:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,atype:n.xtype,btype:n.ytype,fillcolor:i.fillcolor,autocontour:i.autocontour,ncontours:i.ncontours,contours:{type:a.type,start:a.start,end:a.end,size:a.size,coloring:{valType:\"enumerated\",values:[\"fill\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:a.showlines,showlabels:a.showlabels,labelfont:a.labelfont,labelformat:a.labelformat,operation:a.operation,value:a.value,editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:l({},c.color,{}),width:c.width,dash:c.dash,smoothing:l({},c.smoothing,{}),editType:\"plot\"},transforms:void 0},s(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../contour/attributes\":942,\"../heatmap/attributes\":1001,\"../scatter/attributes\":1112}],965:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\"),i=t(\"../../lib\"),a=t(\"../heatmap/convert_column_xyz\"),o=t(\"../heatmap/clean_2d_array\"),s=t(\"../heatmap/interp2d\"),l=t(\"../heatmap/find_empties\"),c=t(\"../heatmap/make_bound_array\"),u=t(\"./defaults\"),h=t(\"../carpet/lookup_carpetid\"),f=t(\"../contour/set_contours\");e.exports=function(t,e){var r=e._carpetTrace=h(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){if(!e.a||!e.b){var p=t.data[r.index],d=t.data[e.index];d.a||(d.a=p.a),d.b||(d.b=p.b),u(d,e,e._defaultColor,t._fullLayout)}var g=function(t,e){var r,u,h,f,p,d,g,v=e._carpetTrace,m=v.aaxis,y=v.baxis;m._minDtick=0,y._minDtick=0,i.isArray1D(e.z)&&a(e,m,y,\"a\",\"b\",[\"z\"]);r=e._a=e._a||e.a,f=e._b=e._b||e.b,r=r?m.makeCalcdata(e,\"_a\"):[],f=f?y.makeCalcdata(e,\"_b\"):[],u=e.a0||0,h=e.da||1,p=e.b0||0,d=e.db||1,g=e._z=o(e._z||e.z,e.transpose),e._emptypoints=l(g),s(g,e._emptypoints);var x=i.maxRowLength(g),b=\"scaled\"===e.xtype?\"\":r,_=c(e,b,u,h,x,m),w=\"scaled\"===e.ytype?\"\":f,k=c(e,w,p,d,g.length,y),T={a:_,b:k,z:g};\"levels\"===e.contours.type&&\"none\"!==e.contours.coloring&&n(t,e,{vals:g,containerStr:\"\",cLetter:\"z\"});return[T]}(t,e);return f(e,e._z),g}}},{\"../../components/colorscale/calc\":601,\"../../lib\":719,\"../carpet/lookup_carpetid\":915,\"../contour/set_contours\":961,\"../heatmap/clean_2d_array\":1003,\"../heatmap/convert_column_xyz\":1005,\"../heatmap/find_empties\":1007,\"../heatmap/interp2d\":1010,\"../heatmap/make_bound_array\":1011,\"./defaults\":966}],966:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"./attributes\"),o=t(\"../contour/constraint_defaults\"),s=t(\"../contour/contours_defaults\"),l=t(\"../contour/style_defaults\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,a,r,i)}if(u(\"carpet\"),t.a&&t.b){if(!i(t,e,u,c,\"a\",\"b\"))return void(e.visible=!1);u(\"text\"),\"constraint\"===u(\"contours.type\")?o(t,e,u,c,r,{hasHover:!1}):(s(t,e,u,function(r){return n.coerce2(t,e,a,r)}),l(t,e,u,c,{hasHover:!1}))}else e._defaultColor=r,e._length=null}},{\"../../lib\":719,\"../contour/constraint_defaults\":947,\"../contour/contours_defaults\":949,\"../contour/style_defaults\":963,\"../heatmap/xyz_defaults\":1015,\"./attributes\":964}],967:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../contour/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../contour/style\"),moduleType:\"trace\",name:\"contourcarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"contour\",\"symbols\",\"showLegend\",\"hasLines\",\"carpetDependent\"],meta:{}}},{\"../../plots/cartesian\":778,\"../contour/colorbar\":945,\"../contour/style\":962,\"./attributes\":964,\"./calc\":965,\"./defaults\":966,\"./plot\":970}],968:[function(t,e,r){\"use strict\";var n=t(\"../../components/drawing\"),i=t(\"../carpet/axis_aligned_line\"),a=t(\"../../lib\");e.exports=function(t,e,r,o,s,l,c,u){var h,f,p,d,g,v,m,y=\"\",x=e.edgepaths.map(function(t,e){return e}),b=!0,_=1e-4*Math.abs(r[0][0]-r[2][0]),w=1e-4*Math.abs(r[0][1]-r[2][1]);function k(t){return Math.abs(t[1]-r[0][1])<w}function T(t){return Math.abs(t[1]-r[2][1])<w}function A(t){return Math.abs(t[0]-r[0][0])<_}function M(t){return Math.abs(t[0]-r[2][0])<_}function S(t,e){var r,n,a,o,h=\"\";for(k(t)&&!M(t)||T(t)&&!A(t)?(o=s.aaxis,a=i(s,l,[t[0],e[0]],.5*(t[1]+e[1]))):(o=s.baxis,a=i(s,l,.5*(t[0]+e[0]),[t[1],e[1]])),r=1;r<a.length;r++)for(h+=o.smoothing?\"C\":\"L\",n=0;n<a[r].length;n++){var f=a[r][n];h+=[c.c2p(f[0]),u.c2p(f[1])]+\" \"}return h}for(h=0,f=null;x.length;){var E=e.edgepaths[h][0];for(f&&(y+=S(f,E)),m=n.smoothopen(e.edgepaths[h].map(o),e.smoothing),y+=b?m:m.replace(/^M/,\"L\"),x.splice(x.indexOf(h),1),f=e.edgepaths[h][e.edgepaths[h].length-1],g=-1,d=0;d<4;d++){if(!f){a.log(\"Missing end?\",h,e);break}for(k(f)&&!M(f)?p=r[1]:A(f)?p=r[0]:T(f)?p=r[3]:M(f)&&(p=r[2]),v=0;v<e.edgepaths.length;v++){var C=e.edgepaths[v][0];Math.abs(f[0]-p[0])<_?Math.abs(f[0]-C[0])<_&&(C[1]-f[1])*(p[1]-C[1])>=0&&(p=C,g=v):Math.abs(f[1]-p[1])<w?Math.abs(f[1]-C[1])<w&&(C[0]-f[0])*(p[0]-C[0])>=0&&(p=C,g=v):a.log(\"endpt to newendpt is not vert. or horz.\",f,p,C)}if(g>=0)break;y+=S(f,p),f=p}if(g===e.edgepaths.length){a.log(\"unclosed perimeter path\");break}h=g,(b=-1===x.indexOf(h))&&(h=x[0],y+=S(f,p)+\"Z\",f=null)}for(h=0;h<e.paths.length;h++)y+=n.smoothclosed(e.paths[h].map(o),e.smoothing);return y}},{\"../../components/drawing\":614,\"../../lib\":719,\"../carpet/axis_aligned_line\":899}],969:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i,a,o,s,l,c,u;for(r=0;r<t.length;r++){for(o=(a=t[r]).pedgepaths=[],s=a.ppaths=[],n=0;n<a.edgepaths.length;n++){for(u=a.edgepaths[n],l=[],i=0;i<u.length;i++)l[i]=e(u[i]);o.push(l)}for(n=0;n<a.paths.length;n++){for(u=a.paths[n],c=[],i=0;i<u.length;i++)c[i]=e(u[i]);s.push(c)}}}},{}],970:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../carpet/map_1d_array\"),a=t(\"../carpet/makepath\"),o=t(\"../../components/drawing\"),s=t(\"../../lib\"),l=t(\"../contour/make_crossings\"),c=t(\"../contour/find_all_paths\"),u=t(\"../contour/plot\"),h=t(\"../contour/constants\"),f=t(\"../contour/convert_to_constraints\"),p=t(\"./join_all_paths\"),d=t(\"../contour/empty_pathinfo\"),g=t(\"./map_pathinfo\"),v=t(\"../carpet/lookup_carpetid\"),m=t(\"../contour/close_boundaries\");function y(t,e,r){var n=t.getPointAtLength(e),i=t.getPointAtLength(r),a=i.x-n.x,o=i.y-n.y,s=Math.sqrt(a*a+o*o);return[a/s,o/s]}function x(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]);return[t[0]/e,t[1]/e]}function b(t,e){var r=Math.abs(t[0]*e[0]+t[1]*e[1]);return Math.sqrt(1-r*r)/r}e.exports=function(t,e,r,_){var w=e.xaxis,k=e.yaxis;s.makeTraceGroups(_,r,\"contour\").each(function(r){var _=n.select(this),T=r[0],A=T.trace,M=A._carpetTrace=v(t,A),S=t.calcdata[M.index][0];if(M.visible&&\"legendonly\"!==M.visible){var E=T.a,C=T.b,L=A.contours,P=d(L,e,T),O=\"constraint\"===L.type,z=L._operation,I=O?\"=\"===z?\"lines\":\"fill\":L.coloring,D=[[E[0],C[C.length-1]],[E[E.length-1],C[C.length-1]],[E[E.length-1],C[0]],[E[0],C[0]]];l(P);var R=1e-8*(E[E.length-1]-E[0]),F=1e-8*(C[C.length-1]-C[0]);c(P,R,F);var B,N,j,U,V=P;\"constraint\"===L.type&&(V=f(P,z),m(V,z,D,A)),g(P,G);var q=[];for(U=S.clipsegments.length-1;U>=0;U--)B=S.clipsegments[U],N=i([],B.x,w.c2p),j=i([],B.y,k.c2p),N.reverse(),j.reverse(),q.push(a(N,j,B.bicubic));var H=\"M\"+q.join(\"L\")+\"Z\";!function(t,e,r,n,o,l){var c,u,h,f,p=s.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"!==l||o?[]:[0]);p.enter().append(\"path\"),p.exit().remove();var d=[];for(f=0;f<e.length;f++)c=e[f],u=i([],c.x,r.c2p),h=i([],c.y,n.c2p),d.push(a(u,h,c.bicubic));p.attr(\"d\",\"M\"+d.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(_,S.clipsegments,w,k,O,I),function(t,e,r,i,a,o,l,c,u,h,f){var d=s.ensureSingle(e,\"g\",\"contourfill\").selectAll(\"path\").data(\"fill\"===h?a:[]);d.enter().append(\"path\"),d.exit().remove(),d.each(function(e){var a=p(t,e,o,l,c,u,r,i);e.prefixBoundary&&(a=f+a),a?n.select(this).attr(\"d\",a).style(\"stroke\",\"none\"):n.select(this).remove()})}(A,_,w,k,V,D,G,M,S,I,H),function(t,e,r,i,a,l,c){var f=s.ensureSingle(t,\"g\",\"contourlines\"),p=!1!==a.showlines,d=a.showlabels,g=p&&d,v=u.createLines(f,p||d,e),m=u.createLineClip(f,g,r,i.trace.uid),_=t.selectAll(\"g.contourlabels\").data(d?[0]:[]);if(_.exit().remove(),_.enter().append(\"g\").classed(\"contourlabels\",!0),d){var w=l.xaxis,k=l.yaxis,T=w._length,A=k._length,M=[[[0,0],[T,0],[T,A],[0,A]]],S=[];s.clearLocationCache();var E=u.labelFormatter(a,i.t.cb,r._fullLayout),C=o.tester.append(\"text\").attr(\"data-notex\",1).call(o.font,a.labelfont),L={left:0,right:T,center:T/2,top:0,bottom:A,middle:A/2},P=Math.sqrt(T*T+A*A),O=h.LABELDISTANCE*P/Math.max(1,e.length/h.LABELINCREASE);v.each(function(t){var e=u.calcTextOpts(t.level,E,C,r);n.select(this).selectAll(\"path\").each(function(r){var n=s.getVisibleSegment(this,L,e.height/2);if(n&&(function(t,e,r,n,i,a){for(var o,s=0;s<r.pedgepaths.length;s++)e===r.pedgepaths[s]&&(o=r.edgepaths[s]);if(!o)return;var l=i.a[0],c=i.a[i.a.length-1],u=i.b[0],h=i.b[i.b.length-1];function f(t,e){var r,n=0;return(Math.abs(t[0]-l)<.1||Math.abs(t[0]-c)<.1)&&(r=x(i.dxydb_rough(t[0],t[1],.1)),n=Math.max(n,a*b(e,r)/2)),(Math.abs(t[1]-u)<.1||Math.abs(t[1]-h)<.1)&&(r=x(i.dxyda_rough(t[0],t[1],.1)),n=Math.max(n,a*b(e,r)/2)),n}var p=y(t,0,1),d=y(t,n.total,n.total-1),g=f(o[0],p),v=n.total-f(o[o.length-1],d);n.min<g&&(n.min=g);n.max>v&&(n.max=v);n.len=n.max-n.min}(this,r,t,n,c,e.height),!(n.len<(e.width+e.height)*h.LABELMIN)))for(var i=Math.min(Math.ceil(n.len/O),h.LABELMAX),a=0;a<i;a++){var o=u.findBestTextLocation(this,n,e,S,L);if(!o)break;u.addLabelData(o,e,S,M)}})}),C.remove(),u.drawLabels(_,S,r,m,g?M:null)}d&&!p&&v.remove()}(_,P,t,T,L,e,M),o.setClipUrl(_,M._clipPathId,t)}function G(t){var e=M.ab2xy(t[0],t[1],!0);return[w.c2p(e[0]),k.c2p(e[1])]}})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../carpet/lookup_carpetid\":915,\"../carpet/makepath\":916,\"../carpet/map_1d_array\":917,\"../contour/close_boundaries\":944,\"../contour/constants\":946,\"../contour/convert_to_constraints\":950,\"../contour/empty_pathinfo\":952,\"../contour/find_all_paths\":954,\"../contour/make_crossings\":959,\"../contour/plot\":960,\"./join_all_paths\":968,\"./map_pathinfo\":969,d3:163}],971:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../scattermapbox/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({lon:o.lon,lat:o.lat,z:{valType:\"data_array\",editType:\"calc\"},radius:{valType:\"number\",editType:\"plot\",arrayOk:!0,min:1,dflt:30},below:{valType:\"string\",editType:\"plot\"},text:o.text,hovertext:o.hovertext,hoverinfo:s({},a.hoverinfo,{flags:[\"lon\",\"lat\",\"z\",\"text\",\"name\"]}),hovertemplate:i()},n(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scattermapbox/attributes\":1171}],972:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../components/colorscale/calc\"),s=t(\"../../lib\")._;e.exports=function(t,e){for(var r=e._length,l=new Array(r),c=e.z,u=i(c)&&c.length,h=0;h<r;h++){var f=l[h]={},p=e.lon[h],d=e.lat[h];if(f.lonlat=n(p)&&n(d)?[+p,+d]:[a,a],u){var g=c[h];f.z=n(g)?g:a}}return o(t,e,{vals:u?c:[0,1],containerStr:\"\",cLetter:\"z\"}),r&&(l[0].t={labels:{lat:s(t,\"lat:\")+\" \",lon:s(t,\"lon:\")+\" \"}}),l}},{\"../../components/colorscale/calc\":601,\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],973:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../../components/colorscale\"),s=t(\"../../constants/numerical\").BADNUM,l=t(\"../../lib/geojson_utils\").makeBlank;e.exports=function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,c=e._opts={heatmap:{layout:{visibility:\"none\"},paint:{}},geojson:l()};if(!r)return c;var u,h=[],f=e.z,p=e.radius,d=i.isArrayOrTypedArray(f)&&f.length,g=i.isArrayOrTypedArray(p);for(u=0;u<t.length;u++){var v=t[u],m=v.lonlat;if(m[0]!==s){var y={};if(d){var x=v.z;y.z=x!==s?x:0}g&&(y.r=n(p[u])&&p[u]>0?+p[u]:0),h.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:m},properties:y})}}var b=o.extractOpts(e),_=b.reversescale?o.flipScale(b.colorscale):b.colorscale,w=_[0][1],k=[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,a.opacity(w)<1?w:a.addOpacity(w,0)];for(u=1;u<_.length;u++)k.push(_[u][0],_[u][1]);var T=[\"interpolate\",[\"linear\"],[\"get\",\"z\"],b.min,0,b.max,1];return i.extendFlat(c.heatmap.paint,{\"heatmap-weight\":d?T:1/(b.max-b.min),\"heatmap-color\":k,\"heatmap-radius\":g?{type:\"identity\",property:\"r\"}:e.radius,\"heatmap-opacity\":e.opacity}),c.geojson={type:\"FeatureCollection\",features:h},c.heatmap.layout.visibility=\"visible\",c}},{\"../../components/color\":593,\"../../components/colorscale\":605,\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/geojson_utils\":714,\"fast-isnumeric\":225}],974:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"lon\")||[],c=s(\"lat\")||[],u=Math.min(l.length,c.length);u?(e._length=u,s(\"z\"),s(\"radius\"),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":971}],975:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.z=e.z,t}},{}],976:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../scattermapbox/hover\");e.exports=function(t,e,r){var o=a(t,e,r);if(o){var s=o[0],l=s.cd,c=l[0].trace,u=l[s.index];if(delete s.color,\"z\"in u){var h=s.subplot.mockAxis;s.z=u.z,s.zLabel=i.tickText(h,h.c2l(u.z),\"hover\").text}return s.extraText=function(t,e,r){if(t.hovertemplate)return;var i=(e.hi||t.hoverinfo).split(\"+\"),a=-1!==i.indexOf(\"all\"),o=-1!==i.indexOf(\"lon\"),s=-1!==i.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}a||o&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):o?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(a||-1!==i.indexOf(\"text\"))&&n.fillText(e,t,c);return c.join(\"<br>\")}(c,u,l[0].t.labels),[s]}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scattermapbox/hover\":1175}],977:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),getBelow:function(t,e){for(var r=e.getMapLayers(),n=0;n<r.length;n++){var i=r[n],a=i.id;if(\"symbol\"===i.type&&\"string\"==typeof a&&-1===a.indexOf(\"plotly-\"))return a}},moduleType:\"trace\",name:\"densitymapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\"],meta:{hr_name:\"density_mapbox\"}}},{\"../../plots/mapbox\":822,\"../heatmap/colorbar\":1004,\"./attributes\":971,\"./calc\":972,\"./defaults\":974,\"./event_data\":975,\"./hover\":976,\"./plot\":978}],978:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function a(t,e){this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"heatmap\",i+e+\"-heatmap\"]],this.below=null}var o=a.prototype;o.update=function(t){var e=this.subplot,r=this.layerList,i=n(t),a=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(i.geojson),a!==this.below&&(this._removeLayers(),this._addLayers(i,a),this.below=a);for(var o=0;o<r.length;o++){var s=r[o],l=s[0],c=s[1],u=i[l];e.setOptions(c,\"setLayoutProperty\",u.layout),\"visible\"===u.layout.visibility&&e.setOptions(c,\"setPaintProperty\",u.paint)}},o._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},o._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},o.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new a(t,r.uid),o=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(o,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),i}},{\"../../plots/mapbox/constants\":820,\"./convert\":973}],979:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":719}],980:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"./constants\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../components/color\");e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,hovertext:n.hovertext,hovertemplate:o({},{keys:s.eventDataKeys}),hoverinfo:l({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"percent initial\",\"percent previous\",\"percent total\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"percent initial\",\"percent previous\",\"percent total\",\"value\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},text:n.text,textposition:l({},n.textposition,{dflt:\"auto\"}),insidetextanchor:l({},n.insidetextanchor,{dflt:\"middle\"}),textangle:l({},n.textangle,{dflt:0}),textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:l({},n.orientation,{}),offset:l({},n.offset,{arrayOk:!1}),width:l({},n.width,{arrayOk:!1}),marker:n.marker,connector:{fillcolor:{valType:\"color\",editType:\"style\"},line:{color:l({},i.color,{dflt:c.defaultLine}),width:l({},i.width,{dflt:0,editType:\"plot\"}),dash:i.dash,editType:\"style\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":593,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../bar/attributes\":857,\"../scatter/attributes\":1112,\"./constants\":982}],981:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"./arrays_to_calcdata\"),a=t(\"../scatter/calc_selection\"),o=t(\"../../constants/numerical\").BADNUM;function s(t){return t===o?0:t}e.exports=function(t,e){var r,l,c,u,h=n.getFromId(t,e.xaxis||\"x\"),f=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=h.makeCalcdata(e,\"x\"),l=f.makeCalcdata(e,\"y\")):(r=f.makeCalcdata(e,\"y\"),l=h.makeCalcdata(e,\"x\"));var p,d=Math.min(l.length,r.length),g=new Array(d);for(e._base=[],c=0;c<d;c++){r[c]<0&&(r[c]=o);var v=!1;r[c]!==o&&c+1<d&&r[c+1]!==o&&(v=!0),u=g[c]={p:l[c],s:r[c],cNext:v},e._base[c]=-.5*u.s,e.ids&&(u.id=String(e.ids[c])),0===c&&(g[0].vTotal=0),g[0].vTotal+=s(u.s),u.begR=s(u.s)/s(g[0].s)}for(c=0;c<d;c++)(u=g[c]).s!==o&&(u.sumR=u.s/g[0].vTotal,u.difR=void 0!==p?u.s/p:1,p=u.s);return i(g,e),a(g,e),g}},{\"../../constants/numerical\":695,\"../../plots/cartesian/axes\":767,\"../scatter/calc_selection\":1114,\"./arrays_to_calcdata\":979}],982:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"percentInitial\",\"percentPrevious\",\"percentTotal\"]}},{}],983:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],h=[],f=[];for(i=0;i<o.length;i++){var p=o[i],d=\"h\"===p.orientation;!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"funnel\"===p.type&&(r=s[i],d?f.push(r):h.push(r),u.push(r))}var g={mode:a.funnelmode,norm:a.funnelnorm,gap:a.funnelgap,groupgap:a.funnelgroupgap};for(n(t,l,c,h,g),n(t,c,l,f,g),i=0;i<u.length;i++){r=u[i];for(var v=0;v<r.length;v++)v+1<r.length&&(r[v].nextP0=r[v+1].p0,r[v].nextS0=r[v+1].s0,r[v].nextP1=r[v+1].p1,r[v].nextS1=r[v+1].s1)}}},{\"../bar/cross_trace_calc\":860}],984:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"./attributes\"),l=t(\"../../components/color\");e.exports={supplyDefaults:function(t,e,r,i){function c(r,i){return n.coerce(t,e,s,r,i)}if(o(t,e,i,c)){c(\"orientation\",e.y&&!e.x?\"v\":\"h\"),c(\"offset\"),c(\"width\");var u=c(\"text\");c(\"hovertext\"),c(\"hovertemplate\");var h=c(\"textposition\");a(t,e,i,c,h,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"!==e.textposition&&c(\"textinfo\",Array.isArray(u)?\"text+value\":\"value\");var f=c(\"marker.color\",r);c(\"marker.line.color\",l.defaultLine),c(\"marker.line.width\"),c(\"connector.visible\")&&(c(\"connector.fillcolor\",function(t){var e=n.isArrayOrTypedArray(t)?\"#000\":t;return l.addOpacity(e,.5*l.opacity(e))}(f)),c(\"connector.line.width\")&&(c(\"connector.line.color\"),c(\"connector.line.dash\")))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,s,t)}if(\"group\"===e.funnelmode)for(var l=0;l<t.length;l++)r=(a=t[l])._input,i(r,a,e,o)}}},{\"../../components/color\":593,\"../../lib\":719,\"../bar/defaults\":861,\"../scatter/xy_defaults\":1137,\"./attributes\":980}],985:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"percentInitial\"in e&&(t.percentInitial=e.percentInitial),\"percentPrevious\"in e&&(t.percentPrevious=e.percentPrevious),\"percentTotal\"in e&&(t.percentTotal=e.percentTotal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],986:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\").opacity,i=t(\"../bar/hover\").hoverOnBars,a=t(\"../../lib\").formatPercent;e.exports=function(t,e,r,o){var s=i(t,e,r,o);if(s){var l=s.cd,c=l[0].trace,u=\"h\"===c.orientation,h=l[s.index];s[(u?\"x\":\"y\")+\"LabelVal\"]=h.s,s.percentInitial=h.begR,s.percentInitialLabel=a(h.begR,1),s.percentPrevious=h.difR,s.percentPreviousLabel=a(h.difR,1),s.percentTotal=h.sumR,s.percentTotalLabel=a(h.sumR,1);var f=h.hi||c.hoverinfo,p=[];if(f&&\"none\"!==f&&\"skip\"!==f){var d=\"all\"===f,g=f.split(\"+\"),v=function(t){return d||-1!==g.indexOf(t)};v(\"percent initial\")&&p.push(s.percentInitialLabel+\" of initial\"),v(\"percent previous\")&&p.push(s.percentPreviousLabel+\" of previous\"),v(\"percent total\")&&p.push(s.percentTotalLabel+\" of total\")}return s.extraText=p.join(\"<br>\"),s.color=function(t,e){var r=t.marker,i=e.mc||r.color,a=e.mlc||r.line.color,o=e.mlw||r.line.width;if(n(i))return i;if(n(a)&&o)return a}(c,h),[s]}}},{\"../../components/color\":593,\"../../lib\":719,\"../bar/hover\":863}],987:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"funnel\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../bar/select\":868,\"./attributes\":980,\"./calc\":981,\"./cross_trace_calc\":983,\"./defaults\":984,\"./event_data\":985,\"./hover\":986,\"./layout_attributes\":988,\"./layout_defaults\":989,\"./plot\":990,\"./style\":991}],988:[function(t,e,r){\"use strict\";e.exports={funnelmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},funnelgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},funnelgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],989:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"funnel\"===l.type){a=!0;break}}a&&(o(\"funnelmode\"),o(\"funnelgap\",.2),o(\"funnelgroupgap\"))}},{\"../../lib\":719,\"./layout_attributes\":988}],990:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../bar/plot\").plot;function s(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),i[3]=o.c2p(t.nextS1,!0),a[3]=s.c2p(t.nextP1,!0),n?[i,a]:[a,i]}e.exports=function(t,e,r,l){var c=t._fullLayout;!function(t,e,r,o){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each(function(r){var o=n.select(this),u=r[0].trace,h=i.ensureSingle(o,\"g\",\"regions\");if(u.connector&&u.connector.visible){var f=\"h\"===u.orientation,p=h.selectAll(\"g.region\").data(i.identity);p.enter().append(\"g\").classed(\"region\",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var u=s(r,l,c,f),h=u[0],p=u[1],g=\"\";void 0!==h[3]&&void 0!==p[3]&&(g+=f?\"M\"+h[0]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[2]+\"H\"+h[3]+\"L\"+h[1]+\",\"+p[1]+\"Z\":\"M\"+h[1]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[3]+\"V\"+p[2]+\"L\"+h[1]+\",\"+p[0]+\"Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}})}else h.remove()})}(t,e,r,l),function(t,e,r,o){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each(function(r){var o=n.select(this),u=r[0].trace,h=i.ensureSingle(o,\"g\",\"lines\");if(u.connector&&u.connector.visible&&u.connector.line.width){var f=\"h\"===u.orientation,p=h.selectAll(\"g.line\").data(i.identity);p.enter().append(\"g\").classed(\"line\",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var u=s(r,l,c,f),h=u[0],p=u[1],g=\"\";void 0!==h[3]&&void 0!==p[3]&&(f?(g+=\"M\"+h[0]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[2],g+=\"M\"+h[1]+\",\"+p[1]+\"L\"+h[3]+\",\"+p[2]):(g+=\"M\"+h[1]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[3],g+=\"M\"+h[1]+\",\"+p[0]+\"L\"+h[2]+\",\"+p[2])),\"\"===g&&(g=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}})}else h.remove()})}(t,e,r,l),o(t,e,r,l,{mode:c.funnelmode,norm:c.funnelmode,gap:c.funnelgap,groupgap:c.funnelgroupgap})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../bar/plot\":867,d3:163}],991:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\").styleTextPoints;e.exports={style:function(t,e,r){var l=r||n.select(t).selectAll(\"g.funnellayer\").selectAll(\"g.trace\");l.style(\"opacity\",function(t){return t[0].trace.opacity}),l.each(function(e){var r=n.select(this),l=e[0].trace;r.selectAll(\".point > path\").each(function(t){if(!t.isBlank){var e=l.marker;n.select(this).call(a.fill,t.mc||e.color).call(a.stroke,t.mlc||e.line.color).call(i.dashLine,e.line.dash,t.mlw||e.line.width).style(\"opacity\",l.selectedpoints&&!t.selected?o:1)}}),s(r,l,t),r.selectAll(\".regions\").each(function(){n.select(this).selectAll(\"path\").style(\"stroke-width\",0).call(a.fill,l.connector.fillcolor)}),r.selectAll(\".lines\").each(function(){var t=l.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)})})}}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../constants/interactions\":694,\"../bar/style\":870,d3:163}],992:[function(t,e,r){\"use strict\";var n=t(\"../pie/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../plots/domain\").attributes,o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports={labels:n.labels,label0:n.label0,dlabel:n.dlabel,values:n.values,marker:{colors:n.marker.colors,line:{color:s({},n.marker.line.color,{dflt:null}),width:s({},n.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},text:n.text,hovertext:n.hovertext,scalegroup:s({},n.scalegroup,{}),textinfo:s({},n.textinfo,{flags:[\"label\",\"text\",\"value\",\"percent\"]}),hoverinfo:s({},i.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:o({},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),textposition:s({},n.textposition,{values:[\"inside\",\"none\"],dflt:\"inside\"}),textfont:n.textfont,insidetextfont:n.insidetextfont,title:{text:n.title.text,font:n.title.font,position:s({},n.title.position,{values:[\"top left\",\"top center\",\"top right\"],dflt:\"top center\"}),editType:\"plot\"},domain:a({name:\"funnelarea\",trace:!0,editType:\"calc\"}),aspectratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},baseratio:{valType:\"number\",min:0,max:1,dflt:.333,editType:\"plot\"}}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../pie/attributes\":1086}],993:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData;r.name=\"funnelarea\",r.plot=function(t){var e=n.getModule(\"funnelarea\"),r=i(t.calcdata,e)[0];e.plot(t,r)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"funnelarea\"),a=e._has&&e._has(\"funnelarea\");i&&!a&&n._funnelarealayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],994:[function(t,e,r){\"use strict\";var n=t(\"../pie/calc\");e.exports={calc:function(t,e){return n.calc(t,e)},crossTraceCalc:function(t){n.crossTraceCalc(t,{type:\"funnelarea\"})}}},{\"../pie/calc\":1088}],995:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}var c,u=l(\"values\"),h=n.isArrayOrTypedArray(u),f=l(\"labels\");if(Array.isArray(f)?(c=f.length,h&&(c=Math.min(c,u.length))):h&&(c=u.length,l(\"label0\"),l(\"dlabel\")),c){e._length=c,l(\"marker.line.width\")&&l(\"marker.line.color\",s.paper_bgcolor),l(\"marker.colors\"),l(\"scalegroup\");var p=l(\"text\"),d=l(\"textinfo\",Array.isArray(p)?\"text+percent\":\"percent\");if(l(\"hovertext\"),l(\"hovertemplate\"),d&&\"none\"!==d){var g=l(\"textposition\");o(t,e,s,l,g,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}a(e,s,l),l(\"title.text\")&&(l(\"title.position\"),n.coerceFont(l,\"title.font\",s.font)),l(\"aspectratio\"),l(\"baseratio\")}else e.visible=!1}},{\"../../lib\":719,\"../../plots/domain\":792,\"../bar/defaults\":861,\"./attributes\":992}],996:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"funnelarea\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"funnelarea\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\"),styleOne:t(\"../pie/style_one\"),meta:{}}},{\"../pie/style_one\":1097,\"./attributes\":992,\"./base_plot\":993,\"./calc\":994,\"./defaults\":995,\"./layout_attributes\":997,\"./layout_defaults\":998,\"./plot\":999,\"./style\":1e3}],997:[function(t,e,r){\"use strict\";var n=t(\"../pie/layout_attributes\").hiddenlabels;e.exports={hiddenlabels:n,funnelareacolorway:{valType:\"colorlist\",editType:\"calc\"},extendfunnelareacolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{\"../pie/layout_attributes\":1093}],998:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"funnelareacolorway\",e.colorway),r(\"extendfunnelareacolors\")}},{\"../../lib\":719,\"./layout_attributes\":997}],999:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../lib\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../bar/plot\"),l=s.getTransform,c=s.toMoveInsideBar,u=t(\"../pie/helpers\"),h=t(\"../pie/plot\"),f=h.attachFxHandlers,p=h.determineInsideTextFont,d=h.layoutAreas,g=h.prerenderTitles,v=h.positionTitleOutside;function m(t,e){return\"l\"+(e[0]-t[0])+\",\"+(e[1]-t[1])}e.exports=function(t,e){var r=t._fullLayout;g(e,t),d(e,r._size),a.makeTraceGroups(r._funnelarealayer,e,\"trace\").each(function(e){var s=n.select(this),h=e[0],d=h.trace;!function(t){if(!t.length)return;var e=t[0],r=e.trace,n=r.aspectratio,i=r.baseratio;i>.999&&(i=.999);var a,o=Math.pow(i,2),s=e.vTotal,l=s,c=s*o/(1-o)/s;function u(){var t,e={x:t=Math.sqrt(c),y:-t};return[e.x,e.y]}var h,f,p=[];for(p.push(u()),h=t.length-1;h>-1;h--)if(!(f=t[h]).hidden){var d=f.v/l;c+=d,p.push(u())}var g=1/0,v=-1/0;for(h=0;h<p.length;h++)a=p[h],g=Math.min(g,a[1]),v=Math.max(v,a[1]);for(h=0;h<p.length;h++)p[h][1]-=(v+g)/2;var m=p[p.length-1][0],y=e.r,x=(v-g)/2,b=y/m,_=y/x*n;for(e.r=_*x,h=0;h<p.length;h++)p[h][0]*=b,p[h][1]*=_;var w=[-(a=p[0])[0],a[1]],k=[a[0],a[1]],T=0;for(h=t.length-1;h>-1;h--)if(!(f=t[h]).hidden){var A=p[T+=1][0],M=p[T][1];f.TL=[-A,M],f.TR=[A,M],f.BL=w,f.BR=k,f.pxmid=(S=f.TR,E=f.BR,[.5*(S[0]+E[0]),.5*(S[1]+E[1])]),w=f.TL,k=f.TR}var S,E}(e),s.each(function(){var s=n.select(this).selectAll(\"g.slice\").data(e);s.enter().append(\"g\").classed(\"slice\",!0),s.exit().remove(),s.each(function(r){if(r.hidden)n.select(this).selectAll(\"path,g\").remove();else{r.pointNumber=r.i,r.curveNumber=d.index;var s=h.cx,g=h.cy,v=n.select(this),y=v.selectAll(\"path.surface\").data([r]);y.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),v.call(f,t,e);var x=\"M\"+(s+r.TR[0])+\",\"+(g+r.TR[1])+m(r.TR,r.BR)+m(r.BR,r.BL)+m(r.BL,r.TL)+\"Z\";y.attr(\"d\",x);var b=u.castOption(d.textposition,r.pts),_=v.selectAll(\"g.slicetext\").data(r.text&&\"none\"!==b?[0]:[]);_.enter().append(\"g\").classed(\"slicetext\",!0),_.exit().remove(),_.each(function(){var e=a.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)});e.text(r.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,p(d,r,t._fullLayout.font)).call(o.convertToTspans,t);var u,h,f,v=i.bBox(e.node()),m=Math.min(r.BL[1],r.BR[1]),y=Math.max(r.TL[1],r.TR[1]);h=Math.max(r.TL[0],r.BL[0]),f=Math.min(r.TR[0],r.BR[0]),u=l(c(h,f,m,y,v,{isHorizontal:!0,constrained:!0,angle:0,anchor:\"middle\"})),e.attr(\"transform\",\"translate(\"+s+\",\"+g+\")\"+u)})}});var g=n.select(this).selectAll(\"g.titletext\").data(d.title.text?[0]:[]);g.enter().append(\"g\").classed(\"titletext\",!0),g.exit().remove(),g.each(function(){var e=a.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),s=d.title.text;d._meta&&(s=a.templateString(s,d._meta)),e.text(s).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,d.title.font).call(o.convertToTspans,t);var l=v(h,r._size);e.attr(\"transform\",\"translate(\"+l.x+\",\"+l.y+\")\"+(l.scale<1?\"scale(\"+l.scale+\")\":\"\")+\"translate(\"+l.tx+\",\"+l.ty+\")\")})})})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../bar/plot\":867,\"../pie/helpers\":1091,\"../pie/plot\":1095,d3:163}],1000:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../pie/style_one\");e.exports=function(t){t._fullLayout._funnelarealayer.selectAll(\".trace\").each(function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each(function(t){n.select(this).call(i,t,e)})})}},{\"../pie/style_one\":1097,d3:163}],1001:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../components/colorscale/attributes\"),o=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../lib/extend\").extendFlat);e.exports=o({z:{valType:\"data_array\",editType:\"calc\"},x:o({},n.x,{impliedEdits:{xtype:\"array\"}}),x0:o({},n.x0,{impliedEdits:{xtype:\"scaled\"}}),dx:o({},n.dx,{impliedEdits:{xtype:\"scaled\"}}),y:o({},n.y,{impliedEdits:{ytype:\"array\"}}),y0:o({},n.y0,{impliedEdits:{ytype:\"scaled\"}}),dy:o({},n.dy,{impliedEdits:{ytype:\"scaled\"}}),text:{valType:\"data_array\",editType:\"calc\"},hovertext:{valType:\"data_array\",editType:\"calc\"},transpose:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xtype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},ytype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},zsmooth:{valType:\"enumerated\",values:[\"fast\",\"best\",!1],dflt:!1,editType:\"calc\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xgap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},ygap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},zhoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},hovertemplate:i()},{transforms:void 0},a(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../scatter/attributes\":1112}],1002:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../histogram2d/calc\"),s=t(\"../../components/colorscale/calc\"),l=t(\"./convert_column_xyz\"),c=t(\"./clean_2d_array\"),u=t(\"./interp2d\"),h=t(\"./find_empties\"),f=t(\"./make_bound_array\");e.exports=function(t,e){var r,p,d,g,v,m,y,x,b,_=a.getFromId(t,e.xaxis||\"x\"),w=a.getFromId(t,e.yaxis||\"y\"),k=n.traceIs(e,\"contour\"),T=n.traceIs(e,\"histogram\"),A=n.traceIs(e,\"gl2d\"),M=k?\"best\":e.zsmooth;if(_._minDtick=0,w._minDtick=0,T)r=(b=o(t,e)).x,p=b.x0,d=b.dx,g=b.y,v=b.y0,m=b.dy,y=b.z;else{var S=e.z;i.isArray1D(S)?(l(e,_,w,\"x\",\"y\",[\"z\"]),r=e._x,g=e._y,S=e._z):(r=e._x=e.x?_.makeCalcdata(e,\"x\"):[],g=e._y=e.y?w.makeCalcdata(e,\"y\"):[]),p=e.x0,d=e.dx,v=e.y0,m=e.dy,y=c(S,e,_,w),(k||e.connectgaps)&&(e._emptypoints=h(y),u(y,e._emptypoints))}function E(t){M=e._input.zsmooth=e.zsmooth=!1,i.warn('cannot use zsmooth: \"fast\": '+t)}if(\"fast\"===M)if(\"log\"===_.type||\"log\"===w.type)E(\"log axis found\");else if(!T){if(r.length){var C=(r[r.length-1]-r[0])/(r.length-1),L=Math.abs(C/100);for(x=0;x<r.length-1;x++)if(Math.abs(r[x+1]-r[x]-C)>L){E(\"x scale is not linear\");break}}if(g.length&&\"fast\"===M){var P=(g[g.length-1]-g[0])/(g.length-1),O=Math.abs(P/100);for(x=0;x<g.length-1;x++)if(Math.abs(g[x+1]-g[x]-P)>O){E(\"y scale is not linear\");break}}}var z=i.maxRowLength(y),I=\"scaled\"===e.xtype?\"\":r,D=f(e,I,p,d,z,_),R=\"scaled\"===e.ytype?\"\":g,F=f(e,R,v,m,y.length,w);A||(e._extremes[_._id]=a.findExtremes(_,D),e._extremes[w._id]=a.findExtremes(w,F));var B={x:D,y:F,z:y,text:e._text||e.text,hovertext:e._hovertext||e.hovertext};if(I&&I.length===D.length-1&&(B.xCenter=I),R&&R.length===F.length-1&&(B.yCenter=R),T&&(B.xRanges=b.xRanges,B.yRanges=b.yRanges,B.pts=b.pts),k||s(t,e,{vals:y,cLetter:\"z\"}),k&&e.contours&&\"heatmap\"===e.contours.coloring){var N={type:\"contour\"===e.type?\"heatmap\":\"histogram2d\",xcalendar:e.xcalendar,ycalendar:e.ycalendar};B.xfill=f(N,I,p,d,z,_),B.yfill=f(N,R,v,m,y.length,w)}return[B]}},{\"../../components/colorscale/calc\":601,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../histogram2d/calc\":1033,\"./clean_2d_array\":1003,\"./convert_column_xyz\":1005,\"./find_empties\":1007,\"./interp2d\":1010,\"./make_bound_array\":1011}],1003:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r,o){var s,l,c,u,h,f;function p(t){if(n(t))return+t}if(e&&e.transpose){for(s=0,h=0;h<t.length;h++)s=Math.max(s,t[h].length);if(0===s)return!1;c=function(t){return t.length},u=function(t,e,r){return(t[r]||[])[e]}}else s=t.length,c=function(t,e){return t[e].length},u=function(t,e,r){return(t[e]||[])[r]};var d=function(t,e,r){return e===a||r===a?a:u(t,e,r)};function g(t){if(e&&\"carpet\"!==e.type&&\"contourcarpet\"!==e.type&&t&&\"category\"===t.type&&e[\"_\"+t._id.charAt(0)].length){var r=t._id.charAt(0),n={},o=e[\"_\"+r+\"CategoryMap\"]||e[r];for(h=0;h<o.length;h++)n[o[h]]=h;return function(e){var r=n[t._categories[e]];return r+1?r:a}}return i.identity}var v=g(r),m=g(o);o&&\"category\"===o.type&&(s=o._categories.length);var y=new Array(s);for(h=0;h<s;h++)for(l=r&&\"category\"===r.type?r._categories.length:c(t,h),y[h]=new Array(l),f=0;f<l;f++)y[h][f]=p(d(t,m(h),v(f)));return y}},{\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],1004:[function(t,e,r){\"use strict\";e.exports={min:\"zmin\",max:\"zmax\"}},{}],1005:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r,a,o,s){var l,c,u,h,f=t._length,p=e.makeCalcdata(t,a),d=r.makeCalcdata(t,o),g=t.text,v=void 0!==g&&n.isArray1D(g),m=t.hovertext,y=void 0!==m&&n.isArray1D(m),x=n.distinctVals(p),b=x.vals,_=n.distinctVals(d),w=_.vals,k=[];for(l=0;l<s.length;l++)k[l]=n.init2dArray(w.length,b.length);for(v&&(u=n.init2dArray(w.length,b.length)),y&&(h=n.init2dArray(w.length,b.length)),l=0;l<f;l++)if(p[l]!==i&&d[l]!==i){var T=n.findBin(p[l]+x.minDiff/2,b),A=n.findBin(d[l]+_.minDiff/2,w);for(c=0;c<s.length;c++){var M=t[s[c]];k[c][A][T]=M[l]}v&&(u[A][T]=g[l]),y&&(h[A][T]=m[l])}for(t[\"_\"+a]=b,t[\"_\"+o]=w,c=0;c<s.length;c++)t[\"_\"+s[c]]=k[c];v&&(t._text=u),y&&(t._hovertext=h),e&&\"category\"===e.type&&(t[\"_\"+a+\"CategoryMap\"]=b.map(function(t){return e._categories[t]})),r&&\"category\"===r.type&&(t[\"_\"+o+\"CategoryMap\"]=w.map(function(t){return r._categories[t]}))}},{\"../../constants/numerical\":695,\"../../lib\":719}],1006:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xyz_defaults\"),a=t(\"./style_defaults\"),o=t(\"../../components/colorscale/defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l)?(c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\"),a(t,e,c,l),c(\"connectgaps\",n.isArray1D(e.z)&&!1!==e.zsmooth),o(t,e,l,c,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":1001,\"./style_defaults\":1014,\"./xyz_defaults\":1015}],1007:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").maxRowLength;e.exports=function(t){var e,r,i,a,o,s,l,c,u=[],h={},f=[],p=t[0],d=[],g=[0,0,0],v=n(t);for(r=0;r<t.length;r++)for(e=d,d=p,p=t[r+1]||[],i=0;i<v;i++)void 0===d[i]&&((s=(void 0!==d[i-1]?1:0)+(void 0!==d[i+1]?1:0)+(void 0!==e[i]?1:0)+(void 0!==p[i]?1:0))?(0===r&&s++,0===i&&s++,r===t.length-1&&s++,i===d.length-1&&s++,s<4&&(h[[r,i]]=[r,i,s]),u.push([r,i,s])):f.push([r,i]));for(;f.length;){for(l={},c=!1,o=f.length-1;o>=0;o--)(s=((h[[(r=(a=f[o])[0])-1,i=a[1]]]||g)[2]+(h[[r+1,i]]||g)[2]+(h[[r,i-1]]||g)[2]+(h[[r,i+1]]||g)[2])/20)&&(l[a]=[r,i,s],f.splice(o,1),c=!0);if(!c)throw\"findEmpties iterated with no new neighbors\";for(a in l)h[a]=l[a],u.push(l[a])}return u.sort(function(t,e){return e[2]-t[2]})}},{\"../../lib\":719}],1008:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../components/colorscale\").extractOpts;e.exports=function(t,e,r,s,l,c){var u,h,f,p,d=t.cd[0],g=d.trace,v=t.xa,m=t.ya,y=d.x,x=d.y,b=d.z,_=d.xCenter,w=d.yCenter,k=d.zmask,T=g.zhoverformat,A=y,M=x;if(!1!==t.index){try{f=Math.round(t.index[1]),p=Math.round(t.index[0])}catch(e){return void i.error(\"Error hovering on heatmap, pointNumber must be [row,col], found:\",t.index)}if(f<0||f>=b[0].length||p<0||p>b.length)return}else{if(n.inbox(e-y[0],e-y[y.length-1],0)>0||n.inbox(r-x[0],r-x[x.length-1],0)>0)return;if(c){var S;for(A=[2*y[0]-y[1]],S=1;S<y.length;S++)A.push((y[S]+y[S-1])/2);for(A.push([2*y[y.length-1]-y[y.length-2]]),M=[2*x[0]-x[1]],S=1;S<x.length;S++)M.push((x[S]+x[S-1])/2);M.push([2*x[x.length-1]-x[x.length-2]])}f=Math.max(0,Math.min(A.length-2,i.findBin(e,A))),p=Math.max(0,Math.min(M.length-2,i.findBin(r,M)))}var E=v.c2p(y[f]),C=v.c2p(y[f+1]),L=m.c2p(x[p]),P=m.c2p(x[p+1]);c?(C=E,u=y[f],P=L,h=x[p]):(u=_?_[f]:(y[f]+y[f+1])/2,h=w?w[p]:(x[p]+x[p+1])/2,v&&\"category\"===v.type&&(u=y[f]),m&&\"category\"===m.type&&(h=x[p]),g.zsmooth&&(E=C=v.c2p(u),L=P=m.c2p(h)));var O,z=b[p][f];k&&!k[p][f]&&(z=void 0),Array.isArray(d.hovertext)&&Array.isArray(d.hovertext[p])?O=d.hovertext[p][f]:Array.isArray(d.text)&&Array.isArray(d.text[p])&&(O=d.text[p][f]);var I=o(g),D={type:\"linear\",range:[I.min,I.max],hoverformat:T,_separators:v._separators,_numFormat:v._numFormat},R=a.tickText(D,z,\"hover\").text;return[i.extendFlat(t,{index:[p,f],distance:t.maxHoverDistance,spikeDistance:t.maxSpikeDistance,x0:E,x1:C,y0:L,y1:P,xLabelVal:u,yLabelVal:h,zLabelVal:z,zLabel:R,text:O})]}},{\"../../components/colorscale\":605,\"../../components/fx\":632,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],1009:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:t(\"./colorbar\"),style:t(\"./style\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"heatmap\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":1001,\"./calc\":1002,\"./colorbar\":1004,\"./defaults\":1006,\"./hover\":1008,\"./plot\":1012,\"./style\":1013}],1010:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[-1,0],[1,0],[0,-1],[0,1]];function a(t){return.5-.25*Math.min(1,.5*t)}function o(t,e,r){var n,a,o,s,l,c,u,h,f,p,d,g,v,m=0;for(s=0;s<e.length;s++){for(a=(n=e[s])[0],o=n[1],d=t[a][o],p=0,f=0,l=0;l<4;l++)(u=t[a+(c=i[l])[0]])&&void 0!==(h=u[o+c[1]])&&(0===p?g=v=h:(g=Math.min(g,h),v=Math.max(v,h)),f++,p+=h);if(0===f)throw\"iterateInterp2d order is wrong: no defined neighbors\";t[a][o]=p/f,void 0===d?f<4&&(m=1):(t[a][o]=(1+r)*t[a][o]-r*d,v>g&&(m=Math.max(m,Math.abs(t[a][o]-d)/(v-g))))}return m}e.exports=function(t,e){var r,i=1;for(o(t,e),r=0;r<e.length&&!(e[r][2]<4);r++);for(e=e.slice(r),r=0;r<100&&i>.01;r++)i=o(t,e,a(i));return i>.01&&n.log(\"interp2d didn't converge quickly\",i),t}},{\"../../lib\":719}],1011:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a,o,s){var l,c,u,h=[],f=n.traceIs(t,\"contour\"),p=n.traceIs(t,\"histogram\"),d=n.traceIs(t,\"gl2d\");if(i(e)&&e.length>1&&!p&&\"category\"!==s.type){var g=e.length;if(!(g<=o))return f?e.slice(0,o):e.slice(0,o+1);if(f||d)h=e.slice(0,o);else if(1===o)h=[e[0]-.5,e[0]+.5];else{for(h=[1.5*e[0]-.5*e[1]],u=1;u<g;u++)h.push(.5*(e[u-1]+e[u]));h.push(1.5*e[g-1]-.5*e[g-2])}if(g<o){var v=h[h.length-1],m=v-h[h.length-2];for(u=g;u<o;u++)v+=m,h.push(v)}}else{var y=t[s._id.charAt(0)+\"calendar\"];if(p)l=s.r2c(r,0,y);else if(i(e)&&1===e.length)l=e[0];else if(void 0===r)l=0;else{l=(\"log\"===s.type?s.d2c:s.r2c)(r,0,y)}for(c=a||1,u=f||d?0:-.5;u<o;u++)h.push(l+c*u)}return h}},{\"../../lib\":719,\"../../registry\":847}],1012:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/colorscale\").makeColorScaleFuncFromTrace,l=t(\"../../constants/xmlns_namespaces\");function c(t,e){var r=e.length-2,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=e[n+1],s=o.constrain(n+(t-i)/(a-i)-.5,0,r),l=Math.round(s),c=Math.abs(s-l);return s&&s!==r&&c?{bin0:l,frac:c,bin1:Math.round(l+c/(s-l))}:{bin0:l,bin1:l,frac:0}}function u(t,e){var r=e.length-1,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=(t-i)/(e[n+1]-i)||0;return a<=0?{bin0:n,bin1:n,frac:0}:a<.5?{bin0:n,bin1:n+1,frac:a}:{bin0:n+1,bin1:n,frac:1-a}}function h(t,e,r){t[e]=r[0],t[e+1]=r[1],t[e+2]=r[2],t[e+3]=Math.round(255*r[3])}e.exports=function(t,e,r,f){var p=e.xaxis,d=e.yaxis;o.makeTraceGroups(f,r,\"hm\").each(function(e){var r,f,g,v,m,y,x=n.select(this),b=e[0],_=b.trace,w=b.z,k=b.x,T=b.y,A=b.xCenter,M=b.yCenter,S=a.traceIs(_,\"contour\"),E=S?\"best\":_.zsmooth,C=w.length,L=o.maxRowLength(w),P=!1,O=!1;for(y=0;void 0===r&&y<k.length-1;)r=p.c2p(k[y]),y++;for(y=k.length-1;void 0===f&&y>0;)f=p.c2p(k[y]),y--;for(f<r&&(g=f,f=r,r=g,P=!0),y=0;void 0===v&&y<T.length-1;)v=d.c2p(T[y]),y++;for(y=T.length-1;void 0===m&&y>0;)m=d.c2p(T[y]),y--;if(m<v&&(g=v,v=m,m=g,O=!0),S&&(A=k,M=T,k=b.xfill,T=b.yfill),\"fast\"!==E){var z=\"best\"===E?0:.5;r=Math.max(-z*p._length,r),f=Math.min((1+z)*p._length,f),v=Math.max(-z*d._length,v),m=Math.min((1+z)*d._length,m)}var I=Math.round(f-r),D=Math.round(m-v);if(I<=0||D<=0){x.selectAll(\"image\").data([]).exit().remove()}else{var R,F;\"fast\"===E?(R=L,F=C):(R=I,F=D);var B=document.createElement(\"canvas\");B.width=R,B.height=F;var N,j,U=B.getContext(\"2d\"),V=s(_,{noNumericCheck:!0,returnArray:!0});\"fast\"===E?(N=P?function(t){return L-1-t}:o.identity,j=O?function(t){return C-1-t}:o.identity):(N=function(t){return o.constrain(Math.round(p.c2p(k[t])-r),0,I)},j=function(t){return o.constrain(Math.round(d.c2p(T[t])-v),0,D)});var q,H,G,Y,W,X=j(0),Z=[X,X],J=P?0:1,K=O?0:1,$=0,Q=0,tt=0,et=0;if(E){var rt,nt=0;try{rt=new Uint8Array(I*D*4)}catch(t){rt=new Array(I*D*4)}if(\"best\"===E){var it,at,ot,st=A||k,lt=M||T,ct=new Array(st.length),ut=new Array(lt.length),ht=new Array(I),ft=A?u:c,pt=M?u:c;for(y=0;y<st.length;y++)ct[y]=Math.round(p.c2p(st[y])-r);for(y=0;y<lt.length;y++)ut[y]=Math.round(d.c2p(lt[y])-v);for(y=0;y<I;y++)ht[y]=ft(y,ct);for(H=0;H<D;H++)for(at=w[(it=pt(H,ut)).bin0],ot=w[it.bin1],y=0;y<I;y++,nt+=4)h(rt,nt,W=Tt(at,ot,ht[y],it))}else for(H=0;H<C;H++)for(Y=w[H],Z=j(H),y=0;y<I;y++)W=kt(Y[y],1),h(rt,nt=4*(Z*I+N(y)),W);var dt=U.createImageData(I,D);try{dt.data.set(rt)}catch(t){var gt=dt.data,vt=gt.length;for(H=0;H<vt;H++)gt[H]=rt[H]}U.putImageData(dt,0,0)}else{var mt=_.xgap,yt=_.ygap,xt=Math.floor(mt/2),bt=Math.floor(yt/2);for(H=0;H<C;H++)if(Y=w[H],Z.reverse(),Z[K]=j(H+1),Z[0]!==Z[1]&&void 0!==Z[0]&&void 0!==Z[1])for(q=[G=N(0),G],y=0;y<L;y++)q.reverse(),q[J]=N(y+1),q[0]!==q[1]&&void 0!==q[0]&&void 0!==q[1]&&(W=kt(Y[y],(q[1]-q[0])*(Z[1]-Z[0])),U.fillStyle=\"rgba(\"+W.join(\",\")+\")\",U.fillRect(q[0]+xt,Z[0]+bt,q[1]-q[0]-mt,Z[1]-Z[0]-yt))}Q=Math.round(Q/$),tt=Math.round(tt/$),et=Math.round(et/$);var _t=i(\"rgb(\"+Q+\",\"+tt+\",\"+et+\")\");t._hmpixcount=(t._hmpixcount||0)+$,t._hmlumcount=(t._hmlumcount||0)+$*_t.getLuminance();var wt=x.selectAll(\"image\").data(e);wt.enter().append(\"svg:image\").attr({xmlns:l.svg,preserveAspectRatio:\"none\"}),wt.attr({height:D,width:I,x:r,y:v,\"xlink:href\":B.toDataURL(\"image/png\")})}function kt(t,e){if(void 0!==t){var r=V(t);return r[0]=Math.round(r[0]),r[1]=Math.round(r[1]),r[2]=Math.round(r[2]),$+=e,Q+=r[0]*e,tt+=r[1]*e,et+=r[2]*e,r}return[0,0,0,0]}function Tt(t,e,r,n){var i=t[r.bin0];if(void 0===i)return kt(void 0,1);var a,o=t[r.bin1],s=e[r.bin0],l=e[r.bin1],c=o-i||0,u=s-i||0;return a=void 0===o?void 0===l?0:void 0===s?2*(l-i):2*(2*l-s-i)/3:void 0===l?void 0===s?0:2*(2*i-o-s)/3:void 0===s?2*(2*l-o-i)/3:l+i-o-s,kt(i+r.frac*c+n.frac*(u+r.frac*a))}})}},{\"../../components/colorscale\":605,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../registry\":847,d3:163,tinycolor2:537}],1013:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t){n.select(t).selectAll(\".hm image\").style(\"opacity\",function(t){return t.trace.opacity})}},{d3:163}],1014:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){!1===r(\"zsmooth\")&&(r(\"xgap\"),r(\"ygap\")),r(\"zhoverformat\")}},{}],1015:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\");function o(t,e){var r=e(t);return\"scaled\"===(r?e(t+\"type\",\"array\"):\"scaled\")&&(e(t+\"0\"),e(\"d\"+t)),r}e.exports=function(t,e,r,s,l,c){var u,h,f=r(\"z\");if(l=l||\"x\",c=c||\"y\",void 0===f||!f.length)return 0;if(i.isArray1D(t.z)){u=r(l),h=r(c);var p=i.minRowLength(u),d=i.minRowLength(h);if(0===p||0===d)return 0;e._length=Math.min(p,d,f.length)}else{if(u=o(l,r),h=o(c,r),!function(t){for(var e,r=!0,a=!1,o=!1,s=0;s<t.length;s++){if(e=t[s],!i.isArrayOrTypedArray(e)){r=!1;break}e.length>0&&(a=!0);for(var l=0;l<e.length;l++)if(n(e[l])){o=!0;break}}return r&&a&&o}(f))return 0;r(\"transpose\"),e._length=null}return a.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[l,c],s),!0}},{\"../../lib\":719,\"../../registry\":847,\"fast-isnumeric\":225}],1016:[function(t,e,r){\"use strict\";for(var n=t(\"../heatmap/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=[\"z\",\"x\",\"x0\",\"dx\",\"y\",\"y0\",\"dy\",\"text\",\"transpose\",\"xtype\",\"ytype\"],l={},c=0;c<s.length;c++){var u=s[c];l[u]=n[u]}a(l,i(\"\",{cLetter:\"z\",autoColorDflt:!1})),e.exports=o(l,\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../heatmap/attributes\":1001}],1017:[function(t,e,r){\"use strict\";var n=t(\"gl-heatmap2d\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib/str2rgbarray\");function o(t,e){this.scene=t,this.uid=e,this.type=\"heatmapgl\",this.name=\"\",this.hoverinfo=\"all\",this.xData=[],this.yData=[],this.zData=[],this.textLabels=[],this.idToIndex=[],this.bounds=[0,0,0,0],this.options={z:[],x:[],y:[],shape:[0,0],colorLevels:[0],colorValues:[0,0,0,1]},this.heatmap=n(t.glplot,this.options),this.heatmap._trace=this}var s=o.prototype;s.handlePick=function(t){var e=this.options,r=e.shape,n=t.pointId,i=n%r[0],a=Math.floor(n/r[0]),o=n;return{trace:this,dataCoord:t.dataCoord,traceCoord:[e.x[i],e.y[a],e.z[o]],textLabel:this.textLabels[n],name:this.name,pointIndex:[a,i],hoverinfo:this.hoverinfo}},s.update=function(t,e){var r=e[0];this.index=t.index,this.name=t.name,this.hoverinfo=t.hoverinfo;var n=r.z;this.options.z=[].concat.apply([],n);var o=n[0].length,s=n.length;this.options.shape=[o,s],this.options.x=r.x,this.options.y=r.y;var l=function(t){for(var e=t.colorscale,r=t.zmin,n=t.zmax,i=e.length,o=new Array(i),s=new Array(4*i),l=0;l<i;l++){var c=e[l],u=a(c[1]);o[l]=r+c[0]*(n-r);for(var h=0;h<4;h++)s[4*l+h]=u[h]}return{colorLevels:o,colorValues:s}}(t);this.options.colorLevels=l.colorLevels,this.options.colorValues=l.colorValues,this.textLabels=[].concat.apply([],t.text),this.heatmap.update(this.options);var c=this.scene.xaxis,u=this.scene.yaxis;t._extremes[c._id]=i.findExtremes(c,r.x),t._extremes[u._id]=i.findExtremes(u,r.y)},s.dispose=function(){this.heatmap.dispose()},e.exports=function(t,e,r){var n=new o(t,e.uid);return n.update(e,r),n}},{\"../../lib/str2rgbarray\":742,\"../../plots/cartesian/axes\":767,\"gl-heatmap2d\":251}],1018:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"../heatmap/defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../heatmap/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"heatmapgl\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"2dMap\"],meta:{}}},{\"../../plots/gl2d\":805,\"../heatmap/calc\":1002,\"../heatmap/colorbar\":1004,\"../heatmap/defaults\":1006,\"./attributes\":1016,\"./convert\":1017}],1019:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"./bin_attributes\"),o=t(\"./constants\"),s=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),orientation:n.orientation,histfunc:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"min\",\"max\"],dflt:\"count\",editType:\"calc\"},histnorm:{valType:\"enumerated\",values:[\"\",\"percent\",\"probability\",\"density\",\"probability density\"],dflt:\"\",editType:\"calc\"},cumulative:{enabled:{valType:\"boolean\",dflt:!1,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"increasing\",\"decreasing\"],dflt:\"increasing\",editType:\"calc\"},currentbin:{valType:\"enumerated\",values:[\"include\",\"exclude\",\"half\"],dflt:\"include\",editType:\"calc\"},editType:\"calc\"},nbinsx:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},xbins:a(\"x\",!0),nbinsy:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},ybins:a(\"y\",!0),autobinx:{valType:\"boolean\",dflt:null,editType:\"calc\"},autobiny:{valType:\"boolean\",dflt:null,editType:\"calc\"},bingroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:i({},{keys:o.eventDataKeys}),marker:n.marker,offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,_deprecated:{bardir:n._deprecated.bardir}}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../bar/attributes\":857,\"./bin_attributes\":1021,\"./constants\":1025}],1020:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=t.length,n=0,i=0;i<r;i++)e[i]?(t[i]/=e[i],n+=t[i]):t[i]=null;return n}},{}],1021:[function(t,e,r){\"use strict\";e.exports=function(t,e){return{start:{valType:\"any\",editType:\"calc\"},end:{valType:\"any\",editType:\"calc\"},size:{valType:\"any\",editType:\"calc\"},editType:\"calc\"}}},{}],1022:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports={count:function(t,e,r){return r[t]++,1},sum:function(t,e,r,i){var a=i[e];return n(a)?(a=Number(a),r[t]+=a,a):0},avg:function(t,e,r,i,a){var o=i[e];return n(o)&&(o=Number(o),r[t]+=o,a[t]++),0},min:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]>a){var o=a-r[t];return r[t]=a,o}}return 0},max:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]<a){var o=a-r[t];return r[t]=a,o}}return 0}}},{\"fast-isnumeric\":225}],1023:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.ONEAVGYEAR,a=n.ONEAVGMONTH,o=n.ONEDAY,s=n.ONEHOUR,l=n.ONEMIN,c=n.ONESEC,u=t(\"../../plots/cartesian/axes\").tickIncrement;function h(t,e,r,n){if(t*e<=0)return 1/0;for(var i=Math.abs(e-t),a=\"date\"===r.type,o=f(i,a),s=0;s<10;s++){var l=f(80*o,a);if(o===l)break;if(!p(l,t,e,a,r,n))break;o=l}return o}function f(t,e){return e&&t>c?t>o?t>1.1*i?i:t>1.1*a?a:o:t>s?s:t>l?l:c:Math.pow(10,Math.floor(Math.log(t)/Math.LN10))}function p(t,e,r,n,a,s){if(n&&t>o){var l=d(e,a,s),c=d(r,a,s),u=t===i?0:1;return l[u]!==c[u]}return Math.floor(r/t)-Math.floor(e/t)>.1}function d(t,e,r){var n=e.c2d(t,i,r).split(\"-\");return\"\"===n[0]&&(n.unshift(),n[0]=\"-\"+n[0]),n}e.exports=function(t,e,r,n,a){var s,l,c=-1.1*e,f=-.1*e,p=t-f,d=r[0],g=r[1],v=Math.min(h(d+f,d+p,n,a),h(g+f,g+p,n,a)),m=Math.min(h(d+c,d+f,n,a),h(g+c,g+f,n,a));if(v>m&&m<Math.abs(g-d)/4e3?(s=v,l=!1):(s=Math.min(v,m),l=!0),\"date\"===n.type&&s>o){var y=s===i?1:6,x=s===i?\"M12\":\"M1\";return function(e,r){var o=n.c2d(e,i,a),s=o.indexOf(\"-\",y);s>0&&(o=o.substr(0,s));var c=n.d2c(o,0,a);if(c<e){var h=u(c,x,!1,a);(c+h)/2<e+t&&(c=h)}return r&&l?u(c,x,!0,a):c}}return function(e,r){var n=s*Math.round(e/s);return n+s/10<e&&n+.9*s<e+t&&(n+=s),r&&l&&(n-=s),n}}},{\"../../constants/numerical\":695,\"../../plots/cartesian/axes\":767}],1024:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../bar/arrays_to_calcdata\"),l=t(\"./bin_functions\"),c=t(\"./norm_functions\"),u=t(\"./average\"),h=t(\"./bin_label_vals\");function f(t,e,r,s,l){var c,u,h,p,d,g,v,m=s+\"bins\",y=t._fullLayout,x=e[\"_\"+s+\"bingroup\"],b=y._histogramBinOpts[x],_=\"overlay\"===y.barmode,w=function(t){return r.r2c(t,0,p)},k=function(t){return r.c2r(t,0,p)},T=\"date\"===r.type?function(t){return t||0===t?i.cleanDate(t,null,p):null}:function(t){return n(t)?Number(t):null};function A(t,e,r){e[t+\"Found\"]?(e[t]=T(e[t]),null===e[t]&&(e[t]=r[t])):(g[t]=e[t]=r[t],i.nestedProperty(u[0],m+\".\"+t).set(r[t]))}if(e[\"_\"+s+\"autoBinFinished\"])delete e[\"_\"+s+\"autoBinFinished\"];else{u=b.traces;var M=[],S=!0,E=!1,C=!1;for(c=0;c<u.length;c++)if((h=u[c]).visible){var L=b.dirs[c];d=h[\"_\"+L+\"pos0\"]=r.makeCalcdata(h,L),M=i.concat(M,d),delete h[\"_\"+s+\"autoBinFinished\"],!0===e.visible&&(S?S=!1:(delete h._autoBin,h[\"_\"+s+\"autoBinFinished\"]=1),a.traceIs(h,\"2dMap\")&&(E=!0),\"histogram2dcontour\"===h.type&&(C=!0))}p=u[0][s+\"calendar\"];var P=o.autoBin(M,r,b.nbins,E,p,b.sizeFound&&b.size),O=u[0]._autoBin={};if(g=O[b.dirs[0]]={},C&&(b.size||(P.start=k(o.tickIncrement(w(P.start),P.size,!0,p))),void 0===b.end&&(P.end=k(o.tickIncrement(w(P.end),P.size,!1,p)))),_&&!a.traceIs(e,\"2dMap\")&&0===P._dataSpan&&\"category\"!==r.type&&\"multicategory\"!==r.type){if(l)return[P,d,!0];P=function(t,e,r,n,a){var o,s,l,c=t._fullLayout,u=function(t,e){for(var r=e.xaxis,n=e.yaxis,i=e.orientation,a=[],o=t._fullData,s=0;s<o.length;s++){var l=o[s];\"histogram\"===l.type&&!0===l.visible&&l.orientation===i&&l.xaxis===r&&l.yaxis===n&&a.push(l)}return a}(t,e),h=!1,p=1/0,d=[e];for(o=0;o<u.length;o++)if((s=u[o])===e)h=!0;else if(h){var g=f(t,s,r,n,!0),v=g[0],m=g[2];s[\"_\"+n+\"autoBinFinished\"]=1,s[\"_\"+n+\"pos0\"]=g[1],m?d.push(s):p=Math.min(p,v.size)}else l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]],p=Math.min(p,l.size||s[a].size);var y=new Array(d.length);for(o=0;o<d.length;o++)for(var x=d[o][\"_\"+n+\"pos0\"],b=0;b<x.length;b++)if(void 0!==x[b]){y[o]=x[b];break}isFinite(p)||(p=i.distinctVals(y).minDiff);for(o=0;o<d.length;o++){var _=(s=d[o])[n+\"calendar\"],w={start:r.c2r(y[o]-p/2,0,_),end:r.c2r(y[o]+p/2,0,_),size:p};s._input[a]=s[a]=w,(l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]])&&i.extendFlat(l,w)}return e[a]}(t,e,r,s,m)}(v=h.cumulative||{}).enabled&&\"include\"!==v.currentbin&&(\"decreasing\"===v.direction?P.start=k(o.tickIncrement(w(P.start),P.size,!0,p)):P.end=k(o.tickIncrement(w(P.end),P.size,!1,p))),b.size=P.size,b.sizeFound||(g.size=P.size,i.nestedProperty(u[0],m+\".size\").set(P.size)),A(\"start\",b,P),A(\"end\",b,P)}d=e[\"_\"+s+\"pos0\"],delete e[\"_\"+s+\"pos0\"];var z=e._input[m]||{},I=i.extendFlat({},b),D=b.start,R=r.r2l(z.start),F=void 0!==R;if((b.startFound||F)&&R!==r.r2l(D)){var B=F?R:i.aggNums(Math.min,null,d),N={type:\"category\"===r.type||\"multicategory\"===r.type?\"linear\":r.type,r2l:r.r2l,dtick:b.size,tick0:D,calendar:p,range:[B,o.tickIncrement(B,b.size,!1,p)].map(r.l2r)},j=o.tickFirst(N);j>r.r2l(B)&&(j=o.tickIncrement(j,b.size,!0,p)),I.start=r.l2r(j),F||i.nestedProperty(e,m+\".start\").set(I.start)}var U=b.end,V=r.r2l(z.end),q=void 0!==V;if((b.endFound||q)&&V!==r.r2l(U)){var H=q?V:i.aggNums(Math.max,null,d);I.end=r.l2r(H),q||i.nestedProperty(e,m+\".start\").set(I.end)}var G=\"autobin\"+s;return!1===e._input[G]&&(e._input[m]=i.extendFlat({},e[m]||{}),delete e._input[G],delete e[G]),[I,d]}e.exports={calc:function(t,e){var r,a,p,d,g=[],v=[],m=o.getFromId(t,\"h\"===e.orientation?e.yaxis:e.xaxis),y=\"h\"===e.orientation?\"y\":\"x\",x={x:\"y\",y:\"x\"}[y],b=e[y+\"calendar\"],_=e.cumulative,w=f(t,e,m,y),k=w[0],T=w[1],A=\"string\"==typeof k.size,M=[],S=A?M:k,E=[],C=[],L=[],P=0,O=e.histnorm,z=e.histfunc,I=-1!==O.indexOf(\"density\");_.enabled&&I&&(O=O.replace(/ ?density$/,\"\"),I=!1);var D,R=\"max\"===z||\"min\"===z?null:0,F=l.count,B=c[O],N=!1,j=function(t){return m.r2c(t,0,b)};for(i.isArrayOrTypedArray(e[x])&&\"count\"!==z&&(D=e[x],N=\"avg\"===z,F=l[z]),r=j(k.start),p=j(k.end)+(r-o.tickIncrement(r,k.size,!1,b))/1e6;r<p&&g.length<1e6&&(a=o.tickIncrement(r,k.size,!1,b),g.push((r+a)/2),v.push(R),L.push([]),M.push(r),I&&E.push(1/(a-r)),N&&C.push(0),!(a<=r));)r=a;M.push(r),A||\"date\"!==m.type||(S={start:j(S.start),end:j(S.end),size:S.size});var U,V=v.length,q=!0,H=1/0,G=1/0,Y={};for(r=0;r<T.length;r++){var W=T[r];(d=i.findBin(W,S))>=0&&d<V&&(P+=F(d,r,v,D,C),q&&L[d].length&&W!==T[L[d][0]]&&(q=!1),L[d].push(r),Y[r]=d,H=Math.min(H,W-M[d]),G=Math.min(G,M[d+1]-W))}q||(U=h(H,G,M,m,b)),N&&(P=u(v,C)),B&&B(v,P,E),_.enabled&&function(t,e,r){var n,i,a;function o(e){a=t[e],t[e]/=2}function s(e){i=t[e],t[e]=a+i/2,a+=i}if(\"half\"===r)if(\"increasing\"===e)for(o(0),n=1;n<t.length;n++)s(n);else for(o(t.length-1),n=t.length-2;n>=0;n--)s(n);else if(\"increasing\"===e){for(n=1;n<t.length;n++)t[n]+=t[n-1];\"exclude\"===r&&(t.unshift(0),t.pop())}else{for(n=t.length-2;n>=0;n--)t[n]+=t[n+1];\"exclude\"===r&&(t.push(0),t.shift())}}(v,_.direction,_.currentbin);var X=Math.min(g.length,v.length),Z=[],J=0,K=X-1;for(r=0;r<X;r++)if(v[r]){J=r;break}for(r=X-1;r>=J;r--)if(v[r]){K=r;break}for(r=J;r<=K;r++)if(n(g[r])&&n(v[r])){var $={p:g[r],s:v[r],b:0};_.enabled||($.pts=L[r],q?$.ph0=$.ph1=L[r].length?T[L[r][0]]:g[r]:($.ph0=U(M[r]),$.ph1=U(M[r+1],!0))),Z.push($)}return 1===Z.length&&(Z[0].width1=o.tickIncrement(Z[0].p,k.size,!1,b)-Z[0].p),s(Z,e),i.isArrayOrTypedArray(e.selectedpoints)&&i.tagSelected(Z,e,Y),Z},calcAllAutoBins:f}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../bar/arrays_to_calcdata\":856,\"./average\":1020,\"./bin_functions\":1022,\"./bin_label_vals\":1023,\"./norm_functions\":1031,\"fast-isnumeric\":225}],1025:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"binNumber\"]}},{}],1026:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../../registry\").traceIs,o=t(\"../bar/defaults\").handleGroupingDefaults,s=n.nestedProperty,l=i.getAxisGroup,c=[{aStr:{x:\"xbins.start\",y:\"ybins.start\"},name:\"start\"},{aStr:{x:\"xbins.end\",y:\"ybins.end\"},name:\"end\"},{aStr:{x:\"xbins.size\",y:\"ybins.size\"},name:\"size\"},{aStr:{x:\"nbinsx\",y:\"nbinsy\"},name:\"nbins\"}],u=[\"x\",\"y\"];e.exports=function(t,e){var r,h,f,p,d,g,v,m=e._histogramBinOpts={},y=[],x={},b=[];function _(t,e){return n.coerce(r._input,r,r._module.attributes,t,e)}function w(t){return\"v\"===t.orientation?\"x\":\"y\"}function k(t,r,a){var o=t.uid+\"__\"+a;r||(r=o);var s=function(t,r){return i.getFromTrace({_fullLayout:e},t,r).type}(t,a),l=t[a+\"calendar\"],c=m[r],u=!0;c&&(s===c.axType&&l===c.calendar?(u=!1,c.traces.push(t),c.dirs.push(a)):(r=o,s!==c.axType&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set on a\",\"type:\"+s,\"axis\",\"with bins on\",\"type:\"+c.axType,\"axis.\"].join(\" \")),l!==c.calendar&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set with a\",l,\"calendar\",\"with bins\",c.calendar?\"on a \"+c.calendar+\" calendar\":\"w/o a set calendar\"].join(\" \")))),u&&(m[r]={traces:[t],dirs:[a],axType:s,calendar:t[a+\"calendar\"]||\"\"}),t[\"_\"+a+\"bingroup\"]=r}for(d=0;d<t.length;d++)r=t[d],a(r,\"histogram\")&&(y.push(r),delete r._xautoBinFinished,delete r._yautoBinFinished,a(r,\"2dMap\")||o(r._input,r,e,_));var T=e._alignmentOpts||{};for(d=0;d<y.length;d++){if(r=y[d],f=\"\",!a(r,\"2dMap\")){if(p=w(r),\"group\"===e.barmode&&r.alignmentgroup){var A=r[p+\"axis\"],M=l(e,A)+r.orientation;(T[M]||{})[r.alignmentgroup]&&(f=M)}f||\"overlay\"===e.barmode||(f=l(e,r.xaxis)+l(e,r.yaxis)+w(r))}f?(x[f]||(x[f]=[]),x[f].push(r)):b.push(r)}for(f in x)if(1!==(h=x[f]).length){var S=!1;for(d=0;d<h.length;d++){r=h[d],S=_(\"bingroup\");break}for(f=S||f,d=0;d<h.length;d++){var E=(r=h[d])._input.bingroup;E&&E!==f&&n.warn([\"Trace\",r.index,\"must match\",\"within bingroup\",f+\".\",\"Ignoring its bingroup:\",E,\"setting.\"].join(\" \")),r.bingroup=f,k(r,f,w(r))}}else b.push(h[0]);for(d=0;d<b.length;d++){r=b[d];var C=_(\"bingroup\");if(a(r,\"2dMap\"))for(v=0;v<2;v++){var L=_((p=u[v])+\"bingroup\",C?C+\"__\"+p:null);k(r,L,p)}else k(r,C,w(r))}for(f in m){var P=m[f];for(h=P.traces,g=0;g<c.length;g++){var O,z,I=c[g],D=I.name;if(\"nbins\"!==D||!P.sizeFound){for(d=0;d<h.length;d++){if(r=h[d],p=P.dirs[d],O=I.aStr[p],void 0!==s(r._input,O).get()){P[D]=_(O),P[D+\"Found\"]=!0;break}(z=(r._autoBin||{})[p]||{})[D]&&s(r,O).set(z[D])}if(\"start\"===D||\"end\"===D)for(;d<h.length;d++)(r=h[d])[\"_\"+p+\"bingroup\"]&&_(O,(z=(r._autoBin||{})[p]||{})[D]);\"nbins\"!==D||P.sizeFound||P.nbinsFound||(r=h[0],P[D]=_(O))}}}}},{\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../bar/defaults\":861}],1027:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../bar/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,n){return i.coerce(t,e,s,r,n)}var u=c(\"x\"),h=c(\"y\");c(\"cumulative.enabled\")&&(c(\"cumulative.direction\"),c(\"cumulative.currentbin\")),c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\");var f=c(\"orientation\",h&&!u?\"h\":\"v\"),p=\"v\"===f?\"x\":\"y\",d=\"v\"===f?\"y\":\"x\",g=u&&h?Math.min(i.minRowLength(u)&&i.minRowLength(h)):i.minRowLength(e[p]||[]);if(g){e._length=g,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],l),e[d]&&c(\"histfunc\"),c(\"histnorm\"),c(\"autobin\"+p),o(t,e,c,r,l),i.coerceSelectionMarkerOpacity(e,c);var v=(e.marker.line||{}).color,m=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");m(t,e,v||a.defaultLine,{axis:\"y\"}),m(t,e,v||a.defaultLine,{axis:\"x\",inherit:\"y\"})}else e.visible=!1}},{\"../../components/color\":593,\"../../lib\":719,\"../../registry\":847,\"../bar/style_defaults\":871,\"./attributes\":1019}],1028:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"zLabelVal\"in e&&(t.z=e.zLabelVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),!(r.cumulative||{}).enabled){var a,o=Array.isArray(i)?n[0].pts[i[0]][i[1]]:n[i].pts;if(t.pointNumbers=o,t.binNumber=t.pointNumber,delete t.pointNumber,delete t.pointIndex,r._indexToPoints){a=[];for(var s=0;s<o.length;s++)a=a.concat(r._indexToPoints[o[s]])}else a=o;t.pointIndices=a}return t}},{}],1029:[function(t,e,r){\"use strict\";var n=t(\"../bar/hover\").hoverPoints,i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o){var s=(t=o[0]).cd[t.index],l=t.cd[0].trace;if(!l.cumulative.enabled){var c=\"h\"===l.orientation?\"y\":\"x\";t[c+\"Label\"]=i(t[c+\"a\"],s.ph0,s.ph1)}return l.hovermplate&&(t.hovertemplate=l.hovertemplate),o}}},{\"../../plots/cartesian/axes\":767,\"../bar/hover\":863}],1030:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"../bar/layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),supplyLayoutDefaults:t(\"../bar/layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"../bar/cross_trace_calc\").crossTraceCalc,plot:t(\"../bar/plot\").plot,layerName:\"barlayer\",style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,colorbar:t(\"../scatter/marker_colorbar\"),hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"histogram\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"histogram\",\"oriented\",\"errorBarsOK\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":778,\"../bar/cross_trace_calc\":860,\"../bar/layout_attributes\":865,\"../bar/layout_defaults\":866,\"../bar/plot\":867,\"../bar/select\":868,\"../bar/style\":870,\"../scatter/marker_colorbar\":1129,\"./attributes\":1019,\"./calc\":1024,\"./cross_trace_defaults\":1026,\"./defaults\":1027,\"./event_data\":1028,\"./hover\":1029}],1031:[function(t,e,r){\"use strict\";e.exports={percent:function(t,e){for(var r=t.length,n=100/e,i=0;i<r;i++)t[i]*=n},probability:function(t,e){for(var r=t.length,n=0;n<r;n++)t[n]/=e},density:function(t,e,r,n){var i=t.length;n=n||1;for(var a=0;a<i;a++)t[a]*=r[a]*n},\"probability density\":function(t,e,r,n){var i=t.length;n&&(e/=n);for(var a=0;a<i;a++)t[a]*=r[a]/e}}},{}],1032:[function(t,e,r){\"use strict\";var n=t(\"../histogram/attributes\"),i=t(\"../histogram/bin_attributes\"),a=t(\"../heatmap/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../lib/extend\").extendFlat;e.exports=l({x:n.x,y:n.y,z:{valType:\"data_array\",editType:\"calc\"},marker:{color:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:i(\"x\"),nbinsy:n.nbinsy,ybins:i(\"y\"),autobinx:n.autobinx,autobiny:n.autobiny,bingroup:l({},n.bingroup,{}),xbingroup:l({},n.bingroup,{}),ybingroup:l({},n.bingroup,{}),xgap:a.xgap,ygap:a.ygap,zsmooth:a.zsmooth,zhoverformat:a.zhoverformat,hovertemplate:o({},{keys:\"z\"})},s(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../heatmap/attributes\":1001,\"../histogram/attributes\":1019,\"../histogram/bin_attributes\":1021}],1033:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../histogram/bin_functions\"),o=t(\"../histogram/norm_functions\"),s=t(\"../histogram/average\"),l=t(\"../histogram/bin_label_vals\"),c=t(\"../histogram/calc\").calcAllAutoBins;function u(t,e,r,n){var i,a=new Array(t);if(n)for(i=0;i<t;i++)a[i]=1/(e[i+1]-e[i]);else{var o=1/r;for(i=0;i<t;i++)a[i]=o}return a}function h(t,e){return{start:t(e.start),end:t(e.end),size:e.size}}function f(t,e,r,n,i,a){var o,s=t.length-1,c=new Array(s),u=l(r,n,t,i,a);for(o=0;o<s;o++){var h=(e||[])[o];c[o]=void 0===h?[u(t[o]),u(t[o+1],!0)]:[h,h]}return c}e.exports=function(t,e){var r,l,p,d,g=i.getFromId(t,e.xaxis),v=i.getFromId(t,e.yaxis),m=e.xcalendar,y=e.ycalendar,x=function(t){return g.r2c(t,0,m)},b=function(t){return v.r2c(t,0,y)},_=c(t,e,g,\"x\"),w=_[0],k=_[1],T=c(t,e,v,\"y\"),A=T[0],M=T[1],S=e._length;k.length>S&&k.splice(S,k.length-S),M.length>S&&M.splice(S,M.length-S);var E=[],C=[],L=[],P=\"string\"==typeof w.size,O=\"string\"==typeof A.size,z=[],I=[],D=P?z:w,R=O?I:A,F=0,B=[],N=[],j=e.histnorm,U=e.histfunc,V=-1!==j.indexOf(\"density\"),q=\"max\"===U||\"min\"===U?null:0,H=a.count,G=o[j],Y=!1,W=[],X=[],Z=\"z\"in e?e.z:\"marker\"in e&&Array.isArray(e.marker.color)?e.marker.color:\"\";Z&&\"count\"!==U&&(Y=\"avg\"===U,H=a[U]);var J=w.size,K=x(w.start),$=x(w.end)+(K-i.tickIncrement(K,J,!1,m))/1e6;for(r=K;r<$;r=i.tickIncrement(r,J,!1,m))C.push(q),z.push(r),Y&&L.push(0);z.push(r);var Q,tt=C.length,et=(r-K)/tt,rt=(Q=K+et/2,g.c2r(Q,0,m)),nt=A.size,it=b(A.start),at=b(A.end)+(it-i.tickIncrement(it,nt,!1,y))/1e6;for(r=it;r<at;r=i.tickIncrement(r,nt,!1,y)){E.push(C.slice()),I.push(r);var ot=new Array(tt);for(l=0;l<tt;l++)ot[l]=[];N.push(ot),Y&&B.push(L.slice())}I.push(r);var st=E.length,lt=(r-it)/st,ct=function(t){return v.c2r(t,0,y)}(it+lt/2);V&&(W=u(C.length,D,et,P),X=u(E.length,R,lt,O)),P||\"date\"!==g.type||(D=h(x,D)),O||\"date\"!==v.type||(R=h(b,R));var ut=!0,ht=!0,ft=new Array(tt),pt=new Array(st),dt=1/0,gt=1/0,vt=1/0,mt=1/0;for(r=0;r<S;r++){var yt=k[r],xt=M[r];p=n.findBin(yt,D),d=n.findBin(xt,R),p>=0&&p<tt&&d>=0&&d<st&&(F+=H(p,r,E[d],Z,B[d]),N[d][p].push(r),ut&&(void 0===ft[p]?ft[p]=yt:ft[p]!==yt&&(ut=!1)),ht&&(void 0===pt[d]?pt[d]=xt:pt[d]!==xt&&(ht=!1)),dt=Math.min(dt,yt-z[p]),gt=Math.min(gt,z[p+1]-yt),vt=Math.min(vt,xt-I[d]),mt=Math.min(mt,I[d+1]-xt))}if(Y)for(d=0;d<st;d++)F+=s(E[d],B[d]);if(G)for(d=0;d<st;d++)G(E[d],F,W,X[d]);return{x:k,xRanges:f(z,ut&&ft,dt,gt,g,m),x0:rt,dx:et,y:M,yRanges:f(I,ht&&pt,vt,mt,v,y),y0:ct,dy:lt,z:E,pts:N}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../histogram/average\":1020,\"../histogram/bin_functions\":1022,\"../histogram/bin_label_vals\":1023,\"../histogram/calc\":1024,\"../histogram/norm_functions\":1031}],1034:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./sample_defaults\"),a=t(\"../heatmap/style_defaults\"),o=t(\"../../components/colorscale/defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,l),o(t,e,l,c,{prefix:\"\",cLetter:\"z\"}),c(\"hovertemplate\"))}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../heatmap/style_defaults\":1014,\"./attributes\":1032,\"./sample_defaults\":1037}],1035:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/hover\"),i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a,o,s){var l=n(t,e,r,a,o,s);if(l){var c=(t=l[0]).index,u=c[0],h=c[1],f=t.cd[0],p=f.xRanges[h],d=f.yRanges[u];return t.xLabel=i(t.xa,p[0],p[1]),t.yLabel=i(t.ya,d[0],d[1]),l}}},{\"../../plots/cartesian/axes\":767,\"../heatmap/hover\":1008}],1036:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../heatmap/calc\"),plot:t(\"../heatmap/plot\"),layerName:\"heatmaplayer\",colorbar:t(\"../heatmap/colorbar\"),style:t(\"../heatmap/style\"),hoverPoints:t(\"./hover\"),eventData:t(\"../histogram/event_data\"),moduleType:\"trace\",name:\"histogram2d\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"histogram\"],meta:{}}},{\"../../plots/cartesian\":778,\"../heatmap/calc\":1002,\"../heatmap/colorbar\":1004,\"../heatmap/plot\":1012,\"../heatmap/style\":1013,\"../histogram/cross_trace_defaults\":1026,\"../histogram/event_data\":1028,\"./attributes\":1032,\"./defaults\":1034,\"./hover\":1035}],1037:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"y\"),l=i.minRowLength(o),c=i.minRowLength(s);l&&c?(e._length=Math.min(l,c),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a),(r(\"z\")||r(\"marker.color\"))&&r(\"histfunc\"),r(\"histnorm\"),r(\"autobinx\"),r(\"autobiny\")):e.visible=!1}},{\"../../lib\":719,\"../../registry\":847}],1038:[function(t,e,r){\"use strict\";var n=t(\"../histogram2d/attributes\"),i=t(\"../contour/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat;e.exports=o({x:n.x,y:n.y,z:n.z,marker:n.marker,histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:n.xbins,nbinsy:n.nbinsy,ybins:n.ybins,autobinx:n.autobinx,autobiny:n.autobiny,bingroup:n.bingroup,xbingroup:n.xbingroup,ybingroup:n.ybingroup,autocontour:i.autocontour,ncontours:i.ncontours,contours:i.contours,line:i.line,zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../contour/attributes\":942,\"../histogram2d/attributes\":1032}],1039:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../histogram2d/sample_defaults\"),a=t(\"../contour/contours_defaults\"),o=t(\"../contour/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,function(r){return n.coerce2(t,e,s,r)}),o(t,e,c,l),c(\"hovertemplate\"))}},{\"../../lib\":719,\"../contour/contours_defaults\":949,\"../contour/style_defaults\":963,\"../histogram2d/sample_defaults\":1037,\"./attributes\":1038}],1040:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../contour/calc\"),plot:t(\"../contour/plot\").plot,layerName:\"contourlayer\",style:t(\"../contour/style\"),colorbar:t(\"../contour/colorbar\"),hoverPoints:t(\"../contour/hover\"),moduleType:\"trace\",name:\"histogram2dcontour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"histogram\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":778,\"../contour/calc\":943,\"../contour/colorbar\":945,\"../contour/hover\":955,\"../contour/plot\":960,\"../contour/style\":962,\"../histogram/cross_trace_defaults\":1026,\"./attributes\":1038,\"./defaults\":1039}],1041:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../lib/extend\").extendDeep,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../components/color/attributes\"),l=t(\"../../plots/domain\").attributes,c=t(\"../../plots/cartesian/layout_attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,h=t(\"../../constants/delta.js\"),f=(t(\"../../constants/docs\").FORMAT_LINK,o({editType:\"plot\",colorEditType:\"plot\"})),p={color:{valType:\"color\",editType:\"plot\"},line:{color:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},width:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"calc\"},thickness:{valType:\"number\",min:0,max:1,dflt:1,editType:\"plot\"},editType:\"calc\"},d={valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},g=u(\"steps\",i({},p,{range:d}));e.exports={mode:{valType:\"flaglist\",editType:\"calc\",flags:[\"number\",\"delta\",\"gauge\"],dflt:\"number\"},value:{valType:\"number\",editType:\"calc\",anim:!0},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},domain:l({name:\"indicator\",trace:!0,editType:\"calc\"}),title:{text:{valType:\"string\",editType:\"plot\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},font:n({},f,{}),editType:\"plot\"},number:{valueformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:n({},f,{}),prefix:{valType:\"string\",dflt:\"\",editType:\"plot\"},suffix:{valType:\"string\",dflt:\"\",editType:\"plot\"},editType:\"plot\"},delta:{reference:{valType:\"number\",editType:\"calc\"},position:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],dflt:\"bottom\",editType:\"plot\"},relative:{valType:\"boolean\",editType:\"plot\",dflt:!1},valueformat:{valType:\"string\",editType:\"plot\"},increasing:{symbol:{valType:\"string\",dflt:h.INCREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:h.INCREASING.COLOR,editType:\"plot\"},editType:\"plot\"},decreasing:{symbol:{valType:\"string\",dflt:h.DECREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:h.DECREASING.COLOR,editType:\"plot\"},editType:\"plot\"},font:n({},f,{}),editType:\"calc\"},gauge:{shape:{valType:\"enumerated\",editType:\"plot\",dflt:\"angular\",values:[\"angular\",\"bullet\"]},bar:i({},p,{color:{dflt:\"green\"}}),bgcolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},axis:a({range:d,visible:n({},c.visible,{dflt:!0}),tickmode:c.tickmode,nticks:c.nticks,tick0:c.tick0,dtick:c.dtick,tickvals:c.tickvals,ticktext:c.ticktext,ticks:n({},c.ticks,{dflt:\"outside\"}),ticklen:c.ticklen,tickwidth:c.tickwidth,tickcolor:c.tickcolor,showticklabels:c.showticklabels,tickfont:o({}),tickangle:c.tickangle,tickformat:c.tickformat,tickformatstops:c.tickformatstops,tickprefix:c.tickprefix,showtickprefix:c.showtickprefix,ticksuffix:c.ticksuffix,showticksuffix:c.showticksuffix,separatethousands:c.separatethousands,exponentformat:c.exponentformat,showexponent:c.showexponent,editType:\"plot\"},\"plot\"),steps:g,threshold:{line:{color:n({},p.line.color,{}),width:n({},p.line.width,{dflt:1}),editType:\"plot\"},thickness:n({},p.thickness,{dflt:.85}),value:{valType:\"number\",editType:\"calc\",dflt:!1},editType:\"plot\"},editType:\"plot\"}}},{\"../../components/color/attributes\":592,\"../../constants/delta.js\":689,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1042:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=r.name=\"indicator\";r.plot=function(t,e,r,o){var s=n.getModule(a),l=i(t.calcdata,s)[0];s.plot(t,l,r,o)},r.clean=function(t,e,r,n){var i=n._has&&n._has(a),o=e._has&&e._has(a);i&&!o&&n._indicatorlayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],1043:[function(t,e,r){\"use strict\";e.exports={calc:function(t,e){var r=[],n=e.value;\"number\"!=typeof e._lastValue&&(e._lastValue=e.value);var i=e._lastValue,a=i;return e._hasDelta&&\"number\"==typeof e.delta.reference&&(a=e.delta.reference),r[0]={y:n,lastY:i,delta:n-a,relativeDelta:(n-a)/a},r}}},{}],1044:[function(t,e,r){\"use strict\";e.exports={defaultNumberFontSize:80,bulletNumberDomainSize:.25,bulletPadding:.025,innerRadius:.75,valueThickness:.5,titlePadding:5,horizontalPadding:10}},{}],1045:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../../plot_api/plot_template\"),s=t(\"../../plots/array_container_defaults\"),l=t(\"./constants.js\"),c=t(\"../../plots/cartesian/tick_value_defaults\"),u=t(\"../../plots/cartesian/tick_mark_defaults\"),h=t(\"../../plots/cartesian/tick_label_defaults\");function f(t,e){function r(r,a){return n.coerce(t,e,i.gauge.steps,r,a)}r(\"color\"),r(\"line.color\"),r(\"line.width\"),r(\"range\"),r(\"thickness\")}e.exports={supplyDefaults:function(t,e,r,p){function d(r,a){return n.coerce(t,e,i,r,a)}a(e,p,d),d(\"mode\"),e._hasNumber=-1!==e.mode.indexOf(\"number\"),e._hasDelta=-1!==e.mode.indexOf(\"delta\"),e._hasGauge=-1!==e.mode.indexOf(\"gauge\");var g=d(\"value\");e._range=[0,\"number\"==typeof g?1.5*g:1];var v,m,y,x,b,_,w=new Array(2);function k(t,e){return n.coerce(y,x,i.gauge,t,e)}function T(t,e){return n.coerce(b,_,i.gauge.axis,t,e)}if(e._hasNumber&&(d(\"number.valueformat\"),d(\"number.font.color\",p.font.color),d(\"number.font.family\",p.font.family),d(\"number.font.size\"),void 0===e.number.font.size&&(e.number.font.size=l.defaultNumberFontSize,w[0]=!0),d(\"number.prefix\"),d(\"number.suffix\"),v=e.number.font.size),e._hasDelta&&(d(\"delta.font.color\",p.font.color),d(\"delta.font.family\",p.font.family),d(\"delta.font.size\"),void 0===e.delta.font.size&&(e.delta.font.size=(e._hasNumber?.5:1)*(v||l.defaultNumberFontSize),w[1]=!0),d(\"delta.reference\",e.value),d(\"delta.relative\"),d(\"delta.valueformat\",e.delta.relative?\"2%\":\"\"),d(\"delta.increasing.symbol\"),d(\"delta.increasing.color\"),d(\"delta.decreasing.symbol\"),d(\"delta.decreasing.color\"),d(\"delta.position\"),m=e.delta.font.size),e._scaleNumbers=(!e._hasNumber||w[0])&&(!e._hasDelta||w[1])||!1,d(\"title.font.color\",p.font.color),d(\"title.font.family\",p.font.family),d(\"title.font.size\",.25*(v||m||l.defaultNumberFontSize)),d(\"title.text\"),e._hasGauge){(y=t.gauge)||(y={}),x=o.newContainer(e,\"gauge\"),k(\"shape\"),(e._isBullet=\"bullet\"===e.gauge.shape)||d(\"title.align\",\"center\"),(e._isAngular=\"angular\"===e.gauge.shape)||d(\"align\",\"center\"),k(\"bgcolor\",p.paper_bgcolor),k(\"borderwidth\"),k(\"bordercolor\"),k(\"bar.color\"),k(\"bar.line.color\"),k(\"bar.line.width\"),k(\"bar.thickness\",l.valueThickness*(\"bullet\"===e.gauge.shape?.5:1)),s(y,x,{name:\"steps\",handleItemDefaults:f}),k(\"threshold.value\"),k(\"threshold.thickness\"),k(\"threshold.line.width\"),k(\"threshold.line.color\"),b={},y&&(b=y.axis||{}),_=o.newContainer(x,\"axis\"),T(\"visible\"),e._range=T(\"range\",e._range);var A={outerTicks:!0};c(b,_,T,\"linear\"),h(b,_,T,\"linear\",A),u(b,_,T,A)}else d(\"title.align\",\"center\"),d(\"align\",\"center\"),e._isAngular=e._isBullet=!1;e._length=null}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/tick_label_defaults\":786,\"../../plots/cartesian/tick_mark_defaults\":787,\"../../plots/cartesian/tick_value_defaults\":788,\"../../plots/domain\":792,\"./attributes\":1041,\"./constants.js\":1044}],1046:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"indicator\",basePlotModule:t(\"./base_plot\"),categories:[\"svg\",\"noOpacity\",\"noHover\"],animatable:!0,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\").calc,plot:t(\"./plot\"),meta:{}}},{\"./attributes\":1041,\"./base_plot\":1042,\"./calc\":1043,\"./defaults\":1045,\"./plot\":1047}],1047:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=i.rad2deg,o=t(\"../../constants/alignment\").MID_SHIFT,s=t(\"../../components/drawing\"),l=t(\"./constants\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"../../plots/cartesian/axes\"),h=t(\"../../plots/cartesian/axis_defaults\"),f=t(\"../../plots/cartesian/position_defaults\"),p=t(\"../../plots/cartesian/layout_attributes\"),d=t(\"../../components/color\"),g={left:\"start\",center:\"middle\",right:\"end\"},v={left:0,center:.5,right:1},m=/[yzafpn\\xb5mkMGTPEZY]/;function y(t){return t&&t.duration>0}function x(t){t.each(function(t){d.stroke(n.select(this),t.line.color)}).each(function(t){d.fill(n.select(this),t.color)}).style(\"stroke-width\",function(t){return t.line.width})}function b(t,e,r){var n=t._fullLayout,a=i.extendFlat({type:\"linear\",ticks:\"outside\",range:r,showline:!0},e),o={type:\"linear\",_id:\"x\"+e._id},s={letter:\"x\",font:n.font,noHover:!0,noTickson:!0};function l(t,e){return i.coerce(a,o,p,t,e)}return h(a,o,l,s,n),f(a,o,l,s),o}function _(t,e){return\"translate(\"+t+\",\"+e+\")\"}function w(t,e,r){return[Math.min(e/t.width,r/t.height),t,e+\"x\"+r]}function k(t,e,r,i){var a=document.createElementNS(\"http://www.w3.org/2000/svg\",\"text\"),o=n.select(a);return o.text(t).attr(\"x\",0).attr(\"y\",0).attr(\"text-anchor\",r).attr(\"data-unformatted\",t).call(c.convertToTspans,i).call(s.font,e),s.bBox(o.node())}function T(t,e,r,n,a,o){var s=\"_cache\"+e;t[s]&&t[s].key===a||(t[s]={key:a,value:r});var l=i.aggNums(o,null,[t[s].value,n],2);return t[s].value=l,l}e.exports=function(t,e,r,h){var f,p=t._fullLayout;y(r)&&h&&(f=h()),i.makeTraceGroups(p._indicatorlayer,e,\"trace\").each(function(e){var h,A,M,S,E,C=e[0].trace,L=n.select(this),P=C._hasGauge,O=C._isAngular,z=C._isBullet,I=C.domain,D={w:p._size.w*(I.x[1]-I.x[0]),h:p._size.h*(I.y[1]-I.y[0]),l:p._size.l+p._size.w*I.x[0],r:p._size.r+p._size.w*(1-I.x[1]),t:p._size.t+p._size.h*(1-I.y[1]),b:p._size.b+p._size.h*I.y[0]},R=D.l+D.w/2,F=D.t+D.h/2,B=Math.min(D.w/2,D.h),N=l.innerRadius*B,j=C.align||\"center\";if(A=F,P){if(O&&(h=R,A=F+B/2,M=function(t){return e=t,r=.9*N,n=Math.sqrt(e.width/2*(e.width/2)+e.height*e.height),[r/n,e,r];var e,r,n}),z){var U=l.bulletPadding,V=1-l.bulletNumberDomainSize+U;h=D.l+(V+(1-V)*v[j])*D.w,M=function(t){return w(t,(l.bulletNumberDomainSize-U)*D.w,D.h)}}}else h=D.l+v[j]*D.w,M=function(t){return w(t,D.w,D.h)};!function(t,e,r,a){var o,l,h,f=r[0].trace,p=a.numbersX,x=a.numbersY,w=f.align||\"center\",A=g[w],M=a.transitionOpts,S=a.onComplete,E=i.ensureSingle(e,\"g\",\"numbers\"),C=[];f._hasNumber&&C.push(\"number\");f._hasDelta&&(C.push(\"delta\"),\"left\"===f.delta.position&&C.reverse());var L=E.selectAll(\"text\").data(C);function P(e,r,n,i){if(!e.match(\"s\")||n>=0==i>=0||r(n).slice(-1).match(m)||r(i).slice(-1).match(m))return r;var a=e.slice().replace(\"s\",\"f\").replace(/\\d+/,function(t){return parseInt(t)-1}),o=b(t,{tickformat:a});return function(t){return Math.abs(t)<1?u.tickText(o,t).text:r(t)}}L.enter().append(\"text\"),L.attr(\"text-anchor\",function(){return A}).attr(\"class\",function(t){return t}).attr(\"x\",null).attr(\"y\",null).attr(\"dx\",null).attr(\"dy\",null),L.exit().remove();var O,z=f.mode+f.align;f._hasDelta&&(O=function(){var e=b(t,{tickformat:f.delta.valueformat},f._range);e.setScale(),u.calcTicks(e);var i=function(t){return u.tickText(e,t).text},a=function(t){var e=f.delta.relative?t.relativeDelta:t.delta;return e},o=function(t,e){return 0===t||\"number\"!=typeof t||isNaN(t)?\"-\":(t>0?f.delta.increasing.symbol:f.delta.decreasing.symbol)+e(t)},h=function(t){return t.delta>=0?f.delta.increasing.color:f.delta.decreasing.color};void 0===f._deltaLastValue&&(f._deltaLastValue=a(r[0]));var p=E.select(\"text.delta\");function g(){p.text(o(a(r[0]),i)).call(d.fill,h(r[0])).call(c.convertToTspans,t)}p.call(s.font,f.delta.font).call(d.fill,h({delta:f._deltaLastValue})),y(M)?p.transition().duration(M.duration).ease(M.easing).tween(\"text\",function(){var t=n.select(this),e=a(r[0]),s=f._deltaLastValue,l=P(f.delta.valueformat,i,s,e),c=n.interpolateNumber(s,e);return f._deltaLastValue=e,function(e){t.text(o(c(e),l)),t.call(d.fill,h({delta:c(e)}))}}).each(\"end\",function(){g(),S&&S()}).each(\"interrupt\",function(){g(),S&&S()}):g();return l=k(o(a(r[0]),i),f.delta.font,A,t),p}(),z+=f.delta.position+f.delta.font.size+f.delta.font.family+f.delta.valueformat,z+=f.delta.increasing.symbol+f.delta.decreasing.symbol,h=l);f._hasNumber&&(!function(){var e=b(t,{tickformat:f.number.valueformat},f._range);e.setScale(),u.calcTicks(e);var i=function(t){return u.tickText(e,t).text},a=f.number.suffix,l=f.number.prefix,h=E.select(\"text.number\");function p(){var e=\"number\"==typeof r[0].y?l+i(r[0].y)+a:\"-\";h.text(e).call(s.font,f.number.font).call(c.convertToTspans,t)}y(M)?h.transition().duration(M.duration).ease(M.easing).each(\"end\",function(){p(),S&&S()}).each(\"interrupt\",function(){p(),S&&S()}).attrTween(\"text\",function(){var t=n.select(this),e=n.interpolateNumber(r[0].lastY,r[0].y);f._lastValue=r[0].y;var o=P(f.number.valueformat,i,r[0].lastY,r[0].y);return function(r){t.text(l+o(e(r))+a)}}):p();o=k(l+i(r[0].y)+a,f.number.font,A,t)}(),z+=f.number.font.size+f.number.font.family+f.number.valueformat+f.number.suffix+f.number.prefix,h=o);if(f._hasDelta&&f._hasNumber){var I,D,R=[(o.left+o.right)/2,(o.top+o.bottom)/2],F=[(l.left+l.right)/2,(l.top+l.bottom)/2],B=.75*f.delta.font.size;\"left\"===f.delta.position&&(I=T(f,\"deltaPos\",0,-1*(o.width*v[f.align]+l.width*(1-v[f.align])+B),z,Math.min),D=R[1]-F[1],h={width:o.width+l.width+B,height:Math.max(o.height,l.height),left:l.left+I,right:o.right,top:Math.min(o.top,l.top+D),bottom:Math.max(o.bottom,l.bottom+D)}),\"right\"===f.delta.position&&(I=T(f,\"deltaPos\",0,o.width*(1-v[f.align])+l.width*v[f.align]+B,z,Math.max),D=R[1]-F[1],h={width:o.width+l.width+B,height:Math.max(o.height,l.height),left:o.left,right:l.right+I,top:Math.min(o.top,l.top+D),bottom:Math.max(o.bottom,l.bottom+D)}),\"bottom\"===f.delta.position&&(I=null,D=l.height,h={width:Math.max(o.width,l.width),height:o.height+l.height,left:Math.min(o.left,l.left),right:Math.max(o.right,l.right),top:o.bottom-o.height,bottom:o.bottom+l.height}),\"top\"===f.delta.position&&(I=null,D=o.top,h={width:Math.max(o.width,l.width),height:o.height+l.height,left:Math.min(o.left,l.left),right:Math.max(o.right,l.right),top:o.bottom-o.height-l.height,bottom:o.bottom}),O.attr({dx:I,dy:D})}(f._hasNumber||f._hasDelta)&&E.attr(\"transform\",function(){var t=a.numbersScaler(h);z+=t[2];var e,r=T(f,\"numbersScale\",1,t[0],z,Math.min);f._scaleNumbers||(r=1),e=f._isAngular?x-r*h.bottom:x-r*(h.top+h.bottom)/2,f._numbersTop=r*h.top+e;var n=h[w];\"center\"===w&&(n=(h.left+h.right)/2);var i=p-r*n;return _(i=T(f,\"numbersTranslate\",0,i,z,Math.max),e)+\" scale(\"+r+\")\"})}(t,L,e,{numbersX:h,numbersY:A,numbersScaler:M,transitionOpts:r,onComplete:f}),P&&(S={range:C.gauge.axis.range,color:C.gauge.bgcolor,line:{color:C.gauge.bordercolor,width:0},thickness:1},E={range:C.gauge.axis.range,color:\"rgba(0, 0, 0, 0)\",line:{color:C.gauge.bordercolor,width:C.gauge.borderwidth},thickness:1});var q=L.selectAll(\"g.angular\").data(O?e:[]);q.exit().remove();var H=L.selectAll(\"g.angularaxis\").data(O?e:[]);H.exit().remove(),O&&function(t,e,r,i){var s,l,c,h,f=r[0].trace,p=i.size,d=i.radius,g=i.innerRadius,v=i.gaugeBg,m=i.gaugeOutline,w=[p.l+p.w/2,p.t+p.h/2+d/2],k=i.gauge,T=i.layer,A=i.transitionOpts,M=i.onComplete,S=Math.PI/2;function E(t){var e=f.gauge.axis.range[0],r=f.gauge.axis.range[1],n=(t-e)/(r-e)*Math.PI-S;return n<-S?-S:n>S?S:n}function C(t){return n.svg.arc().innerRadius((g+d)/2-t/2*(d-g)).outerRadius((g+d)/2+t/2*(d-g)).startAngle(-S)}function L(t){t.attr(\"d\",function(t){return C(t.thickness).startAngle(E(t.range[0])).endAngle(E(t.range[1]))()})}k.enter().append(\"g\").classed(\"angular\",!0),k.attr(\"transform\",_(w[0],w[1])),T.enter().append(\"g\").classed(\"angularaxis\",!0).classed(\"crisp\",!0),T.selectAll(\"g.xangularaxistick,path,text\").remove(),(s=b(t,f.gauge.axis)).type=\"linear\",s.range=f.gauge.axis.range,s._id=\"xangularaxis\",s.setScale();var P=function(t){return(s.range[0]-t.x)/(s.range[1]-s.range[0])*Math.PI+Math.PI},O={},z=u.makeLabelFns(s,0).labelStandoff;O.xFn=function(t){var e=P(t);return Math.cos(e)*z},O.yFn=function(t){var e=P(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(z+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*o)},O.anchorFn=function(t){var e=P(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},O.heightFn=function(t,e,r){var n=P(t);return-.5*(1+Math.sin(n))*r};var I=function(t){return _(w[0]+d*Math.cos(t),w[1]-d*Math.sin(t))};c=function(t){return I(P(t))};if(l=u.calcTicks(s),h=u.getTickSigns(s)[2],s.visible){h=\"inside\"===s.ticks?-1:1;var D=(s.linewidth||1)/2;u.drawTicks(t,s,{vals:l,layer:T,path:\"M\"+h*D+\",0h\"+h*s.ticklen,transFn:function(t){var e=P(t);return I(e)+\"rotate(\"+-a(e)+\")\"}}),u.drawLabels(t,s,{vals:l,layer:T,transFn:c,labelFns:O})}var R=[v].concat(f.gauge.steps),F=k.selectAll(\"g.bg-arc\").data(R);F.enter().append(\"g\").classed(\"bg-arc\",!0).append(\"path\"),F.select(\"path\").call(L).call(x),F.exit().remove();var B=C(f.gauge.bar.thickness),N=k.selectAll(\"g.value-arc\").data([f.gauge.bar]);N.enter().append(\"g\").classed(\"value-arc\",!0).append(\"path\");var j=N.select(\"path\");y(A)?(j.transition().duration(A.duration).ease(A.easing).each(\"end\",function(){M&&M()}).each(\"interrupt\",function(){M&&M()}).attrTween(\"d\",(U=B,V=E(r[0].lastY),q=E(r[0].y),function(){var t=n.interpolate(V,q);return function(e){return U.endAngle(t(e))()}})),f._lastValue=r[0].y):j.attr(\"d\",\"number\"==typeof r[0].y?B.endAngle(E(r[0].y)):\"M0,0Z\");var U,V,q;j.call(x),N.exit().remove(),R=[];var H=f.gauge.threshold.value;H&&R.push({range:[H,H],color:f.gauge.threshold.color,line:{color:f.gauge.threshold.line.color,width:f.gauge.threshold.line.width},thickness:f.gauge.threshold.thickness});var G=k.selectAll(\"g.threshold-arc\").data(R);G.enter().append(\"g\").classed(\"threshold-arc\",!0).append(\"path\"),G.select(\"path\").call(L).call(x),G.exit().remove();var Y=k.selectAll(\"g.gauge-outline\").data([m]);Y.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"path\"),Y.select(\"path\").call(L).call(x),Y.exit().remove()}(t,0,e,{radius:B,innerRadius:N,gauge:q,layer:H,size:D,gaugeBg:S,gaugeOutline:E,transitionOpts:r,onComplete:f});var G=L.selectAll(\"g.bullet\").data(z?e:[]);G.exit().remove();var Y=L.selectAll(\"g.bulletaxis\").data(z?e:[]);Y.exit().remove(),z&&function(t,e,r,n){var i,a,o,s,c,h=r[0].trace,f=n.gauge,p=n.layer,g=n.gaugeBg,v=n.gaugeOutline,m=n.size,_=h.domain,w=n.transitionOpts,k=n.onComplete;f.enter().append(\"g\").classed(\"bullet\",!0),f.attr(\"transform\",\"translate(\"+m.l+\", \"+m.t+\")\"),p.enter().append(\"g\").classed(\"bulletaxis\",!0).classed(\"crisp\",!0),p.selectAll(\"g.xbulletaxistick,path,text\").remove();var T=m.h,A=h.gauge.bar.thickness*T,M=_.x[0],S=_.x[0]+(_.x[1]-_.x[0])*(h._hasNumber||h._hasDelta?1-l.bulletNumberDomainSize:1);(i=b(t,h.gauge.axis))._id=\"xbulletaxis\",i.domain=[M,S],i.setScale(),a=u.calcTicks(i),o=u.makeTransFn(i),s=u.getTickSigns(i)[2],c=m.t+m.h,i.visible&&(u.drawTicks(t,i,{vals:\"inside\"===i.ticks?u.clipEnds(i,a):a,layer:p,path:u.makeTickPath(i,c,s),transFn:o}),u.drawLabels(t,i,{vals:a,layer:p,transFn:o,labelFns:u.makeLabelFns(i,c)}));function E(t){t.attr(\"width\",function(t){return Math.max(0,i.c2p(t.range[1])-i.c2p(t.range[0]))}).attr(\"x\",function(t){return i.c2p(t.range[0])}).attr(\"y\",function(t){return.5*(1-t.thickness)*T}).attr(\"height\",function(t){return t.thickness*T})}var C=[g].concat(h.gauge.steps),L=f.selectAll(\"g.bg-bullet\").data(C);L.enter().append(\"g\").classed(\"bg-bullet\",!0).append(\"rect\"),L.select(\"rect\").call(E).call(x),L.exit().remove();var P=f.selectAll(\"g.value-bullet\").data([h.gauge.bar]);P.enter().append(\"g\").classed(\"value-bullet\",!0).append(\"rect\"),P.select(\"rect\").attr(\"height\",A).attr(\"y\",(T-A)/2).call(x),y(w)?P.select(\"rect\").transition().duration(w.duration).ease(w.easing).each(\"end\",function(){k&&k()}).each(\"interrupt\",function(){k&&k()}).attr(\"width\",Math.max(0,i.c2p(Math.min(h.gauge.axis.range[1],r[0].y)))):P.select(\"rect\").attr(\"width\",\"number\"==typeof r[0].y?Math.max(0,i.c2p(Math.min(h.gauge.axis.range[1],r[0].y))):0);P.exit().remove();var O=r.filter(function(){return h.gauge.threshold.value}),z=f.selectAll(\"g.threshold-bullet\").data(O);z.enter().append(\"g\").classed(\"threshold-bullet\",!0).append(\"line\"),z.select(\"line\").attr(\"x1\",i.c2p(h.gauge.threshold.value)).attr(\"x2\",i.c2p(h.gauge.threshold.value)).attr(\"y1\",(1-h.gauge.threshold.thickness)/2*T).attr(\"y2\",(1-(1-h.gauge.threshold.thickness)/2)*T).call(d.stroke,h.gauge.threshold.line.color).style(\"stroke-width\",h.gauge.threshold.line.width),z.exit().remove();var I=f.selectAll(\"g.gauge-outline\").data([v]);I.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"rect\"),I.select(\"rect\").call(E).call(x),I.exit().remove()}(t,0,e,{gauge:G,layer:Y,size:D,gaugeBg:S,gaugeOutline:E,transitionOpts:r,onComplete:f});var W=L.selectAll(\"text.title\").data(e);W.exit().remove(),W.enter().append(\"text\").classed(\"title\",!0),W.attr(\"text-anchor\",function(){return z?g.right:g[C.title.align]}).text(C.title.text).call(s.font,C.title.font).call(c.convertToTspans,t),W.attr(\"transform\",function(){var t,e=D.l+D.w*v[C.title.align],r=l.titlePadding,n=s.bBox(W.node());if(P){if(O)if(C.gauge.axis.visible)t=s.bBox(H.node()).top-r-n.bottom;else t=D.t+D.h/2-B/2-n.bottom-r;z&&(t=A-(n.top+n.bottom)/2,e=D.l-l.bulletPadding*D.w)}else t=C._numbersTop-r-n.bottom;return _(e,t)})})}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_defaults\":769,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/cartesian/position_defaults\":782,\"./constants\":1044,d3:163}],1048:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;var c=e.exports=l(s({x:{valType:\"data_array\"},y:{valType:\"data_array\"},z:{valType:\"data_array\"},value:{valType:\"data_array\"},isomin:{valType:\"number\"},isomax:{valType:\"number\"},surface:{show:{valType:\"boolean\",dflt:!0},count:{valType:\"integer\",dflt:2,min:1},fill:{valType:\"number\",min:0,max:1,dflt:1},pattern:{valType:\"flaglist\",flags:[\"A\",\"B\",\"C\",\"D\",\"E\"],extras:[\"all\",\"odd\",\"even\"],dflt:\"all\"}},spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:.15}},slices:{x:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}}},caps:{x:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}}},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:i()},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:a.opacity,lightposition:a.lightposition,lighting:a.lighting,flatshading:a.flatshading,contour:a.contour,hoverinfo:s({},o.hoverinfo)}),\"calc\",\"nested\");c.flatshading.dflt=!0,c.lighting.facenormalsepsilon.dflt=0,c.x.editType=c.y.editType=c.z.editType=c.value.editType=\"calc+clearAxisTypes\",c.transforms=void 0},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../mesh3d/attributes\":1053}],1049:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e._len=Math.min(e.x.length,e.y.length,e.z.length,e.value.length);for(var r=1/0,i=-1/0,a=e.value.length,o=0;o<a;o++){var s=e.value[o];r=Math.min(r,s),i=Math.max(i,s)}e._minValues=r,e._maxValues=i,e._vMin=void 0===e.isomin||null===e.isomin?r:e.isomin,e._vMax=void 0===e.isomax||null===e.isomin?i:e.isomax,n(t,e,{vals:[e._vMin,e._vMax],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],1050:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib\"),a=t(\"../../lib/gl_format_color\").parseColorScale,o=t(\"../../lib/str2rgbarray\"),s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\");function c(t){return i.distinctVals(t).vals}var u=function(t,e){for(var r=e.length-1;r>0;r--){var n=Math.min(e[r],e[r-1]),i=Math.max(e[r],e[r-1]);if(i>n&&n<t&&t<=i)return{id:r,distRatio:(i-t)/(i-n)}}return{id:0,distRatio:0}};function h(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var f=h.prototype;function p(t){t._i=[],t._j=[],t._k=[];var e,r,n=t.surface.show,i=t.spaceframe.show,a=t.surface.fill,o=t.spaceframe.fill,s=!1,l=!1,h=0,f=c(t.x.slice(0,t._len)),p=c(t.y.slice(0,t._len)),d=c(t.z.slice(0,t._len)),g=f.length,v=p.length,m=d.length;function y(t,e,r){return r+m*e+m*v*t}var x,b,_,w,k,T=t._minValues,A=t._maxValues,M=t._vMin,S=t._vMax;function E(t,e,n){for(var i=w.length,a=r;a<i;a++)if(t===x[a]&&e===b[a]&&n===_[a])return a;return-1}function C(){r=e}function L(){x=[],b=[],_=[],w=[],e=0,C()}function P(t,r,n,i){return x.push(t),b.push(r),_.push(n),w.push(i),++e-1}function O(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=t[i]*(1-r)+r*e[i];return n}function z(t){k=t}function I(t,e){return\"all\"===t||null===t||t.indexOf(e)>-1}function D(t,e){return null===t?e:t}function R(e,r,n){C();var i,a,o,s=[r],l=[n];if(k>=1)s=[r],l=[n];else if(k>0){var c=function(t,e){var r=t[0],n=t[1],i=t[2],a=function(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=(t[i]+e[i]+r[i])/3;return n}(r,n,i),o=Math.sqrt(1-k),s=O(a,r,o),l=O(a,n,o),c=O(a,i,o),u=e[0],h=e[1],f=e[2];return{xyzv:[[r,n,l],[l,s,r],[n,i,c],[c,l,n],[i,r,s],[s,c,i]],abc:[[u,h,-1],[-1,-1,u],[h,f,-1],[-1,-1,h],[f,u,-1],[-1,-1,f]]}}(r,n);s=c.xyzv,l=c.abc}for(var u=0;u<s.length;u++){r=s[u],n=l[u];for(var f=[],p=0;p<3;p++){var d=r[p][0],g=r[p][1],v=r[p][2],m=r[p][3],y=n[p]>-1?n[p]:E(d,g,v);f[p]=y>-1?y:P(d,g,v,D(e,m))}i=f[0],a=f[1],o=f[2],t._i.push(i),t._j.push(a),t._k.push(o),++h}}function F(t,e,r,n){var i=t[3];i<r&&(i=r),i>n&&(i=n);for(var a=(t[3]-i)/(t[3]-e[3]+1e-9),o=[],s=0;s<4;s++)o[s]=(1-a)*t[s]+a*e[s];return o}function B(t,e,r){return t>=e&&t<=r}function N(t){var e=.001*(S-M);return t>=M-e&&t<=S+e}function j(e){for(var r=[],n=0;n<4;n++){var i=e[n];r.push([t.x[i],t.y[i],t.z[i],t.value[i]])}return r}var U=3;function V(t,e,r,n,i,a){a||(a=1),r=[-1,-1,-1];var o=!1,s=[B(e[0][3],n,i),B(e[1][3],n,i),B(e[2][3],n,i)];if(!s[0]&&!s[1]&&!s[2])return!1;var l=function(t,e,r){return N(e[0][3])&&N(e[1][3])&&N(e[2][3])?(R(t,e,r),!0):a<U&&V(t,e,r,M,S,++a)};if(s[0]&&s[1]&&s[2])return l(t,e,r)||o;var c=!1;return[[0,1,2],[2,0,1],[1,2,0]].forEach(function(a){if(s[a[0]]&&s[a[1]]&&!s[a[2]]){var u=e[a[0]],h=e[a[1]],f=e[a[2]],p=F(f,u,n,i),d=F(f,h,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,o=l(t,[u,h,d],[r[a[0]],r[a[1]],-1])||o,c=!0}}),c?o:([[0,1,2],[1,2,0],[2,0,1]].forEach(function(a){if(s[a[0]]&&!s[a[1]]&&!s[a[2]]){var u=e[a[0]],h=e[a[1]],f=e[a[2]],p=F(h,u,n,i),d=F(f,u,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,c=!0}}),o)}function q(t,e,r,n){var i=!1,a=j(e),o=[B(a[0][3],r,n),B(a[1][3],r,n),B(a[2][3],r,n),B(a[3][3],r,n)];if(!(o[0]||o[1]||o[2]||o[3]))return i;if(o[0]&&o[1]&&o[2]&&o[3])return l&&(i=function(t,e,r){var n=function(n,i,a){R(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(3,0,1),n(2,3,0),n(1,2,3)}(t,a,e)||i),i;var s=!1;return[[0,1,2,3],[3,0,1,2],[2,3,0,1],[1,2,3,0]].forEach(function(c){if(o[c[0]]&&o[c[1]]&&o[c[2]]&&!o[c[3]]){var u=a[c[0]],h=a[c[1]],f=a[c[2]],p=a[c[3]];if(l)i=R(t,[u,h,f],[e[c[0]],e[c[1]],e[c[2]]])||i;else{var d=F(p,u,r,n),g=F(p,h,r,n),v=F(p,f,r,n);i=R(null,[d,g,v],[-1,-1,-1])||i}s=!0}}),s?i:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2],[0,2,3,1],[1,3,2,0]].forEach(function(c){if(o[c[0]]&&o[c[1]]&&!o[c[2]]&&!o[c[3]]){var u=a[c[0]],h=a[c[1]],f=a[c[2]],p=a[c[3]],d=F(f,u,r,n),g=F(f,h,r,n),v=F(p,h,r,n),m=F(p,u,r,n);l?(i=R(t,[u,m,d],[e[c[0]],-1,-1])||i,i=R(t,[h,g,v],[e[c[1]],-1,-1])||i):i=function(t,e,r){var n=function(n,i,a){R(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(2,3,0)}(null,[d,g,v,m],[-1,-1,-1,-1])||i,s=!0}}),s?i:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2]].forEach(function(c){if(o[c[0]]&&!o[c[1]]&&!o[c[2]]&&!o[c[3]]){var u=a[c[0]],h=a[c[1]],f=a[c[2]],p=a[c[3]],d=F(h,u,r,n),g=F(f,u,r,n),v=F(p,u,r,n);l?(i=R(t,[u,d,g],[e[c[0]],-1,-1])||i,i=R(t,[u,g,v],[e[c[0]],-1,-1])||i,i=R(t,[u,v,d],[e[c[0]],-1,-1])||i):i=R(null,[d,g,v],[-1,-1,-1])||i,s=!0}}),i))}function H(t,e,r,n,i,a,o,c,u,h,f){var p=!1;return s&&(I(t,\"A\")&&(p=q(null,[e,r,n,a],h,f)||p),I(t,\"B\")&&(p=q(null,[r,n,i,u],h,f)||p),I(t,\"C\")&&(p=q(null,[r,a,o,u],h,f)||p),I(t,\"D\")&&(p=q(null,[n,a,c,u],h,f)||p),I(t,\"E\")&&(p=q(null,[r,n,a,u],h,f)||p)),l&&(p=q(t,[r,n,a,u],h,f)||p),p}function G(t,e,r,n,i,a,o,s){return[!0===s[0]||V(t,j([e,r,n]),[e,r,n],a,o),!0===s[1]||V(t,j([n,i,e]),[n,i,e],a,o)]}function Y(t,e,r,n,i,a,o,s,l){return s?G(t,e,r,i,n,a,o,l):G(t,r,i,n,e,a,o,l)}function W(t,e,r,n,i,a,o){var s,l,c,u,h=!1,f=function(){h=V(t,[s,l,c],[-1,-1,-1],i,a)||h,h=V(t,[c,u,s],[-1,-1,-1],i,a)||h},p=o[0],d=o[1],g=o[2];return p&&(s=O(j([y(e,r-0,n-0)])[0],j([y(e-1,r-0,n-0)])[0],p),l=O(j([y(e,r-0,n-1)])[0],j([y(e-1,r-0,n-1)])[0],p),c=O(j([y(e,r-1,n-1)])[0],j([y(e-1,r-1,n-1)])[0],p),u=O(j([y(e,r-1,n-0)])[0],j([y(e-1,r-1,n-0)])[0],p),f()),d&&(s=O(j([y(e-0,r,n-0)])[0],j([y(e-0,r-1,n-0)])[0],d),l=O(j([y(e-0,r,n-1)])[0],j([y(e-0,r-1,n-1)])[0],d),c=O(j([y(e-1,r,n-1)])[0],j([y(e-1,r-1,n-1)])[0],d),u=O(j([y(e-1,r,n-0)])[0],j([y(e-1,r-1,n-0)])[0],d),f()),g&&(s=O(j([y(e-0,r-0,n)])[0],j([y(e-0,r-0,n-1)])[0],g),l=O(j([y(e-0,r-1,n)])[0],j([y(e-0,r-1,n-1)])[0],g),c=O(j([y(e-1,r-1,n)])[0],j([y(e-1,r-1,n-1)])[0],g),u=O(j([y(e-1,r-0,n)])[0],j([y(e-1,r-0,n-1)])[0],g),f()),h}function X(t,e,r,n,i,a,o,l,c,u,h,f){var p=t;return f?(s&&\"even\"===t&&(p=null),H(p,e,r,n,i,a,o,l,c,u,h)):(s&&\"odd\"===t&&(p=null),H(p,c,l,o,a,i,n,r,e,u,h))}function Z(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<m;c++)for(var u=1;u<v;u++)a.push(Y(t,y(l,u-1,c-1),y(l,u-1,c),y(l,u,c-1),y(l,u,c),r,n,(l+u+c)%2,i&&i[o]?i[o]:[])),o++;return a}function J(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<g;c++)for(var u=1;u<m;u++)a.push(Y(t,y(c-1,l,u-1),y(c,l,u-1),y(c-1,l,u),y(c,l,u),r,n,(c+l+u)%2,i&&i[o]?i[o]:[])),o++;return a}function K(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<v;c++)for(var u=1;u<g;u++)a.push(Y(t,y(u-1,c-1,l),y(u-1,c,l),y(u,c-1,l),y(u,c,l),r,n,(u+c+l)%2,i&&i[o]?i[o]:[])),o++;return a}function $(t,e,r){for(var n=1;n<m;n++)for(var i=1;i<v;i++)for(var a=1;a<g;a++)X(t,y(a-1,i-1,n-1),y(a-1,i-1,n),y(a-1,i,n-1),y(a-1,i,n),y(a,i-1,n-1),y(a,i-1,n),y(a,i,n-1),y(a,i,n),e,r,(a+i+n)%2)}function Q(t,e,r){s=!0,$(t,e,r),s=!1}function tt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<m;u++)for(var h=1;h<v;h++)o.push(W(t,c,h,u,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function et(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<g;u++)for(var h=1;h<m;h++)o.push(W(t,u,c,h,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function rt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<v;u++)for(var h=1;h<g;h++)o.push(W(t,h,u,c,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function nt(t,e){for(var r=[],n=t;n<e;n++)r.push(n);return r}return function(){if(L(),function(){for(var e=0;e<g;e++)for(var r=0;r<v;r++)for(var n=0;n<m;n++){var i=y(e,r,n);P(t.x[i],t.y[i],t.z[i],t.value[i])}}(),i&&o&&(z(o),l=!0,$(null,M,S),l=!1),n&&a){z(a);for(var e=t.surface.pattern,r=t.surface.count,s=0;s<r;s++){var c=1===r?.5:s/(r-1),k=(1-c)*M+c*S,E=Math.abs(k-T)>Math.abs(k-A)?[T,k]:[k,A];Q(e,E[0],E[1])}}var C=[[Math.min(M,A),Math.max(M,A)],[Math.min(T,S),Math.max(T,S)]];[\"x\",\"y\",\"z\"].forEach(function(e){for(var r=[],n=0;n<C.length;n++){var i=0,a=C[n][0],o=C[n][1],s=t.slices[e];if(s.show&&s.fill){z(s.fill);var l=[],c=[],h=[];if(s.locations.length)for(var y=0;y<s.locations.length;y++){var x=u(s.locations[y],\"x\"===e?f:\"y\"===e?p:d);0===x.distRatio?l.push(x.id):x.id>0&&(c.push(x.id),\"x\"===e?h.push([x.distRatio,0,0]):\"y\"===e?h.push([0,x.distRatio,0]):h.push([0,0,x.distRatio]))}else l=nt(1,\"x\"===e?g-1:\"y\"===e?v-1:m-1);c.length>0&&(r[i]=\"x\"===e?tt(null,c,a,o,h,r[i]):\"y\"===e?et(null,c,a,o,h,r[i]):rt(null,c,a,o,h,r[i]),i++),l.length>0&&(r[i]=\"x\"===e?Z(null,l,a,o,r[i]):\"y\"===e?J(null,l,a,o,r[i]):K(null,l,a,o,r[i]),i++)}var b=t.caps[e];b.show&&b.fill&&(z(b.fill),r[i]=\"x\"===e?Z(null,[0,g-1],a,o,r[i]):\"y\"===e?J(null,[0,v-1],a,o,r[i]):K(null,[0,m-1],a,o,r[i]),i++)}}),0===h&&L(),t._x=x,t._y=b,t._z=_,t._intensity=w,t._Xs=f,t._Ys=p,t._Zs=d}(),t}f.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._x[e],n=this.data._y[e],i=this.data._z[e],a=this.data._Ys.length,o=this.data._Zs.length,s=u(r,this.data._Xs).id,l=u(n,this.data._Ys).id,c=u(i,this.data._Zs).id,h=t.index=c+o*l+o*a*s;t.traceCoordinate=[this.data._x[h],this.data._y[h],this.data._z[h],this.data.value[h]];var f=this.data.hovertext||this.data.text;return Array.isArray(f)&&void 0!==f[h]?t.textLabel=f[h]:f&&(t.textLabel=f),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map(function(e){return t.d2l(e,0,n)*r})}this.data=p(t);var i={positions:l(n(r.xaxis,t._x,e.dataScale[0],t.xcalendar),n(r.yaxis,t._y,e.dataScale[1],t.ycalendar),n(r.zaxis,t._z,e.dataScale[2],t.zcalendar)),cells:l(t._i,t._j,t._k),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:o(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},c=s(t);i.vertexIntensity=t._intensity,i.vertexIntensityBounds=[c.min,c.max],i.colormap=a(t),this.mesh.update(i)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports={findNearestOnAxis:u,generateIsoMeshes:p,createIsosurfaceTrace:function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new h(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../../plots/gl3d/zip3\":818,\"gl-mesh3d\":280}],1051:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"../../components/colorscale/defaults\");function s(t,e,r,n,a){var s=a(\"isomin\"),l=a(\"isomax\");null!=l&&null!=s&&s>l&&(e.isomin=null,e.isomax=null);var c=a(\"x\"),u=a(\"y\"),h=a(\"z\"),f=a(\"value\");c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length?(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],n),[\"x\",\"y\",\"z\"].forEach(function(t){var e=\"caps.\"+t;a(e+\".show\")&&a(e+\".fill\");var r=\"slices.\"+t;a(r+\".show\")&&(a(r+\".fill\"),a(r+\".locations\"))}),a(\"spaceframe.show\")&&a(\"spaceframe.fill\"),a(\"surface.show\")&&(a(\"surface.count\"),a(\"surface.fill\"),a(\"surface.pattern\")),a(\"contour.show\")&&(a(\"contour.color\"),a(\"contour.width\")),[\"text\",\"hovertext\",\"hovertemplate\",\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"flatshading\",\"opacity\"].forEach(function(t){a(t)}),o(t,e,n,a,{prefix:\"\",cLetter:\"c\"}),e._length=null):e.visible=!1}e.exports={supplyDefaults:function(t,e,r,i){s(t,e,0,i,function(r,i){return n.coerce(t,e,a,r,i)})},supplyIsoDefaults:s}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../../registry\":847,\"./attributes\":1048}],1052:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\").createIsosurfaceTrace,moduleType:\"trace\",name:\"isosurface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1048,\"./calc\":1049,\"./convert\":1050,\"./defaults\":1051}],1053:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../surface/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},i:{valType:\"data_array\",editType:\"calc\"},j:{valType:\"data_array\",editType:\"calc\"},k:{valType:\"data_array\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:i({editType:\"calc\"}),delaunayaxis:{valType:\"enumerated\",values:[\"x\",\"y\",\"z\"],dflt:\"z\",editType:\"calc\"},alphahull:{valType:\"number\",dflt:-1,editType:\"calc\"},intensity:{valType:\"data_array\",editType:\"calc\"},color:{valType:\"color\",editType:\"calc\"},vertexcolor:{valType:\"data_array\",editType:\"calc\"},facecolor:{valType:\"data_array\",editType:\"calc\"},transforms:void 0},n(\"\",{colorAttr:\"`intensity`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:a.opacity,flatshading:{valType:\"boolean\",dflt:!1,editType:\"calc\"},contour:{show:s({},a.contours.x.show,{}),color:a.contours.x.color,width:a.contours.x.width,editType:\"calc\"},lightposition:{x:s({},a.lightposition.x,{dflt:1e5}),y:s({},a.lightposition.y,{dflt:1e5}),z:s({},a.lightposition.z,{dflt:0}),editType:\"calc\"},lighting:s({vertexnormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-12,editType:\"calc\"},facenormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-6,editType:\"calc\"},editType:\"calc\"},a.lighting),hoverinfo:s({},o.hoverinfo,{editType:\"calc\"})})},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../surface/attributes\":1224}],1054:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.intensity&&n(t,e,{vals:e.intensity,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],1055:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"delaunay-triangulate\"),a=t(\"alpha-shape\"),o=t(\"convex-hull\"),s=t(\"../../lib/gl_format_color\").parseColorScale,l=t(\"../../lib/str2rgbarray\"),c=t(\"../../components/colorscale\").extractOpts,u=t(\"../../plots/gl3d/zip3\");function h(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.color=\"#fff\",this.data=null,this.showContour=!1}var f=h.prototype;function p(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=l(t[n]);return e}function d(t,e,r,n){for(var i=[],a=e.length,o=0;o<a;o++)i[o]=t.d2l(e[o],0,n)*r;return i}function g(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=Math.round(t[n]);return e}function v(t,e){for(var r=t.length,n=0;n<r;n++)if(t[n]<=-.5||t[n]>=e-.5)return!1;return!0}f.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index;t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]];var r=this.data.hovertext||this.data.text;return Array.isArray(r)&&void 0!==r[e]?t.textLabel=r[e]:r&&(t.textLabel=r),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;this.data=t;var n,h=t.x.length,f=u(d(r.xaxis,t.x,e.dataScale[0],t.xcalendar),d(r.yaxis,t.y,e.dataScale[1],t.ycalendar),d(r.zaxis,t.z,e.dataScale[2],t.zcalendar));if(t.i&&t.j&&t.k){if(t.i.length!==t.j.length||t.j.length!==t.k.length||!v(t.i,h)||!v(t.j,h)||!v(t.k,h))return;n=u(g(t.i),g(t.j),g(t.k))}else n=0===t.alphahull?o(f):t.alphahull>0?a(t.alphahull,f):function(t,e){for(var r=[\"x\",\"y\",\"z\"].indexOf(t),n=[],a=e.length,o=0;o<a;o++)n[o]=[e[o][(r+1)%3],e[o][(r+2)%3]];return i(n)}(t.delaunayaxis,f);var m={positions:f,cells:n,lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:l(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading};if(t.intensity){var y=c(t);this.color=\"#fff\",m.vertexIntensity=t.intensity,m.vertexIntensityBounds=[y.min,y.max],m.colormap=s(t)}else t.vertexcolor?(this.color=t.vertexcolor[0],m.vertexColors=p(t.vertexcolor)):t.facecolor?(this.color=t.facecolor[0],m.cellColors=p(t.facecolor)):(this.color=t.color,m.meshColor=l(t.color));this.mesh.update(m)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new h(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":605,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../../plots/gl3d/zip3\":818,\"alpha-shape\":64,\"convex-hull\":130,\"delaunay-triangulate\":165,\"gl-mesh3d\":280}],1056:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,n){return i.coerce(t,e,o,r,n)}function c(t){var e=t.map(function(t){var e=l(t);return e&&i.isArrayOrTypedArray(e)?e:null});return e.every(function(t){return t&&t.length===e[0].length})&&e}c([\"x\",\"y\",\"z\"])?(c([\"i\",\"j\",\"k\"]),(!e.i||e.j&&e.k)&&(!e.j||e.k&&e.i)&&(!e.k||e.i&&e.j)?(n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],s),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"contour.show\",\"contour.color\",\"contour.width\",\"colorscale\",\"reversescale\",\"flatshading\",\"alphahull\",\"delaunayaxis\",\"opacity\"].forEach(function(t){l(t)}),\"intensity\"in t?(l(\"intensity\"),a(t,e,s,l,{prefix:\"\",cLetter:\"c\"})):(e.showscale=!1,\"facecolor\"in t?l(\"facecolor\"):\"vertexcolor\"in t?l(\"vertexcolor\"):l(\"color\",r)),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),e._length=null):e.visible=!1):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../../registry\":847,\"./attributes\":1053}],1057:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"mesh3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1053,\"./calc\":1054,\"./convert\":1055,\"./defaults\":1056}],1058:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../scatter/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../components/fx/attributes\"),s=t(\"../../constants/delta.js\"),l=s.INCREASING.COLOR,c=s.DECREASING.COLOR,u=i.line;function h(t){return{line:{color:n({},u.color,{dflt:t}),width:u.width,dash:a,editType:\"style\"},editType:\"style\"}}e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},open:{valType:\"data_array\",editType:\"calc\"},high:{valType:\"data_array\",editType:\"calc\"},low:{valType:\"data_array\",editType:\"calc\"},close:{valType:\"data_array\",editType:\"calc\"},line:{width:n({},u.width,{}),dash:n({},a,{}),editType:\"style\"},increasing:h(l),decreasing:h(c),text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},tickwidth:{valType:\"number\",min:0,max:.5,dflt:.3,editType:\"calc\"},hoverlabel:n({},o.hoverlabel,{split:{valType:\"boolean\",dflt:!1,editType:\"style\"}})}},{\"../../components/drawing/attributes\":613,\"../../components/fx/attributes\":623,\"../../constants/delta.js\":689,\"../../lib\":719,\"../scatter/attributes\":1112}],1059:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=n._,a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/numerical\").BADNUM;function s(t,e,r,n){return{o:t,h:e,l:r,c:n}}function l(t,e,r,s,l){for(var c=s.makeCalcdata(e,\"open\"),u=s.makeCalcdata(e,\"high\"),h=s.makeCalcdata(e,\"low\"),f=s.makeCalcdata(e,\"close\"),p=Array.isArray(e.text),d=Array.isArray(e.hovertext),g=!0,v=null,m=[],y=0;y<r.length;y++){var x=r[y],b=c[y],_=u[y],w=h[y],k=f[y];if(x!==o&&b!==o&&_!==o&&w!==o&&k!==o){k===b?null!==v&&k!==v&&(g=k>v):g=k>b,v=k;var T=l(b,_,w,k);T.pos=x,T.yc=(b+k)/2,T.i=y,T.dir=g?\"increasing\":\"decreasing\",T.x=T.pos,T.y=[w,_],p&&(T.tx=e.text[y]),d&&(T.htx=e.hovertext[y]),m.push(T)}else m.push({pos:x,empty:!0})}return e._extremes[s._id]=a.findExtremes(s,n.concat(h,u),{padded:!0}),m.length&&(m[0].t={labels:{open:i(t,\"open:\")+\" \",high:i(t,\"high:\")+\" \",low:i(t,\"low:\")+\" \",close:i(t,\"close:\")+\" \"}}),m}e.exports={calc:function(t,e){var r=a.getFromId(t,e.xaxis),i=a.getFromId(t,e.yaxis),o=function(t,e,r){var i=r._minDiff;if(!i){var a,o=t._fullData,s=[];for(i=1/0,a=0;a<o.length;a++){var l=o[a];if(\"ohlc\"===l.type&&!0===l.visible&&l.xaxis===e._id){s.push(l);var c=e.makeCalcdata(l,\"x\");l._xcalc=c;var u=n.distinctVals(c).minDiff;u&&isFinite(u)&&(i=Math.min(i,u))}}for(i===1/0&&(i=1),a=0;a<s.length;a++)s[a]._minDiff=i}return i*r.tickwidth}(t,r,e),c=e._minDiff;e._minDiff=null;var u=e._xcalc;e._xcalc=null;var h=l(t,e,u,i,s);return e._extremes[r._id]=a.findExtremes(r,u,{vpad:c/2}),h.length?(n.extendFlat(h[0].t,{wHover:c/2,tickLen:o}),h):[{t:{empty:!0}}]},calcCommon:l}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],1060:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./ohlc_defaults\"),a=t(\"./attributes\");function o(t,e,r,n){r(n+\".line.color\"),r(n+\".line.width\",e.line.width),r(n+\".line.dash\",e.line.dash)}e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,a,r,i)}i(t,e,l,s)?(l(\"line.width\"),l(\"line.dash\"),o(t,e,l,\"increasing\"),o(t,e,l,\"decreasing\"),l(\"text\"),l(\"hovertext\"),l(\"tickwidth\"),s._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../lib\":719,\"./attributes\":1058,\"./ohlc_defaults\":1063}],1061:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\").fillText,l=t(\"../../constants/delta.js\"),c={increasing:l.INCREASING.SYMBOL,decreasing:l.DECREASING.SYMBOL};function u(t,e,r,n){var i,s,l=t.cd,c=t.xa,u=l[0].trace,h=l[0].t,f=u.type,p=\"ohlc\"===f?\"l\":\"min\",d=\"ohlc\"===f?\"h\":\"max\",g=h.bPos||0,v=function(t){return t.pos+g-e},m=h.bdPos||h.tickLen,y=h.wHover,x=Math.min(1,m/Math.abs(c.r2c(c.range[1])-c.r2c(c.range[0])));function b(t){var e=v(t);return a.inbox(e-y,e+y,i)}function _(t){var e=t[p],n=t[d];return e===n||a.inbox(e-r,n-r,i)}function w(t){return(b(t)+_(t))/2}i=t.maxHoverDistance-x,s=t.maxSpikeDistance-x;var k=a.getDistanceFunction(n,b,_,w);if(a.getClosest(l,k,t),!1===t.index)return null;var T=l[t.index];if(T.empty)return null;var A=u[T.dir],M=A.line.color;return o.opacity(M)&&A.line.width?t.color=M:t.color=A.fillcolor,t.x0=c.c2p(T.pos+g-m,!0),t.x1=c.c2p(T.pos+g+m,!0),t.xLabelVal=T.pos,t.spikeDistance=w(T)*s/i,t.xSpike=c.c2p(T.pos,!0),t}function h(t,e,r,a){var o=t.cd,s=t.ya,l=o[0].trace,c=o[0].t,h=[],f=u(t,e,r,a);if(!f)return[];var p=o[f.index].hi||l.hoverinfo,d=p.split(\"+\");if(!(\"all\"===p||-1!==d.indexOf(\"y\")))return[];for(var g=[\"high\",\"open\",\"close\",\"low\"],v={},m=0;m<g.length;m++){var y,x=g[m],b=l[x][f.index],_=s.c2p(b,!0);b in v?(y=v[b]).yLabel+=\"<br>\"+c.labels[x]+n.hoverLabelText(s,b):((y=i.extendFlat({},f)).y0=y.y1=_,y.yLabelVal=b,y.yLabel=c.labels[x]+n.hoverLabelText(s,b),y.name=\"\",h.push(y),v[b]=y)}return h}function f(t,e,r,i){var a=t.cd,o=t.ya,l=a[0].trace,h=a[0].t,f=u(t,e,r,i);if(!f)return[];var p=a[f.index],d=f.index=p.i,g=p.dir;function v(t){return h.labels[t]+n.hoverLabelText(o,l[t][d])}var m=p.hi||l.hoverinfo,y=m.split(\"+\"),x=\"all\"===m,b=x||-1!==y.indexOf(\"y\"),_=x||-1!==y.indexOf(\"text\"),w=b?[v(\"open\"),v(\"high\"),v(\"low\"),v(\"close\")+\"  \"+c[g]]:[];return _&&s(p,l,w),f.extraText=w.join(\"<br>\"),f.y0=f.y1=o.c2p(p.yc,!0),[f]}e.exports={hoverPoints:function(t,e,r,n){return t.cd[0].trace.hoverlabel.split?h(t,e,r,n):f(t,e,r,n)},hoverSplit:h,hoverOnPoints:f}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../constants/delta.js\":689,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],1062:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"ohlc\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\"],meta:{},attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\").calc,plot:t(\"./plot\"),style:t(\"./style\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\")}},{\"../../plots/cartesian\":778,\"./attributes\":1058,\"./calc\":1059,\"./defaults\":1060,\"./hover\":1061,\"./plot\":1064,\"./select\":1065,\"./style\":1066}],1063:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"open\"),l=r(\"high\"),c=r(\"low\"),u=r(\"close\");if(r(\"hoverlabel.split\"),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\"],a),s&&l&&c&&u){var h=Math.min(s.length,l.length,c.length,u.length);return o&&(h=Math.min(h,i.minRowLength(o))),e._length=h,h}}},{\"../../lib\":719,\"../../registry\":847}],1064:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=e.xaxis,s=e.yaxis;i.makeTraceGroups(a,r,\"trace ohlc\").each(function(t){var e=n.select(this),r=t[0],a=r.t;if(!0!==r.trace.visible||a.empty)e.remove();else{var l=a.tickLen,c=e.selectAll(\"path\").data(i.identity);c.enter().append(\"path\"),c.exit().remove(),c.attr(\"d\",function(t){if(t.empty)return\"M0,0Z\";var e=o.c2p(t.pos,!0),r=o.c2p(t.pos-l,!0),n=o.c2p(t.pos+l,!0);return\"M\"+r+\",\"+s.c2p(t.o,!0)+\"H\"+e+\"M\"+e+\",\"+s.c2p(t.h,!0)+\"V\"+s.c2p(t.l,!0)+\"M\"+n+\",\"+s.c2p(t.c,!0)+\"H\"+e})}})}},{\"../../lib\":719,d3:163}],1065:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n=t.cd,i=t.xaxis,a=t.yaxis,o=[],s=n[0].t.bPos||0;if(!1===e)for(r=0;r<n.length;r++)n[r].selected=0;else for(r=0;r<n.length;r++){var l=n[r];e.contains([i.c2p(l.pos+s),a.c2p(l.yc)],null,l.i,t)?(o.push({pointNumber:l.i,x:i.c2d(l.pos),y:a.c2d(l.yc)}),l.selected=1):l.selected=0}return o}},{}],1066:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\");e.exports=function(t,e,r){var o=r||n.select(t).selectAll(\"g.ohlclayer\").selectAll(\"g.trace\");o.style(\"opacity\",function(t){return t[0].trace.opacity}),o.each(function(t){var e=t[0].trace;n.select(this).selectAll(\"path\").each(function(t){if(!t.empty){var r=e[t.dir].line;n.select(this).style(\"fill\",\"none\").call(a.stroke,r.color).call(i.dashLine,r.dash,r.width).style(\"opacity\",e.selectedpoints&&!t.selected?.3:1)}})})}},{\"../../components/color\":593,\"../../components/drawing\":614,d3:163}],1067:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../plots/attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/fx/hovertemplate_attributes\"),l=t(\"../../plots/domain\").attributes,c=n({editType:\"calc\"},o(\"line\",{editTypeOverride:\"calc\"}),{shape:{valType:\"enumerated\",values:[\"linear\",\"hspline\"],dflt:\"linear\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\"]})});e.exports={domain:l({name:\"parcats\",trace:!0,editType:\"calc\"}),hoverinfo:n({},i.hoverinfo,{flags:[\"count\",\"probability\"],editType:\"plot\",arrayOk:!1}),hoveron:{valType:\"enumerated\",values:[\"category\",\"color\",\"dimension\"],dflt:\"category\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\",\"category\",\"categorycount\",\"colorcount\",\"bandcolorcount\"]}),arrangement:{valType:\"enumerated\",values:[\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"perpendicular\",editType:\"plot\"},bundlecolors:{valType:\"boolean\",dflt:!0,editType:\"plot\"},sortpaths:{valType:\"enumerated\",values:[\"forward\",\"backward\"],dflt:\"forward\",editType:\"plot\"},labelfont:a({editType:\"calc\"}),tickfont:a({editType:\"calc\"}),dimensions:{_isLinkedToArray:\"dimension\",label:{valType:\"string\",editType:\"calc\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",dflt:[],editType:\"calc\"},displayindex:{valType:\"integer\",editType:\"calc\"},editType:\"calc\",visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"}},line:c,counts:{valType:\"number\",min:0,dflt:1,arrayOk:!0,editType:\"calc\"},customdata:void 0,hoverlabel:void 0,ids:void 0,legendgroup:void 0,opacity:void 0,selectedpoints:void 0,showlegend:void 0}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1068:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"parcats\",r.plot=function(t,e,r,a){var o=n(t.calcdata,\"parcats\");if(o.length){var s=o[0];i(t,s,r,a)}},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcats\"),a=e._has&&e._has(\"parcats\");i&&!a&&n._paperdiv.selectAll(\".parcats\").remove()}},{\"../../plots/get_data\":802,\"./plot\":1073}],1069:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),o=t(\"../../lib/filter_unique.js\"),s=t(\"../../components/drawing\"),l=t(\"../../lib\");function c(t,e,r){t.valueInds.push(e),t.count+=r}function u(t,e,r){t.valueInds.push(e),t.count+=r}e.exports=function(t,e){var r=l.filterVisible(e.dimensions);if(0===r.length)return[];var h,f,p,d=r.map(function(t){var e;return\"trace\"===t.categoryorder?e=null:\"array\"===t.categoryorder?e=t.categoryarray:(e=o(t.values).sort(),\"category descending\"===t.categoryorder&&(e=e.reverse())),function(t,e){e=null==e?[]:e.map(function(t){return t});var r={},n={},i=[];e.forEach(function(t,e){r[t]=0,n[t]=e});for(var a=0;a<t.length;a++){var o,s=t[a];void 0===r[s]?(r[s]=1,o=e.push(s)-1,n[s]=o):(r[s]++,o=n[s]),i.push(o)}var l=e.map(function(t){return r[t]});return{uniqueValues:e,uniqueCounts:l,inds:i}}(t.values,e)});h=l.isArrayOrTypedArray(e.counts)?e.counts:[e.counts],function(t){var e;if(function(t){for(var e=new Array(t.length),r=0;r<t.length;r++){if(t[r]<0||t[r]>=t.length)return!1;if(void 0!==e[t[r]])return!1;e[t[r]]=!0}return!0}(t.map(function(t){return t.displayindex})))for(e=0;e<t.length;e++)t[e]._displayindex=t[e].displayindex;else for(e=0;e<t.length;e++)t[e]._displayindex=e}(r),r.forEach(function(t,e){!function(t,e){t._categoryarray=e.uniqueValues,null===t.ticktext||void 0===t.ticktext?t._ticktext=[]:t._ticktext=t.ticktext.slice();for(var r=t._ticktext.length;r<e.uniqueValues.length;r++)t._ticktext.push(e.uniqueValues[r])}(t,d[e])});var g,v=e.line;v?(i(e,\"line\")&&a(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),g=s.tryColorscale(v)):g=l.identity;var m,y,x,b,_=r[0].values.length,w={},k=d.map(function(t){return t.inds});for(p=0,m=0;m<_;m++){var T=[];for(y=0;y<k.length;y++)T.push(k[y][m]);f=h[m%h.length],p+=f;var A=(x=m,b=void 0,b=l.isArrayOrTypedArray(v.color)?v.color[x%v.color.length]:v.color,{color:g(b),rawColor:b}),M=T+\"-\"+A.rawColor;void 0===w[M]&&(w[M]={categoryInds:T,color:A.color,rawColor:A.rawColor,valueInds:[],count:0}),u(w[M],m,f)}var S,E=r.map(function(t,e){return r=e,n=t._index,i=t._displayindex,a=t.label,{dimensionInd:r,containerInd:n,displayInd:i,dimensionLabel:a,count:p,categories:[],dragX:null};var r,n,i,a});for(m=0;m<_;m++)for(f=h[m%h.length],y=0;y<E.length;y++){var C=E[y].containerInd,L=d[y].inds[m],P=E[y].categories;if(void 0===P[L]){var O=e.dimensions[C]._categoryarray[L],z=e.dimensions[C]._ticktext[L];P[L]={dimensionInd:y,categoryInd:S=L,categoryValue:O,displayInd:S,categoryLabel:z,valueInds:[],count:0,dragY:null}}c(P[L],m,f)}return n(function(t,e,r){var n=t.map(function(t){return t.categories.length}).reduce(function(t,e){return Math.max(t,e)});return{dimensions:t,paths:e,trace:void 0,maxCats:n,count:r}}(E,w,p))}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/filter_unique.js\":711,\"../../lib/gup\":717}],1070:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"./attributes\"),c=t(\"../parcoords/merge_length\");function u(t,e){function r(r,i){return n.coerce(t,e,l.dimensions,r,i)}var i=r(\"values\"),a=r(\"visible\");if(i&&i.length||(a=e.visible=!1),a){r(\"label\"),r(\"displayindex\",e._index);var o,s=t.categoryarray,c=Array.isArray(s)&&s.length>0;c&&(o=\"array\");var u=r(\"categoryorder\",o);\"array\"===u?(r(\"categoryarray\"),r(\"ticktext\")):(delete t.categoryarray,delete t.ticktext),c||\"array\"!==u||(e.categoryorder=\"trace\")}}e.exports=function(t,e,r,h){function f(r,i){return n.coerce(t,e,l,r,i)}var p=s(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=function(t,e,r,o,s){s(\"line.shape\"),s(\"line.hovertemplate\");var l=s(\"line.color\",o.colorway[0]);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,h,f);o(e,h,f),Array.isArray(p)&&p.length||(e.visible=!1),c(e,p,\"values\",d),f(\"hoveron\"),f(\"hovertemplate\"),f(\"arrangement\"),f(\"bundlecolors\"),f(\"sortpaths\"),f(\"counts\");var g={family:h.font.family,size:Math.round(h.font.size),color:h.font.color};n.coerceFont(f,\"labelfont\",g);var v={family:h.font.family,size:Math.round(h.font.size/1.2),color:h.font.color};n.coerceFont(f,\"tickfont\",v)}},{\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/domain\":792,\"../parcoords/merge_length\":1083,\"./attributes\":1067}],1071:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcats\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1067,\"./base_plot\":1068,\"./calc\":1069,\"./defaults\":1070,\"./plot\":1073}],1072:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plot_api/plot_api\"),a=t(\"../../components/fx\"),o=t(\"../../lib\"),s=t(\"../../components/drawing\"),l=t(\"tinycolor2\"),c=t(\"../../lib/svg_text_utils\");function u(t,e,r,i){var a=t.map(function(t,e,r){var n,i=r[0],a=e.margin||{l:80,r:80,t:100,b:80},o=i.trace,s=o.domain,l=e.width,c=e.height,u=Math.floor(l*(s.x[1]-s.x[0])),h=Math.floor(c*(s.y[1]-s.y[0])),f=s.x[0]*l+a.l,p=e.height-s.y[1]*e.height+a.t,d=o.line.shape;n=\"all\"===o.hoverinfo?[\"count\",\"probability\"]:(o.hoverinfo||\"\").split(\"+\");var g={trace:o,key:o.uid,model:i,x:f,y:p,width:u,height:h,hoveron:o.hoveron,hoverinfoItems:n,arrangement:o.arrangement,bundlecolors:o.bundlecolors,sortpaths:o.sortpaths,labelfont:o.labelfont,categorylabelfont:o.tickfont,pathShape:d,dragDimension:null,margin:a,paths:[],dimensions:[],graphDiv:t,traceSelection:null,pathSelection:null,dimensionSelection:null};i.dimensions&&(R(g),D(g));return g}.bind(0,e,r)),l=i.selectAll(\"g.parcatslayer\").data([null]);l.enter().append(\"g\").attr(\"class\",\"parcatslayer\").style(\"pointer-events\",\"all\");var u=l.selectAll(\"g.trace.parcats\").data(a,h),v=u.enter().append(\"g\").attr(\"class\",\"trace parcats\");u.attr(\"transform\",function(t){return\"translate(\"+t.x+\", \"+t.y+\")\"}),v.append(\"g\").attr(\"class\",\"paths\");var x=u.select(\"g.paths\").selectAll(\"path.path\").data(function(t){return t.paths},h);x.attr(\"fill\",function(t){return t.model.color});var w=x.enter().append(\"path\").attr(\"class\",\"path\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.model.color}).attr(\"fill-opacity\",0);y(w),x.attr(\"d\",function(t){return t.svgD}),w.empty()||x.sort(p),x.exit().remove(),x.on(\"mouseover\",d).on(\"mouseout\",g).on(\"click\",m),v.append(\"g\").attr(\"class\",\"dimensions\");var k=u.select(\"g.dimensions\").selectAll(\"g.dimension\").data(function(t){return t.dimensions},h);k.enter().append(\"g\").attr(\"class\",\"dimension\"),k.attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),k.exit().remove();var T=k.selectAll(\"g.category\").data(function(t){return t.categories},h),A=T.enter().append(\"g\").attr(\"class\",\"category\");T.attr(\"transform\",function(t){return\"translate(0, \"+t.y+\")\"}),A.append(\"rect\").attr(\"class\",\"catrect\").attr(\"pointer-events\",\"none\"),T.select(\"rect.catrect\").attr(\"fill\",\"none\").attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}),b(A);var P=T.selectAll(\"rect.bandrect\").data(function(t){return t.bands},h);P.each(function(){o.raiseToTop(this)}),P.attr(\"fill\",function(t){return t.color});var O=P.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.color}).attr(\"fill-opacity\",0);P.attr(\"fill\",function(t){return t.color}).attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}).attr(\"y\",function(t){return t.y}).attr(\"cursor\",function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"perpendicular\"===t.parcatsViewModel.arrangement?\"ns-resize\":\"move\"}),_(O),P.exit().remove(),A.append(\"text\").attr(\"class\",\"catlabel\").attr(\"pointer-events\",\"none\");var z=e._fullLayout.paper_bgcolor;T.select(\"text.catlabel\").attr(\"text-anchor\",function(t){return f(t)?\"start\":\"end\"}).attr(\"alignment-baseline\",\"middle\").style(\"text-shadow\",z+\" -1px  1px 2px, \"+z+\" 1px  1px 2px, \"+z+\"  1px -1px 2px, \"+z+\" -1px -1px 2px\").style(\"fill\",\"rgb(0, 0, 0)\").attr(\"x\",function(t){return f(t)?t.width+5:-5}).attr(\"y\",function(t){return t.height/2}).text(function(t){return t.model.categoryLabel}).each(function(t){s.font(n.select(this),t.parcatsViewModel.categorylabelfont),c.convertToTspans(n.select(this),e)}),A.append(\"text\").attr(\"class\",\"dimlabel\"),T.select(\"text.dimlabel\").attr(\"text-anchor\",\"middle\").attr(\"alignment-baseline\",\"baseline\").attr(\"cursor\",function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"ew-resize\"}).attr(\"x\",function(t){return t.width/2}).attr(\"y\",-5).text(function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null}).each(function(t){s.font(n.select(this),t.parcatsViewModel.labelfont)}),T.selectAll(\"rect.bandrect\").on(\"mouseover\",M).on(\"mouseout\",S),T.exit().remove(),k.call(n.behavior.drag().origin(function(t){return{x:t.x,y:0}}).on(\"dragstart\",E).on(\"drag\",C).on(\"dragend\",L)),u.each(function(t){t.traceSelection=n.select(this),t.pathSelection=n.select(this).selectAll(\"g.paths\").selectAll(\"path.path\"),t.dimensionSelection=n.select(this).selectAll(\"g.dimensions\").selectAll(\"g.dimension\")}),u.exit().remove()}function h(t){return t.key}function f(t){var e=t.parcatsViewModel.dimensions.length,r=t.parcatsViewModel.dimensions[e-1].model.dimensionInd;return t.model.dimensionInd===r}function p(t,e){return t.model.rawColor>e.model.rawColor?1:t.model.rawColor<e.model.rawColor?-1:0}function d(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){o.raiseToTop(this),x(n.select(this));var e=v(t);if(t.parcatsViewModel.graphDiv.emit(\"plotly_hover\",{points:e,event:n.event}),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\")){var r,i,s,c=n.mouse(this)[0],u=t.parcatsViewModel.graphDiv,h=t.parcatsViewModel.trace,f=u._fullLayout,p=f._paperdiv.node().getBoundingClientRect(),d=t.parcatsViewModel.graphDiv.getBoundingClientRect();for(s=0;s<t.leftXs.length-1;s++)if(t.leftXs[s]+t.dimWidths[s]-2<=c&&c<=t.leftXs[s+1]+2){var g=t.parcatsViewModel.dimensions[s],m=t.parcatsViewModel.dimensions[s+1];r=(g.x+g.width+m.x)/2,i=(t.topYs[s]+t.topYs[s+1]+t.height)/2;break}var y=t.parcatsViewModel.x+r,b=t.parcatsViewModel.y+i,_=l.mostReadable(t.model.color,[\"black\",\"white\"]),w=t.model.count,k=w/t.parcatsViewModel.model.count,T={countLabel:w,probabilityLabel:k.toFixed(3)},A=[];-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&A.push([\"Count:\",T.countLabel].join(\" \")),-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&A.push([\"P:\",T.probabilityLabel].join(\" \"));var M=A.join(\"<br>\"),S=n.mouse(u)[0];a.loneHover({trace:h,x:y-p.left+d.left,y:b-p.top+d.top,text:M,color:t.model.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:10,fontColor:_,idealAlign:S<y?\"right\":\"left\",hovertemplate:(h.line||{}).hovertemplate,hovertemplateLabels:T,eventData:[{data:h._input,fullData:h,count:w,probability:k}]},{container:f._hoverlayer.node(),outerContainer:f._paper.node(),gd:u})}}}function g(t){if(!t.parcatsViewModel.dragDimension&&(y(n.select(this)),a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()),t.parcatsViewModel.pathSelection.sort(p),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\"))){var e=v(t);t.parcatsViewModel.graphDiv.emit(\"plotly_unhover\",{points:e,event:n.event})}}function v(t){for(var e=[],r=P(t.parcatsViewModel),n=0;n<t.model.valueInds.length;n++){var i=t.model.valueInds[n];e.push({curveNumber:r,pointNumber:i})}return e}function m(t){if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){var e=v(t);t.parcatsViewModel.graphDiv.emit(\"plotly_click\",{points:e,event:n.event})}}function y(t){t.attr(\"fill\",function(t){return t.model.color}).attr(\"fill-opacity\",.6).attr(\"stroke\",\"lightgray\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1)}function x(t){t.attr(\"fill-opacity\",.8).attr(\"stroke\",function(t){return l.mostReadable(t.model.color,[\"black\",\"white\"])}).attr(\"stroke-width\",.3)}function b(t){t.select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",1).attr(\"stroke-opacity\",1)}function _(t){t.attr(\"stroke\",\"black\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1).attr(\"fill-opacity\",1)}function w(t){var e=t.parcatsViewModel.pathSelection,r=t.categoryViewModel.model.dimensionInd,n=t.categoryViewModel.model.categoryInd;return e.filter(function(e){return e.model.categoryInds[r]===n&&e.model.color===t.color})}function k(t,e,r){var i=n.select(t).datum().parcatsViewModel.graphDiv,a=n.select(t.parentNode).selectAll(\"rect.bandrect\"),o=[];a.each(function(t){w(t).each(function(t){Array.prototype.push.apply(o,v(t))})}),i.emit(e,{points:o,event:r})}function T(t,e,r){var i=n.select(t).datum(),a=i.parcatsViewModel.graphDiv,o=w(i),s=[];o.each(function(t){Array.prototype.push.apply(s,v(t))}),a.emit(e,{points:s,event:r})}function A(t,e){var r,i,a=n.select(e.parentNode).select(\"rect.catrect\"),o=a.node().getBoundingClientRect(),s=a.datum(),l=s.parcatsViewModel,c=l.model.dimensions[s.model.dimensionInd],u=l.trace,h=o.top+o.height/2;l.dimensions.length>1&&c.displayInd===l.dimensions.length-1?(r=o.left,i=\"left\"):(r=o.left+o.width,i=\"right\");var f=s.model.count,p=s.model.categoryLabel,d=f/s.parcatsViewModel.model.count,g={countLabel:f,categoryLabel:p,probabilityLabel:d.toFixed(3)},v=[];-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&v.push([\"Count:\",g.countLabel].join(\" \")),-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&v.push([\"P(\"+g.categoryLabel+\"):\",g.probabilityLabel].join(\" \"));var m=v.join(\"<br>\");return{trace:u,x:r-t.left,y:h-t.top,text:m,color:\"lightgray\",borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:12,fontColor:\"black\",idealAlign:i,hovertemplate:u.hovertemplate,hovertemplateLabels:g,eventData:[{data:u._input,fullData:u,count:f,category:p,probability:d}]}}function M(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){if(n.mouse(this)[1]<-1)return;var e,r=t.parcatsViewModel.graphDiv,i=r._fullLayout,s=i._paperdiv.node().getBoundingClientRect(),c=t.parcatsViewModel.hoveron;if(\"color\"===c?(!function(t){var e=n.select(t).datum(),r=w(e);x(r),r.each(function(){o.raiseToTop(this)}),n.select(t.parentNode).selectAll(\"rect.bandrect\").filter(function(t){return t.color===e.color}).each(function(){o.raiseToTop(this),n.select(this).attr(\"stroke\",\"black\").attr(\"stroke-width\",1.5)})}(this),T(this,\"plotly_hover\",n.event)):(!function(t){n.select(t.parentNode).selectAll(\"rect.bandrect\").each(function(t){var e=w(t);x(e),e.each(function(){o.raiseToTop(this)})}),n.select(t.parentNode).select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",2.5)}(this),k(this,\"plotly_hover\",n.event)),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\"))\"category\"===c?e=A(s,this):\"color\"===c?e=function(t,e){var r,i,a=e.getBoundingClientRect(),o=n.select(e).datum(),s=o.categoryViewModel,c=s.parcatsViewModel,u=c.model.dimensions[s.model.dimensionInd],h=c.trace,f=a.y+a.height/2;c.dimensions.length>1&&u.displayInd===c.dimensions.length-1?(r=a.left,i=\"left\"):(r=a.left+a.width,i=\"right\");var p=s.model.categoryLabel,d=o.parcatsViewModel.model.count,g=0;o.categoryViewModel.bands.forEach(function(t){t.color===o.color&&(g+=t.count)});var v=s.model.count,m=0;c.pathSelection.each(function(t){t.model.color===o.color&&(m+=t.model.count)});var y=g/d,x=g/m,b=g/v,_={countLabel:d,categoryLabel:p,probabilityLabel:y.toFixed(3)},w=[];-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&w.push([\"Count:\",_.countLabel].join(\" \")),-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&(w.push(\"P(color \\u2229 \"+p+\"): \"+_.probabilityLabel),w.push(\"P(\"+p+\" | color): \"+x.toFixed(3)),w.push(\"P(color | \"+p+\"): \"+b.toFixed(3)));var k=w.join(\"<br>\"),T=l.mostReadable(o.color,[\"black\",\"white\"]);return{trace:h,x:r-t.left,y:f-t.top,text:k,color:o.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontColor:T,fontSize:10,idealAlign:i,hovertemplate:h.hovertemplate,hovertemplateLabels:_,eventData:[{data:h._input,fullData:h,category:p,count:d,probability:y,categorycount:v,colorcount:m,bandcolorcount:g}]}}(s,this):\"dimension\"===c&&(e=function(t,e){var r=[];return n.select(e.parentNode.parentNode).selectAll(\"g.category\").select(\"rect.catrect\").each(function(){r.push(A(t,this))}),r}(s,this)),e&&a.loneHover(e,{container:i._hoverlayer.node(),outerContainer:i._paper.node(),gd:r})}}function S(t){var e=t.parcatsViewModel;if(!e.dragDimension&&(y(e.pathSelection),b(e.dimensionSelection.selectAll(\"g.category\")),_(e.dimensionSelection.selectAll(\"g.category\").selectAll(\"rect.bandrect\")),a.loneUnhover(e.graphDiv._fullLayout._hoverlayer.node()),e.pathSelection.sort(p),-1===e.hoverinfoItems.indexOf(\"skip\"))){\"color\"===t.parcatsViewModel.hoveron?T(this,\"plotly_unhover\",n.event):k(this,\"plotly_unhover\",n.event)}}function E(t){\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragDimensionDisplayInd=t.model.displayInd,t.initialDragDimensionDisplayInds=t.parcatsViewModel.model.dimensions.map(function(t){return t.displayInd}),t.dragHasMoved=!1,t.dragCategoryDisplayInd=null,n.select(this).selectAll(\"g.category\").select(\"rect.catrect\").each(function(e){var r=n.mouse(this)[0],i=n.mouse(this)[1];-2<=r&&r<=e.width+2&&-2<=i&&i<=e.height+2&&(t.dragCategoryDisplayInd=e.model.displayInd,t.initialDragCategoryDisplayInds=t.model.categories.map(function(t){return t.displayInd}),e.model.dragY=e.y,o.raiseToTop(this.parentNode),n.select(this.parentNode).selectAll(\"rect.bandrect\").each(function(e){e.y<i&&i<=e.y+e.height&&(t.potentialClickBand=this)}))}),t.parcatsViewModel.dragDimension=t,a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()))}function C(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragHasMoved=!0,null!==t.dragDimensionDisplayInd)){var e=t.dragDimensionDisplayInd,r=e-1,i=e+1,a=t.parcatsViewModel.dimensions[e];if(null!==t.dragCategoryDisplayInd){var o=a.categories[t.dragCategoryDisplayInd];o.model.dragY+=n.event.dy;var s=o.model.dragY,l=o.model.displayInd,c=a.categories,u=c[l-1],h=c[l+1];void 0!==u&&s<u.y+u.height/2&&(o.model.displayInd=u.model.displayInd,u.model.displayInd=l),void 0!==h&&s+o.height>h.y+h.height/2&&(o.model.displayInd=h.model.displayInd,h.model.displayInd=l),t.dragCategoryDisplayInd=o.model.displayInd}if(null===t.dragCategoryDisplayInd||\"freeform\"===t.parcatsViewModel.arrangement){a.model.dragX=n.event.x;var f=t.parcatsViewModel.dimensions[r],p=t.parcatsViewModel.dimensions[i];void 0!==f&&a.model.dragX<f.x+f.width&&(a.model.displayInd=f.model.displayInd,f.model.displayInd=e),void 0!==p&&a.model.dragX+a.width>p.x&&(a.model.displayInd=p.model.displayInd,p.model.displayInd=t.dragDimensionDisplayInd),t.dragDimensionDisplayInd=a.model.displayInd}R(t.parcatsViewModel),D(t.parcatsViewModel),z(t.parcatsViewModel),O(t.parcatsViewModel)}}function L(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&null!==t.dragDimensionDisplayInd){n.select(this).selectAll(\"text\").attr(\"font-weight\",\"normal\");var e={},r=P(t.parcatsViewModel),a=t.parcatsViewModel.model.dimensions.map(function(t){return t.displayInd}),o=t.initialDragDimensionDisplayInds.some(function(t,e){return t!==a[e]});o&&a.forEach(function(r,n){var i=t.parcatsViewModel.model.dimensions[n].containerInd;e[\"dimensions[\"+i+\"].displayindex\"]=r});var s=!1;if(null!==t.dragCategoryDisplayInd){var l=t.model.categories.map(function(t){return t.displayInd});if(s=t.initialDragCategoryDisplayInds.some(function(t,e){return t!==l[e]})){var c=t.model.categories.slice().sort(function(t,e){return t.displayInd-e.displayInd}),u=c.map(function(t){return t.categoryValue}),h=c.map(function(t){return t.categoryLabel});e[\"dimensions[\"+t.model.containerInd+\"].categoryarray\"]=[u],e[\"dimensions[\"+t.model.containerInd+\"].ticktext\"]=[h],e[\"dimensions[\"+t.model.containerInd+\"].categoryorder\"]=\"array\"}}if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")&&!t.dragHasMoved&&t.potentialClickBand&&(\"color\"===t.parcatsViewModel.hoveron?T(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent):k(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent)),t.model.dragX=null,null!==t.dragCategoryDisplayInd)t.parcatsViewModel.dimensions[t.dragDimensionDisplayInd].categories[t.dragCategoryDisplayInd].model.dragY=null,t.dragCategoryDisplayInd=null;t.dragDimensionDisplayInd=null,t.parcatsViewModel.dragDimension=null,t.dragHasMoved=null,t.potentialClickBand=null,R(t.parcatsViewModel),D(t.parcatsViewModel),n.transition().duration(300).ease(\"cubic-in-out\").each(function(){z(t.parcatsViewModel,!0),O(t.parcatsViewModel,!0)}).each(\"end\",function(){(o||s)&&i.restyle(t.parcatsViewModel.graphDiv,e,[r])})}}function P(t){for(var e,r=t.graphDiv._fullData,n=0;n<r.length;n++)if(t.key===r[n].uid){e=n;break}return e}function O(t,e){var r;void 0===e&&(e=!1),t.pathSelection.data(function(t){return t.paths},h),(r=t.pathSelection,e?r.transition():r).attr(\"d\",function(t){return t.svgD})}function z(t,e){function r(t){return e?t.transition():t}void 0===e&&(e=!1),t.dimensionSelection.data(function(t){return t.dimensions},h);var i=t.dimensionSelection.selectAll(\"g.category\").data(function(t){return t.categories},h);r(t.dimensionSelection).attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),r(i).attr(\"transform\",function(t){return\"translate(0, \"+t.y+\")\"}),i.select(\".dimlabel\").text(function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null}),i.select(\".catlabel\").attr(\"text-anchor\",function(t){return f(t)?\"start\":\"end\"}).attr(\"x\",function(t){return f(t)?t.width+5:-5}).each(function(t){var e,r;f(t)?(e=t.width+5,r=\"start\"):(e=-5,r=\"end\"),n.select(this).selectAll(\"tspan\").attr(\"x\",e).attr(\"text-anchor\",r)});var a=i.selectAll(\"rect.bandrect\").data(function(t){return t.bands},h),s=a.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"cursor\",\"move\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.color}).attr(\"fill-opacity\",0);a.attr(\"fill\",function(t){return t.color}).attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}).attr(\"y\",function(t){return t.y}),_(s),a.each(function(){o.raiseToTop(this)}),a.exit().remove()}function I(t,e,r,i,a){var o,s,l=[],c=[];for(s=0;s<r.length-1;s++)o=n.interpolateNumber(r[s]+t[s],t[s+1]),l.push(o(a)),c.push(o(1-a));var u=\"M \"+t[0]+\",\"+e[0];for(u+=\"l\"+r[0]+\",0 \",s=1;s<r.length;s++)u+=\"C\"+l[s-1]+\",\"+e[s-1]+\" \"+c[s-1]+\",\"+e[s]+\" \"+t[s]+\",\"+e[s],u+=\"l\"+r[s]+\",0 \";for(u+=\"l0,\"+i+\" \",u+=\"l -\"+r[r.length-1]+\",0 \",s=r.length-2;s>=0;s--)u+=\"C\"+c[s]+\",\"+(e[s+1]+i)+\" \"+l[s]+\",\"+(e[s]+i)+\" \"+(t[s]+r[s])+\",\"+(e[s]+i),u+=\"l-\"+r[s]+\",0 \";return u+=\"Z\"}function D(t){var e=t.dimensions,r=t.model,n=e.map(function(t){return t.categories.map(function(t){return t.y})}),i=t.model.dimensions.map(function(t){return t.categories.map(function(t){return t.displayInd})}),a=t.model.dimensions.map(function(t){return t.displayInd}),o=t.dimensions.map(function(t){return t.model.dimensionInd}),s=e.map(function(t){return t.x}),l=e.map(function(t){return t.width}),c=[];for(var u in r.paths)r.paths.hasOwnProperty(u)&&c.push(r.paths[u]);function h(t){var e=t.categoryInds.map(function(t,e){return i[e][t]});return o.map(function(t){return e[t]})}c.sort(function(e,r){var n=h(e),i=h(r);return\"backward\"===t.sortpaths&&(n.reverse(),i.reverse()),n.push(e.valueInds[0]),i.push(r.valueInds[0]),t.bundlecolors&&(n.unshift(e.rawColor),i.unshift(r.rawColor)),n<i?-1:n>i?1:0});for(var f=new Array(c.length),p=e[0].model.count,d=e[0].categories.map(function(t){return t.height}).reduce(function(t,e){return t+e}),g=0;g<c.length;g++){var v,m=c[g];v=p>0?d*(m.count/p):0;for(var y,x=new Array(n.length),b=0;b<m.categoryInds.length;b++){var _=m.categoryInds[b],w=i[b][_],k=a[b];x[k]=n[k][w],n[k][w]+=v;var T=t.dimensions[k].categories[w],A=T.bands.length,M=T.bands[A-1];if(void 0===M||m.rawColor!==M.rawColor){var S=void 0===M?0:M.y+M.height;T.bands.push({key:S,color:m.color,rawColor:m.rawColor,height:v,width:T.width,count:m.count,y:S,categoryViewModel:T,parcatsViewModel:t})}else{var E=T.bands[A-1];E.height+=v,E.count+=m.count}}y=\"hspline\"===t.pathShape?I(s,x,l,v,.5):I(s,x,l,v,0),f[g]={key:m.valueInds[0],model:m,height:v,leftXs:s,topYs:x,dimWidths:l,svgD:y,parcatsViewModel:t}}t.paths=f}function R(t){var e=t.model.dimensions.map(function(t){return{displayInd:t.displayInd,dimensionInd:t.dimensionInd}});e.sort(function(t,e){return t.displayInd-e.displayInd});var r=[];for(var n in e){var i=e[n].dimensionInd,a=t.model.dimensions[i];r.push(F(t,a))}t.dimensions=r}function F(t,e){var r,n=t.model.dimensions.length,i=e.displayInd;r=40+(n>1?(t.width-80-16)/(n-1):0)*i;var a,o,s,l,c,u=[],h=t.model.maxCats,f=e.categories.length,p=e.count,d=t.height-8*(h-1),g=8*(h-f)/2,v=e.categories.map(function(t){return{displayInd:t.displayInd,categoryInd:t.categoryInd}});for(v.sort(function(t,e){return t.displayInd-e.displayInd}),c=0;c<f;c++)l=v[c].categoryInd,o=e.categories[l],a=p>0?o.count/p*d:0,s={key:o.valueInds[0],model:o,width:16,height:a,y:null!==o.dragY?o.dragY:g,bands:[],parcatsViewModel:t},g=g+a+8,u.push(s);return{key:e.dimensionInd,x:null!==e.dragX?e.dragX:r,y:0,width:16,model:e,categories:u,parcatsViewModel:t,dragCategoryDisplayInd:null,dragDimensionDisplayInd:null,initialDragDimensionDisplayInds:null,initialDragCategoryDisplayInds:null,dragHasMoved:null,potentialClickBand:null}}e.exports=function(t,e,r,n){u(r,t,n,e)}},{\"../../components/drawing\":614,\"../../components/fx\":632,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_api\":754,d3:163,tinycolor2:537}],1073:[function(t,e,r){\"use strict\";var n=t(\"./parcats\");e.exports=function(t,e,r,i){var a=t._fullLayout,o=a._paper,s=a._size;n(t,o,e,{width:s.w,height:s.h,margin:{t:s.t,r:s.r,b:s.b,l:s.l}},r,i)}},{\"./parcats\":1072}],1074:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/cartesian/layout_attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../plots/domain\").attributes,s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/plot_template\").templatedArray;e.exports={domain:o({name:\"parcoords\",trace:!0,editType:\"plot\"}),labelangle:{valType:\"angle\",dflt:0,editType:\"plot\"},labelside:{valType:\"enumerated\",values:[\"top\",\"bottom\"],dflt:\"top\",editType:\"plot\"},labelfont:a({editType:\"plot\"}),tickfont:a({editType:\"plot\"}),rangefont:a({editType:\"plot\"}),dimensions:l(\"dimension\",{label:{valType:\"string\",editType:\"plot\"},tickvals:s({},i.tickvals,{editType:\"plot\"}),ticktext:s({},i.ticktext,{editType:\"plot\"}),tickformat:s({},i.tickformat,{editType:\"plot\"}),visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},constraintrange:{valType:\"info_array\",freeLength:!0,dimensions:\"1-2\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},multiselect:{valType:\"boolean\",dflt:!0,editType:\"plot\"},values:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"}),line:s({editType:\"calc\"},n(\"line\",{colorscaleDflt:\"Viridis\",autoColorDflt:!1,editTypeOverride:\"calc\"}))}},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1075:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\").keyFun,o=t(\"../../lib/gup\").repeat,s=t(\"../../lib\").sorterAsc,l=n.bar.snapRatio;function c(t,e){return t*(1-l)+e*l}var u=n.bar.snapClose;function h(t,e){return t*(1-u)+e*u}function f(t,e,r,n){if(function(t,e){for(var r=0;r<e.length;r++)if(t>=e[r][0]&&t<=e[r][1])return!0;return!1}(r,n))return r;var i=t?-1:1,a=0,o=e.length-1;if(i<0){var s=a;a=o,o=s}for(var l=e[a],u=l,f=a;i*f<i*o;f+=i){var p=f+i,d=e[p];if(i*r<i*h(l,d))return c(l,u);if(i*r<i*d||p===o)return c(d,l);u=l,l=d}}function p(t){t.attr(\"x\",-n.bar.captureWidth/2).attr(\"width\",n.bar.captureWidth)}function d(t){t.attr(\"visibility\",\"visible\").style(\"visibility\",\"visible\").attr(\"fill\",\"yellow\").attr(\"opacity\",0)}function g(t){if(!t.brush.filterSpecified)return\"0,\"+t.height;for(var e,r,n,i=v(t.brush.filter.getConsolidated(),t.height),a=[0],o=i.length?i[0][0]:null,s=0;s<i.length;s++)r=(e=i[s])[1]-e[0],a.push(o),a.push(r),(n=s+1)<i.length&&(o=i[n][0]-e[1]);return a.push(t.height),a}function v(t,e){return t.map(function(t){return t.map(function(t){return Math.max(0,t*e)}).sort(s)})}function m(){i.select(document.body).style(\"cursor\",null)}function y(t){t.attr(\"stroke-dasharray\",g)}function x(t,e){var r=i.select(t).selectAll(\".highlight, .highlight-shadow\");y(e?r.transition().duration(n.bar.snapDuration).each(\"end\",e):r)}function b(t,e){var r,i=t.brush,a=NaN,o={};if(i.filterSpecified){var s=t.height,l=i.filter.getConsolidated(),c=v(l,s),u=NaN,h=NaN,f=NaN;for(r=0;r<=c.length;r++){var p=c[r];if(p&&p[0]<=e&&e<=p[1]){u=r;break}if(h=r?r-1:NaN,p&&p[0]>e){f=r;break}}if(a=u,isNaN(a)&&(a=isNaN(h)||isNaN(f)?isNaN(h)?f:h:e-c[h][1]<c[f][0]-e?h:f),!isNaN(a)){var d=c[a],g=function(t,e){var r=n.bar.handleHeight;if(!(e>t[1]+r||e<t[0]-r))return e>=.9*t[1]+.1*t[0]?\"n\":e<=.9*t[0]+.1*t[1]?\"s\":\"ns\"}(d,e);g&&(o.interval=l[a],o.intervalPix=d,o.region=g)}}if(t.ordinal&&!o.region){var m=t.unitTickvals,y=t.unitToPaddedPx.invert(e);for(r=0;r<m.length;r++){var x=[.25*m[Math.max(r-1,0)]+.75*m[r],.25*m[Math.min(r+1,m.length-1)]+.75*m[r]];if(y>=x[0]&&y<=x[1]){o.clickableOrdinalRange=x;break}}}return o}function _(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.brush.svgBrush;a.wasDragged=!0,a._dragging=!0,a.grabbingBar?a.newExtent=[r-a.grabPoint,r+a.barLength-a.grabPoint].map(e.unitToPaddedPx.invert):a.newExtent=[a.startExtent,e.unitToPaddedPx.invert(r)].sort(s),e.brush.filterSpecified=!0,a.extent=a.stayingIntervals.concat([a.newExtent]),a.brushCallback(e),x(t.parentNode)}function w(t,e){var r=b(e,e.height-i.mouse(t)[1]-2*n.verticalPadding),a=\"crosshair\";r.clickableOrdinalRange?a=\"pointer\":r.region&&(a=r.region+\"-resize\"),i.select(document.body).style(\"cursor\",a)}function k(t){t.on(\"mousemove\",function(t){i.event.preventDefault(),t.parent.inBrushDrag||w(this,t)}).on(\"mouseleave\",function(t){t.parent.inBrushDrag||m()}).call(i.behavior.drag().on(\"dragstart\",function(t){!function(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.unitToPaddedPx.invert(r),o=e.brush,s=b(e,r),l=s.interval,c=o.svgBrush;if(c.wasDragged=!1,c.grabbingBar=\"ns\"===s.region,c.grabbingBar){var u=l.map(e.unitToPaddedPx);c.grabPoint=r-u[0]-n.verticalPadding,c.barLength=u[1]-u[0]}c.clickableOrdinalRange=s.clickableOrdinalRange,c.stayingIntervals=e.multiselect&&o.filterSpecified?o.filter.getConsolidated():[],l&&(c.stayingIntervals=c.stayingIntervals.filter(function(t){return t[0]!==l[0]&&t[1]!==l[1]})),c.startExtent=s.region?l[\"s\"===s.region?1:0]:a,e.parent.inBrushDrag=!0,c.brushStartCallback()}(this,t)}).on(\"drag\",function(t){_(this,t)}).on(\"dragend\",function(t){!function(t,e){var r=e.brush,n=r.filter,a=r.svgBrush;a._dragging||(w(t,e),_(t,e),e.brush.svgBrush.wasDragged=!1),a._dragging=!1,i.event.sourceEvent.stopPropagation();var o=a.grabbingBar;if(a.grabbingBar=!1,a.grabLocation=void 0,e.parent.inBrushDrag=!1,m(),!a.wasDragged)return a.wasDragged=void 0,a.clickableOrdinalRange?r.filterSpecified&&e.multiselect?a.extent.push(a.clickableOrdinalRange):(a.extent=[a.clickableOrdinalRange],r.filterSpecified=!0):o?(a.extent=a.stayingIntervals,0===a.extent.length&&A(r)):A(r),a.brushCallback(e),x(t.parentNode),void a.brushEndCallback(r.filterSpecified?n.getConsolidated():[]);var s=function(){n.set(n.getConsolidated())};if(e.ordinal){var l=e.unitTickvals;l[l.length-1]<l[0]&&l.reverse(),a.newExtent=[f(0,l,a.newExtent[0],a.stayingIntervals),f(1,l,a.newExtent[1],a.stayingIntervals)];var c=a.newExtent[1]>a.newExtent[0];a.extent=a.stayingIntervals.concat(c?[a.newExtent]:[]),a.extent.length||A(r),a.brushCallback(e),c?x(t.parentNode,s):(s(),x(t.parentNode))}else s();a.brushEndCallback(r.filterSpecified?n.getConsolidated():[])}(this,t)}))}function T(t,e){return t[0]-e[0]}function A(t){t.filterSpecified=!1,t.svgBrush.extent=[[-1/0,1/0]]}function M(t){for(var e,r=t.slice(),n=[],i=r.shift();i;){for(e=i.slice();(i=r.shift())&&i[0]<=e[1];)e[1]=Math.max(e[1],i[1]);n.push(e)}return n}e.exports={makeBrush:function(t,e,r,n,i,a){var o,l=function(){var t,e,r=[];return{set:function(n){1===(r=n.map(function(t){return t.slice().sort(s)}).sort(T)).length&&r[0][0]===-1/0&&r[0][1]===1/0&&(r=[[0,-1]]),t=M(r),e=r.reduce(function(t,e){return[Math.min(t[0],e[0]),Math.max(t[1],e[1])]},[1/0,-1/0])},get:function(){return r.slice()},getConsolidated:function(){return t},getBounds:function(){return e}}}();return l.set(r),{filter:l,filterSpecified:e,svgBrush:{extent:[],brushStartCallback:n,brushCallback:(o=i,function(t){var e=t.brush,r=function(t){return t.svgBrush.extent.map(function(t){return t.slice()})}(e).slice();e.filter.set(r),o()}),brushEndCallback:a}}},ensureAxisBrush:function(t){var e=t.selectAll(\".\"+n.cn.axisBrush).data(o,a);e.enter().append(\"g\").classed(n.cn.axisBrush,!0),function(t){var e=t.selectAll(\".background\").data(o);e.enter().append(\"rect\").classed(\"background\",!0).call(p).call(d).style(\"pointer-events\",\"auto\").attr(\"transform\",\"translate(0 \"+n.verticalPadding+\")\"),e.call(k).attr(\"height\",function(t){return t.height-n.verticalPadding});var r=t.selectAll(\".highlight-shadow\").data(o);r.enter().append(\"line\").classed(\"highlight-shadow\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width+n.bar.strokeWidth).attr(\"stroke\",n.bar.strokeColor).attr(\"opacity\",n.bar.strokeOpacity).attr(\"stroke-linecap\",\"butt\"),r.attr(\"y1\",function(t){return t.height}).call(y);var i=t.selectAll(\".highlight\").data(o);i.enter().append(\"line\").classed(\"highlight\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width-n.bar.strokeWidth).attr(\"stroke\",n.bar.fillColor).attr(\"opacity\",n.bar.fillOpacity).attr(\"stroke-linecap\",\"butt\"),i.attr(\"y1\",function(t){return t.height}).call(y)}(e)},cleanRanges:function(t,e){if(Array.isArray(t[0])?(t=t.map(function(t){return t.sort(s)}),t=e.multiselect?M(t.sort(T)):[t[0]]):t=[t.sort(s)],e.tickvals){var r=e.tickvals.slice().sort(s);if(!(t=t.map(function(t){var e=[f(0,r,t[0],[]),f(1,r,t[1],[])];if(e[1]>e[0])return e}).filter(function(t){return t})).length)return}return t.length>1?t:t[0]}}},{\"../../lib\":719,\"../../lib/gup\":717,\"./constants\":1078,d3:163}],1076:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../constants/xmlns_namespaces\");r.name=\"parcoords\",r.plot=function(t){var e=i(t.calcdata,\"parcoords\")[0];e.length&&a(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcoords\"),a=e._has&&e._has(\"parcoords\");i&&!a&&(n._paperdiv.selectAll(\".parcoords\").remove(),n._glimages.selectAll(\"*\").remove())},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter(function(t,e){return e===r.size()-1}).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each(function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})}),window.setTimeout(function(){n.selectAll(\"#filterBarPattern\").attr(\"id\",\"filterBarPattern\")},60)}},{\"../../constants/xmlns_namespaces\":696,\"../../plots/get_data\":802,\"./plot\":1085,d3:163}],1077:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale\"),a=t(\"../../lib/gup\").wrap;e.exports=function(t,e){var r,o;return i.hasColorscale(e,\"line\")&&n(e.line.color)?(r=e.line.color,o=i.extractOpts(e.line).colorscale,i.calc(t,e,{vals:r,containerStr:\"line\",cLetter:\"c\"})):(r=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=.5;return e}(e._length),o=[[0,e.line.color],[1,e.line.color]]),a({lineColor:r,cscale:o})}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gup\":717}],1078:[function(t,e,r){\"use strict\";e.exports={maxDimensionCount:60,overdrag:45,verticalPadding:2,tickDistance:50,canvasPixelRatio:1,blockLineCount:5e3,layers:[\"contextLineLayer\",\"focusLineLayer\",\"pickLineLayer\"],axisTitleOffset:28,axisExtentOffset:10,deselectedLineColor:\"#777\",bar:{width:4,captureWidth:10,fillColor:\"magenta\",fillOpacity:1,snapDuration:150,snapRatio:.25,snapClose:.01,strokeColor:\"white\",strokeOpacity:1,strokeWidth:1,handleHeight:8,handleOpacity:1,handleOverlap:0},cn:{axisExtentText:\"axis-extent-text\",parcoordsLineLayers:\"parcoords-line-layers\",parcoordsLineLayer:\"parcoords-lines\",parcoords:\"parcoords\",parcoordsControlView:\"parcoords-control-view\",yAxis:\"y-axis\",axisOverlays:\"axis-overlays\",axis:\"axis\",axisHeading:\"axis-heading\",axisTitle:\"axis-title\",axisExtent:\"axis-extent\",axisExtentTop:\"axis-extent-top\",axisExtentTopText:\"axis-extent-top-text\",axisExtentBottom:\"axis-extent-bottom\",axisExtentBottomText:\"axis-extent-bottom-text\",axisBrush:\"axis-brush\"},id:{filterBarPattern:\"filter-bar-pattern\"}}},{}],1079:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"../../plots/cartesian/axes\"),c=t(\"./attributes\"),u=t(\"./axisbrush\"),h=t(\"./constants\").maxDimensionCount,f=t(\"./merge_length\");function p(t,e,r,i){function a(r,i){return n.coerce(t,e,c.dimensions,r,i)}var o=a(\"values\"),s=a(\"visible\");if(o&&o.length||(s=e.visible=!1),s){a(\"label\"),a(\"tickvals\"),a(\"ticktext\"),a(\"tickformat\");var h=a(\"range\");e._ax={_id:\"y\",type:\"linear\",showexponent:\"all\",exponentformat:\"B\",range:h},l.setConvert(e._ax,i.layout),a(\"multiselect\");var f=a(\"constraintrange\");f&&(e.constraintrange=u.cleanRanges(f,e))}}e.exports=function(t,e,r,l){function u(r,i){return n.coerce(t,e,c,r,i)}var d=t.dimensions;Array.isArray(d)&&d.length>h&&(n.log(\"parcoords traces support up to \"+h+\" dimensions at the moment\"),d.splice(h));var g=s(t,e,{name:\"dimensions\",layout:l,handleItemDefaults:p}),v=function(t,e,r,o,s){var l=s(\"line.color\",r);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,l,u);o(e,l,u),Array.isArray(g)&&g.length||(e.visible=!1),f(e,g,\"values\",v);var m={family:l.font.family,size:Math.round(l.font.size/1.2),color:l.font.color};n.coerceFont(u,\"labelfont\",m),n.coerceFont(u,\"tickfont\",m),n.coerceFont(u,\"rangefont\",m),u(\"labelangle\"),u(\"labelside\")}},{\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"../../plots/domain\":792,\"./attributes\":1074,\"./axisbrush\":1075,\"./constants\":1078,\"./merge_length\":1083}],1080:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isTypedArray;r.convertTypedArray=function(t){return n(t)?Array.prototype.slice.call(t):t},r.isOrdinal=function(t){return!!t.tickvals},r.isVisible=function(t){return t.visible||!(\"visible\"in t)}},{\"../../lib\":719}],1081:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcoords\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"noOpacity\",\"noHover\"],meta:{}}},{\"./attributes\":1074,\"./base_plot\":1076,\"./calc\":1077,\"./defaults\":1079,\"./plot\":1085}],1082:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nattribute vec4 p01_04, p05_08, p09_12, p13_16,\\n               p17_20, p21_24, p25_28, p29_32,\\n               p33_36, p37_40, p41_44, p45_48,\\n               p49_52, p53_56, p57_60, colors;\\n\\nuniform mat4 dim0A, dim1A, dim0B, dim1B, dim0C, dim1C, dim0D, dim1D,\\n             loA, hiA, loB, hiB, loC, hiC, loD, hiD;\\n\\nuniform vec2 resolution, viewBoxPos, viewBoxSize;\\nuniform sampler2D mask, palette;\\nuniform float maskHeight;\\nuniform float drwLayer; // 0: context, 1: focus, 2: pick\\nuniform vec4 contextColor;\\n\\nbool isPick    = (drwLayer > 1.5);\\nbool isContext = (drwLayer < 0.5);\\n\\nconst vec4 ZEROS = vec4(0.0, 0.0, 0.0, 0.0);\\nconst vec4 UNITS = vec4(1.0, 1.0, 1.0, 1.0);\\n\\nfloat val(mat4 p, mat4 v) {\\n    return dot(matrixCompMult(p, v) * UNITS, UNITS);\\n}\\n\\nfloat axisY(float ratio, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float y1 = val(A, dim0A) + val(B, dim0B) + val(C, dim0C) + val(D, dim0D);\\n    float y2 = val(A, dim1A) + val(B, dim1B) + val(C, dim1C) + val(D, dim1D);\\n    return y1 * (1.0 - ratio) + y2 * ratio;\\n}\\n\\nint iMod(int a, int b) {\\n    return a - b * (a / b);\\n}\\n\\nbool fOutside(float p, float lo, float hi) {\\n    return (lo < hi) && (lo > p || p > hi);\\n}\\n\\nbool vOutside(vec4 p, vec4 lo, vec4 hi) {\\n    return (\\n        fOutside(p[0], lo[0], hi[0]) ||\\n        fOutside(p[1], lo[1], hi[1]) ||\\n        fOutside(p[2], lo[2], hi[2]) ||\\n        fOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool mOutside(mat4 p, mat4 lo, mat4 hi) {\\n    return (\\n        vOutside(p[0], lo[0], hi[0]) ||\\n        vOutside(p[1], lo[1], hi[1]) ||\\n        vOutside(p[2], lo[2], hi[2]) ||\\n        vOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool outsideBoundingBox(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    return mOutside(A, loA, hiA) ||\\n           mOutside(B, loB, hiB) ||\\n           mOutside(C, loC, hiC) ||\\n           mOutside(D, loD, hiD);\\n}\\n\\nbool outsideRasterMask(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    mat4 pnts[4];\\n    pnts[0] = A;\\n    pnts[1] = B;\\n    pnts[2] = C;\\n    pnts[3] = D;\\n\\n    for(int i = 0; i < 4; ++i) {\\n        for(int j = 0; j < 4; ++j) {\\n            for(int k = 0; k < 4; ++k) {\\n                if(0 == iMod(\\n                    int(255.0 * texture2D(mask,\\n                        vec2(\\n                            (float(i * 2 + j / 2) + 0.5) / 8.0,\\n                            (pnts[i][j][k] * (maskHeight - 1.0) + 1.0) / maskHeight\\n                        ))[3]\\n                    ) / int(pow(2.0, float(iMod(j * 4 + k, 8)))),\\n                    2\\n                )) return true;\\n            }\\n        }\\n    }\\n    return false;\\n}\\n\\nvec4 position(bool isContext, float v, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float x = 0.5 * sign(v) + 0.5;\\n    float y = axisY(x, A, B, C, D);\\n    float z = 1.0 - abs(v);\\n\\n    z += isContext ? 0.0 : 2.0 * float(\\n        outsideBoundingBox(A, B, C, D) ||\\n        outsideRasterMask(A, B, C, D)\\n    );\\n\\n    return vec4(\\n        2.0 * (vec2(x, y) * viewBoxSize + viewBoxPos) / resolution - 1.0,\\n        z,\\n        1.0\\n    );\\n}\\n\\nvoid main() {\\n    mat4 A = mat4(p01_04, p05_08, p09_12, p13_16);\\n    mat4 B = mat4(p17_20, p21_24, p25_28, p29_32);\\n    mat4 C = mat4(p33_36, p37_40, p41_44, p45_48);\\n    mat4 D = mat4(p49_52, p53_56, p57_60, ZEROS);\\n\\n    float v = colors[3];\\n\\n    gl_Position = position(isContext, v, A, B, C, D);\\n\\n    fragColor =\\n        isContext ? vec4(contextColor) :\\n        isPick ? vec4(colors.rgb, 1.0) : texture2D(palette, vec2(abs(v), 0.5));\\n}\\n\"]),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n    gl_FragColor = fragColor;\\n}\\n\"]),o=t(\"./constants\").maxDimensionCount,s=t(\"../../lib\"),l=1e-6,c=2048,u=new Uint8Array(4),h=new Uint8Array(4),f={shape:[256,1],format:\"rgba\",type:\"uint8\",mag:\"nearest\",min:\"nearest\"};function p(t,e,r,n,i){var a=t._gl;a.enable(a.SCISSOR_TEST),a.scissor(e,r,n,i),t.clear({color:[0,0,0,0],depth:1})}function d(t,e,r,n,i,a){var o=a.key;r.drawCompleted||(!function(t){t.read({x:0,y:0,width:1,height:1,data:u})}(t),r.drawCompleted=!0),function s(l){var c=Math.min(n,i-l*n);0===l&&(window.cancelAnimationFrame(r.currentRafs[o]),delete r.currentRafs[o],p(t,a.scissorX,a.scissorY,a.scissorWidth,a.viewBoxSize[1])),r.clearOnly||(a.count=2*c,a.offset=2*l*n,e(a),l*n+c<i&&(r.currentRafs[o]=window.requestAnimationFrame(function(){s(l+1)})),r.drawCompleted=!1)}(0)}function g(t,e){return(t>>>8*e)%256/255}function v(t,e,r){for(var n=new Array(8*e),i=0,a=0;a<e;a++)for(var o=0;o<2;o++)for(var s=0;s<4;s++){var l=4*t+s,c=r[64*a+l];63===l&&0===o&&(c*=-1),n[i++]=c}return n}function m(t){var e=\"0\"+t;return e.substr(e.length-2)}function y(t){return t<o?\"p\"+m(t+1)+\"_\"+m(t+4):\"colors\"}function x(t,e,r,n,i,a,o,l,c,u,h,f,p){for(var d=[[],[]],g=0;g<64;g++)d[0][g]=g===i?1:0,d[1][g]=g===a?1:0;var v=t.lines.canvasOverdrag,m=t.domain,y=t.canvasWidth,x=t.canvasHeight,b=t.deselectedLines.color;return s.extendFlat({key:h,resolution:[y,x],viewBoxPos:[o+v,l],viewBoxSize:[c,u],i0:i,i1:a,dim0A:d[0].slice(0,16),dim0B:d[0].slice(16,32),dim0C:d[0].slice(32,48),dim0D:d[0].slice(48,64),dim1A:d[1].slice(0,16),dim1B:d[1].slice(16,32),dim1C:d[1].slice(32,48),dim1D:d[1].slice(48,64),drwLayer:f,contextColor:[b[0]/255,b[1]/255,b[2]/255,b[3]<1?b[3]:Math.max(1/255,Math.pow(1/t.lines.color.length,1/3))],scissorX:(n===e?0:o+v)+(t.pad.l-v)+t.layoutWidth*m.x[0],scissorWidth:(n===r?y-o+v:c+.5)+(n===e?o+v:0),scissorY:l+t.pad.b+t.layoutHeight*m.y[0],scissorHeight:u,viewportX:t.pad.l-v+t.layoutWidth*m.x[0],viewportY:t.pad.b+t.layoutHeight*m.y[0],viewportWidth:y,viewportHeight:x},p)}function b(t){var e=c-1,r=Math.max(0,Math.floor(t[0]*e),0),n=Math.min(e,Math.ceil(t[1]*e),e);return[Math.min(r,n),Math.max(r,n)]}e.exports=function(t,e){var r,n,u,m,_,w=e.context,k=e.pick,T=e.regl,A={currentRafs:{},drawCompleted:!0,clearOnly:!1},M=function(t){for(var e={},r=0;r<=o;r+=4)e[y(r)]=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)});return e}(T),S=T.texture(f),E=[];L(e);var C=T({profile:!1,blend:{enable:w,func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:1,dstAlpha:1},equation:{rgb:\"add\",alpha:\"add\"},color:[0,0,0,0]},depth:{enable:!w,mask:!0,func:\"less\",range:[0,1]},cull:{enable:!0,face:\"back\"},scissor:{enable:!0,box:{x:T.prop(\"scissorX\"),y:T.prop(\"scissorY\"),width:T.prop(\"scissorWidth\"),height:T.prop(\"scissorHeight\")}},viewport:{x:T.prop(\"viewportX\"),y:T.prop(\"viewportY\"),width:T.prop(\"viewportWidth\"),height:T.prop(\"viewportHeight\")},dither:!1,vert:i,frag:a,primitive:\"lines\",lineWidth:1,attributes:M,uniforms:{resolution:T.prop(\"resolution\"),viewBoxPos:T.prop(\"viewBoxPos\"),viewBoxSize:T.prop(\"viewBoxSize\"),dim0A:T.prop(\"dim0A\"),dim1A:T.prop(\"dim1A\"),dim0B:T.prop(\"dim0B\"),dim1B:T.prop(\"dim1B\"),dim0C:T.prop(\"dim0C\"),dim1C:T.prop(\"dim1C\"),dim0D:T.prop(\"dim0D\"),dim1D:T.prop(\"dim1D\"),loA:T.prop(\"loA\"),hiA:T.prop(\"hiA\"),loB:T.prop(\"loB\"),hiB:T.prop(\"hiB\"),loC:T.prop(\"loC\"),hiC:T.prop(\"hiC\"),loD:T.prop(\"loD\"),hiD:T.prop(\"hiD\"),palette:S,contextColor:T.prop(\"contextColor\"),mask:T.prop(\"maskTexture\"),drwLayer:T.prop(\"drwLayer\"),maskHeight:T.prop(\"maskHeight\")},offset:T.prop(\"offset\"),count:T.prop(\"count\")});function L(t){r=t.model,n=t.viewModel,u=n.dimensions.slice(),m=u[0]?u[0].values.length:0;var e=r.lines,i=k?e.color.map(function(t,r){return r/e.color.length}):e.color,a=function(t,e,r){for(var n,i=new Array(t*(o+4)),a=0,s=0;s<t;s++){for(var c=0;c<o;c++)i[a++]=c<e.length?e[c].paddedUnitValues[s]:.5;i[a++]=g(s,2),i[a++]=g(s,1),i[a++]=g(s,0),i[a++]=(n=r[s],Math.max(l,Math.min(1-l,n)))}return i}(m,u,i);!function(t,e,r){for(var n=0;n<=o;n+=4)t[y(n)](v(n/4,e,r))}(M,m,a),w||k||(S=T.texture(s.extendFlat({data:function(t,e){for(var r=new Array(256),n=0;n<256;n++)r[n]=t(n/255).concat(e);return r}(r.unitToColor,255)},f)))}return{render:function(t,e,n){var i,a,o,s=t.length,l=1/0,h=-1/0;for(i=0;i<s;i++)t[i].dim0.canvasX<l&&(l=t[i].dim0.canvasX,a=i),t[i].dim1.canvasX>h&&(h=t[i].dim1.canvasX,o=i);0===s&&p(T,0,0,r.canvasWidth,r.canvasHeight);var f=function(t){var e,r,n,i=[[],[]];for(n=0;n<64;n++){var a=!t&&n<u.length?u[n].brush.filter.getBounds():[-1/0,1/0];i[0][n]=a[0],i[1][n]=a[1]}var o=8*c,s=new Array(o);for(e=0;e<o;e++)s[e]=255;if(!t)for(e=0;e<u.length;e++){var l=e%8,h=(e-l)/8,f=Math.pow(2,l),p=u[e].brush.filter.get();if(!(p.length<2)){var d=b(p[0])[1];for(r=1;r<p.length;r++){var g=b(p[r]);for(n=d+1;n<g[0];n++)s[8*n+h]&=~f;d=Math.max(d,g[1])}}}var v={shape:[8,c],format:\"alpha\",type:\"uint8\",mag:\"nearest\",min:\"nearest\",data:s};return _?_(v):_=T.texture(v),{maskTexture:_,maskHeight:c,loA:i[0].slice(0,16),loB:i[0].slice(16,32),loC:i[0].slice(32,48),loD:i[0].slice(48,64),hiA:i[1].slice(0,16),hiB:i[1].slice(16,32),hiC:i[1].slice(32,48),hiD:i[1].slice(48,64)}}(w);for(i=0;i<s;i++){var g=t[i],v=g.dim0.crossfilterDimensionIndex,y=g.dim1.crossfilterDimensionIndex,M=g.canvasX,S=g.canvasY,L=M+g.panelSizeX;if(e||!E[v]||E[v][0]!==M||E[v][1]!==L){E[v]=[M,L];var P=x(r,a,o,i,v,y,M,S,g.panelSizeX,g.panelSizeY,g.dim0.crossfilterDimensionIndex,w?0:k?2:1,f);A.clearOnly=n;var O=e?r.lines.blockLineCount:m;d(T,C,A,O,m,P)}}},readPixel:function(t,e){return T.read({x:t,y:e,width:1,height:1,data:h}),h},readPixels:function(t,e,r,n){var i=new Uint8Array(4*r*n);return T.read({x:t,y:e,width:r,height:n,data:i}),i},destroy:function(){for(var e in t.style[\"pointer-events\"]=\"none\",S.destroy(),_&&_.destroy(),M)M[e].destroy()},update:L}}},{\"../../lib\":719,\"./constants\":1078,glslify:409}],1083:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a;for(n||(n=1/0),i=0;i<e.length;i++)(a=e[i]).visible&&(n=Math.min(n,a[r].length));for(n===1/0&&(n=0),t._length=n,i=0;i<e.length;i++)(a=e[i]).visible&&(a._length=n);return n}},{}],1084:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"color-rgba\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../components/drawing\"),c=t(\"../../components/colorscale\"),u=t(\"../../lib/gup\"),h=u.keyFun,f=u.repeat,p=u.unwrap,d=t(\"./helpers\"),g=t(\"./constants\"),v=t(\"./axisbrush\"),m=t(\"./lines\");function y(t,e,r){return o.aggNums(t,null,e,r)}function x(t,e){return _(y(Math.min,t,e),y(Math.max,t,e))}function b(t){var e=t.range;return e?_(e[0],e[1]):x(t.values,t._length)}function _(t,e){return!isNaN(t)&&isFinite(t)||(t=0),!isNaN(e)&&isFinite(e)||(e=0),t===e&&(0===t?(t-=1,e+=1):(t*=.9,e*=1.1)),[t,e]}function w(t){return t.dimensions.some(function(t){return t.brush.filterSpecified})}function k(t,e,r){var a=p(e),s=a.trace,l=d.convertTypedArray(a.lineColor),u=s.line,h={color:i(g.deselectedLineColor)},f=c.extractOpts(u),v=f.reversescale?c.flipScale(a.cscale):a.cscale,m=s.domain,y=s.dimensions,x=t.width,_=s.labelangle,w=s.labelside,k=s.labelfont,T=s.tickfont,A=s.rangefont,M=o.extendDeepNoArrays({},u,{color:l.map(n.scale.linear().domain(b({values:l,range:[f.min,f.max],_length:s._length}))),blockLineCount:g.blockLineCount,canvasOverdrag:g.overdrag*g.canvasPixelRatio}),S=Math.floor(x*(m.x[1]-m.x[0])),E=Math.floor(t.height*(m.y[1]-m.y[0])),C=t.margin||{l:80,r:80,t:100,b:80},L=S,P=E;return{key:r,colCount:y.filter(d.isVisible).length,dimensions:y,tickDistance:g.tickDistance,unitToColor:function(t){var e=t.map(function(t){return t[0]}),r=t.map(function(t){var e=i(t[1]);return n.rgb(\"rgb(\"+e[0]+\",\"+e[1]+\",\"+e[2]+\")\")}),a=\"rgb\".split(\"\").map(function(t){return n.scale.linear().clamp(!0).domain(e).range(r.map((i=t,function(t){return t[i]})));var i});return function(t){return a.map(function(e){return e(t)})}}(v),lines:M,deselectedLines:h,labelAngle:_,labelSide:w,labelFont:k,tickFont:T,rangeFont:A,layoutWidth:x,layoutHeight:t.height,domain:m,translateX:m.x[0]*x,translateY:t.height-m.y[1]*t.height,pad:C,canvasWidth:L*g.canvasPixelRatio+2*M.canvasOverdrag,canvasHeight:P*g.canvasPixelRatio,width:L,height:P,canvasPixelRatio:g.canvasPixelRatio}}function T(t,e,r){var i=r.width,a=r.height,s=r.dimensions,l=r.canvasPixelRatio,c=function(t){return i*t/Math.max(1,r.colCount-1)},u=g.verticalPadding/a,h=function(t,e){return n.scale.linear().range([e,t-e])}(a,g.verticalPadding),f={key:r.key,xScale:c,model:r,inBrushDrag:!1},p={};return f.dimensions=s.filter(d.isVisible).map(function(i,s){var m=function(t,e){return n.scale.linear().domain(b(t)).range([e,1-e])}(i,u),y=p[i.label];p[i.label]=(y||0)+1;var x=i.label+(y?\"__\"+y:\"\"),_=i.constraintrange,k=_&&_.length;k&&!Array.isArray(_[0])&&(_=[_]);var T=k?_.map(function(t){return t.map(m)}):[[-1/0,1/0]],A=i.values;A.length>i._length&&(A=A.slice(0,i._length));var M,S=i.tickvals;function E(t,e){return{val:t,text:M[e]}}function C(t,e){return t.val-e.val}if(Array.isArray(S)&&S.length){M=i.ticktext,Array.isArray(M)&&M.length?M.length>S.length?M=M.slice(0,S.length):S.length>M.length&&(S=S.slice(0,M.length)):M=S.map(n.format(i.tickformat));for(var L=1;L<S.length;L++)if(S[L]<S[L-1]){for(var P=S.map(E).sort(C),O=0;O<S.length;O++)S[O]=P[O].val,M[O]=P[O].text;break}}else S=void 0;return A=d.convertTypedArray(A),A=d.convertTypedArray(A),{key:x,label:i.label,tickFormat:i.tickformat,tickvals:S,ticktext:M,ordinal:d.isOrdinal(i),multiselect:i.multiselect,xIndex:s,crossfilterDimensionIndex:s,visibleIndex:i._index,height:a,values:A,paddedUnitValues:A.map(m),unitTickvals:S&&S.map(m),xScale:c,x:c(s),canvasX:c(s)*l,unitToPaddedPx:h,domainScale:function(t,e,r,i,a){var o,s,l=b(r);return i?n.scale.ordinal().domain(i.map((o=n.format(r.tickformat),s=a,s?function(t,e){var r=s[e];return null==r?o(t):r}:o))).range(i.map(function(r){var n=(r-l[0])/(l[1]-l[0]);return t-e+n*(2*e-t)})):n.scale.linear().domain(l).range([t-e,e])}(a,g.verticalPadding,i,S,M),ordinalScale:function(t){if(t.tickvals){var e=b(t);return n.scale.ordinal().domain(t.tickvals).range(t.tickvals.map(function(t){return(t-e[0])/(e[1]-e[0])}))}}(i),parent:f,model:r,brush:v.makeBrush(t,k,T,function(){t.linePickActive(!1)},function(){var e=f;e.focusLayer&&e.focusLayer.render(e.panels,!0);var r=w(e);!t.contextShown()&&r?(e.contextLayer&&e.contextLayer.render(e.panels,!0),t.contextShown(!0)):t.contextShown()&&!r&&(e.contextLayer&&e.contextLayer.render(e.panels,!0,!0),t.contextShown(!1))},function(r){if(f.focusLayer.render(f.panels,!0),f.pickLayer&&f.pickLayer.render(f.panels,!0),t.linePickActive(!0),e&&e.filterChanged){var n=m.invert,a=r.map(function(t){return t.map(n).sort(o.sorterAsc)}).sort(function(t,e){return t[0]-e[0]});e.filterChanged(f.key,i._index,a)}})}}),f}function A(t){t.classed(g.cn.axisExtentText,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"default\").style(\"user-select\",\"none\")}function M(t,e){var r=\"top\"===e?1:-1,n=t*Math.PI/180;return{dir:r,dx:Math.sin(n),dy:Math.cos(n),degrees:t}}function S(t,e){for(var r=e.panels||(e.panels=[]),n=t.data(),i=0;i<n.length-1;i++){var a=r[i]||(r[i]={}),o=n[i],s=n[i+1];a.dim0=o,a.dim1=s,a.canvasX=o.canvasX,a.panelSizeX=s.canvasX-o.canvasX,a.panelSizeY=e.model.canvasHeight,a.y=0,a.canvasY=0}}function E(t,e){return a.tickText(t._ax,e,!1).text}function C(t,e){if(t.ordinal)return\"\";var r=t.domainScale.domain(),n=r[e?r.length-1:0];return E(t.model.dimensions[t.visibleIndex],n)}e.exports=function(t,e,r,i){var c=t._fullLayout,u=c._toppaper,y=c._glcontainer;!function(t){for(var e=0;e<t.length;e++)for(var r=0;r<t[e].length;r++)for(var n=t[e][r].trace,i=n.dimensions,o=0;o<i.length;o++){var s=i[o].values,l=i[o]._ax;l&&(l.range?l.range=_(l.range[0],l.range[1]):l.range=x(s,n._length),l.dtick||(l.dtick=.01*(Math.abs(l.range[1]-l.range[0])||1)),l.tickformat=i[o].tickformat,a.calcTicks(l),l.cleanRange())}}(e);var b,L,P=(b=!0,L=!1,{linePickActive:function(t){return arguments.length?b=!!t:b},contextShown:function(t){return arguments.length?L=!!t:L}}),O=e.filter(function(t){return p(t).trace.visible}).map(k.bind(0,r)).map(T.bind(0,P,i));y.each(function(t,e){return o.extendFlat(t,O[e])});var z=y.selectAll(\".gl-canvas\").each(function(t){t.viewModel=O[0],t.model=t.viewModel?t.viewModel.model:null}),I=null;z.filter(function(t){return t.pick}).style(\"pointer-events\",\"auto\").on(\"mousemove\",function(t){if(P.linePickActive()&&t.lineLayer&&i&&i.hover){var e=n.event,r=this.width,a=this.height,o=n.mouse(this),s=o[0],l=o[1];if(s<0||l<0||s>=r||l>=a)return;var c=t.lineLayer.readPixel(s,a-1-l),u=0!==c[3],h=u?c[2]+256*(c[1]+256*c[0]):null,f={x:s,y:l,clientX:e.clientX,clientY:e.clientY,dataIndex:t.model.key,curveNumber:h};h!==I&&(u?i.hover(f):i.unhover&&i.unhover(f),I=h)}}),z.style(\"opacity\",function(t){return t.pick?0:1}),u.style(\"background\",\"rgba(255, 255, 255, 0)\");var D=u.selectAll(\".\"+g.cn.parcoords).data(O,h);D.exit().remove(),D.enter().append(\"g\").classed(g.cn.parcoords,!0).style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"none\"),D.attr(\"transform\",function(t){return\"translate(\"+t.model.translateX+\",\"+t.model.translateY+\")\"});var R=D.selectAll(\".\"+g.cn.parcoordsControlView).data(f,h);R.enter().append(\"g\").classed(g.cn.parcoordsControlView,!0),R.attr(\"transform\",function(t){return\"translate(\"+t.model.pad.l+\",\"+t.model.pad.t+\")\"});var F=R.selectAll(\".\"+g.cn.yAxis).data(function(t){return t.dimensions},h);F.enter().append(\"g\").classed(g.cn.yAxis,!0),R.each(function(t){S(F,t)}),z.each(function(t){if(t.viewModel){!t.lineLayer||i?t.lineLayer=m(this,t):t.lineLayer.update(t),(t.key||0===t.key)&&(t.viewModel[t.key]=t.lineLayer);var e=!t.context||i;t.lineLayer.render(t.viewModel.panels,e)}}),F.attr(\"transform\",function(t){return\"translate(\"+t.xScale(t.xIndex)+\", 0)\"}),F.call(n.behavior.drag().origin(function(t){return t}).on(\"drag\",function(t){var e=t.parent;P.linePickActive(!1),t.x=Math.max(-g.overdrag,Math.min(t.model.width+g.overdrag,n.event.x)),t.canvasX=t.x*t.model.canvasPixelRatio,F.sort(function(t,e){return t.x-e.x}).each(function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e.xIndex),e.canvasX=e.x*e.model.canvasPixelRatio}),S(F,e),F.filter(function(e){return 0!==Math.abs(t.xIndex-e.xIndex)}).attr(\"transform\",function(t){return\"translate(\"+t.xScale(t.xIndex)+\", 0)\"}),n.select(this).attr(\"transform\",\"translate(\"+t.x+\", 0)\"),F.each(function(r,n,i){i===t.parent.key&&(e.dimensions[n]=r)}),e.contextLayer&&e.contextLayer.render(e.panels,!1,!w(e)),e.focusLayer.render&&e.focusLayer.render(e.panels)}).on(\"dragend\",function(t){var e=t.parent;t.x=t.xScale(t.xIndex),t.canvasX=t.x*t.model.canvasPixelRatio,S(F,e),n.select(this).attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),e.contextLayer&&e.contextLayer.render(e.panels,!1,!w(e)),e.focusLayer&&e.focusLayer.render(e.panels),e.pickLayer&&e.pickLayer.render(e.panels,!0),P.linePickActive(!0),i&&i.axesMoved&&i.axesMoved(e.key,e.dimensions.map(function(t){return t.crossfilterDimensionIndex}))})),F.exit().remove();var B=F.selectAll(\".\"+g.cn.axisOverlays).data(f,h);B.enter().append(\"g\").classed(g.cn.axisOverlays,!0),B.selectAll(\".\"+g.cn.axis).remove();var N=B.selectAll(\".\"+g.cn.axis).data(f,h);N.enter().append(\"g\").classed(g.cn.axis,!0),N.each(function(t){var e=t.model.height/t.model.tickDistance,r=t.domainScale,i=r.domain();n.select(this).call(n.svg.axis().orient(\"left\").tickSize(4).outerTickSize(2).ticks(e,t.tickFormat).tickValues(t.ordinal?i:null).tickFormat(function(e){return d.isOrdinal(t)?e:E(t.model.dimensions[t.visibleIndex],e)}).scale(r)),l.font(N.selectAll(\"text\"),t.model.tickFont)}),N.selectAll(\".domain, .tick>line\").attr(\"fill\",\"none\").attr(\"stroke\",\"black\").attr(\"stroke-opacity\",.25).attr(\"stroke-width\",\"1px\"),N.selectAll(\"text\").style(\"text-shadow\",\"1px 1px 1px #fff, -1px -1px 1px #fff, 1px -1px 1px #fff, -1px 1px 1px #fff\").style(\"cursor\",\"default\").style(\"user-select\",\"none\");var j=B.selectAll(\".\"+g.cn.axisHeading).data(f,h);j.enter().append(\"g\").classed(g.cn.axisHeading,!0);var U=j.selectAll(\".\"+g.cn.axisTitle).data(f,h);U.enter().append(\"text\").classed(g.cn.axisTitle,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"ew-resize\").style(\"user-select\",\"none\").style(\"pointer-events\",\"auto\"),U.text(function(t){return t.label}).each(function(e){var r=n.select(this);l.font(r,e.model.labelFont),s.convertToTspans(r,t)}).attr(\"transform\",function(t){var e=M(t.model.labelAngle,t.model.labelSide),r=g.axisTitleOffset;return(e.dir>0?\"\":\"translate(0,\"+(2*r+t.model.height)+\")\")+\"rotate(\"+e.degrees+\")translate(\"+-r*e.dx+\",\"+-r*e.dy+\")\"}).attr(\"text-anchor\",function(t){var e=M(t.model.labelAngle,t.model.labelSide);return 2*Math.abs(e.dx)>Math.abs(e.dy)?e.dir*e.dx<0?\"start\":\"end\":\"middle\"});var V=B.selectAll(\".\"+g.cn.axisExtent).data(f,h);V.enter().append(\"g\").classed(g.cn.axisExtent,!0);var q=V.selectAll(\".\"+g.cn.axisExtentTop).data(f,h);q.enter().append(\"g\").classed(g.cn.axisExtentTop,!0),q.attr(\"transform\",\"translate(0,\"+-g.axisExtentOffset+\")\");var H=q.selectAll(\".\"+g.cn.axisExtentTopText).data(f,h);H.enter().append(\"text\").classed(g.cn.axisExtentTopText,!0).call(A),H.text(function(t){return C(t,!0)}).each(function(t){l.font(n.select(this),t.model.rangeFont)});var G=V.selectAll(\".\"+g.cn.axisExtentBottom).data(f,h);G.enter().append(\"g\").classed(g.cn.axisExtentBottom,!0),G.attr(\"transform\",function(t){return\"translate(0,\"+(t.model.height+g.axisExtentOffset)+\")\"});var Y=G.selectAll(\".\"+g.cn.axisExtentBottomText).data(f,h);Y.enter().append(\"text\").classed(g.cn.axisExtentBottomText,!0).attr(\"dy\",\"0.75em\").call(A),Y.text(function(t){return C(t,!1)}).each(function(t){l.font(n.select(this),t.model.rangeFont)}),v.ensureAxisBrush(B)}},{\"../../components/colorscale\":605,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/gup\":717,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"./axisbrush\":1075,\"./constants\":1078,\"./helpers\":1080,\"./lines\":1082,\"color-rgba\":122,d3:163}],1085:[function(t,e,r){\"use strict\";var n=t(\"./parcoords\"),i=t(\"../../lib/prepare_regl\"),a=t(\"./helpers\").isVisible;function o(t,e,r){var n=e.indexOf(r),i=t.indexOf(n);return-1===i&&(i+=e.length),i}e.exports=function(t,e){var r=t._fullLayout;if(i(t)){var s={},l={},c={},u={},h=r._size;e.forEach(function(e,r){var n=e[0].trace;c[r]=n.index;var i=u[r]=n._fullInput.index;s[r]=t.data[i].dimensions,l[r]=t.data[i].dimensions.slice()});n(t,e,{width:h.w,height:h.h,margin:{t:h.t,r:h.r,b:h.b,l:h.l}},{filterChanged:function(e,n,i){var a=l[e][n],o=i.map(function(t){return t.slice()}),s=\"dimensions[\"+n+\"].constraintrange\",h=r._tracePreGUI[t._fullData[c[e]]._fullInput.uid];if(void 0===h[s]){var f=a.constraintrange;h[s]=f||null}var p=t._fullData[c[e]].dimensions[n];o.length?(1===o.length&&(o=o[0]),a.constraintrange=o,p.constraintrange=o.slice(),o=[o]):(delete a.constraintrange,delete p.constraintrange,o=null);var d={};d[s]=o,t.emit(\"plotly_restyle\",[d,[u[e]]])},hover:function(e){t.emit(\"plotly_hover\",e)},unhover:function(e){t.emit(\"plotly_unhover\",e)},axesMoved:function(e,r){var n=function(t,e){return function(r,n){return o(t,e,r)-o(t,e,n)}}(r,l[e].filter(a));s[e].sort(n),l[e].filter(function(t){return!a(t)}).sort(function(t){return l[e].indexOf(t)}).forEach(function(t){s[e].splice(s[e].indexOf(t),1),s[e].splice(l[e].indexOf(t),0,t)}),t.emit(\"plotly_restyle\",[{dimensions:[s[e]]},[u[e]]])}})}}},{\"../../lib/prepare_regl\":732,\"./helpers\":1080,\"./parcoords\":1084}],1086:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../plots/domain\").attributes,a=t(\"../../plots/font_attributes\"),o=t(\"../../components/color/attributes\"),s=t(\"../../components/fx/hovertemplate_attributes\"),l=t(\"../../lib/extend\").extendFlat,c=a({editType:\"plot\",arrayOk:!0,colorEditType:\"plot\"});e.exports={labels:{valType:\"data_array\",editType:\"calc\"},label0:{valType:\"number\",dflt:0,editType:\"calc\"},dlabel:{valType:\"number\",dflt:1,editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},marker:{colors:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:o.defaultLine,arrayOk:!0,editType:\"style\"},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0,editType:\"style\"},editType:\"calc\"},editType:\"calc\"},text:{valType:\"data_array\",editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"value\",\"percent\"],extras:[\"none\"],editType:\"calc\"},hoverinfo:l({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:s({},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"auto\",arrayOk:!0,editType:\"plot\"},textfont:l({},c,{}),insidetextfont:l({},c,{}),outsidetextfont:l({},c,{}),title:{text:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:l({},c,{}),position:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"plot\"},editType:\"plot\"},domain:i({name:\"pie\",trace:!0,editType:\"calc\"}),hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},sort:{valType:\"boolean\",dflt:!0,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"number\",min:-360,max:360,dflt:0,editType:\"calc\"},pull:{valType:\"number\",min:0,max:1,dflt:0,arrayOk:!0,editType:\"calc\"},_deprecated:{title:{valType:\"string\",dflt:\"\",editType:\"calc\"},titlefont:l({},c,{}),titleposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"calc\"}}}},{\"../../components/color/attributes\":592,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1087:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData;r.name=\"pie\",r.plot=function(t){var e=n.getModule(\"pie\"),r=i(t.calcdata,e)[0];e.plot(t,r)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"pie\"),a=e._has&&e._has(\"pie\");i&&!a&&n._pielayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],1088:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"tinycolor2\"),o=t(\"../../components/color\"),s=t(\"./helpers\"),l=t(\"../../lib\").isValidTextValue,c={};function u(t){return function(e,r){return!!e&&(!!(e=a(e)).isValid()&&(e=o.addOpacity(e,e.getAlpha()),t[r]||(t[r]=e),e))}}function h(t,e){var r,n=JSON.stringify(t),i=e[n];if(!i){for(i=t.slice(),r=0;r<t.length;r++)i.push(a(t[r]).lighten(20).toHexString());for(r=0;r<t.length;r++)i.push(a(t[r]).darken(20).toHexString());e[n]=i}return i}e.exports={calc:function(t,e){var r,a,o=[],c=t._fullLayout,h=c.hiddenlabels||[],f=e.labels,p=e.marker.colors||[],d=e.values,g=i(d)&&d.length;if(e.dlabel)for(f=new Array(d.length),r=0;r<d.length;r++)f[r]=String(e.label0+r*e.dlabel);var v={},m=u(c[\"_\"+e.type+\"colormap\"]),y=(g?d:f).length,x=0,b=!1;for(r=0;r<y;r++){var _,w,k;if(g){if(_=d[r],!n(_))continue;if((_=+_)<0)continue}else _=1;void 0!==(w=f[r])&&\"\"!==w||(w=r);var T=v[w=String(w)];void 0===T?(v[w]=o.length,(k=-1!==h.indexOf(w))||(x+=_),o.push({v:_,label:w,color:m(p[r],w),i:r,pts:[r],hidden:k})):(b=!0,(a=o[T]).v+=_,a.pts.push(r),a.hidden||(x+=_),!1===a.color&&p[r]&&(a.color=m(p[r],w)))}(\"funnelarea\"===e.type?b:e.sort)&&o.sort(function(t,e){return e.v-t.v}),o[0]&&(o[0].vTotal=x);var A=e.textinfo;if(A&&\"none\"!==A){var M,S=A.split(\"+\"),E=function(t){return-1!==S.indexOf(t)},C=E(\"label\"),L=E(\"text\"),P=E(\"value\"),O=E(\"percent\"),z=c.separators;for(r=0;r<o.length;r++){if(a=o[r],M=C?[a.label]:[],L){var I=s.getFirstFilled(e.text,a.pts);l(I)&&M.push(I)}P&&M.push(s.formatPieValue(a.v,z)),O&&M.push(s.formatPiePercent(a.v/x,z)),a.text=M.join(\"<br>\")}}return o},crossTraceCalc:function(t,e){var r=(e||{}).type;r||(r=\"pie\");var n=t._fullLayout,i=t.calcdata,a=n[r+\"colorway\"],o=n[\"_\"+r+\"colormap\"];n[\"extend\"+r+\"colors\"]&&(a=h(a,c));for(var s=0,l=0;l<i.length;l++){var u=i[l];if(u[0].trace.type===r)for(var f=0;f<u.length;f++){var p=u[f];!1===p.color&&(o[p.label]?p.color=o[p.label]:(o[p.label]=p.color=a[s%a.length],s++))}}},makePullColorFn:u,generateExtendedColors:h}},{\"../../components/color\":593,\"../../lib\":719,\"./helpers\":1091,\"fast-isnumeric\":225,tinycolor2:537}],1089:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}var c,u=l(\"values\"),h=n.isArrayOrTypedArray(u),f=l(\"labels\");if(Array.isArray(f)?(c=f.length,h&&(c=Math.min(c,u.length))):h&&(c=u.length,l(\"label0\"),l(\"dlabel\")),c){e._length=c,l(\"marker.line.width\")&&l(\"marker.line.color\"),l(\"marker.colors\"),l(\"scalegroup\");var p=l(\"text\"),d=l(\"textinfo\",Array.isArray(p)?\"text+percent\":\"percent\");if(l(\"hovertext\"),l(\"hovertemplate\"),d&&\"none\"!==d){var g=l(\"textposition\");o(t,e,s,l,g,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}a(e,s,l);var v=l(\"hole\");if(l(\"title.text\")){var m=l(\"title.position\",v?\"middle center\":\"top center\");v||\"middle center\"!==m||(e.title.position=\"top center\"),n.coerceFont(l,\"title.font\",s.font)}l(\"sort\"),l(\"direction\"),l(\"rotation\"),l(\"pull\")}else e.visible=!1}},{\"../../lib\":719,\"../../plots/domain\":792,\"../bar/defaults\":861,\"./attributes\":1086}],1090:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/helpers\").appendArrayMultiPointValues;e.exports=function(t,e){var r={curveNumber:e.index,pointNumbers:t.pts,data:e._input,fullData:e,label:t.label,color:t.color,value:t.v,percent:t.percent,text:t.text,v:t.v};return 1===t.pts.length&&(r.pointNumber=r.i=t.pts[0]),n(r,e,t.pts),\"funnelarea\"===e.type&&(delete r.v,delete r.i),r}},{\"../../components/fx/helpers\":628}],1091:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");r.formatPiePercent=function(t,e){var r=(100*t).toPrecision(3);return-1!==r.lastIndexOf(\".\")&&(r=r.replace(/[.]?0+$/,\"\")),n.numSeparate(r,e)+\"%\"},r.formatPieValue=function(t,e){var r=t.toPrecision(10);return-1!==r.lastIndexOf(\".\")&&(r=r.replace(/[.]?0+$/,\"\")),n.numSeparate(r,e)},r.getFirstFilled=function(t,e){if(Array.isArray(t))for(var r=0;r<e.length;r++){var n=t[e[r]];if(n||0===n)return n}},r.castOption=function(t,e){return Array.isArray(t)?r.getFirstFilled(t,e):t||void 0}},{\"../../lib\":719}],1092:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),layoutAttributes:t(\"./layout_attributes\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\"),styleOne:t(\"./style_one\"),moduleType:\"trace\",name:\"pie\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"pie\",\"showLegend\"],meta:{}}},{\"./attributes\":1086,\"./base_plot\":1087,\"./calc\":1088,\"./defaults\":1089,\"./layout_attributes\":1093,\"./layout_defaults\":1094,\"./plot\":1095,\"./style\":1096,\"./style_one\":1097}],1093:[function(t,e,r){\"use strict\";e.exports={hiddenlabels:{valType:\"data_array\",editType:\"calc\"},piecolorway:{valType:\"colorlist\",editType:\"calc\"},extendpiecolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1094:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"piecolorway\",e.colorway),r(\"extendpiecolors\")}},{\"../../lib\":719,\"./layout_attributes\":1093}],1095:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/fx\"),a=t(\"../../components/color\"),o=t(\"../../components/drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"./helpers\"),u=t(\"./event_data\");function h(t,e,r){var a=r[0],o=a.trace,l=a.cx,h=a.cy;\"_hasHoverLabel\"in o||(o._hasHoverLabel=!1),\"_hasHoverEvent\"in o||(o._hasHoverEvent=!1),t.on(\"mouseover\",function(t){var r=e._fullLayout,f=e._fullData[o.index];if(!e._dragging&&!1!==r.hovermode){var p=f.hoverinfo;if(Array.isArray(p)&&(p=i.castHoverinfo({hoverinfo:[c.castOption(p,t.pts)],_module:o._module},r,0)),\"all\"===p&&(p=\"label+text+value+percent+name\"),f.hovertemplate||\"none\"!==p&&\"skip\"!==p&&p){var d=t.rInscribed||0,g=l+t.pxmid[0]*(1-d),v=h+t.pxmid[1]*(1-d),m=r.separators,y=[];if(p&&-1!==p.indexOf(\"label\")&&y.push(t.label),t.text=c.castOption(f.hovertext||f.text,t.pts),p&&-1!==p.indexOf(\"text\")){var x=t.text;s.isValidTextValue(x)&&y.push(x)}t.value=t.v,t.valueLabel=c.formatPieValue(t.v,m),p&&-1!==p.indexOf(\"value\")&&y.push(t.valueLabel),t.percent=t.v/a.vTotal,t.percentLabel=c.formatPiePercent(t.percent,m),p&&-1!==p.indexOf(\"percent\")&&y.push(t.percentLabel);var b=f.hoverlabel,_=b.font;i.loneHover({trace:o,x0:g-d*a.r,x1:g+d*a.r,y:v,text:y.join(\"<br>\"),name:f.hovertemplate||-1!==p.indexOf(\"name\")?f.name:void 0,idealAlign:t.pxmid[0]<0?\"left\":\"right\",color:c.castOption(b.bgcolor,t.pts)||t.color,borderColor:c.castOption(b.bordercolor,t.pts),fontFamily:c.castOption(_.family,t.pts),fontSize:c.castOption(_.size,t.pts),fontColor:c.castOption(_.color,t.pts),nameLength:c.castOption(b.namelength,t.pts),textAlign:c.castOption(b.align,t.pts),hovertemplate:c.castOption(f.hovertemplate,t.pts),hovertemplateLabels:t,eventData:[u(t,f)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e}),o._hasHoverLabel=!0}o._hasHoverEvent=!0,e.emit(\"plotly_hover\",{points:[u(t,f)],event:n.event})}}),t.on(\"mouseout\",function(t){var r=e._fullLayout,a=e._fullData[o.index],s=n.select(this).datum();o._hasHoverEvent&&(t.originalEvent=n.event,e.emit(\"plotly_unhover\",{points:[u(s,a)],event:n.event}),o._hasHoverEvent=!1),o._hasHoverLabel&&(i.loneUnhover(r._hoverlayer.node()),o._hasHoverLabel=!1)}),t.on(\"click\",function(t){var r=e._fullLayout,a=e._fullData[o.index];e._dragging||!1===r.hovermode||(e._hoverdata=[u(t,a)],i.click(e,n.event))})}function f(t,e,r){var n=c.castOption(t.insidetextfont.color,e.pts);!n&&t._input.textfont&&(n=c.castOption(t._input.textfont.color,e.pts));var i=c.castOption(t.insidetextfont.family,e.pts)||c.castOption(t.textfont.family,e.pts)||r.family,o=c.castOption(t.insidetextfont.size,e.pts)||c.castOption(t.textfont.size,e.pts)||r.size;return{color:n||a.contrast(e.color),family:i,size:o}}function p(t,e){for(var r,n,i=0;i<t.length;i++)if((n=(r=t[i][0]).trace).title.text){var a=n.title.text;n._meta&&(a=s.templateString(a,n._meta));var c=o.tester.append(\"text\").attr(\"data-notex\",1).text(a).call(o.font,n.title.font).call(l.convertToTspans,e),u=o.bBox(c.node(),!0);r.titleBox={width:u.width,height:u.height},c.remove()}}function d(t,e,r){var n=Math.sqrt(t.width*t.width+t.height*t.height),i=t.width/t.height,a=e.halfangle,o=e.ring,s=e.rInscribed,l=r.r||e.rpx1,c={scale:s*l*2/n,rCenter:1-s,rotate:0};if(c.scale>=1)return c;var u=i+1/(2*Math.tan(a)),h=l*Math.min(1/(Math.sqrt(u*u+.5)+u),o/(Math.sqrt(i*i+o/2)+i)),f={scale:2*h/t.height,rCenter:Math.cos(h/l)-h*i/l,rotate:(180/Math.PI*e.midangle+720)%180-90},p=1/i,d=p+1/(2*Math.tan(a)),g=l*Math.min(1/(Math.sqrt(d*d+.5)+d),o/(Math.sqrt(p*p+o/2)+p)),v={scale:2*g/t.width,rCenter:Math.cos(g/l)-g/i/l,rotate:(180/Math.PI*e.midangle+810)%180-90},m=v.scale>f.scale?v:f;return c.scale<1&&m.scale>c.scale?m:c}function g(t,e){return t.v!==e.vTotal||e.trace.hole?Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2):1}function v(t,e){var r=e.pxmid[0],n=e.pxmid[1],i=t.width/2,a=t.height/2;return r<0&&(i*=-1),n<0&&(a*=-1),{scale:1,rCenter:1,rotate:0,x:i+Math.abs(a)*(i>0?1:-1)/2,y:a/(1+r*r/(n*n)),outside:!0}}function m(t,e){var r,n,i,a=t.trace,o={x:t.cx,y:t.cy},s={tx:0,ty:0};s.ty+=a.title.font.size,i=x(a),-1!==a.title.position.indexOf(\"top\")?(o.y-=(1+i)*t.r,s.ty-=t.titleBox.height):-1!==a.title.position.indexOf(\"bottom\")&&(o.y+=(1+i)*t.r);var l,c,u=(l=t.r,c=t.trace.aspectratio,l/(void 0===c?1:c)),h=e.w*(a.domain.x[1]-a.domain.x[0])/2;return-1!==a.title.position.indexOf(\"left\")?(h+=u,o.x-=(1+i)*u,s.tx+=t.titleBox.width/2):-1!==a.title.position.indexOf(\"center\")?h*=2:-1!==a.title.position.indexOf(\"right\")&&(h+=u,o.x+=(1+i)*u,s.tx-=t.titleBox.width/2),r=h/t.titleBox.width,n=y(t,e)/t.titleBox.height,{x:o.x,y:o.y,scale:Math.min(r,n),tx:s.tx,ty:s.ty}}function y(t,e){var r=t.trace,n=e.h*(r.domain.y[1]-r.domain.y[0]);return Math.min(t.titleBox.height,n/2)}function x(t){var e,r=t.pull;if(!r)return 0;if(Array.isArray(r))for(r=0,e=0;e<t.pull.length;e++)t.pull[e]>r&&(r=t.pull[e]);return r}function b(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n][0],a=i.trace,o=a.domain,s=e.w*(o.x[1]-o.x[0]),l=e.h*(o.y[1]-o.y[0]);a.title.text&&\"middle center\"!==a.title.position&&(l-=y(i,e));var c=s/2,u=l/2;\"funnelarea\"!==a.type||a.scalegroup||(u/=a.aspectratio),i.r=Math.min(c,u)/(1+x(a)),i.cx=e.l+e.w*(a.domain.x[1]+a.domain.x[0])/2,i.cy=e.t+e.h*(1-a.domain.y[0])-l/2,a.title.text&&-1!==a.title.position.indexOf(\"bottom\")&&(i.cy-=y(i,e)),a.scalegroup&&-1===r.indexOf(a.scalegroup)&&r.push(a.scalegroup)}!function(t,e){for(var r,n,i,a=0;a<e.length;a++){var o=1/0,s=e[a];for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var l;if(\"pie\"===i.type)l=r.r*r.r;else if(\"funnelarea\"===i.type){var c,u;i.aspectratio>1?(c=r.r,u=c/i.aspectratio):(u=r.r,c=u*i.aspectratio),c*=(1+i.baseratio)/2,l=c*u}o=Math.min(o,l/r.vTotal)}for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var h=o*r.vTotal;\"funnelarea\"===i.type&&(h/=(1+i.baseratio)/2,h/=i.aspectratio),r.r=Math.sqrt(h)}}}(t,r)}e.exports={plot:function(t,e){var r=t._fullLayout;p(e,t),b(e,r._size);var i=s.makeTraceGroups(r._pielayer,e,\"trace\").each(function(e){var i=n.select(this),u=e[0],p=u.trace;!function(t){var e,r,n,i=t[0],a=i.trace,o=a.rotation*Math.PI/180,s=2*Math.PI/i.vTotal,l=\"px0\",c=\"px1\";if(\"counterclockwise\"===a.direction){for(e=0;e<t.length&&t[e].hidden;e++);if(e===t.length)return;o+=s*t[e].v,s*=-1,l=\"px1\",c=\"px0\"}function u(t){return[i.r*Math.sin(t),-i.r*Math.cos(t)]}for(n=u(o),e=0;e<t.length;e++)(r=t[e]).hidden||(r[l]=n,o+=s*r.v/2,r.pxmid=u(o),r.midangle=o,o+=s*r.v/2,n=u(o),r[c]=n,r.largeArc=r.v>i.vTotal/2?1:0,r.halfangle=Math.PI*Math.min(r.v/i.vTotal,.5),r.ring=1-a.hole,r.rInscribed=g(r,i))}(e),i.attr(\"stroke-linejoin\",\"round\"),i.each(function(){var i=n.select(this).selectAll(\"g.slice\").data(e);i.enter().append(\"g\").classed(\"slice\",!0),i.exit().remove();var g=[[[],[]],[[],[]]],y=!1;i.each(function(r){if(r.hidden)n.select(this).selectAll(\"path,g\").remove();else{r.pointNumber=r.i,r.curveNumber=p.index,g[r.pxmid[1]<0?0:1][r.pxmid[0]<0?0:1].push(r);var i=u.cx,a=u.cy,m=n.select(this),x=m.selectAll(\"path.surface\").data([r]);if(x.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),m.call(h,t,e),p.pull){var b=+c.castOption(p.pull,r.pts)||0;b>0&&(i+=b*r.pxmid[0],a+=b*r.pxmid[1])}r.cxFinal=i,r.cyFinal=a;var _=p.hole;if(r.v===u.vTotal){var w=\"M\"+(i+r.px0[0])+\",\"+(a+r.px0[1])+S(r.px0,r.pxmid,!0,1)+S(r.pxmid,r.px0,!0,1)+\"Z\";_?x.attr(\"d\",\"M\"+(i+_*r.px0[0])+\",\"+(a+_*r.px0[1])+S(r.px0,r.pxmid,!1,_)+S(r.pxmid,r.px0,!1,_)+\"Z\"+w):x.attr(\"d\",w)}else{var k=S(r.px0,r.px1,!0,1);if(_){var T=1-_;x.attr(\"d\",\"M\"+(i+_*r.px1[0])+\",\"+(a+_*r.px1[1])+S(r.px1,r.px0,!1,_)+\"l\"+T*r.px0[0]+\",\"+T*r.px0[1]+k+\"Z\")}else x.attr(\"d\",\"M\"+i+\",\"+a+\"l\"+r.px0[0]+\",\"+r.px0[1]+k+\"Z\")}var A=c.castOption(p.textposition,r.pts),M=m.selectAll(\"g.slicetext\").data(r.text&&\"none\"!==A?[0]:[]);M.enter().append(\"g\").classed(\"slicetext\",!0),M.exit().remove(),M.each(function(){var e=s.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)});e.text(r.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(o.font,\"outside\"===A?function(t,e,r){var n=c.castOption(t.outsidetextfont.color,e.pts)||c.castOption(t.textfont.color,e.pts)||r.color,i=c.castOption(t.outsidetextfont.family,e.pts)||c.castOption(t.textfont.family,e.pts)||r.family,a=c.castOption(t.outsidetextfont.size,e.pts)||c.castOption(t.textfont.size,e.pts)||r.size;return{color:n,family:i,size:a}}(p,r,t._fullLayout.font):f(p,r,t._fullLayout.font)).call(l.convertToTspans,t);var h,g=o.bBox(e.node());\"outside\"===A?h=v(g,r):(h=d(g,r,u),\"auto\"===A&&h.scale<1&&(e.call(o.font,p.outsidetextfont),p.outsidetextfont.family===p.insidetextfont.family&&p.outsidetextfont.size===p.insidetextfont.size||(g=o.bBox(e.node())),h=v(g,r)));var m=i+r.pxmid[0]*h.rCenter+(h.x||0),x=a+r.pxmid[1]*h.rCenter+(h.y||0);h.outside&&(r.yLabelMin=x-g.height/2,r.yLabelMid=x,r.yLabelMax=x+g.height/2,r.labelExtraX=0,r.labelExtraY=0,y=!0),e.attr(\"transform\",\"translate(\"+m+\",\"+x+\")\"+(h.scale<1?\"scale(\"+h.scale+\")\":\"\")+(h.rotate?\"rotate(\"+h.rotate+\")\":\"\")+\"translate(\"+-(g.left+g.right)/2+\",\"+-(g.top+g.bottom)/2+\")\")})}function S(t,e,n,i){var a=i*(e[0]-t[0]),o=i*(e[1]-t[1]);return\"a\"+i*u.r+\",\"+i*u.r+\" 0 \"+r.largeArc+(n?\" 1 \":\" 0 \")+a+\",\"+o}});var x=n.select(this).selectAll(\"g.titletext\").data(p.title.text?[0]:[]);x.enter().append(\"g\").classed(\"titletext\",!0),x.exit().remove(),x.each(function(){var e,i=s.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),a=p.title.text;p._meta&&(a=s.templateString(a,p._meta)),i.text(a).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(o.font,p.title.font).call(l.convertToTspans,t),e=\"middle center\"===p.title.position?function(t){var e=Math.sqrt(t.titleBox.width*t.titleBox.width+t.titleBox.height*t.titleBox.height);return{x:t.cx,y:t.cy,scale:t.trace.hole*t.r*2/e,tx:0,ty:-t.titleBox.height/2+t.trace.title.font.size}}(u):m(u,r._size),i.attr(\"transform\",\"translate(\"+e.x+\",\"+e.y+\")\"+(e.scale<1?\"scale(\"+e.scale+\")\":\"\")+\"translate(\"+e.tx+\",\"+e.ty+\")\")}),y&&function(t,e){var r,n,i,a,o,s,l,u,h,f,p,d,g;function v(t,e){return t.pxmid[1]-e.pxmid[1]}function m(t,e){return e.pxmid[1]-t.pxmid[1]}function y(t,r){r||(r={});var i,u,h,p,d,g,v=r.labelExtraY+(n?r.yLabelMax:r.yLabelMin),m=n?t.yLabelMin:t.yLabelMax,y=n?t.yLabelMax:t.yLabelMin,x=t.cyFinal+o(t.px0[1],t.px1[1]),b=v-m;if(b*l>0&&(t.labelExtraY=b),Array.isArray(e.pull))for(u=0;u<f.length;u++)(h=f[u])===t||(c.castOption(e.pull,t.pts)||0)>=(c.castOption(e.pull,h.pts)||0)||((t.pxmid[1]-h.pxmid[1])*l>0?(p=h.cyFinal+o(h.px0[1],h.px1[1]),(b=p-m-t.labelExtraY)*l>0&&(t.labelExtraY+=b)):(y+t.labelExtraY-x)*l>0&&(i=3*s*Math.abs(u-f.indexOf(t)),d=h.cxFinal+a(h.px0[0],h.px1[0]),(g=d+i-(t.cxFinal+t.pxmid[0])-t.labelExtraX)*s>0&&(t.labelExtraX+=g)))}for(n=0;n<2;n++)for(i=n?v:m,o=n?Math.max:Math.min,l=n?1:-1,r=0;r<2;r++){for(a=r?Math.max:Math.min,s=r?1:-1,(u=t[n][r]).sort(i),h=t[1-n][r],f=h.concat(u),d=[],p=0;p<u.length;p++)void 0!==u[p].yLabelMid&&d.push(u[p]);for(g=!1,p=0;n&&p<h.length;p++)if(void 0!==h[p].yLabelMid){g=h[p];break}for(p=0;p<d.length;p++){var x=p&&d[p-1];g&&!p&&(x=g),y(d[p],x)}}}(g,p),function(t,e){t.each(function(t){var r=n.select(this);if(t.labelExtraX||t.labelExtraY){var i=r.select(\"g.slicetext text\");i.attr(\"transform\",\"translate(\"+t.labelExtraX+\",\"+t.labelExtraY+\")\"+i.attr(\"transform\"));var o=t.cxFinal+t.pxmid[0],l=t.cyFinal+t.pxmid[1],c=\"M\"+o+\",\"+l,u=(t.yLabelMax-t.yLabelMin)*(t.pxmid[0]<0?-1:1)/4;if(t.labelExtraX){var h=t.labelExtraX*t.pxmid[1]/t.pxmid[0],f=t.yLabelMid+t.labelExtraY-(t.cyFinal+t.pxmid[1]);Math.abs(h)>Math.abs(f)?c+=\"l\"+f*t.pxmid[0]/t.pxmid[1]+\",\"+f+\"H\"+(o+t.labelExtraX+u):c+=\"l\"+t.labelExtraX+\",\"+h+\"v\"+(f-h)+\"h\"+u}else c+=\"V\"+(t.yLabelMid+t.labelExtraY)+\"h\"+u;s.ensureSingle(r,\"path\",\"textline\").call(a.stroke,e.outsidetextfont.color).attr({\"stroke-width\":Math.min(2,e.outsidetextfont.size/8),d:c,fill:\"none\"})}else r.select(\"path.textline\").remove()})}(i,p)})});setTimeout(function(){i.selectAll(\"tspan\").each(function(){var t=n.select(this);t.attr(\"dy\")&&t.attr(\"dy\",t.attr(\"dy\"))})},0)},transformInsideText:d,determineInsideTextFont:f,positionTitleOutside:m,prerenderTitles:p,layoutAreas:b,attachFxHandlers:h}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"./event_data\":1090,\"./helpers\":1091,d3:163}],1096:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./style_one\");e.exports=function(t){t._fullLayout._pielayer.selectAll(\".trace\").each(function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each(function(t){n.select(this).call(i,t,e)})})}},{\"./style_one\":1097,d3:163}],1097:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./helpers\").castOption;e.exports=function(t,e,r){var a=r.marker.line,o=i(a.color,e.pts)||n.defaultLine,s=i(a.width,e.pts)||0;t.style(\"stroke-width\",s).call(n.fill,e.color).call(n.stroke,o)}},{\"../../components/color\":593,\"./helpers\":1091}],1098:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\");e.exports={x:n.x,y:n.y,xy:{valType:\"data_array\",editType:\"calc\"},indices:{valType:\"data_array\",editType:\"calc\"},xbounds:{valType:\"data_array\",editType:\"calc\"},ybounds:{valType:\"data_array\",editType:\"calc\"},text:n.text,marker:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,arrayOk:!1,editType:\"calc\"},blend:{valType:\"boolean\",dflt:null,editType:\"calc\"},sizemin:{valType:\"number\",min:.1,max:2,dflt:.5,editType:\"calc\"},sizemax:{valType:\"number\",min:.1,dflt:20,editType:\"calc\"},border:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},arearatio:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},transforms:void 0}},{\"../scatter/attributes\":1112}],1099:[function(t,e,r){\"use strict\";var n=t(\"gl-pointcloud2d\"),i=t(\"../../lib/str2rgbarray\"),a=t(\"../../plots/cartesian/autorange\").findExtremes,o=t(\"../scatter/get_trace_color\");function s(t,e){this.scene=t,this.uid=e,this.type=\"pointcloud\",this.pickXData=[],this.pickYData=[],this.xData=[],this.yData=[],this.textLabels=[],this.color=\"rgb(0, 0, 0)\",this.name=\"\",this.hoverinfo=\"all\",this.idToIndex=new Int32Array(0),this.bounds=[0,0,0,0],this.pointcloudOptions={positions:new Float32Array(0),idToIndex:this.idToIndex,sizemin:.5,sizemax:12,color:[0,0,0,1],areaRatio:1,borderColor:[0,0,0,1]},this.pointcloud=n(t.glplot,this.pointcloudOptions),this.pointcloud._trace=this}var l=s.prototype;l.handlePick=function(t){var e=this.idToIndex[t.pointId];return{trace:this,dataCoord:t.dataCoord,traceCoord:this.pickXYData?[this.pickXYData[2*e],this.pickXYData[2*e+1]]:[this.pickXData[e],this.pickYData[e]],textLabel:Array.isArray(this.textLabels)?this.textLabels[e]:this.textLabels,color:this.color,name:this.name,pointIndex:e,hoverinfo:this.hoverinfo}},l.update=function(t){this.index=t.index,this.textLabels=t.text,this.name=t.name,this.hoverinfo=t.hoverinfo,this.bounds=[1/0,1/0,-1/0,-1/0],this.updateFast(t),this.color=o(t,{})},l.updateFast=function(t){var e,r,n,o,s,l,c=this.xData=this.pickXData=t.x,u=this.yData=this.pickYData=t.y,h=this.pickXYData=t.xy,f=t.xbounds&&t.ybounds,p=t.indices,d=this.bounds;if(h){if(n=h,e=h.length>>>1,f)d[0]=t.xbounds[0],d[2]=t.xbounds[1],d[1]=t.ybounds[0],d[3]=t.ybounds[1];else for(l=0;l<e;l++)o=n[2*l],s=n[2*l+1],o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);if(p)r=p;else for(r=new Int32Array(e),l=0;l<e;l++)r[l]=l}else for(e=c.length,n=new Float32Array(2*e),r=new Int32Array(e),l=0;l<e;l++)o=c[l],s=u[l],r[l]=l,n[2*l]=o,n[2*l+1]=s,o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);this.idToIndex=r,this.pointcloudOptions.idToIndex=r,this.pointcloudOptions.positions=n;var g=i(t.marker.color),v=i(t.marker.border.color),m=t.opacity*t.marker.opacity;g[3]*=m,this.pointcloudOptions.color=g;var y=t.marker.blend;if(null===y){y=c.length<100||u.length<100}this.pointcloudOptions.blend=y,v[3]*=m,this.pointcloudOptions.borderColor=v;var x=t.marker.sizemin,b=Math.max(t.marker.sizemax,t.marker.sizemin);this.pointcloudOptions.sizeMin=x,this.pointcloudOptions.sizeMax=b,this.pointcloudOptions.areaRatio=t.marker.border.arearatio,this.pointcloud.update(this.pointcloudOptions);var _=this.scene.xaxis,w=this.scene.yaxis,k=b/2||.5;t._extremes[_._id]=a(_,[d[0],d[2]],{ppad:k}),t._extremes[w._id]=a(w,[d[1],d[3]],{ppad:k})},l.dispose=function(){this.pointcloud.dispose()},e.exports=function(t,e){var r=new s(t,e.uid);return r.update(e),r}},{\"../../lib/str2rgbarray\":742,\"../../plots/cartesian/autorange\":766,\"../scatter/get_trace_color\":1121,\"gl-pointcloud2d\":292}],1100:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\");e.exports=function(t,e,r){function a(r,a){return n.coerce(t,e,i,r,a)}a(\"x\"),a(\"y\"),a(\"xbounds\"),a(\"ybounds\"),t.xy&&t.xy instanceof Float32Array&&(e.xy=t.xy),t.indices&&t.indices instanceof Int32Array&&(e.indices=t.indices),a(\"text\"),a(\"marker.color\",r),a(\"marker.opacity\"),a(\"marker.blend\"),a(\"marker.sizemin\"),a(\"marker.sizemax\"),a(\"marker.border.color\",r),a(\"marker.border.arearatio\"),e._length=null}},{\"../../lib\":719,\"./attributes\":1098}],1101:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../scatter3d/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"pointcloud\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"showLegend\"],meta:{}}},{\"../../plots/gl2d\":805,\"../scatter3d/calc\":1139,\"./attributes\":1098,\"./convert\":1099,\"./defaults\":1100}],1102:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../components/fx/attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../../components/fx/hovertemplate_attributes\"),c=t(\"../../components/colorscale/attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,h=t(\"../../lib/extend\").extendFlat,f=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=f({hoverinfo:h({},i.hoverinfo,{flags:[],arrayOk:!1}),hoverlabel:o.hoverlabel,domain:s({name:\"sankey\",trace:!0}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\"},valueformat:{valType:\"string\",dflt:\".3s\"},valuesuffix:{valType:\"string\",dflt:\"\"},arrangement:{valType:\"enumerated\",values:[\"snap\",\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"snap\"},textfont:n({}),node:{label:{valType:\"data_array\",dflt:[]},groups:{valType:\"info_array\",impliedEdits:{x:[],y:[]},dimensions:2,freeLength:!0,dflt:[],items:{valType:\"number\",editType:\"calc\"}},x:{valType:\"data_array\",dflt:[]},y:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:.5,arrayOk:!0}},pad:{valType:\"number\",arrayOk:!1,min:0,dflt:20},thickness:{valType:\"number\",arrayOk:!1,min:1,dflt:20},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]})},link:{label:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0}},source:{valType:\"data_array\",dflt:[]},target:{valType:\"data_array\",dflt:[]},value:{valType:\"data_array\",dflt:[]},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]}),colorscales:u(\"concentrationscales\",{editType:\"calc\",label:{valType:\"string\",editType:\"calc\",dflt:\"\"},cmax:{valType:\"number\",editType:\"calc\",dflt:1},cmin:{valType:\"number\",editType:\"calc\",dflt:0},colorscale:h(c().colorscale,{dflt:[[0,\"white\"],[1,\"black\"]]})})}},\"calc\",\"nested\")).transforms=void 0},{\"../../components/color/attributes\":592,\"../../components/colorscale/attributes\":600,\"../../components/fx/attributes\":623,\"../../components/fx/hovertemplate_attributes\":631,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1103:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../components/fx/layout_attributes\"),s=t(\"../../lib/setcursor\"),l=t(\"../../components/dragelement\"),c=t(\"../../plots/cartesian/select\").prepSelect,u=t(\"../../lib\"),h=t(\"../../registry\");function f(t,e){var r=t._fullData[e],n=t._fullLayout,i=n.dragmode,a=\"pan\"===n.dragmode?\"move\":\"crosshair\",o=r._bgRect;if(\"pan\"!==i&&\"zoom\"!==i){s(o,a);var f={_id:\"x\",c2p:u.identity,_offset:r._sankey.translateX,_length:r._sankey.width},p={_id:\"y\",c2p:u.identity,_offset:r._sankey.translateY,_length:r._sankey.height},d={gd:t,element:o.node(),plotinfo:{id:e,xaxis:f,yaxis:p,fillRangeItems:u.noop},subplot:e,xaxes:[f],yaxes:[p],doneFnCompleted:function(r){var n,i=t._fullData[e],a=i.node.groups.slice(),o=[];function s(t){for(var e=i._sankey.graph.nodes,r=0;r<e.length;r++)if(e[r].pointNumber===t)return e[r]}for(var l=0;l<r.length;l++){var c=s(r[l].pointNumber);if(c)if(c.group){for(var u=0;u<c.childrenNodes.length;u++)o.push(c.childrenNodes[u].pointNumber);a[c.pointNumber-i.node._count]=!1}else o.push(c.pointNumber)}n=a.filter(Boolean).concat([o]),h.call(\"_guiRestyle\",t,{\"node.groups\":[n]},e)},prepFn:function(t,e,r){c(t,e,r,d,i)}};l.init(d)}}r.name=\"sankey\",r.baseLayoutAttrOverrides=n({hoverlabel:o.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){var e=i(t.calcdata,\"sankey\")[0];a(t,e),r.updateFx(t)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"sankey\"),a=e._has&&e._has(\"sankey\");i&&!a&&(n._paperdiv.selectAll(\".sankey\").remove(),n._paperdiv.selectAll(\".bgsankey\").remove())},r.updateFx=function(t){for(var e=0;e<t._fullData.length;e++)f(t,e)}},{\"../../components/dragelement\":611,\"../../components/fx/layout_attributes\":633,\"../../lib\":719,\"../../lib/setcursor\":739,\"../../plot_api/edit_types\":750,\"../../plots/cartesian/select\":784,\"../../plots/get_data\":802,\"../../registry\":847,\"./plot\":1108}],1104:[function(t,e,r){\"use strict\";var n=t(\"strongly-connected-components\"),i=t(\"../../lib\"),a=t(\"../../lib/gup\").wrap,o=i.isArrayOrTypedArray,s=i.isIndex,l=t(\"../../components/colorscale\");function c(t){var e,r=t.node,a=t.link,c=[],u=o(a.color),h={},f={},p=a.colorscales.length;for(e=0;e<p;e++){var d=a.colorscales[e],g=l.extractScale(d,{cLetter:\"c\"}),v=l.makeColorScaleFunc(g);f[d.label]=v}var m=0;for(e=0;e<a.value.length;e++)a.source[e]>m&&(m=a.source[e]),a.target[e]>m&&(m=a.target[e]);var y,x=m+1;t.node._count=x;var b=t.node.groups,_={};for(e=0;e<b.length;e++){var w=b[e];for(y=0;y<w.length;y++){var k=w[y],T=x+e;_.hasOwnProperty(k)?i.warn(\"Node \"+k+\" is already part of a group.\"):_[k]=T}}var A={source:[],target:[]};for(e=0;e<a.value.length;e++){var M=a.value[e],S=a.source[e],E=a.target[e];if(M>0&&s(S,x)&&s(E,x)&&(!_.hasOwnProperty(S)||!_.hasOwnProperty(E)||_[S]!==_[E])){_.hasOwnProperty(E)&&(E=_[E]),_.hasOwnProperty(S)&&(S=_[S]),E=+E,h[S=+S]=h[E]=!0;var C=\"\";a.label&&a.label[e]&&(C=a.label[e]);var L=null;C&&f.hasOwnProperty(C)&&(L=f[C]),c.push({pointNumber:e,label:C,color:u?a.color[e]:a.color,concentrationscale:L,source:S,target:E,value:+M}),A.source.push(S),A.target.push(E)}}var P=x+b.length,O=o(r.color),z=[];for(e=0;e<P;e++)if(h[e]){var I=r.label[e];z.push({group:e>x-1,childrenNodes:[],pointNumber:e,label:I,color:O?r.color[e]:r.color})}var D=!1;return function(t,e,r){for(var a=i.init2dArray(t,0),o=0;o<Math.min(e.length,r.length);o++)if(i.isIndex(e[o],t)&&i.isIndex(r[o],t)){if(e[o]===r[o])return!0;a[e[o]].push(r[o])}return n(a).components.some(function(t){return t.length>1})}(P,A.source,A.target)&&(D=!0),{circular:D,links:c,nodes:z,groups:b,groupLookup:_}}e.exports=function(t,e){var r=c(e);return a({circular:r.circular,_nodes:r.nodes,_links:r.links,_groups:r.groups,_groupLookup:r.groupLookup})}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gup\":717,\"strongly-connected-components\":530}],1105:[function(t,e,r){\"use strict\";e.exports={nodeTextOffsetHorizontal:4,nodeTextOffsetVertical:3,nodePadAcross:10,sankeyIterations:50,forceIterations:5,forceTicksPerFrame:10,duration:500,ease:\"linear\",cn:{sankey:\"sankey\",sankeyLinks:\"sankey-links\",sankeyLink:\"sankey-link\",sankeyNodeSet:\"sankey-node-set\",sankeyNode:\"sankey-node\",nodeRect:\"node-rect\",nodeCapture:\"node-capture\",nodeCentered:\"node-entered\",nodeLabelGuide:\"node-label-guide\",nodeLabel:\"node-label\",nodeLabelTextPath:\"node-label-text-path\"}}},{}],1106:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../components/color\"),o=t(\"tinycolor2\"),s=t(\"../../plots/domain\").defaults,l=t(\"../../components/fx/hoverlabel_defaults\"),c=t(\"../../plot_api/plot_template\"),u=t(\"../../plots/array_container_defaults\");function h(t,e){function r(r,a){return n.coerce(t,e,i.link.colorscales,r,a)}r(\"label\"),r(\"cmin\"),r(\"cmax\"),r(\"colorscale\")}e.exports=function(t,e,r,f){function p(r,a){return n.coerce(t,e,i,r,a)}var d=n.extendDeep(f.hoverlabel,t.hoverlabel),g=t.node,v=c.newContainer(e,\"node\");function m(t,e){return n.coerce(g,v,i.node,t,e)}m(\"label\"),m(\"groups\"),m(\"x\"),m(\"y\"),m(\"pad\"),m(\"thickness\"),m(\"line.color\"),m(\"line.width\"),m(\"hoverinfo\",t.hoverinfo),l(g,v,m,d),m(\"hovertemplate\");var y=f.colorway;m(\"color\",v.label.map(function(t,e){return a.addOpacity(function(t){return y[t%y.length]}(e),.8)}));var x=t.link||{},b=c.newContainer(e,\"link\");function _(t,e){return n.coerce(x,b,i.link,t,e)}_(\"label\"),_(\"source\"),_(\"target\"),_(\"value\"),_(\"line.color\"),_(\"line.width\"),_(\"hoverinfo\",t.hoverinfo),l(x,b,_,d),_(\"hovertemplate\");var w,k=o(f.paper_bgcolor).getLuminance()<.333?\"rgba(255, 255, 255, 0.6)\":\"rgba(0, 0, 0, 0.2)\";_(\"color\",n.repeat(k,b.value.length)),u(x,b,{name:\"colorscales\",handleItemDefaults:h}),s(e,f,p),p(\"orientation\"),p(\"valueformat\"),p(\"valuesuffix\"),v.x.length&&v.y.length&&(w=\"freeform\"),p(\"arrangement\",w),n.coerceFont(p,\"textfont\",n.extendFlat({},f.font)),e._length=null}},{\"../../components/color\":593,\"../../components/fx/hoverlabel_defaults\":630,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/array_container_defaults\":763,\"../../plots/domain\":792,\"./attributes\":1102,tinycolor2:537}],1107:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"sankey\",basePlotModule:t(\"./base_plot\"),selectPoints:t(\"./select.js\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1102,\"./base_plot\":1103,\"./calc\":1104,\"./defaults\":1106,\"./plot\":1108,\"./select.js\":1110}],1108:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./render\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\"),l=t(\"./constants\").cn,c=s._;function u(t){return\"\"!==t}function h(t,e){return t.filter(function(t){return t.key===e.traceId})}function f(t,e){n.select(t).select(\"path\").style(\"fill-opacity\",e),n.select(t).select(\"rect\").style(\"fill-opacity\",e)}function p(t){n.select(t).select(\"text.name\").style(\"fill\",\"black\")}function d(t){return function(e){return-1!==t.node.sourceLinks.indexOf(e.link)||-1!==t.node.targetLinks.indexOf(e.link)}}function g(t){return function(e){return-1!==e.node.sourceLinks.indexOf(t.link)||-1!==e.node.targetLinks.indexOf(t.link)}}function v(t,e,r){e&&r&&h(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(y.bind(0,e,r,!1))}function m(t,e,r){e&&r&&h(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(x.bind(0,e,r,!1))}function y(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",function(t){if(!t.link.concentrationscale)return.4}),i&&h(e,t).selectAll(\".\"+l.sankeyLink).filter(function(t){return t.link.label===i}).style(\"fill-opacity\",function(t){if(!t.link.concentrationscale)return.4}),r&&h(e,t).selectAll(\".\"+l.sankeyNode).filter(g(t)).call(v)}function x(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),i&&h(e,t).selectAll(\".\"+l.sankeyLink).filter(function(t){return t.link.label===i}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),r&&h(e,t).selectAll(l.sankeyNode).filter(g(t)).call(m)}function b(t,e){var r=t.hoverlabel||{},n=s.nestedProperty(r,e).get();return!Array.isArray(n)&&n}e.exports=function(t,e){for(var r=t._fullLayout,s=r._paper,h=r._size,d=0;d<t._fullData.length;d++)if(t._fullData[d].type===l.sankey&&!t._fullData[d]._viewInitial){var g=t._fullData[d].node;t._fullData[d]._viewInitial={node:{groups:g.groups.slice(),x:g.x.slice(),y:g.y.slice()}}}var _=c(t,\"source:\")+\" \",w=c(t,\"target:\")+\" \",k=c(t,\"concentration:\")+\" \",T=c(t,\"incoming flow count:\")+\" \",A=c(t,\"outgoing flow count:\")+\" \";i(t,s,e,{width:h.w,height:h.h,margin:{t:h.t,r:h.r,b:h.b,l:h.l}},{linkEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(y.bind(0,r,i,!0)),\"skip\"!==r.link.trace.link.hoverinfo&&(r.link.fullData=r.link.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.link]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var s=i.link.trace.link;if(\"none\"!==s.hoverinfo&&\"skip\"!==s.hoverinfo){for(var l=[],c=0,h=0;h<i.flow.links.length;h++){var d=i.flow.links[h];if(\"closest\"!==t._fullLayout.hovermode||i.link.pointNumber===d.pointNumber){i.link.pointNumber===d.pointNumber&&(c=h),d.fullData=d.trace,s=i.link.trace.link;var g=m(d),v={valueLabel:n.format(i.valueFormat)(d.value)+i.valueSuffix};l.push({x:g[0],y:g[1],name:v.valueLabel,text:[d.label||\"\",_+d.source.label,w+d.target.label,d.concentrationscale?k+n.format(\"%0.2f\")(d.flow.labelConcentration):\"\"].filter(u).join(\"<br>\"),color:b(s,\"bgcolor\")||o.addOpacity(d.color,1),borderColor:b(s,\"bordercolor\"),fontFamily:b(s,\"font.family\"),fontSize:b(s,\"font.size\"),fontColor:b(s,\"font.color\"),nameLength:b(s,\"namelength\"),textAlign:b(s,\"align\"),idealAlign:n.event.x<g[0]?\"right\":\"left\",hovertemplate:s.hovertemplate,hovertemplateLabels:v,eventData:[d]})}}a.loneHover(l,{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t,anchorIndex:c}).each(function(){i.link.concentrationscale||f(this,.65),p(this)})}}function m(t){var e,r;return t.circular?(e=(t.circularPathData.leftInnerExtent+t.circularPathData.rightInnerExtent)/2+i.parent.translateX,r=t.circularPathData.verticalFullExtent+i.parent.translateY):(e=(t.source.x1+t.target.x0)/2+i.parent.translateX,r=(t.y0+t.y1)/2+i.parent.translateY),[e,r]}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(x.bind(0,i,o,!0)),\"skip\"!==i.link.trace.link.hoverinfo&&(i.link.fullData=i.link.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.link]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r){var i=r.link;i.originalEvent=n.event,t._hoverdata=[i],a.click(t,{target:!0})}},nodeEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(v,r,i),\"skip\"!==r.node.trace.node.hoverinfo&&(r.node.fullData=r.node.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.node]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var o=i.node.trace.node;if(\"none\"!==o.hoverinfo&&\"skip\"!==o.hoverinfo){var s=n.select(e).select(\".\"+l.nodeRect),c=t._fullLayout._paperdiv.node().getBoundingClientRect(),h=s.node().getBoundingClientRect(),d=h.left-2-c.left,g=h.right+2-c.left,v=h.top+h.height/4-c.top,m={valueLabel:n.format(i.valueFormat)(i.node.value)+i.valueSuffix};i.node.fullData=i.node.trace;var y=a.loneHover({x0:d,x1:g,y:v,name:n.format(i.valueFormat)(i.node.value)+i.valueSuffix,text:[i.node.label,T+i.node.targetLinks.length,A+i.node.sourceLinks.length].filter(u).join(\"<br>\"),color:b(o,\"bgcolor\")||i.tinyColorHue,borderColor:b(o,\"bordercolor\"),fontFamily:b(o,\"font.family\"),fontSize:b(o,\"font.size\"),fontColor:b(o,\"font.color\"),nameLength:b(o,\"namelength\"),textAlign:b(o,\"align\"),idealAlign:\"left\",hovertemplate:o.hovertemplate,hovertemplateLabels:m,eventData:[i.node]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t});f(y,.85),p(y)}}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(m,i,o),\"skip\"!==i.node.trace.node.hoverinfo&&(i.node.fullData=i.node.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.node]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r,i){var o=r.node;o.originalEvent=n.event,t._hoverdata=[o],n.select(e).call(m,r,i),a.click(t,{target:!0})}}})}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"./constants\":1105,\"./render\":1109,d3:163}],1109:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"tinycolor2\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"@plotly/d3-sankey\"),c=t(\"@plotly/d3-sankey-circular\"),u=t(\"d3-force\"),h=t(\"../../lib\"),f=t(\"../../lib/gup\"),p=f.keyFun,d=f.repeat,g=f.unwrap,v=t(\"d3-interpolate\").interpolateNumber,m=t(\"../../registry\");function y(){var t=.5;return function(e){if(e.link.circular)return r=e.link,n=r.width/2,i=r.circularPathData,\"top\"===r.circularLinkType?\"M \"+i.targetX+\" \"+(i.targetY+n)+\" L\"+i.rightInnerExtent+\" \"+(i.targetY+n)+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightSmallArcRadius+n)+\" 0 0 1 \"+(i.rightFullExtent-n)+\" \"+(i.targetY-i.rightSmallArcRadius)+\"L\"+(i.rightFullExtent-n)+\" \"+i.verticalRightInnerExtent+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightLargeArcRadius+n)+\" 0 0 1 \"+i.rightInnerExtent+\" \"+(i.verticalFullExtent-n)+\"L\"+i.leftInnerExtent+\" \"+(i.verticalFullExtent-n)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftLargeArcRadius+n)+\" 0 0 1 \"+(i.leftFullExtent+n)+\" \"+i.verticalLeftInnerExtent+\"L\"+(i.leftFullExtent+n)+\" \"+(i.sourceY-i.leftSmallArcRadius)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftSmallArcRadius+n)+\" 0 0 1 \"+i.leftInnerExtent+\" \"+(i.sourceY+n)+\"L\"+i.sourceX+\" \"+(i.sourceY+n)+\"L\"+i.sourceX+\" \"+(i.sourceY-n)+\"L\"+i.leftInnerExtent+\" \"+(i.sourceY-n)+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftSmallArcRadius-n)+\" 0 0 0 \"+(i.leftFullExtent-n)+\" \"+(i.sourceY-i.leftSmallArcRadius)+\"L\"+(i.leftFullExtent-n)+\" \"+i.verticalLeftInnerExtent+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftLargeArcRadius-n)+\" 0 0 0 \"+i.leftInnerExtent+\" \"+(i.verticalFullExtent+n)+\"L\"+i.rightInnerExtent+\" \"+(i.verticalFullExtent+n)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightLargeArcRadius-n)+\" 0 0 0 \"+(i.rightFullExtent+n)+\" \"+i.verticalRightInnerExtent+\"L\"+(i.rightFullExtent+n)+\" \"+(i.targetY-i.rightSmallArcRadius)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightSmallArcRadius-n)+\" 0 0 0 \"+i.rightInnerExtent+\" \"+(i.targetY-n)+\"L\"+i.targetX+\" \"+(i.targetY-n)+\"Z\":\"M \"+i.targetX+\" \"+(i.targetY-n)+\" L\"+i.rightInnerExtent+\" \"+(i.targetY-n)+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightSmallArcRadius+n)+\" 0 0 0 \"+(i.rightFullExtent-n)+\" \"+(i.targetY+i.rightSmallArcRadius)+\"L\"+(i.rightFullExtent-n)+\" \"+i.verticalRightInnerExtent+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightLargeArcRadius+n)+\" 0 0 0 \"+i.rightInnerExtent+\" \"+(i.verticalFullExtent+n)+\"L\"+i.leftInnerExtent+\" \"+(i.verticalFullExtent+n)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftLargeArcRadius+n)+\" 0 0 0 \"+(i.leftFullExtent+n)+\" \"+i.verticalLeftInnerExtent+\"L\"+(i.leftFullExtent+n)+\" \"+(i.sourceY+i.leftSmallArcRadius)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftSmallArcRadius+n)+\" 0 0 0 \"+i.leftInnerExtent+\" \"+(i.sourceY-n)+\"L\"+i.sourceX+\" \"+(i.sourceY-n)+\"L\"+i.sourceX+\" \"+(i.sourceY+n)+\"L\"+i.leftInnerExtent+\" \"+(i.sourceY+n)+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftSmallArcRadius-n)+\" 0 0 1 \"+(i.leftFullExtent-n)+\" \"+(i.sourceY+i.leftSmallArcRadius)+\"L\"+(i.leftFullExtent-n)+\" \"+i.verticalLeftInnerExtent+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftLargeArcRadius-n)+\" 0 0 1 \"+i.leftInnerExtent+\" \"+(i.verticalFullExtent-n)+\"L\"+i.rightInnerExtent+\" \"+(i.verticalFullExtent-n)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightLargeArcRadius-n)+\" 0 0 1 \"+(i.rightFullExtent+n)+\" \"+i.verticalRightInnerExtent+\"L\"+(i.rightFullExtent+n)+\" \"+(i.targetY+i.rightSmallArcRadius)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightSmallArcRadius-n)+\" 0 0 1 \"+i.rightInnerExtent+\" \"+(i.targetY+n)+\"L\"+i.targetX+\" \"+(i.targetY+n)+\"Z\";var r,n,i,a=e.link.source.x1,o=e.link.target.x0,s=v(a,o),l=s(t),c=s(1-t),u=e.link.y0-e.link.width/2,h=e.link.y0+e.link.width/2,f=e.link.y1-e.link.width/2,p=e.link.y1+e.link.width/2;return\"M\"+a+\",\"+u+\"C\"+l+\",\"+u+\" \"+c+\",\"+f+\" \"+o+\",\"+f+\"L\"+o+\",\"+p+\"C\"+c+\",\"+p+\" \"+l+\",\"+h+\" \"+a+\",\"+h+\"Z\"}}function x(t){t.attr(\"transform\",function(t){return\"translate(\"+t.node.x0.toFixed(3)+\", \"+t.node.y0.toFixed(3)+\")\"})}function b(t){t.call(x)}function _(t,e){t.call(b),e.attr(\"d\",y())}function w(t){t.attr(\"width\",function(t){return t.node.x1-t.node.x0}).attr(\"height\",function(t){return t.visibleHeight})}function k(t){return t.link.width>1||t.linkLineWidth>0}function T(t){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"+(t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\")}function A(t){return\"translate(\"+(t.horizontal?0:t.labelY)+\" \"+(t.horizontal?t.labelY:0)+\")\"}function M(t){return i.svg.line()([[t.horizontal?t.left?-t.sizeAcross:t.visibleWidth+n.nodeTextOffsetHorizontal:n.nodeTextOffsetHorizontal,0],[t.horizontal?t.left?-n.nodeTextOffsetHorizontal:t.sizeAcross:t.visibleHeight-n.nodeTextOffsetHorizontal,0]])}function S(t){return t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\"}function E(t){return t.horizontal?\"scale(1 1)\":\"scale(-1 1)\"}function C(t){return t.darkBackground&&!t.horizontal?\"rgb(255,255,255)\":\"rgb(0,0,0)\"}function L(t){return t.horizontal&&t.left?\"100%\":\"0%\"}function P(t,e,r){t.on(\".basic\",null).on(\"mouseover.basic\",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.hover(this,t,e),t.interactionState.hovered=[this,t])}).on(\"mousemove.basic\",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.follow(this,t),t.interactionState.hovered=[this,t])}).on(\"mouseout.basic\",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.unhover(this,t,e),t.interactionState.hovered=!1)}).on(\"click.basic\",function(t){t.interactionState.hovered&&(r.unhover(this,t,e),t.interactionState.hovered=!1),t.interactionState.dragInProgress||t.partOfGroup||r.select(this,t,e)})}function O(t,e,r,a){var o=i.behavior.drag().origin(function(t){return{x:t.node.x0+t.visibleWidth/2,y:t.node.y0+t.visibleHeight/2}}).on(\"dragstart\",function(i){if(\"fixed\"!==i.arrangement&&(h.ensureSingle(a._fullLayout._infolayer,\"g\",\"dragcover\",function(t){a._fullLayout._dragCover=t}),h.raiseToTop(this),i.interactionState.dragInProgress=i.node,I(i.node),i.interactionState.hovered&&(r.nodeEvents.unhover.apply(0,i.interactionState.hovered),i.interactionState.hovered=!1),\"snap\"===i.arrangement)){var o=i.traceId+\"|\"+i.key;i.forceLayouts[o]?i.forceLayouts[o].alpha(1):function(t,e,r,i){!function(t){for(var e=0;e<t.length;e++)t[e].y=(t[e].y0+t[e].y1)/2,t[e].x=(t[e].x0+t[e].x1)/2}(r.graph.nodes);var a=r.graph.nodes.filter(function(t){return t.originalX===r.node.originalX}).filter(function(t){return!t.partOfGroup});r.forceLayouts[e]=u.forceSimulation(a).alphaDecay(0).force(\"collide\",u.forceCollide().radius(function(t){return t.dy/2+r.nodePad/2}).strength(1).iterations(n.forceIterations)).force(\"constrain\",function(t,e,r,i){return function(){for(var t=0,a=0;a<r.length;a++){var o=r[a];o===i.interactionState.dragInProgress?(o.x=o.lastDraggedX,o.y=o.lastDraggedY):(o.vx=(o.originalX-o.x)/n.forceTicksPerFrame,o.y=Math.min(i.size-o.dy/2,Math.max(o.dy/2,o.y))),t=Math.max(t,Math.abs(o.vx),Math.abs(o.vy))}!i.interactionState.dragInProgress&&t<.1&&i.forceLayouts[e].alpha()>0&&i.forceLayouts[e].alpha(0)}}(0,e,a,r)).stop()}(0,o,i),function(t,e,r,i,a){window.requestAnimationFrame(function o(){var s;for(s=0;s<n.forceTicksPerFrame;s++)r.forceLayouts[i].tick();var l=r.graph.nodes;if(function(t){for(var e=0;e<t.length;e++)t[e].y0=t[e].y-t[e].dy/2,t[e].y1=t[e].y0+t[e].dy,t[e].x0=t[e].x-t[e].dx/2,t[e].x1=t[e].x0+t[e].dx}(l),r.sankey.update(r.graph),_(t.filter(D(r)),e),r.forceLayouts[i].alpha()>0)window.requestAnimationFrame(o);else{var c=r.node.originalX;r.node.x0=c-r.visibleWidth/2,r.node.x1=c+r.visibleWidth/2,z(r,a)}})}(t,e,i,o,a)}}).on(\"drag\",function(r){if(\"fixed\"!==r.arrangement){var n=i.event.x,a=i.event.y;\"snap\"===r.arrangement?(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2,r.node.y0=a-r.visibleHeight/2,r.node.y1=a+r.visibleHeight/2):(\"freeform\"===r.arrangement&&(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2),a=Math.max(0,Math.min(r.size-r.visibleHeight/2,a)),r.node.y0=a-r.visibleHeight/2,r.node.y1=a+r.visibleHeight/2),I(r.node),\"snap\"!==r.arrangement&&(r.sankey.update(r.graph),_(t.filter(D(r)),e))}}).on(\"dragend\",function(t){if(\"fixed\"!==t.arrangement){t.interactionState.dragInProgress=!1;for(var e=0;e<t.node.childrenNodes.length;e++)t.node.childrenNodes[e].x=t.node.x,t.node.childrenNodes[e].y=t.node.y;\"snap\"!==t.arrangement&&z(t,a)}});t.on(\".drag\",null).call(o)}function z(t,e){for(var r=[],n=[],i=0;i<t.graph.nodes.length;i++){var a=(t.graph.nodes[i].x0+t.graph.nodes[i].x1)/2,o=(t.graph.nodes[i].y0+t.graph.nodes[i].y1)/2;r.push(a/t.figure.width),n.push(o/t.figure.height)}m.call(\"_guiRestyle\",e,{\"node.x\":[r],\"node.y\":[n]},t.trace.index).then(function(){e._fullLayout._dragCover&&e._fullLayout._dragCover.remove()})}function I(t){t.lastDraggedX=t.x0+t.dx/2,t.lastDraggedY=t.y0+t.dy/2}function D(t){return function(e){return e.node.originalX===t.node.originalX}}e.exports=function(t,e,r,u,f){var v=!1;h.ensureSingle(t._fullLayout._infolayer,\"g\",\"first-render\",function(){v=!0});var m=t._fullLayout._dragCover,b=r.filter(function(t){return g(t).trace.visible}).map(function(t,e,r){var i,o=g(e),s=o.trace,u=s.domain,f=\"h\"===s.orientation,p=s.node.pad,d=s.node.thickness,v=t.width*(u.x[1]-u.x[0]),m=t.height*(u.y[1]-u.y[0]),y=o._nodes,x=o._links,b=o.circular;(i=b?c.sankeyCircular().circularLinkGap(0):l.sankey()).iterations(n.sankeyIterations).size(f?[v,m]:[m,v]).nodeWidth(d).nodePadding(p).nodeId(function(t){return t.pointNumber}).nodes(y).links(x);var _,w,k,T=i();for(var A in i.nodePadding()<p&&h.warn(\"node.pad was reduced to \",i.nodePadding(),\" to fit within the figure.\"),o._groupLookup){var M,S=parseInt(o._groupLookup[A]);for(_=0;_<T.nodes.length;_++)if(T.nodes[_].pointNumber===S){M=T.nodes[_];break}if(M){var E={pointNumber:parseInt(A),x0:M.x0,x1:M.x1,y0:M.y0,y1:M.y1,partOfGroup:!0,sourceLinks:[],targetLinks:[]};T.nodes.unshift(E),M.childrenNodes.unshift(E)}}if(function(){for(_=0;_<T.nodes.length;_++){var t,e,r=T.nodes[_],n={};for(w=0;w<r.targetLinks.length;w++)t=(e=r.targetLinks[w]).source.pointNumber+\":\"+e.target.pointNumber,n.hasOwnProperty(t)||(n[t]=[]),n[t].push(e);var i=Object.keys(n);for(w=0;w<i.length;w++){var o=n[t=i[w]],s=0,l={};for(k=0;k<o.length;k++)l[(e=o[k]).label]||(l[e.label]=0),l[e.label]+=e.value,s+=e.value;for(k=0;k<o.length;k++)(e=o[k]).flow={value:s,labelConcentration:l[e.label]/s,concentration:e.value/s,links:o},e.concentrationscale&&(e.color=a(e.concentrationscale(e.flow.labelConcentration)))}var c=0;for(w=0;w<r.sourceLinks.length;w++)c+=r.sourceLinks[w].value;for(w=0;w<r.sourceLinks.length;w++)(e=r.sourceLinks[w]).concentrationOut=e.value/c;var u=0;for(w=0;w<r.targetLinks.length;w++)u+=r.targetLinks[w].value;for(w=0;w<r.targetLinks.length;w++)(e=r.targetLinks[w]).concenrationIn=e.value/u}}(),s.node.x.length&&s.node.y.length){for(_=0;_<Math.min(s.node.x.length,s.node.y.length,T.nodes.length);_++)if(s.node.x[_]&&s.node.y[_]){var C=[s.node.x[_]*v,s.node.y[_]*m];T.nodes[_].x0=C[0]-d/2,T.nodes[_].x1=C[0]+d/2;var L=T.nodes[_].y1-T.nodes[_].y0;T.nodes[_].y0=C[1]-L/2,T.nodes[_].y1=C[1]+L/2}\"snap\"===s.arrangement&&function(t){t.forEach(function(t){var e,r,n,i=0,a=t.length;for(t.sort(function(t,e){return t.y0-e.y0}),n=0;n<a;++n)(e=t[n]).y0>=i||(r=i-e.y0)>1e-6&&(e.y0+=r,e.y1+=r),i=e.y1+p})}(function(t){var e,r,n=t.map(function(t,e){return{x0:t.x0,index:e}}).sort(function(t,e){return t.x0-e.x0}),i=[],a=-1,o=-1/0;for(_=0;_<n.length;_++){var s=t[n[_].index];s.x0>o+d&&(a+=1,e=s.x0),o=s.x0,i[a]||(i[a]=[]),i[a].push(s),r=e-s.x0,s.x0+=r,s.x1+=r}return i}(y=T.nodes)),i.update(T)}return{circular:b,key:r,trace:s,guid:h.randstr(),horizontal:f,width:v,height:m,nodePad:s.node.pad,nodeLineColor:s.node.line.color,nodeLineWidth:s.node.line.width,linkLineColor:s.link.line.color,linkLineWidth:s.link.line.width,valueFormat:s.valueformat,valueSuffix:s.valuesuffix,textFont:s.textfont,translateX:u.x[0]*t.width+t.margin.l,translateY:t.height-u.y[1]*t.height+t.margin.t,dragParallel:f?m:v,dragPerpendicular:f?v:m,arrangement:s.arrangement,sankey:i,graph:T,forceLayouts:{},interactionState:{dragInProgress:!1,hovered:!1}}}.bind(null,u)),_=e.selectAll(\".\"+n.cn.sankey).data(b,p);_.exit().remove(),_.enter().append(\"g\").classed(n.cn.sankey,!0).style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"shape-rendering\",\"geometricPrecision\").style(\"pointer-events\",\"auto\").attr(\"transform\",T),_.each(function(e,r){t._fullData[r]._sankey=e;var n=\"bgsankey-\"+e.trace.uid+\"-\"+r;h.ensureSingle(t._fullLayout._draggers,\"rect\",n),t._fullData[r]._bgRect=i.select(\".\"+n),t._fullData[r]._bgRect.style(\"pointer-events\",\"all\").attr(\"width\",e.width).attr(\"height\",e.height).attr(\"x\",e.translateX).attr(\"y\",e.translateY).classed(\"bgsankey\",!0).style({fill:\"transparent\",\"stroke-width\":0})}),_.transition().ease(n.ease).duration(n.duration).attr(\"transform\",T);var z=_.selectAll(\".\"+n.cn.sankeyLinks).data(d,p);z.enter().append(\"g\").classed(n.cn.sankeyLinks,!0).style(\"fill\",\"none\");var I=z.selectAll(\".\"+n.cn.sankeyLink).data(function(t){return t.graph.links.filter(function(t){return t.value}).map(function(t,e,r){var n=a(e.color),i=e.source.label+\"|\"+e.target.label+\"__\"+r;return e.trace=t.trace,e.curveNumber=t.trace.index,{circular:t.circular,key:i,traceId:t.key,pointNumber:e.pointNumber,link:e,tinyColorHue:o.tinyRGB(n),tinyColorAlpha:n.getAlpha(),linkPath:y,linkLineColor:t.linkLineColor,linkLineWidth:t.linkLineWidth,valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,parent:t,interactionState:t.interactionState,flow:e.flow}}.bind(null,t))},p);I.enter().append(\"path\").classed(n.cn.sankeyLink,!0).call(P,_,f.linkEvents),I.style(\"stroke\",function(t){return k(t)?o.tinyRGB(a(t.linkLineColor)):t.tinyColorHue}).style(\"stroke-opacity\",function(t){return k(t)?o.opacity(t.linkLineColor):t.tinyColorAlpha}).style(\"fill\",function(t){return t.tinyColorHue}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}).style(\"stroke-width\",function(t){return k(t)?t.linkLineWidth:1}).attr(\"d\",y()),I.style(\"opacity\",function(){return t._context.staticPlot||v||m?1:0}).transition().ease(n.ease).duration(n.duration).style(\"opacity\",1),I.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var D=_.selectAll(\".\"+n.cn.sankeyNodeSet).data(d,p);D.enter().append(\"g\").classed(n.cn.sankeyNodeSet,!0),D.style(\"cursor\",function(t){switch(t.arrangement){case\"fixed\":return\"default\";case\"perpendicular\":return\"ns-resize\";default:return\"move\"}});var R=D.selectAll(\".\"+n.cn.sankeyNode).data(function(t){var e=t.graph.nodes;return function(t){var e,r=[];for(e=0;e<t.length;e++)t[e].originalX=(t[e].x0+t[e].x1)/2,t[e].originalY=(t[e].y0+t[e].y1)/2,-1===r.indexOf(t[e].originalX)&&r.push(t[e].originalX);for(r.sort(function(t,e){return t-e}),e=0;e<t.length;e++)t[e].originalLayerIndex=r.indexOf(t[e].originalX),t[e].originalLayer=t[e].originalLayerIndex/(r.length-1)}(e),e.map(function(t,e){var r=a(e.color),i=n.nodePadAcross,s=t.nodePad/2;e.dx=e.x1-e.x0,e.dy=e.y1-e.y0;var l=e.dx,c=Math.max(.5,e.dy),u=\"node_\"+e.pointNumber;return e.group&&(u=h.randstr()),e.trace=t.trace,e.curveNumber=t.trace.index,{index:e.pointNumber,key:u,partOfGroup:e.partOfGroup||!1,group:e.group,traceId:t.key,trace:t.trace,node:e,nodePad:t.nodePad,nodeLineColor:t.nodeLineColor,nodeLineWidth:t.nodeLineWidth,textFont:t.textFont,size:t.horizontal?t.height:t.width,visibleWidth:Math.ceil(l),visibleHeight:c,zoneX:-i,zoneY:-s,zoneWidth:l+2*i,zoneHeight:c+2*s,labelY:t.horizontal?e.dy/2+1:e.dx/2+1,left:1===e.originalLayer,sizeAcross:t.width,forceLayouts:t.forceLayouts,horizontal:t.horizontal,darkBackground:r.getBrightness()<=128,tinyColorHue:o.tinyRGB(r),tinyColorAlpha:r.getAlpha(),valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,graph:t.graph,arrangement:t.arrangement,uniqueNodeLabelPathId:[t.guid,t.key,u].join(\"_\"),interactionState:t.interactionState,figure:t}}.bind(null,t))},p);R.enter().append(\"g\").classed(n.cn.sankeyNode,!0).call(x).style(\"opacity\",function(e){return!t._context.staticPlot&&!v||e.partOfGroup?0:1}),R.call(P,_,f.nodeEvents).call(O,I,f,t),R.transition().ease(n.ease).duration(n.duration).call(x).style(\"opacity\",function(t){return t.partOfGroup?0:1}),R.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var F=R.selectAll(\".\"+n.cn.nodeRect).data(d);F.enter().append(\"rect\").classed(n.cn.nodeRect,!0).call(w),F.style(\"stroke-width\",function(t){return t.nodeLineWidth}).style(\"stroke\",function(t){return o.tinyRGB(a(t.nodeLineColor))}).style(\"stroke-opacity\",function(t){return o.opacity(t.nodeLineColor)}).style(\"fill\",function(t){return t.tinyColorHue}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),F.transition().ease(n.ease).duration(n.duration).call(w);var B=R.selectAll(\".\"+n.cn.nodeCapture).data(d);B.enter().append(\"rect\").classed(n.cn.nodeCapture,!0).style(\"fill-opacity\",0),B.attr(\"x\",function(t){return t.zoneX}).attr(\"y\",function(t){return t.zoneY}).attr(\"width\",function(t){return t.zoneWidth}).attr(\"height\",function(t){return t.zoneHeight});var N=R.selectAll(\".\"+n.cn.nodeCentered).data(d);N.enter().append(\"g\").classed(n.cn.nodeCentered,!0).attr(\"transform\",A),N.transition().ease(n.ease).duration(n.duration).attr(\"transform\",A);var j=N.selectAll(\".\"+n.cn.nodeLabelGuide).data(d);j.enter().append(\"path\").classed(n.cn.nodeLabelGuide,!0).attr(\"id\",function(t){return t.uniqueNodeLabelPathId}).attr(\"d\",M).attr(\"transform\",S),j.transition().ease(n.ease).duration(n.duration).attr(\"d\",M).attr(\"transform\",S);var U=N.selectAll(\".\"+n.cn.nodeLabel).data(d);U.enter().append(\"text\").classed(n.cn.nodeLabel,!0).attr(\"transform\",E).style(\"user-select\",\"none\").style(\"cursor\",\"default\").style(\"fill\",\"black\"),U.style(\"text-shadow\",function(t){return t.horizontal?\"-1px 1px 1px #fff, 1px 1px 1px #fff, 1px -1px 1px #fff, -1px -1px 1px #fff\":\"none\"}).each(function(t){s.font(U,t.textFont)}),U.transition().ease(n.ease).duration(n.duration).attr(\"transform\",E);var V=U.selectAll(\".\"+n.cn.nodeLabelTextPath).data(d);V.enter().append(\"textPath\").classed(n.cn.nodeLabelTextPath,!0).attr(\"alignment-baseline\",\"middle\").attr(\"xlink:href\",function(t){return\"#\"+t.uniqueNodeLabelPathId}).attr(\"startOffset\",L).style(\"fill\",C),V.text(function(t){return t.horizontal||t.node.dy>5?t.node.label:\"\"}).attr(\"text-anchor\",function(t){return t.horizontal&&t.left?\"end\":\"start\"}),V.transition().ease(n.ease).duration(n.duration).attr(\"startOffset\",L).style(\"fill\",C)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/gup\":717,\"../../registry\":847,\"./constants\":1105,\"@plotly/d3-sankey\":54,\"@plotly/d3-sankey-circular\":53,d3:163,\"d3-force\":156,\"d3-interpolate\":158,tinycolor2:537}],1110:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=[],n=t.cd[0].trace,i=n._sankey.graph.nodes,a=0;a<i.length;a++){var o=i[a];if(!o.partOfGroup){var s=[(o.x0+o.x1)/2,(o.y0+o.y1)/2];\"v\"===n.orientation&&s.reverse(),e&&e.contains(s,!1,a,t)&&r.push({pointNumber:o.pointNumber})}}return r}},{}],1111:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\"),n.mergeArray(e.customdata,t,\"data\"),n.mergeArray(e.textposition,t,\"tp\"),e.textfont&&(n.mergeArrayCastPositive(e.textfont.size,t,\"ts\"),n.mergeArray(e.textfont.color,t,\"tc\"),n.mergeArray(e.textfont.family,t,\"tf\"));var i=e.marker;if(i){n.mergeArrayCastPositive(i.size,t,\"ms\"),n.mergeArrayCastPositive(i.opacity,t,\"mo\"),n.mergeArray(i.symbol,t,\"mx\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;i.line&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"));var o=i.gradient;o&&\"none\"!==o.type&&(n.mergeArray(o.type,t,\"mgt\"),n.mergeArray(o.color,t,\"mgc\"))}}},{\"../../lib\":719}],1112:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../components/drawing/attributes\").dash,s=t(\"../../components/drawing\"),l=t(\"./constants\"),c=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},x0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dx:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},y0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dy:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},stackgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc\"},groupnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},stackgaps:{valType:\"enumerated\",values:[\"infer zero\",\"interpolate\"],dflt:\"infer zero\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"],editType:\"calc\"},hoveron:{valType:\"flaglist\",flags:[\"points\",\"fills\"],editType:\"style\"},hovertemplate:n({},{keys:l.eventDataKeys}),line:{color:{valType:\"color\",editType:\"style\",anim:!0},width:{valType:\"number\",min:0,dflt:2,editType:\"style\",anim:!0},shape:{valType:\"enumerated\",values:[\"linear\",\"spline\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},smoothing:{valType:\"number\",min:0,max:1.3,dflt:1,editType:\"plot\"},dash:c({},o,{editType:\"style\"}),simplify:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cliponaxis:{valType:\"boolean\",dflt:!0,editType:\"plot\"},fill:{valType:\"enumerated\",values:[\"none\",\"tozeroy\",\"tozerox\",\"tonexty\",\"tonextx\",\"toself\",\"tonext\"],editType:\"calc\"},fillcolor:{valType:\"color\",editType:\"style\",anim:!0},marker:c({symbol:{valType:\"enumerated\",values:s.symbolList,dflt:\"circle\",arrayOk:!0,editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,arrayOk:!0,editType:\"style\",anim:!0},size:{valType:\"number\",min:0,dflt:6,arrayOk:!0,editType:\"calc\",anim:!0},maxdisplayed:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},sizeref:{valType:\"number\",dflt:1,editType:\"calc\"},sizemin:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"diameter\",\"area\"],dflt:\"diameter\",editType:\"calc\"},line:c({width:{valType:\"number\",min:0,arrayOk:!0,editType:\"style\",anim:!0},editType:\"calc\"},i(\"marker.line\",{anim:!0})),gradient:{type:{valType:\"enumerated\",values:[\"radial\",\"horizontal\",\"vertical\",\"none\"],arrayOk:!0,dflt:\"none\",editType:\"calc\"},color:{valType:\"color\",arrayOk:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},i(\"marker\",{anim:!0})),selected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},unselected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\"],dflt:\"middle center\",arrayOk:!0,editType:\"calc\"},textfont:a({editType:\"calc\",colorEditType:\"style\",arrayOk:!0}),r:{valType:\"data_array\",editType:\"calc\"},t:{valType:\"data_array\",editType:\"calc\"}}},{\"../../components/colorscale/attributes\":600,\"../../components/drawing\":614,\"../../components/drawing/attributes\":613,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"./constants\":1116}],1113:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/numerical\").BADNUM,s=t(\"./subtypes\"),l=t(\"./colorscale_calc\"),c=t(\"./arrays_to_calcdata\"),u=t(\"./calc_selection\");function h(t,e,r,n,i,o,l){var c=e._length,u=t._fullLayout,h=r._id,f=n._id,p=u._firstScatter[d(e)]===e.uid,v=(g(e,u,r,n)||{}).orientation,m=e.fill;r._minDtick=0,n._minDtick=0;var y={padded:!0},x={padded:!0};l&&(y.ppad=x.ppad=l);var b=c<2||i[0]!==i[c-1]||o[0]!==o[c-1];b&&(\"tozerox\"===m||\"tonextx\"===m&&(p||\"h\"===v))?y.tozero=!0:(e.error_y||{}).visible||\"tonexty\"!==m&&\"tozeroy\"!==m&&(s.hasMarkers(e)||s.hasText(e))||(y.padded=!1,y.ppad=0),b&&(\"tozeroy\"===m||\"tonexty\"===m&&(p||\"v\"===v))?x.tozero=!0:\"tonextx\"!==m&&\"tozerox\"!==m||(x.padded=!1),h&&(e._extremes[h]=a.findExtremes(r,i,y)),f&&(e._extremes[f]=a.findExtremes(n,o,x))}function f(t,e){if(s.hasMarkers(t)){var r,n=t.marker,o=1.6*(t.marker.sizeref||1);if(r=\"area\"===t.marker.sizemode?function(t){return Math.max(Math.sqrt((t||0)/o),3)}:function(t){return Math.max((t||0)/o,3)},i.isArrayOrTypedArray(n.size)){var l={type:\"linear\"};a.setConvert(l);for(var c=l.makeCalcdata(t.marker,\"size\"),u=new Array(e),h=0;h<e;h++)u[h]=r(c[h]);return u}return r(n.size)}}function p(t,e){var r=d(e),n=t._firstScatter;n[r]||(n[r]=e.uid)}function d(t){var e=t.stackgroup;return t.xaxis+t.yaxis+t.type+(e?\"-\"+e:\"\")}function g(t,e,r,n){var i=t.stackgroup;if(i){var a=e._scatterStackOpts[r._id+n._id][i],o=\"v\"===a.orientation?n:r;return\"linear\"===o.type||\"log\"===o.type?a:void 0}}e.exports={calc:function(t,e){var r,s,d,v,m,y,x=t._fullLayout,b=a.getFromId(t,e.xaxis||\"x\"),_=a.getFromId(t,e.yaxis||\"y\"),w=b.makeCalcdata(e,\"x\"),k=_.makeCalcdata(e,\"y\"),T=e._length,A=new Array(T),M=e.ids,S=g(e,x,b,_),E=!1;p(x,e);var C,L=\"x\",P=\"y\";for(S?(i.pushUnique(S.traceIndices,e._expandedIndex),(r=\"v\"===S.orientation)?(P=\"s\",C=\"x\"):(L=\"s\",C=\"y\"),m=\"interpolate\"===S.stackgaps):h(t,e,b,_,w,k,f(e,T)),s=0;s<T;s++){var O=A[s]={},z=n(w[s]),I=n(k[s]);z&&I?(O[L]=w[s],O[P]=k[s]):S&&(r?z:I)?(O[C]=r?w[s]:k[s],O.gap=!0,m?(O.s=o,E=!0):O.s=0):O[L]=O[P]=o,M&&(O.id=String(M[s]))}if(c(A,e),l(t,e),u(A,e),S){for(s=0;s<A.length;)A[s][C]===o?A.splice(s,1):s++;if(i.sort(A,function(t,e){return t[C]-e[C]||t.i-e.i}),E){for(s=0;s<A.length-1&&A[s].gap;)s++;for((y=A[s].s)||(y=A[s].s=0),d=0;d<s;d++)A[d].s=y;for(v=A.length-1;v>s&&A[v].gap;)v--;for(y=A[v].s,d=A.length-1;d>v;d--)A[d].s=y;for(;s<v;)if(A[++s].gap){for(d=s+1;A[d].gap;)d++;for(var D=A[s-1][C],R=A[s-1].s,F=(A[d].s-R)/(A[d][C]-D);s<d;)A[s].s=R+(A[s][C]-D)*F,s++}}}return A},calcMarkerSize:f,calcAxisExpansion:h,setFirstScatter:p,getStackOpts:g}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./arrays_to_calcdata\":1111,\"./calc_selection\":1114,\"./colorscale_calc\":1115,\"./subtypes\":1135,\"fast-isnumeric\":225}],1114:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){n.isArrayOrTypedArray(e.selectedpoints)&&n.tagSelected(t,e)}},{\"../../lib\":719}],1115:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"./subtypes\");e.exports=function(t,e){a.hasLines(e)&&n(e,\"line\")&&i(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),a.hasMarkers(e)&&(n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}))}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"./subtypes\":1135}],1116:[function(t,e,r){\"use strict\";e.exports={PTS_LINESONLY:20,minTolerance:.2,toleranceGrowth:10,maxScreensAway:20,eventDataKeys:[]}},{}],1117:[function(t,e,r){\"use strict\";var n=t(\"./calc\");function i(t,e,r,n,i,a,o){i[n]=!0;var s={i:null,gap:!0,s:0};if(s[o]=r,t.splice(e,0,s),e&&r===t[e-1][o]){var l=t[e-1];s.s=l.s,s.i=l.i,s.gap=l.gap}else a&&(s.s=function(t,e,r,n){var i=t[e-1],a=t[e+1];return a?i?i.s+(a.s-i.s)*(r-i[n])/(a[n]-i[n]):a.s:i.s}(t,e,r,o));e||(t[0].t=t[1].t,t[0].trace=t[1].trace,delete t[1].t,delete t[1].trace)}e.exports=function(t,e){var r=e.xaxis,a=e.yaxis,o=r._id+a._id,s=t._fullLayout._scatterStackOpts[o];if(s){var l,c,u,h,f,p,d,g,v,m,y,x,b,_,w,k=t.calcdata;for(var T in s){var A=(m=s[T]).traceIndices;if(A.length){for(y=\"interpolate\"===m.stackgaps,x=m.groupnorm,\"v\"===m.orientation?(b=\"x\",_=\"y\"):(b=\"y\",_=\"x\"),w=new Array(A.length),l=0;l<w.length;l++)w[l]=!1;p=k[A[0]];var M=new Array(p.length);for(l=0;l<p.length;l++)M[l]=p[l][b];for(l=1;l<A.length;l++){for(f=k[A[l]],c=u=0;c<f.length;c++){for(d=f[c][b];d>M[u]&&u<M.length;u++)i(f,c,M[u],l,w,y,b),c++;if(d!==M[u]){for(h=0;h<l;h++)i(k[A[h]],u,d,h,w,y,b);M.splice(u,0,d)}u++}for(;u<M.length;u++)i(f,c,M[u],l,w,y,b),c++}var S=M.length;for(c=0;c<p.length;c++){for(g=p[c][_]=p[c].s,l=1;l<A.length;l++)(f=k[A[l]])[0].trace._rawLength=f[0].trace._length,f[0].trace._length=S,g+=f[c].s,f[c][_]=g;if(x)for(v=(\"fraction\"===x?g:g/100)||1,l=0;l<A.length;l++){var E=k[A[l]][c];E[_]/=v,E.sNorm=E.s/v}}for(l=0;l<A.length;l++){var C=(f=k[A[l]])[0].trace,L=n.calcMarkerSize(C,C._rawLength),P=Array.isArray(L);if(L&&w[l]||P){var O=L;for(L=new Array(S),c=0;c<S;c++)L[c]=f[c].gap?0:P?O[f[c].i]:O}var z=new Array(S),I=new Array(S);for(c=0;c<S;c++)z[c]=f[c].x,I[c]=f[c].y;n.calcAxisExpansion(t,C,r,a,z,I,L),f[0].t.orientation=m.orientation}}}}}},{\"./calc\":1113}],1118:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0;e<t.length;e++){var r=t[e];if(\"scatter\"===r.type){var n=r.fill;if(\"none\"!==n&&\"toself\"!==n&&(r.opacity=void 0,\"tonexty\"===n||\"tonextx\"===n))for(var i=e-1;i>=0;i--){var a=t[i];if(\"scatter\"===a.type&&a.xaxis===r.xaxis&&a.yaxis===r.yaxis){a.opacity=void 0;break}}}}}},{}],1119:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"./constants\"),s=t(\"./subtypes\"),l=t(\"./xy_defaults\"),c=t(\"./stack_defaults\"),u=t(\"./marker_defaults\"),h=t(\"./line_defaults\"),f=t(\"./line_shape_defaults\"),p=t(\"./text_defaults\"),d=t(\"./fillcolor_defaults\");e.exports=function(t,e,r,g){function v(r,i){return n.coerce(t,e,a,r,i)}var m=l(t,e,g,v);if(m||(e.visible=!1),e.visible){var y=c(t,e,g,v),x=!y&&m<o.PTS_LINESONLY?\"lines+markers\":\"lines\";v(\"text\"),v(\"hovertext\"),v(\"mode\",x),s.hasLines(e)&&(h(t,e,r,g,v),f(t,e,v),v(\"connectgaps\"),v(\"line.simplify\")),s.hasMarkers(e)&&u(t,e,r,g,v,{gradient:!0}),s.hasText(e)&&p(t,e,g,v);var b=[];(s.hasMarkers(e)||s.hasText(e))&&(v(\"cliponaxis\"),v(\"marker.maxdisplayed\"),b.push(\"points\")),v(\"fill\",y?y.fillDflt:\"none\"),\"none\"!==e.fill&&(d(t,e,r,v),s.hasLines(e)||f(t,e,v));var _=(e.line||{}).color,w=(e.marker||{}).color;\"tonext\"!==e.fill&&\"toself\"!==e.fill||b.push(\"fills\"),v(\"hoveron\",b.join(\"+\")||\"points\"),\"fills\"!==e.hoveron&&v(\"hovertemplate\");var k=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");k(t,e,_||w||r,{axis:\"y\"}),k(t,e,_||w||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,v)}}},{\"../../lib\":719,\"../../registry\":847,\"./attributes\":1112,\"./constants\":1116,\"./fillcolor_defaults\":1120,\"./line_defaults\":1124,\"./line_shape_defaults\":1126,\"./marker_defaults\":1130,\"./stack_defaults\":1133,\"./subtypes\":1135,\"./text_defaults\":1136,\"./xy_defaults\":1137}],1120:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a){var o=!1;if(e.marker){var s=e.marker.color,l=(e.marker.line||{}).color;s&&!i(s)?o=s:l&&!i(l)&&(o=l)}a(\"fillcolor\",n.addOpacity((e.line||{}).color||o||r,.5))}},{\"../../components/color\":593,\"../../lib\":719}],1121:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./subtypes\");e.exports=function(t,e){var r,a;if(\"lines\"===t.mode)return(r=t.line.color)&&n.opacity(r)?r:t.fillcolor;if(\"none\"===t.mode)return t.fill?t.fillcolor:\"\";var o=e.mcc||(t.marker||{}).color,s=e.mlcc||((t.marker||{}).line||{}).color;return(a=o&&n.opacity(o)?o:s&&n.opacity(s)&&(e.mlw||((t.marker||{}).line||{}).width)?s:\"\")?n.opacity(a)<.3?n.addOpacity(a,.3):a:(r=(t.line||{}).color)&&n.opacity(r)&&i.hasLines(t)&&t.line.width?r:t.fillcolor}},{\"../../components/color\":593,\"./subtypes\":1135}],1122:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/fx\"),a=t(\"../../registry\"),o=t(\"./get_trace_color\"),s=t(\"../../components/color\"),l=n.fillText;e.exports=function(t,e,r,c){var u=t.cd,h=u[0].trace,f=t.xa,p=t.ya,d=f.c2p(e),g=p.c2p(r),v=[d,g],m=h.hoveron||\"\",y=-1!==h.mode.indexOf(\"markers\")?3:.5;if(-1!==m.indexOf(\"points\")){var x=function(t){var e=Math.max(y,t.mrc||0),r=f.c2p(t.x)-d,n=p.c2p(t.y)-g;return Math.max(Math.sqrt(r*r+n*n)-e,1-y/e)},b=i.getDistanceFunction(c,function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(f.c2p(t.x)-d);return n<e?r*n/e:n-e+r},function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(p.c2p(t.y)-g);return n<e?r*n/e:n-e+r},x);if(i.getClosest(u,b,t),!1!==t.index){var _=u[t.index],w=f.c2p(_.x,!0),k=p.c2p(_.y,!0),T=_.mrc||1;t.index=_.i;var A=u[0].t.orientation,M=A&&(_.sNorm||_.s),S=\"h\"===A?M:_.x,E=\"v\"===A?M:_.y;return n.extendFlat(t,{color:o(h,_),x0:w-T,x1:w+T,xLabelVal:S,y0:k-T,y1:k+T,yLabelVal:E,spikeDistance:x(_),hovertemplate:h.hovertemplate}),l(_,h,t),a.getComponentMethod(\"errorbars\",\"hoverInfo\")(_,h,t),[t]}}if(-1!==m.indexOf(\"fills\")&&h._polygons){var C,L,P,O,z,I,D,R,F,B=h._polygons,N=[],j=!1,U=1/0,V=-1/0,q=1/0,H=-1/0;for(C=0;C<B.length;C++)(P=B[C]).contains(v)&&(j=!j,N.push(P),q=Math.min(q,P.ymin),H=Math.max(H,P.ymax));if(j){var G=((q=Math.max(q,0))+(H=Math.min(H,p._length)))/2;for(C=0;C<N.length;C++)for(O=N[C].pts,L=1;L<O.length;L++)(R=O[L-1][1])>G!=(F=O[L][1])>=G&&(I=O[L-1][0],D=O[L][0],F-R&&(z=I+(D-I)*(G-R)/(F-R),U=Math.min(U,z),V=Math.max(V,z)));U=Math.max(U,0),V=Math.min(V,f._length);var Y=s.defaultLine;return s.opacity(h.fillcolor)?Y=h.fillcolor:s.opacity((h.line||{}).color)&&(Y=h.line.color),n.extendFlat(t,{distance:t.maxHoverDistance,x0:U,x1:V,y0:G,y1:G,color:Y,hovertemplate:!1}),delete t.index,h.text&&!Array.isArray(h.text)?t.text=String(h.text):t.text=h.name,[t]}}}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"../../registry\":847,\"./get_trace_color\":1121}],1123:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports={hasLines:n.hasLines,hasMarkers:n.hasMarkers,hasText:n.hasText,isBubble:n.isBubble,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./cross_trace_calc\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\"),colorbar:t(\"./marker_colorbar\"),style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"./select\"),animatable:!0,moduleType:\"trace\",name:\"scatter\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"./arrays_to_calcdata\":1111,\"./attributes\":1112,\"./calc\":1113,\"./cross_trace_calc\":1117,\"./cross_trace_defaults\":1118,\"./defaults\":1119,\"./hover\":1122,\"./marker_colorbar\":1129,\"./plot\":1131,\"./select\":1132,\"./style\":1134,\"./subtypes\":1135}],1124:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s,l){var c=(t.marker||{}).color;(s(\"line.color\",r),i(t,\"line\"))?a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}):s(\"line.color\",!n(c)&&c||r);s(\"line.width\"),(l||{}).noDash||s(\"line.dash\")}},{\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"../../lib\":719}],1125:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.BADNUM,a=n.LOG_CLIP,o=a+.5,s=a-.5,l=t(\"../../lib\"),c=l.segmentsIntersect,u=l.constrain,h=t(\"./constants\");e.exports=function(t,e){var r,n,a,f,p,d,g,v,m,y,x,b,_,w,k,T,A,M,S=e.xaxis,E=e.yaxis,C=\"log\"===S.type,L=\"log\"===E.type,P=S._length,O=E._length,z=e.connectGaps,I=e.baseTolerance,D=e.shape,R=\"linear\"===D,F=e.fill&&\"none\"!==e.fill,B=[],N=h.minTolerance,j=t.length,U=new Array(j),V=0;function q(e){var r=t[e];if(!r)return!1;var n=S.c2p(r.x),a=E.c2p(r.y);if(n===i){if(C&&(n=S.c2p(r.x,!0)),n===i)return!1;L&&a===i&&(n*=Math.abs(S._m*O*(S._m>0?o:s)/(E._m*P*(E._m>0?o:s)))),n*=1e3}if(a===i){if(L&&(a=E.c2p(r.y,!0)),a===i)return!1;a*=1e3}return[n,a]}function H(t,e,r,n){var i=r-t,a=n-e,o=.5-t,s=.5-e,l=i*i+a*a,c=i*o+a*s;if(c>0&&c<l){var u=o*a-s*i;if(u*u<l)return!0}}function G(t,e){var r=t[0]/P,n=t[1]/O,i=Math.max(0,-r,r-1,-n,n-1);return i&&void 0!==A&&H(r,n,A,M)&&(i=0),i&&e&&H(r,n,e[0]/P,e[1]/O)&&(i=0),(1+h.toleranceGrowth*i)*I}function Y(t,e){var r=t[0]-e[0],n=t[1]-e[1];return Math.sqrt(r*r+n*n)}var W,X,Z,J,K,$,Q,tt=h.maxScreensAway,et=-P*tt,rt=P*(1+tt),nt=-O*tt,it=O*(1+tt),at=[[et,nt,rt,nt],[rt,nt,rt,it],[rt,it,et,it],[et,it,et,nt]];function ot(t){if(t[0]<et||t[0]>rt||t[1]<nt||t[1]>it)return[u(t[0],et,rt),u(t[1],nt,it)]}function st(t,e){return t[0]===e[0]&&(t[0]===et||t[0]===rt)||(t[1]===e[1]&&(t[1]===nt||t[1]===it)||void 0)}function lt(t,e,r){return function(n,i){var a=ot(n),o=ot(i),s=[];if(a&&o&&st(a,o))return s;a&&s.push(a),o&&s.push(o);var c=2*l.constrain((n[t]+i[t])/2,e,r)-((a||n)[t]+(o||i)[t]);c&&((a&&o?c>0==a[t]>o[t]?a:o:a||o)[t]+=c);return s}}function ct(t){var e=t[0],r=t[1],n=e===U[V-1][0],i=r===U[V-1][1];if(!n||!i)if(V>1){var a=e===U[V-2][0],o=r===U[V-2][1];n&&(e===et||e===rt)&&a?o?V--:U[V-1]=t:i&&(r===nt||r===it)&&o?a?V--:U[V-1]=t:U[V++]=t}else U[V++]=t}function ut(t){U[V-1][0]!==t[0]&&U[V-1][1]!==t[1]&&ct([Z,J]),ct(t),K=null,Z=J=0}function ht(t){if(A=t[0]/P,M=t[1]/O,W=t[0]<et?et:t[0]>rt?rt:0,X=t[1]<nt?nt:t[1]>it?it:0,W||X){if(V)if(K){var e=Q(K,t);e.length>1&&(ut(e[0]),U[V++]=e[1])}else $=Q(U[V-1],t)[0],U[V++]=$;else U[V++]=[W||t[0],X||t[1]];var r=U[V-1];W&&X&&(r[0]!==W||r[1]!==X)?(K&&(Z!==W&&J!==X?ct(Z&&J?(n=K,a=(i=t)[0]-n[0],o=(i[1]-n[1])/a,(n[1]*i[0]-i[1]*n[0])/a>0?[o>0?et:rt,it]:[o>0?rt:et,nt]):[Z||W,J||X]):Z&&J&&ct([Z,J])),ct([W,X])):Z-W&&J-X&&ct([W||Z,X||J]),K=t,Z=W,J=X}else K&&ut(Q(K,t)[0]),U[V++]=t;var n,i,a,o}for(\"linear\"===D||\"spline\"===D?Q=function(t,e){for(var r=[],n=0,i=0;i<4;i++){var a=at[i],o=c(t[0],t[1],e[0],e[1],a[0],a[1],a[2],a[3]);o&&(!n||Math.abs(o.x-r[0][0])>1||Math.abs(o.y-r[0][1])>1)&&(o=[o.x,o.y],n&&Y(o,t)<Y(r[0],t)?r.unshift(o):r.push(o),n++)}return r}:\"hv\"===D||\"vh\"===D?Q=function(t,e){var r=[],n=ot(t),i=ot(e);return n&&i&&st(n,i)?r:(n&&r.push(n),i&&r.push(i),r)}:\"hvh\"===D?Q=lt(0,et,rt):\"vhv\"===D&&(Q=lt(1,nt,it)),r=0;r<j;r++)if(n=q(r)){for(V=0,K=null,ht(n),r++;r<j;r++){if(!(f=q(r))){if(z)continue;break}if(R&&e.simplify){var ft=q(r+1);if(y=Y(f,n),F&&(0===V||V===j-1)||!(y<G(f,ft)*N)){for(v=[(f[0]-n[0])/y,(f[1]-n[1])/y],p=n,x=y,b=w=k=0,g=!1,a=f,r++;r<t.length;r++){if(d=ft,ft=q(r+1),!d){if(z)continue;break}if(T=(m=[d[0]-n[0],d[1]-n[1]])[0]*v[1]-m[1]*v[0],w=Math.min(w,T),(k=Math.max(k,T))-w>G(d,ft))break;a=d,(_=m[0]*v[0]+m[1]*v[1])>x?(x=_,f=d,g=!1):_<b&&(b=_,p=d,g=!0)}if(g?(ht(f),a!==p&&ht(p)):(p!==n&&ht(p),a!==f&&ht(f)),ht(a),r>=t.length||!d)break;ht(d),n=d}}else ht(f)}K&&ct([Z||K[0],J||K[1]]),B.push(U.slice(0,V))}return B}},{\"../../constants/numerical\":695,\"../../lib\":719,\"./constants\":1116}],1126:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){\"spline\"===r(\"line.shape\")&&r(\"line.smoothing\")}},{}],1127:[function(t,e,r){\"use strict\";var n={tonextx:1,tonexty:1,tonext:1};e.exports=function(t,e,r){var i,a,o,s,l,c={},u=!1,h=-1,f=0,p=-1;for(a=0;a<r.length;a++)(o=(i=r[a][0].trace).stackgroup||\"\")?o in c?l=c[o]:(l=c[o]=f,f++):i.fill in n&&p>=0?l=p:(l=p=f,f++),l<h&&(u=!0),i._groupIndex=h=l;var d=r.slice();u&&d.sort(function(t,e){var r=t[0].trace,n=e[0].trace;return r._groupIndex-n._groupIndex||r.index-n.index});var g={};for(a=0;a<d.length;a++)o=(i=d[a][0].trace).stackgroup||\"\",!0===i.visible?(i._nexttrace=null,i.fill in n&&(s=g[o],i._prevtrace=s||null,s&&(s._nexttrace=i)),i._ownfill=i.fill&&(\"tozero\"===i.fill.substr(0,6)||\"toself\"===i.fill||\"to\"===i.fill.substr(0,2)&&!i._prevtrace),g[o]=i):i._prevtrace=i._nexttrace=i._ownfill=null;return d}},{}],1128:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t){var e=t.marker,r=e.sizeref||1,i=e.sizemin||0,a=\"area\"===e.sizemode?function(t){return Math.sqrt(t/r)}:function(t){return t/r};return function(t){var e=a(t/2);return n(e)&&e>0?Math.max(e,i):0}}},{\"fast-isnumeric\":225}],1129:[function(t,e,r){\"use strict\";e.exports={container:\"marker\",min:\"cmin\",max:\"cmax\"}},{}],1130:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"./subtypes\");e.exports=function(t,e,r,s,l,c){var u=o.isBubble(t),h=(t.line||{}).color;(c=c||{},h&&(r=h),l(\"marker.symbol\"),l(\"marker.opacity\",u?.7:1),l(\"marker.size\"),l(\"marker.color\",r),i(t,\"marker\")&&a(t,e,s,l,{prefix:\"marker.\",cLetter:\"c\"}),c.noSelect||(l(\"selected.marker.color\"),l(\"unselected.marker.color\"),l(\"selected.marker.size\"),l(\"unselected.marker.size\")),c.noLine||(l(\"marker.line.color\",h&&!Array.isArray(h)&&e.marker.color!==h?h:u?n.background:n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,l,{prefix:\"marker.line.\",cLetter:\"c\"}),l(\"marker.line.width\",u?1:0)),u&&(l(\"marker.sizeref\"),l(\"marker.sizemin\"),l(\"marker.sizemode\")),c.gradient)&&(\"none\"!==l(\"marker.gradient.type\")&&l(\"marker.gradient.color\"))}},{\"../../components/color\":593,\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"./subtypes\":1135}],1131:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=a.ensureSingle,s=a.identity,l=t(\"../../components/drawing\"),c=t(\"./subtypes\"),u=t(\"./line_points\"),h=t(\"./link_traces\"),f=t(\"../../lib/polygon\").tester;function p(t,e,r,h,p,d,g){var v;!function(t,e,r,i,o){var s=r.xaxis,l=r.yaxis,u=n.extent(a.simpleMap(s.range,s.r2c)),h=n.extent(a.simpleMap(l.range,l.r2c)),f=i[0].trace;if(!c.hasMarkers(f))return;var p=f.marker.maxdisplayed;if(0===p)return;var d=i.filter(function(t){return t.x>=u[0]&&t.x<=u[1]&&t.y>=h[0]&&t.y<=h[1]}),g=Math.ceil(d.length/p),v=0;o.forEach(function(t,r){var n=t[0].trace;c.hasMarkers(n)&&n.marker.maxdisplayed>0&&r<e&&v++});var m=Math.round(v*g/3+Math.floor(v/3)*g/7.1);i.forEach(function(t){delete t.vis}),d.forEach(function(t,e){0===Math.round((e+m)%g)&&(t.vis=!0)})}(0,e,r,h,p);var m=!!g&&g.duration>0;function y(t){return m?t.transition():t}var x=r.xaxis,b=r.yaxis,_=h[0].trace,w=_.line,k=n.select(d),T=o(k,\"g\",\"errorbars\"),A=o(k,\"g\",\"lines\"),M=o(k,\"g\",\"points\"),S=o(k,\"g\",\"text\");if(i.getComponentMethod(\"errorbars\",\"plot\")(t,T,r,g),!0===_.visible){var E,C;y(k).style(\"opacity\",_.opacity);var L=_.fill.charAt(_.fill.length-1);\"x\"!==L&&\"y\"!==L&&(L=\"\"),h[0][r.isRangePlot?\"nodeRangePlot3\":\"node3\"]=k;var P,O,z=\"\",I=[],D=_._prevtrace;D&&(z=D._prevRevpath||\"\",C=D._nextFill,I=D._polygons);var R,F,B,N,j,U,V,q=\"\",H=\"\",G=[],Y=a.noop;if(E=_._ownFill,c.hasLines(_)||\"none\"!==_.fill){for(C&&C.datum(h),-1!==[\"hv\",\"vh\",\"hvh\",\"vhv\"].indexOf(w.shape)?(R=l.steps(w.shape),F=l.steps(w.shape.split(\"\").reverse().join(\"\"))):R=F=\"spline\"===w.shape?function(t){var e=t[t.length-1];return t.length>1&&t[0][0]===e[0]&&t[0][1]===e[1]?l.smoothclosed(t.slice(1),w.smoothing):l.smoothopen(t,w.smoothing)}:function(t){return\"M\"+t.join(\"L\")},B=function(t){return F(t.reverse())},G=u(h,{xaxis:x,yaxis:b,connectGaps:_.connectgaps,baseTolerance:Math.max(w.width||1,3)/4,shape:w.shape,simplify:w.simplify,fill:_.fill}),V=_._polygons=new Array(G.length),v=0;v<G.length;v++)_._polygons[v]=f(G[v]);G.length&&(N=G[0][0],U=(j=G[G.length-1])[j.length-1]),Y=function(t){return function(e){if(P=R(e),O=B(e),q?L?(q+=\"L\"+P.substr(1),H=O+\"L\"+H.substr(1)):(q+=\"Z\"+P,H=O+\"Z\"+H):(q=P,H=O),c.hasLines(_)&&e.length>1){var r=n.select(this);if(r.datum(h),t)y(r.style(\"opacity\",0).attr(\"d\",P).call(l.lineGroupStyle)).style(\"opacity\",1);else{var i=y(r);i.attr(\"d\",P),l.singleLineStyle(h,i)}}}}}var W=A.selectAll(\".js-line\").data(G);y(W.exit()).style(\"opacity\",0).remove(),W.each(Y(!1)),W.enter().append(\"path\").classed(\"js-line\",!0).style(\"vector-effect\",\"non-scaling-stroke\").call(l.lineGroupStyle).each(Y(!0)),l.setClipUrl(W,r.layerClipId,t),G.length?(E?(E.datum(h),N&&U&&(L?(\"y\"===L?N[1]=U[1]=b.c2p(0,!0):\"x\"===L&&(N[0]=U[0]=x.c2p(0,!0)),y(E).attr(\"d\",\"M\"+U+\"L\"+N+\"L\"+q.substr(1)).call(l.singleFillStyle)):y(E).attr(\"d\",q+\"Z\").call(l.singleFillStyle))):C&&(\"tonext\"===_.fill.substr(0,6)&&q&&z?(\"tonext\"===_.fill?y(C).attr(\"d\",q+\"Z\"+z+\"Z\").call(l.singleFillStyle):y(C).attr(\"d\",q+\"L\"+z.substr(1)+\"Z\").call(l.singleFillStyle),_._polygons=_._polygons.concat(I)):(Z(C),_._polygons=null)),_._prevRevpath=H,_._prevPolygons=V):(E?Z(E):C&&Z(C),_._polygons=_._prevRevpath=_._prevPolygons=null),M.datum(h),S.datum(h),function(e,i,a){var o,u=a[0].trace,h=c.hasMarkers(u),f=c.hasText(u),p=tt(u),d=et,g=et;if(h||f){var v=s,_=u.stackgroup,w=_&&\"infer zero\"===t._fullLayout._scatterStackOpts[x._id+b._id][_].stackgaps;u.marker.maxdisplayed||u._needsCull?v=w?K:J:_&&!w&&(v=$),h&&(d=v),f&&(g=v)}var k,T=(o=e.selectAll(\"path.point\").data(d,p)).enter().append(\"path\").classed(\"point\",!0);m&&T.call(l.pointStyle,u,t).call(l.translatePoints,x,b).style(\"opacity\",0).transition().style(\"opacity\",1),o.order(),h&&(k=l.makePointStyleFns(u)),o.each(function(e){var i=n.select(this),a=y(i);l.translatePoint(e,a,x,b)?(l.singlePointStyle(e,a,u,k,t),r.layerClipId&&l.hideOutsideRangePoint(e,a,x,b,u.xcalendar,u.ycalendar),u.customdata&&i.classed(\"plotly-customdata\",null!==e.data&&void 0!==e.data)):a.remove()}),m?o.exit().transition().style(\"opacity\",0).remove():o.exit().remove(),(o=i.selectAll(\"g\").data(g,p)).enter().append(\"g\").classed(\"textpoint\",!0).append(\"text\"),o.order(),o.each(function(t){var e=n.select(this),i=y(e.select(\"text\"));l.translatePoint(t,i,x,b)?r.layerClipId&&l.hideOutsideRangePoint(t,e,x,b,u.xcalendar,u.ycalendar):e.remove()}),o.selectAll(\"text\").call(l.textPointStyle,u,t).each(function(t){var e=x.c2p(t.x),r=b.c2p(t.y);n.select(this).selectAll(\"tspan.line\").each(function(){y(n.select(this)).attr({x:e,y:r})})}),o.exit().remove()}(M,S,h);var X=!1===_.cliponaxis?null:r.layerClipId;l.setClipUrl(M,X,t),l.setClipUrl(S,X,t)}function Z(t){y(t).attr(\"d\",\"M0,0Z\")}function J(t){return t.filter(function(t){return!t.gap&&t.vis})}function K(t){return t.filter(function(t){return t.vis})}function $(t){return t.filter(function(t){return!t.gap})}function Q(t){return t.id}function tt(t){if(t.ids)return Q}function et(){return!1}}e.exports=function(t,e,r,i,a,c){var u,f,d=!a,g=!!a&&a.duration>0,v=h(t,e,r);((u=i.selectAll(\"g.trace\").data(v,function(t){return t[0].trace.uid})).enter().append(\"g\").attr(\"class\",function(t){return\"trace scatter trace\"+t[0].trace.uid}).style(\"stroke-miterlimit\",2),u.order(),function(t,e,r){e.each(function(e){var i=o(n.select(this),\"g\",\"fills\");l.setClipUrl(i,r.layerClipId,t);var a=e[0].trace,c=[];a._ownfill&&c.push(\"_ownFill\"),a._nexttrace&&c.push(\"_nextFill\");var u=i.selectAll(\"g\").data(c,s);u.enter().append(\"g\"),u.exit().each(function(t){a[t]=null}).remove(),u.order().each(function(t){a[t]=o(n.select(this),\"path\",\"js-fill\")})})}(t,u,e),g)?(c&&(f=c()),n.transition().duration(a.duration).ease(a.easing).each(\"end\",function(){f&&f()}).each(\"interrupt\",function(){f&&f()}).each(function(){i.selectAll(\"g.trace\").each(function(r,n){p(t,n,e,r,v,this,a)})})):u.each(function(r,n){p(t,n,e,r,v,this,a)});d&&u.exit().remove(),i.selectAll(\"path:not([d])\").remove()}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/polygon\":731,\"../../registry\":847,\"./line_points\":1125,\"./link_traces\":1127,\"./subtypes\":1135,d3:163}],1132:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports=function(t,e){var r,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[],h=s[0].trace;if(!n.hasMarkers(h)&&!n.hasText(h))return[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)i=s[r],a=l.c2p(i.x),o=c.c2p(i.y),null!==i.i&&e.contains([a,o],!1,r,t)?(u.push({pointNumber:i.i,x:l.c2d(i.x),y:c.c2d(i.y)}),i.selected=1):i.selected=0;return u}},{\"./subtypes\":1135}],1133:[function(t,e,r){\"use strict\";var n=[\"orientation\",\"groupnorm\",\"stackgaps\"];e.exports=function(t,e,r,i){var a=r._scatterStackOpts,o=i(\"stackgroup\");if(o){var s=e.xaxis+e.yaxis,l=a[s];l||(l=a[s]={});var c=l[o],u=!1;c?c.traces.push(e):(c=l[o]={traceIndices:[],traces:[e]},u=!0);for(var h={orientation:e.x&&!e.y?\"h\":\"v\"},f=0;f<n.length;f++){var p=n[f],d=p+\"Found\";if(!c[d]){var g=void 0!==t[p],v=\"orientation\"===p;if((g||u)&&(c[p]=i(p,h[p]),v&&(c.fillDflt=\"h\"===c[p]?\"tonextx\":\"tonexty\"),g&&(c[d]=!0,!u&&(delete c.traces[0][p],v))))for(var m=0;m<c.traces.length-1;m++){var y=c.traces[m];y._input.fill!==y.fill&&(y.fill=c.fillDflt)}}}return c}}},{}],1134:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../registry\");function o(t,e,r){i.pointStyle(t.selectAll(\"path.point\"),e,r)}function s(t,e,r){i.textPointStyle(t.selectAll(\"text\"),e,r)}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.trace.scatter\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.selectAll(\"g.points\").each(function(e){o(n.select(this),e.trace||e[0].trace,t)}),e.selectAll(\"g.text\").each(function(e){s(n.select(this),e.trace||e[0].trace,t)}),e.selectAll(\"g.trace path.js-line\").call(i.lineGroupStyle),e.selectAll(\"g.trace path.js-fill\").call(i.fillGroupStyle),a.getComponentMethod(\"errorbars\",\"style\")(e)},stylePoints:o,styleText:s,styleOnSelect:function(t,e,r){var n=e[0].trace;n.selectedpoints?(i.selectedPointStyle(r.selectAll(\"path.point\"),n),i.selectedTextStyle(r.selectAll(\"text\"),n)):(o(r,n,t),s(r,n,t))}}},{\"../../components/drawing\":614,\"../../registry\":847,d3:163}],1135:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports={hasLines:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"lines\")},hasMarkers:function(t){return t.visible&&(t.mode&&-1!==t.mode.indexOf(\"markers\")||\"splom\"===t.type)},hasText:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"text\")},isBubble:function(t){return n.isPlainObject(t.marker)&&n.isArrayOrTypedArray(t.marker.size)}}},{\"../../lib\":719}],1136:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i,a){a=a||{},i(\"textposition\"),n.coerceFont(i,\"textfont\",r.font),a.noSelect||(i(\"selected.textfont.color\"),i(\"unselected.textfont.color\"))}},{\"../../lib\":719}],1137:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");e.exports=function(t,e,r,a){var o,s=a(\"x\"),l=a(\"y\");if(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],r),s){var c=n.minRowLength(s);l?o=Math.min(c,n.minRowLength(l)):(o=c,a(\"y0\"),a(\"dy\"))}else{if(!l)return 0;o=n.minRowLength(l),a(\"x0\"),a(\"dx\")}return e._length=o,o}},{\"../../lib\":719,\"../../registry\":847}],1138:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../constants/gl3d_dashes\"),l=t(\"../../constants/gl3d_markers\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../plot_api/edit_types\").overrideAll,h=n.line,f=n.marker,p=f.line,d=c({width:h.width,dash:{valType:\"enumerated\",values:Object.keys(s),dflt:\"solid\"}},i(\"line\"));var g=e.exports=u({x:n.x,y:n.y,z:{valType:\"data_array\"},text:c({},n.text,{}),hovertext:c({},n.hovertext,{}),hovertemplate:a(),mode:c({},n.mode,{dflt:\"lines+markers\"}),surfaceaxis:{valType:\"enumerated\",values:[-1,0,1,2],dflt:-1},surfacecolor:{valType:\"color\"},projection:{x:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},y:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},z:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}}},connectgaps:n.connectgaps,line:d,marker:c({symbol:{valType:\"enumerated\",values:Object.keys(l),dflt:\"circle\",arrayOk:!0},size:c({},f.size,{dflt:8}),sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode,opacity:c({},f.opacity,{arrayOk:!1}),colorbar:f.colorbar,line:c({width:c({},p.width,{arrayOk:!1})},i(\"marker.line\"))},i(\"marker\")),textposition:c({},n.textposition,{dflt:\"top center\"}),textfont:{color:n.textfont.color,size:n.textfont.size,family:c({},n.textfont.family,{arrayOk:!1})},hoverinfo:c({},o.hoverinfo)},\"calc\",\"nested\");g.x.editType=g.y.editType=g.z.editType=\"calc+clearAxisTypes\"},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../constants/gl3d_dashes\":692,\"../../constants/gl3d_markers\":693,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1139:[function(t,e,r){\"use strict\";var n=t(\"../scatter/arrays_to_calcdata\"),i=t(\"../scatter/colorscale_calc\");e.exports=function(t,e){var r=[{x:!1,y:!1,trace:e,t:{}}];return n(r,e),i(t,e),r}},{\"../scatter/arrays_to_calcdata\":1111,\"../scatter/colorscale_calc\":1115}],1140:[function(t,e,r){\"use strict\";var n=t(\"../../registry\");function i(t,e,r,i){if(!e||!e.visible)return null;for(var a=n.getComponentMethod(\"errorbars\",\"makeComputeError\")(e),o=new Array(t.length),s=0;s<t.length;s++){var l=a(+t[s],s);if(\"log\"===i.type){var c=i.c2l(t[s]),u=t[s]-l[0],h=t[s]+l[1];if(o[s]=[(i.c2l(u,!0)-c)*r,(i.c2l(h,!0)-c)*r],u>0){var f=i.c2l(u);i._lowerLogErrorBound||(i._lowerLogErrorBound=f),i._lowerErrorBound=Math.min(i._lowerLogErrorBound,f)}}else o[s]=[-l[0]*r,l[1]*r]}return o}e.exports=function(t,e,r){var n=[i(t.x,t.error_x,e[0],r.xaxis),i(t.y,t.error_y,e[1],r.yaxis),i(t.z,t.error_z,e[2],r.zaxis)],a=function(t){for(var e=0;e<t.length;e++)if(t[e])return t[e].length;return 0}(n);if(0===a)return null;for(var o=new Array(a),s=0;s<a;s++){for(var l=[[0,0,0],[0,0,0]],c=0;c<3;c++)if(n[c])for(var u=0;u<2;u++)l[u][c]=n[c][s][u];o[s]=l}return o}},{\"../../registry\":847}],1141:[function(t,e,r){\"use strict\";var n=t(\"gl-line3d\"),i=t(\"gl-scatter3d\"),a=t(\"gl-error3d\"),o=t(\"gl-mesh3d\"),s=t(\"delaunay-triangulate\"),l=t(\"../../lib\"),c=t(\"../../lib/str2rgbarray\"),u=t(\"../../lib/gl_format_color\").formatColor,h=t(\"../scatter/make_bubble_size_func\"),f=t(\"../../constants/gl3d_dashes\"),p=t(\"../../constants/gl3d_markers\"),d=t(\"./calc_errors\");function g(t,e){this.scene=t,this.uid=e,this.linePlot=null,this.scatterPlot=null,this.errorBars=null,this.textMarkers=null,this.delaunayMesh=null,this.color=null,this.mode=\"\",this.dataPoints=[],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.textLabels=null,this.data=null}var v=g.prototype;function m(t){return null==t?0:t.indexOf(\"left\")>-1?-1:t.indexOf(\"right\")>-1?1:0}function y(t){return null==t?0:t.indexOf(\"top\")>-1?-1:t.indexOf(\"bottom\")>-1?1:0}function x(t,e){return e(4*t)}function b(t){return p[t]}function _(t,e,r,n,i){var a=null;if(l.isArrayOrTypedArray(t)){a=[];for(var o=0;o<e;o++)void 0===t[o]?a[o]=n:a[o]=r(t[o],i)}else a=r(t,l.identity);return a}function w(t,e){var r,n,i,a,o,s,f=[],p=t.fullSceneLayout,g=t.dataScale,v=p.xaxis,w=p.yaxis,k=p.zaxis,T=e.marker,A=e.line,M=e.x||[],S=e.y||[],E=e.z||[],C=M.length,L=e.xcalendar,P=e.ycalendar,O=e.zcalendar;for(o=0;o<C;o++)r=v.d2l(M[o],0,L)*g[0],n=w.d2l(S[o],0,P)*g[1],i=k.d2l(E[o],0,O)*g[2],f[o]=[r,n,i];if(Array.isArray(e.text))s=e.text;else if(void 0!==e.text)for(s=new Array(C),o=0;o<C;o++)s[o]=e.text;if(a={position:f,mode:e.mode,text:s},\"line\"in e&&(a.lineColor=u(A,1,C),a.lineWidth=A.width,a.lineDashes=A.dash),\"marker\"in e){var z=h(e);a.scatterColor=u(T,1,C),a.scatterSize=_(T.size,C,x,20,z),a.scatterMarker=_(T.symbol,C,b,\"\\u25cf\"),a.scatterLineWidth=T.line.width,a.scatterLineColor=u(T.line,1,C),a.scatterAngle=0}\"textposition\"in e&&(a.textOffset=function(t){var e=[0,0];if(Array.isArray(t))for(var r=0;r<t.length;r++)e[r]=[0,0],t[r]&&(e[r][0]=m(t[r]),e[r][1]=y(t[r]));else e[0]=m(t),e[1]=y(t);return e}(e.textposition),a.textColor=u(e.textfont,1,C),a.textSize=_(e.textfont.size,C,l.identity,12),a.textFont=e.textfont.family,a.textAngle=0);var I=[\"x\",\"y\",\"z\"];for(a.project=[!1,!1,!1],a.projectScale=[1,1,1],a.projectOpacity=[1,1,1],o=0;o<3;++o){var D=e.projection[I[o]];(a.project[o]=D.show)&&(a.projectOpacity[o]=D.opacity,a.projectScale[o]=D.scale)}a.errorBounds=d(e,g,p);var R=function(t){for(var e=[0,0,0],r=[[0,0,0],[0,0,0],[0,0,0]],n=[1,1,1],i=0;i<3;i++){var a=t[i];a&&!1!==a.copy_zstyle&&!1!==t[2].visible&&(a=t[2]),a&&a.visible&&(e[i]=a.width/2,r[i]=c(a.color),n[i]=a.thickness)}return{capSize:e,color:r,lineWidth:n}}([e.error_x,e.error_y,e.error_z]);return a.errorColor=R.color,a.errorLineWidth=R.lineWidth,a.errorCapSize=R.capSize,a.delaunayAxis=e.surfaceaxis,a.delaunayColor=c(e.surfacecolor),a}function k(t){if(Array.isArray(t)){var e=t[0];return Array.isArray(e)&&(t=e),\"rgb(\"+t.slice(0,3).map(function(t){return Math.round(255*t)})+\")\"}return null}v.handlePick=function(t){if(t.object&&(t.object===this.linePlot||t.object===this.delaunayMesh||t.object===this.textMarkers||t.object===this.scatterPlot)){var e=t.index=t.data.index;return t.object.highlight&&t.object.highlight(null),this.scatterPlot&&(t.object=this.scatterPlot,this.scatterPlot.highlight(t.data)),t.textLabel=\"\",this.textLabels&&(Array.isArray(this.textLabels)?(this.textLabels[e]||0===this.textLabels[e])&&(t.textLabel=this.textLabels[e]):t.textLabel=this.textLabels),t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]],!0}},v.update=function(t){var e,r,l,c,u=this.scene.glplot.gl,h=f.solid;this.data=t;var p=w(this.scene,t);\"mode\"in p&&(this.mode=p.mode),\"lineDashes\"in p&&p.lineDashes in f&&(h=f[p.lineDashes]),this.color=k(p.scatterColor)||k(p.lineColor),this.dataPoints=p.position,e={gl:this.scene.glplot.gl,position:p.position,color:p.lineColor,lineWidth:p.lineWidth||1,dashes:h[0],dashScale:h[1],opacity:t.opacity,connectGaps:t.connectgaps},-1!==this.mode.indexOf(\"lines\")?this.linePlot?this.linePlot.update(e):(this.linePlot=n(e),this.linePlot._trace=this,this.scene.glplot.add(this.linePlot)):this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose(),this.linePlot=null);var d=t.opacity;if(t.marker&&t.marker.opacity&&(d*=t.marker.opacity),r={gl:this.scene.glplot.gl,position:p.position,color:p.scatterColor,size:p.scatterSize,glyph:p.scatterMarker,opacity:d,orthographic:!0,lineWidth:p.scatterLineWidth,lineColor:p.scatterLineColor,project:p.project,projectScale:p.projectScale,projectOpacity:p.projectOpacity},-1!==this.mode.indexOf(\"markers\")?this.scatterPlot?this.scatterPlot.update(r):(this.scatterPlot=i(r),this.scatterPlot._trace=this,this.scatterPlot.highlightScale=1,this.scene.glplot.add(this.scatterPlot)):this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose(),this.scatterPlot=null),c={gl:this.scene.glplot.gl,position:p.position,glyph:p.text,color:p.textColor,size:p.textSize,angle:p.textAngle,alignment:p.textOffset,font:p.textFont,orthographic:!0,lineWidth:0,project:!1,opacity:t.opacity},this.textLabels=t.hovertext||t.text,-1!==this.mode.indexOf(\"text\")?this.textMarkers?this.textMarkers.update(c):(this.textMarkers=i(c),this.textMarkers._trace=this,this.textMarkers.highlightScale=1,this.scene.glplot.add(this.textMarkers)):this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose(),this.textMarkers=null),l={gl:this.scene.glplot.gl,position:p.position,color:p.errorColor,error:p.errorBounds,lineWidth:p.errorLineWidth,capSize:p.errorCapSize,opacity:t.opacity},this.errorBars?p.errorBounds?this.errorBars.update(l):(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose(),this.errorBars=null):p.errorBounds&&(this.errorBars=a(l),this.errorBars._trace=this,this.scene.glplot.add(this.errorBars)),p.delaunayAxis>=0){var g=function(t,e,r){var n,i=(r+1)%3,a=(r+2)%3,o=[],l=[];for(n=0;n<t.length;++n){var c=t[n];!isNaN(c[i])&&isFinite(c[i])&&!isNaN(c[a])&&isFinite(c[a])&&(o.push([c[i],c[a]]),l.push(n))}var u=s(o);for(n=0;n<u.length;++n)for(var h=u[n],f=0;f<h.length;++f)h[f]=l[h[f]];return{positions:t,cells:u,meshColor:e}}(p.position,p.delaunayColor,p.delaunayAxis);g.opacity=t.opacity,this.delaunayMesh?this.delaunayMesh.update(g):(g.gl=u,this.delaunayMesh=o(g),this.delaunayMesh._trace=this,this.scene.glplot.add(this.delaunayMesh))}else this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose(),this.delaunayMesh=null)},v.dispose=function(){this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose()),this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose()),this.errorBars&&(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose()),this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose()),this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose())},e.exports=function(t,e){var r=new g(t,e.uid);return r.update(e),r}},{\"../../constants/gl3d_dashes\":692,\"../../constants/gl3d_markers\":693,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../scatter/make_bubble_size_func\":1128,\"./calc_errors\":1140,\"delaunay-triangulate\":165,\"gl-error3d\":247,\"gl-line3d\":255,\"gl-mesh3d\":280,\"gl-scatter3d\":297}],1142:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,n){return i.coerce(t,e,c,r,n)}if(function(t,e,r,i){var a=0,o=r(\"x\"),s=r(\"y\"),l=r(\"z\");n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],i),o&&s&&l&&(a=Math.min(o.length,s.length,l.length),e._length=e._xlength=e._ylength=e._zlength=a);return a}(t,e,h,u)){h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),a.hasLines(e)&&(h(\"connectgaps\"),s(t,e,r,u,h)),a.hasMarkers(e)&&o(t,e,r,u,h,{noSelect:!0}),a.hasText(e)&&l(t,e,u,h,{noSelect:!0});var f=(e.line||{}).color,p=(e.marker||{}).color;h(\"surfaceaxis\")>=0&&h(\"surfacecolor\",f||p);for(var d=[\"x\",\"y\",\"z\"],g=0;g<3;++g){var v=\"projection.\"+d[g];h(v+\".show\")&&(h(v+\".opacity\"),h(v+\".scale\"))}var m=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");m(t,e,f||p||r,{axis:\"z\"}),m(t,e,f||p||r,{axis:\"y\",inherit:\"z\"}),m(t,e,f||p||r,{axis:\"x\",inherit:\"z\"})}else e.visible=!1}},{\"../../lib\":719,\"../../registry\":847,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1138}],1143:[function(t,e,r){\"use strict\";e.exports={plot:t(\"./convert\"),attributes:t(\"./attributes\"),markerSymbols:t(\"../../constants/gl3d_markers\"),supplyDefaults:t(\"./defaults\"),colorbar:[{container:\"marker\",min:\"cmin\",max:\"cmax\"},{container:\"line\",min:\"cmin\",max:\"cmax\"}],calc:t(\"./calc\"),moduleType:\"trace\",name:\"scatter3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"symbols\",\"showLegend\"],meta:{}}},{\"../../constants/gl3d_markers\":693,\"../../plots/gl3d\":807,\"./attributes\":1138,\"./calc\":1139,\"./convert\":1141,\"./defaults\":1142}],1144:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=n.marker,c=n.line,u=l.line;e.exports={carpet:{valType:\"string\",editType:\"calc\"},a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},mode:s({},n.mode,{dflt:\"markers\"}),text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),line:{color:c.color,width:c.width,dash:c.dash,shape:s({},c.shape,{values:[\"linear\",\"spline\"]}),smoothing:c.smoothing,editType:\"calc\"},connectgaps:n.connectgaps,fill:s({},n.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:n.fillcolor,marker:s({symbol:l.symbol,opacity:l.opacity,maxdisplayed:l.maxdisplayed,size:l.size,sizeref:l.sizeref,sizemin:l.sizemin,sizemode:l.sizemode,line:s({width:u.width,editType:\"calc\"},o(\"marker.line\")),gradient:l.gradient,editType:\"calc\"},o(\"marker\")),textfont:n.textfont,textposition:n.textposition,selected:n.selected,unselected:n.unselected,hoverinfo:s({},i.hoverinfo,{flags:[\"a\",\"b\",\"text\",\"name\"]}),hoveron:n.hoveron,hovertemplate:a()}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1145:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=t(\"../carpet/lookup_carpetid\");e.exports=function(t,e){var r=e._carpetTrace=l(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){var c;e.xaxis=r.xaxis,e.yaxis=r.yaxis;var u,h,f=e._length,p=new Array(f),d=!1;for(c=0;c<f;c++)if(u=e.a[c],h=e.b[c],n(u)&&n(h)){var g=r.ab2xy(+u,+h,!0),v=r.isVisible(+u,+h);v||(d=!0),p[c]={x:g[0],y:g[1],a:u,b:h,vis:v}}else p[c]={x:!1,y:!1};return e._needsCull=d,p[0].carpet=r,p[0].trace=e,s(e,f),i(t,e),a(p,e),o(p,e),p}}},{\"../carpet/lookup_carpetid\":915,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc\":1113,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1146:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}p(\"carpet\"),e.xaxis=\"x\",e.yaxis=\"y\";var d=p(\"a\"),g=p(\"b\"),v=Math.min(d.length,g.length);if(v){e._length=v,p(\"text\"),p(\"hovertext\"),p(\"mode\",v<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,f,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,f,p,{gradient:!0}),a.hasText(e)&&c(t,e,f,p);var m=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"marker.maxdisplayed\"),m.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||m.push(\"fills\"),\"fills\"!==p(\"hoveron\",m.join(\"+\")||\"points\")&&p(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/line_shape_defaults\":1126,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1144}],1147:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=n[i];return t.a=a.a,t.b=a.b,t.y=a.y,t}},{}],1148:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../lib\").fillText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,h=c-u;return s.x0=Math.max(Math.min(s.x0,h),u),s.x1=Math.max(Math.min(s.x1,h),u),o}var f=s.cd[s.index];s.a=f.a,s.b=f.b,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.trace,d=p._carpet,g=d.ab2ij([f.a,f.b]),v=Math.floor(g[0]),m=g[0]-v,y=Math.floor(g[1]),x=g[1]-y,b=d.evalxy([],v,y,m,x);s.yLabel=b[1].toFixed(3),delete s.text;var _=[];if(!p.hovertemplate){var w=(f.hi||p.hoverinfo).split(\"+\");-1!==w.indexOf(\"all\")&&(w=[\"a\",\"b\",\"text\"]),-1!==w.indexOf(\"a\")&&k(d.aaxis,f.a),-1!==w.indexOf(\"b\")&&k(d.baxis,f.b),_.push(\"y: \"+s.yLabel),-1!==w.indexOf(\"text\")&&i(f,p,_),s.extraText=_.join(\"<br>\")}return o}function k(t,e){var r;r=t.labelprefix&&t.labelprefix.length>0?t.labelprefix.replace(/ = $/,\"\"):t._hovertitle,_.push(r+\": \"+e.toFixed(3)+t.labelsuffix)}}},{\"../../lib\":719,\"../scatter/hover\":1122}],1149:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scattercarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"svg\",\"carpet\",\"symbols\",\"showLegend\",\"carpetDependent\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../scatter/marker_colorbar\":1129,\"../scatter/select\":1132,\"../scatter/style\":1134,\"./attributes\":1144,\"./calc\":1145,\"./defaults\":1146,\"./event_data\":1147,\"./hover\":1148,\"./plot\":1150}],1150:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../components/drawing\");e.exports=function(t,e,r,o){var s,l,c,u=r[0][0].carpet,h={xaxis:i.getFromId(t,u.xaxis||\"x\"),yaxis:i.getFromId(t,u.yaxis||\"y\"),plot:e.plot};for(n(t,h,r,o),s=0;s<r.length;s++)l=r[s][0].trace,c=o.selectAll(\"g.trace\"+l.uid+\" .js-line\"),a.setClipUrl(c,r[s][0].carpet._clipPathId,t)}},{\"../../components/drawing\":614,\"../../plots/cartesian/axes\":767,\"../scatter/plot\":1131}],1151:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/drawing/attributes\").dash,l=t(\"../../lib/extend\").extendFlat,c=t(\"../../plot_api/edit_types\").overrideAll,u=i.marker,h=i.line,f=u.line;e.exports=c({lon:{valType:\"data_array\"},lat:{valType:\"data_array\"},locations:{valType:\"data_array\"},locationmode:{valType:\"enumerated\",values:[\"ISO-3\",\"USA-states\",\"country names\"],dflt:\"ISO-3\"},mode:l({},i.mode,{dflt:\"markers\"}),text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),textfont:i.textfont,textposition:i.textposition,line:{color:h.color,width:h.width,dash:s},connectgaps:i.connectgaps,marker:l({symbol:u.symbol,opacity:u.opacity,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,colorbar:u.colorbar,line:l({width:f.width},o(\"marker.line\")),gradient:u.gradient},o(\"marker\")),fill:{valType:\"enumerated\",values:[\"none\",\"toself\"],dflt:\"none\"},fillcolor:i.fillcolor,selected:i.selected,unselected:i.unselected,hoverinfo:l({},a.hoverinfo,{flags:[\"lon\",\"lat\",\"location\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":600,\"../../components/drawing/attributes\":613,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1152:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../scatter/colorscale_calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\"),l=t(\"../../lib\")._;e.exports=function(t,e){for(var r=Array.isArray(e.locations),c=r?e.locations.length:e._length,u=new Array(c),h=0;h<c;h++){var f=u[h]={};if(r){var p=e.locations[h];f.loc=\"string\"==typeof p?p:null}else{var d=e.lon[h],g=e.lat[h];n(d)&&n(g)?f.lonlat=[+d,+g]:f.lonlat=[i,i]}}return o(u,e),a(t,e),s(u,e),c&&(u[0].t={labels:{lat:l(t,\"lat:\")+\" \",lon:l(t,\"lon:\")+\" \"}}),u}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1153:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,i){return n.coerce(t,e,c,r,i)}!function(t,e,r){var n,i,a=0,o=r(\"locations\");if(o)return r(\"locationmode\"),a=o.length;return n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length),e._length=a,a}(0,e,h)?e.visible=!1:(h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),i.hasLines(e)&&(o(t,e,r,u,h),h(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,u,h,{gradient:!0}),i.hasText(e)&&s(t,e,u,h),h(\"fill\"),\"none\"!==e.fill&&l(t,e,r,h),n.coerceSelectionMarkerOpacity(e,h))}},{\"../../lib\":719,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1151}],1154:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.location=e.loc?e.loc:null,t}},{}],1155:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../scatter/get_trace_color\"),s=t(\"../../lib\").fillText,l=t(\"./attributes\");e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,h=t.xa,f=t.ya,p=t.subplot,d=p.projection.isLonLatOverEdges,g=p.project;if(n.getClosest(c,function(t){var n=t.lonlat;if(n[0]===a)return 1/0;if(d(n))return 1/0;var i=g(n),o=g([e,r]),s=Math.abs(i[0]-o[0]),l=Math.abs(i[1]-o[1]),c=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(s*s+l*l)-c,1-3/c)},t),!1!==t.index){var v=c[t.index],m=v.lonlat,y=[h.c2p(m),f.c2p(m)],x=v.mrc||1;t.x0=y[0]-x,t.x1=y[0]+x,t.y0=y[1]-x,t.y1=y[1]+x,t.loc=v.loc,t.lon=m[0],t.lat=m[1];var b=p.mockAxis;return t.lonLabel=i.tickText(b,b.c2l(t.lon),\"hover\").text,t.latLabel=i.tickText(b,b.c2l(t.lat),\"hover\").text,t.color=o(u,v),t.extraText=function(t,e,r,n){if(t.hovertemplate)return;var i=e.hi||t.hoverinfo,a=\"all\"===i?l.hoverinfo.flags:i.split(\"+\"),o=-1!==a.indexOf(\"location\")&&Array.isArray(t.locations),c=-1!==a.indexOf(\"lon\"),u=-1!==a.indexOf(\"lat\"),h=-1!==a.indexOf(\"text\"),f=[];function p(t){return t+\"\\xb0\"}o?f.push(e.loc):c&&u?f.push(\"(\"+p(r.lonLabel)+\", \"+p(r.latLabel)+\")\"):c?f.push(n.lon+p(r.lonLabel)):u&&f.push(n.lat+p(r.latLabel));h&&s(e,t,f);return f.join(\"<br>\")}(u,v,t,c[0].t.labels),t.hovertemplate=u.hovertemplate,[t]}}},{\"../../components/fx\":632,\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scatter/get_trace_color\":1121,\"./attributes\":1151}],1156:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"scattergeo\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/geo\":797,\"../scatter/marker_colorbar\":1129,\"../scatter/style\":1134,\"./attributes\":1151,\"./calc\":1152,\"./defaults\":1153,\"./event_data\":1154,\"./hover\":1155,\"./plot\":1157,\"./select\":1158,\"./style\":1159}],1157:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../lib/topojson_utils\").getTopojsonFeatures,s=t(\"../../lib/geo_location_utils\").locationToFeature,l=t(\"../../lib/geojson_utils\"),c=t(\"../scatter/subtypes\"),u=t(\"./style\");function h(t,e){var r=t[0].trace;if(Array.isArray(r.locations))for(var n=o(r,e),i=r.locationmode,l=0;l<t.length;l++){var c=t[l],u=s(i,c.loc,n);c.lonlat=u?u.properties.ct:[a,a]}}e.exports=function(t,e,r){for(var o=0;o<r.length;o++)h(r[o],e.topojson);function s(t,e){t.lonlat[0]===a&&n.select(e).remove()}var f=e.layers.frontplot.select(\".scatterlayer\"),p=i.makeTraceGroups(f,r,\"trace scattergeo\");p.selectAll(\"*\").remove(),p.each(function(e){var r=n.select(this),a=e[0].trace;if(c.hasLines(a)||\"none\"!==a.fill){var o=l.calcTraceToLineCoords(e),h=\"none\"!==a.fill?l.makePolygon(o):l.makeLine(o);r.selectAll(\"path.js-line\").data([{geojson:h,trace:a}]).enter().append(\"path\").classed(\"js-line\",!0).style(\"stroke-miterlimit\",2)}c.hasMarkers(a)&&r.selectAll(\"path.point\").data(i.identity).enter().append(\"path\").classed(\"point\",!0).each(function(t){s(t,this)}),c.hasText(a)&&r.selectAll(\"g\").data(i.identity).enter().append(\"g\").append(\"text\").each(function(t){s(t,this)}),u(t,e)})}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/geo_location_utils\":713,\"../../lib/geojson_utils\":714,\"../../lib/topojson_utils\":746,\"../scatter/subtypes\":1135,\"./style\":1159,d3:163}],1158:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,a,o,s,l,c=t.cd,u=t.xaxis,h=t.yaxis,f=[],p=c[0].trace;if(!n.hasMarkers(p)&&!n.hasText(p))return[];if(!1===e)for(l=0;l<c.length;l++)c[l].selected=0;else for(l=0;l<c.length;l++)(a=(r=c[l]).lonlat)[0]!==i&&(o=u.c2p(a),s=h.c2p(a),e.contains([o,s],null,l,t)?(f.push({pointNumber:l,lon:a[0],lat:a[1]}),r.selected=1):r.selected=0);return f}},{\"../../constants/numerical\":695,\"../scatter/subtypes\":1135}],1159:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../scatter/style\"),s=o.stylePoints,l=o.styleText;e.exports=function(t,e){e&&function(t,e){var r=e[0].trace,o=e[0].node3;o.style(\"opacity\",e[0].trace.opacity),s(o,r,t),l(o,r,t),o.selectAll(\"path.js-line\").style(\"fill\",\"none\").each(function(t){var e=n.select(this),r=t.trace,o=r.line||{};e.call(a.stroke,o.color).call(i.dashLine,o.dash||\"\",o.width||0),\"none\"!==r.fill&&e.call(a.fill,r.fillcolor)})}(t,e)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../scatter/style\":1134,d3:163}],1160:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=t(\"./constants\").DASHES,c=i.line,u=i.marker,h=u.line,f=e.exports=s({x:i.x,x0:i.x0,dx:i.dx,y:i.y,y0:i.y0,dy:i.dy,text:i.text,hovertext:i.hovertext,textposition:i.textposition,textfont:i.textfont,mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"]},line:{color:c.color,width:c.width,shape:{valType:\"enumerated\",values:[\"linear\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},dash:{valType:\"enumerated\",values:Object.keys(l),dflt:\"solid\"}},marker:o({},a(\"marker\"),{symbol:u.symbol,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:o({},a(\"marker.line\"),{width:h.width})}),connectgaps:i.connectgaps,fill:o({},i.fill,{dflt:\"none\"}),fillcolor:i.fillcolor,selected:{marker:i.selected.marker,textfont:i.selected.textfont},unselected:{marker:i.unselected.marker,textfont:i.unselected.textfont},opacity:n.opacity},\"calc\",\"nested\");f.x.editType=f.y.editType=f.x0.editType=f.y0.editType=\"calc+clearAxisTypes\",f.hovertemplate=i.hovertemplate},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../scatter/attributes\":1112,\"./constants\":1162}],1161:[function(t,e,r){\"use strict\";var n=t(\"point-cluster\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../plots/cartesian/autorange\").findExtremes,s=t(\"../scatter/calc\"),l=s.calcMarkerSize,c=s.calcAxisExpansion,u=s.setFirstScatter,h=t(\"../scatter/colorscale_calc\"),f=t(\"./convert\"),p=t(\"./scene_update\"),d=t(\"../../constants/numerical\").BADNUM,g=t(\"./constants\").TOO_MANY_POINTS;function v(t,e,r){var n=t._extremes[e._id],i=o(e,r._bnds,{padded:!0});n.min=n.min.concat(i.min),n.max=n.max.concat(i.max)}e.exports=function(t,e){var r,o,s,m=t._fullLayout,y=a.getFromId(t,e.xaxis),x=a.getFromId(t,e.yaxis),b=m._plots[e.xaxis+e.yaxis],_=e._length,w=_>=g,k=2*_,T={},A=y.makeCalcdata(e,\"x\"),M=x.makeCalcdata(e,\"y\"),S=new Array(k);for(r=0;r<_;r++)o=A[r],s=M[r],S[2*r]=o===d?NaN:o,S[2*r+1]=s===d?NaN:s;if(\"log\"===y.type)for(r=0;r<k;r+=2)S[r]=y.c2l(S[r]);if(\"log\"===x.type)for(r=1;r<k;r+=2)S[r]=x.c2l(S[r]);if(w&&\"log\"!==y.type&&\"log\"!==x.type)T.tree=n(S);else{var E=T.ids=new Array(_);for(r=0;r<_;r++)E[r]=r}h(t,e);var C,L=function(t,e,r,n,a,o){var s=f.style(t,r);s.marker&&(s.marker.positions=n);s.line&&n.length>1&&i.extendFlat(s.line,f.linePositions(t,r,n));if(s.errorX||s.errorY){var l=f.errorBarPositions(t,r,n,a,o);s.errorX&&i.extendFlat(s.errorX,l.x),s.errorY&&i.extendFlat(s.errorY,l.y)}s.text&&(i.extendFlat(s.text,{positions:n},f.textPosition(t,r,s.text,s.marker)),i.extendFlat(s.textSel,{positions:n},f.textPosition(t,r,s.text,s.markerSel)),i.extendFlat(s.textUnsel,{positions:n},f.textPosition(t,r,s.text,s.markerUnsel)));return s}(t,0,e,S,A,M),P=p(t,b);return u(m,e),w?L.marker&&(C=2*(L.marker.sizeAvg||Math.max(L.marker.size,3))):C=l(e,_),c(t,e,y,x,A,M,C),L.errorX&&v(e,y,L.errorX),L.errorY&&v(e,x,L.errorY),L.fill&&!P.fill2d&&(P.fill2d=!0),L.marker&&!P.scatter2d&&(P.scatter2d=!0),L.line&&!P.line2d&&(P.line2d=!0),!L.errorX&&!L.errorY||P.error2d||(P.error2d=!0),L.text&&!P.glText&&(P.glText=!0),L.marker&&(L.marker.snap=T.tree||g),P.lineOptions.push(L.line),P.errorXOptions.push(L.errorX),P.errorYOptions.push(L.errorY),P.fillOptions.push(L.fill),P.markerOptions.push(L.marker),P.markerSelectedOptions.push(L.markerSel),P.markerUnselectedOptions.push(L.markerUnsel),P.textOptions.push(L.text),P.textSelectedOptions.push(L.textSel),P.textUnselectedOptions.push(L.textUnsel),P.selectBatch.push([]),P.unselectBatch.push([]),T._scene=P,T.index=P.count,T.x=A,T.y=M,T.positions=S,P.count++,[{x:!1,y:!1,t:T,trace:e}]}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/autorange\":766,\"../../plots/cartesian/axis_ids\":770,\"../scatter/calc\":1113,\"../scatter/colorscale_calc\":1115,\"./constants\":1162,\"./convert\":1163,\"./scene_update\":1169,\"point-cluster\":469}],1162:[function(t,e,r){\"use strict\";e.exports={TOO_MANY_POINTS:1e5,SYMBOL_SDF_SIZE:200,SYMBOL_SIZE:20,SYMBOL_STROKE:1,DOT_RE:/-dot/,OPEN_RE:/-open/,DASHES:{solid:[1],dot:[1,1],dash:[4,1],longdash:[8,1],dashdot:[4,1,1,1],longdashdot:[8,1,1,1]}}},{}],1163:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"svg-path-sdf\"),a=t(\"color-normalize\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../components/drawing\"),c=t(\"../../plots/cartesian/axis_ids\"),u=t(\"../../lib/gl_format_color\").formatColor,h=t(\"../scatter/subtypes\"),f=t(\"../scatter/make_bubble_size_func\"),p=t(\"./constants\"),d=t(\"../../constants/interactions\").DESELECTDIM,g={start:1,left:1,end:-1,right:-1,middle:0,center:0,bottom:1,top:-1};function v(t){var e,r=t._length,i=t.textfont,a=t.textposition,o=Array.isArray(a)?a:[a],s=i.color,l=i.size,c=i.family,u={};for(u.text=t.text,u.opacity=t.opacity,u.font={},u.align=[],u.baseline=[],e=0;e<o.length;e++){var h=o[e].split(/\\s+/);switch(h[1]){case\"left\":u.align.push(\"right\");break;case\"right\":u.align.push(\"left\");break;default:u.align.push(h[1])}switch(h[0]){case\"top\":u.baseline.push(\"bottom\");break;case\"bottom\":u.baseline.push(\"top\");break;default:u.baseline.push(h[0])}}if(Array.isArray(s))for(u.color=new Array(r),e=0;e<r;e++)u.color[e]=s[e];else u.color=s;if(Array.isArray(l)||Array.isArray(c))for(u.font=new Array(r),e=0;e<r;e++){var f=u.font[e]={};f.size=Array.isArray(l)?n(l[e])?l[e]:0:l,f.family=Array.isArray(c)?c[e]:c}else u.font={size:l,family:c};return u}function m(t){var e,r,n=t._length,i=t.marker,o={},l=Array.isArray(i.symbol),c=s.isArrayOrTypedArray(i.color),h=s.isArrayOrTypedArray(i.line.color),d=s.isArrayOrTypedArray(i.opacity),g=s.isArrayOrTypedArray(i.size),v=s.isArrayOrTypedArray(i.line.width);if(l||(r=p.OPEN_RE.test(i.symbol)),l||c||h||d){o.colors=new Array(n),o.borderColors=new Array(n);var m=u(i,i.opacity,n),y=u(i.line,i.opacity,n);if(!Array.isArray(y[0])){var x=y;for(y=Array(n),e=0;e<n;e++)y[e]=x}if(!Array.isArray(m[0])){var b=m;for(m=Array(n),e=0;e<n;e++)m[e]=b}for(o.colors=m,o.borderColors=y,e=0;e<n;e++){if(l){var _=i.symbol[e];r=p.OPEN_RE.test(_)}r&&(y[e]=m[e].slice(),m[e]=m[e].slice(),m[e][3]=0)}o.opacity=t.opacity}else r?(o.color=a(i.color,\"uint8\"),o.color[3]=0,o.borderColor=a(i.color,\"uint8\")):(o.color=a(i.color,\"uint8\"),o.borderColor=a(i.line.color,\"uint8\")),o.opacity=t.opacity*i.opacity;if(l)for(o.markers=new Array(n),e=0;e<n;e++)o.markers[e]=M(i.symbol[e]);else o.marker=M(i.symbol);var w,k=f(t);if(g||v){var T,A=o.sizes=new Array(n),S=o.borderSizes=new Array(n),E=0;if(g){for(e=0;e<n;e++)A[e]=k(i.size[e]),E+=A[e];T=E/n}else for(w=k(i.size),e=0;e<n;e++)A[e]=w;if(v)for(e=0;e<n;e++)S[e]=i.line.width[e]/2;else for(w=i.line.width/2,e=0;e<n;e++)S[e]=w;o.sizeAvg=T}else o.size=k(i&&i.size||10),o.borderSizes=k(i.line.width);return o}function y(t,e){var r=t.marker,n={};return e?(e.marker&&e.marker.symbol?n=m(s.extendFlat({},r,e.marker)):e.marker&&(e.marker.size&&(n.size=e.marker.size/2),e.marker.color&&(n.colors=e.marker.color),void 0!==e.marker.opacity&&(n.opacity=e.marker.opacity)),n):n}function x(t,e){var r={};if(!e)return r;if(e.textfont){var n={opacity:1,text:t.text,textposition:t.textposition,textfont:s.extendFlat({},t.textfont)};e.textfont&&s.extendFlat(n.textfont,e.textfont),r=v(n)}return r}function b(t,e){var r={capSize:2*e.width,lineWidth:e.thickness,color:e.color};return e.copy_ystyle&&(r=t.error_y),r}var _=p.SYMBOL_SDF_SIZE,w=p.SYMBOL_SIZE,k=p.SYMBOL_STROKE,T={},A=l.symbolFuncs[0](.05*w);function M(t){if(\"circle\"===t)return null;var e,r,n=l.symbolNumber(t),a=l.symbolFuncs[n%100],o=!!l.symbolNoDot[n%100],s=!!l.symbolNoFill[n%100],c=p.DOT_RE.test(t);return T[t]?T[t]:(e=c&&!o?a(1.1*w)+A:a(w),r=i(e,{w:_,h:_,viewBox:[-w,-w,w,w],stroke:s?k:-k}),T[t]=r,r||null)}e.exports={style:function(t,e){var r,n={marker:void 0,markerSel:void 0,markerUnsel:void 0,line:void 0,fill:void 0,errorX:void 0,errorY:void 0,text:void 0,textSel:void 0,textUnsel:void 0};if(!0!==e.visible)return n;if(h.hasText(e)&&(n.text=v(e),n.textSel=x(e,e.selected),n.textUnsel=x(e,e.unselected)),h.hasMarkers(e)&&(n.marker=m(e),n.markerSel=y(e,e.selected),n.markerUnsel=y(e,e.unselected),!e.unselected&&Array.isArray(e.marker.opacity))){var i=e.marker.opacity;for(n.markerUnsel.opacity=new Array(i.length),r=0;r<i.length;r++)n.markerUnsel.opacity[r]=d*i[r]}if(h.hasLines(e)){n.line={overlay:!0,thickness:e.line.width,color:e.line.color,opacity:e.opacity};var a=(p.DASHES[e.line.dash]||[1]).slice();for(r=0;r<a.length;++r)a[r]*=e.line.width;n.line.dashes=a}return e.error_x&&e.error_x.visible&&(n.errorX=b(e,e.error_x)),e.error_y&&e.error_y.visible&&(n.errorY=b(e,e.error_y)),e.fill&&\"none\"!==e.fill&&(n.fill={closed:!0,fill:e.fillcolor,thickness:0}),n},markerStyle:m,markerSelection:y,linePositions:function(t,e,r){var n,i,a=r.length,o=a/2;if(h.hasLines(e)&&o)if(\"hv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i+2],r[2*i+1]));n.push(r[a-2],r[a-1])}else if(\"hvh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var s=(r[2*i]+r[2*i+2])/2;n.push(r[2*i],r[2*i+1],s,r[2*i+1],s,r[2*i+3])}n.push(r[a-2],r[a-1])}else if(\"vhv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var l=(r[2*i+1]+r[2*i+3])/2;n.push(r[2*i],r[2*i+1],r[2*i],l,r[2*i+2],l)}n.push(r[a-2],r[a-1])}else if(\"vh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+3]));n.push(r[a-2],r[a-1])}else n=r;var c=!1;for(i=0;i<n.length;i++)if(isNaN(n[i])){c=!0;break}var u=c||n.length>p.TOO_MANY_POINTS?\"rect\":h.hasMarkers(e)?\"rect\":\"round\";if(c&&e.connectgaps){var f=n[0],d=n[1];for(i=0;i<n.length;i+=2)isNaN(n[i])||isNaN(n[i+1])?(n[i]=f,n[i+1]=d):(f=n[i],d=n[i+1])}return{join:u,positions:n}},errorBarPositions:function(t,e,r,i,a){var s=o.getComponentMethod(\"errorbars\",\"makeComputeError\"),l=c.getFromId(t,e.xaxis),u=c.getFromId(t,e.yaxis),h=r.length/2,f={};function p(t,i){var a=i._id.charAt(0),o=e[\"error_\"+a];if(o&&o.visible&&(\"linear\"===i.type||\"log\"===i.type)){for(var l=s(o),c={x:0,y:1}[a],u={x:[0,1,2,3],y:[2,3,0,1]}[a],p=new Float64Array(4*h),d=1/0,g=-1/0,v=0,m=0;v<h;v++,m+=4){var y=t[v];if(n(y)){var x=r[2*v+c],b=l(y,v),_=b[0],w=b[1];if(n(_)&&n(w)){var k=y-_,T=y+w;p[m+u[0]]=x-i.c2l(k),p[m+u[1]]=i.c2l(T)-x,p[m+u[2]]=0,p[m+u[3]]=0,d=Math.min(d,y-_),g=Math.max(g,y+w)}}}f[a]={positions:r,errors:p,_bnds:[d,g]}}}return p(i,l),p(a,u),f},textPosition:function(t,e,r,n){var i,a=e._length,o={};if(h.hasMarkers(e)){var s=r.font,l=r.align,c=r.baseline;for(o.offset=new Array(a),i=0;i<a;i++){var u=n.sizes?n.sizes[i]:n.size,f=Array.isArray(s)?s[i].size:s.size,p=Array.isArray(l)?l.length>1?l[i]:l[0]:l,d=Array.isArray(c)?c.length>1?c[i]:c[0]:c,v=g[p],m=g[d],y=u?u/.8+1:0,x=-m*y-.5*m;o.offset[i]=[v*y/f,x/f]}}return o}}},{\"../../components/drawing\":614,\"../../constants/interactions\":694,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../scatter/make_bubble_size_func\":1128,\"../scatter/subtypes\":1135,\"./constants\":1162,\"color-normalize\":120,\"fast-isnumeric\":225,\"svg-path-sdf\":535}],1164:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"../scatter/constants\"),s=t(\"../scatter/subtypes\"),l=t(\"../scatter/xy_defaults\"),c=t(\"../scatter/marker_defaults\"),u=t(\"../scatter/line_defaults\"),h=t(\"../scatter/fillcolor_defaults\"),f=t(\"../scatter/text_defaults\");e.exports=function(t,e,r,p){function d(r,i){return n.coerce(t,e,a,r,i)}var g=!!t.marker&&/-open/.test(t.marker.symbol),v=s.isBubble(t),m=l(t,e,p,d);if(m){var y=m<o.PTS_LINESONLY?\"lines+markers\":\"lines\";d(\"text\"),d(\"hovertext\"),d(\"hovertemplate\"),d(\"mode\",y),s.hasLines(e)&&(d(\"connectgaps\"),u(t,e,r,p,d),d(\"line.shape\")),s.hasMarkers(e)&&(c(t,e,r,p,d),d(\"marker.line.width\",g||v?1:0)),s.hasText(e)&&f(t,e,p,d);var x=(e.line||{}).color,b=(e.marker||{}).color;d(\"fill\"),\"none\"!==e.fill&&h(t,e,r,d);var _=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");_(t,e,x||b||r,{axis:\"y\"}),_(t,e,x||b||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}},{\"../../lib\":719,\"../../registry\":847,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"../scatter/xy_defaults\":1137,\"./attributes\":1160}],1165:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../constants/interactions\").DESELECTDIM;e.exports={styleTextSelection:function(t){var e,r,o=t[0],s=o.trace,l=o.t,c=l._scene,u=l.index,h=c.selectBatch[u],f=c.unselectBatch[u],p=c.textOptions[u],d=c.textSelectedOptions[u]||{},g=c.textUnselectedOptions[u]||{},v=n.extendFlat({},p);if(h.length||f.length){var m=d.color,y=g.color,x=p.color,b=Array.isArray(x);for(v.color=new Array(s._length),e=0;e<h.length;e++)r=h[e],v.color[r]=m||(b?x[r]:x);for(e=0;e<f.length;e++){r=f[e];var _=b?x[r]:x;v.color[r]=y||(m?_:i.addOpacity(_,a))}}c.glText[u].update(v)}}},{\"../../components/color\":593,\"../../constants/interactions\":694,\"../../lib\":719}],1166:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\");function o(t,e,r,o){var s=t.xa,l=t.ya,c=t.distance,u=t.dxy,h=t.index,f={pointNumber:h,x:e[h],y:r[h]};f.tx=Array.isArray(o.text)?o.text[h]:o.text,f.htx=Array.isArray(o.hovertext)?o.hovertext[h]:o.hovertext,f.data=Array.isArray(o.customdata)?o.customdata[h]:o.customdata,f.tp=Array.isArray(o.textposition)?o.textposition[h]:o.textposition;var p=o.textfont;p&&(f.ts=Array.isArray(p.size)?p.size[h]:p.size,f.tc=Array.isArray(p.color)?p.color[h]:p.color,f.tf=Array.isArray(p.family)?p.family[h]:p.family);var d=o.marker;d&&(f.ms=i.isArrayOrTypedArray(d.size)?d.size[h]:d.size,f.mo=i.isArrayOrTypedArray(d.opacity)?d.opacity[h]:d.opacity,f.mx=Array.isArray(d.symbol)?d.symbol[h]:d.symbol,f.mc=i.isArrayOrTypedArray(d.color)?d.color[h]:d.color);var g=d&&d.line;g&&(f.mlc=Array.isArray(g.color)?g.color[h]:g.color,f.mlw=i.isArrayOrTypedArray(g.width)?g.width[h]:g.width);var v=d&&d.gradient;v&&\"none\"!==v.type&&(f.mgt=Array.isArray(v.type)?v.type[h]:v.type,f.mgc=Array.isArray(v.color)?v.color[h]:v.color);var m=s.c2p(f.x,!0),y=l.c2p(f.y,!0),x=f.mrc||1,b=o.hoverlabel;b&&(f.hbg=Array.isArray(b.bgcolor)?b.bgcolor[h]:b.bgcolor,f.hbc=Array.isArray(b.bordercolor)?b.bordercolor[h]:b.bordercolor,f.hts=Array.isArray(b.font.size)?b.font.size[h]:b.font.size,f.htc=Array.isArray(b.font.color)?b.font.color[h]:b.font.color,f.htf=Array.isArray(b.font.family)?b.font.family[h]:b.font.family,f.hnl=Array.isArray(b.namelength)?b.namelength[h]:b.namelength);var _=o.hoverinfo;_&&(f.hi=Array.isArray(_)?_[h]:_);var w=o.hovertemplate;w&&(f.ht=Array.isArray(w)?w[h]:w);var k={};return k[t.index]=f,i.extendFlat(t,{color:a(o,f),x0:m-x,x1:m+x,xLabelVal:f.x,y0:y-x,y1:y+x,yLabelVal:f.y,cd:k,distance:c,spikeDistance:u,hovertemplate:f.ht}),f.htx?t.text=f.htx:f.tx?t.text=f.tx:o.text&&(t.text=o.text),i.fillText(f,o,t),n.getComponentMethod(\"errorbars\",\"hoverInfo\")(f,o,t),t}e.exports={hoverPoints:function(t,e,r,n){var i,a,s,l,c,u,h,f,p,d=t.cd,g=d[0].t,v=d[0].trace,m=t.xa,y=t.ya,x=g.x,b=g.y,_=m.c2p(e),w=y.c2p(r),k=t.distance;if(g.tree){var T=m.p2c(_-k),A=m.p2c(_+k),M=y.p2c(w-k),S=y.p2c(w+k);i=\"x\"===n?g.tree.range(Math.min(T,A),Math.min(y._rl[0],y._rl[1]),Math.max(T,A),Math.max(y._rl[0],y._rl[1])):g.tree.range(Math.min(T,A),Math.min(M,S),Math.max(T,A),Math.max(M,S))}else{if(!g.ids)return[t];i=g.ids}var E=k;if(\"x\"===n)for(c=0;c<i.length;c++)s=x[i[c]],(u=Math.abs(m.c2p(s)-_))<E&&(E=u,h=y.c2p(b[i[c]])-w,p=Math.sqrt(u*u+h*h),a=i[c]);else for(c=i.length-1;c>-1;c--)s=x[i[c]],l=b[i[c]],u=m.c2p(s)-_,h=y.c2p(l)-w,(f=Math.sqrt(u*u+h*h))<E&&(E=p=f,a=i[c]);return t.index=a,t.distance=E,t.dxy=p,void 0===a?[t]:(o(t,x,b,v),[t])},calcHover:o}},{\"../../lib\":719,\"../../registry\":847,\"../scatter/get_trace_color\":1121}],1167:[function(t,e,r){\"use strict\";var n=t(\"./hover\");e.exports={moduleType:\"trace\",name:\"scattergl\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../scatter/cross_trace_defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:n.hoverPoints,selectPoints:t(\"./select\"),meta:{}}},{\"../../plots/cartesian\":778,\"../scatter/cross_trace_defaults\":1118,\"../scatter/marker_colorbar\":1129,\"./attributes\":1160,\"./calc\":1161,\"./defaults\":1164,\"./hover\":1166,\"./plot\":1168,\"./select\":1170}],1168:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"regl-line2d\"),a=t(\"regl-error2d\"),o=t(\"gl-text\"),s=t(\"../../lib\"),l=t(\"../../lib/prepare_regl\"),c=t(\"../scatter/subtypes\"),u=t(\"../scatter/link_traces\"),h=t(\"./edit_style\").styleTextSelection;e.exports=function(t,e,r){if(r.length){var f,p,d=t._fullLayout,g=e._scene,v=e.xaxis,m=e.yaxis;if(g)if(l(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])){var y=g.count,x=d._glcanvas.data()[0].regl;if(u(t,e,r),g.dirty){if(!0===g.error2d&&(g.error2d=a(x)),!0===g.line2d&&(g.line2d=i(x)),!0===g.scatter2d&&(g.scatter2d=n(x)),!0===g.fill2d&&(g.fill2d=i(x)),!0===g.glText)for(g.glText=new Array(y),f=0;f<y;f++)g.glText[f]=new o(x);if(g.glText){if(y>g.glText.length){var b=y-g.glText.length;for(f=0;f<b;f++)g.glText.push(new o(x))}else if(y<g.glText.length){var _=g.glText.length-y;g.glText.splice(y,_).forEach(function(t){t.destroy()})}for(f=0;f<y;f++)g.glText[f].update(g.textOptions[f])}if(g.line2d&&(g.line2d.update(g.lineOptions),g.lineOptions=g.lineOptions.map(function(t){if(t&&t.positions){for(var e=t.positions,r=0;r<e.length&&(isNaN(e[r])||isNaN(e[r+1]));)r+=2;for(var n=e.length-2;n>r&&(isNaN(e[n])||isNaN(e[n+1]));)n-=2;t.positions=e.slice(r,n+2)}return t}),g.line2d.update(g.lineOptions)),g.error2d){var w=(g.errorXOptions||[]).concat(g.errorYOptions||[]);g.error2d.update(w)}g.scatter2d&&g.scatter2d.update(g.markerOptions),g.fillOrder=s.repeat(null,y),g.fill2d&&(g.fillOptions=g.fillOptions.map(function(t,e){var n=r[e];if(t&&n&&n[0]&&n[0].trace){var i,a,o=n[0],s=o.trace,l=o.t,c=g.lineOptions[e],u=[];s._ownfill&&u.push(e),s._nexttrace&&u.push(e+1),u.length&&(g.fillOrder[e]=u);var h,f,p=[],d=c&&c.positions||l.positions;if(\"tozeroy\"===s.fill){for(h=0;h<d.length&&isNaN(d[h+1]);)h+=2;for(f=d.length-2;f>h&&isNaN(d[f+1]);)f-=2;0!==d[h+1]&&(p=[d[h],0]),p=p.concat(d.slice(h,f+2)),0!==d[f+1]&&(p=p.concat([d[f],0]))}else if(\"tozerox\"===s.fill){for(h=0;h<d.length&&isNaN(d[h]);)h+=2;for(f=d.length-2;f>h&&isNaN(d[f]);)f-=2;0!==d[h]&&(p=[0,d[h+1]]),p=p.concat(d.slice(h,f+2)),0!==d[f]&&(p=p.concat([0,d[f+1]]))}else if(\"toself\"===s.fill||\"tonext\"===s.fill){for(p=[],i=0,a=0;a<d.length;a+=2)(isNaN(d[a])||isNaN(d[a+1]))&&((p=p.concat(d.slice(i,a))).push(d[i],d[i+1]),i=a+2);p=p.concat(d.slice(i)),i&&p.push(d[i],d[i+1])}else{var v=s._nexttrace;if(v){var m=g.lineOptions[e+1];if(m){var y=m.positions;if(\"tonexty\"===s.fill){for(p=d.slice(),e=Math.floor(y.length/2);e--;){var x=y[2*e],b=y[2*e+1];isNaN(x)||isNaN(b)||p.push(x,b)}t.fill=v.fillcolor}}}}if(s._prevtrace&&\"tonext\"===s._prevtrace.fill){var _=g.lineOptions[e-1].positions,w=p.length/2,k=[i=w];for(a=0;a<_.length;a+=2)(isNaN(_[a])||isNaN(_[a+1]))&&(k.push(a/2+w+1),i=a+2);p=p.concat(_),t.hole=k}return t.fillmode=s.fill,t.opacity=s.opacity,t.positions=p,t}}),g.fill2d.update(g.fillOptions))}var k=d.dragmode,T=\"lasso\"===k||\"select\"===k,A=d.clickmode.indexOf(\"select\")>-1;for(f=0;f<y;f++){var M=r[f][0],S=M.trace,E=M.t,C=E.index,L=S._length,P=E.x,O=E.y;if(S.selectedpoints||T||A){if(T||(T=!0),S.selectedpoints){var z=g.selectBatch[C]=s.selIndices2selPoints(S),I={};for(p=0;p<z.length;p++)I[z[p]]=1;var D=[];for(p=0;p<L;p++)I[p]||D.push(p);g.unselectBatch[C]=D}var R=E.xpx=new Array(L),F=E.ypx=new Array(L);for(p=0;p<L;p++)R[p]=v.c2p(P[p]),F[p]=m.c2p(O[p])}else E.xpx=E.ypx=null}if(T){if(g.select2d||(g.select2d=n(d._glcanvas.data()[1].regl)),g.scatter2d){var B=new Array(y);for(f=0;f<y;f++)B[f]=g.selectBatch[f].length||g.unselectBatch[f].length?g.markerUnselectedOptions[f]:{};g.scatter2d.update(B)}g.select2d&&(g.select2d.update(g.markerOptions),g.select2d.update(g.markerSelectedOptions)),g.glText&&r.forEach(function(t){var e=((t||[])[0]||{}).trace||{};c.hasText(e)&&h(t)})}else g.scatter2d&&g.scatter2d.update(g.markerOptions);var N={viewport:function(t,e,r){var n=t._size,i=t.width,a=t.height;return[n.l+e.domain[0]*n.w,n.b+r.domain[0]*n.h,i-n.r-(1-e.domain[1])*n.w,a-n.t-(1-r.domain[1])*n.h]}(d,v,m),range:[(v._rl||v.range)[0],(m._rl||m.range)[0],(v._rl||v.range)[1],(m._rl||m.range)[1]]},j=s.repeat(N,g.count);g.fill2d&&g.fill2d.update(j),g.line2d&&g.line2d.update(j),g.error2d&&g.error2d.update(j.concat(j)),g.scatter2d&&g.scatter2d.update(j),g.select2d&&g.select2d.update(j),g.glText&&g.glText.forEach(function(t){t.update(N)})}else g.init()}}},{\"../../lib\":719,\"../../lib/prepare_regl\":732,\"../scatter/link_traces\":1127,\"../scatter/subtypes\":1135,\"./edit_style\":1165,\"gl-text\":317,\"regl-error2d\":490,\"regl-line2d\":491,\"regl-scatter2d\":497}],1169:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=e._scene,i={count:0,dirty:!0,lineOptions:[],fillOptions:[],markerOptions:[],markerSelectedOptions:[],markerUnselectedOptions:[],errorXOptions:[],errorYOptions:[],textOptions:[],textSelectedOptions:[],textUnselectedOptions:[],selectBatch:[],unselectBatch:[]},a={fill2d:!1,scatter2d:!1,error2d:!1,line2d:!1,glText:!1,select2d:!1};return e._scene||((r=e._scene={}).init=function(){n.extendFlat(r,a,i)},r.init(),r.update=function(t){var e=n.repeat(t,r.count);if(r.fill2d&&r.fill2d.update(e),r.scatter2d&&r.scatter2d.update(e),r.line2d&&r.line2d.update(e),r.error2d&&r.error2d.update(e.concat(e)),r.select2d&&r.select2d.update(e),r.glText)for(var i=0;i<r.count;i++)r.glText[i].update(t)},r.draw=function(){for(var t=r.count,e=r.fill2d,i=r.error2d,a=r.line2d,o=r.scatter2d,s=r.glText,l=r.select2d,c=r.selectBatch,u=r.unselectBatch,h=0;h<t;h++){if(e&&r.fillOrder[h]&&e.draw(r.fillOrder[h]),a&&r.lineOptions[h]&&a.draw(h),i&&(r.errorXOptions[h]&&i.draw(h),r.errorYOptions[h]&&i.draw(h+t)),o&&r.markerOptions[h])if(u[h].length){var f=n.repeat([],r.count);f[h]=u[h],o.draw(f)}else c[h].length||o.draw(h);s[h]&&r.textOptions[h]&&s[h].render()}l&&l.draw(c),r.dirty=!1},r.destroy=function(){r.fill2d&&r.fill2d.destroy&&r.fill2d.destroy(),r.scatter2d&&r.scatter2d.destroy&&r.scatter2d.destroy(),r.error2d&&r.error2d.destroy&&r.error2d.destroy(),r.line2d&&r.line2d.destroy&&r.line2d.destroy(),r.select2d&&r.select2d.destroy&&r.select2d.destroy(),r.glText&&r.glText.forEach(function(t){t.destroy&&t.destroy()}),r.lineOptions=null,r.fillOptions=null,r.markerOptions=null,r.markerSelectedOptions=null,r.markerUnselectedOptions=null,r.errorXOptions=null,r.errorYOptions=null,r.textOptions=null,r.textSelectedOptions=null,r.textUnselectedOptions=null,r.selectBatch=null,r.unselectBatch=null,e._scene=null}),r.dirty||n.extendFlat(r,i),r}},{\"../../lib\":719}],1170:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"./edit_style\").styleTextSelection;e.exports=function(t,e){var r=t.cd,a=[],o=r[0].trace,s=r[0].t,l=o._length,c=s.x,u=s.y,h=s._scene,f=s.index;if(!h)return a;var p=n.hasText(o),d=n.hasMarkers(o),g=!d&&!p;if(!0!==o.visible||g)return a;var v=[],m=[];if(!1!==e&&!e.degenerate)for(var y=0;y<l;y++)e.contains([s.xpx[y],s.ypx[y]],!1,y,t)?(v.push(y),a.push({pointNumber:y,x:c[y],y:u[y]})):m.push(y);if(d){var x=h.scatter2d;if(v.length||m.length){if(!h.selectBatch[f].length&&!h.unselectBatch[f].length){var b=new Array(h.count);b[f]=h.markerUnselectedOptions[f],x.update.apply(x,b)}}else{var _=new Array(h.count);_[f]=h.markerOptions[f],x.update.apply(x,_)}}return h.selectBatch[f]=v,h.unselectBatch[f]=m,p&&i(r),a}},{\"../scatter/subtypes\":1135,\"./edit_style\":1165}],1171:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scattergeo/attributes\"),a=t(\"../scatter/attributes\"),o=t(\"../../plots/mapbox/layout_attributes\"),s=t(\"../../plots/attributes\"),l=t(\"../../components/colorscale/attributes\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../plot_api/edit_types\").overrideAll,h=i.line,f=i.marker;e.exports=u({lon:i.lon,lat:i.lat,mode:c({},a.mode,{dflt:\"markers\"}),text:c({},a.text,{}),hovertext:c({},a.hovertext,{}),line:{color:h.color,width:h.width},connectgaps:a.connectgaps,marker:c({symbol:{valType:\"string\",dflt:\"circle\",arrayOk:!0},opacity:f.opacity,size:f.size,sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode},l(\"marker\")),fill:i.fill,fillcolor:a.fillcolor,textfont:o.layers.symbol.textfont,textposition:o.layers.symbol.textposition,below:{valType:\"string\"},selected:{marker:a.selected.marker},unselected:{marker:a.unselected.marker},hoverinfo:c({},s.hoverinfo,{flags:[\"lon\",\"lat\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../../plots/mapbox/layout_attributes\":824,\"../scatter/attributes\":1112,\"../scattergeo/attributes\":1151}],1172:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../lib/geojson_utils\"),s=t(\"../../components/colorscale\"),l=t(\"../../components/drawing\"),c=t(\"../scatter/make_bubble_size_func\"),u=t(\"../scatter/subtypes\"),h=t(\"../../plots/mapbox/convert_text_opts\");function f(){return{geojson:o.makeBlank(),layout:{visibility:\"none\"},paint:{}}}function p(t){return i.isArrayOrTypedArray(t)?function(t){return t}:t?function(){return t}:d}function d(){return\"\"}function g(t){return t[0]===a}e.exports=function(t){var e,r=t[0].trace,a=!0===r.visible&&0!==r._length,v=\"none\"!==r.fill,m=u.hasLines(r),y=u.hasMarkers(r),x=u.hasText(r),b=y&&\"circle\"===r.marker.symbol,_=y&&\"circle\"!==r.marker.symbol,w=f(),k=f(),T=f(),A=f(),M={fill:w,line:k,circle:T,symbol:A};if(!a)return M;if((v||m)&&(e=o.calcTraceToLineCoords(t)),v&&(w.geojson=o.makePolygon(e),w.layout.visibility=\"visible\",i.extendFlat(w.paint,{\"fill-color\":r.fillcolor})),m&&(k.geojson=o.makeLine(e),k.layout.visibility=\"visible\",i.extendFlat(k.paint,{\"line-width\":r.line.width,\"line-color\":r.line.color,\"line-opacity\":r.opacity})),b){var S=function(t){var e,r,a,o,u=t[0].trace,h=u.marker,f=u.selectedpoints,p=i.isArrayOrTypedArray(h.color),d=i.isArrayOrTypedArray(h.size),v=i.isArrayOrTypedArray(h.opacity);function m(t){return u.opacity*t}p&&(r=s.hasColorscale(u,\"marker\")?s.makeColorScaleFuncFromTrace(h):i.identity);d&&(a=c(u));v&&(o=function(t){var e=n(t)?+i.constrain(t,0,1):0;return m(e)});var y,x=[];for(e=0;e<t.length;e++){var b=t[e],_=b.lonlat;if(!g(_)){var w={};r&&(w.mcc=b.mcc=r(b.mc)),a&&(w.mrc=b.mrc=a(b.ms)),o&&(w.mo=o(b.mo)),f&&(w.selected=b.selected||0),x.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:_},properties:w})}}if(f)for(y=l.makeSelectedPointStyleFns(u),e=0;e<x.length;e++){var k=x[e].properties;y.selectedOpacityFn&&(k.mo=m(y.selectedOpacityFn(k))),y.selectedColorFn&&(k.mcc=y.selectedColorFn(k)),y.selectedSizeFn&&(k.mrc=y.selectedSizeFn(k))}return{geojson:{type:\"FeatureCollection\",features:x},mcc:p||y&&y.selectedColorFn?{type:\"identity\",property:\"mcc\"}:h.color,mrc:d||y&&y.selectedSizeFn?{type:\"identity\",property:\"mrc\"}:(T=h.size,T/2),mo:v||y&&y.selectedOpacityFn?{type:\"identity\",property:\"mo\"}:m(h.opacity)};var T}(t);T.geojson=S.geojson,T.layout.visibility=\"visible\",i.extendFlat(T.paint,{\"circle-color\":S.mcc,\"circle-radius\":S.mrc,\"circle-opacity\":S.mo})}if((_||x)&&(A.geojson=function(t){for(var e=t[0].trace,r=(e.marker||{}).symbol,n=e.text,i=\"circle\"!==r?p(r):d,a=u.hasText(e)?p(n):d,o=[],s=0;s<t.length;s++){var l=t[s];g(l.lonlat)||o.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:l.lonlat},properties:{symbol:i(l.mx),text:a(l.tx)}})}return{type:\"FeatureCollection\",features:o}}(t),i.extendFlat(A.layout,{visibility:\"visible\",\"icon-image\":\"{symbol}-15\",\"text-field\":\"{text}\"}),_&&(i.extendFlat(A.layout,{\"icon-size\":r.marker.size/10}),i.extendFlat(A.paint,{\"icon-opacity\":r.opacity*r.marker.opacity,\"icon-color\":r.marker.color})),x)){var E=(r.marker||{}).size,C=h(r.textposition,E);i.extendFlat(A.layout,{\"text-size\":r.textfont.size,\"text-anchor\":C.anchor,\"text-offset\":C.offset}),i.extendFlat(A.paint,{\"text-color\":r.textfont.color,\"text-opacity\":r.opacity})}return M}},{\"../../components/colorscale\":605,\"../../components/drawing\":614,\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/geojson_utils\":714,\"../../plots/mapbox/convert_text_opts\":821,\"../scatter/make_bubble_size_func\":1128,\"../scatter/subtypes\":1135,\"fast-isnumeric\":225}],1173:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,i){return n.coerce(t,e,c,r,i)}if(function(t,e,r){var n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length);return e._length=a,a}(0,e,h)){if(h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),h(\"below\"),i.hasLines(e)&&(o(t,e,r,u,h,{noDash:!0}),h(\"connectgaps\")),i.hasMarkers(e)){a(t,e,r,u,h,{noLine:!0});var f=e.marker;\"circle\"!==f.symbol&&(n.isArrayOrTypedArray(f.size)&&(f.size=f.size[0]),n.isArrayOrTypedArray(f.color)&&(f.color=f.color[0]))}i.hasText(e)&&s(t,e,u,h,{noSelect:!0}),h(\"fill\"),\"none\"!==e.fill&&l(t,e,r,h),n.coerceSelectionMarkerOpacity(e,h)}else e.visible=!1}},{\"../../lib\":719,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1171}],1174:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t}},{}],1175:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\"),o=i.fillText,s=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,h=t.ya,f=t.subplot,p=360*(e>=0?Math.floor((e+180)/360):Math.ceil((e-180)/360)),d=e-p;if(n.getClosest(l,function(t){var e=t.lonlat;if(e[0]===s)return 1/0;var n=i.modHalf(e[0],360),a=e[1],o=f.project([n,a]),l=o.x-u.c2p([d,a]),c=o.y-h.c2p([n,r]),p=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(l*l+c*c)-p,1-3/p)},t),!1!==t.index){var g=l[t.index],v=g.lonlat,m=[i.modHalf(v[0],360)+p,v[1]],y=u.c2p(m),x=h.c2p(m),b=g.mrc||1;return t.x0=y-b,t.x1=y+b,t.y0=x-b,t.y1=x+b,t.color=a(c,g),t.extraText=function(t,e,r){if(t.hovertemplate)return;var n=(e.hi||t.hoverinfo).split(\"+\"),i=-1!==n.indexOf(\"all\"),a=-1!==n.indexOf(\"lon\"),s=-1!==n.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}i||a&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):a?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(i||-1!==n.indexOf(\"text\"))&&o(e,t,c);return c.join(\"<br>\")}(c,g,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},{\"../../components/fx\":632,\"../../constants/numerical\":695,\"../../lib\":719,\"../scatter/get_trace_color\":1121}],1176:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"../scattergeo/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.update(e)},moduleType:\"trace\",name:\"scattermapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"symbols\",\"showLegend\",\"scatterlike\"],meta:{}}},{\"../../plots/mapbox\":822,\"../scatter/marker_colorbar\":1129,\"../scattergeo/calc\":1152,\"./attributes\":1171,\"./defaults\":1173,\"./event_data\":1174,\"./hover\":1175,\"./plot\":1177,\"./select\":1178}],1177:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix,a=[\"fill\",\"line\",\"circle\",\"symbol\"];function o(t,e){this.subplot=t,this.uid=e,this.sourceIds={fill:\"source-\"+e+\"-fill\",line:\"source-\"+e+\"-line\",circle:\"source-\"+e+\"-circle\",symbol:\"source-\"+e+\"-symbol\"},this.layerIds={fill:i+e+\"-fill\",line:i+e+\"-line\",circle:i+e+\"-circle\",symbol:i+e+\"-symbol\"},this.below=null}var s=o.prototype;s.addSource=function(t,e){this.subplot.map.addSource(this.sourceIds[t],{type:\"geojson\",data:e.geojson})},s.setSourceData=function(t,e){this.subplot.map.getSource(this.sourceIds[t]).setData(e.geojson)},s.addLayer=function(t,e,r){this.subplot.addLayer({type:t,id:this.layerIds[t],source:this.sourceIds[t],layout:e.layout,paint:e.paint},r)},s.update=function(t){var e,r,i,o=this.subplot,s=o.map,l=n(t),c=o.belowLookup[\"trace-\"+this.uid];if(c!==this.below){for(e=a.length-1;e>=0;e--)r=a[e],s.removeLayer(this.layerIds[r]);for(e=0;e<a.length;e++)i=l[r=a[e]],this.addLayer(r,i,c);this.below=c}for(e=0;e<a.length;e++)i=l[r=a[e]],o.setOptions(this.layerIds[r],\"setLayoutProperty\",i.layout),\"visible\"===i.layout.visibility&&(this.setSourceData(r,i),o.setOptions(this.layerIds[r],\"setPaintProperty\",i.paint));t[0].trace._glTrace=this},s.dispose=function(){for(var t=this.subplot.map,e=a.length-1;e>=0;e--){var r=a[e];t.removeLayer(this.layerIds[r]),t.removeSource(this.sourceIds[r])}},e.exports=function(t,e){for(var r=e[0].trace,i=new o(t,r.uid),s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid],c=0;c<a.length;c++){var u=a[c],h=s[u];i.addSource(u,h),i.addLayer(u,h,l)}return e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":820,\"./convert\":1172}],1178:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,o=t.cd,s=t.xaxis,l=t.yaxis,c=[],u=o[0].trace;if(!i.hasMarkers(u))return[];if(!1===e)for(r=0;r<o.length;r++)o[r].selected=0;else for(r=0;r<o.length;r++){var h=o[r],f=h.lonlat;if(f[0]!==a){var p=[n.modHalf(f[0],360),f[1]],d=[s.c2p(p),l.c2p(p)];e.contains(d,null,r,t)?(c.push({pointNumber:r,lon:f[0],lat:f[1]}),h.selected=1):h.selected=0}}return c}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../scatter/subtypes\":1135}],1179:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../scatter/attributes\"),o=t(\"../../plots/attributes\"),s=a.line;e.exports={mode:a.mode,r:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},theta:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},r0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dr:{valType:\"number\",dflt:1,editType:\"calc\"},theta0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dtheta:{valType:\"number\",editType:\"calc\"},thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\",\"gradians\"],dflt:\"degrees\",editType:\"calc+clearAxisTypes\"},text:a.text,hovertext:a.hovertext,line:{color:s.color,width:s.width,dash:s.dash,shape:i({},s.shape,{values:[\"linear\",\"spline\"]}),smoothing:s.smoothing,editType:\"calc\"},connectgaps:a.connectgaps,marker:a.marker,cliponaxis:i({},a.cliponaxis,{dflt:!1}),textposition:a.textposition,textfont:a.textfont,fill:i({},a.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:a.fillcolor,hoverinfo:i({},o.hoverinfo,{flags:[\"r\",\"theta\",\"text\",\"name\"]}),hoveron:a.hoveron,hovertemplate:n(),selected:a.selected,unselected:a.unselected}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1180:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../plots/cartesian/axes\"),o=t(\"../scatter/colorscale_calc\"),s=t(\"../scatter/arrays_to_calcdata\"),l=t(\"../scatter/calc_selection\"),c=t(\"../scatter/calc\").calcMarkerSize;e.exports=function(t,e){for(var r=t._fullLayout,u=e.subplot,h=r[u].radialaxis,f=r[u].angularaxis,p=h.makeCalcdata(e,\"r\"),d=f.makeCalcdata(e,\"theta\"),g=e._length,v=new Array(g),m=0;m<g;m++){var y=p[m],x=d[m],b=v[m]={};n(y)&&n(x)?(b.r=y,b.theta=x):b.r=i}var _=c(e,g);return e._extremes.x=a.findExtremes(h,p,{ppad:_}),o(t,e),s(v,e),l(v,e),v}},{\"../../constants/numerical\":695,\"../../plots/cartesian/axes\":767,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc\":1113,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1181:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/line_shape_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,h=t(\"./attributes\");function f(t,e,r,n){var i,a=n(\"r\"),o=n(\"theta\");if(a)o?i=Math.min(a.length,o.length):(i=a.length,n(\"theta0\"),n(\"dtheta\"));else{if(!o)return 0;i=e.theta.length,n(\"r0\"),n(\"dr\")}return e._length=i,i}e.exports={handleRThetaDefaults:f,supplyDefaults:function(t,e,r,p){function d(r,i){return n.coerce(t,e,h,r,i)}var g=f(0,e,0,d);if(g){d(\"thetaunit\"),d(\"mode\",g<u?\"lines+markers\":\"lines\"),d(\"text\"),d(\"hovertext\"),\"fills\"!==e.hoveron&&d(\"hovertemplate\"),i.hasLines(e)&&(o(t,e,r,p,d),s(t,e,d),d(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,p,d,{gradient:!0}),i.hasText(e)&&l(t,e,p,d);var v=[];(i.hasMarkers(e)||i.hasText(e))&&(d(\"cliponaxis\"),d(\"marker.maxdisplayed\"),v.push(\"points\")),d(\"fill\"),\"none\"!==e.fill&&(c(t,e,r,d),i.hasLines(e)||s(t,e,d)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||v.push(\"fills\"),d(\"hoveron\",v.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/line_shape_defaults\":1126,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1179}],1182:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\");function o(t,e,r,n){var o=r.radialAxis,s=r.angularAxis;o._hovertitle=\"r\",s._hovertitle=\"\\u03b8\";var l=o.c2l(t.r);n.rLabel=i.tickText(o,l,\"hover\").text;var c=\"degrees\"===s.thetaunit?a.rad2deg(t.theta):t.theta;n.thetaLabel=i.tickText(s,c,\"hover\").text;var u=t.hi||e.hoverinfo,h=[];function f(t,e){h.push(t._hovertitle+\": \"+e)}if(!e.hovertemplate){var p=u.split(\"+\");-1!==p.indexOf(\"all\")&&(p=[\"r\",\"theta\",\"text\"]),-1!==p.indexOf(\"r\")&&f(o,n.rLabel),-1!==p.indexOf(\"theta\")&&f(s,n.thetaLabel),-1!==p.indexOf(\"text\")&&n.text&&(h.push(n.text),delete n.text),n.extraText=h.join(\"<br>\")}}e.exports={hoverPoints:function(t,e,r,i){var a=n(t,e,r,i);if(a&&!1!==a[0].index){var s=a[0];if(void 0===s.index)return a;var l=t.subplot,c=s.cd[s.index],u=s.trace;if(l.isPtInside(c))return s.xLabelVal=void 0,s.yLabelVal=void 0,o(c,u,l,s),s.hovertemplate=u.hovertemplate,a}},makeHoverPointText:o}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scatter/hover\":1122}],1183:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scatter/select\"),meta:{}}},{\"../../plots/polar\":831,\"../scatter/marker_colorbar\":1129,\"../scatter/select\":1132,\"../scatter/style\":1134,\"./attributes\":1179,\"./calc\":1180,\"./defaults\":1181,\"./hover\":1182,\"./plot\":1184}],1184:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){for(var a=e.layers.frontplot.select(\"g.scatterlayer\"),o={xaxis:e.xaxis,yaxis:e.yaxis,plot:e.framework,layerClipId:e._hasClipOnAxisFalse?e.clipIds.forTraces:null},s=e.radialAxis,l=e.angularAxis,c=0;c<r.length;c++)for(var u=r[c],h=0;h<u.length;h++){var f=u[h],p=f.r;if(p===i)f.x=f.y=i;else{var d=s.c2g(p),g=l.c2g(f.theta);f.x=d*Math.cos(g),f.y=d*Math.sin(g)}}n(t,o,r,a)}},{\"../../constants/numerical\":695,\"../scatter/plot\":1131}],1185:[function(t,e,r){\"use strict\";var n=t(\"../scatterpolar/attributes\"),i=t(\"../scattergl/attributes\");e.exports={mode:n.mode,r:n.r,theta:n.theta,r0:n.r0,dr:n.dr,theta0:n.theta0,dtheta:n.dtheta,thetaunit:n.thetaunit,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,line:i.line,connectgaps:i.connectgaps,marker:i.marker,fill:i.fill,fillcolor:i.fillcolor,textposition:i.textposition,textfont:i.textfont,hoverinfo:n.hoverinfo,selected:n.selected,unselected:n.unselected}},{\"../scattergl/attributes\":1160,\"../scatterpolar/attributes\":1179}],1186:[function(t,e,r){\"use strict\";var n=t(\"../scatter/colorscale_calc\"),i=t(\"../scatter/calc\").calcMarkerSize,a=t(\"../scattergl/convert\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r=t._fullLayout,l=e.subplot,c=r[l].radialaxis,u=r[l].angularaxis,h=c.makeCalcdata(e,\"r\"),f=u.makeCalcdata(e,\"theta\"),p=e._length,d={};p<h.length&&(h=h.slice(0,p)),p<f.length&&(f=f.slice(0,p)),d.r=h,d.theta=f,n(t,e);var g,v=d.opts=a.style(t,e);return p<s?g=i(e,p):v.marker&&(g=2*(v.marker.sizeAvg||Math.max(v.marker.size,3))),e._extremes.x=o.findExtremes(c,h,{ppad:g}),[{x:!1,y:!1,t:d,trace:e}]}},{\"../../plots/cartesian/axes\":767,\"../scatter/calc\":1113,\"../scatter/colorscale_calc\":1115,\"../scattergl/constants\":1162,\"../scattergl/convert\":1163}],1187:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatterpolar/defaults\").handleRThetaDefaults,o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}var d=a(t,e,f,p);d?(p(\"thetaunit\"),p(\"mode\",d<u?\"lines+markers\":\"lines\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),i.hasLines(e)&&(s(t,e,r,f,p),p(\"connectgaps\")),i.hasMarkers(e)&&o(t,e,r,f,p),i.hasText(e)&&l(t,e,f,p),p(\"fill\"),\"none\"!==e.fill&&c(t,e,r,p),n.coerceSelectionMarkerOpacity(e,p)):e.visible=!1}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"../scatterpolar/defaults\":1181,\"./attributes\":1185}],1188:[function(t,e,r){\"use strict\";var n=t(\"../scattergl/hover\"),i=t(\"../scatterpolar/hover\").makeHoverPointText;e.exports={hoverPoints:function(t,e,r,a){var o=t.cd[0].t,s=o.r,l=o.theta,c=n.hoverPoints(t,e,r,a);if(c&&!1!==c[0].index){var u=c[0];if(void 0===u.index)return c;var h=t.subplot,f=u.cd[u.index],p=u.trace;if(f.r=s[u.index],f.theta=l[u.index],h.isPtInside(f))return u.xLabelVal=void 0,u.yLabelVal=void 0,i(f,p,h,u),c}}}},{\"../scattergl/hover\":1166,\"../scatterpolar/hover\":1182}],1189:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolargl\",basePlotModule:t(\"../../plots/polar\"),categories:[\"gl\",\"regl\",\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scattergl/select\"),meta:{}}},{\"../../plots/polar\":831,\"../scatter/marker_colorbar\":1129,\"../scattergl/select\":1170,\"./attributes\":1185,\"./calc\":1186,\"./defaults\":1187,\"./hover\":1188,\"./plot\":1190}],1190:[function(t,e,r){\"use strict\";var n=t(\"point-cluster\"),i=t(\"fast-isnumeric\"),a=t(\"../scattergl/plot\"),o=t(\"../scattergl/scene_update\"),s=t(\"../scattergl/convert\"),l=t(\"../../lib\"),c=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e,r){if(r.length){var u=e.radialAxis,h=e.angularAxis,f=o(t,e);return r.forEach(function(r){if(r&&r[0]&&r[0].trace){var a,o=r[0],p=o.trace,d=o.t,g=p._length,v=d.r,m=d.theta,y=d.opts,x=v.slice(),b=m.slice();for(a=0;a<v.length;a++)e.isPtInside({r:v[a],theta:m[a]})||(x[a]=NaN,b[a]=NaN);var _=new Array(2*g),w=Array(g),k=Array(g);for(a=0;a<g;a++){var T,A,M=x[a];if(i(M)){var S=u.c2g(M),E=h.c2g(b[a],p.thetaunit);T=S*Math.cos(E),A=S*Math.sin(E)}else T=A=NaN;w[a]=_[2*a]=T,k[a]=_[2*a+1]=A}d.tree=n(_),y.marker&&g>=c&&(y.marker.cluster=d.tree),y.marker&&(y.markerSel.positions=y.markerUnsel.positions=y.marker.positions=_),y.line&&_.length>1&&l.extendFlat(y.line,s.linePositions(t,p,_)),y.text&&(l.extendFlat(y.text,{positions:_},s.textPosition(t,p,y.text,y.marker)),l.extendFlat(y.textSel,{positions:_},s.textPosition(t,p,y.text,y.markerSel)),l.extendFlat(y.textUnsel,{positions:_},s.textPosition(t,p,y.text,y.markerUnsel))),y.fill&&!f.fill2d&&(f.fill2d=!0),y.marker&&!f.scatter2d&&(f.scatter2d=!0),y.line&&!f.line2d&&(f.line2d=!0),y.text&&!f.glText&&(f.glText=!0),f.lineOptions.push(y.line),f.fillOptions.push(y.fill),f.markerOptions.push(y.marker),f.markerSelectedOptions.push(y.markerSel),f.markerUnselectedOptions.push(y.markerUnsel),f.textOptions.push(y.text),f.textSelectedOptions.push(y.textSel),f.textUnselectedOptions.push(y.textUnsel),f.selectBatch.push([]),f.unselectBatch.push([]),d.x=w,d.y=k,d.rawx=w,d.rawy=k,d.r=v,d.theta=m,d.positions=_,d._scene=f,d.index=f.count,f.count++}}),a(t,e,r)}}},{\"../../lib\":719,\"../scattergl/constants\":1162,\"../scattergl/convert\":1163,\"../scattergl/plot\":1168,\"../scattergl/scene_update\":1169,\"fast-isnumeric\":225,\"point-cluster\":469}],1191:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/drawing/attributes\").dash,l=t(\"../../lib/extend\").extendFlat,c=i.marker,u=i.line,h=c.line;e.exports={a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},c:{valType:\"data_array\",editType:\"calc\"},sum:{valType:\"number\",dflt:0,min:0,editType:\"calc\"},mode:l({},i.mode,{dflt:\"markers\"}),text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),line:{color:u.color,width:u.width,dash:s,shape:l({},u.shape,{values:[\"linear\",\"spline\"]}),smoothing:u.smoothing,editType:\"calc\"},connectgaps:i.connectgaps,cliponaxis:i.cliponaxis,fill:l({},i.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:i.fillcolor,marker:l({symbol:c.symbol,opacity:c.opacity,maxdisplayed:c.maxdisplayed,size:c.size,sizeref:c.sizeref,sizemin:c.sizemin,sizemode:c.sizemode,line:l({width:h.width,editType:\"calc\"},o(\"marker.line\")),gradient:c.gradient,editType:\"calc\"},o(\"marker\")),textfont:i.textfont,textposition:i.textposition,selected:i.selected,unselected:i.unselected,hoverinfo:l({},a.hoverinfo,{flags:[\"a\",\"b\",\"c\",\"text\",\"name\"]}),hoveron:i.hoveron,hovertemplate:n()}},{\"../../components/colorscale/attributes\":600,\"../../components/drawing/attributes\":613,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1192:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=[\"a\",\"b\",\"c\"],c={a:[\"b\",\"c\"],b:[\"a\",\"c\"],c:[\"a\",\"b\"]};e.exports=function(t,e){var r,u,h,f,p,d,g=t._fullLayout[e.subplot].sum,v=e.sum||g,m={a:e.a,b:e.b,c:e.c};for(r=0;r<l.length;r++)if(!m[h=l[r]]){for(p=m[c[h][0]],d=m[c[h][1]],f=new Array(p.length),u=0;u<p.length;u++)f[u]=v-p[u]-d[u];m[h]=f}var y,x,b,_,w,k,T=e._length,A=new Array(T);for(r=0;r<T;r++)y=m.a[r],x=m.b[r],b=m.c[r],n(y)&&n(x)&&n(b)?(1!==(_=g/((y=+y)+(x=+x)+(b=+b)))&&(y*=_,x*=_,b*=_),k=y,w=b-x,A[r]={x:w,y:k,a:y,b:x,c:b}):A[r]={x:!1,y:!1};return s(e,T),i(t,e),a(A,e),o(A,e),A}},{\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc\":1113,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1193:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}var d,g=p(\"a\"),v=p(\"b\"),m=p(\"c\");if(g?(d=g.length,v?(d=Math.min(d,v.length),m&&(d=Math.min(d,m.length))):d=m?Math.min(d,m.length):0):v&&m&&(d=Math.min(v.length,m.length)),d){e._length=d,p(\"sum\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),p(\"mode\",d<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,f,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,f,p,{gradient:!0}),a.hasText(e)&&c(t,e,f,p);var y=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"cliponaxis\"),p(\"marker.maxdisplayed\"),y.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||y.push(\"fills\"),p(\"hoveron\",y.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/line_shape_defaults\":1126,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1191}],1194:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),n[i]){var a=n[i];t.a=a.a,t.b=a.b,t.c=a.c}else t.a=e.a,t.b=e.b,t.c=e.c;return t}},{}],1195:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,h=c-u;return s.x0=Math.max(Math.min(s.x0,h),u),s.x1=Math.max(Math.min(s.x1,h),u),o}var f=s.cd[s.index];s.a=f.a,s.b=f.b,s.c=f.c,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.subplot;s.aLabel=i.tickText(p.aaxis,f.a,\"hover\").text,s.bLabel=i.tickText(p.baxis,f.b,\"hover\").text,s.cLabel=i.tickText(p.caxis,f.c,\"hover\").text;var d=s.trace,g=f.hi||d.hoverinfo,v=[];if(!d.hovertemplate){var m=g.split(\"+\");-1!==m.indexOf(\"all\")&&(m=[\"a\",\"b\",\"c\"]),-1!==m.indexOf(\"a\")&&y(p.aaxis,s.aLabel),-1!==m.indexOf(\"b\")&&y(p.baxis,s.bLabel),-1!==m.indexOf(\"c\")&&y(p.caxis,s.cLabel)}return s.extraText=v.join(\"<br>\"),s.hovertemplate=d.hovertemplate,o}function y(t,e){v.push(t._hovertitle+\": \"+e)}}},{\"../../plots/cartesian/axes\":767,\"../scatter/hover\":1122}],1196:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scatterternary\",basePlotModule:t(\"../../plots/ternary\"),categories:[\"ternary\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/ternary\":843,\"../scatter/marker_colorbar\":1129,\"../scatter/select\":1132,\"../scatter/style\":1134,\"./attributes\":1191,\"./calc\":1192,\"./defaults\":1193,\"./event_data\":1194,\"./hover\":1195,\"./plot\":1197}],1197:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\");e.exports=function(t,e,r){var i=e.plotContainer;i.select(\".scatterlayer\").selectAll(\"*\").remove();var a={xaxis:e.xaxis,yaxis:e.yaxis,plot:i,layerClipId:e._hasClipOnAxisFalse?e.clipIdRelative:null},o=e.layers.frontplot.select(\"g.scatterlayer\");n(t,a,r,o)}},{\"../scatter/plot\":1131}],1198:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../scattergl/attributes\"),s=t(\"../../plots/cartesian/constants\").idRegex,l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"../../lib/extend\").extendFlat,u=n.marker,h=u.line,f=c(i(\"marker.line\",{editTypeOverride:\"calc\"}),{width:c({},h.width,{editType:\"calc\"}),editType:\"calc\"}),p=c(i(\"marker\"),{symbol:u.symbol,size:c({},u.size,{editType:\"markerSize\"}),sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:f,editType:\"calc\"});function d(t){return{valType:\"info_array\",freeLength:!0,editType:\"calc\",items:{valType:\"subplotid\",regex:s[t],editType:\"plot\"}}}p.color.editType=p.cmin.editType=p.cmax.editType=\"style\",e.exports={dimensions:l(\"dimension\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},label:{valType:\"string\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},axis:{type:{valType:\"enumerated\",values:[\"linear\",\"log\",\"date\",\"category\"],editType:\"calc+clearAxisTypes\"},matches:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc+clearAxisTypes\"},editType:\"calc+clearAxisTypes\"}),text:c({},o.text,{}),hovertext:c({},o.hovertext,{}),hovertemplate:a(),marker:p,xaxes:d(\"x\"),yaxes:d(\"y\"),diagonal:{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},showupperhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},showlowerhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},selected:{marker:o.selected.marker,editType:\"calc\"},unselected:{marker:o.unselected.marker,editType:\"calc\"},opacity:o.opacity}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773,\"../scatter/attributes\":1112,\"../scattergl/attributes\":1160}],1199:[function(t,e,r){\"use strict\";var n=t(\"regl-line2d\"),i=t(\"../../registry\"),a=t(\"../../lib/prepare_regl\"),o=t(\"../../plots/get_data\").getModuleCalcData,s=t(\"../../plots/cartesian\"),l=t(\"../../plots/cartesian/axis_ids\").getFromId,c=t(\"../../plots/cartesian/axes\").shouldShowZeroLine,u=\"splom\";function h(t,e,r){for(var n=r.matrixOptions.data.length,i=e._visibleDims,a=r.viewOpts.ranges=new Array(n),o=0;o<i.length;o++){var s=i[o],c=a[o]=new Array(4),u=l(t,e._diag[s][0]);u&&(c[0]=u.r2l(u.range[0]),c[2]=u.r2l(u.range[1]));var h=l(t,e._diag[s][1]);h&&(c[1]=h.r2l(h.range[0]),c[3]=h.r2l(h.range[1]))}r.selectBatch.length||r.unselectBatch.length?r.matrix.update({ranges:a},{ranges:a}):r.matrix.update({ranges:a})}function f(t){var e=t._fullLayout,r=e._glcanvas.data()[0].regl,i=e._splomGrid;i||(i=e._splomGrid=n(r)),i.update(function(t){var e,r=t._fullLayout,n=r._size,i=[0,0,r.width,r.height],a={};function o(t,e,r,n,o,s){var l=e[t+\"color\"],c=e[t+\"width\"],u=String(l+c);u in a?a[u].data.push(NaN,NaN,r,n,o,s):a[u]={data:[r,n,o,s],join:\"rect\",thickness:c,color:l,viewport:i,range:i,overlay:!1}}for(e in r._splomSubplots){var s,l,u=r._plots[e],h=u.xaxis,f=u.yaxis,p=h._vals,d=f._vals,g=n.b+f.domain[0]*n.h,v=-f._m,m=-v*f.r2l(f.range[0],f.calendar);if(h.showgrid)for(e=0;e<p.length;e++)s=h._offset+h.l2p(p[e].x),o(\"grid\",h,s,g,s,g+f._length);if(f.showgrid)for(e=0;e<d.length;e++)l=g+m+v*d[e].x,o(\"grid\",f,h._offset,l,h._offset+h._length,l);c(t,h,f)&&(s=h._offset+h.l2p(0),o(\"zeroline\",h,s,g,s,g+f._length)),c(t,f,h)&&(l=g+m+0,o(\"zeroline\",f,h._offset,l,h._offset+h._length,l))}var y=[];for(e in a)y.push(a[e]);return y}(t))}e.exports={name:u,attr:s.attr,attrRegex:s.attrRegex,layoutAttributes:s.layoutAttributes,supplyLayoutDefaults:s.supplyLayoutDefaults,drawFramework:s.drawFramework,plot:function(t){var e=t._fullLayout,r=i.getModule(u),n=o(t.calcdata,r)[0];a(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])&&(e._hasOnlyLargeSploms&&f(t),r.plot(t,{},n))},drag:function(t){var e=t.calcdata,r=t._fullLayout;r._hasOnlyLargeSploms&&f(t);for(var n=0;n<e.length;n++){var i=e[n][0].trace,a=r._splomScenes[i.uid];\"splom\"===i.type&&a&&a.matrix&&h(t,i,a)}},updateGrid:f,clean:function(t,e,r,n){var i,a={};if(n._splomScenes){for(i=0;i<t.length;i++){var o=t[i];\"splom\"===o.type&&(a[o.uid]=1)}for(i=0;i<r.length;i++){var l=r[i];if(!a[l.uid]){var c=n._splomScenes[l.uid];c&&c.destroy&&c.destroy(),n._splomScenes[l.uid]=null,delete n._splomScenes[l.uid]}}}0===Object.keys(n._splomScenes||{}).length&&delete n._splomScenes,n._splomGrid&&!e._hasOnlyLargeSploms&&n._hasOnlyLargeSploms&&(n._splomGrid.destroy(),n._splomGrid=null,delete n._splomGrid),s.clean(t,e,r,n)},updateFx:s.updateFx,toSVG:s.toSVG}},{\"../../lib/prepare_regl\":732,\"../../plots/cartesian\":778,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_ids\":770,\"../../plots/get_data\":802,\"../../registry\":847,\"regl-line2d\":491}],1200:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../scatter/calc\").calcMarkerSize,o=t(\"../scatter/calc\").calcAxisExpansion,s=t(\"../scatter/colorscale_calc\"),l=t(\"../scattergl/convert\").markerSelection,c=t(\"../scattergl/convert\").markerStyle,u=t(\"./scene_update\"),h=t(\"../../constants/numerical\").BADNUM,f=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r,p,d,g,v,m,y=e.dimensions,x=e._length,b={},_=b.cdata=[],w=b.data=[],k=e._visibleDims=[];function T(t,r){for(var i=t.makeCalcdata({v:r.values,vcalendar:e.calendar},\"v\"),a=0;a<i.length;a++)i[a]=i[a]===h?NaN:i[a];_.push(i),w.push(\"log\"===t.type?n.simpleMap(i,t.c2l):i)}for(r=0;r<y.length;r++)if((d=y[r]).visible){if(g=i.getFromId(t,e._diag[r][0]),v=i.getFromId(t,e._diag[r][1]),g&&v&&g.type!==v.type){n.log(\"Skipping splom dimension \"+r+\" with conflicting axis types\");continue}g?(T(g,d),v&&\"category\"===v.type&&(v._categories=g._categories.slice())):T(v,d),k.push(r)}for(s(t,e),n.extendFlat(b,c(e)),m=_.length*x>f?2*(b.sizeAvg||Math.max(b.size,3)):a(e,x),p=0;p<k.length;p++)d=y[r=k[p]],g=i.getFromId(t,e._diag[r][0])||{},v=i.getFromId(t,e._diag[r][1])||{},o(t,e,g,v,_[p],_[p],m);var A=u(t,e);return A.matrix||(A.matrix=!0),A.matrixOptions=b,A.selectedOptions=l(e,e.selected),A.unselectedOptions=l(e,e.unselected),[{x:!1,y:!1,t:{},trace:e}]}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../scatter/calc\":1113,\"../scatter/colorscale_calc\":1115,\"../scattergl/constants\":1162,\"../scattergl/convert\":1163,\"./scene_update\":1207}],1201:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"../scatter/subtypes\"),s=t(\"../scatter/marker_defaults\"),l=t(\"../parcoords/merge_length\"),c=/-open/;function u(t,e){function r(r,i){return n.coerce(t,e,a.dimensions,r,i)}r(\"label\");var i=r(\"values\");i&&i.length?r(\"visible\"):e.visible=!1,r(\"axis.type\"),r(\"axis.matches\")}e.exports=function(t,e,r,h){function f(r,i){return n.coerce(t,e,a,r,i)}var p=i(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=f(\"diagonal.visible\"),g=f(\"showupperhalf\"),v=f(\"showlowerhalf\");if(l(e,p,\"values\")&&(d||g||v)){f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),s(t,e,r,h,f);var m=c.test(e.marker.symbol),y=o.isBubble(e);f(\"marker.line.width\",m||y?1:0),function(t,e,r,n){var i,a,o=e.dimensions,s=o.length,l=e.showupperhalf,c=e.showlowerhalf,u=e.diagonal.visible,h=new Array(s),f=new Array(s);for(i=0;i<s;i++){var p=i?i+1:\"\";h[i]=\"x\"+p,f[i]=\"y\"+p}var d=n(\"xaxes\",h),g=n(\"yaxes\",f),v=e._diag=new Array(s);e._xaxes={},e._yaxes={};var m=[],y=[];function x(t,n,i,a){if(t){var o=t.charAt(0),s=r._splomAxes[o];if(e[\"_\"+o+\"axes\"][t]=1,a.push(t),!(t in s)){var l=s[t]={};i&&(l.label=i.label||\"\",i.visible&&i.axis&&(i.axis.type&&(l.type=i.axis.type),i.axis.matches&&(l.matches=n)))}}}var b=!u&&!c,_=!u&&!l;for(e._axesDim={},i=0;i<s;i++){var w=o[i],k=0===i,T=i===s-1,A=k&&b||T&&_?void 0:d[i],M=k&&_||T&&b?void 0:g[i];x(A,M,w,m),x(M,A,w,y),v[i]=[A,M],e._axesDim[A]=i,e._axesDim[M]=i}for(i=0;i<m.length;i++)for(a=0;a<y.length;a++){var S=m[i]+y[a];i>a&&l?r._splomSubplots[S]=1:i<a&&c?r._splomSubplots[S]=1:i!==a||!u&&c&&l||(r._splomSubplots[S]=1)}(!c||!u&&l&&c)&&(r._splomGridDflt.xside=\"bottom\",r._splomGridDflt.yside=\"left\")}(0,e,h,f),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../parcoords/merge_length\":1083,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"./attributes\":1198}],1202:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scattergl/convert\").markerStyle;e.exports=function(t,e){var r=e.trace,o=t._fullLayout._splomScenes[r.uid];if(o){i(t,r),n.extendFlat(o.matrixOptions,a(r));var s=n.extendFlat({},o.matrixOptions,o.viewOpts);o.matrix.update(s,null)}}},{\"../../lib\":719,\"../scatter/colorscale_calc\":1115,\"../scattergl/convert\":1163}],1203:[function(t,e,r){\"use strict\";r.getDimIndex=function(t,e){for(var r=e._id,n={x:0,y:1}[r.charAt(0)],i=t._visibleDims,a=0;a<i.length;a++){var o=i[a];if(t._diag[o][n]===r)return a}return!1}},{}],1204:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i=t(\"../scattergl/hover\").calcHover;e.exports={hoverPoints:function(t,e,r){var a=t.cd[0].trace,o=t.scene.matrixOptions.cdata,s=t.xa,l=t.ya,c=s.c2p(e),u=l.c2p(r),h=t.distance,f=n.getDimIndex(a,s),p=n.getDimIndex(a,l);if(!1===f||!1===p)return[t];for(var d,g,v=o[f],m=o[p],y=h,x=0;x<v.length;x++){var b=v[x],_=m[x],w=s.c2p(b)-c,k=l.c2p(_)-u,T=Math.sqrt(w*w+k*k);T<y&&(y=g=T,d=x)}return t.index=d,t.distance=y,t.dxy=g,void 0===d?[t]:(i(t,v,m,a),[t])}}},{\"../scattergl/hover\":1166,\"./helpers\":1203}],1205:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../components/grid\");e.exports={moduleType:\"trace\",name:\"splom\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\"),editStyle:t(\"./edit_style\"),meta:{}},n.register(i)},{\"../../components/grid\":636,\"../../registry\":847,\"../scatter/marker_colorbar\":1129,\"./attributes\":1198,\"./base_plot\":1199,\"./calc\":1200,\"./defaults\":1201,\"./edit_style\":1202,\"./hover\":1204,\"./plot\":1206,\"./select\":1208}],1206:[function(t,e,r){\"use strict\";var n=t(\"regl-splom\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\");function o(t,e){var r,o,s,l,c,u=t._fullLayout,h=u._size,f=e.trace,p=e.t,d=u._splomScenes[f.uid],g=d.matrixOptions,v=g.cdata,m=u._glcanvas.data()[0].regl,y=u.dragmode;if(0!==v.length){g.lower=f.showupperhalf,g.upper=f.showlowerhalf,g.diagonal=f.diagonal.visible;var x=f._visibleDims,b=v.length,_=d.viewOpts={};for(_.ranges=new Array(b),_.domains=new Array(b),c=0;c<x.length;c++){s=x[c];var w=_.ranges[c]=new Array(4),k=_.domains[c]=new Array(4);(r=a.getFromId(t,f._diag[s][0]))&&(w[0]=r._rl[0],w[2]=r._rl[1],k[0]=r.domain[0],k[2]=r.domain[1]),(o=a.getFromId(t,f._diag[s][1]))&&(w[1]=o._rl[0],w[3]=o._rl[1],k[1]=o.domain[0],k[3]=o.domain[1])}_.viewport=[h.l,h.b,h.w+h.l,h.h+h.b],!0===d.matrix&&(d.matrix=n(m));var T=u.clickmode.indexOf(\"select\")>-1,A=!0;if(\"lasso\"===y||\"select\"===y||!!f.selectedpoints||T){var M=f._length;if(f.selectedpoints){d.selectBatch=f.selectedpoints;var S=f.selectedpoints,E={};for(s=0;s<S.length;s++)E[S[s]]=!0;var C=[];for(s=0;s<M;s++)E[s]||C.push(s);d.unselectBatch=C}var L=p.xpx=new Array(b),P=p.ypx=new Array(b);for(c=0;c<x.length;c++){if(s=x[c],r=a.getFromId(t,f._diag[s][0]))for(L[c]=new Array(M),l=0;l<M;l++)L[c][l]=r.c2p(v[c][l]);if(o=a.getFromId(t,f._diag[s][1]))for(P[c]=new Array(M),l=0;l<M;l++)P[c][l]=o.c2p(v[c][l])}if(d.selectBatch.length||d.unselectBatch.length){var O=i.extendFlat({},g,d.unselectedOptions,_),z=i.extendFlat({},g,d.selectedOptions,_);d.matrix.update(O,z),A=!1}}else p.xpx=p.ypx=null;if(A){var I=i.extendFlat({},g,_);d.matrix.update(I,null)}}}e.exports=function(t,e,r){if(r.length)for(var n=0;n<r.length;n++)o(t,r[n][0])}},{\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"regl-splom\":501}],1207:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t._fullLayout,i=e.uid,a=r._splomScenes;a||(a=r._splomScenes={});var o={dirty:!0},s=a[e.uid];return s||((s=a[i]=n.extendFlat({},o,{matrix:!1,selectBatch:[],unselectBatch:[]})).draw=function(){s.matrix&&s.matrix.draw&&(s.selectBatch.length||s.unselectBatch.length?s.matrix.draw(s.unselectBatch,s.selectBatch):s.matrix.draw()),s.dirty=!1},s.destroy=function(){s.matrix&&s.matrix.destroy&&s.matrix.destroy(),s.matrixOptions=null,s.selectBatch=null,s.unselectBatch=null,s=null}),s.dirty||n.extendFlat(s,o),s}},{\"../../lib\":719}],1208:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"./helpers\");e.exports=function(t,e){var r=t.cd,o=r[0].trace,s=r[0].t,l=t.scene,c=l.matrixOptions.cdata,u=t.xaxis,h=t.yaxis,f=[];if(!l)return f;var p=!i.hasMarkers(o)&&!i.hasText(o);if(!0!==o.visible||p)return f;var d=a.getDimIndex(o,u),g=a.getDimIndex(o,h);if(!1===d||!1===g)return f;var v=s.xpx[d],m=s.ypx[g],y=c[d],x=c[g],b=[],_=[];if(!1!==e&&!e.degenerate)for(var w=0;w<y.length;w++)e.contains([v[w],m[w]],null,w,t)?(b.push(w),f.push({pointNumber:w,x:y[w],y:x[w]})):_.push(w);var k=l.matrixOptions;return b.length||_.length?l.selectBatch.length||l.unselectBatch.length||l.matrix.update(l.unselectedOptions,n.extendFlat({},k,l.selectedOptions,l.viewOpts)):l.matrix.update(k,null),l.selectBatch=b,l.unselectBatch=_,f}},{\"../../lib\":719,\"../scatter/subtypes\":1135,\"./helpers\":1203}],1209:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},starts:{x:{valType:\"data_array\",editType:\"calc\"},y:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},maxdisplayed:{valType:\"integer\",min:0,dflt:1e3,editType:\"calc\"},sizeref:{valType:\"number\",editType:\"calc\",min:0,dflt:1},text:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:i({editType:\"calc\"},{keys:[\"tubex\",\"tubey\",\"tubez\",\"tubeu\",\"tubev\",\"tubew\",\"norm\",\"divergence\"]})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach(function(t){l[t]=a[t]}),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"divergence\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../mesh3d/attributes\":1053}],1210:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){var r,i,a,o,s=e.u,l=e.v,c=e.w,u=e.x,h=e.y,f=e.z,p=Math.min(u.length,h.length,f.length,s.length,l.length,c.length),d=0;e.starts&&(i=e.starts.x||[],a=e.starts.y||[],o=e.starts.z||[],d=Math.min(i.length,a.length,o.length));var g=0,v=1/0;for(r=0;r<p;r++){var m=s[r],y=l[r],x=c[r],b=Math.sqrt(m*m+y*y+x*x);g=Math.max(g,b),v=Math.min(v,b)}n(t,e,{vals:[v,g],containerStr:\"\",cLetter:\"c\"});var _=-1/0,w=1/0,k=-1/0,T=1/0,A=-1/0,M=1/0;for(r=0;r<p;r++){var S=u[r];_=Math.max(_,S),w=Math.min(w,S);var E=h[r];k=Math.max(k,E),T=Math.min(T,E);var C=f[r];A=Math.max(A,C),M=Math.min(M,C)}for(r=0;r<d;r++){var L=i[r];_=Math.max(_,L),w=Math.min(w,L);var P=a[r];k=Math.max(k,P),T=Math.min(T,P);var O=o[r];A=Math.max(A,O),M=Math.min(M,O)}e._len=p,e._slen=d,e._normMax=g,e._xbnds=[w,_],e._ybnds=[T,k],e._zbnds=[M,A]}},{\"../../components/colorscale/calc\":601}],1211:[function(t,e,r){\"use strict\";var n=t(\"gl-streamtube3d\"),i=n.createTubeMesh,a=t(\"../../lib\"),o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\"),c={xaxis:0,yaxis:1,zaxis:2};function u(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var h=u.prototype;function f(t){return a.distinctVals(t).vals}function p(t){var e=t.length;return e>2?t.slice(1,e-1):2===e?[(t[0]+t[1])/2]:t}function d(t){var e=t.length;return 1===e?[.5,.5]:[t[1]-t[0],t[e-1]-t[e-2]]}function g(t,e){var r=t.fullSceneLayout,i=t.dataScale,u=e._len,h={};function g(t,e){var n=r[e],o=i[c[e]];return a.simpleMap(t,function(t){return n.d2l(t)*o})}h.vectors=l(g(e.u,\"xaxis\"),g(e.v,\"yaxis\"),g(e.w,\"zaxis\"),u);var v=f(e.x.slice(0,u)),m=f(e.y.slice(0,u)),y=f(e.z.slice(0,u));if(v.length*m.length*y.length>u)return{positions:[],cells:[]};var x=g(v,\"xaxis\"),b=g(m,\"yaxis\"),_=g(y,\"zaxis\");if(h.meshgrid=[x,b,_],e.starts){var w=e._slen;h.startingPositions=l(g(e.starts.x.slice(0,w),\"xaxis\"),g(e.starts.y.slice(0,w),\"yaxis\"),g(e.starts.z.slice(0,w),\"zaxis\"))}else{for(var k=b[0],T=p(x),A=p(_),M=new Array(T.length*A.length),S=0,E=0;E<T.length;E++)for(var C=0;C<A.length;C++)M[S++]=[T[E],k,A[C]];h.startingPositions=M}h.colormap=o(e),h.tubeSize=e.sizeref,h.maxLength=e.maxdisplayed;var L=g(e._xbnds,\"xaxis\"),P=g(e._ybnds,\"yaxis\"),O=g(e._zbnds,\"zaxis\"),z=d(x),I=d(b),D=d(_),R=[[L[0]-z[0],P[0]-I[0],O[0]-D[0]],[L[1]+z[1],P[1]+I[1],O[1]+D[1]]],F=n(h,R),B=s(e);F.vertexIntensityBounds=[B.min/e._normMax,B.max/e._normMax];var N=e.lightposition;return F.lightPosition=[N.x,N.y,N.z],F.ambient=e.lighting.ambient,F.diffuse=e.lighting.diffuse,F.specular=e.lighting.specular,F.roughness=e.lighting.roughness,F.fresnel=e.lighting.fresnel,F.opacity=e.opacity,e._pad=F.tubeScale*e.sizeref*2,F}h.handlePick=function(t){var e=this.scene.fullSceneLayout,r=this.scene.dataScale;function n(t,n){var i=e[n],a=r[c[n]];return i.l2c(t)/a}if(t.object===this.mesh){var i=t.data.position,a=t.data.velocity;return t.traceCoordinate=[n(i[0],\"xaxis\"),n(i[1],\"yaxis\"),n(i[2],\"zaxis\"),n(a[0],\"xaxis\"),n(a[1],\"yaxis\"),n(a[2],\"zaxis\"),t.data.intensity*this.data._normMax,t.data.divergence],t.textLabel=this.data.hovertext||this.data.text,!0}},h.update=function(t){this.data=t;var e=g(this.scene,t);this.mesh.update(e)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=g(t,e),a=i(r,n),o=new u(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../plots/gl3d/zip3\":818,\"gl-streamtube3d\":313}],1212:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),h=s(\"x\"),f=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length&&p&&p.length?(s(\"starts.x\"),s(\"starts.y\"),s(\"starts.z\"),s(\"maxdisplayed\"),s(\"sizeref\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":1209}],1213:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"streamtube\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),eventData:function(t,e){return t.tubex=t.x,t.tubey=t.y,t.tubez=t.z,t.tubeu=e.traceCoordinate[3],t.tubev=e.traceCoordinate[4],t.tubew=e.traceCoordinate[5],t.norm=e.traceCoordinate[6],t.divergence=e.traceCoordinate[7],delete t.x,delete t.y,delete t.z,t},meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1209,\"./calc\":1210,\"./convert\":1211,\"./defaults\":1212}],1214:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../plots/domain\").attributes,o=t(\"../pie/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports={labels:{valType:\"data_array\",editType:\"calc\"},parents:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},branchvalues:{valType:\"enumerated\",values:[\"remainder\",\"total\"],dflt:\"remainder\",editType:\"calc\"},level:{valType:\"any\",editType:\"plot\",anim:!0},maxdepth:{valType:\"integer\",editType:\"plot\",dflt:-1},marker:{colors:{valType:\"data_array\",editType:\"calc\"},line:{color:s({},o.marker.line.color,{dflt:null}),width:s({},o.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},leaf:{opacity:{valType:\"number\",editType:\"style\",min:0,max:1,dflt:.7},editType:\"plot\"},text:o.text,textinfo:s({},o.textinfo,{editType:\"plot\",flags:[\"label\",\"text\",\"value\"]}),textfont:o.textfont,hovertext:o.hovertext,hoverinfo:s({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"name\"]}),hovertemplate:i(),insidetextfont:o.insidetextfont,outsidetextfont:o.outsidetextfont,domain:a({name:\"sunburst\",trace:!0,editType:\"calc\"})}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../pie/attributes\":1086}],1215:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=r.name=\"sunburst\";r.plot=function(t,e,r,o){var s=n.getModule(a),l=i(t.calcdata,s)[0];s.plot(t,l,r,o)},r.clean=function(t,e,r,n){var i=n._has&&n._has(a),o=e._has&&e._has(a);i&&!o&&n._sunburstlayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],1216:[function(t,e,r){\"use strict\";var n=t(\"d3-hierarchy\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../pie/calc\").makePullColorFn,s=t(\"../pie/calc\").generateExtendedColors,l=a.isArrayOrTypedArray,c={};r.calc=function(t,e){var r,s,c,u,h,f,p=t._fullLayout,d=e.ids,g=l(d),v=e.labels,m=e.parents,y=e.values,x=l(y),b=[],_={},w={},k=function(t){return t||\"number\"==typeof t},T=function(t){return!x||i(y[t])&&y[t]>=0};g?(r=Math.min(d.length,m.length),s=function(t){return k(d[t])&&T(t)},c=function(t){return String(d[t])}):(r=Math.min(v.length,m.length),s=function(t){return k(v[t])&&T(t)},c=function(t){return String(v[t])}),x&&(r=Math.min(r,y.length));for(var A=0;A<r;A++)if(s(A)){var M=c(A),S=k(m[A])?String(m[A]):\"\",E={i:A,id:M,pid:S,label:k(v[A])?String(v[A]):\"\"};x&&(E.v=+y[A]),b.push(E),h=M,_[u=S]?_[u].push(h):_[u]=[h],w[h]=1}if(_[\"\"]){if(_[\"\"].length>1){for(var C=a.randstr(),L=0;L<b.length;L++)\"\"===b[L].pid&&(b[L].pid=C);b.unshift({hasMultipleRoots:!0,id:C,pid:\"\"})}}else{var P,O=[];for(P in _)w[P]||O.push(P);if(1!==O.length)return a.warn(\"Multiple implied roots, cannot build sunburst hierarchy.\");P=O[0],b.unshift({id:P,pid:\"\",label:P})}try{f=n.stratify().id(function(t){return t.id}).parentId(function(t){return t.pid})(b)}catch(t){return a.warn(\"Failed to build sunburst hierarchy. Error: \"+t.message)}var z=n.hierarchy(f),I=!1;if(x)switch(e.branchvalues){case\"remainder\":z.sum(function(t){return t.data.v});break;case\"total\":z.each(function(t){var e=t.data.data.v;if(t.children&&e<t.children.reduce(function(t,e){return t+e.data.data.v},0))return I=!0,a.warn([\"Total value for node\",t.data.data.id,\"is smaller than the sum of its children.\"].join(\" \"));t.value=e})}else z.count();if(!I){z.sort(function(t,e){return e.value-t.value});var D=e.marker.colors||[],R=o(p._sunburstcolormap);return z.each(function(t){var e=t.data.data,r=e.id;e.color=R(D[e.i],r)}),b[0].hierarchy=z,b}},r.crossTraceCalc=function(t){var e=t._fullLayout,r=t.calcdata,n=e.sunburstcolorway,i=e._sunburstcolormap;e.extendsunburstcolors&&(n=s(n,c));var a=0;function o(t){var e=t.data.data,r=e.id;!1===e.color&&(i[r]?e.color=i[r]:t.parent?t.parent.parent?e.color=t.parent.data.data.color:(i[r]=e.color=n[a%n.length],a++):e.color=\"rgba(0,0,0,0)\")}for(var l=0;l<r.length;l++){var u=r[l][0];\"sunburst\"===u.trace.type&&u.hierarchy&&u.hierarchy.each(o)}}},{\"../../lib\":719,\"../pie/calc\":1088,\"d3-hierarchy\":157,\"fast-isnumeric\":225}],1217:[function(t,e,r){\"use strict\";e.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:\"linear\"}},{}],1218:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}var c=l(\"labels\"),u=l(\"parents\");if(c&&c.length&&u&&u.length){var h=l(\"values\");h&&h.length&&l(\"branchvalues\"),l(\"level\"),l(\"maxdepth\"),l(\"marker.line.width\")&&l(\"marker.line.color\",s.paper_bgcolor),l(\"marker.colors\"),l(\"leaf.opacity\");var f=l(\"text\");l(\"textinfo\",Array.isArray(f)?\"text+label\":\"label\"),l(\"hovertext\"),l(\"hovertemplate\");o(t,e,s,l,\"auto\",{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),a(e,s,l),e._length=null}else e.visible=!1}},{\"../../lib\":719,\"../../plots/domain\":792,\"../bar/defaults\":861,\"./attributes\":1214}],1219:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"sunburst\",basePlotModule:t(\"./base_plot\"),categories:[],animatable:!0,attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\").style,meta:{}}},{\"./attributes\":1214,\"./base_plot\":1215,\"./calc\":1216,\"./defaults\":1218,\"./layout_attributes\":1220,\"./layout_defaults\":1221,\"./plot\":1222,\"./style\":1223}],1220:[function(t,e,r){\"use strict\";e.exports={sunburstcolorway:{valType:\"colorlist\",editType:\"calc\"},extendsunburstcolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1221:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"sunburstcolorway\",e.colorway),r(\"extendsunburstcolors\")}},{\"../../lib\":719,\"./layout_attributes\":1220}],1222:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"d3-hierarchy\"),a=t(\"../../registry\"),o=t(\"../../components/fx\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../lib\"),u=t(\"../../lib/events\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"../../lib/setcursor\"),p=t(\"../../components/fx/helpers\").appendArrayPointValue,d=t(\"../pie/plot\").transformInsideText,g=t(\"../pie/helpers\").formatPieValue,v=t(\"./style\").styleOne,m=t(\"./constants\");function y(t,e,r,a){var o=t._fullLayout,u=a&&a.duration>0,f=n.select(r).selectAll(\"g.slice\"),p=e[0],m=p.trace,y=x(p.hierarchy,m.level),w=m.maxdepth>=0?m.maxdepth:1/0,M=o._size,S=m.domain,E=M.w*(S.x[1]-S.x[0]),C=M.h*(S.y[1]-S.y[0]),L=.5*Math.min(E,C),P=p.cx=M.l+M.w*(S.x[1]+S.x[0])/2,O=p.cy=M.t+M.h*(1-S.y[0])-C/2;if(!y)return f.remove();var z=null,I={};u&&f.each(function(t){I[k(t)]={rpx0:t.rpx0,rpx1:t.rpx1,x0:t.x0,x1:t.x1,transform:t.transform},!z&&_(t)&&(z=t)});var D=function(t){return i.partition().size([2*Math.PI,t.height+1])(t)}(y).descendants(),R=y.height+1,F=0,B=w;p.hasMultipleRoots&&b(y)&&(D=D.slice(1),R-=1,F=1,B+=1),D=D.filter(function(t){return t.y1<=B});var N=Math.min(R,w),j=function(t){return(t-F)/N*L},U=function(t,e){return[t*Math.cos(e),-t*Math.sin(e)]},V=function(t){return c.pathAnnulus(t.rpx0,t.rpx1,t.x0,t.x1,P,O)},q=function(t){return P+t.pxmid[0]*t.transform.rCenter+(t.transform.x||0)},H=function(t){return O+t.pxmid[1]*t.transform.rCenter+(t.transform.y||0)};(f=f.data(D,function(t){return k(t)})).enter().append(\"g\").classed(\"slice\",!0),u?f.exit().transition().each(function(){var t=n.select(this);t.select(\"path.surface\").transition().attrTween(\"d\",function(t){var e=function(t){var e,r=k(t),i=I[r],a=I[k(y)];if(a){var o=t.x1>a.x1?2*Math.PI:0;e=t.rpx1<a.rpx1?{rpx0:0,rpx1:0}:{x0:o,x1:o}}else{var s,l=k(t.parent);f.each(function(t){if(k(t)===l)return s=t});var c,u=s.children;u.forEach(function(t,e){if(k(t)===r)return c=e});var h=u.length,p=n.interpolate(s.x0,s.x1);e={rpx0:L,rpx1:L,x0:p(c/h),x1:p((c+1)/h)}}return n.interpolate(i,e)}(t);return function(t){return V(e(t))}}),t.select(\"g.slicetext\").attr(\"opacity\",0)}).remove():f.exit().remove(),f.order();var G=null;if(u&&z){var Y=k(z);f.each(function(t){null===G&&k(t)===Y&&(G=t.x1)})}var W=f;function X(t){var e=t.parent,r=I[k(e)],i={};if(r){var a=e.children,o=a.indexOf(t),s=a.length,l=n.interpolate(r.x0,r.x1);i.x0=l(o/s),i.x1=l(o/s)}else i.x0=i.x1=0;return i}u&&(W=W.transition().each(\"end\",function(){T(n.select(this),t,{isTransitioning:!1})})),W.each(function(r){var i=n.select(this),a=c.ensureSingle(i,\"path\",\"surface\",function(t){t.style(\"pointer-events\",\"all\")});r.rpx0=j(r.y0),r.rpx1=j(r.y1),r.xmid=(r.x0+r.x1)/2,r.pxmid=U(r.rpx1,r.xmid),r.midangle=-(r.xmid-Math.PI/2),r.halfangle=.5*Math.min(c.angleDelta(r.x0,r.x1)||Math.PI,Math.PI),r.ring=1-r.rpx0/r.rpx1,r.rInscribed=function(t){return 0===t.rpx0&&c.isFullCircle([t.x0,t.x1])?1:Math.max(0,Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2))}(r),u?a.transition().attrTween(\"d\",function(t){var e=function(t){var e,r=I[k(t)],i={x0:t.x0,x1:t.x1,rpx0:t.rpx0,rpx1:t.rpx1};if(r)e=r;else if(z)if(t.parent)if(G){var a=t.x1>G?2*Math.PI:0;e={x0:a,x1:a}}else e={rpx0:L,rpx1:L},c.extendFlat(e,X(t));else e={rpx0:0,rpx1:0};else e={x0:0,x1:0};return n.interpolate(e,i)}(t);return function(t){return V(e(t))}}):a.attr(\"d\",V),i.call(A,t,e).call(T,t,{isTransitioning:t._transitioning}),a.call(v,r,m);var f=c.ensureSingle(i,\"g\",\"slicetext\"),y=c.ensureSingle(f,\"text\",\"\",function(t){t.attr(\"data-notex\",1)});y.text(function(t,e,r){var n=e.textinfo;if(!n||\"none\"===n)return\"\";var i=t.data.data,a=r.separators,o=n.split(\"+\"),s=function(t){return-1!==o.indexOf(t)},l=[];s(\"label\")&&i.label&&l.push(i.label);i.hasOwnProperty(\"v\")&&s(\"value\")&&l.push(g(i.v,a));if(s(\"text\")){var u=c.castOption(e,i.i,\"text\");c.isValidTextValue(u)&&l.push(u)}return l.join(\"<br>\")}(r,m,o)).classed(\"slicetext\",!0).attr(\"text-anchor\",\"middle\").call(l.font,b(r)?function(t,e,r){var n=e.data.data.i,i=c.castOption(t,n,\"outsidetextfont.color\")||c.castOption(t,n,\"textfont.color\")||r.color,a=c.castOption(t,n,\"outsidetextfont.family\")||c.castOption(t,n,\"textfont.family\")||r.family,o=c.castOption(t,n,\"outsidetextfont.size\")||c.castOption(t,n,\"textfont.size\")||r.size;return{color:i,family:a,size:o}}(m,r,o.font):function(t,e,r){var n=e.data.data,i=n.i,a=c.castOption(t,i,\"insidetextfont.color\");!a&&t._input.textfont&&(a=c.castOption(t._input,i,\"textfont.color\"));var o=c.castOption(t,i,\"insidetextfont.family\")||c.castOption(t,i,\"textfont.family\")||r.family,l=c.castOption(t,i,\"insidetextfont.size\")||c.castOption(t,i,\"textfont.size\")||r.size;return{color:a||s.contrast(n.color),family:o,size:l}}(m,r,o.font)).call(h.convertToTspans,t);var x=l.bBox(y.node());r.transform=d(x,r,p),r.translateX=q(r),r.translateY=H(r);var _=function(t,e){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"+(t.transform.scale<1?\"scale(\"+t.transform.scale+\")\":\"\")+(t.transform.rotate?\"rotate(\"+t.transform.rotate+\")\":\"\")+\"translate(\"+-(e.left+e.right)/2+\",\"+-(e.top+e.bottom)/2+\")\"};u?y.transition().attrTween(\"transform\",function(t){var e=function(t){var e,r=I[k(t)],i=t.transform;if(r)e=r;else if(e={rpx1:t.rpx1,transform:{scale:0,rotate:i.rotate,rCenter:i.rCenter,x:i.x,y:i.y}},z)if(t.parent)if(G){var a=t.x1>G?2*Math.PI:0;e.x0=e.x1=a}else c.extendFlat(e,X(t));else e.x0=e.x1=0;else e.x0=e.x1=0;var o=n.interpolate(e.rpx1,t.rpx1),s=n.interpolate(e.x0,t.x0),l=n.interpolate(e.x1,t.x1),u=n.interpolate(e.transform.scale,i.scale),h=n.interpolate(e.transform.rotate,i.rotate),f=0===i.rCenter?3:0===e.transform.rCenter?1/3:1,p=n.interpolate(e.transform.rCenter,i.rCenter);return function(t){var e=o(t),r=s(t),n=l(t),a=function(t){return p(Math.pow(t,f))}(t),c={pxmid:U(e,(r+n)/2),transform:{rCenter:a,x:i.x,y:i.y}},d={rpx1:o(t),translateX:q(c),translateY:H(c),transform:{scale:u(t),rotate:h(t),rCenter:a}};return d}}(t);return function(t){return _(e(t),x)}}):y.attr(\"transform\",_(r,x))})}function x(t,e){var r;return e&&t.eachAfter(function(t){if(k(t)===e)return r=t.copy()}),r||t}function b(t){return\"\"===t.data.data.pid}function _(t){return!t.parent}function w(t){return!t.children}function k(t){return t.data.data.id}function T(t,e,r){var n=t.datum(),i=(r||{}).isTransitioning;f(t,i||w(n)||b(n)?null:\"pointer\")}function A(t,e,r){var i=r[0],s=i.trace;\"_hasHoverLabel\"in s||(s._hasHoverLabel=!1),\"_hasHoverEvent\"in s||(s._hasHoverEvent=!1),t.on(\"mouseover\",function(t){var r=e._fullLayout;if(!e._dragging&&!1!==r.hovermode){var a=e._fullData[s.index],l=t.data.data,u=l.i,h=function(t){return c.castOption(a,u,t)},f=h(\"hovertemplate\"),p=o.castHoverinfo(a,r,u),d=r.separators;if(f||p&&\"none\"!==p&&\"skip\"!==p){var v=t.rInscribed,m=i.cx+t.pxmid[0]*(1-v),y=i.cy+t.pxmid[1]*(1-v),x={},b=[],_=[],w=function(t){return-1!==b.indexOf(t)};if(p&&(b=\"all\"===p?a._module.attributes.hoverinfo.flags:p.split(\"+\")),x.label=l.label,w(\"label\")&&x.label&&_.push(x.label),l.hasOwnProperty(\"v\")&&(x.value=l.v,x.valueLabel=g(x.value,d),w(\"value\")&&_.push(x.valueLabel)),x.text=h(\"hovertext\")||h(\"text\"),w(\"text\")){var k=x.text;c.isValidTextValue(k)&&_.push(k)}o.loneHover({trace:a,x0:m-v*t.rpx1,x1:m+v*t.rpx1,y:y,idealAlign:t.pxmid[0]<0?\"left\":\"right\",text:_.join(\"<br>\"),name:f||w(\"name\")?a.name:void 0,color:h(\"hoverlabel.bgcolor\")||l.color,borderColor:h(\"hoverlabel.bordercolor\"),fontFamily:h(\"hoverlabel.font.family\"),fontSize:h(\"hoverlabel.font.size\"),fontColor:h(\"hoverlabel.font.color\"),nameLength:h(\"hoverlabel.namelength\"),textAlign:h(\"hoverlabel.align\"),hovertemplate:f,hovertemplateLabels:x,eventData:[M(t,a)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e}),s._hasHoverLabel=!0}s._hasHoverEvent=!0,e.emit(\"plotly_hover\",{points:[M(t,a)],event:n.event})}}),t.on(\"mouseout\",function(t){var r=e._fullLayout,i=e._fullData[s.index],a=n.select(this).datum();s._hasHoverEvent&&(t.originalEvent=n.event,e.emit(\"plotly_unhover\",{points:[M(a,i)],event:n.event}),s._hasHoverEvent=!1),s._hasHoverLabel&&(o.loneUnhover(r._hoverlayer.node()),s._hasHoverLabel=!1)}),t.on(\"click\",function(t){var r=e._fullLayout,l=e._fullData[s.index];if(!1===u.triggerHandler(e,\"plotly_sunburstclick\",{points:[M(t,l)],event:n.event})||w(t)||b(t))r.hovermode&&(e._hoverdata=[M(t,l)],o.click(e,n.event));else if(!e._dragging&&!e._transitioning){a.call(\"_storeDirectGUIEdit\",l,r._tracePreGUI[l.uid],{level:l.level});var c=i.hierarchy,h=k(t),f=_(t)?function(t,e){var r;return t.eachAfter(function(t){for(var n=t.children||[],i=0;i<n.length;i++)if(k(n[i])===e)return r=t.copy()}),r||t}(c,h):x(c,h),p={data:[{level:k(f)}],traces:[s.index]},d={frame:{redraw:!1,duration:m.CLICK_TRANSITION_TIME},transition:{duration:m.CLICK_TRANSITION_TIME,easing:m.CLICK_TRANSITION_EASING},mode:\"immediate\",fromcurrent:!0};o.loneUnhover(r._hoverlayer.node()),a.call(\"animate\",e,p,d)}})}function M(t,e){var r=t.data.data,n={curveNumber:e.index,pointNumber:r.i,data:e._input,fullData:e};return p(n,e,r.i),n}e.exports=function(t,e,r,i){var a,o,s=t._fullLayout._sunburstlayer,l=!r,c=r&&r.duration>0;((a=s.selectAll(\"g.trace.sunburst\").data(e,function(t){return t[0].trace.uid})).enter().append(\"g\").classed(\"trace\",!0).classed(\"sunburst\",!0).attr(\"stroke-linejoin\",\"round\"),a.order(),c)?(i&&(o=i()),n.transition().duration(r.duration).ease(r.easing).each(\"end\",function(){o&&o()}).each(\"interrupt\",function(){o&&o()}).each(function(){s.selectAll(\"g.trace\").each(function(e){y(t,e,this,r)})})):a.each(function(e){y(t,e,this,r)});l&&a.exit().remove()}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../components/fx/helpers\":628,\"../../lib\":719,\"../../lib/events\":709,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../registry\":847,\"../pie/helpers\":1091,\"../pie/plot\":1095,\"./constants\":1217,\"./style\":1223,d3:163,\"d3-hierarchy\":157}],1223:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../lib\");function o(t,e,r){var n=e.data.data,o=!e.children,s=n.i,l=a.castOption(r,s,\"marker.line.color\")||i.defaultLine,c=a.castOption(r,s,\"marker.line.width\")||0;t.style(\"stroke-width\",c).call(i.fill,n.color).call(i.stroke,l).style(\"opacity\",o?r.leaf.opacity:null)}e.exports={style:function(t){t._fullLayout._sunburstlayer.selectAll(\".trace\").each(function(t){var e=n.select(this),r=t[0].trace;e.style(\"opacity\",r.opacity),e.selectAll(\"path.surface\").each(function(t){n.select(this).call(o,t,r)})})},styleOne:o}},{\"../../components/color\":593,\"../../lib\":719,d3:163}],1224:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;function c(t){return{show:{valType:\"boolean\",dflt:!1},start:{valType:\"number\",dflt:null,editType:\"plot\"},end:{valType:\"number\",dflt:null,editType:\"plot\"},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\"},project:{x:{valType:\"boolean\",dflt:!1},y:{valType:\"boolean\",dflt:!1},z:{valType:\"boolean\",dflt:!1}},color:{valType:\"color\",dflt:n.defaultLine},usecolormap:{valType:\"boolean\",dflt:!1},width:{valType:\"number\",min:1,max:16,dflt:2},highlight:{valType:\"boolean\",dflt:!0},highlightcolor:{valType:\"color\",dflt:n.defaultLine},highlightwidth:{valType:\"number\",min:1,max:16,dflt:2}}}var u=e.exports=l(s({z:{valType:\"data_array\"},x:{valType:\"data_array\"},y:{valType:\"data_array\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:a(),connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},surfacecolor:{valType:\"data_array\"}},i(\"\",{colorAttr:\"z or surfacecolor\",showScaleDflt:!0,autoColorDflt:!1,editTypeOverride:\"calc\"}),{contours:{x:c(),y:c(),z:c()},hidesurface:{valType:\"boolean\",dflt:!1},lightposition:{x:{valType:\"number\",min:-1e5,max:1e5,dflt:10},y:{valType:\"number\",min:-1e5,max:1e5,dflt:1e4},z:{valType:\"number\",min:-1e5,max:1e5,dflt:0}},lighting:{ambient:{valType:\"number\",min:0,max:1,dflt:.8},diffuse:{valType:\"number\",min:0,max:1,dflt:.8},specular:{valType:\"number\",min:0,max:2,dflt:.05},roughness:{valType:\"number\",min:0,max:1,dflt:.5},fresnel:{valType:\"number\",min:0,max:5,dflt:.2}},opacity:{valType:\"number\",min:0,max:1,dflt:1},_deprecated:{zauto:s({},i.zauto,{}),zmin:s({},i.zmin,{}),zmax:s({},i.zmax,{})},hoverinfo:s({},o.hoverinfo)}),\"calc\",\"nested\");u.x.editType=u.y.editType=u.z.editType=\"calc+clearAxisTypes\",u.transforms=void 0},{\"../../components/color\":593,\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764}],1225:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.surfacecolor?n(t,e,{vals:e.surfacecolor,containerStr:\"\",cLetter:\"c\"}):n(t,e,{vals:e.z,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],1226:[function(t,e,r){\"use strict\";var n=t(\"gl-surface3d\"),i=t(\"ndarray\"),a=t(\"ndarray-homography\"),o=t(\"ndarray-fill\"),s=t(\"../../lib\").isArrayOrTypedArray,l=t(\"../../lib/gl_format_color\").parseColorScale,c=t(\"../../lib/str2rgbarray\"),u=t(\"../../components/colorscale\").extractOpts,h=t(\"../heatmap/interp2d\"),f=t(\"../heatmap/find_empties\");function p(t,e,r){this.scene=t,this.uid=r,this.surface=e,this.data=null,this.showContour=[!1,!1,!1],this.contourStart=[null,null,null],this.contourEnd=[null,null,null],this.contourSize=[0,0,0],this.minValues=[1/0,1/0,1/0],this.maxValues=[-1/0,-1/0,-1/0],this.dataScaleX=1,this.dataScaleY=1,this.refineData=!0,this.objectOffset=[0,0,0]}var d=p.prototype;d.getXat=function(t,e,r,n){var i=s(this.data.x)?s(this.data.x[0])?this.data.x[e][t]:this.data.x[t]:t;return void 0===r?i:n.d2l(i,0,r)},d.getYat=function(t,e,r,n){var i=s(this.data.y)?s(this.data.y[0])?this.data.y[e][t]:this.data.y[e]:e;return void 0===r?i:n.d2l(i,0,r)},d.getZat=function(t,e,r,n){var i=this.data.z[e][t];return null===i&&this.data.connectgaps&&this.data._interpolatedZ&&(i=this.data._interpolatedZ[e][t]),void 0===r?i:n.d2l(i,0,r)},d.handlePick=function(t){if(t.object===this.surface){var e=(t.data.index[0]-1)/this.dataScaleX-1,r=(t.data.index[1]-1)/this.dataScaleY-1,n=Math.max(Math.min(Math.round(e),this.data.z[0].length-1),0),i=Math.max(Math.min(Math.round(r),this.data._ylength-1),0);t.index=[n,i],t.traceCoordinate=[this.getXat(n,i),this.getYat(n,i),this.getZat(n,i)],t.dataCoordinate=[this.getXat(n,i,this.data.xcalendar,this.scene.fullSceneLayout.xaxis),this.getYat(n,i,this.data.ycalendar,this.scene.fullSceneLayout.yaxis),this.getZat(n,i,this.data.zcalendar,this.scene.fullSceneLayout.zaxis)];for(var a=0;a<3;a++){var o=t.dataCoordinate[a];null!=o&&(t.dataCoordinate[a]*=this.scene.dataScale[a])}var s=this.data.hovertext||this.data.text;return Array.isArray(s)&&s[i]&&void 0!==s[i][n]?t.textLabel=s[i][n]:t.textLabel=s||\"\",t.data.dataCoordinate=t.dataCoordinate.slice(),this.surface.highlight(t.data),this.scene.glplot.spikes.position=t.dataCoordinate,!0}};var g=[2,3,5,7,11,13,17,19,23,29,31,37,41,43,47,53,59,61,67,71,73,79,83,89,97,101,103,107,109,113,127,131,137,139,149,151,157,163,167,173,179,181,191,193,197,199,211,223,227,229,233,239,241,251,257,263,269,271,277,281,283,293,307,311,313,317,331,337,347,349,353,359,367,373,379,383,389,397,401,409,419,421,431,433,439,443,449,457,461,463,467,479,487,491,499,503,509,521,523,541,547,557,563,569,571,577,587,593,599,601,607,613,617,619,631,641,643,647,653,659,661,673,677,683,691,701,709,719,727,733,739,743,751,757,761,769,773,787,797,809,811,821,823,827,829,839,853,857,859,863,877,881,883,887,907,911,919,929,937,941,947,953,967,971,977,983,991,997,1009,1013,1019,1021,1031,1033,1039,1049,1051,1061,1063,1069,1087,1091,1093,1097,1103,1109,1117,1123,1129,1151,1153,1163,1171,1181,1187,1193,1201,1213,1217,1223,1229,1231,1237,1249,1259,1277,1279,1283,1289,1291,1297,1301,1303,1307,1319,1321,1327,1361,1367,1373,1381,1399,1409,1423,1427,1429,1433,1439,1447,1451,1453,1459,1471,1481,1483,1487,1489,1493,1499,1511,1523,1531,1543,1549,1553,1559,1567,1571,1579,1583,1597,1601,1607,1609,1613,1619,1621,1627,1637,1657,1663,1667,1669,1693,1697,1699,1709,1721,1723,1733,1741,1747,1753,1759,1777,1783,1787,1789,1801,1811,1823,1831,1847,1861,1867,1871,1873,1877,1879,1889,1901,1907,1913,1931,1933,1949,1951,1973,1979,1987,1993,1997,1999,2003,2011,2017,2027,2029,2039,2053,2063,2069,2081,2083,2087,2089,2099,2111,2113,2129,2131,2137,2141,2143,2153,2161,2179,2203,2207,2213,2221,2237,2239,2243,2251,2267,2269,2273,2281,2287,2293,2297,2309,2311,2333,2339,2341,2347,2351,2357,2371,2377,2381,2383,2389,2393,2399,2411,2417,2423,2437,2441,2447,2459,2467,2473,2477,2503,2521,2531,2539,2543,2549,2551,2557,2579,2591,2593,2609,2617,2621,2633,2647,2657,2659,2663,2671,2677,2683,2687,2689,2693,2699,2707,2711,2713,2719,2729,2731,2741,2749,2753,2767,2777,2789,2791,2797,2801,2803,2819,2833,2837,2843,2851,2857,2861,2879,2887,2897,2903,2909,2917,2927,2939,2953,2957,2963,2969,2971,2999];function v(t,e){if(t<e)return 0;for(var r=0;0===Math.floor(t%e);)t/=e,r++;return r}function m(t){for(var e=[],r=0;r<g.length;r++){var n=g[r];e.push(v(t,n))}return e}function y(t){for(var e=m(t),r=t,n=0;n<g.length;n++)if(e[n]>0){r=g[n];break}return r}function x(t,e){if(!(t<1||e<1)){for(var r=m(t),n=m(e),i=1,a=0;a<g.length;a++)i*=Math.pow(g[a],Math.max(r[a],n[a]));return i}}d.calcXnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getXat(e-1,0),i=this.getXat(e,0);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r},d.calcYnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getYat(0,e-1),i=this.getYat(0,e);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r};var b=[1,2,4,6,12,24,36,48,60,120,180,240,360,720,840,1260],_=b[9],w=b[13];function k(t,e){for(var r=!1,n=0;n<t.length;n++)if(e===t[n]){r=!0;break}!1===r&&t.push(e)}d.estimateScale=function(t,e){for(var r=1+function(t){if(0!==t.length){for(var e=1,r=0;r<t.length;r++)e=x(e,t[r]);return e}}(0===e?this.calcXnums(t):this.calcYnums(t));r<_;)r*=2;for(;r>w;)r--,r/=y(r),++r<_&&(r=w);var n=Math.round(r/t);return n>1?n:1},d.refineCoords=function(t){for(var e=this.dataScaleX,r=this.dataScaleY,n=t[0].shape[0],o=t[0].shape[1],s=0|Math.floor(t[0].shape[0]*e+1),l=0|Math.floor(t[0].shape[1]*r+1),c=1+n+1,u=1+o+1,h=i(new Float32Array(c*u),[c,u]),f=0;f<t.length;++f){this.surface.padField(h,t[f]);var p=i(new Float32Array(s*l),[s,l]);a(p,h,[e,0,0,0,r,0,0,0,1]),t[f]=p}},d.setContourLevels=function(){var t,e,r,n=[[],[],[]],i=[!1,!1,!1],a=!1;for(t=0;t<3;++t)if(this.showContour[t]&&(a=!0,this.contourSize[t]>0&&null!==this.contourStart[t]&&null!==this.contourEnd[t]&&this.contourEnd[t]>this.contourStart[t]))for(i[t]=!0,e=this.contourStart[t];e<this.contourEnd[t];e+=this.contourSize[t])r=e*this.scene.dataScale[t],k(n[t],r);if(a){var o=[[],[],[]];for(t=0;t<3;++t)this.showContour[t]&&(o[t]=i[t]?n[t]:this.scene.contourLevels[t]);this.surface.update({levels:o})}},d.update=function(t){var e,r,n,a,s=this.scene,p=s.fullSceneLayout,d=this.surface,g=t.opacity,v=l(t,g),m=s.dataScale,y=t.z[0].length,x=t._ylength,b=s.contourLevels;this.data=t;var _=[];for(e=0;e<3;e++)for(_[e]=[],r=0;r<y;r++)_[e][r]=[];for(r=0;r<y;r++)for(n=0;n<x;n++)_[0][r][n]=this.getXat(r,n,t.xcalendar,p.xaxis),_[1][r][n]=this.getYat(r,n,t.ycalendar,p.yaxis),_[2][r][n]=this.getZat(r,n,t.zcalendar,p.zaxis);if(t.connectgaps)for(t._emptypoints=f(_[2]),h(_[2],t._emptypoints),t._interpolatedZ=[],r=0;r<y;r++)for(t._interpolatedZ[r]=[],n=0;n<x;n++)t._interpolatedZ[r][n]=_[2][r][n];for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null==(a=_[e][r][n])?_[e][r][n]=NaN:a=_[e][r][n]*=m[e];for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null!=(a=_[e][r][n])&&(this.minValues[e]>a&&(this.minValues[e]=a),this.maxValues[e]<a&&(this.maxValues[e]=a));for(e=0;e<3;e++)this.objectOffset[e]=.5*(this.minValues[e]+this.maxValues[e]);for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null!=(a=_[e][r][n])&&(_[e][r][n]-=this.objectOffset[e]);var k=[i(new Float32Array(y*x),[y,x]),i(new Float32Array(y*x),[y,x]),i(new Float32Array(y*x),[y,x])];o(k[0],function(t,e){return _[0][t][e]}),o(k[1],function(t,e){return _[1][t][e]}),o(k[2],function(t,e){return _[2][t][e]}),_=[];var T={colormap:v,levels:[[],[],[]],showContour:[!0,!0,!0],showSurface:!t.hidesurface,contourProject:[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],contourWidth:[1,1,1],contourColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],contourTint:[1,1,1],dynamicColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],dynamicWidth:[1,1,1],dynamicTint:[1,1,1],opacity:t.opacity},A=u(t);if(T.intensityBounds=[A.min,A.max],t.surfacecolor){var M=i(new Float32Array(y*x),[y,x]);o(M,function(e,r){return t.surfacecolor[r][e]}),k.push(M)}else T.intensityBounds[0]*=m[2],T.intensityBounds[1]*=m[2];(w<k[0].shape[0]||w<k[0].shape[1])&&(this.refineData=!1),!0===this.refineData&&(this.dataScaleX=this.estimateScale(k[0].shape[0],0),this.dataScaleY=this.estimateScale(k[0].shape[1],1),1===this.dataScaleX&&1===this.dataScaleY||this.refineCoords(k)),t.surfacecolor&&(T.intensity=k.pop());var S=[!0,!0,!0],E=[\"x\",\"y\",\"z\"];for(e=0;e<3;++e){var C=t.contours[E[e]];S[e]=C.highlight,T.showContour[e]=C.show||C.highlight,T.showContour[e]&&(T.contourProject[e]=[C.project.x,C.project.y,C.project.z],C.show?(this.showContour[e]=!0,T.levels[e]=b[e],d.highlightColor[e]=T.contourColor[e]=c(C.color),C.usecolormap?d.highlightTint[e]=T.contourTint[e]=0:d.highlightTint[e]=T.contourTint[e]=1,T.contourWidth[e]=C.width,this.contourStart[e]=C.start,this.contourEnd[e]=C.end,this.contourSize[e]=C.size):(this.showContour[e]=!1,this.contourStart[e]=null,this.contourEnd[e]=null,this.contourSize[e]=0),C.highlight&&(T.dynamicColor[e]=c(C.highlightcolor),T.dynamicWidth[e]=C.highlightwidth))}(function(t){var e=t[0].rgb,r=t[t.length-1].rgb;return e[0]===r[0]&&e[1]===r[1]&&e[2]===r[2]&&e[3]===r[3]})(v)&&(T.vertexColor=!0),T.objectOffset=this.objectOffset,T.coords=k,d.update(T),d.visible=t.visible,d.enableDynamic=S,d.enableHighlight=S,d.snapToData=!0,\"lighting\"in t&&(d.ambientLight=t.lighting.ambient,d.diffuseLight=t.lighting.diffuse,d.specularLight=t.lighting.specular,d.roughness=t.lighting.roughness,d.fresnel=t.lighting.fresnel),\"lightposition\"in t&&(d.lightPosition=[t.lightposition.x,t.lightposition.y,t.lightposition.z]),g&&g<1&&(d.supportsTransparency=!0)},d.dispose=function(){this.scene.glplot.remove(this.surface),this.surface.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new p(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../heatmap/find_empties\":1007,\"../heatmap/interp2d\":1010,\"gl-surface3d\":316,ndarray:450,\"ndarray-fill\":440,\"ndarray-homography\":442}],1227:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");function s(t,e,r){e in t&&!(r in t)&&(t[r]=t[e])}e.exports=function(t,e,r,l){var c,u;function h(r,n){return i.coerce(t,e,o,r,n)}var f=h(\"x\"),p=h(\"y\"),d=h(\"z\");if(!d||!d.length||f&&f.length<1||p&&p.length<1)e.visible=!1;else{e._xlength=Array.isArray(f)&&i.isArrayOrTypedArray(f[0])?d.length:d[0].length,e._ylength=d.length,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],l),h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"hidesurface\",\"connectgaps\",\"opacity\"].forEach(function(t){h(t)});var g=h(\"surfacecolor\"),v=[\"x\",\"y\",\"z\"];for(c=0;c<3;++c){var m=\"contours.\"+v[c],y=h(m+\".show\"),x=h(m+\".highlight\");if(y||x)for(u=0;u<3;++u)h(m+\".project.\"+v[u]);y&&(h(m+\".color\"),h(m+\".width\"),h(m+\".usecolormap\")),x&&(h(m+\".highlightcolor\"),h(m+\".highlightwidth\")),h(m+\".start\"),h(m+\".end\"),h(m+\".size\")}g||(s(t,\"zmin\",\"cmin\"),s(t,\"zmax\",\"cmax\"),s(t,\"zauto\",\"cauto\")),a(t,e,l,h,{prefix:\"\",cLetter:\"c\"}),e._length=null}}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../../registry\":847,\"./attributes\":1224}],1228:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"surface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"2dMap\",\"noOpacity\"],meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1224,\"./calc\":1225,\"./convert\":1226,\"./defaults\":1227}],1229:[function(t,e,r){\"use strict\";var n=t(\"../../components/annotations/attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../plots/domain\").attributes;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=a({domain:s({name:\"table\",trace:!0}),columnwidth:{valType:\"number\",arrayOk:!0,dflt:null},columnorder:{valType:\"data_array\"},header:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:28},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))},cells:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:20},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))}},\"calc\",\"from-root\")).transforms=void 0},{\"../../components/annotations/attributes\":576,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1230:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"table\",r.plot=function(t){var e=n(t.calcdata,\"table\")[0];e.length&&i(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"table\"),a=e._has&&e._has(\"table\");i&&!a&&n._paperdiv.selectAll(\".table\").remove()}},{\"../../plots/get_data\":802,\"./plot\":1237}],1231:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap;e.exports=function(){return n({})}},{\"../../lib/gup\":717}],1232:[function(t,e,r){\"use strict\";e.exports={cellPad:8,columnExtentOffset:10,columnTitleOffset:28,emptyHeaderHeight:16,latexCheck:/^\\$.*\\$$/,goldenRatio:1.618,lineBreaker:\"<br>\",maxDimensionCount:60,overdrag:45,releaseTransitionDuration:120,releaseTransitionEase:\"cubic-out\",scrollbarCaptureWidth:18,scrollbarHideDelay:1e3,scrollbarHideDuration:1e3,scrollbarOffset:5,scrollbarWidth:8,transitionDuration:100,transitionEase:\"cubic-out\",uplift:5,wrapSpacer:\" \",wrapSplitCharacter:\" \",cn:{table:\"table\",tableControlView:\"table-control-view\",scrollBackground:\"scroll-background\",yColumn:\"y-column\",columnBlock:\"column-block\",scrollAreaClip:\"scroll-area-clip\",scrollAreaClipRect:\"scroll-area-clip-rect\",columnBoundary:\"column-boundary\",columnBoundaryClippath:\"column-boundary-clippath\",columnBoundaryRect:\"column-boundary-rect\",columnCells:\"column-cells\",columnCell:\"column-cell\",cellRect:\"cell-rect\",cellText:\"cell-text\",cellTextHolder:\"cell-text-holder\",scrollbarKit:\"scrollbar-kit\",scrollbar:\"scrollbar\",scrollbarSlider:\"scrollbar-slider\",scrollbarGlyph:\"scrollbar-glyph\",scrollbarCaptureZone:\"scrollbar-capture-zone\"}}},{}],1233:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"fast-isnumeric\");function o(t){if(Array.isArray(t)){for(var e=0,r=0;r<t.length;r++)e=Math.max(e,o(t[r]));return e}return t}function s(t,e){return t+e}function l(t){var e,r=t.slice(),n=1/0,i=0;for(e=0;e<r.length;e++)Array.isArray(r[e])||(r[e]=[r[e]]),n=Math.min(n,r[e].length),i=Math.max(i,r[e].length);if(n!==i)for(e=0;e<r.length;e++){var a=i-r[e].length;a&&(r[e]=r[e].concat(c(a)))}return r}function c(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=\"\";return e}function u(t){return t.calcdata.columns.reduce(function(e,r){return r.xIndex<t.xIndex?e+r.columnWidth:e},0)}function h(t,e){return Object.keys(t).map(function(r){return i({},t[r],{auxiliaryBlocks:e})})}function f(t,e){for(var r,n={},i=0,a=0,o={firstRowIndex:null,lastRowIndex:null,rows:[]},s=0,l=0,c=0;c<t.length;c++)r=t[c],o.rows.push({rowIndex:c,rowHeight:r}),((a+=r)>=e||c===t.length-1)&&(n[i]=o,o.key=l++,o.firstRowIndex=s,o.lastRowIndex=c,o={firstRowIndex:null,lastRowIndex:null,rows:[]},i+=a,s=c+1,a=0);return n}e.exports=function(t,e){var r=l(e.cells.values),p=function(t){return t.slice(e.header.values.length,t.length)},d=l(e.header.values);d.length&&!d[0].length&&(d[0]=[\"\"],d=l(d));var g=d.concat(p(r).map(function(){return c((d[0]||[\"\"]).length)})),v=e.domain,m=Math.floor(t._fullLayout._size.w*(v.x[1]-v.x[0])),y=Math.floor(t._fullLayout._size.h*(v.y[1]-v.y[0])),x=e.header.values.length?g[0].map(function(){return e.header.height}):[n.emptyHeaderHeight],b=r.length?r[0].map(function(){return e.cells.height}):[],_=x.reduce(s,0),w=f(b,y-_+n.uplift),k=h(f(x,_),[]),T=h(w,k),A={},M=e._fullInput.columnorder.concat(p(r.map(function(t,e){return e}))),S=g.map(function(t,r){var n=Array.isArray(e.columnwidth)?e.columnwidth[Math.min(r,e.columnwidth.length-1)]:e.columnwidth;return a(n)?Number(n):1}),E=S.reduce(s,0);S=S.map(function(t){return t/E*m});var C=Math.max(o(e.header.line.width),o(e.cells.line.width)),L={key:e.uid+t._context.staticPlot,translateX:v.x[0]*t._fullLayout._size.w,translateY:t._fullLayout._size.h*(1-v.y[1]),size:t._fullLayout._size,width:m,maxLineWidth:C,height:y,columnOrder:M,groupHeight:y,rowBlocks:T,headerRowBlocks:k,scrollY:0,cells:i({},e.cells,{values:r}),headerCells:i({},e.header,{values:g}),gdColumns:g.map(function(t){return t[0]}),gdColumnsOriginalOrder:g.map(function(t){return t[0]}),prevPages:[0,0],scrollbarState:{scrollbarScrollInProgress:!1},columns:g.map(function(t,e){var r=A[t];return A[t]=(r||0)+1,{key:t+\"__\"+A[t],label:t,specIndex:e,xIndex:M[e],xScale:u,x:void 0,calcdata:void 0,columnWidth:S[e]}})};return L.columns.forEach(function(t){t.calcdata=L,t.x=u(t)}),L}},{\"../../lib/extend\":710,\"./constants\":1232,\"fast-isnumeric\":225}],1234:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat;r.splitToPanels=function(t){var e=[0,0],r=n({},t,{key:\"header\",type:\"header\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!0,values:t.calcdata.headerCells.values[t.specIndex],rowBlocks:t.calcdata.headerRowBlocks,calcdata:n({},t.calcdata,{cells:t.calcdata.headerCells})});return[n({},t,{key:\"cells1\",type:\"cells\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),n({},t,{key:\"cells2\",type:\"cells\",page:1,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),r]},r.splitToCells=function(t){var e=function(t){var e=t.rowBlocks[t.page],r=e?e.rows[0].rowIndex:0,n=e?r+e.rows.length:0;return[r,n]}(t);return(t.values||[]).slice(e[0],e[1]).map(function(r,n){return{keyWithinBlock:n+(\"string\"==typeof r&&r.match(/[<$&> ]/)?\"_keybuster_\"+Math.random():\"\"),key:e[0]+n,column:t,calcdata:t.calcdata,page:t.page,rowBlocks:t.rowBlocks,value:r}})}},{\"../../lib/extend\":710}],1235:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults;e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}a(e,o,s),s(\"columnwidth\"),s(\"header.values\"),s(\"header.format\"),s(\"header.align\"),s(\"header.prefix\"),s(\"header.suffix\"),s(\"header.height\"),s(\"header.line.width\"),s(\"header.line.color\"),s(\"header.fill.color\"),n.coerceFont(s,\"header.font\",n.extendFlat({},o.font)),function(t,e){for(var r=t.columnorder||[],n=t.header.values.length,i=r.slice(0,n),a=i.slice().sort(function(t,e){return t-e}),o=i.map(function(t){return a.indexOf(t)}),s=o.length;s<n;s++)o.push(s);e(\"columnorder\",o)}(e,s),s(\"cells.values\"),s(\"cells.format\"),s(\"cells.align\"),s(\"cells.prefix\"),s(\"cells.suffix\"),s(\"cells.height\"),s(\"cells.line.width\"),s(\"cells.line.color\"),s(\"cells.fill.color\"),n.coerceFont(s,\"cells.font\",n.extendFlat({},o.font)),e._length=null}},{\"../../lib\":719,\"../../plots/domain\":792,\"./attributes\":1229}],1236:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"table\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1229,\"./base_plot\":1230,\"./calc\":1231,\"./defaults\":1235,\"./plot\":1237}],1237:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\"),o=t(\"../../components/drawing\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../lib\").raiseToTop,c=t(\"../../lib\").cancelTransition,u=t(\"./data_preparation_helper\"),h=t(\"./data_split_helpers\"),f=t(\"../../components/color\");function p(t){return Math.ceil(t.calcdata.maxLineWidth/2)}function d(t,e){return\"clip\"+t._fullLayout._uid+\"_scrollAreaBottomClip_\"+e.key}function g(t,e){return\"clip\"+t._fullLayout._uid+\"_columnBoundaryClippath_\"+e.calcdata.key+\"_\"+e.specIndex}function v(t){return[].concat.apply([],t.map(function(t){return t})).map(function(t){return t.__data__})}function m(t,e,r){var o=t.selectAll(\".\"+n.cn.scrollbarKit).data(a.repeat,a.keyFun);o.enter().append(\"g\").classed(n.cn.scrollbarKit,!0).style(\"shape-rendering\",\"geometricPrecision\"),o.each(function(t){var e=t.scrollbarState;e.totalHeight=function(t){var e=t.rowBlocks;return z(e,e.length-1)+(e.length?I(e[e.length-1],1/0):1)}(t),e.scrollableAreaHeight=t.groupHeight-A(t),e.currentlyVisibleHeight=Math.min(e.totalHeight,e.scrollableAreaHeight),e.ratio=e.currentlyVisibleHeight/e.totalHeight,e.barLength=Math.max(e.ratio*e.currentlyVisibleHeight,n.goldenRatio*n.scrollbarWidth),e.barWiggleRoom=e.currentlyVisibleHeight-e.barLength,e.wiggleRoom=Math.max(0,e.totalHeight-e.scrollableAreaHeight),e.topY=0===e.barWiggleRoom?0:t.scrollY/e.wiggleRoom*e.barWiggleRoom,e.bottomY=e.topY+e.barLength,e.dragMultiplier=e.wiggleRoom/e.barWiggleRoom}).attr(\"transform\",function(t){return\"translate(\"+(t.width+n.scrollbarWidth/2+n.scrollbarOffset)+\" \"+A(t)+\")\"});var s=o.selectAll(\".\"+n.cn.scrollbar).data(a.repeat,a.keyFun);s.enter().append(\"g\").classed(n.cn.scrollbar,!0);var l=s.selectAll(\".\"+n.cn.scrollbarSlider).data(a.repeat,a.keyFun);l.enter().append(\"g\").classed(n.cn.scrollbarSlider,!0),l.attr(\"transform\",function(t){return\"translate(0 \"+(t.scrollbarState.topY||0)+\")\"});var c=l.selectAll(\".\"+n.cn.scrollbarGlyph).data(a.repeat,a.keyFun);c.enter().append(\"line\").classed(n.cn.scrollbarGlyph,!0).attr(\"stroke\",\"black\").attr(\"stroke-width\",n.scrollbarWidth).attr(\"stroke-linecap\",\"round\").attr(\"y1\",n.scrollbarWidth/2),c.attr(\"y2\",function(t){return t.scrollbarState.barLength-n.scrollbarWidth/2}).attr(\"stroke-opacity\",function(t){return t.columnDragInProgress||!t.scrollbarState.barWiggleRoom||r?0:.4}),c.transition().delay(0).duration(0),c.transition().delay(n.scrollbarHideDelay).duration(n.scrollbarHideDuration).attr(\"stroke-opacity\",0);var u=s.selectAll(\".\"+n.cn.scrollbarCaptureZone).data(a.repeat,a.keyFun);u.enter().append(\"line\").classed(n.cn.scrollbarCaptureZone,!0).attr(\"stroke\",\"white\").attr(\"stroke-opacity\",.01).attr(\"stroke-width\",n.scrollbarCaptureWidth).attr(\"stroke-linecap\",\"butt\").attr(\"y1\",0).on(\"mousedown\",function(r){var n=i.event.y,a=this.getBoundingClientRect(),o=r.scrollbarState,s=n-a.top,l=i.scale.linear().domain([0,o.scrollableAreaHeight]).range([0,o.totalHeight]).clamp(!0);o.topY<=s&&s<=o.bottomY||S(e,t,null,l(s-o.barLength/2))(r)}).call(i.behavior.drag().origin(function(t){return i.event.stopPropagation(),t.scrollbarState.scrollbarScrollInProgress=!0,t}).on(\"drag\",S(e,t)).on(\"dragend\",function(){})),u.attr(\"y2\",function(t){return t.scrollbarState.scrollableAreaHeight}),e._context.staticPlot&&(c.remove(),u.remove())}function y(t,e,r,s){var l=function(t){var e=t.selectAll(\".\"+n.cn.columnCell).data(h.splitToCells,function(t){return t.keyWithinBlock});return e.enter().append(\"g\").classed(n.cn.columnCell,!0),e.exit().remove(),e}(function(t){var e=t.selectAll(\".\"+n.cn.columnCells).data(a.repeat,a.keyFun);return e.enter().append(\"g\").classed(n.cn.columnCells,!0),e.exit().remove(),e}(r));!function(t){t.each(function(t,e){var r=t.calcdata.cells.font,n=t.column.specIndex,i={size:_(r.size,n,e),color:_(r.color,n,e),family:_(r.family,n,e)};t.rowNumber=t.key,t.align=_(t.calcdata.cells.align,n,e),t.cellBorderWidth=_(t.calcdata.cells.line.width,n,e),t.font=i})}(l),function(t){t.attr(\"width\",function(t){return t.column.columnWidth}).attr(\"stroke-width\",function(t){return t.cellBorderWidth}).each(function(t){var e=i.select(this);f.stroke(e,_(t.calcdata.cells.line.color,t.column.specIndex,t.rowNumber)),f.fill(e,_(t.calcdata.cells.fill.color,t.column.specIndex,t.rowNumber))})}(function(t){var e=t.selectAll(\".\"+n.cn.cellRect).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"rect\").classed(n.cn.cellRect,!0),e}(l));var c=function(t){var e=t.selectAll(\".\"+n.cn.cellText).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"text\").classed(n.cn.cellText,!0).style(\"cursor\",function(){return\"auto\"}).on(\"mousedown\",function(){i.event.stopPropagation()}),e}(function(t){var e=t.selectAll(\".\"+n.cn.cellTextHolder).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"g\").classed(n.cn.cellTextHolder,!0).style(\"shape-rendering\",\"geometricPrecision\"),e}(l));!function(t){t.each(function(t){o.font(i.select(this),t.font)})}(c),x(c,e,s,t),O(l)}function x(t,e,r,a){t.text(function(t){var e=t.column.specIndex,r=t.rowNumber,a=t.value,o=\"string\"==typeof a,s=o&&a.match(/<br>/i),l=!o||s;t.mayHaveMarkup=o&&a.match(/[<&>]/);var c,u=\"string\"==typeof(c=a)&&c.match(n.latexCheck);t.latex=u;var h,f,p=u?\"\":_(t.calcdata.cells.prefix,e,r)||\"\",d=u?\"\":_(t.calcdata.cells.suffix,e,r)||\"\",g=u?null:_(t.calcdata.cells.format,e,r)||null,v=p+(g?i.format(g)(t.value):t.value)+d;if(t.wrappingNeeded=!t.wrapped&&!l&&!u&&(h=b(v)),t.cellHeightMayIncrease=s||u||t.mayHaveMarkup||(void 0===h?b(v):h),t.needsConvertToTspans=t.mayHaveMarkup||t.wrappingNeeded||t.latex,t.wrappingNeeded){var m=(\" \"===n.wrapSplitCharacter?v.replace(/<a href=/gi,\"<a_href=\"):v).split(n.wrapSplitCharacter),y=\" \"===n.wrapSplitCharacter?m.map(function(t){return t.replace(/<a_href=/gi,\"<a href=\")}):m;t.fragments=y.map(function(t){return{text:t,width:null}}),t.fragments.push({fragment:n.wrapSpacer,width:null}),f=y.join(n.lineBreaker)+n.lineBreaker+n.wrapSpacer}else delete t.fragments,f=v;return f}).attr(\"dy\",function(t){return t.needsConvertToTspans?0:\"0.75em\"}).each(function(t){var o=i.select(this),l=t.wrappingNeeded?C:L;t.needsConvertToTspans?s.convertToTspans(o,a,l(r,this,e,a,t)):i.select(this.parentNode).attr(\"transform\",function(t){return\"translate(\"+P(t)+\" \"+n.cellPad+\")\"}).attr(\"text-anchor\",function(t){return{left:\"start\",center:\"middle\",right:\"end\"}[t.align]})})}function b(t){return-1!==t.indexOf(n.wrapSplitCharacter)}function _(t,e,r){if(Array.isArray(t)){var n=t[Math.min(e,t.length-1)];return Array.isArray(n)?n[Math.min(r,n.length-1)]:n}return t}function w(t,e,r){t.transition().ease(n.releaseTransitionEase).duration(n.releaseTransitionDuration).attr(\"transform\",\"translate(\"+e.x+\" \"+r+\")\")}function k(t){return\"cells\"===t.type}function T(t){return\"header\"===t.type}function A(t){return(t.rowBlocks.length?t.rowBlocks[0].auxiliaryBlocks:[]).reduce(function(t,e){return t+I(e,1/0)},0)}function M(t,e,r){var n=v(e)[0];if(void 0!==n){var i=n.rowBlocks,a=n.calcdata,o=z(i,i.length),s=n.calcdata.groupHeight-A(n),l=a.scrollY=Math.max(0,Math.min(o-s,a.scrollY)),c=function(t,e,r){for(var n=[],i=0,a=0;a<t.length;a++){for(var o=t[a],s=o.rows,l=0,c=0;c<s.length;c++)l+=s[c].rowHeight;o.allRowsHeight=l,e<i+l&&e+r>i&&n.push(a),i+=l}return n}(i,l,s);1===c.length&&(c[0]===i.length-1?c.unshift(c[0]-1):c.push(c[0]+1)),c[0]%2&&c.reverse(),e.each(function(t,e){t.page=c[e],t.scrollY=l}),e.attr(\"transform\",function(t){return\"translate(0 \"+(z(t.rowBlocks,t.page)-t.scrollY)+\")\"}),t&&(E(t,r,e,c,n.prevPages,n,0),E(t,r,e,c,n.prevPages,n,1),m(r,t))}}function S(t,e,r,a){return function(o){var s=o.calcdata?o.calcdata:o,l=e.filter(function(t){return s.key===t.key}),c=r||s.scrollbarState.dragMultiplier,u=s.scrollY;s.scrollY=void 0===a?s.scrollY+c*i.event.dy:a;var h=l.selectAll(\".\"+n.cn.yColumn).selectAll(\".\"+n.cn.columnBlock).filter(k);return M(t,h,l),s.scrollY===u}}function E(t,e,r,n,i,a,o){n[o]!==i[o]&&(clearTimeout(a.currentRepaint[o]),a.currentRepaint[o]=setTimeout(function(){var a=r.filter(function(t,e){return e===o&&n[e]!==i[e]});y(t,e,a,r),i[o]=n[o]}))}function C(t,e,r,a){return function(){var o=i.select(e.parentNode);o.each(function(t){var e=t.fragments;o.selectAll(\"tspan.line\").each(function(t,r){e[r].width=this.getComputedTextLength()});var r,i,a=e[e.length-1].width,s=e.slice(0,-1),l=[],c=0,u=t.column.columnWidth-2*n.cellPad;for(t.value=\"\";s.length;)c+(i=(r=s.shift()).width+a)>u&&(t.value+=l.join(n.wrapSpacer)+n.lineBreaker,l=[],c=0),l.push(r.text),c+=i;c&&(t.value+=l.join(n.wrapSpacer)),t.wrapped=!0}),o.selectAll(\"tspan.line\").remove(),x(o.select(\".\"+n.cn.cellText),r,t,a),i.select(e.parentNode.parentNode).call(O)}}function L(t,e,r,a,o){return function(){if(!o.settledY){var s=i.select(e.parentNode),l=R(o),c=o.key-l.firstRowIndex,u=l.rows[c].rowHeight,h=o.cellHeightMayIncrease?e.parentNode.getBoundingClientRect().height+2*n.cellPad:u,f=Math.max(h,u);f-l.rows[c].rowHeight&&(l.rows[c].rowHeight=f,t.selectAll(\".\"+n.cn.columnCell).call(O),M(null,t.filter(k),0),m(r,a,!0)),s.attr(\"transform\",function(){var t=this.parentNode.getBoundingClientRect(),e=i.select(this.parentNode).select(\".\"+n.cn.cellRect).node().getBoundingClientRect(),r=this.transform.baseVal.consolidate(),a=e.top-t.top+(r?r.matrix.f:n.cellPad);return\"translate(\"+P(o,i.select(this.parentNode).select(\".\"+n.cn.cellTextHolder).node().getBoundingClientRect().width)+\" \"+a+\")\"}),o.settledY=!0}}}function P(t,e){switch(t.align){case\"left\":return n.cellPad;case\"right\":return t.column.columnWidth-(e||0)-n.cellPad;case\"center\":return(t.column.columnWidth-(e||0))/2;default:return n.cellPad}}function O(t){t.attr(\"transform\",function(t){var e=t.rowBlocks[0].auxiliaryBlocks.reduce(function(t,e){return t+I(e,1/0)},0);return\"translate(0 \"+(I(R(t),t.key)+e)+\")\"}).selectAll(\".\"+n.cn.cellRect).attr(\"height\",function(t){return(e=R(t),r=t.key,e.rows[r-e.firstRowIndex]).rowHeight;var e,r})}function z(t,e){for(var r=0,n=e-1;n>=0;n--)r+=D(t[n]);return r}function I(t,e){for(var r=0,n=0;n<t.rows.length&&t.rows[n].rowIndex<e;n++)r+=t.rows[n].rowHeight;return r}function D(t){var e=t.allRowsHeight;if(void 0!==e)return e;for(var r=0,n=0;n<t.rows.length;n++)r+=t.rows[n].rowHeight;return t.allRowsHeight=r,r}function R(t){return t.rowBlocks[t.page]}e.exports=function(t,e){var r=!t._context.staticPlot,s=t._fullLayout._paper.selectAll(\".\"+n.cn.table).data(e.map(function(e){var r=a.unwrap(e).trace;return u(t,r)}),a.keyFun);s.exit().remove(),s.enter().append(\"g\").classed(n.cn.table,!0).attr(\"overflow\",\"visible\").style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"overflow\",\"visible\").style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"all\"),s.attr(\"width\",function(t){return t.width+t.size.l+t.size.r}).attr(\"height\",function(t){return t.height+t.size.t+t.size.b}).attr(\"transform\",function(t){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"});var f=s.selectAll(\".\"+n.cn.tableControlView).data(a.repeat,a.keyFun),x=f.enter().append(\"g\").classed(n.cn.tableControlView,!0).style(\"box-sizing\",\"content-box\");r&&x.on(\"mousemove\",function(e){f.filter(function(t){return e===t}).call(m,t)}).on(\"mousewheel\",function(e){if(!e.scrollbarState.wheeling){e.scrollbarState.wheeling=!0;var r=e.scrollY+i.event.deltaY;S(t,f,null,r)(e)||(i.event.stopPropagation(),i.event.preventDefault()),e.scrollbarState.wheeling=!1}}).call(m,t,!0),f.attr(\"transform\",function(t){return\"translate(\"+t.size.l+\" \"+t.size.t+\")\"});var b=f.selectAll(\".\"+n.cn.scrollBackground).data(a.repeat,a.keyFun);b.enter().append(\"rect\").classed(n.cn.scrollBackground,!0).attr(\"fill\",\"none\"),b.attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}),f.each(function(e){o.setClipUrl(i.select(this),d(t,e),t)});var _=f.selectAll(\".\"+n.cn.yColumn).data(function(t){return t.columns},a.keyFun);_.enter().append(\"g\").classed(n.cn.yColumn,!0),_.exit().remove(),_.attr(\"transform\",function(t){return\"translate(\"+t.x+\" 0)\"}),r&&_.call(i.behavior.drag().origin(function(e){return w(i.select(this),e,-n.uplift),l(this),e.calcdata.columnDragInProgress=!0,m(f.filter(function(t){return e.calcdata.key===t.key}),t),e}).on(\"drag\",function(t){var e=i.select(this),r=function(e){return(t===e?i.event.x:e.x)+e.columnWidth/2};t.x=Math.max(-n.overdrag,Math.min(t.calcdata.width+n.overdrag-t.columnWidth,i.event.x)),v(_).filter(function(e){return e.calcdata.key===t.calcdata.key}).sort(function(t,e){return r(t)-r(e)}).forEach(function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e)}),_.filter(function(e){return t!==e}).transition().ease(n.transitionEase).duration(n.transitionDuration).attr(\"transform\",function(t){return\"translate(\"+t.x+\" 0)\"}),e.call(c).attr(\"transform\",\"translate(\"+t.x+\" -\"+n.uplift+\" )\")}).on(\"dragend\",function(e){var r=i.select(this),n=e.calcdata;e.x=e.xScale(e),e.calcdata.columnDragInProgress=!1,w(r,e,0),function(t,e,r){var n=e.gdColumnsOriginalOrder;e.gdColumns.sort(function(t,e){return r[n.indexOf(t)]-r[n.indexOf(e)]}),e.columnorder=r,t.emit(\"plotly_restyle\")}(t,n,n.columns.map(function(t){return t.xIndex}))})),_.each(function(e){o.setClipUrl(i.select(this),g(t,e),t)});var A=_.selectAll(\".\"+n.cn.columnBlock).data(h.splitToPanels,a.keyFun);A.enter().append(\"g\").classed(n.cn.columnBlock,!0).attr(\"id\",function(t){return t.key}),A.style(\"cursor\",function(t){return t.dragHandle?\"ew-resize\":t.calcdata.scrollbarState.barWiggleRoom?\"ns-resize\":\"default\"});var E=A.filter(T),C=A.filter(k);r&&C.call(i.behavior.drag().origin(function(t){return i.event.stopPropagation(),t}).on(\"drag\",S(t,f,-1)).on(\"dragend\",function(){})),y(t,f,E,A),y(t,f,C,A);var L=f.selectAll(\".\"+n.cn.scrollAreaClip).data(a.repeat,a.keyFun);L.enter().append(\"clipPath\").classed(n.cn.scrollAreaClip,!0).attr(\"id\",function(e){return d(t,e)});var P=L.selectAll(\".\"+n.cn.scrollAreaClipRect).data(a.repeat,a.keyFun);P.enter().append(\"rect\").classed(n.cn.scrollAreaClipRect,!0).attr(\"x\",-n.overdrag).attr(\"y\",-n.uplift).attr(\"fill\",\"none\"),P.attr(\"width\",function(t){return t.width+2*n.overdrag}).attr(\"height\",function(t){return t.height+n.uplift}),_.selectAll(\".\"+n.cn.columnBoundary).data(a.repeat,a.keyFun).enter().append(\"g\").classed(n.cn.columnBoundary,!0);var O=_.selectAll(\".\"+n.cn.columnBoundaryClippath).data(a.repeat,a.keyFun);O.enter().append(\"clipPath\").classed(n.cn.columnBoundaryClippath,!0),O.attr(\"id\",function(e){return g(t,e)});var z=O.selectAll(\".\"+n.cn.columnBoundaryRect).data(a.repeat,a.keyFun);z.enter().append(\"rect\").classed(n.cn.columnBoundaryRect,!0).attr(\"fill\",\"none\"),z.attr(\"width\",function(t){return t.columnWidth+2*p(t)}).attr(\"height\",function(t){return t.calcdata.height+2*p(t)+n.uplift}).attr(\"x\",function(t){return-p(t)}).attr(\"y\",function(t){return-p(t)}),M(null,C,f)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/gup\":717,\"../../lib/svg_text_utils\":743,\"./constants\":1232,\"./data_preparation_helper\":1233,\"./data_split_helpers\":1234,d3:163}],1238:[function(t,e,r){\"use strict\";var n=t(\"../box/attributes\"),i=t(\"../../lib/extend\").extendFlat;e.exports={y:n.y,x:n.x,x0:n.x0,y0:n.y0,name:i({},n.name,{}),orientation:i({},n.orientation,{}),bandwidth:{valType:\"number\",min:0,editType:\"calc\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},scalemode:{valType:\"enumerated\",values:[\"width\",\"count\"],dflt:\"width\",editType:\"calc\"},spanmode:{valType:\"enumerated\",values:[\"soft\",\"hard\",\"manual\"],dflt:\"soft\",editType:\"calc\"},span:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}],editType:\"calc\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,points:i({},n.boxpoints,{}),jitter:i({},n.jitter,{}),pointpos:i({},n.pointpos,{}),width:i({},n.width,{}),marker:n.marker,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,box:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},width:{valType:\"number\",min:0,max:1,dflt:.25,editType:\"plot\"},fillcolor:{valType:\"color\",editType:\"style\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},editType:\"plot\"},meanline:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"plot\"},side:{valType:\"enumerated\",values:[\"both\",\"positive\",\"negative\"],dflt:\"both\",editType:\"calc\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,hoveron:{valType:\"flaglist\",flags:[\"violins\",\"points\",\"kde\"],dflt:\"violins+points+kde\",extras:[\"all\"],editType:\"style\"}}},{\"../../lib/extend\":710,\"../box/attributes\":880}],1239:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/calc\"),o=t(\"./helpers\"),s=t(\"../../constants/numerical\").BADNUM;function l(t,e,r){var i=e.max-e.min;if(!i)return t.bandwidth?t.bandwidth:0;if(t.bandwidth)return Math.max(t.bandwidth,i/1e4);var a=r.length,o=n.stdev(r,a-1,e.mean);return Math.max(function(t,e,r){return 1.059*Math.min(e,r/1.349)*Math.pow(t,-.2)}(a,o,e.q3-e.q1),i/100)}function c(t,e,r,n){var a,o=t.spanmode,l=t.span||[],c=[e.min,e.max],u=[e.min-2*n,e.max+2*n];function h(n){var i=l[n],a=\"multicategory\"===r.type?r.r2c(i):r.d2c(i,0,t[e.valLetter+\"calendar\"]);return a===s?u[n]:a}var f={type:\"linear\",range:a=\"soft\"===o?u:\"hard\"===o?c:[h(0),h(1)]};return i.setConvert(f),f.cleanRange(),a}e.exports=function(t,e){var r=a(t,e);if(r[0].t.empty)return r;for(var s=t._fullLayout,u=i.getFromId(t,e[\"h\"===e.orientation?\"xaxis\":\"yaxis\"]),h=1/0,f=-1/0,p=0,d=0,g=0;g<r.length;g++){var v=r[g],m=v.pts.map(o.extractVal),y=v.bandwidth=l(e,v,m),x=v.span=c(e,v,u,y);if(v.min===v.max&&0===y)x=v.span=[v.min,v.max],v.density=[{v:1,t:x[0]}],v.bandwidth=y,p=Math.max(p,1);else{var b=x[1]-x[0],_=Math.ceil(b/(y/3)),w=b/_;if(!isFinite(w)||!isFinite(_))return n.error(\"Something went wrong with computing the violin span\"),r[0].t.empty=!0,r;var k=o.makeKDE(v,e,m);v.density=new Array(_);for(var T=0,A=x[0];A<x[1]+w/2;T++,A+=w){var M=k(A);v.density[T]={v:M,t:A},p=Math.max(p,M)}}d=Math.max(d,m.length),h=Math.min(h,x[0]),f=Math.max(f,x[1])}var S=i.findExtremes(u,[h,f],{padded:!0});if(e._extremes[u._id]=S,e.width)r[0].t.maxKDE=p;else{var E=s._violinScaleGroupStats,C=e.scalegroup,L=E[C];L?(L.maxKDE=Math.max(L.maxKDE,p),L.maxCount=Math.max(L.maxCount,d)):E[C]={maxKDE:p,maxCount:d}}return r[0].t.labels.kde=n._(t,\"kde:\"),r}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../box/calc\":881,\"./helpers\":1242}],1240:[function(t,e,r){\"use strict\";var n=t(\"../box/cross_trace_calc\").setPositionOffset,i=[\"v\",\"h\"];e.exports=function(t,e){for(var r=t.calcdata,a=e.xaxis,o=e.yaxis,s=0;s<i.length;s++){for(var l=i[s],c=\"h\"===l?o:a,u=[],h=0;h<r.length;h++){var f=r[h],p=f[0].t,d=f[0].trace;!0!==d.visible||\"violin\"!==d.type||p.empty||d.orientation!==l||d.xaxis!==a._id||d.yaxis!==o._id||u.push(h)}n(\"violin\",t,u,c)}}},{\"../box/cross_trace_calc\":882}],1241:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../box/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}function c(r,i){return n.coerce2(t,e,o,r,i)}if(a.handleSampleDefaults(t,e,l,s),!1!==e.visible){l(\"bandwidth\"),l(\"side\"),l(\"width\")||(l(\"scalegroup\",e.name),l(\"scalemode\"));var u,h=l(\"span\");Array.isArray(h)&&(u=\"manual\"),l(\"spanmode\",u);var f=l(\"line.color\",(t.marker||{}).color||r),p=l(\"line.width\"),d=l(\"fillcolor\",i.addOpacity(e.line.color,.5));a.handlePointsDefaults(t,e,l,{prefix:\"\"});var g=c(\"box.width\"),v=c(\"box.fillcolor\",d),m=c(\"box.line.color\",f),y=c(\"box.line.width\",p);l(\"box.visible\",Boolean(g||v||m||y))||(e.box={visible:!1});var x=c(\"meanline.color\",f),b=c(\"meanline.width\",p);l(\"meanline.visible\",Boolean(x||b))||(e.meanline={visible:!1})}}},{\"../../components/color\":593,\"../../lib\":719,\"../box/defaults\":883,\"./attributes\":1238}],1242:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=function(t){return 1/Math.sqrt(2*Math.PI)*Math.exp(-.5*t*t)};r.makeKDE=function(t,e,r){var n=r.length,a=i,o=t.bandwidth,s=1/(n*o);return function(t){for(var e=0,i=0;i<n;i++)e+=a((t-r[i])/o);return s*e}},r.getPositionOnKdePath=function(t,e,r){var i,a;\"h\"===e.orientation?(i=\"y\",a=\"x\"):(i=\"x\",a=\"y\");var o=n.findPointOnPath(t.path,r,a,{pathLength:t.pathLength}),s=t.posCenterPx,l=o[i];return[l,\"both\"===e.side?2*s-l:s]},r.getKdeValue=function(t,e,n){var i=t.pts.map(r.extractVal);return r.makeKDE(t,e,i)(n)/t.posDensityScale},r.extractVal=function(t){return t.v}},{\"../../lib\":719}],1243:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/hover\"),o=t(\"./helpers\");e.exports=function(t,e,r,s,l){var c,u,h=t.cd,f=h[0].trace,p=f.hoveron,d=-1!==p.indexOf(\"violins\"),g=-1!==p.indexOf(\"kde\"),v=[];if(d||g){var m=a.hoverOnBoxes(t,e,r,s);if(g&&m.length>0){var y,x,b,_,w,k=t.xa,T=t.ya;\"h\"===f.orientation?(w=e,y=\"y\",b=T,x=\"x\",_=k):(w=r,y=\"x\",b=k,x=\"y\",_=T);var A=h[t.index];if(w>=A.span[0]&&w<=A.span[1]){var M=n.extendFlat({},t),S=_.c2p(w,!0),E=o.getKdeValue(A,f,w),C=o.getPositionOnKdePath(A,f,S),L=b._offset,P=b._length;M[y+\"0\"]=C[0],M[y+\"1\"]=C[1],M[x+\"0\"]=M[x+\"1\"]=S,M[x+\"Label\"]=x+\": \"+i.hoverLabelText(_,w)+\", \"+h[0].t.labels.kde+\" \"+E.toFixed(3),M.spikeDistance=m[0].spikeDistance;var O=y+\"Spike\";M[O]=m[0][O],m[0].spikeDistance=void 0,m[0][O]=void 0,M.hovertemplate=!1,v.push(M),(u={stroke:t.color})[y+\"1\"]=n.constrain(L+C[0],L,L+P),u[y+\"2\"]=n.constrain(L+C[1],L,L+P),u[x+\"1\"]=u[x+\"2\"]=_._offset+S}}d&&(v=v.concat(m))}-1!==p.indexOf(\"points\")&&(c=a.hoverOnPoints(t,e,r));var z=l.selectAll(\".violinline-\"+f.uid).data(u?[0]:[]);return z.enter().append(\"line\").classed(\"violinline-\"+f.uid,!0).attr(\"stroke-width\",1.5),z.exit().remove(),z.attr(u),\"closest\"===s?c?[c]:v:c?(v.push(c),v):v}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../box/hover\":885,\"./helpers\":1242}],1244:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../box/defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../box/select\"),moduleType:\"trace\",name:\"violin\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"violinLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../box/defaults\":883,\"../box/select\":890,\"../scatter/style\":1134,\"./attributes\":1238,\"./calc\":1239,\"./cross_trace_calc\":1240,\"./defaults\":1241,\"./hover\":1243,\"./layout_attributes\":1245,\"./layout_defaults\":1246,\"./plot\":1247,\"./style\":1248}],1245:[function(t,e,r){\"use strict\";var n=t(\"../box/layout_attributes\"),i=t(\"../../lib\").extendFlat;e.exports={violinmode:i({},n.boxmode,{}),violingap:i({},n.boxgap,{}),violingroupgap:i({},n.boxgroupgap,{})}},{\"../../lib\":719,\"../box/layout_attributes\":887}],1246:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"../box/layout_defaults\");e.exports=function(t,e,r){a._supply(t,e,r,function(r,a){return n.coerce(t,e,i,r,a)},\"violin\")}},{\"../../lib\":719,\"../box/layout_defaults\":888,\"./layout_attributes\":1245}],1247:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../box/plot\"),s=t(\"../scatter/line_points\"),l=t(\"./helpers\");e.exports=function(t,e,r,c){var u=t._fullLayout,h=e.xaxis,f=e.yaxis;function p(t){var e=s(t,{xaxis:h,yaxis:f,connectGaps:!0,baseTolerance:.75,shape:\"spline\",simplify:!0});return a.smoothopen(e[0],1)}i.makeTraceGroups(c,r,\"trace violins\").each(function(t){var r=n.select(this),a=t[0],s=a.t,c=a.trace;if(!0!==c.visible||s.empty)r.remove();else{var d=s.bPos,g=s.bdPos,v=e[s.valLetter+\"axis\"],m=e[s.posLetter+\"axis\"],y=\"both\"===c.side,x=y||\"positive\"===c.side,b=y||\"negative\"===c.side,_=r.selectAll(\"path.violin\").data(i.identity);_.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"violin\"),_.exit().remove(),_.each(function(t){var e,r,i,a,o,l,h,f,_=n.select(this),w=t.density,k=w.length,T=t.pos+d,A=m.c2p(T);if(c.width)e=s.maxKDE/g;else{var M=u._violinScaleGroupStats[c.scalegroup];e=\"count\"===c.scalemode?M.maxKDE/g*(M.maxCount/t.pts.length):M.maxKDE/g}if(x){for(h=new Array(k),o=0;o<k;o++)(f=h[o]={})[s.posLetter]=T+w[o].v/e,f[s.valLetter]=w[o].t;r=p(h)}if(b){for(h=new Array(k),l=0,o=k-1;l<k;l++,o--)(f=h[l]={})[s.posLetter]=T-w[o].v/e,f[s.valLetter]=w[o].t;i=p(h)}if(y)a=r+\"L\"+i.substr(1)+\"Z\";else{var S=[A,v.c2p(w[0].t)],E=[A,v.c2p(w[k-1].t)];\"h\"===c.orientation&&(S.reverse(),E.reverse()),a=x?\"M\"+S+\"L\"+r.substr(1)+\"L\"+E:\"M\"+E+\"L\"+i.substr(1)+\"L\"+S}_.attr(\"d\",a),t.posCenterPx=A,t.posDensityScale=e*g,t.path=_.node(),t.pathLength=t.path.getTotalLength()/(y?2:1)});var w,k,T,A=c.box,M=A.width,S=(A.line||{}).width;y?(w=g*M,k=0):x?(w=[0,g*M/2],k=-S):(w=[g*M/2,0],k=S),o.plotBoxAndWhiskers(r,{pos:m,val:v},c,{bPos:d,bdPos:w,bPosPxOffset:k}),o.plotBoxMean(r,{pos:m,val:v},c,{bPos:d,bdPos:w,bPosPxOffset:k}),!c.box.visible&&c.meanline.visible&&(T=i.identity);var E=r.selectAll(\"path.meanline\").data(T||[]);E.enter().append(\"path\").attr(\"class\",\"meanline\").style(\"fill\",\"none\").style(\"vector-effect\",\"non-scaling-stroke\"),E.exit().remove(),E.each(function(t){var e=v.c2p(t.mean,!0),r=l.getPositionOnKdePath(t,c,e);n.select(this).attr(\"d\",\"h\"===c.orientation?\"M\"+e+\",\"+r[0]+\"V\"+r[1]:\"M\"+r[0]+\",\"+e+\"H\"+r[1])}),o.plotPoints(r,{x:h,y:f},c,s)}})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../box/plot\":889,\"../scatter/line_points\":1125,\"./helpers\":1242,d3:163}],1248:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../scatter/style\").stylePoints;e.exports=function(t){var e=n.select(t).selectAll(\"g.trace.violins\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.each(function(e){var r=e[0].trace,o=n.select(this),s=r.box||{},l=s.line||{},c=r.meanline||{},u=c.width;o.selectAll(\"path.violin\").style(\"stroke-width\",r.line.width+\"px\").call(i.stroke,r.line.color).call(i.fill,r.fillcolor),o.selectAll(\"path.box\").style(\"stroke-width\",l.width+\"px\").call(i.stroke,l.color).call(i.fill,s.fillcolor);var h={\"stroke-width\":u+\"px\",\"stroke-dasharray\":2*u+\"px,\"+u+\"px\"};o.selectAll(\"path.mean\").style(h).call(i.stroke,c.color),o.selectAll(\"path.meanline\").style(h).call(i.stroke,c.color),a(o,r,t)})}},{\"../../components/color\":593,\"../scatter/style\":1134,d3:163}],1249:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../isosurface/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=e.exports=s(o({x:i.x,y:i.y,z:i.z,value:i.value,isomin:i.isomin,isomax:i.isomax,surface:i.surface,spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:1}},slices:i.slices,caps:i.caps,text:i.text,hovertext:i.hovertext,hovertemplate:i.hovertemplate},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{colorbar:i.colorbar,opacity:i.opacity,opacityscale:{valType:\"any\",editType:\"calc\"},lightposition:i.lightposition,lighting:i.lighting,flatshading:i.flatshading,contour:i.contour,hoverinfo:o({},a.hoverinfo)}),\"calc\",\"nested\");l.x.editType=l.y.editType=l.z.editType=l.value.editType=\"calc+clearAxisTypes\",l.transforms=void 0},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../isosurface/attributes\":1048}],1250:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib/gl_format_color\").parseColorScale,a=t(\"../../lib/str2rgbarray\"),o=t(\"../../components/colorscale\").extractOpts,s=t(\"../../plots/gl3d/zip3\"),l=t(\"../isosurface/convert\").findNearestOnAxis,c=t(\"../isosurface/convert\").generateIsoMeshes;function u(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var h=u.prototype;h.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._x[e],n=this.data._y[e],i=this.data._z[e],a=this.data._Ys.length,o=this.data._Zs.length,s=l(r,this.data._Xs).id,c=l(n,this.data._Ys).id,u=l(i,this.data._Zs).id,h=t.index=u+o*c+o*a*s;t.traceCoordinate=[this.data._x[h],this.data._y[h],this.data._z[h],this.data.value[h]];var f=this.data.hovertext||this.data.text;return Array.isArray(f)&&void 0!==f[h]?t.textLabel=f[h]:f&&(t.textLabel=f),!0}},h.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map(function(e){return t.d2l(e,0,n)*r})}this.data=c(t);var l={positions:s(n(r.xaxis,t._x,e.dataScale[0],t.xcalendar),n(r.yaxis,t._y,e.dataScale[1],t.ycalendar),n(r.zaxis,t._z,e.dataScale[2],t.zcalendar)),cells:s(t._i,t._j,t._k),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,opacityscale:t.opacityscale,contourEnable:t.contour.show,contourColor:a(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},u=o(t);l.vertexIntensity=t._intensity,l.vertexIntensityBounds=[u.min,u.max],l.colormap=i(t),this.mesh.update(l)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new u(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":605,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../../plots/gl3d/zip3\":818,\"../isosurface/convert\":1050,\"gl-mesh3d\":280}],1251:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../isosurface/defaults\").supplyIsoDefaults;e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}a(t,e,r,o,s);var l=s(\"opacityscale\");\"max\"===l?e.opacityscale=[[0,.1],[1,1]]:\"min\"===l?e.opacityscale=[[0,1],[1,.1]]:\"extremes\"===l?e.opacityscale=function(t,e){for(var r=[],n=0;n<32;n++){var i=n/31,a=e+(1-e)*(1-Math.pow(Math.sin(t*i*Math.PI),2));r.push([i,Math.max(1,Math.min(0,a))])}return r}(1,.1):function(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var n=t[r];if(2!==n.length||+n[0]<e)return!1;e=+n[0]}return!0}(l)||(e.opacityscale=void 0)}},{\"../../lib\":719,\"../isosurface/defaults\":1051,\"./attributes\":1249}],1252:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../isosurface/calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"volume\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],meta:{}}},{\"../../plots/gl3d\":807,\"../isosurface/calc\":1049,\"./attributes\":1249,\"./convert\":1250,\"./defaults\":1251}],1253:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"./constants\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../components/color\");function u(t){return{marker:{color:l({},n.marker.color,{arrayOk:!1,editType:\"style\"}),line:{color:l({},n.marker.line.color,{arrayOk:!1,editType:\"style\"}),width:l({},n.marker.line.width,{arrayOk:!1,editType:\"style\"}),editType:\"style\"},editType:\"style\"},editType:\"style\"}}e.exports={measure:{valType:\"data_array\",dflt:[],editType:\"calc\"},base:{valType:\"number\",dflt:null,arrayOk:!1,editType:\"calc\"},x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,hovertext:n.hovertext,hovertemplate:o({},{keys:s.eventDataKeys}),hoverinfo:l({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"initial\",\"delta\",\"final\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"initial\",\"delta\",\"final\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},text:n.text,textposition:n.textposition,insidetextanchor:n.insidetextanchor,textangle:n.textangle,textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:n.orientation,offset:n.offset,width:n.width,increasing:u(),decreasing:u(),totals:u(),connector:{line:{color:l({},i.color,{dflt:c.defaultLine}),width:l({},i.width,{editType:\"plot\"}),dash:i.dash,editType:\"plot\"},mode:{valType:\"enumerated\",values:[\"spanning\",\"between\"],dflt:\"between\",editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":593,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../bar/attributes\":857,\"../scatter/attributes\":1112,\"./constants\":1255}],1254:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\").mergeArray,a=t(\"../scatter/calc_selection\"),o=t(\"../../constants/numerical\").BADNUM;function s(t){return\"a\"===t||\"absolute\"===t}function l(t){return\"t\"===t||\"total\"===t}e.exports=function(t,e){var r,c,u=n.getFromId(t,e.xaxis||\"x\"),h=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=u.makeCalcdata(e,\"x\"),c=h.makeCalcdata(e,\"y\")):(r=h.makeCalcdata(e,\"y\"),c=u.makeCalcdata(e,\"x\"));for(var f,p=Math.min(c.length,r.length),d=new Array(p),g=0,v=!1,m=0;m<p;m++){var y=r[m]||0,x=!1;(r[m]!==o||l(e.measure[m])||s(e.measure[m]))&&m+1<p&&(r[m+1]!==o||l(e.measure[m+1])||s(e.measure[m+1]))&&(x=!0);var b=d[m]={i:m,p:c[m],s:y,rawS:y,cNext:x};s(e.measure[m])?(g=b.s,b.isSum=!0,b.dir=\"totals\",b.s=g):l(e.measure[m])?(b.isSum=!0,b.dir=\"totals\",b.s=g):(b.isSum=!1,b.dir=b.rawS<0?\"decreasing\":\"increasing\",f=b.s,b.s=g+f,g+=f),\"totals\"===b.dir&&(v=!0),e.ids&&(b.id=String(e.ids[m])),b.v=(e.base||0)+g}return d.length&&(d[0].hasTotals=v),i(e.text,d,\"tx\"),i(e.hovertext,d,\"htx\"),a(d,e),d}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scatter/calc_selection\":1114}],1255:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"initial\",\"delta\",\"final\"]}},{}],1256:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],h=[],f=[];for(i=0;i<o.length;i++){var p=o[i];!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"waterfall\"===p.type&&(r=s[i],\"h\"===p.orientation?f.push(r):h.push(r),u.push(r))}var d={mode:a.waterfallmode,norm:a.waterfallnorm,gap:a.waterfallgap,groupgap:a.waterfallgroupgap};for(n(t,l,c,h,d),n(t,c,l,f,d),i=0;i<u.length;i++){r=u[i];for(var g=0;g<r.length;g++){var v=r[g];!1===v.isSum&&(v.s0+=0===g?0:r[g-1].s),g+1<r.length&&(r[g].nextP0=r[g+1].p0,r[g].nextS0=r[g+1].s0)}}}},{\"../bar/cross_trace_calc\":860}],1257:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"./attributes\"),l=t(\"../../components/color\"),c=t(\"../../constants/delta.js\"),u=c.INCREASING.COLOR,h=c.DECREASING.COLOR,f=\"#4499FF\";function p(t,e,r){t(e+\".marker.color\",r),t(e+\".marker.line.color\",l.defaultLine),t(e+\".marker.line.width\")}e.exports={supplyDefaults:function(t,e,r,i){function l(r,i){return n.coerce(t,e,s,r,i)}if(o(t,e,i,l)){l(\"measure\"),l(\"orientation\",e.x&&!e.y?\"h\":\"v\"),l(\"base\"),l(\"offset\"),l(\"width\"),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\");var c=l(\"textposition\");a(t,e,i,l,c,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"!==e.textposition&&l(\"textinfo\"),p(l,\"increasing\",u),p(l,\"decreasing\",h),p(l,\"totals\",f),l(\"connector.visible\")&&(l(\"connector.mode\"),l(\"connector.line.width\")&&(l(\"connector.line.color\"),l(\"connector.line.dash\")))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,s,t)}if(\"group\"===e.waterfallmode)for(var l=0;l<t.length;l++)r=(a=t[l])._input,i(r,a,e,o)}}},{\"../../components/color\":593,\"../../constants/delta.js\":689,\"../../lib\":719,\"../bar/defaults\":861,\"../scatter/xy_defaults\":1137,\"./attributes\":1253}],1258:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"initial\"in e&&(t.initial=e.initial),\"delta\"in e&&(t.delta=e.delta),\"final\"in e&&(t.final=e.final),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],1259:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\").hoverLabelText,i=t(\"../../components/color\").opacity,a=t(\"../bar/hover\").hoverOnBars,o=t(\"../../constants/delta.js\"),s=o.INCREASING.SYMBOL,l=o.DECREASING.SYMBOL;e.exports=function(t,e,r,o){var c=a(t,e,r,o);if(c){var u=c.cd,h=u[0].trace,f=\"h\"===h.orientation,p=f?t.xa:t.ya,d=u[c.index],g=d.isSum?d.b+d.s:d.rawS;if(!d.isSum){c.initial=d.b+d.s-g,c.delta=g,c.final=c.initial+c.delta;var v=w(Math.abs(c.delta));c.deltaLabel=g<0?\"(\"+v+\")\":v,c.finalLabel=w(c.final),c.initialLabel=w(c.initial)}var m=d.hi||h.hoverinfo,y=[];if(m&&\"none\"!==m&&\"skip\"!==m){var x=\"all\"===m,b=m.split(\"+\"),_=function(t){return x||-1!==b.indexOf(t)};d.isSum||(!_(\"final\")||_(f?\"x\":\"y\")||y.push(c.finalLabel),_(\"delta\")&&(g<0?y.push(c.deltaLabel+\" \"+l):y.push(c.deltaLabel+\" \"+s)),_(\"initial\")&&y.push(\"Initial: \"+c.initialLabel))}return y.length&&(c.extraText=y.join(\"<br>\")),c.color=function(t,e){var r=t[e.dir].marker,n=r.color,a=r.line.color,o=r.line.width;if(i(n))return n;if(i(a)&&o)return a}(h,d),[c]}function w(t){return n(p,t)}}},{\"../../components/color\":593,\"../../constants/delta.js\":689,\"../../plots/cartesian/axes\":767,\"../bar/hover\":863}],1260:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"waterfall\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../bar/select\":868,\"./attributes\":1253,\"./calc\":1254,\"./cross_trace_calc\":1256,\"./defaults\":1257,\"./event_data\":1258,\"./hover\":1259,\"./layout_attributes\":1261,\"./layout_defaults\":1262,\"./plot\":1263,\"./style\":1264}],1261:[function(t,e,r){\"use strict\";e.exports={waterfallmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"group\",editType:\"calc\"},waterfallgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},waterfallgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],1262:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"waterfall\"===l.type){a=!0;break}}a&&(o(\"waterfallmode\"),o(\"waterfallgap\",.2),o(\"waterfallgroupgap\"))}},{\"../../lib\":719,\"./layout_attributes\":1261}],1263:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../bar/plot\").plot;e.exports=function(t,e,r,s){var l=t._fullLayout;o(t,e,r,s,{mode:l.waterfallmode,norm:l.waterfallmode,gap:l.waterfallgap,groupgap:l.waterfallgroupgap}),function(t,e,r,o){var s=e.xaxis,l=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each(function(r){var o=n.select(this),c=r[0].trace,u=i.ensureSingle(o,\"g\",\"lines\");if(c.connector&&c.connector.visible){var h=\"h\"===c.orientation,f=c.connector.mode,p=u.selectAll(\"g.line\").data(i.identity);p.enter().append(\"g\").classed(\"line\",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var c=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),n?[i,a]:[a,i]}(r,s,l,h),u=c[0],p=c[1],g=\"\";\"spanning\"===f&&!r.isSum&&o>0&&(g+=h?\"M\"+u[0]+\",\"+p[1]+\"V\"+p[0]:\"M\"+u[1]+\",\"+p[0]+\"H\"+u[0]),\"between\"!==f&&(r.isSum||o<d-1)&&(g+=h?\"M\"+u[1]+\",\"+p[0]+\"V\"+p[1]:\"M\"+u[0]+\",\"+p[1]+\"H\"+u[1]),void 0!==u[2]&&void 0!==p[2]&&(g+=h?\"M\"+u[1]+\",\"+p[1]+\"V\"+p[2]:\"M\"+u[1]+\",\"+p[1]+\"H\"+u[2]),\"\"===g&&(g=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}})}else u.remove()})}(t,e,r,s)}},{\"../../components/drawing\":614,\"../../lib\":719,\"../bar/plot\":867,d3:163}],1264:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\").styleTextPoints;e.exports={style:function(t,e,r){var l=r||n.select(t).selectAll(\"g.waterfalllayer\").selectAll(\"g.trace\");l.style(\"opacity\",function(t){return t[0].trace.opacity}),l.each(function(e){var r=n.select(this),l=e[0].trace;r.selectAll(\".point > path\").each(function(t){if(!t.isBlank){var e=l[t.dir].marker;n.select(this).call(a.fill,e.color).call(a.stroke,e.line.color).call(i.dashLine,e.line.dash,e.line.width).style(\"opacity\",l.selectedpoints&&!t.selected?o:1)}}),s(r,l,t),r.selectAll(\".lines\").each(function(){var t=l.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)})})}}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../constants/interactions\":694,\"../bar/style\":870,d3:163}],1265:[function(t,e,r){\"use strict\";var n=t(\"../plots/cartesian/axes\"),i=t(\"../lib\"),a=t(\"../plot_api/plot_schema\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/numerical\").BADNUM;r.moduleType=\"transform\",r.name=\"aggregate\";var l=r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},aggregations:{_isLinkedToArray:\"aggregation\",target:{valType:\"string\",editType:\"calc\"},func:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"median\",\"mode\",\"rms\",\"stddev\",\"min\",\"max\",\"first\",\"last\",\"change\",\"range\"],dflt:\"first\",editType:\"calc\"},funcmode:{valType:\"enumerated\",values:[\"sample\",\"population\"],dflt:\"sample\",editType:\"calc\"},enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},c=l.aggregations;function u(t,e,r,a){if(a.enabled){for(var o=a.target,l=i.nestedProperty(e,o),c=l.get(),u=function(t,e){var r=t.func,n=e.d2c,i=e.c2d;switch(r){case\"count\":return h;case\"first\":return f;case\"last\":return p;case\"sum\":return function(t,e){for(var r=0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r+=o)}return i(r)};case\"avg\":return function(t,e){for(var r=0,a=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l,a++)}return a?i(r/a):s};case\"min\":return function(t,e){for(var r=1/0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r=Math.min(r,o))}return r===1/0?s:i(r)};case\"max\":return function(t,e){for(var r=-1/0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r=Math.max(r,o))}return r===-1/0?s:i(r)};case\"range\":return function(t,e){for(var r=1/0,a=-1/0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r=Math.min(r,l),a=Math.max(a,l))}return a===-1/0||r===1/0?s:i(a-r)};case\"change\":return function(t,e){var r=n(t[e[0]]),a=n(t[e[e.length-1]]);return r===s||a===s?s:i(a-r)};case\"median\":return function(t,e){for(var r=[],a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&r.push(o)}if(!r.length)return s;r.sort();var l=(r.length-1)/2;return i((r[Math.floor(l)]+r[Math.ceil(l)])/2)};case\"mode\":return function(t,e){for(var r={},a=0,o=s,l=0;l<e.length;l++){var c=n(t[e[l]]);if(c!==s){var u=r[c]=(r[c]||0)+1;u>a&&(a=u,o=c)}}return a?i(o):s};case\"rms\":return function(t,e){for(var r=0,a=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l*l,a++)}return a?i(Math.sqrt(r/a)):s};case\"stddev\":return function(e,r){var i,a=0,o=0,l=1,c=s;for(i=0;i<r.length&&c===s;i++)c=n(e[r[i]]);if(c===s)return s;for(;i<r.length;i++){var u=n(e[r[i]]);if(u!==s){var h=u-c;a+=h,o+=h*h,l++}}var f=\"sample\"===t.funcmode?l-1:l;return f?Math.sqrt((o-a*a/l)/f):0}}}(a,n.getDataConversions(t,e,o,c)),d=new Array(r.length),g=0;g<r.length;g++)d[g]=u(c,r[g]);l.set(d),\"count\"===a.func&&i.pushUnique(e._arrayAttrs,o)}}function h(t,e){return e.length}function f(t,e){return t[e[0]]}function p(t,e){return t[e[e.length-1]]}r.supplyDefaults=function(t,e){var r,n={};function o(e,r){return i.coerce(t,n,l,e,r)}if(!o(\"enabled\"))return n;var s=a.findArrayAttributes(e),u={};for(r=0;r<s.length;r++)u[s[r]]=1;var h=o(\"groups\");if(!Array.isArray(h)){if(!u[h])return n.enabled=!1,n;u[h]=0}var f,p=t.aggregations||[],d=n.aggregations=new Array(p.length);function g(t,e){return i.coerce(p[r],f,c,t,e)}for(r=0;r<p.length;r++){f={_index:r};var v=g(\"target\"),m=g(\"func\");g(\"enabled\")&&v&&(u[v]||\"count\"===m&&void 0===u[v])?(\"stddev\"===m&&g(\"funcmode\"),u[v]=0,d[r]=f):d[r]={enabled:!1,_index:r}}for(r=0;r<s.length;r++)u[s[r]]&&d.push({target:s[r],func:c.func.dflt,enabled:!0,_index:-1});return n},r.calcTransform=function(t,e,r){if(r.enabled){var n=r.groups,a=i.getTargetArray(e,{target:n});if(a){var s,l,c,h,f={},p={},d=[],g=o(e.transforms,r),v=a.length;for(e._length&&(v=Math.min(v,e._length)),s=0;s<v;s++)void 0===(c=f[l=a[s]])?(f[l]=d.length,h=[s],d.push(h),p[f[l]]=g(s)):(d[c].push(s),p[f[l]]=(p[f[l]]||[]).concat(g(s)));r._indexToPoints=p;var m=r.aggregations;for(s=0;s<m.length;s++)u(t,e,d,m[s]);\"string\"==typeof n&&u(t,e,d,{target:n,func:\"first\",enabled:!0}),e._length=d.length}}}},{\"../constants/numerical\":695,\"../lib\":719,\"../plot_api/plot_schema\":756,\"../plots/cartesian/axes\":767,\"./helpers\":1268}],1266:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../registry\"),a=t(\"../plots/cartesian/axes\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/filter_ops\"),l=s.COMPARISON_OPS,c=s.INTERVAL_OPS,u=s.SET_OPS;r.moduleType=\"transform\",r.name=\"filter\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},operation:{valType:\"enumerated\",values:[].concat(l).concat(c).concat(u),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},preservegaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function a(i,a){return n.coerce(t,e,r.attributes,i,a)}if(a(\"enabled\")){var o=a(\"target\");if(n.isArrayOrTypedArray(o)&&0===o.length)return e.enabled=!1,e;a(\"preservegaps\"),a(\"operation\"),a(\"value\");var s=i.getComponentMethod(\"calendars\",\"handleDefaults\");s(t,e,\"valuecalendar\",null),s(t,e,\"targetcalendar\",null)}return e},r.calcTransform=function(t,e,r){if(r.enabled){var i=n.getTargetArray(e,r);if(i){var s=r.target,h=i.length;e._length&&(h=Math.min(h,e._length));var f=r.targetcalendar,p=e._arrayAttrs,d=r.preservegaps;if(\"string\"==typeof s){var g=n.nestedProperty(e,s+\"calendar\").get();g&&(f=g)}var v,m,y=function(t,e,r){var n=t.operation,i=t.value,a=Array.isArray(i);function o(t){return-1!==t.indexOf(n)}var s,h=function(r){return e(r,0,t.valuecalendar)},f=function(t){return e(t,0,r)};o(l)?s=h(a?i[0]:i):o(c)?s=a?[h(i[0]),h(i[1])]:[h(i),h(i)]:o(u)&&(s=a?i.map(h):[h(i)]);switch(n){case\"=\":return function(t){return f(t)===s};case\"!=\":return function(t){return f(t)!==s};case\"<\":return function(t){return f(t)<s};case\"<=\":return function(t){return f(t)<=s};case\">\":return function(t){return f(t)>s};case\">=\":return function(t){return f(t)>=s};case\"[]\":return function(t){var e=f(t);return e>=s[0]&&e<=s[1]};case\"()\":return function(t){var e=f(t);return e>s[0]&&e<s[1]};case\"[)\":return function(t){var e=f(t);return e>=s[0]&&e<s[1]};case\"(]\":return function(t){var e=f(t);return e>s[0]&&e<=s[1]};case\"][\":return function(t){var e=f(t);return e<=s[0]||e>=s[1]};case\")(\":return function(t){var e=f(t);return e<s[0]||e>s[1]};case\"](\":return function(t){var e=f(t);return e<=s[0]||e>s[1]};case\")[\":return function(t){var e=f(t);return e<s[0]||e>=s[1]};case\"{}\":return function(t){return-1!==s.indexOf(f(t))};case\"}{\":return function(t){return-1===s.indexOf(f(t))}}}(r,a.getDataToCoordFunc(t,e,s,i),f),x={},b={},_=0;d?(v=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set(new Array(h))},m=function(t,e){var r=x[t.astr][e];t.get()[e]=r}):(v=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set([])},m=function(t,e){var r=x[t.astr][e];t.get().push(r)}),T(v);for(var w=o(e.transforms,r),k=0;k<h;k++){y(i[k])?(T(m,k),b[_++]=w(k)):d&&_++}r._indexToPoints=b,e._length=_}}function T(t,r){for(var i=0;i<p.length;i++){t(n.nestedProperty(e,p[i]),r)}}}},{\"../constants/filter_ops\":691,\"../lib\":719,\"../plots/cartesian/axes\":767,\"../registry\":847,\"./helpers\":1268}],1267:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_schema\"),a=t(\"../plots/plots\"),o=t(\"./helpers\").pointsAccessorFunction;function s(t,e){var r,s,l,c,u,h,f,p,d,g,v=e.transform,m=e.transformIndex,y=t.transforms[m].groups,x=o(t.transforms,v);if(!Array.isArray(y)||0===y.length)return[t];var b=n.filterUnique(y),_=new Array(b.length),w=y.length,k=i.findArrayAttributes(t),T=v.styles||[],A={};for(r=0;r<T.length;r++)A[T[r].target]=T[r].value;v.styles&&(g=n.keyedContainer(v,\"styles\",\"target\",\"value.name\"));var M={},S={};for(r=0;r<b.length;r++){M[h=b[r]]=r,S[h]=0,(f=_[r]=n.extendDeepNoArrays({},t))._group=h,f.transforms[m]._indexToPoints={};var E=null;for(g&&(E=g.get(h)),f.name=E||\"\"===E?E:n.templateString(v.nameformat,{trace:t.name,group:h}),p=f.transforms,f.transforms=[],s=0;s<p.length;s++)f.transforms[s]=n.extendDeepNoArrays({},p[s]);for(s=0;s<k.length;s++)n.nestedProperty(f,k[s]).set([])}for(l=0;l<k.length;l++){for(c=k[l],s=0,d=[];s<b.length;s++)d[s]=n.nestedProperty(_[s],c).get();for(u=n.nestedProperty(t,c).get(),s=0;s<w;s++)d[M[y[s]]].push(u[s])}for(s=0;s<w;s++){(f=_[M[y[s]]]).transforms[m]._indexToPoints[S[y[s]]]=x(s),S[y[s]]++}for(r=0;r<b.length;r++)h=b[r],f=_[r],a.clearExpandedTraceDefaultColors(f),f=n.extendDeepNoArrays(f,A[h]||{});return _}r.moduleType=\"transform\",r.name=\"groupby\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"data_array\",dflt:[],editType:\"calc\"},nameformat:{valType:\"string\",editType:\"calc\"},styles:{_isLinkedToArray:\"style\",target:{valType:\"string\",editType:\"calc\"},value:{valType:\"any\",dflt:{},editType:\"calc\",_compareAsJSON:!0},editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t,e,i){var a,o={};function s(e,i){return n.coerce(t,o,r.attributes,e,i)}if(!s(\"enabled\"))return o;s(\"groups\"),s(\"nameformat\",i._dataLength>1?\"%{group} (%{trace})\":\"%{group}\");var l=t.styles,c=o.styles=[];if(l)for(a=0;a<l.length;a++){var u=c[a]={};n.coerce(l[a],c[a],r.attributes.styles,\"target\");var h=n.coerce(l[a],c[a],r.attributes.styles,\"value\");n.isPlainObject(h)?u.value=n.extendDeep({},h):h&&delete u.value}return o},r.transform=function(t,e){var r,n,i,a=[];for(n=0;n<t.length;n++)for(r=s(t[n],e),i=0;i<r.length;i++)a.push(r[i]);return a}},{\"../lib\":719,\"../plot_api/plot_schema\":756,\"../plots/plots\":828,\"./helpers\":1268}],1268:[function(t,e,r){\"use strict\";r.pointsAccessorFunction=function(t,e){for(var r,n,i=0;i<t.length&&(r=t[i])!==e;i++)r._indexToPoints&&!1!==r.enabled&&(n=r._indexToPoints);return n?function(t){return n[t]}:function(t){return[t]}}},{}],1269:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/cartesian/axes\"),a=t(\"./helpers\").pointsAccessorFunction;r.moduleType=\"transform\",r.name=\"sort\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},order:{valType:\"enumerated\",values:[\"ascending\",\"descending\"],dflt:\"ascending\",editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function i(i,a){return n.coerce(t,e,r.attributes,i,a)}return i(\"enabled\")&&(i(\"target\"),i(\"order\")),e},r.calcTransform=function(t,e,r){if(r.enabled){var o=n.getTargetArray(e,r);if(o){var s=r.target,l=o.length;e._length&&(l=Math.min(l,e._length));var c,u,h=e._arrayAttrs,f=function(t,e,r,n){var i,a=new Array(n),o=new Array(n);for(i=0;i<n;i++)a[i]={v:e[i],i:i};for(a.sort(function(t,e){switch(t.order){case\"ascending\":return function(t,r){return e(t.v)-e(r.v)};case\"descending\":return function(t,r){return e(r.v)-e(t.v)}}}(t,r)),i=0;i<n;i++)o[i]=a[i].i;return o}(r,o,i.getDataToCoordFunc(t,e,s,o),l),p=a(e.transforms,r),d={};for(c=0;c<h.length;c++){var g=n.nestedProperty(e,h[c]),v=g.get(),m=new Array(l);for(u=0;u<l;u++)m[u]=v[f[u]];g.set(m)}for(u=0;u<l;u++)d[u]=p(f[u]);r._indexToPoints=d,e._length=l}}}},{\"../lib\":719,\"../plots/cartesian/axes\":767,\"./helpers\":1268}]},{},[25])(25)});</script>    \n",
       "            <div id=\"1cbe1a87-0db4-4dfb-8365-bc40217062f7\" class=\"plotly-graph-div\" style=\"height:600px; width:500px;\"></div>\n",
       "            <script type=\"text/javascript\">\n",
       "                \n",
       "                    window.PLOTLYENV=window.PLOTLYENV || {};\n",
       "                    \n",
       "                if (document.getElementById(\"1cbe1a87-0db4-4dfb-8365-bc40217062f7\")) {\n",
       "                    Plotly.newPlot(\n",
       "                        '1cbe1a87-0db4-4dfb-8365-bc40217062f7',\n",
       "                        [{\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha = 0.1\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.1, 0.10717734625362932, 0.11161231740339045, 0.1148698354997035, 0.11746189430880191, 0.11962311988513157, 0.1214814044039067, 0.12311444133449163, 0.12457309396155175, 0.12589254117941673, 0.12709816152101408, 0.12820888539868155, 0.1292392220780832, 0.13020054543174678, 0.131101942303975, 0.1319507910772894, 0.13275316748885194, 0.1335141362540313, 0.13423796509621047, 0.13492828476735633, 0.1355882106693847, 0.1362204366553743, 0.1368273083326153, 0.1374108810316637, 0.13797296614612148, 0.13851516854212415, 0.13903891703159096, 0.1395454894014972, 0.14003603312913962, 0.1405115826483646, 0.14097307383555407, 0.14142135623730953, 0.1418572034507081, 0.1422813219821873, 0.1426943588457651, 0.14309690811052556, 0.14348951656753597, 0.1438726886549916, 0.14424689075546288, 0.1446125549591925, 0.14497008237135636, 0.14531984602822678, 0.14566219347661555, 0.14599744906233633, 0.14632591596632238, 0.1466478780211681, 0.14696360133599295, 0.14727333575346888, 0.1475773161594552, 0.14787576366283137, 0.14816888666071196, 0.14845688180219063, 0.14873993486203083, 0.1490182215342446, 0.14929190815424387, 0.14956115235716425, 0.14982610367903493, 0.150086904106665, 0.15034368858142386, 0.15059658546149227, 0.15084571694663826, 0.1510911994691163, 0.15133314405389134, 0.15157165665103983, 0.15180683844287585, 0.15203878612808078, 0.15226759218487862, 0.15249334511509008, 0.1527161296707143, 0.152936027064522, 0.15315311516599991, 0.15336746868385576, 0.1535791593361787, 0.1537882560092468, 0.15399482490588157, 0.1541989296841664, 0.15440063158727363, 0.15459998956507684, 0.1547970603881666, 0.15499189875483374, 0.15518455739153597, 0.15537508714732026, 0.15556353708263268, 0.1557499545529136, 0.15593438528734202, 0.1561168734630637, 0.15629746177521228, 0.1564761915030063, 0.15665310257218434, 0.15682823361402, 0.1570016220211393, 0.1571733040003473, 0.15734331462265458, 0.15751168787068054, 0.15767845668359715, 0.1578436529997654, 0.15800730779720562, 0.15816945113203257, 0.15833011217497764, 0.15848931924611137, 0.15864709984787198], [0.0, 0.18660659830736148, 0.19999999999999998, 0.2082759487984821, 0.2143546925072586, 0.21919164527704346, 0.2232246348067809, 0.2266923163341395, 0.229739670999407, 0.23246161304788485, 0.2349237886176038, 0.23717355572556018, 0.2392462397702631, 0.24116891599880752, 0.24296280880781337, 0.24464487484832742, 0.24622888266898324, 0.24772616999622069, 0.24914618792310345, 0.2504969003030616, 0.25178508235883346, 0.2530165476359577, 0.25419632304202816, 0.2553287856350184, 0.25641777079736305, 0.2574666587090447, 0.25847844415616633, 0.2594557933960465, 0.26040109086349356, 0.2613164778268572, 0.26220388460794997, 0.2630650576138525, 0.2639015821545789, 0.26471490181331936, 0.2655063349777038, 0.26627708901858177, 0.26702827250806255, 0.26776090579435674, 0.268475930192421, 0.26917421600290514, 0.26985656953471265, 0.270523739276568, 0.27117642133876935, 0.2718152642665997, 0.2724408733107486, 0.27305381422684255, 0.2736546166652306, 0.27424377720308846, 0.2748217620633274, 0.27538900955845946, 0.27594593229224296, 0.27649291914744445, 0.2770303370842483, 0.277558532770621, 0.2780778340631819, 0.2785885513547849, 0.2790909788029944, 0.27958539545190764, 0.2800720662582792, 0.2805512430316081, 0.2810231652967292, 0.28148806108647273, 0.28194614767110815, 0.2823976322305457, 0.282842712474619, 0.2832815772162025, 0.28371440690141614, 0.28414137410072776, 0.2845626439643746, 0.2849783746451791, 0.2853887176915302, 0.28579381841302814, 0.28619381622105106, 0.2865888449462856, 0.2869790331350719, 0.28736450432624305, 0.2877453773099832, 0.28812176637009274, 0.2884937815109257, 0.2888615286701498, 0.28922510991838496, 0.28958462364668036, 0.2899401647427127, 0.29029182475651166, 0.29063969205645357, 0.2909838519762037, 0.29132438695323104, 0.2916613766594722, 0.2919948981246726, 0.292325025852895, 0.29265183193264477, 0.29297538614102936, 0.29329575604233615, 0.293613007081385, 0.29392720267198585, 0.2942384042808071, 0.29454667150693775, 0.2948520621574077, 0.2951546323189104, 0.2954544364259553, 0.2957515273256628, 0.2960459563393971], [0.0, 0.2687875379522287, 0.28807935023766545, 0.30000000000000004, 0.3087558026894282, 0.3157229337446777, 0.32153203876088804, 0.32652687596705116, 0.330916275726621, 0.3348369522101714, 0.33838346190164986, 0.3416240191348806, 0.34460950649911054, 0.34737892309229296, 0.3499628404663651, 0.35238568292640576, 0.3546672826451353, 0.3568239704468836, 0.3588693596553947, 0.36081492137927623, 0.3626704146273491, 0.36444421321172016, 0.36614355787375585, 0.36777475331354137, 0.3693433240034749, 0.3708541387438219, 0.3723115112147555, 0.3737192818846553, 0.37508088528567257, 0.37639940569378166, 0.3776776235382502, 0.3789180543381633, 0.3801229815689149, 0.38129448456304227, 0.38243446232180434, 0.3835446539382502, 0.3846266561960447, 0.3856819388014352, 0.38671185762142735, 0.3877176662342496, 0.38870052604462707, 0.3896615151732867, 0.39060163629524036, 0.3915218235730068, 0.392422948807713, 0.39330582691192506, 0.3941712207922852, 0.3950198457169441, 0.39585237323186834, 0.3966694346809762, 0.39747162437738087, 0.39825950246655584, 0.39903359751675843, 0.3997944088674013, 0.40054240876209396, 0.4012780442896946, 0.40200173915380344, 0.40271389528863155, 0.40341489433702726, 0.4041050990045752, 0.40478485430206906, 0.40545448868725675, 0.4061143151155286, 0.4067646320081541, 0.4074057241457354, 0.4080378634937234, 0.40866130996612293, 0.4092763121328754, 0.4098831078758458, 0.41048192499784597, 0.4110729817886828, 0.41165648755183254, 0.4122326430949912, 0.41280164118744506, 0.4133636669869249, 0.4139188984383645, 0.4144675066467592, 0.41500965622612385, 0.41554550562637255, 0.41607520743977766, 0.41659890868852856, 0.41711675109477286, 0.4176288713344118, 0.4181354012758106, 0.4186364682044916, 0.419132195034789, 0.4196227005093651, 0.42010809938741883, 0.42058850262234504, 0.42106401752955375, 0.42153474794509393, 0.4220007943756844, 0.4224622541407052, 0.4229192215066623, 0.42337178781460144, 0.4238200416009122, 0.42426406871192857, 0.42470395241270886, 0.4251397734903439, 0.42557161035212426, 0.42599953911887045, 0.426423633713709], [0.0, 0.34822022531844965, 0.37321319661472296, 0.3886566631452294, 0.39999999999999997, 0.40902607302542915, 0.41655189759696426, 0.4230228201353009, 0.4287093850145173, 0.43378870847907947, 0.4383832905540869, 0.44258150442408223, 0.4464492696135618, 0.4500371103201128, 0.453384632668279, 0.4565234788877656, 0.45947934199881396, 0.462273378947059, 0.46492322609576964, 0.4674437445209259, 0.4698475772352076, 0.4721455726981855, 0.4743471114511204, 0.47646036137300285, 0.4784924795405262, 0.48044977359257246, 0.48233783199761504, 0.4841616301677383, 0.4859256176156268, 0.48763379008930874, 0.48928974969665484, 0.4908967553485108, 0.49245776533796654, 0.4939754734865072, 0.4954523399924414, 0.4968906178894403, 0.4982923758462069, 0.4996595178998279, 0.5009938006061232, 0.5022968480035307, 0.5035701647176669, 0.5048151474778791, 0.5060330952719154, 0.5072252183280668, 0.5083926460840563, 0.5095364342772131, 0.5106575712700367, 0.5117569837083027, 0.5128355415947262, 0.5138940628493758, 0.5149333174180895, 0.5159540309817694, 0.5169568883123327, 0.5179425363150789, 0.518911586792093, 0.5198646189569208, 0.5208021817269871, 0.5217247958169894, 0.5226329556537144, 0.5235271311303025, 0.5244077692158999, 0.5252752954348145, 0.526130115227705, 0.5269726152059544, 0.5278031643091577, 0.5286221148745971, 0.5294298036266387, 0.5302265525931623, 0.5310126699554076, 0.531788450836977, 0.5325541780371637, 0.5333101227132696, 0.5340565450161252, 0.5347936946826223, 0.5355218115887134, 0.5362411262660127, 0.536951860384842, 0.5376542272063135, 0.5383484320058103, 0.5390346724700102, 0.5397131390694253, 0.5403840154082453, 0.5410474785531361, 0.5417036993424934, 0.5423528426775387, 0.5429950677965218, 0.5436305285331993, 0.5442593735606619, 0.5448817466214972, 0.5454977867452023, 0.5461076284536851, 0.546711401955632, 0.5473092333304611, 0.5479012447025249, 0.5484875544061769, 0.549068277142276, 0.5496435241266548, 0.5502134032310456, 0.5507780191169189, 0.5513374733626611, 0.5518918645844859, 0.5524412885514456], [0.0, 0.4256699612603923, 0.4562217682777404, 0.47510010825283816, 0.4889663842714642, 0.5, 0.5091996880735121, 0.5171098470646901, 0.5240611947344789, 0.5302702408070094, 0.5358867312681466, 0.5410186949091713, 0.5457467128089485, 0.550132546553009, 0.5542246113001359, 0.5580615870169522, 0.561674881261479, 0.5650903566217397, 0.5683295720696824, 0.571410694021778, 0.5743491774985174, 0.5771582838300289, 0.5798494799396691, 0.5824327503730811, 0.5849168440550466, 0.5873094715440095, 0.589617464273027, 0.5918469042652421, 0.5940032306759779, 0.5960913279713986, 0.5981155994256577, 0.6000800287833873, 0.6019882323092768, 0.6038435029737049, 0.6056488481623507, 0.6074070220195334, 0.6091205533188933, 0.6107917695857545, 0.6124228180619875, 0.6140156839980991, 0.6155722066724582, 0.6170940934693113, 0.6185829322920147, 0.6200402025429471, 0.621467284864808, 0.6228654698077587, 0.6242359655618935, 0.6255799048737984, 0.6268983512486784, 0.6281923045250796, 0.6294627058970835, 0.6307104424486071, 0.6319363512557712, 0.6331412231059393, 0.6343258058757445, 0.6354908076050703, 0.6366368992993373, 0.6377647174885032, 0.638874866567763, 0.6399679209419917, 0.6410444269934077, 0.642104904889716, 0.6431498502480495, 0.6441797356683329, 0.645195012148216, 0.6461961103904159, 0.6471834420121721, 0.6481574006655049, 0.6491183630760802, 0.6500666900076999, 0.6510027271587339, 0.6519268059961958, 0.652839244532613, 0.653740348050348, 0.6546304097775938, 0.6555097115198749, 0.6563785242505307, 0.6572371086633486, 0.6580857156902331, 0.6589245869865348, 0.6597539553864471, 0.6605740453306624, 0.6613850732682989, 0.6621872480349384, 0.6629807712084659, 0.6637658374442597, 0.6645426347911588, 0.6653113449895225, 0.6660721437525841, 0.6668252010322196, 0.6675706812701565, 0.6683087436355711, 0.6690395422499569, 0.6697632264000709, 0.6704799407397158, 0.6711898254810524, 0.6718930165760894, 0.672589645888954, 0.6732798413594981, 0.673963727158763, 0.6746414238367817, 0.6753130484631724], [0.0, 0.5015752812467621, 0.5375750759044573, 0.5598197949220844, 0.5761587004753308, 0.5891598267371476, 0.6000000000000001, 0.6093206958014116, 0.6175116053788564, 0.6248278463954464, 0.6314458674893553, 0.6374929611084903, 0.643064077521776, 0.6482319916192733, 0.6530537519341022, 0.6575749358311305, 0.6618325514532419, 0.6658570731961942, 0.6696739044203427, 0.673304450971248, 0.6767669238032996, 0.6800769490024186, 0.6832480382697612, 0.6862919565916896, 0.6892190129982211, 0.6920382929919087, 0.6947578461845858, 0.6973848391436546, 0.6999256809327302, 0.7023861270142909, 0.7047713658528114, 0.707086091572886, 0.7093345652902706, 0.7115206671766806, 0.713647940893767, 0.7157196317039103, 0.7177387193107893, 0.7197079462832379, 0.7216298427585525, 0.7235067479964226, 0.7253408292546982, 0.7271340983777934, 0.7288884264234402, 0.7306055566005373, 0.7322871157475117, 0.7339346245449824, 0.7355495066270825, 0.7371330967313768, 0.7386866480069498, 0.7402113385832109, 0.7417082774876438, 0.7431785099886622, 0.744623022429511, 0.7460427466104819, 0.7474385637693104, 0.7488113082033064, 0.750161770571345, 0.7514907009091849, 0.7527988113875632, 0.754086778839033, 0.7553552470765004, 0.7566048290237956, 0.7578361086763266, 0.7590496429078731, 0.7602459631378297, 0.7614255768716723, 0.7625889691260844, 0.7637366037489777, 0.7648689246436087, 0.7659863569050551, 0.7670893078765004, 0.7681781681320415, 0.7692533123920893, 0.7703151003768512, 0.7713638776028702, 0.7723999761271343, 0.7734237152428546, 0.7744354021306447, 0.775435332468499, 0.7764237910036669, 0.777401052089254, 0.7783673801881396, 0.7793230303465732, 0.780268248639626, 0.7812032725904806, 0.7821283315653954, 0.7830436471460135, 0.7839494334805716, 0.7848458976154259, 0.7857332398082124, 0.78661165382385, 0.7874813272145078, 0.7883424415845703, 0.7891951728415575, 0.790039691433888, 0.7908761625763064, 0.7917047464637366, 0.7925255984742712, 0.7933388693619523, 0.7941447054399581, 0.7949432487547617, 0.7957346372517954], [0.0, 0.576219877795131, 0.6175771736067273, 0.6431323589461301, 0.6619028257398595, 0.6768387838420242, 0.689292195216828, 0.7000000000000001, 0.7094098834057659, 0.7178149297908671, 0.72541784693722, 0.7323648709962455, 0.7387650827667823, 0.7447020875217089, 0.7502414237754053, 0.7554354517310079, 0.7603266870952656, 0.764950139473428, 0.7693349927622039, 0.7735058384320546, 0.7774835975975269, 0.7812862218237332, 0.7849292336275917, 0.788426148864563, 0.7917888107578656, 0.7950276569174987, 0.7981519349011476, 0.8011698778071069, 0.8040888484979246, 0.8069154589658774, 0.809655669824411, 0.8123148737792695, 0.8148979660868417, 0.8174094043672605, 0.8198532596510565, 0.8222332601616132, 0.8245528290430811, 0.82681511701428, 0.8290230307483618, 0.8311792576344041, 0.8332862874622756, 0.8353464314797303, 0.8373618391959209, 0.8393345132446615, 0.841266322571003, 0.8431590141637489, 0.8450142235227276, 0.846833484021582, 0.8486182353034514, 0.8503698308273469, 0.8520895446665837, 0.8537785776467606, 0.8554380628990449, 0.8570690708945514, 0.8586726140171018, 0.8602496507244032, 0.8618010893414415, 0.8633277915245413, 0.8648305754299205, 0.8663102186165729, 0.8677674607098508, 0.8692030058491081, 0.8706175249401397, 0.8720116577308622, 0.8733860147266772, 0.8747411789601911, 0.8760777076284276, 0.8773961336092959, 0.8786969668678793, 0.8799806957620436, 0.8812477882559171, 0.8824986930489609, 0.8837338406275993, 0.8849536442457183, 0.8861585008397451, 0.8873487918834966, 0.8885248841875035, 0.8896871306470985, 0.8908358709431711, 0.8919714321991487, 0.893094129597456, 0.8942042669584235, 0.895302137284367, 0.8963880232713293, 0.8974621977907709, 0.8985249243433109, 0.8995764574864449, 0.9006170432380197, 0.901646919457098, 0.9026663162037218, 0.9036754560789686, 0.9046745545465823, 0.9056638202373708, 0.9066434552374686, 0.9076136553614835, 0.908574610411472, 0.9095265044226187, 0.9104695158964347, 0.9114038180222275, 0.91232957888755, 0.9132469616782779, 0.9141561248689273], [0.0, 0.6498019170849885, 0.6964404506368994, 0.7252589781902133, 0.7464263932294459, 0.7632696410629377, 0.7773133262904589, 0.7893884947183534, 0.8, 0.8094783527342472, 0.8180521460508584, 0.8258862901433245, 0.8331037951939285, 0.8397989426891102, 0.8460456402706018, 0.851902934426885, 0.8574187700290345, 0.8626326273336055, 0.8675774169581589, 0.8722808706510533, 0.8767665811081738, 0.8810547922708946, 0.8851630088481646, 0.8891064726411224, 0.8928985392271236, 0.8965509790765195, 0.9000742206402256, 0.9034775483654846, 0.9067692653365582, 0.9099568278829187, 0.9130469577755312, 0.9160457363570667, 0.9189586839976281, 0.9217908275458535, 0.9245467578941181, 0.9272306793519144, 0.9298464521915394, 0.9323976294718308, 0.934887489041852, 0.9373190614644866, 0.9396951544704154, 0.9420183744487605, 0.9442911453963712, 0.9465157256790929, 0.9486942229022409, 0.9508286071413321, 0.9529207227460057, 0.9549722988984218, 0.9569849590810525, 0.9589602295867145, 0.960899547185145, 0.96280426604479, 0.9646756639952301, 0.9665149482044394, 0.9683232603354766, 0.9701016812390368, 0.9718512352312537, 0.9735728940001114, 0.9752675801786175, 0.9769361706183771, 0.9785794993933098, 0.9801983605598508, 0.9817935106970217, 0.9833656712471731, 0.9849155306759332, 0.9864437464679184, 0.9879509469730144, 0.9894377331164932, 0.9909046799848829, 0.9923523382982983, 0.9937812357788807, 0.9951918784240477, 0.9965847516924139, 0.9979603216094981, 0.9993190357996556, 1.0006613244500897, 1.0019876012122466, 1.0032982640454342, 1.0045936960070614, 1.0058742659935138, 1.0071403294353338, 1.0083922289500549, 1.0096302949557585, 1.010854846248164, 1.0120661905438308, 1.0132646249918407, 1.0144504366561333, 1.0156239029705063, 1.0167852921681126, 1.0179348636871672, 1.0190728685544264, 1.0201995497478906, 1.0213151425400735, 1.0224198748230744, 1.0235139674166054, 1.0245976343600374, 1.0256710831894524, 1.0267345152006206, 1.0277881256987516, 1.0288321042358173, 1.0298666348361791, 1.030891896211208], [0.0, 0.7224674055842076, 0.7743213928525987, 0.806362613856686, 0.829897120333555, 0.8486239003628652, 0.8642380507129963, 0.8776635506641641, 0.889461710208793, 0.9000000000000001, 0.9095325760829622, 0.918242790086096, 0.9262674080682846, 0.93371125474474, 0.9406565026372284, 0.9471688012340329, 0.953301456943931, 0.9590983649875663, 0.9645961162826638, 0.9698255437396259, 0.9748128783579909, 0.9795806279011533, 0.9841482545795618, 0.9885327046413501, 0.9927488271798629, 0.9968097089234609, 1.000726944506877, 1.004510856630514, 1.0081706768887821, 1.0117146954311365, 1.0151503857049495, 1.018484509112037, 1.0217232033496901, 1.0248720574046417, 1.0279361755556213, 1.0309202322680184, 1.0338285194973316, 1.036664987630799, 1.0394332810699622, 1.0421367692768788, 1.0447785739627145, 1.047361592981627, 1.0498885213990954, 1.0523618701275532, 1.0547839824597862, 1.0571570487792172, 1.0594831196838266, 1.0617641177252661, 1.0640018479354059, 1.0661980072880197, 1.0683541932226923, 1.0704719113406507, 1.0725525823675004, 1.0745975484653545, 1.076608078966184, 1.0785853755891237, 1.0805305771966485, 1.0824447641378288, 1.0843289622210803, 1.0861841463538136, 1.0880112438820473, 1.089811137659275, 1.0915846688705848, 1.0933326396351604, 1.0950558154077705, 1.0967549271976547, 1.0984306736212675, 1.1000837228036342, 1.1017147141415633, 1.1033242599406239, 1.1049129469366137, 1.106481337711193, 1.1080299720104247, 1.1095593679741265, 1.1110700232832047, 1.1125624162314656, 1.1140370067278136, 1.1154942372342063, 1.1169345336442664, 1.1183583061070064, 1.119765949799749, 1.1211578456539657, 1.1225343610374463, 1.123895850395923, 1.1252426558570174, 1.1265751077991424, 1.1278935253877764, 1.1291982170813448, 1.1304894811087458, 1.1317676059204278, 1.1330328706147506, 1.134285545341249, 1.1355258916822886, 1.1367541630144897, 1.1379706048512006, 1.139175455167203, 1.1403689447067444, 1.1415512972759247, 1.1427227300203768, 1.1438834536891265, 1.145033672885453, 1.146173586305508], [0.0, 0.7943282347242815, 0.8513399225207846, 0.8865681505652133, 0.9124435365554808, 0.9330329915368074, 0.9502002165056764, 0.9649610951198176, 0.9779327685429285, 0.9895192582062144, 1.0, 1.009576582776887, 1.0183993761470242, 1.026583631304232, 1.0342196941293802, 1.0413797439924106, 1.0481223894689577, 1.0544958918547662, 1.0605404816140187, 1.0662900584785258, 1.0717734625362931, 1.0770154403043632, 1.0820373898183429, 1.086857942899213, 1.091493425617897, 1.0959582263852172, 1.100265093106018, 1.1044253752367947, 1.108449222600272, 1.1123457499326046, 1.1161231740339044, 1.1197889288345146, 1.1233497625229583, 1.126811819999242, 1.1301807132434794, 1.1334615816706974, 1.1366591441393648, 1.1397777439653138, 1.1428213880435563, 1.145793780982531, 1.148698354997035, 1.1515382961787317, 1.1543165676600577, 1.1570359301034678, 1.1596989598793381, 1.1623080652394242, 1.1648655007461621, 1.1673733801794233, 1.1698336881100935, 1.1722482903028724, 1.174618943088019, 1.1769473018226546, 1.179234928546054, 1.1814832989196156, 1.1836938085304842, 1.185867778627801, 1.1880064613519559, 1.19011104450985, 1.1921826559427973, 1.1942223675281953, 1.1962311988513155, 1.198210120579418, 1.2001600575667746, 1.202081891716029, 1.2039764646185536, 1.2058445799940376, 1.2076870059474099, 1.2095044770593142, 1.2112976963247013, 1.2130673369526295, 1.214814044039067, 1.216538436123333, 1.2182411066377865, 1.2199226252594597, 1.2215835391715089, 1.223224374241637, 1.224845636123975, 1.2264478112903319, 1.2280313679961983, 1.2295967571864037, 1.2311444133449163, 1.2326747552928772, 1.2341881869386229, 1.235685097983129, 1.2371658645840293, 1.2386308499811036, 1.240080405085894, 1.2415148690379023, 1.242934569729616, 1.24433982430245, 1.2457309396155174, 1.2471082126890045, 1.248471931123787, 1.2498223734988043, 1.2511598097475969, 1.252484501515308, 1.2537967024973569, 1.2550966587609054, 1.2563846090501594, 1.2576607850764745, 1.2589254117941673, 1.2601787076628697], [0.0, 0.8654727864164494, 0.9275907650284918, 0.965974233415095, 0.9941671660512758, 1.0166007296519326, 1.035305548868138, 1.0513884956723267, 1.0655219858986698, 1.0781462274342235, 1.089565684035974, 1.1, 1.1096130128934416, 1.1185302964621298, 1.126850288477554, 1.1346516331042984, 1.1419981882351644, 1.1489425377218627, 1.1555285152976196, 1.1617930569469137, 1.1677675858399605, 1.1734790649325293, 1.1789508087899225, 1.1842031180049124, 1.1892537809041324, 1.194118474606262, 1.198811088790963, 1.2033439894365654, 1.207728235441609, 1.2119737579098269, 1.2160895095846536, 1.2200835902214886, 1.223963352414976, 1.2277354914372949, 1.2314061219093966, 1.2349808435615304, 1.2384647978999517, 1.2418627172525465, 1.2451789673946185, 1.2484175847403962, 1.2515823089133427, 1.2546766113695997, 1.2577037206365884, 1.2606666446373842, 1.2635681904967386, 1.2664109821631226, 1.2691974761303995, 1.2719299755005804, 1.2746106425940003, 1.2772415102838501, 1.27982449220731, 1.2823613919846946, 1.284853911560394, 1.28730365876443, 1.2897121541806642, 1.292080837396821, 1.2944110727021008, 1.296704154290142, 1.2989613110181382, 1.3011837107669184, 1.3033724644416067, 1.3055286296479405, 1.3076532140753967, 1.3097471786148327, 1.311811440235328, 1.3138468746422753, 1.315854318736447, 1.3178345728917047, 1.3197884030672227, 1.3217165427684892, 1.3236196948699337, 1.3254985333107732, 1.3273537046745418, 1.3291858296617844, 1.330995504464491, 1.3327833020500655, 1.3345497733618965, 1.3362954484429737, 1.3380208374884106, 1.3397264318322193, 1.3414127048732216, 1.3430801129445606, 1.344729096130899, 1.3463600790370476, 1.347973471511455, 1.349569669327721, 1.3511490548270197, 1.3527119975241146, 1.3542588546794079, 1.3557899718393025, 1.357305683346958, 1.3588063128253762, 1.3602921736346025, 1.3617635693046892, 1.3632207939459595, 1.3646641326379825, 1.3660938617985812, 1.3675102495340912, 1.3689135559720067, 1.370304033577069, 1.3716819274517822, 1.3730474756222644], [0.0, 0.9359725702851642, 1.0031505624935244, 1.0446606759553492, 1.0751501518089148, 1.099411111267736, 1.1196395898441691, 1.13703262321776, 1.152317400950662, 1.1659699894356885, 1.1783196534742955, 1.1896039291734248, 1.2000000000000004, 1.2096436687007865, 1.2186413916028231, 1.227078219076288, 1.2350232107577128, 1.2425332338803763, 1.2496556927908928, 1.2564305322095026, 1.2628917349787108, 1.269068460405903, 1.2749859222169808, 1.280666074652786, 1.2861281550435522, 1.2913891175365326, 1.2964639832385467, 1.3013661254372386, 1.3061075038682046, 1.3106988586041919, 1.315149871662261, 1.3194693025886377, 1.3236651029064843, 1.3277445132722472, 1.3317141463923887, 1.335580058140643, 1.3393478088406856, 1.343022516306923, 1.3466089019424965, 1.3501113309603385, 1.3535338476065997, 1.3568802061157037, 1.3601538980048373, 1.3633581762168274, 1.3664960765395227, 1.369570436663297, 1.3725839131833795, 1.375538996808135, 1.3784380259964424, 1.381283199215516, 1.3840765859838178, 1.3868201368411774, 1.3895156923691718, 1.392164991368629, 1.3947696782873091, 1.397331309979043, 1.3998513618654607, 1.4023312335627782, 1.404772254028582, 1.407175686277076, 1.409542731705623, 1.4118745340705336, 1.4141721831457723, 1.4164367180945567, 1.4186691305805414, 1.4208703676424317, 1.4230413343533614, 1.42518289628414, 1.4272958817875343, 1.4293810841190087, 1.4314392634078208, 1.433471148491007, 1.4354774386215787, 1.4374588050611794, 1.4394158925664757, 1.4413493207777177, 1.4432596855171052, 1.4451475600039319, 1.4470134959928453, 1.4488580248410006, 1.4506816585093965, 1.452484890503215, 1.454268196755587, 1.4560320364588315, 1.4577768528468806, 1.459503073932306, 1.4612111132010746, 1.4629013702679263, 1.4645742314950236, 1.4662300705763285, 1.467869249089965, 1.4694921170206559, 1.4710990132541653, 1.4726902660455325, 1.474266193462754, 1.4758271038074435, 1.4773732960138999, 1.4789050600278961, 1.480422677166422, 1.4819264204595217, 1.483416554975288, 1.4848933381289982], [0.0, 1.0058865869794325, 1.0780825502457605, 1.1226933301776152, 1.155460267776856, 1.1815334396641957, 1.2032729178508645, 1.221965152573139, 1.2383916520183136, 1.2530640431445341, 1.2663361857313113, 1.2784633590373347, 1.2896359815411698, 1.3, 1.3096698226720027, 1.3187368529051988, 1.327275308859708, 1.335346305560702, 1.3430007883007444, 1.3502816855369133, 1.35722551851625, 1.363863624648756, 1.3702231010412242, 1.3763275418427687, 1.3821976213477705, 1.3878515601215091, 1.3933055012971811, 1.3985738171022348, 1.4036693606244657, 1.4086036741840895, 1.413387163012419, 1.4180292409644502, 1.4225384535154975, 1.4269225821747973, 1.4311887335958406, 1.4353434160058502, 1.43939260506606, 1.4433418008744747, 1.4471960775072399, 1.4509601262440757, 1.4546382934227773, 1.4582346137065083, 1.4617528394170967, 1.4651964664813055, 1.46856875745017, 1.4718727619800327, 1.475111335104889, 1.478287153580679, 1.4814027305413282, 1.4844604286721903, 1.4874624720778262, 1.4904109569968589, 1.4933078614961455, 1.4961550542591127, 1.4989543025682626, 1.5017072795691926, 1.5044155708925884, 1.5070806807013102, 1.5097040372216262, 1.5122869978106712, 1.5148308536061688, 1.5173368337991948, 1.5198061095661803, 1.5222397976923554, 1.5246389639153282, 1.5270046260144248, 1.5293377566687105, 1.5316392861042363, 1.5339101045489465, 1.5361510645118321, 1.5383629829012613, 1.540546642995956, 1.5427027962807862, 1.5448321641583922, 1.5469354395466044, 1.5490132883707248, 1.5510663509588762, 1.553095243347914, 1.5551005585067101, 1.55708286748302, 1.5590427204796142, 1.5609806478648596, 1.5628971611224984, 1.5647927537449775, 1.5666679020743197, 1.568523066094203, 1.5703586901766104, 1.5721752037861658, 1.5739730221449904, 1.5757525468607345, 1.5775141665201968, 1.579258257250787, 1.580985183251901, 1.5826952972981303, 1.584388941216085, 1.5860664463364782, 1.5877281339229987, 1.5893743155793982, 1.5910052936361037, 1.5926213615175893, 1.5942228040916462, 1.5958098980016115], [0.0, 1.0752643127243293, 1.152439755590262, 1.2001274176432633, 1.2351543472134545, 1.2630258305525168, 1.2862647178922604, 1.3062461881515304, 1.323805651479719, 1.3394900226251123, 1.3536775676840485, 1.3666411729641899, 1.378584390433656, 1.3896632330481709, 1.4, 1.4096923988830834, 1.4188197668115317, 1.4274474340187813, 1.435629859581734, 1.4434129328068925, 1.45083569387444, 1.4579316415893748, 1.464729741992491, 1.4712552165618948, 1.4775301655335646, 1.4835740661764647, 1.4894041750434177, 1.4950358556390868, 1.5004828475508105, 1.505757489192457, 1.5108709034620156, 1.5158331535042318, 1.5206533741905315, 1.5253398837342098, 1.529900278946856, 1.5343415169393042, 1.5386699855244075, 1.542891564151378, 1.5470116768641093, 1.5510353385079418, 1.554967195195054, 1.5588115598662589, 1.5625724436474664, 1.5662535835855131, 1.5698584672551834, 1.573390354652856, 1.576852297729126, 1.5802471578603876, 1.5835776215157311, 1.5868462143389765, 1.5900553138349973, 1.5932071608235947, 1.5963038698022949, 1.5993474383408308, 1.6023397556142136, 1.605282610167767, 1.6081776969958492, 1.611026624006016, 1.6138309179317547, 1.6165920297494532, 1.619311339648822, 1.621990161600357, 1.624629747558539, 1.6272312913351938, 1.6297959321736835, 1.6323247580513218, 1.6348188087345208, 1.6372790786086193, 1.6397065193021128, 1.6421020421230015, 1.6444665203232267, 1.6468007912055895, 1.6491056580861623, 1.6513818921239645, 1.6536302340285596, 1.6558513956552616, 1.6580460614967236, 1.6602148900789213, 1.6623585152688083, 1.6644775475002844, 1.666572574924551, 1.6686441644903915, 1.6706928629594606, 1.6727191978612272, 1.6747236783918418, 1.676706796260846, 1.6786690264893225, 1.6806108281628076, 1.6825326451420057, 1.6844349067341366, 1.6863180283274979, 1.6881824119916526, 1.690028447045455, 1.6918565105949657, 1.6936669680431637, 1.6954601735732102, 1.6972364706069025, 1.6989961922398384, 1.700739661654694, 1.7024671925139327, 1.7041790893331674, 1.7058756478363009], [0.0, 1.144147808674014, 1.2262672585558603, 1.277009883781177, 1.3142807056973023, 1.3439376897611433, 1.3686653048332214, 1.3899268264337157, 1.4086111826898404, 1.4253003247585148, 1.440396751188327, 1.4541908299076411, 1.4668991528143929, 1.4786877273537313, 1.4896866874389445, 1.5, 1.5097120846388332, 1.5188924567690427, 1.5275990642205364, 1.5358807360568798, 1.5437790134471407, 1.5513295411940704, 1.5585631409586385, 1.5655066499552546, 1.5721835842034368, 1.578614668723388, 1.5848182655558307, 1.5908107224210282, 1.5966066590906587, 1.602219204401067, 1.6076601938044397, 1.6129403351098917, 1.6180693483862478, 1.6230560847275144, 1.627908627611614, 1.6326343798352554, 1.6372401384268453, 1.641732159484399, 1.646116214526473, 1.6503976396590272, 1.654581378633105, 1.6586720206847867, 1.662673833900408, 1.6665907947291994, 1.6704266141666808, 1.6741847610508567, 1.6778684828461357, 1.6814808242341772, 1.6850246437844374, 1.6885026289383283, 1.691917309508249, 1.6952710698652191, 1.698566159965535, 1.7018047053470815, 1.7049887162090471, 1.7081200956744027, 1.7112006473220982, 1.7142320820653345, 1.7172160244430763, 1.720154018384045, 1.7230475324955525, 1.7258979649235673, 1.7287066478251778, 1.7314748514900866, 1.7342037881437724, 1.7368946154614646, 1.739548439819007, 1.7421663193039727, 1.7447492665080047, 1.7472982511192432, 1.7498142023318253, 1.7522980110877768, 1.75475053216514, 1.7571725861248608, 1.75956496112778, 1.7619284146320284, 1.7642636749801734, 1.7665714428846284, 1.768852392819081, 1.7711071743229982, 1.7733364132256764, 1.7755407127957263, 1.7777206548214042, 1.7798768006267287, 1.7820096920279336, 1.784119852234418, 1.7862077866980264, 1.788273983914196, 1.7903189161782, 1.7923430402995026, 1.7943467982769734, 1.7963306179375234, 1.7982949135405197, 1.8002400863501618, 1.802166525177844, 1.804074606896381, 1.8059646969278302, 1.8078371497065324, 1.809692309118866, 1.8115305089211147, 1.8133520731367454, 1.815157316434302], [0.0, 1.2125732532083184, 1.299603834169977, 1.3533811081194858, 1.3928809012737986, 1.424311513100356, 1.4505179563804267, 1.4730510174236051, 1.492852786458892, 1.5105400180718433, 1.5265392821258754, 1.5411583119233234, 1.5546266525809178, 1.5671202395733368, 1.5787769894367065, 1.5897070868146024, 1.5999999999999999, 1.6097294017566597, 1.6189567054684944, 1.6277336604077663, 1.6361042921017168, 1.6441063770807063, 1.6517725802866492, 1.6591313439261701, 1.666207590387857, 1.673023284146037, 1.6795978853782203, 1.6859487194755771, 1.6920912805412038, 1.6980394825778868, 1.7038058688537698, 1.709401787555543, 1.7148375400580693, 1.720122506792594, 1.725265254667211, 1.7302736292008458, 1.7351548339163179, 1.73991549905586, 1.7445617413021068, 1.7490992158853653, 1.753533162216348, 1.7578684439891348, 1.7621095845417891, 1.7662607981339924, 1.7703260176963291, 1.7743089195197057, 1.7782129452822448, 1.7820413217519535, 1.7857970784542474, 1.7894830635522316, 1.793101958153039, 1.7966562892243412, 1.8001484412804512, 1.8035806669764611, 1.8069550967309689, 1.8102737474826898, 1.8135385306731162, 1.8167512595361421, 1.8199136557658373, 1.8230273556251546, 1.8260939155510625, 1.8291148173052634, 1.8320914727141333, 1.8350252280367012, 1.8379173679952563, 1.840769119499476, 1.8435816550917068, 1.8463560961381578, 1.8490935157882362, 1.8517949417220143, 1.8544613587038288, 1.8570937109582477, 1.8596929043830785, 1.862259808612689, 1.8647952589436614, 1.8673000581337018, 1.869774978083704, 1.8722207614119943, 1.8746381229289732, 1.8770277510196371, 1.8793903089408306, 1.8817264360394779, 1.8840367488975212, 1.886321842408808, 1.888582290792742, 1.8908186485491167, 1.8930314513581854, 1.8952212169297196, 1.8973884458044816, 1.8995336221113, 1.9016572142826642, 1.9037596757315565, 1.9058414454920114, 1.9079029488257224, 1.9099445977968434, 1.9119667918169634, 1.913969918162105, 1.9159543524634572, 1.917920459173429, 1.9198685920085063, 1.9217990943702903, 1.9237122997459906], [0.0, 1.2805720813725665, 1.3724831736799834, 1.4292761760407522, 1.4709910433277964, 1.5041842247698687, 1.5318602761158295, 1.5556569488557326, 1.5765691638673067, 1.5952482621736461, 1.612144734874072, 1.6275835723759162, 1.6418071922544648, 1.6550013961150232, 1.6673118345937534, 1.6788548712818738, 1.6897249916860118, 1.7000000000000002, 1.709744753554853, 1.7190139036247216, 1.7278539446056385, 1.7363047714647597, 1.7444008809325253, 1.752172310201031, 1.7596453792595572, 1.7668432843088542, 1.7737865768165977, 1.78049355374932, 1.7869805780902868, 1.7932623441133997, 1.7993520984896965, 1.8052618257908397, 1.8110024050734264, 1.8165837428056488, 1.8220148863116987, 1.827304121072453, 1.8324590545707458, 1.837486688860329, 1.842393483635898, 1.8471854112624428, 1.8518680049669778, 1.856446401190402, 1.8609253769310727, 1.8653093827764304, 1.8696025722084126, 1.8738088276774072, 1.8779317838643748, 1.8819748484884056, 1.8859412209650046, 1.8898339091769085, 1.8936557445826971, 1.897409395857638, 1.9010973812351235, 1.9047220796949076, 1.9082857411254581, 1.911790495571621, 1.9152383616649333, 1.918631254322037, 1.9219709917863679, 1.925259302079429, 1.9284978289202472, 1.9316881371649357, 1.9348317178124388, 1.9379299926174605, 1.9409843183471007, 1.9439959907138245, 1.946966248013949, 1.9498962744977912, 1.9527872034949598, 1.9556401203158935, 1.9584560649486609, 1.9612360345681688, 1.9639809858732704, 1.9666918372657936, 1.9693694708841827, 1.9720147345032868, 1.97462844331075, 1.977211381569538, 1.979764304175275, 1.9822879381162937, 1.984782983843635, 1.987250116557597, 1.9896899874168779, 1.9921032246758534, 1.994490434755072, 1.9968522032496328, 1.9991890958797305, 2.001501659387327, 2.0037904223825707, 2.0060558961433226, 2.008298575370887, 2.0105189389047933, 2.0127174503992786, 2.0148945589639133, 2.017050699770634, 2.019186294629281, 2.0213017525335872, 2.0233974701794333, 2.025473832457034, 2.0275312129186305, 2.02956997422314, 2.031590468559108], [0.0, 1.3481718494401385, 1.4449348111684153, 1.5047258437402864, 1.5486427857051974, 1.5835881928903954, 1.6127252277133721, 1.6377780964780029, 1.6597942406671102, 1.6794593847662536, 1.6972478007257303, 1.7135016347822698, 1.7284761014259926, 1.742366810492142, 1.755327101328328, 1.767479480211443, 1.7789234204175859, 1.7897408333248195, 1.8, 1.8097584566883882, 1.8190651521659245, 1.8279620874042346, 1.8364855801721922, 1.8446672532869806, 1.8525348161365691, 1.860112689419582, 1.86742250948948, 1.8744835391863393, 1.881313005274457, 1.8879263777197264, 1.8943376024680658, 1.9005592967414013, 1.9066029138878624, 1.9124788833254711, 1.9181967299751326, 1.923765176697699, 1.9291922325653277, 1.9344852692612635, 1.9396510874792523, 1.9446959748578199, 1.949625756715982, 1.9544458406408072, 1.9591612558023066, 1.9637766877287606, 1.9682965091591236, 1.9727248074933914, 1.9770654092827002, 1.9813219021352881, 1.985497654359726, 1.9895958326210477, 1.993619417846922, 1.9975712195885829, 2.001453889013754, 2.005269930685498, 2.009021713261028, 2.0127114792275425, 2.0163413537775643, 2.0199133529137447, 2.023429390862273, 2.0268912868647044, 2.030300771409899, 2.033659491960729, 2.0369690182240743, 2.0402308470072557, 2.0434464066993803, 2.046617061411922, 2.0497441148092834, 2.0528288136568458, 2.0558723511112427, 2.058875869775069, 2.061840464536037, 2.064767185208646, 2.067657038994663, 2.0705109927771774, 2.0733299752615975, 2.0761148789757264, 2.078866562139925, 2.0815858504174014, 2.0842735385537576, 2.0869303919141133, 2.089557147925429, 2.0921545174309637, 2.0947231859632542, 2.0972638149414244, 2.0997770427981903, 2.10226348604147, 2.1047237402551064, 2.107158381042873, 2.1095679649195724, 2.1119530301527747, 2.1143140975584345, 2.1166516712534094, 2.118966239367653, 2.121258274718658, 2.123528235450532, 2.1257765656399195, 2.1280036958708117, 2.130210043780159, 2.1323960145760394, 2.1345620015300417, 2.1367083864453846, 2.138835540102199], [0.0, 1.4153969025366557, 1.5169848390948557, 1.579757283376969, 1.625864093611755, 1.6625520137076624, 1.6931419335718623, 1.719444035090924, 1.7425579892237029, 1.763203713325881, 1.781879128378148, 1.7989434413494687, 1.8146645927097094, 1.8292479461556592, 1.842854487126775, 1.8556128305358557, 1.8676274097805683, 1.8789842206565088, 1.8897549489881291, 1.9000000000000001, 1.9097707632429999, 1.9191113340193462, 1.9280598410420753, 1.9366494839641166, 1.9449093538704973, 1.952865089170152, 1.9605394050886533, 1.9679525249856489, 1.9751225346184085, 1.982065675345047, 1.9887965885101857, 1.995328520479145, 2.0016734957082085, 2.007842463666444, 2.0138454242240846, 2.0196915351974996, 2.025389205022103, 2.0309461729617255, 2.0363695788189573, 2.041666023758255, 2.0468416235715297, 2.051902055489016, 2.0568525994545594, 2.061698174634967, 2.06644337181084, 2.071092482195717, 2.075649523147346, 2.080118261165963, 2.0845022325170075, 2.0888047617676566, 2.093028978486141, 2.097177832318765, 2.1012541066307104, 2.1052604308722236, 2.10919929181091, 2.1130730437530367, 2.1168839178614314, 2.120634030664419, 2.124325391838897, 2.127959911340829, 2.131539405947929, 2.135065605271929, 2.1385401572913523, 2.141964633450113, 2.1453405333623126, 2.14866928915929, 2.151952269511186, 2.1551907833519186, 2.1583860833335176, 2.161539369033153, 2.1646517899338655, 2.16772444819796, 2.1707584012501697, 2.173754664186108, 2.1767142120200216, 2.179637981784594, 2.182526874494367, 2.185381756983304, 2.1882034636260905, 2.1909927979519064, 2.193750534158666, 2.196477418535019, 2.1991741707968004, 2.2018414853440444, 2.204480032444188, 2.2070904593466136, 2.209673391333274, 2.2122294327097682, 2.2147591677408767, 2.2172631615342673, 2.2197419608757896, 2.2221960950195134, 2.224626076435437, 2.2270324015175578, 2.2294155512548177, 2.2317759918672366, 2.2341141754093865, 2.236430540343208, 2.238725512082018, 2.240999503507446, 2.243252915460892, 2.245486137211015], [0.0, 1.4822688982138954, 1.588656469448563, 1.6543946674462313, 1.7026798450415692, 1.7411011265922482, 1.7731363011304266, 1.8006810745925546, 1.8248870731109619, 1.8465082273348536, 1.8660659830736148, 1.8839365184276522, 1.9004004330113529, 1.915672793157013, 1.929922190239635, 1.943283315726147, 1.9558655370858569, 1.9677589130810524, 1.9790385164124287, 1.9897676062163525, 2.0, 2.0097818763970237, 2.019153165553774, 2.0281486356775864, 2.0367987522940485, 2.0451303651271457, 2.053167262608464, 2.060930623572695, 2.068439388258761, 2.075710565365743, 2.0827594879848212, 2.0896000283205285, 2.096244778937916, 2.102705206625855, 2.1089917837095324, 2.115114100676504, 2.1210809632280374, 2.12690047627806, 2.132580116957052, 2.1381267983088006, 2.1435469250725867, 2.1488464427056804, 2.1540308806087265, 2.159105390360022, 2.1640747796366857, 2.1689435423953976, 2.173715885798426, 2.178395754298484, 2.182986851235794, 2.1874926582503935, 2.1919164527704345, 2.1962613238015303, 2.200530186212036, 2.20472579368349, 2.208850750473589, 2.2129075221204113, 2.216898445200544, 2.2208257362400396, 2.224691499865209, 2.2284977362700014, 2.2322463480678087, 2.235939146587786, 2.2395778576690293, 2.243164127000062, 2.2466995250459165, 2.250185551600564, 2.2536236399984837, 2.2570151610156275, 2.2603614264869587, 2.2636636926650007, 2.266923163341395, 2.270140992751325, 2.2733182882787295, 2.2764561129785386, 2.2795554879306272, 2.282617394438828, 2.2856427760871125, 2.2886325406639765, 2.291587561965062, 2.294508681483175, 2.29739670999407, 2.3002524290456305, 2.3030765923574634, 2.3058699271373038, 2.3086331353201155, 2.311366894735295, 2.3140718602069352, 2.3167486645917235, 2.3193979197586763, 2.3220202175146003, 2.3246161304788484, 2.3271862129106857, 2.3297310014923243, 2.332251016070445, 2.334746760358846, 2.33721872260463, 2.339667376220187, 2.342093180383078, 2.3444965806057447, 2.3468780092768657, 2.3492378861760383, 2.3515766189633505], [0.0, 1.5488072227168734, 1.6599704798924833, 1.728659633385393, 1.7791123089423988, 1.8192583029947837, 1.852731520820182, 1.8815127656656008, 1.9068053595961343, 1.9293970768383906, 1.9498327706486203, 1.9685055055778238, 1.9857084772195788, 2.0016664061284524, 2.016555451663658, 2.0305163515260727, 2.04366338263711, 2.0560906464527666, 2.067876585650484, 2.0790872990382634, 2.089779019964806, 2.1, 2.1097919617349006, 2.1191912341046324, 2.128229650217298, 2.136935265067836, 2.1453329349388692, 2.1534447893726014, 2.1612906188259977, 2.168888195510308, 2.17625354081166, 2.1834011496510524, 2.1903441798676093, 2.1970946129887365, 2.2036633914371673, 2.2100605362127435, 2.216295248300347, 2.2223759964395216, 2.228310593405469, 2.2341062625651267, 2.2397696961633815, 2.245307106546168, 2.250724271326216, 2.256026573333648, 2.261219036059853, 2.2663063551930236, 2.271292926752882, 2.27618287225669, 2.2809800612857973, 2.2856881317693576, 2.290310508257666, 2.2948504184202845, 2.29931090797258, 2.303694854207506, 2.3080049782866117, 2.31224385642477, 2.3164139300863473, 2.320517515296164, 2.324556811156175, 2.328533907648056, 2.332450792792581, 2.336309359228584, 2.3401114102672316, 2.3438586654711995, 2.347552765802925, 2.3511952783813963, 2.354787700882775, 2.358331465616473, 2.3618279433050833, 2.365278446593689, 2.3686842333115488, 2.3720465095068977, 2.3753664322735966, 2.378645112386591, 2.3818836167615305, 2.385082970752496, 2.388244160300482, 2.391368133944164, 2.3944558047034428, 2.3975080518453242, 2.4005257225408885, 2.403509633421321, 2.4064605720403325, 2.4093792982496565, 2.4122665454937735, 2.4151230220295106, 2.417949412075692, 2.420746376897632, 2.4235145558308475, 2.4262545672480633, 2.4289670094732334, 2.4316524616460504, 2.4343114845401272, 2.4369446213378083, 2.4395523983643574, 2.442135325784049, 2.444693898260525, 2.447228595583602, 2.449739883264556, 2.4522282131017814, 2.4546940237185764, 2.457137741074691], [0.0, 1.6150293260076727, 1.730945572832899, 1.802571657501521, 1.8551815300569836, 1.8970440399712882, 1.9319484668301905, 1.9619603067690696, 1.9883343321025517, 2.011891999794154, 2.0332014593038656, 2.0526725813809765, 2.070611097736276, 2.087251337265226, 2.1027769913446535, 2.1173348151748552, 2.1310439717973395, 2.144002586149042, 2.1562924548684475, 2.1679825029397426, 2.179131368071948, 2.1897893649196267, 2.2000000000000006, 2.209801155558677, 2.2192260257868837, 2.2283038652225002, 2.2370605929242595, 2.2455192846236707, 2.2537005769551084, 2.2616230020134247, 2.269303266208597, 2.2767564842186476, 2.2839963764703297, 2.2910354367833037, 2.297885075443726, 2.3045557419177296, 2.3110570305952396, 2.317397772312344, 2.323586113893828, 2.3296295875549755, 2.3355351716799215, 2.3413093442348845, 2.3469581298650586, 2.352487141553376, 2.3579016175798455, 2.36320645440545, 2.3684062360098252, 2.3735052601332898, 2.378507561808265, 2.3834169345102616, 2.3882369492125246, 2.3929709715895684, 2.3976221775819266, 2.4021935675065076, 2.4066879788731312, 2.411108098047478, 2.415456470883218, 2.4197355124310747, 2.4239475158196537, 2.4280946603916442, 2.432179019169307, 2.4362025657147335, 2.4401671804429776, 2.4440746564397817, 2.447926704829952, 2.4517249597375343, 2.4554709828745898, 2.4591662677915567, 2.462812243818793, 2.4664102797259404, 2.469961687123061, 2.473467723625203, 2.476929595799904, 2.4803484619153364, 2.4837254345050925, 2.4870615827641545, 2.4903579347892375, 2.493615479675535, 2.496835169480793, 2.500017921066697, 2.5031646178266853, 2.5062761113085132, 2.5093532227392004, 2.5123967444593385, 2.5154074412731773, 2.5183860517203676, 2.5213332892747684, 2.5242498434753107, 2.5271363809934773, 2.529993546641657, 2.5328219643262457, 2.5356222379491196, 2.538394952260799, 2.54114067366839, 2.543859951001161, 2.546553316236399, 2.5492212851880005, 2.5518643581600786, 2.5544830205677007, 2.557077743526733, 2.559648984414621, 2.562197187403806], [0.0, 1.6809509943796455, 1.801598667600098, 1.876148359242458, 1.930905642074529, 1.9744768804009738, 2.0108060232170746, 2.0420428753138284, 2.0694934258370825, 2.094012661676194, 2.11619192280521, 2.136457809925734, 2.155128533992198, 2.172447988650058, 2.1886073631226695, 2.203759402809697, 2.218028134705505, 2.2315156889743326, 2.244307200999534, 2.2564744091197513, 2.268078344496276, 2.2791713755085907, 2.2897987845068095, 2.3000000000000007, 2.309809571087583, 2.3192579464083205, 2.328372102975478, 2.3371760584172185, 2.34569129170641, 2.353937091374082, 2.3619308457462624, 2.3696882864462983, 2.3772236939362354, 2.3845500720038344, 2.3916792966760823, 2.398622243941548, 2.405388899810407, 2.411988455572542, 2.4184293905868124, 2.424719544515674, 2.4308661805843577, 2.436876041174306, 2.4427553968424482, 2.448510089680372, 2.454145571782259, 2.459666939471021, 2.465078963833475, 2.4703861180335114, 2.475592601804009, 2.480702363461156, 2.4857191197368587, 2.4906463736844877, 2.4954874308789385, 2.500245414102944, 2.5049232766867475, 2.5095238146471095, 2.514049677753409, 2.5185033796330165, 2.5228873070146105, 2.527203728196482, 2.531454800816747, 2.535642578993621, 2.5397690198962444, 2.543835989799868, 2.547845269673356, 2.5517985603418234, 2.5556974872627167, 2.5595436049496603, 2.5633384010748914, 2.567083300277981, 2.570779667705806, 2.5744288123062793, 2.5780319898961643, 2.581590406021396, 2.5851052186265493, 2.5885775405486102, 2.5920084418487654, 2.595398951994729, 2.5987500619049877, 2.6020627258653466, 2.605337863327271, 2.608576360596676, 2.6117790724211205, 2.6149468234826623, 2.6180804098030475, 2.6211806000673636, 2.624248136871782, 2.6272837379005773, 2.6302880970371825, 2.633261885413699, 2.636205752402903, 2.6391203265565135, 2.642006216493181, 2.6448640117394064, 2.647694283526368, 2.650497585545405, 2.6532744546647136, 2.656025411609635, 2.658750961608729, 2.6614515950076947, 2.66412778785304, 2.666780002447273], [0.0, 1.7465865744991227, 1.8719451405703282, 1.9494057512549654, 2.006301124987049, 2.051573676149883, 2.0893213519106983, 2.1217778998316206, 2.1503003036178296, 2.1757769345706404, 2.198822222535472, 2.2198794255612415, 2.2392791796883382, 2.2572749018029072, 2.2740652464355198, 2.2898089231888132, 2.304634801901323, 2.3186490005826217, 2.3319399788713766, 2.3445822762512307, 2.3566393069485905, 2.36816548415506, 2.3792078583468497, 2.3898073975859786, 2.4000000000000004, 2.409817303146377, 2.4192873374015726, 2.4284350582027416, 2.4372827832056463, 2.445850554094696, 2.4541564381525753, 2.462216781270523, 2.470046421515426, 2.477658870429974, 2.485066467760752, 2.4922805141677347, 2.4993113855817857, 2.506168632182278, 2.5128610644190057, 2.5193968280673307, 2.5257834699574215, 2.5320279957384297, 2.5381369208118056, 2.5441163153835045, 2.5499718444339616, 2.5557088032806554, 2.561332149305572, 2.566846530334866, 2.572256310087104, 2.5775655910471693, 2.5827782350730653, 2.5878978820008167, 2.592927966477093, 2.5978717332189705, 2.602732250874477, 2.6075124246355843, 2.6122150077364092, 2.6168426119531603, 2.6213977172083833, 2.62588268036992, 2.630299743324522, 2.634651040396932, 2.6389386051772754, 2.6431643768126833, 2.647330205812968, 2.6514378594148424, 2.6554890265444935, 2.6594853224141652, 2.663428292784777, 2.667319417923367, 2.671160116281286, 2.674951747916534, 2.6786956176813708, 2.682392978194313, 2.686045032613845, 2.6896529372295586, 2.693217803884993, 2.696740702245173, 2.700222661920677, 2.7036646744590174, 2.707067695213199, 2.7104326450964535, 2.7137604122314074, 2.7170518535012267, 2.720307796009674, 2.723529038456451, 2.726716352433654, 2.7298704836487557, 2.732992153079045, 2.7360820580621117, 2.739140873326594, 2.742169251967077, 2.7451678263667585, 2.7481372090711997, 2.7510779936162693, 2.7539907553131227, 2.7568760519928843, 2.759734424713499, 2.762566398431032, 2.7653724826375603, 2.7681531719676356, 2.77090894677515], [0.0, 1.811949159194239, 1.9419990242893346, 2.0223584467479383, 2.081383018504683, 2.1283498063019617, 2.1675101149605576, 2.2011812856739406, 2.2307710846070057, 2.2572011286185862, 2.2811088413887024, 2.30295406903135, 2.323079820993716, 2.3417489977930037, 2.3591676882168486, 2.3755005412641914, 2.3908812494750924, 2.405419902117972, 2.4192082692603707, 2.4323236798802417, 2.4448319213573213, 2.4567894431904294, 2.468245056627776, 2.479241262880932, 2.489815303494627, 2.5, 2.5098244317555016, 2.5193144881066876, 2.5284933219039143, 2.537381724852411, 2.5459984403675606, 2.554360426053596, 2.562483075263019, 2.570380405181566, 2.5780652173466905, 2.585549235323451, 2.5928432233416205, 2.5999570889773462, 2.6068999723942654, 2.613680324207442, 2.6203059736723953, 2.626784188610987, 2.633121728250818, 2.639324889963421, 2.64539955073004, 2.651351204035047, 2.6571849927807487, 2.6629057387290973, 2.6685179689022878, 2.6740259393126724, 2.6794336563407333, 2.6847448960362352, 2.6899632215807783, 2.695091999118626, 2.7001344121359536, 2.705093474545857, 2.7099720426168523, 2.7147728258657624, 2.7194983970213804, 2.724151201152715, 2.7287335640447425, 2.7332476998951334, 2.7376957183971435, 2.7420796312666904, 2.746401358265295, 2.7506627327650457, 2.7548655068968873, 2.7590113563192205, 2.7631018846400437, 2.7671386275224914, 2.77112305650068, 2.77505658253012, 2.778940559294612, 2.7827762862894705, 2.786565011699031, 2.7903079350847615, 2.794006209898769, 2.7976609458361987, 2.801273211038791, 2.804844034160783, 2.808374406307396, 2.8118652828552375, 2.8153175851631853, 2.8187322021815806, 2.8221099919669275, 2.825451783108699, 2.8287583760743162, 2.832030544477896, 2.8352690362778894, 2.8384745749083833, 2.8416478603484125, 2.8447895701333503, 2.8479003603120976, 2.8509808663535354, 2.85403170400545, 2.857053470108891, 2.8600467433707215, 2.8630120850969205, 2.865950039889007, 2.8688611363058025, 2.871745887492588, 2.8746047917795607], [0.0, 1.8770507427923377, 2.011773173958865, 2.095019832868082, 2.156165100491521, 2.204819359621317, 2.2453866603552304, 2.2802676037180944, 2.3109205355537124, 2.338300185524704, 2.3630668793283913, 2.3856969849055996, 2.406545835701729, 2.4258857779956995, 2.443930305146278, 2.4608499818319447, 2.4767833040366267, 2.491844316429851, 2.5061280862890682, 2.519714720947738, 2.5326723714626227, 2.545059515508525, 2.5569267180746693, 2.568318007400118, 2.5792719630823395, 2.589822585898394, 2.6, 2.6098310249119003, 2.6193396453440063, 2.628547400027439, 2.6374737058103976, 2.646136129567459, 2.6545506177194165, 2.6627316910759538, 2.6706926111214044, 2.6784455226371975, 2.686001576601489, 2.6933710365600683, 2.700563371073827, 2.7075873343802677, 2.7144510370325006, 2.7211620079782084, 2.7277272492975126, 2.7341532846204246, 2.740446202082449, 2.7466116925435466, 2.752655083685537, 2.7585813705116253, 2.7643952426955414, 2.7701011091640506, 2.7757031202430182, 2.7812051876520307, 2.7866110025943622, 2.7919240521565887, 2.7971476342044697, 2.802284870938089, 2.8073387212489314, 2.8123119920041435, 2.817207348368179, 2.822027323259016, 2.826774326024838, 2.8314506504173007, 2.8360584819289003, 2.840599904554566, 2.845076907030995, 2.849491388601565, 2.853845164349594, 2.8581399701382715, 2.8623774671916813, 2.8665592463478524, 2.870686832011701, 2.874761685833006, 2.8787852101321203, 2.88275875109397, 2.886683601748949, 2.89056100475761, 2.8943921550144798, 2.8981782020849804, 2.9019202524881518, 2.9056193718367846, 2.9092765868455546, 2.912892887216828, 2.9164692274130166, 2.9200065283235905, 2.9235056788341933, 2.9269675373047193, 2.930392932962611, 2.933782667217192, 2.9371375149003405, 2.9404582254384293, 2.9437455239600654, 2.9470001123438134, 2.950222670209778, 2.9534138558586225, 2.9565743071613575, 2.9597046424029547, 2.9628054610826564, 2.9658773446736233, 2.968920857344381, 2.9719365466443595, 2.974924944155653, 2.9778865661129825], [0.0, 1.9419023519771341, 2.0812794076859045, 2.167402216752623, 2.230660037281007, 2.2809952882595197, 2.3229641785577964, 2.359050249334318, 2.390762231898002, 2.4190878415700583, 2.4447102181268754, 2.468122187896269, 2.4896913610006655, 2.509699493211249, 2.5283674540261476, 2.5458717010885956, 2.5623555153823174, 2.5779368817901593, 2.592714152138989, 2.6067702014495553, 2.6201755353796976, 2.632990651992493, 2.6452678632842357, 2.6570527186580617, 2.6683851306263793, 2.679300274684148, 2.6898293157646003, 2.7000000000000006, 2.7098371407656763, 2.7193630209502406, 2.7285977282488867, 2.7375594364670865, 2.746264642970275, 2.7547283702582885, 2.762964337996254, 2.7709851105646037, 2.778802224204854, 2.7864262970656, 2.793867124844021, 2.8011337642342204, 2.8082346060067844, 2.8151774392325577, 2.8219695079116858, 2.828617561063881, 2.8351278971681273, 2.841506403702099, 2.847758592417622, 2.8538896308939457, 2.859904370831794, 2.865807373485192, 2.871602932572671, 2.877295094962699, 2.882887679388654, 2.888384293415034, 2.893788348847992, 2.8991030757588043, 2.9043315352678776, 2.9094766312188787, 2.9145411208569936, 2.919527624611848, 2.9244386350739733, 2.9292765252435387, 2.9340435561212326, 2.93874188370346, 2.9433735654372484, 2.947940566184334, 2.9524447637386855, 2.9568879539371085, 2.961271855398542, 2.9655981139240506, 2.969868306586339, 2.974083945534801, 2.978246481539589, 2.982357307295964, 2.98641776050818, 2.9904291267703833, 2.9943926422603946, 2.9983094962608163, 3.0021808335206313, 3.0060077564692715, 3.0097913272941343, 3.0135325698915425, 3.0172324717003334, 3.020891985426465, 3.024512030666347, 3.028093495435981, 3.0316372376124, 3.035144086293409, 3.0386148430811235, 3.0420502832944, 3.045451157114849, 3.048818190670754, 3.0521520870629146, 3.055453527336111, 3.0587231713996275, 3.0619616589000196, 3.0651696100490704, 3.0683476264096856, 3.0714962916422643, 3.074616172213925, 3.0777078180727853, 3.080771763289338], [0.0, 2.0065141567879, 2.1505286254486586, 2.239516949418075, 2.304879511180524, 2.3568895381373514, 2.4002548352865265, 2.4375415772291475, 2.470308694426909, 2.4995767658872285, 2.5260516611050337, 2.550242603936299, 2.5725294357845208, 2.5932032871192927, 2.6124923763030607, 2.6305790321531637, 2.647611302959438, 2.6637110992481663, 2.678980045250224, 2.6935037734394633, 2.707355135368097, 2.720596642016606, 2.7332823459283797, 2.7454593120457567, 2.757168780867312, 2.7684470982621043, 2.7793264660963413, 2.7898355536834556, 2.8000000000000003, 2.80984282934038, 2.819384797766167, 2.828644683769452, 2.8376395336230638, 2.8463848696618714, 2.8548948680375625, 2.863182511178004, 2.871259719163468, 2.879137463434129, 2.8868258656137855, 2.8943342837347394, 2.90167138774888, 2.9088452258883453, 2.9158632831787497, 2.9227325331960725, 2.929459483984982, 2.936050218913825, 2.9425104331237897, 2.9488454661320302, 2.9550603310671293, 2.9611597409471067, 2.9671481323529294, 2.973029686802204, 2.9788083500868354, 2.9844878498037497, 2.990071711278173, 2.9955632720536927, 3.000965695101621, 3.006281980883553, 3.011514978384914, 3.016667395223384, 3.021741806924031, 3.0267406654425013, 3.0316663070084635, 3.036520959353556, 3.041306748381063, 3.04602570432844, 3.050679767468419, 3.0552707933896555, 3.059800557893712, 3.064270761541449, 3.0686830338786084, 3.073038937367465, 3.077339971048815, 3.0815875739562717, 3.0857831283027557, 3.089927962457253, 3.0940233537282187, 3.0980705309685757, 3.1020706770158837, 3.106024930980078, 3.109934390390108, 3.1138001132098134, 3.117623119732518, 3.1214043943630196, 3.1251448872949323, 3.1288455160907067, 3.1325071671710254, 3.1361306972197913, 3.1397169345103664, 3.1432666801583493, 3.146780709305712, 3.1502597722407897, 3.1537045954582514, 3.1571158826628904, 3.1604943157207748, 3.163840555561054, 3.167155243031462, 3.170438999710363, 3.1736924286779535, 3.1769161152490892, 3.1801106276699946, 3.1832765177809863], [0.0, 2.07089556537613, 2.2195309106542296, 2.3113745315203436, 2.3788343293182153, 2.4325131602477756, 2.4772698848657613, 2.515753016557147, 2.5495715059335846, 2.5797786785016146, 2.6071030524238594, 2.632070190613271, 2.6550721221394613, 2.676409318741633, 2.6963173214415774, 2.7149843092949912, 2.732563080898309, 2.749179458422981, 2.764938326834978, 2.77992806622858, 2.7942238656852587, 2.8078902419251324, 2.820982981832147, 2.8335506604836547, 2.8456358416289937, 2.857276037337939, 2.8685044827121216, 2.879350766954214, 2.8898413516980233, 2.9000000000000004, 2.9098481339047986, 2.919405134434907, 2.928688594813222, 2.9377145354273084, 2.9464975872876495, 2.9550511493788507, 2.9633875242512295, 2.9715180353767496, 2.9794531291436273, 2.9872024638478316, 2.994774987627036, 3.002179006950542, 3.009422247009969, 3.0165119051368303, 3.023454698194197, 3.0302569047425734, 3.036924402658567, 3.043462702784133, 3.0498769791000857, 3.056172095847269, 3.0623526319596617, 3.068422903123868, 3.074386981737249, 3.080248715001141, 3.086011741355049, 3.0916795054316415, 3.097255271689952, 3.1027421368649772, 3.1081430413552504, 3.113460779655606, 3.118698009929917, 3.1238572628077614, 3.128940949479533, 3.1339513691563066, 3.1388907159535178, 3.143761085251222, 3.148564479578124, 3.1533028140616617, 3.157977921482118, 3.1625915569648826, 3.167145402341624, 3.1716410702080897, 3.176080107703594, 3.1804640000348656, 3.184794173764782, 3.1890719998846375, 3.193298796686859, 3.197475832453586, 3.2016043279751365, 3.205685458911152, 3.209720358006113, 3.213710117169894, 3.2176557894331523, 3.2215583907864915, 3.225418901911626, 3.229238269812095, 3.2330174093504502, 3.236757204698323, 3.240458510705218, 3.244122154191486, 3.247748935170458, 3.2513396280043674, 3.2548949824983358, 3.2584157249363654, 3.261902559063015, 3.2653561670141356, 3.2687772101998287, 3.2721663301425434, 3.2755241492730276, 3.2788512716866642, 3.2821482838625378, 3.285415755347422], [0.0, 2.135055305374796, 2.288295617348028, 2.3829847041728445, 2.4525345171117205, 2.5078764062338106, 2.554019767562354, 2.593695169769421, 2.6285614113946045, 2.65970445169564, 2.6878753795222865, 2.713616040588238, 2.7373306096664427, 2.7593288676032297, 2.779853652867431, 2.7990989746104225, 2.8172223653796804, 2.834353545523822, 2.850600649517029, 2.8660547956138087, 2.880793502376654, 2.894883285359453, 2.9083816598152827, 2.9213387057570332, 2.9337983056287853, 2.9457991336857376, 2.957375454707462, 2.968557774618643, 2.9793733748778894, 2.989846754760102, 2.9999999999999996, 3.0098530920759257, 3.019424169277667, 3.028729748330661, 3.0377849135380854, 3.046603479007057, 3.0551981284410723, 3.0635805361318234, 3.07176147211376, 3.079750893912696, 3.087558026894282, 3.0951914348758556, 3.102659082388141, 3.1099683897477806, 3.117126281917277, 3.124139231977232, 3.1310132999105087, 3.137754167293982, 3.1443671684068737, 3.1508573181921844, 3.157229337446776, 3.1634876755642987, 3.169636531111661, 3.1756798704828046, 3.181621444842056, 3.1874648055424513, 3.193213318181317, 3.198870175435578, 3.2044384088021336, 3.2099208993538517, 3.2153203876088794, 3.220639482599848, 3.2258806702197833, 3.2310463209130895, 3.236138696772495, 3.241159958096366, 3.2461121694550283, 3.250997305309709, 3.255817255223228, 3.2605738286976385, 3.265268759670511, 3.2699037106984523, 3.2744802768536907, 3.2789999893570942, 3.283464318968797, 3.2878746791556517, 3.292232429052946, 3.296538876236278, 3.300795279318054, 3.3050028503817774, 3.30916275726621, 3.313276125710384, 3.317344041369574, 3.321367551711437, 3.3253476678008154, 3.3292853659809714, 3.3331815894583983, 3.3370372497978136, 3.340853228333361, 3.344630377501643, 3.3483695221017133, 3.3520714604868185, 3.3557369656922713, 3.3593667865035437, 3.3629616484683535, 3.366522254856241, 3.3700492875688743, 3.3735434080041222, 3.3770052578766565, 3.3804354599977255, 3.3838346190164983, 3.3872033221252402], [0.0, 2.199001494154954, 2.3568314455129373, 2.4543565273615253, 2.5259893989718174, 2.5829888109132666, 2.6305141936288146, 2.6713778979623304, 2.707288404465995, 2.7393641975295773, 2.7683788615650142, 2.794890470890576, 2.8193153055564197, 2.841972424531288, 2.863111939442011, 2.882933670130576, 2.901599867338876, 2.919244136617882, 2.935977851134229, 2.9518948581888735, 2.9670749980718165, 2.9815867785177357, 2.9954894373960834, 3.0088345546462163, 3.021667327017771, 3.03402758708312, 3.0459506258725626, 3.0574678629815515, 3.068607396964766, 3.079394460865106, 3.0898518018983103, 3.1000000000000005, 3.109857736712636, 3.1194420234475033, 3.128768396291719, 3.1378510830932056, 3.146703147439998, 3.1553366132758356, 3.1637625732041696, 3.1719912829846924, 3.1800322442882965, 3.1878942774237933, 3.1955855854643853, 3.2031138109696555, 3.2104860863088933, 3.2177090784353513, 3.2247890288320207, 3.2317317892424144, 3.2385428537106224, 3.2452273873802002, 3.25179025243871, 3.258236031541816, 3.2645690490060257, 3.2707933900211628, 3.276912918101178, 3.282931290964264, 3.2888519750094085, 3.2946782585361283, 3.300413263836476, 3.3060599582731816, 3.311621164444557, 3.3170995695253276, 3.3224977338625092, 3.327818098896739, 3.333062994471782, 3.3382346455882366, 3.343335178651551, 3.348366627259252, 3.353330937567701, 3.3582299732746237, 3.3630655202500632, 3.367839290845195, 3.3725529279056183, 3.3772080085131866, 3.381806047478183, 3.38634850060164, 3.390836767725766, 3.3952721955888325, 3.3996560804994425, 3.4039896708437296, 3.408274169437927, 3.412510735737628, 3.4167004879141336, 3.420844504807388, 3.4249438277642317, 3.4289994623699935, 3.433012380080769, 3.436983519763186, 3.4409137891478747, 3.444804066202426, 3.4486552004291213, 3.452468014092366, 3.4562433033803446, 3.459981839505104, 3.463684369744952, 3.467351618432773, 3.4709842878936015, 3.4745830593345683, 3.4781485936900856, 3.4816815324249726, 3.4851824982980038, 3.488652096088206], [0.0, 2.2627416997969525, 2.4251465064166373, 2.5254984479962466, 2.599207668339954, 2.657859263896684, 2.706762216238972, 2.7488103949461684, 2.7857618025475976, 2.8187673437952703, 2.848623026200712, 2.8759031004112696, 2.9010359127608534, 2.9243497704539774, 2.94610203484721, 2.9664983177557835, 2.9857055729177837, 3.0038612785715433, 3.0210800361436867, 3.037458413190832, 3.053078564251751, 3.0680109828247075, 3.0823166238466473, 3.096048562351837, 3.1092533051618356, 3.1219718394350227, 3.1342404791466736, 3.146091554619895, 3.1575539788734135, 3.1686537163545165, 3.1794141736292048, 3.189856527162629, 3.2000000000000006, 3.209862096644973, 3.2194588035133194, 3.2288047608610277, 3.2379134109369887, 3.246797126210693, 3.2554673208155336, 3.2639345477844133, 3.272208584203434, 3.2802985060466705, 3.288212754161413, 3.2959591926342964, 3.3035451605732984, 3.3109775181798233, 3.3182626878523402, 3.325406690952863, 3.3324151807757145, 3.339293472181179, 3.3460465682920746, 3.352679184596813, 3.3591957707564406, 3.365600530373996, 3.3718974389511542, 3.3780902602286424, 3.384182561082408, 3.3901777251265393, 3.3960789651557737, 3.4018893345447467, 3.40761173770754, 3.413248939709262, 3.4188035751110863, 3.4242781561211912, 3.4296750801161386, 3.434996636590342, 3.440245013585188, 3.4454223036440133, 3.450530509334422, 3.4555715483752385, 3.460547258401692, 3.4654594013991304, 3.4703096678326357, 3.4750996804973195, 3.4798309981117197, 3.4845051186746847, 3.489123482604214, 3.493687475675105, 3.4981984317707306, 3.5026576354629158, 3.507066324432696, 3.511425691743618, 3.51573688797827, 3.5200010232478247, 3.5242191690835782, 3.528392360218732, 3.5325215962679843, 3.53660784331193, 3.5406520353926587, 3.5446550759265074, 3.548617839039412, 3.5525411708299135, 3.556425890564489, 3.560272791809521, 3.5640826435039066, 3.5678561909760274, 3.571594156908495, 3.575297242253893, 3.5789661271044637, 3.5826014715185104, 3.5862039163060784, 3.589774083776306], [0.0, 2.326282994255325, 2.493248379592326, 2.596418359249349, 2.672197448758669, 2.7324960720358225, 2.7827722950854756, 2.8260012518306215, 2.863990312236728, 2.8979227002452856, 2.9286167764926536, 2.9566629174745156, 2.9825014981538276, 3.006470045110323, 3.0288331468064036, 3.0498021889557982, 3.0695488136163567, 3.0882143596284513, 3.1059166466044137, 3.122754953867543, 3.1388137429834084, 3.1541654870169804, 3.16887285261432, 3.1829904052389293, 3.1965659576960093, 3.2096416481268806, 3.222254810259536, 3.234438682302671, 3.2462229891973964, 3.257634424512928, 3.268697052107922, 3.2794326431154976, 3.289860960393774, 3.3000000000000007, 3.3098661972732866, 3.319474603590703, 3.328839038680325, 3.3379722224497663, 3.3468858895589797, 3.3555908893863893, 3.364097273573831, 3.3724143729627998, 3.3805508654326624, 3.3885148359057973, 3.3963138295837103, 3.4039548993128954, 3.411444647842726, 3.4187892656243957, 3.425994564705494, 3.4330660091958225, 3.440008742713642, 3.446827613165589, 3.4535271951660893, 3.460111810361871, 3.466585545892859, 3.472952271191454, 3.4792156532970093, 3.4853791708407416, 3.491446126837645, 3.4974196604058485, 3.503302757519882, 3.509098260892169, 3.514808879066445, 3.5204371947975877, 3.5259856727842096, 3.531456666813276, 3.5368524263697676, 3.5421751027588813, 3.547426754783424, 3.5526093540147374, 3.557724789691697, 3.5627748732789293, 3.5677613427123975, 3.5726858663578143, 3.5775500467049515, 3.5823554238187865, 3.5871034785664895, 3.591795635637562, 3.5964332663728897, 3.601017691417066, 3.6055501832071277, 3.6100319683096966, 3.6144642296175022, 3.6188481084153605, 3.623184706324827, 3.6274750871360153, 3.631720278534355, 3.6359212737294806, 3.640079032992831, 3.644194485110076, 3.648268528753961, 3.652302033782787, 3.6562958424693037, 3.6602507706644656, 3.664167608900169, 3.6680471234347696, 3.671890057244928, 3.675697130967063, 3.6794690437914603, 3.6832064743118846, 3.6869100813333207, 3.6905805046403115], [0.0, 2.3896319999231235, 2.561144162745133, 2.667123652527183, 2.7449663473599664, 2.806907014119008, 2.8585523520815044, 2.902958513591773, 2.941982086655593, 2.9768385165995404, 3.0083684495397374, 3.0371783390201297, 3.063720552231659, 3.088341807229586, 3.1113138977114647, 3.132853965816537, 3.153138327734613, 3.1723121712251454, 3.190496524347292, 3.2077933699846786, 3.224289469748144, 3.240059270278795, 3.2551671447518324, 3.2696691445496535, 3.283614384508929, 3.2970461502708166, 3.3100027922300463, 3.322518453733459, 3.3346236691875073, 3.346345859076866, 3.357709742563747, 3.3687376836496523, 3.379449983372024, 3.3898651278541694, 3.4000000000000004, 3.4098700610635344, 3.419489507109706, 3.428871404432831, 3.438027807249444, 3.44696986038669, 3.4557078892112774, 3.464251478660842, 3.4726095429295194, 3.4807903871071373, 3.4888017618650506, 3.4966509121118583, 3.5043446204020614, 3.511889245764334, 3.5192907585191144, 3.52655477157406, 3.533686568617709, 3.540691129574197, 3.5475731536331954, 3.554337080127898, 3.5609871074986397, 3.56752721054965, 3.5739611561805735, 3.5802925177522145, 3.5865246882267994, 3.5926608922064713, 3.598704196979393, 3.6046575226703257, 3.6105236515816794, 3.6163052368015447, 3.6220048101468523, 3.627624789502559, 3.6331674856112968, 3.6386351083623, 3.6440297726233974, 3.64935350365548, 3.654608242144906, 3.6597958488858477, 3.6649181091414915, 3.6699767367102467, 3.674973377720657, 3.679909614176529, 3.684786967271796, 3.6896069004929, 3.6943708225248857, 3.69908008997595, 3.7037360099339556, 3.708339842367208, 3.7128928023808045, 3.7173960623388647, 3.721850753862145, 3.7262579697097395, 3.7306187655528604, 3.7349341616480842, 3.7392051444168253, 3.7434326679373107, 3.7476176553548144, 3.7517610002154935, 3.755863567728749, 3.7599261959626724, 3.7639496969768107, 3.7679348578961585, 3.7718824419300088, 3.7757931893390495, 3.779667818353817, 3.7835070260474426, 3.7873114891653943, 3.7910818649147373], [0.0, 2.4527949305852137, 2.6288405156447814, 2.7376212631790393, 2.8175215019083018, 2.8810993889756547, 2.9341098203503795, 2.979689728822746, 3.0197447758707177, 3.055522533562096, 3.087885868033636, 3.11745726265444, 3.1447010416186676, 3.169973087458991, 3.1935523779441826, 3.2156617947306505, 3.2364823144108414, 3.256162962357858, 3.2748279656535146, 3.292582002800599, 3.309514128699297, 3.3257007577698676, 3.3412079647040636, 3.356093282438588, 3.370407124017127, 3.3841939192101207, 3.397493032092786, 3.410339508491444, 3.42276468990025, 3.4347967215841666, 3.44646097608414, 3.457780408528621, 3.468775856553584, 3.479466294908921, 3.4898690527487153, 3.4999999999999996, 3.509873707959152, 3.5195035882897527, 3.5289020138262814, 3.5380804239767842, 3.5470494170288296, 3.5558188312698373, 3.564397816514585, 3.5727948973736523, 3.581018029384715, 3.5890746489543357, 3.596971717913999, 3.6047157633746982, 3.6123129134648257, 3.619768929452831, 3.6270892346860997, 3.634278940718494, 3.6413428709490145, 3.648285582051641, 3.655111383440195, 3.661824354981227, 3.6684283631413526, 3.6749270757327155, 3.6813239754005704, 3.687622371979985, 3.6938254138339115, 3.699936098272064, 3.705957281138878, 3.7118916856490656, 3.7177419105407306, 3.723510437608544, 3.7291996386728608, 3.7348117820348694, 3.740349038462744, 3.7458134867492214, 3.751207118877026, 3.75653184482498, 3.7617894970444787, 3.766981834633179, 3.772110547230216, 3.7771772586550387, 3.782183530309892, 3.7871308643641997, 3.7920207067374743, 3.796854449895882, 3.8016334354763286, 3.806358956750696, 3.811032260941829, 3.815654551401863, 3.8202269896626393, 3.824750697367141, 3.829226758090159, 3.833656219055769, 3.838040092758549, 3.842379358494993, 3.846674963811019, 3.850927825871063, 3.855138832753805, 3.8593088446792145, 3.8634386951712574, 3.8675291921602732, 3.8715811190287615, 3.8755952356040346, 3.8795722791009517, 3.883512965017734, 3.887417987987635, 3.891288022589066], [0.0, 2.5157776275776857, 2.696343698880277, 2.8079177108554925, 2.8898696223368305, 2.955080057949785, 3.0094516874805732, 3.056201993660658, 3.0972855714103953, 3.1339820278660473, 3.167176385780791, 3.197507112608222, 3.2254504554267442, 3.2513714350958574, 3.2755561929560053, 3.2982333338032084, 3.31958848133422, 3.33977448758527, 3.358918769532507, 3.3771286936060054, 3.3944956014514607, 3.4110978696532803, 3.42700326956454, 3.442270811448674, 3.4569522028519852, 3.4710930144094583, 3.4847336209842834, 3.497909968307065, 3.510654202656657, 3.52299519201017, 3.5349589604228857, 3.5465690524634415, 3.5578468408351727, 3.5688117875202745, 3.5794816666496394, 3.5898727556571783, 3.6, 3.6098771557254463, 3.6195169133767773, 3.628931006102359, 3.6381303043318494, 3.6471248989795253, 3.655924174808469, 3.664536875323617, 3.6729711603443844, 3.6812346572288632, 3.689334506573961, 3.697277403093371, 3.7050696322731387, 3.7127171033191626, 3.720225378839164, 3.727599701641129, 3.73484501897896, 3.741966004532594, 3.7489670783726785, 3.7558524251282934, 3.762626010548914, 3.7692915966285083, 3.7758527554394528, 3.782312881806529, 3.7886752049361316, 3.794942799102687, 3.801118593482803, 3.8072053812177087, 3.813205827775725, 3.819122478678872, 3.8249577666509422, 3.830714018238404, 3.8363934599502656, 3.841998223958358, 3.8475303533953986, 3.852991807284513, 3.858384465130656, 3.86371013120147, 3.8689705385225266, 3.874167352609598, 3.879302174958505, 3.8843765463112745, 3.8893919497156397, 3.894349813393415, 3.899251513431964, 3.9040983763117154, 3.908891681281615, 3.9136326625933893, 3.918322511604613, 3.9229623787597405, 3.9275533754575207, 3.9320965758125754, 3.936593018318247, 3.9410437074173377, 3.945449614986783, 3.9498116817419033, 3.9541308185654005, 3.958407907765913, 3.962643804270576, 3.966839336755709, 3.970995308719452, 3.975112499499911, 3.9791916652420958, 3.9832335398167404, 3.9872388356938444, 3.9912082447735955], [0.0, 2.578585591832089, 2.7636596082040747, 2.878019135273725, 2.9620170275565765, 3.0288554825398024, 3.084584533858029, 3.132501990714411, 3.174611245715771, 3.212223852192023, 3.246246928043719, 3.2773348804643447, 3.3059758463389173, 3.332543959501329, 3.3573325049898153, 3.3805757948623176, 3.4024640870274463, 3.4231540495682564, 3.442776280505514, 3.4614408267394716, 3.4792413103172213, 3.4962580645436927, 3.5125605527262396, 3.5282092583564855, 3.5432571798920134, 3.557751025667254, 3.5717321785291474, 3.5852374816159767, 3.5982998837585813, 3.6109489736412046, 3.6232114250259673, 3.6351113702864097, 3.6466707157087943, 3.6579094091558915, 3.668845668500904, 3.679496177554076, 3.6898762548952155, 3.7000000000000006, 3.7098804202390534, 3.7195295416861387, 3.7289585061579986, 3.738177656494906, 3.747196611756432, 3.7560243337345898, 3.7646691859637973, 3.7731389862239193, 3.781441053381337, 3.789582249287465, 3.797569016349445, 3.805407411300201, 3.8131031356214415, 3.8206615630111362, 3.828087764234482, 3.835386529652761, 3.8425623896864542, 3.849619633436528, 3.856562325659876, 3.863394322271002, 3.8701192845213077, 3.876740691989501, 3.883261854501138, 3.8896859230818297, 3.896015900036915, 3.9022546482401417, 3.908404899704917, 3.914469263503813, 3.920450233095096, 3.9263501931089233, 3.932171425640495, 3.9379161160926484, 3.943586358606188, 3.9491841611124796, 3.954711450039495, 3.96017007469955, 3.9655618113842848, 3.9708883671901147, 3.9761513835952087, 3.9813524398071825, 3.9864930558989844, 3.9915746957488816, 3.996598769799121, 4.001566637646546, 4.006479610477352, 4.011338953357135, 4.016145887386457, 4.020901591731338, 4.025607205537294, 4.03026382973489, 4.034872528744107, 4.039434332084289, 4.043950235895889, 4.048421204379774, 4.052848171159403, 4.057232040570803, 4.0615736888849, 4.065873965466437, 4.070133693873389, 4.074353672900525, 4.078534677570489, 4.0826774600755575, 4.086782750672989, 4.090851258536694], [0.0, 2.641224012371414, 2.8307938050733115, 2.947931328022547, 3.0339696781897114, 3.102431757870407, 3.159514566753938, 3.208596023682008, 3.2517281872235104, 3.2902544706665084, 3.3251040274153247, 3.356947161375628, 3.3862838671437245, 3.413497366928351, 3.4388880701818474, 3.4626959808179043, 3.485115978447405, 3.5063085368991977, 3.5264074266517618, 3.545525367839868, 3.5637582567562958, 3.5811883781445273, 3.5978868826989374, 3.6139157231625076, 3.6293291854194183, 3.644175112432442, 3.658495892311318, 3.6723292631795474, 3.6857089742535503, 3.6986653329792234, 3.711225661071711, 3.723414677122737, 3.735254819561137, 3.746766520818672, 3.757968441313017, 3.7688776701337803, 3.779509897976258, 3.789879566817418, 3.8000000000000007, 3.809883515732446, 3.8195415264859998, 3.828984626346882, 3.8382226680386924, 3.847264831051277, 3.85611968208415, 3.8647952288249234, 3.873298967928233, 3.8816379279320414, 3.8898187077409947, 3.89784751121681, 3.905730178340304, 3.913472213346109, 3.9210788101773066, 3.9285548755615576, 3.9359050499712973, 3.9431337266973654, 3.950245069236817, 3.957243027171161, 3.9641313506900935, 3.9709136038974666, 3.9775931770203714, 3.9841732976284248, 3.99065704095829, 3.997047339428, 4.003346991416417, 4.0095586693751155, 4.015684927332888, 4.021728207846792, 4.027690848448169, 4.033575087627171, 4.039383070394999, 4.045116853459235, 4.050778410044206, 4.056369634385305, 4.06189234592345, 4.067348293223458, 4.072739157637915, 4.078066556736193, 4.083332047516509, 4.088537129417334, 4.093683247143058, 4.098771793317546, 4.103804110978032, 4.108781495920803, 4.113705198909118, 4.118576427753035, 4.1233963492699335, 4.128166091133939, 4.13288674362168, 4.137559361261354, 4.142184964391434, 4.146764540634936, 4.151299046294692, 4.155789407674654, 4.1602365223319255, 4.164641260263826, 4.169004465034015, 4.173326954841404, 4.177609523535313, 4.181852941580105, 4.186057956972282, 4.190225296112847], [0.0, 2.70369779173372, 2.8977515438981785, 3.017659760938298, 3.1057332057736398, 3.175814642555673, 3.234247650737282, 3.284490048235535, 3.328642431665956, 3.3680799905328462, 3.4037538558253537, 3.4363501863778136, 3.4663808033305687, 3.494237993378973, 3.520229271663396, 3.5446003189925874, 3.5675506245318482, 3.5892444578526557, 3.609818753552594, 3.629388897974524, 3.648053055679198, 3.6658954577194174, 3.682988937741386, 3.699396913877608, 3.7151749560549407, 3.7303720388821993, 3.745031553089651, 3.759192129433603, 3.772888315412292, 3.786151135344048, 3.7990085571939343, 3.811485884231022, 3.8236060856280147, 3.8353900771120046, 3.8468569604819414, 3.8580242290415403, 3.8689079446235093, 3.87952289080586, 3.8898827060729375, 3.9000000000000004, 3.909886455001399, 3.919552915748916, 3.9290094680160093, 3.9382655084181533, 3.9473298062859494, 3.956210558715597, 3.964915439682681, 3.9734516439735885, 3.9818259265791247, 3.9900446381030803, 3.998113756661346, 4.006038916682107, 4.013825434962566, 4.021478334290901, 4.029002364902234, 4.036402024003424, 4.043681573572154, 4.050845056610741, 4.0578963120134075, 4.0648389881869775, 4.07167655554875, 4.078412318011156, 4.085049423550488, 4.091590873946269, 4.09803953376838, 4.10439813868081, 4.110669303123673, 4.116855527428669, 4.122959204417571, 4.128982625528306, 4.134927986508765, 4.14079739271454, 4.146592864043312, 4.152316339535474, 4.157969681667805, 4.163554680364528, 4.1690730567478385, 4.174526466648033, 4.179916503891544, 4.185244703383573, 4.190512544000602, 4.195721451306705, 4.20087280010644, 4.205967916846006, 4.2110080818733975, 4.215994531567417, 4.220928460344578, 4.225811022552269, 4.230643334255807, 4.235426474926507, 4.240161489037258, 4.244849387571665, 4.249491149452315, 4.254087722893351, 4.258640026682099, 4.263148951394226, 4.267615360546492, 4.27204009169095, 4.276423957454109, 4.280767746524392, 4.285072224590918, 4.289338135236504], [0.0, 2.7660115687249567, 2.964537796427791, 3.0872096114997976, 3.177312938897126, 3.249009585424942, 3.308789334892463, 3.3601896996616083, 3.4053596900831384, 3.4457061904951316, 3.4822022531844965, 3.51554985130798, 3.5462726022608533, 3.574771834009919, 3.6013621491851087, 3.6262948909510664, 3.649774146221923, 3.671967970590462, 3.693016454669707, 3.713037644182151, 3.7321319661472296, 3.7503855929423464, 3.767873036855305, 3.784659177655106, 3.8008008660227053, 3.816348205314688, 3.831345586314026, 3.8458325301236997, 3.8598443804792706, 3.873412876735514, 3.8865666314522938, 3.8993315310786008, 3.911731074171714, 3.923786658516284, 3.9355178261621053, 3.9469424735917658, 3.9580770328248573, 3.968936628165558, 3.9795352124327055, 3.9898856858221525, 4.0, 4.009889249581816, 4.019563752794047, 4.0290331228217156, 4.038306331107548, 4.047391763671236, 4.056297271355173, 4.06503021476839, 4.073597504588097, 4.082005637784336, 4.0902607302542915, 4.098368546286261, 4.106334525216928, 4.114163805597737, 4.12186124714539, 4.129431450716622, 4.136878776517521, 4.144207360731954, 4.151421130731486, 4.158523819010005, 4.1655189759696425, 4.172409981670117, 4.179200056641058, 4.185892271845838, 4.192489557875832, 4.1989947134455505, 4.205410413251709, 4.21173921525268, 4.217983567419065, 4.224145814000964, 4.230228201353009, 4.236232883354213, 4.242161926456075, 4.248017314389236, 4.25380095255612, 4.259514672134425, 4.265160233914104, 4.270739331888388, 4.276253596617601, 4.281704598382845, 4.2870938501451725, 4.292422810324505, 4.297692885411361, 4.3029054324233575, 4.308061761217453, 4.313163136668027, 4.318210780720043, 4.323205874325838, 4.328149559273371, 4.333042939913192, 4.337887084790794, 4.3426830281905415, 4.347431771596851, 4.352134285077931, 4.3567915085969675, 4.361404353255267, 4.365973702471588, 4.370500413101558, 4.374985316500788, 4.379429219535083, 4.38383290554087, 4.388197135238772], [0.0, 2.828169738841296, 3.0311572736383, 3.1565857856221857, 3.2487139266593905, 3.322021749511282, 3.3831448772491357, 3.435700317670707, 3.481885373965613, 3.52313854615894, 3.560454753094581, 3.594551742760952, 3.6259648993512283, 3.6551045695262476, 3.6822924257069753, 3.7077854592741963, 3.7317923434096003, 3.754484910273012, 3.776006398611849, 3.7964775068873657, 3.8160009189279815, 3.834664743587923, 3.852545167604773, 3.869708528734101, 3.8862129552127276, 3.9021096763263534, 3.9174440804133734, 3.932256576700112, 3.9465833031711317, 3.960456712432098, 3.973906060028025, 3.986957814131537, 3.9996360013625356, 4.011962500359457, 4.02395729232357, 4.035638675909536, 4.0470234523994195, 4.05812708597272, 4.068963842997826, 4.079546913565464, 4.0898885179211195, 4.1000000000000005, 4.109891909901075, 4.119574076838101, 4.129055673861231, 4.138345275441874, 4.147450908847572, 4.156380100095915, 4.165139915161745, 4.173736997015858, 4.18217759899267, 4.190467614916313, 4.198612606356947, 4.206617827340211, 4.21448824679099, 4.222228568957066, 4.229843252027645, 4.237336525135452, 4.244712403908454, 4.251974704717626, 4.259127057750195, 4.2661729190230195, 4.273115581437889, 4.279958184969261, 4.286703726065139, 4.29335506633311, 4.299914940576019, 4.306385964235011, 4.312770640291799, 4.319071365676775, 4.325290437224945, 4.331430057217569, 4.33749233854371, 4.343479309512663, 4.349392918345299, 4.3552350373697815, 4.361007466944763, 4.366711939131108, 4.372350121131305, 4.377923618514014, 4.383433978239747, 4.388882691502224, 4.394271196398803, 4.399600880442175, 4.404873082924574, 4.410089097144801, 4.415250172507525, 4.4203575165035955, 4.4254122965793785, 4.430415641902534, 4.435368645031048, 4.440272363491854, 4.445127821274858, 4.449936010247768, 4.454697891496743, 4.4594143965974755, 4.464086428821027, 4.468714864278393, 4.473300553007517, 4.477844320006196, 4.482346966214095, 4.486809269446851], [0.0, 2.890176472650677, 3.0976144454337464, 3.225792938172988, 3.319940959784966, 3.3948560336427973, 3.457319266770786, 3.511026968727335, 3.5582246178847976, 3.6003822529297898, 3.6385166059895675, 3.6733611614519046, 3.7054630416403636, 3.73524158993752, 3.763025531331201, 3.7890774916575505, 3.8136107191922677, 3.836800813461346, 3.8587941536767807, 3.879714084575703, 3.89966554129724, 3.9187385644545913, 3.9370110111556476, 3.954550673590447, 3.971416954439157, 3.9876622061734865, 4.003332812256905, 4.018470067875337, 4.033110903327317, 4.047288482731701, 4.061032703052145, 4.074370612767652, 4.087326765274221, 4.099923518892569, 4.112181292905533, 4.124118787160033, 4.135753171300968, 4.14710024855512, 4.158174598076527, 4.168989699144512, 4.179558039929612, 4.189891213079248, 4.2, 4.209894445408052, 4.219583923469801, 4.229077196649251, 4.238382468209264, 4.247507429173004, 4.256459300434596, 4.26524487060988, 4.273870530135672, 4.282342302056344, 4.2906658698777385, 4.298846602818357, 4.306889578745203, 4.314799605045214, 4.3225812376519945, 4.3302387984206785, 4.337776391020615, 4.345197915495515, 4.35250708162332, 4.359707421192974, 4.366802299302105, 4.3737949247681245, 4.380688359735218, 4.387485528550822, 4.394189225977472, 4.400802124799043, 4.407326782874334, 4.4137656496856845, 4.420121072425487, 4.426395301659325, 4.432590496600694, 4.4387087300289325, 4.444751992879042, 4.450722198529394, 4.456621186810938, 4.462450727759432, 4.468212525130253, 4.473908219693652, 4.479539392326762, 4.48510756691726, 4.490614213092336, 4.496060748785461, 4.501448542652431, 4.506778916347218, 4.512053146667295, 4.517272467577371, 4.522438072119706, 4.527551114218605, 4.532612710386047, 4.537623941334912, 4.542585853505763, 4.547499460512695, 4.552365744513379, 4.557185657508014, 4.561960122571595, 4.5666900350235755, 4.571376263538715, 4.576019651202629, 4.580621016515332, 4.585181154345824], [0.0, 2.9520357323812494, 3.1639135584251137, 3.2948354914868614, 3.390998589678808, 3.467517091927729, 3.531317243198343, 3.586174466201894, 3.6343822999157434, 3.6774422466778756, 3.71639280001916, 3.7519831432999706, 3.784772109056805, 3.815188015996572, 3.8435666249004465, 3.870176182659191, 3.895234501761313, 3.918920940138836, 3.9413850099991916, 3.962752696061602, 3.983131179421485, 4.002612427856601, 4.021275964872415, 4.03919103363427, 4.056418308234601, 4.07301126165979, 4.089017270131617, 4.104478512688483, 4.119432710058486, 4.133913736181445, 4.1479521279141345, 4.1615755126617575, 4.174808969343555, 4.1876753348216695, 4.200195465418585, 4.21238846121931, 4.2242718593554756, 4.235861801294774, 4.247173178232975, 4.258219757950209, 4.269014295904834, 4.27956863286497, 4.289893780994668, 4.3, 4.309896864685281, 4.319593325059996, 4.329097759963751, 4.338418025032839, 4.3475614957122115, 4.3565351059163655, 4.365345382858429, 4.373998478495691, 4.382500197979664, 4.390856025447745, 4.39907114744995, 4.407150474267074, 4.4150986593446495, 4.422920117039689, 4.430619038853531, 4.43819940830362, 4.445665014569317, 4.4530194650314385, 4.460266196811742, 4.467408487406862, 4.474449464500916, 4.481392115031969, 4.4882392935796505, 4.4949937301341745, 4.501658037300915, 4.508234716989168, 4.5147261666289475, 4.521134684955324, 4.5274624773960435, 4.533711661094729, 4.539884269598919, 4.5459822572395625, 4.5520075032260285, 4.557961815478647, 4.563846934218751, 4.569664535334458, 4.57541623353886, 4.581103585335829, 4.586728091807399, 4.592291201235471, 4.597794311569566, 4.603238772751386, 4.60862588890606, 4.613956920409191, 4.619233085838057, 4.624455563814732, 4.629625494748212, 4.6347439824821794, 4.6398120958544595, 4.644830870173814, 4.6498013086193115, 4.6547243835670775, 4.659601037848942, 4.664432185947134, 4.6692187151289, 4.673961486524655, 4.678661336153, 4.683319075895739], [0.0, 3.013751286929225, 3.230058652015345, 3.3637176521162107, 3.461891145665798, 3.5400093513829636, 3.605143315003042, 3.6611473886024344, 3.710363060113967, 3.7543232224338183, 3.794088079942576, 3.830422478502946, 3.8638969336603806, 3.894948718595551, 3.9239206135381384, 3.9510864733752564, 3.9766686642051026, 4.000850293634584, 4.023783999588307, 4.045598400634647, 4.06640291860773, 4.08629144397289, 4.105345162761953, 4.1236347657448125, 4.141222195472552, 4.15816204284316, 4.174502674530451, 4.190287151372029, 4.205553982689307, 4.220337750594081, 4.23466963034971, 4.2485778269426975, 4.262087943594679, 4.275223294597524, 4.288005172298083, 4.300453076089652, 4.312584909736894, 4.3244171521626384, 4.335965005879486, 4.347242526498155, 4.358262736143897, 4.36903772312911, 4.3795787298392534, 4.389896230470839, 4.4, 4.409899175546017, 4.4196023111173535, 4.429117426581023, 4.438452051573766, 4.447613264971192, 4.456607730445, 4.465441728565911, 4.474121185848519, 4.482651701082145, 4.4910385692473405, 4.499286803279721, 4.507401153910217, 4.51538612778283, 4.5232460040268485, 4.530984849439528, 4.538606532417194, 4.546114735756927, 4.553512968437295, 4.560804576474608, 4.5679927529406585, 4.57508054721874, 4.5820708735666065, 4.588966519047923, 4.595770150887452, 4.602484323299656, 4.609111483835459, 4.61565397928752, 4.622114061190478, 4.62849389094917, 4.634795544624686, 4.641021017405412, 4.647172227787656, 4.65325102148831, 4.659259175109951, 4.665198399576981, 4.671070343359843, 4.676876595502837, 4.682618688469769, 4.6882981008204645, 4.693916259730117, 4.699474543362446, 4.704974283106751, 4.710416765688174, 4.71580323515969, 4.721134894783765, 4.726412908810899, 4.731638404161843, 4.73681247201965, 4.741936169337351, 4.747010520266579, 4.75203651751205, 4.75701512361653, 4.761947272180506, 4.766833869020523, 4.771675793269874, 4.776473898425049, 4.781229013341134], [0.0, 3.075326725469258, 3.2960535729865867, 3.4324434260220418, 3.5326227506249546, 3.612337027921038, 3.678801775667581, 3.7359500961087306, 3.786171317271792, 3.831029651343531, 3.8716069642629933, 3.9086837288358303, 3.942842117091907, 3.9745283363558577, 4.004092170369251, 4.03181306928343, 4.057917942467986, 4.0825936386916295, 4.105995914499664, 4.128256016329855, 4.149485601667775, 4.169780479301147, 4.189223494013648, 4.207886780893143, 4.225833548069521, 4.243119501814325, 4.2597939970047305, 4.275900974275544, 4.2914797297511145, 4.306565552107414, 4.321190253564981, 4.335382615380304, 4.349168763887065, 4.362572489722924, 4.3756155202691716, 4.38831775332082, 4.400697458443178, 4.412771451248072, 4.424555244858134, 4.4360631820611935, 4.447308551043966, 4.458303687101119, 4.469060062316834, 4.479588364891096, 4.489898569517395, 4.5, 4.509901385118541, 4.519610908597886, 4.5291362539165005, 4.538484644581988, 4.547662880414811, 4.556677370307129, 4.565534161861076, 4.5742389682576, 4.582797192661609, 4.59121395043048, 4.599494089359667, 4.60764220817064, 4.615662673421686, 4.623559635000801, 4.631337040341423, 4.638998647485676, 4.6465480371057994, 4.653988623582211, 4.66132366522593, 4.6685562737237, 4.675689422875915, 4.682725956690111, 4.689668596886434, 4.696519949865763, 4.703282513186142, 4.709958681588707, 4.71655075261031, 4.723060931816518, 4.729491337685449, 4.735844006170164, 4.742120894964718, 4.748323887496754, 4.754454796667492, 4.760515368358074, 4.766507284719656, 4.7724321672630845, 4.77829157976269, 4.7840870309874814, 4.789819977271975, 4.795491824937832, 4.801103932576621, 4.806657613203201, 4.812154136288408, 4.817594729679155, 4.8229805814133195, 4.8283128414363246, 4.833592623225722, 4.838821005329675, 4.843999032824758, 4.8491277186981305, 4.854208045158743, 4.859240964881935, 4.864227402191435, 4.869168254182543, 4.874064391789955, 4.878916660803505], [0.0, 3.1367654698256238, 3.361901988759291, 3.5010166323817264, 3.6031973352001954, 3.6845041408815673, 3.752296718484916, 3.8105867456009697, 3.8618112841490584, 3.907565796079384, 3.9489537608019476, 3.9867712433743665, 4.021612046434148, 4.053931291616567, 4.084085750627656, 4.1123604564618, 4.138986851674164, 4.164155517890083, 4.188025323352388, 4.210730136534503, 4.23238384561042, 4.253084173431681, 4.272915619851468, 4.291951761069315, 4.310257067984395, 4.327888359765736, 4.344895977300115, 4.3613247390664425, 4.377214726245339, 4.392601932508422, 4.407518805619393, 4.421994701825441, 4.436056269411011, 4.449727774302094, 4.463031377948665, 4.475987375663024, 4.488614401999068, 4.5009296085101855, 4.5129488182395034, 4.5246866605144485, 4.536156688992553, 4.547371485402469, 4.558342751017181, 4.569081387565069, 4.579597569013619, 4.58990080543766, 4.6000000000000005, 4.609903499919615, 4.619619142175166, 4.629154294585181, 4.638515892816641, 4.647710473798277, 4.656744205950956, 4.665622916593308, 4.674352116834436, 4.6829370242261055, 4.691382583412819, 4.699693484989106, 4.707874182748164, 4.715928909484273, 4.723861691492525, 4.731676361893048, 4.7393765728925965, 4.7469658070839325, 4.75444738787247, 4.7618244891101, 4.769100144007668, 4.776277253390171, 4.7833585933521645, 4.790346822365089, 4.797244487883096, 4.804054032489355, 4.810777799620814, 4.817418038905728, 4.823976911145083, 4.830456492966122, 4.836858781173625, 4.843185696822274, 4.849439089031348, 4.855620738561128, 4.861732361168714, 4.867775610759428, 4.873752082348612, 4.8796633148474005, 4.885510793684896, 4.891295953278192, 4.8970201793607435, 4.902684811178762, 4.908291143564517, 4.913840428894795, 4.919333878942041, 4.924772666625239, 4.930157927666949, 4.9354907621625195, 4.940772236067022, 4.946003382605029, 4.951185203608018, 4.956318670783836, 4.961404726922312, 4.966444287040874, 4.971438239473717, 4.976387446907827], [0.0, 3.198070785741504, 3.4276073994703355, 3.56944091616691, 3.673618650745341, 3.756514526268356, 3.8256320500389283, 3.885061304349833, 3.9372869813472398, 3.9839357248787, 4.026132580886519, 4.064689172818101, 4.100210908660039, 4.133161804998762, 4.163905606328788, 4.192732916363107, 4.2198797009976, 4.2455402666074615, 4.269876586375281, 4.293025145115784, 4.315102056846927, 4.336206954327237, 4.356425988885037, 4.375834174701821, 4.394497242703651, 4.412473122540127, 4.429813138966279, 4.446562986398678, 4.462763529369289, 4.478451465014308, 4.493659875260377, 4.508418690096655, 4.522755078624816, 4.536693781026984, 4.5502573918791365, 4.563466603147561, 4.576340413582082, 4.588896309948083, 4.601150424536117, 4.61311767259092, 4.624811872664312, 4.636245852383742, 4.647431541713257, 4.6583800554459085, 4.669101766390411, 4.679606370487619, 4.689902944904813, 4.700000000000001, 4.7099055259186855, 4.719627034476913, 4.729171596893161, 4.738545877854669, 4.747756166338654, 4.75680840355355, 4.765708208318231, 4.774460900156911, 4.78307152035281, 4.791544851173993, 4.799885433459119, 4.808097582728702, 4.8161854039682215, 4.824152805212759, 4.8320035100482315, 4.8397410691316045, 4.847368870821324, 4.854890150999415, 4.862308002158158, 4.869625381816616, 4.876845120325664, 4.883969928114227, 4.891002402424197, 4.8979450335768835, 4.904800210809641, 4.911570227717726, 4.918257287333075, 4.924863506868779, 4.931390922155409, 4.937841491792966, 4.944217101040136, 4.95051956546059, 4.956750634344387, 4.96291199392097, 4.969005270378851, 4.975032032705826, 4.9809937953624, 4.9868920208000835, 4.99272812183527, 4.998503463888558, 5.004219367098574, 5.0098771083187, 5.015477923004411, 5.021023006998355, 5.026513518219789, 5.031950578264456, 5.037335273920578, 5.042668658606193, 5.047951753732691, 5.053185549999091, 5.058371008621219, 5.063509062499712, 5.068600617330475, 5.073646552660947], [0.0, 3.2592457931658836, 3.4931731489982463, 3.6377197596249564, 3.743890281140657, 3.828371848832582, 3.8988115025099317, 3.9593775625131635, 4.0126022499740985, 4.060143324358458, 4.103147352299767, 4.142441482564831, 4.178642703821397, 4.21222390870024, 4.243555799663241, 4.272934539301069, 4.300600607235659, 4.326752026674866, 4.351553869141281, 4.375145230229727, 4.397644445070945, 4.419153052270816, 4.439758851122484, 4.459538290732877, 4.4785583593766765, 4.496878094823653, 4.5145498036058145, 4.531620054215531, 4.548130492871041, 4.564118518677866, 4.5796178463776265, 4.594658978481931, 4.609269603802648, 4.623474935769972, 4.637298001165244, 4.650759887765628, 4.663879957742754, 4.676676032361479, 4.689164552502462, 4.701360718720011, 4.713278613897183, 4.724931311037548, 4.736330968310121, 4.747488913119742, 4.7584157166937, 4.769121260443808, 4.779614795171957, 4.78990499402843, 4.800000000000002, 4.809907468594159, 4.819634606292755, 4.82918820526998, 4.838574674803146, 4.8478000697484145, 4.856870116405484, 4.865790236054267, 4.8745655664112935, 4.883200981223301, 4.891701108189393, 4.900070345380474, 4.908312876305152, 4.916432683754223, 4.924433562541047, 4.932319131242119, 4.940092843030852, 4.94775799568756, 4.955317740859948, 4.962775092640639, 4.970132935521505, 4.977394031778511, 4.98456102833547, 4.9916364631503525, 4.998622771163572, 5.005522289843933, 5.012337264364556, 5.019069852438113, 5.025722128838012, 5.03229608962977, 5.038793656134662, 5.0452166786457715, 5.051566939914843, 5.057846158426732, 5.06405599147686, 5.0701980380657545, 5.076273841623612, 5.082284892576776, 5.088232630767009, 5.094118447733661, 5.099943688867923, 5.105709655447755, 5.111417606561311, 5.117068760926184, 5.122664298611144, 5.1282053626666295, 5.133693060669732, 5.13912846618903, 5.144512620174209, 5.1498465322750935, 5.1551311820943395, 5.160367520377783, 5.165556470146131, 5.170698927771446], [0.0, 3.3202934756623566, 3.5586024350473076, 3.705856492780334, 3.814015653600737, 3.9000796131245625, 3.9718386449297824, 4.033539144565917, 4.087760763227285, 4.136192311236139, 4.180001831125719, 4.220031964669034, 4.2569112571118515, 4.29112145865538, 4.32304021524709, 4.352969236785509, 4.3811535072241075, 4.407794758867471, 4.4330611551295505, 4.457094396951388, 4.480015035953658, 4.501926512622911, 4.522918270787167, 4.543068191492242, 4.562444517744494, 4.581107393127503, 4.599110103906866, 4.6165000908315115, 4.633319780179017, 4.649607271563198, 4.66539691122357, 4.680719773002579, 4.695604064340607, 4.710075470930936, 4.724157450860715, 4.73787148689417, 4.751237303868337, 4.764273056851353, 4.776995494671701, 4.789420102599441, 4.801561227298708, 4.813432186638489, 4.825045366517797, 4.836412306510745, 4.847543775850226, 4.858449841032985, 4.869139926134135, 4.879622866757409, 4.889906958412745, 4.9, 4.909909332982876, 4.919641876757171, 4.929204160649912, 4.938602352928449, 4.947842287149601, 4.956929486137197, 4.965869183840361, 4.974666345294115, 4.983325684877216, 4.991851683039148, 5.000248601648213, 5.008520498095336, 5.016671238273067, 5.02470450853607, 5.032623826737823, 5.040432552428101, 5.0481338962869104, 5.055730928862689, 5.063226588675617, 5.070623689740791, 5.07792492856054, 5.085132890630351, 5.09225005649857, 5.099278807416236, 5.106221430609944, 5.113080124207655, 5.1198570018445615, 5.1265540969737176, 5.133173366903931, 5.139716696585414, 5.14618590216195, 5.152582734306675, 5.158908881357175, 5.165165972264243, 5.171355579367476, 5.177479221009819, 5.18353836400216, 5.189534425948239, 5.1954687774392525, 5.2013427441268965, 5.2071576086828255, 5.212914612651962, 5.2186149582064925, 5.224259809806894, 5.2298502957758615, 5.235387509790572, 5.24087251229834, 5.246306331860357, 5.251689966427837, 5.257024384554673, 5.262310526550319, 5.267549305576438], [0.0, 3.3812166890312074, 3.623898318388478, 3.77385430305792, 3.883998048578669, 3.971641173621408, 4.044716893495877, 4.107549519774386, 4.162766037009366, 4.212086243070515, 4.256699612603923, 4.297464248800368, 4.335020229921115, 4.369858145678253, 4.402362571347881, 4.432840752826067, 4.461542169214011, 4.488672254350612, 4.514402257237172, 4.538876478848955, 4.562217682777405, 4.584531207512027, 4.6059081380627, 4.6264277844945765, 4.646159641987431, 4.665164957684037, 4.6834979955860065, 4.701207066920407, 4.718335376433698, 4.734921722819738, 4.751001082528382, 4.766605099568041, 4.781762498950186, 4.796499437668295, 4.810839804235944, 4.824805475599088, 4.838416538520741, 4.851691481191725, 4.864647359760484, 4.877299943632324, 4.8896638427146435, 4.901752619242589, 4.913578886380859, 4.925154395440252, 4.936490113255552, 4.947596291031073, 4.958482525761863, 4.969157815173884, 4.979630606989254, 4.989908843207848, 5.0, 5.009911123723727, 5.019648863511003, 5.029219500809133, 5.038628976213375, 5.047882913884435, 5.056986643807829, 5.065945222120729, 5.074763449704822, 5.08344588922021, 5.091996880735121, 5.100420556088509, 5.108720852107192, 5.1169015227858115, 5.124966150526038, 5.132918156521161, 5.1407608103631315, 5.1484972389410935, 5.156130434693381, 5.163663263268731, 5.171098470646902, 5.178438689763974, 5.185686446683241, 5.192844166348704, 5.199914177954692, 5.206898719962053, 5.213799944788531, 5.220619923198486, 5.227360648414884, 5.234024039974405, 5.24061194734479, 5.247126153321826, 5.253568377221974, 5.259940277885227, 5.266243456501636, 5.272479459273832, 5.278649779926841, 5.28475586207565, 5.29079910146008, 5.296780848055873, 5.302702408070094, 5.308565045828457, 5.3143699855614965, 5.320118413096076, 5.325811477458194, 5.33145029239263, 5.3370359378045755, 5.342569461128025, 5.348051878625345, 5.3534841766221755, 5.3588673126814665, 5.36420221672025], [0.0, 3.442018169224932, 3.689063731343038, 3.8417162441176997, 3.953840608858585, 4.043059744024748, 4.11744952103995, 4.181412011812085, 4.237621439672972, 4.287828528122257, 4.333244141094503, 4.374741812304155, 4.412973129983389, 4.448437505692583, 4.481526430190685, 4.512552674309607, 4.541770203316331, 4.569388145187888, 4.595580828347489, 4.620495148609386, 4.644256077115961, 4.666970846567199, 4.688732179875523, 4.709620813270038, 4.72970749160192, 4.749054563368065, 4.767717268352451, 4.785744786520938, 4.8031810995333855, 4.82006570376683, 4.836434204622217, 4.85231881513465, 4.86774877685251, 4.882750717127749, 4.8973489540403135, 4.911565757930258, 4.925421576763394, 4.938935231187607, 4.952124084057227, 4.96500418834507, 4.977590416675795, 4.989896575162436, 5.001935503781262, 5.01371916515668, 5.025258723330531, 5.036564613845622, 5.047646606271421, 5.058513860132171, 5.069174975058036, 5.07963803586297, 5.089910653154775, 5.100000000000001, 5.109912845096183, 5.1196555828444295, 5.129234260664559, 5.138654603851672, 5.147922038235776, 5.157041710874166, 5.16601850897861, 5.174857077255559, 5.183561833816916, 5.192136984800901, 5.200586537826867, 5.2089143143942795, 5.21712396132402, 5.225218961329725, 5.2332026427975755, 5.241078188844844, 5.2488486457202805, 5.256516930603093, 5.264085838851606, 5.271558050747702, 5.278936137778672, 5.286222568494178, 5.293419713972428, 5.300529852926563, 5.307555176479384, 5.314497792632007, 5.321359730449793, 5.328142943986784, 5.334849315968087, 5.34148066124796, 5.348038730059835, 5.354525211073181, 5.3609417342708605, 5.367289873659521, 5.3735711498245475, 5.379787032340199, 5.385938942044675, 5.392028253189154, 5.3980562954690905, 5.404024355945466, 5.40993368086309, 5.415785477372519, 5.421580915161687, 5.427321128002878, 5.433007215220279, 5.43864024308298, 5.444221246127911, 5.449751228416946, 5.4552311647320595, 5.460662001712172], [0.0, 3.502700539627843, 3.7541014855846755, 3.9094452439796976, 4.02354634791773, 4.11433840581149, 4.1900396657361645, 4.255129807603121, 4.312330200983042, 4.363422434422373, 4.409638719242634, 4.451867989453627, 4.490773320710461, 4.5268629291398454, 4.560535207436188, 4.592108440543916, 4.621841071107424, 4.64994591400507, 4.676600371049407, 4.7019539278104, 4.726133758656783, 4.749248986788274, 4.7713939698112, 4.7926508673247685, 4.813091671403458, 4.832779829740738, 4.851771555991398, 4.870116897158245, 4.887860610292557, 4.905042888087797, 4.921699963663889, 4.93786461796791, 4.953566608073254, 4.968833030768919, 4.983688632859702, 4.998156077309104, 5.0122561725781365, 5.026008071120465, 5.039429441895476, 5.052536620887983, 5.065344742925246, 5.077867857520427, 5.09011903101705, 5.102110436939165, 5.113853436149339, 5.125358648167758, 5.136636014800235, 5.147694857052336, 5.158543926164679, 5.169191449485525, 5.179645171796788, 5.189912392625324, 5.2, 5.209914501054455, 5.2196620498238, 5.229248472539403, 5.238679290688012, 5.247959742068928, 5.257094800054878, 5.266089191237937, 5.274947411620795, 5.283673741495386, 5.292272259134918, 5.300746853411432, 5.309101235438833, 5.31733894933058, 5.3254633821519075, 5.333477773138066, 5.341385222242808, 5.349188698074865, 5.356891045274395, 5.36449499137633, 5.372003153202978, 5.379418042824235, 5.386742073120136, 5.393977562977264, 5.401126742147654, 5.4081917557962305, 5.415174668760535, 5.422077469544349, 5.428902074065, 5.43565032917241, 5.442324015956417, 5.448924852857534, 5.455454498595024, 5.461914554925088, 5.468306569240848, 5.474632037024982, 5.480892404164897, 5.487089069139659, 5.493223385087092, 5.499296661758912, 5.505310167371074, 5.511265130356056, 5.517162741023251, 5.523004153133211, 5.528790485391082, 5.534522822864147, 5.540202218328102, 5.5458296935463105, 5.551406240486037, 5.556932822475334], [0.0, 3.56326631776208, 3.8190142793268116, 3.9770441125087155, 4.093118157629643, 4.185480116110831, 4.262490339123045, 4.328705965468747, 4.386895420372896, 4.43887109812608, 4.485886516420912, 4.528845979973138, 4.568424029789405, 4.605137669646071, 4.639392180911947, 4.671511352049416, 4.701758094477666, 4.7303489028925405, 4.7574642465908665, 4.783256195922484, 4.807854124249311, 4.8313690416384745, 4.853896937249383, 4.875521391316549, 4.8963156407413955, 4.916344230302023, 4.935664345652886, 4.954326899167844, 4.972377421799802, 4.989856801220778, 5.006801897063602, 5.0232460570961655, 5.039219552926372, 5.054749949878308, 5.069862422657893, 5.084580026097702, 5.098923928461311, 5.112913613370648, 5.12656705530202, 5.139900872708471, 5.152930462116082, 5.165670115970483, 5.178133126547521, 5.190331877865675, 5.202277927230079, 5.213982077784811, 5.2254544432411025, 5.236704505775578, 5.247741167948015, 5.258572799367122, 5.269207278731127, 5.27965203178422, 5.289914065657321, 5.300000000000002, 5.309916095257816, 5.319668278404471, 5.32926216639966, 5.338703087610344, 5.347996101404665, 5.35714601610299, 5.3661574054491386, 5.375034623746286, 5.38378181978574, 5.392402949682677, 5.400901788720489, 5.409281942294491, 5.417546856036227, 5.425699825191104, 5.43374400331469, 5.441682410346424, 5.44951794011361, 5.4572533673134425, 5.464891354016137, 5.472434455728211, 5.479885127051209, 5.487245726967967, 5.494518523785534, 5.501705699761239, 5.508809355436073, 5.515831513697367, 5.522774123590894, 5.529639063900765, 5.53642814651394, 5.543143119584772, 5.549785670513717, 5.5563574287532065, 5.562859968452595, 5.569294810953201, 5.575663427143512, 5.581967239683927, 5.588207625109603, 5.594385915819388, 5.600503401958174, 5.606561333199467, 5.612560920434499, 5.618503337373688, 5.624389722065895, 5.630221178340484, 5.6359987771768685, 5.6417235580058955, 5.647396529947099, 5.653018672985597], [0.0, 3.623717921475175, 3.883804703954268, 4.044515548320415, 4.162558815371808, 4.256487714972283, 4.334804433505246, 4.4021434226441, 4.461320074562014, 4.514177531220859, 4.5619905765190385, 4.605678856902451, 4.645928357115593, 4.683264852018602, 4.718100498668635, 4.750764578671186, 4.781524463796003, 4.810600321619483, 4.838175683140116, 4.864405198614969, 4.88942043625375, 4.913334289434008, 4.936244375792538, 4.958235693521076, 4.97938272200133, 4.99975110102788, 5.019398986422497, 5.03837815429876, 5.056734908052295, 5.074510829023545, 5.09174340217719, 5.108466541033404, 5.124711030764636, 5.140504904346809, 5.155873763580319, 5.170841054428086, 5.185428304277978, 5.199655327295891, 5.2135404028991115, 5.227100431476425, 5.240351070759395, 5.253306855668163, 5.265981303984985, 5.278387009825961, 5.290535726568471, 5.3024384406343295, 5.3141054373161225, 5.3255463596577055, 5.3367702612527586, 5.347785653702258, 5.358600549368295, 5.369222499974459, 5.3796586315292, 5.389915675985913, 5.4, 5.409917631097593, 5.419674281531352, 5.429275370065166, 5.43872604190048, 5.448031186931883, 5.457195456497773, 5.466223278773046, 5.475118872934172, 5.483886262212703, 5.492529285940549, 5.501051610679357, 5.509456740516576, 5.517748026602179, 5.525928675992508, 5.534001759860941, 5.5419702211292075, 5.549836881567853, 5.557604448409707, 5.565275520516021, 5.5728525941311995, 5.5803380682587465, 5.587734249688041, 5.595043357698894, 5.60226752846844, 5.609408819202742, 5.616469212013568, 5.623450617559017, 5.630354878465115, 5.63718377254404, 5.643939015823371, 5.650622265399561, 5.65723512212776, 5.663779133159179, 5.670255794336254, 5.676666552455132, 5.6830128074041975, 5.689295914186739, 5.695517184835243, 5.701677890224204, 5.70777926178789, 5.713822493148981, 5.719808741663586, 5.725739129887781, 5.731614746970383, 5.737436649976413, 5.743205865145341, 5.748923389087952], [0.0, 3.6840576746581384, 3.9484752501517573, 4.111862145163406, 4.231870990594005, 4.327363932082247, 4.406984728793694, 4.475445002224614, 4.53560702459583, 4.58934462864964, 4.637953825142459, 4.682369573864316, 4.723289282123785, 4.761247479636099, 4.796663186425023, 4.829871167075475, 4.861143245455007, 4.890703255224822, 4.9187377834201635, 4.945404055431855, 4.970835830256378, 4.995147881097111, 5.018439451055145, 5.040796953655868, 5.062296108462371, 5.083003648259663, 5.10297869724178, 5.122273893663888, 5.140936311935117, 5.15900822578088, 5.176527744340689, 5.193529345840214, 5.210044328066227, 5.226101190781221, 5.241725962089827, 5.2569424783616325, 5.27177262544432, 5.286236547436169, 5.300352828131226, 5.31413864933237, 5.327609929493349, 5.340781445560179, 5.3536669404042785, 5.366279217850641, 5.3786302269861075, 5.390731137171118, 5.4025924049621485, 5.414223833972638, 5.425634628550718, 5.436833442026915, 5.44782842017987, 5.458627240479477, 5.469237147591765, 5.479664985566162, 5.4899172270714045, 5.5, 5.509919111721261, 5.519680071228746, 5.529288109398393, 5.538748197548077, 5.548065064467208, 5.5572432120657185, 5.566286929775016, 5.5752003078188395, 5.583987249459114, 5.592651482310648, 5.601196568808633, 5.609625915904176, 5.617942784055397, 5.626150295574824, 5.63425144238777, 5.642249093251037, 5.650146000476504, 5.657944806199941, 5.665648048231562, 5.673258165521491, 5.680777503270238, 5.688208317711591, 5.6955527805928945, 5.702812983375444, 5.709990941175823, 5.717088596467144, 5.724107822557622, 5.731050426862388, 5.737918153983176, 5.744712688609314, 5.751435658252332, 5.758088635825578, 5.7646731420792685, 5.771190647900643, 5.777642576488098, 5.784030305407543, 5.790355168538561, 5.796618457917407, 5.802821425483378, 5.808965284734569, 5.815051212298617, 5.82108034942366, 5.827053803394299, 5.832972648877103, 5.838837929199803, 5.844650657568087], [0.0, 3.744287812537539, 4.013028313575801, 4.179086397825863, 4.301057250897317, 4.398111392980194, 4.47903389883615, 4.548613419594919, 4.6097590223610485, 4.664375174903318, 4.713779076274703, 4.758920971790605, 4.800509670573054, 4.839088441287993, 4.875083154458295, 4.908834047687732, 4.940617388853818, 4.970660671042629, 4.999153531774457, 5.026255766895804, 5.052103322210067, 5.076812847331493, 5.100485207872598, 5.123208230121275, 5.1450588715690415, 5.16610495600577, 5.186406574238585, 5.20601722509804, 5.224984752606122, 5.243352121615405, 5.261158064306327, 5.278437622584197, 5.295222605918877, 5.311541980011444, 5.327422198496333, 5.342887487440564, 5.357960090500449, 5.372660481107282, 5.3870075468789285, 5.401018750521134, 5.414710270736195, 5.428097126056327, 5.441193284033212, 5.454011757819766, 5.46656469185676, 5.47886343811093, 5.490918624091513, 5.502740213689839, 5.514337561734625, 5.525719463028473, 5.5368941965242096, 5.547869565209597, 5.558652932192683, 5.569251253415294, 5.579671107366911, 5.589918722124089, 5.6000000000000005, 5.609920540053962, 5.61968565868076, 5.629300408473645, 5.638769595532334, 5.648097795367849, 5.657289367538905, 5.66634846913973, 5.6752790672461275, 5.684084950415151, 5.692769739323743, 5.701336896622771, 5.709789736075126, 5.71813143103958, 5.726365022356009, 5.734493425682116, 5.742519438326937, 5.750445745622146, 5.758274926868257, 5.766009460889445, 5.773651731227572, 5.781204031003272, 5.788668567469479, 5.796047466280496, 5.80334277549776, 5.810556469351604, 5.817690451776691, 5.82474655973733, 5.831726566357499, 5.838632183869277, 5.845465066392145, 5.852226812554791, 5.858918967969964, 5.865543027572229, 5.872100437827651, 5.878592598823771, 5.885020866247579, 5.89138655325865, 5.89769093226406, 5.90393523660121, 5.9101206621342595, 5.9162483687694465, 5.922319481894213, 5.9283350937447015, 5.93429626470586, 5.94020402454813], [0.0, 3.8044104865803825, 4.07746620011164, 4.246190707609967, 4.3701200676683545, 4.468732624820025, 4.550954517284568, 4.621651288387349, 4.683778716624253, 4.7392718501309075, 4.789469038452256, 4.835335785156332, 4.877592280835265, 4.916790517513506, 4.953363203990229, 4.987656041122987, 5.01994973287017, 5.050475425213501, 5.079425800715587, 5.106963221092345, 5.133225815052345, 5.1583321052727715, 5.182384576982647, 5.20547246671169, 5.227673967671108, 5.249057992709046, 5.269685597521062, 5.2896111399776435, 5.3088832323404755, 5.327545529356166, 5.345637385134444, 5.363194404254525, 5.380248906956403, 5.396830324048406, 5.412965533935532, 5.428679151686929, 5.443993778129127, 5.4589302154388335, 5.473507654515644, 5.487743838466978, 5.501655205779338, 5.515257016140099, 5.528563461380325, 5.541587763607367, 5.554342262267375, 5.566838491607567, 5.579087249784926, 5.591098660682702, 5.602882229341706, 5.614446891784199, 5.62580105989958, 5.636952661969527, 5.647909179332784, 5.65867767962393, 5.669264846964387, 5.6796770094360065, 5.689920164126419, 5.700000000000001, 5.709921918817806, 5.719691054303443, 5.729312289728999, 5.738790274075267, 5.748129436903144, 5.757334002058038, 5.766408000315771, 5.775355281066908, 5.784179523126225, 5.792884244744973, 5.8014728128957, 5.809948451892349, 5.818314251402087, 5.82657317389983, 5.834728061611492, 5.8427816429875765, 5.85073653874487, 5.858595267510456, 5.866360251099136, 5.874033819452579, 5.88161821526596, 5.889115598325577, 5.896528049578943, 5.903857574956946, 5.9111061089660595, 5.918275518067039, 5.925367603855225, 5.932384106056297, 5.939326705350221, 5.946197026035141, 5.952996638541972, 5.959727061809704, 5.9663897655305576, 5.972986172273518, 5.979517659494076, 5.985985561437435, 5.99239117094193, 5.9987357411488755, 6.005020487124625, 6.011246587400232, 6.017415185433681, 6.023527390999332, 6.029584281508921, 6.035586903268091], [0.0, 3.8644277690463977, 4.14179113075226, 4.313177387412826, 4.439061821308459, 4.539230061717271, 4.622749063040687, 4.6945611260121245, 4.757668658636431, 4.814037235810467, 4.865026320495551, 4.911616647765511, 4.9545397697315225, 4.99435638648499, 5.031506033114293, 5.0663398641539965, 5.099143011867168, 5.130150268727868, 5.159557357003229, 5.187529199780768, 5.214206104847719, 5.239708464660833, 5.264140381226543, 5.2875924988443215, 5.310144244278922, 5.331865617527704, 5.352818637483266, 5.373058519550182, 5.392634642883156, 5.411591350913484, 5.429968618589982, 5.447802612179434, 5.465126161796619, 5.481969162541808, 5.498358916845962, 5.514320428098461, 5.529876653669956, 5.545048723906291, 5.559856132457161, 5.574316902340128, 5.588447731370518, 5.602264119968131, 5.615780483850265, 5.629010253712422, 5.641965963664294, 5.654659329914059, 5.667101320967309, 5.679302220418754, 5.691271683257988, 5.703018786479384, 5.714552074675878, 5.725879601203436, 5.737008965424243, 5.747947346469843, 5.758701533908427, 5.769277955651843, 5.7796827033960465, 5.789921555852873, 5.800000000000001, 5.809923250549182, 5.819696267809597, 5.829323774103017, 5.838810268869814, 5.848160042589564, 5.857377189626444, 5.866465620097896, 5.875429070854616, 5.884271115650772, 5.892995174575299, 5.901604522807988, 5.910102298757702, 5.91849151163451, 5.926775048502459, 5.934955680855302, 5.943036070753499, 5.951018776557265, 5.958906258287255, 5.966700882641626, 5.974404927695663, 5.982020587307831, 5.989549975254072, 5.99699512911026, 6.004358013901084, 6.011640525532047, 6.0188444940199375, 6.025971686535846, 6.03302381027366, 6.040002515155982, 6.046909396388394, 6.0537459968722285, 6.060513809485147, 6.067214279238171, 6.073848805317133, 6.080418743015905, 6.086925405568265, 6.0933700658847245, 6.099753958200171, 6.106078279637828, 6.112344191694539, 6.118552821652147, 6.124705263919324, 6.13080258130793], [0.0, 3.92434165721872, 4.206005246132722, 4.38004866644843, 4.5078848060934815, 4.609606049718538, 4.694419925316907, 4.767345358796847, 4.831431307341558, 4.888673820019393, 4.940453436835082, 4.987766098128288, 5.031354697956269, 5.071788629475631, 5.109514242304023, 5.144888135257743, 5.1781998612757105, 5.209687853042355, 5.239550867292712, 5.267956384073313, 5.295046886496065, 5.32094463357614, 5.345755341312093, 5.369571059347924, 5.392472445876836, 5.414530586172527, 5.435808460665298, 5.4563621408164975, 5.476241771352688, 5.495492383203433, 5.514154571087083, 5.532265061990352, 5.549857195024422, 5.566961328781649, 5.5836051889884715, 5.599814166685524, 5.615611575173347, 5.631018872401571, 5.646055854248426, 5.660740823159408, 5.6750907358319065, 5.689121333003429, 5.702847253891807, 5.716282137421353, 5.729438712029945, 5.742328875573247, 5.754963766611995, 5.767353828177218, 5.77950886494897, 5.791438094650874, 5.803150194350795, 5.81465334226351, 5.8259552555713245, 5.837063224710665, 5.847984144514838, 5.858724542553703, 5.869290604968554, 5.879688200064077, 5.889922899887768, 5.9, 5.909924537614331, 5.919701308267164, 5.929334881157961, 5.938829613285672, 5.948189662493284, 5.957418999520499, 5.966521419153951, 5.975500550555107, 5.984359866837788, 5.993102693959998, 6.001732218988332, 6.010251497787496, 6.018663462182426, 6.026970926635973, 6.035176594481044, 6.043283063742538, 6.051292832581145, 6.059208304388184, 6.0670317925581045, 6.07476552496284, 6.082411648150202, 6.089972231286538, 6.097449269862177, 6.104844689176645, 6.112160347619213, 6.119398039759102, 6.126559499258446, 6.133646401620161, 6.140660366781814, 6.1476029615658, 6.1544757019952785, 6.1612800554846485, 6.168017442912645, 6.174689240585547, 6.181296782097442, 6.187841360093978, 6.194324227945559, 6.200746601335543, 6.207109659768561, 6.213414548003775, 6.219662377417515, 6.225854227299416], [0.0, 3.9841540773407558, 4.270110610749592, 4.446806694641686, 4.576591234696056, 4.67986285142582, 4.765969408345689, 4.840006326769061, 4.905069034223441, 4.963184002338695, 5.015752812467621, 5.063786584464621, 5.108039535124708, 5.149089735947425, 5.187390339538841, 5.223303379776745, 5.257122822789208, 5.289090735306096, 5.31940890339128, 5.34824735971993, 5.375750759044573, 5.402043223777663, 5.427232081176477, 5.4514107838495, 5.474661219332885, 5.49705555633868, 5.518657735206459, 5.539524682004561, 5.559707305734863, 5.579251323660867, 5.598197949220844, 5.616584469171822, 5.634444730759363, 5.6518095552829575, 5.668707091047644, 5.685163116088799, 5.701201299034058, 5.716843424882023, 5.732109591227618, 5.747018379471039, 5.761587004753308, 5.775831447722646, 5.789766570718906, 5.803406220542559, 5.8167633196305655, 5.829849947178441, 5.8426774115140665, 5.855256314834776, 5.8675966112575715, 5.879707658996993, 5.891598267371475, 5.903276739243158, 5.914750909414924, 5.926028179439585, 5.937115549237286, 5.948019645867123, 5.958746749755779, 5.969302818649058, 5.979693509520204, 5.989924198641287, 6.0, 6.009925782223383, 6.019706184151851, 6.029345629191071, 6.038848338555334, 6.048218343503931, 6.0574594966613216, 6.066575482502435, 6.075569827076171, 6.084445907032759, 6.093206958014115, 6.101856082460569, 6.110396256882145, 6.118830338638019, 6.127161072263646, 6.135391095381437, 6.14352294422752, 6.15155905882424, 6.159501787825392, 6.167353393058771, 6.175116053788564, 6.182791870718085, 6.190382869751712, 6.197891005533208, 6.205318164776282, 6.2126661694018805, 6.21993677949556, 6.227131696097229, 6.234252563834554, 6.241300973410479, 6.248278463954464, 6.2551865252463426, 6.262026599821017, 6.268800084961585, 6.275508334587963, 6.282152661047514, 6.288734336813747, 6.295254596098725, 6.30171463638437, 6.308115619877563, 6.314458674893553, 6.320744897171851], [0.0, 4.043866888284192, 4.334109216892214, 4.513453546722361, 4.64518324239903, 4.750002650305015, 4.837399735767338, 4.912546288112198, 4.978584127821574, 5.0375700984223455, 5.0909267875739745, 5.139680469366248, 5.18459666447551, 5.22626210829168, 5.265136745079824, 5.301588034727891, 5.335914349203559, 5.3683613832301385, 5.399133947155412, 5.428404622032146, 5.456320230636926, 5.483006755676262, 5.508573132982825, 5.533114215793148, 5.556713118939033, 5.579443092766565, 5.601369035926001, 5.622548727669437, 5.643033840001272, 5.662870775375958, 5.682101364921293, 5.700763454232398, 5.718891397842991, 5.736516478989125, 5.753667267850689, 5.77036992881332, 5.78664848524, 5.8025250486336475, 5.818020017803413, 5.833152252639635, 5.847939226296565, 5.862397158933598, 5.876541135641034, 5.890385210749313, 5.903942500371398, 5.917225264740663, 5.930244981669408, 5.943012412256204, 5.955537659806133, 5.967830222790686, 5.979899042558626, 5.991752546411864, 6.003398686577988, 6.01484497554114, 6.026098518133302, 6.037166040737116, 6.048053917907638, 6.058768196682838, 6.069314618820274, 6.079698641169302, 6.089925454363891, 6.100000000000001, 6.109926986443016, 6.11971090339473, 6.129356035335204, 6.138866473942534, 6.148246129582679, 6.1574987419519145, 6.166627889946067, 6.1756370008231665, 6.184529358719556, 6.193308112573626, 6.20197628350607, 6.2105367717009505, 6.218992362827656, 6.227345734040163, 6.23559945958663, 6.243756016059422, 6.251817787312959, 6.2597870690743544, 6.26766607326968, 6.275456932086702, 6.283161701793191, 6.290782366328283, 6.298320840682951, 6.305778974084322, 6.313158552997363, 6.320461303956452, 6.327688896238234, 6.334842944386435, 6.3419250105983345, 6.348936606981955, 6.355879197692298, 6.362754200954348, 6.369562990979999, 6.376306899785519, 6.382987218915711, 6.389605201080485, 6.396162061709112, 6.402658980427139, 6.409097102460523, 6.415477539971255], [0.0, 4.103481884970612, 4.398002988309908, 4.5799912260440285, 4.713662891025875, 4.820027554705012, 4.9087130547230515, 4.984967423322202, 5.051978797943636, 5.1118343442596945, 5.165977621826533, 5.215450034145501, 5.261028387257629, 5.303308066251083, 5.34275579592466, 5.379744453288238, 5.41457680893199, 5.447502179629734, 5.4787283950591545, 5.508430580476169, 5.5367577231300285, 5.563837662973991, 5.589780941781152, 5.614683811121754, 5.6386306111128395, 5.66169567196273, 5.683944849062576, 5.7054367734506535, 5.7262238788840225, 5.746353251885688, 5.765867340261151, 5.784804547528207, 5.803199734677753, 5.821084646125712, 5.838488273235765, 5.855437166110931, 5.871955702268458, 5.888066319180743, 5.903789716377749, 5.919145031783767, 5.934149996143634, 5.948821068735582, 5.963173557035471, 5.977221722563764, 5.990978874792168, 6.00445745469536, 6.017669109292433, 6.030624758322898, 6.043334654035543, 6.055808434929052, 6.06805517416624, 6.080083423284952, 6.091901251745125, 6.1035162827805225, 6.114935725963103, 6.126166406836361, 6.137214793929532, 6.148087023426486, 6.158788921730212, 6.169326026135359, 6.1797036037966215, 6.1899266691593455, 6.200000000000001, 6.209928152207912, 6.219715473425272, 6.229366115650013, 6.238884046895007, 6.248273061987421, 6.257536792583439, 6.26667871646599, 6.275702166186412, 6.2846103371049855, 6.293406294879996, 6.302092982450245, 6.310673226551671, 6.3191497438050614, 6.327525146408339, 6.3358019474639855, 6.343982565969385, 6.352069331495435, 6.360064488576593, 6.3679702008335015, 6.375788554847587, 6.383521563805372, 6.391171170928771, 6.398739252706359, 6.406227621939311, 6.4136380306147025, 6.420972172617787, 6.4282316862940165, 6.435418156870703, 6.442533118747482, 6.4495780576640405, 6.456554412752946, 6.463463578484828, 6.470306906512643, 6.477085707421245, 6.48380125238809, 6.490454774760401, 6.497047471553857, 6.503580504877421, 6.510055003288666], [0.0, 4.163000801566975, 4.461793783636801, 4.64642166815062, 4.782032172611323, 4.889939601611176, 4.97991143967745, 5.057271839089455, 5.12525517959959, 5.18597890015618, 5.240907498412152, 5.291097482896705, 5.337336926827198, 5.380229851049526, 5.420249749968192, 5.457774908984352, 5.493112490221523, 5.526515426666454, 5.558194562460546, 5.588327562962438, 5.617065576405615, 5.644538296996803, 5.670857869861266, 5.696121942649292, 5.7204160787884035, 5.743815686608769, 5.766387576700475, 5.788191230515173, 5.809279842334886, 5.829701181648677, 5.849498311945861, 5.86871019376772, 5.887372193746082, 5.905516516733472, 5.923172574598546, 5.940367302540056, 5.957125431658736, 5.9734697248711, 5.989421181943258, 6.0049992183853576, 6.020221822117666, 6.035105691151869, 6.0496663549909755, 6.063918282011544, 6.0778749747323975, 6.09154905457822, 6.104952337502188, 6.11809590162908, 6.130990147911332, 6.14364485464915, 6.156069226606956, 6.168271939358301, 6.180261179406533, 6.19204468055654, 6.203629756951454, 6.215023333135804, 6.226231971461552, 6.2372618971147915, 6.248119021007521, 6.258808960750033, 6.269337059894418, 6.279708405618001, 6.28992784499647, 6.300000000000002, 6.309929281331131, 6.319719901210404, 6.329375885204702, 6.338901083183229, 6.348299179477493, 6.357573702313897, 6.3667280325807365, 6.375765411985369, 6.384688950651894, 6.393501634204941, 6.402206330380816, 6.410805795203509, 6.419302678759544, 6.4276995306026725, 6.435998804816609, 6.44420286476149, 6.452313987527602, 6.460334368117805, 6.468266123378328, 6.476111295695937, 6.483871856477993, 6.491549709430584, 6.499146693648641, 6.506664586530924, 6.514105106531626, 6.52146991575957, 6.528760622434981, 6.5359787832131815, 6.543125905383756, 6.550203448953157, 6.557212828618103, 6.564155415636585, 6.571032539602828, 6.577845490132067, 6.584595518460601, 6.59128383896621, 6.597911630613658, 6.60448003832967], [0.0, 4.222425314473262, 4.525483399593905, 4.712746744111004, 4.850293012833275, 4.95974076015468, 5.050996895992493, 5.129461571928193, 5.198415336679909, 5.260005854455123, 5.315718527793368, 5.366624946293412, 5.413524432477944, 5.457029629253301, 5.497620789892336, 5.5356815996091715, 5.571523605095194, 5.605403349814372, 5.6375346875905405, 5.668097819856173, 5.697246052401424, 5.725110930745435, 5.75180620082254, 5.777430904148732, 5.802071825521707, 5.8258054496834575, 5.848699540907955, 5.8708144297113725, 5.8922040696944205, 5.912916912228955, 5.932996635511567, 5.952482756223518, 5.971411145835569, 5.989814468906536, 6.007722557143087, 6.025162730228902, 6.042160072287373, 6.058737671162944, 6.074916826381666, 6.090717230599256, 6.106157128503503, 6.121253456460891, 6.136021965649415, 6.150477330973636, 6.164633247693295, 6.178502517396869, 6.192097124703673, 6.205428305872531, 6.218506610323671, 6.231341955937077, 6.243943678870045, 6.256320578535098, 6.268480958293347, 6.28043266234543, 6.29218310923979, 6.303739322364965, 6.315107957746827, 6.326295329432527, 6.337307432709033, 6.348149965374889, 6.3588283472584095, 6.369347738153538, 6.379713054325259, 6.389928983719796, 6.400000000000001, 6.409930375513517, 6.419724193289945, 6.429385358153224, 6.438917607026639, 6.448324518500052, 6.457609521722056, 6.466775904673569, 6.475826821873977, 6.484765301566036, 6.493594252421385, 6.502316469804718, 6.510934641631067, 6.519451353847641, 6.5278690955688266, 6.536190263890409, 6.544417168406868, 6.552552035453503, 6.560597012093342, 6.568554169867082, 6.576425508322825, 6.584212958340999, 6.591918385268592, 6.599543591875734, 6.607090321146597, 6.614560258915677, 6.621955036359647, 6.629276232354213, 6.6365253757046805, 6.643703947258277, 6.650813381905726, 6.657855070478964, 6.664830361551429, 6.671740563146894, 6.678586944362359, 6.685370736910168, 6.69209313658415, 6.698755304654218], [0.0, 4.281757045118832, 4.589073573986178, 4.7789682636400626, 4.918447274224968, 5.029432934897161, 5.121971363272567, 5.201538591573574, 5.271461265398287, 5.333917227021244, 5.390412751228802, 5.442034485142532, 5.489592983026377, 5.5337094963851, 5.574871026806963, 5.613466650888076, 5.649812293041871, 5.68416810157232, 5.716750935286542, 5.74774352773115, 5.777301338884279, 5.805557762686942, 5.8326281433831255, 5.858612914178223, 5.883600079333118, 5.907667198320977, 5.930882987610625, 5.953308625457073, 5.974998823594159, 5.996002714211876, 6.016364589254322, 6.036124520674409, 6.055318883993601, 6.073980802759248, 6.092140527860513, 6.109825762865694, 6.127061944369649, 6.143872484637424, 6.160278982486985, 6.176301407286896, 6.1919582600915675, 6.207266715250125, 6.2222427452694395, 6.23690123125961, 6.251256060920364, 6.265320215722671, 6.279105848688636, 6.292624353964231, 6.305886429205666, 6.318902131654766, 6.3316809286565565, 6.344231743269171, 6.356562995529035, 6.368682639860166, 6.380598199053306, 6.392316795186672, 6.40384517781379, 6.4151897497041235, 6.426356590387875, 6.437351477726633, 6.448179907705848, 6.458847112622696, 6.469358077823435, 6.479717557127323, 6.489930087059224, 6.5, 6.509931436352252, 6.5197283558088515, 6.5293945478027435, 6.53893364120862, 6.548349113360014, 6.557644298439159, 6.566822395291411, 6.575886474711107, 6.58483948624131, 6.593684264525993, 6.6024235352496286, 6.611059920696061, 6.619595944955657, 6.628034038807176, 6.63637654429854, 6.644625719048569, 6.65278374028991, 6.660852708671671, 6.668834651838758, 6.67673152780351, 6.684545228123982, 6.692277580902065, 6.699930353613606, 6.707505255781734, 6.715003941503722, 6.722428011840971, 6.729779017080909, 6.737058458879002, 6.744267792288449, 6.7514084276845665, 6.758481732590377, 6.765489033409449, 6.772431617071593, 6.779310732596654, 6.78612759258125, 6.792883374612965], [0.0, 4.340997562582496, 4.652565988510651, 4.845087978023018, 4.986496759184652, 5.099017968908318, 5.192836718498698, 5.273504804164575, 5.344394897517339, 5.4077149725045635, 5.464992144071645, 5.517328093714384, 5.565544590170951, 5.61027148031017, 5.652002503661242, 5.691132119913865, 5.727980624473455, 5.76281176494212, 5.795845400490571, 5.827266792886838, 5.857233552985307, 5.885880920307208, 5.913325834949032, 5.939670119666067, 5.965002996307655, 5.989403097425906, 6.012940090220646, 6.035675999382462, 6.057666293612809, 6.078960784873167, 6.0996043779115965, 6.119637699099025, 6.139097627232715, 6.1580177441429305, 6.176428719256903, 6.194358639437382, 6.211833293208828, 6.228876416758143, 6.245509907735088, 6.261754011795678, 6.277627485966819, 6.2931477422144155, 6.308330974033961, 6.323192268424081, 6.337745705228641, 6.352004445524567, 6.365980810477859, 6.3796863518789095, 6.393131915392019, 6.406327697406614, 6.419283296253762, 6.432007758447127, 6.444509620519073, 6.45679694694755, 6.468877364605342, 6.480758094108625, 6.492445978394793, 6.50394750881923, 6.515268849025856, 6.526415856816228, 6.537394104215845, 6.548208895913658, 6.558865286230996, 6.56936809475888, 6.579721920787548, 6.589931156638787, 6.6000000000000005, 6.609932465348635, 6.619732394546574, 6.629403466676031, 6.638949207181406, 6.648372996375219, 6.65767807736065, 6.666867563418204, 6.675944444899533, 6.684911595667501, 6.69377177911796, 6.702527653815527, 6.7111817787727786, 6.719736618399666, 6.728194547147662, 6.736557853871011, 6.7448287459256, 6.7530093530242015, 6.761101730865325, 6.769107864551516, 6.777029671811594, 6.784869006040273, 6.7926276591674215, 6.80030736436838, 6.807909798625791, 6.81543658515264, 6.822889295685452, 6.830269452655942, 6.8375785312487904, 6.844817961352649, 6.851989129410988, 6.859093380178918, 6.866132018391646, 6.87310631034991, 6.880017485427285, 6.886866737503941], [0.0, 4.4001483860499135, 4.715962271390198, 4.911107582858191, 5.054443212798394, 5.168497646652402, 5.263594778968169, 5.345362055229269, 5.417218103374001, 5.481400983401661, 5.5394586188633275, 5.592507702866012, 5.64138120164267, 5.68671754441224, 5.72901719844319, 5.7686799983684445, 5.806030603967443, 5.841336356690856, 5.87482011153024, 5.906669654647151, 5.937044744515661, 5.966082463442887, 5.993901344961597, 6.020604599273111, 6.046282663971717, 6.071015243063758, 6.094872953040593, 6.117918663746827, 6.140208599705431, 6.161793251620158, 6.182718136115205, 6.203024433140086, 6.222749524005874, 6.241927448131873, 6.260589292849694, 6.278763527736205, 6.296476292712617, 6.313751647397257, 6.330611787819229, 6.347077235503681, 6.363167003062452, 6.378898739718466, 6.39428885962124, 6.4093526553462015, 6.424104398590436, 6.438557429764887, 6.4527242379248735, 6.4666165322665226, 6.480245306238131, 6.493620895166046, 6.506753028169059, 6.519650875029442, 6.532323088599119, 6.544777843243342, 6.557022869759348, 6.569065487152081, 6.580912631601414, 6.592570882914526, 6.604046488721702, 6.61534538664343, 6.62647322463013, 6.637435379652924, 6.648236974903777, 6.65888289564589, 6.669377803839844, 6.679726151657601, 6.689932193984626, 6.699999999999999, 6.70993346391516, 6.719736314943828, 6.729412126568423, 6.73896432516191, 6.748396198018284, 6.757710900839891, 6.766911464725182, 6.7760008026965375, 6.784981715804088, 6.793856898838293, 6.802628945681064, 6.811300354322622, 6.819873531568931, 6.828350797462371, 6.836734389436458, 6.8450264662236195, 6.853229111533501, 6.861344337517834, 6.869374088036582, 6.877320241738984, 6.8851846149719025, 6.892968964527085, 6.900674990237889, 6.908304337435346, 6.915858599272605, 6.923339318926172, 6.930747991681726, 6.938086066911712, 6.945354949951403, 6.952556003879661, 6.959690551210137, 6.966759875498296, 6.973765222869264, 6.980707803471133], [0.0, 4.459210987120711, 4.779263999846246, 4.9770287206320285, 5.122288325490265, 5.237873696698212, 5.334247305054366, 5.417112132487551, 5.489932694719933, 5.554977092929723, 5.613814028238016, 5.667575182973486, 5.717104704163009, 5.763049590575221, 5.805917027183544, 5.8461122155475085, 5.883964173311185, 5.919743830413644, 5.95367703319908, 5.985954088457483, 6.016736899079474, 6.046164387409578, 6.074356678040259, 6.101418366549514, 6.127441104463317, 6.152505665644187, 6.176683614459171, 6.200038664646353, 6.22262779542293, 6.244502175222592, 6.265707931633073, 6.286286797356819, 6.306276655469227, 6.3257120022961555, 6.344624342450291, 6.363042527651811, 6.380993048694583, 6.398500288145956, 6.415586739969357, 6.432273201147609, 6.448578939496288, 6.464521841141467, 6.480118540557589, 6.495384535590269, 6.510334289503665, 6.524981321775266, 6.539338289099306, 6.553417057842877, 6.567228769017858, 6.580783896680295, 6.594092300541632, 6.607163273468901, 6.620005584460092, 6.632627517603867, 6.645036907466917, 6.657241171296203, 6.669247338375015, 6.681062076830393, 6.692691718153731, 6.704142279665398, 6.715419485127494, 6.7265287836855014, 6.737475367299304, 6.7482641868063356, 6.758899966744047, 6.769387219045306, 6.779730255708338, 6.789933200532263, 6.800000000000001, 6.809934433382003, 6.819740122127069, 6.829420538599904, 6.838979014219411, 6.848418747046503, 6.857742808865661, 6.866954151800371, 6.876055614498887, 6.885049927923476, 6.893939720773379, 6.9027275245690065, 6.911415778422554, 6.920006833518017, 6.928502957321684, 6.936906337542357, 6.945219085859038, 6.953443241432297, 6.961580774214274, 6.969633588071059, 6.9776035237301, 6.985492361564321, 6.993301824223717, 7.001033579124373, 7.008689240804122, 7.016270373153321, 7.023778491528667, 7.031215064757335, 7.038581517038228, 7.045879229746633, 7.05310954314812, 7.060273758027149, 7.067373137235418, 7.074408907164671], [0.0, 4.518186791976555, 4.842472702422459, 5.042852983138936, 5.190033735512799, 5.307147794265748, 5.4047960028002935, 5.488756768484937, 5.562540427390725, 5.628445077727374, 5.6880601676520515, 5.742532346687485, 5.792716926223587, 5.839269461985202, 5.8827038467786155, 5.923430641202922, 5.961783214362669, 5.998036079411821, 6.032418069651222, 6.065122008795079, 6.0963119409992075, 6.126128625941485, 6.154693776935911, 6.18211337290126, 6.208480277511247, 6.233876332912343, 6.258374049954317, 6.282037985028582, 6.304925870937489, 6.3270895528486975, 6.34857576841563, 6.36942680228136, 6.38968103854823, 6.409373429777202, 6.42853589724882, 6.447197674264987, 6.4653856019765925, 6.48312438542542, 6.500436816071381, 6.517343965950173, 6.5338653577060715, 6.550019114020154, 6.565822089368009, 6.581289986563778, 6.596437460157178, 6.61127820842909, 6.625825055466306, 6.640090024575913, 6.654084404116516, 6.667818806669987, 6.681303222348513, 6.694547066922999, 6.707559225366823, 6.720348091330807, 6.732921602998601, 6.745287275714815, 6.757452231729326, 6.769423227359256, 6.781206677833856, 6.792808680056257, 6.804235033488828, 6.815491259345349, 6.826582618252564, 6.837514126525771, 6.848290571187334, 6.858916523843203, 6.869396353520428, 6.879734238557909, 6.889934177633224, 6.900000000000001, 6.909935375002921, 6.919743820930849, 6.929428713262749, 6.938993292355853, 6.9484406706208794, 6.957773839224962, 6.966995674359221, 6.976108943104577, 6.985116308926433, 6.9940203368261145, 7.002823498174571, 7.011528175251654, 7.020136665512284, 7.028651185599059, 7.037073875119229, 7.045406800202519, 7.053651956854894, 7.061811274122245, 7.06988661707677, 7.077879789637918, 7.085792537238787, 7.09362654934807, 7.101383461856849, 7.109064859338893, 7.116672277192425, 7.1242072036707595, 7.131671081808705, 7.139065311251085, 7.146391249989307, 7.153650216011502, 7.160843488871359, 7.167972311180408], [0.0, 4.577077183420476, 4.905589861170428, 5.108581913757425, 5.257681031289564, 5.376321563621647, 5.4752425263580795, 5.560297643069971, 5.635043003816604, 5.701806660395136, 5.76219877795131, 5.817380951525238, 5.86821964070076, 5.915378945766064, 5.959379457645492, 6.000637088216317, 6.039489551741435, 6.076214939400211, 6.111045067124192, 6.144175271906592, 6.175771736067273, 6.205977053956494, 6.234914525308881, 6.262691510380519, 6.289402083237335, 6.315129152762584, 6.339946174917982, 6.3639185475278754, 6.387104755888367, 6.409557320920988, 6.431323589461301, 6.452446397293647, 6.472964628821685, 6.492913692180724, 6.512325924715717, 6.531230940757652, 6.549655931307029, 6.567625923413033, 6.5851640056012, 6.602291524561751, 6.619028257398596, 6.6353925630052215, 6.651401515539735, 6.66707102248796, 6.682415929408128, 6.697450113125562, 6.712186564877176, 6.726637464682763, 6.740814248034255, 6.754727665838724, 6.768387838420242, 6.781804304275592, 6.794986064185573, 6.807941621204491, 6.820679016982888, 6.8332058648209495, 6.8455293798005, 6.857656406301015, 6.869593443168334, 6.881346666773087, 6.8929219521682805, 6.904324892531615, 6.9155608170572425, 6.926634807443501, 6.937551713107168, 6.948316165240854, 6.958932589817842, 6.969405219637819, 6.9797381054974315, 6.989935126561091, 7.0, 7.009936289960667, 7.019747415918305, 7.029436660465213, 7.039007176579505, 7.048461994415417, 7.057804027652564, 7.06703607943821, 7.076160847953569, 7.085180931632389, 7.094098834057659, 7.102916968560047, 7.1116376625396756, 7.120263161531032, 7.12879563302917, 7.137237170093908, 7.145589794747305, 7.153855461178582, 7.162036058769431, 7.170133414951725, 7.178149297908671, 7.186085419129625, 7.193943435827999, 7.201724953231016, 7.2094315267493965, 7.2170646640344644, 7.224625826929652, 7.232116433322862, 7.2395378589056625, 7.246891438844947, 7.2541784693722, 7.261400209295249], [0.0, 4.635883502796818, 4.968616913707425, 5.174217009592999, 5.3252317536205975, 5.445396580334382, 5.545588480285674, 5.631736385726597, 5.707442075386164, 5.775063511887156, 5.8362315477882705, 5.892122702310744, 5.943614567317156, 5.991379775460802, 6.035945606221825, 6.07773331511618, 6.117084955361956, 6.154282191055915, 6.189559816502302, 6.223115678385372, 6.255118094136584, 6.285711490159399, 6.315020750344288, 6.343154614312649, 6.37020836479466, 6.396265975887484, 6.421401847315542, 6.4456822171348795, 6.469166322061091, 6.49190735780487, 6.513953279514251, 6.535347473328029, 6.55612932323695, 6.5763346923002945, 6.595996333333443, 6.615144241152516, 6.6338059561081755, 6.652006826797306, 6.669770238386984, 6.687117811829851, 6.7040695783261866, 6.720644132644667, 6.7368587683123025, 6.752729597194403, 6.768271655585037, 6.783498998599074, 6.798424784384933, 6.813061349451381, 6.827420276213632, 6.841512453706486, 6.855348132280011, 6.86893697298166, 6.882288092234327, 6.8954101023396195, 6.908311148267261, 6.920998941133169, 6.933480788718591, 6.945763623339637, 6.957854027339363, 6.969758256442452, 6.981482261184631, 6.993031706604787, 7.004411990366597, 7.015628259458092, 7.026685425601391, 7.037588179490699, 7.048341003964234, 7.058948186204724, 7.069413829053478, 7.0797418615144405, 7.0899360485170515, 7.100000000000001, 7.109937179371944, 7.119750911399946, 7.129444389571608, 7.139020682972609, 7.148482742717535, 7.157833407968511, 7.167075411572999, 7.176211385349443, 7.185243865046883, 7.194175295002476, 7.203008032518798, 7.211744351980978, 7.2203864487320635, 7.228936442723517, 7.237396381956352, 7.245768245727229, 7.254053947692625, 7.262255338763272, 7.270374209840008, 7.278412294401412, 7.286371270952791, 7.294252765345337, 7.302058352973695, 7.309789560859507, 7.317447869627979, 7.325034715384046, 7.332551491494173, 7.339999550279484, 7.347380204625459, 7.354694729513092], [0.0, 4.69460705180036, 5.031555255155371, 5.239759723497368, 5.392687397760554, 5.5143743733993, 5.615835421710985, 5.7030745777719165, 5.779739244673661, 5.848217253764896, 5.910160115899569, 5.966759253474137, 6.018903374961146, 6.067273633369621, 6.112403987321315, 6.154721028449649, 6.194571142820789, 6.232239562419985, 6.267964055732094, 6.301944975600002, 6.334352771561581, 6.365333699494861, 6.395014225216444, 6.42350446577158, 6.450900910853488, 6.477288598273942, 6.502742870191714, 6.52733080371192, 6.5511123859120115, 6.574141486342076, 6.596466667606416, 6.61813186542365, 6.639176962668441, 6.659638276683725, 6.6795489751705395, 6.698939432894599, 6.717837539065013, 6.736268963373789, 6.754257387212011, 6.77182470540872, 6.788991202902921, 6.805775710006485, 6.82219573930656, 6.838267606760278, 6.854006539129079, 6.86942676956644, 6.8845416228973475, 6.899363591899292, 6.9139044057039705, 6.928175091279496, 6.942186028818916, 6.955947001747866, 6.969467241968567, 6.98275547087616, 6.995819936614129, 7.008668447976449, 7.021308405313313, 7.033746828753692, 7.045990384020339, 7.058045406080297, 7.069917920845771, 7.0816136651156905, 7.093138104926882, 7.104496452465179, 7.115693681670344, 7.126734542654429, 7.137623575040548, 7.148365120317925, 7.158963333299278, 7.169422192757935, 7.179745511314356, 7.189936944634958, 7.2, 7.209938044291955, 7.219754311450891, 7.229451909439132, 7.239033826753554, 7.248502938520441, 7.2578620122047175, 7.26711371296253, 7.276260608663698, 7.285305174608224, 7.294249797959051, 7.303096781911341, 7.3118483496169375, 7.320506647881102, 7.3290737506472325, 7.3375516622840875, 7.345942320688768, 7.354247600217818, 7.362469314457726, 7.370609218845352, 7.3786690131479205, 7.386650343811568, 7.394554806186741, 7.402383946638127, 7.4101392645462765, 7.417822214207515, 7.425434206638325, 7.43297661128992, 7.440450757678329, 7.447857936934955], [0.0, 4.753249094182493, 5.09440623996947, 5.305211465972746, 5.460049415378577, 5.583256427242724, 5.6859848623728535, 5.774313754428866, 5.851936067539561, 5.921269460322565, 5.983986073253948, 6.041292211220203, 6.094087683874301, 6.14306215275499, 6.188756246355169, 6.231601885019346, 6.271949781647893, 6.310088731162422, 6.346259472100322, 6.380664859984636, 6.41347747350034, 6.444845395460778, 6.474896671413016, 6.503742793914324, 6.531481457945739, 6.558198763557237, 6.58397099403387, 6.608866064365245, 6.632944710949192, 6.656261476239925, 6.6788655294548755, 6.700801355129691, 6.722109334330511, 6.742826238053398, 6.7629856483091935, 6.782618319285845, 6.80175248856671, 6.820414146493242, 6.838627270269386, 6.856414028220449, 6.8737949586719775, 6.89078912715211, 6.907414265004084, 6.9236868919935795, 6.939622425085048, 6.955235275223455, 6.97053893367902, 6.985546049281055, 7.000268497674101, 7.014717443568139, 7.0289033968189765, 7.042836263060575, 7.056525389514201, 7.06997960651711, 7.083207265243343, 7.096216272029356, 7.109014119665808, 7.121607915972651, 7.134004409936601, 7.146210015657078, 7.158230834318146, 7.1700726743791705, 7.181741070155235, 7.193241298939477, 7.204578396802948, 7.215757173193077, 7.226782224439058, 7.237657946261235, 7.248388545371602, 7.258978050243789, 7.269430321123084, 7.279749059340161, 7.289937815985992, 7.300000000000002, 7.309938885718577, 7.319757619926731, 7.329459228451738, 7.3390466223341315, 7.348522603608244, 7.357889870721656, 7.367151023620381, 7.376308568524295, 7.385364922415259, 7.3943224172584845, 7.403183303976011, 7.411949756189624, 7.420623873749103, 7.429207686060506, 7.43770315522791, 7.446112179021124, 7.454436593680811, 7.462678176571625, 7.470838648693204, 7.478919677058038, 7.4869228769446785, 7.4948498140340165, 7.502702006435906, 7.51048092661282, 7.51818800320676, 7.525824622775249, 7.533392131441788, 7.54089183646577], [0.0, 4.811810857361606, 5.157171183664178, 5.370573606969239, 5.5273192164081495, 5.652044183613544, 5.75603827054745, 5.845455406782543, 5.924034055113154, 5.994221660593222, 6.057710965079605, 6.115723135575146, 6.169169067716058, 6.218746919922885, 6.265003981428821, 6.308377493994618, 6.349222491431542, 6.387831326720015, 6.424447704384046, 6.459276979200738, 6.492493856087438, 6.52424824229178, 6.55466976092869, 6.583871278184425, 6.611951692677835, 6.638998165242926, 6.665087919002658, 6.690289705684089, 6.7146650099796314, 6.738269046326435, 6.761151589724634, 6.783357672775584, 6.804928174054894, 6.8259003175907145, 6.846308099136514, 6.866182651783056, 6.885552561011029, 6.904444137372376, 6.922881653478945, 6.940887550777897, 6.958482620634444, 6.975686163470988, 6.992516129087385, 7.008989240778856, 7.025121105452479, 7.0409263116013205, 7.056418516712971, 7.071610525454934, 7.086514359784028, 7.10114132196353, 7.115502051334508, 7.12960657557195, 7.143464357058296, 7.15708433492378, 7.170474963231952, 7.183644245728223, 7.196599767517163, 7.20934872398966, 7.221897947282409, 7.234253930518874, 7.2464228500519345, 7.258410585903296, 7.27022274057282, 7.281864656371823, 7.293341431417589, 7.304657934411693, 7.315818818311783, 7.326828532995081, 7.337691337001808, 7.348411308437859, 7.358992355108153, 7.369438223945108, 7.379752509790431, 7.389938663582927, 7.4, 7.409939704596203, 7.419760840478107, 7.429466354551326, 7.439059083372277, 7.448541758634402, 7.457917012315997, 7.4671873815144805, 7.476355312989813, 7.485423167437867, 7.494393223512864, 7.503267681616403, 7.512048667469179, 7.5207382354802705, 7.529338371927595, 7.53785099796218, 7.546277972447839, 7.55462109464701, 7.562882106762674, 7.571062696345524, 7.57916449857493, 7.587189098421545, 7.59513803269889, 7.603012792010712, 7.610814822600403, 7.618545528108384, 7.626206271242884, 7.633798375369211], [0.0, 4.870293533944303, 5.219851364443605, 5.435847477582716, 5.594498170794517, 5.72073904337007, 5.825997072868003, 5.916500983628198, 5.996034675665398, 6.067075340243815, 6.131336292779301, 6.190053542320034, 6.244149055514049, 6.294329476188803, 6.3411487453225766, 6.385049418905885, 6.4263908458255825, 6.465468932315805, 6.502530344881673, 6.537782934179148, 6.571403528486511, 6.603543857021822, 6.63433511833739, 6.663891550393398, 6.692313253821016, 6.719688448805716, 6.746095297039125, 6.771603385855758, 6.7962749472320505, 6.820165866680588, 6.843326524166106, 6.865802499615518, 6.887635168442023, 6.90886220709405, 6.929518024508941, 6.949634132168577, 6.969239462981146, 6.988360647276643, 7.007022252675874, 7.02524699337901, 7.043055913449203, 7.060468547885898, 7.077503064650546, 7.094176390293048, 7.110504321406593, 7.126501623792573, 7.142182120931478, 7.157558773118547, 7.172643748425278, 7.187448486482488, 7.201983755941635, 7.216259706353917, 7.230285915107427, 7.2440714299784545, 7.257624807781111, 7.270954149538206, 7.284067132543558, 7.2969710396407255, 7.309672786004092, 7.322178943674445, 7.3344957640719635, 7.346629198684049, 7.3585849181032605, 7.370368329571287, 7.381984593167852, 7.393438636768656, 7.404735169883326, 7.415878696472823, 7.426873526835602, 7.437723788642795, 7.448433437194724, 7.459006264963965, 7.46944591048388, 7.479755866635928, 7.489939488384057, 7.5, 7.509940501819278, 7.5197639765641515, 7.529473295266504, 7.539071222820735, 7.548560423194167, 7.557943464320062, 7.567222822696263, 7.5764008877105065, 7.585479965711742, 7.594462283845215, 7.6033499936675994, 7.612145174557232, 7.620849836933219, 7.6294659252962305, 7.637995321102682, 7.646439845483221, 7.654801261815536, 7.663081278160786, 7.671281549572287, 7.6794036802844, 7.687449225789057, 7.695419694806778, 7.703316551158576, 7.711141215544697, 7.718895067235705, 7.72657944568107], [0.0, 4.9286982831635, 5.282448024742828, 5.501034371659901, 5.661587610146623, 5.789342368169244, 5.895862656045094, 5.987451893218258, 6.067939356379424, 6.139831943366654, 6.204863515740814, 6.2642849048185925, 6.319029133507876, 6.369811319736349, 6.417192047364015, 6.461619179530018, 6.50345637444702, 6.54300308686821, 6.580508941333016, 6.616184281050543, 6.6502080548306495, 6.682733811434073, 6.713894322751257, 6.743805196688439, 6.772567734287449, 6.800271213673646, 6.826994733856702, 6.852808716665146, 6.877776140363696, 6.901953560646174, 6.925391961635809, 6.948137469855767, 6.9702319568948115, 6.991713551018803, 7.012617073798396, 7.032974414602387, 7.0528148533035235, 7.0721653395837505, 7.091050735679738, 7.109494028181227, 7.127516513512593, 7.145137960937752, 7.1623767562890555, 7.179250029100246, 7.195773765397876, 7.211962908055397, 7.227831446325015, 7.243392495922334, 7.2586583708388375, 7.273640647889839, 7.288350224864884, 7.302797373028982, 7.316991784622636, 7.330942615923421, 7.344658526359094, 7.358147714100246, 7.3714179485071005, 7.38447659975936, 7.397330665958447, 7.409986797957317, 7.422451322143422, 7.434730261374632, 7.446829354245475, 7.458754072841488, 7.470509639122274, 7.48210104005881, 7.493533041637343, 7.504810201830511, 7.515936882626035, 7.52691726119424, 7.5377553402675606, 7.5484549577980555, 7.559019795952516, 7.5694533894991745, 7.579759133634835, 7.589940291296822, 7.600000000000001, 7.609941278235555, 7.619767031464892, 7.629480057739133, 7.6390830529719995, 7.64857861589151, 7.657969252693764, 7.66725738142013, 7.676445336077384, 7.685535370518783, 7.694529662102553, 7.703430315143015, 7.7122393641683, 7.720958776997606, 7.729590457649847, 7.738136249094739, 7.746597935856465, 7.75497724647932, 7.763275855864082, 7.771495387483156, 7.779637415481989, 7.78770346667374, 7.79569502243362, 7.803613520498966, 7.811460356680609, 7.819236886490749], [0.0, 4.98702623223898, 5.344962372686096, 5.566135547316914, 5.728588829299978, 5.857855482064776, 5.965636368494194, 6.0583095049151465, 6.139749485025567, 6.212492874174298, 6.278294053049772, 6.338418655746441, 6.39381074689346, 6.4451939073756, 6.493135355199442, 6.538088253674046, 6.580420564671275, 6.6204352867971945, 6.658384998735835, 6.694482532971822, 6.728908956058172, 6.761819633905666, 6.793348909674, 6.823613759414037, 6.852716682999767, 6.8807480151052856, 6.907787790825767, 6.9339072653864315, 6.959170162358931, 6.983633706737061, 7.007349486008098, 7.030364172572708, 7.0527201335427625, 7.074455948407432, 7.095606850828086, 7.116205107563529, 7.136280344994818, 7.155859831735916, 7.174968724251945, 7.193630281164038, 7.211866050925941, 7.229696036757999, 7.247138842076966, 7.2642117991335144, 7.280931083138455, 7.2973118138044635, 7.313368145937475, 7.329113350469084, 7.344559887118882, 7.359719469706286, 7.374603124989118, 7.389221245786148, 7.4035836390392635, 7.417699569384649, 7.431577798728775, 7.4452266222622665, 7.458653901290689, 7.471867093215044, 7.484873278954747, 7.497679188071288, 7.510291221820814, 7.522715474337811, 7.534957752129353, 7.547023592039565, 7.558918277826555, 7.570646855478866, 7.582214147385108, 7.593624765458567, 7.604883123308261, 7.615993447538618, 7.626959788251818, 7.637786028819591, 7.648475894984789, 7.659032963347332, 7.6694606692839775, 7.6797623143467995, 7.689941073181118, 7.7, 7.709942034649108, 7.7197700082926834, 7.729486648748839, 7.7390945854998545, 7.748596354401037, 7.757994402109705, 7.7672910902540915, 7.776488699360348, 7.785589432554321, 7.794595419053529, 7.8035087174634254, 7.81233131889107, 7.821065149888208, 7.829712075234908, 7.838273900574038, 7.846752374906095, 7.855149192953222, 7.863465997400567, 7.87170438102257, 7.879865888701231, 7.887952019342879, 7.895964227699538, 7.903903926100556, 7.911772486099742], [0.0, 5.045278477665545, 5.407395583467439, 5.6311522283770135, 5.795503087796356, 5.926279673020232, 6.035319521876595, 6.129075150756148, 6.2114664115472795, 6.285059498604246, 6.351629285111345, 6.412456188728314, 6.468495301474563, 6.520478656207908, 6.568980096471069, 6.614458078863951, 6.657284863331911, 6.697766987734339, 6.736159981065692, 6.772679161855293, 6.807507711650707, 6.840802811154283, 6.872700372755627, 6.903318738874515, 6.932761606661136, 6.961120365967035, 6.988475986757945, 7.014900556574112, 7.040458543326792, 7.065207840441072, 7.089200637985174, 7.112484153528767, 7.1351012490636965, 7.1570909547168, 7.178488915705311, 7.199327775688227, 7.219637507105187, 7.239445697088228, 7.258777795949048, 7.277657333987098, 7.296106111358396, 7.3141443649360545, 7.331790915438834, 7.34906329757123, 7.365977875482771, 7.3825499454958345, 7.398793827755215, 7.414722948207045, 7.4303499121098815, 7.44568657010943, 7.460744077764398, 7.475532949289554, 7.490063106179301, 7.504343921287791, 7.518384258867205, 7.532192511002278, 7.545776630824582, 7.559144162843214, 7.572302270688094, 7.58525776252709, 7.5980171143878685, 7.610586491589028, 7.622971768462043, 7.635178546525575, 7.647212171256028, 7.659077747582919, 7.6707801542240075, 7.682324056963223, 7.693713920963882, 7.704954022200353, 7.716048458083081, 7.727001157344519, 7.737815889247018, 7.748496272167897, 7.759045781611718, 7.769467757695182, 7.779765412145874, 7.789941834852384, 7.8, 7.809942771823105, 7.819772910002797, 7.8294930747357, 7.839105831497832, 7.848613655525325, 7.858018936032018, 7.867323980182335, 7.876531016836305, 7.885642200082317, 7.894659612571898, 7.9035852686697465, 7.912421117431193, 7.921169045418349, 7.92983087936536, 7.938408388702375, 7.946903287947175, 7.955317238972716, 7.9636518531582485, 7.971908693431168, 7.980089276206161, 7.988195073227861, 7.996227513322693, 8.004187984065252], [0.0, 5.103456086433481, 5.469748800658732, 5.696085605732786, 5.862331611285747, 5.994616194342614, 6.104913392559367, 6.199750126936048, 6.283091449563692, 6.357533145839312, 6.42487055518672, 6.48639885988925, 6.543084165227541, 6.59566694520322, 6.644727660406071, 6.690730053944724, 6.734050678331054, 6.774999606143047, 6.813835312905452, 6.850775600007006, 6.886005761279947, 6.919684789892964, 6.951950165454966, 6.982921595003963, 7.0127039714323125, 7.041389738417044, 7.06906079959663, 7.095790073759927, 7.121642772204098, 7.1466774559290815, 7.1709469168119755, 7.19449891689295, 7.217376812409749, 7.239620083549489, 7.261264786557956, 7.2823439415114315, 7.302887866464743, 7.322924466659893, 7.342479485878662, 7.361576725750725, 7.380238237811873, 7.398484492288618, 7.416334526923304, 7.43380607861485, 7.450915700209425, 7.467678864412822, 7.484110056496851, 7.500222857223569, 7.516030017204025, 7.531543523734899, 7.546774661010758, 7.561734064486831, 7.576431770063258, 7.590877258673508, 7.605079496784335, 7.619046973250442, 7.632787732911751, 7.646309407273847, 7.659619242571178, 7.672724125477275, 7.6856306066955264, 7.698344922637432, 7.710873015371969, 7.723220551009466, 7.7353929366655505, 7.74739533613519, 7.7592326843931225, 7.770909701024899, 7.782430902682079, 7.793800614645717, 7.805022981573904, 7.8161019775017015, 7.8270414151551995, 7.837844954635586, 7.848516111523811, 7.859058264451795, 7.869474662181875, 7.879768430232452, 7.889942577084442, 7.9, 7.909943490482381, 7.919775739403202, 7.929499341821241, 7.939116801514823, 7.948630535248051, 7.958042876789492, 7.96735608070038, 7.976572325908116, 7.985693719079484, 7.994722297807027, 8.003660033620823, 8.012508834837123, 8.021270549254321, 8.029946966706047, 8.038539821480354, 8.047050794613419, 8.055481516065472, 8.063833566786176, 8.072108480676148, 8.080307746450854, 8.088432809412662, 8.096485073136424], [0.0, 5.1615600971857285, 5.532023137449914, 5.760936838637683, 5.929075592855582, 6.062866266041593, 6.174419222999597, 6.270335695212874, 6.354625877794253, 6.429915109749139, 6.498019170849885, 6.560247989325327, 6.617578669784926, 6.67076011669559, 6.720379399323217, 6.766905540597429, 6.810719380166277, 6.852134520854718, 6.891412380990263, 6.928773241680105, 6.964404506368993, 6.998466978399082, 7.031099702615962, 7.062423748949555, 7.0925452045217074, 7.12155756550178, 7.149543668019839, 7.1765772610617695, 7.202724298370219, 7.228044007675456, 7.252589781902133, 7.276409926872133, 7.299548292443848, 7.322044808295325, 7.343935941180925, 7.365255087118024, 7.386032909339415, 7.406297630794641, 7.426075288364304, 7.44538995466506, 7.46426393229446, 7.482717924537211, 7.500771185884693, 7.5184416551744615, 7.535746073710611, 7.552700090359217, 7.569318355310212, 7.585614603945723, 7.601601732045412, 7.617291863384065, 7.632696410629377, 7.647826130323655, 7.662691172628052, 7.677301126418627, 7.6916650602473995, 7.7057915596166175, 7.719688760958542, 7.733364382665186, 7.746825753471029, 7.76007983845595, 7.773133262904588, 7.78599233423141, 7.798663062157202, 7.811151177302252, 7.823462148343429, 7.8356011978666835, 7.847573317032568, 7.8593832791601885, 7.871035652324211, 7.882534811050003, 7.893884947183532, 7.905090080005155, 7.916154065649716, 7.927080605889489, 7.937873256331115, 7.948535434073012, 7.959070424865412, 7.969481389811458, 7.979771371644306, 7.989943300612102, 8.0, 8.009944191315807, 8.019778499163632, 8.029505455827891, 8.039127505588095, 8.048647008783298, 8.05806624564343, 8.067387419903474, 8.076612662215098, 8.085744033369297, 8.094783527342472, 8.103733074177487, 8.112594542710346, 8.121369743152336, 8.13006042953678, 8.138668302038834, 8.147195009176194, 8.155642149897998, 8.164011275568672, 8.172303891853048, 8.180521460508585, 8.188665401090159], [0.0, 5.21959152131576, 5.59421967782567, 5.825707055931401, 5.995736194291884, 6.131031076119103, 6.243838223057713, 6.340833084241623, 6.42607094141039, 6.502206650257869, 6.571076405369786, 6.634004862499059, 6.691980111843021, 6.745759477802075, 6.795936630062328, 6.842985864778558, 6.88729230337927, 6.929173074526224, 6.968892535673388, 7.0066734445486105, 7.042705311573714, 7.0771507480029525, 7.110150361963223, 7.14182658457376, 7.172286695694004, 7.201625242670819, 7.229925992960946, 7.257263524710175, 7.2837045331791295, 7.309308911995498, 7.334130654380624, 7.358218609258786, 7.381617119492364, 7.404366563688806, 7.426503818598223, 7.448062655709439, 7.469074083001995, 7.489566640736079, 7.509566658524961, 7.5290984796337455, 7.548184657408104, 7.5668461278997885, 7.585102362078442, 7.602971500467983, 7.620470472595001, 7.637615103265786, 7.654420207382367, 7.670899674753781, 7.687066546146953, 7.702933081644276, 7.718510822226077, 7.733810645370478, 7.748842815356901, 7.763617028869144, 7.778142456416966, 7.792427780029423, 7.80648122761669, 7.820310604348666, 7.833923321356801, 7.8473264220293695, 7.860526606139092, 7.8735302520147, 7.886343436944277, 7.898971955977476, 7.911421339275509, 7.92369686814186, 7.935803589852705, 7.947746331393581, 7.959529712198021, 7.971158155974184, 7.982635901696965, 7.9939670138354915, 8.005155391879137, 8.016204779219203, 8.02711877143802, 8.037900824052443, 8.048554259754399, 8.059082275187317, 8.0694879472938, 8.07977423926678, 8.089944006133607, 8.1, 8.109944874978499, 8.119781191823993, 8.129511422297027, 8.139137953273954, 8.148663090621325, 8.15808906285072, 8.167418024568727, 8.176652059735813, 8.185793184746661, 8.194843351343602, 8.20380444937397, 8.212678309401257, 8.221466705179385, 8.23017135599858, 8.238793928910823, 8.247336040842239, 8.255799260599245, 8.264185110774864, 8.272495069561094, 8.280730572472873], [0.0, 5.2775513440099315, 5.656339477682592, 5.890397357203263, 6.062314547276599, 6.1991117817937, 6.313171571244372, 6.411243490840518, 6.497427853318782, 6.574408994642629, 6.644043499022564, 6.707670731564191, 6.7662897544982705, 6.820666301769859, 6.871400635341413, 6.918972318086557, 6.963770747931224, 7.00611657502366, 7.0462770923178795, 7.084477531106638, 7.120909506189162, 7.155737434501129, 7.189103485521905, 7.221131449880552, 7.251929798702457, 7.2815941292150015, 7.310209139052495, 7.337850234497582, 7.364584851413952, 7.3904735485051, 7.415570918548392, 7.439926352900397, 7.4635846868192015, 7.486586747287747, 7.508969820546024, 7.5307680530910295, 7.552012797223697, 7.572732910123348, 7.592955013774732, 7.612703721757468, 7.632001837855964, 7.650870530601821, 7.669329487175846, 7.687397049539471, 7.705090335209546, 7.72242534471549, 7.739417057468202, 7.7560795175130925, 7.772425910425456, 7.788468632427114, 7.804219352652707, 7.819689069366955, 7.834888160826747, 7.849826431390604, 7.864513153400223, 7.878957105292369, 7.8931666063422625, 7.907149548390621, 7.920913424864196, 7.934465357363041, 7.94781212005605, 7.960960162098725, 7.973915628263074, 7.986684377948627, 7.99927200272507, 8.011683842540979, 8.023925000718913, 8.036000357844621, 8.047914584647138, 8.05967215395673, 8.071277351819072, 8.082734287836306, 8.094046904798839, 8.105218987665653, 8.116254171945439, 8.127155951526092, 8.137927685995653, 8.148572607493982, 8.159093827130926, 8.169494341003551, 8.179777035842239, 8.18994469431287, 8.200000000000001, 8.209945542093868, 8.21978381980215, 8.229517246505743, 8.2391481536762, 8.248678794571124, 8.258111347722462, 8.267447920231572, 8.276690550883748, 8.285841213094029, 8.294901817695143, 8.30387421557768, 8.312760200191828, 8.321561509919299, 8.33027983032349, 8.338916796285334, 8.347473994031716, 8.355952963062965, 8.364355197985342, 8.372682150254144], [0.0, 5.335440525237726, 5.7183835658904965, 5.955008813897453, 6.128811754525092, 6.267109510663723, 6.382420415905018, 6.4815680811939655, 6.568697795380492, 6.6465233387671026, 6.716921660338192, 6.781246816624286, 6.84050882851685, 6.895481829256033, 6.946772665045974, 6.994866159060065, 7.040155980509465, 7.082966296736919, 7.123567332618701, 7.162186789997687, 7.199018385485691, 7.234228339499053, 7.2679603809666276, 7.3003396583703335, 7.331475832649586, 7.361465549632694, 7.39039443599783, 7.418338725155162, 7.4453665926687975, 7.471539261507442, 7.496911923273746, 7.521534511095454, 7.545452352026222, 7.568706720878009, 7.5913353128815935, 7.613372649085094, 7.6348504256911705, 7.655797816412015, 7.676241735247522, 7.696207065762357, 7.715716861874435, 7.734792524311859, 7.753453956203078, 7.77171970070153, 7.789607063085199, 7.807132219392465, 7.824310313342591, 7.841155543029379, 7.85768123866, 7.873899932429777, 7.889823421471469, 7.905462824689181, 7.92082863417835, 7.935930761840989, 7.9507785817266186, 7.965380968562212, 7.97974633287668, 7.9938826530759215, 8.00779750478169, 8.021498087710492, 8.034991250336724, 8.04828351255633, 8.061381086543, 8.074289895967704, 8.087015593733762, 8.09956357836336, 8.111939009157137, 8.124146820235726, 8.136191733561141, 8.148078271025886, 8.159810765689043, 8.171393372230765, 8.182830076689717, 8.194124705541897, 8.205280934173697, 8.216302294797284, 8.22719218385184, 8.237953868930397, 8.248590495268406, 8.259105091826957, 8.269500577000825, 8.279779763978807, 8.289945365781557, 8.3, 8.309946193255493, 8.319786385401182, 8.329522933482401, 8.33915811547262, 8.348694133799988, 8.358133118678547, 8.367477131256917, 8.376728166596424, 8.385888156489617, 8.394958972129409, 8.403942426638245, 8.412840277466056, 8.421654228665096, 8.430385933049218, 8.439036994244548, 8.447608968638107, 8.45610336723042, 8.46452165739772], [0.0, 5.393260000693119, 5.780352945301355, 6.019542470363701, 6.195228890867494, 6.33502536181304, 6.451585876345977, 6.551807991996149, 6.639881919569933, 6.7185508482542255, 6.7897120672855955, 6.854734306929185, 6.914638533541573, 6.970207269544211, 7.02205393745467, 7.070668614412055, 7.116449235769595, 7.159723481829393, 7.20076450585958, 7.239802477278309, 7.277033211979136, 7.312624731687444, 7.34672232290381, 7.379452490327984, 7.410926083280728, 7.441240794928628, 7.47048317987504, 7.498730297661687, 7.526051062662404, 7.5525073613112506, 7.578154983315101, 7.603044402920515, 7.627221438384538, 7.650727811808898, 7.673601626922693, 7.695877778874152, 7.717588307353562, 7.738762702224843, 7.759428169151408, 7.779609861357879, 7.799331082594482, 7.818613465506229, 7.837477128909184, 7.855940816906529, 7.874022022311296, 7.891737096459492, 7.909101347180895, 7.926129126432206, 7.942833908878315, 7.95922836252432, 7.975324412346974, 7.9911332977445, 8.00666562451381, 8.021931411970908, 8.036940135750674, 8.051700766754344, 8.066221806654633, 8.080511320318392, 8.094576965463402, 8.108426019828562, 8.12206540610429, 8.135501714841803, 8.148741225535304, 8.161789926049819, 8.174653530548442, 8.187337496056447, 8.199847037785139, 8.212187143325579, 8.224362585811066, 8.23637793613727, 8.248237574320067, 8.25994570006334, 8.271506342601937, 8.282923369878876, 8.29420049711024, 8.305341294786315, 8.316349196153055, 8.327227504213973, 8.337979398289026, 8.348607940163761, 8.359116079859223, 8.369506661050366, 8.379782426158497, 8.389946021141036, 8.4, 8.409946829028913, 8.419788890816104, 8.429528488021141, 8.439167846939602, 8.448709120870381, 8.458154393298502, 8.467505680905505, 8.476764936418528, 8.485934051308357, 8.495014858346009, 8.50400913402667, 8.512918600869192, 8.52174492959875, 8.530489741219762, 8.539154608985614, 8.547741060271346, 8.556250578354954], [0.0, 5.451010682690002, 5.842248593708987, 6.083999344856686, 6.26156700427727, 6.402860406862832, 6.520669043905589, 6.6219643315387975, 6.7109813490772545, 6.7904926596016395, 6.862415868399916, 6.92813436201307, 6.988680039239914, 7.044843801701771, 7.097245640405166, 7.14638088020376, 7.192651717517013, 7.236389341426669, 7.277869830108531, 7.31732581762011, 7.354955216638981, 7.390927848056385, 7.425390554091422, 7.458471194048048, 7.4902818042144395, 7.520921123849342, 7.550476634377249, 7.579026220488512, 7.606639534487657, 7.63337912548471, 7.659301380579146, 7.6844573144925175, 7.708893236100826, 7.732651314263388, 7.755770060721588, 7.778284744278661, 7.800227747703844, 7.821628876636626, 7.842515628056918, 7.862913424528458, 7.882845819336533, 7.902334676767131, 7.921400331067305, 7.940061727050893, 7.958336544842847, 7.97624131086823, 7.993791496872077, 8.011001608490922, 8.027885264675504, 8.044455269079103, 8.06072367437036, 8.07670184029825, 8.092400486225882, 8.10782973875545, 8.122999174986326, 8.137917861879579, 8.152594392143293, 8.167036917002394, 8.181253176173009, 8.195250525323605, 8.209035961272322, 8.222616145141576, 8.23599742366599, 8.249185848828267, 8.262187195978392, 8.275006980575116, 8.287650473673889, 8.300122716272579, 8.312428532614893, 8.324572542541352, 8.336559172968768, 8.348392668571178, 8.360077101728221, 8.371616381800601, 8.383014263786693, 8.394274356409367, 8.405400129677556, 8.41639492196312, 8.427261946629967, 8.438004298249055, 8.44862495843006, 8.459126801297824, 8.469512598639328, 8.47978502474473, 8.489946660964144, 8.500000000000002, 8.509947449953234, 8.519791338140145, 8.529533914695339, 8.539177355975095, 8.548723767774264, 8.558175188368882, 8.567533591395764, 8.576800888579442, 8.585978932316129, 8.595069518123609, 8.604074386965351, 8.612995227456551, 8.621833677959238, 8.630591328573095, 8.639269723028193, 8.647870360485376], [0.0, 5.508693461014455, 5.904071464762499, 6.148380430487268, 6.327827116850227, 6.47061569097268, 6.589670982973724, 6.692038180746534, 6.781997179357618, 6.862349881243393, 6.935034183855459, 7.001448112777692, 7.062634486396687, 7.119392575681318, 7.172348932403788, 7.222004122962014, 7.268764599831487, 7.312965056747953, 7.354884493355751, 7.394758005453812, 7.43278560003832, 7.4691388950508975, 7.503966286599942, 7.537396987000866, 7.569544218113611, 7.600507764059081, 7.630376031993144, 7.659227730784564, 7.687133249800895, 7.714155800048949, 7.740352365318382, 7.765774500170247, 7.790469003522627, 7.814478490467128, 7.837841880277673, 7.860594814973163, 7.882770019998384, 7.904397616397106, 7.925505392123207, 7.946119038762847, 7.966262358842972, 7.985957448018176, 8.005224855713204, 8.024083727216544, 8.04255192974483, 8.060646164606307, 8.07838206726854, 8.095774296867194, 8.112836616469203, 8.129581965216538, 8.146022523319582, 8.162169770736558, 8.178034540263234, 8.19362706566185, 8.208957025376966, 8.224033582316537, 8.238865420116973, 8.253460776259734, 8.26782747236289, 8.281972941932832, 8.295904255828269, 8.309628145659834, 8.323151025323517, 8.336479010844297, 8.34961793868711, 8.362573382675478, 8.375350669643337, 8.387954893932564, 8.400390930837172, 8.412663449084993, 8.42477692243862, 8.436735640489374, 8.448543718710953, 8.460205107833046, 8.471723602589547, 8.483102849890956, 8.494346356465952, 8.505457496013161, 8.516439515900418, 8.527295543445529, 8.538028591809669, 8.548641565531765, 8.559137265729941, 8.569518394993782, 8.579787561989336, 8.589947285796896, 8.6, 8.609948056542686, 8.619793729370564, 8.629539217870185, 8.639186650119994, 8.64873808596513, 8.658195519927501, 8.667560883961572, 8.676836050065676, 8.686022832757827, 8.695122991424423, 8.70413823254965, 8.713070211832731, 8.721920536199844, 8.73069076571686, 8.739382415408796], [0.0, 5.566309203736386, 5.965822488836184, 6.212686696128391, 6.394010225736843, 6.538292233793947, 6.658592731962689, 6.762030594162878, 6.852930479130442, 6.934123594561031, 7.0075681064874935, 7.074676662523944, 7.136502987954647, 7.193854713369652, 7.247364943682295, 7.297539480743327, 7.344789028138131, 7.389451780183545, 7.431809654597283, 7.472100206058801, 7.510525533448996, 7.547259049671441, 7.582450702917995, 7.616231056943129, 7.648714517800754, 7.680001913259648, 7.710182575131225, 7.739336035504845, 7.767533419954522, 7.794838600614633, 7.821309157271578, 7.846997183698538, 7.871949968286182, 7.8962105718398155, 7.919818320692293, 7.942809229644449, 7.9652163664183835, 7.9870701670956015, 8.008398710265793, 8.0292279562249, 8.049581956451872, 8.06948303770103, 8.088951964324734, 8.108008081853153, 8.12666944437717, 8.144952927884974, 8.16287433137639, 8.180448467307826, 8.19768924269493, 8.214609732010901, 8.23122224285965, 8.247538375268944, 8.263569075335386, 8.279324683856728, 8.294814980504935, 8.310049224023349, 8.325036188871033, 8.339784198685742, 8.3543011568923, 8.368594574744566, 8.382671597055777, 8.396539025842863, 8.410203342085124, 8.423670725775397, 8.436947074422545, 8.450038020147025, 8.462948945496441, 8.475684998094684, 8.48825110422675, 8.500651981450964, 8.512892150321258, 8.52497594529404, 8.536907524886983, 8.548690881150684, 8.560329848508381, 8.571828112013819, 8.583189215072753, 8.594416566669521, 8.605513448136366, 8.61648301949989, 8.62732832543609, 8.638052300862642, 8.648657776194717, 8.659147482288448, 8.669524055094069, 8.679790040039077, 8.689947896160001, 8.700000000000001, 8.709948649288012, 8.7197960664141, 8.729544401714397, 8.73919573657809, 8.748752086387901, 8.758215403304721, 8.76758757890622, 8.77687044668856, 8.786065784439666, 8.795175316491937, 8.804200715861654, 8.813143606281924, 8.822005564135441, 8.830788120292953], [0.0, 5.623858757982957, 6.027502573858451, 6.2769190872783085, 6.46011730403069, 6.605891030378239, 6.727435304232422, 6.8319426008898, 6.923782291331596, 7.005814854847065, 7.080018702765927, 7.147821087934873, 7.210286630006084, 7.268231309587324, 7.322294777204869, 7.372988064147861, 7.420726120227934, 7.465850636321582, 7.508646444867637, 7.549353556601337, 7.588176159885152, 7.625289460522572, 7.660844957005893, 7.694974562976129, 7.727793867320761, 7.759404740257512, 7.789897437191102, 7.819352312485784, 7.8478412270762785, 7.875428713465031, 7.902172946750513, 7.928126559298588, 7.953337328410207, 7.977848760092347, 8.00170058726917, 8.024929197095187, 8.047567999176614, 8.069647744270776, 8.091196801269296, 8.112241398869205, 8.132805837215463, 8.15291267389663, 8.17258288794578, 8.191836024904722, 8.210690325523906, 8.229162840270803, 8.247269531489625, 8.265025364781396, 8.282444390945104, 8.299539819629718, 8.31632408568632, 8.33280890907429, 8.349005349060903, 8.364923853356466, 8.380574302744058, 8.395966051692314, 8.411107965378614, 8.42600845349803, 8.440675501188162, 8.455116697361028, 8.469339260699421, 8.483350063545696, 8.497155653885395, 8.510762275605732, 8.524175887189358, 8.53740217898671, 8.550446589195047, 8.563314318659067, 8.576010344596167, 8.588539433339074, 8.600906152179304, 8.613114880386808, 8.625169819473788, 8.637075002764284, 8.648834304325277, 8.660451447309939, 8.671930011758972, 8.683273441901886, 8.69448505299631, 8.705568037740072, 8.716525472287794, 8.727360321900983, 8.73807544625822, 8.748673604449701, 8.759157459678507, 8.76952958368907, 8.779792460941676, 8.789948492550339, 8.8, 8.809949228657814, 8.819798351092034, 8.82954947021114, 8.839204622234707, 8.848765779506836, 8.858234853162045, 8.86761369565284, 8.876904103147533, 8.886107817806234, 8.895226529942386, 8.904261880076719, 8.913215460890001, 8.922088819080512], [0.0, 5.681342950675976, 6.089112606102152, 6.341078526883619, 6.526149301615495, 6.673413052043583, 6.796199688972594, 6.901775205483529, 6.994553634021251, 7.07742469222358, 7.152387013723643, 7.220882440012899, 7.283986472738236, 7.34252343304165, 7.397139509628217, 7.448350957286169, 7.496576967230768, 7.54216272292696, 7.585395968224325, 7.626519167124431, 7.665738595098206, 7.703231248812779, 7.739150175300142, 7.773628636554722, 7.806783402954179, 7.838717385981224, 7.869521763584919, 7.8992777114705115, 7.928057825098253, 7.955927296588648, 7.982944895676111, 8.009163792707492, 8.034632253338744, 8.059394228272883, 8.083489856563586, 8.106955897296157, 8.129826101572622, 8.152131534468742, 8.173900854848359, 8.195160559504766, 8.215935196966505, 8.236247555394211, 8.256118828257845, 8.275568760883699, 8.294615780469794, 8.31327711176471, 8.331568880271538, 8.34950620456198, 8.367103279055067, 8.384373448422007, 8.401329274616538, 8.417982597393435, 8.434344589062125, 8.450425804124027, 8.466236224358516, 8.481785299850786, 8.497081986393507, 8.51213477964133, 8.526951746351825, 8.541540553006968, 8.555908492075213, 8.570062506144469, 8.584009210130418, 8.597754911742076, 8.611305630366646, 8.624667114518395, 8.637844857981042, 8.650844114759645, 8.663669912946158, 8.67632706759231, 8.688820192674124, 8.701153712224196, 8.713331870700424, 8.725358742653414, 8.737238241748868, 8.748974129196114, 8.760570021629194, 8.772029398482754, 8.783355608901289, 8.794551878216737, 8.805621314026592, 8.816566911901743, 8.827391560750934, 8.83809804786636, 8.848689063672994, 8.859167206202324, 8.869534985309503, 8.879794826651501, 8.889949075442289, 8.900000000000002, 8.909949795099777, 8.91980058514494, 8.929554427168252, 8.939213313674108, 8.948779175331655, 8.95825388352822, 8.96763925279162, 8.976937043089434, 8.986148962012615, 8.995276666850458, 9.004321766563292, 9.013285823658952], [0.0, 5.7387625892353515, 6.150653450938516, 6.405165916124388, 6.5921071459731735, 6.740859247200692, 6.864886852044084, 6.971529388809104, 7.06524550124991, 7.148954112518534, 7.224674055842076, 7.293861744973876, 7.357603551335162, 7.416732127235832, 7.47190019221746, 7.523629218701432, 7.572342634543583, 7.618389111875181, 7.662059302687061, 7.703598121492135, 7.743213928525987, 7.781085509308263, 7.8173674576716605, 7.852194382449832, 7.885684234183813, 7.917940964451976, 7.949056672711715, 7.979113355086921, 8.008184340738504, 8.036335480664286, 8.063626138566859, 8.090110022169906, 8.115835884935974, 8.140848121764716, 8.165187277383259, 8.188890482390013, 8.211991828999327, 8.234522696252416, 8.25651203265971, 8.277986602809689, 8.298971203335551, 8.319488852711071, 8.339560958602293, 8.35920746589563, 8.378446988027294, 8.397296923831266, 8.415773561786287, 8.433892173262947, 8.451667096139044, 8.469111809956392, 8.48623900362865, 8.503060636571465, 8.519587994009461, 8.535831737115254, 8.551801948551088, 8.567508173911348, 8.582959459502227, 8.598164386841427, 8.613131104214828, 8.627867355587254, 8.642380507129962, 8.656677571597527, 8.670765230760608, 8.684649856078359, 8.698337527774129, 8.71183405246071, 8.725144979445847, 8.738275615835265, 8.751231040538343, 8.7640161172711, 8.77663550664164, 8.789093677394936, 8.801394916886355, 8.813543340846774, 8.825542902496142, 8.837397401057213, 8.849110489716267, 8.860685683073559, 8.872126364122387, 8.88343579079216, 8.89461710208793, 8.905673323855929, 8.916607374202238, 8.927422068589387, 8.938120124633668, 8.948704166624099, 8.959176729782191, 8.969540264280306, 8.97979713903479, 8.989949645288997, 9.0, 9.009950349041834, 9.01980277023708, 9.029559276227777, 9.039221817195772, 9.048792283441943, 9.058272507833, 9.067664268123988, 9.076969289163976, 9.086189244991983, 9.095325760829622, 9.10438041497653], [0.0, 5.796118462250499, 6.212125953556753, 6.46918213516354, 6.657991742955092, 6.808230542141636, 6.933497736782158, 7.041206108856027, 7.135858863885029, 7.220404098102162, 7.296880821896485, 7.366760005100456, 7.431138876838566, 7.490858411336703, 7.546577851720323, 7.598823882249692, 7.648024162716356, 7.694530850043673, 7.738637501134194, 7.780591478290836, 7.820603224198668, 7.8588533112433065, 7.895497878340397, 7.9306728796671315, 7.96449744461733, 7.997076563709978, 8.028503256887454, 8.058860339781196, 8.088221874437993, 8.116654370001285, 8.14421778348223, 8.170966359384577, 8.196949338435745, 8.222211559238744, 8.246793971743635, 8.270734077649369, 8.294066309903803, 8.31682236116494, 8.339031469268146, 8.360720666299692, 8.381914996721905, 8.402637709065942, 8.422910424956052, 8.442753288617157, 8.462185099516843, 8.481223430381164, 8.499884732483515, 8.518184429823707, 8.536137003578975, 8.553756068011973, 8.571054438855285, 8.588044195052543, 8.604736734618173, 8.621142825277534, 8.6372726504637, 8.653135851174186, 8.668741564128194, 8.684098456611117, 8.699214758346614, 8.714098290696304, 8.728756493452405, 8.74319644945823, 8.757424907265179, 8.77144830201174, 8.785272774689854, 8.798904189946315, 8.812348152551241, 8.825610022652047, 8.838694929919106, 8.851607786678683, 8.864353300119179, 8.87693598364829, 8.889360167471215, 8.901630008453363, 8.913749499325016, 8.92572247728013, 8.937552632016633, 8.949243513261342, 8.960798537818764, 8.972220996179578, 8.983514058721518, 8.994680781532537, 9.00572411188363, 9.016646893376373, 9.027451870788187, 9.038141694636456, 9.048718925480884, 9.059186037981995, 9.069545424732194, 9.079799399874588, 9.089950202523557, 9.1, 9.10995089089323, 9.119804907960571, 9.129564020874895, 9.13923013882963, 9.148805113010017, 9.158290738938808, 9.16768875870402, 9.177000863075804, 9.186228693518993, 9.19537384410749], [0.0, 5.8534113401215215, 6.2735309396512475, 6.533128043862483, 6.723803977518582, 6.875527841792967, 7.002033264763453, 7.11080630151716, 7.206394670400391, 7.2917756086857075, 7.369008281763135, 7.439578199557005, 7.504593436969832, 7.5649032810033585, 7.621173491201938, 7.673935957940447, 7.723622568298115, 7.770588960162975, 7.815131592158767, 7.857500271689953, 7.897907521603895, 7.936535699189622, 7.973542486748734, 8.009065182324344, 8.043224092868297, 8.076125246699101, 8.107862583233134, 8.138519736709299, 8.168171501255312, 8.196885043437389, 8.224720912923598, 8.251733890408207, 8.27797370334833, 8.303485633563005, 8.328311035780166, 8.35248778239171, 8.376050646704776, 8.399031634649699, 8.421460273069007, 8.443363861252966, 8.46476769122084, 8.485695241308484, 8.506168346863362, 8.526207351229965, 8.545831239702936, 8.565057758709402, 8.58390352213863, 8.602384106451995, 8.62051413596879, 8.638307359524541, 8.655776719531472, 8.672934414329918, 8.68979195460023, 8.706360214503476, 8.722649478132885, 8.738669481784317, 8.754429452490678, 8.769938143210858, 8.785203865016843, 8.80023451658205, 8.815037611238786, 8.829620301842136, 8.843989403650882, 8.858151415412912, 8.872112538822021, 8.885878696495253, 8.899455548604188, 8.912848508279675, 8.92606275589733, 8.939103252340278, 8.95197475132605, 8.964681810876012, 8.977228803998134, 8.989619928647183, 9.00185921702037, 9.013950544241151, 9.025897636479007, 9.037704078548726, 9.049373321028897, 9.060908686935703, 9.072313377985104, 9.083590480473557, 9.09474297080494, 9.105773720688969, 9.116685502034361, 9.127480991558063, 9.138162775130136, 9.148733351872375, 9.159195138027238, 9.169550470612437, 9.17980161087532, 9.189950747560095, 9.200000000000001, 9.209951421045547, 9.219806999839228, 9.229568664446276, 9.239238284350332, 9.24881767282235, 9.258308589170362, 9.267712740877267, 9.277031785633284, 9.286267333269251], [0.0, 5.910641975671822, 6.334869216078145, 6.597004482464862, 6.789544714430646, 6.942752030435316, 7.070494336538812, 7.180330881332947, 7.276853847630322, 7.363069582084577, 7.441057383190539, 7.512317285168229, 7.577968196915453, 7.63886770917891, 7.695688090842485, 7.7489664327398, 7.799138844645297, 7.84656444163, 7.891542580886443, 7.934325512264305, 7.975127836513372, 8.014133693886992, 8.051502308396, 8.08737232048947, 8.121865213397985, 8.155088052112129, 8.187135694523361, 8.218092592588732, 8.248034271721567, 8.277028555196624, 8.305136584695042, 8.33241367651909, 8.358910044326796, 8.384671412671729, 8.409739540619942, 8.43415267085357, 8.457945916669258, 8.481151596929354, 8.503799527169564, 8.525917273593866, 8.547530375509515, 8.568662540807406, 8.589335818326033, 8.609570750313141, 8.629386507688537, 8.648801010391727, 8.667831034751174, 8.686492309524192, 8.704799602016628, 8.722766795490674, 8.74040695890057, 8.757732409853647, 8.774754771573782, 8.79148502454212, 8.807933553402687, 8.824110189646161, 8.840024250521036, 8.855684574566622, 8.871099554114858, 8.886277165066963, 8.90122499421545, 8.915950264351103, 8.93045985736763, 8.944760335553207, 8.95885796123753, 8.972758714944927, 8.98646831218825, 8.999992219024222, 9.013335666478609, 9.026503663938648, 9.039501011600455, 9.052332312050599, 9.065001981053314, 9.077514257608087, 9.089873213336185, 9.10208276124936, 9.114146663949017, 9.1260685412998, 9.137851877617688, 9.149500028409033, 9.161016226693974, 9.172403588944654, 9.183665120666184, 9.194803721645886, 9.205822190894297, 9.216723231299463, 9.227509454014305, 9.238183382595318, 9.248747456909314, 9.259204036823762, 9.269555405694932, 9.279803773667073, 9.289951280794805, 9.3, 9.309951939873626, 9.319809047332205, 9.329573210137909, 9.339246259290611, 9.348829971299647, 9.35832607034251, 9.367736230317178, 9.377062076794308], [0.0, 5.967811104733727, 6.396141571483008, 6.6608122722501895, 6.85521479894067, 7.009903972391274, 7.13888183233382, 7.249780742202831, 7.347237301490681, 7.434286934947865, 7.513029052536711, 7.584978197163486, 7.651264100077856, 7.712752646847331, 7.770122608699665, 7.8239162713382235, 7.874573962694478, 7.9224582712854685, 7.967871449757398, 8.011068187780232, 8.052265161773036, 8.091648293037299, 8.129378345636201, 8.165595300982073, 8.200421817320079, 8.233965995198743, 8.266323609997523, 8.297579930512798, 8.327811212657576, 8.357085935709394, 8.385465832726211, 8.413006755042673, 8.4397594019952, 8.465769940396074, 8.491080533214923, 8.515729793026162, 8.539753172750562, 8.563183303846152, 8.586050290231569, 8.60838196473764, 8.630204113693853, 8.651540674299437, 8.672413908654473, 8.692844557696189, 8.712851977770073, 8.732454262141529, 8.75166834940364, 8.77051012044599, 8.788994485407303, 8.807135461831969, 8.824946245080252, 8.842439271898298, 8.859626277932556, 8.876518349869988, 8.893125972797355, 8.909459073297842, 8.925527058738576, 8.941338853147315, 8.956902930028614, 8.972227342428505, 8.987319750520752, 9.002187446956684, 9.016837380193309, 9.031276175990815, 9.04551015724963, 9.059545362339133, 9.073387562053966, 9.087042275319849, 9.100514783758271, 9.113810145208445, 9.12693320629512, 9.139888614122176, 9.152680827164163, 9.165314125421176, 9.177792619896163, 9.190120261448458, 9.202300849072234, 9.214338037644325, 9.22623534518184, 9.237996159646379, 9.249623745328622, 9.261121248843967, 9.272491704767484, 9.283738040933923, 9.294863083426511, 9.305869561276273, 9.316760110891815, 9.32753728023807, 9.33820353278082, 9.348761251212734, 9.359212740975238, 9.369560233589624, 9.379805889809624, 9.389951802606905, 9.4, 9.40995244773647, 9.41981105183737, 9.429577661012438, 9.439254068953826, 9.448842016515682, 9.458343193786321, 9.467759242059307], [0.0, 6.024919446708575, 6.457348776901097, 6.72455221615897, 6.920815057423786, 7.076984512683278, 7.207196612718803, 7.319156758065661, 7.417545917668406, 7.505428563456076, 7.5849241954742785, 7.657561849888651, 7.724482068793475, 7.786559023757316, 7.844477981437944, 7.898786416884845, 7.949928871701413, 7.998271404157444, 8.044119159274114, 8.087729263947454, 8.129320468058776, 8.169080472063948, 8.207171578440983, 8.243735108139642, 8.27889489317029, 8.312760068538312, 8.345427326135596, 8.376982750729324, 8.407503327955459, 8.437058192396794, 8.46570966785931, 8.493514140141135, 8.520522793740671, 8.54678223725866, 8.572335037138844, 8.597220175454618, 8.621473444389753, 8.645127787665595, 8.668213597277068, 8.690758972398354, 8.712789946118514, 8.734330684701288, 8.755403663281594, 8.776029821274879, 8.796228700255146, 8.816018566629404, 8.835416521082827, 8.854438596475502, 8.87309984562716, 8.891414420221613, 8.90939564189074, 8.927056066392822, 8.944407541677347, 8.961461260524162, 8.978227808355967, 8.994717206747342, 9.010938953088228, 9.026902056803927, 9.04261507248531, 9.058086130241184, 9.073322963548545, 9.08833293484498, 9.103123059080032, 9.117700025418399, 9.132070217266849, 9.146239730778294, 9.160214391970397, 9.173999772581656, 9.187601204775483, 9.20102379479155, 9.214272435633875, 9.227351818876308, 9.240266445658307, 9.253020636936977, 9.265618543055078, 9.278064152679278, 9.290361301157821, 9.30251367834251, 9.314524835915742, 9.326398194259864, 9.338137048902842, 9.349744576571279, 9.361223840879292, 9.37257779767924, 9.383809300098259, 9.394921103282543, 9.405915868869542, 9.416796169206666, 9.427564491333575, 9.438223240743865, 9.448774744940645, 9.459221256799513, 9.46956495775131, 9.47980796079617, 9.489952313359543, 9.500000000000002, 9.509952944978068, 9.519813014694515, 9.529582020006046, 9.539261718425728, 9.548853816214999, 9.558359970373608], [0.0, 6.081967705102637, 6.518491586331767, 6.788225099390858, 6.986346297996492, 7.143994477663125, 7.275439519249913, 7.388459783550739, 7.487780562281314, 7.576495343988741, 7.656743697665164, 7.730069137487263, 7.797623005019863, 7.860287749114898, 7.918755125026326, 7.973577791690053, 8.025204499948195, 8.074004774172789, 8.120286648716915, 8.164309685138472, 8.206294704599534, 8.246431184838505, 8.284882965129661, 8.321792704550873, 8.357285407642793, 8.391471242779303, 8.424447817400479, 8.456302031385812, 8.487111599326484, 8.516946310421101, 8.545869078602136, 8.573936823568895, 8.60120121447132, 8.62770930123381, 8.653504053349732, 8.678624822002702, 8.703107738282561, 8.726986057845435, 8.750290460459455, 8.773049311361934, 8.79528889014189, 8.817033591886586, 8.838306104541632, 8.859127565791878, 8.879517702244968, 8.899494953267352, 8.919076581465752, 8.938278771510879, 8.957116718753353, 8.975604708875283, 8.993756189647305, 9.011583835714632, 9.029099607211629, 9.046314802899413, 9.06324010843106, 9.079885640272602, 9.096260985742083, 9.112375239572499, 9.12823703735573, 9.14385458618228, 9.159235692755253, 9.174387789225076, 9.189317956963862, 9.204032948474124, 9.218539207605296, 9.232842888233044, 9.246949871539941, 9.260865782021705, 9.274596002330489, 9.28814568705551, 9.301519775531258, 9.314723003754764, 9.327759915485506, 9.34063487259451, 9.353352064722957, 9.36591551830507, 9.378329105004925, 9.390596549612484, 9.402721437440022, 9.41470722125652, 9.426557227794364, 9.438274663859685, 9.449862622075097, 9.461324086281085, 9.472661936620241, 9.48387895432646, 9.494977826239483, 9.50596114906355, 9.516831433387399, 9.52759110748156, 9.538242520887616, 9.548787947813002, 9.559229590343914, 9.569569581487887, 9.579809988056859, 9.58995281340063, 9.600000000000001, 9.609953431928167, 9.61981493718832, 9.629586289934918, 9.639269212585512, 9.648865377829509], [0.0, 6.13895656804017, 6.579570737288332, 6.8518316899772795, 7.051809311105987, 7.210934675614597, 7.34361137508285, 7.457690654601071, 7.557942082509736, 7.647488133763533, 7.7284884254064785, 7.802500934552596, 7.870687790993456, 7.933939712246509, 7.992954935406344, 8.048291297898107, 8.10040175542022, 8.149659294838242, 8.196374836828955, 8.240810375077283, 8.283188799869565, 8.323701364376333, 8.362513443068101, 8.399769031757662, 8.435594306295183, 8.470100467347164, 8.503386036948642, 8.535538729242775, 8.566636987017011, 8.596751253404223, 8.625945031848971, 8.654275775395865, 8.6817956373418, 8.70855210847535, 8.73458856091987, 8.759944714584906, 8.784657039113515, 8.808759101771837, 8.83228186980159, 8.855253974226216, 8.877701940878048, 8.899650393429626, 8.92112223241569, 8.942138793584071, 8.962719988383396, 8.982884428959489, 9.002649539672035, 9.022031656844309, 9.04104611820943, 9.059707343308283, 9.078028905918945, 9.096023599449772, 9.113703496103213, 9.13108000051131, 9.14816389845316, 9.164965401187452, 9.1814941858667, 9.19775943244279, 9.213769857424262, 9.22953374480318, 9.245058974432506, 9.260353048102933, 9.27542311353999, 9.290275986518054, 9.304918171266303, 9.319355879323057, 9.333595046978362, 9.347641351430225, 9.361500225766985, 9.375176872877057, 9.388676278377165, 9.402003222641277, 9.415162292004512, 9.428157889209219, 9.440994243154087, 9.453675418001575, 9.466205321693776, 9.478587713922439, 9.490826213594703, 9.502924305832462, 9.514885348540036, 9.526712578571765, 9.538409117528554, 9.549977977209883, 9.561422064745669, 9.572744187430347, 9.583947057279708, 9.595033295329468, 9.606005435692918, 9.616865929393816, 9.627617147989262, 9.638261386996332, 9.648800869135062, 9.659237747399562, 9.669574107968074, 9.679811972962062, 9.689953303063632, 9.700000000000001, 9.709953908903, 9.719816820551157, 9.729590473501306, 9.739276556116183], [0.0, 6.195886708754785, 6.640586951324714, 6.9153727393298725, 7.117204870094615, 7.2778058973306505, 7.411712985560669, 7.526850189070306, 7.628031307201475, 7.718407771448395, 7.800159226249126, 7.8748580967522, 7.943677289859565, 8.007515783234037, 8.067078289131834, 8.122927818131355, 8.17552152645457, 8.225235859892756, 8.272384622472279, 8.317232237498994, 8.360003662251438, 8.400891923502844, 8.44006392933807, 8.47766501092744, 8.513822514223703, 8.54864867112228, 8.58224291731076, 8.614693780356937, 8.646080430494182, 8.676473964115809, 8.705938473571019, 8.734531944700166, 8.762307014448217, 8.789311614013657, 8.815589517734944, 8.841180813867618, 8.866122310259101, 8.890447885464457, 8.914188793902778, 8.93737393210976, 8.960030071907317, 8.982182065317733, 9.003853025245823, 9.025064485298303, 9.045836541574335, 9.066187978821066, 9.086136382984485, 9.105698241884157, 9.124889035488987, 9.143723317060713, 9.162214786255008, 9.180376355120995, 9.198220207813732, 9.215757854727093, 9.233000181663023, 9.249957494575197, 9.266639560358033, 9.28305564409449, 9.299214543126398, 9.315124618268127, 9.330793822447141, 9.346229727022624, 9.361439546005158, 9.376430158375786, 9.391208128681216, 9.405779726062995, 9.420150941861872, 9.434327505923834, 9.448314901721432, 9.46211838039251, 9.47574297378834, 9.489193506614098, 9.502474607736676, 9.51559072072763, 9.528546113702705, 9.54134488851372, 9.553990989343403, 9.566488210749329, 9.578840205198881, 9.591050490133533, 9.603122454597417, 9.61505936546212, 9.62686437327698, 9.63854051777166, 9.650090733035594, 9.661517852396903, 9.67282461302149, 9.68401366025147, 9.695087551700452, 9.706048761121972, 9.716899682065971, 9.727642631337195, 9.73827985226827, 9.74881351781928, 9.759245733514819, 9.769578540228668, 9.77981391682549, 9.789953782668327, 9.800000000000002, 9.809954376205981, 9.819818665965753, 9.829594573299232], [0.0, 6.252758786060273, 6.7015409345400485, 6.978848982765975, 7.182533731740693, 7.344608916666443, 7.479745138776977, 7.595939187294688, 7.6980490474514465, 7.789255077748046, 7.871756929590527, 7.947141461426284, 8.016592346276008, 8.081016813523295, 8.141126043981943, 8.197488216107468, 8.250564682361249, 8.300735343932498, 8.348316885256427, 8.393576156781823, 8.436740180671299, 8.478003755491864, 8.517535321378586, 8.555481543497384, 8.591970936710183, 8.627116763089576, 8.661019371043864, 8.693768100735857, 8.725442849102924, 8.756115365132551, 8.78585032947796, 8.814706260231844, 8.84273627749397, 8.869988752423547, 8.896507861163922, 8.922334059940951, 8.947504494461482, 8.972053354252017, 8.996012180616129, 9.019410135330968, 9.04227423595715, 9.0646295626338, 9.086499440419212, 9.107905600577194, 9.128868323669106, 9.149406566867395, 9.16953807753954, 9.189279494846891, 9.208646440849071, 9.227653602392284, 9.246314804881413, 9.264643078885355, 9.282650720397589, 9.300349345465959, 9.317749939813242, 9.334862903991517, 9.35169809454558, 9.368264861602631, 9.384572083255353, 9.400628197062076, 9.416441228950227, 9.432018819776534, 9.447368249769024, 9.46249646105094, 9.477410078425002, 9.492115428577243, 9.506618557842959, 9.520925248662422, 9.53504103484101, 9.548971215716788, 9.562720869328416, 9.576294864667068, 9.589697873088028, 9.602934378950419, 9.616008689547046, 9.628924944380643, 9.641687123837617, 9.654299057305805, 9.666764430778608, 9.679086793984114, 9.691269567074508, 9.703316046908013, 9.715229412952873, 9.727012732840446, 9.738668967592188, 9.750200976543356, 9.761611521984314, 9.772903273538782, 9.784078812296723, 9.795140634718269, 9.806091156323767, 9.816932715183928, 9.827667575222938, 9.838297929346492, 9.84882590240581, 9.859253554007863, 9.869582881181321, 9.879815820907073, 9.889954252521477, 9.9, 9.909954834128344, 9.91982047456763], [0.0, 6.309573444801933, 6.762433378062415, 7.04226114001237, 7.247796636776956, 7.411344491069478, 7.547708606115841, 7.664958432641344, 7.767996097157338, 7.860030855966229, 7.943282347242816, 8.019351848161373, 8.089433786991753, 8.154443636507333, 8.21509903954877, 8.271973337231158, 8.325532074018732, 8.376158603010033, 8.424172486141028, 8.469842998552984, 8.513399225207847, 8.555037734677597, 8.594928497600737, 8.633219511791959, 8.67004045984223, 8.705505632961241, 8.739716291356507, 8.772762586965454, 8.804725142695762, 8.835676359470229, 8.865681505652134, 8.894799631049143, 8.923084338428023, 8.95058443846453, 8.977344508701224, 9.003405372962773, 9.028804514474343, 9.05357643341992, 9.077752957697912, 9.10136351405914, 9.12443536555481, 9.14699382021059, 9.169062415024055, 9.190663078716549, 9.2118162761254, 9.23254113667427, 9.252855568989153, 9.27277636342039, 9.292319283974864, 9.311499150948377, 9.330329915368075, 9.348824726202954, 9.366995991172013, 9.38485543187039, 9.402414133840812, 9.419682592138262, 9.436670752867396, 9.4533880511138, 9.469843445639476, 9.486045450669236, 9.502002165056764, 9.517721299086176, 9.533210199136082, 9.548475870408183, 9.563524997900371, 9.578363965785066, 9.59299887533659, 9.607435561536404, 9.621679608471888, 9.635736363632674, 9.649610951198177, 9.663308284400852, 9.676833077041483, 9.69018985422558, 9.703382962383449, 9.716416578630735, 9.729294719520968, 9.742021249237082, 9.754599887264648, 9.767034215585772, 9.779327685429287, 9.79148362360977, 9.80350523848518, 9.815395625560399, 9.827157772761716, 9.838794565405264, 9.850308790880502, 9.861703143068246, 9.872980226511103, 9.884142560352878, 9.895192582062146, 9.906132650954108, 9.916965051523727, 9.927691996602169, 9.938315630347766, 9.948838031081765, 9.959261213978507, 9.96958713361894, 9.979817686415696, 9.9899547129175, 10.000000000000002, 10.009955282949738], [0.0, 6.3663313162894095, 6.823264958512738, 7.105609915688381, 7.3129943103877535, 7.478013362088023, 7.615604142769555, 7.7339086920340945, 7.837873233552495, 7.9307358925449005, 8.014736273977748, 8.091490059340416, 8.162202421401865, 8.227797068085827, 8.288998097800915, 8.346384009161634, 8.400424534445088, 8.45150647520891, 8.499952268013708, 8.546033610269694, 8.58998164767636, 8.631994717041495, 8.672244317977274, 8.710879779615158, 8.748031951107992, 8.783816151773918, 8.818334552708308, 8.851678116811824, 8.883928192236835, 8.915157831189827, 8.945432889156713, 8.974812947128672, 9.003352090057042, 9.03109956769481, 9.058100358582557, 9.084395653776332, 9.110023273682268, 9.135018028831324, 9.159412033430291, 9.183234978938806, 9.206514373653306, 9.229275753258213, 9.251542866478555, 9.273337839295847, 9.294681320639196, 9.315592612011308, 9.336089783135519, 9.35618977540004, 9.375908494617137, 9.39526089439883, 9.41426105126895, 9.432922232478267, 9.451256957359616, 9.469277052949938, 9.486993704512143, 9.50441750150965, 9.521558479517465, 9.53842615849464, 9.55502957779187, 9.571377328223813, 9.587477581497527, 9.603338117255113, 9.61896634795965, 9.634369341828249, 9.649553843993807, 9.664526296057675, 9.679292854178286, 9.693859405825773, 9.708231585319266, 9.722414788251827, 9.73641418489751, 9.750234732685838, 9.763881187820662, 9.777358116113154, 9.79066990309201, 9.803820763448181, 9.816814749866172, 9.829655761289239, 9.842347550661646, 9.854893732187278, 9.867297788140554, 9.879563075262467, 9.891692830771811, 9.903690178019133, 9.915558131808663, 9.927299603411441, 9.938917405290935, 9.950414255560808, 9.961792782192877, 9.973055526991944, 9.98420494935287, 9.99524342981412, 10.006173273420865, 10.016996712909833, 10.027715911727164, 10.038332966889678, 10.048849911699254, 10.0592687183193, 10.069591300221663, 10.079819514511753, 10.089955164139086, 10.100000000000001]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha = 0.2\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.09999999999999999, 0.11486983549970349, 0.12457309396155174, 0.1319507910772894, 0.13797296614612148, 0.14309690811052556, 0.1475773161594552, 0.1515716566510398, 0.15518455739153597, 0.15848931924611134, 0.16153942662021778, 0.16437518295172257, 0.16702776523348103, 0.16952182030724353, 0.17187719275874785, 0.17411011265922482, 0.1762340347832317, 0.17826024579660033, 0.18019831273171422, 0.18205642030260805, 0.1838416287252544, 0.18556007362580842, 0.18721712305548577, 0.1888175022589804, 0.19036539387158785, 0.1918645191625306, 0.19331820449317627, 0.19472943612303362, 0.1961009057454548, 0.197435048583482, 0.19873407546644578, 0.19999999999999998, 0.20123466170855583, 0.2024397458499885, 0.2036168004640398, 0.20476725110792193, 0.2058924136478517, 0.20699350540816142, 0.20807165492618437, 0.20912791051825463, 0.21016324782757848, 0.2111785764966754, 0.2121747460841898, 0.21315255132709487, 0.2141127368338324, 0.21505600128111396, 0.2159830011764466, 0.21689435423953973, 0.217790642448278, 0.21867241478865562, 0.219540189742749, 0.22039445754429604, 0.2212356822276117, 0.222064303492292, 0.22288073840335185, 0.22368538294402895, 0.2244786134364092, 0.22526078784323253, 0.22603224696268157, 0.22679331552660545, 0.22754430321145305, 0.22828550557016292, 0.22901720489235827, 0.22973967099940698, 0.23045316198021407, 0.2311579248730029, 0.23185419629780504, 0.23254220304389966, 0.2332221626160242, 0.23389428374280205, 0.23455876685050028, 0.23521580450493473, 0.23586558182407358, 0.23650827686365636, 0.23714406097793117, 0.2377730991574249, 0.23839555034548998, 0.2390115677352187, 0.23962129904817697, 0.24022488679628626, 0.2408224685280692, 0.2414141770603736, 0.24200014069659626, 0.24258048343234653, 0.24315532514941224, 0.24372478179882237, 0.24428896557373941, 0.2448479850728549, 0.24540194545491306, 0.24595094858493635, 0.24649509317268692, 0.24703447490385586, 0.24756918656443666, 0.24809931815870692, 0.2486249570212102, 0.24914618792310347, 0.24966309317320873, 0.2501757527140844, 0.25068424421341, 0.251188643150958, 0.25168902290140654], [0.0, 0.17411011265922482, 0.19999999999999998, 0.21689435423953973, 0.22973967099940698, 0.24022488679628623, 0.24914618792310347, 0.25694703142468783, 0.2639015821545789, 0.27019200770412266, 0.27594593229224296, 0.281256477677527, 0.2861938162210511, 0.2908122302201994, 0.29515463231891037, 0.2992555739477689, 0.3031433133020796, 0.3068412765049822, 0.31036911478307194, 0.3137434853072099, 0.3169786384922227, 0.32008686688809423, 0.32307885324043556, 0.32596394386926586, 0.32875036590344514, 0.33144540173399867, 0.33405553046696207, 0.33658654363385987, 0.3390436406144871, 0.34143150791917165, 0.34375438551749576, 0.34601612268689763, 0.34822022531844965, 0.3503698962101765, 0.3524680695664634, 0.3545174406810487, 0.35652049159320065, 0.3584795133590718, 0.3603966254634285, 0.36227379280389316, 0.36411284060521604, 0.3659154675608828, 0.36768325745050884, 0.3694176894416071, 0.3711201472516169, 0.37279192731913513, 0.3744342461109715, 0.37604824667308606, 0.3776350045179608, 0.37919553292794633, 0.3807307877431757, 0.38224167169337625, 0.3837290383250613, 0.3851936955688993, 0.38663640898635254, 0.3880579047297881, 0.3894588722460673, 0.3908399667499979, 0.3922018114909096, 0.39354499983290214, 0.394870097166964, 0.39617764267110905, 0.3974681509328916, 0.3987421134470927, 0.39999999999999997, 0.4012422599504966, 0.40246932341711167, 0.4036816023792486, 0.40487949169997706, 0.40606337007704024, 0.40723360092807964, 0.40839053321549457, 0.40953450221584387, 0.4106658302382306, 0.4117848272957035, 0.4128917917333368, 0.41398701081632283, 0.41507076128111164, 0.41614330985236875, 0.41720491372827895, 0.4182558210365093, 0.41929627126294755, 0.420326495655157, 0.42134671760232634, 0.42235715299335075, 0.4233580105545461, 0.4243494921683795, 0.42533179317449266, 0.4263051026541897, 0.4272696036994786, 0.4282254736676648, 0.4291728844224264, 0.4301120025622279, 0.43104298963686716, 0.4319660023528933, 0.4328811927685784, 0.43378870847907947, 0.43468869279237915, 0.435581284896556, 0.43646662001889447, 0.43734482957731124, 0.4382160413245411], [0.0, 0.2408224685280692, 0.27663237344451835, 0.30000000000000004, 0.3177671523146437, 0.332269902974487, 0.34460950649911054, 0.35539933576267324, 0.3650186051359235, 0.3737192818846552, 0.38167789096181765, 0.38902323483289747, 0.39585237323186834, 0.40224038736253726, 0.4082466323576216, 0.41391889843836444, 0.4192962712629476, 0.42441115295159476, 0.42929072433157667, 0.43395802496644426, 0.43843276548657767, 0.4427319484783656, 0.4468703499081746, 0.45086089724945383, 0.45471496995311944, 0.45844264074473967, 0.4620528712767166, 0.46555367217460797, 0.46895223502227934, 0.47225504202210655, 0.4754679577383341, 0.4785963063447307, 0.4816449370561384, 0.4846182798606534, 0.4875203932378919, 0.49035500521537373, 0.49312554885516774, 0.4958351930587798, 0.49848686941671677, 0.5010832957004432, 0.5036269964912325, 0.5061203213571384, 0.5085654609217307, 0.5109644611131087, 0.5133192358364697, 0.5156315782762437, 0.5179031710029348, 0.5201355950341274, 0.5223303379776745, 0.5244888013670841, 0.5266123072839791, 0.5287021043496952, 0.5307593731572212, 0.5327852312054494, 0.534780737389801, 0.5367468960965404, 0.5386846609422752, 0.5405949381951427, 0.5424785899098494, 0.5443364368049916, 0.5461692609078241, 0.5479778079888159, 0.5497627898058493, 0.5515248861757633, 0.5532647468890367, 0.5549829934817414, 0.5566802208774253, 0.5583569989102893, 0.5600138737398741, 0.5616513691664573, 0.5632699878554623, 0.5648702124783733, 0.5664525067769413, 0.568017316556827, 0.5695650706162577, 0.5710961816147636, 0.5726110468866044, 0.574110049203085, 0.5755935574875919, 0.5770619274868466, 0.5785155024015763, 0.5799546134795288, 0.5813795805735156, 0.5827907126669437, 0.5841883083691009, 0.5855726563822677, 0.5869440359425744, 0.5883027172363645, 0.5896489617936876, 0.5909830228604276, 0.592305145750446, 0.5936155681790288, 0.5949145205788193, 0.5962022263993374, 0.5974789023911063, 0.5987447588753295, 0.6000000000000001, 0.6012448239832547, 0.602479423344736, 0.6037039851256676, 0.6049186910983, 0.6061237179653447], [0.0, 0.3031433133020796, 0.34822022531844965, 0.37763500451796084, 0.4, 0.4182558210365093, 0.43378870847907947, 0.4473707658880579, 0.459479341998814, 0.47043160900986947, 0.4804497735925725, 0.48969597014570987, 0.498292375846207, 0.5063335016631935, 0.5138940628493757, 0.5210342169394704, 0.5278031643091577, 0.5342416922078281, 0.5403840154082454, 0.5462591357293617, 0.551891864584486, 0.557303604546244, 0.5625129553550541, 0.5675361898992312, 0.5723876324421022, 0.5770799623628855, 0.5816244604403988, 0.5860312103167044, 0.5903092646378209, 0.59446678309216, 0.5985111478955379, 0.6024490610292391, 0.6062866266041592, 0.6100294210155475, 0.6136825530099644, 0.6172507153663745, 0.6207382295661439, 0.624149084569721, 0.6274869706144199, 0.6307553087857052, 0.6339572769844454, 0.6370958328077823, 0.6401737337761886, 0.6431935552698874, 0.6461577064808713, 0.6490684446398418, 0.6519278877385317, 0.6547380259355499, 0.6575007318068904, 0.6602177695795954, 0.6628908034679974, 0.6655214052158417, 0.6681110609339243, 0.6706611773112422, 0.6731730872677197, 0.6756480551080615, 0.6780872812289743, 0.6804919064256982, 0.6828630158383433, 0.6852016425738122, 0.6875087710349915, 0.6897853399853292, 0.6920322453737955, 0.6942503429425073, 0.6964404506368993, 0.6986033508362294, 0.7007397924203531, 0.7028504926870738, 0.7049361391329269, 0.7069973911089799, 0.7090348813620976, 0.7110492174711066, 0.7130409831864014, 0.7150107396807244, 0.7169590267181438, 0.7188863637476047, 0.720793250926857, 0.7226801700820457, 0.7245475856077863, 0.7263959453121283, 0.7282256812104322, 0.730037210271847, 0.7318309351217657, 0.7336072447033564, 0.7353665149010177, 0.7371091091283732, 0.7388353788832142, 0.7405456642716104, 0.7422402945032338, 0.7439195883597857, 0.7455838546382704, 0.7472333925707314, 0.7488684922219431, 0.7504894348664403, 0.7520964933461722, 0.7536899324099681, 0.7552700090359217, 0.7568369727377231, 0.7583910658558928, 0.759932523834808, 0.7614615754863515, 0.7629784432409538], [0.0, 0.3623898318388477, 0.4162766037009365, 0.4514402257237171, 0.47817624989501845, 0.49999999999999994, 0.518568644668324, 0.5348051878625344, 0.5492802716530588, 0.5623730565710473, 0.5743491774985174, 0.585402456482446, 0.5956789490835458, 0.6052916375537973, 0.6143298395415735, 0.6228654698077586, 0.6309573444801932, 0.6386542222937699, 0.6459970049778166, 0.6530203624849001, 0.6597539553864471, 0.6662233691872481, 0.6724508387726091, 0.6784558174143035, 0.6842554289186316, 0.6898648307306073, 0.6952975083515085, 0.7005655161767013, 0.705679676106998, 0.7106497425654109, 0.7154845405526277, 0.7201920818893416, 0.7247796636776954, 0.7292539521671095, 0.7336210545607641, 0.737886580797276, 0.7420556969510294, 0.7461331715873947, 0.7501234161659723, 0.7540305203913071, 0.7578582832551989, 0.7616102403894225, 0.7652896882459744, 0.7688997055389976, 0.7724431723144727, 0.7759227869576798, 0.7793410814019791, 0.7827004347638213, 0.7860030855966227, 0.7892511429290607, 0.7924465962305567, 0.7955913244274354, 0.798687104076915, 0.8017356167921695, 0.8047384559998255, 0.8076971331010889, 0.8106130830989491, 0.8134876697463804, 0.8163221902639539, 0.8191178796696308, 0.8218759147586128, 0.8245974177668625, 0.8272834597481767, 0.8299350636914465, 0.832553207401873, 0.8351388261674052, 0.8376928152294452, 0.8402160320749276, 0.8427092985651398, 0.8451734029151341, 0.8476091015362177, 0.8500171207528029, 0.8523981584038258, 0.85475288533798, 0.8570819468111608, 0.8593859637937393, 0.8616655341946088, 0.8639212340083167, 0.8661536183910526, 0.868363222670751, 0.8705505632961241, 0.872716138729032, 0.874860430284226, 0.8769839029201701, 0.8790870059843445, 0.8811701739161585, 0.883233826910351, 0.885278371543535, 0.8873042013663259, 0.8893116974633203, 0.8913012289830017, 0.8932731536395112, 0.8952278181880637, 0.8971655588756652, 0.8990867018686658, 0.9009915636585711, 0.9028804514474342, 0.9047536635140568, 0.9066114895621419, 0.908454211051463, 0.9102821015130401, 0.9120954268492462], [0.0, 0.41929627126294755, 0.4816449370561384, 0.5223303379776745, 0.5532647468890367, 0.5785155024015763, 0.6000000000000001, 0.6187861838865271, 0.6355343046292874, 0.6506830627186192, 0.664539805948974, 0.6773287924381185, 0.6892190129982211, 0.7003411915978159, 0.7107986715253464, 0.7206746603888587, 0.730037210271847, 0.7389427365423367, 0.7474385637693104, 0.7555648061628231, 0.7633557819236353, 0.7708410942740636, 0.7780464696657949, 0.7849944161374159, 0.7917047464637366, 0.7981949982785916, 0.8044807747250744, 0.8105760231123681, 0.8164932647152433, 0.8222437857035593, 0.827837796876729, 0.8332845681596994, 0.8385925425258951, 0.8437694330325811, 0.8488223059031895, 0.853757652010635, 0.8585814486631533, 0.8632992132387264, 0.8679160499328885, 0.8724366906605983, 0.8768655309731552, 0.8812066617061443, 0.8854638969567313, 0.8896407988926346, 0.8937406998163493, 0.897766721843307, 0.9017217944989075, 0.9056086704946488, 0.9094299399062389, 0.9131880429452479, 0.9168852814894793, 0.9205238295149467, 0.9241057425534334, 0.9276329662835194, 0.9311073443492158, 0.9345306254885788, 0.9379044700445587, 0.9412304559216298, 0.9445100840442131, 0.9477447833663809, 0.9509359154766681, 0.9540847788368781, 0.9571926126894615, 0.960260600664283, 0.9632898741122768, 0.9662815151905984, 0.9692365597213068, 0.9721559998433715, 0.9750407864757838, 0.9778918316077975, 0.9807100104307476, 0.9834961633244984, 0.9862510977103356, 0.9889755897809971, 0.9916703861175596, 0.9943362052019961, 0.9969737388334335, 0.9995836534554224, 1.0021665914008862, 1.004723172060843, 1.007253992982465, 1.0097596309015795, 1.0122406427142767, 1.014697566391915, 1.0171309218434612, 1.0195412117287816, 1.0219289222262173, 1.0242945237575152, 1.026638471672939, 1.028961206899183, 1.0312631565524875, 1.0335447345192048, 1.0358063420058696, 1.0380483680606931, 1.040271190068255, 1.0424751742190403, 1.044660675955349, 1.0468280403950028, 1.048977602734168, 1.0511096886305296, 1.0532246145679582, 1.0553226882037439], [0.0, 0.4743276393803367, 0.5448593790858196, 0.590884615890877, 0.6258790724605868, 0.654443913303929, 0.6787481862669054, 0.7, 0.7189462609625462, 0.7360832477580963, 0.7517586466500455, 0.7662261489562102, 0.7796769250220154, 0.7922588559417013, 0.8040888484979244, 0.8152610310457598, 0.825852387298946, 0.8359267369720245, 0.8455376158406002, 0.8547304029835368, 0.8635439207617047, 0.8720116577308621, 0.8801627168617118, 0.8880225603048657, 0.8956136012019356, 0.9029556789481827, 0.9100664445520651, 0.916961675864935, 0.923655537541026, 0.9301607970258747, 0.936489005255451, 0.9426506488043291, 0.9486552787606733, 0.9545116204971992, 0.9602276676578037, 0.9658107630228504, 0.9712676684042124, 0.9766046253190532, 0.9818274078731416, 0.9869413690309704, 0.99195148124666, 0.9968623722655997, 1.001678356773679, 1.0064034644623607, 1.0110414649887696, 1.0155958902365498, 1.0200700542224543, 1.024467070943044, 1.028789870413634, 1.0330412131161866, 1.0372237030430085, 1.0413397994978935, 1.0453918277949577, 1.0493819889772136, 1.0533123686613752, 1.0571849451020823, 1.0610015965572788, 1.064764108026631, 1.0684741774263533, 1.0721334212564202, 1.0757433798097462, 1.0793055219673209, 1.0828212496184209, 1.086291901740752, 1.0897187581716392, 1.093103043098093, 1.0964459282906869, 1.0997485361036305, 1.1030119422611586, 1.1062371784483576, 1.1094252347227795, 1.1125770617616058, 1.1156935729577244, 1.1187756463768246, 1.1218241265864923, 1.1248398263672872, 1.1278235283148808, 1.1307759863415245, 1.1336979270843972, 1.136590051227715, 1.1394530347449108, 1.1422875300666449, 1.1450941671799364, 1.1478735546632586, 1.150626280662058, 1.1533529138087892, 1.1560540040912306, 1.1587300836725616, 1.1613816676663917, 1.1640092548697105, 1.1666133284564741, 1.1691943566343672, 1.1717527932670697, 1.174289078464194, 1.1768036391409056, 1.179296889549083, 1.181769231781754, 1.1842210562524114, 1.186652742150705, 1.189064657875906, 1.191457161449437, 1.1938306009076767], [0.0, 0.5278031643091577, 0.6062866266041593, 0.6575007318068904, 0.6964404506368993, 0.7282256812104322, 0.7552700090359217, 0.7789177444921346, 0.8, 0.8190690044316878, 0.8365116420730186, 0.8526102053083794, 0.867577416958159, 0.8815778301771843, 0.8947415317761157, 0.9071732621064218, 0.9189586839976281, 0.9301688121755988, 0.9408632180197389, 0.9510923966296996, 0.9608995471851451, 0.9703219337293861, 0.9793919402914197, 0.9881378996154235, 0.9965847516924139, 1.0047545726038323, 1.012667003326387, 1.0203396005006329, 1.0277881256987516, 1.0350267857634294, 1.042068433878941, 1.0489247388724505, 1.0556063286183155, 1.0621229121845868, 1.0684833844156563, 1.074695915914266, 1.0807680308164909, 1.0867066743058615, 1.0925182714587236, 1.0982087787308328, 1.1037837291689718, 1.1092482722488564, 1.1146072090924881, 1.1198650236972745, 1.1250259107101084, 1.1300938001979068, 1.1350723797984623, 1.1399651145791705, 1.1447752648842044, 1.149505902411255, 1.154159924725771, 1.1587400683925582, 1.1632489208807977, 1.1676889313782874, 1.1720624206334087, 1.1763715899285072, 1.180618529275642, 1.1848052249146899, 1.18893356618432, 1.1930053518281234, 1.1970222957910759, 1.2009860325552737, 1.2048981220584785, 1.2087600542342543, 1.2125732532083187, 1.2163390811820787, 1.220058842031095, 1.2237337846433811, 1.2273651060199289, 1.2309539541576253, 1.234501430732749, 1.2380085936014802, 1.241476459132288, 1.244906004383666, 1.248298169139442, 1.2516538578127594, 1.2549739412288399, 1.2582592582957273, 1.2615106175714101, 1.2647287987349878, 1.267914553968891, 1.2710686092585748, 1.2741916656155647, 1.277284400229249, 1.2803474675523772, 1.283381500324819, 1.2863871105397746, 1.2893648903563057, 1.2923154129617425, 1.2952392333872644, 1.2981368892796836, 1.3010089016322481, 1.3038557754770634, 1.3066780005415388, 1.3094760518711, 1.312250390420231, 1.3150014636137808, 1.3177297058803163, 1.3204355391591909, 1.3231193733828748, 1.325781606935995, 1.3284226270924244], [0.0, 0.5799546134795288, 0.666192910476876, 0.7224674055842076, 0.7652547003754745, 0.8001805825189799, 0.829897120333555, 0.8558814535160307, 0.8790468154750565, 0.9, 0.9191661188401216, 0.9368553572723312, 0.9533014569439311, 0.9686852302633299, 0.9831496177263357, 0.9968097089234609, 1.0097596309015797, 1.02207741524647, 1.0338285194973316, 1.045068428099846, 1.055844608680657, 1.0661980072880195, 1.0761642077688864, 1.0857743423839363, 1.0950558154077703, 1.10403288422675, 1.112727130513411, 1.1211578456539657, 1.1293423485982057, 1.1372962499459074, 1.1450336728854529, 1.1525674392235408, 1.1599092269590576, 1.1670697044986924, 1.1740586455732414, 1.1808850281106056, 1.1875571196956047, 1.194082551755071, 1.2004683842176302, 1.2067211620876117, 1.2128469651239586, 1.218851451614457, 1.224739897072865, 1.2305172285537347, 1.2361880551708073, 1.2417566953150934, 1.247227200994415, 1.2526033796543472, 1.2578888137888427, 1.2630868786054934, 1.2682007579738996, 1.2732334588547842, 1.2781878243813263, 1.2830665457419441, 1.28787217299473, 1.292607124927479, 1.297273698063247, 1.3018740748993327, 1.3064103314571607, 1.310884444211514, 1.3152982964597328, 1.3196536841846698, 1.3239523214592266, 1.328195845435097, 1.332385820953752, 1.336523744813703, 1.3406110497245236, 1.3446491079750031, 1.3486392348400293, 1.3525826917483612, 1.3564806892312802, 1.360334389670168, 1.3641449098593583, 1.3679133233990477, 1.3716406629317122, 1.375327922234219, 1.3789760581767403, 1.382585992558582, 1.3861586138301498, 1.3896947787094807, 1.3931953137010378, 1.3966610165238238, 1.4000926574552752, 1.4034909805968607, 1.406856705066838, 1.4101905261251653, 1.4134931162351854, 1.4167651260663197, 1.4200071854416902, 1.4232199042342852, 1.4264038732150022, 1.429559664855661, 1.432687834089841, 1.4357889190341921, 1.4388634416726753, 1.4419119085060044, 1.4449348111684153, 1.4479326270137185, 1.4509058196724698, 1.4538548395819604, 1.4567801244906116, 1.4596820999382552], [0.0, 0.6309573444801932, 0.7247796636776955, 0.7860030855966228, 0.8325532074018731, 0.8705505632961241, 0.9028804514474343, 0.9311499150948377, 0.956352499790037, 0.9791483623609768, 1.0, 1.0192448764914566, 1.0371372893366482, 1.0538739520617835, 1.0696103757250688, 1.0844717711976986, 1.0985605433061179, 1.111961585938579, 1.1247461131420948, 1.136974488810138, 1.148698354997035, 1.1599622586540013, 1.1708049129648923, 1.1812601880431086, 1.1913578981670916, 1.2011244339814313, 1.2105832751075947, 1.2197554094669347, 1.2286596790831472, 1.2373130673931283, 1.2457309396155174, 1.2539272451403496, 1.2619146889603865, 1.2697048776900042, 1.2773084445875398, 1.2847351571234393, 1.2919940099556333, 1.2990933056386602, 1.3060407249698005, 1.3128433885382442, 1.3195079107728942, 1.3260404475662166, 1.3324467383744967, 1.3387321435503967, 1.3449016775452187, 1.3509600385206135, 1.356911634828607, 1.362760608751532, 1.3685108578372633, 1.3741660541180074, 1.379729661461215, 1.3852049512676268, 1.3905950167030172, 1.3959027856259776, 1.4011310323534027, 1.4062823883876352, 1.4113593522139962, 1.4163642982643259, 1.421299485130822, 1.426167063104648, 1.4309690811052556, 1.4357074930589433, 1.4403841637786836, 1.445000874391587, 1.449559327355391, 1.454061151100997, 1.4585079043342193, 1.4629010800265252, 1.4672421091215284, 1.4715323639813442, 1.4757731615945522, 1.4799657665654045, 1.484111393902059, 1.488211211619932, 1.4922663431747896, 1.4962778697388448, 1.500246832331945, 1.5041742338188457, 1.5080610407826143, 1.51190818528332, 1.5157165665103982, 1.5194870523363546, 1.5232204807788452, 1.5269176613775752, 1.5305793764919489, 1.534206382524911, 1.5377994110779951, 1.5413591700421998, 1.5448863446289454, 1.5483815983450517, 1.5518455739153598, 1.5552788941563636, 1.5586821628039584, 1.562055965298185, 1.5654008695276431, 1.5687174265360497, 1.5720061711932456, 1.5752676228327884, 1.5785022858581217, 1.5817106503191745, 1.5848931924611136, 1.5880503752468602], [0.0, 0.6809483127522302, 0.7822042066964934, 0.8482783814744369, 0.8985166855040226, 0.93952458502622, 0.9744159813792331, 1.0049252443928347, 1.0321246385758591, 1.0567266252096805, 1.079230345298891, 1.1, 1.1193100348931466, 1.1373727491851455, 1.1543559751290424, 1.1703948440965921, 1.1855998744839988, 1.200062686351595, 1.2138601360599284, 1.2270573701545953, 1.2397101223077183, 1.2518664689408392, 1.2635681904967386, 1.274851840629597, 1.2857495958134313, 1.296289937632715, 1.3064982060074317, 1.31639705173919, 1.3260068097117295, 1.3353458089655157, 1.3444306321107666, 1.3532763337525067, 1.3618966255044604, 1.3703040335770693, 1.3785100337054, 1.3865251672399543, 1.3943591414885168, 1.402020916819889, 1.4095187825835718, 1.4168604235354954, 1.4240529781680489, 1.431103090107184, 1.438016953548289, 1.4448003535466192, 1.451458701850184, 1.4579970688576047, 1.4644202121961603, 1.4707326023426428, 1.4769384456489911, 1.4830417050837916, 1.489046118957909, 1.4949552178662942, 1.5007723400473143, 1.5065006453348075, 1.5121431278557544, 1.5177026276073367, 1.5231818410307303, 1.5285833306848298, 1.533909534110873, 1.5391627719683343, 1.5443452555132617, 1.5494590934822086, 1.554506298437923, 1.5594887926268317, 1.5644084133929868, 1.569266918188432, 1.5740659892157813, 1.5788072377351472, 1.5834922080643001, 1.5881223812980794, 1.5926991787705245, 1.5972239652809193, 1.6016980521029374, 1.6061226997942601, 1.6104991208224415, 1.6148284820213425, 1.6191119068911721, 1.6233504777540075, 1.6275452377756257, 1.631697192863537, 1.6358073134502664, 1.639876536170158, 1.6439057654372957, 1.6478958749314956, 1.651847708998767, 1.655762083972122, 1.6596397894181358, 1.6634815893142552, 1.667288223161438, 1.6710604070363788, 1.6747988345872293, 1.6785041779764496, 1.6821770887741383, 1.6858181988049525, 1.6894281209515025, 1.6930074499168886, 1.6965567629488738, 1.7000766205279934, 1.7035675670217494, 1.707030131306896, 1.7104648273616692, 1.7138721548297022], [0.0, 0.730037210271847, 0.8385925425258951, 0.9094299399062389, 0.9632898741122768, 1.007253992982465, 1.0446606759553492, 1.0773693218845504, 1.1065294937780734, 1.1329050135538825, 1.1570310048031527, 1.1792979235873753, 1.2000000000000002, 1.2193648376899149, 1.237572367773054, 1.2547674631095278, 1.2710686092585748, 1.2865740310810212, 1.3013661254372384, 1.315514735223545, 1.3290796118979482, 1.3421122976641735, 1.354657584876237, 1.3667546623054792, 1.378438025996442, 1.3897382107431535, 1.4006823831956317, 1.4112948270296084, 1.421597343050693, 1.4316095816219423, 1.4413493207777177, 1.4508327003947878, 1.460074420543694, 1.4690879104371297, 1.4778854730846733, 1.4864784097524693, 1.4948771275386208, 1.503091232756148, 1.5111296123256464, 1.5190005049895805, 1.5267115638472706, 1.5342699114571619, 1.5416821885481273, 1.5489545972143939, 1.55609293933159, 1.5631026508184114, 1.5699888322748317, 1.5767562764499412, 1.5834094929274733, 1.5899527303625416, 1.596389996557183, 1.6027250766234844, 1.6089615494501488, 1.6151028026603447, 1.6211520462247362, 1.627112324873123, 1.6329865294304868, 1.6387774071880852, 1.6444875714071185, 1.650119510041132, 1.655675593753458, 1.6611580832974044, 1.666569136319399, 1.6719108136387322, 1.6771850850517902, 1.6823938347036156, 1.6875388660651622, 1.6926219065507078, 1.697644611806379, 1.7026085696976934, 1.70751530402127, 1.712366277963438, 1.7171628973263067, 1.7219065135399272, 1.726598426477453, 1.7312398870886565, 1.735832099865777, 1.7403762251544315, 1.7448733813211965, 1.7493246467884709, 1.7537310619463107, 1.758093630950113, 1.7624133234122885, 1.766691075995376, 1.7709277939134624, 1.7751243523482079, 1.7792815977852692, 1.7834003492764798, 1.7874813996326984, 1.7915255165518869, 1.795533443686614, 1.7995059016548736, 1.8034435889978153, 1.8073471830877175, 1.8112173409892978, 1.8150547002772215, 1.8188598798124778, 1.822633480480095, 1.8263760858904958, 1.8300882630466424, 1.8337705629789587, 1.8374235213498984], [0.0, 0.7783137122039472, 0.8940476808803098, 0.9695694720194644, 1.026991100316126, 1.0738625146497733, 1.1137428575641026, 1.1486144877716113, 1.179702987529729, 1.2078226894013284, 1.233544104071174, 1.2572835080007883, 1.2793545883735817, 1.3000000000000003, 1.3194115726290119, 1.3377437593925443, 1.3551228811604874, 1.3716536582881662, 1.3874239364434007, 1.402508177151083, 1.4169700831628491, 1.4308646051077254, 1.4442394974054071, 1.457136540334583, 1.469592511122642, 1.4816399637936208, 1.4933078614961455, 1.5046220937568582, 1.5156059030429971, 1.5262802391730128, 1.5366640558217652, 1.546774560177088, 1.5566274244078944, 1.5662369657849158, 1.5756163009012816, 1.584777478362572, 1.5937315934760452, 1.602488887808901, 1.6110588359633393, 1.6194502215001727, 1.6276712036091765, 1.6357293758552074, 1.6436318181107266, 1.6513851426071566, 1.6589955348913359, 1.666468790352869, 1.6738103468884062, 1.6810253141858964, 1.688118500042541, 1.695094434072018, 1.7019573891075988, 1.708711400566379, 1.7153602840047628, 1.7219076510654527, 1.7283569239906975, 1.7347113488546964, 1.7409740076492866, 1.747147829340865, 1.7532356000025209, 1.7592399721132406, 1.7651634731055337, 1.7710085132336657, 1.7767773928266837, 1.7824723089834333, 1.7880953617606197, 1.7936485598995795, 1.7991338261326801, 1.804553002106073, 1.8099078529518156, 1.8152000715391041, 1.820431282431436, 1.8256030455739303, 1.8307168597327366, 1.8357741657063855, 1.840776349327113, 1.8457247442685283, 1.850620634674526, 1.8554652576230128, 1.8602598054368322, 1.8650054278531878, 1.8697032340619053, 1.8743542946219978, 1.8789596432652036, 1.8835202785944534, 1.8880371656845774, 1.8925112375919684, 1.8969433967793847, 1.9013345164615938, 1.9056854418771034, 1.9099969914908395, 1.9142699581322395, 1.9185051100729178, 1.9227031920477289, 1.9268649262227826, 1.9309910131137134, 1.9350821324572494, 1.9391389440389288, 1.9431620884796001, 1.947152187983157, 1.9511098470478, 1.9550356531429474, 1.95893017735378], [0.0, 0.825852387298946, 0.9486552787606733, 1.028789870413634, 1.0897187581716392, 1.1394530347449108, 1.1817692317817543, 1.218770788614574, 1.2517581449211739, 1.2815953719373026, 1.3088878266078583, 1.3340772111720975, 1.357496372533811, 1.379402786632782, 1.4, 1.4194518996205303, 1.4378925219250926, 1.455432983490574, 1.4721664955161928, 1.4881720675672823, 1.5035172933000913, 1.518260479676778, 1.5324522979124207, 1.5461370801861345, 1.5593538500440307, 1.5721371498795496, 1.5845177118834026, 1.5965230068903544, 1.6081776969958492, 1.6195040116136943, 1.6305220620915197, 1.6412501066161314, 1.651704774597892, 1.661901257793066, 1.671853473944049, 1.6815742075740039, 1.6910752316812006, 1.700367413378204, 1.7094608059670737, 1.7183647295003186, 1.7270878415234092, 1.735638199409057, 1.7440233154617246, 1.7522502057817582, 1.760325433723424, 1.7682551486533145, 1.7760451206097312, 1.7837007713755948, 1.7912272024038713, 1.7986292199728153, 1.8059113578963657, 1.8130778980711282, 1.8201328891041306, 1.827080163233841, 1.83392335172987, 1.8406658989336, 1.8473110750820523, 1.853861988040158, 1.8603215940517497, 1.866692707606755, 1.872978010510902, 1.879180060234537, 1.8853012976086585, 1.891344053928859, 1.8973105575213467, 1.9032029398195047, 1.9090232409943984, 1.9147734151782072, 1.9204553353156073, 1.9260707976746656, 1.931621526045701, 1.9371091756538252, 1.942535336808425, 1.9479015383106602, 1.9532092506381067, 1.9584598889239127, 1.9636548157462834, 1.9687953437426895, 1.9738827380619408, 1.9789182186661158, 1.9839029624933204, 1.9888381054913122, 1.9937247445311996, 1.9985639392096481, 2.003356713547358, 2.0081040575909355, 2.0128069289247215, 2.0174662540986272, 2.022082929977539, 2.0266578250174567, 2.0311917804730997, 2.035685611541396, 2.040140108444909, 2.0445560374589813, 2.0489341418860882, 2.0532751429806426, 2.057579740827268, 2.061848615175336, 2.066082426232373, 2.0702818154187663, 2.074447406086017, 2.0785798042006567], [0.0, 0.8727161387290321, 1.0024875929374033, 1.0871694955165432, 1.1515558489121325, 1.204112342640346, 1.2488298111028098, 1.2879310552267333, 1.3227903093325808, 1.3543206771711513, 1.3831618672225916, 1.409780646524983, 1.4345287496850556, 1.4576782633510283, 1.4794442844885438, 1.4999999999999998, 1.5194870523363546, 1.5380228634865991, 1.5557059340049721, 1.5726197569270821, 1.5888357615732185, 1.6044155635876032, 1.6194127095699042, 1.6338740473694158, 1.6478408149591766, 1.661349514872435, 1.674432623226261, 1.6871191697131422, 1.699435215901756, 1.7114042526343916, 1.7230475324955525, 1.7343843497496063, 1.7454322774580642, 1.7562073694473386, 1.7667243332348856, 1.776996678813366, 1.7870368472506373, 1.796856322323538, 1.8064657278179765, 1.8158749126613922, 1.8250930256796172, 1.8341285814683692, 1.8429895186247207, 1.8516832513840693, 1.8602167155442406, 1.868596409423276, 1.8768284304855953, 1.8849185081781648, 1.8928720334405797, 1.900694085287764, 1.9083894548090883, 1.9159626668813097, 1.9234179998533762, 1.9307595034276441, 1.93799101493345, 1.9451161741644873, 1.9521384369303783, 1.9590610874547005, 1.965887249736056, 1.9726198979751843, 1.9792618661593413, 1.985815856884874, 1.9922844494899752, 1.998670107561745, 2.0049751858748066, 2.011201936812686, 2.017352516317828, 2.0234289894114346, 2.029433335320147, 2.0353674522429106, 2.0412331617881083, 2.047032213108119, 2.052766286755895, 2.0584369982858206, 2.0640459016190706, 2.0695944921918223, 2.0750842099030313, 2.080516441876986, 2.0858925250545255, 2.091213748625597, 2.096481356314738, 2.101696548530104, 2.106860484385761, 2.11197428360616, 2.117039028320994, 2.1220557647579734, 2.1270255048404416, 2.131949227696233, 2.136827881083656, 2.1416623827400425, 2.1464536216578836, 2.151202459293203, 2.1559097307104707, 2.1605762456680253, 2.1652027896477235, 2.1697901248322213, 2.1743389910330864, 2.1788501065726926, 2.1833241691226486, 2.187761856501329, 2.1921638274328883, 2.1965307222699844], [0.0, 0.9189586839976281, 1.0556063286183155, 1.1447752648842044, 1.2125732532083187, 1.267914553968891, 1.3150014636137808, 1.3561745624579484, 1.3928809012737988, 1.4260819663728028, 1.4564513624208644, 1.4844805890064676, 1.5105400180718433, 1.5349161533002453, 1.5578354889842692, 1.579480388667856, 1.6000000000000003, 1.6195179667999084, 1.6381380088633757, 1.6559480432652913, 1.6730232841460375, 1.6894286119734032, 1.705220410616759, 1.720448010248912, 1.7351548339163179, 1.7493793183092452, 1.7631556603543683, 1.7765144279383365, 1.7894830635522319, 1.8020863027458605, 1.8143465242128438, 1.8262840445613033, 1.8379173679952563, 1.8492633989840235, 1.8603376243511975, 1.8711542699424164, 1.8817264360394779, 1.892066214909251, 1.9021847932593994, 1.91209254188175, 1.92179909437029, 1.931313416482989, 1.9406438674587727, 1.9497982543905794, 1.95878388058284, 1.967607588679491, 1.976275799230847, 1.9847945452696554, 1.993169503384828, 2.001406021712675, 2.0095091452076645, 2.017483638505862, 2.025334006652774, 2.0330645139320347, 2.0406792010012658, 2.0481819005156385, 2.0555762513975036, 2.062865711891349, 2.070053571526859, 2.0771429620985273, 2.084136867757882, 2.091038134303542, 2.097849477744901, 2.104573492206967, 2.111212657236631, 2.1177693445642976, 2.1242458243691735, 2.1306442710915867, 2.1369667688313125, 2.1432153163670242, 2.149391831828532, 2.155498157050422, 2.1615360616329817, 2.167507246733855, 2.1734133486117235, 2.1792559419413293, 2.185036542917447, 2.190756612163818, 2.196417557461665, 2.202020736311148, 2.207567458337944, 2.213058987556147, 2.218496544497713, 2.2238813082178495, 2.2292144181849762, 2.2344969760631925, 2.239730047394549, 2.2449146631878545, 2.2500518214202163, 2.255142488457046, 2.260187600395814, 2.265188064338451, 2.2701447595969246, 2.2750585388361797, 2.2799302291583414, 2.284760633131782, 2.289550529768409, 2.294300675452291, 2.29901180482251, 2.303684631612953, 2.308319849451542, 2.3129181326212547], [0.0, 0.9646263856416863, 1.1080647423733405, 1.2016649337633383, 1.2728321467944697, 1.330923636497959, 1.3803505326715677, 1.423569730895957, 1.4621001932101518, 1.4969511870400218, 1.5288297918718774, 1.558251932392911, 1.585606386199111, 1.6111938947898092, 1.6352522081037575, 1.6579727522511036, 1.6795120867813487, 1.7000000000000004, 1.7195453660637319, 1.7382404710912376, 1.756164266993685, 1.7733848584772296, 1.7899614314106878, 1.8059457674324806, 1.821383447499712, 1.8363148184160583, 1.8507757765263197, 1.8647984087899303, 1.8784115214540555, 1.8916410793029905, 1.9045105731407497, 1.9170413292103972, 1.9292527712833727, 1.9411626438975167, 1.9527872034949598, 1.9641413828755114, 1.9752389333401832, 1.9860925480817022, 1.996713969731776, 2.0071140844592943, 2.01730300460022, 2.02729014146635, 2.037084269709444, 2.0466935843963454, 2.0561257517695957, 2.065387954518693, 2.074486932263548, 2.0834290178487977, 2.0922201699617475, 2.1008660025146324, 2.109371811171205, 2.1177425973463797, 2.125983089964144, 2.134097765221937, 2.1420908645780816, 2.149966411151755, 2.1577282247017515, 2.165379935330207, 2.172924996040161, 2.1803666942608055, 2.1877081624412393, 2.194952387802199, 2.202102221325313, 2.2091603860507707, 2.216129484746681, 2.22301200700672, 2.2298103358267727, 2.236526753706097, 2.2431634483139207, 2.24972251775833, 2.2562059754907016, 2.2626157548756907, 2.268953713453967, 2.275221636922295, 2.281421242853321, 2.287554184175334, 2.2936220524304907, 2.2996263808283066, 2.305568647109771, 2.3114502762360862, 2.317272642914849, 2.3230370739754016, 2.328744850604103, 2.334397210449372, 2.339995349605574, 2.345540424484066, 2.3510335535790667, 2.356475819135426, 2.361868268724776, 2.3672119167361103, 2.3725077457863137, 2.377756708055797, 2.3829597265539837, 2.3881176963190485, 2.3932314855560026, 2.398301936716896, 2.4033298675266765, 2.408316071957959, 2.413261321157755, 2.4181663643289952, 2.4230319295694795, 2.427858724670714], [0.0, 1.0097596309015795, 1.1599092269590576, 1.2578888137888427, 1.332385820953752, 1.3931953137010376, 1.4449348111684155, 1.490176162946172, 1.5305094007509492, 1.5669910139330236, 1.60036116503796, 1.6311599180008391, 1.6597942406671102, 1.686578945724755, 1.7117629070320612, 1.735546507204729, 1.7580936309501132, 1.779540139150122, 1.8000000000000003, 1.8195698175306316, 1.8383322376802433, 1.856358551659581, 1.8737107145446625, 1.890442930749629, 1.9066029138878622, 1.9222328985220838, 1.9373704605266595, 1.9520491881558577, 1.9662992354526716, 1.980147782049959, 1.9936194178469222, 2.0067364669056498, 2.019519261803159, 2.0319863773143556, 2.04415483049294, 2.0560402528192943, 2.067657038994663, 2.079018476104901, 2.090136856199692, 2.101023574793448, 2.1116892173613135, 2.1221436355545285, 2.1323960145760394, 2.1424549329260785, 2.1523284155377733, 2.1620239811665765, 2.1715486847678727, 2.1809091554894415, 2.190111630815541, 2.1991619873239108, 2.2080657684535003, 2.21682820962701, 2.2254542610268224, 2.2339486082841233, 2.2423156913079314, 2.250559721452401, 2.258684697196412, 2.2666944184884694, 2.2745924998918152, 2.2823823826489202, 2.290067345770906, 2.2976505162455396, 2.305134878447082, 2.312523282822191, 2.3198184539181153, 2.327022997812429, 2.334139408997385, 2.3411700767665398, 2.348117291146483, 2.3549832484122475, 2.361770056221211, 2.3684797383969083, 2.37511423939121, 2.3816754284506287, 2.3881651035101426, 2.3945849948357747, 2.4009367684352605, 2.407222029254409, 2.4134423241752234, 2.419599144830442, 2.4256939302479177, 2.431728069337104, 2.4377029032289146, 2.4436197274792537, 2.44947979414573, 2.455284313746241, 2.4610344571074694, 2.466731357110678, 2.4723761103416146, 2.477969778650826, 2.483513390630187, 2.4890079430110283, 2.4944544019888304, 2.4998537044790985, 2.505206759308695, 2.510514448346583, 2.5157776275776853, 2.520997128123259, 2.526173757210987, 2.5313082990977436, 2.5364015159477997, 2.5414541486690347], [0.0, 1.0543938903738732, 1.2111805273913923, 1.3134910917803058, 1.3912810794189334, 1.4547785254123173, 1.508805056431297, 1.5560462051630304, 1.598162287267028, 1.636256491940092, 1.6711016990261411, 1.7032618448285624, 1.7331618863338394, 1.7611305518498404, 1.7874277161701517, 1.8122626193943627, 1.8358063904019342, 1.8582008955137617, 1.879565140644803, 1.9000000000000001, 1.9195917727040788, 1.9384149012429017, 1.9565340792837849, 1.9740059072307778, 1.9908802077752392, 2.007201082368182, 2.023007767844932, 2.038335337156521, 2.053215277240761, 2.067675969147903, 2.081743089720922, 2.0954399498092067, 2.1087877807477464, 2.1218059783695447, 2.1345123119306755, 2.146923103867596, 2.159053385168456, 2.170917030246251, 2.182526874494367, 2.1938948171414965, 2.2050319115710173, 2.215948444905289, 2.2266540083594615, 2.237157559627976, 2.2474674783689226, 2.2575916156882183, 2.267537338390424, 2.2773115686505836, 2.2869208196675728, 2.2963712277806505, 2.3056685814645985, 2.314818347562754, 2.323825695069697, 2.3326955167348946, 2.3414324487240226, 2.350040888545117, 2.358525011421243, 2.366888785269483, 2.3751359844270965, 2.383270202249299, 2.3912948626888686, 2.399213230955362, 2.407028423340906, 2.4147434162900407, 2.4223610547827845, 2.4298840600927827, 2.43731503697597, 2.444656480339503, 2.451910781435685, 2.459080233621178, 2.466167037717836, 2.473173307007973, 2.4801010718937855, 2.4869522842478204, 2.4937288214789173, 2.5004324903357986, 2.5070650304684996, 2.513628117766017, 2.5201233674869576, 2.526552337198486, 2.5329165295375957, 2.539217394807505, 2.545456333420944, 2.551634698201088, 2.5577537965500676, 2.5638148924941286, 2.5698192086138367, 2.5757679278670427, 2.5816621953117154, 2.587503119735228, 2.593291775196155, 2.599029202484197, 2.6047164105034355, 2.610354377583716, 2.615944052724643, 2.6214863567763085, 2.6269821835606115, 2.632432400936743, 2.6378378518141545, 2.6431993551161153, 2.648517706696732, 2.6537936802141293], [0.0, 1.0985605433061176, 1.2619146889603865, 1.3685108578372633, 1.449559327355391, 1.515716566510398, 1.5720061711932456, 1.6212261661978982, 1.6651064148037462, 1.7047963168076516, 1.7411011265922482, 1.7746084027326519, 1.8057609028948687, 1.8349011252209961, 1.8622998301896752, 1.8881750225898037, 1.912704999580074, 1.936037570004963, 1.9582967247219536, 1.979587563373977, 2.0, 2.0196115953469707, 2.038489752982913, 2.056693444200427, 2.0742745786732963, 2.091279105182547, 2.1077479041235665, 2.1237175175898693, 2.139220751450138, 2.154287175585486, 2.168943542395397, 2.183214139178577, 2.1971210866122353, 2.210684592985739, 2.223923171877158, 2.2368538294402893, 2.2494922262841897, 2.261852817995919, 2.273948977620276, 2.2857931028231215, 2.2973967099940698, 2.308770517164429, 2.319924517308003, 2.330868043340851, 2.341609825929785, 2.352158045049347, 2.362520376086217, 2.3727040311728307, 2.382715796334183, 2.3925620649496873, 2.4022488679628626, 2.4117819012132253, 2.4211665502151893, 2.4304079126666474, 2.4395108189338695, 2.4484798507285492, 2.4573193581662944, 2.466033475373057, 2.4746261347862566, 2.4831010802802607, 2.491461879231035, 2.4997119336218585, 2.5078544902806996, 2.5158926503299757, 2.523829377920773, 2.531667508315967, 2.5394097553800083, 2.5470587185272, 2.5546168891750796, 2.5620866567448726, 2.5694703142468787, 2.576770063484986, 2.5839880199112666, 2.591126217158678, 2.598186611277321, 2.605171084697352, 2.612081449939601, 2.618919453093024, 2.625686777076488, 2.6323850447008303, 2.639015821545789, 2.6455806186651616, 2.6520808951324333, 2.658518060438097, 2.664893476748993, 2.6712084610391402, 2.677464287100793, 2.6836621874437667, 2.689803355090437, 2.6958889452732757, 2.701920077041227, 2.7078978347807907, 2.713823269657214, 2.7196974009808117, 2.7255212175030645, 2.7312956786468088, 2.7370217156745267, 2.7427002327984606, 2.748332108236015, 2.7539181952136724, 2.75945932292243, 2.764956297427551], [0.0, 1.142287530066645, 1.3121438067211812, 1.42298291814101, 1.5072574323001682, 1.5760479871502193, 1.634578137257459, 1.6857572796964846, 1.7313841330402582, 1.7726538476726315, 1.810403730235845, 1.8452447264239062, 1.8776372173817608, 1.907937334011045, 1.9364266141116284, 1.9633317399117873, 1.9888381054913125, 2.01309940306217, 2.0362445588007163, 2.058382855724867, 2.0796077868024114, 2.1, 2.119629581810095, 2.1385578508123397, 2.1568387828876388, 2.1745201557574014, 2.191644477015916, 2.208249743274289, 2.224370066202506, 2.240036192678075, 2.255275939950137, 2.270114562046446, 2.28457506013329, 2.298678446868631, 2.3124439727430275, 2.325889320821409, 2.339030775066046, 2.351883366452645, 2.3644610003252544, 2.3767765678251043, 2.388842043738954, 2.400668572717488, 2.412266545493774, 2.423645666470267, 2.4348150138283096, 2.4457830931372797, 2.4565578852941288, 2.467146889502245, 2.4775571618968377, 2.487795350338713, 2.4978677258264232, 2.5077802109160734, 2.5175384054865195, 2.527147610143877, 2.536612847521801, 2.5459388817019484, 2.5551302359514647, 2.5641912089506107, 2.5731258896631264, 2.5819381709841545, 2.5906317622851143, 2.5992102009614646, 2.6076768630775673, 2.616034973192587, 2.6242876134423625, 2.6324377319442718, 2.640488150585136, 2.648441572246068, 2.656300587512724, 2.664067680914597, 2.671745236732724, 2.67933554441136, 2.6868408036058073, 2.6942631288955314, 2.7016045541890428, 2.7088670368445484, 2.7160524615282635, 2.7231626438302827, 2.730199333656196, 2.73716421841103, 2.7440589259906925, 2.7508850275948054, 2.7576440403736586, 2.764337429920955, 2.770966612623078, 2.7775329578747407, 2.784037790170088, 2.790482391077625, 2.7968680011066622, 2.8031958214724217, 2.8094670157663533, 2.8156827115377605, 2.8218440017923614, 2.8279519464129876, 2.8340075735072805, 2.84001188068684, 2.84596583628202, 2.8518703804962326, 2.8577264265033517, 2.8635348614915976, 2.8692965476569974, 2.8750123231493494], [0.0, 1.1855998744839986, 1.3618966255044604, 1.4769384456489911, 1.5644084133929868, 1.6358073134502662, 1.696556762948874, 1.749676475153355, 1.7970333710080455, 1.8398679176525994, 1.87904917005244, 1.9152112392514733, 1.9488319627584663, 1.9802809749615793, 2.009850488785669, 2.0377757816143354, 2.0642492771517182, 2.0894304951880818, 2.113453250419361, 2.136430969569487, 2.158460690597782, 2.1796261194159547, 2.2, 2.2196459759583926, 2.238620069786293, 2.2569718708025155, 2.2747454983702906, 2.291980389825818, 2.3087119502580853, 2.3249720923800967, 2.3407896881931842, 2.3561909492871167, 2.3711997489679972, 2.3858378966349374, 2.4001253727031897, 2.41408053072999, 2.4277202721198567, 2.4410601977810056, 2.454114740309191, 2.466897279641621, 2.479420244615436, 2.4916952024552654, 2.503732937881679, 2.515543523260897, 2.5271363809934777, 2.5385203391561713, 2.5497036812591936, 2.5606941908547243, 2.5714991916268626, 2.5821255835046784, 2.59257987526543, 2.602868214031965, 2.6129964120148634, 2.6229699708043825, 2.63279410347838, 2.6424737547591493, 2.652013619423459, 2.661418159145488, 2.6706916179310314, 2.6798380362829146, 2.6888612642215333, 2.697764973270477, 2.7065526675050133, 2.715227693750562, 2.723793251008921, 2.7322523991818244, 2.7406080671541386, 2.7488630602926603, 2.7570200674108, 2.7650816672444503, 2.7730503344799087, 2.7809284453707463, 2.788718282977034, 2.7964220420571695, 2.804041833639778, 2.8115796893006095, 2.819037565167143, 2.826417345671567, 2.8337208470709903, 2.8409498207521136, 2.8481059563360978, 2.8551908845980556, 2.862206180214368, 2.8691533643499456, 2.876033907096578, 2.8828492297725905, 2.889600707093238, 2.8962896692205136, 2.9029174037003678, 2.90948515729474, 2.9159941377152094, 2.9224455152645916, 2.9288404243923205, 2.9351799651690174, 2.941465204685286, 2.947697178379364, 2.9538768912979823, 2.960005319294431, 2.9660834101675833, 2.97211208474535, 2.978092237915818, 2.9840247396090787], [0.0, 1.2285201067417038, 1.411199025694977, 1.5304055069078983, 1.6210419993892384, 1.6950256309730263, 1.7579742882635063, 1.8130170020086807, 1.862088278079523, 1.9064734901131382, 1.9470731539765267, 1.9845443363446358, 2.019382173055373, 2.051969679734644, 2.0826096477890275, 2.111545871944413, 2.1389777418892097, 2.1650705522341696, 2.1899629619384178, 2.213772503918405, 2.236599729031725, 2.258531373451182, 2.2796428145777656, 2.3000000000000007, 2.319660980299045, 2.3386771399904958, 2.3570941956149776, 2.3749530121907143, 2.3922902765162104, 2.409139056585509, 2.4255292696033277, 2.4414880760525177, 2.4570402134834075, 2.4722082808232564, 2.487012981803913, 2.5014733344048636, 2.5156068518830947, 2.529429699919658, 2.542956833588739, 2.55620211719839, 2.5691784295255564, 2.5818977565431984, 2.594371273392567, 2.6066094170724274, 2.6186219510862907, 2.630418023098581, 2.642006216493181, 2.653394596596817, 2.6645907522203225, 2.675601833079027, 2.6864345835762533, 2.697095373368559, 2.7075902250759847, 2.7179248394533917, 2.728104618298727, 2.738134685339556, 2.7480199053095733, 2.757764901401271, 2.767374071258883, 2.776851601656607, 2.7862014819905023, 2.795427516698009, 2.8045333367064034, 2.8135224100004663, 2.822398051389954, 2.8311634315489576, 2.839821585391723, 2.8483754198429136, 2.8568277210544255, 2.8651811611156903, 2.8734383042998153, 2.8816016128837902, 2.889673452577381, 2.897656097592049, 2.9055517353783555, 2.9133624710576913, 2.9210903315718535, 2.9287372695718856, 2.9363051670657283, 2.943795838842521, 2.951211035689873, 2.958552447419042, 2.9658217057117073, 2.9730203868008975, 2.9801500139976045, 2.987212060073696, 2.9942079495108773, 3.0011390606247077, 3.008006727571948, 3.0148122422489156, 3.021556856087893, 3.0282417817581555, 3.0348681947776575, 3.0414372350409846, 3.0479500082687854, 3.0544075873834866, 3.0608110138157967, 3.067161298746143, 3.07345942428493, 3.079706344595218, 3.085902986961187, 3.0920502528055107], [0.0, 1.2710686092585748, 1.460074420543694, 1.5834094929274731, 1.6771850850517902, 1.7537310619463105, 1.818859879812478, 1.8758089400891171, 1.9265797482245537, 1.972502195420671, 2.01450798596493, 2.053276943345878, 2.0893213519106983, 2.123037492628885, 2.1547386437691007, 2.184677043631296, 2.213058987556147, 2.2400554949594964, 2.265810027107765, 2.2904441875464174, 2.3140620096063054, 2.3367532334764034, 2.3585958471747506, 2.3796580823152773, 2.4, 2.4196747643932, 2.4387296753798298, 2.4572070132950636, 2.4751447355461083, 2.492577055402221, 2.509534926219056, 2.526046449154239, 2.5421372185171496, 2.5578306159251385, 2.5731480621620424, 2.5881092338750777, 2.602732250874477, 2.617033838722661, 2.63102947044709, 2.6447334905315527, 2.658159223795896, 2.6713190713346537, 2.6842245953283475, 2.6968865942502234, 2.7093151697524744, 2.7215197863192655, 2.733509324610958, 2.745292129288391, 2.7568760519928843, 2.7682684900626424, 2.779476421486307, 2.790506436526796, 2.8013647663912637, 2.812057309274224, 2.822589654059217, 2.832967101928727, 2.843194686101386, 2.853277189889099, 2.8632191632438846, 2.873024937944464, 2.8826986415554354, 2.892244210276931, 2.901665400789576, 2.910965801188159, 2.920148841087388, 2.9292178009743175, 2.938175820874259, 2.9470259083901564, 2.9557709461693467, 2.96441369884627, 2.972956819504939, 2.981402855700717, 2.989754255077242, 2.998013370610898, 3.0061824655122966, 3.0142637178114966, 3.0222592246512927, 3.030171006310745, 3.0380010099791606, 3.0457511132989934, 3.0534231276945416, 3.0610188015018984, 3.068539822914324, 3.0759878227560202, 3.0833643770962547, 3.0906710097148, 3.0979091944287878, 3.105080357290288, 3.1121858786631797, 3.1192270951872496, 3.1262053016368228, 3.1331217526806996, 3.1399776645496638, 3.1467742166173513, 3.153512552899883, 3.160193783479226, 3.1668189858549463, 3.1733892062286437, 3.179905460725083, 3.18636873655376, 3.1927799931143666, 3.199140163049404], [0.0, 1.3132639022018837, 1.5085440841362907, 1.6359734748530934, 1.7328621078878659, 1.811949159194239, 1.8792400393825317, 1.9380796209604725, 1.9905358527674863, 2.037982774014807, 2.081383018504683, 2.1214389776272204, 2.1586799418832774, 2.1935153474658144, 2.2262688724505715, 2.257201128618586, 2.286525259636632, 2.3144179622020937, 2.3410274600231027, 2.366479393482464, 2.390881249475093, 2.4143257472687747, 2.43689346382698, 2.4586548958285745, 2.4796720982064158, 2.5, 2.51968747129473, 2.538778195993704, 2.557311391565076, 2.5753224070459977, 2.5928432233416205, 2.609902874475482, 2.6265278044037674, 2.64274217093654, 2.658568105957135, 2.6740259393126724, 2.6891343923314253, 2.7039107458094214, 2.7183709864276877, 2.732529934859647, 2.7464013582652944, 2.7599980694146726, 2.7733320143146294, 2.786414349912169, 2.799255513201079, 2.811865282855237, 2.82425283434369, 2.8364267893425428, 2.848395260141756, 2.8601658896468076, 2.8717458874925876, 2.883142062717045, 2.8943608533828957, 2.9054083534852926, 2.9162903374403077, 2.927012282412231, 2.937579388705981, 2.9479965984236696, 2.958268612560742, 2.968399906696711, 2.978394745417729, 2.9882571955928143, 2.99799113861202, 3.0076002816830676, 3.0170881682725814, 3.0264581877689873, 3.0357135844360967, 3.0448574657193697, 3.0538928099605442, 3.062822473570822, 3.071649197707868, 3.0803756144974983, 3.08900425283706, 3.0975375438140054, 3.1059778257700885, 3.1143273490387933, 3.1225882803811524, 3.130762707142838, 3.138852641153431, 3.146860022386934, 3.1547867224009667, 3.162634547570625, 3.170405242131627, 3.1781004910461688, 3.185721922703828, 3.1932711114688495, 3.200749580084241, 3.2081588019423064, 3.21550020323046, 3.222775164960529, 3.229985024889084, 3.2371310793357972, 3.2442145849063104, 3.2512367601255825, 3.2581987869873013, 3.2651018124245015, 3.271946949706187, 3.2787352797644056, 3.2854678524559193, 3.292145687762328, 3.298769776932236, 3.305341083568804], [0.0, 1.3551228811604872, 1.5566274244078941, 1.6881185000425407, 1.7880953617606195, 1.869703234061905, 1.9391389440389288, 1.9998539786793306, 2.053982200632252, 2.102941445240332, 2.1477250292995467, 2.1890577322260265, 2.2274857151282053, 2.263431464569923, 2.2972289755432227, 2.3291471665701082, 2.359405975059458, 2.388187729739905, 2.415645378802657, 2.441908567292591, 2.467088208142348, 2.491279975954033, 2.5145670160015765, 2.5370220719752736, 2.558709176747163, 2.579685010165171, 2.6, 2.619699222535653, 2.6388231452580238, 2.6574082439196185, 2.675487518785089, 2.693090929308557, 2.7102457623209744, 2.7269769456385418, 2.7433073165763324, 2.7592578529750966, 2.7748478728868013, 2.7900952079156363, 2.805016354302166, 2.8196266051140166, 2.833940166325698, 2.847970259101537, 2.8617292102154512, 2.8752285322310205, 2.8884789948108143, 2.9014906883142015, 2.9142730806691657, 2.926835068359152, 2.939185022245284, 2.95133082884304, 2.9632799275872412, 2.975039344547141, 2.9866157229922914, 2.9980153511578713, 3.009244187513716, 3.0203078838032704, 3.0312118060859943, 3.0419610539885813, 3.052560478346025, 3.0630146973924783, 3.0733281116435305, 3.0835049175955977, 3.0935491203541763, 3.103464545290542, 3.1132548488157883, 3.1229235283517216, 3.1324739315698316, 3.1419092649623073, 3.151232601802563, 3.160446889547064, 3.169554956725144, 3.1785595193590095, 3.1874631869520904, 3.196268468080332, 3.2049777756178024, 3.2135934316251236, 3.2221176719266786, 3.230552650400204, 3.238900443000345, 3.247163051535843, 3.2553424072183534, 3.263440373999379, 3.271458751710415, 3.279399279020148, 3.2872636362214527, 3.295053447859866, 3.302770285214313, 3.3104156686400086, 3.3179910697826713, 3.325497913672505, 3.332937580705738, 3.3403114085209427, 3.3476206937768125, 3.3548666938375757, 3.3620506283717932, 3.3691736808698467, 3.3762370000850814, 3.3832417014031777, 3.390188868144036, 3.397079552800154, 3.403914778215197, 3.4106955387062188], [0.0, 1.3966610165238238, 1.604342212169403, 1.7398638404385867, 1.8429052599712974, 1.9270146315044916, 1.9985787314306283, 2.061154844031224, 2.1169422405444127, 2.167402216752623, 2.213558537264427, 2.25615819792069, 2.295764101126424, 2.3328116837869626, 2.3676451787328374, 2.40054174755694, 2.4317280693371046, 2.4613920616644336, 2.489691361000665, 2.516759586357539, 2.5427110504452908, 2.567644360548092, 2.5916452105645718, 2.6147885739734056, 2.6371404464251693, 2.6587592451565, 2.679696943683947, 2.7, 2.7197101220270716, 2.7388649035968946, 2.7574983565203652, 2.775641358588885, 2.7933220330476476, 2.810566071816994, 2.827397012236695, 2.8438364751743443, 2.8599043708317935, 2.875619077399522, 2.8909975967719235, 2.90605569078999, 2.920808000879288, 2.9352681534681406, 2.9494488531790077, 2.9633619654662873, 2.9770185901114687, 2.9904291267703833, 3.003603333588294, 3.0165503797496216, 3.029278892704739, 3.041797000711886, 3.05411237124443, 3.06623224573941, 3.0781634711003325, 3.089912528313578, 3.1014855584919947, 3.1128883866200585, 3.124126543241283, 3.1352052842995377, 3.146129609320866, 3.1569042781006282, 3.167533826041971, 3.178022578275132, 3.188374662672788, 3.1985940218640594, 3.208684424338806, 3.218649474724152, 3.2284926233066593, 3.2382171748660658, 3.2478262968798233, 3.2573230271518088, 3.266710280913336, 3.2759908574399432, 3.2851674462233116, 3.2942426327339374, 3.303218903806923, 3.31209865268025, 3.32088418371229, 3.3295777168028846, 3.338181391540233, 3.3466972710938605, 3.3551273458722166, 3.363473536961897, 3.3717376993640378, 3.379921625042165, 3.388027045794617, 3.3960556359635903, 3.4040090149919044, 3.4118887498377233, 3.419696357256636, 3.4274333059598283, 3.435101018656359, 3.442700873986996, 3.4502342083564836, 3.457702317670623, 3.465106458984072, 3.4724478520643545, 3.4797276808771733, 3.4869470949977583, 3.4941072109526585, 3.5012091134960777, 3.5082538568245707, 3.5152424657336643], [0.0, 1.4378925219250926, 1.651704774597892, 1.7912272024038713, 1.897310557521347, 1.9839029624933204, 2.0575797408272685, 2.1220031931145575, 2.1794375163432784, 2.2313871459154493, 2.2789060694898216, 2.322763335332784, 2.3635384635635086, 2.4016797458308234, 2.4375415772291475, 2.4714093015728125, 2.5035162898423478, 2.5340560072349554, 2.5631907438746055, 2.591058063404511, 2.617775653215717, 2.643445031625726, 2.6681544223441955, 2.691981012178128, 2.714992745067622, 2.73724976281281, 2.758805573265564, 2.77970800592724, 2.8000000000000007, 2.8197202591412687, 2.838903799241061, 2.857582409648994, 2.8757850438501853, 2.893538152228582, 2.910865966981148, 2.9277907472555653, 2.9443329910323857, 2.9605116190535385, 2.976344135134565, 2.9918467664293886, 3.0070345866001826, 3.0219216243476508, 3.036520959353557, 3.0508448073581182, 3.0649045958248418, 3.0787110314228294, 3.092274160372269, 3.1056034225455105, 3.118707700088062, 3.1315953612164056, 3.1442742997590996, 3.1567519709311473, 3.1690354237668057, 3.1811313305807896, 3.193046013780709, 3.2047854703132246, 3.216355393991699, 3.227761195923264, 3.2390080232273886, 3.2501007762156555, 3.2610441241830395, 3.2718425199440415, 3.282500213232263, 3.293021263069087, 3.303409549195784, 3.313668782653419, 3.323802515586132, 3.3338141503356633, 3.3437069478880983, 3.353484035727791, 3.363148415148008, 3.3727029680630567, 3.3821504633624015, 3.3914935628434644, 3.400734826756409, 3.409876718991154, 3.418921611934148, 3.4278717910199696, 3.4367294590006368, 3.4454967399534997, 3.4541756830468193, 3.462768266080517, 3.4712763988181146, 3.47970192612456, 3.488046630923449, 3.496312236986043, 3.5045004115635163, 3.512612767872963, 3.520650867446848, 3.5286162223548896, 3.536510297306629, 3.544334511642355, 3.5520902412194633, 3.559778820200816, 3.56740154275119, 3.574959664647457, 3.5824544048077427, 3.5898869467444445, 3.5972584399456307, 3.6045700011890593, 3.611822715792732, 3.6190176388056585], [0.0, 1.4788304974808695, 1.6987301597757218, 1.8422249051589266, 1.9513285401182219, 2.0403863016478, 2.1161607180906277, 2.182418358729787, 2.2414878840925674, 2.294916562086737, 2.343788388261312, 2.388894306315511, 2.4308303357800485, 2.4700575315334667, 2.506940378588235, 2.541772344730344, 2.5747934452029173, 2.6062026533154743, 2.6361668797244855, 2.6648276046225425, 2.6923058660569215, 2.7187060726546126, 2.7441189599264106, 2.768623912250812, 2.792290807987432, 2.8151815012226193, 2.83735102322053, 2.8588485652275235, 2.8797182889599506, 2.9000000000000004, 2.9197297111687033, 2.938940116884447, 2.957660994961739, 2.975919548848581, 2.9937407006523933, 3.0111473432569893, 3.0281605582371833, 3.0447998050238954, 3.061083085780604, 3.077027089661571, 3.092647319488453, 3.1079582033705315, 3.1229731933788036, 3.1377048530455958, 3.152164935183643, 3.166364451289669, 3.1803137336079628, 3.194022490771758, 3.207499857808505, 3.2207544411846514, 3.2337943594725065, 3.24662728014314, 3.259260452922577, 3.2717007400917857, 3.28395464406249, 3.296028332519324, 3.3079276613831716, 3.3196581958198084, 3.3312252294914018, 3.3426338022254116, 3.3538887162554576, 3.3649945511713093, 3.3759556776999586, 3.386776270426444, 3.3974603195514437, 3.408011641772394, 3.4184338903658835, 3.428730564541102, 3.438905018127075, 3.4489604676501933, 3.458899999852996, 3.4687265787002466, 3.4784430519139558, 3.4880521570750944, 3.497556527326242, 3.5069586967062762, 3.516261105145428, 3.5254661031464662, 3.5345759561755603, 3.543592848784278, 3.5525188884823757, 3.561356109379356, 3.5701064756112704, 3.5787718845678786, 3.5873541699340685, 3.595855104558279, 3.604276403159689, 3.612619724885001, 3.6208866757247855, 3.6290788107986227, 3.637197636517532, 3.645244612631579, 3.6532211541699455, 3.661128633280201, 3.668968380973051, 3.6767416887783613, 3.684449810317853, 3.6920939627994893, 3.699675328438204, 3.7071950558073294, 3.7146542611247586, 3.72205402947761], [0.0, 1.5194870523363548, 1.7454322774580644, 1.89287203344058, 2.004975185874807, 2.096481356314738, 2.174338991033087, 2.242418211228409, 2.3031116978242654, 2.3580092567898685, 2.4082246852806923, 2.454570671912596, 2.49765962220562, 2.537965266529508, 2.5758621104534667, 2.6116516898883724, 2.645580618665162, 2.6778533403411537, 2.708641354342303, 2.738090030486971, 2.7663237344451836, 2.793449745284513, 2.8195612930499663, 2.8447399445847266, 2.8690574993701112, 2.892577512007882, 2.915356526702057, 2.937445087082931, 2.9588885689770885, 2.9797278723165044, 3.0000000000000004, 3.019738545293004, 3.0389741046727097, 3.0577346294743704, 3.0760457269731987, 3.0939309194326357, 3.1114118680099447, 3.1285085671219166, 3.145239513854165, 3.161621856185351, 3.177671523146437, 3.1934033395096204, 3.2088311271752072, 3.223967795076801, 3.2388254191398094, 3.2534153135930963, 3.267748094738832, 3.281833738123583, 3.295681629918354, 3.3093006132017493, 3.3226990297448706, 3.3358847578157373, 3.348865246452523, 3.3616475465965614, 3.374238339426285, 3.3866439621905933, 3.398870431803513, 3.4109234664304147, 3.422808505268784, 3.43453072670288, 3.4460950649911055, 3.4575062256270055, 3.4687686994992135, 3.479886775962005, 3.490864554916129, 3.50170595798908, 3.512414738894677, 3.5229944930436634, 3.533448666469772, 3.543780564129326, 3.553993357626733, 3.5640900924131698, 3.5740736945012754, 3.5839469767346084, 3.593712644647077, 3.6033733019442944, 3.6129314556359535, 3.6223895208457164, 3.6317498253227845, 3.641014613677226, 3.6501860513592352, 3.6592662284008046, 3.6682571629367393, 3.677160804520542, 3.685979037249442, 3.6947136827116833, 3.7033665027681386, 3.7119392021793858, 3.7204334310884812, 3.7288507873689274, 3.7371928188465526, 3.745461025403412, 3.7536568609711916, 3.7617817354210494, 3.7698370163563304, 3.777824030814116, 3.78574406688116, 3.7935983752293563, 3.8013881705755286, 3.809114633070013, 3.816778909618177, 3.8243821151387554], [0.0, 1.5598734100953933, 1.7918240201801936, 1.9431825688393956, 2.0582653044251624, 2.1522036120332677, 2.2321306202847264, 2.3020193141037537, 2.3643259693406558, 2.420682647324795, 2.4722327487612916, 2.519810562669337, 2.5640447716595767, 2.605421697353629, 2.6443257992823845, 2.681066627862113, 2.7158973516583815, 2.7490278481218984, 2.7806341749518597, 2.810865565742552, 2.839849691671894, 2.867696683171538, 2.8945022482424205, 2.9203501216880947, 2.9453140113441036, 2.9694591610262644, 2.9928436178236955, 3.015519268762895, 3.0375326957118953, 3.058925885679579, 3.0797368250626573, 3.1000000000000005, 3.1197468201907865, 3.1390059798871786, 3.1578037669786636, 3.1761643289255503, 3.1941099026157387, 3.2116610138964576, 3.22883665148628, 3.245654419138992, 3.2621306692623415, 3.278280620655281, 3.2941184625895996, 3.3096574471046933, 3.324909971091288, 3.339887649498477, 3.354601380798505, 3.369061405677411, 3.3832773597806907, 3.3972583212266194, 3.4110128535017457, 3.424549044270116, 3.4378745405574547, 3.4509965807116547, 3.463922023489799, 3.4766573745781577, 3.4892088108139636, 3.5015822023453724, 3.5137831329379807, 3.5258169186120223, 3.5376886247732657, 3.5494030819822946, 3.5609649004908093, 3.572378483659583, 3.583648040360387, 3.594777596453426, 3.605771005422258, 3.6166319582398385, 3.6273639925318313, 3.6379705010968, 3.6484547398370415, 3.658819835148602, 3.669068790814439, 3.679204494440517, 3.689229723470971, 3.699147150815154, 3.708959350116425, 3.718668800689875, 3.728277892153817, 3.7377889287776784, 3.747204133567029, 3.7565256521046986, 3.765755556165381, 3.774895847119646, 3.7839484591420347, 3.7929152622366784, 3.8017980650928473, 3.8105986177818507, 3.8193186143058018, 3.8279596950079893, 3.8365234488538142, 3.8450114155906086, 3.853425087794025, 3.8617659128081043, 3.8700352945856413, 3.8782345954349577, 3.886365137678791, 3.8944282052305703, 3.9024250450930063, 3.910356868783583, 3.9182248536911977, 3.926030144367946], [0.0, 1.6000000000000003, 1.8379173679952563, 1.993169503384828, 2.111212657236631, 2.207567458337944, 2.2895505297684093, 2.361237058551284, 2.4251465064166373, 2.482952918264576, 2.535829107937782, 2.584630825923485, 2.6300029272275616, 2.672444243735697, 2.712349124915897, 2.750035084139966, 2.785761802547598, 2.819744556531708, 2.852163932745606, 2.883173003707428, 2.912902724841729, 2.9414660596040707, 2.9689611780129352, 2.9954739688877727, 3.0210800361436867, 3.045846301945406, 3.0698323066004902, 3.0930912718908212, 3.1156709779685388, 3.1376144919272773, 3.1589607773357122, 3.179745207463133, 3.2000000000000006, 3.219754587336894, 3.239035933599817, 3.257868807424637, 3.2762760177267514, 3.294278618365628, 3.311896086530583, 3.329146478818951, 3.3460465682920746, 3.362611965241256, 3.378857223946807, 3.394795937347037, 3.4104408212335184, 3.425803789341319, 3.440896020497824, 3.4557280188231463, 3.470309667832636, 3.4846502791724485, 3.4987586366184904, 3.512643035883985, 3.526311320708737, 3.5397709156417876, 3.553028855876673, 3.5660918144536304, 3.5789661271044637, 3.5916578149825478, 3.6041726054917214, 3.6165159514029055, 3.6286930484256876, 3.6407088513832493, 3.652568089122607, 3.664275278277733, 3.6758347359905126, 3.687250591683426, 3.698526797968047, 3.709667140764881, 3.720675248702395, 3.7315546018563874, 3.7423085398848333, 3.7529402696080054, 3.763452872078956, 3.7738493091851777, 3.7841324298185026, 3.7943049756468996, 3.8043695865187988, 3.81432880552784, 3.8241850837634996, 3.833940784770832, 3.843598188740581, 3.853159496449108, 3.8626268329659785, 3.872002251145541, 3.881287734917545, 3.8904852023905967, 3.899596508781159, 3.9086234491798315, 3.9175677611656794, 3.9264311272786094, 3.935215177358982, 3.943921490762991, 3.9525515984616946, 3.961106985030987, 3.9695890905393116, 3.9779993123393638, 3.986339006769656, 3.99460949077134, 4.00281204342535, 4.010947907414561, 4.019018290415329, 4.027024366422506], [0.0, 1.639876536170158, 1.8837234794968962, 2.0428449382566907, 2.1638300621673756, 2.2625862980882414, 2.34661262008948, 2.4200857804085567, 2.4855880329047966, 2.544835144423311, 2.5990291586527943, 2.6490471538087617, 2.6955500565120682, 2.7390491309532323, 2.779948554907025, 2.8185737550786603, 2.855190884598056, 2.8900205851561718, 2.923247944137699, 2.955029849061904, 2.985500519133793, 3.014775733178504, 3.0429561078897023, 3.0701296726797223, 3.0963739157275776, 3.121757427088073, 3.1463412309820358, 3.170179875629042, 3.1933223319980844, 3.21581274053687, 3.237691035896673, 3.258993472948939, 3.279753072340316, 3.3000000000000007, 3.3197618920764627, 3.339064134510198, 3.3579301046794394, 3.3763813811655243, 3.394437926584546, 3.4121182475554366, 3.4294395351717815, 3.4464177887775986, 3.463067925387128, 3.4794038767132394, 3.4954386754610813, 3.511184532289777, 3.526652904634782, 3.541854558408664, 3.556799623451996, 3.571497643483555, 3.585957621195846, 3.600188059054785, 3.614196996288411, 3.6279920424865764, 3.6415804081797853, 3.6549689327193575, 3.6681641097414954, 3.6811721104637862, 3.69399880503321, 3.7066497821191997, 3.7191303669231544, 3.7314456377564977, 3.7436004413225206, 3.7555994068225185, 3.7674469589937924, 3.779147330175738, 3.790704571490216, 3.802122563213604, 3.8134050244100774, 3.8245555218887906, 3.835577478541463, 3.8464741811114207, 3.857248787440294, 3.8679043332342076, 3.8784437383874555, 3.888869812898145, 3.8991852624072143, 3.909392693389406, 3.9194946180222954, 3.92949345875718, 3.9393915526136225, 3.9491911552175702, 3.9588944446013468, 3.9685035247822515, 3.978020429135188, 3.9874471235734665, 3.9967855095508042, 4.0060374268965475, 4.0152046564951585, 4.024288922820209, 4.0332918963323, 4.0422151957496615, 4.05106039019949, 4.05982900125752, 4.068522504882782, 4.077142333253966, 4.085689876513381, 4.09416648442409, 4.102573467945347, 4.110912100731208, 4.11918362055675, 4.127389230676101], [0.0, 1.6795120867813484, 1.9292527712833725, 2.0922201699617475, 2.216129484746681, 2.3172726429148485, 2.4033298675266765, 2.478578862245574, 2.5456642935889393, 2.606343398208985, 2.661847272995918, 2.7130741950038453, 2.7607010653431354, 2.8052515053770892, 2.847139461791914, 2.8866982268036474, 2.924200386420304, 2.959871915206823, 2.9939023740800437, 3.026452442505194, 3.057659583743755, 3.087642374976339, 3.116503864785822, 3.144334210241194, 3.1712127723982215, 3.1972097991222386, 3.2223877895796185, 3.2468026104115797, 3.2705044162075154, 3.2935384142826134, 3.3159455045022077, 3.337762818012124, 3.359024173562697, 3.3797604661887535, 3.400000000000001, 3.4197687745110095, 3.4390907321274637, 3.4579879729815204, 3.4764809421824756, 3.494588593651246, 3.5123285339873695, 3.5297171492364208, 3.5467697169544596, 3.5635005055816036, 3.579922862821376, 3.5960492944625555, 3.6118915348649607, 3.6274606101515228, 3.642766894999424, 3.657820163797579, 3.672629636832116, 3.687204022072176, 3.7015515530526395, 3.7156800232859144, 3.7295968175798606, 3.743308940591813, 3.7568230429081115, 3.770145444903673, 3.783282158605981, 3.7962389077617047, 3.8090211462814993, 3.8216340752187543, 3.8340826584207948, 3.846371636975963, 3.858505542566745, 3.870488709827495, 3.882325287795033, 3.8940192505313895, 3.9055744069899196, 3.916994410188978, 3.9282827657510233, 3.9394428398594354, 3.9504778666803664, 3.961390955292467, 3.9721850961634044, 3.9828631672084858, 3.993427939463552, 4.003882082401419, 4.014228168918588, 4.0244686800166125, 4.03460600920044, 4.044642466614132, 4.054580282932701, 4.0644216130272035, 4.074168539418887, 4.083823075536867, 4.09338716879269, 4.102862703484082, 4.1122515035391904, 4.121555335111837, 4.130775909037386, 4.139914883158224, 4.148973864527097, 4.15795441149598, 4.166858035697596, 4.175686203926158, 4.184440339923495, 4.19312182607622, 4.201732005029265, 4.210272181220695, 4.21874362234241, 4.227147560731], [0.0, 1.7189151347155782, 1.9745149876272916, 2.141305765888571, 2.268122118204461, 2.3716381969016833, 2.4597144108218676, 2.5367288228719342, 2.605388146113855, 2.667490843744494, 2.724296895429098, 2.7767256527076896, 2.8254698974735803, 2.8710655357755104, 2.9139362259065558, 2.954423079454385, 2.9928050775697597, 3.0293134964088866, 3.0641423441789537, 3.097456070047545, 3.1293953623029345, 3.1600815800660196, 3.1896201895433913, 3.2181034629798333, 3.2456126233215428, 3.2722195665196456, 3.2979882580340094, 3.322975875193618, 3.3472337492651296, 3.3708081481729533, 3.393740931334527, 3.4160701010298156, 3.4378302694311564, 3.4590530564020607, 3.4797674300952046, 3.5, 3.519775270235123, 3.539115859424126, 3.5580426923391957, 3.5765751675793553, 3.5947313048127305, 3.6125278745180553, 3.6299805126782685, 3.6471038224854873, 3.663911464793825, 3.6804162387904817, 3.6966301541351956, 3.712564495634866, 3.728229881367068, 3.743636315037741, 3.758793233250228, 3.7737095482714103, 3.788393686803204, 3.80285362520168, 3.817096921529742, 3.8311307447810514, 3.8449619015714123, 3.858596860558116, 3.8720417748168736, 3.8853025023792265, 3.8983846251100767, 3.9112934660847722, 3.9240341056075048, 3.9366113959973323, 3.949029975254583, 3.9612942797085067, 3.9734085557365133, 3.9853768706361365, 3.9972031227226212, 4.008891050717817, 4.0204442424896225, 4.031866143195476, 4.04316006287833, 4.0543291835589566, 4.065376565864412, 4.076305155228799, 4.087117787699255, 4.097817195377123, 4.10840601152165, 4.11888677534119, 4.129261936494729, 4.139533859324642, 4.149704826839826, 4.159777044466787, 4.169752643584821, 4.179633684860122, 4.189422161392477, 4.1991200016871355, 4.208729072463443, 4.218251181310968, 4.227688079203001, 4.237041462876582, 4.246312977087536, 4.2555042167483474, 4.2646167289561685, 4.273652014917684, 4.282611531777142, 4.291496694353341, 4.300308876791015, 4.309049414131667, 4.3177196038085235, 4.326320707070035], [0.0, 1.7580936309501132, 2.0195192618031594, 2.190111630815541, 2.3198184539181157, 2.4256939302479177, 2.5157776275776857, 2.594547396126494, 2.6647716419075045, 2.728289819718717, 2.7863906274020755, 2.8400143708833805, 2.889869622336831, 2.9365045024881375, 2.980352325892344, 3.0217619789473953, 3.061018801501899, 3.098359341090404, 3.1339820278660473, 3.1680550592158347, 3.2007223300759207, 3.2321079656536513, 3.2623198360016787, 3.2914523164865312, 3.3195884813342205, 3.3468018651894833, 3.37315789144951, 3.398715040661648, 3.4235258140641234, 3.4476375341463252, 3.4710930144094587, 3.4939311233031747, 3.5161872619002263, 3.5378937707621265, 3.5590802783002444, 3.579774000502684, 3.6000000000000005, 3.6197814109523425, 3.639139635061264, 3.658094513069745, 3.6766644753604867, 3.6948666746545595, 3.712717103319163, 3.7302306973907156, 3.747421429089326, 3.7643023893285843, 3.780885861499258, 3.797183387618016, 3.813205827775725, 3.828963413688509, 3.844465797044168, 3.859722093243064, 3.87474092105332, 3.8895304386326726, 3.904098376311716, 3.918452066483912, 3.9325984709053436, 3.9465442056706355, 3.9602955640999182, 3.973858537744335, 3.9872388356938444, 4.00044190235037, 4.0134729338113, 4.026336892992521, 4.039038523606319, 4.051582363097292, 4.063972754628711, 4.0762138582022835, 4.08830966098588, 4.1002639869164375, 4.1120805056385885, 4.123762740833771, 4.135314077989327, 4.146737771652465, 4.158036952209803, 4.169214632229461, 4.1802737123993845, 4.19121698709253, 4.202047149586895, 4.212766796965924, 4.223378434722628, 4.233884481088825, 4.244287271109058, 4.254589060477172, 4.264792029152079, 4.274898284767856, 4.284909865852157, 4.2948287448658276, 4.304656831075546, 4.314395973270497, 4.324047962333154, 4.333614533673556, 4.343097369535746, 4.352498101184365, 4.361818310978884, 4.371059534342353, 4.380223261631082, 4.38931093991123, 4.398323974647822, 4.40726373131139, 4.416131536907001, 4.424928681430201], [0.0, 1.7970550417308229, 2.0642741702753242, 2.238647065676141, 2.3712283436581343, 2.4794501443544372, 2.571530201761122, 2.652045600494526, 2.723826097682443, 2.7887519125922595, 2.8481403021171032, 2.902952410461687, 2.9539125125881944, 3.0015808762185934, 3.046400418665186, 3.0887277580564834, 3.1288545577058158, 3.1670226073177177, 3.2034347344895635, 3.2382628640591458, 3.271654079842675, 3.3037352578072445, 3.334616658532017, 3.3643947488520056, 3.3931544440152175, 3.4209709082801085, 3.447911014902857, 3.4740345404281263, 3.499395149582978, 3.524041213578504, 3.5480164947131625, 3.571360722806902, 3.5941100834616457, 3.616297633943568, 3.6379536592642827, 3.6591059785500164, 3.6797802098485253, 3.7, 3.719787224992728, 3.7391621652637563, 3.7581436596346185, 3.776749240950743, 3.794995255988888, 3.812896971785504, 3.830468670201438, 3.8477237322602336, 3.864674713566961, 3.881333411922876, 3.8977109280911595, 3.913817720534729, 3.9296636548340733, 3.945258048397486, 3.9606097109950698, 3.9757269815788776, 3.9906177617926692, 4.005289546524321, 4.01974945181057, 4.034004240366436, 4.048060344979382, 4.061923889980334, 4.075600710979356, 4.089096373032688, 4.102416187389311, 4.1155652269491325, 4.1285483405506485, 4.1413701661935365, 4.154035143290646, 4.1665475240341845, 4.178911383952325, 4.191130631724921, 4.20320901832022, 4.215150145508561, 4.226957473803646, 4.238634329877253, 4.25018391348903, 4.261609303969129, 4.2729134662881325, 4.28409925674557, 4.295169428305628, 4.306126635606156, 4.316973439664824, 4.327712312304292, 4.33834564031642, 4.348875729383868, 4.359304807775986, 4.369635029834488, 4.379868479263185, 4.3900071722349585, 4.400053060328072, 4.410008033303039, 4.419873921730383, 4.429652499478859, 4.439345486073006, 4.448954548928196, 4.458481305470838, 4.467927325150749, 4.477294131352282, 4.4865832032102695, 4.495795977336488, 4.504933849461893, 4.513998175999537, 4.522990275532772], [0.0, 1.8358063904019342, 2.1087877807477464, 2.2869208196675728, 2.4223610547827845, 2.5329165295375953, 2.626982183560612, 2.7092338008389447, 2.7825621588378673, 2.8488880215107746, 2.9095570508246347, 2.9655511169126014, 3.017610112862594, 3.0663063879017853, 3.1120924103260608, 3.155332488308544, 3.1963245745340565, 3.2353156726137353, 3.2725129838801843, 3.308092140525272, 3.3422033980522827, 3.374976368357218, 3.406523689657125, 3.4369439089792606, 3.4663237726676783, 3.494740065808422, 3.5222611036996807, 3.548947951896009, 3.574855432340304, 3.600032959311133, 3.624525238788726, 3.6483728573192145, 3.6716127808038683, 3.694278779349382, 3.7164017910275233, 3.738010234850798, 3.759130281289606, 3.779786087100046, 3.8000000000000007, 3.8197927377499536, 3.839183545408157, 3.8581903338949397, 3.8768298024858043, 3.895117547432634, 3.91306815856757, 3.930695305459971, 3.9480118144615552, 3.9650297377790915, 3.981760415550479, 3.998214531762915, 4.014402164736364, 4.030332832797918, 4.046015535689865, 4.061458792183812, 4.076670674313042, 4.091658838583752, 4.106430554481522, 4.120992730551255, 4.135351938295806, 4.14951443410999, 4.163486179441845, 4.177272859351409, 4.190879899618414, 4.204312482533804, 4.217575561495493, 4.230673874516091, 4.243611956739089, 4.25639415205015, 4.269024623861351, 4.2815073651385624, 4.293846207735192, 4.306044831089458, 4.318106770336913, 4.330035423885046, 4.341834060492503, 4.35350582589152, 4.365053748988734, 4.376480747676365, 4.387789634282992, 4.398983120690562, 4.4100638231420355, 4.421034266761981, 4.431896889810579, 4.442654047689786, 4.453308016718923, 4.4638609976955115, 4.474315119255952, 4.484672441049489, 4.494934956737844, 4.505104596831963, 4.515183231376437, 4.525172672491388, 4.535074676780848, 4.544890947616015, 4.554623137301168, 4.5642728491294395, 4.5738416393351455, 4.5833310189489005, 4.592742455561301, 4.602077375000572, 4.611337162929198, 4.620523166364209], [0.0, 1.874354294621998, 2.153067694913917, 2.3349411366118416, 2.4732253193448743, 2.586102216377183, 2.68214304264093, 2.7661217633226323, 2.840989855868474, 2.9087084160583934, 2.970651361806657, 3.0278211803638033, 3.0809733009483784, 3.1306920908649003, 3.1774395192502056, 3.2215875439493202, 3.2634403739993796, 3.3032501995451296, 3.341228572692308, 3.3775548135232643, 3.4123823325770086, 3.4458434633148345, 3.4780532091090817, 3.509112186258248, 3.539108962589187, 3.5681219355061886, 3.5962208547787387, 3.623468068203986, 3.6499195488652814, 3.675625748632568, 3.7006323122135227, 3.724980678382649, 3.748708589243996, 3.7718505240023656, 3.794438070361118, 3.8165002440696343, 3.8380637651207454, 3.859153297509397, 3.879791658206491, 3.9000000000000012, 3.9197979720521547, 3.93920386137329, 3.9582347178870365, 3.976906465332331, 3.995233999895761, 4.013231278177634, 4.030911395854899, 4.048286658204208, 4.065368643481462, 4.0821682600141385, 4.098695797744796, 4.114960974864499, 4.130972980090369, 4.146740511069516, 4.1622718093302025, 4.177574692148446, 4.192656581653069, 4.20752453145325, 4.222185251038977, 4.236645128175622, 4.250910249488547, 4.264986419411571, 4.278879177653889, 4.292593815323178, 4.306135389827834, 4.319508738668332, 4.332718492216221, 4.345769085569226, 4.35866476956194, 4.37140962100375, 4.384007552208572, 4.396462319874751, 4.408777533367927, 4.420956662454685, 4.4330030445304285, 4.444919891380863, 4.456710295513015, 4.468377236088439, 4.4799235844884375, 4.491352109538526, 4.502665482417025, 4.513866281270575, 4.524956995557467, 4.53594003013793, 4.546817709128992, 4.557592279540091, 4.568265914704321, 4.578840717519039, 4.589318723508485, 4.599701903720096, 4.609992167465297, 4.620191364914753, 4.630301289557324, 4.640323680531265, 4.650260224835618, 4.66011255942915, 4.669882273223683, 4.679570908978158, 4.68917996509935, 4.698710897354748, 4.708165120502707, 4.717544009844658], [0.0, 1.9127049995800742, 2.1971210866122357, 2.3827157963341836, 2.523829377920773, 2.639015821545789, 2.737021715674527, 2.8227187044279924, 2.8991186547107826, 2.968222787804118, 3.0314331330207964, 3.0897726892578907, 3.1440123423864916, 3.194748416307661, 3.2424523323957963, 3.2875036590344515, 3.3302128296074933, 3.37083719426056, 3.4095926336153037, 3.446662136778435, 3.482202253184497, 3.5163480239373786, 3.549216805465304, 3.580911272752256, 3.6115218057897374, 3.641128406052161, 3.6698022504419923, 3.6976069624394143, 3.724599660379351, 3.7508318284151225, 3.7763500451796084, 3.801196597315946, 3.8254099991601485, 3.8490254353875963, 3.872075140009926, 3.894588722460673, 3.9165934494439076, 3.9381144895985467, 3.9591751267479545, 3.9797969464821286, 4.0, 4.019802948477955, 4.039223190693942, 4.058276976198625, 4.076979505965827, 4.0953450221584395, 4.113386888400855, 4.131117661744985, 4.148549157346593, 4.165692506725777, 4.182558210365094, 4.1991561852971415, 4.215495808247134, 4.231585954822615, 4.2474350351797385, 4.2630510265418975, 4.278441502900276, 4.293613662186227, 4.308574351170972, 4.32333008831839, 4.337887084790795, 4.352251263785106, 4.366428278357155, 4.380423527874679, 4.394242173224471, 4.4078891508859215, 4.4213691859714785, 4.434686804324316, 4.447846343754316, 4.460851964485466, 4.4737076588805795, 4.486417260502889, 4.49898445256838, 4.511412775837686, 4.523705635991839, 4.53586631053211, 4.547897955240553, 4.55980361023462, 4.571586205646243, 4.583248566953202, 4.59479341998814, 4.60622339564853, 4.617541034328858, 4.62874879009461, 4.639849034616006, 4.6508440608779935, 4.661736086681702, 4.67252725795136, 4.683219651859569, 4.693815279782888, 4.704316090098695, 4.714723970833544, 4.7250407521724345, 4.735268208837701, 4.745408062345662, 4.755461983148498, 4.765431592668367, 4.775318465230222, 4.7851241298993745, 4.7948500722294165, 4.804497735925725, 4.814068524429441], [0.0, 1.9508644077311323, 2.2409547359830166, 2.4302521517053735, 2.5741810188465064, 2.691665488835609, 2.791626648891967, 2.8790333348396566, 2.9569575018135734, 3.0274402964465676, 3.091911719227754, 3.151415178386779, 3.2067369393480885, 3.2584852229686962, 3.3071408557119413, 3.3530909785378435, 3.396652218129394, 3.4380870588945713, 3.4776156883799083, 3.5154247464150505, 3.5516739056729754, 3.5865009013942015, 3.620025431325581, 3.6523522188676676, 3.6835734471373756, 3.7137707136779903, 3.743016615406288, 3.771376045122263, 3.798907260699794, 3.825662773426453, 3.8516900912018195, 3.8770323443084194, 3.9017288154622647, 3.925815391290366, 3.9493249488887883, 3.972287688413872, 3.9947314205538818, 4.016681816074496, 4.038162623322838, 4.059195858532073, 4.079801972932441, 4.100000000000001, 4.1198076856269035, 4.139241603550364, 4.158317258011127, 4.1770491753102625, 4.195450985683061, 4.21353549670081, 4.231314759237462, 4.248800126892427, 4.266002309638072, 4.282931422356685, 4.299597028843773, 4.316008181779627, 4.3321734591071674, 4.348100997199325, 4.363798521152146, 4.379273372499263, 4.394532534608361, 4.4095826559898885, 4.42443007172191, 4.439080823172046, 4.45354067617738, 4.467815137825699, 4.481909471966033, 4.495828713562971, 4.509577681997285, 4.523160993404951, 4.536583072137301, 4.549848161416839, 4.562960333255989, 4.575923497699461, 4.588741411445214, 4.601417685893803, 4.613955794671277, 4.626359080666673, 4.638630762621456, 4.650773941304917, 4.662791605306569, 4.674686636473863, 4.686461815021153, 4.69811982433361, 4.709663255487845, 4.72109461150916, 4.732416311383766, 4.743630693842791, 4.754740020933592, 4.765746481392642, 4.776652193833162, 4.787459209759667, 4.798169516420621, 4.808785039509642, 4.8193076457248205, 4.82973914519508, 4.840081293781836, 4.850335795263615, 4.860504303410747, 4.870588423956744, 4.8805897164725245, 4.890509696149207, 4.900349835494805, 4.9101115659498], [0.0, 1.9888381054913122, 2.28457506013329, 2.4775571618968377, 2.6242876134423625, 2.744058925990692, 2.8459658362820206, 2.935073898840633, 3.014514864600337, 3.0863696112409023, 3.1520959743004386, 3.212757672015068, 3.269156274514918, 3.321911841714041, 3.3715145593929687, 3.418359104234732, 3.462768266080517, 3.505009638613726, 3.545307695345263, 3.5838527090607353, 3.6208074604716907, 3.6563123658437213, 3.6904894528478125, 3.723445483332062, 3.755274434763521, 3.786059492986763, 3.8158746680220896, 3.844786115811908, 3.8728532282232573, 3.900129538679207, 3.926663479823575, 3.9524990214725353, 3.9776762109826245, 4.002231633516293, 4.026198806124339, 4.049608516811035, 4.072489117601433, 4.0948667789442705, 4.116765711449735, 4.138208359898346, 4.159215573604822, 4.179806756533023, 4.200000000000001, 4.219812200351803, 4.239259163620191, 4.258355698861592, 4.277115701624679, 4.295552228780919, 4.3136775657752775, 4.33150328720569, 4.349040311514803, 4.366298950471721, 4.383288954031832, 4.400019551086412, 4.416499486548578, 4.432737055166271, 4.448740132405012, 4.464516202701847, 4.48007238535615, 4.49541545829204, 4.510551879900274, 4.52548780914407, 4.5402291240928925, 4.554781439030335, 4.56915012026658, 4.5833403007721145, 4.5973568937372615, 4.611204605151374, 4.624887945486055, 4.638411240558403, 4.651778641642819, 4.664994134893274, 4.678061550132092, 4.690984569055966, 4.703766732905291, 4.716411449638649, 4.728922000650509, 4.74130154706683, 4.753553135650208, 4.765679704343435, 4.777684087477909, 4.789569020671063, 4.801337145434976, 4.812991013516495, 4.824533090987547, 4.835965762102811, 4.847291332940534, 4.858512034841083, 4.869630027656619, 4.880647402824316, 4.891566186274559, 4.902388341184712, 4.913115770588258, 4.923750319848394, 4.9342937790044905, 4.944747884999226, 4.9551143237936754, 4.965394732377054, 4.975590700677426, 4.985703773379199, 4.9957354516528465, 5.005687194801929], [0.0, 2.0266313872687673, 2.327988140740992, 2.524637422316621, 2.6741561477217837, 2.7962034378630087, 2.9000468539790574, 2.9908482097763818, 3.0717987678932213, 3.145018948290982, 3.211994289310292, 3.273808722699332, 3.33127905058007, 3.385037115675317, 3.4355824186159567, 3.4833171360052253, 3.528570191560862, 3.571614263967131, 3.612678092336356, 3.651955565149652, 3.6896125563906033, 3.72579215061212, 3.7606186943396676, 3.7942009781840667, 3.8266347654374107, 3.858004822699414, 3.8883865663801442, 3.917847409563131, 3.946447872720885, 3.9742425065557283, 4.001280664062186, 4.02760715060139, 4.053262774537535, 4.078284816249716, 4.102707429702989, 4.126561987956648, 4.149877381800598, 4.1726802789926065, 4.194995350209673, 4.216845466743613, 4.23825187410229, 4.259234344977152, 4.279811314469008, 4.3, 4.319816507959074, 4.339275928814622, 4.358392422168178, 4.377179293006938, 4.395649060232419, 4.413813518391097, 4.431683793405445, 4.449270392995959, 4.466583252393441, 4.4836317758629685, 4.500424874494564, 4.516971000658723, 4.533278179476029, 4.549354037607994, 4.565205829639859, 4.58084046229456, 4.5962645166896765, 4.611484268825322, 4.626505708470112, 4.641334556594156, 4.655976281481984, 4.670436113644352, 4.684719059635434, 4.698829914871057, 4.712773275533937, 4.726553549643351, 4.7401749673590965, 4.7536415905828076, 4.76695732191375, 4.780125913010772, 4.793150972407377, 4.806035972822539, 4.818784258006062, 4.831399049153816, 4.843883450925093, 4.856240457091511, 4.868472955844402, 4.8805837347853, 4.892575485622128, 4.904450808591798, 4.916212216628247, 4.927862139293415, 4.939402926487251, 4.950836851951597, 4.962166116581624, 4.973392851557448, 4.984519121307589, 4.995546926315066, 5.006478205776129, 5.017314840120846, 5.028058653404155, 5.038711415575329, 5.049274844633242, 5.059750608674316, 5.070140327839529, 5.080445576166457, 5.090667883351855, 5.100808736429982], [0.0, 2.0642492771517182, 2.3711997489679972, 2.571499191626862, 2.7237932510089204, 2.8481059563360973, 2.9538768912979823, 3.0463636820614597, 3.1288168267859735, 3.2033961042058743, 3.2716146269005324, 3.3345764463228758, 3.3931135258977476, 3.4478694364748015, 3.4993529503067093, 3.547973709111118, 3.594066742016091, 3.637909789108168, 3.6797358353051988, 3.7197423680040034, 3.75809834010488, 3.794949492065009, 3.8304224785029466, 3.8646281093771075, 3.8976639255169316, 3.9296162669412738, 3.9605619499231577, 3.9905696388530716, 4.019700977571339, 4.048011529338523, 4.075551563228671, 4.102366716270257, 4.1284985543034365, 4.153985049697569, 4.1788609903761635, 4.203158331738398, 4.226906500838722, 4.250132660436004, 4.272861939138974, 4.295117632771379, 4.316921381195563, 4.338293324119363, 4.35925223883191, 4.3798156623413815, 4.400000000000001, 4.4198206223821455, 4.439291951916784, 4.458427540555386, 4.477240139572586, 4.495741762442662, 4.51394374160503, 4.531856779822207, 4.549490996740581, 4.566855971185147, 4.583960779651636, 4.600814031401603, 4.617423900516171, 4.633798155221277, 4.6499441847601934, 4.665869024056941, 4.6815793763863685, 4.697081634242333, 4.712381898574233, 4.7274859965435745, 4.7423994979359945, 4.757127730349847, 4.771675793269874, 4.7860485711233665, 4.800250745406379, 4.814286805958884, 4.82816106145998, 4.8418776492074365, 4.8554405442397135, 4.868853567853133, 4.882120395562011, 4.895244564545174, 4.908229480618381, 4.921078424768637, 4.933794559283241, 4.9463809335035505, 4.958840489230872, 4.971176065809592, 4.983390404910531, 4.995486155035629, 5.007465875763357, 5.019332041752652, 5.031087046521794, 5.042733206017326, 5.0542727619869545, 5.065707885169297, 5.0770406783123425, 5.088273179031644, 5.099407362518387, 5.110445144106772, 5.121388381709449, 5.132238878129102, 5.142998383253724, 5.153668596142582, 5.164251167009357, 5.174747699108565, 5.18515975053086, 5.195488835912507], [0.0, 2.101696548530104, 2.4142153679994767, 2.6181484161870965, 2.7732052218295604, 2.899773067397644, 3.00746277881221, 3.1016273601366295, 3.1855762763848037, 3.26150848654963, 3.3309645523843803, 3.3950685537924374, 3.4546675467363976, 3.5104167769990364, 3.5628342464027427, 3.612337027921038, 3.6592662284008046, 3.7039046263745243, 3.7464894333084295, 3.7872217191919213, 3.826273501877373, 3.8637931656802, 3.8999096628435357, 3.9347358135145023, 3.9683709279977424, 4.0009029125949, 4.032409977092787, 4.062962031513455, 4.092621837969932, 4.121445967688496, 4.1494856016677755, 4.176787204831504, 4.203393097060208, 4.229341939574949, 4.254669151382323, 4.2794072675801536, 4.303586249055167, 4.3272337513222245, 4.350375358844803, 4.373034790053086, 4.3952340773752825, 4.416993725870986, 4.438332853465632, 4.459269315303929, 4.4798198143454115, 4.500000000000001, 4.519824556332028, 4.539307281137113, 4.558461157009064, 4.577298415356998, 4.595830594200608, 4.614068590459798, 4.6320227073601155, 4.649702697494744, 4.667117802014917, 4.684276786361656, 4.701187972901002, 4.717859270781247, 4.734298203292939, 4.75051193297972, 4.766507284719656, 4.782290766971983, 4.7978685913626125, 4.813246690762811, 4.828430735998953, 4.84342615131665, 4.858238128709713, 4.872871641213181, 4.887331455249506, 4.9016221421082475, 4.91574808863168, 4.929713507171739, 4.94352244487753, 4.957178792367003, 4.970686291831489, 4.9840485446173055, 4.997269018324661, 5.01035105346051, 5.023297869678784, 5.036112571638535, 5.048798154507899, 5.061357509139427, 5.0737934269402265, 5.086108604458359, 5.098305647705268, 5.11038707623235, 5.1223553269783775, 5.1342127579031756, 5.145961651421697, 5.157604217651636, 5.169142597486658, 5.180578865506425, 5.191915032733805, 5.20315304924882, 5.214294806668265, 5.2253421404992295, 5.236296832374193, 5.2471606121748255, 5.25793516005112, 5.268622108342016, 5.2792230434032845, 5.2897395073480045], [0.0, 2.1389777418892097, 2.4570402134834075, 2.6645907522203225, 2.822398051389954, 2.951211035689873, 3.0608110138157967, 3.1566459447282145, 3.2420839987784773, 3.3193631414542404, 3.390051261946053, 3.4552923797819113, 3.5159485765270126, 3.572686721119123, 3.6260340040173613, 3.6764148964936294, 3.7241765561590463, 3.7696067776466142, 3.8129469802262768, 3.854401800591277, 3.894146307953054, 3.932331518759791, 3.969088672689272, 4.004532591162172, 4.038764346110746, 4.07187340317299, 4.103939359469287, 4.135033365128907, 4.165219295578056, 4.194554725538416, 4.223091743888827, 4.25087763977658, 4.2779554837784195, 4.304364622912058, 4.330141104468339, 4.355318040672776, 4.379925923876836, 4.40399290016601, 4.42754500783681, 4.450606386051607, 4.4731994580634495, 4.495345092663362, 4.517062746902365, 4.538370592650767, 4.559285629155532, 4.5798237834254945, 4.6000000000000005, 4.6198283214285025, 4.63932196059809, 4.658493365886179, 4.677354279980992, 4.695915793098739, 4.714188391229956, 4.732181999965356, 4.749906024381429, 4.767369385406012, 4.784580553032422, 4.801547576706314, 4.818278113171019, 4.834779452023808, 4.851058539206655, 4.867121998629875, 4.882976152105036, 4.898627037744349, 4.914080426966815, 4.929341840236666, 4.944416561646514, 4.959309652446166, 4.974025963607826, 4.988570147509415, 5.002946668809728, 5.017159814582007, 5.03121370376619, 5.045112295994415, 5.058859399839317, 5.072458680530123, 5.085913667177478, 5.099227759544315, 5.11240423439678, 5.125446251466286, 5.138356859051114, 5.151138999283547, 5.163795513086398, 5.176329144840765, 5.188742546785134, 5.201038283164263, 5.213218834144855, 5.22528659951368, 5.237243902172581, 5.249092991443689, 5.260836046197163, 5.272475177812842, 5.284012432986363, 5.295449796389471, 5.3067891931936355, 5.3180324914653, 5.329181504440645, 5.340237992687054, 5.351203666158055, 5.362080186148029, 5.372869167152507, 5.383572178639522], [0.0, 2.176097180981549, 2.49967925210719, 2.7108315859588235, 2.871377444915748, 3.0024258268223765, 3.113927783464904, 3.2114258167141325, 3.2983465475503095, 3.376966778715908, 3.4488816082714764, 3.515254908856317, 3.5769637224456985, 3.6346864907022605, 3.6889595528545334, 3.740214746373335, 3.7888052533811907, 3.835023862847948, 3.8791161835906, 3.921290403531149, 3.961724630000974, 4.0005725001608266, 4.037967531198504, 4.074026537125183, 4.1088523438574445, 4.142535969604046, 4.1751583927996325, 4.206791998300155, 4.2375017700146005, 4.267346281806126, 4.296378526494703, 4.32464661387507, 4.352194361963098, 4.37906180059764, 4.405285602627812, 4.430899454902796, 4.4559343789328985, 4.480419009245771, 4.504379836001891, 4.527841417270355, 4.550826565433355, 4.573356511435201, 4.595451049981118, 4.617128668292813, 4.63840666061916, 4.659301230363469, 4.679827581409964, 4.7, 4.7198319283147585, 4.739336030758582, 4.758524253800214, 4.777407880113505, 4.795997577661002, 4.814303444280355, 4.8323350482620775, 4.8501014653462, 4.867611312512796, 4.884872778896169, 4.901893654113411, 4.918681354264166, 4.93524294582905, 4.951585167668538, 4.967714451301792, 4.983636939625346, 4.99935850421438, 5.014884761334281, 5.030221086776863, 5.045372629623962, 5.06034432503069, 5.075140906111506, 5.089766915004101, 5.104226713178821, 5.118524491054956, 5.132664276979393, 5.146649945618063, 5.1604852258059255, 5.174173707897186, 5.187718850653656, 5.201123987705899, 5.214392333618746, 5.227526989590102, 5.240530948809492, 5.253407101500595, 5.2661582396700135, 5.278787061582706, 5.291296175982879, 5.303688106077605, 5.31596529329913, 5.32813010086052, 5.340184817118241, 5.352131658754178, 5.363972773788682, 5.375710244435379, 5.387346089807657, 5.398882268486066, 5.4103206809551425, 5.421663171917647, 5.432911532493533, 5.444067502310561, 5.455132771492917, 5.4661089825538, 5.476997732197513], [0.0, 2.213058987556147, 2.5421372185171496, 2.7568760519928843, 2.920148841087388, 3.0534231276945416, 3.1668189858549467, 3.265973058860973, 3.354370170103581, 3.434325794652614, 3.5074621238926214, 3.5749627992653967, 3.637719759624956, 3.6964229702137334, 3.7516178801782343, 3.8037436619066725, 3.8531594964491083, 3.900163145903136, 3.9450043908413424, 3.987894955333734, 4.029015971929861, 4.068523687373846, 4.106553886691757, 4.143225368023479, 4.178642703821397, 4.212898458271834, 4.24607498525777, 4.278245899118409, 4.309477287538202, 4.339828719278796, 4.369354087262593, 4.398102318446794, 4.426117975112294, 4.453441767019403, 4.480110989918993, 4.506159902843699, 4.53162005421553, 4.556520564930062, 4.580888375092836, 4.604748459900736, 4.628124019212611, 4.651036644588125, 4.673506466952808, 4.695552287540596, 4.717191694349502, 4.738441166003569, 4.759316164630555, 4.77983121912885, 4.800000000000001, 4.819835386757889, 4.8393495287864, 4.858553900399725, 4.87745935075966, 4.896076149219318, 4.914414026590127, 4.9324822127668835, 4.950289471092217, 4.967844129795875, 4.985154110804443, 5.002226956182731, 5.019069852438112, 5.035689652893073, 5.052092898308479, 5.068285835920211, 5.084274437034299, 5.100064413310453, 5.115661231850277, 5.1310701291946454, 5.146296124324086, 5.1613440307467355, 5.176218467750156, 5.190923870885865, 5.2054645017489545, 5.219844457109258, 5.2340676774453225, 5.248137954927736, 5.262058940894181, 5.275834152854805, 5.289466981063105, 5.302960694684472, 5.316318447591793, 5.329543283815009, 5.342638142669308, 5.355605863584544, 5.368449190656695, 5.38117077694044, 5.393773188500447, 5.406258908237582, 5.418630339504949, 5.430889809527587, 5.443039572638532, 5.455081813343046, 5.467018649221917, 5.478852133683911, 5.490584258576783, 5.5022169566655, 5.513752103985769, 5.525191522080373, 5.536536980125285, 5.547790196952071, 5.558952842972615, 5.570026542011827], [0.0, 2.2498670948012274, 2.584418630760128, 2.802729050016767, 2.9687174297778487, 3.1042083650428243, 3.2194902492566633, 3.320293475662357, 3.4101608280368407, 3.4914462929650933, 3.5657990424927277, 3.6344224046588542, 3.6982231532501233, 3.7579027291699343, 3.814015653600737, 3.867008403347146, 3.9172461334412456, 3.9650315584284797, 4.010618613289499, 4.054222543537849, 4.096027494361399, 4.136192311236139, 4.174855037595995, 4.212136447458896, 4.248142852550364, 4.282968356605608, 4.316696683236372, 4.349402671152521, 4.381153507224108, 4.412009750974157, 4.442026191684578, 4.471252570077002, 4.499734189602455, 4.527512437115363, 4.554625228678125, 4.581107393127504, 4.606991003606137, 4.632305665355047, 4.6570787665538225, 4.681335697792579, 4.705100044795565, 4.728393758238243, 4.751237303868338, 4.773649795626241, 4.795649114037604, 4.817252011802743, 4.838474208219089, 4.85933047383302, 4.879834706517015, 4.9, 4.919838705737216, 4.939362488886289, 4.958582379054778, 4.977508816398042, 4.99615169357261, 5.0145203939870155, 5.032623826737824, 5.050470458571818, 5.068068343174892, 5.085425148053219, 5.102548179241818, 5.119444404049214, 5.136120472023718, 5.152582734306675, 5.168837261520256, 5.1848898603218085, 5.200746088743034, 5.216411270420161, 5.231890507810556, 5.247188694481737, 5.26231052655032, 5.277260513340935, 5.292042987328509, 5.306662113421296, 5.321121897636789, 5.335426195217831, 5.349578718231997, 5.363583042693472, 5.377442615243233, 5.39116075942018, 5.404740681553143, 5.418185476301071, 5.431498131866519, 5.444681534905393, 5.457738475154107, 5.47067164979356, 5.483483667567795, 5.496177052673861, 5.508754248437984, 5.521217620792145, 5.5335694615639675, 5.5458119915919095, 5.557947363676849, 5.569977665380321, 5.581904921678953, 5.593731097483902, 5.605458100033534, 5.617087781166952, 5.628621939485472, 5.640062322408662, 5.651410628131082, 5.6626685074854715], [0.0, 2.286525259636632, 2.6265278044037674, 2.848395260141756, 3.0170881682725814, 3.1547867224009662, 3.271946949706187, 3.3743926114797564, 3.465724215775732, 3.548334103812776, 3.623898318388478, 3.6936397939434613, 3.7584800787650634, 3.8191320426701165, 3.876159241920945, 3.930015427983114, 3.981071705534973, 4.029635721395401, 4.075965548029614, 4.120279938049658, 4.162766037009367, 4.203585278530336, 4.242877955254442, 4.280766809028679, 4.317359883766555, 4.3527528164806215, 4.387030694931628, 4.420269577212474, 4.452537744901144, 4.483896744246047, 4.514402257237172, 4.5441048350456095, 4.573050519273264, 4.601281371110454, 4.6288359244041875, 4.655749575474188, 4.682054920046205, 4.70778204573367, 4.732958786964929, 4.757610948031174, 4.781762498950185, 4.805435748050317, 4.82865149453755, 4.851429163784885, 4.873786927653961, 4.895741811804885, 4.917309791657149, 4.938505878420735, 4.9593441964128315, 4.979838052704777, 5.000000000000001, 5.0198418935221465, 5.039374942589461, 5.058609757463772, 5.077556391987408, 5.096224382457284, 5.1146227831301525, 5.132760198705567, 5.150644814091995, 5.168284421725968, 5.185686446683241, 5.202857969794042, 5.219805748950965, 5.2365362387775525, 5.253055608807535, 5.269369760308918, 5.28548434187308, 5.301404763876813, 5.317136211914271, 5.332683659286215, 5.348051878625345, 5.363245452728884, 5.378268784662851, 5.393126107196351, 5.407821491618843, 5.422358855988493, 5.436741972855375, 5.450974476499392, 5.465059869719294, 5.4790015302059984, 5.49280271653059, 5.50646657377478, 5.519996138829346, 5.533394345383862, 5.546664028629259, 5.559807929692895, 5.572828699824338, 5.585728904348588, 5.598511026402158, 5.611177470466297, 5.623730565710475, 5.6361725691583375, 5.64850566868738, 5.660731985872783, 5.672853578685087, 5.684872444050691, 5.696790520283512, 5.708609689395557, 5.720331779293615, 5.731958565868802, 5.743491774985176, 5.754933084373288], [0.0, 2.3230370739754016, 2.6684688654726694, 2.8938791569250593, 3.0652657961292595, 3.205163155637932, 3.324194227120022, 3.428275767162036, 3.5210657776423573, 3.604994801290015, 3.681765644378398, 3.7526207694749485, 3.8184964403834094, 3.8801169102063615, 3.9380547342152283, 3.9927709094938773, 4.044642466614132, 4.093981964977178, 4.141051598014704, 4.186073611435858, 4.229238139182065, 4.270709192687871, 4.310629304823581, 4.3491231774090835, 4.386300579630456, 4.422258675656283, 4.457083911950225, 4.4908535611200655, 4.523636995081319, 4.555496742868473, 4.586489375615633, 4.616666251707789, 4.646074147950803, 4.674755797178733, 4.702750348556813, 4.730093763622162, 4.756819158597333, 4.782957101542385, 4.808535871352868, 4.833581684369428, 4.858118893369158, 4.882170162905451, 4.905756624311274, 4.928898013148901, 4.9516127914528605, 4.973918256753312, 4.9958306395692915, 5.017365190813583, 5.0385362603440464, 5.059357367722706, 5.079841266097739, 5.100000000000001, 5.119844957740973, 5.139386919009828, 5.158636098191196, 5.177602183859994, 5.196294374853642, 5.214721413273714, 5.232891614727366, 5.250812896082731, 5.268492800981056, 5.285938523321055, 5.3031569289070655, 5.32015457543169, 5.336937730945339, 5.353512390948958, 5.369884294232064, 5.386058937565714, 5.402041589348944, 5.417837302297442, 5.433450925254513, 5.448887114196646, 5.464150342499137, 5.4792449105210155, 5.494174954563125, 5.508944455248175, 5.523557245367273, 5.538017017233426, 5.55232732957896, 5.5664916140306175, 5.58051318119317, 5.594395226369792, 5.6081408349450985, 5.621752987454565, 5.635234564362167, 5.64858835056628, 5.661817039652296, 5.674923237908973, 5.687909468124177, 5.700778173174523, 5.7135317194222495, 5.726172399931726, 5.7387024375170315, 5.751123987631193, 5.763439141106947, 5.775649926758121, 5.7877583138501185, 5.799766214447389, 5.8116754856452015, 5.823487931692551, 5.835205306012528, 5.846829313126113], [0.0, 2.359405975059458, 2.710245762320975, 2.9391850222452844, 3.1132548488157887, 3.2553424072183534, 3.3762370000850823, 3.481948015298573, 3.57619072352124, 3.661433719465473, 3.7394064681238106, 3.8113708837542073, 3.878277888077858, 3.9408630729270357, 3.9997079573586616, 4.055280755714359, 4.107964401264504, 4.158076346763933, 4.205882890480665, 4.251609757548393, 4.295450058599094, 4.337570372790277, 4.378115464452053, 4.417211987705549, 4.4549714302564105, 4.4914924774517155, 4.526862929139846, 4.561161267689663, 4.594457951086446, 4.6268164873039765, 4.658294333140218, 4.688943651034494, 4.718811950118916, 4.747942632242354, 4.7763754594798105, 4.804146956373449, 4.831290757605314, 4.857837909801549, 4.883817134585183, 4.909255058733492, 4.934176416284696, 4.958604226622903, 4.982559951908068, 5.006063636677607, 5.029134032003155, 5.0517887062207745, 5.074044143950547, 5.09591583486982, 5.117418353494327, 5.138565431045051, 5.159370020330343, 5.179844354447291, 5.200000000000001, 5.219847905441825, 5.2393984450713065, 5.258661459145324, 5.277646290516049, 5.296361818149262, 5.314816487839238, 5.3330183403986595, 5.350975037570178, 5.368693885878433, 5.386181858617116, 5.403445616144462, 5.42049152464195, 5.437325673474622, 5.4539538912770835, 5.470381760876497, 5.486614633152666, 5.50265763992536, 5.518515705950194, 5.534193560096487, 5.549695745773604, 5.565026630665947, 5.580190415831274, 5.595191144211952, 5.610032708604333, 5.624718859127369, 5.639253210228033, 5.65363924725778, 5.667880332651397, 5.681979711736948, 5.6959405182030745, 5.709765779247787, 5.7234584204309025, 5.7370212702504855, 5.750457064462042, 5.76376845015775, 5.7769579896216285, 5.790028163975371, 5.802981376628404, 5.815819956544753, 5.828546161338332, 5.841162180207415, 5.853670136718306, 5.866072091447443, 5.878370044490569, 5.890565937846948, 5.902661657686081, 5.914659036503839, 5.926559855174483, 5.9383658449045535], [0.0, 2.3956352549618356, 2.7518622765475627, 2.984316957139667, 3.1610596702485814, 3.305329019313044, 3.428079979456092, 3.5354142142423988, 3.6311040432620154, 3.7176559671281186, 3.796826007208857, 3.8698954547771414, 3.937829833199483, 4.00137602950816, 4.061124492133378, 4.117550624967275, 4.17104324131816, 4.2219246685088025, 4.270465293884981, 4.316894308647328, 4.361407788690775, 4.404174871038239, 4.445342542913005, 4.485039403242499, 4.523378651654494, 4.560460488834716, 4.59637406282059, 4.631199061097746, 4.665007023551781, 4.697862433337595, 4.729823629516923, 4.760943575496635, 4.791270509923671, 4.820848501093349, 4.849717921637464, 4.877915856941832, 4.905476458157607, 4.932431248639789, 4.958809391039249, 4.984637920994207, 5.009941952340348, 5.034744857930284, 5.059068429480905, 5.082933019318607, 5.1063576664425065, 5.129360208954944, 5.151957384601542, 5.17416492090759, 5.195997616184224, 5.217469412498824, 5.238593461553412, 5.259382184287403, 5.27984732491305, 5.300000000000002, 5.319850743146794, 5.33940954570996, 5.358685894003546, 5.377688803332115, 5.396426849177264, 5.414908195820402, 5.4331406226521946, 5.451131548390825, 5.468888053406688, 5.486416900329516, 5.503724553095125, 5.520817194572313, 5.537700742895852, 5.554380866618636, 5.570862998784595, 5.5871523500138975, 5.603253920683034, 5.61917251227432, 5.634912737962326, 5.650479032498361, 5.665875661448498, 5.681106729835512, 5.696176190230633, 5.71108785033685, 5.7258453801018865, 5.740452318395657, 5.754912079283993, 5.7692279579277965, 5.783403136134298, 5.7974406875849045, 5.811343582762148, 5.825114693596402, 5.838756797851396, 5.852272583266083, 5.865664651469005, 5.878935521680111, 5.892087634213793, 5.905123353795912, 5.918044972706619, 5.930854713759884, 5.943554733129914, 5.956147123033823, 5.968633914279334, 5.981017078685603, 5.993298531384746, 6.005480133011075, 6.017563691784629, 6.029550965495063], [0.0, 2.431728069337104, 2.7933220330476476, 3.0292788927047387, 3.208684424338806, 3.3551273458722166, 3.4797276808771733, 3.5886790210238346, 3.6858105199425952, 3.773666441366528, 3.854029263008983, 3.9281995801700504, 3.9971574628612565, 4.06166105076904, 4.122309688062448, 4.179585941103113, 4.233884481088825, 4.285532491549161, 4.334804433505246, 4.3819329511689515, 4.427117074528854, 4.470528488838516, 4.51231639584138, 4.552611331945635, 4.591528202252848, 4.629168717079538, 4.665623367573924, 4.700973041799071, 4.735290357465676, 4.768640769236523, 4.801083495113881, 4.832672296455146, 4.863456138674208, 4.893479754002518, 4.922784123328866, 4.951406890770179, 4.97938272200133, 5.006743615310469, 5.033519172715079, 5.059736837174266, 5.085422100890581, 5.110598688853728, 5.135288721096185, 5.159512856573972, 5.183290421129144, 5.206639521614187, 5.229577147946811, 5.252119264604341, 5.2742808928503395, 5.296076184804386, 5.317518490313, 5.338620417450366, 5.359393887367894, 5.379850184118273, 5.4, 5.41985347690011, 5.439420244054144, 5.458709452591895, 5.477729807193789, 5.496489595144892, 5.51499671304073, 5.533258691370434, 5.55128271717777, 5.569075654978744, 5.586644066095295, 5.60399422654777, 5.621132143633988, 5.638063571309674, 5.65479402447339, 5.671328792248887, 5.687672950348689, 5.703831372594591, 5.719808741663587, 5.735609559121272, 5.7512381547990445, 5.766698695566252, 5.781995193543847, 5.797131513801948, 5.812111381579979, 5.826938389064723, 5.8416160017585765, 5.856147564467573, 5.870536306936282, 5.884785349154416, 5.898897706358015, 5.912876293746161, 5.926723930932574, 5.940443346149877, 5.954037180222937, 5.967507990326451, 5.980858253540767, 5.994090370218876, 6.007206667176588, 6.02020940071695, 6.033100759499244, 6.045882867262081, 6.058557785409477, 6.071127515468165, 6.083594001423772, 6.095959131943068, 6.1082247424888605, 6.1203926173337955], [0.0, 2.467687445492278, 2.834628509283815, 3.074074600150511, 3.256133105642016, 3.4047415637611507, 3.5311844363310607, 3.641746903261323, 3.740314742102371, 3.829469840093692, 3.9110210334824664, 3.9862881502273253, 4.056265753204621, 4.121723193152928, 4.183268677091828, 4.241391907372184, 4.2964933914241525, 4.348905151030303, 4.398905705826383, 4.446731140269425, 4.492583427520113, 4.536636791641628, 4.579042640710302, 4.619933441452051, 4.659425798136957, 4.6976229251311, 4.734616651727894, 4.7704890621292, 4.805313847886006, 4.839157431577234, 4.872079906896165, 4.904135830200632, 4.935374890984556, 4.9658424829608885, 4.995580193026641, 5.024626221964173, 5.0530157480698366, 5.080781242809066, 5.107952745941579, 5.134558106241467, 5.160623192879295, 5.186172081679977, 5.211227219777766, 5.23580957162467, 5.2599387488452045, 5.283633126048403, 5.306909944391761, 5.329785404428612, 5.35227474955067, 5.374392341153132, 5.3961517264944545, 5.417565700091743, 5.438646359381402, 5.459405155279964, 5.47985293819916, 5.5, 5.519856112311128, 5.539430561585412, 5.558732181224445, 5.577769381062194, 5.596550174465732, 5.61508220328191, 5.633372760833486, 5.651428813146052, 5.66925701856763, 5.686863745925726, 5.704255091351564, 5.721436893887957, 5.738414749985474, 5.755194026981214, 5.771779875645213, 5.788177241871299, 5.804390877581934, 5.8204253509099795, 5.8362850557145665, 5.85197422048296, 5.867496916665679, 5.882857066487879, 5.898058450276264, 5.913104713337371, 5.927999372419993, 5.942745821791756, 5.957347338957338, 5.971807090043555, 5.986128134874491, 6.000313431757974, 6.014365842002989, 6.028288134186121, 6.0420829881836475, 6.055752998984698, 6.069300680299642, 6.082728467976889, 6.096038723240223, 6.109233735757959, 6.122315726554355, 6.135286850772976, 6.148149200301022, 6.160904806262961, 6.173555641391267, 6.1861036222815216, 6.19855061153859, 6.210898419820194], [0.0, 2.5035162898423478, 2.8757850438501853, 3.118707700088062, 3.303409549195784, 3.454175683046819, 3.582454404807743, 3.6946221501641046, 3.794621115042694, 3.88507067361685, 3.967805924986641, 4.044165859955078, 4.115159481654537, 4.1815673111798315, 4.244006386229115, 4.302973519238985, 4.358875032686558, 4.412047769044635, 4.462774291830899, 4.511294113259523, 4.557812138979644, 4.602505122648233, 4.645526670665568, 4.68701117306828, 4.727076927127017, 4.765828645797749, 4.803359491661647, 4.83975274071741, 4.875083154458296, 4.909418119865849, 4.942818603145625, 4.975339952770055, 5.0070325796846955, 5.037942536682837, 5.068112014469911, 5.097579768473025, 5.126381487749211, 5.154550115223557, 5.182116126809023, 5.209107775621584, 5.235551306431433, 5.261471144625172, 5.286890063251453, 5.3118293311493305, 5.336308844688392, 5.360347245262271, 5.383962024356256, 5.40716961774273, 5.429985490135244, 5.452424211444943, 5.474499525625621, 5.496224412960521, 5.517611146531128, 5.53867134351211, 5.559416011854481, 5.579855592848824, 5.600000000000001, 5.619858654592738, 5.639440518282538, 5.6587541230074185, 5.677807598482122, 5.696608697506992, 5.715164819297989, 5.733483031021816, 5.751570087700371, 5.769432450631432, 5.787076304457164, 5.804507572998602, 5.821731933962296, 5.838754832614776, 5.8555814945111315, 5.872216937355607, 5.888665982064772, 5.904933263097114, 5.921023238107078, 5.9369401969761775, 5.952688270269131, 5.968271437158657, 5.983693532858777, 5.9989582556029575, 6.014069173200366, 6.029029729200674, 6.0438432486953015, 6.058512943780689, 6.073041918707113, 6.087433174734663, 6.101689614716236, 6.115814047425932, 6.129809191649683, 6.143677680053782, 6.157422062845659, 6.17104481124029, 6.184548320744538, 6.197934914270864, 6.211206845091022, 6.2243662996395335, 6.237415400176124, 6.250356207315559, 6.263190722432811, 6.275920889950894, 6.288548599518199, 6.301075688081751], [0.0, 2.5392173948075056, 2.9167948443952385, 3.16318167112162, 3.350517439620643, 3.5034335565141874, 3.6335415821741774, 3.7473088827109544, 3.8487338712811106, 3.940473275340918, 4.024388363209259, 4.101837220212876, 4.173843238256802, 4.241198068966794, 4.30452754923585, 4.364335576236952, 4.421034266761982, 4.4749652667869295, 4.526415169293891, 4.575626902033315, 4.622808292687687, 4.668138615489092, 4.711773667324142, 4.753849754683068, 4.794486861801085, 4.83379119488118, 4.871857245038758, 4.908769475820277, 4.94460371484664, 4.97942831006366, 5.013305097078424, 5.046290213653867, 5.078434789615011, 5.109785534485688, 5.140385240627014, 5.170273216133388, 5.199485659001518, 5.228055981935274, 5.25601509544585, 5.283391655549522, 5.310212281276997, 5.33650174633028, 5.362283148510457, 5.387578059958404, 5.4124066607735895, 5.43678785818309, 5.460739393107498, 5.484277935699632, 5.507419171205804, 5.530177877309694, 5.552567993959164, 5.5746026865412865, 5.596294403156408, 5.617654926644573, 5.63869542193441, 5.659426479213323, 5.679858153356564, 5.700000000000001, 5.719861108595792, 5.739450132750671, 5.758775318112237, 5.77784452803875, 5.796665267261834, 5.815244703728707, 5.833589688790477, 5.851706775885513, 5.869602237851356, 5.887282082985005, 5.904752069959289, 5.922017721692334, 5.939084338257653, 5.9559570089138845, 5.972640623325719, 5.989139882040806, 6.005459306281458, 6.021603247104546, 6.037575893978231, 6.053381282819766, 6.069023303534797, 6.084505707095022, 6.09983211218794, 6.115006011469564, 6.130030777448398, 6.14490966802661, 6.159645831722282, 6.174242312594625, 6.188702054892335, 6.203027907443711, 6.217222627805617, 6.231288886187179, 6.245229269162769, 6.259046283187835, 6.27274235793009, 6.286319849427621, 6.299781043084703, 6.313128156515255, 6.32636334224324, 6.339488690268586, 6.35250623050664, 6.365417935108636, 6.378225720670079, 6.390931450333562], [0.0, 2.5747934452029173, 2.9576609949617394, 3.2074998578085054, 3.3974603195514437, 3.552518888482376, 3.684449810317854, 3.799811063080038, 3.9026570802364446, 3.9956818116844275, 4.080772603295601, 4.159306568035744, 4.232321436181256, 4.300619950900587, 4.364836717459575, 4.425482692951023, 4.482975768185136, 4.537662375815279, 4.589833124173475, 4.639734344582432, 4.687576776522625, 4.7335422059721335, 4.7777886126310225, 4.8204542127301275, 4.861660671560098, 4.90151568334036, 4.9401150630669335, 4.9775444576742744, 5.013880757176472, 5.049193267117521, 5.083544689460689, 5.1169919484946655, 5.149586890405835, 5.181376879148161, 5.2124053066309495, 5.24271203168, 5.272333759448972, 5.301304370774963, 5.329655209245086, 5.357415332364629, 5.384611732113843, 5.4112695292900534, 5.437412145309227, 5.463061454551652, 5.488237919852823, 5.512960713342089, 5.537247824501624, 5.561116157043687, 5.584581615974865, 5.607659186023584, 5.63036300244524, 5.652706415082349, 5.674702046441061, 5.696361844446502, 5.717697130455048, 5.738718643029365, 5.759436577919902, 5.779860624643059, 5.800000000000002, 5.819863478839995, 5.8394594223374074, 5.8587958040211445, 5.877880233768895, 5.896719979955376, 5.915321989923479, 5.933692908929413, 5.951839097697163, 5.969766648703789, 5.9874814013047875, 6.004988955797879, 6.0222946865139795, 6.039403754015475, 6.0563211164743675, 6.07305154029597, 6.0895996100477925, 6.105969737747781, 6.12216617156121, 6.138193003951097, 6.154054179323142, 6.169753501202542, 6.185294638976907, 6.200681134236585, 6.215916406741065, 6.231003760037798, 6.245946386757607, 6.260747373608908, 6.2754097060911915, 6.289936272946654, 6.304329870367286, 6.3185932059735395, 6.332728902579339, 6.346739501757167, 6.360627467215926, 6.374395188003296, 6.388044981543517, 6.401579096520691, 6.414999715617011, 6.428308958114631, 6.441508882369304, 6.454601488163355, 6.467588718945014, 6.480472463960686], [0.0, 2.6102470241664695, 2.998386462795929, 3.251665478043504, 3.444241597459062, 3.6014352429833463, 3.7351827856292203, 3.8521325033969216, 3.956394657213585, 4.050700291278474, 4.136962739243317, 4.216578076209812, 4.290598321465528, 4.359837271538695, 4.424938269882654, 4.486419309206083, 4.544704034460303, 4.600143648497807, 4.653032761177594, 4.703621095677759, 4.752122293252826, 4.798720642980122, 4.843576299858774, 4.886829383285894, 4.928603233820492, 4.9690070285759, 5.008137901871261, 5.046082679955184, 5.082919311577632, 5.1187180565842265, 5.153542480311962, 5.1874502908676465, 5.220494048332939, 5.252721768839041, 5.284177441779489, 5.314901474815577, 5.344931078512014, 5.374300600227567, 5.403041815134393, 5.431184180844653, 5.458755061004259, 5.48577992231097, 5.512282508681581, 5.538284995695326, 5.5638081279504, 5.588871341566494, 5.613492873731682, 5.637689860913628, 5.661478427122666, 5.684873763419212, 5.707890199693842, 5.730541269609526, 5.75283976947782, 5.774797811740621, 5.79642687364355, 5.817737841613745, 5.838741051791887, 5.859446327114024, 5.8798630112919215, 5.9, 5.91986576954169, 5.9394684032372815, 5.9588156157485574, 5.977914775532008, 5.996772925591858, 6.015396802686071, 6.033792855122521, 6.05196725926854, 6.06992593488454, 6.087674559381456, 6.105218581091969, 6.122563231636751, 6.139713537459279, 6.156674330595809, 6.173450258740985, 6.190045794663966, 6.206465245025072, 6.222712758638429, 6.238792334222171, 6.254707827674076, 6.270462958907332, 6.286061318278159, 6.301506372634374, 6.316801471011573, 6.331949850001461, 6.346954638814836, 6.361818864059982, 6.376545454255584, 6.391137244095757, 6.405596978483491, 6.419927316347504, 6.434130834256426, 6.448210029843161, 6.462167325051342, 6.476005069214948, 6.4897255419813025, 6.503330956087008, 6.51682345999564, 6.530205140405452, 6.54347802463474, 6.556644082892014, 6.569705230437628], [0.0, 2.6455806186651616, 3.0389741046727097, 3.2956816299183536, 3.4908645549161283, 3.650186051359235, 3.78574406688116, 3.904276873860757, 4.009950371749614, 4.10553257351179, 4.192962712629476, 4.273655762167313, 4.348677982066174, 4.418854184806522, 4.484836422456818, 4.547149699531195, 4.606223395648531, 4.6624134677167985, 4.716018513579737, 4.767291636791868, 4.816449370561385, 4.863678498593695, 4.909141343825192, 4.952979922378438, 4.995319244411239, 5.036269964912326, 5.075930533059015, 5.114388950422955, 5.151724220906934, 5.188007555428589, 5.223303379776746, 5.257670183223686, 5.291161237330323, 5.323825208197957, 5.3557066806823075, 5.3868466094227525, 5.417282708684606, 5.447049790769469, 5.476180060973942, 5.50470337566299, 5.532647468890367, 5.560038152083648, 5.586899490569027, 5.613253960105345, 5.639122586099933, 5.6645250677694134, 5.689479889169453, 5.71400441873542, 5.7381149987402225, 5.761827025877984, 5.785155024015764, 5.808112710014889, 5.830713053404114, 5.852968330585341, 5.874890174165862, 5.8964896179368775, 5.917777137954178, 5.938762690121932, 5.959455744633009, 5.979865317578078, 6.000000000000001, 6.019867984638892, 6.039477090586009, 6.058834786040913, 6.077948209345419, 6.096824188449575, 6.115469258948741, 6.133889680816609, 6.152091453946397, 6.170080332601282, 6.187861838865271, 6.20544127517684, 6.2228237360198895, 6.240014118839509, 6.257017134243834, 6.273837315547641, 6.29047902770833, 6.306946475700431, 6.323243712370701, 6.339374645812258, 6.355343046292875, 6.371152552769608, 6.386806679019242, 6.402308819411574, 6.417662254350414, 6.432870155405106, 6.447935590153601, 6.46286152675646, 6.477650838279618, 6.492306306782432, 6.506830627186193, 6.5212264109372375, 6.535496189477664, 6.549642417535732, 6.563667476247167, 6.5775736761177255, 6.591363259836707, 6.6050384049503545, 6.618601226403499, 6.632053778957218, 6.645398059489741, 6.658636009187332], [0.0, 2.6807966246166024, 3.079426672778695, 3.3395512981017474, 3.5373323533548797, 3.698774619328632, 3.8361370825576904, 3.956247710302447, 4.063327855376541, 4.16018237647851, 4.248776320727584, 4.330543496259812, 4.406564356277144, 4.477674692551703, 4.544535236785207, 4.607677981962285, 4.6675380232846635, 4.724476055894526, 4.778794652348521, 4.8307502853278645, 4.880562370370131, 4.928420177506806, 4.974488190396754, 5.0189103155757735, 5.061813227244124, 5.103309053347628, 5.143497553545995, 5.182467900822491, 5.220300150721229, 5.257066462066737, 5.292832118236134, 5.32765638706749, 5.361593249233205, 5.394692018641604, 5.426997873628921, 5.458552313992302, 5.489393556021374, 5.519556875413262, 5.549074906157576, 5.577977902045056, 5.606293966304599, 5.634049253946349, 5.661268150636264, 5.687973431313807, 5.714186401260931, 5.739927021915608, 5.76521402337954, 5.790065005283817, 5.814496527437558, 5.83852419148425, 5.862162714621896, 5.8854259963005005, 5.908327178689559, 5.930878701605327, 5.953092352499732, 5.9749793120376165, 5.996550195724249, 6.01781509198941, 6.0387835970861445, 6.059464847120631, 6.07986754749332, 6.100000000000001, 6.119870127813874, 6.139485498545629, 6.15885334555739, 6.17798058768781, 6.196873847529244, 6.2155394683835095, 6.233983530009948, 6.25221186326822, 6.270230063748216, 6.288043504470538, 6.305657347733077, 6.323076556172075, 6.3403059030997895, 6.3573499821751165, 6.374213216458534, 6.390899866898069, 6.407414040288967, 6.423759696745983, 6.439940656723897, 6.455960607618859, 6.471823109980444, 6.487531603361782, 6.503089411832983, 6.518499749180968, 6.53376572381701, 6.548890343411621, 6.563876519274857, 6.578727070498785, 6.593444727877489, 6.608032137618941, 6.622491864861916, 6.636826397010197, 6.651038146895421, 6.665129455779082, 6.679102596203495, 6.692959774700783, 6.706703134368352, 6.720334757318737, 6.733856667011126, 6.747270830471415], [0.0, 2.7158973516583815, 3.1197468201907865, 3.3832773597806907, 3.583648040360387, 3.7472041335670285, 3.886365137678791, 4.008048421223161, 4.116530608850325, 4.214653284379506, 4.304407224066535, 4.387245009462629, 4.464261240569453, 4.53630265251029, 4.604038628207507, 4.668008126239605, 4.7286519386813115, 4.786335483398501, 4.84136529464959, 4.894001203213715, 4.944465497522583, 4.992949925794818, 5.039621125338674, 5.084624886914951, 5.1280895433191525, 5.1701286906325015, 5.210843394707257, 5.250323996103709, 5.28865159856477, 5.325899305718905, 5.362133255724226, 5.3974134924359705, 5.431794703316763, 5.465326847961371, 5.498055696243796, 5.530023291334388, 5.561268349903719, 5.591826609527525, 5.621731131485104, 5.651012565692008, 5.679699383343787, 5.707818081908445, 5.735393366343076, 5.762448309788406, 5.789004496484842, 5.8150821492333336, 5.8407002433761885, 5.865876608983404, 5.890628022688208, 5.9149702904125565, 5.938918322052529, 5.962486199049106, 5.985687235647392, 6.008534034543058, 6.03103853752579, 6.053212071653278, 6.0750653914237915, 6.096608717358893, 6.117851771359158, 6.138803809153401, 6.159473650125314, 6.179869704769371, 6.200000000000001, 6.219872202513607, 6.239493640381573, 6.258871323033634, 6.278011959774357, 6.2969219769609115, 6.315607533957327, 6.334074537969005, 6.352328657851101, 6.370375336975295, 6.388219805231478, 6.405867090233647, 6.423322027792916, 6.44058927171477, 6.45767330297256, 6.474578438304586, 6.491308838277983, 6.507868514858849, 6.524261338524683, 6.54049104495217, 6.556561241310563, 6.572475412188415, 6.588236925179198, 6.603849036149214, 6.619314894209386, 6.634637546410844, 6.649819942182575, 6.6648649375281295, 6.679775298996954, 6.6945537074448636, 6.709202761597011, 6.7237249814257325, 6.738122811354823, 6.752398623300837, 6.766554719561381, 6.780593335559573, 6.794516642453238, 6.808326749616832, 6.822025707003491, 6.835615507394158], [0.0, 2.7508850275948054, 3.159937105984126, 3.4268625901999354, 3.629814555538057, 3.795477667842105, 3.936431420163544, 4.059682294356702, 4.1695620088908605, 4.268948754423031, 4.359858953478209, 4.443763900558069, 4.521772296900505, 4.594741785734032, 4.663350373338132, 4.728143961450658, 4.789569020671064, 4.847995676378143, 4.903734411772377, 4.957048404915191, 5.008162807879514, 5.057271839089454, 5.104544282566262, 5.150127807227101, 5.1941523991207745, 5.2367331177353895, 5.2779723309088205, 5.317961543017895, 5.356782902628323, 5.3945104551295175, 5.431211190707536, 5.466945926735418, 5.501770055189611, 5.535734179271719, 5.568884658488311, 5.601264077632861, 5.632911652145283, 5.6638635799923165, 5.694153348366756, 5.723812002033136, 5.752868378968529, 5.781349317995821, 5.809279842334886, 5.836683322367272, 5.8635816203933855, 5.889995219735363, 5.9159433401862564, 5.941444041512782, 5.966514316473938, 5.991170174612216, 6.0154267179011365, 6.0392982091865095, 6.062798134234829, 6.085939258096592, 6.108733676402149, 6.131192862130552, 6.1533277083253966, 6.175148567174602, 6.196665285821584, 6.217887239232522, 6.238823360407234, 6.2594821681887876, 6.279871792898717, 6.300000000000002, 6.319874211968252, 6.339501528532513, 6.358888745430286, 6.378042371806588, 6.396968646373748, 6.415673552437019, 6.434162831880853, 6.4524419982014205, 6.470516348662917, 6.488390975647815, 6.506070777264792, 6.523560467272204, 6.540864584369752, 6.55798750090632, 6.574933431047747, 6.591706438444474, 6.6083104434356095, 6.624749229822868, 6.641026451245031, 6.65714563718103, 6.673110198607518, 6.688923433334648, 6.704588531041915, 6.7201085780342265, 6.73548656173673, 6.750725374945574, 6.765827819850411, 6.78079661184331, 6.795634383127618, 6.810343686139339, 6.824926996792669, 6.839386717560491, 6.853725180399871, 6.867944649531868, 6.882047324084351, 6.896035340605894, 6.909910775458249, 6.923675647094454], [0.0, 2.7857618025475976, 3.2000000000000006, 3.470309667832636, 3.6758347359905126, 3.8435981887405806, 3.9863390067696565, 4.111152502795006, 4.222425314473262, 4.3230721232659635, 4.415134916675888, 4.500103642840433, 4.579101059536819, 4.652995683523192, 4.722474117102567, 4.7880891831643035, 4.8502930128332755, 4.909460424079716, 4.965905836529152, 5.0198957649153595, 5.071658215875565, 5.121389870209509, 5.169261651846971, 5.215423101908255, 5.260005854455123, 5.3031264277439805, 5.344888487471394, 5.385384698141759, 5.424698249831795, 5.462904126706747, 5.500070168279933, 5.536257962990363, 5.571523605095195, 5.605918339362826, 5.639489113063416, 5.672279050896781, 5.704327865491211, 5.735672213745151, 5.766346007414857, 5.796380684862291, 5.8258054496834575, 5.854647480974125, 5.882932119208142, 5.910683031065714, 5.937922356025871, 5.964670837106164, 5.990947937775545, 6.016771946769378, 6.042160072287374, 6.067128526847143, 6.091692603890812, 6.115866747094021, 6.139664613200981, 6.163099129102391, 6.1861825437816425, 6.208926475676611, 6.2313419559370775, 6.253439467999967, 6.2752289838545545, 6.296719997326436, 6.3179215546714245, 6.338842282737746, 6.359490414926267, 6.379873815153485, 6.400000000000001, 6.419876159207947, 6.439509174673788, 6.4589056380679795, 6.478071867199634, 6.497013921232645, 6.515737614849275, 6.534248531447914, 6.552552035453504, 6.570653283811691, 6.588557236731257, 6.60626866773339, 6.623792173061167, 6.641132180497787, 6.658292957637901, 6.675278619652465, 6.69209313658415, 6.708740340207162, 6.725223930482513, 6.741547481637222, 6.757714447893614, 6.773728168872739, 6.789591874694074, 6.805308690791884, 6.820881642467036, 6.836313659191658, 6.851607578682638, 6.866766150758823, 6.881792040995649, 6.896687834189875, 6.9114560376462935, 6.926099084297256, 6.940619335665272, 6.955019084678068, 6.969300558344897, 6.983465920302313, 6.997517273236981, 7.011456661192659], [0.0, 2.8205297528345774, 3.2399378873012727, 3.5136211792121412, 3.721711321435541, 3.8915685610197355, 4.036090868643729, 4.162462110712185, 4.275123672706847, 4.377026613032922, 4.470238404401549, 4.556267590381623, 4.636250941429606, 4.7110678139050215, 4.781413379312573, 4.8478473600973215, 4.910827530247239, 4.970733385681889, 5.027883270169162, 5.082547024703898, 5.13495550158063, 5.1853078362914795, 5.233777085997675, 5.280514658180899, 5.325653829773643, 5.369312573248867, 5.411595848112175, 5.4525974753756286, 5.492401683377167, 5.531084392128644, 5.568714287820512, 5.605353727551826, 5.641059505669155, 5.675883506505828, 5.709873263261628, 5.743072438858056, 5.775521241560429, 5.807256785766898, 5.838313406472443, 5.868722934408323, 5.898514937648644, 5.92771693450032, 5.956354581701258, 5.98445184130579, 6.012031129106705, 6.039113447006643, 6.065718501390129, 6.091864809246732, 6.117569793544643, 6.142849869143254, 6.1677205203558705, 6.192196371123721, 6.216291248635241, 6.240018241116347, 6.26338975042497, 6.286417540003941, 6.309112778678298, 6.3314860807244395, 6.353547542587949, 6.375306776582964, 6.3967729418679085, 6.417954772959159, 6.4388606060152815, 6.459498403099091, 6.4798757746025455, 6.500000000000001, 6.5198780470780475, 6.539516589775077, 6.558922024750184, 6.578100486789204, 6.59705786314506, 6.615799806900249, 6.634331749430898, 6.65265891204438, 6.670786316855805, 6.688718796962722, 6.706461005972031, 6.724017426928279, 6.741392380688213, 6.75859003378255, 6.775614405802437, 6.7924693763448785, 6.809158691548585, 6.825685970249037, 6.842054709779287, 6.85826829144083, 6.874329985666939, 6.890242956899139, 6.906010268195838, 6.921634885590704, 6.937119682217004, 6.952467442212948, 6.967680864421922, 6.9827625659004795, 6.997715085246049, 7.012540885755415, 7.0272423584242825, 7.041821824797465, 7.056281539678608, 7.070623693707723, 7.084850415814246, 7.0989637755528054], [0.0, 2.8551908845980556, 3.2797530723403154, 3.5567996234519956, 3.767446958993792, 3.9393915526136216, 4.085689876513381, 4.2136140787192184, 4.327660124334751, 4.4308153369469725, 4.525172596176483, 4.612258983892423, 4.69322524017896, 4.768961527694191, 4.8401715608171125, 4.907421940350798, 4.971176065809593, 5.031818096690198, 5.089670288846621, 5.145005799315402, 5.1980583173055885, 5.249029425460064, 5.298094307617522, 5.345406231886954, 5.391100113024136, 5.435295373250762, 5.478098261906464, 5.5196037529577975, 5.55989710981405, 5.59905518545845, 5.6371475101573205, 5.674237207308181, 5.710381769196111, 5.74563371775442, 5.780041170312343, 5.813648326359475, 5.846495888275398, 5.878621426552385, 5.910059698123808, 5.940842924884738, 5.971001038267585, 6.000561894748242, 6.029551466357008, 6.057994009614856, 6.0859122157794046, 6.113327344843006, 6.140259345359443, 6.166726961871214, 6.192747831455154, 6.218338570690777, 6.243514854176145, 6.268291485564245, 6.2926824619640715, 6.316701032441089, 6.340359751258083, 6.36367052641734, 6.386644663996169, 6.409292908708462, 6.43162548107374, 6.4536521115306495, 6.475382071793345, 6.496824203715568, 6.517986945897878, 6.538878358247866, 6.559506144680631, 6.579877674127064, 6.6000000000000005, 6.619879878253012, 6.639523784152925, 6.658937927875177, 6.678128269020396, 6.69710053014109, 6.715860209358879, 6.734412592145117, 6.752762762331049, 6.770915612407546, 6.788875853169092, 6.806648022751798, 6.824236495110871, 6.8416454879789965, 6.858879070343563, 6.875941169477453, 6.892835577555197, 6.909565957883686, 6.926135850774255, 6.942548679080782, 6.958807753426478, 6.97491627714029, 6.990877350922161, 7.00669397725497, 7.022369064579553, 7.037905431248041, 7.053305809269564, 7.06857284786135, 7.083709116817328, 7.098717109705427, 7.113599246903991, 7.128357878487006, 7.142995286967109, 7.157513689904811, 7.171915242391692, 7.186202039414872], [0.0, 2.8897471372026358, 3.3194477828620585, 3.5998474164786907, 3.8130442076722018, 3.9870698393211073, 4.135138805549398, 4.2646112688783395, 4.380037608884031, 4.484441304602492, 4.5799405656864485, 4.668080956211296, 4.750027143618998, 4.826680064168058, 4.898751949262366, 4.966816257250172, 5.031341996150234, 5.092717974925136, 5.15127034967764, 5.207275583452164, 5.260970193788213, 5.312558203074737, 5.362216915392902, 5.410101453849036, 5.456348366066408, 5.501078519628732, 5.54439944980683, 5.586407280033098, 5.627188305656199, 5.666820309807719, 5.705373664275804, 5.742912256437743, 5.7794942744052715, 5.815172875782401, 5.849996760260335, 5.884010662273193, 5.917255776819706, 5.949770129106204, 5.981588896727727, 6.01274469155956, 6.043267807292953, 6.07318643754953, 6.1025268686979555, 6.131313650834835, 6.159569749849102, 6.187316683041885, 6.214574640403454, 6.241362593340701, 6.267698392391242, 6.293598855244341, 6.319079846207049, 6.344156348100324, 6.368842527439573, 6.393151793643129, 6.4170968529174806, 6.440689757386956, 6.46394194996583, 6.486864305410807, 6.509467167939915, 6.531760385758882, 6.553753342797021, 6.57545498792065, 6.596873861862346, 6.618018122078418, 6.638895565724117, 6.659513650916189, 6.679879516434621, 6.7, 6.719881655249031, 6.739530767518635, 6.758953368538232, 6.778155250120137, 6.797141976929499, 6.8159188984075065, 6.834491159914793, 6.8528637131558385, 6.87104132593967, 6.889028591327264, 6.90682993621162, 6.924449629372461, 6.941891789043955, 6.959160390030598, 6.976259270403449, 6.993192137806241, 7.009962575398548, 7.026574047460901, 7.043029904684841, 7.059333389169067, 7.075487639141161, 7.091495693422924, 7.107360495655924, 7.1230848983026895, 7.138671666437738, 7.15412348134166, 7.169442943910492, 7.184632577891705, 7.199694832957381, 7.214632087624348, 7.229446652030398, 7.24414077057508, 7.258716624432954, 7.273176333946682], [0.0, 2.9242003864203037, 3.359024173562697, 3.642766894999424, 3.858505542566745, 4.03460600920044, 4.184440339923495, 4.315456449403502, 4.432258969493362, 4.537907426907933, 4.634545285829697, 4.723736537449552, 4.806659735053353, 4.8842265563866505, 4.957157724491148, 5.026033534819676, 5.0913285871778795, 5.153436326135354, 5.21268679641797, 5.269359757223655, 5.323694545991836, 5.375897617585269, 5.426148390007691, 5.4746038358334905, 5.521402130686271, 5.5666655832035055, 5.610503010754178, 5.653011682810254, 5.694278923583828, 5.7343834435823045, 5.773396453607295, 5.811382602738626, 5.848400772840607, 5.884504755293181, 5.919743830413645, 5.954163265986111, 5.9878047481600865, 6.02070675550057, 6.052904885010388, 6.084432137382605, 6.11531916748751, 6.1455945050875105, 6.175284749952679, 6.204414744880176, 6.233007729571645, 6.261085477870015, 6.288668420482388, 6.315775755003821, 6.342425544796443, 6.368634808059808, 6.394419598244477, 6.419795076805335, 6.444775579159237, 6.4693746745994165, 6.493605220823159, 6.517479413647242, 6.541008832415031, 6.564204481538418, 6.587076828565227, 6.60963583911723, 6.631891009004415, 6.653851393786698, 6.675525636024248, 6.69692199043132, 6.718048347125394, 6.738912253143229, 6.759520932377507, 6.779881304072105, 6.800000000000002, 6.819883380435568, 6.83953754902202, 6.858968366625029, 6.8781814642549275, 6.897182255132058, 6.915975945963042, 6.934567547489465, 6.952961884364951, 6.971163604411628, 6.9891771873024915, 7.007006952712143, 7.02465706797474, 7.042131555284715, 7.0594342984728415, 7.076569049387547, 7.093539433908918, 7.110348957620659, 7.127001011163206, 7.143498875289452, 7.159845725642751, 7.176044637275511, 7.192098588925111, 7.208010467062799, 7.2237830697299215, 7.239419110174859, 7.254921220303047, 7.270291953951543, 7.285533789998848, 7.300649135319853, 7.315640327595158, 7.330509637983354, 7.345259273664233, 7.359891380260417], [0.0, 2.9585524474190414, 3.398484329522705, 3.685560320225111, 3.9038333588059326, 4.082002566692723, 4.233597077084931, 4.366152299070899, 4.484326957442925, 4.591216520723695, 4.688989633453605, 4.7792286598191405, 4.863125998167716, 4.941604036184485, 5.015391963609264, 5.085076892919079, 5.151138999283547, 5.213976349264627, 5.273922864790519, 5.33126159153195, 5.386234678546307, 5.439051006026042, 5.489892099688931, 5.538916776145593, 5.586264834238569, 5.632060019426761, 5.676412427411826, 5.719420470339415, 5.761172498263311, 5.801748146343061, 5.8412194619295805, 5.879651853568137, 5.917104894838083, 5.953633009033908, 5.989286055393723, 6.024109833485196, 6.058146519166119, 6.091435043028654, 6.124011420251626, 6.155909039203931, 6.187158914874126, 6.217789912178169, 6.247828943367083, 6.277301143078934, 6.306230024023894, 6.33463761583324, 6.362544589223923, 6.3899703673148585, 6.416933225667629, 6.443450382403183, 6.469538079560089, 6.495211656702509, 6.520485617652691, 6.545373691109219, 6.569888885815254, 6.5940435408579985, 6.617849371609224, 6.641317511755214, 6.6644585518113715, 6.687282574470668, 6.709799187095175, 6.73201755162505, 6.753946412148988, 6.775594120353547, 6.79696865904541, 6.818077663920192, 6.838928443733297, 6.85952799901246, 6.87988303943745, 6.9, 6.919885056045907, 6.9395441372914, 6.958982940897135, 6.978206943675291, 6.997221413498309, 7.016031419971488, 7.0346418444260985, 7.053057389284588, 7.071282586844934, 7.08932180752714, 7.10717926762115, 7.1248590365721425, 7.142365043836222, 7.159701085336673, 7.176870829548632, 7.193877823237664, 7.210725496875779, 7.227417169756528, 7.243956054829159, 7.260345263270271, 7.276587808809983, 7.292686611828376, 7.308644503236806, 7.324464228157554, 7.340148449414379, 7.355699750845555, 7.371120640450222, 7.386413553378049, 7.401580854771552, 7.41662484246977, 7.431547749581352, 7.446351746934636], [0.0, 2.9928050775697597, 3.4378302694311564, 3.728229881367068, 3.949029975254583, 4.129261936494729, 4.282611531777142, 4.416701411361353, 4.536244236408922, 4.644371313218046, 4.743276393803367, 4.834560162166954, 4.919428821643735, 4.9988154388589185, 5.0734576457438685, 5.143949352068169, 5.21077629222771, 5.274341141398615, 5.334981687488989, 5.392984253129778, 5.4485937908581965, 5.502021599176359, 5.553451305415379, 5.603043564884603, 5.650939794947161, 5.697265173724554, 5.742131071551021, 5.785637039938471, 5.827872451813112, 5.8689178643102595, 5.908846158908771, 5.947723501421107, 5.985610155139519, 6.022561173443988, 6.058626992817773, 6.093853943072869, 6.128284688357907, 6.161958609983839, 6.19491214009509, 6.227179053614275, 6.258790724605868, 6.289776352169286, 6.320163160132041, 6.349976574128377, 6.3792403790867835, 6.407976859686513, 6.436206925959666, 6.463950225896247, 6.491225246643086, 6.518049405663864, 6.544439133039291, 6.570409945927277, 6.59597651606802, 6.621152731104061, 6.645951750387236, 6.6703860558604875, 6.694467498530259, 6.718207340983048, 6.741616296345907, 6.764704564044153, 6.787481862669054, 6.809957460233097, 6.832140202059632, 6.854038536526838, 6.875660538862313, 6.89701393316391, 6.9181061128041215, 6.9389441593592665, 6.959534860190409, 6.979884724790374, 7.000000000000001, 7.019886684186787, 7.039550540470246, 7.058997109070329, 7.078231718848253, 7.097259498102652, 7.116085384678391, 7.134714135440197, 7.153150335158711, 7.171398404852458, 7.189462609625462, 7.207347066036892, 7.225055749036112, 7.242592498493695, 7.259961025356537, 7.277164917452868, 7.294207644970974, 7.3110925656335155, 7.327822929587649, 7.34440188402961, 7.3608324775809635, 7.377117664432484, 7.393260308270392, 7.409263185998611, 7.425128991269734, 7.440860337836412, 7.456459762734136, 7.4719297293055105, 7.487272630075482, 7.502490789486312, 7.517586466500456, 7.532561857079011], [0.0, 3.026959979085027, 3.47706394861683, 3.770777698924158, 3.994097637995648, 4.17638646719963, 4.331486139813685, 4.46710629835449, 4.588013386463144, 4.697374445962029, 4.797408264704094, 4.889733794237418, 4.975571003496437, 5.0558636075775665, 5.1313576565166965, 5.202653837982126, 5.27024342973459, 5.334533702415211, 5.395866298881692, 5.454530809375469, 5.510774981914774, 5.564812526411534, 5.6168291658139315, 5.666987388883921, 5.715430226887304, 5.762284286520545, 5.807662209113725, 5.851664682294199, 5.89438209894217, 5.935895935538167, 5.97627990530908, 6.015600929173949, 6.053919958170054, 6.0912926739651265, 6.127770088640594, 6.163399060739901, 6.198222741309339, 6.232280961092671, 6.265610568010247, 6.298245722435501, 6.330218156484315, 6.361557402486084, 6.392290994955824, 6.422444649693701, 6.452042423069833, 6.481106854083753, 6.509659091399903, 6.537719007237782, 6.565305299725777, 6.592435585101542, 6.619126480951414, 6.6453936815203445, 6.671252025987383, 6.696715560485532, 6.721797594545594, 6.746510752558654, 6.770867020778842, 6.794877790325091, 6.8185538965862795, 6.841905655387003, 6.864942896230376, 6.88767499289857, 6.910110891660752, 6.932259137310842, 6.95412789723366, 6.975724983677072, 6.997057874389232, 7.018133731763798, 7.038959420621486, 7.059541524743654, 7.0798863622621955, 7.100000000000001, 7.1198882668472505, 7.139556766250755, 7.159010887886492, 7.17825581857897, 7.19729655252541, 7.216137900877479, 7.234784500728772, 7.253240823551969, 7.271511183125897, 7.28959974298929, 7.307510523454976, 7.325247408215427, 7.342814150568115, 7.360214379286779, 7.377451604162663, 7.394529221237892, 7.4114505177514, 7.428218676816286, 7.444836781846015, 7.461307820745582, 7.477634689882563, 7.493820197851844, 7.509867069046891, 7.525777947049383, 7.541555397848316, 7.557201912898791, 7.572719912030058, 7.588111746211695, 7.603379700186203, 7.618525994975725], [0.0, 3.0610188015018984, 3.5161872619002263, 3.813205827775725, 4.039038523606319, 4.223378434722628, 4.380223261631082, 4.517369394392824, 4.639636907836231, 4.75022847878242, 4.851387860495835, 4.944752220683229, 5.0315552551553715, 5.112751297525306, 5.189094792252988, 5.261193185838932, 5.32954328381501, 5.394556939360118, 5.456579639437434, 5.515904232706962, 5.572781254804152, 5.627426820267352, 5.680028741766762, 5.730751336359365, 5.779739244673662, 5.827120497962447, 5.873009004976275, 5.917506586262014, 5.960704651784689, 6.002685594783888, 6.0435239578947915, 6.083287415018877, 6.122037603003797, 6.159830830037635, 6.196718682180808, 6.232748545220863, 6.267964055732095, 6.302405492626802, 6.33611011843167, 6.369112477886655, 6.40144466015184, 6.433136529849207, 6.4642159313073035, 6.4947088696759625, 6.524639672003358, 6.5540311308938906, 6.582904632973062, 6.611280274059097, 6.639176962668441, 6.666612513253564, 6.693603730378967, 6.72016648487849, 6.746315782899021, 6.772065828618188, 6.797430081323296, 6.822421307452863, 6.847051628128248, 6.871332562639253, 6.895275068292651, 6.918889576984887, 6.942186028818917, 6.965173903049067, 6.987862246606351, 7.010259700429213, 7.032374523800453, 7.054214616869978, 7.075787541524253, 7.097100540746931, 7.118160556600489, 7.138974246945833, 7.159548001005369, 7.179887953864816, 7.200000000000002, 7.219889805906736, 7.239562821904687, 7.259024293179601, 7.278279270122528, 7.2973326180193725, 7.31618902613949, 7.334853016267787, 7.353328950720974, 7.3716210398851905, 7.38973334930912, 7.4076698063838595, 7.425434206638325, 7.443030219676583, 7.46046139478143, 7.477731166206664, 7.494842858178651, 7.511799689626322, 7.5286047786571695, 7.5452611467955695, 7.561771722998517, 7.578139347462718, 7.594366775236033, 7.610456679645259, 7.62641165555145, 7.642234222443122, 7.657926827377018, 7.673491847775416, 7.688931594088336, 7.704248312328474], [0.0, 3.0949831440200946, 3.555202046279434, 3.8555162600943405, 4.083854742243279, 4.270240045527012, 4.42882518563469, 4.5674930595323815, 4.691117224461695, 4.802935893390228, 4.905217715739342, 4.999618024842451, 5.087384205308006, 5.1694811798096945, 5.246671763945221, 5.319570144298173, 5.388678638837406, 5.454413670567532, 5.51712455989357, 5.577107404855171, 5.634615520972096, 5.6898674207386275, 5.743053000750048, 5.794338401286643, 5.843869867875204, 5.891776852373106, 5.938174527435527, 5.983165843386104, 6.026843224453268, 6.069289978092559, 6.110581474046652, 6.150786137110671, 6.189966288040189, 6.228178859805663, 6.265476010854264, 6.301905652755062, 6.337511906263484, 6.37233549721714, 6.406414101598919, 6.439782647449063, 6.472473579981408, 6.5045170951887314, 6.5359413463536855, 6.56677262717311, 6.597035534622367, 6.626753114207217, 6.655946989854116, 6.684637480359745, 6.712843704044988, 6.7405836730272775, 6.767874378330596, 6.7947318668878145, 6.821171311350486, 6.847207073502442, 6.872852761972064, 6.898121284851262, 6.9230248977544955, 6.947575247786893, 6.971783413834914, 6.995659943544867, 7.019214887312747, 7.042457829572447, 7.065397917637597, 7.088043888324452, 7.110404092558868, 7.132486518148951, 7.154298810886074, 7.175848294120328, 7.197141986941678, 7.218186621085083, 7.2389886566662565, 7.259554296844377, 7.279889501498988, 7.300000000000001, 7.319891303142542, 7.339568714311705, 7.359037339936486, 7.378302099286853, 7.39736773366319, 7.416238815023061, 7.434919754086414, 7.45341480795684, 7.471728087293389, 7.489863563064568, 7.507825072913584, 7.525616327161563, 7.543240914473309, 7.560702307208287, 7.578003866477697, 7.595148846926946, 7.61214040126131, 7.628981584531288, 7.64567535819289, 7.662224593956975, 7.678632077440765, 7.69490051163366, 7.711032520188681, 7.7270306505499935, 7.742897376926305, 7.75863510311921, 7.774246165214937, 7.789732834147409], [0.0, 3.1288545577058158, 3.5941100834616457, 3.8977109280911595, 4.1285483405506485, 4.316973439664824, 4.477294131352282, 4.617479582795036, 4.7424566873162695, 4.855499096800671, 4.958900288708875, 5.054333712298526, 5.143060403522245, 5.226055845141942, 5.304091200989053, 5.377787379288892, 5.447652195364887, 5.514106629543998, 5.577503825184519, 5.6381431208152195, 5.696280604234207, 5.752137179330726, 5.805904820923375, 5.857751487527271, 5.90782502517639, 5.956256302445804, 6.003161752437187, 6.048645452159795, 6.092800837330373, 6.1357121271190485, 6.177455516112968, 6.218100177946404, 6.2577091154116316, 6.296339884552029, 6.334045214635435, 6.370873541573865, 6.406869468979128, 6.442074168391319, 6.476525728118292, 6.510259458451838, 6.54330815968535, 6.575702358275758, 6.607470515614491, 6.638639213155914, 6.669233317064036, 6.699276125054023, 6.728789497704011, 6.757793976179055, 6.786308888030436, 6.814352442499723, 6.841941816560217, 6.869093232761998, 6.895822029805715, 6.922142726650184, 6.9480690808562535, 6.973614141781651, 6.998790299165957, 7.023609327579909, 7.048082427157009, 7.072220260976727, 7.096032989426326, 7.11953030183149, 7.142721445613806, 7.165615253205018, 7.1882201669232915, 7.210544261995094, 7.232595267887136, 7.254380588096061, 7.275907318528566, 7.297182264591542, 7.318211957100035, 7.339002667100436, 7.359560419697051, 7.3798910069618655, 7.400000000000001, 7.4198927602366584, 7.439574449985457, 7.459050042352725, 7.478324330527513, 7.497401936502768, 7.516287319269239, 7.534984782520147, 7.553498481901487, 7.571832431839939, 7.589990511977776, 7.607976473241781, 7.625793943571009, 7.643446433326337, 7.660937340402876, 7.678269955064787, 7.695447464520468, 7.712472957254811, 7.729349427133924, 7.74607977729659, 7.762666823845754, 7.779113299352261, 7.795421856182319, 7.811595069659258, 7.827635441069459, 7.843545400521657, 7.8593273096681475, 7.874983464295893], [0.0, 3.1626345475706246, 3.6329131022511687, 3.939791706605651, 4.173121304403092, 4.363580693645161, 4.525632252408872, 4.667331185236456, 4.793657577570913, 4.90792042455928, 5.012437964687017, 5.108901714238506, 5.198586323663599, 5.2824778073092284, 5.361355654707479, 5.435847477582716, 5.506466573774781, 5.573638468632118, 5.637720118147595, 5.69901409259255, 5.757779244560663, 5.814238862881417, 5.868586994987305, 5.920993412720602, 5.971607558302459, 6.02056171320173, 6.067973567564454, 6.113948322044421, 6.158580421116533, 6.201954993204661, 6.244149055514049, 6.285232528496892, 6.325269095141249, 6.364316932881662, 6.402429340265907, 6.439655276133667, 6.476039825649832, 6.511624604853974, 6.546448113265983, 6.580546042397443, 6.6139515466629035, 6.646695482091467, 6.678806617351716, 6.710311820878838, 6.741236227298911, 6.771603385855758, 6.801435393140435, 6.830753012086169, 6.859575778909895, 6.887922099445254, 6.915809336112958, 6.943253886606281, 6.97027125522678, 6.996876117684012, 7.023082380069309, 7.048903232624915, 7.07435119885351, 7.099438180447392, 7.124175498459842, 7.148573931091922, 7.172643748425278, 7.196394744394269, 7.219836266258236, 7.242977241806326, 7.265826204502337, 7.288391316755143, 7.310680391480941, 7.332700912106595, 7.3544600511482, 7.375964687485723, 7.397221422442721, 7.4182365947695565, 7.439016294619248, 7.459566376596611, 7.479892471953979, 7.5, 7.519894178782078, 7.539580035097588, 7.559062413884191, 7.578345987035166, 7.597435261681774, 7.616334587981112, 7.635048166444694, 7.653580054840073, 7.671934174695227, 7.690114317432996, 7.708124150160679, 7.725967221137993, 7.743646964944676, 7.761166707367501, 7.778529670024861, 7.795738974745797, 7.812797647719031, 7.8297086234264475, 7.846474748374426, 7.863098784635412, 7.879583413211302, 7.8959312372293375, 7.912144784980487, 7.92822651280962, 7.944178807866092, 7.960003990722825], [0.0, 3.196324574534057, 3.6716127808038688, 3.9817604155504793, 4.217575561495493, 4.4100638231420355, 4.573841639335146, 4.7170500228424865, 4.84472210956557, 4.960202143787571, 5.065833059075191, 5.163324390623431, 5.253964367121224, 5.338749506452806, 5.41846760167789, 5.493752950167129, 5.5651243176757355, 5.633011762469333, 5.69777604302155, 5.759722952739514, 5.81911410164927, 5.8761751571689675, 5.931102233825204, 5.984066911958156, 6.035220225725188, 6.084695865726112, 6.132612775803571, 6.179077277263395, 6.224184820652122, 6.26802144122584, 6.3106649766170895, 6.352186092107065, 6.392649149068114, 6.432112944671045, 6.4706313452274715, 6.5082538311120794, 6.5450259677603695, 6.580989814527597, 6.616184281050545, 6.650645439045334, 6.6844067961045655, 6.717499536951803, 6.749952736714437, 6.781793550044195, 6.813047379314252, 6.843738024627218, 6.873887817958521, 6.903517743418944, 6.932647545335358, 6.961295825609911, 6.989480131616845, 7.017217035726183, 7.044522207399362, 7.071410478679227, 7.097895903792019, 7.1239918134893, 7.149710864680609, 7.175065085841257, 7.200065918622267, 7.2247242560397, 7.249050477577453, 7.273054481499961, 7.296745714638431, 7.3201331998854595, 7.3432255616077375, 7.366031049164358, 7.388557558698765, 7.4108126533551735, 7.432803582055048, 7.4545372969557615, 7.476020469701597, 7.497259506566584, 7.518260562579213, 7.539029554710597, 7.559572174200094, 7.579893898085643, 7.600000000000002, 7.619895560288605, 7.639585475499908, 7.659074467294623, 7.678367090816317, 7.697467742562221, 7.716380667789881, 7.735109967492299, 7.753659604971609, 7.772033412038853, 7.790235094865268, 7.808268239508475, 7.82613631713514, 7.843842688960048, 7.861390610919943, 7.878783238099212, 7.896023628923112, 7.913114749133155, 7.930059475558185, 7.946860599693679, 7.963520831100959, 7.980042800637129, 7.996429063525831, 8.012682102278195, 8.02880432947273, 8.044798090402308], [0.0, 3.2299260572778854, 3.710210748757166, 4.023618822221423, 4.261912983789674, 4.456424785552773, 4.621924322220857, 4.766638189265612, 4.895652433619704, 5.012346456060575, 5.119087820332485, 5.2176040331837035, 5.309196865855884, 5.394873312165137, 5.475429446875452, 5.551506235432536, 5.623627897136186, 5.692229011255773, 5.757674128752001, 5.820272257696731, 5.880287758301283, 5.937948670321058, 5.993453169944015, 6.046974641255138, 6.098665706164067, 6.148661460698095, 6.197082099101498, 6.244035060386849, 6.289616798528159, 6.3339142532303905, 6.377006080397138, 6.41896368818103, 6.459852114555771, 6.499730774799648, 6.538654101495906, 6.57667209518354, 6.61383080030641, 6.650172718370332, 6.685737168051115, 6.720560600270154, 6.754676874869886, 6.788117504404457, 6.820911869654631, 6.8530874107364355, 6.884669797066456, 6.915683078946778, 6.946149823118563, 6.976091234288851, 7.005527264347496, 7.034476710749842, 7.062957305337568, 7.090985794698361, 7.118578013019464, 7.14574894826613, 7.172512802410185, 7.19888304634322, 7.224872470031014, 7.250493228398677, 7.275756883378023, 7.300674442498353, 7.325256394358282, 7.349512741278122, 7.373453029399251, 7.397086376467764, 7.420421497514332, 7.443466728619748, 7.466230048935959, 7.488719101115023, 7.510941210282963, 7.532903401681969, 7.554612417092236, 7.576074730133992, 7.597296560540697, 7.618283887485844, 7.639042462038161, 7.659577818813157, 7.679895286882851, 7.700000000000001, 7.719896906188212, 7.7395907767448335, 7.759086214699552, 7.778387662767942, 7.797499410835979, 7.816425603008507, 7.835170244252025, 7.853737206659633, 7.872130235363833, 7.890352954120813, 7.9084088705880085, 7.9263013813151, 7.944033776466994, 7.9616092442960165, 7.979030875379239, 7.996301666635641, 8.01342452513684, 8.030402271724013, 8.047237644442847, 8.063933301807435, 8.080491825903298, 8.096915725339061, 8.113207438055555, 8.129369334000634], [0.0, 3.263440373999379, 3.7487085892439955, 4.065368643481462, 4.306135389827833, 4.502665482417024, 4.669882273223683, 4.816097718412371, 4.946450638689749, 5.064355500127623, 5.172204432754366, 5.271742868251288, 5.36428608528186, 5.450851526418319, 5.532243526645264, 5.609109702185715, 5.681979711736948, 5.751292643844093, 5.817416832116787, 5.880664490952426, 5.941302723613314, 5.999561936037992, 6.055642360727606, 6.109719180832823, 6.161946601896756, 6.212461121728339, 6.2613841817298, 6.308824335720997, 6.354879038500411, 6.39963613187564, 6.443175087898641, 6.485568055666387, 6.526880747998758, 6.56717319667808, 6.606500399090258, 6.64491287458923, 6.682457145384616, 6.719176153985801, 6.7551096270465285, 6.79029439370977, 6.824764665154016, 6.858552280913569, 6.891686926629669, 6.924196327142116, 6.956106418218163, 6.987441499710327, 7.018224372516495, 7.048476461367713, 7.078217925178374, 7.107467756449735, 7.136243871012377, 7.164563189219715, 7.192441709557478, 7.2198945755088495, 7.246936136407971, 7.273580002922924, 7.299839097730563, 7.325725701877774, 7.351251497265136, 7.376427605638136, 7.4012646244270455, 7.425772659738125, 7.449961356765298, 7.473839927862102, 7.497417178487991, 7.520701531220494, 7.54370104800473, 7.5664234507943435, 7.588876140722235, 7.61106621592582, 7.633000488139269, 7.654685498154299, 7.676127530241491, 7.697332625615359, 7.718306595018795, 7.739055030495513, 7.759583316412982, 7.779896639792737, 7.800000000000001, 7.819898217839998, 7.83959594410431, 7.859097667606959, 7.87840772274658, 7.897530296628025, 7.916469435774072, 7.935229052455386, 7.95381293066466, 7.972224731758857, 7.990467999791521, 8.008546166555567, 8.026462556355268, 8.044220390524853, 8.061822791709798, 8.079272787925673, 8.096573316408415, 8.113727227268779, 8.130737286962924, 8.14760618159018, 8.164336520028277, 8.180930836915625, 8.197391595489592, 8.213721190289045], [0.0, 3.2968688640702464, 3.7871078407984355, 4.107011547827371, 4.350244546921536, 4.548787761705661, 4.717717408943129, 4.865430586891587, 4.99711875488359, 5.1162313544867715, 5.2251850191019376, 5.325743059439564, 5.419234226993845, 5.506686386334985, 5.588912111514624, 5.666565652501158, 5.740182093459612, 5.810205020663094, 5.877006540683206, 5.940902066031817, 6.0021614359975475, 6.061017416642534, 6.117672291515103, 6.172303038224388, 6.225065441891458, 6.276097398517069, 6.325521593467563, 6.373447692515177, 6.419974148719855, 6.46518970368164, 6.509174643510782, 6.552001856351118, 6.593737728140493, 6.634442905586468, 6.6741729494312105, 6.7129788965149695, 6.750907745589615, 6.788002879038742, 6.824304430449235, 6.859849606217058, 6.894672967957023, 6.928806681346224, 6.962280736105659, 6.995123141069757, 7.027360097674341, 7.059016154683286, 7.090114346551556, 7.120676317470742, 7.1507224328496095, 7.180271879735835, 7.209342757477728, 7.237952159749433, 7.266116248914414, 7.293850323575522, 7.321168880051832, 7.348085668429964, 7.374613743757988, 7.400765512881584, 7.426552777362868, 7.451986772871014, 7.477078205389247, 7.501837284543989, 7.52627375432805, 7.550396921460121, 7.574215681596871, 7.597738543591049, 7.620973651968924, 7.643928807782644, 7.666611487977341, 7.689028863398979, 7.711187815556557, 7.733094952241267, 7.754756622095533, 7.776178928216012, 7.7973677408669415, 7.818328709373172, 7.839067273256015, 7.859588672669368, 7.879897958188592, 7.9, 7.919899496534758, 7.939600982587282, 7.959108836954873, 7.978427289632271, 7.997560428592116, 8.016512206179742, 8.035286445148522, 8.053886844359898, 8.072316984170318, 8.090580331525677, 8.108680244782187, 8.12661997827126, 8.144402686624652, 8.162031428874892, 8.179509172344988, 8.19683879634031, 8.214023095654742, 8.231064783902207, 8.247966496684022, 8.264730794601734, 8.281360166124454, 8.297857030319104], [0.0, 3.330212829607493, 3.8254099991601485, 4.148549157346593, 4.394242173224471, 4.59479341998814, 4.765431592668367, 4.914638716332589, 5.047658755841547, 5.167976039822534, 5.278031643091578, 5.379606710180875, 5.474043431349054, 5.56238006681207, 5.645437408855985, 5.723876324421022, 5.798237309421565, 5.8689684364861145, 5.936445575608237, 6.00098732932778, 6.062866266041594, 6.122317505967796, 6.179545378515782, 6.234728651215835, 6.288024684772983, 6.339572769844455, 6.389496832615321, 6.437907647998606, 6.484904664791594, 6.530577522111633, 6.575007318068904, 6.618267677985415, 6.660425659214986, 6.701542521835563, 6.74167438852112, 6.780872812289743, 6.8191852672306075, 6.856655574489287, 6.893324273556871, 6.929228947128424, 6.964404506368994, 6.99888344227381, 7.032696047874758, 7.06587061528281, 7.09843361093061, 7.130409831864015, 7.161822545504512, 7.192693614949327, 7.223043611579476, 7.252891916497137, 7.282256812104322, 7.3111555649576605, 7.339604500883986, 7.367619073213588, 7.395213924878829, 7.4224029450323386, 7.449199320758703, 7.475615584384309, 7.501663656830246, 7.527354887401315, 7.552700090359217, 7.5777095785887845, 7.602393194631894, 7.626760339333794, 7.650819998320297, 7.674580766501227, 7.698050870775193, 7.721238191092844, 7.744150280019853, 7.766794380926888, 7.7891774449213464, 7.811306146624488, 7.833186898887816, 7.854825866533657, 7.876228979197094, 7.897401943339281, 7.91835025349591, 7.939079202818897, 7.959593892964256, 7.979899243374527, 8.000000000000002, 8.019900743499228, 8.039605896955912, 8.059119733146233, 8.078446381387883, 8.097589833999542, 8.11655395239725, 8.135342472852102, 8.153959011931654, 8.172407071645896, 8.190690044316879, 8.208811217189764, 8.22677377680171, 8.244580813123779, 8.262235323489971, 8.279740216326458, 8.297098314693185, 8.314312359649106, 8.331385013451554, 8.34831886259956, 8.365116420730187, 8.381780131376383], [0.0, 3.363473536961897, 3.8636165189841902, 4.189983049571472, 4.43812993969651, 4.640684204486193, 4.8130266365082095, 4.963723975581869, 5.098072560992471, 5.21959152131576, 5.330746311754014, 5.433335866131007, 5.528715779913893, 5.617934683006979, 5.701821565410236, 5.781043894513474, 5.856147564467574, 5.927585123054224, 5.995736194291885, 6.060922562783049, 6.1234195192183485, 6.183464532093673, 6.24126397157108, 6.2969983906326545, 6.350826721633238, 6.402889646404143, 6.453312328850905, 6.50220665025787, 6.5496730526733575, 6.595802070490965, 6.640675611793282, 6.68436803723979, 6.726947073923794, 6.768474593762072, 6.809007279957284, 6.848597200416488, 6.8872923033792715, 6.925136847657618, 6.962171777633303, 6.998435051360888, 7.03396192868285, 7.068785225100251, 7.102935536198514, 7.136441436657822, 7.169329657245961, 7.201625242670821, 7.233351692738706, 7.264531088905884, 7.295184208011314, 7.325330624727135, 7.3549888040519855, 7.384176184993301, 7.412909256433121, 7.441203626042834, 7.469074083001996, 7.496534655182012, 7.523598661374295, 7.550278759072618, 7.576586988259009, 7.602534811590156, 7.628133151335872, 7.653392423381564, 7.678322568572107, 7.702933081644278, 7.7272330379683805, 7.751231118296436, 7.774935631693716, 7.798354536812363, 7.821495461649769, 7.844365721920216, 7.86697233815572, 7.8893220516407325, 7.91142133927551, 7.933276427453925, 7.95489330503366, 7.9762777354695, 7.997435268174158, 8.018371249165233, 8.03909083105184, 8.059598982409764, 8.079900496589763, 8.100000000000001, 8.119901959900005, 8.139610691740574, 8.159130366081214, 8.178465015114138, 8.197618538821517, 8.216594710790686, 8.23539718370989, 8.25402949456567, 8.272495069561096, 8.290797228772897, 8.30893919056397, 8.326924075766655, 8.34475491165101, 8.362434635691296, 8.379966099142944, 8.3973520704414, 8.414595238433463, 8.431698215450982, 8.448663540236126, 8.465493680726778], [0.0, 3.396652218129394, 3.901728815462265, 4.231314759237462, 4.481909471966033, 4.686461815021153, 4.860504303410747, 5.012688182785964, 5.148362037693013, 5.271079710833889, 5.383330977671218, 5.486932517449133, 5.583253297783934, 5.67335229269499, 5.758066669679313, 5.838070480298543, 5.913915003627148, 5.986057251563568, 6.054880592893135, 6.120709986433513, 6.183823438455509, 6.244460759941559, 6.302830356773558, 6.359114562982194, 6.413473878696176, 6.466050373490047, 6.5169704459373925, 6.56634708096539, 6.614281711423883, 6.660865764774822, 6.706181957075688, 6.750305382509975, 6.793304436258788, 6.835241600568844, 6.876174117789143, 6.916154569445911, 6.955231376759817, 6.993449235129903, 7.030849492830102, 7.067470482348781, 7.103347811345951, 7.1385146190282205, 7.173001802788405, 7.206838219179042, 7.240050862651163, 7.272665024963921, 7.304704437735335, 7.336191400242209, 7.367146894274752, 7.397590687597693, 7.4275414273559806, 7.457016724582565, 7.486033230812577, 7.51460670767787, 7.542752090244527, 7.570483544760624, 7.597814521399589, 7.624757802513901, 7.651325546852907, 7.677529330145633, 7.70338018240364, 7.728888622258895, 7.7540646886168405, 7.778917969874226, 7.80345763092453, 7.827692438150267, 7.851630782580732, 7.875280701375474, 7.898649897777577, 7.921745759666528, 7.9445753768277445, 7.967145557044472, 7.989462841107764, 8.011533516831197, 8.033363632148992, 8.054959007369023, 8.076325246645677, 8.097467748731862, 8.118391717064146, 8.139102169230371, 8.159603945864884, 8.179901719012625, 8.200000000000003, 8.21990314684719, 8.239615371253805, 8.259140745187251, 8.278483207100725, 8.297646567805772, 8.316634516022255, 8.33545062362699, 8.354098350620525, 8.372581049830186, 8.390901971366121, 8.409064266845835, 8.427070993401621, 8.444925117484189, 8.462629518474923, 8.48018699211825, 8.497600253784855, 8.514871941575699, 8.532004619276144, 8.549000779168825], [0.0, 3.429750072090244, 3.9397482658610254, 4.2725457799513675, 4.525582352096981, 4.732127905861649, 4.907866309079661, 5.0615331073677625, 5.1985290032574145, 5.322442469009131, 5.435787541098841, 5.540398600961086, 5.637657955785175, 5.72863489850604, 5.814174754196379, 5.894958142549842, 5.971541714446169, 6.044386935025435, 6.113880908717146, 6.180351760821372, 6.244080206573616, 6.305308393736291, 6.364246758951874, 6.421079412960804, 6.475968419846378, 6.529057233545662, 6.580473484292494, 6.630331257968279, 6.6787329758106715, 6.725770956174357, 6.7715287211233814, 6.816082096578304, 6.859500144180488, 6.901845955019752, 6.943177329229288, 6.983547360703253, 7.023004942491163, 7.0615952055155375, 7.0993599009585395, 7.136337734830173, 7.172564661760659, 7.208074143873571, 7.242897379633876, 7.2770635067797915, 7.31059978280323, 7.343531745912761, 7.375883358973402, 7.40767713855185, 7.438934270890283, 7.46967471637562, 7.499917303855393, 7.529679815968993, 7.558979066508395, 7.587830970690855, 7.6162506091135835, 7.644252286064228, 7.671849582778171, 7.699055406162425, 7.72588203344432, 7.75234115314977, 7.778443902769605, 7.804200903432054, 7.829622291864241, 7.85471774989472, 7.879496531722051, 7.903967489150639, 7.928139094974129, 7.952019464668224, 7.97561637653839, 7.998937290453515, 8.021989365283712, 8.04477947514902, 8.067314224575647, 8.089599962647236, 8.111642796230647, 8.133448602348327, 8.155023039762987, 8.176371559834376, 8.197499416702685, 8.21841167684843, 8.239113228074334, 8.259608787950958, 8.279902911764234, 8.300000000000002, 8.319904305397767, 8.339619939603233, 8.3591508794469, 8.378500972873839, 8.397673944547751, 8.416673401150742, 8.435502836398493, 8.454165635789144, 8.472665081102752, 8.491004354666996, 8.509186543403654, 8.527214642669295, 8.545091559902735, 8.562820118090858, 8.580403059063618, 8.597843046628313, 8.615142669552489, 8.632304444404221], [0.0, 3.4627682660805164, 3.9776762109826245, 4.3136775657752775, 4.569150120266579, 4.777684087477908, 4.9551143237936754, 5.1102604719029285, 5.248575226884725, 5.373681607211614, 5.488117851981384, 5.593736002213324, 5.69193167256404, 5.783784450048447, 5.870147797681265, 5.951708887479961, 6.029029729200674, 6.102576230507047, 6.1727392224818045, 6.239849989286327, 6.304191948600877, 6.366009579343672, 6.425515344030136, 6.482895125834271, 6.538312549029835, 6.591912448584528, 6.6438236834280815, 6.694161437746347, 6.743029118785938, 6.790519933650073, 6.836718208469464, 6.88170049914059, 6.925536532161033, 6.968290005998352, 7.010019277227451, 7.050777950877256, 7.090615390690525, 7.12957716206504, 7.167705418121471, 7.20503923749247, 7.2416149209433796, 7.277466252737538, 7.3126247316874435, 7.347119776040237, 7.380978905695626, 7.414227904718437, 7.446890966664123, 7.478990824866301, 7.510548869527043, 7.541585253191853, 7.572118985973525, 7.602168021704865, 7.631749336044179, 7.66087899742447, 7.689572231623816, 7.717843480637199, 7.745706456446515, 7.773174190213532, 7.800259077358414, 7.826972918932479, 7.85332695964715, 7.879331922880226, 7.9049980429450715, 7.930335094877178, 7.955352421965249, 7.980058961229983, 8.004463267032586, 8.02857353297642, 8.052397612248678, 8.075943036534383, 8.09921703362207, 8.12222654380891, 8.144978235202865, 8.167478518010194, 8.189733557888541, 8.21174928843843, 8.23353142289947, 8.255085465111629, 8.276416719796691, 8.297530302210166, 8.318431147209646, 8.33912401778172, 8.359613513066048, 8.379904075911936, 8.4, 8.419905436558745, 8.439624400703604, 8.459160777423806, 8.47851832724038, 8.497700691556947, 8.516711397723183, 8.535553863829405, 8.554231403249359, 8.572747228946982, 8.591104457561839, 8.60930611328679, 8.627355131550555, 8.645254362516903, 8.66300657441138, 8.680614456685745, 8.698080623029606, 8.71540761423803], [0.0, 3.495707936800062, 4.015513956552311, 4.354711532731363, 4.612614276359274, 4.823131928208431, 5.002249974135133, 5.158871953902596, 5.298502431489737, 5.42479888942397, 5.540323711866702, 5.646946557424266, 5.746076316572989, 5.838802845926572, 5.925987727088251, 6.00832466881669, 6.086381027000052, 6.160627141260413, 6.231457560471057, 6.2992067201423305, 6.364160733972349, 6.4265664064912205, 6.486638221269423, 6.544563829699355, 6.600508412534814, 6.654618182489796, 6.707023224267858, 6.757839817747337, 6.807172353838894, 6.855114926280672, 6.901752663357838, 6.94716284920677, 6.991415873600124, 7.034576040938742, 7.076702262915923, 7.1178486544797845, 7.1580650489469395, 7.197397445157167, 7.235888397213764, 7.273577355485864, 7.310500966050759, 7.346693334545445, 7.382186259415672, 7.417009438750401, 7.451190654233081, 7.484755935200109, 7.517729705348743, 7.550134914264015, 7.581993155622832, 7.613324773672298, 7.644148959359387, 7.6744838373031925, 7.704346544643399, 7.733753302664386, 7.762719481979829, 7.791259661964554, 7.819387685036032, 7.847116706315287, 7.874459239134229, 7.9014271968019765, 7.928031930995553, 7.954284267099163, 7.980194536780332, 8.005772608059827, 8.031027913104621, 8.055969473949046, 8.080605926327888, 8.104945541786366, 8.128996248215316, 8.152765648945104, 8.176261040518789, 8.19948942925329, 8.22245754668712, 8.245171864003783, 8.2676386055119, 8.28986376125552, 8.311853098821583, 8.33361217440548, 8.355146343190295, 8.376460769090533, 8.397560433906742, 8.418450145933546, 8.439134548060034, 8.459618125398233, 8.479905212472497, 8.500000000000002, 8.519906541290068, 8.53962875828798, 8.55917044728682, 8.578535284329154, 8.59772683031866, 8.616748535860324, 8.635603745846447, 8.654295703804365, 8.672827556020755, 8.691202355456188, 8.709423065462726, 8.72749256331639, 8.745413643575544, 8.763189021275425, 8.780821334968424, 8.798313149618995], [0.0, 3.528570191560862, 4.053262774537535, 4.395649060232419, 4.655976281481984, 4.868472955844402, 5.049274844633242, 5.207369187508068, 5.348312295443567, 5.475796034023396, 5.5924068757260175, 5.700032055339337, 5.800093707958116, 5.893691935658869, 5.9816964195527635, 6.064807389776782, 6.1435975357864425, 6.218541618746116, 6.290037896581964, 6.35842394874689, 6.423988578620585, 6.486980910879318, 6.547617445398665, 6.606087597633689, 6.66255810116014, 6.717176543200277, 6.770074231350633, 6.821368538606889, 6.871164837231914, 6.91955810551498, 6.9666342720104515, 7.012471347383075, 7.057140383121724, 7.100706288136442, 7.143228527934262, 7.1847617261840675, 7.225356184672712, 7.265058334663284, 7.303911130299305, 7.34195439281272, 7.379225112781206, 7.415757716460115, 7.4515843012242415, 7.486734844346668, 7.521237388679336, 7.555118208253765, 7.588401956368132, 7.621111798350641, 7.653269530874822, 7.684895689438835, 7.716009645398828, 7.746629693758799, 7.776773132760289, 7.806456336179818, 7.835694819126263, 7.8645032980314165, 7.892895745441771, 7.920885440146272, 7.9484850131114575, 7.975706489640414, 8.002561328124372, 8.029060455714198, 8.05521430120278, 8.08103282537762, 8.10652554907507, 8.131701579143304, 8.156569632499432, 8.181138058447356, 8.205414859405979, 8.22940771018263, 8.253123975913297, 8.276570728779493, 8.299754763601198, 8.322682612395855, 8.345360557985215, 8.367794646724194, 8.389990700419347, 8.411954327498426, 8.433690933487226, 8.455205730844884, 8.476503748204582, 8.497589839062488, 8.518468689954304, 8.539144828155443, 8.559622628938016, 8.579906322415052, 8.6, 8.619907620507346, 8.639633015918148, 8.659179896832509, 8.678551857629246, 8.697752381351604, 8.716784844336358, 8.735652520602411, 8.754358586013877, 8.772906122231428, 8.791298120464837, 8.809537485038664, 8.827627036782195, 8.845569516254022, 8.86336758681089, 8.881023837529824], [0.0, 3.5613561093793566, 4.0909239044027075, 4.4364914924426095, 4.699237559405438, 4.913708659136809, 5.096190479327166, 5.255753765102846, 5.398006454229308, 5.526674715476781, 5.644369053685139, 5.752994238995509, 5.853985620354667, 5.948453521502387, 6.037275704243113, 6.1211589049434005, 6.200681134236585, 6.276321564558364, 6.348482154271884, 6.417503619469424, 6.4836774469642915, 6.547255076189362, 6.608455018641561, 6.66746844974081, 6.724463652277703, 6.7795895847898695, 6.832978774926111, 6.8847496862602116, 6.935008670127631, 6.983851587314009, 7.031365164783937, 7.077628138042849, 7.122712218758713, 7.166682918946535, 7.209600256640609, 7.251519363048856, 7.292491007340146, 7.3325620521963835, 7.371775850872046, 7.410172594600401, 7.4477896176592555, 7.484661666177544, 7.520821135764708, 7.556298282229431, 7.591121408985463, 7.625317034191035, 7.658910040211899, 7.691923807618269, 7.724380335608752, 7.756300350488299, 7.787703403603155, 7.818607959946424, 7.849031478487279, 7.878990485140148, 7.908500639173458, 7.937576793757594, 7.966233051265785, 7.994482813867629, 8.022338829891034, 8.049813236372895, 8.076917598170764, 8.103662943965771, 8.13005979945055, 8.15611821796384, 8.181847808805415, 8.207257763440259, 8.232356879779234, 8.257153584704286, 8.281655954989269, 8.305871736752437, 8.329808363563368, 8.353472973315174, 8.376872423962297, 8.40001330821481, 8.42290196727167, 8.44554450366786, 8.467946793303588, 8.490114496717649, 8.51205306966159, 8.53376777302643, 8.555263682169185, 8.576545695682572, 8.597618543647513, 8.61848679540487, 8.639154866879851, 8.659627027489833, 8.679907406663867, 8.700000000000003, 8.719908675084374, 8.739637176994343, 8.759189133506112, 8.778568060025824, 8.797777364261686, 8.816820350653343, 8.835700224573637, 8.85442009631667, 8.872982984885219, 8.891391821589545, 8.909649453468836, 8.927758646545746, 8.945722088923755, 8.96354239373645], [0.0, 3.594066742016091, 4.1284985543034365, 4.4772401395725865, 4.7423994979359945, 4.958840489230872, 5.142998383253725, 5.304027238846918, 5.447586502017842, 5.577436565954067, 5.6962119126721955, 5.8058348074007355, 5.9077537825959645, 6.003089360189257, 6.092727364122919, 6.177381022053046, 6.257633653571948, 6.3339688322572005, 6.4067922084117495, 6.4764476275646885, 6.543229253801066, 6.607390835995068, 6.669152892645752, 6.728708355096553, 6.786227051795495, 6.8418593094466775, 6.895738872949602, 6.947985293951906, 6.99870590061342, 7.047997434189712, 7.095947418222238, 7.142635311392688, 7.188133484032182, 7.232508049875794, 7.275819578216337, 7.31812370663532, 7.3594716706103975, 7.399910763251638, 7.4394847360080085, 7.478234149264479, 7.51619668020976, 7.553407394111853, 7.58989898413002, 7.625701983968954, 7.660844957005895, 7.6953546649652065, 7.729256218754215, 7.76257321369089, 7.795327851033865, 7.827541047456739, 7.8592325338825475, 7.8904209449031635, 7.921123899846317, 7.951358076414995, 7.981139277706144, 8.010482493314754, 8.039401955142678, 8.067911188456847, 8.096023058677046, 8.123749814317414, 8.151103126457341, 8.178094125075086, 8.204733432540516, 8.231031194531097, 8.256997108606873, 8.282640450655345, 8.307970099395138, 8.332994559108114, 8.357721980752327, 8.38216018159321, 8.406316663476797, 8.430198629856894, 8.453813001677446, 8.477166432201779, 8.50026532087201, 8.523115826274184, 8.54572387827795, 8.568095189413482, 8.590235265542757, 8.612149415877449, 8.633842762391128, 8.655320248669502, 8.676586648238727, 8.697646572408514, 8.71850447766382, 8.739164672636113, 8.759631324682763, 8.779908466100906, 8.8, 8.819909705855498, 8.839641244764293, 8.859198164421116, 8.87858390383357, 8.897801797792187, 8.916855081110773, 8.935746892651116, 8.954480279145173, 8.97305819882694, 8.991483524885323, 9.009759048748567, 9.027887483210062, 9.045871465404716], [0.0, 3.6267031149657987, 4.1659879022238355, 4.517896279112868, 4.7854634502220685, 5.003869861032094, 5.189700023864177, 5.352191122137887, 5.497053993168526, 5.628083176864722, 5.747937077986809, 5.85855541713333, 5.961399880340854, 6.057601164580419, 6.1480531376295255, 6.233475503697279, 6.314456879282568, 6.391485229113374, 6.4649698870509935, 6.5352578209568915, 6.6026458661099126, 6.667390075582659, 6.729712970320024, 6.7898092336026545, 6.8478502360270594, 6.903987669357789, 6.9583564929816495, 7.011077344149977, 7.062258525629396, 7.111997657146554, 7.160383057011379, 7.207494905440071, 7.253406229931597, 7.2981837445750815, 7.34188856867038, 7.384576845023026, 7.426300274360844, 7.467106579244906, 7.507039908414689, 7.546141190568817, 7.584448445028429, 7.62199705547608, 7.658820011945359, 7.694948125406085, 7.730410218608823, 7.765233296291123, 7.799442697383047, 7.833062231462806, 7.866114301390342, 7.898620013775723, 7.930599278711105, 7.962070900002103, 7.993052656970959, 8.02356137876463, 8.05361301198206, 8.083222682333135, 8.112404750954273, 8.141172865930287, 8.169540009507013, 8.19751854142276, 8.225120238737611, 8.25235633249699, 8.27923754152852, 8.305774103638763, 8.331975804447671, 8.357852004073601, 8.383411661859498, 8.408663359311413, 8.4336153214032, 8.45827543638595, 8.482651274227146, 8.50675010379246, 8.53057890887233, 8.55414440314588, 8.57745304416616, 8.600511046443023, 8.623324393693046, 8.645898850319744, 8.668239972181766, 8.690353116701747, 8.712243452363978, 8.733915967645016, 8.755375479417618, 8.776626640865071, 8.797673948940005, 8.81852175139895, 8.839174253441488, 8.859635523980536, 8.879909501568223, 8.900000000000002, 8.919910713617817, 8.939645222331684, 8.959206996377546, 8.978599400827914, 8.99782569987073, 9.016889060870609, 9.035792558225737, 9.054539177032725, 9.07313181657083, 9.09157329361621, 9.109866345596119, 9.128013633592294], [0.0, 3.6592662284008046, 4.203393097060209, 4.558461157009065, 4.828430735998954, 5.048798154507899, 5.236296832374194, 5.400246891003228, 5.546410443659122, 5.67861610032174, 5.799546134795289, 5.9111576838659285, 6.014925557624421, 6.111990605241352, 6.203254720273259, 6.2894440689442135, 6.371152552769608, 6.448872517770925, 6.523016973099261, 6.593936001939686, 6.661929104768761, 6.727254633685226, 6.790137107584876, 6.850772957752967, 6.909335093472795, 6.965976568505189, 7.020833553998073, 7.074027770369606, 7.125668492805486, 7.17585421753152, 7.224674055842078, 7.27220890786822, 7.318532456801609, 7.363712015737789, 7.407809252749049, 7.450880814730861, 7.492978866616859, 7.534151559455127, 7.5744434383838435, 7.613895799588525, 7.652547003754746, 7.690432752264867, 7.727586331360402, 7.7640388286539155, 7.799819325687073, 7.834955069665119, 7.869471627029005, 7.903393021136223, 7.936741855995486, 7.969539427726984, 8.001805825189802, 8.033560021023462, 8.064819954185573, 8.095602604927116, 8.12592406302691, 8.155799590004197, 8.185243675939864, 8.214270091460913, 8.242891935376994, 8.27112167840091, 8.298971203335551, 8.326451842066628, 8.35357440966301, 8.380349235853542, 8.406786194120418, 8.432894728623776, 8.458683879149898, 8.484162304255689, 8.509338302764649, 8.534219833754179, 8.558814535160309, 8.583129741113739, 8.607172498110334, 8.630949580109391, 8.65446750264445, 8.677732536023646, 8.700750717689607, 8.723527863802753, 8.746069580106171, 8.768381272125238, 8.790468154750567, 8.812335261248792, 8.833987451741974, 8.855429421192978, 8.876665706931265, 8.897700695750611, 8.91853863060786, 8.939183616949515, 8.959639628690823, 8.979910513870196, 9.000000000000002, 9.01991169913323, 9.039649112664058, 9.059215635879012, 9.078614562274227, 9.09784908765316, 9.11692231401813, 9.135837253268061, 9.154596830713999, 9.173203888423112, 9.191661188401218, 9.209971415623137], [0.0, 3.6917570580704493, 4.240715259654219, 4.598935988782319, 4.871302642775625, 5.0936267159285915, 5.282790205050913, 5.448195985427629, 5.59565733244907, 5.729036850537416, 5.851040629556123, 5.963643183818425, 6.068332418336433, 6.166259311944377, 6.258333766162168, 6.345288394884426, 6.427722372911345, 6.506132417832288, 6.580935205929725, 6.652483928796921, 6.7210807461919355, 6.78698630413625, 6.850427115041505, 6.911601354317335, 6.970683466518239, 7.027827864377956, 7.083171928115654, 7.1368384589119005, 7.188937702212882, 7.239569028797907, 7.288822341185518, 7.336779257823566, 7.383514116140899, 7.429094826909802, 7.473583605756831, 7.517037602548413, 7.559509445393548, 7.601047712876172, 7.641697345653236, 7.681500006581403, 7.72049439695292, 7.758716535144719, 7.7962000029487175, 7.832976164006131, 7.869074358075262, 7.904522074290814, 7.9393451060996005, 7.97356769016385, 8.00721263119453, 8.040301414401279, 8.072854307013284, 8.104890450129194, 8.136427941987629, 8.167483913608166, 8.198074597631674, 8.228215391085277, 8.257920912708103, 8.287205055397317, 8.316081034267638, 8.344561430760026, 8.372658233185442, 8.400382874046043, 8.4277462644383, 8.4547588258093, 8.481430519308438, 8.50777087295108, 8.533789006788272, 8.559493656256732, 8.584893193865682, 8.609995649361615, 8.63480872849822, 8.659339830526354, 8.683596064508118, 8.707584264549167, 8.731311004034835, 8.754782608947664, 8.778005170337082, 8.800984556005519, 8.82372642146977, 8.846236220251173, 8.868519213543646, 8.890580479304482, 8.912424920809034, 8.93405727470701, 8.955482118615071, 8.976703878277577, 8.997726834324828, 9.018555128655816, 9.039192770470402, 9.059643641973947, 9.07991150377561, 9.1, 9.119912663130373, 9.13965291860019, 9.159224089148724, 9.178629398955149, 9.197871977564638, 9.216954863618936, 9.235881008403084, 9.254653279219127, 9.273274462596888, 9.291747267351226], [0.0, 3.7241765561590463, 4.2779554837784195, 4.639321960598091, 4.914080426966815, 5.138356859051114, 5.329181504440646, 5.496039810619147, 5.6447961027799085, 5.779346905154763, 5.902422071379746, 6.016013455143897, 6.121622027631594, 6.220408875101671, 6.313291889456429, 6.401010118105582, 6.4841679975569555, 6.563266607370295, 6.638726282908482, 6.710903317348663, 6.780102523892107, 6.846586837446879, 6.9105847595638235, 6.972296205947834, 7.031897153054025, 7.089543369605505, 7.145373442238246, 7.199511250522475, 7.252068008034724, 7.303143958187776, 7.35282979298726, 7.401207847620801, 7.448353112318093, 7.4943340942160015, 7.5392135552932285, 7.583049147282915, 7.6258939604525535, 7.667796999983302, 7.708803601182555, 7.748955792773108, 7.788292615906108, 7.826850405257114, 7.864663037519583, 7.901762151757381, 7.938177345378545, 7.9739363489161015, 8.009065182324344, 8.04358829510194, 8.077528692221494, 8.11090804756694, 8.14374680634598, 8.176064277746546, 8.207878718938575, 8.23920741137924, 8.270066730257813, 8.300472207811803, 8.330438591156112, 8.359979895189642, 8.389109451076834, 8.417839950743705, 8.446183487777654, 8.47415159507639, 8.501755279553162, 8.529005054171936, 8.555910967556839, 8.582482631394365, 8.608729245824115, 8.63465962299383, 8.66028220893668, 8.685605103913101, 8.710636081345553, 8.735382605462089, 8.759851847753673, 8.78405070234028, 8.80798580033202, 8.831663523263627, 8.855090015673621, 8.878271196893074, 8.901212772103214, 8.923920242715967, 8.9463989161269, 8.96865391488585, 8.990690185326724, 9.012512505694545, 9.03412549380473, 9.055533614266713, 9.076741185301534, 9.097752385180648, 9.118571258311064, 9.139201720990082, 9.159647566850989, 9.179912472019604, 9.200000000000003, 9.2199136063064, 9.239656642857007, 9.259232362144415, 9.278643921196181, 9.297894385338155, 9.316986731772358, 9.335923852980308, 9.354708559961985, 9.373343585319956], [0.0, 3.7565256521046986, 4.315114837076831, 4.67962023028618, 4.956765314973455, 5.182989866248785, 5.375472060540582, 5.543779738217587, 5.693828163416368, 5.829547706518187, 5.953691933326282, 6.068269999251328, 6.174795913275489, 6.274440847132929, 6.368130665756436, 6.456610836099803, 6.540491044952172, 6.620276724371217, 6.69639186085418, 6.769195842426692, 6.838996129971018, 6.906057942311262, 6.970611765817859, 7.032859252711743, 7.092977908021967, 7.151124853516344, 7.207439879627798, 7.2620479419743855, 7.315061220160592, 7.366580828337667, 7.416698246283876, 7.465496524370147, 7.513051304209397, 7.5594316880080115, 7.604700982910376, 7.648917341426494, 7.6921343149787305, 7.734401334419066, 7.77576412884831, 7.8162650920608865, 7.855943604328796, 7.894836315939357, 7.932977397847156, 7.970398763940599, 8.007130268717953, 8.04319988358634, 8.078633854515655, 8.11345684337881, 8.147692054975145, 8.181361351453187, 8.214485355612638, 8.247083544365696, 8.27917433346848, 8.31077515448907, 8.34190252485558, 8.372572111722281, 8.402798790301077, 8.432596697227657, 8.461979279464174, 8.490959339181776, 8.519549075015682, 8.54776012004113, 8.575603576780072, 8.603090049514616, 8.630229674153663, 8.657032145873135, 8.683506744727262, 8.70966235940823, 8.735507509313484, 8.761050365064284, 8.78629876760491, 8.811260245999495, 8.835942034032312, 8.860351085707322, 8.884494089734053, 8.908377483078795, 8.932007463653008, 8.955390002204503, 8.978530853471089, 9.001435566651281, 9.024109495241968, 9.046557806288686, 9.068785489090391, 9.090797363397101, 9.112598087135687, 9.134192163696259, 9.155583948808967, 9.176777657038738, 9.197777367923278, 9.21858703177779, 9.239210475187972, 9.259651406211363, 9.27991341930549, 9.300000000000002, 9.319914529328676, 9.339660288036043, 9.35924046057236, 9.37865813888964, 9.397916326050597, 9.417017939661537, 9.43596581513947, 9.454762708823006], [0.0, 3.7888052533811907, 4.352194361963098, 4.7198319283147585, 4.99935850421438, 5.227526989590102, 5.421663171917647, 5.591417107448407, 5.742754889831497, 5.879640662886863, 6.004851653644753, 6.120414282068665, 6.227855566929809, 6.328356743771332, 6.422851633428265, 6.512092108607554, 6.59669309510062, 6.6771643681127175, 6.753933557431816, 6.827363139283455, 6.897763216542954, 6.965401287043982, 7.030509817712635, 7.0932921935553725, 7.153927444891397, 7.212574043626516, 7.269372981404521, 7.324450287579656, 7.377919105709068, 7.429881418811888, 7.480429492746672, 7.5296470915312375, 7.577610506762381, 7.624389434437631, 7.670047725695896, 7.714644032748236, 7.7582323671812, 7.800862584603137, 7.842580807062299, 7.883429792640457, 7.923449260001947, 7.962676174367824, 8.001145000321653, 8.038887925985984, 8.07593506239701, 8.112314621318486, 8.148053074250365, 8.183175294983567, 8.21770468771489, 8.251663302453002, 8.285071939208091, 8.317950242256307, 8.350316785599265, 8.382189150593469, 8.41358399660031, 8.444517125400983, 8.475003540029203, 8.505057498595928, 8.534692563612253, 8.563921647257626, 8.592757052989407, 8.621210513845158, 8.649293227750142, 8.677015890108436, 8.704388723926195, 8.731421507689415, 8.75812360119528, 8.784503969515974, 8.810571205255625, 8.836333549245147, 8.861798909805591, 8.886974880697894, 8.911868757865799, 8.93648755506861, 8.960838018491543, 8.98492664041335, 9.008759672003782, 9.032343135316925, 9.055682834540708, 9.078784366557581, 9.101653130866712, 9.12429433891375, 9.146713022870404, 9.168914043902511, 9.190902099962234, 9.212681733137046, 9.234257336585626, 9.255633161088408, 9.27681332123832, 9.297801801295389, 9.31860246072694, 9.339219039453623, 9.35965516281993, 9.379914346306457, 9.400000000000002, 9.419915432836339, 9.439663856629517, 9.459248389900509, 9.478672061517164, 9.497937814156613, 9.51704850760043, 9.536006921872278], [0.0, 3.821016246244964, 4.389195076478536, 4.759958158720896, 5.041861164111979, 5.271969451869366, 5.46775610677741, 5.6389532262250786, 5.791577625338867, 5.92962714959393, 6.0559026369569615, 6.172447735249484, 6.2808024453802025, 6.382158045311209, 6.47745629486997, 6.567455458901529, 6.652775691064392, 6.7339311004802855, 6.811352952484305, 6.885406804938109, 6.956405397094668, 7.024618500953319, 7.090280559786257, 7.153596687702538, 7.214747437069593, 7.273892627061588, 7.331174447980078, 7.3867200006333285, 7.440643390482325, 7.493047467567353, 7.544025282156485, 7.593661310397621, 7.642032492489928, 7.689209116960012, 7.735255577785077, 7.780231025815152, 7.824189931822919, 7.867182575270299, 7.909255470317796, 7.950451738560266, 7.990811436335141, 8.03037184312784, 8.069167716526817, 8.107231518305893, 8.144593615493932, 8.181282459700462, 8.217324747476143, 8.252745564079477, 8.287568512680917, 8.321815830749983, 8.355508495130707, 8.388666317107461, 8.421308028591012, 8.453451360407925, 8.485113113551202, 8.516309224142814, 8.547054822766608, 8.577364288750628, 8.607251299909317, 8.636728878196603, 8.665809431669198, 8.694504793114524, 8.722826255658378, 8.750784605633127, 8.778390152957073, 8.805652759249202, 8.83258186388017, 8.859186508139821, 8.885475357683358, 8.911456723402134, 8.93713858085076, 8.962528588349464, 8.98763410386935, 9.01246220079806, 9.03701968267433, 9.061313096971816, 9.085348748005353, 9.109132709026266, 9.132670833567493, 9.155968766094071, 9.179031952009673, 9.20186564706569, 9.224474926215459, 9.246864691952615, 9.269039682169534, 9.29100447756881, 9.312763508658094, 9.334321062356352, 9.355681288237232, 9.376848204433434, 9.397825703224017, 9.41861755632503, 9.439227419902272, 9.45965883932363, 9.479915253667174, 9.500000000000002, 9.519916317441792, 9.539667351026008, 9.559256155370791, 9.5786856981708, 9.597958863520395, 9.617078455077953], [0.0, 3.853159496449108, 4.426117975112294, 4.800000000000001, 5.084274437034299, 5.316318447591793, 5.5137521039857695, 5.686389372202773, 5.840297682174777, 5.979508510154484, 6.106846255389083, 6.22437175732636, 6.333637971709894, 6.435846197800597, 6.531946117721946, 6.622702375013832, 6.708740340207163, 6.790578447225517, 6.868651589305228, 6.943328399463109, 7.014924247785244, 7.083711175653851, 7.149925598530794, 7.213774355991262, 7.275439519249912, 7.335082251915836, 7.392845940427467, 7.448858754793728, 7.50323576035647, 7.556080672353706, 7.607487323813347, 7.657540901515693, 7.706318992898216, 7.753892477770456, 7.800326291806272, 7.845680083445981, 7.890008781682685, 7.933363088940478, 7.97578991066747, 8.017332731207093, 8.05803194385972, 8.097925141714214, 8.137047374747693, 8.17543137780974, 8.213107773383514, 8.2501052524199, 8.286450736046957, 8.32216952054604, 8.357285407642793, 8.391820821873345, 8.425796916543668, 8.459233669595124, 8.49214997051554, 8.52456369928719, 8.556491798236818, 8.587950337544646, 8.618954575076405, 8.649519011122285, 8.679657438557593, 8.709382988879865, 8.738708174525188, 8.767644927821056, 8.79620463689359, 8.824398178812213, 8.852235950224587, 8.879727895707864, 8.906883534038807, 8.933711982564631, 8.960221979837986, 8.986421906663317, 9.0123198056874, 9.037923399653975, 9.063240108431062, 9.088277064909231, 9.113041129860123, 9.13753890583622, 9.161776750185672, 9.185760787249361, 9.209496919801472, 9.232990839789547, 9.256248038425223, 9.279273815672463, 9.30207328917625, 9.324651402671101, 9.347012933905615, 9.369162502116284, 9.391104575081192, 9.412843475781832, 9.434383388699004, 9.455728365766843, 9.476882332007138, 9.497849090864463, 9.518632329261111, 9.5392356223894, 9.559662438257702, 9.579916142005274, 9.600000000000001, 9.619917183732076, 9.639670773515778, 9.659263762010681, 9.678699057572802, 9.697979487445517], [0.0, 3.885235849926138, 4.462964029585662, 4.839958505956381, 5.126599439195989, 5.3605751439155656, 5.559652374046003, 5.733726793785993, 5.888916342533155, 6.029286057325158, 6.157683849653805, 6.276187714813829, 6.386363536422004, 6.489422614181672, 6.586322536024394, 6.677834310909525, 6.764588515382991, 6.847107899169419, 6.925830975855968, 7.001129447214578, 7.0733213086891356, 7.142680866321693, 7.209446503659246, 7.273826782152066, 7.336005288701002, 7.3961445285520275, 7.454389081791044, 7.5108681854024075, 7.565697862611122, 7.618982692052276, 7.670817287884531, 7.7212875460416175, 7.770471699852276, 7.818441219178398, 7.865261580263115, 7.910992928101446, 7.95569064895326, 7.999405867324552, 8.042185879136687, 8.08407453072672, 8.125112551656684, 8.165337847966194, 8.204785761412527, 8.243489299352696, 8.281479339192503, 8.318784810726063, 8.355432859191454, 8.391448991453696, 8.42685720738039, 8.461680118184951, 8.495939053268035, 8.52965415688115, 8.562844475761231, 8.59552803873584, 8.62772192917131, 8.65944235102712, 8.69070468918598, 8.721523564648484, 8.75191288511133, 8.781885891387688, 8.811455200075777, 8.840632842836007, 8.8694303025971, 8.897858546976702, 8.925928059171325, 8.953648866543631, 8.981030567111238, 9.008082354120441, 9.03481303886962, 9.061231071930807, 9.087344562903308, 9.113161298820303, 9.138688761317905, 9.163934142665775, 9.188904360749344, 9.213606073085284, 9.238045689944697, 9.262229386651692, 9.286163115119212, 9.309852614678492, 9.333303422253795, 9.356520881929637, 9.379510153953799, 9.402276223215852, 9.424823907237664, 9.447157863709432, 9.469282597602103, 9.491202467884646, 9.512921693872359, 9.53444436123047, 9.55577442765535, 9.576915728254068, 9.597871980641397, 9.618646789772017, 9.63924365252439, 9.659665962051513, 9.679917011912762, 9.700000000000003, 9.719918032270169, 9.739674126295798, 9.759271214644059, 9.778712148094256], [0.0, 3.9172461334412456, 4.499734189602455, 4.879834706517015, 5.168837261520256, 5.404740681553142, 5.605458100033535, 5.7809667110926215, 5.937434859555697, 6.078961074117854, 6.2084167300856485, 6.32789694326364, 6.4389804985133265, 6.542888675381858, 6.640586951324713, 6.732852687609407, 6.8203216560736815, 6.903520913353645, 6.982892585930188, 7.058811438009439, 7.131598084985456, 7.201529092895438, 7.268844809317709, 7.333755514030955, 7.396446306500246, 7.457081030844973, 7.515805458339868, 7.572749890746988, 7.628031307201475, 7.681755147957089, 7.734016806694293, 7.7849028870395545, 7.834492266882491, 7.882857004921974, 7.930063116856959, 7.976171243214375, 8.021237226578998, 8.065312612669327, 8.1084450870757, 8.150678857383168, 8.192054988722797, 8.23261169944036, 8.27238462247228, 8.311407037121706, 8.34971007519199, 8.38732290482853, 8.424272894917792, 8.460585762474714, 8.496285705100728, 8.531395520302018, 8.565936713211215, 8.59992959404741, 8.633393366472744, 8.66634620785348, 8.698805342305041, 8.730787107290599, 8.762307014448217, 8.79337980524026, 8.824019501948314, 8.85423945447601, 8.884052383369156, 8.913470419416468, 8.942505140154006, 8.971167603561119, 8.99946837920491, 9.027417577063026, 9.055024874230726, 9.082299539697043, 9.10925045735625, 9.135886147404262, 9.162214786255008, 9.188244225098689, 9.213982007212275, 9.239435384122219, 9.264611330710096, 9.289516559343559, 9.314157533107645, 9.338540478204685, 9.362671395585158, 9.386556071866396, 9.410200089591132, 9.433608836873551, 9.456787516476487, 9.479741154359791, 9.502474607736676, 9.52499257267184, 9.547299591252482, 9.569400058360923, 9.591298228075207, 9.612998219722176, 9.634504023605485, 9.655819506429474, 9.676948416438178, 9.697894388287338, 9.718660947666041, 9.739251515683316, 9.75966941303403, 9.779917863957333, 9.8, 9.819918863596214, 9.839677411474431, 9.8592785179014], [0.0, 3.9491911552175702, 4.536429383567263, 4.9196296085104745, 5.210988970463928, 5.4488161756339615, 5.651170438490689, 5.828110316876675, 5.985854458279608, 6.128534814770072, 6.2590461776319675, 6.379500748274818, 6.491490186502127, 6.596245731358201, 6.6947407337374845, 6.787758894264725, 6.875941169477454, 6.959818914142443, 7.039837860268441, 7.1163758282521545, 7.189756048096322, 7.26025734122567, 7.328122015245637, 7.393562064760038, 7.456764098714389, 7.517893297371838, 7.577096620767379, 7.634505433269934, 7.690237667975892, 7.744399625001044, 7.797087475958383, 7.848388530724288, 7.8983823104351405, 7.947141461426285, 7.994732537752674, 8.041216674462868, 8.086650169536204, 8.131084989044933, 8.174569207453914, 8.217147392859697, 8.258860945278226, 8.29974839472471, 8.339845664721075, 8.379186305962161, 8.417801704130222, 8.455721265235981, 8.492972581358337, 8.529581579233689, 8.565572653794169, 8.600968788458918, 8.635791663734265, 8.670061755468515, 8.703798423929081, 8.737019994718091, 8.769743832413099, 8.801986407708782, 8.833763358740143, 8.865089547185713, 8.895979109678356, 8.926445504989756, 8.956501557401378, 8.986159496628154, 9.015430994620587, 9.044327199535513, 9.072858767134527, 9.101035889841835, 9.128868323669106, 9.156365413193699, 9.183536114757768, 9.210389018039166, 9.236932366130226, 9.26317407424736, 9.289121747182733, 9.314782695598774, 9.340163951257, 9.36527228126422, 9.390114201411727, 9.414695988676339, 9.439023692946108, 9.463103148028049, 9.486939981990357, 9.510539626887125, 9.533907327909558, 9.557048152004056, 9.579966995994253, 9.602668594241113, 9.625157525872416, 9.647438221610612, 9.669514970225622, 9.691391924637273, 9.71307310769002, 9.73456241762106, 9.755863633241244, 9.776980418846817, 9.797916328878753, 9.818674812345119, 9.839259217020949, 9.85967279343896, 9.8799186986836, 9.900000000000002, 9.91991967822866, 9.939680631075872], [0.0, 3.981071705534973, 4.573050519273264, 4.959344196412832, 5.253055608807535, 5.49280271653059, 5.696790520283513, 5.875158777411963, 6.034176336545164, 6.1780085056741205, 6.309573444801933, 6.431000406460921, 6.5438938994123745, 6.649495102097495, 6.748785222959513, 6.842554289186317, 6.931448431551465, 7.016003294277901, 7.0966682076255525, 7.1738240420137, 7.247796636776957, 7.318867064175758, 7.3872795878869235, 7.453247913878537, 7.516960157530127, 7.578582832551992, 7.638264085340233, 7.69613634072608, 7.752318483841891, 7.8069176729301075, 7.8600308559662295, 7.911746047651194, 7.962143411069946, 8.011296179008337, 8.059271442790802, 8.106130830989493, 8.15193109605923, 8.196724623577651, 8.240559876099319, 8.283481781504692, 8.325532074018732, 8.36674959469707, 8.407170557060674, 8.446828782648353, 8.485755910508885, 8.52398158403826, 8.561533618057357, 8.598438148600783, 8.634719767533111, 8.670401643811235, 8.705505632961243, 8.740052376126375, 8.774061389863258, 8.807551147710715, 8.840539154424949, 8.873042013663262, 8.90507548980229, 8.936654564494116, 8.967793488492095, 8.99850582921625, 9.028804514474345, 9.058701872707864, 9.08820967009122, 9.11733914477673, 9.146101038546528, 9.174505626104983, 9.202562742220909, 9.230281806907431, 9.257671848808377, 9.284741526943302, 9.311499150948379, 9.337952699937013, 9.364109840092413, 9.389977941093633, 9.415564091467342, 9.440875112949021, 9.465917573929858, 9.490697802058683, 9.515221896062348, 9.539495736842317, 9.563524997900371, 9.587315155141829, 9.610871496100636, 9.634199128627019, 9.6573029890751, 9.680187850024815, 9.70285832756977, 9.725318888200212, 9.747573855307921, 9.769627415337911, 9.79148362360977, 9.813146409829908, 9.8346195833143, 9.855906837939878, 9.877011756841473, 9.897937816869888, 9.918688392825665, 9.93926676148203, 9.959676105409555, 9.97991951661426, 10.000000000000002, 10.019920476665336], [0.0, 4.012888557303688, 4.609598484561172, 4.998979433062281, 5.295038196412243, 5.5367013706502, 5.742319451422653, 5.922113233338664, 6.082401665865211, 6.227383346267322, 6.359999756575714, 6.482397166376708, 6.596192907716678, 6.702638078574429, 6.802721729242296, 6.897240200830597, 6.986844788010594, 7.072075415890907, 7.153385005793204, 7.231157472065275, 7.305721258160067, 7.377359682676464, 7.446318961454366, 7.512814508406754, 7.5770359423372575, 7.639151107739046, 7.699309334998933, 7.757644107291616, 7.814275259883211, 7.8693108074282465, 7.922848472713526, 7.974976973856279, 8.025777114607376, 8.075322713031424, 8.123681396648857, 8.170915286569336, 8.217081588815109, 8.262233107631019, 8.3064186928859, 8.349683631525268, 8.392069991315337, 8.433616923730689, 8.474360931711903, 8.514336107100608, 8.553574341805861, 8.59210551613462, 8.629957667204694, 8.667157139930715, 8.703728722716217, 8.739695769685136, 8.77508031103362, 8.80990315286958, 8.844183967726591, 8.877941376784579, 8.91119302469832, 8.943955647822074, 8.976245136521873, 9.008076592183645, 9.039464379453216, 9.070422174181862, 9.100963007496798, 9.131099306368808, 9.160842931007942, 9.190205209382187, 9.219196969122343, 9.247828567048545, 9.27610991652939, 9.30405051286305, 9.331659456850558, 9.358945476714634, 9.385916948502324, 9.412581915096363, 9.43894810394834, 9.465022943636017, 9.490813579337793, 9.516326887308681, 9.541569488434655, 9.56654776093532, 9.591267852278746, 9.615735690366746, 9.63995699404391, 9.663937282979164, 9.687681886964597, 9.711195954672537, 9.734484461908604, 9.757552219395341, 9.780403880118326, 9.803043946264136, 9.825476775777238, 9.847706588560845, 9.869737472344788, 9.891573388241818, 9.913218176012084, 9.934675559054098, 9.955949149139222, 9.977042450905357, 9.997958866124563, 10.01870169775814, 10.039274153811862, 10.059679351003163, 10.079920318251189, 10.100000000000003]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha = 0.30000000000000004\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.1, 0.12311444133449165, 0.13903891703159096, 0.15157165665103983, 0.16206565966927627, 0.17117698594097056, 0.17927899625209978, 0.1866065983073615, 0.1933182044931763, 0.199526231496888, 0.20531364136588445, 0.21074358993444717, 0.21586538444215803, 0.2207183346658568, 0.2253343380842656, 0.22973967099940704, 0.23395626336814518, 0.23800262745964412, 0.2418945481487588, 0.24564560522315815, 0.249267574854026, 0.2527707425511104, 0.25616415021458133, 0.2594557933960466, 0.26265278044037677, 0.26576146209051543, 0.2687875379522287, 0.27173614464666324, 0.27461192933624795, 0.2774191114672182, 0.2801615349437185, 0.2828427124746191, 0.28546586347325026, 0.28803394661274384, 0.2905496879244225, 0.29301560515835223, 0.2954340289925339, 0.2978071215719373, 0.30013689277445693, 0.30242521453322196, 0.3046738334899584, 0.3068843822095699, 0.3090583891496704, 0.3111972875488457, 0.3133024233726666, 0.3153750624359298, 0.317416396802466, 0.3194275505495156, 0.321409584971604, 0.3233635032886788, 0.32529025491464575, 0.3271907393351149, 0.32906580963691917, 0.3309162757266211, 0.3327429072706327, 0.3345464363856255, 0.33632756010449455, 0.3380869426401906, 0.339825217467169, 0.34154298923797627, 0.34324083555054885, 0.3449193085800955, 0.3465789365879481, 0.34822022531844976, 0.3498436592938026, 0.3514497030157747, 0.3530388020822698, 0.3546113842259675, 0.35616786028153175, 0.3577086250872617, 0.3592340583264961, 0.3607445253135852, 0.36224037772879897, 0.36372195430613813, 0.36518958147766223, 0.36664357397762093, 0.3680842354093935, 0.3695118587779748, 0.37092672699051593, 0.372329113327214, 0.3737192818846553, 0.37509748799354153, 0.3764639786125728, 0.377818992700118, 0.3791627615651738, 0.3804955091989958, 0.38181745258867694, 0.3831288020138528, 0.3844297613276209, 0.38572052822268227, 0.3870012944836372, 0.38827224622629913, 0.38953356412482837, 0.3907854236274292, 0.39202799516130105, 0.39326144432748694, 0.3944859320862162, 0.39570161493329836, 0.3969086450680871, 0.39810717055349737, 0.3992973354685279], [0.0, 0.16245047927124712, 0.2, 0.22586938709137114, 0.24622888266898332, 0.26327644086684754, 0.27807783406318193, 0.29123958864421723, 0.30314331330207966, 0.3140463497177345, 0.32413131933855255, 0.3335329944081287, 0.34235397188194105, 0.3506743516070058, 0.3585579925041995, 0.3660567121805817, 0.373213196614723, 0.380063071126653, 0.38663640898635265, 0.39295885279867626, 0.399052462993776, 0.4049363700181799, 0.4106272827317689, 0.4161398897447047, 0.42148717986889433, 0.42668070064464847, 0.43173076888431605, 0.4366466436247808, 0.44143666933171366, 0.4461083953427532, 0.4506686761685312, 0.45512375624975304, 0.45947934199881413, 0.463740663368099, 0.4679125267362904, 0.4719993605543371, 0.4760052549192883, 0.47993399602872644, 0.48378909629751765, 0.4875738207819343, 0.4912912104463163, 0.49494410271851874, 0.49853514970805207, 0.5020668344016355, 0.5055414851022207, 0.5089612883373287, 0.5123283004291627, 0.5156444578911296, 0.5189115867920931, 0.5221314112100969, 0.5253055608807536, 0.5284355781315034, 0.531522924181031, 0.5345689848729849, 0.5375750759044575, 0.5405424476022241, 0.5434722892933264, 0.5463657333110431, 0.5492238586724959, 0.5520476944599737, 0.5548382229344364, 0.5575963824064997, 0.5603230698874369, 0.5630191435403132, 0.5656854249492381, 0.5683227012228512, 0.5709317269465005, 0.5735132259961168, 0.5760678932254877, 0.578596396037494, 0.5810993758488451, 0.5835774494569442, 0.5860312103167045, 0.5884612297344097, 0.5908680579850678, 0.5932522253591237, 0.5956142431438746, 0.5979546045444651, 0.6002737855489139, 0.6025722457412435, 0.6048504290664439, 0.6071087645506855, 0.6093476669799168, 0.6115675375397297, 0.6137687644191397, 0.6159517233807207, 0.6181167782993408, 0.6202642816715723, 0.6223945750976914, 0.6245079897380315, 0.6266048467453333, 0.6286854576745989, 0.6307501248718596, 0.6327991418431543, 0.634832793604932, 0.6368513570169949, 0.6388551010990311, 0.6408442873317046, 0.642819169943208, 0.6447799961821206, 0.6467270065773576, 0.648660435185943], [0.0, 0.2157669279974593, 0.26564024798866687, 0.30000000000000004, 0.3270415072708054, 0.3496840952072148, 0.3693433240034749, 0.38682478275783583, 0.40263532460835283, 0.41711675109477286, 0.4305116202499343, 0.4429989367348897, 0.4547149699531195, 0.4657661086207498, 0.47623717023567047, 0.4861969790078288, 0.49570223050689044, 0.5048002423270921, 0.5135309578229116, 0.5219284355339119, 0.5300219761507747, 0.5378369887562993, 0.5453956660788974, 0.5527175175487992, 0.5598197949220846, 0.5667178356561127, 0.5734253425538376, 0.5799546134795289, 0.5863167315628376, 0.5925217238433759, 0.598578694490664, 0.6044959373785898, 0.6102810317711722, 0.6159409240976533, 0.6214819981961593, 0.6269101359407314, 0.6322307698033415, 0.6374489286163136, 0.642569277573428, 0.647596153326474, 0.6525335948880588, 0.6573853709333776, 0.6621550039975704, 0.6668457919866768, 0.6714608273555641, 0.6760030142527966, 0.6804750838880749, 0.6848796083409066, 0.6892190129982212, 0.6934955877826134, 0.6977114973109455, 0.7018687901044356, 0.705969406955552, 0.7100151885435478, 0.7140078823789323, 0.7179491491472788, 0.7218405685142385, 0.7256836444462764, 0.7294798100952716, 0.733230432289596, 0.7369368156694744, 0.7406002065002304, 0.7442217961933492, 0.747802724562078, 0.75134408283545, 0.754846916452136, 0.7583122276533311, 0.761740977891944, 0.765134090073637, 0.768492450643744, 0.7718169115327335, 0.7751082919716816, 0.7783673801881398, 0.7815949349918222, 0.7847916872586769, 0.7879583413211304, 0.7910955762716047, 0.7942040471857846, 0.7972843862715464, 0.8003372039489589, 0.8033630898663084, 0.8063626138566862, 0.8093363268393033, 0.8122847616693606, 0.8152084339399895, 0.8181078427395068, 0.8209834713669633, 0.8238357880087438, 0.8266652463787582, 0.8294722863245724, 0.8322573344016545, 0.8350208044177447, 0.8377630979492167, 0.8404846048311554, 0.8431857036227615, 0.8458667620495676, 0.8485281374238572, 0.8511701770445723, 0.8537932185779136, 0.8563975904197508, 0.8589836120408871, 0.8615515943161521], [0.0, 0.2639015821545788, 0.3249009585424942, 0.36692590185696067, 0.4, 0.4276938399964752, 0.45173877418274216, 0.47312010758013934, 0.4924577653379665, 0.5101698002503163, 0.526552881733695, 0.5418259479437468, 0.5561556681263637, 0.5696721648669191, 0.5824791772884342, 0.5946608833419245, 0.6062866266041592, 0.6174142805782684, 0.6280926994354689, 0.6383635397102438, 0.648262638677105, 0.6578210738381236, 0.6670659888162573, 0.676021245329112, 0.6847079437638821, 0.6931448431551465, 0.7013487032140114, 0.7093345652902706, 0.717115985008399, 0.7247052263035723, 0.7321134243611633, 0.7393507233050262, 0.746426393229446, 0.7533489302171373, 0.7601261422533059, 0.7667652233777422, 0.7732728179727052, 0.779655076734314, 0.7859177055973525, 0.7920660086613835, 0.7981049259875519, 0.8040390669910071, 0.8098727400363597, 0.8156099787474352, 0.8212545654635377, 0.8268100522091041, 0.8322797794894093, 0.8376668931797637, 0.8429743597377887, 0.8482049799365282, 0.8533614012892968, 0.8584461293144127, 0.863461537768632, 0.8684098779616042, 0.8732932872495615, 0.8781137967943428, 0.8828733386634271, 0.887573752337653, 0.8922167906855063, 0.896804125456097, 0.9013373523370622, 0.9058179956184943, 0.910247512499506, 0.9146272970701094, 0.918958683997628, 0.9232429519438193, 0.9274813267361979, 0.9316749843146821, 0.9358250534725806, 0.9399326184090719, 0.9439987211086741, 0.9480243635617255, 0.9520105098385764, 0.9559580880290229, 0.9598679920574528, 0.9637410833832353, 0.9675781925950351, 0.9713801209069738, 0.9751476415638684, 0.9788815011621667, 0.9825824208926325, 0.9862510977103356, 0.9898882054370374, 0.9934943958006548, 0.9970702994161039, 1.0006165267114868, 1.0041336688032707, 1.0076222983238272, 1.0110829702044413, 1.0145162224166626, 1.0179225766746571, 1.021302539101019, 1.0246566008583253, 1.0279852387485429, 1.031288915782259, 1.034568081719549, 1.037823173584186, 1.0410546161527618, 1.0442628224201935, 1.0474481940429836, 1.050611121761507, 1.0537519858025213], [0.0, 0.3085169313600048, 0.3798288964661869, 0.42895860022204746, 0.4676242239113107, 0.5, 0.5281099842196291, 0.5531060578099961, 0.5757129508131623, 0.5964193922626064, 0.6155722066724582, 0.6334273460055121, 0.6501796567036683, 0.665981259949423, 0.680953433060007, 0.6951945851579547, 0.7087857830839414, 0.7217946844679325, 0.7342784027946782, 0.7462856370756998, 0.7578582832551991, 0.7690326728151439, 0.7798405382945836, 0.7903097754864594, 0.8004650520212367, 0.8103282983463813, 0.8199191075791407, 0.8292550639683243, 0.8383520148598692, 0.8472242975366968, 0.8558849297048526, 0.8643457704594476, 0.8726176571020963, 0.8807105220680125, 0.8886334933647517, 0.8963949812604987, 0.9040027534404962, 0.9114640004409924, 0.9187853928452997, 0.9259731314670223, 0.9330329915368075, 0.9399703617401102, 0.9467902788160734, 0.9534974583152249, 0.9600963220212688, 0.9665910224658815, 0.9729854649020296, 0.9792833270484644, 0.9854880768737936, 0.9916029886513196, 0.99763115748444, 1.0035755124758021, 1.0094388286908085, 1.015223738046778, 1.0209327392425835, 1.0265682068294222, 1.0321323995111822, 1.0376274677523623, 1.0430554607623757, 1.0484183329171726, 1.0537179496722358, 1.0589560930149935, 1.0641344664994563, 1.0692546999012742, 1.0743183535273755, 1.07932692221079, 1.0842818390181181, 1.0891844786943394, 1.094036160867191, 1.098838153031171, 1.1035916733292839, 1.1082978931489154, 1.1129579395466886, 1.1175728975157806, 1.1221438121079361, 1.1266716904213279, 1.131157503464405, 1.135602187904997, 1.1400066477131223, 1.1443717557052424, 1.148698354997035, 1.1529872603711848, 1.1572392595661367, 1.1614551144912943, 1.1656355623736845, 1.1697813168407258, 1.1738930689433664, 1.177971488123527, 1.1820172231294868, 1.1860309028825664, 1.1900131372982206, 1.1939645180644127, 1.1978856193799399, 1.201776998655177, 1.2056391971775395, 1.209472740743794, 1.2132781402611963, 1.2170558923193067, 1.2208064797341946, 1.2245303720666352, 1.2282280261157905, 1.2318998863897663], [0.0, 0.3505144086407193, 0.43153385599491867, 0.4873514378137414, 0.5312804959773337, 0.5680634885994444, 0.6000000000000001, 0.6283987135300648, 0.6540830145416107, 0.6776081612741134, 0.6993681904144295, 0.7196538958923571, 0.7386866480069498, 0.7566392757374455, 0.7736495655156717, 0.7898293226005426, 0.8052706492167057, 0.8200504130227778, 0.8342335021895457, 0.8478752449777619, 0.8610232404998686, 0.8737187659326515, 0.8859978734697794, 0.8978922562741636, 0.909429939906239, 0.9206358401389935, 0.9315322172414996, 0.9421390491532035, 0.9524743404713412, 0.9625543801698194, 0.9723939580156576, 0.9820065474467369, 0.9914044610137811, 1.0005989832243862, 1.0096004846541842, 1.018418520435745, 1.0270619156458234, 1.0355388396466314, 1.043856871067824, 1.0520230548210174, 1.0600439523015495, 1.0679256857403374, 1.0756739775125985, 1.0832941850825, 1.0907913321577951, 1.0981701365417451, 1.1054350350975983, 1.1125902061808428, 1.1196395898441693, 1.1265869060778078, 1.1334356713122253, 1.140189213379959, 1.1468506851076752, 1.1534230766876423, 1.1599092269590578, 1.1663118337135951, 1.1726334631256752, 1.1788765583960288, 1.185043447686752, 1.1911363514170856, 1.197157388981328, 1.20310858494347, 1.2089918747571795, 1.2148091100545397, 1.2205620635423444, 1.226252433540725, 1.2318818481953069, 1.2374518693909473, 1.2429639963923187, 1.2484196692341143, 1.2538202718814628, 1.2591671351791742, 1.2644615396066832, 1.2697047178540075, 1.2748978572326273, 1.2800421019339454, 1.285138555146856, 1.2901882810449485, 1.295192306652948, 1.3001516236011823, 1.3050671897761177, 1.3099399308743422, 1.3147707418667551, 1.3195604883791836, 1.3243100079951409, 1.3290201114859894, 1.3336915839733536, 1.3383251860282597, 1.3429216547111285, 1.347481704556439, 1.3520060285055935, 1.3564952987912493, 1.3609501677761497, 1.3653712687492592, 1.369759216681813, 1.374114608945702, 1.3784380259964424, 1.3827300320228302, 1.3869911755652269, 1.391221990104297, 1.395422994621891, 1.3995946941356596], [0.0, 0.3904528777122722, 0.4807038790699097, 0.5428814526898255, 0.5918158951901497, 0.6327900319620664, 0.668365467587651, 0.7000000000000001, 0.7286108330920732, 0.7548164925853019, 0.7790559126704492, 0.8016530210489499, 0.8228544114931993, 0.8428526055390655, 0.8618010893414415, 0.8798244075239154, 0.8970251566638912, 0.9134889629090254, 0.9292881079469989, 0.9444842242759265, 0.9591303345675485, 0.9732724192211366, 0.9869506383054892, 1.0002002961800205, 1.0130526117060712, 1.0255353396207472, 1.0376732765826269, 1.0494886768664426, 1.061001596557279, 1.0722301806345713, 1.0831909040475693, 1.0938987754306218, 1.104367510256598, 1.1146096788174917, 1.124636833337688, 1.1344596176849338, 1.1440878624868154, 1.1535306679426571, 1.162796476209714, 1.1718931349140638, 1.180827953072478, 1.1896077504978388, 1.1982389015867938, 1.2067273742460807, 1.2150787645970023, 1.2232983280008631, 1.2313910068679628, 1.2393614556458332, 1.2472140633264064, 1.2549529737646983, 1.2625821040618643, 1.2701051612318202, 1.2775256573420153, 1.2848469232945383, 1.2920721213928692, 1.2992042568216626, 1.3062461881515306, 1.3132006369674707, 1.3200701967080632, 1.3268573407925481, 1.3335644301041945, 1.3401937198907656, 1.346747366136255, 1.3532274314522341, 1.3596358905320451, 1.3659746352065694, 1.3722454791363263, 1.3784501621711556, 1.3845903544056124, 1.3906676599554655, 1.3966836204782158, 1.402639718458386, 1.4085373802763697, 1.4143779790779, 1.420162837459632, 1.425893229984935, 1.4315703855427442, 1.4371954895611911, 1.4427696860867099, 1.4482940797384127, 1.453769737546694, 1.459197690684275, 1.4645789360972274, 1.4699144380429032, 1.4752051295411301, 1.4804519137445422, 1.4856556652334423, 1.4908172312401795, 1.495937432807642, 1.5010170658861153, 1.5060569023724397, 1.5110576910951061, 1.516020158748664, 1.5209450107805713, 1.5258329322333908, 1.5306845885450269, 1.535500626309518, 1.5402816740007108, 1.5450283426609976, 1.5497412265571346, 1.5544209038050338, 1.5590679369652924], [0.0, 0.4287093850145173, 0.5278031643091577, 0.5960728861369785, 0.6498019170849885, 0.6947906928878748, 0.7338518037139214, 0.7685858822925763, 0.8, 0.8287732856038029, 0.8553876799929505, 0.8801988492505947, 0.9034775483654844, 0.925435162101199, 0.9462402151602787, 0.9660294550275881, 0.9849155306759331, 1.0029924578885194, 1.0203396005006329, 1.037024629752189, 1.0531057634673902, 1.0686334871972962, 1.0836518958874939, 1.0981997530125958, 1.1123113362527277, 1.1260171197494695, 1.1393443297338381, 1.1523174009506618, 1.164958354576869, 1.1772871134339291, 1.1893217666838491, 1.2010787935044471, 1.2125732532083187, 1.2238189477225525, 1.234828561156537, 1.2456137802623908, 1.256185398870938, 1.2665534088175026, 1.2767270794204881, 1.2867150272150552, 1.2965252773542102, 1.3061653178549548, 1.3156421476762477, 1.3249623194593252, 1.334131977632515, 1.3431568924765382, 1.3520424906582242, 1.3607938826670918, 1.3694158875277644, 1.3779130551094756, 1.3862896863102931, 1.3945498513567334, 1.402697406428023, 1.410736008787478, 1.4186691305805412, 1.4265000714393548, 1.434231970016798, 1.4418678145583093, 1.4494104526071447, 1.4568625999277458, 1.464226848722327, 1.4715056752074482, 1.4787014466100525, 1.4858164276360457, 1.492852786458892, 1.4998126002707441, 1.506697860434275, 1.5135104772695176, 1.520252284506612, 1.5269250434323196, 1.5335304467554847, 1.5400701222142132, 1.5465456359454106, 1.5529584956353981, 1.5593101534686282, 1.565602008889975, 1.571835411194705, 1.5780116619589986, 1.584132017322767, 1.5901976901355181, 1.596209851975104, 1.6021696350483758, 1.6080781339820145, 1.6139364075111446, 1.6197454800727196, 1.625506343310117, 1.6312199574948705, 1.6368872528710128, 1.6425091309270756, 1.64808646560042, 1.6536201044182086, 1.6591108695790215, 1.6645595589788191, 1.6699669471846819, 1.6753337863595277, 1.680660807140755, 1.6859487194755773, 1.6911982134156036, 1.6964099598730566, 1.7015846113408493, 1.7067228025785937, 1.71182515126648], [0.0, 0.46555367217460786, 0.5731638026099791, 0.6473007839923779, 0.7056474135148042, 0.754502629924318, 0.7969207439660005, 0.834639950489428, 0.8687538709400411, 0.8999999999999999, 0.928901697685371, 0.9558451968542797, 0.9811245218124158, 1.0049692242243011, 1.0275623121995368, 1.0490522856216442, 1.0695614747796018, 1.0891919753928967, 1.1080299720104247, 1.1261489516967214, 1.1436121356519529, 1.1604743482735074, 1.1767834741297183, 1.1925816081188618, 1.2079059738250584, 1.222789664408884, 1.2372622459873228, 1.2513502532843184, 1.2650776000282444, 1.2784659212544414, 1.2915348607498027, 1.3043023139512284, 1.3167846344038567, 1.328996810204669, 1.3409526155650784, 1.3526647416240118, 1.3641449098593583, 1.3754039708281371, 1.3864519904756527, 1.3972983258622493, 1.4079516918413504, 1.4184202199676512, 1.4287115107070114, 1.43883267984998, 1.4487903998914244, 1.4585909370234862, 1.4682401842934332, 1.477743691398205, 1.4871066915206714, 1.4963341255564686, 1.505430664032903, 1.514400726981276, 1.5232485019898763, 1.5319779606357817, 1.5405928734687346, 1.5490968236989806, 1.5574932197225675, 1.5657853066017355, 1.5739761766042673, 1.5820687788937517, 1.590065928452324, 1.5979703143083868, 1.6057845071339019, 1.6135109662688976, 1.6211520462247362, 1.6287100027123218, 1.6361869982366923, 1.6435851072952528, 1.6509063212131996, 1.6581525526463974, 1.665325639779047, 1.6724273502408749, 1.6794593847662536, 1.6864233806155937, 1.6933209147774753, 1.7001535069683378, 1.706922622445039, 1.7136296746442594, 1.7202760276615126, 1.726862998581429, 1.7333918596700018, 1.7398638404385867, 1.7462801295886412, 1.7526418768454628, 1.7589501946885127, 1.765206159985319, 1.7714108155353974, 1.7775651715301275, 1.7836702069340746, 1.7897268707928193, 1.7957360834719918, 1.8016987378318405, 1.8076157003413706, 1.8134878121357692, 1.8193158900205941, 1.8251007274259308, 1.8308430953135164, 1.836543743039609, 1.8422033991761968, 1.8478227722929599, 1.853402551702236, 1.8589434081690945], [0.0, 0.5011872336272722, 0.6170338627200096, 0.696845301935949, 0.7596577929323739, 0.8122523963562355, 0.8579172004440949, 0.8985234417906398, 0.9352484478226213, 0.9688861611972633, 1.0, 1.029005759421095, 1.0562199684392581, 1.0818897486445278, 1.1062121156199922, 1.1293469354568555, 1.1514259016263246, 1.172558924272542, 1.1928387845252129, 1.2123445941619542, 1.2311444133449163, 1.2492972627406829, 1.2668546920110242, 1.2838620180052702, 1.3003593134073366, 1.3163822043342375, 1.331962519898846, 1.3471288257976295, 1.3619068661200142, 1.3763199318508206, 1.3903891703159095, 1.404133846672126, 1.417571566167883, 1.4307184640917887, 1.443589368935865, 1.4561979432210856, 1.4685568055893563, 1.480677637101274, 1.4925712741514, 1.5042477899911528, 1.5157165665103982, 1.526986357654484, 1.538065345630288, 1.5489611908722425, 1.559681076589167, 1.570231748588672, 1.5806195509729188, 1.5908504582136447, 1.6009301040424737, 1.6108638075320787, 1.6206565966927626, 1.630313229865815, 1.6398382151582813, 1.6492358281324608, 1.6585101279366485, 1.6676649720406436, 1.6767040297197382, 1.6856307944138174, 1.6944485950733938, 1.7031606065915659, 1.7117698594097053, 1.7202792483749303, 1.7286915409188952, 1.7370093846199548, 1.7452353142041923, 1.7533717580350288, 1.761421044136025, 1.7693854057869887, 1.7772669867295035, 1.785067846014457, 1.7927899625209973, 1.800435239173547, 1.8080055068809924, 1.8155025282199488, 1.8229280008819848, 1.8302835609029084, 1.8375707856905994, 1.8447911968664354, 1.8519462629340446, 1.8590374017879512, 1.866065983073615, 1.8730333304094113, 1.8799407234802203, 1.8867894000115193, 1.8935805576321467, 1.9003153556332646, 1.9069949166304498, 1.9136203281353115, 1.9201926440425376, 1.9267128860378282, 1.933182044931763, 1.9396010819242742, 1.9459709298040593, 1.9522924940869437, 1.9585666540969289, 1.964794263993381, 1.970976153747587, 1.9771131300716667, 1.9832059773026391, 1.9892554582442343, 1.9952623149688797, 2.001227269582124], [0.0, 0.5357656669484113, 0.6596049077255497, 0.7449227811521515, 0.8120688971611996, 0.8682921624214404, 0.917107520388829, 0.9605153099684796, 0.9997740859911781, 1.0357325676355595, 1.068993044916333, 1.1, 1.1290918001633157, 1.1565326166672798, 1.182533057799954, 1.2072640193009534, 1.2308662805750588, 1.2534573348019247, 1.2751363643639049, 1.2959879392010434, 1.3160848151533144, 1.3354900849028026, 1.3542588546794079, 1.3724395678798817, 1.390075061924621, 1.4072034208849309, 1.423858669861099, 1.4400713453839722, 1.4558689677060945, 1.4712764347282485, 1.4863163527946979, 1.5010093162241194, 1.51537414490462, 1.5294280873475004, 1.5431869951075978, 1.5566654733248098, 1.5698770112395692, 1.582834095824412, 1.5955483111097557, 1.608030425331307, 1.6202904676640801, 1.6323377960147674, 1.6441811571056135, 1.6558287398877476, 1.667288223161438, 1.6785668181481024, 1.6896713066488274, 1.7006080753323476, 1.7113831466185856, 1.7220022065592346, 1.7324706300623378, 1.7427935037616389, 1.752975646792216, 1.7630216297004293, 1.7729357916875748, 1.7827222563620388, 1.7923849461535886, 1.801927595525164, 1.8113537631017098, 1.8206668428218666, 1.829870074206384, 1.8389665518266973, 1.8479592340479973, 1.8568509511131313, 1.8656444126266527, 1.874342214492169, 1.882946845350676, 1.8914606925627544, 1.8998860477732478, 1.908225112093234, 1.9164800009307594, 1.924652748498796, 1.93274531202621, 1.940759575695144, 1.9486973543260766, 1.9565603968299086, 1.964350389444692, 1.972068958773097, 1.979717674635288, 1.9872980527506503, 1.994811557260654, 2.0022596031041364, 2.0096435582553345, 2.016964745834175, 2.024224446097556, 2.0314238983196677, 2.038564302568753, 2.045646821387159, 2.0526725813809765, 2.0596426747251138, 2.0665581605891883, 2.0734200664892435, 2.080229389569909, 2.086987097821304, 2.0936941312346704, 2.1003514029004298, 2.1069598000521155, 2.113520185059373, 2.12003339637302, 2.1265002494249394, 2.132921537485394, 2.139298032480194], [0.0, 0.5694123367516262, 0.7010288172814387, 0.7917047464637367, 0.8630677119898374, 0.9228218597947636, 0.9747028756274828, 1.0208367218639414, 1.0625609919546675, 1.1007777055708823, 1.1361269771988889, 1.1690812029713358, 1.2000000000000002, 1.2291641297899731, 1.2567974270601296, 1.2830815199894259, 1.3081660290832213, 1.3321758262213441, 1.3552163225482268, 1.3773773990886347, 1.398736380828859, 1.4193603227404181, 1.4393077917847144, 1.458630273656793, 1.4773732960138999, 1.4955773346486674, 1.5132785514748908, 1.5305094007509494, 1.5472991310313435, 1.5636742038322535, 1.5796586452010852, 1.5952743428022507, 1.6105412984334115, 1.625477843831241, 1.6401008260455558, 1.6544257674350114, 1.6684670043790917, 1.6822378080458638, 1.695750489955524, 1.7090164946007576, 1.7220464809997373, 1.7348503947459304, 1.7474375318653033, 1.759816595584072, 1.771995746939559, 1.7839826500257736, 1.7957845125483274, 1.8074081222657354, 1.8188598798124784, 1.8301458283305132, 1.8412716802779872, 1.8522428417348056, 1.8630644344829994, 1.8737413161042389, 1.884278098306407, 1.894679163665006, 1.904948680942682, 1.915090619130732, 1.925108760339639, 1.9350067116511018, 1.9447879160313155, 1.9544556623941862, 1.9640130948934738, 1.9734632215143715, 1.982808922027562, 1.9920529553622388, 2.001197966448773, 2.010246492576601, 2.0192009693083683, 2.0280637359873364, 2.03683704087149, 2.0455230459246003, 2.0541238312916468, 2.062641399483471, 2.071077679293263, 2.07943452946544, 2.087713742135648, 2.0959170460589838, 2.104046109642035, 2.1121025437930214, 2.1200879046030994, 2.128003695870812, 2.135851371480675, 2.1436323376459927, 2.151347955025197, 2.1589995407202522, 2.166588370165, 2.1741156789107174, 2.1815826643155902, 2.188990487144305, 2.1963402730834902, 2.20363311417832, 2.210870070195197, 2.218052169915079, 2.2251804123616856, 2.2322557679685158, 2.2392791796883382, 2.2462515640485563, 2.2531738121556155, 2.2600467906514123, 2.2668713426244507, 2.2736482884783245], [0.0, 0.6022271719754774, 0.741428618342117, 0.8373301379846805, 0.9128057013659376, 0.9760034389696841, 1.0308743215051672, 1.0796668290750424, 1.123795639706062, 1.1642147558330256, 1.2016011812929526, 1.2364545360776396, 1.2691551617818178, 1.3, 1.3292257848895588, 1.3570246117345335, 1.3835547235654946, 1.4089481885414803, 1.4333164925775455, 1.4567546964791294, 1.4793445814174706, 1.5011570666952567, 1.5222540944469662, 1.5426901174522867, 1.5625132870955483, 1.5817664117610406, 1.6004877373483912, 1.6187115884322196, 1.636468899140792, 1.653787655948982, 1.670693269508525, 1.6872088888546442, 1.703355668474629, 1.719152996550332, 1.7346186910152832, 1.7497691687708243, 1.7646195923919754, 1.7791839978549486, 1.7934754061842495, 1.8075059214106826, 1.8212868168241927, 1.834828611175851, 1.8481411362151074, 1.8612335967290252, 1.8741146240698072, 1.8867923240078468, 1.8992743196237956, 1.9115677898499503, 1.923679504184886, 1.9356158540326092, 1.9473828810562397, 1.9589863028842922, 1.9704315364635177, 1.9817237193146258, 1.9928677289150027, 2.003868200404916, 2.0147295427898912, 2.025455953791421, 2.036051433480374, 2.0465197968120474, 2.056864685168373, 2.067089577001069, 2.077197797659279, 2.0871925284762822, 2.097076815181935, 2.1068535757005917, 2.1165256073881134, 2.1260955937561556, 2.1355661107271375, 2.144939632459038, 2.1542185367753786, 2.1634051102323935, 2.172501552852364, 2.1815099825494326, 2.1904324392717935, 2.1992708888820065, 2.2080272267952434, 2.2167032813935488, 2.225300817232617, 2.2338215380561834, 2.242267089631851, 2.2506390624210217, 2.2589389940945606, 2.2671683719048628, 2.2753286349241555, 2.283421176158068, 2.2914473445428043, 2.299408446833598, 2.3073057493915514, 2.3151404798754083, 2.322913828844332, 2.3306269512772966, 2.338280968014303, 2.3458769671242363, 2.3534160052038553, 2.360899108612064, 2.3683272746433404, 2.3757014726439216, 2.383022645074096, 2.3902917085197255, 2.397509554655917, 2.40467705116555], [0.0, 0.6342925711719626, 0.7809057554245444, 0.88191352176933, 0.9614077581398196, 1.0279704397030547, 1.085762905379651, 1.13715335489873, 1.1836317903802993, 1.2262030098232404, 1.265580063924133, 1.3022891747864505, 1.336730935175302, 1.3692180972484058, 1.4000000000000001, 1.4292789667680108, 1.4572216661841464, 1.4839671983356564, 1.509632985170604, 1.5343191489775632, 1.5581118253408985, 1.5810857096395978, 1.6033060420979, 1.6248301748168763, 1.6457088229863988, 1.6659870743099154, 1.685705211078131, 1.7048993854670063, 1.7236021786828832, 1.74184306733182, 1.7596488150478309, 1.777043803429348, 1.7940503133277828, 1.8106887652427235, 1.826977925818051, 1.8429350860679325, 1.8585762158939982, 1.8739160986136645, 1.8889684485518534, 1.903746014214739, 1.9182606691350972, 1.932523492131641, 1.9465448384422737, 1.9603344029600938, 1.9739012766109787, 1.9872539967545548, 2.000400592360041, 2.013348624599761, 2.026105223412143, 2.0386771205095204, 2.0510706792414943, 2.0632919216699377, 2.0753465531652537, 2.0872399847938503, 2.0989773537328857, 2.1105635419192352, 2.1220031931145575, 2.1333007285467263, 2.144460361269143, 2.155486109363219, 2.166381808095139, 2.177151121125704, 2.1877975508612435, 2.1983244480241413, 2.208735020513196, 2.219032341616741, 2.2292193576349835, 2.2392988949623254, 2.2492736666753763, 2.259146278667891, 2.268919235369868, 2.278594945084519, 2.2881757249736308, 2.297663805719028, 2.3070613358853143, 2.316370386006793, 2.325592952419428, 2.334730960856901, 2.3437862698281275, 2.3527606737921496, 2.361655906144956, 2.3704736420315746, 2.379215500995678, 2.387883049477955, 2.3964778031735876, 2.4050012292583585, 2.4134547484921614, 2.421839737208008, 2.430157529194005, 2.4384094174752056, 2.4465966560017267, 2.4547204612490403, 2.462782013735926, 2.4707824594651595, 2.4787229112916664, 2.4866044502225133, 2.4944281266528128, 2.502194961541343, 2.5099059475293966, 2.517562050006169, 2.5251642081237287, 2.5327133357644627], [0.0, 0.6656775051475124, 0.8195451415517417, 0.9255507940800144, 1.0089784225053955, 1.0788346399872963, 1.1394866893985607, 1.19341994950448, 1.2421981480530842, 1.2868758006661423, 1.328201239943334, 1.3667267255719306, 1.402872671733932, 1.4369673056316439, 1.4692723036068125, 1.5, 1.5293253102429558, 1.5573942171254123, 1.5843299526588872, 1.6102375932045057, 1.6352075363540264, 1.6593181734299882, 1.6826379727570728, 1.705227124230751, 1.727138852439487, 1.7484204760360735, 1.7691142704876952, 1.789258176787819, 1.8088863882679431, 1.8280298400429849, 1.8467166200173744, 1.8649723161963212, 1.8828203118925961, 1.9002820380165362, 1.917377189789631, 1.9341239137891788, 1.9505389701110047, 1.9666378735542782, 1.9824350170316913, 1.997943779848269, 2.013176623041764, 2.028145173613241, 2.0428602991800213, 2.057332174340616, 2.071570339841886, 2.0855837554738637, 2.099380847480907, 2.112969551163784, 2.1263573492518244, 2.139551306543947, 2.1525581012496713, 2.1653840534037974, 2.178035150679693, 2.1905170718845057, 2.2028352083840343, 2.2149946836744485, 2.227000371291741, 2.2388569112270993, 2.250568724996722, 2.2621400294975587, 2.273574849765597, 2.284877030740369, 2.2960502481280294, 2.3070980184454317, 2.3180237083189024, 2.3288305431037486, 2.3395216148837505, 2.350099889903918, 2.3605682154844794, 2.370929326459378, 2.381185851178352, 2.391340317107978, 2.4013951560637103, 2.411352709101994, 2.4212152310988753, 2.4309848950391437, 2.4406637960379007, 2.450253955114547, 2.459757322737422, 2.4691757821557907, 2.4785111525344523, 2.487765191904973, 2.4969395999463972, 2.5060360206072394, 2.515056044579607, 2.52400121163546, 2.5328730128341985, 2.5416728926100904, 2.5504022507473674, 2.559062444250243, 2.567654789114558, 2.576180562007253, 2.5846410018594344, 2.593037311378343, 2.601370658483208, 2.609642177669559, 2.6178529713062884, 2.626004110869434, 2.634096638116397, 2.6421315662040374, 2.650109880753873, 2.6580325408673895], [0.0, 0.6964404506368993, 0.8574187700290345, 0.9683232603354766, 1.0556063286183155, 1.128690810528371, 1.1921457722739568, 1.2485714493954332, 1.299603834169977, 1.3463461745354395, 1.3895813857757495, 1.429887249147593, 1.4677036074278427, 1.5033738561780403, 1.5371717645851524, 1.5693194795937333, 1.6, 1.6293660548943611, 1.657546571207606, 1.6846514811933069, 1.710775359985901, 1.7360002216050487, 1.7603976985011893, 1.7840307621246136, 1.8069550967309689, 1.8292202077093056, 1.8508703242023978, 1.8719451405703282, 1.8924804303205576, 1.9125085581720485, 1.9320589100551762, 1.9511582564732868, 1.9698310613518664, 1.9880997459876197, 2.005984915777039, 2.0235055559049524, 2.0406792010012658, 2.0575220828503507, 2.0740492595043785, 2.0902747285660146, 2.1062115269347803, 2.121871818930182, 2.137266974394593, 2.152407638125106, 2.1673037917749878, 2.1819648091929253, 2.1963995060251915, 2.2106161842865024, 2.2246226725054554, 2.238426361966426, 2.252034239498939, 2.265452917205477, 2.2786886594676763, 2.2917474075273208, 2.3046348019013236, 2.317356202857914, 2.3299167091537374, 2.3423211752078297, 2.3545742268678587, 2.3666802759061745, 2.3786435333676983, 2.3904680218781005, 2.4021575870088943, 2.413715907785679, 2.4251465064166373, 2.4364527573103776, 2.447637895445105, 2.4587050241448707, 2.469657122313074, 2.480497051168501, 2.4912275605247816, 2.5018512946502702, 2.512370797741876, 2.5227885190432535, 2.533106817635005, 2.5433279669220368, 2.553454158840976, 2.563487507808565, 2.5734300544301103, 2.58328376898545, 2.5930505547084204, 2.6027322508744772, 2.6123306357099096, 2.621847429135002, 2.631284295352495, 2.6406428452918083, 2.6499246389186504, 2.6591311874189105, 2.66826395526503, 2.677324362172439, 2.6863137849530765, 2.695233559272476, 2.7040849813164485, 2.7128693093729295, 2.7215877653341836, 2.7302415361241663, 2.7388317750555284, 2.747359603120416, 2.7558261102189507, 2.7642323563289968, 2.772579372620586, 2.7808681625181473], [0.0, 0.7266315402400411, 0.8945883613267384, 1.0103006243597221, 1.1013674632907975, 1.1776201990550452, 1.2438259694793528, 1.302697731793518, 1.3559423994703272, 1.4047110468731592, 1.4498205291087471, 1.4918736745798402, 1.5313293934978294, 1.5685459678171387, 1.6038090347746836, 1.6373503715114004, 1.6693609099253943, 1.7000000000000002, 1.7294021577217789, 1.7576820809700138, 1.7849384447650047, 1.8112568184808064, 1.836711939875322, 1.8613695102470247, 1.8852876277957118, 1.908517943997203, 1.9311066053527652, 1.9530950269955645, 1.9745205332349547, 1.9954168918188715, 2.0158147625744838, 2.0357420765216823, 2.0552243581110354, 2.074285000615211, 2.092945502686358, 2.1112256725278638, 2.1291438049058122, 2.1467168352616586, 2.1639604744226997, 2.180889326795637, 2.197516994436999, 2.2138561689964624, 2.229918713205532, 2.24571573331931, 2.2612576437014065, 2.2765542245621817, 2.2916146737111873, 2.306447653060199, 2.321061330508981, 2.335463417758289, 2.3496612045206824, 2.3636615895370463, 2.377471108753523, 2.3910959609681073, 2.4045420312173276, 2.41781491214009, 2.430919923527039, 2.4438621302390384, 2.456646358656881, 2.4692772118057587, 2.4817590832817844, 2.4940961700937394, 2.506292484520848, 2.518351865076562, 2.5302779866587928, 2.5420743699586796, 2.5537443901925734, 2.565291285215387, 2.576718163067677, 2.5880280090036916, 2.599223692043043, 2.6103079710846258, 2.621283500617729, 2.6321528360621143, 2.6429184387658697, 2.6535826806872964, 2.664147848784721, 2.6746161491360545, 2.6849897108080034, 2.695270589493158, 2.705460770931623, 2.7155621741324913, 2.725576654409174, 2.7355060062414767, 2.7453519659762753, 2.7551162143776966, 2.76480037903685, 2.7744060366503915, 2.783934715176476, 2.7933878958760054, 2.8027670152464985, 2.8120734668553498, 2.8213086030787617, 2.830473736752168, 2.839570142737558, 2.8485990594127153, 2.8575616900870497, 2.866459204348355, 2.8752927393445424, 2.884063401004119, 2.892772265198925, 2.901420378852408], [0.0, 0.756294171712541, 0.9311073443492157, 1.051543225922158, 1.1463276052199582, 1.2256931384262184, 1.2946015679847558, 1.3558765997593754, 1.4112948270296082, 1.4620543134412238, 1.509005259848636, 1.5527751033809727, 1.5938414879320009, 1.6325773212809114, 1.669279900978856, 1.704190465798333, 1.7375077418800822, 1.7693975842097245, 1.8, 1.829434369339449, 1.857803395370742, 1.885196140590194, 1.9116903937085594, 1.9373545380898372, 1.9622490436248319, 1.9864276703115065, 2.0099384484486023, 2.0328244838223397, 2.0551246243990735, 2.0768740163974044, 2.0981045712432884, 2.1188453601597366, 2.139122949559204, 2.158961687677071, 2.1783839507857934, 2.197410355701384, 2.2160599440208495, 2.2343503425260725, 2.252297903393443, 2.2699178272123364, 2.287224271303906, 2.304230445417727, 2.320948696547015, 2.337390584327621, 2.3535669482594366, 2.369487967801627, 2.385163216237724, 2.400601709077003, 2.415811947650117, 2.430801958465708, 2.4455793288177685, 2.4601512390683333, 2.474524491974646, 2.4887055393827047, 2.502700506568637, 2.51651521447466, 2.530155200056489, 2.5436257349332854, 2.556931842508883, 2.5700783137136667, 2.5830697214996055, 2.5959104342062282, 2.6086046279024564, 2.6211562977979543, 2.6335692688077135, 2.6458472053449085, 2.6579936204093384, 2.6700118840319793, 2.6819052311301568, 2.6936767688224905, 2.705329483248024, 2.7168662459297197, 2.728289819718717, 2.7396028643523995, 2.7508079416562743, 2.7619075204169805, 2.7729039809513054, 2.783799619393912, 2.7945966517244987, 2.8052972175533606, 2.815903383682701, 2.82641714745961, 2.836840439935303, 2.847175128844035, 2.857423021414023, 2.867585867021728, 2.87766535969996, 2.887663140509458, 2.8975807997828493, 2.9074198792492285, 2.917181874046973, 2.926868234631835, 2.9364803685868663, 2.9460196423402105, 2.95548738279641, 2.964884878886442, 2.974213383041343, 2.9834741125939455, 2.992668251112937, 3.0017969496731585, 3.0108613280658054, 3.0198624759519492], [0.0, 0.7854662349940811, 0.967022367084028, 1.0921037467845816, 1.1905441848150782, 1.272971035222585, 1.3445374266468886, 1.4081759819965476, 1.4657318219753608, 1.5184492223907102, 1.5672111783641802, 1.6126693287658624, 1.655319741349467, 1.6955497078333173, 1.7336679932415409, 1.7699251414993142, 1.804527544086831, 1.8376474534106062, 1.8694302770942552, 1.9000000000000001, 1.9294632867747636, 1.9579126352669705, 1.9854288346827877, 2.012082906095054, 2.0379376518619483, 2.0630489056322974, 2.0874665503475933, 2.1112353544866576, 2.1343956644742152, 2.156983982202033, 2.1790334499955915, 2.2005742604240517, 2.221634004629524, 2.2422379700166823, 2.26240939596398, 2.2821696945270133, 2.3015386417824315, 2.3205345444189778, 2.3391743853553413, 2.3574739515037484, 2.3754479462668705, 2.3931100889257113, 2.4104732027263536, 2.427549293187271, 2.444349617913622, 2.4608847490105, 2.4771646290257294, 2.4931986212182022, 2.508995554835095, 2.524563765986559, 2.5399111346265464, 2.5550451180807165, 2.5699727815048243, 2.5847008256078987, 2.599235611932522, 2.613583185948485, 2.6277492981850403, 2.641739423600228, 2.655558779362503, 2.66921234119982, 2.6827048584537714, 2.6960408679611207, 2.709224706871692, 2.722260524499879, 2.7351522932967325, 2.747903819020552, 2.7605187501758843, 2.7730005867838097, 2.785352688540101, 2.797578282412326, 2.809680469722007, 2.821662232753569, 2.833526440927887, 2.8452758565747343, 2.856913140335315, 2.868440856223235, 2.879861476369757, 2.8911773854769125, 2.902390885000004, 2.913504197079179, 2.924519468238113, 2.9354387728663185, 2.9462641165002457, 2.9569974389170977, 2.9676406170541783, 2.9781954677655547, 2.988663750426909, 2.9990471693985907, 3.0093473763561365, 3.019565972496795, 3.029704510629984, 3.0397644971589806, 3.049747393960659, 3.0596546201695434, 3.0694875538720376, 3.079247533716249, 3.0889358604424553, 3.0985537983389095, 3.108102576627355, 3.1175833907823236, 3.12699740378802, 3.1363457473363314], [0.0, 0.8141810630738087, 1.0023744672545445, 1.132028532774118, 1.2340677254400192, 1.3195079107728942, 1.3936906038718977, 1.4596556375533993, 1.5193155858647476, 1.573960212457742, 1.624504792712471, 1.6716247879083048, 1.7158344008881896, 1.757535081859526, 1.7970468835812794, 1.8346295092848033, 1.8704968956452424, 1.9048275922185238, 1.9377723223945267, 1.9694596036351502, 2.0, 2.02948939084481, 2.05801151884219, 2.085640001431066, 2.1124399368785163, 2.138469199982376, 2.163779497289055, 2.1884172339093726, 2.2124242312399844, 2.2358383255973595, 2.258693870913711, 2.2810221635286667, 2.3028518032526493, 2.324209001939336, 2.345117848545084, 2.365600537900696, 2.3856775690504257, 2.405367917933196, 2.4246891883239083, 2.44365774426777, 2.4622888266898326, 2.4805966564162687, 2.4985945254813657, 2.5162948782975745, 2.5337093840220484, 2.5508490012515814, 2.5677240360105404, 2.584344193856896, 2.600718626814673, 2.6168559757429213, 2.632764408668475, 2.6484516555395645, 2.663925039797692, 2.6791915071143038, 2.694257651595259, 2.709129739718734, 2.723813732240028, 2.7383153042689763, 2.752639863701641, 2.766792568167078, 2.780778340631819, 2.7946018837888813, 2.8082676933442516, 2.8217800703016565, 2.8351431323357654, 2.8483608243345953, 2.8614369281835774, 2.874375071856463, 2.88717873787173, 2.8998512711674125, 2.9123958864421713, 2.924815675005851, 2.9371136111787126, 2.949292558274915, 2.961355274202548, 2.9733044167096225, 2.9851425483027993, 2.9968721408633, 3.008495579982305, 3.020015169036266, 3.0314331330207964, 3.04275162216029, 3.053972715308968, 3.0650984231578007, 3.0761306912605755, 3.087071402891342, 3.0979223817444845, 3.108685394487825, 3.119362153178334, 3.1299543175493287, 3.140463497177344, 3.1508912535362774, 3.1612391019458377, 3.1715085134208234, 3.1817009164272894, 3.1918176985512194, 3.201860208084947, 3.2118297555361774, 3.221727615064157, 3.2315550258472014, 3.241313193385525, 3.251003290743052], [0.0, 0.8424681795174462, 1.0371999926337658, 1.1713586331368167, 1.2769429764524494, 1.3653516126386915, 1.4421116372097291, 1.5103684959822152, 1.572101211619462, 1.628644358069476, 1.6809450101515975, 1.729702096716145, 1.7754476855704486, 1.818597174518185, 1.859481735920668, 1.8983700958861995, 1.9354836238980746, 1.9710070728646545, 2.005096402762953, 2.0378845961408003, 2.069486058388153, 2.1, 2.12951307312307, 2.1581014528891194, 2.1858324992762195, 2.212766097827997, 2.238955751532913, 2.264449477755906, 2.2892905508956374, 2.3135181218168235, 2.3371677380113476, 2.3602717831484785, 2.382859850682688, 2.40495906314685, 2.426594346420636, 2.4477886664505033, 2.468563234479598, 2.488937685728444, 2.5089302355804075, 2.5285578166171963, 2.547836199279766, 2.5667800984688673, 2.585403268024325, 2.603718584715172, 2.621738123120432, 2.639473222571746, 2.6569345471559864, 2.6741321396316082, 2.691075469991674, 2.707773479304851, 2.724234619379969, 2.740466888727076, 2.7564778652262145, 2.7722747358624975, 2.787864323840997, 2.803253113356323, 2.81844727225847, 2.8334526728277796, 2.8482749108470062, 2.8629193231368606, 2.8773910037026456, 2.8916948186231797, 2.905835419798893, 2.91981725766341, 2.9336445929518926, 2.9473215076097157, 2.960851914916468, 2.974239568892698, 2.987488073050124, 3.0006008885400615, 3.01358134174954, 3.0264326313898717, 3.039157835118214, 3.051759915728933, 3.0642417269481994, 3.0766060188622415, 3.0888554430069637, 3.100992557144228, 3.1130198297478806, 3.124939644220647, 3.1367543028612284, 3.1484660305993284, 3.1600769785148604, 3.1715892271562898, 3.1830047896718363, 3.1943256147661945, 3.2055535894944165, 3.2166905419037146, 3.227738243533106, 3.238698411780071, 3.249572712142708, 3.2603627603452483, 3.271070124354198, 3.2816963262918653, 3.2922428442535425, 3.3027111140341545, 3.313102530769794, 3.323418450499174, 3.3336601916496935, 3.343829036452475, 3.3539262322904633, 3.3639529929833767], [0.0, 0.8703538937284877, 1.0715313338968226, 1.2101306281823734, 1.3192098154510994, 1.410544779328305, 1.489845562304303, 1.5603617245174997, 1.624137794322399, 1.6825525200923601, 1.7365843248428807, 1.786955271983718, 1.8342150407776578, 1.8787927787042913, 1.921030619936959, 1.9612061854237197, 1.9995481719823562, 2.036247447846327, 2.071465135271119, 2.1053386185296534, 2.137986089832666, 2.1695100435445878, 2.2, 2.2295346557291005, 2.2581836003266313, 2.2860087015489547, 2.3130652333345596, 2.339402802424159, 2.3650661155999084, 2.390095619620957, 2.414528038601907, 2.438396828112151, 2.461732561150118, 2.4845632580050823, 2.5069146696038493, 2.5288105220661805, 2.5502727287278097, 2.571321574735468, 2.591975878402087, 2.6122531327781817, 2.6321696303066293, 2.651740572951702, 2.6709801698056057, 2.6899017238586977, 2.708517709358816, 2.726839840969715, 2.7448791357597635, 2.7626459689029295, 2.780150123849242, 2.797400837616927, 2.814406841769862, 2.8311763995689425, 2.8477173397221986, 2.8640370871040988, 2.8801426907679444, 2.8960408495353227, 2.911737935412189, 2.927240015051488, 2.9425528694564975, 2.9576820120968055, 2.9726327055893957, 2.9874099770803966, 3.0020186324482387, 3.016463269435992, 3.03074828980924, 3.0448779106258352, 3.0588561746950007, 3.072686960295444, 3.0863739902151957, 3.099920840169751, 3.1133309466496195, 3.1266076142435244, 3.1397540224791385, 3.1527732322193827, 3.165668191648824, 3.178441741881601, 3.1910966222195114, 3.2036354750863887, 3.216060850662614, 3.2283752112415924, 3.2405809353281603, 3.2526803214972397, 3.264675592029535, 3.2765688963397084, 3.288362314211227, 3.3000578588509515, 3.311657479775495, 3.323163065540472, 3.334576446322876, 3.34589939636608, 3.357133636296205, 3.3682808353179867, 3.379342613297655, 3.390320542739799, 3.401216150664695, 3.4120309203921106, 3.422766293237171, 3.4334236701234997, 3.444004413118469, 3.454509846895079, 3.464941260124675, 3.4752999068044343], [0.0, 0.897861780453415, 1.1053975149611417, 1.248377295982989, 1.3609039750697631, 1.455125617410136, 1.5369327336960898, 1.609677587728114, 1.675469326006028, 1.7357302728030064, 1.791469774589561, 1.8434327158814692, 1.892186148776871, 1.938172784134969, 1.9817455694179889, 2.023190899896304, 2.0627447004430937, 2.100603871759509, 2.136934628435069, 2.171878696828189, 2.2055580046622145, 2.2380782856774064, 2.269531889534717, 2.3000000000000003, 2.3295544060752773, 2.3582589308723656, 2.3861705952849293, 2.413340573894779, 2.4398149864599974, 2.4656355580759093, 2.490840173537609, 2.5154633457912867, 2.539536614107348, 2.5630888843676396, 2.5861467213674207, 2.6087346011000605, 2.63087512948113, 2.652589232777623, 2.673896324062862, 2.694814449262296, 2.715360415748046, 2.7355499059486132, 2.755397578040307, 2.774917155459874, 2.794121506708799, 2.8130227166975206, 2.831632150693308, 2.8499605117816977, 2.8680178926226128, 2.885813822173975, 2.9033573079642685, 2.9206568744180905, 2.9377205976729543, 2.9545561372694875, 2.9711707650491714, 2.9875713915525584, 3.003764590175428, 3.019756619309744, 3.0355534426697313, 3.051160747980412, 3.066583964185909, 3.0818282773173356, 3.096898645144854, 3.111799810725062, 3.126536314943126, 3.1411125081387152, 3.1555325608956735, 3.169800474067275, 3.1839200881017717, 3.197895091726592, 3.2117290300439185, 3.2254253120853362, 3.238987217868776, 3.2524179049969697, 3.2657204148330483, 3.278897678285712, 3.2919525212335006, 3.3048876696151193, 3.3177057542104325, 3.3304093151346237, 3.3430008060661365, 3.3554825982272827, 3.3678569841348462, 3.3801261811366095, 3.392292334748437, 3.4043575218054056, 3.4163237534393907, 3.428192977894568, 3.439967083191418, 3.4516478996489903, 3.4632372022744917, 3.474736713028548, 3.4861481029739165, 3.497472994314829, 3.5087129623336555, 3.519869537231085, 3.5309442058755893, 3.54193841346755, 3.5528535651230286, 3.5636910273818523, 3.5744521296443446, 3.5851381655407697], [0.0, 0.9250130700826241, 1.1388246735032521, 1.286128155043552, 1.4020576345628775, 1.4991285340564293, 1.5834094929274733, 1.6583541472448604, 1.7261354239796747, 1.7882186584109354, 1.8456437195895272, 1.899178017296996, 1.9494057512549654, 1.996783019874065, 2.0416734437278827, 2.0843720786636246, 2.125121983909335, 2.164126014432269, 2.2015554111417646, 2.237556186193325, 2.2722539543977778, 2.305757646877729, 2.3381624059426716, 2.3695518703509637, 2.4000000000000004, 2.429572548008903, 2.458328259579946, 2.4863198568114093, 2.5135948541202593, 2.540196238366353, 2.5661630399788518, 2.5915308155734937, 2.616332058166443, 2.6405965477517843, 2.6643516524426882, 2.687622588385184, 2.710432645096454, 2.7328033816526274, 2.7547547981772698, 2.776305486303597, 2.797472761657718, 2.818272780903886, 2.8387206454808362, 2.8588304938212694, 2.8786155835694287, 2.898088365082764, 2.917260547313586, 2.936143157008135, 2.9547465920278, 2.973080669485654, 2.9911546692973348, 3.0089773736655587, 3.026557102949782, 3.0439017483147093, 3.061018801501899, 3.077915382026258, 3.0945982620626866, 3.1110738892565677, 3.127348407664507, 3.143427677008013, 3.1593172904021705, 3.1750225907033824, 3.1905486856045013, 3.205900461591889, 3.2210825968668226, 3.236099573322999, 3.250955687662482, 3.265655061724123, 3.2802016520911117, 3.2945992590377875, 3.3088515348700227, 3.3229619917083255, 3.3369340087581834, 3.350770839108057, 3.3644756160917275, 3.378051359248409, 3.391500979911048, 3.4048272864505837, 3.4180329892015147, 3.4311207050919648, 3.4440929619994747, 3.4569522028519857, 3.469700789491861, 3.482341006319353, 3.4948750637306065, 3.5073051013640737, 3.5196331911681438, 3.5318613403017878, 3.543991493879118, 3.55602553756793, 3.5679653000515477, 3.579812555362589, 3.5915690250966548, 3.603236380513342, 3.614816244531471, 3.6263101936249114, 3.6377197596249564, 3.6490464314347637, 3.6602916566610264, 3.671456843167658, 3.682543360555974, 3.6935525415755444], [0.0, 0.9518269693579392, 1.1718364557960497, 1.3234099102098917, 1.4426999059072136, 1.542584656800024, 1.6293087175202055, 1.7064258367216945, 1.7761719292909024, 1.8400548070445832, 1.8991444823309347, 1.9542306102913258, 2.005914325189171, 2.0546649466286566, 2.100856635667338, 2.144793001110237, 2.1867241478865562, 2.2268588112400947, 2.2653731959413967, 2.3024175466864114, 2.338121119556553, 2.372596003325108, 2.4059400982477923, 2.4382394675689683, 2.4695702151051857, 2.5, 2.5295892703375014, 2.558392276502519, 2.58645791024044, 2.613830404496574, 2.640549921098146, 2.666653047361479, 2.6921732181969564, 2.71714107684891, 2.741584784766144, 2.7655302890499804, 2.789001554324569, 2.8120207646116904, 2.834608499790284, 2.8567838904202003, 2.878564754065812, 2.8999677157341246, 2.9210083146181836, 2.941701098989773, 2.962059710800289, 2.982096961313032, 3.0018248988946183, 3.0212548699300825, 3.040397573689753, 3.059263111861148, 3.077861033362291, 3.0962003749707874, 3.114289698233258, 3.132137123060253, 3.149750358360859, 3.167136730027561, 3.1843032065442842, 3.2012564224581115, 3.21800269992704, 3.23454806853178, 3.2508982835183415, 3.2670588426196563, 3.283035001588281, 3.2988317885580396, 3.314454017339987, 3.3299062997471154, 3.3451930570325255, 3.3603185305172416, 3.375286791476263, 3.3901017503447224, 3.404767165300035, 3.4192866502706183, 3.4336636824169813, 3.447901609126778, 3.462003654561583, 3.475972925789774, 3.4898124185368222, 3.503525022581572, 3.5171135268245854, 3.5305806240524245, 3.5439289154197073, 3.557160914668968, 3.570279052106686, 3.5832856783523717, 3.596183067876226, 3.608973422339662, 3.62165887375186, 3.6342414874544895, 3.646723264945834, 3.6591061465546524, 3.6713920139733904, 3.6835826926595967, 3.695679954113778, 3.707685518041318, 3.7196010544055427, 3.7314281853784994, 3.743168487195578, 3.7548234919196495, 3.766394689120036, 3.7778835274712326, 3.7892914162759954, 3.8006197269170925], [0.0, 0.9783209271758403, 1.2044543439509545, 1.3602468222387079, 1.482857236684234, 1.5855222643101052, 1.6746602759693607, 1.7539239383650822, 1.8256114027318748, 1.8912724505973293, 1.952006877939368, 2.0086263198292, 2.061748643010334, 2.1118562305262123, 2.1593336581500844, 2.2044929855915294, 2.247591279412124, 2.2888430849691885, 2.328429511666051, 2.3665049862367464, 2.4032023625859047, 2.4386368494606385, 2.472909072155279, 2.5061074894714044, 2.538310323563635, 2.5695871168574183, 2.5999999999999996, 2.6296047334273576, 2.658451569779118, 2.686585973217844, 2.7140492234690665, 2.740878926251452, 2.7671094471309896, 2.7927722823020202, 2.81789637708296, 2.8425084008087205, 2.866632985155091, 2.890292931632698, 2.9135093929582587, 2.9363020321878244, 2.9586891628349408, 2.9806878726611363, 3.0023141333905135, 3.0235828982437716, 3.0445081888939325, 3.0651031732038483, 3.085380234904573, 3.1053510362060295, 3.1250265741910965, 3.144417231726216, 3.163532823522081, 3.1823826378936166, 3.2009754746967825, 3.219319679858593, 3.2374231768644393, 3.2552934955219, 3.2729377982815833, 3.2903629043621723, 3.307575311897964, 3.324581218302123, 3.3413865390170496, 3.35799692480423, 3.374417777709288, 3.3906542658233807, 3.4067113369492574, 3.4225937312690173, 3.4383059931006636, 3.4538524818217415, 3.4692373820305664, 3.4844647130086326, 3.4995383375416487, 3.514461970151175, 3.5292391847839504, 3.543873422001652, 3.558367995709897, 3.5727260994618355, 3.5869508123684986, 3.6010451046452805, 3.6150118428213642, 3.628853794636613, 3.642573633648385, 3.656173943568852, 3.6696572223517014, 3.6830258860455793, 3.696282272430214, 3.7094286444499285, 3.7224671934580496, 3.7354000422847182, 3.748229248139614, 3.7609568053602502, 3.7735846480156936, 3.7861146523748226, 3.7985486392475907, 3.8108883762071173, 3.8231355796999003, 3.835291917050898, 3.847359008369771, 3.8593384283641257, 3.871231708065218, 3.8830403364711747, 3.894765762112479, 3.9064093945441276], [0.0, 1.0045108566305139, 1.2366979292849734, 1.3966610165238238, 1.5225537466344214, 1.62796714624774, 1.7194914078299375, 1.800876981010554, 1.874483539186339, 1.941902351977134, 2.0042626572119717, 2.0623978176637467, 2.1169422405444123, 2.1683912224286734, 2.2171396342926024, 2.263507889772954, 2.3077599371762676, 2.3501160653000963, 2.3907622318980017, 2.4298569977516076, 2.467536773302356, 2.5039198514682837, 2.539109551311469, 2.5731966997007674, 2.6062616128201235, 2.6383756947654917, 2.669602739439215, 2.7, 2.729619074364929, 2.7585066437851253, 2.7867050930561135, 2.8142530346123427, 2.8411857539957777, 2.8675355905628392, 2.89333226450635, 2.918603159106901, 2.9433735654372484, 2.967666895410943, 2.991504868008943, 3.014907672672904, 3.037894113174337, 3.0604817347190063, 3.0826869365986105, 3.1045250723358206, 3.126010538967833, 3.1471568568649326, 3.1679767412741757, 3.1884821666061622, 3.2086844243388066, 3.228594175290838, 3.2482214969155474, 3.2675759261786905, 3.286666498510874, 3.3055017832619527, 3.3240899160312742, 3.3424386282015086, 3.360555273964103, 3.3784468550901643, 3.3961200436708925, 3.4135812030259656, 3.430836406955859, 3.4478914574945514, 3.464751901301963, 3.4814230448205223, 3.4979099683070647, 3.514217538839713, 3.530350422389155, 3.5463130950347126, 3.5621098533975886, 3.577744824356586, 3.593221974105285, 3.608545116604045, 3.623717921475176, 3.6387439213851676, 3.6536265189538346, 3.668368993226653, 3.6829745057433314, 3.6974461062327757, 3.7117867379619693, 3.725999242763959, 3.740086365767994, 3.7540507598529556, 3.767894989843463, 3.7816215364664694, 3.7952328000847335, 3.80873110422224, 3.822118698895468, 3.8353977637633245, 3.8485704111075782, 3.8616386886547245, 3.8746045822494084, 3.887470018388761, 3.900236866626335, 3.9129069418536853, 3.9254820064670715, 3.9379637724262144, 3.95035390321157, 3.9626540156861174, 3.9748656818672528, 3.9869904306140076, 3.999029749234437, 4.010985085017726], [0.0, 1.0304113218507693, 1.2685851423439252, 1.4326727428722108, 1.5618115108490889, 1.6699429060643585, 1.7638270435386598, 1.847311075082052, 1.9228155162796388, 1.991972666296311, 2.0559408794061094, 2.1155750059381577, 2.1715258107593014, 2.2243013612486853, 2.2743067097974596, 2.321870531637762, 2.367263580760598, 2.4107118259243716, 2.4524060196464808, 2.492508811064571, 2.531160127848266, 2.568481312998725, 2.604578349572901, 2.6395444063338576, 2.673461870350604, 2.706403986813485, 2.738436194496811, 2.769617222783698, 2.8000000000000003, 2.8296324110335327, 2.8585579335360216, 2.886816175530974, 2.914443332368293, 2.9414725772474304, 2.9679343966713128, 2.9938568799753265, 3.019265970341208, 3.044185683338953, 3.0686382979551263, 3.092644524199107, 3.1162236506817966, 3.1393936749972915, 3.1621714192791956, 3.1845726329278126, 3.2066120841957995, 3.2283036420647875, 3.2496603496337526, 3.2706944900633728, 3.2914176459727975, 3.3118407530609755, 3.331974148619831, 3.3518276155177382, 3.3714104221562615, 3.3907313588387145, 3.409798770934012, 3.4286205891720054, 3.447204357365766, 3.465557257821162, 3.48368613466364, 3.5015975152857064, 3.5192976300956618, 3.536792430728035, 3.5540876068586957, 3.5711886017522145, 3.5881006266555646, 3.6048286741403732, 3.6213775304854465, 3.637751787182037, 3.6539558516361015, 3.669993957134532, 3.685870172135865, 3.701588408940211, 3.717152431787996, 3.7325658644325364, 3.747832197227329, 3.762954793765271, 3.7779368971037064, 3.7927816356062283, 3.8074920284294778, 3.822070990680769, 3.836521338270194, 3.850845792478879, 3.8650469842632815, 3.8791274583138082, 3.893089676884547, 3.9069360234095876, 3.920668805920187, 3.9342902602759198, 3.9478025532219574, 3.9612077852836953, 3.9745079935091097, 3.9877051540684336, 4.000801184720082, 4.013797947151057, 4.026697249199521, 4.039500846966631, 4.052210446824285, 4.064827707324908, 4.077354241019041, 4.089791616186054, 4.102141358482988, 4.114404952516159], [0.0, 1.0560356962676236, 1.3001324477526937, 1.468300595557525, 1.6006507996591803, 1.7114712174991586, 1.8076900753316603, 1.8932501963324684, 1.9706322897164725, 2.0415092468315827, 2.1070682280247115, 2.1681853421306294, 2.2255275373036243, 2.279615515594526, 2.3308644022788845, 2.3796110461182147, 2.4261329342415356, 2.470661654821507, 2.513392704028691, 2.5544927757761666, 2.594105277469196, 2.632354569679133, 2.6693492710604603, 2.705184867306595, 2.739945794296627, 2.7737071186898055, 2.806535906598591, 2.8384923478944213, 2.8696306871301864, 2.9000000000000004, 2.9296448453622923, 2.9586058162169584, 2.986920008023576, 3.0146214189361222, 3.0417412935990047, 3.0683084198760824, 3.0943493861067957, 3.119888805082798, 3.144949509826776, 3.1695527253667466, 3.1937182199847647, 3.217464438840942, 3.2408086224034265, 3.263766911730223, 3.2863544423324105, 3.3085854280868774, 3.3304732364497234, 3.3520304560405245, 3.373268957516192, 3.394199948525757, 3.4148340234299788, 3.435181208378607, 3.4552510022607654, 3.4750524139779317, 3.4945939964325117, 3.513883877576559, 3.532929788823462, 3.551739091089409, 3.570318798700258, 3.5886756013723833, 3.606815884452517, 3.6247457475810467, 3.6424710219252847, 3.659997286113463, 3.677329880986378, 3.6944739232714414, 3.711434318273131, 3.728215771664375, 3.744822800454953, 3.7612597432055703, 3.7775307695496068, 3.793639889078653, 3.809590959642653, 3.8253876951107912, 3.8410336726350334, 3.8565323394544504, 3.8718870192750683, 3.8871009182569467, 3.902177130637424, 3.917118644017002, 3.931928344332113, 3.9466090205369824, 3.961163369014962, 3.9755939977380805, 3.9899034301920127, 4.004094109082332, 4.018168399836655, 4.032128593916138, 4.045976911948795, 4.059715506696104, 4.073346465863558, 4.086871814764994, 4.100293518849839, 4.113613486101721, 4.126833569316304, 4.139955568265651, 4.15298123175589, 4.1659122595844975, 4.1787503044030885, 4.191496973491164, 4.204153830445962, 4.216722396793137], [0.0, 1.0813962975130147, 1.3313550102950251, 1.503561700881817, 1.6390902831034837, 1.7525720432035965, 1.851101588160029, 1.938716427688703, 2.017956845010791, 2.0905359058078465, 2.157669279974593, 2.2202541160198237, 2.2789733787971214, 2.3343602749697316, 2.38683989900896, 2.4367571890687065, 2.4843962961061687, 2.5299943698629193, 2.573751601332285, 2.615838687566514, 2.6564024798866686, 2.695570325371919, 2.7334534511438613, 2.7701496359761597, 2.8057453434678643, 2.8403174429972218, 2.8739346112632878, 2.9066584835917904, 2.938544607213626, 2.9696432363712413, 3.0000000000000004, 3.029656465937002, 3.058650620485912, 3.0870172782632856, 3.114788434250825, 3.1419935676503234, 3.168659905317775, 3.1948126511187875, 3.220475186409012, 3.2456692459335836, 3.270415072708053, 3.294731554851377, 3.3186363468599773, 3.3421459774179, 3.3652759455141465, 3.3880408063705665, 3.4104542484615026, 3.432529162721086, 3.4542777048789746, 3.475711351734872, 3.4968409520721475, 3.517676772817626, 3.538228540975391, 3.5585054817948687, 3.5785163535756386, 3.5982694794617855, 3.6177727765358862, 3.6370337824858625, 3.6560596800859706, 3.674857319705515, 3.693433240034749, 3.71179368719637, 3.7299446323926424, 3.747891788222049, 3.7656406237851923, 3.783196378687227, 3.800564076033073, 3.8177485345019653, 3.8347543795792625, 3.851586054015811, 3.868247827578358, 3.8847438061484714, 3.90107794022201, 3.9172540328563903, 3.9332757471085564, 3.949146613002713, 3.964870034063383, 3.9804492934462696, 3.9958875596965386, 4.011187892161647, 4.026353246083528, 4.041386477392889, 4.056290347226483, 4.07106752618655, 4.085720598360043, 4.100252065113889, 4.114664348681232, 4.128959795552462, 4.143140679683772, 4.157209205535011, 4.171167510947728, 4.18501766987349, 4.1987616949618145, 4.212401540016378, 4.225939102327568, 4.239376224888809, 4.252714698503649, 4.265956263790047, 4.279102613087895, 4.292155392275366, 4.305116202499343, 4.317986601824782], [0.0, 1.1065045030620488, 1.3622668372858342, 1.5384718779632598, 1.6771472062095032, 1.7932638221577564, 1.8940810576427292, 1.9837301665739255, 2.064810413281864, 2.1390746379556957, 2.2077667363030735, 2.2718046871141766, 2.3318873125392763, 2.3885601994046817, 2.4422583121612687, 2.4933345978474595, 2.5420798049283744, 2.588736589364233, 2.633509790246954, 2.6765740679276115, 2.718079683368268, 2.7581569404333606, 2.7969196487514143, 2.8344678573549733, 2.870890037382621, 2.906264842990445, 2.940662545435093, 2.974146211111024, 3.0067726769625307, 3.0385933640511547, 3.0696549607394936, 3.1, 3.129667350114503, 3.1586926340364743, 3.187108589617348, 3.2149453805164647, 3.2422308657516803, 3.2689908343800265, 3.295249210632956, 3.3210282338998787, 3.3463486172051624, 3.371229687218158, 3.3956895083430396, 3.419744993032133, 3.4434120001349293, 3.466705422821081, 3.4896392673883105, 3.512226724076587, 3.5344802308511922, 3.5564115309838398, 3.578031725148427, 3.5993513186525727, 3.620380264345056, 3.6411280016700998, 3.6616034922802876, 3.681815252569128, 3.701771383440558, 3.721479597594951, 3.740947244578515, 3.760181333814624, 3.779188555810936, 3.797975301714624, 3.8165476813692405, 3.8349115400102076, 3.8530724737214586, 3.8710358437629777, 3.888806789867744, 3.9063902425966295, 3.923790934830994, 3.941013412474895, 3.958062044431892, 3.9749410319152254, 3.9916544171446326, 4.008206091478135, 4.024599803022706, 4.040839163763782, 4.056927656250009, 4.072868639866451, 4.088665356726569, 4.104320937210731, 4.119838405176622, 4.135220682864863, 4.150470595521165, 4.165590875754666, 4.180584167650479, 4.195453030653067, 4.21019994323576, 4.224827306370513, 4.239337446810962, 4.253732620200812, 4.2680150140187, 4.282186750369865, 4.296249888634165, 4.3102064279793195, 4.324058309747607, 4.337807419723666, 4.351455590290495, 4.365004602480278, 4.3784561879261945, 4.391812030720948, 4.405073769187359, 4.418242997566036], [0.0, 1.131370849898476, 1.3928809012737986, 1.5730457773099473, 1.714837540058069, 1.8335636311938623, 1.9366465206709529, 2.0283103035868377, 2.1112126572366305, 2.1871458131829224, 2.257381621056742, 2.3228586892787155, 2.3842915445479136, 2.4422380345998556, 2.4971428987908664, 2.5493670158970603, 2.5992076683399534, 2.6469129652589007, 2.692692349070879, 2.7367244052486903, 2.779162771551499, 2.8201406801473135, 2.8597744982951854, 2.8981665234179173, 2.935407214855686, 2.9715769943502686, 3.00674771235608, 3.040983852551318, 3.074343529170305, 3.1068793188541104, 3.1386389591874666, 3.169665938981363, 3.2, 3.2296775657473344, 3.2587321097887223, 3.287194473647908, 3.315093142415212, 3.3424544847021402, 3.369302962386614, 3.3956613146412504, 3.421550719971802, 3.446990939373609, 3.472000443210098, 3.4965965240051644, 3.5207953970023786, 3.5446122900638595, 3.5680615242492273, 3.591156586221178, 3.613910193461938, 3.6363343531483996, 3.658440415418611, 3.6802391216647465, 3.7017406484047957, 3.722954647214513, 3.7438902811406565, 3.7645562579646543, 3.7849608606411147, 3.805111975197027, 3.825017116344097, 3.8446834510276533, 3.864117820110352, 3.883326758366874, 3.902316512946573, 3.921093060444168, 3.9396621227037323, 3.958029181468223, 3.9761994919752395, 3.994178095589574, 4.011969831554078, 4.029579347932382, 4.047011111809905, 4.064269418813264, 4.0813584020025315, 4.098282040185762, 4.115044165700701, 4.131648471704514, 4.148098519008757, 4.164397742493562, 4.180549457132029, 4.196556863653199, 4.212423053869561, 4.228151015692905, 4.243743637860365, 4.259203714390681, 4.274533948789185, 4.289736958018438, 4.304815276250212, 4.319771358413224, 4.3346075835499756, 4.349326257994987, 4.363929618385851, 4.378419834517629, 4.392799012050383, 4.407069195078895, 4.421232368573005, 4.4352904606963675, 4.44924534501091, 4.463098842573748, 4.476852723932852, 4.490508711027342, 4.504068478997878, 4.517533657912253], [0.0, 1.1560051208396862, 1.4232092463198946, 1.607297000845234, 1.7521761126275672, 1.8734873248994515, 1.978814723176649, 2.072474377264262, 2.157181832257842, 2.2347683434564543, 2.306533453522472, 2.3734362079720523, 2.4362066914835983, 2.4954148982716218, 2.5515152513693806, 2.6048764872643213, 2.6558023613533925, 2.704546385060941, 2.751322561166487, 2.796313363631672, 2.8396757754973474, 2.8815459299054385, 2.9220427278753354, 2.961270694236026, 2.9993222579735344, 3.036279591918573, 3.0722161109847796, 3.107197702906679, 3.1412837472877633, 3.1745279655636867, 3.206979134748999, 3.238681690572452, 3.2696762401284665, 3.3000000000000003, 3.3296871725999666, 3.3587692709900514, 3.3872754004899472, 3.415232503856695, 3.4426655755968647, 3.46959785000184, 3.4960509667144524, 3.5220451170024973, 3.5475991733998624, 3.5727308049548343, 3.5974565799788585, 3.62179205790286, 3.6457518716107056, 3.669349801421325, 3.6925988417251774, 3.715511261141324, 3.738098656943734, 3.760372004405774, 3.782341701627157, 3.804017610335359, 3.825409093091715, 3.8465250472793624, 3.867373936204513, 3.88796381760313, 3.9083023698109356, 3.9283969158250724, 3.948254445459944, 3.96788163577727, 3.987284869950743, 4.006470254708408, 4.025443636480772, 4.044210616369303, 4.0627765640382245, 4.081146630622124, 4.099325760732679, 4.117318703639645, 4.135130023693979, 4.152764110054519, 4.170225185773862, 4.187517316293937, 4.20464441739714, 4.221610262654793, 4.2384184904109405, 4.255072610336194, 4.271576009583298, 4.287931958573406, 4.304143616439592, 4.320214036151917, 4.336146169346367, 4.351942870878163, 4.367606903118284, 4.383140940010578, 4.39854757090543, 4.413829304184746, 4.428988570691881, 4.444027726979081, 4.458949058384094, 4.473754781946719, 4.488447049175293, 4.503027948672359, 4.517499508628142, 4.531863699189797, 4.54612243471386, 4.560277575908826, 4.5743309318742655, 4.588284262042501, 4.602139278028412, 4.615897645392603], [0.0, 1.1804164196559914, 1.4532630804800821, 1.6412382063527704, 1.7891767226534767, 1.9130496573599347, 2.020601248719444, 2.116238708754235, 2.202734926581594, 2.2819598280215994, 2.35524039811009, 2.4235559344765156, 2.487651938958705, 2.548110442308763, 2.6053954635870356, 2.6598835258698146, 2.711884798940654, 2.7616581476112008, 2.8094220937463183, 2.8553629646006162, 2.899641058217494, 2.942395382455212, 2.98374734915968, 3.023803690405156, 3.0626587869956587, 3.1003965470012074, 3.137091935634277, 3.1728122319771868, 3.2076180695493672, 3.2415643042191786, 3.2747007430228003, 3.30707276003591, 3.338721819850788, 3.369685924951001, 3.4000000000000004, 3.429696223519124, 3.4588043154435577, 3.487351787479112, 3.5153641619400275, 3.542865163754986, 3.569876889530009, 3.596419956910823, 3.6225136369616124, 3.6481759718470195, 3.6734238797506436, 3.6982732486710868, 3.722739020494049, 3.7468352665367237, 3.7705752555914236, 3.7939715153529883, 3.8170358879944057, 3.8397795805533086, 3.86221321070553, 3.884346848428121, 3.9061900539911285, 3.9277519126632576, 3.9490410664699085, 3.9700657433018263, 3.990833783637743, 4.011352665114142, 4.031629525148967, 4.051671181803097, 4.071484153043364, 4.091074674553265, 4.11044871622207, 4.12961199742941, 4.148570001230421, 4.167327987535931, 4.185891005372715, 4.2042639043006105, 4.2224513450557275, 4.24045780948254, 4.258287609811624, 4.275944897334627, 4.293433670523316, 4.310757782635319, 4.3279209488453985, 4.344926752937693, 4.361778653591273, 4.378479990288602, 4.3950339888739975, 4.411443766786929, 4.427712337992925, 4.443842617633028, 4.459837426411063, 4.475699494736407, 4.491431466638619, 4.507035903468972, 4.522515287402813, 4.537872024755575, 4.553108449124363, 4.568226824366088, 4.583229347422375, 4.598118151000674, 4.612895306120397, 4.627562824532192, 4.642122661017961, 4.656576715578678, 4.670926835516578, 4.68517481741782, 4.699322409041364, 4.71337131111937], [0.0, 1.2046132367247342, 1.4830528566349936, 1.6748811987612655, 1.8258522391413918, 1.9522643885613609, 2.0620206308713684, 2.1596185195200337, 2.24788778381223, 2.3287366803233915, 2.4035193953495484, 2.473235300694993, 2.5386451798992447, 2.6003429944969705, 2.6588022752633083, 2.714407263449127, 2.7674744868667123, 2.818268116679257, 2.86701115413153, 2.9138937459154337, 2.9590794759507477, 3.002710201554332, 3.044909823338075, 3.085787261228278, 3.1254388306979557, 3.163950159810332, 3.201397750455535, 3.2378502608390654, 3.273369567379175, 3.308011650409616, 3.341827337938255, 3.374862934143224, 3.407160753580542, 3.4387595777293307, 3.4696950471577663, 3.4999999999999996, 3.529704765406594, 3.558837419033252, 3.587424006364478, 3.61548873865543, 3.6430541654603656, 3.6701413270567147, 3.696769889537404, 3.7229582649051687, 3.7487237181417274, 3.774082462926509, 3.7990497474321048, 3.8236399314172114, 3.847866555665056, 3.871742404669973, 3.8952795633522457, 3.918489468477453, 3.941382955368315, 3.963970300421744, 3.9862612598793956, 4.0082651052447495, 4.029990655692137, 4.0514463077720775, 4.072640062681695, 4.093579551338131, 4.114272057465996, 4.134724538886488, 4.154943647175262, 4.174935745838245, 4.194706927138739, 4.214263027695327, 4.233609642957789, 4.252752140657458, 4.27169567331881, 4.290445189910588, 4.309005446707207, 4.327381017424424, 4.345576302687257, 4.363595538882788, 4.381442806445629, 4.399122037619577, 4.416637023735064, 4.433991422038584, 4.4511887621070905, 4.468232451877572, 4.4851257833194556, 4.501871937775179, 4.518473990992172, 4.534934917867624, 4.551257596925678, 4.5674448145451265, 4.583499268954281, 4.599423574008388, 4.615220262763771, 4.630891790861824, 4.646440539734995, 4.661868819645961, 4.677178872570451, 4.692372874933313, 4.707452940206839, 4.722421121379632, 4.737279413303779, 4.752029754927506, 4.76667403142005, 4.781214076194971, 4.795651672837742, 4.809988556943054], [0.0, 1.2286035066475314, 1.512588343425082, 1.708237010254878, 1.8622146886984314, 1.9911443777681819, 2.1030864518443155, 2.2026280346357936, 2.292655210439916, 2.3751142393912095, 2.451386276852437, 2.5224905974469927, 2.589203135969511, 2.6521296828945276, 2.7117531995187503, 2.7684655793842903, 2.822589654059216, 2.8743948557625654, 2.9241086268824477, 2.971924900944851, 3.0180105196972717, 3.062510165591823, 3.105550206761945, 3.1472417323101958, 3.1876829758640017, 3.2269612707977102, 3.265154642561822, 3.3023331167126457, 3.338559801957712, 3.3738917934975827, 3.4083809315966658, 3.4420744425960734, 3.4750154837601643, 3.5072436089140067, 3.538795168419449, 3.5697036543929133, 3.6, 3.6297128400323557, 3.658868738678898, 3.6874923893699183, 3.715606790741484, 3.743233402095089, 3.770392281180388, 3.7971022066812234, 3.823380787417119, 3.8492445599682763, 3.874709076179674, 3.8997889817893396, 3.9244980872496638, 3.9488494316624028, 3.9728553406230125, 3.996527478664031, 4.0198768968972045, 4.042914076377278, 4.065648967644679, 4.088091026847937, 4.110249248798147, 4.1321321972659035, 4.153748032794809, 4.175104538274237, 4.196209142486577, 4.217068941820329, 4.237690720319472, 4.258080968221253, 4.278245899118407, 4.298191465867701, 4.317923375354142, 4.337447102209204, 4.356767901571587, 4.375890820970379, 4.394820711402767, 4.4135622376715675, 4.432119888041699, 4.450497983269287, 4.468700685052144, 4.486732003946001, 4.504595806786885, 4.522295823656562, 4.539835654424672, 4.557218774898393, 4.574448542607811, 4.591528202252847, 4.608460890835453, 4.625249642498882, 4.6418973930940295, 4.658406984491343, 4.674781168655241, 4.691022611496759, 4.707133896518873, 4.723117528267885, 4.738975935603254, 4.754711474797305, 4.770326432475447, 4.785823028406751, 4.801203418154005, 4.816469695591758, 4.8316238953002335, 4.84666799484245, 4.861603916931415, 4.8764335314937215, 4.891158657635536, 4.90578106551649], [0.0, 1.2523946590098143, 1.5418786877429442, 1.741315970848732, 1.8982753324703165, 2.029701665787038, 2.1438114293786956, 2.2452805737877024, 2.3370510705612935, 2.4211068679662104, 2.4988558665905827, 2.571337078684901, 2.63934146454456, 2.7034865454045893, 2.7642646348105977, 2.8220752150824593, 2.8772473692232925, 2.9300557468415844, 2.980732194607608, 3.0294744014509782, 3.0764524399071655, 3.121813794115112, 3.1656872792495534, 3.2081861355852936, 3.249410498983625, 3.2894493939760525, 3.328382356928007, 3.3662807693976897, 3.4032089621539927, 3.439225136010974, 3.4743821350879234, 3.508728100235044, 3.5423070244306145, 3.575159227435234, 3.607321763513183, 3.63882877333515, 3.6697117890684887, 3.7, 3.7297204847178067, 3.758898414825311, 3.7875572343130437, 3.815718818028693, 3.843403612127917, 3.8706307589322386, 3.8974182082451563, 3.9237828168675923, 3.949740437796451, 3.9753060003754825, 4.000493582488008, 4.025316475729978, 4.049787244374437, 4.073917778830433, 4.097719344207701, 4.121202624520178, 4.144377762994392, 4.167254398891382, 4.189841701201239, 4.212148399526712, 4.2341828124353205, 4.25595287352731, 4.277466155438879, 4.298729891975733, 4.319750998550695, 4.340536091080472, 4.361091503480205, 4.381423303880076, 4.401537309675415, 4.421439101510575, 4.441134036286787, 4.460627259275441, 4.479923715410305, 4.499028159825237, 4.517945167697648, 4.536679143452454, 4.555234329376191, 4.573614813686535, 4.591824538098421, 4.609867304924355, 4.627746783743243, 4.645466517669136, 4.6630299292486255, 4.6804403260132545, 4.697700905711093, 4.714814761239711, 4.731784885300957, 4.748614174796352, 4.7653054349804185, 4.781861383387919, 4.798284653549778, 4.8145777985113, 4.830743294165315, 4.846783542411914, 4.862700874155604, 4.87849755214992, 4.894175773698799, 4.909737673223386, 4.9251853247023, 4.940520743992854, 4.95574589104021, 4.970862671980943, 4.985872941147092, 5.000778502976344], [0.0, 1.2759936632617046, 1.570932469988162, 1.7741277707907994, 1.9340447341680562, 2.0679475477032447, 2.1842074935691627, 2.2875886317359817, 2.381088369630156, 2.466728039264233, 2.54594207044517, 2.619789053640547, 2.6890748532937767, 2.7544286266574534, 2.8163519639930947, 2.875251875107934, 2.9314636439507216, 2.985267095381397, 3.0368984447814205, 3.0865591061536946, 3.1344223567283604, 3.1806384597034976, 3.225338657531725, 3.268638324286252, 3.310639482698934, 3.351432834799885, 3.391099415666634, 3.429711951907587, 3.4673359864830817, 3.504030816891233, 3.5398502829986285, 3.5748434327785734, 3.609055088173662, 3.642526328693982, 3.6752949068212124, 3.707395606542289, 3.7388605541885105, 3.7697194890634793, 3.8000000000000003, 3.8297277329126467, 3.8589265735495273, 3.8876188089483854, 3.915825270533941, 3.943565461328493, 3.9708576693655755, 3.997719069080583, 4.024165812190108, 4.050213109353094, 4.075875303723897, 4.10116593735341, 4.126097811264595, 4.150683039918725, 4.174933100695187, 4.198858878927911, 4.222470708973314, 4.245778411726042, 4.26879132894843, 4.29151835473605, 4.313967964404066, 4.3361482410463825, 4.358066899991182, 4.379731311351531, 4.401148520848103, 4.422325269062018, 4.4432680092590475, 4.4639829239117885, 4.484475940033365, 4.504752743424793, 4.52481879192796, 4.544679327767146, 4.564339389054027, 4.583803820523944, 4.603077283564862, 4.622164265594737, 4.641069088837955, 4.659795918546909, 4.678348770710682, 4.696731519289155, 4.714947903007497, 4.733001531743025, 4.750895892533741, 4.768634355235348, 4.786220177851423, 4.8036565115593275, 4.820946405452707, 4.838092811019703, 4.855098586374542, 4.87196650025878, 4.888699235827243, 4.905299394232537, 4.921769498021, 4.938111994351978, 4.954329258051459, 4.970423594510278, 4.986397242436404, 5.002252376470103, 5.017991109670189, 5.03361549587899, 5.0491275319731175, 5.064529160006681, 5.079822269253092, 5.095008698151246], [0.0, 1.2994070685374635, 1.599757753090793, 1.806681515926432, 1.9695328204229459, 2.1058926374144447, 2.224285855026351, 2.3295639497027985, 2.4247793287631656, 2.5119904139540408, 2.592657955656985, 2.6678599685799598, 2.7384171040978122, 2.804970063966971, 2.8680296422063174, 2.928010316909052, 2.9852535242010076, 3.0400442234918024, 3.0926229645155012, 3.1431948570517294, 3.191936357821349, 3.2390004872251263, 3.2845208959037615, 3.328615074947195, 3.3713869191181858, 3.41292879475244, 3.4533232238526685, 3.492644267499077, 3.5309586713099272, 3.5683268208423096, 3.6048035438788575, 3.640438788381733, 3.675278198738294, 3.7093636082329184, 3.7427334620734167, 3.7754231825034865, 3.807465485345453, 3.838890655594004, 3.86972678831371, 3.9, 3.9297346146842735, 3.9589533283525804, 3.987677354668677, 4.015926554518837, 4.043719551506555, 4.0710738352036, 4.098005853696909, 4.124531096748166, 4.150664170696484, 4.176418866077946, 4.201808218803465, 4.22684456562444, 4.251539594520469, 4.275904390562161, 4.299949477732636, 4.323684857131658, 4.347120041935005, 4.370264089437388, 4.393125630468836, 4.4157128964412, 4.438033744252412, 4.460095679250881, 4.481905876440306, 4.5034712000857695, 4.524798221865018, 4.545893237693791, 4.566762283340899, 4.587411148936999, 4.6078453924707645, 4.628070352356859, 4.6480911591520515, 4.667912746488483, 4.687539861286645, 4.70697707330482, 4.726228784076562, 4.745299235283121, 4.76419251660359, 4.7829125730817355, 4.8014632120451735, 4.819848109609422, 4.838070816796681, 4.856134765296659, 4.874043272894542, 4.891799548589135, 4.909406697422376, 4.926867725039716, 4.9441855419993646, 4.961362967846946, 4.978402734970906, 4.995307492252805, 5.012079808525574, 5.028722175851865, 5.045237012633715, 5.0616266665639325, 5.077893417428885, 5.09403947977165, 5.110067005423886, 5.12597808591419, 5.141774754760173, 5.157458989650996, 5.173032714526639, 5.1884978015598], [0.0, 1.3226410390991368, 1.6283621261476173, 1.8389857769788214, 2.004748934509089, 2.1435469250725863, 2.264057065548236, 2.3712175789152745, 2.4681354508800384, 2.5569059086763413, 2.6390158215457884, 2.715562479574009, 2.7873812077437954, 2.855124163841105, 2.919311275106798, 2.980364430684892, 3.038631171729495, 3.0944015528499484, 3.147920424915484, 3.1993965651589047, 3.249009585424942, 3.296915242186508, 3.3432495758166096, 3.388132178197612, 3.4316688017763797, 3.4739534644393735, 3.515070163719052, 3.5550942849403446, 3.5940937671625592, 3.6321300756631367, 3.669259018569607, 3.7055314369356886, 3.7409937912904856, 3.7756886629159205, 3.809655184437048, 3.8429294114628805, 3.875544644789054, 3.907531710919295, 3.9389192072703008, 3.969733717311939, 4.0, 4.029741157134759, 4.058978781689621, 4.087733089672254, 4.11602303768438, 4.143866428019014, 4.171280002862132, 4.198279528939175, 4.224879873757033, 4.251095074432645, 4.276938399964752, 4.302422407691301, 4.327558994578111, 4.352359443901735, 4.376834467818745, 4.400994246252973, 4.424848462479969, 4.4484063357428605, 4.471676651194719, 4.494667787428664, 4.517387741827422, 4.539844153938338, 4.562044327057333, 4.583995248185574, 4.6057036065052985, 4.627175810505995, 4.648418003878672, 4.669436080284078, 4.690235697090168, 4.710822288164813, 4.731201075801393, 4.751377081847566, 4.771355138100851, 4.791139896028824, 4.810735835866393, 4.83014727513794, 4.849378376647817, 4.868433155978915, 4.88731548853554, 4.906029116163778, 4.924577653379665, 4.942964593233037, 4.961193312832537, 4.979267078555285, 4.9971890509627315, 5.014962289442597, 5.032589756595149, 5.0500743223807305, 5.067418768044097, 5.0846257898299765, 5.101698002503164, 5.118637942685488, 5.135448072021081, 5.152130780180532, 5.168688387713793, 5.185123148760945, 5.201437253629346, 5.217632831245044, 5.233711951485843, 5.2496766274028515, 5.26552881733695, 5.2812704269361035], [0.0, 1.345701385982374, 1.6567527433827107, 1.8710486335490026, 2.0397018843094883, 2.180919828370928, 2.303531072290494, 2.412559937339795, 2.511167579756725, 2.6014857572209134, 2.6850272626520217, 2.7629085174715877, 2.835979410616866, 2.9049034702943004, 2.9702096887156495, 3.0323273106941704, 3.0916099367903667, 3.148352678737703, 3.202804656398897, 3.255178287053648, 3.30565631409283, 3.3543972096152794, 3.4015393858682303, 3.4472045198275914, 3.4915002077421633, 3.534522106707392, 3.5763556787590876, 3.6170776235710416, 3.6567570647252152, 3.695456539150826, 3.733232827994342, 3.770137658727112, 3.8062183019210902, 3.8415180812660803, 3.876076811667425, 3.9099311773664156, 3.9431150597605864, 3.9756598228160973, 4.007594562547774, 4.038946325910298, 4.069740303533735, 4.1000000000000005, 4.129747384757628, 4.159003026281913, 4.18778621168437, 4.21611505364234, 4.244006586243084, 4.2714768511060965, 4.2985409749543795, 4.3252132396430705, 4.35150714551691, 4.377435468851985, 4.403010314038617, 4.428243161078141, 4.4531449088943935, 4.47772591489895, 4.501996031196002, 4.525964637766885, 4.549640672934479, 4.573032661373309, 4.596148739901077, 4.618996681261216, 4.6415839160831665, 4.66391755318699, 4.686004398381324, 4.707850971888156, 4.729463524514217, 4.750848052676675, 4.772010312380126, 4.792955832232338, 4.813689925577774, 4.8342177018203865, 4.854544077000452, 4.874673783684234, 4.894611380219878, 4.914361259408131, 4.933927656632155, 4.953314657486832, 4.972526204944439, 4.9915661060904295, 5.010438038460203, 5.029145556005181, 5.047692094714157, 5.0660809779137805, 5.084315421270132, 5.102398537511587, 5.120333340891577, 5.138122751408419, 5.1557695987980825, 5.173276626314527, 5.190646494311169, 5.207881783636034, 5.224984998852203, 5.241958571294355, 5.258804861971406, 5.275526164324542, 5.292124706849294, 5.308602655589698, 5.324962116512033, 5.34120513776511, 5.357333711833627, 5.373349777590669], [0.0, 1.3685935953338417, 1.6849363590348923, 1.9028777135158876, 2.0743999852675317, 2.2180202384692556, 2.3427172662736333, 2.453600860485035, 2.5538859529048983, 2.6457405653079893, 2.730703225277383, 2.8099093460801874, 2.884223274419458, 2.9543198260181494, 3.02073699196443, 3.083911319109164, 3.1442024232389234, 3.2019104363388093, 3.257288716138952, 3.3105532934256483, 3.3618900203031945, 3.411460064696189, 3.4594041934322894, 3.505846153378121, 3.5508953711408973, 3.5946491310732536, 3.6371943490363696, 3.6786090294697207, 3.718963471841336, 3.7583212769185836, 3.7967401917723986, 3.834272823828713, 3.870967247796149, 3.906867524359351, 3.9420141457293085, 3.97644442019611, 4.010192805525906, 4.043291199228544, 4.075769192281601, 4.107654291745217, 4.138972116776306, 4.169746571801663, 4.2, 4.229753319744328, 4.25902614624614, 4.287836900304032, 4.316202905778239, 4.344140477178002, 4.37166499855244, 4.398790994710453, 4.425532195655994, 4.4519015950069685, 4.477911503065826, 4.503573595124327, 4.528898955511812, 4.553898117833502, 4.578581101791274, 4.602957446932688, 4.627036243633647, 4.650826161584973, 4.674335476022695, 4.697572091915174, 4.720543566296956, 4.743257128918793, 4.765719701365375, 4.787937914776529, 4.809918126293699, 4.831666434341261, 4.853188692841271, 4.8744905244506285, 4.895577332901006, 4.916454314514262, 4.937126468959196, 4.957598609309457, 4.977875371456888, 4.997961222929746, 5.017860471160815, 5.037577271246499, 5.0571156332343925, 5.076479428973644, 5.095672398559531, 5.114698156401018, 5.133560196937735, 5.152261900030634, 5.170806536048649, 5.189197270671893, 5.207437169430344, 5.225529201995459, 5.2434762462408635, 5.261281092086993, 5.278946445143492, 5.296474930162117, 5.313869094311973, 5.331131410288044, 5.3482642792632165, 5.3652700336932275, 5.382150939983347, 5.398909201024963, 5.415546958609701, 5.432066295728169, 5.448469238759937, 5.464757759560957], [0.0, 1.3913228538564608, 1.7129193586844873, 1.9344802284150482, 2.1088510989547635, 2.2548565612318736, 2.381624525939384, 2.494349647019932, 2.596300249054444, 2.6896803597785293, 2.7760540582547506, 2.8565756144084427, 2.932123729795507, 3.0033844273088537, 3.0709046328574527, 3.1351281433525697, 3.1964205469893936, 3.2550869602696153, 3.311384948624881, 3.3655341306265014, 3.417723444963819, 3.4681167361978242, 3.516857108976276, 3.564070365322664, 3.6098677491737976, 3.654348160556394, 3.6975999588084156, 3.739702443847466, 3.780727082657475, 3.8207385322713723, 3.859795498808936, 3.897951463387009, 3.935255299126894, 3.9717517984620136, 4.007482126087822, 4.042484209901116, 4.076793079933966, 4.110441163442046, 4.143458542842458, 4.17587318202568, 4.207711125625147, 4.23899667506637, 4.2697525445979565, 4.3, 4.329758982248496, 4.359048218070036, 4.387885319035173, 4.416286870600418, 4.444268512309309, 4.471845010195127, 4.499030322286276, 4.525837657995406, 4.552279532071374, 4.578367813706253, 4.604113771315139, 4.629528113442724, 4.654621026195573, 4.679402207551657, 4.703880898857555, 4.728065913788139, 4.751965665012476, 4.775588188782657, 4.798941167638557, 4.822031951400812, 4.8448675766060525, 4.867454784522408, 4.889800037869132, 4.911909536351699, 4.93378923111263, 4.955444838188499, 4.976881851054797, 4.9981055523325875, 5.019121024723916, 5.039933161236749, 5.0605466747546535, 5.080966107001475, 5.101195836946759, 5.121240088693707, 5.141102938887774, 5.160788323680809, 5.1803000452826495, 5.1996417781294575, 5.218817074695638, 5.2378293709740245, 5.256681991647015, 5.275378154969544, 5.29392097738314, 5.312313477878819, 5.330558582125207, 5.3486591263770356, 5.366617861178038, 5.384437454871186, 5.402120496928329, 5.419669501110349, 5.437086908468208, 5.454375090194481, 5.471536350334328, 5.488572928364203, 5.50548700164607, 5.5222806877643205, 5.538956046752127, 5.555515083213528], [0.0, 1.413894071717889, 1.7407077874569754, 1.9658630052904187, 2.1430626677936453, 2.2914367543543865, 2.4202612563647468, 2.5348150998437746, 2.6384196309021988, 2.7333146328804854, 2.8210895586566105, 2.9029174037003673, 2.979691124608606, 3.052107873518702, 3.1207234490349993, 3.185988847718176, 3.248275588644798, 3.3078937381748954, 3.3651050401847202, 3.4201326760840747, 3.4731686496857614, 3.5243794635760244, 3.5739105439674366, 3.621889733750473, 3.668430081555316, 3.71363209184869, 3.7575855574085826, 3.8003710646230324, 3.8420612398739182, 3.882721789115328, 3.92241237084744, 3.961187333803077, 3.999096343964713, 4.036184920426567, 4.072494895692654, 4.1080648129582364, 4.142930270542239, 4.177124221762746, 4.210677237059308, 4.243617733976323, 4.275972179665333, 4.307765269790154, 4.339020087089176, 4.369758242333992, 4.4, 4.429764390614615, 4.459069311458202, 4.487931617050598, 4.516367200653264, 4.544391067846579, 4.57201740309791, 4.599259630114185, 4.62613046666912, 4.6526419745068734, 4.678805604848319, 4.704632239961228, 4.730132231199817, 4.755315433870868, 4.780191239241915, 4.804768603970725, 4.829056077203814, 4.853061825564158, 4.876793656224302, 4.9002590382398985, 4.923465122300236, 4.946418759036004, 4.9691265160101645, 4.991594693505063, 5.013829339207699, 5.035836261885031, 5.057621044132362, 5.079189054269911, 5.10054545745562, 5.121695226075976, 5.142643149470936, 5.163393843044036, 5.183951756804174, 5.204321183381532, 5.224506265556363, 5.244511003336103, 5.264339260613259, 5.283994771433807, 5.303481145903404, 5.3228018757564675, 5.341960339611211, 5.360959807931827, 5.3798034477173955, 5.398494326935564, 5.417035418717632, 5.435429605330461, 5.45367968193943, 5.471788360175635, 5.489758271519528, 5.507591970512349, 5.525291937805859, 5.542860583060127, 5.560300247698484, 5.577613207528068, 5.594801675233854, 5.611867802753481, 5.6288136835397236, 5.645641354717007], [0.0, 1.4363119032269167, 1.7683073754786227, 1.9970325154425377, 2.1770417463971174, 2.3277683608730393, 2.4586354246552253, 2.5750055631546465, 2.680252783695471, 2.776652382240043, 2.8658190130498955, 2.948944269886821, 3.0269352675161865, 3.10050021168926, 3.170203713409923, 3.2365039199618897, 3.29977824099884, 3.3603416591015836, 3.4184600681956825, 3.4743601883175876, 3.5282370675740204, 3.58025984851344, 3.6305762631366627, 3.6793161813321107, 3.726594444159253, 3.7725131496215902, 3.817163514195963, 3.860627401998427, 3.9029785909299353, 3.944283828737618, 3.9846037198300026, 4.023993474659865, 4.062503546682837, 4.100180176715792, 4.137065860533102, 4.17319975244714, 4.208618015201797, 4.243354124602624, 4.2774391357951895, 4.310901916894932, 4.343769354700206, 4.376066536434028, 4.407816910820438, 4.4390424312780805, 4.469763683583365, 4.5, 4.529769561576579, 4.559089490067802, 4.587975930728868, 4.616444127059379, 4.6445084884268555, 4.672182651376237, 4.699479535326408, 4.726411393265096, 4.752989857976662, 4.779225984271399, 4.805130287628203, 4.830712779613517, 4.855983000397016, 4.880950048647703, 4.90562260906208, 4.9300089777480585, 4.954117085663891, 4.977954520289965, 5.001528545692483, 5.024846121121507, 5.047913918271219, 5.070738337317357, 5.0933255218353075, 5.115681372692253, 5.137811560997684, 5.1597215401885865, 5.181416557318461, 5.2029016636128835, 5.224181724348629, 5.245261428108221, 5.266145295457155, 5.286837687086903, 5.307342811463086, 5.327664732014789, 5.347807373898011, 5.367774530363458, 5.387569868756391, 5.407196936174016, 5.426659164803829, 5.4459598769644835, 5.465102289869043, 5.484089520128956, 5.502924588015654, 5.521610421495445, 5.540149860052123, 5.558545658310733, 5.576800489474857, 5.594916948588964, 5.612897555636497, 5.6307447584836074, 5.648460935677789, 5.6660483991099735, 5.683509396548103, 5.700846114049609, 5.718060678259764, 5.735155158602379], [0.0, 1.458580765539925, 1.79572356090683, 2.0279949004378004, 2.2107950299222834, 2.363858539481459, 2.4967545919659777, 2.61492895598617, 2.7218079501395263, 2.8197021470246084, 2.910251234820272, 2.9946652819924133, 3.0738654673921797, 3.1485709769321306, 3.2193551754562275, 3.2866833134538034, 3.350938652012056, 3.412441057263695, 3.471460545606013, 3.5282273521875083, 3.582939549179122, 3.635768901548658, 3.6868654317629383, 3.736361023238684, 3.784372297553742, 3.831002935659146, 3.8763455682699375, 3.920483328739534, 3.963491138835978, 4.005436781176603, 4.046381799792608, 4.086382261130493, 4.125489400886188, 4.1637501768032905, 4.201207743519018, 4.2379018624019045, 4.273869256870138, 4.309143921744745, 4.343757393656378, 4.377738988297417, 4.411116009324429, 4.443913932917671, 4.476156571354814, 4.507866218424622, 4.539063779069434, 4.569768885284177, 4.6000000000000005, 4.6297745104306545, 4.6591088121505555, 4.688018384997517, 4.716517861744732, 4.7446210903608135, 4.7723411905698585, 4.799690605332327, 4.826681147789558, 4.853324044147797, 4.879629972919994, 4.905609100893888, 4.9312711161518195, 4.956625258430348, 4.981680347075218, 5.00644480681883, 5.030926691582573, 5.055133706484624, 5.079073228214695, 5.102752323920433, 5.126177768735279, 5.149356062064552, 5.1722934427348415, 5.194995903101536, 5.217469202200121, 5.2397188780187465, 5.26175025896226, 5.283568474571432, 5.305178465555246, 5.326584993188933, 5.347792648125724, 5.368805858666111, 5.389628898524591, 5.410265894130455, 5.430720831496092, 5.450997562683516, 5.4710998118972265, 5.4910311812293235, 5.510795156080614, 5.530395110279632, 5.549834310919748, 5.569115922932964, 5.588243013417598, 5.607218555735719, 5.626045433395041, 5.644726443728854, 5.663264301386616, 5.681661641646876, 5.6999210235633955, 5.718044932954524, 5.736035785245225, 5.753895928170441, 5.77162764434795, 5.789233153728248, 5.806714615928536, 5.824074132457377], [0.0, 1.48070485562373, 1.8229615108138462, 2.0587559956934167, 2.2443288797812753, 2.3997140920216027, 2.5346259425383004, 2.654592802618326, 2.763092962051371, 2.8624720407350734, 2.9543945980174646, 3.0400890569625423, 3.120490569075121, 3.1963292290458654, 3.268187098649176, 3.336536485401312, 3.4017664637822023, 3.4642017517279675, 3.5241164613070075, 3.5817443199277528, 3.6372864041656014, 3.6909170843590786, 3.742788658550449, 3.793035010594571, 3.8417745310123346, 3.8891124734113935, 3.9351428735508804, 3.979950125770127, 4.023610288267864, 4.066192171803829, 4.107758253923308, 4.148365451501612, 4.18806577738955, 4.2269069015966245, 4.26493263333956, 4.302183337096518, 4.338696293314978, 4.3745060124572674, 4.40964450950894, 4.444141544829572, 4.4780248362238995, 4.511320246300771, 4.544051948527987, 4.576242574851652, 4.607913347305098, 4.63908419566589, 4.669773862915182, 4.7, 4.729779251186622, 4.759127331114618, 4.788059094510467, 4.816588599391968, 4.844729164486227, 4.872493421491402, 4.899893362733288, 4.926940384699823, 4.953645327878109, 4.980018513268069, 5.006069775903117, 5.031808495670271, 5.057243625689148, 5.082383718480439, 5.107236950129271, 5.131811142626835, 5.1561137845541785, 5.180152050255074, 5.203932817629754, 5.227462684668019, 5.250747984828422, 5.273794801359783, 5.296608980651968, 5.319196144694609, 5.3415617027150315, 5.363710862060066, 5.385648638380512, 5.4073798651717215, 5.428909202719015, 5.45024114649237, 5.471380035030973, 5.492330057354746, 5.513095259936838, 5.533679553268226, 5.554086718043007, 5.574320410990646, 5.594384170379312, 5.614281421212554, 5.634015480139766, 5.653589560099372, 5.673006774712146, 5.692270142440798, 5.711382590530756, 5.730346958745906, 5.749166002912135, 5.76784239828051, 5.786378742721107, 5.804777559757746, 5.82304130145311, 5.841172351153133, 5.859173026098864, 5.877045579913522, 5.894792204971879, 5.912415034658667], [0.0, 1.5026881656708997, 1.850026140165248, 2.089321351910698, 2.2776493470065042, 2.43534148846669, 2.572256310087104, 2.6940042602138785, 2.8041152691257545, 2.904969781006429, 2.9982570681128586, 3.085223791313138, 3.1668189858549463, 3.2437835857922996, 3.3167082944897204, 3.3860724315851134, 3.452270847959349, 3.5156330824789594, 3.576437316821871, 3.634920748434494, 3.691287439179054, 3.7457143481862993, 3.7983560345939917, 3.8493483699659397, 3.898811502509931, 3.946852248483113, 3.993566039748129, 4.039038523606319, 4.0833468874557655, 4.12656096365633, 4.168744157327249, 4.209954230361199, 4.25024396781867, 4.2896617474427785, 4.328252028864538, 4.3660557758340275, 4.403110822283529, 4.439452191035541, 4.47511237238665, 4.510121568534121, 4.5445079087955556, 4.578297639749466, 4.611515293755458, 4.644183838765212, 4.676324811885343, 4.7079584387811995, 4.7391037407019265, 4.76977863064964, 4.800000000000001, 4.829783796700246, 4.859145096017806, 4.8880981646830834, 4.916656519159892, 4.944832978683115, 4.972639713622818, 5.000088289665093, 5.027189708240518, 5.05395444357992, 5.080392476732706, 5.106513326844546, 5.1323260799577035, 5.15783941556801, 5.183061631146987, 5.208000664815146, 5.232664116332885, 5.257059266557994, 5.281193095503569, 5.305072299116577, 5.328703304885376, 5.352092286373841, 5.375245176770367, 5.398167681531552, 5.420865290192907, 5.443343287412226, 5.465606763305255, 5.487660623127917, 5.509509596354539, 5.531158245197171, 5.5526109726071935, 5.573872029796889, 5.594945523315436, 5.615835421710985, 5.636545561807772, 5.657079654624957, 5.6774412909616725, 5.697633946670837, 5.717660987642538, 5.737525674516146, 5.7572311671388565, 5.776780528787043, 5.796176730165528, 5.8154226531988025, 5.834521094627172, 5.853474769419861, 5.872286314016269, 5.890958289405757, 5.909493184055599, 5.927893416696112, 5.946161338971307, 5.964299237962859, 5.982309338594669, 6.0001938059248], [0.0, 1.5245344971379458, 1.8769221291029832, 2.119696254593611, 2.310762193528584, 2.470746889672295, 2.609652201831067, 2.7331701439859057, 2.84488196513136, 2.9472027167461508, 3.0418462300093747, 3.130077289952992, 3.212858729057578, 3.290942253200147, 3.3649271534893677, 3.4352997179920766, 3.5024605379971807, 3.56674394326228, 3.6284321597169837, 3.6877658332237857, 3.744951992330337, 3.8001701688287772, 3.8535771688634215, 3.905310839321559, 3.955493075145686, 4.004232245505531, 4.051625169668092, 4.097758740089475, 4.142711266331047, 4.186553595987178, 4.229350055971311, 4.271159247928168, 4.31203472431626, 4.3520255662024105, 4.391176879579173, 4.4295302237344645, 4.467123982636593, 4.503993688275699, 4.540172303297725, 4.575690468984522, 4.610576723602408, 4.644857695307039, 4.678558273113557, 4.711701758885562, 4.744310002839721, 4.77640352468548, 4.808001622206084, 4.839122468825861, 4.869783201490114, 4.9, 4.9297881587897034, 4.959162152001737, 4.98813569260452, 5.016721786201115, 5.0449327800964605, 5.072780408120521, 5.100275831644512, 5.127429677175377, 5.154252070868685, 5.180752670261034, 5.20694069348909, 5.232824946232642, 5.258413846593238, 5.283715448097113, 5.3087374609912485, 5.333487271983762, 5.357971962564344, 5.382198326026759, 5.406172883303261, 5.429901897710031, 5.453391388693144, 5.476647144656081, 5.499674734942135, 5.52247952103834, 5.545066667061391, 5.567441149580646, 5.589607766828315, 5.611571147342649, 5.633335758085874, 5.654905912075103, 5.6762857755612135, 5.697479374787771, 5.718490602359404, 5.73932322324669, 5.759980880452395, 5.78046710036197, 5.800785297799376, 5.820938780807699, 5.8409307551725265, 5.86076432870465, 5.880442515297497, 5.899968238773457, 5.9193443365323155, 5.9385735630139695, 5.957658592986818, 5.97660202467231, 5.995406382715475, 6.014074121010534, 6.03260762539009, 6.051009216185795, 6.069281150667864, 6.087425625370338], [0.0, 1.5462474735549583, 1.9036539387158782, 2.1498857418591495, 2.3436729115920993, 2.505936168136361, 2.646819820419783, 2.772096950162781, 2.8853998118144264, 2.989177852897546, 3.0851693136000478, 3.174656992483676, 3.25861743504041, 3.337813053216566, 3.412851673443388, 3.4842265096797442, 3.552343858581804, 3.617542811553529, 3.680109614089166, 3.7402883394173645, 3.798288964661869, 3.854293578572091, 3.908461220582651, 3.9609317008464915, 4.011828650378342, 4.061261981781177, 4.109329893257313, 4.1561205148169105, 4.201713271334676, 4.246180019442261, 4.289586002220474, 4.331990655940038, 4.3734482957731124, 4.414008701816979, 4.453717622480188, 4.492617208953198, 4.5307463918827935, 4.568141209318678, 4.604835093372823, 4.640859121731394, 4.676242239113106, 4.711011452921522, 4.745192006650216, 4.778807534036429, 4.811880196495585, 4.844430805986316, 4.876478935137936, 4.908043016207311, 4.939140430210371, 4.969787587386903, 5.0, 5.029792348338193, 5.059178540675002, 5.08817176784403, 5.116784553005037, 5.145028797105475, 5.1729158204808785, 5.2004564009847805, 5.227660808993147, 5.254538839588743, 5.281099842196291, 5.30735274790929, 5.333306094722957, 5.358968050864787, 5.384346436393912, 5.409448743222638, 5.434282153697819, 5.458853557865786, 5.483169569532287, 5.507236541217938, 5.531060578099961, 5.55464755102239, 5.5780031086491375, 5.601132688827491, 5.624041529223381, 5.646734677284277, 5.669216999580567, 5.691493190571832, 5.7135677808404, 5.735445144830949, 5.757129508131623, 5.778624954329215, 5.799935431468248, 5.821064758141385, 5.842016629236365, 5.86279462136271, 5.883402197979545, 5.903842714244317, 5.924119421600577, 5.944235472121694, 5.964193922626063, 5.983997738578223, 6.003649797789237, 6.023152893928741, 6.042509739860164, 6.061722970809771, 6.080795147379505, 6.099728758412846, 6.118526223722295, 6.137189896686513, 6.155722066724581, 6.174124961654378], [0.0, 1.567830552236559, 1.9302258254575144, 2.1798946207201233, 2.376386741506099, 2.540914926978636, 2.683765083980215, 2.810790876983455, 2.925675260752163, 3.030901873079166, 3.128233217134454, 3.2189699972437342, 3.3041023898723916, 3.3844034489870567, 3.4604894852790387, 3.5328605971651355, 3.6019287525364567, 3.6680377759568086, 3.731477908438058, 3.7924966300708136, 3.8513068489150775, 3.9080931953805536, 3.963016928831524, 4.016219810941359, 4.067827198410982, 4.1179505380430355, 4.166689398725681, 4.214133140619477, 4.260362297240114, 4.305449728219965, 4.349461587326242, 4.392458140462521, 4.434494460951683, 4.475621023739521, 4.515884215807337, 4.555326776707071, 4.593988180493489, 4.631904968248359, 4.669111038741105, 4.705637903451416, 4.741514911118811, 4.7767694461259085, 4.811427104324052, 4.84551184933869, 4.8790461519222585, 4.912051114534201, 4.944546583005629, 4.97655124687749, 5.008082729776183, 5.03915767100153, 5.069791799342376, 5.1000000000000005, 5.129796375384611, 5.159194300452213, 5.188206473165336, 5.216844960589142, 5.2451212410724795, 5.273046242910041, 5.300630379835399, 5.327883583654602, 5.354815334295014, 5.381434687513548, 5.4077503004818315, 5.433770455442419, 5.45950308160964, 5.4849557754706115, 5.510135819625966, 5.535050200295783, 5.5597056236036915, 5.584108530741074, 5.608265112103417, 5.632181320482105, 5.655862883387136, 5.679315314569225, 5.70254392480353, 5.7255538319916095, 5.74834997063319, 5.770937100714809, 5.793319816058295, 5.8155025521683985, 5.837489593615542, 5.859285080986693, 5.880893017434603, 5.902317274853221, 5.923561599704863, 5.944629618522651, 5.965524843109922, 5.986250675456614, 6.006810412391101, 6.0272072499845235, 6.047444287723451, 6.067524532465439, 6.087450902191077, 6.107226229565047, 6.126853265317899, 6.146334681459336, 6.165673074333106, 6.184870967522859, 6.2039308146177135, 6.222855001845633, 6.241645850582237, 6.260305619742086], [0.0, 1.589287035008061, 1.9566418543516808, 2.20972748199869, 2.4089086879019095, 2.5756885173240955, 2.720493644477416, 2.849257843927209, 2.965714473368468, 3.0723811603204214, 3.171044528620211, 3.2630230833309484, 3.3493205519387215, 3.430720568009525, 3.5078478767301644, 3.581209420594464, 3.65122280546375, 3.7182365612992445, 3.782544901194659, 3.844398692119555, 3.9040137558787364, 3.9615772496340487, 4.017252639658401, 4.071183627698915, 4.123497286020669, 4.174306586627096, 4.223712461052425, 4.271805492392142, 4.318667316300169, 4.364371789526486, 4.40898597118306, 4.452570951940095, 4.495182558824249, 4.536871957554179, 4.577686169938378, 4.617668520439228, 4.656859023332103, 4.695294719780297, 4.733009972473494, 4.770036724140489, 4.80640472517181, 4.842141734717956, 4.877273698921278, 4.911824909360471, 4.945818144310558, 4.979274795027855, 5.012214978942809, 5.044657641371334, 5.076620647127271, 5.108120863226919, 5.1391742337148365, 5.169795847503137, 5.2, 5.229800249203863, 5.259209466854715, 5.28823988516106, 5.316903139558235, 5.345210307899675, 5.373171946435689, 5.400798122893664, 5.428098446938134, 5.455082098258211, 5.481757852502904, 5.5081341052610675, 5.534218894261978, 5.560019919954178, 5.585544564604041, 5.610799910041282, 5.635792754165921, 5.660529626320009, 5.685016801617442, 5.709260314316297, 5.733265970310182, 5.757039358808028, 5.780585863265397, 5.803910671624684, 5.8270187859165175, 5.84991503127004, 5.872604064375649, 5.895090381440015, 5.917378325669882, 5.939472094318056, 5.9613757453222735, 5.983093203565139, 6.004628266781027, 6.0259846111338335, 6.047165796487543, 6.068175271389892, 6.089016377787865, 6.109692355492311, 6.1302063464076975, 6.150561398541811, 6.170760469809147, 6.190806431640708, 6.21070207241206, 6.230450100700585, 6.250053148382193, 6.269513773576938, 6.2888344634524325, 6.30801763689327, 6.327065647044162, 6.345980783733958], [0.0, 1.610620078046958, 1.9829059111086653, 2.239388714009855, 2.4412435346500447, 2.610262054252614, 2.7570109045608895, 2.8875035093573715, 3.005523339298799, 3.1136218160869733, 3.213609545459331, 3.306822730808259, 3.394278572681153, 3.476771223378651, 3.554933814059168, 3.629280091919394, 3.7002332683554733, 3.7681465516557657, 3.8333181041443303, 3.8960021601848744, 3.9564174385641513, 4.014753608659673, 4.071176330956568, 4.125831236114416, 4.1788471020927584, 4.230338417321301, 4.280407468140996, 4.329146053546682, 4.376636904989881, 4.422954870601733, 4.468167909630486, 4.512337932768073, 4.5555215164088425, 4.5977705130702855, 4.639132575735908, 4.679651610413526, 4.7193681684912185, 4.758319788336821, 4.796541293891335, 4.834065056651672, 4.870921226348659, 4.907137934744625, 4.942741476257699, 4.977756468533091, 5.012205995599233, 5.046111735847853, 5.079494076746213, 5.112372217913719, 5.144764263964094, 5.176687308320051, 5.208157509043495, 5.239190157585416, 5.269799741241645, 5.300000000000001, 5.32980397837819, 5.35922407277798, 5.388272074817476, 5.416959211048439, 5.445296179418011, 5.47329318279296, 5.500959959828606, 5.528305813433279, 5.555339637051762, 5.582069938967125, 5.608504864799307, 5.634652218360177, 5.660519481008471, 5.6861138296334985, 5.711442153383675, 5.736511069244586, 5.7613269365611535, 5.7858958705894645, 5.810223755155794, 5.834316254493176, 5.858178824319442, 5.881816722214881, 5.9052350173525125, 5.928438599629321, 5.951432188242582, 5.974220339751674, 5.99680745566232, 6.019197789567166, 6.041395453873757, 6.0634044261485025, 6.085228555102869, 6.106871566246002, 6.128337067226035, 6.149628552880654, 6.17074941001589, 6.191702921930661, 6.212492272703303, 6.233120551255094, 6.253590755204694, 6.2739057945264065, 6.294068495024234, 6.3140816016328705, 6.333947781555963, 6.353669627251284, 6.373249659271762, 6.392690328970747, 6.411994021079274, 6.431163056162627], [0.0, 1.6318327009279796, 2.0090217132610277, 2.2688825151376233, 2.4733958585699467, 2.6446404314578977, 2.793322033047647, 2.9255332867372106, 3.0451074932688424, 3.1546296777664735, 3.25593429249548, 3.3503751392744974, 3.4389828156598745, 3.5225619333110334, 3.6017539620211076, 3.6770794152786554, 3.7489670783726776, 3.8177748115105805, 3.8838047039542674, 3.947314338453422, 4.008525314423943, 4.067629799278126, 4.1247956353274935, 4.180170371255809, 4.2338844810888245, 4.2860539611226365, 4.336782444857346, 4.386162940323672, 4.434279268585205, 4.481207263558129, 4.527015779545908, 4.571767542633366, 4.615519874352536, 4.658325310142918, 4.700232130600193, 4.7412848199949185, 4.7815244637960035, 4.8209890947692156, 4.859713995503215, 4.897731963842734, 4.935073546604712, 4.971767246060002, 5.007839702936568, 5.043315859105571, 5.078219102622938, 5.112571397394999, 5.146393399401534, 5.179704561129953, 5.212523225640247, 5.244866711483534, 5.2767513895309826, 5.308192752629173, 5.33920547887843, 5.369803489228661, 5.4, 5.429807570860648, 5.459238148729856, 5.488303108018346, 5.517013287570251, 5.5453790246288825, 5.573410186112226, 5.601116197452285, 5.628506069224684, 5.655588421770582, 5.6823715079915535, 5.708863234479337, 5.7350711811256785, 5.761002619342887, 5.7866645290126995, 5.812063614269511, 5.837206318213802, 5.862098836642454, 5.886747130874496, 5.911156939743575, 5.935333790821885, 5.959283010934519, 5.983009736017886, 6.0065189203712075, 6.029815345345807, 6.052903627513088, 6.075788226348673, 6.09847345146702, 6.120963469438013, 6.143262310214477, 6.16537387319722, 6.18730193296209, 6.209050144671641, 6.230622049192214, 6.252021077935665, 6.273250557443501, 6.294313713729865, 6.31521367639858, 6.3359534825483514, 6.356536080479209, 6.376964333212324, 6.397241021834467, 6.417368848677612, 6.437350440343416, 6.457188350581676, 6.476885063031213, 6.496442993831093, 6.515864494109534], [0.0, 1.652927794949702, 2.0349928204148573, 2.298212905412222, 2.505370042050766, 2.6788283347420565, 2.8294319791754456, 2.9633523595577915, 3.0844723306325186, 3.195410334765415, 3.2980245386277485, 3.393686244960053, 3.4834393741012994, 3.5680989391194595, 3.6483147022420503, 3.7246139057607577, 3.7974308779751986, 3.8671281052377995, 3.9340115819910495, 3.9983422208188237, 4.060344485805998, 4.12021302855925, 4.178117861128056, 4.234208439593521, 4.288616924650527, 4.3414608121072025, 4.392845075158845, 4.442863924173367, 4.491602263789423, 4.539136908246476, 4.585537601944146, 4.630867881842444, 4.675185810482647, 4.718544602442522, 4.760993162452628, 4.802576549842398, 4.843336381202477, 4.883311180957354, 4.922536687802201, 4.961046123567382, 4.9988704299558915, 5.036038477694295, 5.0725772519016585, 5.1085120168787155, 5.143866463024418, 5.178662838177798, 5.212922065343459, 5.246663848475798, 5.279906767759953, 5.312668365628122, 5.3449652245816655, 5.376813037746919, 5.408226672971542, 5.439220231164912, 5.4698070994977135, 5.500000000000001, 5.529811034031726, 5.559251723043355, 5.588333045995366, 5.617065473763105, 5.6454590008165795, 5.67352317443262, 5.701267121668731, 5.728699574303295, 5.755828891925135, 5.7826630833364, 5.809209826415921, 5.835476486575304, 5.8614701339268995, 5.887197559271058, 5.91266528899977, 5.937879599004477, 5.9628465276676135, 5.987571888010108, 6.012061279060412, 6.036320096504767, 6.060353542673068, 6.084166635909957, 6.107764219376436, 6.131150969323436, 6.154331402875295, 6.177309885357894, 6.2000906372033695, 6.222677740460718, 6.245075144939236, 6.267286674009624, 6.289316030085601, 6.3111667998071415, 6.3328424589447865, 6.354346377043046, 6.375681821819525, 6.396851963335186, 6.417859877950043, 6.438708552077509, 6.459400885749717, 6.479939696005217, 6.50032772010968, 6.520567618619472, 6.540661978297329, 6.560613314888672, 6.580424075766573, 6.600096642452852], [0.0, 1.6739081308117671, 2.0608226437015387, 2.327383737184428, 2.5371702846878503, 2.712830254457742, 2.865345485744421, 3.000965695101621, 3.1236230216981773, 3.2359691433505966, 3.339885812128717, 3.436761736489251, 3.5276540870773196, 3.613388221785362, 3.6946221501641037, 3.7718898067033977, 3.8456310325592775, 3.916212915062774, 3.983945332592622, 4.049092509452458, 4.111881758812219, 4.172510202958849, 4.2311500118763155, 4.287952538666746, 4.343051621518603, 4.396566247594645, 4.44860272249737, 4.499256452391121, 4.548613419594919, 4.596751413338518, 4.643741063275524, 4.689646712829953, 4.734527161521197, 4.778436299370754, 4.821423651848743, 4.863534850215123, 4.9048120392929615, 4.945294232490818, 4.985017622129142, 5.024015851717429, 5.062320255696532, 5.099960071244317, 5.13696262599745, 5.173353504932204, 5.209156699145802, 5.244394738865372, 5.279088812667715, 5.31325887460622, 5.346923740701208, 5.380101176048034, 5.41280797362697, 5.445060025754579, 5.476872388993622, 5.508259343233961, 5.539234445567396, 5.569810579502579, 5.6000000000000005, 5.629814374749967, 5.659264822067065, 5.68836194573171, 5.717115867072043, 5.745536254546883, 5.773632351061948, 5.801412999226621, 5.828886664736586, 5.856061458048378, 5.88294515449486, 5.909545212975576, 5.9358687933426255, 5.961922772590854, 5.987713759950653, 6.013248110972302, 6.038531940682415, 6.063571135885622, 6.088371366677906, 6.112938097232051, 6.137276595910252, 6.161391944754162, 6.185289048398214, 6.208972642448211, 6.232447301363593, 6.2557174458785925, 6.278787349994583, 6.301661147573328, 6.324342838558391, 6.3468362948498775, 6.369145265855625, 6.391273383740226, 6.413224168391599, 6.435001032123316, 6.456607284129575, 6.478046134708393, 6.499320699267505, 6.52043400212637, 6.5413889801267455, 6.562188486063378, 6.582835291945594, 6.603332092099758, 6.623681506121951, 6.643886081689527, 6.663948297239661, 6.683870564522427], [0.0, 1.6947763657040333, 2.0865144545055214, 2.3563987049822432, 2.5688006140278885, 2.746650496997227, 2.9010671012520843, 3.038378057152006, 3.1625645249574252, 3.276311240353744, 3.381523414789174, 3.4796070694353487, 3.571632554445234, 3.658435517261845, 3.7406821706924727, 3.818913105667755, 3.893573646744153, 3.9650354576476072, 4.033612279940666, 4.099571631951727, 4.163143660712716, 4.224527945989642, 4.283898804170806, 4.341409475243301, 4.397195465926083, 4.451377246768011, 4.504062448659539, 4.55534766717213, 4.605319956546973, 4.65405807579459, 4.701633535092541, 4.748111480019786, 4.7935514431360575, 4.838007986297588, 4.881531252397355, 4.924167441569938, 4.965959224048402, 5.006946099612666, 5.047164711784671, 5.086649123499952, 5.125431059838764, 5.163540122472274, 5.201003979724622, 5.237848535534211, 5.274098080089856, 5.309775424497943, 5.344902021488475, 5.379498073877526, 5.413582632260494, 5.447173683206166, 5.480288229049112, 5.512942360231818, 5.545151321023816, 5.57692956933913, 5.6082908312827655, 5.63924815097917, 5.669813936168658, 5.7, 5.729817599397301, 5.759277470335913, 5.788389860324291, 5.817164558355748, 5.845610922565222, 5.873737905800912, 5.901554079298418, 5.929067654625508, 5.9562865040483635, 5.983218179454947, 6.009869929957617, 6.036248718285162, 6.062361236063759, 6.088213918076896, 6.113812955585845, 6.1391643087847, 6.164273718457252, 6.189146716896892, 6.213788638145301, 6.238204627600797, 6.262399651042781, 6.286378503114786, 6.310145815305008, 6.333706063459972, 6.357063574864065, 6.38022253491497, 6.403186993422645, 6.425960870557301, 6.448547962469795, 6.470951946606099, 6.493176386735775, 6.515224737712942, 6.5371003499867735, 6.558806473877349, 6.580346263631487, 6.601722781272156, 6.622939000254054, 6.643997808937081, 6.664902013888573, 6.685654343024455, 6.706257448598722, 6.726713910050047, 6.747026236713719, 6.767196870406559], [0.0, 1.7155350498622057, 2.1120713925352472, 2.385261354625775, 2.6002648955053873, 2.780293195416831, 2.9366011911150496, 3.0755940177459213, 3.2013015993183602, 3.3164415558447327, 3.4229424349983173, 3.5222274797801356, 3.61538015066332, 3.7032463306250176, 3.7865003926649363, 3.8656895492105763, 3.9412645794329446, 4.013601699428462, 4.0830184936631655, 4.149785757197766, 4.214136456049423, 4.276272614562326, 4.336370684261259, 4.394585782112813, 4.451055074607249, 4.505900507892287, 4.559231031189051, 4.611144423232162, 4.661728804557769, 4.711063898866166, 4.7592220922364294, 4.806269328191441, 4.852265868483071, 4.8972669432754, 4.941323309643014, 4.984481733608725, 5.026785408057382, 5.068274316586989, 5.108985551552334, 5.148953593113154, 5.188210554938391, 5.226786401279051, 5.264709139358266, 5.302004990402127, 5.3386985421209205, 5.374812885025775, 5.41036973461319, 5.445389541156001, 5.479891588593254, 5.513894083804514, 5.547414237379611, 5.580468336846864, 5.613071813197182, 5.6452393014341915, 5.676984695788843, 5.708321200158201, 5.739261374260372, 5.76981717593898, 5.800000000000001, 5.829820713919745, 5.859289690724584, 5.888416839309559, 5.917211632433917, 5.945683132605957, 5.973840016047151, 6.001690594905702, 6.029242837872244, 6.056504389335001, 6.0834825871980085, 6.110184479473927, 6.136616839752165, 6.162786181633479, 6.188698772213591, 6.214360644690793, 6.2397776101655955, 6.264955268694393, 6.289899019653552, 6.314614071465456, 6.339105450733492, 6.363378010828995, 6.3874364399695285, 6.4112852688245985, 6.434928877681884, 6.458371503204444, 6.481617244806852, 6.50467007067602, 6.527533823460445, 6.550212225649762, 6.572708884664821, 6.5950272976769595, 6.617170856173755, 6.639142850287246, 6.660946472899446, 6.682584823538901, 6.704060912081049, 6.725377662264231, 6.746537915032383, 6.767544431714655, 6.788399897051513, 6.809106922076213, 6.829668046859957, 6.850085743128469], [0.0, 1.7361866326385886, 2.1374964732971207, 2.41397509166794, 2.6315668416442115, 2.8137623192755226, 2.9719519480607666, 3.112617968057592, 3.239838815433997, 3.356364824867458, 3.4641477598564943, 3.564627996378017, 3.658902037584553, 3.7478259491786465, 3.8320822222511093, 3.9122246565636627, 3.9887094577595765, 4.061917370818467, 4.1321698032829595, 4.1997408100402644, 4.26486616154863, 4.327750314117987, 4.388571843393678, 4.447487733637795, 4.5046368025485535, 4.560142464259402, 4.614114979520399, 4.666653304124968, 4.717846619402826, 4.767775608766863, 4.816513529678588, 4.864127119487928, 4.910677365376734, 4.956220162368894, 5.000806878551827, 5.044484842916958, 5.087297768304378, 5.129286119633986, 5.1704874357777255, 5.210936611966934, 5.250666148454373, 5.289706370200208, 5.328085621578067, 5.365830439464727, 5.402965707556929, 5.4395147943289945, 5.475499676688215, 5.510941051087475, 5.545858433605559, 5.580270250296153, 5.6141939189298835, 5.6476459231040685, 5.680641879567632, 5.713196599500135, 5.7453241443910485, 5.777037877085738, 5.808350508495987, 5.839274140413748, 5.869820304815481, 5.900000000000001, 5.929823723863997, 5.959301504585628, 5.988442928957062, 6.017257168580924, 6.045753004122898, 6.073938847792688, 6.101822764207898, 6.129412489779771, 6.156715450745911, 6.183738779962838, 6.210489332560321, 6.2369737005497345, 6.263198226469995, 6.289169016146937, 6.314891950635005, 6.340372697403978, 6.365616720827828, 6.390629292027843, 6.415415498117577, 6.439980250893169, 6.46432829500887, 6.488464215674311, 6.512392445907002, 6.536117273370883, 6.559642846829212, 6.582973182237871, 6.606112168503095, 6.629063572925789, 6.651831046352876, 6.674418128054583, 6.696828250345163, 6.719064742963207, 6.741130837226591, 6.763029669975934, 6.784764287319505, 6.80633764819156, 6.827752627735273, 6.849012020520625, 6.870118543606947, 6.891074839459068, 6.911883478725527, 6.932546962886643], [0.0, 1.7567334681314133, 2.162792595026029, 2.442543189221426, 2.66271002059005, 2.8470616837581297, 3.0071234017636335, 3.1494541284906985, 3.278180566206967, 3.3960855983223537, 3.5051440864071925, 3.606813452513794, 3.702203176320057, 3.7921794546059306, 3.877432855377405, 3.9585237323186826, 4.035913690021582, 4.1099879793778795, 4.181071811615693, 4.249442484914502, 4.315338559949185, 4.378966912660197, 4.4405082320396465, 4.500121360173978, 4.557946757594243, 4.614109298973817, 4.668720549939462, 4.721880637373226, 4.77367979801792, 4.824199670131254, 4.873514378137413, 4.921691449186986, 4.9687925922123375, 5.014874363724914, 5.0599887397258385, 5.104183609319705, 5.147503202664569, 5.189988463560906, 5.231677375133028, 5.2726052455785775, 5.312804959773336, 5.352307201557073, 5.391140650743838, 5.429332158260084, 5.466906902287723, 5.50388852785441, 5.5402992719523185, 5.5761600759657295, 5.611490686935729, 5.64630974897844, 5.6806348859944436, 5.714482776655571, 5.7478692225265755, 5.780809210069364, 5.81331696718358, 5.845406014856678, 5.87708921442725, 5.90837881090545, 5.939286472742482, 5.969823328396114, 6.0, 6.029826634410397, 6.059312931874003, 6.088468172534431, 6.117301240971823, 6.145820648949864, 6.17403455652657, 6.201950791669454, 6.229576868501649, 6.256920004293199, 6.283987135300646, 6.310784931548278, 6.337319810635549, 6.363597950647461, 6.389625302237574, 6.4154075999471285, 6.440950372818023, 6.466258954352433, 6.491338491867166, 6.516193955286829, 6.540830145416106, 6.565251701728117, 6.589463109702754, 6.613468707746152, 6.637272693719953, 6.660879131106719, 6.684291954835799, 6.707514976792078, 6.730551891028292, 6.753406278700028, 6.776081612741132, 6.798581262295862, 6.820908496923004, 6.843066490586, 6.865058325442171, 6.886886995443172, 6.908555409757948, 6.9300663960287165, 6.951422703469743, 6.9726270058180075, 6.993681904144294, 7.014589929532594], [0.0, 1.7771778204116564, 2.1879625451203055, 2.4709687952259993, 2.6936978640327887, 2.8801949581462165, 3.0421194277921075, 3.1861065580489614, 3.3163310765431016, 3.4356082530707788, 3.5459359320659094, 3.6487884966340296, 3.7452883382542863, 3.8363117342523863, 3.9225572892635787, 4.004591878204983, 4.082882477688171, 4.1578188220425565, 4.229729907209777, 4.298896258484736, 4.365559212841943, 4.429928053783772, 4.4921855731081815, 4.552492461459537, 4.61099081400763, 4.667806958680901, 4.7230537594743724, 4.776832508517572, 4.829234492702234, 4.880342300368328, 4.9302309185784905, 4.978968660344616, 5.026617952749643, 5.073236010493223, 5.118875414458034, 5.163584611068121, 5.207408345219228, 5.250388037203854, 5.292562112182846, 5.3339662892603625, 5.3746338360167885, 5.414595793381481, 5.45388117493581, 5.492517144089486, 5.53052917204077, 5.567941178991256, 5.604775660720756, 5.641053802323279, 5.676795580650222, 5.712019856792502, 5.746744459752516, 5.780986262303622, 5.814761249904578, 5.848084583425369, 5.880970656345791, 5.913433147006608, 5.945485066422926, 5.977138802108759, 6.008406158309345, 6.039298392992204, 6.069826251908284, 6.1000000000000005, 6.129829450402696, 6.159323991259591, 6.188492610546983, 6.217343919085982, 6.245886171898983, 6.274127288053103, 6.302074869118652, 6.3297362163581585, 6.357118346750299, 6.38422800794316, 6.4110716922223485, 6.437655649571619, 6.463985899896506, 6.490068244475166, 6.515908276694881, 6.5415113921275685, 6.566882797993009, 6.592027522054345, 6.616950420986627, 6.64165618825581, 6.666149361542495, 6.690434329741924, 6.714515339569231, 6.7383965017966005, 6.762081797146945, 6.785575081866757, 6.808880092999079, 6.832000453375945, 6.854939676348192, 6.877701170269197, 6.900288242747921, 6.922704104685466, 6.944951874108403, 6.967034579811123, 6.9889551648186305, 7.010716489680423, 7.0323213356053165, 7.053772407446467, 7.075072336545158, 7.096223683441403], [0.0, 1.7975218683822294, 2.2130090061240977, 2.4992549392046715, 2.724533674571669, 2.9131656736931597, 3.0769437559265196, 3.2225791630476506, 3.354294412419006, 3.4749370013287213, 3.586527644315513, 3.690557602323636, 3.7881621152854583, 3.880227491615161, 3.9674603331478506, 4.05043400403902, 4.129620826563728, 4.205414996492332, 4.2781492759113915, 4.3481074013983205, 4.415533472606147, 4.48063916878716, 4.543609374228353, 4.6046066190626025, 4.663774625078553, 4.721241166329735, 4.777120398809363, 4.831514774177496, 4.884516624322537, 4.9362094830054115, 4.98666919569492, 5.03596485740866, 5.08415960985675, 5.131311322697832, 5.177473178728466, 5.222694178957815, 5.267019580493909, 5.310491277783492, 5.353148135855224, 5.395026282703786, 5.436159366736536, 5.476578784220462, 5.516313880866722, 5.555392131035176, 5.593839297502829, 5.631679574295159, 5.668935714709947, 5.705629146355238, 5.741780074765242, 5.777407576941145, 5.81252968598089, 5.847163467807057, 5.881325090870186, 5.91502988959266, 5.948292422222049, 5.981126523680426, 6.0135453539250605, 6.045561442274676, 6.07718672810231, 6.108432598249829, 6.139309921478987, 6.169829080239, 6.2, 6.229832176374946, 6.259334700229006, 6.288516280954721, 6.317385268072949, 6.345949671303456, 6.374217179234696, 6.402195176709597, 6.4298907610329294, 6.457310757095739, 6.484461731503361, 6.511350005785552, 6.537981668760053, 6.564362588114517, 6.590498421265912, 6.616394625551373, 6.642056467799757, 6.667489033328973, 6.692697234410325, 6.717685818237706, 6.742459374436316, 6.767022342142795, 6.791379016686079, 6.8155335558959695, 6.839489986064266, 6.863252207581418, 6.8868240002698595, 6.910209028433596, 6.933410845642162, 6.956432899265688, 6.979278534776622, 7.001950999832504, 7.024453448153175, 7.046788943204813, 7.068960461702384, 7.090970896941205, 7.1128230619676795, 7.13451969259847, 7.156063450296854, 7.177456924914341], [0.0, 1.8177677103009144, 2.237934561295751, 2.527404538552339, 2.7552206325707704, 2.9459772309542753, 3.111599977901298, 3.2588757052222554, 3.39207448932215, 3.5140758994104497, 3.6269234097306824, 3.7321250775920682, 3.830828929357348, 3.923931256106482, 4.012146618269854, 4.096054837916075, 4.176133557178774, 4.252781411732709, 4.326334911629187, 4.397080989226435, 4.465266493519825, 4.531105487946646, 4.594784939181937, 4.6564692079673895, 4.716303634858386, 4.774417433052724, 4.830926044304995, 4.885933074208428, 4.93953189460363, 4.991806980108678, 5.042835030454793, 5.092685918890327, 5.141423498302881, 5.189106290148435, 5.235788076231832, 5.281518409470227, 5.326343056711347, 5.370304384267323, 5.413441694911264, 5.455791523554556, 5.4973878975931765, 5.538262566916436, 5.578445207762004, 5.617963603938852, 5.6568438083952035, 5.695110287658598, 5.732786051301679, 5.7698927682758505, 5.806450871694225, 5.842479653425997, 5.877997349679438, 5.913021218593963, 5.94756761072855, 5.981652033220191, 6.015289208288859, 6.048493126682074, 6.081277096580289, 6.113653788422401, 6.145635276056958, 6.1772330745780595, 6.208458175164459, 6.239321077204938, 6.269831817962147, 6.300000000000001, 6.329834816575868, 6.359345075177887, 6.3885392193692105, 6.417425349084652, 6.446011239510746, 6.474304358667359, 6.5023118837975975, 6.530040716662597, 6.55749749782866, 6.584688620026172, 6.6116202406524245, 6.638298293483992, 6.6647284996584375, 6.690916377979959, 6.71686725459874, 6.742586272109625, 6.768078398111793, 6.793348433267718, 6.818401018896447, 6.843240644133488, 6.867871652686913, 6.892298249216974, 6.916524505364389, 6.940554365450471, 6.964391651870535, 6.9880400702003636, 7.011503214034043, 7.0347845695701094, 7.057887519961725, 7.0808153494454364, 7.103571247262047, 7.12615831138216, 7.148579552048064, 7.1708378951428315, 7.192936185396758, 7.21487718944055, 7.236663598714064, 7.25829803223882], [0.0, 1.8379173679952558, 2.262741699796952, 2.555420404396124, 2.785761802547597, 2.978632906617711, 3.1460915546198946, 3.294999809284905, 3.4296750801161378, 3.553028855876672, 3.6671272623877247, 3.773495073527082, 3.8732930413419058, 3.967427392152151, 4.0566206071736755, 4.141458935707865, 4.222425314473261, 4.299922797955863, 4.374291626365845, 4.445821912659684, 4.514763242113484, 4.581332051022718, 4.645717378557431, 4.708085407371247, 4.768583089095827, 4.82734106923613, 4.88447606919971, 4.940092843030851, 4.994285797581734, 5.04714034385776, 5.0987340317941205, 5.149137509172698, 5.198415336679908, 5.246626684472491, 5.2938259305178015, 5.340063177018975, 5.385384698141758, 5.4298333298219195, 5.4734488104973815, 5.516268080063042, 5.558325543102998, 5.599653301448891, 5.640281360294628, 5.680237811428157, 5.719548996590372, 5.758239653516267, 5.7963330468358345, 5.83385108569726, 5.870814429711372, 5.907242584594578, 5.943153988700537, 5.978566091472315, 6.013495424712161, 6.0479576674511435, 6.081967705102637, 6.115539683499307, 6.1486870583406095, 6.181422640515188, 6.213758637708221, 6.2457066926567455, 6.277277918374933, 6.308482930635571, 6.339331877962725, 6.369834469363161, 6.4, 6.429837374990947, 6.459355131494669, 6.488561459232433, 6.517464219577445, 6.546070963331347, 6.574388947295817, 6.602425149736877, 6.630186284830424, 6.657678816169214, 6.6849089694042805, 6.711882744087139, 6.738605924773228, 6.765084091441786, 6.791322629282501, 6.817326737895038, 6.843101439943604, 6.868651589305228, 6.893981878747219, 6.91909684716642, 6.944000886420195, 6.968698247776769, 6.993193048010329, 7.017489275164344, 7.041590794004758, 7.065501351183053, 7.089224580127719, 7.112764005681233, 7.1361230484984555, 7.159305029221157, 7.182313172442356, 7.205150610473152, 7.2278203869238755, 7.2503254601105365, 7.272668706296799, 7.2948529227810175, 7.316880830837222, 7.338755078518354], [0.0, 1.857972790794881, 2.2874328215339808, 2.58330524706283, 2.81616013913336, 3.011135859877386, 3.1804218228860113, 3.3309549699741883, 3.4670998223786778, 3.591799639136423, 3.7071430917105848, 3.8146715923683168, 3.9155585593263678, 4.010720107680062, 4.100886602387205, 4.186650689923401, 4.268500576830661, 4.346843715740549, 4.422024059577094, 4.494334887020161, 4.564028506829687, 4.631323717062066, 4.696411619689809, 4.759460210757848, 4.820618045439527, 4.88001719484842, 4.937775654060429, 4.993999320199874, 5.048783630290023, 5.1022149273443524, 5.154371607525835, 5.205325089527581, 5.2551406385246215, 5.3038780703406525, 5.351592356317434, 5.39833414537521, 5.444150216625147, 5.48908387343034, 5.533175287856027, 5.576461802886617, 5.61897819853031, 5.660756926915129, 5.7018283206527745, 5.742220778069834, 5.781960928349259, 5.821073779165127, 5.859582849011942, 5.8975102861113315, 5.934876975512564, 5.971702635779154, 6.008005906464763, 6.043804427421427, 6.079114910847038, 6.1139532068628375, 6.148334363312385, 6.1822726803881975, 6.215781760618826, 6.248874554685808, 6.281563403485038, 6.313860076799532, 6.345775808909088, 6.3773213314262, 6.408506903616008, 6.439342340430319, 6.469837038461423, 6.5, 6.52983985536251, 6.559364883636765, 6.588583031979566, 6.617501933587188, 6.646128924447793, 6.674471058974509, 6.702535124608565, 6.730327655473684, 6.757854945155437, 6.785123058672666, 6.812137843702097, 6.838904941111908, 6.865429794855178, 6.891717661269798, 6.917773617827473, 6.943602571370918, 6.969209265875097, 6.994598289765463, 7.019774082823489, 7.0447409427074, 7.069503031113775, 7.094064379603762, 7.118428895115775, 7.142600365184898, 7.166582462887726, 7.190378751529949, 7.213992689092741, 7.2374276324528415, 7.260686841390144, 7.283773482395645, 7.306690632291667, 7.32944128167547, 7.352028338196617, 7.374454629677687, 7.3967229070873515, 7.418835847374206], [0.0, 1.8779358592042297, 2.3120102416793724, 2.6110616811854634, 2.8464184926397897, 3.0434891383852256, 3.214594001690468, 3.366744558639588, 3.5043522252551345, 3.6303918845471195, 3.7469746497989034, 3.8556584950479125, 3.957629446353298, 4.053813462048353, 4.144948754528524, 4.231634337984916, 4.314363664515684, 4.3935485646446875, 4.469536686912909, 4.542624461145582, 4.613066907044944, 4.681085173552499, 4.746872415944105, 4.810598435305411, 4.872413382967197, 4.9324507490867875, 4.9908297965432435, 5.047657560277081, 5.103030502738762, 5.157035894657979, 5.209752974528643, 5.261253928405076, 5.311604722706786, 5.360865815951155, 5.409092770121883, 5.456336778338711, 5.502645122332974, 5.548061570742614, 5.592626727263345, 5.636378336112874, 5.679351550994696, 5.721579172720113, 5.763091859810878, 5.803918315720614, 5.844085455750671, 5.883618556271159, 5.922541388472053, 5.9608763385474965, 5.99864451594707, 6.035865851101239, 6.072559183837146, 6.108742343538981, 6.14443222196956, 6.179644839552432, 6.214395405813358, 6.248698374593888, 6.2825674945755265, 6.316015855588961, 6.349055931127373, 6.3816996174347205, 6.413958269497998, 6.445842734235975, 6.477363381144904, 6.508530130633764, 6.539352480256933, 6.569839529030589, 6.6000000000000005, 6.629842261207992, 6.659374345199933, 6.688603967187302, 6.717538541980103, 6.746185199787906, 6.774550800979895, 6.802641949885967, 6.83046500771339, 6.858026104646865, 6.885331151193729, 6.912385848830712, 6.93919570000368, 6.965766017527471, 6.992101933428905, 7.0182084072724775, 7.044090234004996, 7.069752051352445, 7.095198346799725, 7.12043346418143, 7.145461609909669, 7.170286858862871, 7.194913159957718, 7.219344341424626, 7.24358411580572, 7.267636084692781, 7.291503743221411, 7.315190484336454, 7.33869960284265, 7.3620342992534935, 7.385197683450354, 7.408192778163097, 7.431022522282648, 7.453689774015247, 7.476197313887467, 7.498547847610494], [0.0, 1.8978083883364973, 2.336476194899598, 2.638692230477756, 2.8765396142640283, 3.0756956838164045, 3.2486111980893253, 3.402371829397824, 3.5414356758664987, 3.668809101053003, 3.7866255582796384, 3.8964595082408673, 3.9995095276574077, 4.096711373458103, 4.1888110698852525, 4.276413969965715, 4.360018747563418, 4.440041591239287, 4.516833828390389, 4.590695025695811, 4.661882901505051, 4.730620944982663, 4.797104355395424, 4.8615047306832295, 4.923973811095183, 4.984646499396513, 5.043643320519522, 5.101072442060542, 5.157031347246572, 5.211608230316007, 5.264883168273444, 5.316929111054176, 5.367812723141801, 5.417595102832556, 5.466332400073321, 5.5140763497152046, 5.5608747338301585, 5.606771784220787, 5.651808534255696, 5.6960231275661615, 5.739451089856133, 5.7821255690388025, 5.824077548067854, 5.865336034140099, 5.905928227377642, 5.945879671627993, 5.98521438963054, 6.023955004472661, 6.062122848986512, 6.099738064508622, 6.136819690231311, 6.1733857442113225, 6.209453296962013, 6.245038538436861, 6.280156839110546, 6.314822805776799, 6.349050332607223, 6.382852647950571, 6.416242357295939, 6.4492314827746755, 6.481831499533533, 6.514053369274597, 6.5459075712253, 6.577404130773507, 6.60855264597779, 6.639362312141142, 6.66984194461708, 6.7, 6.7298445958365765, 6.759383528981524, 6.788624292709203, 6.817574092681867, 6.846239861865898, 6.874628274478959, 6.902745759043331, 6.93059851061402, 6.95819250224402, 6.985533495743728, 7.012627051786517, 7.039478539408029, 7.06609314494277, 7.092475880437908, 7.118631591580916, 7.144564965174723, 7.170280536191297, 7.1957826944321805, 7.22107569082221, 7.246163643360639, 7.271050542752029, 7.295740257737565, 7.32023654014591, 7.3445430296812955, 7.368663258465243, 7.392600655347121, 7.416358549997667, 7.439940176798568, 7.463348678540311, 7.486587109939628, 7.509658440987122, 7.532565560134892, 7.555311277333358, 7.577898326925846], [0.0, 1.9175921311276536, 2.360832839311983, 2.666199332202895, 2.9065261609601647, 3.1077583370781645, 3.282476412705541, 3.437839924894906, 3.5783534453069534, 3.7070546773984145, 3.82609931471987, 3.9370782309638512, 4.0412024974388885, 4.13941762589128, 4.23247741750847, 4.32099353583246, 4.405469853163189, 4.486326896627841, 4.5639196560432, 4.638550820927391, 4.710480796220181, 4.779935400853536, 4.847111868953031, 4.912183587284834, 4.975303877917411, 5.0366090499126575, 5.096220884617526, 5.154248677223693, 5.210790927174072, 5.265936748089723, 5.31976705173963, 5.372355548527196, 5.42376959788131, 5.474070935018657, 5.523316295222402, 5.57155795265468, 5.618844187492638, 5.665219692634221, 5.710725929201234, 5.755401438454029, 5.799282116434989, 5.842401456608411, 5.8847907649104245, 5.926479350923961, 5.967494698319361, 6.007862617226501, 6.047607380810313, 6.086751847993017, 6.125317573991318, 6.163324910105526, 6.200793094002416, 6.237740331568332, 6.274183871268555, 6.310140071829066, 6.345624463954374, 6.3806518067070375, 6.4152361390987345, 6.4493908273774165, 6.483128608438358, 6.516461629737868, 6.549401486045602, 6.581959253334134, 6.614145520071821, 6.645970416156392, 6.677443639701577, 6.7085744818669975, 6.739371849902002, 6.7698442885569365, 6.800000000000002, 6.829846862364388, 6.859392447038249, 6.888644034799413, 6.917608630887116, 6.946292979094538, 6.974703574958224, 7.002846678113661, 7.030728323880055, 7.058354334131917, 7.085730327509972, 7.112861729019487, 7.139753779060019, 7.166411541926924, 7.192839913821647, 7.219043630404788, 7.245027273923226, 7.27079527994008, 7.29635194369404, 7.3217014261125275, 7.346847759501288, 7.371794852931277, 7.396546497342174, 7.421106370380383, 7.4454780409881, 7.469664973758801, 7.493670533073448, 7.517497987030606, 7.541150511182847, 7.564631192090861, 7.587943030705977, 7.611088945591026, 7.6340717759888115, 7.656894284746881], [0.0, 1.9372887813476258, 2.385082260191911, 2.693585341360245, 2.9363807000033373, 3.1396798431899127, 3.3161925448834246, 3.4731518817045592, 3.615108694262943, 3.745131887948966, 3.865399298634904, 3.9775181407575775, 4.0827119252092885, 4.181935875610851, 4.275951535858951, 4.3653768522304075, 4.450720872576457, 4.532408443491182, 4.610798201088269, 4.6861959439774346, 4.7588647518617195, 4.829032763184341, 4.89689923797175, 4.962639343941564, 5.026407978018084, 5.08834284936903, 5.148566990224979, 5.2071908184090185, 5.264313845106363, 5.3200260992734005, 5.374409323768682, 5.427537986115966, 5.479480137630117, 5.530298147644407, 5.5800493342014965, 5.628786508400374, 5.6765584463306125, 5.723410299955651, 5.7693839562674265, 5.814518352404907, 5.858849753118598, 5.902411995902709, 5.945236708253966, 5.987353500810252, 6.028790139541899, 6.069572699688912, 6.109725703739337, 6.149272245412038, 6.188234101329281, 6.226631831830848, 6.264484872184235, 6.301811615278526, 6.338629486747533, 6.374955013346769, 6.4108038853052065, 6.4461910132839, 6.481130580496993, 6.515636090484565, 6.549720410969595, 6.583395814181636, 6.616674013986643, 6.649566200124635, 6.682083069823989, 6.71423485703222, 6.746031359477751, 6.777481963754848, 6.808595668604151, 6.839381106543861, 6.869846563991191, 6.9, 6.9298490637283585, 6.959401110738994, 6.988663218225832, 7.017642199251285, 7.046344616071152, 7.074776792617097, 7.102944826200432, 7.130854598495365, 7.158511785854787, 7.185921869007201, 7.213090142179204, 7.240021721684337, 7.266721554015637, 7.293194423476298, 7.31944495937999, 7.345477642849959, 7.371296813243668, 7.396906674227727, 7.422311299525926, 7.4475146383614526, 7.472520520612826, 7.4973326617015905, 7.521954667228522, 7.546390037373859, 7.5706421710759795, 7.594714370001897, 7.618609842322043, 7.6423317063008795, 7.66588299371417, 7.6892666531029175, 7.712485552873362, 7.735542484251785], [0.0, 1.9568999764242132, 2.4092264734494684, 2.7208525346116845, 2.9661057132699877, 3.1714628558598124, 3.349762397522531, 3.508310635390906, 3.651704478282783, 3.783043898150679, 3.9045287771227217, 4.017782599484686, 4.124041261742736, 4.2242696572566265, 4.319237039040067, 4.4095676088466496, 4.49577556762446, 4.578290062694203, 4.657473360646783, 4.733634355694517, 4.807038790699097, 4.877917113551642, 4.946470601389986, 5.012876195156427, 5.07729035979849, 5.139852198515273, 5.20068598899394, 5.2599032668183865, 5.317604550526617, 5.373880780439112, 5.428814526898254, 5.4824810112633395, 5.534948973733425, 5.58628141500721, 5.636536233358514, 5.685766774493648, 5.73402230826306, 5.781348443703998, 5.827787491830868, 5.873378783943712, 5.918158951901495, 5.962162175735742, 6.005420403108665, 6.047963544406952, 6.08981964667615, 6.1310150491162005, 6.171574522456556, 6.211521394194044, 6.250877661395911, 6.289664092534479, 6.327900319620665, 6.365604921734965, 6.402795500911071, 6.439488751205016, 6.475700521678131, 6.511445873932252, 6.546739134758349, 6.581593944392984, 6.616023300819232, 6.65003960049856, 6.68365467587651, 6.716879829966961, 6.749725868286447, 6.782203128380844, 6.814321507161084, 6.846090486242027, 6.877519155458661, 6.908616234716262, 6.939390094315533, 6.969848773879918, 7.0, 7.029851202698945, 7.059409530813188, 7.088681866373847, 7.117674838066504, 7.146394833840054, 7.174848012728955, 7.203040315947665, 7.2309774773108595, 7.258665033028511, 7.286108330920731, 7.313312539093558, 7.340282654113429, 7.367023508715091, 7.393539779074807, 7.419835991678281, 7.445916529810337, 7.471785639691349, 7.497447436283455, 7.522905908787871, 7.548164925853019, 7.573228240511694, 7.5980994948642095, 7.622782224523163, 7.647279862834423, 7.6715957448878145, 7.695733111330111, 7.719695111992001, 7.743484809339946, 7.76710518176306, 7.7905591267044905, 7.813849463646133], [0.0, 1.9764273000938692, 2.4332674288929437, 2.748003113967228, 2.995703601255696, 3.2031099417807956, 3.383188681615186, 3.543319025260764, 3.688143752723197, 3.820793769654429, 3.9434909101529865, 4.057874858772159, 4.165193844662289, 4.266422389567395, 4.362337422648544, 4.453569374383241, 4.540637576778118, 4.623975459487534, 4.703948904053114, 4.780869887050778, 4.8550068031113085, 4.92659239969689, 4.995829962430135, 5.062898197894453, 5.12795513235461, 5.191141257079217, 5.252582089885566, 5.312390279338018, 5.370667347019216, 5.427505140716089, 5.482987054715942, 5.537189060989676, 5.590180585674379, 5.6420252581340105, 5.692781554392069, 5.7425033524758256, 5.791240413884933, 5.8390388027756766, 5.885941252371507, 5.93198748644783, 5.97721450240205, 6.021656821338075, 6.065346709714352, 6.108314376384433, 6.150588148267004, 6.192194627393058, 6.2331588316718, 6.273504321378221, 6.31325331308177, 6.352426782497182, 6.391044557537384, 6.429125402677998, 6.4666870955981794, 6.503746496938993, 6.54031961391484, 6.576421658422812, 6.61206710021667, 6.647269715644846, 6.682042632393427, 6.7163983706244865, 6.750348880856028, 6.783905578891349, 6.817079378072023, 6.849880719099224, 6.882319597642224, 6.914405589930097, 6.946147876502597, 6.977555264278343, 7.008636207082786, 7.0393988247643815, 7.069850921015067, 7.1000000000000005, 7.129853281891736, 7.159417717395134, 7.188700001341463, 7.217706585423059, 7.24644369013356, 7.2749173159730365, 7.303133253972198, 7.331097095585211, 7.358814241996497, 7.386289912883089, 7.413529154670678, 7.440536848318433, 7.467317716664794, 7.493876331363919, 7.520217119440131, 7.546344369485576, 7.572262237524376, 7.597974752564802, 7.6234858218593695, 7.648799235891273, 7.6739186731042635, 7.698847704391766, 7.723589797359987, 7.748148320378625, 7.772526546431904, 7.796727656781736, 7.820754744454027, 7.844610817558352, 7.868298802450583, 7.891821546747385], [0.0, 1.995872284892263, 2.4572070132950627, 2.775039210247872, 3.0251766868501644, 3.2346235846669025, 3.416474020509756, 3.578179798828698, 3.724429377396863, 3.858384465130655, 3.982288755536364, 4.097798065124784, 4.206172903688631, 4.3083973807571665, 4.405256069271587, 4.497385602169287, 4.585310420879832, 4.66946821933436, 4.750228478782419, 4.827906245166447, 4.902772553704874, 4.97506244173458, 5.044981194893985, 5.112709277962613, 5.178406271939023, 5.242214050308406, 5.304259365789055, 5.364655975232806, 5.423506399037501, 5.4809033886300975, 5.536931158768581, 5.591666428870429, 5.645179308118434, 5.697534051890988, 5.748789711525131, 5.79900069512451, 5.848217253764896, 5.896485904802557, 5.943849801889704, 5.990349059622194, 6.036021039394544, 6.08090060194488, 6.125020331183648, 6.168410733172747, 6.211100413523891, 6.2531162359908725, 6.2944834646203915, 6.33522589148407, 6.375365951728004, 6.414924827435491, 6.453922541595421, 6.492378043296807, 6.530309285123645, 6.567733293599603, 6.604666233425292, 6.64112346615932, 6.677119603915423, 6.712668558579973, 6.747783586995166, 6.782477332502086, 6.816761863193332, 6.850648707186033, 6.884148885192147, 6.917272940633185, 6.950030967520329, 6.982432636297922, 7.014487217828014, 7.046203605675672, 7.077590336838898, 7.10865561105289, 7.139407308785827, 7.1698530080322405, 7.2, 7.229855303778143, 7.2594256800647115, 7.2887176440267085, 7.317737477357796, 7.346491239593677, 7.374984778739837, 7.403223741261696, 7.431213581482968, 7.458959570434226, 7.4864668041901785, 7.5137402117310765, 7.540784562360776, 7.567604472711436, 7.594204413362447, 7.620588715099059, 7.646761574834238, 7.672727061215459, 7.6984891199365535, 7.724051578773203, 7.749418152359349, 7.774592446720479, 7.799577963578679, 7.824378104443189, 7.8489961744993275, 7.873435386307703, 7.8976988633248055, 7.921789643255352, 7.945710681246025, 7.969464852929632], [0.0, 2.015236414496383, 2.481047053276462, 2.801962886342034, 3.0545272188871833, 3.2660061890490333, 3.449620953919792, 3.6128956160159196, 3.7605641209429397, 3.8958188527970714, 4.020925273597638, 4.137555264733812, 4.246981565575912, 4.350197833570978, 4.447996253656339, 4.541019635438511, 4.629797508524236, 4.714771813389923, 4.796315616024915, 4.874747018975273, 4.950339687067111, 5.023330937990361, 5.093928049082879, 5.162313236009457, 5.228647628037631, 5.293074475121705, 5.355721759746067, 5.416704342441598, 5.47612573826812, 5.534079598535143, 5.590650955059691, 5.645917271597822, 5.699949337537827, 5.7528120316694675, 5.804564978251085, 5.8552631132585615, 5.904957175308056, 5.953694133071344, 6.001517558881193, 6.048467956528818, 6.094583049892296, 6.139898037931717, 6.184445820689511, 6.228257200200095, 6.271361059609355, 6.313784523305604, 6.355553100449559, 6.396690813945627, 6.437220316607679, 6.477162996029456, 6.516539069464663, 6.555367669848051, 6.593666923941175, 6.631454023460542, 6.668745289938122, 6.705556233971722, 6.741901609443101, 6.777795463212982, 6.813251180742619, 6.848281528039911, 6.8828986902831595, 6.9171143074363055, 6.950939507135231, 6.984384935094656, 7.017460783258752, 7.0501768158953695, 7.082542393813283, 7.1145664968637155, 7.146257744871378, 7.177624417126026, 7.2086744705528405, 7.239415556668723, 7.2698550374214905, 7.300000000000002, 7.32985727069519, 7.359433427884786, 7.388734814208, 7.417767547990686, 7.446537533976197, 7.47505047341246, 7.503311873541521, 7.531327056533957, 7.559101167907047, 7.586639184462442, 7.6139459217762075, 7.641026041271477, 7.667884056901596, 7.694524341469479, 7.7209511326069125, 7.747168538435749, 7.77318054293129, 7.7989910110066365, 7.824603693335437, 7.850022230929159, 7.875250159483904, 7.900290913510656, 7.9251478302619365, 7.949824153466898, 7.974323036886085, 7.998647547696293, 8.022800669715298, 8.046785306475556], [0.0, 2.034521125928944, 2.504789318019628, 2.8287761402705343, 3.0837573754858885, 3.2972600838475294, 3.4826319416974636, 3.647469053102329, 3.7965506649406326, 3.9330997106801884, 4.059403331574076, 4.177149408002906, 4.28762285875739, 4.3918268500434365, 4.490561147575404, 4.584474712296532, 4.674102141122587, 4.7598896036588725, 4.842213735932421, 4.921395684556858, 4.997711733181165, 5.0714014704959025, 5.142674157369802, 5.211713753172011, 5.27868292908912, 5.34372630589923, 5.406973090809178, 5.468539243502371, 5.528529269621195, 5.587037716667027, 5.644150430164919, 5.699945615156752, 5.754494738446585, 5.807863299678752, 5.860111493683169, 5.911294782142993, 5.961464389215216, 6.010667733036143, 6.0589488029019565, 6.106348490203027, 6.15290487981433, 6.198653507530777, 6.243627588230224, 6.28785821870573, 6.331374558499107, 6.374203991564243, 6.416372271170587, 6.457903650108615, 6.49882099796725, 6.539145907007822, 6.578898787952105, 6.618098956826582, 6.656764713856014, 6.694913415272242, 6.7325615387953786, 6.769724743451177, 6.8064179243079845, 6.842655262647307, 6.878450272021948, 6.913815840603527, 6.948764270175846, 6.98330731209094, 7.017456200470087, 7.051221682901681, 7.084614048861228, 7.117643156055291, 7.150318454870468, 7.182649011090251, 7.214643527026366, 7.246310361196847, 7.2776575466703, 7.308692808184466, 7.3394235781369765, 7.369857011537219, 7.3999999999999995, 7.42985918485453, 7.4594409694356125, 7.488751530618136, 7.517796829650621, 7.546582622338824, 7.5751144686260865, 7.603397741613252, 7.6314376360573855, 7.659239176385414, 7.686807224255833, 7.71414648569905, 7.741261517864476, 7.7681567354003604, 7.794836416490312, 7.821304708568664, 7.847565633735184, 7.873623093888082, 7.899480875592901, 7.925142654703602, 7.950612000750964, 7.9758923811123665, 8.000987164976014, 8.025899627111773, 8.050632951459955, 8.075190234548561, 8.099574488748875, 8.123788645378566], [0.0, 2.0537278116349436, 2.5284355218254415, 2.855480908073818, 3.1128692671982305, 3.3283875257375626, 3.515509367388149, 3.6819026064493405, 3.832391607784185, 3.9702297306296748, 4.097725707758709, 4.216583353811595, 4.32809971772164, 4.433287435981289, 4.532953824410192, 4.6277539704000725, 4.718227517673441, 4.804824847853493, 4.887926152560616, 4.967855610159739, 5.044892112526978, 5.119277510165083, 5.191223039448316, 5.2609143963951706, 5.328515787872707, 5.394173199936483, 5.458017059560572, 5.52016442113375, 5.580720776873081, 5.639781566845822, 5.697433446992805, 5.753755360642496, 5.808819449273909, 5.862691830873978, 5.915433268535666, 5.9670997475224, 6.017742975567514, 6.067410818453311, 6.116147680752364, 6.16399483988597, 6.210990740265422, 6.257171253157614, 6.302569907002015, 6.347218092157733, 6.39114524344421, 6.4343790033307116, 6.4769453682077565, 6.5188688198217735, 6.56017244365967, 6.600878035822276, 6.641006199716672, 6.680576433720283, 6.719607210819246, 6.758116051095109, 6.79611958782419, 6.833633627859654, 6.8706732068851935, 6.907252640059235, 6.943385568507873, 6.979085002072177, 7.0143633586696605, 7.049232500589781, 7.083703768008373, 7.117788009975324, 7.151495613102867, 7.18483652815822, 7.217820294743377, 7.250456064226419, 7.282752621072342, 7.314718402706904, 7.346361518034064, 7.377689764716143, 7.408710645315558, 7.4394313823878155, 7.4698589326073, 7.500000000000001, 7.529861048350739, 7.55944831284655, 7.588767811012504, 7.617825352991444, 7.64662655121478, 7.675176829507557, 7.703481431667406, 7.731545429553833, 7.759373730721319, 7.786971085627062, 7.814342094441771, 7.841491213489722, 7.868422761342274, 7.895140924587184, 7.921649763294437, 7.947953216197704, 7.974055105609212, 7.999959142084437, 8.025668928851944, 8.05118796602253, 8.076519654590868, 8.101667300241957, 8.12663411697376, 8.15142323054673, 8.176037681770133, 8.200480429634437], [0.0, 2.0728578214393822, 2.551987326523409, 2.8820790665339464, 3.1418649399763243, 3.3593907023219227, 3.5482555415815993, 3.7161986960096662, 3.8680894683361124, 4.007211522102984, 4.13589509540649, 4.255859873534738, 4.368414987138326, 4.474582505189463, 4.575177263471963, 4.670860451368359, 4.762176739260312, 4.849580703973917, 4.933456078528467, 5.014130060936998, 5.091884140890341, 5.166962421673944, 5.239578107281095, 5.309918623446676, 5.378149706587554, 5.444418702586357, 5.508857253314908, 5.57158350349712, 5.63270392798619, 5.692314855852004, 5.750503750215869, 5.807350289745495, 5.862927287901444, 5.9173014785447355, 5.970534190762795, 6.022681931309107, 6.073796889562842, 6.12392737716523, 6.173118212307391, 6.221411056900461, 6.268844713456722, 6.315455387375801, 6.361276919406996, 6.406340992303504, 6.450677315063451, 6.494313787639446, 6.5372766485725045, 6.579590607650981, 6.621278965397869, 6.662363720939749, 6.702865669599771, 6.7428044913783385, 6.782198831333269, 6.821066372741706, 6.859423903815175, 6.8972873786441, 6.9346719729661634, 6.971592135282253, 7.008061633782468, 7.0440935994916005, 7.079700565997258, 7.114894506083438, 7.149686865557147, 7.1840885945247175, 7.2181101763473245, 7.251761654481331, 7.285052657387965, 7.3179924216782295, 7.350589813642426, 7.382853349299021, 7.414791213084579, 7.446411275294884, 7.477721108377022, 7.50872800216297, 7.5394389781269595, 7.5698608027414656, 7.600000000000001, 7.62986286316896, 7.659455465825294, 7.688783672232012, 7.7178531470990555, 7.746669364773169, 7.775237617896773, 7.803563025572597, 7.831650541067883, 7.85950495908926, 7.887130922656986, 7.914532929604993, 7.941715338731152, 7.968682375620338, 7.995438138161168, 8.021986601775728, 8.048331624380216, 8.074476951093095, 8.100426218706188, 8.126182959933029, 8.151750607447793, 8.17713249772718, 8.20233187470682, 8.227351893262918, 8.25219562252919, 8.276866049058428], [0.0, 2.09191246439442, 2.5754463437457864, 2.9085724357428675, 3.170746377972216, 3.3902717351246303, 3.5808727050738467, 3.75035966863888, 3.903646689374122, 4.044047615736249, 4.173914106419865, 4.294981654834994, 4.408571425750964, 4.515714883458436, 4.617234354078848, 4.713797104945414, 4.8059528132953275, 4.894160234629665, 4.978806629414511, 5.060222203414447, 5.138691033900355, 5.21445946806506, 5.287742669769007, 5.358729787648872, 5.427588081645332, 5.494466252110751, 5.559497151028343, 5.622800009161555, 5.684482280128398, 5.744641178498967, 5.803364971394987, 5.860734069926375, 5.916821956887827, 5.9716959795880795, 6.025418030879157, 6.078045136950083, 6.129629966928309, 6.1802212765574405, 6.229864296017599, 6.278601070194979, 6.326470758292034, 6.373509898524739, 6.419752642721804, 6.4652309648785655, 6.509974847091646, 6.554012445782589, 6.597370240688899, 6.640073168742437, 6.682144744655103, 6.723607169779357, 6.764481430598331, 6.804787388019856, 6.844543858495523, 6.883768687855126, 6.922478818634992, 6.960690351582731, 6.998418601938248, 7.035678151019555, 7.07248289358016, 7.1088460813511505, 7.144780363134518, 7.180297821773484, 7.215410008290069, 7.250127973448918, 7.284462296978983, 7.318423114660605, 7.352020143464162, 7.385262704907749, 7.418159746784601, 7.450719863396265, 7.482951314414332, 7.514862042481891, 7.546459689655372, 7.577751612778173, 7.60874489786908, 7.639446373601031, 7.669862623939027, 7.700000000000001, 7.729864631191961, 7.759462435684863, 7.788799130261214, 7.817880239590422, 7.846711104967258, 7.875296892551553, 7.903642601143211, 7.931753069523965, 7.959632983394808, 7.987286881935787, 8.014719164012806, 8.04193409405422, 8.068935807618287, 8.095728316670959, 8.122315514592144, 8.148701180927114, 8.174888985898727, 8.20088249469481, 8.226685171544222, 8.252300383594063, 8.27773140459968, 8.302981418438321, 8.328053522456562, 8.352950730660936], [0.0, 2.1108930105235717, 2.598814137074927, 2.934962781527521, 3.199515506181586, 3.421032682417671, 3.6133630318528636, 3.7843878012223895, 3.9390656408458913, 4.080740466716123, 4.211785274828889, 4.333951305243887, 4.448571710052701, 4.55668731232935, 4.659127899405596, 4.756566792930316, 4.849558657526331, 4.938566411120295, 5.0239808279080815, 5.106135109709724, 5.18531591131397, 5.261771815095246, 5.3357199371599195, 5.407351142346699, 5.4768342081956245, 5.544319184261735, 5.609940127933942, 5.673817351791988, 5.736059284412636, 5.796764022422787, 5.856020633818104, 5.913910259302506, 5.970507048402016, 6.025878959487601, 6.080088446983605, 6.133193054494684, 6.1852459290310025, 6.2362962687115795, 6.28638971410346, 6.335568691578637, 6.383872715642698, 6.4313386560337555, 6.478000974450253, 6.523891934997131, 6.569041791807523, 6.613478956774587, 6.65723014989439, 6.70032053435902, 6.742773838236372, 6.784612464318407, 6.82585758950488, 6.866529254907566, 6.906646447705337, 6.946227175648527, 6.985288534998154, 7.023846772588714, 7.061917342619854, 7.099514958710238, 7.136653641684619, 7.173346763510996, 7.209607087757715, 7.245446806899241, 7.280877576763465, 7.3159105483819165, 7.350556397476587, 7.384825351792776, 7.418727216465837, 7.452271397590778, 7.4854669241468335, 7.518322468414213, 7.550846365006973, 7.5830466286341744, 7.614930970690906, 7.646506814771401, 7.677781311188008, 7.708761350572255, 7.739453576627419, 7.769864398096016, 7.8, 7.829866354206651, 7.859469229368547, 7.888814200282073, 7.917906656705161, 7.946751811671752, 7.975354709337353, 8.003720232387408, 8.031853109037675, 8.059757919653531, 8.08743910301311, 8.114900962237197, 8.1421476704072, 8.16918327589084, 8.196011707393819, 8.222636778754357, 8.249062193496332, 8.275291549155588, 8.301328341392967, 8.327175967906701, 8.352837732155892, 8.37831684690606, 8.40361643760693, 8.428739545612013], [0.0, 2.1298006924699155, 2.6220922240724707, 2.9612518177414953, 3.228174192941969, 3.451675541892182, 3.6457286319199205, 3.8182853036303346, 3.974348622944739, 4.117292457966076, 4.249511060079847, 4.372771355545805, 4.488418437759814, 4.597502452651926, 4.7008606201214835, 4.799172292891188, 4.892997103823476, 4.982802117291495, 5.068981607732093, 5.151871761519238, 5.231761801064737, 5.308902535344011, 5.383513025214896, 5.455785845129827, 5.525891284402313, 5.593980736610631, 5.66018945992197, 5.724638844579404, 5.787438290375683, 5.848686772608403, 5.908474157072699, 5.9668823112656595, 6.023986048885129, 6.079853937018507, 6.134548989506645, 6.1881292653835285, 6.240648387707499, 6.292155995274758, 6.342698137463843, 6.392317620668071, 6.441054313332188, 6.48894541544377, 6.536025697381441, 6.5823277122460455, 6.627881985162908, 6.67271718251608, 6.71686026363786, 6.760336617111975, 6.803170183543272, 6.845383566389902, 6.886998132237259, 6.928034101709279, 6.968510632056712, 7.0084458923288375, 7.04785713192123, 7.086760743194463, 7.125172318774476, 7.163106704072695, 7.200578045501145, 7.23759983480316, 7.2741849498728675, 7.310345692395113, 7.346093822601318, 7.381440591404987, 7.416396770152642, 7.4509726782014996, 7.48517820851343, 7.519022851435676, 7.552515716821808, 7.585665554631344, 7.618480774133112, 7.650969461825492, 7.6831393981760465, 7.7149980732735965, 7.746552701477239, 7.777810235139236, 7.8087773774718165, 7.839460594621856, 7.869866127011763, 7.9, 7.9298680339100995, 7.959475853472984, 7.988828896723706, 8.01793242339037, 8.046791522809972, 8.075411121403125, 8.103795989737142, 8.131950749204632, 8.159879878342728, 8.187587718816113, 8.215078481085301, 8.242356249780041, 8.269424988796214, 8.296288546133336, 8.322950658488478, 8.349414955621315, 8.375684964504007, 8.401764113268632, 8.427655734964027, 8.453363071133078, 8.478889275220773, 8.504237415822628], [0.0, 2.1486367070547505, 2.645282078198274, 2.9874412084321627, 3.256724252295235, 3.482202253184496, 3.6779715539576427, 3.852054321511926, 4.009497869018178, 4.153705903159552, 4.2870938501451725, 4.411444262978139, 4.528114131096472, 4.638162887949061, 4.742435157830549, 4.841616301677382, 4.936270901760077, 5.026870153181654, 5.1138118173526825, 5.197435053888459, 5.278031643091577, 5.3558546120987796, 5.431124959148018, 5.504036961825364, 5.574762415487592, 5.6434540526418555, 5.71024832768221, 5.775267704430305, 5.838622550213597, 5.900412715669876, 5.960728861369784, 6.019653578848756, 6.077262343458991, 6.133624328697055, 6.188803105699897, 6.242857246977166, 6.295840849830969, 6.347803992064358, 6.398793130317811, 6.448851449565538, 6.498019170849885, 6.5463338231561155, 6.593830484373017, 6.640541995501933, 6.68649915163322, 6.731730872677197, 6.776264356395225, 6.820125215908346, 6.86333760355276, 6.905924322692211, 6.947906928878748, 6.989305821568048, 7.0301403274381045, 7.070428776225754, 7.110188569880689, 7.149436245737964, 7.1881875343251185, 7.226457412346798, 7.264260151326274, 7.301609362328223, 7.338518037139214, 7.374998586240523, 7.411062873871377, 7.4467222504486585, 7.48198758258097, 7.516869280890202, 7.551377325831841, 7.585521291686019, 7.619310368874096, 7.652753384740468, 7.685858822925762, 7.718634841445566, 7.751089289578108, 7.783229723654755, 7.815063421838591, 7.846597397968666, 7.8778384145406015, 7.9087929948880475, 7.939467434623878, 7.969867812394986, 8.0, 8.029869671915119, 8.05948231426952, 8.088843233308484, 8.117957563379242, 8.146830274471805, 8.175466179344507, 8.203869940261681, 8.232046075368762, 8.25999896472823, 8.28773285603803, 8.315251870052478, 8.342560005724266, 8.369661145084716, 8.39655905787835, 8.423257405966535, 8.449759747514067, 8.476069540971515, 8.50219014886529, 8.528124841406575, 8.553876799929505, 8.579449120168338], [0.0, 2.1674022167526226, 2.6683851306263784, 3.0135325698915416, 3.2851674462233107, 3.512614700266654, 3.71009378785492, 3.885696938939861, 4.0445155483204145, 4.18998304957147, 4.324535964466519, 4.449972414259708, 4.567661239903264, 4.678671127600903, 4.783854078327251, 4.88390143874322, 4.979382722001329, 5.070773238472782, 5.1584742234898115, 5.242827798779937, 5.324128292962125, 5.402630943031661, 5.47855867735483, 5.552107470276352, 5.623450617559016, 5.692742185627124, 5.760119820624012, 5.825707055931401, 5.889615222789891, 5.951945043900982, 6.012787971635915, 6.072227318858326, 6.13033922009814, 6.187193452991241, 6.242854143884674, 6.297380376841759, 6.350826721633237, 6.403243693425765, 6.454678154597345, 6.50517366728602, 6.554770803811926, 6.603507420926551, 6.651418902877808, 6.698538377489901, 6.744896908807712, 6.790523669318862, 6.835446094321308, 6.879690020632948, 6.923279811528804, 6.966238469529947, 7.008587738447763, 7.050348195900288, 7.091539337358573, 7.13217965264555, 7.172286695694004, 7.2118771482708155, 7.250966878288947, 7.289570993254823, 7.327703889334658, 7.365379296467839, 7.402610319907067, 7.439409478522817, 7.475788740172807, 7.511759554404851, 7.5473328827330555, 7.582519226702369, 7.617328653934408, 7.651770822328018, 7.6858550025707775, 7.719590099102301, 7.752984669656636, 7.786046943498883, 7.81878483846037, 7.85120597686706, 7.883317700447198, 7.915127084296474, 7.946640949971996, 7.977865877780134, 8.008808218317645, 8.039474103320389, 8.06986945586942, 8.1, 8.129871269755421, 8.159488617724021, 8.188857223094784, 8.217982099264036, 8.246868101023212, 8.275519931355376, 8.30394214786601, 8.33213916887167, 8.360115279168339, 8.387874635499696, 8.415421271744007, 8.442759103837027, 8.469891934447025, 8.496823457416902, 8.523557261987332, 8.550096836813893, 8.576445573790235, 8.602606771688517, 8.628583639627644, 8.654379300379029], [0.0, 2.1860983510881815, 2.691402771964748, 3.0395274725984747, 3.313505486765422, 3.5429147137102324, 3.7420972670980053, 3.9192151809145956, 4.079403768618977, 4.226126080778606, 4.361839656741856, 4.488358128458702, 4.607062144580988, 4.71902960986018, 4.825119874679589, 4.926030249295598, 5.02233515951345, 5.114514015758545, 5.202971514441828, 5.288052728452223, 5.3700545253040435, 5.44923434368136, 5.525817034943175, 5.600000263920014, 5.671958821233733, 5.741848102294338, 5.809806940588601, 5.875959935104192, 5.9404193774313, 6.003286859111158, 6.064654621388341, 6.124606695787969, 6.183219873580734, 6.240564534308364, 6.296705357475406, 6.3517019368076575, 6.405609312797795, 6.458478436359163, 6.5103565741072975, 6.561287663949706, 6.611312628185661, 6.660469650121132, 6.70879441923056, 6.756320349100639, 6.803078771736462, 6.849099111269179, 6.894409039655184, 6.939034616582228, 6.9830004154843275, 7.0263296373036015, 7.069044213414784, 7.111164898939613, 7.152711357518176, 7.193702238467664, 7.234155247142083, 7.274087209206178, 7.3135141294504304, 7.352451245699467, 7.390913078301653, 7.4289134756316075, 7.466465655988684, 7.503582246231844, 7.540275317454224, 7.576556417968087, 7.61243660384218, 7.647926467208375, 7.6830361625321615, 7.717775431021969, 7.75215362333485, 7.786179720720623, 7.819862354732832, 7.853209825622686, 7.886230119521174, 7.918930924504874, 7.951319645632195, 7.983403419029004, 8.015189125095548, 8.04668340090029, 8.077892651820596, 8.10882306248503, 8.13948060706747, 8.169871058979043, 8.200000000000001, 8.229872828890418, 8.259494769515255, 8.288870878516677, 8.318006052563826, 8.346905035207966, 8.37557242336874, 8.404012673475352, 8.432230107284681, 8.460228917396709, 8.488013172486168, 8.515586822267897, 8.542953702212195, 8.570117538025258, 8.597081949908759, 8.623850456611615, 8.650426479286141, 8.676813345159895, 8.70301429103382, 8.729032466616534], [0.0, 2.204726207959915, 2.7143363538849714, 3.0654274430591273, 3.3417400380244926, 3.573104072831655, 3.773983871036436, 3.9526110157375167, 4.114164578664882, 4.2621371192185995, 4.39900711756666, 4.526603659710483, 4.646319158880329, 4.759240704709682, 4.866234970150819, 4.968005207276803, 5.065130736604811, 5.158095053641218, 5.247306303235974, 5.3331124986619, 5.415813037056717, 5.495667550752809, 5.572902807079214, 5.647718155178679, 5.720289875072968, 5.7907746863044, 5.859312605367047, 5.926029292962989, 5.991037997524846, 6.05444117626062, 6.116331856407288, 6.176794785526935, 6.235907409232634, 6.293740706773818, 6.3503599087924325, 6.405825116815486, 6.460191840338536, 6.513511464430287, 6.5658316584675465, 6.617196734754999, 6.667647964292941, 6.717223855749264, 6.765960402710261, 6.813891303481524, 6.861048157049776, 6.90746063827071, 6.9531566548948875, 6.998162488666005, 7.042502922409575, 7.086201354764144, 7.129279903982822, 7.17175950204281, 7.213659980139087, 7.255000146500639, 7.295797857349708, 7.3360700817233955, 7.375832960789828, 7.415101862215925, 7.453891430078686, 7.492215630755448, 7.530087795179374, 7.567520657803541, 7.604526392579497, 7.6411166462232645, 7.6773025690129275, 7.713094843336458, 7.748503710186071, 7.783538993775536, 7.818210124439336, 7.852526159956982, 7.886495805431932, 7.920127431842264, 7.953429093369202, 7.98640854359982, 8.019073250691413, 8.051430411577146, 8.083486965285505, 8.115249605439766, 8.146724791997839, 8.177918762287828, 8.208837541389858, 8.239486951910585, 8.269872623192905, 8.3, 8.329874350709657, 8.359500775051949, 8.388884211420788, 8.418029443787482, 8.446941108242266, 8.475623699187807, 8.504081575206895, 8.532318964624876, 8.560339970785867, 8.588148577060432, 8.615748651601107, 8.64314395186103, 8.670338128889794, 8.697334731419758, 8.724137209755053, 8.750748919474715, 8.777173124960632, 8.803413002760255], [0.0, 2.223286854895418, 2.737187190667683, 3.091233965552308, 3.3698727180697845, 3.603184507726563, 3.8057554270317753, 3.9858863572613825, 4.148799970535063, 4.298018228616631, 4.436040476938511, 4.5647111997948295, 4.685434532547266, 4.799306716571957, 4.90720172097007, 5.009828718193075, 5.107771905809797, 5.201518849668475, 5.2914811306159795, 5.378009691700021, 5.461406450554766, 5.541933225246155, 5.619818692160375, 5.6952638786753385, 5.7684465488389165, 5.839524741548219, 5.908639652036298, 5.975917998888932, 6.041473983928861, 6.105410926907493, 6.167822638218328, 6.228794578876924, 6.288404846477848, 6.346725017814473, 6.403820872677619, 6.459753018563344, 6.514577432277904, 6.568345931478923, 6.6211065868512975, 6.6729040837460545, 6.723780040606389, 6.773773290288197, 6.8229201293923785, 6.871254539916147, 6.918808386864579, 6.965611594913285, 7.011692306756242, 7.057077025391905, 7.101790742281795, 7.145857053047588, 7.189298262146507, 7.232135477773114, 7.274388698072739, 7.316076889612802, 7.357218058939441, 7.397829317944825, 7.437926943682671, 7.477526433193712, 7.516642553837168, 7.555289389567334, 7.593480383544797, 7.631228377428549, 7.668545647657425, 7.705443938996174, 7.7419344955922975, 7.778028089764224, 7.813735048718702, 7.849065279375354, 7.884028291458617, 7.918633219001572, 7.95288884039222, 7.986803597080324, 8.020385611051813, 8.053642701167895, 8.086582398457086, 8.119211960440454, 8.151538384563201, 8.183568420799348, 8.215308583490433, 8.246765162473954, 8.277944233552612, 8.308851668351092, 8.339493143603326, 8.369874149909627, 8.4, 8.429875836536963, 8.459506639488657, 8.488897233100598, 8.51805229249228, 8.546976349902822, 8.575673800608064, 8.60414890852981, 8.632405811556477, 8.660448526592921, 8.688280954356005, 8.715906883931249, 8.743329997104878, 8.77055387248451, 8.797581989420905, 8.82441773174229, 8.851064391311986, 8.877525171419439], [0.0, 2.241781330242513, 2.7599565606690044, 3.1169484837855834, 3.3979051007422947, 3.6331577012002048, 3.837413712496528, 4.019043067025747, 4.1833118818550705, 4.3337714162880685, 4.472941806633691, 4.602682880581466, 4.724410453833276, 4.839229886880524, 4.948022418961365, 5.05150312179861, 5.150261052625279, 5.244787833120082, 5.335498467876942, 5.42274681927336, 5.506837316453986, 5.588033955425835, 5.666567314826159, 5.742640094284869, 5.816431536585158, 5.888100995275225, 5.957790840124708, 6.025628843831572, 6.0917301582096846, 6.156198962478768, 6.219129847396763, 6.280608984889134, 6.340715122207521, 6.399520431558905, 6.457091239925178, 6.513488658967588, 6.568769131137057, 6.622984905137877, 6.676184451532313, 6.728412827387764, 6.779711997351636, 6.830121117312047, 6.879676785804213, 6.928413267505562, 6.976362692491129, 7.023555234365794, 7.070019269929341, 7.115781522646175, 7.160867191870005, 7.205300069503362, 7.249102645543735, 7.292296203774806, 7.33490090869705, 7.376935884651821, 7.418419287973227, 7.4593683728992, 7.499799551884596, 7.539728450882724, 7.579169960095506, 7.618138280635011, 7.656646967489146, 7.694708969140609, 7.732336664150142, 7.769541894981656, 7.806335999317417, 7.842729839085693, 7.878733827400394, 7.914357953592139, 7.949611806492281, 7.984504596115616, 8.019045173873417, 8.053242051435888, 8.087103418351928, 8.120637158524172, 8.153850865628208, 8.186751857557, 8.2193471899642, 8.251643668973683, 8.283647863116718, 8.315366114553001, 8.34680454962697, 8.37796908880659, 8.408865456047865, 8.439499187624824, 8.469875640461566, 8.5, 8.52987728763427, 8.559512367740517, 8.588909954328352, 8.618074617338456, 8.647010788608894, 8.675722767531024, 8.704214726414412, 8.732490715578649, 8.76055466818882, 8.788410404850067, 8.816061637975656, 8.843511975941952, 8.870764927042801, 8.897823903254896, 8.924692223825021, 8.951373118689274], [0.0, 2.2602106443002135, 2.7826457077129216, 3.1425724024677613, 3.4258387173689746, 3.66302529060034, 3.868960456830096, 4.052082956284539, 4.217702197909526, 4.369398635324824, 4.509713122463747, 4.640520776352086, 4.763249051878767, 4.879012396521232, 4.988699294039863, 5.093030694644, 5.192600498108888, 5.287904367653858, 5.3793607195570585, 5.467326325240151, 5.552108116509501, 5.633972259639697, 5.713151228816884, 5.789849390031155, 5.864247459591014, 5.9365061010638644, 6.0067688546177065, 6.075164543348749, 6.1418092657149055, 6.206808057376056, 6.270256286705139, 6.332240834032786, 6.392841093978788, 6.452129832065917, 6.51017392053923, 6.567034973448848, 6.622769897249762, 6.677431370174229, 6.731068261253004, 6.783725997960193, 6.8354468899276375, 6.886270414937547, 6.9362334723956485, 6.985370608663625, 7.033714217952552, 7.08129472191953, 7.1281407306453275, 7.174279187283538, 7.219735498347596, 7.264533651329331, 7.308696321112788, 7.352244966452121, 7.395199917616831, 7.437580456166324, 7.479404887694932, 7.520690608284829, 7.561454165314948, 7.601711313196983, 7.641477064542745, 7.6807657372093, 7.719590997617871, 7.757965900698495, 7.795902926774017, 7.833414015663289, 7.870510598253787, 7.9072036257679, 7.943503596924027, 7.979420583173425, 8.014964252175645, 8.050143889659491, 8.084968419802232, 8.1194464242471, 8.15358615986793, 8.187395575379613, 8.220882326884093, 8.25405379243352, 8.286917085684914, 8.319479068714166, 8.351746364051358, 8.383725365994033, 8.415422251250295, 8.446842988959299, 8.47799335013274, 8.50887891655745, 8.539505089195911, 8.569877096118695, 8.6, 8.629878705205195, 8.659517964496992, 8.688922385384792, 8.718096436140073, 8.74704445149878, 8.775770638070346, 8.804279079471367, 8.832573741200836, 8.860658475272452, 8.888537024618618, 8.916213027279568, 8.943690020390251, 8.970971443976659, 8.99806064457255, 9.024960878666798], [0.0, 2.2785757803932314, 2.8052558424141596, 3.168107088802871, 3.45367505839138, 3.6927888695586493, 3.900397343258081, 4.085007787932433, 4.251972753647224, 4.404901786672574, 4.54635638641942, 4.678226906006461, 4.80195239897754, 4.91865636815175, 5.0292345165834895, 5.134413652497476, 5.23479250134758, 5.330870753819557, 5.42307022599498, 5.511750588209261, 5.597221266215251, 5.679750588997404, 5.759572919689727, 5.836894284839585, 5.911896869149417, 5.984742641643835, 6.055576308813423, 6.124527740494748, 6.191713978493185, 6.25724091192632, 6.321204684074134, 6.383692881205487, 6.444785543053935, 6.504556026391888, 6.563071746828751, 6.620394819054007, 6.676582611910873, 6.731688231663794, 6.785760944424388, 6.838846546783577, 6.890987692156265, 6.942224179097792, 6.992593206836653, 7.04212960243785, 7.090866023328677, 7.138833138354643, 7.186059790065126, 7.232573140537864, 7.278398802724607, 7.32356095902537, 7.368082468566904, 7.41198496446452, 7.455288942179476, 7.498013839941735, 7.540178112086072, 7.581799296044944, 7.622894073651509, 7.6634783273285, 7.703567191671338, 7.743175100875539, 7.782315832407587, 7.821002547274165, 7.859247827205848, 7.897063709037399, 7.9344617165369336, 7.971452889909999, 8.008047813181381, 8.044256639636993, 8.080089115490077, 8.115554601919785, 8.150662095615969, 8.185420247951232, 8.219837382889882, 8.253921513733369, 8.2876803587926, 8.321121356069415, 8.354251677022209, 8.387078239484046, 8.419607719795772, 8.451846564211218, 8.483800999626764, 8.515477043683264, 8.546880514284245, 8.578017038570836, 8.608892061390558, 8.639510853294185, 8.669878518092215, 8.7, 8.729880090398384, 8.759523434234673, 8.788934536086876, 8.818117765912442, 8.847077364501223, 8.875817448650874, 8.904342016081689, 8.932654950106553, 8.960760024070726, 8.988660905575012, 9.016361160495022, 9.043864256808366, 9.071173568240763, 9.098292377741387], [0.0, 2.296877695893461, 2.827788143435778, 3.1935538739104268, 3.481415574913951, 3.72244998964621, 3.931726010580837, 4.117819278336152, 4.286125335587291, 4.4402827211054765, 4.582873508708773, 4.715803235159689, 4.840522512729493, 4.9581638684066, 5.069630199687548, 5.1756541526466595, 5.276839261804397, 5.373689231448689, 5.466629265760971, 5.556021924011109, 5.642179117313221, 5.725371329916659, 5.805834807400735, 5.883777231153739, 5.959382249217212, 6.032813131579036, 6.104215747037403, 6.173721008565912, 6.241446898069999, 6.30750015518699, 6.371977695436352, 6.434967808595033, 6.4965511772895965, 6.556801747506762, 6.615787476349791, 6.673570977424116, 6.7302100803694405, 6.785758318008931, 6.84026535216815, 6.893777347284172, 6.946337299371523, 6.997985326654434, 7.04875892715205, 7.098693207666393, 7.147821087934873, 7.1961734831404796, 7.243779467500946, 7.290666421264525, 7.336860163110632, 7.382385069676511, 7.42726418369738, 7.47151931204948, 7.515171114817164, 7.55823918636163, 7.600742129246065, 7.642697621766622, 7.684122479747836, 7.725032713182808, 7.765443578230656, 7.805369625024852, 7.844824741694879, 7.883822194958908, 7.922374667606153, 7.960494293153319, 7.998192687929425, 8.035480980816862, 8.072369840853135, 8.108869502877113, 8.144989791385308, 8.180740142747485, 8.216129625916473, 8.251166961754192, 8.285860541084478, 8.320218441573004, 8.354248443525492, 8.3879580446871, 8.421354474118614, 8.454444705218338, 8.487235467952646, 8.519733260352789, 8.551944359330664, 8.583874830861857, 8.615530539580307, 8.646917157825312, 8.678040174178351, 8.708904901524178, 8.739516484667984, 8.76987990753791, 8.8, 8.829881444310589, 8.85952878122923, 8.888946415813631, 8.918138622916402, 8.947109552402033, 8.975863234101194, 9.004403582518218, 9.032734401306525, 9.060859387525724, 9.088782135693156, 9.116506141641832, 9.144034806195819, 9.171371438673505], [0.0, 2.3151173231916333, 2.850243758685416, 3.218914054176404, 3.509061680176766, 3.7520101619482102, 3.962948054836715, 4.15051909907644, 4.32016168363235, 4.475543241104551, 4.619266349695894, 4.753251678137133, 4.878961358088325, 4.997536909994617, 5.109888401309334, 5.216754296088033, 5.3187429215507365, 5.4163619819277695, 5.5100400579694675, 5.60014258804804, 5.686983960180265, 5.770836806545226, 5.85193924876088, 5.930500617424409, 6.006706018936167, 6.080720019819648, 6.1526896472248875, 6.222746853712332, 6.291010558087973, 6.357588347614242, 6.422577907421874, 6.486068228401606, 6.5481406338850086, 6.608869657067793, 6.668323794704173, 6.726566157617533, 6.783655034675808, 6.839644383809143, 6.894584261210286, 6.948521197910549, 7.001498531358081, 7.053556698358057, 7.104733494703374, 7.155064305981028, 7.204582313345804, 7.253318677479796, 7.301302703480638, 7.348561989024583, 7.395122557818546, 7.441008980075934, 7.486244481515548, 7.530851042183186, 7.574849486226024, 7.618259563605117, 7.661100024607593, 7.703388687913889, 7.745142502883891, 7.786377606646904, 7.827109376512012, 7.867352478156067, 7.907120909994923, 7.946428044098461, 7.985286663970595, 8.02370899948093, 8.061706759204366, 8.099291160398339, 8.136472956823747, 8.17326246459485, 8.209669586225015, 8.245703833018712, 8.281374345945807, 8.316689915121044, 8.351658998000236, 8.38628973639423, 8.420589972392559, 8.454567263280381, 8.48822889552483, 8.521581897900338, 8.554633053816296, 8.587388912905169, 8.619855801924137, 8.652039835019025, 8.683946923395135, 8.715582784436117, 8.746952950308563, 8.778062776087125, 8.808917447432163, 8.839521987849459, 8.86988126555928, 8.9, 8.92988276798959, 8.959534009566548, 8.988958033530322, 9.01815902269969, 9.047141038906421, 9.075908027740136, 9.10446382305927, 9.132812151281971, 9.16095663546984, 9.188900799216478, 9.216648070352077, 9.244201784474498], [0.0, 2.333295570622097, 2.8726238064538334, 3.2441888925390443, 3.5366147509572454, 3.781470858562705, 3.994065030885075, 4.1831088786059984, 4.354083492794235, 4.51068510264545, 4.655536721746079, 4.790574099873119, 4.917270849310451, 5.036777453695234, 5.150011126309293, 5.257716129610789, 5.360505567390942, 5.4588911303618985, 5.553304764480086, 5.644114777531324, 5.731638026099791, 5.816149283066108, 5.897888539773642, 5.977066770478561, 6.053870535032373, 6.128465692131092, 6.201000423378519, 6.2716077174235405, 6.340407426819847, 6.407507983602556, 6.473007839923779, 6.536996685428661, 6.59955648199768, 6.660762348059471, 6.720683318203167, 6.7793829987968754, 6.836920136391365, 6.893349112593195, 6.948720376635176, 7.003080824909195, 7.056474135148042, 7.108941061665742, 7.1605196970268805, 7.211245704665262, 7.261152526273325, 7.310271567206119, 7.358632362664221, 7.406262727020199, 7.453188888318507, 7.4994356096973, 7.5450262992431805, 7.589983109588757, 7.634327028391926, 7.678077960689976, 7.721254803996854, 7.763875516904863, 7.80595718185987, 7.847516062699541, 7.888567657475236, 7.929126747018361, 7.969207439660005, 8.008823212467231, 8.04798694931973, 8.086710976115757, 8.125007093365673, 8.162886606404557, 8.200360353431584, 8.237438731562913, 8.274131721066205, 8.310448907928478, 8.34639950489428, 8.381992371098132, 8.417236030403592, 8.452138688550818, 8.486708249205249, 8.520952328991665, 8.554878271590379, 8.588493160965589, 8.621803833789864, 8.654816891123225, 8.68753870940041, 8.71997545077537, 8.752133072868057, 8.784017337954879, 8.815633821640876, 8.846987921048623, 8.878084862556161, 8.908929709113723, 8.93952736716673, 8.969882593210476, 9.0, 9.029884062436883, 9.059539123153158, 9.088969397811006, 9.118178980135601, 9.147171846697244, 9.175951861457737, 9.204522780094976, 9.232888254118757, 9.261051834789855, 9.28901697685371, 9.316787042099216], [0.0, 2.3514133233434853, 2.8949293764991353, 3.269379619713324, 3.5640761289049925, 3.8108335140278715, 4.025078453913786, 4.2155902038283415, 4.387892414837357, 4.5457100169009514, 4.69168639098299, 4.827772317719068, 4.95545285181095, 5.075887410259539, 5.190000328394819, 5.298541647781274, 5.402129232885546, 5.50127874763514, 5.5964254919936325, 5.687940633611436, 5.77614348942508, 5.861310965892763, 5.943684917861069, 6.023477957775285, 6.100878094101185, 6.176052473407132, 6.249150427908826, 6.320305978895633, 6.389639909561564, 6.457261493903131, 6.523269948541283, 6.58775565955021, 6.650801225234299, 6.712482347307531, 6.77286859640412, 6.832024072787788, 6.890007979169035, 6.9468751194208975, 7.002676334508264, 7.05745888496773, 7.111266787684299, 7.164141113424227, 7.216120250536171, 7.2672401393761055, 7.317534481307093, 7.367034925542896, 7.415771236621287, 7.4637714448900105, 7.511061982051056, 7.5576678035252955, 7.603612499160242, 7.648918393600967, 7.6936066374719445, 7.737697290370628, 7.7812093965478315, 7.824161054042116, 7.866569477942434, 7.908451058373153, 7.949821413726089, 7.990695439603983, 8.03108735388738, 8.071010738291108, 8.110478576736595, 8.149503290831179, 8.188096772714731, 8.226270415506864, 8.264035141564037, 8.30140142873473, 8.338379334782157, 8.374978520127346, 8.411208269050668, 8.447077509476735, 8.482594831455854, 8.517768504444746, 8.552606493479836, 8.587116474328061, 8.621305847692506, 8.655181752543477, 8.688751078639463, 8.722020478296907, 8.754996377462774, 8.78768498613938, 8.820092308206865, 8.852224150685005, 8.884086132472724, 8.915683692600588, 8.947022098028823, 8.978106451020844, 9.008941696120019, 9.03953262675524, 9.06988389149902, 9.1, 9.12988532861022, 9.159544125725953, 9.18898051685965, 9.218198509459185, 9.247201997489551, 9.27599476579102, 9.304580494226911, 9.332962761633105, 9.361145049580708, 9.389130745962497], [0.0, 2.369471444177833, 2.91716153107985, 3.294487435357657, 3.59144712181366, 3.8400995266819318, 4.055989800875601, 4.247964621602152, 4.421590059844566, 4.580619651863121, 4.727717078962918, 4.864848103166318, 4.993509183931955, 5.114868642221633, 5.229857911972339, 5.3392327948338085, 5.443615900279052, 5.5435268523736845, 5.639404294049217, 5.7316222434078385, 5.820502469640544, 5.906324005760751, 5.989330563984827, 6.069736389555313, 6.147730934784359, 6.223482629873828, 6.29714195386426, 6.368843957286715, 6.438710350912456, 6.506851247928204, 6.573366626907607, 6.63834756806171, 6.701877304024112, 6.764032117874344, 6.82488211452739, 6.884491886517, 6.942921091212026, 7.000224953362151, 7.056454704375017, 7.111657967733398, 7.165879098358244, 7.219159482426483, 7.271537803097316, 7.323050276737441, 7.373730863525877, 7.423611455732472, 7.472722046477367, 7.521090881372632, 7.568744595107485, 7.615708334752643, 7.662005871318292, 7.707659700895811, 7.752691136539875, 7.797120391899387, 7.8409666574790675, 7.884248170304768, 7.9269822776719545, 7.969185495576036, 8.010873562353206, 8.05206148799979, 8.092763599585217, 8.13299358312765, 8.172764522260985, 8.212088933986628, 8.250978801772375, 8.289445606233443, 8.327500353606581, 8.36515360220688, 8.402415487038036, 8.439295742710096, 8.475803724803809, 8.511948429807465, 8.547738513740276, 8.58318230956581, 8.618287843489489, 8.653062850225746, 8.687514787312756, 8.72165084854589, 8.755477976594834, 8.789002874863746, 8.822232018648858, 8.855171665643368, 8.887827865835343, 8.920206470840657, 8.952313142709626, 8.984153362242877, 9.015732436849245, 9.047055507975935, 9.078127558138869, 9.108953417578975, 9.139537770568355, 9.169885161388345, 9.200000000000001, 9.229886567425956, 9.259549020861309, 9.288991398529884, 9.31821762430111, 9.347231512081652, 9.376036769995032, 9.404637004361472, 9.433035723489462, 9.461236341289736], [0.0, 2.387470774410536, 2.9393213059397927, 3.3195135091861476, 3.6187290048334595, 3.8692702599596136, 4.086800511857504, 4.280233640175442, 4.455177997709922, 4.61541563388978, 4.763630464270911, 4.9018031834885525, 5.03144161862851, 5.15372296562547, 5.26958573391297, 5.379791466473271, 5.484967502337761, 5.585637412817409, 5.682243172928189, 5.775161641944038, 5.864717033326782, 5.951190499721777, 6.034827604668257, 6.115844220890233, 6.194431239845593, 6.270758371190668, 6.344977237057192, 6.417223913867089, 6.487621036949024, 6.556279555947833, 6.623300208909222, 6.688774767921239, 6.752787097881554, 6.815414061342532, 6.8767262957605055, 6.936788884336606, 6.995661937617831, 7.053401099860297, 7.110057991643258, 7.165680598214046, 7.220313611429039, 7.273998731848977, 7.326774936483807, 7.378678716812363, 7.429744290987008, 7.48000379354238, 7.5294874454368035, 7.578223706845855, 7.626239414785126, 7.673559907351243, 7.7202091361272585, 7.7662097680927, 7.811583278203625, 7.856350033658854, 7.900529370740864, 7.944139665010306, 7.987198395538743, 8.029722203782837, 8.071726947632664, 8.113227751105708, 8.154239050104806, 8.194774634611882, 8.234847687648672, 8.274470821300085, 8.313656110064505, 8.352415121767907, 8.390758946254245, 8.428698222043247, 8.466243161127627, 8.503403572064922, 8.540188881504127, 8.576608154273991, 8.612670112147864, 8.648383151389407, 8.683755359173892, 8.718794528971337, 8.753508174969973, 8.787903545611746, 8.82198763630528, 8.855767201376125, 8.889248765309118, 8.922438633333075, 8.955342901393873, 8.987967465558306, 9.020318030887593, 9.05240011981643, 9.084219080070577, 9.115780092153466, 9.147088176429941, 9.178148199833126, 9.208964882218483, 9.239542802387291, 9.269886403800207, 9.300000000000002, 9.329887779761277, 9.359553811983613, 9.389002050343512, 9.418236337719406, 9.447260410403016, 9.476077902109425, 9.504692347797457, 9.5331071873111], [0.0, 2.405412134553377, 2.96140971124746, 3.3444589820294905, 3.6459230216276928, 3.8983470436287493, 4.117511991386833, 4.312398730553501, 4.48865775956255, 4.650099549179574, 4.799428184043205, 4.938639243308386, 5.0692518850766, 5.192452151671966, 5.309185605236651, 5.420219511594455, 5.526185924102742, 5.6276123486050205, 5.724944081470147, 5.8185608139933045, 5.908789196034929, 5.995912493045663, 6.080178113925084, 6.161803553637079, 6.240981138150243, 6.317881852454661, 6.392658458091731, 6.465448054070173, 6.536374197298352, 6.605548671185252, 6.673072970802624, 6.739039557887202, 6.8035329275644045, 6.866630519993137, 6.928403503455935, 6.988917450241026, 7.048232922614015, 7.1064059829863515, 7.163488639855506, 7.219529239068244, 7.274572808331203, 7.328661361576408, 7.381834168718158, 7.434127995461368, 7.485577317100898, 7.536214509655918, 7.586070021189142, 7.635172525748614, 7.683549062024669, 7.731225158524608, 7.778224946822787, 7.824571264236501, 7.870285747101761, 7.915388915672769, 7.959900251540254, 8.003838268353489, 8.047220576535727, 8.090063942600812, 8.13238434360766, 8.174197017227684, 8.215516507846615, 8.256356709075302, 8.296730903003224, 8.336651796492555, 8.3761315547791, 8.4151818326187, 8.453813803193249, 8.492038184968797, 8.52986526667912, 8.567304930591082, 8.604366674193036, 8.641059630434091, 8.677392586629956, 8.713374002140517, 8.749012024914535, 8.784314506988377, 8.81928901901788, 8.853942863915568, 8.888283089659142, 8.922316501331546, 8.956049672447799, 8.989488955619239, 9.022640492601544, 9.055510223769256, 9.088103897055975, 9.120427076396377, 9.152485149703304, 9.184283336410621, 9.215826694610197, 9.247120127809177, 9.278168391331782, 9.308976098388056, 9.339547725830364, 9.36988761961688, 9.4, 9.429888966456259, 9.459558502373243, 9.489012479507837, 9.518254662229236, 9.54728871155916, 9.576118189020933, 9.604746560308275], [0.0, 2.4232963250727027, 2.9834277324925242, 3.3693249668474277, 3.6730303854764625, 3.9273311749704045, 4.148125609677756, 4.344461327804361, 4.522030839125471, 4.684672945179673, 4.83511183542014, 4.975357926092426, 5.1069416702077435, 5.231057928290876, 5.348659292719376, 5.460518733922907, 5.567273004562748, 5.669453532477675, 5.76750892480603, 5.86182169584009, 5.95272092407539, 6.040491981035459, 6.125384115100039, 6.207616438303667, 6.28738270655462, 6.364855176112925, 6.440187744298944, 6.513518529449754, 6.584972007116832, 6.654660791816543, 6.722687133234443, 6.789144180558404, 6.8541170571333945, 6.9176837788843315, 6.979916043228491, 7.040879909982736, 7.10063639169189, 7.1592419675902965, 7.216749032857551, 7.273206292790812, 7.328659109876804, 7.383149810420286, 7.436717956306573, 7.489400586592853, 7.541232432897107, 7.59224611195355, 7.642472298205627, 7.691939878892346, 7.74067609373616, 7.788706661048304, 7.836055891820901, 7.882746793166237, 7.928801162286043, 7.974239672002197, 8.01908194875066, 8.063346643829313, 8.107051498594547, 8.150213404218901, 8.192848456550394, 8.234972006552224, 8.276598706747334, 8.317742554045287, 8.358416929287628, 8.398634633811797, 8.438407923301876, 8.477748539166585, 8.516667737660194, 8.555176316940335, 8.593284642237311, 8.631002669292435, 8.668339966207702, 8.705305733835507, 8.741908824825074, 8.77815776143146, 8.81406075218326, 8.849625707496571, 8.884860254314901, 8.919771749847786, 8.954367294474498, 8.988653743873629, 9.022637720434155, 9.056325623998946, 9.089723641987513, 9.12283775894096, 9.155673765528661, 9.18823726705303, 9.220533691485931, 9.252568297067615, 9.284346179496765, 9.315872278737999, 9.347151385471275, 9.378188147205766, 9.40898707407914, 9.439552544361685, 9.469888809683283, 9.5, 9.529890128315822, 9.559563095174074, 9.589022692931955, 9.618272609830811, 9.647316433873817, 9.676157656522058], [0.0, 2.4411241270846884, 3.0053763313417994, 3.3941125496954285, 3.7000522803304965, 3.9562239199056615, 4.178642703821396, 4.376422832305261, 4.5552986940130085, 4.719137331929842, 4.870682976933381, 5.0119608355787335, 5.144512620174208, 5.269541981641636, 5.388008520427757, 5.500690893581588, 5.608230538251509, 5.711162791905588, 5.809939562012859, 5.904946176961839, 5.996514136225717, 6.084930910760513, 6.170447582626276, 6.253284875829607, 6.333637971709893, 6.41168039378881, 6.487567171584599, 6.561437439548768, 6.6334165889794425, 6.703618062879903, 6.772144863170228, 6.83909082432191, 6.904541695918699, 6.968576067836148, 7.03126616495792, 7.092678533092344, 7.1528746336437425, 7.211911361355117, 7.26984149686899, 7.326714103799567, 7.382574878358109, 7.4374664582372025, 7.4914286963726004, 7.544498904311888, 7.596712069187984, 7.648101047691181, 7.69869673993188, 7.748528245667868, 7.7976230050198625, 7.846006925504586, 7.893704496966227, 7.940738895776703, 7.987132079496259, 8.032904873033404, 8.078077047212638, 8.122667390546445, 8.166693774911531, 8.210173215746071, 8.253121927312662, 8.295555373509071, 8.337488314654498, 8.378934850631524, 8.419908460722398, 8.46042204044194, 8.50048793563734, 8.540117974096969, 8.579323494885559, 8.618115375601048, 8.656504057729077, 8.694499570253752, 8.732111551668055, 8.769349270513576, 8.806221644567058, 8.842737258780419, 8.878904382071083, 8.914730983050807, 8.9502247447733, 8.985393078573905, 9.020243137068242, 9.054781826371036, 9.089015817591111, 9.122951557653955, 9.156595279498934, 9.189953011694454, 9.223030587510916, 9.255833653488045, 9.288367677530424, 9.320637956562331, 9.352649623770686, 9.384407655462635, 9.4159168775624, 9.44718197177013, 9.478207481403855, 9.50899781694409, 9.539557261299281, 9.569889974808913, 9.600000000000001, 9.62989126611154, 9.659567593400494, 9.689032697242004, 9.718290192035612, 9.74734359492852], [0.0, 2.458896303019504, 3.027256446456931, 3.4188227906481456, 3.7269898618178345, 3.985026514072005, 4.2090645789227406, 4.4082846109333556, 4.588462746970168, 4.753494183346397, 4.906143129831116, 5.048449537140455, 5.181966341748704, 5.307905957547063, 5.427234971184968, 5.540737708587476, 5.649060276773591, 5.7527419106418956, 5.852237807694472, 5.947936101635563, 6.0401707053621205, 6.12923118271202, 6.2153704437042006, 6.298810819287668, 6.3797489117853114, 6.458359508026359, 6.534798766194265, 6.609206833684498, 6.6817100146845325, 6.752422578099533, 6.8214482757369845, 6.888881625213789, 6.954809000398494, 7.0193095633264555, 7.08245606470193, 7.144315534808331, 7.20494988250895, 7.264416416758985, 7.322768302461165, 7.380054960428733, 7.436322419556197, 7.491613627952385, 7.545968728695358, 7.599425304972876, 7.65201859863554, 7.703781705581013, 7.754745750882529, 7.804940046153555, 7.854392231287796, 7.9031284024171, 7.951173227679675, 7.9985500521789445, 8.045280993333321, 8.091387027663403, 8.136888069931713, 8.181803045437203, 8.22614995616964, 8.269945941445116, 8.313207333571317, 8.355949709028208, 8.398187935594901, 8.4399362158057, 8.481208127076403, 8.522016658805365, 8.562374246721546, 8.602292804723461, 8.641783754427909, 8.680858052625275, 8.719526216818602, 8.757798349006256, 8.795684157852575, 8.83319297937714, 8.870333796281004, 8.907115256017324, 8.94354568770392, 8.979633117966635, 9.0153852857943, 9.050809656479183, 9.085913434710273, 9.120703576881045, 9.155186802668164, 9.189369605932828, 9.22325826499222, 9.256858852304688, 9.29017724360873, 9.323219126552715, 9.355990008849343, 9.388495225986224, 9.420739948521542, 9.452729188991572, 9.484467808454836, 9.515960522695776, 9.547211908109254, 9.578226407285513, 9.609008334313963, 9.63956187982271, 9.66989111576968, 9.700000000000001, 9.729892380583347, 9.759571999943999, 9.789042498795498, 9.818307419891019], [0.0, 2.47661359725609, 3.049068994275892, 3.443456724681995, 3.7538442582059672, 4.013740163852074, 4.239392509187222, 4.440047998203738, 4.621524387057168, 4.787744938449338, 4.941493779344591, 5.084825559089098, 5.219304403662134, 5.3461514628636175, 5.466340287971811, 5.580660856281929, 5.68976393026272, 5.7941926302077515, 5.894405433492302, 5.990793270473339, 6.083692460018749, 6.173394652385309, 6.260154579905984, 6.344196175509836, 6.425717458115157, 6.504894473957555, 6.581884506400294, 6.656828712654769, 6.729854306978737, 6.801076381628802, 6.870599435984154, 6.938518668697503, 7.004921075994363, 7.069886390303021, 7.13348788652456, 7.195793077921382, 7.256864319433968, 7.3167593329505936, 7.375531666447572, 7.43323109683413, 7.489903984660675, 7.545593587493688, 7.600340337657556, 7.654182089141376, 7.707154337726844, 7.759290417780303, 7.810621678643119, 7.861177643130217, 7.9109861502913725, 7.960073484291109, 8.008464491011063, 8.056182683765114, 8.103250339336185, 8.14968858538878, 8.19551748017895, 8.24075608536971, 8.285422532662094, 8.329534084867559, 8.373107191974357, 8.416157542696983, 8.458700111942624, 8.500749204580307, 8.542318495856335, 8.583421068762682, 8.624069448632518, 8.664275635208584, 8.704051132404821, 8.743406975959509, 8.782353759158347, 8.820901656788488, 8.85906044746893, 8.896839534488873, 8.934247965273189, 8.971294449583255, 9.0079873765514, 9.04433483063839, 9.08034460659545, 9.116024223505153, 9.151380937969044, 9.186421756504092, 9.221153447204818, 9.255582550723188, 9.289715390614079, 9.323558083090235, 9.357116546227115, 9.390396508654781, 9.423403517771124, 9.456142947507997, 9.488620005679442, 9.520839740938992, 9.552807049370962, 9.58452668073884, 9.616003244412168, 9.64724121499177, 9.678244937651723, 9.709018633215226, 9.739566402980229, 9.769892233309655, 9.8, 9.829893472441158, 9.859576317579407, 9.889052103694826], [0.0, 2.494276736729108, 3.0708148697602304, 3.468015362519059, 3.7806165713218047, 4.042366047357326, 4.269627738959684, 4.471714297357574, 4.654484970782051, 4.821891002535702, 4.976736375899144, 5.121090393920687, 5.256528337882702, 5.384280066791603, 5.505326075266365, 5.6204619746983555, 5.730343168776199, 5.8355166513123296, 5.936444169529947, 6.033519441890482, 6.127081185878656, 6.217423131792787, 6.3048018287097705, 6.389442806642109, 6.471545496773527, 6.551287200896499, 6.628826324114874, 6.704305030369364, 6.77785144120628, 6.849581469717009, 6.919600360567417, 6.98800399136436, 7.054879978788023, 7.1203086239161575, 7.184363724244409, 7.247113274537893, 7.308620074450796, 7.368942257542302, 7.428133753691405, 7.486244694814866, 7.543321772105252, 7.59940855164081, 7.654545754108143, 7.708771503469945, 7.762121548662846, 7.814629461792963, 7.866326815784296, 7.917243344007666, 7.96740708406018, 8.016844507564294, 8.06558063760178, 8.113639155182824, 8.161042495967745, 8.207811938302966, 8.25396768349946, 8.299528929167499, 8.3445139363229, 8.388940090895016, 8.432823960192957, 8.476181344822697, 8.519027326492044, 8.561376312091953, 8.603242074400208, 8.644637789716315, 8.685576072703775, 8.726069008687158, 8.766128183626007, 8.805764711965173, 8.84498926254138, 8.88381208270808, 8.92224302082511, 8.960291547245665, 8.997966773920604, 9.035277472729081, 9.07223209263448, 9.10883877575572, 9.145105372435976, 9.181039455383708, 9.21664833295434, 9.25193906163513, 9.286918457790456, 9.321593108720037, 9.355969383078167, 9.390053440698248, 9.42385124186329, 9.457368556059786, 9.490610970249515, 9.52358389669106, 9.556292580340454, 9.588742105858081, 9.620937404246998, 9.65288325914587, 9.68458431279814, 9.716045071717357, 9.747269912067262, 9.778263084773844, 9.809028720385399, 9.839570833695479, 9.869893328142656, 9.9, 9.929894542366359, 9.959580548970678], [0.0, 2.5118864315095797, 3.0924949471099166, 3.4924996914343946, 3.8073078774317564, 4.070905315369043, 4.299771483718299, 4.503284781403061, 4.687345823184198, 4.8559337483020375, 5.011872336272722, 5.157245499507891, 5.293639640839565, 5.4222933021285575, 5.544193900325561, 5.660142663870589, 5.770799623628853, 5.876715635211255, 5.978355705795092, 6.076116333510078, 6.1703386272000955, 6.261318390911263, 6.349313984967352, 6.434552531631885, 6.517234870080821, 6.59753955386447, 6.675626106433132, 6.751637695410694, 6.825703346886777, 6.897939792303886, 6.9684530193594885, 7.037339582560232, 7.104687717163609, 7.170578291176233, 7.235085623107058, 7.298278187766995, 7.360219228178333, 7.420967288325536, 7.48057667883473, 7.539097885556038, 7.596577929323738, 7.653060683794353, 7.708587157144183, 7.763195742492644, 7.816922441165303, 7.869801062288709, 7.921863401692984, 7.97313940266775, 8.023657300756685, 8.073443754472972, 8.122523963562355, 8.17092177622391, 8.218659786514626, 8.265759423006914, 8.312241029633821, 8.358123939541525, 8.403426542669353, 8.448166347692023, 8.492360038884522, 8.536023528405737, 8.579172004440949, 8.621819975594343, 8.663981311880075, 8.705669282622855, 8.746896591546223, 8.787675409297629, 8.828017403633957, 8.867933767468493, 8.907435244960377, 8.946532155809791, 8.985234417906396, 9.023551568464462, 9.061492783765587, 9.099066897618748, 9.136282418637355, 9.173147546424017, 9.209670186745646, 9.245857965774332, 9.281718243462787, 9.31725812611735, 9.352484478226213, 9.387403933595694, 9.422022905843043, 9.45634759829034, 9.490384013300432, 9.524137961092618, 9.557615068072858, 9.590820784710496, 9.62376039299117, 9.656439013473168, 9.688861611972634, 9.721033005900912, 9.752957870275871, 9.78464074342723, 9.816086032414622, 9.847298018175751, 9.878280860420743, 9.909038602287758, 9.939575174773806, 9.969894400953795, 9.999999999999998, 10.02989559101324], [0.0, 2.5294433753605827, 3.1141100804474897, 3.5169106760286746, 3.833919228084015, 4.099359092238936, 4.3298249310257955, 4.534760694111685, 4.720108238871289, 4.889874516918672, 5.046903044704654, 5.193292300240949, 5.330639774593945, 5.46019266646882, 5.582945294411715, 5.699704487085074, 5.811134888669699, 5.917791205006706, 6.0201416934620955, 6.118585623507194, 6.213466488181583, 6.305082159067142, 6.393692802308815, 6.479527127651459, 6.56278737804554, 6.643653355049486, 6.722285697109969, 6.798828572527461, 6.873411909225273, 6.9461532545456075, 7.017159336991741, 7.08652738594241, 7.154346253379432, 7.220697372540014, 7.2856555813856865, 7.349289833335152, 7.411663813450662, 7.472836474912512, 7.532862507953404, 7.5917927512965955, 7.649674554430613, 7.706552097668885, 7.762466675816216, 7.817456950342467, 7.8715591742061, 7.924807392844081, 7.977233624324927, 8.028868021228236, 8.079739016451299, 8.12987345483818, 8.179296712269386, 8.22803280363206, 8.276104480905374, 8.323533322437717, 8.370339814356976, 8.416543424939226, 8.462162672661108, 8.50721518857502, 8.551717773571434, 8.595686451027998, 8.639136515288499, 8.68208257636567, 8.724538601218752, 8.766517951919006, 8.808033420983222, 8.849097264126138, 8.889721230656955, 8.929916591722332, 8.969694166578197, 9.009064347054741, 9.048037120363164, 9.086622090378526, 9.124828497520461, 9.162665237342257, 9.200140877928657, 9.237263676193765, 9.27404159316221, 9.310482308309556, 9.346593233031236, 9.38238152330344, 9.41785409159401, 9.453017618076556, 9.487878561196593, 9.522443167634604, 9.556717481707217, 9.59070735424453, 9.624418450978515, 9.657856260474821, 9.691026101637762, 9.723933130816006, 9.756582348534483, 9.788978605876059, 9.821126610534852, 9.853030932561438, 9.884696009818796, 9.916126153166434, 9.947325551388964, 9.978298275884242, 10.009048285125157, 10.039579428908178, 10.069895452400894, 10.100000000000001]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha = 0.4\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.1, 0.1319507910772894, 0.15518455739153597, 0.17411011265922482, 0.19036539387158785, 0.20476725110792196, 0.21779064244827798, 0.229739670999407, 0.2408224685280692, 0.251188643150958, 0.2609498635278873, 0.2701920077041227, 0.27898274358890857, 0.2873764756028137, 0.29541769390627776, 0.3031433133020796, 0.31058435015977326, 0.3177671523146437, 0.32471431911356685, 0.33144540173399867, 0.3379774445235429, 0.3443254092401545, 0.3505025116517289, 0.3565204915932007, 0.36238983183884776, 0.3681199371346908, 0.3737192818846552, 0.37919553292794633, 0.3845556523418775, 0.38980598409161893, 0.3949523275150298, 0.4, 0.4049538907295691, 0.4098185069980794, 0.414598014312126, 0.41929627126294755, 0.4239168599773808, 0.4284631128115855, 0.4329381358372115, 0.43734482957731124, 0.4416859073743617, 0.4459639117116218, 0.4501812287589041, 0.4543401013724981, 0.45844264074473967, 0.46249083687022485, 0.46648656797184945, 0.47043160900986947, 0.47432763938033673, 0.47817624989501856, 0.48197894912282235, 0.4857371691624451, 0.48945227090716775, 0.4931255488551678, 0.4967582355122337, 0.5003515054281688, 0.5039064789033284, 0.5074242253975382, 0.5109057666699868, 0.5143520796755041, 0.5177640992398568, 0.5211427205342488, 0.5244888013670841, 0.5278031643091577, 0.5310865986667878, 0.5343398623159287, 0.5375636834090112, 0.5407587619651025, 0.5439257713529524, 0.547065359675584, 0.5501781510642736, 0.5532647468890367, 0.5563257268920875, 0.5593616502501593, 0.5623730565710474, 0.565360466829266, 0.5683243842452905, 0.5712652951124705, 0.5741836695753587, 0.5770799623628855, 0.5799546134795288, 0.5828080488573741, 0.5856406809717238, 0.5884529094227096, 0.591245121485164, 0.594017692628836, 0.5967709870108765, 0.5995053579423699, 0.6022211483305613, 0.6049186910983, 0.607598309582116, 0.6102603179102379, 0.6129050213617684, 0.6155327167081528, 0.6181436925379863, 0.6207382295661439, 0.623316600928143, 0.6258790724605868, 0.628425902968486, 0.6309573444801932, 0.6334736424906476], [0.0, 0.1515716566510398, 0.19999999999999998, 0.23521580450493473, 0.2639015821545788, 0.2885399811814427, 0.310369114783072, 0.33010888478979766, 0.34822022531844965, 0.36501860513592344, 0.3807307877431757, 0.3955260311778463, 0.40953450221584387, 0.42285876622823126, 0.43558128489655595, 0.44776949269404304, 0.45947934199881396, 0.4707578448360347, 0.4816449370561384, 0.4921748728635773, 0.502377286301916, 0.5122780117711829, 0.5218997270557746, 0.5312624635140294, 0.5403840154082454, 0.5492802716530589, 0.5579654871778171, 0.5664525067769413, 0.5747529512056274, 0.5828773729997969, 0.5908353878125555, 0.5986357857963711, 0.6062866266041592, 0.6137953208516493, 0.6211687003195465, 0.6284130787352045, 0.6355343046292874, 0.6425378074907848, 0.6494286382271337, 0.6562115047625906, 0.6628908034679973, 0.6694706470014973, 0.6759548890470857, 0.6823471463618782, 0.688650818480309, 0.6948691053715768, 0.7010050233034578, 0.707061419129511, 0.7130409831864014, 0.7189462609625462, 0.7247796636776956, 0.7305434778947342, 0.7362398742693816, 0.7418709155301295, 0.7474385637693105, 0.7529446871163665, 0.7583910658558928, 0.7637793980456973, 0.769111304683755, 0.7743883344673949, 0.7796119681832379, 0.7847836227621847, 0.7899046550300596, 0.7949763651812709, 0.8000000000000002, 0.8049767558509093, 0.8099077814591382, 0.814794180497389, 0.8196370139961588, 0.8244373025916167, 0.8291960286242521, 0.83391413810018, 0.8385925425258952, 0.8432321206262763, 0.8478337199547615, 0.8523981584038258, 0.8569262256231709, 0.8614186843524079, 0.865876271674423, 0.8702997001951036, 0.8746896591546225, 0.8790468154750565, 0.8833718147487235, 0.8876652821712726, 0.8919278234232436, 0.8961600255035158, 0.9003624575178082, 0.904535671425147, 0.9086802027449962, 0.9127965712275475, 0.9168852814894793, 0.9209468236173268, 0.9249816737404498, 0.9289902945754418, 0.9329731359436989, 0.9369306352637357, 0.9408632180197389, 0.9447712982077369, 0.9486552787606733, 0.9525155519535902, 0.956352499790037, 0.9601664943707598], [0.0, 0.1933182044931763, 0.25508490012515816, 0.30000000000000004, 0.33658654363385987, 0.36801096140891665, 0.39585237323186834, 0.42102895953516445, 0.44412860698458406, 0.4655536721746079, 0.48559337483020387, 0.5044635907995056, 0.5223303379776746, 0.5393244307518799, 0.5555510427711303, 0.5710961816147636, 0.5860312103167044, 0.6004160891656731, 0.6143017533237658, 0.6277318914425902, 0.6407442995073612, 0.6533719273448341, 0.6656436987568479, 0.6775851622286084, 0.6892190129982211, 0.7005655161767015, 0.7116428528501936, 0.7224674055842077, 0.7330539957746369, 0.7434160823843389, 0.7535659294528742, 0.7635147481560646, 0.7732728179727052, 0.782849590583662, 0.7922537794094292, 0.801493437132564, 0.8105760231123682, 0.8195084622521248, 0.8282971966029294, 0.8369482307667259, 0.8454671719825998, 0.8538592656355098, 0.8621294268084412, 0.870282268402032, 0.8783221262657902, 0.8862530817188333, 0.8940789817829836, 0.9018034574050197, 0.909429939906239, 0.9169616758649352, 0.9244017406098536, 0.9317530504793198, 0.9390183739808212, 0.9462003419688138, 0.9533014569439312, 0.9603241015642342, 0.9672705464483133, 0.9741429573407007, 0.9809434017019287, 0.9876738547785151, 0.9943362052019962, 1.0009322601607584, 1.0074637501837014, 1.0139323335706287, 1.0203396005006329, 1.0266870768465153, 1.0329762277204637, 1.039208460773683, 1.0453851292704652, 1.051507534955187, 1.0575769307289757, 1.063594523151209, 1.0695614747796023, 1.075478906361395, 1.0813478988870084, 1.0871694955165434, 1.0929447033885766, 1.0986744953198957, 1.1043598114040727, 1.1100015605161155, 1.1156006217298278, 1.1211578456539657, 1.1266740556927892, 1.1321500492361471, 1.1375865987838392, 1.1429844530086177, 1.1483443377618605, 1.1536669570256326, 1.158952993814579, 1.1642031110308289, 1.169417952274857, 1.1745981426150374, 1.1797442893184213, 1.1848569825450892, 1.1899367960082703, 1.1949842876022552, 1.2000000000000002, 1.2049844612221832, 1.2099381851793523, 1.2148616721887073, 1.2197554094669347, 1.2246198716004426], [0.0, 0.22973967099940704, 0.30314331330207966, 0.35652049159320076, 0.4, 0.43734482957731124, 0.4704316090098695, 0.5003515054281688, 0.5278031643091577, 0.5532647468890367, 0.5770799623628855, 0.5995053579423699, 0.620738229566144, 0.6409340372662778, 0.6602177695795954, 0.6786916380543178, 0.6964404506368994, 0.7135354642327094, 0.730037210271847, 0.7459976084194732, 0.7614615754863515, 0.7764682691005909, 0.7910520623556927, 0.8052433171133403, 0.8190690044316878, 0.8325532074018733, 0.8457175324564626, 0.8585814486631534, 0.8711625697931121, 0.8834768904998529, 0.8955389853880863, 0.9073621778375299, 0.9189586839976281, 0.9303397362614103, 0.9415156896720696, 0.9524961140507527, 0.963289874112277, 0.9739051994230516, 0.9843497457271546, 0.9946306489033756, 1.0047545726038323, 1.0147277504526042, 1.024556023542366, 1.0342448738517942, 1.0437994541115494, 1.0532246145679585, 1.0625249270280588, 1.071704706514952, 1.0807680308164909, 1.0897187581716394, 1.098560543306118, 1.1072968520011714, 1.1159309743556345, 1.1244660368812536, 1.1329050135538827, 1.1412507359282653, 1.149505902411255, 1.1576730867772032, 1.1657547459995938, 1.1737532274646256, 1.181670775625111, 1.1895095381466902, 1.1972715715927424, 1.2049588466894725, 1.2125732532083189, 1.2201166044990195, 1.2275906417032991, 1.234997037676156, 1.2423374006390933, 1.2496132775872597, 1.2568261574704094, 1.2639774741656828, 1.271068609258575, 1.2781008946469414, 1.2850756149815696, 1.2919940099556335, 1.2988572764542674, 1.3056665705745363, 1.3124230095251812, 1.3191276734147515, 1.3257816069359951, 1.3323858209537522, 1.3389412940029948, 1.3454489737031252, 1.3519097780941716, 1.35832459690006, 1.3646942927237566, 1.3710197021787016, 1.3773016369606181, 1.3835408848634825, 1.3897382107431537, 1.395894357431912, 1.4020100466069159, 1.4080859796153722, 1.4141228382590225, 1.4201212855403558, 1.426081966372803, 1.4320055082570027, 1.4378925219250926, 1.4437436019548526, 1.4495593273553913, 1.4553402621259737], [0.0, 0.2626527804403767, 0.3465724215775732, 0.40759655480296136, 0.4573050519273263, 0.49999999999999994, 0.5378268784662851, 0.5720331779293615, 0.6034176336545163, 0.6325269095141249, 0.6597539553864471, 0.6853920721113645, 0.709666820762555, 0.7327559329851151, 0.754802303502351, 0.7759227869576798, 0.7962143411069944, 0.8157584313073201, 0.8346242608806185, 0.852871187639821, 0.870550563296124, 0.8877071553024171, 0.9043802611319715, 0.9206045923666214, 0.9364109840092412, 0.9518269693579393, 0.9668772502396322, 0.981584084911856, 0.9959676105409553, 1.01004611321657, 1.0238362555396097, 1.0373532696322088, 1.0506111217615068, 1.063622653502698, 1.0763997033896955, 1.0889532122413899, 1.101293314754956, 1.1134294194861292, 1.1253702789610172, 1.137124051363171, 1.1486983549970349, 1.160100316532068, 1.1713366138712415, 1.1824135143559145, 1.1933369089104924, 1.204112342640346, 1.2147450423216124, 1.2252399411589503, 1.235601701134824, 1.2458347332296575, 1.25594321575479, 1.2659311110084015, 1.2758021804375381, 1.2855599984662411, 1.2952079651299664, 1.3047493176394367, 1.3141871409823676, 1.3235243776587924, 1.3327638366346783, 1.3419082015889436, 1.3509600385206133, 1.359921802775555, 1.3687958455458267, 1.377584419889051, 1.386289686310293, 1.3949137179445428, 1.4034585053740674, 1.4119259611114718, 1.4203179237763002, 1.4286361619902954, 1.4368823780140687, 1.4450582111457708, 1.4531652409004676, 1.4612049899872042, 1.4691789270992188, 1.4770884695313886, 1.484934985637761, 1.4927197971409056, 1.5004441813038272, 1.508109372974265, 1.5157165665103982, 1.5232669175962223, 1.5307615449542022, 1.538201531962189, 1.5455879281810383, 1.5529217507988662, 1.5602039859974082, 1.5674355902455464, 1.5746174915246673, 1.5817505904901845, 1.5888357615732185, 1.5958738540261557, 1.602865692915522, 1.6098120800653695, 1.6167137949541506, 1.6235715955678343, 1.6303862192118455, 1.6371583832842145, 1.6438887860121714, 1.6505781071542722, 1.6572270086699934, 1.6638361353586175], [0.0, 0.2930156051583522, 0.3866364089863526, 0.4547149699531195, 0.5101698002503163, 0.5578003108649138, 0.6000000000000002, 0.6381605689480848, 0.6731730872677197, 0.7056474135148042, 0.7360219228178334, 0.7646238217761332, 0.7917047464637367, 0.8174629744144144, 0.8420579190703289, 0.8656199435443283, 0.8882572139691681, 0.9100606131477952, 0.9311073443492159, 0.9514636271864408, 0.9711867496604077, 0.9903266543693932, 1.0089271815990113, 1.0270270556115375, 1.0446606759553492, 1.0618587587949346, 1.07864886150376, 1.0950558154077705, 1.1111020855422606, 1.1268080718802014, 1.1421923632295274, 1.1572719525551616, 1.1720624206334087, 1.186578093533539, 1.2008321783313465, 1.2148368806111876, 1.2286035066475318, 1.2421425526310068, 1.2554637828851805, 1.2685762986846942, 1.2814885990147225, 1.2942086343921448, 1.3067438546896681, 1.3191012517572087, 1.331287397513696, 1.3433084780821294, 1.3551703244572169, 1.3668784401251426, 1.3784380259964422, 1.3898540029636202, 1.401131032353403, 1.4122735345081043, 1.4232857057003874, 1.434171533559935, 1.4449348111684155, 1.455579149960124, 1.466107991549274, 1.4765246185907321, 1.4868321647686777, 1.4970336239969806, 1.5071318589057483, 1.5171296086803574, 1.5270294963121294, 1.5368340353135492, 1.5465456359454106, 1.5561666109983974, 1.5656991811673242, 1.5751454800524425, 1.5845075588188584, 1.5937873905420885, 1.6029868742651283, 1.6121078387900145, 1.6211520462247366, 1.6301211953044517, 1.6390169245042496, 1.647840814959177, 1.6565943932058589, 1.6652791337588169, 1.673896461533452, 1.6824477541266705, 1.6909343439652, 1.6993575203308238, 1.7077185312710197, 1.7160185854027914, 1.7242588536168826, 1.7324404706889875, 1.740564536804064, 1.748632118999391, 1.7566442525315806, 1.764601942172372, 1.7725061634376669, 1.7803578637539554, 1.7881579635659675, 1.7959073573891136, 1.8036069148100395, 1.8112574814383644, 1.818859879812478, 1.8264149102620693, 1.83392335172987, 1.8413859625549485, 1.8488034812197072, 1.8561766270626276], [0.0, 0.3214095849716039, 0.42410248996826405, 0.4987780418521562, 0.5596065904916064, 0.6118526223722295, 0.6581415719437339, 0.7, 0.7384053230743222, 0.7740264966144386, 0.8073443754472972, 0.8387178733489493, 0.8684230105882647, 0.8966772783115048, 0.9236555375410259, 0.9495007839168503, 0.9743316651533829, 0.9982478708352801, 1.0213340854305806, 1.0436629454062847, 1.0652972901207103, 1.0862919017407517, 1.106694868790557, 1.1265486680148695, 1.1458910323684282, 1.164755654492534, 1.183172762142339, 1.2011695928643287, 1.2187707886145738, 1.2359987261768723, 1.2528737956633487, 1.2694146367017467, 1.2856383398864155, 1.3015606195202702, 1.3171959624793503, 1.332557757101115, 1.3476584052676501, 1.3625094202779546, 1.3771215126441316, 1.39150466557818, 1.4056682016392041, 1.4196208417699987, 1.4333707577554535, 1.4469256189740602, 1.4602926341809104, 1.4734785889505286, 1.486489879316287, 1.4993325420666, 1.5120122820938597, 1.524534497137946, 1.5369043002203584, 1.5491265400261611, 1.5612058194578322, 1.573146512556818, 1.5849527799643384, 1.5966285830721327, 1.6081776969958492, 1.6196037224882105, 1.6309100968956034, 1.6421001042499952, 1.6531768845778512, 1.6641434424987869, 1.6750026551788546, 1.6857572796964848, 1.6964099598730564, 1.7069632326147302, 1.7174195338074658, 1.7277812038029692, 1.7380504925296194, 1.7482295642591192, 1.7583205020567063, 1.7683253119401257, 1.7782459267702475, 1.7880842098941168, 1.7978419585593512, 1.8075209071171265, 1.8171227300294661, 1.8266490446952115, 1.8361014141077994, 1.8454813493568856, 1.854790311984838, 1.8640297162082229, 1.8732009310135884, 1.8823052821360922, 1.8913440539288588, 1.9003184911303204, 1.9092298005362391, 1.918079152582602, 1.9268676828450992, 1.935596493460484, 1.9442666544747045, 1.95287920512236, 1.961435155041686, 1.96993548542898, 1.9783811501361122, 1.9867730767144887, 1.9951121674086247, 2.0033993001022528, 2.011635329219696, 2.0198210865850648, 2.027957382241642, 2.0360450052336923], [0.0, 0.3482202253184497, 0.459479341998814, 0.5403840154082454, 0.6062866266041592, 0.6628908034679973, 0.7130409831864014, 0.7583910658558927, 0.8, 0.8385925425258951, 0.8746896591546225, 0.9086802027449961, 0.9408632180197389, 0.97147433832489, 1.0007030108563375, 1.0287041593510082, 1.0556063286183155, 1.081517523930205, 1.1065294937780734, 1.1307209336585322, 1.1541599247257708, 1.1769058188454191, 1.1990107158847398, 1.2205206358204759, 1.241476459132288, 1.2619146889603867, 1.2818680745325557, 1.3013661254372384, 1.3204355391591909, 1.3391005590597198, 1.3573832761086355, 1.375303884773298, 1.3928809012737988, 1.410131350734334, 1.4270709284654186, 1.4437141396035034, 1.460074420543694, 1.4761642449761323, 1.491995216838946, 1.5075781521018337, 1.5229231509727028, 1.5380396618588412, 1.5529365382011815, 1.5676220891256212, 1.5821041247113854, 1.5963899965571833, 1.6104866342266806, 1.6244005780718769, 1.6381380088633757, 1.651704774597892, 1.6651064148037464, 1.6783481826229878, 1.6914350649129253, 1.7043718005792083, 1.717162897326307, 1.729812646988655, 1.742325139586224, 1.7547042762314362, 1.7669537809997056, 1.7790772118631806, 1.7910779707761724, 1.8029593129910706, 1.8147243556750599, 1.826376085890496, 1.8379173679952563, 1.849350950513579, 1.8606794725228206, 1.871905469597016, 1.883031379344139, 1.894059546570366, 1.9049922281015055, 1.9158315972888942, 1.926579748224554, 1.93723869968813, 1.947810398846103, 1.9582967247219538, 1.968699491454309, 1.9790204513586422, 1.989261297806751, 1.9994236679370565, 2.0095091452076645, 2.019519261803159, 2.0294555009052084, 2.0393192988362396, 2.0491120470847317, 2.058835094219979, 2.0684897477035884, 2.07807727560441, 2.087598908223099, 2.0970558396320356, 2.106449229135917, 2.1157802026579358, 2.1250498540561176, 2.134259246374042, 2.143409413029904, 2.1525013589475606, 2.1615360616329817, 2.1705144721992813, 2.1794375163432784, 2.188306095276364, 2.1971210866122357, 2.2058833452139233], [0.0, 0.3737192818846552, 0.4931255488551677, 0.5799546134795288, 0.6506830627186191, 0.7114321829337935, 0.7652547003754746, 0.8139256249696815, 0.8585814486631532, 0.8999999999999999, 0.9387403933595694, 0.9752199560554082, 1.0097596309015795, 1.042612305922578, 1.0739813009282666, 1.10403288422675, 1.1329050135538823, 1.1607136030632275, 1.1875571196956047, 1.2135200215678696, 1.2386753752000104, 1.2630868786054932, 1.2868104467587054, 1.3098954695325211, 1.332385820953752, 1.3543206771711516, 1.3757351855340105, 1.3966610165238238, 1.4171268225970124, 1.4371586223789157, 1.4567801244906116, 1.4760130021759006, 1.4948771275386208, 1.5133907723985167, 1.531570781383638, 1.5494327217953172, 1.5669910139330234, 1.5842590448954468, 1.6012492683400972, 1.6179732922556398, 1.6344419564559964, 1.6506654012251878, 1.6666531283133907, 1.6824140552972933, 1.697956564163314, 1.7132885448442907, 1.7284174343337364, 1.7433502519127695, 1.758093630950113, 1.7726538476726312, 1.7870368472506375, 1.8012482674970192, 1.8152934604407425, 1.8291775120024043, 1.8429052599712976, 1.856481310459204, 1.8699100529852137, 1.8831956743277705, 1.896342171264454, 1.9093533623063665, 1.9222328985220836, 1.934984273535746, 1.9476108327747501, 1.960115782034502, 1.9725021954206712, 1.9847730227231601, 1.9969310962705438, 2.0089791373088577, 2.020919761944333, 2.032755486685825, 2.0444887336192985, 2.056121835243677, 2.067657038994663, 2.079096511480697, 2.0904423424530516, 2.101696548530104, 2.112861076694067, 2.123937807576888, 2.134928558550581, 2.1458350866359917, 2.156659091242814, 2.1674022167526226, 2.178066054955749, 2.188652147351931, 2.1991619873239108, 2.2095970221924115, 2.219958655160284, 2.2302482471530163, 2.2404671185622567, 2.250616550898498, 2.2606977883586223, 2.270712039313588, 2.2806604777211548, 2.2905442444681934, 2.3003644486468176, 2.310122168768253, 2.3198184539181153, 2.329454324856498, 2.3390307750660457, 2.348548771750986, 2.3580092567898685, 2.367413147644616], [0.0, 0.39810717055349726, 0.5253055608807534, 0.617800850567412, 0.6931448431551464, 0.757858283255199, 0.8151931096059228, 0.8670401643811234, 0.9146101038546527, 0.9587315155141827, 1.0, 1.0388601182540846, 1.0756537569325701, 1.110650306834322, 1.144066355858723, 1.1760790225246736, 1.2068352673090326, 1.2364585686030396, 1.2650538190282499, 1.292710988205075, 1.3195079107728942, 1.3455124415016924, 1.370784144222729, 1.39537563185564, 1.4193336415251103, 1.4426999059072136, 1.4655118659702304, 1.4878032589238495, 1.5096046070047022, 1.5309436267417922, 1.5518455739153598, 1.5723335361052666, 1.592428682213989, 1.6121504764297885, 1.6315168626146401, 1.6505444239489884, 1.6692485217612372, 1.6876434167551815, 1.705742375279642, 1.7235577628285792, 1.7411011265922482, 1.758383268581612, 1.7754143106048341, 1.79220375217504, 1.8087605222639431, 1.8250930256796174, 1.8412091847332428, 1.8571164767648465, 1.8728219680184823, 1.8883323442902544, 1.9036539387158786, 1.918792757016348, 1.9337545004792647, 1.9485445869183637, 1.9631681698237122, 1.9776301558892317, 1.9919352210819108, 2.0060878253977963, 2.02009222643314, 2.033952491884537, 2.0476725110792193, 2.0612560056255953, 2.0747065392644175, 2.088027526992451, 2.101222243523014, 2.1142938311411563, 2.1272453070053965, 2.140079569942774, 2.152799406779391, 2.1654074982445235, 2.17790642448278, 2.1902986702055256, 2.2025866295099124, 2.214772610391266, 2.2268588389722583, 2.2388474634702153, 2.2507405579220343, 2.2625401256845117, 2.274248102726342, 2.2858663607267022, 2.29739670999407, 2.3088409022178236, 2.320200633064136, 2.3314775446267633, 2.342673227742483, 2.3537892241801734, 2.364827028711829, 2.375788091073179, 2.3866738178209848, 2.397485574093577, 2.4082246852806923, 2.418892438608241, 2.4294900846432252, 2.440018838723644, 2.450479882317901, 2.4608743643178865, 2.471203402269648, 2.481468083545264, 2.491669466459315, 2.5018085813331057, 2.51188643150958, 2.521903994321694], [0.0, 0.4215369133091901, 0.556221291794264, 0.6541601931608093, 0.7339383946628497, 0.8024604053351735, 0.8631695497884125, 0.9180679516527257, 0.9684375177775888, 1.0151556003882185, 1.0588528529217847, 1.1, 1.1389590492840878, 1.1760152459899775, 1.2113979248328386, 1.2452946282617143, 1.2778609657967936, 1.3092276828849148, 1.3395058453776614, 1.368790717864283, 1.3971647157747427, 1.4246996873258229, 1.4514587018501839, 1.4774974686878823, 1.5028654755767288, 1.5276069112798434, 1.5517614202733065, 1.5753647252978467, 1.5984491449107985, 1.6210440268379704, 1.643176113234323, 1.6648698504496595, 1.6861476532367603, 1.7070301313068958, 1.727536284569511, 1.74768367217253, 1.7674885595023577, 1.7869660465458923, 1.8061301804144303, 1.8249940543465297, 1.8435698951175354, 1.8618691404675727, 1.8799025079020921, 1.8976800560076683, 1.9152112392514733, 1.9325049570885149, 1.9495695980805874, 1.9664130796305108, 1.9830428838509613, 1.9994660900162176, 2.0156894039851, 2.0317191849324168, 2.04756146968281, 2.06322199490381, 2.0787062173830764, 2.0940193325874668, 2.109166291677967, 2.124151817134116, 2.13898041712385, 2.153656398739315, 2.168183880205746, 2.182566802158824, 2.1968089380756113, 2.2109139039351753, 2.2248851671770566, 2.2387260550187436, 2.2524397621871417, 2.2660293581135322, 2.2794977936366836, 2.2928479072544383, 2.306082430960275, 2.319203995697912, 2.3322151364639487, 2.34511829708582, 2.357915834699869, 2.3706100239521386, 2.3832030609425154, 2.395697066931058, 2.4080940918237435, 2.420396117453406, 2.432605060670343, 2.44472277625585, 2.4567510596708915, 2.468691649651126, 2.480546230658614, 2.4923164351997307, 2.504003846018067, 2.515609998170436, 2.5271363809934773, 2.538584439967807, 2.549955578486128, 2.5612511595312686, 2.572472507269667, 2.5836209085654307, 2.5946976144197484, 2.6057038413400773, 2.6166407726432372, 2.6275095596962563, 2.638311323098547, 2.6490471538087617, 2.65971811421944, 2.67032523918237], [0.0, 0.444128606984584, 0.5860312103167042, 0.6892190129982211, 0.7732728179727051, 0.8454671719825998, 0.909429939906239, 0.9672705464483131, 1.0203396005006327, 1.069561474779602, 1.1156006217298275, 1.158952993814579, 1.2, 1.2390421728287935, 1.2763211378961694, 1.3120344887319337, 1.3463461745354393, 1.3793939478767236, 1.4112948270296084, 1.4421491821585612, 1.4720438456356666, 1.5010545162845061, 1.5292476435522662, 1.556681922444803, 1.5834094929274733, 1.6094769119996513, 1.6349259488288288, 1.65979424066711, 1.6841158381406578, 1.7079216618264603, 1.7312398870886565, 1.7540962704456937, 1.776514427938336, 1.7985160738271098, 1.8201212262955901, 1.8413483855501915, 1.8622146886984317, 1.882736044990331, 1.9029272543728812, 1.9228021117988336, 1.9423734993208153, 1.9616534676689728, 1.980653308738786, 1.9993836201930044, 2.0178543631980226, 2.0360749141629535, 2.0540541112230746, 2.0718002961035697, 2.089321351910698, 2.1066247373227505, 2.1237175175898693, 2.140606392698128, 2.15729772300752, 2.1737975526344164, 2.190111630815541, 2.206245431461683, 2.2222041710845213, 2.237992825258419, 2.2536161437604023, 2.2690786645153214, 2.2843847264590544, 2.299538481420255, 2.314543905110323, 2.3294048073017724, 2.344124841266818, 2.358707512540613, 2.373156187067078, 2.3874740987794607, 2.4016643566626925, 2.4157299513400208, 2.429673761222375, 2.443498558255299, 2.4572070132950636, 2.4708017011426895, 2.484285105262013, 2.4976596222056195, 2.5109275657703605, 2.5240911709023233, 2.537152597369388, 2.5501139332180074, 2.562977198029445, 2.57574434598946, 2.5884172687842897, 2.600997798334749, 2.613487709379336, 2.62588872191637, 2.638202503514417, 2.6504306714995582, 2.6625747950273917, 2.674636397047087, 2.6866169561642588, 2.6985179084089324, 2.7103406489144333, 2.7220865335125892, 2.733756880250285, 2.7453529708320286, 2.7568760519928843, 2.7683273368058203, 2.7797080059272394, 2.7910192087842307, 2.8022620647068055, 2.8134376640082173], [0.0, 0.4659786420036066, 0.6148625043749694, 0.7231268931323869, 0.8113159385604054, 0.887062077207642, 0.9541716559808098, 1.0148578780914161, 1.0705377990665903, 1.1221812684866597, 1.1704854282221195, 1.215970630377514, 1.259037048301951, 1.3, 1.339112998451817, 1.3765833583028444, 1.412583094649769, 1.4472567371502378, 1.4807270610893088, 1.5130993745966563, 1.5444647819834854, 1.574902706269298, 1.6044828660506327, 1.6332668439832594, 1.6613093451905792, 1.6886592171618164, 1.7153602840047626, 1.741452034631747, 1.7669701948759833, 1.7919472065307913, 1.8164126311189208, 1.8403934923161724, 1.8639145680144265, 1.886998640762415, 1.9096667135891061, 1.9319381968655633, 1.9538310708028417, 1.9753620273469294, 1.996546594565807, 2.0173992460899677, 2.0379334977373427, 2.0581619931043584, 2.0780965796199786, 2.097748376325891, 2.117127834453376, 2.136244791707811, 2.155108521038989, 2.173727774564455, 2.192110823219906, 2.2102654926322574, 2.2281991956445797, 2.2459189618657818, 2.263431464569923, 2.280743045229034, 2.2978597359281423, 2.3147872798809845, 2.3315311502387828, 2.34809656736192, 2.3644885147047683, 2.3807117534469193, 2.396770835989223, 2.4126701184200905, 2.4284137720461434, 2.444005794071332, 2.459450017499878, 2.474750120330642, 2.4899096341037055, 2.504931951853877, 2.5198203355205004, 2.5345779228581296, 2.5492077338884322, 2.5637126769298537, 2.578095554238225, 2.5923590672884425, 2.6065058217246557, 2.620538332003941, 2.634459025756265, 2.648270247881564, 2.6619742644029856, 2.675573266093732, 2.6890693718934977, 2.702464632129174, 2.715761031553308, 2.7289604922127126, 2.7420648761586555, 2.755075988009141, 2.7679955773730076, 2.7808253411448014, 2.793566925678716, 2.8062219288492747, 2.81879190200585, 2.831278351827614, 2.843682742085019, 2.8560064953134834, 2.8682509944045576, 2.8804175841194577, 2.8925075725295475, 2.904522232388001, 2.9164628024366115, 2.9283304886514534, 2.9401264654308226, 2.9518518767287016], [0.0, 0.4871658325766915, 0.6428191699432078, 0.7560061410469299, 0.8482049799365281, 0.927395155992419, 0.9975560837043126, 1.0610015965572788, 1.119213180983213, 1.1732047838365092, 1.2237052447444592, 1.2712585752633725, 1.3162831438874678, 1.3591086055502029, 1.4000000000000001, 1.43917406809738, 1.4768106461486445, 1.5130608353087662, 1.5480529932288773, 1.5818972162053428, 1.6146887508945944, 1.6465106315345432, 1.6774357466978989, 1.7075284790903604, 1.7368460211765295, 1.765439441450995, 1.7933545566230098, 1.820632651093013, 1.8473110750820523, 1.8734237454520348, 1.899001567833701, 1.9240727946196163, 1.948663330306766, 1.9727969933244107, 1.9964957416705604, 2.019779868270099, 2.0426681708611616, 2.065178100341775, 2.0873258908125694, 2.109126673993359, 2.1305945802414206, 2.151742828034224, 2.172583803481504, 2.1931291311872956, 2.2133897375811142, 2.233375907670682, 2.253097336029739, 2.272563172718494, 2.2917820647368567, 2.3107621935285843, 2.329511308985068, 2.348036760338586, 2.366345524284678, 2.3844442306304274, 2.402339185728658, 2.420036393926455, 2.437541577229148, 2.45486019335729, 2.4719974523537447, 2.48895833188017, 2.5057475913266973, 2.5223697848450555, 2.538829273403494, 2.555130235951465, 2.5712766797728315, 2.587272450098289, 2.603121239040541, 2.6188265939094393, 2.634391924958701, 2.649820512610802, 2.6651155142022307, 2.6802799702873163, 2.6953168105353007, 2.710228859252169, 2.7250188405559097, 2.7396893832313314, 2.7542430252882637, 2.768682218244925, 2.7830093311563604, 2.7972266544061952, 2.811336403278409, 2.82534072132448, 2.839241683539998, 2.853041299363704, 2.8667415155109075, 2.8803442186522696, 2.893851237948121, 2.9072643474476756, 2.9205852683618208, 2.933815671217491, 2.9469571779010577, 2.9600113635976193, 2.972979758632575, 2.985863850221408, 2.9986650841332008, 3.011384866272985, 3.0240245641877195, 3.0365855085003215, 3.0490689942758924, 3.0614762823240165, 3.073808600440717, 3.0860671445934575], [0.0, 0.5077556391987408, 0.6699875826622859, 0.7879583413211302, 0.8840539154424946, 0.9665910224658812, 1.0397172647327195, 1.1058442686782979, 1.166516134976123, 1.222789664408884, 1.2754245006257907, 1.324987647544266, 1.3719151557819789, 1.4165506129640464, 1.4591702606038799, 1.4999999999999998, 1.5392272681452155, 1.5770095524050118, 1.6134806353988551, 1.64875526658493, 1.682932718169299, 1.7160995337880844, 1.7483316826110262, 1.779696268444877, 1.8102529009635488, 1.8400548070445832, 1.8691497398162518, 1.8975807285423747, 1.9253867020313653, 1.9526030106233871, 1.9792618661593413, 2.0053927151042434, 2.031022556794963, 2.0561762163340935, 2.080876579762834, 2.105144797675822, 2.129000462287665, 2.1524617620493807, 2.1755456171872876, 2.198267798955346, 2.22064303492292, 2.2426851022394483, 2.264406910507053, 2.2858205756375187, 2.306937485860134, 2.3277683608730393, 2.3483233049860153, 2.368611854981732, 2.3886430233209834, 2.4084253372319266, 2.427966874151019, 2.44727529392196, 2.4663578681066416, 2.485221506717442, 2.5038727826418556, 2.5223179539975282, 2.54056298462732, 2.558613562919463, 2.576475119116529, 2.5941528412584183, 2.6116516898883724, 2.6289764116369367, 2.646131551786382, 2.6631214659072513, 2.679950330649144, 2.696622153759399, 2.7131407833959145, 2.7295099167937193, 2.745733108339103, 2.761813777099864, 2.7777552138556514, 2.793560587668216, 2.8092329520277235, 2.824775250607959, 2.840190322660321, 2.8554809080738175, 2.870649652125924, 2.885699109946982, 2.900631750718897, 2.915449961627148, 2.9301560515835217, 2.9447522547355676, 2.9592407337774693, 2.973623583075834, 2.9879028316228657, 3.002080445828365, 3.0161583321611567, 3.0301383396497097, 3.0440222622509787, 3.057811841095838, 3.071508766618829, 3.0851146805794167, 3.0986311779813955, 3.1120598088966256, 3.1254020801988553, 3.1386594572129507, 3.1518333652845207, 3.1649251912745564, 3.1779362849834025, 3.1908679605080943, 3.203721497536806, 3.216498142583933], [0.0, 0.5278031643091577, 0.6964404506368993, 0.8190690044316877, 0.9189586839976279, 1.004754572603832, 1.0807680308164909, 1.1495059024112548, 1.2125732532083184, 1.2710686092585746, 1.3257816069359947, 1.3773016369606177, 1.4260819663728026, 1.472479748538763, 1.5167821317117853, 1.5592239363664755, 1.5999999999999999, 1.6392740279923177, 1.6771850850517902, 1.7138524512463418, 1.7493793183092448, 1.7838556468464872, 1.8173604054899921, 1.8499633474808994, 1.8817264360394779, 1.912704999580074, 1.94294867664978, 1.972502195420671, 2.001406021712675, 2.0296969015901527, 2.0574083187020165, 2.0845708821369953, 2.111212657236631, 2.1373594492637142, 2.16303504786041, 2.1882614387023356, 2.213058987556147, 2.237446601000637, 2.261441867317064, 2.285061180449882, 2.3083198494515416, 2.3312321954294966, 2.3538116376908382, 2.376070770515344, 2.3980214317694797, 2.4196747643932, 2.4410412716409513, 2.462130866832611, 2.4829529182645755, 2.5035162898423473, 2.523829377920773, 2.5439001447742817, 2.5637361490651114, 2.583344573631062, 2.602732250874477, 2.6219056859999075, 2.6408710783183813, 2.6596343408106256, 2.678201118119439, 2.6965768031221518, 2.7147665522172706, 2.7327752994447714, 2.750607769546596, 2.7682684900626424, 2.7857618025475976, 2.8030918729851826, 2.820262701468668, 2.837278131209623, 2.854141856930837, 2.8708574326938763, 2.8874282792070067, 2.903857690654854, 2.920148841087388, 2.9363047904023603, 2.952328489952264, 2.968222787804118, 2.9839904336778917, 2.9996340835871793, 3.015156304203667, 3.030559576965181, 3.0458463019454056, 3.061018801501898, 3.0760793237176824, 3.0910300456504576, 3.1058730764023625, 3.1206104600222186, 3.1352441782512424, 3.1497761531223984, 3.1642082494227703, 3.1785422770276486, 3.192779993114366, 3.2069231042633604, 3.2209732684533607, 3.2349320969571327, 3.2488011561437538, 3.262581969192962, 3.276276017726751, 3.2898847433630234, 3.3034095491957833, 3.316851801206066, 3.3302128296074924, 3.3434939301301188], [0.0, 0.5473553316918489, 0.722239690171116, 0.8494109488449693, 0.9530009846549518, 1.0419751330523241, 1.1208044664980472, 1.1920886933665806, 1.2574923382265664, 1.3181546214003115, 1.3748944308911808, 1.4283229910624944, 1.4789103599737665, 1.5270269215340906, 1.572970461240126, 1.6169844983571173, 1.6592710880262584, 1.7000000000000002, 1.7393154505595605, 1.7773411384349924, 1.8141840780385095, 1.8499375625154726, 1.8846834858457635, 1.918494185239582, 1.9514339193093737, 1.9835600660790587, 2.0149241029274125, 2.0455724149561503, 2.0755469670184348, 2.1048858664156365, 2.1336238371793566, 2.1617926222945685, 2.1894213267673956, 2.21653671180188, 2.2431634483139202, 2.269324336425956, 2.295040496342861, 2.320331535026863, 2.3452156923070744, 2.369709969432276, 2.393830242570043, 2.41759136334509, 2.4410072481750915, 2.4640909578877404, 2.486854768876519, 2.509310236865241, 2.5314682541954268, 2.5533391014202382, 2.5749324938792726, 2.5962576238363586, 2.617323198684523, 2.638137475656112, 2.658708293419698, 2.6790431008972146, 2.699148983593454, 2.7190326876945625, 2.738700642161512, 2.7581589790180296, 2.7774135520094902, 2.7964699537892894, 2.8153335317717785, 2.8340094027756315, 2.8525024665681626, 2.8708174184094055, 2.8889587606844644, 2.9069308137035543, 2.9247377257411196, 2.9423834823783133, 2.9598719152068225, 2.9772067099463997, 2.9943914140234984, 3.0114294436539364, 3.028324090468555, 3.0450785277172745, 3.0616958160837586, 3.0781789091400453, 3.094530658467914, 3.1107538184714674, 3.126851050903282, 3.1428249291246337, 3.1586779421185684, 3.174412498273055, 3.1900309289500726, 3.2055354918551813, 3.220928374221007, 3.2362116958169937, 3.2513875117968323, 3.266457815394103, 3.2814245404758644, 3.296289563963205, 3.3110547081270907, 3.3257217427672576, 3.340292387281314, 3.3547683126307044, 3.3691511432097583, 3.383442458623537, 3.397643795379877, 3.411756648500595, 3.425782473056512, 3.439722685630653, 3.453578665713643, 3.467351757035121], [0.0, 0.5664525067769411, 0.7474385637693104, 0.8790468154750565, 0.9862510977103354, 1.0783295456214068, 1.1599092269590578, 1.2336805536738755, 1.3013661254372384, 1.364144909859358, 1.422864365867587, 1.4781570433847246, 1.530509400750949, 1.5803047445344587, 1.627851249939363, 1.6734009325947412, 1.7171628973263064, 1.7593128371369082, 1.8, 1.8393524004824757, 1.8774807867191388, 1.9144817068442543, 1.9504399121108165, 1.9854302635673589, 2.019519261803159, 2.052766286755895, 2.085224611845156, 2.1169422405444123, 2.1479626018565336, 2.1783251326429838, 2.2080657684535, 2.2372173597827607, 2.2658100271077646, 2.293871465328399, 2.321427206126455, 2.3485008451184592, 2.37511423939121, 2.4012876799919693, 2.4270400431357393, 2.452388923243243, 2.4773507504000207, 2.5019408944025505, 2.5261737572109864, 2.5500628553440485, 2.5736208935174107, 2.5968598306329844, 2.6197909390650422, 2.6424248580542606, 2.664771641907504, 2.686840803605807, 2.708641354342303, 2.730181839443385, 2.7514703710680215, 2.772514658030317, 2.7933220330476476, 2.813899477679949, 2.834253645194025, 2.854390881559322, 2.8743172447578313, 2.89403852257009, 2.913560248981223, 2.932887719335218, 2.9520260043518016, 2.9709799631081797, 2.989754255077242, 3.0083533513044123, 3.026781544797034, 3.0450429601928035, 3.063141562767276, 3.081081166834612, 3.098865443590635, 3.1164979284426044, 3.1339820278660473, 3.151321025825269, 3.1685180897908936, 3.1855762763848037, 3.2024985366801944, 3.2192877211820634, 3.2359465845112796, 3.2524777898134483, 3.2688839129119933, 3.285167446223311, 3.301330802450376, 3.3173763180698783, 3.3333062566267815, 3.349122811849082, 3.3648281105945865, 3.3804242156406037, 3.395913128326628, 3.4112967910593457, 3.4265770896885814, 3.441755855762216, 3.456834868667473, 3.471815857665484, 3.4867005038255394, 3.501490441864971, 3.516187261900226, 3.5307925111142886, 3.5453076953452625, 3.559734280600617, 3.574073694501275, 3.5883273276594716], [0.0, 0.5851297242409217, 0.7720832999642582, 0.9080309727295892, 1.01877002207848, 1.1138845042109662, 1.1981540517434992, 1.2743577855801407, 1.344275103390831, 1.4091238460084716, 1.4697794149937133, 1.5268952168677883, 1.5809737496001428, 1.632410958241538, 1.6815251792280232, 1.7285767377126928, 1.7737816331792515, 1.8173213516253397, 1.859350062066904, 1.9000000000000001, 1.9393855651753613, 1.9776064891371203, 2.0147503175783408, 2.050894379885266, 2.0861073693216734, 2.1204506237157896, 2.1539791730320705, 2.186742603526836, 2.218785776155186, 2.2501494281009053, 2.280870679789901, 2.3109834648717955, 2.3405188969636868, 2.369505584128811, 2.3979698998861245, 2.42593621785288, 2.453427115793352, 2.4804635537964224, 2.507065030468499, 2.5332497203580626, 2.55903459528765, 2.584435531830615, 2.60946740681224, 2.6341441824213683, 2.658478982276822, 2.6824841595924944, 2.7061713584182776, 2.729551568794622, 2.7526351765415797, 2.7754320083046373, 2.797951372396302, 2.8202020959016623, 2.842192558455874, 2.8639307230500393, 2.8854241641777745, 2.906680093596801, 2.927705383947144, 2.9485065904391834, 2.969089970800248, 2.98946150364706, 3.009626905432723, 3.029591646100666, 3.049360963563687, 3.0689398771137344, 3.0883331998570336, 3.1075455502594655, 3.1265813628785137, 3.1454448983504877, 3.1641402526950264, 3.182671365992836, 3.2010420304873506, 3.219255898156186, 3.237316487794054, 3.255227191644974, 3.2729912816182254, 3.290611915119412, 3.3080921405252717, 3.3254349023283845, 3.3426430459756857, 3.359719322422701, 3.3766663924235663, 3.39348683057527, 3.410183129133049, 3.4267577016125035, 3.443212886192781, 3.4595509489340417, 3.475774086821393, 3.4918844306465675, 3.5078840477377393, 3.523774944547125, 3.5395590691052754, 3.555238313350337, 3.5708145153399466, 3.5862894613528775, 3.6016648878870683, 3.6169424835601696, 3.632123890918357, 3.6472107081587293, 3.6622044907702698, 3.677106753098024, 3.6919189698347967, 3.7066425774444482], [0.0, 0.6034176336545163, 0.7962143411069944, 0.9364109840092412, 1.0506111217615068, 1.1486983549970349, 1.235601701134824, 1.3141871409823676, 1.3862896863102927, 1.4531652409004674, 1.515716566510398, 1.5746174915246671, 1.6303862192118455, 1.6834310696686388, 1.7340803287622468, 1.7826024579660031, 1.8292202077093052, 1.8741207362353605, 1.9174630310283654, 1.9593834605324598, 1.9999999999999998, 2.039415498029968, 2.0777202365081693, 2.114993961708508, 2.1513075138651403, 2.1867241478865562, 2.221300613668644, 2.2550880472590378, 2.288132711717446, 2.3204766174460456, 2.352158045049347, 2.3832119887546277, 2.413670534618065, 2.443563184832261, 2.472917137206079, 2.5017575271408434, 2.5301076380564997, 2.5579890851380402, 2.5854219764101494, 2.612425054456877, 2.6390158215457884, 2.665210650463852, 2.6910248830033843, 2.716472917733804, 2.741568288445458, 2.766323734445183, 2.7907512637112797, 2.8148622097719005, 2.8386672830502206, 2.862176617318155, 2.8853998118144273, 2.9083459695098397, 2.931023731940461, 2.953441310976324, 2.975606517847699, 2.9975267897118494, 3.0192092140094045, 3.0406605508302587, 3.061887253483584, 3.0828954874444983, 3.103691147830719, 3.124279875545765, 3.144667072210533, 3.164857913992195, 3.1848573644279785, 3.2046701863313887, 3.224300952859577, 3.2437540578127106, 3.2630337252292803, 3.28214401833506, 3.3010888478979767, 3.31987198003621, 3.3384970435224743, 3.356967536623521, 3.3752868335103625, 3.3934581902715886, 3.4114847505592834, 3.4293695508945325, 3.4471155256571584, 3.464725511782296, 3.4822022531844965, 3.499548404928369, 3.516766537163224, 3.5338591388377707, 3.5508286212096682, 3.5676773211635457, 3.5844075043500796, 3.601021368157731, 3.6175210445278863, 3.633908602623327, 3.650186051359235, 3.6663553418052466, 3.6824183694664856, 3.6983769764508905, 3.714232953529693, 3.7299880420973652, 3.7456439360369647, 3.761202283496365, 3.7766646885805084, 3.7920327129644646, 3.807307877431757, 3.822491663342136], [0.0, 0.6213432387360743, 0.819867318817501, 0.9642287549148116, 1.0818214129638553, 1.1828225037144082, 1.2723074699047923, 1.353227431452234, 1.4274719124493171, 1.4963341255564684, 1.5607436506913628, 1.6213943335215408, 1.6788197714748194, 1.7334404145300821, 1.785594300876107, 1.8355578671166886, 1.8835604808829862, 1.929794860290125, 1.9744247158312014, 2.0175904670200278, 2.05941359377582, 2.1, 2.139442649564018, 2.1778236577481387, 2.215215969222967, 2.25168471799771, 2.2872883398258885, 2.3220794898433157, 2.3561058054370188, 2.38941054500366, 2.422033126341892, 2.4540095832453934, 2.4853729549442973, 2.5161536200468477, 2.546379584321692, 2.5760767298624163, 2.605269031764794, 2.633978747331727, 2.662226581932905, 2.6900318349345147, 2.71741252854043, 2.7443855219206763, 2.770966612623078, 2.7971706269524304, 2.8230115007446424, 2.848502351750551, 2.873655544667029, 2.898482749705048, 2.9229949954601486, 2.947202716746151, 2.971115797964412, 2.99474361250584, 3.01809505861886, 3.0411785921218604, 3.064002256291742, 3.0865737092198886, 3.1089002488920885, 3.1309888362188536, 3.1528461162165016, 3.1744784375166666, 3.195891870362131, 3.2170922232295878, 3.23808505820479, 3.258875705222256, 3.2794692752700048, 3.299870672649476, 3.320084606371671, 3.340115600762487, 3.3599680053430667, 3.3796460040446084, 3.399153623811427, 3.418494742641009, 3.437673097105285, 3.456692289393304, 3.475555793911892, 3.4942669634776014, 3.5128290351303506, 3.5312451355965395, 3.5495182864270167, 3.5676514088331728, 3.5856473282424712, 3.603508778592986, 3.6212384063849306, 3.638838774505709, 3.6563123658437213, 3.6736615867049545, 3.690888770045308, 3.707996178530617, 3.724986007435416, 3.7418603873906875, 3.758621386990046, 3.775271015263159, 3.7918112240245354, 3.8082439101052397, 3.824570917474582, 3.840794039258285, 3.8569150196592465, 3.872935555786535, 3.8888572993979116, 3.9046818585608105, 3.920410799236362, 3.9360456467907703], [0.0, 0.6389304828983968, 0.8430738266183799, 0.9915214419254805, 1.1124425835885279, 1.2163025303351713, 1.3083203863216186, 1.3915308035023033, 1.4678767893256992, 1.5386881610942322, 1.6049208106703468, 1.6672882231614379, 1.7263390995768246, 1.7825057908158095, 1.8361359033054512, 1.887513698242688, 1.9368750355551771, 1.984418088282687, 2.030311200776437, 2.074698767152554, 2.117705705843569, 2.1594409183819336, 2.1999999999999997, 2.2394673902674014, 2.2779180985681755, 2.3154191025426383, 2.3520304919799546, 2.387806412430048, 2.4227958496656767, 2.4570432865210377, 2.4905892565234287, 2.5234708134102375, 2.5557219315935873, 2.587373849554282, 2.618455365769829, 2.648993094931631, 2.6790116907553227, 2.7085340405411995, 2.7375814357285657, 2.7661737219560125, 2.794329431549485, 2.822065900881175, 2.8493993746516453, 2.8763450988272026, 2.9029174037003673, 2.9291297783225274, 2.9549949373757642, 2.9805248813986958, 3.0057309511534567, 3.0306238768133515, 3.0552138225596863, 3.079510427099067, 3.103522840546613, 3.127259758064336, 3.1507294505956933, 3.17393979299587, 3.1968982898215965, 3.2196120990133443, 3.2420880536759404, 3.264332682140303, 3.286352226468645, 3.3081526595477513, 3.3297397008993186, 3.3511188313227236, 3.3722953064735206, 3.3932741694703776, 3.4140602626137917, 3.434658238291604, 3.4550725691390216, 3.475307557514248, 3.49536734434506, 3.5152559173964346, 3.5349771190047155, 3.5545346533196307, 3.573932093091784, 3.5931728860398677, 3.6122603608288597, 3.6311977326877747, 3.649988108693059, 3.668634492741574, 3.687139790235071, 3.705506812496284, 3.723738280935145, 3.7418368309820944, 3.759805015804184, 3.7776453098183707, 3.7953601120153357, 3.8129517491061216, 3.830422478502946, 3.8477744911447256, 3.8650099141770293, 3.8821308134955097, 3.8991391961611743, 3.916037012695269, 3.9328261592610216, 3.949508479738937, 3.966085767701922, 3.9825597682960567, 3.9989321800324342, 4.0152046564951585, 4.0313788079702, 4.047456202999559], [0.0, 0.6562007185515857, 0.8658620391836747, 1.018322180684357, 1.1425118103408085, 1.2491790824589155, 1.3436841731285136, 1.4291437606837147, 1.5075533718961576, 1.5802787689148563, 1.6483016812765647, 1.7123548795293786, 1.7730018960234086, 1.8306867680653456, 1.8857664978538857, 1.9385330301415182, 1.989228600129331, 2.0380567374572047, 2.085190336809603, 2.1307776952631143, 2.1749471077846887, 2.217810419505775, 2.259465809589581, 2.3000000000000003, 2.339490027618228, 2.378004680484402, 2.4156056726094866, 2.452348613092933, 2.4882838117886985, 2.5234569538981377, 2.557909668566283, 2.5916800110898373, 2.6248028742063427, 2.657310340770035, 2.6892319876787774, 2.7205951490167766, 2.7514251448874676, 2.7817454812328917, 2.8115780249981146, 2.840943158247622, 2.8698599142345236, 2.8983460979316527, 2.9264183931324212, 2.9540924579002863, 2.981383009874335, 3.008303902713846, 3.034868194777657, 3.061088210977907, 3.086975598616549, 3.1125413779025433, 3.1377959877541373, 3.1627493274113414, 3.1874107943160954, 3.2117893186598883, 3.2358933949490614, 3.2597311108954554, 3.283310173903319, 3.306637935391635, 3.329721413163463, 3.3525673120099406, 3.3751820427156822, 3.3975717396140848, 3.4197422768250227, 3.4416992832934046, 3.4634481567346995, 3.484994076582637, 3.506342016024677, 3.527496753202302, 3.548462881645661, 3.569244820005328, 3.589846821137998, 3.6102729805975917, 3.6305272445784706, 3.6506134173532097, 3.6705351682435525, 3.6902960381597283, 3.7098994457402426, 3.7293486931214708, 3.7486469713638675, 3.7677973655593657, 3.7868028596424743, 3.805666340925739, 3.824390604378565, 3.8429783566668507, 3.8614322199695317, 3.879754735586841, 3.8979483673539708, 3.9160155048727607, 3.933958466573087, 3.9517795026147535, 3.9694807976398914, 3.987064473385133, 4.004532591162172, 4.0218871542146735, 4.039130109958995, 4.05626335211557, 4.073288722737428, 4.090208014141794, 4.1070229707503705, 4.123735290843495, 4.140346628233032, 4.156858593858532], [0.0, 0.6731730872677197, 0.888257213969168, 1.044660675955349, 1.1720624206334085, 1.2814885990147222, 1.3784380259964422, 1.4661079915492736, 1.5465456359454102, 1.621152046224736, 1.6909343439651996, 1.7566442525315802, 1.8188598798124778, 1.878036747961642, 1.9345410928966262, 1.9886724104039921, 2.0406792010012653, 2.0907702585409305, 2.139122949559204, 2.1858894067771533, 2.231201243459655, 2.2751731975676783, 2.317905987629158, 2.3594885786368427, 2.4000000000000004, 2.4395108189338695, 2.478084345657587, 2.5157776275776853, 2.5526422757923393, 2.5887251571323358, 2.6240689774638675, 2.6587127763686413, 2.692692349070879, 2.7260406082349884, 2.7587878957534473, 2.790962252695601, 2.822589654059217, 2.8536942137581107, 2.8842983643171225, 2.9144230149746706, 2.944087691271333, 2.9733106586984315, 3.0021090325690123, 3.0304988759360705, 3.0584952871045323, 3.086112478053025, 3.113363844889606, 3.1402620313053284, 3.1668189858549463, 3.193046013780709, 3.2189538239993025, 3.2445525717906154, 3.2698518976576576, 3.294860962767744, 3.3195884813342205, 3.3440427502543533, 3.3682316762813156, 3.3921628009755964, 3.4158433236529206, 3.439280122521162, 3.4624797741773126, 3.485448571616844, 3.5081925408913874, 3.530717456536258, 3.553028855876673, 3.5751320523103396, 3.5970321476542195, 3.618734043634511, 3.6402424525911803, 3.6615619074614276, 3.6826967711003835, 3.7036512449918293, 3.7244293773968637, 3.745035070984048, 3.7654720899806615, 3.78574406688116, 3.8058545087457625, 3.82580680311928, 3.8456042235976673, 3.8652499350675247, 3.884746998641631, 3.904098376311715, 3.9233069353379455, 3.9423754523930503, 3.961306617477572, 3.9801030376214577, 3.998767240386009, 4.01730167717916, 4.035708726396045, 4.053990696395953, 4.072149828325907, 4.090188298800408, 4.108108222446149, 4.125911654319894, 4.1436005922071395, 4.161176978808643, 4.178642703821396, 4.195999605920192, 4.213249474645501, 4.2303940522030015, 4.2474350351797385, 4.26437407618157], [0.0, 0.6898648307306073, 0.91028210151304, 1.070563684169162, 1.201124433981431, 1.3132639022018835, 1.4126172502473835, 1.5024610468729152, 1.5848931924611134, 1.6613495148724349, 1.7328621078878659, 1.8002013343184107, 1.8639596365956757, 1.9246038318272283, 1.982509236976936, 2.037982774014807, 2.0912791051825463, 2.1426122015054765, 2.192163827432888, 2.240089887910852, 2.2865252596366314, 2.3315875255699714, 2.3753799016170625, 2.4179935587127273, 2.459509485849363, 2.5, 2.539529981199853, 2.578157891381218, 2.6159366213714015, 2.652914200093276, 2.6891343923314253, 2.724637205678154, 2.7594593229224293, 2.7936344728185505, 2.827193749605003, 2.860165889646807, 2.8925775120078816, 2.924453328521464, 2.9558163279407355, 2.986687937961626, 3.0170881682725814, 3.0470357372690877, 3.076548184648975, 3.1056419717585824, 3.1343325712746535, 3.1626345475706246, 3.190561628919346, 3.218126772520019, 3.245342223199209, 3.2722195665196456, 3.2987697769322355, 3.3250032615233187, 3.3509298998381456, 3.3765590802008467, 3.4018997328990817, 3.426960360556823, 3.4517490659800822, 3.47627357772701, 3.5005412736248225, 3.524559202430816, 3.5483341038127754, 3.571872426804892, 3.595180346878478, 3.618263781752026, 3.641128406052161, 3.663779664925576, 3.6862227866919417, 3.708462794618793, 3.730504517891483, 3.752352601844195, 3.7740115175117555, 3.7954855705563366, 3.8167789096181766, 3.8378955341349204, 3.8588393016701934, 3.879613934788399, 3.9002230275094876, 3.92067005137454, 3.940958361150349, 3.961091200198838, 3.9810717055349727, 4.0009029125949, 4.02058775973428, 4.0401290924751585, 4.0595296675183095, 4.0787921565366, 4.097919149763778, 4.116913159391958, 4.135776622790052, 4.154511905554546, 4.173121304403093, 4.191607049920696, 4.209971309167529, 4.228216188156757, 4.246343734210208, 4.264355938199105, 4.282254736676648, 4.300042013908709, 4.317719603808523, 4.335289291780837, 4.352752816480621, 4.370111871491119], [0.0, 0.7062915473248845, 0.9319572840072131, 1.096055411609953, 1.2297250087499387, 1.3445346859467486, 1.4462537862647737, 1.5382368984767494, 1.6226318771208108, 1.700908739272883, 1.774124154415284, 1.8430668288532899, 1.9083433119616193, 1.9704315364635172, 2.0297157561828323, 2.08651020136214, 2.1410755981331806, 2.1936310124924, 2.2443625369733193, 2.2934297888526745, 2.3409708564442386, 2.3871061225344343, 2.431941260755028, 2.47556961295758, 2.518074096603902, 2.559528750642645, 2.6, 2.639547698674578, 2.678225996903634, 2.7160840672507502, 2.753166716605689, 2.7895149052015493, 2.825166189299538, 2.8601551007861956, 2.8945134743004752, 2.928270730463361, 2.9614541221786177, 2.994088949705307, 3.0261987491933127, 3.0578054585641516, 3.0889295639669707, 3.1195902295103357, 3.1498054125385955, 3.179591966367442, 3.2089657321012655, 3.2379416209130834, 3.2665336879665188, 3.2947551989911243, 3.322618690381158, 3.3501360235689783, 3.377318434323633, 3.4041765775398, 3.430720568009525, 3.4569600176070208, 3.482904069263494, 3.508561428063149, 3.5339403897519666, 3.559048866916661, 3.583894413061582, 3.6084842447855134, 3.632825262237841, 3.656924068013935, 3.680786984632345, 3.7044200707213184, 3.7278291360288534, 3.751019755358755, 3.77399728152483, 3.796766857406148, 3.819333427178212, 3.8417017467875807, 3.8638763937311267, 3.885861776195299, 3.9076621416056834, 3.9292815846325357, 3.950724054693859, 3.9719933629938993, 3.9930931891316135, 4.0140270873106845, 4.034798492179935, 4.055410724330603, 4.075866995474685, 4.096170413326617, 4.116323986208717, 4.136330627399179, 4.156193159239956, 4.175914317020458, 4.195496752651782, 4.214943038145105, 4.234255668906752, 4.2534370668616095, 4.272489583415622, 4.29141550226737, 4.310217042077978, 4.328896359007948, 4.34745554912891, 4.36589665071772, 4.384221646439812, 4.402432465428257, 4.420530985264514, 4.4385190338664975, 4.4563983912891585, 4.474170791442502], [0.0, 0.7224674055842076, 0.953301456943931, 1.1211578456539657, 1.2578888137888427, 1.3753279222342187, 1.4793766465655034, 1.5734664041012518, 1.65979424066711, 1.7398638404385864, 1.8147560732948997, 1.8852777089054578, 1.9520491881558575, 2.0155593896344297, 2.0762013675469815, 2.1342965488013803, 2.1901116308155406, 2.2438706967498847, 2.2957641011264234, 2.3459551168602113, 2.3945849948357742, 2.4417768749090447, 2.4876388509045495, 2.532266402437731, 2.57574434598946, 2.6181484161870965, 2.6595465592552165, 2.7, 2.7395641288357435, 2.7782892445017873, 2.8162211800787085, 2.853401833892278, 2.8898696223368305, 2.9256598681662247, 2.9608051351129587, 2.9953355176044583, 3.0292788927047387, 3.0626611401126214, 3.095506335015198, 3.1278369177677345, 3.1596738437038745, 3.1910367158386173, 3.2219439027848003, 3.2524126438415615, 3.2824591429145453, 3.31209865268025, 3.3413455502010034, 3.370213405025032, 3.398715040661647, 3.426862590199935, 3.4546675467363976, 3.4821408091896826, 3.5092927240060905, 3.5361331231960023, 3.562671359086815, 3.5889163361311227, 3.6148765400684164, 3.6405600647036094, 3.6659746365353563, 3.6911276374407587, 3.716026125600031, 3.740676854824635, 3.765086292434745, 3.7892606358164804, 3.813205827775725, 3.8369275707933546, 3.860431340276117, 3.883722396887986, 3.9068057980385573, 3.929686408597564, 3.9523689108981053, 3.97485781408522, 3.9971574628612565, 4.019272045674748, 4.041205602395335, 4.062962031513455, 4.084545096900163, 4.105958434159374, 4.127205556602032, 4.148289860869293, 4.16921463222946, 4.189983049571471, 4.210598190115812, 4.2310630338621, 4.251380467791037, 4.27155328983706, 4.291584212646724, 4.311475867136748, 4.331230805864557, 4.350851506223228, 4.370340373471835, 4.389699743611415, 4.408931886116033, 4.428039006527702, 4.447023248923382, 4.4658866982616106, 4.484631382615863, 4.5032592753012235, 4.5217722969005045, 4.540172317195551, 4.558461157009064, 4.57664058996196], [0.0, 0.7384053230743223, 0.9743316651533829, 1.1458910323684282, 1.2856383398864155, 1.4056682016392041, 1.5120122820938597, 1.608177696995849, 1.6964099598730562, 1.7782459267702473, 1.854790311984838, 1.9268676828450992, 1.9951121674086247, 2.0600234291192883, 2.1220031931145575, 2.1813799771073623, 2.2384263619664257, 2.2933713742155577, 2.3464095676730183, 2.397707817119119, 2.447410489488918, 2.495643441152405, 2.5425171505267445, 2.588129203545563, 2.6325662877749356, 2.675905808578137, 2.7182172111004057, 2.759563070791425, 2.8000000000000003, 2.839579407075608, 2.8783481361947603, 2.9163490099769107, 2.953621292297289, 2.9902010851437124, 3.0261216706175325, 3.0614138070411787, 3.0961059864577547, 3.1302246594825007, 3.1637944324106853, 3.1968382406407096, 3.229377501789189, 3.2614322513214073, 3.293021263069086, 3.3241621566371395, 3.3548714933957973, 3.3851648625016493, 3.4150569581807204, 3.4445616493308524, 3.473692042353059, 3.502460537997181, 3.53087888290199, 3.5589582164205997, 3.5867091132460196, 3.614141622286679, 3.6412653021860266, 3.6680892538324117, 3.6946221501641046, 3.720872263538564, 3.746847490904069, 3.7725553769848585, 3.7980031356674018, 3.8231976697549186, 3.8481455892392322, 3.8728532282232573, 3.8973266606135324, 3.9215717146899234, 3.9455939866488214, 3.969398853206535, 3.9929914833411204, 4.016376849243267, 4.039559736540198, 4.062544753850482, 4.085336341722323, 4.10793878100309, 4.130356200683549, 4.152592585256384, 4.174651781625138, 4.19653750559659, 4.2182533479867175, 4.239802780367926, 4.261189160482842, 4.282415737347952, 4.303485656068447, 4.324401962383918, 4.345167606963008, 4.365785449463694, 4.38625826237459, 4.406588734651484, 4.4267794751622285, 4.4468330159521745, 4.466751815341364, 4.486538260863944, 4.506194672059478, 4.52572330312511, 4.545126345436988, 4.564405929948663, 4.583564129473713, 4.602602960859338, 4.621524387057168, 4.640330319097176, 4.659022617970136, 4.677603096423743], [0.0, 0.754117117337764, 0.9950635019764305, 1.1702733107544192, 1.3129941625792796, 1.4355780206730986, 1.5441848913068417, 1.6423965146623505, 1.732506184321991, 1.8160834575655194, 1.8942565548098473, 1.967867588533333, 2.037564179775359, 2.103856623822483, 2.1671551937228015, 2.227795397391721, 2.286055615675829, 2.342169748327109, 2.396336488881493, 2.4487262628821784, 2.499486509105002, 2.548745761892782, 2.596616850423312, 2.6431994370644785, 2.6885820539210705, 2.7328437533882894, 2.7760554582657195, 2.8182810754839545, 2.859578421989801, 2.9, 2.93959365044182, 2.978403107114747, 3.016468469351056, 3.053826607316945, 3.0905115112905794, 3.126554594070215, 3.1619849539528717, 3.1968296043701896, 3.23111367519038, 3.2648605898314322, 3.298092221634176, 3.330829032378683, 3.3630901953664134, 3.3948937051123727, 3.426256475379757, 3.4571944270313524, 3.48772256695704, 3.51785505915718, 3.5476052889108884, 3.5769859208312598, 3.6060089515021363, 3.6346857572998763, 3.663027137925889, 3.6910433561093567, 3.7187441738826186, 3.7461388857827975, 3.773236349291012, 3.800045012784008, 3.8265729412413934, 3.8528278399241067, 3.878817076215751, 3.9045476997974475, 3.9300264613084765, 3.9552598296288455, 3.9802540079057227, 4.00501494843316, 4.029548366483458, 4.053859753178739, 4.077954387482612, 4.101837347384081, 4.125513520338984, 4.148987613028109, 4.17226416048568, 4.195347534646972, 4.218241952359446, 4.240951482897856, 4.263480055020186, 4.285831463598182, 4.308009375853232, 4.330017337225887, 4.351858776904845, 4.373537013039194, 4.395055257655697, 4.416416621301215, 4.437624117428741, 4.458680666544079, 4.479589100128877, 4.500352164354544, 4.520972523600443, 4.541452763788809, 4.561795395547833, 4.582002857213636, 4.60207751768096, 4.622021679111775, 4.641837579510347, 4.661527395172673, 4.681093243017677, 4.700537182807047, 4.719861219260113, 4.739067304069761, 4.758157337824938, 4.777133171845005], [0.0, 0.7696136340726079, 1.0155112783974816, 1.1943215116604917, 1.3399751653245717, 1.4650780257917606, 1.5759166826422606, 1.6761464780162718, 1.7681078308849894, 1.8534025517022357, 1.9331820449317627, 2.0083057278044842, 2.079434529465439, 2.1470892313700647, 2.2116885373565958, 2.273574849765597, 2.333032269952246, 2.3902995041254242, 2.445579328817768, 2.4990456716840463, 2.5508490012515814, 2.6011204931433705, 2.649975295088532, 2.6975151174386367, 2.743830311563958, 2.7890015543245688, 2.833101225928093, 2.876194546542548, 2.91834052120776, 2.959592731019947, 3.0, 3.039606960642769, 3.0784545362904314, 3.116580354762254, 3.1540191048100237, 3.1908028447404235, 3.2269612707977107, 3.262521951518409, 3.29751053316986, 3.3319509205029667, 3.3658654363385985, 3.3992749629303978, 3.432199067576169, 3.464656114564122, 3.496663365222053, 3.528237067574021, 3.559392536889754, 3.5901442282287364, 3.620505801927098, 3.6504901828458234, 3.680109614089167, 3.709375705809119, 3.738299479632504, 3.7668914091795593, 3.79516145708475, 3.8231191088806655, 3.850773404062731, 3.878132964615225, 3.9052060212467747, 3.9320004375554034, 3.9585237323186826, 3.9847831000831655, 4.010785430208487, 4.036537324505078, 4.062045113589927, 4.087314872072072, 4.112352432668188, 4.137163399338659, 4.161753159525668, 4.18612689556692, 4.210289595351645, 4.234246062279238, 4.258000924575331, 4.281558644015045, 4.304923524098761, 4.328099717721641, 4.351091234374575, 4.3739019469109515, 4.396535597910692, 4.418995805670373, 4.44128606984584, 4.463409776771548, 4.485370204478897, 4.507170527434051, 4.528813821014107, 4.550303065738975, 4.5716411512750375, 4.592830880225376, 4.613874971720269, 4.634776064820623, 4.6555367217460795, 4.676159430938657, 4.696646609972031, 4.717000608315799, 4.737223709963465, 4.757318135932204, 4.777286046641967, 4.797129544180936, 4.816850674463853, 4.836451429289365, 4.855933748302038, 4.8752995208643926], [0.0, 0.7849048566202034, 1.0356881675144227, 1.2180511276907326, 1.366598730129163, 1.4941872218222718, 1.6072280987137666, 1.7094493298408762, 1.8032378352576224, 1.890227251309476, 1.9715918593702613, 2.04820815217418, 2.120750190669293, 2.189749103561632, 2.2556319137904586, 2.3187478267857804, 2.3793865886274217, 2.4377916483063586, 2.494169811261357, 2.5486984608636116, 2.6015310552544992, 2.6528013763461415, 2.7026268597033627, 2.7511112365302144, 2.798346653361256, 2.844415390000904, 2.889391264757428, 2.9333407936388065, 2.976324154038313, 3.018395991638901, 3.0596061005312944, 3.1000000000000005, 3.1396194264808135, 3.1785027554088594, 3.2166853647563336, 3.254199949786803, 3.2910767967702976, 3.327344021994329, 3.3630277812842353, 3.398152454347246, 3.4327408075296675, 3.466814137988378, 3.5003924017979555, 3.533494328121146, 3.5661375212458926, 3.598338552023373, 3.630113040017817, 3.6614757274919523, 3.6924405461950314, 3.723020677788227, 3.7532286086303603, 3.7830761795520518, 3.8125746311655244, 3.8417346451882346, 3.8705663821992458, 3.89907951619635, 3.927283266277997, 3.9551864257360854, 3.982797388812725, 4.01012417534541, 4.03717445350005, 4.063955560769485, 4.090474523395973, 4.1167380743593345, 4.142752670057692, 4.168524505794665, 4.194059530175432, 4.219363458503783, 4.2444417852633745, 4.269299795758226, 4.2939425769804425, 4.318375027766723, 4.342601868299525, 4.366627649003643, 4.390456758884416, 4.414093433349635, 4.437541761553563, 4.460805693298151, 4.483889045523518, 4.506795508417091, 4.52952865116833, 4.55209192739375, 4.574488680254977, 4.596722147290691, 4.6187954649817335, 4.640711673067073, 4.662473718627005, 4.684084459948692, 4.705546670187996, 4.726863040840534, 4.748036185033922, 4.7690686406522875, 4.78996287330335, 4.810721279137615, 4.8313461875285695, 4.851839863622112, 4.872204510762931, 4.892442272804966, 4.9125552363126275, 4.932545432659014, 4.952414840026903, 4.9721653853179975], [0.0, 0.8, 1.0556063286183153, 1.2414764591322878, 1.3928809012737986, 1.5229231509727028, 1.6381380088633757, 1.7423251395862238, 1.837917367995256, 1.9265797482245537, 2.009509145207664, 2.0875989082230983, 2.1615360616329817, 2.2318619487112685, 2.2990118048225097, 2.363341551250222, 2.425146506416637, 2.484674801278186, 2.5421372185171496, 2.597714552908535, 2.6515632138719893, 2.703819556188343, 2.754603273921236, 2.8040200932138313, 2.8521639327456056, 2.899118654710782, 2.9449594970775266, 2.9897542550772416, 3.0335642634235707, 3.07644521873502, 3.1184478727329514, 3.1596186201202383, 3.2, 3.239631125836553, 3.2785480559846354, 3.316784114497008, 3.3543701701035804, 3.3913348798190466, 3.427704902492684, 3.463505086697692, 3.49875863661849, 3.5334872589948936, 3.5677112936929745, 3.6014498300712328, 3.6347208109799847, 3.6675411259579174, 3.699926694961799, 3.7318925437747956, 3.7634528720789557, 3.794621115042694, 3.8254099991601485, 3.855831592982579, 3.8858973532995607, 3.915618167257342, 3.9450043908413424, 3.9740658840978695, 4.00281204342535, 4.031251831226627, 4.059393803180305, 4.087246133359894, 4.114816637404033, 4.142112793918854, 4.1691417642739905, 4.195910410936673, 4.222425314473262, 4.248692789334302, 4.274718898527429, 4.300509467272089, 4.32607009572082, 4.351406170823619, 4.376522877404672, 4.401425208514189, 4.426117975112294, 4.4506058151367, 4.474893202001274, 4.498984452568379, 4.522883734634128, 4.546595073962324, 4.570122360899764, 4.59346935660287, 4.616639698903084, 4.6396369078362305, 4.662464390858993, 4.685125447773791, 4.7076232753816765, 4.729960971881312, 4.752141541030688, 4.774167896087012, 4.796042863538959, 4.81776918664449, 4.8393495287864, 4.860786476656928, 4.8820825432819035, 4.903240170894147, 4.924261733665222, 4.94514954030389, 4.965905836529151, 4.986532807425144, 5.007032579684695, 5.027407223747888, 5.047658755841546, 5.067789139925181], [0.0, 0.8149075920852832, 1.075277014305422, 1.2646107399275701, 1.4188365266482628, 1.5513020473626218, 1.6686638753827923, 1.7747924801623307, 1.8721660210059192, 1.9624805794824276, 2.0469553234931666, 2.126500249424939, 2.201815183988549, 2.2734515581138344, 2.3418527175544406, 2.40738121600552, 2.470337874997523, 2.530975449280733, 2.589508649365237, 2.64612163904449, 2.700973742347922, 2.754203854958177, 2.80593390137674, 2.8562715778995433, 2.905312553332766, 2.9531422525998616, 2.999837315690167, 3.0454668011646557, 3.090093186678085, 3.1337732067270467, 3.176558558765354, 3.2184965020375107, 3.2596303683411327, 3.3000000000000003, 3.339642127297907, 3.378590695264344, 3.4168771478522633, 3.4545306760852155, 3.4915784355865416, 3.528045737969933, 3.5639562198179524, 3.5993319923644456, 3.6341937744985153, 3.668561011299126, 3.7024519799724587, 3.735883884785143, 3.7688729423542244, 3.801434458460676, 3.8335828973903814, 3.865331944669267, 3.896694563943202, 3.927683048654744, 3.9583090690849, 3.988583715256338, 4.018517536132984, 4.048120575498084, 4.077402404847155, 4.106372153592849, 4.135038536844479, 4.1634098809952444, 4.191494147324228, 4.219298953797573, 4.246831595233384, 4.274099061977469, 4.301108057221689, 4.327865013083152, 4.354376105550552, 4.380647268393328, 4.406684206120005, 4.4324924060636475, 4.458077149664995, 4.483443523017204, 4.508596426730186, 4.533540585167259, 4.558280555102076, 4.58282073383953, 4.607165366840488, 4.63131855488681, 4.65528426081992, 4.679066315883474, 4.702668425698048, 4.7260941758935395, 4.749347037422848, 4.77243037157853, 4.795347434732395, 4.818101382816456, 4.840695275562205, 4.863132080513911, 4.8854146768304245, 4.907545858888918, 4.929528339702969, 4.951364754166506, 4.973057662134313, 4.994609551348978, 5.016022840223536, 5.03729988048836, 5.0584429597102805, 5.079454303691364, 5.100336078754273, 5.121090393920688, 5.141719302988788, 5.162224806515471], [0.0, 0.8296355440131292, 1.0947106633836976, 1.2874662469396363, 1.444479380342232, 1.5793389710592838, 1.6988218976899385, 1.8068685812854601, 1.9060019693099035, 1.9979487968786938, 2.0839502661046483, 2.164932819881106, 2.2416089329960944, 2.314540002476595, 2.384177386733161, 2.4508901919503883, 2.5149846764531327, 2.5767181630676768, 2.636309242800623, 2.6939454078663685, 2.7497888617823616, 2.803981010514567, 2.8566459821249888, 2.907893419321503, 2.957820719947533, 3.006514852824489, 3.054053843068181, 3.100507997345719, 3.145940922480252, 3.1904103783397733, 3.2339689967142347, 3.276664890971833, 3.318542176052517, 3.3596414143565934, 3.4000000000000004, 3.439652491506038, 3.478630901119121, 3.516964947436718, 3.5546822768699844, 3.59180865849335, 3.6283681560770185, 3.664383280474612, 3.6998751250309447, 3.7348634862589236, 3.769366971691527, 3.8034030965307766, 3.8369883704791636, 3.8701383759414285, 3.9028678386187474, 3.93519069137769, 3.967120132158117, 3.9986686765838906, 4.029848205854825, 4.060670010425296, 4.0911448299123006, 4.121282889621941, 4.1510939340368695, 4.180587257567033, 4.209771732831273, 4.238655836706993, 4.267247674358712, 4.2955550014332635, 4.323585244589137, 4.351345520509748, 4.378842653534791, 4.406083192030029, 4.43307342360376, 4.459819389267365, 4.4863268966278405, 4.512601532191676, 4.538648672851913, 4.564473496623462, 4.5900809926857224, 4.615475970786165, 4.6406630700537255, 4.665646767266472, 4.690431384614148, 4.7150210969926825, 4.739419938864552, 4.763631810716075, 4.787660485140086, 4.81150961257013, 4.83518272669018, 4.858683249541955, 4.882014496350183, 4.905179680084526, 4.928181915775481, 4.951024224600205, 4.973709537753038, 4.996240700114366, 5.018620473730482, 5.040851541116165, 5.0629365083908535, 5.084877908258493, 5.106678202840477, 5.128339786370367, 5.149864987758545, 5.171256073034344, 5.192515247672716, 5.213644658812018, 5.234646397369045, 5.25552250005707], [0.0, 0.8441912115297928, 1.1139169818185153, 1.3100543951507542, 1.4698222694537972, 1.6070479248580194, 1.7286271379442195, 1.838569463082637, 1.939442111974454, 2.0330021147030615, 2.1205124498413204, 2.202915814401413, 2.2809371832941046, 2.3551478030622626, 2.4260069510430124, 2.493890209260781, 2.5591092092363814, 2.621925788435724, 2.6825623729687127, 2.7412097445355377, 2.798032952458032, 2.8531758836207297, 2.906764843869377, 2.9589113995550838, 3.009714657332614, 3.059263111861148, 3.107636157180058, 3.154905333462512, 3.201135363491285, 3.2463850205111937, 3.2907078597186694, 3.334152838614245, 3.3767648461191713, 3.4185851562869827, 3.4596518193003956, 3.5000000000000004, 3.5396622722739237, 3.5786688761221064, 3.6170479430023863, 3.654825694098656, 3.6920266153716113, 3.728673612619983, 3.7647881492639956, 3.800390369139501, 3.83549920624218, 3.8701324830721933, 3.904306998989029, 3.938038609785306, 3.971342299519515, 4.0042322455055315, 4.036721877236486, 4.068823929918517, 4.100550493202964, 4.131913055631303, 4.162922545243381, 4.193589366744747, 4.223923435581614, 4.253934209231128, 4.283630715979145, 4.313021581426938, 4.342115052941324, 4.370919022239265, 4.399441046277397, 4.4276883665988755, 4.455667927274062, 4.4833863915575245, 4.510850157371465, 4.538065371714711, 4.565037944086708, 4.591773559007259, 4.618277687705131, 4.644555599041706, 4.670612369729801, 4.696452893902239, 4.722081892079862, 4.747503919584252, 4.772723374436473, 4.797744504779553, 4.822571415859211, 4.847208076594443, 4.871658325766915, 4.8959258778557615, 4.920014328542213, 4.943927159906524, 4.967667745337886, 4.9912393541764, 5.014645156104691, 5.03788822530542, 5.060971544399713, 5.0838980081803955, 5.1066704271529035, 5.129291530895807, 5.151763971252002, 5.174090325360848, 5.196273098540803, 5.218314727031424, 5.240217580603017, 5.2619839650416145, 5.283616124516458, 5.305116243836702, 5.326486450603552, 5.3477288172637065], [0.0, 0.8585814486631533, 1.1329050135538825, 1.3323858209537522, 1.4948771275386208, 1.6344419564559967, 1.7580936309501132, 1.8699100529852137, 1.9725021954206712, 2.067657038994663, 2.156659091242814, 2.2404671185622567, 2.3198184539181157, 2.395294081425862, 2.4673611073477515, 2.5364015159477997, 2.602732250874477, 2.666619612922822, 2.7282898197187166, 2.787936905061957, 2.845728731735174, 2.90181163934494, 2.9563140867694497, 3.009349542140152, 3.0610188015018984, 3.1114118680099447, 3.160609489068918, 3.208684424338806, 3.2557024998787267, 3.3017234907929316, 3.3468018651894833, 3.390987415107385, 3.4343257946526133, 3.4768589814437374, 3.518625674273817, 3.5596616374097194, 3.6000000000000005, 3.6396715175211476, 3.6787048009649514, 3.7171265184863813, 3.754961573438278, 3.7922332620757886, 3.8289634136885087, 3.8651725154877834, 3.9008798242216334, 3.9361034661958016, 3.970860527134718, 4.005167133111731, 4.039038523606319, 4.072489117601433, 4.10553257351179, 4.138181843630171, 4.170449223690313, 4.202346398069463, 4.233884481088825, 4.2650740548144555, 4.295925203713067, 4.326447546475684, 4.356650265285968, 4.386542132778763, 4.416131536907001, 4.445426503911289, 4.474434719565522, 4.50316354885352, 4.531620054215531, 4.559811012489174, 4.587742930656799, 4.615422060500095, 4.642854412252911, 4.670045767334409, 4.697001690236919, 4.723727539635793, 4.750228478782421, 4.776509485235903, 4.802575359983939, 4.828430735998954, 4.854080086271479, 4.879527731359161, 4.904777846486487, 4.9298344682273685, 4.954701500800042, 4.97938272200133, 5.003881788805102, 5.028202242647783, 5.052347514421974, 5.076320929197541, 5.100125710688097, 5.123764985479382, 5.147241787034822, 5.170559059492411, 5.19371966126597, 5.216726368462963, 5.239581878130085, 5.262288811337081, 5.284849716108522, 5.307267070212551, 5.329543283815009, 5.351680702006776, 5.373681607211614, 5.39554822148133, 5.417282708684606, 5.438887176595447], [0.0, 0.8728126548676132, 1.1516832027205075, 1.35447045531362, 1.5196550966939724, 1.6615332481997944, 1.7872344806944858, 1.900904288406046, 2.0051969217340444, 2.101928981077563, 2.1924062650118117, 2.277603431731167, 2.3582700356824593, 2.4349966909408587, 2.508258246173897, 2.578443017132062, 2.6458732008855272, 2.710819512232841, 2.7735119184146537, 2.8341476693904166, 2.89289741031114, 2.949909906399649, 3.005315745772766, 3.0592302773251205, 3.1117559678216806, 3.1629843122429264, 3.2129973964022835, 3.2618691859696383, 3.309666598087803, 3.35645039864861, 3.4022759585828855, 3.4471938952453622, 3.4912506194704527, 3.534488804666445, 3.5769477910687524, 3.6186639357460737, 3.659670916971042, 3.6999999999999997, 3.7396802700592158, 3.778738837335119, 3.8172010179599685, 3.8550904943302733, 3.892429457561665, 3.9292387344462343, 3.9655379009175054, 4.001345383729356, 4.036678551806451, 4.071553798515912, 4.105986615935471, 4.139991662046395, 4.173582821655104, 4.206773261741929, 4.2395754818455265, 4.272001360014674, 4.304062194793279, 4.335768743647837, 4.367131258197669, 4.39815951656605, 4.428862853133675, 4.459250185944045, 4.489330041982549, 4.519110580526777, 4.548599614744283, 4.577804631695369, 4.606732810882031, 4.635391041469696, 4.663785938295606, 4.691923856766321, 4.719810906736848, 4.747452965454847, 4.774855689645522, 4.802024526805634, 4.828964725768782, 4.8556813465983755, 4.882179269859709, 4.908463205317903, 4.934537700104449, 4.9604071463913355, 4.986075788608459, 5.0115477302369715, 5.036826940208524, 5.06191725893788, 5.086822404014184, 5.111545975574072, 5.136091461378062, 5.1604622416099035, 5.184661593417081, 5.20869269520929, 5.232558630730386, 5.256262392918199, 5.279806887565488, 5.303194936794406, 5.326429282355884, 5.349512588764562, 5.372447446279173, 5.395236373737494, 5.41788182125448, 5.440386172791491, 5.462751748604041, 5.484980807575013, 5.507075549439766, 5.529038116909194], [0.0, 0.8868908165896259, 1.1702594484818434, 1.37631758827079, 1.5441665999285166, 1.688333196211783, 1.8160619454591787, 1.9315652072653249, 2.0375400441569607, 2.1358323576598877, 2.227769008421933, 2.314340375531994, 2.3963081034869984, 2.474272332759813, 2.5487155711602814, 2.620032397835628, 2.688550206781662, 2.754544079331596, 2.8182476920169433, 2.8798614763697565, 2.9395588299874267, 2.997490917623599, 3.053790433735577, 3.108574587755167, 3.161947499200286, 3.214002138833329, 3.2648219164830765, 3.3144819908597043, 3.363050358456047, 3.41058876529644, 3.4571534754253865, 3.502795922637781, 3.5475632663585035, 3.5914988683029363, 3.63464270325068, 3.677031714697188, 3.7187001241338087, 3.7596797011144933, 3.8000000000000003, 3.8396885682545485, 3.878771130350723, 3.917271750673775, 3.9552129782742407, 3.9926159758730564, 4.0295006351566816, 4.065885680096066, 4.101788759770532, 4.137226531966456, 4.172214738643347, 4.206768274210564, 4.24090124743158, 4.274627037665496, 4.307958346064141, 4.340907242265048, 4.373485207053672, 4.405703171410666, 4.437571552310372, 4.46910028559376, 4.500298856201811, 4.531176326022934, 4.561741359579802, 4.5920022477562865, 4.621966929743591, 4.651643013365673, 4.681037793927374, 4.710158271713944, 4.739011168257623, 4.76760294147545, 4.795939799772249, 4.82402771519362, 4.8518724357057605, 4.8794794966716415, 4.9068542315867045, 4.934001782131406, 4.960927107592845, 4.987634993703001, 5.014130060936998, 5.04041677231102, 5.066499440716125, 5.092382235821177, 5.118069190575301, 5.143564207337802, 5.168871063661231, 5.193993417751167, 5.218934813624481, 5.243698685986096, 5.2682883648427365, 5.292707079870732, 5.316957964553644, 5.341044060104337, 5.364968319184989, 5.388733609437592, 5.412342716836555, 5.435798348874209, 5.459103137589245, 5.482259642447413, 5.50527035308316, 5.528137691910307, 5.550864016609275, 5.573451622497935, 5.595902744792604, 5.618219560765351], [0.0, 0.900821544043058, 1.188641153559468, 1.39793592601082, 1.5684214051919367, 1.7148524803976866, 1.8445875131249083, 1.9619050280838735, 2.0695444515762995, 2.16938067939716, 2.262761413693267, 2.350692589810167, 2.433947815681216, 2.5131366584112915, 2.5887492047417884, 2.661186231622926, 2.730780275551078, 2.7978107386653672, 2.862514967942429, 2.9250965431677356, 2.985731585559923, 3.0445736342742484, 3.1017574680497377, 3.157402137370804, 3.211613397199771, 3.26448567862575, 3.316103701627056, 3.366543805459979, 3.415875054663829, 3.464160165130955, 3.511456284666359, 3.5578156549548865, 3.603286176172232, 3.647911891132542, 3.691733402514307, 3.734788234098352, 3.777111144905853, 3.8187344035070896, 3.859688028484274, 3.9000000000000004, 3.9396964465908155, 3.978801810630316, 4.017338995355452, 4.055329495897971, 4.092793516390532, 4.129750074908533, 4.16621709775202, 4.202211504357483, 4.237749283949308, 4.272845564888937, 4.307514677551497, 4.341770211450713, 4.375625067240178, 4.409091504139759, 4.442181183267927, 4.474905207302354, 4.507274156840714, 4.539298123789969, 4.570986742074631, 4.602349215921598, 4.633394345950456, 4.664130553273108, 4.694565901784619, 4.724708118807895, 4.754564614237873, 4.784142498315917, 4.813448598151899, 4.84248947309979, 4.871271429082161, 4.899800531949778, 4.928082619954304, 4.956123315404738, 4.983928035571737, 5.011502002898069, 5.038850254568215, 5.06597765148545, 5.092888886700435, 5.119588493331627, 5.146080852014288, 5.172370197911836, 5.198460627320443, 5.22435610389524, 5.250060464524218, 5.275577424873762, 5.30091058462795, 5.326063432441908, 5.351039350628026, 5.375841619592374, 5.400473422037318, 5.4249378469451965, 5.449237893356762, 5.4733764739571376, 5.497356418481079, 5.521180476948516, 5.5448513227405645, 5.56837155552546, 5.59174370404328, 5.6149702287576035, 5.638053524381828, 5.660995922287245, 5.683799692799553, 5.706467047390053], [0.0, 0.9146101038546526, 1.2068352673090323, 1.41933364152511, 1.5924286822139888, 1.741101126592248, 1.8728219680184823, 1.9919352210819103, 2.1012222435230137, 2.202586629509912, 2.2973967099940698, 2.3866738178209843, 2.4712034022696474, 2.551604360875076, 2.6283742819647347, 2.7019200770412266, 2.772579372620585, 2.8406358475526, 2.906330481800935, 2.969869971275522, 3.0314331330207955, 3.091175856362076, 3.1492349830493342, 3.2057313858310437, 3.260772438423691, 3.314454017339987, 3.3668621393372775, 3.418074312170107, 3.4681606575244937, 3.5171848512629826, 3.5652049159320067, 3.612273892861581, 3.6584404154186103, 3.703749200565168, 3.748241472470721, 3.791955329279463, 3.8349260620567307, 3.8771864332965045, 3.918766921064919, 3.959695933807117, 3.9999999999999996, 4.0397039361480145, 4.078830996059936, 4.117403003885964, 4.155440473016339, 4.192962712629475, 4.229987923417015, 4.2665332837953365, 4.302615027730281, 4.33824851514782, 4.3734482957731124, 4.408228167129809, 4.442601227337288, 4.476579923263002, 4.5101760945180756, 4.5434010137249805, 4.576265423434892, 4.608779570028055, 4.64095323489209, 4.672795763139775, 4.704316090098694, 4.73552276577976, 4.766423977509255, 4.797027570889511, 4.82734106923613, 4.85737169162445, 4.887126369664522, 4.916611763112052, 4.9458342744121575, 4.974800062263458, 5.003515054281687, 5.031984958834561, 5.0602152761129995, 5.088211308497872, 5.1159781702760805, 5.143520796755041, 5.170843952820299, 5.197952240977166, 5.224850108913754, 5.251541856619643, 5.278031643091577, 5.304323492654968, 5.330421300927704, 5.356328840450578, 5.3820497660067685, 5.407587619651024, 5.432945835467607, 5.458127744074612, 5.483136576890916, 5.507975470180828, 5.532647468890366, 5.557155530288105, 5.581502527422559, 5.605691252407251, 5.629724419543801, 5.65360466829266, 5.67733456610044, 5.700916611092179, 5.724353234636309, 5.747646803789608, 5.770799623628854, 5.793813939475562], [0.0, 0.9282614481346684, 1.2248483240791976, 1.4405184197240475, 1.616197053119423, 1.7670885618996666, 1.9007754504399492, 2.021666571492183, 2.132584796958918, 2.235462133792311, 2.3316873364629074, 2.422296982089408, 2.508088243458424, 2.5896892556842315, 2.6676050340290507, 2.7422485635004556, 2.813962509981299, 2.8830347864727606, 2.9497099697722087, 3.014197840904224, 3.076679885911785, 3.1373143209027847, 3.196240030108281, 3.253579690406724, 3.3094422781598833, 3.363925100920078, 3.4171154593189117, 3.4690920179809837, 3.519925945218928, 3.569681867312433, 3.618418672844457, 3.666190194832594, 3.7130457925386735, 3.7590308503639807, 3.8041872077842496, 3.8485535315913206, 3.8921656396001048, 3.9350567833130494, 3.977257895707701, 4.018797809249738, 4.059703448376447, 4.1000000000000005, 4.139711065012315, 4.178858793307848, 4.217464004456871, 4.255546295843936, 4.293124139821696, 4.3302149712092035, 4.366835266278235, 4.403000614214901, 4.4387257819115495, 4.4740247728317675, 4.508910880595657, 4.5433967378508955, 4.577494360925012, 4.611215190694087, 4.644570130051133, 4.677569578312454, 4.710223462861312, 4.742541268294349, 4.774532063306618, 4.806204525525316, 4.837566964479626, 4.868627342874259, 4.899393296316791, 4.929872151633479, 4.960070943894633, 4.989996432258551, 5.019655114732365, 5.049053241938581, 5.078196829967708, 5.10709167238977, 5.13574335149078, 5.164157248794211, 5.192338554922108, 5.220292278845602, 5.248023256570266, 5.27553615929777, 5.302835501101805, 5.329925646153003, 5.35681081552472, 5.383495093608893, 5.4099824341688665, 5.436276666053857, 5.462381498597832, 5.488300526723762, 5.514037235772576, 5.539595006074715, 5.56497711728077, 5.590186752466497, 5.615227002026361, 5.640100867368716, 5.664811264424805, 5.6893610269828505, 5.7137529098577655, 5.737989591906223, 5.76207367889619, 5.786007706239372, 5.809794141594474, 5.833435387348634, 5.85693378298389, 5.880291607335118], [0.0, 0.9417802404414931, 1.2426864774721484, 1.4614974977300743, 1.639734637635002, 1.7928236641212354, 1.9284575098296233, 2.051109236108465, 2.1636428259277105, 2.268018423140789, 2.3656450074288164, 2.4575742521646853, 2.544614939809584, 2.627404353361897, 2.706454862904468, 2.7821854679772566, 2.854943824898634, 2.9250220397083613, 2.9926682511129368, 3.0580952952957072, 3.1214873013827256, 3.183004789671836, 3.2427886670430817, 3.3009633969871253, 3.357639542949639, 3.412915829627423, 3.4668808290601643, 3.519614351509527, 3.5711886017522145, 3.621669147256686, 3.671115734233377, 3.719582979700321, 3.7671209617659724, 3.813775725790117, 3.85958972058025, 3.904602176054396, 3.9488494316624028, 3.9923652231670044, 4.0351809340400555, 4.077325816650609, 4.11882718755164, 4.159710600466454, 4.2, 4.239717858628075, 4.278885299128036, 4.31752220429214, 4.355647315496277, 4.393278321472553, 4.430431938445933, 4.467123982636593, 4.50336943599542, 4.539182505926298, 4.574576679651777, 4.6095647737958725, 4.644158979686631, 4.678370904820033, 4.712211610874038, 4.745691648616028, 4.77882109000732, 4.811609557774055, 4.844066252683783, 4.876199978740854, 4.908019166490787, 4.93953189460363, 4.9707459098885955, 5.001668645876622, 5.032307240093696, 5.062668550135532, 5.092759168643384, 5.122585437271081, 5.1521534597248335, 5.181469113949677, 5.210538063529588, 5.239365768362186, 5.267957494663453, 5.296318324352985, 5.324453163865809, 5.352366752432932, 5.380063669869029, 5.407548343902601, 5.434825057080861, 5.461897953279038, 5.488771043841353, 5.515448213378698, 5.541933225246156, 5.568229726721574, 5.594341253904861, 5.620271236356103, 5.646023001489286, 5.671599778737081, 5.697004703501102, 5.7222408209009, 5.747311089334058, 5.7722183838588474, 5.7969654994100965, 5.821555153858171, 5.845989990920297, 5.870272582932807, 5.8944054334923015, 5.918390979973232, 5.942231595928824, 5.965929593381905], [0.0, 0.9551708790378903, 1.2603555310303953, 1.4822777009677934, 1.6630490935809787, 1.8183148060271876, 1.9558771523892622, 2.0802727939354853, 2.194406434983793, 2.300266089560305, 2.399280770828355, 2.4925171053074964, 2.5807953750775927, 2.6647619243022014, 2.744936408163504, 2.8217437837180572, 2.8955366504120597, 2.9666112675752254, 3.035219302057454, 3.101576616238957, 3.165869957273302, 3.2282621278053223, 3.2888960381899963, 3.347897921593703, 3.405379913500983, 3.4614421423190547, 3.516174439443155, 3.569657749911752, 3.621965305140278, 3.6731636048638046, 3.7233132447902153, 3.772469618505917, 3.8206835161515613, 3.868001637779763, 3.914467035753513, 3.960119497778772, 4.004995879995393, 4.0491303978357704, 4.092554880995529, 4.135298997766548, 4.177390453100367, 4.2188551640541725, 4.259717415687659, 4.3, 4.3397243401013315, 4.378910601486047, 4.417577792003022, 4.4557438518904, 4.4934257350516615, 4.530639482588836, 4.567400289472667, 4.603722565114048, 4.639619988502691, 4.67510555849491, 4.710191639760327, 4.744890004835316, 4.779211872677557, 4.813167944069803, 4.846768434180872, 4.880023102556985, 4.912941280786183, 4.9455318980519545, 4.977803504768961, 5.009764294473271, 5.041422124121583, 5.072784532937989, 5.103858759932908, 5.134651760206313, 5.165170220136482, 5.19542057154562, 5.225409004925071, 5.255141481795034, 5.284623746266771, 5.313861335869085, 5.342859591695295, 5.371623667921925, 5.40015854074582, 5.428469016782419, 5.456559740964182, 5.484435203974969, 5.5120997492531, 5.539557579593215, 5.566812763374558, 5.5938692404411015, 5.620730827656935, 5.647401224158482, 5.673884016323445, 5.700182682474883, 5.726300597337385, 5.752241036261099, 5.7780071792281325, 5.8036021146548595, 5.829028843002643, 5.854290280208573, 5.87938926094707, 5.904328541732357, 5.929110803871174, 5.953738656274442, 5.978214638135982, 6.002541221485887, 6.026720813625591, 6.0507557594512615], [0.0, 0.9684375177775887, 1.2778609657967936, 1.5028654755767286, 1.6861476532367599, 1.843569895117535, 1.9830428838509613, 2.1091662916779668, 2.2248851671770558, 2.332215136463948, 2.4326050606703427, 2.527136380993477, 2.616640772643237, 2.701773557040241, 2.7830616070046066, 2.860935781941751, 2.9357535786513984, 3.007815371292962, 3.0773763221884645, 3.1446552918918247, 3.2098416213406935, 3.2731003743919254, 3.3345764463228758, 3.394397823588107, 3.4526781991536493, 3.509519092138515, 3.5650115816316195, 3.619237736939984, 3.6722718066109024, 3.724181214013092, 3.7750273964853767, 3.8248665169913663, 3.8737500711103547, 3.9217254075252073, 3.968836176565374, 4.015122718559525, 4.060622401552874, 4.1053699162056425, 4.149397534305107, 4.192735336214456, 4.235411411687138, 4.277452037749688, 4.318881836763867, 4.359723917293379, 4.4, 4.439730530462385, 4.478934780534802, 4.5176309396324426, 4.555836197136351, 4.593566816947964, 4.6308382050852765, 4.667664971095568, 4.70406098395991, 4.740039423079414, 4.775612824860097, 4.810793125350424, 4.845591699331354, 4.880019396211842, 4.914086573042075, 4.9478031249213785, 4.981178513046857, 5.014221790621959, 5.046941626820475, 5.079346328980816, 5.1114438631871755, 5.143241873378064, 5.174747699108564, 5.205968392080003, 5.236910731539658, 5.267581238643134, 5.297986189863263, 5.328131629521484, 5.3580233815106455, 5.387667060271859, 5.417068081082399, 5.446231669706606, 5.475162871457131, 5.503866559709857, 5.532347443912025, 5.5606100771198745, 5.588658863098971, 5.616498063017757, 5.6441318017623505, 5.671564073898329, 5.698798749303291, 5.7258395784920095, 5.752690197654405, 5.779354133424948, 5.805834807400735, 5.8321355404241775, 5.858259556645056, 5.884209987375633, 5.9099898747515285, 5.935602175210109, 5.9610497627973915, 5.986335432313603, 6.011461902306914, 6.036431817924146, 6.061247753626702, 6.085912215779404, 6.110427645119373, 6.134796419111703], [0.0, 0.9815840849118561, 1.2952079651299664, 1.5232669175962226, 1.7090371560850535, 1.8685964094232759, 2.009962747986858, 2.1377982846995818, 2.2550880472590378, 2.3638750239633906, 2.4656277442758388, 2.56144232998895, 2.6521617463274842, 2.738450210719178, 2.820841748297822, 2.899773067397644, 2.975606517847699, 3.0486465513952448, 3.119151794198159, 3.1873440778486692, 3.253415313593096, 3.3175328060348943, 3.3798434174089738, 3.440476871589695, 3.49954840492837, 3.5571609146689678, 3.6134067163016548, 3.6683689932266526, 3.722123001917418, 3.774737081016837, 3.826273501877373, 3.8767891898764817, 3.9263363396474245, 3.974962942632798, 4.022713241716529, 4.069628124848408, 4.1157454673459375, 4.161100430796047, 4.205725725076455, 4.249651838892141, 4.292907243315766, 4.335518572085257, 4.37751078181164, 4.418907294758038, 4.459730126444834, 4.500000000000001, 4.539736448893781, 4.578957909463202, 4.617681804435648, 4.6559246184954866, 4.693701966797848, 4.7310286572150355, 4.767918746999941, 4.804385594464422, 4.840441906196566, 4.876099780277042, 4.911370745899786, 4.946265799754791, 4.9807954394894995, 5.0149696945294915, 5.048798154507898, 5.082289995525662, 5.115454004440857, 5.148298601364255, 5.180831860519866, 5.21306152961289, 5.24499504783308, 5.276639562608809, 5.308001945215834, 5.339088805334632, 5.369906504641334, 5.400461169509219, 5.430758702890648, 5.460804795442928, 5.490604935955883, 5.52016442113375, 5.549488364779449, 5.578581706425076, 5.607449219448757, 5.636095518714599, 5.664525067769413, 5.692742185627124, 5.720751053169299, 5.748555719187857, 5.776160106094097, 5.803568015316138, 5.830783132405281, 5.857809031870163, 5.884649181756159, 5.911306947986211, 5.937785598478025, 5.96408830705152, 5.990218157139392, 6.01617814531273, 6.041971184632809, 6.0676001078393496, 6.09306767038489, 6.118376553324198, 6.143529366067064, 6.1685286490022815, 6.193376876000052, 6.218076456799626], [0.0, 0.9946143000646653, 1.3124014371031711, 1.5434877993082745, 1.7317240783673493, 1.8934014298212367, 2.0366443613687135, 2.166176873993278, 2.285023620681617, 2.3952547097489045, 2.498358164917831, 2.5954446586475957, 2.687368346257027, 2.774802262448023, 2.8582875213674295, 2.9382666285131, 3.0151067437923147, 3.089116360452018, 3.160557537829712, 3.2296550522611467, 3.296603362553129, 3.3615719942242785, 3.4247097590587567, 3.486148102973916, 3.5460037920468173, 3.6043810894494737, 3.661373536130691, 3.717065419723757, 3.7715329957077715, 3.824845509899273, 3.8770660602830365, 3.928252327902718, 3.9784572002586613, 4.027729305864534, 4.0761134749144095, 4.123651138132553, 4.170380673619206, 4.2163377097201336, 4.261555390526229, 4.306064609470291, 4.349894215569377, 4.393071196115774, 4.435620839011549, 4.477566877442884, 4.518931619179162, 4.559736062441261, 4.6000000000000005, 4.639742112928889, 4.678980055236456, 4.717730530435986, 4.756009360968804, 4.793831551276989, 4.831211345218973, 4.868162278433936, 4.904697226185866, 4.940828447153585, 4.976567623577397, 5.011925898124841, 5.046913907796275, 5.081541815154701, 5.1158193371325655, 5.149755771640621, 5.183360022179674, 5.216640620634776, 5.2496057484126855, 5.282263256066909, 5.31462068154007, 5.346685267140369, 5.378463975357555, 5.409963503613499, 5.441190298033553, 5.4721505663166425, 5.502850289774935, 5.533295234607397, 5.563490962465783, 5.593442840366388, 5.623156049996229, 5.652635596458115, 5.681886316495243, 5.710912886232564, 5.739719828469048, 5.768311519552151, 5.796692195863304, 5.82486595994085, 5.8528367862648425, 5.880608526726143, 5.908184915800572, 5.935569575447224, 5.96276601974867, 5.989777659309402, 6.016607805427691, 6.043259674054902, 6.069736389555314, 6.09604098827854, 6.122176421955814, 6.148145560930569, 6.173951197233098, 6.1995960475083125, 6.225082755805086, 6.25041389623506, 6.275591975508274, 6.300619435352496], [0.0, 1.007531689590605, 1.3294460347691834, 1.5635335930706444, 1.7542145598235936, 1.917991669270219, 2.063094944815883, 2.1943097396293685, 2.3146999888802227, 2.4263626860746585, 2.5308051803985627, 2.629152568986901, 2.722270100360125, 2.8108395501475556, 2.8954090601269615, 2.976426882763522, 3.054264946393384, 3.1292357507687645, 3.2016047586796805, 3.271599665707549, 3.339417456160925, 3.405229857243201, 3.4691876134070934, 3.5314238777021716, 3.592056932685706, 3.6511923956304955, 3.7089250223330232, 3.7653401950983425, 3.8205151597610367, 3.874520061456291, 3.927418817643573, 3.9792698584895994, 4.03012675836242, 4.08003877733052, 4.129051327812741, 4.177206378608061, 4.2245428062459816, 4.271096701789544, 4.316901639783067, 4.361988914882725, 4.406387750777435, 4.450125485252501, 4.493227734632457, 4.535718540334333, 4.577620499845997, 4.618954884099263, 4.659741742920305, 4.7, 4.739747538625407, 4.779001279243938, 4.817777249788274, 4.856090649568214, 4.893955907431958, 4.931386734810572, 4.968396174183416, 5.004996643436884, 5.041199976532456, 5.077017460851231, 5.112459871539857, 5.147537503145951, 5.182260198799022, 5.216637377164906, 5.250678057377162, 5.284390882127294, 5.317784139076735, 5.350865780736762, 5.383643442947789, 5.416124462076301, 5.448315891036235, 5.480224514231132, 5.511856861504331, 5.543219221176227, 5.574317652240296, 5.605157995783063, 5.63574588568732, 5.666086758672603, 5.696185863722236, 5.726048270941978, 5.75567887989143, 5.785082427425948, 5.814263495083607, 5.84322651604896, 5.87197578172274, 5.900515447924334, 5.928849540751698, 5.956981962121497, 5.984916495010437, 6.012656808417213, 6.040206462062963, 6.067568910846847, 6.094747509072074, 6.121745514456649, 6.148566091942017, 6.175212317311884, 6.201687180632605, 6.2279935895257275, 6.254134372282578, 6.280112280830048, 6.305929993556157, 6.331590118003403, 6.357095193437305, 6.382447693297171], [0.0, 1.0203396005006327, 1.3463461745354395, 1.5834094929274733, 1.776514427938336, 1.9423734993208153, 2.0893213519106983, 2.222204171084521, 2.3441248412668174, 2.457207013295063, 2.562977198029445, 2.6625747950273917, 2.7568760519928843, 2.846571411400774, 2.9322159830985477, 3.014263717811496, 3.0930912718908203, 3.169015117637717, 3.2423040924494724, 3.3131887864117178, 3.381868687930399, 3.4485177072337647, 3.513288505063161, 3.5763159271319345, 3.637719759624956, 3.6976069624394143, 3.7560734959232844, 3.8132058277757244, 3.869082185793253, 3.923773606807715, 3.9773448208079847, 4.0298550007348055, 4.081358402002531, 4.131904910881854, 4.181540517081861, 4.230307722915902, 4.278245899118408, 4.325391595548034, 4.3717788135543065, 4.417439245616291, 4.46240248691931, 4.506696222771157, 4.550346395135357, 4.593377351047442, 4.635811975258316, 4.677671809099428, 4.718977157273685, 4.759747184033081, 4.800000000000001, 4.839752740717409, 4.879021637867739, 4.9178220839769535, 4.956168691315175, 4.99407534561547, 5.0315552551553715, 5.068620995679518, 5.1052845515846785, 5.141557353739026, 5.1774503142646715, 5.212973858575237, 5.248137954927735, 5.282952141719654, 5.317425552737284, 5.351566940539463, 5.385384698141759, 5.418886879149101, 5.452081216469978, 5.48497513973199, 5.517575791506895, 5.549890042442699, 5.5819245053912026, 5.613685548610977, 5.6451793081184345, 5.6764116992529665, 5.707388427516221, 5.7381149987402225, 5.768596728634245, 5.798838751756078, 5.828846029949341, 5.858623360285088, 5.888175382542667, 5.917506586262013, 5.946621317396864, 5.975523784596072, 6.004218065138025, 6.0327081105412015, 6.060997751872141, 6.089090704770459, 6.116990574209066, 6.144700859006371, 6.17222495610605, 6.19956616463876, 6.226727689779213, 6.253712646410985, 6.280524062610658, 6.307164882961948, 6.333637971709893, 6.3599461157643375, 6.386092027561418, 6.412078347791144, 6.437907647998605, 6.46358243306588], [0.0, 1.0330412131161864, 1.3631060528612353, 1.6031204342465077, 1.7986292199728149, 1.9665529742044574, 2.1153300949099445, 2.249867094801227, 2.3733054843014094, 2.4877953503387125, 2.594882206416745, 2.69571963581352, 2.791194794129649, 2.882006718755681, 2.9687174297778482, 3.051786528889274, 3.1315953612164047, 3.208464338639546, 3.282665645155955, 3.3544327413327557, 3.4239675988907172, 3.4914462929650933, 3.557023384681765, 3.620835398369723, 3.683003611362192, 3.743636315037741, 3.8028306642987526, 3.8606742032303423, 3.917246133441245, 3.972618376059396, 4.026856466859549, 4.080020315391877, 4.132164852464745, 4.183340585353936, 4.233594076267603, 4.282968356605607, 4.331503287205689, 4.37923587291438, 4.426200538344177, 4.472429370495333, 4.517952332966374, 4.5627974557033415, 4.606991003606137, 4.650557626792337, 4.693520494891765, 4.7359014173913385, 4.777720951755374, 4.818998500800457, 4.85975240059755, 4.9, 4.939757732748986, 4.9790411829830505, 5.017865144871945, 5.056243677004129, 5.094190152079278, 5.1317173023901415, 5.168837261520256, 5.2055616026340035, 5.241901373692141, 5.277867129888184, 5.313468963568162, 5.348716531867511, 5.383619082273701, 5.418185476301071, 5.452424211444942, 5.486343441564877, 5.51995099583183, 5.553254396360504, 5.586260874636366, 5.6189773868361135, 5.651410628131081, 5.683567046054577, 5.7154528530067035, 5.747074037963462, 5.778436377450965, 5.809545445840126, 5.840406625012385, 5.871025113442646, 5.901405934741627, 5.93155394569632, 5.961473843843984, 5.991170174612215, 6.020647338054994, 6.049909595212191, 6.078961074117853, 6.107805775480608, 6.136447578057706, 6.164890243742597, 6.193137422384394, 6.2211926563562585, 6.249059384888435, 6.276740948180533, 6.304240591306617, 6.331561467925634, 6.3587066438089215, 6.385679100195603, 6.412481736986031, 6.439117375782667, 6.465588762787181, 6.491898571561996, 6.518049405663864, 6.54404380115668], [0.0, 1.0456395525912732, 1.3797296614612147, 1.6226711115996042, 1.82056420302608, 1.990535852767486, 2.141127368338324, 2.277305099281833, 2.402248867962862, 2.518134982456162, 2.626527804403767, 2.7285949854805387, 2.8252345004947665, 2.917153911869922, 3.0049220937458303, 3.0890042528370594, 3.1697863849222268, 3.247592809429166, 3.3226990297448693, 3.395341353578899, 3.4657242157757313, 3.534025838775392, 3.6004026686368213, 3.6649928946563133, 3.7279192731913513, 3.789291416275995, 3.849207663654457, 3.9077566270460276, 3.965018473953872, 4.021066002612059, 4.075965548029614, 4.129777750376977, 4.182558210365093, 4.23435805122562, 4.285224403010953, 4.335200821905617, 4.384327654865776, 4.432642358026459, 4.480179775821704, 4.526972386565217, 4.573050519273263, 4.618442545727981, 4.663175051139943, 4.707272986244501, 4.750759803234126, 4.793657577570913, 4.835987117425454, 4.877768062239231, 4.919018971698726, 4.9597574062333, 5.0, 5.039762527192, 5.079059962399707, 5.117906535661535, 5.156315782762436, 5.194300591270423, 5.231873242742803, 5.269045451483201, 5.305828400186552, 5.342232772771063, 5.3782687846628505, 5.413946210769874, 5.449274411356308, 5.484262356006109, 5.51891864584486, 5.55325153417161, 5.587268945637101, 5.620978494091152, 5.654387499210006, 5.687503002003642, 5.720331779293615, 5.752880357243409, 5.785155024015763, 5.817161841624571, 5.848906657042927, 5.880395112623368, 5.91163265588147, 5.9426245486895635, 5.973375875923252, 6.003891553599934, 6.034176336545163, 6.064234825619793, 6.094071474538175, 6.123690596305218, 6.15309636929795, 6.182292843015197, 6.211283943517164, 6.240073478575053, 6.268665142549307, 6.297062521013708, 6.32526909514125, 6.353288245866577, 6.381123257838692, 6.4087773231766425, 6.436253545040038, 6.463554941025374, 6.490684446398417, 6.5176449171721655, 6.54443913303929, 6.571069800167345, 6.597539553864471, 6.623850961122849], [0.0, 1.0581374994243518, 1.3962208011758808, 1.6420659950755467, 1.842324392337243, 2.0143276184821377, 2.1667190705133486, 2.3045244579824393, 2.4309616098988576, 2.5482328465349076, 2.657921227475505, 2.761208360685245, 2.8590029539648554, 2.952021026837128, 3.040838252877445, 3.1259253991569724, 3.207673075046753, 3.286409476383997, 3.3624133994941414, 3.435923976541106, 3.50714808586513, 3.576266080099742, 3.6434362752164358, 3.7087985122111515, 3.7724770146796995, 3.834582704787697, 3.895215097679513, 3.954463864200935, 4.012410130052616, 4.069127563585345, 4.124683292673542, 4.179138682285812, 4.232549997697407, 4.284968973187484, 4.336443302127689, 4.387017061305346, 4.4367310799213, 4.485623261802887, 4.533728867860249, 4.581080764602273, 4.627709643551054, 4.673644215600829, 4.718911383720378, 4.763536396867289, 4.807542987545015, 4.850953495071352, 4.893788976325355, 4.936069305487806, 4.977813264078776, 5.019038622417651, 5.059762213480288, 5.1000000000000005, 5.139767135550129, 5.179078020252808, 5.217946351678682, 5.256385171433681, 5.294406907869724, 5.3320234153049775, 5.369246010094897, 5.406085503856611, 5.442552234115529, 5.4786560926136385, 5.5144065514931375, 5.549812687546418, 5.584883204703524, 5.61962645491059, 5.654050457537291, 5.688162917437548, 5.721971241775618, 5.755482555718746, 5.788703717088059, 5.821641330050637, 5.854301757928122, 5.886691135190282, 5.918815378695823, 5.950680198237176, 5.9822911064410365, 6.013653428071961, 6.044772308782238, 6.075652723347682, 6.106299483425626, 6.13671724486845, 6.1669105146232726, 6.196883657245944, 6.226640901055304, 6.256186343951583, 6.2855239589209955, 6.31465759924691, 6.343591003446401, 6.372327799949617, 6.40087151153807, 6.4292255595568335, 6.45739326791449, 6.485377866883705, 6.5131824967144265, 6.5408102110708, 6.568263980302187, 6.5955466945579175, 6.62266116675478, 6.6496101354056405, 6.67639626731701, 6.703022160162896], [0.0, 1.0705377990665903, 1.4125830946497688, 1.661309345190579, 1.863914568014426, 2.0379334977373422, 2.1921108232199056, 2.3315311502387823, 2.459450017499877, 2.578095554238224, 2.6890693718934973, 2.7935669256787157, 2.892507572529547, 2.9866157229922905, 3.0764737969534983, 3.162558078397542, 3.245263754241621, 3.3249228664457084, 3.401817478545766, 3.476189525092443, 3.5482483088305674, 3.618176295943842, 3.6861336577065793, 3.752261873909538, 3.8166866239232387, 3.8795201298087187, 3.940863072927035, 4.000806174975454, 4.059431512365665, 4.116813616766904, 4.173020402724281, 4.228113954341671, 4.282151196266361, 4.335184469050854, 4.3872620249848, 4.43842845739082, 4.488725073946639, 4.538190222674052, 4.586859577705349, 4.634766390711609, 4.681941712888477, 4.728414591592791, 4.774212245068868, 4.819360218166504, 4.863882521510056, 4.907801756211491, 4.951139225915159, 4.993915037707111, 5.036148193207803, 5.07785667098677, 5.1190575012852895, 5.159766833903743, 5.2, 5.239771568451038, 5.279095397349156, 5.317984681134695, 5.356451993807268, 5.394509328605644, 5.4321681345015, 5.4694393498131655, 5.506333433211377, 5.5428603923593185, 5.579029810403099, 5.614850870505922, 5.650332378599077, 5.685482784505045, 5.720310201572391, 5.754822424948121, 5.7890269486009505, 5.82293098119787, 5.856541460926722, 5.889865069348735, 5.922908244357235, 5.955677192311763, 5.988177899410613, 6.020416142359202, 6.052397498386624, 6.084127354658285, 6.115610917128302, 6.1468532188718275, 6.177859127933941, 6.2086333547288985, 6.239180459020671, 6.269504856513284, 6.299610825077191, 6.329502510635861, 6.359183932734883, 6.388658989814203, 6.417931464202531, 6.447005026851536, 6.475883241826167, 6.504569570566193, 6.5330673759330375, 6.56137992605489, 6.58951039798225, 6.6174618811651085, 6.645237380762316, 6.672839820792824, 6.700272047137956, 6.727536830403176, 6.754636868647265, 6.7815747899863394], [0.0, 1.0828430707200105, 1.4288199979406664, 1.6804052265417653, 1.8853392903532198, 2.0613584765873445, 2.217307989725977, 2.358330880427772, 2.487720108112028, 2.6077294131930757, 2.7199788167957633, 2.8256775152650517, 2.9257554330633697, 3.0209453074570707, 3.11183625294445, 3.1989100281449794, 3.282566362442621, 3.3631411144458787, 3.440919589863421, 3.5161465041569215, 3.5890335658967065, 3.659765338619752, 3.7285038346853314, 3.795392160120344, 3.8605574389138915, 3.9241131830608618, 3.9861612312018586, 4.046793347832573, 4.106092552790083, 4.164134234446155, 4.220987087988043, 4.276713911143902, 4.331372282880042, 4.385015145376222, 4.437691305556904, 4.489445869321614, 4.540320619158207, 4.590354343878918, 4.639583127671515, 4.6880406044176315, 4.735758182230154, 4.78276524235008, 4.829089315881203, 4.874756241297993, 4.9197903052143666, 4.964214368530246, 5.008049979764218, 5.051317477122764, 5.0940360806400244, 5.136223975539776, 5.17789838781701, 5.219075652905607, 5.259771278187072, 5.300000000000001, 5.339775835728205, 5.379112131475213, 5.418021605772183, 5.456516389713884, 5.49460806387193, 5.532307692294897, 5.569625853870464, 5.606572671294668, 5.643157837866863, 5.67939064230591, 5.715279991762667, 5.750834433185903, 5.786062173182878, 5.820971096501732, 5.855568783250429, 5.889862524955813, 5.9238593395565635, 5.957565985414959, 5.99098897442454, 6.0241345842837, 6.05700886999895, 6.089617674675912, 6.121966639651011, 6.1540612140122954, 6.185906663553606, 6.217508079202653, 6.24887038496015, 6.279998345384098, 6.310896572650569, 6.341569533219795, 6.372021554134111, 6.402256828972206, 6.432279423482241, 6.46209328091469, 6.491702227074149, 6.52110997510796, 6.550320130048127, 6.579336193121861, 6.608161565844918, 6.63679955391091, 6.665253370888865, 6.693526141740391, 6.721620906167061, 6.749540621797897, 6.777288167226138, 6.804866344903908, 6.832277883902759, 6.85952544254763], [0.0, 1.0950558154077705, 1.4449348111684153, 1.6993575203308238, 1.906602913887862, 2.08460731611473, 2.2423156913079314, 2.384929095543812, 2.5157776275776853, 2.6371404464251693, 2.750655844468438, 2.8575466558607703, 2.9587532931310068, 3.0550167576544918, 3.146932808202504, 3.234988636864221, 3.31958848133422, 3.40107198817103, 3.479727680877173, 3.555803034914859, 3.6295121465897995, 3.7010416610216272, 3.770555417810916, 3.8381981369925557, 3.9040983763117154, 3.968370927997743, 4.03111877926886, 4.092434729578075, 4.152402735093964, 4.211099034449018, 4.2685930976027615, 4.324948430541677, 4.380223261631082, 4.434471130154174, 4.487741393499769, 4.540079666290076, 4.591528202252848, 4.642126227676323, 4.691910233720423, 4.740914233603377, 4.789169989671549, 4.836707214539526, 4.883553749818089, 4.929735725398538, 4.975277701809099, 5.020202797784225, 5.064532804875462, 5.108288290671859, 5.15148869197892, 5.1941523991207745, 5.236296832374193, 5.277938511410725, 5.319093118510434, 5.359775556214335, 5.400000000000001, 5.4397799464937435, 5.479128257671488, 5.518057201447427, 5.556578489003575, 5.594703309173345, 5.632442360157417, 5.669805878819711, 5.706803667784556, 5.743445120532764, 5.779739244673662, 5.815694683551986, 5.85131973633245, 5.8866223766905925, 5.9216102702259175, 5.956290790702077, 5.990671035208918, 6.024757838332277, 6.058557785409478, 6.092077224941354, 6.125322280225243, 6.158298860267686, 6.191012670030396, 6.2234692200584565, 6.255673835535469, 6.287631664806702, 6.31934768740775, 6.350826721633237, 6.382073431677235, 6.41309233437453, 6.443887805569601, 6.474464086138024, 6.504825287683123, 6.534975397928953, 6.5649182858290915, 6.594657706409266, 6.624197305360501, 6.65354062339827, 6.682691100402008, 6.711652079348283, 6.740426810050065, 6.769018452713547, 6.797430081323295, 6.825664686865674, 6.853725180399869, 6.881614395985198, 6.909335093472795, 6.936889961169266], [0.0, 1.107178423389128, 1.4609306882990152, 1.7181699358710047, 1.92770960030144, 2.10768456654595, 2.2671388224339473, 2.4113310013478975, 2.543628067270604, 2.6663344102158555, 2.78110645897132, 2.889180584844144, 2.991507611021937, 3.0888367419954115, 3.181770331770475, 3.270800965804046, 3.35633735682753, 3.4387229113923463, 3.518249347045801, 3.5951668788803315, 3.669691973314248, 3.742013341686627, 3.812296637353305, 3.8806881824449073, 3.9473179578807684, 4.012302026675868, 4.075744516148919, 4.137739253071697, 4.198371123033638, 4.257717208652576, 4.315847748942062, 4.372826952919572, 4.428713693556512, 4.483562102832575, 4.537422084538199, 4.590339758263628, 4.642357845498505, 4.693516006778262, 4.743851137231293, 4.79339762661272, 4.842187588887944, 4.890251065599423, 4.937616206573217, 4.984309430966639, 5.03035557120059, 5.075778001941093, 5.12059875597894, 5.164838628592776, 5.20851727175958, 5.251653279390081, 5.294264264608923, 5.3363669299655525, 5.377977131347741, 5.419109936272264, 5.459779677143631, 5.500000000000001, 5.539783909203366, 5.579143808477541, 5.618091538650959, 5.656638412420897, 5.694795246420439, 5.732572390838766, 5.769979756818306, 5.807026841828617, 5.8437227531960625, 5.880076229949887, 5.916095663129137, 5.951789114680413, 5.98716433506379, 6.022228779672772, 6.056989624164193, 6.091453778784881, 6.125627901773887, 6.15951841191192, 6.193131500283122, 6.226473141308572, 6.259549103105682, 6.292364957222977, 6.3249260877955, 6.357237700162297, 6.389304828983969, 6.421132345895159, 6.4527249667240145, 6.484087258308085, 6.515223644933809, 6.546138414424573, 6.576835723900422, 6.60731960523076, 6.6375939701996804, 6.667662615402211, 6.6975292268883075, 6.727197384570266, 6.756670566408053, 6.7859521523860264, 6.815045428293595, 6.843953589321416, 6.872679743484019, 6.901226914878917, 6.929598046791623, 6.957796004655375, 6.985823578873713, 7.013683487513633], [0.0, 1.119213180983213, 1.4768106461486445, 1.7368460211765295, 1.948663330306766, 2.1305945802414206, 2.2917820647368567, 2.4375415772291475, 2.571276679772831, 2.6953168105353003, 2.8113364032784087, 2.9205852683618208, 3.0240245641877195, 3.122411638915664, 3.2163553939916985, 3.3063537691557023, 3.3928199197461124, 3.476100985059239, 3.556491853540495, 3.6342454600589327, 3.709580623969676, 3.782688107857718, 3.853735365690199, 3.922870310083372, 3.99022433481725, 4.055914764483284, 4.120046858238577, 4.18271546272887, 4.244006386229115, 4.303997549226272, 4.3627599542147255, 4.420358508148202, 4.476852723932852, 4.532297321949694, 4.586742748431116, 4.640235624275982, 4.692819135346037, 4.7445333732769965, 4.795415634238238, 4.845500681793078, 4.894820978977837, 4.943406893879161, 4.99128688230481, 5.038487650581845, 5.08503430105349, 5.130950462462644, 5.176258407091126, 5.220979156257154, 5.265132575549871, 5.308737460991249, 5.351811617156274, 5.3943719281470015, 5.436434422200811, 5.478014330614686, 5.519126141582851, 5.559783649472552, 5.600000000000001, 5.639787731714445, 5.679158814151216, 5.718124682973831, 5.75669627238952, 5.7948840450914805, 5.832698019953822, 5.870147797681267, 5.907242584594579, 5.943991214714106, 5.980402170287426, 6.0164836008925215, 6.052243341235065, 6.087688927746856, 6.122827614082358, 6.157666385601084, 6.19221197291551, 6.226470864576914, 6.260449318965002, 6.2941533754413435, 6.3275888648213705, 6.360761419214974, 6.393676481281419, 6.426339312940513, 6.4587550035783785, 6.490928477783132, 6.522864502642816, 6.55456769463538, 6.586042526138173, 6.6172933315821645, 6.648324313274279, 6.679139546909347, 6.709742986791595, 6.7401384707841085, 6.770329725003299, 6.800320368274231, 6.830113916361442, 6.859713785988889, 6.889123298661707, 6.918345684301488, 6.947384084706118, 6.976241556844308, 7.004921075994362, 7.033425538736072, 7.06175776580398, 7.089920504809803], [0.0, 1.1311622768584233, 1.4925775726825683, 1.755389172722765, 1.9694679145968534, 2.1533415236683586, 2.316249899892775, 2.463565589902529, 2.598728493323943, 2.7240929181887674, 2.8413511750761566, 2.9517664177409983, 3.0563100662354405, 3.155747554422395, 3.250694284584279, 3.341653512632899, 3.4290428048918673, 3.513213006833229, 3.5944621552304974, 3.673045885370349, 3.7491853527968475, 3.823073356740422, 3.8948791389630153, 3.9647521912456574, 4.032825310172493, 4.099217072931722, 4.164033862462565, 4.227371538025415, 4.2893168240131905, 4.349948472818144, 4.40933824498114, 4.467551740424348, 4.524649107433693, 4.580685650603365, 4.635712354746672, 4.689776338502856, 4.742921248800429, 4.795187605306875, 4.846613102378005, 4.897232874724615, 4.947079731969304, 4.996184366418617, 5.04457553768407, 5.092280237218447, 5.139323835366017, 5.185730213138079, 5.231521880602812, 5.276720083509089, 5.321344899537755, 5.365415325383428, 5.408949355708716, 5.451964054876019, 5.494475622245565, 5.536499451728777, 5.578050186200713, 5.619141767301912, 5.6597874810966715, 5.7, 5.739791421338011, 5.779173302865206, 5.818156695526084, 5.85675217371707, 5.894969863277139, 5.9328194674113615, 5.970310290730274, 6.0074512615691935, 6.044250952735023, 6.080717600813377, 6.116859124155876, 6.152683139655798, 6.188196978410058, 6.223407700356214, 6.258322107965021, 6.29294675906171, 6.327287978842552, 6.361351871147369, 6.395144329043337, 6.428671044770643, 6.461937519096212, 6.494949070117873, 6.527710841557748, 6.560227810580507, 6.5925047951692255, 6.624546461088927, 6.656357328465557, 6.687941778005931, 6.719304056882211, 6.750448284302716, 6.781378456789152, 6.81209845317892, 6.842612039369703, 6.872922872822356, 6.9030345068368995, 6.932950394615386, 6.9626738931244505, 6.992208266769417, 7.02155669089106, 7.050722255095314, 7.0797079664255556, 7.108516752386432, 7.1371514638276, 7.165614877695198], [0.0, 1.1430278078379148, 1.508234234675528, 1.7738026444554442, 1.9901270039528611, 2.1759293884524227, 2.3405466215088384, 2.4894076060526626, 2.625988325158559, 2.752667782797541, 2.8711560413461976, 2.9827295046388405, 3.0883697826136833, 3.188850338290372, 3.2847930293247014, 3.3767063906222474, 3.465012368643982, 3.550065489118889, 3.632166915131039, 3.711574963499614, 3.7885131096196947, 3.8631761751240563, 3.935735177066666, 4.006341175349589, 4.075128359550719, 4.142216550695087, 4.207713247644966, 4.271715315193772, 4.334310387445603, 4.395578042880155, 4.4555907947834426, 4.514414931199866, 4.572111231351659, 4.628735579960538, 4.684339496654219, 4.738970594331418, 4.792672977762986, 4.845487591654778, 4.897452525764357, 4.948603283354412, 4.9989730182100045, 5.048592744590169, 5.097491523785564, 5.14569663038069, 5.193233700846624, 5.240126866698844, 5.286398874128957, 5.332071191746954, 5.377164107842141, 5.4216968183783925, 5.465687506776579, 5.5091534163988145, 5.552110916531439, 5.594575562563091, 5.63656215096791, 5.67808476962979, 5.719156843979602, 5.7597911793619385, 5.800000000000001, 5.839794984885441, 5.87918730088364, 5.918187633313059, 5.956806214229495, 5.995052848621536, 6.032936938702114, 6.070467506461928, 6.107653214633891, 6.144502386202768, 6.181023022581159, 6.217222820561119, 6.253109188140431, 6.288689259313138, 6.323969907905744, 6.358957760532972, 6.393659208740379, 6.428080420395119, 6.46222735038076, 6.496105750647271, 6.529721179662865, 6.563079011310518, 6.596184443268353, 6.6290425049099095, 6.661658064757367, 6.694035837518131, 6.726180390732827, 6.758096151060484, 6.789787410224745, 6.821258330643108, 6.852512950759515, 6.883555190099131, 6.914388854062706, 6.9450176384766875, 6.975445133914081, 7.005674829799924, 7.035710118314361, 7.065554298105283, 7.095210577821777, 7.124682079478756, 7.1539718416625195, 7.183082822586306, 7.212017903004273, 7.240779888991838], [0.0, 1.154811784266086, 1.5237832847928614, 1.792089556118625, 2.010644098587687, 2.198362001593646, 2.3646763461120104, 2.515072004021531, 2.653060793835288, 2.7810462457226297, 2.90075605184535, 3.0134797750463123, 3.12020914511234, 3.221725599033555, 3.3186574054698466, 3.4115183420368105, 3.500734705227077, 3.5866646757313063, 3.6696125214562683, 3.749839222322854, 3.827570557632287, 3.9030033575192467, 3.9763104021277305, 4.047644308702777, 4.117140650241662, 4.184920483057067, 4.251092414264318, 4.315754307278591, 4.3789946996625115, 4.440893990305322, 4.501525440064401, 4.560956020376752, 4.619247137064344, 4.676455250989074, 4.732632412917156, 4.787826726609625, 4.842082751532813, 4.895441854509557, 4.947942517981484, 4.999620611230034, 5.050509629837221, 5.100640907801719, 5.150043806019813, 5.198745880261692, 5.246773031296089, 5.294149639420891, 5.340898685328197, 5.3870418589573426, 5.432599657758532, 5.477591475595273, 5.522035683349322, 5.565949702152196, 5.609350070048409, 5.652252502793941, 5.694671949406294, 5.736622643007552, 5.778118147437258, 5.819171400055936, 5.859794751111678, 5.9, 5.93979842871041, 5.979200832721019, 6.0182175495743815, 6.056858485343032, 6.095133139171447, 6.133050626062, 6.170619698055524, 6.207848763942096, 6.244745907624398, 6.281318905244101, 6.317575241171292, 6.353522122947501, 6.38916649526453, 6.4245150530537884, 6.459574253754089, 6.494350328819839, 6.528849294526121, 6.563076962122286, 6.597038947381242, 6.630740679587688, 6.664187410004896, 6.69738421985643, 6.730336027856205, 6.7630475973176205, 6.795523542870088, 6.82776833680901, 6.859786315103295, 6.891581683082635, 6.923158520825068, 6.954520788263868, 6.985672330031332, 7.016616880055812, 7.047358065927107, 7.077899413044274, 7.108244348558933, 7.138396205126188, 7.1683582244745, 7.198133560805007, 7.227725284030133, 7.257136382860637, 7.286369767749635, 7.315428273701615], [0.0, 1.166516134976123, 1.5392272681452155, 1.8102529009635488, 2.0310225567949627, 2.2206430349229196, 2.3886430233209834, 2.5405629846273197, 2.6799503306491435, 2.809232952027723, 2.930156051583521, 3.0440222622509787, 3.1518333652845203, 3.2543787177636836, 3.352292956032543, 3.4460950649911046, 3.5362156617699783, 3.623016557324495, 3.706805103404471, 3.7878449250376143, 3.866364089863525, 3.9425614229471027, 4.016611455608968, 4.0886683519139835, 4.158869058930878, 4.227335859912999, 4.2941784627401285, 4.359495722701402, 4.4233770747131915, 4.485903732530686, 4.547149699531194, 4.607182625926564, 4.666064539904492, 4.723852474574001, 4.7805990082508485, 4.836352732241565, 4.891158657635536, 4.945058570520286, 4.998091343368093, 5.0502932090059165, 5.101698002503163, 5.1523373754376225, 5.20224098628674, 5.251436670106387, 5.299950590177064, 5.34780737389801, 5.3950302348772725, 5.441641082887982, 5.4876606231279155, 5.533108446022986, 5.5780031086491375, 5.622362208706082, 5.666202451856186, 5.709539713139156, 5.752389093085096, 5.794764969072895, 5.83668104241552, 5.878150381597379, 5.919185462039893, 5.959798202728859, 5.999999999999999, 6.039801758746715, 6.079213921285537, 6.118246494089904, 6.156909072580863, 6.1952108641439665, 6.233160709524508, 6.270767102738079, 6.308038209620047, 6.344981885125524, 6.381605689480847, 6.41791690327806, 6.4539225415954204, 6.4896293672194005, 6.525043903036817, 6.560172443659668, 6.5950210663397195, 6.629595641225013, 6.663901841005933, 6.697945149994547, 6.731730872677197, 6.765264141777113, 6.7985499258607955, 6.8315930365192, 6.864398135152338, 6.896969739383617, 6.929312229128243, 6.961429852338137, 6.993326730444105, 7.025006863514488, 7.056474135148042, 7.087732317117558, 7.118785073779508, 7.149635966263881, 7.180288456457473, 7.210745910792806, 7.241011603854195, 7.271088721811518, 7.300980365691646, 7.330689554496784, 7.360219228178332, 7.389572250474365], [0.0, 1.1781427118943884, 1.554568628364076, 1.8282955528939455, 2.051265602965766, 2.2427760138671586, 2.4124504452744637, 2.565884581192353, 2.706661190209659, 2.8372323615676045, 2.9593606923894145, 3.074361798852157, 3.1832474468872456, 3.286814861035735, 3.3857050030135047, 3.4804420304032835, 3.571460852263623, 3.6591268856919155, 3.7437505457893145, 3.825598085113975, 3.904899844438182, 3.98185663050102, 4.056644714163406, 4.129419796031623, 4.20032018811534, 4.269469392455715, 4.336978210382564, 4.402946482468111, 4.467464535019685, 4.530614391243751, 4.592470792103607, 4.653102062075578, 4.712570847577553, 4.770934750163184, 4.828246872192267, 4.884556289277166, 4.939908461129342, 4.994345590315051, 5.047906936745526, 5.100629094377535, 5.152546235512025, 5.203690327195641, 5.254091323509597, 5.303777336939633, 5.352774791533662, 5.401108560150324, 5.448802087765919, 5.495877502526606, 5.542355715997282, 5.5882565138601334, 5.633598638148059, 5.678399861955693, 5.722677057449463, 5.7664462578943745, 5.809722714326361, 5.852520947422542, 5.894854795055825, 5.936737455963197, 5.97818152990765, 6.019199054670598, 6.05980154017417, 6.1000000000000005, 6.139804980542393, 6.179226588008536, 6.218274513456306, 6.25695805604056, 6.295286144621623, 6.333267357874288, 6.370909943022179, 6.408221833310143, 6.445210664316714, 6.481883789199038, 6.518248292954121, 6.5543110057726075, 6.59007851555443, 6.625557179649501, 6.660753135881088, 6.6956723129045495, 6.73032043994954, 6.764703055989845, 6.798825518381214, 6.832693011004339, 6.8663105519470395, 6.8996830007570304, 6.93281506529414, 6.965711308208581, 6.99837615306984, 7.030813890168847, 7.063028682014397, 7.095024568543201, 7.126805472061549, 7.158375201935203, 7.189737459042992, 7.220895840008419, 7.251853841222634, 7.28261486267114, 7.313182211575782, 7.343559105862746, 7.373748677466602, 7.403753975479718, 7.433577969155767, 7.463223550775478], [0.0, 1.189693294313711, 1.5698097132404067, 1.846220273097516, 2.0713763350288454, 2.2647643255841645, 2.4361022553814653, 2.5910406688499137, 2.733197460258326, 2.865048759279186, 2.988374443644544, 3.1045030279120556, 3.2144561974275327, 3.3190389927696593, 3.4188986596817523, 3.5145644946191905, 3.6064756705152448, 3.695001187038638, 3.780454502618952, 3.8631044801705294, 3.9431837187405225, 4.020894993789432, 4.09641630434836, 4.169904877521753, 4.241500381338587, 4.311327528661506, 4.379498207123265, 4.446113236139098, 4.511263827580918, 4.5750328088156635, 4.637495653571562, 4.698721356182235, 4.758773177254844, 4.817709283072156, 4.875583296612717, 4.932444774629163, 4.988339622522715, 5.043310456616143, 5.097396921727223, 5.1506359705820906, 5.2030621105089985, 5.25470762196145, 5.305602752692283, 5.355775890803749, 5.405253719406726, 5.454061355214864, 5.502222473060429, 5.549759418035264, 5.596693306722512, 5.6430441187843865, 5.688830780001809, 5.73407123771791, 5.778782529514856, 5.822980845848753, 5.866681587277614, 5.9098994168401555, 5.952648308076627, 5.994941589125233, 6.036791983277802, 6.0782116463348865, 6.119212201062589, 6.159804769020363, 6.200000000000001, 6.239808099290559, 6.279238852961628, 6.318301651337545, 6.357005510817719, 6.395359094182792, 6.433370729512667, 6.471048427830202, 6.5083998995736065, 6.5454325699908225, 6.582153593540596, 6.618569867377174, 6.654688043988658, 6.690514543052804, 6.72605556256847, 6.761317089315909, 6.796304908694492, 6.8310246139824375, 6.865481615059336, 6.899681146628955, 6.933628275976757, 6.9673279102937515, 7.000784803595911, 7.034003563265949, 7.066988656242292, 7.099744414878144, 7.132275042491785, 7.164584618627714, 7.1966771040467465, 7.228556345461897, 7.260226080035634, 7.291689939652977, 7.322951454983905, 7.354014059347585, 7.384881092390064, 7.415555803586272, 7.446041355576454, 7.4763408273464655, 7.506457217260721, 7.536393445956046], [0.0, 1.2011695928643287, 1.5849527799643384, 1.8640297162082233, 2.0913577313644347, 2.2866112265219276, 2.4596019564525036, 2.6160349731925865, 2.759563070791425, 2.892686264744435, 3.017201602257794, 3.1344504133179454, 3.245464238891566, 3.351055885328627, 3.4518788419861743, 3.548467511143225, 3.641265302186026, 3.7306447743144693, 3.8169224097143766, 3.900369664868608, 3.9812213825758107, 4.059682294356702, 4.135932116298397, 4.210129592186319, 4.282415737347952, 4.352916467680413, 4.421744750133189, 4.489002376669406, 4.554781439030335, 4.619165563571693, 4.6822309520740895, 4.744047264420473, 4.804678371457315, 4.864183000564624, 4.922615291991502, 4.980025280536555, 5.036459314424459, 5.091960421073551, 5.1465686277327505, 5.200321243590248, 5.253253108846981, 5.305396815347737, 5.356782902628322, 5.407440032634961, 5.457395145875413, 5.506673601350067, 5.555299302268907, 5.603294809274244, 5.65068144264896, 5.697479374787772, 5.743707714037909, 5.789384580870375, 5.8345271772192575, 5.879151849720838, 5.923274147493605, 5.9669088750223205, 6.010070140642074, 6.052771401060085, 6.095025502302583, 6.136844717430257, 6.178240781327461, 6.219224922837046, 6.259807894483323, 6.300000000000002, 6.339811119857354, 6.379250734962866, 6.418327948692055, 6.457051507390508, 6.495429819474406, 6.533470973244417, 6.571182753516987, 6.608572657167227, 6.645647907668901, 6.6824154687092046, 6.718882056949028, 6.7550541539931315, 6.790938017628963, 6.826539692387859, 6.861865019477667, 6.896919646131798, 6.931709034415893, 6.966238469529948, 7.000513067640659, 7.034537783275937, 7.068317416311058, 7.1018566185735486, 7.135159900091868, 7.16823163501098, 7.201076067196201, 7.233697315545088, 7.266099379025676, 7.298286141458047, 7.330261376054962, 7.36202874973618, 7.393591827230061, 7.424954074975057, 7.456118864832893, 7.487089477624348, 7.5178691064978675, 7.548460860140545, 7.578867765840317, 7.609092772407745], [0.0, 1.2125732532083184, 1.5999999999999999, 1.8817264360394779, 2.1112126572366305, 2.3083198494515416, 2.482952918264576, 2.6408710783183813, 2.785761802547597, 2.9201488410873875, 3.0458463019454056, 3.1642082494227703, 3.276276017726751, 3.38287012982585, 3.4846502791724476, 3.5821559415523443, 3.6758347359905117, 3.766062758688278, 3.8531594964491074, 3.9373989829086184, 4.019018290415328, 4.098224094169463, 4.175197816446197, 4.250099708112235, 4.3230721232659635, 4.394242173224471, 4.463723897422537, 4.53162005421553, 4.598023609645019, 4.663018983998375, 4.726683102500444, 4.789086286370969, 4.850293012833274, 4.910362566813195, 4.969349602556372, 5.027304629881636, 5.084274437034299, 5.1403024599262785, 5.19542910581707, 5.249692038100725, 5.303126427743979, 5.355765176011978, 5.407639112376685, 5.458777170895026, 5.509206547842472, 5.558952842972614, 5.6080401864276626, 5.656491353036088, 5.704327865491211, 5.75157008770037, 5.798237309421565, 5.844347823157873, 5.889918994155053, 5.934967324241036, 5.979508510154484, 6.023557496930932, 6.067128526847142, 6.110235184365578, 6.15289043747004, 6.195106675739159, 6.236895745465903, 6.278268982097478, 6.319237240240477, 6.359810921450167, 6.400000000000001, 6.439814046807275, 6.479262251673106, 6.518353443979112, 6.557096111969271, 6.595498420732934, 6.633568228994017, 6.67131310480144, 6.708740340207162, 6.74585696501021, 6.782669759638092, 6.819185267230607, 6.855409804985367, 6.891349474819263, 6.927010173395384, 6.962397601560829, 6.99751727323698, 7.032374523800452, 7.066974517989788, 7.101322257370181, 7.135422587385949, 7.1692802040281265, 7.2028996601424655, 7.236285371401176, 7.269441621959969, 7.30237256982038, 7.335082251915835, 7.367574588938615, 7.3998533899235985, 7.431922356603534, 7.463785087549591, 7.495445082109885, 7.5269057441579115, 7.558170385661895, 7.589242230085387, 7.620124415628721, 7.650819998320296, 7.681331954966079], [0.0, 1.223905859480782, 1.61495346362619, 1.8993128909243258, 2.130943870784843, 2.329893210018033, 2.5061583846075832, 2.6655524343253134, 2.811797294913613, 2.947440303261301, 3.074312521874847, 3.1937806700249167, 3.3068958141395233, 3.414486145724897, 3.5172175236721963, 3.615634465661934, 3.7101887741283366, 3.801260060235774, 3.889170796684145, 3.9741975782040693, 4.056579692802027, 4.13652574724705, 4.214218859371432, 4.289820777732821, 4.363475186858872, 4.435310386038211, 4.505441480508452, 4.573972188995795, 4.640996346394513, 4.706599161976784, 4.770858279904049, 4.833844678612178, 4.895623437923128, 4.9562543968345985, 5.015792720386152, 5.074289390457081, 5.131791632571649, 5.188343288590105, 5.243985143414747, 5.298755212438499, 5.352688995332952, 5.405819700855672, 5.45817844660824, 5.50979443706281, 5.560695122668928, 5.610906342433299, 5.660452452016386, 5.709356439098266, 5.757640027521514, 5.805323771512813, 5.852427141110598, 5.89896859977812, 5.944965675055243, 5.990435022994577, 6.035392487035164, 6.079853151887571, 6.12383139293566, 6.167340921601126, 6.21039482706544, 6.2530056146991795, 6.295185241509755, 6.336945148884498, 6.378296292876227, 6.419249172252261, 6.459813854504761, 6.5, 6.539816884426194, 6.579273419683607, 6.618378173346624, 6.657139386814824, 6.6955649922590865, 6.7336626284586725, 6.771439655616438, 6.808903169231311, 6.846060013100097, 6.882916791514222, 6.919479880711289, 6.955755439636184, 6.991749420061707, 7.027467576114586, 7.062915473248846, 7.098098496705074, 7.13302185949102, 7.167690609916081, 7.202109638709681, 7.2362836857511885, 7.270217346436864, 7.303915077707413, 7.3373812037579, 7.37061992145019, 7.403635305446545, 7.436431313081699, 7.469011788989449, 7.5013804694986215, 7.533540986812325, 7.5654968729832826, 7.597251563697303, 7.628808401875983, 7.660170641109091, 7.6913414489263126, 7.722323909917427, 7.753121028709376], [0.0, 1.2351689374987616, 1.6298151841705664, 1.9167914486951907, 2.150554028610844, 2.3513342128490238, 2.5292214798551407, 2.690082364300122, 2.8376730532965255, 2.9745643257764414, 3.1026040947252436, 3.2231716567418736, 3.337327750765584, 3.445908189792016, 3.5495849603246614, 3.648907591005514, 3.7443320420118384, 3.8362414179059043, 3.924961158964855, 4.010770405301382, 4.093910646986333, 4.174592410506911, 4.253000498849878, 4.329298149075133, 4.403630367977098, 4.476126635527445, 4.54690311622767, 4.616064483282697, 4.683705435108881, 4.7499119651226, 4.814762432011041, 4.878328467394022, 4.940675749995046, 5.001864669484314, 5.061950898561465, 5.12098588827005, 5.179017298730474, 5.236089375260727, 5.29224327808898, 5.34751737244743, 5.401947484695844, 5.455567129197667, 5.508407709916354, 5.560498700080225, 5.61186780275348, 5.662541094728065, 5.712543155799087, 5.76189718519233, 5.810625106665532, 5.858747663597062, 5.906284505199723, 5.953254264848061, 5.999674631380334, 6.045562414127623, 6.0909336023293115, 6.135803419514052, 6.18018637335617, 6.224096301457662, 6.2675464134540935, 6.310549329797577, 6.353117117530708, 6.395261323330971, 6.436993004075021, 6.478322755145802, 6.519260736682266, 6.5598166979508745, 6.600000000000001, 6.639819636742288, 6.679284254595814, 6.718402170802205, 6.757181390528689, 6.795629622850919, 6.833754295704527, 6.871562569885258, 6.909061352170431, 6.946257307627915, 6.983156871173083, 7.019766258428933, 7.056091475939866, 7.092138330785357, 7.127912439635905, 7.163419237290145, 7.198663984728891, 7.233651776718952, 7.2683875489970315, 7.302876085061561, 7.337122022598251, 7.371129859563115, 7.404903959944917, 7.438448559227434, 7.471767769570287, 7.504865584725858, 7.537745884708449, 7.570412440230712, 7.602868916921353, 7.635118879337056, 7.667165794780763, 7.699013036937539, 7.730663889338534, 7.762121548662846, 7.793389127886403, 7.824469659286435], [0.0, 1.2463639577568397, 1.6445871019623635, 1.9341643913325823, 2.170045690994407, 2.3726456572573187, 2.5521452150985824, 2.7144640708424053, 2.863392456005752, 3.001524449914163, 3.1307247142119854, 3.2523850468272486, 3.367575800763769, 3.4771403644533367, 3.581756814985348, 3.6819796616842697, 3.778268997347016, 3.8710113988247117, 3.9605352560399982, 4.0471222391070265, 4.131016026854923, 4.212429053889056, 4.291547798168025, 4.368536976259617, 4.443542909235157, 4.51669625061502, 4.588114217763923, 4.657902432598029, 4.726156451837893, 4.792963048305857, 4.8584012908973, 4.922543460469082, 4.985455831027359, 5.047199339587365, 5.107830163441254, 5.167400219961882, 5.225957601239728, 5.283546953612604, 5.3402098103666304, 5.395984884459352, 5.450908326964682, 5.505013956005304, 5.558333460176188, 5.61089657983785, 5.6627312691427045, 5.713863841231108, 5.764319098678464, 5.814120450977994, 5.863290020594591, 5.911848738915356, 5.959816433244789, 6.007211905842034, 6.054053005869086, 6.100356695009306, 6.146139107421408, 6.1914156046133195, 6.236200825750453, 6.280508733852659, 6.324352658281745, 6.367745333875972, 6.4106989370482275, 6.453225119129931, 6.495335037212331, 6.5370393827102, 6.578348407849455, 6.61927195025956, 6.659819455833257, 6.699999999999999, 6.739822307545141, 6.779294771094076, 6.818425468369298, 6.857222178318086, 6.895692396199561, 6.933843347711729, 6.971682002231857, 7.0092150852370185, 7.046449089965785, 7.083390288376792, 7.120044741455078, 7.156418308912896, 7.192516658327741, 7.2283452737568386, 7.263909463864185, 7.299214369593285, 7.334264971416155, 7.3690660961867245, 7.403622423624619, 7.437938492453316, 7.472018706214831, 7.5058673387814725, 7.539488539583644, 7.572886338571317, 7.606064650925513, 7.639027281534942, 7.67177792925193, 7.704320190940717, 7.736657565330329, 7.76879345668341, 7.800731178291569, 7.83247395580718, 7.864024930420794, 7.89538716189285], [0.0, 1.2574923382265666, 1.6592710880262584, 1.9514339193093737, 2.189421326767395, 2.3938302425700426, 2.5749324938792726, 2.7387006421615117, 2.888958760684464, 3.0283240904685544, 3.158677942118568, 3.2814245404758644, 3.397643795379877, 3.5081866256047927, 3.6137371625709203, 3.7148548666370527, 3.812003938619807, 3.905574406989919, 3.9958975937573875, 4.083257683977666, 4.167900532209297, 4.250040469817495, 4.329865639762212, 4.4075422293121695, 4.483217865992189, 4.557024369885649, 4.62908000495319, 4.699491336174884, 4.7683547734663225, 4.835757864416301, 4.9017803839007765, 4.966495258148995, 5.029969352906266, 5.092264149274714, 5.1534363261353535, 5.213538264414468, 5.272618485601246, 5.330722034666206, 5.387890815732737, 5.444163887413859, 5.499577723564723, 5.554166444259088, 5.607962021029134, 5.660994459777432, 5.713291964249978, 5.764881082528644, 5.815786838643006, 5.86603285110207, 5.915641439895066, 5.964633723298672, 6.013029705648978, 6.060848357084412, 6.108107686136363, 6.154824805933572, 6.2010159946914385, 6.246696751075821, 6.291881844960505, 6.336585364036624, 6.3808207566795465, 6.424600871432783, 6.467937993428469, 6.510843878028995, 6.553329781943666, 6.595406492047437, 6.637084352105035, 6.6783732875829305, 6.719282828713188, 6.759822131956831, 6.800000000000001, 6.839824900403128, 6.8793049830120765, 6.918448096229826, 6.957261802238243, 6.995753391251253, 7.033929894873436, 7.071798098631476, 7.109364553739969, 7.14663558815784, 7.1836173169867, 7.22031565225828, 7.256736312154038, 7.292884829696573, 7.328766560949224, 7.364386692757316, 7.39975025006189, 7.434862102814291, 7.469726972517847, 7.50434943842083, 7.538733943383054, 7.572884799436854, 7.606806193061553, 7.640502190189243, 7.673976740958328, 7.707233684230138, 7.740276751882858, 7.773109572895961, 7.805735677237495, 7.838158499565662, 7.8703813827553795, 7.902407581259828, 7.934240264316234, 7.965882519004645], [0.0, 1.2685554469752462, 1.673868947537882, 1.9686021556547568, 2.208683317873334, 2.414890573113909, 2.597586117551024, 2.7627950577800133, 2.9143751103259876, 3.05496654205307, 3.1864672148746918, 3.310293707657486, 3.4275354310224255, 3.5390507899180843, 3.645529934584983, 3.7475372473767465, 3.845541013034767, 3.9399346914044755, 4.03105251938554, 4.119181182223736, 4.204568697445628, 4.287431282051144, 4.3679587342357875, 4.446318703343055, 4.522660115688472, 4.597115951076139, 4.669805513923973, 4.740836306744568, 4.810305587644277, 4.878301674434078, 4.944905043829694, 5.010189263647424, 5.074221787900985, 5.137064638588136, 5.198774993236768, 5.259405693607685, 5.3190056880702254, 5.377620417889492, 5.435292155851061, 5.492060304196038, 5.54796165766759, 5.603030636519507, 5.6572994935616565, 5.710798498681172, 5.76355610375368, 5.815599090424555, 5.866952702878638, 5.91764076741478, 5.967685800387993, 6.017109105868364, 6.065930864185223, 6.114170212371614, 6.1618453173935634, 6.208973442936915, 6.2555710104288105, 6.301653654888563, 6.34723627613168, 6.392333085789343, 6.436957650552422, 6.4811229320027595, 6.5248413233540665, 6.568124683389523, 6.610984367852199, 6.653431258517325, 6.69547579015153, 6.737127975543102, 6.778397428768744, 6.819293386845779, 6.859824729904214, 6.9, 6.939827418679343, 6.979314903393542, 7.018470082854685, 7.057300311414208, 7.095812682539021, 7.134014041453205, 7.171910997007335, 7.209509932832161, 7.24681701782846, 7.283838216040563, 7.320579295957085, 7.357045839278799, 7.393243249190374, 7.429176758169727, 7.464851435366095, 7.500272193575459, 7.535443795839774, 7.570370861694412, 7.6050578730863805, 7.639509179984213, 7.673729005698849, 7.707721451933453, 7.741490503578777, 7.7750400332695095, 7.808373805715984, 7.841495481824543, 7.874408622619027, 7.907116692974917, 7.939623065176923, 7.971931022310105, 8.00404376149386, 8.035964396967609], [0.0, 1.2795546046181905, 1.6883824230595852, 1.9856711497597572, 2.22783396363703, 2.435829162883457, 2.6201087903015083, 2.7867501938744805, 2.939644538907594, 3.0814549850061024, 3.2140958497160383, 3.338995994515966, 3.457254275888438, 3.569736541682039, 3.6771389261652736, 3.7800307052346485, 3.878884223948907, 3.974096353692863, 4.066004229406122, 4.15489702207225, 4.24102489968264, 4.324605953971883, 4.405831628802825, 4.484871027142107, 4.561874366588208, 4.6369757799620945, 4.710295606124524, 4.781942279701141, 4.852013902086025, 4.920599556860014, 4.987780418521561, 5.05363069276528, 5.118218418472762, 5.181606155410717, 5.243851576871447, 5.3050079827863925, 5.3651247459374245, 5.424247701593424, 5.4824194890710745, 5.5396798522531965, 5.596065904916064, 5.6516123657582815, 5.7063517672414585, 5.760314641711307, 5.813529687738754, 5.866023919182545, 5.917822799110167, 5.968950360409164, 6.019429314665227, 6.069281150667864, 6.118526223722295, 6.167183836791439, 6.215272314360115, 6.262809069800965, 6.309810666925024, 6.356292876316862, 6.402270726982569, 6.4477585537769295, 6.4927700410223865, 6.537318262685684, 6.581415719437337, 6.625074372883485, 6.668305677228489, 6.71112060859928, 6.7535296922383425, 6.7955430277510125, 6.8371703125739645, 6.878420863815154, 6.91930363860079, 6.959827253051713, 7.0, 7.039829865546138, 7.0793245445478465, 7.1184914551233245, 7.157337752244211, 7.195870340486899, 7.234095886004771, 7.272020827778593, 7.30965138819731, 7.346993583017198, 7.384053230743222, 7.420835961472941, 7.457347225239965, 7.493592299891019, 7.52957629852799, 7.56530417654383, 7.600780738279, 7.636010643323093, 7.6709984124843595, 7.70574843344824, 7.740264966144386, 7.774552147840254, 7.808613997978057, 7.842454422770612, 7.876077219570612, 7.909486081026714, 7.942684599039029, 7.975676268525644, 8.00846449101106, 8.041052578046704, 8.07344375447297, 8.105641161531656], [0.0, 1.290491086617243, 1.7028131975733602, 2.0026428809441916, 2.246875484766536, 2.456648439916648, 2.64250312385888, 2.8105688282814567, 2.964769976671126, 3.107792490926348, 3.2415670504579066, 3.3675347293672453, 3.4868037761738773, 3.6002474392151025, 3.7085678026890863, 3.812339008150724, 3.91203743783952, 4.00806335523996, 4.1007567768179145, 4.19040934513045, 4.277273366379966, 4.361568796353057, 4.4434887152025375, 4.523203671235125, 4.6008651659742315, 4.6766084786875455, 4.750554976784183, 4.8228140216914435, 4.8934845532859, 4.962656416554721, 5.030411479802971, 5.096824582968799, 5.161964346468972, 5.225893864774818, 5.288671304118076, 5.350350419990066, 5.410981007166794, 5.470609292675797, 5.5292782802762925, 5.5870280535460655, 5.643896043476572, 5.69991726551063, 5.75512453016807, 5.809548630757638, 5.8632185111398325, 5.916161416063574, 5.968403026231745, 6.019967579943403, 6.070877982902443, 6.121155907565225, 6.170821883215807, 6.219895377801478, 6.2683948724282725, 6.31633792930268, 6.363741253808297, 6.410620751322467, 6.456991579305708, 6.50286819513425, 6.548264400091819, 6.593193379889668, 6.6376677420428, 6.681699550394407, 6.725300357049089, 6.768481231947836, 6.811252790293442, 6.853625218013585, 6.895608295429907, 6.937211419284623, 6.978443623261401, 7.019313597123935, 7.059829704583971, 7.1000000000000005, 7.139832243998469, 7.1793339181009745, 7.218512238433422, 7.257374168586312, 7.2959264316893115, 7.334175521757804, 7.372127714364119, 7.409789076681806, 7.447165476947177, 7.484262593378802, 7.521085922592279, 7.557640787544619, 7.593932345039905, 7.629965592825329, 7.665745376304539, 7.701276394893105, 7.7365632080390805, 7.771610240929898, 7.806421789905254, 7.841002027594248, 7.87535500779367, 7.909484670103129, 7.943394844331676, 7.977089254689408, 8.010571523776767, 8.043845176383256, 8.076913643106549, 8.109780263802236, 8.142448290873746, 8.174920892411386], [0.0, 1.3013661254372384, 1.7171628973263067, 2.0195192618031594, 2.2658100271077646, 2.4773507504000207, 2.6647716419075045, 2.834253645194025, 2.9897542550772416, 3.133982027866047, 3.2688839129119933, 3.395913128326628, 3.516187261900226, 3.630586920881485, 3.7398201059704275, 3.844465797044167, 3.945004390841342, 4.041839523888666, 4.135314077989326, 4.225722153388135, 4.313318182485628, 4.3983239746478215, 4.480934237124512, 4.5613209554423095, 4.639636907836231, 4.716018513579737, 4.790588162851724, 4.863456138674208, 4.934722214695503, 5.004476993031388, 5.0728030318955994, 5.139775801906535, 5.205464501748954, 5.2699327575947414, 5.333239225845644, 5.395438114993441, 5.456579639437433, 5.5167104157628435, 5.575873810123913, 5.634110243884927, 5.691457463470348, 5.747950779400041, 5.803623278689879, 5.858506014145501, 5.912628173538899, 5.966017231211977, 6.018699084280303, 6.070698175300406, 6.122037603003797, 6.1727392224818045, 6.2228237360198895, 6.272310775622792, 6.321218978137836, 6.3695660537691845, 6.417368848677613, 6.464643402275947, 6.5114049997574535, 6.55766822033146, 6.603446981585862, 6.6487545803486245, 6.693603730378966, 6.738006597182742, 6.781974830214769, 6.825519592703036, 6.868651589305228, 6.911381091786392, 6.953717962887475, 6.99567167853755, 7.037251348547634, 7.0784657359105285, 7.119323274819439, 7.159832087507374, 7.200000000000001, 7.239834556866111, 7.279343035042294, 7.318532456801608, 7.357409601929903, 7.39598101916798, 7.434253036972763, 7.4722317736462, 7.509923146876556, 7.547332882733056, 7.584466524151577, 7.62132943894598, 7.657926827377017, 7.694263729308171, 7.730345030975566, 7.766175471397008, 7.801759648443267, 7.83710202459307, 7.872206932391603, 7.90707857963094, 7.941721054269436, 7.976138329105924, 8.010334266223461, 8.044312621216267, 8.078077047212638, 8.111631098705669, 8.144978235202865, 8.178121824704965, 8.21106514702358, 8.243811396946684], [0.0, 1.3121809125710286, 1.7314330945026677, 2.036302141349568, 2.2846396651702623, 2.497938362523634, 2.6869167842345396, 2.8578072395721197, 3.0146001114576975, 3.160026465207696, 3.296049429973025, 3.424134300593085, 3.5454079523859408, 3.6607583107406327, 3.77089926007946, 3.876414591795683, 3.9777886948852803, 4.075428560229311, 4.169679919093261, 4.260839315793203, 4.3491632971478955, 4.434875515833267, 4.518172297181388, 4.599227055976033, 4.678193840090378, 4.755210202487609, 4.830399550449883, 4.903873083487963, 4.975731404402501, 5.04606586824312, 5.1149597193098835, 5.182489055407235, 5.248723650284115, 5.313727658867145, 5.377560225012363, 5.440276007702218, 5.50192563863444, 5.562556121793644, 5.622211183721298, 5.680931581696721, 5.738755375829772, 5.7957181700825275, 5.851853326435015, 5.907192155752058, 5.961764088365781, 6.0155968269390465, 6.068716483801103, 6.121147704634285, 6.172913780128278, 6.22403674699752, 6.274537479570376, 6.324435773000103, 6.3737504190124525, 6.422499274989296, 6.470699327088634, 6.5183667480161676, 6.565516949990224, 6.6121646333782325, 6.658323831427889, 6.704007951468242, 6.749229812914094, 6.794001682370718, 6.838335306103791, 6.882241940111453, 6.925732378010672, 6.9688169769282915, 7.01150568156793, 7.053808046606797, 7.095733257561478, 7.137290150248176, 7.178487228951057, 7.219332683401598, 7.259834404662353, 7.300000000000001, 7.339836806824905, 7.379351905767557, 7.41855213295609, 7.457444091553532, 7.496034162608394, 7.53432851526776, 7.572333116397859, 7.610053739653463, 7.647495974034098, 7.684665231961952, 7.7215667569136786, 7.75820563063571, 7.794586779970427, 7.830714983318453, 7.8665948767604, 7.902230959859686, 7.937627601166394, 7.972789043440753, 8.007719408613418, 8.04242270249851, 8.076902819274284, 8.111163545745201, 8.145208565398272, 8.179041462265623, 8.212665724604417, 8.246084748404606, 8.279301840734128, 8.312320222930714], [0.0, 1.3229366004427638, 1.7456253097352263, 2.052993307967736, 2.303366405441015, 2.5184134701042615, 2.7089409106272404, 2.8812321212877037, 3.039310193387945, 3.1859285782475837, 3.3230664963995893, 3.452201253415864, 3.5744689613889715, 3.6907648238570596, 3.801808576812092, 3.9081887968701206, 4.010393843468089, 4.108834043510954, 4.203857962155126, 4.295764574431889, 4.384812530023623, 4.4712273148430866, 4.555206863462334, 4.636926012111885, 4.716540071364919, 4.794187721679101, 4.869993381881718, 4.9440691629639675, 5.016516492347795, 5.087427473902128, 5.156886034264125, 5.2249688949969055, 5.291746401771055, 5.357283235378466, 5.421639024465682, 5.484868876044043, 5.547023836829308, 5.608151296088473, 5.668295338780833, 5.727497056265081, 5.7857948206222805, 5.843224527653156, 5.899819812799298, 5.9556122435745085, 6.010631491545533, 6.064905486448492, 6.118460554650241, 6.171321543848908, 6.223511935643362, 6.275053947378638, 6.325968624485853, 6.376275924375224, 6.425994792804568, 6.475143233529192, 6.523738371939277, 6.571796513305003, 6.619333196175607, 6.666363241414526, 6.71290079729722, 6.758959381049962, 6.804551917165771, 6.849690772796859, 6.8943877904907245, 6.938654318508703, 6.982501238940907, 7.025938993809508, 7.068977609332892, 7.1116267185060735, 7.153895582137505, 7.195793108468829, 7.237327871492149, 7.278508128068555, 7.319341833942085, 7.359836658734677, 7.3999999999999995, 7.439838996407076, 7.4793605401184315, 7.518571288421916, 7.557477674670239, 7.596085918577762, 7.634402035919938, 7.67243184767705, 7.7101809886605475, 7.747654915657176, 7.784858915123331, 7.8217981104595165, 7.858477468892469, 7.894901807990417, 7.931075801835012, 7.967003986871702, 8.002690767458715, 8.038140421133345, 8.073357103612905, 8.108344853546374, 8.143107597031825, 8.177649151913405, 8.211973231870944, 8.246083450314163, 8.27998332409279, 8.31367627703303, 8.347165643310207, 8.38045467066672], [0.0, 1.3336343041982999, 1.7597410144677612, 2.0695944921918223, 2.321992189501729, 2.5387781959937032, 2.7308463045391203, 2.904530719024099, 3.0638870628004047, 3.2116910525074855, 3.3499379133114293, 3.4801168967665532, 3.6033733019442935, 3.7206095712952676, 3.8325512608351815, 3.9397917066056505, 4.042823217079862, 4.142059437202104, 4.23785175074215, 4.330501550342464, 4.420269577212473, 4.507383140618746, 4.592041775697883, 4.6744217324641, 4.754679577383341, 4.832955112329406, 4.909373762221453, 4.984048544617305, 5.057081707114652, 5.128566098364831, 5.198586323663598, 5.267219724970058, 5.3345372167931995, 5.400604002955232, 5.465480194279698, 5.529221343391489, 5.5918789097870265, 5.6535006659386235, 5.714131053291164, 5.773811495481686, 5.832580674880615, 5.890474777554016, 5.947527710930808, 6.003771297790167, 6.059235449632965, 6.11394832204442, 6.167936454275117, 6.221224894949903, 6.273837315547639, 6.325796113070174, 6.377122503128954, 6.42783660451643, 6.4779575161920935, 6.527503387495584, 6.576491482298664, 6.62493823772133, 6.6728593179626765, 6.720269663732557, 6.767183537714072, 6.813614566438267, 6.859575778909894, 6.905079642286059, 6.95013809487702, 6.994762576709915, 7.038964057871046, 7.082753064820233, 7.126139704851189, 7.169133688854517, 7.211744352524636, 7.253980676138181, 7.2958513030194005, 7.337364556797097, 7.37852845754809, 7.419350736913425, 7.45983885226584, 7.5, 7.539841128010742, 7.579368947418952, 7.618589943599559, 7.6575103865616, 7.6961363407260786, 7.734473674143653, 7.772528067190729, 7.810305020779434, 7.847809864114205, 7.885047762025058, 7.922023721905371, 7.9587426002798285, 7.995209109026252, 8.031427821273292, 8.067403176994276, 8.103139488316085, 8.138640944560533, 8.173911617034461, 8.208955463583667, 8.24377633292465, 8.27837796876729, 8.312764013740534, 8.34693801313252, 8.38090341845565, 8.414663590846496, 8.448221804309775], [0.0, 1.344275103390831, 1.7737816331792515, 2.0861073693216734, 2.3405188969636863, 2.55903459528765, 2.7526351765415797, 2.9277053839471434, 3.088333199857033, 3.237316487794053, 3.376666392423566, 3.507884047737739, 3.632123890918357, 3.750295564822377, 3.8631304145306493, 3.971226510193423, 4.07508008831392, 4.175108094226032, 4.271664715319775, 4.365053748988733, 4.455538016843865, 4.543346641806544, 4.628680751063988, 4.711718000893738, 4.792616206973997, 4.871516286629529, 4.948544665519626, 5.023815262946419, 5.097431142320563, 5.169485893114057, 5.240064795671256, 5.309245809047159, 5.377100413563324, 5.443694333290106, 5.509088158663191, 5.5733378855506635, 5.6364953840338865, 5.698608807752099, 5.759722952739512, 5.819879573144011, 5.879117659974853, 5.93747368801943, 5.994981835247198, 6.051674178344871, 6.107580867471154, 6.162730282859004, 6.217149175510333, 6.270862793907917, 6.323894998400571, 6.376268364691308, 6.428004277666657, 6.47912301664286, 6.529643832966153, 6.579585020786099, 6.628963981719409, 6.677797284034546, 6.726100716912094, 6.773889340270813, 6.8211775305928795, 6.867979023132681, 6.914306950850771, 6.960173880377188, 7.0055918452755614, 7.050572376850699, 7.095126532717007, 7.139264923322808, 7.182997736605873, 7.226334760938043, 7.269285406501359, 7.311858725224274, 7.354063429394376, 7.395907909053026, 7.4374002482676165, 7.4785482403684, 7.519359402228986, 7.559840987662623, 7.6, 7.639843203908681, 7.679377136509097, 7.718608117837419, 7.757542260701446, 7.796185479971829, 7.83454350134755, 7.872621869631406, 7.910425956548481, 7.94796096813793, 7.985231951746112, 8.02224380264694, 8.059001270313363, 8.0955089643621, 8.131771360192133, 8.16779280433593, 8.203577519541064, 8.239129609598505, 8.274453063932912, 8.309551761968914, 8.344429477286694, 8.379089881579006, 8.413536548421126, 8.447772956864377, 8.481802494863159, 8.515628462544814], [0.0, 1.354860043569177, 1.7877485454796374, 2.102533561887599, 2.358948348233117, 2.5791846583492304, 2.7743096675761976, 2.95075839316433, 3.11265100659825, 3.2628074020237663, 3.4032545600358945, 3.535505434687642, 3.660723553300511, 3.779825721339172, 3.8935490425598474, 4.002496296369653, 4.107167626681603, 4.20798326189375, 4.305300178298714, 4.399424565417429, 4.490621314341288, 4.579121352125664, 4.6651273896509045, 4.7488184820756745, 4.830353687732684, 4.909875033542081, 4.9875099406498995, 5.0633732253688555, 5.1375687626399476, 5.210190878866895, 5.281325525898968, 5.3510512766476115, 5.419440174276708, 5.486558460373717, 5.55246720246873, 5.617222837346214, 5.680877643517107, 5.743480153786629, 5.805075516916899, 5.865705815831627, 5.925410348558702, 5.984225877091192, 6.042186848518885, 6.0993255921031455, 6.1556724954076705, 6.211256162133866, 6.26610355392338, 6.320240118067758, 6.373689902794299, 6.4264756615690795, 6.4786189476651055, 6.530140200079733, 6.581058821745991, 6.63139325086318, 6.68116102606987, 6.730378846094525, 6.779062624443121, 6.8272275396175415, 6.874888081301646, 6.922058092902421, 6.968750810790504, 7.014978900546681, 7.060754490487919, 7.106089202717531, 7.15099418191855, 7.195480122086902, 7.239557291381072, 7.283235555247401, 7.326524397964531, 7.3694329427365926, 7.411969970452493, 7.454143937217511, 7.495962990753701, 7.537434985756677, 7.578567498288576, 7.619367839279806, 7.659843067205896, 7.7, 7.7398452262564055, 7.7793851157758045, 7.818625829498781, 7.857573328870197, 7.896233384673691, 7.9346115853723225, 7.972713344988613, 8.010543910554526, 8.048108369159667, 8.085411654623769, 8.122458553817545, 8.159253712654241, 8.195801641772523, 8.23210672192984, 8.268173209124047, 8.30400523945973, 8.339606833774619, 8.37498190204028, 8.410134247550396, 8.445067570908952, 8.47978547382987, 8.514291462758823, 8.54858895232727, 8.582681268648042], [0.0, 1.3653901377755393, 1.8016430880861158, 2.118874641974654, 2.377282307118936, 2.599230313660221, 2.79587185202164, 2.973691952986775, 3.136842810383874, 3.2881662348298586, 3.429704960795373, 3.562983701148502, 3.689175026249816, 3.809202867058578, 3.923810056167747, 4.033604057840246, 4.139088903152599, 4.240688086555791, 4.33876135879432, 4.433617289121634, 4.525522827386534, 4.614710695430248, 4.701385179620334, 4.785726726748267, 4.867895631362432, 4.9480350242289886, 5.026273316822583, 5.10272621781865, 5.177498409483577, 5.250684951334384, 5.322372463245853, 5.392640128805164, 5.461560551102157, 5.52920048655987, 5.5956214773307345, 5.660880398830987, 5.725029935884859, 5.788118998498899, 5.850193086335471, 5.911294609390553, 5.971463171119847, 6.0307358192339375, 6.089147268548497, 6.146730099590816, 6.2035149360994755, 6.259530604086421, 6.314804274741608, 6.36936159313522, 6.423226794399542, 6.476422808842642, 6.5289713572515, 6.5808930374772, 6.632207403254113, 6.682933036084883, 6.733087610919959, 6.782687956271825, 6.831750109327658, 6.880289366558024, 6.92832033026191, 6.975856951438507, 7.022912569332717, 7.06949994796336, 7.115631309909773, 7.161318367603304, 7.206572352344465, 7.2514040412438785, 7.295823782265085, 7.33984151752956, 7.383466805028614, 7.426708838872741, 7.4695764681967045, 7.5120782148274, 7.554222289811707, 7.596016608892643, 7.637468807014179, 7.6785862519279355, 7.719376056968547, 7.759845093058757, 7.800000000000001, 7.839847197099637, 7.879392893181632, 7.918643096023734, 7.957603621260633, 7.996280100789426, 8.034677990710904, 8.072802578837434, 8.110658991795942, 8.148252201752252, 8.185587032781063, 8.222668166904084, 8.259500149817066, 8.2960873963251, 8.33243419550404, 8.368544715604648, 8.404423008714968, 8.440073015195216, 8.475498567898615, 8.51070339619058, 8.545691129777873, 8.580465302358588, 8.615029355102994, 8.64938663997478], [0.0, 1.3758663679589664, 1.815466556688226, 2.135132133416124, 2.395522483293741, 2.6191734305117964, 2.817323740587982, 2.9965082020076212, 3.16091086714042, 3.3133953509662706, 3.456020061246495, 3.5903214095150227, 3.7174809629141237, 3.8384297414489925, 3.953916277244918, 4.06455269545644, 4.170846894439793, 4.273225617992231, 4.372051377118124, 4.46763510863052, 4.560245810604573, 4.6501179904866, 4.737457502072361, 4.822446176667596, 4.905245538712823, 4.985999817173761, 5.064838408787901, 5.141877910028737, 5.2172238063583825, 5.2909718866571, 5.363209435408064, 5.434016243750442, 5.503465471835866, 5.571624388289444, 5.638555007458138, 5.704314641146244, 5.768956378412892, 5.832529504536486, 5.89507986828469, 5.956650205052698, 6.017280422161684, 6.0770078515782355, 6.135867474474423, 6.19389212135818, 6.251112650934875, 6.307558110389822, 6.363255879389391, 6.4182317997707194, 6.472510292615016, 6.526114464167743, 6.579066201872982, 6.63138626162297, 6.683094347182034, 6.73420918262313, 6.784748578511316, 6.834729492479219, 6.884168084762556, 6.93307976919714, 6.981479260121028, 7.029380615575258, 7.076797277152768, 7.123742106806875, 7.170227420897116, 7.216265021720818, 7.261866226752905, 7.307041895793546, 7.351802456203109, 7.396157926385999, 7.440117937669129, 7.4836917547066575, 7.526888294530113, 7.569716144351817, 7.612183578219558, 7.6542985726114825, 7.6960688210522035, 7.737501747823893, 7.7786045208396795, 7.819384063740839, 7.859847067274019, 7.9, 7.939849118381202, 7.979400476291255, 8.018659933986472, 8.057633166575814, 8.0963256720231, 8.134742778712504, 8.172889652606022, 8.21077130401942, 8.248392594041086, 8.285758240616474, 8.3228728243191, 8.359740793827536, 8.396366471126433, 8.43275405644829, 8.468907632971616, 8.504831171289831, 8.540528533664496, 8.576003478075327, 8.611259662078744, 8.646300646485846, 8.68112989886998, 8.715750796913442], [0.0, 1.3862896863102927, 1.8292202077093052, 2.1513075138651403, 2.413670534618065, 2.6390158215457884, 2.8386672830502206, 3.019209214009404, 3.184857364427978, 3.338497043522474, 3.4822022531844965, 3.617521044527886, 3.7456439360369647, 3.867509000958529, 3.983870442163821, 4.095345022158439, 4.202444487046027, 4.305598813558782, 4.405173259019824, 4.501481115844069, 4.5947934199881395, 4.685346455484966, 4.773347635641969, 4.8589801692864505, 4.942406804539296, 5.02377286301916, 5.1032087217501525, 5.1808318605198656, 5.25674856392947, 5.331055346538713, 5.403840154082454, 5.475183382183307, 5.545158745241171, 5.6138340214962685, 5.681271695105201, 5.747529512056274, 5.8126609636018705, 5.876715708396875, 5.939739942551044, 6.001776725215309, 6.062866266041592, 6.123046179816809, 6.182351712724153, 6.240815943989634, 6.298469966098669, 6.355343046292874, 6.411462771662088, 6.466855179816602, 6.521544876847382, 6.575555144048686, 6.628908034679974, 6.681624461876419, 6.733724278674556, 6.78522635099758, 6.836148624340215, 6.88650818480309, 6.936321315048988, 6.985603545686193, 7.034369702525965, 7.082633950110556, 7.1304098318640134, 7.177710307179523, 7.224547785723163, 7.270934159204365, 7.316880830837222, 7.362398742693816, 7.407498401130337, 7.452189900448835, 7.496482944941443, 7.540386869449684, 7.583910658558928, 7.627062964536687, 7.669852124113462, 7.712286174195775, 7.75437286659301, 7.796119681832379, 7.837533842129838, 7.8786223235789405, 7.919391867614235, 7.9598489918011675, 8.0, 8.03985099194743, 8.079407872296029, 8.118676359148372, 8.157661992119872, 8.196370139961587, 8.234806007771928, 8.272974643823916, 8.310880946032677, 8.34852966808598, 8.385925425258952, 8.423072699932558, 8.459975846834032, 8.496639098016091, 8.533066567590675, 8.56926225623171, 8.605230055460561, 8.640973751726733, 8.67649703029564, 8.71180347895445, 8.746896591546225, 8.781779771341984], [0.0, 1.3966610165238236, 1.842905259971297, 2.1674022167526226, 2.4317280693371037, 2.658759245156499, 2.859904370831793, 3.041797000711885, 3.2086844243388057, 3.363473536961896, 3.50825385682457, 3.644585016566121, 3.7736664413665277, 3.896443222534902, 4.013675205404596, 4.125983766702656, 4.2338844810888245, 4.337810542105401, 4.438129939696509, 4.535158310129955, 4.629168717079536, 4.7203992123037555, 4.809058760843357, 4.89533194217657, 4.97938272200133, 5.061357509139426, 5.141387656012233, 5.219591521315759, 5.296076184804385, 5.370938883097887, 5.444268219884699, 5.516145192255916, 5.586644066095294, 5.655833126716373, 5.723775325742133, 5.790528841179326, 5.856147564467572, 5.920681525775961, 5.984177266823907, 6.0466781689032905, 6.108224742488859, 6.168854883777234, 6.228604102640944, 6.28750572578355, 6.345591078304501, 6.402889646404141, 6.459429223561221, 6.515236042182729, 6.570334892446621, 6.624749229822866, 6.678501272559265, 6.731612090249653, 6.78410168445825, 6.835989062250988, 6.887292303379271, 6.938028621770973, 6.988214421905315, 7.037865350580633, 7.086996344525395, 7.135621674251871, 7.183754984507323, 7.231409331638802, 7.278597218153548, 7.325330624727134, 7.37162103988519, 7.417479487561358, 7.462916552713648, 7.507942405163203, 7.5525668218034445, 7.596799207313192, 7.640648613494722, 7.684123757346262, 7.72723303796838, 7.769984552394579, 7.812386110428309, 7.854445248561288, 7.896169243041461, 7.9375651221530354, 7.97863967776565, 8.019399476204997, 8.059850868492774, 8.1, 8.139852819554063, 8.17941508803672, 8.21869238650723, 8.257690123882206, 8.296413544201261, 8.334867733505362, 8.37305762635269, 8.41098801199506, 8.448663540236124, 8.48608872699115, 8.523267959566645, 8.560205501676833, 8.596905498212795, 8.633371979778937, 8.66960886701049, 8.705619974684746, 8.74140901563791, 8.776979604498674, 8.81233526124879, 8.84747941462037], [0.0, 1.4069812549906497, 1.8565228962693368, 2.183417633139118, 2.4496966481583953, 2.67840540776236, 2.8810368394480954, 3.06427351437098, 3.2323941062388464, 3.3883269899956905, 3.5341771237993336, 3.6715156647610563, 3.8015509008798984, 3.9252349069545716, 4.043333142984366, 4.1564715771869825, 4.265169593917837, 4.369863587682532, 4.470924267584623, 4.568669602198406, 4.663374672925815, 4.75527929054267, 4.844593964178816, 4.931504637211244, 5.016176486916849, 5.098757003964725, 5.179378511368464, 5.258160242402766, 5.335210068058101, 5.4106259434572275, 5.484497127000912, 5.556905214285747, 5.627925019962599, 5.697625333920355, 5.766069572945521, 5.833316344935064, 5.899419939544418, 5.964430756626707, 6.0283956818084485, 6.091358416935522, 6.153359771823571, 6.214437922692633, 6.2746286418055695, 6.333965502124356, 6.392480060216563, 6.450202020162614, 6.507159380813448, 6.563378568413137, 6.618884556319768, 6.673700973320984, 6.727850201840157, 6.781353467159031, 6.834230918637824, 6.886501703789904, 6.938184035961969, 6.989295256279433, 7.039851890437857, 7.089869700853243, 7.139363734624866, 7.18834836771298, 7.236837345688914, 7.284843821375969, 7.332380389665188, 7.379459119760015, 7.426091585077349, 7.472288891009126, 7.518061700727962, 7.563420259202068, 7.608374415568499, 7.652933643999341, 7.697107063182642, 7.740903454528469, 7.78433127920021, 7.827398694062146, 7.870113566626099, 7.912483489072599, 7.954515791415402, 7.99621755387227, 8.037595618499475, 8.078656600142747, 8.119406896752894, 8.159852699110447, 8.200000000000001, 8.239854602871747, 8.27942213002463, 8.31870803034295, 8.357717586615696, 8.396455922465716, 8.434928008913742, 8.473138670600433, 8.511092591687872, 8.548794321460429, 8.586248279643394, 8.623458761456519, 8.660429942418409, 8.6971658829165, 8.733670532556472, 8.769947734303846, 8.806001228429801, 8.841834656272326, 8.877451563823099, 8.912855405149894], [0.0, 1.4172512719280759, 1.8700742648620423, 2.1993551134674987, 2.4675777862182695, 2.69795596595597, 2.902066470819181, 3.0866406502385475, 3.2559884093624727, 3.4130594983026508, 3.559974239995828, 3.698315259943561, 3.8292996658346836, 3.9538864819736492, 4.072846755702954, 4.186811024387311, 4.296302463538635, 4.401760653048935, 4.503559007948914, 4.602017817769617, 4.697414171822217, 4.789989631339918, 4.8799562420276414, 4.967501304523981, 5.052791201788866, 5.135974501074085, 5.2171844912622385, 5.296541275950747, 5.374153513515766, 5.450119874086568, 5.524530267590222, 5.597466885216299, 5.6690050877123035, 5.739214167087049, 5.808158003026931, 5.875895631227151, 5.94248173762112, 6.00796708994699, 6.072398916064822, 6.135821236814581, 6.198275159896119, 6.2597991401902044, 6.3204292110731615, 6.3801991905670095, 6.439140865581038, 6.497284157015482, 6.554657268094064, 6.611286817954665, 6.667197962244088, 6.722414502224239, 6.776958983695125, 6.830852786868774, 6.884116208182182, 6.936768534912686, 6.988828113352171, 7.0403124112045985, 7.091238074791997, 7.141620981585404, 7.191476288517797, 7.240818476484275, 7.2896613913895925, 7.338018282063815, 7.385901835332219, 7.433324208495319, 7.480297059448171, 7.526831574644605, 7.572938495091228, 7.618628140537625, 7.663910432012932, 7.708794912844315, 7.753290768280117, 7.797406843828789, 7.841151662414522, 7.884533440441223, 7.927560102848258, 7.9702392972339675, 8.01257840711628, 8.054584564393785, 8.096264661065163, 8.13762536026007, 8.178673106630056, 8.219414136144179, 8.259854485330337, 8.3, 8.33985634349112, 8.379429004461183, 8.418723304259986, 8.457744403909379, 8.4964973107152, 8.534986884534744, 8.573217843721325, 8.611194770766028, 8.648922117655166, 8.686404210960708, 8.723645256679736, 8.760649344837784, 8.797420453869995, 8.833962454792955, 8.870279115179311, 8.906374102946364, 8.94225098996915, 8.977913255527815], [0.0, 1.4274719124493171, 1.883560480882986, 2.2152159692229665, 2.485372954944297, 2.71741252854043, 2.922994995460149, 3.108900248892088, 3.2794692752700043, 3.437673097105284, 3.585647328242471, 3.7249860074354157, 3.856915019659246, 3.9824003053121673, 4.10221847221693, 4.217004604917612, 4.327285651855421, 4.4335043629939985, 4.536036846281578, 4.635205701047211, 4.731290014857633, 4.824533090987547, 4.915148504329371, 5.003324906257825, 5.089229879619169, 5.173013063071864, 5.254808706723795, 5.334737780310742, 5.412909725808936, 5.4894239249165455, 5.564370935954513, 5.637833542841886, 5.709887649797269, 5.780603048535298, 5.8500440794167226, 5.9182702038781985, 5.9853365022258735, 6.051294108314211, 6.116190590591414, 6.180070287357865, 6.242974602765451, 6.30494226901592, 6.366009579343672, 6.426210595652564, 6.485577334086164, 6.544139931322087, 6.60192679397425, 6.658964733146942, 6.715279085899277, 6.7708938251381925, 6.825831659254846, 6.880114122646673, 6.933761658120329, 6.986793692045159, 7.039228703019055, 7.091084284715965, 7.142377203504429, 7.193123451357357, 7.243338294513372, 7.293036318297905, 7.342231468466754, 7.390937089395163, 7.439165959400642, 7.486930323457215, 7.534241923531946, 7.581112026750825, 7.627551451580234, 7.673570592191603, 7.7191794411605, 7.764387610636688, 7.809204352108793, 7.85363857487548, 7.897698863324806, 7.941393493114045, 7.984730446334009, 8.02771742573441, 8.070361868080111, 8.112670956702054, 8.154651633301217, 8.19631060905904, 8.237654375103281, 8.278689212374275, 8.31942120093291, 8.359856228748269, 8.4, 8.439858042927558, 8.47943571725615, 8.518738221226823, 8.557770598256072, 8.5965377432485, 8.63504440858428, 8.673295209801553, 8.711294630992555, 8.74904702993073, 8.786556642945106, 8.823827589556819, 8.860863876891866, 8.89766940388304, 8.934247965273185, 8.970603255431136, 9.00673887199084, 9.042658319323596], [0.0, 1.4376439975772874, 1.8969826276783983, 2.231001474506298, 2.5030835838203984, 2.736776658459244, 2.9438240945570513, 3.13105409844268, 3.302838590176783, 3.462169763611239, 3.61119845085558, 3.751530049694795, 3.8843991806918816, 4.010778667482378, 4.131450651953009, 4.247054744224846, 4.358121647744258, 4.465097267486405, 4.568360391523751, 4.6682359180101525, 4.765004923274758, 4.858912444357821, 4.950173578074511, 5.038978320118713, 5.125495447522687, 5.209875665261621, 5.292254180102167, 5.372752823803689, 5.451481818219827, 5.528541253237183, 5.604022332490236, 5.678008429811615, 5.75057599030915, 5.8217953030293375, 5.891731166818745, 5.960443466832903, 6.027987675877147, 6.094415292182929, 6.15977422316856, 6.2241091230866745, 6.287461691132831, 6.349870935512288, 6.411373408083004, 6.472003413472062, 6.531793195968281, 6.590773107001557, 6.648971755609751, 6.706416143951586, 6.763131789636642, 6.819142836401452, 6.874472154455904, 6.9291414316503435, 6.9831712564657265, 7.036581193702621, 7.089389853636374, 7.141614955312472, 7.193273384575663, 7.244381247356761, 7.294953918680754, 7.345006087807286, 7.394551799868832, 7.44360449433191, 7.4921770405716055, 7.540281770818946, 7.587930510713595, 7.6351346076704525, 7.68190495724769, 7.728252027685021, 7.774185882764548, 7.81971620313168, 7.864852306200631, 7.909603164757231, 7.953977424361408, 7.997983419642308, 8.041629189570674, 8.084922491785585, 8.127870816045874, 8.170481396870498, 8.21276122542661, 8.25471706071915, 8.296355440131292, 8.337682689361003, 8.378704931795344, 8.419428097360738, 8.459857930884496, 8.5, 8.539859702625561, 8.579442274044599, 8.618752793612712, 8.657796191115327, 8.696577252797802, 8.735100627088356, 8.773370830032606, 8.811392250457255, 8.849169154879167, 8.886705692174962, 8.924005898025191, 8.961073699146223, 8.997912917322028, 9.034527273247308, 9.070920390192546, 9.107095797501], [0.0, 1.4477683252060298, 1.9103417580757804, 2.2467128675258303, 2.5207110620607907, 2.7560498746265494, 2.964555401935587, 3.1531039366288867, 3.3260981871619575, 3.4865514193286455, 3.6366296120543753, 3.7779494688251143, 3.911754304778524, 4.039023794470974, 4.1605455878709705, 4.2769637994291925, 4.388812869967586, 4.49654184466018, 4.60053217912061, 4.701111059534649, 4.798561541656709, 4.893130388152635, 4.985034210614992, 5.074464342745305, 5.161590750155185, 5.2465651991302344, 5.329523848604403, 5.410589388313474, 5.489872816327008, 5.567474927395122, 5.6434875674361145, 5.71799469742658, 5.791073300824119, 5.862794161672138, 5.93322253515045, 6.002418728144122, 6.070438604114908, 6.137334023960516, 6.203153232477913, 6.267941198388603, 6.331739914546604, 6.394588663864853, 6.456524255610644, 6.517581235994712, 6.577792076379993, 6.637187341940413, 6.695795843187406, 6.753644772437132, 6.810759827001965, 6.867165320645997, 6.922884284638109, 6.977938559561108, 7.03234887888631, 7.086134945195582, 7.139315499823504, 7.191908386598491, 7.243930610280556, 7.295398390223394, 7.346327209727608, 7.396731861499093, 7.44662648958043, 7.49602462808296, 7.544939237011834, 7.593382735445413, 7.641367032303123, 7.688903554911822, 7.736003275559526, 7.782676736206485, 7.8289340715070255, 7.874785030280617, 7.920238995557544, 7.965305003312735, 8.009991759990786, 8.054307658915846, 8.098260795671541, 8.141858982528612, 8.185109761991056, 8.228020419525523, 8.270597995533096, 8.312849296617694, 8.354780906200734, 8.396399194527678, 8.437710328108345, 8.478720278629513, 8.519434831375317, 8.559859593188113, 8.6, 8.63986132396286, 8.679448680202663, 8.718767033221887, 8.757821202972094, 8.79661587061715, 8.835155584006044, 8.873444762872934, 8.9114877037808, 8.949288584823913, 8.986851470103321, 9.024180313988527, 9.06127896517767, 9.09815117056772, 9.134800578945333, 9.171230744508481], [0.0, 1.4578456710130647, 1.9236388955877572, 2.2623513520132925, 2.538256740198479, 2.7752336536639133, 2.985190505929292, 3.1750514528037628, 3.3492498482645123, 3.510819932263257, 3.6619427602526966, 3.8042462889558055, 3.938982487737839, 4.067137850284382, 4.189505509085536, 4.306734062019296, 4.419361669939939, 4.527840503648313, 4.632554673920525, 4.733833644356683, 4.831962440950961, 4.927189543987052, 5.019733072805611, 5.109785692906793, 5.197518552965974, 5.283084475654167, 5.366620567654105, 5.448250372696559, 5.528085661464987, 5.606227930302112, 5.682769664429543, 5.757795409243203, 5.831382684052259, 5.9036027656, 5.974521363281875, 6.044199203755456, 6.112692539326078, 6.180053591874762, 6.2463309420115225, 6.31156987146745, 6.3758126653922975, 6.439098880131907, 6.501465581168405, 6.562947555175106, 6.623577499535333, 6.683386192175163, 6.7424026441446685, 6.800654237035025, 6.858166847027489, 6.9149649571247, 6.971071758907143, 7.026509244981328, 7.081298293136113, 7.135458743095284, 7.189009466644479, 7.241968431815984, 7.294352761733258, 7.346178788646536, 7.397462103629588, 7.448217602354512, 7.498459527315007, 7.548201506828041, 7.59745659110826, 7.646237285678348, 7.69455558235103, 7.742422987994295, 7.789850551269937, 7.836848887516646, 7.883428201932091, 7.929598311193437, 7.975368663642553, 8.020748358150232, 8.065746161763212, 8.110370526228262, 8.154629603479187, 8.198531260164868, 8.24208309128971, 8.285292433031623, 8.32816637479716, 8.370711770568326, 8.412935249591149, 8.454843226451864, 8.496441910582936, 8.53773731523771, 8.578735265969403, 8.619441408647397, 8.659861217041177, 8.700000000000001, 8.739862908254219, 8.779454940862255, 8.81878095132546, 8.857845653391438, 8.89665362656497, 8.93520932134424, 8.973517064198917, 9.011581062305341, 9.04940540805317, 9.086994083336714, 9.124350963643389, 9.161479821950836, 9.198384332443489, 9.235068074058685], [0.0, 1.4678767893256992, 1.9368750355551771, 2.2779180985681755, 2.5557219315935873, 2.794329431549485, 3.005730951153457, 3.1968982898215965, 3.37229530647352, 3.5349771190047146, 3.6871397902350704, 3.830422478502946, 3.966085767701922, 4.095122939365619, 4.2183325833559335, 4.336367760411491, 4.4497703343541115, 4.558995587273367, 4.664430272927896, 4.766406121885031, 4.865210121340685, 4.961092461317228, 5.054272761986954, 5.144945014539333, 5.233281545286474, 5.31943622843888, 5.4035471140804825, 5.485738596019536, 5.566123214009214, 5.64480316276645, 5.721871563883503, 5.79741354449474, 5.871507157302797, 5.944224169490699, 6.015630742585924, 6.085788021092938, 6.15475264437693, 6.2225771936462975, 6.289310583783649, 6.3549984080937945, 6.419683242681387, 6.483404916070863, 6.54620074878385, 6.608105766853183, 6.6691528926457515, 6.729373115863835, 6.788795647176214, 6.847448056580829, 6.9053563983072985, 6.962545323820468, 7.01903818427703, 7.0748571236098305, 7.130023163263239, 7.184556279473858, 7.238475473879969, 7.2917988381479715, 7.344543613221806, 7.39672624373036, 7.448362428026184, 7.49946716427525, 7.550054792970752, 7.600139036203137, 7.649733033982733, 7.6988493778799985, 7.74750014222071, 7.795696913049107, 7.843450815050415, 7.8907725366051595, 7.937672353130748, 7.984160148850761, 8.030245437119051, 8.075937379413755, 8.12124480310575, 8.166176218096432, 8.210739832411285, 8.254943566827889, 8.298795068610215, 8.34230172441482, 8.385470672428912, 8.428308813795256, 8.470822823374277, 8.513019159889577, 8.554904075499376, 8.596483624832901, 8.637763673527735, 8.678749906301254, 8.719447834586758, 8.75986280376254, 8.8, 8.839864456755, 8.87946106092477, 8.918794558691188, 8.957869561069606, 8.996690549181118, 9.035261879264885, 9.073587787445915, 9.111672394272702, 9.149519709038108, 9.187133633895929, 9.224517967784847, 9.261676410170553, 9.298612564616276], [0.0, 1.4778624139441148, 1.950051146233185, 2.2934142459350437, 2.573107913866438, 2.81333860518487, 3.026178240190543, 3.2186460458305173, 3.395236247619104, 3.5590247467087295, 3.7122225452242166, 3.8564799523171085, 3.9930661273402164, 4.122981108890564, 4.247028919451263, 4.365867062381352, 4.480041087676285, 4.590009374603867, 4.696161307918665, 4.798830874873955, 4.898307014972842, 4.994841620222262, 5.088655804819499, 5.179944879630994, 5.268882343264701, 5.355623116701614, 5.440306189148299, 5.523056800635176, 5.603988256497199, 5.683203446658209, 5.760796126195012, 5.836852001342085, 5.911449655776459, 5.984661344896622, 6.056553680311548, 6.127188222477552, 6.196621996064261, 6.264907939977813, 6.332095301857393, 6.398229985168465, 6.463354855651026, 6.52751001277371, 6.590733030940975, 6.653059174459618, 6.714521589659738, 6.775151477059356, 6.834978246040643, 6.894029654153828, 6.952331932869397, 7.00990990135038, 7.066787069605963, 7.1229857322090195, 7.17852705360792, 7.233431145932958, 7.287717140086148, 7.341403250807288, 7.394506836326453, 7.447044453141521, 7.499031906397285, 7.5504842962887535, 7.601416060864162, 7.65184101556215, 7.701772389781482, 7.7512228607501426, 7.800204584932742, 7.848729227190684, 7.8968079878878426, 7.944451628115311, 7.991670493191775, 8.038474534580889, 8.08487333035364, 8.130876104311573, 8.176491743876115, 8.221728816839548, 8.266595587064641, 8.311100029212184, 8.355249842568707, 8.399052464040476, 8.442515080374127, 8.485644639659295, 8.52844786216393, 8.570931250548826, 8.613101099504187, 8.654963504847471, 8.696524372118832, 8.737789424707458, 8.778764211539647, 8.81945411435706, 8.859864354611414, 8.900000000000002, 8.93986597066448, 8.979467045073896, 9.01880786561127, 9.057892943881724, 9.096726665758897, 9.13531329618517, 9.173656983740175, 9.211761764991058, 9.249631568637064, 9.287270219460169, 9.324681442092668, 9.361868864611997], [0.0, 1.4878032589238495, 1.9631681698237118, 2.3088409022178236, 2.5904159302599323, 2.8322625338847054, 3.0465338351924447, 3.240296275976668, 3.418074312170107, 3.5829645349814747, 3.7371928188465517, 3.882420573725245, 4.019925495973715, 4.150714350950948, 4.275596569399163, 4.395234077375282, 4.5101760945180756, 4.620884083384566, 4.727750047926781, 4.831110221964035, 4.931255488551677, 5.028439434048816, 5.122884659977899, 5.214787790964368, 5.3043234926549685, 5.391647728107035, 5.476900421438355, 5.560207655106707, 5.641683496595644, 5.721431527918321, 5.799546134795288, 5.876113599964207, 5.951213035695398, 6.024917183413453, 6.0972931027904895, 6.168402768369377, 6.238303588396318, 6.307048857871123, 6.374688155697338, 6.441267694110194, 6.506830627186191, 6.571417324123128, 6.635065612069788, 6.697810992538405, 6.759686834817947, 6.820724549296791, 6.880953743179389, 6.940402360727194, 6.999096809856739, 7.057062076677213, 7.1143218293379356, 7.170898512376272, 7.226813432603309, 7.28208683743363, 7.336737986453305, 7.390785216923623, 7.444246003834835, 7.4971370150521395, 7.549474162033673, 7.60127264654594, 7.652547003754744, 7.703311142028302, 7.7535783797529625, 7.803361479430112, 7.852672679294849, 7.901523722672294, 7.949925885265596, 7.997890000550352, 8.045426483433056, 8.092545352315911, 8.139256249696816, 8.185568461421243, 8.231490934691875, 8.27703229493227, 8.322200861592094, 8.367004662973706, 8.411451450152908, 8.45554871006033, 8.499303677784281, 8.542723348150734, 8.585814486631532, 8.628583639627644, 8.671037144170512, 8.713181137081131, 8.75502156362328, 8.79656418568454, 8.837814589516075, 8.87877819305984, 8.919460252889667, 8.959865870790718, 9.0, 9.039867451128941, 9.079472897787563, 9.118820881928306, 9.157915818926403, 9.19676200241238, 9.235363608871294, 9.273724702022276, 9.311849236990971, 9.349741064286762, 9.387403933595694, 9.42484149739947], [0.0, 1.4977000193201075, 1.9762270234575983, 2.3241991460348577, 2.607647190935471, 2.85110254079357, 3.0667991594046002, 3.2618504940252455, 3.44081109694407, 3.6067981576720523, 3.762052357001814, 3.9082461564729623, 4.046665751586032, 4.178324604630849, 4.304037530624785, 4.424470858709338, 4.54017746189286, 4.651621872348154, 4.759198701609374, 4.863246420099046, 4.964057845805706, 5.061888251926707, 5.1569617207138325, 5.249476184725406, 5.339607471471509, 5.427512581464528, 5.513332369587432, 5.597193756989448, 5.679211569922837, 5.759490079420865, 5.838124299051112, 5.915201085497815, 5.99080007728043, 6.064994499694283, 6.137851858487612, 6.209434540453493, 6.279800335713656, 6.349002893782425, 6.41709212335865, 6.48411454407803, 6.550113597074882, 6.615129920080007, 6.679201591865667, 6.7423643500976045, 6.804651786034899, 6.866095519005577, 6.926725353159084, 6.986569418640095, 7.045654299028707, 7.104005146639913, 7.161645787061858, 7.2185988141313615, 7.274885676390883, 7.330526755939356, 7.385541440476234, 7.439948189240949, 7.493764593466132, 7.547007431890423, 7.5996927218138355, 7.651835766123935, 7.7034511966734005, 7.754553014347915, 7.805154626126779, 7.855268879406618, 7.904908093830395, 7.9540840908389825, 8.002808221140699, 8.05109139027464, 8.098944082426515, 8.146376382640211, 8.193397997554836, 8.240018274784637, 8.286246221048447, 8.332090519145522, 8.377559543865907, 8.422661376915656, 8.467403820930167, 8.511794412642598, 8.55584043526854, 8.59954893016305, 8.642926707801404, 8.685980358130758, 8.728716260336034, 8.771140592059917, 8.813259338113657, 8.855078298712494, 8.896603097266933, 8.937839187758692, 8.978791861727954, 9.019466254896589, 9.05986735345018, 9.099999999999998, 9.139868899244583, 9.179478623349114, 9.218833617059587, 9.257938202567447, 9.29679658413943, 9.335412852526234, 9.37379098916272, 9.411934870171574, 9.449848270181493, 9.487534865970218], [0.0, 1.5075533718961576, 1.9892286001293307, 2.339490027618228, 2.6248028742063423, 2.8698599142345236, 3.0869755986165495, 3.2833101739033186, 3.4634481567346986, 3.6305272445784698, 3.786802859642474, 3.9339584665730865, 4.073288722737427, 4.205813757983002, 4.332353747986557, 4.4535794056619595, 4.570047241363234, 4.6822248434154305, 4.790509419497809, 4.895241666826226, 4.996716329835662, 5.0951903611631355, 5.190889317295192, 5.284012432986362, 5.374736692514054, 5.463220129295364, 5.549604524896046, 5.634017635478225, 5.716575042734859, 5.797381703697239, 5.8765332570262006, 5.954117130835186, 6.03021348758463, 6.104896034318299, 6.178232720904036, 6.250286344576969, 6.321115075659425, 6.390772916625316, 6.459310104522293, 6.526773465038248, 6.593206725106259, 6.658650789812329, 6.723143988448557, 6.786722293798413, 6.849419518117514, 6.91126748875711, 6.972296205947832, 7.032533984902276, 7.0920075840936345, 7.150742321313712, 7.208762178898948, 7.266089899330773, 7.322747072261383, 7.378754213883322, 7.434130839447516, 7.488895529636534, 7.543065991415543, 7.596659113910327, 7.649691019798546, 7.7021771126453, 7.754132120566073, 7.805570136558227, 7.856504655805437, 7.906948610227216, 7.9569144005173245, 8.006413925889772, 8.055458611729067, 8.104059435321732, 8.152226949828819, 8.199971306643617, 8.247302276265108, 8.294229267805392, 8.340761347238415, 8.386907254487472, 8.432675419440267, 8.478073976972311, 8.523110781052457, 8.567793417997951, 8.612129218940582, 8.656125271560411, 8.699788431138757, 8.743125330977964, 8.786142392231548, 8.828845833184841, 8.8712416780231, 8.91333576512112, 8.955133754885768, 8.996641137180447, 9.037863238358327, 9.078805227929136, 9.119472124882522, 9.159868803689244, 9.200000000000001, 9.239870316060204, 9.27948422585778, 9.318846080019828, 9.357960110472913, 9.396830434880735, 9.43546106087197, 9.473855890070285, 9.512018721937608, 9.549953257441167], [0.0, 1.5173639757979167, 2.0021737695871615, 2.3547145698606102, 2.6418841277122453, 2.8885359089932887, 3.107064502543268, 3.304676751169016, 3.4859870058616553, 3.6541533830721975, 3.811445982468218, 3.9595592240659885, 4.099796190387489, 4.23318364991077, 4.360547115714784, 4.4825616654668154, 4.59978743108597, 4.7126950437904584, 4.821684296141299, 4.927098102486752, 5.0292331253503795, 5.128347989522628, 5.224669719328855, 5.31839884607023, 5.409713505772867, 5.498772760277325, 5.585719313811736, 5.670681753928427, 5.7537764144835855, 5.835108935530327, 5.914775578110784, 5.992864339288465, 6.069455903191667, 6.144624456522541, 6.218438391341722, 6.290960913545691, 6.362250572007879, 6.432361720630473, 6.501344923385386, 6.569247310684898, 6.636112894020912, 6.701982844674719, 6.766895741371376, 6.830887790992022, 6.893993025830022, 6.956243480357342, 7.017669350035101, 7.078299134340906, 7.138159765882266, 7.197276727209882, 7.255674156728435, 7.313374944919075, 7.370400821931529, 7.4267724374701904, 7.482509433784072, 7.537630512472008, 7.59215349572959, 7.646095382590834, 7.699472400653868, 7.752300053724539, 7.804593165763498, 7.856365921480162, 7.907631903879904, 7.958404129038425, 8.008695078348648, 8.058516728460297, 8.10788057911009, 8.156797679020697, 8.205278650029273, 8.253333709590644, 8.300972691786614, 8.34820506696033, 8.395039960083768, 8.441486167956437, 8.487552175324653, 8.533246170002712, 8.578576057070213, 8.62354947221337, 8.668173794272283, 8.712456157051035, 8.7564034604426, 8.800022380916419, 8.843319381412517, 8.886300720682542, 8.92897246211494, 8.971340482078505, 9.013410477815953, 9.055187974916704, 9.096678334395875, 9.137886759404473, 9.178818301593884, 9.21947786715613, 9.259870222559792, 9.299999999999999, 9.339871702579755, 9.379489709238438, 9.418858279442441, 9.457981557651705, 9.496863577575084, 9.535508266226577, 9.573919447793617, 9.612100847327971], [0.0, 1.5271324731966918, 2.0150633791812096, 2.369873769312703, 2.6588920695383664, 2.907131747541803, 3.127067186141289, 3.3259516244113514, 3.508429119647187, 3.677678119646028, 3.8359833385404376, 3.985050104696817, 4.126189889631765, 4.260436071961284, 4.388619479258736, 4.511419535211572, 4.629399977760444, 4.743034467956819, 4.852725372149316, 4.9588178123028115, 5.061610360797125, 5.161363307399357, 5.258305137973801, 5.352637674803571, 5.444540200720249, 5.534172801573929, 5.621679100295111, 5.7071885122580515, 5.790818120253923, 5.872674244426186, 5.952853765527044, 6.031445247128172, 6.108529892786767, 6.184182366804697, 6.258471501537528, 6.331460909789143, 6.403209517359361, 6.473772028070332, 6.543199331415097, 6.611538861222461, 6.678834912321849, 6.745128921047339, 6.810459714486401, 6.874863732613109, 6.938375226814186, 7.001026437793367, 7.062847755404342, 7.123867862598871, 7.184113865371411, 7.243611410324421, 7.30238479126099, 7.360457046026782, 7.417850044666046, 7.474584569822003, 7.530680390196684, 7.586156327786221, 7.641030319522073, 7.695319473874765, 7.749040122912581, 7.8022078702518884, 7.8548376352871445, 7.906943694046198, 7.958539716979198, 8.009638803956836, 8.06025351672484, 8.110395909036304, 8.160077554661038, 8.209309573451266, 8.258102655625482, 8.306467084416523, 8.354412757216123, 8.401949205335672, 8.449085612491963, 8.495830832116608, 8.542193403579086, 8.588181567405266, 8.633803279566132, 8.679066224904975, 8.72397782976545, 8.768545273877695, 8.81277550155487, 8.856675232248243, 8.900250970505, 8.943509015369434, 8.986455469264913, 9.029096246391168, 9.071437080668664, 9.113483533259506, 9.155240999691994, 9.196714716614018, 9.237909768198525, 9.27883109222266, 9.31948348584061, 9.359871611068685, 9.4, 9.439873059764704, 9.479495077250812, 9.518870223599503, 9.558002558487875, 9.596896034211282, 9.635554499576546, 9.673981703616596], [0.0, 1.5368594899018897, 2.027898254671938, 2.384968597134065, 2.675827789282168, 2.925648621204608, 3.146984930863331, 3.3471361565846536, 3.5307759358237663, 3.701102961389623, 3.8604164998212913, 4.010432741514366, 4.152471511357255, 4.287572770034797, 4.416572637047431, 4.540154863647946, 4.658886778486028, 4.77324505958059, 4.883634636138594, 4.9904028283671575, 5.093850110392401, 5.194238429887963, 5.291797728050832, 5.386731112664073, 5.479219008494974, 5.569422521054832, 5.657486188075366, 5.743540249237517, 5.827702533087189, 5.910080036970263, 5.990770258717497, 6.069862326003127, 6.147437959607559, 6.223572299404311, 6.298334616174223, 6.371788927900703, 6.44399453570938, 6.515006491856482, 6.5848760099738906, 6.653650826018519, 6.721375516954154, 6.788091783042148, 6.853838698677745, 6.9186529359381534, 6.982568964373102, 7.045619230042359, 7.107834316366718, 7.169243088992997, 7.229872826566332, 7.2897493390443175, 7.348897074968567, 7.407339218923496, 7.465097780253832, 7.522193673977114, 7.5786467947114255, 7.634476084338942, 7.68969959403978, 7.744334541256267, 7.798397362083221, 7.851903759523697, 7.904868748000714, 7.957306694472776, 8.009231356463488, 8.060655917282704, 8.111593018687755, 8.16205479120769, 8.21205288233104, 8.261598482737538, 8.31070235073665, 8.359374835059903, 8.407625896140118, 8.455465125998044, 8.50290176684583, 8.549944728506714, 8.59660260474139, 8.642883688563465, 8.6887959866192, 8.734347232700227, 8.779544900452038, 8.82439621533581, 8.868908165896258, 8.913087514383962, 8.956940806776597, 9.000474382239988, 9.043694382066683, 9.086606758126697, 9.129217280862504, 9.171531546857828, 9.213554986007605, 9.255292868314367, 9.296750310334522, 9.337932281296213, 9.378843608908932, 9.419488984883541, 9.459872970180161, 9.5, 9.53987438853626, 9.579500333498055, 9.618881920420453, 9.658023126772818, 9.696927825876807, 9.735599790644688], [0.0, 1.5465456359454104, 2.0406792010012653, 2.4000000000000004, 2.692692349070879, 2.944087691271333, 3.1668189858549467, 3.3682316762813156, 3.5530288558766725, 3.7244293773968633, 3.884746998641631, 4.035708726396045, 4.178642703821397, 4.314595446015039, 4.444408342169043, 4.568769452918109, 4.688249682533635, 4.803328713325385, 4.914414026590126, 5.021855131540722, 5.12595439605889, 5.2269754187586726, 5.325149590054783, 5.420681297828867, 5.513752103985769, 5.604524129413612, 5.693142822801549, 5.779739244673662, 5.864431966197095, 5.947328659074711, 6.028527435622993, 6.108117985248517, 6.186182543781642, 6.262796724669296, 6.338030235275434, 6.411947497060512, 6.484608184898946, 6.5560676980169985, 6.6263775728234355, 6.695585846133807, 6.763737375860798, 6.830874125084079, 6.897035414467529, 6.962258147216256, 7.026577010126322, 7.090024653750667, 7.152631854263869, 7.214427659240157, 7.275439519249912, 7.335693406919481, 7.395213924878829, 7.454024403834558, 7.51214699184657, 7.56960273575051, 7.62641165555145, 7.682592812513874, 7.738164371586507, 7.793143658725605, 7.84754721361543, 7.901390838228121, 7.954689641615969, 8.007458081286067, 8.059710001469611, 8.11145866856503, 8.162716804005063, 8.213496614772122, 8.26380982176371, 8.313667686189463, 8.363081034163722, 8.412060279641496, 8.460615445831806, 8.508756185209672, 8.556491798236818, 8.60383125089116, 8.650783191096068, 8.697355964132347, 8.743557627108613, 8.789395962559166, 8.834878491232582, 8.880012484128924, 8.924804973838622, 8.969262765231726, 9.013392445542314, 9.057200393889177, 9.100692790270713, 9.143875624068942, 9.186754702094884, 9.22933565620506, 9.271623950516632, 9.31362488824663, 9.355343618198855, 9.396785140920299, 9.43795431454737, 9.478855860360714, 9.519494368066162, 9.559874300818041, 9.600000000000001, 9.639875689777465, 9.679505481434818, 9.718893377509659, 9.758043275735478, 9.796958972803541], [0.0, 1.5561915061393068, 2.0534070030284, 2.4149689009669606, 2.7094867845324346, 2.9624500900582866, 3.186570569096427, 3.3892394789463296, 3.57518924632516, 3.7476588001088182, 3.9089763291017823, 4.060879611503095, 4.204705074158819, 4.341505759324996, 4.472128303973484, 4.597265060202111, 4.71749049303623, 4.833287276584354, 4.945065433621239, 5.053176653263411, 5.15792518927379, 5.259576284342062, 5.358362772074692, 5.4544903151291395, 5.548141607819491, 5.639479782188666, 5.728651194095415, 5.815787721493818, 5.9010086750843795, 5.9844223981229, 6.066127614856512, 6.14621457408839, 6.224766024557227, 6.301858051314204, 6.377560796491033, 6.451939083347533, 6.525052958952817, 6.596958168060459, 6.667706568513969, 6.7373464967365395, 6.805923090421544, 6.873478574374143, 6.940052514502856, 7.005682044179628, 7.070402066543531, 7.134245435790375, 7.197243120047037, 7.259424348058685, 7.3208167416060625, 7.381446435307882, 7.441338185241745, 7.500515467628852, 7.559000568667487, 7.616814666463294, 7.673977905886959, 7.730509467088875, 7.786427628313315, 7.841749823579255, 7.896492695729661, 7.95067214529424, 8.004303375561076, 8.057400934209342, 8.109978751817286, 8.162050177526423, 8.213628012113602, 8.2647245386967, 8.31535155127695, 8.365520381300625, 8.415241922404999, 8.464526653497352, 8.513384660301886, 8.561825655496511, 8.609858997550324, 8.657493708362422, 8.704738489793636, 8.751601739174639, 8.79809156386657, 8.844215794943727, 8.88998200006191, 8.935397495570715, 8.980469357923132, 9.025204434431474, 9.069609353414679, 9.113690533778362, 9.157454194065835, 9.200906361015146, 9.24405287765464, 9.286899410966965, 9.329451459149208, 9.37171435849479, 9.413693289920815, 9.4553932851629, 9.496819232657852, 9.537975883133145, 9.578867854920796, 9.619499639012014, 9.659875603867842, 9.700000000000001, 9.73987696433513, 9.779510524374821, 9.818904602162894, 9.858063018070737], [0.0, 1.5657976806082026, 2.0660824262323727, 2.4298762002987755, 2.7262121057224706, 2.980736921921992, 3.206240868493016, 3.4101608280368403, 3.59725843994563, 3.770792626595926, 3.9331059484089153, 4.0859469106699295, 4.230660189819889, 4.3683053284122595, 4.499734189602454, 4.625643399290736, 4.74661096860282, 4.863122551133788, 4.975590700677425, 5.084369277282947, 5.18976441283349, 5.292042987328509, 5.39143927162704, 5.488160197916266, 5.582389588259298, 5.6742915816926445, 5.7640134375113625, 5.851687847735562, 5.937434859555697, 6.0213634850168605, 6.103573057778549, 6.184154383738448, 6.26319072243281, 6.340758628576268, 6.416928677279092, 6.491766091946933, 6.56533129031191, 6.637680361232951, 6.708865482665511, 6.778935289407447, 6.847935197781435, 6.91590769324105, 6.982892585930187, 7.048927238440427, 7.114046769363531, 7.178284235700128, 7.241670796739447, 7.304235861652025, 7.3660072227243845, 7.427011175900952, 7.487272630075483, 7.546815206384941, 7.605661328597506, 7.663832305548609, 7.721348406460686, 7.778228929880788, 7.834492266882491, 7.890155959102778, 7.945236752118792, 7.999750644612208, 8.053712933719098, 8.10713825691963, 8.160040630783755, 8.212433486855565, 8.264329704929493, 8.315741643945557, 8.366681170707874, 8.417159686610317, 8.467188152535206, 8.516777112074804, 8.565936713211215, 8.61467672857749, 8.66300657441138, 8.710935328303028, 8.75847174582876, 8.805624276154916, 8.852401076688354, 8.898810026843607, 8.944858740990666, 8.990554580642032, 9.03590466593275, 9.080915886442728, 9.125594911406685, 9.169948199353335, 9.213982007212273, 9.257702398923845, 9.301115253584674, 9.34422627315898, 9.38704098978353, 9.42956477269201, 9.471802834782679, 9.513760238851418, 9.555441903510749, 9.596852608813778, 9.637997001600915, 9.678879600585688, 9.719504801195102, 9.75987688017875, 9.8, 9.839878213021708, 9.879515465497972, 9.918915601382857], [0.0, 1.5753647252978464, 2.078706217383076, 2.44472277625585, 2.742869298009768, 2.9989492642273032, 3.2258310429162664, 3.4309969561297295, 3.619237736939984, 3.79383221978271, 3.9571372781544776, 4.110912100731207, 4.2565095799447885, 4.394995732167804, 4.527227625450899, 4.653906142087865, 4.775612824860096, 4.892836294712613, 5.005991626148376, 5.115434841306215, 5.221473942539152, 5.324377440486993, 5.424381037406845, 5.521692929844312, 5.616498063017758, 5.7089615788553925, 5.7992316364085275, 5.887441738447283, 5.973712665652047, 6.05815409613296, 6.1408659704795, 6.221939649414599, 6.301458901191386, 6.379500748274817, 6.4561361969900295, 6.53143086925855, 6.605445551965647, 6.678236676673921, 6.749856740146836, 6.820354674341504, 6.889776173074944, 6.958163981387414, 7.025558152663321, 7.09199627778018, 7.157513689904811, 7.222143648016561, 7.2859175017883295, 7.348864840081077, 7.411013624992569, 7.472390313135802, 7.533019965598203, 7.592926347842198, 7.652132020645489, 7.710658423040774, 7.768525948095712, 7.825754012271729, 7.88236111901211, 7.9383649171334705, 7.993782254528654, 8.048629227631494, 8.102921227043767, 8.156672979680838, 8.209898587754093, 8.262611564874533, 8.314824869532305, 8.366550936180717, 8.417801704130222, 8.468588644437354, 8.518922784955572, 8.56881473369863, 8.61827470065294, 8.667312518162465, 8.7159376599983, 8.76415925921478, 8.811986124884923, 8.859426757799584, 8.90648936520749, 8.953181874666498, 8.999511947070502, 9.045486988910943, 9.091114163826987, 9.136400403493967, 9.181352417895711, 9.225976705022635, 9.270279560034254, 9.31426708392167, 9.357945191702868, 9.401319620181141, 9.444395935294686, 9.487179539083284, 9.529675676296062, 9.57188944066266, 9.613825780848384, 9.65548950611253, 9.696885291687764, 9.738017683897011, 9.7788911050234, 9.819509857947514, 9.859878130565434, 9.9, 9.939879436616984, 9.979520307857053], [0.0, 1.5848931924611134, 2.0912791051825463, 2.459509485849363, 2.7594593229224293, 3.017088168272581, 3.245342223199209, 3.451749065980082, 3.6411284060521605, 3.816778909618176, 3.9810717055349722, 4.135776622790051, 4.282254736676648, 4.421578511281855, 4.554610198563667, 4.682054920046205, 4.804497735925724, 4.922430222531833, 5.036269964912325, 5.146375138577377, 5.253055608807534, 5.356581510307667, 5.457189970961077, 5.555090446573472, 5.650469000989534, 5.743491774985175, 5.834307823739845, 5.923051457504459, 6.0098441874916615, 6.094796355190843, 6.17800850567412, 6.259572552252427, 6.3395727698444535, 6.418086646779356, 6.495185618858333, 6.570935704911838, 6.6453980594897395, 6.718629455476418, 6.790682707157798, 6.861607042452013, 6.9314484315514635, 7.000249878036358, 7.068051677550784, 7.134891648337663, 7.200805337273644, 7.265826204502337, 7.329985789312627, 7.393313859531326, 7.455838546382703, 7.517586466500456, 7.578582832551991, 7.638851553743224, 7.698415327308915, 7.757295721954028, 7.815513254092056, 7.8730874576233365, 7.930036947907745, 7.986379480509348, 8.042132005224119, 8.09731071584388, 8.151931096059227, 8.206007961860093, 8.259555500753955, 8.312587308087807, 8.365116420730187, 8.417155348343194, 8.46871610245124, 8.519810223492629, 8.570448806021906, 8.620642522214542, 8.670401643811235, 8.719736062626094, 8.768655309731553, 8.8171685734225, 8.865284716052917, 8.913012289830016, 8.960359551643409, 9.00733447700015, 9.053944773130434, 9.100197891323273, 9.146101038546528, 9.191661188401214, 9.236885091455962, 9.281779285003758, 9.326350102279886, 9.370603681176803, 9.414545972489002, 9.458182747718375, 9.501519606468252, 9.54456198345221, 9.587315155141827, 9.629784246075758, 9.671974234850909, 9.713889959815, 9.755536124478464, 9.7969173026623, 9.838037943397453, 9.878902375590144, 9.9195148124666, 9.959879355809816, 10.0, 10.039880635869725], [0.0, 1.59438362112266, 2.1038018008780828, 2.474237165562344, 2.7759831189568915, 3.0351546601742365, 3.264775513087816, 3.4724183315331594, 3.662931685635631, 3.839633994194808, 4.004910584519121, 4.160541883430569, 4.307897116417008, 4.4480551695401855, 4.581883457970819, 4.710091325539967, 4.833267335816907, 4.951906008717675, 5.066427429812574, 5.177191919386677, 5.284511198211075, 5.388657018572292, 5.489867928288593, 5.588354637398709, 5.684304323907982, 5.77788412345254, 5.869243983762543, 5.958519019346167, 6.04583146903196, 6.1312923350402935, 6.215002764512774, 6.29705522114236, 6.37753448449064, 6.456518506891204, 6.5340791519068, 6.6102828336923185, 6.685191072994475, 6.75886098265684, 6.831345693220224, 6.902694727382273, 6.972954330607461, 7.0421677639838265, 7.110375564448018, 7.177615776700701, 7.243924160475199, 7.309334376276327, 7.373878152251986, 7.4375854344803916, 7.500484522637151, 7.562602192737844, 7.623963808424736, 7.684593422073398, 7.744513866830893, 7.803746840556793, 7.8623129825180165, 7.920231943584983, 7.977522450587379, 8.03420236541058, 8.090288739346878, 8.145797863157423, 8.200745313250012, 8.255145994333551, 8.3090141788711, 8.36236354361935, 8.415207203512333, 8.4675577431207, 8.519427245894539, 8.570827321376944, 8.621769130557267, 8.672263409516562, 8.722320491503279, 8.771950327564264, 8.821162505844544, 8.869966269659024, 8.918370534429958, 8.966383903575652, 9.014014683428426, 9.061270897253122, 9.108160298431256, 9.154690382870573, 9.200868400694658, 9.246701367262839, 9.292196073566524, 9.337359096044375, 9.382196805855443, 9.426715377646227, 9.470920797844906, 9.51481887251345, 9.558415234785922, 9.601715351919268, 9.644724531980874, 9.687447930195411, 9.729890554971908, 9.772057273630375, 9.81395281784613, 9.855581788828466, 9.896948662249375, 9.938057792936807, 9.978913419346021, 10.01951966782172, 10.059880556662682, 10.100000000000001]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha = 0.5\", \"showscale\": false, \"type\": \"surface\", \"visible\": true, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.1, 0.1414213562373095, 0.17320508075688776, 0.2, 0.223606797749979, 0.24494897427831783, 0.2645751311064591, 0.282842712474619, 0.3, 0.31622776601683794, 0.33166247903554, 0.3464101615137755, 0.36055512754639896, 0.37416573867739417, 0.38729833462074165, 0.4, 0.41231056256176607, 0.4242640687119285, 0.43588989435406744, 0.447213595499958, 0.45825756949558405, 0.469041575982343, 0.479583152331272, 0.48989794855663565, 0.5, 0.5099019513592785, 0.5196152422706632, 0.5291502622129182, 0.5385164807134505, 0.5477225575051661, 0.5567764362830022, 0.565685424949238, 0.574456264653803, 0.5830951894845301, 0.5916079783099616, 0.6, 0.608276253029822, 0.6164414002968976, 0.6244997998398399, 0.6324555320336759, 0.6403124237432849, 0.6480740698407861, 0.6557438524302001, 0.66332495807108, 0.6708203932499369, 0.6782329983125268, 0.6855654600401044, 0.692820323027551, 0.7000000000000001, 0.7071067811865476, 0.7141428428542851, 0.7211102550927979, 0.7280109889280519, 0.7348469228349535, 0.7416198487095663, 0.7483314773547883, 0.754983443527075, 0.7615773105863909, 0.7681145747868608, 0.7745966692414833, 0.7810249675906654, 0.787400787401181, 0.7937253933193772, 0.8, 0.8062257748298549, 0.812403840463596, 0.8185352771872451, 0.8246211251235321, 0.8306623862918076, 0.8366600265340756, 0.8426149773176359, 0.848528137423857, 0.8544003745317531, 0.8602325267042626, 0.8660254037844387, 0.8717797887081349, 0.8774964387392122, 0.8831760866327848, 0.8888194417315589, 0.894427190999916, 0.9, 0.9055385138137417, 0.9110433579144299, 0.9165151389911681, 0.9219544457292888, 0.9273618495495705, 0.9327379053088816, 0.938083151964686, 0.9433981132056604, 0.9486832980505138, 0.9539392014169457, 0.959166304662544, 0.9643650760992956, 0.9695359714832659, 0.9746794344808963, 0.9797958971132713, 0.9848857801796106, 0.9899494936611666, 0.9949874371066201, 1.0, 1.0049875621120892], [0.0, 0.1414213562373095, 0.19999999999999998, 0.24494897427831783, 0.282842712474619, 0.31622776601683794, 0.34641016151377546, 0.3741657386773941, 0.39999999999999997, 0.4242640687119285, 0.4472135954999579, 0.469041575982343, 0.48989794855663565, 0.5099019513592785, 0.529150262212918, 0.5477225575051661, 0.565685424949238, 0.58309518948453, 0.6, 0.6164414002968976, 0.6324555320336759, 0.6480740698407861, 0.6633249580710799, 0.6782329983125268, 0.6928203230275509, 0.7071067811865476, 0.7211102550927979, 0.7348469228349535, 0.7483314773547882, 0.7615773105863909, 0.7745966692414833, 0.7874007874011811, 0.7999999999999999, 0.812403840463596, 0.8246211251235321, 0.8366600265340756, 0.848528137423857, 0.8602325267042626, 0.8717797887081348, 0.8831760866327847, 0.8944271909999159, 0.9055385138137417, 0.9165151389911681, 0.9273618495495702, 0.938083151964686, 0.9486832980505137, 0.9591663046625439, 0.9695359714832658, 0.9797958971132713, 0.9899494936611665, 1.0, 1.0099504938362078, 1.019803902718557, 1.0295630140987002, 1.0392304845413265, 1.0488088481701516, 1.058300524425836, 1.0677078252031311, 1.0770329614269007, 1.0862780491200215, 1.0954451150103321, 1.104536101718726, 1.1135528725660042, 1.1224972160321824, 1.131370849898476, 1.1401754250991378, 1.1489125293076057, 1.1575836902790224, 1.16619037896906, 1.174734012447073, 1.1832159566199232, 1.1916375287812984, 1.2, 1.2083045973594573, 1.2165525060596438, 1.224744871391589, 1.2328828005937953, 1.2409673645990857, 1.2489995996796797, 1.2569805089976536, 1.2649110640673518, 1.2727922061357855, 1.2806248474865698, 1.2884098726725124, 1.2961481396815722, 1.3038404810405297, 1.3114877048604001, 1.3190905958272918, 1.3266499161421599, 1.3341664064126333, 1.3416407864998738, 1.349073756323204, 1.3564659966250536, 1.3638181696985856, 1.3711309200802089, 1.378404875209022, 1.3856406460551018, 1.392838827718412, 1.4, 1.407124727947029, 1.4142135623730951, 1.4212670403551897], [0.0, 0.17320508075688776, 0.24494897427831783, 0.3000000000000001, 0.3464101615137755, 0.38729833462074176, 0.42426406871192857, 0.45825756949558405, 0.48989794855663565, 0.5196152422706632, 0.5477225575051662, 0.574456264653803, 0.6000000000000002, 0.6244997998398399, 0.6480740698407861, 0.6708203932499369, 0.692820323027551, 0.7141428428542851, 0.7348469228349536, 0.7549834435270751, 0.7745966692414835, 0.7937253933193773, 0.8124038404635961, 0.8306623862918077, 0.8485281374238571, 0.8660254037844388, 0.8831760866327849, 0.9000000000000001, 0.9165151389911681, 0.9327379053088817, 0.9486832980505139, 0.9643650760992957, 0.9797958971132713, 0.9949874371066202, 1.009950493836208, 1.02469507659596, 1.0392304845413265, 1.053565375285274, 1.0677078252031313, 1.081665382639197, 1.0954451150103324, 1.1090536506409419, 1.1224972160321827, 1.1357816691600549, 1.148912529307606, 1.161895003862225, 1.1747340124470733, 1.187434208703792, 1.2000000000000004, 1.2124355652982142, 1.2247448713915892, 1.2369316876852985, 1.2489995996796799, 1.2609520212918495, 1.2727922061357857, 1.2845232578665131, 1.2961481396815722, 1.3076696830622023, 1.3190905958272923, 1.3304134695650072, 1.3416407864998738, 1.3527749258468684, 1.3638181696985856, 1.3747727084867523, 1.385640646055102, 1.3964240043768943, 1.4071247279470291, 1.4177446878757827, 1.4282856857085702, 1.4387494569938162, 1.4491376746189442, 1.4594519519326425, 1.4696938456699071, 1.4798648586948744, 1.489966442575134, 1.5000000000000002, 1.5099668870541503, 1.5198684153570665, 1.5297058540778359, 1.5394804318340656, 1.549193338482967, 1.5588457268119897, 1.5684387141358125, 1.5779733838059502, 1.5874507866387546, 1.5968719422671316, 1.6062378404209012, 1.6155494421403516, 1.6248076809271923, 1.6340134638368193, 1.6431676725154984, 1.6522711641858308, 1.6613247725836153, 1.670329308849007, 1.6792855623746668, 1.6881943016134133, 1.6970562748477143, 1.7058722109231985, 1.7146428199482249, 1.7233687939614089, 1.7320508075688776, 1.7406895185529214], [0.0, 0.2, 0.282842712474619, 0.3464101615137755, 0.4, 0.447213595499958, 0.48989794855663565, 0.5291502622129182, 0.565685424949238, 0.6, 0.6324555320336759, 0.66332495807108, 0.692820323027551, 0.7211102550927979, 0.7483314773547883, 0.7745966692414833, 0.8, 0.8246211251235321, 0.848528137423857, 0.8717797887081349, 0.894427190999916, 0.9165151389911681, 0.938083151964686, 0.959166304662544, 0.9797958971132713, 1.0, 1.019803902718557, 1.0392304845413265, 1.0583005244258363, 1.077032961426901, 1.0954451150103321, 1.1135528725660044, 1.131370849898476, 1.148912529307606, 1.1661903789690602, 1.1832159566199232, 1.2, 1.216552506059644, 1.2328828005937953, 1.2489995996796799, 1.2649110640673518, 1.2806248474865698, 1.2961481396815722, 1.3114877048604001, 1.32664991614216, 1.3416407864998738, 1.3564659966250536, 1.3711309200802089, 1.385640646055102, 1.4000000000000001, 1.4142135623730951, 1.4282856857085702, 1.4422205101855958, 1.4560219778561039, 1.469693845669907, 1.4832396974191326, 1.4966629547095767, 1.50996688705415, 1.5231546211727818, 1.5362291495737217, 1.5491933384829666, 1.5620499351813308, 1.574801574802362, 1.5874507866387544, 1.6, 1.6124515496597098, 1.624807680927192, 1.6370705543744901, 1.6492422502470643, 1.661324772583615, 1.6733200530681511, 1.6852299546352718, 1.697056274847714, 1.7088007490635062, 1.7204650534085253, 1.7320508075688774, 1.7435595774162698, 1.7549928774784245, 1.7663521732655696, 1.7776388834631178, 1.788854381999832, 1.8, 1.8110770276274835, 1.8220867158288598, 1.8330302779823362, 1.8439088914585775, 1.854723699099141, 1.8654758106177631, 1.876166303929372, 1.8867962264113207, 1.8973665961010275, 1.9078784028338913, 1.918332609325088, 1.9287301521985911, 1.9390719429665317, 1.9493588689617927, 1.9595917942265426, 1.9697715603592212, 1.9798989873223332, 1.9899748742132402, 2.0, 2.0099751242241783], [0.0, 0.223606797749979, 0.31622776601683794, 0.38729833462074176, 0.447213595499958, 0.5000000000000001, 0.5477225575051662, 0.5916079783099617, 0.6324555320336759, 0.6708203932499369, 0.7071067811865476, 0.7416198487095664, 0.7745966692414835, 0.806225774829855, 0.8366600265340756, 0.8660254037844386, 0.894427190999916, 0.9219544457292888, 0.9486832980505139, 0.9746794344808966, 1.0000000000000002, 1.02469507659596, 1.0488088481701516, 1.072380529476361, 1.0954451150103324, 1.118033988749895, 1.140175425099138, 1.1618950038622253, 1.1832159566199234, 1.2041594578792296, 1.2247448713915892, 1.2449899597988734, 1.2649110640673518, 1.2845232578665131, 1.30384048104053, 1.3228756555322954, 1.3416407864998738, 1.3601470508735445, 1.3784048752090223, 1.3964240043768943, 1.4142135623730951, 1.4317821063276355, 1.4491376746189442, 1.466287829861518, 1.4832396974191329, 1.5, 1.5165750888103102, 1.5329709716755893, 1.549193338482967, 1.565247584249853, 1.5811388300841898, 1.5968719422671316, 1.61245154965971, 1.627882059609971, 1.6431676725154984, 1.6583123951777001, 1.6733200530681511, 1.6881943016134133, 1.7029386365926404, 1.7175564037317668, 1.7320508075688772, 1.746424919657298, 1.760681686165901, 1.7748239349298849, 1.788854381999832, 1.8027756377319946, 1.8165902124584952, 1.8303005217723127, 1.8439088914585775, 1.8574175621006712, 1.8708286933869709, 1.8841443681416774, 1.8973665961010278, 1.91049731745428, 1.9235384061671346, 1.9364916731037085, 1.9493588689617931, 1.9621416870348585, 1.9748417658131503, 1.9874606914351793, 2.0000000000000004, 2.012461179749811, 2.024845673131659, 2.0371548787463363, 2.04939015319192, 2.0615528128088303, 2.0736441353327724, 2.0856653614614213, 2.0976176963403033, 2.1095023109728985, 2.121320343559643, 2.1330729007701543, 2.144761058952722, 2.1563858652847827, 2.1679483388678804, 2.179449471770337, 2.1908902300206647, 2.2022715545545246, 2.2135943621178655, 2.224859546128699, 2.23606797749979, 2.2472205054244236], [0.0, 0.24494897427831783, 0.34641016151377546, 0.42426406871192857, 0.48989794855663565, 0.5477225575051662, 0.6000000000000001, 0.6480740698407861, 0.6928203230275509, 0.7348469228349535, 0.7745966692414834, 0.8124038404635961, 0.8485281374238571, 0.8831760866327848, 0.916515138991168, 0.9486832980505138, 0.9797958971132713, 1.0099504938362078, 1.0392304845413265, 1.0677078252031313, 1.0954451150103324, 1.1224972160321824, 1.148912529307606, 1.174734012447073, 1.2000000000000002, 1.2247448713915892, 1.2489995996796799, 1.2727922061357857, 1.2961481396815722, 1.319090595827292, 1.3416407864998738, 1.3638181696985856, 1.3856406460551018, 1.4071247279470291, 1.4282856857085702, 1.449137674618944, 1.469693845669907, 1.489966442575134, 1.50996688705415, 1.5297058540778357, 1.5491933384829668, 1.5684387141358125, 1.5874507866387546, 1.606237840420901, 1.6248076809271923, 1.6431676725154982, 1.661324772583615, 1.6792855623746665, 1.6970562748477143, 1.7146428199482247, 1.7320508075688774, 1.7492855684535904, 1.7663521732655696, 1.7832554500127011, 1.8, 1.8165902124584952, 1.833030277982336, 1.849324200890693, 1.8654758106177631, 1.8814887722226779, 1.8973665961010275, 1.9131126469708992, 1.928730152198591, 1.9442222095223582, 1.9595917942265426, 1.9748417658131499, 1.98997487421324, 2.004993765576342, 2.0199009876724157, 2.0346989949375804, 2.04939015319192, 2.0639767440550294, 2.078460969082653, 2.092844953645635, 2.1071307505705477, 2.121320343559643, 2.1354156504062627, 2.149418526020468, 2.1633307652783937, 2.177154105707724, 2.1908902300206647, 2.2045407685048604, 2.2181073012818837, 2.2315913604421396, 2.244994432064365, 2.2583179581272432, 2.2715633383201097, 2.2847319317591728, 2.297825058615212, 2.3108440016582685, 2.32379000772445, 2.3366642891095846, 2.349468024894146, 2.3622023622035435, 2.374868417407584, 2.3874672772626644, 2.4000000000000004, 2.412467616362964, 2.4248711305964283, 2.4372115213907883, 2.4494897427831783, 2.4617067250182347], [0.0, 0.2645751311064591, 0.3741657386773941, 0.45825756949558405, 0.5291502622129182, 0.5916079783099617, 0.6480740698407861, 0.7000000000000001, 0.7483314773547882, 0.7937253933193772, 0.8366600265340756, 0.8774964387392122, 0.9165151389911681, 0.9539392014169458, 0.9899494936611666, 1.0246950765959597, 1.0583005244258363, 1.0908712114635715, 1.1224972160321824, 1.1532562594670797, 1.1832159566199234, 1.2124355652982142, 1.2409673645990857, 1.2688577540449522, 1.2961481396815722, 1.3228756555322954, 1.3490737563232043, 1.374772708486752, 1.4000000000000001, 1.4247806848775009, 1.4491376746189437, 1.4730919862656235, 1.4966629547095764, 1.5198684153570665, 1.5427248620541514, 1.5652475842498528, 1.5874507866387544, 1.6093476939431082, 1.6309506430300091, 1.6522711641858308, 1.6733200530681511, 1.6941074346097418, 1.7146428199482249, 1.7349351572897471, 1.7549928774784245, 1.7748239349298847, 1.7944358444926363, 1.8138357147217055, 1.8330302779823362, 1.8520259177452134, 1.8708286933869709, 1.8894443627691186, 1.9078784028338915, 1.9261360284258224, 1.9442222095223582, 1.9621416870348585, 1.9798989873223332, 1.997498435543818, 2.0149441679609885, 2.0322401432901573, 2.0493901531919194, 2.0663978319771825, 2.083266665599966, 2.1, 2.1166010488516727, 2.133072900770154, 2.149418526020468, 2.1656407827707715, 2.181742422927143, 2.1977260975835913, 2.2135943621178655, 2.2293496809607953, 2.244994432064365, 2.260530911091463, 2.2759613353482084, 2.29128784747792, 2.3065125189341593, 2.32163735324878, 2.336664289109585, 2.3515952032609695, 2.366431913239847, 2.3811761799581315, 2.395829710142188, 2.41039415863879, 2.4248711305964283, 2.4392621835300936, 2.4535688292770597, 2.4677925358506134, 2.4819347291981715, 2.495996794869737, 2.5099800796022267, 2.5238858928247927, 2.5377155080899043, 2.551470164434615, 2.5651510676761324, 2.578759391645525, 2.5922962793631443, 2.6057628441590768, 2.619160170741759, 2.632489316217637, 2.6457513110645907, 2.6589471600616665], [0.0, 0.282842712474619, 0.39999999999999997, 0.48989794855663565, 0.565685424949238, 0.6324555320336759, 0.6928203230275509, 0.7483314773547882, 0.7999999999999999, 0.848528137423857, 0.8944271909999159, 0.938083151964686, 0.9797958971132713, 1.019803902718557, 1.058300524425836, 1.0954451150103321, 1.131370849898476, 1.16619037896906, 1.2, 1.2328828005937953, 1.2649110640673518, 1.2961481396815722, 1.3266499161421599, 1.3564659966250536, 1.3856406460551018, 1.4142135623730951, 1.4422205101855958, 1.469693845669907, 1.4966629547095764, 1.5231546211727818, 1.5491933384829666, 1.5748015748023623, 1.5999999999999999, 1.624807680927192, 1.6492422502470643, 1.6733200530681511, 1.697056274847714, 1.7204650534085253, 1.7435595774162695, 1.7663521732655694, 1.7888543819998317, 1.8110770276274835, 1.8330302779823362, 1.8547236990991405, 1.876166303929372, 1.8973665961010273, 1.9183326093250879, 1.9390719429665315, 1.9595917942265426, 1.979898987322333, 2.0, 2.0199009876724157, 2.039607805437114, 2.0591260281974004, 2.078460969082653, 2.0976176963403033, 2.116601048851672, 2.1354156504062622, 2.1540659228538015, 2.172556098240043, 2.1908902300206643, 2.209072203437452, 2.2271057451320084, 2.244994432064365, 2.262741699796952, 2.2803508501982757, 2.2978250586152114, 2.315167380558045, 2.33238075793812, 2.349468024894146, 2.3664319132398464, 2.3832750575625967, 2.4, 2.4166091947189146, 2.4331050121192876, 2.449489742783178, 2.4657656011875906, 2.4819347291981715, 2.4979991993593593, 2.513961017995307, 2.5298221281347035, 2.545584412271571, 2.5612496949731396, 2.576819745345025, 2.5922962793631443, 2.6076809620810595, 2.6229754097208002, 2.6381811916545836, 2.6532998322843198, 2.6683328128252666, 2.6832815729997477, 2.698147512646408, 2.7129319932501073, 2.727636339397171, 2.7422618401604177, 2.756809750418044, 2.7712812921102037, 2.785677655436824, 2.8, 2.814249455894058, 2.8284271247461903, 2.8425340807103794], [0.0, 0.3, 0.4242640687119285, 0.5196152422706632, 0.6, 0.6708203932499369, 0.7348469228349535, 0.7937253933193772, 0.848528137423857, 0.8999999999999999, 0.9486832980505138, 0.99498743710662, 1.0392304845413265, 1.0816653826391969, 1.1224972160321824, 1.1618950038622249, 1.2, 1.236931687685298, 1.2727922061357855, 1.307669683062202, 1.3416407864998738, 1.374772708486752, 1.407124727947029, 1.438749456993816, 1.469693845669907, 1.5, 1.5297058540778354, 1.5588457268119895, 1.5874507866387544, 1.6155494421403513, 1.6431676725154982, 1.6703293088490065, 1.697056274847714, 1.7233687939614086, 1.7492855684535902, 1.7748239349298847, 1.7999999999999998, 1.8248287590894658, 1.849324200890693, 1.8734993995195195, 1.8973665961010275, 1.9209372712298547, 1.9442222095223582, 1.9672315572906, 1.98997487421324, 2.0124611797498106, 2.0346989949375804, 2.056696380120313, 2.078460969082653, 2.1, 2.1213203435596424, 2.142428528562855, 2.1633307652783937, 2.1840329667841556, 2.2045407685048604, 2.224859546128699, 2.244994432064365, 2.264950330581225, 2.2847319317591723, 2.3043437243605824, 2.3237900077244498, 2.3430749027719964, 2.362202362203543, 2.3811761799581315, 2.4, 2.4186773244895647, 2.437211521390788, 2.455605831561735, 2.473863375370596, 2.4919871588754225, 2.5099800796022267, 2.5278449319529073, 2.545584412271571, 2.563201123595259, 2.580697580112788, 2.598076211353316, 2.615339366124404, 2.6324893162176366, 2.6495282598983545, 2.6664583251946765, 2.6832815729997477, 2.7, 2.716615541441225, 2.7331300737432893, 2.749545416973504, 2.765863337187866, 2.7820855486487113, 2.7982137159266447, 2.814249455894058, 2.830194339616981, 2.846049894151541, 2.8618176042508368, 2.877498913987632, 2.8930952282978866, 2.9086079144497976, 2.9240383034426887, 2.939387691339814, 2.9546573405388314, 2.9698484809834995, 2.98496231131986, 3.0, 3.0149626863362675], [0.0, 0.31622776601683794, 0.4472135954999579, 0.5477225575051662, 0.6324555320336759, 0.7071067811865476, 0.7745966692414834, 0.8366600265340756, 0.8944271909999159, 0.9486832980505138, 1.0, 1.0488088481701516, 1.0954451150103324, 1.140175425099138, 1.1832159566199232, 1.224744871391589, 1.2649110640673518, 1.3038404810405297, 1.3416407864998738, 1.3784048752090223, 1.4142135623730951, 1.449137674618944, 1.4832396974191326, 1.5165750888103102, 1.5491933384829668, 1.5811388300841898, 1.61245154965971, 1.6431676725154984, 1.6733200530681511, 1.7029386365926402, 1.7320508075688772, 1.760681686165901, 1.7888543819998317, 1.8165902124584952, 1.8439088914585775, 1.8708286933869707, 1.8973665961010275, 1.9235384061671346, 1.949358868961793, 1.97484176581315, 2.0, 2.024845673131659, 2.04939015319192, 2.073644135332772, 2.0976176963403033, 2.1213203435596424, 2.1447610589527217, 2.16794833886788, 2.1908902300206647, 2.2135943621178655, 2.23606797749979, 2.2583179581272432, 2.280350850198276, 2.302172886644268, 2.32379000772445, 2.345207879911715, 2.3664319132398464, 2.3874672772626644, 2.4083189157584592, 2.4289915602982237, 2.449489742783178, 2.4698178070456938, 2.4899799195977463, 2.5099800796022267, 2.5298221281347035, 2.5495097567963922, 2.569046515733026, 2.588435821108957, 2.6076809620810595, 2.6267851073127395, 2.6457513110645907, 2.6645825188948455, 2.6832815729997477, 2.701851217221259, 2.7202941017470885, 2.7386127875258306, 2.7568097504180447, 2.7748873851023217, 2.7928480087537886, 2.8106938645110393, 2.8284271247461903, 2.8460498941515415, 2.863564212655271, 2.8809720581775866, 2.898275349237888, 2.9154759474226504, 2.932575659723036, 2.9495762407505253, 2.9664793948382653, 2.9832867780352594, 3.0, 3.0166206257996713, 3.0331501776206204, 3.0495901363953815, 3.0659419433511785, 3.082207001484488, 3.0983866769659336, 3.1144823004794877, 3.1304951684997055, 3.146426544510455, 3.1622776601683795, 3.178049716414141], [0.0, 0.33166247903554, 0.469041575982343, 0.574456264653803, 0.66332495807108, 0.7416198487095664, 0.8124038404635961, 0.8774964387392122, 0.938083151964686, 0.99498743710662, 1.0488088481701516, 1.1, 1.148912529307606, 1.1958260743101399, 1.2409673645990857, 1.284523257866513, 1.32664991614216, 1.3674794331177345, 1.407124727947029, 1.4456832294800963, 1.4832396974191329, 1.5198684153570665, 1.5556349186104048, 1.5905973720586868, 1.6248076809271923, 1.6583123951777001, 1.6911534525287766, 1.7233687939614089, 1.7549928774784245, 1.7860571099491753, 1.816590212458495, 1.846618531261939, 1.876166303929372, 1.9052558883257653, 1.9339079605813718, 1.9621416870348585, 1.98997487421324, 2.017424100183202, 2.0445048300260877, 2.0712315177207983, 2.0976176963403033, 2.1236760581595306, 2.149418526020468, 2.1748563170931545, 2.2, 2.224859546128699, 2.249444375840399, 2.273763400180415, 2.297825058615212, 2.32163735324878, 2.345207879911715, 2.368543856465403, 2.3916521486202797, 2.4145392935299275, 2.4372115213907883, 2.459674775249769, 2.4819347291981715, 2.503996805109783, 2.525866188063018, 2.5475478405713994, 2.569046515733026, 2.5903667693977237, 2.6115129714401193, 2.632489316217637, 2.65329983228432, 2.6739483914241875, 2.6944387170614963, 2.714774392099646, 2.734958866235469, 2.7549954627911823, 2.774887385102322, 2.7946377224964243, 2.814249455894058, 2.833725463060951, 2.8530685235374214, 2.8722813232690148, 2.8913664589601926, 2.91032644217105, 2.9291637031753623, 2.9478805945967355, 2.9664793948382657, 2.9849623113198605, 3.003331483536242, 3.0215889859476257, 3.039736830714133, 3.0577769702841313, 3.07571129984594, 3.093541659651604, 3.1112698372208096, 3.1288975694324033, 3.146426544510455, 3.1638584039112754, 3.1811947441173736, 3.1984371183438958, 3.2155870381627056, 3.2326459750489227, 3.2496153618543846, 3.2664965942122155, 3.283291031876401, 3.3000000000000007, 3.3166247903554003, 3.333166662499792], [0.0, 0.3464101615137755, 0.48989794855663565, 0.6000000000000002, 0.692820323027551, 0.7745966692414835, 0.8485281374238571, 0.9165151389911681, 0.9797958971132713, 1.0392304845413265, 1.0954451150103324, 1.148912529307606, 1.2000000000000004, 1.2489995996796799, 1.2961481396815722, 1.3416407864998738, 1.385640646055102, 1.4282856857085702, 1.4696938456699071, 1.5099668870541503, 1.549193338482967, 1.5874507866387546, 1.6248076809271923, 1.6613247725836153, 1.6970562748477143, 1.7320508075688776, 1.7663521732655698, 1.8000000000000003, 1.8330302779823362, 1.8654758106177634, 1.8973665961010278, 1.9287301521985913, 1.9595917942265426, 1.9899748742132404, 2.019900987672416, 2.04939015319192, 2.078460969082653, 2.107130750570548, 2.1354156504062627, 2.163330765278394, 2.1908902300206647, 2.2181073012818837, 2.2449944320643653, 2.2715633383201097, 2.297825058615212, 2.32379000772445, 2.3494680248941466, 2.374868417407584, 2.400000000000001, 2.4248711305964283, 2.4494897427831783, 2.473863375370597, 2.4979991993593598, 2.521904042583699, 2.5455844122715714, 2.5690465157330262, 2.5922962793631443, 2.6153393661244047, 2.6381811916545845, 2.6608269391300143, 2.6832815729997477, 2.705549851693737, 2.727636339397171, 2.7495454169735045, 2.771281292110204, 2.7928480087537886, 2.8142494558940583, 2.8354893757515653, 2.8565713714171403, 2.8774989139876324, 2.8982753492378883, 2.918903903865285, 2.9393876913398143, 2.9597297173897488, 2.979932885150268, 3.0000000000000004, 3.0199337741083006, 3.039736830714133, 3.0594117081556718, 3.078960863668131, 3.098386676965934, 3.1176914536239795, 3.136877428271625, 3.1559467676119004, 3.174901573277509, 3.193743884534263, 3.2124756808418025, 3.231098884280703, 3.2496153618543846, 3.2680269276736387, 3.286335345030997, 3.3045423283716615, 3.3226495451672307, 3.340658617698014, 3.3585711247493335, 3.3763886032268267, 3.3941125496954285, 3.411744421846397, 3.4292856398964497, 3.4467375879228177, 3.4641016151377553, 3.481379037105843], [0.0, 0.36055512754639896, 0.5099019513592785, 0.6244997998398399, 0.7211102550927979, 0.806225774829855, 0.8831760866327848, 0.9539392014169458, 1.019803902718557, 1.0816653826391969, 1.140175425099138, 1.1958260743101399, 1.2489995996796799, 1.3000000000000003, 1.3490737563232043, 1.396424004376894, 1.4422205101855958, 1.4866068747318506, 1.5297058540778357, 1.5716233645501714, 1.61245154965971, 1.6522711641858308, 1.6911534525287764, 1.7291616465790585, 1.7663521732655696, 1.8027756377319948, 1.8384776310850237, 1.8734993995195197, 1.9078784028338915, 1.94164878389476, 1.9748417658131499, 2.0074859899884734, 2.039607805437114, 2.0712315177207983, 2.102379604162864, 2.1330729007701543, 2.1633307652783937, 2.193171219946131, 2.222611077089287, 2.2516660498395407, 2.280350850198276, 2.3086792761230397, 2.336664289109585, 2.364318083507378, 2.3916521486202797, 2.4186773244895647, 2.445403852127497, 2.471841418861655, 2.4979991993593598, 2.5238858928247927, 2.5495097567963927, 2.574878637916747, 2.6000000000000005, 2.624880949681338, 2.6495282598983545, 2.673948391424188, 2.6981475126464085, 2.72213151776324, 2.7459060435491964, 2.7694764848252458, 2.792848008753788, 2.816025568065745, 2.839013913315678, 2.861817604250837, 2.8844410203711917, 2.9068883707497264, 2.9291637031753623, 2.951270912674741, 2.973213749463701, 2.994995826374388, 3.0166206257996717, 3.0380915061926625, 3.0594117081556713, 3.0805843601498726, 3.1016124838541645, 3.122498999199199, 3.1432467291003428, 3.1638584039112754, 3.1843366656181322, 3.204684071792413, 3.22490309931942, 3.2449961479175906, 3.264965543462902, 3.2848135411313684, 3.3045423283716615, 3.3241540277189325, 3.343650699460098, 3.363034344160048, 3.3823069050575527, 3.4014702703389896, 3.420526275297414, 3.439476704383968, 3.458323293158117, 3.4770677301427426, 3.4957116585897072, 3.5142566781611158, 3.532704346531139, 3.5510561809129415, 3.5693136595149495, 3.58747822293042, 3.6055512754639896, 3.6235341863986883], [0.0, 0.37416573867739417, 0.529150262212918, 0.6480740698407861, 0.7483314773547883, 0.8366600265340756, 0.916515138991168, 0.9899494936611666, 1.058300524425836, 1.1224972160321824, 1.1832159566199232, 1.2409673645990857, 1.2961481396815722, 1.3490737563232043, 1.4, 1.4491376746189437, 1.4966629547095767, 1.5427248620541512, 1.5874507866387544, 1.6309506430300091, 1.6733200530681511, 1.7146428199482247, 1.7549928774784245, 1.7944358444926363, 1.833030277982336, 1.8708286933869707, 1.9078784028338913, 1.9442222095223582, 1.9798989873223332, 2.0149441679609885, 2.0493901531919194, 2.083266665599966, 2.116601048851672, 2.149418526020468, 2.181742422927143, 2.2135943621178655, 2.244994432064365, 2.2759613353482084, 2.3065125189341593, 2.3366642891095846, 2.3664319132398464, 2.395829710142188, 2.4248711305964283, 2.453568829277059, 2.4819347291981715, 2.5099800796022262, 2.5377155080899043, 2.565151067676132, 2.5922962793631443, 2.619160170741759, 2.6457513110645907, 2.672077843177478, 2.6981475126464085, 2.7239676943752476, 2.749545416973504, 2.7748873851023217, 2.8, 2.824889378365107, 2.8495613697550017, 2.8740215726399825, 2.8982753492378874, 2.9223278392404914, 2.9461839725312466, 2.9698484809834995, 2.9933259094191533, 3.016620625799671, 3.0397368307141326, 3.062678566222711, 3.0854497241083023, 3.1080540535840107, 3.1304951684997055, 3.152776554086889, 3.1749015732775088, 3.196873472629156, 3.218695387886216, 3.24037034920393, 3.2619012860600183, 3.283291031876401, 3.3045423283716615, 3.3256578296631782, 3.3466401061363023, 3.3674916480965473, 3.3882148692194836, 3.408812109811862, 3.4292856398964493, 3.449637662132068, 3.4698703145794947, 3.4899856733230297, 3.509985754956849, 3.529872518944558, 3.5496478698597693, 3.5693136595149495, 3.5888716889852725, 3.6083237105337433, 3.627671429443411, 3.6469165057620936, 3.666060555964672, 3.685105154537656, 3.704051835490427, 3.722902093797257, 3.7416573867739413, 3.7603191353926335], [0.0, 0.38729833462074165, 0.5477225575051661, 0.6708203932499369, 0.7745966692414833, 0.8660254037844386, 0.9486832980505138, 1.0246950765959597, 1.0954451150103321, 1.1618950038622249, 1.224744871391589, 1.284523257866513, 1.3416407864998738, 1.396424004376894, 1.4491376746189437, 1.4999999999999998, 1.5491933384829666, 1.5968719422671311, 1.6431676725154982, 1.6881943016134133, 1.7320508075688772, 1.7748239349298847, 1.816590212458495, 1.857417562100671, 1.8973665961010275, 1.9364916731037083, 1.9748417658131499, 2.0124611797498106, 2.0493901531919194, 2.085665361461421, 2.1213203435596424, 2.1563858652847823, 2.1908902300206643, 2.224859546128699, 2.258317958127243, 2.29128784747792, 2.3237900077244498, 2.355843797877949, 2.3874672772626644, 2.4186773244895647, 2.449489742783178, 2.479919353527449, 2.5099800796022267, 2.5396850198400585, 2.569046515733026, 2.5980762113533156, 2.626785107312739, 2.6551836094703507, 2.6832815729997477, 2.7110883423451915, 2.7386127875258306, 2.765863337187866, 2.792848008753788, 2.819574435974337, 2.846049894151541, 2.8722813232690143, 2.8982753492378874, 2.924038303442689, 2.9495762407505253, 2.974894956128703, 2.9999999999999996, 3.0248966924508345, 3.049590136395381, 3.074085229787879, 3.098386676965933, 3.1224989991991987, 3.1464265445104544, 3.1701734968294715, 3.1937438845342623, 3.217141588429082, 3.24037034920393, 3.2634337744161437, 3.2863353450309964, 3.309078421554859, 3.3316662497915357, 3.3541019662496843, 3.3763886032268267, 3.3985290935932855, 3.420526275297414, 3.442382895611701, 3.4641016151377544, 3.485685011586675, 3.5071355833500366, 3.5284557528754696, 3.5496478698597693, 3.5707142142714248, 3.591656999213594, 3.6124783736376886, 3.63318042491699, 3.6537651812890215, 3.674234614174767, 3.694590640382233, 3.714835124201342, 3.7349698793966195, 3.7549966711037173, 3.7749172176353745, 3.794733192202055, 3.8144462245521304, 3.8340579025361623, 3.853569773599539, 3.8729833462074166, 3.892300091205713], [0.0, 0.4, 0.565685424949238, 0.692820323027551, 0.8, 0.894427190999916, 0.9797958971132713, 1.0583005244258363, 1.131370849898476, 1.2, 1.2649110640673518, 1.32664991614216, 1.385640646055102, 1.4422205101855958, 1.4966629547095767, 1.5491933384829666, 1.6, 1.6492422502470643, 1.697056274847714, 1.7435595774162698, 1.788854381999832, 1.8330302779823362, 1.876166303929372, 1.918332609325088, 1.9595917942265426, 2.0, 2.039607805437114, 2.078460969082653, 2.1166010488516727, 2.154065922853802, 2.1908902300206643, 2.227105745132009, 2.262741699796952, 2.297825058615212, 2.3323807579381204, 2.3664319132398464, 2.4, 2.433105012119288, 2.4657656011875906, 2.4979991993593598, 2.5298221281347035, 2.5612496949731396, 2.5922962793631443, 2.6229754097208002, 2.65329983228432, 2.6832815729997477, 2.7129319932501073, 2.7422618401604177, 2.771281292110204, 2.8000000000000003, 2.8284271247461903, 2.8565713714171403, 2.8844410203711917, 2.9120439557122078, 2.939387691339814, 2.9664793948382653, 2.9933259094191533, 3.0199337741083, 3.0463092423455636, 3.0724582991474434, 3.098386676965933, 3.1240998703626617, 3.149603149604724, 3.1749015732775088, 3.2, 3.2249030993194197, 3.249615361854384, 3.2741411087489802, 3.2984845004941286, 3.32264954516723, 3.3466401061363023, 3.3704599092705436, 3.394112549695428, 3.4176014981270124, 3.4409301068170506, 3.464101615137755, 3.4871191548325395, 3.509985754956849, 3.532704346531139, 3.5552777669262356, 3.577708763999664, 3.6, 3.622154055254967, 3.6441734316577197, 3.6660605559646724, 3.687817782917155, 3.709447398198282, 3.7309516212355263, 3.752332607858744, 3.7735924528226414, 3.794733192202055, 3.8157568056677826, 3.836665218650176, 3.8574603043971822, 3.8781438859330635, 3.8987177379235853, 3.9191835884530852, 3.9395431207184424, 3.9597979746446663, 3.9799497484264803, 4.0, 4.019950248448357], [0.0, 0.41231056256176607, 0.58309518948453, 0.7141428428542851, 0.8246211251235321, 0.9219544457292888, 1.0099504938362078, 1.0908712114635715, 1.16619037896906, 1.236931687685298, 1.3038404810405297, 1.3674794331177345, 1.4282856857085702, 1.4866068747318506, 1.5427248620541512, 1.5968719422671311, 1.6492422502470643, 1.7, 1.7492855684535902, 1.797220075561143, 1.8439088914585775, 1.8894443627691184, 1.9339079605813716, 1.977371993328519, 2.0199009876724157, 2.0615528128088303, 2.102379604162864, 2.142428528562855, 2.181742422927143, 2.220360331117452, 2.258317958127243, 2.2956480566497994, 2.33238075793812, 2.3685438564654024, 2.4041630560342617, 2.4392621835300936, 2.473863375370596, 2.5079872407968904, 2.541653005427767, 2.574878637916747, 2.6076809620810595, 2.6400757564888173, 2.672077843177478, 2.7037011669191546, 2.734958866235469, 2.765863337187866, 2.7964262908219126, 2.826658805020514, 2.8565713714171403, 2.8861739379323623, 2.9154759474226504, 2.944486372867092, 2.973213749463701, 3.001666203960727, 3.0298514815086235, 3.0577769702841313, 3.0854497241083023, 3.1128764832546763, 3.1400636936215167, 3.167017524422623, 3.1937438845342623, 3.2202484376209237, 3.246536616149585, 3.2726136343907144, 3.2984845004941286, 3.324154027718932, 3.3496268448888453, 3.374907406137241, 3.4, 3.424908757908742, 3.4496376621320683, 3.4741905532080417, 3.4985711369071804, 3.522782990761707, 3.5468295701936396, 3.570714214271425, 3.594440151122286, 3.6180105030251086, 3.6414282912066254, 3.664696440361739, 3.687817782917155, 3.710795063055895, 3.733630940518894, 3.7563279941985894, 3.778888725538237, 3.8013155617496426, 3.8236108588610325, 3.845776904605882, 3.867815921162743, 3.8897300677553446, 3.9115214431215892, 3.9331920878594273, 3.954743986657038, 3.976179070414209, 3.9974992182613374, 4.018706259482023, 4.039801975344831, 4.060788100849391, 4.08166632639171, 4.102438299353203, 4.123105625617661, 4.1436698710201325], [0.0, 0.4242640687119285, 0.6, 0.7348469228349536, 0.848528137423857, 0.9486832980505139, 1.0392304845413265, 1.1224972160321824, 1.2, 1.2727922061357855, 1.3416407864998738, 1.407124727947029, 1.4696938456699071, 1.5297058540778357, 1.5874507866387544, 1.6431676725154982, 1.697056274847714, 1.7492855684535902, 1.8, 1.8493242008906932, 1.8973665961010278, 1.9442222095223582, 1.98997487421324, 2.0346989949375804, 2.078460969082653, 2.121320343559643, 2.1633307652783937, 2.2045407685048604, 2.244994432064365, 2.2847319317591728, 2.32379000772445, 2.3622023622035435, 2.4, 2.4372115213907883, 2.4738633753705965, 2.5099800796022267, 2.545584412271571, 2.5806975801127883, 2.615339366124404, 2.6495282598983545, 2.6832815729997477, 2.716615541441225, 2.749545416973504, 2.782085548648711, 2.814249455894058, 2.846049894151541, 2.877498913987632, 2.9086079144497976, 2.9393876913398143, 2.9698484809834995, 3.0, 3.029851481508624, 3.0594117081556713, 3.0886890422961004, 3.1176914536239795, 3.146426544510455, 3.1749015732775088, 3.2031234756093934, 3.2310988842807027, 3.2588341473600644, 3.2863353450309964, 3.3136083051561784, 3.340658617698013, 3.3674916480965473, 3.394112549695428, 3.420526275297414, 3.4467375879228173, 3.4727510708370675, 3.4985711369071804, 3.5242020373412193, 3.5496478698597698, 3.5749125863438955, 3.6, 3.6249137920783716, 3.6496575181789317, 3.6742346141747673, 3.6986484017813863, 3.722902093797257, 3.7469987990390394, 3.7709415269929605, 3.7947331922020555, 3.8183766184073566, 3.84187454245971, 3.8652296180175374, 3.8884444190447165, 3.9115214431215897, 3.9344631145812006, 3.957271787481876, 3.97994974842648, 4.0024992192379, 4.024922359499621, 4.047221268969612, 4.069397989875161, 4.091454509095757, 4.113392760240627, 4.135214625627066, 4.156921938165306, 4.178516483155236, 4.2, 4.221374183841087, 4.242640687119286, 4.263801121065569], [0.0, 0.43588989435406744, 0.6164414002968976, 0.7549834435270751, 0.8717797887081349, 0.9746794344808966, 1.0677078252031313, 1.1532562594670797, 1.2328828005937953, 1.307669683062202, 1.3784048752090223, 1.4456832294800963, 1.5099668870541503, 1.5716233645501714, 1.6309506430300091, 1.6881943016134133, 1.7435595774162698, 1.797220075561143, 1.8493242008906932, 1.9000000000000004, 1.9493588689617931, 1.9974984355438181, 2.0445048300260877, 2.0904544960366875, 2.1354156504062627, 2.179449471770337, 2.2226110770892875, 2.2649503305812253, 2.3065125189341593, 2.3473389188611007, 2.3874672772626644, 2.4269322199023198, 2.4657656011875906, 2.503996805109783, 2.5416530054277673, 2.5787593916455256, 2.615339366124404, 2.651414716712571, 2.687005768508881, 2.7221315177632404, 2.7568097504180447, 2.791057147390573, 2.8248893783651075, 2.8583211855912904, 2.8913664589601926, 2.924038303442689, 2.956349099818897, 2.9883105594967874, 3.0199337741083006, 3.051229260478472, 3.082207001484489, 3.1128764832546767, 3.1432467291003428, 3.1733263305244868, 3.203123475609394, 3.232645975048923, 3.2619012860600183, 3.290896534380867, 3.319638534539567, 3.3481338085566414, 3.3763886032268267, 3.4044089061098406, 3.432200460346103, 3.4597687784012394, 3.4871191548325395, 3.5142566781611158, 3.541186241925155, 3.567912554982255, 3.594440151122286, 3.6207733980463352, 3.6469165057620945, 3.672873534441392, 3.6986484017813863, 3.7242448899072147, 3.749666651850535, 3.7749172176353754, 3.8000000000000007, 3.824918299781056, 3.8496753109840323, 3.874274125562104, 3.8987177379235862, 3.9230090491866068, 3.947150871198111, 3.9711459303329564, 3.9949968710876362, 4.018706259482024, 4.042276586281548, 4.065710270051225, 4.0890096600521755, 4.112177038990418, 4.135214625627067, 4.158124577258358, 4.180908992073375, 4.203569911396741, 4.226109321823088, 4.2485291572496005, 4.270831300812525, 4.293017586733137, 4.315089802078284, 4.337049688440289, 4.358898943540674, 4.380639222761903], [0.0, 0.447213595499958, 0.6324555320336759, 0.7745966692414835, 0.894427190999916, 1.0000000000000002, 1.0954451150103324, 1.1832159566199234, 1.2649110640673518, 1.3416407864998738, 1.4142135623730951, 1.4832396974191329, 1.549193338482967, 1.61245154965971, 1.6733200530681511, 1.7320508075688772, 1.788854381999832, 1.8439088914585775, 1.8973665961010278, 1.9493588689617931, 2.0000000000000004, 2.04939015319192, 2.0976176963403033, 2.144761058952722, 2.1908902300206647, 2.23606797749979, 2.280350850198276, 2.3237900077244507, 2.366431913239847, 2.4083189157584592, 2.4494897427831783, 2.489979919597747, 2.5298221281347035, 2.5690465157330262, 2.60768096208106, 2.6457513110645907, 2.6832815729997477, 2.720294101747089, 2.7568097504180447, 2.7928480087537886, 2.8284271247461903, 2.863564212655271, 2.8982753492378883, 2.932575659723036, 2.9664793948382657, 3.0, 3.0331501776206204, 3.0659419433511785, 3.098386676965934, 3.130495168499706, 3.1622776601683795, 3.193743884534263, 3.22490309931942, 3.255764119219942, 3.286335345030997, 3.3166247903554003, 3.3466401061363023, 3.3763886032268267, 3.405877273185281, 3.4351128074635335, 3.4641016151377544, 3.492849839314596, 3.521363372331802, 3.5496478698597698, 3.577708763999664, 3.605551275463989, 3.6331804249169903, 3.6606010435446255, 3.687817782917155, 3.7148351242013424, 3.7416573867739418, 3.768288736283355, 3.7947331922020555, 3.82099463490856, 3.847076812334269, 3.872983346207417, 3.8987177379235862, 3.924283374069717, 3.9496835316263006, 3.9749213828703587, 4.000000000000001, 4.024922359499622, 4.049691346263318, 4.0743097574926725, 4.09878030638384, 4.123105625617661, 4.147288270665545, 4.171330722922843, 4.1952353926806065, 4.219004621945797, 4.242640687119286, 4.266145801540309, 4.289522117905444, 4.312771730569565, 4.335896677735761, 4.358898943540674, 4.3817804600413295, 4.404543109109049, 4.427188724235731, 4.449719092257398, 4.47213595499958, 4.494441010848847], [0.0, 0.45825756949558405, 0.6480740698407861, 0.7937253933193773, 0.9165151389911681, 1.02469507659596, 1.1224972160321824, 1.2124355652982142, 1.2961481396815722, 1.374772708486752, 1.449137674618944, 1.5198684153570665, 1.5874507866387546, 1.6522711641858308, 1.7146428199482247, 1.7748239349298847, 1.8330302779823362, 1.8894443627691184, 1.9442222095223582, 1.9974984355438181, 2.04939015319192, 2.1, 2.149418526020468, 2.1977260975835913, 2.244994432064365, 2.2912878474779204, 2.336664289109585, 2.381176179958132, 2.4248711305964283, 2.4677925358506134, 2.5099800796022267, 2.551470164434615, 2.5922962793631443, 2.632489316217637, 2.672077843177478, 2.711088342345192, 2.749545416973504, 2.787471972953271, 2.824889378365107, 2.861817604250837, 2.898275349237888, 2.934280150224242, 2.9698484809835, 3.004995840263344, 3.039736830714133, 3.0740852297878796, 3.108054053584011, 3.1416556144810017, 3.174901573277509, 3.2078029864690882, 3.2403703492039306, 3.272613634390715, 3.3045423283716615, 3.336165463522456, 3.3674916480965478, 3.398529093593286, 3.4292856398964493, 3.459768778401239, 3.48998567332303, 3.5199431813596083, 3.5496478698597693, 3.5791060336346563, 3.608323710533743, 3.6373066958946425, 3.6660605559646724, 3.6945906403822333, 3.722902093797257, 3.7509998667022106, 3.778888725538237, 3.8065732621348563, 3.834057902536163, 3.861346915261565, 3.8884444190447165, 3.915354390090379, 3.9420806688854046, 3.968626966596886, 3.9949968710876362, 4.02119385257662, 4.047221268969613, 4.07308237088326, 4.09878030638384, 4.124318125460256, 4.149698784249287, 4.174925149029621, 4.2, 4.224926034855522, 4.249705872175156, 4.274342054632503, 4.298837052040936, 4.323193264243457, 4.347413023856832, 4.371498598878879, 4.3954521951671826, 4.419275958796871, 4.442971978304612, 4.466542286825459, 4.48998886412873, 4.513313638558704, 4.536518488885503, 4.559605246071199, 4.582575694955841, 4.605431575867782], [0.0, 0.469041575982343, 0.6633249580710799, 0.8124038404635961, 0.938083151964686, 1.0488088481701516, 1.148912529307606, 1.2409673645990857, 1.3266499161421599, 1.407124727947029, 1.4832396974191326, 1.5556349186104048, 1.6248076809271923, 1.6911534525287764, 1.7549928774784245, 1.816590212458495, 1.876166303929372, 1.9339079605813716, 1.98997487421324, 2.0445048300260877, 2.0976176963403033, 2.149418526020468, 2.2, 2.249444375840399, 2.297825058615212, 2.345207879911715, 2.3916521486202797, 2.4372115213907883, 2.4819347291981715, 2.5258661880630178, 2.569046515733026, 2.6115129714401193, 2.6532998322843198, 2.6944387170614963, 2.734958866235469, 2.7748873851023217, 2.814249455894058, 2.8530685235374214, 2.891366458960192, 2.9291637031753623, 2.9664793948382653, 3.0033314835362415, 3.039736830714133, 3.0757112998459397, 3.1112698372208096, 3.1464265445104544, 3.1811947441173736, 3.2155870381627056, 3.2496153618543846, 3.283291031876401, 3.3166247903554003, 3.3496268448888458, 3.3823069050575527, 3.414674215792775, 3.4467375879228173, 3.4785054261852175, 3.509985754956849, 3.5411862419251547, 3.5721142198983507, 3.602776706930364, 3.63318042491699, 3.6633318168028404, 3.6932370625238775, 3.722902093797257, 3.752332607858744, 3.7815340802378072, 3.81051177665153, 3.8392707640904935, 3.867815921162743, 3.8961519477556315, 3.924283374069717, 3.952214569073901, 3.97994974842648, 4.007492981902776, 4.034848200366403, 4.06201920231798, 4.0890096600521755, 4.115823125451336, 4.1424630354415966, 4.168932717135166, 4.1952353926806065, 4.221374183841087, 4.247352116319061, 4.273172123844299, 4.298837052040936, 4.324349662087931, 4.349712634186309, 4.374928570845472, 4.4, 4.424929377967517, 4.449719092257398, 4.474371464239419, 4.498888751680798, 4.523273151159457, 4.54752680036083, 4.571651780264984, 4.595650117230424, 4.61952378498044, 4.64327470649756, 4.666904755831214, 4.69041575982343, 4.713809499757071], [0.0, 0.479583152331272, 0.6782329983125268, 0.8306623862918077, 0.959166304662544, 1.072380529476361, 1.174734012447073, 1.2688577540449522, 1.3564659966250536, 1.438749456993816, 1.5165750888103102, 1.5905973720586868, 1.6613247725836153, 1.7291616465790585, 1.7944358444926363, 1.857417562100671, 1.918332609325088, 1.977371993328519, 2.0346989949375804, 2.0904544960366875, 2.144761058952722, 2.1977260975835913, 2.249444375840399, 2.3000000000000003, 2.349468024894146, 2.39791576165636, 2.4454038521274972, 2.491987158875423, 2.5377155080899043, 2.582634314028992, 2.6267851073127395, 2.670205984563738, 2.7129319932501073, 2.754995462791183, 2.7964262908219126, 2.8372521918222215, 2.877498913987632, 2.917190429162965, 2.956349099818897, 2.994995826374388, 3.0331501776206204, 3.0708305065568178, 3.108054053584011, 3.1448370387032774, 3.1811947441173736, 3.2171415884290826, 3.252691193458119, 3.2878564445547194, 3.3226495451672307, 3.357082066318904, 3.3911649915626345, 3.4249087579087423, 3.458323293158117, 3.491418050019219, 3.5242020373412197, 3.5566838487557484, 3.5888716889852725, 3.620773398046335, 3.6523964735499352, 3.6837480912787726, 3.714835124201342, 3.745664160065609, 3.7762415176998414, 3.8065732621348563, 3.836665218650176, 3.866522985836241, 3.8961519477556315, 3.9255572852781047, 3.954743986657038, 3.9837168574084183, 4.012480529547776, 4.041039470235351, 4.069397989875161, 4.097560249709576, 4.125530268947254, 4.153311931459037, 4.180908992073375, 4.2083250825001635, 4.235563716909475, 4.262628297189424, 4.289522117905444, 4.316248370981448, 4.342810150121694, 4.369210454990696, 4.3954521951671826, 4.421538193886829, 4.447471191587417, 4.473253849269009, 4.498888751680798, 4.524378410345448, 4.549725266430931, 4.57493169347915, 4.6000000000000005, 4.624932431938872, 4.649731175025068, 4.674398357008098, 4.698936049788292, 4.723346271447818, 4.747630988187688, 4.77179211617606, 4.79583152331272, 4.819751030914357], [0.0, 0.48989794855663565, 0.6928203230275509, 0.8485281374238571, 0.9797958971132713, 1.0954451150103324, 1.2000000000000002, 1.2961481396815722, 1.3856406460551018, 1.469693845669907, 1.5491933384829668, 1.6248076809271923, 1.6970562748477143, 1.7663521732655696, 1.833030277982336, 1.8973665961010275, 1.9595917942265426, 2.0199009876724157, 2.078460969082653, 2.1354156504062627, 2.1908902300206647, 2.244994432064365, 2.297825058615212, 2.349468024894146, 2.4000000000000004, 2.4494897427831783, 2.4979991993593598, 2.5455844122715714, 2.5922962793631443, 2.638181191654584, 2.6832815729997477, 2.727636339397171, 2.7712812921102037, 2.8142494558940583, 2.8565713714171403, 2.898275349237888, 2.939387691339814, 2.979932885150268, 3.0199337741083, 3.0594117081556713, 3.0983866769659336, 3.136877428271625, 3.174901573277509, 3.212475680841802, 3.2496153618543846, 3.2863353450309964, 3.32264954516723, 3.358571124749333, 3.3941125496954285, 3.4292856398964493, 3.464101615137755, 3.498571136907181, 3.532704346531139, 3.5665109000254023, 3.6, 3.6331804249169903, 3.666060555964672, 3.698648401781386, 3.7309516212355263, 3.7629775444453557, 3.794733192202055, 3.8262252939417984, 3.857460304397182, 3.8884444190447165, 3.9191835884530852, 3.9496835316262997, 3.97994974842648, 4.009987531152684, 4.039801975344831, 4.069397989875161, 4.09878030638384, 4.127953488110059, 4.156921938165306, 4.18568990729127, 4.214261501141095, 4.242640687119286, 4.270831300812525, 4.298837052040936, 4.3266615305567875, 4.354308211415448, 4.3817804600413295, 4.409081537009721, 4.436214602563767, 4.463182720884279, 4.48998886412873, 4.5166359162544865, 4.543126676640219, 4.5694638635183455, 4.595650117230424, 4.621688003316537, 4.6475800154489, 4.673328578219169, 4.698936049788292, 4.724404724407087, 4.749736834815168, 4.774934554525329, 4.800000000000001, 4.824935232725928, 4.849742261192857, 4.874423042781577, 4.898979485566357, 4.9234134500364695], [0.0, 0.5, 0.7071067811865476, 0.8660254037844388, 1.0, 1.118033988749895, 1.2247448713915892, 1.3228756555322954, 1.4142135623730951, 1.5, 1.5811388300841898, 1.6583123951777001, 1.7320508075688776, 1.8027756377319948, 1.8708286933869707, 1.9364916731037083, 2.0, 2.0615528128088303, 2.121320343559643, 2.179449471770337, 2.23606797749979, 2.2912878474779204, 2.345207879911715, 2.39791576165636, 2.4494897427831783, 2.5000000000000004, 2.5495097567963927, 2.5980762113533165, 2.6457513110645907, 2.6925824035672523, 2.7386127875258306, 2.783882181415011, 2.8284271247461903, 2.8722813232690148, 2.9154759474226504, 2.958039891549808, 3.0, 3.04138126514911, 3.0822070014844885, 3.1224989991991996, 3.1622776601683795, 3.2015621187164247, 3.2403703492039306, 3.278719262151, 3.3166247903554003, 3.3541019662496843, 3.3911649915626345, 3.4278273002005224, 3.4641016151377553, 3.5, 3.535533905932738, 3.5707142142714257, 3.6055512754639896, 3.64005494464026, 3.6742346141747677, 3.708099243547832, 3.7416573867739413, 3.774917217635375, 3.8078865529319548, 3.840572873934304, 3.8729833462074166, 3.9051248379533274, 3.9370039370059056, 3.968626966596886, 4.0, 4.031128874149275, 4.06201920231798, 4.092676385936225, 4.123105625617661, 4.153311931459037, 4.183300132670378, 4.2130748865881795, 4.242640687119286, 4.272001872658766, 4.301162633521313, 4.330127018922194, 4.358898943540674, 4.387482193696061, 4.415880433163924, 4.444097208657795, 4.47213595499958, 4.500000000000001, 4.527692569068709, 4.55521678957215, 4.582575694955841, 4.609772228646444, 4.636809247747852, 4.663689526544408, 4.69041575982343, 4.716990566028302, 4.743416490252569, 4.769696007084729, 4.79583152331272, 4.821825380496478, 4.847679857416329, 4.873397172404482, 4.898979485566357, 4.924428900898053, 4.949747468305833, 4.974937185533101, 5.000000000000001, 5.024937810560446], [0.0, 0.5099019513592785, 0.7211102550927979, 0.8831760866327849, 1.019803902718557, 1.140175425099138, 1.2489995996796799, 1.3490737563232043, 1.4422205101855958, 1.5297058540778354, 1.61245154965971, 1.6911534525287766, 1.7663521732655698, 1.8384776310850237, 1.9078784028338913, 1.9748417658131499, 2.039607805437114, 2.102379604162864, 2.1633307652783937, 2.2226110770892875, 2.280350850198276, 2.336664289109585, 2.3916521486202797, 2.4454038521274972, 2.4979991993593598, 2.5495097567963927, 2.6000000000000005, 2.6495282598983545, 2.6981475126464085, 2.7459060435491964, 2.792848008753788, 2.839013913315678, 2.8844410203711917, 2.9291637031753623, 2.973213749463701, 3.0166206257996713, 3.059411708155671, 3.101612483854165, 3.1432467291003428, 3.1843366656181322, 3.22490309931942, 3.264965543462902, 3.304542328371662, 3.3436506994600976, 3.382306905057553, 3.420526275297414, 3.458323293158117, 3.4957116585897072, 3.5327043465311396, 3.5693136595149495, 3.6055512754639896, 3.6414282912066254, 3.6769552621700474, 3.712142238654118, 3.7469987990390394, 3.7815340802378077, 3.8157568056677826, 3.849675310984032, 3.8832975677895205, 3.916631205513228, 3.9496835316262997, 3.9824615503479754, 4.014971979976946, 4.047221268969613, 4.079215610874228, 4.110960958218893, 4.142463035441596, 4.173727350941841, 4.204759208325728, 4.235563716909475, 4.266145801540309, 4.296510211788167, 4.3266615305567875, 4.356604182158393, 4.386342439892262, 4.415880433163924, 4.445222154178575, 4.474371464239419, 4.503332099679082, 4.532107677449864, 4.560701700396552, 4.589117562233507, 4.617358552246079, 4.645427859734774, 4.67332857821917, 4.701063709417264, 4.7286361670147565, 4.756048780237647, 4.7833042972405595, 4.810405388322278, 4.83735464897913, 4.864154602806124, 4.8908077042549944, 4.917316341257699, 4.943682837723311, 4.969909455915671, 4.9959983987187195, 5.021951811795889, 5.047771785649585, 5.073460357586329, 5.099019513592785, 5.1244511901275835], [0.0, 0.5196152422706632, 0.7348469228349535, 0.9000000000000001, 1.0392304845413265, 1.1618950038622253, 1.2727922061357857, 1.374772708486752, 1.469693845669907, 1.5588457268119895, 1.6431676725154984, 1.7233687939614089, 1.8000000000000003, 1.8734993995195197, 1.9442222095223582, 2.0124611797498106, 2.078460969082653, 2.142428528562855, 2.2045407685048604, 2.2649503305812253, 2.3237900077244507, 2.381176179958132, 2.4372115213907883, 2.491987158875423, 2.5455844122715714, 2.5980762113533165, 2.6495282598983545, 2.7, 2.749545416973504, 2.7982137159266447, 2.8460498941515415, 2.8930952282978866, 2.939387691339814, 2.9849623113198605, 3.0298514815086235, 3.0740852297878796, 3.117691453623979, 3.160696125855822, 3.203123475609394, 3.244996147917591, 3.286335345030997, 3.3271609519228256, 3.3674916480965478, 3.407345007480164, 3.4467375879228177, 3.4856850115866753, 3.5242020373412197, 3.5623026261113755, 3.6000000000000005, 3.6373066958946425, 3.6742346141747677, 3.7107950630558952, 3.7469987990390394, 3.782856063875548, 3.818376618407357, 3.853569773599539, 3.8884444190447165, 3.9230090491866063, 3.957271787481876, 3.9912404086950213, 4.024922359499621, 4.058324777540605, 4.091454509095756, 4.124318125460256, 4.156921938165306, 4.189272013130682, 4.221374183841087, 4.253234063627348, 4.28485705712571, 4.316248370981448, 4.3474130238568325, 4.378355855797928, 4.409081537009721, 4.439594576084623, 4.469899327725402, 4.5, 4.529900661162451, 4.559605246071199, 4.589117562233508, 4.618441295502196, 4.647580015448901, 4.676537180435969, 4.705316142407438, 4.73392015141785, 4.762352359916264, 4.790615826801394, 4.818713521262704, 4.846648326421054, 4.874423042781577, 4.902040391510457, 4.929503017546495, 4.956813492557492, 4.983974317750846, 5.0109879265470205, 5.037856687124, 5.06458290484024, 5.091168824543143, 5.117616632769595, 5.143928459844674, 5.170106381884226, 5.196152422706633, 5.222068555658764], [0.0, 0.5291502622129182, 0.7483314773547882, 0.9165151389911681, 1.0583005244258363, 1.1832159566199234, 1.2961481396815722, 1.4000000000000001, 1.4966629547095764, 1.5874507866387544, 1.6733200530681511, 1.7549928774784245, 1.8330302779823362, 1.9078784028338915, 1.9798989873223332, 2.0493901531919194, 2.1166010488516727, 2.181742422927143, 2.244994432064365, 2.3065125189341593, 2.366431913239847, 2.4248711305964283, 2.4819347291981715, 2.5377155080899043, 2.5922962793631443, 2.6457513110645907, 2.6981475126464085, 2.749545416973504, 2.8000000000000003, 2.8495613697550017, 2.8982753492378874, 2.946183972531247, 2.993325909419153, 3.039736830714133, 3.0854497241083028, 3.1304951684997055, 3.1749015732775088, 3.2186953878862163, 3.2619012860600183, 3.3045423283716615, 3.3466401061363023, 3.3882148692194836, 3.4292856398964497, 3.4698703145794942, 3.509985754956849, 3.5496478698597693, 3.5888716889852725, 3.627671429443411, 3.6660605559646724, 3.704051835490427, 3.7416573867739418, 3.7788887255382373, 3.815756805667783, 3.852272056851645, 3.8884444190447165, 3.924283374069717, 3.9597979746446663, 3.994996871087636, 4.029888335921977, 4.064480286580315, 4.098780306383839, 4.132795663954365, 4.166533331199932, 4.2, 4.233202097703345, 4.266145801540308, 4.298837052040936, 4.331281565541543, 4.363484845854286, 4.3954521951671826, 4.427188724235731, 4.458699361921591, 4.48998886412873, 4.521061822182926, 4.551922670696417, 4.58257569495584, 4.613025037868319, 4.64327470649756, 4.67332857821917, 4.703190406521939, 4.732863826479694, 4.762352359916263, 4.791659420284376, 4.82078831727758, 4.849742261192857, 4.878524367060187, 4.907137658554119, 4.935585071701227, 4.963869458396343, 4.991993589739474, 5.019960159204453, 5.047771785649585, 5.075431016179809, 5.10294032886923, 5.130302135352265, 5.15751878329105, 5.184592558726289, 5.2115256883181535, 5.238320341483518, 5.264978632435274, 5.291502622129181, 5.317894320123333], [0.0, 0.5385164807134505, 0.7615773105863909, 0.9327379053088817, 1.077032961426901, 1.2041594578792296, 1.319090595827292, 1.4247806848775009, 1.5231546211727818, 1.6155494421403513, 1.7029386365926402, 1.7860571099491753, 1.8654758106177634, 1.94164878389476, 2.0149441679609885, 2.085665361461421, 2.154065922853802, 2.220360331117452, 2.2847319317591728, 2.3473389188611007, 2.4083189157584592, 2.4677925358506134, 2.5258661880630178, 2.582634314028992, 2.638181191654584, 2.6925824035672523, 2.7459060435491964, 2.7982137159266447, 2.8495613697550017, 2.9000000000000004, 2.9495762407505253, 2.99833287011299, 3.0463092423455636, 3.0935416596516045, 3.1400636936215167, 3.1859064644147983, 3.2310988842807027, 3.2756678708318403, 3.3196385345395667, 3.363034344160048, 3.4058772731852804, 3.448187929913334, 3.48998567332303, 3.531288716601915, 3.5721142198983507, 3.6124783736376886, 3.6523964735499352, 3.691882988394947, 3.7309516212355267, 3.769615364994153, 3.8078865529319548, 3.845776904605883, 3.88329756778952, 3.9204591567825324, 3.957271787481876, 3.993745109543172, 4.029888335921977, 4.065710270051224, 4.101219330881976, 4.136423575989287, 4.171330722922842, 4.205948168962618, 4.240283009422838, 4.274342054632503, 4.308131845707604, 4.341658669218482, 4.374928570845472, 4.407947368106838, 4.440720662234904, 4.473253849269009, 4.505552130427525, 4.537620521815371, 4.5694638635183455, 4.601086828130937, 4.632493928760188, 4.663689526544408, 4.694677837722201, 4.725462940284264, 4.756048780237647, 4.786439177509728, 4.8166378315169185, 4.846648326421054, 4.876474136094644, 4.906118628814432, 4.935585071701227, 4.964876634922565, 4.993996395673509, 5.022947341949744, 5.0517323761260355, 5.0803543183522155, 5.10881590977792, 5.137119815616529, 5.165268628057984, 5.193264869039514, 5.221110992882646, 5.2488093888042835, 5.276362383309168, 5.3037722424704485, 5.331041174104736, 5.358171329847527, 5.385164807134505, 5.412023651093924], [0.0, 0.5477225575051661, 0.7745966692414833, 0.9486832980505139, 1.0954451150103321, 1.2247448713915892, 1.3416407864998738, 1.4491376746189437, 1.5491933384829666, 1.6431676725154982, 1.7320508075688772, 1.816590212458495, 1.8973665961010278, 1.9748417658131499, 2.0493901531919194, 2.1213203435596424, 2.1908902300206643, 2.258317958127243, 2.32379000772445, 2.3874672772626644, 2.4494897427831783, 2.5099800796022267, 2.569046515733026, 2.6267851073127395, 2.6832815729997477, 2.7386127875258306, 2.792848008753788, 2.8460498941515415, 2.8982753492378874, 2.9495762407505253, 2.9999999999999996, 3.049590136395381, 3.098386676965933, 3.146426544510455, 3.1937438845342623, 3.2403703492039297, 3.2863353450309964, 3.331666249791536, 3.376388603226826, 3.420526275297414, 3.4641016151377544, 3.5071355833500366, 3.5496478698597698, 3.5916569992135936, 3.63318042491699, 3.674234614174767, 3.714835124201342, 3.7549966711037173, 3.7947331922020555, 3.8340579025361627, 3.872983346207417, 3.9115214431215892, 3.9496835316262997, 3.9874804074753776, 4.024922359499621, 4.06201920231798, 4.098780306383839, 4.135214625627066, 4.171330722922842, 4.207136793592525, 4.242640687119285, 4.277849927241487, 4.3127717305695645, 4.347413023856832, 4.381780460041329, 4.415880433163923, 4.449719092257397, 4.483302354291978, 4.516635916254486, 4.54972526643093, 4.58257569495584, 4.61519230368573, 4.6475800154489, 4.679743582719036, 4.711687595755898, 4.743416490252569, 4.774934554525329, 4.806245936279166, 4.83735464897913, 4.868264577855234, 4.898979485566357, 4.929503017546495, 4.959838707054898, 4.9899899799498595, 5.019960159204453, 5.049752469181039, 5.079370039680118, 5.10881590977792, 5.138093031466052, 5.167204273105525, 5.196152422706632, 5.224940191045253, 5.253570214625479, 5.282045058497703, 5.310367218940701, 5.338539126015655, 5.366563145999495, 5.394441583704471, 5.422176684690383, 5.449770637375485, 5.477225575051661, 5.504543577809154], [0.0, 0.5567764362830022, 0.7874007874011811, 0.9643650760992957, 1.1135528725660044, 1.2449899597988734, 1.3638181696985856, 1.4730919862656235, 1.5748015748023623, 1.6703293088490065, 1.760681686165901, 1.846618531261939, 1.9287301521985913, 2.0074859899884734, 2.083266665599966, 2.1563858652847823, 2.227105745132009, 2.2956480566497994, 2.3622023622035435, 2.4269322199023198, 2.489979919597747, 2.551470164434615, 2.6115129714401193, 2.670205984563738, 2.727636339397171, 2.783882181415011, 2.839013913315678, 2.8930952282978866, 2.946183972531247, 2.99833287011299, 3.049590136395381, 3.1, 3.1496031496047245, 3.1984371183438953, 3.2465366161495854, 3.2939338184001206, 3.340658617698013, 3.38673884437522, 3.432200460346103, 3.477067730142742, 3.521363372331802, 3.5651086939951777, 3.6083237105337433, 3.6510272527057364, 3.693237062523878, 3.7349698793966195, 3.7762415176998414, 3.817066936798463, 3.8574603043971827, 3.8974350539810154, 3.9370039370059056, 3.9761790704142093, 4.014971979976947, 4.053393639902249, 4.091454509095757, 4.129164564412516, 4.166533331199932, 4.20356991139674, 4.240283009422838, 4.276680956068619, 4.3127717305695645, 4.34856298103178, 4.384062043356595, 4.419275958796871, 4.454211490264018, 4.488875137492688, 4.523273151159456, 4.557411546042337, 4.591296113299599, 4.624932431938872, 4.658325879540847, 4.69148164229596, 4.724404724407087, 4.757099956906519, 4.789572005931219, 4.8218253804964775, 4.8538644398046396, 4.8856934001224435, 4.917316341257699, 4.948737212663449, 4.979959839195494, 5.01098792654702, 5.041825066382213, 5.072474741188959, 5.10294032886923, 5.13322510708424, 5.163332257370235, 5.193264869039514, 5.223025942880239, 5.252618394667558, 5.282045058497703, 5.3113086899558, 5.340411969127476, 5.36935750346352, 5.398147830506312, 5.426785420486054, 5.455272678794342, 5.483611948342078, 5.511805511808268, 5.539855593785817, 5.567764362830022, 5.595533933415113], [0.0, 0.565685424949238, 0.7999999999999999, 0.9797958971132713, 1.131370849898476, 1.2649110640673518, 1.3856406460551018, 1.4966629547095764, 1.5999999999999999, 1.697056274847714, 1.7888543819998317, 1.876166303929372, 1.9595917942265426, 2.039607805437114, 2.116601048851672, 2.1908902300206643, 2.262741699796952, 2.33238075793812, 2.4, 2.4657656011875906, 2.5298221281347035, 2.5922962793631443, 2.6532998322843198, 2.7129319932501073, 2.7712812921102037, 2.8284271247461903, 2.8844410203711917, 2.939387691339814, 2.993325909419153, 3.0463092423455636, 3.098386676965933, 3.1496031496047245, 3.1999999999999997, 3.249615361854384, 3.2984845004941286, 3.3466401061363023, 3.394112549695428, 3.4409301068170506, 3.487119154832539, 3.5327043465311387, 3.5777087639996634, 3.622154055254967, 3.6660605559646724, 3.709447398198281, 3.752332607858744, 3.7947331922020546, 3.8366652186501757, 3.878143885933063, 3.9191835884530852, 3.959797974644666, 4.0, 4.039801975344831, 4.079215610874228, 4.118252056394801, 4.156921938165306, 4.1952353926806065, 4.233202097703344, 4.2708313008125245, 4.308131845707603, 4.345112196480086, 4.381780460041329, 4.418144406874904, 4.454211490264017, 4.48998886412873, 4.525483399593904, 4.560701700396551, 4.595650117230423, 4.63033476111609, 4.66476151587624, 4.698936049788292, 4.732863826479693, 4.766550115125193, 4.8, 4.833218389437829, 4.866210024238575, 4.898979485566356, 4.931531202375181, 4.963869458396343, 4.995998398718719, 5.027922035990614, 5.059644256269407, 5.091168824543142, 5.122499389946279, 5.15363949069005, 5.184592558726289, 5.215361924162119, 5.2459508194416005, 5.276362383309167, 5.3065996645686395, 5.336665625650533, 5.366563145999495, 5.396295025292816, 5.4258639865002145, 5.455272678794342, 5.4845236803208355, 5.513619500836088, 5.542562584220407, 5.571355310873648, 5.6, 5.628498911788116, 5.656854249492381, 5.685068161420759], [0.0, 0.574456264653803, 0.812403840463596, 0.9949874371066202, 1.148912529307606, 1.2845232578665131, 1.4071247279470291, 1.5198684153570665, 1.624807680927192, 1.7233687939614086, 1.8165902124584952, 1.9052558883257653, 1.9899748742132404, 2.0712315177207983, 2.149418526020468, 2.224859546128699, 2.297825058615212, 2.3685438564654024, 2.4372115213907883, 2.503996805109783, 2.5690465157330262, 2.632489316217637, 2.6944387170614963, 2.754995462791183, 2.8142494558940583, 2.8722813232690148, 2.9291637031753623, 2.9849623113198605, 3.039736830714133, 3.0935416596516045, 3.146426544510455, 3.1984371183438953, 3.249615361854384, 3.3000000000000007, 3.3496268448888458, 3.398529093593286, 3.4467375879228173, 3.49428104193123, 3.541186241925155, 3.58747822293042, 3.6331804249169903, 3.678314831549905, 3.7229020937972575, 3.7669616403674726, 3.8105117766515306, 3.853569773599539, 3.896151947755632, 3.9382737335030438, 3.9799497484264807, 4.02119385257662, 4.06201920231798, 4.102438299353204, 4.1424630354415966, 4.182104733265298, 4.221374183841087, 4.260281680828159, 4.298837052040936, 4.337049688440288, 4.374928570845472, 4.412482294582042, 4.449719092257398, 4.486646854834912, 4.523273151159457, 4.559605246071199, 4.595650117230424, 4.631414470763764, 4.666904755831214, 4.702127178203499, 4.737087712930805, 4.77179211617606, 4.806245936279167, 4.8404545241123795, 4.874423042781577, 4.908156476723211, 4.941659640242335, 4.974937185533101, 5.007993610219566, 5.040833264451424, 5.07346035758633, 5.105878964487898, 5.1380930314660525, 5.170106381884226, 5.201922721455982, 5.23354564325181, 5.264978632435274, 5.296225070746145, 5.327288240746882, 5.358171329847526, 5.388877434122993, 5.419409561935692, 5.449770637375486, 5.479963503528103, 5.509990925582366, 5.539855593785817, 5.569560126257729, 5.599107071667768, 5.628498911788117, 5.657738063926256, 5.686826883245173, 5.715767664977296, 5.7445626465380295, 5.773214009544425], [0.0, 0.5830951894845301, 0.8246211251235321, 1.009950493836208, 1.1661903789690602, 1.30384048104053, 1.4282856857085702, 1.5427248620541514, 1.6492422502470643, 1.7492855684535902, 1.8439088914585775, 1.9339079605813718, 2.019900987672416, 2.102379604162864, 2.181742422927143, 2.258317958127243, 2.3323807579381204, 2.4041630560342617, 2.4738633753705965, 2.5416530054277673, 2.60768096208106, 2.672077843177478, 2.734958866235469, 2.7964262908219126, 2.8565713714171403, 2.9154759474226504, 2.973213749463701, 3.0298514815086235, 3.0854497241083028, 3.1400636936215167, 3.1937438845342623, 3.2465366161495854, 3.2984845004941286, 3.3496268448888458, 3.4000000000000004, 3.449637662132068, 3.4985711369071804, 3.54682957019364, 3.594440151122286, 3.6414282912066254, 3.687817782917155, 3.733630940518894, 3.7788887255382373, 3.823610858861032, 3.8678159211627436, 3.911521443121589, 3.954743986657038, 3.997499218261337, 4.039801975344832, 4.08166632639171, 4.123105625617661, 4.164132562731403, 4.204759208325728, 4.244997055358225, 4.28485705712571, 4.324349662087931, 4.363484845854286, 4.402272140611028, 4.440720662234904, 4.4788391353117385, 4.516635916254486, 4.5541190146942805, 4.591296113299598, 4.628174586162454, 4.664761515876241, 4.701063709417263, 4.737087712930805, 4.77283982551269, 4.8083261120685235, 4.843552415324934, 4.878524367060187, 4.913247398615299, 4.947726750741193, 4.98196748283246, 5.015974481593781, 5.049752469181039, 5.083306010855535, 5.1166395221864125, 5.149757275833494, 5.182663407939976, 5.21536192416212, 5.247856705360771, 5.280151512977635, 5.31224999411737, 5.344155686354956, 5.375872022286245, 5.40740233383831, 5.4387498563548595, 5.469917732470938, 5.500909015790026, 5.531726674375733, 5.562373594069352, 5.592852581643825, 5.62316636780382, 5.653317610041029, 5.683308895353129, 5.713142742834281, 5.742821606144492, 5.772347875864725, 5.801723881744115, 5.830951894845301, 5.860034129593445], [0.0, 0.5916079783099616, 0.8366600265340756, 1.02469507659596, 1.1832159566199232, 1.3228756555322954, 1.449137674618944, 1.5652475842498528, 1.6733200530681511, 1.7748239349298847, 1.8708286933869707, 1.9621416870348585, 2.04939015319192, 2.1330729007701543, 2.2135943621178655, 2.29128784747792, 2.3664319132398464, 2.4392621835300936, 2.5099800796022267, 2.5787593916455256, 2.6457513110645907, 2.711088342345192, 2.7748873851023217, 2.8372521918222215, 2.898275349237888, 2.958039891549808, 3.0166206257996713, 3.0740852297878796, 3.1304951684997055, 3.1859064644147983, 3.2403703492039297, 3.2939338184001206, 3.3466401061363023, 3.398529093593286, 3.449637662132068, 3.5, 3.5496478698597693, 3.5986108430893164, 3.646916505762094, 3.6945906403822333, 3.7416573867739413, 3.7881393849751626, 3.834057902536163, 3.879432948254164, 3.924283374069717, 3.9686269665968856, 4.012480529547776, 4.05585995813465, 4.09878030638384, 4.141255848169731, 4.183300132670378, 4.224926034855522, 4.266145801540309, 4.306971093471606, 4.347413023856832, 4.387482193696061, 4.427188724235731, 4.466542286825459, 4.505552130427525, 4.544227107000705, 4.58257569495584, 4.620606020859168, 4.658325879540846, 4.695742752749559, 4.732863826479693, 4.769696007084728, 4.806245936279166, 4.8425200051213, 4.878524367060187, 4.914264950122246, 4.949747468305833, 4.984977432245807, 5.019960159204453, 5.054700782440045, 5.089204259999788, 5.123475382979799, 5.157518783291051, 5.191338940966964, 5.2249401910452535, 5.2583267300539625, 5.291502622129181, 5.324471804789654, 5.35723809439155, 5.389805191284746, 5.422176684690384, 5.454356057317858, 5.486346689738081, 5.518151864528558, 5.549774770204643, 5.58121850495033, 5.612486080160912, 5.643580423808984, 5.674504383644443, 5.705260730238365, 5.735852159879995, 5.766281297335397, 5.796550698475776, 5.826662852782887, 5.856620185738529, 5.886425061104576, 5.916079783099616, 5.9455865984779], [0.0, 0.6, 0.848528137423857, 1.0392304845413265, 1.2, 1.3416407864998738, 1.469693845669907, 1.5874507866387544, 1.697056274847714, 1.7999999999999998, 1.8973665961010275, 1.98997487421324, 2.078460969082653, 2.1633307652783937, 2.244994432064365, 2.3237900077244498, 2.4, 2.473863375370596, 2.545584412271571, 2.615339366124404, 2.6832815729997477, 2.749545416973504, 2.814249455894058, 2.877498913987632, 2.939387691339814, 3.0, 3.059411708155671, 3.117691453623979, 3.1749015732775088, 3.2310988842807027, 3.2863353450309964, 3.340658617698013, 3.394112549695428, 3.4467375879228173, 3.4985711369071804, 3.5496478698597693, 3.5999999999999996, 3.6496575181789317, 3.698648401781386, 3.746998799039039, 3.794733192202055, 3.8418745424597094, 3.8884444190447165, 3.9344631145812, 3.97994974842648, 4.024922359499621, 4.069397989875161, 4.113392760240626, 4.156921938165306, 4.2, 4.242640687119285, 4.28485705712571, 4.3266615305567875, 4.368065933568311, 4.409081537009721, 4.449719092257398, 4.48998886412873, 4.52990066116245, 4.569463863518345, 4.608687448721165, 4.6475800154488995, 4.686149805543993, 4.724404724407086, 4.762352359916263, 4.8, 4.8373546489791295, 4.874423042781576, 4.91121166312347, 4.947726750741192, 4.983974317750845, 5.019960159204453, 5.0556898639058145, 5.091168824543142, 5.126402247190518, 5.161395160225576, 5.196152422706632, 5.230678732248808, 5.264978632435273, 5.299056519796709, 5.332916650389353, 5.366563145999495, 5.4, 5.43323108288245, 5.466260147486579, 5.499090833947008, 5.531726674375732, 5.5641710972974225, 5.596427431853289, 5.628498911788116, 5.660388679233962, 5.692099788303082, 5.7236352085016735, 5.754997827975264, 5.786190456595773, 5.817215828899595, 5.848076606885377, 5.878775382679628, 5.909314681077663, 5.939696961966999, 5.96992462263972, 6.0, 6.029925372672535], [0.0, 0.608276253029822, 0.8602325267042626, 1.053565375285274, 1.216552506059644, 1.3601470508735445, 1.489966442575134, 1.6093476939431082, 1.7204650534085253, 1.8248287590894658, 1.9235384061671346, 2.017424100183202, 2.107130750570548, 2.193171219946131, 2.2759613353482084, 2.355843797877949, 2.433105012119288, 2.5079872407968904, 2.5806975801127883, 2.651414716712571, 2.720294101747089, 2.787471972953271, 2.8530685235374214, 2.917190429162965, 2.979932885150268, 3.04138126514911, 3.101612483854165, 3.160696125855822, 3.2186953878862163, 3.2756678708318403, 3.331666249791536, 3.38673884437522, 3.4409301068170506, 3.49428104193123, 3.54682957019364, 3.5986108430893164, 3.6496575181789317, 3.7, 3.7496666518505353, 3.7986839826445165, 3.847076812334269, 3.89486841883009, 3.942080668885405, 3.988734135035826, 4.034848200366404, 4.080441152620633, 4.125530268947254, 4.170131892398609, 4.214261501141096, 4.257933771208754, 4.301162633521314, 4.343961325794695, 4.386342439892262, 4.428317965096906, 4.469899327725402, 4.511097427455985, 4.551922670696417, 4.592385001282014, 4.632493928760188, 4.672258554489466, 4.711687595755898, 4.750789408087881, 4.789572005931219, 4.828043081829325, 4.866210024238576, 4.904079934095691, 4.941659640242335, 4.978955713801841, 5.015974481593781, 5.052722038663912, 5.089204259999789, 5.1254268114957995, 5.1613951602255765, 5.197114584074513, 5.232590180780452, 5.26782687642637, 5.302829433425142, 5.3376024580330075, 5.372150407425318, 5.406477596365309, 5.440588203494178, 5.474486277268398, 5.508175741568166, 5.541660400998964, 5.574943945906542, 5.608029957123981, 5.640921910468182, 5.673623181001714, 5.706137047074843, 5.7384666941614295, 5.770615218501404, 5.8025856305616035, 5.83438085832593, 5.866003750424986, 5.897457079114693, 5.928743543112655, 5.959865770300536, 5.990826320300065, 6.021627686929839, 6.052272300549605, 6.08276253029822, 6.113100686231171], [0.0, 0.6164414002968976, 0.8717797887081348, 1.0677078252031313, 1.2328828005937953, 1.3784048752090223, 1.50996688705415, 1.6309506430300091, 1.7435595774162695, 1.849324200890693, 1.949358868961793, 2.0445048300260877, 2.1354156504062627, 2.222611077089287, 2.3065125189341593, 2.3874672772626644, 2.4657656011875906, 2.541653005427767, 2.615339366124404, 2.687005768508881, 2.7568097504180447, 2.824889378365107, 2.891366458960192, 2.956349099818897, 3.0199337741083, 3.0822070014844885, 3.1432467291003428, 3.203123475609394, 3.2619012860600183, 3.3196385345395667, 3.376388603226826, 3.432200460346103, 3.487119154832539, 3.541186241925155, 3.594440151122286, 3.646916505762094, 3.698648401781386, 3.7496666518505353, 3.8000000000000003, 3.8496753109840323, 3.898717737923586, 3.9471508711981107, 3.9949968710876362, 4.042276586281547, 4.0890096600521755, 4.135214625627066, 4.180908992073375, 4.226109321823088, 4.270831300812525, 4.315089802078284, 4.358898943540674, 4.402272140611029, 4.445222154178574, 4.487761134463376, 4.529900661162451, 4.571651780264984, 4.613025037868319, 4.654030511288038, 4.694677837722201, 4.734976240700686, 4.774934554525329, 4.814561246884289, 4.853864439804639, 4.892851929090027, 4.931531202375181, 4.969909455915671, 5.007993610219566, 5.045790324617146, 5.083306010855534, 5.120546845796843, 5.157518783291051, 5.194227565288221, 5.230678732248808, 5.266877632905477, 5.302829433425141, 5.338539126015656, 5.374011537017762, 5.409251334519409, 5.444263035526481, 5.47905101272109, 5.513619500836089, 5.547972602672079, 5.582114294781146, 5.616048432839589, 5.649778756730214, 5.68330889535313, 5.716642371182581, 5.749782604586021, 5.782732917920384, 5.815496539419485, 5.848076606885378, 5.880476171195663, 5.912698199637794, 5.944745579080741, 5.976621118993575, 6.008327554319921, 6.0398675482166, 6.071243694664217, 6.102458520956943, 6.133514490078262, 6.164414002968977, 6.1951594006934165], [0.0, 0.6244997998398399, 0.8831760866327847, 1.081665382639197, 1.2489995996796799, 1.3964240043768943, 1.5297058540778357, 1.6522711641858308, 1.7663521732655694, 1.8734993995195195, 1.97484176581315, 2.0712315177207983, 2.163330765278394, 2.2516660498395407, 2.3366642891095846, 2.4186773244895647, 2.4979991993593598, 2.574878637916747, 2.6495282598983545, 2.7221315177632404, 2.7928480087537886, 2.861817604250837, 2.9291637031753623, 2.994995826374388, 3.0594117081556713, 3.1224989991991996, 3.1843366656181322, 3.244996147917591, 3.3045423283716615, 3.363034344160048, 3.420526275297414, 3.477067730142742, 3.5327043465311387, 3.58747822293042, 3.6414282912066254, 3.6945906403822333, 3.746998799039039, 3.7986839826445165, 3.8496753109840323, 3.900000000000001, 3.9496835316263, 3.9987498046264416, 4.047221268969613, 4.095119045888654, 4.1424630354415966, 4.189272013130682, 4.235563716909475, 4.281354925721529, 4.326661530556788, 4.371498598878879, 4.415880433163924, 4.459820624195553, 4.503332099679081, 4.546427168667723, 4.589117562233507, 4.631414470763765, 4.673328578219169, 4.7148700936505135, 4.756048780237647, 4.796873982084583, 4.8373546489791295, 4.87749935930288, 4.917316341257699, 4.956813492557492, 4.9959983987187195, 5.034878350069642, 5.073460357586329, 5.111751167652823, 5.149757275833494, 5.187484939737176, 5.2249401910452535, 5.262128846769148, 5.299056519796709, 5.335728628781641, 5.372150407425317, 5.408326913195984, 5.444263035526481, 5.479963503528103, 5.515432893255072, 5.550675634551168, 5.585696017507577, 5.620498198558559, 5.655086206239478, 5.68946394662977, 5.723635208501674, 5.757603668193913, 5.791372894228104, 5.8249463516842805, 5.858327406350725, 5.8915193286621745, 5.92452529743945, 5.957348403442593, 5.989991652748776, 6.02245796996542, 6.054750201288242, 6.08687111741328, 6.118823416311343, 6.150609725872713, 6.182232606429493, 6.213694553162394, 6.244997998398399, 6.276145313805283], [0.0, 0.6324555320336759, 0.8944271909999159, 1.0954451150103324, 1.2649110640673518, 1.4142135623730951, 1.5491933384829668, 1.6733200530681511, 1.7888543819998317, 1.8973665961010275, 2.0, 2.0976176963403033, 2.1908902300206647, 2.280350850198276, 2.3664319132398464, 2.449489742783178, 2.5298221281347035, 2.6076809620810595, 2.6832815729997477, 2.7568097504180447, 2.8284271247461903, 2.898275349237888, 2.9664793948382653, 3.0331501776206204, 3.0983866769659336, 3.1622776601683795, 3.22490309931942, 3.286335345030997, 3.3466401061363023, 3.4058772731852804, 3.4641016151377544, 3.521363372331802, 3.5777087639996634, 3.6331804249169903, 3.687817782917155, 3.7416573867739413, 3.794733192202055, 3.847076812334269, 3.898717737923586, 3.9496835316263, 4.0, 4.049691346263318, 4.09878030638384, 4.147288270665544, 4.1952353926806065, 4.242640687119285, 4.2895221179054435, 4.33589667773576, 4.3817804600413295, 4.427188724235731, 4.47213595499958, 4.5166359162544865, 4.560701700396552, 4.604345773288536, 4.6475800154489, 4.69041575982343, 4.732863826479693, 4.774934554525329, 4.8166378315169185, 4.857983120596447, 4.898979485566356, 4.9396356140913875, 4.979959839195493, 5.019960159204453, 5.059644256269407, 5.0990195135927845, 5.138093031466052, 5.176871642217914, 5.215361924162119, 5.253570214625479, 5.291502622129181, 5.329165037789691, 5.366563145999495, 5.403702434442518, 5.440588203494177, 5.477225575051661, 5.513619500836089, 5.549774770204643, 5.585696017507577, 5.621387729022079, 5.656854249492381, 5.692099788303083, 5.727128425310542, 5.761944116355173, 5.796550698475776, 5.830951894845301, 5.865151319446072, 5.8991524815010505, 5.932958789676531, 5.966573556070519, 6.0, 6.0332412515993425, 6.066300355241241, 6.099180272790763, 6.131883886702357, 6.164414002968976, 6.196773353931867, 6.228964600958975, 6.260990336999411, 6.29285308902091, 6.324555320336759, 6.356099432828282], [0.0, 0.6403124237432849, 0.9055385138137417, 1.1090536506409419, 1.2806248474865698, 1.4317821063276355, 1.5684387141358125, 1.6941074346097418, 1.8110770276274835, 1.9209372712298547, 2.024845673131659, 2.1236760581595306, 2.2181073012818837, 2.3086792761230397, 2.395829710142188, 2.479919353527449, 2.5612496949731396, 2.6400757564888173, 2.716615541441225, 2.791057147390573, 2.863564212655271, 2.934280150224242, 3.0033314835362415, 3.0708305065568178, 3.136877428271625, 3.2015621187164247, 3.264965543462902, 3.3271609519228256, 3.3882148692194836, 3.448187929913334, 3.5071355833500366, 3.5651086939951777, 3.622154055254967, 3.678314831549905, 3.733630940518894, 3.7881393849751626, 3.8418745424597094, 3.89486841883009, 3.9471508711981107, 3.9987498046264416, 4.049691346263318, 4.1000000000000005, 4.149698784249287, 4.198809355043403, 4.247352116319061, 4.295346318982906, 4.342810150121693, 4.389760813529594, 4.436214602563767, 4.4821869662029945, 4.527692569068709, 4.572745346069471, 4.617358552246079, 4.661544808322667, 4.705316142407437, 4.748684028233507, 4.791659420284376, 4.8342527861087286, 4.876474136094644, 4.9183330509431755, 4.959838707054898, 5.000999900019996, 5.041825066382213, 5.082322303829225, 5.122499389946279, 5.162363799656123, 5.201922721455982, 5.241183072551464, 5.280151512977635, 5.3188344587888805, 5.35723809439155, 5.395368384086485, 5.43323108288245, 5.470831746635972, 5.508175741568165, 5.545268253204709, 5.582114294781146, 5.61871871515206, 5.655086206239478, 5.691221310052879, 5.727128425310542, 5.762811813689565, 5.798275605729691, 5.833523806414096, 5.868560300448484, 5.903388857258177, 5.93801313572141, 5.9724366886556455, 6.006662967072483, 6.040695324215583, 6.074537019394977, 6.1081912216301815, 6.1416610131136355, 6.174949392505174, 6.208059278067504, 6.24099351065197, 6.27375485654325, 6.306346010171025, 6.338769596696192, 6.3710281744785915, 6.403124237432849, 6.435060217278469], [0.0, 0.6480740698407861, 0.9165151389911681, 1.1224972160321827, 1.2961481396815722, 1.4491376746189442, 1.5874507866387546, 1.7146428199482249, 1.8330302779823362, 1.9442222095223582, 2.04939015319192, 2.149418526020468, 2.2449944320643653, 2.336664289109585, 2.4248711305964283, 2.5099800796022267, 2.5922962793631443, 2.672077843177478, 2.749545416973504, 2.8248893783651075, 2.8982753492378883, 2.9698484809835, 3.039736830714133, 3.108054053584011, 3.174901573277509, 3.2403703492039306, 3.304542328371662, 3.3674916480965478, 3.4292856398964497, 3.48998567332303, 3.5496478698597698, 3.6083237105337433, 3.6660605559646724, 3.7229020937972575, 3.7788887255382373, 3.834057902536163, 3.8884444190447165, 3.942080668885405, 3.9949968710876362, 4.047221268969613, 4.09878030638384, 4.149698784249287, 4.200000000000001, 4.249705872175156, 4.298837052040936, 4.347413023856832, 4.3954521951671826, 4.442971978304612, 4.489988864128731, 4.536518488885503, 4.582575694955841, 4.628174586162455, 4.67332857821917, 4.718050444834181, 4.762352359916264, 4.806245936279167, 4.849742261192857, 4.892851929090027, 4.935585071701227, 4.9779513858614575, 5.019960159204453, 5.061620293937506, 5.10294032886923, 5.143928459844674, 5.184592558726289, 5.224940191045253, 5.264978632435274, 5.304714883949938, 5.344155686354956, 5.383307533477909, 5.422176684690385, 5.46076917659042, 5.499090833947008, 5.537147279962851, 5.574943945906542, 5.612486080160912, 5.649778756730215, 5.686826883245173, 5.723635208501675, 5.760208329565868, 5.796550698475777, 5.832666628567075, 5.868560300448485, 5.904235767650205, 5.939696961967, 5.974947698515863, 6.009991680526689, 6.044832503882966, 6.079473661428266, 6.113918547053109, 6.148170459575759, 6.182232606429493, 6.216108107168022, 6.249799996799899, 6.283311228962004, 6.316644678941503, 6.349803146555018, 6.38278935889318, 6.4156059729381765, 6.448255578061405, 6.480740698407861, 6.5130637951735135], [0.0, 0.6557438524302001, 0.9273618495495702, 1.1357816691600549, 1.3114877048604001, 1.466287829861518, 1.606237840420901, 1.7349351572897471, 1.8547236990991405, 1.9672315572906, 2.073644135332772, 2.1748563170931545, 2.2715633383201097, 2.364318083507378, 2.453568829277059, 2.5396850198400585, 2.6229754097208002, 2.7037011669191546, 2.782085548648711, 2.8583211855912904, 2.932575659723036, 3.004995840263344, 3.0757112998459397, 3.1448370387032774, 3.212475680841802, 3.278719262151, 3.3436506994600976, 3.407345007480164, 3.4698703145794942, 3.531288716601915, 3.5916569992135936, 3.6510272527057364, 3.709447398198281, 3.7669616403674726, 3.823610858861032, 3.879432948254164, 3.9344631145812, 3.988734135035826, 4.042276586281547, 4.095119045888654, 4.147288270665544, 4.198809355043403, 4.249705872175156, 4.299999999999999, 4.349712634186309, 4.398863489584553, 4.447471191587417, 4.495553358597804, 4.543126676640219, 4.5902069670114, 4.636809247747852, 4.682947789587239, 4.728636167014756, 4.773887304912004, 4.818713521262703, 4.863126566315131, 4.907137658554118, 4.950757517794625, 4.993996395673509, 5.03686410378521, 5.079370039680117, 5.121523210920751, 5.163332257370234, 5.204805471869242, 5.2459508194416005, 5.28677595515452, 5.3272882407468805, 5.367494760127856, 5.407402333838309, 5.447017532558529, 5.486346689738081, 5.525395913416522, 5.564171097297422, 5.602677931132575, 5.6409219104681805, 5.678908345800274, 5.716642371182581, 5.754128952326321, 5.791372894228104, 5.8283788483591215, 5.865151319446072, 5.9016946718718, 5.938013135721409, 5.974110812497538, 6.009991680526688, 6.0456596000767355, 6.081118318204308, 6.1163714733492105, 6.151422599691879, 6.186275131288617, 6.220932405998315, 6.255397669213365, 6.289674077406555, 6.323764701504951, 6.357672530100933, 6.3914004725099165, 6.424951361683604, 6.458327956987009, 6.491532946846992, 6.524568951279464, 6.557438524302, 6.590144156238162], [0.0, 0.66332495807108, 0.938083151964686, 1.148912529307606, 1.32664991614216, 1.4832396974191329, 1.6248076809271923, 1.7549928774784245, 1.876166303929372, 1.98997487421324, 2.0976176963403033, 2.2, 2.297825058615212, 2.3916521486202797, 2.4819347291981715, 2.569046515733026, 2.65329983228432, 2.734958866235469, 2.814249455894058, 2.8913664589601926, 2.9664793948382657, 3.039736830714133, 3.1112698372208096, 3.1811947441173736, 3.2496153618543846, 3.3166247903554003, 3.382306905057553, 3.4467375879228177, 3.509985754956849, 3.5721142198983507, 3.63318042491699, 3.693237062523878, 3.752332607858744, 3.8105117766515306, 3.8678159211627436, 3.924283374069717, 3.97994974842648, 4.034848200366404, 4.0890096600521755, 4.1424630354415966, 4.1952353926806065, 4.247352116319061, 4.298837052040936, 4.349712634186309, 4.4, 4.449719092257398, 4.498888751680798, 4.54752680036083, 4.595650117230424, 4.64327470649756, 4.69041575982343, 4.737087712930806, 4.7833042972405595, 4.829078587059855, 4.874423042781577, 4.919349550499538, 4.963869458396343, 5.007993610219566, 5.051732376126036, 5.095095681142799, 5.138093031466052, 5.180733538795447, 5.223025942880239, 5.264978632435274, 5.30659966456864, 5.347896782848375, 5.388877434122993, 5.429548784199292, 5.469917732470938, 5.509990925582365, 5.549774770204644, 5.589275444992849, 5.628498911788116, 5.667450926121902, 5.706137047074843, 5.7445626465380295, 5.782732917920385, 5.8206528843421, 5.858327406350725, 5.895761189193471, 5.9329587896765315, 5.969924622639721, 6.006662967072484, 6.043177971895251, 6.079473661428266, 6.115553940568263, 6.15142259969188, 6.187083319303208, 6.222539674441619, 6.2577951388648065, 6.29285308902091, 6.327716807822551, 6.362389488234747, 6.3968742366877915, 6.431174076325411, 6.465291950097845, 6.499230723708769, 6.532993188424431, 6.566582063752802, 6.600000000000001, 6.6332495807108005, 6.666333324999584], [0.0, 0.6708203932499369, 0.9486832980505137, 1.161895003862225, 1.3416407864998738, 1.5, 1.6431676725154982, 1.7748239349298847, 1.8973665961010273, 2.0124611797498106, 2.1213203435596424, 2.224859546128699, 2.32379000772445, 2.4186773244895647, 2.5099800796022262, 2.5980762113533156, 2.6832815729997477, 2.765863337187866, 2.846049894151541, 2.924038303442689, 3.0, 3.0740852297878796, 3.1464265445104544, 3.2171415884290826, 3.2863353450309964, 3.3541019662496843, 3.420526275297414, 3.4856850115866753, 3.5496478698597693, 3.6124783736376886, 3.674234614174767, 3.7349698793966195, 3.7947331922020546, 3.853569773599539, 3.911521443121589, 3.9686269665968856, 4.024922359499621, 4.080441152620633, 4.135214625627066, 4.189272013130682, 4.242640687119285, 4.295346318982906, 4.347413023856832, 4.398863489584553, 4.449719092257398, 4.499999999999999, 4.54972526643093, 4.598912915026768, 4.6475800154489, 4.695742752749558, 4.743416490252569, 4.790615826801393, 4.8373546489791295, 4.883646178829912, 4.9295030175464944, 4.9749371855331, 5.0199601592044525, 5.064582904840239, 5.10881590977792, 5.1526692111953, 5.196152422706631, 5.239274758971893, 5.282045058497702, 5.324471804789654, 5.366563145999495, 5.4083269131959835, 5.449770637375485, 5.490901565316937, 5.531726674375732, 5.572252686302012, 5.612486080160912, 5.652433104425031, 5.692099788303082, 5.731491952362839, 5.770615218501403, 5.809475019311125, 5.848076606885378, 5.886425061104575, 5.92452529743945, 5.962382074305537, 6.0, 6.037383539249432, 6.074537019394977, 6.111464636239008, 6.148170459575759, 6.18465843842649, 6.220932405998316, 6.256996084384263, 6.292853089020909, 6.328506932918695, 6.363961030678928, 6.399218702310462, 6.434283176858165, 6.469157595854347, 6.5038450166036395, 6.53834841531101, 6.572670690061993, 6.606814663663572, 6.640783086353596, 6.674578638386096, 6.7082039324993685, 6.74166151627327], [0.0, 0.6782329983125268, 0.9591663046625439, 1.1747340124470733, 1.3564659966250536, 1.5165750888103102, 1.661324772583615, 1.7944358444926363, 1.9183326093250879, 2.0346989949375804, 2.1447610589527217, 2.249444375840399, 2.3494680248941466, 2.445403852127497, 2.5377155080899043, 2.626785107312739, 2.7129319932501073, 2.7964262908219126, 2.877498913987632, 2.956349099818897, 3.0331501776206204, 3.108054053584011, 3.1811947441173736, 3.252691193458119, 3.32264954516723, 3.3911649915626345, 3.458323293158117, 3.5242020373412197, 3.5888716889852725, 3.6523964735499352, 3.714835124201342, 3.7762415176998414, 3.8366652186501757, 3.896151947755632, 3.954743986657038, 4.012480529547776, 4.069397989875161, 4.125530268947254, 4.180908992073375, 4.235563716909475, 4.2895221179054435, 4.342810150121693, 4.3954521951671826, 4.447471191587417, 4.498888751680798, 4.54972526643093, 4.6000000000000005, 4.649731175025068, 4.698936049788293, 4.747630988187688, 4.79583152331272, 4.843552415324934, 4.890807704254994, 4.937610758251404, 4.983974317750845, 5.029910535983717, 5.075431016179809, 5.120546845796843, 5.165268628057984, 5.209606511052442, 5.253570214625478, 5.297169055259611, 5.340411969127476, 5.383307533477908, 5.4258639865002145, 5.468089245796926, 5.509990925582365, 5.551576352712804, 5.592852581643825, 5.63382640840131, 5.674504383644443, 5.71489282489182, 5.754997827975264, 5.794825277780168, 5.834380858325929, 5.873670062235366, 5.912698199637794, 5.951470406546605, 5.989991652748776, 6.028266749240615, 6.066300355241241, 6.104096984812742, 6.1416610131136355, 6.178996682310163, 6.216108107168022, 6.252999280345393, 6.289674077406556, 6.326136261573884, 6.362389488234747, 6.398437309218556, 6.434283176858165, 6.469930447848725, 6.505382386916238, 6.540642170307134, 6.57571288910944, 6.6105975524153635, 6.64529909033446, 6.679820356865895, 6.714164132637808, 6.748333127521196, 6.782329983125269, 6.81615727518079], [0.0, 0.6855654600401044, 0.9695359714832658, 1.187434208703792, 1.3711309200802089, 1.5329709716755893, 1.6792855623746665, 1.8138357147217055, 1.9390719429665315, 2.056696380120313, 2.16794833886788, 2.273763400180415, 2.374868417407584, 2.471841418861655, 2.565151067676132, 2.6551836094703507, 2.7422618401604177, 2.826658805020514, 2.9086079144497976, 2.9883105594967874, 3.0659419433511785, 3.1416556144810017, 3.2155870381627056, 3.2878564445547194, 3.358571124749333, 3.4278273002005224, 3.4957116585897072, 3.5623026261113755, 3.627671429443411, 3.691882988394947, 3.7549966711037173, 3.817066936798463, 3.878143885933063, 3.9382737335030438, 3.997499218261337, 4.05585995813465, 4.113392760240626, 4.170131892398609, 4.226109321823088, 4.281354925721529, 4.33589667773576, 4.389760813529594, 4.442971978304612, 4.495553358597804, 4.54752680036083, 4.598912915026768, 4.649731175025068, 4.7, 4.749736834815168, 4.798958220280731, 4.847679857416329, 4.89591666595746, 4.94368283772331, 4.990991885387113, 5.037856687124, 5.084289527554465, 5.130302135352264, 5.175905717843014, 5.221110992882646, 5.265928218272634, 5.310367218940701, 5.354437412091022, 5.3981478305063115, 5.441507144165117, 5.4845236803208355, 5.527205442174191, 5.569560126257728, 5.61159513863928, 5.653317610041028, 5.69473440996154, 5.735852159879995, 5.776677245614472, 5.817215828899595, 5.857473858242988, 5.897457079114692, 5.937171043518958, 5.976621118993575, 6.015812497078014, 6.054750201288242, 6.09343909463285, 6.131883886702357, 6.17008914036094, 6.208059278067503, 6.245798587850876, 6.2833112289620034, 6.320601237224193, 6.357672530100934, 6.394528911499267, 6.431174076325411, 6.4676116148080505, 6.5038450166036395, 6.539877674696982, 6.575712889109439, 6.611353870426239, 6.646803743153547, 6.682065548915245, 6.717142249498666, 6.7520367297579185, 6.786751800382861, 6.821290200541244, 6.855654600401045, 6.889847603539574], [0.0, 0.692820323027551, 0.9797958971132713, 1.2000000000000004, 1.385640646055102, 1.549193338482967, 1.6970562748477143, 1.8330302779823362, 1.9595917942265426, 2.078460969082653, 2.1908902300206647, 2.297825058615212, 2.400000000000001, 2.4979991993593598, 2.5922962793631443, 2.6832815729997477, 2.771281292110204, 2.8565713714171403, 2.9393876913398143, 3.0199337741083006, 3.098386676965934, 3.174901573277509, 3.2496153618543846, 3.3226495451672307, 3.3941125496954285, 3.4641016151377553, 3.5327043465311396, 3.6000000000000005, 3.6660605559646724, 3.7309516212355267, 3.7947331922020555, 3.8574603043971827, 3.9191835884530852, 3.9799497484264807, 4.039801975344832, 4.09878030638384, 4.156921938165306, 4.214261501141096, 4.270831300812525, 4.326661530556788, 4.3817804600413295, 4.436214602563767, 4.489988864128731, 4.543126676640219, 4.595650117230424, 4.6475800154489, 4.698936049788293, 4.749736834815168, 4.800000000000002, 4.849742261192857, 4.898979485566357, 4.947726750741194, 4.9959983987187195, 5.043808085167398, 5.091168824543143, 5.1380930314660525, 5.184592558726289, 5.230678732248809, 5.276362383309169, 5.321653878260029, 5.366563145999495, 5.411099703387474, 5.455272678794342, 5.499090833947009, 5.542562584220408, 5.585696017507577, 5.628498911788117, 5.670978751503131, 5.713142742834281, 5.754997827975265, 5.796550698475777, 5.83780780773057, 5.8787753826796285, 5.9194594347794975, 5.959865770300536, 6.000000000000001, 6.039867548216601, 6.079473661428266, 6.1188234163113435, 6.157921727336262, 6.196773353931868, 6.235382907247959, 6.27375485654325, 6.311893535223801, 6.349803146555018, 6.387487769068526, 6.424951361683605, 6.462197768561406, 6.499230723708769, 6.536053855347277, 6.572670690061994, 6.609084656743323, 6.645299090334461, 6.681317235396028, 6.717142249498667, 6.752777206453653, 6.788225099390857, 6.823488843692794, 6.8585712797928995, 6.893475175845635, 6.9282032302755105, 6.962758074211686], [0.0, 0.7000000000000001, 0.9899494936611665, 1.2124355652982142, 1.4000000000000001, 1.565247584249853, 1.7146428199482247, 1.8520259177452134, 1.979898987322333, 2.1, 2.2135943621178655, 2.32163735324878, 2.4248711305964283, 2.5238858928247927, 2.619160170741759, 2.7110883423451915, 2.8000000000000003, 2.8861739379323623, 2.9698484809834995, 3.051229260478472, 3.130495168499706, 3.2078029864690882, 3.283291031876401, 3.357082066318904, 3.4292856398964493, 3.5, 3.5693136595149495, 3.6373066958946425, 3.704051835490427, 3.769615364994153, 3.8340579025361627, 3.8974350539810154, 3.959797974644666, 4.02119385257662, 4.08166632639171, 4.141255848169731, 4.2, 4.257933771208754, 4.315089802078284, 4.371498598878879, 4.427188724235731, 4.4821869662029945, 4.536518488885503, 4.5902069670114, 4.64327470649756, 4.695742752749558, 4.747630988187688, 4.798958220280731, 4.849742261192857, 4.9, 4.949747468305833, 4.998999899979996, 5.047771785649585, 5.096076922496363, 5.143928459844674, 5.191338940966964, 5.238320341483518, 5.2848841046895245, 5.331041174104736, 5.376802023508025, 5.422176684690383, 5.467174773134658, 5.511805511808268, 5.55607775323564, 5.6000000000000005, 5.643580423808984, 5.686826883245172, 5.729746940310715, 5.772347875864725, 5.814636704042653, 5.856620185738529, 5.898304841223451, 5.939696961966999, 5.980802621722272, 6.021627686929839, 6.06217782649107, 6.102458520956944, 6.142475071174486, 6.182232606429493, 6.221736092120913, 6.260990336999412, 6.300000000000001, 6.338769596696192, 6.377303505401009, 6.4156059729381765, 6.4536811201050215, 6.491532946846993, 6.529165337162171, 6.566582063752802, 6.603786792439623, 6.640783086353597, 6.67757440991862, 6.714164132637808, 6.750555532695069, 6.786751800382861, 6.822756041366274, 6.858571279792899, 6.894200461257274, 6.929646455628165, 6.96491205974634, 7.0, 7.034912934784624], [0.0, 0.7071067811865476, 1.0, 1.2247448713915892, 1.4142135623730951, 1.5811388300841898, 1.7320508075688774, 1.8708286933869709, 2.0, 2.1213203435596424, 2.23606797749979, 2.345207879911715, 2.4494897427831783, 2.5495097567963927, 2.6457513110645907, 2.7386127875258306, 2.8284271247461903, 2.9154759474226504, 3.0, 3.082207001484489, 3.1622776601683795, 3.2403703492039306, 3.3166247903554003, 3.3911649915626345, 3.464101615137755, 3.535533905932738, 3.6055512754639896, 3.6742346141747677, 3.7416573867739418, 3.8078865529319548, 3.872983346207417, 3.9370039370059056, 4.0, 4.06201920231798, 4.123105625617661, 4.183300132670378, 4.242640687119285, 4.301162633521314, 4.358898943540674, 4.415880433163924, 4.47213595499958, 4.527692569068709, 4.582575694955841, 4.636809247747852, 4.69041575982343, 4.743416490252569, 4.79583152331272, 4.847679857416329, 4.898979485566357, 4.949747468305833, 5.000000000000001, 5.04975246918104, 5.099019513592785, 5.147815070493501, 5.196152422706632, 5.244044240850759, 5.291502622129181, 5.338539126015656, 5.385164807134505, 5.431390245600108, 5.477225575051661, 5.522680508593631, 5.5677643628300215, 5.612486080160912, 5.656854249492381, 5.70087712549569, 5.744562646538029, 5.787918451395113, 5.830951894845301, 5.873670062235366, 5.916079783099617, 5.958187643906493, 6.0, 6.041522986797286, 6.082762530298219, 6.123724356957946, 6.164414002968978, 6.2048368229954285, 6.244997998398399, 6.284902544988268, 6.324555320336759, 6.3639610306789285, 6.403124237432849, 6.442049363362563, 6.480740698407861, 6.519202405202649, 6.557438524302001, 6.59545297913646, 6.6332495807108005, 6.670832032063167, 6.708203932499369, 6.745368781616021, 6.782329983125269, 6.8190908484929285, 6.855654600401045, 6.892024376045111, 6.92820323027551, 6.9641941385920605, 7.0, 7.035623639735145, 7.071067811865476, 7.1063352017759485], [0.0, 0.7141428428542851, 1.0099504938362078, 1.2369316876852985, 1.4282856857085702, 1.5968719422671316, 1.7492855684535904, 1.8894443627691186, 2.0199009876724157, 2.142428528562855, 2.2583179581272432, 2.368543856465403, 2.473863375370597, 2.574878637916747, 2.672077843177478, 2.765863337187866, 2.8565713714171403, 2.944486372867092, 3.029851481508624, 3.1128764832546767, 3.193743884534263, 3.272613634390715, 3.3496268448888458, 3.4249087579087423, 3.498571136907181, 3.5707142142714257, 3.6414282912066254, 3.7107950630558952, 3.7788887255382373, 3.845776904605883, 3.9115214431215892, 3.9761790704142093, 4.039801975344831, 4.102438299353204, 4.164132562731403, 4.224926034855522, 4.28485705712571, 4.343961325794695, 4.402272140611029, 4.459820624195553, 4.5166359162544865, 4.572745346069471, 4.628174586162455, 4.682947789587239, 4.737087712930806, 4.790615826801393, 4.843552415324934, 4.89591666595746, 4.947726750741194, 4.998999899979996, 5.04975246918104, 5.100000000000001, 5.149757275833494, 5.199038372622384, 5.247856705360771, 5.296225070746145, 5.344155686354956, 5.391660226683429, 5.43874985635486, 5.485435260760991, 5.531726674375732, 5.577633906953737, 5.62316636780382, 5.668333088307356, 5.713142742834281, 5.757603668193913, 5.801723881744115, 5.845511098270194, 5.888972745734184, 5.932115979985557, 5.974947698515863, 6.017474553332154, 6.059702963017248, 6.101639124038721, 6.143289021363068, 6.184658438426491, 6.225752966509353, 6.266578013557321, 6.307138812488593, 6.347440429023341, 6.387487769068526, 6.427285585688566, 6.466838485689898, 6.506150935845249, 6.54522726878143, 6.584071688552609, 6.62268827591938, 6.661080993352356, 6.6992536897776915, 6.73721010508059, 6.77495387438173, 6.81248853210044, 6.8498175158174845, 6.886944169949399, 6.923871749245506, 6.960603422117942, 6.997142273814362, 7.033491309442276, 7.069653456853455, 7.105631569396208, 7.141428428542851, 7.177046746399247], [0.0, 0.7211102550927979, 1.019803902718557, 1.2489995996796799, 1.4422205101855958, 1.61245154965971, 1.7663521732655696, 1.9078784028338915, 2.039607805437114, 2.1633307652783937, 2.280350850198276, 2.3916521486202797, 2.4979991993593598, 2.6000000000000005, 2.6981475126464085, 2.792848008753788, 2.8844410203711917, 2.973213749463701, 3.0594117081556713, 3.1432467291003428, 3.22490309931942, 3.3045423283716615, 3.3823069050575527, 3.458323293158117, 3.532704346531139, 3.6055512754639896, 3.6769552621700474, 3.7469987990390394, 3.815756805667783, 3.88329756778952, 3.9496835316262997, 4.014971979976947, 4.079215610874228, 4.1424630354415966, 4.204759208325728, 4.266145801540309, 4.3266615305567875, 4.386342439892262, 4.445222154178574, 4.503332099679081, 4.560701700396552, 4.617358552246079, 4.67332857821917, 4.728636167014756, 4.7833042972405595, 4.8373546489791295, 4.890807704254994, 4.94368283772331, 4.9959983987187195, 5.047771785649585, 5.099019513592785, 5.149757275833494, 5.200000000000001, 5.249761899362676, 5.299056519796709, 5.347896782848376, 5.396295025292817, 5.44426303552648, 5.491812087098393, 5.5389529696504916, 5.585696017507576, 5.63205113613149, 5.678027826631356, 5.723635208501674, 5.768882040742383, 5.813776741499453, 5.858327406350725, 5.902541825349482, 5.946427498927402, 5.989991652748776, 6.033241251599343, 6.076183012385325, 6.118823416311343, 6.161168720299745, 6.203224967708329, 6.244997998398398, 6.2864934582006855, 6.327716807822551, 6.3686733312362644, 6.409368143584826, 6.44980619863884, 6.489992295835181, 6.529931086925804, 6.569627082262737, 6.609084656743323, 6.648308055437865, 6.687301398920196, 6.726068688320096, 6.764613810115105, 6.802940540677979, 6.841052550594828, 6.878953408767936, 6.916646586316234, 6.954135460285485, 6.9914233171794145, 7.0285133563222315, 7.065408693062278, 7.102112361825883, 7.138627319029899, 7.17495644586084, 7.211102550927979, 7.247068372797377], [0.0, 0.7280109889280519, 1.0295630140987002, 1.2609520212918495, 1.4560219778561039, 1.627882059609971, 1.7832554500127011, 1.9261360284258224, 2.0591260281974004, 2.1840329667841556, 2.302172886644268, 2.4145392935299275, 2.521904042583699, 2.624880949681338, 2.7239676943752476, 2.819574435974337, 2.9120439557122078, 3.001666203960727, 3.0886890422961004, 3.1733263305244868, 3.255764119219942, 3.336165463522456, 3.414674215792775, 3.491418050019219, 3.5665109000254023, 3.64005494464026, 3.712142238654118, 3.782856063875548, 3.852272056851645, 3.9204591567825324, 3.9874804074753776, 4.053393639902249, 4.118252056394801, 4.182104733265298, 4.244997055358225, 4.306971093471606, 4.368065933568311, 4.428317965096906, 4.487761134463376, 4.546427168667723, 4.604345773288536, 4.661544808322667, 4.718050444834181, 4.773887304912004, 4.829078587059855, 4.883646178829912, 4.937610758251404, 4.990991885387113, 5.043808085167398, 5.096076922496363, 5.147815070493501, 5.199038372622384, 5.249761899362676, 5.300000000000001, 5.349766350038103, 5.399073994677236, 5.447935388750495, 5.496362433464519, 5.5443665102516455, 5.591958512006326, 5.639148871948674, 5.6859475903318, 5.732364259186606, 5.7784080852774675, 5.8240879114244155, 5.869412236331676, 5.914389233048499, 5.959026766175833, 6.003332407921454, 6.047313453096343, 6.090976933136425, 6.134329629226001, 6.177378084592201, 6.220128616033596, 6.262587324740471, 6.304760106459247, 6.3466526610489735, 6.388270501473776, 6.429618962271405, 6.470703207534712, 6.511528238439884, 6.552098900352467, 6.592419889539805, 6.632495759516172, 6.672330927044912, 6.711929677819935, 6.751296171847301, 6.790434448545985, 6.82934843158555, 6.868041933477111, 6.906518659932804, 6.944782214007867, 6.982836100038438, 7.020683727387242, 7.058328414008519, 7.095773389842717, 7.1330218000508046, 7.170076708097342, 7.206941098690901, 7.243617880589783, 7.28010988928052, 7.31641988953614], [0.0, 0.7348469228349535, 1.0392304845413265, 1.2727922061357857, 1.469693845669907, 1.6431676725154984, 1.8, 1.9442222095223582, 2.078460969082653, 2.2045407685048604, 2.32379000772445, 2.4372115213907883, 2.5455844122715714, 2.6495282598983545, 2.749545416973504, 2.846049894151541, 2.939387691339814, 3.0298514815086235, 3.1176914536239795, 3.203123475609394, 3.286335345030997, 3.3674916480965478, 3.4467375879228173, 3.5242020373412197, 3.6, 3.6742346141747677, 3.7469987990390394, 3.818376618407357, 3.8884444190447165, 3.957271787481876, 4.024922359499621, 4.091454509095757, 4.156921938165306, 4.221374183841087, 4.28485705712571, 4.347413023856832, 4.409081537009721, 4.469899327725402, 4.529900661162451, 4.589117562233507, 4.6475800154489, 4.705316142407437, 4.762352359916264, 4.818713521262703, 4.874423042781577, 4.9295030175464944, 4.983974317750845, 5.037856687124, 5.091168824543143, 5.143928459844674, 5.196152422706632, 5.247856705360771, 5.299056519796709, 5.349766350038103, 5.4, 5.449770637375486, 5.499090833947008, 5.547972602672079, 5.596427431853289, 5.644466316668034, 5.692099788303082, 5.739337940912697, 5.786190456595773, 5.8326666285670745, 5.878775382679628, 5.924525297439449, 5.96992462263972, 6.014981296729027, 6.059702963017247, 6.104096984812742, 6.148170459575759, 6.191930232165088, 6.235382907247959, 6.278534860936905, 6.321392251711643, 6.363961030678928, 6.406246951218788, 6.448255578061404, 6.489992295835182, 6.5314623171231725, 6.572670690061994, 6.613622305514581, 6.654321903845651, 6.694774081326419, 6.7349832961930955, 6.77495387438173, 6.814690014960329, 6.854195795277518, 6.8934751758456345, 6.932532004974806, 6.971370023173351, 7.009992867328754, 7.0484040746824395, 7.0866070866106305, 7.124605252222751, 7.162401831787993, 7.2, 7.237402849088892, 7.274613391789285, 7.3116345641723655, 7.348469228349535, 7.385120175054704], [0.0, 0.7416198487095663, 1.0488088481701516, 1.2845232578665131, 1.4832396974191326, 1.6583123951777001, 1.8165902124584952, 1.9621416870348585, 2.0976176963403033, 2.224859546128699, 2.345207879911715, 2.459674775249769, 2.5690465157330262, 2.673948391424188, 2.7748873851023217, 2.8722813232690143, 2.9664793948382653, 3.0577769702841313, 3.146426544510455, 3.232645975048923, 3.3166247903554003, 3.398529093593286, 3.4785054261852175, 3.5566838487557484, 3.6331804249169903, 3.708099243547832, 3.7815340802378077, 3.853569773599539, 3.924283374069717, 3.993745109543172, 4.06201920231798, 4.129164564412516, 4.1952353926806065, 4.260281680828159, 4.324349662087931, 4.387482193696061, 4.449719092257398, 4.511097427455985, 4.571651780264984, 4.631414470763765, 4.69041575982343, 4.748684028233507, 4.806245936279167, 4.863126566315131, 4.919349550499538, 4.9749371855331, 5.029910535983717, 5.084289527554465, 5.1380930314660525, 5.191338940966964, 5.244044240850759, 5.296225070746145, 5.347896782848376, 5.399073994677236, 5.449770637375486, 5.5, 5.549774770204643, 5.599107071667768, 5.648008498577176, 5.6964901474504455, 5.744562646538029, 5.792236183029832, 5.839520528262573, 5.886425061104576, 5.932958789676531, 5.979130371550699, 6.024948132556827, 6.070420084310475, 6.115553940568263, 6.1603571325045765, 6.2048368229954285, 6.248999919987198, 6.29285308902091, 6.336402764976356, 6.3796551630946325, 6.422616289332565, 6.465291950097846, 6.507687761409578, 6.549809157525127, 6.591661399070799, 6.6332495807108005, 6.674578638386097, 6.715653356152327, 6.756478372643548, 6.797058187186572, 6.837397165588672, 6.87749954561976, 6.917369442208505, 6.957010852370435, 6.996427659884722, 7.035623639735144, 7.074602462329597, 7.113367697511497, 7.15192281837549, 7.1902712048990205, 7.2284161474004796, 7.266360849833981, 7.30410843293006, 7.341661937191061, 7.379024325749307, 7.416198487095664, 7.4531872376856345], [0.0, 0.7483314773547883, 1.058300524425836, 1.2961481396815722, 1.4966629547095767, 1.6733200530681511, 1.833030277982336, 1.9798989873223332, 2.116601048851672, 2.244994432064365, 2.3664319132398464, 2.4819347291981715, 2.5922962793631443, 2.6981475126464085, 2.8, 2.8982753492378874, 2.9933259094191533, 3.0854497241083023, 3.1749015732775088, 3.2619012860600183, 3.3466401061363023, 3.4292856398964493, 3.509985754956849, 3.5888716889852725, 3.666060555964672, 3.7416573867739413, 3.8157568056677826, 3.8884444190447165, 3.9597979746446663, 4.029888335921977, 4.098780306383839, 4.166533331199932, 4.233202097703344, 4.298837052040936, 4.363484845854286, 4.427188724235731, 4.48998886412873, 4.551922670696417, 4.613025037868319, 4.673328578219169, 4.732863826479693, 4.791659420284376, 4.849742261192857, 4.907137658554118, 4.963869458396343, 5.0199601592044525, 5.075431016179809, 5.130302135352264, 5.184592558726289, 5.238320341483518, 5.291502622129181, 5.344155686354956, 5.396295025292817, 5.447935388750495, 5.499090833947008, 5.549774770204643, 5.6, 5.649778756730214, 5.6991227395100035, 5.748043145279965, 5.796550698475775, 5.844655678480983, 5.892367945062493, 5.939696961966999, 5.986651818838307, 6.033241251599342, 6.079473661428265, 6.125357132445422, 6.170899448216605, 6.216108107168021, 6.260990336999411, 6.305553108173778, 6.3498031465550175, 6.393746945258312, 6.437390775772432, 6.48074069840786, 6.523802572120037, 6.566582063752802, 6.609084656743323, 6.6513156593263565, 6.6932802122726045, 6.734983296193095, 6.776429738438967, 6.817624219623724, 6.858571279792899, 6.899275324264136, 6.939740629158989, 6.979971346646059, 7.019971509913698, 7.059745037889116, 7.099295739719539, 7.138627319029899, 7.177743377970545, 7.216647421067487, 7.255342858886822, 7.293833011524187, 7.332121111929344, 7.370210309075312, 7.408103670980854, 7.445804187594514, 7.483314773547883, 7.520638270785267], [0.0, 0.754983443527075, 1.0677078252031311, 1.3076696830622023, 1.50996688705415, 1.6881943016134133, 1.849324200890693, 1.997498435543818, 2.1354156504062622, 2.264950330581225, 2.3874672772626644, 2.503996805109783, 2.6153393661244047, 2.72213151776324, 2.824889378365107, 2.924038303442689, 3.0199337741083, 3.1128764832546763, 3.2031234756093934, 3.290896534380867, 3.3763886032268267, 3.459768778401239, 3.5411862419251547, 3.620773398046335, 3.698648401781386, 3.774917217635375, 3.849675310984032, 3.9230090491866063, 3.994996871087636, 4.065710270051224, 4.135214625627066, 4.20356991139674, 4.2708313008125245, 4.337049688440288, 4.402272140611028, 4.466542286825459, 4.52990066116245, 4.592385001282014, 4.654030511288038, 4.7148700936505135, 4.774934554525329, 4.8342527861087286, 4.892851929090027, 4.950757517794625, 5.007993610219566, 5.064582904840239, 5.120546845796843, 5.175905717843014, 5.230678732248809, 5.2848841046895245, 5.338539126015656, 5.391660226683429, 5.44426303552648, 5.496362433464519, 5.547972602672079, 5.599107071667768, 5.649778756730214, 5.7, 5.749782604586021, 5.799137866959191, 5.848076606885378, 5.8966091951222275, 5.944745579080739, 5.9924953066314535, 6.0398675482166, 6.08687111741328, 6.133514490078261, 6.17980582219215, 6.2257529665093525, 6.271363488110062, 6.316644678941503, 6.361603571427569, 6.406246951218787, 6.450581369148055, 6.494613152451807, 6.5383484153110105, 6.581793068761734, 6.624952830020755, 6.667833231267862, 6.710439627923047, 6.752777206453653, 6.794850991743675, 6.836665854054885, 6.878226515607057, 6.919537556802478, 6.960603422117942, 7.001428425685718, 7.042016756583302, 7.0823724838503095, 7.122499561249548, 7.162401831787993, 7.202083032012336, 7.24154679609267, 7.280796659706959, 7.31983606373804, 7.358668357794092, 7.397296803562772, 7.4357245780085215, 7.473954776421918, 7.5119904153293495, 7.54983443527075, 7.587489703452652], [0.0, 0.7615773105863909, 1.0770329614269007, 1.3190905958272923, 1.5231546211727818, 1.7029386365926404, 1.8654758106177631, 2.0149441679609885, 2.1540659228538015, 2.2847319317591723, 2.4083189157584592, 2.525866188063018, 2.6381811916545845, 2.7459060435491964, 2.8495613697550017, 2.9495762407505253, 3.0463092423455636, 3.1400636936215167, 3.2310988842807027, 3.319638534539567, 3.405877273185281, 3.48998567332303, 3.5721142198983507, 3.6523964735499352, 3.7309516212355263, 3.8078865529319548, 3.8832975677895205, 3.957271787481876, 4.029888335921977, 4.101219330881976, 4.171330722922842, 4.240283009422838, 4.308131845707603, 4.374928570845472, 4.440720662234904, 4.505552130427525, 4.569463863518345, 4.632493928760188, 4.694677837722201, 4.756048780237647, 4.8166378315169185, 4.876474136094644, 4.935585071701227, 4.993996395673509, 5.051732376126036, 5.10881590977792, 5.165268628057984, 5.221110992882646, 5.276362383309169, 5.331041174104736, 5.385164807134505, 5.43874985635486, 5.491812087098393, 5.5443665102516455, 5.596427431853289, 5.648008498577176, 5.6991227395100035, 5.749782604586021, 5.800000000000001, 5.849786320883866, 5.8991524815010505, 5.948108943185221, 5.99666574022598, 6.044832503882966, 6.092618484691127, 6.1400325732035, 6.187083319303208, 6.23377895020348, 6.280127387243033, 6.326136261573885, 6.3718129288295975, 6.417164482853779, 6.462197768561405, 6.5069193939989765, 6.55133574166368, 6.59545297913646, 6.639277069079134, 6.682813778641449, 6.726068688320096, 6.76904720030818, 6.811754546370562, 6.854195795277518, 6.8963758598266685, 6.938299503480662, 6.97997134664606, 7.021395872616784, 7.062577433203831, 7.103520254071217, 7.144228439796701, 7.184705978674423, 7.224956747275378, 7.264984514780469, 7.3047929470998705, 7.3443856107914165, 7.383765976789894, 7.4229374239582535, 7.4619032424710525, 7.5006666370396715, 7.539230729988306, 7.577598564189055, 7.6157731058639095, 7.653757247260983], [0.0, 0.7681145747868608, 1.0862780491200215, 1.3304134695650072, 1.5362291495737217, 1.7175564037317668, 1.8814887722226779, 2.0322401432901573, 2.172556098240043, 2.3043437243605824, 2.4289915602982237, 2.5475478405713994, 2.6608269391300143, 2.7694764848252458, 2.8740215726399825, 2.974894956128703, 3.0724582991474434, 3.167017524422623, 3.2588341473600644, 3.3481338085566414, 3.4351128074635335, 3.5199431813596083, 3.602776706930364, 3.6837480912787726, 3.7629775444453557, 3.840572873934304, 3.916631205513228, 3.9912404086950213, 4.064480286580315, 4.136423575989287, 4.207136793592525, 4.276680956068619, 4.345112196480086, 4.412482294582042, 4.4788391353117385, 4.544227107000705, 4.608687448721165, 4.672258554489466, 4.734976240700686, 4.796873982084583, 4.857983120596447, 4.9183330509431755, 4.9779513858614575, 5.03686410378521, 5.095095681142799, 5.1526692111953, 5.209606511052442, 5.265928218272634, 5.321653878260029, 5.376802023508025, 5.431390245600108, 5.485435260760991, 5.5389529696504916, 5.591958512006326, 5.644466316668034, 5.6964901474504455, 5.748043145279965, 5.799137866959191, 5.849786320883866, 5.8999999999999995, 5.949789912257406, 5.999166608788257, 6.048140210014975, 6.096720429870472, 6.144916598294887, 6.192737682156413, 6.240192304729077, 6.287288763847259, 6.334035048845246, 6.380438856379708, 6.4265076052238514, 6.472248450113762, 6.517668294720129, 6.562773803811921, 6.607571414672716, 6.652067347825035, 6.696267617113283, 6.740178039191546, 6.783804242458652, 6.827151675479314, 6.870225614927067, 6.913031173081747, 6.955573304911681, 6.997856814768361, 7.0398863627192165, 7.0816664705420855, 7.123201527403251, 7.164495795239188, 7.205553413860728, 7.246378405796926, 7.286974680894671, 7.327346040688948, 7.367496182557545, 7.407428703673091, 7.447147104764348, 7.486654793697916, 7.525955088890711, 7.565051222562872, 7.603946343840151, 7.642643521714199, 7.681145747868608, 7.719455939378112], [0.0, 0.7745966692414833, 1.0954451150103321, 1.3416407864998738, 1.5491933384829666, 1.7320508075688772, 1.8973665961010275, 2.0493901531919194, 2.1908902300206643, 2.3237900077244498, 2.449489742783178, 2.569046515733026, 2.6832815729997477, 2.792848008753788, 2.8982753492378874, 2.9999999999999996, 3.098386676965933, 3.1937438845342623, 3.2863353450309964, 3.3763886032268267, 3.4641016151377544, 3.5496478698597693, 3.63318042491699, 3.714835124201342, 3.794733192202055, 3.8729833462074166, 3.9496835316262997, 4.024922359499621, 4.098780306383839, 4.171330722922842, 4.242640687119285, 4.3127717305695645, 4.381780460041329, 4.449719092257398, 4.516635916254486, 4.58257569495584, 4.6475800154488995, 4.711687595755898, 4.774934554525329, 4.8373546489791295, 4.898979485566356, 4.959838707054898, 5.019960159204453, 5.079370039680117, 5.138093031466052, 5.196152422706631, 5.253570214625478, 5.310367218940701, 5.366563145999495, 5.422176684690383, 5.477225575051661, 5.531726674375732, 5.585696017507576, 5.639148871948674, 5.692099788303082, 5.744562646538029, 5.796550698475775, 5.848076606885378, 5.8991524815010505, 5.949789912257406, 5.999999999999999, 6.049793384901669, 6.099180272790762, 6.148170459575758, 6.196773353931866, 6.244997998398397, 6.292853089020909, 6.340346993658943, 6.387487769068525, 6.434283176858164, 6.48074069840786, 6.526867548832287, 6.572670690061993, 6.618156843109718, 6.663332499583071, 6.7082039324993685, 6.752777206453653, 6.797058187186571, 6.841052550594828, 6.884765791223402, 6.928203230275509, 6.97137002317335, 7.014271166700073, 7.056911505750939, 7.099295739719539, 7.1414284285428495, 7.183313998427188, 7.224956747275377, 7.26636084983398, 7.307530362578043, 7.348469228349534, 7.389181280764466, 7.429670248402684, 7.469939758793239, 7.5099933422074345, 7.549834435270749, 7.58946638440411, 7.628892449104261, 7.668115805072325, 7.707139547199078, 7.745966692414833, 7.784600182411426], [0.0, 0.7810249675906654, 1.104536101718726, 1.3527749258468684, 1.5620499351813308, 1.746424919657298, 1.9131126469708992, 2.0663978319771825, 2.209072203437452, 2.3430749027719964, 2.4698178070456938, 2.5903667693977237, 2.705549851693737, 2.816025568065745, 2.9223278392404914, 3.0248966924508345, 3.1240998703626617, 3.2202484376209237, 3.3136083051561784, 3.4044089061098406, 3.492849839314596, 3.5791060336346563, 3.6633318168028404, 3.745664160065609, 3.8262252939417984, 3.9051248379533274, 3.9824615503479754, 4.058324777540605, 4.132795663954365, 4.205948168962618, 4.277849927241487, 4.34856298103178, 4.418144406874904, 4.486646854834912, 4.5541190146942805, 4.620606020859168, 4.686149805543993, 4.750789408087881, 4.814561246884289, 4.87749935930288, 4.9396356140913875, 5.000999900019996, 5.061620293937506, 5.121523210920751, 5.180733538795447, 5.239274758971893, 5.297169055259611, 5.354437412091022, 5.411099703387474, 5.467174773134658, 5.522680508593631, 5.577633906953737, 5.63205113613149, 5.6859475903318, 5.739337940912697, 5.792236183029832, 5.844655678480983, 5.8966091951222275, 5.948108943185221, 5.999166608788257, 6.049793384901669, 6.1, 6.149796744608719, 6.199193495931548, 6.248199740725323, 6.296824596572465, 6.345076831686122, 6.392964883369843, 6.440496875241847, 6.487680633323437, 6.534523701081817, 6.5810333535091585, 6.627216610312357, 6.673080248281149, 6.71863081289633, 6.7638746292343415, 6.808817812219681, 6.853466276272176, 6.897825744392215, 6.941901756723442, 6.985699678629192, 7.029224708315989, 7.07248188403477, 7.115476090888086, 7.158212067269313, 7.200694410957877, 7.242927584892728, 7.284915922644544, 7.326663633605681, 7.368174807915458, 7.409453421137082, 7.450503338701353, 7.491328320131218, 7.531932023060219, 7.572318007057021, 7.6124897372673015, 7.652450587883597, 7.692203845452876, 7.731752712031082, 7.771100308193172, 7.810249675906655, 7.849203781276163], [0.0, 0.787400787401181, 1.1135528725660042, 1.3638181696985856, 1.574801574802362, 1.760681686165901, 1.928730152198591, 2.083266665599966, 2.2271057451320084, 2.362202362203543, 2.4899799195977463, 2.6115129714401193, 2.727636339397171, 2.839013913315678, 2.9461839725312466, 3.049590136395381, 3.149603149604724, 3.246536616149585, 3.340658617698013, 3.432200460346103, 3.521363372331802, 3.608323710533743, 3.6932370625238775, 3.7762415176998414, 3.857460304397182, 3.9370039370059056, 4.014971979976946, 4.091454509095756, 4.166533331199932, 4.240283009422838, 4.3127717305695645, 4.384062043356595, 4.454211490264017, 4.523273151159457, 4.591296113299598, 4.658325879540846, 4.724404724407086, 4.789572005931219, 4.853864439804639, 4.917316341257699, 4.979959839195493, 5.041825066382213, 5.10294032886923, 5.163332257370234, 5.223025942880239, 5.282045058497702, 5.340411969127476, 5.3981478305063115, 5.455272678794342, 5.511805511808268, 5.5677643628300215, 5.62316636780382, 5.678027826631356, 5.732364259186606, 5.786190456595773, 5.839520528262573, 5.892367945062493, 5.944745579080739, 5.99666574022598, 6.048140210014975, 6.099180272790762, 6.149796744608719, 6.199999999999999, 6.249799996799897, 6.299206299209448, 6.348228099241551, 6.39687423668779, 6.445153217728807, 6.49307323229917, 6.540642170307133, 6.587867636800241, 6.6347569661593475, 6.681317235396026, 6.727555276621664, 6.773477688750439, 6.819090848492928, 6.864400920692206, 6.90941386804988, 6.954135460285484, 6.998571282769077, 7.042726744663604, 7.08660708661063, 7.130217387990355, 7.173562573784381, 7.216647421067486, 7.259476565152615, 7.302054505411474, 7.344385610791416, 7.386474125047755, 7.428324171709255, 7.469939758793239, 7.511324783285569, 7.552483035399683, 7.593418202627852, 7.634133873596926, 7.674633541739956, 7.714920608794364, 7.754998388136519, 7.79487010796203, 7.834538914320357, 7.874007874011811, 7.913279977354524], [0.0, 0.7937253933193772, 1.1224972160321824, 1.3747727084867523, 1.5874507866387544, 1.7748239349298849, 1.9442222095223582, 2.1, 2.244994432064365, 2.3811761799581315, 2.5099800796022267, 2.632489316217637, 2.7495454169735045, 2.861817604250837, 2.9698484809834995, 3.074085229787879, 3.1749015732775088, 3.2726136343907144, 3.3674916480965473, 3.4597687784012394, 3.5496478698597698, 3.6373066958946425, 3.722902093797257, 3.8065732621348563, 3.8884444190447165, 3.968626966596886, 4.047221268969613, 4.124318125460256, 4.2, 4.274342054632503, 4.347413023856832, 4.419275958796871, 4.48998886412873, 4.559605246071199, 4.628174586162454, 4.695742752749559, 4.762352359916263, 4.828043081829325, 4.892851929090027, 4.956813492557492, 5.019960159204453, 5.082322303829225, 5.143928459844674, 5.204805471869242, 5.264978632435274, 5.324471804789654, 5.383307533477908, 5.441507144165117, 5.499090833947009, 5.55607775323564, 5.612486080160912, 5.668333088307356, 5.723635208501674, 5.7784080852774675, 5.8326666285670745, 5.886425061104576, 5.939696961966999, 5.9924953066314535, 6.044832503882966, 6.096720429870472, 6.148170459575758, 6.199193495931548, 6.249799996799897, 6.3, 6.3498031465550175, 6.3992187023104625, 6.448255578061403, 6.496922348312315, 6.545227268781429, 6.593178292750774, 6.640783086353597, 6.688049042882386, 6.734983296193095, 6.7815927332743895, 6.827884006044625, 6.87386354243376, 6.919537556802479, 6.96491205974634, 7.009992867328754, 7.0547856097829085, 7.0992957397195395, 7.143528539874395, 7.187489130426565, 7.23118247591637, 7.274613391789285, 7.317786550590281, 7.3607064878311785, 7.40337760755184, 7.445804187594514, 7.487990384609211, 7.52994023880668, 7.571657678474378, 7.6131465242697125, 7.654410493303845, 7.695453203028396, 7.736278174936576, 7.776888838089433, 7.817288532477231, 7.857480512225277, 7.897467948652911, 7.937253933193772, 7.976841480185], [0.0, 0.8, 1.131370849898476, 1.385640646055102, 1.6, 1.788854381999832, 1.9595917942265426, 2.1166010488516727, 2.262741699796952, 2.4, 2.5298221281347035, 2.65329983228432, 2.771281292110204, 2.8844410203711917, 2.9933259094191533, 3.098386676965933, 3.2, 3.2984845004941286, 3.394112549695428, 3.4871191548325395, 3.577708763999664, 3.6660605559646724, 3.752332607858744, 3.836665218650176, 3.9191835884530852, 4.0, 4.079215610874228, 4.156921938165306, 4.233202097703345, 4.308131845707604, 4.381780460041329, 4.454211490264018, 4.525483399593904, 4.595650117230424, 4.664761515876241, 4.732863826479693, 4.8, 4.866210024238576, 4.931531202375181, 4.9959983987187195, 5.059644256269407, 5.122499389946279, 5.184592558726289, 5.2459508194416005, 5.30659966456864, 5.366563145999495, 5.4258639865002145, 5.4845236803208355, 5.542562584220408, 5.6000000000000005, 5.656854249492381, 5.713142742834281, 5.768882040742383, 5.8240879114244155, 5.878775382679628, 5.932958789676531, 5.986651818838307, 6.0398675482166, 6.092618484691127, 6.144916598294887, 6.196773353931866, 6.248199740725323, 6.299206299209448, 6.3498031465550175, 6.4, 6.449806198638839, 6.499230723708768, 6.5482822174979605, 6.596969000988257, 6.64529909033446, 6.6932802122726045, 6.740919818541087, 6.788225099390856, 6.835202996254025, 6.881860213634101, 6.92820323027551, 6.974238309665079, 7.019971509913698, 7.065408693062278, 7.110555533852471, 7.155417527999328, 7.2, 7.244308110509934, 7.288346863315439, 7.332121111929345, 7.37563556583431, 7.418894796396564, 7.4619032424710525, 7.504665215717488, 7.547184905645283, 7.58946638440411, 7.631513611335565, 7.673330437300352, 7.7149206087943645, 7.756287771866127, 7.797435475847171, 7.8383671769061705, 7.879086241436885, 7.919595949289333, 7.959899496852961, 8.0, 8.039900496896713], [0.0, 0.8062257748298549, 1.1401754250991378, 1.3964240043768943, 1.6124515496597098, 1.8027756377319946, 1.9748417658131499, 2.133072900770154, 2.2803508501982757, 2.4186773244895647, 2.5495097567963922, 2.6739483914241875, 2.7928480087537886, 2.9068883707497264, 3.016620625799671, 3.1224989991991987, 3.2249030993194197, 3.324154027718932, 3.420526275297414, 3.5142566781611158, 3.605551275463989, 3.6945906403822333, 3.7815340802378072, 3.866522985836241, 3.9496835316262997, 4.031128874149275, 4.110960958218893, 4.189272013130682, 4.266145801540308, 4.341658669218482, 4.415880433163923, 4.488875137492688, 4.560701700396551, 4.631414470763764, 4.701063709417263, 4.769696007084728, 4.8373546489791295, 4.904079934095691, 4.969909455915671, 5.034878350069642, 5.0990195135927845, 5.162363799656123, 5.224940191045253, 5.28677595515452, 5.347896782848375, 5.4083269131959835, 5.468089245796926, 5.527205442174191, 5.585696017507577, 5.643580423808984, 5.70087712549569, 5.757603668193913, 5.813776741499453, 5.869412236331676, 5.924525297439449, 5.979130371550699, 6.033241251599342, 6.08687111741328, 6.1400325732035, 6.192737682156413, 6.244997998398397, 6.296824596572465, 6.348228099241551, 6.3992187023104625, 6.449806198638839, 6.499999999999999, 6.549809157525125, 6.599242380758566, 6.648308055437864, 6.697014260101287, 6.745368781616021, 6.793379129711516, 6.841052550594828, 6.888396039717809, 6.93541635375988, 6.98212002188447, 7.0285133563222315, 7.074602462329597, 7.12039324756716, 7.165891430938652, 7.211102550927978, 7.256031973468694, 7.300684899377592, 7.345066371381541, 7.389181280764467, 7.433034373659253, 7.476630257007497, 7.519973404208288, 7.5630681604756145, 7.6059187479225665, 7.648529270389177, 7.6909037180295, 7.733045971672482, 7.774959806970066, 7.816648898345122, 7.858116822750854, 7.899367063252599, 7.940403012442127, 7.981227975693965, 8.021845174272563, 8.06225774829855, 8.10246875958186], [0.0, 0.812403840463596, 1.1489125293076057, 1.4071247279470291, 1.624807680927192, 1.8165902124584952, 1.98997487421324, 2.149418526020468, 2.2978250586152114, 2.437211521390788, 2.569046515733026, 2.6944387170614963, 2.8142494558940583, 2.9291637031753623, 3.0397368307141326, 3.1464265445104544, 3.249615361854384, 3.3496268448888453, 3.4467375879228173, 3.541186241925155, 3.6331804249169903, 3.722902093797257, 3.81051177665153, 3.8961519477556315, 3.97994974842648, 4.06201920231798, 4.142463035441596, 4.221374183841087, 4.298837052040936, 4.374928570845472, 4.449719092257397, 4.523273151159456, 4.595650117230423, 4.666904755831214, 4.737087712930805, 4.806245936279166, 4.874423042781576, 4.941659640242335, 5.007993610219566, 5.073460357586329, 5.138093031466052, 5.201922721455982, 5.264978632435274, 5.3272882407468805, 5.388877434122993, 5.449770637375485, 5.509990925582365, 5.569560126257728, 5.628498911788117, 5.686826883245172, 5.744562646538029, 5.801723881744115, 5.858327406350725, 5.914389233048499, 5.96992462263972, 6.024948132556827, 6.079473661428265, 6.133514490078261, 6.187083319303208, 6.240192304729077, 6.292853089020909, 6.345076831686122, 6.39687423668779, 6.448255578061403, 6.499230723708768, 6.549809157525125, 6.6, 6.649812027418519, 6.699253689777691, 6.748333127521196, 6.797058187186572, 6.8454364360499325, 6.8934751758456345, 6.941181455631311, 6.988562083862459, 7.035623639735144, 7.08237248385031, 7.128814768248646, 7.17495644586084, 7.2208032794142785, 7.266360849833981, 7.311634564172365, 7.356629663099809, 7.401351227985333, 7.445804187594514, 7.489993324429602, 7.533923280734945, 7.577598564189054, 7.62102355330306, 7.664202502543888, 7.707139547199077, 7.749838707999025, 7.792303895511263, 7.834538914320357, 7.8765474670060875, 7.918333157931661, 7.95989949685296, 8.001249902359007, 8.04238770515324, 8.083316151184489, 8.12403840463596, 8.16455755078008], [0.0, 0.8185352771872451, 1.1575836902790224, 1.4177446878757827, 1.6370705543744901, 1.8303005217723127, 2.004993765576342, 2.1656407827707715, 2.315167380558045, 2.455605831561735, 2.588435821108957, 2.714774392099646, 2.8354893757515653, 2.951270912674741, 3.062678566222711, 3.1701734968294715, 3.2741411087489802, 3.374907406137241, 3.4727510708370675, 3.567912554982255, 3.6606010435446255, 3.7509998667022106, 3.8392707640904935, 3.9255572852781047, 4.009987531152684, 4.092676385936225, 4.173727350941841, 4.253234063627348, 4.331281565541543, 4.407947368106838, 4.483302354291978, 4.557411546042337, 4.63033476111609, 4.702127178203499, 4.77283982551269, 4.8425200051213, 4.91121166312347, 4.978955713801841, 5.045790324617146, 5.111751167652823, 5.176871642217914, 5.241183072551464, 5.304714883949938, 5.367494760127856, 5.429548784199292, 5.490901565316937, 5.551576352712804, 5.61159513863928, 5.670978751503131, 5.729746940310715, 5.787918451395113, 5.845511098270194, 5.902541825349482, 5.959026766175833, 6.014981296729027, 6.070420084310475, 6.125357132445422, 6.17980582219215, 6.23377895020348, 6.287288763847259, 6.340346993658943, 6.392964883369843, 6.445153217728807, 6.496922348312315, 6.5482822174979605, 6.599242380758566, 6.649812027418519, 6.7, 6.749814812274482, 6.79926466612383, 6.848357467305573, 6.897100840208152, 6.945502141674135, 6.993568473962345, 7.041306696913577, 7.088723439378913, 7.13582510996451, 7.182617907142214, 7.229107828771128, 7.275300681071539, 7.321202087089251, 7.366817494685205, 7.4121521840825695, 7.457211275000863, 7.501999733404421, 7.546522377890362, 7.590783885739338, 7.634788798650556, 7.678541528180987, 7.722046360907191, 7.76530746332687, 7.808328886515987, 7.851114570556209, 7.893668348746355, 7.935993951610599, 7.978095010715276, 8.019975062305368, 8.061637550770936, 8.103085831953157, 8.144323176298936, 8.18535277187245, 8.226177727231525], [0.0, 0.8246211251235321, 1.16619037896906, 1.4282856857085702, 1.6492422502470643, 1.8439088914585775, 2.0199009876724157, 2.181742422927143, 2.33238075793812, 2.473863375370596, 2.6076809620810595, 2.734958866235469, 2.8565713714171403, 2.973213749463701, 3.0854497241083023, 3.1937438845342623, 3.2984845004941286, 3.4, 3.4985711369071804, 3.594440151122286, 3.687817782917155, 3.778888725538237, 3.867815921162743, 3.954743986657038, 4.039801975344831, 4.123105625617661, 4.204759208325728, 4.28485705712571, 4.363484845854286, 4.440720662234904, 4.516635916254486, 4.591296113299599, 4.66476151587624, 4.737087712930805, 4.8083261120685235, 4.878524367060187, 4.947726750741192, 5.015974481593781, 5.083306010855534, 5.149757275833494, 5.215361924162119, 5.280151512977635, 5.344155686354956, 5.407402333838309, 5.469917732470938, 5.531726674375732, 5.592852581643825, 5.653317610041028, 5.713142742834281, 5.772347875864725, 5.830951894845301, 5.888972745734184, 5.946427498927402, 6.003332407921454, 6.059702963017247, 6.115553940568263, 6.170899448216605, 6.2257529665093525, 6.280127387243033, 6.334035048845246, 6.387487769068525, 6.440496875241847, 6.49307323229917, 6.545227268781429, 6.596969000988257, 6.648308055437864, 6.699253689777691, 6.749814812274482, 6.8, 6.849817515817484, 6.899275324264137, 6.948381106416083, 6.997142273814361, 7.045565981523414, 7.093659140387279, 7.14142842854285, 7.188880302244572, 7.236021006050217, 7.282856582413251, 7.329392880723478, 7.37563556583431, 7.42159012611179, 7.467261881037788, 7.512655988397179, 7.557777451076474, 7.602631123499285, 7.647221717722065, 7.691553809211764, 7.735631842325486, 7.779460135510689, 7.8230428862431785, 7.866384175718855, 7.909487973314076, 7.952358140828418, 7.994998436522675, 8.037412518964047, 8.079603950689663, 8.121576201698781, 8.16333265278342, 8.204876598706406, 8.246211251235321, 8.287339742040265], [0.0, 0.8306623862918076, 1.174734012447073, 1.4387494569938162, 1.661324772583615, 1.8574175621006712, 2.0346989949375804, 2.1977260975835913, 2.349468024894146, 2.4919871588754225, 2.6267851073127395, 2.7549954627911823, 2.8774989139876324, 2.994995826374388, 3.1080540535840107, 3.217141588429082, 3.32264954516723, 3.424908757908742, 3.5242020373412193, 3.6207733980463352, 3.7148351242013424, 3.8065732621348563, 3.8961519477556315, 3.9837168574084183, 4.069397989875161, 4.153311931459037, 4.235563716909475, 4.316248370981448, 4.3954521951671826, 4.473253849269009, 4.54972526643093, 4.624932431938872, 4.698936049788292, 4.77179211617606, 4.843552415324934, 4.914264950122246, 4.983974317750845, 5.052722038663912, 5.120546845796843, 5.187484939737176, 5.253570214625479, 5.3188344587888805, 5.383307533477909, 5.447017532558529, 5.509990925582365, 5.572252686302012, 5.63382640840131, 5.69473440996154, 5.754997827975265, 5.814636704042653, 5.873670062235366, 5.932115979985557, 5.989991652748776, 6.047313453096343, 6.104096984812742, 6.1603571325045765, 6.216108107168021, 6.271363488110062, 6.326136261573885, 6.380438856379708, 6.434283176858164, 6.487680633323437, 6.540642170307133, 6.593178292750774, 6.64529909033446, 6.697014260101287, 6.748333127521196, 6.79926466612383, 6.849817515817484, 6.9, 6.949820141557622, 6.999285677838847, 7.048404074682439, 7.097182539571601, 7.145628033979938, 7.19374728496908, 7.2415467960926705, 7.289032857656769, 7.336211556382492, 7.383088784512889, 7.429670248402685, 7.475961476626268, 7.521967827636597, 7.567694497005016, 7.6131465242697125, 7.658328799418317, 7.703246069028303, 7.747902942086975, 7.792303895511263, 7.836453279386026, 7.880355321938218, 7.924014134263013, 7.967433714816837, 8.010617953691215, 8.053570636680355, 8.096295449154509, 8.138795979750322, 8.18107572388864, 8.223138087129511, 8.264986388373547, 8.306623862918075, 8.34805366537614], [0.0, 0.8366600265340756, 1.1832159566199232, 1.4491376746189442, 1.6733200530681511, 1.8708286933869709, 2.04939015319192, 2.2135943621178655, 2.3664319132398464, 2.5099800796022267, 2.6457513110645907, 2.774887385102322, 2.8982753492378883, 3.0166206257996717, 3.1304951684997055, 3.24037034920393, 3.3466401061363023, 3.4496376621320683, 3.5496478698597698, 3.6469165057620945, 3.7416573867739418, 3.834057902536163, 3.924283374069717, 4.012480529547776, 4.09878030638384, 4.183300132670378, 4.266145801540309, 4.3474130238568325, 4.427188724235731, 4.505552130427525, 4.58257569495584, 4.658325879540847, 4.732863826479693, 4.806245936279167, 4.878524367060187, 4.949747468305833, 5.019960159204453, 5.089204259999789, 5.157518783291051, 5.2249401910452535, 5.291502622129181, 5.35723809439155, 5.422176684690385, 5.486346689738081, 5.549774770204644, 5.612486080160912, 5.674504383644443, 5.735852159879995, 5.796550698475777, 5.856620185738529, 5.916079783099617, 5.974947698515863, 6.033241251599343, 6.090976933136425, 6.148170459575759, 6.2048368229954285, 6.260990336999411, 6.316644678941503, 6.3718129288295975, 6.4265076052238514, 6.48074069840786, 6.534523701081817, 6.587867636800241, 6.640783086353597, 6.6932802122726045, 6.745368781616021, 6.797058187186572, 6.848357467305573, 6.899275324264137, 6.949820141557622, 7.000000000000001, 7.049822692805827, 7.0992957397195395, 7.148426400264607, 7.197221686178633, 7.24568837309472, 7.293833011524189, 7.341661937191062, 7.3891812807644675, 7.436396977031284, 7.4833147735478835, 7.529940238806681, 7.576278769950325, 7.622335600063802, 7.668115805072326, 7.713624310270757, 7.75886589650833, 7.803845206050669, 7.848566748139434, 7.893034904268446, 7.937253933193772, 7.981227975693966, 8.024961059095553, 8.068457101577724, 8.1117199162693, 8.154753215150045, 8.19756061276768, 8.240145629781066, 8.282511696339462, 8.324662155306966, 8.366600265340756, 8.408329203831164], [0.0, 0.8426149773176359, 1.1916375287812984, 1.4594519519326425, 1.6852299546352718, 1.8841443681416774, 2.0639767440550294, 2.2293496809607953, 2.3832750575625967, 2.5278449319529073, 2.6645825188948455, 2.7946377224964243, 2.918903903865285, 3.0380915061926625, 3.152776554086889, 3.2634337744161437, 3.3704599092705436, 3.4741905532080417, 3.5749125863438955, 3.672873534441392, 3.768288736283355, 3.861346915261565, 3.952214569073901, 4.041039470235351, 4.127953488110059, 4.2130748865881795, 4.296510211788167, 4.378355855797928, 4.458699361921591, 4.537620521815371, 4.61519230368573, 4.69148164229596, 4.766550115125193, 4.8404545241123795, 4.913247398615299, 4.984977432245807, 5.0556898639058145, 5.1254268114957995, 5.194227565288221, 5.262128846769148, 5.329165037789691, 5.395368384086485, 5.46076917659042, 5.525395913416522, 5.589275444992849, 5.652433104425031, 5.71489282489182, 5.776677245614472, 5.83780780773057, 5.898304841223451, 5.958187643906493, 6.017474553332154, 6.076183012385325, 6.134329629226001, 6.191930232165088, 6.248999919987198, 6.305553108173778, 6.361603571427569, 6.417164482853779, 6.472248450113762, 6.526867548832287, 6.5810333535091585, 6.6347569661593475, 6.688049042882386, 6.740919818541087, 6.793379129711516, 6.8454364360499325, 6.897100840208152, 6.948381106416083, 6.999285677838847, 7.049822692805827, 7.1, 7.149825172687791, 7.199305522062527, 7.248448109768049, 7.297259759663212, 7.345747068882784, 7.3939164182454755, 7.441773982055624, 7.489325737341113, 7.53657747256671, 7.583534795858723, 7.630203142774117, 7.676587783644501, 7.72269383052313, 7.768526243760782, 7.814089838234521, 7.859389289251424, 7.904429138147802, 7.949213797602879, 7.993747556684537, 8.038034585643434, 8.082078940470701, 8.125884567233282, 8.16945530620004, 8.212794895770866, 8.255906976220118, 8.298795093265047, 8.341462701469089, 8.383913167489272, 8.426149773176359, 8.468175718535841], [0.0, 0.848528137423857, 1.2, 1.4696938456699071, 1.697056274847714, 1.8973665961010278, 2.078460969082653, 2.244994432064365, 2.4, 2.545584412271571, 2.6832815729997477, 2.814249455894058, 2.9393876913398143, 3.0594117081556713, 3.1749015732775088, 3.2863353450309964, 3.394112549695428, 3.4985711369071804, 3.6, 3.6986484017813863, 3.7947331922020555, 3.8884444190447165, 3.97994974842648, 4.069397989875161, 4.156921938165306, 4.242640687119286, 4.3266615305567875, 4.409081537009721, 4.48998886412873, 4.5694638635183455, 4.6475800154489, 4.724404724407087, 4.8, 4.874423042781577, 4.947726750741193, 5.019960159204453, 5.091168824543142, 5.1613951602255765, 5.230678732248808, 5.299056519796709, 5.366563145999495, 5.43323108288245, 5.499090833947008, 5.564171097297422, 5.628498911788116, 5.692099788303082, 5.754997827975264, 5.817215828899595, 5.8787753826796285, 5.939696961966999, 6.0, 6.059702963017248, 6.118823416311343, 6.177378084592201, 6.235382907247959, 6.29285308902091, 6.3498031465550175, 6.406246951218787, 6.462197768561405, 6.517668294720129, 6.572670690061993, 6.627216610312357, 6.681317235396026, 6.734983296193095, 6.788225099390856, 6.841052550594828, 6.8934751758456345, 6.945502141674135, 6.997142273814361, 7.048404074682439, 7.0992957397195395, 7.149825172687791, 7.2, 7.249827584156743, 7.299315036357863, 7.3484692283495345, 7.397296803562773, 7.445804187594514, 7.493997598078079, 7.541883053985921, 7.589466384404111, 7.636753236814713, 7.68374908491942, 7.730459236035075, 7.776888838089433, 7.823042886243179, 7.868926229162401, 7.914543574963752, 7.95989949685296, 8.0049984384758, 8.049844718999243, 8.094442537939225, 8.138795979750322, 8.182909018191515, 8.226785520481254, 8.270429251254132, 8.313843876330612, 8.357032966310472, 8.4, 8.442748367682174, 8.485281374238571, 8.527602242131138], [0.0, 0.8544003745317531, 1.2083045973594573, 1.4798648586948744, 1.7088007490635062, 1.91049731745428, 2.092844953645635, 2.260530911091463, 2.4166091947189146, 2.563201123595259, 2.701851217221259, 2.833725463060951, 2.9597297173897488, 3.0805843601498726, 3.196873472629156, 3.309078421554859, 3.4176014981270124, 3.522782990761707, 3.6249137920783716, 3.7242448899072147, 3.82099463490856, 3.915354390090379, 4.007492981902776, 4.097560249709576, 4.18568990729127, 4.272001872658766, 4.356604182158393, 4.439594576084623, 4.521061822182926, 4.601086828130937, 4.679743582719036, 4.757099956906519, 4.833218389437829, 4.908156476723211, 4.98196748283246, 5.054700782440045, 5.126402247190518, 5.197114584074513, 5.266877632905477, 5.335728628781641, 5.403702434442518, 5.470831746635972, 5.537147279962851, 5.602677931132575, 5.667450926121902, 5.731491952362839, 5.794825277780168, 5.857473858242988, 5.9194594347794975, 5.980802621722272, 6.041522986797286, 6.101639124038721, 6.161168720299745, 6.220128616033596, 6.278534860936905, 6.336402764976356, 6.393746945258312, 6.450581369148055, 6.5069193939989765, 6.562773803811921, 6.618156843109718, 6.673080248281149, 6.727555276621664, 6.7815927332743895, 6.835202996254025, 6.888396039717809, 6.941181455631311, 6.993568473962345, 7.045565981523414, 7.097182539571601, 7.148426400264607, 7.199305522062527, 7.249827584156743, 7.3, 7.349829930005183, 7.399324293474371, 7.448489779814429, 7.4973328590906245, 7.545859791965394, 7.594076639065476, 7.64198926981712, 7.689603370785778, 7.736924453553881, 7.783957862167549, 7.830708780180758, 7.877182237323192, 7.923383115816122, 7.969316156358713, 8.014985963805552, 8.060397012554654, 8.105553651663778, 8.150460109711599, 8.195120499419152, 8.239538822045807, 8.283718971573094, 8.327664738688751, 8.37137981458254, 8.414867794564572, 8.4581321815162, 8.501176389182852, 8.544003745317532, 8.586617494683225], [0.0, 0.8602325267042626, 1.2165525060596438, 1.489966442575134, 1.7204650534085253, 1.9235384061671346, 2.1071307505705477, 2.2759613353482084, 2.4331050121192876, 2.580697580112788, 2.7202941017470885, 2.8530685235374214, 2.979932885150268, 3.1016124838541645, 3.218695387886216, 3.3316662497915357, 3.4409301068170506, 3.5468295701936396, 3.6496575181789317, 3.749666651850535, 3.847076812334269, 3.9420806688854046, 4.034848200366403, 4.125530268947254, 4.214261501141095, 4.301162633521313, 4.386342439892262, 4.469899327725402, 4.551922670696417, 4.632493928760188, 4.711687595755898, 4.789572005931219, 4.866210024238575, 4.941659640242335, 5.015974481593781, 5.089204259999788, 5.161395160225576, 5.232590180780452, 5.302829433425141, 5.372150407425317, 5.440588203494177, 5.508175741568165, 5.574943945906542, 5.6409219104681805, 5.706137047074843, 5.770615218501403, 5.834380858325929, 5.897457079114692, 5.959865770300536, 6.021627686929839, 6.082762530298219, 6.143289021363068, 6.203224967708329, 6.262587324740471, 6.321392251711643, 6.3796551630946325, 6.437390775772432, 6.494613152451807, 6.55133574166368, 6.607571414672716, 6.663332499583071, 6.71863081289633, 6.773477688750439, 6.827884006044625, 6.881860213634101, 6.93541635375988, 6.988562083862459, 7.041306696913577, 7.093659140387279, 7.145628033979938, 7.197221686178633, 7.248448109768049, 7.299315036357863, 7.349829930005183, 7.3999999999999995, 7.44983221287567, 7.49933330370107, 7.548509786706248, 7.597367965289032, 7.645913941446111, 7.694153624668538, 7.742092740338364, 7.789736837660179, 7.837091297158659, 7.884161337770809, 7.930952023559341, 7.977468270071652, 8.023714850367003, 8.069696400732806, 8.115417426109392, 8.160882305241266, 8.206095295571457, 8.251060537894508, 8.295782060782456, 8.340263784797218, 8.384509526501832, 8.42852300228219, 8.472307831990054, 8.515867542417507, 8.559205570612264, 8.602325267042627, 8.645229898620395], [0.0, 0.8660254037844387, 1.224744871391589, 1.5000000000000002, 1.7320508075688774, 1.9364916731037085, 2.121320343559643, 2.29128784747792, 2.449489742783178, 2.598076211353316, 2.7386127875258306, 2.8722813232690148, 3.0000000000000004, 3.122498999199199, 3.24037034920393, 3.3541019662496843, 3.464101615137755, 3.570714214271425, 3.6742346141747673, 3.7749172176353754, 3.872983346207417, 3.968626966596886, 4.06201920231798, 4.153311931459037, 4.242640687119286, 4.330127018922194, 4.415880433163924, 4.5, 4.58257569495584, 4.663689526544408, 4.743416490252569, 4.8218253804964775, 4.898979485566356, 4.974937185533101, 5.049752469181039, 5.123475382979799, 5.196152422706632, 5.26782687642637, 5.338539126015656, 5.408326913195984, 5.477225575051661, 5.545268253204709, 5.612486080160912, 5.678908345800274, 5.7445626465380295, 5.809475019311125, 5.873670062235366, 5.937171043518958, 6.000000000000001, 6.06217782649107, 6.123724356957946, 6.184658438426491, 6.244997998398398, 6.304760106459247, 6.363961030678928, 6.422616289332565, 6.48074069840786, 6.5383484153110105, 6.59545297913646, 6.652067347825035, 6.7082039324993685, 6.7638746292343415, 6.819090848492928, 6.87386354243376, 6.92820323027551, 6.98212002188447, 7.035623639735144, 7.088723439378913, 7.14142842854285, 7.19374728496908, 7.24568837309472, 7.297259759663212, 7.3484692283495345, 7.399324293474371, 7.44983221287567, 7.5, 7.549834435270751, 7.599342076785332, 7.6485292703891785, 7.697402159170327, 7.745966692414834, 7.794228634059948, 7.842193570679062, 7.88986691902975, 7.937253933193772, 7.984359711335657, 8.031189202104505, 8.077747210701757, 8.12403840463596, 8.170067319184096, 8.215838362577491, 8.261355820929154, 8.306623862918075, 8.351646544245034, 8.396427811873334, 8.440971508067065, 8.485281374238571, 8.529361054615991, 8.573214099741124, 8.616843969807043, 8.660254037844387, 8.703447592764606], [0.0, 0.8717797887081349, 1.2328828005937953, 1.5099668870541503, 1.7435595774162698, 1.9493588689617931, 2.1354156504062627, 2.3065125189341593, 2.4657656011875906, 2.615339366124404, 2.7568097504180447, 2.8913664589601926, 3.0199337741083006, 3.1432467291003428, 3.2619012860600183, 3.3763886032268267, 3.4871191548325395, 3.594440151122286, 3.6986484017813863, 3.8000000000000007, 3.8987177379235862, 3.9949968710876362, 4.0890096600521755, 4.180908992073375, 4.270831300812525, 4.358898943540674, 4.445222154178575, 4.529900661162451, 4.613025037868319, 4.694677837722201, 4.774934554525329, 4.8538644398046396, 4.931531202375181, 5.007993610219566, 5.083306010855535, 5.157518783291051, 5.230678732248808, 5.302829433425142, 5.374011537017762, 5.444263035526481, 5.513619500836089, 5.582114294781146, 5.649778756730215, 5.716642371182581, 5.782732917920385, 5.848076606885378, 5.912698199637794, 5.976621118993575, 6.039867548216601, 6.102458520956944, 6.164414002968978, 6.225752966509353, 6.2864934582006855, 6.3466526610489735, 6.406246951218788, 6.465291950097846, 6.523802572120037, 6.581793068761734, 6.639277069079134, 6.696267617113283, 6.752777206453653, 6.808817812219681, 6.864400920692206, 6.919537556802479, 6.974238309665079, 7.0285133563222315, 7.08237248385031, 7.13582510996451, 7.188880302244572, 7.2415467960926705, 7.293833011524189, 7.345747068882784, 7.397296803562773, 7.448489779814429, 7.49933330370107, 7.549834435270751, 7.600000000000001, 7.649836599562112, 7.6993506219680645, 7.748548251124208, 7.7974354758471724, 7.8460180983732135, 7.894301742396222, 7.942291860665913, 7.9899937421752725, 8.037412518964048, 8.084553172563096, 8.13142054010245, 8.178019320104351, 8.224354077980836, 8.270429251254134, 8.316249154516717, 8.36181798414675, 8.407139822793482, 8.452218643646177, 8.497058314499201, 8.54166260162505, 8.586035173466273, 8.630179604156568, 8.674099376880578, 8.717797887081348, 8.761278445523805], [0.0, 0.8774964387392122, 1.2409673645990857, 1.5198684153570665, 1.7549928774784245, 1.9621416870348585, 2.149418526020468, 2.32163735324878, 2.4819347291981715, 2.6324893162176366, 2.7748873851023217, 2.91032644217105, 3.039736830714133, 3.1638584039112754, 3.283291031876401, 3.3985290935932855, 3.509985754956849, 3.6180105030251086, 3.722902093797257, 3.824918299781056, 3.924283374069717, 4.02119385257662, 4.115823125451336, 4.2083250825001635, 4.298837052040936, 4.387482193696061, 4.474371464239419, 4.559605246071199, 4.64327470649756, 4.725462940284264, 4.806245936279166, 4.8856934001224435, 4.963869458396343, 5.040833264451424, 5.1166395221864125, 5.191338940966964, 5.264978632435273, 5.3376024580330075, 5.409251334519409, 5.479963503528103, 5.549774770204643, 5.61871871515206, 5.686826883245173, 5.754128952326321, 5.8206528843421, 5.886425061104575, 5.951470406546605, 6.015812497078014, 6.079473661428266, 6.142475071174486, 6.2048368229954285, 6.266578013557321, 6.327716807822551, 6.388270501473776, 6.448255578061404, 6.507687761409578, 6.566582063752802, 6.624952830020755, 6.682813778641449, 6.740178039191546, 6.797058187186571, 6.853466276272176, 6.90941386804988, 6.96491205974634, 7.019971509913698, 7.074602462329597, 7.128814768248646, 7.182617907142214, 7.236021006050217, 7.289032857656769, 7.341661937191062, 7.3939164182454755, 7.445804187594514, 7.4973328590906245, 7.548509786706248, 7.599342076785332, 7.649836599562112, 7.7, 7.749838707999026, 7.799358948016177, 7.848566748139434, 7.897467948652911, 7.9460682101275735, 7.994373021069257, 8.04238770515324, 8.090117428072352, 8.137567204023572, 8.184741901856162, 8.231646250902672, 8.278284846512591, 8.324662155306966, 8.370782520170978, 8.416650165000327, 8.462269199216012, 8.507643622061282, 8.55277732669336, 8.597674104081872, 8.64233764672499, 8.6867715521936, 8.73097932651315, 8.774964387392123, 8.81873006730561], [0.0, 0.8831760866327848, 1.2489995996796797, 1.5297058540778359, 1.7663521732655696, 1.9748417658131503, 2.1633307652783937, 2.336664289109585, 2.4979991993593593, 2.6495282598983545, 2.7928480087537886, 2.9291637031753623, 3.0594117081556718, 3.1843366656181322, 3.3045423283716615, 3.420526275297414, 3.532704346531139, 3.6414282912066254, 3.7469987990390394, 3.8496753109840323, 3.9496835316263006, 4.047221268969613, 4.1424630354415966, 4.235563716909475, 4.3266615305567875, 4.415880433163924, 4.503332099679082, 4.589117562233508, 4.67332857821917, 4.756048780237647, 4.83735464897913, 4.917316341257699, 4.995998398718719, 5.07346035758633, 5.149757275833494, 5.2249401910452535, 5.299056519796709, 5.372150407425318, 5.444263035526481, 5.515432893255072, 5.585696017507577, 5.655086206239478, 5.723635208501675, 5.791372894228104, 5.858327406350725, 5.92452529743945, 5.989991652748776, 6.054750201288242, 6.1188234163113435, 6.182232606429493, 6.244997998398399, 6.307138812488593, 6.3686733312362644, 6.429618962271405, 6.489992295835182, 6.549809157525127, 6.609084656743323, 6.667833231267862, 6.726068688320096, 6.783804242458652, 6.841052550594828, 6.897825744392215, 6.954135460285484, 7.009992867328754, 7.065408693062278, 7.12039324756716, 7.17495644586084, 7.229107828771128, 7.282856582413251, 7.336211556382492, 7.3891812807644675, 7.441773982055624, 7.493997598078079, 7.545859791965394, 7.597367965289032, 7.6485292703891785, 7.6993506219680645, 7.749838707999026, 7.800000000000002, 7.849840762716147, 7.899367063252601, 7.9485847796950635, 7.997499609252884, 8.046117075956577, 8.094442537939226, 8.142481194328914, 8.19023809177731, 8.23771813064759, 8.284926070883193, 8.33186653757728, 8.378544026261366, 8.424962907930219, 8.47112743381895, 8.517041739947036, 8.56270985144306, 8.608135686662937, 8.653323061113575, 8.698275691193055, 8.742997197757758, 8.787491109526087, 8.831760866327848, 8.875809822207776], [0.0, 0.8888194417315589, 1.2569805089976536, 1.5394804318340656, 1.7776388834631178, 1.9874606914351793, 2.177154105707724, 2.3515952032609695, 2.513961017995307, 2.6664583251946765, 2.8106938645110393, 2.9478805945967355, 3.078960863668131, 3.204684071792413, 3.3256578296631782, 3.442382895611701, 3.5552777669262356, 3.664696440361739, 3.7709415269929605, 3.874274125562104, 3.9749213828703587, 4.07308237088326, 4.168932717135166, 4.262628297189424, 4.354308211415448, 4.444097208657795, 4.532107677449864, 4.618441295502196, 4.703190406521939, 4.786439177509728, 4.868264577855234, 4.948737212663449, 5.027922035990614, 5.105878964487898, 5.182663407939976, 5.2583267300539625, 5.332916650389353, 5.406477596365309, 5.47905101272109, 5.550675634551168, 5.621387729022079, 5.691221310052879, 5.760208329565868, 5.8283788483591215, 5.895761189193471, 5.962382074305537, 6.028266749240615, 6.09343909463285, 6.157921727336262, 6.221736092120913, 6.284902544988268, 6.347440429023341, 6.409368143584826, 6.470703207534712, 6.5314623171231725, 6.591661399070799, 6.6513156593263565, 6.710439627923047, 6.76904720030818, 6.827151675479314, 6.884765791223402, 6.941901756723442, 6.998571282769077, 7.0547856097829085, 7.110555533852471, 7.165891430938652, 7.2208032794142785, 7.275300681071539, 7.329392880723478, 7.383088784512889, 7.436396977031284, 7.489325737341113, 7.541883053985921, 7.594076639065476, 7.645913941446111, 7.697402159170327, 7.748548251124208, 7.799358948016177, 7.849840762716147, 7.9, 7.949842765740717, 7.999374975584031, 8.048602363143555, 8.097530487747484, 8.14616474176652, 8.194510357550353, 8.242572413997951, 8.290355842785038, 8.337865434270332, 8.385105843100611, 8.432081593533118, 8.478797084492587, 8.525256594378847, 8.571464285639882, 8.61742420912421, 8.663140308225419, 8.708616422830897, 8.753856293085923, 8.798863562983575, 8.843641783790206, 8.88819441731559, 8.932524839036274], [0.0, 0.894427190999916, 1.2649110640673518, 1.549193338482967, 1.788854381999832, 2.0000000000000004, 2.1908902300206647, 2.366431913239847, 2.5298221281347035, 2.6832815729997477, 2.8284271247461903, 2.9664793948382657, 3.098386676965934, 3.22490309931942, 3.3466401061363023, 3.4641016151377544, 3.577708763999664, 3.687817782917155, 3.7947331922020555, 3.8987177379235862, 4.000000000000001, 4.09878030638384, 4.1952353926806065, 4.289522117905444, 4.3817804600413295, 4.47213595499958, 4.560701700396552, 4.647580015448901, 4.732863826479694, 4.8166378315169185, 4.898979485566357, 4.979959839195494, 5.059644256269407, 5.1380930314660525, 5.21536192416212, 5.291502622129181, 5.366563145999495, 5.440588203494178, 5.513619500836089, 5.585696017507577, 5.656854249492381, 5.727128425310542, 5.796550698475777, 5.865151319446072, 5.9329587896765315, 6.0, 6.066300355241241, 6.131883886702357, 6.196773353931868, 6.260990336999412, 6.324555320336759, 6.387487769068526, 6.44980619863884, 6.511528238439884, 6.572670690061994, 6.6332495807108005, 6.6932802122726045, 6.752777206453653, 6.811754546370562, 6.870225614927067, 6.928203230275509, 6.985699678629192, 7.042726744663604, 7.0992957397195395, 7.155417527999328, 7.211102550927978, 7.266360849833981, 7.321202087089251, 7.37563556583431, 7.429670248402685, 7.4833147735478835, 7.53657747256671, 7.589466384404111, 7.64198926981712, 7.694153624668538, 7.745966692414834, 7.7974354758471724, 7.848566748139434, 7.899367063252601, 7.949842765740717, 8.000000000000002, 8.049844718999244, 8.099382692526635, 8.148619514985345, 8.19756061276768, 8.246211251235321, 8.29457654133109, 8.342661445845685, 8.390470785361213, 8.438009243891594, 8.485281374238571, 8.532291603080617, 8.579044235810889, 8.62554346113913, 8.671793355471522, 8.717797887081348, 8.763560920082659, 8.809086218218098, 8.854377448471462, 8.899438184514796, 8.94427190999916, 8.988882021697695], [0.0, 0.9, 1.2727922061357855, 1.5588457268119897, 1.8, 2.012461179749811, 2.2045407685048604, 2.3811761799581315, 2.545584412271571, 2.7, 2.8460498941515415, 2.9849623113198605, 3.1176914536239795, 3.2449961479175906, 3.3674916480965473, 3.485685011586675, 3.6, 3.710795063055895, 3.8183766184073566, 3.9230090491866068, 4.024922359499622, 4.124318125460256, 4.221374183841087, 4.316248370981448, 4.409081537009721, 4.500000000000001, 4.589117562233507, 4.676537180435969, 4.762352359916263, 4.846648326421054, 4.929503017546495, 5.01098792654702, 5.091168824543142, 5.170106381884226, 5.247856705360771, 5.324471804789654, 5.4, 5.474486277268398, 5.547972602672079, 5.620498198558559, 5.692099788303083, 5.762811813689565, 5.832666628567075, 5.9016946718718, 5.969924622639721, 6.037383539249432, 6.104096984812742, 6.17008914036094, 6.235382907247959, 6.300000000000001, 6.3639610306789285, 6.427285585688566, 6.489992295835181, 6.552098900352467, 6.613622305514581, 6.674578638386097, 6.734983296193095, 6.794850991743675, 6.854195795277518, 6.913031173081747, 6.97137002317335, 7.029224708315989, 7.08660708661063, 7.143528539874395, 7.2, 7.256031973468694, 7.311634564172365, 7.366817494685205, 7.42159012611179, 7.475961476626268, 7.529940238806681, 7.583534795858723, 7.636753236814713, 7.689603370785778, 7.742092740338364, 7.794228634059948, 7.8460180983732135, 7.897467948652911, 7.9485847796950635, 7.999374975584031, 8.049844718999244, 8.100000000000001, 8.149846624323676, 8.19939022122987, 8.248636250920512, 8.2975900115636, 8.346256645946134, 8.394641147779934, 8.442748367682174, 8.490583018850943, 8.538149682454625, 8.58545281275251, 8.632496741962896, 8.67928568489366, 8.725823743349393, 8.772114910328067, 8.818163074019441, 8.863972021616496, 8.909545442950499, 8.95488693395958, 9.000000000000002, 9.044888059008803], [0.0, 0.9055385138137417, 1.2806248474865698, 1.5684387141358125, 1.8110770276274835, 2.024845673131659, 2.2181073012818837, 2.395829710142188, 2.5612496949731396, 2.716615541441225, 2.863564212655271, 3.003331483536242, 3.136877428271625, 3.264965543462902, 3.3882148692194836, 3.5071355833500366, 3.622154055254967, 3.733630940518894, 3.84187454245971, 3.947150871198111, 4.049691346263318, 4.149698784249287, 4.247352116319061, 4.342810150121694, 4.436214602563767, 4.527692569068709, 4.617358552246079, 4.705316142407438, 4.791659420284376, 4.876474136094644, 4.959838707054898, 5.041825066382213, 5.122499389946279, 5.201922721455982, 5.280151512977635, 5.35723809439155, 5.43323108288245, 5.508175741568166, 5.582114294781146, 5.655086206239478, 5.727128425310542, 5.798275605729691, 5.868560300448485, 5.938013135721409, 6.006662967072484, 6.074537019394977, 6.1416610131136355, 6.208059278067503, 6.27375485654325, 6.338769596696192, 6.403124237432849, 6.466838485689898, 6.529931086925804, 6.592419889539805, 6.654321903845651, 6.715653356152327, 6.776429738438967, 6.836665854054885, 6.8963758598266685, 6.955573304911681, 7.014271166700073, 7.07248188403477, 7.130217387990355, 7.187489130426565, 7.244308110509934, 7.300684899377592, 7.356629663099809, 7.4121521840825695, 7.467261881037788, 7.521967827636597, 7.576278769950325, 7.630203142774117, 7.68374908491942, 7.736924453553881, 7.789736837660179, 7.842193570679062, 7.894301742396222, 7.9460682101275735, 7.997499609252884, 8.048602363143555, 8.099382692526635, 8.149846624323676, 8.200000000000001, 8.249848483457136, 8.299397568498573, 8.348652585896723, 8.397618710086808, 8.446300965511472, 8.494704232638123, 8.542833253669418, 8.590692637965812, 8.638286867197687, 8.685620300243388, 8.732697177848321, 8.77952162705919, 8.826097665446492, 8.872429205127535, 8.918520056601322, 8.964373932405989, 9.009994450608726, 9.055385138137417, 9.100549433962767], [0.0, 0.9110433579144299, 1.2884098726725124, 1.5779733838059502, 1.8220867158288598, 2.0371548787463363, 2.2315913604421396, 2.41039415863879, 2.576819745345025, 2.7331300737432893, 2.8809720581775866, 3.0215889859476257, 3.1559467676119004, 3.2848135411313684, 3.408812109811862, 3.5284557528754696, 3.6441734316577197, 3.7563279941985894, 3.8652296180175374, 3.9711459303329564, 4.0743097574926725, 4.174925149029621, 4.273172123844299, 4.369210454990696, 4.463182720884279, 4.55521678957215, 4.645427859734774, 4.73392015141785, 4.82078831727758, 4.906118628814432, 4.9899899799498595, 5.072474741188959, 5.15363949069005, 5.23354564325181, 5.31224999411737, 5.389805191284746, 5.466260147486579, 5.541660400998964, 5.616048432839589, 5.68946394662977, 5.761944116355173, 5.833523806414096, 5.904235767650205, 5.974110812497538, 6.043177971895251, 6.111464636239008, 6.178996682310163, 6.245798587850876, 6.311893535223801, 6.377303505401009, 6.442049363362563, 6.506150935845249, 6.569627082262737, 6.632495759516172, 6.694774081326419, 6.756478372643548, 6.817624219623724, 6.878226515607057, 6.938299503480662, 6.997856814768361, 7.056911505750939, 7.115476090888086, 7.173562573784381, 7.23118247591637, 7.288346863315439, 7.345066371381541, 7.401351227985333, 7.457211275000863, 7.512655988397179, 7.567694497005016, 7.622335600063802, 7.676587783644501, 7.730459236035075, 7.783957862167549, 7.837091297158659, 7.88986691902975, 7.942291860665913, 7.994373021069257, 8.046117075956577, 8.097530487747484, 8.148619514985345, 8.19939022122987, 8.249848483457136, 8.299999999999999, 8.349850298059241, 8.399404740813482, 8.44866853415377, 8.49764673306675, 8.546344247688598, 8.594765849050223, 8.64291617453276, 8.690799733051039, 8.738420909981391, 8.78578397184907, 8.832893070789435, 8.879752248796134, 8.926365441768558, 8.972736483370054, 9.018869108707587, 9.064766957842878, 9.1104335791443, 9.155872432488342], [0.0, 0.9165151389911681, 1.2961481396815722, 1.5874507866387546, 1.8330302779823362, 2.04939015319192, 2.244994432064365, 2.4248711305964283, 2.5922962793631443, 2.749545416973504, 2.898275349237888, 3.039736830714133, 3.174901573277509, 3.3045423283716615, 3.4292856398964493, 3.5496478698597693, 3.6660605559646724, 3.778888725538237, 3.8884444190447165, 3.9949968710876362, 4.09878030638384, 4.2, 4.298837052040936, 4.3954521951671826, 4.48998886412873, 4.582575694955841, 4.67332857821917, 4.762352359916264, 4.849742261192857, 4.935585071701227, 5.019960159204453, 5.10294032886923, 5.184592558726289, 5.264978632435274, 5.344155686354956, 5.422176684690384, 5.499090833947008, 5.574943945906542, 5.649778756730214, 5.723635208501674, 5.796550698475776, 5.868560300448484, 5.939696961967, 6.009991680526688, 6.079473661428266, 6.148170459575759, 6.216108107168022, 6.2833112289620034, 6.349803146555018, 6.4156059729381765, 6.480740698407861, 6.54522726878143, 6.609084656743323, 6.672330927044912, 6.7349832961930955, 6.797058187186572, 6.858571279792899, 6.919537556802478, 6.97997134664606, 7.0398863627192165, 7.099295739719539, 7.158212067269313, 7.216647421067486, 7.274613391789285, 7.332121111929345, 7.389181280764467, 7.445804187594514, 7.501999733404421, 7.557777451076474, 7.6131465242697125, 7.668115805072326, 7.72269383052313, 7.776888838089433, 7.830708780180758, 7.884161337770809, 7.937253933193772, 7.9899937421752725, 8.04238770515324, 8.094442537939226, 8.14616474176652, 8.19756061276768, 8.248636250920512, 8.299397568498573, 8.349850298059241, 8.4, 8.449852069711044, 8.499411744350311, 8.548684109265006, 8.597674104081872, 8.646386528486914, 8.694826047713663, 8.742997197757758, 8.790904390334365, 8.838551917593742, 8.885943956609225, 8.933084573650918, 8.97997772825746, 9.026627277117408, 9.073036977771006, 9.119210492142399, 9.165151389911681, 9.210863151735564], [0.0, 0.9219544457292888, 1.3038404810405297, 1.5968719422671316, 1.8439088914585775, 2.0615528128088303, 2.2583179581272432, 2.4392621835300936, 2.6076809620810595, 2.765863337187866, 2.9154759474226504, 3.0577769702841313, 3.193743884534263, 3.3241540277189325, 3.449637662132068, 3.5707142142714248, 3.687817782917155, 3.8013155617496426, 3.9115214431215897, 4.018706259482024, 4.123105625617661, 4.224926034855522, 4.324349662087931, 4.421538193886829, 4.5166359162544865, 4.609772228646444, 4.701063709417264, 4.790615826801394, 4.878524367060187, 4.964876634922565, 5.049752469181039, 5.13322510708424, 5.215361924162119, 5.296225070746145, 5.375872022286245, 5.454356057317858, 5.531726674375732, 5.608029957123981, 5.68330889535313, 5.757603668193913, 5.830951894845301, 5.903388857258177, 5.974947698515863, 6.0456596000767355, 6.115553940568263, 6.18465843842649, 6.252999280345393, 6.320601237224193, 6.387487769068526, 6.4536811201050215, 6.519202405202649, 6.584071688552609, 6.648308055437865, 6.711929677819935, 6.77495387438173, 6.837397165588672, 6.899275324264136, 6.960603422117942, 7.021395872616784, 7.0816664705420855, 7.1414284285428495, 7.200694410957877, 7.259476565152615, 7.317786550590281, 7.37563556583431, 7.433034373659253, 7.489993324429602, 7.546522377890362, 7.602631123499285, 7.658328799418317, 7.713624310270757, 7.768526243760782, 7.823042886243179, 7.877182237323192, 7.930952023559341, 7.984359711335657, 8.037412518964048, 8.090117428072352, 8.142481194328914, 8.194510357550353, 8.246211251235321, 8.2975900115636, 8.348652585896723, 8.399404740813482, 8.449852069711044, 8.5, 8.549853799919623, 8.599418584997478, 8.648699324175862, 8.697700845625814, 8.746427842267952, 8.794884877018005, 8.843076387773658, 8.891006692158093, 8.938679992034618, 8.986100377805714, 9.033271832508973, 9.080198235721511, 9.126883367283709, 9.173330910852394, 9.219544457292889, 9.265527507918803], [0.0, 0.9273618495495705, 1.3114877048604001, 1.6062378404209012, 1.854723699099141, 2.0736441353327724, 2.2715633383201097, 2.4535688292770597, 2.6229754097208002, 2.7820855486487113, 2.932575659723036, 3.07571129984594, 3.2124756808418025, 3.343650699460098, 3.4698703145794947, 3.591656999213594, 3.709447398198282, 3.8236108588610325, 3.9344631145812006, 4.042276586281548, 4.147288270665545, 4.249705872175156, 4.349712634186309, 4.447471191587417, 4.543126676640219, 4.636809247747852, 4.7286361670147565, 4.818713521262704, 4.907137658554119, 4.993996395673509, 5.079370039680118, 5.163332257370235, 5.2459508194416005, 5.327288240746882, 5.40740233383831, 5.486346689738081, 5.5641710972974225, 5.640921910468182, 5.716642371182581, 5.791372894228104, 5.865151319446072, 5.93801313572141, 6.009991680526689, 6.081118318204308, 6.15142259969188, 6.220932405998316, 6.289674077406556, 6.357672530100934, 6.424951361683605, 6.491532946846993, 6.557438524302001, 6.62268827591938, 6.687301398920196, 6.751296171847301, 6.814690014960329, 6.87749954561976, 6.939740629158989, 7.001428425685718, 7.062577433203831, 7.123201527403251, 7.183313998427188, 7.242927584892728, 7.302054505411474, 7.3607064878311785, 7.418894796396564, 7.476630257007497, 7.533923280734945, 7.590783885739338, 7.647221717722065, 7.703246069028303, 7.75886589650833, 7.814089838234521, 7.868926229162401, 7.923383115816122, 7.977468270071652, 8.031189202104505, 8.084553172563096, 8.137567204023572, 8.19023809177731, 8.242572413997951, 8.29457654133109, 8.346256645946134, 8.397618710086808, 8.44866853415377, 8.499411744350311, 8.549853799919623, 8.600000000000001, 8.649855490122365, 8.699425268372618, 8.748714191239761, 8.79772697916911, 8.84646822183859, 8.894942383174834, 8.943153806124549, 8.99110671719561, 9.038805230781334, 9.086253353280439, 9.133454987024352, 9.180413934022802, 9.22713389953782, 9.273618495495704, 9.319871243745807], [0.0, 0.9327379053088816, 1.3190905958272918, 1.6155494421403516, 1.8654758106177631, 2.0856653614614213, 2.2847319317591728, 2.4677925358506134, 2.6381811916545836, 2.7982137159266447, 2.9495762407505253, 3.093541659651604, 3.231098884280703, 3.363034344160048, 3.4899856733230297, 3.6124783736376886, 3.7309516212355263, 3.845776904605882, 3.957271787481876, 4.065710270051225, 4.171330722922843, 4.274342054632503, 4.374928570845472, 4.473253849269009, 4.5694638635183455, 4.663689526544408, 4.756048780237647, 4.846648326421054, 4.935585071701227, 5.022947341949744, 5.10881590977792, 5.193264869039514, 5.276362383309167, 5.358171329847526, 5.4387498563548595, 5.518151864528558, 5.596427431853289, 5.673623181001714, 5.749782604586021, 5.8249463516842805, 5.8991524815010505, 5.9724366886556455, 6.044832503882966, 6.1163714733492105, 6.187083319303208, 6.256996084384263, 6.326136261573884, 6.394528911499267, 6.462197768561406, 6.529165337162171, 6.59545297913646, 6.661080993352356, 6.726068688320096, 6.790434448545985, 6.854195795277518, 6.917369442208505, 6.979971346646059, 7.042016756583302, 7.103520254071217, 7.164495795239188, 7.224956747275377, 7.284915922644544, 7.344385610791416, 7.40337760755184, 7.4619032424710525, 7.519973404208288, 7.577598564189054, 7.634788798650556, 7.691553809211764, 7.747902942086975, 7.803845206050669, 7.859389289251424, 7.914543574963752, 7.969316156358713, 8.023714850367003, 8.077747210701757, 8.13142054010245, 8.184741901856162, 8.23771813064759, 8.290355842785038, 8.342661445845685, 8.394641147779934, 8.446300965511472, 8.49764673306675, 8.548684109265006, 8.599418584997478, 8.649855490122365, 8.700000000000001, 8.749857141690944, 8.799431799837988, 8.848728722251575, 8.897752525216692, 8.946507698538017, 8.994998610338971, 9.043229511629129, 9.091204540653564, 9.138927727036691, 9.186402995732335, 9.233634170791044, 9.280624978954814, 9.327379053088816, 9.373899935459095], [0.0, 0.938083151964686, 1.3266499161421599, 1.6248076809271923, 1.876166303929372, 2.0976176963403033, 2.297825058615212, 2.4819347291981715, 2.6532998322843198, 2.814249455894058, 2.9664793948382653, 3.1112698372208096, 3.2496153618543846, 3.3823069050575527, 3.509985754956849, 3.63318042491699, 3.752332607858744, 3.867815921162743, 3.97994974842648, 4.0890096600521755, 4.1952353926806065, 4.298837052040936, 4.4, 4.498888751680798, 4.595650117230424, 4.69041575982343, 4.7833042972405595, 4.874423042781577, 4.963869458396343, 5.0517323761260355, 5.138093031466052, 5.223025942880239, 5.3065996645686395, 5.388877434122993, 5.469917732470938, 5.549774770204643, 5.628498911788116, 5.706137047074843, 5.782732917920384, 5.858327406350725, 5.932958789676531, 6.006662967072483, 6.079473661428266, 6.151422599691879, 6.222539674441619, 6.292853089020909, 6.362389488234747, 6.431174076325411, 6.499230723708769, 6.566582063752802, 6.6332495807108005, 6.6992536897776915, 6.764613810115105, 6.82934843158555, 6.8934751758456345, 6.957010852370435, 7.019971509913698, 7.0823724838503095, 7.144228439796701, 7.205553413860728, 7.26636084983398, 7.326663633605681, 7.386474125047755, 7.445804187594514, 7.504665215717488, 7.5630681604756145, 7.62102355330306, 7.678541528180987, 7.735631842325486, 7.792303895511263, 7.848566748139434, 7.904429138147802, 7.95989949685296, 8.014985963805552, 8.069696400732806, 8.12403840463596, 8.178019320104351, 8.231646250902672, 8.284926070883193, 8.337865434270332, 8.390470785361213, 8.442748367682174, 8.494704232638123, 8.546344247688598, 8.597674104081872, 8.648699324175862, 8.699425268372618, 8.749857141690944, 8.8, 8.849858755935035, 8.899438184514796, 8.948742928478838, 8.997777503361595, 9.046546302318914, 9.09505360072166, 9.143303560529969, 9.191300234460847, 9.23904756996088, 9.28654941299512, 9.333809511662428, 9.38083151964686, 9.427618999514142], [0.0, 0.9433981132056604, 1.3341664064126333, 1.6340134638368193, 1.8867962264113207, 2.1095023109728985, 2.3108440016582685, 2.495996794869737, 2.6683328128252666, 2.830194339616981, 2.9832867780352594, 3.1288975694324033, 3.2680269276736387, 3.4014702703389896, 3.529872518944558, 3.6537651812890215, 3.7735924528226414, 3.8897300677553446, 4.0024992192379, 4.112177038990418, 4.219004621945797, 4.323193264243457, 4.424929377967517, 4.524378410345448, 4.621688003316537, 4.716990566028302, 4.810405388322278, 4.902040391510457, 4.991993589739474, 5.0803543183522155, 5.167204273105525, 5.252618394667558, 5.336665625650533, 5.419409561935692, 5.500909015790026, 5.58121850495033, 5.660388679233962, 5.7384666941614295, 5.815496539419485, 5.8915193286621745, 5.966573556070519, 6.040695324215583, 6.113918547053109, 6.186275131288617, 6.2577951388648065, 6.328506932918695, 6.398437309218556, 6.4676116148080505, 6.536053855347277, 6.603786792439623, 6.670832032063167, 6.73721010508059, 6.802940540677979, 6.868041933477111, 6.932532004974806, 6.996427659884722, 7.059745037889116, 7.122499561249548, 7.184705978674423, 7.246378405796926, 7.307530362578043, 7.368174807915458, 7.428324171709255, 7.487990384609211, 7.547184905645283, 7.6059187479225665, 7.664202502543888, 7.722046360907191, 7.779460135510689, 7.836453279386026, 7.893034904268446, 7.949213797602879, 8.0049984384758, 8.060397012554654, 8.115417426109392, 8.170067319184096, 8.224354077980836, 8.278284846512591, 8.33186653757728, 8.385105843100611, 8.438009243891594, 8.490583018850943, 8.542833253669418, 8.594765849050223, 8.646386528486914, 8.697700845625814, 8.748714191239761, 8.799431799837988, 8.849858755935035, 8.899999999999999, 8.949860334105779, 8.99944442729661, 9.048756820690896, 9.097801932335084, 9.1465840618233, 9.195107394696377, 9.243376006633074, 9.291393867445294, 9.339164844888433, 9.38669270829721, 9.433981132056603, 9.481033698917013], [0.0, 0.9486832980505138, 1.3416407864998738, 1.6431676725154984, 1.8973665961010275, 2.121320343559643, 2.32379000772445, 2.5099800796022267, 2.6832815729997477, 2.846049894151541, 3.0, 3.146426544510455, 3.286335345030997, 3.420526275297414, 3.5496478698597693, 3.674234614174767, 3.794733192202055, 3.9115214431215892, 4.024922359499621, 4.135214625627067, 4.242640687119286, 4.347413023856832, 4.449719092257398, 4.549725266430931, 4.6475800154489, 4.743416490252569, 4.83735464897913, 4.929503017546495, 5.019960159204453, 5.10881590977792, 5.196152422706632, 5.282045058497703, 5.366563145999495, 5.449770637375486, 5.531726674375733, 5.612486080160912, 5.692099788303082, 5.770615218501404, 5.848076606885378, 5.92452529743945, 6.0, 6.074537019394977, 6.148170459575759, 6.220932405998315, 6.29285308902091, 6.363961030678928, 6.434283176858165, 6.5038450166036395, 6.572670690061994, 6.640783086353597, 6.708203932499369, 6.77495387438173, 6.841052550594828, 6.906518659932804, 6.971370023173351, 7.035623639735144, 7.099295739719539, 7.162401831787993, 7.224956747275378, 7.286974680894671, 7.348469228349534, 7.409453421137082, 7.469939758793239, 7.52994023880668, 7.58946638440411, 7.648529270389177, 7.707139547199077, 7.76530746332687, 7.8230428862431785, 7.880355321938218, 7.937253933193772, 7.993747556684537, 8.049844718999243, 8.105553651663778, 8.160882305241266, 8.215838362577491, 8.270429251254134, 8.324662155306966, 8.378544026261366, 8.432081593533118, 8.485281374238571, 8.538149682454625, 8.590692637965812, 8.64291617453276, 8.694826047713663, 8.746427842267952, 8.79772697916911, 8.848728722251575, 8.899438184514796, 8.949860334105779, 9.0, 9.049861877399014, 9.099450532861862, 9.148770409186145, 9.197825830053535, 9.246621004453464, 9.2951600308978, 9.343446901438464, 9.391485505499116, 9.439279633531365, 9.486832980505138, 9.534149149242424], [0.0, 0.9539392014169457, 1.349073756323204, 1.6522711641858308, 1.9078784028338913, 2.1330729007701543, 2.3366642891095846, 2.5238858928247927, 2.698147512646408, 2.8618176042508368, 3.0166206257996713, 3.1638584039112754, 3.3045423283716615, 3.439476704383968, 3.5693136595149495, 3.694590640382233, 3.8157568056677826, 3.9331920878594273, 4.047221268969612, 4.158124577258358, 4.266145801540309, 4.371498598878879, 4.474371464239419, 4.57493169347915, 4.673328578219169, 4.769696007084729, 4.864154602806124, 4.956813492557492, 5.047771785649585, 5.137119815616529, 5.224940191045253, 5.3113086899558, 5.396295025292816, 5.479963503528103, 5.562373594069352, 5.643580423808984, 5.7236352085016735, 5.8025856305616035, 5.880476171195663, 5.957348403442593, 6.0332412515993425, 6.1081912216301815, 6.182232606429493, 6.255397669213365, 6.327716807822551, 6.399218702310462, 6.469930447848725, 6.539877674696982, 6.609084656743323, 6.67757440991862, 6.745368781616021, 6.81248853210044, 6.878953408767936, 6.944782214007867, 7.009992867328754, 7.074602462329597, 7.138627319029899, 7.202083032012336, 7.264984514780469, 7.327346040688948, 7.389181280764466, 7.450503338701353, 7.511324783285569, 7.571657678474378, 7.631513611335565, 7.6909037180295, 7.749838707999025, 7.808328886515987, 7.866384175718855, 7.924014134263013, 7.981227975693966, 8.038034585643434, 8.094442537939225, 8.150460109711599, 8.206095295571457, 8.261355820929154, 8.316249154516717, 8.370782520170978, 8.424962907930219, 8.478797084492587, 8.532291603080617, 8.58545281275251, 8.638286867197687, 8.690799733051039, 8.742997197757758, 8.794884877018005, 8.84646822183859, 8.897752525216692, 8.948742928478838, 8.99944442729661, 9.049861877399014, 9.1, 9.1498633869583, 9.199456505685541, 9.248783703817493, 9.297849213662264, 9.346657156438338, 9.395211546314432, 9.443516294262428, 9.491575211733826, 9.539392014169458, 9.586970324351693], [0.0, 0.959166304662544, 1.3564659966250536, 1.6613247725836153, 1.918332609325088, 2.144761058952722, 2.349468024894146, 2.5377155080899043, 2.7129319932501073, 2.877498913987632, 3.0331501776206204, 3.1811947441173736, 3.3226495451672307, 3.458323293158117, 3.5888716889852725, 3.714835124201342, 3.836665218650176, 3.954743986657038, 4.069397989875161, 4.180908992073375, 4.289522117905444, 4.3954521951671826, 4.498888751680798, 4.6000000000000005, 4.698936049788292, 4.79583152331272, 4.8908077042549944, 4.983974317750846, 5.075431016179809, 5.165268628057984, 5.253570214625479, 5.340411969127476, 5.4258639865002145, 5.509990925582366, 5.592852581643825, 5.674504383644443, 5.754997827975264, 5.83438085832593, 5.912698199637794, 5.989991652748776, 6.066300355241241, 6.1416610131136355, 6.216108107168022, 6.289674077406555, 6.362389488234747, 6.434283176858165, 6.505382386916238, 6.575712889109439, 6.645299090334461, 6.714164132637808, 6.782329983125269, 6.8498175158174845, 6.916646586316234, 6.982836100038438, 7.0484040746824395, 7.113367697511497, 7.177743377970545, 7.24154679609267, 7.3047929470998705, 7.367496182557545, 7.429670248402684, 7.491328320131218, 7.552483035399683, 7.6131465242697125, 7.673330437300352, 7.733045971672482, 7.792303895511263, 7.851114570556209, 7.909487973314076, 7.967433714816837, 8.024961059095553, 8.082078940470701, 8.138795979750322, 8.195120499419152, 8.251060537894508, 8.306623862918075, 8.36181798414675, 8.416650165000327, 8.47112743381895, 8.525256594378847, 8.579044235810889, 8.632496741962896, 8.685620300243388, 8.738420909981391, 8.790904390334365, 8.843076387773658, 8.894942383174834, 8.946507698538017, 8.997777503361595, 9.048756820690896, 9.099450532861862, 9.1498633869583, 9.200000000000001, 9.249864863877743, 9.299462350050137, 9.348796714016196, 9.397872099576585, 9.446692542895637, 9.495261976375376, 9.54358423235212, 9.59166304662544, 9.639502061828715], [0.0, 0.9643650760992956, 1.3638181696985856, 1.670329308849007, 1.9287301521985911, 2.1563858652847827, 2.3622023622035435, 2.551470164434615, 2.727636339397171, 2.8930952282978866, 3.0495901363953815, 3.1984371183438958, 3.340658617698014, 3.4770677301427426, 3.6083237105337433, 3.7349698793966195, 3.8574603043971822, 3.976179070414209, 4.091454509095757, 4.203569911396741, 4.312771730569565, 4.419275958796871, 4.523273151159457, 4.624932431938872, 4.724404724407087, 4.821825380496478, 4.917316341257699, 5.0109879265470205, 5.10294032886923, 5.193264869039514, 5.282045058497703, 5.36935750346352, 5.455272678794342, 5.539855593785817, 5.62316636780382, 5.705260730238365, 5.786190456595773, 5.866003750424986, 5.944745579080741, 6.02245796996542, 6.099180272790763, 6.174949392505174, 6.249799996799899, 6.323764701504951, 6.3968742366877915, 6.469157595854347, 6.540642170307134, 6.611353870426239, 6.681317235396028, 6.750555532695069, 6.8190908484929285, 6.886944169949399, 6.954135460285485, 7.020683727387242, 7.0866070866106305, 7.15192281837549, 7.216647421067487, 7.280796659706959, 7.3443856107914165, 7.407428703673091, 7.469939758793239, 7.531932023060219, 7.593418202627852, 7.654410493303845, 7.7149206087943645, 7.774959806970066, 7.834538914320357, 7.893668348746355, 7.952358140828418, 8.010617953691215, 8.068457101577724, 8.125884567233282, 8.182909018191515, 8.239538822045807, 8.295782060782456, 8.351646544245034, 8.407139822793482, 8.462269199216012, 8.517041739947036, 8.571464285639882, 8.62554346113913, 8.67928568489366, 8.732697177848321, 8.78578397184907, 8.838551917593742, 8.891006692158093, 8.943153806124549, 8.994998610338971, 9.046546302318914, 9.097801932335084, 9.148770409186145, 9.199456505685541, 9.249864863877743, 9.3, 9.349866309204641, 9.39946807005588, 9.448809448814174, 9.497894503520243, 9.5467271878901, 9.595311355031686, 9.643650760992957, 9.691749068150704], [0.0, 0.9695359714832659, 1.3711309200802089, 1.6792855623746668, 1.9390719429665317, 2.1679483388678804, 2.374868417407584, 2.5651510676761324, 2.7422618401604177, 2.9086079144497976, 3.0659419433511785, 3.2155870381627056, 3.3585711247493335, 3.4957116585897072, 3.627671429443411, 3.7549966711037173, 3.8781438859330635, 3.9974992182613374, 4.113392760240627, 4.226109321823088, 4.335896677735761, 4.442971978304612, 4.54752680036083, 4.649731175025068, 4.749736834815168, 4.847679857416329, 4.943682837723311, 5.037856687124, 5.130302135352265, 5.221110992882646, 5.310367218940701, 5.398147830506312, 5.4845236803208355, 5.569560126257729, 5.653317610041029, 5.735852159879995, 5.817215828899595, 5.897457079114693, 5.976621118993575, 6.054750201288242, 6.131883886702357, 6.208059278067504, 6.283311228962004, 6.357672530100933, 6.431174076325411, 6.5038450166036395, 6.57571288910944, 6.646803743153547, 6.717142249498667, 6.786751800382861, 6.855654600401045, 6.923871749245506, 6.9914233171794145, 7.058328414008519, 7.124605252222751, 7.1902712048990205, 7.255342858886822, 7.31983606373804, 7.383765976789894, 7.447147104764348, 7.5099933422074345, 7.572318007057021, 7.634133873596926, 7.695453203028396, 7.756287771866127, 7.816648898345122, 7.8765474670060875, 7.935993951610599, 7.994998436522675, 8.053570636680355, 8.1117199162693, 8.16945530620004, 8.226785520481254, 8.283718971573094, 8.340263784797218, 8.396427811873334, 8.452218643646177, 8.507643622061282, 8.56270985144306, 8.61742420912421, 8.671793355471522, 8.725823743349393, 8.77952162705919, 8.832893070789435, 8.885943956609225, 8.938679992034618, 8.99110671719561, 9.043229511629129, 9.09505360072166, 9.1465840618233, 9.197825830053535, 9.248783703817493, 9.299462350050137, 9.349866309204641, 9.4, 9.44986772394196, 9.499473669630335, 9.548821916864929, 9.597916440561463, 9.646761114488118, 9.695359714832659, 9.743715923609434], [0.0, 0.9746794344808963, 1.378404875209022, 1.6881943016134133, 1.9493588689617927, 2.179449471770337, 2.3874672772626644, 2.578759391645525, 2.756809750418044, 2.9240383034426887, 3.082207001484488, 3.2326459750489227, 3.3763886032268267, 3.5142566781611158, 3.6469165057620936, 3.7749172176353745, 3.8987177379235853, 4.018706259482023, 4.135214625627066, 4.2485291572496005, 4.358898943540674, 4.466542286825459, 4.571651780264984, 4.674398357008098, 4.774934554525329, 4.873397172404482, 4.969909455915671, 5.06458290484024, 5.15751878329105, 5.2488093888042835, 5.338539126015655, 5.426785420486054, 5.513619500836088, 5.599107071667768, 5.683308895353129, 5.766281297335397, 5.848076606885377, 5.928743543112655, 6.008327554319921, 6.08687111741328, 6.164414002968976, 6.24099351065197, 6.316644678941503, 6.3914004725099165, 6.465291950097845, 6.53834841531101, 6.6105975524153635, 6.682065548915245, 6.752777206453653, 6.822756041366274, 6.892024376045111, 6.960603422117942, 7.0285133563222315, 7.095773389842717, 7.162401831787993, 7.2284161474004796, 7.293833011524187, 7.358668357794092, 7.4229374239582535, 7.486654793697916, 7.549834435270749, 7.6124897372673015, 7.674633541739956, 7.736278174936576, 7.797435475847171, 7.858116822750854, 7.918333157931661, 7.978095010715276, 8.037412518964047, 8.096295449154509, 8.154753215150045, 8.212794895770866, 8.270429251254132, 8.327664738688751, 8.384509526501832, 8.440971508067065, 8.497058314499201, 8.55277732669336, 8.608135686662937, 8.663140308225419, 8.717797887081348, 8.772114910328067, 8.826097665446492, 8.879752248796134, 8.933084573650918, 8.986100377805714, 9.038805230781334, 9.091204540653564, 9.143303560529969, 9.195107394696377, 9.246621004453464, 9.297849213662264, 9.348796714016196, 9.39946807005588, 9.44986772394196, 9.499999999999998, 9.549869109050658, 9.599479152537391, 9.648834126463154, 9.697937925146768, 9.746794344808963, 9.795407086997457], [0.0, 0.9797958971132713, 1.3856406460551018, 1.6970562748477143, 1.9595917942265426, 2.1908902300206647, 2.4000000000000004, 2.5922962793631443, 2.7712812921102037, 2.939387691339814, 3.0983866769659336, 3.2496153618543846, 3.3941125496954285, 3.532704346531139, 3.666060555964672, 3.794733192202055, 3.9191835884530852, 4.039801975344831, 4.156921938165306, 4.270831300812525, 4.3817804600413295, 4.48998886412873, 4.595650117230424, 4.698936049788292, 4.800000000000001, 4.898979485566357, 4.9959983987187195, 5.091168824543143, 5.184592558726289, 5.276362383309168, 5.366563145999495, 5.455272678794342, 5.542562584220407, 5.628498911788117, 5.713142742834281, 5.796550698475776, 5.878775382679628, 5.959865770300536, 6.0398675482166, 6.118823416311343, 6.196773353931867, 6.27375485654325, 6.349803146555018, 6.424951361683604, 6.499230723708769, 6.572670690061993, 6.64529909033446, 6.717142249498666, 6.788225099390857, 6.858571279792899, 6.92820323027551, 6.997142273814362, 7.065408693062278, 7.1330218000508046, 7.2, 7.266360849833981, 7.332121111929344, 7.397296803562772, 7.4619032424710525, 7.525955088890711, 7.58946638440411, 7.652450587883597, 7.714920608794364, 7.776888838089433, 7.8383671769061705, 7.899367063252599, 7.95989949685296, 8.019975062305368, 8.079603950689663, 8.138795979750322, 8.19756061276768, 8.255906976220118, 8.313843876330612, 8.37137981458254, 8.42852300228219, 8.485281374238571, 8.54166260162505, 8.597674104081872, 8.653323061113575, 8.708616422830897, 8.763560920082659, 8.818163074019441, 8.872429205127535, 8.926365441768558, 8.97997772825746, 9.033271832508973, 9.086253353280439, 9.138927727036691, 9.191300234460847, 9.243376006633074, 9.2951600308978, 9.346657156438338, 9.397872099576585, 9.448809448814174, 9.499473669630335, 9.549869109050658, 9.600000000000001, 9.649870465451857, 9.699484522385713, 9.748846085563153, 9.797958971132713, 9.846826900072939], [0.0, 0.9848857801796106, 1.392838827718412, 1.7058722109231985, 1.9697715603592212, 2.2022715545545246, 2.412467616362964, 2.6057628441590768, 2.785677655436824, 2.9546573405388314, 3.1144823004794877, 3.2664965942122155, 3.411744421846397, 3.5510561809129415, 3.685105154537656, 3.8144462245521304, 3.9395431207184424, 4.060788100849391, 4.178516483155236, 4.293017586733137, 4.404543109109049, 4.513313638558704, 4.61952378498044, 4.723346271447818, 4.824935232725928, 4.924428900898053, 5.021951811795889, 5.117616632769595, 5.2115256883181535, 5.3037722424704485, 5.394441583704471, 5.483611948342078, 5.571355310873648, 5.657738063926256, 5.742821606144492, 5.826662852782887, 5.909314681077663, 5.990826320300065, 6.071243694664217, 6.150609725872713, 6.228964600958975, 6.306346010171025, 6.38278935889318, 6.458327956987009, 6.532993188424431, 6.606814663663572, 6.679820356865895, 6.7520367297579185, 6.823488843692794, 6.894200461257274, 6.9641941385920605, 7.033491309442276, 7.102112361825883, 7.170076708097342, 7.237402849088892, 7.30410843293006, 7.370210309075312, 7.4357245780085215, 7.5006666370396715, 7.565051222562872, 7.628892449104261, 7.692203845452876, 7.754998388136519, 7.817288532477231, 7.879086241436885, 7.940403012442127, 8.001249902359007, 8.061637550770936, 8.121576201698781, 8.18107572388864, 8.240145629781066, 8.298795093265047, 8.357032966310472, 8.414867794564572, 8.472307831990054, 8.529361054615991, 8.586035173466273, 8.64233764672499, 8.698275691193055, 8.753856293085923, 8.809086218218098, 8.863972021616496, 8.918520056601322, 8.972736483370054, 9.026627277117408, 9.080198235721511, 9.133454987024352, 9.186402995732335, 9.23904756996088, 9.291393867445294, 9.343446901438464, 9.395211546314432, 9.446692542895637, 9.497894503520243, 9.548821916864929, 9.599479152537391, 9.649870465451857, 9.700000000000003, 9.749871794028884, 9.799489782636646, 9.848857801796106, 9.897979591815698], [0.0, 0.9899494936611666, 1.4, 1.7146428199482249, 1.9798989873223332, 2.2135943621178655, 2.4248711305964283, 2.619160170741759, 2.8, 2.9698484809834995, 3.1304951684997055, 3.283291031876401, 3.4292856398964497, 3.5693136595149495, 3.704051835490427, 3.8340579025361623, 3.9597979746446663, 4.08166632639171, 4.2, 4.315089802078284, 4.427188724235731, 4.536518488885503, 4.64327470649756, 4.747630988187688, 4.849742261192857, 4.949747468305833, 5.047771785649585, 5.143928459844674, 5.238320341483518, 5.331041174104736, 5.422176684690383, 5.511805511808268, 5.6, 5.686826883245173, 5.772347875864725, 5.856620185738529, 5.939696961966999, 6.021627686929839, 6.102458520956943, 6.182232606429493, 6.260990336999411, 6.338769596696192, 6.4156059729381765, 6.491532946846992, 6.566582063752802, 6.640783086353596, 6.714164132637808, 6.786751800382861, 6.8585712797928995, 6.929646455628165, 7.0, 7.069653456853455, 7.138627319029899, 7.206941098690901, 7.274613391789285, 7.341661937191061, 7.408103670980854, 7.473954776421918, 7.539230729988306, 7.603946343840151, 7.668115805072325, 7.731752712031082, 7.79487010796203, 7.857480512225277, 7.919595949289333, 7.981227975693965, 8.04238770515324, 8.103085831953157, 8.16333265278342, 8.223138087129511, 8.282511696339462, 8.341462701469089, 8.4, 8.4581321815162, 8.515867542417507, 8.573214099741124, 8.630179604156568, 8.6867715521936, 8.742997197757758, 8.798863562983575, 8.854377448471462, 8.909545442950499, 8.964373932405989, 9.018869108707587, 9.073036977771006, 9.126883367283709, 9.180413934022802, 9.233634170791044, 9.28654941299512, 9.339164844888433, 9.391485505499116, 9.443516294262428, 9.495261976375376, 9.5467271878901, 9.597916440561463, 9.648834126463154, 9.699484522385713, 9.749871794028884, 9.8, 9.849873095629203, 9.899494936611665, 9.948869282486328], [0.0, 0.9949874371066201, 1.407124727947029, 1.7233687939614089, 1.9899748742132402, 2.224859546128699, 2.4372115213907883, 2.632489316217637, 2.814249455894058, 2.98496231131986, 3.146426544510455, 3.3000000000000007, 3.4467375879228177, 3.58747822293042, 3.722902093797257, 3.853569773599539, 3.9799497484264803, 4.102438299353203, 4.221374183841087, 4.337049688440289, 4.449719092257398, 4.559605246071199, 4.666904755831214, 4.77179211617606, 4.874423042781577, 4.974937185533101, 5.073460357586329, 5.170106381884226, 5.264978632435274, 5.358171329847527, 5.449770637375485, 5.539855593785817, 5.628498911788116, 5.715767664977296, 5.801723881744115, 5.886425061104576, 5.96992462263972, 6.052272300549605, 6.133514490078262, 6.213694553162394, 6.29285308902091, 6.3710281744785915, 6.448255578061405, 6.524568951279464, 6.600000000000001, 6.674578638386096, 6.748333127521196, 6.821290200541244, 6.893475175845635, 6.96491205974634, 7.035623639735145, 7.105631569396208, 7.17495644586084, 7.243617880589783, 7.3116345641723655, 7.379024325749307, 7.445804187594514, 7.5119904153293495, 7.577598564189055, 7.642643521714199, 7.707139547199078, 7.771100308193172, 7.834538914320357, 7.897467948652911, 7.959899496852961, 8.021845174272563, 8.083316151184489, 8.144323176298936, 8.204876598706406, 8.264986388373547, 8.324662155306966, 8.383913167489272, 8.442748367682174, 8.501176389182852, 8.559205570612264, 8.616843969807043, 8.674099376880578, 8.73097932651315, 8.787491109526087, 8.843641783790206, 8.899438184514796, 8.95488693395958, 9.009994450608726, 9.064766957842878, 9.119210492142399, 9.173330910852394, 9.22713389953782, 9.280624978954814, 9.333809511662428, 9.38669270829721, 9.439279633531365, 9.491575211733826, 9.54358423235212, 9.595311355031686, 9.646761114488118, 9.697937925146768, 9.748846085563153, 9.799489782636646, 9.849873095629203, 9.900000000000002, 9.949874371066201, 9.999499987499377], [0.0, 1.0, 1.4142135623730951, 1.7320508075688776, 2.0, 2.23606797749979, 2.4494897427831783, 2.6457513110645907, 2.8284271247461903, 3.0, 3.1622776601683795, 3.3166247903554003, 3.4641016151377553, 3.6055512754639896, 3.7416573867739413, 3.8729833462074166, 4.0, 4.123105625617661, 4.242640687119286, 4.358898943540674, 4.47213595499958, 4.582575694955841, 4.69041575982343, 4.79583152331272, 4.898979485566357, 5.000000000000001, 5.099019513592785, 5.196152422706633, 5.291502622129181, 5.385164807134505, 5.477225575051661, 5.567764362830022, 5.656854249492381, 5.7445626465380295, 5.830951894845301, 5.916079783099616, 6.0, 6.08276253029822, 6.164414002968977, 6.244997998398399, 6.324555320336759, 6.403124237432849, 6.480740698407861, 6.557438524302, 6.6332495807108005, 6.7082039324993685, 6.782329983125269, 6.855654600401045, 6.9282032302755105, 7.0, 7.071067811865476, 7.141428428542851, 7.211102550927979, 7.28010988928052, 7.348469228349535, 7.416198487095664, 7.483314773547883, 7.54983443527075, 7.6157731058639095, 7.681145747868608, 7.745966692414833, 7.810249675906655, 7.874007874011811, 7.937253933193772, 8.0, 8.06225774829855, 8.12403840463596, 8.18535277187245, 8.246211251235321, 8.306623862918075, 8.366600265340756, 8.426149773176359, 8.485281374238571, 8.544003745317532, 8.602325267042627, 8.660254037844387, 8.717797887081348, 8.774964387392123, 8.831760866327848, 8.88819441731559, 8.94427190999916, 9.000000000000002, 9.055385138137417, 9.1104335791443, 9.165151389911681, 9.219544457292889, 9.273618495495704, 9.327379053088816, 9.38083151964686, 9.433981132056603, 9.486832980505138, 9.539392014169458, 9.59166304662544, 9.643650760992957, 9.695359714832659, 9.746794344808963, 9.797958971132713, 9.848857801796106, 9.899494936611665, 9.949874371066201, 10.000000000000002, 10.049875621120892], [0.0, 1.0049875621120892, 1.4212670403551897, 1.7406895185529214, 2.0099751242241783, 2.2472205054244236, 2.4617067250182347, 2.6589471600616665, 2.8425340807103794, 3.0149626863362675, 3.178049716414141, 3.333166662499792, 3.481379037105843, 3.6235341863986883, 3.7603191353926335, 3.892300091205713, 4.019950248448357, 4.1436698710201325, 4.263801121065569, 4.380639222761903, 4.494441010848847, 4.605431575867782, 4.713809499757071, 4.819751030914357, 4.9234134500364695, 5.024937810560446, 5.1244511901275835, 5.222068555658764, 5.317894320123333, 5.412023651093924, 5.504543577809154, 5.595533933415113, 5.685068161420759, 5.773214009544425, 5.860034129593445, 5.9455865984779, 6.029925372672535, 6.113100686231171, 6.1951594006934165, 6.276145313805283, 6.356099432828282, 6.435060217278469, 6.5130637951735135, 6.590144156238162, 6.666333324999584, 6.74166151627327, 6.81615727518079, 6.889847603539574, 6.962758074211686, 7.034912934784624, 7.1063352017759485, 7.177046746399247, 7.247068372797377, 7.31641988953614, 7.385120175054704, 7.4531872376856345, 7.520638270785267, 7.587489703452652, 7.653757247260983, 7.719455939378112, 7.784600182411426, 7.849203781276163, 7.913279977354524, 7.976841480185, 8.039900496896713, 8.10246875958186, 8.16455755078008, 8.226177727231525, 8.287339742040265, 8.34805366537614, 8.408329203831164, 8.468175718535841, 8.527602242131138, 8.586617494683225, 8.645229898620395, 8.703447592764606, 8.761278445523805, 8.81873006730561, 8.875809822207776, 8.932524839036274, 8.988882021697695, 9.044888059008803, 9.100549433962767, 9.155872432488342, 9.210863151735564, 9.265527507918803, 9.319871243745807, 9.373899935459095, 9.427618999514142, 9.481033698917013, 9.534149149242424, 9.586970324351693, 9.639502061828715, 9.691749068150704, 9.743715923609434, 9.795407086997457, 9.846826900072939, 9.897979591815698, 9.948869282486328, 9.999499987499377, 10.049875621120892, 10.100000000000001]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha = 0.6\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.1, 0.1515716566510398, 0.1933182044931763, 0.22973967099940704, 0.2626527804403767, 0.2930156051583522, 0.3214095849716039, 0.3482202253184497, 0.3737192818846552, 0.39810717055349726, 0.4215369133091901, 0.444128606984584, 0.4659786420036066, 0.4871658325766915, 0.5077556391987408, 0.5278031643091577, 0.5473553316918489, 0.5664525067769411, 0.5851297242409217, 0.6034176336545163, 0.6213432387360743, 0.6389304828983968, 0.6562007185515857, 0.6731730872677197, 0.6898648307306073, 0.7062915473248845, 0.7224674055842076, 0.7384053230743223, 0.754117117337764, 0.7696136340726079, 0.7849048566202034, 0.8, 0.8149075920852832, 0.8296355440131292, 0.8441912115297928, 0.8585814486631533, 0.8728126548676132, 0.8868908165896259, 0.900821544043058, 0.9146101038546526, 0.9282614481346684, 0.9417802404414931, 0.9551708790378903, 0.9684375177775887, 0.9815840849118561, 0.9946143000646653, 1.007531689590605, 1.0203396005006327, 1.0330412131161864, 1.0456395525912732, 1.0581374994243518, 1.0705377990665903, 1.0828430707200105, 1.0950558154077705, 1.107178423389128, 1.119213180983213, 1.1311622768584233, 1.1430278078379148, 1.154811784266086, 1.166516134976123, 1.1781427118943884, 1.189693294313711, 1.2011695928643287, 1.2125732532083184, 1.223905859480782, 1.2351689374987616, 1.2463639577568397, 1.2574923382265666, 1.2685554469752462, 1.2795546046181905, 1.290491086617243, 1.3013661254372384, 1.3121809125710286, 1.3229366004427638, 1.3336343041982999, 1.344275103390831, 1.354860043569177, 1.3653901377755393, 1.3758663679589664, 1.3862896863102927, 1.3966610165238236, 1.4069812549906497, 1.4172512719280759, 1.4274719124493171, 1.4376439975772874, 1.4477683252060298, 1.4578456710130647, 1.4678767893256992, 1.4778624139441148, 1.4878032589238495, 1.4977000193201075, 1.5075533718961576, 1.5173639757979167, 1.5271324731966918, 1.5368594899018897, 1.5465456359454104, 1.5561915061393068, 1.5657976806082026, 1.5753647252978464, 1.5848931924611134, 1.59438362112266], [0.0, 0.1319507910772894, 0.19999999999999998, 0.25508490012515816, 0.30314331330207966, 0.3465724215775732, 0.3866364089863526, 0.42410248996826405, 0.459479341998814, 0.4931255488551677, 0.5253055608807534, 0.556221291794264, 0.5860312103167042, 0.6148625043749694, 0.6428191699432078, 0.6699875826622859, 0.6964404506368993, 0.722239690171116, 0.7474385637693104, 0.7720832999642582, 0.7962143411069944, 0.819867318817501, 0.8430738266183799, 0.8658620391836747, 0.888257213969168, 0.91028210151304, 0.9319572840072131, 0.953301456943931, 0.9743316651533829, 0.9950635019764305, 1.0155112783974816, 1.0356881675144227, 1.0556063286183153, 1.075277014305422, 1.0947106633836976, 1.1139169818185153, 1.1329050135538825, 1.1516832027205075, 1.1702594484818434, 1.188641153559468, 1.2068352673090323, 1.2248483240791976, 1.2426864774721484, 1.2603555310303953, 1.2778609657967936, 1.2952079651299664, 1.3124014371031711, 1.3294460347691834, 1.3463461745354395, 1.3631060528612353, 1.3797296614612147, 1.3962208011758808, 1.4125830946497688, 1.4288199979406664, 1.4449348111684153, 1.4609306882990152, 1.4768106461486445, 1.4925775726825683, 1.508234234675528, 1.5237832847928614, 1.5392272681452155, 1.554568628364076, 1.5698097132404067, 1.5849527799643384, 1.5999999999999999, 1.61495346362619, 1.6298151841705664, 1.6445871019623635, 1.6592710880262584, 1.673868947537882, 1.6883824230595852, 1.7028131975733602, 1.7171628973263067, 1.7314330945026677, 1.7456253097352263, 1.7597410144677612, 1.7737816331792515, 1.7877485454796374, 1.8016430880861158, 1.815466556688226, 1.8292202077093052, 1.842905259971297, 1.8565228962693368, 1.8700742648620423, 1.883560480882986, 1.8969826276783983, 1.9103417580757804, 1.9236388955877572, 1.9368750355551771, 1.950051146233185, 1.9631681698237118, 1.9762270234575983, 1.9892286001293307, 2.0021737695871615, 2.0150633791812096, 2.027898254671938, 2.0406792010012653, 2.0534070030284, 2.0660824262323727, 2.078706217383076, 2.0912791051825463, 2.1038018008780828], [0.0, 0.15518455739153597, 0.23521580450493473, 0.30000000000000004, 0.35652049159320076, 0.40759655480296136, 0.4547149699531195, 0.4987780418521562, 0.5403840154082454, 0.5799546134795288, 0.617800850567412, 0.6541601931608093, 0.6892190129982211, 0.7231268931323869, 0.7560061410469299, 0.7879583413211302, 0.8190690044316877, 0.8494109488449693, 0.8790468154750565, 0.9080309727295892, 0.9364109840092412, 0.9642287549148116, 0.9915214419254805, 1.018322180684357, 1.044660675955349, 1.070563684169162, 1.096055411609953, 1.1211578456539657, 1.1458910323684282, 1.1702733107544192, 1.1943215116604917, 1.2180511276907326, 1.2414764591322878, 1.2646107399275701, 1.2874662469396363, 1.3100543951507542, 1.3323858209537522, 1.35447045531362, 1.37631758827079, 1.39793592601082, 1.41933364152511, 1.4405184197240475, 1.4614974977300743, 1.4822777009677934, 1.5028654755767286, 1.5232669175962226, 1.5434877993082745, 1.5635335930706444, 1.5834094929274733, 1.6031204342465077, 1.6226711115996042, 1.6420659950755467, 1.661309345190579, 1.6804052265417653, 1.6993575203308238, 1.7181699358710047, 1.7368460211765295, 1.755389172722765, 1.7738026444554442, 1.792089556118625, 1.8102529009635488, 1.8282955528939455, 1.846220273097516, 1.8640297162082233, 1.8817264360394779, 1.8993128909243258, 1.9167914486951907, 1.9341643913325823, 1.9514339193093737, 1.9686021556547568, 1.9856711497597572, 2.0026428809441916, 2.0195192618031594, 2.036302141349568, 2.052993307967736, 2.0695944921918223, 2.0861073693216734, 2.102533561887599, 2.118874641974654, 2.135132133416124, 2.1513075138651403, 2.1674022167526226, 2.183417633139118, 2.1993551134674987, 2.2152159692229665, 2.231001474506298, 2.2467128675258303, 2.2623513520132925, 2.2779180985681755, 2.2934142459350437, 2.3088409022178236, 2.3241991460348577, 2.339490027618228, 2.3547145698606102, 2.369873769312703, 2.384968597134065, 2.4000000000000004, 2.4149689009669606, 2.4298762002987755, 2.44472277625585, 2.459509485849363, 2.474237165562344], [0.0, 0.17411011265922482, 0.2639015821545788, 0.33658654363385987, 0.4, 0.4573050519273263, 0.5101698002503163, 0.5596065904916064, 0.6062866266041592, 0.6506830627186191, 0.6931448431551464, 0.7339383946628497, 0.7732728179727051, 0.8113159385604054, 0.8482049799365281, 0.8840539154424946, 0.9189586839976279, 0.9530009846549518, 0.9862510977103354, 1.01877002207848, 1.0506111217615068, 1.0818214129638553, 1.1124425835885279, 1.1425118103408085, 1.1720624206334085, 1.201124433981431, 1.2297250087499387, 1.2578888137888427, 1.2856383398864155, 1.3129941625792796, 1.3399751653245717, 1.366598730129163, 1.3928809012737986, 1.4188365266482628, 1.444479380342232, 1.4698222694537972, 1.4948771275386208, 1.5196550966939724, 1.5441665999285166, 1.5684214051919367, 1.5924286822139888, 1.616197053119423, 1.639734637635002, 1.6630490935809787, 1.6861476532367599, 1.7090371560850535, 1.7317240783673493, 1.7542145598235936, 1.776514427938336, 1.7986292199728149, 1.82056420302608, 1.842324392337243, 1.863914568014426, 1.8853392903532198, 1.906602913887862, 1.92770960030144, 1.948663330306766, 1.9694679145968534, 1.9901270039528611, 2.010644098587687, 2.0310225567949627, 2.051265602965766, 2.0713763350288454, 2.0913577313644347, 2.1112126572366305, 2.130943870784843, 2.150554028610844, 2.170045690994407, 2.189421326767395, 2.208683317873334, 2.22783396363703, 2.246875484766536, 2.2658100271077646, 2.2846396651702623, 2.303366405441015, 2.321992189501729, 2.3405188969636863, 2.358948348233117, 2.377282307118936, 2.395522483293741, 2.413670534618065, 2.4317280693371037, 2.4496966481583953, 2.4675777862182695, 2.485372954944297, 2.5030835838203984, 2.5207110620607907, 2.538256740198479, 2.5557219315935873, 2.573107913866438, 2.5904159302599323, 2.607647190935471, 2.6248028742063423, 2.6418841277122453, 2.6588920695383664, 2.675827789282168, 2.692692349070879, 2.7094867845324346, 2.7262121057224706, 2.742869298009768, 2.7594593229224293, 2.7759831189568915], [0.0, 0.19036539387158785, 0.2885399811814427, 0.36801096140891665, 0.43734482957731124, 0.49999999999999994, 0.5578003108649138, 0.6118526223722295, 0.6628908034679973, 0.7114321829337935, 0.757858283255199, 0.8024604053351735, 0.8454671719825998, 0.887062077207642, 0.927395155992419, 0.9665910224658812, 1.004754572603832, 1.0419751330523241, 1.0783295456214068, 1.1138845042109662, 1.1486983549970349, 1.1828225037144082, 1.2163025303351713, 1.2491790824589155, 1.2814885990147222, 1.3132639022018835, 1.3445346859467486, 1.3753279222342187, 1.4056682016392041, 1.4355780206730986, 1.4650780257917606, 1.4941872218222718, 1.5229231509727028, 1.5513020473626218, 1.5793389710592838, 1.6070479248580194, 1.6344419564559967, 1.6615332481997944, 1.688333196211783, 1.7148524803976866, 1.741101126592248, 1.7670885618996666, 1.7928236641212354, 1.8183148060271876, 1.843569895117535, 1.8685964094232759, 1.8934014298212367, 1.917991669270219, 1.9423734993208153, 1.9665529742044574, 1.990535852767486, 2.0143276184821377, 2.0379334977373422, 2.0613584765873445, 2.08460731611473, 2.10768456654595, 2.1305945802414206, 2.1533415236683586, 2.1759293884524227, 2.198362001593646, 2.2206430349229196, 2.2427760138671586, 2.2647643255841645, 2.2866112265219276, 2.3083198494515416, 2.329893210018033, 2.3513342128490238, 2.3726456572573187, 2.3938302425700426, 2.414890573113909, 2.435829162883457, 2.456648439916648, 2.4773507504000207, 2.497938362523634, 2.5184134701042615, 2.5387781959937032, 2.55903459528765, 2.5791846583492304, 2.599230313660221, 2.6191734305117964, 2.6390158215457884, 2.658759245156499, 2.67840540776236, 2.69795596595597, 2.71741252854043, 2.736776658459244, 2.7560498746265494, 2.7752336536639133, 2.794329431549485, 2.81333860518487, 2.8322625338847054, 2.85110254079357, 2.8698599142345236, 2.8885359089932887, 2.907131747541803, 2.925648621204608, 2.944087691271333, 2.9624500900582866, 2.980736921921992, 2.9989492642273032, 3.017088168272581, 3.0351546601742365], [0.0, 0.20476725110792196, 0.310369114783072, 0.39585237323186834, 0.4704316090098695, 0.5378268784662851, 0.6000000000000002, 0.6581415719437339, 0.7130409831864014, 0.7652547003754746, 0.8151931096059228, 0.8631695497884125, 0.909429939906239, 0.9541716559808098, 0.9975560837043126, 1.0397172647327195, 1.0807680308164909, 1.1208044664980472, 1.1599092269590578, 1.1981540517434992, 1.235601701134824, 1.2723074699047923, 1.3083203863216186, 1.3436841731285136, 1.3784380259964422, 1.4126172502473835, 1.4462537862647737, 1.4793766465655034, 1.5120122820938597, 1.5441848913068417, 1.5759166826422606, 1.6072280987137666, 1.6381380088633757, 1.6686638753827923, 1.6988218976899385, 1.7286271379442195, 1.7580936309501132, 1.7872344806944858, 1.8160619454591787, 1.8445875131249083, 1.8728219680184823, 1.9007754504399492, 1.9284575098296233, 1.9558771523892622, 1.9830428838509613, 2.009962747986858, 2.0366443613687135, 2.063094944815883, 2.0893213519106983, 2.1153300949099445, 2.141127368338324, 2.1667190705133486, 2.1921108232199056, 2.217307989725977, 2.2423156913079314, 2.2671388224339473, 2.2917820647368567, 2.316249899892775, 2.3405466215088384, 2.3646763461120104, 2.3886430233209834, 2.4124504452744637, 2.4361022553814653, 2.4596019564525036, 2.482952918264576, 2.5061583846075832, 2.5292214798551407, 2.5521452150985824, 2.5749324938792726, 2.597586117551024, 2.6201087903015083, 2.64250312385888, 2.6647716419075045, 2.6869167842345396, 2.7089409106272404, 2.7308463045391203, 2.7526351765415797, 2.7743096675761976, 2.79587185202164, 2.817323740587982, 2.8386672830502206, 2.859904370831793, 2.8810368394480954, 2.902066470819181, 2.922994995460149, 2.9438240945570513, 2.964555401935587, 2.985190505929292, 3.005730951153457, 3.026178240190543, 3.0465338351924447, 3.0667991594046002, 3.0869755986165495, 3.107064502543268, 3.127067186141289, 3.146984930863331, 3.1668189858549467, 3.186570569096427, 3.206240868493016, 3.2258310429162664, 3.245342223199209, 3.264775513087816], [0.0, 0.21779064244827798, 0.33010888478979766, 0.42102895953516445, 0.5003515054281688, 0.5720331779293615, 0.6381605689480848, 0.7, 0.7583910658558927, 0.8139256249696815, 0.8670401643811234, 0.9180679516527257, 0.9672705464483131, 1.0148578780914161, 1.0610015965572788, 1.1058442686782979, 1.1495059024112548, 1.1920886933665806, 1.2336805536738755, 1.2743577855801407, 1.3141871409823676, 1.353227431452234, 1.3915308035023033, 1.4291437606837147, 1.4661079915492736, 1.5024610468729152, 1.5382368984767494, 1.5734664041012518, 1.608177696995849, 1.6423965146623505, 1.6761464780162718, 1.7094493298408762, 1.7423251395862238, 1.7747924801623307, 1.8068685812854601, 1.838569463082637, 1.8699100529852137, 1.900904288406046, 1.9315652072653249, 1.9619050280838735, 1.9919352210819103, 2.021666571492183, 2.051109236108465, 2.0802727939354853, 2.1091662916779668, 2.1377982846995818, 2.166176873993278, 2.1943097396293685, 2.222204171084521, 2.249867094801227, 2.277305099281833, 2.3045244579824393, 2.3315311502387823, 2.358330880427772, 2.384929095543812, 2.4113310013478975, 2.4375415772291475, 2.463565589902529, 2.4894076060526626, 2.515072004021531, 2.5405629846273197, 2.565884581192353, 2.5910406688499137, 2.6160349731925865, 2.6408710783183813, 2.6655524343253134, 2.690082364300122, 2.7144640708424053, 2.7387006421615117, 2.7627950577800133, 2.7867501938744805, 2.8105688282814567, 2.834253645194025, 2.8578072395721197, 2.8812321212877037, 2.904530719024099, 2.9277053839471434, 2.95075839316433, 2.973691952986775, 2.9965082020076212, 3.019209214009404, 3.041797000711885, 3.06427351437098, 3.0866406502385475, 3.108900248892088, 3.13105409844268, 3.1531039366288867, 3.1750514528037628, 3.1968982898215965, 3.2186460458305173, 3.240296275976668, 3.2618504940252455, 3.2833101739033186, 3.304676751169016, 3.3259516244113514, 3.3471361565846536, 3.3682316762813156, 3.3892394789463296, 3.4101608280368403, 3.4309969561297295, 3.451749065980082, 3.4724183315331594], [0.0, 0.229739670999407, 0.34822022531844965, 0.44412860698458406, 0.5278031643091577, 0.6034176336545163, 0.6731730872677197, 0.7384053230743222, 0.8, 0.8585814486631532, 0.9146101038546527, 0.9684375177775888, 1.0203396005006327, 1.0705377990665903, 1.119213180983213, 1.166516134976123, 1.2125732532083184, 1.2574923382265664, 1.3013661254372384, 1.344275103390831, 1.3862896863102927, 1.4274719124493171, 1.4678767893256992, 1.5075533718961576, 1.5465456359454102, 1.5848931924611134, 1.6226318771208108, 1.65979424066711, 1.6964099598730562, 1.732506184321991, 1.7681078308849894, 1.8032378352576224, 1.837917367995256, 1.8721660210059192, 1.9060019693099035, 1.939442111974454, 1.9725021954206712, 2.0051969217340444, 2.0375400441569607, 2.0695444515762995, 2.1012222435230137, 2.132584796958918, 2.1636428259277105, 2.194406434983793, 2.2248851671770558, 2.2550880472590378, 2.285023620681617, 2.3146999888802227, 2.3441248412668174, 2.3733054843014094, 2.402248867962862, 2.4309616098988576, 2.459450017499877, 2.487720108112028, 2.5157776275776853, 2.543628067270604, 2.571276679772831, 2.598728493323943, 2.625988325158559, 2.653060793835288, 2.6799503306491435, 2.706661190209659, 2.733197460258326, 2.759563070791425, 2.785761802547597, 2.811797294913613, 2.8376730532965255, 2.863392456005752, 2.888958760684464, 2.9143751103259876, 2.939644538907594, 2.964769976671126, 2.9897542550772416, 3.0146001114576975, 3.039310193387945, 3.0638870628004047, 3.088333199857033, 3.11265100659825, 3.136842810383874, 3.16091086714042, 3.184857364427978, 3.2086844243388057, 3.2323941062388464, 3.2559884093624727, 3.2794692752700043, 3.302838590176783, 3.3260981871619575, 3.3492498482645123, 3.37229530647352, 3.395236247619104, 3.418074312170107, 3.44081109694407, 3.4634481567346986, 3.4859870058616553, 3.508429119647187, 3.5307759358237663, 3.5530288558766725, 3.57518924632516, 3.59725843994563, 3.619237736939984, 3.6411284060521605, 3.662931685635631], [0.0, 0.2408224685280692, 0.36501860513592344, 0.4655536721746079, 0.5532647468890367, 0.6325269095141249, 0.7056474135148042, 0.7740264966144386, 0.8385925425258951, 0.8999999999999999, 0.9587315155141827, 1.0151556003882185, 1.069561474779602, 1.1221812684866597, 1.1732047838365092, 1.222789664408884, 1.2710686092585746, 1.3181546214003115, 1.364144909859358, 1.4091238460084716, 1.4531652409004674, 1.4963341255564684, 1.5386881610942322, 1.5802787689148563, 1.621152046224736, 1.6613495148724349, 1.700908739272883, 1.7398638404385864, 1.7782459267702473, 1.8160834575655194, 1.8534025517022357, 1.890227251309476, 1.9265797482245537, 1.9624805794824276, 1.9979487968786938, 2.0330021147030615, 2.067657038994663, 2.101928981077563, 2.1358323576598877, 2.16938067939716, 2.202586629509912, 2.235462133792311, 2.268018423140789, 2.300266089560305, 2.332215136463948, 2.3638750239633906, 2.3952547097489045, 2.4263626860746585, 2.457207013295063, 2.4877953503387125, 2.518134982456162, 2.5482328465349076, 2.578095554238224, 2.6077294131930757, 2.6371404464251693, 2.6663344102158555, 2.6953168105353003, 2.7240929181887674, 2.752667782797541, 2.7810462457226297, 2.809232952027723, 2.8372323615676045, 2.865048759279186, 2.892686264744435, 2.9201488410873875, 2.947440303261301, 2.9745643257764414, 3.001524449914163, 3.0283240904685544, 3.05496654205307, 3.0814549850061024, 3.107792490926348, 3.133982027866047, 3.160026465207696, 3.1859285782475837, 3.2116910525074855, 3.237316487794053, 3.2628074020237663, 3.2881662348298586, 3.3133953509662706, 3.338497043522474, 3.363473536961896, 3.3883269899956905, 3.4130594983026508, 3.437673097105284, 3.462169763611239, 3.4865514193286455, 3.510819932263257, 3.5349771190047146, 3.5590247467087295, 3.5829645349814747, 3.6067981576720523, 3.6305272445784698, 3.6541533830721975, 3.677678119646028, 3.701102961389623, 3.7244293773968633, 3.7476588001088182, 3.770792626595926, 3.79383221978271, 3.816778909618176, 3.839633994194808], [0.0, 0.251188643150958, 0.3807307877431757, 0.48559337483020387, 0.5770799623628855, 0.6597539553864471, 0.7360219228178334, 0.8073443754472972, 0.8746896591546225, 0.9387403933595694, 1.0, 1.0588528529217847, 1.1156006217298275, 1.1704854282221195, 1.2237052447444592, 1.2754245006257907, 1.3257816069359947, 1.3748944308911808, 1.422864365867587, 1.4697794149937133, 1.515716566510398, 1.5607436506913628, 1.6049208106703468, 1.6483016812765647, 1.6909343439651996, 1.7328621078878659, 1.774124154415284, 1.8147560732948997, 1.854790311984838, 1.8942565548098473, 1.9331820449317627, 1.9715918593702613, 2.009509145207664, 2.0469553234931666, 2.0839502661046483, 2.1205124498413204, 2.156659091242814, 2.1924062650118117, 2.227769008421933, 2.262761413693267, 2.2973967099940698, 2.3316873364629074, 2.3656450074288164, 2.399280770828355, 2.4326050606703427, 2.4656277442758388, 2.498358164917831, 2.5308051803985627, 2.562977198029445, 2.594882206416745, 2.626527804403767, 2.657921227475505, 2.6890693718934973, 2.7199788167957633, 2.750655844468438, 2.78110645897132, 2.8113364032784087, 2.8413511750761566, 2.8711560413461976, 2.90075605184535, 2.930156051583521, 2.9593606923894145, 2.988374443644544, 3.017201602257794, 3.0458463019454056, 3.074312521874847, 3.1026040947252436, 3.1307247142119854, 3.158677942118568, 3.1864672148746918, 3.2140958497160383, 3.2415670504579066, 3.2688839129119933, 3.296049429973025, 3.3230664963995893, 3.3499379133114293, 3.376666392423566, 3.4032545600358945, 3.429704960795373, 3.456020061246495, 3.4822022531844965, 3.50825385682457, 3.5341771237993336, 3.559974239995828, 3.585647328242471, 3.61119845085558, 3.6366296120543753, 3.6619427602526966, 3.6871397902350704, 3.7122225452242166, 3.7371928188465517, 3.762052357001814, 3.786802859642474, 3.811445982468218, 3.8359833385404376, 3.8604164998212913, 3.884746998641631, 3.9089763291017823, 3.9331059484089153, 3.9571372781544776, 3.9810717055349722, 4.004910584519121], [0.0, 0.2609498635278873, 0.3955260311778463, 0.5044635907995056, 0.5995053579423699, 0.6853920721113645, 0.7646238217761332, 0.8387178733489493, 0.9086802027449961, 0.9752199560554082, 1.0388601182540846, 1.1, 1.158952993814579, 1.215970630377514, 1.2712585752633725, 1.324987647544266, 1.3773016369606177, 1.4283229910624944, 1.4781570433847246, 1.5268952168677883, 1.5746174915246671, 1.6213943335215408, 1.6672882231614379, 1.7123548795293786, 1.7566442525315802, 1.8002013343184107, 1.8430668288532899, 1.8852777089054578, 1.9268676828450992, 1.967867588533333, 2.0083057278044842, 2.04820815217418, 2.0875989082230983, 2.126500249424939, 2.164932819881106, 2.202915814401413, 2.2404671185622567, 2.277603431731167, 2.314340375531994, 2.350692589810167, 2.3866738178209843, 2.422296982089408, 2.4575742521646853, 2.4925171053074964, 2.527136380993477, 2.56144232998895, 2.5954446586475957, 2.629152568986901, 2.6625747950273917, 2.69571963581352, 2.7285949854805387, 2.761208360685245, 2.7935669256787157, 2.8256775152650517, 2.8575466558607703, 2.889180584844144, 2.9205852683618208, 2.9517664177409983, 2.9827295046388405, 3.0134797750463123, 3.0440222622509787, 3.074361798852157, 3.1045030279120556, 3.1344504133179454, 3.1642082494227703, 3.1937806700249167, 3.2231716567418736, 3.2523850468272486, 3.2814245404758644, 3.310293707657486, 3.338995994515966, 3.3675347293672453, 3.395913128326628, 3.424134300593085, 3.452201253415864, 3.4801168967665532, 3.507884047737739, 3.535505434687642, 3.562983701148502, 3.5903214095150227, 3.617521044527886, 3.644585016566121, 3.6715156647610563, 3.698315259943561, 3.7249860074354157, 3.751530049694795, 3.7779494688251143, 3.8042462889558055, 3.830422478502946, 3.8564799523171085, 3.882420573725245, 3.9082461564729623, 3.9339584665730865, 3.9595592240659885, 3.985050104696817, 4.010432741514366, 4.035708726396045, 4.060879611503095, 4.0859469106699295, 4.110912100731207, 4.135776622790051, 4.160541883430569], [0.0, 0.2701920077041227, 0.40953450221584387, 0.5223303379776746, 0.620738229566144, 0.709666820762555, 0.7917047464637367, 0.8684230105882647, 0.9408632180197389, 1.0097596309015795, 1.0756537569325701, 1.1389590492840878, 1.2, 1.259037048301951, 1.3162831438874678, 1.3719151557819789, 1.4260819663728026, 1.4789103599737665, 1.530509400750949, 1.5809737496001428, 1.6303862192118455, 1.6788197714748194, 1.7263390995768246, 1.7730018960234086, 1.8188598798124778, 1.8639596365956757, 1.9083433119616193, 1.9520491881558575, 1.9951121674086247, 2.037564179775359, 2.079434529465439, 2.120750190669293, 2.1615360616329817, 2.201815183988549, 2.2416089329960944, 2.2809371832941046, 2.3198184539181157, 2.3582700356824593, 2.3963081034869984, 2.433947815681216, 2.4712034022696474, 2.508088243458424, 2.544614939809584, 2.5807953750775927, 2.616640772643237, 2.6521617463274842, 2.687368346257027, 2.722270100360125, 2.7568760519928843, 2.791194794129649, 2.8252345004947665, 2.8590029539648554, 2.892507572529547, 2.9257554330633697, 2.9587532931310068, 2.991507611021937, 3.0240245641877195, 3.0563100662354405, 3.0883697826136833, 3.12020914511234, 3.1518333652845203, 3.1832474468872456, 3.2144561974275327, 3.245464238891566, 3.276276017726751, 3.3068958141395233, 3.337327750765584, 3.367575800763769, 3.397643795379877, 3.4275354310224255, 3.457254275888438, 3.4868037761738773, 3.516187261900226, 3.5454079523859408, 3.5744689613889715, 3.6033733019442935, 3.632123890918357, 3.660723553300511, 3.689175026249816, 3.7174809629141237, 3.7456439360369647, 3.7736664413665277, 3.8015509008798984, 3.8292996658346836, 3.856915019659246, 3.8843991806918816, 3.911754304778524, 3.938982487737839, 3.966085767701922, 3.9930661273402164, 4.019925495973715, 4.046665751586032, 4.073288722737427, 4.099796190387489, 4.126189889631765, 4.152471511357255, 4.178642703821397, 4.204705074158819, 4.230660189819889, 4.2565095799447885, 4.282254736676648, 4.307897116417008], [0.0, 0.27898274358890857, 0.42285876622823126, 0.5393244307518799, 0.6409340372662778, 0.7327559329851151, 0.8174629744144144, 0.8966772783115048, 0.97147433832489, 1.042612305922578, 1.110650306834322, 1.1760152459899775, 1.2390421728287935, 1.3, 1.3591086055502029, 1.4165506129640464, 1.472479748538763, 1.5270269215340906, 1.5803047445344587, 1.632410958241538, 1.6834310696686388, 1.7334404145300821, 1.7825057908158095, 1.8306867680653456, 1.878036747961642, 1.9246038318272283, 1.9704315364635172, 2.0155593896344297, 2.0600234291192883, 2.103856623822483, 2.1470892313700647, 2.189749103561632, 2.2318619487112685, 2.2734515581138344, 2.314540002476595, 2.3551478030622626, 2.395294081425862, 2.4349966909408587, 2.474272332759813, 2.5131366584112915, 2.551604360875076, 2.5896892556842315, 2.627404353361897, 2.6647619243022014, 2.701773557040241, 2.738450210719178, 2.774802262448023, 2.8108395501475556, 2.846571411400774, 2.882006718755681, 2.917153911869922, 2.952021026837128, 2.9866157229922905, 3.0209453074570707, 3.0550167576544918, 3.0888367419954115, 3.122411638915664, 3.155747554422395, 3.188850338290372, 3.221725599033555, 3.2543787177636836, 3.286814861035735, 3.3190389927696593, 3.351055885328627, 3.38287012982585, 3.414486145724897, 3.445908189792016, 3.4771403644533367, 3.5081866256047927, 3.5390507899180843, 3.569736541682039, 3.6002474392151025, 3.630586920881485, 3.6607583107406327, 3.6907648238570596, 3.7206095712952676, 3.750295564822377, 3.779825721339172, 3.809202867058578, 3.8384297414489925, 3.867509000958529, 3.896443222534902, 3.9252349069545716, 3.9538864819736492, 3.9824003053121673, 4.010778667482378, 4.039023794470974, 4.067137850284382, 4.095122939365619, 4.122981108890564, 4.150714350950948, 4.178324604630849, 4.205813757983002, 4.23318364991077, 4.260436071961284, 4.287572770034797, 4.314595446015039, 4.341505759324996, 4.3683053284122595, 4.394995732167804, 4.421578511281855, 4.4480551695401855], [0.0, 0.2873764756028137, 0.43558128489655595, 0.5555510427711303, 0.6602177695795954, 0.754802303502351, 0.8420579190703289, 0.9236555375410259, 1.0007030108563375, 1.0739813009282666, 1.144066355858723, 1.2113979248328386, 1.2763211378961694, 1.339112998451817, 1.4000000000000001, 1.4591702606038799, 1.5167821317117853, 1.572970461240126, 1.627851249939363, 1.6815251792280232, 1.7340803287622468, 1.785594300876107, 1.8361359033054512, 1.8857664978538857, 1.9345410928966262, 1.982509236976936, 2.0297157561828323, 2.0762013675469815, 2.1220031931145575, 2.1671551937228015, 2.2116885373565958, 2.2556319137904586, 2.2990118048225097, 2.3418527175544406, 2.384177386733161, 2.4260069510430124, 2.4673611073477515, 2.508258246173897, 2.5487155711602814, 2.5887492047417884, 2.6283742819647347, 2.6676050340290507, 2.706454862904468, 2.744936408163504, 2.7830616070046066, 2.820841748297822, 2.8582875213674295, 2.8954090601269615, 2.9322159830985477, 2.9687174297778482, 3.0049220937458303, 3.040838252877445, 3.0764737969534983, 3.11183625294445, 3.146932808202504, 3.181770331770475, 3.2163553939916985, 3.250694284584279, 3.2847930293247014, 3.3186574054698466, 3.352292956032543, 3.3857050030135047, 3.4188986596817523, 3.4518788419861743, 3.4846502791724476, 3.5172175236721963, 3.5495849603246614, 3.581756814985348, 3.6137371625709203, 3.645529934584983, 3.6771389261652736, 3.7085678026890863, 3.7398201059704275, 3.77089926007946, 3.801808576812092, 3.8325512608351815, 3.8631304145306493, 3.8935490425598474, 3.923810056167747, 3.953916277244918, 3.983870442163821, 4.013675205404596, 4.043333142984366, 4.072846755702954, 4.10221847221693, 4.131450651953009, 4.1605455878709705, 4.189505509085536, 4.2183325833559335, 4.247028919451263, 4.275596569399163, 4.304037530624785, 4.332353747986557, 4.360547115714784, 4.388619479258736, 4.416572637047431, 4.444408342169043, 4.472128303973484, 4.499734189602454, 4.527227625450899, 4.554610198563667, 4.581883457970819], [0.0, 0.29541769390627776, 0.44776949269404304, 0.5710961816147636, 0.6786916380543178, 0.7759227869576798, 0.8656199435443283, 0.9495007839168503, 1.0287041593510082, 1.10403288422675, 1.1760790225246736, 1.2452946282617143, 1.3120344887319337, 1.3765833583028444, 1.43917406809738, 1.4999999999999998, 1.5592239363664755, 1.6169844983571173, 1.6734009325947412, 1.7285767377126928, 1.7826024579660031, 1.8355578671166886, 1.887513698242688, 1.9385330301415182, 1.9886724104039921, 2.037982774014807, 2.08651020136214, 2.1342965488013803, 2.1813799771073623, 2.227795397391721, 2.273574849765597, 2.3187478267857804, 2.363341551250222, 2.40738121600552, 2.4508901919503883, 2.493890209260781, 2.5364015159477997, 2.578443017132062, 2.620032397835628, 2.661186231622926, 2.7019200770412266, 2.7422485635004556, 2.7821854679772566, 2.8217437837180572, 2.860935781941751, 2.899773067397644, 2.9382666285131, 2.976426882763522, 3.014263717811496, 3.051786528889274, 3.0890042528370594, 3.1259253991569724, 3.162558078397542, 3.1989100281449794, 3.234988636864221, 3.270800965804046, 3.3063537691557023, 3.341653512632899, 3.3767063906222474, 3.4115183420368105, 3.4460950649911046, 3.4804420304032835, 3.5145644946191905, 3.548467511143225, 3.5821559415523443, 3.615634465661934, 3.648907591005514, 3.6819796616842697, 3.7148548666370527, 3.7475372473767465, 3.7800307052346485, 3.812339008150724, 3.844465797044167, 3.876414591795683, 3.9081887968701206, 3.9397917066056505, 3.971226510193423, 4.002496296369653, 4.033604057840246, 4.06455269545644, 4.095345022158439, 4.125983766702656, 4.1564715771869825, 4.186811024387311, 4.217004604917612, 4.247054744224846, 4.2769637994291925, 4.306734062019296, 4.336367760411491, 4.365867062381352, 4.395234077375282, 4.424470858709338, 4.4535794056619595, 4.4825616654668154, 4.511419535211572, 4.540154863647946, 4.568769452918109, 4.597265060202111, 4.625643399290736, 4.653906142087865, 4.682054920046205, 4.710091325539967], [0.0, 0.3031433133020796, 0.45947934199881396, 0.5860312103167044, 0.6964404506368994, 0.7962143411069944, 0.8882572139691681, 0.9743316651533829, 1.0556063286183155, 1.1329050135538823, 1.2068352673090326, 1.2778609657967936, 1.3463461745354393, 1.412583094649769, 1.4768106461486445, 1.5392272681452155, 1.5999999999999999, 1.6592710880262584, 1.7171628973263064, 1.7737816331792515, 1.8292202077093052, 1.8835604808829862, 1.9368750355551771, 1.989228600129331, 2.0406792010012653, 2.0912791051825463, 2.1410755981331806, 2.1901116308155406, 2.2384263619664257, 2.286055615675829, 2.333032269952246, 2.3793865886274217, 2.425146506416637, 2.470337874997523, 2.5149846764531327, 2.5591092092363814, 2.602732250874477, 2.6458732008855272, 2.688550206781662, 2.730780275551078, 2.772579372620585, 2.813962509981299, 2.854943824898634, 2.8955366504120597, 2.9357535786513984, 2.975606517847699, 3.0151067437923147, 3.054264946393384, 3.0930912718908203, 3.1315953612164047, 3.1697863849222268, 3.207673075046753, 3.245263754241621, 3.282566362442621, 3.31958848133422, 3.35633735682753, 3.3928199197461124, 3.4290428048918673, 3.465012368643982, 3.500734705227077, 3.5362156617699783, 3.571460852263623, 3.6064756705152448, 3.641265302186026, 3.6758347359905117, 3.7101887741283366, 3.7443320420118384, 3.778268997347016, 3.812003938619807, 3.845541013034767, 3.878884223948907, 3.91203743783952, 3.945004390841342, 3.9777886948852803, 4.010393843468089, 4.042823217079862, 4.07508008831392, 4.107167626681603, 4.139088903152599, 4.170846894439793, 4.202444487046027, 4.2338844810888245, 4.265169593917837, 4.296302463538635, 4.327285651855421, 4.358121647744258, 4.388812869967586, 4.419361669939939, 4.4497703343541115, 4.480041087676285, 4.5101760945180756, 4.54017746189286, 4.570047241363234, 4.59978743108597, 4.629399977760444, 4.658886778486028, 4.688249682533635, 4.71749049303623, 4.74661096860282, 4.775612824860096, 4.804497735925724, 4.833267335816907], [0.0, 0.31058435015977326, 0.4707578448360347, 0.6004160891656731, 0.7135354642327094, 0.8157584313073201, 0.9100606131477952, 0.9982478708352801, 1.081517523930205, 1.1607136030632275, 1.2364585686030396, 1.3092276828849148, 1.3793939478767236, 1.4472567371502378, 1.5130608353087662, 1.5770095524050118, 1.6392740279923177, 1.7000000000000002, 1.7593128371369082, 1.8173213516253397, 1.8741207362353605, 1.929794860290125, 1.984418088282687, 2.0380567374572047, 2.0907702585409305, 2.1426122015054765, 2.1936310124924, 2.2438706967498847, 2.2933713742155577, 2.342169748327109, 2.3902995041254242, 2.4377916483063586, 2.484674801278186, 2.530975449280733, 2.5767181630676768, 2.621925788435724, 2.666619612922822, 2.710819512232841, 2.754544079331596, 2.7978107386653672, 2.8406358475526, 2.8830347864727606, 2.9250220397083613, 2.9666112675752254, 3.007815371292962, 3.0486465513952448, 3.089116360452018, 3.1292357507687645, 3.169015117637717, 3.208464338639546, 3.247592809429166, 3.286409476383997, 3.3249228664457084, 3.3631411144458787, 3.40107198817103, 3.4387229113923463, 3.476100985059239, 3.513213006833229, 3.550065489118889, 3.5866646757313063, 3.623016557324495, 3.6591268856919155, 3.695001187038638, 3.7306447743144693, 3.766062758688278, 3.801260060235774, 3.8362414179059043, 3.8710113988247117, 3.905574406989919, 3.9399346914044755, 3.974096353692863, 4.00806335523996, 4.041839523888666, 4.075428560229311, 4.108834043510954, 4.142059437202104, 4.175108094226032, 4.20798326189375, 4.240688086555791, 4.273225617992231, 4.305598813558782, 4.337810542105401, 4.369863587682532, 4.401760653048935, 4.4335043629939985, 4.465097267486405, 4.49654184466018, 4.527840503648313, 4.558995587273367, 4.590009374603867, 4.620884083384566, 4.651621872348154, 4.6822248434154305, 4.7126950437904584, 4.743034467956819, 4.77324505958059, 4.803328713325385, 4.833287276584354, 4.863122551133788, 4.892836294712613, 4.922430222531833, 4.951906008717675], [0.0, 0.3177671523146437, 0.4816449370561384, 0.6143017533237658, 0.730037210271847, 0.8346242608806185, 0.9311073443492159, 1.0213340854305806, 1.1065294937780734, 1.1875571196956047, 1.2650538190282499, 1.3395058453776614, 1.4112948270296084, 1.4807270610893088, 1.5480529932288773, 1.6134806353988551, 1.6771850850517902, 1.7393154505595605, 1.8, 1.859350062066904, 1.9174630310283654, 1.9744247158312014, 2.030311200776437, 2.085190336809603, 2.139122949559204, 2.192163827432888, 2.2443625369733193, 2.2957641011264234, 2.3464095676730183, 2.396336488881493, 2.445579328817768, 2.494169811261357, 2.5421372185171496, 2.589508649365237, 2.636309242800623, 2.6825623729687127, 2.7282898197187166, 2.7735119184146537, 2.8182476920169433, 2.862514967942429, 2.906330481800935, 2.9497099697722087, 2.9926682511129368, 3.035219302057454, 3.0773763221884645, 3.119151794198159, 3.160557537829712, 3.2016047586796805, 3.2423040924494724, 3.282665645155955, 3.3226990297448693, 3.3624133994941414, 3.401817478545766, 3.440919589863421, 3.479727680877173, 3.518249347045801, 3.556491853540495, 3.5944621552304974, 3.632166915131039, 3.6696125214562683, 3.706805103404471, 3.7437505457893145, 3.780454502618952, 3.8169224097143766, 3.8531594964491074, 3.889170796684145, 3.924961158964855, 3.9605352560399982, 3.9958975937573875, 4.03105251938554, 4.066004229406122, 4.1007567768179145, 4.135314077989326, 4.169679919093261, 4.203857962155126, 4.23785175074215, 4.271664715319775, 4.305300178298714, 4.33876135879432, 4.372051377118124, 4.405173259019824, 4.438129939696509, 4.470924267584623, 4.503559007948914, 4.536036846281578, 4.568360391523751, 4.60053217912061, 4.632554673920525, 4.664430272927896, 4.696161307918665, 4.727750047926781, 4.759198701609374, 4.790509419497809, 4.821684296141299, 4.852725372149316, 4.883634636138594, 4.914414026590126, 4.945065433621239, 4.975590700677425, 5.005991626148376, 5.036269964912325, 5.066427429812574], [0.0, 0.32471431911356685, 0.4921748728635773, 0.6277318914425902, 0.7459976084194732, 0.852871187639821, 0.9514636271864408, 1.0436629454062847, 1.1307209336585322, 1.2135200215678696, 1.292710988205075, 1.368790717864283, 1.4421491821585612, 1.5130993745966563, 1.5818972162053428, 1.64875526658493, 1.7138524512463418, 1.7773411384349924, 1.8393524004824757, 1.9000000000000001, 1.9593834605324598, 2.0175904670200278, 2.074698767152554, 2.1307776952631143, 2.1858894067771533, 2.240089887910852, 2.2934297888526745, 2.3459551168602113, 2.397707817119119, 2.4487262628821784, 2.4990456716840463, 2.5486984608636116, 2.597714552908535, 2.64612163904449, 2.6939454078663685, 2.7412097445355377, 2.787936905061957, 2.8341476693904166, 2.8798614763697565, 2.9250965431677356, 2.969869971275522, 3.014197840904224, 3.0580952952957072, 3.101576616238957, 3.1446552918918247, 3.1873440778486692, 3.2296550522611467, 3.271599665707549, 3.3131887864117178, 3.3544327413327557, 3.395341353578899, 3.435923976541106, 3.476189525092443, 3.5161465041569215, 3.555803034914859, 3.5951668788803315, 3.6342454600589327, 3.673045885370349, 3.711574963499614, 3.749839222322854, 3.7878449250376143, 3.825598085113975, 3.8631044801705294, 3.900369664868608, 3.9373989829086184, 3.9741975782040693, 4.010770405301382, 4.0471222391070265, 4.083257683977666, 4.119181182223736, 4.15489702207225, 4.19040934513045, 4.225722153388135, 4.260839315793203, 4.295764574431889, 4.330501550342464, 4.365053748988733, 4.399424565417429, 4.433617289121634, 4.46763510863052, 4.501481115844069, 4.535158310129955, 4.568669602198406, 4.602017817769617, 4.635205701047211, 4.6682359180101525, 4.701111059534649, 4.733833644356683, 4.766406121885031, 4.798830874873955, 4.831110221964035, 4.863246420099046, 4.895241666826226, 4.927098102486752, 4.9588178123028115, 4.9904028283671575, 5.021855131540722, 5.053176653263411, 5.084369277282947, 5.115434841306215, 5.146375138577377, 5.177191919386677], [0.0, 0.33144540173399867, 0.502377286301916, 0.6407442995073612, 0.7614615754863515, 0.870550563296124, 0.9711867496604077, 1.0652972901207103, 1.1541599247257708, 1.2386753752000104, 1.3195079107728942, 1.3971647157747427, 1.4720438456356666, 1.5444647819834854, 1.6146887508945944, 1.682932718169299, 1.7493793183092448, 1.8141840780385095, 1.8774807867191388, 1.9393855651753613, 1.9999999999999998, 2.05941359377582, 2.117705705843569, 2.1749471077846887, 2.231201243459655, 2.2865252596366314, 2.3409708564442386, 2.3945849948357742, 2.447410489488918, 2.499486509105002, 2.5508490012515814, 2.6015310552544992, 2.6515632138719893, 2.700973742347922, 2.7497888617823616, 2.798032952458032, 2.845728731735174, 2.89289741031114, 2.9395588299874267, 2.985731585559923, 3.0314331330207955, 3.076679885911785, 3.1214873013827256, 3.165869957273302, 3.2098416213406935, 3.253415313593096, 3.296603362553129, 3.339417456160925, 3.381868687930399, 3.4239675988907172, 3.4657242157757313, 3.50714808586513, 3.5482483088305674, 3.5890335658967065, 3.6295121465897995, 3.669691973314248, 3.709580623969676, 3.7491853527968475, 3.7885131096196947, 3.827570557632287, 3.866364089863525, 3.904899844438182, 3.9431837187405225, 3.9812213825758107, 4.019018290415328, 4.056579692802027, 4.093910646986333, 4.131016026854923, 4.167900532209297, 4.204568697445628, 4.24102489968264, 4.277273366379966, 4.313318182485628, 4.3491632971478955, 4.384812530023623, 4.420269577212473, 4.455538016843865, 4.490621314341288, 4.525522827386534, 4.560245810604573, 4.5947934199881395, 4.629168717079536, 4.663374672925815, 4.697414171822217, 4.731290014857633, 4.765004923274758, 4.798561541656709, 4.831962440950961, 4.865210121340685, 4.898307014972842, 4.931255488551677, 4.964057845805706, 4.996716329835662, 5.0292331253503795, 5.061610360797125, 5.093850110392401, 5.12595439605889, 5.15792518927379, 5.18976441283349, 5.221473942539152, 5.253055608807534, 5.284511198211075], [0.0, 0.3379774445235429, 0.5122780117711829, 0.6533719273448341, 0.7764682691005909, 0.8877071553024171, 0.9903266543693932, 1.0862919017407517, 1.1769058188454191, 1.2630868786054932, 1.3455124415016924, 1.4246996873258229, 1.5010545162845061, 1.574902706269298, 1.6465106315345432, 1.7160995337880844, 1.7838556468464872, 1.8499375625154726, 1.9144817068442543, 1.9776064891371203, 2.039415498029968, 2.1, 2.1594409183819336, 2.217810419505775, 2.2751731975676783, 2.3315875255699714, 2.3871061225344343, 2.4417768749090447, 2.495643441152405, 2.548745761892782, 2.6011204931433705, 2.6528013763461415, 2.703819556188343, 2.754203854958177, 2.803981010514567, 2.8531758836207297, 2.90181163934494, 2.949909906399649, 2.997490917623599, 3.0445736342742484, 3.091175856362076, 3.1373143209027847, 3.183004789671836, 3.2282621278053223, 3.2731003743919254, 3.3175328060348943, 3.3615719942242785, 3.405229857243201, 3.4485177072337647, 3.4914462929650933, 3.534025838775392, 3.576266080099742, 3.618176295943842, 3.659765338619752, 3.7010416610216272, 3.742013341686627, 3.782688107857718, 3.823073356740422, 3.8631761751240563, 3.9030033575192467, 3.9425614229471027, 3.98185663050102, 4.020894993789432, 4.059682294356702, 4.098224094169463, 4.13652574724705, 4.174592410506911, 4.212429053889056, 4.250040469817495, 4.287431282051144, 4.324605953971883, 4.361568796353057, 4.3983239746478215, 4.434875515833267, 4.4712273148430866, 4.507383140618746, 4.543346641806544, 4.579121352125664, 4.614710695430248, 4.6501179904866, 4.685346455484966, 4.7203992123037555, 4.75527929054267, 4.789989631339918, 4.824533090987547, 4.858912444357821, 4.893130388152635, 4.927189543987052, 4.961092461317228, 4.994841620222262, 5.028439434048816, 5.061888251926707, 5.0951903611631355, 5.128347989522628, 5.161363307399357, 5.194238429887963, 5.2269754187586726, 5.259576284342062, 5.292042987328509, 5.324377440486993, 5.356581510307667, 5.388657018572292], [0.0, 0.3443254092401545, 0.5218997270557746, 0.6656436987568479, 0.7910520623556927, 0.9043802611319715, 1.0089271815990113, 1.106694868790557, 1.1990107158847398, 1.2868104467587054, 1.370784144222729, 1.4514587018501839, 1.5292476435522662, 1.6044828660506327, 1.6774357466978989, 1.7483316826110262, 1.8173604054899921, 1.8846834858457635, 1.9504399121108165, 2.0147503175783408, 2.0777202365081693, 2.139442649564018, 2.1999999999999997, 2.259465809589581, 2.317905987629158, 2.3753799016170625, 2.431941260755028, 2.4876388509045495, 2.5425171505267445, 2.596616850423312, 2.649975295088532, 2.7026268597033627, 2.754603273921236, 2.80593390137674, 2.8566459821249888, 2.906764843869377, 2.9563140867694497, 3.005315745772766, 3.053790433735577, 3.1017574680497377, 3.1492349830493342, 3.196240030108281, 3.2427886670430817, 3.2888960381899963, 3.3345764463228758, 3.3798434174089738, 3.4247097590587567, 3.4691876134070934, 3.513288505063161, 3.557023384681765, 3.6004026686368213, 3.6434362752164358, 3.6861336577065793, 3.7285038346853314, 3.770555417810916, 3.812296637353305, 3.853735365690199, 3.8948791389630153, 3.935735177066666, 3.9763104021277305, 4.016611455608968, 4.056644714163406, 4.09641630434836, 4.135932116298397, 4.175197816446197, 4.214218859371432, 4.253000498849878, 4.291547798168025, 4.329865639762212, 4.3679587342357875, 4.405831628802825, 4.4434887152025375, 4.480934237124512, 4.518172297181388, 4.555206863462334, 4.592041775697883, 4.628680751063988, 4.6651273896509045, 4.701385179620334, 4.737457502072361, 4.773347635641969, 4.809058760843357, 4.844593964178816, 4.8799562420276414, 4.915148504329371, 4.950173578074511, 4.985034210614992, 5.019733072805611, 5.054272761986954, 5.088655804819499, 5.122884659977899, 5.1569617207138325, 5.190889317295192, 5.224669719328855, 5.258305137973801, 5.291797728050832, 5.325149590054783, 5.358362772074692, 5.39143927162704, 5.424381037406845, 5.457189970961077, 5.489867928288593], [0.0, 0.3505025116517289, 0.5312624635140294, 0.6775851622286084, 0.8052433171133403, 0.9206045923666214, 1.0270270556115375, 1.1265486680148695, 1.2205206358204759, 1.3098954695325211, 1.39537563185564, 1.4774974686878823, 1.556681922444803, 1.6332668439832594, 1.7075284790903604, 1.779696268444877, 1.8499633474808994, 1.918494185239582, 1.9854302635673589, 2.050894379885266, 2.114993961708508, 2.1778236577481387, 2.2394673902674014, 2.3000000000000003, 2.3594885786368427, 2.4179935587127273, 2.47556961295758, 2.532266402437731, 2.588129203545563, 2.6431994370644785, 2.6975151174386367, 2.7511112365302144, 2.8040200932138313, 2.8562715778995433, 2.907893419321503, 2.9589113995550838, 3.009349542140152, 3.0592302773251205, 3.108574587755167, 3.157402137370804, 3.2057313858310437, 3.253579690406724, 3.3009633969871253, 3.347897921593703, 3.394397823588107, 3.440476871589695, 3.486148102973916, 3.5314238777021716, 3.5763159271319345, 3.620835398369723, 3.6649928946563133, 3.7087985122111515, 3.752261873909538, 3.795392160120344, 3.8381981369925557, 3.8806881824449073, 3.922870310083372, 3.9647521912456574, 4.006341175349589, 4.047644308702777, 4.0886683519139835, 4.129419796031623, 4.169904877521753, 4.210129592186319, 4.250099708112235, 4.289820777732821, 4.329298149075133, 4.368536976259617, 4.4075422293121695, 4.446318703343055, 4.484871027142107, 4.523203671235125, 4.5613209554423095, 4.599227055976033, 4.636926012111885, 4.6744217324641, 4.711718000893738, 4.7488184820756745, 4.785726726748267, 4.822446176667596, 4.8589801692864505, 4.89533194217657, 4.931504637211244, 4.967501304523981, 5.003324906257825, 5.038978320118713, 5.074464342745305, 5.109785692906793, 5.144945014539333, 5.179944879630994, 5.214787790964368, 5.249476184725406, 5.284012432986362, 5.31839884607023, 5.352637674803571, 5.386731112664073, 5.420681297828867, 5.4544903151291395, 5.488160197916266, 5.521692929844312, 5.555090446573472, 5.588354637398709], [0.0, 0.3565204915932007, 0.5403840154082454, 0.6892190129982211, 0.8190690044316878, 0.9364109840092412, 1.0446606759553492, 1.1458910323684282, 1.241476459132288, 1.332385820953752, 1.4193336415251103, 1.5028654755767288, 1.5834094929274733, 1.6613093451905792, 1.7368460211765295, 1.8102529009635488, 1.8817264360394779, 1.9514339193093737, 2.019519261803159, 2.0861073693216734, 2.1513075138651403, 2.215215969222967, 2.2779180985681755, 2.339490027618228, 2.4000000000000004, 2.459509485849363, 2.518074096603902, 2.57574434598946, 2.6325662877749356, 2.6885820539210705, 2.743830311563958, 2.798346653361256, 2.8521639327456056, 2.905312553332766, 2.957820719947533, 3.009714657332614, 3.0610188015018984, 3.1117559678216806, 3.161947499200286, 3.211613397199771, 3.260772438423691, 3.3094422781598833, 3.357639542949639, 3.405379913500983, 3.4526781991536493, 3.49954840492837, 3.5460037920468173, 3.592056932685706, 3.637719759624956, 3.683003611362192, 3.7279192731913513, 3.7724770146796995, 3.8166866239232387, 3.8605574389138915, 3.9040983763117154, 3.9473179578807684, 3.99022433481725, 4.032825310172493, 4.075128359550719, 4.117140650241662, 4.158869058930878, 4.20032018811534, 4.241500381338587, 4.282415737347952, 4.3230721232659635, 4.363475186858872, 4.403630367977098, 4.443542909235157, 4.483217865992189, 4.522660115688472, 4.561874366588208, 4.6008651659742315, 4.639636907836231, 4.678193840090378, 4.716540071364919, 4.754679577383341, 4.792616206973997, 4.830353687732684, 4.867895631362432, 4.905245538712823, 4.942406804539296, 4.97938272200133, 5.016176486916849, 5.052791201788866, 5.089229879619169, 5.125495447522687, 5.161590750155185, 5.197518552965974, 5.233281545286474, 5.268882343264701, 5.3043234926549685, 5.339607471471509, 5.374736692514054, 5.409713505772867, 5.444540200720249, 5.479219008494974, 5.513752103985769, 5.548141607819491, 5.582389588259298, 5.616498063017758, 5.650469000989534, 5.684304323907982], [0.0, 0.36238983183884776, 0.5492802716530589, 0.7005655161767015, 0.8325532074018733, 0.9518269693579393, 1.0618587587949346, 1.164755654492534, 1.2619146889603867, 1.3543206771711516, 1.4426999059072136, 1.5276069112798434, 1.6094769119996513, 1.6886592171618164, 1.765439441450995, 1.8400548070445832, 1.912704999580074, 1.9835600660790587, 2.052766286755895, 2.1204506237157896, 2.1867241478865562, 2.25168471799771, 2.3154191025426383, 2.378004680484402, 2.4395108189338695, 2.5, 2.559528750642645, 2.6181484161870965, 2.675905808578137, 2.7328437533882894, 2.7890015543245688, 2.844415390000904, 2.899118654710782, 2.9531422525998616, 3.006514852824489, 3.059263111861148, 3.1114118680099447, 3.1629843122429264, 3.214002138833329, 3.26448567862575, 3.314454017339987, 3.363925100920078, 3.412915829627423, 3.4614421423190547, 3.509519092138515, 3.5571609146689678, 3.6043810894494737, 3.6511923956304955, 3.6976069624394143, 3.743636315037741, 3.789291416275995, 3.834582704787697, 3.8795201298087187, 3.9241131830608618, 3.968370927997743, 4.012302026675868, 4.055914764483284, 4.099217072931722, 4.142216550695087, 4.184920483057067, 4.227335859912999, 4.269469392455715, 4.311327528661506, 4.352916467680413, 4.394242173224471, 4.435310386038211, 4.476126635527445, 4.51669625061502, 4.557024369885649, 4.597115951076139, 4.6369757799620945, 4.6766084786875455, 4.716018513579737, 4.755210202487609, 4.794187721679101, 4.832955112329406, 4.871516286629529, 4.909875033542081, 4.9480350242289886, 4.985999817173761, 5.02377286301916, 5.061357509139426, 5.098757003964725, 5.135974501074085, 5.173013063071864, 5.209875665261621, 5.2465651991302344, 5.283084475654167, 5.31943622843888, 5.355623116701614, 5.391647728107035, 5.427512581464528, 5.463220129295364, 5.498772760277325, 5.534172801573929, 5.569422521054832, 5.604524129413612, 5.639479782188666, 5.6742915816926445, 5.7089615788553925, 5.743491774985175, 5.77788412345254], [0.0, 0.3681199371346908, 0.5579654871778171, 0.7116428528501936, 0.8457175324564626, 0.9668772502396322, 1.07864886150376, 1.183172762142339, 1.2818680745325557, 1.3757351855340105, 1.4655118659702304, 1.5517614202733065, 1.6349259488288288, 1.7153602840047626, 1.7933545566230098, 1.8691497398162518, 1.94294867664978, 2.0149241029274125, 2.085224611845156, 2.1539791730320705, 2.221300613668644, 2.2872883398258885, 2.3520304919799546, 2.4156056726094866, 2.478084345657587, 2.539529981199853, 2.6, 2.6595465592552165, 2.7182172111004057, 2.7760554582657195, 2.833101225928093, 2.889391264757428, 2.9449594970775266, 2.999837315690167, 3.054053843068181, 3.107636157180058, 3.160609489068918, 3.2129973964022835, 3.2648219164830765, 3.316103701627056, 3.3668621393372775, 3.4171154593189117, 3.4668808290601643, 3.516174439443155, 3.5650115816316195, 3.6134067163016548, 3.661373536130691, 3.7089250223330232, 3.7560734959232844, 3.8028306642987526, 3.849207663654457, 3.895215097679513, 3.940863072927035, 3.9861612312018586, 4.03111877926886, 4.075744516148919, 4.120046858238577, 4.164033862462565, 4.207713247644966, 4.251092414264318, 4.2941784627401285, 4.336978210382564, 4.379498207123265, 4.421744750133189, 4.463723897422537, 4.505441480508452, 4.54690311622767, 4.588114217763923, 4.62908000495319, 4.669805513923973, 4.710295606124524, 4.750554976784183, 4.790588162851724, 4.830399550449883, 4.869993381881718, 4.909373762221453, 4.948544665519626, 4.9875099406498995, 5.026273316822583, 5.064838408787901, 5.1032087217501525, 5.141387656012233, 5.179378511368464, 5.2171844912622385, 5.254808706723795, 5.292254180102167, 5.329523848604403, 5.366620567654105, 5.4035471140804825, 5.440306189148299, 5.476900421438355, 5.513332369587432, 5.549604524896046, 5.585719313811736, 5.621679100295111, 5.657486188075366, 5.693142822801549, 5.728651194095415, 5.7640134375113625, 5.7992316364085275, 5.834307823739845, 5.869243983762543], [0.0, 0.3737192818846552, 0.5664525067769413, 0.7224674055842077, 0.8585814486631534, 0.981584084911856, 1.0950558154077705, 1.2011695928643287, 1.3013661254372384, 1.3966610165238238, 1.4878032589238495, 1.5753647252978467, 1.65979424066711, 1.741452034631747, 1.820632651093013, 1.8975807285423747, 1.972502195420671, 2.0455724149561503, 2.1169422405444123, 2.186742603526836, 2.2550880472590378, 2.3220794898433157, 2.387806412430048, 2.452348613092933, 2.5157776275776853, 2.578157891381218, 2.639547698674578, 2.7, 2.759563070791425, 2.8182810754839545, 2.876194546542548, 2.9333407936388065, 2.9897542550772416, 3.0454668011646557, 3.100507997345719, 3.154905333462512, 3.208684424338806, 3.2618691859696383, 3.3144819908597043, 3.366543805459979, 3.418074312170107, 3.4690920179809837, 3.519614351509527, 3.569657749911752, 3.619237736939984, 3.6683689932266526, 3.717065419723757, 3.7653401950983425, 3.8132058277757244, 3.8606742032303423, 3.9077566270460276, 3.954463864200935, 4.000806174975454, 4.046793347832573, 4.092434729578075, 4.137739253071697, 4.18271546272887, 4.227371538025415, 4.271715315193772, 4.315754307278591, 4.359495722701402, 4.402946482468111, 4.446113236139098, 4.489002376669406, 4.53162005421553, 4.573972188995795, 4.616064483282697, 4.657902432598029, 4.699491336174884, 4.740836306744568, 4.781942279701141, 4.8228140216914435, 4.863456138674208, 4.903873083487963, 4.9440691629639675, 4.984048544617305, 5.023815262946419, 5.0633732253688555, 5.10272621781865, 5.141877910028737, 5.1808318605198656, 5.219591521315759, 5.258160242402766, 5.296541275950747, 5.334737780310742, 5.372752823803689, 5.410589388313474, 5.448250372696559, 5.485738596019536, 5.523056800635176, 5.560207655106707, 5.597193756989448, 5.634017635478225, 5.670681753928427, 5.7071885122580515, 5.743540249237517, 5.779739244673662, 5.815787721493818, 5.851687847735562, 5.887441738447283, 5.923051457504459, 5.958519019346167], [0.0, 0.37919553292794633, 0.5747529512056274, 0.7330539957746369, 0.8711625697931121, 0.9959676105409553, 1.1111020855422606, 1.2187707886145738, 1.3204355391591909, 1.4171268225970124, 1.5096046070047022, 1.5984491449107985, 1.6841158381406578, 1.7669701948759833, 1.8473110750820523, 1.9253867020313653, 2.001406021712675, 2.0755469670184348, 2.1479626018565336, 2.218785776155186, 2.288132711717446, 2.3561058054370188, 2.4227958496656767, 2.4882838117886985, 2.5526422757923393, 2.6159366213714015, 2.678225996903634, 2.7395641288357435, 2.8000000000000003, 2.859578421989801, 2.91834052120776, 2.976324154038313, 3.0335642634235707, 3.090093186678085, 3.145940922480252, 3.201135363491285, 3.2557024998787267, 3.309666598087803, 3.363050358456047, 3.415875054663829, 3.4681606575244937, 3.519925945218928, 3.5711886017522145, 3.621965305140278, 3.6722718066109024, 3.722123001917418, 3.7715329957077715, 3.8205151597610367, 3.869082185793253, 3.917246133441245, 3.965018473953872, 4.012410130052616, 4.059431512365665, 4.106092552790083, 4.152402735093964, 4.198371123033638, 4.244006386229115, 4.2893168240131905, 4.334310387445603, 4.3789946996625115, 4.4233770747131915, 4.467464535019685, 4.511263827580918, 4.554781439030335, 4.598023609645019, 4.640996346394513, 4.683705435108881, 4.726156451837893, 4.7683547734663225, 4.810305587644277, 4.852013902086025, 4.8934845532859, 4.934722214695503, 4.975731404402501, 5.016516492347795, 5.057081707114652, 5.097431142320563, 5.1375687626399476, 5.177498409483577, 5.2172238063583825, 5.25674856392947, 5.296076184804385, 5.335210068058101, 5.374153513515766, 5.412909725808936, 5.451481818219827, 5.489872816327008, 5.528085661464987, 5.566123214009214, 5.603988256497199, 5.641683496595644, 5.679211569922837, 5.716575042734859, 5.7537764144835855, 5.790818120253923, 5.827702533087189, 5.864431966197095, 5.9010086750843795, 5.937434859555697, 5.973712665652047, 6.0098441874916615, 6.04583146903196], [0.0, 0.3845556523418775, 0.5828773729997969, 0.7434160823843389, 0.8834768904998529, 1.01004611321657, 1.1268080718802014, 1.2359987261768723, 1.3391005590597198, 1.4371586223789157, 1.5309436267417922, 1.6210440268379704, 1.7079216618264603, 1.7919472065307913, 1.8734237454520348, 1.9526030106233871, 2.0296969015901527, 2.1048858664156365, 2.1783251326429838, 2.2501494281009053, 2.3204766174460456, 2.38941054500366, 2.4570432865210377, 2.5234569538981377, 2.5887251571323358, 2.652914200093276, 2.7160840672507502, 2.7782892445017873, 2.839579407075608, 2.9, 2.959592731019947, 3.018395991638901, 3.07644521873502, 3.1337732067270467, 3.1904103783397733, 3.2463850205111937, 3.3017234907929316, 3.35645039864861, 3.41058876529644, 3.464160165130955, 3.5171848512629826, 3.569681867312433, 3.621669147256686, 3.6731636048638046, 3.724181214013092, 3.774737081016837, 3.824845509899273, 3.874520061456291, 3.923773606807715, 3.972618376059396, 4.021066002612059, 4.069127563585345, 4.116813616766904, 4.164134234446155, 4.211099034449018, 4.257717208652576, 4.303997549226272, 4.349948472818144, 4.395578042880155, 4.440893990305322, 4.485903732530686, 4.530614391243751, 4.5750328088156635, 4.619165563571693, 4.663018983998375, 4.706599161976784, 4.7499119651226, 4.792963048305857, 4.835757864416301, 4.878301674434078, 4.920599556860014, 4.962656416554721, 5.004476993031388, 5.04606586824312, 5.087427473902128, 5.128566098364831, 5.169485893114057, 5.210190878866895, 5.250684951334384, 5.2909718866571, 5.331055346538713, 5.370938883097887, 5.4106259434572275, 5.450119874086568, 5.4894239249165455, 5.528541253237183, 5.567474927395122, 5.606227930302112, 5.64480316276645, 5.683203446658209, 5.721431527918321, 5.759490079420865, 5.797381703697239, 5.835108935530327, 5.872674244426186, 5.910080036970263, 5.947328659074711, 5.9844223981229, 6.0213634850168605, 6.05815409613296, 6.094796355190843, 6.1312923350402935], [0.0, 0.38980598409161893, 0.5908353878125555, 0.7535659294528742, 0.8955389853880863, 1.0238362555396097, 1.1421923632295274, 1.2528737956633487, 1.3573832761086355, 1.4567801244906116, 1.5518455739153598, 1.643176113234323, 1.7312398870886565, 1.8164126311189208, 1.899001567833701, 1.9792618661593413, 2.0574083187020165, 2.1336238371793566, 2.2080657684535, 2.280870679789901, 2.352158045049347, 2.422033126341892, 2.4905892565234287, 2.557909668566283, 2.6240689774638675, 2.6891343923314253, 2.753166716605689, 2.8162211800787085, 2.8783481361947603, 2.93959365044182, 3.0, 3.0596061005312944, 3.1184478727329514, 3.176558558765354, 3.2339689967142347, 3.2907078597186694, 3.3468018651894833, 3.4022759585828855, 3.4571534754253865, 3.511456284666359, 3.5652049159320067, 3.618418672844457, 3.671115734233377, 3.7233132447902153, 3.7750273964853767, 3.826273501877373, 3.8770660602830365, 3.927418817643573, 3.9773448208079847, 4.026856466859549, 4.075965548029614, 4.124683292673542, 4.173020402724281, 4.220987087988043, 4.2685930976027615, 4.315847748942062, 4.3627599542147255, 4.40933824498114, 4.4555907947834426, 4.501525440064401, 4.547149699531194, 4.592470792103607, 4.637495653571562, 4.6822309520740895, 4.726683102500444, 4.770858279904049, 4.814762432011041, 4.8584012908973, 4.9017803839007765, 4.944905043829694, 4.987780418521561, 5.030411479802971, 5.0728030318955994, 5.1149597193098835, 5.156886034264125, 5.198586323663598, 5.240064795671256, 5.281325525898968, 5.322372463245853, 5.363209435408064, 5.403840154082454, 5.444268219884699, 5.484497127000912, 5.524530267590222, 5.564370935954513, 5.604022332490236, 5.6434875674361145, 5.682769664429543, 5.721871563883503, 5.760796126195012, 5.799546134795288, 5.838124299051112, 5.8765332570262006, 5.914775578110784, 5.952853765527044, 5.990770258717497, 6.028527435622993, 6.066127614856512, 6.103573057778549, 6.1408659704795, 6.17800850567412, 6.215002764512774], [0.0, 0.3949523275150298, 0.5986357857963711, 0.7635147481560646, 0.9073621778375299, 1.0373532696322088, 1.1572719525551616, 1.2694146367017467, 1.375303884773298, 1.4760130021759006, 1.5723335361052666, 1.6648698504496595, 1.7540962704456937, 1.8403934923161724, 1.9240727946196163, 2.0053927151042434, 2.0845708821369953, 2.1617926222945685, 2.2372173597827607, 2.3109834648717955, 2.3832119887546277, 2.4540095832453934, 2.5234708134102375, 2.5916800110898373, 2.6587127763686413, 2.724637205678154, 2.7895149052015493, 2.853401833892278, 2.9163490099769107, 2.978403107114747, 3.039606960642769, 3.1000000000000005, 3.1596186201202383, 3.2184965020375107, 3.276664890971833, 3.334152838614245, 3.390987415107385, 3.4471938952453622, 3.502795922637781, 3.5578156549548865, 3.612273892861581, 3.666190194832594, 3.719582979700321, 3.772469618505917, 3.8248665169913663, 3.8767891898764817, 3.928252327902718, 3.9792698584895994, 4.0298550007348055, 4.080020315391877, 4.129777750376977, 4.179138682285812, 4.228113954341671, 4.276713911143902, 4.324948430541677, 4.372826952919572, 4.420358508148202, 4.467551740424348, 4.514414931199866, 4.560956020376752, 4.607182625926564, 4.653102062075578, 4.698721356182235, 4.744047264420473, 4.789086286370969, 4.833844678612178, 4.878328467394022, 4.922543460469082, 4.966495258148995, 5.010189263647424, 5.05363069276528, 5.096824582968799, 5.139775801906535, 5.182489055407235, 5.2249688949969055, 5.267219724970058, 5.309245809047159, 5.3510512766476115, 5.392640128805164, 5.434016243750442, 5.475183382183307, 5.516145192255916, 5.556905214285747, 5.597466885216299, 5.637833542841886, 5.678008429811615, 5.71799469742658, 5.757795409243203, 5.79741354449474, 5.836852001342085, 5.876113599964207, 5.915201085497815, 5.954117130835186, 5.992864339288465, 6.031445247128172, 6.069862326003127, 6.108117985248517, 6.14621457408839, 6.184154383738448, 6.221939649414599, 6.259572552252427, 6.29705522114236], [0.0, 0.4, 0.6062866266041592, 0.7732728179727052, 0.9189586839976281, 1.0506111217615068, 1.1720624206334087, 1.2856383398864155, 1.3928809012737988, 1.4948771275386208, 1.592428682213989, 1.6861476532367603, 1.776514427938336, 1.8639145680144265, 1.948663330306766, 2.031022556794963, 2.111212657236631, 2.1894213267673956, 2.2658100271077646, 2.3405188969636868, 2.413670534618065, 2.4853729549442973, 2.5557219315935873, 2.6248028742063427, 2.692692349070879, 2.7594593229224293, 2.825166189299538, 2.8898696223368305, 2.953621292297289, 3.016468469351056, 3.0784545362904314, 3.1396194264808135, 3.2, 3.2596303683411327, 3.318542176052517, 3.3767648461191713, 3.4343257946526133, 3.4912506194704527, 3.5475632663585035, 3.603286176172232, 3.6584404154186103, 3.7130457925386735, 3.7671209617659724, 3.8206835161515613, 3.8737500711103547, 3.9263363396474245, 3.9784572002586613, 4.03012675836242, 4.081358402002531, 4.132164852464745, 4.182558210365093, 4.232549997697407, 4.282151196266361, 4.331372282880042, 4.380223261631082, 4.428713693556512, 4.476852723932852, 4.524649107433693, 4.572111231351659, 4.619247137064344, 4.666064539904492, 4.712570847577553, 4.758773177254844, 4.804678371457315, 4.850293012833274, 4.895623437923128, 4.940675749995046, 4.985455831027359, 5.029969352906266, 5.074221787900985, 5.118218418472762, 5.161964346468972, 5.205464501748954, 5.248723650284115, 5.291746401771055, 5.3345372167931995, 5.377100413563324, 5.419440174276708, 5.461560551102157, 5.503465471835866, 5.545158745241171, 5.586644066095294, 5.627925019962599, 5.6690050877123035, 5.709887649797269, 5.75057599030915, 5.791073300824119, 5.831382684052259, 5.871507157302797, 5.911449655776459, 5.951213035695398, 5.99080007728043, 6.03021348758463, 6.069455903191667, 6.108529892786767, 6.147437959607559, 6.186182543781642, 6.224766024557227, 6.26319072243281, 6.301458901191386, 6.3395727698444535, 6.37753448449064], [0.0, 0.4049538907295691, 0.6137953208516493, 0.782849590583662, 0.9303397362614103, 1.063622653502698, 1.186578093533539, 1.3015606195202702, 1.410131350734334, 1.5133907723985167, 1.6121504764297885, 1.7070301313068958, 1.7985160738271098, 1.886998640762415, 1.9727969933244107, 2.0561762163340935, 2.1373594492637142, 2.21653671180188, 2.293871465328399, 2.369505584128811, 2.443563184832261, 2.5161536200468477, 2.587373849554282, 2.657310340770035, 2.7260406082349884, 2.7936344728185505, 2.8601551007861956, 2.9256598681662247, 2.9902010851437124, 3.053826607316945, 3.116580354762254, 3.1785027554088594, 3.239631125836553, 3.3000000000000003, 3.3596414143565934, 3.4185851562869827, 3.4768589814437374, 3.534488804666445, 3.5914988683029363, 3.647911891132542, 3.703749200565168, 3.7590308503639807, 3.813775725790117, 3.868001637779763, 3.9217254075252073, 3.974962942632798, 4.027729305864534, 4.08003877733052, 4.131904910881854, 4.183340585353936, 4.23435805122562, 4.284968973187484, 4.335184469050854, 4.385015145376222, 4.434471130154174, 4.483562102832575, 4.532297321949694, 4.580685650603365, 4.628735579960538, 4.676455250989074, 4.723852474574001, 4.770934750163184, 4.817709283072156, 4.864183000564624, 4.910362566813195, 4.9562543968345985, 5.001864669484314, 5.047199339587365, 5.092264149274714, 5.137064638588136, 5.181606155410717, 5.225893864774818, 5.2699327575947414, 5.313727658867145, 5.357283235378466, 5.400604002955232, 5.443694333290106, 5.486558460373717, 5.52920048655987, 5.571624388289444, 5.6138340214962685, 5.655833126716373, 5.697625333920355, 5.739214167087049, 5.780603048535298, 5.8217953030293375, 5.862794161672138, 5.9036027656, 5.944224169490699, 5.984661344896622, 6.024917183413453, 6.064994499694283, 6.104896034318299, 6.144624456522541, 6.184182366804697, 6.223572299404311, 6.262796724669296, 6.301858051314204, 6.340758628576268, 6.379500748274817, 6.418086646779356, 6.456518506891204], [0.0, 0.4098185069980794, 0.6211687003195465, 0.7922537794094292, 0.9415156896720696, 1.0763997033896955, 1.2008321783313465, 1.3171959624793503, 1.4270709284654186, 1.531570781383638, 1.6315168626146401, 1.727536284569511, 1.8201212262955901, 1.9096667135891061, 1.9964957416705604, 2.080876579762834, 2.16303504786041, 2.2431634483139202, 2.321427206126455, 2.3979698998861245, 2.472917137206079, 2.546379584321692, 2.618455365769829, 2.6892319876787774, 2.7587878957534473, 2.827193749605003, 2.8945134743004752, 2.9608051351129587, 3.0261216706175325, 3.0905115112905794, 3.1540191048100237, 3.2166853647563336, 3.2785480559846354, 3.339642127297907, 3.4000000000000004, 3.4596518193003956, 3.518625674273817, 3.5769477910687524, 3.63464270325068, 3.691733402514307, 3.748241472470721, 3.8041872077842496, 3.85958972058025, 3.914467035753513, 3.968836176565374, 4.022713241716529, 4.0761134749144095, 4.129051327812741, 4.181540517081861, 4.233594076267603, 4.285224403010953, 4.336443302127689, 4.3872620249848, 4.437691305556904, 4.487741393499769, 4.537422084538199, 4.586742748431116, 4.635712354746672, 4.684339496654219, 4.732632412917156, 4.7805990082508485, 4.828246872192267, 4.875583296612717, 4.922615291991502, 4.969349602556372, 5.015792720386152, 5.061950898561465, 5.107830163441254, 5.1534363261353535, 5.198774993236768, 5.243851576871447, 5.288671304118076, 5.333239225845644, 5.377560225012363, 5.421639024465682, 5.465480194279698, 5.509088158663191, 5.55246720246873, 5.5956214773307345, 5.638555007458138, 5.681271695105201, 5.723775325742133, 5.766069572945521, 5.808158003026931, 5.8500440794167226, 5.891731166818745, 5.93322253515045, 5.974521363281875, 6.015630742585924, 6.056553680311548, 6.0972931027904895, 6.137851858487612, 6.178232720904036, 6.218438391341722, 6.258471501537528, 6.298334616174223, 6.338030235275434, 6.377560796491033, 6.416928677279092, 6.4561361969900295, 6.495185618858333, 6.5340791519068], [0.0, 0.414598014312126, 0.6284130787352045, 0.801493437132564, 0.9524961140507527, 1.0889532122413899, 1.2148368806111876, 1.332557757101115, 1.4437141396035034, 1.5494327217953172, 1.6505444239489884, 1.74768367217253, 1.8413483855501915, 1.9319381968655633, 2.019779868270099, 2.105144797675822, 2.1882614387023356, 2.269324336425956, 2.3485008451184592, 2.42593621785288, 2.5017575271408434, 2.5760767298624163, 2.648993094931631, 2.7205951490167766, 2.790962252695601, 2.860165889646807, 2.928270730463361, 2.9953355176044583, 3.0614138070411787, 3.126554594070215, 3.1908028447404235, 3.254199949786803, 3.316784114497008, 3.378590695264344, 3.439652491506038, 3.5000000000000004, 3.5596616374097194, 3.6186639357460737, 3.677031714697188, 3.734788234098352, 3.791955329279463, 3.8485535315913206, 3.904602176054396, 3.960119497778772, 4.015122718559525, 4.069628124848408, 4.123651138132553, 4.177206378608061, 4.230307722915902, 4.282968356605607, 4.335200821905617, 4.387017061305346, 4.43842845739082, 4.489445869321614, 4.540079666290076, 4.590339758263628, 4.640235624275982, 4.689776338502856, 4.738970594331418, 4.787826726609625, 4.836352732241565, 4.884556289277166, 4.932444774629163, 4.980025280536555, 5.027304629881636, 5.074289390457081, 5.12098588827005, 5.167400219961882, 5.213538264414468, 5.259405693607685, 5.3050079827863925, 5.350350419990066, 5.395438114993441, 5.440276007702218, 5.484868876044043, 5.529221343391489, 5.5733378855506635, 5.617222837346214, 5.660880398830987, 5.704314641146244, 5.747529512056274, 5.790528841179326, 5.833316344935064, 5.875895631227151, 5.9182702038781985, 5.960443466832903, 6.002418728144122, 6.044199203755456, 6.085788021092938, 6.127188222477552, 6.168402768369377, 6.209434540453493, 6.250286344576969, 6.290960913545691, 6.331460909789143, 6.371788927900703, 6.411947497060512, 6.451939083347533, 6.491766091946933, 6.53143086925855, 6.570935704911838, 6.6102828336923185], [0.0, 0.41929627126294755, 0.6355343046292874, 0.8105760231123682, 0.963289874112277, 1.101293314754956, 1.2286035066475318, 1.3476584052676501, 1.460074420543694, 1.5669910139330234, 1.6692485217612372, 1.7674885595023577, 1.8622146886984317, 1.9538310708028417, 2.0426681708611616, 2.129000462287665, 2.213058987556147, 2.295040496342861, 2.37511423939121, 2.453427115793352, 2.5301076380564997, 2.605269031764794, 2.6790116907553227, 2.7514251448874676, 2.822589654059217, 2.8925775120078816, 2.9614541221786177, 3.0292788927047387, 3.0961059864577547, 3.1619849539528717, 3.2269612707977107, 3.2910767967702976, 3.3543701701035804, 3.4168771478522633, 3.478630901119121, 3.5396622722739237, 3.6000000000000005, 3.659670916971042, 3.7187001241338087, 3.777111144905853, 3.8349260620567307, 3.8921656396001048, 3.9488494316624028, 4.004995879995393, 4.060622401552874, 4.1157454673459375, 4.170380673619206, 4.2245428062459816, 4.278245899118408, 4.331503287205689, 4.384327654865776, 4.4367310799213, 4.488725073946639, 4.540320619158207, 4.591528202252848, 4.642357845498505, 4.692819135346037, 4.742921248800429, 4.792672977762986, 4.842082751532813, 4.891158657635536, 4.939908461129342, 4.988339622522715, 5.036459314424459, 5.084274437034299, 5.131791632571649, 5.179017298730474, 5.225957601239728, 5.272618485601246, 5.3190056880702254, 5.3651247459374245, 5.410981007166794, 5.456579639437433, 5.50192563863444, 5.547023836829308, 5.5918789097870265, 5.6364953840338865, 5.680877643517107, 5.725029935884859, 5.768956378412892, 5.8126609636018705, 5.856147564467572, 5.899419939544418, 5.94248173762112, 5.9853365022258735, 6.027987675877147, 6.070438604114908, 6.112692539326078, 6.15475264437693, 6.196621996064261, 6.238303588396318, 6.279800335713656, 6.321115075659425, 6.362250572007879, 6.403209517359361, 6.44399453570938, 6.484608184898946, 6.525052958952817, 6.56533129031191, 6.605445551965647, 6.6453980594897395, 6.685191072994475], [0.0, 0.4239168599773808, 0.6425378074907848, 0.8195084622521248, 0.9739051994230516, 1.1134294194861292, 1.2421425526310068, 1.3625094202779546, 1.4761642449761323, 1.5842590448954468, 1.6876434167551815, 1.7869660465458923, 1.882736044990331, 1.9753620273469294, 2.065178100341775, 2.1524617620493807, 2.237446601000637, 2.320331535026863, 2.4012876799919693, 2.4804635537964224, 2.5579890851380402, 2.633978747331727, 2.7085340405411995, 2.7817454812328917, 2.8536942137581107, 2.924453328521464, 2.994088949705307, 3.0626611401126214, 3.1302246594825007, 3.1968296043701896, 3.262521951518409, 3.327344021994329, 3.3913348798190466, 3.4545306760852155, 3.516964947436718, 3.5786688761221064, 3.6396715175211476, 3.6999999999999997, 3.7596797011144933, 3.8187344035070896, 3.8771864332965045, 3.9350567833130494, 3.9923652231670044, 4.0491303978357704, 4.1053699162056425, 4.161100430796047, 4.2163377097201336, 4.271096701789544, 4.325391595548034, 4.37923587291438, 4.432642358026459, 4.485623261802887, 4.538190222674052, 4.590354343878918, 4.642126227676323, 4.693516006778262, 4.7445333732769965, 4.795187605306875, 4.845487591654778, 4.895441854509557, 4.945058570520286, 4.994345590315051, 5.043310456616143, 5.091960421073551, 5.1403024599262785, 5.188343288590105, 5.236089375260727, 5.283546953612604, 5.330722034666206, 5.377620417889492, 5.424247701593424, 5.470609292675797, 5.5167104157628435, 5.562556121793644, 5.608151296088473, 5.6535006659386235, 5.698608807752099, 5.743480153786629, 5.788118998498899, 5.832529504536486, 5.876715708396875, 5.920681525775961, 5.964430756626707, 6.00796708994699, 6.051294108314211, 6.094415292182929, 6.137334023960516, 6.180053591874762, 6.2225771936462975, 6.264907939977813, 6.307048857871123, 6.349002893782425, 6.390772916625316, 6.432361720630473, 6.473772028070332, 6.515006491856482, 6.5560676980169985, 6.596958168060459, 6.637680361232951, 6.678236676673921, 6.718629455476418, 6.75886098265684], [0.0, 0.4284631128115855, 0.6494286382271337, 0.8282971966029294, 0.9843497457271546, 1.1253702789610172, 1.2554637828851805, 1.3771215126441316, 1.491995216838946, 1.6012492683400972, 1.705742375279642, 1.8061301804144303, 1.9029272543728812, 1.996546594565807, 2.0873258908125694, 2.1755456171872876, 2.261441867317064, 2.3452156923070744, 2.4270400431357393, 2.507065030468499, 2.5854219764101494, 2.662226581932905, 2.7375814357285657, 2.8115780249981146, 2.8842983643171225, 2.9558163279407355, 3.0261987491933127, 3.095506335015198, 3.1637944324106853, 3.23111367519038, 3.29751053316986, 3.3630277812842353, 3.427704902492684, 3.4915784355865416, 3.5546822768699844, 3.6170479430023863, 3.6787048009649514, 3.7396802700592158, 3.8000000000000003, 3.859688028484274, 3.918766921064919, 3.977257895707701, 4.0351809340400555, 4.092554880995529, 4.149397534305107, 4.205725725076455, 4.261555390526229, 4.316901639783067, 4.3717788135543065, 4.426200538344177, 4.480179775821704, 4.533728867860249, 4.586859577705349, 4.639583127671515, 4.691910233720423, 4.743851137231293, 4.795415634238238, 4.846613102378005, 4.897452525764357, 4.947942517981484, 4.998091343368093, 5.047906936745526, 5.097396921727223, 5.1465686277327505, 5.19542910581707, 5.243985143414747, 5.29224327808898, 5.3402098103666304, 5.387890815732737, 5.435292155851061, 5.4824194890710745, 5.5292782802762925, 5.575873810123913, 5.622211183721298, 5.668295338780833, 5.714131053291164, 5.759722952739512, 5.805075516916899, 5.850193086335471, 5.89507986828469, 5.939739942551044, 5.984177266823907, 6.0283956818084485, 6.072398916064822, 6.116190590591414, 6.15977422316856, 6.203153232477913, 6.2463309420115225, 6.289310583783649, 6.332095301857393, 6.374688155697338, 6.41709212335865, 6.459310104522293, 6.501344923385386, 6.543199331415097, 6.5848760099738906, 6.6263775728234355, 6.667706568513969, 6.708865482665511, 6.749856740146836, 6.790682707157798, 6.831345693220224], [0.0, 0.4329381358372115, 0.6562115047625906, 0.8369482307667259, 0.9946306489033756, 1.137124051363171, 1.2685762986846942, 1.39150466557818, 1.5075781521018337, 1.6179732922556398, 1.7235577628285792, 1.8249940543465297, 1.9228021117988336, 2.0173992460899677, 2.109126673993359, 2.198267798955346, 2.285061180449882, 2.369709969432276, 2.452388923243243, 2.5332497203580626, 2.612425054456877, 2.6900318349345147, 2.7661737219560125, 2.840943158247622, 2.9144230149746706, 2.986687937961626, 3.0578054585641516, 3.1278369177677345, 3.1968382406407096, 3.2648605898314322, 3.3319509205029667, 3.398152454347246, 3.463505086697692, 3.528045737969933, 3.59180865849335, 3.654825694098656, 3.7171265184863813, 3.778738837335119, 3.8396885682545485, 3.9000000000000004, 3.959695933807117, 4.018797809249738, 4.077325816650609, 4.135298997766548, 4.192735336214456, 4.249651838892141, 4.306064609470291, 4.361988914882725, 4.417439245616291, 4.472429370495333, 4.526972386565217, 4.581080764602273, 4.634766390711609, 4.6880406044176315, 4.740914233603377, 4.79339762661272, 4.845500681793078, 4.897232874724615, 4.948603283354412, 4.999620611230034, 5.0502932090059165, 5.100629094377535, 5.1506359705820906, 5.200321243590248, 5.249692038100725, 5.298755212438499, 5.34751737244743, 5.395984884459352, 5.444163887413859, 5.492060304196038, 5.5396798522531965, 5.5870280535460655, 5.634110243884927, 5.680931581696721, 5.727497056265081, 5.773811495481686, 5.819879573144011, 5.865705815831627, 5.911294609390553, 5.956650205052698, 6.001776725215309, 6.0466781689032905, 6.091358416935522, 6.135821236814581, 6.180070287357865, 6.2241091230866745, 6.267941198388603, 6.31156987146745, 6.3549984080937945, 6.398229985168465, 6.441267694110194, 6.48411454407803, 6.526773465038248, 6.569247310684898, 6.611538861222461, 6.653650826018519, 6.695585846133807, 6.7373464967365395, 6.778935289407447, 6.820354674341504, 6.861607042452013, 6.902694727382273], [0.0, 0.43734482957731124, 0.6628908034679973, 0.8454671719825998, 1.0047545726038323, 1.1486983549970349, 1.2814885990147225, 1.4056682016392041, 1.5229231509727028, 1.6344419564559964, 1.7411011265922482, 1.8435698951175354, 1.9423734993208153, 2.0379334977373427, 2.1305945802414206, 2.22064303492292, 2.3083198494515416, 2.393830242570043, 2.4773507504000207, 2.55903459528765, 2.6390158215457884, 2.71741252854043, 2.794329431549485, 2.8698599142345236, 2.944087691271333, 3.0170881682725814, 3.0889295639669707, 3.1596738437038745, 3.229377501789189, 3.298092221634176, 3.3658654363385985, 3.4327408075296675, 3.49875863661849, 3.5639562198179524, 3.6283681560770185, 3.6920266153716113, 3.754961573438278, 3.8172010179599685, 3.878771130350723, 3.9396964465908155, 3.9999999999999996, 4.059703448376447, 4.11882718755164, 4.177390453100367, 4.235411411687138, 4.292907243315766, 4.349894215569377, 4.406387750777435, 4.46240248691931, 4.517952332966374, 4.573050519273263, 4.627709643551054, 4.681941712888477, 4.735758182230154, 4.789169989671549, 4.842187588887944, 4.894820978977837, 4.947079731969304, 4.9989730182100045, 5.050509629837221, 5.101698002503163, 5.152546235512025, 5.2030621105089985, 5.253253108846981, 5.303126427743979, 5.352688995332952, 5.401947484695844, 5.450908326964682, 5.499577723564723, 5.54796165766759, 5.596065904916064, 5.643896043476572, 5.691457463470348, 5.738755375829772, 5.7857948206222805, 5.832580674880615, 5.879117659974853, 5.925410348558702, 5.971463171119847, 6.017280422161684, 6.062866266041592, 6.108224742488859, 6.153359771823571, 6.198275159896119, 6.242974602765451, 6.287461691132831, 6.331739914546604, 6.3758126653922975, 6.419683242681387, 6.463354855651026, 6.506830627186191, 6.550113597074882, 6.593206725106259, 6.636112894020912, 6.678834912321849, 6.721375516954154, 6.763737375860798, 6.805923090421544, 6.847935197781435, 6.889776173074944, 6.9314484315514635, 6.972954330607461], [0.0, 0.4416859073743617, 0.6694706470014973, 0.8538592656355098, 1.0147277504526042, 1.160100316532068, 1.2942086343921448, 1.4196208417699987, 1.5380396618588412, 1.6506654012251878, 1.758383268581612, 1.8618691404675727, 1.9616534676689728, 2.0581619931043584, 2.151742828034224, 2.2426851022394483, 2.3312321954294966, 2.41759136334509, 2.5019408944025505, 2.584435531830615, 2.665210650463852, 2.7443855219206763, 2.822065900881175, 2.8983460979316527, 2.9733106586984315, 3.0470357372690877, 3.1195902295103357, 3.1910367158386173, 3.2614322513214073, 3.330829032378683, 3.3992749629303978, 3.466814137988378, 3.5334872589948936, 3.5993319923644456, 3.664383280474612, 3.728673612619983, 3.7922332620757886, 3.8550904943302733, 3.917271750673775, 3.978801810630316, 4.0397039361480145, 4.1000000000000005, 4.159710600466454, 4.2188551640541725, 4.277452037749688, 4.335518572085257, 4.393071196115774, 4.450125485252501, 4.506696222771157, 4.5627974557033415, 4.618442545727981, 4.673644215600829, 4.728414591592791, 4.78276524235008, 4.836707214539526, 4.890251065599423, 4.943406893879161, 4.996184366418617, 5.048592744590169, 5.100640907801719, 5.1523373754376225, 5.203690327195641, 5.25470762196145, 5.305396815347737, 5.355765176011978, 5.405819700855672, 5.455567129197667, 5.505013956005304, 5.554166444259088, 5.603030636519507, 5.6516123657582815, 5.69991726551063, 5.747950779400041, 5.7957181700825275, 5.843224527653156, 5.890474777554016, 5.93747368801943, 5.984225877091192, 6.0307358192339375, 6.0770078515782355, 6.123046179816809, 6.168854883777234, 6.214437922692633, 6.2597991401902044, 6.30494226901592, 6.349870935512288, 6.394588663864853, 6.439098880131907, 6.483404916070863, 6.52751001277371, 6.571417324123128, 6.615129920080007, 6.658650789812329, 6.701982844674719, 6.745128921047339, 6.788091783042148, 6.830874125084079, 6.873478574374143, 6.91590769324105, 6.958163981387414, 7.000249878036358, 7.0421677639838265], [0.0, 0.4459639117116218, 0.6759548890470857, 0.8621294268084412, 1.024556023542366, 1.1713366138712415, 1.3067438546896681, 1.4333707577554535, 1.5529365382011815, 1.6666531283133907, 1.7754143106048341, 1.8799025079020921, 1.980653308738786, 2.0780965796199786, 2.172583803481504, 2.264406910507053, 2.3538116376908382, 2.4410072481750915, 2.5261737572109864, 2.60946740681224, 2.6910248830033843, 2.770966612623078, 2.8493993746516453, 2.9264183931324212, 3.0021090325690123, 3.076548184648975, 3.1498054125385955, 3.2219439027848003, 3.293021263069086, 3.3630901953664134, 3.432199067576169, 3.5003924017979555, 3.5677112936929745, 3.6341937744985153, 3.6998751250309447, 3.7647881492639956, 3.8289634136885087, 3.892429457561665, 3.9552129782742407, 4.017338995355452, 4.078830996059936, 4.139711065012315, 4.2, 4.259717415687659, 4.318881836763867, 4.37751078181164, 4.435620839011549, 4.493227734632457, 4.550346395135357, 4.606991003606137, 4.663175051139943, 4.718911383720378, 4.774212245068868, 4.829089315881203, 4.883553749818089, 4.937616206573217, 4.99128688230481, 5.04457553768407, 5.097491523785564, 5.150043806019813, 5.20224098628674, 5.254091323509597, 5.305602752692283, 5.356782902628322, 5.407639112376685, 5.45817844660824, 5.508407709916354, 5.558333460176188, 5.607962021029134, 5.6572994935616565, 5.7063517672414585, 5.75512453016807, 5.803623278689879, 5.851853326435015, 5.899819812799298, 5.947527710930808, 5.994981835247198, 6.042186848518885, 6.089147268548497, 6.135867474474423, 6.182351712724153, 6.228604102640944, 6.2746286418055695, 6.3204292110731615, 6.366009579343672, 6.411373408083004, 6.456524255610644, 6.501465581168405, 6.54620074878385, 6.590733030940975, 6.635065612069788, 6.679201591865667, 6.723143988448557, 6.766895741371376, 6.810459714486401, 6.853838698677745, 6.897035414467529, 6.940052514502856, 6.982892585930187, 7.025558152663321, 7.068051677550784, 7.110375564448018], [0.0, 0.4501812287589041, 0.6823471463618782, 0.870282268402032, 1.0342448738517942, 1.1824135143559145, 1.3191012517572087, 1.4469256189740602, 1.5676220891256212, 1.6824140552972933, 1.79220375217504, 1.8976800560076683, 1.9993836201930044, 2.097748376325891, 2.1931291311872956, 2.2858205756375187, 2.376070770515344, 2.4640909578877404, 2.5500628553440485, 2.6341441824213683, 2.716472917733804, 2.7971706269524304, 2.8763450988272026, 2.9540924579002863, 3.0304988759360705, 3.1056419717585824, 3.179591966367442, 3.2524126438415615, 3.3241621566371395, 3.3948937051123727, 3.464656114564122, 3.533494328121146, 3.6014498300712328, 3.668561011299126, 3.7348634862589236, 3.800390369139501, 3.8651725154877834, 3.9292387344462343, 3.9926159758730564, 4.055329495897971, 4.117403003885964, 4.178858793307848, 4.239717858628075, 4.3, 4.359723917293379, 4.418907294758038, 4.477566877442884, 4.535718540334333, 4.593377351047442, 4.650557626792337, 4.707272986244501, 4.763536396867289, 4.819360218166504, 4.874756241297993, 4.929735725398538, 4.984309430966639, 5.038487650581845, 5.092280237218447, 5.14569663038069, 5.198745880261692, 5.251436670106387, 5.303777336939633, 5.355775890803749, 5.407440032634961, 5.458777170895026, 5.50979443706281, 5.560498700080225, 5.61089657983785, 5.660994459777432, 5.710798498681172, 5.760314641711307, 5.809548630757638, 5.858506014145501, 5.907192155752058, 5.9556122435745085, 6.003771297790167, 6.051674178344871, 6.0993255921031455, 6.146730099590816, 6.19389212135818, 6.240815943989634, 6.28750572578355, 6.333965502124356, 6.3801991905670095, 6.426210595652564, 6.472003413472062, 6.517581235994712, 6.562947555175106, 6.608105766853183, 6.653059174459618, 6.697810992538405, 6.7423643500976045, 6.786722293798413, 6.830887790992022, 6.874863732613109, 6.9186529359381534, 6.962258147216256, 7.005682044179628, 7.048927238440427, 7.09199627778018, 7.134891648337663, 7.177615776700701], [0.0, 0.4543401013724981, 0.688650818480309, 0.8783221262657902, 1.0437994541115494, 1.1933369089104924, 1.331287397513696, 1.4602926341809104, 1.5821041247113854, 1.697956564163314, 1.8087605222639431, 1.9152112392514733, 2.0178543631980226, 2.117127834453376, 2.2133897375811142, 2.306937485860134, 2.3980214317694797, 2.486854768876519, 2.5736208935174107, 2.658478982276822, 2.741568288445458, 2.8230115007446424, 2.9029174037003673, 2.981383009874335, 3.0584952871045323, 3.1343325712746535, 3.2089657321012655, 3.2824591429145453, 3.3548714933957973, 3.426256475379757, 3.496663365222053, 3.5661375212458926, 3.6347208109799847, 3.7024519799724587, 3.769366971691527, 3.83549920624218, 3.9008798242216334, 3.9655379009175054, 4.0295006351566816, 4.092793516390532, 4.155440473016339, 4.217464004456871, 4.278885299128036, 4.3397243401013315, 4.4, 4.459730126444834, 4.518931619179162, 4.577620499845997, 4.635811975258316, 4.693520494891765, 4.750759803234126, 4.807542987545015, 4.863882521510056, 4.9197903052143666, 4.975277701809099, 5.03035557120059, 5.08503430105349, 5.139323835366017, 5.193233700846624, 5.246773031296089, 5.299950590177064, 5.352774791533662, 5.405253719406726, 5.457395145875413, 5.509206547842472, 5.560695122668928, 5.61186780275348, 5.6627312691427045, 5.713291964249978, 5.76355610375368, 5.813529687738754, 5.8632185111398325, 5.912628173538899, 5.961764088365781, 6.010631491545533, 6.059235449632965, 6.107580867471154, 6.1556724954076705, 6.2035149360994755, 6.251112650934875, 6.298469966098669, 6.345591078304501, 6.392480060216563, 6.439140865581038, 6.485577334086164, 6.531793195968281, 6.577792076379993, 6.623577499535333, 6.6691528926457515, 6.714521589659738, 6.759686834817947, 6.804651786034899, 6.849419518117514, 6.893993025830022, 6.938375226814186, 6.982568964373102, 7.026577010126322, 7.070402066543531, 7.114046769363531, 7.157513689904811, 7.200805337273644, 7.243924160475199], [0.0, 0.45844264074473967, 0.6948691053715768, 0.8862530817188333, 1.0532246145679585, 1.204112342640346, 1.3433084780821294, 1.4734785889505286, 1.5963899965571833, 1.7132885448442907, 1.8250930256796174, 1.9325049570885149, 2.0360749141629535, 2.136244791707811, 2.233375907670682, 2.3277683608730393, 2.4196747643932, 2.509310236865241, 2.5968598306329844, 2.6824841595924944, 2.766323734445183, 2.848502351750551, 2.9291297783225274, 3.008303902713846, 3.086112478053025, 3.1626345475706246, 3.2379416209130834, 3.31209865268025, 3.3851648625016493, 3.4571944270313524, 3.528237067574021, 3.598338552023373, 3.6675411259579174, 3.735883884785143, 3.8034030965307766, 3.8701324830721933, 3.9361034661958016, 4.001345383729356, 4.065885680096066, 4.129750074908533, 4.192962712629475, 4.255546295843936, 4.31752220429214, 4.378910601486047, 4.439730530462385, 4.500000000000001, 4.559736062441261, 4.618954884099263, 4.677671809099428, 4.7359014173913385, 4.793657577570913, 4.850953495071352, 4.907801756211491, 4.964214368530246, 5.020202797784225, 5.075778001941093, 5.130950462462644, 5.185730213138079, 5.240126866698844, 5.294149639420891, 5.34780737389801, 5.401108560150324, 5.454061355214864, 5.506673601350067, 5.558952842972614, 5.610906342433299, 5.662541094728065, 5.713863841231108, 5.764881082528644, 5.815599090424555, 5.866023919182545, 5.916161416063574, 5.966017231211977, 6.0155968269390465, 6.064905486448492, 6.11394832204442, 6.162730282859004, 6.211256162133866, 6.259530604086421, 6.307558110389822, 6.355343046292874, 6.402889646404141, 6.450202020162614, 6.497284157015482, 6.544139931322087, 6.590773107001557, 6.637187341940413, 6.683386192175163, 6.729373115863835, 6.775151477059356, 6.820724549296791, 6.866095519005577, 6.91126748875711, 6.956243480357342, 7.001026437793367, 7.045619230042359, 7.090024653750667, 7.134245435790375, 7.178284235700128, 7.222143648016561, 7.265826204502337, 7.309334376276327], [0.0, 0.46249083687022485, 0.7010050233034578, 0.8940789817829836, 1.0625249270280588, 1.2147450423216124, 1.3551703244572169, 1.486489879316287, 1.6104866342266806, 1.7284174343337364, 1.8412091847332428, 1.9495695980805874, 2.0540541112230746, 2.155108521038989, 2.253097336029739, 2.3483233049860153, 2.4410412716409513, 2.5314682541954268, 2.6197909390650422, 2.7061713584182776, 2.7907512637112797, 2.873655544667029, 2.9549949373757642, 3.034868194777657, 3.113363844889606, 3.190561628919346, 3.2665336879665188, 3.3413455502010034, 3.4150569581807204, 3.48772256695704, 3.559392536889754, 3.630113040017817, 3.699926694961799, 3.7688729423542244, 3.8369883704791636, 3.904306998989029, 3.970860527134718, 4.036678551806451, 4.101788759770532, 4.16621709775202, 4.229987923417015, 4.293124139821696, 4.355647315496277, 4.417577792003022, 4.478934780534802, 4.539736448893781, 4.6000000000000005, 4.659741742920305, 4.718977157273685, 4.777720951755374, 4.835987117425454, 4.893788976325355, 4.951139225915159, 5.008049979764218, 5.064532804875462, 5.12059875597894, 5.176258407091126, 5.231521880602812, 5.286398874128957, 5.340898685328197, 5.3950302348772725, 5.448802087765919, 5.502222473060429, 5.555299302268907, 5.6080401864276626, 5.660452452016386, 5.712543155799087, 5.764319098678464, 5.815786838643006, 5.866952702878638, 5.917822799110167, 5.968403026231745, 6.018699084280303, 6.068716483801103, 6.118460554650241, 6.167936454275117, 6.217149175510333, 6.26610355392338, 6.314804274741608, 6.363255879389391, 6.411462771662088, 6.459429223561221, 6.507159380813448, 6.554657268094064, 6.60192679397425, 6.648971755609751, 6.695795843187406, 6.7424026441446685, 6.788795647176214, 6.834978246040643, 6.880953743179389, 6.926725353159084, 6.972296205947832, 7.017669350035101, 7.062847755404342, 7.107834316366718, 7.152631854263869, 7.197243120047037, 7.241670796739447, 7.2859175017883295, 7.329985789312627, 7.373878152251986], [0.0, 0.46648656797184945, 0.707061419129511, 0.9018034574050197, 1.071704706514952, 1.2252399411589503, 1.3668784401251426, 1.4993325420666, 1.6244005780718769, 1.7433502519127695, 1.8571164767648465, 1.9664130796305108, 2.0718002961035697, 2.173727774564455, 2.272563172718494, 2.368611854981732, 2.462130866832611, 2.5533391014202382, 2.6424248580542606, 2.729551568794622, 2.8148622097719005, 2.898482749705048, 2.9805248813986958, 3.061088210977907, 3.1402620313053284, 3.218126772520019, 3.2947551989911243, 3.370213405025032, 3.4445616493308524, 3.51785505915718, 3.5901442282287364, 3.6614757274919523, 3.7318925437747956, 3.801434458460676, 3.8701383759414285, 3.938038609785306, 4.005167133111731, 4.071553798515912, 4.137226531966456, 4.202211504357483, 4.2665332837953365, 4.3302149712092035, 4.393278321472553, 4.4557438518904, 4.5176309396324426, 4.578957909463202, 4.639742112928889, 4.7, 4.759747184033081, 4.818998500800457, 4.877768062239231, 4.936069305487806, 4.993915037707111, 5.051317477122764, 5.108288290671859, 5.164838628592776, 5.220979156257154, 5.276720083509089, 5.332071191746954, 5.3870418589573426, 5.441641082887982, 5.495877502526606, 5.549759418035264, 5.603294809274244, 5.656491353036088, 5.709356439098266, 5.76189718519233, 5.814120450977994, 5.86603285110207, 5.91764076741478, 5.968950360409164, 6.019967579943403, 6.070698175300406, 6.121147704634285, 6.171321543848908, 6.221224894949903, 6.270862793907917, 6.320240118067758, 6.36936159313522, 6.4182317997707194, 6.466855179816602, 6.515236042182729, 6.563378568413137, 6.611286817954665, 6.658964733146942, 6.706416143951586, 6.753644772437132, 6.800654237035025, 6.847448056580829, 6.894029654153828, 6.940402360727194, 6.986569418640095, 7.032533984902276, 7.078299134340906, 7.123867862598871, 7.169243088992997, 7.214427659240157, 7.259424348058685, 7.304235861652025, 7.348864840081077, 7.393313859531326, 7.4375854344803916], [0.0, 0.47043160900986947, 0.7130409831864014, 0.909429939906239, 1.0807680308164909, 1.235601701134824, 1.3784380259964422, 1.5120122820938597, 1.6381380088633757, 1.758093630950113, 1.8728219680184823, 1.9830428838509613, 2.089321351910698, 2.192110823219906, 2.2917820647368567, 2.3886430233209834, 2.4829529182645755, 2.5749324938792726, 2.664771641907504, 2.7526351765415797, 2.8386672830502206, 2.9229949954601486, 3.0057309511534567, 3.086975598616549, 3.1668189858549463, 3.245342223199209, 3.322618690381158, 3.398715040661647, 3.473692042353059, 3.5476052889108884, 3.620505801927098, 3.6924405461950314, 3.7634528720789557, 3.8335828973903814, 3.9028678386187474, 3.971342299519515, 4.039038523606319, 4.105986615935471, 4.172214738643347, 4.237749283949308, 4.302615027730281, 4.366835266278235, 4.430431938445933, 4.4934257350516615, 4.555836197136351, 4.617681804435648, 4.678980055236456, 4.739747538625407, 4.800000000000001, 4.85975240059755, 4.919018971698726, 4.977813264078776, 5.036148193207803, 5.0940360806400244, 5.15148869197892, 5.20851727175958, 5.265132575549871, 5.321344899537755, 5.377164107842141, 5.432599657758532, 5.4876606231279155, 5.542355715997282, 5.596693306722512, 5.65068144264896, 5.704327865491211, 5.757640027521514, 5.810625106665532, 5.863290020594591, 5.915641439895066, 5.967685800387993, 6.019429314665227, 6.070877982902443, 6.122037603003797, 6.172913780128278, 6.223511935643362, 6.273837315547639, 6.323894998400571, 6.373689902794299, 6.423226794399542, 6.472510292615016, 6.521544876847382, 6.570334892446621, 6.618884556319768, 6.667197962244088, 6.715279085899277, 6.763131789636642, 6.810759827001965, 6.858166847027489, 6.9053563983072985, 6.952331932869397, 6.999096809856739, 7.045654299028707, 7.0920075840936345, 7.138159765882266, 7.184113865371411, 7.229872826566332, 7.275439519249912, 7.3208167416060625, 7.3660072227243845, 7.411013624992569, 7.455838546382703, 7.500484522637151], [0.0, 0.47432763938033673, 0.7189462609625462, 0.9169616758649352, 1.0897187581716394, 1.2458347332296575, 1.3898540029636202, 1.524534497137946, 1.651704774597892, 1.7726538476726312, 1.8883323442902544, 1.9994660900162176, 2.1066247373227505, 2.2102654926322574, 2.3107621935285843, 2.4084253372319266, 2.5035162898423473, 2.5962576238363586, 2.686840803605807, 2.7754320083046373, 2.862176617318155, 2.947202716746151, 3.0306238768133515, 3.1125413779025433, 3.193046013780709, 3.2722195665196456, 3.3501360235689783, 3.426862590199935, 3.502460537997181, 3.5769859208312598, 3.6504901828458234, 3.723020677788227, 3.794621115042694, 3.865331944669267, 3.93519069137769, 4.0042322455055315, 4.072489117601433, 4.139991662046395, 4.206768274210564, 4.272845564888937, 4.33824851514782, 4.403000614214901, 4.467123982636593, 4.530639482588836, 4.593566816947964, 4.6559246184954866, 4.717730530435986, 4.779001279243938, 4.839752740717409, 4.9, 4.9597574062333, 5.019038622417651, 5.07785667098677, 5.136223975539776, 5.1941523991207745, 5.251653279390081, 5.308737460991249, 5.365415325383428, 5.4216968183783925, 5.477591475595273, 5.533108446022986, 5.5882565138601334, 5.6430441187843865, 5.697479374787772, 5.75157008770037, 5.805323771512813, 5.858747663597062, 5.911848738915356, 5.964633723298672, 6.017109105868364, 6.069281150667864, 6.121155907565225, 6.1727392224818045, 6.22403674699752, 6.275053947378638, 6.325796113070174, 6.376268364691308, 6.4264756615690795, 6.476422808842642, 6.526114464167743, 6.575555144048686, 6.624749229822866, 6.673700973320984, 6.722414502224239, 6.7708938251381925, 6.819142836401452, 6.867165320645997, 6.9149649571247, 6.962545323820468, 7.00990990135038, 7.057062076677213, 7.104005146639913, 7.150742321313712, 7.197276727209882, 7.243611410324421, 7.2897493390443175, 7.335693406919481, 7.381446435307882, 7.427011175900952, 7.472390313135802, 7.517586466500456, 7.562602192737844], [0.0, 0.47817624989501856, 0.7247796636776956, 0.9244017406098536, 1.098560543306118, 1.25594321575479, 1.401131032353403, 1.5369043002203584, 1.6651064148037464, 1.7870368472506375, 1.9036539387158786, 2.0156894039851, 2.1237175175898693, 2.2281991956445797, 2.329511308985068, 2.427966874151019, 2.523829377920773, 2.617323198684523, 2.708641354342303, 2.797951372396302, 2.8853998118144273, 2.971115797964412, 3.0552138225596863, 3.1377959877541373, 3.2189538239993025, 3.2987697769322355, 3.377318434323633, 3.4546675467363976, 3.53087888290199, 3.6060089515021363, 3.680109614089167, 3.7532286086303603, 3.8254099991601485, 3.896694563943202, 3.967120132158117, 4.036721877236486, 4.10553257351179, 4.173582821655104, 4.24090124743158, 4.307514677551497, 4.3734482957731124, 4.4387257819115495, 4.50336943599542, 4.567400289472667, 4.6308382050852765, 4.693701966797848, 4.756009360968804, 4.817777249788274, 4.879021637867739, 4.939757732748986, 5.0, 5.059762213480288, 5.1190575012852895, 5.17789838781701, 5.236296832374193, 5.294264264608923, 5.351811617156274, 5.408949355708716, 5.465687506776579, 5.522035683349322, 5.5780031086491375, 5.633598638148059, 5.688830780001809, 5.743707714037909, 5.798237309421565, 5.852427141110598, 5.906284505199723, 5.959816433244789, 6.013029705648978, 6.065930864185223, 6.118526223722295, 6.170821883215807, 6.2228237360198895, 6.274537479570376, 6.325968624485853, 6.377122503128954, 6.428004277666657, 6.4786189476651055, 6.5289713572515, 6.579066201872982, 6.628908034679974, 6.678501272559265, 6.727850201840157, 6.776958983695125, 6.825831659254846, 6.874472154455904, 6.922884284638109, 6.971071758907143, 7.01903818427703, 7.066787069605963, 7.1143218293379356, 7.161645787061858, 7.208762178898948, 7.255674156728435, 7.30238479126099, 7.348897074968567, 7.395213924878829, 7.441338185241745, 7.487272630075483, 7.533019965598203, 7.578582832551991, 7.623963808424736], [0.0, 0.48197894912282235, 0.7305434778947342, 0.9317530504793198, 1.1072968520011714, 1.2659311110084015, 1.4122735345081043, 1.5491265400261611, 1.6783481826229878, 1.8012482674970192, 1.918792757016348, 2.0317191849324168, 2.140606392698128, 2.2459189618657818, 2.348036760338586, 2.44727529392196, 2.5439001447742817, 2.638137475656112, 2.730181839443385, 2.8202020959016623, 2.9083459695098397, 2.99474361250584, 3.079510427099067, 3.1627493274113414, 3.2445525717906154, 3.3250032615233187, 3.4041765775398, 3.4821408091896826, 3.5589582164205997, 3.6346857572998763, 3.709375705809119, 3.7830761795520518, 3.855831592982579, 3.927683048654744, 3.9986686765838906, 4.068823929918517, 4.138181843630171, 4.206773261741929, 4.274627037665496, 4.341770211450713, 4.408228167129809, 4.4740247728317675, 4.539182505926298, 4.603722565114048, 4.667664971095568, 4.7310286572150355, 4.793831551276989, 4.856090649568214, 4.9178220839769535, 4.9790411829830505, 5.039762527192, 5.1000000000000005, 5.159766833903743, 5.219075652905607, 5.277938511410725, 5.3363669299655525, 5.3943719281470015, 5.451964054876019, 5.5091534163988145, 5.565949702152196, 5.622362208706082, 5.678399861955693, 5.73407123771791, 5.789384580870375, 5.844347823157873, 5.89896859977812, 5.953254264848061, 6.007211905842034, 6.060848357084412, 6.114170212371614, 6.167183836791439, 6.219895377801478, 6.272310775622792, 6.324435773000103, 6.376275924375224, 6.42783660451643, 6.47912301664286, 6.530140200079733, 6.5808930374772, 6.63138626162297, 6.681624461876419, 6.731612090249653, 6.781353467159031, 6.830852786868774, 6.880114122646673, 6.9291414316503435, 6.977938559561108, 7.026509244981328, 7.0748571236098305, 7.1229857322090195, 7.170898512376272, 7.2185988141313615, 7.266089899330773, 7.313374944919075, 7.360457046026782, 7.407339218923496, 7.454024403834558, 7.500515467628852, 7.546815206384941, 7.592926347842198, 7.638851553743224, 7.684593422073398], [0.0, 0.4857371691624451, 0.7362398742693816, 0.9390183739808212, 1.1159309743556345, 1.2758021804375381, 1.4232857057003874, 1.5612058194578322, 1.6914350649129253, 1.8152934604407425, 1.9337545004792647, 2.04756146968281, 2.15729772300752, 2.263431464569923, 2.366345524284678, 2.4663578681066416, 2.5637361490651114, 2.658708293419698, 2.7514703710680215, 2.842192558455874, 2.931023731940461, 3.01809505861886, 3.103522840546613, 3.1874107943160954, 3.2698518976576576, 3.3509298998381456, 3.430720568009525, 3.5092927240060905, 3.5867091132460196, 3.663027137925889, 3.738299479632504, 3.8125746311655244, 3.8858973532995607, 3.9583090690849, 4.029848205854825, 4.100550493202964, 4.170449223690313, 4.2395754818455265, 4.307958346064141, 4.375625067240178, 4.442601227337288, 4.508910880595657, 4.574576679651777, 4.639619988502691, 4.70406098395991, 4.767918746999941, 4.831211345218973, 4.893955907431958, 4.956168691315175, 5.017865144871945, 5.079059962399707, 5.139767135550129, 5.2, 5.259771278187072, 5.319093118510434, 5.377977131347741, 5.436434422200811, 5.494475622245565, 5.552110916531439, 5.609350070048409, 5.666202451856186, 5.722677057449463, 5.778782529514856, 5.8345271772192575, 5.889918994155053, 5.944965675055243, 5.999674631380334, 6.054053005869086, 6.108107686136363, 6.1618453173935634, 6.215272314360115, 6.2683948724282725, 6.321218978137836, 6.3737504190124525, 6.425994792804568, 6.4779575161920935, 6.529643832966153, 6.581058821745991, 6.632207403254113, 6.683094347182034, 6.733724278674556, 6.78410168445825, 6.834230918637824, 6.884116208182182, 6.933761658120329, 6.9831712564657265, 7.03234887888631, 7.081298293136113, 7.130023163263239, 7.17852705360792, 7.226813432603309, 7.274885676390883, 7.322747072261383, 7.370400821931529, 7.417850044666046, 7.465097780253832, 7.51214699184657, 7.559000568667487, 7.605661328597506, 7.652132020645489, 7.698415327308915, 7.744513866830893], [0.0, 0.48945227090716775, 0.7418709155301295, 0.9462003419688138, 1.1244660368812536, 1.2855599984662411, 1.434171533559935, 1.573146512556818, 1.7043718005792083, 1.8291775120024043, 1.9485445869183637, 2.06322199490381, 2.1737975526344164, 2.280743045229034, 2.3844442306304274, 2.485221506717442, 2.583344573631062, 2.6790431008972146, 2.772514658030317, 2.8639307230500393, 2.953441310976324, 3.0411785921218604, 3.127259758064336, 3.2117893186598883, 3.294860962767744, 3.3765590802008467, 3.4569600176070208, 3.5361331231960023, 3.614141622286679, 3.6910433561093567, 3.7668914091795593, 3.8417346451882346, 3.915618167257342, 3.988583715256338, 4.060670010425296, 4.131913055631303, 4.202346398069463, 4.272001360014674, 4.340907242265048, 4.409091504139759, 4.476579923263002, 4.5433967378508955, 4.6095647737958725, 4.67510555849491, 4.740039423079414, 4.804385594464422, 4.868162278433936, 4.931386734810572, 4.99407534561547, 5.056243677004129, 5.117906535661535, 5.179078020252808, 5.239771568451038, 5.300000000000001, 5.359775556214335, 5.419109936272264, 5.478014330614686, 5.536499451728777, 5.594575562563091, 5.652252502793941, 5.709539713139156, 5.7664462578943745, 5.822980845848753, 5.879151849720838, 5.934967324241036, 5.990435022994577, 6.045562414127623, 6.100356695009306, 6.154824805933572, 6.208973442936915, 6.262809069800965, 6.31633792930268, 6.3695660537691845, 6.422499274989296, 6.475143233529192, 6.527503387495584, 6.579585020786099, 6.63139325086318, 6.682933036084883, 6.73420918262313, 6.78522635099758, 6.835989062250988, 6.886501703789904, 6.936768534912686, 6.986793692045159, 7.036581193702621, 7.086134945195582, 7.135458743095284, 7.184556279473858, 7.233431145932958, 7.28208683743363, 7.330526755939356, 7.378754213883322, 7.4267724374701904, 7.474584569822003, 7.522193673977114, 7.56960273575051, 7.616814666463294, 7.663832305548609, 7.710658423040774, 7.757295721954028, 7.803746840556793], [0.0, 0.4931255488551678, 0.7474385637693105, 0.9533014569439312, 1.1329050135538827, 1.2952079651299664, 1.4449348111684155, 1.5849527799643384, 1.717162897326307, 1.8429052599712976, 1.9631681698237122, 2.0787062173830764, 2.190111630815541, 2.2978597359281423, 2.402339185728658, 2.5038727826418556, 2.602732250874477, 2.699148983593454, 2.7933220330476476, 2.8854241641777745, 2.975606517847699, 3.064002256291742, 3.1507294505956933, 3.2358933949490614, 3.3195884813342205, 3.4018997328990817, 3.482904069263494, 3.562671359086815, 3.6412653021860266, 3.7187441738826186, 3.79516145708475, 3.8705663821992458, 3.9450043908413424, 4.018517536132984, 4.0911448299123006, 4.162922545243381, 4.233884481088825, 4.304062194793279, 4.373485207053672, 4.442181183267927, 4.5101760945180756, 4.577494360925012, 4.644158979686631, 4.710191639760327, 4.775612824860097, 4.840441906196566, 4.904697226185866, 4.968396174183416, 5.0315552551553715, 5.094190152079278, 5.156315782762436, 5.217946351678682, 5.279095397349156, 5.339775835728205, 5.400000000000001, 5.459779677143631, 5.519126141582851, 5.578050186200713, 5.63656215096791, 5.694671949406294, 5.752389093085096, 5.809722714326361, 5.866681587277614, 5.923274147493605, 5.979508510154484, 6.035392487035164, 6.0909336023293115, 6.146139107421408, 6.2010159946914385, 6.2555710104288105, 6.309810666925024, 6.363741253808297, 6.417368848677613, 6.470699327088634, 6.523738371939277, 6.576491482298664, 6.628963981719409, 6.68116102606987, 6.733087610919959, 6.784748578511316, 6.836148624340215, 6.887292303379271, 6.938184035961969, 6.988828113352171, 7.039228703019055, 7.089389853636374, 7.139315499823504, 7.189009466644479, 7.238475473879969, 7.287717140086148, 7.336737986453305, 7.385541440476234, 7.434130839447516, 7.482509433784072, 7.530680390196684, 7.5786467947114255, 7.62641165555145, 7.673977905886959, 7.721348406460686, 7.768525948095712, 7.815513254092056, 7.8623129825180165], [0.0, 0.4967582355122337, 0.7529446871163665, 0.9603241015642342, 1.1412507359282653, 1.3047493176394367, 1.455579149960124, 1.5966285830721327, 1.729812646988655, 1.856481310459204, 1.9776301558892317, 2.0940193325874668, 2.206245431461683, 2.3147872798809845, 2.420036393926455, 2.5223179539975282, 2.6219056859999075, 2.7190326876945625, 2.813899477679949, 2.906680093596801, 2.9975267897118494, 3.0865737092198886, 3.17393979299587, 3.2597311108954554, 3.3440427502543533, 3.426960360556823, 3.508561428063149, 3.5889163361311227, 3.6680892538324117, 3.7461388857827975, 3.8231191088806655, 3.89907951619635, 3.9740658840978695, 4.048120575498084, 4.121282889621941, 4.193589366744747, 4.2650740548144555, 4.335768743647837, 4.405703171410666, 4.474905207302354, 4.5434010137249805, 4.611215190694087, 4.678370904820033, 4.744890004835316, 4.810793125350424, 4.876099780277042, 4.940828447153585, 5.004996643436884, 5.068620995679518, 5.1317173023901415, 5.194300591270423, 5.256385171433681, 5.317984681134695, 5.379112131475213, 5.4397799464937435, 5.500000000000001, 5.559783649472552, 5.619141767301912, 5.67808476962979, 5.736622643007552, 5.794764969072895, 5.852520947422542, 5.9098994168401555, 5.9669088750223205, 6.023557496930932, 6.079853151887571, 6.135803419514052, 6.1914156046133195, 6.246696751075821, 6.301653654888563, 6.356292876316862, 6.410620751322467, 6.464643402275947, 6.5183667480161676, 6.571796513305003, 6.62493823772133, 6.677797284034546, 6.730378846094525, 6.782687956271825, 6.834729492479219, 6.88650818480309, 6.938028621770973, 6.989295256279433, 7.0403124112045985, 7.091084284715965, 7.141614955312472, 7.191908386598491, 7.241968431815984, 7.2917988381479715, 7.341403250807288, 7.390785216923623, 7.439948189240949, 7.488895529636534, 7.537630512472008, 7.586156327786221, 7.634476084338942, 7.682592812513874, 7.730509467088875, 7.778228929880788, 7.825754012271729, 7.8730874576233365, 7.920231943584983], [0.0, 0.5003515054281688, 0.7583910658558928, 0.9672705464483133, 1.149505902411255, 1.3141871409823676, 1.466107991549274, 1.6081776969958492, 1.742325139586224, 1.8699100529852137, 1.9919352210819108, 2.109166291677967, 2.2222041710845213, 2.3315311502387828, 2.437541577229148, 2.54056298462732, 2.6408710783183813, 2.738700642161512, 2.834253645194025, 2.927705383947144, 3.0192092140094045, 3.1089002488920885, 3.1968982898215965, 3.283310173903319, 3.3682316762813156, 3.4517490659800822, 3.5339403897519666, 3.6148765400684164, 3.6946221501641046, 3.773236349291012, 3.850773404062731, 3.927283266277997, 4.00281204342535, 4.077402404847155, 4.1510939340368695, 4.223923435581614, 4.295925203713067, 4.367131258197669, 4.437571552310372, 4.507274156840714, 4.576265423434892, 4.644570130051133, 4.712211610874038, 4.779211872677557, 4.845591699331354, 4.911370745899786, 4.976567623577397, 5.041199976532456, 5.1052845515846785, 5.168837261520256, 5.231873242742803, 5.294406907869724, 5.356451993807268, 5.418021605772183, 5.479128257671488, 5.539783909203366, 5.600000000000001, 5.6597874810966715, 5.719156843979602, 5.778118147437258, 5.83668104241552, 5.894854795055825, 5.952648308076627, 6.010070140642074, 6.067128526847142, 6.12383139293566, 6.18018637335617, 6.236200825750453, 6.291881844960505, 6.34723627613168, 6.402270726982569, 6.456991579305708, 6.5114049997574535, 6.565516949990224, 6.619333196175607, 6.6728593179626765, 6.726100716912094, 6.779062624443121, 6.831750109327658, 6.884168084762556, 6.936321315048988, 6.988214421905315, 7.039851890437857, 7.091238074791997, 7.142377203504429, 7.193273384575663, 7.243930610280556, 7.294352761733258, 7.344543613221806, 7.394506836326453, 7.444246003834835, 7.493764593466132, 7.543065991415543, 7.59215349572959, 7.641030319522073, 7.68969959403978, 7.738164371586507, 7.786427628313315, 7.834492266882491, 7.88236111901211, 7.930036947907745, 7.977522450587379], [0.0, 0.5039064789033284, 0.7637793980456973, 0.9741429573407007, 1.1576730867772032, 1.3235243776587924, 1.4765246185907321, 1.6196037224882105, 1.7547042762314362, 1.8831956743277705, 2.0060878253977963, 2.124151817134116, 2.237992825258419, 2.34809656736192, 2.45486019335729, 2.558613562919463, 2.6596343408106256, 2.7581589790180296, 2.854390881559322, 2.9485065904391834, 3.0406605508302587, 3.1309888362188536, 3.2196120990133443, 3.306637935391635, 3.3921628009755964, 3.47627357772701, 3.559048866916661, 3.6405600647036094, 3.720872263538564, 3.800045012784008, 3.878132964615225, 3.9551864257360854, 4.031251831226627, 4.106372153592849, 4.180587257567033, 4.253934209231128, 4.326447546475684, 4.39815951656605, 4.46910028559376, 4.539298123789969, 4.608779570028055, 4.677569578312454, 4.745691648616028, 4.813167944069803, 4.880019396211842, 4.946265799754791, 5.011925898124841, 5.077017460851231, 5.141557353739026, 5.2055616026340035, 5.269045451483201, 5.3320234153049775, 5.394509328605644, 5.456516389713884, 5.518057201447427, 5.579143808477541, 5.639787731714445, 5.7, 5.7597911793619385, 5.819171400055936, 5.878150381597379, 5.936737455963197, 5.994941589125233, 6.052771401060085, 6.110235184365578, 6.167340921601126, 6.224096301457662, 6.280508733852659, 6.336585364036624, 6.392333085789343, 6.4477585537769295, 6.50286819513425, 6.55766822033146, 6.6121646333782325, 6.666363241414526, 6.720269663732557, 6.773889340270813, 6.8272275396175415, 6.880289366558024, 6.93307976919714, 6.985603545686193, 7.037865350580633, 7.089869700853243, 7.141620981585404, 7.193123451357357, 7.244381247356761, 7.295398390223394, 7.346178788646536, 7.39672624373036, 7.447044453141521, 7.4971370150521395, 7.547007431890423, 7.596659113910327, 7.646095382590834, 7.695319473874765, 7.744334541256267, 7.793143658725605, 7.841749823579255, 7.890155959102778, 7.9383649171334705, 7.986379480509348, 8.03420236541058], [0.0, 0.5074242253975382, 0.769111304683755, 0.9809434017019287, 1.1657547459995938, 1.3327638366346783, 1.4868321647686777, 1.6309100968956034, 1.7669537809997056, 1.896342171264454, 2.02009222643314, 2.13898041712385, 2.2536161437604023, 2.3644885147047683, 2.4719974523537447, 2.576475119116529, 2.678201118119439, 2.7774135520094902, 2.8743172447578313, 2.969089970800248, 3.061887253483584, 3.1528461162165016, 3.2420880536759404, 3.329721413163463, 3.4158433236529206, 3.5005412736248225, 3.583894413061582, 3.6659746365353563, 3.746847490904069, 3.8265729412413934, 3.9052060212467747, 3.982797388812725, 4.059393803180305, 4.135038536844479, 4.209771732831273, 4.283630715979145, 4.356650265285968, 4.428862853133675, 4.500298856201811, 4.570986742074631, 4.64095323489209, 4.710223462861312, 4.77882109000732, 4.846768434180872, 4.914086573042075, 4.9807954394894995, 5.046913907796275, 5.112459871539857, 5.1774503142646715, 5.241901373692141, 5.305828400186552, 5.369246010094897, 5.4321681345015, 5.49460806387193, 5.556578489003575, 5.618091538650959, 5.679158814151216, 5.739791421338011, 5.800000000000001, 5.859794751111678, 5.919185462039893, 5.97818152990765, 6.036791983277802, 6.095025502302583, 6.15289043747004, 6.21039482706544, 6.2675464134540935, 6.324352658281745, 6.3808207566795465, 6.436957650552422, 6.4927700410223865, 6.548264400091819, 6.603446981585862, 6.658323831427889, 6.71290079729722, 6.767183537714072, 6.8211775305928795, 6.874888081301646, 6.92832033026191, 6.981479260121028, 7.034369702525965, 7.086996344525395, 7.139363734624866, 7.191476288517797, 7.243338294513372, 7.294953918680754, 7.346327209727608, 7.397462103629588, 7.448362428026184, 7.499031906397285, 7.549474162033673, 7.5996927218138355, 7.649691019798546, 7.699472400653868, 7.749040122912581, 7.798397362083221, 7.84754721361543, 7.896492695729661, 7.945236752118792, 7.993782254528654, 8.042132005224119, 8.090288739346878], [0.0, 0.5109057666699868, 0.7743883344673949, 0.9876738547785151, 1.1737532274646256, 1.3419082015889436, 1.4970336239969806, 1.6421001042499952, 1.7790772118631806, 1.9093533623063665, 2.033952491884537, 2.153656398739315, 2.2690786645153214, 2.3807117534469193, 2.48895833188017, 2.5941528412584183, 2.6965768031221518, 2.7964699537892894, 2.89403852257009, 2.98946150364706, 3.0828954874444983, 3.1744784375166666, 3.264332682140303, 3.3525673120099406, 3.439280122521162, 3.524559202430816, 3.6084842447855134, 3.6911276374407587, 3.7725553769848585, 3.8528278399241067, 3.9320004375554034, 4.01012417534541, 4.087246133359894, 4.1634098809952444, 4.238655836706993, 4.313021581426938, 4.386542132778763, 4.459250185944045, 4.531176326022934, 4.602349215921598, 4.672795763139775, 4.742541268294349, 4.811609557774055, 4.880023102556985, 4.9478031249213785, 5.0149696945294915, 5.081541815154701, 5.147537503145951, 5.212973858575237, 5.277867129888184, 5.342232772771063, 5.406085503856611, 5.4694393498131655, 5.532307692294897, 5.594703309173345, 5.656638412420897, 5.718124682973831, 5.779173302865206, 5.839794984885441, 5.9, 5.959798202728859, 6.019199054670598, 6.0782116463348865, 6.136844717430257, 6.195106675739159, 6.2530056146991795, 6.310549329797577, 6.367745333875972, 6.424600871432783, 6.4811229320027595, 6.537318262685684, 6.593193379889668, 6.6487545803486245, 6.704007951468242, 6.758959381049962, 6.813614566438267, 6.867979023132681, 6.922058092902421, 6.975856951438507, 7.029380615575258, 7.082633950110556, 7.135621674251871, 7.18834836771298, 7.240818476484275, 7.293036318297905, 7.345006087807286, 7.396731861499093, 7.448217602354512, 7.49946716427525, 7.5504842962887535, 7.60127264654594, 7.651835766123935, 7.7021771126453, 7.752300053724539, 7.8022078702518884, 7.851903759523697, 7.901390838228121, 7.95067214529424, 7.999750644612208, 8.048629227631494, 8.09731071584388, 8.145797863157423], [0.0, 0.5143520796755041, 0.7796119681832379, 0.9943362052019962, 1.181670775625111, 1.3509600385206133, 1.5071318589057483, 1.6531768845778512, 1.7910779707761724, 1.9222328985220836, 2.0476725110792193, 2.168183880205746, 2.2843847264590544, 2.396770835989223, 2.5057475913266973, 2.6116516898883724, 2.7147665522172706, 2.8153335317717785, 2.913560248981223, 3.009626905432723, 3.103691147830719, 3.195891870362131, 3.286352226468645, 3.3751820427156822, 3.4624797741773126, 3.5483341038127754, 3.632825262237841, 3.716026125600031, 3.7980031356674018, 3.878817076215751, 3.9585237323186826, 4.03717445350005, 4.114816637404033, 4.191494147324228, 4.267247674358712, 4.342115052941324, 4.416131536907001, 4.489330041982549, 4.561741359579802, 4.633394345950456, 4.704316090098694, 4.774532063306618, 4.844066252683783, 4.912941280786183, 4.981178513046857, 5.048798154507898, 5.1158193371325655, 5.182260198799022, 5.248137954927735, 5.313468963568162, 5.3782687846628505, 5.442552234115529, 5.506333433211377, 5.569625853870464, 5.632442360157417, 5.694795246420439, 5.75669627238952, 5.818156695526084, 5.87918730088364, 5.93979842871041, 5.999999999999999, 6.05980154017417, 6.119212201062589, 6.178240781327461, 6.236895745465903, 6.295185241509755, 6.353117117530708, 6.4106989370482275, 6.467937993428469, 6.5248413233540665, 6.581415719437337, 6.6376677420428, 6.693603730378966, 6.749229812914094, 6.804551917165771, 6.859575778909894, 6.914306950850771, 6.968750810790504, 7.022912569332717, 7.076797277152768, 7.1304098318640134, 7.183754984507323, 7.236837345688914, 7.2896613913895925, 7.342231468466754, 7.394551799868832, 7.44662648958043, 7.498459527315007, 7.550054792970752, 7.601416060864162, 7.652547003754744, 7.7034511966734005, 7.754132120566073, 7.804593165763498, 7.8548376352871445, 7.904868748000714, 7.954689641615969, 8.004303375561076, 8.053712933719098, 8.102921227043767, 8.151931096059227, 8.200745313250012], [0.0, 0.5177640992398568, 0.7847836227621847, 1.0009322601607584, 1.1895095381466902, 1.359921802775555, 1.5171296086803574, 1.6641434424987869, 1.8029593129910706, 1.934984273535746, 2.0612560056255953, 2.182566802158824, 2.299538481420255, 2.4126701184200905, 2.5223697848450555, 2.6289764116369367, 2.7327752994447714, 2.8340094027756315, 2.932887719335218, 3.029591646100666, 3.124279875545765, 3.2170922232295878, 3.3081526595477513, 3.3975717396140848, 3.485448571616844, 3.571872426804892, 3.656924068013935, 3.740676854824635, 3.8231976697549186, 3.9045476997974475, 3.9847831000831655, 4.063955560769485, 4.142112793918854, 4.219298953797573, 4.2955550014332635, 4.370919022239265, 4.445426503911289, 4.519110580526777, 4.5920022477562865, 4.664130553273108, 4.73552276577976, 4.806204525525316, 4.876199978740854, 4.9455318980519545, 5.014221790621959, 5.082289995525662, 5.149755771640621, 5.216637377164906, 5.282952141719654, 5.348716531867511, 5.413946210769874, 5.4786560926136385, 5.5428603923593185, 5.606572671294668, 5.669805878819711, 5.732572390838766, 5.7948840450914805, 5.85675217371707, 5.918187633313059, 5.979200832721019, 6.039801758746715, 6.1000000000000005, 6.159804769020363, 6.219224922837046, 6.278268982097478, 6.336945148884498, 6.395261323330971, 6.453225119129931, 6.510843878028995, 6.568124683389523, 6.625074372883485, 6.681699550394407, 6.738006597182742, 6.794001682370718, 6.849690772796859, 6.905079642286059, 6.960173880377188, 7.014978900546681, 7.06949994796336, 7.123742106806875, 7.177710307179523, 7.231409331638802, 7.284843821375969, 7.338018282063815, 7.390937089395163, 7.44360449433191, 7.49602462808296, 7.548201506828041, 7.600139036203137, 7.65184101556215, 7.703311142028302, 7.754553014347915, 7.805570136558227, 7.856365921480162, 7.906943694046198, 7.957306694472776, 8.007458081286067, 8.057400934209342, 8.10713825691963, 8.156672979680838, 8.206007961860093, 8.255145994333551], [0.0, 0.5211427205342488, 0.7899046550300596, 1.0074637501837014, 1.1972715715927424, 1.3687958455458267, 1.5270294963121294, 1.6750026551788546, 1.8147243556750599, 1.9476108327747501, 2.0747065392644175, 2.1968089380756113, 2.314543905110323, 2.4284137720461434, 2.538829273403494, 2.646131551786382, 2.750607769546596, 2.8525024665681626, 2.9520260043518016, 3.049360963563687, 3.144667072210533, 3.23808505820479, 3.3297397008993186, 3.4197422768250227, 3.5081925408913874, 3.595180346878478, 3.680786984632345, 3.765086292434745, 3.8481455892392322, 3.9300264613084765, 4.010785430208487, 4.090474523395973, 4.1691417642739905, 4.246831595233384, 4.323585244589137, 4.399441046277397, 4.474434719565522, 4.548599614744283, 4.621966929743591, 4.694565901784619, 4.766423977509255, 4.837566964479626, 4.908019166490787, 4.977803504768961, 5.046941626820475, 5.115454004440857, 5.183360022179674, 5.250678057377162, 5.317425552737284, 5.383619082273701, 5.449274411356308, 5.5144065514931375, 5.579029810403099, 5.643157837866863, 5.706803667784556, 5.769979756818306, 5.832698019953822, 5.894969863277139, 5.956806214229495, 6.0182175495743815, 6.079213921285537, 6.139804980542393, 6.200000000000001, 6.259807894483323, 6.319237240240477, 6.378296292876227, 6.436993004075021, 6.495335037212331, 6.553329781943666, 6.610984367852199, 6.668305677228489, 6.725300357049089, 6.781974830214769, 6.838335306103791, 6.8943877904907245, 6.95013809487702, 7.0055918452755614, 7.060754490487919, 7.115631309909773, 7.170227420897116, 7.224547785723163, 7.278597218153548, 7.332380389665188, 7.385901835332219, 7.439165959400642, 7.4921770405716055, 7.544939237011834, 7.59745659110826, 7.649733033982733, 7.701772389781482, 7.7535783797529625, 7.805154626126779, 7.856504655805437, 7.907631903879904, 7.958539716979198, 8.009231356463488, 8.059710001469611, 8.109978751817286, 8.160040630783755, 8.209898587754093, 8.259555500753955, 8.3090141788711], [0.0, 0.5244888013670841, 0.7949763651812709, 1.0139323335706287, 1.2049588466894725, 1.377584419889051, 1.5368340353135492, 1.6857572796964848, 1.826376085890496, 1.960115782034502, 2.088027526992451, 2.2109139039351753, 2.3294048073017724, 2.444005794071332, 2.555130235951465, 2.6631214659072513, 2.7682684900626424, 2.8708174184094055, 2.9709799631081797, 3.0689398771137344, 3.164857913992195, 3.258875705222256, 3.3511188313227236, 3.4416992832934046, 3.530717456536258, 3.618263781752026, 3.7044200707213184, 3.7892606358164804, 3.8728532282232573, 3.9552598296288455, 4.036537324505078, 4.1167380743593345, 4.195910410936673, 4.274099061977469, 4.351345520509748, 4.4276883665988755, 4.50316354885352, 4.577804631695369, 4.651643013365673, 4.724708118807895, 4.797027570889511, 4.868627342874259, 4.93953189460363, 5.009764294473271, 5.079346328980816, 5.148298601364255, 5.216640620634776, 5.284390882127294, 5.351566940539463, 5.418185476301071, 5.484262356006109, 5.549812687546418, 5.614850870505922, 5.67939064230591, 5.743445120532764, 5.807026841828617, 5.870147797681267, 5.9328194674113615, 5.995052848621536, 6.056858485343032, 6.118246494089904, 6.179226588008536, 6.239808099290559, 6.300000000000002, 6.359810921450167, 6.419249172252261, 6.478322755145802, 6.5370393827102, 6.595406492047437, 6.653431258517325, 6.71112060859928, 6.768481231947836, 6.825519592703036, 6.882241940111453, 6.938654318508703, 6.994762576709915, 7.050572376850699, 7.106089202717531, 7.161318367603304, 7.216265021720818, 7.270934159204365, 7.325330624727134, 7.379459119760015, 7.433324208495319, 7.486930323457215, 7.540281770818946, 7.593382735445413, 7.646237285678348, 7.6988493778799985, 7.7512228607501426, 7.803361479430112, 7.855268879406618, 7.906948610227216, 7.958404129038425, 8.009638803956836, 8.060655917282704, 8.11145866856503, 8.162050177526423, 8.212433486855565, 8.262611564874533, 8.312587308087807, 8.36236354361935], [0.0, 0.5278031643091577, 0.8000000000000002, 1.0203396005006329, 1.2125732532083189, 1.386289686310293, 1.5465456359454106, 1.6964099598730564, 1.8379173679952563, 1.9725021954206712, 2.101222243523014, 2.2248851671770566, 2.344124841266818, 2.459450017499878, 2.5712766797728315, 2.679950330649144, 2.7857618025475976, 2.8889587606844644, 2.989754255077242, 3.0883331998570336, 3.1848573644279785, 3.2794692752700048, 3.3722953064735206, 3.4634481567346995, 3.553028855876673, 3.641128406052161, 3.7278291360288534, 3.813205827775725, 3.8973266606135324, 3.9802540079057227, 4.062045113589927, 4.142752670057692, 4.222425314473262, 4.301108057221689, 4.378842653534791, 4.455667927274062, 4.531620054215531, 4.606732810882031, 4.681037793927374, 4.754564614237873, 4.82734106923613, 4.899393296316791, 4.9707459098885955, 5.041422124121583, 5.1114438631871755, 5.180831860519866, 5.2496057484126855, 5.317784139076735, 5.385384698141759, 5.452424211444942, 5.51891864584486, 5.584883204703524, 5.650332378599077, 5.715279991762667, 5.779739244673662, 5.8437227531960625, 5.907242584594579, 5.970310290730274, 6.032936938702114, 6.095133139171447, 6.156909072580863, 6.218274513456306, 6.279238852961628, 6.339811119857354, 6.400000000000001, 6.459813854504761, 6.519260736682266, 6.578348407849455, 6.637084352105035, 6.69547579015153, 6.7535296922383425, 6.811252790293442, 6.868651589305228, 6.925732378010672, 6.982501238940907, 7.038964057871046, 7.095126532717007, 7.15099418191855, 7.206572352344465, 7.261866226752905, 7.316880830837222, 7.37162103988519, 7.426091585077349, 7.480297059448171, 7.534241923531946, 7.587930510713595, 7.641367032303123, 7.69455558235103, 7.74750014222071, 7.800204584932742, 7.852672679294849, 7.904908093830395, 7.9569144005173245, 8.008695078348648, 8.06025351672484, 8.111593018687755, 8.162716804005063, 8.213628012113602, 8.264329704929493, 8.314824869532305, 8.365116420730187, 8.415207203512333], [0.0, 0.5310865986667878, 0.8049767558509093, 1.0266870768465153, 1.2201166044990195, 1.3949137179445428, 1.5561666109983974, 1.7069632326147302, 1.849350950513579, 1.9847730227231601, 2.1142938311411563, 2.2387260550187436, 2.358707512540613, 2.474750120330642, 2.587272450098289, 2.696622153759399, 2.8030918729851826, 2.9069308137035543, 3.0083533513044123, 3.1075455502594655, 3.2046701863313887, 3.299870672649476, 3.3932741694703776, 3.484994076582637, 3.5751320523103396, 3.663779664925576, 3.751019755358755, 3.8369275707933546, 3.9215717146899234, 4.00501494843316, 4.087314872072072, 4.168524505794665, 4.248692789334302, 4.327865013083152, 4.406083192030029, 4.4833863915575245, 4.559811012489174, 4.635391041469696, 4.710158271713944, 4.784142498315917, 4.85737169162445, 4.929872151633479, 5.001668645876622, 5.072784532937989, 5.143241873378064, 5.21306152961289, 5.282263256066909, 5.350865780736762, 5.418886879149101, 5.486343441564877, 5.55325153417161, 5.61962645491059, 5.685482784505045, 5.750834433185903, 5.815694683551986, 5.880076229949887, 5.943991214714106, 6.0074512615691935, 6.070467506461928, 6.133050626062, 6.1952108641439665, 6.25695805604056, 6.318301651337545, 6.379250734962866, 6.439814046807275, 6.5, 6.5598166979508745, 6.61927195025956, 6.6783732875829305, 6.737127975543102, 6.7955430277510125, 6.853625218013585, 6.911381091786392, 6.9688169769282915, 7.025938993809508, 7.082753064820233, 7.139264923322808, 7.195480122086902, 7.2514040412438785, 7.307041895793546, 7.362398742693816, 7.417479487561358, 7.472288891009126, 7.526831574644605, 7.581112026750825, 7.6351346076704525, 7.688903554911822, 7.742422987994295, 7.795696913049107, 7.848729227190684, 7.901523722672294, 7.9540840908389825, 8.006413925889772, 8.058516728460297, 8.110395909036304, 8.16205479120769, 8.213496614772122, 8.2647245386967, 8.315741643945557, 8.366550936180717, 8.417155348343194, 8.4675577431207], [0.0, 0.5343398623159287, 0.8099077814591382, 1.0329762277204637, 1.2275906417032991, 1.4034585053740674, 1.5656991811673242, 1.7174195338074658, 1.8606794725228206, 1.9969310962705438, 2.1272453070053965, 2.2524397621871417, 2.373156187067078, 2.4899096341037055, 2.603121239040541, 2.7131407833959145, 2.820262701468668, 2.9247377257411196, 3.026781544797034, 3.1265813628785137, 3.224300952859577, 3.320084606371671, 3.4140602626137917, 3.506342016024677, 3.5970321476542195, 3.6862227866919417, 3.77399728152483, 3.860431340276117, 3.9455939866488214, 4.029548366483458, 4.112352432668188, 4.194059530175432, 4.274718898527429, 4.354376105550552, 4.43307342360376, 4.510850157371465, 4.587742930656799, 4.663785938295606, 4.739011168257623, 4.813448598151899, 4.887126369664522, 4.960070943894633, 5.032307240093696, 5.103858759932908, 5.174747699108564, 5.24499504783308, 5.31462068154007, 5.383643442947789, 5.452081216469978, 5.51995099583183, 5.587268945637101, 5.654050457537291, 5.720310201572391, 5.786062173182878, 5.85131973633245, 5.916095663129137, 5.980402170287426, 6.044250952735023, 6.107653214633891, 6.170619698055524, 6.233160709524508, 6.295286144621623, 6.357005510817719, 6.418327948692055, 6.479262251673106, 6.539816884426194, 6.600000000000001, 6.659819455833257, 6.719282828713188, 6.778397428768744, 6.8371703125739645, 6.895608295429907, 6.953717962887475, 7.01150568156793, 7.068977609332892, 7.126139704851189, 7.182997736605873, 7.239557291381072, 7.295823782265085, 7.351802456203109, 7.407498401130337, 7.462916552713648, 7.518061700727962, 7.572938495091228, 7.627551451580234, 7.68190495724769, 7.736003275559526, 7.789850551269937, 7.843450815050415, 7.8968079878878426, 7.949925885265596, 8.002808221140699, 8.055458611729067, 8.10788057911009, 8.160077554661038, 8.21205288233104, 8.26380982176371, 8.31535155127695, 8.366681170707874, 8.417801704130222, 8.46871610245124, 8.519427245894539], [0.0, 0.5375636834090112, 0.814794180497389, 1.039208460773683, 1.234997037676156, 1.4119259611114718, 1.5751454800524425, 1.7277812038029692, 1.871905469597016, 2.0089791373088577, 2.140079569942774, 2.2660293581135322, 2.3874740987794607, 2.504931951853877, 2.6188265939094393, 2.7295099167937193, 2.837278131209623, 2.9423834823783133, 3.0450429601928035, 3.1454448983504877, 3.2437540578127106, 3.340115600762487, 3.434658238291604, 3.527496753202302, 3.618734043634511, 3.708462794618793, 3.796766857406148, 3.883722396887986, 3.969398853206535, 4.053859753178739, 4.137163399338659, 4.219363458503783, 4.300509467272089, 4.380647268393328, 4.459819389267365, 4.538065371714711, 4.615422060500095, 4.691923856766321, 4.76760294147545, 4.84248947309979, 4.916611763112052, 4.989996432258551, 5.062668550135532, 5.134651760206313, 5.205968392080003, 5.276639562608809, 5.346685267140369, 5.416124462076301, 5.48497513973199, 5.553254396360504, 5.620978494091152, 5.688162917437548, 5.754822424948121, 5.820971096501732, 5.8866223766905925, 5.951789114680413, 6.0164836008925215, 6.080717600813377, 6.144502386202768, 6.207848763942096, 6.270767102738079, 6.333267357874288, 6.395359094182792, 6.457051507390508, 6.518353443979112, 6.579273419683607, 6.639819636742288, 6.699999999999999, 6.759822131956831, 6.819293386845779, 6.878420863815154, 6.937211419284623, 6.99567167853755, 7.053808046606797, 7.1116267185060735, 7.169133688854517, 7.226334760938043, 7.283235555247401, 7.33984151752956, 7.396157926385999, 7.452189900448835, 7.507942405163203, 7.563420259202068, 7.618628140537625, 7.673570592191603, 7.728252027685021, 7.782676736206485, 7.836848887516646, 7.8907725366051595, 7.944451628115311, 7.997890000550352, 8.05109139027464, 8.104059435321732, 8.156797679020697, 8.209309573451266, 8.261598482737538, 8.313667686189463, 8.365520381300625, 8.417159686610317, 8.468588644437354, 8.519810223492629, 8.570827321376944], [0.0, 0.5407587619651025, 0.8196370139961588, 1.0453851292704652, 1.2423374006390933, 1.4203179237763002, 1.5845075588188584, 1.7380504925296194, 1.883031379344139, 2.020919761944333, 2.152799406779391, 2.2794977936366836, 2.4016643566626925, 2.5198203355205004, 2.634391924958701, 2.745733108339103, 2.854141856930837, 2.9598719152068225, 3.063141562767276, 3.1641402526950264, 3.2630337252292803, 3.3599680053430667, 3.4550725691390216, 3.548462881645661, 3.6402424525911803, 3.730504517891483, 3.819333427178212, 3.9068057980385573, 3.9929914833411204, 4.077954387482612, 4.161753159525668, 4.2444417852633745, 4.32607009572082, 4.406684206120005, 4.4863268966278405, 4.565037944086708, 4.642854412252911, 4.719810906736848, 4.795939799772249, 4.871271429082161, 4.9458342744121575, 5.019655114732365, 5.092759168643384, 5.165170220136482, 5.236910731539658, 5.308001945215834, 5.378463975357555, 5.448315891036235, 5.517575791506895, 5.586260874636366, 5.654387499210006, 5.721971241775618, 5.7890269486009505, 5.855568783250429, 5.9216102702259175, 5.98716433506379, 6.052243341235065, 6.116859124155876, 6.181023022581159, 6.244745907624398, 6.308038209620047, 6.370909943022179, 6.433370729512667, 6.495429819474406, 6.557096111969271, 6.618378173346624, 6.679284254595814, 6.739822307545141, 6.800000000000001, 6.859824729904214, 6.91930363860079, 6.978443623261401, 7.037251348547634, 7.095733257561478, 7.153895582137505, 7.211744352524636, 7.269285406501359, 7.326524397964531, 7.383466805028614, 7.440117937669129, 7.496482944941443, 7.5525668218034445, 7.608374415568499, 7.663910432012932, 7.7191794411605, 7.774185882764548, 7.8289340715070255, 7.883428201932091, 7.937672353130748, 7.991670493191775, 8.045426483433056, 8.098944082426515, 8.152226949828819, 8.205278650029273, 8.258102655625482, 8.31070235073665, 8.363081034163722, 8.415241922404999, 8.467188152535206, 8.518922784955572, 8.570448806021906, 8.621769130557267], [0.0, 0.5439257713529524, 0.8244373025916167, 1.051507534955187, 1.2496132775872597, 1.4286361619902954, 1.5937873905420885, 1.7482295642591192, 1.894059546570366, 2.032755486685825, 2.1654074982445235, 2.2928479072544383, 2.4157299513400208, 2.5345779228581296, 2.649820512610802, 2.761813777099864, 2.8708574326938763, 2.9772067099463997, 3.081081166834612, 3.182671365992836, 3.28214401833506, 3.3796460040446084, 3.475307557514248, 3.569244820005328, 3.6615619074614276, 3.752352601844195, 3.8417017467875807, 3.929686408597564, 4.016376849243267, 4.101837347384081, 4.18612689556692, 4.269299795758226, 4.351406170823619, 4.4324924060636475, 4.512601532191676, 4.591773559007259, 4.670045767334409, 4.747452965454847, 4.82402771519362, 4.899800531949778, 4.974800062263458, 5.049053241938581, 5.122585437271081, 5.19542057154562, 5.267581238643134, 5.339088805334632, 5.409963503613499, 5.480224514231132, 5.549890042442699, 5.6189773868361135, 5.687503002003642, 5.755482555718746, 5.82293098119787, 5.889862524955813, 5.956290790702077, 6.022228779672772, 6.087688927746856, 6.152683139655798, 6.217222820561119, 6.281318905244101, 6.344981885125524, 6.408221833310143, 6.471048427830202, 6.533470973244417, 6.595498420732934, 6.657139386814824, 6.718402170802205, 6.779294771094076, 6.839824900403128, 6.9, 6.959827253051713, 7.019313597123935, 7.0784657359105285, 7.137290150248176, 7.195793108468829, 7.253980676138181, 7.311858725224274, 7.3694329427365926, 7.426708838872741, 7.4836917547066575, 7.540386869449684, 7.596799207313192, 7.652933643999341, 7.708794912844315, 7.764387610636688, 7.81971620313168, 7.874785030280617, 7.929598311193437, 7.984160148850761, 8.038474534580889, 8.092545352315911, 8.146376382640211, 8.199971306643617, 8.253333709590644, 8.306467084416523, 8.359374835059903, 8.412060279641496, 8.464526653497352, 8.516777112074804, 8.56881473369863, 8.620642522214542, 8.672263409516562], [0.0, 0.547065359675584, 0.8291960286242521, 1.0575769307289757, 1.2568261574704094, 1.4368823780140687, 1.6029868742651283, 1.7583205020567063, 1.9049922281015055, 2.0444887336192985, 2.17790642448278, 2.306082430960275, 2.429673761222375, 2.5492077338884322, 2.6651155142022307, 2.7777552138556514, 2.8874282792070067, 2.9943914140234984, 3.098865443590635, 3.2010420304873506, 3.3010888478979767, 3.399153623811427, 3.49536734434506, 3.589846821137998, 3.6826967711003835, 3.7740115175117555, 3.8638763937311267, 3.9523689108981053, 4.039559736540198, 4.125513520338984, 4.210289595351645, 4.2939425769804425, 4.376522877404672, 4.458077149664995, 4.538648672851913, 4.618277687705131, 4.697001690236919, 4.774855689645522, 4.8518724357057605, 4.928082619954304, 5.003515054281687, 5.078196829967708, 5.1521534597248335, 5.225409004925071, 5.297986189863263, 5.369906504641334, 5.441190298033553, 5.511856861504331, 5.5819245053912026, 5.651410628131081, 5.720331779293615, 5.788703717088059, 5.856541460926722, 5.9238593395565635, 5.990671035208918, 6.056989624164193, 6.122827614082358, 6.188196978410058, 6.253109188140431, 6.317575241171292, 6.381605689480847, 6.445210664316714, 6.5083998995736065, 6.571182753516987, 6.633568228994017, 6.6955649922590865, 6.757181390528689, 6.818425468369298, 6.8793049830120765, 6.939827418679343, 7.0, 7.059829704583971, 7.119323274819439, 7.178487228951057, 7.237327871492149, 7.2958513030194005, 7.354063429394376, 7.411969970452493, 7.4695764681967045, 7.526888294530113, 7.583910658558928, 7.640648613494722, 7.697107063182642, 7.753290768280117, 7.809204352108793, 7.864852306200631, 7.920238995557544, 7.975368663642553, 8.030245437119051, 8.08487333035364, 8.139256249696816, 8.193397997554836, 8.247302276265108, 8.300972691786614, 8.354412757216123, 8.407625896140118, 8.460615445831806, 8.513384660301886, 8.565936713211215, 8.61827470065294, 8.670401643811235, 8.722320491503279], [0.0, 0.5501781510642736, 0.83391413810018, 1.063594523151209, 1.2639774741656828, 1.4450582111457708, 1.6121078387900145, 1.7683253119401257, 1.9158315972888942, 2.056121835243677, 2.1902986702055256, 2.319203995697912, 2.443498558255299, 2.5637126769298537, 2.6802799702873163, 2.793560587668216, 2.903857690654854, 3.0114294436539364, 3.1164979284426044, 3.219255898156186, 3.31987198003621, 3.418494742641009, 3.5152559173964346, 3.6102729805975917, 3.7036512449918293, 3.7954855705563366, 3.885861776195299, 3.97485781408522, 4.062544753850482, 4.148987613028109, 4.234246062279238, 4.318375027766723, 4.401425208514189, 4.483443523017204, 4.564473496623462, 4.644555599041706, 4.723727539635793, 4.802024526805634, 4.8794794966716415, 4.956123315404738, 5.031984958834561, 5.10709167238977, 5.181469113949677, 5.255141481795034, 5.328131629521484, 5.400461169509219, 5.4721505663166425, 5.543219221176227, 5.613685548610977, 5.683567046054577, 5.752880357243409, 5.821641330050637, 5.889865069348735, 5.957565985414959, 6.024757838332277, 6.091453778784881, 6.157666385601084, 6.223407700356214, 6.288689259313138, 6.353522122947501, 6.41791690327806, 6.481883789199038, 6.5454325699908225, 6.608572657167227, 6.67131310480144, 6.7336626284586725, 6.795629622850919, 6.857222178318086, 6.918448096229826, 6.979314903393542, 7.039829865546138, 7.1000000000000005, 7.159832087507374, 7.219332683401598, 7.278508128068555, 7.337364556797097, 7.395907909053026, 7.454143937217511, 7.5120782148274, 7.569716144351817, 7.627062964536687, 7.684123757346262, 7.740903454528469, 7.797406843828789, 7.85363857487548, 7.909603164757231, 7.965305003312735, 8.020748358150232, 8.075937379413755, 8.130876104311573, 8.185568461421243, 8.240018274784637, 8.294229267805392, 8.34820506696033, 8.401949205335672, 8.455465125998044, 8.508756185209672, 8.561825655496511, 8.61467672857749, 8.667312518162465, 8.719736062626094, 8.771950327564264], [0.0, 0.5532647468890367, 0.8385925425258952, 1.0695614747796023, 1.271068609258575, 1.4531652409004676, 1.6211520462247366, 1.7782459267702475, 1.926579748224554, 2.067657038994663, 2.2025866295099124, 2.3322151364639487, 2.4572070132950636, 2.578095554238225, 2.6953168105353007, 2.8092329520277235, 2.920148841087388, 3.028324090468555, 3.1339820278660473, 3.237316487794054, 3.3384970435224743, 3.437673097105285, 3.5349771190047155, 3.6305272445784706, 3.7244293773968637, 3.8167789096181766, 3.9076621416056834, 3.9971574628612565, 4.085336341722323, 4.17226416048568, 4.258000924575331, 4.342601868299525, 4.426117975112294, 4.508596426730186, 4.5900809926857224, 4.670612369729801, 4.750228478782421, 4.828964725768782, 4.9068542315867045, 4.983928035571737, 5.0602152761129995, 5.13574335149078, 5.210538063529588, 5.284623746266771, 5.3580233815106455, 5.430758702890648, 5.502850289774935, 5.574317652240296, 5.6451793081184345, 5.7154528530067035, 5.785155024015763, 5.854301757928122, 5.922908244357235, 5.99098897442454, 6.058557785409478, 6.125627901773887, 6.19221197291551, 6.258322107965021, 6.323969907905744, 6.38916649526453, 6.4539225415954204, 6.518248292954121, 6.582153593540596, 6.645647907668901, 6.708740340207162, 6.771439655616438, 6.833754295704527, 6.895692396199561, 6.957261802238243, 7.018470082854685, 7.0793245445478465, 7.139832243998469, 7.200000000000001, 7.259834404662353, 7.319341833942085, 7.37852845754809, 7.4374002482676165, 7.495962990753701, 7.554222289811707, 7.612183578219558, 7.669852124113462, 7.72723303796838, 7.78433127920021, 7.841151662414522, 7.897698863324806, 7.953977424361408, 8.009991759990786, 8.065746161763212, 8.12124480310575, 8.176491743876115, 8.231490934691875, 8.286246221048447, 8.340761347238415, 8.395039960083768, 8.449085612491963, 8.50290176684583, 8.556491798236818, 8.609858997550324, 8.66300657441138, 8.7159376599983, 8.768655309731553, 8.821162505844544], [0.0, 0.5563257268920875, 0.8432321206262763, 1.075478906361395, 1.2781008946469414, 1.4612049899872042, 1.6301211953044517, 1.7880842098941168, 1.93723869968813, 2.079096511480697, 2.214772610391266, 2.34511829708582, 2.4708017011426895, 2.5923590672884425, 2.710228859252169, 2.824775250607959, 2.9363047904023603, 3.0450785277172745, 3.151321025825269, 3.255227191644974, 3.356967536623521, 3.456692289393304, 3.5545346533196307, 3.6506134173532097, 3.745035070984048, 3.8378955341349204, 3.9292815846325357, 4.019272045674748, 4.10793878100309, 4.195347534646972, 4.281558644015045, 4.366627649003643, 4.4506058151367, 4.533540585167259, 4.615475970786165, 4.696452893902239, 4.776509485235903, 4.8556813465983755, 4.934001782131406, 5.011502002898069, 5.088211308497872, 5.164157248794211, 5.239365768362186, 5.313861335869085, 5.387667060271859, 5.460804795442928, 5.533295234607397, 5.605157995783063, 5.6764116992529665, 5.747074037963462, 5.817161841624571, 5.886691135190282, 5.955677192311763, 6.0241345842837, 6.092077224941354, 6.15951841191192, 6.226470864576914, 6.29294675906171, 6.358957760532972, 6.4245150530537884, 6.4896293672194005, 6.5543110057726075, 6.618569867377174, 6.6824154687092046, 6.74585696501021, 6.808903169231311, 6.871562569885258, 6.933843347711729, 6.995753391251253, 7.057300311414208, 7.1184914551233245, 7.1793339181009745, 7.239834556866111, 7.300000000000001, 7.359836658734677, 7.419350736913425, 7.4785482403684, 7.537434985756677, 7.596016608892643, 7.6542985726114825, 7.712286174195775, 7.769984552394579, 7.827398694062146, 7.884533440441223, 7.941393493114045, 7.997983419642308, 8.054307658915846, 8.110370526228262, 8.166176218096432, 8.221728816839548, 8.27703229493227, 8.332090519145522, 8.386907254487472, 8.441486167956437, 8.495830832116608, 8.549944728506714, 8.60383125089116, 8.657493708362422, 8.710935328303028, 8.76415925921478, 8.8171685734225, 8.869966269659024], [0.0, 0.5593616502501593, 0.8478337199547615, 1.0813478988870084, 1.2850756149815696, 1.4691789270992188, 1.6390169245042496, 1.7978419585593512, 1.947810398846103, 2.0904423424530516, 2.2268588389722583, 2.357915834699869, 2.484285105262013, 2.6065058217246557, 2.7250188405559097, 2.840190322660321, 2.952328489952264, 3.0616958160837586, 3.1685180897908936, 3.2729912816182254, 3.3752868335103625, 3.475555793911892, 3.573932093091784, 3.6705351682435525, 3.7654720899806615, 3.8588393016701934, 3.950724054693859, 4.041205602395335, 4.130356200683549, 4.218241952359446, 4.304923524098761, 4.390456758884416, 4.474893202001274, 4.558280555102076, 4.6406630700537255, 4.722081892079862, 4.802575359983939, 4.882179269859709, 4.960927107592845, 5.038850254568215, 5.1159781702760805, 5.192338554922108, 5.267957494663453, 5.342859591695295, 5.417068081082399, 5.490604935955883, 5.563490962465783, 5.63574588568732, 5.707388427516221, 5.778436377450965, 5.848906657042927, 5.918815378695823, 5.988177899410613, 6.05700886999895, 6.125322280225243, 6.193131500283122, 6.260449318965002, 6.327287978842552, 6.393659208740379, 6.459574253754089, 6.525043903036817, 6.59007851555443, 6.654688043988658, 6.718882056949028, 6.782669759638092, 6.846060013100097, 6.909061352170431, 6.971682002231857, 7.033929894873436, 7.095812682539021, 7.157337752244211, 7.218512238433422, 7.279343035042294, 7.339836806824905, 7.3999999999999995, 7.45983885226584, 7.519359402228986, 7.578567498288576, 7.637468807014179, 7.6960688210522035, 7.75437286659301, 7.812386110428309, 7.870113566626099, 7.927560102848258, 7.984730446334009, 8.041629189570674, 8.098260795671541, 8.154629603479187, 8.210739832411285, 8.266595587064641, 8.322200861592094, 8.377559543865907, 8.432675419440267, 8.487552175324653, 8.542193403579086, 8.59660260474139, 8.650783191096068, 8.704738489793636, 8.75847174582876, 8.811986124884923, 8.865284716052917, 8.918370534429958], [0.0, 0.5623730565710474, 0.8523981584038258, 1.0871694955165434, 1.2919940099556335, 1.4770884695313886, 1.647840814959177, 1.8075209071171265, 1.9582967247219538, 2.101696548530104, 2.2388474634702153, 2.3706100239521386, 2.4976596222056195, 2.620538332003941, 2.7396893832313314, 2.8554809080738175, 2.968222787804118, 3.0781789091400453, 3.1855762763848037, 3.290611915119412, 3.3934581902715886, 3.4942669634776014, 3.5931728860398677, 3.6902960381597283, 3.78574406688116, 3.879613934788399, 3.9719933629938993, 4.062962031513455, 4.152592585256384, 4.240951482897856, 4.328099717721641, 4.414093433349635, 4.498984452568379, 4.58282073383953, 4.665646767266472, 4.747503919584252, 4.828430735998954, 4.908463205317903, 4.987634993703001, 5.06597765148545, 5.143520796755041, 5.220292278845602, 5.296318324352985, 5.371623667921925, 5.446231669706606, 5.52016442113375, 5.593442840366388, 5.666086758672603, 5.7381149987402225, 5.809545445840126, 5.880395112623368, 5.950680198237176, 6.020416142359202, 6.089617674675912, 6.158298860267686, 6.226473141308572, 6.2941533754413435, 6.361351871147369, 6.428080420395119, 6.494350328819839, 6.560172443659668, 6.625557179649501, 6.690514543052804, 6.7550541539931315, 6.819185267230607, 6.882916791514222, 6.946257307627915, 7.0092150852370185, 7.071798098631476, 7.134014041453205, 7.195870340486899, 7.257374168586312, 7.318532456801608, 7.379351905767557, 7.439838996407076, 7.5, 7.559840987662623, 7.619367839279806, 7.6785862519279355, 7.737501747823893, 7.796119681832379, 7.854445248561288, 7.912483489072599, 7.9702392972339675, 8.02771742573441, 8.084922491785585, 8.141858982528612, 8.198531260164868, 8.254943566827889, 8.311100029212184, 8.367004662973706, 8.422661376915656, 8.478073976972311, 8.533246170002712, 8.588181567405266, 8.642883688563465, 8.697355964132347, 8.751601739174639, 8.805624276154916, 8.859426757799584, 8.913012289830016, 8.966383903575652], [0.0, 0.565360466829266, 0.8569262256231709, 1.0929447033885766, 1.2988572764542674, 1.484934985637761, 1.6565943932058589, 1.8171227300294661, 1.968699491454309, 2.112861076694067, 2.2507405579220343, 2.3832030609425154, 2.5109275657703605, 2.634459025756265, 2.7542430252882637, 2.870649652125924, 2.9839904336778917, 3.094530658467914, 3.2024985366801944, 3.3080921405252717, 3.4114847505592834, 3.5128290351303506, 3.6122603608288597, 3.7098994457402426, 3.8058545087457625, 3.9002230275094876, 3.9930931891316135, 4.084545096900163, 4.174651781625138, 4.263480055020186, 4.351091234374575, 4.437541761553563, 4.522883734634128, 4.607165366840488, 4.690431384614148, 4.772723374436473, 4.854080086271479, 4.934537700104449, 5.014130060936998, 5.092888886700435, 5.170843952820299, 5.248023256570266, 5.324453163865809, 5.40015854074582, 5.475162871457131, 5.549488364779449, 5.623156049996229, 5.696185863722236, 5.768596728634245, 5.840406625012385, 5.91163265588147, 5.9822911064410365, 6.052397498386624, 6.121966639651011, 6.191012670030396, 6.259549103105682, 6.3275888648213705, 6.395144329043337, 6.46222735038076, 6.528849294526121, 6.5950210663397195, 6.660753135881088, 6.72605556256847, 6.790938017628963, 6.855409804985367, 6.919479880711289, 6.983156871173083, 7.046449089965785, 7.109364553739969, 7.171910997007335, 7.234095886004771, 7.2959264316893115, 7.357409601929903, 7.41855213295609, 7.4793605401184315, 7.539841128010742, 7.6, 7.659843067205896, 7.719376056968547, 7.7786045208396795, 7.837533842129838, 7.896169243041461, 7.954515791415402, 8.01257840711628, 8.070361868080111, 8.127870816045874, 8.185109761991056, 8.24208309128971, 8.298795068610215, 8.355249842568707, 8.411451450152908, 8.467403820930167, 8.523110781052457, 8.578576057070213, 8.633803279566132, 8.6887959866192, 8.743557627108613, 8.79809156386657, 8.852401076688354, 8.90648936520749, 8.960359551643409, 9.014014683428426], [0.0, 0.5683243842452905, 0.8614186843524079, 1.0986744953198957, 1.3056665705745363, 1.4927197971409056, 1.6652791337588169, 1.8266490446952115, 1.9790204513586422, 2.123937807576888, 2.2625401256845117, 2.395697066931058, 2.5240911709023233, 2.648270247881564, 2.768682218244925, 2.885699109946982, 2.9996340835871793, 3.1107538184714674, 3.2192877211820634, 3.3254349023283845, 3.4293695508945325, 3.5312451355965395, 3.6311977326877747, 3.7293486931214708, 3.82580680311928, 3.92067005137454, 4.0140270873106845, 4.105958434159374, 4.19653750559659, 4.285831463598182, 4.3739019469109515, 4.460805693298151, 4.546595073962324, 4.63131855488681, 4.7150210969926825, 4.797744504779553, 4.879527731359161, 4.9604071463913355, 5.04041677231102, 5.119588493331627, 5.197952240977166, 5.27553615929777, 5.352366752432932, 5.428469016782419, 5.503866559709857, 5.578581706425076, 5.652635596458115, 5.726048270941978, 5.798838751756078, 5.871025113442646, 5.9426245486895635, 6.013653428071961, 6.084127354658285, 6.1540612140122954, 6.2234692200584565, 6.292364957222977, 6.360761419214974, 6.428671044770643, 6.496105750647271, 6.563076962122286, 6.629595641225013, 6.6956723129045495, 6.761317089315909, 6.826539692387859, 6.891349474819263, 6.955755439636184, 7.019766258428933, 7.083390288376792, 7.14663558815784, 7.209509932832161, 7.272020827778593, 7.334175521757804, 7.39598101916798, 7.457444091553532, 7.518571288421916, 7.579368947418952, 7.639843203908681, 7.7, 7.759845093058757, 7.819384063740839, 7.8786223235789405, 7.9375651221530354, 7.99621755387227, 8.054584564393785, 8.112670956702054, 8.170481396870498, 8.228020419525523, 8.285292433031623, 8.34230172441482, 8.399052464040476, 8.45554871006033, 8.511794412642598, 8.567793417997951, 8.62354947221337, 8.679066224904975, 8.734347232700227, 8.789395962559166, 8.844215794943727, 8.898810026843607, 8.953181874666498, 9.00733447700015, 9.061270897253122], [0.0, 0.5712652951124705, 0.865876271674423, 1.1043598114040727, 1.3124230095251812, 1.5004441813038272, 1.673896461533452, 1.8361014141077994, 1.989261297806751, 2.134928558550581, 2.274248102726342, 2.4080940918237435, 2.537152597369388, 2.6619742644029856, 2.7830093311563604, 2.900631750718897, 3.015156304203667, 3.126851050903282, 3.2359465845112796, 3.3426430459756857, 3.4471155256571584, 3.5495182864270167, 3.649988108693059, 3.7486469713638675, 3.8456042235976673, 3.940958361150349, 4.034798492179935, 4.127205556602032, 4.2182533479867175, 4.308009375853232, 4.396535597910692, 4.483889045523518, 4.570122360899764, 4.65528426081992, 4.739419938864552, 4.822571415859211, 4.904777846486487, 4.986075788608459, 5.066499440716125, 5.146080852014288, 5.224850108913754, 5.302835501101805, 5.380063669869029, 5.456559740964182, 5.532347443912025, 5.607449219448757, 5.681886316495243, 5.75567887989143, 5.828846029949341, 5.901405934741627, 5.973375875923252, 6.044772308782238, 6.115610917128302, 6.185906663553606, 6.255673835535469, 6.3249260877955, 6.393676481281419, 6.461937519096212, 6.529721179662865, 6.597038947381242, 6.663901841005933, 6.73032043994954, 6.796304908694492, 6.861865019477667, 6.927010173395384, 6.991749420061707, 7.056091475939866, 7.120044741455078, 7.1836173169867, 7.24681701782846, 7.30965138819731, 7.372127714364119, 7.434253036972763, 7.496034162608394, 7.557477674670239, 7.618589943599559, 7.679377136509097, 7.7398452262564055, 7.800000000000001, 7.859847067274019, 7.919391867614235, 7.97863967776565, 8.037595618499475, 8.096264661065163, 8.154651633301217, 8.21276122542661, 8.270597995533096, 8.32816637479716, 8.385470672428912, 8.442515080374127, 8.499303677784281, 8.55584043526854, 8.612129218940582, 8.668173794272283, 8.72397782976545, 8.779544900452038, 8.834878491232582, 8.88998200006191, 8.944858740990666, 8.999511947070502, 9.053944773130434, 9.108160298431256], [0.0, 0.5741836695753587, 0.8702997001951036, 1.1100015605161155, 1.3191276734147515, 1.508109372974265, 1.6824477541266705, 1.8454813493568856, 1.9994236679370565, 2.1458350866359917, 2.2858663607267022, 2.420396117453406, 2.5501139332180074, 2.675573266093732, 2.7972266544061952, 2.915449961627148, 3.030559576965181, 3.1428249291246337, 3.2524777898134483, 3.359719322422701, 3.464725511782296, 3.5676514088331728, 3.668634492741574, 3.7677973655593657, 3.8652499350675247, 3.961091200198838, 4.055410724330603, 4.148289860869293, 4.239802780367926, 4.330017337225887, 4.418995805670373, 4.506795508417091, 4.59346935660287, 4.679066315883474, 4.763631810716075, 4.847208076594443, 4.9298344682273685, 5.0115477302369715, 5.092382235821177, 5.172370197911836, 5.251541856619643, 5.329925646153003, 5.407548343902601, 5.484435203974969, 5.5606100771198745, 5.636095518714599, 5.710912886232564, 5.785082427425948, 5.858623360285088, 5.93155394569632, 6.003891553599934, 6.075652723347682, 6.1468532188718275, 6.217508079202653, 6.287631664806702, 6.357237700162297, 6.426339312940513, 6.494949070117873, 6.563079011310518, 6.630740679587688, 6.697945149994547, 6.764703055989845, 6.8310246139824375, 6.896919646131798, 6.962397601560829, 7.027467576114586, 7.092138330785357, 7.156418308912896, 7.22031565225828, 7.283838216040563, 7.346993583017198, 7.409789076681806, 7.4722317736462, 7.53432851526776, 7.596085918577762, 7.6575103865616, 7.718608117837419, 7.7793851157758045, 7.839847197099637, 7.9, 7.9598489918011675, 8.019399476204997, 8.078656600142747, 8.13762536026007, 8.19631060905904, 8.25471706071915, 8.312849296617694, 8.370711770568326, 8.428308813795256, 8.485644639659295, 8.542723348150734, 8.59954893016305, 8.656125271560411, 8.712456157051035, 8.768545273877695, 8.82439621533581, 8.880012484128924, 8.935397495570715, 8.990554580642032, 9.045486988910943, 9.100197891323273, 9.154690382870573], [0.0, 0.5770799623628855, 0.8746896591546225, 1.1156006217298278, 1.3257816069359951, 1.5157165665103982, 1.6909343439652, 1.854790311984838, 2.0095091452076645, 2.156659091242814, 2.29739670999407, 2.432605060670343, 2.562977198029445, 2.6890693718934977, 2.811336403278409, 2.9301560515835217, 3.0458463019454056, 3.1586779421185684, 3.2688839129119933, 3.3766663924235663, 3.4822022531844965, 3.5856473282424712, 3.687139790235071, 3.7868028596424743, 3.884746998641631, 3.9810717055349727, 4.075866995474685, 4.16921463222946, 4.261189160482842, 4.351858776904845, 4.44128606984584, 4.52952865116833, 4.616639698903084, 4.702668425698048, 4.787660485140086, 4.871658325766915, 4.954701500800042, 5.036826940208524, 5.118069190575301, 5.198460627320443, 5.278031643091577, 5.35681081552472, 5.434825057080861, 5.5120997492531, 5.588658863098971, 5.664525067769413, 5.739719828469048, 5.814263495083607, 5.888175382542667, 5.961473843843984, 6.034176336545163, 6.106299483425626, 6.177859127933941, 6.24887038496015, 6.31934768740775, 6.389304828983969, 6.4587550035783785, 6.527710841557748, 6.596184443268353, 6.664187410004896, 6.731730872677197, 6.798825518381214, 6.865481615059336, 6.931709034415893, 6.99751727323698, 7.062915473248846, 7.127912439635905, 7.192516658327741, 7.256736312154038, 7.320579295957085, 7.384053230743222, 7.447165476947177, 7.509923146876556, 7.572333116397859, 7.634402035919938, 7.6961363407260786, 7.757542260701446, 7.818625829498781, 7.879392893181632, 7.939849118381202, 8.0, 8.059850868492774, 8.119406896752894, 8.178673106630056, 8.237654375103281, 8.296355440131292, 8.354780906200734, 8.412935249591149, 8.470822823374277, 8.52844786216393, 8.585814486631532, 8.642926707801404, 8.699788431138757, 8.7564034604426, 8.81277550155487, 8.868908165896258, 8.924804973838622, 8.980469357923132, 9.03590466593275, 9.091114163826987, 9.146101038546528, 9.200868400694658], [0.0, 0.5799546134795288, 0.8790468154750565, 1.1211578456539657, 1.3323858209537522, 1.5232669175962223, 1.6993575203308238, 1.8640297162082229, 2.019519261803159, 2.1674022167526226, 2.3088409022178236, 2.44472277625585, 2.57574434598946, 2.702464632129174, 2.82534072132448, 2.9447522547355676, 3.061018801501898, 3.174412498273055, 3.285167446223311, 3.39348683057527, 3.499548404928369, 3.603508778592986, 3.705506812496284, 3.805666340925739, 3.904098376311715, 4.0009029125949, 4.096170413326617, 4.189983049571471, 4.282415737347952, 4.373537013039194, 4.463409776771548, 4.55209192739375, 4.6396369078362305, 4.7260941758935395, 4.81150961257013, 4.8959258778557615, 4.97938272200133, 5.06191725893788, 5.143564207337802, 5.22435610389524, 5.304323492654968, 5.383495093608893, 5.461897953279038, 5.539557579593215, 5.616498063017757, 5.692742185627124, 5.768311519552151, 5.84322651604896, 5.917506586262013, 5.991170174612215, 6.064234825619793, 6.13671724486845, 6.2086333547288985, 6.279998345384098, 6.350826721633237, 6.421132345895159, 6.490928477783132, 6.560227810580507, 6.6290425049099095, 6.69738421985643, 6.765264141777113, 6.832693011004339, 6.899681146628955, 6.966238469529948, 7.032374523800452, 7.098098496705074, 7.163419237290145, 7.2283452737568386, 7.292884829696573, 7.357045839278799, 7.420835961472941, 7.484262593378802, 7.547332882733056, 7.610053739653463, 7.67243184767705, 7.734473674143653, 7.796185479971829, 7.857573328870197, 7.918643096023734, 7.979400476291255, 8.03985099194743, 8.1, 8.159852699110447, 8.219414136144179, 8.278689212374275, 8.337682689361003, 8.396399194527678, 8.454843226451864, 8.513019159889577, 8.570931250548826, 8.628583639627644, 8.685980358130758, 8.743125330977964, 8.800022380916419, 8.856675232248243, 8.913087514383962, 8.969262765231726, 9.025204434431474, 9.080915886442728, 9.136400403493967, 9.191661188401214, 9.246701367262839], [0.0, 0.5828080488573741, 0.8833718147487235, 1.1266740556927892, 1.3389412940029948, 1.5307615449542022, 1.7077185312710197, 1.8732009310135884, 2.0294555009052084, 2.178066054955749, 2.320200633064136, 2.4567510596708915, 2.5884172687842897, 2.715761031553308, 2.839241683539998, 2.9592407337774693, 3.0760793237176824, 3.1900309289500726, 3.301330802450376, 3.410183129133049, 3.516766537163224, 3.6212384063849306, 3.723738280935145, 3.824390604378565, 3.9233069353379455, 4.02058775973428, 4.116323986208717, 4.210598190115812, 4.303485656068447, 4.395055257655697, 4.485370204478897, 4.574488680254977, 4.662464390858993, 4.749347037422848, 4.83518272669018, 4.920014328542213, 5.003881788805102, 5.086822404014184, 5.168871063661231, 5.250060464524218, 5.330421300927704, 5.4099824341688665, 5.488771043841353, 5.566812763374558, 5.6441318017623505, 5.720751053169299, 5.796692195863304, 5.87197578172274, 5.946621317396864, 6.020647338054994, 6.094071474538175, 6.1669105146232726, 6.239180459020671, 6.310896572650569, 6.382073431677235, 6.4527249667240145, 6.522864502642816, 6.5925047951692255, 6.661658064757367, 6.730336027856205, 6.7985499258607955, 6.8663105519470395, 6.933628275976757, 7.000513067640659, 7.066974517989788, 7.13302185949102, 7.198663984728891, 7.263909463864185, 7.328766560949224, 7.393243249190374, 7.457347225239965, 7.521085922592279, 7.584466524151577, 7.647495974034098, 7.7101809886605475, 7.772528067190729, 7.83454350134755, 7.896233384673691, 7.957603621260633, 8.018659933986472, 8.079407872296029, 8.139852819554063, 8.200000000000001, 8.259854485330337, 8.31942120093291, 8.378704931795344, 8.437710328108345, 8.496441910582936, 8.554904075499376, 8.613101099504187, 8.671037144170512, 8.728716260336034, 8.786142392231548, 8.843319381412517, 8.900250970505, 8.956940806776597, 9.013392445542314, 9.069609353414679, 9.125594911406685, 9.181352417895711, 9.236885091455962, 9.292196073566524], [0.0, 0.5856406809717238, 0.8876652821712726, 1.1321500492361471, 1.3454489737031252, 1.538201531962189, 1.7160185854027914, 1.8823052821360922, 2.0393192988362396, 2.188652147351931, 2.3314775446267633, 2.468691649651126, 2.600997798334749, 2.7289604922127126, 2.853041299363704, 2.973623583075834, 3.0910300456504576, 3.2055354918551813, 3.3173763180698783, 3.4267577016125035, 3.5338591388377707, 3.638838774505709, 3.7418368309820944, 3.8429783566668507, 3.9423754523930503, 4.0401290924751585, 4.136330627399179, 4.2310630338621, 4.324401962383918, 4.416416621301215, 4.507170527434051, 4.596722147290691, 4.685125447773791, 4.77243037157853, 4.858683249541955, 4.943927159906524, 5.028202242647783, 5.111545975574072, 5.193993417751167, 5.275577424873762, 5.356328840450578, 5.436276666053857, 5.515448213378698, 5.5938692404411015, 5.671564073898329, 5.748555719187857, 5.82486595994085, 5.900515447924334, 5.975523784596072, 6.049909595212191, 6.123690596305218, 6.196883657245944, 6.269504856513284, 6.341569533219795, 6.41309233437453, 6.484087258308085, 6.55456769463538, 6.624546461088927, 6.694035837518131, 6.7630475973176205, 6.8315930365192, 6.8996830007570304, 6.9673279102937515, 7.034537783275937, 7.101322257370181, 7.167690609916081, 7.233651776718952, 7.299214369593285, 7.364386692757316, 7.429176758169727, 7.493592299891019, 7.557640787544619, 7.62132943894598, 7.684665231961952, 7.747654915657176, 7.810305020779434, 7.872621869631406, 7.9346115853723225, 7.996280100789426, 8.057633166575814, 8.118676359148372, 8.17941508803672, 8.239854602871747, 8.3, 8.359856228748269, 8.419428097360738, 8.478720278629513, 8.53773731523771, 8.596483624832901, 8.654963504847471, 8.713181137081131, 8.771140592059917, 8.828845833184841, 8.886300720682542, 8.943509015369434, 9.000474382239988, 9.057200393889177, 9.113690533778362, 9.169948199353335, 9.225976705022635, 9.281779285003758, 9.337359096044375], [0.0, 0.5884529094227096, 0.8919278234232436, 1.1375865987838392, 1.3519097780941716, 1.5455879281810383, 1.7242588536168826, 1.8913440539288588, 2.0491120470847317, 2.1991619873239108, 2.342673227742483, 2.480546230658614, 2.613487709379336, 2.7420648761586555, 2.8667415155109075, 2.9879028316228657, 3.1058730764023625, 3.220928374221007, 3.3333062566267815, 3.443212886192781, 3.5508286212096682, 3.6563123658437213, 3.759805015804184, 3.8614322199695317, 3.961306617477572, 4.0595296675183095, 4.156193159239956, 4.251380467791037, 4.345167606963008, 4.437624117428741, 4.528813821014107, 4.6187954649817335, 4.7076232753816765, 4.795347434732395, 4.882014496350183, 4.967667745337886, 5.052347514421974, 5.136091461378062, 5.218934813624481, 5.30091058462795, 5.3820497660067685, 5.462381498597832, 5.541933225246156, 5.620730827656935, 5.698798749303291, 5.776160106094097, 5.8528367862648425, 5.928849540751698, 6.004218065138025, 6.078961074117853, 6.15309636929795, 6.226640901055304, 6.299610825077191, 6.372021554134111, 6.443887805569601, 6.515223644933809, 6.586042526138173, 6.656357328465557, 6.726180390732827, 6.795523542870088, 6.864398135152338, 6.93281506529414, 7.000784803595911, 7.068317416311058, 7.135422587385949, 7.202109638709681, 7.2683875489970315, 7.334264971416155, 7.39975025006189, 7.464851435366095, 7.52957629852799, 7.593932345039905, 7.657926827377017, 7.7215667569136786, 7.784858915123331, 7.847809864114205, 7.910425956548481, 7.972713344988613, 8.034677990710904, 8.0963256720231, 8.157661992119872, 8.21869238650723, 8.27942213002463, 8.33985634349112, 8.4, 8.459857930884496, 8.519434831375317, 8.578735265969403, 8.637763673527735, 8.696524372118832, 8.75502156362328, 8.813259338113657, 8.8712416780231, 8.92897246211494, 8.986455469264913, 9.043694382066683, 9.100692790270713, 9.157454194065835, 9.213982007212273, 9.270279560034254, 9.326350102279886, 9.382196805855443], [0.0, 0.591245121485164, 0.8961600255035158, 1.1429844530086177, 1.35832459690006, 1.5529217507988662, 1.7324404706889875, 1.9003184911303204, 2.058835094219979, 2.2095970221924115, 2.3537892241801734, 2.4923164351997307, 2.62588872191637, 2.755075988009141, 2.8803442186522696, 3.002080445828365, 3.1206104600222186, 3.2362116958169937, 3.349122811849082, 3.4595509489340417, 3.5676773211635457, 3.6736615867049545, 3.7776453098183707, 3.879754735586841, 3.9801030376214577, 4.0787921565366, 4.175914317020458, 4.27155328983706, 4.365785449463694, 4.458680666544079, 4.550303065738975, 4.640711673067073, 4.729960971881312, 4.818101382816456, 4.905179680084526, 4.9912393541764, 5.076320929197541, 5.1604622416099035, 5.243698685986096, 5.326063432441908, 5.407587619651024, 5.488300526723762, 5.568229726721574, 5.647401224158482, 5.7258395784920095, 5.803568015316138, 5.880608526726143, 5.956981962121497, 6.0327081105412015, 6.107805775480608, 6.182292843015197, 6.256186343951583, 6.329502510635861, 6.402256828972206, 6.474464086138024, 6.546138414424573, 6.6172933315821645, 6.687941778005931, 6.758096151060484, 6.82776833680901, 6.896969739383617, 6.965711308208581, 7.034003563265949, 7.1018566185735486, 7.1692802040281265, 7.2362836857511885, 7.302876085061561, 7.3690660961867245, 7.434862102814291, 7.500272193575459, 7.56530417654383, 7.629965592825329, 7.694263729308171, 7.75820563063571, 7.8217981104595165, 7.885047762025058, 7.94796096813793, 8.010543910554526, 8.072802578837434, 8.134742778712504, 8.196370139961587, 8.257690123882206, 8.31870803034295, 8.379429004461183, 8.439858042927558, 8.5, 8.559859593188113, 8.619441408647397, 8.678749906301254, 8.737789424707458, 8.79656418568454, 8.855078298712494, 8.91333576512112, 8.971340482078505, 9.029096246391168, 9.086606758126697, 9.143875624068942, 9.200906361015146, 9.257702398923845, 9.31426708392167, 9.370603681176803, 9.426715377646227], [0.0, 0.594017692628836, 0.9003624575178082, 1.1483443377618605, 1.3646942927237566, 1.5602039859974082, 1.740564536804064, 1.9092298005362391, 2.0684897477035884, 2.219958655160284, 2.364827028711829, 2.504003846018067, 2.638202503514417, 2.7679955773730076, 2.893851237948121, 3.0161583321611567, 3.1352441782512424, 3.2513875117968323, 3.3648281105945865, 3.475774086821393, 3.5844075043500796, 3.690888770045308, 3.7953601120153357, 3.8979483673539708, 3.998767240386009, 4.097919149763778, 4.195496752651782, 4.291584212646724, 4.38625826237459, 4.479589100128877, 4.5716411512750375, 4.662473718627005, 4.752141541030688, 4.840695275562205, 4.928181915775481, 5.014645156104691, 5.100125710688097, 5.184661593417081, 5.2682883648427365, 5.351039350628026, 5.432945835467607, 5.514037235772576, 5.594341253904861, 5.673884016323445, 5.752690197654405, 5.830783132405281, 5.908184915800572, 5.984916495010437, 6.060997751872141, 6.136447578057706, 6.211283943517164, 6.2855239589209955, 6.359183932734883, 6.432279423482241, 6.504825287683123, 6.576835723900422, 6.648324313274279, 6.719304056882211, 6.789787410224745, 6.859786315103295, 6.929312229128243, 6.99837615306984, 7.066988656242292, 7.135159900091868, 7.2028996601424655, 7.270217346436864, 7.337122022598251, 7.403622423624619, 7.469726972517847, 7.535443795839774, 7.600780738279, 7.665745376304539, 7.730345030975566, 7.794586779970427, 7.858477468892469, 7.922023721905371, 7.985231951746112, 8.048108369159667, 8.110658991795942, 8.172889652606022, 8.234806007771928, 8.296413544201261, 8.357717586615696, 8.418723304259986, 8.47943571725615, 8.539859702625561, 8.6, 8.659861217041177, 8.719447834586758, 8.778764211539647, 8.837814589516075, 8.896603097266933, 8.955133754885768, 9.013410477815953, 9.071437080668664, 9.129217280862504, 9.186754702094884, 9.24405287765464, 9.301115253584674, 9.357945191702868, 9.414545972489002, 9.470920797844906], [0.0, 0.5967709870108765, 0.904535671425147, 1.1536669570256326, 1.3710197021787016, 1.5674355902455464, 1.748632118999391, 1.918079152582602, 2.07807727560441, 2.2302482471530163, 2.375788091073179, 2.515609998170436, 2.6504306714995582, 2.7808253411448014, 2.9072643474476756, 3.0301383396497097, 3.1497761531223984, 3.266457815394103, 3.3804242156406037, 3.4918844306465675, 3.601021368157731, 3.707996178530617, 3.8129517491061216, 3.9160155048727607, 4.01730167717916, 4.116913159391958, 4.214943038145105, 4.311475867136748, 4.406588734651484, 4.500352164354544, 4.592830880225376, 4.684084459948692, 4.774167896087012, 4.863132080513911, 4.951024224600205, 5.03788822530542, 5.123764985479382, 5.20869269520929, 5.292707079870732, 5.375841619592374, 5.458127744074612, 5.539595006074715, 5.620271236356103, 5.700182682474883, 5.779354133424948, 5.857809031870163, 5.935569575447224, 6.012656808417213, 6.089090704770459, 6.164890243742597, 6.240073478575053, 6.31465759924691, 6.388658989814203, 6.46209328091469, 6.534975397928953, 6.60731960523076, 6.679139546909347, 6.750448284302716, 6.821258330643108, 6.891581683082635, 6.961429852338137, 7.030813890168847, 7.099744414878144, 7.16823163501098, 7.236285371401176, 7.303915077707413, 7.371129859563115, 7.437938492453316, 7.50434943842083, 7.570370861694412, 7.636010643323093, 7.701276394893105, 7.766175471397008, 7.830714983318453, 7.894901807990417, 7.9587426002798285, 8.02224380264694, 8.085411654623769, 8.148252201752252, 8.21077130401942, 8.272974643823916, 8.334867733505362, 8.396455922465716, 8.457744403909379, 8.518738221226823, 8.579442274044599, 8.63986132396286, 8.700000000000001, 8.75986280376254, 8.81945411435706, 8.87877819305984, 8.937839187758692, 8.996641137180447, 9.055187974916704, 9.113483533259506, 9.171531546857828, 9.22933565620506, 9.286899410966965, 9.34422627315898, 9.401319620181141, 9.458182747718375, 9.51481887251345], [0.0, 0.5995053579423699, 0.9086802027449962, 1.158952993814579, 1.3773016369606181, 1.5746174915246673, 1.7566442525315806, 1.9268676828450992, 2.087598908223099, 2.2404671185622567, 2.3866738178209848, 2.5271363809934773, 2.6625747950273917, 2.793566925678716, 2.9205852683618208, 3.0440222622509787, 3.1642082494227703, 3.2814245404758644, 3.395913128326628, 3.5078840477377393, 3.6175210445278863, 3.724986007435416, 3.830422478502946, 3.933958466573087, 4.035708726396045, 4.135776622790052, 4.234255668906752, 4.331230805864557, 4.4267794751622285, 4.520972523600443, 4.613874971720269, 4.705546670187996, 4.796042863538959, 4.8854146768304245, 4.973709537753038, 5.060971544399713, 5.147241787034822, 5.232558630730386, 5.316957964553644, 5.400473422037318, 5.483136576890916, 5.56497711728077, 5.646023001489286, 5.726300597337385, 5.805834807400735, 5.884649181756159, 5.96276601974867, 6.040206462062963, 6.116990574209066, 6.193137422384394, 6.268665142549307, 6.343591003446401, 6.417931464202531, 6.491702227074149, 6.5649182858290915, 6.6375939701996804, 6.709742986791595, 6.781378456789152, 6.852512950759515, 6.923158520825068, 6.993326730444105, 7.063028682014397, 7.132275042491785, 7.201076067196201, 7.269441621959969, 7.3373812037579, 7.404903959944917, 7.472018706214831, 7.538733943383054, 7.6050578730863805, 7.6709984124843595, 7.7365632080390805, 7.801759648443267, 7.8665948767604, 7.931075801835012, 7.995209109026252, 8.059001270313363, 8.122458553817545, 8.185587032781063, 8.248392594041086, 8.310880946032677, 8.37305762635269, 8.434928008913742, 8.4964973107152, 8.557770598256072, 8.618752793612712, 8.679448680202663, 8.739862908254219, 8.8, 8.859864354611414, 8.919460252889667, 8.978791861727954, 9.037863238358327, 9.096678334395875, 9.155240999691994, 9.213554986007605, 9.271623950516632, 9.329451459149208, 9.38704098978353, 9.444395935294686, 9.501519606468252, 9.558415234785922], [0.0, 0.6022211483305613, 0.9127965712275475, 1.1642031110308289, 1.3835408848634825, 1.5817505904901845, 1.764601942172372, 1.935596493460484, 2.0970558396320356, 2.250616550898498, 2.397485574093577, 2.538584439967807, 2.674636397047087, 2.8062219288492747, 2.933815671217491, 3.057811841095838, 3.1785422770276486, 3.296289563963205, 3.4112967910593457, 3.523774944547125, 3.633908602623327, 3.7418603873906875, 3.8477744911447256, 3.9517795026147535, 4.053990696395953, 4.154511905554546, 4.2534370668616095, 4.350851506223228, 4.4468330159521745, 4.541452763788809, 4.634776064820623, 4.726863040840534, 4.81776918664449, 4.907545858888918, 4.996240700114366, 5.0838980081803955, 5.170559059492411, 5.256262392918199, 5.341044060104337, 5.4249378469451965, 5.507975470180828, 5.590186752466497, 5.671599778737081, 5.752241036261099, 5.8321355404241775, 5.911306947986211, 5.989777659309402, 6.067568910846847, 6.144700859006371, 6.2211926563562585, 6.297062521013708, 6.372327799949617, 6.447005026851536, 6.52110997510796, 6.594657706409266, 6.667662615402211, 6.7401384707841085, 6.81209845317892, 6.883555190099131, 6.954520788263868, 7.025006863514488, 7.095024568543201, 7.164584618627714, 7.233697315545088, 7.30237256982038, 7.37061992145019, 7.438448559227434, 7.5058673387814725, 7.572884799436854, 7.639509179984213, 7.70574843344824, 7.771610240929898, 7.83710202459307, 7.902230959859686, 7.967003986871702, 8.031427821273292, 8.0955089643621, 8.159253712654241, 8.222668166904084, 8.285758240616474, 8.34852966808598, 8.41098801199506, 8.473138670600433, 8.534986884534744, 8.5965377432485, 8.657796191115327, 8.718767033221887, 8.779454940862255, 8.839864456755, 8.900000000000002, 8.959865870790718, 9.019466254896589, 9.078805227929136, 9.137886759404473, 9.196714716614018, 9.255292868314367, 9.31362488824663, 9.37171435849479, 9.42956477269201, 9.487179539083284, 9.54456198345221, 9.601715351919268], [0.0, 0.6049186910983, 0.9168852814894793, 1.169417952274857, 1.3897382107431537, 1.5888357615732185, 1.7725061634376669, 1.9442666544747045, 2.106449229135917, 2.2606977883586223, 2.4082246852806923, 2.549955578486128, 2.6866169561642588, 2.81879190200585, 2.9469571779010577, 3.071508766618829, 3.192779993114366, 3.3110547081270907, 3.4265770896885814, 3.5395590691052754, 3.650186051359235, 3.758621386990046, 3.8650099141770293, 3.9694807976398914, 4.072149828325907, 4.173121304403093, 4.272489583415622, 4.370340373471835, 4.466751815341364, 4.561795395547833, 4.6555367217460795, 4.748036185033922, 4.8393495287864, 4.929528339702969, 5.018620473730482, 5.1066704271529035, 5.19371966126597, 5.279806887565488, 5.364968319184989, 5.449237893356762, 5.532647468890366, 5.615227002026361, 5.697004703501102, 5.7780071792281325, 5.858259556645056, 5.937785598478025, 6.016607805427691, 6.094747509072074, 6.17222495610605, 6.249059384888435, 6.32526909514125, 6.40087151153807, 6.475883241826167, 6.550320130048127, 6.624197305360501, 6.6975292268883075, 6.770329725003299, 6.842612039369703, 6.914388854062706, 6.985672330031332, 7.056474135148042, 7.126805472061549, 7.1966771040467465, 7.266099379025676, 7.335082251915835, 7.403635305446545, 7.471767769570287, 7.539488539583644, 7.606806193061553, 7.673729005698849, 7.740264966144386, 7.806421789905254, 7.872206932391603, 7.937627601166394, 8.002690767458715, 8.067403176994276, 8.131771360192133, 8.195801641772523, 8.259500149817066, 8.3228728243191, 8.385925425258952, 8.448663540236124, 8.511092591687872, 8.573217843721325, 8.63504440858428, 8.696577252797802, 8.757821202972094, 8.81878095132546, 8.87946106092477, 8.93986597066448, 9.0, 9.05986735345018, 9.119472124882522, 9.178818301593884, 9.237909768198525, 9.296750310334522, 9.355343618198855, 9.413693289920815, 9.471802834782679, 9.529675676296062, 9.587315155141827, 9.644724531980874], [0.0, 0.607598309582116, 0.9209468236173268, 1.1745981426150374, 1.395894357431912, 1.5958738540261557, 1.7803578637539554, 1.95287920512236, 2.1157802026579358, 2.270712039313588, 2.418892438608241, 2.5612511595312686, 2.6985179084089324, 2.831278351827614, 2.9600113635976193, 3.0851146805794167, 3.2069231042633604, 3.3257217427672576, 3.441755855762216, 3.555238313350337, 3.6663553418052466, 3.775271015263159, 3.8821308134955097, 3.987064473385133, 4.090188298800408, 4.191607049920696, 4.29141550226737, 4.389699743611415, 4.486538260863944, 4.582002857213636, 4.676159430938657, 4.7690686406522875, 4.860786476656928, 4.951364754166506, 5.040851541116165, 5.129291530895807, 5.216726368462963, 5.303194936794406, 5.388733609437592, 5.4733764739571376, 5.557155530288105, 5.640100867368716, 5.7222408209009, 5.8036021146548595, 5.884209987375633, 5.96408830705152, 6.043259674054902, 6.121745514456649, 6.19956616463876, 6.276740948180533, 6.353288245866577, 6.4292255595568335, 6.504569570566193, 6.579336193121861, 6.65354062339827, 6.727197384570266, 6.800320368274231, 6.872922872822356, 6.9450176384766875, 7.016616880055812, 7.087732317117558, 7.158375201935203, 7.228556345461897, 7.298286141458047, 7.367574588938615, 7.436431313081699, 7.504865584725858, 7.572886338571317, 7.640502190189243, 7.707721451933453, 7.774552147840254, 7.841002027594248, 7.90707857963094, 7.972789043440753, 8.038140421133345, 8.103139488316085, 8.16779280433593, 8.23210672192984, 8.2960873963251, 8.359740793827536, 8.423072699932558, 8.48608872699115, 8.548794321460429, 8.611194770766028, 8.673295209801553, 8.735100627088356, 8.79661587061715, 8.857845653391438, 8.918794558691188, 8.979467045073896, 9.039867451128941, 9.099999999999998, 9.159868803689244, 9.21947786715613, 9.27883109222266, 9.337932281296213, 9.396785140920299, 9.4553932851629, 9.513760238851418, 9.57188944066266, 9.629784246075758, 9.687447930195411], [0.0, 0.6102603179102379, 0.9249816737404498, 1.1797442893184213, 1.4020100466069159, 1.602865692915522, 1.7881579635659675, 1.961435155041686, 2.1250498540561176, 2.2806604777211548, 2.4294900846432252, 2.572472507269667, 2.7103406489144333, 2.843682742085019, 2.972979758632575, 3.0986311779813955, 3.2209732684533607, 3.340292387281314, 3.456834868667473, 3.5708145153399466, 3.6824183694664856, 3.7918112240245354, 3.8991391961611743, 4.004532591162172, 4.108108222446149, 4.209971309167529, 4.310217042077978, 4.408931886116033, 4.506194672059478, 4.60207751768096, 4.696646609972031, 4.78996287330335, 4.8820825432819035, 4.973057662134313, 5.0629365083908535, 5.151763971252002, 5.239581878130085, 5.326429282355884, 5.412342716836555, 5.497356418481079, 5.581502527422559, 5.664811264424805, 5.747311089334058, 5.829028843002643, 5.9099898747515285, 5.990218157139392, 6.069736389555314, 6.148566091942017, 6.226727689779213, 6.304240591306617, 6.381123257838692, 6.45739326791449, 6.5330673759330375, 6.608161565844918, 6.682691100402008, 6.756670566408053, 6.830113916361442, 6.9030345068368995, 6.975445133914081, 7.047358065927107, 7.118785073779508, 7.189737459042992, 7.260226080035634, 7.330261376054962, 7.3998533899235985, 7.469011788989449, 7.537745884708449, 7.606064650925513, 7.673976740958328, 7.741490503578777, 7.808613997978057, 7.87535500779367, 7.941721054269436, 8.007719408613418, 8.073357103612905, 8.138640944560533, 8.203577519541064, 8.268173209124047, 8.33243419550404, 8.396366471126433, 8.459975846834032, 8.523267959566645, 8.586248279643394, 8.648922117655166, 8.711294630992555, 8.773370830032606, 8.835155584006044, 8.89665362656497, 8.957869561069606, 9.01880786561127, 9.079472897787563, 9.139868899244583, 9.200000000000001, 9.259870222559792, 9.31948348584061, 9.378843608908932, 9.43795431454737, 9.496819232657852, 9.555441903510749, 9.613825780848384, 9.671974234850909, 9.729890554971908], [0.0, 0.6129050213617684, 0.9289902945754418, 1.1848569825450892, 1.4080859796153722, 1.6098120800653695, 1.7959073573891136, 1.96993548542898, 2.134259246374042, 2.2905442444681934, 2.440018838723644, 2.5836209085654307, 2.7220865335125892, 2.8560064953134834, 2.985863850221408, 3.1120598088966256, 3.2349320969571327, 3.3547683126307044, 3.471815857665484, 3.5862894613528775, 3.6983769764508905, 3.8082439101052397, 3.916037012695269, 4.0218871542146735, 4.125911654319894, 4.228216188156757, 4.328896359007948, 4.428039006527702, 4.52572330312511, 4.622021679111775, 4.717000608315799, 4.810721279137615, 4.903240170894147, 4.994609551348978, 5.084877908258493, 5.174090325360848, 5.262288811337081, 5.349512588764562, 5.435798348874209, 5.521180476948516, 5.605691252407251, 5.6893610269828505, 5.7722183838588474, 5.854290280208573, 5.935602175210109, 6.01617814531273, 6.09604098827854, 6.175212317311884, 6.253712646410985, 6.331561467925634, 6.4087773231766425, 6.485377866883705, 6.56137992605489, 6.63679955391091, 6.711652079348283, 6.7859521523860264, 6.859713785988889, 6.932950394615386, 7.005674829799924, 7.077899413044274, 7.149635966263881, 7.220895840008419, 7.291689939652977, 7.36202874973618, 7.431922356603534, 7.5013804694986215, 7.570412440230712, 7.639027281534942, 7.707233684230138, 7.7750400332695095, 7.842454422770612, 7.909484670103129, 7.976138329105924, 8.04242270249851, 8.108344853546374, 8.173911617034461, 8.239129609598505, 8.30400523945973, 8.368544715604648, 8.43275405644829, 8.496639098016091, 8.560205501676833, 8.623458761456519, 8.686404210960708, 8.74904702993073, 8.811392250457255, 8.873444762872934, 8.93520932134424, 8.996690549181118, 9.057892943881724, 9.118820881928306, 9.179478623349114, 9.239870316060204, 9.299999999999999, 9.359871611068685, 9.419488984883541, 9.478855860360714, 9.537975883133145, 9.596852608813778, 9.65548950611253, 9.713889959815, 9.772057273630375], [0.0, 0.6155327167081528, 0.9329731359436989, 1.1899367960082703, 1.4141228382590225, 1.6167137949541506, 1.8036069148100395, 1.9783811501361122, 2.143409413029904, 2.3003644486468176, 2.450479882317901, 2.5946976144197484, 2.733756880250285, 2.8682509944045576, 2.9986650841332008, 3.1254020801988553, 3.2488011561437538, 3.3691511432097583, 3.4867005038255394, 3.6016648878870683, 3.714232953529693, 3.824570917474582, 3.9328261592610216, 4.039130109958995, 4.1436005922071395, 4.246343734210208, 4.34745554912891, 4.447023248923382, 4.545126345436988, 4.641837579510347, 4.737223709963465, 4.8313461875285695, 4.924261733665222, 5.016022840223536, 5.106678202840477, 5.196273098540803, 5.284849716108522, 5.372447446279173, 5.459103137589245, 5.5448513227405645, 5.629724419543801, 5.7137529098577655, 5.7969654994100965, 5.87938926094707, 5.9610497627973915, 6.041971184632809, 6.122176421955814, 6.201687180632605, 6.280524062610658, 6.3587066438089215, 6.436253545040038, 6.5131824967144265, 6.58951039798225, 6.665253370888865, 6.740426810050065, 6.815045428293595, 6.889123298661707, 6.9626738931244505, 7.035710118314361, 7.108244348558933, 7.180288456457473, 7.251853841222634, 7.322951454983905, 7.393591827230061, 7.463785087549591, 7.533540986812325, 7.602868916921353, 7.67177792925193, 7.740276751882858, 7.808373805715984, 7.876077219570612, 7.943394844331676, 8.010334266223461, 8.076902819274284, 8.143107597031825, 8.208955463583667, 8.274453063932912, 8.339606833774619, 8.404423008714968, 8.468907632971616, 8.533066567590675, 8.596905498212795, 8.660429942418409, 8.723645256679736, 8.786556642945106, 8.849169154879167, 8.9114877037808, 8.973517064198917, 9.035261879264885, 9.096726665758897, 9.157915818926403, 9.218833617059587, 9.27948422585778, 9.339871702579755, 9.4, 9.459872970180161, 9.519494368066162, 9.578867854920796, 9.637997001600915, 9.696885291687764, 9.755536124478464, 9.81395281784613], [0.0, 0.6181436925379863, 0.9369306352637357, 1.1949842876022552, 1.4201212855403558, 1.6235715955678343, 1.8112574814383644, 1.9867730767144887, 2.1525013589475606, 2.310122168768253, 2.4608743643178865, 2.6057038413400773, 2.7453529708320286, 2.8804175841194577, 3.011384866272985, 3.1386594572129507, 3.262581969192962, 3.383442458623537, 3.501490441864971, 3.6169424835601696, 3.7299880420973652, 3.840794039258285, 3.949508479738937, 4.05626335211557, 4.161176978808643, 4.264355938199105, 4.36589665071772, 4.4658866982616106, 4.564405929948663, 4.661527395172673, 4.757318135932204, 4.851839863622112, 4.94514954030389, 5.03729988048836, 5.128339786370367, 5.218314727031424, 5.307267070212551, 5.395236373737494, 5.482259642447413, 5.56837155552546, 5.65360466829266, 5.737989591906223, 5.821555153858171, 5.904328541732357, 5.986335432313603, 6.0676001078393496, 6.148145560930569, 6.2279935895257275, 6.307164882961948, 6.385679100195603, 6.463554941025374, 6.5408102110708, 6.6174618811651085, 6.693526141740391, 6.769018452713547, 6.843953589321416, 6.918345684301488, 6.992208266769417, 7.065554298105283, 7.138396205126188, 7.210745910792806, 7.28261486267114, 7.354014059347585, 7.424954074975057, 7.495445082109885, 7.5654968729832826, 7.635118879337056, 7.704320190940717, 7.773109572895961, 7.841495481824543, 7.909486081026714, 7.977089254689408, 8.044312621216267, 8.111163545745201, 8.177649151913405, 8.24377633292465, 8.309551761968914, 8.37498190204028, 8.440073015195216, 8.504831171289831, 8.56926225623171, 8.633371979778937, 8.6971658829165, 8.760649344837784, 8.823827589556819, 8.886705692174962, 8.949288584823913, 9.011581062305341, 9.073587787445915, 9.13531329618517, 9.19676200241238, 9.257938202567447, 9.318846080019828, 9.379489709238438, 9.439873059764704, 9.5, 9.559874300818041, 9.619499639012014, 9.678879600585688, 9.738017683897011, 9.7969173026623, 9.855581788828466], [0.0, 0.6207382295661439, 0.9408632180197389, 1.2000000000000002, 1.426081966372803, 1.6303862192118455, 1.818859879812478, 1.9951121674086247, 2.1615360616329817, 2.3198184539181153, 2.471203402269648, 2.6166407726432372, 2.7568760519928843, 2.8925075725295475, 3.0240245641877195, 3.1518333652845207, 3.276276017726751, 3.397643795379877, 3.516187261900226, 3.632123890918357, 3.7456439360369647, 3.8569150196592465, 3.966085767701922, 4.073288722737428, 4.178642703821396, 4.282254736676648, 4.384221646439812, 4.484631382615863, 4.583564129473713, 4.681093243017677, 4.777286046641967, 4.872204510762931, 4.965905836529151, 5.0584429597102805, 5.149864987758545, 5.240217580603017, 5.329543283815009, 5.41788182125448, 5.50527035308316, 5.59174370404328, 5.67733456610044, 5.76207367889619, 5.845989990920297, 5.929110803871174, 6.011461902306914, 6.09306767038489, 6.173951197233098, 6.254134372282578, 6.333637971709893, 6.412481736986031, 6.490684446398417, 6.568263980302187, 6.645237380762316, 6.721620906167061, 6.797430081323295, 6.872679743484019, 6.947384084706118, 7.02155669089106, 7.095210577821777, 7.1683582244745, 7.241011603854195, 7.313182211575782, 7.384881092390064, 7.456118864832893, 7.5269057441579115, 7.597251563697303, 7.667165794780763, 7.736657565330329, 7.805735677237495, 7.874408622619027, 7.942684599039029, 8.010571523776767, 8.078077047212638, 8.145208565398272, 8.211973231870944, 8.27837796876729, 8.344429477286694, 8.410134247550396, 8.475498567898615, 8.540528533664496, 8.605230055460561, 8.66960886701049, 8.733670532556472, 8.797420453869995, 8.860863876891866, 8.924005898025191, 8.986851470103321, 9.04940540805317, 9.111672394272702, 9.173656983740175, 9.235363608871294, 9.29679658413943, 9.357960110472913, 9.418858279442441, 9.479495077250812, 9.53987438853626, 9.600000000000001, 9.659875603867842, 9.719504801195102, 9.7788911050234, 9.838037943397453, 9.896948662249375], [0.0, 0.623316600928143, 0.9447712982077369, 1.2049844612221832, 1.4320055082570027, 1.6371583832842145, 1.8264149102620693, 2.0033993001022528, 2.1705144721992813, 2.329454324856498, 2.481468083545264, 2.6275095596962563, 2.7683273368058203, 2.904522232388001, 3.0365855085003215, 3.1649251912745564, 3.2898847433630234, 3.411756648500595, 3.5307925111142886, 3.6472107081587293, 3.761202283496365, 3.872935555786535, 3.9825597682960567, 4.090208014141794, 4.195999605920192, 4.300042013908709, 4.402432465428257, 4.5032592753012235, 4.602602960859338, 4.700537182807047, 4.797129544180936, 4.892442272804966, 4.986532807425144, 5.079454303691364, 5.171256073034344, 5.2619839650416145, 5.351680702006776, 5.440386172791491, 5.528137691910307, 5.6149702287576035, 5.700916611092179, 5.786007706239372, 5.870272582932807, 5.953738656274442, 6.036431817924146, 6.118376553324198, 6.1995960475083125, 6.280112280830048, 6.3599461157643375, 6.439117375782667, 6.5176449171721655, 6.5955466945579175, 6.672839820792824, 6.749540621797897, 6.825664686865674, 6.901226914878917, 6.976241556844308, 7.050722255095314, 7.124682079478756, 7.198133560805007, 7.271088721811518, 7.343559105862746, 7.415555803586272, 7.487089477624348, 7.558170385661895, 7.628808401875983, 7.699013036937539, 7.76879345668341, 7.838158499565662, 7.907116692974917, 7.975676268525644, 8.043845176383256, 8.111631098705669, 8.179041462265623, 8.246083450314163, 8.312764013740534, 8.379089881579006, 8.445067570908952, 8.51070339619058, 8.576003478075327, 8.640973751726733, 8.705619974684746, 8.769947734303846, 8.833962454792955, 8.89766940388304, 8.961073699146223, 9.024180313988527, 9.086994083336714, 9.149519709038108, 9.211761764991058, 9.273724702022276, 9.335412852526234, 9.396830434880735, 9.457981557651705, 9.518870223599503, 9.579500333498055, 9.639875689777465, 9.700000000000001, 9.75987688017875, 9.819509857947514, 9.878902375590144, 9.938057792936807], [0.0, 0.6258790724605868, 0.9486552787606733, 1.2099381851793523, 1.4378925219250926, 1.6438887860121714, 1.83392335172987, 2.011635329219696, 2.1794375163432784, 2.3390307750660457, 2.491669466459315, 2.638311323098547, 2.7797080059272394, 2.9164628024366115, 3.0490689942758924, 3.1779362849834025, 3.3034095491957833, 3.425782473056512, 3.5453076953452625, 3.6622044907702698, 3.7766646885805084, 3.8888572993979116, 3.9989321800324342, 4.1070229707503705, 4.213249474645501, 4.317719603808523, 4.420530985264514, 4.5217722969005045, 4.621524387057168, 4.719861219260113, 4.816850674463853, 4.9125552363126275, 5.007032579684695, 5.100336078754273, 5.192515247672716, 5.283616124516458, 5.373681607211614, 5.462751748604041, 5.550864016609275, 5.638053524381828, 5.724353234636309, 5.809794141594474, 5.8944054334923015, 5.978214638135982, 6.061247753626702, 6.143529366067064, 6.225082755805086, 6.305929993556157, 6.386092027561418, 6.465588762787181, 6.54443913303929, 6.62266116675478, 6.700272047137956, 6.777288167226138, 6.853725180399869, 6.929598046791623, 7.004921075994362, 7.0797079664255556, 7.1539718416625195, 7.227725284030133, 7.300980365691646, 7.373748677466602, 7.446041355576454, 7.5178691064978675, 7.589242230085387, 7.660170641109091, 7.730663889338534, 7.800731178291569, 7.8703813827553795, 7.939623065176923, 8.00846449101106, 8.076913643106549, 8.144978235202865, 8.212665724604417, 8.27998332409279, 8.34693801313252, 8.413536548421126, 8.47978547382987, 8.545691129777873, 8.611259662078744, 8.67649703029564, 8.74140901563791, 8.806001228429801, 8.870279115179311, 8.934247965273185, 8.997912917322028, 9.06127896517767, 9.124350963643389, 9.187133633895929, 9.249631568637064, 9.311849236990971, 9.37379098916272, 9.43546106087197, 9.496863577575084, 9.558002558487875, 9.618881920420453, 9.679505481434818, 9.73987696433513, 9.8, 9.859878130565434, 9.9195148124666, 9.978913419346021], [0.0, 0.628425902968486, 0.9525155519535902, 1.2148616721887073, 1.4437436019548526, 1.6505781071542722, 1.8413859625549485, 2.0198210865850648, 2.188306095276364, 2.348548771750986, 2.5018085813331057, 2.6490471538087617, 2.7910192087842307, 2.9283304886514534, 3.0614762823240165, 3.1908679605080943, 3.316851801206066, 3.439722685630653, 3.559734280600617, 3.677106753098024, 3.7920327129644646, 3.9046818585608105, 4.0152046564951585, 4.123735290843495, 4.2303940522030015, 4.335289291780837, 4.4385190338664975, 4.540172317195551, 4.640330319097176, 4.739067304069761, 4.836451429289365, 4.932545432659014, 5.027407223747888, 5.121090393920688, 5.213644658812018, 5.305116243836702, 5.39554822148133, 5.484980807575013, 5.573451622497935, 5.660995922287245, 5.747646803789608, 5.833435387348634, 5.918390979973232, 6.002541221485887, 6.085912215779404, 6.1685286490022815, 6.25041389623506, 6.331590118003403, 6.412078347791144, 6.491898571561996, 6.571069800167345, 6.6496101354056405, 6.727536830403176, 6.804866344903908, 6.881614395985198, 6.957796004655375, 7.033425538736072, 7.108516752386432, 7.183082822586306, 7.257136382860637, 7.330689554496784, 7.403753975479718, 7.4763408273464655, 7.548460860140545, 7.620124415628721, 7.6913414489263126, 7.762121548662846, 7.83247395580718, 7.902407581259828, 7.971931022310105, 8.041052578046704, 8.109780263802236, 8.178121824704965, 8.246084748404606, 8.31367627703303, 8.38090341845565, 8.447772956864377, 8.514291462758823, 8.580465302358588, 8.646300646485846, 8.71180347895445, 8.776979604498674, 8.841834656272326, 8.906374102946364, 8.970603255431136, 9.034527273247308, 9.09815117056772, 9.161479821950836, 9.224517967784847, 9.287270219460169, 9.349741064286762, 9.411934870171574, 9.473855890070285, 9.535508266226577, 9.596896034211282, 9.658023126772818, 9.718893377509659, 9.779510524374821, 9.839878213021708, 9.9, 9.959879355809816, 10.01951966782172], [0.0, 0.6309573444801932, 0.956352499790037, 1.2197554094669347, 1.4495593273553913, 1.6572270086699934, 1.8488034812197072, 2.027957382241642, 2.1971210866122357, 2.3580092567898685, 2.51188643150958, 2.65971811421944, 2.8022620647068055, 2.9401264654308226, 3.073808600440717, 3.203721497536806, 3.3302128296074924, 3.453578665713643, 3.574073694501275, 3.6919189698347967, 3.807307877431757, 3.920410799236362, 4.0313788079702, 4.140346628233032, 4.2474350351797385, 4.352752816480621, 4.4563983912891585, 4.558461157009064, 4.659022617970136, 4.758157337824938, 4.855933748302038, 4.952414840026903, 5.047658755841546, 5.141719302988788, 5.234646397369045, 5.326486450603552, 5.417282708684606, 5.507075549439766, 5.595902744792604, 5.683799692799553, 5.770799623628854, 5.85693378298389, 5.942231595928824, 6.026720813625591, 6.110427645119373, 6.193376876000052, 6.275591975508274, 6.357095193437305, 6.437907647998605, 6.518049405663864, 6.597539553864471, 6.67639626731701, 6.754636868647265, 6.832277883902759, 6.909335093472795, 6.985823578873713, 7.06175776580398, 7.1371514638276, 7.212017903004273, 7.286369767749635, 7.360219228178332, 7.433577969155767, 7.506457217260721, 7.578867765840317, 7.650819998320296, 7.722323909917427, 7.793389127886403, 7.864024930420794, 7.934240264316234, 8.00404376149386, 8.07344375447297, 8.142448290873746, 8.21106514702358, 8.279301840734128, 8.347165643310207, 8.414663590846496, 8.481802494863159, 8.54858895232727, 8.615029355102994, 8.68112989886998, 8.746896591546225, 8.81233526124879, 8.877451563823099, 8.94225098996915, 9.00673887199084, 9.070920390192546, 9.134800578945333, 9.198384332443489, 9.261676410170553, 9.324681442092668, 9.387403933595694, 9.449848270181493, 9.512018721937608, 9.573919447793617, 9.635554499576546, 9.696927825876807, 9.758043275735478, 9.818904602162894, 9.879515465497972, 9.939879436616984, 10.0, 10.059880556662682], [0.0, 0.6334736424906476, 0.9601664943707598, 1.2246198716004426, 1.4553402621259737, 1.6638361353586175, 1.8561766270626276, 2.0360450052336923, 2.2058833452139233, 2.367413147644616, 2.521903994321694, 2.67032523918237, 2.8134376640082173, 2.9518518767287016, 3.0860671445934575, 3.216498142583933, 3.3434939301301188, 3.467351757035121, 3.5883273276594716, 3.7066425774444482, 3.822491663342136, 3.9360456467907703, 4.047456202999559, 4.156858593858532, 4.26437407618157, 4.370111871491119, 4.474170791442502, 4.57664058996196, 4.677603096423743, 4.777133171845005, 4.8752995208643926, 4.9721653853179975, 5.067789139925181, 5.162224806515471, 5.25552250005707, 5.3477288172637065, 5.438887176595447, 5.529038116909194, 5.618219560765351, 5.706467047390053, 5.793813939475562, 5.880291607335118, 5.965929593381905, 6.0507557594512615, 6.134796419111703, 6.218076456799626, 6.300619435352496, 6.382447693297171, 6.46358243306588, 6.54404380115668, 6.623850961122849, 6.703022160162896, 6.7815747899863394, 6.85952544254763, 6.936889961169266, 7.013683487513633, 7.089920504809803, 7.165614877695198, 7.240779888991838, 7.315428273701615, 7.389572250474365, 7.463223550775478, 7.536393445956046, 7.609092772407745, 7.681331954966079, 7.753121028709376, 7.824469659286435, 7.89538716189285, 7.965882519004645, 8.035964396967609, 8.105641161531656, 8.174920892411386, 8.243811396946684, 8.312320222930714, 8.38045467066672, 8.448221804309775, 8.515628462544814, 8.582681268648042, 8.64938663997478, 8.715750796913442, 8.781779771341984, 8.84747941462037, 8.912855405149894, 8.977913255527815, 9.042658319323596, 9.107095797501, 9.171230744508481, 9.235068074058685, 9.298612564616276, 9.361868864611997, 9.42484149739947, 9.487534865970218, 9.549953257441167, 9.612100847327971, 9.673981703616596, 9.735599790644688, 9.796958972803541, 9.858063018070737, 9.918915601382857, 9.979520307857053, 10.039880635869725, 10.100000000000001]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha = 0.7000000000000001\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.1, 0.1624504792712471, 0.21576692799745933, 0.2639015821545789, 0.30851693136000485, 0.3505144086407194, 0.3904528777122723, 0.42870938501451733, 0.46555367217460797, 0.5011872336272724, 0.5357656669484114, 0.5694123367516263, 0.6022271719754775, 0.6342925711719627, 0.6656775051475127, 0.6964404506368994, 0.7266315402400413, 0.7562941717125412, 0.7854662349940812, 0.8141810630738089, 0.8424681795174463, 0.870353893728488, 0.8978617804534154, 0.9250130700826243, 0.9518269693579395, 0.9783209271758406, 1.004510856630514, 1.0304113218507696, 1.0560356962676238, 1.081396297513015, 1.1065045030620493, 1.1313708498984765, 1.1560051208396867, 1.1804164196559919, 1.2046132367247346, 1.2286035066475318, 1.2523946590098145, 1.275993663261705, 1.299407068537464, 1.3226410390991374, 1.3457013859823745, 1.3685935953338422, 1.3913228538564615, 1.4138940717178896, 1.4363119032269174, 1.4585807655399257, 1.4807048556237306, 1.5026881656709001, 1.5245344971379464, 1.5462474735549592, 1.5678305522365594, 1.5892870350080617, 1.6106200780469584, 1.6318327009279805, 1.6529277949497028, 1.673908130811768, 1.6947763657040338, 1.7155350498622066, 1.736186632638589, 1.7567334681314142, 1.777177820411657, 1.7975218683822303, 1.8177677103009149, 1.8379173679952565, 1.857972790794882, 1.8779358592042303, 1.8978083883364982, 1.9175921311276543, 1.9372887813476267, 1.956899976424214, 1.9764273000938701, 1.9958722848922639, 2.0152364144963837, 2.034521125928945, 2.0537278116349444, 2.072857821439383, 2.091912464394421, 2.1108930105235726, 2.1298006924699164, 2.1486367070547514, 2.1674022167526235, 2.1860983510881824, 2.204726207959916, 2.2232868548954188, 2.241781330242514, 2.2602106443002143, 2.2785757803932327, 2.2968776958934622, 2.315117323191634, 2.333295570622098, 2.3514133233434866, 2.3694714441778344, 2.387470774410537, 2.4054121345533783, 2.423296325072704, 2.4411241270846893, 2.4588963030195052, 2.476613597256091, 2.4942767367291094, 2.511886431509581, 2.5294433753605845], [0.0, 0.12311444133449163, 0.19999999999999998, 0.26564024798866687, 0.32490095854249423, 0.379828896466187, 0.4315338559949187, 0.4807038790699098, 0.5278031643091577, 0.5731638026099791, 0.6170338627200097, 0.6596049077255498, 0.7010288172814388, 0.7414286183421172, 0.7809057554245447, 0.819545141551742, 0.8574187700290347, 0.8945883613267386, 0.9311073443492159, 0.9670223670840282, 1.0023744672545447, 1.037199992633766, 1.0715313338968229, 1.105397514961142, 1.1388246735032523, 1.17183645579605, 1.204454343950955, 1.2366979292849736, 1.2685851423439254, 1.3001324477526939, 1.3313550102950253, 1.3622668372858349, 1.392880901273799, 1.423209246319895, 1.4532630804800826, 1.4830528566349943, 1.5125883434250824, 1.5418786877429445, 1.5709324699881624, 1.5997577530907934, 1.628362126147618, 1.6567527433827114, 1.6849363590348927, 1.712919358684488, 1.740707787456976, 1.7683073754786232, 1.7957235609068305, 1.8229615108138468, 1.8500261401652487, 1.8769221291029838, 1.903653938715879, 1.930225825457515, 1.9566418543516815, 1.982905911108666, 2.0090217132610286, 2.0349928204148577, 2.0608226437015396, 2.086514454505522, 2.112071392535248, 2.1374964732971216, 2.16279259502603, 2.1879625451203064, 2.2130090061240986, 2.2379345612957517, 2.2627416997969525, 2.2874328215339816, 2.3120102416793737, 2.336476194899599, 2.3608328393119837, 2.3850822601919117, 2.4092264734494693, 2.4332674288929446, 2.4572070132950636, 2.481047053276463, 2.504789318019629, 2.5284355218254424, 2.5519873265234105, 2.5754463437457873, 2.598814137074928, 2.6220922240724716, 2.645282078198275, 2.6683851306263793, 2.6914027719647495, 2.7143363538849723, 2.7371871906676843, 2.7599565606690057, 2.7826457077129225, 2.805255842414161, 2.8277881434357792, 2.850243758685417, 2.8726238064538343, 2.8949293764991366, 2.9171615310798518, 2.9393213059397936, 2.9614097112474616, 2.9834277324925256, 3.0053763313418003, 3.027256446456932, 3.049068994275893, 3.0708148697602313, 3.0924949471099183, 3.1141100804474915], [0.0, 0.13903891703159096, 0.2258693870913711, 0.30000000000000004, 0.3669259018569607, 0.42895860022204757, 0.48735143781374146, 0.5428814526898255, 0.5960728861369785, 0.647300783992378, 0.6968453019359491, 0.7449227811521516, 0.7917047464637369, 0.8373301379846806, 0.8819135217693302, 0.9255507940800147, 0.9683232603354767, 1.0103006243597223, 1.0515432259221582, 1.0921037467845818, 1.1320285327741184, 1.1713586331368169, 1.2101306281823736, 1.2483772959829893, 1.2861281550435522, 1.323409910209892, 1.3602468222387083, 1.396661016523824, 1.432672742872211, 1.4683005955575252, 1.5035617008818172, 1.5384718779632605, 1.573045777309948, 1.6072970008452345, 1.6412382063527708, 1.6748811987612662, 1.7082370102548787, 1.7413159708487322, 1.7741277707908, 1.8066815159264324, 1.8389857769788218, 1.8710486335490033, 1.9028777135158883, 1.9344802284150486, 1.9658630052904194, 1.9970325154425383, 2.0279949004378013, 2.058755995693417, 2.089321351910699, 2.1196962545936113, 2.149885741859151, 2.179894620720124, 2.2097274819986903, 2.239388714009856, 2.268882515137624, 2.298212905412223, 2.327383737184429, 2.356398704982244, 2.3852613546257757, 2.4139750916679406, 2.442543189221427, 2.470968795226, 2.4992549392046723, 2.5274045385523394, 2.555420404396125, 2.583305247062831, 2.6110616811854643, 2.638692230477757, 2.6661993322028956, 2.693585341360246, 2.7208525346116854, 2.748003113967229, 2.7750392102478734, 2.8019628863420354, 2.8287761402705356, 2.855480908073819, 2.8820790665339473, 2.9085724357428684, 2.9349627815275223, 2.9612518177414966, 2.9874412084321635, 3.013532569891543, 3.039527472598476, 3.0654274430591286, 3.091233965552309, 3.1169484837855848, 3.142572402467762, 3.1681070888028726, 3.1935538739104286, 3.2189140541764054, 3.244188892539045, 3.2693796197133254, 3.294487435357659, 3.3195135091861485, 3.3444589820294923, 3.3693249668474294, 3.3941125496954294, 3.4188227906481465, 3.443456724681996, 3.4680153625190604, 3.492499691434397, 3.5169106760286764], [0.0, 0.1515716566510398, 0.24622888266898324, 0.32704150727080533, 0.4, 0.4676242239113107, 0.5312804959773337, 0.5918158951901497, 0.6498019170849885, 0.7056474135148042, 0.7596577929323739, 0.8120688971611996, 0.8630677119898374, 0.9128057013659376, 0.9614077581398196, 1.0089784225053957, 1.0556063286183155, 1.1013674632907975, 1.1463276052199582, 1.1905441848150782, 1.2340677254400194, 1.2769429764524494, 1.3192098154510996, 1.3609039750697633, 1.4020576345628775, 1.4426999059072139, 1.4828572366842343, 1.5225537466344214, 1.5618115108490889, 1.6006507996591803, 1.6390902831034837, 1.6771472062095034, 1.7148375400580695, 1.7521761126275677, 1.789176722653477, 1.825852239141392, 1.8622146886984319, 1.8982753324703165, 1.9340447341680564, 1.969532820422946, 2.0047489345090894, 2.0397018843094887, 2.074399985267532, 2.108851098954764, 2.1430626677936457, 2.177041746397118, 2.210795029922284, 2.2443288797812757, 2.2776493470065047, 2.3107621935285843, 2.3436729115921, 2.376386741506099, 2.40890868790191, 2.441243534650045, 2.4733958585699476, 2.5053700420507665, 2.5371702846878508, 2.5688006140278885, 2.600264895505388, 2.631566841644212, 2.6627100205900507, 2.6936978640327895, 2.7245336745716697, 2.7552206325707704, 2.7857618025475976, 2.8161601391333604, 2.84641849263979, 2.876539614264029, 2.9065261609601647, 2.9363807000033377, 2.966105713269988, 2.9957036012556966, 3.025176686850165, 3.054527218887184, 3.083757375485889, 3.1128692671982314, 3.141864939976325, 3.170746377972217, 3.1995155061815868, 3.2281741929419696, 3.2567242522952355, 3.2851674462233116, 3.3135054867654223, 3.341740038024493, 3.3698727180697854, 3.3979051007422956, 3.4258387173689755, 3.453675058391381, 3.481415574913952, 3.509061680176767, 3.536614750957246, 3.5640761289049934, 3.5914471218136614, 3.6187290048334604, 3.645923021627694, 3.6730303854764643, 3.7000522803304974, 3.7269898618178354, 3.7538442582059677, 3.780616571321805, 3.8073078774317577, 3.8339192280840164], [0.0, 0.16206565966927625, 0.2632764408668475, 0.3496840952072148, 0.42769383999647526, 0.5, 0.5680634885994444, 0.6327900319620665, 0.6947906928878748, 0.754502629924318, 0.8122523963562356, 0.8682921624214405, 0.9228218597947637, 0.9760034389696842, 1.027970439703055, 1.0788346399872968, 1.1286908105283713, 1.1776201990550452, 1.2256931384262186, 1.2729710352225851, 1.3195079107728944, 1.3653516126386918, 1.4105447793283055, 1.4551256174101361, 1.4991285340564295, 1.5425846568000243, 1.5855222643101057, 1.6279671462477403, 1.6699429060643587, 1.7114712174991589, 1.7525720432035967, 1.793263822157757, 1.8335636311938628, 1.8734873248994521, 1.9130496573599354, 1.9522643885613615, 1.9911443777681825, 2.0297016657870386, 2.0679475477032456, 2.105892637414445, 2.1435469250725867, 2.1809198283709286, 2.218020238469256, 2.2548565612318745, 2.2914367543543874, 2.32776836087304, 2.36385853948146, 2.399714092021603, 2.435341488466691, 2.470746889672296, 2.505936168136362, 2.540914926978637, 2.575688517324096, 2.610262054252615, 2.644640431457899, 2.6788283347420574, 2.712830254457743, 2.746650496997228, 2.780293195416832, 2.813762319275523, 2.847061683758131, 2.8801949581462174, 2.913165673693161, 2.945977230954276, 2.9786329066177117, 3.0111358598773874, 3.0434891383852265, 3.0756956838164053, 3.1077583370781654, 3.1396798431899136, 3.1714628558598137, 3.2031099417807964, 3.234623584666904, 3.266006189049034, 3.2972600838475308, 3.3283875257375635, 3.359390702321924, 3.3902717351246316, 3.4210326824176724, 3.4516755418921834, 3.4822022531844974, 3.5126147002666555, 3.5429147137102337, 3.5731040728316565, 3.6031845077265645, 3.633157701200206, 3.6630252906003413, 3.6927888695586515, 3.7224499896462118, 3.7520101619482116, 3.7814708585627064, 3.8108335140278724, 3.840099526681934, 3.869270259959615, 3.898347043628751, 3.9273311749704063, 3.956223919905663, 3.9850265140720063, 4.013740163852076, 4.042366047357327, 4.070905315369044, 4.099359092238938], [0.0, 0.1711769859409705, 0.2780778340631818, 0.3693433240034749, 0.45173877418274216, 0.5281099842196291, 0.6000000000000001, 0.668365467587651, 0.7338518037139213, 0.7969207439660005, 0.8579172004440949, 0.917107520388829, 0.9747028756274828, 1.0308743215051672, 1.085762905379651, 1.139486689398561, 1.1921457722739568, 1.2438259694793528, 1.2946015679847558, 1.3445374266468886, 1.393690603871898, 1.4421116372097291, 1.4898455623043032, 1.53693273369609, 1.5834094929274733, 1.6293087175202057, 1.674660275969361, 1.7194914078299375, 1.7638270435386598, 1.8076900753316603, 1.851101588160029, 1.8940810576427296, 1.9366465206709533, 1.9788147231766495, 2.0206012487194442, 2.062020630871369, 2.103086451844316, 2.1438114293786956, 2.184207493569163, 2.2242858550263516, 2.2640570655482364, 2.3035310722904945, 2.3427172662736333, 2.3816245259393845, 2.4202612563647468, 2.4586354246552258, 2.496754591965978, 2.534625942538301, 2.572256310087104, 2.6096522018310675, 2.6468198204197835, 2.6837650839802154, 2.720493644477416, 2.75701090456089, 2.793322033047648, 2.829431979175446, 2.865345485744422, 2.901067101252085, 2.9366011911150505, 2.9719519480607666, 3.0071234017636344, 3.042119427792108, 3.0769437559265205, 3.1115999779012986, 3.146091554619895, 3.180421822886012, 3.214594001690469, 3.248611198089326, 3.2824764127055412, 3.3161925448834255, 3.3497623975225315, 3.3831886816151866, 3.416474020509757, 3.449620953919793, 3.4826319416974645, 3.51550936738815, 3.5482555415815997, 3.580872705073847, 3.6133630318528644, 3.645728631919921, 3.677971553957643, 3.710093787854921, 3.742097267098006, 3.773983871036437, 3.8057554270317757, 3.837413712496529, 3.8689604568300964, 3.9003973432580823, 3.9317260105808387, 3.962948054836716, 3.994065030885076, 4.025078453913786, 4.055989800875603, 4.086800511857504, 4.117511991386834, 4.1481256096777575, 4.178642703821397, 4.209064578922741, 4.239392509187223, 4.269627738959685, 4.299771483718301, 4.329824931025797], [0.0, 0.17927899625209973, 0.2912395886442171, 0.38682478275783583, 0.47312010758013934, 0.5531060578099961, 0.6283987135300648, 0.7000000000000001, 0.7685858822925762, 0.834639950489428, 0.8985234417906398, 0.9605153099684796, 1.0208367218639414, 1.0796668290750424, 1.13715335489873, 1.1934199495044802, 1.2485714493954332, 1.302697731793518, 1.3558765997593754, 1.4081759819965476, 1.4596556375533996, 1.5103684959822152, 1.5603617245174999, 1.6096775877281142, 1.6583541472448604, 1.7064258367216947, 1.7539239383650824, 1.800876981010554, 1.847311075082052, 1.8932501963324684, 1.938716427688703, 1.983730166573926, 2.028310303586838, 2.0724743772642626, 2.1162387087542354, 2.159618519520034, 2.202628034635794, 2.2452805737877024, 2.287588631735982, 2.3295639497027985, 2.371217578915275, 2.412559937339795, 2.4536008604850355, 2.494349647019932, 2.534815099843775, 2.575005563154647, 2.6149289559861706, 2.6545928026183265, 2.694004260213879, 2.7331701439859057, 2.7720969501627817, 2.8107908769834555, 2.849257843927209, 2.887503509357372, 2.9255332867372115, 2.963352359557792, 3.000965695101622, 3.0383780571520065, 3.0755940177459222, 3.1126179680575925, 3.1494541284906994, 3.1861065580489623, 3.2225791630476515, 3.258875705222256, 3.2949998092849055, 3.3309549699741887, 3.3667445586395885, 3.4023718293978247, 3.4378399248949063, 3.4731518817045597, 3.508310635390907, 3.543319025260765, 3.5781797988286987, 3.6128956160159205, 3.6474690531023297, 3.6819026064493414, 3.716198696009667, 3.7503596686388807, 3.7843878012223904, 3.818285303630335, 3.8520543215119267, 3.8856969389398617, 3.9192151809145965, 3.9526110157375176, 3.985886357261383, 4.0190430670257475, 4.05208295628454, 4.085007787932435, 4.117819278336154, 4.1505190990764405, 4.183108878605999, 4.215590203828342, 4.2479646216021525, 4.280233640175443, 4.312398730553503, 4.344461327804363, 4.376422832305262, 4.408284610933356, 4.440047998203739, 4.4717142973575745, 4.503284781403063, 4.534760694111687], [0.0, 0.18660659830736148, 0.3031433133020796, 0.40263532460835283, 0.49245776533796654, 0.5757129508131624, 0.6540830145416108, 0.7286108330920733, 0.8, 0.8687538709400412, 0.9352484478226214, 0.9997740859911782, 1.0625609919546677, 1.1237956397060622, 1.1836317903802993, 1.2421981480530846, 1.299603834169977, 1.3559423994703275, 1.4112948270296084, 1.465731821975361, 1.519315585864748, 1.5721012116194621, 1.6241377943223994, 1.6754693260060285, 1.726135423979675, 1.7761719292909026, 1.8256114027318753, 1.8744835391863393, 1.922815516279639, 1.9706322897164728, 2.0179568450107914, 2.0648104132818648, 2.1112126572366314, 2.1571818322578427, 2.202734926581595, 2.247887783812231, 2.292655210439917, 2.337051070561294, 2.3810883696301564, 2.4247793287631665, 2.468135450880039, 2.5111675797567257, 2.553885952904899, 2.596300249054445, 2.638419630902199, 2.680252783695472, 2.7218079501395267, 2.763092962051372, 2.804115269125755, 2.8448819651313606, 2.8853998118144277, 2.925675260752164, 2.9657144733684686, 3.0055233392987994, 3.045107493268844, 3.084472330632519, 3.1236230216981786, 3.162564524957426, 3.201301599318361, 3.239838815433998, 3.278180566206968, 3.316331076543103, 3.3542944124190073, 3.392074489322151, 3.4296750801161386, 3.467099822378679, 3.504352225255136, 3.5414356758665, 3.5783534453069543, 3.6151086942629442, 3.6517044782827845, 3.688143752723198, 3.724429377396864, 3.760564120942941, 3.796550664940634, 3.832391607784186, 3.868089468336114, 3.9036466893741233, 3.9390656408458926, 3.9743486229447402, 4.00949786901818, 4.044515548320416, 4.0794037686189775, 4.114164578664883, 4.148799970535064, 4.183311881855072, 4.217702197909528, 4.251972753647227, 4.286125335587292, 4.320161683632352, 4.354083492794236, 4.387892414837358, 4.4215900598445685, 4.4551779977099235, 4.488657759562552, 4.522030839125473, 4.55529869401301, 4.58846274697017, 4.6215243870571685, 4.654484970782053, 4.6873458231842005, 4.720108238871291], [0.0, 0.19331820449317624, 0.3140463497177344, 0.4171167510947728, 0.5101698002503163, 0.5964193922626064, 0.6776081612741134, 0.7548164925853019, 0.8287732856038028, 0.8999999999999999, 0.9688861611972633, 1.0357325676355595, 1.1007777055708823, 1.1642147558330256, 1.2262030098232404, 1.2868758006661425, 1.3463461745354395, 1.4047110468731592, 1.4620543134412238, 1.5184492223907102, 1.5739602124577423, 1.628644358069476, 1.6825525200923603, 1.7357302728030066, 1.7882186584109354, 1.8400548070445835, 1.8912724505973295, 1.941902351977134, 1.991972666296311, 2.0415092468315827, 2.0905359058078465, 2.139074637955696, 2.187145813182923, 2.2347683434564547, 2.2819598280216, 2.328736680323392, 2.37511423939121, 2.4211068679662104, 2.4667280392642335, 2.511990413954041, 2.5569059086763417, 2.601485757220914, 2.6457405653079897, 2.6896803597785297, 2.733314632880486, 2.7766523822400435, 2.819702147024609, 2.862472040735074, 2.9049697810064297, 2.947202716746151, 2.989177852897547, 3.0309018730791664, 3.072381160320422, 3.1136218160869737, 3.1546296777664744, 3.1954103347654153, 3.2359691433505975, 3.2763112403537447, 3.3164415558447335, 3.3563648248674585, 3.3960855983223546, 3.4356082530707797, 3.474937001328722, 3.51407589941045, 3.5530288558766725, 3.5917996391364237, 3.6303918845471204, 3.6688091010530037, 3.707054677398415, 3.745131887948967, 3.7830438981506798, 3.82079376965443, 3.858384465130656, 3.8958188527970723, 3.9330997106801893, 3.970229730629675, 4.007211522102985, 4.0440476157362495, 4.080740466716124, 4.117292457966077, 4.153705903159553, 4.189983049571471, 4.226126080778607, 4.2621371192186, 4.298018228616632, 4.333771416288069, 4.369398635324825, 4.404901786672576, 4.440282721105478, 4.4755432411045515, 4.510685102645451, 4.545710016900952, 4.580619651863123, 4.615415633889781, 4.650099549179576, 4.684672945179675, 4.719137331929843, 4.7534941833463975, 4.787744938449339, 4.821891002535703, 4.855933748302039, 4.889874516918674], [0.0, 0.19952623149688795, 0.32413131933855244, 0.4305116202499342, 0.526552881733695, 0.6155722066724582, 0.6993681904144295, 0.7790559126704492, 0.8553876799929504, 0.928901697685371, 1.0, 1.068993044916333, 1.1361269771988889, 1.2016011812929526, 1.265580063924133, 1.3282012399433343, 1.3895813857757495, 1.4498205291087471, 1.509005259848636, 1.5672111783641802, 1.6245047927124712, 1.6809450101515975, 1.736584324842881, 1.7914697745895611, 1.8456437195895272, 1.899144482330935, 1.9520068779393682, 2.0042626572119717, 2.0559408794061094, 2.1070682280247115, 2.157669279974593, 2.207766736303074, 2.2573816210567426, 2.3065334535224724, 2.3552403981100904, 2.403519395349549, 2.4513862768524373, 2.4988558665905827, 2.5459420704451703, 2.5926579556569855, 2.639015821545789, 2.685027262652022, 2.7307032252773835, 2.776054058254751, 2.821089558656611, 2.865819013049896, 2.9102512348202723, 2.954394598017465, 2.998257068112859, 3.041846230009375, 3.0851693136000486, 3.1282332171344542, 3.1710445286202114, 3.2136095454593314, 3.255934292495481, 3.298024538627749, 3.339885812128718, 3.3815234147891746, 3.422942434998318, 3.4641477598564947, 3.5051440864071934, 3.5459359320659103, 3.586527644315514, 3.626923409730683, 3.667127262387725, 3.7071430917105856, 3.7469746497989043, 3.7866255582796393, 3.8260993147198703, 3.865399298634905, 3.9045287771227226, 3.9434909101529874, 3.982288755536365, 4.020925273597639, 4.059403331574077, 4.09772570775871, 4.135895095406491, 4.173914106419866, 4.21178527482889, 4.249511060079848, 4.287093850145173, 4.32453596446652, 4.361839656741857, 4.3990071175666605, 4.436040476938512, 4.472941806633692, 4.509713122463748, 4.546356386419422, 4.582873508708775, 4.619266349695895, 4.6555367217460795, 4.691686390982991, 4.72771707896292, 4.7636304642709115, 4.799428184043207, 4.8351118354201414, 4.870682976933382, 4.906143129831117, 4.941493779344592, 4.9767363758991445, 5.011872336272724, 5.0469030447046554], [0.0, 0.2053136413658844, 0.3335329944081286, 0.44299893673488966, 0.5418259479437468, 0.6334273460055121, 0.7196538958923571, 0.8016530210489499, 0.8801988492505946, 0.9558451968542797, 1.029005759421095, 1.1, 1.1690812029713358, 1.2364545360776396, 1.3022891747864505, 1.3667267255719309, 1.429887249147593, 1.4918736745798402, 1.5527751033809727, 1.6126693287658624, 1.671624787908305, 1.729702096716145, 1.7869552719837183, 1.8434327158814694, 1.899178017296996, 1.954230610291326, 2.0086263198292005, 2.0623978176637467, 2.1155750059381577, 2.1681853421306294, 2.2202541160198237, 2.271804687114177, 2.322858689278716, 2.373436207972053, 2.423555934476516, 2.4732353006949936, 2.522490597446993, 2.571337078684901, 2.6197890536405475, 2.66785996857996, 2.7155624795740096, 2.762908517471588, 2.809909346080188, 2.856575614408443, 2.9029174037003678, 2.9489442698868213, 2.9946652819924138, 3.0400890569625427, 3.0852237913131386, 3.1300772899529923, 3.1746569924836767, 3.2189699972437347, 3.263023083330949, 3.3068227308082596, 3.3503751392744983, 3.3936862449600533, 3.436761736489252, 3.479607069435349, 3.522227479780137, 3.5646279963780176, 3.6068134525137947, 3.6487884966340305, 3.690557602323637, 3.7321250775920687, 3.7734950735270822, 3.8146715923683177, 3.8556584950479134, 3.896459508240868, 3.9370782309638517, 3.9775181407575784, 4.017782599484687, 4.05787485877216, 4.097798065124785, 4.1375552647338125, 4.177149408002907, 4.216583353811596, 4.255859873534739, 4.294981654834995, 4.333951305243888, 4.372771355545806, 4.41144426297814, 4.449972414259709, 4.488358128458703, 4.526603659710484, 4.56471119979483, 4.602682880581467, 4.640520776352087, 4.678226906006463, 4.715803235159691, 4.753251678137135, 4.79057409987312, 4.827772317719069, 4.864848103166321, 4.901803183488553, 4.938639243308388, 4.975357926092427, 5.011960835578734, 5.048449537140456, 5.084825559089099, 5.121090393920688, 5.1572454995078925, 5.193292300240951], [0.0, 0.2107435899344471, 0.34235397188194094, 0.4547149699531194, 0.5561556681263637, 0.6501796567036683, 0.7386866480069498, 0.8228544114931993, 0.9034775483654843, 0.9811245218124158, 1.0562199684392581, 1.1290918001633157, 1.2000000000000002, 1.2691551617818178, 1.336730935175302, 1.4028726717339322, 1.4677036074278427, 1.5313293934978294, 1.5938414879320009, 1.655319741349467, 1.7158344008881898, 1.7754476855704486, 1.834215040777658, 1.8921861487768712, 1.9494057512549654, 2.0059143251891713, 2.0617486430103344, 2.1169422405444123, 2.1715258107593014, 2.2255275373036243, 2.2789733787971214, 2.3318873125392767, 2.384291544547914, 2.4362066914835987, 2.4876519389587055, 2.538645179899245, 2.589203135969512, 2.63934146454456, 2.689074853293777, 2.7384171040978127, 2.787381207743796, 2.8359794106168668, 2.8842232744194582, 2.932123729795508, 2.9796911246086064, 3.026935267516187, 3.07386546739218, 3.120490569075122, 3.1668189858549467, 3.2128587290575785, 3.258617435040411, 3.304102389872392, 3.349320551938722, 3.3942785726811535, 3.4389828156598754, 3.4834393741013, 3.5276540870773205, 3.5716325544452343, 3.615380150663321, 3.6589020375845536, 3.702203176320058, 3.745288338254287, 3.788162115285459, 3.8308289293573483, 3.873293041341906, 3.9155585593263686, 3.957629446353299, 3.999509527657409, 4.0412024974388885, 4.082711925209289, 4.124041261742737, 4.16519384466229, 4.206172903688632, 4.246981565575913, 4.287622858757391, 4.328099717721641, 4.368414987138327, 4.4085714257509645, 4.448571710052702, 4.488418437759815, 4.528114131096473, 4.567661239903265, 4.607062144580989, 4.64631915888033, 4.685434532547267, 4.7244104538332765, 4.763249051878768, 4.801952398977542, 4.840522512729494, 4.8789613580883255, 4.9172708493104516, 4.955452851810952, 4.993509183931957, 5.031441618628511, 5.069251885076603, 5.106941670207745, 5.144512620174209, 5.181966341748705, 5.219304403662135, 5.256528337882703, 5.293639640839567, 5.330639774593947], [0.0, 0.21586538444215797, 0.35067435160700566, 0.46576610862074974, 0.5696721648669191, 0.665981259949423, 0.7566392757374455, 0.8428526055390655, 0.9254351621011989, 1.0049692242243011, 1.0818897486445278, 1.1565326166672798, 1.2291641297899731, 1.3, 1.3692180972484058, 1.436967305631644, 1.5033738561780403, 1.5685459678171387, 1.6325773212809114, 1.6955497078333173, 1.7575350818595261, 1.818597174518185, 1.8787927787042915, 1.9381727841349692, 1.996783019874065, 2.054664946628657, 2.1118562305262127, 2.1683912224286734, 2.2243013612486853, 2.279615515594526, 2.3343602749697316, 2.388560199404682, 2.442238034599856, 2.495414898271622, 2.5481104423087633, 2.600342994496971, 2.652129682894528, 2.7034865454045893, 2.754428626657454, 2.8049700639669712, 2.8551241638411056, 2.904903470294301, 2.95431982601815, 3.003384427308854, 3.0521078735187026, 3.1005002116892606, 3.148570976932131, 3.1963292290458662, 3.2437835857923, 3.2909422532001473, 3.337813053216567, 3.384403448987057, 3.4307205680095256, 3.4767712233786514, 3.5225619333110343, 3.56809893911946, 3.613388221785363, 3.6584355172618457, 3.7032463306250185, 3.747825949178647, 3.7921794546059315, 3.836311734252387, 3.880227491615162, 3.9239312561064823, 3.9674273921521515, 4.010720107680063, 4.053813462048354, 4.0967113734581035, 4.139417625891281, 4.181935875610852, 4.224269657256628, 4.266422389567396, 4.308397380757167, 4.350197833570979, 4.391826850043437, 4.43328743598129, 4.474582505189464, 4.515714883458437, 4.556687312329352, 4.597502452651927, 4.638162887949062, 4.678671127600904, 4.719029609860181, 4.759240704709683, 4.799306716571958, 4.839229886880525, 4.879012396521233, 4.918656368151752, 4.958163868406602, 4.997536909994618, 5.036777453695235, 5.07588741025954, 5.1148686422216345, 5.153722965625472, 5.192452151671968, 5.231057928290879, 5.269541981641637, 5.307905957547064, 5.346151462863618, 5.384280066791604, 5.422293302128559, 5.460192666468822], [0.0, 0.22071833466585675, 0.3585579925041994, 0.4762371702356704, 0.5824791772884342, 0.680953433060007, 0.7736495655156717, 0.8618010893414415, 0.9462402151602786, 1.0275623121995368, 1.1062121156199922, 1.182533057799954, 1.2567974270601296, 1.3292257848895588, 1.4000000000000001, 1.4692723036068127, 1.5371717645851524, 1.6038090347746836, 1.669279900978856, 1.7336679932415409, 1.7970468835812796, 1.859481735920668, 1.9210306199369591, 1.981745569417989, 2.0416734437278827, 2.1008566356673386, 2.1593336581500844, 2.2171396342926024, 2.2743067097974596, 2.3308644022788845, 2.38683989900896, 2.442258312161269, 2.497142898790867, 2.551515251369381, 2.605395463587036, 2.6588022752633087, 2.7117531995187507, 2.7642646348105977, 2.816351963993095, 2.868029642206318, 2.919311275106799, 2.97020968871565, 3.0207369919644305, 3.070904632857453, 3.1207234490349998, 3.1702037134099235, 3.219355175456228, 3.2681870986491766, 3.316708294489721, 3.3649271534893685, 3.412851673443389, 3.460489485279039, 3.507847876730165, 3.5549338140591686, 3.6017539620211085, 3.648314702242051, 3.694622150164105, 3.7406821706924736, 3.786500392664937, 3.8320822222511097, 3.8774328553774065, 3.9225572892635796, 3.967460333147852, 4.012146618269854, 4.0566206071736755, 4.100886602387206, 4.144948754528525, 4.188811069885254, 4.23247741750847, 4.275951535858952, 4.319237039040068, 4.362337422648545, 4.405256069271588, 4.44799625365634, 4.490561147575405, 4.532953824410193, 4.575177263471964, 4.617234354078849, 4.659127899405597, 4.700860620121484, 4.74243515783055, 4.783854078327253, 4.82511987467959, 4.86623497015082, 4.907201720970071, 4.948022418961367, 4.988699294039864, 5.029234516583492, 5.069630199687551, 5.109888401309335, 5.150011126309294, 5.19000032839482, 5.229857911972341, 5.269585733912971, 5.309185605236654, 5.348659292719378, 5.388008520427758, 5.42723497118497, 5.466340287971812, 5.505326075266366, 5.5441939003255625, 5.582945294411717], [0.0, 0.2253343380842655, 0.3660567121805816, 0.48619697900782877, 0.5946608833419245, 0.6951945851579547, 0.7898293226005426, 0.8798244075239154, 0.966029455027588, 1.0490522856216442, 1.1293469354568555, 1.2072640193009534, 1.2830815199894259, 1.3570246117345335, 1.4292789667680108, 1.5000000000000002, 1.5693194795937333, 1.6373503715114004, 1.704190465798333, 1.7699251414993142, 1.8346295092848035, 1.8983700958861995, 1.96120618542372, 2.0231908998963046, 2.0843720786636246, 2.1447930011102376, 2.20449298559153, 2.263507889772954, 2.321870531637762, 2.3796110461182147, 2.4367571890687065, 2.4933345978474604, 2.5493670158970607, 2.6048764872643217, 2.659883525869815, 2.7144072634491274, 2.7684655793842907, 2.8220752150824593, 2.8752518751079346, 2.928010316909053, 2.9803644306848924, 3.032327310694171, 3.0839113191091645, 3.13512814335257, 3.1859888477181766, 3.23650391996189, 3.286683313453804, 3.3365364854013126, 3.386072431585114, 3.435299717992077, 3.484226509679745, 3.532860597165136, 3.5812094205944645, 3.6292800919193944, 3.6770794152786563, 3.724613905760758, 3.7718898067033986, 3.8189131056677557, 3.8656895492105776, 3.912224656563663, 3.9585237323186835, 4.004591878204985, 4.050434004039021, 4.096054837916076, 4.141458935707865, 4.186650689923402, 4.231634337984917, 4.2764139699657155, 4.320993535832461, 4.365376852230408, 4.40956760884665, 4.4535693743832425, 4.497385602169289, 4.541019635438512, 4.584474712296534, 4.627753970400073, 4.67086045136836, 4.713797104945415, 4.756566792930317, 4.799172292891189, 4.841616301677384, 4.883901438743221, 4.926030249295599, 4.9680052072768035, 5.009828718193076, 5.051503121798611, 5.093030694644001, 5.134413652497478, 5.175654152646661, 5.216754296088034, 5.25771612961079, 5.298541647781275, 5.33923279483381, 5.3797914664732716, 5.420219511594457, 5.460518733922909, 5.500690893581589, 5.540737708587477, 5.58066085628193, 5.620461974698356, 5.660142663870591, 5.699704487085076], [0.0, 0.22973967099940698, 0.3732131966147229, 0.4957022305068904, 0.6062866266041592, 0.7087857830839414, 0.8052706492167057, 0.8970251566638912, 0.984915530675933, 1.0695614747796018, 1.1514259016263246, 1.2308662805750588, 1.3081660290832213, 1.3835547235654946, 1.4572216661841464, 1.529325310242956, 1.6, 1.6693609099253943, 1.7375077418800822, 1.804527544086831, 1.8704968956452428, 1.9354836238980746, 1.9995481719823565, 2.062744700443094, 2.125121983909335, 2.1867241478865562, 2.247591279412124, 2.3077599371762676, 2.367263580760598, 2.4261329342415356, 2.4843962961061687, 2.542079804928375, 2.599207668339954, 2.655802361353393, 2.7118847989406545, 2.7674744868667127, 2.822589654059217, 2.8772473692232925, 2.931463643950722, 2.985253524201008, 3.0386311717294956, 3.091609936790367, 3.144202423238924, 3.196420546989394, 3.2482755886447983, 3.2997782409988403, 3.3509386520120565, 3.4017664637822027, 3.4522708479593494, 3.502460537997181, 3.5523438585818052, 3.601928752536457, 3.6512228054637506, 3.700233268355474, 3.7489670783726785, 3.797430877975199, 3.8456310325592784, 3.8935736467441537, 3.9412645794329455, 3.988709457759577, 4.035913690021583, 4.082882477688172, 4.129620826563729, 4.176133557178775, 4.222425314473262, 4.268500576830662, 4.314363664515685, 4.3600187475634185, 4.405469853163189, 4.450720872576458, 4.495775567624461, 4.540637576778119, 4.585310420879834, 4.629797508524238, 4.674102141122588, 4.718227517673442, 4.762176739260313, 4.805952813295329, 4.849558657526332, 4.892997103823477, 4.936270901760078, 4.97938272200133, 5.022335159513451, 5.065130736604812, 5.1077719058097975, 5.15026105262528, 5.192600498108889, 5.234792501347582, 5.276839261804399, 5.318742921550737, 5.360505567390943, 5.402129232885547, 5.443615900279054, 5.484967502337762, 5.526185924102744, 5.567273004562749, 5.60823053825151, 5.649060276773592, 5.689763930262721, 5.7303431687762, 5.7707996236288555, 5.8111348886697005], [0.0, 0.23395626336814512, 0.38006307112665283, 0.504800242327092, 0.6174142805782684, 0.7217946844679325, 0.8200504130227778, 0.9134889629090254, 1.0029924578885194, 1.0891919753928967, 1.172558924272542, 1.2534573348019247, 1.3321758262213441, 1.4089481885414803, 1.4839671983356564, 1.5573942171254125, 1.6293660548943611, 1.7000000000000002, 1.7693975842097245, 1.8376474534106062, 1.904827592218524, 1.9710070728646545, 2.036247447846327, 2.100603871759509, 2.164126014432269, 2.2268588112400947, 2.288843084969189, 2.3501160653000963, 2.4107118259243716, 2.470661654821507, 2.5299943698629193, 2.5887365893642333, 2.646912965258901, 2.7045463850609415, 2.761658147611201, 2.8182681166792576, 2.874394855762566, 2.9300557468415844, 2.9852670953813973, 3.040044223491803, 3.094401552849949, 3.1483526787377034, 3.20191043633881, 3.2550869602696157, 3.3078937381748963, 3.360341659101584, 3.4124410572636954, 3.464201751727968, 3.51563308247896, 3.5667439432622805, 3.61754281155353, 3.668037775956809, 3.7182365612992454, 3.7681465516557666, 3.8177748115105814, 3.8671281052378, 3.9162129150627747, 3.9650354576476077, 4.013601699428464, 4.061917370818468, 4.109987979377881, 4.157818822042557, 4.205414996492333, 4.25278141173271, 4.299922797955863, 4.34684371574055, 4.393548564644688, 4.440041591239288, 4.486326896627841, 4.532408443491183, 4.578290062694204, 4.623975459487535, 4.669468219334361, 4.714771813389924, 4.759889603658873, 4.804824847853494, 4.849580703973918, 4.894160234629666, 4.938566411120297, 4.982802117291496, 5.0268701531816555, 5.070773238472783, 5.114514015758546, 5.15809505364122, 5.201518849668476, 5.244787833120083, 5.2879043676538595, 5.330870753819559, 5.373689231448691, 5.41636198192777, 5.458891130361899, 5.501278747635141, 5.543526852373686, 5.58563741281741, 5.627612348605023, 5.669453532477678, 5.711162791905589, 5.752741910641896, 5.794192630207753, 5.83551665131233, 5.876715635211257, 5.917791205006708], [0.0, 0.23800262745964407, 0.3866364089863525, 0.5135309578229116, 0.6280926994354689, 0.7342784027946782, 0.8342335021895457, 0.9292881079469989, 1.0203396005006327, 1.1080299720104247, 1.1928387845252129, 1.2751363643639049, 1.3552163225482268, 1.4333164925775455, 1.509632985170604, 1.5843299526588874, 1.657546571207606, 1.7294021577217789, 1.8, 1.8694302770942552, 1.937772322394527, 2.005096402762953, 2.0714651352711195, 2.136934628435069, 2.2015554111417646, 2.265373195941397, 2.3284295116660516, 2.3907622318980017, 2.4524060196464808, 2.513392704028691, 2.573751601332285, 2.633509790246955, 2.6926923490708794, 2.7513225611664875, 2.809422093746319, 2.8670111541315304, 2.924108626882448, 2.980732194607608, 3.036898444781421, 3.0926229645155017, 3.1479204249154846, 3.2028046563988974, 3.2572887161389525, 3.3113849486248816, 3.365105040184721, 3.418460068195683, 3.4714605456060132, 3.524116461307008, 3.5764373168218713, 3.628432159716984, 3.6801096140891674, 3.7314779084380585, 3.7825449011946595, 3.8333181041443307, 3.8838047039542687, 3.93401158199105, 3.983945332592623, 4.033612279940666, 4.083018493663166, 4.13216980328296, 4.181071811615694, 4.229729907209778, 4.278149275911392, 4.326334911629188, 4.374291626365846, 4.422024059577095, 4.46953668691291, 4.51683382839039, 4.5639196560432, 4.61079820108827, 4.657473360646784, 4.703948904053115, 4.75022847878242, 4.796315616024916, 4.842213735932422, 4.887926152560617, 4.933456078528469, 4.978806629414512, 5.023980827908083, 5.068981607732095, 5.113811817352683, 5.158474223489812, 5.2029715144418285, 5.247306303235976, 5.29148113061598, 5.335498467876943, 5.379360719557059, 5.423070225994983, 5.4666292657609725, 5.510040057969468, 5.553304764480088, 5.596425491993633, 5.6394042940492195, 5.68224317292819, 5.724944081470149, 5.767508924806033, 5.80993956201286, 5.852237807694473, 5.894405433492303, 5.936444169529948, 5.978355705795095, 6.020141693462097], [0.0, 0.24189454814875874, 0.3929588527986761, 0.5219284355339119, 0.6383635397102438, 0.7462856370756998, 0.8478752449777619, 0.9444842242759265, 1.037024629752189, 1.1261489516967214, 1.2123445941619542, 1.2959879392010434, 1.3773773990886347, 1.4567546964791294, 1.5343191489775632, 1.6102375932045059, 1.6846514811933069, 1.7576820809700138, 1.829434369339449, 1.9000000000000001, 1.9694596036351504, 2.0378845961408003, 2.105338618529654, 2.171878696828189, 2.237556186193325, 2.302417546686412, 2.3665049862367464, 2.4298569977516076, 2.492508811064571, 2.5544927757761666, 2.615838687566514, 2.6765740679276124, 2.7367244052486908, 2.7963133636316724, 2.855362964600617, 2.913893745915434, 2.971924900944852, 3.0294744014509782, 3.0865591061536954, 3.14319485705173, 3.1993965651589056, 3.2551782870536488, 3.3105532934256487, 3.365534130626502, 3.4201326760840756, 3.474360188317588, 3.528227352187509, 3.581744319927753, 3.6349207484344945, 3.687765833223786, 3.740288339417366, 3.792496630070814, 3.8443986921195554, 3.8960021601848753, 3.9473143384534235, 3.9983422208188246, 4.049092509452459, 4.0995716319517275, 4.149785757197767, 4.1997408100402644, 4.2494424849145025, 4.298896258484737, 4.348107401398321, 4.397080989226436, 4.445821912659684, 4.494334887020162, 4.542624461145583, 4.590695025695813, 4.638550820927392, 4.686195943977436, 4.733634355694519, 4.780869887050779, 4.827906245166448, 4.874747018975274, 4.92139568455686, 4.96785561015974, 5.014130060936999, 5.0602222034144475, 5.106135109709726, 5.151871761519239, 5.1974350538884595, 5.242827798779938, 5.288052728452224, 5.333112498661901, 5.378009691700022, 5.422746819273361, 5.467326325240152, 5.511750588209263, 5.556021924011111, 5.600142588048041, 5.644114777531326, 5.687940633611437, 5.73162224340784, 5.77516164194404, 5.818560813993306, 5.861821695840093, 5.90494617696184, 5.947936101635565, 5.990793270473341, 6.033519441890483, 6.076116333510081, 6.1185856235071965], [0.0, 0.24564560522315806, 0.3990524629937759, 0.5300219761507746, 0.648262638677105, 0.7578582832551991, 0.8610232404998686, 0.9591303345675485, 1.05310576346739, 1.1436121356519529, 1.2311444133449163, 1.3160848151533144, 1.398736380828859, 1.4793445814174706, 1.5581118253408985, 1.6352075363540266, 1.710775359985901, 1.7849384447650047, 1.857803395370742, 1.9294632867747636, 2.0, 2.069486058388153, 2.1379860898326664, 2.2055580046622145, 2.2722539543977778, 2.3381211195565537, 2.403202362585905, 2.467536773302356, 2.531160127848266, 2.594105277469196, 2.6564024798866686, 2.7180796833682686, 2.7791627715514995, 2.8396757754973483, 2.8996410582174943, 2.959079475950748, 3.0180105196972726, 3.0764524399071655, 3.134422356728361, 3.1919363578213495, 3.2490095854249423, 3.3056563140928303, 3.3618900203031954, 3.4177234449638196, 3.4731686496857623, 3.5282370675740213, 3.5829395491791223, 3.637286404165602, 3.691287439179055, 3.7449519923303374, 3.79828896466187, 3.851306848915078, 3.904013755878737, 3.9564174385641517, 4.008525314423944, 4.060344485805998, 4.11188175881222, 4.163143660712716, 4.214136456049424, 4.26486616154863, 4.315338559949187, 4.365559212841944, 4.415533472606148, 4.465266493519825, 4.514763242113485, 4.564028506829688, 4.613066907044945, 4.661882901505053, 4.710480796220181, 4.758864751861721, 4.807038790699098, 4.855006803111309, 4.902772553704875, 4.950339687067112, 4.997711733181166, 5.044892112526979, 5.0918841408903415, 5.138691033900356, 5.185315911313971, 5.231761801064738, 5.278031643091578, 5.324128292962126, 5.370054525304045, 5.415813037056718, 5.461406450554767, 5.5068373164539866, 5.552108116509502, 5.597221266215253, 5.642179117313223, 5.686983960180266, 5.731638026099792, 5.776143489425082, 5.820502469640545, 5.864717033326783, 5.908789196034931, 5.9527209240753916, 5.996514136225719, 6.040170705362121, 6.083692460018751, 6.127081185878657, 6.170338627200097, 6.213466488181585], [0.0, 0.24926757485402593, 0.4049363700181797, 0.5378369887562992, 0.6578210738381236, 0.7690326728151439, 0.8737187659326515, 0.9732724192211366, 1.068633487197296, 1.1604743482735074, 1.2492972627406829, 1.3354900849028026, 1.4193603227404181, 1.5011570666952567, 1.5810857096395978, 1.6593181734299884, 1.7360002216050487, 1.8112568184808064, 1.885196140590194, 1.9579126352669705, 2.0294893908448106, 2.1, 2.169510043544588, 2.238078285677407, 2.305757646877729, 2.3725960033251083, 2.438636849460639, 2.5039198514682837, 2.568481312998725, 2.632354569679133, 2.695570325371919, 2.7581569404333615, 2.820140680147314, 2.881545929905439, 2.9423953824552123, 3.0027102015543323, 3.062510165591824, 3.121813794115112, 3.180638459703498, 3.239000487225127, 3.2969152421865084, 3.35439720961528, 3.4114600646961897, 3.4681167361978247, 3.5243794635760253, 3.5802598485134403, 3.6357689015486585, 3.690917084359079, 3.7457143481863, 3.800170168828778, 3.854293578572092, 3.908093195380554, 3.961577249634049, 4.014753608659673, 4.0676297992781265, 4.120213028559251, 4.17251020295885, 4.224527945989642, 4.276272614562327, 4.327750314117988, 4.378966912660198, 4.429928053783773, 4.480639168787161, 4.531105487946646, 4.581332051022719, 4.631323717062067, 4.6810851735525, 4.730620944982664, 4.779935400853536, 4.829032763184342, 4.877917113551643, 4.926592399696891, 4.975062441734582, 5.0233309379903615, 5.071401470495903, 5.119277510165084, 5.166962421673945, 5.214459468065061, 5.261771815095247, 5.308902535344012, 5.35585461209878, 5.402630943031663, 5.449234343681362, 5.4956675507528105, 5.541933225246156, 5.5880339554258365, 5.633972259639698, 5.679750588997407, 5.725371329916661, 5.770836806545228, 5.8161492830661095, 5.861310965892764, 5.9063240057607524, 5.951190499721778, 5.995912493045665, 6.040491981035462, 6.084930910760514, 6.1292311827120205, 6.17339465238531, 6.2174231317927875, 6.261318390911265, 6.305082159067144], [0.0, 0.2527707425511103, 0.4106272827317688, 0.5453956660788974, 0.6670659888162573, 0.7798405382945836, 0.8859978734697794, 0.9869506383054892, 1.0836518958874937, 1.1767834741297183, 1.2668546920110242, 1.3542588546794079, 1.4393077917847144, 1.5222540944469662, 1.6033060420979, 1.6826379727570733, 1.7603976985011893, 1.836711939875322, 1.9116903937085594, 1.9854288346827877, 2.05801151884219, 2.12951307312307, 2.2, 2.269531889534717, 2.3381624059426716, 2.4059400982477923, 2.472909072155279, 2.539109551311469, 2.604578349572901, 2.6693492710604603, 2.7334534511438613, 2.7969196487514147, 2.8597744982951863, 2.922042727875336, 2.9837473491596804, 3.0449098233380756, 3.105550206761946, 3.1656872792495534, 3.2253386575317253, 3.284520895903762, 3.34324957581661, 3.401539385868231, 3.45940419343229, 3.5168571089762763, 3.573910543967437, 3.630576263136663, 3.686865431762939, 3.7427886585504493, 3.7983560345939926, 3.853577168863422, 3.9084612205826526, 3.9630169288315242, 4.017252639658401, 4.071176330956569, 4.124795635327494, 4.178117861128057, 4.231150011876316, 4.283898804170807, 4.33637068426126, 4.388571843393679, 4.440508232039647, 4.492185573108182, 4.543609374228355, 4.594784939181938, 4.645717378557432, 4.69641161968981, 4.7468724159441065, 4.797104355395425, 4.847111868953032, 4.896899237971751, 4.946470601389987, 4.995829962430136, 5.044981194893986, 5.09392804908288, 5.142674157369803, 5.1912230394483165, 5.239578107281096, 5.287742669769008, 5.33571993715992, 5.383513025214897, 5.431124959148019, 5.4785586773548305, 5.525817034943177, 5.572902807079215, 5.619818692160376, 5.6665673148261595, 5.713151228816886, 5.75957291968973, 5.805834807400736, 5.851939248760881, 5.897888539773643, 5.94368491786107, 5.989330563984828, 6.034827604668258, 6.080178113925086, 6.125384115100041, 6.170447582626278, 6.215370443704201, 6.260154579905985, 6.304801828709771, 6.349313984967353, 6.393692802308816], [0.0, 0.2561641502145812, 0.4161398897447045, 0.552717517548799, 0.6760212453291119, 0.7903097754864593, 0.8978922562741635, 1.0002002961800203, 1.0981997530125953, 1.1925816081188616, 1.28386201800527, 1.3724395678798815, 1.4586302736567929, 1.5426901174522865, 1.624830174816876, 1.705227124230751, 1.7840307621246134, 1.8613695102470245, 1.9373545380898367, 2.0120829060950536, 2.085640001431066, 2.158101452889119, 2.2295346557291005, 2.3000000000000003, 2.3695518703509633, 2.438239467568968, 2.506107489471404, 2.573196699700767, 2.639544406333857, 2.7051848673065946, 2.770149635976159, 2.8344678573549733, 2.8981665234179173, 2.9612706942360263, 3.023803690405156, 3.085787261228278, 3.1472417323101958, 3.208186135585293, 3.268638324286252, 3.328615074947195, 3.388132178197612, 3.4472045198275914, 3.505846153378121, 3.564070365322664, 3.621889733750473, 3.6793161813321107, 3.7363610232386835, 3.793035010594571, 3.8493483699659397, 3.905310839321559, 3.960931700846492, 4.016219810941358, 4.071183627698915, 4.125831236114416, 4.18017037125581, 4.234208439593521, 4.287952538666746, 4.341409475243301, 4.394585782112814, 4.447487733637795, 4.500121360173978, 4.552492461459537, 4.604606619062603, 4.6564692079673895, 4.708085407371246, 4.759460210757848, 4.810598435305411, 4.8615047306832295, 4.912183587284833, 4.962639343941564, 5.012876195156427, 5.062898197894453, 5.112709277962613, 5.162313236009457, 5.211713753172011, 5.2609143963951706, 5.309918623446676, 5.358729787648872, 5.4073511423467, 5.455785845129828, 5.504036961825365, 5.552107470276353, 5.600000263920015, 5.647718155178679, 5.6952638786753385, 5.742640094284869, 5.789849390031155, 5.836894284839587, 5.88377723115374, 5.930500617424409, 5.977066770478561, 6.023477957775285, 6.069736389555315, 6.115844220890233, 6.16180355363708, 6.207616438303668, 6.253284875829608, 6.298810819287668, 6.344196175509836, 6.389442806642109, 6.434552531631886, 6.47952712765146], [0.0, 0.2594557933960465, 0.4214871798688942, 0.5598197949220844, 0.6847079437638821, 0.8004650520212367, 0.909429939906239, 1.0130526117060712, 1.1123113362527275, 1.2079059738250584, 1.3003593134073366, 1.390075061924621, 1.4773732960138999, 1.5625132870955483, 1.6457088229863988, 1.7271388524394873, 1.8069550967309689, 1.8852876277957118, 1.9622490436248319, 2.0379376518619483, 2.1124399368785167, 2.1858324992762195, 2.258183600326632, 2.3295544060752778, 2.4000000000000004, 2.469570215105186, 2.5383103235636355, 2.6062616128201235, 2.673461870350604, 2.739945794296627, 2.8057453434678643, 2.8708900373826216, 2.9354072148556862, 2.9993222579735352, 3.062658786995659, 3.125438830697956, 3.187682975864002, 3.249410498983625, 3.3106394826989347, 3.3713869191181867, 3.43166880177638, 3.4915002077421637, 3.550895371140898, 3.6098677491737985, 3.6684300815553166, 3.726594444159254, 3.784372297553743, 3.841774531012335, 3.8988115025099312, 3.9554930751456863, 4.011828650378343, 4.067827198410982, 4.123497286020669, 4.178847102092759, 4.233884481088826, 4.288616924650528, 4.343051621518605, 4.3971954659260835, 4.4510550746072495, 4.504636802548554, 4.5579467575942445, 4.610990814007631, 4.663774625078554, 4.716303634858387, 4.768583089095828, 4.820618045439528, 4.872413382967198, 4.923973811095184, 4.975303877917412, 5.026407978018085, 5.077290359798491, 5.127955132354612, 5.178406271939025, 5.228647628037632, 5.278682929089122, 5.328515787872709, 5.378149706587556, 5.427588081645333, 5.476834208195626, 5.525891284402314, 5.5747624154875925, 5.623450617559018, 5.671958821233734, 5.720289875072969, 5.768446548838917, 5.816431536585159, 5.864247459591016, 5.91189686914942, 5.959382249217214, 6.006706018936168, 6.053870535032375, 6.100878094101186, 6.147730934784361, 6.194431239845595, 6.240981138150245, 6.287382706554622, 6.333637971709894, 6.379748911785312, 6.425717458115158, 6.471545496773528, 6.517234870080823, 6.562787378045543], [0.0, 0.26265278044037665, 0.42668070064464825, 0.5667178356561124, 0.6931448431551464, 0.8103282983463811, 0.9206358401389934, 1.025535339620747, 1.1260171197494693, 1.222789664408884, 1.3163822043342372, 1.4072034208849307, 1.4955773346486672, 1.5817664117610404, 1.6659870743099152, 1.7484204760360735, 1.8292202077093052, 1.9085179439972026, 1.986427670311506, 2.063048905632297, 2.138469199982376, 2.2127660978279966, 2.2860087015489547, 2.3582589308723656, 2.4295725480089025, 2.5, 2.569587116857418, 2.6383756947654913, 2.7064039868134846, 2.773707118689805, 2.8403174429972213, 2.906264842990445, 2.9715769943502686, 3.036279591918573, 3.1003965470012074, 3.1639501598103323, 3.2269612707977102, 3.289449393976052, 3.351432834799885, 3.41292879475244, 3.4739534644393735, 3.5345221067073918, 3.5946491310732536, 3.654348160556394, 3.71363209184869, 3.7725131496215902, 3.831002935659146, 3.8891124734113935, 3.9468522484831126, 4.004232245505531, 4.061261981781178, 4.1179505380430355, 4.174306586627096, 4.230338417321301, 4.2860539611226365, 4.341460812107202, 4.396566247594646, 4.451377246768011, 4.505900507892288, 4.560142464259402, 4.614109298973817, 4.6678069586809015, 4.721241166329736, 4.774417433052724, 4.82734106923613, 4.880017194848421, 4.932450749086788, 4.984646499396513, 5.0366090499126575, 5.088342849369031, 5.139852198515273, 5.1911412570792175, 5.242214050308407, 5.293074475121706, 5.343726305899231, 5.394173199936483, 5.444418702586358, 5.494466252110751, 5.544319184261735, 5.593980736610631, 5.6434540526418555, 5.692742185627124, 5.741848102294338, 5.7907746863044, 5.839524741548219, 5.888100995275225, 5.9365061010638644, 5.9847426416438365, 6.032813131579037, 6.080720019819648, 6.128465692131092, 6.176052473407132, 6.22348262987383, 6.270758371190668, 6.317881852454662, 6.3648551761129255, 6.41168039378881, 6.458359508026359, 6.504894473957555, 6.551287200896499, 6.597539553864472, 6.643653355049488], [0.0, 0.2657614620905154, 0.4317307688843159, 0.5734253425538375, 0.7013487032140114, 0.8199191075791407, 0.9315322172414996, 1.0376732765826269, 1.139344329733838, 1.2372622459873228, 1.331962519898846, 1.423858669861099, 1.5132785514748908, 1.6004877373483912, 1.685705211078131, 1.7691142704876954, 1.8508703242023978, 1.9311066053527652, 2.0099384484486023, 2.0874665503475933, 2.1637794972890556, 2.238955751532913, 2.31306523333456, 2.3861705952849297, 2.458328259579946, 2.529589270337502, 2.6, 2.669602739439215, 2.738436194496811, 2.806535906598591, 2.8739346112632878, 2.9406625454350936, 3.006747712356081, 3.07221611098478, 3.1370919356342775, 3.201397750455536, 3.2651546425618228, 3.328382356928007, 3.3910994156666345, 3.453323223852669, 3.5150701637190522, 3.5763556787590884, 3.63719434903637, 3.697599958808416, 3.757585557408583, 3.8171635141959634, 3.8763455682699384, 3.9351428735508813, 3.99356603974813, 4.0516251696680925, 4.109329893257314, 4.166689398725682, 4.2237124610524255, 4.2804074681409965, 4.336782444857348, 4.392845075158846, 4.4486027224973705, 4.50406244865954, 4.559231031189052, 4.6141149795204, 4.668720549939464, 4.723053759474373, 4.777120398809364, 4.830926044304995, 4.884476069199711, 4.937775654060431, 4.990829796543244, 5.043643320519523, 5.0962208846175265, 5.14856699022498, 5.200685988993942, 5.252582089885567, 5.304259365789057, 5.355721759746068, 5.406973090809179, 5.458017059560574, 5.5088572533149085, 5.559497151028345, 5.6099401279339425, 5.660189459921971, 5.710248327682211, 5.760119820624013, 5.809806940588602, 5.859312605367048, 5.9086396520363, 5.9577908401247095, 6.006768854617707, 6.055576308813426, 6.104215747037406, 6.152689647224888, 6.201000423378521, 6.249150427908827, 6.297141953864263, 6.3449772370571935, 6.3926584580917325, 6.440187744298946, 6.4875671715846, 6.534798766194266, 6.581884506400295, 6.6288263241148755, 6.675626106433134, 6.722285697109972], [0.0, 0.2687875379522286, 0.43664664362478056, 0.5799546134795288, 0.7093345652902705, 0.8292550639683242, 0.9421390491532032, 1.0494886768664426, 1.1523174009506616, 1.2513502532843181, 1.3471288257976293, 1.440071345383972, 1.5305094007509492, 1.6187115884322194, 1.7048993854670058, 1.789258176787819, 1.871945140570328, 1.953095026995564, 2.0328244838223397, 2.111235354486657, 2.1884172339093726, 2.2644494777559054, 2.339402802424159, 2.413340573894779, 2.486319856811409, 2.5583922765025187, 2.6296047334273576, 2.6999999999999997, 2.7696172227836975, 2.838492347894421, 2.90665848359179, 2.9741462111110244, 3.0409838525513186, 3.107197702906679, 3.172812231977187, 3.237850260839066, 3.3023331167126457, 3.366280769397689, 3.4297119519075876, 3.492644267499077, 3.5550942849403446, 3.6170776235710416, 3.6786090294697207, 3.739702443847466, 3.8003710646230324, 3.860627401998427, 3.920483328739534, 3.979950125770127, 4.039038523606318, 4.097758740089475, 4.156120514816911, 4.214133140619477, 4.271805492392142, 4.329146053546682, 4.386162940323672, 4.442863924173367, 4.499256452391121, 4.55534766717213, 4.611144423232163, 4.666653304124967, 4.721880637373227, 4.776832508517572, 4.831514774177496, 4.885933074208428, 4.940092843030851, 4.993999320199874, 5.047657560277081, 5.101072442060543, 5.154248677223693, 5.207190818409019, 5.2599032668183865, 5.312390279338018, 5.364655975232806, 5.416704342441599, 5.468539243502371, 5.52016442113375, 5.571583503497121, 5.622800009161555, 5.673817351791988, 5.724638844579404, 5.775267704430305, 5.825707055931401, 5.875959935104192, 5.926029292962989, 5.975917998888933, 6.025628843831572, 6.075164543348749, 6.124527740494749, 6.173721008565913, 6.222746853712332, 6.2716077174235405, 6.320305978895633, 6.368843957286716, 6.417223913867089, 6.4654480540701735, 6.5135185294497555, 6.561437439548768, 6.609206833684498, 6.65682871265477, 6.704305030369364, 6.751637695410695, 6.798828572527462], [0.0, 0.27173614464666307, 0.44143666933171344, 0.5863167315628375, 0.7171159850083989, 0.8383520148598691, 0.9524743404713409, 1.0610015965572788, 1.1649583545768685, 1.2650776000282442, 1.361906866120014, 1.4558689677060943, 1.5472991310313433, 1.6364688991407919, 1.723602178682883, 1.8088863882679431, 1.8924804303205571, 1.9745205332349542, 2.0551246243990735, 2.134395664474215, 2.2124242312399844, 2.2892905508956374, 2.3650661155999084, 2.439814986459997, 2.513594854120259, 2.5864579102404397, 2.6584515697791176, 2.7296190743649285, 2.8, 2.869630687130186, 2.938544607213625, 3.0067726769625307, 3.074343529170305, 3.1412837472877633, 3.2076180695493672, 3.273369567379175, 3.338559801957712, 3.4032089621539923, 3.4673359864830817, 3.5309586713099272, 3.5940937671625592, 3.6567570647252152, 3.718963471841336, 3.780727082657475, 3.8420612398739182, 3.9029785909299353, 3.963491138835978, 4.023610288267864, 4.0833468874557655, 4.142711266331047, 4.201713271334677, 4.260362297240114, 4.318667316300169, 4.376636904989881, 4.434279268585206, 4.491602263789423, 4.54861341959492, 4.605319956546973, 4.661728804557769, 4.717846619402826, 4.773679798017921, 4.829234492702235, 4.884516624322538, 4.93953189460363, 4.994285797581733, 5.048783630290023, 5.103030502738763, 5.157031347246572, 5.210790927174072, 5.264313845106363, 5.317604550526617, 5.370667347019217, 5.423506399037501, 5.47612573826812, 5.528529269621195, 5.580720776873081, 5.63270392798619, 5.684482280128398, 5.736059284412636, 5.787438290375684, 5.838622550213598, 5.889615222789891, 5.9404193774313, 5.991037997524846, 6.041473983928861, 6.0917301582096846, 6.141809265714906, 6.191713978493186, 6.24144689807, 6.291010558087973, 6.340407426819847, 6.389639909561564, 6.438710350912457, 6.487621036949024, 6.536374197298354, 6.584972007116834, 6.6334165889794425, 6.681710014684533, 6.729854306978737, 6.77785144120628, 6.825703346886778, 6.873411909225275], [0.0, 0.2746119293362479, 0.44610839534275304, 0.5925217238433759, 0.7247052263035723, 0.8472242975366968, 0.9625543801698194, 1.0722301806345713, 1.1772871134339291, 1.2784659212544414, 1.3763199318508206, 1.4712764347282485, 1.5636742038322535, 1.653787655948982, 1.74184306733182, 1.8280298400429853, 1.9125085581720485, 1.9954168918188715, 2.0768740163974044, 2.156983982202033, 2.2358383255973595, 2.3135181218168235, 2.3900956196209573, 2.4656355580759097, 2.540196238366353, 2.613830404496574, 2.686585973217844, 2.7585066437851253, 2.8296324110335327, 2.9000000000000004, 2.9696432363712413, 3.038593364051155, 3.106879318854111, 3.174527965563687, 3.241564304219179, 3.3080116504096164, 3.373891793497583, 3.439225136010974, 3.504030816891234, 3.56832682084231, 3.632130075663137, 3.6954565391508263, 3.7583212769185845, 3.8207385322713727, 3.8827217891153283, 3.9442838287376185, 4.005436781176604, 4.06619217180383, 4.126560963656331, 4.186553595987179, 4.246180019442262, 4.3054497282199655, 4.364371789526487, 4.422954870601734, 4.48120726355813, 4.539136908246477, 4.596751413338519, 4.654058075794591, 4.7110638988661675, 4.767775608766864, 4.8241996701312555, 4.88034230036833, 4.936209483005412, 4.991806980108679, 5.04714034385776, 5.102214927344353, 5.15703589465798, 5.211608230316009, 5.2659367480897235, 5.320026099273402, 5.373880780439113, 5.42750514071609, 5.480903388630099, 5.534079598535144, 5.5870377166670275, 5.639781566845823, 5.692314855852005, 5.744641178498968, 5.796764022422788, 5.848686772608405, 5.900412715669877, 5.951945043900984, 6.003286859111159, 6.054441176260621, 6.105410926907495, 6.156198962478769, 6.206808057376057, 6.2572409119263215, 6.307500155186992, 6.357588347614243, 6.407507983602557, 6.457261493903132, 6.506851247928206, 6.5562795559478335, 6.605548671185255, 6.6546607918165455, 6.703618062879904, 6.752422578099534, 6.8010763816288025, 6.849581469717011, 6.897939792303888, 6.94615325454561], [0.0, 0.2774191114672181, 0.45066867616853096, 0.5985786944906638, 0.7321134243611632, 0.8558849297048525, 0.9723939580156575, 1.0831909040475693, 1.1893217666838487, 1.2915348607498025, 1.3903891703159093, 1.4863163527946976, 1.579658645201085, 1.6706932695085248, 1.7596488150478307, 1.8467166200173744, 1.9320589100551757, 2.0158147625744833, 2.098104571243288, 2.179033449995591, 2.258693870913711, 2.337167738011347, 2.414528038601907, 2.4908401735376087, 2.5661630399788513, 2.640549921098146, 2.7140492234690665, 2.786705093056113, 2.858557933536021, 2.929644845362292, 3.0, 3.0696549607394936, 3.1386389591874666, 3.206979134748999, 3.2747007430228003, 3.341827337938255, 3.408380931596666, 3.4743821350879225, 3.5398502829986285, 3.6048035438788575, 3.669259018569607, 3.733232827994342, 3.7967401917723986, 3.859795498808936, 3.92241237084744, 3.9846037198300026, 4.046381799792608, 4.107758253923308, 4.168744157327248, 4.229350055971311, 4.289586002220475, 4.349461587326242, 4.408985971183059, 4.468167909630486, 4.527015779545909, 4.585537601944146, 4.643741063275525, 4.701633535092541, 4.7592220922364294, 4.816513529678588, 4.873514378137413, 4.930230918578491, 4.98666919569492, 5.042835030454793, 5.0987340317941205, 5.154371607525836, 5.2097529745286435, 5.264883168273444, 5.319767051739629, 5.374409323768683, 5.428814526898254, 5.482987054715942, 5.536931158768581, 5.590650955059692, 5.6441504301649195, 5.697433446992805, 5.75050375021587, 5.803364971394987, 5.856020633818105, 5.9084741570727, 5.960728861369785, 6.012787971635915, 6.064654621388341, 6.116331856407289, 6.167822638218328, 6.219129847396763, 6.2702562867051395, 6.321204684074136, 6.371977695436353, 6.422577907421874, 6.473007839923779, 6.523269948541283, 6.5733666269076085, 6.623300208909222, 6.673072970802626, 6.722687133234444, 6.772144863170228, 6.8214482757369845, 6.870599435984154, 6.919600360567417, 6.96845301935949, 7.017159336991742], [0.0, 0.2801615349437183, 0.4551237562497528, 0.6044959373785896, 0.739350723305026, 0.8643457704594475, 0.9820065474467368, 1.0938987754306215, 1.201078793504447, 1.3043023139512282, 1.4041338466721258, 1.5010093162241192, 1.5952743428022504, 1.687208888854644, 1.7770438034293479, 1.8649723161963212, 1.9511582564732863, 2.035742076521682, 2.118845360159736, 2.2005742604240512, 2.2810221635286667, 2.360271783148478, 2.438396828112151, 2.5154633457912867, 2.5915308155734933, 2.666653047361479, 2.740878926251452, 2.814253034612342, 2.8868161755309734, 2.958605816216958, 3.0296564659370016, 3.1, 3.169665938981363, 3.2386816905724523, 3.3070727600359104, 3.374862934143224, 3.4420744425960734, 3.5087281002350434, 3.5748434327785734, 3.640438788381733, 3.7055314369356886, 3.770137658727112, 3.834272823828713, 3.897951463387009, 3.961187333803077, 4.023993474659865, 4.086382261130493, 4.148365451501612, 4.209954230361199, 4.271159247928168, 4.3319906559400385, 4.39245814046252, 4.452570951940095, 4.512337932768073, 4.571767542633366, 4.630867881842444, 4.689646712829953, 4.748111480019786, 4.8062693281914415, 4.864127119487928, 4.921691449186986, 4.978968660344616, 5.03596485740866, 5.092685918890326, 5.149137509172698, 5.205325089527582, 5.261253928405077, 5.316929111054176, 5.372355548527196, 5.427537986115966, 5.4824810112633395, 5.537189060989677, 5.591666428870429, 5.645917271597822, 5.699945615156752, 5.753755360642496, 5.807350289745496, 5.860734069926375, 5.913910259302506, 5.9668823112656595, 6.019653578848756, 6.072227318858326, 6.124606695787969, 6.176794785526935, 6.228794578876925, 6.280608984889134, 6.3322408340327865, 6.383692881205489, 6.434967808595034, 6.4860682284016065, 6.536996685428661, 6.58775565955021, 6.638347568061711, 6.68877476792124, 6.739039557887204, 6.789144180558406, 6.83909082432191, 6.888881625213789, 6.938518668697503, 6.98800399136436, 7.037339582560234, 7.086527385942412], [0.0, 0.28284271247461895, 0.4594793419988139, 0.610281031771172, 0.7464263932294459, 0.872617657102096, 0.9914044610137809, 1.104367510256598, 1.2125732532083184, 1.3167846344038565, 1.4175715661678827, 1.5153741449046199, 1.6105412984334113, 1.7033556684746287, 1.7940503133277823, 1.8828203118925961, 1.9698310613518661, 2.055224358111035, 2.1391229495592037, 2.2216340046295238, 2.3028518032526493, 2.3828598506826877, 2.461732561150118, 2.539536614107348, 2.6163320581664427, 2.6921732181969564, 2.767109447130989, 2.841185753995777, 2.9144433323682923, 2.9869200080235756, 3.0586506204859116, 3.1296673501145036, 3.2000000000000006, 3.2696762401284665, 3.3387218198507886, 3.4071607535805426, 3.4750154837601643, 3.542307024430614, 3.609055088173662, 3.675278198738294, 3.7409937912904856, 3.8062183019210902, 3.870967247796149, 3.935255299126894, 3.999096343964713, 4.062503546682837, 4.125489400886188, 4.18806577738955, 4.25024396781867, 4.312034724316259, 4.3734482957731124, 4.434494460951683, 4.495182558824248, 4.5555215164088425, 4.615519874352536, 4.675185810482647, 4.734527161521197, 4.7935514431360575, 4.852265868483072, 4.910677365376734, 4.9687925922123375, 5.0266179527496435, 5.0841596098567505, 5.141423498302881, 5.198415336679908, 5.2551406385246215, 5.311604722706787, 5.367812723141801, 5.423769597881309, 5.479480137630118, 5.534948973733425, 5.590180585674379, 5.645179308118434, 5.699949337537827, 5.754494738446586, 5.80881944927391, 5.862927287901445, 5.916821956887827, 5.970507048402016, 6.02398604888513, 6.077262343458992, 6.13033922009814, 6.183219873580734, 6.2359074092326345, 6.288404846477848, 6.340715122207522, 6.392841093978788, 6.444785543053936, 6.496551177289597, 6.5481406338850086, 6.599556481997681, 6.650801225234299, 6.701877304024114, 6.752787097881554, 6.803532927564406, 6.854117057133396, 6.9045416959187, 6.954809000398494, 7.004921075994363, 7.054879978788023, 7.1046877171636105, 7.154346253379434], [0.0, 0.28546586347325015, 0.46374066336809877, 0.6159409240976532, 0.7533489302171372, 0.8807105220680124, 1.000598983224386, 1.1146096788174915, 1.2238189477225523, 1.3289968102046688, 1.4307184640917885, 1.5294280873475001, 1.6254778438312407, 1.7191529965503318, 1.810688765242723, 1.9002820380165362, 1.9880997459876193, 2.0742850006152107, 2.158961687677071, 2.242237970016682, 2.324209001939336, 2.4049590631468494, 2.4845632580050823, 2.5630888843676396, 2.640596547751784, 2.71714107684891, 2.7927722823020202, 2.867535590562839, 2.94147257724743, 3.014621418936122, 3.087017278263285, 3.1586926340364747, 3.2296775657473344, 3.3000000000000003, 3.369685924951001, 3.4387595777293307, 3.5072436089140067, 3.5751592274352335, 3.642526328693982, 3.7093636082329184, 3.7756886629159205, 3.8415180812660803, 3.906867524359351, 3.9717517984620136, 4.036184920426567, 4.100180176715792, 4.1637501768032905, 4.2269069015966245, 4.2896617474427785, 4.3520255662024105, 4.414008701816979, 4.475621023739521, 4.536871957554178, 4.5977705130702855, 4.658325310142919, 4.718544602442522, 4.778436299370755, 4.838007986297588, 4.8972669432754, 4.9562201623688935, 5.014874363724915, 5.073236010493224, 5.131311322697832, 5.189106290148435, 5.246626684472491, 5.303878070340653, 5.360865815951155, 5.417595102832557, 5.474070935018657, 5.530298147644407, 5.58628141500721, 5.642025258134011, 5.697534051890988, 5.752812031669468, 5.807863299678753, 5.862691830873978, 5.917301478544736, 5.97169597958808, 6.025878959487601, 6.079853937018508, 6.133624328697055, 6.187193452991241, 6.240564534308364, 6.293740706773818, 6.346725017814473, 6.399520431558905, 6.452129832065918, 6.50455602639189, 6.556801747506764, 6.608869657067793, 6.660762348059471, 6.712482347307531, 6.764032117874345, 6.815414061342532, 6.866630519993139, 6.917683778884333, 6.968576067836148, 7.0193095633264555, 7.069886390303021, 7.1203086239161575, 7.170578291176235, 7.220697372540015], [0.0, 0.28803394661274373, 0.4679125267362902, 0.6214819981961592, 0.7601261422533058, 0.8886334933647516, 1.009600484654184, 1.124636833337688, 1.2348285611565366, 1.3409526155650782, 1.4435893689358648, 1.5431869951075976, 1.6401008260455556, 1.734618691015283, 1.8269779258180505, 1.917377189789631, 2.005984915777039, 2.0929455026863577, 2.1783839507857934, 2.2624093959639797, 2.345117848545084, 2.4265943464206354, 2.5069146696038493, 2.5861467213674203, 2.664351652442688, 2.741584784766144, 2.81789637708296, 2.8933322645063497, 2.9679343966713123, 3.0417412935990042, 3.1147884342508245, 3.187108589617348, 3.2587321097887223, 3.3296871725999666, 3.4000000000000004, 3.4696950471577663, 3.538795168419449, 3.6073217635131827, 3.6752949068212124, 3.742733462073417, 3.809655184437048, 3.876076811667425, 3.9420141457293085, 4.007482126087822, 4.072494895692654, 4.137065860533102, 4.201207743519018, 4.26493263333956, 4.328252028864538, 4.391176879579173, 4.453717622480189, 4.515884215807337, 4.577686169938378, 4.639132575735908, 4.700232130600193, 4.760993162452628, 4.821423651848744, 4.881531252397355, 4.941323309643014, 5.000806878551827, 5.0599887397258385, 5.118875414458035, 5.177473178728467, 5.235788076231831, 5.2938259305178015, 5.351592356317435, 5.409092770121883, 5.466332400073321, 5.523316295222402, 5.5800493342014965, 5.636536233358515, 5.69278155439207, 5.748789711525132, 5.804564978251085, 5.860111493683169, 5.915433268535666, 5.970534190762795, 6.025418030879158, 6.080088446983606, 6.134548989506645, 6.188803105699898, 6.242854143884675, 6.296705357475407, 6.3503599087924325, 6.403820872677619, 6.4570912399251785, 6.510173920539231, 6.563071746828752, 6.615787476349793, 6.668323794704173, 6.720683318203167, 6.772868596404121, 6.824882114527392, 6.8767262957605055, 6.928403503455937, 6.979916043228493, 7.03126616495792, 7.08245606470193, 7.133487886524561, 7.184363724244409, 7.235085623107059, 7.285655581385688], [0.0, 0.29054968792442243, 0.47199936055433694, 0.6269101359407313, 0.7667652233777422, 0.8963949812604987, 1.018418520435745, 1.1344596176849338, 1.2456137802623906, 1.3526647416240118, 1.4561979432210856, 1.5566654733248098, 1.6544257674350114, 1.7497691687708243, 1.8429350860679325, 1.934123913789179, 2.0235055559049524, 2.1112256725278638, 2.197410355701384, 2.2821696945270133, 2.3656005379006966, 2.4477886664505033, 2.528810522066181, 2.608734601100061, 2.687622588385184, 2.765530289049981, 2.842508400808721, 2.918603159106901, 2.9938568799753265, 3.0683084198760824, 3.1419935676503234, 3.214945380516465, 3.287194473647909, 3.358769270990052, 3.429696223519125, 3.5000000000000004, 3.569703654392914, 3.63882877333515, 3.7073956065422893, 3.775423182503487, 3.8429294114628814, 3.9099311773664165, 3.9764444201961107, 4.042484209901116, 4.108064812958237, 4.1731997524471405, 4.237901862401905, 4.302183337096519, 4.3660557758340275, 4.429530223734465, 4.4926172089532, 4.555326776707072, 4.617668520439229, 4.679651610413527, 4.74128481999492, 4.802576549842398, 4.8635348502151245, 4.924167441569939, 4.9844817336087255, 5.044484842916959, 5.104183609319707, 5.163584611068122, 5.222694178957817, 5.281518409470228, 5.340063177018976, 5.398334145375212, 5.456336778338712, 5.514076349715206, 5.571557952654681, 5.628786508400376, 5.68576677449365, 5.742503352475827, 5.799000695124511, 5.855263113258562, 5.911294782142994, 5.967099747522401, 6.0226819313091084, 6.078045136950084, 6.133193054494685, 6.188129265383529, 6.242857246977167, 6.29738037684176, 6.351701936807658, 6.405825116815487, 6.459753018563345, 6.5134886589675896, 6.56703497344885, 6.62039481905401, 6.673570977424118, 6.726566157617534, 6.779382998796876, 6.83202407278779, 6.884491886517003, 6.936788884336607, 6.988917450241028, 7.040879909982738, 7.092678533092345, 7.144315534808332, 7.195793077921384, 7.247113274537894, 7.298278187766997, 7.349289833335154], [0.0, 0.2930156051583521, 0.476005254919288, 0.6322307698033414, 0.7732728179727051, 0.9040027534404961, 1.0270619156458232, 1.1440878624868152, 1.2561853988709375, 1.364144909859358, 1.468556805589356, 1.569877011239569, 1.6684670043790915, 1.7646195923919752, 1.8585762158939978, 1.9505389701110047, 2.0406792010012653, 2.129143804905812, 2.216059944020849, 2.301538641782431, 2.3856775690504257, 2.4685632344795976, 2.5502727287278097, 2.63087512948113, 2.7104326450964535, 2.789001554324569, 2.866632985155091, 2.943373565437248, 3.0192659703412077, 3.094349386106795, 3.1686599053177744, 3.2422308657516807, 3.315093142415212, 3.3872754004899477, 3.4588043154435577, 3.5297047654065943, 3.6, 3.6697117890684883, 3.7388605541885105, 3.8074654853454533, 3.875544644789054, 3.943115059760587, 4.010192805525906, 4.076793079933966, 4.142930270542239, 4.208618015201797, 4.273869256870138, 4.338696293314978, 4.403110822283529, 4.467123982636593, 4.5307463918827935, 4.593988180493489, 4.656859023332103, 4.7193681684912185, 4.7815244637960035, 4.843336381202477, 4.904812039292962, 4.965959224048402, 5.026785408057382, 5.087297768304378, 5.14750320266457, 5.207408345219229, 5.267019580493909, 5.326343056711347, 5.385384698141758, 5.444150216625147, 5.502645122332975, 5.560874733830159, 5.618844187492637, 5.676558446330613, 5.734022308263061, 5.791240413884934, 5.848217253764896, 5.9049571753080565, 5.961464389215217, 6.017742975567514, 6.073796889562842, 6.129629966928309, 6.185245929031003, 6.240648387707499, 6.295840849830969, 6.350826721633238, 6.405609312797795, 6.460191840338536, 6.514577432277905, 6.568769131137058, 6.622769897249762, 6.676582611910875, 6.730210080369442, 6.783655034675809, 6.836920136391365, 6.890007979169035, 6.942921091212027, 6.9956619376178315, 7.048232922614017, 7.100636391691891, 7.1528746336437425, 7.20494988250895, 7.256864319433968, 7.308620074450797, 7.360219228178334, 7.411663813450664], [0.0, 0.2954340289925338, 0.4799339960287262, 0.6374489286163135, 0.7796550767343139, 0.9114640004409923, 1.0355388396466312, 1.153530667942657, 1.2665534088175023, 1.375403970828137, 1.4806776371012738, 1.5828340958244116, 1.6822378080458635, 1.7791839978549482, 1.8739160986136643, 1.9666378735542782, 2.05752208285035, 2.146716835261658, 2.234350342526072, 2.3205345444189773, 2.405367917933196, 2.4889376857284438, 2.571321574735468, 2.652589232777623, 2.732803381652627, 2.8120207646116904, 2.890292931632698, 2.9676668954109426, 3.0441856833389527, 3.1198888050827978, 3.194812651118787, 3.2689908343800265, 3.3424544847021407, 3.415232503856695, 3.487351787479112, 3.558837419033252, 3.6297128400323557, 3.6999999999999997, 3.7697194890634793, 3.8388906555940046, 3.9075317109192955, 3.9756598228160973, 4.043291199228544, 4.110441163442046, 4.177124221762746, 4.243354124602624, 4.309143921744745, 4.3745060124572674, 4.439452191035541, 4.503993688275699, 4.568141209318679, 4.631904968248359, 4.695294719780297, 4.758319788336821, 4.820989094769216, 4.883311180957354, 4.945294232490818, 5.006946099612666, 5.06827431658699, 5.129286119633985, 5.189988463560906, 5.250388037203855, 5.310491277783493, 5.370304384267323, 5.4298333298219195, 5.48908387343034, 5.548061570742615, 5.606771784220788, 5.665219692634221, 5.723410299955652, 5.781348443703999, 5.8390388027756766, 5.896485904802557, 5.953694133071345, 6.0106677330361435, 6.067410818453311, 6.123927377165231, 6.180221276557441, 6.23629626871158, 6.292155995274758, 6.347803992064358, 6.403243693425765, 6.458478436359164, 6.513511464430288, 6.568345931478923, 6.622984905137877, 6.677431370174229, 6.731688231663795, 6.7857583180089325, 6.839644383809144, 6.893349112593195, 6.9468751194208975, 7.000224953362152, 7.053401099860297, 7.106405982986353, 7.159241967590298, 7.211911361355117, 7.264416416758985, 7.3167593329505936, 7.368942257542302, 7.420967288325537, 7.472836474912514], [0.0, 0.2978071215719372, 0.48378909629751743, 0.6425692775734279, 0.7859177055973524, 0.9187853928452996, 1.0438568710678238, 1.1627964762097138, 1.2767270794204877, 1.3864519904756525, 1.4925712741513997, 1.5955483111097555, 1.6957504899555238, 1.7934754061842493, 1.888968448551853, 1.9824350170316913, 2.074049259504378, 2.1639604744226992, 2.2522979033934427, 2.339174385355341, 2.4246891883239083, 2.5089302355804075, 2.5919758784020868, 2.673896324062862, 2.7547547981772693, 2.834608499790284, 2.9135093929582587, 2.9915048680089424, 3.068638297955126, 3.1449495098267755, 3.2204751864090118, 3.2952492106329565, 3.369302962386614, 3.4426655755968647, 3.5153641619400275, 3.587424006364478, 3.658868738678898, 3.729720484717806, 3.8000000000000003, 3.86972678831371, 3.9389192072703008, 4.007594562547774, 4.075769192281601, 4.143458542842458, 4.210677237059308, 4.2774391357951895, 4.343757393656378, 4.40964450950894, 4.47511237238665, 4.540172303297725, 4.604835093372824, 4.669111038741105, 4.733009972473494, 4.796541293891335, 4.859713995503216, 4.922536687802201, 4.985017622129143, 5.047164711784671, 5.108985551552334, 5.1704874357777255, 5.231677375133028, 5.292562112182846, 5.353148135855225, 5.413441694911264, 5.473448810497381, 5.533175287856028, 5.592626727263345, 5.6518085342556965, 5.710725929201234, 5.7693839562674265, 5.827787491830868, 5.885941252371508, 5.943849801889704, 6.0015175588811935, 6.058948802901957, 6.116147680752364, 6.173118212307392, 6.2298642960176, 6.28638971410346, 6.342698137463843, 6.398793130317811, 6.454678154597346, 6.5103565741072975, 6.5658316584675465, 6.6211065868512975, 6.676184451532313, 6.731068261253004, 6.78576094442439, 6.840265352168152, 6.894584261210287, 6.948720376635176, 7.002676334508264, 7.056454704375019, 7.110057991643258, 7.163488639855508, 7.216749032857553, 7.26984149686899, 7.322768302461165, 7.375531666447573, 7.428133753691405, 7.480576678834732, 7.532862507953406], [0.0, 0.3001368927744568, 0.48757382078193406, 0.6475961533264739, 0.7920660086613834, 0.9259731314670222, 1.0520230548210172, 1.1718931349140636, 1.286715027215055, 1.3972983258622491, 1.5042477899911526, 1.6080304253313067, 1.7090164946007573, 1.8075059214106821, 1.9037460142147387, 1.997943779848269, 2.0902747285660146, 2.1808893267956364, 2.269917827212336, 2.3574739515037484, 2.44365774426777, 2.5285578166171963, 2.6122531327781817, 2.694814449262296, 2.7763054863035967, 2.8567838904202003, 2.9363020321878244, 3.0149076726729036, 3.0926445241991067, 3.169552725366746, 3.245669245933583, 3.3210282338998787, 3.3956613146412504, 3.46959785000184, 3.542865163754986, 3.61548873865543, 3.6874923893699187, 3.7588984148253104, 3.8297277329126467, 3.9000000000000004, 3.969733717311939, 4.038946325910298, 4.107654291745217, 4.17587318202568, 4.243617733976323, 4.310901916894932, 4.377738988297417, 4.444141544829572, 4.510121568534121, 4.575690468984522, 4.640859121731395, 4.705637903451416, 4.770036724140489, 4.834065056651672, 4.897731963842735, 4.961046123567382, 5.024015851717429, 5.086649123499951, 5.148953593113155, 5.210936611966934, 5.272605245578578, 5.333966289260363, 5.395026282703786, 5.455791523554556, 5.516268080063041, 5.576461802886617, 5.636378336112875, 5.6960231275661615, 5.755401438454029, 5.814518352404907, 5.873378783943713, 5.93198748644783, 5.990349059622194, 6.048467956528819, 6.106348490203028, 6.163994839885971, 6.221411056900462, 6.27860107019498, 6.335568691578637, 6.392317620668071, 6.448851449565539, 6.50517366728602, 6.561287663949706, 6.617196734755, 6.672904083746055, 6.728412827387764, 6.783725997960193, 6.838846546783579, 6.893777347284174, 6.948521197910549, 7.003080824909196, 7.057458884967731, 7.1116579677334, 7.165680598214047, 7.219529239068245, 7.273206292790813, 7.326714103799567, 7.380054960428733, 7.433231096834131, 7.486244694814866, 7.53909788555604, 7.591792751296597], [0.0, 0.3024252145332218, 0.4912912104463161, 0.6525335948880586, 0.7981049259875518, 0.9330329915368074, 1.0600439523015495, 1.1808279530724777, 1.2965252773542097, 1.4079516918413502, 1.515716566510398, 1.62029046766408, 1.7220464809997371, 1.8212868168241922, 1.918260669135097, 2.013176623041764, 2.10621152693478, 2.1975169944369988, 2.2872242713039057, 2.37544794626687, 2.4622888266898326, 2.5478361992797653, 2.6321696303066293, 2.715360415748046, 2.797472761657718, 2.878564754065812, 2.9586891628349408, 3.0378941131743367, 3.116223650681796, 3.1937182199847642, 3.2704150727080528, 3.3463486172051624, 3.421550719971802, 3.4960509667144524, 3.569876889530009, 3.643054165460366, 3.715606790741484, 3.7875572343130433, 3.8589265735495273, 3.929734614684274, 4.0, 4.069740303533735, 4.138972116776306, 4.207711125625147, 4.275972179665333, 4.343769354700206, 4.411116009324429, 4.4780248362238995, 4.5445079087955556, 4.610576723602408, 4.676242239113107, 4.741514911118811, 4.80640472517181, 4.870921226348659, 4.935073546604713, 4.998870429955891, 5.062320255696532, 5.125431059838764, 5.188210554938392, 5.250666148454373, 5.312804959773337, 5.374633836016789, 5.436159366736537, 5.497387897593176, 5.558325543102998, 5.618978198530311, 5.679351550994696, 5.739451089856134, 5.799282116434989, 5.858849753118599, 5.918158951901496, 5.977214502402051, 6.036021039394545, 6.094583049892296, 6.152904879814331, 6.210990740265422, 6.268844713456722, 6.326470758292035, 6.383872715642698, 6.441054313332189, 6.498019170849885, 6.554770803811926, 6.611312628185661, 6.667647964292941, 6.72378004060639, 6.779711997351636, 6.835446889927638, 6.8909876921562665, 6.946337299371525, 7.001498531358082, 7.056474135148042, 7.1112667876843, 7.165879098358245, 7.220313611429039, 7.274572808331205, 7.3286591098768055, 7.382574878358109, 7.436322419556198, 7.489903984660675, 7.543321772105252, 7.59657792932374, 7.649674554430614], [0.0, 0.30467383348995825, 0.4949441027185185, 0.6573853709333773, 0.804039066991007, 0.93997036174011, 1.0679256857403372, 1.1896077504978388, 1.3061653178549544, 1.418420219967651, 1.5269863576544838, 1.6323377960147671, 1.7348503947459302, 1.8348286111758507, 1.9325234921316405, 2.028145173613241, 2.121871818930182, 2.2138561689964624, 2.3042304454177267, 2.393110088925711, 2.4805966564162687, 2.566780098468867, 2.6517405729517014, 2.735549905948613, 2.8182727809038854, 2.8999677157341246, 2.9806878726611363, 3.060481734719006, 3.139393674997291, 3.2174644388409415, 3.2947315548513765, 3.371229687218158, 3.4469909393736096, 3.522045117002498, 3.5964199569108235, 3.6701413270567147, 3.7432334020950893, 3.8157188180286923, 3.887618808948386, 3.9589533283525804, 4.029741157134759, 4.1000000000000005, 4.169746571801663, 4.23899667506637, 4.307765269790154, 4.376066536434028, 4.443913932917671, 4.511320246300771, 4.578297639749466, 4.644857695307039, 4.711011452921522, 4.7767694461259085, 4.842141734717956, 4.907137934744625, 4.971767246060003, 5.036038477694295, 5.099960071244318, 5.1635401224722735, 5.2267864012790515, 5.289706370200208, 5.352307201557074, 5.414595793381482, 5.476578784220463, 5.538262566916436, 5.599653301448891, 5.660756926915129, 5.721579172720114, 5.7821255690388025, 5.842401456608411, 5.9024119959027095, 5.962162175735742, 6.021656821338075, 6.080900601944881, 6.139898037931717, 6.198653507530777, 6.2571712531576145, 6.315455387375802, 6.37350989852474, 6.4313386560337555, 6.488945415443771, 6.5463338231561155, 6.603507420926551, 6.660469650121132, 6.717223855749264, 6.773773290288197, 6.830121117312047, 6.886270414937548, 6.942224179097794, 6.997985326654436, 7.053556698358058, 7.108941061665742, 7.164141113424227, 7.219159482426485, 7.273998731848977, 7.32866136157641, 7.383149810420288, 7.4374664582372025, 7.491613627952386, 7.545593587493688, 7.599408551640811, 7.6530606837943544, 7.706552097668886], [0.0, 0.30688438220956976, 0.49853514970805185, 0.6621550039975702, 0.8098727400363596, 0.9467902788160732, 1.0756739775125985, 1.1982389015867936, 1.3156421476762472, 1.4287115107070112, 1.5380653456302877, 1.6441811571056133, 1.747437531865303, 1.8481411362151072, 1.9465448384422732, 2.0428602991800213, 2.1372669743945925, 2.229918713205532, 2.3209486965470147, 2.4104732027263536, 2.4985945254813657, 2.5854032680243244, 2.6709801698056057, 2.755397578040307, 2.8387206454808362, 2.921008314618183, 3.0023141333905135, 3.08268693659861, 3.162171419279195, 3.240808622403426, 3.3186363468599764, 3.3956895083430396, 3.472000443210098, 3.547599173399863, 3.622513636961613, 3.696769889537404, 3.770392281180388, 3.8434036121279167, 3.9158252705339414, 3.987677354668677, 4.058978781689621, 4.129747384757628, 4.2, 4.2697525445979565, 4.339020087089176, 4.407816910820438, 4.476156571354814, 4.544051948527987, 4.611515293755458, 4.678558273113557, 4.745192006650217, 4.811427104324052, 4.877273698921278, 4.942741476257699, 5.007839702936568, 5.0725772519016585, 5.136962625997451, 5.201003979724622, 5.264709139358267, 5.328085621578067, 5.391140650743839, 5.453881174935811, 5.516313880866723, 5.578445207762004, 5.640281360294627, 5.701828320652775, 5.763091859810878, 5.824077548067855, 5.8847907649104245, 5.945236708253967, 6.005420403108665, 6.065346709714352, 6.125020331183648, 6.184445820689512, 6.243627588230225, 6.302569907002016, 6.361276919406997, 6.419752642721805, 6.478000974450254, 6.536025697381442, 6.593830484373017, 6.651418902877808, 6.70879441923056, 6.765960402710261, 6.822920129392379, 6.879676785804213, 6.9362334723956485, 6.992593206836655, 7.048758927152051, 7.104733494703375, 7.1605196970268805, 7.216120250536171, 7.271537803097318, 7.326774936483807, 7.38183416871816, 7.436717956306575, 7.4914286963726004, 7.5459687286953585, 7.600340337657556, 7.654545754108144, 7.708587157144184, 7.762466675816217], [0.0, 0.3090583891496702, 0.5020668344016351, 0.6668457919866766, 0.815609978747435, 0.9534974583152247, 1.0832941850824997, 1.2067273742460802, 1.3249623194593247, 1.4388326798499795, 1.548961190872242, 1.6558287398877471, 1.7598165955840714, 1.8612335967290246, 1.9603344029600933, 2.0573321743406154, 2.1524076381251054, 2.245715733319309, 2.3373905843276206, 2.4275492931872704, 2.516294878297574, 2.6037185847151716, 2.6899017238586973, 2.7749171554598737, 2.8588304938212685, 2.9417010989897725, 3.023582898243771, 3.1045250723358198, 3.1845726329278117, 3.263766911730222, 3.342145977417899, 3.4197449930321326, 3.496596524005164, 3.572730804954834, 3.648175971847019, 3.7229582649051682, 3.797102206681223, 3.8706307589322373, 3.9435654613284927, 4.0159265545188365, 4.087733089672254, 4.159003026281913, 4.229753319744328, 4.3, 4.369758242333992, 4.4390424312780805, 4.507866218424621, 4.576242574851651, 4.644183838765211, 4.711701758885561, 4.778807534036429, 4.845511849338689, 4.91182490936047, 4.977756468533091, 5.043315859105571, 5.108512016878715, 5.173353504932204, 5.23784853553421, 5.302004990402127, 5.365830439464726, 5.429332158260083, 5.4925171440894855, 5.555392131035176, 5.617963603938851, 5.680237811428156, 5.742220778069834, 5.803918315720613, 5.865336034140099, 5.92647935092396, 5.987353500810252, 6.047963544406952, 6.108314376384433, 6.168410733172747, 6.228257200200094, 6.287858218705729, 6.347218092157732, 6.4063409923035035, 6.4652309648785655, 6.523891934997131, 6.582327712246045, 6.640541995501933, 6.698538377489901, 6.756320349100639, 6.813891303481523, 6.871254539916146, 6.928413267505562, 6.985370608663624, 7.042129602437851, 7.098693207666394, 7.155064305981028, 7.211245704665261, 7.267240139376105, 7.323050276737442, 7.378678716812362, 7.434127995461369, 7.489400586592854, 7.5444989043118875, 7.5994253049728755, 7.654182089141375, 7.708771503469945, 7.763195742492644, 7.817456950342467], [0.0, 0.3111972875488455, 0.5055414851022205, 0.671460827355564, 0.8212545654635376, 0.9600963220212687, 1.090791332157795, 1.215078764597002, 1.3341319776325147, 1.4487903998914242, 1.5596810765891669, 1.6672882231614379, 1.7719957469395589, 1.874114624069807, 1.9739012766109785, 2.071570339841886, 2.1673037917749873, 2.2612576437014065, 2.353566948259436, 2.4443496179136215, 2.5337093840220484, 2.6217381231204318, 2.708517709358816, 2.794121506708799, 2.8786155835694283, 2.9620597108002884, 3.0445081888939325, 3.1260105389678325, 3.206612084195799, 3.28635444233241, 3.365275945514146, 3.4434120001349298, 3.520795397002379, 3.597456579978859, 3.673423879750644, 3.748723718141728, 3.823380787417119, 3.8974182082451554, 3.970857669365576, 4.043719551506555, 4.11602303768438, 4.18778621168437, 4.25902614624614, 4.329758982248496, 4.4, 4.469763683583365, 4.539063779069434, 4.607913347305099, 4.676324811885343, 4.744310002839721, 4.811880196495585, 4.8790461519222585, 4.945818144310558, 5.012205995599233, 5.078219102622939, 5.143866463024418, 5.209156699145803, 5.274098080089856, 5.338698542120921, 5.402965707556929, 5.4669069022877235, 5.53052917204077, 5.5938392975028295, 5.6568438083952035, 5.719548996590372, 5.781960928349259, 5.844085455750672, 5.905928227377643, 5.967494698319361, 6.028790139541899, 6.089819646676151, 6.150588148267005, 6.211100413523892, 6.271361059609355, 6.331374558499108, 6.39114524344421, 6.4506773150634515, 6.509974847091646, 6.569041791807524, 6.627881985162909, 6.68649915163322, 6.744896908807713, 6.803078771736462, 6.861048157049777, 6.91880838686458, 6.976362692491129, 7.033714217952552, 7.090866023328679, 7.147821087934875, 7.204582313345805, 7.261152526273326, 7.317534481307094, 7.3737308635258785, 7.429744290987008, 7.4855773171008995, 7.541232432897109, 7.596712069187985, 7.652018598635541, 7.707154337726844, 7.762121548662846, 7.816922441165305, 7.8715591742061015], [0.0, 0.3133024233726665, 0.5089612883373283, 0.6760030142527965, 0.826810052209104, 0.9665910224658812, 1.098170136541745, 1.2232983280008631, 1.3431568924765378, 1.458590937023486, 1.5702317485886719, 1.6785668181481022, 1.7839826500257734, 1.8867923240078466, 1.9872539967545546, 2.085583755473864, 2.181964809192925, 2.2765542245621813, 2.369487967801627, 2.4608847490104995, 2.5508490012515814, 2.6394732225717457, 2.726839840969715, 2.8130227166975206, 2.8980883650827636, 2.982096961313032, 3.0651031732038483, 3.147156856864932, 3.228303642064787, 3.308585428086877, 3.388040806370566, 3.466705422821081, 3.5446122900638595, 3.62179205790286, 3.698273248671087, 3.7740824629265095, 3.8492445599682767, 3.9237828168675914, 3.9977190690805835, 4.0710738352036, 4.143866428019014, 4.21611505364234, 4.287836900304032, 4.359048218070036, 4.429764390614615, 4.5, 4.569768885284177, 4.63908419566589, 4.7079584387811995, 4.77640352468548, 4.844430805986317, 4.912051114534201, 4.979274795027855, 5.046111735847853, 5.1125713973949996, 5.178662838177798, 5.244394738865373, 5.309775424497943, 5.374812885025776, 5.4395147943289945, 5.50388852785441, 5.567941178991257, 5.63167957429516, 5.695110287658598, 5.7582396535162665, 5.821073779165128, 5.88361855627116, 5.945879671627994, 6.007862617226501, 6.069572699688912, 6.131015049116201, 6.192194627393058, 6.2531162359908725, 6.313784523305604, 6.374203991564244, 6.434379003330712, 6.494313787639447, 6.55401244578259, 6.613478956774588, 6.67271718251608, 6.731730872677197, 6.790523669318862, 6.849099111269179, 6.90746063827071, 6.965611594913286, 7.023555234365795, 7.08129472191953, 7.138833138354645, 7.196173483140481, 7.253318677479797, 7.31027156720612, 7.367034925542897, 7.423611455732474, 7.48000379354238, 7.536214509655919, 7.592246111953552, 7.648101047691181, 7.703781705581013, 7.759290417780303, 7.814629461792964, 7.869801062288711, 7.924807392844083], [0.0, 0.3153750624359296, 0.5123283004291624, 0.6804750838880746, 0.8322797794894092, 0.9729854649020294, 1.1054350350975983, 1.2313910068679625, 1.3520424906582238, 1.468240184293433, 1.5806195509729186, 1.6896713066488271, 1.7957845125483272, 1.8992743196237953, 2.000400592360041, 2.099380847480907, 2.196399506025191, 2.2916146737111873, 2.3851632162377236, 2.4771646290257294, 2.5677240360105404, 2.656934547155986, 2.7448791357597635, 2.831632150693308, 2.9172605473135858, 3.0018248988946183, 3.085380234904573, 3.1679767412741753, 3.249660349633752, 3.330473236449723, 3.410454248461502, 3.489639267388311, 3.5680615242492277, 3.6457518716107056, 3.7227390204940494, 3.7990497474321048, 3.8747090761796743, 3.94974043779645, 4.024165812190108, 4.098005853696909, 4.171280002862133, 4.244006586243084, 4.316202905778239, 4.387885319035173, 4.459069311458202, 4.529769561576579, 4.6000000000000005, 4.669773862915182, 4.7391037407019265, 4.808001622206084, 4.8764789351379365, 4.944546583005629, 5.012214978942809, 5.079494076746213, 5.146393399401535, 5.212922065343459, 5.279088812667716, 5.344902021488475, 5.41036973461319, 5.475499676688215, 5.540299271952319, 5.604775660720756, 5.6689357147099475, 5.732786051301678, 5.7963330468358345, 5.859582849011943, 5.9225413884720535, 5.985214389630541, 6.047607380810313, 6.109725703739338, 6.171574522456557, 6.233158831671801, 6.294483464620392, 6.35555310044956, 6.416372271170588, 6.476945368207757, 6.5372766485725045, 6.597370240688899, 6.657230149894391, 6.7168602636378605, 6.776264356395225, 6.835446094321308, 6.894409039655184, 6.9531566548948875, 7.011692306756243, 7.070019269929341, 7.128140730645328, 7.186059790065128, 7.243779467500948, 7.301302703480639, 7.358632362664221, 7.415771236621288, 7.472722046477369, 7.529487445436804, 7.586070021189144, 7.642472298205629, 7.69869673993188, 7.754745750882529, 7.81062167864312, 7.866326815784296, 7.921863401692986, 7.977233624324929], [0.0, 0.31741639680246586, 0.5156444578911292, 0.6848796083409062, 0.8376668931797635, 0.9792833270484642, 1.1125902061808424, 1.2393614556458328, 1.3607938826670913, 1.4777436913982045, 1.5908504582136442, 1.7006080753323471, 1.807408122265735, 1.9115677898499497, 2.01334862459976, 2.1129695511637836, 2.210616184286502, 2.3064476530601987, 2.400601709077002, 2.4931986212182013, 2.584344193856896, 2.674132139631608, 2.762645968902929, 2.8499605117816973, 2.936143157008134, 3.021254869930082, 3.105351036206029, 3.1884821666061613, 3.270694490063372, 3.3520304560405236, 3.432529162721085, 3.512226724076587, 3.591156586221178, 3.6693498014213244, 3.7468352665367233, 3.823639931417211, 3.899788981789339, 3.9753060003754817, 4.050213109353093, 4.124531096748165, 4.1982795289391746, 4.2714768511060965, 4.3441404771780014, 4.416286870600417, 4.487931617050597, 4.559089490067801, 4.6297745104306545, 4.699999999999999, 4.76977863064964, 4.8391224688258605, 4.908043016207312, 4.976551246877489, 5.044657641371333, 5.112372217913719, 5.179704561129953, 5.246663848475797, 5.31325887460622, 5.379498073877525, 5.445389541156001, 5.510941051087474, 5.5761600759657295, 5.641053802323279, 5.705629146355237, 5.76989276827585, 5.833851085697259, 5.897510286111331, 5.960876338547496, 6.02395500447266, 6.086751847993016, 6.149272245412037, 6.211521394194043, 6.273504321378221, 6.335225891484069, 6.396690813945627, 6.457903650108615, 6.5188688198217735, 6.579590607650981, 6.640073168742437, 6.70032053435902, 6.7603366171119745, 6.820125215908345, 6.879690020632947, 6.939034616582228, 6.998162488666004, 7.057077025391905, 7.1157815226461745, 7.174279187283538, 7.232573140537865, 7.290666421264526, 7.348561989024582, 7.406262727020198, 7.46377144489001, 7.521090881372633, 7.578223706845854, 7.635172525748614, 7.691939878892346, 7.748528245667867, 7.804940046153555, 7.861177643130216, 7.917243344007665, 7.9731394026677505, 8.028868021228238], [0.0, 0.31942755054951544, 0.5189115867920929, 0.689219012998221, 0.8429743597377884, 0.9854880768737933, 1.119639589844169, 1.2472140633264062, 1.369415887527764, 1.487106691520671, 1.6009301040424733, 1.7113831466185851, 1.8188598798124778, 1.9236795041848853, 2.0261052234121424, 2.126357349251824, 2.224622672505455, 2.32106133050898, 2.4158119476501163, 2.508995554835094, 2.600718626814673, 2.6910754699916732, 2.7801501238492414, 2.8680178926226123, 2.9547465920277993, 3.0403975736897526, 3.125026574191096, 3.2086844243388057, 3.2914176459727966, 3.373268957516191, 3.4542777048789737, 3.534480230851192, 3.6139101934619378, 3.692598841725177, 3.770575255591423, 3.8478665556650555, 3.9244980872496638, 4.000493582488006, 4.075875303723897, 4.1506641706964835, 4.2248798737570326, 4.2985409749543795, 4.371664998552439, 4.444268512309309, 4.516367200653263, 4.587975930728868, 4.659108812150555, 4.7297792511866215, 4.800000000000001, 4.869783201490114, 4.939140430210371, 5.0080827297761825, 5.07662064712727, 5.144764263964093, 5.212523225640247, 5.279906767759952, 5.346923740701208, 5.413582632260493, 5.479891588593254, 5.5458584336055585, 5.611490686935728, 5.676795580650222, 5.741780074765242, 5.806450871694224, 5.870814429711371, 5.934876975512564, 5.99864451594707, 6.062122848986512, 6.1253175739913175, 6.188234101329281, 6.250877661395911, 6.31325331308177, 6.375365951728004, 6.437220316607679, 6.4988209979672495, 6.560172443659669, 6.6212789653978685, 6.682144744655102, 6.742773838236372, 6.803170183543272, 6.863337603552759, 6.923279811528803, 6.9830004154843275, 7.042502922409574, 7.1017907422817945, 7.160867191870005, 7.219735498347595, 7.278398802724608, 7.336860163110633, 7.395122557818545, 7.453188888318506, 7.511061982051055, 7.568744595107485, 7.626239414785125, 7.68354906202467, 7.740676093736161, 7.7976230050198625, 7.854392231287795, 7.910986150291372, 7.967407084060179, 8.023657300756685, 8.079739016451299], [0.0, 0.32140958497160377, 0.5221314112100965, 0.6934955877826132, 0.848204979936528, 0.9916029886513194, 1.1265869060778075, 1.254952973764698, 1.377913055109475, 1.4963341255564682, 1.6108638075320783, 1.722002206559234, 1.8301458283305128, 1.9356158540326087, 2.03867712050952, 2.139551306543947, 2.2384263619664257, 2.3354634177582887, 2.430801958465707, 2.5245637659865583, 2.616855975742921, 2.70777347930485, 2.7974008376169266, 2.8858138221739744, 2.973080669485653, 3.0592631118611475, 3.1444172317262153, 3.228594175290837, 3.3118407530609746, 3.394199948525756, 3.475711351734871, 3.5564115309838393, 3.636334353148399, 3.715511261141324, 3.7939715153529883, 3.871742404669973, 3.9488494316624023, 4.025316475729977, 4.10116593735341, 4.176418866077946, 4.251095074432645, 4.32521323964307, 4.398790994710453, 4.471845010195126, 4.544391067846578, 4.616444127059378, 4.688018384997516, 4.759127331114618, 4.829783796700246, 4.9, 4.969787587386903, 5.039157671001529, 5.108120863226918, 5.17668730832005, 5.244866711483534, 5.312668365628121, 5.380101176048034, 5.447173683206165, 5.513894083804514, 5.580270250296152, 5.64630974897844, 5.712019856792501, 5.777407576941144, 5.842479653425996, 5.907242584594577, 5.971702635779154, 6.035865851101239, 6.099738064508621, 6.163324910105525, 6.226631831830848, 6.289664092534478, 6.352426782497182, 6.414924827435491, 6.477162996029456, 6.539145907007821, 6.600878035822276, 6.662363720939749, 6.723607169779357, 6.784612464318407, 6.845383566389902, 6.905924322692211, 6.966238469529947, 7.0263296373036015, 7.086201354764143, 7.145857053047588, 7.2053000695033615, 7.264533651329331, 7.323560959025371, 7.382385069676512, 7.441008980075934, 7.499435609697299, 7.5576678035252955, 7.615708334752644, 7.673559907351242, 7.731225158524609, 7.7887066610483044, 7.846006925504585, 7.9031284024171, 7.960073484291109, 8.016844507564292, 8.073443754472972, 8.12987345483818], [0.0, 0.32336350328867863, 0.5253055608807533, 0.6977114973109453, 0.8533614012892966, 0.9976311574844396, 1.1334356713122251, 1.2625821040618639, 1.3862896863102925, 1.5054306640329025, 1.6206565966927622, 1.7324706300623371, 1.8412716802779867, 1.9473828810562392, 2.051070679241494, 2.152558101249671, 2.2520342394989386, 2.349661204520682, 2.4455793288177676, 2.539911134626546, 2.6327644086684745, 2.7242346193799687, 2.8144068417698618, 2.903357307964268, 2.991154669297334, 3.0778610333622907, 3.1635328235220808, 3.2482214969155465, 3.33197414861983, 3.414834023429978, 3.4968409520721466, 3.578031725148427, 3.6584404154186108, 3.7380986569437336, 3.8170358879944053, 3.8952795633522452, 3.9728553406230125, 4.0497872443744365, 4.126097811264594, 4.201808218803465, 4.276938399964752, 4.351507145516909, 4.425532195655993, 4.499030322286276, 4.5720174030979095, 4.644508488426855, 4.716517861744731, 4.788059094510466, 4.859145096017805, 4.9297881587897034, 5.0, 5.069791799342375, 5.139174233714836, 5.208157509043494, 5.2767513895309826, 5.344965224581665, 5.41280797362697, 5.480288229049111, 5.547414237379611, 5.614193918929883, 5.6806348859944436, 5.746744459752516, 5.81252968598089, 5.877997349679437, 5.943153988700536, 6.008005906464762, 6.072559183837146, 6.136819690231311, 6.200793094002415, 6.2644848721842346, 6.327900319620664, 6.391044557537383, 6.4539225415954204, 6.516539069464663, 6.578898787952104, 6.641006199716671, 6.702865669599771, 6.764481430598331, 6.82585758950488, 6.886998132237258, 6.947906928878747, 7.008587738447762, 7.069044213414784, 7.129279903982821, 7.189298262146506, 7.249102645543735, 7.308696321112788, 7.368082468566905, 7.427264183697381, 7.4862444815155476, 7.5450262992431805, 7.603612499160242, 7.662005871318293, 7.7202091361272585, 7.778224946822788, 7.836055891820902, 7.893704496966226, 7.951173227679674, 8.008464491011061, 8.065580637601778, 8.122523963562356, 8.179296712269386], [0.0, 0.32529025491464564, 0.5284355781315032, 0.7018687901044354, 0.8584461293144126, 1.0035755124758021, 1.1401892133799587, 1.2701051612318202, 1.394549851356733, 1.5144007269812758, 1.6303132298658147, 1.7427935037616387, 1.8522428417348054, 1.958986302884292, 2.0632919216699377, 2.1653840534037974, 2.2654529172054767, 2.363661589537046, 2.460151239068333, 2.555045118080716, 2.6484516555395645, 2.7404668887270756, 2.8311763995689425, 2.9206568744180905, 3.0089773736655583, 3.0962003749707874, 3.1823826378936166, 3.26757592617869, 3.351827615517738, 3.4351812083786064, 3.5176767728176257, 3.599351318652573, 3.6802391216647465, 3.7603720044057742, 3.839779580553309, 3.918489468477453, 3.9965274786640315, 4.073917778830432, 4.150683039918725, 4.22684456562444, 4.302422407691301, 4.377435468851986, 4.4519015950069685, 4.525837657995406, 4.599259630114185, 4.672182651376238, 4.7446210903608135, 4.816588599391969, 4.8880981646830834, 4.959162152001737, 5.029792348338194, 5.1000000000000005, 5.169795847503137, 5.239190157585416, 5.308192752629174, 5.376813037746919, 5.44506002575458, 5.512942360231818, 5.580468336846865, 5.6476459231040685, 5.714482776655572, 5.780986262303623, 5.847163467807058, 5.913021218593963, 5.978566091472315, 6.043804427421427, 6.108742343538982, 6.1733857442113225, 6.237740331568332, 6.301811615278527, 6.365604921734966, 6.4291254026779985, 6.4923780432968075, 6.555367669848051, 6.618098956826582, 6.680576433720284, 6.7428044913783385, 6.804787388019857, 6.866529254907566, 6.928034101709279, 6.989305821568049, 7.0503481959002885, 7.111164898939614, 7.17175950204281, 7.232135477773115, 7.292296203774807, 7.352244966452122, 7.411984964464522, 7.471519312049482, 7.530851042183187, 7.589983109588758, 7.648918393600967, 7.707659700895813, 7.7662097680927005, 7.824571264236503, 7.8827467931662385, 7.940738895776703, 7.998550052178945, 8.056182683765114, 8.113639155182824, 8.170921776223912, 8.228032803632061], [0.0, 0.3271907393351147, 0.5315229241810306, 0.7059694069555519, 0.8634615377686319, 1.0094388286908083, 1.146850685107675, 1.277525657342015, 1.4026974064280227, 1.523248501989876, 1.639838215158281, 1.7529756467922157, 1.8630644344829992, 1.9704315364635174, 2.0753465531652537, 2.178035150679693, 2.278688659467676, 2.3774711087535225, 2.4745244919746456, 2.569972781504824, 2.663925039797692, 2.7564778652262145, 2.8477173397221986, 2.937720597672954, 3.0265571029497815, 3.114289698233258, 3.2009754746967825, 3.2866664985108733, 3.371410422156261, 3.455251002260765, 3.5382285409753904, 3.6203802643450564, 3.701740648404796, 3.7823417016271574, 3.86221321070553, 3.941382955368315, 4.0198768968972045, 4.097719344207701, 4.174933100695187, 4.2515395945204695, 4.327558994578111, 4.403010314038617, 4.477911503065826, 4.552279532071374, 4.62613046666912, 4.699479535326408, 4.7723411905698585, 4.844729164486227, 4.916656519159892, 4.98813569260452, 5.059178540675003, 5.129796375384611, 5.2, 5.269799741241645, 5.33920547887843, 5.408226672971542, 5.476872388993622, 5.545151321023816, 5.613071813197183, 5.680641879567632, 5.7478692225265755, 5.814761249904579, 5.881325090870187, 5.94756761072855, 6.01349542471216, 6.079114910847038, 6.14443222196956, 6.209453296962013, 6.274183871268555, 6.338629486747534, 6.402795500911071, 6.46668709559818, 6.5303092851236455, 6.593666923941175, 6.656764713856015, 6.719607210819247, 6.782198831333269, 6.844543858495524, 6.906646447705338, 6.968510632056713, 7.0301403274381045, 7.091539337358574, 7.152711357518177, 7.213659980139087, 7.274388698072739, 7.33490090869705, 7.395199917616831, 7.455288942179478, 7.515171114817167, 7.574849486226025, 7.634327028391926, 7.6936066374719445, 7.752691136539877, 7.811583278203625, 7.870285747101763, 7.928801162286045, 7.98713207949626, 8.045280993333321, 8.103250339336185, 8.161042495967745, 8.218659786514628, 8.276104480905376], [0.0, 0.32906580963691906, 0.5345689848729845, 0.7100151885435476, 0.868409877961604, 1.0152237380467777, 1.153423076687642, 1.284846923294538, 1.4107360087874778, 1.5319779606357815, 1.6492358281324606, 1.763021629700429, 1.8737413161042387, 1.9817237193146255, 2.08723998479385, 2.1905170718845057, 2.2917474075273203, 2.391095960968107, 2.4887055393827042, 2.5847008256078983, 2.6791915071143038, 2.772274735862497, 2.8640370871040988, 2.9545561372694875, 3.043901748314709, 3.132137123060253, 3.219319679858593, 3.305501783261952, 3.390731358838714, 3.4750524139779313, 3.5585054817948683, 3.6411280016701, 3.722954647214513, 3.804017610335359, 3.8843468484281214, 3.963970300421744, 4.042914076377278, 4.121202624520177, 4.198858878927912, 4.275904390562161, 4.352359443901735, 4.428243161078141, 4.503573595124327, 4.578367813706253, 4.6526419745068734, 4.726411393265096, 4.799690605332327, 4.872493421491402, 4.944832978683115, 5.016721786201115, 5.088171767844031, 5.159194300452213, 5.229800249203863, 5.300000000000001, 5.369803489228662, 5.439220231164912, 5.508259343233962, 5.57692956933913, 5.645239301434192, 5.713196599500134, 5.780809210069365, 5.84808458342537, 5.91502988959266, 5.981652033220191, 6.047957667451143, 6.113953206862838, 6.179644839552433, 6.245038538436862, 6.310140071829065, 6.37495501334677, 6.439488751205017, 6.503746496938993, 6.567733293599603, 6.631454023460543, 6.694913415272243, 6.758116051095109, 6.821066372741707, 6.8837686878551265, 6.946227175648528, 7.008445892328838, 7.0704287762257545, 7.132179652645551, 7.193702238467664, 7.25500014650064, 7.316076889612803, 7.376935884651822, 7.437580456166325, 7.498013839941737, 7.558239186361631, 7.618259563605117, 7.6780779606899765, 7.737697290370628, 7.797120391899389, 7.856350033658854, 7.915388915672771, 7.974239672002199, 8.032904873033404, 8.091387027663403, 8.14968858538878, 8.207811938302967, 8.265759423006916, 8.323533322437719], [0.0, 0.3309162757266209, 0.5375750759044572, 0.7140078823789322, 0.8732932872495612, 1.0209327392425835, 1.1599092269590578, 1.292072121392869, 1.418669130580541, 1.5405928734687344, 1.6585101279366483, 1.7729357916875745, 1.8842780983064067, 1.9928677289150025, 2.0989773537328853, 2.2028352083840343, 2.304634801901323, 2.4045420312173276, 2.5027005065686367, 2.5992356119325217, 2.694257651595259, 2.7878643238409966, 2.8801426907679444, 2.9711707650491714, 3.0610188015018984, 3.149750358360859, 3.2374231768644393, 3.324089916031274, 3.4097987709340116, 3.4945939964325112, 3.578516353575638, 3.6616034922802876, 3.7438902811406565, 3.825409093091715, 3.9061900539911285, 3.986261259879396, 4.065648967644679, 4.144377762994392, 4.222470708973315, 4.299949477732636, 4.376834467818745, 4.4531449088943935, 4.528898955511812, 4.604113771315139, 4.678805604848319, 4.7529898579766625, 4.826681147789558, 4.899893362733288, 4.972639713622818, 5.0449327800964605, 5.116784553005038, 5.188206473165336, 5.259209466854715, 5.32980397837819, 5.4, 5.4698070994977135, 5.539234445567397, 5.6082908312827655, 5.6769846957888435, 5.7453241443910485, 5.813316967183581, 5.8809706563457915, 5.948292422222049, 6.015289208288859, 6.081967705102637, 6.148334363312386, 6.214395405813359, 6.280156839110547, 6.345624463954374, 6.4108038853052065, 6.475700521678132, 6.540319613914841, 6.604666233425293, 6.668745289938123, 6.732561538795379, 6.796119587824191, 6.859423903815176, 6.922478818634993, 6.985288534998154, 7.04785713192123, 7.11018856988069, 7.172286695694005, 7.234155247142084, 7.295797857349709, 7.357218058939442, 7.418419287973228, 7.479404887694932, 7.540178112086074, 7.600742129246067, 7.6611000246075935, 7.721254803996855, 7.7812093965478315, 7.840966657479069, 7.900529370740865, 7.9599002515402555, 8.019081948750662, 8.078077047212638, 8.136888069931713, 8.195517480178951, 8.25396768349946, 8.312241029633823, 8.370339814356978], [0.0, 0.33274290727063255, 0.5405424476022238, 0.7179491491472785, 0.8781137967943424, 1.026568206829422, 1.166311833713595, 1.2992042568216624, 1.4265000714393543, 1.5490968236989802, 1.6676649720406431, 1.7827222563620384, 1.8946791636650053, 2.0038682004049155, 2.110563541919235, 2.214994683674448, 2.3173562028579133, 2.417814912140089, 2.516515214474659, 2.613583185948484, 2.709129739718734, 2.8032531133563223, 2.8960408495353223, 2.987571391552558, 3.0779153820262577, 3.1671367300275604, 3.2552934955218995, 3.3424386282015077, 3.4286205891720045, 3.513883877576558, 3.598269479461784, 3.6818152525691277, 3.7645562579646543, 3.846525047279362, 3.927751912663257, 4.008265105244749, 4.088091026847936, 4.167254398891381, 4.245778411726042, 4.323684857131658, 4.4009942462529725, 4.477725914898949, 4.553898117833501, 4.629528113442723, 4.704632239961227, 4.779225984271398, 4.853324044147796, 4.926940384699823, 5.000088289665092, 5.07278040812052, 5.145028797105475, 5.216844960589141, 5.288239885161059, 5.359224072777979, 5.429807570860648, 5.5, 5.569810579502579, 5.639248150979169, 5.708321200158201, 5.777037877085737, 5.845406014856678, 5.913433147006608, 5.981126523680426, 6.048493126682073, 6.115539683499306, 6.1822726803881975, 6.248698374593888, 6.314822805776799, 6.380651806707037, 6.4461910132839, 6.511445873932252, 6.576421658422812, 6.6411234661593195, 6.705556233971722, 6.769724743451177, 6.833633627859654, 6.8972873786441, 6.960690351582731, 7.023846772588714, 7.086760743194463, 7.149436245737964, 7.211877148270815, 7.2740872092061775, 7.336070081723395, 7.397829317944825, 7.4593683728992, 7.520690608284828, 7.581799296044945, 7.642697621766623, 7.703388687913888, 7.7638755169048626, 7.824161054042115, 7.884248170304769, 7.944139665010305, 8.003838268353489, 8.063346643829313, 8.122667390546445, 8.181803045437203, 8.24075608536971, 8.299528929167499, 8.358123939541525, 8.416543424939226], [0.0, 0.3345464363856253, 0.5434722892933261, 0.7218405685142383, 0.882873338663427, 1.032132399511182, 1.172633463125675, 1.3062461881515304, 1.4342319700167976, 1.5574932197225673, 1.676704029719738, 1.7923849461535883, 1.9049486809426819, 2.014729542789891, 2.1220031931145575, 2.227000371291741, 2.329916709153737, 2.430919923527039, 2.5301552000564884, 2.62774929818504, 2.723813732240028, 2.8184472722584695, 2.911737935412189, 3.003764590175428, 3.094598262062686, 3.1843032065442842, 3.2729377982815833, 3.3605552739641027, 3.4472043573657656, 3.5329297888234614, 3.617772776535886, 3.7017713834405583, 3.7849608606411147, 3.8673739362045136, 3.9490410664699085, 4.029990655692137, 4.110249248798147, 4.189841701201238, 4.26879132894843, 4.347120041935005, 4.424848462479969, 4.501996031196003, 4.578581101791275, 4.654621026195573, 4.730132231199817, 4.805130287628203, 4.879629972919994, 4.953645327878109, 5.027189708240518, 5.100275831644512, 5.172915820480879, 5.2451212410724795, 5.316903139558235, 5.388272074817476, 5.459238148729857, 5.529811034031726, 5.6000000000000005, 5.669813936168658, 5.739261374260372, 5.808350508495987, 5.877089214427251, 5.945485066422926, 6.013545353925061, 6.081277096580288, 6.1486870583406095, 6.215781760618827, 6.2825674945755265, 6.349050332607224, 6.4152361390987345, 6.481130580496994, 6.54673913475835, 6.612067100216671, 6.677119603915424, 6.741901609443101, 6.8064179243079845, 6.870673206885194, 6.934671972966164, 6.998418601938248, 7.0619173426198545, 7.125172318774476, 7.1881875343251185, 7.250966878288947, 7.3135141294504304, 7.375832960789829, 7.437926943682672, 7.499799551884596, 7.561454165314949, 7.622894073651511, 7.684122479747837, 7.745142502883891, 7.80595718185987, 7.866569477942434, 7.926982277671956, 7.987198395538743, 8.04722057653573, 8.107051498594549, 8.166693774911531, 8.22614995616964, 8.285422532662094, 8.344513936322901, 8.403426542669354, 8.46216267266111], [0.0, 0.3363275601044944, 0.5463657333110428, 0.7256836444462762, 0.8875737523376529, 1.037627467752362, 1.1788765583960286, 1.3132006369674705, 1.441867814558309, 1.5657853066017353, 1.6856307944138171, 1.8019275955251637, 1.9150906191307318, 2.025455953791421, 2.133300728546726, 2.2388569112270993, 2.3423211752078297, 2.443862130239038, 2.543625734933285, 2.6417394236002276, 2.7383153042689763, 2.833452672827779, 2.927240015051488, 3.019756619309744, 3.1110738892565672, 3.2012564224581115, 3.2903629043621723, 3.378446855090164, 3.4655572578211618, 3.5517390910894084, 3.637033782485862, 3.721479597594951, 3.8051119751970273, 3.88796381760313, 3.9700657433018267, 4.0514463077720775, 4.1321321972659035, 4.212148399526711, 4.291518354736051, 4.370264089437388, 4.4484063357428605, 4.525964637766885, 4.602957446932689, 4.679402207551657, 4.755315433870868, 4.830712779613518, 4.905609100893888, 4.980018513268069, 5.053954443579921, 5.127429677175377, 5.200456400984781, 5.273046242910041, 5.345210307899675, 5.416959211048439, 5.488303108018347, 5.559251723043356, 5.629814374749968, 5.7, 5.7698171759389805, 5.839274140413748, 5.908378810905451, 5.977138802108759, 6.045561442274676, 6.113653788422401, 6.181422640515188, 6.248874554685808, 6.316015855588962, 6.382852647950572, 6.4493908273774165, 6.515636090484566, 6.581593944392985, 6.647269715644847, 6.712668558579974, 6.777795463212983, 6.842655262647308, 6.907252640059236, 6.971592135282254, 7.035678151019556, 7.099514958710239, 7.163106704072696, 7.226457412346798, 7.289570993254823, 7.352451245699468, 7.415101862215926, 7.477526433193712, 7.539728450882724, 7.601711313196984, 7.663478327328502, 7.725032713182809, 7.786377606646905, 7.847516062699542, 7.908451058373153, 7.9691854955760375, 8.029722203782837, 8.090063942600816, 8.150213404218903, 8.210173215746073, 8.269945941445116, 8.32953408486756, 8.388940090895016, 8.448166347692025, 8.507215188575021], [0.0, 0.33808694264019046, 0.5492238586724956, 0.7294798100952713, 0.8922167906855061, 1.0430554607623752, 1.1850434476867515, 1.3200701967080628, 1.4494104526071443, 1.5739761766042668, 1.6944485950733934, 1.8113537631017094, 1.9251087603396386, 2.0360514334803734, 2.1444603612691426, 2.2505687249967217, 2.354574226867858, 2.4566463586568803, 2.5569318425088823, 2.6555587793625026, 2.752639863701641, 2.8482749108470053, 2.942552869456497, 3.035553442669731, 3.1273484076645066, 3.2180026999270397, 3.3075753118979634, 3.3961200436708916, 3.483686134663639, 3.570318798700257, 3.6560596800859697, 3.7409472445785146, 3.825017116344097, 3.9083023698109356, 3.9908337836377425, 4.072640062681695, 4.153748032794809, 4.23418281243532, 4.313967964404065, 4.393125630468836, 4.471676651194719, 4.549640672934478, 4.627036243633647, 4.703880898857555, 4.780191239241914, 4.855983000397015, 4.931271116151819, 5.006069775903117, 5.0803924767327056, 5.154252070868684, 5.227660808993148, 5.300630379835398, 5.373171946435688, 5.44529617941801, 5.517013287570251, 5.588333045995365, 5.659264822067065, 5.7298175993973, 5.800000000000001, 5.86982030481548, 5.939286472742482, 6.008406158309345, 6.07718672810231, 6.145635276056957, 6.21375863770822, 6.281563403485038, 6.349055931127373, 6.416242357295939, 6.483128608438357, 6.549720410969595, 6.616023300819232, 6.6820426323934266, 6.747783586995166, 6.813251180742619, 6.878450272021948, 6.943385568507873, 7.008061633782467, 7.07248289358016, 7.136653641684619, 7.200578045501145, 7.264260151326274, 7.327703889334657, 7.390913078301653, 7.453891430078686, 7.516642553837167, 7.579169960095506, 7.641477064542745, 7.70356719167134, 7.765443578230657, 7.827109376512012, 7.888567657475236, 7.949821413726088, 8.010873562353208, 8.071726947632662, 8.13238434360766, 8.192848456550395, 8.253121927312662, 8.313207333571317, 8.373107191974357, 8.432823960192957, 8.492360038884522, 8.551717773571434], [0.0, 0.33982521746716876, 0.5520476944599734, 0.7332304322895956, 0.8968041254560968, 1.0484183329171723, 1.1911363514170852, 1.326857340792548, 1.4568625999277454, 1.5820687788937515, 1.7031606065915654, 1.8206668428218662, 1.9350067116511012, 2.0465197968120465, 2.1554861093632187, 2.2621400294975587, 2.3666802759061736, 2.469277211805758, 2.570078313713666, 2.6692123411998194, 2.7667925681670775, 2.8629193231368597, 2.957682012096805, 3.051160747980412, 3.1434276770080123, 3.2345480685317796, 3.3245812183021224, 3.4135812030259647, 3.5015975152857055, 3.5886756013723824, 3.6748573197055143, 3.760181333814624, 3.844683451027653, 3.9283969158250724, 4.011352665114142, 4.09357955133813, 4.175104538274236, 4.255952873527309, 4.3361482410463825, 4.4157128964412, 4.494667787428664, 4.5730326613733085, 4.650826161584972, 4.7280659137881385, 4.804768603970725, 4.880950048647702, 4.956625258430347, 5.03180849567027, 5.106513326844546, 5.180752670261034, 5.254538839588743, 5.327883583654601, 5.400798122893664, 5.473293182792959, 5.5453790246288825, 5.6170654737631045, 5.68836194573171, 5.759277470335912, 5.829820713919745, 5.9, 5.969823328396114, 6.039298392992204, 6.108432598249829, 6.177233074578059, 6.245706692656745, 6.313860076799532, 6.3816996174347205, 6.4492314827746755, 6.516461629737867, 6.583395814181636, 6.65003960049856, 6.7163983706244865, 6.7824773325020855, 6.8482815280399105, 6.913815840603527, 6.979085002072176, 7.0440935994916, 7.1088460813511505, 7.173346763510995, 7.237599834803159, 7.301609362328223, 7.365379296467839, 7.428913475631607, 7.492215630755448, 7.555289389567333, 7.618138280635011, 7.6807657372093, 7.743175100875541, 7.805369625024853, 7.867352478156067, 7.929126747018361, 7.990695439603983, 8.05206148799979, 8.113227751105706, 8.174197017227684, 8.234972006552224, 8.29555537350907, 8.355949709028206, 8.416157542696983, 8.476181344822695, 8.536023528405739, 8.595686451028], [0.0, 0.3415429892379761, 0.5548382229344361, 0.7369368156694741, 0.9013373523370619, 1.0537179496722355, 1.1971573889813278, 1.333564430104194, 1.4642268487223262, 1.5900659284523238, 1.7117698594097048, 1.8298700742063836, 1.944787916031315, 2.0568646851683727, 2.1663818080951383, 2.273574849765597, 2.3786435333676974, 2.481759083281784, 2.583069721499605, 2.6827048584537705, 2.7807783406318185, 2.8773910037026447, 2.9726327055893953, 3.0665839641859085, 3.1593172904021696, 3.250898283518341, 3.341386539017049, 3.430836406955858, 3.519297630095661, 3.606815884452516, 3.6934332400347483, 3.779188555810936, 3.864117820110352, 3.9482544454599435, 4.031629525148967, 4.114272057465996, 4.196209142486576, 4.277466155438878, 4.358066899991182, 4.438033744252411, 4.517387741827422, 4.596148739901077, 4.674335476022694, 4.7519656650124755, 4.829056077203814, 4.905622609062079, 4.981680347075217, 5.057243625689147, 5.132326079957703, 5.206940693489089, 5.281099842196291, 5.354815334295013, 5.428098446938133, 5.500959959828605, 5.573410186112226, 5.645459000816579, 5.717115867072043, 5.7883898603242905, 5.859289690724584, 5.929823723863996, 6.0, 6.0698262519082835, 6.139309921478987, 6.208458175164458, 6.277277918374932, 6.345775808909088, 6.413958269497998, 6.481831499533533, 6.549401486045601, 6.616674013986643, 6.683654675876509, 6.750348880856028, 6.816761863193332, 6.8828986902831595, 6.948764270175846, 7.0143633586696605, 7.079700565997257, 7.144780363134517, 7.209607087757714, 7.274184949872867, 7.338518037139214, 7.402610319907067, 7.466465655988684, 7.530087795179373, 7.593480383544796, 7.656646967489146, 7.719590997617871, 7.782315832407588, 7.844824741694881, 7.907120909994923, 7.969207439660004, 8.03108735388738, 8.092763599585219, 8.154239050104804, 8.215516507846615, 8.276598706747336, 8.337488314654497, 8.3981879355949, 8.458700111942623, 8.519027326492042, 8.579172004440949, 8.639136515288499], [0.0, 0.34324083555054863, 0.5575963824064993, 0.7406002065002301, 0.9058179956184941, 1.0589560930149933, 1.2031085849434697, 1.3401937198907652, 1.4715056752074478, 1.5979703143083863, 1.7202792483749298, 1.8389665518266969, 1.9544556623941856, 2.0670895770010684, 2.177151121125703, 2.2848770307403687, 2.3904680218781, 2.4940961700937385, 2.5959104342062274, 2.69604086796112, 2.7946018837888813, 2.891694818623179, 2.987409977080396, 3.081828277317335, 3.1750225907033816, 3.267058842619656, 3.3579969248042296, 3.4478914574945505, 3.5367924307280343, 3.624745747581046, 3.7117936871963693, 3.797975301714624, 3.883326758366874, 3.96788163577727, 4.051671181803097, 4.134724538886488, 4.217068941820329, 4.298729891975731, 4.37973131135153, 4.460095679250881, 4.539844153938338, 4.618996681261216, 4.697572091915174, 4.775588188782657, 4.853061825564157, 4.9300089777480585, 5.00644480681883, 5.082383718480438, 5.15783941556801, 5.2328249462326415, 5.30735274790929, 5.381434687513548, 5.455082098258211, 5.5283058134332785, 5.601116197452285, 5.673523174432619, 5.745536254546883, 5.817164558355747, 5.888416839309559, 5.9593015045856275, 6.029826634410397, 6.1000000000000005, 6.169829080239, 6.239321077204937, 6.30848293063557, 6.3773213314262, 6.445842734235975, 6.514053369274597, 6.581959253334133, 6.649566200124635, 6.716879829966961, 6.783905578891349, 6.850648707186033, 6.9171143074363055, 6.98330731209094, 7.049232500589781, 7.114894506083438, 7.180297821773483, 7.24544680689924, 7.310345692395112, 7.374998586240523, 7.439409478522817, 7.503582246231844, 7.567520657803541, 7.631228377428549, 7.694708969140608, 7.757965900698495, 7.8210025472741656, 7.883822194958909, 7.94642804409846, 8.008823212467231, 8.071010738291106, 8.13299358312765, 8.194774634611882, 8.256356709075304, 8.317742554045289, 8.378934850631524, 8.4399362158057, 8.500749204580305, 8.561376312091953, 8.621819975594345, 8.68208257636567], [0.0, 0.3449193085800954, 0.5603230698874366, 0.7442217961933489, 0.9102475124995059, 1.064134466499456, 1.2089918747571793, 1.3467473661362548, 1.478701446610052, 1.6057845071339016, 1.728691540918895, 1.8479592340479971, 1.9640130948934735, 2.0771977976592786, 2.187797550861243, 2.2960502481280294, 2.402157587008894, 2.5062924845208476, 2.6086046279024564, 2.7092247068716917, 2.808267693344252, 2.9058354197988927, 3.0020186324482387, 3.096898645144854, 3.190548685604501, 3.283035001588281, 3.374417777709288, 3.4647519013019625, 3.5540876068586953, 3.6424710219252843, 3.729944632392642, 3.8165476813692405, 3.9023165129465736, 3.9872848699507433, 4.071484153043364, 4.154943647175262, 4.237690720319472, 4.319750998550695, 4.401148520848103, 4.481905876440306, 4.562044327057333, 4.6415839160831665, 4.720543566296956, 4.798941167638557, 4.876793656224302, 4.954117085663891, 5.030926691582573, 5.107236950129271, 5.183061631146987, 5.258413846593238, 5.333306094722958, 5.4077503004818315, 5.481757852502904, 5.555339637051762, 5.628506069224685, 5.701267121668731, 5.7736323510619485, 5.845610922565222, 5.917211632433917, 5.988442928957062, 6.059312931874004, 6.1298294504026964, 6.2, 6.269831817962147, 6.339331877962725, 6.408506903616009, 6.4773633811449045, 6.5459075712253005, 6.614145520071821, 6.68208306982399, 6.749725868286448, 6.817079378072023, 6.884148885192148, 6.950939507135232, 7.017456200470088, 7.083703768008374, 7.149686865557148, 7.21541000829007, 7.280877576763466, 7.346093822601319, 7.411062873871378, 7.475788740172808, 7.540275317454225, 7.604526392579497, 7.668545647657426, 7.732336664150143, 7.795902926774018, 7.85924782720585, 7.922374667606155, 7.985286663970596, 8.04798694931973, 8.110478576736595, 8.172764522260987, 8.234847687648672, 8.296730903003226, 8.35841692928763, 8.419908460722398, 8.481208127076403, 8.542318495856337, 8.603242074400208, 8.663981311880077, 8.724538601218754], [0.0, 0.3465789365879479, 0.5630191435403129, 0.7478027245620779, 0.9146272970701093, 1.069254699901274, 1.2148091100545395, 1.353227431452234, 1.4858164276360455, 1.6135109662688973, 1.7370093846199546, 1.856850951113131, 1.9734632215143713, 2.0871925284762822, 2.1983244480241413, 2.3070980184454317, 2.4137159077856785, 2.518351865076562, 2.621156297797954, 2.7222605244998785, 2.8217800703016565, 2.91981725766341, 3.016463269435992, 3.111799810725062, 3.2059004615918885, 3.2988317885580396, 3.3906542658233807, 3.481423044820522, 3.571188601752214, 3.6599972861134624, 3.7478917882220486, 3.834911540010208, 3.921093060444168, 4.006470254708408, 4.091074674553265, 4.174935745838245, 4.258080968221254, 4.340536091080471, 4.422325269062019, 4.5034712000857695, 4.583995248185574, 4.66391755318699, 4.743257128918793, 4.822031951400812, 4.900259038239899, 4.977954520289965, 5.055133706484624, 5.131811142626835, 5.208000664815146, 5.283715448097113, 5.358968050864788, 5.433770455442419, 5.5081341052610675, 5.582069938967125, 5.655588421770583, 5.728699574303295, 5.8014129992266215, 5.873737905800912, 5.945683132605957, 6.017257168580924, 6.088468172534432, 6.159323991259592, 6.229832176374947, 6.300000000000001, 6.369834469363161, 6.43934234043032, 6.508530130633765, 6.577404130773508, 6.645970416156392, 6.71423485703222, 6.782203128380845, 6.849880719099225, 6.917272940633186, 6.984384935094657, 7.051221682901681, 7.117788009975325, 7.1840885945247175, 7.250127973448919, 7.3159105483819165, 7.381440591404988, 7.446722250448659, 7.511759554404851, 7.576556417968087, 7.641116646223265, 7.705443938996175, 7.769541894981657, 7.833414015663289, 7.8970637090374005, 7.960494293153321, 8.023708999480931, 8.086710976115759, 8.14950329083118, 8.21208893398663, 8.274470821300085, 8.336651796492557, 8.398634633811799, 8.460422040441943, 8.522016658805367, 8.583421068762684, 8.644637789716317, 8.705669282622859, 8.766517951919008], [0.0, 0.3482202253184496, 0.5656854249492379, 0.7513440828354497, 0.9189586839976279, 1.0743183535273755, 1.2205620635423442, 1.359635890532045, 1.4928527864588916, 1.621152046224736, 1.745235314204192, 1.8656444126266525, 1.9828089220275618, 2.0970768151819343, 2.208735020513196, 2.3180237083189024, 2.425146506416637, 2.5302779866587923, 2.633569268807713, 2.735152293296732, 2.8351431323357654, 2.933644592951892, 3.03074828980924, 3.126536314943126, 3.221082596866822, 3.314454017339987, 3.4067113369492574, 3.4979099683070642, 3.588100626655564, 3.6773298809863775, 3.765640623785192, 3.853072473721459, 3.9396621227037327, 4.025443636480772, 4.11044871622207, 4.19470692713874, 4.278245899118408, 4.361091503480204, 4.443268009259048, 4.524798221865018, 4.6057036065052985, 4.686004398381324, 4.765719701365375, 4.844867576606053, 4.923465122300236, 5.001528545692483, 5.079073228214696, 5.1561137845541785, 5.232664116332885, 5.308737460991249, 5.384346436393913, 5.45950308160964, 5.534218894261978, 5.608504864799307, 5.682371507991554, 5.755828891925135, 5.8288866647365865, 5.901554079298418, 5.973840016047152, 6.045753004122898, 6.117301240971824, 6.188492610546984, 6.259334700229007, 6.329834816575868, 6.4, 6.469837038461424, 6.539352480256933, 6.608552645977791, 6.677443639701577, 6.746031359477752, 6.814321507161084, 6.8823195976422245, 6.95003096752033, 7.017460783258752, 7.084614048861229, 7.151495613102868, 7.2181101763473245, 7.284462296978984, 7.350556397476588, 7.416396770152643, 7.481987582580971, 7.5473328827330555, 7.6124366038421805, 7.677302569012928, 7.741934495592298, 7.806335999317418, 7.870510598253787, 7.934461716536935, 7.998192687929427, 8.061706759204366, 8.125007093365673, 8.188096772714731, 8.250978801772376, 8.313656110064505, 8.376131554779102, 8.43840792330188, 8.50048793563734, 8.562374246721546, 8.62406944863252, 8.685576072703777, 8.746896591546225, 8.808033420983223], [0.0, 0.34984365929380246, 0.5683227012228509, 0.7548469164521356, 0.9232429519438191, 1.0793269222107897, 1.2262524335407248, 1.365974635206569, 1.4998126002707437, 1.6287100027123214, 1.7533717580350283, 1.8743422144921686, 1.9920529553622384, 2.106853575700591, 2.2190323416167406, 2.3288305431037486, 2.4364527573103767, 2.5420743699586787, 2.6458472053449076, 2.747903819020551, 2.848360824334595, 2.947321507609715, 3.044877910625835, 3.141112508138715, 3.2360995733229982, 3.329906299747115, 3.422593731269017, 3.5142175388397123, 3.6048286741403723, 3.6944739232714405, 3.7831963786872262, 3.8710358437629777, 3.958029181468223, 4.044210616369303, 4.129611997429409, 4.214263027695327, 4.298191465867701, 4.381423303880074, 4.4639829239117885, 4.545893237693791, 4.627175810505994, 4.707850971888156, 4.787937914776528, 4.867454784522407, 4.946418759036004, 5.024846121121506, 5.102752323920432, 5.1801520502550735, 5.257059266557993, 5.333487271983762, 5.409448743222639, 5.484955775470611, 5.560019919954177, 5.634652218360176, 5.708863234479337, 5.7826630833363994, 5.856061458048378, 5.9290676546255074, 6.001690594905702, 6.073938847792687, 6.145820648949864, 6.217343919085982, 6.288516280954721, 6.359345075177886, 6.429837374990946, 6.5, 6.569839529030589, 6.639362312141142, 6.708574481866996, 6.777481963754848, 6.846090486242027, 6.914405589930097, 6.982432636297921, 7.0501768158953695, 7.117643156055291, 7.18483652815822, 7.251761654481331, 7.318423114660604, 7.384825351792776, 7.4509726782014996, 7.516869280890201, 7.582519226702369, 7.647926467208374, 7.713094843336458, 7.778028089764224, 7.842729839085692, 7.907203625767899, 7.971452889910001, 8.035480980816864, 8.099291160398339, 8.162886606404555, 8.226270415506864, 8.289445606233445, 8.352415121767907, 8.415181832618702, 8.477748539166585, 8.540117974096969, 8.602292804723461, 8.664275635208583, 8.726069008687158, 8.78767540929763, 8.849097264126138], [0.0, 0.3514497030157745, 0.5709317269465002, 0.7583122276533308, 0.9274813267361977, 1.084281839018118, 1.2318818481953064, 1.372245479136326, 1.5066978604342742, 1.636186998236692, 1.7614210441360245, 1.8829468453506752, 2.001197966448772, 2.116525607388113, 2.229219357634983, 2.33952161488375, 2.4476378954451046, 2.553744390192573, 2.6579936204093375, 2.760518750175884, 2.861436928183577, 2.960851914916467, 3.0588561746950007, 3.1555325608956735, 3.250955687662481, 3.345193057032525, 3.438305993100663, 3.530350422389154, 3.6213775304854456, 3.71143431827313, 3.800564076033072, 3.888806789867744, 3.976199491975239, 4.062776564038224, 4.148570001230421, 4.233609642957789, 4.317923375354142, 4.4015373096754145, 4.484475940033364, 4.566762283340898, 4.648418003878672, 4.729463524514217, 4.809918126293699, 4.889800037869132, 4.9691265160101645, 5.047913918271219, 5.126177768735278, 5.203932817629754, 5.281193095503568, 5.357971962564343, 5.434282153697819, 5.510135819625965, 5.5855445646040405, 5.660519481008471, 5.7350711811256785, 5.80920982641592, 5.882945154494861, 5.9562865040483635, 6.029242837872244, 6.101822764207897, 6.17403455652657, 6.245886171898983, 6.317385268072949, 6.38853921936921, 6.459355131494668, 6.52983985536251, 6.6000000000000005, 6.669841944617079, 6.739371849902001, 6.808595668604151, 6.877519155458661, 6.946147876502597, 7.014487217828014, 7.082542393813283, 7.150318454870468, 7.217820294743377, 7.285052657387965, 7.352020143464162, 7.418727216465837, 7.48517820851343, 7.551377325831841, 7.617328653934408, 7.683036162532161, 7.74850371018607, 7.813735048718702, 7.878733827400393, 7.943503596924026, 8.008047813181381, 8.072369840853137, 8.136472956823745, 8.200360353431584, 8.264035141564037, 8.327500353606583, 8.390758946254245, 8.45381380319325, 8.516667737660196, 8.579323494885557, 8.641783754427909, 8.704051132404821, 8.766128183626005, 8.828017403633957, 8.889721230656955], [0.0, 0.3530388020822696, 0.5735132259961164, 0.7617409778919436, 0.9316749843146819, 1.0891844786943392, 1.237451869390947, 1.3784501621711551, 1.513510477269517, 1.6435851072952525, 1.7693854057869882, 1.891460692562754, 2.0102464925766004, 2.126095593756155, 2.2392988949623245, 2.3500998899039174, 2.45870502414487, 2.5652912852153866, 2.6700118840319784, 2.773000586783809, 2.874375071856463, 2.9742395688926972, 3.072686960295444, 3.169800474067275, 3.265655061724122, 3.360318530517241, 3.453852481821741, 3.5463130950347117, 3.637751787182036, 3.7282157716643742, 3.817748534501964, 3.906390242596629, 3.994178095589574, 4.081146630622123, 4.16732798753593, 4.252752140657458, 4.337447102209204, 4.4214391015105745, 4.504752743424793, 4.587411148936999, 4.669436080284077, 4.750848052676674, 4.831666434341261, 4.911909536351698, 4.991594693505063, 5.070738337317356, 5.149356062064551, 5.227462684668018, 5.305072299116577, 5.382198326026758, 5.458853557865786, 5.535050200295782, 5.6107999100412815, 5.686113829633498, 5.761002619342887, 5.835476486575304, 5.909545212975576, 5.983218179454946, 6.056504389335001, 6.12941248977977, 6.201950791669454, 6.274127288053103, 6.345949671303456, 6.417425349084652, 6.488561459232432, 6.559364883636765, 6.629842261207992, 6.7, 6.769844288556936, 6.83938110654386, 6.908616234716262, 6.977555264278343, 7.046203605675672, 7.114566496863715, 7.18264901109025, 7.250456064226419, 7.317992421678229, 7.385262704907748, 7.452271397590778, 7.519022851435676, 7.585521291686019, 7.651770822328018, 7.717775431021968, 7.783538993775535, 7.8490652793753535, 7.914357953592139, 7.979420583173424, 8.044256639636995, 8.108869502877114, 8.17326246459485, 8.237438731562913, 8.30140142873473, 8.365153602206881, 8.428698222043247, 8.492038184968798, 8.555176316940337, 8.618115375601047, 8.680858052625275, 8.743406975959509, 8.805764711965173, 8.867933767468495, 8.929916591722334], [0.0, 0.3546113842259673, 0.5760678932254873, 0.7651340900736366, 0.9358250534725804, 1.0940361608671905, 1.2429639963923185, 1.384590354405612, 1.5202522845066113, 1.6509063212131991, 1.777266986729503, 1.8998860477732473, 2.019200969308368, 2.135566110727137, 2.249273666675376, 2.3605682154844794, 2.469657122313073, 2.5767181630676768, 2.6819052311301563, 2.7853526885401, 2.8871787378717295, 2.9874880730501236, 3.086373990215195, 3.1839200881017713, 3.280201652091111, 3.3752867914762628, 3.4692373820305655, 3.5621098533975877, 3.6539558516361006, 3.744822800454952, 3.8347543795792616, 3.9237909348309934, 4.011969831554078, 4.099325760732679, 4.185891005372715, 4.27169567331881, 4.356767901571587, 4.441134036286786, 4.524818791927959, 4.6078453924707645, 4.690235697090168, 4.772010312380125, 4.853188692841271, 4.9337892311126295, 5.013829339207699, 5.093325521835307, 5.172293442734841, 5.250747984828421, 5.328703304885376, 5.4061728833032605, 5.483169569532287, 5.559705623603691, 5.63579275416592, 5.711442153383674, 5.7866645290126995, 5.861470133926899, 5.9358687933426255, 6.009869929957616, 6.0834825871980085, 6.15671545074591, 6.229576868501649, 6.302074869118652, 6.374217179234696, 6.446011239510745, 6.517464219577444, 6.588583031979566, 6.659374345199933, 6.7298445958365765, 6.800000000000001, 6.869846563991191, 6.939390094315533, 7.008636207082785, 7.077590336838898, 7.146257744871378, 7.214643527026365, 7.282752621072342, 7.350589813642425, 7.4181597467846006, 7.4854669241468335, 7.552515716821807, 7.619310368874096, 7.6858550025707775, 7.75215362333485, 7.818210124439335, 7.884028291458616, 7.949611806492281, 8.014964252175643, 8.080089115490079, 8.144989791385308, 8.209669586225013, 8.274131721066203, 8.338379334782157, 8.402415487038036, 8.466243161127627, 8.52986526667912, 8.593284642237311, 8.656504057729077, 8.719526216818602, 8.782353759158346, 8.84498926254138, 8.907435244960379, 8.969694166578197], [0.0, 0.3561678602815316, 0.5785963960374937, 0.7684924506437437, 0.9399326184090717, 1.0988381530311706, 1.248419669234114, 1.3906676599554653, 1.5269250434323192, 1.658152552646397, 1.7850678460144564, 1.9082251120932336, 2.028063735987336, 2.144939632459037, 2.2591462786678904, 2.370929326459378, 2.4804970511685007, 2.5880280090036907, 2.69367676882249, 2.797578282412325, 2.899851271167412, 3.0006008885400606, 3.0999208401697507, 3.1978950917265916, 3.2945992590377866, 3.390101750344722, 3.484464713008632, 3.5777448243565853, 3.669993957134531, 3.7612597432055694, 3.8515860540158102, 3.9410134124748946, 4.029579347932382, 4.117318703639645, 4.2042639043006105, 4.290445189910588, 4.375890820970378, 4.460627259275439, 4.544679327767145, 4.628070352356859, 4.710822288164812, 4.792955832232337, 4.874490524450628, 4.955444838188499, 5.03583626188503, 5.115681372692253, 5.194995903101535, 5.273794801359783, 5.352092286373841, 5.42990189771003, 5.507236541217938, 5.584108530741074, 5.660529626320008, 5.736511069244585, 5.812063614269512, 5.8871975592710575, 5.961922772590854, 6.036248718285162, 6.110184479473927, 6.183738779962837, 6.256920004293199, 6.3297362163581585, 6.402195176709597, 6.474304358667358, 6.5460709633313465, 6.617501933587188, 6.688603967187302, 6.759383528981524, 6.829846862364387, 6.9, 6.969848773879918, 7.0393988247643815, 7.10865561105289, 7.177624417126026, 7.246310361196846, 7.314718402706904, 7.38285334929902, 7.450719863396264, 7.518322468414213, 7.585665554631343, 7.652753384740468, 7.719590099102301, 7.786179720720623, 7.852526159956981, 7.918633219001571, 7.984504596115616, 8.050143889659491, 8.115554601919786, 8.180740142747487, 8.245703833018712, 8.310448907928478, 8.374978520127346, 8.439295742710097, 8.50340357206492, 8.567304930591082, 8.631002669292437, 8.694499570253752, 8.757798349006254, 8.820901656788486, 8.883812082708078, 8.946532155809793, 9.009064347054741], [0.0, 0.35770862508726153, 0.5810993758488447, 0.7718169115327334, 0.943998721108674, 1.1035916733292837, 1.2538202718814626, 1.3966836204782158, 1.5335304467554842, 1.6653256397790468, 1.792789962520997, 1.9164800009307592, 2.0368370408714895, 2.154218536775378, 2.2689192353698675, 2.381185851178352, 2.491227560524781, 2.599223692043043, 2.7053294832480237, 2.8096804697220064, 2.9123958864421713, 3.0135813417495396, 3.1133309466496195, 3.2117290300439185, 3.3088515348700223, 3.404767165300035, 3.4995383375416487, 3.5932219741052847, 3.6858701721358647, 3.7775307695496063, 3.8682478275783576, 3.958062044431892, 4.047011111809905, 4.135130023693979, 4.2224513450557275, 4.309005446707207, 4.394820711402768, 4.479923715410305, 4.564339389054027, 4.648091159152052, 4.731201075801393, 4.8136899255777745, 4.895577332901007, 4.976881851054797, 5.057621044132362, 5.137811560997684, 5.217469202200121, 5.296608980651968, 5.375245176770367, 5.453391388693144, 5.531060578099962, 5.608265112103417, 5.685016801617442, 5.7613269365611535, 5.837206318213803, 5.91266528899977, 5.987713759950654, 6.062361236063759, 6.136616839752166, 6.210489332560321, 6.283987135300647, 6.3571183467503, 6.42989076103293, 6.5023118837975975, 6.574388947295817, 6.646128924447794, 6.717538541980104, 6.788624292709204, 6.859392447038249, 6.929849063728359, 7.000000000000001, 7.069850921015067, 7.139407308785828, 7.2086744705528405, 7.277657546670301, 7.346361518034064, 7.4147912130845794, 7.482951314414332, 7.550846365006974, 7.618480774133113, 7.685858822925763, 7.7529846696566365, 7.819862354732833, 7.886495805431933, 7.952888840392221, 8.019045173873417, 8.084968419802232, 8.15066209561597, 8.216129625916475, 8.281374345945807, 8.34639950489428, 8.411208269050668, 8.47580372480381, 8.540188881504127, 8.604366674193038, 8.668339966207705, 8.732111551668057, 8.795684157852575, 8.85906044746893, 8.92224302082511, 8.9852344179064, 9.048037120363166], [0.0, 0.35923405832649585, 0.5835774494569439, 0.7751082919716814, 0.9480243635617253, 1.108297893148915, 1.259167135179174, 1.4026397184583856, 1.5400701222142128, 1.6724273502408744, 1.8004352391735465, 1.9246527484987956, 2.0455230459246, 2.163405110232393, 2.2785949450845187, 2.391340317107978, 2.50185129465027, 2.610307971084625, 2.716866245929719, 2.8216622327535683, 2.9248156750058505, 3.026432631389871, 3.126607614243524, 3.225425312085336, 3.3229619917083246, 3.419286650270618, 3.5144619701511743, 3.608545116604044, 3.7015884089402102, 3.7936398890786522, 3.8847438061484705, 3.9749410319152254, 4.064269418813264, 4.152764110054519, 4.24045780948254, 4.327381017424423, 4.4135622376715675, 4.499028159825236, 4.583803820523944, 4.667912746488483, 4.751377081847566, 4.8342177018203865, 4.916454314514261, 4.9981055523325875, 5.07918905426991, 5.1597215401885865, 5.239718878018746, 5.319196144694609, 5.398167681531552, 5.47664714465608, 5.55464755102239, 5.632181320482104, 5.709260314316296, 5.785895870589464, 5.862098836642454, 5.937879599004477, 6.013248110972302, 6.088213918076895, 6.162786181633479, 6.236973700549734, 6.310784931548278, 6.38422800794316, 6.457310757095739, 6.5300407166625964, 6.602425149736876, 6.674471058974509, 6.746185199787906, 6.817574092681866, 6.8886440347994125, 6.959401110738994, 7.029851202698945, 7.1000000000000005, 7.1698530080322405, 7.239415556668723, 7.308692808184465, 7.377689764716143, 7.446411275294884, 7.514862042481891, 7.5830466286341744, 7.650969461825492, 7.718634841445565, 7.786046943498882, 7.853209825622685, 7.920127431842264, 7.986803597080323, 8.053242051435886, 8.1194464242471, 8.185420247951233, 8.251166961754194, 8.316689915121044, 8.381992371098132, 8.447077509476735, 8.511948429807466, 8.576608154273991, 8.641059630434091, 8.705305733835507, 8.769349270513574, 8.833192979377138, 8.896839534488873, 8.960291547245665, 9.023551568464462, 9.086622090378526], [0.0, 0.36074452531358503, 0.5860312103167041, 0.7783673801881394, 0.9520105098385762, 1.1129579395466884, 1.2644615396066827, 1.4085373802763692, 1.54654563594541, 1.6794593847662531, 1.808005506880992, 1.9327453120262095, 2.0541238312916463, 2.1725015528523635, 2.2881757249736303, 2.40139515606371, 2.512370797741875, 2.621283500617728, 2.728289819718716, 2.833526440927886, 2.937113611178712, 3.039157835118213, 3.139754022479138, 3.2389872178687757, 3.3369340087581825, 3.433663682416981, 3.52923918478395, 3.623717921475175, 3.717152431787995, 3.809590959642652, 3.901077940222009, 3.9916544171446326, 4.081358402002531, 4.170225185773862, 4.258287609811624, 4.345576302687256, 4.432119888041698, 4.517945167697647, 4.603077283564862, 4.687539861286645, 4.771355138100851, 4.854544077000452, 4.937126468959195, 5.0191210247239155, 5.1005454574556195, 5.181416557318461, 5.261750258962259, 5.3415617027150315, 5.420865290192906, 5.499674734942134, 5.5780031086491375, 5.655862883387135, 5.733265970310181, 5.810223755155793, 5.886747130874496, 5.962846527667613, 6.038531940682416, 6.1138129555858445, 6.188698772213591, 6.263198226469995, 6.337319810635549, 6.4110716922223485, 6.484461731503361, 6.557497497828659, 6.630186284830423, 6.702535124608565, 6.774550800979895, 6.846239861865898, 6.917608630887115, 6.988663218225832, 7.059409530813188, 7.129853281891736, 7.2, 7.2698550374214905, 7.3394235781369765, 7.408710645315558, 7.477721108377022, 7.5464596896553715, 7.614930970690906, 7.6831393981760465, 7.751089289578108, 7.8187848384603695, 7.886230119521174, 7.953429093369201, 8.020385611051811, 8.087103418351928, 8.15358615986793, 8.219837382889882, 8.285860541084478, 8.351658998000236, 8.417236030403592, 8.482594831455854, 8.547738513740276, 8.612670112147864, 8.677392586629958, 8.741908824825076, 8.806221644567058, 8.870333796281004, 8.934247965273187, 8.997966773920604, 9.061492783765587, 9.124828497520461], [0.0, 0.36224037772879875, 0.5884612297344094, 0.7815949349918219, 0.9559580880290227, 1.1175728975157804, 1.269704717854007, 1.4143779790778999, 1.5529584956353977, 1.6864233806155933, 1.8155025282199484, 1.9407595756951432, 2.0626413994834705, 2.1815099825494317, 2.2976638057190275, 2.4113527091019935, 2.5227885190432526, 2.632152836062114, 2.739602864352399, 2.845275856574734, 2.9492925582749145, 3.051759915728932, 3.1527732322193827, 3.2524179049969693, 3.350770839108056, 3.4479016091267773, 3.543873422001651, 3.6387439213851667, 3.7325658644325355, 3.8253876951107904, 3.9172540328563894, 4.008206091478135, 4.098282040185762, 4.187517316293937, 4.275944897334627, 4.363595538882787, 4.450497983269286, 4.536679143452453, 4.622164265594737, 4.70697707330482, 4.791139896028824, 4.8746737836842335, 4.957598609309457, 5.039933161236749, 5.121695226075976, 5.2029016636128835, 5.283568474571431, 5.363710862060066, 5.443343287412226, 5.522479521038339, 5.601132688827491, 5.679315314569225, 5.757039358808028, 5.834316254493175, 5.911156939743575, 5.987571888010107, 6.063571135885623, 6.1391643087847, 6.214360644690793, 6.2891690161469365, 6.363597950647461, 6.437655649571619, 6.511350005785552, 6.584688620026171, 6.657678816169213, 6.730327655473684, 6.802641949885967, 6.874628274478959, 6.946292979094537, 7.017642199251285, 7.088681866373847, 7.159417717395134, 7.229855303778143, 7.300000000000001, 7.369857011537219, 7.4394313823878155, 7.50872800216297, 7.577751612778173, 7.6465068147714, 7.7149980732735965, 7.783229723654755, 7.85120597686706, 7.918930924504873, 7.98640854359982, 8.053642701167893, 8.120637158524172, 8.187395575379613, 8.253921513733369, 8.320218441573006, 8.386289736394229, 8.452138688550818, 8.517768504444746, 8.58318230956581, 8.648383151389407, 8.713374002140519, 8.778157761431462, 8.842737258780419, 8.907115256017322, 8.971294449583255, 9.03527747272908, 9.09906689761875, 9.162665237342257], [0.0, 0.363721954306138, 0.5908680579850676, 0.7847916872586768, 0.9598679920574527, 1.122143812107936, 1.2748978572326273, 1.4201628374596318, 1.5593101534686278, 1.693320914777475, 1.8229280008819846, 1.9486973543260764, 2.071077679293263, 2.190432439271793, 2.3070613358853143, 2.4212152310988757, 2.533106817635005, 2.6429184387658697, 2.750807941656274, 2.8569131403353145, 2.961355274202548, 3.064241726948199, 3.165668191648824, 3.2657204148330483, 3.364475616091727, 3.462003654561583, 3.558367995709897, 3.653626518953834, 3.7478321972273285, 3.841033672635033, 3.933275747108556, 4.024599803022706, 4.115044165700701, 4.204644417397141, 4.293433670523316, 4.381442806445629, 4.468700685052145, 4.55523432937619, 4.641069088837955, 4.726228784076562, 4.810735835866393, 4.894611380219878, 4.977875371456888, 5.0605466747546535, 5.142643149470936, 5.224181724348629, 5.305178465555246, 5.385648638380512, 5.465606763305255, 5.545066667061391, 5.624041529223382, 5.70254392480353, 5.780585863265397, 5.858178824319443, 5.935333790821886, 6.012061279060412, 6.088371366677907, 6.1642737184572525, 6.239777610165596, 6.314891950635005, 6.389625302237575, 6.463985899896507, 6.537981668760054, 6.6116202406524245, 6.6849089694042805, 6.7578549451554375, 6.830465007713391, 6.902745759043332, 6.974703574958224, 7.046344616071153, 7.117674838066505, 7.188700001341463, 7.259425680064712, 7.32985727069519, 7.4, 7.4698589326073, 7.53943897812696, 7.608744897869081, 7.677781311188009, 7.74655270147724, 7.815063421838591, 7.883317700447199, 7.9513196456321955, 8.019073250691413, 8.086582398457088, 8.153850865628208, 8.220882326884093, 8.287680358792601, 8.354248443525494, 8.42058997239256, 8.486708249205249, 8.552606493479836, 8.618287843489492, 8.683755359173892, 8.749012024914537, 8.814060752183261, 8.878904382071083, 8.94354568770392, 9.0079873765514, 9.072232092634481, 9.136282418637357, 9.200140877928659], [0.0, 0.365189581477662, 0.5932522253591234, 0.7879583413211301, 0.963741083383235, 1.1266716904213276, 1.2800421019339452, 1.4258932299849345, 1.5656020088899745, 1.7001535069683373, 1.830283560902908, 1.9565603968299081, 2.0794345294654395, 2.199270888882006, 2.3163703860067923, 2.4309848950391437, 2.5433279669220363, 2.653582680687296, 2.7619075204169796, 2.868440856223234, 2.973304416709622, 3.0766060188622406, 3.1784417418816004, 3.2788976782857118, 3.378051359248408, 3.4759729257897733, 3.572726099461835, 3.668368993226652, 3.76295479376527, 3.8565323394544495, 3.949146613002712, 4.040839163763781, 4.131648471704514, 4.221610262654793, 4.310757782635319, 4.399122037619577, 4.486732003946001, 4.573614813686533, 4.659795918546909, 4.745299235283121, 4.830147275137939, 4.914361259408131, 4.997961222929745, 5.080966107001474, 5.163393843044035, 5.245261428108221, 5.326584993188933, 5.4073798651717215, 5.487660623127916, 5.567441149580645, 5.646734677284278, 5.725553831991609, 5.803910671624684, 5.8818167222148805, 5.959283010934519, 6.036320096504767, 6.112938097232051, 6.189146716896892, 6.264955268694393, 6.340372697403977, 6.4154075999471285, 6.490068244475166, 6.564362588114517, 6.638298293483991, 6.711882744087138, 6.785123058672666, 6.858026104646865, 6.93059851061402, 7.00284667811366, 7.074776792617096, 7.146394833840054, 7.217706585423059, 7.2887176440267085, 7.359433427884786, 7.42985918485453, 7.500000000000001, 7.5698608027414656, 7.639446373601031, 7.708761350572254, 7.777810235139235, 7.846597397968666, 7.915127084296474, 7.983403419029004, 8.051430411577146, 8.119211960440454, 8.186751857557, 8.25405379243352, 8.321121356069417, 8.387958044687101, 8.45456726328038, 8.520952328991665, 8.587116474328061, 8.653062850225748, 8.718794528971337, 8.784314506988379, 8.849625707496571, 8.914730983050806, 8.979633117966634, 9.044334830638388, 9.10883877575572, 9.173147546424017, 9.237263676193765], [0.0, 0.3666435739776207, 0.5956142431438742, 0.7910955762716044, 0.9675781925950349, 1.1311575034644048, 1.2851385551468557, 1.431570385542744, 1.5718354111947046, 1.7069226224450385, 1.837570785690599, 1.9643503894446916, 2.0877137421356475, 2.2080272267952425, 2.3255929524194277, 2.4406637960379003, 2.5534541588409754, 2.6641478487847206, 2.7729039809513045, 2.879861476369756, 2.9851425483027993, 3.088855443006963, 3.191096622219511, 3.2919525212335, 3.391500979911047, 3.489812418536822, 3.586950812368498, 3.6829745057433305, 3.7779368971037055, 3.8718870192750674, 3.964870034063382, 4.056927656250009, 4.148098519008756, 4.2384184904109405, 4.327920948845398, 4.416637023735063, 4.504595806786885, 4.59182453809842, 4.678348770710682, 4.764192516603589, 4.849378376647817, 4.933927656632155, 5.017860471160814, 5.101195836946759, 5.1839517568041735, 5.266145295457154, 5.347792648125724, 5.428909202719015, 5.509509596354538, 5.589607766828314, 5.669216999580567, 5.748349970633189, 5.827018785916517, 5.9052350173525125, 5.983009736017886, 6.0603535426730675, 6.137276595910252, 6.213788638145301, 6.289899019653552, 6.365616720827827, 6.4409503728180235, 6.515908276694881, 6.590498421265912, 6.664728499658437, 6.7386059247732275, 6.812137843702097, 6.885331151193729, 6.95819250224402, 7.030728323880054, 7.102944826200432, 7.174848012728955, 7.24644369013356, 7.317737477357796, 7.388734814208, 7.459440969435612, 7.529861048350738, 7.6000000000000005, 7.669862623939027, 7.739453576627419, 7.808777377471816, 7.8778384145406015, 7.946640949971996, 8.015189125095548, 8.083486965285505, 8.151538384563201, 8.2193471899642, 8.286917085684914, 8.35425167702221, 8.421354474118615, 8.48822889552483, 8.554878271590379, 8.621305847692504, 8.687514787312756, 8.753508174969971, 8.81928901901788, 8.884860254314903, 8.9502247447733, 9.015385285794299, 9.08034460659545, 9.145105372435975, 9.209670186745647, 9.27404159316221], [0.0, 0.3680842354093933, 0.5979546045444648, 0.7942040471857843, 0.9713801209069736, 1.1356021879049967, 1.2901882810449483, 1.4371954895611907, 1.5780116619589981, 1.713629674644259, 1.844791196866435, 1.9720689587730966, 2.0959170460589833, 2.2167032813935483, 2.3347309608569007, 2.4502539551145466, 2.5634875078085644, 2.6746161491360536, 2.783799619393911, 2.891177385476912, 2.9968721408632994, 3.1009925571442274, 3.2036354750863882, 3.304887669615119, 3.404827286450583, 3.5035250225815715, 3.60104510464528, 3.697446106232775, 3.7927816356062274, 3.887100918256946, 3.9804492934462687, 4.072868639866451, 4.164397742493561, 4.255072610336193, 4.344926752937693, 4.433991422038584, 4.522295823656561, 4.609867304924354, 4.696731519289155, 4.782912573081735, 4.868433155978914, 4.953314657486832, 5.037577271246499, 5.121240088693706, 5.204321183381532, 5.286837687086903, 5.368805858666111, 5.4502411464923695, 5.53115824519717, 5.611571147342648, 5.691493190571832, 5.770937100714808, 5.84991503127004, 5.92843859962932, 6.0065189203712075, 6.084166635909957, 6.161391944754163, 6.238204627600796, 6.314614071465456, 6.3906292920278425, 6.466258954352433, 6.5415113921275685, 6.616394625551373, 6.690916377979958, 6.765084091441785, 6.838904941111908, 6.912385848830712, 6.985533495743728, 7.058354334131916, 7.130854598495365, 7.203040315947665, 7.2749173159730365, 7.346491239593677, 7.417767547990686, 7.488751530618136, 7.55944831284655, 7.62986286316896, 7.7, 7.769864398096015, 7.839460594621856, 7.9087929948880475, 7.977865877780134, 8.04668340090029, 8.115249605439766, 8.183568420799348, 8.251643668973683, 8.319479068714166, 8.387078239484046, 8.45444470521834, 8.521581897900338, 8.588493160965589, 8.655181752543477, 8.721650848545892, 8.787903545611746, 8.853942863915568, 8.919771749847788, 8.985393078573903, 9.050809656479183, 9.116024223505153, 9.181039455383708, 9.245857965774334, 9.310482308309556], [0.0, 0.3695118587779746, 0.6002737855489134, 0.7972843862715461, 0.9751476415638681, 1.1400066477131219, 1.2951923066529478, 1.4427696860867094, 1.5841320173227667, 1.720276027661512, 1.8519462629340442, 1.9797176746352876, 2.1040461096420344, 2.2253008172326165, 2.343786269828127, 2.459757322737422, 2.57343005443011, 2.684989710808003, 2.794596651724498, 2.9023908850000035, 3.008495579982305, 3.1130198297478797, 3.2160608506626134, 3.3177057542104325, 3.4180329892015138, 3.517113526824585, 3.615011842821364, 3.7117867379619685, 3.8074920284294764, 3.902177130637423, 3.9958875596965377, 4.088665356726569, 4.180549457132029, 4.271576009583297, 4.361778653591273, 4.4511887621070905, 4.539835654424672, 4.627746783743242, 4.714947903007496, 4.8014632120451735, 4.88731548853554, 4.9725262049444385, 5.057115633234392, 5.141102938887774, 5.2245062655563625, 5.307342811463085, 5.389628898524591, 5.471380035030972, 5.5526109726071935, 5.633335758085873, 5.713567780840401, 5.793319816058295, 5.872604064375648, 5.951432188242581, 6.029815345345807, 6.107764219376435, 6.185289048398214, 6.26239965104278, 6.339105450733493, 6.415415498117576, 6.491338491867166, 6.566882797993009, 6.642056467799757, 6.716867254598739, 6.7913226292825, 6.865429794855178, 6.93919570000368, 7.012627051786517, 7.085730327509971, 7.158511785854787, 7.2309774773108595, 7.303133253972198, 7.374984778739837, 7.446537533976197, 7.517796829650621, 7.588767811012504, 7.659455465825293, 7.729864631191961, 7.8, 7.869866127011763, 7.939467434623877, 8.008808218317645, 8.077892651820596, 8.146724791997839, 8.215308583490433, 8.283647863116718, 8.351746364051358, 8.419607719795774, 8.487235467952646, 8.554633053816296, 8.621803833789864, 8.688751078639463, 8.755477976594834, 8.82198763630528, 8.888283089659144, 8.954367294474498, 9.020243137068242, 9.085913434710271, 9.151380937969043, 9.216648332954339, 9.281718243462787, 9.346593233031236], [0.0, 0.37092672699051576, 0.6025722457412431, 0.8003372039489587, 0.9788815011621664, 1.144371755705242, 1.3001516236011819, 1.4482940797384125, 1.5901976901355175, 1.7268629985814286, 1.8590374017879507, 1.9872980527506496, 2.1121025437930205, 2.233821538056183, 2.3527606737921487, 2.4691757821557907, 2.5832837689854493, 2.6952705894931572, 2.8052972175533597, 2.9135041970791784, 3.0200151690362658, 3.124939644220646, 3.228375211241592, 3.3304093151346237, 3.431120705091964, 3.530580624052424, 3.6288537946366124, 3.725999242763958, 3.822070990680768, 3.917118644017001, 4.011187892161646, 4.104320937210731, 4.196556863653199, 4.287931958573406, 4.378479990288601, 4.468232451877571, 4.557218774898393, 4.645466517669135, 4.733001531743025, 4.819848109609422, 4.9060291161637775, 4.991566106090429, 5.076479428973644, 5.1607883236808085, 5.244511003336102, 5.327664732014788, 5.410265894130454, 5.492330057354746, 5.573872029796888, 5.654905912075102, 5.73544514483095, 5.8155025521683985, 5.895090381440014, 5.974220339751673, 6.052903627513088, 6.131150969323436, 6.208972642448211, 6.286378503114786, 6.363378010828995, 6.439980250893168, 6.5161939552868295, 6.592027522054345, 6.667489033328973, 6.742586272109624, 6.817326737895037, 6.891717661269798, 6.965766017527471, 7.039478539408029, 7.112861729019486, 7.185921869007201, 7.258665033028511, 7.331097095585211, 7.403223741261696, 7.47505047341246, 7.546582622338824, 7.617825352991444, 7.688783672232012, 7.759462435684863, 7.82986635420665, 7.9, 7.969867812394986, 8.039474103320389, 8.10882306248503, 8.177918762287828, 8.246765162473952, 8.315366114553001, 8.383725365994033, 8.45184656421122, 8.51973326035279, 8.587388912905167, 8.654816891123225, 8.722020478296907, 8.789002874863746, 8.855767201376125, 8.922316501331547, 8.988653743873629, 9.054781826371036, 9.120703576881043, 9.18642175650409, 9.251939061635127, 9.31725812611735, 9.38238152330344], [0.0, 0.3723291133272138, 0.6048504290664436, 0.8033630898663081, 0.9825824208926323, 1.1486983549970349, 1.3050671897761175, 1.4537697375466938, 1.5962098519751033, 1.7333918596700013, 1.8660659830736146, 1.9948115572606535, 2.120087904603099, 2.24226708963185, 2.3616559061449554, 2.478511152534452, 2.59305055470842, 2.7054607709316225, 2.8159033836827003, 2.924519468238112, 3.031433133020796, 3.136754302861228, 3.24058093532816, 3.343000806066136, 3.444092961999474, 3.543928915419707, 3.6425736336483845, 3.740086365767993, 3.836521338270193, 3.9319283443321122, 4.026353246083527, 4.119838405176622, 4.21242305386956, 4.304143616439592, 4.3950339888739975, 4.4851257833194556, 4.574448542607811, 4.663029929248625, 4.75089589253374, 4.83807081679668, 4.924577653379665, 5.010438038460202, 5.095672398559531, 5.1803000452826495, 5.264339260613259, 5.34780737389801, 5.430720831496092, 5.513095259936837, 5.5949455233154355, 5.676285775561213, 5.757129508131624, 5.837489593615541, 5.9173783256698815, 5.996807455662319, 6.075788226348673, 6.154331402875295, 6.232447301363593, 6.310145815305007, 6.3874364399695285, 6.46432829500887, 6.540830145416106, 6.616950420986627, 6.692697234410325, 6.768078398111793, 6.843101439943603, 6.917773617827473, 6.992101933428905, 7.06609314494277, 7.139753779060018, 7.213090142179204, 7.286108330920731, 7.358814241996497, 7.431213581482968, 7.503311873541521, 7.5751144686260865, 7.64662655121478, 7.7178531470990555, 7.788799130261214, 7.859469229368547, 7.9298680339100995, 8.0, 8.06986945586942, 8.13948060706747, 8.208837541389858, 8.27794423355261, 8.34680454962697, 8.415422251250295, 8.483800999626764, 8.551944359330665, 8.619855801924137, 8.68753870940041, 8.754996377462774, 8.822232018648858, 8.889248765309118, 8.9560496724478, 9.022637720434155, 9.089015817591111, 9.155186802668164, 9.221153447204816, 9.286918457790454, 9.352484478226215, 9.41785409159401], [0.0, 0.37371928188465514, 0.6071087645506852, 0.8063626138566858, 0.9862510977103354, 1.1529872603711844, 1.309939930874342, 1.4591976906842745, 1.6021696350483754, 1.7398638404385862, 1.873033330409411, 2.002259603104136, 2.1280036958708117, 2.2506390624210213, 2.370473642031574, 2.4877651919049724, 2.6027322508744763, 2.715562174132491, 2.826417147459609, 2.9354387728663176, 3.0427516221602895, 3.1484660305993275, 3.2526803214972397, 3.3554825982272822, 3.4569522028519852, 3.5571609146689678, 3.6561739435688514, 3.7540507598529547, 3.850845792478878, 3.9466090205369815, 4.041386477392888, 4.135220682864862, 4.228151015692905, 4.320214036151917, 4.411443766786929, 4.501871937775179, 4.591528202252847, 4.680440326013254, 4.768634355235348, 4.856134765296658, 4.942964593233037, 5.029145556005181, 5.114698156401017, 5.1996417781294575, 5.283994771433807, 5.367774530363458, 5.450997562683515, 5.533679553268225, 5.615835421710984, 5.697479374787771, 5.778624954329215, 5.859285080986693, 5.939472094318055, 6.019197789567165, 6.09847345146702, 6.177309885357893, 6.2557174458785925, 6.333706063459972, 6.4112852688245985, 6.48846421567431, 6.565251701728117, 6.64165618825581, 6.717685818237706, 6.793348433267718, 6.868651589305227, 6.943602571370918, 7.0182084072724775, 7.092475880437908, 7.166411541926923, 7.240021721684337, 7.313312539093557, 7.386289912883089, 7.458959570434226, 7.531327056533957, 7.603397741613252, 7.675176829507556, 7.746669364773169, 7.817880239590421, 7.888814200282072, 7.959475853472983, 8.029869671915119, 8.1, 8.169871058979043, 8.239486951910585, 8.308851668351092, 8.37796908880659, 8.446842988959297, 8.515477043683264, 8.583874830861859, 8.652039835019025, 8.71997545077537, 8.78768498613938, 8.85517166564337, 8.922438633333073, 8.989488955619239, 9.056325623998948, 9.122951557653955, 9.189369605932827, 9.255582550723188, 9.321593108720036, 9.387403933595694, 9.453017618076556], [0.0, 0.37509748799354137, 0.6093476669799165, 0.809336326839303, 0.9898882054370371, 1.1572392595661365, 1.314770741866755, 1.4645789360972272, 1.608078133982014, 1.746280129588641, 1.87994072348022, 2.009643558255334, 2.1358513714806744, 2.25893899409456, 2.3792155009956777, 2.496939599946397, 2.612330635709909, 2.7255766544091733, 2.836840439935302, 2.946264116500245, 3.0539727153089675, 3.16007697851486, 3.2646755920295347, 3.3678569841348462, 3.46970078949186, 3.5702790521066854, 3.669657222351701, 3.767894989843462, 3.8650469842632806, 3.9611633690149612, 4.056290347226482, 4.150470595521165, 4.243743637860364, 4.3361461693463665, 4.427712337992925, 4.518473990992171, 4.608460890835453, 4.697700905711092, 4.786220177851423, 4.874043272894541, 4.961193312832537, 5.047692094714157, 5.133560196937735, 5.218817074695637, 5.303481145903404, 5.387569868756391, 5.471099811897226, 5.554086718043007, 5.636545561807771, 5.718490602359404, 5.799935431468249, 5.880893017434602, 5.961375745322273, 6.041395453873756, 6.120963469438013, 6.200090637203369, 6.278787349994584, 6.357063574864065, 6.434928877681884, 6.512392445907001, 6.589463109702754, 6.666149361542495, 6.742459374436316, 6.818401018896446, 6.893981878747218, 6.969209265875097, 7.044090234004996, 7.118631591580916, 7.192839913821646, 7.266721554015637, 7.340282654113429, 7.413529154670678, 7.4864668041901785, 7.559101167907047, 7.6314376360573855, 7.703481431667405, 7.775237617896773, 7.846711104967258, 7.917906656705161, 7.988828896723705, 8.059482314269518, 8.12987126975542, 8.200000000000001, 8.269872623192905, 8.339493143603326, 8.408865456047865, 8.47799335013274, 8.546880514284247, 8.615530539580307, 8.683946923395135, 8.752133072868055, 8.820092308206865, 8.887827865835344, 8.955342901393873, 9.022640492601544, 9.089723641987515, 9.156595279498934, 9.22325826499222, 9.289715390614079, 9.355969383078165, 9.422022905843045, 9.487878561196595], [0.0, 0.37646397861257264, 0.6115675375397294, 0.8122847616693603, 0.9934943958006546, 1.161455114491294, 1.3195604883791832, 1.469914438042903, 1.613936407511144, 1.7526418768454624, 1.8867894000115188, 2.0169647458341746, 2.1436323376459923, 2.2671683719048623, 2.3878830494779546, 2.506036020607239, 2.6218474291350016, 2.7355060062414758, 2.847175128844034, 2.956997438917097, 3.0650984231578002, 3.171589227156289, 3.276568896339708, 3.380126181136609, 3.482341006319352, 3.583285678352371, 3.6830258860455785, 3.7816215364664685, 3.8791274583138073, 3.9755939977380796, 4.071067526186549, 4.165590875754666, 4.259203714390681, 4.351942870878162, 4.443842617633028, 4.5349349178676235, 4.625249642498881, 4.714814761239709, 4.803656511559327, 4.891799548589135, 4.979267078555284, 5.06608097791378, 5.152261900030634, 5.237829370974024, 5.3228018757564675, 5.407196936174016, 5.4910311812293235, 5.574320410990645, 5.657079654624957, 5.739323223246689, 5.821064758141385, 5.90231727485322, 5.983093203565138, 6.063404426148502, 6.143262310214478, 6.222677740460717, 6.301661147573328, 6.380222534914969, 6.458371503204444, 6.536117273370882, 6.613468707746152, 6.690434329741925, 6.767022342142795, 6.843240644133487, 6.919096847166419, 6.994598289765463, 7.069752051352445, 7.144564965174723, 7.219043630404787, 7.293194423476298, 7.367023508715091, 7.440536848318433, 7.5137402117310765, 7.586639184462442, 7.659239176385414, 7.731545429553833, 7.803563025572597, 7.875296892551553, 7.946751811671752, 8.01793242339037, 8.088843233308484, 8.159488617724021, 8.229872828890418, 8.3, 8.369874149909627, 8.439499187624822, 8.508878916557448, 8.578017038570838, 8.646917157825314, 8.715582784436117, 8.784017337954879, 8.852224150685005, 8.920206470840657, 8.987967465558306, 9.055510223769256, 9.122837758940962, 9.189953011694454, 9.256858852304688, 9.323558083090235, 9.390053440698248, 9.45634759829034, 9.522443167634604], [0.0, 0.37781899270011776, 0.6137687644191394, 0.8152084339399892, 0.9970702994161037, 1.165635562373684, 1.3243100079951406, 1.4752051295411297, 1.619745480072719, 1.7589501946885122, 1.8935805576321463, 2.0242244460975556, 2.1513479550251966, 2.2753286349241546, 2.396477803173587, 2.515056044579607, 2.6312842953524944, 2.745351965976275, 2.857423021414022, 2.9676406170541774, 3.0761306912605755, 3.183004789671836, 3.2883623142112266, 3.3922923347484364, 3.4948750637306056, 3.5961830678762254, 3.6962822724302136, 3.7952328000847326, 3.893089676884546, 3.9899034301920113, 4.085720598360042, 4.180584167650478, 4.274533948789185, 4.367606903118284, 4.459837426411063, 4.551257596925677, 4.6418973930940295, 4.731784885300955, 4.820946405452706, 4.909406697422375, 4.9971890509627315, 5.084315421270132, 5.170806536048648, 5.256681991647014, 5.3419603396112105, 5.426659164803829, 5.510795156080613, 5.594384170379312, 5.677441290961672, 5.759980880452394, 5.842016629236366, 5.923561599704863, 6.004628266781026, 6.085228555102869, 6.165373873197221, 6.245075144939235, 6.324342838558391, 6.403186993422644, 6.481617244806852, 6.559642846829211, 6.637272693719953, 6.714515339569231, 6.791379016686079, 6.867871652686912, 6.944000886420195, 7.019774082823489, 7.095198346799725, 7.170280536191297, 7.245027273923225, 7.31944495937999, 7.393539779074807, 7.467317716664794, 7.540784562360776, 7.6139459217762075, 7.686807224255833, 7.759373730721319, 7.831650541067883, 7.903642601143211, 7.975354709337353, 8.046791522809972, 8.117957563379242, 8.188857223094784, 8.259494769515255, 8.329874350709657, 8.4, 8.469875640461566, 8.539505089195911, 8.60889206139056, 8.678040174178353, 8.746952950308561, 8.815633821640875, 8.884086132472722, 8.952313142709627, 9.020318030887593, 9.088103897055975, 9.155673765528661, 9.223030587510916, 9.29017724360873, 9.357116546227115, 9.42385124186329, 9.490384013300432, 9.556717481707219], [0.0, 0.3791627615651736, 0.6159517233807204, 0.8181078427395065, 1.0006165267114866, 1.1697813168407254, 1.329020111485989, 1.4804519137445418, 1.6255063433101162, 1.7652061599853186, 1.9003153556332641, 2.0314238983196673, 2.158999540720252, 2.2834211761580674, 2.405001229258358, 2.5240012116354595, 2.6406428452918074, 2.755116214377696, 2.867585867021727, 2.978195467765554, 3.0870714028913415, 3.1943256147661936, 3.300057858850951, 3.4043575218054056, 3.507305101364073, 3.608973422339662, 3.709428644449928, 3.808731104222239, 3.9069360234095867, 4.004094109082331, 4.100252065113888, 4.195453030653067, 4.289736958018438, 4.383140940010578, 4.475699494736407, 4.567444814545126, 4.658406984491343, 4.7486141747963515, 4.838092811019703, 4.926867725039716, 5.014962289442597, 5.102398537511587, 5.189197270671892, 5.275378154969544, 5.360959807931826, 5.4459598769644835, 5.530395110279632, 5.614281421212554, 5.697633946670836, 5.780467100361969, 5.86279462136271, 5.944629618522651, 6.0259846111338335, 6.106871566246002, 6.18730193296209, 6.267286674009623, 6.3468362948498775, 6.4259608705573, 6.5046700706760205, 6.58297318223787, 6.660879131106719, 6.7383965017966005, 6.8155335558959695, 6.8922982492169735, 6.968698247776768, 7.0447409427074, 7.12043346418143, 7.1957826944321805, 7.270795279940079, 7.345477642849959, 7.419835991678281, 7.493876331363919, 7.567604472711436, 7.641026041271477, 7.714146485699049, 7.786971085627062, 7.859504959089259, 7.931753069523965, 8.003720232387408, 8.075411121403125, 8.146830274471805, 8.217982099264036, 8.288870878516677, 8.359500775051949, 8.429875836536963, 8.5, 8.569877096118695, 8.639510853294185, 8.70890490152418, 8.778062776087125, 8.84698792104862, 8.915683692600588, 8.984153362242878, 9.05240011981643, 9.120427076396378, 9.188237267053031, 9.255833653488045, 9.323219126552715, 9.390396508654781, 9.457368556059786, 9.52413796109262, 9.59070735424453], [0.0, 0.38049550919899555, 0.6181167782993404, 0.820983471366963, 1.0041336688032705, 1.1738930689433662, 1.3336915839733534, 1.4856556652334418, 1.63121995749487, 1.771410815535397, 1.9069949166304494, 2.0385643025687528, 2.1665883701649995, 2.2914473445428034, 2.413454748492161, 2.532873012834198, 2.64992463891865, 2.764800379036849, 2.8776653596999595, 2.988663750426908, 3.0979223817444845, 3.2055535894944156, 3.311657479775495, 3.41632375343939, 3.519633191168143, 3.6216588737518594, 3.722467193458049, 3.822118698895467, 3.920668805920186, 4.018168399836654, 4.114664348681231, 4.21019994323576, 4.304815276250212, 4.39854757090543, 4.491431466638619, 4.583499268954281, 4.674781168655241, 4.765305434980418, 4.855098586374541, 4.9441855419993646, 5.032589756595149, 5.120333340891577, 5.207437169430343, 5.29392097738314, 5.3798034477173955, 5.465102289869043, 5.549834310919747, 5.634015480139766, 5.717660987642537, 5.800785297799375, 5.883402197979546, 5.965524843109921, 6.047165796487542, 6.128337067226034, 6.209050144671641, 6.2893160300856, 6.369145265855625, 6.448547962469795, 6.527533823460446, 6.606112168503095, 6.684291954835799, 6.762081797146945, 6.839489986064266, 6.9165245053643885, 6.993193048010328, 7.069503031113775, 7.145461609909669, 7.22107569082221, 7.296351943694039, 7.371296813243668, 7.445916529810337, 7.520217119440131, 7.594204413362447, 7.667884056901596, 7.7412615178644755, 7.81434209444177, 7.887130922656986, 7.959632983394808, 8.031853109037673, 8.103795989737142, 8.175466179344507, 8.246868101023212, 8.318006052563826, 8.388884211420788, 8.459506639488657, 8.52987728763427, 8.6, 8.669878518092217, 8.739516484667986, 8.808917447432163, 8.878084862556161, 8.947022098028823, 9.015732436849245, 9.084219080070575, 9.152485149703304, 9.220533691485931, 9.288367677530424, 9.355990008849343, 9.423403517771124, 9.490610970249515, 9.557615068072858, 9.624418450978515], [0.0, 0.3818174525886767, 0.620264281671572, 0.8238357880087436, 1.007622298323827, 1.1779714881235268, 1.3383251860282595, 1.490817231240179, 1.636887252871012, 1.777565171530127, 1.913620328135311, 2.0456468213871584, 2.174115678910717, 2.2994084468335974, 2.4218397372080074, 2.5416728926100904, 2.65913118741891, 2.774406036650391, 2.8876631405094573, 2.99904716939859, 3.1086853944878245, 3.2166905419037137, 3.3231630655404714, 3.4281929778945677, 3.531861340301787, 3.634241487454489, 3.735400042284718, 3.8353977637633236, 3.934290260275919, 4.032128593916137, 4.128959795552461, 4.224827306370513, 4.319771358413224, 4.413829304184746, 4.507035903468972, 4.599423574008388, 4.691022611496759, 4.781861383387918, 4.87196650025878, 4.961362967846945, 5.05007432238073, 5.138122751408418, 5.2255292019954585, 5.312313477878819, 5.398494326935563, 5.484089520128955, 5.569115922932964, 5.6535895600993715, 5.737525674516145, 5.820938780807699, 5.903842714244317, 5.986250675456614, 6.068175271389891, 6.149628552880653, 6.230622049192214, 6.311166799807141, 6.391273383740227, 6.470951946606098, 6.550212225649762, 6.629063572925788, 6.707514976792078, 6.7855750818667575, 6.863252207581418, 6.94055436545047, 7.017489275164343, 7.094064379603762, 7.170286858862871, 7.246163643360639, 7.321701426112527, 7.396906674227727, 7.471785639691349, 7.546344369485576, 7.620588715099058, 7.694524341469479, 7.7681567354003604, 7.841491213489722, 7.914532929604993, 7.987286881935787, 8.059757919653531, 8.131950749204632, 8.203869940261681, 8.275519931355376, 8.346905035207966, 8.418029443787482, 8.488897233100596, 8.559512367740517, 8.629878705205195, 8.700000000000001, 8.76987990753791, 8.839521987849459, 8.908929709113723, 8.978106451020844, 9.047055507975937, 9.115780092153466, 9.184283336410623, 9.252568297067617, 9.320637956562331, 9.388495225986222, 9.456142947507995, 9.52358389669106, 9.590820784710498, 9.657856260474823], [0.0, 0.38312880201385263, 0.622394575097691, 0.8266652463787579, 1.011082970204441, 1.1820172231294865, 1.342921654711128, 1.4959374328076418, 1.6425091309270752, 1.7836702069340742, 1.9201926440425372, 2.052672581380976, 2.18158266431559, 2.3073057493915505, 2.430157529194004, 2.5504022507473674, 2.6682639552650294, 2.7839347151764753, 2.8975807997828484, 3.0093473763561356, 3.1193621531783338, 3.2277382435331057, 3.3345764463228758, 3.4399670831914175, 3.5439914938791173, 3.6467232649458334, 3.7482292481396136, 3.8485704111075774, 3.947802553221956, 4.045976911948794, 4.143140679683771, 4.239337446810962, 4.3346075835499756, 4.428988570691881, 4.522515287402813, 4.615220262763771, 4.707133896518872, 4.798284653549777, 4.888699235827243, 4.978402734970906, 5.067418768044097, 5.1557695987980825, 5.2434762462408635, 5.330558582125206, 5.417035418717632, 5.502924588015654, 5.588243013417597, 5.673006774712145, 5.7572311671388565, 5.840930755172526, 5.924119421600577, 6.0068104123911, 6.089016377787865, 6.1707494100158895, 6.252021077935665, 6.3328424589447865, 6.413224168391599, 6.493176386735774, 6.572708884664821, 6.651831046352875, 6.730551891028292, 6.808880092999079, 6.8868240002698595, 6.964391651870534, 7.041590794004757, 7.118428895115775, 7.194913159957718, 7.271050542752029, 7.346847759501287, 7.422311299525926, 7.497447436283455, 7.572262237524376, 7.646761574834238, 7.7209511326069125, 7.794836416490312, 7.868422761342274, 7.941715338731152, 8.014719164012806, 8.08743910301311, 8.159879878342728, 8.23204607536876, 8.30394214786601, 8.37557242336874, 8.446941108242266, 8.518052292492278, 8.588909954328352, 8.659517964496992, 8.729880090398385, 8.800000000000002, 8.86988126555928, 8.93952736716673, 9.008941696120019, 9.07812755813887, 9.147088176429941, 9.215826694610199, 9.284346179496767, 9.352649623770686, 9.420739948521542, 9.488620005679442, 9.556292580340452, 9.62376039299117, 9.691026101637764], [0.0, 0.3844297613276207, 0.6245079897380311, 0.8294722863245722, 1.0145162224166624, 1.186030902882566, 1.3474817045564387, 1.501017065886115, 1.6480864656004193, 1.789726870792819, 1.9267128860378278, 2.0596426747251133, 2.1889904871443044, 2.315140479875408, 2.4384094174752047, 2.5590624442502428, 2.6773243621724383, 2.7933878958760046, 2.907419879249228, 3.0195659724967947, 3.1299543175493283, 3.23869841178007, 3.3458993963660797, 3.45164789964899, 3.5560255375679293, 3.659106146554652, 3.76095680536025, 3.8616386886547236, 3.9612077852836944, 4.0597155066961035, 4.15720920553501, 4.253732620200812, 4.349326257994987, 4.444027726979081, 4.537872024755575, 4.630891790861824, 4.723117528267885, 4.814577798511299, 4.905299394232537, 4.995307492252805, 5.084625789829976, 5.173276626314526, 5.261281092086992, 5.3486591263770356, 5.4354296053304605, 5.521610421495444, 5.607218555735718, 5.692270142440798, 5.776780528787043, 5.860764328704649, 5.944235472121694, 6.027207249984523, 6.10969235549231, 6.19170292193066, 6.273250557443501, 6.354346377043045, 6.435001032123316, 6.515224737712941, 6.5950272976769595, 6.674418128054583, 6.753406278700028, 6.832000453375945, 6.910209028433596, 6.988040070200363, 7.065501351183053, 7.142600365184898, 7.219344341424626, 7.295740257737565, 7.371794852931276, 7.4475146383614526, 7.522905908787871, 7.597974752564802, 7.672727061215459, 7.747168538435749, 7.821304708568663, 7.895140924587184, 7.968682375620338, 8.04193409405422, 8.114900962237197, 8.187587718816113, 8.25999896472823, 8.33213916887167, 8.404012673475352, 8.475623699187807, 8.546976349902822, 8.618074617338456, 8.688922385384792, 8.759523434234675, 8.82988144431059, 8.9, 8.969882593210476, 9.03953262675524, 9.108953417578975, 9.178148199833124, 9.247120127809179, 9.315872278737999, 9.384407655462635, 9.452729188991572, 9.52083974093899, 9.58874210585808, 9.65643901347317, 9.723933130816008], [0.0, 0.3857205282226821, 0.6266048467453329, 0.8322573344016542, 1.017922576674657, 1.1900131372982201, 1.3520060285055933, 1.5060569023724395, 1.653620104418208, 1.7957360834719913, 1.9331820449317625, 2.066558160589188, 2.19634027308349, 2.3229138288443316, 2.4465966560017263, 2.5676547891145574, 2.6863137849530756, 2.8027670152464976, 2.917181874046972, 3.029704510629983, 3.1404634971773437, 3.2495727121427076, 3.3571336362962048, 3.4632372022744913, 3.5679653000515468, 3.6713920139733904, 3.773584648015693, 3.8746045822494075, 3.9745079935091088, 4.073346465863557, 4.171167510947727, 4.2680150140187, 4.363929618385851, 4.458949058384094, 4.553108449124363, 4.646440539734994, 4.738975935603254, 4.830743294165314, 4.921769498021, 5.012079808525574, 5.101698002503163, 5.190646494311169, 5.278946445143491, 5.366617861178038, 5.45367968193943, 5.540149860052123, 5.626045433395041, 5.711382590530755, 5.796176730165528, 5.880442515297497, 5.964193922626064, 6.04744428772345, 6.1302063464076975, 6.212492272703302, 6.294313713729865, 6.375681821819525, 6.456607284129575, 6.5371003499867735, 6.617170856173756, 6.696828250345162, 6.776081612741133, 6.854939676348192, 6.933410845642163, 7.011503214034042, 7.089224580127718, 7.166582462887726, 7.24358411580572, 7.32023654014591, 7.396546497342174, 7.472520520612826, 7.548164925853019, 7.6234858218593695, 7.6984891199365535, 7.77318054293129, 7.847565633735184, 7.921649763294437, 7.995438138161168, 8.068935807618287, 8.1421476704072, 8.215078481085301, 8.28773285603803, 8.360115279168339, 8.43223010728468, 8.504081575206895, 8.575673800608064, 8.647010788608892, 8.718096436140073, 8.788934536086877, 8.859528781229232, 8.929882767989588, 9.0, 9.069883891499018, 9.139537770568356, 9.208964882218481, 9.278168391331782, 9.347151385471276, 9.415916877562399, 9.484467808454836, 9.552807049370962, 9.620937404246996, 9.688861611972634, 9.756582348534485], [0.0, 0.38700129448363696, 0.6286854576745986, 0.8350208044177445, 1.0213025391010189, 1.1939645180644125, 1.356495298791249, 1.5110576910951057, 1.659110869579021, 1.8016987378318403, 1.9396010819242737, 2.073420066489243, 2.2036331141783196, 2.330626951277296, 2.45472046124904, 2.576180562007253, 2.6952335592724754, 2.812073466855349, 2.926868234631834, 3.0397644971589797, 3.150891253536277, 3.260362760345248, 3.3682808353179863, 3.4747367130285474, 3.579812555362588, 3.6835826926595963, 3.786114652374822, 3.8874700183887603, 3.9877051540684323, 4.086871814764993, 4.185017669873489, 4.282186750369865, 4.378419834517628, 4.473754781946719, 4.568226824366088, 4.661868819645961, 4.754711474797305, 4.846783542411913, 4.938111994351978, 5.028722175851865, 5.118637942685488, 5.207881783636033, 5.296474930162117, 5.384437454871186, 5.471788360175634, 5.558545658310733, 5.644726443728854, 5.730346958745905, 5.8154226531988025, 5.899968238773457, 5.983997738578223, 6.0675245324654385, 6.150561398541811, 6.233120551255093, 6.31521367639858, 6.396851963335186, 6.478046134708393, 6.558806473877348, 6.639142850287246, 6.719064742963206, 6.798581262295863, 6.877701170269198, 6.956432899265688, 7.034784569570109, 7.112764005681232, 7.190378751529949, 7.267636084692781, 7.3445430296812955, 7.421106370380382, 7.4973326617015905, 7.573228240511694, 7.648799235891273, 7.724051578773203, 7.7989910110066365, 7.873623093888082, 7.947953216197704, 8.021986601775728, 8.095728316670959, 8.16918327589084, 8.24235624978004, 8.315251870052478, 8.387874635499696, 8.460228917396709, 8.532318964624876, 8.60414890852981, 8.675722767531024, 8.74704445149878, 8.818117765912442, 8.888946415813631, 8.959534009566548, 9.029884062436881, 9.1, 9.169885161388347, 9.239542802387291, 9.308976098388056, 9.378188147205767, 9.44718197177013, 9.515960522695776, 9.584526680738838, 9.65288325914587, 9.721033005900912, 9.78897860587606], [0.0, 0.38827224622629886, 0.6307501248718591, 0.8377630979492163, 1.0246566008583249, 1.1978856193799394, 1.3609501677761493, 1.5160201587486635, 1.6645595589788182, 1.80761570034137, 1.9459709298040586, 2.0802293895699084, 2.210870070195196, 2.338280968014302, 2.462782013735925, 2.584641001859434, 2.7040849813164476, 2.821308603078761, 2.9364803685868655, 3.0497473939606583, 3.1612391019458372, 3.271070124354197, 3.3793426132976543, 3.4861481029739156, 3.5915690250966534, 3.695679954113777, 3.79854863924759, 3.900236866626334, 4.00080118472008, 4.100293518849838, 4.198761694961813, 4.296249888634165, 4.392799012050382, 4.488447049175292, 4.583229347422374, 4.67717887257045, 4.770326432475446, 4.862700874155602, 4.954329258051458, 5.045237012633714, 5.13544807202108, 5.224984998852202, 5.313869094311972, 5.402120496928328, 5.489758271519526, 5.576800489474856, 5.663264301386615, 5.749166002912134, 5.8345210946271715, 5.919344336532314, 6.003649797789236, 6.087450902191075, 6.170760469809146, 6.253590755204693, 6.3359534825483514, 6.4178598779500415, 6.499320699267504, 6.580346263631485, 6.660946472899446, 6.7411308372265895, 6.820908496923003, 6.900288242747921, 6.979278534776621, 7.0578875199617235, 7.136123048498454, 7.213992689092741, 7.29150374322141, 7.368663258465242, 7.445478040988098, 7.521954667228521, 7.598099494864209, 7.673918673104263, 7.749418152359348, 7.824603693335436, 7.8994808755929, 7.974055105609211, 8.048331624380216, 8.122315514592142, 8.196011707393819, 8.269424988796212, 8.342560005724264, 8.415421271744005, 8.488013172486168, 8.560339970785867, 8.632405811556476, 8.704214726414412, 8.775770638070345, 8.847077364501223, 8.918138622916404, 8.98895803353032, 9.059539123153158, 9.129885328610218, 9.200000000000001, 9.269886403800205, 9.339547725830364, 9.40898707407914, 9.478207481403853, 9.547211908109253, 9.616003244412168, 9.684584312798139, 9.752957870275871, 9.821126610534852], [0.0, 0.38953356412482815, 0.6327991418431539, 0.840484604831155, 1.0279852387485424, 1.2017769986551765, 1.3653712687492587, 1.5209450107805709, 1.669966947184681, 1.8134878121357685, 1.952292494086943, 2.086987097821303, 2.218052169915078, 2.3458769671242354, 2.4707824594651586, 2.5930373113783425, 2.7128693093729286, 2.8304737367521673, 2.946019642340209, 3.0596546201695425, 3.171508513420823, 3.281696326291864, 3.390320542739798, 3.497472994314828, 3.6032363805133407, 3.707685518041317, 3.8108883762071164, 3.912906941853684, 4.0137979471510565, 4.11361348610172, 4.212401540016377, 4.310206427979319, 4.407069195078894, 4.503027948672358, 4.598118151000673, 4.692372874933312, 4.7858230284067504, 4.878497552149918, 4.970423594510277, 5.061626666563932, 5.152130780180531, 5.2419585712943535, 5.331131410288043, 5.419669501110348, 5.507591970512348, 5.594916948588963, 5.681661641646875, 5.767842398280508, 5.853474769419859, 5.938573563013968, 6.023152893928741, 6.107226229565045, 6.190806431640707, 6.273905794526406, 6.356536080479209, 6.438708552077507, 6.52043400212637, 6.601722781272154, 6.6825848235389005, 6.763029669975933, 6.843066490585999, 6.922704104685465, 7.001950999832504, 7.080815349445435, 7.159305029221156, 7.237427632452841, 7.315190484336453, 7.39260065534712, 7.4696649737588, 7.546390037373858, 7.622782224523162, 7.698847704391765, 7.7745924467204786, 7.8500222309291585, 7.925142654703601, 7.999959142084435, 8.074476951093095, 8.148701180927114, 8.222636778754355, 8.296288546133335, 8.369661145084716, 8.442759103837027, 8.515586822267895, 8.58814857706043, 8.66044852659292, 8.732490715578647, 8.804279079471366, 8.875817448650876, 8.947109552402035, 9.018159022699688, 9.088969397811004, 9.159544125725951, 9.229886567425956, 9.3, 9.36988761961688, 9.439552544361685, 9.508997816944088, 9.578226407285511, 9.647241214991768, 9.716045071717355, 9.78464074342723, 9.853030932561438], [0.0, 0.39078542362742896, 0.6348327936049316, 0.843185703622761, 1.0312889157822585, 1.205639197177539, 1.3697592166818127, 1.5258329322333903, 1.6753337863595268, 1.8193158900205935, 1.9585666540969282, 2.0936941312346695, 2.2251804123616847, 2.3534160052038544, 2.4787229112916656, 2.6013706584832077, 2.7215877653341827, 2.839570142737557, 2.955487382796409, 3.0694875538720368, 3.1817009164272885, 3.292242844253541, 3.4012161506646943, 3.508712962333655, 3.6148162445314695, 3.719601054405542, 3.8231355796998994, 3.92548200646707, 4.02669724919952, 4.126833569316303, 4.225939102327567, 4.324058309747607, 4.421232368573004, 4.517499508628141, 4.612895306120397, 4.707452940206838, 4.801203418154004, 4.894175773698797, 4.986397242436403, 5.077893417428884, 5.168688387713792, 5.258804861971405, 5.348264279263216, 5.437086908468207, 5.525291937805858, 5.612897555636496, 5.699921023563395, 5.786378742721106, 5.872286314016268, 5.957658592986817, 6.042509739860164, 6.126853265317897, 6.210702072412058, 6.294068495024233, 6.376964333212324, 6.459400885749716, 6.541388980126745, 6.6229390002540525, 6.704060912081048, 6.784764287319504, 6.865058325442171, 6.944951874108402, 7.024453448153174, 7.103571247262046, 7.182313172442355, 7.260686841390144, 7.33869960284265, 7.416358549997666, 7.4936705330734465, 7.570642171075979, 7.647279862834422, 7.7235897973599865, 7.799577963578678, 7.875250159483903, 7.950612000750963, 8.025668928851944, 8.100426218706188, 8.174888985898725, 8.24906219349633, 8.322950658488478, 8.39655905787835, 8.469891934447025, 8.542953702212193, 8.615748651601107, 8.688280954356003, 8.760554668188819, 8.832573741200834, 8.904342016081689, 8.975863234101194, 9.047141038906421, 9.118178980135601, 9.18898051685965, 9.259549020861309, 9.329887779761275, 9.4, 9.469888809683283, 9.53955726129928, 9.60900833431396, 9.678244937651721, 9.74726991206726, 9.816086032414622, 9.884696009818796], [0.0, 0.3920279951613008, 0.6368513570169946, 0.8458667620495673, 1.0345680817195488, 1.2094727407437935, 1.3741146089457015, 1.5306845885450266, 1.6806608071407545, 1.8251007274259303, 1.9647942639933806, 2.1003514029004293, 2.2322557679685153, 2.3608991086120636, 2.4866044502225124, 2.609642177669559, 2.730241536124166, 2.8485990594127144, 2.964884878886441, 3.079247533716248, 3.191817698551219, 3.3027111140341536, 3.41203092039211, 3.5198695372310844, 3.6263101936249105, 3.731428185378499, 3.8352919170508977, 3.9379637724262135, 4.0395008469666305, 4.13995556826565, 4.239376224888808, 4.337807419723666, 4.435290460696367, 4.531863699189796, 4.627562824532192, 4.722421121379632, 4.816469695591758, 4.909737673223385, 5.002252376470102, 5.0940394797716495, 5.185123148760945, 5.275526164324542, 5.3652700336932275, 5.454375090194481, 5.5428605830601265, 5.630744758483607, 5.718044932954524, 5.804777559757745, 5.890958289405757, 5.97660202467231, 6.061722970809771, 6.146334681459336, 6.230450100700585, 6.31408160163287, 6.397241021834467, 6.479939696005217, 6.562188486063379, 6.64399780893708, 6.725377662264231, 6.80633764819156, 6.886886995443172, 6.967034579811123, 7.046788943204814, 7.126158311382159, 7.205150610473151, 7.283773482395646, 7.3620342992534935, 7.439940176798568, 7.517497987030605, 7.594714370001897, 7.6715957448878145, 7.748148320378625, 7.824378104443188, 7.900290913510656, 7.9758923811123665, 8.05118796602253, 8.126182959933029, 8.20088249469481, 8.275291549155588, 8.349414955621315, 8.423257405966535, 8.4968234574169, 8.570117538025258, 8.64314395186103, 8.715906883931249, 8.788410404850067, 8.86065847527245, 8.932654950106555, 9.004403582518218, 9.075908027740136, 9.147171846697244, 9.218198509459185, 9.288991398529886, 9.359553811983611, 9.42988896645626, 9.5, 9.569889974808913, 9.63956187982271, 9.709018633215226, 9.778263084773844, 9.847298018175751, 9.916126153166436], [0.0, 0.3932614443274868, 0.6388551010990308, 0.8485281374238569, 1.0378231735841859, 1.213278140261196, 1.378438025996442, 1.5355006263095174, 1.6859487194755767, 1.830843095313516, 1.9709761537475865, 2.106959800052115, 2.239279179688338, 2.36832727464334, 2.4944281266528123, 2.6178529713062884, 2.738831775055528, 2.8575616900870493, 2.974213383041342, 3.088935860442455, 3.2018602080849465, 3.313102530769793, 3.4227662932371707, 3.530944205875589, 3.6377197596249555, 3.7431684871955775, 3.8473590083697706, 3.9503539032115693, 4.052210446824284, 4.152981231755889, 4.252714698503648, 4.351455590290494, 4.44924534501091, 4.54612243471386, 4.642122661017961, 4.737279413303779, 4.831623895300233, 4.925185324702299, 5.017991109670189, 5.110067005423886, 5.201437253629346, 5.292124706849293, 5.3821509399833465, 5.471536350334327, 5.560300247698484, 5.648460935677789, 5.736035785245225, 5.82304130145311, 5.909493184055599, 5.995406382715474, 6.080795147379505, 6.165673074333105, 6.250053148382193, 6.333947781555962, 6.417368848677612, 6.500327720109679, 6.582835291945594, 6.664902013888572, 6.746537915032383, 6.827752627735272, 6.908555409757948, 6.988955164818631, 7.068960461702384, 7.148579552048063, 7.227820386923875, 7.306690632291667, 7.385197683450354, 7.463348678540311, 7.541150511182846, 7.618609842322043, 7.695733111330111, 7.772526546431904, 7.8489961744993275, 7.9251478302619365, 8.000987164976014, 8.076519654590868, 8.151750607447793, 8.226685171544222, 8.301328341392967, 8.375684964504007, 8.449759747514065, 8.523557261987332, 8.597081949908759, 8.670338128889794, 8.743329997104878, 8.816061637975654, 8.888537024618616, 8.960760024070728, 9.032734401306527, 9.10446382305927, 9.175951861457735, 9.247201997489551, 9.318217624301111, 9.38900205034351, 9.459558502373245, 9.529890128315824, 9.600000000000001, 9.66989111576968, 9.739566402980229, 9.809028720385399, 9.878280860420743, 9.947325551388966], [0.0, 0.394485932086216, 0.6408442873317042, 0.851170177044572, 1.0410546161527616, 1.2170558923193064, 1.38273003202283, 1.5402816740007104, 1.691198213415603, 1.8365437430396085, 1.9771131300716662, 2.1135201850593726, 2.246251564048556, 2.375701472643921, 2.502194961541342, 2.6260041108694336, 2.7473596031204157, 2.8664592043483546, 2.983474112593945, 3.0985537983389086, 3.211829755536177, 3.3234184504991737, 3.4334236701234997, 3.5419384134675496, 3.649046431434763, 3.754823491919649, 3.859338428364125, 3.9626540156861165, 4.064827707324907, 4.165912259584497, 4.265956263790046, 4.365004602480277, 4.463098842573748, 4.560277575908826, 4.656576715578678, 4.752029754927505, 4.84666799484245, 4.940520743992853, 5.03361549587899, 5.1259780859141895, 5.217632831245044, 5.308602655589698, 5.398909201024962, 5.488572928364203, 5.577613207528067, 5.6660483991099735, 5.75389592817044, 5.841172351153133, 5.9278934166961115, 6.014074121010533, 6.099728758412846, 6.184870967522859, 6.2695137735769375, 6.353669627251283, 6.437350440343416, 6.520567618619472, 6.603332092099758, 6.685654343024455, 6.767544431714656, 6.849012020520625, 6.930066396028717, 7.010716489680423, 7.090970896941205, 7.170837895142831, 7.250325460110536, 7.32944128167547, 7.408192778163097, 7.486587109939628, 7.56463119209086, 7.64233170630088, 7.719695111992001, 7.796727656781736, 7.873435386307703, 7.949824153466898, 8.025899627111773, 8.101667300241957, 8.17713249772718, 8.252300383594063, 8.3271759679067, 8.401764113268632, 8.476069540971515, 8.550096836813893, 8.623850456611615, 8.697334731419758, 8.77055387248451, 8.843511975941952, 8.916213027279568, 8.988660905575014, 9.060859387525726, 9.132812151281971, 9.204522780094974, 9.27599476579102, 9.347231512081654, 9.418236337719406, 9.489012479507839, 9.559563095174076, 9.629891266111539, 9.700000000000001, 9.769892233309653, 9.839570833695477, 9.90903860228776, 9.978298275884244], [0.0, 0.3957016149332982, 0.6428191699432075, 0.8537932185779132, 1.0442628224201933, 1.2208064797341942, 1.3869911755652267, 1.5450283426609972, 1.696409959873056, 1.8422033991761964, 1.9832059773026387, 2.1200333963730196, 2.253173812155615, 2.383022645074095, 2.509905947529396, 2.6340966381163966, 2.7558261102189503, 2.8752927393445415, 2.9926682511129368, 3.108102576627354, 3.221727615064157, 3.3336601916496926, 3.444004413118469, 3.5528535651230286, 3.6602916566610255, 3.7663946891200357, 3.8712317080652174, 3.974865681867252, 4.07735424101904, 4.178750304403087, 4.279102613087893, 4.3784561879261945, 4.476852723932852, 4.5743309318742655, 4.670926835516577, 4.766674031420049, 4.861603916931415, 4.955745891040209, 5.0491275319731175, 5.141774754760173, 5.233711951485843, 5.324962116512032, 5.415546958609701, 5.5054870016460695, 5.594801675233854, 5.683509396548103, 5.771627644347949, 5.859173026098863, 5.946161338971307, 6.0326076253900895, 6.118526223722296, 6.203930814617713, 6.288834463452432, 6.373249659271762, 6.457188350581676, 6.5406619782973285, 6.623681506121951, 6.706257448598721, 6.788399897051513, 6.870118543606946, 6.951422703469743, 7.0323213356053165, 7.1128230619676795, 7.192936185396758, 7.272668706296798, 7.352028338196617, 7.431022522282649, 7.509658440987122, 7.5879430307059765, 7.66588299371417, 7.743484809339946, 7.820754744454027, 7.8976988633248055, 7.974323036886085, 8.050632951459955, 8.12663411697376, 8.20233187470682, 8.27773140459968, 8.352837732155892, 8.427655734964027, 8.50219014886529, 8.576445573790235, 8.650426479286141, 8.724137209755053, 8.797581989420905, 8.870764927042801, 8.943690020390251, 9.016361160495023, 9.088782135693158, 9.160956635469839, 9.232888254118757, 9.304580494226911, 9.376036769995034, 9.447260410403016, 9.518254662229237, 9.589022692931957, 9.659567593400492, 9.729892380583346, 9.8, 9.869893328142656, 9.939575174773806, 10.009048285125159], [0.0, 0.3969086450680869, 0.6447799961821201, 0.8563975904197504, 1.0474481940429832, 1.224530372066635, 1.3912219901042966, 1.549741226557134, 1.7015846113408484, 1.8478227722929592, 1.9892554582442337, 2.1265002494249385, 2.260046790651412, 2.390291708519725, 2.517562050006168, 2.642131566204037, 2.764232356328996, 2.884063401004118, 3.0017969496731576, 3.1175833907823227, 3.2315550258472006, 3.343829036452474, 3.4545098468950783, 3.5636910273818514, 3.671456843167657, 3.7778835274712317, 3.883040336471174, 3.9869904306140063, 4.089791616186053, 4.191496973491163, 4.292155392275365, 4.391812030720947, 4.490508711027341, 4.5882842620425, 4.68517481741782, 4.781214076194971, 4.876433531493721, 4.9708626719809414, 5.06452916000668, 5.157458989650995, 5.249676627402851, 5.341205137765109, 5.432066295728168, 5.52228068776432, 5.61186780275348, 5.700846114049608, 5.789233153728247, 5.877045579913521, 5.964299237962858, 6.051009216185794, 6.137189896686513, 6.222855001845632, 6.308017636893268, 6.392690328970746, 6.4768850630312125, 6.56061331488867, 6.643886081689527, 6.726713910050045, 6.809106922076213, 6.891074839459067, 6.9726270058180075, 7.053772407446466, 7.13451969259847, 7.214877189440548, 7.294852922781017, 7.374454629677686, 7.453689774015246, 7.532565560134891, 7.611088945591024, 7.6892666531029175, 7.767105181763059, 7.844610817558351, 7.921789643255351, 7.998647547696292, 8.07519023454856, 8.15142323054673, 8.227351893262918, 8.302981418438321, 8.37831684690606, 8.453363071133078, 8.528124841406573, 8.602606771688516, 8.676813345159895, 8.750748919474713, 8.824417731742288, 8.897823903254896, 8.970971443976657, 9.043864256808366, 9.116506141641834, 9.188900799216476, 9.261051834789855, 9.332962761633103, 9.404637004361474, 9.476077902109424, 9.54728871155916, 9.618272609830811, 9.689032697242002, 9.759571999943997, 9.829893472441157, 9.9, 9.969894400953795, 10.039579428908178], [0.0, 0.39810717055349715, 0.6467270065773572, 0.8589836120408868, 1.0506111217615068, 1.2282280261157903, 1.3954229946218906, 1.5544209038050334, 1.7067228025785932, 1.8534025517022354, 1.9952623149688793, 2.1329215374853936, 2.2668713426244502, 2.3975095546559166, 2.5251642081237278, 2.650109880753873, 2.7725793726205854, 2.8927722651989245, 3.010861328065805, 3.1269974037880193, 3.241313193385525, 3.353926232290463, 3.4649412601246747, 3.574452129644344, 3.682543360555973, 3.789291416275995, 3.8947657621124785, 3.999029749234436, 4.102141358482987, 4.204153830445961, 4.305116202499342, 4.405073769187359, 4.504068478997878, 4.602139278028412, 4.699322409041364, 4.795651672837741, 4.891158657635536, 4.985872941147091, 5.079822269253092, 5.173032714526639, 5.26552881733695, 5.357333711833627, 5.448469238759937, 5.538956046752126, 5.6288136835397236, 5.718060678259764, 5.806714615928536, 5.894792204971879, 5.982309338594668, 6.069281150667864, 6.155722066724581, 6.241645850582236, 6.3270656470441615, 6.411994021079273, 6.496442993831094, 6.580424075766572, 6.663948297239661, 6.747026236713719, 6.829668046859957, 6.911883478725527, 6.993681904144294, 7.075072336545158, 7.156063450296854, 7.236663598714063, 7.3168808308372215, 7.3967229070873515, 7.476197313887467, 7.555311277333358, 7.6340717759888115, 7.712485552873362, 7.7905591267044905, 7.868298802450583, 7.945710681246025, 8.022800669715298, 8.099574488748875, 8.176037681770133, 8.25219562252919, 8.328053522456562, 8.40361643760693, 8.478889275220773, 8.553876799929505, 8.628583639627644, 8.703014291033819, 8.777173124960632, 8.851064391311986, 8.924692223825021, 8.99806064457255, 9.071173568240765, 9.14403480619582, 9.216648070352075, 9.28901697685371, 9.361145049580708, 9.433035723489464, 9.504692347797457, 9.576118189020933, 9.647316433873819, 9.718290192035612, 9.789042498795498, 9.859576317579407, 9.929894542366357, 10.0, 10.069895452400896], [0.0, 0.39929733546852775, 0.6486604351859426, 0.8615515943161518, 1.053751985802521, 1.2318998863897659, 1.3995946941356594, 1.5590679369652922, 1.7118251512664793, 1.858943408169094, 2.0012272695821234, 2.1392980324801933, 2.2736482884783236, 2.4046770511655495, 2.532713335764462, 2.6580325408673895, 2.7808681625181464, 2.9014203788524076, 3.019862475951949, 3.1363457473363305, 3.251003290743052, 3.3639529929833762, 3.475299906804434, 3.5851381655407693, 3.693552541575544, 3.800619726917092, 3.906409394544127, 4.010985085017725, 4.114404952516158, 4.216722396793136, 4.3179866018247814, 4.418242997566036, 4.517533657912252, 4.615897645392603, 4.71337131111937, 4.809988556943054, 4.90578106551649, 5.000778502976343, 5.095008698151246, 5.188497801559799, 5.2812704269361035, 5.373349777590669, 5.464757759560956, 5.555515083213528, 5.645641354717007, 5.735155158602379, 5.824074132457376, 5.912415034658666, 6.000193805924799, 6.087425625370337, 6.174124961654379, 6.260305619742086, 6.345980783733957, 6.431163056162626, 6.515864494109534, 6.600096642452852, 6.683870564522427, 6.767196870406558, 6.850085743128469, 6.932546962886642, 7.014589929532594, 7.096223683441403, 7.177456924914341, 7.2582980322388195, 7.338755078518354, 7.418835847374207, 7.498547847610494, 7.577898326925846, 7.65689428474688, 7.735542484251785, 7.813849463646133, 7.891821546747385, 7.969464852929632, 8.046785306475556, 8.123788645378566, 8.200480429634437, 8.276866049058428, 8.352950730660936, 8.428739545612013, 8.504237415822628, 8.579449120168338, 8.654379300379029, 8.729032466616532, 8.803413002760255, 8.877525171419439, 8.951373118689274, 9.024960878666798, 9.098292377741389, 9.171371438673507, 9.244201784474498, 9.316787042099216, 9.389130745962497, 9.461236341289736, 9.5331071873111, 9.604746560308277, 9.676157656522058, 9.74734359492852, 9.818307419891019, 9.889052103694825, 9.959580548970678, 10.02989559101324, 10.100000000000003]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha = 0.8\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.10000000000000002, 0.17411011265922485, 0.24082246852806927, 0.30314331330207966, 0.36238983183884776, 0.4192962712629476, 0.47432763938033673, 0.5278031643091579, 0.5799546134795289, 0.6309573444801934, 0.6809483127522303, 0.7300372102718471, 0.7783137122039473, 0.8258523872989461, 0.8727161387290322, 0.9189586839976283, 0.9646263856416865, 1.0097596309015797, 1.0543938903738734, 1.0985605433061179, 1.142287530066645, 1.1855998744839988, 1.228520106741704, 1.271068609258575, 1.313263902201884, 1.3551228811604874, 1.396661016523824, 1.4378925219250929, 1.4788304974808697, 1.519487052336355, 1.5598734100953937, 1.6000000000000005, 1.6398765361701582, 1.679512086781349, 1.7189151347155787, 1.7580936309501134, 1.797055041730823, 1.8358063904019344, 1.8743542946219982, 1.9127049995800744, 1.9508644077311328, 1.9888381054913127, 2.026631387268768, 2.0642492771517187, 2.1016965485301045, 2.13897774188921, 2.1760971809815493, 2.2130589875561473, 2.249867094801228, 2.2865252596366323, 2.323037073975402, 2.3594059750594583, 2.395635254961836, 2.4317280693371046, 2.4676874454922784, 2.503516289842348, 2.539217394807506, 2.5747934452029178, 2.61024702416647, 2.6455806186651625, 2.680796624616603, 2.715897351658382, 2.750885027594806, 2.785761802547598, 2.820529752834578, 2.855190884598056, 2.889747137202636, 2.924200386420304, 2.9585524474190423, 2.99280507756976, 3.026959979085028, 3.061018801501899, 3.094983144020095, 3.128854557705816, 3.1626345475706255, 3.1963245745340574, 3.229926057277886, 3.26344037399938, 3.296868864070247, 3.3302128296074938, 3.3634735369618975, 3.3966522181293946, 3.4297500720902443, 3.462768266080517, 3.4957079368000623, 3.5285701915608625, 3.5613561093793575, 3.5940667420160914, 3.626703114965799, 3.659266228400805, 3.69175705807045, 3.7241765561590467, 3.7565256521046995, 3.788805253381191, 3.821016246244965, 3.8531594964491087, 3.885235849926139, 3.917246133441246, 3.9491911552175707, 3.9810717055349736, 4.012888557303689], [0.0, 0.11486983549970352, 0.2, 0.2766323734445184, 0.3482202253184497, 0.4162766037009366, 0.4816449370561385, 0.5448593790858196, 0.6062866266041593, 0.6661929104768761, 0.7247796636776956, 0.7822042066964935, 0.8385925425258952, 0.89404768088031, 0.9486552787606736, 1.0024875929374035, 1.0556063286183157, 1.1080647423733407, 1.1599092269590578, 1.2111805273913923, 1.2619146889603867, 1.3121438067211815, 1.3618966255044607, 1.4111990256949771, 1.4600744205436942, 1.508544084136291, 1.5566274244078944, 1.6043422121694033, 1.6517047745978921, 1.698730159775722, 1.7454322774580646, 1.791824020180194, 1.8379173679952565, 1.8837234794968964, 1.929252771283373, 1.9745149876272918, 2.01951926180316, 2.0642741702753247, 2.108787780747747, 2.153067694913917, 2.197121086612236, 2.240954735983017, 2.28457506013329, 2.3279881407409926, 2.3711997489679977, 2.414215367999477, 2.457040213483408, 2.4996792521071907, 2.54213721851715, 2.5844186307601285, 2.626527804403768, 2.66846886547267, 2.7102457623209752, 2.751862276547563, 2.793322033047648, 2.8346285092838155, 2.8757850438501857, 2.916794844395239, 2.95766099496174, 2.9983864627959296, 3.03897410467271, 3.0794266727786956, 3.119746820190787, 3.1599371059841266, 3.200000000000001, 3.239937887301273, 3.279753072340316, 3.3194477828620594, 3.3590241735626973, 3.3984843295227054, 3.437830269431157, 3.4770639486168307, 3.516187261900227, 3.555202046279435, 3.5941100834616466, 3.632913102251169, 3.671612780803869, 3.7102107487571665, 3.7487085892439964, 3.787107840798436, 3.825409999160149, 3.8636165189841907, 3.9017288154622656, 3.939748265861026, 3.977676210982625, 4.015513956552311, 4.053262774537536, 4.090923904402708, 4.128498554303437, 4.165987902223836, 4.203393097060209, 4.24071525965422, 4.27795548377842, 4.315114837076832, 4.3521943619630985, 4.389195076478536, 4.4261179751122945, 4.462964029585662, 4.499734189602456, 4.536429383567264, 4.573050519273265, 4.609598484561173], [0.0, 0.12457309396155174, 0.21689435423953973, 0.30000000000000004, 0.37763500451796084, 0.4514402257237171, 0.5223303379776745, 0.590884615890877, 0.6575007318068904, 0.7224674055842076, 0.7860030855966228, 0.8482783814744369, 0.9094299399062389, 0.9695694720194644, 1.028789870413634, 1.0871694955165432, 1.1447752648842044, 1.2016649337633383, 1.2578888137888427, 1.3134910917803058, 1.3685108578372633, 1.42298291814101, 1.4769384456489911, 1.5304055069078983, 1.5834094929274731, 1.6359734748530934, 1.6881185000425407, 1.7398638404385867, 1.7912272024038713, 1.8422249051589266, 1.89287203344058, 1.9431825688393956, 1.993169503384828, 2.0428449382566907, 2.0922201699617475, 2.141305765888571, 2.190111630815541, 2.238647065676141, 2.2869208196675728, 2.3349411366118416, 2.3827157963341836, 2.4302521517053735, 2.4775571618968377, 2.524637422316621, 2.571499191626862, 2.6181484161870965, 2.6645907522203225, 2.7108315859588235, 2.7568760519928843, 2.802729050016767, 2.848395260141756, 2.8938791569250593, 2.9391850222452844, 2.984316957139667, 3.0292788927047387, 3.074074600150511, 3.118707700088062, 3.16318167112162, 3.2074998578085054, 3.251665478043504, 3.2956816299183536, 3.3395512981017474, 3.3832773597806907, 3.4268625901999354, 3.470309667832636, 3.5136211792121412, 3.5567996234519956, 3.5998474164786907, 3.642766894999424, 3.685560320225111, 3.728229881367068, 3.770777698924158, 3.813205827775725, 3.8555162600943405, 3.8977109280911595, 3.939791706605651, 3.9817604155504793, 4.023618822221423, 4.065368643481462, 4.107011547827371, 4.148549157346593, 4.189983049571472, 4.231314759237462, 4.2725457799513675, 4.3136775657752775, 4.354711532731363, 4.395649060232419, 4.4364914924426095, 4.4772401395725865, 4.517896279112868, 4.558461157009065, 4.598935988782319, 4.639321960598091, 4.67962023028618, 4.7198319283147585, 4.759958158720896, 4.800000000000001, 4.839958505956381, 4.879834706517015, 4.9196296085104745, 4.959344196412832, 4.998979433062281], [0.0, 0.13195079107728944, 0.229739670999407, 0.3177671523146437, 0.4000000000000001, 0.4781762498950185, 0.5532647468890367, 0.6258790724605869, 0.6964404506368994, 0.7652547003754746, 0.8325532074018732, 0.8985166855040227, 0.963289874112277, 1.026991100316126, 1.0897187581716392, 1.1515558489121325, 1.2125732532083187, 1.2728321467944699, 1.3323858209537522, 1.3912810794189336, 1.4495593273553913, 1.5072574323001684, 1.564408413392987, 1.6210419993892387, 1.6771850850517904, 1.732862107887866, 1.7880953617606197, 1.8429052599712976, 1.8973105575213471, 1.9513285401182223, 2.004975185874807, 2.058265304425163, 2.1112126572366314, 2.163830062167376, 2.2161294847466815, 2.268122118204461, 2.3198184539181157, 2.3712283436581343, 2.4223610547827845, 2.4732253193448748, 2.5238293779207734, 2.5741810188465064, 2.624287613442363, 2.6741561477217837, 2.723793251008921, 2.773205221829561, 2.8223980513899543, 2.8713774449157485, 2.9201488410873884, 2.9687174297778487, 3.017088168272582, 3.06526579612926, 3.113254848815789, 3.161059670248582, 3.2086844243388066, 3.2561331056420166, 3.3034095491957842, 3.3505174396206434, 3.397460319551444, 3.4442415974590626, 3.4908645549161292, 3.53733235335488, 3.5836480403603876, 3.6298145555380574, 3.675834735990513, 3.7217113214355413, 3.7674469589937924, 3.813044207672202, 3.8585055425667454, 3.903833358805933, 3.9490299752545837, 3.9940976379956483, 4.039038523606319, 4.083854742243279, 4.128548340550649, 4.173121304403093, 4.217575561495494, 4.261912983789674, 4.306135389827834, 4.3502445469215365, 4.394242173224472, 4.438129939696511, 4.481909471966034, 4.525582352096982, 4.56915012026658, 4.612614276359275, 4.655976281481985, 4.6992375594054385, 4.742399497935995, 4.785463450222069, 4.828430735998954, 4.871302642775626, 4.914080426966816, 4.956765314973456, 4.999358504214381, 5.04186116411198, 5.0842744370343, 5.1265994391959895, 5.168837261520257, 5.210988970463929, 5.253055608807536, 5.295038196412244], [0.0, 0.13797296614612148, 0.24022488679628623, 0.332269902974487, 0.4182558210365093, 0.49999999999999994, 0.5785155024015763, 0.654443913303929, 0.7282256812104322, 0.8001805825189799, 0.8705505632961241, 0.93952458502622, 1.007253992982465, 1.0738625146497733, 1.1394530347449108, 1.204112342640346, 1.267914553968891, 1.330923636497959, 1.3931953137010376, 1.4547785254123173, 1.515716566510398, 1.5760479871502193, 1.6358073134502662, 1.6950256309730263, 1.7537310619463105, 1.811949159194239, 1.869703234061905, 1.9270146315044916, 1.9839029624933204, 2.0403863016478, 2.096481356314738, 2.1522036120332677, 2.207567458337944, 2.2625862980882414, 2.3172726429148485, 2.3716381969016833, 2.4256939302479177, 2.4794501443544372, 2.5329165295375953, 2.586102216377183, 2.639015821545789, 2.691665488835609, 2.744058925990692, 2.7962034378630087, 2.8481059563360973, 2.899773067397644, 2.951211035689873, 3.0024258268223765, 3.0534231276945416, 3.1042083650428243, 3.1547867224009662, 3.205163155637932, 3.2553424072183534, 3.305329019313044, 3.3551273458722166, 3.4047415637611507, 3.454175683046819, 3.5034335565141874, 3.552518888482376, 3.6014352429833463, 3.650186051359235, 3.698774619328632, 3.7472041335670285, 3.795477667842105, 3.8435981887405806, 3.8915685610197355, 3.9393915526136216, 3.9870698393211073, 4.03460600920044, 4.082002566692723, 4.129261936494729, 4.17638646719963, 4.223378434722628, 4.270240045527012, 4.316973439664824, 4.363580693645161, 4.4100638231420355, 4.456424785552773, 4.502665482417024, 4.548787761705661, 4.59479341998814, 4.640684204486193, 4.686461815021153, 4.732127905861649, 4.777684087477908, 4.823131928208431, 4.868472955844402, 4.913708659136809, 4.958840489230872, 5.003869861032094, 5.048798154507899, 5.0936267159285915, 5.138356859051114, 5.182989866248785, 5.227526989590102, 5.271969451869366, 5.316318447591793, 5.3605751439155656, 5.404740681553142, 5.4488161756339615, 5.49280271653059, 5.5367013706502], [0.0, 0.14309690811052556, 0.24914618792310347, 0.34460950649911054, 0.43378870847907947, 0.518568644668324, 0.6000000000000001, 0.6787481862669054, 0.7552700090359217, 0.829897120333555, 0.9028804514474343, 0.9744159813792331, 1.0446606759553492, 1.1137428575641026, 1.1817692317817543, 1.2488298111028098, 1.3150014636137808, 1.3803505326715677, 1.4449348111684155, 1.508805056431297, 1.5720061711932456, 1.634578137257459, 1.696556762948874, 1.7579742882635063, 1.818859879812478, 1.8792400393825317, 1.9391389440389288, 1.9985787314306283, 2.0575797408272685, 2.1161607180906277, 2.174338991033087, 2.2321306202847264, 2.2895505297684093, 2.34661262008948, 2.4033298675266765, 2.4597144108218676, 2.5157776275776857, 2.571530201761122, 2.626982183560612, 2.68214304264093, 2.737021715674527, 2.791626648891967, 2.8459658362820206, 2.9000468539790574, 2.9538768912979823, 3.00746277881221, 3.0608110138157967, 3.113927783464904, 3.1668189858549467, 3.2194902492566633, 3.271946949706187, 3.324194227120022, 3.3762370000850823, 3.428079979456092, 3.4797276808771733, 3.5311844363310607, 3.582454404807743, 3.6335415821741774, 3.684449810317854, 3.7351827856292203, 3.78574406688116, 3.8361370825576904, 3.886365137678791, 3.936431420163544, 3.9863390067696565, 4.036090868643729, 4.085689876513381, 4.135138805549398, 4.184440339923495, 4.233597077084931, 4.282611531777142, 4.331486139813685, 4.380223261631082, 4.42882518563469, 4.477294131352282, 4.525632252408872, 4.573841639335146, 4.621924322220857, 4.669882273223683, 4.717717408943129, 4.765431592668367, 4.8130266365082095, 4.860504303410747, 4.907866309079661, 4.9551143237936754, 5.002249974135133, 5.049274844633242, 5.096190479327166, 5.142998383253725, 5.189700023864177, 5.236296832374194, 5.282790205050913, 5.329181504440646, 5.375472060540582, 5.421663171917647, 5.46775610677741, 5.5137521039857695, 5.559652374046003, 5.605458100033535, 5.651170438490689, 5.696790520283513, 5.742319451422653], [0.0, 0.1475773161594552, 0.25694703142468783, 0.35539933576267324, 0.4473707658880579, 0.5348051878625344, 0.6187861838865271, 0.7, 0.7789177444921346, 0.8558814535160307, 0.9311499150948377, 1.0049252443928347, 1.0773693218845504, 1.1486144877716113, 1.218770788614574, 1.2879310552267333, 1.3561745624579484, 1.423569730895957, 1.490176162946172, 1.5560462051630304, 1.6212261661978982, 1.6857572796964846, 1.749676475153355, 1.8130170020086807, 1.8758089400891171, 1.9380796209604725, 1.9998539786793306, 2.061154844031224, 2.1220031931145575, 2.182418358729787, 2.242418211228409, 2.3020193141037537, 2.361237058551284, 2.4200857804085567, 2.478578862245574, 2.5367288228719342, 2.594547396126494, 2.652045600494526, 2.7092338008389447, 2.7661217633226323, 2.8227187044279924, 2.8790333348396566, 2.935073898840633, 2.9908482097763818, 3.0463636820614597, 3.1016273601366295, 3.1566459447282145, 3.2114258167141325, 3.265973058860973, 3.320293475662357, 3.3743926114797564, 3.428275767162036, 3.481948015298573, 3.5354142142423988, 3.5886790210238346, 3.641746903261323, 3.6946221501641046, 3.7473088827109544, 3.799811063080038, 3.8521325033969216, 3.904276873860757, 3.956247710302447, 4.008048421223161, 4.059682294356702, 4.111152502795006, 4.162462110712185, 4.2136140787192184, 4.2646112688783395, 4.315456449403502, 4.366152299070899, 4.416701411361353, 4.46710629835449, 4.517369394392824, 4.5674930595323815, 4.617479582795036, 4.667331185236456, 4.7170500228424865, 4.766638189265612, 4.816097718412371, 4.865430586891587, 4.914638716332589, 4.963723975581869, 5.012688182785964, 5.0615331073677625, 5.1102604719029285, 5.158871953902596, 5.207369187508068, 5.255753765102846, 5.304027238846918, 5.352191122137887, 5.400246891003228, 5.448195985427629, 5.496039810619147, 5.543779738217587, 5.591417107448407, 5.6389532262250786, 5.686389372202773, 5.733726793785993, 5.7809667110926215, 5.828110316876675, 5.875158777411963, 5.922113233338664], [0.0, 0.1515716566510398, 0.2639015821545789, 0.3650186051359235, 0.459479341998814, 0.5492802716530588, 0.6355343046292874, 0.7189462609625462, 0.8, 0.8790468154750565, 0.956352499790037, 1.0321246385758591, 1.1065294937780734, 1.179702987529729, 1.2517581449211739, 1.3227903093325808, 1.3928809012737988, 1.4621001932101518, 1.5305094007509492, 1.598162287267028, 1.6651064148037462, 1.7313841330402582, 1.7970333710080455, 1.862088278079523, 1.9265797482245537, 1.9905358527674863, 2.053982200632252, 2.1169422405444127, 2.1794375163432784, 2.2414878840925674, 2.3031116978242654, 2.3643259693406558, 2.4251465064166373, 2.4855880329047966, 2.5456642935889393, 2.605388146113855, 2.6647716419075045, 2.723826097682443, 2.7825621588378673, 2.840989855868474, 2.8991186547107826, 2.9569575018135734, 3.014514864600337, 3.0717987678932213, 3.1288168267859735, 3.1855762763848037, 3.2420839987784773, 3.2983465475503095, 3.354370170103581, 3.4101608280368407, 3.465724215775732, 3.5210657776423573, 3.57619072352124, 3.6311040432620154, 3.6858105199425952, 3.740314742102371, 3.794621115042694, 3.8487338712811106, 3.9026570802364446, 3.956394657213585, 4.009950371749614, 4.063327855376541, 4.116530608850325, 4.1695620088908605, 4.222425314473262, 4.275123672706847, 4.327660124334751, 4.380037608884031, 4.432258969493362, 4.484326957442925, 4.536244236408922, 4.588013386463144, 4.639636907836231, 4.691117224461695, 4.7424566873162695, 4.793657577570913, 4.84472210956557, 4.895652433619704, 4.946450638689749, 4.99711875488359, 5.047658755841547, 5.098072560992471, 5.148362037693013, 5.1985290032574145, 5.248575226884725, 5.298502431489737, 5.348312295443567, 5.398006454229308, 5.447586502017842, 5.497053993168526, 5.546410443659122, 5.59565733244907, 5.6447961027799085, 5.693828163416368, 5.742754889831497, 5.791577625338867, 5.840297682174777, 5.888916342533155, 5.937434859555697, 5.985854458279608, 6.034176336545164, 6.082401665865211], [0.0, 0.15518455739153597, 0.27019200770412266, 0.3737192818846552, 0.47043160900986947, 0.5623730565710473, 0.6506830627186192, 0.7360832477580963, 0.8190690044316878, 0.9, 0.9791483623609768, 1.0567266252096805, 1.1329050135538825, 1.2078226894013284, 1.2815953719373026, 1.3543206771711513, 1.4260819663728028, 1.4969511870400218, 1.5669910139330236, 1.636256491940092, 1.7047963168076516, 1.7726538476726315, 1.8398679176525994, 1.9064734901131382, 1.972502195420671, 2.037982774014807, 2.102941445240332, 2.167402216752623, 2.2313871459154493, 2.294916562086737, 2.3580092567898685, 2.420682647324795, 2.482952918264576, 2.544835144423311, 2.606343398208985, 2.667490843744494, 2.728289819718717, 2.7887519125922595, 2.8488880215107746, 2.9087084160583934, 2.968222787804118, 3.0274402964465676, 3.0863696112409023, 3.145018948290982, 3.2033961042058743, 3.26150848654963, 3.3193631414542404, 3.376966778715908, 3.434325794652614, 3.4914462929650933, 3.548334103812776, 3.604994801290015, 3.661433719465473, 3.7176559671281186, 3.773666441366528, 3.829469840093692, 3.88507067361685, 3.940473275340918, 3.9956818116844275, 4.050700291278474, 4.10553257351179, 4.16018237647851, 4.214653284379506, 4.268948754423031, 4.3230721232659635, 4.377026613032922, 4.4308153369469725, 4.484441304602492, 4.537907426907933, 4.591216520723695, 4.644371313218046, 4.697374445962029, 4.75022847878242, 4.802935893390228, 4.855499096800671, 4.90792042455928, 4.960202143787571, 5.012346456060575, 5.064355500127623, 5.1162313544867715, 5.167976039822534, 5.21959152131576, 5.271079710833889, 5.322442469009131, 5.373681607211614, 5.42479888942397, 5.475796034023396, 5.526674715476781, 5.577436565954067, 5.628083176864722, 5.67861610032174, 5.729036850537416, 5.779346905154763, 5.829547706518187, 5.879640662886863, 5.92962714959393, 5.979508510154484, 6.029286057325158, 6.078961074117854, 6.128534814770072, 6.1780085056741205, 6.227383346267322], [0.0, 0.15848931924611134, 0.27594593229224296, 0.38167789096181765, 0.4804497735925725, 0.5743491774985174, 0.664539805948974, 0.7517586466500455, 0.8365116420730186, 0.9191661188401216, 1.0, 1.079230345298891, 1.1570310048031527, 1.233544104071174, 1.3088878266078583, 1.3831618672225916, 1.4564513624208644, 1.5288297918718774, 1.60036116503796, 1.6711016990261411, 1.7411011265922482, 1.810403730235845, 1.87904917005244, 1.9470731539765267, 2.01450798596493, 2.081383018504683, 2.1477250292995467, 2.213558537264427, 2.2789060694898216, 2.343788388261312, 2.4082246852806923, 2.4722327487612916, 2.535829107937782, 2.5990291586527943, 2.661847272995918, 2.724296895429098, 2.7863906274020755, 2.8481403021171032, 2.9095570508246347, 2.970651361806657, 3.0314331330207964, 3.091911719227754, 3.1520959743004386, 3.211994289310292, 3.2716146269005324, 3.3309645523843803, 3.390051261946053, 3.4488816082714764, 3.5074621238926214, 3.5657990424927277, 3.623898318388478, 3.681765644378398, 3.7394064681238106, 3.796826007208857, 3.854029263008983, 3.9110210334824664, 3.967805924986641, 4.024388363209259, 4.080772603295601, 4.136962739243317, 4.192962712629476, 4.248776320727584, 4.304407224066535, 4.359858953478209, 4.415134916675888, 4.470238404401549, 4.525172596176483, 4.5799405656864485, 4.634545285829697, 4.688989633453605, 4.743276393803367, 4.797408264704094, 4.851387860495835, 4.905217715739342, 4.958900288708875, 5.012437964687017, 5.065833059075191, 5.119087820332485, 5.172204432754366, 5.2251850191019376, 5.278031643091578, 5.330746311754014, 5.383330977671218, 5.435787541098841, 5.488117851981384, 5.540323711866702, 5.5924068757260175, 5.644369053685139, 5.6962119126721955, 5.747937077986809, 5.799546134795289, 5.851040629556123, 5.902422071379746, 5.953691933326282, 6.004851653644753, 6.0559026369569615, 6.106846255389083, 6.157683849653805, 6.2084167300856485, 6.2590461776319675, 6.309573444801933, 6.359999756575714], [0.0, 0.16153942662021778, 0.281256477677527, 0.38902323483289747, 0.48969597014570987, 0.585402456482446, 0.6773287924381185, 0.7662261489562102, 0.8526102053083794, 0.9368553572723312, 1.0192448764914566, 1.1, 1.1792979235873753, 1.2572835080007883, 1.3340772111720975, 1.409780646524983, 1.4844805890064676, 1.558251932392911, 1.6311599180008391, 1.7032618448285624, 1.7746084027326519, 1.8452447264239062, 1.9152112392514733, 1.9845443363446358, 2.053276943345878, 2.1214389776272204, 2.1890577322260265, 2.25615819792069, 2.322763335332784, 2.388894306315511, 2.454570671912596, 2.519810562669337, 2.584630825923485, 2.6490471538087617, 2.7130741950038453, 2.7767256527076896, 2.8400143708833805, 2.902952410461687, 2.9655511169126014, 3.0278211803638033, 3.0897726892578907, 3.151415178386779, 3.212757672015068, 3.273808722699332, 3.3345764463228758, 3.3950685537924374, 3.4552923797819113, 3.515254908856317, 3.5749627992653967, 3.6344224046588542, 3.6936397939434613, 3.7526207694749485, 3.8113708837542073, 3.8698954547771414, 3.9281995801700504, 3.9862881502273253, 4.044165859955078, 4.101837220212876, 4.159306568035744, 4.216578076209812, 4.273655762167313, 4.330543496259812, 4.387245009462629, 4.443763900558069, 4.500103642840433, 4.556267590381623, 4.612258983892423, 4.668080956211296, 4.723736537449552, 4.7792286598191405, 4.834560162166954, 4.889733794237418, 4.944752220683229, 4.999618024842451, 5.054333712298526, 5.108901714238506, 5.163324390623431, 5.2176040331837035, 5.271742868251288, 5.325743059439564, 5.379606710180875, 5.433335866131007, 5.486932517449133, 5.540398600961086, 5.593736002213324, 5.646946557424266, 5.700032055339337, 5.752994238995509, 5.8058348074007355, 5.85855541713333, 5.9111576838659285, 5.963643183818425, 6.016013455143897, 6.068269999251328, 6.120414282068665, 6.172447735249484, 6.22437175732636, 6.276187714813829, 6.32789694326364, 6.379500748274818, 6.431000406460921, 6.482397166376708], [0.0, 0.16437518295172257, 0.2861938162210511, 0.39585237323186834, 0.498292375846207, 0.5956789490835458, 0.6892190129982211, 0.7796769250220154, 0.867577416958159, 0.9533014569439311, 1.0371372893366482, 1.1193100348931466, 1.2000000000000002, 1.2793545883735817, 1.357496372533811, 1.4345287496850556, 1.5105400180718433, 1.585606386199111, 1.6597942406671102, 1.7331618863338394, 1.8057609028948687, 1.8776372173817608, 1.9488319627584663, 2.019382173055373, 2.0893213519106983, 2.1586799418832774, 2.2274857151282053, 2.295764101126424, 2.3635384635635086, 2.4308303357800485, 2.49765962220562, 2.5640447716595767, 2.6300029272275616, 2.6955500565120682, 2.7607010653431354, 2.8254698974735803, 2.889869622336831, 2.9539125125881944, 3.017610112862594, 3.0809733009483784, 3.1440123423864916, 3.2067369393480885, 3.269156274514918, 3.33127905058007, 3.3931135258977476, 3.4546675467363976, 3.5159485765270126, 3.5769637224456985, 3.637719759624956, 3.6982231532501233, 3.7584800787650634, 3.8184964403834094, 3.878277888077858, 3.937829833199483, 3.9971574628612565, 4.056265753204621, 4.115159481654537, 4.173843238256802, 4.232321436181256, 4.290598321465528, 4.348677982066174, 4.406564356277144, 4.464261240569453, 4.521772296900505, 4.579101059536819, 4.636250941429606, 4.69322524017896, 4.750027143618998, 4.806659735053353, 4.863125998167716, 4.919428821643735, 4.975571003496437, 5.0315552551553715, 5.087384205308006, 5.143060403522245, 5.198586323663599, 5.253964367121224, 5.309196865855884, 5.36428608528186, 5.419234226993845, 5.474043431349054, 5.528715779913893, 5.583253297783934, 5.637657955785175, 5.69193167256404, 5.746076316572989, 5.800093707958116, 5.853985620354667, 5.9077537825959645, 5.961399880340854, 6.014925557624421, 6.068332418336433, 6.121622027631594, 6.174795913275489, 6.227855566929809, 6.2808024453802025, 6.333637971709894, 6.386363536422004, 6.4389804985133265, 6.491490186502127, 6.5438938994123745, 6.596192907716678], [0.0, 0.16702776523348103, 0.2908122302201994, 0.40224038736253726, 0.5063335016631935, 0.6052916375537973, 0.7003411915978159, 0.7922588559417013, 0.8815778301771843, 0.9686852302633299, 1.0538739520617835, 1.1373727491851455, 1.2193648376899149, 1.3000000000000003, 1.379402786632782, 1.4576782633510283, 1.5349161533002453, 1.6111938947898092, 1.686578945724755, 1.7611305518498404, 1.8349011252209961, 1.907937334011045, 1.9802809749615793, 2.051969679734644, 2.123037492628885, 2.1935153474658144, 2.263431464569923, 2.3328116837869626, 2.4016797458308234, 2.4700575315334667, 2.537965266529508, 2.605421697353629, 2.672444243735697, 2.7390491309532323, 2.8052515053770892, 2.8710655357755104, 2.9365045024881375, 3.0015808762185934, 3.0663063879017853, 3.1306920908649003, 3.194748416307661, 3.2584852229686962, 3.321911841714041, 3.385037115675317, 3.4478694364748015, 3.5104167769990364, 3.572686721119123, 3.6346864907022605, 3.6964229702137334, 3.7579027291699343, 3.8191320426701165, 3.8801169102063615, 3.9408630729270357, 4.00137602950816, 4.06166105076904, 4.121723193152928, 4.1815673111798315, 4.241198068966794, 4.300619950900587, 4.359837271538695, 4.418854184806522, 4.477674692551703, 4.53630265251029, 4.594741785734032, 4.652995683523192, 4.7110678139050215, 4.768961527694191, 4.826680064168058, 4.8842265563866505, 4.941604036184485, 4.9988154388589185, 5.0558636075775665, 5.112751297525306, 5.1694811798096945, 5.226055845141942, 5.2824778073092284, 5.338749506452806, 5.394873312165137, 5.450851526418319, 5.506686386334985, 5.56238006681207, 5.617934683006979, 5.67335229269499, 5.72863489850604, 5.783784450048447, 5.838802845926572, 5.893691935658869, 5.948453521502387, 6.003089360189257, 6.057601164580419, 6.111990605241352, 6.166259311944377, 6.220408875101671, 6.274440847132929, 6.328356743771332, 6.382158045311209, 6.435846197800597, 6.489422614181672, 6.542888675381858, 6.596245731358201, 6.649495102097495, 6.702638078574429], [0.0, 0.16952182030724353, 0.29515463231891037, 0.4082466323576216, 0.5138940628493757, 0.6143298395415735, 0.7107986715253464, 0.8040888484979244, 0.8947415317761157, 0.9831496177263357, 1.0696103757250688, 1.1543559751290424, 1.237572367773054, 1.3194115726290119, 1.4, 1.4794442844885438, 1.5578354889842692, 1.6352522081037575, 1.7117629070320612, 1.7874277161701517, 1.8622998301896752, 1.9364266141116284, 2.009850488785669, 2.0826096477890275, 2.1547386437691007, 2.2262688724505715, 2.2972289755432227, 2.3676451787328374, 2.4375415772291475, 2.506940378588235, 2.5758621104534667, 2.6443257992823845, 2.712349124915897, 2.779948554907025, 2.847139461791914, 2.9139362259065558, 2.980352325892344, 3.046400418665186, 3.1120924103260608, 3.1774395192502056, 3.2424523323957963, 3.3071408557119413, 3.3715145593929687, 3.4355824186159567, 3.4993529503067093, 3.5628342464027427, 3.6260340040173613, 3.6889595528545334, 3.7516178801782343, 3.814015653600737, 3.876159241920945, 3.9380547342152283, 3.9997079573586616, 4.061124492133378, 4.122309688062448, 4.183268677091828, 4.244006386229115, 4.30452754923585, 4.364836717459575, 4.424938269882654, 4.484836422456818, 4.544535236785207, 4.604038628207507, 4.663350373338132, 4.722474117102567, 4.781413379312573, 4.8401715608171125, 4.898751949262366, 4.957157724491148, 5.015391963609264, 5.0734576457438685, 5.1313576565166965, 5.189094792252988, 5.246671763945221, 5.304091200989053, 5.361355654707479, 5.41846760167789, 5.475429446875452, 5.532243526645264, 5.588912111514624, 5.645437408855985, 5.701821565410236, 5.758066669679313, 5.814174754196379, 5.870147797681265, 5.925987727088251, 5.9816964195527635, 6.037275704243113, 6.092727364122919, 6.1480531376295255, 6.203254720273259, 6.258333766162168, 6.313291889456429, 6.368130665756436, 6.422851633428265, 6.47745629486997, 6.531946117721946, 6.586322536024394, 6.640586951324713, 6.6947407337374845, 6.748785222959513, 6.802721729242296], [0.0, 0.17187719275874785, 0.2992555739477689, 0.41391889843836444, 0.5210342169394704, 0.6228654698077586, 0.7206746603888587, 0.8152610310457598, 0.9071732621064218, 0.9968097089234609, 1.0844717711976986, 1.1703948440965921, 1.2547674631095278, 1.3377437593925443, 1.4194518996205303, 1.4999999999999998, 1.579480388667856, 1.6579727522511036, 1.735546507204729, 1.8122626193943627, 1.8881750225898037, 1.9633317399117873, 2.0377757816143354, 2.111545871944413, 2.184677043631296, 2.257201128618586, 2.3291471665701082, 2.40054174755694, 2.4714093015728125, 2.541772344730344, 2.6116516898883724, 2.681066627862113, 2.750035084139966, 2.8185737550786603, 2.8866982268036474, 2.954423079454385, 3.0217619789473953, 3.0887277580564834, 3.155332488308544, 3.2215875439493202, 3.2875036590344515, 3.3530909785378435, 3.418359104234732, 3.4833171360052253, 3.547973709111118, 3.612337027921038, 3.6764148964936294, 3.740214746373335, 3.8037436619066725, 3.867008403347146, 3.930015427983114, 3.9927709094938773, 4.055280755714359, 4.117550624967275, 4.179585941103113, 4.241391907372184, 4.302973519238985, 4.364335576236952, 4.425482692951023, 4.486419309206083, 4.547149699531195, 4.607677981962285, 4.668008126239605, 4.728143961450658, 4.7880891831643035, 4.8478473600973215, 4.907421940350798, 4.966816257250172, 5.026033534819676, 5.085076892919079, 5.143949352068169, 5.202653837982126, 5.261193185838932, 5.319570144298173, 5.377787379288892, 5.435847477582716, 5.493752950167129, 5.551506235432536, 5.609109702185715, 5.666565652501158, 5.723876324421022, 5.781043894513474, 5.838070480298543, 5.894958142549842, 5.951708887479961, 6.00832466881669, 6.064807389776782, 6.1211589049434005, 6.177381022053046, 6.233475503697279, 6.2894440689442135, 6.345288394884426, 6.401010118105582, 6.456610836099803, 6.512092108607554, 6.567455458901529, 6.622702375013832, 6.677834310909525, 6.732852687609407, 6.787758894264725, 6.842554289186317, 6.897240200830597], [0.0, 0.1741101126592248, 0.30314331330207955, 0.4192962712629475, 0.5278031643091576, 0.6309573444801931, 0.7300372102718469, 0.8258523872989457, 0.9189586839976279, 1.0097596309015795, 1.0985605433061176, 1.1855998744839986, 1.2710686092585746, 1.3551228811604872, 1.4378925219250922, 1.5194870523363544, 1.6, 1.6795120867813484, 1.758093630950113, 1.835806390401934, 1.9127049995800738, 1.988838105491312, 2.064249277151718, 2.1389777418892093, 2.2130589875561464, 2.2865252596366314, 2.3594059750594574, 2.431728069337104, 2.5035162898423473, 2.574793445202917, 2.6455806186651616, 2.715897351658381, 2.785761802547597, 2.8551908845980556, 2.9242003864203037, 2.992805077569759, 3.061018801501898, 3.128854557705815, 3.196324574534056, 3.263440373999379, 3.3302128296074924, 3.3966522181293937, 3.462768266080516, 3.5285701915608616, 3.59406674201609, 3.6592662284008037, 3.724176556159046, 3.78880525338119, 3.8531594964491074, 3.917246133441245, 3.9810717055349722, 4.044642466614131, 4.107964401264504, 4.171043241318159, 4.2338844810888245, 4.296493391424152, 4.358875032686557, 4.421034266761981, 4.482975768185135, 4.5447040344603025, 4.60622339564853, 4.667538023284663, 4.728651938681311, 4.789569020671063, 4.850293012833274, 4.9108275302472375, 4.971176065809591, 5.031341996150233, 5.091328587177878, 5.151138999283546, 5.210776292227709, 5.270243429734589, 5.329543283815008, 5.388678638837405, 5.447652195364886, 5.506466573774779, 5.565124317675735, 5.623627897136184, 5.681979711736947, 5.7401820934596115, 5.798237309421564, 5.856147564467572, 5.913915003627146, 5.971541714446167, 6.029029729200673, 6.0863810270000505, 6.143597535786442, 6.200681134236584, 6.257633653571947, 6.3144568792825675, 6.371152552769607, 6.427722372911343, 6.484167997556955, 6.54049104495217, 6.596693095100619, 6.65277569106439, 6.708740340207161, 6.764588515382989, 6.820321656073681, 6.875941169477453, 6.931448431551464, 6.986844788010592], [0.0, 0.17623403478323169, 0.30684127650498216, 0.4244111529515947, 0.534241692207828, 0.6386542222937697, 0.7389427365423364, 0.8359267369720242, 0.9301688121755985, 1.0220774152464698, 1.1119615859385787, 1.2000626863515946, 1.286574031081021, 1.371653658288166, 1.4554329834905735, 1.538022863486599, 1.619517966799908, 1.7, 1.7795401391501218, 1.8582008955137614, 1.9360375700049626, 2.0130994030621694, 2.0894304951880813, 2.165070552234169, 2.240055494959496, 2.3144179622020933, 2.3881877297399043, 2.4613920616644327, 2.534056007234955, 2.606202653315474, 2.6778533403411533, 2.749027848121898, 2.8197445565317074, 2.890020585156171, 2.959871915206822, 3.029313496408886, 3.0983593410904033, 3.167022607317717, 3.235315672613735, 3.3032501995451287, 3.3708371942605595, 3.438087058894571, 3.5050096386137253, 3.57161426396713, 3.6379097891081678, 3.7039046263745234, 3.7696067776466133, 3.835023862847947, 3.900163145903135, 3.965031558428479, 4.0296357213954, 4.093981964977177, 4.158076346763932, 4.2219246685088025, 4.28553249154916, 4.348905151030302, 4.4120477690446345, 4.474965266786929, 4.5376623758152785, 4.600143648497806, 4.662413467716798, 4.724476055894524, 4.7863354833985, 4.847995676378142, 4.9094604240797155, 4.970733385681888, 5.0318180966901975, 5.092717974925135, 5.1534363261353535, 5.213976349264626, 5.274341141398614, 5.334533702415209, 5.394556939360117, 5.454413670567531, 5.514106629543997, 5.573638468632117, 5.633011762469332, 5.6922290112557725, 5.751292643844092, 5.810205020663093, 5.868968436486114, 5.9275851230542225, 5.986057251563567, 6.044386935025434, 6.102576230507046, 6.160627141260412, 6.218541618746115, 6.276321564558362, 6.3339688322572, 6.391485229113373, 6.448872517770924, 6.506132417832287, 6.563266607370293, 6.620276724371216, 6.677164368112717, 6.733931100480284, 6.790578447225516, 6.847107899169417, 6.903520913353643, 6.959818914142442, 7.016003294277899, 7.072075415890906], [0.0, 0.17826024579660033, 0.31036911478307194, 0.42929072433157667, 0.5403840154082454, 0.6459970049778166, 0.7474385637693104, 0.8455376158406002, 0.9408632180197389, 1.0338285194973316, 1.1247461131420948, 1.2138601360599284, 1.3013661254372384, 1.3874239364434007, 1.4721664955161928, 1.5557059340049721, 1.6381380088633757, 1.7195453660637319, 1.8000000000000003, 1.879565140644803, 1.9582967247219536, 2.0362445588007163, 2.113453250419361, 2.1899629619384178, 2.265810027107765, 2.3410274600231027, 2.415645378802657, 2.489691361000665, 2.5631907438746055, 2.6361668797244855, 2.708641354342303, 2.7806341749518597, 2.852163932745606, 2.923247944137699, 2.9939023740800437, 3.0641423441789537, 3.1339820278660473, 3.2034347344895635, 3.2725129838801843, 3.341228572692308, 3.4095926336153037, 3.4776156883799083, 3.545307695345263, 3.612678092336356, 3.6797358353051988, 3.7464894333084295, 3.8129469802262768, 3.8791161835906, 3.9450043908413424, 4.010618613289499, 4.075965548029614, 4.141051598014704, 4.205882890480665, 4.270465293884981, 4.334804433505246, 4.398905705826383, 4.462774291830899, 4.526415169293891, 4.589833124173475, 4.653032761177594, 4.716018513579737, 4.778794652348521, 4.84136529464959, 4.903734411772377, 4.965905836529152, 5.027883270169162, 5.089670288846621, 5.15127034967764, 5.21268679641797, 5.273922864790519, 5.334981687488989, 5.395866298881692, 5.456579639437434, 5.51712455989357, 5.577503825184519, 5.637720118147595, 5.69777604302155, 5.757674128752001, 5.817416832116787, 5.877006540683206, 5.936445575608237, 5.995736194291885, 6.054880592893135, 6.113880908717146, 6.1727392224818045, 6.231457560471057, 6.290037896581964, 6.348482154271884, 6.4067922084117495, 6.4649698870509935, 6.523016973099261, 6.580935205929725, 6.638726282908482, 6.69639186085418, 6.753933557431816, 6.811352952484305, 6.868651589305228, 6.925830975855968, 6.982892585930188, 7.039837860268441, 7.0966682076255525, 7.153385005793204], [0.0, 0.18019831273171422, 0.3137434853072099, 0.43395802496644426, 0.5462591357293617, 0.6530203624849001, 0.7555648061628231, 0.8547304029835368, 0.9510923966296996, 1.045068428099846, 1.136974488810138, 1.2270573701545953, 1.315514735223545, 1.402508177151083, 1.4881720675672823, 1.5726197569270821, 1.6559480432652913, 1.7382404710912376, 1.8195698175306316, 1.9000000000000001, 1.979587563373977, 2.058382855724867, 2.136430969569487, 2.213772503918405, 2.2904441875464174, 2.366479393482464, 2.441908567292591, 2.516759586357539, 2.591058063404511, 2.6648276046225425, 2.738090030486971, 2.810865565742552, 2.883173003707428, 2.955029849061904, 3.026452442505194, 3.097456070047545, 3.1680550592158347, 3.2382628640591458, 3.308092140525272, 3.3775548135232643, 3.446662136778435, 3.5154247464150505, 3.5838527090607353, 3.651955565149652, 3.7197423680040034, 3.7872217191919213, 3.854401800591277, 3.921290403531149, 3.987894955333734, 4.054222543537849, 4.120279938049658, 4.186073611435858, 4.251609757548393, 4.316894308647328, 4.3819329511689515, 4.446731140269425, 4.511294113259523, 4.575626902033315, 4.639734344582432, 4.703621095677759, 4.767291636791868, 4.8307502853278645, 4.894001203213715, 4.957048404915191, 5.0198957649153595, 5.082547024703898, 5.145005799315402, 5.207275583452164, 5.269359757223655, 5.33126159153195, 5.392984253129778, 5.454530809375469, 5.515904232706962, 5.577107404855171, 5.6381431208152195, 5.69901409259255, 5.759722952739514, 5.820272257696731, 5.880664490952426, 5.940902066031817, 6.00098732932778, 6.060922562783049, 6.120709986433513, 6.180351760821372, 6.239849989286327, 6.2992067201423305, 6.35842394874689, 6.417503619469424, 6.4764476275646885, 6.5352578209568915, 6.593936001939686, 6.652483928796921, 6.710903317348663, 6.769195842426692, 6.827363139283455, 6.885406804938109, 6.943328399463109, 7.001129447214578, 7.058811438009439, 7.1163758282521545, 7.1738240420137, 7.231157472065275], [0.0, 0.182056420302608, 0.31697863849222263, 0.43843276548657756, 0.5518918645844859, 0.659753955386447, 0.7633557819236352, 0.8635439207617045, 0.9608995471851449, 1.0558446086806568, 1.1486983549970349, 1.239710122307718, 1.3290796118979478, 1.416970083162849, 1.503517293300091, 1.588835761573218, 1.673023284146037, 1.7561642669936848, 1.8383322376802431, 1.9195917727040783, 1.9999999999999998, 2.079607786802411, 2.1584606905977815, 2.2365997290317248, 2.314062009606305, 2.3908812494750924, 2.4670882081423477, 2.5427110504452903, 2.6177756532157166, 2.6923058660569206, 2.766323734445183, 2.8398496916718936, 2.9129027248417283, 2.9855005191337924, 3.0576595837437544, 3.1293953623029336, 3.20072233007592, 3.2716540798426745, 3.342203398052282, 3.412382332577008, 3.4822022531844965, 3.551673905672975, 3.6208074604716898, 3.6896125563906024, 3.7580983401048798, 3.826273501877372, 3.8941463079530534, 3.961724630000973, 4.02901597192986, 4.096027494361398, 4.162766037009366, 4.229238139182064, 4.295450058599093, 4.361407788690774, 4.427117074528853, 4.492583427520112, 4.557812138979643, 4.622808292687686, 4.687576776522624, 4.7521222932528255, 4.816449370561384, 4.88056237037013, 4.944465497522582, 5.008162807879513, 5.071658215875563, 5.134955501580629, 5.198058317305588, 5.2609701937882125, 5.3236945459918354, 5.386234678546306, 5.448593790858195, 5.510774981914772, 5.57278125480415, 5.634615520972095, 5.6962806042342065, 5.757779244560662, 5.819114101649269, 5.880287758301282, 5.941302723613313, 6.002161435997546, 6.062866266041592, 6.123419519218347, 6.183823438455507, 6.244080206573615, 6.304191948600876, 6.364160733972347, 6.423988578620584, 6.48367744696429, 6.543229253801065, 6.602645866109911, 6.6619291047687605, 6.721080746191934, 6.780102523892106, 6.838996129971017, 6.897763216542952, 6.9564053970946675, 7.014924247785242, 7.073321308689135, 7.1315980849854546, 7.18975604809632, 7.247796636776956, 7.305721258160065], [0.0, 0.1838416287252544, 0.32008686688809423, 0.4427319484783656, 0.557303604546244, 0.6662233691872481, 0.7708410942740636, 0.8720116577308621, 0.9703219337293861, 1.0661980072880195, 1.1599622586540013, 1.2518664689408392, 1.3421122976641735, 1.4308646051077254, 1.518260479676778, 1.6044155635876032, 1.6894286119734032, 1.7733848584772296, 1.856358551659581, 1.9384149012429017, 2.0196115953469707, 2.1, 2.1796261194159547, 2.258531373451182, 2.3367532334764034, 2.4143257472687747, 2.491279975954033, 2.567644360548092, 2.643445031625726, 2.7187060726546126, 2.793449745284513, 2.867696683171538, 2.9414660596040707, 3.014775733178504, 3.087642374976339, 3.1600815800660196, 3.2321079656536513, 3.3037352578072445, 3.374976368357218, 3.4458434633148345, 3.5163480239373786, 3.5865009013942015, 3.6563123658437213, 3.72579215061212, 3.794949492065009, 3.8637931656802, 3.932331518759791, 4.0005725001608266, 4.068523687373846, 4.136192311236139, 4.203585278530336, 4.270709192687871, 4.337570372790277, 4.404174871038239, 4.470528488838516, 4.536636791641628, 4.602505122648233, 4.668138615489092, 4.7335422059721335, 4.798720642980122, 4.863678498593695, 4.928420177506806, 4.992949925794818, 5.057271839089454, 5.121389870209509, 5.1853078362914795, 5.249029425460064, 5.312558203074737, 5.375897617585269, 5.439051006026042, 5.502021599176359, 5.564812526411534, 5.627426820267352, 5.6898674207386275, 5.752137179330726, 5.814238862881417, 5.8761751571689675, 5.937948670321058, 5.999561936037992, 6.061017416642534, 6.122317505967796, 6.183464532093673, 6.244460759941559, 6.305308393736291, 6.366009579343672, 6.4265664064912205, 6.486980910879318, 6.547255076189362, 6.607390835995068, 6.667390075582659, 6.727254633685226, 6.78698630413625, 6.846586837446879, 6.906057942311262, 6.965401287043982, 7.024618500953319, 7.083711175653851, 7.142680866321693, 7.201529092895438, 7.26025734122567, 7.318867064175758, 7.377359682676464], [0.0, 0.18556007362580842, 0.32307885324043556, 0.4468703499081746, 0.5625129553550541, 0.6724508387726091, 0.7780464696657949, 0.8801627168617118, 0.9793919402914197, 1.0761642077688864, 1.1708049129648923, 1.2635681904967386, 1.354657584876237, 1.4442394974054071, 1.5324522979124207, 1.6194127095699042, 1.705220410616759, 1.7899614314106878, 1.8737107145446625, 1.9565340792837849, 2.038489752982913, 2.119629581810095, 2.2, 2.2796428145777656, 2.3585958471747506, 2.43689346382698, 2.5145670160015765, 2.5916452105645718, 2.6681544223441955, 2.7441189599264106, 2.8195612930499663, 2.8945022482424205, 2.9689611780129352, 3.0429561078897023, 3.116503864785822, 3.1896201895433913, 3.2623198360016787, 3.334616658532017, 3.406523689657125, 3.4780532091090817, 3.549216805465304, 3.620025431325581, 3.6904894528478125, 3.7606186943396676, 3.8304224785029466, 3.8999096628435357, 3.969088672689272, 4.037967531198504, 4.106553886691757, 4.174855037595995, 4.242877955254442, 4.310629304823581, 4.378115464452053, 4.445342542913005, 4.51231639584138, 4.579042640710302, 4.645526670665568, 4.711773667324142, 4.7777886126310225, 4.843576299858774, 4.909141343825192, 4.974488190396754, 5.039621125338674, 5.104544282566262, 5.169261651846971, 5.233777085997675, 5.298094307617522, 5.362216915392902, 5.426148390007691, 5.489892099688931, 5.553451305415379, 5.6168291658139315, 5.680028741766762, 5.743053000750048, 5.805904820923375, 5.868586994987305, 5.931102233825204, 5.993453169944015, 6.055642360727606, 6.117672291515103, 6.179545378515782, 6.24126397157108, 6.302830356773558, 6.364246758951874, 6.425515344030136, 6.486638221269423, 6.547617445398665, 6.608455018641561, 6.669152892645752, 6.729712970320024, 6.790137107584876, 6.850427115041505, 6.9105847595638235, 6.970611765817859, 7.030509817712635, 7.090280559786257, 7.149925598530794, 7.209446503659246, 7.268844809317709, 7.328122015245637, 7.3872795878869235, 7.446318961454366], [0.0, 0.1872171230554857, 0.32596394386926575, 0.4508608972494537, 0.567536189899231, 0.6784558174143034, 0.7849944161374158, 0.8880225603048655, 0.9881378996154234, 1.085774342383936, 1.1812601880431084, 1.2748518406295968, 1.3667546623054787, 1.4571365403345828, 1.546137080186134, 1.6338740473694155, 1.7204480102489117, 1.8059457674324801, 1.8904429307496289, 1.9740059072307774, 2.056693444200427, 2.1385578508123393, 2.219645975958392, 2.3000000000000003, 2.379658082315277, 2.458654895828574, 2.537022071975273, 2.614788573973405, 2.6919810121781276, 2.768623912250811, 2.844739944584726, 2.9203501216880943, 2.9954739688877723, 3.0701296726797214, 3.1443342102411935, 3.2181034629798324, 3.2914523164865304, 3.3643947488520047, 3.4369439089792597, 3.5091121862582475, 3.5809112727522554, 3.652352218867667, 3.723445483332061, 3.7942009781840658, 3.8646281093771067, 3.9347358135145014, 4.004532591162172, 4.0740265371251825, 4.1432253680234785, 4.212136447458896, 4.280766809028678, 4.349123177409083, 4.4172119877055485, 4.4850394032424985, 4.552611331945634, 4.6199334414520505, 4.687011173068279, 4.753849754683067, 4.820454212730127, 4.886829383285893, 4.952979922378437, 5.018910315575773, 5.08462488691495, 5.150127807227099, 5.215423101908254, 5.280514658180898, 5.345406231886953, 5.410101453849034, 5.47460383583349, 5.538916776145592, 5.603043564884602, 5.66698738888392, 5.730751336359364, 5.794338401286642, 5.8577514875272705, 5.920993412720601, 5.9840669119581555, 6.0469746412551375, 6.109719180832822, 6.1723030382243875, 6.234728651215834, 6.296998390632654, 6.359114562982193, 6.421079412960802, 6.48289512583427, 6.544563829699353, 6.606087597633688, 6.667468449740809, 6.728708355096551, 6.789809233602654, 6.850772957752966, 6.911601354317333, 6.972296205947832, 7.0328592527117415, 7.093292193555372, 7.153596687702536, 7.21377435599126, 7.273826782152065, 7.333755514030953, 7.393562064760037, 7.453247913878535, 7.512814508406752], [0.0, 0.1888175022589804, 0.32875036590344514, 0.45471496995311944, 0.5723876324421022, 0.6842554289186316, 0.7917047464637366, 0.8956136012019356, 0.9965847516924139, 1.0950558154077703, 1.1913578981670916, 1.2857495958134313, 1.378438025996442, 1.469592511122642, 1.5593538500440307, 1.6478408149591766, 1.7351548339163179, 1.821383447499712, 1.9066029138878622, 1.9908802077752392, 2.0742745786732963, 2.1568387828876388, 2.238620069786293, 2.319660980299045, 2.4, 2.4796720982064158, 2.558709176747163, 2.6371404464251693, 2.714992745067622, 2.792290807987432, 2.8690574993701112, 2.9453140113441036, 3.0210800361436867, 3.0963739157275776, 3.1712127723982215, 3.2456126233215428, 3.3195884813342205, 3.3931544440152175, 3.4663237726676783, 3.539108962589187, 3.6115218057897374, 3.6835734471373756, 3.755274434763521, 3.8266347654374107, 3.8976639255169316, 3.9683709279977424, 4.038764346110746, 4.1088523438574445, 4.178642703821397, 4.248142852550364, 4.317359883766555, 4.386300579630456, 4.4549714302564105, 4.523378651654494, 4.591528202252848, 4.659425798136957, 4.727076927127017, 4.794486861801085, 4.861660671560098, 4.928603233820492, 4.995319244411239, 5.061813227244124, 5.1280895433191525, 5.1941523991207745, 5.260005854455123, 5.325653829773643, 5.391100113024136, 5.456348366066408, 5.521402130686271, 5.586264834238569, 5.650939794947161, 5.715430226887304, 5.779739244673662, 5.843869867875204, 5.90782502517639, 5.971607558302459, 6.035220225725188, 6.098665706164067, 6.161946601896756, 6.225065441891458, 6.288024684772983, 6.350826721633238, 6.413473878696176, 6.475968419846378, 6.538312549029835, 6.600508412534814, 6.66255810116014, 6.724463652277703, 6.786227051795495, 6.8478502360270594, 6.909335093472795, 6.970683466518239, 7.031897153054025, 7.092977908021967, 7.153927444891397, 7.214747437069593, 7.275439519249912, 7.336005288701002, 7.396446306500246, 7.456764098714389, 7.516960157530127, 7.5770359423372575], [0.0, 0.19036539387158782, 0.3314454017339986, 0.4584426407447396, 0.5770799623628854, 0.6898648307306072, 0.7981949982785914, 0.9029556789481826, 1.004754572603832, 1.10403288422675, 1.201124433981431, 1.2962899376327148, 1.3897382107431533, 1.4816399637936206, 1.5721371498795493, 1.6613495148724347, 1.749379318309245, 1.8363148184160578, 1.9222328985220836, 2.0072010823681814, 2.0912791051825463, 2.174520155757401, 2.256971870802515, 2.3386771399904953, 2.4196747643931995, 2.4999999999999996, 2.5796850101651705, 2.6587592451564994, 2.7372497628128096, 2.815181501222619, 2.8925775120078816, 2.969459161026264, 3.0458463019454056, 3.1217574270880726, 3.197209799122238, 3.272219566519645, 3.346801865189483, 3.4209709082801076, 3.494740065808421, 3.568121935506188, 3.6411284060521605, 3.7137707136779894, 3.786059492986762, 3.8580048226994132, 3.929616266941273, 4.0009029125949, 4.071873403172989, 4.142535969604045, 4.212898458271833, 4.282968356605607, 4.352752816480621, 4.422258675656282, 4.491492477451715, 4.560460488834715, 4.629168717079537, 4.697622925131099, 4.765828645797748, 4.833791194881179, 4.901515683340359, 4.969007028575899, 5.036269964912325, 5.103309053347627, 5.170128690632501, 5.236733117735389, 5.30312642774398, 5.369312573248866, 5.435295373250761, 5.501078519628731, 5.566665583203505, 5.63206001942676, 5.697265173724553, 5.762284286520544, 5.827120497962446, 5.8917768523731056, 5.956256302445803, 6.0205617132017295, 6.084695865726111, 6.148661460698094, 6.212461121728337, 6.276097398517068, 6.339572769844454, 6.402889646404142, 6.466050373490045, 6.52905723354566, 6.5919124485845275, 6.654618182489794, 6.717176543200276, 6.779589584789869, 6.841859309446676, 6.903987669357787, 6.965976568505188, 7.027827864377954, 7.0895433696055035, 7.151124853516343, 7.212574043626514, 7.273892627061587, 7.335082251915835, 7.396144528552026, 7.4570810308449715, 7.517893297371836, 7.578582832551991, 7.639151107739044], [0.0, 0.1918645191625306, 0.33405553046696207, 0.4620528712767166, 0.5816244604403988, 0.6952975083515085, 0.8044807747250744, 0.9100664445520651, 1.012667003326387, 1.112727130513411, 1.2105832751075947, 1.3064982060074317, 1.4006823831956317, 1.4933078614961455, 1.5845177118834026, 1.674432623226261, 1.7631556603543683, 1.8507757765263197, 1.9373704605266595, 2.023007767844932, 2.1077479041235665, 2.191644477015916, 2.2747454983702906, 2.3570941956149776, 2.4387296753798298, 2.51968747129473, 2.6, 2.679696943683947, 2.758805573265564, 2.83735102322053, 2.915356526702057, 2.9928436178236955, 3.0698323066004902, 3.1463412309820358, 3.2223877895796185, 3.2979882580340094, 3.37315789144951, 3.447911014902857, 3.5222611036996807, 3.5962208547787387, 3.6698022504419923, 3.743016615406288, 3.8158746680220896, 3.8883865663801442, 3.9605619499231577, 4.032409977092787, 4.103939359469287, 4.1751583927996325, 4.24607498525777, 4.316696683236372, 4.387030694931628, 4.457083911950225, 4.526862929139846, 4.59637406282059, 4.665623367573924, 4.734616651727894, 4.803359491661647, 4.871857245038758, 4.9401150630669335, 5.008137901871261, 5.075930533059015, 5.143497553545995, 5.210843394707257, 5.2779723309088205, 5.344888487471394, 5.411595848112175, 5.478098261906464, 5.54439944980683, 5.610503010754178, 5.676412427411826, 5.742131071551021, 5.807662209113725, 5.873009004976275, 5.938174527435527, 6.003161752437187, 6.067973567564454, 6.132612775803571, 6.197082099101498, 6.2613841817298, 6.325521593467563, 6.389496832615321, 6.453312328850905, 6.5169704459373925, 6.580473484292494, 6.6438236834280815, 6.707023224267858, 6.770074231350633, 6.832978774926111, 6.895738872949602, 6.9583564929816495, 7.020833553998073, 7.083171928115654, 7.145373442238246, 7.207439879627798, 7.269372981404521, 7.331174447980078, 7.392845940427467, 7.454389081791044, 7.515805458339868, 7.577096620767379, 7.638264085340233, 7.699309334998933], [0.0, 0.19331820449317627, 0.33658654363385987, 0.46555367217460797, 0.5860312103167044, 0.7005655161767013, 0.8105760231123681, 0.916961675864935, 1.0203396005006329, 1.1211578456539657, 1.2197554094669347, 1.31639705173919, 1.4112948270296084, 1.5046220937568582, 1.5965230068903544, 1.6871191697131422, 1.7765144279383365, 1.8647984087899303, 1.9520491881558577, 2.038335337156521, 2.1237175175898693, 2.208249743274289, 2.291980389825818, 2.3749530121907143, 2.4572070132950636, 2.538778195993704, 2.619699222535653, 2.7, 2.77970800592724, 2.8588485652275235, 2.937445087082931, 3.015519268762895, 3.0930912718908212, 3.170179875629042, 3.2468026104115797, 3.322975875193618, 3.398715040661648, 3.4740345404281263, 3.548947951896009, 3.623468068203986, 3.6976069624394143, 3.771376045122263, 3.844786115811908, 3.917847409563131, 3.9905696388530716, 4.062962031513455, 4.135033365128907, 4.206791998300155, 4.278245899118409, 4.349402671152521, 4.420269577212474, 4.4908535611200655, 4.561161267689663, 4.631199061097746, 4.700973041799071, 4.7704890621292, 4.83975274071741, 4.908769475820277, 4.9775444576742744, 5.046082679955184, 5.114388950422955, 5.182467900822491, 5.250323996103709, 5.317961543017895, 5.385384698141759, 5.4525974753756286, 5.5196037529577975, 5.586407280033098, 5.653011682810254, 5.719420470339415, 5.785637039938471, 5.851664682294199, 5.917506586262014, 5.983165843386104, 6.048645452159795, 6.113948322044421, 6.179077277263395, 6.244035060386849, 6.308824335720997, 6.373447692515177, 6.437907647998606, 6.50220665025787, 6.56634708096539, 6.630331257968279, 6.694161437746347, 6.757839817747337, 6.821368538606889, 6.8847496862602116, 6.947985293951906, 7.011077344149977, 7.074027770369606, 7.1368384589119005, 7.199511250522475, 7.2620479419743855, 7.324450287579656, 7.3867200006333285, 7.448858754793728, 7.5108681854024075, 7.572749890746988, 7.634505433269934, 7.69613634072608, 7.757644107291616], [0.0, 0.19472943612303362, 0.3390436406144871, 0.46895223502227934, 0.5903092646378209, 0.705679676106998, 0.8164932647152433, 0.923655537541026, 1.0277881256987516, 1.1293423485982057, 1.2286596790831472, 1.3260068097117295, 1.421597343050693, 1.5156059030429971, 1.6081776969958492, 1.699435215901756, 1.7894830635522319, 1.8784115214540555, 1.9662992354526716, 2.053215277240761, 2.139220751450138, 2.224370066202506, 2.3087119502580853, 2.3922902765162104, 2.4751447355461083, 2.557311391565076, 2.6388231452580238, 2.7197101220270716, 2.8000000000000007, 2.8797182889599506, 2.9588885689770885, 3.0375326957118953, 3.1156709779685388, 3.1933223319980844, 3.2705044162075154, 3.3472337492651296, 3.4235258140641234, 3.499395149582978, 3.574855432340304, 3.6499195488652814, 3.724599660379351, 3.798907260699794, 3.8728532282232573, 3.946447872720885, 4.019700977571339, 4.092621837969932, 4.165219295578056, 4.2375017700146005, 4.309477287538202, 4.381153507224108, 4.452537744901144, 4.523636995081319, 4.594457951086446, 4.665007023551781, 4.735290357465676, 4.805313847886006, 4.875083154458296, 4.94460371484664, 5.013880757176472, 5.082919311577632, 5.151724220906934, 5.220300150721229, 5.28865159856477, 5.356782902628323, 5.424698249831795, 5.492401683377167, 5.55989710981405, 5.627188305656199, 5.694278923583828, 5.761172498263311, 5.827872451813112, 5.89438209894217, 5.960704651784689, 6.026843224453268, 6.092800837330373, 6.158580421116533, 6.224184820652122, 6.289616798528159, 6.354879038500411, 6.419974148719855, 6.484904664791594, 6.5496730526733575, 6.614281711423883, 6.6787329758106715, 6.743029118785938, 6.807172353838894, 6.871164837231914, 6.935008670127631, 6.99870590061342, 7.062258525629396, 7.125668492805486, 7.188937702212882, 7.252068008034724, 7.315061220160592, 7.377919105709068, 7.440643390482325, 7.50323576035647, 7.565697862611122, 7.628031307201475, 7.690237667975892, 7.752318483841891, 7.814275259883211], [0.0, 0.1961009057454548, 0.34143150791917165, 0.47225504202210655, 0.59446678309216, 0.7106497425654109, 0.8222437857035593, 0.9301607970258747, 1.0350267857634294, 1.1372962499459074, 1.2373130673931283, 1.3353458089655157, 1.4316095816219423, 1.5262802391730128, 1.6195040116136943, 1.7114042526343916, 1.8020863027458605, 1.8916410793029905, 1.980147782049959, 2.067675969147903, 2.154287175585486, 2.240036192678075, 2.3249720923800967, 2.409139056585509, 2.492577055402221, 2.5753224070459977, 2.6574082439196185, 2.7388649035968946, 2.8197202591412687, 2.9000000000000004, 2.9797278723165044, 3.058925885679579, 3.1376144919272773, 3.21581274053687, 3.2935384142826134, 3.3708081481729533, 3.4476375341463252, 3.524041213578504, 3.600032959311133, 3.675625748632568, 3.7508318284151225, 3.825662773426453, 3.900129538679207, 3.9742425065557283, 4.048011529338523, 4.121445967688496, 4.194554725538416, 4.267346281806126, 4.339828719278796, 4.412009750974157, 4.483896744246047, 4.555496742868473, 4.6268164873039765, 4.697862433337595, 4.768640769236523, 4.839157431577234, 4.909418119865849, 4.97942831006366, 5.049193267117521, 5.1187180565842265, 5.188007555428589, 5.257066462066737, 5.325899305718905, 5.3945104551295175, 5.462904126706747, 5.531084392128644, 5.59905518545845, 5.666820309807719, 5.7343834435823045, 5.801748146343061, 5.8689178643102595, 5.935895935538167, 6.002685594783888, 6.069289978092559, 6.1357121271190485, 6.201954993204661, 6.26802144122584, 6.3339142532303905, 6.39963613187564, 6.46518970368164, 6.530577522111633, 6.595802070490965, 6.660865764774822, 6.725770956174357, 6.790519933650073, 6.855114926280672, 6.91955810551498, 6.983851587314009, 7.047997434189712, 7.111997657146554, 7.17585421753152, 7.239569028797907, 7.303143958187776, 7.366580828337667, 7.429881418811888, 7.493047467567353, 7.556080672353706, 7.618982692052276, 7.681755147957089, 7.744399625001044, 7.8069176729301075, 7.8693108074282465], [0.0, 0.19743504858348196, 0.3437543855174957, 0.475467957738334, 0.5985111478955378, 0.7154845405526276, 0.8278377968767289, 0.9364890052554508, 1.0420684338789408, 1.1450336728854527, 1.2457309396155172, 1.3444306321107664, 1.4413493207777173, 1.536664055821765, 1.6305220620915195, 1.7230475324955523, 1.8143465242128436, 1.9045105731407495, 1.9936194178469218, 2.081743089720922, 2.168943542395397, 2.2552759399501365, 2.340789688193184, 2.4255292696033273, 2.5095349262190556, 2.59284322334162, 2.6754875187850886, 2.7574983565203643, 2.8389037992410606, 2.919729711168703, 3.0, 3.0797368250626564, 3.158960777335712, 3.2376910358966726, 3.3159455045022073, 3.393740931334526, 3.471093014409458, 3.548016494713162, 3.624525238788725, 3.7006323122135223, 3.776350045179608, 3.851690091201819, 3.9266634798235747, 4.001280664062185, 4.07555156322867, 4.149485601667775, 4.223091743888826, 4.296378526494702, 4.369354087262593, 4.442026191684577, 4.514402257237172, 4.586489375615632, 4.658294333140217, 4.729823629516922, 4.80108349511388, 4.872079906896164, 4.942818603145624, 5.013305097078423, 5.083544689460688, 5.153542480311961, 5.223303379776745, 5.2928321182361335, 5.362133255724225, 5.431211190707535, 5.500070168279932, 5.568714287820511, 5.63714751015732, 5.705373664275803, 5.773396453607294, 5.84121946192958, 5.90884615890877, 5.976279905309079, 6.043523957894791, 6.1105814740466515, 6.177455516112967, 6.244149055514048, 6.310664976617088, 6.377006080397137, 6.44317508789864, 6.5091746435107805, 6.575007318068903, 6.640675611793281, 6.706181957075687, 6.771528721123381, 6.836718208469463, 6.901752663357837, 6.966634272010451, 7.031365164783936, 7.095947418222236, 7.160383057011378, 7.224674055842076, 7.288822341185516, 7.352829792987259, 7.416698246283874, 7.48042949274667, 7.5440252821564835, 7.607487323813345, 7.670817287884529, 7.734016806694291, 7.797087475958382, 7.860030855966228, 7.922848472713525], [0.0, 0.19873407546644578, 0.34601612268689763, 0.4785963063447307, 0.6024490610292391, 0.7201920818893416, 0.8332845681596994, 0.9426506488043291, 1.0489247388724505, 1.1525674392235408, 1.2539272451403496, 1.3532763337525067, 1.4508327003947878, 1.546774560177088, 1.6412501066161314, 1.7343843497496063, 1.8262840445613033, 1.9170413292103972, 2.0067364669056498, 2.0954399498092067, 2.183214139178577, 2.270114562046446, 2.3561909492871167, 2.4414880760525177, 2.526046449154239, 2.609902874475482, 2.693090929308557, 2.775641358588885, 2.857582409648994, 2.938940116884447, 3.019738545293004, 3.1000000000000005, 3.179745207463133, 3.258993472948939, 3.337762818012124, 3.4160701010298156, 3.4939311233031747, 3.571360722806902, 3.6483728573192145, 3.724980678382649, 3.801196597315946, 3.8770323443084194, 3.9524990214725353, 4.02760715060139, 4.102366716270257, 4.176787204831504, 4.25087763977658, 4.32464661387507, 4.398102318446794, 4.471252570077002, 4.5441048350456095, 4.616666251707789, 4.688943651034494, 4.760943575496635, 4.832672296455146, 4.904135830200632, 4.975339952770055, 5.046290213653867, 5.1169919484946655, 5.1874502908676465, 5.257670183223686, 5.32765638706749, 5.3974134924359705, 5.466945926735418, 5.536257962990363, 5.605353727551826, 5.674237207308181, 5.742912256437743, 5.811382602738626, 5.879651853568137, 5.947723501421107, 6.015600929173949, 6.083287415018877, 6.150786137110671, 6.218100177946404, 6.285232528496892, 6.352186092107065, 6.41896368818103, 6.485568055666387, 6.552001856351118, 6.618267677985415, 6.68436803723979, 6.750305382509975, 6.816082096578304, 6.88170049914059, 6.94716284920677, 7.012471347383075, 7.077628138042849, 7.142635311392688, 7.207494905440071, 7.27220890786822, 7.336779257823566, 7.401207847620801, 7.465496524370147, 7.5296470915312375, 7.593661310397621, 7.657540901515693, 7.7212875460416175, 7.7849028870395545, 7.848388530724288, 7.911746047651194, 7.974976973856279], [0.0, 0.19999999999999998, 0.34822022531844965, 0.4816449370561384, 0.6062866266041592, 0.7247796636776954, 0.8385925425258951, 0.9486552787606733, 1.0556063286183155, 1.1599092269590576, 1.2619146889603865, 1.3618966255044604, 1.460074420543694, 1.5566274244078944, 1.651704774597892, 1.7454322774580642, 1.8379173679952563, 1.9292527712833727, 2.019519261803159, 2.1087877807477464, 2.1971210866122353, 2.28457506013329, 2.3711997489679972, 2.4570402134834075, 2.5421372185171496, 2.6265278044037674, 2.7102457623209744, 2.7933220330476476, 2.8757850438501853, 2.957660994961739, 3.0389741046727097, 3.1197468201907865, 3.2000000000000006, 3.279753072340316, 3.359024173562697, 3.4378302694311564, 3.5161872619002263, 3.5941100834616457, 3.6716127808038683, 3.748708589243996, 3.8254099991601485, 3.9017288154622647, 3.9776762109826245, 4.053262774537535, 4.1284985543034365, 4.203393097060208, 4.2779554837784195, 4.352194361963098, 4.426117975112294, 4.499734189602455, 4.573050519273264, 4.646074147950803, 4.718811950118916, 4.791270509923671, 4.863456138674208, 4.935374890984556, 5.0070325796846955, 5.078434789615011, 5.149586890405835, 5.220494048332939, 5.291161237330323, 5.361593249233205, 5.431794703316763, 5.501770055189611, 5.571523605095195, 5.641059505669155, 5.710381769196111, 5.7794942744052715, 5.848400772840607, 5.917104894838083, 5.985610155139519, 6.053919958170054, 6.122037603003797, 6.189966288040189, 6.2577091154116316, 6.325269095141249, 6.392649149068114, 6.459852114555771, 6.526880747998758, 6.593737728140493, 6.660425659214986, 6.726947073923794, 6.793304436258788, 6.859500144180488, 6.925536532161033, 6.991415873600124, 7.057140383121724, 7.122712218758713, 7.188133484032182, 7.253406229931597, 7.318532456801609, 7.383514116140899, 7.448353112318093, 7.513051304209397, 7.577610506762381, 7.642032492489928, 7.706318992898216, 7.770471699852276, 7.834492266882491, 7.8983823104351405, 7.962143411069946, 8.025777114607376], [0.0, 0.20123466170855583, 0.3503698962101765, 0.4846182798606534, 0.6100294210155475, 0.7292539521671095, 0.8437694330325811, 0.9545116204971992, 1.0621229121845868, 1.1670697044986924, 1.2697048776900042, 1.3703040335770693, 1.4690879104371297, 1.5662369657849158, 1.661901257793066, 1.7562073694473386, 1.8492633989840235, 1.9411626438975167, 2.0319863773143556, 2.1218059783695447, 2.210684592985739, 2.298678446868631, 2.3858378966349374, 2.4722082808232564, 2.5578306159251385, 2.64274217093654, 2.7269769456385418, 2.810566071816994, 2.893538152228582, 2.975919548848581, 3.0577346294743704, 3.1390059798871786, 3.219754587336894, 3.3000000000000007, 3.3797604661887535, 3.4590530564020607, 3.5378937707621265, 3.616297633943568, 3.694278779349382, 3.7718505240023656, 3.8490254353875963, 3.925815391290366, 4.002231633516293, 4.078284816249716, 4.153985049697569, 4.229341939574949, 4.304364622912058, 4.37906180059764, 4.453441767019403, 4.527512437115363, 4.601281371110454, 4.674755797178733, 4.747942632242354, 4.820848501093349, 4.893479754002518, 4.9658424829608885, 5.037942536682837, 5.109785534485688, 5.181376879148161, 5.252721768839041, 5.323825208197957, 5.394692018641604, 5.465326847961371, 5.535734179271719, 5.605918339362826, 5.675883506505828, 5.74563371775442, 5.815172875782401, 5.884504755293181, 5.953633009033908, 6.022561173443988, 6.0912926739651265, 6.159830830037635, 6.228178859805663, 6.296339884552029, 6.364316932881662, 6.432112944671045, 6.499730774799648, 6.56717319667808, 6.634442905586468, 6.701542521835563, 6.768474593762072, 6.835241600568844, 6.901845955019752, 6.968290005998352, 7.034576040938742, 7.100706288136442, 7.166682918946535, 7.232508049875794, 7.2981837445750815, 7.363712015737789, 7.429094826909802, 7.4943340942160015, 7.5594316880080115, 7.624389434437631, 7.689209116960012, 7.753892477770456, 7.818441219178398, 7.882857004921974, 7.947141461426285, 8.011296179008337, 8.075322713031424], [0.0, 0.20243974584998847, 0.35246806956646337, 0.4875203932378918, 0.6136825530099643, 0.733621054560764, 0.8488223059031893, 0.9602276676578034, 1.068483384415656, 1.1740586455732411, 1.2773084445875396, 1.3785100337053997, 1.4778854730846729, 1.5756163009012814, 1.6718534739440487, 1.7667243332348854, 1.860337624351197, 1.9527872034949596, 2.0441548304929396, 2.134512311930675, 2.2239231718771575, 2.312443972743027, 2.4001253727031893, 2.4870129818039124, 2.573148062162042, 2.6585681059571344, 2.743307316576332, 2.8273970122366947, 2.9108659669811474, 2.993740700652393, 3.0760457269731982, 3.1578037669786627, 3.239035933599816, 3.319761892076462, 3.4, 3.4797674300952037, 3.5590802783002435, 3.6379536592642823, 3.716401791027523, 3.794438070361117, 3.8720751400099256, 3.949324948888788, 4.026198806124339, 4.102707429702988, 4.178860990376163, 4.2546691513823225, 4.330141104468338, 4.405285602627812, 4.480110989918992, 4.554625228678124, 4.628835924404187, 4.702750348556812, 4.77637545947981, 4.849717921637463, 4.922784123328865, 4.99558019302664, 5.06811201446991, 5.140385240627013, 5.212405306630949, 5.284177441779488, 5.355706680682307, 5.4269978736289195, 5.498055696243795, 5.56888465848831, 5.639489113063415, 5.709873263261627, 5.780041170312342, 5.849996760260334, 5.919743830413644, 5.989286055393722, 6.058626992817772, 6.1277700886405935, 6.196718682180807, 6.265476010854263, 6.3340452146354345, 6.402429340265906, 6.47063134522747, 6.538654101495904, 6.606500399090257, 6.674172949431209, 6.741674388521119, 6.809007279957283, 6.876174117789142, 6.943177329229287, 7.0100192772274506, 7.076702262915921, 7.143228527934261, 7.209600256640607, 7.2758195782163355, 7.341888568670378, 7.407809252749048, 7.47358360575683, 7.539213555293227, 7.604700982910375, 7.670047725695894, 7.735255577785076, 7.80032629180627, 7.865261580263114, 7.930063116856958, 7.9947325377526735, 8.059271442790802, 8.123681396648855], [0.0, 0.2036168004640398, 0.3545174406810487, 0.49035500521537373, 0.6172507153663745, 0.737886580797276, 0.853757652010635, 0.9658107630228504, 1.074695915914266, 1.1808850281106056, 1.2847351571234393, 1.3865251672399543, 1.4864784097524693, 1.584777478362572, 1.6815742075740039, 1.776996678813366, 1.8711542699424164, 1.9641413828755114, 2.0560402528192943, 2.146923103867596, 2.2368538294402893, 2.325889320821409, 2.41408053072999, 2.5014733344048636, 2.5881092338750777, 2.6740259393126724, 2.7592578529750966, 2.8438364751743443, 2.9277907472555653, 3.0111473432569893, 3.0939309194326357, 3.1761643289255503, 3.257868807424637, 3.339064134510198, 3.4197687745110095, 3.5, 3.579774000502684, 3.6591059785500164, 3.738010234850798, 3.8165002440696343, 3.894588722460673, 3.972287688413872, 4.049608516811035, 4.126561987956648, 4.203158331738398, 4.2794072675801536, 4.355318040672776, 4.430899454902796, 4.506159902843699, 4.581107393127504, 4.655749575474188, 4.730093763622162, 4.804146956373449, 4.877915856941832, 4.951406890770179, 5.024626221964173, 5.097579768473025, 5.170273216133388, 5.24271203168, 5.314901474815577, 5.3868466094227525, 5.458552313992302, 5.530023291334388, 5.601264077632861, 5.672279050896781, 5.743072438858056, 5.813648326359475, 5.884010662273193, 5.954163265986111, 6.024109833485196, 6.093853943072869, 6.163399060739901, 6.232748545220863, 6.301905652755062, 6.370873541573865, 6.439655276133667, 6.5082538311120794, 6.57667209518354, 6.64491287458923, 6.7129788965149695, 6.780872812289743, 6.848597200416488, 6.916154569445911, 6.983547360703253, 7.050777950877256, 7.1178486544797845, 7.1847617261840675, 7.251519363048856, 7.31812370663532, 7.384576845023026, 7.450880814730861, 7.517037602548413, 7.583049147282915, 7.648917341426494, 7.714644032748236, 7.780231025815152, 7.845680083445981, 7.910992928101446, 7.976171243214375, 8.041216674462868, 8.106130830989493, 8.170915286569336], [0.0, 0.20476725110792193, 0.35652049159320065, 0.49312554885516774, 0.6207382295661439, 0.7420556969510294, 0.8585814486631533, 0.9712676684042124, 1.0807680308164909, 1.1875571196956047, 1.2919940099556333, 1.3943591414885168, 1.4948771275386208, 1.5937315934760452, 1.6910752316812006, 1.7870368472506373, 1.8817264360394779, 1.9752389333401832, 2.067657038994663, 2.159053385168456, 2.2494922262841897, 2.339030775066046, 2.4277202721198567, 2.5156068518830947, 2.602732250874477, 2.6891343923314253, 2.7748478728868013, 2.8599043708317935, 2.9443329910323857, 3.0281605582371833, 3.1114118680099447, 3.1941099026157387, 3.2762760177267514, 3.3579301046794394, 3.4390907321274637, 3.519775270235123, 3.6000000000000005, 3.6797802098485253, 3.759130281289606, 3.8380637651207454, 3.9165934494439076, 3.9947314205538818, 4.072489117601433, 4.149877381800598, 4.226906500838722, 4.303586249055167, 4.379925923876836, 4.4559343789328985, 4.53162005421553, 4.606991003606137, 4.682054920046205, 4.756819158597333, 4.831290757605314, 4.905476458157607, 4.97938272200133, 5.0530157480698366, 5.126381487749211, 5.199485659001518, 5.272333759448972, 5.344931078512014, 5.417282708684606, 5.489393556021374, 5.561268349903719, 5.632911652145283, 5.704327865491211, 5.775521241560429, 5.846495888275398, 5.917255776819706, 5.9878047481600865, 6.058146519166119, 6.128284688357907, 6.198222741309339, 6.267964055732095, 6.337511906263484, 6.406869468979128, 6.476039825649832, 6.5450259677603695, 6.61383080030641, 6.682457145384616, 6.750907745589615, 6.8191852672306075, 6.8872923033792715, 6.955231376759817, 7.023004942491163, 7.090615390690525, 7.1580650489469395, 7.225356184672712, 7.292491007340146, 7.3594716706103975, 7.426300274360844, 7.492978866616859, 7.559509445393548, 7.6258939604525535, 7.6921343149787305, 7.7582323671812, 7.824189931822919, 7.890008781682685, 7.95569064895326, 8.021237226578998, 8.086650169536204, 8.15193109605923, 8.217081588815109], [0.0, 0.2058924136478517, 0.3584795133590718, 0.4958351930587798, 0.624149084569721, 0.7461331715873947, 0.8632992132387264, 0.9766046253190532, 1.0867066743058615, 1.194082551755071, 1.2990933056386602, 1.402020916819889, 1.503091232756148, 1.602488887808901, 1.700367413378204, 1.796856322323538, 1.892066214909251, 1.9860925480817022, 2.079018476104901, 2.170917030246251, 2.261852817995919, 2.351883366452645, 2.4410601977810056, 2.529429699919658, 2.617033838722661, 2.7039107458094214, 2.7900952079156363, 2.875619077399522, 2.9605116190535385, 3.0447998050238954, 3.1285085671219166, 3.2116610138964576, 3.294278618365628, 3.3763813811655243, 3.4579879729815204, 3.539115859424126, 3.6197814109523425, 3.7, 3.779786087100046, 3.859153297509397, 3.9381144895985467, 4.016681816074496, 4.0948667789442705, 4.1726802789926065, 4.250132660436004, 4.3272337513222245, 4.40399290016601, 4.480419009245771, 4.556520564930062, 4.632305665355047, 4.70778204573367, 4.782957101542385, 4.857837909801549, 4.932431248639789, 5.006743615310469, 5.080781242809066, 5.154550115223557, 5.228055981935274, 5.301304370774963, 5.374300600227567, 5.447049790769469, 5.519556875413262, 5.591826609527525, 5.6638635799923165, 5.735672213745151, 5.807256785766898, 5.878621426552385, 5.949770129106204, 6.02070675550057, 6.091435043028654, 6.161958609983839, 6.232280961092671, 6.302405492626802, 6.37233549721714, 6.442074168391319, 6.511624604853974, 6.580989814527597, 6.650172718370332, 6.719176153985801, 6.788002879038742, 6.856655574489287, 6.925136847657618, 6.993449235129903, 7.0615952055155375, 7.12957716206504, 7.197397445157167, 7.265058334663284, 7.3325620521963835, 7.399910763251638, 7.467106579244906, 7.534151559455127, 7.601047712876172, 7.667796999983302, 7.734401334419066, 7.800862584603137, 7.867182575270299, 7.933363088940478, 7.999405867324552, 8.065312612669327, 8.131084989044933, 8.196724623577651, 8.262233107631019], [0.0, 0.2069935054081614, 0.36039662546342843, 0.4984868694167167, 0.6274869706144198, 0.7501234161659722, 0.8679160499328884, 0.9818274078731414, 1.0925182714587234, 1.20046838421763, 1.3060407249698003, 1.4095187825835713, 1.511129612325646, 1.6110588359633389, 1.7094608059670735, 1.806465727817976, 1.902184793259399, 1.9967139697317757, 2.090136856199692, 2.1825268744943664, 2.2739489776202757, 2.364461000325254, 2.4541147403091905, 2.5429568335887387, 2.6310294704470896, 2.7183709864276873, 2.8050163543021656, 2.890997596771923, 2.9763441351345645, 3.0610830857806035, 3.1452395138541647, 3.2288366514862794, 3.3118960865305827, 3.3944379265845455, 3.4764809421824747, 3.5580426923391952, 3.6391396350612633, 3.7197872249927273, 3.8, 3.8797916582064906, 3.959175126747954, 4.038162623322838, 4.116765711449734, 4.194995350209672, 4.272861939138974, 4.350375358844802, 4.42754500783681, 4.50437983600189, 4.580888375092835, 4.657078766553822, 4.732958786964928, 4.808535871352867, 4.883817134585182, 4.958809391039248, 5.033519172715078, 5.107952745941578, 5.182116126809022, 5.256015095445849, 5.329655209245085, 5.403041815134392, 5.476180060973941, 5.549074906157575, 5.621731131485103, 5.694153348366755, 5.766346007414856, 5.838313406472442, 5.910059698123807, 5.981588896727726, 6.0529048850103875, 6.124011420251625, 6.194912140095089, 6.2656105680102465, 6.3361101184316695, 6.4064141015989176, 6.4765257281182915, 6.546448113265981, 6.616184281050544, 6.685737168051113, 6.755109627046528, 6.824304430449234, 6.89332427355687, 6.962171777633301, 7.030849492830101, 7.099359900958538, 7.16770541812147, 7.235888397213762, 7.303911130299304, 7.371775850872044, 7.439484736008007, 7.507039908414688, 7.574443438383843, 7.6416973456532356, 7.708803601182554, 7.7757641288483095, 7.842580807062297, 7.909255470317795, 7.975789910667468, 8.042185879136685, 8.108445087075697, 8.174569207453912, 8.240559876099317, 8.306418692885899], [0.0, 0.20807165492618435, 0.3622737928038931, 0.5010832957004431, 0.6307553087857051, 0.754030520391307, 0.8724366906605981, 0.9869413690309702, 1.0982087787308326, 1.2067211620876115, 1.312843388538244, 1.4168604235354951, 1.5190005049895803, 1.6194502215001725, 1.7183647295003182, 1.8158749126613918, 1.9120925418817496, 2.007114084459294, 2.1010235747934476, 2.193894817141496, 2.2857931028231215, 2.376776567825104, 2.4668972796416204, 2.5562021171983895, 2.6447334905315523, 2.7325299348596466, 2.819626605114016, 2.9060556907899895, 2.991846766429388, 3.0770270896615703, 3.1616218561853504, 3.2456544191389916, 3.32914647881895, 3.4121182475554357, 3.4945885936512453, 3.576575167579355, 3.6580945130697446, 3.739162165263756, 3.819792737749953, 3.9000000000000004, 3.9797969464821277, 4.059195858532072, 4.1382083598983455, 4.216845466743613, 4.295117632771378, 4.373034790053085, 4.450606386051606, 4.527841417270354, 4.604748459900735, 4.681335697792578, 4.757610948031173, 4.8335816843694275, 4.909255058733491, 4.984637920994207, 5.059736837174265, 5.1345581062414665, 5.209107775621583, 5.283391655549521, 5.357415332364628, 5.431184180844652, 5.504703375662989, 5.577977902045055, 5.651012565692007, 5.723812002033134, 5.7963806848622905, 5.868722934408322, 5.940842924884737, 6.0127446915595595, 6.084432137382604, 6.15590903920393, 6.227179053614274, 6.2982457224354995, 6.369112477886654, 6.4397826474490625, 6.510259458451836, 6.580546042397442, 6.6506454390453325, 6.7205606002701535, 6.790294393709768, 6.859849606217057, 6.929228947128423, 6.998435051360887, 7.06747048234878, 7.136337734830171, 7.205039237492469, 7.273577355485863, 7.3419543928127196, 7.4101725946004, 7.478234149264477, 7.546141190568815, 7.613895799588523, 7.681500006581401, 7.748955792773107, 7.816265092060886, 7.883429792640455, 7.950451738560265, 8.017332731207091, 8.08407453072672, 8.150678857383168, 8.217147392859696, 8.283481781504692, 8.349683631525268], [0.0, 0.20912791051825463, 0.36411284060521604, 0.5036269964912325, 0.6339572769844454, 0.7578582832551989, 0.8768655309731552, 0.99195148124666, 1.1037837291689718, 1.2128469651239586, 1.3195079107728942, 1.4240529781680489, 1.5267115638472706, 1.6276712036091765, 1.7270878415234092, 1.8250930256796172, 1.92179909437029, 2.01730300460022, 2.1116892173613135, 2.2050319115710173, 2.2973967099940698, 2.388842043738954, 2.479420244615436, 2.5691784295255564, 2.658159223795896, 2.7464013582652944, 2.833940166325698, 2.920808000879288, 3.0070345866001826, 3.092647319488453, 3.177671523146437, 3.2621306692623415, 3.3460465682920746, 3.4294395351717815, 3.5123285339873695, 3.5947313048127305, 3.6766644753604867, 3.7581436596346185, 3.839183545408157, 3.9197979720521547, 4.0, 4.079801972932441, 4.159215573604822, 4.23825187410229, 4.316921381195563, 4.3952340773752825, 4.4731994580634495, 4.550826565433355, 4.628124019212611, 4.705100044795565, 4.781762498950185, 4.858118893369158, 4.934176416284696, 5.009941952340348, 5.085422100890581, 5.160623192879295, 5.235551306431433, 5.310212281276997, 5.384611732113843, 5.458755061004259, 5.532647468890367, 5.606293966304599, 5.679699383343787, 5.752868378968529, 5.8258054496834575, 5.898514937648644, 5.971001038267585, 6.043267807292953, 6.11531916748751, 6.187158914874126, 6.258790724605868, 6.330218156484315, 6.40144466015184, 6.472473579981408, 6.54330815968535, 6.6139515466629035, 6.6844067961045655, 6.754676874869886, 6.824764665154016, 6.894672967957023, 6.964404506368994, 7.03396192868285, 7.103347811345951, 7.172564661760659, 7.2416149209433796, 7.310500966050759, 7.379225112781206, 7.4477896176592555, 7.51619668020976, 7.584448445028429, 7.652547003754746, 7.72049439695292, 7.788292615906108, 7.855943604328796, 7.923449260001947, 7.990811436335141, 8.05803194385972, 8.125112551656684, 8.192054988722797, 8.258860945278226, 8.325532074018732, 8.392069991315337], [0.0, 0.21016324782757845, 0.3659154675608827, 0.5061203213571382, 0.6370958328077823, 0.7616102403894224, 0.881206661706144, 0.9968623722655995, 1.1092482722488564, 1.2188514516144568, 1.3260404475662164, 1.4311030901071837, 1.5342699114571616, 1.6357293758552072, 1.7356381994090566, 1.834128581468369, 1.9313134164829886, 2.02729014146635, 2.122143635554528, 2.215948444905289, 2.3087705171644286, 2.4006685727174877, 2.491695202455265, 2.581897756543198, 2.6713190713346533, 2.759998069414672, 2.8479702591015363, 2.93526815346814, 3.02192162434765, 3.107958203370531, 3.19340333950962, 3.2782806206552806, 3.3626119652412556, 3.446417788777598, 3.52971714923642, 3.612527874518055, 3.6948666746545586, 3.7767492409507426, 3.8581903338949393, 3.9392038613732896, 4.019802948477954, 4.1000000000000005, 4.179806756533023, 4.259234344977151, 4.338293324119362, 4.416993725870985, 4.495345092663361, 4.5733565114352, 4.651036644588124, 4.7283937582382425, 4.805435748050316, 4.88217016290545, 4.958604226622902, 5.034744857930283, 5.110598688853727, 5.186172081679976, 5.261471144625171, 5.3365017463302795, 5.411269529290053, 5.485779922310969, 5.5600381520836475, 5.6340492539463485, 5.707818081908444, 5.78134931799582, 5.8546474809741245, 5.927716934500319, 6.000561894748241, 6.073186437549529, 6.14559450508751, 6.217789912178168, 6.2897763521692855, 6.361557402486082, 6.4331365298492065, 6.504517095188731, 6.575702358275757, 6.6466954820914665, 6.717499536951802, 6.788117504404456, 6.858552280913568, 6.928806681346223, 6.998883442273808, 7.0687852251002505, 7.138514619028219, 7.20807414387357, 7.277466252737537, 7.346693334545443, 7.4157577164601145, 7.484661666177543, 7.553407394111852, 7.621997055476079, 7.690432752264866, 7.7587165351447185, 7.826850405257113, 7.894836315939355, 7.962676174367823, 8.03037184312784, 8.097925141714212, 8.165337847966194, 8.232611699440358, 8.29974839472471, 8.366749594697069, 8.433616923730687], [0.0, 0.21117857649667537, 0.3676832574505088, 0.5085654609217306, 0.6401737337761886, 0.7652896882459743, 0.8854638969567312, 1.0016783567736787, 1.114607209092488, 1.2247398970728647, 1.3324467383744965, 1.4380169535482887, 1.541682188548127, 1.6436318181107263, 1.7440233154617242, 1.8429895186247205, 1.9406438674587725, 2.0370842697094433, 2.132396014576039, 2.226654008359461, 2.3199245173080025, 2.4122665454937735, 2.5037329378816784, 2.5943712733925666, 2.684224595328347, 2.773332014314629, 2.861729210215451, 2.9494488531790073, 3.0365209593535565, 3.122973193378803, 3.208831127175207, 3.294118462589599, 3.3788572239468064, 3.4630679253871275, 3.546769716954459, 3.629980512678268, 3.7127171033191626, 3.794995255988887, 3.8768298024858034, 3.958234717887036, 4.039223190693941, 4.119807685626903, 4.2, 4.279811314469007, 4.3592522388319095, 4.438332853465632, 4.517062746902364, 4.595451049981117, 4.673506466952808, 4.751237303868337, 4.828651494537549, 4.905756624311273, 4.982559951908067, 5.059068429480904, 5.135288721096184, 5.211227219777765, 5.286890063251452, 5.362283148510456, 5.437412145309226, 5.51228250868158, 5.586899490569026, 5.661268150636263, 5.735393366343075, 5.8092798423348855, 5.882932119208141, 5.956354581701257, 6.029551466357007, 6.102526868697955, 6.175284749952678, 6.247828943367082, 6.320163160132039, 6.392290994955823, 6.464215931307303, 6.535941346353684, 6.60747051561449, 6.678806617351715, 6.7499527367144365, 6.82091186965463, 6.891686926629668, 6.962280736105658, 7.032696047874757, 7.102935536198513, 7.173001802788403, 7.242897379633875, 7.312624731687443, 7.382186259415671, 7.45158430122424, 7.520821135764707, 7.589898984130019, 7.658820011945358, 7.727586331360401, 7.796200002948717, 7.864663037519582, 7.9329773978471545, 8.001145000321653, 8.069167716526815, 8.137047374747691, 8.204785761412525, 8.272384622472279, 8.339845664721075, 8.407170557060672, 8.474360931711901], [0.0, 0.21217474608418974, 0.36941768944160697, 0.5109644611131087, 0.6431935552698873, 0.7688997055389974, 0.8896407988926345, 1.0064034644623605, 1.1198650236972743, 1.2305172285537345, 1.3387321435503965, 1.444800353546619, 1.5489545972143937, 1.6513851426071562, 1.7522502057817577, 1.8516832513840689, 1.9497982543905792, 2.046693584396345, 2.142454932926078, 2.2371575596279754, 2.3308680433408506, 2.4236456664702666, 2.5155435232608965, 2.606609417072427, 2.696886594250223, 2.7864143499121687, 2.87522853223102, 2.963361965466287, 3.050844807358118, 3.1377048530455953, 3.2239677950768004, 3.309657447104693, 3.3947959373470367, 3.479403876713239, 3.563500505581603, 3.6471038224854864, 3.7302306973907147, 3.8128969717855035, 3.895117547432633, 3.97690646533233, 4.058276976198625, 4.139241603550363, 4.219812200351802, 4.3, 4.379815662341381, 4.459269315303929, 4.538370592650766, 4.617128668292812, 4.695552287540595, 4.773649795626241, 4.851429163784884, 4.9288980131489, 5.006063636677607, 5.082933019318606, 5.159512856573971, 5.235809571624669, 5.31182933114933, 5.387578059958403, 5.463061454551651, 5.538284995695325, 5.613253960105343, 5.6879734313138055, 5.762448309788405, 5.836683322367271, 5.910683031065713, 5.984451841305789, 6.0579940096148555, 6.1313136508348345, 6.204414744880175, 6.277301143078933, 6.349976574128376, 6.4224446496937, 6.494708869675962, 6.566772627173108, 6.638639213155913, 6.710311820878837, 6.781793550044194, 6.853087410736435, 6.924196327142115, 6.995123141069756, 7.065870615282809, 7.1364414366578215, 7.2068382191790405, 7.27706350677979, 7.347119776040236, 7.4170094387504, 7.4867348443466675, 7.556298282229429, 7.625701983968952, 7.694948125406084, 7.764038828653914, 7.83297616400613, 7.901762151757379, 7.970398763940598, 8.038887925985984, 8.107231518305891, 8.175431377809739, 8.243489299352696, 8.311407037121704, 8.37918630596216, 8.446828782648351, 8.514336107100606], [0.0, 0.21315255132709482, 0.37112014725161685, 0.5133192358364695, 0.6461577064808712, 0.7724431723144726, 0.8937406998163491, 1.0110414649887693, 1.1250259107101082, 1.236188055170807, 1.3449016775452185, 1.4514587018501839, 1.5560929393315899, 1.6589955348913357, 1.7603254337234238, 1.8602167155442402, 1.9587838805828395, 2.0561257517695952, 2.152328415537773, 2.247467478368922, 2.3416098259297846, 2.434815013828309, 2.5271363809934773, 2.6186219510862903, 2.709315169752474, 2.7992555132010786, 2.888478994810814, 2.977018590111468, 3.0649045958248413, 3.1521649351836425, 3.238825419139809, 3.3249099710912877, 3.410440821233518, 3.495438675461081, 3.5799228628213755, 3.6639114647938245, 3.747421429089325, 3.8304686702014377, 3.9130681585675697, 3.9952339998957607, 4.076979505965826, 4.1583172580111265, 4.23925916362019, 4.319816507959073, 4.4, 4.479819814345411, 4.559285629155531, 4.63840666061916, 4.717191694349501, 4.795649114037603, 4.87378692765396, 4.95161279145286, 5.029134032003154, 5.106357666442506, 5.1832904211291435, 5.259938748845204, 5.336308844688391, 5.412406660773589, 5.488237919852822, 5.5638081279503995, 5.6391225860999326, 5.714186401260929, 5.789004496484841, 5.863581620393385, 5.9379223560258705, 6.012031129106704, 6.085912215779404, 6.159569749849101, 6.233007729571644, 6.306230024023893, 6.379240379086783, 6.452042423069832, 6.5246396720033575, 6.597035534622366, 6.669233317064035, 6.741236227298909, 6.813047379314251, 6.884669797066455, 6.9561064182181624, 7.0273600976743404, 7.098433610930609, 7.16932965724596, 7.240050862651162, 7.310599782803229, 7.380978905695624, 7.45119065423308, 7.521237388679335, 7.591121408985461, 7.660844957005893, 7.730410218608821, 7.799819325687072, 7.869074358075261, 7.938177345378544, 8.007130268717951, 8.075935062397008, 8.14459361549393, 8.213107773383514, 8.2814793391925, 8.34971007519199, 8.417801704130222, 8.485755910508884, 8.55357434180586], [0.0, 0.21411273683383236, 0.3727919273191351, 0.5156315782762436, 0.6490684446398417, 0.7759227869576797, 0.8977667218433067, 1.0155958902365496, 1.1300938001979068, 1.2417566953150931, 1.3509600385206133, 1.4579970688576045, 1.5631026508184112, 1.6664687903528688, 1.768255148653314, 1.8685964094232759, 1.9676075886794906, 2.065387954518693, 2.162023981166576, 2.257591615688218, 2.352158045049347, 2.4457830931372793, 2.538520339156171, 2.6304180230985805, 2.721519786319265, 2.8118652828552366, 2.901490688314201, 2.990429126770383, 3.078711031422829, 3.166364451289668, 3.253415313593096, 3.3398876494984764, 3.4258037893413182, 3.5111845322897763, 3.596049294462555, 3.6804162387904813, 3.764302389328584, 3.847723732260233, 3.9306953054599707, 4.013231278177633, 4.095345022158439, 4.177049175310262, 4.258355698861591, 4.339275928814622, 4.4198206223821455, 4.5, 4.579823783425494, 4.659301230363469, 4.738441166003568, 4.817252011802742, 4.895741811804884, 4.973918256753311, 5.051788706220774, 5.129360208954943, 5.2066395216141865, 5.283633126048402, 5.36034724526227, 5.436787858183089, 5.512960713342088, 5.5888713415664935, 5.664525067769412, 5.739927021915607, 5.815082149233333, 5.889995219735362, 5.964670837106163, 6.039113447006641, 6.113327344843005, 6.1873166830418835, 6.261085477870014, 6.334637615833239, 6.407976859686512, 6.481106854083752, 6.55403113089389, 6.626753114207216, 6.6992761250540225, 6.771603385855757, 6.843738024627217, 6.915683078946777, 6.987441499710326, 7.0590161546832855, 7.1304098318640134, 7.20162524267082, 7.272665024963919, 7.34353174591276, 7.4142279047184365, 7.484755935200107, 7.555118208253763, 7.625317034191033, 7.695354664965206, 7.765233296291122, 7.834955069665118, 7.9045220742908135, 7.9739363489161, 8.04319988358634, 8.112314621318484, 8.18128245970046, 8.2501052524199, 8.318784810726063, 8.387322904828528, 8.45572126523598, 8.523981584038259, 8.592105516134618], [0.0, 0.2150560012811139, 0.3744342461109714, 0.5179031710029347, 0.6519278877385316, 0.779341081401979, 0.9017217944989074, 1.0200700542224543, 1.135072379798462, 1.2472272009944148, 1.3569116348286068, 1.4644202121961598, 1.5699888322748314, 1.6738103468884058, 1.776045120609731, 1.8768284304855951, 1.9762757992308468, 2.074486932263548, 2.171548684767872, 2.2675373383904236, 2.362520376086217, 2.4565578852941288, 2.549703681259193, 2.6420062164931806, 2.7335093246109574, 2.8242528343436897, 2.9142730806691652, 3.0036033335882935, 3.092274160372268, 3.1803137336079623, 3.267748094738831, 3.3546013807985045, 3.4408960204978234, 3.5266529046347816, 3.6118915348649603, 3.696630154135195, 3.7808858614992578, 3.8646747135669606, 3.948011814461555, 4.030911395854898, 4.113386888400854, 4.19545098568306, 4.277115701624679, 4.358392422168177, 4.4392919519167835, 4.519824556332027, 4.6000000000000005, 4.679827581409963, 4.759316164630554, 4.838474208219088, 4.917309791657148, 4.9958306395692915, 5.074044143950546, 5.151957384601541, 5.22957714794681, 5.3069099443917604, 5.383962024356255, 5.460739393107497, 5.537247824501623, 5.613492873731681, 5.689479889169452, 5.7652140233795395, 5.840700243376188, 5.915943340186256, 5.990947937775544, 6.065718501390128, 6.140259345359442, 6.214574640403453, 6.288668420482387, 6.362544589223921, 6.436206925959665, 6.509659091399902, 6.582904632973061, 6.655946989854114, 6.72878949770401, 6.8014353931404345, 6.87388781795852, 6.946149823118562, 7.018224372516494, 7.090114346551555, 7.16182254550451, 7.233351692738705, 7.304704437735334, 7.3758833589734, 7.446890966664122, 7.517729705348742, 7.5884019563681315, 7.658910040211898, 7.729256218754214, 7.799442697383046, 7.869471627029003, 7.9393451060996, 8.009065182324344, 8.078633854515655, 8.148053074250365, 8.217324747476141, 8.286450736046957, 8.355432859191453, 8.42427289491779, 8.492972581358336, 8.561533618057355, 8.629957667204694], [0.0, 0.2159830011764466, 0.37604824667308606, 0.5201355950341274, 0.6547380259355499, 0.7827004347638213, 0.9056086704946488, 1.024467070943044, 1.1399651145791705, 1.2526033796543472, 1.362760608751532, 1.4707326023426428, 1.5767562764499412, 1.6810253141858964, 1.7837007713755948, 1.8849185081781648, 1.9847945452696554, 2.0834290178487977, 2.1809091554894415, 2.2773115686505836, 2.3727040311728307, 2.467146889502245, 2.5606941908547243, 2.653394596596817, 2.745292129288391, 2.8364267893425428, 2.926835068359152, 3.0165503797496216, 3.1056034225455105, 3.194022490771758, 3.281833738123583, 3.369061405677411, 3.4557280188231463, 3.541854558408664, 3.6274606101515228, 3.712564495634866, 3.797183387618016, 3.881333411922876, 3.9650297377790915, 4.048286658204208, 4.131117661744985, 4.21353549670081, 4.295552228780919, 4.377179293006938, 4.458427540555386, 4.539307281137113, 4.6198283214285025, 4.7, 4.77983121912885, 4.85933047383302, 4.938505878420735, 5.017365190813583, 5.09591583486982, 5.17416492090759, 5.252119264604341, 5.329785404428612, 5.40716961774273, 5.484277935699632, 5.561116157043687, 5.637689860913628, 5.71400441873542, 5.790065005283817, 5.865876608983404, 5.941444041512782, 6.016771946769378, 6.091864809246732, 6.166726961871214, 6.241362593340701, 6.315775755003821, 6.3899703673148585, 6.463950225896247, 6.537719007237782, 6.611280274059097, 6.684637480359745, 6.757793976179055, 6.830753012086169, 6.903517743418944, 6.976091234288851, 7.048476461367713, 7.120676317470742, 7.192693614949327, 7.264531088905884, 7.336191400242209, 7.40767713855185, 7.478990824866301, 7.550134914264015, 7.621111798350641, 7.691923807618269, 7.76257321369089, 7.833062231462806, 7.903393021136223, 7.97356769016385, 8.04358829510194, 8.11345684337881, 8.183175294983567, 8.252745564079477, 8.32216952054604, 8.391448991453696, 8.460585762474714, 8.529581579233689, 8.598438148600783, 8.667157139930715], [0.0, 0.21689435423953968, 0.3776350045179607, 0.5223303379776745, 0.6575007318068903, 0.7860030855966226, 0.9094299399062388, 1.0287898704136338, 1.1447752648842044, 1.2578888137888424, 1.3685108578372631, 1.476938445648991, 1.583409492927473, 1.6881185000425407, 1.7912272024038711, 1.8928720334405795, 1.9931695033848278, 2.0922201699617475, 2.1901116308155406, 2.2869208196675723, 2.3827157963341827, 2.4775571618968373, 2.571499191626862, 2.664590752220322, 2.756876051992884, 2.8483952601417557, 2.9391850222452836, 3.0292788927047383, 3.1187077000880614, 3.2074998578085046, 3.295681629918353, 3.38327735978069, 3.4703096678326357, 3.5567996234519956, 3.6427668949994234, 3.728229881367067, 3.8132058277757244, 3.8977109280911586, 3.981760415550478, 4.065368643481462, 4.148549157346593, 4.231314759237461, 4.313677565775277, 4.395649060232418, 4.477240139572585, 4.558461157009064, 4.63932196059809, 4.719831928314758, 4.8, 4.8798347065170145, 4.9593441964128315, 5.038536260344046, 5.117418353494326, 5.195997616184223, 5.274280892850339, 5.352274749550669, 5.429985490135243, 5.507419171205803, 5.584581615974864, 5.661478427122665, 5.738114998740222, 5.814496527437557, 5.890628022688206, 5.966514316473936, 6.042160072287373, 6.117569793544642, 6.192747831455153, 6.2676983923912415, 6.342425544796442, 6.416933225667628, 6.4912252466430855, 6.565305299725775, 6.63917696266844, 6.712843704044987, 6.786308888030435, 6.859575778909894, 6.932647545335357, 7.005527264347495, 7.078217925178373, 7.150722432849609, 7.223043611579475, 7.295184208011312, 7.36714689427475, 7.4389342708902815, 7.5105488695270415, 7.581993155622831, 7.65326953087482, 7.724380335608751, 7.795327851033863, 7.86611430139034, 7.936741855995485, 8.00721263119453, 8.077528692221492, 8.147692054975144, 8.217704687714889, 8.287568512680915, 8.357285407642792, 8.426857207380388, 8.496285705100727, 8.565572653794167, 8.63471976753311, 8.703728722716216], [0.0, 0.21779064244827795, 0.3791955329279463, 0.524488801367084, 0.6602177695795953, 0.7892511429290606, 0.9131880429452478, 1.0330412131161864, 1.1495059024112548, 1.2630868786054932, 1.3741660541180072, 1.4830417050837914, 1.5899527303625414, 1.6950944340720178, 1.798629219972815, 1.9006940852877636, 2.001406021712675, 2.100866002514632, 2.1991619873239103, 2.29637122778065, 2.392562064949687, 2.4877953503387125, 2.582125583504678, 2.6756018330790265, 2.768268490062642, 2.860165889646807, 2.9513308288430395, 3.0417970007118855, 3.131595361216405, 3.220754441184651, 3.309300613201749, 3.3972583212266185, 3.484650279172448, 3.5714976434835544, 3.6578201637975787, 3.7436363150377407, 3.8289634136885087, 3.9138177205347287, 3.9982145317629145, 4.0821682600141385, 4.165692506725776, 4.2488001268924265, 4.331503287205689, 4.4138135183910965, 4.495741762442661, 4.5772984153569976, 4.658493365886178, 4.739336030758581, 4.819835386757888, 4.8999999999999995, 4.9798380527047765, 5.059357367722705, 5.13856543104505, 5.217469412498823, 5.296076184804385, 5.374392341153132, 5.452424211444942, 5.5301778773096935, 5.607659186023583, 5.684873763419211, 5.761827025877983, 5.838524191484249, 5.914970290412556, 5.991170174612215, 6.067128526847141, 6.1428498691432525, 6.218338570690776, 6.2935988552443405, 6.368634808059807, 6.4434503824031815, 6.518049405663863, 6.5924355851015415, 6.666612513253563, 6.740583673027277, 6.814352442499722, 6.887922099445253, 6.961295825609909, 7.034476710749841, 7.107467756449733, 7.180271879735834, 7.252891916497135, 7.325330624727134, 7.397590687597691, 7.469674716375619, 7.541585253191852, 7.613324773672297, 7.684895689438834, 7.756300350488298, 7.827541047456737, 7.898620013775722, 7.969539427726983, 8.040301414401279, 8.11090804756694, 8.181361351453187, 8.251663302453, 8.321815830749982, 8.391820821873344, 8.46168011818495, 8.531395520302016, 8.600968788458916, 8.670401643811235, 8.739695769685136], [0.0, 0.21867241478865557, 0.38073078774317565, 0.5266123072839791, 0.6628908034679973, 0.7924465962305566, 0.9168852814894792, 1.0372237030430083, 1.1541599247257708, 1.2682007579738996, 1.3797296614612147, 1.4890461189579087, 1.5963899965571828, 1.7019573891075983, 1.8059113578963655, 1.9083894548090878, 2.009509145207664, 2.1093718111712048, 2.2080657684535, 2.3056685814645985, 2.402248867962862, 2.497867725826423, 2.5925798752654297, 2.686434583576253, 2.7794764214863066, 2.871745887492587, 2.963279927587241, 3.0541123712444294, 3.1442742997590987, 3.233794359472506, 3.3226990297448697, 3.411012853501745, 3.49875863661849, 3.5859576211958455, 3.6726296368321156, 3.7587932332502274, 3.844465797044167, 3.9296636548340724, 4.014402164736364, 4.098695797744795, 4.182558210365093, 4.266002309638071, 4.349040311514802, 4.431683793405444, 4.51394374160503, 4.595830594200607, 4.6773542799809915, 4.758524253800214, 4.8393495287864, 4.919838705737215, 5.0, 5.079841266097739, 5.159370020330342, 5.238593461553411, 5.317518490312999, 5.396151726494454, 5.47449952562562, 5.552567993959163, 5.630363002445239, 5.707890199693841, 5.785155024015763, 5.8621627146218955, 5.938918322052528, 6.015426717901136, 6.091692603890811, 6.16772052035587, 6.243514854176144, 6.319079846207048, 6.394419598244476, 6.469538079560088, 6.54443913303929, 6.619126480951413, 6.693603730378966, 6.767874378330595, 6.841941816560216, 6.915809336112957, 6.989480131616843, 7.062957305337567, 7.1362438710123755, 7.209342757477727, 7.282256812104321, 7.354988804051985, 7.427541427355979, 7.499917303855392, 7.572118985973524, 7.644148959359385, 7.716009645398827, 7.787703403603154, 7.859232533882547, 7.930599278711104, 8.0018058251898, 8.072854307013282, 8.143746806345979, 8.214485355612636, 8.28507193920809, 8.355508495130707, 8.425796916543666, 8.495939053268033, 8.565936713211213, 8.635791663734263, 8.705505632961241, 8.775080311033618], [0.0, 0.21954018974274897, 0.3822416716933762, 0.5287021043496951, 0.6655214052158416, 0.7955913244274352, 0.9205238295149465, 1.0413397994978932, 1.1587400683925582, 1.273233458854784, 1.3852049512676265, 1.494955217866294, 1.6027250766234842, 1.7087114005663788, 1.813077898071128, 1.9159626668813095, 2.017483638505862, 2.1177425973463797, 2.2168282096270095, 2.314818347562754, 2.411781901213225, 2.507780210916073, 2.6028682140319646, 2.6970953733685588, 2.7905064365267958, 2.8831420627170448, 2.9750393445471404, 3.0662322457394096, 3.1567519709311465, 3.2466272801431395, 3.335884757815737, 3.4245490442701154, 3.512643035883984, 3.6001880590547843, 3.6872040220721756, 3.77370954827141, 3.8597220932430636, 3.945258048397485, 4.030332832797917, 4.114960974864498, 4.199156185297141, 4.282931422356684, 4.366298950471721, 4.449270392995958, 4.531856779822206, 4.614068590459797, 4.695915793098738, 4.777407880113504, 4.858553900399724, 4.939362488886288, 5.019841893522146, 5.1000000000000005, 5.17984435444729, 5.259382184287402, 5.3386204174503655, 5.4175657000917425, 5.49622441296052, 5.574602686541286, 5.652706415082348, 5.7305412696095255, 5.808112710014888, 5.8854259963005, 5.9624861990491045, 6.039298209186509, 6.11586674709402, 6.19219637112372, 6.268291485564244, 6.344156348100323, 6.419795076805333, 6.495211656702508, 6.570409945927276, 6.645393681520344, 6.720166484878488, 6.794731866887814, 6.869093232761997, 6.94325388660628, 7.0172170357261825, 7.09098579469836, 7.164563189219714, 7.237952159749431, 7.31115556495766, 7.384176184993299, 7.457016724582563, 7.529679815968992, 7.602168021704864, 7.674483837303192, 7.7466296937587975, 7.818607959946423, 7.890420944903163, 7.962070900002102, 8.03356002102346, 8.104890450129192, 8.176064277746544, 8.247083544365694, 8.317950242256307, 8.38866631710746, 8.459233669595124, 8.529654156881149, 8.599929594047408, 8.670061755468513, 8.740052376126373, 8.809903152869579], [0.0, 0.22039445754429599, 0.38372903832506117, 0.5307593731572211, 0.6681110609339241, 0.7986871040769149, 0.9241057425534331, 1.0453918277949574, 1.1632489208807975, 1.278187824381326, 1.390595016703017, 1.500772340047314, 1.6089615494501486, 1.7153602840047624, 1.8201328891041304, 1.923417999853376, 2.025334006652774, 2.1259830899641434, 2.225454261026822, 2.3238256950696967, 2.4211665502151893, 2.5175384054865195, 2.612996412014863, 2.7075902250759842, 2.8013647663912633, 2.8943608533828953, 2.986615722992291, 3.078163471100332, 3.1690354237668052, 3.2592604529225766, 3.3488652464525224, 3.437874540557454, 3.5263113207087367, 3.6141969962884106, 3.701551553052639, 3.7883936868032038, 3.8747409210533195, 3.960609710995069, 4.046015535689864, 4.130972980090368, 4.215495808247134, 4.299597028843772, 4.383288954031831, 4.46658325239344, 4.54949099674058, 4.632022707360115, 4.714188391229955, 4.7959975776610015, 4.8774593507596595, 4.958582379054777, 5.03937494258946, 5.119844957740972, 5.2, 5.2798473249130495, 5.359393887367894, 5.438646359381401, 5.517611146531127, 5.596294403156407, 5.67470204644106, 5.752839769477819, 5.830713053404113, 5.908327178689558, 5.985687235647391, 6.0627981342348285, 6.1396646132009804, 6.2162912486352395, 6.292682461964071, 6.368842527439572, 6.444775579159236, 6.52048561765269, 6.595976516068019, 6.671252025987381, 6.74631578289902, 6.8211713113504855, 6.895822029805714, 6.970271255226779, 7.044522207399361, 7.118578013019463, 7.192441709557476, 7.266116248914413, 7.3396045008839845, 7.412909256433119, 7.486033230812576, 7.558979066508394, 7.631749336044178, 7.704346544643398, 7.7767731327602885, 7.849031478487278, 7.921123899846316, 7.993052656970958, 8.064819954185573, 8.136427941987629, 8.207878718938574, 8.279174333468479, 8.350316785599265, 8.42130802859101, 8.49214997051554, 8.56284447576123, 8.633393366472742, 8.703798423929081, 8.774061389863258, 8.84418396772659], [0.0, 0.22123568222761164, 0.38519369556889926, 0.5327852312054493, 0.6706611773112421, 0.8017356167921694, 0.9276329662835192, 1.0493819889772134, 1.1676889313782872, 1.283066545741944, 1.3959027856259774, 1.5065006453348073, 1.6151028026603444, 1.7219076510654525, 1.8270801632338407, 1.930759503427644, 2.0330645139320347, 2.134097765221937, 2.233948608284123, 2.332695516734894, 2.430407912666647, 2.5271476101438766, 2.622969970804382, 2.7179248394533913, 2.8120573092742234, 2.905408353485292, 2.998015351157871, 3.0899125283135778, 3.181131330580789, 3.2717007400917852, 3.361647546596561, 3.450996580711654, 3.539770915641787, 3.627992042486576, 3.7156800232859135, 3.8028536252016796, 3.889530438632672, 3.975726981578877, 4.061458792183811, 4.146740511069515, 4.231585954822614, 4.316008181779626, 4.4000195510864115, 4.483631775862968, 4.566855971185146, 4.649702697494743, 4.732181999965356, 4.8143034442803545, 4.896076149219317, 4.977508816398042, 5.058609757463771, 5.139386919009827, 5.219847905441824, 5.300000000000001, 5.379850184118272, 5.459405155279963, 5.538671343512109, 5.6176549266445726, 5.696361844446501, 5.77479781174062, 5.85296833058534, 5.930878701605326, 6.008534034543057, 6.085939258096591, 6.16309912910239, 6.2400182411163465, 6.316701032441088, 6.393151793643128, 6.469374674599416, 6.545373691109218, 6.621152731104059, 6.696715560485531, 6.772065828618187, 6.847207073502441, 6.922142726650183, 6.996876117684011, 7.071410478679226, 7.145748948266129, 7.219894575508848, 7.29385032357552, 7.3676190732135876, 7.441203626042833, 7.514606707677869, 7.587830970690853, 7.6608789974244695, 7.733753302664384, 7.806456336179817, 7.8789904851401475, 7.951358076414994, 8.023561378764628, 8.095602604927114, 8.167483913608164, 8.239207411379239, 8.310775154489068, 8.382189150593467, 8.453451360407925, 8.52456369928719, 8.595528038735837, 8.66634620785348, 8.73701999471809, 8.807551147710713, 8.877941376784577], [0.0, 0.22206430349229198, 0.3866364089863525, 0.5347807373898009, 0.6731730872677196, 0.8047384559998254, 0.9311073443492157, 1.053312368661375, 1.1720624206334085, 1.2878721729947298, 1.4011310323534025, 1.5121431278557542, 1.621152046224736, 1.728356923990697, 1.8339233517298699, 1.9379910149334496, 2.0406792010012653, 2.142090864578081, 2.242315691307931, 2.341432448724022, 2.439510818933869, 2.5366128475218006, 2.6327941034783797, 2.7281046182987265, 2.8225896540592164, 2.9162903374403073, 3.0092441875137155, 3.1014855584919943, 3.1930460137807084, 3.2839546440624896, 3.3742383394262845, 3.4639220234897987, 3.553028855876672, 3.641580408179785, 3.72959681757986, 3.8170969215297412, 3.904098376311715, 3.990617761792669, 4.076670674313042, 4.1622718093302025, 4.247435035179738, 4.332173459107167, 4.416499486548577, 4.500424874494563, 4.583960779651635, 4.667117802014916, 4.749906024381429, 4.832335048262077, 4.914414026590126, 4.99615169357261, 5.077556391987407, 5.158636098191195, 5.239398445071306, 5.319850743146793, 5.3999999999999995, 5.479852938199159, 5.55941601185448, 5.638695421934409, 5.717697130455047, 5.796426873643549, 5.874890174165861, 5.9530923524997315, 6.031038537525788, 6.1087336764021485, 6.186182543781641, 6.263389750424969, 6.340359751258082, 6.41709685291748, 6.4936052208231585, 6.569888885815253, 6.645951750387235, 6.721797594545593, 6.797430081323294, 6.872852761972063, 6.948069080856253, 7.023082380069307, 7.097895903792018, 7.172512802410184, 7.24693613640797, 7.321168880051831, 7.395213924878828, 7.469074083001995, 7.542752090244525, 7.616250609113583, 7.689572231623814, 7.762719481979827, 7.835694819126261, 7.9085006391734565, 7.981139277706143, 8.053613011982058, 8.12592406302691, 8.198074597631672, 8.270066730257811, 8.341902524855579, 8.413583996600309, 8.4851131135512, 8.556491798236816, 8.62772192917131, 8.69880534230504, 8.769743832413097, 8.840539154424947, 8.911193024698319], [0.0, 0.22288073840335182, 0.388057904729788, 0.5367468960965402, 0.6756480551080614, 0.8076971331010888, 0.9345306254885786, 1.0571849451020823, 1.1763715899285072, 1.2926071249274789, 1.406282388387635, 1.5177026276073364, 1.6271123248731227, 1.7347113488546961, 1.8406658989335996, 1.945116174164487, 2.048181900515638, 2.1499664111517545, 2.2505597214524005, 2.3500408885451165, 2.448479850728549, 2.545938881701948, 2.642473754759149, 2.7381346853395554, 2.8329671019287264, 2.9270122824122304, 3.02030788380327, 3.112888386620058, 3.2047854703132237, 3.2960283325193234, 3.3866439621905924, 3.4766573745781573, 3.56609181445363, 3.654968932719357, 3.7433089405918127, 3.8311307447810505, 3.9184520664839115, 4.00528954652432, 4.091658838583751, 4.177574692148446, 4.263051026541897, 4.3481009971993245, 4.43273705516627, 4.516971000658722, 4.600814031401602, 4.6842767863616555, 4.7673693854060115, 4.850101465346199, 4.932482212766883, 5.014520393987015, 5.096224382457283, 5.177602183859993, 5.258661459145323, 5.339409545709959, 5.419853476900109, 5.499999999999999, 5.579855592848823, 5.659426479213322, 5.738718643029364, 5.817737841613744, 5.896489617936876, 5.974979312037616, 6.053212071653277, 6.1311928621305505, 6.20892647567661, 6.28641754000394, 6.363670526417339, 6.440689757386955, 6.517479413647241, 6.594043540857998, 6.670386055860487, 6.7465107525586525, 6.822421307452862, 6.8981212848512605, 6.97361414178165, 7.048903232624914, 7.123991813489299, 7.198883046343219, 7.273580002922923, 7.348085668429963, 7.422402945032338, 7.496534655182011, 7.570483544760622, 7.644252286064227, 7.717843480637198, 7.7912596619645536, 7.864503298031416, 7.937576793757593, 8.010482493314754, 8.083222682333133, 8.155799590004197, 8.228215391085277, 8.3004722078118, 8.37257211172228, 8.444517125400983, 8.516309224142812, 8.587950337544646, 8.659442351027119, 8.730787107290597, 8.80198640770878, 8.87304201366326, 8.943955647822072], [0.0, 0.22368538294402893, 0.38945887224606723, 0.5386846609422752, 0.6780872812289742, 0.810613083098949, 0.9379044700445586, 1.0610015965572785, 1.1806185292756417, 1.2972736980632469, 1.411359352213996, 1.5231818410307298, 1.6329865294304864, 1.7409740076492863, 1.847311075082052, 1.952138436930378, 2.055576251397503, 2.157728224701751, 2.2586846971964114, 2.358525011421243, 2.457319358166294, 2.5551302359514643, 2.6520136194234585, 2.748019905309573, 2.8431946861013855, 2.9375793887059807, 3.031211806085994, 3.124126543241282, 3.2163553939916985, 3.307927661383171, 3.398870431803512, 3.489208810813963, 3.5789661271044633, 3.6681641097414945, 3.7568230429081106, 3.844961901571412, 3.932598470905343, 4.019749451810569, 4.106430554481521, 4.192656581653068, 4.278441502900276, 4.3637985211521455, 4.448740132405011, 4.533278179476028, 4.61742390051617, 4.701187972901002, 4.784580553032421, 4.867611312512795, 4.9502894710922165, 5.032623826737823, 5.114622783130152, 5.196294374853641, 5.277646290516048, 5.358685894003545, 5.439420244054143, 5.519856112311127, 5.6000000000000005, 5.679858153356563, 5.759436577919901, 5.838741051791886, 5.917777137954177, 5.996550195724248, 6.07506539142379, 6.153327708325396, 6.231341955937077, 6.309112778678297, 6.386644663996167, 6.463941949965828, 6.54100883241503, 6.617849371609223, 6.694467498530258, 6.770867020778841, 6.847051628128246, 6.923024897754495, 6.998790299165956, 7.074351198853509, 7.149710864680608, 7.224872470031013, 7.299839097730561, 7.374613743757987, 7.449199320758702, 7.523598661374294, 7.597814521399588, 7.67184958277817, 7.745706456446514, 7.81938768503603, 7.892895745441769, 7.9662330512657835, 8.039401955142678, 8.112404750954273, 8.185243675939864, 8.257920912708101, 8.330438591156112, 8.402798790301075, 8.475003540029201, 8.547054822766608, 8.618954575076403, 8.69070468918598, 8.762307014448217, 8.833763358740141, 8.905075489802288, 8.976245136521872], [0.0, 0.22447861343640918, 0.3908399667499978, 0.5405949381951426, 0.6804919064256981, 0.8134876697463803, 0.9412304559216297, 1.0647641080266308, 1.1848052249146899, 1.3018740748993325, 1.4163642982643256, 1.5285833306848295, 1.638777407188085, 1.7471478293408649, 1.8538619880401574, 1.9590610874547003, 2.0628657118913485, 2.165379935330207, 2.266694418488469, 2.3668887852694827, 2.4660334753730564, 2.5641912089506103, 2.6614181591454877, 2.7577649014012704, 2.8532771898890985, 2.947996598423669, 3.041961053988581, 3.1352052842995373, 3.2277611959232635, 3.319658195819808, 3.410923466430414, 3.5015822023453715, 3.5916578149825473, 3.681172110463786, 3.7701454449036724, 3.858596860558115, 3.9465442056706346, 4.034004240366436, 4.120992730551254, 4.207524531453249, 4.293613662186226, 4.379273372499262, 4.464516202701847, 4.549354037607993, 4.633798155221276, 4.717859270781246, 4.801547576706313, 4.8848727788961686, 4.967844129795874, 5.050470458571817, 5.132760198705566, 5.214721413273713, 5.296361818149261, 5.377688803332114, 5.458709452591894, 5.539430561585411, 5.619858654592737, 5.7, 5.779860624643058, 5.859446327114023, 5.938762690121931, 6.017815091989409, 6.096608717358892, 6.175148567174601, 6.253439467999966, 6.331486080724439, 6.409292908708461, 6.486864305410805, 6.564204481538417, 6.641317511755213, 6.718207340983047, 6.79487779032509, 6.871332562639252, 6.947575247786891, 7.023609327579908, 7.099438180447391, 7.175065085841256, 7.2504932283986765, 7.325725701877772, 7.400765512881582, 7.475615584384308, 7.550278759072616, 7.6247578025139005, 7.699055406162424, 7.773174190213531, 7.847116706315286, 7.920885440146271, 7.994482813867628, 8.067911188456847, 8.141172865930285, 8.21427009146091, 8.287205055397317, 8.35997989518964, 8.432596697227655, 8.505057498595926, 8.577364288750626, 8.649519011122283, 8.721523564648482, 8.793379805240258, 8.865089547185711, 8.936654564494114, 9.008076592183643], [0.0, 0.22526078784323253, 0.3922018114909096, 0.5424785899098494, 0.6828630158383433, 0.8163221902639539, 0.9445100840442131, 1.0684741774263533, 1.18893356618432, 1.3064103314571607, 1.421299485130822, 1.533909534110873, 1.6444875714071185, 1.7532356000025209, 1.8603215940517497, 1.965887249736056, 2.070053571526859, 2.172924996040161, 2.2745924998918152, 2.3751359844270965, 2.4746261347862566, 2.5731258896631264, 2.6706916179310314, 2.767374071258883, 2.8632191632438846, 2.958268612560742, 3.052560478346025, 3.146129609320866, 3.2390080232273886, 3.3312252294914018, 3.422808505268784, 3.5137831329379807, 3.6041726054917214, 3.69399880503321, 3.783282158605981, 3.8720417748168736, 3.9602955640999182, 4.048060344979382, 4.135351938295806, 4.222185251038977, 4.308574351170972, 4.394532534608361, 4.48007238535615, 4.565205829639859, 4.6499441847601934, 4.734298203292939, 4.818278113171019, 4.901893654113411, 4.985154110804443, 5.068068343174892, 5.150644814091995, 5.232891614727366, 5.314816487839238, 5.396426849177264, 5.477729807193789, 5.558732181224445, 5.639440518282538, 5.719861108595792, 5.800000000000002, 5.8798630112919215, 5.959455744633009, 6.0387835970861445, 6.117851771359158, 6.196665285821584, 6.2752289838545545, 6.353547542587949, 6.43162548107374, 6.509467167939915, 6.587076828565227, 6.6644585518113715, 6.741616296345907, 6.8185538965862795, 6.895275068292651, 6.971783413834914, 7.048082427157009, 7.124175498459842, 7.200065918622267, 7.275756883378023, 7.351251497265136, 7.426552777362868, 7.501663656830246, 7.576586988259009, 7.651325546852907, 7.72588203344432, 7.800259077358414, 7.874459239134229, 7.9484850131114575, 8.022338829891034, 8.096023058677046, 8.169540009507013, 8.242891935376994, 8.316081034267638, 8.389109451076834, 8.461979279464174, 8.534692563612253, 8.607251299909317, 8.679657438557593, 8.75191288511133, 8.824019501948314, 8.895979109678356, 8.967793488492095, 9.039464379453216], [0.0, 0.22603224696268157, 0.39354499983290214, 0.5443364368049916, 0.6852016425738122, 0.8191178796696308, 0.9477447833663809, 1.0721334212564202, 1.1930053518281234, 1.310884444211514, 1.426167063104648, 1.5391627719683343, 1.650119510041132, 1.7592399721132406, 1.866692707606755, 1.9726198979751843, 2.0771429620985273, 2.1803666942608055, 2.2823823826489202, 2.383270202249299, 2.4831010802802607, 2.5819381709841545, 2.6798380362829146, 2.776851601656607, 2.873024937944464, 2.968399906696711, 3.0630146973924783, 3.1569042781006282, 3.2501007762156555, 3.3426338022254116, 3.43453072670288, 3.5258169186120223, 3.6165159514029055, 3.7066497821191997, 3.7962389077617047, 3.8853025023792265, 3.973858537744335, 4.061923889980334, 4.14951443410999, 4.236645128175622, 4.32333008831839, 4.4095826559898885, 4.49541545829204, 4.58084046229456, 4.665869024056941, 4.75051193297972, 4.834779452023808, 4.918681354264166, 5.002226956182731, 5.085425148053219, 5.168284421725968, 5.250812896082731, 5.3330183403986595, 5.414908195820402, 5.496489595144892, 5.577769381062194, 5.6587541230074185, 5.739450132750671, 5.819863478839995, 5.9, 5.979865317578078, 6.059464847120631, 6.138803809153401, 6.217887239232522, 6.296719997326436, 6.375306776582964, 6.4536521115306495, 6.531760385758882, 6.60963583911723, 6.687282574470668, 6.764704564044153, 6.841905655387003, 6.918889576984887, 6.995659943544867, 7.072220260976727, 7.148573931091922, 7.2247242560397, 7.300674442498353, 7.376427605638136, 7.451986772871014, 7.527354887401315, 7.602534811590156, 7.677529330145633, 7.75234115314977, 7.826972918932479, 7.9014271968019765, 7.975706489640414, 8.049813236372895, 8.123749814317414, 8.19751854142276, 8.27112167840091, 8.344561430760026, 8.417839950743705, 8.490959339181776, 8.563921647257626, 8.636728878196603, 8.709382988879865, 8.781885891387688, 8.85423945447601, 8.926445504989756, 8.99850582921625, 9.070422174181862], [0.0, 0.22679331552660542, 0.3948700971669639, 0.546169260907824, 0.6875087710349914, 0.8218759147586127, 0.950935915476668, 1.075743379809746, 1.1970222957910757, 1.3152982964597326, 1.4309690811052553, 1.5443452555132613, 1.6556755937534577, 1.7651634731055335, 1.8729780105109017, 1.979261866159341, 2.0841368677578815, 2.1877081624412393, 2.2900673457709058, 2.391294862688868, 2.4914618792310343, 2.590631762285114, 2.688861264221533, 2.786201481990502, 2.882698641555435, 2.9783947454177286, 3.07332811164353, 3.1675338260419705, 3.261044124183039, 3.353888716255457, 3.446095064991105, 3.537688624773265, 3.628693048425687, 3.719130366923154, 3.809021146281499, 3.8983846251100758, 3.987238835693844, 4.075600710979356, 4.163486179441844, 4.250910249488547, 4.337887084790794, 4.424430071721909, 4.510551879900273, 4.5962645166896765, 4.681579376386368, 4.766507284719655, 4.8510585392066545, 4.935242945829049, 5.019069852438111, 5.1025481792418175, 5.18568644668324, 5.268492800981055, 5.350975037570177, 5.433140622652194, 5.514996713040729, 5.596550174465731, 5.677807598482121, 5.758775318112236, 5.839459422337407, 5.919865769541689, 6.0, 6.079867547493319, 6.159473650125313, 6.238823360407233, 6.317921554671424, 6.396772941867908, 6.475382071793344, 6.5537533427970205, 6.6318910090044145, 6.709799187095173, 6.787481862669053, 6.864942896230375, 6.9421860288189166, 7.019214887312746, 7.096032989426325, 7.172643748425276, 7.249050477577452, 7.325256394358281, 7.401264624427044, 7.477078205389246, 7.552700090359216, 7.628133151335871, 7.703380182403638, 7.778443902769603, 7.853326959647148, 7.9280319309955525, 8.00256132812437, 8.076917598170763, 8.15110312645734, 8.225120238737611, 8.29897120333555, 8.37265823318544, 8.446183487777652, 8.51954907501568, 8.592757052989406, 8.665809431669196, 8.738708174525186, 8.811455200075777, 8.884052383369154, 8.956501557401378, 9.028804514474343, 9.100963007496798], [0.0, 0.22754430321145303, 0.396177642671109, 0.5479778079888158, 0.6897853399853291, 0.8245974177668624, 0.9540847788368779, 1.0793055219673207, 1.2009860325552735, 1.3196536841846696, 1.435707493058943, 1.5494590934822081, 1.6611580832974042, 1.7710085132336653, 1.8791800602345368, 1.9858158568848736, 2.0910381343035414, 2.1949523878021986, 2.297650516245539, 2.3992132309553615, 2.499711933621858, 2.599210200961464, 2.6977649732704765, 2.7954275166980085, 2.8922442102769303, 2.988257195592814, 3.0835049175955973, 3.1780225782751317, 3.271842519944041, 3.364994551171309, 3.457506225627005, 3.5494030819822937, 3.640708851383249, 3.7314456377564973, 3.821634075218754, 3.911293466084772, 4.000441902350369, 4.089096373032687, 4.177272859351408, 4.264986419411571, 4.352251263785105, 4.439080823172045, 4.525487809144069, 4.611484268825321, 4.697081634242333, 4.782290766971983, 4.867121998629874, 4.951585167668537, 5.035689652893072, 5.119444404049213, 5.202857969794041, 5.285938523321054, 5.368693885878432, 5.4511315483908245, 5.533258691370433, 5.615082203281909, 5.696608697506991, 5.777844528038749, 5.858795804021144, 5.939468403237281, 6.01986798463889, 6.1, 6.17986970476937, 6.259482168188787, 6.338842282737745, 6.417954772959157, 6.496824203715567, 6.575454987920649, 6.653851393786697, 6.732017551625049, 6.809957460233096, 6.887674992898569, 6.965173903049065, 7.042457829572446, 7.119530301831489, 7.196394744394268, 7.27305448149996, 7.349512741278121, 7.425772659738124, 7.5018372845439885, 7.577709578588784, 7.653392423381563, 7.728888622258893, 7.804200903432053, 7.879331922880224, 7.954284267099161, 8.029060455714196, 8.10366294396577, 8.178094125075084, 8.252356332496989, 8.326451842066627, 8.400382874046041, 8.474151595076389, 8.54776012004113, 8.621210513845156, 8.694504793114522, 8.767644927821054, 8.840632842836005, 8.913470419416468, 8.986159496628153, 9.058701872707863, 9.131099306368807], [0.0, 0.2282855055701629, 0.39746815093289156, 0.5497627898058493, 0.6920322453737954, 0.8272834597481766, 0.9571926126894614, 1.0828212496184206, 1.2048981220584782, 1.3239523214592264, 1.4403841637786834, 1.5545062984379228, 1.6665691363193988, 1.7767773928266832, 1.8853012976086583, 1.992284449489975, 2.097849477744901, 2.2021022213253127, 2.3051348784470815, 2.4070284233409054, 2.507854490280699, 2.607676863077567, 2.706552667505013, 2.804533336706403, 2.9016654007895757, 2.9979911386120195, 3.093549120354176, 3.1883746626727874, 3.2825002132322627, 3.3759556776999577, 3.468768699499213, 3.560964900490809, 3.6525680891226067, 3.74360044132252, 3.8340826584207943, 3.9240341056075043, 4.0134729338112995, 4.10241618738931, 4.190879899618413, 4.278879177653889, 4.366428278357154, 4.453540676177379, 4.540229124092892, 4.626505708470112, 4.7123818985742325, 4.797868591362612, 4.882976152105036, 4.9677144513017915, 5.052092898308478, 5.136120472023718, 5.219805748950964, 5.303156928907065, 5.386181858617115, 5.468888053406687, 5.55128271717777, 5.633372760833485, 5.715164819297988, 5.796665267261833, 5.877880233768894, 5.958815615748557, 6.039477090586008, 6.119870127813873, 6.2, 6.279871792898716, 6.359490414926266, 6.438860606015281, 6.517986945897877, 6.5968738618623455, 6.675525636024247, 6.753946412148987, 6.832140202059631, 6.910110891660751, 6.987862246606349, 7.065397917637595, 7.142721445613805, 7.219836266258234, 7.296745714638429, 7.37345302939925, 7.449961356765297, 7.526273754328048, 7.602393194631892, 7.678322568572106, 7.754064688616839, 7.829622291864239, 7.90499804294507, 7.980194536780331, 8.05521430120278, 8.130059799450548, 8.204733432540515, 8.27923754152852, 8.353574409663008, 8.427746264438298, 8.50175527955316, 8.57560357678007, 8.649293227750142, 8.722826255658378, 8.796204636893588, 8.869430302597099, 8.942505140154005, 9.015430994620585, 9.088209670091219, 9.16084293100794], [0.0, 0.22901720489235822, 0.39874211344709265, 0.5515248861757632, 0.6942503429425072, 0.8299350636914463, 0.9602606006642828, 1.0862919017407517, 1.208760054234254, 1.3281958454350968, 1.4450008743915868, 1.5594887926268315, 1.671910813638732, 1.7824723089834331, 1.8913440539288588, 1.9986701075617448, 2.104573492206967, 2.2091603860507703, 2.3125232828221907, 2.4147434162900403, 2.5158926503299757, 2.6160349731925865, 2.7152276937505615, 2.813522410000466, 2.9109658011881585, 3.007600281683067, 3.1034645452905414, 3.198594021864059, 3.2930212630690865, 3.3867762704264437, 3.4798867759620045, 3.572378483659582, 3.6642752782777324, 3.7555994068225176, 3.8463716369759626, 3.9366113959973315, 4.026336892992521, 4.1155652269491325, 4.204312482533804, 4.292593815323177, 4.380423527874679, 4.467815137825698, 4.554781439030334, 4.641334556594155, 4.7274859965435745, 4.81324669076281, 4.898627037744348, 4.983636939625345, 5.06828583592021, 5.152582734306675, 5.236536238777552, 5.3201545754316895, 5.403445616144461, 5.486416900329515, 5.569075654978743, 5.651428813146051, 5.733483031021815, 5.815244703728706, 5.896719979955375, 5.977914775532007, 6.058834786040912, 6.139485498545628, 6.219872202513606, 6.300000000000001, 6.379873815153484, 6.45949840309909, 6.538878358247865, 6.618018122078417, 6.696921990431319, 6.775594120353546, 6.854038536526837, 6.932259137310841, 7.010259700429211, 7.088043888324451, 7.165615253205017, 7.242977241806325, 7.320133199885459, 7.397086376467763, 7.4738399278621, 7.55039692146012, 7.626760339333793, 7.702933081644277, 7.778917969874225, 7.854717749894718, 7.930335094877177, 8.005772608059827, 8.081032825377617, 8.15611821796384, 8.231031194531095, 8.305774103638761, 8.38034923585354, 8.454758825809298, 8.529005054171934, 8.603090049514615, 8.677015890108434, 8.750784605633125, 8.824398178812212, 8.8978585469767, 8.971167603561119, 9.044327199535513, 9.11733914477673, 9.190205209382187], [0.0, 0.22973967099940698, 0.39999999999999997, 0.5532647468890367, 0.6964404506368993, 0.832553207401873, 0.9632898741122768, 1.0897187581716392, 1.2125732532083187, 1.332385820953752, 1.449559327355391, 1.5644084133929868, 1.6771850850517902, 1.7880953617606197, 1.8973105575213467, 2.0049751858748066, 2.111212657236631, 2.216129484746681, 2.3198184539181153, 2.4223610547827845, 2.523829377920773, 2.6242876134423625, 2.723793251008921, 2.822398051389954, 2.920148841087388, 3.0170881682725814, 3.1132548488157883, 3.208684424338806, 3.303409549195784, 3.3974603195514437, 3.490864554916129, 3.583648040360387, 3.6758347359905126, 3.7674469589937924, 3.858505542566745, 3.949029975254583, 4.039038523606319, 4.1285483405506485, 4.217575561495493, 4.306135389827834, 4.394242173224471, 4.481909471966033, 4.56915012026658, 4.655976281481984, 4.7423994979359945, 4.828430735998953, 4.914080426966815, 4.99935850421438, 5.084274437034299, 5.168837261520256, 5.253055608807535, 5.336937730945339, 5.42049152464195, 5.503724553095125, 5.586644066095295, 5.66925701856763, 5.751570087700371, 5.833589688790477, 5.915321989923479, 5.996772925591858, 6.077948209345419, 6.15885334555739, 6.239493640381573, 6.319874211968252, 6.400000000000001, 6.4798757746025455, 6.559506144680631, 6.638895565724117, 6.718048347125394, 6.79696865904541, 6.875660538862313, 6.95412789723366, 7.032374523800453, 7.110404092558868, 7.1882201669232915, 7.265826204502337, 7.3432255616077375, 7.420421497514332, 7.497417178487991, 7.574215681596871, 7.650819998320297, 7.7272330379683805, 7.80345763092453, 7.879496531722051, 7.955352421965249, 8.031027913104621, 8.10652554907507, 8.181847808805415, 8.256997108606873, 8.331975804447671, 8.406786194120418, 8.481430519308438, 8.555910967556839, 8.630229674153663, 8.704388723926195, 8.778390152957073, 8.852235950224587, 8.925928059171325, 8.99946837920491, 9.072858767134527, 9.146101038546528, 9.219196969122343], [0.0, 0.23045316198021404, 0.40124225995049656, 0.5549829934817413, 0.6986033508362294, 0.8351388261674051, 0.9662815151905982, 1.0931030430980928, 1.2163390811820787, 1.3365237448137028, 1.4540611511009969, 1.5692669181884318, 1.6823938347036151, 1.7936485598995793, 1.9032029398195045, 2.011201936812686, 2.117769344564297, 2.2230120070067194, 2.3270229978124286, 2.4298840600927822, 2.5316675083159668, 2.6324377319442718, 2.732252399181824, 2.831163431548957, 2.929217800974317, 3.0264581877689865, 3.122923528351721, 3.2186494747241516, 3.3136687826534184, 3.4080116417723936, 3.5017059579890795, 3.5947775964534254, 3.687250591683425, 3.7791473301757375, 3.870488709827494, 3.9612942797085062, 4.051582363097291, 4.1413701661935365, 4.23067387451609, 4.319508738668332, 4.407889150885921, 4.49582871356297, 4.583340300772114, 4.670436113644351, 4.757127730349847, 4.843426151316649, 4.929341840236665, 5.01488476133428, 5.100064413310452, 5.1848898603218085, 5.269369760308917, 5.353512390948957, 5.437325673474621, 5.520817194572312, 5.603994226547769, 5.686863745925725, 5.769432450631431, 5.851706775885512, 5.933692908929412, 6.0153968026860705, 6.096824188449574, 6.177980587687809, 6.258871323033633, 6.339501528532512, 6.419876159207946, 6.5, 6.579877674127063, 6.659513650916188, 6.738912253143227, 6.8180776639201905, 6.897013933163908, 6.975724983677071, 7.054214616869976, 7.13248651814895, 7.210544261995093, 7.288391316755141, 7.3660310491643575, 7.443466728619746, 7.520701531220492, 7.597738543591047, 7.674580766501226, 7.7512311182964355, 7.827692438150266, 7.903967489150638, 7.9800589612299815, 8.055969473949045, 8.131701579143302, 8.207257763440257, 8.282640450655343, 8.3578520040736, 8.432894728623776, 8.507770872951077, 8.582482631394363, 8.657032145873133, 8.731421507689413, 8.805652759249202, 8.879727895707862, 8.95364886654363, 9.027417577063025, 9.101035889841834, 9.174505626104981, 9.247828567048543], [0.0, 0.2311579248730029, 0.40246932341711167, 0.5566802208774253, 0.7007397924203531, 0.8376928152294452, 0.9692365597213068, 1.0964459282906869, 1.220058842031095, 1.3406110497245236, 1.4585079043342193, 1.5740659892157813, 1.6875388660651622, 1.7991338261326801, 1.9090232409943984, 2.017352516317828, 2.1242458243691735, 2.2298103358267727, 2.334139408997385, 2.43731503697597, 2.5394097553800083, 2.640488150585136, 2.7406080671541386, 2.839821585391723, 2.938175820874259, 3.0357135844360967, 3.1324739315698316, 3.2284926233066593, 3.323802515586132, 3.4184338903658835, 3.512414738894677, 3.605771005422258, 3.698526797968047, 3.790704571490216, 3.882325287795033, 3.9734085557365133, 4.063972754628711, 4.154035143290646, 4.243611956739089, 4.332718492216221, 4.4213691859714785, 4.509577681997285, 4.5973568937372615, 4.684719059635434, 4.771675793269874, 4.858238128709713, 4.944416561646514, 5.030221086776863, 5.115661231850277, 5.200746088743034, 5.28548434187308, 5.369884294232064, 5.4539538912770835, 5.537700742895852, 5.621132143633988, 5.704255091351564, 5.787076304457164, 5.869602237851356, 5.951839097697163, 6.033792855122521, 6.115469258948741, 6.196873847529244, 6.278011959774357, 6.358888745430286, 6.439509174673788, 6.5198780470780475, 6.6000000000000005, 6.679879516434621, 6.759520932377507, 6.838928443733297, 6.9181061128041215, 6.997057874389232, 7.075787541524253, 7.154298810886074, 7.232595267887136, 7.310680391480941, 7.388557558698765, 7.466230048935959, 7.54370104800473, 7.620973651968924, 7.698050870775193, 7.774935631693716, 7.851630782580732, 7.928139094974129, 8.004463267032586, 8.080605926327888, 8.156569632499432, 8.232356879779234, 8.307970099395138, 8.383411661859498, 8.458683879149898, 8.533789006788272, 8.608729245824115, 8.683506744727262, 8.75812360119528, 8.83258186388017, 8.906883534038807, 8.981030567111238, 9.055024874230726, 9.128868323669106, 9.202562742220909, 9.27610991652939], [0.0, 0.23185419629780504, 0.4036816023792486, 0.5583569989102893, 0.7028504926870738, 0.8402160320749276, 0.9721559998433715, 1.0997485361036305, 1.2237337846433811, 1.3446491079750031, 1.4629010800265252, 1.5788072377351472, 1.6926219065507078, 1.804553002106073, 1.9147734151782072, 2.0234289894114346, 2.1306442710915867, 2.236526753706097, 2.3411700767665398, 2.444656480339503, 2.5470587185272, 2.648441572246068, 2.7488630602926603, 2.8483754198429136, 2.9470259083901564, 3.0448574657193697, 3.1419092649623073, 3.2382171748660658, 3.3338141503356633, 3.428730564541102, 3.5229944930436634, 3.6166319582398385, 3.709667140764881, 3.802122563213604, 3.8940192505313895, 3.9853768706361365, 4.0762138582022835, 4.1665475240341845, 4.25639415205015, 4.345769085569226, 4.434686804324316, 4.523160993404951, 4.611204605151374, 4.698829914871057, 4.7860485711233665, 4.872871641213181, 4.959309652446166, 5.045372629623962, 5.1310701291946454, 5.216411270420161, 5.301404763876813, 5.386058937565714, 5.470381760876497, 5.554380866618636, 5.638063571309674, 5.721436893887957, 5.804507572998602, 5.887282082985005, 5.969766648703789, 6.05196725926854, 6.133889680816609, 6.2155394683835095, 6.2969219769609115, 6.378042371806588, 6.4589056380679795, 6.539516589775077, 6.619879878253012, 6.7, 6.779881304072105, 6.85952799901246, 6.9389441593592665, 7.018133731763798, 7.097100540746931, 7.175848294120328, 7.254380588096061, 7.332700912106595, 7.4108126533551735, 7.488719101115023, 7.5664234507943435, 7.643928807782644, 7.721238191092844, 7.798354536812363, 7.875280701375474, 7.952019464668224, 8.02857353297642, 8.104945541786366, 8.181138058447356, 8.257153584704286, 8.332994559108114, 8.408663359311413, 8.484162304255689, 8.559493656256732, 8.63465962299383, 8.70966235940823, 8.784503969515974, 8.859186508139821, 8.933711982564631, 9.008082354120441, 9.082299539697043, 9.156365413193699, 9.230281806907431, 9.30405051286305], [0.0, 0.2325422030438996, 0.40487949169997695, 0.560013873739874, 0.7049361391329267, 0.8427092985651397, 0.9750407864757836, 1.1030119422611584, 1.2273651060199287, 1.3486392348400291, 1.4672421091215282, 1.5834922080643, 1.6976446118063788, 1.8099078529518153, 1.920455335315607, 2.0294333353201464, 2.136966768831312, 2.2431634483139202, 2.3481172911464827, 2.4519107814356844, 2.554616889175079, 2.6563005875127237, 2.7570200674107994, 2.856827721054425, 2.955770946169346, 3.053892809960544, 3.1512326018025627, 3.247826296879823, 3.343706947888098, 3.4389050181270746, 3.5334486664697713, 3.627363992531831, 3.7206752487023946, 3.8134050244100766, 3.905574406989919, 3.997203122722621, 4.088309660985879, 4.178911383952325, 4.26902462386135, 4.358664769561939, 4.447846343754316, 4.5365830721373, 4.624887945486054, 4.712773275533936, 4.8002507454063785, 4.887331455249505, 4.974025963607825, 5.060344325030689, 5.146296124324085, 5.231890507810555, 5.31713621191427, 5.4020415893489435, 5.486614633152665, 5.570862998784594, 5.654794024473389, 5.738414749985473, 5.821731933962295, 5.904752069959288, 5.987481401304787, 6.069925934884539, 6.1520914539463964, 6.233983530009947, 6.315607533957325, 6.396968646373747, 6.478071867199633, 6.558922024750183, 6.639523784152924, 6.719881655249029, 6.8, 6.879883039437449, 6.959534860190408, 7.038959420621485, 7.118160556600488, 7.197141986941677, 7.275907318528565, 7.354460051148198, 7.432803582055047, 7.510941210282962, 7.588876140722234, 7.666611487977339, 7.744150280019851, 7.821495461649767, 7.898649897777576, 7.9756163765383885, 8.052397612248678, 8.128996248215314, 8.205414859405979, 8.281655954989267, 8.357721980752327, 8.4336153214032, 8.509338302764647, 8.58489319386568, 8.660282208936678, 8.735507509313482, 8.810571205255624, 8.885475357683356, 8.960221979837986, 9.03481303886962, 9.109250457356248, 9.183536114757768, 9.257671848808375, 9.331659456850558], [0.0, 0.23322216261602416, 0.4060633700770402, 0.5616513691664572, 0.7069973911089797, 0.8451734029151339, 0.9778918316077974, 1.1062371784483573, 1.230953954157625, 1.352582691748361, 1.471532363981344, 1.5881223812980791, 1.7026085696976931, 1.815200071539104, 1.9260707976746652, 2.03536745224291, 2.143215316367024, 2.2497225177583298, 2.3549832484122475, 2.459080233621178, 2.5620866567448726, 2.6640676809145964, 2.76508166724445, 2.86518116111569, 2.9644136988462697, 3.0628224735708214, 3.1604468895470634, 3.2573230271518083, 3.35348403572779, 3.4489604676501924, 3.5437805641293254, 3.6379705010967998, 3.731554601856387, 3.82455552188879, 3.9169944101889773, 4.008891050717817, 4.100263986916437, 4.191130631724921, 4.2815073651385624, 4.371409621003749, 4.460851964485465, 4.549848161416838, 4.638411240558402, 4.726553549643351, 4.814286805958883, 4.901622142108247, 4.988570147509414, 5.075140906111505, 5.161344030746735, 5.2471886944817365, 5.332683659286214, 5.417837302297441, 5.502657639925359, 5.587152350013897, 5.671328792248886, 5.755194026981213, 5.838754832614775, 5.922017721692333, 6.004988955797878, 6.087674559381455, 6.170080332601281, 6.2522118632682195, 6.334074537969004, 6.415673552437018, 6.497013921232644, 6.578100486789203, 6.658937927875176, 6.739530767518634, 6.819883380435567, 6.8999999999999995, 6.979884724790373, 7.059541524743653, 7.138974246945831, 7.218186621085082, 7.297182264591541, 7.375964687485722, 7.45453729695576, 7.532903401681967, 7.6110662159258196, 7.6890288633989785, 7.7667943809268865, 7.844365721920215, 7.921745759666527, 7.998937290453514, 8.075943036534381, 8.152765648945103, 8.22940771018263, 8.305871736752435, 8.382160181593209, 8.458275436385948, 8.534219833754179, 8.609995649361613, 8.6856051039131, 8.761050365064282, 8.836333549245147, 8.911456723402132, 8.986421906663317, 9.061231071930806, 9.13588614740426, 9.210389018039164, 9.284741526943302, 9.358945476714633], [0.0, 0.23389428374280202, 0.4072336009280796, 0.5632699878554623, 0.7090348813620975, 0.8476091015362176, 0.9807100104307473, 1.1094252347227793, 1.2345014307327489, 1.35648068923128, 1.475773161594552, 1.5926991787705242, 1.7075153040212698, 1.8204312824314357, 1.9316215260457008, 2.041233161788108, 2.1493918318285314, 2.2562059754907016, 2.361770056221211, 2.4661670377178355, 2.5694703142468787, 2.6717452367327237, 2.7730503344799082, 2.873438304299815, 2.9729568195049385, 3.0716491977078677, 3.1695549567251438, 3.2667102809133355, 3.3631484151480078, 3.4588999998529957, 3.5539933576267324, 3.648454739837041, 3.742308539884833, 3.8355774785414627, 3.9282827657510224, 4.0204442424896225, 4.1120805056385885, 4.20320901832022, 4.293846207735192, 4.384007552208571, 4.473707658880579, 4.562960333255989, 4.651778641642818, 4.740174967359096, 4.828161061459979, 4.915748088631679, 5.002946668809727, 5.0897669150041, 5.176218467750156, 5.262310526550319, 5.348051878625344, 5.433450925254512, 5.518515705950193, 5.603253920683034, 5.687672950348688, 5.771779875645212, 5.855581494511131, 5.939084338257652, 6.022294686513979, 6.105218581091968, 6.18786183886527, 6.270230063748215, 6.3523286578511, 6.434162831880852, 6.515737614849274, 6.597057863145059, 6.6781282690203945, 6.758953368538231, 6.839537549022018, 6.919885056045906, 6.999999999999999, 7.079886362262195, 7.159548001005368, 7.238988656666255, 7.318211957100034, 7.39722142244272, 7.476020469701596, 7.554612417092235, 7.633000488139268, 7.711187815556555, 7.789177444921346, 7.866972338155718, 7.944575376827744, 8.021989365283712, 8.099217033622068, 8.176261040518787, 8.253123975913295, 8.329808363563368, 8.406316663476796, 8.482651274227145, 8.558814535160307, 8.634808728498218, 8.710636081345552, 8.786298767604908, 8.861798909805591, 8.937138580850759, 9.012319805687397, 9.087344562903308, 9.162214786255008, 9.236932366130224, 9.311499150948377, 9.385916948502322], [0.0, 0.23455876685050028, 0.40839053321549457, 0.5648702124783733, 0.7110492174711066, 0.8500171207528029, 0.9834961633244984, 1.1125770617616058, 1.2380085936014802, 1.360334389670168, 1.4799657665654045, 1.5972239652809193, 1.712366277963438, 1.8256030455739303, 1.9371091756538252, 2.047032213108119, 2.155498157050422, 2.2626157548756907, 2.3684797383969083, 2.473173307007973, 2.576770063484986, 2.67933554441136, 2.7809284453707463, 2.8816016128837902, 2.981402855700717, 3.0803756144974983, 3.1785595193590095, 3.2759908574399432, 3.3727029680630567, 3.4687265787002466, 3.5640900924131698, 3.658819835148602, 3.7529402696080054, 3.8464741811114207, 3.9394428398594354, 4.031866143195476, 4.123762740833771, 4.215150145508561, 4.306044831089458, 4.396462319874751, 4.486417260502889, 4.575923497699461, 4.664994134893274, 4.7536415905828076, 4.8418776492074365, 4.929713507171739, 5.017159814582007, 5.104226713178821, 5.190923870885865, 5.277260513340935, 5.363245452728884, 5.448887114196646, 5.534193560096487, 5.61917251227432, 5.703831372594591, 5.788177241871299, 5.872216937355607, 5.9559570089138845, 6.039403754015475, 6.122563231636751, 6.20544127517684, 6.288043504470538, 6.370375336975295, 6.4524419982014205, 6.534248531447914, 6.615799806900249, 6.69710053014109, 6.778155250120137, 6.858968366625029, 6.9395441372914, 7.019886684186787, 7.100000000000001, 7.179887953864816, 7.259554296844377, 7.339002667100436, 7.4182365947695565, 7.497259506566584, 7.576074730133992, 7.654685498154299, 7.733094952241267, 7.811306146624488, 7.8893220516407325, 7.967145557044472, 8.04477947514902, 8.12222654380891, 8.19948942925329, 8.276570728779493, 8.353472973315174, 8.430198629856894, 8.50675010379246, 8.583129741113739, 8.659339830526354, 8.735382605462089, 8.811260245999495, 8.886974880697894, 8.962528588349464, 9.037923399653975, 9.113161298820303, 9.188244225098689, 9.26317407424736, 9.337952699937013, 9.412581915096363], [0.0, 0.23521580450493468, 0.4095345022158438, 0.5664525067769411, 0.7130409831864013, 0.8523981584038256, 0.9862510977103354, 1.1156935729577244, 1.2414764591322878, 1.364144909859358, 1.4841113939020587, 1.6016980521029371, 1.7171628973263064, 1.8307168597327363, 1.9425353368084246, 2.0527662867558947, 2.1615360616329813, 2.2689537134539663, 2.3751142393912095, 2.480101071893785, 2.583988019911266, 2.686840803605807, 2.7887182829770336, 2.8896734525773806, 2.9897542550772416, 3.0890042528370594, 3.18746318695209, 3.285167446223311, 3.382150463362401, 3.4784430519139553, 3.574073694501275, 3.6690687908144386, 3.7634528720789557, 3.857248787440293, 3.950477866680366, 4.0431600628783295, 4.135314077989326, 4.226957473803645, 4.318106770336912, 4.408777533367926, 4.498984452568379, 4.588741411445213, 4.6780615501320915, 4.7669573219137495, 4.855440544239713, 4.943522444877529, 5.0312137037661895, 5.118524491054955, 5.205464501748954, 5.292042987328508, 5.3782687846628505, 5.464150342499136, 5.549695745773603, 5.634912737962325, 5.719808741663586, 5.804390877581933, 5.888665982064771, 5.972640623325718, 6.056321116474367, 6.1397135374592775, 6.222823736019889, 6.305657347733075, 6.388219805231477, 6.470516348662916, 6.552552035453502, 6.634331749430897, 6.715860209358878, 6.797141976929498, 6.878181464254927, 6.958982940897133, 7.039550540470245, 7.11988826684725, 7.2, 7.279889501498987, 7.3595604196970505, 7.439016294619247, 7.518260562579212, 7.597296560540696, 7.67612753024149, 7.754756622095532, 7.833186898887814, 7.911421339275508, 7.9894628411077635, 8.067314224575645, 8.144978235202863, 8.222457546687119, 8.299754763601197, 8.376872423962295, 8.453813001677444, 8.53057890887233, 8.607172498110334, 8.683596064508118, 8.759851847753671, 8.83594203403231, 8.911868757865797, 8.987634103869349, 9.06324010843106, 9.138688761317903, 9.213982007212273, 9.289121747182731, 9.36410984009241, 9.438948103948338], [0.0, 0.23586558182407352, 0.41066583023823056, 0.5680173165568269, 0.7150107396807243, 0.8547528853379799, 0.9889755897809969, 1.1187756463768244, 1.2449060043836657, 1.3679133233990475, 1.4882112116199318, 1.6061226997942597, 1.721906513539927, 1.8357741657063853, 1.94790153831066, 2.05843699828582, 2.1675072467338548, 2.2752216369222946, 2.3816754284506283, 2.48695228424782, 2.5911262171586777, 2.694263128895531, 2.796422042057169, 2.8976560975920487, 2.9980133706108973, 3.097537543814005, 3.1962684680803317, 3.294242632733937, 3.391493562843464, 3.488052157075094, 3.583946976734608, 3.679204494440516, 3.7738493091851772, 3.8679043332342067, 3.9613909552924667, 4.0543291835589566, 4.1467377716524645, 4.238634329877253, 4.330035423885045, 4.420956662454685, 4.511412775837685, 4.601417685893802, 4.690984569055965, 4.780125913010771, 4.868853567853132, 4.957178792367002, 5.045112295994414, 5.132664276979392, 5.219844457109257, 5.306662113421295, 5.39312610719635, 5.479244910521015, 5.565026630665946, 5.65047903249836, 5.735609559121271, 5.8204253509099795, 5.904933263097113, 5.9891398820408055, 6.073051540295969, 6.156674330595808, 6.240014118839508, 6.323076556172074, 6.405867090233646, 6.488390975647813, 6.57065328381169, 6.652658912044379, 6.734412592145116, 6.815918898407505, 6.897182255132056, 6.97820694367529, 7.0589971090703285, 7.139556766250754, 7.219889805906735, 7.3, 7.379891006961865, 7.45956637659661, 7.539029554710596, 7.618283887485843, 7.697332625615357, 7.7761789282160105, 7.854825866533656, 7.933276427453924, 8.011533516831195, 8.089599962647235, 8.167478518010192, 8.245171864003783, 8.322682612395853, 8.400013308214808, 8.477166432201777, 8.55414440314588, 8.63094958010939, 8.707584264549165, 8.784050702340279, 8.86035108570732, 8.93648755506861, 9.01246220079806, 9.088277064909231, 9.163934142665774, 9.239435384122217, 9.314782695598772, 9.389977941093631, 9.465022943636015], [0.0, 0.23650827686365633, 0.4117848272957034, 0.5695650706162576, 0.7169590267181437, 0.8570819468111606, 0.9916703861175595, 1.121824126586492, 1.2482981691394417, 1.371640662931712, 1.4922663431747893, 1.6104991208224413, 1.7265984264774528, 1.8407763493271128, 1.9532092506381065, 2.06404590161907, 2.173413348611723, 2.281421242853321, 2.388165103510142, 2.4937288214789173, 2.5981866112773204, 2.7016045541890423, 2.804041833639778, 2.905551735378355, 3.006182465512296, 3.105977825770088, 3.204977775617802, 3.3032189038069224, 3.4007348267564086, 3.4975565273262412, 3.5937126446470766, 3.6892297234709703, 3.784132429818502, 3.8784437383874546, 3.972185096163404, 4.065376565864411, 4.158036952209803, 4.250183913489029, 4.341834060492502, 4.433003044530428, 4.523705635991838, 4.613955794671276, 4.70376673290529, 4.793150972407376, 4.88212039556201, 4.9706862918314885, 5.058859399839316, 5.146649945618062, 5.234067677445322, 5.321121897636788, 5.407821491618843, 5.494174954563124, 5.580190415831273, 5.6658756614484975, 5.751238154799044, 5.836285055714566, 5.921023238107077, 6.005459306281457, 6.089599610047792, 6.173450258740984, 6.257017134243833, 6.340305903099789, 6.423322027792915, 6.506070777264791, 6.588557236731256, 6.670786316855804, 6.752762762331048, 6.834491159914792, 6.915975945963041, 6.997221413498307, 7.078231718848252, 7.15901088788649, 7.239562821904685, 7.319891303142541, 7.4, 7.4798924719539785, 7.559572174200093, 7.6390424620381605, 7.718306595018794, 7.79736774086694, 7.876228979197093, 7.954893305033658, 8.033363632148992, 8.111642796230647, 8.18973355788854, 8.2676386055119, 8.345360557985213, 8.422901967271669, 8.50026532087201, 8.57745304416616, 8.654467502644449, 8.731311004034833, 8.80798580033202, 8.884494089734053, 8.960838018491541, 9.037019682674329, 9.113041129860123, 9.188904360749342, 9.264611330710094, 9.340163951256999, 9.41556409146734, 9.490813579337791], [0.0, 0.23714406097793114, 0.41289179173333673, 0.5710961816147635, 0.7188863637476046, 0.8593859637937392, 0.994336205201996, 1.124839826367287, 1.2516538578127592, 1.3753279222342187, 1.4962778697388446, 1.614828482021342, 1.731239887088656, 1.845724744268528, 1.9584598889239124, 2.069594492191822, 2.179255941941329, 2.2875541841753337, 2.3945849948357742, 2.500432490335798, 2.6051710846973517, 2.708867036844548, 2.811579689300609, 2.913362471057691, 3.014263717811496, 3.114327349038793, 3.213593431625123, 3.3120986526802496, 3.4098767189911534, 3.506958696706276, 3.603373301944294, 3.6991471508151537, 3.7943049756468987, 3.8888698128981445, 3.9828631672084853, 4.076305155228798, 4.16921463222946, 4.261609303969128, 4.35350582589152, 4.444919891380862, 4.535866310532109, 4.626359080666672, 4.716411449638648, 4.806035972822538, 4.895244564545173, 4.984048544617305, 5.072458680530122, 5.160485225805925, 5.248137954927735, 5.33542619521783, 5.4223588559884925, 5.508944455248174, 5.595191144211952, 5.681106729835511, 5.766698695566251, 5.851974220482959, 5.936940196976177, 6.0216032471045455, 6.10596973774778, 6.190045794663965, 6.273837315547639, 6.357349982175116, 6.440589271714769, 6.523560467272203, 6.6062686677333895, 6.688718796962721, 6.770915612407545, 6.852863713155838, 6.934567547489464, 7.016031419971487, 7.09725949810265, 7.178255818578969, 7.2590242931796, 7.339568714311704, 7.419892760236658, 7.499999999999999, 7.579893898085642, 7.659577818813156, 7.739055030495512, 7.818328709373171, 7.89740194333928, 7.976277735469499, 8.054959007369021, 8.133448602348325, 8.211749288438428, 8.289863761255518, 8.367794646724192, 8.445544503667858, 8.523115826274182, 8.600511046443023, 8.677732536023646, 8.754782608947664, 8.831663523263625, 8.908377483078793, 8.984926640413349, 9.061313096971814, 9.137538905836218, 9.213606073085282, 9.289516559343557, 9.365272281264218, 9.440875112949021, 9.51632688730868], [0.0, 0.23777309915742487, 0.4139870108163228, 0.5726110468866042, 0.7207932509268569, 0.8616655341946087, 0.9969737388334334, 1.1278235283148805, 1.2549739412288397, 1.37897605817674, 1.5002468323319447, 1.619111906891172, 1.7358320998657768, 1.8506206346745255, 1.963654815746283, 2.075084209903031, 2.1850365429174468, 2.29362205243049, 2.40093676843526, 2.507065030468499, 2.6120814499396006, 2.716052461528263, 2.819037565167143, 2.921090331571853, 3.0222592246512923, 3.122588280381152, 3.2221176719266778, 3.3208841837122898, 3.4189216119341475, 3.516261105145427, 3.612931455635953, 3.708959350116424, 3.8043695865187983, 3.899185262407214, 3.9934279394635515, 4.087117787699255, 4.180273712399384, 4.272913466288132, 4.365053748988733, 4.456710295513014, 4.547897955240552, 4.638630762621455, 4.728922000650508, 4.818784258006061, 4.908229480618381, 4.99726901832466, 5.085913667177477, 5.174173707897185, 5.26205894089418, 5.349578718231996, 5.436741972855375, 5.5235572453672726, 5.610032708604332, 5.6961761902306325, 5.781995193543846, 5.8674969166656785, 5.95268827026913, 6.0375758939782305, 6.122166171561209, 6.206465245025071, 6.290479027708329, 6.374213216458533, 6.457673302972559, 6.540864584369751, 6.623792173061165, 6.70646100597203, 6.788875853169091, 6.871041325939669, 6.95296188436495, 7.034641844426098, 7.1160853846783905, 7.197296552525409, 7.278279270122527, 7.359037339936485, 7.439574449985456, 7.519894178782077, 7.600000000000001, 7.67989528688285, 7.759583316412981, 7.839067273256013, 7.918350253495909, 7.997435268174157, 8.076325246645675, 8.155023039762986, 8.233531422899468, 8.311853098821581, 8.389990700419345, 8.467946793303586, 8.545723878277949, 8.623324393693045, 8.700750717689607, 8.778005170337082, 8.85509001567362, 8.932007463653006, 9.00875967200378, 9.085348748005352, 9.16177675018567, 9.238045689944695, 9.314157533107645, 9.390114201411725, 9.465917573929858, 9.541569488434655], [0.0, 0.23839555034548993, 0.4150707612811116, 0.574110049203085, 0.7226801700820455, 0.8639212340083166, 0.9995836534554222, 1.1307759863415245, 1.2582592582957273, 1.3825859925585817, 1.5041742338188455, 1.6233504777540073, 1.7403762251544312, 1.8554652576230126, 1.9687953437426893, 2.0805164418769855, 2.1907566121638173, 2.299626380828306, 2.4072220292544086, 2.5136281177660167, 2.618919453093024, 2.7231626438302823, 2.8264173456715667, 2.928737269571885, 3.0301710063107445, 3.1307627071428374, 3.2305526504002033, 3.329577716802884, 3.427871791019969, 3.525466103146466, 3.622389520845716, 3.718668800689874, 3.8143288055278397, 3.9093926933894054, 4.003882082401419, 4.0978171953771225, 4.191216987092529, 4.284099256745569, 4.376480747676364, 4.468377236088438, 4.559803610234619, 4.650773941304916, 4.74130154706683, 4.8313990491538155, 4.921078424768637, 5.010351053460509, 5.0992277595443145, 5.187718850653655, 5.275834152854804, 5.363583042693472, 5.4509744764993915, 5.538017017233425, 5.624718859127368, 5.711087850336849, 5.797131513801947, 5.882857066487878, 5.9682714371586565, 6.053381282819765, 6.138193003951096, 6.222712758638428, 6.30694647570043, 6.390899866898068, 6.474578438304585, 6.557987500906319, 6.641132180497786, 6.724017426928278, 6.806648022751797, 6.889028591327263, 6.971163604411627, 7.053057389284586, 7.134714135440196, 7.216137900877478, 7.297332618019372, 7.378302099286852, 7.459050042352724, 7.539580035097587, 7.6198955602886045, 7.699999999999999, 7.779896639792735, 7.859588672669367, 7.939079202818896, 8.01837124916523, 8.09746774873186, 8.176371559834376, 8.255085465111627, 8.333612174405479, 8.411954327498426, 8.490114496717647, 8.56809518941348, 8.645898850319742, 8.723527863802751, 8.800984556005517, 8.878271196893072, 8.955390002204501, 9.032343135316923, 9.109132709026264, 9.18576078724936, 9.262229386651692, 9.338540478204683, 9.414695988676339, 9.490697802058682, 9.566547760935318], [0.0, 0.2390115677352187, 0.41614330985236875, 0.5755935574875919, 0.7245475856077863, 0.8661536183910526, 1.0021665914008862, 1.1336979270843972, 1.2615106175714101, 1.3861586138301498, 1.5080610407826143, 1.6275452377756257, 1.7448733813211965, 1.8602598054368322, 1.9738827380619408, 2.0858925250545255, 2.196417557461665, 2.305568647109771, 2.4134423241752234, 2.5201233674869576, 2.625686777076488, 2.730199333656196, 2.8337208470709903, 2.9363051670657283, 3.0380010099791606, 3.138852641153431, 3.238900443000345, 3.338181391540233, 3.4367294590006368, 3.5345759561755603, 3.6317498253227845, 3.728277892153817, 3.8241850837634996, 3.9194946180222954, 4.014228168918588, 4.10840601152165, 4.202047149586895, 4.295169428305628, 4.387789634282992, 4.4799235844884375, 4.571586205646243, 4.662791605306569, 4.753553135650208, 4.843883450925093, 4.933794559283241, 5.023297869678784, 5.11240423439678, 5.201123987705899, 5.289466981063105, 5.377442615243233, 5.465059869719294, 5.55232732957896, 5.639253210228033, 5.7258453801018865, 5.812111381579979, 5.898058450276264, 5.983693532858777, 6.069023303534797, 6.154054179323142, 6.238792334222171, 6.323243712370701, 6.407414040288967, 6.491308838277983, 6.574933431047747, 6.658292957637901, 6.741392380688213, 6.824236495110871, 6.90682993621162, 6.9891771873024915, 7.071282586844934, 7.153150335158711, 7.234784500728772, 7.31618902613949, 7.39736773366319, 7.478324330527513, 7.559062413884191, 7.639585475499908, 7.719896906188212, 7.800000000000001, 7.879897958188592, 7.959593892964256, 8.03909083105184, 8.118391717064146, 8.197499416702685, 8.276416719796691, 8.355146343190295, 8.433690933487226, 8.51205306966159, 8.590235265542757, 8.668239972181766, 8.746069580106171, 8.82372642146977, 8.901212772103214, 8.978530853471089, 9.055682834540708, 9.132670833567493, 9.209496919801472, 9.286163115119212, 9.362671395585158, 9.439023692946108, 9.515221896062348, 9.591267852278746], [0.0, 0.23962129904817694, 0.4172049137282789, 0.5770619274868465, 0.7263959453121281, 0.8683632226707508, 1.0047231720608427, 1.1365900512277147, 1.2647287987349876, 1.3896947787094804, 1.5119081852833198, 1.6316971928635369, 1.7493246467884707, 1.8650054278531873, 1.9789182186661156, 2.091213748625597, 2.2020207363111477, 2.311450276236086, 2.4195991448304417, 2.5265523371984857, 2.63238504470083, 2.7371642184110296, 2.840949820752113, 2.9437958388425205, 3.045751113298993, 3.1468600223869334, 3.2471630515358427, 3.34669727109386, 3.4454967399534993, 3.5435928487842774, 3.6410146136772257, 3.737788928777678, 3.8339407847708316, 3.9294934587571797, 4.0244686800166125, 4.118886775341189, 4.212766796965923, 4.306126635606156, 4.398983120690561, 4.491352109538525, 4.583248566953201, 4.674686636473863, 4.765679704343434, 4.85624045709151, 4.94638093350355, 5.036112571638534, 5.125446251466285, 5.214392333618745, 5.302960694684472, 5.391160759420179, 5.479001530205998, 5.566491614030617, 5.653639247257779, 5.740452318395656, 5.826938389064722, 5.91310471333737, 5.998958255602957, 6.084505707095021, 6.16975350120254, 6.254707827674075, 6.339374645812257, 6.423759696745982, 6.507868514858848, 6.591706438444473, 6.675278619652464, 6.758590033782549, 6.841645487978996, 6.92444962937246, 7.007006952712142, 7.089321807527139, 7.171398404852457, 7.253240823551967, 7.334853016267786, 7.41623881502306, 7.497401936502767, 7.578345987035164, 7.659074467294621, 7.739590776744833, 7.819898217839997, 7.8999999999999995, 7.979899243374526, 8.059598982409762, 8.139102169230371, 8.218411676848428, 8.297530302210166, 8.376460769090533, 8.455205730844883, 8.533767773026428, 8.612149415877447, 8.690353116701745, 8.768381272125238, 8.846236220251171, 8.923920242715965, 9.00143556665128, 9.078784366557581, 9.155968766094071, 9.232990839789545, 9.30985261467849, 9.386556071866396, 9.463103148028047, 9.539495736842316, 9.615735690366744], [0.0, 0.24022488679628623, 0.41825582103650927, 0.5785155024015763, 0.7282256812104321, 0.870550563296124, 1.007253992982465, 1.1394530347449106, 1.2679145539688907, 1.3931953137010376, 1.515716566510398, 1.6358073134502662, 1.7537310619463105, 1.869703234061905, 1.9839029624933202, 2.0964813563147375, 2.2075674583379437, 2.3172726429148485, 2.4256939302479172, 2.5329165295375953, 2.6390158215457884, 2.744058925990692, 2.8481059563360973, 2.9512110356898726, 3.053423127694541, 3.1547867224009662, 3.255342407218353, 3.355127345872216, 3.454175683046819, 3.5525188884823753, 3.650186051359235, 3.7472041335670285, 3.84359818874058, 3.9393915526136216, 4.034606009200439, 4.1292619364947285, 4.223378434722628, 4.316973439664824, 4.410063823142035, 4.502665482417024, 4.59479341998814, 4.686461815021153, 4.777684087477908, 4.8684729558444015, 4.958840489230871, 5.048798154507898, 5.138356859051113, 5.2275269895901015, 5.316318447591792, 5.404740681553142, 5.492802716530589, 5.580513181193169, 5.6678803326513965, 5.754912079283992, 5.841616001758576, 5.927999372419992, 6.014069173200365, 6.099832112187939, 6.185294638976906, 6.270462958907331, 6.355343046292874, 6.439940656723896, 6.524261338524682, 6.608310443435609, 6.692093136584149, 6.775614405802435, 6.858879070343562, 6.941891789043954, 7.024657067974739, 7.107179267621149, 7.189462609625461, 7.271511183125896, 7.353328950720973, 7.434919754086413, 7.516287319269238, 7.597435261681772, 7.678367090816315, 7.759086214699551, 7.839595944104309, 7.919899496534757, 8.0, 8.079900496589762, 8.159603945864882, 8.239113228074334, 8.318431147209644, 8.397560433906742, 8.476503748204582, 8.555263682169183, 8.633842762391128, 8.712243452363976, 8.790468154750565, 8.868519213543644, 8.9463989161269, 9.024109495241966, 9.10165313086671, 9.179031952009671, 9.256248038425221, 9.333303422253795, 9.41020008959113, 9.486939981990357, 9.563524997900371, 9.639956994043908], [0.0, 0.24082246852806916, 0.4192962712629475, 0.5799546134795288, 0.7300372102718469, 0.8727161387290319, 1.0097596309015795, 1.1422875300666446, 1.2710686092585746, 1.3966610165238236, 1.5194870523363544, 1.6398765361701577, 1.7580936309501127, 1.8743542946219975, 1.988838105491312, 2.1016965485301036, 2.2130589875561464, 2.323037073975401, 2.431728069337104, 2.5392173948075047, 2.645580618665161, 2.750885027594805, 2.855190884598055, 2.9585524474190414, 3.061018801501898, 3.1626345475706246, 3.2634403739993787, 3.3634735369618967, 3.4627682660805164, 3.5613561093793558, 3.6592662284008037, 3.756525652104698, 3.8531594964491074, 3.9491911552175694, 4.044642466614131, 4.139533859324641, 4.2338844810888245, 4.327712312304291, 4.42103426676198, 4.513866281270574, 4.60622339564853, 4.6981198243336095, 4.789569020671062, 4.880583734785299, 4.971176065809592, 5.061357509139426, 5.151138999283546, 5.240530948809491, 5.329543283815008, 5.41818547630107, 5.506466573774779, 5.594395226369791, 5.681979711736947, 5.769227957927796, 5.856147564467572, 5.942745821791755, 6.029029729200673, 6.115006011469563, 6.200681134236584, 6.286061318278158, 6.371152552769607, 6.4559606076188585, 6.540491044952169, 6.624749229822867, 6.708740340207161, 6.792469376344878, 6.875941169477452, 6.959160390030597, 7.042131555284714, 7.124859036572142, 7.20734706603689, 7.289599742989289, 7.37162103988519, 7.453414807956838, 7.534984782520146, 7.616334587981111, 7.697467742562219, 7.778387662767941, 7.859097667606958, 7.93960098258728, 8.019900743499226, 8.1, 8.179901719012623, 8.259608787950958, 8.339124017781717, 8.418450145933544, 8.497589839062487, 8.57654569568257, 8.655320248669502, 8.733915967645014, 8.81233526124879, 8.89058047930448, 8.96865391488585, 9.046557806288684, 9.12429433891375, 9.20186564706569, 9.279273815672461, 9.356520881929635, 9.43360883687355, 9.510539626887125, 9.587315155141827, 9.663937282979164], [0.0, 0.24141417706037357, 0.4203264956551569, 0.5813795805735155, 0.7318309351217656, 0.8748604302842259, 1.0122406427142765, 1.1450941671799362, 1.2741916656155645, 1.400092657455275, 1.523220480778845, 1.6439057654372955, 1.7624133234122883, 1.8789596432652034, 1.9937247445311994, 2.106860484385761, 2.2184965444977127, 2.3287448506041026, 2.437702903228914, 2.5454563334209435, 2.652080895132433, 2.757644040373658, 2.8622061802143675, 2.965821705711707, 3.0685398229143237, 3.1704052421316264, 3.2714587517104143, 3.3717376993640373, 3.4712763988181137, 3.57010647561127, 3.668257162936739, 3.76575555616538, 3.8626268329659776, 3.9588944446013463, 4.0545802829327, 4.149704826839825, 4.244287271109057, 4.338345640316419, 4.431896889810578, 4.524956995557466, 4.617541034328858, 4.709663255487844, 4.801337145434976, 4.892575485622127, 4.983390404910531, 5.073793426940226, 5.163795513086397, 5.253407101500595, 5.3426381426693075, 5.431498131866518, 5.519996138829345, 5.608140834945098, 5.695940518203074, 5.7834031361342975, 5.870536306936281, 5.957347338957337, 6.043843248695301, 6.130030777448397, 6.215916406741064, 6.301506372634372, 6.38680667901924, 6.471823109980443, 6.556561241310561, 6.64102645124503, 6.725223930482512, 6.809158691548584, 6.892835577555196, 6.976259270403447, 7.059434298472841, 7.142365043836221, 7.22505574903611, 7.307510523454974, 7.389733349309118, 7.471728087293388, 7.553498481901486, 7.635048166444693, 7.71638066778988, 7.797499410835977, 7.878407722746579, 7.959108836954871, 8.03960589695591, 8.119901959900004, 8.200000000000001, 8.279902911764232, 8.359613513066046, 8.439134548060034, 8.518468689954302, 8.597618543647512, 8.676586648238725, 8.755375479417618, 8.833987451741972, 8.912424920809034, 8.990690185326724, 9.06878548909039, 9.146713022870403, 9.224474926215459, 9.30207328917625, 9.379510153953797, 9.456787516476487, 9.533907327909558, 9.610871496100634, 9.687681886964597], [0.0, 0.24200014069659623, 0.4213467176023263, 0.5827907126669437, 0.7336072447033563, 0.8769839029201699, 1.0146975663919149, 1.1478735546632584, 1.2772844002292487, 1.4034909805968605, 1.526917661377575, 1.6478958749314954, 1.7666910759953756, 1.8835202785944531, 1.998563939209648, 2.1119742836061595, 2.223881308217849, 2.3343972104493718, 2.4436197274792533, 2.5516346982010876, 2.6585180604380967, 2.7643374299209547, 2.869153364349945, 2.973020386800897, 3.07598782275602, 3.1781004910461683, 3.2793992790201476, 3.3799216250421646, 3.4797019261245596, 3.578771884567878, 3.6771608045205415, 3.7748958471196454, 3.87200225114554, 3.968503524782251, 4.064421613027203, 4.159777044466786, 4.254589060477171, 4.348875729383868, 4.442654047689786, 4.535940030137929, 4.62874879009461, 4.72109461150916, 4.812991013516495, 4.904450808591797, 4.995486155035628, 5.086108604458359, 5.176329144840764, 5.266158239670013, 5.355605863584544, 5.444681534905392, 5.533394345383861, 5.621752987454564, 5.709765779247786, 5.797440687584904, 5.8847853491544155, 5.971807090043554, 6.058512943780688, 6.144909668026609, 6.231003760037797, 6.316801471011572, 6.402308819411573, 6.487531603361781, 6.572475412188414, 6.657145637181029, 6.741547481637221, 6.825685970249036, 6.909565957883685, 6.99319213780624, 7.076569049387546, 7.159701085336672, 7.2425924984936945, 7.325247408215426, 7.407669806383858, 7.489863563064566, 7.571832431839938, 7.653580054840072, 7.735109967492298, 7.816425603008506, 7.897530296628024, 7.97842728963227, 8.05911973314623, 8.139610691740574, 8.21990314684719, 8.3, 8.379904075911936, 8.459618125398231, 8.539144828155441, 8.618486795404868, 8.697646572408512, 8.776626640865071, 8.855429421192976, 8.93405727470701, 9.012512505694545, 9.0907973633971, 9.168914043902511, 9.246864691952613, 9.3246514026711, 9.40227622321585, 9.47974115435979, 9.557048152004054, 9.634199128627017, 9.711195954672537], [0.0, 0.24258048343234653, 0.42235715299335075, 0.5841883083691009, 0.7353665149010177, 0.8790870059843445, 1.0171309218434612, 1.150626280662058, 1.2803474675523772, 1.406856705066838, 1.5305793764919489, 1.651847708998767, 1.7709277939134624, 1.8880371656845774, 2.003356713547358, 2.117039028320994, 2.2292144181849762, 2.339995349605574, 2.44947979414573, 2.5577537965500676, 2.664893476748993, 2.770966612623078, 2.876033907096578, 2.9801500139976045, 3.0833643770962547, 3.185721922703828, 3.2872636362214527, 3.388027045794617, 3.488046630923449, 3.5873541699340685, 3.685979037249442, 3.7839484591420347, 3.881287734917545, 3.978020429135188, 4.074168539418887, 4.169752643584821, 4.264792029152079, 4.359304807775986, 4.453308016718923, 4.546817709128992, 4.639849034616006, 4.732416311383766, 4.824533090987547, 4.916212216628247, 5.007465875763357, 5.098305647705268, 5.188742546785134, 5.278787061582706, 5.368449190656695, 5.457738475154107, 5.546664028629259, 5.635234564362167, 5.7234584204309025, 5.811343582762148, 5.898897706358015, 5.986128134874491, 6.073041918707113, 6.159645831722282, 6.245946386757607, 6.331949850001461, 6.417662254350414, 6.503089411832983, 6.588236925179198, 6.673110198607518, 6.757714447893614, 6.842054709779287, 6.926135850774255, 7.009962575398548, 7.093539433908918, 7.176870829548632, 7.259961025356537, 7.342814150568115, 7.425434206638325, 7.507825072913584, 7.589990511977776, 7.671934174695227, 7.753659604971609, 7.835170244252025, 7.916469435774072, 7.997560428592116, 8.078446381387883, 8.159130366081214, 8.239615371253805, 8.319904305397767, 8.4, 8.479905212472497, 8.559622628938016, 8.639154866879851, 8.71850447766382, 8.797673948940005, 8.876665706931265, 8.955482118615071, 9.03412549380473, 9.112598087135687, 9.190902099962234, 9.269039682169534, 9.347012933905615, 9.424823907237664, 9.502474607736676, 9.579966995994253, 9.6573029890751, 9.734484461908604], [0.0, 0.2431553251494122, 0.423358010554546, 0.5855726563822676, 0.7371091091283731, 0.8811701739161584, 1.0195412117287816, 1.153352913808789, 1.283381500324819, 1.4101905261251653, 1.5342063825249108, 1.6557620839721219, 1.7751243523482076, 1.8925112375919682, 2.008104057590935, 2.1220557647579734, 2.234496976063192, 2.3455404244840654, 2.4552843137462403, 2.563814892494128, 2.67120846103914, 2.7775329578747403, 2.88284922977259, 2.9872120600736958, 3.0906710097147996, 3.193271111468849, 3.2950534478598654, 3.39605563596359, 3.496312236986042, 3.5958551045582787, 3.694713682711683, 3.792915262236678, 3.890485202390596, 3.987447123573466, 4.083823075536866, 4.179633684860121, 4.274898284767855, 4.3696350298344875, 4.463860997695511, 4.557592279540091, 4.650844060877993, 4.74363069384279, 4.83596576210281, 4.927862139293415, 5.0193320417526515, 5.110387076232349, 5.201038283164263, 5.291296175982878, 5.381170776940439, 5.470671649793559, 5.559807929692894, 5.648588350566279, 5.737021270250485, 5.825114693596401, 5.9128762937461605, 6.000313431757973, 6.087433174734662, 6.174242312594624, 6.260747373608907, 6.346954638814835, 6.432870155405105, 6.518499749180967, 6.603849036149213, 6.688923433334647, 6.773728168872738, 6.8582682914408295, 6.94254867908078, 7.0265740474609, 7.110348957620658, 7.1938778232376634, 7.277164917452867, 7.360214379286778, 7.443030219676582, 7.525616327161562, 7.60797647324178, 7.690114317432995, 7.772033412038852, 7.853737206659632, 7.935229052455385, 8.01651220617974, 8.09758983399954, 8.178465015114137, 8.259140745187251, 8.339619939603233, 8.419905436558743, 8.5, 8.579906322415052, 8.659627027489831, 8.739164672636113, 8.818521751398949, 8.89770069575061, 8.976703878277576, 9.05553361426671, 9.134192163696257, 9.212681733137044, 9.291004477568809, 9.369162502116284, 9.44715786370943, 9.524992572671838, 9.602668594241111, 9.680187850024815, 9.75755221939534], [0.0, 0.24372478179882237, 0.4243494921683795, 0.5869440359425744, 0.7388353788832142, 0.883233826910351, 1.0219289222262173, 1.1560540040912306, 1.2863871105397746, 1.4134931162351854, 1.5377994110779951, 1.6596397894181358, 1.7792815977852692, 1.8969433967793847, 2.0128069289247215, 2.1270255048404416, 2.239730047394549, 2.3510335535790667, 2.4610344571074694, 2.5698192086138367, 2.677464287100793, 2.784037790170088, 2.889600707093238, 2.9942079495108773, 3.0979091944287878, 3.200749580084241, 3.302770285214313, 3.4040090149919044, 3.5045004115635163, 3.604276403159689, 3.7033665027681386, 3.8017980650928473, 3.899596508781159, 3.9967855095508042, 4.09338716879269, 4.189422161392477, 4.284909865852157, 4.379868479263185, 4.474315119255952, 4.568265914704321, 4.661736086681702, 4.754740020933592, 4.847291332940534, 4.939402926487251, 5.031087046521794, 5.1223553269783775, 5.213218834144855, 5.303688106077605, 5.393773188500447, 5.483483667567795, 5.572828699824338, 5.661817039652296, 5.750457064462042, 5.838756797851396, 5.926723930932574, 6.014365842002989, 6.101689614716236, 6.188702054892335, 6.2754097060911915, 6.361818864059982, 6.447935590153601, 6.53376572381701, 6.619314894209386, 6.704588531041915, 6.789591874694074, 6.874329985666939, 6.958807753426478, 7.043029904684841, 7.127001011163206, 7.210725496875779, 7.294207644970974, 7.377451604162663, 7.46046139478143, 7.543240914473309, 7.625793943571009, 7.708124150160679, 7.790235094865268, 7.872130235363833, 7.95381293066466, 8.035286445148522, 8.11655395239725, 8.197618538821517, 8.278483207100725, 8.3591508794469, 8.439624400703604, 8.519906541290068, 8.6, 8.679907406663867, 8.759631324682763, 8.839174253441488, 8.91853863060786, 8.997726834324828, 9.076741185301534, 9.155583948808967, 9.234257336585626, 9.312763508658094, 9.391104575081192, 9.469282597602103, 9.547299591252482, 9.625157525872416, 9.70285832756977, 9.780403880118326], [0.0, 0.2442889655737394, 0.4253317931744926, 0.5883027172363644, 0.7405456642716103, 0.8852783715435348, 1.024294523757515, 1.1587300836725614, 1.2893648903563055, 1.4167651260663197, 1.5413591700421996, 1.663481589314255, 1.7834003492764796, 1.9013345164615936, 2.017466254098627, 2.1319492276962326, 2.2449146631878545, 2.356475819135426, 2.4667313571106777, 2.5757679278670427, 2.6836621874437663, 2.7904823910776244, 2.896289669220513, 3.0011390606247073, 3.1050803572902876, 3.208158801942306, 3.310415668640008, 3.411888749837723, 3.5126127678729624, 3.6126197248850005, 3.7119392021793853, 3.8105986177818503, 3.908623449179831, 4.0060374268965475, 4.102862703484081, 4.1991200016871355, 4.294828744865827, 4.390007172234958, 4.484672441049489, 4.578840717519038, 4.6725272579513595, 4.765746481392641, 4.858512034841082, 4.950836851951596, 5.042733206017325, 5.1342127579031756, 5.225286599513679, 5.315965293299129, 5.406258908237581, 5.496177052673861, 5.585728904348587, 5.674923237908972, 5.76376845015775, 5.852272583266082, 5.940443346149876, 6.02828813418612, 6.115814047425931, 6.20302790744371, 6.289936272946653, 6.3765454542555835, 6.462861526756459, 6.54889034341162, 6.634637546410843, 6.720108578034226, 6.805308690791883, 6.8902429568991375, 6.974916277140289, 7.059333389169066, 7.14349887528945, 7.227417169756527, 7.311092565633515, 7.3945292212378915, 7.477731166206663, 7.560702307208286, 7.643446433326336, 7.725967221137992, 7.808268239508474, 7.890352954120812, 7.972224731758856, 8.053886844359898, 8.135342472852102, 8.216594710790684, 8.29764656780577, 8.378500972873837, 8.459160777423806, 8.539628758287979, 8.619907620507345, 8.700000000000001, 8.779908466100906, 8.859635523980534, 8.939183616949514, 9.018555128655814, 9.097752385180646, 9.176777657038738, 9.255633161088406, 9.33432106235635, 9.412843475781832, 9.491202467884644, 9.569400058360921, 9.647438221610612, 9.72531888820021, 9.803043946264134], [0.0, 0.2448479850728549, 0.4263051026541897, 0.5896489617936876, 0.7422402945032338, 0.8873042013663259, 1.026638471672939, 1.1613816676663917, 1.2923154129617425, 1.4200071854416902, 1.5448863446289454, 1.667288223161438, 1.7874813996326984, 1.9056854418771034, 2.022082929977539, 2.136827881083656, 2.2500518214202163, 2.361868268724776, 2.4723761103416146, 2.5816621953117154, 2.689803355090437, 2.7968680011066622, 2.9029174037003678, 3.008006727571948, 3.1121858786631797, 3.21550020323046, 3.3179910697826713, 3.419696357256636, 3.520650867446848, 3.6208866757247855, 3.7204334310884812, 3.8193186143058018, 3.9175677611656794, 4.0152046564951585, 4.1122515035391904, 4.208729072463443, 4.304656831075546, 4.400053060328072, 4.494934956737844, 4.589318723508485, 4.683219651859569, 4.776652193833162, 4.869630027656619, 4.962166116581624, 5.0542727619869545, 5.145961651421697, 5.237243902172581, 5.32813010086052, 5.418630339504949, 5.508754248437984, 5.598511026402158, 5.687909468124177, 5.7769579896216285, 5.865664651469005, 5.954037180222937, 6.0420829881836475, 6.129809191649683, 6.217222627805617, 6.304329870367286, 6.391137244095757, 6.477650838279618, 6.563876519274857, 6.649819942182575, 6.73548656173673, 6.820881642467036, 6.906010268195838, 6.990877350922161, 7.075487639141161, 7.159845725642751, 7.243956054829159, 7.327822929587649, 7.4114505177514, 7.494842858178651, 7.578003866477697, 7.660937340402876, 7.743646964944676, 7.82613631713514, 7.9084088705880085, 7.990467999791521, 8.072316984170318, 8.153959011931654, 8.23539718370989, 8.316634516022255, 8.397673944547751, 8.47851832724038, 8.55917044728682, 8.639633015918148, 8.719908675084374, 8.8, 8.879909501568223, 8.959639628690823, 9.039192770470402, 9.118571258311064, 9.197777367923278, 9.27681332123832, 9.355681288237232, 9.434383388699004, 9.512921693872359, 9.591298228075207, 9.669514970225622, 9.747573855307921, 9.825476775777238], [0.0, 0.245401945454913, 0.42726960369947853, 0.5909830228604275, 0.7439195883597856, 0.8893116974633202, 1.0289612068991827, 1.1640092548697103, 1.2952392333872642, 1.423219904234285, 1.5483815983450515, 1.6710604070363786, 1.7915255165518866, 1.909996991490839, 2.0266578250174563, 2.1416623827400425, 2.2551424884570457, 2.36721191673611, 2.4779697786508255, 2.587503119735228, 2.6958889452732753, 2.8031958214724213, 2.9094851572947396, 3.014812242248915, 3.119227095187249, 3.2227751649605287, 3.3254979136725047, 3.427433305959828, 3.528616222354889, 3.6290788107986223, 3.728850787368927, 3.827959695007989, 3.926431127278609, 4.024288922820208, 4.121555335111837, 4.218251181310968, 4.314395973270496, 4.410008033303038, 4.505104596831962, 4.599701903720095, 4.693815279782888, 4.787459209759666, 4.880647402824316, 4.973392851557447, 5.065707885169296, 5.1576042176516355, 5.249092991443688, 5.3401848171182404, 5.430889809527586, 5.521217620792144, 5.611177470466296, 5.700778173174522, 5.79002816397537, 5.87893552168011, 5.9675079903264505, 6.055752998984697, 6.143677680053781, 6.231288886187178, 6.318593205973539, 6.40559697848349, 6.492306306782431, 6.578727070498784, 6.664864937528129, 6.750725374945573, 6.836313659191657, 6.921634885590703, 7.006693977254969, 7.091495693422923, 7.17604463727551, 7.2603452632702705, 7.344401884029609, 7.428218676816285, 7.511799689626321, 7.595148846926945, 7.678269955064786, 7.7611667073675, 7.843842688960047, 7.926301381315099, 8.008546166555567, 8.090580331525677, 8.172407071645896, 8.25402949456567, 8.335450623626988, 8.41667340115074, 8.497700691556947, 8.578535284329153, 8.659179896832507, 8.739637176994341, 8.819909705855498, 8.9, 8.979910513870195, 9.059643641973945, 9.139201720990082, 9.218587031777789, 9.297801801295389, 9.376848204433433, 9.455728365766841, 9.534444361230468, 9.612998219722174, 9.691391924637271, 9.76962741533791, 9.847706588560843], [0.0, 0.2459509485849363, 0.4282254736676647, 0.5923051457504459, 0.7455838546382703, 0.8913012289830016, 1.0312631565524872, 1.166613328456474, 1.2981368892796834, 1.4264038732150022, 1.5518455739153596, 1.6747988345872291, 1.7955334436866137, 1.9142699581322393, 2.0311917804730997, 2.146453621657883, 2.2601876003958137, 2.3725077457863133, 2.4835133906301867, 2.5932917751961546, 2.7019200770412266, 2.809467015766353, 2.915994137715209, 3.0215568560878925, 3.1262053016368223, 3.2299850248890833, 3.3329375807057375, 3.4351010186563586, 3.5365102973066285, 3.637197636517531, 3.737192818846552, 3.836523448853814, 3.9352151773589816, 4.0332918963323, 4.130775909037386, 4.227688079203, 4.324047962333153, 4.419873921730382, 4.515183231376437, 4.609992167465296, 4.704316090098694, 4.79816951642062, 4.8915661862745585, 4.984519121307588, 5.077040678312342, 5.169142597486657, 5.260836046197162, 5.352131658754177, 5.443039572638531, 5.533569461563967, 5.623730565710474, 5.7135317194222495, 5.802981376628403, 5.892087634213792, 5.980858253540766, 6.069300680299641, 6.157422062845658, 6.245229269162768, 6.332728902579338, 6.419927316347503, 6.506830627186192, 6.593444727877488, 6.679775298996953, 6.7658278198504105, 6.851607578682637, 6.937119682217003, 7.022369064579552, 7.107360495655923, 7.19209858892511, 7.276587808809982, 7.360832477580963, 7.444836781846014, 7.528604778657169, 7.612140401261309, 7.695447464520467, 7.77852967002486, 7.861390610919942, 7.944033776466992, 8.026462556355266, 8.108680244782185, 8.190690044316877, 8.272495069561094, 8.354098350620525, 8.435502836398491, 8.516711397723181, 8.597726830318658, 8.678551857629245, 8.75918913350611, 8.839641244764291, 8.919910713617815, 9.0, 9.079911503775609, 9.159647566850987, 9.23921047518797, 9.318602460726938, 9.397825703224015, 9.476882332007136, 9.555774427655349, 9.634504023605484, 9.713073107690018, 9.79148362360977, 9.869737472344786], [0.0, 0.2464950931726869, 0.42917288442242635, 0.5936155681790287, 0.7472333925707313, 0.893273153639511, 1.0335447345192046, 1.1691943566343672, 1.3010089016322481, 1.4295596648556608, 1.5552788941563633, 1.6785041779764494, 1.7995059016548731, 1.9185051100729176, 2.0356856115413957, 2.151202459293203, 2.2651880643384508, 2.3777567080557964, 2.489007943011028, 2.5990292024841968, 2.7078978347807903, 2.8156827115377605, 2.922445515264591, 3.028241781758155, 3.133121752680699, 3.237131079335797, 3.3403114085209418, 3.4427008739869955, 3.5443345116423544, 3.6452446126315783, 3.745461025403411, 3.845011415590608, 3.9439214907629907, 4.0422151957496615, 4.139914883158223, 4.237041462876581, 4.333614533673556, 4.429652499478859, 4.525172672491387, 4.620191364914752, 4.714723970833544, 4.808785039509641, 4.902388341184711, 4.995546926315065, 5.088273179031643, 5.180578865506424, 5.272475177812841, 5.3639727737886815, 5.455081813343045, 5.545811991591909, 5.636172569158337, 5.726172399931725, 5.815819956544752, 5.905123353795911, 5.994090370218875, 6.082728467976888, 6.171044811240289, 6.259046283187834, 6.346739501757166, 6.434130834256425, 6.521226410937237, 6.60803213761894, 6.694553707444863, 6.780796611843309, 6.8667661507588225, 6.952467442212947, 7.03790543124804, 7.123084898302689, 7.208010467062798, 7.292686611828375, 7.377117664432483, 7.461307820745581, 7.545261146795569, 7.628981584531286, 7.7124729572548105, 7.795738974745796, 7.878783238099211, 7.961609244296016, 8.04422039052485, 8.126619978271258, 8.208811217189762, 8.290797228772895, 8.372581049830186, 8.454165635789142, 8.535553863829403, 8.616748535860323, 8.697752381351604, 8.778568060025822, 8.859198164421116, 8.939645222331682, 9.019911699133228, 9.1, 9.179912472019604, 9.259651406211361, 9.33921903945362, 9.418617556325028, 9.497849090864461, 9.576915728254068, 9.655819506429472, 9.73456241762106, 9.813146409829907, 9.891573388241817], [0.0, 0.24703447490385583, 0.43011200256222787, 0.5949145205788192, 0.748868492221943, 0.8952278181880636, 1.0358063420058694, 1.1717527932670695, 1.3038557754770632, 1.4326878340898408, 1.5586821628039582, 1.682177088774138, 1.803443588997815, 1.9227031920477287, 2.0401401084449087, 2.15590973071047, 2.2701447595969246, 2.3829597265539832, 2.49445440198883, 2.604716410503435, 2.7138232696572135, 2.821844001792361, 2.92884042439232, 3.034868194777657, 3.1399776645496633, 3.24421458490631, 3.347620693776812, 3.450234208356483, 3.5520902412194624, 3.653221154169945, 3.753656860971191, 3.8534250877940246, 3.952551598461694, 4.051060390199489, 4.148973864527096, 4.246312977087535, 4.343097369535745, 4.439345486073005, 4.535074676780848, 4.630301289557323, 4.7250407521724345, 4.8193076457248205, 4.9131157705882575, 5.006478205776128, 5.099407362518386, 5.191915032733805, 5.284012432986362, 5.375710244435378, 5.467018649221916, 5.557947363676848, 5.64850566868738, 5.738702437517031, 5.828546161338331, 5.9180449727066184, 6.007206667176587, 6.0960387232402224, 6.184548320744537, 6.272742357930089, 6.3606274672159255, 6.44821002984316, 6.535496189477663, 6.6224918648619155, 6.70920276159701, 6.795634383127617, 6.881792040995648, 6.967680864421921, 7.053305809269563, 7.138671666437737, 7.223783069729921, 7.308644503236805, 7.393260308270391, 7.477634689882562, 7.561771722998516, 7.645675358192889, 7.729349427133923, 7.812797647719029, 7.896023628923111, 7.979030875379238, 8.061822791709796, 8.14440268662465, 8.226773776801709, 8.30893919056397, 8.390901971366121, 8.47266508110275, 8.554231403249357, 8.635603745846446, 8.716784844336356, 8.797777364261684, 8.878583903833569, 8.959206996377544, 9.039649112664057, 9.119912663130371, 9.200000000000001, 9.279913419305489, 9.359655162819928, 9.43922741990227, 9.51863232926111, 9.597871980641395, 9.676948416438178, 9.755863633241242, 9.834619583314298, 9.913218176012082], [0.0, 0.2475691865644366, 0.4310429896368671, 0.5962022263993374, 0.7504894348664402, 0.8971655588756651, 1.038048368060693, 1.1742890784641937, 1.3066780005415386, 1.435788919034192, 1.5620559652981847, 1.6858181988049523, 1.8073471830877172, 1.9268649262227822, 2.0445560374589813, 2.160576245668025, 2.2750585388361797, 2.388117696319048, 2.499853704479098, 2.6103543775837155, 2.7196974009808113, 2.827951946412987, 2.935179965169017, 3.041437235040984, 3.146774216617351, 3.2512367601255816, 3.3548666938375753, 3.4577023176706225, 3.5597788202008154, 3.6611286332802, 3.761781735421049, 3.861765912808104, 3.9611069850309866, 4.059829001257519, 4.15795441149598, 4.2555042167483474, 4.352498101184364, 4.448954548928195, 4.544890947616014, 4.640323680531264, 4.7352682088377005, 4.829739145195079, 4.923750319848394, 5.017314840120845, 5.110445144106771, 5.203153049248819, 5.295449796389471, 5.387346089807656, 5.47885213368391, 5.56997766538032, 5.660731985872782, 5.751123987631192, 5.841162180207414, 5.930854713759883, 6.020209400716949, 6.109233735757958, 6.1979349142708635, 6.2863198494276205, 6.374395188003295, 6.462167325051341, 6.549642417535731, 6.636826397010196, 6.723724981425732, 6.810343686139338, 6.8966878341898745, 6.982762565900479, 7.068572847861349, 7.154123481341659, 7.239419110174858, 7.324464228157553, 7.4092631859986104, 7.493820197851843, 7.5781393474627174, 7.662224593956974, 7.746079777296589, 7.829708623426446, 7.913114749133154, 7.99630166663564, 8.079272787925671, 8.16203142887489, 8.244580813123779, 8.326924075766655, 8.409064266845835, 8.491004354666995, 8.57274722894698, 8.654295703804364, 8.73565252060241, 8.816820350653341, 8.897801797792185, 8.978599400827912, 9.059215635879012, 9.139652918600188, 9.2199136063064, 9.3, 9.379914346306455, 9.459658839323628, 9.539235622389398, 9.618646789772015, 9.697894388287336, 9.776980418846817, 9.855906837939877, 9.934675559054098], [0.0, 0.2480993181587069, 0.4319660023528932, 0.5974789023911062, 0.7520964933461722, 0.8990867018686657, 1.040271190068255, 1.1768036391409054, 1.3094760518710997, 1.438863441672675, 1.565400869527643, 1.689428120951502, 1.8112173409892975, 1.9309910131137131, 2.0489341418860882, 2.165202789647723, 2.2799302291583414, 2.393231485556002, 2.5052067593086944, 2.6159440527246427, 2.725521217503064, 2.83400757350728, 2.9414652046852856, 3.047950008268785, 3.1535125528998824, 3.258198786987301, 3.362050628371793, 3.4651064589840717, 3.5674015427511896, 3.6689683809730504, 3.76983701635633, 3.8700352945856404, 3.9695890905393107, 4.068522504882782, 4.1668580356975955, 4.264616728956168, 4.361818310978884, 4.458481305470837, 4.554623137301167, 4.650260224835617, 4.745408062345661, 4.840081293781835, 4.93429377900449, 5.0280586534041545, 5.1213883817094485, 5.214294806668264, 5.306789193193635, 5.398882268486065, 5.490584258576782, 5.5819049216789525, 5.672853578685086, 5.7634391411069466, 5.853670136718305, 5.943554733129913, 6.033100759499243, 6.122315726554354, 6.211206845091021, 6.299781043084702, 6.3880449815435165, 6.476005069214947, 6.563667476247166, 6.65103814689542, 6.738122811354822, 6.8249269967926685, 6.911456037646293, 6.997715085246048, 7.083709116817327, 7.169442943910491, 7.2549212203030455, 7.340148449414378, 7.425128991269732, 7.509867069046889, 7.594366775236032, 7.678632077440764, 7.762666823845753, 7.846474748374424, 7.930059475558184, 8.013424525136838, 8.096573316408413, 8.179509172344986, 8.26223532348997, 8.344754911651009, 8.427070993401621, 8.509186543403652, 8.591104457561839, 8.672827556020755, 8.754358586013877, 8.835700224573635, 8.916855081110773, 8.99782569987073, 9.078614562274225, 9.159224089148722, 9.239656642857005, 9.319914529328676, 9.4, 9.479915253667173, 9.559662438257702, 9.639243652524389, 9.71866094766604, 9.79791632887875, 9.87701175684147, 9.95594914913922], [0.0, 0.24862495702121018, 0.43288119276857834, 0.5987447588753295, 0.753689932409968, 0.900991563658571, 1.0424751742190401, 1.1792968895490827, 1.3122503904202307, 1.4419119085060041, 1.5687174265360495, 1.6930074499168883, 1.8150547002772213, 1.9350821324572491, 2.0532751429806426, 2.169790124832221, 2.2847606331317816, 2.3983019367168956, 2.5105144483465827, 2.621486356776308, 2.7312956786468083, 2.8400118806868395, 2.9476971783793635, 3.054407587383486, 3.1601937834792255, 3.265101812424501, 3.3691736808698463, 3.472447852064354, 3.5749596646474564, 3.6767416887783604, 3.7778240308141156, 3.8782345954349573, 3.9779993123393633, 4.077142333253965, 4.175686203926158, 4.273652014917683, 4.371059534342352, 4.4679273251507485, 4.564272849129439, 4.66011255942915, 4.755461983148497, 4.850335795263614, 4.9447478849992255, 5.038711415575328, 5.132238878129101, 5.2253421404992295, 5.318032491465299, 5.410320680955142, 5.5022169566654995, 5.593731097483901, 5.684872444050691, 5.7756499267581205, 5.8660720914474425, 5.956147123033822, 6.04588286726208, 6.135286850772975, 6.224366299639533, 6.313128156515254, 6.40157909652069, 6.489725541981302, 6.577573676117725, 6.6651294557790814, 6.752398623300836, 6.83938671756049, 6.926099084297254, 7.0125408857554135, 7.098717109705426, 7.184632577891704, 7.270291953951542, 7.355699750845554, 7.44086033783641, 7.525777947049382, 7.610456679645258, 7.6949005116336595, 7.77911329935226, 7.863098784635411, 7.946860599693678, 8.03040227172401, 8.113727227268777, 8.19683879634031, 8.279740216326458, 8.362434635691294, 8.444925117484187, 8.527214642669295, 8.609306113286788, 8.691202355456186, 8.772906122231428, 8.85442009631667, 8.935746892651116, 9.016889060870607, 9.09784908765316, 9.178629398955149, 9.259232362144415, 9.339660288036043, 9.419915432836339, 9.5, 9.579916142005272, 9.65966596205151, 9.739251515683314, 9.818674812345117, 9.897937816869886, 9.977042450905357], [0.0, 0.24914618792310342, 0.43378870847907935, 0.6, 0.7552700090359216, 0.9028804514474341, 1.044660675955349, 1.1817692317817539, 1.3150014636137806, 1.444934811168415, 1.5720061711932454, 1.6965567629488736, 1.8188598798124775, 1.9391389440389286, 2.0575797408272676, 2.1743389910330864, 2.289550529768409, 2.403329867526676, 2.5157776275776853, 2.626982183560611, 2.7370217156745262, 2.84596583628202, 2.953876891297982, 3.0608110138157962, 3.166818985854946, 3.2719469497061864, 3.376237000085081, 3.479727680877173, 3.5824544048077422, 3.6844498103178527, 3.7857440668811595, 3.8863651376787907, 3.9863390067696556, 4.085689876513381, 4.184440339923495, 4.282611531777142, 4.380223261631081, 4.477294131352281, 4.573841639335145, 4.669882273223683, 4.765431592668366, 4.860504303410746, 4.955114323793675, 5.049274844633241, 5.142998383253724, 5.236296832374192, 5.329181504440644, 5.421663171917646, 5.513752103985768, 5.605458100033533, 5.696790520283511, 5.787758313850118, 5.878370044490568, 5.968633914279333, 6.0585577854094765, 6.148149200301021, 6.237415400176123, 6.326363342243239, 6.41499971561701, 6.503330956087007, 6.591363259836706, 6.679102596203494, 6.76655471956138, 6.853725180399869, 6.9406193356652714, 7.027242358424282, 7.11359924690399, 7.19969483295738, 7.285533789998847, 7.371120640450221, 7.456459762734135, 7.541555397848314, 7.626411655551449, 7.71103252018868, 7.795421856182318, 7.879583413211301, 7.963520831100957, 8.047237644442845, 8.130737286962923, 8.214023095654742, 8.297098314693185, 8.379966099142942, 8.462629518474921, 8.545091559902735, 8.627355131550553, 8.709423065462724, 8.791298120464836, 8.872982984885217, 8.954480279145171, 9.035792558225735, 9.116922314018128, 9.197871977564636, 9.27864392119618, 9.359240460572359, 9.439663856629515, 9.51991631744179, 9.600000000000001, 9.67991701191276, 9.759669413034029, 9.839259217020947, 9.918688392825663, 9.997958866124561], [0.0, 0.24966309317320867, 0.4346886927923791, 0.6012448239832546, 0.756836972737723, 0.9047536635140567, 1.0468280403950025, 1.1842210562524111, 1.3177297058803163, 1.4479326270137185, 1.5752676228327882, 1.7000766205279931, 1.8226334804800948, 1.9431620884796, 2.0618486151753355, 2.1788501065726926, 2.2943006754522908, 2.408316071957959, 2.520997128123259, 2.632432400936743, 2.74270023279846, 2.851870380496232, 2.960005319294431, 3.0671612987461425, 3.1733892062286433, 3.278735279764405, 3.3832417014031773, 3.486947094997758, 3.589886946744444, 3.692093962799489, 3.793598375229356, 3.8944282052305694, 3.9946094907713396, 4.094166484424089, 4.1931218260762195, 4.29149669435334, 4.389310939911229, 4.486583203210269, 4.5833310189489005, 4.679570908978158, 4.775318465230222, 4.870588423956743, 4.965394732377053, 5.059750608674315, 5.153668596142581, 5.2471606121748255, 5.340237992687053, 5.432911532493532, 5.525191522080372, 5.617087781166951, 5.708609689395556, 5.799766214447388, 5.890565937846947, 5.9810170786856025, 6.071127515468164, 6.16090480626296, 6.2503562073155585, 6.339488690268585, 6.42830895811463, 6.516823459995639, 6.605038404950354, 6.692959774700782, 6.780593335559572, 6.867944649531866, 6.955019084678066, 7.041821824797464, 7.128357878487005, 7.214632087624347, 7.300649135319851, 7.3864135533780475, 7.47192972930551, 7.5572019128987895, 7.642234222443121, 7.727030650549993, 7.8115950696592575, 7.895931237229336, 7.980042800637128, 8.063933301807433, 8.14760618159018, 8.231064783902207, 8.314312359649104, 8.3973520704414, 8.480186992118249, 8.562820118090858, 8.645254362516903, 8.727492563316389, 8.809537485038664, 8.891391821589544, 8.973058198826939, 9.054539177032725, 9.13583725326806, 9.216954863618934, 9.297894385338154, 9.378658138889639, 9.459248389900507, 9.539667351026006, 9.619917183732076, 9.700000000000001, 9.779917863957332, 9.859672793438959, 9.939266761482028, 10.018701697758138], [0.0, 0.2501757527140843, 0.4355812848965559, 0.602479423344736, 0.7583910658558927, 0.9066114895621418, 1.048977602734168, 1.1866527421507047, 1.3204355391591907, 1.4509058196724696, 1.5785022858581215, 1.7035675670217492, 1.8263760858904956, 1.9471521879831568, 2.0660824262323727, 2.183324169122648, 2.2990118048225097, 2.4132613211577545, 2.5261737572109864, 2.637837851814154, 2.7483321082360144, 2.8577264265033513, 2.966083410167583, 3.0734594242849296, 3.1799054607250827, 3.285467852455919, 3.3901888681440355, 3.494107210952658, 3.59725843994563, 3.6996753284382033, 3.801388170575528, 3.902425045093006, 4.00281204342535, 4.102573467945346, 4.201732005029264, 4.300308876791014, 4.3983239746478215, 4.495795977336488, 4.5927424555613, 4.689179965099349, 4.785124129899374, 4.880589716472524, 4.975590700677425, 5.070140327839528, 5.164251167009356, 5.257935160051119, 5.351203666158054, 5.44406750231056, 5.536536980125285, 5.6286219394854715, 5.720331779293614, 5.811675485645201, 5.90266165768608, 5.993298531384745, 6.083594001423771, 6.173555641391266, 6.26319072243281, 6.3525062305066395, 6.441508882369303, 6.530205140405451, 6.618601226403498, 6.706703134368351, 6.794516642453237, 6.8820473240843505, 6.969300558344896, 7.056281539678606, 7.142995286967108, 7.229446652030397, 7.315640327595157, 7.401580854771551, 7.4872726300754815, 7.572719912030056, 7.657926827377017, 7.7428973769263045, 7.827635441069458, 7.912144784980486, 7.99642906352583, 8.080491825903296, 8.164336520028275, 8.24796649668402, 8.331385013451552, 8.414595238433462, 8.497600253784853, 8.580403059063617, 8.663006574411378, 8.745413643575542, 8.827627036782195, 8.909649453468834, 8.991483524885323, 9.07313181657083, 9.154596830713997, 9.235881008403082, 9.316986731772358, 9.397916326050595, 9.478672061517162, 9.55925615537079, 9.639670773515777, 9.719918032270169, 9.8, 9.879918698683598, 9.959676105409553, 10.039274153811862], [0.0, 0.25068424421341, 0.4364666200188944, 0.6037039851256675, 0.7599325238348079, 0.9084542110514628, 1.0511096886305296, 1.1890646578759059, 1.3231193733828746, 1.4538548395819602, 1.5817106503191742, 1.7070301313068958, 1.8300882630466422, 1.9511098470477999, 2.0702818154187663, 2.1877618565013286, 2.3036846316129527, 2.418166364328995, 2.531308299097743, 2.643199355116115, 2.753918195213672, 2.8635348614915976, 2.9721120847453495, 3.0797063445952175, 3.1863687365537596, 3.2921456877623276, 3.3970795528001534, 3.501209113496077, 3.604570001189059, 3.707195055807329, 3.8091146330700125, 3.910356868783582, 4.01094790741456, 4.110912100731207, 4.210272181220694, 4.309049414131666, 4.407263731311389, 4.504933849461893, 4.6020773750005715, 4.698710897354748, 4.794850072229416, 4.8905096961492065, 4.985703773379198, 5.080445576166456, 5.174747699108564, 5.268622108342015, 5.362080186148029, 5.4551327714929165, 5.54779019695207, 5.640062322408661, 5.731958565868801, 5.82348793169255, 5.914659036503839, 6.0054801330110745, 6.095959131943067, 6.186103622281521, 6.275920889950893, 6.365417935108635, 6.454601488163354, 6.543478024634739, 6.632053778957217, 6.720334757318736, 6.808326749616831, 6.896035340605893, 6.983465920302312, 7.070623693707722, 7.15751368990481, 7.244140770575079, 7.330509637983353, 7.416624842469768, 7.502490789486311, 7.588111746211694, 7.6734918477754155, 7.758635103119209, 7.8435454005216565, 7.928226512809619, 8.012682102278193, 8.09691572533906, 8.180930836915625, 8.264730794601732, 8.348318862599559, 8.43169821545098, 8.514871941575699, 8.597843046628313, 8.680614456685744, 8.763189021275423, 8.84556951625402, 8.927758646545744, 9.009759048748565, 9.09157329361621, 9.17320388842311, 9.254653279219125, 9.335923852980306, 9.417017939661536, 9.49793781415661, 9.578685698170798, 9.659263762010681, 9.739674126295796, 9.819918863596213, 9.9, 9.979919516614258, 10.059679351003163], [0.0, 0.25118864315095796, 0.4373448295773112, 0.6049186910982999, 0.7614615754863514, 0.91028210151304, 1.0532246145679582, 1.1914571614494367, 1.3257816069359947, 1.4567801244906113, 1.5848931924611134, 1.710464827361669, 1.8337705629789585, 1.955035653142947, 2.074447406086017, 2.192163827432888, 2.308319849451542, 2.423031929569479, 2.5364015159477993, 2.6485177066967314, 2.7594593229224293, 2.869296547656997, 2.9780922379158175, 3.0859029869611865, 3.192779993114366, 3.2987697769322355, 3.4039147782151966, 3.5082538568245702, 3.611822715792731, 3.714654261124758, 3.8167789096181766, 3.918224853691197, 4.019018290415328, 4.119183620556749, 4.2187436223424095, 4.317719603808523, 4.416131536907, 4.513998175999536, 4.611337162929197, 4.708165120502707, 4.804497735925725, 4.900349835494804, 4.995735451652846, 5.090667883351854, 5.185159750530859, 5.279223043403284, 5.372869167152506, 5.466108982553799, 5.558952842972614, 5.651410628131081, 5.743491774985175, 5.8352053060125275, 5.9265598551744825, 6.017563691784628, 6.10822474248886, 6.1985506115385895, 6.288548599518198, 6.378225720670078, 6.467588718945013, 6.556644082892013, 6.64539805948974, 6.733856667011125, 6.82202570700349, 6.909910775458248, 6.99751727323698, 7.084850415814245, 7.17191524239169, 7.258716624432953, 7.345259273664231, 7.431547749581351, 7.517586466500455, 7.603379700186202, 7.688931594088335, 7.774246165214936, 7.859327309668147, 7.944178807866091, 8.028804329472727, 8.113207438055554, 8.19739159548959, 8.281360166124454, 8.365116420730187, 8.448663540236126, 8.532004619276142, 8.615142669552487, 8.698080623029604, 8.780821334968424, 8.863367586810888, 8.945722088923754, 9.02788748321006, 9.109866345596117, 9.191661188401216, 9.273274462596886, 9.354708559961983, 9.43596581513947, 9.517048507600428, 9.597958863520393, 9.6786990575728, 9.759271214644057, 9.83967741147443, 9.919919678228657, 10.0, 10.079920318251189], [0.0, 0.2516890229014065, 0.43821604132454106, 0.6061237179653446, 0.7629784432409537, 0.912095426849246, 1.0553226882037436, 1.1938306009076765, 1.3284226270924242, 1.459682099938255, 1.58805037524686, 1.713872154829702, 1.8374235213498982, 1.9589301773537797, 2.0785798042006562, 2.196530722269984, 2.3129181326212542, 2.4278587246707137, 2.5414541486690347, 2.653793680214129, 2.7649562974275503, 2.875012323149349, 2.984024739609078, 3.0920502528055103, 3.1991401630494036, 3.3053410835688037, 3.4106955387062183, 3.515242465733664, 3.619017638805658, 3.7220540294776097, 3.824382115138755, 3.9260301443679455, 4.027024366422505, 4.1273892306761, 4.227147560730999, 4.3263207070700345, 4.4249286814302, 4.522990275532771, 4.620523166364208, 4.717544009844657, 4.81406852442944, 4.910111565949799, 5.005687194801928, 5.100808736429981, 5.195488835912506, 5.2897395073480045, 5.383572178639521, 5.476997732197512, 5.570026542011826, 5.662668507485471, 5.754933084373287, 5.846829313126112, 5.938365844904553, 6.029550965495062, 6.120392617333795, 6.210898419820193, 6.30107568808175, 6.390931450333561, 6.480472463960685, 6.569705230437627, 6.658636009187331, 6.747270830471414, 6.835615507394157, 6.923675647094453, 7.011456661192658, 7.098963775552805, 7.186202039414871, 7.27317633394668, 7.359891380260416, 7.446351746934635, 7.532561857079009, 7.618525994975724, 7.704248312328472, 7.789732834147407, 7.874983464295892, 7.960003990722824, 8.044798090402306, 8.129369334000634, 8.213721190289045, 8.297857030319102, 8.381780131376381, 8.465493680726777, 8.549000779168823, 8.63230444440422, 8.715407614238028, 8.798313149618993, 8.881023837529822, 8.96354239373645, 9.045871465404714, 9.128013633592293, 9.209971415623135, 9.291747267351225, 9.373343585319954, 9.454762708823006, 9.536006921872278, 9.617078455077952, 9.697979487445515, 9.778712148094254, 9.859278517901398, 9.93968063107587, 10.019920476665334, 10.100000000000001]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha = 0.9\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.10000000000000002, 0.1866065983073615, 0.2687875379522287, 0.3482202253184497, 0.42566996126039236, 0.5015752812467622, 0.5762198777951311, 0.6498019170849886, 0.7224674055842077, 0.7943282347242816, 0.8654727864164495, 0.9359725702851643, 1.0058865869794325, 1.0752643127243295, 1.1441478086740142, 1.2125732532083187, 1.2805720813725667, 1.3481718494401387, 1.415396902536656, 1.4822688982138956, 1.5488072227168737, 1.615029326007673, 1.680950994379646, 1.7465865744991231, 1.8119491591942392, 1.877050742792338, 1.9419023519771343, 2.0065141567879006, 2.0708955653761305, 2.1350553053747965, 2.1990014941549543, 2.2627416997969525, 2.3262829942553256, 2.3896319999231235, 2.452794930585214, 2.5157776275776857, 2.5785855918320895, 2.6412240123714144, 2.70369779173372, 2.766011568724957, 2.8281697388412965, 2.8901764726506776, 2.9520357323812494, 3.0137512869292253, 3.0753267254692584, 3.136765469825624, 3.1980707857415043, 3.259245793165884, 3.320293475662357, 3.381216689031208, 3.4420181692249323, 3.5027005396278432, 3.5632663177620802, 3.6237179214751754, 3.684057674658139, 3.7442878125375394, 3.804410486580383, 3.864427769046398, 3.9243416572187204, 3.984154077340756, 4.043866888284193, 4.103481884970613, 4.163000801566976, 4.222425314473263, 4.281757045118833, 4.340997562582497, 4.4001483860499135, 4.459210987120712, 4.5181867919765555, 4.577077183420477, 4.635883502796819, 4.694607051800361, 4.753249094182494, 4.811810857361607, 4.870293533944303, 4.9286982831635004, 4.987026232238981, 5.045278477665546, 5.103456086433482, 5.1615600971857285, 5.219591521315761, 5.277551344009932, 5.335440525237727, 5.39326000069312, 5.451010682690003, 5.508693461014455, 5.566309203736387, 5.6238587579829575, 5.681342950675977, 5.738762589235352, 5.7961184622505, 5.853411340121522, 5.9106419756718225, 5.967811104733728, 6.024919446708576, 6.081967705102638, 6.138956568040171, 6.195886708754786, 6.252758786060274, 6.309573444801934, 6.36633131628941], [0.0, 0.10717734625362932, 0.19999999999999998, 0.28807935023766545, 0.37321319661472296, 0.4562217682777404, 0.5375750759044573, 0.6175771736067273, 0.6964404506368994, 0.7743213928525987, 0.8513399225207846, 0.9275907650284918, 1.0031505624935244, 1.0780825502457605, 1.152439755590262, 1.2262672585558603, 1.299603834169977, 1.3724831736799834, 1.4449348111684153, 1.5169848390948557, 1.588656469448563, 1.6599704798924833, 1.730945572832899, 1.801598667600098, 1.8719451405703282, 1.9419990242893346, 2.011773173958865, 2.0812794076859045, 2.1505286254486586, 2.2195309106542296, 2.288295617348028, 2.3568314455129373, 2.4251465064166373, 2.493248379592326, 2.561144162745133, 2.6288405156447814, 2.696343698880277, 2.7636596082040747, 2.8307938050733115, 2.8977515438981785, 2.964537796427791, 3.0311572736383, 3.0976144454337464, 3.1639135584251137, 3.230058652015345, 3.2960535729865867, 3.361901988759291, 3.4276073994703355, 3.4931731489982463, 3.5586024350473076, 3.623898318388478, 3.689063731343038, 3.7541014855846755, 3.8190142793268116, 3.883804703954268, 3.9484752501517573, 4.013028313575801, 4.07746620011164, 4.14179113075226, 4.206005246132722, 4.270110610749592, 4.334109216892214, 4.398002988309908, 4.461793783636801, 4.525483399593905, 4.589073573986178, 4.652565988510651, 4.715962271390198, 4.779263999846246, 4.842472702422459, 4.905589861170428, 4.968616913707425, 5.031555255155371, 5.09440623996947, 5.157171183664178, 5.219851364443605, 5.282448024742828, 5.344962372686096, 5.407395583467439, 5.469748800658732, 5.532023137449914, 5.59421967782567, 5.656339477682592, 5.7183835658904965, 5.780352945301355, 5.842248593708987, 5.904071464762499, 5.965822488836184, 6.027502573858451, 6.089112606102152, 6.150653450938516, 6.212125953556753, 6.2735309396512475, 6.334869216078145, 6.396141571483008, 6.457348776901097, 6.518491586331767, 6.579570737288332, 6.640586951324714, 6.7015409345400485, 6.762433378062415, 6.823264958512738], [0.0, 0.11161231740339045, 0.2082759487984821, 0.30000000000000004, 0.3886566631452294, 0.47510010825283816, 0.5598197949220844, 0.6431323589461301, 0.7252589781902133, 0.806362613856686, 0.8865681505652133, 0.965974233415095, 1.0446606759553492, 1.1226933301776152, 1.2001274176432633, 1.277009883781177, 1.3533811081194858, 1.4292761760407522, 1.5047258437402864, 1.579757283376969, 1.6543946674462313, 1.728659633385393, 1.802571657501521, 1.876148359242458, 1.9494057512549654, 2.0223584467479383, 2.095019832868082, 2.167402216752623, 2.239516949418075, 2.3113745315203436, 2.3829847041728445, 2.4543565273615253, 2.5254984479962466, 2.596418359249349, 2.667123652527183, 2.7376212631790393, 2.8079177108554925, 2.878019135273725, 2.947931328022547, 3.017659760938298, 3.0872096114997976, 3.1565857856221857, 3.225792938172988, 3.2948354914868614, 3.3637176521162107, 3.4324434260220418, 3.5010166323817264, 3.56944091616691, 3.6377197596249564, 3.705856492780334, 3.77385430305792, 3.8417162441176997, 3.9094452439796976, 3.9770441125087155, 4.044515548320415, 4.111862145163406, 4.179086397825863, 4.246190707609967, 4.313177387412826, 4.38004866644843, 4.446806694641686, 4.513453546722361, 4.5799912260440285, 4.64642166815062, 4.712746744111004, 4.7789682636400626, 4.845087978023018, 4.911107582858191, 4.9770287206320285, 5.042852983138936, 5.108581913757425, 5.174217009592999, 5.239759723497368, 5.305211465972746, 5.370573606969239, 5.435847477582716, 5.501034371659901, 5.566135547316914, 5.6311522283770135, 5.696085605732786, 5.760936838637683, 5.825707055931401, 5.890397357203263, 5.955008813897453, 6.019542470363701, 6.083999344856686, 6.148380430487268, 6.212686696128391, 6.2769190872783085, 6.341078526883619, 6.405165916124388, 6.46918213516354, 6.533128043862483, 6.597004482464862, 6.6608122722501895, 6.72455221615897, 6.788225099390858, 6.8518316899772795, 6.9153727393298725, 6.978848982765975, 7.04226114001237, 7.105609915688381], [0.0, 0.11486983549970352, 0.21435469250725864, 0.30875580268942826, 0.4, 0.48896638427146427, 0.5761587004753309, 0.6619028257398596, 0.746426393229446, 0.8298971203335551, 0.9124435365554809, 0.9941671660512759, 1.075150151808915, 1.1554602677768562, 1.2351543472134545, 1.3142807056973023, 1.3928809012737988, 1.4709910433277964, 1.5486427857051976, 1.6258640936117552, 1.7026798450415694, 1.779112308942399, 1.8551815300569838, 1.9309056420745292, 2.006301124987049, 2.0813830185046833, 2.1561651004915214, 2.2306600372810075, 2.3048795111805243, 2.3788343293182157, 2.4525345171117205, 2.525989398971818, 2.5992076683399543, 2.6721974487586695, 2.744966347359967, 2.817521501908302, 2.889869622336831, 2.962017027556577, 3.033969678189712, 3.10573320577364, 3.1773129388971264, 3.248713926659391, 3.3199409597849665, 3.3909985896788086, 3.461891145665798, 3.532622750624955, 3.603197335200196, 3.6736186507453414, 3.7438902811406574, 3.8140156536007375, 3.8839980485786696, 3.953840608858586, 4.02354634791773, 4.093118157629643, 4.162558815371809, 4.231870990594006, 4.301057250897318, 4.370120067668355, 4.439061821308459, 4.507884806093482, 4.576591234696056, 4.645183242399031, 4.713662891025875, 4.782032172611323, 4.850293012833275, 4.9184472742249685, 4.986496759184652, 5.054443212798395, 5.122288325490266, 5.1900337355128, 5.257681031289564, 5.3252317536205975, 5.392687397760554, 5.4600494153785775, 5.52731921640815, 5.594498170794518, 5.661587610146624, 5.728588829299978, 5.795503087796357, 5.862331611285747, 5.9290755928555825, 5.995736194291885, 6.0623145472766, 6.128811754525093, 6.195228890867495, 6.261567004277271, 6.327827116850228, 6.394010225736843, 6.460117304030691, 6.5261493016154954, 6.592107145973174, 6.657991742955093, 6.723803977518583, 6.789544714430647, 6.855214798940671, 6.920815057423787, 6.9863462979964925, 7.051809311105988, 7.117204870094616, 7.182533731740694, 7.247796636776957, 7.312994310387754], [0.0, 0.11746189430880191, 0.21919164527704346, 0.3157229337446777, 0.40902607302542915, 0.5, 0.5891598267371476, 0.6768387838420242, 0.7632696410629377, 0.8486239003628652, 0.9330329915368074, 1.0166007296519326, 1.099411111267736, 1.1815334396641957, 1.2630258305525168, 1.3439376897611433, 1.424311513100356, 1.5041842247698687, 1.5835881928903954, 1.6625520137076624, 1.7411011265922482, 1.8192583029947837, 1.8970440399712882, 1.9744768804009738, 2.051573676149883, 2.1283498063019617, 2.204819359621317, 2.2809952882595197, 2.3568895381373514, 2.4325131602477756, 2.5078764062338106, 2.5829888109132666, 2.657859263896684, 2.7324960720358225, 2.806907014119008, 2.8810993889756547, 2.955080057949785, 3.0288554825398024, 3.102431757870407, 3.175814642555673, 3.249009585424942, 3.322021749511282, 3.3948560336427973, 3.467517091927729, 3.5400093513829636, 3.612337027921038, 3.6845041408815673, 3.756514526268356, 3.828371848832582, 3.9000796131245625, 3.971641173621408, 4.043059744024748, 4.11433840581149, 4.185480116110831, 4.256487714972283, 4.327363932082247, 4.398111392980194, 4.468732624820025, 4.539230061717271, 4.609606049718538, 4.67986285142582, 4.750002650305015, 4.820027554705012, 4.889939601611176, 4.95974076015468, 5.029432934897161, 5.099017968908318, 5.168497646652402, 5.237873696698212, 5.307147794265748, 5.376321563621647, 5.445396580334382, 5.5143743733993, 5.583256427242724, 5.652044183613544, 5.72073904337007, 5.789342368169244, 5.857855482064776, 5.926279673020232, 5.994616194342614, 6.062866266041593, 6.131031076119103, 6.1991117817937, 6.267109510663723, 6.33502536181304, 6.402860406862832, 6.47061569097268, 6.538292233793947, 6.605891030378239, 6.673413052043583, 6.740859247200692, 6.808230542141636, 6.875527841792967, 6.942752030435316, 7.009903972391274, 7.076984512683278, 7.143994477663125, 7.210934675614597, 7.2778058973306505, 7.344608916666443, 7.411344491069478, 7.478013362088023], [0.0, 0.11962311988513157, 0.2232246348067809, 0.32153203876088804, 0.41655189759696426, 0.5091996880735121, 0.6000000000000001, 0.689292195216828, 0.7773133262904589, 0.8642380507129963, 0.9502002165056764, 1.035305548868138, 1.1196395898441691, 1.2032729178508645, 1.2862647178922604, 1.3686653048332214, 1.4505179563804267, 1.5318602761158295, 1.6127252277133721, 1.6931419335718623, 1.7731363011304266, 1.852731520820182, 1.9319484668301905, 2.0108060232170746, 2.0893213519106983, 2.1675101149605576, 2.2453866603552304, 2.3229641785577964, 2.4002548352865265, 2.4772698848657613, 2.554019767562354, 2.6305141936288146, 2.706762216238972, 2.7827722950854756, 2.8585523520815044, 2.9341098203503795, 3.0094516874805732, 3.084584533858029, 3.159514566753938, 3.234247650737282, 3.308789334892463, 3.3831448772491357, 3.457319266770786, 3.531317243198343, 3.605143315003042, 3.678801775667581, 3.752296718484916, 3.8256320500389283, 3.8988115025099317, 3.9718386449297824, 4.044716893495877, 4.11744952103995, 4.1900396657361645, 4.262490339123045, 4.334804433505246, 4.406984728793694, 4.47903389883615, 4.550954517284568, 4.622749063040687, 4.694419925316907, 4.765969408345689, 4.837399735767338, 4.9087130547230515, 4.97991143967745, 5.050996895992493, 5.121971363272567, 5.192836718498698, 5.263594778968169, 5.334247305054366, 5.4047960028002935, 5.4752425263580795, 5.545588480285674, 5.615835421710985, 5.6859848623728535, 5.75603827054745, 5.825997072868003, 5.895862656045094, 5.965636368494194, 6.035319521876595, 6.104913392559367, 6.174419222999597, 6.243838223057713, 6.313171571244372, 6.382420415905018, 6.451585876345977, 6.520669043905589, 6.589670982973724, 6.658592731962689, 6.727435304232422, 6.796199688972594, 6.864886852044084, 6.933497736782158, 7.002033264763453, 7.070494336538812, 7.13888183233382, 7.207196612718803, 7.275439519249913, 7.34361137508285, 7.411712985560669, 7.479745138776977, 7.547708606115841, 7.615604142769555], [0.0, 0.1214814044039067, 0.2266923163341395, 0.32652687596705116, 0.4230228201353009, 0.5171098470646901, 0.6093206958014116, 0.7000000000000001, 0.7893884947183534, 0.8776635506641641, 0.9649610951198176, 1.0513884956723267, 1.13703262321776, 1.221965152573139, 1.3062461881515304, 1.3899268264337157, 1.4730510174236051, 1.5556569488557326, 1.6377780964780029, 1.719444035090924, 1.8006810745925546, 1.8815127656656008, 1.9619603067690696, 2.0420428753138284, 2.1217778998316206, 2.2011812856739406, 2.2802676037180944, 2.359050249334318, 2.4375415772291475, 2.515753016557147, 2.593695169769421, 2.6713778979623304, 2.7488103949461684, 2.8260012518306215, 2.902958513591773, 2.979689728822746, 3.056201993660658, 3.132501990714411, 3.208596023682008, 3.284490048235535, 3.3601896996616083, 3.435700317670707, 3.511026968727335, 3.586174466201894, 3.6611473886024344, 3.7359500961087306, 3.8105867456009697, 3.885061304349833, 3.9593775625131635, 4.033539144565917, 4.107549519774386, 4.181412011812085, 4.255129807603121, 4.328705965468747, 4.4021434226441, 4.475445002224614, 4.548613419594919, 4.621651288387349, 4.6945611260121245, 4.767345358796847, 4.840006326769061, 4.912546288112198, 4.984967423322202, 5.057271839089455, 5.129461571928193, 5.201538591573574, 5.273504804164575, 5.345362055229269, 5.417112132487551, 5.488756768484937, 5.560297643069971, 5.631736385726597, 5.7030745777719165, 5.774313754428866, 5.845455406782543, 5.916500983628198, 5.987451893218258, 6.0583095049151465, 6.129075150756148, 6.199750126936048, 6.270335695212874, 6.340833084241623, 6.411243490840518, 6.4815680811939655, 6.551807991996149, 6.6219643315387975, 6.692038180746534, 6.762030594162878, 6.8319426008898, 6.901775205483529, 6.971529388809104, 7.041206108856027, 7.11080630151716, 7.180330881332947, 7.249780742202831, 7.319156758065661, 7.388459783550739, 7.457690654601071, 7.526850189070306, 7.595939187294688, 7.664958432641344, 7.7339086920340945], [0.0, 0.12311444133449163, 0.229739670999407, 0.330916275726621, 0.4287093850145173, 0.5240611947344789, 0.6175116053788564, 0.7094098834057659, 0.8, 0.889461710208793, 0.9779327685429285, 1.0655219858986698, 1.152317400950662, 1.2383916520183136, 1.323805651479719, 1.4086111826898404, 1.492852786458892, 1.5765691638673067, 1.6597942406671102, 1.7425579892237029, 1.8248870731109619, 1.9068053595961343, 1.9883343321025517, 2.0694934258370825, 2.1503003036178296, 2.2307710846070057, 2.3109205355537124, 2.390762231898002, 2.470308694426909, 2.5495715059335846, 2.6285614113946045, 2.707288404465995, 2.7857618025475976, 2.863990312236728, 2.941982086655593, 3.0197447758707177, 3.0972855714103953, 3.174611245715771, 3.2517281872235104, 3.328642431665956, 3.4053596900831384, 3.481885373965613, 3.5582246178847976, 3.6343822999157434, 3.710363060113967, 3.786171317271792, 3.8618112841490584, 3.9372869813472398, 4.0126022499740985, 4.087760763227285, 4.162766037009366, 4.237621439672972, 4.312330200983042, 4.386895420372896, 4.461320074562014, 4.53560702459583, 4.6097590223610485, 4.683778716624253, 4.757668658636431, 4.831431307341558, 4.905069034223441, 4.978584127821574, 5.051978797943636, 5.12525517959959, 5.198415336679909, 5.271461265398287, 5.344394897517339, 5.417218103374001, 5.489932694719933, 5.562540427390725, 5.635043003816604, 5.707442075386164, 5.779739244673661, 5.851936067539561, 5.924034055113154, 5.996034675665398, 6.067939356379424, 6.139749485025567, 6.2114664115472795, 6.283091449563692, 6.354625877794253, 6.42607094141039, 6.497427853318782, 6.568697795380492, 6.639881919569933, 6.7109813490772545, 6.781997179357618, 6.852930479130442, 6.923782291331596, 6.994553634021251, 7.06524550124991, 7.135858863885029, 7.206394670400391, 7.276853847630322, 7.347237301490681, 7.417545917668406, 7.487780562281314, 7.557942082509736, 7.628031307201475, 7.6980490474514465, 7.767996097157338, 7.837873233552495], [0.0, 0.12457309396155175, 0.23246161304788485, 0.3348369522101714, 0.43378870847907947, 0.5302702408070094, 0.6248278463954464, 0.7178149297908671, 0.8094783527342472, 0.9000000000000001, 0.9895192582062144, 1.0781462274342235, 1.1659699894356885, 1.2530640431445341, 1.3394900226251123, 1.4253003247585148, 1.5105400180718433, 1.5952482621736461, 1.6794593847662536, 1.763203713325881, 1.8465082273348536, 1.9293970768383906, 2.011891999794154, 2.094012661676194, 2.1757769345706404, 2.2572011286185862, 2.338300185524704, 2.4190878415700583, 2.4995767658872285, 2.5797786785016146, 2.65970445169564, 2.7393641975295773, 2.8187673437952703, 2.8979227002452856, 2.9768385165995404, 3.055522533562096, 3.1339820278660473, 3.212223852192023, 3.2902544706665084, 3.3680799905328462, 3.4457061904951316, 3.52313854615894, 3.6003822529297898, 3.6774422466778756, 3.7543232224338183, 3.831029651343531, 3.907565796079384, 3.9839357248787, 4.060143324358458, 4.136192311236139, 4.212086243070515, 4.287828528122257, 4.363422434422373, 4.43887109812608, 4.514177531220859, 4.58934462864964, 4.664375174903318, 4.7392718501309075, 4.814037235810467, 4.888673820019393, 4.963184002338695, 5.0375700984223455, 5.1118343442596945, 5.18597890015618, 5.260005854455123, 5.333917227021244, 5.4077149725045635, 5.481400983401661, 5.554977092929723, 5.628445077727374, 5.701806660395136, 5.775063511887156, 5.848217253764896, 5.921269460322565, 5.994221660593222, 6.067075340243815, 6.139831943366654, 6.212492874174298, 6.285059498604246, 6.357533145839312, 6.429915109749139, 6.502206650257869, 6.574408994642629, 6.6465233387671026, 6.7185508482542255, 6.7904926596016395, 6.862349881243393, 6.934123594561031, 7.005814854847065, 7.07742469222358, 7.148954112518534, 7.220404098102162, 7.2917756086857075, 7.363069582084577, 7.434286934947865, 7.505428563456076, 7.576495343988741, 7.647488133763533, 7.718407771448395, 7.789255077748046, 7.860030855966229, 7.9307358925449005], [0.0, 0.12589254117941673, 0.2349237886176038, 0.33838346190164986, 0.4383832905540869, 0.5358867312681466, 0.6314458674893553, 0.72541784693722, 0.8180521460508584, 0.9095325760829622, 1.0, 1.089565684035974, 1.1783196534742955, 1.2663361857313113, 1.3536775676840485, 1.440396751188327, 1.5265392821258754, 1.612144734874072, 1.6972478007257303, 1.781879128378148, 1.8660659830736148, 1.9498327706486203, 2.0332014593038656, 2.11619192280521, 2.198822222535472, 2.2811088413887024, 2.3630668793283913, 2.4447102181268754, 2.5260516611050337, 2.6071030524238594, 2.6878753795222865, 2.7683788615650142, 2.848623026200712, 2.9286167764926536, 3.0083684495397374, 3.087885868033636, 3.167176385780791, 3.246246928043719, 3.3251040274153247, 3.4037538558253537, 3.4822022531844965, 3.560454753094581, 3.6385166059895675, 3.71639280001916, 3.794088079942576, 3.8716069642629933, 3.9489537608019476, 4.026132580886519, 4.103147352299767, 4.180001831125719, 4.256699612603923, 4.333244141094503, 4.409638719242634, 4.485886516420912, 4.5619905765190385, 4.637953825142459, 4.713779076274703, 4.789469038452256, 4.865026320495551, 4.940453436835082, 5.015752812467621, 5.0909267875739745, 5.165977621826533, 5.240907498412152, 5.315718527793368, 5.390412751228802, 5.464992144071645, 5.5394586188633275, 5.613814028238016, 5.6880601676520515, 5.76219877795131, 5.8362315477882705, 5.910160115899569, 5.983986073253948, 6.057710965079605, 6.131336292779301, 6.204863515740814, 6.278294053049772, 6.351629285111345, 6.42487055518672, 6.498019170849885, 6.571076405369786, 6.644043499022564, 6.716921660338192, 6.7897120672855955, 6.862415868399916, 6.935034183855459, 7.0075681064874935, 7.080018702765927, 7.152387013723643, 7.224674055842076, 7.296880821896485, 7.369008281763135, 7.441057383190539, 7.513029052536711, 7.5849241954742785, 7.656743697665164, 7.7284884254064785, 7.800159226249126, 7.871756929590527, 7.943282347242816, 8.014736273977748], [0.0, 0.12709816152101408, 0.23717355572556018, 0.3416240191348806, 0.44258150442408223, 0.5410186949091713, 0.6374929611084903, 0.7323648709962455, 0.8258862901433245, 0.918242790086096, 1.009576582776887, 1.1, 1.1896039291734248, 1.2784633590373347, 1.3666411729641899, 1.4541908299076411, 1.5411583119233234, 1.6275835723759162, 1.7135016347822698, 1.7989434413494687, 1.8839365184276522, 1.9685055055778238, 2.0526725813809765, 2.136457809925734, 2.2198794255612415, 2.30295406903135, 2.3856969849055996, 2.468122187896269, 2.550242603936299, 2.632070190613271, 2.713616040588238, 2.794890470890576, 2.8759031004112696, 2.9566629174745156, 3.0371783390201297, 3.11745726265444, 3.197507112608222, 3.2773348804643447, 3.356947161375628, 3.4363501863778136, 3.51554985130798, 3.594551742760952, 3.6733611614519046, 3.7519831432999706, 3.830422478502946, 3.9086837288358303, 3.9867712433743665, 4.064689172818101, 4.142441482564831, 4.220031964669034, 4.297464248800368, 4.374741812304155, 4.451867989453627, 4.528845979973138, 4.605678856902451, 4.682369573864316, 4.758920971790605, 4.835335785156332, 4.911616647765511, 4.987766098128288, 5.063786584464621, 5.139680469366248, 5.215450034145501, 5.291097482896705, 5.366624946293412, 5.442034485142532, 5.517328093714384, 5.592507702866012, 5.667575182973486, 5.742532346687485, 5.817380951525238, 5.892122702310744, 5.966759253474137, 6.041292211220203, 6.115723135575146, 6.190053542320034, 6.2642849048185925, 6.338418655746441, 6.412456188728314, 6.48639885988925, 6.560247989325327, 6.634004862499059, 6.707670731564191, 6.781246816624286, 6.854734306929185, 6.92813436201307, 7.001448112777692, 7.074676662523944, 7.147821087934873, 7.220882440012899, 7.293861744973876, 7.366760005100456, 7.439578199557005, 7.512317285168229, 7.584978197163486, 7.657561849888651, 7.730069137487263, 7.802500934552596, 7.8748580967522, 7.947141461426284, 8.019351848161373, 8.091490059340416], [0.0, 0.12820888539868155, 0.2392462397702631, 0.34460950649911054, 0.4464492696135618, 0.5457467128089485, 0.643064077521776, 0.7387650827667823, 0.8331037951939285, 0.9262674080682846, 1.0183993761470242, 1.1096130128934416, 1.2000000000000004, 1.2896359815411698, 1.378584390433656, 1.4668991528143929, 1.5546266525809178, 1.6418071922544648, 1.7284761014259926, 1.8146645927097094, 1.9004004330113529, 1.9857084772195788, 2.070611097736276, 2.155128533992198, 2.2392791796883382, 2.323079820993716, 2.406545835701729, 2.4896913610006655, 2.5725294357845208, 2.6550721221394613, 2.7373306096664427, 2.8193153055564197, 2.9010359127608534, 2.9825014981538276, 3.063720552231659, 3.1447010416186676, 3.2254504554267442, 3.3059758463389173, 3.3862838671437245, 3.4663808033305687, 3.5462726022608533, 3.6259648993512283, 3.7054630416403636, 3.784772109056805, 3.8638969336603806, 3.942842117091907, 4.021612046434148, 4.100210908660039, 4.178642703821397, 4.2569112571118515, 4.335020229921115, 4.412973129983389, 4.490773320710461, 4.568424029789405, 4.645928357115593, 4.723289282123785, 4.800509670573054, 4.877592280835265, 4.9545397697315225, 5.031354697956269, 5.108039535124708, 5.18459666447551, 5.261028387257629, 5.337336926827198, 5.413524432477944, 5.489592983026377, 5.565544590170951, 5.64138120164267, 5.717104704163009, 5.792716926223587, 5.86821964070076, 5.943614567317156, 6.018903374961146, 6.094087683874301, 6.169169067716058, 6.244149055514049, 6.319029133507876, 6.39381074689346, 6.468495301474563, 6.543084165227541, 6.617578669784926, 6.691980111843021, 6.7662897544982705, 6.84050882851685, 6.914638533541573, 6.988680039239914, 7.062634486396687, 7.136502987954647, 7.210286630006084, 7.283986472738236, 7.357603551335162, 7.431138876838566, 7.504593436969832, 7.577968196915453, 7.651264100077856, 7.724482068793475, 7.797623005019863, 7.870687790993456, 7.943677289859565, 8.016592346276008, 8.089433786991753, 8.162202421401865], [0.0, 0.1292392220780832, 0.24116891599880752, 0.34737892309229296, 0.4500371103201128, 0.550132546553009, 0.6482319916192733, 0.7447020875217089, 0.8397989426891102, 0.93371125474474, 1.026583631304232, 1.1185302964621298, 1.2096436687007865, 1.3, 1.3896632330481709, 1.4786877273537313, 1.5671202395733368, 1.6550013961150232, 1.742366810492142, 1.8292479461556592, 1.915672793157013, 2.0016664061284524, 2.087251337265226, 2.172447988650058, 2.2572749018029072, 2.3417489977930037, 2.4258857779956995, 2.509699493211249, 2.5932032871192927, 2.676409318741633, 2.7593288676032297, 2.841972424531288, 2.9243497704539774, 3.006470045110323, 3.088341807229586, 3.169973087458991, 3.2513714350958574, 3.332543959501329, 3.413497366928351, 3.494237993378973, 3.574771834009919, 3.6551045695262476, 3.73524158993752, 3.815188015996572, 3.894948718595551, 3.9745283363558577, 4.053931291616567, 4.133161804998762, 4.21222390870024, 4.29112145865538, 4.369858145678253, 4.448437505692583, 4.5268629291398454, 4.605137669646071, 4.683264852018602, 4.761247479636099, 4.839088441287993, 4.916790517513506, 4.99435638648499, 5.071788629475631, 5.149089735947425, 5.22626210829168, 5.303308066251083, 5.380229851049526, 5.457029629253301, 5.5337094963851, 5.61027148031017, 5.68671754441224, 5.763049590575221, 5.839269461985202, 5.915378945766064, 5.991379775460802, 6.067273633369621, 6.14306215275499, 6.218746919922885, 6.294329476188803, 6.369811319736349, 6.4451939073756, 6.520478656207908, 6.59566694520322, 6.67076011669559, 6.745759477802075, 6.820666301769859, 6.895481829256033, 6.970207269544211, 7.044843801701771, 7.119392575681318, 7.193854713369652, 7.268231309587324, 7.34252343304165, 7.416732127235832, 7.490858411336703, 7.5649032810033585, 7.63886770917891, 7.712752646847331, 7.786559023757316, 7.860287749114898, 7.933939712246509, 8.007515783234037, 8.081016813523295, 8.154443636507333, 8.227797068085827], [0.0, 0.13020054543174678, 0.24296280880781337, 0.3499628404663651, 0.453384632668279, 0.5542246113001359, 0.6530537519341022, 0.7502414237754053, 0.8460456402706018, 0.9406565026372284, 1.0342196941293802, 1.126850288477554, 1.2186413916028231, 1.3096698226720027, 1.4, 1.4896866874389445, 1.5787769894367065, 1.6673118345937534, 1.755327101328328, 1.842854487126775, 1.929922190239635, 2.016555451663658, 2.1027769913446535, 2.1886073631226695, 2.2740652464355198, 2.3591676882168486, 2.443930305146278, 2.5283674540261476, 2.6124923763030607, 2.6963173214415774, 2.779853652867431, 2.863111939442011, 2.94610203484721, 3.0288331468064036, 3.1113138977114647, 3.1935523779441826, 3.2755561929560053, 3.3573325049898153, 3.4388880701818474, 3.520229271663396, 3.6013621491851087, 3.6822924257069753, 3.763025531331201, 3.8435666249004465, 3.9239206135381384, 4.004092170369251, 4.084085750627656, 4.163905606328788, 4.243555799663241, 4.32304021524709, 4.402362571347881, 4.481526430190685, 4.560535207436188, 4.639392180911947, 4.718100498668635, 4.796663186425023, 4.875083154458295, 4.953363203990229, 5.031506033114293, 5.109514242304023, 5.187390339538841, 5.265136745079824, 5.34275579592466, 5.420249749968192, 5.497620789892336, 5.574871026806963, 5.652002503661242, 5.72901719844319, 5.805917027183544, 5.8827038467786155, 5.959379457645492, 6.035945606221825, 6.112403987321315, 6.188756246355169, 6.265003981428821, 6.3411487453225766, 6.417192047364015, 6.493135355199442, 6.568980096471069, 6.644727660406071, 6.720379399323217, 6.795936630062328, 6.871400635341413, 6.946772665045974, 7.02205393745467, 7.097245640405166, 7.172348932403788, 7.247364943682295, 7.322294777204869, 7.397139509628217, 7.47190019221746, 7.546577851720323, 7.621173491201938, 7.695688090842485, 7.770122608699665, 7.844477981437944, 7.918755125026326, 7.992954935406344, 8.067078289131834, 8.141126043981943, 8.21509903954877, 8.288998097800915], [0.0, 0.131101942303975, 0.24464487484832742, 0.35238568292640576, 0.4565234788877656, 0.5580615870169522, 0.6575749358311305, 0.7554354517310079, 0.851902934426885, 0.9471688012340329, 1.0413797439924106, 1.1346516331042984, 1.227078219076288, 1.3187368529051988, 1.4096923988830834, 1.5, 1.5897070868146024, 1.6788548712818738, 1.767479480211443, 1.8556128305358557, 1.943283315726147, 2.0305163515260727, 2.1173348151748552, 2.203759402809697, 2.2898089231888132, 2.3755005412641914, 2.4608499818319447, 2.5458717010885956, 2.6305790321531637, 2.7149843092949912, 2.7990989746104225, 2.882933670130576, 2.9664983177557835, 3.0498021889557982, 3.132853965816537, 3.2156617947306505, 3.2982333338032084, 3.3805757948623176, 3.4626959808179043, 3.5446003189925874, 3.6262948909510664, 3.7077854592741963, 3.7890774916575505, 3.870176182659191, 3.9510864733752564, 4.03181306928343, 4.1123604564618, 4.192732916363107, 4.272934539301069, 4.352969236785509, 4.432840752826067, 4.512552674309607, 4.592108440543916, 4.671511352049416, 4.750764578671186, 4.829871167075475, 4.908834047687732, 4.987656041122987, 5.0663398641539965, 5.144888135257743, 5.223303379776745, 5.301588034727891, 5.379744453288238, 5.457774908984352, 5.5356815996091715, 5.613466650888076, 5.691132119913865, 5.7686799983684445, 5.8461122155475085, 5.923430641202922, 6.000637088216317, 6.07773331511618, 6.154721028449649, 6.231601885019346, 6.308377493994618, 6.385049418905885, 6.461619179530018, 6.538088253674046, 6.614458078863951, 6.690730053944724, 6.766905540597429, 6.842985864778558, 6.918972318086557, 6.994866159060065, 7.070668614412055, 7.14638088020376, 7.222004122962014, 7.297539480743327, 7.372988064147861, 7.448350957286169, 7.523629218701432, 7.598823882249692, 7.673935957940447, 7.7489664327398, 7.8239162713382235, 7.898786416884845, 7.973577791690053, 8.048291297898107, 8.122927818131355, 8.197488216107468, 8.271973337231158, 8.346384009161634], [0.0, 0.1319507910772894, 0.24622888266898324, 0.3546672826451353, 0.45947934199881396, 0.561674881261479, 0.6618325514532419, 0.7603266870952656, 0.8574187700290345, 0.953301456943931, 1.0481223894689577, 1.1419981882351644, 1.2350232107577128, 1.327275308859708, 1.4188197668115317, 1.5097120846388332, 1.5999999999999999, 1.6897249916860118, 1.7789234204175859, 1.8676274097805683, 1.9558655370858569, 2.04366338263711, 2.1310439717973395, 2.218028134705505, 2.304634801901323, 2.3908812494750924, 2.4767833040366267, 2.5623555153823174, 2.647611302959438, 2.732563080898309, 2.8172223653796804, 2.901599867338876, 2.9857055729177837, 3.0695488136163567, 3.153138327734613, 3.2364823144108414, 3.31958848133422, 3.4024640870274463, 3.485115978447405, 3.5675506245318482, 3.649774146221923, 3.7317923434096003, 3.8136107191922677, 3.895234501761313, 3.9766686642051026, 4.057917942467986, 4.138986851674164, 4.2198797009976, 4.300600607235659, 4.3811535072241075, 4.461542169214011, 4.541770203316331, 4.621841071107424, 4.701758094477666, 4.781524463796003, 4.861143245455007, 4.940617388853818, 5.01994973287017, 5.099143011867168, 5.1781998612757105, 5.257122822789208, 5.335914349203559, 5.41457680893199, 5.493112490221523, 5.571523605095194, 5.649812293041871, 5.727980624473455, 5.806030603967443, 5.883964173311185, 5.961783214362669, 6.039489551741435, 6.117084955361956, 6.194571142820789, 6.271949781647893, 6.349222491431542, 6.4263908458255825, 6.50345637444702, 6.580420564671275, 6.657284863331911, 6.734050678331054, 6.810719380166277, 6.88729230337927, 6.963770747931224, 7.040155980509465, 7.116449235769595, 7.192651717517013, 7.268764599831487, 7.344789028138131, 7.420726120227934, 7.496576967230768, 7.572342634543583, 7.648024162716356, 7.723622568298115, 7.799138844645297, 7.874573962694478, 7.949928871701413, 8.025204499948195, 8.10040175542022, 8.17552152645457, 8.250564682361249, 8.325532074018732, 8.400424534445088], [0.0, 0.13275316748885194, 0.24772616999622069, 0.3568239704468836, 0.462273378947059, 0.5650903566217397, 0.6658570731961942, 0.764950139473428, 0.8626326273336055, 0.9590983649875663, 1.0544958918547662, 1.1489425377218627, 1.2425332338803763, 1.335346305560702, 1.4274474340187813, 1.5188924567690427, 1.6097294017566597, 1.7000000000000002, 1.7897408333248195, 1.8789842206565088, 1.9677589130810524, 2.0560906464527666, 2.144002586149042, 2.2315156889743326, 2.3186490005826217, 2.405419902117972, 2.491844316429851, 2.5779368817901593, 2.6637110992481663, 2.749179458422981, 2.834353545523822, 2.919244136617882, 3.0038612785715433, 3.0882143596284513, 3.1723121712251454, 3.256162962357858, 3.33977448758527, 3.4231540495682564, 3.5063085368991977, 3.5892444578526557, 3.671967970590462, 3.754484910273012, 3.836800813461346, 3.918920940138836, 4.000850293634584, 4.0825936386916295, 4.164155517890083, 4.2455402666074615, 4.326752026674866, 4.407794758867471, 4.488672254350612, 4.569388145187888, 4.64994591400507, 4.7303489028925405, 4.810600321619483, 4.890703255224822, 4.970660671042629, 5.050475425213501, 5.130150268727868, 5.209687853042355, 5.289090735306096, 5.3683613832301385, 5.447502179629734, 5.526515426666454, 5.605403349814372, 5.68416810157232, 5.76281176494212, 5.841336356690856, 5.919743830413644, 5.998036079411821, 6.076214939400211, 6.154282191055915, 6.232239562419985, 6.310088731162422, 6.387831326720015, 6.465468932315805, 6.54300308686821, 6.6204352867971945, 6.697766987734339, 6.774999606143047, 6.852134520854718, 6.929173074526224, 7.00611657502366, 7.082966296736919, 7.159723481829393, 7.236389341426669, 7.312965056747953, 7.389451780183545, 7.465850636321582, 7.54216272292696, 7.618389111875181, 7.694530850043673, 7.770588960162975, 7.84656444163, 7.9224582712854685, 7.998271404157444, 8.074004774172789, 8.149659294838242, 8.225235859892756, 8.300735343932498, 8.376158603010033, 8.45150647520891], [0.0, 0.1335141362540313, 0.24914618792310345, 0.3588693596553947, 0.46492322609576964, 0.5683295720696824, 0.6696739044203427, 0.7693349927622039, 0.8675774169581589, 0.9645961162826638, 1.0605404816140187, 1.1555285152976196, 1.2496556927908928, 1.3430007883007444, 1.435629859581734, 1.5275990642205364, 1.6189567054684944, 1.709744753554853, 1.8, 1.8897549489881291, 1.9790385164124287, 2.067876585650484, 2.1562924548684475, 2.244307200999534, 2.3319399788713766, 2.4192082692603707, 2.5061280862890682, 2.592714152138989, 2.678980045250224, 2.764938326834978, 2.850600649517029, 2.935977851134229, 3.0210800361436867, 3.1059166466044137, 3.190496524347292, 3.2748279656535146, 3.358918769532507, 3.442776280505514, 3.5264074266517618, 3.609818753552594, 3.693016454669707, 3.776006398611849, 3.8587941536767807, 3.9413850099991916, 4.023783999588307, 4.105995914499664, 4.188025323352388, 4.269876586375281, 4.351553869141281, 4.4330611551295505, 4.514402257237172, 4.595580828347489, 4.676600371049407, 4.7574642465908665, 4.838175683140116, 4.9187377834201635, 4.999153531774457, 5.079425800715587, 5.159557357003229, 5.239550867292712, 5.31940890339128, 5.399133947155412, 5.4787283950591545, 5.558194562460546, 5.6375346875905405, 5.716750935286542, 5.795845400490571, 5.87482011153024, 5.95367703319908, 6.032418069651222, 6.111045067124192, 6.189559816502302, 6.267964055732094, 6.346259472100322, 6.424447704384046, 6.502530344881673, 6.580508941333016, 6.658384998735835, 6.736159981065692, 6.813835312905452, 6.891412380990263, 6.968892535673388, 7.0462770923178795, 7.123567332618701, 7.20076450585958, 7.277869830108531, 7.354884493355751, 7.431809654597283, 7.508646444867637, 7.585395968224325, 7.662059302687061, 7.738637501134194, 7.815131592158767, 7.891542580886443, 7.967871449757398, 8.044119159274114, 8.120286648716915, 8.196374836828955, 8.272384622472279, 8.348316885256427, 8.424172486141028, 8.499952268013708], [0.0, 0.13423796509621047, 0.2504969003030616, 0.36081492137927623, 0.4674437445209259, 0.571410694021778, 0.673304450971248, 0.7735058384320546, 0.8722808706510533, 0.9698255437396259, 1.0662900584785258, 1.1617930569469137, 1.2564305322095026, 1.3502816855369133, 1.4434129328068925, 1.5358807360568798, 1.6277336604077663, 1.7190139036247216, 1.8097584566883882, 1.9000000000000001, 1.9897676062163525, 2.0790872990382634, 2.1679825029397426, 2.2564744091197513, 2.3445822762512307, 2.4323236798802417, 2.519714720947738, 2.6067702014495553, 2.6935037734394633, 2.77992806622858, 2.8660547956138087, 2.9518948581888735, 3.037458413190832, 3.122754953867543, 3.2077933699846786, 3.292582002800599, 3.3771286936060054, 3.4614408267394716, 3.545525367839868, 3.629388897974524, 3.713037644182151, 3.7964775068873657, 3.879714084575703, 3.962752696061602, 4.045598400634647, 4.128256016329855, 4.210730136534503, 4.293025145115784, 4.375145230229727, 4.457094396951388, 4.538876478848955, 4.620495148609386, 4.7019539278104, 4.783256195922484, 4.864405198614969, 4.945404055431855, 5.026255766895804, 5.106963221092345, 5.187529199780768, 5.267956384073313, 5.34824735971993, 5.428404622032146, 5.508430580476169, 5.588327562962438, 5.668097819856173, 5.74774352773115, 5.827266792886838, 5.906669654647151, 5.985954088457483, 6.065122008795079, 6.144175271906592, 6.223115678385372, 6.301944975600002, 6.380664859984636, 6.459276979200738, 6.537782934179148, 6.616184281050543, 6.694482532971822, 6.772679161855293, 6.850775600007006, 6.928773241680105, 7.0066734445486105, 7.084477531106638, 7.162186789997687, 7.239802477278309, 7.31732581762011, 7.394758005453812, 7.472100206058801, 7.549353556601337, 7.626519167124431, 7.703598121492135, 7.780591478290836, 7.857500271689953, 7.934325512264305, 8.011068187780232, 8.087729263947454, 8.164309685138472, 8.240810375077283, 8.317232237498994, 8.393576156781823, 8.469842998552984, 8.546033610269694], [0.0, 0.13492828476735633, 0.25178508235883346, 0.3626704146273491, 0.4698475772352076, 0.5743491774985174, 0.6767669238032996, 0.7774835975975269, 0.8767665811081738, 0.9748128783579909, 1.0717734625362931, 1.1677675858399605, 1.2628917349787108, 1.35722551851625, 1.45083569387444, 1.5437790134471407, 1.6361042921017168, 1.7278539446056385, 1.8190651521659245, 1.9097707632429999, 2.0, 2.089779019964806, 2.179131368071948, 2.268078344496276, 2.3566393069485905, 2.4448319213573213, 2.5326723714626227, 2.6201755353796976, 2.707355135368097, 2.7942238656852587, 2.880793502376654, 2.9670749980718165, 3.053078564251751, 3.1388137429834084, 3.224289469748144, 3.309514128699297, 3.3944956014514607, 3.4792413103172213, 3.5637582567562958, 3.648053055679198, 3.7321319661472296, 3.8160009189279815, 3.89966554129724, 3.983131179421485, 4.06640291860773, 4.149485601667775, 4.23238384561042, 4.315102056846927, 4.397644445070945, 4.480015035953658, 4.562217682777405, 4.644256077115961, 4.726133758656783, 4.807854124249311, 4.88942043625375, 4.970835830256378, 5.052103322210067, 5.133225815052345, 5.214206104847719, 5.295046886496065, 5.375750759044573, 5.456320230636926, 5.5367577231300285, 5.617065576405615, 5.697246052401424, 5.777301338884279, 5.857233552985307, 5.937044744515661, 6.016736899079474, 6.0963119409992075, 6.175771736067273, 6.255118094136584, 6.334352771561581, 6.41347747350034, 6.492493856087438, 6.571403528486511, 6.6502080548306495, 6.728908956058172, 6.807507711650707, 6.886005761279947, 6.964404506368993, 7.042705311573714, 7.120909506189162, 7.199018385485691, 7.277033211979136, 7.354955216638981, 7.43278560003832, 7.510525533448996, 7.588176159885152, 7.665738595098206, 7.743213928525987, 7.820603224198668, 7.897907521603895, 7.975127836513372, 8.052265161773036, 8.129320468058776, 8.206294704599534, 8.283188799869565, 8.360003662251438, 8.436740180671299, 8.513399225207847, 8.58998164767636], [0.0, 0.1355882106693847, 0.2530165476359577, 0.36444421321172016, 0.4721455726981855, 0.5771582838300289, 0.6800769490024186, 0.7812862218237332, 0.8810547922708946, 0.9795806279011533, 1.0770154403043632, 1.1734790649325293, 1.269068460405903, 1.363863624648756, 1.4579316415893748, 1.5513295411940704, 1.6441063770807063, 1.7363047714647597, 1.8279620874042346, 1.9191113340193462, 2.0097818763970237, 2.1, 2.1897893649196267, 2.2791713755085907, 2.36816548415506, 2.4567894431904294, 2.545059515508525, 2.632990651992493, 2.720596642016606, 2.8078902419251324, 2.894883285359453, 2.9815867785177357, 3.0680109828247075, 3.1541654870169804, 3.240059270278795, 3.3257007577698676, 3.4110978696532803, 3.4962580645436927, 3.5811883781445273, 3.6658954577194174, 3.7503855929423464, 3.834664743587923, 3.9187385644545913, 4.002612427856601, 4.08629144397289, 4.169780479301147, 4.253084173431681, 4.336206954327237, 4.419153052270816, 4.501926512622911, 4.584531207512027, 4.666970846567199, 4.749248986788274, 4.8313690416384745, 4.913334289434008, 4.995147881097111, 5.076812847331493, 5.1583321052727715, 5.239708464660833, 5.32094463357614, 5.402043223777663, 5.483006755676262, 5.563837662973991, 5.644538296996803, 5.725110930745435, 5.805557762686942, 5.885880920307208, 5.966082463442887, 6.046164387409578, 6.126128625941485, 6.205977053956494, 6.285711490159399, 6.365333699494861, 6.444845395460778, 6.52424824229178, 6.603543857021822, 6.682733811434073, 6.761819633905666, 6.840802811154283, 6.919684789892964, 6.998466978399082, 7.0771507480029525, 7.155737434501129, 7.234228339499053, 7.312624731687444, 7.390927848056385, 7.4691388950508975, 7.547259049671441, 7.625289460522572, 7.703231248812779, 7.781085509308263, 7.8588533112433065, 7.936535699189622, 8.014133693886992, 8.091648293037299, 8.169080472063948, 8.246431184838505, 8.323701364376333, 8.400891923502844, 8.478003755491864, 8.555037734677597, 8.631994717041495], [0.0, 0.1362204366553743, 0.25419632304202816, 0.36614355787375585, 0.4743471114511204, 0.5798494799396691, 0.6832480382697612, 0.7849292336275917, 0.8851630088481646, 0.9841482545795618, 1.0820373898183429, 1.1789508087899225, 1.2749859222169808, 1.3702231010412242, 1.464729741992491, 1.5585631409586385, 1.6517725802866492, 1.7444008809325253, 1.8364855801721922, 1.9280598410420753, 2.019153165553774, 2.1097919617349006, 2.2000000000000006, 2.2897987845068095, 2.3792078583468497, 2.468245056627776, 2.5569267180746693, 2.6452678632842357, 2.7332823459283797, 2.820982981832147, 2.9083816598152827, 2.9954894373960834, 3.0823166238466473, 3.16887285261432, 3.2551671447518324, 3.3412079647040636, 3.42700326956454, 3.5125605527262396, 3.5978868826989374, 3.682988937741386, 3.767873036855305, 3.852545167604773, 3.9370110111556476, 4.021275964872415, 4.105345162761953, 4.189223494013648, 4.272915619851468, 4.356425988885037, 4.439758851122484, 4.522918270787167, 4.6059081380627, 4.688732179875523, 4.7713939698112, 4.853896937249383, 4.936244375792538, 5.018439451055145, 5.100485207872598, 5.182384576982647, 5.264140381226543, 5.345755341312093, 5.427232081176477, 5.508573132982825, 5.589780941781152, 5.670857869861266, 5.75180620082254, 5.8326281433831255, 5.913325834949032, 5.993901344961597, 6.074356678040259, 6.154693776935911, 6.234914525308881, 6.315020750344288, 6.395014225216444, 6.474896671413016, 6.55466976092869, 6.63433511833739, 6.713894322751257, 6.793348909674, 6.872700372755627, 6.951950165454966, 7.031099702615962, 7.110150361963223, 7.189103485521905, 7.2679603809666276, 7.34672232290381, 7.425390554091422, 7.503966286599942, 7.582450702917995, 7.660844957005893, 7.739150175300142, 7.8173674576716605, 7.895497878340397, 7.973542486748734, 8.051502308396, 8.129378345636201, 8.207171578440983, 8.284882965129661, 8.362513443068101, 8.44006392933807, 8.517535321378586, 8.594928497600737, 8.672244317977274], [0.0, 0.13682730833261528, 0.2553287856350183, 0.36777475331354126, 0.47646036137300274, 0.582432750373081, 0.6862919565916895, 0.7884261488645629, 0.8891064726411223, 0.98853270464135, 1.0868579428992127, 1.1842031180049122, 1.2806660746527858, 1.3763275418427683, 1.4712552165618946, 1.5655066499552543, 1.65913134392617, 1.7521723102010305, 1.8446672532869801, 1.9366494839641162, 2.028148635677586, 2.119191234104632, 2.2098011555586767, 2.3000000000000003, 2.389807397585978, 2.4792412628809313, 2.5683180074001175, 2.6570527186580613, 2.7454593120457558, 2.8335506604836542, 2.921338705757033, 3.0088345546462154, 3.096048562351836, 3.182990405238929, 3.2696691445496526, 3.356093282438587, 3.4422708114486738, 3.528209258356485, 3.613915723162507, 3.699396913877607, 3.7846591776551053, 3.8697085287341, 3.9545506735904463, 4.039191033634269, 4.123634765744812, 4.207886780893142, 4.291951761069314, 4.37583417470182, 4.459538290732876, 4.5430681914922415, 4.626427784494576, 4.709620813270037, 4.792650867324768, 4.875521391316548, 4.958235693521075, 5.040796953655867, 5.123208230121274, 5.205472466711689, 5.287592498844321, 5.369571059347922, 5.451410783849499, 5.533114215793147, 5.614683811121752, 5.696121942649291, 5.777430904148731, 5.858612914178221, 5.939670119666066, 6.02060459927311, 6.101418366549512, 6.182113372901259, 6.2626915103805185, 6.343154614312648, 6.423504465771578, 6.503742793914323, 6.583871278184423, 6.663891550393396, 6.743805196688438, 6.823613759414036, 6.903318738874513, 6.982921595003961, 7.062423748949553, 7.141826584573759, 7.22113144988055, 7.300339658370332, 7.379452490327983, 7.458471194048046, 7.537396987000864, 7.616231056943128, 7.694974562976128, 7.773628636554721, 7.852194382449831, 7.93067287966713, 8.009065182324342, 8.087372320489468, 8.165595300982071, 8.24373510813964, 8.321792704550871, 8.39976903175766, 8.47766501092744, 8.555481543497383, 8.633219511791957, 8.710879779615157], [0.0, 0.1374108810316637, 0.25641777079736305, 0.3693433240034749, 0.4784924795405262, 0.5849168440550466, 0.6892190129982211, 0.7917888107578656, 0.8928985392271236, 0.9927488271798629, 1.091493425617897, 1.1892537809041324, 1.2861281550435522, 1.3821976213477705, 1.4775301655335646, 1.5721835842034368, 1.666207590387857, 1.7596453792595572, 1.8525348161365691, 1.9449093538704973, 2.0367987522940485, 2.128229650217298, 2.2192260257868837, 2.309809571087583, 2.4000000000000004, 2.489815303494627, 2.5792719630823395, 2.6683851306263793, 2.757168780867312, 2.8456358416289937, 2.9337983056287853, 3.021667327017771, 3.1092533051618356, 3.1965659576960093, 3.283614384508929, 3.370407124017127, 3.4569522028519852, 3.5432571798920134, 3.6293291854194183, 3.7151749560549407, 3.8008008660227053, 3.8862129552127276, 3.971416954439157, 4.056418308234601, 4.141222195472552, 4.225833548069521, 4.310257067984395, 4.394497242703651, 4.4785583593766765, 4.562444517744494, 4.646159641987431, 4.72970749160192, 4.813091671403458, 4.8963156407413955, 4.97938272200133, 5.062296108462371, 5.1450588715690415, 5.227673967671108, 5.310144244278922, 5.392472445876836, 5.474661219332885, 5.556713118939033, 5.6386306111128395, 5.7204160787884035, 5.802071825521707, 5.883600079333118, 5.965002996307655, 6.046282663971717, 6.127441104463317, 6.208480277511247, 6.289402083237335, 6.37020836479466, 6.450900910853488, 6.531481457945739, 6.611951692677835, 6.692313253821016, 6.772567734287449, 6.852716682999767, 6.932761606661136, 7.0127039714323125, 7.0925452045217074, 7.172286695694004, 7.251929798702457, 7.331475832649586, 7.410926083280728, 7.4902818042144395, 7.569544218113611, 7.648714517800754, 7.727793867320761, 7.806783402954179, 7.885684234183813, 7.96449744461733, 8.043224092868297, 8.121865213397985, 8.200421817320079, 8.27889489317029, 8.357285407642793, 8.435594306295183, 8.513822514223703, 8.591970936710183, 8.67004045984223, 8.748031951107992], [0.0, 0.13797296614612148, 0.2574666587090447, 0.3708541387438219, 0.48044977359257246, 0.5873094715440095, 0.6920382929919087, 0.7950276569174987, 0.8965509790765195, 0.9968097089234609, 1.0959582263852172, 1.194118474606262, 1.2913891175365326, 1.3878515601215091, 1.4835740661764647, 1.578614668723388, 1.673023284146037, 1.7668432843088542, 1.860112689419582, 1.952865089170152, 2.0451303651271457, 2.136935265067836, 2.2283038652225002, 2.3192579464083205, 2.409817303146377, 2.5, 2.589822585898394, 2.679300274684148, 2.7684470982621043, 2.857276037337939, 2.9457991336857376, 3.03402758708312, 3.1219718394350227, 3.2096416481268806, 3.2970461502708166, 3.3841939192101207, 3.4710930144094583, 3.557751025667254, 3.644175112432442, 3.7303720388821993, 3.816348205314688, 3.9021096763263534, 3.9876622061734865, 4.07301126165979, 4.15816204284316, 4.243119501814325, 4.327888359765736, 4.412473122540127, 4.496878094823653, 4.581107393127503, 4.665164957684037, 4.749054563368065, 4.832779829740738, 4.916344230302023, 4.99975110102788, 5.083003648259663, 5.16610495600577, 5.249057992709046, 5.331865617527704, 5.414530586172527, 5.49705555633868, 5.579443092766565, 5.66169567196273, 5.743815686608769, 5.8258054496834575, 5.907667198320977, 5.989403097425906, 6.071015243063758, 6.152505665644187, 6.233876332912343, 6.315129152762584, 6.396265975887484, 6.477288598273942, 6.558198763557237, 6.638998165242926, 6.719688448805716, 6.800271213673646, 6.8807480151052856, 6.961120365967035, 7.041389738417044, 7.12155756550178, 7.201625242670819, 7.2815941292150015, 7.361465549632694, 7.441240794928628, 7.520921123849342, 7.600507764059081, 7.680001913259648, 7.759404740257512, 7.838717385981224, 7.917940964451976, 7.997076563709978, 8.076125246699101, 8.155088052112129, 8.233965995198743, 8.312760068538312, 8.391471242779303, 8.470100467347164, 8.54864867112228, 8.627116763089576, 8.705505632961241, 8.783816151773918], [0.0, 0.13851516854212415, 0.25847844415616633, 0.3723115112147555, 0.48233783199761504, 0.589617464273027, 0.6947578461845858, 0.7981519349011476, 0.9000742206402256, 1.000726944506877, 1.100265093106018, 1.198811088790963, 1.2964639832385467, 1.3933055012971811, 1.4894041750434177, 1.5848182655558307, 1.6795978853782203, 1.7737865768165977, 1.86742250948948, 1.9605394050886533, 2.053167262608464, 2.1453329349388692, 2.2370605929242595, 2.328372102975478, 2.4192873374015726, 2.5098244317555016, 2.6, 2.6898293157646003, 2.7793264660963413, 2.8685044827121216, 2.957375454707462, 3.0459506258725626, 3.1342404791466736, 3.222254810259536, 3.3100027922300463, 3.397493032092786, 3.4847336209842834, 3.5717321785291474, 3.658495892311318, 3.745031553089651, 3.831345586314026, 3.9174440804133734, 4.003332812256905, 4.089017270131617, 4.174502674530451, 4.2597939970047305, 4.344895977300115, 4.429813138966279, 4.5145498036058145, 4.599110103906866, 4.6834979955860065, 4.767717268352451, 4.851771555991398, 4.935664345652886, 5.019398986422497, 5.10297869724178, 5.186406574238585, 5.269685597521062, 5.352818637483266, 5.435808460665298, 5.518657735206459, 5.601369035926001, 5.683944849062576, 5.766387576700475, 5.848699540907955, 5.930882987610625, 6.012940090220646, 6.094872953040593, 6.176683614459171, 6.258374049954317, 6.339946174917982, 6.421401847315542, 6.502742870191714, 6.58397099403387, 6.665087919002658, 6.746095297039125, 6.826994733856702, 6.907787790825767, 6.988475986757945, 7.06906079959663, 7.149543668019839, 7.229925992960946, 7.310209139052495, 7.39039443599783, 7.47048317987504, 7.550476634377249, 7.630376031993144, 7.710182575131225, 7.789897437191102, 7.869521763584919, 7.949056672711715, 8.028503256887454, 8.107862583233134, 8.187135694523361, 8.266323609997523, 8.345427326135596, 8.424447817400479, 8.503386036948642, 8.58224291731076, 8.661019371043864, 8.739716291356507, 8.818334552708308], [0.0, 0.13903891703159096, 0.2594557933960465, 0.3737192818846553, 0.4841616301677383, 0.5918469042652421, 0.6973848391436546, 0.8011698778071069, 0.9034775483654846, 1.004510856630514, 1.1044253752367947, 1.2033439894365654, 1.3013661254372386, 1.3985738171022348, 1.4950358556390868, 1.5908107224210282, 1.6859487194755771, 1.78049355374932, 1.8744835391863393, 1.9679525249856489, 2.060930623572695, 2.1534447893726014, 2.2455192846236707, 2.3371760584172185, 2.4284350582027416, 2.5193144881066876, 2.6098310249119003, 2.7000000000000006, 2.7898355536834556, 2.879350766954214, 2.968557774618643, 3.0574678629815515, 3.146091554619895, 3.234438682302671, 3.322518453733459, 3.410339508491444, 3.497909968307065, 3.5852374816159767, 3.6723292631795474, 3.759192129433603, 3.8458325301236997, 3.932256576700112, 4.018470067875337, 4.104478512688483, 4.190287151372029, 4.275900974275544, 4.3613247390664425, 4.446562986398678, 4.531620054215531, 4.6165000908315115, 4.701207066920407, 4.785744786520938, 4.870116897158245, 4.954326899167844, 5.03837815429876, 5.122273893663888, 5.20601722509804, 5.2896111399776435, 5.373058519550182, 5.4563621408164975, 5.539524682004561, 5.622548727669437, 5.7054367734506535, 5.788191230515173, 5.8708144297113725, 5.953308625457073, 6.035675999382462, 6.117918663746827, 6.200038664646353, 6.282037985028582, 6.3639185475278754, 6.4456822171348795, 6.52733080371192, 6.608866064365245, 6.690289705684089, 6.771603385855758, 6.852808716665146, 6.9339072653864315, 7.014900556574112, 7.095790073759927, 7.1765772610617695, 7.257263524710175, 7.337850234497582, 7.418338725155162, 7.498730297661687, 7.579026220488512, 7.659227730784564, 7.739336035504845, 7.819352312485784, 7.8992777114705115, 7.979113355086921, 8.058860339781196, 8.138519736709299, 8.218092592588732, 8.297579930512798, 8.376982750729324, 8.456302031385812, 8.535538729242775, 8.614693780356937, 8.693768100735857, 8.772762586965454, 8.851678116811824], [0.0, 0.13954548940149716, 0.2604010908634935, 0.37508088528567246, 0.48592561761562675, 0.5940032306759778, 0.6999256809327301, 0.8040888484979245, 0.906769265336558, 1.0081706768887821, 1.1084492226002718, 1.2077282354416088, 1.3061075038682044, 1.4036693606244655, 1.5004828475508103, 1.5966066590906582, 1.6920912805412036, 1.7869805780902865, 1.8813130052744569, 1.9751225346184083, 2.0684393882587604, 2.1612906188259973, 2.253700576955108, 2.3456912917064097, 2.437282783205646, 2.528493321903914, 2.6193396453440054, 2.709837140765676, 2.8, 2.889841351698023, 2.979373374877889, 3.0686073969647656, 3.157553978873413, 3.246222989197396, 3.334623669187507, 3.4227646899002493, 3.510654202656656, 3.598299883758581, 3.6857089742535494, 3.772888315412291, 3.85984438047927, 3.946583303171131, 4.033110903327316, 4.1194327100584855, 4.205553982689306, 4.291479729751114, 4.377214726245338, 4.462763529369288, 4.54813049287104, 4.633319780179016, 4.718335376433697, 4.803181099533384, 4.887860610292555, 4.972377421799801, 5.056734908052294, 5.140936311935115, 5.2249847526061215, 5.308883232340475, 5.392634642883155, 5.476241771352687, 5.559707305734862, 5.643033840001271, 5.726223878884022, 5.8092798423348855, 5.89220406969442, 5.9749988235941585, 6.057666293612807, 6.1402085997054305, 6.222627795422929, 6.304925870937488, 6.387104755888366, 6.469166322061089, 6.55111238591201, 6.632944710949191, 6.714665009979631, 6.796274947232049, 6.877776140363695, 6.95917016235893, 7.040458543326791, 7.121642772204097, 7.202724298370217, 7.283704533179128, 7.364584851413951, 7.445366592668796, 7.526051062662402, 7.606639534487655, 7.687133249800894, 7.767533419954521, 7.847841227076277, 7.928057825098251, 8.008184340738502, 8.088221874437991, 8.168171501255312, 8.248034271721565, 8.327811212657574, 8.407503327955457, 8.487111599326482, 8.56663698701701, 8.64608043049418, 8.725442849102922, 8.80472514269576, 8.883928192236834], [0.0, 0.14003603312913962, 0.2613164778268572, 0.37639940569378166, 0.48763379008930874, 0.5960913279713986, 0.7023861270142909, 0.8069154589658774, 0.9099568278829187, 1.0117146954311365, 1.1123457499326046, 1.2119737579098269, 1.3106988586041919, 1.4086036741840895, 1.505757489192457, 1.602219204401067, 1.6980394825778868, 1.7932623441133997, 1.8879263777197264, 1.982065675345047, 2.075710565365743, 2.168888195510308, 2.2616230020134247, 2.353937091374082, 2.445850554094696, 2.537381724852411, 2.628547400027439, 2.7193630209502406, 2.80984282934038, 2.9000000000000004, 2.989846754760102, 3.079394460865106, 3.1686537163545165, 3.257634424512928, 3.346345859076866, 3.4347967215841666, 3.52299519201017, 3.6109489736412046, 3.6986653329792234, 3.786151135344048, 3.873412876735514, 3.960456712432098, 4.047288482731701, 4.133913736181445, 4.220337750594081, 4.306565552107414, 4.392601932508422, 4.478451465014308, 4.564118518677866, 4.649607271563198, 4.734921722819738, 4.82006570376683, 4.905042888087797, 4.989856801220778, 5.074510829023545, 5.15900822578088, 5.243352121615405, 5.327545529356166, 5.411591350913484, 5.495492383203433, 5.579251323660867, 5.662870775375958, 5.746353251885688, 5.829701181648677, 5.912916912228955, 5.996002714211876, 6.078960784873167, 6.161793251620158, 6.244502175222592, 6.3270895528486975, 6.409557320920988, 6.49190735780487, 6.574141486342076, 6.656261476239925, 6.738269046326435, 6.820165866680588, 6.901953560646174, 6.983633706737061, 7.065207840441072, 7.1466774559290815, 7.228044007675456, 7.309308911995498, 7.3904735485051, 7.471539261507442, 7.5525073613112506, 7.63337912548471, 7.714155800048949, 7.794838600614633, 7.875428713465031, 7.955927296588648, 8.036335480664286, 8.116654370001285, 8.196885043437389, 8.277028555196624, 8.357085935709394, 8.437058192396794, 8.516946310421101, 8.596751253404223, 8.676473964115809, 8.756115365132551, 8.835676359470229, 8.915157831189827], [0.0, 0.1405115826483646, 0.26220388460794997, 0.3776776235382502, 0.48928974969665484, 0.5981155994256577, 0.7047713658528114, 0.809655669824411, 0.9130469577755312, 1.0151503857049495, 1.1161231740339044, 1.2160895095846536, 1.315149871662261, 1.413387163012419, 1.5108709034620156, 1.6076601938044397, 1.7038058688537698, 1.7993520984896965, 1.8943376024680658, 1.9887965885101857, 2.0827594879848212, 2.17625354081166, 2.269303266208597, 2.3619308457462624, 2.4541564381525753, 2.5459984403675606, 2.6374737058103976, 2.7285977282488867, 2.819384797766167, 2.9098481339047986, 2.9999999999999996, 3.0898518018983103, 3.1794141736292048, 3.268697052107922, 3.357709742563747, 3.44646097608414, 3.5349589604228857, 3.6232114250259673, 3.711225661071711, 3.7990085571939343, 3.8865666314522938, 3.973906060028025, 4.061032703052145, 4.1479521279141345, 4.23466963034971, 4.321190253564981, 4.407518805619393, 4.493659875260377, 4.5796178463776265, 4.66539691122357, 4.751001082528382, 4.836434204622217, 4.921699963663889, 5.006801897063602, 5.09174340217719, 5.176527744340689, 5.261158064306327, 5.345637385134444, 5.429968618589982, 5.514154571087083, 5.598197949220844, 5.682101364921293, 5.765867340261151, 5.849498311945861, 5.932996635511567, 6.016364589254322, 6.0996043779115965, 6.182718136115205, 6.265707931633073, 6.34857576841563, 6.431323589461301, 6.513953279514251, 6.596466667606416, 6.6788655294548755, 6.761151589724634, 6.843326524166106, 6.925391961635809, 7.007349486008098, 7.089200637985174, 7.1709469168119755, 7.252589781902133, 7.334130654380624, 7.415570918548392, 7.496911923273746, 7.578154983315101, 7.659301380579146, 7.740352365318382, 7.821309157271578, 7.902172946750513, 7.982944895676111, 8.063626138566859, 8.14421778348223, 8.224720912923598, 8.305136584695042, 8.385465832726211, 8.46570966785931, 8.545869078602136, 8.625945031848971, 8.705938473571019, 8.78585032947796, 8.865681505652134, 8.945432889156713], [0.0, 0.14097307383555407, 0.2630650576138525, 0.3789180543381633, 0.4908967553485108, 0.6000800287833873, 0.707086091572886, 0.8123148737792695, 0.9160457363570667, 1.018484509112037, 1.1197889288345146, 1.2200835902214886, 1.3194693025886377, 1.4180292409644502, 1.5158331535042318, 1.6129403351098917, 1.709401787555543, 1.8052618257908397, 1.9005592967414013, 1.995328520479145, 2.0896000283205285, 2.1834011496510524, 2.2767564842186476, 2.3696882864462983, 2.462216781270523, 2.554360426053596, 2.646136129567459, 2.7375594364670865, 2.828644683769452, 2.919405134434907, 3.0098530920759257, 3.1000000000000005, 3.189856527162629, 3.2794326431154976, 3.3687376836496523, 3.457780408528621, 3.5465690524634415, 3.6351113702864097, 3.723414677122737, 3.811485884231022, 3.8993315310786008, 3.986957814131537, 4.074370612767652, 4.1615755126617575, 4.2485778269426975, 4.335382615380304, 4.421994701825441, 4.508418690096655, 4.594658978481931, 4.680719773002579, 4.766605099568041, 4.85231881513465, 4.93786461796791, 5.0232460570961655, 5.108466541033404, 5.193529345840214, 5.278437622584197, 5.363194404254525, 5.447802612179434, 5.532265061990352, 5.616584469171822, 5.700763454232398, 5.784804547528207, 5.86871019376772, 5.952482756223518, 6.036124520674409, 6.119637699099025, 6.203024433140086, 6.286286797356819, 6.36942680228136, 6.452446397293647, 6.535347473328029, 6.61813186542365, 6.700801355129691, 6.783357672775584, 6.865802499615518, 6.948137469855767, 7.030364172572708, 7.112484153528767, 7.19449891689295, 7.276409926872133, 7.358218609258786, 7.439926352900397, 7.521534511095454, 7.603044402920515, 7.6844573144925175, 7.765774500170247, 7.846997183698538, 7.928126559298588, 8.009163792707492, 8.090110022169906, 8.170966359384577, 8.251733890408207, 8.33241367651909, 8.413006755042673, 8.493514140141135, 8.573936823568895, 8.654275775395865, 8.734531944700166, 8.814706260231844, 8.894799631049143, 8.974812947128672], [0.0, 0.1414213562373095, 0.2639015821545788, 0.3801229815689148, 0.4924577653379665, 0.6019882323092767, 0.7093345652902705, 0.8148979660868416, 0.918958683997628, 1.02172320334969, 1.123349762522958, 1.2239633524149758, 1.323665102906484, 1.422538453515497, 1.5206533741905313, 1.6180693483862476, 1.714837540058069, 1.811002405073426, 1.906602913887862, 2.001673495708208, 2.0962447789379155, 2.190344179867609, 2.2839963764703293, 2.377223693936235, 2.470046421515425, 2.5624830752630188, 2.654550617719416, 2.7462646429702744, 2.8376395336230633, 2.9286885948132215, 3.0194241692776664, 3.1098577367126357, 3.2, 3.2898609603937734, 3.3794499833720235, 3.468775856553583, 3.5578468408351718, 3.646670715708794, 3.7352548195611366, 3.823606085628014, 3.9117310741717137, 3.9996360013625347, 4.08732676527422, 4.174808969343554, 4.262087943594679, 4.349168763887064, 4.43605626941101, 4.522755078624815, 4.609269603802647, 4.695604064340606, 4.781762498950185, 4.867748776852509, 4.953566608073253, 5.0392195529263715, 5.124711030764634, 5.210044328066226, 5.295222605918876, 5.380248906956402, 5.465126161796618, 5.549857195024421, 5.634444730759361, 5.71889139784299, 5.803199734677752, 5.8873721937460815, 5.971411145835567, 6.0553188839936, 6.139097627232713, 6.222749524005872, 6.306276655469226, 6.389681038548229, 6.472964628821683, 6.5561293232369495, 6.639176962668439, 6.7221093343305105, 6.8049281740548935, 6.8876351684420225, 6.97023195689481, 7.052720133542762, 7.135101249063696, 7.217376812409747, 7.299548292443847, 7.381617119492362, 7.4635846868192, 7.5454523520262216, 7.627221438384536, 7.708893236100824, 7.790469003522626, 7.871949968286181, 7.953337328410206, 8.034632253338742, 8.115835884935972, 8.196949338435743, 8.277973703348328, 8.358910044326795, 8.439759401995198, 8.52052279374067, 8.601201214471319, 8.681795637341798, 8.762307014448215, 8.842736277493968, 8.923084338428021, 9.00335209005704], [0.0, 0.1418572034507081, 0.26471490181331936, 0.38129448456304227, 0.4939754734865072, 0.6038435029737049, 0.7115206671766806, 0.8174094043672605, 0.9217908275458535, 1.0248720574046417, 1.126811819999242, 1.2277354914372949, 1.3277445132722472, 1.4269225821747973, 1.5253398837342098, 1.6230560847275144, 1.720122506792594, 1.8165837428056488, 1.9124788833254711, 2.007842463666444, 2.102705206625855, 2.1970946129887365, 2.2910354367833037, 2.3845500720038344, 2.477658870429974, 2.570380405181566, 2.6627316910759538, 2.7547283702582885, 2.8463848696618714, 2.9377145354273084, 3.028729748330661, 3.1194420234475033, 3.209862096644973, 3.3000000000000007, 3.3898651278541694, 3.479466294908921, 3.5688117875202745, 3.6579094091558915, 3.746766520818672, 3.8353900771120046, 3.923786658516284, 4.011962500359457, 4.099923518892569, 4.1876753348216695, 4.275223294597524, 4.362572489722924, 4.449727774302094, 4.536693781026984, 4.623474935769972, 4.710075470930936, 4.796499437668295, 4.882750717127749, 4.968833030768919, 5.054749949878308, 5.140504904346809, 5.226101190781221, 5.311541980011444, 5.396830324048406, 5.481969162541808, 5.566961328781649, 5.6518095552829575, 5.736516478989125, 5.821084646125712, 5.905516516733472, 5.989814468906536, 6.073980802759248, 6.1580177441429305, 6.241927448131873, 6.3257120022961555, 6.409373429777202, 6.492913692180724, 6.5763346923002945, 6.659638276683725, 6.742826238053398, 6.8259003175907145, 6.90886220709405, 6.991713551018803, 7.074455948407432, 7.1570909547168, 7.239620083549489, 7.322044808295325, 7.404366563688806, 7.486586747287747, 7.568706720878009, 7.650727811808898, 7.732651314263388, 7.814478490467128, 7.8962105718398155, 7.977848760092347, 8.059394228272883, 8.140848121764716, 8.222211559238744, 8.303485633563005, 8.384671412671729, 8.465769940396074, 8.54678223725866, 8.62770930123381, 8.70855210847535, 8.789311614013657, 8.869988752423547, 8.95058443846453, 9.03109956769481], [0.0, 0.1422813219821873, 0.2655063349777038, 0.38243446232180434, 0.4954523399924414, 0.6056488481623507, 0.713647940893767, 0.8198532596510565, 0.9245467578941181, 1.0279361755556213, 1.1301807132434794, 1.2314061219093966, 1.3317141463923887, 1.4311887335958406, 1.529900278946856, 1.627908627611614, 1.725265254667211, 1.8220148863116987, 1.9181967299751326, 2.0138454242240846, 2.1089917837095324, 2.2036633914371673, 2.297885075443726, 2.3916792966760823, 2.485066467760752, 2.5780652173466905, 2.6706926111214044, 2.762964337996254, 2.8548948680375625, 2.9464975872876495, 3.0377849135380854, 3.128768396291719, 3.2194588035133194, 3.3098661972732866, 3.4000000000000004, 3.4898690527487153, 3.5794816666496394, 3.668845668500904, 3.757968441313017, 3.8468569604819414, 3.9355178261621053, 4.02395729232357, 4.112181292905533, 4.200195465418585, 4.288005172298083, 4.3756155202691716, 4.463031377948665, 4.5502573918791365, 4.637298001165244, 4.724157450860715, 4.810839804235944, 4.8973489540403135, 4.983688632859702, 5.069862422657893, 5.155873763580319, 5.241725962089827, 5.327422198496333, 5.412965533935532, 5.498358916845962, 5.5836051889884715, 5.668707091047644, 5.753667267850689, 5.838488273235765, 5.923172574598546, 6.007722557143087, 6.092140527860513, 6.176428719256903, 6.260589292849694, 6.344624342450291, 6.42853589724882, 6.512325924715717, 6.595996333333443, 6.6795489751705395, 6.7629856483091935, 6.846308099136514, 6.929518024508941, 7.012617073798396, 7.095606850828086, 7.178488915705311, 7.261264786557956, 7.343935941180925, 7.426503818598223, 7.508969820546024, 7.5913353128815935, 7.673601626922693, 7.755770060721588, 7.837841880277673, 7.919818320692293, 8.00170058726917, 8.083489856563586, 8.165187277383259, 8.246793971743635, 8.328311035780166, 8.409739540619942, 8.491080533214923, 8.572335037138844, 8.653504053349732, 8.73458856091987, 8.815589517734944, 8.896507861163922, 8.977344508701224, 9.058100358582557], [0.0, 0.1426943588457651, 0.26627708901858177, 0.3835446539382502, 0.4968906178894403, 0.6074070220195334, 0.7157196317039103, 0.8222332601616132, 0.9272306793519144, 1.0309202322680184, 1.1334615816706974, 1.2349808435615304, 1.335580058140643, 1.4353434160058502, 1.5343415169393042, 1.6326343798352554, 1.7302736292008458, 1.827304121072453, 1.923765176697699, 2.0196915351974996, 2.115114100676504, 2.2100605362127435, 2.3045557419177296, 2.398622243941548, 2.4922805141677347, 2.585549235323451, 2.6784455226371975, 2.7709851105646037, 2.863182511178004, 2.9550511493788507, 3.046603479007057, 3.1378510830932056, 3.2288047608610277, 3.319474603590703, 3.4098700610635344, 3.4999999999999996, 3.5898727556571783, 3.679496177554076, 3.7688776701337803, 3.8580242290415403, 3.9469424735917658, 4.035638675909536, 4.124118787160033, 4.21238846121931, 4.300453076089652, 4.38831775332082, 4.475987375663024, 4.563466603147561, 4.650759887765628, 4.73787148689417, 4.824805475599088, 4.911565757930258, 4.998156077309104, 5.084580026097702, 5.170841054428086, 5.2569424783616325, 5.342887487440564, 5.428679151686929, 5.514320428098461, 5.599814166685524, 5.685163116088799, 5.77036992881332, 5.855437166110931, 5.940367302540056, 6.025162730228902, 6.109825762865694, 6.194358639437382, 6.278763527736205, 6.363042527651811, 6.447197674264987, 6.531230940757652, 6.615144241152516, 6.698939432894599, 6.782618319285845, 6.866182651783056, 6.949634132168577, 7.032974414602387, 7.116205107563529, 7.199327775688227, 7.2823439415114315, 7.365255087118024, 7.448062655709439, 7.5307680530910295, 7.613372649085094, 7.695877778874152, 7.778284744278661, 7.860594814973163, 7.942809229644449, 8.024929197095187, 8.106955897296157, 8.188890482390013, 8.270734077649369, 8.35248778239171, 8.43415267085357, 8.515729793026162, 8.597220175454618, 8.678624822002702, 8.759944714584906, 8.841180813867618, 8.922334059940951, 9.003405372962773, 9.084395653776332], [0.0, 0.14309690811052556, 0.26702827250806255, 0.3846266561960447, 0.4982923758462069, 0.6091205533188933, 0.7177387193107893, 0.8245528290430811, 0.9298464521915394, 1.0338285194973316, 1.1366591441393648, 1.2384647978999517, 1.3393478088406856, 1.43939260506606, 1.5386699855244075, 1.6372401384268453, 1.7351548339163179, 1.8324590545707458, 1.9291922325653277, 2.025389205022103, 2.1210809632280374, 2.216295248300347, 2.3110570305952396, 2.405388899810407, 2.4993113855817857, 2.5928432233416205, 2.686001576601489, 2.778802224204854, 2.871259719163468, 2.9633875242512295, 3.0551981284410723, 3.146703147439998, 3.2379134109369887, 3.328839038680325, 3.419489507109706, 3.509873707959152, 3.6, 3.6898762548952155, 3.779509897976258, 3.8689079446235093, 3.9580770328248573, 4.0470234523994195, 4.135753171300968, 4.2242718593554756, 4.312584909736894, 4.400697458443178, 4.488614401999068, 4.576340413582082, 4.663879957742754, 4.751237303868337, 4.838416538520741, 4.925421576763394, 5.0122561725781365, 5.098923928461311, 5.185428304277978, 5.27177262544432, 5.357960090500449, 5.443993778129127, 5.529876653669956, 5.615611575173347, 5.701201299034058, 5.78664848524, 5.871955702268458, 5.957125431658736, 6.042160072287373, 6.127061944369649, 6.211833293208828, 6.296476292712617, 6.380993048694583, 6.4653856019765925, 6.549655931307029, 6.6338059561081755, 6.717837539065013, 6.80175248856671, 6.885552561011029, 6.969239462981146, 7.0528148533035235, 7.136280344994818, 7.219637507105187, 7.302887866464743, 7.386032909339415, 7.469074083001995, 7.552012797223697, 7.6348504256911705, 7.717588307353562, 7.800227747703844, 7.882770019998384, 7.9652163664183835, 8.047567999176614, 8.129826101572622, 8.211991828999327, 8.294066309903803, 8.376050646704776, 8.457945916669258, 8.539753172750562, 8.621473444389753, 8.703107738282561, 8.784657039113515, 8.866122310259101, 8.947504494461482, 9.028804514474343, 9.110023273682268], [0.0, 0.14348951656753595, 0.2677609057943567, 0.38568193880143514, 0.49965951789982777, 0.6107917695857544, 0.7197079462832378, 0.8268151170142798, 0.9323976294718307, 1.0366649876307987, 1.1397777439653136, 1.241862717252546, 1.3430225163069225, 1.4433418008744745, 1.5428915641513778, 1.6417321594843985, 1.7399154990558596, 1.8374866888603285, 1.934485269261263, 2.030946172961725, 2.1269004762780597, 2.222375996439521, 2.3173977723123436, 2.4119884555725415, 2.5061686321822774, 2.599957088977346, 2.693371036560068, 2.7864262970655997, 2.879137463434128, 2.971518035376749, 3.063580536131823, 3.155336613275835, 3.246797126210692, 3.337972222449766, 3.4288714044328303, 3.519503588289752, 3.6098771557254454, 3.6999999999999997, 3.789879566817417, 3.879522890805859, 3.968936628165557, 4.058127085972719, 4.147100248555119, 4.2358618012947735, 4.324417152162638, 4.412771451248071, 4.500929608510185, 4.588896309948082, 4.676676032361478, 4.764273056851352, 4.851691481191724, 4.938935231187606, 5.026008071120464, 5.1129136133706465, 5.19965532729589, 5.286236547436168, 5.372660481107281, 5.458930215438833, 5.54504872390629, 5.63101887240157, 5.716843424882022, 5.802525048633646, 5.8880663191807425, 5.973469724871099, 6.058737671162943, 6.1438724846374235, 6.228876416758141, 6.313751647397256, 6.398500288145955, 6.483124385425419, 6.567625923413032, 6.652006826797305, 6.736268963373788, 6.82041414649324, 6.904444137372375, 6.988360647276641, 7.07216533958375, 7.155859831735914, 7.239445697088227, 7.322924466659892, 7.406297630794639, 7.4895666407360775, 7.572732910123346, 7.655797816412013, 7.738762702224841, 7.821628876636625, 7.904397616397104, 7.9870701670956, 8.069647744270775, 8.15213153446874, 8.234522696252414, 8.316822361164938, 8.399031634649697, 8.481151596929353, 8.56318330384615, 8.645127787665595, 8.726986057845435, 8.808759101771836, 8.890447885464456, 8.972053354252015, 9.053576433419918, 9.135018028831322], [0.0, 0.14387268865499156, 0.26847593019242094, 0.38671185762142724, 0.5009938006061232, 0.6124228180619874, 0.7216298427585524, 0.8290230307483616, 0.9348874890418518, 1.0394332810699622, 1.142821388043556, 1.2451789673946183, 1.3466089019424963, 1.4471960775072397, 1.5470116768641091, 1.6461162145264727, 1.7445617413021066, 1.8423934836358977, 1.9396510874792519, 2.036369578818957, 2.1325801169570515, 2.2283105934054688, 2.3235861138938274, 2.418429390586812, 2.5128610644190053, 2.606899972394265, 2.7005633710738266, 2.7938671248440206, 2.886825865613785, 2.979453129143627, 3.0717614721137596, 3.163762573204169, 3.255467320815533, 3.3468858895589793, 3.4380278072494432, 3.528902013826281, 3.6195169133767764, 3.7098804202390525, 3.8, 3.8898827060729366, 3.9795352124327046, 4.068963842997825, 4.158174598076526, 4.247173178232974, 4.335965005879485, 4.424555244858133, 4.512948818239503, 4.601150424536116, 4.6891645525024614, 4.7769954946717, 4.864647359760483, 4.9521240840572265, 5.039429441895475, 5.126567055302019, 5.21354040289911, 5.300352828131225, 5.387007546878928, 5.473507654515643, 5.55985613245716, 5.6460558542484245, 5.7321095912276165, 5.818020017803411, 5.903789716377747, 5.989421181943257, 6.074916826381664, 6.160278982486983, 6.245509907735086, 6.330611787819228, 6.415586739969356, 6.50043681607138, 6.585164005601198, 6.669770238386983, 6.75425738721201, 6.838627270269384, 6.922881653478943, 7.007022252675872, 7.091050735679736, 7.174968724251944, 7.258777795949047, 7.34247948587866, 7.426075288364302, 7.50956665852496, 7.5929550137747315, 7.67624173524752, 7.759428169151406, 7.842515628056917, 7.925505392123205, 8.00839871026579, 8.091196801269295, 8.173900854848359, 8.256512032659709, 8.339031469268145, 8.421460273069005, 8.503799527169562, 8.586050290231567, 8.668213597277068, 8.750290460459453, 8.832281869801589, 8.914188793902776, 8.996012180616127, 9.07775295769791, 9.15941203343029], [0.0, 0.14424689075546288, 0.26917421600290514, 0.3877176662342496, 0.5022968480035307, 0.6140156839980991, 0.7235067479964226, 0.8311792576344041, 0.9373190614644866, 1.0421367692768788, 1.145793780982531, 1.2484175847403962, 1.3501113309603385, 1.4509601262440757, 1.5510353385079418, 1.6503976396590272, 1.7490992158853653, 1.8471854112624428, 1.9446959748578199, 2.041666023758255, 2.1381267983088006, 2.2341062625651267, 2.3296295875549755, 2.424719544515674, 2.5193968280673307, 2.613680324207442, 2.7075873343802677, 2.8011337642342204, 2.8943342837347394, 2.9872024638478316, 3.079750893912696, 3.1719912829846924, 3.2639345477844133, 3.3555908893863893, 3.44696986038669, 3.5380804239767842, 3.628931006102359, 3.7195295416861387, 3.809883515732446, 3.9000000000000004, 3.9898856858221525, 4.079546913565464, 4.168989699144512, 4.258219757950209, 4.347242526498155, 4.4360631820611935, 4.5246866605144485, 4.61311767259092, 4.701360718720011, 4.789420102599441, 4.877299943632324, 4.96500418834507, 5.052536620887983, 5.139900872708471, 5.227100431476425, 5.31413864933237, 5.401018750521134, 5.487743838466978, 5.574316902340128, 5.660740823159408, 5.747018379471039, 5.833152252639635, 5.919145031783767, 6.0049992183853576, 6.090717230599256, 6.176301407286896, 6.261754011795678, 6.347077235503681, 6.432273201147609, 6.517343965950173, 6.602291524561751, 6.687117811829851, 6.77182470540872, 6.856414028220449, 6.940887550777897, 7.02524699337901, 7.109494028181227, 7.193630281164038, 7.277657333987098, 7.361576725750725, 7.44538995466506, 7.5290984796337455, 7.612703721757468, 7.696207065762357, 7.779609861357879, 7.862913424528458, 7.946119038762847, 8.0292279562249, 8.112241398869205, 8.195160559504766, 8.277986602809689, 8.360720666299692, 8.443363861252966, 8.525917273593866, 8.60838196473764, 8.690758972398354, 8.773049311361934, 8.855253974226216, 8.93737393210976, 9.019410135330968, 9.10136351405914, 9.183234978938806], [0.0, 0.14461255495919248, 0.26985656953471265, 0.388700526044627, 0.5035701647176668, 0.615572206672458, 0.7253408292546981, 0.8332862874622754, 0.9396951544704152, 1.0447785739627142, 1.1486983549970349, 1.2515823089133424, 1.3535338476065994, 1.454638293422777, 1.5549671951950539, 1.6545813786331047, 1.7535331622163477, 1.8518680049669776, 1.9496257567159816, 2.046841623571529, 2.1435469250725863, 2.239769696163381, 2.335535171679921, 2.430866180584357, 2.525783469957421, 2.6203059736723944, 2.7144510370324997, 2.808234606006784, 2.9016713877488796, 2.9947749876270358, 3.0875580268942815, 3.180032244288296, 3.2722085842034336, 3.3640972735738304, 3.4557078892112765, 3.5470494170288287, 3.638130304331849, 3.7289585061579977, 3.819541526485999, 3.9098864550013985, 3.9999999999999996, 4.0898885179211195, 4.179558039929611, 4.269014295904833, 4.358262736143896, 4.447308551043965, 4.536156688992552, 4.624811872664311, 4.713278613897182, 4.801561227298707, 4.889663842714643, 4.9775904166757945, 5.065344742925245, 5.152930462116081, 5.240351070759394, 5.327609929493348, 5.414710270736194, 5.501655205779337, 5.588447731370517, 5.675090735831906, 5.7615870047533075, 5.847939226296564, 5.934149996143633, 6.020221822117665, 6.106157128503502, 6.191958260091567, 6.277627485966817, 6.363167003062451, 6.4485789394962865, 6.53386535770607, 6.619028257398595, 6.704069578326185, 6.7889912029029205, 6.873794958671976, 6.958482620634443, 7.0430559134492015, 7.1275165135125915, 7.2118660509259405, 7.2961061113583945, 7.380238237811872, 7.464263932294459, 7.548184657408103, 7.632001837855962, 7.715716861874434, 7.79933108259448, 7.882845819336532, 7.96626235884297, 8.04958195645187, 8.13280583721546, 8.215935196966504, 8.29897120333555, 8.381914996721903, 8.464767691220839, 8.547530375509513, 8.630204113693852, 8.712789946118512, 8.795288890141888, 8.877701940878046, 8.960030071907315, 9.042274235957148, 9.124435365554808, 9.206514373653304], [0.0, 0.14497008237135636, 0.270523739276568, 0.3896615151732867, 0.5048151474778791, 0.6170940934693113, 0.7271340983777934, 0.8353464314797303, 0.9420183744487605, 1.047361592981627, 1.1515382961787317, 1.2546766113695997, 1.3568802061157037, 1.4582346137065083, 1.5588115598662589, 1.6586720206847867, 1.7578684439891348, 1.856446401190402, 1.9544458406408072, 2.051902055489016, 2.1488464427056804, 2.245307106546168, 2.3413093442348845, 2.436876041174306, 2.5320279957384297, 2.626784188610987, 2.7211620079782084, 2.8151774392325577, 2.9088452258883453, 3.002179006950542, 3.0951914348758556, 3.1878942774237933, 3.2802985060466705, 3.3724143729627998, 3.464251478660842, 3.5558188312698373, 3.6471248989795253, 3.738177656494906, 3.828984626346882, 3.919552915748916, 4.009889249581816, 4.1000000000000005, 4.189891213079248, 4.27956863286497, 4.36903772312911, 4.458303687101119, 4.547371485402469, 4.636245852383742, 4.724931311037548, 4.813432186638489, 4.901752619242589, 4.989896575162436, 5.077867857520427, 5.165670115970483, 5.253306855668163, 5.340781445560179, 5.428097126056327, 5.515257016140099, 5.602264119968131, 5.689121333003429, 5.775831447722646, 5.862397158933598, 5.948821068735582, 6.035105691151869, 6.121253456460891, 6.207266715250125, 6.2931477422144155, 6.378898739718466, 6.464521841141467, 6.550019114020154, 6.6353925630052215, 6.720644132644667, 6.805775710006485, 6.89078912715211, 6.975686163470988, 7.060468547885898, 7.145137960937752, 7.229696036757999, 7.3141443649360545, 7.398484492288618, 7.482717924537211, 7.5668461278997885, 7.650870530601821, 7.734792524311859, 7.818613465506229, 7.902334676767131, 7.985957448018176, 8.06948303770103, 8.15291267389663, 8.236247555394211, 8.319488852711071, 8.402637709065942, 8.485695241308484, 8.568662540807406, 8.651540674299437, 8.734330684701288, 8.817033591886586, 8.899650393429626, 8.982182065317733, 9.0646295626338, 9.14699382021059, 9.229275753258213], [0.0, 0.14531984602822678, 0.27117642133876935, 0.39060163629524036, 0.5060330952719154, 0.6185829322920147, 0.7288884264234402, 0.8373618391959209, 0.9442911453963712, 1.0498885213990954, 1.1543165676600577, 1.2577037206365884, 1.3601538980048373, 1.4617528394170967, 1.5625724436474664, 1.662673833900408, 1.7621095845417891, 1.8609253769310727, 1.9591612558023066, 2.0568525994545594, 2.1540308806087265, 2.250724271326216, 2.3469581298650586, 2.4427553968424482, 2.5381369208118056, 2.633121728250818, 2.7277272492975126, 2.8219695079116858, 2.9158632831787497, 3.009422247009969, 3.102659082388141, 3.1955855854643853, 3.288212754161413, 3.3805508654326624, 3.4726095429295194, 3.564397816514585, 3.655924174808469, 3.747196611756432, 3.8382226680386924, 3.9290094680160093, 4.019563752794047, 4.109891909901075, 4.2, 4.289893780994668, 4.3795787298392534, 4.469060062316834, 4.558342751017181, 4.647431541713257, 4.736330968310121, 4.825045366517797, 4.913578886380859, 5.001935503781262, 5.09011903101705, 5.178133126547521, 5.265981303984985, 5.3536669404042785, 5.441193284033212, 5.528563461380325, 5.615780483850265, 5.702847253891807, 5.789766570718906, 5.876541135641034, 5.963173557035471, 6.0496663549909755, 6.136021965649415, 6.2222427452694395, 6.308330974033961, 6.39428885962124, 6.480118540557589, 6.565822089368009, 6.651401515539735, 6.7368587683123025, 6.82219573930656, 6.907414265004084, 6.992516129087385, 7.077503064650546, 7.1623767562890555, 7.247138842076966, 7.331790915438834, 7.416334526923304, 7.500771185884693, 7.585102362078442, 7.669329487175846, 7.753453956203078, 7.837477128909184, 7.921400331067305, 8.005224855713204, 8.088951964324734, 8.17258288794578, 8.256118828257845, 8.339560958602293, 8.422910424956052, 8.506168346863362, 8.589335818326033, 8.672413908654473, 8.755403663281594, 8.838306104541632, 8.92112223241569, 9.003853025245823, 9.086499440419212, 9.169062415024055, 9.251542866478555], [0.0, 0.14566219347661552, 0.27181526426659963, 0.39152182357300674, 0.5072252183280667, 0.620040202542947, 0.7306055566005372, 0.8393345132446612, 0.9465157256790927, 1.0523618701275532, 1.1570359301034676, 1.260666644637384, 1.3633581762168272, 1.4651964664813053, 1.5662535835855127, 1.6665907947291991, 1.766260798133992, 1.8653093827764302, 1.9637766877287604, 2.0616981746349667, 2.1591053903600215, 2.2560265733336475, 2.3524871415533757, 2.4485100896803718, 2.544116315383504, 2.6393248899634205, 2.7341532846204237, 2.8286175610638806, 2.922732533196072, 3.01651190513683, 3.1099683897477797, 3.203113810969655, 3.2959591926342955, 3.3885148359057964, 3.480790387107137, 3.5727948973736514, 3.6645368753236163, 3.756024333734589, 3.8472648310512763, 3.9382655084181524, 4.029033122821715, 4.1195740768381, 4.209894445408051, 4.299999999999999, 4.389896230470838, 4.479588364891095, 4.569081387565068, 4.658380055445908, 4.747488913119741, 4.836412306510744, 4.92515439544025, 5.0137191651566795, 5.1021104369391646, 5.190331877865674, 5.27838700982596, 5.36627921785064, 5.454011757819765, 5.5415877636073665, 5.629010253712421, 5.716282137421352, 5.803406220542557, 5.890385210749312, 5.977221722563763, 6.063918282011542, 6.150477330973635, 6.236901231259609, 6.323192268424079, 6.409352655346201, 6.495384535590267, 6.581289986563777, 6.667071022487959, 6.752729597194402, 6.838267606760276, 6.923686891993579, 7.008989240778855, 7.094176390293046, 7.179250029100245, 7.264211799133513, 7.349063297571228, 7.4338060786148485, 7.51844165517446, 7.602971500467981, 7.687397049539469, 7.771719700701528, 7.855940816906527, 7.940061727050892, 8.024083727216544, 8.108008081853152, 8.19183602490472, 8.275568760883699, 8.359207465895627, 8.442753288617155, 8.526207351229964, 8.60957075031314, 8.692844557696187, 8.776029821274877, 8.859127565791876, 8.94213879358407, 9.025064485298302, 9.107905600577192, 9.190663078716547, 9.273337839295845], [0.0, 0.14599744906233633, 0.2724408733107486, 0.392422948807713, 0.5083926460840563, 0.621467284864808, 0.7322871157475117, 0.841266322571003, 0.9486942229022409, 1.0547839824597862, 1.1596989598793381, 1.2635681904967386, 1.3664960765395227, 1.46856875745017, 1.5698584672551834, 1.6704266141666808, 1.7703260176963291, 1.8696025722084126, 1.9682965091591236, 2.06644337181084, 2.1640747796366857, 2.261219036059853, 2.3579016175798455, 2.454145571782259, 2.5499718444339616, 2.64539955073004, 2.740446202082449, 2.8351278971681273, 2.929459483984982, 3.023454698194197, 3.117126281917277, 3.2104860863088933, 3.3035451605732984, 3.3963138295837103, 3.4888017618650506, 3.581018029384715, 3.6729711603443844, 3.7646691859637973, 3.85611968208415, 3.9473298062859494, 4.038306331107548, 4.129055673861231, 4.219583923469801, 4.309896864685281, 4.4, 4.489898569517395, 4.579597569013619, 4.669101766390411, 4.7584157166937, 4.847543775850226, 4.936490113255552, 5.025258723330531, 5.113853436149339, 5.202277927230079, 5.290535726568471, 5.3786302269861075, 5.46656469185676, 5.554342262267375, 5.641965963664294, 5.729438712029945, 5.8167633196305655, 5.903942500371398, 5.990978874792168, 6.0778749747323975, 6.164633247693295, 6.251256060920364, 6.337745705228641, 6.424104398590436, 6.510334289503665, 6.596437460157178, 6.682415929408128, 6.768271655585037, 6.854006539129079, 6.939622425085048, 7.025121105452479, 7.110504321406593, 7.195773765397876, 7.280931083138455, 7.365977875482771, 7.450915700209425, 7.535746073710611, 7.620470472595001, 7.705090335209546, 7.789607063085199, 7.874022022311296, 7.958336544842847, 8.04255192974483, 8.12666944437717, 8.210690325523906, 8.294615780469794, 8.378446988027294, 8.462185099516843, 8.545831239702936, 8.629386507688537, 8.712851977770073, 8.796228700255146, 8.879517702244968, 8.962719988383396, 9.045836541574335, 9.128868323669106, 9.2118162761254, 9.294681320639196], [0.0, 0.14632591596632236, 0.2730538142268425, 0.393305826911925, 0.5095364342772131, 0.6228654698077586, 0.7339346245449823, 0.8431590141637488, 0.9508286071413319, 1.057157048779217, 1.162308065239424, 1.2664109821631224, 1.3695704366632968, 1.4718727619800323, 1.5733903546528558, 1.6741847610508565, 1.7743089195197055, 1.8738088276774068, 1.972724807493391, 2.0710924821957164, 2.168943542395397, 2.266306355193023, 2.3632064544054496, 2.4596669394710204, 2.5557088032806545, 2.6513512040350466, 2.7466116925435458, 2.8415064037020987, 2.9360502189138247, 3.0302569047425725, 3.124139231977231, 3.217709078435351, 3.310977518179823, 3.403954899312895, 3.496650912111858, 3.589074648954335, 3.6812346572288623, 3.7731389862239184, 3.8647952288249225, 3.956210558715596, 4.047391763671235, 4.138345275441873, 4.22907719664925, 4.319593325059995, 4.409899175546016, 4.499999999999999, 4.589900805437659, 4.679606370487618, 4.769121260443807, 4.858449841032984, 4.947596291031072, 5.036564613845621, 5.125358648167757, 5.21398207778481, 5.302438440634328, 5.390731137171117, 5.4788634381109285, 5.566838491607566, 5.654659329914058, 5.7423288755732464, 5.82984994717844, 5.9172252647406625, 6.004457454695358, 6.091549054578218, 6.178502517396868, 6.26532021572267, 6.352004445524565, 6.438557429764886, 6.5249813217752655, 6.6112782084290895, 6.69745011312556, 6.7834989985990735, 6.869426769566438, 6.955235275223454, 7.04092631160132, 7.1265016237925725, 7.211962908055396, 7.297311813804463, 7.382549945495834, 7.467678864412821, 7.552700090359216, 7.6376151032657855, 7.7224253447154885, 7.8071322193924635, 7.89173709645949, 7.976241310868228, 8.060646164606306, 8.144952927884972, 8.229162840270801, 8.313277111764709, 8.397296923831266, 8.481223430381162, 8.5650577587094, 8.648801010391725, 8.732454262141527, 8.816018566629403, 8.89949495326735, 8.982884428959487, 9.066187978821064, 9.149406566867393, 9.232541136674268, 9.315592612011306], [0.0, 0.1466478780211681, 0.2736546166652306, 0.3941712207922852, 0.5106575712700367, 0.6242359655618935, 0.7355495066270825, 0.8450142235227276, 0.9529207227460057, 1.0594831196838266, 1.1648655007461621, 1.2691974761303995, 1.3725839131833795, 1.475111335104889, 1.576852297729126, 1.6778684828461357, 1.7782129452822448, 1.8779317838643748, 1.9770654092827002, 2.075649523147346, 2.173715885798426, 2.271292926752882, 2.3684062360098252, 2.465078963833475, 2.561332149305572, 2.6571849927807487, 2.752655083685537, 2.847758592417622, 2.9425104331237897, 3.036924402658567, 3.1310132999105087, 3.2247890288320207, 3.3182626878523402, 3.411444647842726, 3.5043446204020614, 3.596971717913999, 3.689334506573961, 3.781441053381337, 3.873298967928233, 3.964915439682681, 4.056297271355173, 4.147450908847572, 4.238382468209264, 4.329097759963751, 4.4196023111173535, 4.509901385118541, 4.6000000000000005, 4.689902944904813, 4.779614795171957, 4.869139926134135, 4.958482525761863, 5.047646606271421, 5.136636014800235, 5.2254544432411025, 5.3141054373161225, 5.4025924049621485, 5.490918624091513, 5.579087249784926, 5.667101320967309, 5.754963766611995, 5.8426774115140665, 5.930244981669408, 6.017669109292433, 6.104952337502188, 6.192097124703673, 6.279105848688636, 6.365980810477859, 6.4527242379248735, 6.539338289099306, 6.625825055466306, 6.712186564877176, 6.798424784384933, 6.8845416228973475, 6.97053893367902, 7.056418516712971, 7.142182120931478, 7.227831446325015, 7.313368145937475, 7.398793827755215, 7.484110056496851, 7.569318355310212, 7.654420207382367, 7.739417057468202, 7.824310313342591, 7.909101347180895, 7.993791496872077, 8.07838206726854, 8.16287433137639, 8.247269531489625, 8.331568880271538, 8.415773561786287, 8.499884732483515, 8.58390352213863, 8.667831034751174, 8.75166834940364, 8.835416521082827, 8.919076581465752, 9.002649539672035, 9.086136382984485, 9.16953807753954, 9.252855568989153, 9.336089783135519], [0.0, 0.14696360133599293, 0.2742437772030884, 0.39501984571694404, 0.5117569837083026, 0.6255799048737983, 0.7371330967313767, 0.8468334840215819, 0.9549722988984216, 1.061764117725266, 1.167373380179423, 1.2719299755005802, 1.3755389968081346, 1.4782871535806785, 1.5802471578603874, 1.6814808242341768, 1.782041321751953, 1.8819748484884053, 1.9813219021352877, 2.0801182611659628, 2.1783957542984838, 2.2761828722566895, 2.3735052601332893, 2.470386118033511, 2.5668465303348658, 2.662905738729097, 2.758581370511625, 2.853889630893945, 2.9488454661320294, 3.0434627027841326, 3.137754167293981, 3.2317317892424136, 3.3254066909528626, 3.418789265624395, 3.5118892457643334, 3.604715763374698, 3.6972774030933704, 3.7895822492874647, 3.8816379279320405, 3.9734516439735876, 4.065030214768389, 4.156380100095914, 4.2475074291730035, 4.338418025032838, 4.429117426581022, 4.519610908597885, 4.609903499919614, 4.7, 4.789904994028429, 4.879622866757408, 4.969157815173882, 5.05851386013217, 5.147694857052335, 5.2367045057755774, 5.325546359657705, 5.4142238339726365, 5.5027402136898385, 5.591098660682701, 5.679302220418752, 5.7673538281772165, 5.855256314834775, 5.943012412256202, 6.030624758322897, 6.118095901629078, 6.20542830587253, 6.29262435396423, 6.379686351878909, 6.466616532266521, 6.553417057842876, 6.640090024575911, 6.726637464682762, 6.813061349451379, 6.899363591899291, 6.985546049281053, 7.0716105254549335, 7.157558773118546, 7.243392495922333, 7.329113350469083, 7.414722948207044, 7.500222857223568, 7.5856146039457215, 7.67089967475378, 7.756079517513092, 7.8411555430293784, 7.926129126432204, 8.01100160849092, 8.095774296867193, 8.180448467307825, 8.265025364781394, 8.349506204561978, 8.433892173262945, 8.518184429823707, 8.602384106451993, 8.686492309524192, 8.770510120445989, 8.8544385964755, 8.938278771510877, 9.022031656844307, 9.105698241884156, 9.18927949484689, 9.272776363420387, 9.356189775400038], [0.0, 0.14727333575346888, 0.2748217620633274, 0.39585237323186834, 0.5128355415947262, 0.6268983512486784, 0.7386866480069498, 0.8486182353034514, 0.9569849590810525, 1.0640018479354059, 1.1698336881100935, 1.2746106425940003, 1.3784380259964424, 1.4814027305413282, 1.5835776215157311, 1.6850246437844374, 1.7857970784542474, 1.8859412209650046, 1.985497654359726, 2.0845022325170075, 2.182986851235794, 2.2809800612857973, 2.378507561808265, 2.475592601804009, 2.572256310087104, 2.6685179689022878, 2.7643952426955414, 2.859904370831794, 2.9550603310671293, 3.0498769791000857, 3.1443671684068737, 3.2385428537106224, 3.3324151807757145, 3.425994564705494, 3.5192907585191144, 3.6123129134648257, 3.7050696322731387, 3.797569016349445, 3.8898187077409947, 3.9818259265791247, 4.073597504588097, 4.165139915161745, 4.256459300434596, 4.3475614957122115, 4.438452051573766, 4.5291362539165005, 4.619619142175166, 4.7099055259186855, 4.800000000000002, 4.889906958412745, 4.979630606989254, 5.069174975058036, 5.158543926164679, 5.247741167948015, 5.3367702612527586, 5.425634628550718, 5.514337561734625, 5.602882229341706, 5.691271683257988, 5.77950886494897, 5.8675966112575715, 5.955537659806133, 6.043334654035543, 6.130990147911332, 6.218506610323671, 6.305886429205666, 6.393131915392019, 6.480245306238131, 6.567228769017858, 6.654084404116516, 6.740814248034255, 6.827420276213632, 6.9139044057039705, 7.000268497674101, 7.086514359784028, 7.172643748425278, 7.2586583708388375, 7.344559887118882, 7.4303499121098815, 7.516030017204025, 7.601601732045412, 7.687066546146953, 7.772425910425456, 7.85768123866, 7.942833908878315, 8.027885264675504, 8.112836616469203, 8.19768924269493, 8.282444390945104, 8.367103279055067, 8.451667096139044, 8.536137003578975, 8.62051413596879, 8.704799602016628, 8.788994485407303, 8.87309984562716, 8.957116718753353, 9.04104611820943, 9.124889035488987, 9.208646440849071, 9.292319283974864, 9.375908494617137], [0.0, 0.1475773161594552, 0.27538900955845946, 0.3966694346809762, 0.5138940628493758, 0.6281923045250796, 0.7402113385832109, 0.8503698308273469, 0.9589602295867145, 1.0661980072880197, 1.1722482903028724, 1.2772415102838501, 1.381283199215516, 1.4844604286721903, 1.5868462143389765, 1.6885026289383283, 1.7894830635522316, 1.8898339091769085, 1.9895958326210477, 2.0888047617676566, 2.1874926582503935, 2.2856881317693576, 2.3834169345102616, 2.480702363461156, 2.5775655910471693, 2.6740259393126724, 2.7701011091640506, 2.865807373485192, 2.9611597409471067, 3.056172095847269, 3.1508573181921844, 3.2452273873802002, 3.339293472181179, 3.4330660091958225, 3.52655477157406, 3.619768929452831, 3.7127171033191626, 3.805407411300201, 3.89784751121681, 3.9900446381030803, 4.082005637784336, 4.173736997015858, 4.26524487060988, 4.3565351059163655, 4.447613264971192, 4.538484644581988, 4.629154294585181, 4.719627034476913, 4.809907468594159, 4.9, 4.989908843207848, 5.07963803586297, 5.169191449485525, 5.258572799367122, 5.347785653702258, 5.436833442026915, 5.525719463028473, 5.614446891784199, 5.703018786479384, 5.791438094650874, 5.879707658996993, 5.967830222790686, 6.055808434929052, 6.14364485464915, 6.231341955937077, 6.318902131654766, 6.406327697406614, 6.493620895166046, 6.580783896680295, 6.667818806669987, 6.754727665838724, 6.841512453706486, 6.928175091279496, 7.014717443568139, 7.10114132196353, 7.187448486482488, 7.273640647889839, 7.359719469706286, 7.44568657010943, 7.531543523734899, 7.617291863384065, 7.702933081644276, 7.788468632427114, 7.873899932429777, 7.95922836252432, 8.044455269079103, 8.129581965216538, 8.214609732010901, 8.299539819629718, 8.384373448422007, 8.469111809956392, 8.553756068011973, 8.638307359524541, 8.722766795490674, 8.807135461831969, 8.891414420221613, 8.975604708875283, 9.059707343308283, 9.143723317060713, 9.227653602392284, 9.311499150948377, 9.39526089439883], [0.0, 0.14787576366283137, 0.27594593229224296, 0.39747162437738087, 0.5149333174180895, 0.6294627058970835, 0.7417082774876438, 0.8520895446665837, 0.960899547185145, 1.0683541932226923, 1.174618943088019, 1.27982449220731, 1.3840765859838178, 1.4874624720778262, 1.5900553138349973, 1.691917309508249, 1.793101958153039, 1.8936557445826971, 1.993619417846922, 2.093028978486141, 2.1919164527704345, 2.290310508257666, 2.3882369492125246, 2.4857191197368587, 2.5827782350730653, 2.6794336563407333, 2.7757031202430182, 2.871602932572671, 2.9671481323529294, 3.0623526319596617, 3.157229337446776, 3.25179025243871, 3.3460465682920746, 3.440008742713642, 3.533686568617709, 3.6270892346860997, 3.720225378839164, 3.8131031356214415, 3.905730178340304, 3.998113756661346, 4.0902607302542915, 4.18217759899267, 4.273870530135672, 4.365345382858429, 4.456607730445, 4.547662880414811, 4.638515892816641, 4.729171596893161, 4.819634606292755, 4.909909332982876, 5.0, 5.089910653154775, 5.179645171796788, 5.269207278731127, 5.358600549368295, 5.44782842017987, 5.5368941965242096, 5.62580105989958, 5.714552074675878, 5.803150194350795, 5.891598267371475, 5.979899042558626, 6.06805517416624, 6.156069226606956, 6.243943678870045, 6.3316809286565565, 6.419283296253762, 6.506753028169059, 6.594092300541632, 6.681303222348513, 6.768387838420242, 6.855348132280011, 6.942186028818916, 7.0289033968189765, 7.115502051334508, 7.201983755941635, 7.288350224864884, 7.374603124989118, 7.460744077764398, 7.546774661010758, 7.632696410629377, 7.718510822226077, 7.804219352652707, 7.889823421471469, 7.975324412346974, 8.06072367437036, 8.146022523319582, 8.23122224285965, 8.31632408568632, 8.401329274616538, 8.48623900362865, 8.571054438855285, 8.655776719531472, 8.74040695890057, 8.824946245080252, 8.90939564189074, 8.993756189647305, 9.078028905918945, 9.162214786255008, 9.246314804881413, 9.330329915368075, 9.41426105126895], [0.0, 0.14816888666071193, 0.2764929191474444, 0.3982595024665558, 0.5159540309817693, 0.630710442448607, 0.7431785099886621, 0.8537785776467604, 0.9628042660447897, 1.0704719113406505, 1.1769473018226544, 1.2823613919846943, 1.3868201368411772, 1.4904109569968587, 1.5932071608235945, 1.695271069865219, 1.796656289224341, 1.8974093958576377, 1.9975712195885824, 2.0971778323187644, 2.19626132380153, 2.294850418420284, 2.392970971589568, 2.490646373684487, 2.587897882000816, 2.684744896036235, 2.7812051876520303, 2.8772950949626988, 2.9730296868022035, 3.0684229031238677, 3.163487675564298, 3.258236031541815, 3.3526791845968127, 3.4468276131655884, 3.540691129574196, 3.634278940718493, 3.727599701641128, 3.8206615630111354, 3.913472213346108, 4.006038916682106, 4.0983685462862605, 4.1904676149163125, 4.282342302056343, 4.3739984784956905, 4.46544172856591, 4.556677370307128, 4.647710473798276, 4.738545877854668, 4.829188205269979, 4.9196418767571695, 5.009911123723726, 5.1000000000000005, 5.189912392625323, 5.279652031784219, 5.369222499974458, 5.458627240479476, 5.547869565209596, 5.636952661969525, 5.725879601203435, 5.814653342263509, 5.903276739243157, 5.991752546411863, 6.080083423284951, 6.1682719393583, 6.256320578535097, 6.34423174326917, 6.432007758447125, 6.519650875029441, 6.6071632734689, 6.694547066922997, 6.781804304275591, 6.868936972981659, 6.955947001747864, 7.0428362630605745, 7.129606575571949, 7.216259706353915, 7.30279737302898, 7.389221245786147, 7.475532949289553, 7.56173406448683, 7.647826130323653, 7.733810645370477, 7.819689069366954, 7.905462824689179, 7.991133297744499, 8.076701840298249, 8.162169770736556, 8.247538375268944, 8.332808909074288, 8.417982597393435, 8.503060636571465, 8.588044195052541, 8.672934414329916, 8.757732409853645, 8.842439271898296, 8.92705606639282, 9.01158383571463, 9.09602359944977, 9.180376355120993, 9.264643078885353, 9.348824726202952, 9.432922232478266], [0.0, 0.14845688180219063, 0.2770303370842483, 0.39903359751675843, 0.5169568883123327, 0.6319363512557712, 0.744623022429511, 0.8554380628990449, 0.9646756639952301, 1.0725525823675004, 1.179234928546054, 1.284853911560394, 1.3895156923691718, 1.4933078614961455, 1.5963038698022949, 1.698566159965535, 1.8001484412804512, 1.9010973812351235, 2.001453889013754, 2.1012541066307104, 2.200530186212036, 2.29931090797258, 2.3976221775819266, 2.4954874308789385, 2.592927966477093, 2.6899632215807783, 2.7866110025943622, 2.882887679388654, 2.9788083500868354, 3.074386981737249, 3.169636531111661, 3.2645690490060257, 3.3591957707564406, 3.4535271951660893, 3.5475731536331954, 3.6413428709490145, 3.73484501897896, 3.828087764234482, 3.9210788101773066, 4.013825434962566, 4.106334525216928, 4.198612606356947, 4.2906658698777385, 4.382500197979664, 4.474121185848519, 4.565534161861076, 4.656744205950956, 4.747756166338654, 4.838574674803146, 4.929204160649912, 5.019648863511003, 5.109912845096183, 5.2, 5.289914065657321, 5.3796586315292, 5.469237147591765, 5.558652932192683, 5.647909179332784, 5.737008965424243, 5.8259552555713245, 5.914750909414924, 6.003398686577988, 6.091901251745125, 6.180261179406533, 6.268480958293347, 6.356562995529035, 6.444509620519073, 6.532323088599119, 6.620005584460092, 6.707559225366823, 6.794986064185573, 6.882288092234327, 6.969467241968567, 7.056525389514201, 7.143464357058296, 7.230285915107427, 7.316991784622636, 7.4035836390392635, 7.490063106179301, 7.576431770063258, 7.662691172628052, 7.748842815356901, 7.834888160826747, 7.92082863417835, 8.00666562451381, 8.092400486225882, 8.178034540263234, 8.263569075335386, 8.349005349060903, 8.434344589062125, 8.519587994009461, 8.604736734618173, 8.68979195460023, 8.774754771573782, 8.859626277932556, 8.944407541677347, 9.029099607211629, 9.113703496103213, 9.198220207813732, 9.282650720397589, 9.366995991172013, 9.451256957359616], [0.0, 0.1487399348620308, 0.2775585327706209, 0.39979440886740125, 0.5179425363150789, 0.6331412231059392, 0.7460427466104818, 0.8570690708945513, 0.9665149482044392, 1.0745975484653543, 1.1814832989196153, 1.2873036587644298, 1.3921649913686285, 1.4961550542591124, 1.5993474383408304, 1.701804705347081, 1.8035806669764607, 1.9047220796949074, 2.0052699306854977, 2.105260430872223, 2.2047257936834894, 2.3036948542075057, 2.402193567506507, 2.5002454141029435, 2.59787173321897, 2.6950919991186257, 2.7919240521565882, 2.888384293415033, 2.9844878498037493, 3.08024871500114, 3.175679870482804, 3.2707933900211623, 3.365600530373995, 3.46011181036187, 3.554337080127897, 3.64828558205164, 3.741966004532593, 3.83538652965276, 3.928554875561557, 4.0214783342909, 4.1141638055977365, 4.20661782734021, 4.298846602818356, 4.390856025447744, 4.482651701082144, 4.574238968257599, 4.665622916593307, 4.756808403553549, 4.847800069748414, 4.938602352928448, 5.029219500809132, 5.119655582844429, 5.209914501054454, 5.300000000000001, 5.389915675985912, 5.479664985566161, 5.569251253415293, 5.6586776796239295, 5.747947346469842, 5.837063224710664, 5.926028179439584, 6.0148449755411395, 6.103516282780522, 6.192044680556538, 6.2804326623454285, 6.3686826398601655, 6.456796946947549, 6.54477784324334, 6.632627517603866, 6.7203480913308065, 6.80794162120449, 6.895410102339619, 6.982755470876159, 7.069979606517109, 7.157084334923779, 7.244071429978454, 7.330942615923419, 7.417699569384648, 7.5043439212877905, 7.5908772586735065, 7.677301126418626, 7.763617028869143, 7.8498264313906025, 7.935930761840988, 8.021931411970908, 8.10782973875545, 8.19362706566185, 8.279324683856727, 8.364923853356464, 8.450425804124025, 8.535831737115254, 8.621142825277532, 8.706360214503475, 8.791485024542117, 8.876518349869986, 8.96146126052416, 9.046314802899412, 9.131080000511309, 9.21575785472709, 9.300349345465957, 9.384855431870388, 9.469277052949936], [0.0, 0.1490182215342446, 0.2780778340631819, 0.40054240876209396, 0.518911586792093, 0.6343258058757445, 0.7474385637693104, 0.8586726140171018, 0.9683232603354766, 1.076608078966184, 1.1836938085304842, 1.2897121541806642, 1.3947696782873091, 1.4989543025682626, 1.6023397556142136, 1.7049887162090471, 1.8069550967309689, 1.9082857411254581, 2.009021713261028, 2.10919929181091, 2.208850750473589, 2.3080049782866117, 2.4066879788731312, 2.5049232766867475, 2.602732250874477, 2.7001344121359536, 2.7971476342044697, 2.893788348847992, 2.990071711278173, 3.086011741355049, 3.181621444842056, 3.276912918101178, 3.3718974389511542, 3.466585545892859, 3.5609871074986397, 3.655111383440195, 3.7489670783726785, 3.8425623896864542, 3.9359050499712973, 4.029002364902234, 4.12186124714539, 4.21448824679099, 4.306889578745203, 4.39907114744995, 4.4910385692473405, 4.582797192661609, 4.674352116834436, 4.765708208318231, 4.856870116405484, 4.947842287149601, 5.038628976213375, 5.129234260664559, 5.2196620498238, 5.309916095257816, 5.4, 5.4899172270714045, 5.579671107366911, 5.669264846964387, 5.758701533908427, 5.847984144514838, 5.937115549237286, 6.026098518133302, 6.114935725963103, 6.203629756951454, 6.29218310923979, 6.380598199053306, 6.468877364605342, 6.557022869759348, 6.645036907466917, 6.732921602998601, 6.820679016982888, 6.908311148267261, 6.995819936614129, 7.083207265243343, 7.170474963231952, 7.257624807781111, 7.344658526359094, 7.431577798728775, 7.518384258867205, 7.605079496784335, 7.6916650602473995, 7.778142456416966, 7.864513153400223, 7.9507785817266186, 8.036940135750674, 8.122999174986326, 8.208957025376966, 8.294814980504935, 8.380574302744058, 8.466236224358516, 8.551801948551088, 8.6372726504637, 8.722649478132885, 8.807933553402687, 8.893125972797355, 8.978227808355967, 9.06324010843106, 9.14816389845316, 9.233000181663023, 9.317749939813242, 9.402414133840812, 9.486993704512143], [0.0, 0.14929190815424387, 0.2785885513547849, 0.4012780442896946, 0.5198646189569208, 0.6354908076050703, 0.7488113082033064, 0.8602496507244032, 0.9701016812390368, 1.0785853755891237, 1.185867778627801, 1.292080837396821, 1.397331309979043, 1.5017072795691926, 1.605282610167767, 1.7081200956744027, 1.8102737474826898, 1.911790495571621, 2.0127114792275425, 2.1130730437530367, 2.2129075221204113, 2.31224385642477, 2.411108098047478, 2.5095238146471095, 2.6075124246355843, 2.705093474545857, 2.802284870938089, 2.8991030757588043, 2.9955632720536927, 3.0916795054316415, 3.1874648055424513, 3.282931290964264, 3.3780902602286424, 3.472952271191454, 3.56752721054965, 3.661824354981227, 3.7558524251282934, 3.849619633436528, 3.9431337266973654, 4.036402024003424, 4.129431450716622, 4.222228568957066, 4.314799605045214, 4.407150474267074, 4.499286803279721, 4.59121395043048, 4.6829370242261055, 4.774460900156911, 4.865790236054267, 4.956929486137197, 5.047882913884435, 5.138654603851672, 5.229248472539403, 5.319668278404471, 5.409917631097593, 5.5, 5.589918722124089, 5.6796770094360065, 5.769277955651843, 5.858724542553703, 5.948019645867123, 6.037166040737116, 6.126166406836361, 6.215023333135804, 6.303739322364965, 6.392316795186672, 6.480758094108625, 6.569065487152081, 6.657241171296203, 6.745287275714815, 6.8332058648209495, 6.920998941133169, 7.008668447976449, 7.096216272029356, 7.183644245728223, 7.270954149538206, 7.358147714100246, 7.4452266222622665, 7.532192511002278, 7.619046973250442, 7.7057915596166175, 7.792427780029423, 7.878957105292369, 7.965380968562212, 8.051700766754344, 8.137917861879579, 8.224033582316537, 8.310049224023349, 8.395966051692314, 8.481785299850786, 8.567508173911348, 8.653135851174186, 8.738669481784317, 8.824110189646161, 8.909459073297842, 8.994717206747342, 9.079885640272602, 9.164965401187452, 9.249957494575197, 9.334862903991517, 9.419682592138262, 9.50441750150965], [0.0, 0.14956115235716425, 0.2790909788029944, 0.40200173915380344, 0.5208021817269871, 0.6366368992993373, 0.750161770571345, 0.8618010893414415, 0.9718512352312537, 1.0805305771966485, 1.1880064613519559, 1.2944110727021008, 1.3998513618654607, 1.5044155708925884, 1.6081776969958492, 1.7112006473220982, 1.8135385306731162, 1.9152383616649333, 2.0163413537775643, 2.1168839178614314, 2.216898445200544, 2.3164139300863473, 2.415456470883218, 2.514049677753409, 2.6122150077364092, 2.7099720426168523, 2.8073387212489314, 2.9043315352678776, 3.000965695101621, 3.097255271689952, 3.193213318181317, 3.2888519750094085, 3.384182561082408, 3.4792156532970093, 3.5739611561805735, 3.6684283631413526, 3.762626010548914, 3.856562325659876, 3.950245069236817, 4.043681573572154, 4.136878776517521, 4.229843252027645, 4.3225812376519945, 4.4150986593446495, 4.507401153910217, 4.599494089359667, 4.691382583412819, 4.78307152035281, 4.8745655664112935, 4.965869183840361, 5.056986643807829, 5.147922038235776, 5.238679290688012, 5.32926216639966, 5.419674281531352, 5.509919111721261, 5.6000000000000005, 5.689920164126419, 5.7796827033960465, 5.869290604968554, 5.958746749755779, 6.048053917907638, 6.137214793929532, 6.226231971461552, 6.315107957746827, 6.40384517781379, 6.492445978394793, 6.580912631601414, 6.669247338375015, 6.757452231729326, 6.8455293798005, 6.933480788718591, 7.021308405313313, 7.109014119665808, 7.196599767517163, 7.284067132543558, 7.3714179485071005, 7.458653901290689, 7.545776630824582, 7.632787732911751, 7.719688760958542, 7.80648122761669, 7.8931666063422625, 7.97974633287668, 8.066221806654633, 8.152594392143293, 8.238865420116973, 8.325036188871033, 8.411107965378614, 8.497081986393507, 8.582959459502227, 8.668741564128194, 8.754429452490678, 8.840024250521036, 8.925527058738576, 9.010938953088228, 9.096260985742083, 9.1814941858667, 9.266639560358033, 9.35169809454558, 9.436670752867396, 9.521558479517465], [0.0, 0.1498261036790349, 0.2795853954519076, 0.40271389528863144, 0.5217247958169893, 0.637764717488503, 0.7514907009091848, 0.8633277915245412, 0.9735728940001113, 1.0824447641378285, 1.1901110445098497, 1.2967041542901419, 1.402331233562778, 1.50708068070131, 1.6110266240060156, 1.714232082065334, 1.8167512595361417, 1.9186312543220367, 2.0199133529137443, 2.1206340306644185, 2.220825736240039, 2.3205175152961637, 2.419735512431074, 2.518503379633016, 2.61684261195316, 2.7147728258657615, 2.8123119920041426, 2.9094766312188782, 3.0062819808835526, 3.102742136864977, 3.198870175435577, 3.294678258536128, 3.3901777251265384, 3.485379170840741, 3.580292517752214, 3.6749270757327146, 3.769291596628508, 3.8633943222710014, 3.95724302717116, 4.05084505661074, 4.144207360731953, 4.237336525135451, 4.330238798420678, 4.422920117039688, 4.515386127782829, 4.607642208170639, 4.699693484989105, 4.791544851173992, 4.8832009812233, 4.974666345294114, 5.065945222120728, 5.157041710874165, 5.247959742068927, 5.338703087610343, 5.429275370065165, 5.519680071228745, 5.609920540053961, 5.7, 5.789921555852872, 5.879688200064076, 5.969302818649057, 6.058768196682837, 6.148087023426485, 6.237261897114791, 6.326295329432526, 6.415189749704123, 6.503947508819229, 6.592570882914524, 6.6810620768303925, 6.769423227359254, 6.857656406301014, 6.945763623339635, 7.033746828753691, 7.12160791597265, 7.209348723989658, 7.296971039640725, 7.384476599759359, 7.471867093215042, 7.559144162843213, 7.646309407273845, 7.733364382665184, 7.820310604348665, 7.90714954839062, 7.99388265307592, 8.080511320318392, 8.167036917002392, 8.253460776259733, 8.339784198685742, 8.426008453498028, 8.512134779641329, 8.598164386841425, 8.684098456611116, 8.769938143210856, 8.855684574566622, 8.941338853147313, 9.026902056803925, 9.112375239572497, 9.197759432442789, 9.283055644094489, 9.36826486160263, 9.453388051113798, 9.538426158494639], [0.0, 0.150086904106665, 0.2800720662582792, 0.40341489433702726, 0.5226329556537144, 0.638874866567763, 0.7527988113875632, 0.8648305754299205, 0.9752675801786175, 1.0843289622210803, 1.1921826559427973, 1.2989613110181382, 1.404772254028582, 1.5097040372216262, 1.6138309179317547, 1.7172160244430763, 1.8199136557658373, 1.9219709917863679, 2.023429390862273, 2.124325391838897, 2.224691499865209, 2.324556811156175, 2.4239475158196537, 2.5228873070146105, 2.6213977172083833, 2.7194983970213804, 2.817207348368179, 2.9145411208569936, 3.011514978384914, 3.1081430413552504, 3.2044384088021336, 3.300413263836476, 3.3960789651557737, 3.491446126837645, 3.5865246882267994, 3.6813239754005704, 3.7758527554394528, 3.8701192845213077, 3.9641313506900935, 4.0578963120134075, 4.151421130731486, 4.244712403908454, 4.337776391020615, 4.430619038853531, 4.5232460040268485, 4.615662673421686, 4.707874182748164, 4.799885433459119, 4.891701108189393, 4.983325684877216, 5.074763449704822, 5.16601850897861, 5.257094800054878, 5.347996101404665, 5.43872604190048, 5.529288109398393, 5.61968565868076, 5.709921918817806, 5.800000000000001, 5.889922899887768, 5.979693509520204, 6.069314618820274, 6.158788921730212, 6.248119021007521, 6.337307432709033, 6.426356590387875, 6.515268849025856, 6.604046488721702, 6.692691718153731, 6.781206677833856, 6.869593443168334, 6.957854027339363, 7.045990384020339, 7.134004409936601, 7.221897947282409, 7.309672786004092, 7.397330665958447, 7.484873278954747, 7.572302270688094, 7.659619242571178, 7.746825753471029, 7.833923321356801, 7.920913424864196, 8.00779750478169, 8.094576965463402, 8.181253176173009, 8.26782747236289, 8.3543011568923, 8.440675501188162, 8.526951746351825, 8.613131104214828, 8.699214758346614, 8.785203865016843, 8.871099554114858, 8.956902930028614, 9.04261507248531, 9.12823703735573, 9.213769857424262, 9.299214543126398, 9.384572083255353, 9.469843445639476, 9.55502957779187], [0.0, 0.15034368858142386, 0.2805512430316081, 0.4041050990045752, 0.5235271311303025, 0.6399679209419917, 0.754086778839033, 0.8663102186165729, 0.9769361706183771, 1.0861841463538136, 1.1942223675281953, 1.3011837107669184, 1.407175686277076, 1.5122869978106712, 1.6165920297494532, 1.720154018384045, 1.8230273556251546, 1.925259302079429, 2.0268912868647044, 2.127959911340829, 2.2284977362700014, 2.328533907648056, 2.4280946603916442, 2.527203728196482, 2.62588268036992, 2.724151201152715, 2.822027323259016, 2.919527624611848, 3.016667395223384, 3.113460779655606, 3.2099208993538517, 3.3060599582731816, 3.4018893345447467, 3.4974196604058485, 3.5926608922064713, 3.687622371979985, 3.782312881806529, 3.876740691989501, 3.9709136038974666, 4.0648389881869775, 4.158523819010005, 4.251974704717626, 4.345197915495515, 4.43819940830362, 4.530984849439528, 4.623559635000801, 4.715928909484273, 4.808097582728702, 4.900070345380474, 4.991851683039148, 5.08344588922021, 5.174857077255559, 5.266089191237937, 5.35714601610299, 5.448031186931883, 5.538748197548077, 5.629300408473645, 5.719691054303443, 5.809923250549182, 5.9, 5.989924198641287, 6.079698641169302, 6.169326026135359, 6.258808960750033, 6.348149965374889, 6.437351477726633, 6.526415856816228, 6.61534538664343, 6.704142279665398, 6.792808680056257, 6.881346666773087, 6.969758256442452, 7.058045406080297, 7.146210015657078, 7.234253930518874, 7.322178943674445, 7.409986797957317, 7.497679188071288, 7.58525776252709, 7.672724125477275, 7.76007983845595, 7.8473264220293695, 7.934465357363041, 8.021498087710492, 8.108426019828562, 8.195250525323605, 8.281972941932832, 8.368594574744566, 8.455116697361028, 8.541540553006968, 8.627867355587254, 8.714098290696304, 8.80023451658205, 8.886277165066963, 8.972227342428505, 9.058086130241184, 9.14385458618228, 9.22953374480318, 9.315124618268127, 9.400628197062076, 9.486045450669236, 9.571377328223813], [0.0, 0.15059658546149227, 0.2810231652967292, 0.40478485430206906, 0.5244077692158999, 0.6410444269934077, 0.7553552470765004, 0.8677674607098508, 0.9785794993933098, 1.0880112438820473, 1.1962311988513155, 1.3033724644416067, 1.409542731705623, 1.5148308536061688, 1.619311339648822, 1.7230475324955525, 1.8260939155510625, 1.9284978289202472, 2.030300771409899, 2.131539405947929, 2.2322463480678087, 2.332450792792581, 2.432179019169307, 2.531454800816747, 2.630299743324522, 2.7287335640447425, 2.826774326024838, 2.9244386350739733, 3.021741806924031, 3.118698009929917, 3.2153203876088794, 3.311621164444557, 3.40761173770754, 3.503302757519882, 3.598704196979393, 3.6938254138339115, 3.7886752049361316, 3.883261854501138, 3.9775931770203714, 4.07167655554875, 4.1655189759696425, 4.259127057750195, 4.35250708162332, 4.445665014569317, 4.538606532417194, 4.631337040341423, 4.723861691492525, 4.8161854039682215, 4.908312876305152, 5.000248601648213, 5.091996880735121, 5.183561833816916, 5.274947411620795, 5.3661574054491386, 5.457195456497773, 5.548065064467208, 5.638769595532334, 5.729312289728999, 5.819696267809597, 5.909924537614331, 6.0, 6.089925454363891, 6.1797036037966215, 6.269337059894418, 6.3588283472584095, 6.448179907705848, 6.537394104215845, 6.62647322463013, 6.715419485127494, 6.804235033488828, 6.8929219521682805, 6.981482261184631, 7.069917920845771, 7.158230834318146, 7.2464228500519345, 7.3344957640719635, 7.422451322143422, 7.510291221820814, 7.5980171143878685, 7.6856306066955264, 7.773133262904588, 7.860526606139092, 7.94781212005605, 8.034991250336724, 8.12206540610429, 8.209035961272322, 8.295904255828269, 8.382671597055777, 8.469339260699421, 8.555908492075213, 8.642380507129962, 8.728756493452405, 8.815037611238786, 8.90122499421545, 8.987319750520752, 9.073322963548545, 9.159235692755253, 9.245058974432506, 9.330793822447141, 9.416441228950227, 9.502002165056764, 9.587477581497527], [0.0, 0.15084571694663823, 0.2814880610864727, 0.4054544886872567, 0.5252752954348144, 0.6421049048897159, 0.7566048290237954, 0.869203005849108, 0.9801983605598505, 1.0898111376592747, 1.1982101205794178, 1.3055286296479403, 1.4118745340705334, 1.5173368337991946, 1.6219901616003567, 1.725897964923567, 1.8291148173052632, 1.9316881371649355, 2.033659491960729, 2.1350656052719286, 2.2359391465877856, 2.3363093592285837, 2.436202565714733, 2.5356425789936208, 2.6346510403969314, 2.733247699895133, 2.8314506504173003, 2.929276525243538, 3.026740665442501, 3.1238572628077605, 3.2206394825998474, 3.317099569525327, 3.4132489397092614, 3.509098260892168, 3.604657522670325, 3.699936098272063, 3.794942799102686, 3.8896859230818293, 3.984173297628424, 4.078412318011155, 4.172409981670116, 4.266172919023019, 4.359707421192974, 4.453019465031438, 4.546114735756926, 4.638998647485675, 4.731676361893047, 4.8241528052127585, 4.9164326837542225, 5.0085204980953355, 5.100420556088508, 5.1921369848009, 5.283673741495385, 5.375034623746285, 5.466223278773045, 5.557243212065718, 5.648097795367848, 5.738790274075265, 5.829323774103016, 5.919701308267162, 6.009925782223382, 6.1, 6.189926669159345, 6.279708405618, 6.369347738153536, 6.458847112622695, 6.548208895913657, 6.637435379652922, 6.726528783685501, 6.815491259345348, 6.904324892531613, 6.993031706604786, 7.081613665115689, 7.17007267437917, 7.258410585903294, 7.346629198684047, 7.434730261374631, 7.52271547433781, 7.610586491589026, 7.698344922637431, 7.785992334231409, 7.873530252014699, 7.960960162098723, 8.048283512556328, 8.135501714841801, 8.222616145141574, 8.309628145659833, 8.396539025842863, 8.483350063545695, 8.570062506144469, 8.656677571597525, 8.743196449458228, 8.829620301842134, 8.915950264351101, 9.002187446956682, 9.08833293484498, 9.174387789225074, 9.260353048102932, 9.346229727022623, 9.432018819776532, 9.517721299086174, 9.603338117255111], [0.0, 0.15109119946911628, 0.2819461476711081, 0.4061143151155285, 0.5261301152277049, 0.6431498502480493, 0.7578361086763264, 0.8706175249401394, 0.9817935106970215, 1.0915846688705846, 1.2001600575667744, 1.3076532140753965, 1.414172183145772, 1.5198061095661801, 1.6246297475585387, 1.7287066478251774, 1.832091472714133, 1.9348317178124386, 2.036969018224074, 2.138540157291352, 2.239577857669029, 2.340111410267231, 2.440167180442977, 2.539769019896244, 2.638938605177275, 2.737695718397143, 2.8360584819289, 2.934043556121232, 3.031666307008463, 3.1289409494795324, 3.225880670219783, 3.322497733862509, 3.418803575111086, 3.5148088790664445, 3.610523651581679, 3.7059572811388777, 3.8011185934828022, 3.896015900036914, 3.9906570409582893, 4.085049423550487, 4.179200056641057, 4.273115581437888, 4.366802299302104, 4.460266196811741, 4.553512968437294, 4.646548037105799, 4.739376572892596, 4.832003510048231, 4.924433562541046, 5.016671238273065, 5.108720852107191, 5.200586537826866, 5.292272259134917, 5.383781819785739, 5.475118872934171, 5.566286929775015, 5.657289367538904, 5.748129436903143, 5.838810268869813, 5.92933488115796, 6.01970618415185, 6.109926986443015, 6.2, 6.289927844996468, 6.379713054325257, 6.469358077823434, 6.558865286230995, 6.648236974903775, 6.737475367299303, 6.826582618252562, 6.915560817057242, 7.004411990366595, 7.093138104926881, 7.181741070155233, 7.270222740572819, 7.358584918103259, 7.446829354245473, 7.534957752129352, 7.622971768462042, 7.710873015371967, 7.798663062157201, 7.8863434369442755, 7.9739156282630725, 8.061381086542998, 8.148741225535304, 8.235997423665989, 8.323151025323515, 8.410203342085122, 8.497155653885395, 8.584009210130416, 8.670765230760606, 8.757424907265177, 8.84398940365088, 8.930459857367628, 9.016837380193307, 9.10312305908003, 9.18931795696386, 9.275423113539988, 9.361439546005156, 9.447368249769022, 9.53321019913608, 9.618966347959649], [0.0, 0.15133314405389134, 0.2823976322305457, 0.4067646320081541, 0.5269726152059544, 0.6441797356683329, 0.7590496429078731, 0.8720116577308622, 0.9833656712471731, 1.0933326396351604, 1.202081891716029, 1.3097471786148327, 1.4164367180945567, 1.5222397976923554, 1.6272312913351938, 1.7314748514900866, 1.8350252280367012, 1.9379299926174605, 2.0402308470072557, 2.141964633450113, 2.243164127000062, 2.3438586654711995, 2.4440746564397817, 2.543835989799868, 2.6431643768126833, 2.7420796312666904, 2.840599904554566, 2.93874188370346, 3.036520959353556, 3.1339513691563066, 3.2310463209130895, 3.327818098896739, 3.4242781561211912, 3.5204371947975877, 3.6163052368015447, 3.7118916856490656, 3.8072053812177087, 3.9022546482401417, 3.997047339428, 4.091590873946269, 4.185892271845838, 4.279958184969261, 4.3737949247681245, 4.467408487406862, 4.560804576474608, 4.653988623582211, 4.7469658070839325, 4.8397410691316045, 4.932319131242119, 5.02470450853607, 5.1169015227858115, 5.2089143143942795, 5.300746853411432, 5.392402949682677, 5.483886262212703, 5.5752003078188395, 5.66634846913973, 5.757334002058038, 5.848160042589564, 5.938829613285672, 6.029345629191071, 6.11971090339473, 6.209928152207912, 6.300000000000002, 6.389928983719796, 6.479717557127323, 6.56936809475888, 6.65888289564589, 6.7482641868063356, 6.837514126525771, 6.926634807443501, 7.015628259458092, 7.104496452465179, 7.193241298939477, 7.281864656371823, 7.370368329571287, 7.458754072841488, 7.547023592039565, 7.635178546525575, 7.723220551009466, 7.811151177302252, 7.898971955977476, 7.986684377948627, 8.074289895967704, 8.161789926049819, 8.249185848828267, 8.336479010844297, 8.423670725775397, 8.510762275605732, 8.597754911742076, 8.684649856078359, 8.77144830201174, 8.858151415412912, 8.944760335553207, 9.031276175990815, 9.117700025418399, 9.204032948474124, 9.290275986518054, 9.376430158375786, 9.46249646105094, 9.548475870408183, 9.634369341828249], [0.0, 0.15157165665103983, 0.282842712474619, 0.4074057241457354, 0.5278031643091577, 0.645195012148216, 0.7602459631378297, 0.8733860147266772, 0.9849155306759332, 1.0950558154077705, 1.2039764646185536, 1.311811440235328, 1.4186691305805414, 1.5246389639153282, 1.6297959321736835, 1.7342037881437724, 1.8379173679952563, 1.9409843183471007, 2.0434464066993803, 2.1453405333623126, 2.2466995250459165, 2.347552765802925, 2.447926704829952, 2.547845269673356, 2.647330205812968, 2.746401358265295, 2.845076907030995, 2.9433735654372484, 3.041306748381063, 3.1388907159535178, 3.236138696772495, 3.333062994471782, 3.4296750801161386, 3.5259856727842096, 3.6220048101468523, 3.7177419105407306, 3.813205827775725, 3.908404899704917, 4.003346991416417, 4.09803953376838, 4.192489557875832, 4.286703726065139, 4.380688359735218, 4.474449464500916, 4.5679927529406585, 4.66132366522593, 4.75444738787247, 4.847368870821324, 4.940092843030852, 5.032623826737823, 5.124966150526038, 5.21712396132402, 5.309101235438833, 5.400901788720489, 5.492529285940549, 5.583987249459114, 5.6752790672461275, 5.766408000315771, 5.857377189626444, 5.948189662493284, 6.038848338555334, 6.129356035335204, 6.219715473425272, 6.309929281331131, 6.400000000000001, 6.489930087059224, 6.579721920787548, 6.669377803839844, 6.758899966744047, 6.848290571187334, 6.937551713107168, 7.026685425601391, 7.115693681670344, 7.204578396802948, 7.293341431417589, 7.381984593167852, 7.470509639122274, 7.558918277826555, 7.647212171256028, 7.7353929366655505, 7.823462148343429, 7.911421339275509, 7.99927200272507, 8.087015593733762, 8.174653530548442, 8.262187195978392, 8.34961793868711, 8.436947074422545, 8.524175887189358, 8.611305630366646, 8.698337527774129, 8.785272774689854, 8.872112538822021, 8.95885796123753, 9.04551015724963, 9.132070217266849, 9.218539207605296, 9.304918171266303, 9.391208128681216, 9.477410078425002, 9.563524997900371, 9.649553843993807], [0.0, 0.15180683844287585, 0.2832815772162025, 0.4080378634937234, 0.5286221148745971, 0.6461961103904159, 0.7614255768716723, 0.8747411789601911, 0.9864437464679184, 1.0967549271976547, 1.2058445799940376, 1.3138468746422753, 1.4208703676424317, 1.5270046260144248, 1.6323247580513218, 1.7368946154614646, 1.840769119499476, 1.9439959907138245, 2.046617061411922, 2.14866928915929, 2.250185551600564, 2.3511952783813963, 2.4517249597375343, 2.5517985603418234, 2.6514378594148424, 2.7506627327650457, 2.849491388601565, 2.947940566184334, 3.04602570432844, 3.143761085251222, 3.241159958096366, 3.3382346455882366, 3.434996636590342, 3.531456666813276, 3.627624789502559, 3.723510437608544, 3.819122478678872, 3.914469263503813, 4.0095586693751155, 4.10439813868081, 4.1989947134455505, 4.29335506633311, 4.387485528550822, 4.481392115031969, 4.57508054721874, 4.6685562737237, 4.7618244891101, 4.854890150999415, 4.94775799568756, 5.040432552428101, 5.132918156521161, 5.225218961329725, 5.31733894933058, 5.409281942294491, 5.501051610679357, 5.592651482310648, 5.684084950415151, 5.775355281066908, 5.866465620097896, 5.957418999520499, 6.048218343503931, 6.138866473942534, 6.229366115650013, 6.319719901210404, 6.409930375513517, 6.5, 6.589931156638787, 6.679726151657601, 6.769387219045306, 6.858916523843203, 6.948316165240854, 7.037588179490699, 7.126734542654429, 7.215757173193077, 7.304657934411693, 7.393438636768656, 7.48210104005881, 7.570646855478866, 7.659077747582919, 7.74739533613519, 7.8356011978666835, 7.92369686814186, 8.011683842540979, 8.09956357836336, 8.187337496056447, 8.275006980575116, 8.362573382675478, 8.450038020147025, 8.53740217898671, 8.624667114518395, 8.71183405246071, 8.798904189946315, 8.885878696495253, 8.972758714944927, 9.059545362339133, 9.146239730778294, 9.232842888233044, 9.319355879323057, 9.405779726062995, 9.492115428577243, 9.578363965785066, 9.664526296057675], [0.0, 0.15203878612808078, 0.28371440690141614, 0.40866130996612293, 0.5294298036266387, 0.6471834420121721, 0.7625889691260844, 0.8760777076284276, 0.9879509469730144, 1.0984306736212675, 1.2076870059474099, 1.315854318736447, 1.4230413343533614, 1.5293377566687105, 1.6348188087345208, 1.739548439819007, 1.8435816550917068, 1.946966248013949, 2.0497441148092834, 2.151952269511186, 2.2536236399984837, 2.354787700882775, 2.4554709828745898, 2.5556974872627167, 2.6554890265444935, 2.7548655068968873, 2.853845164349594, 2.9524447637386855, 3.050679767468419, 3.148564479578124, 3.2461121694550283, 3.343335178651551, 3.440245013585188, 3.5368524263697676, 3.6331674856112968, 3.7291996386728608, 3.8249577666509422, 3.920450233095096, 4.015684927332888, 4.110669303123673, 4.205410413251709, 4.299914940576019, 4.394189225977472, 4.4882392935796505, 4.5820708735666065, 4.675689422875915, 4.769100144007668, 4.862308002158158, 4.955317740859948, 5.0481338962869104, 5.1407608103631315, 5.2332026427975755, 5.3254633821519075, 5.417546856036227, 5.509456740516576, 5.601196568808633, 5.692769739323743, 5.784179523126225, 5.875429070854616, 5.966521419153951, 6.0574594966613216, 6.148246129582679, 6.238884046895007, 6.329375885204702, 6.419724193289945, 6.509931436352252, 6.6000000000000005, 6.689932193984626, 6.779730255708338, 6.869396353520428, 6.958932589817842, 7.048341003964234, 7.137623575040548, 7.226782224439058, 7.315818818311783, 7.404735169883326, 7.493533041637343, 7.582214147385108, 7.6707801542240075, 7.7592326843931225, 7.847573317032568, 7.935803589852705, 8.023925000718913, 8.111939009157137, 8.199847037785139, 8.287650473673889, 8.375350669643337, 8.462948945496441, 8.550446589195047, 8.637844857981042, 8.725144979445847, 8.812348152551241, 8.899455548604188, 8.98646831218825, 9.073387562053966, 9.160214391970397, 9.246949871539941, 9.333595046978362, 9.420150941861872, 9.506618557842959, 9.59299887533659, 9.679292854178286], [0.0, 0.15226759218487862, 0.28414137410072776, 0.4092763121328754, 0.5302265525931623, 0.6481574006655049, 0.7637366037489777, 0.8773961336092959, 0.9894377331164932, 1.1000837228036342, 1.2095044770593142, 1.3178345728917047, 1.42518289628414, 1.5316392861042363, 1.6372790786086193, 1.7421663193039727, 1.8463560961381578, 1.9498962744977912, 2.0528288136568458, 2.1551907833519186, 2.2570151610156275, 2.358331465616473, 2.4591662677915567, 2.5595436049496603, 2.6594853224141652, 2.7590113563192205, 2.8581399701382715, 2.9568879539371085, 3.0552707933896555, 3.1533028140616617, 3.250997305309709, 3.348366627259252, 3.4454223036440133, 3.5421751027588813, 3.6386351083623, 3.7348117820348694, 3.830714018238404, 3.9263501931089233, 4.021728207846792, 4.116855527428669, 4.21173921525268, 4.306385964235011, 4.400802124799043, 4.4949937301341745, 4.588966519047923, 4.682725956690111, 4.776277253390171, 4.869625381816616, 4.962775092640639, 5.055730928862689, 5.1484972389410935, 5.241078188844844, 5.333477773138066, 5.425699825191104, 5.517748026602179, 5.609625915904176, 5.701336896622771, 5.792884244744973, 5.884271115650772, 5.975500550555107, 6.066575482502435, 6.1574987419519145, 6.248273061987421, 6.338901083183229, 6.429385358153224, 6.5197283558088515, 6.609932465348635, 6.699999999999999, 6.789933200532263, 6.879734238557909, 6.969405219637819, 7.058948186204724, 7.148365120317925, 7.237657946261235, 7.326828532995081, 7.415878696472823, 7.504810201830511, 7.593624765458567, 7.682324056963223, 7.770909701024899, 7.8593832791601885, 7.947746331393581, 8.036000357844621, 8.124146820235726, 8.212187143325579, 8.300122716272579, 8.387954893932564, 8.475684998094684, 8.563314318659067, 8.650844114759645, 8.738275615835265, 8.825610022652047, 8.912848508279675, 8.999992219024222, 9.087042275319849, 9.173999772581656, 9.260865782021705, 9.347641351430225, 9.434327505923834, 9.520925248662422, 9.607435561536404, 9.693859405825773], [0.0, 0.15249334511509008, 0.2845626439643746, 0.4098831078758458, 0.5310126699554076, 0.6491183630760802, 0.7648689246436087, 0.8786969668678793, 0.9909046799848829, 1.1017147141415633, 1.2112976963247013, 1.3197884030672227, 1.4272958817875343, 1.5339101045489465, 1.6397065193021128, 1.7447492665080047, 1.8490935157882362, 1.9527872034949598, 2.0558723511112427, 2.1583860833335176, 2.2603614264869587, 2.3618279433050833, 2.462812243818793, 2.5633384010748914, 2.663428292784777, 2.7631018846400437, 2.8623774671916813, 2.961271855398542, 3.059800557893712, 3.157977921482118, 3.255817255223228, 3.353330937567701, 3.450530509334422, 3.547426754783424, 3.6440297726233974, 3.740349038462744, 3.8363934599502656, 3.932171425640495, 4.027690848448169, 4.122959204417571, 4.217983567419065, 4.312770640291799, 4.407326782874334, 4.501658037300915, 4.595770150887452, 4.689668596886434, 4.7833585933521645, 4.876845120325664, 4.970132935521505, 5.063226588675617, 5.156130434693381, 5.2488486457202805, 5.341385222242808, 5.43374400331469, 5.525928675992508, 5.617942784055397, 5.709789736075126, 5.8014728128957, 5.892995174575299, 5.984359866837788, 6.075569827076171, 6.166627889946067, 6.257536792583439, 6.348299179477493, 6.438917607026639, 6.5293945478027435, 6.619732394546574, 6.70993346391516, 6.800000000000001, 6.889934177633224, 6.9797381054974315, 7.069413829053478, 7.158963333299278, 7.248388545371602, 7.337691337001808, 7.426873526835602, 7.515936882626035, 7.604883123308261, 7.693713920963882, 7.782430902682079, 7.871035652324211, 7.959529712198021, 8.047914584647138, 8.136191733561141, 8.224362585811066, 8.312428532614893, 8.400390930837172, 8.48825110422675, 8.576010344596167, 8.663669912946158, 8.751231040538343, 8.838694929919106, 8.92606275589733, 9.013335666478609, 9.100514783758271, 9.187601204775483, 9.274596002330489, 9.361500225766985, 9.448314901721432, 9.53504103484101, 9.621679608471888, 9.708231585319266], [0.0, 0.1527161296707143, 0.2849783746451791, 0.41048192499784597, 0.531788450836977, 0.6500666900076999, 0.7659863569050551, 0.8799806957620436, 0.9923523382982983, 1.1033242599406239, 1.2130673369526295, 1.3217165427684892, 1.4293810841190087, 1.5361510645118321, 1.6421020421230015, 1.7472982511192432, 1.8517949417220143, 1.9556401203158935, 2.058875869775069, 2.161539369033153, 2.2636636926650007, 2.365278446593689, 2.4664102797259404, 2.567083300277981, 2.667319417923367, 2.7671386275224914, 2.8665592463478524, 2.9655981139240506, 3.064270761541449, 3.1625915569648826, 3.2605738286976385, 3.3582299732746237, 3.4555715483752385, 3.5526093540147374, 3.64935350365548, 3.7458134867492214, 3.841998223958358, 3.9379161160926484, 4.033575087627171, 4.128982625528306, 4.224145814000964, 4.319071365676775, 4.4137656496856845, 4.508234716989168, 4.602484323299656, 4.696519949865763, 4.790346822365089, 4.883969928114227, 4.977394031778511, 5.070623689740791, 5.163663263268731, 5.256516930603093, 5.349188698074865, 5.441682410346424, 5.534001759860941, 5.626150295574824, 5.71813143103958, 5.809948451892349, 5.901604522807988, 5.993102693959998, 6.084445907032759, 6.1756370008231665, 6.26667871646599, 6.357573702313897, 6.448324518500052, 6.53893364120862, 6.629403466676031, 6.719736314943828, 6.809934433382003, 6.900000000000001, 6.989935126561091, 7.0797418615144405, 7.169422192757935, 7.258978050243789, 7.348411308437859, 7.437723788642795, 7.52691726119424, 7.615993447538618, 7.704954022200353, 7.793800614645717, 7.882534811050003, 7.971158155974184, 8.05967215395673, 8.148078271025886, 8.23637793613727, 8.324572542541352, 8.412663449084993, 8.500651981450964, 8.588539433339074, 8.67632706759231, 8.7640161172711, 8.851607786678683, 8.939103252340278, 9.026503663938648, 9.113810145208445, 9.20102379479155, 9.28814568705551, 9.375176872877057, 9.46211838039251, 9.548971215716788, 9.635736363632674, 9.722414788251827], [0.0, 0.152936027064522, 0.2853887176915302, 0.4110729817886828, 0.5325541780371637, 0.6510027271587339, 0.7670893078765004, 0.8812477882559171, 0.9937812357788807, 1.1049129469366137, 1.214814044039067, 1.3236196948699337, 1.4314392634078208, 1.5383629829012613, 1.6444665203232267, 1.7498142023318253, 1.8544613587038288, 1.9584560649486609, 2.061840464536037, 2.1646517899338655, 2.266923163341395, 2.3686842333115488, 2.469961687123061, 2.570779667705806, 2.671160116281286, 2.77112305650068, 2.870686832011701, 2.969868306586339, 3.0686830338786084, 3.167145402341624, 3.265268759670511, 3.3630655202500632, 3.460547258401692, 3.557724789691697, 3.654608242144906, 3.751207118877026, 3.8475303533953986, 3.943586358606188, 4.039383070394999, 4.134927986508765, 4.230228201353009, 4.325290437224945, 4.420121072425487, 4.5147261666289475, 4.609111483835459, 4.703282513186142, 4.797244487883096, 4.891002402424197, 4.98456102833547, 5.07792492856054, 5.171098470646902, 5.264085838851606, 5.356891045274395, 5.44951794011361, 5.5419702211292075, 5.63425144238777, 5.726365022356009, 5.818314251402087, 5.910102298757702, 6.001732218988332, 6.093206958014115, 6.184529358719556, 6.275702166186412, 6.3667280325807365, 6.457609521722056, 6.548349113360014, 6.638949207181406, 6.729412126568423, 6.819740122127069, 6.909935375002921, 7.0, 7.0899360485170515, 7.179745511314356, 7.269430321123084, 7.358992355108153, 7.448433437194724, 7.5377553402675606, 7.626959788251818, 7.716048458083081, 7.805022981573904, 7.893884947183532, 7.982635901696965, 8.071277351819072, 8.159810765689043, 8.248237574320067, 8.336559172968768, 8.42477692243862, 8.512892150321258, 8.600906152179304, 8.688820192674124, 8.77663550664164, 8.864353300119179, 8.95197475132605, 9.039501011600455, 9.12693320629512, 9.214272435633875, 9.301519775531258, 9.388676278377165, 9.47574297378834, 9.562720869328416, 9.649610951198177, 9.73641418489751], [0.0, 0.15315311516599991, 0.28579381841302814, 0.41165648755183254, 0.5333101227132696, 0.6519268059961958, 0.7681781681320415, 0.8824986930489609, 0.9951918784240477, 1.106481337711193, 1.216538436123333, 1.3254985333107732, 1.433471148491007, 1.540546642995956, 1.6468007912055895, 1.7522980110877768, 1.8570937109582477, 1.9612360345681688, 2.064767185208646, 2.16772444819796, 2.270140992751325, 2.3720465095068977, 2.473467723625203, 2.5744288123062793, 2.674951747916534, 2.77505658253012, 2.874761685833006, 2.974083945534801, 3.073038937367465, 3.1716410702080897, 3.2699037106984523, 3.367839290845195, 3.4654594013991304, 3.5627748732789293, 3.6597958488858477, 3.75653184482498, 3.852991807284513, 3.9491841611124796, 4.045116853459235, 4.14079739271454, 4.236232883354213, 4.331430057217569, 4.426395301659325, 4.521134684955324, 4.61565397928752, 4.709958681588707, 4.804054032489355, 4.8979450335768835, 4.9916364631503525, 5.085132890630351, 5.178438689763974, 5.271558050747702, 5.36449499137633, 5.4572533673134425, 5.549836881567853, 5.642249093251037, 5.734493425682116, 5.82657317389983, 5.91849151163451, 6.010251497787496, 6.101856082460569, 6.193308112573626, 6.2846103371049855, 6.375765411985369, 6.466775904673569, 6.557644298439159, 6.648372996375219, 6.73896432516191, 6.829420538599904, 6.919743820930849, 7.009936289960667, 7.100000000000001, 7.189936944634958, 7.279749059340161, 7.369438223945108, 7.459006264963965, 7.5484549577980555, 7.637786028819591, 7.727001157344519, 7.8161019775017015, 7.905090080005155, 7.9939670138354915, 8.082734287836306, 8.171393372230765, 8.25994570006334, 8.348392668571178, 8.436735640489374, 8.52497594529404, 8.613114880386808, 8.701153712224196, 8.789093677394936, 8.87693598364829, 8.964681810876012, 9.052332312050599, 9.139888614122176, 9.227351818876308, 9.314723003754764, 9.402003222641277, 9.489193506614098, 9.576294864667068, 9.663308284400852, 9.750234732685838], [0.0, 0.15336746868385576, 0.28619381622105106, 0.4122326430949912, 0.5340565450161252, 0.652839244532613, 0.7692533123920893, 0.8837338406275993, 0.9965847516924139, 1.1080299720104247, 1.2182411066377865, 1.3273537046745418, 1.4354774386215787, 1.5427027962807862, 1.6491056580861623, 1.75475053216514, 1.8596929043830785, 1.9639809858732704, 2.067657038994663, 2.1707584012501697, 2.2733182882787295, 2.3753664322735966, 2.476929595799904, 2.5780319898961643, 2.6786956176813708, 2.778940559294612, 2.8787852101321203, 2.978246481539589, 3.077339971048815, 3.176080107703594, 3.2744802768536907, 3.3725529279056183, 3.4703096678326357, 3.5677613427123975, 3.6649181091414915, 3.7617894970444787, 3.858384465130656, 3.954711450039495, 4.050778410044206, 4.146592864043312, 4.242161926456075, 4.33749233854371, 4.432590496600694, 4.5274624773960435, 4.622114061190478, 4.71655075261031, 4.810777799620814, 4.904800210809641, 4.998622771163572, 5.09225005649857, 5.185686446683241, 5.278936137778672, 5.372003153202978, 5.464891354016137, 5.557604448409707, 5.650146000476504, 5.742519438326937, 5.834728061611492, 5.926775048502459, 6.018663462182426, 6.110396256882145, 6.20197628350607, 6.293406294879996, 6.384688950651894, 6.475826821873977, 6.566822395291411, 6.65767807736065, 6.748396198018284, 6.838979014219411, 6.929428713262749, 7.019747415918305, 7.109937179371944, 7.2, 7.289937815985992, 7.379752509790431, 7.46944591048388, 7.559019795952516, 7.648475894984789, 7.737815889247018, 7.8270414151551995, 7.916154065649716, 8.005155391879137, 8.094046904798839, 8.182830076689717, 8.271506342601937, 8.360077101728221, 8.448543718710953, 8.536907524886983, 8.625169819473788, 8.713331870700424, 8.801394916886355, 8.889360167471215, 8.977228803998134, 9.065001981053314, 9.152680827164163, 9.240266445658307, 9.327759915485506, 9.415162292004512, 9.502474607736676, 9.589697873088028, 9.676833077041483, 9.763881187820662], [0.0, 0.15357915933617866, 0.28658884494628556, 0.412801641187445, 0.5347936946826222, 0.6537403480503479, 0.770315100376851, 0.8849536442457182, 0.997960321609498, 1.1095593679741265, 1.2199226252594595, 1.3291858296617842, 1.4374588050611792, 1.5448321641583918, 1.651381892123964, 1.7571725861248604, 1.8622598086126887, 1.9666918372657933, 2.070510992777177, 2.173754664186108, 2.276456112978538, 2.3786451123865904, 2.480348461915336, 2.5815904060213954, 2.6823929781943128, 2.7827762862894696, 2.8827587510939696, 2.9823573072959637, 3.0815875739562713, 3.1804640000348647, 3.278999989357094, 3.377208008513186, 3.4750996804973187, 3.572685866357814, 3.6699767367102463, 3.766981834633178, 3.863710131201469, 3.9601700746995494, 4.056369634385304, 4.152316339535473, 4.248017314389236, 4.343479309512662, 4.438708730028932, 4.533711661094728, 4.628493890949169, 4.7230609318165175, 4.8174180389057275, 4.911570227717725, 5.005522289843932, 5.099278807416235, 5.192844166348703, 5.2862225684941775, 5.379418042824234, 5.4724344557282105, 5.56527552051602, 5.65794480619994, 5.750445745622145, 5.842781642987576, 5.9349556808553015, 6.026970926635972, 6.118830338638018, 6.21053677170095, 6.302092982450244, 6.39350163420494, 6.484765301566034, 6.5758864747111065, 6.6668675634182035, 6.75771090083989, 6.848418747046502, 6.9389932923558515, 7.029436660465212, 7.1197509113999455, 7.209938044291954, 7.3, 7.389938663582925, 7.479755866635927, 7.569453389499174, 7.659032963347331, 7.7484962721678965, 7.837844954635584, 7.927080605889487, 8.016204779219201, 8.105218987665651, 8.194124705541896, 8.282923369878876, 8.3716163818006, 8.460205107833044, 8.548690881150682, 8.637075002764282, 8.725358742653412, 8.813543340846772, 8.901630008453361, 8.989619928647182, 9.077514257608085, 9.165314125421174, 9.253020636936975, 9.340634872594508, 9.428157889209217, 9.515590720727628, 9.602934378950417, 9.690189854225578, 9.777358116113152], [0.0, 0.1537882560092468, 0.2869790331350719, 0.4133636669869249, 0.5355218115887134, 0.6546304097775938, 0.7713638776028702, 0.8861585008397451, 0.9993190357996556, 1.1110700232832047, 1.2215835391715089, 1.330995504464491, 1.4394158925664757, 1.5469354395466044, 1.6536302340285596, 1.75956496112778, 1.8647952589436614, 1.9693694708841827, 2.0733299752615975, 2.1767142120200216, 2.2795554879306272, 2.3818836167615305, 2.4837254345050925, 2.5851052186265493, 2.686045032613845, 2.786565011699031, 2.886683601748949, 2.98641776050818, 3.0857831283027557, 3.184794173764782, 3.283464318968797, 3.381806047478183, 3.4798309981117197, 3.5775500467049515, 3.674973377720657, 3.772110547230216, 3.8689705385225266, 3.9655618113842848, 4.06189234592345, 4.157969681667805, 4.25380095255612, 4.349392918345299, 4.444751992879042, 4.539884269598919, 4.634795544624686, 4.729491337685449, 4.823976911145083, 4.918257287333075, 5.012337264364556, 5.106221430609944, 5.199914177954692, 5.293419713972428, 5.386742073120136, 5.479885127051209, 5.5728525941311995, 5.665648048231562, 5.758274926868257, 5.85073653874487, 5.943036070753499, 6.035176594481044, 6.127161072263646, 6.218992362827656, 6.310673226551671, 6.402206330380816, 6.493594252421385, 6.58483948624131, 6.675944444899533, 6.766911464725182, 6.857742808865661, 6.9484406706208794, 7.039007176579505, 7.129444389571608, 7.219754311450891, 7.309938885718577, 7.4, 7.489939488384057, 7.579759133634835, 7.6694606692839775, 7.759045781611718, 7.848516111523811, 7.937873256331115, 8.02711877143802, 8.116254171945439, 8.205280934173697, 8.29420049711024, 8.383014263786693, 8.471723602589547, 8.560329848508381, 8.648834304325277, 8.737238241748868, 8.825542902496142, 8.913749499325016, 9.00185921702037, 9.089873213336185, 9.177792619896163, 9.265618543055078, 9.353352064722957, 9.440994243154087, 9.528546113702705, 9.616008689547046, 9.703382962383449, 9.79066990309201], [0.0, 0.15399482490588157, 0.28736450432624305, 0.4139188984383645, 0.5362411262660127, 0.6555097115198749, 0.7723999761271343, 0.8873487918834966, 1.0006613244500897, 1.1125624162314656, 1.223224374241637, 1.3327833020500655, 1.4413493207777177, 1.5490132883707248, 1.6558513956552616, 1.7619284146320284, 1.8673000581337018, 1.9720147345032868, 2.0761148789757264, 2.179637981784594, 2.282617394438828, 2.385082970752496, 2.4870615827641545, 2.5885775405486102, 2.6896529372295586, 2.7903079350847615, 2.89056100475761, 2.9904291267703833, 3.089927962457253, 3.1890719998846375, 3.2878746791556517, 3.38634850060164, 3.4845051186746847, 3.5823554238187865, 3.679909614176529, 3.7771772586550387, 3.874167352609598, 3.9708883671901147, 4.067348293223458, 4.163554680364528, 4.259514672134425, 4.3552350373697815, 4.450722198529394, 4.5459822572395625, 4.641021017405412, 4.735844006170164, 4.830456492966122, 4.924863506868779, 5.019069852438113, 5.113080124207655, 5.206898719962053, 5.300529852926563, 5.393977562977264, 5.487245726967967, 5.5803380682587465, 5.673258165521491, 5.766009460889445, 5.858595267510456, 5.951018776557265, 6.043283063742538, 6.135391095381437, 6.227345734040163, 6.3191497438050614, 6.410805795203509, 6.502316469804718, 6.593684264525993, 6.684911595667501, 6.7760008026965375, 6.866954151800371, 6.957773839224962, 7.048461994415417, 7.139020682972609, 7.229451909439132, 7.319757619926731, 7.409939704596203, 7.5, 7.589940291296822, 7.6797623143467995, 7.769467757695182, 7.859058264451795, 7.948535434073012, 8.037900824052443, 8.127155951526092, 8.216302294797284, 8.305341294786315, 8.394274356409367, 8.483102849890956, 8.571828112013819, 8.660451447309939, 8.748974129196114, 8.837397401057213, 8.92572247728013, 9.013950544241151, 9.10208276124936, 9.190120261448458, 9.278064152679278, 9.36591551830507, 9.453675418001575, 9.54134488851372, 9.628924944380643, 9.716416578630735, 9.803820763448181], [0.0, 0.15419892968416637, 0.2877453773099831, 0.41446750664675913, 0.5369518603848419, 0.6563785242505306, 0.7734237152428545, 0.8885248841875034, 1.0019876012122464, 1.1140370067278134, 1.2248456361239748, 1.3345497733618963, 1.443259685517105, 1.551066350958876, 1.6580460614967232, 1.7642636749801732, 1.8697749780837036, 1.9746284433107495, 2.0788665621399245, 2.1825268744943664, 2.285642776087112, 2.3882441603004816, 2.490357934789237, 2.592008441848765, 2.6932178038849925, 2.794006209898768, 2.8943921550144793, 2.9943926422603937, 3.0940233537282182, 3.1932987966868587, 3.292232429052945, 3.390836767725765, 3.4891234826042132, 3.587103478566489, 3.6847869672717954, 3.782183530309891, 3.879302174958504, 3.976151383595208, 4.072739157637914, 4.169073056747838, 4.265160233914103, 4.361007466944762, 4.4566211868109376, 4.552007503226028, 4.647172227787655, 4.742120894964717, 4.836858781173624, 4.931390922155408, 5.025722128838011, 5.119857001844561, 5.21379994478853, 5.307555176479383, 5.401126742147653, 5.494518523785533, 5.58773424968804, 5.680777503270237, 5.77365173122757, 5.8663602510991355, 5.958906258287254, 6.051292832581143, 6.143522944227519, 6.235599459586628, 6.327525146408338, 6.419302678759542, 6.510934641631066, 6.602423535249628, 6.6937717791179585, 6.784981715804087, 6.8760556144988865, 6.96699567435922, 7.057804027652563, 7.148482742717534, 7.239033826753553, 7.3294592284517375, 7.419760840478106, 7.509940501819277, 7.6, 7.689941073181116, 7.779765412145873, 7.869474662181873, 7.95907042486541, 8.048554259754397, 8.13792768599565, 8.227192183851837, 8.316349196153054, 8.405400129677554, 8.49434635646595, 8.583189215072752, 8.67193001175897, 8.760570021629192, 8.849110489716265, 8.937552632016631, 9.025897636479005, 9.114146663949015, 9.202300849072232, 9.290361301157821, 9.378329105004923, 9.466205321693774, 9.553990989343403, 9.641687123837615, 9.729294719520967, 9.81681474986617], [0.0, 0.15440063158727363, 0.28812176637009274, 0.41500965622612385, 0.5376542272063135, 0.6572371086633486, 0.7744354021306447, 0.8896871306470985, 1.0032982640454342, 1.1154942372342063, 1.2264478112903319, 1.3362954484429737, 1.4451475600039319, 1.553095243347914, 1.6602148900789213, 1.7665714428846284, 1.8722207614119943, 1.977211381569538, 2.0815858504174014, 2.185381756983304, 2.2886325406639765, 2.391368133944164, 2.493615479675535, 2.595398951994729, 2.696740702245173, 2.7976609458361987, 2.8981782020849804, 2.9983094962608163, 3.0980705309685757, 3.197475832453586, 3.296538876236278, 3.3952721955888325, 3.493687475675105, 3.591795635637562, 3.6896069004929, 3.7871308643641997, 3.8843765463112745, 3.9813524398071825, 4.078066556736193, 4.174526466648033, 4.270739331888388, 4.366711939131108, 4.462450727759432, 4.557961815478647, 4.65325102148831, 4.748323887496754, 4.843185696822274, 4.937841491792966, 5.03229608962977, 5.1265540969737176, 5.220619923198486, 5.314497792632007, 5.4081917557962305, 5.501705699761239, 5.595043357698894, 5.688208317711591, 5.781204031003272, 5.874033819452579, 5.966700882641626, 6.059208304388184, 6.15155905882424, 6.243756016059422, 6.3358019474639855, 6.4276995306026725, 6.519451353847641, 6.611059920696061, 6.702527653815527, 6.793856898838293, 6.885049927923476, 6.976108943104577, 7.06703607943821, 7.157833407968511, 7.248502938520441, 7.3390466223341315, 7.429466354551326, 7.5197639765641515, 7.609941278235555, 7.7, 7.789941834852384, 7.879768430232452, 7.969481389811458, 8.059082275187317, 8.148572607493982, 8.237953868930397, 8.327227504213973, 8.41639492196312, 8.505457496013161, 8.594416566669521, 8.683273441901886, 8.772029398482754, 8.860685683073559, 8.949243513261342, 9.037704078548726, 9.1260685412998, 9.214338037644325, 9.30251367834251, 9.390596549612484, 9.478587713922439, 9.566488210749329, 9.654299057305805, 9.742021249237082, 9.829655761289239], [0.0, 0.15459998956507684, 0.2884937815109257, 0.41554550562637255, 0.5383484320058103, 0.6580857156902331, 0.775435332468499, 0.8908358709431711, 1.0045936960070614, 1.1169345336442664, 1.2280313679961983, 1.3380208374884106, 1.4470134959928453, 1.5551005585067101, 1.6623585152688083, 1.768852392819081, 1.8746381229289732, 1.979764304175275, 2.0842735385537576, 2.1882034636260905, 2.291587561965062, 2.3944558047034428, 2.496835169480793, 2.5987500619049877, 2.700222661920677, 2.801273211038791, 2.9019202524881518, 3.0021808335206313, 3.1020706770158837, 3.2016043279751365, 3.300795279318054, 3.3996560804994425, 3.4981984317707306, 3.5964332663728897, 3.6943708225248857, 3.7920207067374743, 3.8893919497156397, 3.9864930558989844, 4.083332047516509, 4.179916503891544, 4.276253596617601, 4.372350121131305, 4.468212525130253, 4.563846934218751, 4.659259175109951, 4.754454796667492, 4.849439089031348, 4.944217101040136, 5.038793656134662, 5.133173366903931, 5.227360648414884, 5.321359730449793, 5.415174668760535, 5.508809355436073, 5.60226752846844, 5.6955527805928945, 5.788668567469479, 5.88161821526596, 5.974404927695663, 6.0670317925581045, 6.159501787825392, 6.251817787312959, 6.343982565969385, 6.435998804816609, 6.5278690955688266, 6.619595944955657, 6.7111817787727786, 6.802628945681064, 6.893939720773379, 6.985116308926433, 7.076160847953569, 7.167075411572999, 7.2578620122047175, 7.348522603608244, 7.439059083372277, 7.529473295266504, 7.619767031464892, 7.709942034649108, 7.8, 7.889942577084442, 7.979771371644306, 8.0694879472938, 8.159093827130926, 8.248590495268406, 8.337979398289026, 8.427261946629967, 8.516439515900418, 8.605513448136366, 8.69448505299631, 8.783355608901289, 8.872126364122387, 8.960798537818764, 9.049373321028897, 9.137851877617688, 9.22623534518184, 9.314524835915742, 9.402721437440022, 9.490826213594703, 9.578840205198881, 9.666764430778608, 9.754599887264648, 9.842347550661646], [0.0, 0.1547970603881666, 0.2888615286701498, 0.41607520743977766, 0.5390346724700102, 0.6589245869865348, 0.7764237910036669, 0.8919714321991487, 1.0058742659935138, 1.1183583061070064, 1.2295967571864037, 1.3397264318322193, 1.4488580248410006, 1.55708286748302, 1.6644775475002844, 1.7711071743229982, 1.8770277510196371, 1.9822879381162937, 2.0869303919141133, 2.1909927979519064, 2.294508681483175, 2.3975080518453242, 2.500017921066697, 2.6020627258653466, 2.7036646744590174, 2.804844034160783, 2.9056193718367846, 3.0060077564692715, 3.106024930980078, 3.205685458911152, 3.3050028503817774, 3.4039896708437296, 3.5026576354629158, 3.601017691417066, 3.69908008997595, 3.796854449895882, 3.894349813393415, 3.9915746957488816, 4.088537129417334, 4.185244703383573, 4.281704598382845, 4.377923618514014, 4.473908219693652, 4.569664535334458, 4.665198399576981, 4.760515368358074, 4.855620738561128, 4.95051956546059, 5.0452166786457715, 5.139716696585414, 5.234024039974405, 5.328142943986784, 5.422077469544349, 5.515831513697367, 5.609408819202742, 5.702812983375444, 5.796047466280496, 5.889115598325577, 5.982020587307831, 6.07476552496284, 6.167353393058771, 6.2597870690743544, 6.352069331495435, 6.44420286476149, 6.536190263890409, 6.628034038807176, 6.719736618399666, 6.811300354322622, 6.9027275245690065, 6.9940203368261145, 7.085180931632389, 7.176211385349443, 7.26711371296253, 7.357889870721656, 7.448541758634402, 7.539071222820735, 7.629480057739133, 7.7197700082926834, 7.809942771823105, 7.9, 7.989943300612102, 8.07977423926678, 8.169494341003551, 8.259105091826957, 8.348607940163761, 8.438004298249055, 8.527295543445529, 8.61648301949989, 8.705568037740072, 8.794551878216737, 8.88343579079216, 8.972220996179578, 9.060908686935703, 9.149500028409033, 9.237996159646379, 9.326398194259864, 9.41470722125652, 9.502924305832462, 9.591050490133533, 9.679086793984114, 9.767034215585772, 9.854893732187278], [0.0, 0.15499189875483374, 0.28922510991838496, 0.41659890868852856, 0.5397131390694253, 0.6597539553864471, 0.777401052089254, 0.893094129597456, 1.0071403294353338, 1.119765949799749, 1.2311444133449163, 1.3414127048732216, 1.4506816585093965, 1.5590427204796142, 1.666572574924551, 1.7733364132256764, 1.8793903089408306, 1.984782983843635, 2.089557147925429, 2.193750534158666, 2.29739670999407, 2.4005257225408885, 2.5031646178266853, 2.605337863327271, 2.707067695213199, 2.808374406307396, 2.9092765868455546, 3.0097913272941343, 3.109934390390108, 3.209720358006113, 3.30916275726621, 3.408274169437927, 3.507066324432696, 3.6055501832071277, 3.7037360099339556, 3.8016334354763286, 3.899251513431964, 3.996598769799121, 4.093683247143058, 4.190512544000602, 4.2870938501451725, 4.383433978239747, 4.479539392326762, 4.57541623353886, 4.671070343359843, 4.766507284719656, 4.861732361168714, 4.956750634344387, 5.051566939914843, 5.14618590216195, 5.24061194734479, 5.334849315968087, 5.428902074065, 5.522774123590894, 5.616469212013568, 5.709990941175823, 5.80334277549776, 5.896528049578943, 5.989549975254072, 6.082411648150202, 6.175116053788564, 6.26766607326968, 6.360064488576593, 6.452313987527602, 6.544417168406868, 6.63637654429854, 6.728194547147662, 6.819873531568931, 6.911415778422554, 7.002823498174571, 7.094098834057659, 7.185243865046883, 7.276260608663698, 7.367151023620381, 7.457917012315997, 7.548560423194167, 7.6390830529719995, 7.729486648748839, 7.819772910002797, 7.909943490482381, 8.0, 8.089944006133607, 8.179777035842239, 8.269500577000825, 8.359116079859223, 8.44862495843006, 8.538028591809669, 8.62732832543609, 8.716525472287794, 8.805621314026592, 8.89461710208793, 8.983514058721518, 9.072313377985104, 9.161016226693974, 9.249623745328622, 9.338137048902842, 9.426557227794364, 9.514885348540036, 9.603122454597417, 9.691269567074508, 9.779327685429287, 9.867297788140554], [0.0, 0.15518455739153597, 0.28958462364668036, 0.41711675109477286, 0.5403840154082453, 0.6605740453306624, 0.7783673801881396, 0.8942042669584235, 1.0083922289500549, 1.1211578456539657, 1.2326747552928772, 1.3430801129445606, 1.452484890503215, 1.5609806478648596, 1.6686441644903915, 1.7755407127957263, 1.8817264360394779, 1.987250116557597, 2.0921545174309637, 2.196477418535019, 2.3002524290456305, 2.403509633421321, 2.5062761113085132, 2.608576360596676, 2.7104326450964535, 2.8118652828552375, 2.912892887216828, 3.0135325698915425, 3.1138001132098134, 3.213710117169894, 3.313276125710384, 3.412510735737628, 3.511425691743618, 3.6100319683096966, 3.708339842367208, 3.806358956750696, 3.9040983763117154, 4.001566637646546, 4.098771793317546, 4.195721451306705, 4.292422810324505, 4.388882691502224, 4.48510756691726, 4.581103585335829, 4.676876595502837, 4.7724321672630845, 4.867775610759428, 4.96291199392097, 5.057846158426732, 5.152582734306675, 5.247126153321826, 5.34148066124796, 5.43565032917241, 5.529639063900765, 5.623450617559017, 5.717088596467144, 5.810556469351604, 5.903857574956946, 5.99699512911026, 6.089972231286538, 6.182791870718085, 6.275456932086702, 6.3679702008335015, 6.460334368117805, 6.552552035453503, 6.644625719048569, 6.736557853871011, 6.828350797462371, 6.920006833518017, 7.011528175251654, 7.102916968560047, 7.194175295002476, 7.285305174608224, 7.376308568524295, 7.4671873815144805, 7.557943464320062, 7.64857861589151, 7.7390945854998545, 7.8294930747357, 7.919775739403202, 8.009944191315807, 8.1, 8.18994469431287, 8.279779763978807, 8.369506661050366, 8.459126801297824, 8.548641565531765, 8.638052300862642, 8.727360321900983, 8.816566911901743, 8.905673323855929, 8.994680781532537, 9.083590480473557, 9.172403588944654, 9.261121248843967, 9.349744576571279, 9.438274663859685, 9.526712578571765, 9.61505936546212, 9.703316046908013, 9.79148362360977, 9.879563075262467], [0.0, 0.15537508714732026, 0.2899401647427127, 0.4176288713344118, 0.5410474785531361, 0.6613850732682989, 0.7793230303465732, 0.895302137284367, 1.0096302949557585, 1.1225343610374463, 1.2341881869386229, 1.344729096130899, 1.454268196755587, 1.5628971611224984, 1.6706928629594606, 1.7777206548214042, 1.8840367488975212, 1.9896899874168779, 2.0947231859632542, 2.1991741707968004, 2.3030765923574634, 2.4064605720403325, 2.5093532227392004, 2.6117790724211205, 2.7137604122314074, 2.8153175851631853, 2.9164692274130166, 3.0172324717003334, 3.117623119732518, 3.2176557894331523, 3.317344041369574, 3.4167004879141336, 3.51573688797827, 3.6144642296175022, 3.7128928023808045, 3.811032260941829, 3.908891681281615, 4.006479610477352, 4.103804110978032, 4.20087280010644, 4.297692885411361, 4.394271196398803, 4.490614213092336, 4.586728091807399, 4.682618688469769, 4.77829157976269, 4.873752082348612, 4.969005270378851, 5.06405599147686, 5.158908881357175, 5.253568377221974, 5.348038730059835, 5.442324015956417, 5.53642814651394, 5.630354878465115, 5.724107822557622, 5.817690451776691, 5.9111061089660595, 6.004358013901084, 6.097449269862177, 6.190382869751712, 6.283161701793191, 6.375788554847587, 6.468266123378328, 6.560597012093342, 6.65278374028991, 6.7448287459256, 6.836734389436458, 6.928502957321684, 7.020136665512284, 7.1116376625396756, 7.203008032518798, 7.294249797959051, 7.385364922415259, 7.476355312989813, 7.567222822696263, 7.657969252693764, 7.748596354401037, 7.839105831497832, 7.929499341821241, 8.019778499163632, 8.109944874978499, 8.200000000000001, 8.289945365781557, 8.379782426158497, 8.469512598639328, 8.559137265729941, 8.648657776194717, 8.73807544625822, 8.827391560750934, 8.916607374202238, 9.00572411188363, 9.09474297080494, 9.183665120666184, 9.272491704767484, 9.361223840879292, 9.449862622075097, 9.538409117528554, 9.62686437327698, 9.715229412952873, 9.80350523848518, 9.891692830771811], [0.0, 0.15556353708263265, 0.2902918247565116, 0.41813540127581056, 0.5417036993424934, 0.6621872480349383, 0.7802682486396257, 0.896388023271329, 1.010854846248164, 1.1238958503959229, 1.2356850979831289, 1.3463600790370474, 1.4560320364588313, 1.564792753744977, 1.672719197861227, 1.7798768006267285, 1.8863218424088075, 1.992103224675853, 2.097263814941424, 2.201841485344044, 2.3058699271373033, 2.409379298249656, 2.512396744459338, 2.614946823482662, 2.7170518535012262, 2.81873220218158, 2.9200065283235896, 3.020891985426464, 3.1214043943630188, 3.221558390786491, 3.3213675517114365, 3.420844504807387, 3.5200010232478243, 3.6188481084153596, 3.7173960623388638, 3.8156545514018627, 3.9136326625933884, 4.011338953357134, 4.108781495920802, 4.205967916846005, 4.302905432423357, 4.399600880442174, 4.49606074878546, 4.59229120123547, 4.688298100820464, 4.7840870309874814, 4.8796633148474, 4.975032032705825, 5.070198038065754, 5.1651659722642425, 5.259940277885225, 5.35452521107318, 5.448924852857533, 5.543143119584771, 5.637183772544039, 5.731050426862386, 5.824746559737329, 5.918275518067038, 6.011640525532046, 6.104844689176644, 6.197891005533207, 6.2907823663282825, 6.38352156380537, 6.476111295695936, 6.568554169867081, 6.66085270867167, 6.7530093530242, 6.845026466223619, 6.936906337542356, 7.028651185599058, 7.12026316153103, 7.211744351980977, 7.303096781911339, 7.394322417258483, 7.485423167437865, 7.576400887710505, 7.6672573814201295, 7.757994402109703, 7.848613655525323, 7.939116801514822, 8.02950545582789, 8.119781191823991, 8.209945542093866, 8.299999999999999, 8.389946021141034, 8.479785024744729, 8.56951839499378, 8.659147482288446, 8.7486736044497, 8.838098047866358, 8.927422068589385, 9.016646893376372, 9.105773720688967, 9.194803721645885, 9.28373804093392, 9.372577797679238, 9.461324086281083, 9.549977977209881, 9.638540517771657, 9.727012732840445, 9.815395625560397, 9.903690178019131], [0.0, 0.1557499545529136, 0.29063969205645357, 0.4186364682044916, 0.5423528426775387, 0.6629807712084659, 0.7812032725904806, 0.8974621977907709, 1.0120661905438308, 1.1252426558570174, 1.2371658645840293, 1.347973471511455, 1.4577768528468806, 1.5666679020743197, 1.6747236783918418, 1.7820096920279336, 1.888582290792742, 1.994490434755072, 2.0997770427981903, 2.204480032444188, 2.3086331353201155, 2.4122665454937735, 2.5154074412731773, 2.6180804098030475, 2.720307796009674, 2.8221099919669275, 2.9235056788341933, 3.024512030666347, 3.1251448872949323, 3.225418901911626, 3.3253476678008154, 3.4249438277642317, 3.5242191690835782, 3.623184706324827, 3.721850753862145, 3.8202269896626393, 3.918322511604613, 4.016145887386457, 4.113705198909118, 4.2110080818733975, 4.308061761217453, 4.404873082924574, 4.501448542652431, 4.597794311569566, 4.693916259730117, 4.789819977271975, 4.885510793684896, 4.9809937953624, 5.076273841623612, 5.171355579367476, 5.266243456501636, 5.3609417342708605, 5.455454498595024, 5.549785670513717, 5.643939015823371, 5.737918153983176, 5.831726566357499, 5.925367603855225, 6.0188444940199375, 6.112160347619213, 6.205318164776282, 6.298320840682951, 6.391171170928771, 6.483871856477993, 6.576425508322825, 6.668834651838758, 6.761101730865325, 6.853229111533501, 6.945219085859038, 7.037073875119229, 7.12879563302917, 7.2203864487320635, 7.3118483496169375, 7.403183303976011, 7.494393223512864, 7.585479965711742, 7.676445336077384, 7.7672910902540915, 7.858018936032018, 7.948630535248051, 8.039127505588095, 8.129511422297027, 8.21978381980215, 8.309946193255493, 8.4, 8.489946660964144, 8.579787561989336, 8.669524055094069, 8.759157459678507, 8.848689063672994, 8.938120124633668, 9.027451870788187, 9.116685502034361, 9.205822190894297, 9.294863083426511, 9.383809300098259, 9.472661936620241, 9.561422064745669, 9.650090733035594, 9.738668967592188, 9.827157772761716, 9.915558131808663], [0.0, 0.155934385287342, 0.29098385197620363, 0.4191321950347889, 0.5429950677965217, 0.6637658374442595, 0.7821283315653953, 0.8985249243433108, 1.0132646249918404, 1.1265751077991422, 1.2386308499811034, 1.3495696693277208, 1.4595030739323058, 1.5685230660942027, 1.6767067962608455, 1.7841198522344175, 1.8908186485491165, 1.9968522032496325, 2.10226348604147, 2.207090459346613, 2.3113668947352948, 2.4151230220295106, 2.518386051720367, 2.621180600067363, 2.7235290384564506, 2.8254517831086985, 2.926967537304719, 3.0280934954359804, 3.128845516090706, 3.229238269812094, 3.3292853659809705, 3.428999462369993, 3.528392360218731, 3.627475087136015, 3.726257969709739, 3.82475069736714, 3.92296237875974, 4.020901591731337, 4.118576427753034, 4.215994531567416, 4.3131631366680265, 4.410089097144801, 4.506778916347217, 4.603238772751385, 4.699474543362445, 4.795491824937831, 4.891295953278191, 4.986892020800083, 5.082284892576775, 5.177479221009818, 5.272479459273831, 5.36728987365952, 5.461914554925087, 5.556357428753206, 5.65062226539956, 5.744712688609313, 5.838632183869276, 5.932384106056296, 6.025971686535844, 6.1193980397591, 6.21266616940188, 6.30577897408432, 6.398739252706358, 6.491549709430583, 6.5842129583409985, 6.6767315278035095, 6.769107864551514, 6.861344337517832, 6.9534432414322955, 7.045406800202518, 7.137237170093907, 7.2289364427235165, 7.3205066478811, 7.411949756189623, 7.503267681616401, 7.594462283845213, 7.685535370518782, 7.776488699360346, 7.867323980182333, 7.958042876789491, 8.048647008783297, 8.139137953273952, 8.229517246505742, 8.31978638540118, 8.409946829028911, 8.5, 8.589947285796894, 8.679790040039075, 8.769529583689069, 8.859167206202322, 8.948704166624097, 9.038141694636456, 9.127480991558063, 9.216723231299461, 9.305869561276271, 9.394921103282542, 9.483878954326459, 9.572744187430345, 9.661517852396901, 9.750200976543354, 9.838794565405262, 9.92729960341144], [0.0, 0.1561168734630637, 0.29132438695323104, 0.4196227005093651, 0.5436305285331993, 0.6645426347911588, 0.7830436471460135, 0.8995764574864449, 1.0144504366561333, 1.1278935253877764, 1.240080405085894, 1.3511490548270197, 1.4612111132010746, 1.5703586901766104, 1.6786690264893225, 1.7862077866980264, 1.8930314513581854, 1.9991890958797305, 2.1047237402551064, 2.209673391333274, 2.3140718602069352, 2.417949412075692, 2.5213332892747684, 2.624248136871782, 2.726716352433654, 2.8287583760743162, 2.930392932962611, 3.0316372376124, 3.1325071671710254, 3.2330174093504502, 3.3331815894583983, 3.433012380080769, 3.5325215962679843, 3.631720278534355, 3.7306187655528604, 3.829226758090159, 3.9275533754575207, 4.025607205537294, 4.1233963492699335, 4.220928460344578, 4.318210780720043, 4.415250172507525, 4.512053146667295, 4.60862588890606, 4.704974283106751, 4.801103932576621, 4.8970201793607435, 4.99272812183527, 5.088232630767009, 5.18353836400216, 5.278649779926841, 5.3735711498245475, 5.468306569240848, 5.562859968452595, 5.65723512212776, 5.751435658252332, 5.845465066392145, 5.939326705350221, 6.03302381027366, 6.126559499258446, 6.21993677949556, 6.313158552997363, 6.406227621939311, 6.499146693648641, 6.591918385268592, 6.684545228123982, 6.777029671811594, 6.869374088036582, 6.961580774214274, 7.053651956854894, 7.145589794747305, 7.237396381956352, 7.3290737506472325, 7.420623873749103, 7.512048667469179, 7.6033499936675994, 7.694529662102553, 7.785589432554321, 7.876531016836305, 7.96735608070038, 8.05806624564343, 8.148663090621325, 8.2391481536762, 8.329522933482401, 8.419788890816104, 8.509947449953234, 8.6, 8.689947896160001, 8.779792460941676, 8.869534985309503, 8.959176729782191, 9.048718925480884, 9.138162775130136, 9.227509454014305, 9.316760110891815, 9.405915868869542, 9.494977826239483, 9.583947057279708, 9.67282461302149, 9.761611521984314, 9.850308790880502, 9.938917405290935], [0.0, 0.15629746177521228, 0.2916613766594722, 0.42010809938741883, 0.5442593735606619, 0.6653113449895225, 0.7839494334805716, 0.9006170432380197, 1.0156239029705063, 1.1291982170813448, 1.2415148690379023, 1.3527119975241146, 1.4629013702679263, 1.5721752037861658, 1.6806108281628076, 1.788273983914196, 1.8952212169297196, 2.001501659387327, 2.107158381042873, 2.2122294327097682, 2.3167486645917235, 2.420746376897632, 2.5242498434753107, 2.6272837379005773, 2.7298704836487557, 2.832030544477896, 2.933782667217192, 3.035144086293409, 3.1361306972197913, 3.236757204698323, 3.3370372497978136, 3.436983519763186, 3.53660784331193, 3.6359212737294806, 3.7349341616480842, 3.833656219055769, 3.9320965758125754, 4.03026382973489, 4.128166091133939, 4.225811022552269, 4.323205874325838, 4.4203575165035955, 4.517272467577371, 4.613956920409191, 4.710416765688174, 4.806657613203201, 4.902684811178762, 4.998503463888558, 5.094118447733661, 5.189534425948239, 5.28475586207565, 5.379787032340199, 5.474632037024982, 5.569294810953201, 5.663779133159179, 5.758088635825578, 5.852226812554791, 5.946197026035141, 6.040002515155982, 6.133646401620161, 6.227131696097229, 6.320461303956452, 6.4136380306147025, 6.506664586530924, 6.599543591875734, 6.692277580902065, 6.784869006040273, 6.877320241738984, 6.969633588071059, 7.061811274122245, 7.153855461178582, 7.245768245727229, 7.3375516622840875, 7.429207686060506, 7.5207382354802705, 7.612145174557232, 7.703430315143015, 7.794595419053529, 7.885642200082317, 7.976572325908116, 8.067387419903474, 8.15808906285072, 8.248678794571124, 8.33915811547262, 8.429528488021141, 8.519791338140145, 8.609948056542686, 8.700000000000001, 8.789948492550339, 8.879794826651501, 8.969540264280306, 9.059186037981995, 9.148733351872375, 9.238183382595318, 9.32753728023807, 9.416796169206666, 9.50596114906355, 9.595033295329468, 9.68401366025147, 9.772903273538782, 9.861703143068246, 9.950414255560808], [0.0, 0.1564761915030063, 0.2919948981246726, 0.42058850262234504, 0.5448817466214972, 0.6660721437525841, 0.7848458976154259, 0.901646919457098, 1.0167852921681126, 1.1304894811087458, 1.242934569729616, 1.3542588546794079, 1.4645742314950236, 1.5739730221449904, 1.6825326451420057, 1.7903189161782, 1.8973884458044816, 2.0037904223825707, 2.1095679649195724, 2.2147591677408767, 2.3193979197586763, 2.4235145558308475, 2.5271363809934773, 2.6302880970371825, 2.732992153079045, 2.8352690362778894, 2.9371375149003405, 3.0386148430811235, 3.1397169345103664, 3.240458510705218, 3.340853228333361, 3.4409137891478747, 3.5406520353926587, 3.640079032992831, 3.7392051444168253, 3.838040092758549, 3.936593018318247, 4.034872528744107, 4.13288674362168, 4.230643334255807, 4.328149559273371, 4.4254122965793785, 4.522438072119706, 4.619233085838057, 4.71580323515969, 4.812154136288408, 4.908291143564517, 5.004219367098574, 5.099943688867923, 5.1954687774392525, 5.29079910146008, 5.385938942044675, 5.480892404164897, 5.575663427143512, 5.670255794336254, 5.7646731420792685, 5.858918967969964, 5.952996638541972, 6.046909396388394, 6.140660366781814, 6.234252563834554, 6.327688896238234, 6.420972172617787, 6.514105106531626, 6.607090321146597, 6.699930353613606, 6.7926276591674215, 6.8851846149719025, 6.9776035237301, 7.06988661707677, 7.162036058769431, 7.254053947692625, 7.345942320688768, 7.43770315522791, 7.529338371927595, 7.620849836933219, 7.7122393641683, 7.8035087174634254, 7.894659612571898, 7.985693719079484, 8.076612662215098, 8.167418024568727, 8.258111347722462, 8.348694133799988, 8.439167846939602, 8.529533914695339, 8.619793729370564, 8.709948649288012, 8.8, 8.889949075442289, 8.97979713903479, 9.069545424732194, 9.159195138027238, 9.248747456909314, 9.33820353278082, 9.427564491333575, 9.516831433387399, 9.606005435692918, 9.695087551700452, 9.784078812296723, 9.872980226511103, 9.961792782192877], [0.0, 0.15665310257218432, 0.29232502585289494, 0.4210640175295537, 0.5454977867452023, 0.6668252010322195, 0.7857332398082123, 0.9026663162037217, 1.017934863687167, 1.1317676059204278, 1.2443398243024497, 1.3557899718393023, 1.4662300705763283, 1.5757525468607343, 1.6844349067341364, 1.7923430402995024, 1.8995336221112995, 2.006055896143322, 2.1119530301527747, 2.217263161534267, 2.3220202175146, 2.426254567248063, 2.5299935466416565, 2.6332618854136984, 2.7360820580621112, 2.8384745749083824, 2.9404582254384284, 3.0420502832943996, 3.143266680158349, 3.2441221541914858, 3.3446303775016424, 3.4448040662024257, 3.544655075926507, 3.6441944851100754, 3.7434326679373098, 3.842379358494992, 3.941043707417337, 4.039434332084288, 4.137559361261353, 4.2354264749265065, 4.333042939913191, 4.430415641902533, 4.527551114218604, 4.624455563814731, 4.721134894783764, 4.817594729679154, 4.913840428894794, 5.009877108318699, 5.105709655447754, 5.201342744126896, 5.296780848055872, 5.392028253189153, 5.4870890691396585, 5.581967239683926, 5.676666552455131, 5.771190647900641, 5.865543027572227, 5.959727061809703, 6.053745996872228, 6.147602961565799, 6.241300973410477, 6.334842944386434, 6.428231686294016, 6.521469915759569, 6.614560258915676, 6.707505255781732, 6.800307364368378, 6.892968964527084, 6.9854923615643205, 7.077879789637916, 7.1701334149517235, 7.2622553387632705, 7.354247600217816, 7.4461121790211235, 7.537850997962178, 7.62946592529623, 7.720958776997605, 7.812331318891069, 7.903585268669746, 7.994722297807026, 8.085744033369295, 8.176652059735813, 8.26744792023157, 8.358133118678545, 8.448709120870381, 8.539177355975093, 8.629539217870184, 8.719796066414098, 8.809949228657812, 8.9, 8.989949645288997, 9.079799399874586, 9.169550470612435, 9.25920403682376, 9.348761251212732, 9.438223240743863, 9.52759110748156, 9.616865929393814, 9.70604876112197, 9.795140634718267, 9.884142560352876, 9.973055526991942], [0.0, 0.15682823361401999, 0.2926518319326447, 0.4215347479450938, 0.546107628453685, 0.6675706812701564, 0.7866116538238499, 0.9036754560789685, 1.0190728685544261, 1.1330328706147503, 1.2457309396155172, 1.3573056833469577, 1.4678692490899647, 1.5775141665201966, 1.6863180283274974, 1.794346798276973, 1.9016572142826638, 2.0082985753708864, 2.114314097558434, 2.219741960875789, 2.324616130478848, 2.428967009473233, 2.5328219643262453, 2.6362057524029026, 2.7391408733265936, 2.841647860348412, 2.943745523960065, 3.0454511571148486, 3.1467807093057116, 3.247748935170457, 3.348369522101713, 3.448655200429121, 3.548617839039411, 3.6482685287539605, 3.7476176553548135, 3.8466749638110183, 3.9454496149867824, 4.043950235895888, 4.142184964391433, 4.240161489037257, 4.337887084790794, 4.435368645031047, 4.532612710386046, 4.629625494748211, 4.726412908810898, 4.822980581413319, 4.91933387894204, 5.01547792300441, 5.11141760656131, 5.207157608682825, 5.302702408070093, 5.39805629546909, 5.4932233850870915, 5.588207625109602, 5.683012807404197, 5.777642576488097, 5.87210043782765, 5.966389765530557, 6.060513809485145, 6.154475701995278, 6.248278463954462, 6.341925010598334, 6.435418156870702, 6.52876062243498, 6.621955036359646, 6.715003941503721, 6.80790979862579, 6.900674990237888, 6.993301824223715, 7.085792537238786, 7.1781492979086705, 7.270374209840006, 7.362469314457725, 7.454436593680809, 7.546277972447838, 7.6379953211026805, 7.729590457649846, 7.821065149888207, 7.912421117431192, 8.003660033620822, 8.094783527342472, 8.18579318474666, 8.276690550883746, 8.367477131256916, 8.4581543932985, 8.548723767774263, 8.639186650119992, 8.729544401714396, 8.819798351092034, 8.909949795099777, 8.999999999999998, 9.089950202523555, 9.179801610875318, 9.26955540569493, 9.359212740975236, 9.448774744940645, 9.538242520887614, 9.62761714798926, 9.71689968206597, 9.806091156323765, 9.895192582062144, 9.984204949352868], [0.0, 0.1570016220211393, 0.29297538614102936, 0.4220007943756844, 0.546711401955632, 0.6683087436355711, 0.7874813272145078, 0.9046745545465823, 1.0201995497478906, 1.134285545341249, 1.2471082126890045, 1.3588063128253762, 1.4694921170206559, 1.579258257250787, 1.6881824119916526, 1.7963306179375234, 1.9037596757315565, 2.0105189389047933, 2.1166516712534094, 2.2221960950195134, 2.3271862129106857, 2.4316524616460504, 2.5356222379491196, 2.6391203265565135, 2.742169251967077, 2.8447895701333503, 2.9470001123438134, 3.048818190670754, 3.1502597722407897, 3.2513396280043674, 3.3520714604868185, 3.452468014092366, 3.5525411708299135, 3.652302033782787, 3.7517610002154935, 3.850927825871063, 3.9498116817419033, 4.048421204379774, 4.146764540634936, 4.244849387571665, 4.3426830281905415, 4.440272363491854, 4.537623941334912, 4.6347439824821794, 4.731638404161843, 4.8283128414363246, 4.924772666625239, 5.021023006998355, 5.117068760926184, 5.212914612651962, 5.308565045828457, 5.404024355945466, 5.499296661758912, 5.594385915819388, 5.689295914186739, 5.784030305407543, 5.878592598823771, 5.972986172273518, 6.067214279238171, 6.1612800554846485, 6.2551865252463426, 6.348936606981955, 6.442533118747482, 6.5359787832131815, 6.629276232354213, 6.722428011840971, 6.81543658515264, 6.908304337435346, 7.001033579124373, 7.09362654934807, 7.186085419129625, 7.278412294401412, 7.370609218845352, 7.462678176571625, 7.55462109464701, 7.646439845483221, 7.738136249094739, 7.829712075234908, 7.921169045418349, 8.012508834837123, 8.103733074177487, 8.194843351343602, 8.285841213094029, 8.376728166596424, 8.467505680905505, 8.558175188368882, 8.64873808596513, 8.73919573657809, 8.82954947021114, 8.91980058514494, 9.009950349041834, 9.1, 9.189950747560095, 9.279803773667073, 9.369560233589624, 9.459221256799513, 9.548787947813002, 9.638261386996332, 9.727642631337195, 9.816932715183928, 9.906132650954108, 9.99524342981412], [0.0, 0.1571733040003473, 0.29329575604233615, 0.4224622541407052, 0.5473092333304611, 0.6690395422499569, 0.7883424415845703, 0.9056638202373708, 1.0213151425400735, 1.1355258916822886, 1.248471931123787, 1.3602921736346025, 1.4710990132541653, 1.580985183251901, 1.690028447045455, 1.7982949135405197, 1.9058414454920114, 2.0127174503992786, 2.118966239367653, 2.224626076435437, 2.3297310014923243, 2.4343114845401272, 2.538394952260799, 2.642006216493181, 2.7451678263667585, 2.8479003603120976, 2.950222670209778, 3.0521520870629146, 3.1537045954582514, 3.2548949824983358, 3.3557369656922713, 3.4562433033803446, 3.556425890564489, 3.6562958424693037, 3.755863567728749, 3.855138832753805, 3.9541308185654005, 4.052848171159403, 4.151299046294692, 4.249491149452315, 4.347431771596851, 4.445127821274858, 4.542585853505763, 4.6398120958544595, 4.73681247201965, 4.833592623225722, 4.930157927666949, 5.026513518219789, 5.122664298611144, 5.2186149582064925, 5.3143699855614965, 5.40993368086309, 5.505310167371074, 5.600503401958174, 5.695517184835243, 5.790355168538561, 5.885020866247579, 5.979517659494076, 6.073848805317133, 6.168017442912645, 6.262026599821017, 6.355879197692298, 6.4495780576640405, 6.543125905383756, 6.6365253757046805, 6.729779017080909, 6.822889295685452, 6.915858599272605, 7.008689240804122, 7.101383461856849, 7.193943435827999, 7.286371270952791, 7.3786690131479205, 7.470838648693204, 7.562882106762674, 7.654801261815536, 7.746597935856465, 7.838273900574038, 7.92983087936536, 8.021270549254321, 8.112594542710346, 8.20380444937397, 8.294901817695143, 8.385888156489617, 8.476764936418528, 8.567533591395764, 8.658195519927501, 8.748752086387901, 8.839204622234707, 8.929554427168252, 9.01980277023708, 9.10995089089323, 9.200000000000001, 9.289951280794805, 9.379805889809624, 9.46956495775131, 9.559229590343914, 9.648800869135062, 9.73827985226827, 9.827667575222938, 9.916965051523727, 10.006173273420865], [0.0, 0.15734331462265458, 0.293613007081385, 0.4229192215066623, 0.5479012447025249, 0.6697632264000709, 0.7891951728415575, 0.9066434552374686, 1.0224198748230744, 1.1367541630144897, 1.2498223734988043, 1.3617635693046892, 1.4726902660455325, 1.5826952972981303, 1.6918565105949657, 1.8002400863501618, 1.9079029488257224, 2.0148945589639133, 2.121258274718658, 2.2270324015175578, 2.332251016070445, 2.4369446213378083, 2.54114067366839, 2.6448640117394064, 2.7481372090711997, 2.8509808663535354, 2.9534138558586225, 3.055453527336111, 3.1571158826628904, 3.2584157249363654, 3.3593667865035437, 3.459981839505104, 3.560272791809521, 3.6602507706644656, 3.7599261959626724, 3.8593088446792145, 3.958407907765913, 4.057232040570803, 4.155789407674654, 4.254087722893351, 4.352134285077931, 4.449936010247768, 4.547499460512695, 4.644830870173814, 4.741936169337351, 4.838821005329675, 4.9354907621625195, 5.031950578264456, 5.1282053626666295, 5.224259809806894, 5.320118413096076, 5.415785477372519, 5.511265130356056, 5.606561333199467, 5.701677890224204, 5.796618457917407, 5.89138655325865, 5.985985561437435, 6.080418743015905, 6.174689240585547, 6.268800084961585, 6.362754200954348, 6.456554412752946, 6.550203448953157, 6.643703947258277, 6.737058458879002, 6.830269452655942, 6.923339318926172, 7.016270373153321, 7.109064859338893, 7.201724953231016, 7.294252765345337, 7.386650343811568, 7.478919677058038, 7.571062696345524, 7.663081278160786, 7.75497724647932, 7.846752374906095, 7.938408388702375, 8.029946966706047, 8.121369743152336, 8.212678309401257, 8.30387421557768, 8.394958972129409, 8.485934051308357, 8.576800888579442, 8.667560883961572, 8.758215403304721, 8.848765779506836, 8.939213313674108, 9.029559276227777, 9.119804907960571, 9.209951421045547, 9.3, 9.389951802606905, 9.47980796079617, 9.569569581487887, 9.659237747399562, 9.74881351781928, 9.838297929346492, 9.927691996602169, 10.016996712909833], [0.0, 0.15751168787068054, 0.29392720267198585, 0.42337178781460144, 0.5484875544061769, 0.6704799407397158, 0.790039691433888, 0.9076136553614835, 1.0235139674166054, 1.1379706048512006, 1.2511598097475969, 1.3632207939459595, 1.474266193462754, 1.584388941216085, 1.6936669680431637, 1.802166525177844, 1.9099445977968434, 2.017050699770634, 2.123528235450532, 2.2294155512548177, 2.334746760358846, 2.4395523983643574, 2.543859951001161, 2.647694283526368, 2.7510779936162693, 2.85403170400545, 2.9565743071613575, 3.0587231713996275, 3.1604943157207748, 3.261902559063015, 3.3629616484683535, 3.463684369744952, 3.5640826435039066, 3.664167608900169, 3.7639496969768107, 3.8634386951712574, 3.962643804270576, 4.0615736888849, 4.1602365223319255, 4.258640026682099, 4.3567915085969675, 4.454697891496743, 4.552365744513379, 4.6498013086193115, 4.747010520266579, 4.843999032824758, 4.940772236067022, 5.037335273920578, 5.133693060669732, 5.2298502957758615, 5.325811477458194, 5.421580915161687, 5.517162741023251, 5.612560920434499, 5.70777926178789, 5.802821425483378, 5.89769093226406, 5.99239117094193, 6.086925405568265, 6.181296782097442, 6.275508334587963, 6.369562990979999, 6.463463578484828, 6.557212828618103, 6.650813381905726, 6.744267792288449, 6.8375785312487904, 6.930747991681726, 7.023778491528667, 7.116672277192425, 7.2094315267493965, 7.302058352973695, 7.394554806186741, 7.4869228769446785, 7.57916449857493, 7.671281549572287, 7.763275855864082, 7.855149192953222, 7.946903287947175, 8.038539821480354, 8.13006042953678, 8.221466705179385, 8.312760200191828, 8.403942426638245, 8.495014858346009, 8.585978932316129, 8.676836050065676, 8.76758757890622, 8.858234853162045, 8.948779175331655, 9.039221817195772, 9.129564020874895, 9.219806999839228, 9.309951939873626, 9.4, 9.489952313359543, 9.579809988056859, 9.669574107968074, 9.759245733514819, 9.84882590240581, 9.938315630347766, 10.027715911727164], [0.0, 0.15767845668359712, 0.29423840428080705, 0.4238200416009121, 0.5490682771422759, 0.6711898254810523, 0.7908761625763063, 0.9085746104114719, 1.0245976343600371, 1.1391754551672029, 1.2524845015153079, 1.3646641326379823, 1.4758271038074433, 1.5860664463364778, 1.6954601735732098, 1.8040746068963809, 1.911966791816963, 2.0191862946292805, 2.125776565639919, 2.231775991867236, 2.3372187226046295, 2.4421353257840486, 2.5465533162363987, 2.6504975855454047, 2.753990755313122, 2.8570534701088905, 2.9597046424029543, 3.061961658900019, 3.1638405555610536, 3.265356167014135, 3.36652225485624, 3.4673516184327724, 3.567856190976027, 3.668047123434769, 3.7679348578961576, 3.8675291921602724, 3.9668393367557084, 4.065873965466436, 4.164641260263825, 4.263148951394225, 4.361404353255266, 4.459414396597475, 4.557185657508013, 4.6547243835670775, 4.752036517512049, 4.84912771869813, 4.946003382605028, 5.042668658606192, 5.139128466189029, 5.235387509790571, 5.3314502923926295, 5.427321128002877, 5.52300415313321, 5.618503337373687, 5.71382249314898, 5.808965284734568, 5.9039352366012094, 5.998735741148875, 6.093370065884723, 6.187841360093977, 6.282152661047512, 6.376306899785517, 6.470306906512641, 6.564155415636584, 6.657855070478963, 6.751408427684566, 6.844817961352648, 6.93808606691171, 7.031215064757334, 7.124207203670759, 7.217064664034463, 7.309789560859506, 7.4023839466381265, 7.494849814034016, 7.587189098421543, 7.679403680284399, 7.771495387483154, 7.863465997400566, 7.9553172389727145, 8.047050794613419, 8.138668302038832, 8.230171355998579, 8.321561509919297, 8.412840277466055, 8.504009134026669, 8.595069518123607, 8.686022832757825, 8.776870446688559, 8.867613695652839, 8.958253883528219, 9.04879228344194, 9.139230138829628, 9.229568664446274, 9.319809047332203, 9.409952447736469, 9.5, 9.589952813400629, 9.67981197296206, 9.769578540228666, 9.85925355400786, 9.948838031081763, 10.038332966889676], [0.0, 0.1578436529997654, 0.29454667150693775, 0.42426406871192857, 0.5496435241266548, 0.6718930165760894, 0.7917047464637366, 0.9095265044226187, 1.0256710831894524, 1.1403689447067444, 1.2537967024973569, 1.3660938617985812, 1.4773732960138999, 1.5877281339229987, 1.6972364706069025, 1.8059646969278302, 1.913969918162105, 2.0213017525335872, 2.1280036958708117, 2.2341141754093865, 2.339667376220187, 2.444693898260525, 2.5492212851880005, 2.6532744546647136, 2.7568760519928843, 2.8600467433707215, 2.9628054610826564, 3.0651696100490704, 3.167155243031462, 3.2687772101998287, 3.3700492875688743, 3.4709842878936015, 3.571594156908495, 3.671890057244928, 3.7718824419300088, 3.8715811190287615, 3.970995308719452, 4.070133693873389, 4.169004465034015, 4.267615360546492, 4.365973702471588, 4.464086428821027, 4.561960122571595, 4.659601037848942, 4.75701512361653, 4.854208045158743, 4.951185203608018, 5.047951753732691, 5.144512620174209, 5.24087251229834, 5.3370359378045755, 5.433007215220279, 5.528790485391082, 5.624389722065895, 5.719808741663586, 5.815051212298617, 5.9101206621342595, 6.005020487124625, 6.099753958200171, 6.194324227945559, 6.288734336813747, 6.382987218915711, 6.477085707421245, 6.571032539602828, 6.664830361551429, 6.758481732590377, 6.851989129410988, 6.945354949951403, 7.038581517038228, 7.131671081808705, 7.224625826929652, 7.317447869627979, 7.4101392645462765, 7.502702006435906, 7.59513803269889, 7.687449225789057, 7.779637415481989, 7.87170438102257, 7.9636518531582485, 8.055481516065472, 8.147195009176194, 8.238793928910823, 8.33027983032349, 8.421654228665096, 8.512918600869192, 8.604074386965351, 8.695122991424423, 8.786065784439666, 8.876904103147533, 8.96763925279162, 9.058272507833, 9.148805113010017, 9.239238284350332, 9.329573210137909, 9.41981105183737, 9.509952944978068, 9.600000000000001, 9.689953303063632, 9.77981391682549, 9.869582881181321, 9.959261213978507, 10.048849911699254], [0.0, 0.1580073077972056, 0.29485206215740767, 0.4247039524127088, 0.5502134032310456, 0.6725896458889539, 0.7925255984742711, 0.9104695158964345, 1.0267345152006204, 1.1415512972759247, 1.2550966587609051, 1.367510249534091, 1.478905060027896, 1.5893743155793978, 1.6989961922398382, 1.8078371497065322, 1.915954352463457, 2.0233974701794333, 2.1302100437801585, 2.2364305403432074, 2.3420931803830776, 2.4472285955836015, 2.551864358160078, 2.6560254116096345, 2.7597344247134985, 2.86301208509692, 2.965877344673623, 3.0683476264096847, 3.170438999710362, 3.272166330142543, 3.373543408004122, 3.474583059334568, 3.575297242253892, 3.675697130967062, 3.775793189339049, 3.8755952356040337, 3.97511249949991, 4.074353672900524, 4.173326954841404, 4.27204009169095, 4.370500413101557, 4.468714864278392, 4.566690035023575, 4.664432185947133, 4.761947272180505, 4.859240964881934, 4.956318670783835, 5.05318554999909, 5.149846532275092, 5.246306331860356, 5.342569461128024, 5.438640243082979, 5.5345228228641465, 5.630221178340483, 5.72573912988778, 5.821080349423659, 5.916248368769446, 6.011246587400231, 6.106078279637827, 6.200746601335542, 6.295254596098724, 6.389605201080483, 6.483801252388089, 6.577845490132066, 6.671740563146893, 6.765489033409448, 6.8590933801789165, 6.9525560038796606, 7.045879229746632, 7.139065311251084, 7.23211643332286, 7.325034715384044, 7.417822214207513, 7.510480926612819, 7.60301279201071, 7.695419694806776, 7.787703466673738, 7.8798658887012305, 7.971908693431166, 8.063833566786174, 8.155642149897998, 8.247336040842239, 8.338916796285332, 8.430385933049216, 8.521744929598748, 8.61299522745655, 8.704138232549647, 8.795175316491935, 8.886107817806232, 8.976937043089432, 9.067664268123988, 9.158290738938806, 9.24881767282235, 9.33924625929061, 9.429577661012436, 9.519813014694513, 9.609953431928165, 9.7, 9.789953782668325, 9.879815820907071, 9.969587133618939, 10.059268718319299], [0.0, 0.15816945113203254, 0.29515463231891037, 0.42513977349034376, 0.5507780191169188, 0.673279841359498, 0.7933388693619522, 0.9114038180222274, 1.0277881256987513, 1.1427227300203766, 1.2563846090501591, 1.3689135559720065, 1.4804226771664217, 1.5910052936361032, 1.7007396616546935, 1.8096923091188657, 1.9179204591734287, 2.0254738324570334, 2.132396014576039, 2.2387255120820178, 2.3444965806057443, 2.4497398832645554, 2.5544830205677003, 2.6587509616087286, 2.7625663984310314, 2.8659500398890065, 2.9689208573443806, 3.0714962916422635, 3.1736924286779526, 3.275524149273027, 3.377005257876656, 3.478148593690085, 3.578966127104463, 3.67946904379146, 3.779667818353816, 3.8795722791009513, 3.979191665242095, 4.078534677570488, 4.177609523535312, 4.276423957454109, 4.374985316500787, 4.473300553007516, 4.571376263538714, 4.669218715128899, 4.766833869020522, 4.8642274021914345, 4.961404726922311, 5.058371008621218, 5.155131182094339, 5.251689966427836, 5.348051878625344, 5.44422124612791, 5.5402022183281, 5.635998777176868, 5.731614746970382, 5.827053803394298, 5.922319481894212, 6.01741518543368, 6.112344191694538, 6.207109659768559, 6.301714636384369, 6.39616206170911, 6.4904547747604, 6.5845955184606, 6.678586944362357, 6.772431617071591, 6.866132018391645, 6.959690551210136, 7.0531095431481186, 7.146391249989305, 7.239537858905662, 7.332551491494171, 7.425434206638323, 7.518188003206758, 7.6108148226004015, 7.703316551158575, 7.795695022433619, 7.887952019342878, 7.980089276206159, 8.072108480676146, 8.164011275568672, 8.255799260599243, 8.347473994031715, 8.439036994244546, 8.53048974121976, 8.621833677959236, 8.71307021183273, 8.804200715861654, 8.895226529942384, 8.986148962012614, 9.076969289163975, 9.167688758704019, 9.25830858917036, 9.348829971299645, 9.439254068953824, 9.529582020006044, 9.619814937188318, 9.709953908902998, 9.8, 9.889954252521475, 9.979817686415696, 10.069591300221662], [0.0, 0.15833011217497764, 0.2954544364259553, 0.42557161035212426, 0.5513374733626611, 0.673963727158763, 0.7941447054399581, 0.91232957888755, 1.0288321042358173, 1.1438834536891265, 1.2576607850764745, 1.370304033577069, 1.4819264204595217, 1.5926213615175893, 1.7024671925139327, 1.8115305089211147, 1.9198685920085063, 2.0275312129186305, 2.1345620015300417, 2.240999503507446, 2.3468780092768657, 2.4522282131017814, 2.557077743526733, 2.6614515950076947, 2.7653724826375603, 2.8688611363058025, 2.9719365466443595, 3.074616172213925, 3.1769161152490892, 3.2788512716866642, 3.3804354599977255, 3.4816815324249726, 3.5826014715185104, 3.6832064743118846, 3.7835070260474426, 3.883512965017734, 3.9832335398167404, 4.0826774600755575, 4.181852941580105, 4.280767746524392, 4.379429219535083, 4.477844320006196, 4.576019651202629, 4.673961486524655, 4.771675793269874, 4.869168254182543, 4.966444287040874, 5.063509062499712, 5.160367520377783, 5.257024384554673, 5.3534841766221755, 5.449751228416946, 5.5458296935463105, 5.6417235580058955, 5.737436649976413, 5.832972648877103, 5.9283350937447015, 6.023527390999332, 6.118552821652147, 6.213414548003775, 6.308115619877563, 6.402658980427139, 6.497047471553857, 6.59128383896621, 6.685370736910168, 6.779310732596654, 6.87310631034991, 6.966759875498296, 7.060273758027149, 7.153650216011502, 7.246891438844947, 7.339999550279484, 7.43297661128992, 7.525824622775249, 7.618545528108384, 7.711141215544697, 7.803613520498966, 7.895964227699538, 7.988195073227861, 8.080307746450854, 8.172303891853048, 8.264185110774864, 8.355952963062965, 8.447608968638107, 8.539154608985614, 8.630591328573095, 8.721920536199844, 8.813143606281924, 8.904261880076719, 8.995276666850458, 9.086189244991983, 9.177000863075804, 9.267712740877267, 9.35832607034251, 9.448842016515682, 9.539261718425728, 9.629586289934918, 9.719816820551157, 9.809954376205981, 9.9, 9.9899547129175, 10.079819514511753], [0.0, 0.15848931924611134, 0.29575152732566273, 0.4259995391188704, 0.5518918645844859, 0.6746414238367816, 0.7949432487547616, 0.9132469616782778, 1.029866634836179, 1.1450336728854529, 1.258925411794167, 1.371681927451782, 1.4834165549752876, 1.594222804091646, 1.7041790893331672, 1.8133520731367452, 1.9217990943702898, 2.0295699742231395, 2.1367083864453846, 2.2432529154608916, 2.349237886176038, 2.454694023718576, 2.5596489844146206, 2.6641277878530394, 2.7681531719676347, 2.8717458874925876, 2.9749249441556525, 3.0777078180727844, 3.180110627669994, 3.2821482838625373, 3.3838346190164974, 3.485182498298003, 3.586203916306078, 3.68691008133332, 3.787311489165394, 3.8874179879876345, 3.987238835693844, 4.086782750672989, 4.186057956972281, 4.285072224590917, 4.383832905540869, 4.482346966214095, 4.580621016515331, 4.678661336152999, 4.776473898425048, 4.874064391789954, 4.971438239473716, 5.068600617330474, 5.1655564701461305, 5.262310526550318, 5.358867312681466, 5.455231164732059, 5.551406240486036, 5.647396529947098, 5.74320586514534, 5.838837929199802, 5.934296264705859, 6.02958428150892, 6.124705263919323, 6.219662377417513, 6.314458674893552, 6.409097102460522, 6.50358050487742, 6.597911630613657, 6.692093136584149, 6.7861275925812485, 6.880017485427284, 6.973765222869263, 7.067373137235416, 7.1608434888713575, 7.254178469372199, 7.347380204625457, 7.440450757678327, 7.533392131441786, 7.626206271242883, 7.718895067235704, 7.811460356680607, 7.903903926100555, 7.996227513322691, 8.08843280941266, 8.180521460508583, 8.272495069561094, 8.36435519798534, 8.456103367230419, 8.547741060271344, 8.63926972302819, 8.730690765716858, 8.82200556413544, 8.91321546089, 9.00432176656329, 9.09532576082962, 9.186228693518993, 9.277031785633282, 9.367736230317176, 9.45834319378632, 9.548853816214997, 9.63926921258551, 9.729590473501304, 9.819818665965752, 9.909954834128342, 10.0, 10.089955164139084], [0.0, 0.15864709984787198, 0.2960459563393971, 0.426423633713709, 0.5524412885514456, 0.6753130484631724, 0.7957346372517954, 0.9141561248689273, 1.030891896211208, 1.146173586305508, 1.2601787076628697, 1.3730474756222644, 1.4848933381289982, 1.5958098980016115, 1.7058756478363009, 1.815157316434302, 1.9237122997459906, 2.031590468559108, 2.138835540102199, 2.245486137211015, 2.3515766189633505, 2.457137741074691, 2.562197187403806, 2.666780002447273, 2.77090894677515, 2.8746047917795607, 2.9778865661129825, 3.080771763289338, 3.1832765177809863, 3.285415755347422, 3.3872033221252402, 3.488652096088206, 3.589774083776306, 3.6905805046403115, 3.7910818649147373, 3.891288022589066, 3.9912082447735955, 4.090851258536694, 4.190225296112847, 4.289338135236504, 4.388197135238772, 4.486809269446851, 4.585181154345824, 4.683319075895739, 4.781229013341134, 4.878916660803505, 4.976387446907827, 5.073646552660947, 5.170698927771446, 5.267549305576438, 5.36420221672025, 5.460662001712172, 5.556932822475334, 5.653018672985597, 5.748923389087952, 5.844650657568087, 5.94020402454813, 6.035586903268091, 6.13080258130793, 6.225854227299416, 6.320744897171851, 6.415477539971255, 6.510055003288666, 6.60448003832967, 6.698755304654218, 6.792883374612965, 6.886866737503941, 6.980707803471133, 7.074408907164671, 7.167972311180408, 7.261400209295249, 7.354694729513092, 7.447857936934955, 7.54089183646577, 7.633798375369211, 7.72657944568107, 7.819236886490749, 7.911772486099742, 8.004187984065252, 8.096485073136424, 8.188665401090159, 8.280730572472873, 8.372682150254144, 8.46452165739772, 8.556250578354954, 8.647870360485376, 8.739382415408796, 8.830788120292953, 8.922088819080512, 9.013285823658952, 9.10438041497653, 9.19537384410749, 9.286267333269251, 9.377062076794308, 9.467759242059307, 9.558359970373608, 9.648865377829509, 9.739276556116183, 9.829594573299232, 9.91982047456763, 10.009955282949738, 10.100000000000001]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha = 1.0\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001]]}, {\"colorscale\": [[0.0, \"#440154\"], [0.1111111111111111, \"#482878\"], [0.2222222222222222, \"#3e4989\"], [0.3333333333333333, \"#31688e\"], [0.4444444444444444, \"#26828e\"], [0.5555555555555556, \"#1f9e89\"], [0.6666666666666666, \"#35b779\"], [0.7777777777777778, \"#6ece58\"], [0.8888888888888888, \"#b5de2b\"], [1.0, \"#fde725\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha = 0.5\", \"showscale\": false, \"type\": \"surface\", \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.1, 0.1414213562373095, 0.17320508075688776, 0.2, 0.223606797749979, 0.24494897427831783, 0.2645751311064591, 0.282842712474619, 0.3, 0.31622776601683794, 0.33166247903554, 0.3464101615137755, 0.36055512754639896, 0.37416573867739417, 0.38729833462074165, 0.4, 0.41231056256176607, 0.4242640687119285, 0.43588989435406744, 0.447213595499958, 0.45825756949558405, 0.469041575982343, 0.479583152331272, 0.48989794855663565, 0.5, 0.5099019513592785, 0.5196152422706632, 0.5291502622129182, 0.5385164807134505, 0.5477225575051661, 0.5567764362830022, 0.565685424949238, 0.574456264653803, 0.5830951894845301, 0.5916079783099616, 0.6, 0.608276253029822, 0.6164414002968976, 0.6244997998398399, 0.6324555320336759, 0.6403124237432849, 0.6480740698407861, 0.6557438524302001, 0.66332495807108, 0.6708203932499369, 0.6782329983125268, 0.6855654600401044, 0.692820323027551, 0.7000000000000001, 0.7071067811865476, 0.7141428428542851, 0.7211102550927979, 0.7280109889280519, 0.7348469228349535, 0.7416198487095663, 0.7483314773547883, 0.754983443527075, 0.7615773105863909, 0.7681145747868608, 0.7745966692414833, 0.7810249675906654, 0.787400787401181, 0.7937253933193772, 0.8, 0.8062257748298549, 0.812403840463596, 0.8185352771872451, 0.8246211251235321, 0.8306623862918076, 0.8366600265340756, 0.8426149773176359, 0.848528137423857, 0.8544003745317531, 0.8602325267042626, 0.8660254037844387, 0.8717797887081349, 0.8774964387392122, 0.8831760866327848, 0.8888194417315589, 0.894427190999916, 0.9, 0.9055385138137417, 0.9110433579144299, 0.9165151389911681, 0.9219544457292888, 0.9273618495495705, 0.9327379053088816, 0.938083151964686, 0.9433981132056604, 0.9486832980505138, 0.9539392014169457, 0.959166304662544, 0.9643650760992956, 0.9695359714832659, 0.9746794344808963, 0.9797958971132713, 0.9848857801796106, 0.9899494936611666, 0.9949874371066201, 1.0, 1.0049875621120892], [0.0, 0.1414213562373095, 0.19999999999999998, 0.24494897427831783, 0.282842712474619, 0.31622776601683794, 0.34641016151377546, 0.3741657386773941, 0.39999999999999997, 0.4242640687119285, 0.4472135954999579, 0.469041575982343, 0.48989794855663565, 0.5099019513592785, 0.529150262212918, 0.5477225575051661, 0.565685424949238, 0.58309518948453, 0.6, 0.6164414002968976, 0.6324555320336759, 0.6480740698407861, 0.6633249580710799, 0.6782329983125268, 0.6928203230275509, 0.7071067811865476, 0.7211102550927979, 0.7348469228349535, 0.7483314773547882, 0.7615773105863909, 0.7745966692414833, 0.7874007874011811, 0.7999999999999999, 0.812403840463596, 0.8246211251235321, 0.8366600265340756, 0.848528137423857, 0.8602325267042626, 0.8717797887081348, 0.8831760866327847, 0.8944271909999159, 0.9055385138137417, 0.9165151389911681, 0.9273618495495702, 0.938083151964686, 0.9486832980505137, 0.9591663046625439, 0.9695359714832658, 0.9797958971132713, 0.9899494936611665, 1.0, 1.0099504938362078, 1.019803902718557, 1.0295630140987002, 1.0392304845413265, 1.0488088481701516, 1.058300524425836, 1.0677078252031311, 1.0770329614269007, 1.0862780491200215, 1.0954451150103321, 1.104536101718726, 1.1135528725660042, 1.1224972160321824, 1.131370849898476, 1.1401754250991378, 1.1489125293076057, 1.1575836902790224, 1.16619037896906, 1.174734012447073, 1.1832159566199232, 1.1916375287812984, 1.2, 1.2083045973594573, 1.2165525060596438, 1.224744871391589, 1.2328828005937953, 1.2409673645990857, 1.2489995996796797, 1.2569805089976536, 1.2649110640673518, 1.2727922061357855, 1.2806248474865698, 1.2884098726725124, 1.2961481396815722, 1.3038404810405297, 1.3114877048604001, 1.3190905958272918, 1.3266499161421599, 1.3341664064126333, 1.3416407864998738, 1.349073756323204, 1.3564659966250536, 1.3638181696985856, 1.3711309200802089, 1.378404875209022, 1.3856406460551018, 1.392838827718412, 1.4, 1.407124727947029, 1.4142135623730951, 1.4212670403551897], [0.0, 0.17320508075688776, 0.24494897427831783, 0.3000000000000001, 0.3464101615137755, 0.38729833462074176, 0.42426406871192857, 0.45825756949558405, 0.48989794855663565, 0.5196152422706632, 0.5477225575051662, 0.574456264653803, 0.6000000000000002, 0.6244997998398399, 0.6480740698407861, 0.6708203932499369, 0.692820323027551, 0.7141428428542851, 0.7348469228349536, 0.7549834435270751, 0.7745966692414835, 0.7937253933193773, 0.8124038404635961, 0.8306623862918077, 0.8485281374238571, 0.8660254037844388, 0.8831760866327849, 0.9000000000000001, 0.9165151389911681, 0.9327379053088817, 0.9486832980505139, 0.9643650760992957, 0.9797958971132713, 0.9949874371066202, 1.009950493836208, 1.02469507659596, 1.0392304845413265, 1.053565375285274, 1.0677078252031313, 1.081665382639197, 1.0954451150103324, 1.1090536506409419, 1.1224972160321827, 1.1357816691600549, 1.148912529307606, 1.161895003862225, 1.1747340124470733, 1.187434208703792, 1.2000000000000004, 1.2124355652982142, 1.2247448713915892, 1.2369316876852985, 1.2489995996796799, 1.2609520212918495, 1.2727922061357857, 1.2845232578665131, 1.2961481396815722, 1.3076696830622023, 1.3190905958272923, 1.3304134695650072, 1.3416407864998738, 1.3527749258468684, 1.3638181696985856, 1.3747727084867523, 1.385640646055102, 1.3964240043768943, 1.4071247279470291, 1.4177446878757827, 1.4282856857085702, 1.4387494569938162, 1.4491376746189442, 1.4594519519326425, 1.4696938456699071, 1.4798648586948744, 1.489966442575134, 1.5000000000000002, 1.5099668870541503, 1.5198684153570665, 1.5297058540778359, 1.5394804318340656, 1.549193338482967, 1.5588457268119897, 1.5684387141358125, 1.5779733838059502, 1.5874507866387546, 1.5968719422671316, 1.6062378404209012, 1.6155494421403516, 1.6248076809271923, 1.6340134638368193, 1.6431676725154984, 1.6522711641858308, 1.6613247725836153, 1.670329308849007, 1.6792855623746668, 1.6881943016134133, 1.6970562748477143, 1.7058722109231985, 1.7146428199482249, 1.7233687939614089, 1.7320508075688776, 1.7406895185529214], [0.0, 0.2, 0.282842712474619, 0.3464101615137755, 0.4, 0.447213595499958, 0.48989794855663565, 0.5291502622129182, 0.565685424949238, 0.6, 0.6324555320336759, 0.66332495807108, 0.692820323027551, 0.7211102550927979, 0.7483314773547883, 0.7745966692414833, 0.8, 0.8246211251235321, 0.848528137423857, 0.8717797887081349, 0.894427190999916, 0.9165151389911681, 0.938083151964686, 0.959166304662544, 0.9797958971132713, 1.0, 1.019803902718557, 1.0392304845413265, 1.0583005244258363, 1.077032961426901, 1.0954451150103321, 1.1135528725660044, 1.131370849898476, 1.148912529307606, 1.1661903789690602, 1.1832159566199232, 1.2, 1.216552506059644, 1.2328828005937953, 1.2489995996796799, 1.2649110640673518, 1.2806248474865698, 1.2961481396815722, 1.3114877048604001, 1.32664991614216, 1.3416407864998738, 1.3564659966250536, 1.3711309200802089, 1.385640646055102, 1.4000000000000001, 1.4142135623730951, 1.4282856857085702, 1.4422205101855958, 1.4560219778561039, 1.469693845669907, 1.4832396974191326, 1.4966629547095767, 1.50996688705415, 1.5231546211727818, 1.5362291495737217, 1.5491933384829666, 1.5620499351813308, 1.574801574802362, 1.5874507866387544, 1.6, 1.6124515496597098, 1.624807680927192, 1.6370705543744901, 1.6492422502470643, 1.661324772583615, 1.6733200530681511, 1.6852299546352718, 1.697056274847714, 1.7088007490635062, 1.7204650534085253, 1.7320508075688774, 1.7435595774162698, 1.7549928774784245, 1.7663521732655696, 1.7776388834631178, 1.788854381999832, 1.8, 1.8110770276274835, 1.8220867158288598, 1.8330302779823362, 1.8439088914585775, 1.854723699099141, 1.8654758106177631, 1.876166303929372, 1.8867962264113207, 1.8973665961010275, 1.9078784028338913, 1.918332609325088, 1.9287301521985911, 1.9390719429665317, 1.9493588689617927, 1.9595917942265426, 1.9697715603592212, 1.9798989873223332, 1.9899748742132402, 2.0, 2.0099751242241783], [0.0, 0.223606797749979, 0.31622776601683794, 0.38729833462074176, 0.447213595499958, 0.5000000000000001, 0.5477225575051662, 0.5916079783099617, 0.6324555320336759, 0.6708203932499369, 0.7071067811865476, 0.7416198487095664, 0.7745966692414835, 0.806225774829855, 0.8366600265340756, 0.8660254037844386, 0.894427190999916, 0.9219544457292888, 0.9486832980505139, 0.9746794344808966, 1.0000000000000002, 1.02469507659596, 1.0488088481701516, 1.072380529476361, 1.0954451150103324, 1.118033988749895, 1.140175425099138, 1.1618950038622253, 1.1832159566199234, 1.2041594578792296, 1.2247448713915892, 1.2449899597988734, 1.2649110640673518, 1.2845232578665131, 1.30384048104053, 1.3228756555322954, 1.3416407864998738, 1.3601470508735445, 1.3784048752090223, 1.3964240043768943, 1.4142135623730951, 1.4317821063276355, 1.4491376746189442, 1.466287829861518, 1.4832396974191329, 1.5, 1.5165750888103102, 1.5329709716755893, 1.549193338482967, 1.565247584249853, 1.5811388300841898, 1.5968719422671316, 1.61245154965971, 1.627882059609971, 1.6431676725154984, 1.6583123951777001, 1.6733200530681511, 1.6881943016134133, 1.7029386365926404, 1.7175564037317668, 1.7320508075688772, 1.746424919657298, 1.760681686165901, 1.7748239349298849, 1.788854381999832, 1.8027756377319946, 1.8165902124584952, 1.8303005217723127, 1.8439088914585775, 1.8574175621006712, 1.8708286933869709, 1.8841443681416774, 1.8973665961010278, 1.91049731745428, 1.9235384061671346, 1.9364916731037085, 1.9493588689617931, 1.9621416870348585, 1.9748417658131503, 1.9874606914351793, 2.0000000000000004, 2.012461179749811, 2.024845673131659, 2.0371548787463363, 2.04939015319192, 2.0615528128088303, 2.0736441353327724, 2.0856653614614213, 2.0976176963403033, 2.1095023109728985, 2.121320343559643, 2.1330729007701543, 2.144761058952722, 2.1563858652847827, 2.1679483388678804, 2.179449471770337, 2.1908902300206647, 2.2022715545545246, 2.2135943621178655, 2.224859546128699, 2.23606797749979, 2.2472205054244236], [0.0, 0.24494897427831783, 0.34641016151377546, 0.42426406871192857, 0.48989794855663565, 0.5477225575051662, 0.6000000000000001, 0.6480740698407861, 0.6928203230275509, 0.7348469228349535, 0.7745966692414834, 0.8124038404635961, 0.8485281374238571, 0.8831760866327848, 0.916515138991168, 0.9486832980505138, 0.9797958971132713, 1.0099504938362078, 1.0392304845413265, 1.0677078252031313, 1.0954451150103324, 1.1224972160321824, 1.148912529307606, 1.174734012447073, 1.2000000000000002, 1.2247448713915892, 1.2489995996796799, 1.2727922061357857, 1.2961481396815722, 1.319090595827292, 1.3416407864998738, 1.3638181696985856, 1.3856406460551018, 1.4071247279470291, 1.4282856857085702, 1.449137674618944, 1.469693845669907, 1.489966442575134, 1.50996688705415, 1.5297058540778357, 1.5491933384829668, 1.5684387141358125, 1.5874507866387546, 1.606237840420901, 1.6248076809271923, 1.6431676725154982, 1.661324772583615, 1.6792855623746665, 1.6970562748477143, 1.7146428199482247, 1.7320508075688774, 1.7492855684535904, 1.7663521732655696, 1.7832554500127011, 1.8, 1.8165902124584952, 1.833030277982336, 1.849324200890693, 1.8654758106177631, 1.8814887722226779, 1.8973665961010275, 1.9131126469708992, 1.928730152198591, 1.9442222095223582, 1.9595917942265426, 1.9748417658131499, 1.98997487421324, 2.004993765576342, 2.0199009876724157, 2.0346989949375804, 2.04939015319192, 2.0639767440550294, 2.078460969082653, 2.092844953645635, 2.1071307505705477, 2.121320343559643, 2.1354156504062627, 2.149418526020468, 2.1633307652783937, 2.177154105707724, 2.1908902300206647, 2.2045407685048604, 2.2181073012818837, 2.2315913604421396, 2.244994432064365, 2.2583179581272432, 2.2715633383201097, 2.2847319317591728, 2.297825058615212, 2.3108440016582685, 2.32379000772445, 2.3366642891095846, 2.349468024894146, 2.3622023622035435, 2.374868417407584, 2.3874672772626644, 2.4000000000000004, 2.412467616362964, 2.4248711305964283, 2.4372115213907883, 2.4494897427831783, 2.4617067250182347], [0.0, 0.2645751311064591, 0.3741657386773941, 0.45825756949558405, 0.5291502622129182, 0.5916079783099617, 0.6480740698407861, 0.7000000000000001, 0.7483314773547882, 0.7937253933193772, 0.8366600265340756, 0.8774964387392122, 0.9165151389911681, 0.9539392014169458, 0.9899494936611666, 1.0246950765959597, 1.0583005244258363, 1.0908712114635715, 1.1224972160321824, 1.1532562594670797, 1.1832159566199234, 1.2124355652982142, 1.2409673645990857, 1.2688577540449522, 1.2961481396815722, 1.3228756555322954, 1.3490737563232043, 1.374772708486752, 1.4000000000000001, 1.4247806848775009, 1.4491376746189437, 1.4730919862656235, 1.4966629547095764, 1.5198684153570665, 1.5427248620541514, 1.5652475842498528, 1.5874507866387544, 1.6093476939431082, 1.6309506430300091, 1.6522711641858308, 1.6733200530681511, 1.6941074346097418, 1.7146428199482249, 1.7349351572897471, 1.7549928774784245, 1.7748239349298847, 1.7944358444926363, 1.8138357147217055, 1.8330302779823362, 1.8520259177452134, 1.8708286933869709, 1.8894443627691186, 1.9078784028338915, 1.9261360284258224, 1.9442222095223582, 1.9621416870348585, 1.9798989873223332, 1.997498435543818, 2.0149441679609885, 2.0322401432901573, 2.0493901531919194, 2.0663978319771825, 2.083266665599966, 2.1, 2.1166010488516727, 2.133072900770154, 2.149418526020468, 2.1656407827707715, 2.181742422927143, 2.1977260975835913, 2.2135943621178655, 2.2293496809607953, 2.244994432064365, 2.260530911091463, 2.2759613353482084, 2.29128784747792, 2.3065125189341593, 2.32163735324878, 2.336664289109585, 2.3515952032609695, 2.366431913239847, 2.3811761799581315, 2.395829710142188, 2.41039415863879, 2.4248711305964283, 2.4392621835300936, 2.4535688292770597, 2.4677925358506134, 2.4819347291981715, 2.495996794869737, 2.5099800796022267, 2.5238858928247927, 2.5377155080899043, 2.551470164434615, 2.5651510676761324, 2.578759391645525, 2.5922962793631443, 2.6057628441590768, 2.619160170741759, 2.632489316217637, 2.6457513110645907, 2.6589471600616665], [0.0, 0.282842712474619, 0.39999999999999997, 0.48989794855663565, 0.565685424949238, 0.6324555320336759, 0.6928203230275509, 0.7483314773547882, 0.7999999999999999, 0.848528137423857, 0.8944271909999159, 0.938083151964686, 0.9797958971132713, 1.019803902718557, 1.058300524425836, 1.0954451150103321, 1.131370849898476, 1.16619037896906, 1.2, 1.2328828005937953, 1.2649110640673518, 1.2961481396815722, 1.3266499161421599, 1.3564659966250536, 1.3856406460551018, 1.4142135623730951, 1.4422205101855958, 1.469693845669907, 1.4966629547095764, 1.5231546211727818, 1.5491933384829666, 1.5748015748023623, 1.5999999999999999, 1.624807680927192, 1.6492422502470643, 1.6733200530681511, 1.697056274847714, 1.7204650534085253, 1.7435595774162695, 1.7663521732655694, 1.7888543819998317, 1.8110770276274835, 1.8330302779823362, 1.8547236990991405, 1.876166303929372, 1.8973665961010273, 1.9183326093250879, 1.9390719429665315, 1.9595917942265426, 1.979898987322333, 2.0, 2.0199009876724157, 2.039607805437114, 2.0591260281974004, 2.078460969082653, 2.0976176963403033, 2.116601048851672, 2.1354156504062622, 2.1540659228538015, 2.172556098240043, 2.1908902300206643, 2.209072203437452, 2.2271057451320084, 2.244994432064365, 2.262741699796952, 2.2803508501982757, 2.2978250586152114, 2.315167380558045, 2.33238075793812, 2.349468024894146, 2.3664319132398464, 2.3832750575625967, 2.4, 2.4166091947189146, 2.4331050121192876, 2.449489742783178, 2.4657656011875906, 2.4819347291981715, 2.4979991993593593, 2.513961017995307, 2.5298221281347035, 2.545584412271571, 2.5612496949731396, 2.576819745345025, 2.5922962793631443, 2.6076809620810595, 2.6229754097208002, 2.6381811916545836, 2.6532998322843198, 2.6683328128252666, 2.6832815729997477, 2.698147512646408, 2.7129319932501073, 2.727636339397171, 2.7422618401604177, 2.756809750418044, 2.7712812921102037, 2.785677655436824, 2.8, 2.814249455894058, 2.8284271247461903, 2.8425340807103794], [0.0, 0.3, 0.4242640687119285, 0.5196152422706632, 0.6, 0.6708203932499369, 0.7348469228349535, 0.7937253933193772, 0.848528137423857, 0.8999999999999999, 0.9486832980505138, 0.99498743710662, 1.0392304845413265, 1.0816653826391969, 1.1224972160321824, 1.1618950038622249, 1.2, 1.236931687685298, 1.2727922061357855, 1.307669683062202, 1.3416407864998738, 1.374772708486752, 1.407124727947029, 1.438749456993816, 1.469693845669907, 1.5, 1.5297058540778354, 1.5588457268119895, 1.5874507866387544, 1.6155494421403513, 1.6431676725154982, 1.6703293088490065, 1.697056274847714, 1.7233687939614086, 1.7492855684535902, 1.7748239349298847, 1.7999999999999998, 1.8248287590894658, 1.849324200890693, 1.8734993995195195, 1.8973665961010275, 1.9209372712298547, 1.9442222095223582, 1.9672315572906, 1.98997487421324, 2.0124611797498106, 2.0346989949375804, 2.056696380120313, 2.078460969082653, 2.1, 2.1213203435596424, 2.142428528562855, 2.1633307652783937, 2.1840329667841556, 2.2045407685048604, 2.224859546128699, 2.244994432064365, 2.264950330581225, 2.2847319317591723, 2.3043437243605824, 2.3237900077244498, 2.3430749027719964, 2.362202362203543, 2.3811761799581315, 2.4, 2.4186773244895647, 2.437211521390788, 2.455605831561735, 2.473863375370596, 2.4919871588754225, 2.5099800796022267, 2.5278449319529073, 2.545584412271571, 2.563201123595259, 2.580697580112788, 2.598076211353316, 2.615339366124404, 2.6324893162176366, 2.6495282598983545, 2.6664583251946765, 2.6832815729997477, 2.7, 2.716615541441225, 2.7331300737432893, 2.749545416973504, 2.765863337187866, 2.7820855486487113, 2.7982137159266447, 2.814249455894058, 2.830194339616981, 2.846049894151541, 2.8618176042508368, 2.877498913987632, 2.8930952282978866, 2.9086079144497976, 2.9240383034426887, 2.939387691339814, 2.9546573405388314, 2.9698484809834995, 2.98496231131986, 3.0, 3.0149626863362675], [0.0, 0.31622776601683794, 0.4472135954999579, 0.5477225575051662, 0.6324555320336759, 0.7071067811865476, 0.7745966692414834, 0.8366600265340756, 0.8944271909999159, 0.9486832980505138, 1.0, 1.0488088481701516, 1.0954451150103324, 1.140175425099138, 1.1832159566199232, 1.224744871391589, 1.2649110640673518, 1.3038404810405297, 1.3416407864998738, 1.3784048752090223, 1.4142135623730951, 1.449137674618944, 1.4832396974191326, 1.5165750888103102, 1.5491933384829668, 1.5811388300841898, 1.61245154965971, 1.6431676725154984, 1.6733200530681511, 1.7029386365926402, 1.7320508075688772, 1.760681686165901, 1.7888543819998317, 1.8165902124584952, 1.8439088914585775, 1.8708286933869707, 1.8973665961010275, 1.9235384061671346, 1.949358868961793, 1.97484176581315, 2.0, 2.024845673131659, 2.04939015319192, 2.073644135332772, 2.0976176963403033, 2.1213203435596424, 2.1447610589527217, 2.16794833886788, 2.1908902300206647, 2.2135943621178655, 2.23606797749979, 2.2583179581272432, 2.280350850198276, 2.302172886644268, 2.32379000772445, 2.345207879911715, 2.3664319132398464, 2.3874672772626644, 2.4083189157584592, 2.4289915602982237, 2.449489742783178, 2.4698178070456938, 2.4899799195977463, 2.5099800796022267, 2.5298221281347035, 2.5495097567963922, 2.569046515733026, 2.588435821108957, 2.6076809620810595, 2.6267851073127395, 2.6457513110645907, 2.6645825188948455, 2.6832815729997477, 2.701851217221259, 2.7202941017470885, 2.7386127875258306, 2.7568097504180447, 2.7748873851023217, 2.7928480087537886, 2.8106938645110393, 2.8284271247461903, 2.8460498941515415, 2.863564212655271, 2.8809720581775866, 2.898275349237888, 2.9154759474226504, 2.932575659723036, 2.9495762407505253, 2.9664793948382653, 2.9832867780352594, 3.0, 3.0166206257996713, 3.0331501776206204, 3.0495901363953815, 3.0659419433511785, 3.082207001484488, 3.0983866769659336, 3.1144823004794877, 3.1304951684997055, 3.146426544510455, 3.1622776601683795, 3.178049716414141], [0.0, 0.33166247903554, 0.469041575982343, 0.574456264653803, 0.66332495807108, 0.7416198487095664, 0.8124038404635961, 0.8774964387392122, 0.938083151964686, 0.99498743710662, 1.0488088481701516, 1.1, 1.148912529307606, 1.1958260743101399, 1.2409673645990857, 1.284523257866513, 1.32664991614216, 1.3674794331177345, 1.407124727947029, 1.4456832294800963, 1.4832396974191329, 1.5198684153570665, 1.5556349186104048, 1.5905973720586868, 1.6248076809271923, 1.6583123951777001, 1.6911534525287766, 1.7233687939614089, 1.7549928774784245, 1.7860571099491753, 1.816590212458495, 1.846618531261939, 1.876166303929372, 1.9052558883257653, 1.9339079605813718, 1.9621416870348585, 1.98997487421324, 2.017424100183202, 2.0445048300260877, 2.0712315177207983, 2.0976176963403033, 2.1236760581595306, 2.149418526020468, 2.1748563170931545, 2.2, 2.224859546128699, 2.249444375840399, 2.273763400180415, 2.297825058615212, 2.32163735324878, 2.345207879911715, 2.368543856465403, 2.3916521486202797, 2.4145392935299275, 2.4372115213907883, 2.459674775249769, 2.4819347291981715, 2.503996805109783, 2.525866188063018, 2.5475478405713994, 2.569046515733026, 2.5903667693977237, 2.6115129714401193, 2.632489316217637, 2.65329983228432, 2.6739483914241875, 2.6944387170614963, 2.714774392099646, 2.734958866235469, 2.7549954627911823, 2.774887385102322, 2.7946377224964243, 2.814249455894058, 2.833725463060951, 2.8530685235374214, 2.8722813232690148, 2.8913664589601926, 2.91032644217105, 2.9291637031753623, 2.9478805945967355, 2.9664793948382657, 2.9849623113198605, 3.003331483536242, 3.0215889859476257, 3.039736830714133, 3.0577769702841313, 3.07571129984594, 3.093541659651604, 3.1112698372208096, 3.1288975694324033, 3.146426544510455, 3.1638584039112754, 3.1811947441173736, 3.1984371183438958, 3.2155870381627056, 3.2326459750489227, 3.2496153618543846, 3.2664965942122155, 3.283291031876401, 3.3000000000000007, 3.3166247903554003, 3.333166662499792], [0.0, 0.3464101615137755, 0.48989794855663565, 0.6000000000000002, 0.692820323027551, 0.7745966692414835, 0.8485281374238571, 0.9165151389911681, 0.9797958971132713, 1.0392304845413265, 1.0954451150103324, 1.148912529307606, 1.2000000000000004, 1.2489995996796799, 1.2961481396815722, 1.3416407864998738, 1.385640646055102, 1.4282856857085702, 1.4696938456699071, 1.5099668870541503, 1.549193338482967, 1.5874507866387546, 1.6248076809271923, 1.6613247725836153, 1.6970562748477143, 1.7320508075688776, 1.7663521732655698, 1.8000000000000003, 1.8330302779823362, 1.8654758106177634, 1.8973665961010278, 1.9287301521985913, 1.9595917942265426, 1.9899748742132404, 2.019900987672416, 2.04939015319192, 2.078460969082653, 2.107130750570548, 2.1354156504062627, 2.163330765278394, 2.1908902300206647, 2.2181073012818837, 2.2449944320643653, 2.2715633383201097, 2.297825058615212, 2.32379000772445, 2.3494680248941466, 2.374868417407584, 2.400000000000001, 2.4248711305964283, 2.4494897427831783, 2.473863375370597, 2.4979991993593598, 2.521904042583699, 2.5455844122715714, 2.5690465157330262, 2.5922962793631443, 2.6153393661244047, 2.6381811916545845, 2.6608269391300143, 2.6832815729997477, 2.705549851693737, 2.727636339397171, 2.7495454169735045, 2.771281292110204, 2.7928480087537886, 2.8142494558940583, 2.8354893757515653, 2.8565713714171403, 2.8774989139876324, 2.8982753492378883, 2.918903903865285, 2.9393876913398143, 2.9597297173897488, 2.979932885150268, 3.0000000000000004, 3.0199337741083006, 3.039736830714133, 3.0594117081556718, 3.078960863668131, 3.098386676965934, 3.1176914536239795, 3.136877428271625, 3.1559467676119004, 3.174901573277509, 3.193743884534263, 3.2124756808418025, 3.231098884280703, 3.2496153618543846, 3.2680269276736387, 3.286335345030997, 3.3045423283716615, 3.3226495451672307, 3.340658617698014, 3.3585711247493335, 3.3763886032268267, 3.3941125496954285, 3.411744421846397, 3.4292856398964497, 3.4467375879228177, 3.4641016151377553, 3.481379037105843], [0.0, 0.36055512754639896, 0.5099019513592785, 0.6244997998398399, 0.7211102550927979, 0.806225774829855, 0.8831760866327848, 0.9539392014169458, 1.019803902718557, 1.0816653826391969, 1.140175425099138, 1.1958260743101399, 1.2489995996796799, 1.3000000000000003, 1.3490737563232043, 1.396424004376894, 1.4422205101855958, 1.4866068747318506, 1.5297058540778357, 1.5716233645501714, 1.61245154965971, 1.6522711641858308, 1.6911534525287764, 1.7291616465790585, 1.7663521732655696, 1.8027756377319948, 1.8384776310850237, 1.8734993995195197, 1.9078784028338915, 1.94164878389476, 1.9748417658131499, 2.0074859899884734, 2.039607805437114, 2.0712315177207983, 2.102379604162864, 2.1330729007701543, 2.1633307652783937, 2.193171219946131, 2.222611077089287, 2.2516660498395407, 2.280350850198276, 2.3086792761230397, 2.336664289109585, 2.364318083507378, 2.3916521486202797, 2.4186773244895647, 2.445403852127497, 2.471841418861655, 2.4979991993593598, 2.5238858928247927, 2.5495097567963927, 2.574878637916747, 2.6000000000000005, 2.624880949681338, 2.6495282598983545, 2.673948391424188, 2.6981475126464085, 2.72213151776324, 2.7459060435491964, 2.7694764848252458, 2.792848008753788, 2.816025568065745, 2.839013913315678, 2.861817604250837, 2.8844410203711917, 2.9068883707497264, 2.9291637031753623, 2.951270912674741, 2.973213749463701, 2.994995826374388, 3.0166206257996717, 3.0380915061926625, 3.0594117081556713, 3.0805843601498726, 3.1016124838541645, 3.122498999199199, 3.1432467291003428, 3.1638584039112754, 3.1843366656181322, 3.204684071792413, 3.22490309931942, 3.2449961479175906, 3.264965543462902, 3.2848135411313684, 3.3045423283716615, 3.3241540277189325, 3.343650699460098, 3.363034344160048, 3.3823069050575527, 3.4014702703389896, 3.420526275297414, 3.439476704383968, 3.458323293158117, 3.4770677301427426, 3.4957116585897072, 3.5142566781611158, 3.532704346531139, 3.5510561809129415, 3.5693136595149495, 3.58747822293042, 3.6055512754639896, 3.6235341863986883], [0.0, 0.37416573867739417, 0.529150262212918, 0.6480740698407861, 0.7483314773547883, 0.8366600265340756, 0.916515138991168, 0.9899494936611666, 1.058300524425836, 1.1224972160321824, 1.1832159566199232, 1.2409673645990857, 1.2961481396815722, 1.3490737563232043, 1.4, 1.4491376746189437, 1.4966629547095767, 1.5427248620541512, 1.5874507866387544, 1.6309506430300091, 1.6733200530681511, 1.7146428199482247, 1.7549928774784245, 1.7944358444926363, 1.833030277982336, 1.8708286933869707, 1.9078784028338913, 1.9442222095223582, 1.9798989873223332, 2.0149441679609885, 2.0493901531919194, 2.083266665599966, 2.116601048851672, 2.149418526020468, 2.181742422927143, 2.2135943621178655, 2.244994432064365, 2.2759613353482084, 2.3065125189341593, 2.3366642891095846, 2.3664319132398464, 2.395829710142188, 2.4248711305964283, 2.453568829277059, 2.4819347291981715, 2.5099800796022262, 2.5377155080899043, 2.565151067676132, 2.5922962793631443, 2.619160170741759, 2.6457513110645907, 2.672077843177478, 2.6981475126464085, 2.7239676943752476, 2.749545416973504, 2.7748873851023217, 2.8, 2.824889378365107, 2.8495613697550017, 2.8740215726399825, 2.8982753492378874, 2.9223278392404914, 2.9461839725312466, 2.9698484809834995, 2.9933259094191533, 3.016620625799671, 3.0397368307141326, 3.062678566222711, 3.0854497241083023, 3.1080540535840107, 3.1304951684997055, 3.152776554086889, 3.1749015732775088, 3.196873472629156, 3.218695387886216, 3.24037034920393, 3.2619012860600183, 3.283291031876401, 3.3045423283716615, 3.3256578296631782, 3.3466401061363023, 3.3674916480965473, 3.3882148692194836, 3.408812109811862, 3.4292856398964493, 3.449637662132068, 3.4698703145794947, 3.4899856733230297, 3.509985754956849, 3.529872518944558, 3.5496478698597693, 3.5693136595149495, 3.5888716889852725, 3.6083237105337433, 3.627671429443411, 3.6469165057620936, 3.666060555964672, 3.685105154537656, 3.704051835490427, 3.722902093797257, 3.7416573867739413, 3.7603191353926335], [0.0, 0.38729833462074165, 0.5477225575051661, 0.6708203932499369, 0.7745966692414833, 0.8660254037844386, 0.9486832980505138, 1.0246950765959597, 1.0954451150103321, 1.1618950038622249, 1.224744871391589, 1.284523257866513, 1.3416407864998738, 1.396424004376894, 1.4491376746189437, 1.4999999999999998, 1.5491933384829666, 1.5968719422671311, 1.6431676725154982, 1.6881943016134133, 1.7320508075688772, 1.7748239349298847, 1.816590212458495, 1.857417562100671, 1.8973665961010275, 1.9364916731037083, 1.9748417658131499, 2.0124611797498106, 2.0493901531919194, 2.085665361461421, 2.1213203435596424, 2.1563858652847823, 2.1908902300206643, 2.224859546128699, 2.258317958127243, 2.29128784747792, 2.3237900077244498, 2.355843797877949, 2.3874672772626644, 2.4186773244895647, 2.449489742783178, 2.479919353527449, 2.5099800796022267, 2.5396850198400585, 2.569046515733026, 2.5980762113533156, 2.626785107312739, 2.6551836094703507, 2.6832815729997477, 2.7110883423451915, 2.7386127875258306, 2.765863337187866, 2.792848008753788, 2.819574435974337, 2.846049894151541, 2.8722813232690143, 2.8982753492378874, 2.924038303442689, 2.9495762407505253, 2.974894956128703, 2.9999999999999996, 3.0248966924508345, 3.049590136395381, 3.074085229787879, 3.098386676965933, 3.1224989991991987, 3.1464265445104544, 3.1701734968294715, 3.1937438845342623, 3.217141588429082, 3.24037034920393, 3.2634337744161437, 3.2863353450309964, 3.309078421554859, 3.3316662497915357, 3.3541019662496843, 3.3763886032268267, 3.3985290935932855, 3.420526275297414, 3.442382895611701, 3.4641016151377544, 3.485685011586675, 3.5071355833500366, 3.5284557528754696, 3.5496478698597693, 3.5707142142714248, 3.591656999213594, 3.6124783736376886, 3.63318042491699, 3.6537651812890215, 3.674234614174767, 3.694590640382233, 3.714835124201342, 3.7349698793966195, 3.7549966711037173, 3.7749172176353745, 3.794733192202055, 3.8144462245521304, 3.8340579025361623, 3.853569773599539, 3.8729833462074166, 3.892300091205713], [0.0, 0.4, 0.565685424949238, 0.692820323027551, 0.8, 0.894427190999916, 0.9797958971132713, 1.0583005244258363, 1.131370849898476, 1.2, 1.2649110640673518, 1.32664991614216, 1.385640646055102, 1.4422205101855958, 1.4966629547095767, 1.5491933384829666, 1.6, 1.6492422502470643, 1.697056274847714, 1.7435595774162698, 1.788854381999832, 1.8330302779823362, 1.876166303929372, 1.918332609325088, 1.9595917942265426, 2.0, 2.039607805437114, 2.078460969082653, 2.1166010488516727, 2.154065922853802, 2.1908902300206643, 2.227105745132009, 2.262741699796952, 2.297825058615212, 2.3323807579381204, 2.3664319132398464, 2.4, 2.433105012119288, 2.4657656011875906, 2.4979991993593598, 2.5298221281347035, 2.5612496949731396, 2.5922962793631443, 2.6229754097208002, 2.65329983228432, 2.6832815729997477, 2.7129319932501073, 2.7422618401604177, 2.771281292110204, 2.8000000000000003, 2.8284271247461903, 2.8565713714171403, 2.8844410203711917, 2.9120439557122078, 2.939387691339814, 2.9664793948382653, 2.9933259094191533, 3.0199337741083, 3.0463092423455636, 3.0724582991474434, 3.098386676965933, 3.1240998703626617, 3.149603149604724, 3.1749015732775088, 3.2, 3.2249030993194197, 3.249615361854384, 3.2741411087489802, 3.2984845004941286, 3.32264954516723, 3.3466401061363023, 3.3704599092705436, 3.394112549695428, 3.4176014981270124, 3.4409301068170506, 3.464101615137755, 3.4871191548325395, 3.509985754956849, 3.532704346531139, 3.5552777669262356, 3.577708763999664, 3.6, 3.622154055254967, 3.6441734316577197, 3.6660605559646724, 3.687817782917155, 3.709447398198282, 3.7309516212355263, 3.752332607858744, 3.7735924528226414, 3.794733192202055, 3.8157568056677826, 3.836665218650176, 3.8574603043971822, 3.8781438859330635, 3.8987177379235853, 3.9191835884530852, 3.9395431207184424, 3.9597979746446663, 3.9799497484264803, 4.0, 4.019950248448357], [0.0, 0.41231056256176607, 0.58309518948453, 0.7141428428542851, 0.8246211251235321, 0.9219544457292888, 1.0099504938362078, 1.0908712114635715, 1.16619037896906, 1.236931687685298, 1.3038404810405297, 1.3674794331177345, 1.4282856857085702, 1.4866068747318506, 1.5427248620541512, 1.5968719422671311, 1.6492422502470643, 1.7, 1.7492855684535902, 1.797220075561143, 1.8439088914585775, 1.8894443627691184, 1.9339079605813716, 1.977371993328519, 2.0199009876724157, 2.0615528128088303, 2.102379604162864, 2.142428528562855, 2.181742422927143, 2.220360331117452, 2.258317958127243, 2.2956480566497994, 2.33238075793812, 2.3685438564654024, 2.4041630560342617, 2.4392621835300936, 2.473863375370596, 2.5079872407968904, 2.541653005427767, 2.574878637916747, 2.6076809620810595, 2.6400757564888173, 2.672077843177478, 2.7037011669191546, 2.734958866235469, 2.765863337187866, 2.7964262908219126, 2.826658805020514, 2.8565713714171403, 2.8861739379323623, 2.9154759474226504, 2.944486372867092, 2.973213749463701, 3.001666203960727, 3.0298514815086235, 3.0577769702841313, 3.0854497241083023, 3.1128764832546763, 3.1400636936215167, 3.167017524422623, 3.1937438845342623, 3.2202484376209237, 3.246536616149585, 3.2726136343907144, 3.2984845004941286, 3.324154027718932, 3.3496268448888453, 3.374907406137241, 3.4, 3.424908757908742, 3.4496376621320683, 3.4741905532080417, 3.4985711369071804, 3.522782990761707, 3.5468295701936396, 3.570714214271425, 3.594440151122286, 3.6180105030251086, 3.6414282912066254, 3.664696440361739, 3.687817782917155, 3.710795063055895, 3.733630940518894, 3.7563279941985894, 3.778888725538237, 3.8013155617496426, 3.8236108588610325, 3.845776904605882, 3.867815921162743, 3.8897300677553446, 3.9115214431215892, 3.9331920878594273, 3.954743986657038, 3.976179070414209, 3.9974992182613374, 4.018706259482023, 4.039801975344831, 4.060788100849391, 4.08166632639171, 4.102438299353203, 4.123105625617661, 4.1436698710201325], [0.0, 0.4242640687119285, 0.6, 0.7348469228349536, 0.848528137423857, 0.9486832980505139, 1.0392304845413265, 1.1224972160321824, 1.2, 1.2727922061357855, 1.3416407864998738, 1.407124727947029, 1.4696938456699071, 1.5297058540778357, 1.5874507866387544, 1.6431676725154982, 1.697056274847714, 1.7492855684535902, 1.8, 1.8493242008906932, 1.8973665961010278, 1.9442222095223582, 1.98997487421324, 2.0346989949375804, 2.078460969082653, 2.121320343559643, 2.1633307652783937, 2.2045407685048604, 2.244994432064365, 2.2847319317591728, 2.32379000772445, 2.3622023622035435, 2.4, 2.4372115213907883, 2.4738633753705965, 2.5099800796022267, 2.545584412271571, 2.5806975801127883, 2.615339366124404, 2.6495282598983545, 2.6832815729997477, 2.716615541441225, 2.749545416973504, 2.782085548648711, 2.814249455894058, 2.846049894151541, 2.877498913987632, 2.9086079144497976, 2.9393876913398143, 2.9698484809834995, 3.0, 3.029851481508624, 3.0594117081556713, 3.0886890422961004, 3.1176914536239795, 3.146426544510455, 3.1749015732775088, 3.2031234756093934, 3.2310988842807027, 3.2588341473600644, 3.2863353450309964, 3.3136083051561784, 3.340658617698013, 3.3674916480965473, 3.394112549695428, 3.420526275297414, 3.4467375879228173, 3.4727510708370675, 3.4985711369071804, 3.5242020373412193, 3.5496478698597698, 3.5749125863438955, 3.6, 3.6249137920783716, 3.6496575181789317, 3.6742346141747673, 3.6986484017813863, 3.722902093797257, 3.7469987990390394, 3.7709415269929605, 3.7947331922020555, 3.8183766184073566, 3.84187454245971, 3.8652296180175374, 3.8884444190447165, 3.9115214431215897, 3.9344631145812006, 3.957271787481876, 3.97994974842648, 4.0024992192379, 4.024922359499621, 4.047221268969612, 4.069397989875161, 4.091454509095757, 4.113392760240627, 4.135214625627066, 4.156921938165306, 4.178516483155236, 4.2, 4.221374183841087, 4.242640687119286, 4.263801121065569], [0.0, 0.43588989435406744, 0.6164414002968976, 0.7549834435270751, 0.8717797887081349, 0.9746794344808966, 1.0677078252031313, 1.1532562594670797, 1.2328828005937953, 1.307669683062202, 1.3784048752090223, 1.4456832294800963, 1.5099668870541503, 1.5716233645501714, 1.6309506430300091, 1.6881943016134133, 1.7435595774162698, 1.797220075561143, 1.8493242008906932, 1.9000000000000004, 1.9493588689617931, 1.9974984355438181, 2.0445048300260877, 2.0904544960366875, 2.1354156504062627, 2.179449471770337, 2.2226110770892875, 2.2649503305812253, 2.3065125189341593, 2.3473389188611007, 2.3874672772626644, 2.4269322199023198, 2.4657656011875906, 2.503996805109783, 2.5416530054277673, 2.5787593916455256, 2.615339366124404, 2.651414716712571, 2.687005768508881, 2.7221315177632404, 2.7568097504180447, 2.791057147390573, 2.8248893783651075, 2.8583211855912904, 2.8913664589601926, 2.924038303442689, 2.956349099818897, 2.9883105594967874, 3.0199337741083006, 3.051229260478472, 3.082207001484489, 3.1128764832546767, 3.1432467291003428, 3.1733263305244868, 3.203123475609394, 3.232645975048923, 3.2619012860600183, 3.290896534380867, 3.319638534539567, 3.3481338085566414, 3.3763886032268267, 3.4044089061098406, 3.432200460346103, 3.4597687784012394, 3.4871191548325395, 3.5142566781611158, 3.541186241925155, 3.567912554982255, 3.594440151122286, 3.6207733980463352, 3.6469165057620945, 3.672873534441392, 3.6986484017813863, 3.7242448899072147, 3.749666651850535, 3.7749172176353754, 3.8000000000000007, 3.824918299781056, 3.8496753109840323, 3.874274125562104, 3.8987177379235862, 3.9230090491866068, 3.947150871198111, 3.9711459303329564, 3.9949968710876362, 4.018706259482024, 4.042276586281548, 4.065710270051225, 4.0890096600521755, 4.112177038990418, 4.135214625627067, 4.158124577258358, 4.180908992073375, 4.203569911396741, 4.226109321823088, 4.2485291572496005, 4.270831300812525, 4.293017586733137, 4.315089802078284, 4.337049688440289, 4.358898943540674, 4.380639222761903], [0.0, 0.447213595499958, 0.6324555320336759, 0.7745966692414835, 0.894427190999916, 1.0000000000000002, 1.0954451150103324, 1.1832159566199234, 1.2649110640673518, 1.3416407864998738, 1.4142135623730951, 1.4832396974191329, 1.549193338482967, 1.61245154965971, 1.6733200530681511, 1.7320508075688772, 1.788854381999832, 1.8439088914585775, 1.8973665961010278, 1.9493588689617931, 2.0000000000000004, 2.04939015319192, 2.0976176963403033, 2.144761058952722, 2.1908902300206647, 2.23606797749979, 2.280350850198276, 2.3237900077244507, 2.366431913239847, 2.4083189157584592, 2.4494897427831783, 2.489979919597747, 2.5298221281347035, 2.5690465157330262, 2.60768096208106, 2.6457513110645907, 2.6832815729997477, 2.720294101747089, 2.7568097504180447, 2.7928480087537886, 2.8284271247461903, 2.863564212655271, 2.8982753492378883, 2.932575659723036, 2.9664793948382657, 3.0, 3.0331501776206204, 3.0659419433511785, 3.098386676965934, 3.130495168499706, 3.1622776601683795, 3.193743884534263, 3.22490309931942, 3.255764119219942, 3.286335345030997, 3.3166247903554003, 3.3466401061363023, 3.3763886032268267, 3.405877273185281, 3.4351128074635335, 3.4641016151377544, 3.492849839314596, 3.521363372331802, 3.5496478698597698, 3.577708763999664, 3.605551275463989, 3.6331804249169903, 3.6606010435446255, 3.687817782917155, 3.7148351242013424, 3.7416573867739418, 3.768288736283355, 3.7947331922020555, 3.82099463490856, 3.847076812334269, 3.872983346207417, 3.8987177379235862, 3.924283374069717, 3.9496835316263006, 3.9749213828703587, 4.000000000000001, 4.024922359499622, 4.049691346263318, 4.0743097574926725, 4.09878030638384, 4.123105625617661, 4.147288270665545, 4.171330722922843, 4.1952353926806065, 4.219004621945797, 4.242640687119286, 4.266145801540309, 4.289522117905444, 4.312771730569565, 4.335896677735761, 4.358898943540674, 4.3817804600413295, 4.404543109109049, 4.427188724235731, 4.449719092257398, 4.47213595499958, 4.494441010848847], [0.0, 0.45825756949558405, 0.6480740698407861, 0.7937253933193773, 0.9165151389911681, 1.02469507659596, 1.1224972160321824, 1.2124355652982142, 1.2961481396815722, 1.374772708486752, 1.449137674618944, 1.5198684153570665, 1.5874507866387546, 1.6522711641858308, 1.7146428199482247, 1.7748239349298847, 1.8330302779823362, 1.8894443627691184, 1.9442222095223582, 1.9974984355438181, 2.04939015319192, 2.1, 2.149418526020468, 2.1977260975835913, 2.244994432064365, 2.2912878474779204, 2.336664289109585, 2.381176179958132, 2.4248711305964283, 2.4677925358506134, 2.5099800796022267, 2.551470164434615, 2.5922962793631443, 2.632489316217637, 2.672077843177478, 2.711088342345192, 2.749545416973504, 2.787471972953271, 2.824889378365107, 2.861817604250837, 2.898275349237888, 2.934280150224242, 2.9698484809835, 3.004995840263344, 3.039736830714133, 3.0740852297878796, 3.108054053584011, 3.1416556144810017, 3.174901573277509, 3.2078029864690882, 3.2403703492039306, 3.272613634390715, 3.3045423283716615, 3.336165463522456, 3.3674916480965478, 3.398529093593286, 3.4292856398964493, 3.459768778401239, 3.48998567332303, 3.5199431813596083, 3.5496478698597693, 3.5791060336346563, 3.608323710533743, 3.6373066958946425, 3.6660605559646724, 3.6945906403822333, 3.722902093797257, 3.7509998667022106, 3.778888725538237, 3.8065732621348563, 3.834057902536163, 3.861346915261565, 3.8884444190447165, 3.915354390090379, 3.9420806688854046, 3.968626966596886, 3.9949968710876362, 4.02119385257662, 4.047221268969613, 4.07308237088326, 4.09878030638384, 4.124318125460256, 4.149698784249287, 4.174925149029621, 4.2, 4.224926034855522, 4.249705872175156, 4.274342054632503, 4.298837052040936, 4.323193264243457, 4.347413023856832, 4.371498598878879, 4.3954521951671826, 4.419275958796871, 4.442971978304612, 4.466542286825459, 4.48998886412873, 4.513313638558704, 4.536518488885503, 4.559605246071199, 4.582575694955841, 4.605431575867782], [0.0, 0.469041575982343, 0.6633249580710799, 0.8124038404635961, 0.938083151964686, 1.0488088481701516, 1.148912529307606, 1.2409673645990857, 1.3266499161421599, 1.407124727947029, 1.4832396974191326, 1.5556349186104048, 1.6248076809271923, 1.6911534525287764, 1.7549928774784245, 1.816590212458495, 1.876166303929372, 1.9339079605813716, 1.98997487421324, 2.0445048300260877, 2.0976176963403033, 2.149418526020468, 2.2, 2.249444375840399, 2.297825058615212, 2.345207879911715, 2.3916521486202797, 2.4372115213907883, 2.4819347291981715, 2.5258661880630178, 2.569046515733026, 2.6115129714401193, 2.6532998322843198, 2.6944387170614963, 2.734958866235469, 2.7748873851023217, 2.814249455894058, 2.8530685235374214, 2.891366458960192, 2.9291637031753623, 2.9664793948382653, 3.0033314835362415, 3.039736830714133, 3.0757112998459397, 3.1112698372208096, 3.1464265445104544, 3.1811947441173736, 3.2155870381627056, 3.2496153618543846, 3.283291031876401, 3.3166247903554003, 3.3496268448888458, 3.3823069050575527, 3.414674215792775, 3.4467375879228173, 3.4785054261852175, 3.509985754956849, 3.5411862419251547, 3.5721142198983507, 3.602776706930364, 3.63318042491699, 3.6633318168028404, 3.6932370625238775, 3.722902093797257, 3.752332607858744, 3.7815340802378072, 3.81051177665153, 3.8392707640904935, 3.867815921162743, 3.8961519477556315, 3.924283374069717, 3.952214569073901, 3.97994974842648, 4.007492981902776, 4.034848200366403, 4.06201920231798, 4.0890096600521755, 4.115823125451336, 4.1424630354415966, 4.168932717135166, 4.1952353926806065, 4.221374183841087, 4.247352116319061, 4.273172123844299, 4.298837052040936, 4.324349662087931, 4.349712634186309, 4.374928570845472, 4.4, 4.424929377967517, 4.449719092257398, 4.474371464239419, 4.498888751680798, 4.523273151159457, 4.54752680036083, 4.571651780264984, 4.595650117230424, 4.61952378498044, 4.64327470649756, 4.666904755831214, 4.69041575982343, 4.713809499757071], [0.0, 0.479583152331272, 0.6782329983125268, 0.8306623862918077, 0.959166304662544, 1.072380529476361, 1.174734012447073, 1.2688577540449522, 1.3564659966250536, 1.438749456993816, 1.5165750888103102, 1.5905973720586868, 1.6613247725836153, 1.7291616465790585, 1.7944358444926363, 1.857417562100671, 1.918332609325088, 1.977371993328519, 2.0346989949375804, 2.0904544960366875, 2.144761058952722, 2.1977260975835913, 2.249444375840399, 2.3000000000000003, 2.349468024894146, 2.39791576165636, 2.4454038521274972, 2.491987158875423, 2.5377155080899043, 2.582634314028992, 2.6267851073127395, 2.670205984563738, 2.7129319932501073, 2.754995462791183, 2.7964262908219126, 2.8372521918222215, 2.877498913987632, 2.917190429162965, 2.956349099818897, 2.994995826374388, 3.0331501776206204, 3.0708305065568178, 3.108054053584011, 3.1448370387032774, 3.1811947441173736, 3.2171415884290826, 3.252691193458119, 3.2878564445547194, 3.3226495451672307, 3.357082066318904, 3.3911649915626345, 3.4249087579087423, 3.458323293158117, 3.491418050019219, 3.5242020373412197, 3.5566838487557484, 3.5888716889852725, 3.620773398046335, 3.6523964735499352, 3.6837480912787726, 3.714835124201342, 3.745664160065609, 3.7762415176998414, 3.8065732621348563, 3.836665218650176, 3.866522985836241, 3.8961519477556315, 3.9255572852781047, 3.954743986657038, 3.9837168574084183, 4.012480529547776, 4.041039470235351, 4.069397989875161, 4.097560249709576, 4.125530268947254, 4.153311931459037, 4.180908992073375, 4.2083250825001635, 4.235563716909475, 4.262628297189424, 4.289522117905444, 4.316248370981448, 4.342810150121694, 4.369210454990696, 4.3954521951671826, 4.421538193886829, 4.447471191587417, 4.473253849269009, 4.498888751680798, 4.524378410345448, 4.549725266430931, 4.57493169347915, 4.6000000000000005, 4.624932431938872, 4.649731175025068, 4.674398357008098, 4.698936049788292, 4.723346271447818, 4.747630988187688, 4.77179211617606, 4.79583152331272, 4.819751030914357], [0.0, 0.48989794855663565, 0.6928203230275509, 0.8485281374238571, 0.9797958971132713, 1.0954451150103324, 1.2000000000000002, 1.2961481396815722, 1.3856406460551018, 1.469693845669907, 1.5491933384829668, 1.6248076809271923, 1.6970562748477143, 1.7663521732655696, 1.833030277982336, 1.8973665961010275, 1.9595917942265426, 2.0199009876724157, 2.078460969082653, 2.1354156504062627, 2.1908902300206647, 2.244994432064365, 2.297825058615212, 2.349468024894146, 2.4000000000000004, 2.4494897427831783, 2.4979991993593598, 2.5455844122715714, 2.5922962793631443, 2.638181191654584, 2.6832815729997477, 2.727636339397171, 2.7712812921102037, 2.8142494558940583, 2.8565713714171403, 2.898275349237888, 2.939387691339814, 2.979932885150268, 3.0199337741083, 3.0594117081556713, 3.0983866769659336, 3.136877428271625, 3.174901573277509, 3.212475680841802, 3.2496153618543846, 3.2863353450309964, 3.32264954516723, 3.358571124749333, 3.3941125496954285, 3.4292856398964493, 3.464101615137755, 3.498571136907181, 3.532704346531139, 3.5665109000254023, 3.6, 3.6331804249169903, 3.666060555964672, 3.698648401781386, 3.7309516212355263, 3.7629775444453557, 3.794733192202055, 3.8262252939417984, 3.857460304397182, 3.8884444190447165, 3.9191835884530852, 3.9496835316262997, 3.97994974842648, 4.009987531152684, 4.039801975344831, 4.069397989875161, 4.09878030638384, 4.127953488110059, 4.156921938165306, 4.18568990729127, 4.214261501141095, 4.242640687119286, 4.270831300812525, 4.298837052040936, 4.3266615305567875, 4.354308211415448, 4.3817804600413295, 4.409081537009721, 4.436214602563767, 4.463182720884279, 4.48998886412873, 4.5166359162544865, 4.543126676640219, 4.5694638635183455, 4.595650117230424, 4.621688003316537, 4.6475800154489, 4.673328578219169, 4.698936049788292, 4.724404724407087, 4.749736834815168, 4.774934554525329, 4.800000000000001, 4.824935232725928, 4.849742261192857, 4.874423042781577, 4.898979485566357, 4.9234134500364695], [0.0, 0.5, 0.7071067811865476, 0.8660254037844388, 1.0, 1.118033988749895, 1.2247448713915892, 1.3228756555322954, 1.4142135623730951, 1.5, 1.5811388300841898, 1.6583123951777001, 1.7320508075688776, 1.8027756377319948, 1.8708286933869707, 1.9364916731037083, 2.0, 2.0615528128088303, 2.121320343559643, 2.179449471770337, 2.23606797749979, 2.2912878474779204, 2.345207879911715, 2.39791576165636, 2.4494897427831783, 2.5000000000000004, 2.5495097567963927, 2.5980762113533165, 2.6457513110645907, 2.6925824035672523, 2.7386127875258306, 2.783882181415011, 2.8284271247461903, 2.8722813232690148, 2.9154759474226504, 2.958039891549808, 3.0, 3.04138126514911, 3.0822070014844885, 3.1224989991991996, 3.1622776601683795, 3.2015621187164247, 3.2403703492039306, 3.278719262151, 3.3166247903554003, 3.3541019662496843, 3.3911649915626345, 3.4278273002005224, 3.4641016151377553, 3.5, 3.535533905932738, 3.5707142142714257, 3.6055512754639896, 3.64005494464026, 3.6742346141747677, 3.708099243547832, 3.7416573867739413, 3.774917217635375, 3.8078865529319548, 3.840572873934304, 3.8729833462074166, 3.9051248379533274, 3.9370039370059056, 3.968626966596886, 4.0, 4.031128874149275, 4.06201920231798, 4.092676385936225, 4.123105625617661, 4.153311931459037, 4.183300132670378, 4.2130748865881795, 4.242640687119286, 4.272001872658766, 4.301162633521313, 4.330127018922194, 4.358898943540674, 4.387482193696061, 4.415880433163924, 4.444097208657795, 4.47213595499958, 4.500000000000001, 4.527692569068709, 4.55521678957215, 4.582575694955841, 4.609772228646444, 4.636809247747852, 4.663689526544408, 4.69041575982343, 4.716990566028302, 4.743416490252569, 4.769696007084729, 4.79583152331272, 4.821825380496478, 4.847679857416329, 4.873397172404482, 4.898979485566357, 4.924428900898053, 4.949747468305833, 4.974937185533101, 5.000000000000001, 5.024937810560446], [0.0, 0.5099019513592785, 0.7211102550927979, 0.8831760866327849, 1.019803902718557, 1.140175425099138, 1.2489995996796799, 1.3490737563232043, 1.4422205101855958, 1.5297058540778354, 1.61245154965971, 1.6911534525287766, 1.7663521732655698, 1.8384776310850237, 1.9078784028338913, 1.9748417658131499, 2.039607805437114, 2.102379604162864, 2.1633307652783937, 2.2226110770892875, 2.280350850198276, 2.336664289109585, 2.3916521486202797, 2.4454038521274972, 2.4979991993593598, 2.5495097567963927, 2.6000000000000005, 2.6495282598983545, 2.6981475126464085, 2.7459060435491964, 2.792848008753788, 2.839013913315678, 2.8844410203711917, 2.9291637031753623, 2.973213749463701, 3.0166206257996713, 3.059411708155671, 3.101612483854165, 3.1432467291003428, 3.1843366656181322, 3.22490309931942, 3.264965543462902, 3.304542328371662, 3.3436506994600976, 3.382306905057553, 3.420526275297414, 3.458323293158117, 3.4957116585897072, 3.5327043465311396, 3.5693136595149495, 3.6055512754639896, 3.6414282912066254, 3.6769552621700474, 3.712142238654118, 3.7469987990390394, 3.7815340802378077, 3.8157568056677826, 3.849675310984032, 3.8832975677895205, 3.916631205513228, 3.9496835316262997, 3.9824615503479754, 4.014971979976946, 4.047221268969613, 4.079215610874228, 4.110960958218893, 4.142463035441596, 4.173727350941841, 4.204759208325728, 4.235563716909475, 4.266145801540309, 4.296510211788167, 4.3266615305567875, 4.356604182158393, 4.386342439892262, 4.415880433163924, 4.445222154178575, 4.474371464239419, 4.503332099679082, 4.532107677449864, 4.560701700396552, 4.589117562233507, 4.617358552246079, 4.645427859734774, 4.67332857821917, 4.701063709417264, 4.7286361670147565, 4.756048780237647, 4.7833042972405595, 4.810405388322278, 4.83735464897913, 4.864154602806124, 4.8908077042549944, 4.917316341257699, 4.943682837723311, 4.969909455915671, 4.9959983987187195, 5.021951811795889, 5.047771785649585, 5.073460357586329, 5.099019513592785, 5.1244511901275835], [0.0, 0.5196152422706632, 0.7348469228349535, 0.9000000000000001, 1.0392304845413265, 1.1618950038622253, 1.2727922061357857, 1.374772708486752, 1.469693845669907, 1.5588457268119895, 1.6431676725154984, 1.7233687939614089, 1.8000000000000003, 1.8734993995195197, 1.9442222095223582, 2.0124611797498106, 2.078460969082653, 2.142428528562855, 2.2045407685048604, 2.2649503305812253, 2.3237900077244507, 2.381176179958132, 2.4372115213907883, 2.491987158875423, 2.5455844122715714, 2.5980762113533165, 2.6495282598983545, 2.7, 2.749545416973504, 2.7982137159266447, 2.8460498941515415, 2.8930952282978866, 2.939387691339814, 2.9849623113198605, 3.0298514815086235, 3.0740852297878796, 3.117691453623979, 3.160696125855822, 3.203123475609394, 3.244996147917591, 3.286335345030997, 3.3271609519228256, 3.3674916480965478, 3.407345007480164, 3.4467375879228177, 3.4856850115866753, 3.5242020373412197, 3.5623026261113755, 3.6000000000000005, 3.6373066958946425, 3.6742346141747677, 3.7107950630558952, 3.7469987990390394, 3.782856063875548, 3.818376618407357, 3.853569773599539, 3.8884444190447165, 3.9230090491866063, 3.957271787481876, 3.9912404086950213, 4.024922359499621, 4.058324777540605, 4.091454509095756, 4.124318125460256, 4.156921938165306, 4.189272013130682, 4.221374183841087, 4.253234063627348, 4.28485705712571, 4.316248370981448, 4.3474130238568325, 4.378355855797928, 4.409081537009721, 4.439594576084623, 4.469899327725402, 4.5, 4.529900661162451, 4.559605246071199, 4.589117562233508, 4.618441295502196, 4.647580015448901, 4.676537180435969, 4.705316142407438, 4.73392015141785, 4.762352359916264, 4.790615826801394, 4.818713521262704, 4.846648326421054, 4.874423042781577, 4.902040391510457, 4.929503017546495, 4.956813492557492, 4.983974317750846, 5.0109879265470205, 5.037856687124, 5.06458290484024, 5.091168824543143, 5.117616632769595, 5.143928459844674, 5.170106381884226, 5.196152422706633, 5.222068555658764], [0.0, 0.5291502622129182, 0.7483314773547882, 0.9165151389911681, 1.0583005244258363, 1.1832159566199234, 1.2961481396815722, 1.4000000000000001, 1.4966629547095764, 1.5874507866387544, 1.6733200530681511, 1.7549928774784245, 1.8330302779823362, 1.9078784028338915, 1.9798989873223332, 2.0493901531919194, 2.1166010488516727, 2.181742422927143, 2.244994432064365, 2.3065125189341593, 2.366431913239847, 2.4248711305964283, 2.4819347291981715, 2.5377155080899043, 2.5922962793631443, 2.6457513110645907, 2.6981475126464085, 2.749545416973504, 2.8000000000000003, 2.8495613697550017, 2.8982753492378874, 2.946183972531247, 2.993325909419153, 3.039736830714133, 3.0854497241083028, 3.1304951684997055, 3.1749015732775088, 3.2186953878862163, 3.2619012860600183, 3.3045423283716615, 3.3466401061363023, 3.3882148692194836, 3.4292856398964497, 3.4698703145794942, 3.509985754956849, 3.5496478698597693, 3.5888716889852725, 3.627671429443411, 3.6660605559646724, 3.704051835490427, 3.7416573867739418, 3.7788887255382373, 3.815756805667783, 3.852272056851645, 3.8884444190447165, 3.924283374069717, 3.9597979746446663, 3.994996871087636, 4.029888335921977, 4.064480286580315, 4.098780306383839, 4.132795663954365, 4.166533331199932, 4.2, 4.233202097703345, 4.266145801540308, 4.298837052040936, 4.331281565541543, 4.363484845854286, 4.3954521951671826, 4.427188724235731, 4.458699361921591, 4.48998886412873, 4.521061822182926, 4.551922670696417, 4.58257569495584, 4.613025037868319, 4.64327470649756, 4.67332857821917, 4.703190406521939, 4.732863826479694, 4.762352359916263, 4.791659420284376, 4.82078831727758, 4.849742261192857, 4.878524367060187, 4.907137658554119, 4.935585071701227, 4.963869458396343, 4.991993589739474, 5.019960159204453, 5.047771785649585, 5.075431016179809, 5.10294032886923, 5.130302135352265, 5.15751878329105, 5.184592558726289, 5.2115256883181535, 5.238320341483518, 5.264978632435274, 5.291502622129181, 5.317894320123333], [0.0, 0.5385164807134505, 0.7615773105863909, 0.9327379053088817, 1.077032961426901, 1.2041594578792296, 1.319090595827292, 1.4247806848775009, 1.5231546211727818, 1.6155494421403513, 1.7029386365926402, 1.7860571099491753, 1.8654758106177634, 1.94164878389476, 2.0149441679609885, 2.085665361461421, 2.154065922853802, 2.220360331117452, 2.2847319317591728, 2.3473389188611007, 2.4083189157584592, 2.4677925358506134, 2.5258661880630178, 2.582634314028992, 2.638181191654584, 2.6925824035672523, 2.7459060435491964, 2.7982137159266447, 2.8495613697550017, 2.9000000000000004, 2.9495762407505253, 2.99833287011299, 3.0463092423455636, 3.0935416596516045, 3.1400636936215167, 3.1859064644147983, 3.2310988842807027, 3.2756678708318403, 3.3196385345395667, 3.363034344160048, 3.4058772731852804, 3.448187929913334, 3.48998567332303, 3.531288716601915, 3.5721142198983507, 3.6124783736376886, 3.6523964735499352, 3.691882988394947, 3.7309516212355267, 3.769615364994153, 3.8078865529319548, 3.845776904605883, 3.88329756778952, 3.9204591567825324, 3.957271787481876, 3.993745109543172, 4.029888335921977, 4.065710270051224, 4.101219330881976, 4.136423575989287, 4.171330722922842, 4.205948168962618, 4.240283009422838, 4.274342054632503, 4.308131845707604, 4.341658669218482, 4.374928570845472, 4.407947368106838, 4.440720662234904, 4.473253849269009, 4.505552130427525, 4.537620521815371, 4.5694638635183455, 4.601086828130937, 4.632493928760188, 4.663689526544408, 4.694677837722201, 4.725462940284264, 4.756048780237647, 4.786439177509728, 4.8166378315169185, 4.846648326421054, 4.876474136094644, 4.906118628814432, 4.935585071701227, 4.964876634922565, 4.993996395673509, 5.022947341949744, 5.0517323761260355, 5.0803543183522155, 5.10881590977792, 5.137119815616529, 5.165268628057984, 5.193264869039514, 5.221110992882646, 5.2488093888042835, 5.276362383309168, 5.3037722424704485, 5.331041174104736, 5.358171329847527, 5.385164807134505, 5.412023651093924], [0.0, 0.5477225575051661, 0.7745966692414833, 0.9486832980505139, 1.0954451150103321, 1.2247448713915892, 1.3416407864998738, 1.4491376746189437, 1.5491933384829666, 1.6431676725154982, 1.7320508075688772, 1.816590212458495, 1.8973665961010278, 1.9748417658131499, 2.0493901531919194, 2.1213203435596424, 2.1908902300206643, 2.258317958127243, 2.32379000772445, 2.3874672772626644, 2.4494897427831783, 2.5099800796022267, 2.569046515733026, 2.6267851073127395, 2.6832815729997477, 2.7386127875258306, 2.792848008753788, 2.8460498941515415, 2.8982753492378874, 2.9495762407505253, 2.9999999999999996, 3.049590136395381, 3.098386676965933, 3.146426544510455, 3.1937438845342623, 3.2403703492039297, 3.2863353450309964, 3.331666249791536, 3.376388603226826, 3.420526275297414, 3.4641016151377544, 3.5071355833500366, 3.5496478698597698, 3.5916569992135936, 3.63318042491699, 3.674234614174767, 3.714835124201342, 3.7549966711037173, 3.7947331922020555, 3.8340579025361627, 3.872983346207417, 3.9115214431215892, 3.9496835316262997, 3.9874804074753776, 4.024922359499621, 4.06201920231798, 4.098780306383839, 4.135214625627066, 4.171330722922842, 4.207136793592525, 4.242640687119285, 4.277849927241487, 4.3127717305695645, 4.347413023856832, 4.381780460041329, 4.415880433163923, 4.449719092257397, 4.483302354291978, 4.516635916254486, 4.54972526643093, 4.58257569495584, 4.61519230368573, 4.6475800154489, 4.679743582719036, 4.711687595755898, 4.743416490252569, 4.774934554525329, 4.806245936279166, 4.83735464897913, 4.868264577855234, 4.898979485566357, 4.929503017546495, 4.959838707054898, 4.9899899799498595, 5.019960159204453, 5.049752469181039, 5.079370039680118, 5.10881590977792, 5.138093031466052, 5.167204273105525, 5.196152422706632, 5.224940191045253, 5.253570214625479, 5.282045058497703, 5.310367218940701, 5.338539126015655, 5.366563145999495, 5.394441583704471, 5.422176684690383, 5.449770637375485, 5.477225575051661, 5.504543577809154], [0.0, 0.5567764362830022, 0.7874007874011811, 0.9643650760992957, 1.1135528725660044, 1.2449899597988734, 1.3638181696985856, 1.4730919862656235, 1.5748015748023623, 1.6703293088490065, 1.760681686165901, 1.846618531261939, 1.9287301521985913, 2.0074859899884734, 2.083266665599966, 2.1563858652847823, 2.227105745132009, 2.2956480566497994, 2.3622023622035435, 2.4269322199023198, 2.489979919597747, 2.551470164434615, 2.6115129714401193, 2.670205984563738, 2.727636339397171, 2.783882181415011, 2.839013913315678, 2.8930952282978866, 2.946183972531247, 2.99833287011299, 3.049590136395381, 3.1, 3.1496031496047245, 3.1984371183438953, 3.2465366161495854, 3.2939338184001206, 3.340658617698013, 3.38673884437522, 3.432200460346103, 3.477067730142742, 3.521363372331802, 3.5651086939951777, 3.6083237105337433, 3.6510272527057364, 3.693237062523878, 3.7349698793966195, 3.7762415176998414, 3.817066936798463, 3.8574603043971827, 3.8974350539810154, 3.9370039370059056, 3.9761790704142093, 4.014971979976947, 4.053393639902249, 4.091454509095757, 4.129164564412516, 4.166533331199932, 4.20356991139674, 4.240283009422838, 4.276680956068619, 4.3127717305695645, 4.34856298103178, 4.384062043356595, 4.419275958796871, 4.454211490264018, 4.488875137492688, 4.523273151159456, 4.557411546042337, 4.591296113299599, 4.624932431938872, 4.658325879540847, 4.69148164229596, 4.724404724407087, 4.757099956906519, 4.789572005931219, 4.8218253804964775, 4.8538644398046396, 4.8856934001224435, 4.917316341257699, 4.948737212663449, 4.979959839195494, 5.01098792654702, 5.041825066382213, 5.072474741188959, 5.10294032886923, 5.13322510708424, 5.163332257370235, 5.193264869039514, 5.223025942880239, 5.252618394667558, 5.282045058497703, 5.3113086899558, 5.340411969127476, 5.36935750346352, 5.398147830506312, 5.426785420486054, 5.455272678794342, 5.483611948342078, 5.511805511808268, 5.539855593785817, 5.567764362830022, 5.595533933415113], [0.0, 0.565685424949238, 0.7999999999999999, 0.9797958971132713, 1.131370849898476, 1.2649110640673518, 1.3856406460551018, 1.4966629547095764, 1.5999999999999999, 1.697056274847714, 1.7888543819998317, 1.876166303929372, 1.9595917942265426, 2.039607805437114, 2.116601048851672, 2.1908902300206643, 2.262741699796952, 2.33238075793812, 2.4, 2.4657656011875906, 2.5298221281347035, 2.5922962793631443, 2.6532998322843198, 2.7129319932501073, 2.7712812921102037, 2.8284271247461903, 2.8844410203711917, 2.939387691339814, 2.993325909419153, 3.0463092423455636, 3.098386676965933, 3.1496031496047245, 3.1999999999999997, 3.249615361854384, 3.2984845004941286, 3.3466401061363023, 3.394112549695428, 3.4409301068170506, 3.487119154832539, 3.5327043465311387, 3.5777087639996634, 3.622154055254967, 3.6660605559646724, 3.709447398198281, 3.752332607858744, 3.7947331922020546, 3.8366652186501757, 3.878143885933063, 3.9191835884530852, 3.959797974644666, 4.0, 4.039801975344831, 4.079215610874228, 4.118252056394801, 4.156921938165306, 4.1952353926806065, 4.233202097703344, 4.2708313008125245, 4.308131845707603, 4.345112196480086, 4.381780460041329, 4.418144406874904, 4.454211490264017, 4.48998886412873, 4.525483399593904, 4.560701700396551, 4.595650117230423, 4.63033476111609, 4.66476151587624, 4.698936049788292, 4.732863826479693, 4.766550115125193, 4.8, 4.833218389437829, 4.866210024238575, 4.898979485566356, 4.931531202375181, 4.963869458396343, 4.995998398718719, 5.027922035990614, 5.059644256269407, 5.091168824543142, 5.122499389946279, 5.15363949069005, 5.184592558726289, 5.215361924162119, 5.2459508194416005, 5.276362383309167, 5.3065996645686395, 5.336665625650533, 5.366563145999495, 5.396295025292816, 5.4258639865002145, 5.455272678794342, 5.4845236803208355, 5.513619500836088, 5.542562584220407, 5.571355310873648, 5.6, 5.628498911788116, 5.656854249492381, 5.685068161420759], [0.0, 0.574456264653803, 0.812403840463596, 0.9949874371066202, 1.148912529307606, 1.2845232578665131, 1.4071247279470291, 1.5198684153570665, 1.624807680927192, 1.7233687939614086, 1.8165902124584952, 1.9052558883257653, 1.9899748742132404, 2.0712315177207983, 2.149418526020468, 2.224859546128699, 2.297825058615212, 2.3685438564654024, 2.4372115213907883, 2.503996805109783, 2.5690465157330262, 2.632489316217637, 2.6944387170614963, 2.754995462791183, 2.8142494558940583, 2.8722813232690148, 2.9291637031753623, 2.9849623113198605, 3.039736830714133, 3.0935416596516045, 3.146426544510455, 3.1984371183438953, 3.249615361854384, 3.3000000000000007, 3.3496268448888458, 3.398529093593286, 3.4467375879228173, 3.49428104193123, 3.541186241925155, 3.58747822293042, 3.6331804249169903, 3.678314831549905, 3.7229020937972575, 3.7669616403674726, 3.8105117766515306, 3.853569773599539, 3.896151947755632, 3.9382737335030438, 3.9799497484264807, 4.02119385257662, 4.06201920231798, 4.102438299353204, 4.1424630354415966, 4.182104733265298, 4.221374183841087, 4.260281680828159, 4.298837052040936, 4.337049688440288, 4.374928570845472, 4.412482294582042, 4.449719092257398, 4.486646854834912, 4.523273151159457, 4.559605246071199, 4.595650117230424, 4.631414470763764, 4.666904755831214, 4.702127178203499, 4.737087712930805, 4.77179211617606, 4.806245936279167, 4.8404545241123795, 4.874423042781577, 4.908156476723211, 4.941659640242335, 4.974937185533101, 5.007993610219566, 5.040833264451424, 5.07346035758633, 5.105878964487898, 5.1380930314660525, 5.170106381884226, 5.201922721455982, 5.23354564325181, 5.264978632435274, 5.296225070746145, 5.327288240746882, 5.358171329847526, 5.388877434122993, 5.419409561935692, 5.449770637375486, 5.479963503528103, 5.509990925582366, 5.539855593785817, 5.569560126257729, 5.599107071667768, 5.628498911788117, 5.657738063926256, 5.686826883245173, 5.715767664977296, 5.7445626465380295, 5.773214009544425], [0.0, 0.5830951894845301, 0.8246211251235321, 1.009950493836208, 1.1661903789690602, 1.30384048104053, 1.4282856857085702, 1.5427248620541514, 1.6492422502470643, 1.7492855684535902, 1.8439088914585775, 1.9339079605813718, 2.019900987672416, 2.102379604162864, 2.181742422927143, 2.258317958127243, 2.3323807579381204, 2.4041630560342617, 2.4738633753705965, 2.5416530054277673, 2.60768096208106, 2.672077843177478, 2.734958866235469, 2.7964262908219126, 2.8565713714171403, 2.9154759474226504, 2.973213749463701, 3.0298514815086235, 3.0854497241083028, 3.1400636936215167, 3.1937438845342623, 3.2465366161495854, 3.2984845004941286, 3.3496268448888458, 3.4000000000000004, 3.449637662132068, 3.4985711369071804, 3.54682957019364, 3.594440151122286, 3.6414282912066254, 3.687817782917155, 3.733630940518894, 3.7788887255382373, 3.823610858861032, 3.8678159211627436, 3.911521443121589, 3.954743986657038, 3.997499218261337, 4.039801975344832, 4.08166632639171, 4.123105625617661, 4.164132562731403, 4.204759208325728, 4.244997055358225, 4.28485705712571, 4.324349662087931, 4.363484845854286, 4.402272140611028, 4.440720662234904, 4.4788391353117385, 4.516635916254486, 4.5541190146942805, 4.591296113299598, 4.628174586162454, 4.664761515876241, 4.701063709417263, 4.737087712930805, 4.77283982551269, 4.8083261120685235, 4.843552415324934, 4.878524367060187, 4.913247398615299, 4.947726750741193, 4.98196748283246, 5.015974481593781, 5.049752469181039, 5.083306010855535, 5.1166395221864125, 5.149757275833494, 5.182663407939976, 5.21536192416212, 5.247856705360771, 5.280151512977635, 5.31224999411737, 5.344155686354956, 5.375872022286245, 5.40740233383831, 5.4387498563548595, 5.469917732470938, 5.500909015790026, 5.531726674375733, 5.562373594069352, 5.592852581643825, 5.62316636780382, 5.653317610041029, 5.683308895353129, 5.713142742834281, 5.742821606144492, 5.772347875864725, 5.801723881744115, 5.830951894845301, 5.860034129593445], [0.0, 0.5916079783099616, 0.8366600265340756, 1.02469507659596, 1.1832159566199232, 1.3228756555322954, 1.449137674618944, 1.5652475842498528, 1.6733200530681511, 1.7748239349298847, 1.8708286933869707, 1.9621416870348585, 2.04939015319192, 2.1330729007701543, 2.2135943621178655, 2.29128784747792, 2.3664319132398464, 2.4392621835300936, 2.5099800796022267, 2.5787593916455256, 2.6457513110645907, 2.711088342345192, 2.7748873851023217, 2.8372521918222215, 2.898275349237888, 2.958039891549808, 3.0166206257996713, 3.0740852297878796, 3.1304951684997055, 3.1859064644147983, 3.2403703492039297, 3.2939338184001206, 3.3466401061363023, 3.398529093593286, 3.449637662132068, 3.5, 3.5496478698597693, 3.5986108430893164, 3.646916505762094, 3.6945906403822333, 3.7416573867739413, 3.7881393849751626, 3.834057902536163, 3.879432948254164, 3.924283374069717, 3.9686269665968856, 4.012480529547776, 4.05585995813465, 4.09878030638384, 4.141255848169731, 4.183300132670378, 4.224926034855522, 4.266145801540309, 4.306971093471606, 4.347413023856832, 4.387482193696061, 4.427188724235731, 4.466542286825459, 4.505552130427525, 4.544227107000705, 4.58257569495584, 4.620606020859168, 4.658325879540846, 4.695742752749559, 4.732863826479693, 4.769696007084728, 4.806245936279166, 4.8425200051213, 4.878524367060187, 4.914264950122246, 4.949747468305833, 4.984977432245807, 5.019960159204453, 5.054700782440045, 5.089204259999788, 5.123475382979799, 5.157518783291051, 5.191338940966964, 5.2249401910452535, 5.2583267300539625, 5.291502622129181, 5.324471804789654, 5.35723809439155, 5.389805191284746, 5.422176684690384, 5.454356057317858, 5.486346689738081, 5.518151864528558, 5.549774770204643, 5.58121850495033, 5.612486080160912, 5.643580423808984, 5.674504383644443, 5.705260730238365, 5.735852159879995, 5.766281297335397, 5.796550698475776, 5.826662852782887, 5.856620185738529, 5.886425061104576, 5.916079783099616, 5.9455865984779], [0.0, 0.6, 0.848528137423857, 1.0392304845413265, 1.2, 1.3416407864998738, 1.469693845669907, 1.5874507866387544, 1.697056274847714, 1.7999999999999998, 1.8973665961010275, 1.98997487421324, 2.078460969082653, 2.1633307652783937, 2.244994432064365, 2.3237900077244498, 2.4, 2.473863375370596, 2.545584412271571, 2.615339366124404, 2.6832815729997477, 2.749545416973504, 2.814249455894058, 2.877498913987632, 2.939387691339814, 3.0, 3.059411708155671, 3.117691453623979, 3.1749015732775088, 3.2310988842807027, 3.2863353450309964, 3.340658617698013, 3.394112549695428, 3.4467375879228173, 3.4985711369071804, 3.5496478698597693, 3.5999999999999996, 3.6496575181789317, 3.698648401781386, 3.746998799039039, 3.794733192202055, 3.8418745424597094, 3.8884444190447165, 3.9344631145812, 3.97994974842648, 4.024922359499621, 4.069397989875161, 4.113392760240626, 4.156921938165306, 4.2, 4.242640687119285, 4.28485705712571, 4.3266615305567875, 4.368065933568311, 4.409081537009721, 4.449719092257398, 4.48998886412873, 4.52990066116245, 4.569463863518345, 4.608687448721165, 4.6475800154488995, 4.686149805543993, 4.724404724407086, 4.762352359916263, 4.8, 4.8373546489791295, 4.874423042781576, 4.91121166312347, 4.947726750741192, 4.983974317750845, 5.019960159204453, 5.0556898639058145, 5.091168824543142, 5.126402247190518, 5.161395160225576, 5.196152422706632, 5.230678732248808, 5.264978632435273, 5.299056519796709, 5.332916650389353, 5.366563145999495, 5.4, 5.43323108288245, 5.466260147486579, 5.499090833947008, 5.531726674375732, 5.5641710972974225, 5.596427431853289, 5.628498911788116, 5.660388679233962, 5.692099788303082, 5.7236352085016735, 5.754997827975264, 5.786190456595773, 5.817215828899595, 5.848076606885377, 5.878775382679628, 5.909314681077663, 5.939696961966999, 5.96992462263972, 6.0, 6.029925372672535], [0.0, 0.608276253029822, 0.8602325267042626, 1.053565375285274, 1.216552506059644, 1.3601470508735445, 1.489966442575134, 1.6093476939431082, 1.7204650534085253, 1.8248287590894658, 1.9235384061671346, 2.017424100183202, 2.107130750570548, 2.193171219946131, 2.2759613353482084, 2.355843797877949, 2.433105012119288, 2.5079872407968904, 2.5806975801127883, 2.651414716712571, 2.720294101747089, 2.787471972953271, 2.8530685235374214, 2.917190429162965, 2.979932885150268, 3.04138126514911, 3.101612483854165, 3.160696125855822, 3.2186953878862163, 3.2756678708318403, 3.331666249791536, 3.38673884437522, 3.4409301068170506, 3.49428104193123, 3.54682957019364, 3.5986108430893164, 3.6496575181789317, 3.7, 3.7496666518505353, 3.7986839826445165, 3.847076812334269, 3.89486841883009, 3.942080668885405, 3.988734135035826, 4.034848200366404, 4.080441152620633, 4.125530268947254, 4.170131892398609, 4.214261501141096, 4.257933771208754, 4.301162633521314, 4.343961325794695, 4.386342439892262, 4.428317965096906, 4.469899327725402, 4.511097427455985, 4.551922670696417, 4.592385001282014, 4.632493928760188, 4.672258554489466, 4.711687595755898, 4.750789408087881, 4.789572005931219, 4.828043081829325, 4.866210024238576, 4.904079934095691, 4.941659640242335, 4.978955713801841, 5.015974481593781, 5.052722038663912, 5.089204259999789, 5.1254268114957995, 5.1613951602255765, 5.197114584074513, 5.232590180780452, 5.26782687642637, 5.302829433425142, 5.3376024580330075, 5.372150407425318, 5.406477596365309, 5.440588203494178, 5.474486277268398, 5.508175741568166, 5.541660400998964, 5.574943945906542, 5.608029957123981, 5.640921910468182, 5.673623181001714, 5.706137047074843, 5.7384666941614295, 5.770615218501404, 5.8025856305616035, 5.83438085832593, 5.866003750424986, 5.897457079114693, 5.928743543112655, 5.959865770300536, 5.990826320300065, 6.021627686929839, 6.052272300549605, 6.08276253029822, 6.113100686231171], [0.0, 0.6164414002968976, 0.8717797887081348, 1.0677078252031313, 1.2328828005937953, 1.3784048752090223, 1.50996688705415, 1.6309506430300091, 1.7435595774162695, 1.849324200890693, 1.949358868961793, 2.0445048300260877, 2.1354156504062627, 2.222611077089287, 2.3065125189341593, 2.3874672772626644, 2.4657656011875906, 2.541653005427767, 2.615339366124404, 2.687005768508881, 2.7568097504180447, 2.824889378365107, 2.891366458960192, 2.956349099818897, 3.0199337741083, 3.0822070014844885, 3.1432467291003428, 3.203123475609394, 3.2619012860600183, 3.3196385345395667, 3.376388603226826, 3.432200460346103, 3.487119154832539, 3.541186241925155, 3.594440151122286, 3.646916505762094, 3.698648401781386, 3.7496666518505353, 3.8000000000000003, 3.8496753109840323, 3.898717737923586, 3.9471508711981107, 3.9949968710876362, 4.042276586281547, 4.0890096600521755, 4.135214625627066, 4.180908992073375, 4.226109321823088, 4.270831300812525, 4.315089802078284, 4.358898943540674, 4.402272140611029, 4.445222154178574, 4.487761134463376, 4.529900661162451, 4.571651780264984, 4.613025037868319, 4.654030511288038, 4.694677837722201, 4.734976240700686, 4.774934554525329, 4.814561246884289, 4.853864439804639, 4.892851929090027, 4.931531202375181, 4.969909455915671, 5.007993610219566, 5.045790324617146, 5.083306010855534, 5.120546845796843, 5.157518783291051, 5.194227565288221, 5.230678732248808, 5.266877632905477, 5.302829433425141, 5.338539126015656, 5.374011537017762, 5.409251334519409, 5.444263035526481, 5.47905101272109, 5.513619500836089, 5.547972602672079, 5.582114294781146, 5.616048432839589, 5.649778756730214, 5.68330889535313, 5.716642371182581, 5.749782604586021, 5.782732917920384, 5.815496539419485, 5.848076606885378, 5.880476171195663, 5.912698199637794, 5.944745579080741, 5.976621118993575, 6.008327554319921, 6.0398675482166, 6.071243694664217, 6.102458520956943, 6.133514490078262, 6.164414002968977, 6.1951594006934165], [0.0, 0.6244997998398399, 0.8831760866327847, 1.081665382639197, 1.2489995996796799, 1.3964240043768943, 1.5297058540778357, 1.6522711641858308, 1.7663521732655694, 1.8734993995195195, 1.97484176581315, 2.0712315177207983, 2.163330765278394, 2.2516660498395407, 2.3366642891095846, 2.4186773244895647, 2.4979991993593598, 2.574878637916747, 2.6495282598983545, 2.7221315177632404, 2.7928480087537886, 2.861817604250837, 2.9291637031753623, 2.994995826374388, 3.0594117081556713, 3.1224989991991996, 3.1843366656181322, 3.244996147917591, 3.3045423283716615, 3.363034344160048, 3.420526275297414, 3.477067730142742, 3.5327043465311387, 3.58747822293042, 3.6414282912066254, 3.6945906403822333, 3.746998799039039, 3.7986839826445165, 3.8496753109840323, 3.900000000000001, 3.9496835316263, 3.9987498046264416, 4.047221268969613, 4.095119045888654, 4.1424630354415966, 4.189272013130682, 4.235563716909475, 4.281354925721529, 4.326661530556788, 4.371498598878879, 4.415880433163924, 4.459820624195553, 4.503332099679081, 4.546427168667723, 4.589117562233507, 4.631414470763765, 4.673328578219169, 4.7148700936505135, 4.756048780237647, 4.796873982084583, 4.8373546489791295, 4.87749935930288, 4.917316341257699, 4.956813492557492, 4.9959983987187195, 5.034878350069642, 5.073460357586329, 5.111751167652823, 5.149757275833494, 5.187484939737176, 5.2249401910452535, 5.262128846769148, 5.299056519796709, 5.335728628781641, 5.372150407425317, 5.408326913195984, 5.444263035526481, 5.479963503528103, 5.515432893255072, 5.550675634551168, 5.585696017507577, 5.620498198558559, 5.655086206239478, 5.68946394662977, 5.723635208501674, 5.757603668193913, 5.791372894228104, 5.8249463516842805, 5.858327406350725, 5.8915193286621745, 5.92452529743945, 5.957348403442593, 5.989991652748776, 6.02245796996542, 6.054750201288242, 6.08687111741328, 6.118823416311343, 6.150609725872713, 6.182232606429493, 6.213694553162394, 6.244997998398399, 6.276145313805283], [0.0, 0.6324555320336759, 0.8944271909999159, 1.0954451150103324, 1.2649110640673518, 1.4142135623730951, 1.5491933384829668, 1.6733200530681511, 1.7888543819998317, 1.8973665961010275, 2.0, 2.0976176963403033, 2.1908902300206647, 2.280350850198276, 2.3664319132398464, 2.449489742783178, 2.5298221281347035, 2.6076809620810595, 2.6832815729997477, 2.7568097504180447, 2.8284271247461903, 2.898275349237888, 2.9664793948382653, 3.0331501776206204, 3.0983866769659336, 3.1622776601683795, 3.22490309931942, 3.286335345030997, 3.3466401061363023, 3.4058772731852804, 3.4641016151377544, 3.521363372331802, 3.5777087639996634, 3.6331804249169903, 3.687817782917155, 3.7416573867739413, 3.794733192202055, 3.847076812334269, 3.898717737923586, 3.9496835316263, 4.0, 4.049691346263318, 4.09878030638384, 4.147288270665544, 4.1952353926806065, 4.242640687119285, 4.2895221179054435, 4.33589667773576, 4.3817804600413295, 4.427188724235731, 4.47213595499958, 4.5166359162544865, 4.560701700396552, 4.604345773288536, 4.6475800154489, 4.69041575982343, 4.732863826479693, 4.774934554525329, 4.8166378315169185, 4.857983120596447, 4.898979485566356, 4.9396356140913875, 4.979959839195493, 5.019960159204453, 5.059644256269407, 5.0990195135927845, 5.138093031466052, 5.176871642217914, 5.215361924162119, 5.253570214625479, 5.291502622129181, 5.329165037789691, 5.366563145999495, 5.403702434442518, 5.440588203494177, 5.477225575051661, 5.513619500836089, 5.549774770204643, 5.585696017507577, 5.621387729022079, 5.656854249492381, 5.692099788303083, 5.727128425310542, 5.761944116355173, 5.796550698475776, 5.830951894845301, 5.865151319446072, 5.8991524815010505, 5.932958789676531, 5.966573556070519, 6.0, 6.0332412515993425, 6.066300355241241, 6.099180272790763, 6.131883886702357, 6.164414002968976, 6.196773353931867, 6.228964600958975, 6.260990336999411, 6.29285308902091, 6.324555320336759, 6.356099432828282], [0.0, 0.6403124237432849, 0.9055385138137417, 1.1090536506409419, 1.2806248474865698, 1.4317821063276355, 1.5684387141358125, 1.6941074346097418, 1.8110770276274835, 1.9209372712298547, 2.024845673131659, 2.1236760581595306, 2.2181073012818837, 2.3086792761230397, 2.395829710142188, 2.479919353527449, 2.5612496949731396, 2.6400757564888173, 2.716615541441225, 2.791057147390573, 2.863564212655271, 2.934280150224242, 3.0033314835362415, 3.0708305065568178, 3.136877428271625, 3.2015621187164247, 3.264965543462902, 3.3271609519228256, 3.3882148692194836, 3.448187929913334, 3.5071355833500366, 3.5651086939951777, 3.622154055254967, 3.678314831549905, 3.733630940518894, 3.7881393849751626, 3.8418745424597094, 3.89486841883009, 3.9471508711981107, 3.9987498046264416, 4.049691346263318, 4.1000000000000005, 4.149698784249287, 4.198809355043403, 4.247352116319061, 4.295346318982906, 4.342810150121693, 4.389760813529594, 4.436214602563767, 4.4821869662029945, 4.527692569068709, 4.572745346069471, 4.617358552246079, 4.661544808322667, 4.705316142407437, 4.748684028233507, 4.791659420284376, 4.8342527861087286, 4.876474136094644, 4.9183330509431755, 4.959838707054898, 5.000999900019996, 5.041825066382213, 5.082322303829225, 5.122499389946279, 5.162363799656123, 5.201922721455982, 5.241183072551464, 5.280151512977635, 5.3188344587888805, 5.35723809439155, 5.395368384086485, 5.43323108288245, 5.470831746635972, 5.508175741568165, 5.545268253204709, 5.582114294781146, 5.61871871515206, 5.655086206239478, 5.691221310052879, 5.727128425310542, 5.762811813689565, 5.798275605729691, 5.833523806414096, 5.868560300448484, 5.903388857258177, 5.93801313572141, 5.9724366886556455, 6.006662967072483, 6.040695324215583, 6.074537019394977, 6.1081912216301815, 6.1416610131136355, 6.174949392505174, 6.208059278067504, 6.24099351065197, 6.27375485654325, 6.306346010171025, 6.338769596696192, 6.3710281744785915, 6.403124237432849, 6.435060217278469], [0.0, 0.6480740698407861, 0.9165151389911681, 1.1224972160321827, 1.2961481396815722, 1.4491376746189442, 1.5874507866387546, 1.7146428199482249, 1.8330302779823362, 1.9442222095223582, 2.04939015319192, 2.149418526020468, 2.2449944320643653, 2.336664289109585, 2.4248711305964283, 2.5099800796022267, 2.5922962793631443, 2.672077843177478, 2.749545416973504, 2.8248893783651075, 2.8982753492378883, 2.9698484809835, 3.039736830714133, 3.108054053584011, 3.174901573277509, 3.2403703492039306, 3.304542328371662, 3.3674916480965478, 3.4292856398964497, 3.48998567332303, 3.5496478698597698, 3.6083237105337433, 3.6660605559646724, 3.7229020937972575, 3.7788887255382373, 3.834057902536163, 3.8884444190447165, 3.942080668885405, 3.9949968710876362, 4.047221268969613, 4.09878030638384, 4.149698784249287, 4.200000000000001, 4.249705872175156, 4.298837052040936, 4.347413023856832, 4.3954521951671826, 4.442971978304612, 4.489988864128731, 4.536518488885503, 4.582575694955841, 4.628174586162455, 4.67332857821917, 4.718050444834181, 4.762352359916264, 4.806245936279167, 4.849742261192857, 4.892851929090027, 4.935585071701227, 4.9779513858614575, 5.019960159204453, 5.061620293937506, 5.10294032886923, 5.143928459844674, 5.184592558726289, 5.224940191045253, 5.264978632435274, 5.304714883949938, 5.344155686354956, 5.383307533477909, 5.422176684690385, 5.46076917659042, 5.499090833947008, 5.537147279962851, 5.574943945906542, 5.612486080160912, 5.649778756730215, 5.686826883245173, 5.723635208501675, 5.760208329565868, 5.796550698475777, 5.832666628567075, 5.868560300448485, 5.904235767650205, 5.939696961967, 5.974947698515863, 6.009991680526689, 6.044832503882966, 6.079473661428266, 6.113918547053109, 6.148170459575759, 6.182232606429493, 6.216108107168022, 6.249799996799899, 6.283311228962004, 6.316644678941503, 6.349803146555018, 6.38278935889318, 6.4156059729381765, 6.448255578061405, 6.480740698407861, 6.5130637951735135], [0.0, 0.6557438524302001, 0.9273618495495702, 1.1357816691600549, 1.3114877048604001, 1.466287829861518, 1.606237840420901, 1.7349351572897471, 1.8547236990991405, 1.9672315572906, 2.073644135332772, 2.1748563170931545, 2.2715633383201097, 2.364318083507378, 2.453568829277059, 2.5396850198400585, 2.6229754097208002, 2.7037011669191546, 2.782085548648711, 2.8583211855912904, 2.932575659723036, 3.004995840263344, 3.0757112998459397, 3.1448370387032774, 3.212475680841802, 3.278719262151, 3.3436506994600976, 3.407345007480164, 3.4698703145794942, 3.531288716601915, 3.5916569992135936, 3.6510272527057364, 3.709447398198281, 3.7669616403674726, 3.823610858861032, 3.879432948254164, 3.9344631145812, 3.988734135035826, 4.042276586281547, 4.095119045888654, 4.147288270665544, 4.198809355043403, 4.249705872175156, 4.299999999999999, 4.349712634186309, 4.398863489584553, 4.447471191587417, 4.495553358597804, 4.543126676640219, 4.5902069670114, 4.636809247747852, 4.682947789587239, 4.728636167014756, 4.773887304912004, 4.818713521262703, 4.863126566315131, 4.907137658554118, 4.950757517794625, 4.993996395673509, 5.03686410378521, 5.079370039680117, 5.121523210920751, 5.163332257370234, 5.204805471869242, 5.2459508194416005, 5.28677595515452, 5.3272882407468805, 5.367494760127856, 5.407402333838309, 5.447017532558529, 5.486346689738081, 5.525395913416522, 5.564171097297422, 5.602677931132575, 5.6409219104681805, 5.678908345800274, 5.716642371182581, 5.754128952326321, 5.791372894228104, 5.8283788483591215, 5.865151319446072, 5.9016946718718, 5.938013135721409, 5.974110812497538, 6.009991680526688, 6.0456596000767355, 6.081118318204308, 6.1163714733492105, 6.151422599691879, 6.186275131288617, 6.220932405998315, 6.255397669213365, 6.289674077406555, 6.323764701504951, 6.357672530100933, 6.3914004725099165, 6.424951361683604, 6.458327956987009, 6.491532946846992, 6.524568951279464, 6.557438524302, 6.590144156238162], [0.0, 0.66332495807108, 0.938083151964686, 1.148912529307606, 1.32664991614216, 1.4832396974191329, 1.6248076809271923, 1.7549928774784245, 1.876166303929372, 1.98997487421324, 2.0976176963403033, 2.2, 2.297825058615212, 2.3916521486202797, 2.4819347291981715, 2.569046515733026, 2.65329983228432, 2.734958866235469, 2.814249455894058, 2.8913664589601926, 2.9664793948382657, 3.039736830714133, 3.1112698372208096, 3.1811947441173736, 3.2496153618543846, 3.3166247903554003, 3.382306905057553, 3.4467375879228177, 3.509985754956849, 3.5721142198983507, 3.63318042491699, 3.693237062523878, 3.752332607858744, 3.8105117766515306, 3.8678159211627436, 3.924283374069717, 3.97994974842648, 4.034848200366404, 4.0890096600521755, 4.1424630354415966, 4.1952353926806065, 4.247352116319061, 4.298837052040936, 4.349712634186309, 4.4, 4.449719092257398, 4.498888751680798, 4.54752680036083, 4.595650117230424, 4.64327470649756, 4.69041575982343, 4.737087712930806, 4.7833042972405595, 4.829078587059855, 4.874423042781577, 4.919349550499538, 4.963869458396343, 5.007993610219566, 5.051732376126036, 5.095095681142799, 5.138093031466052, 5.180733538795447, 5.223025942880239, 5.264978632435274, 5.30659966456864, 5.347896782848375, 5.388877434122993, 5.429548784199292, 5.469917732470938, 5.509990925582365, 5.549774770204644, 5.589275444992849, 5.628498911788116, 5.667450926121902, 5.706137047074843, 5.7445626465380295, 5.782732917920385, 5.8206528843421, 5.858327406350725, 5.895761189193471, 5.9329587896765315, 5.969924622639721, 6.006662967072484, 6.043177971895251, 6.079473661428266, 6.115553940568263, 6.15142259969188, 6.187083319303208, 6.222539674441619, 6.2577951388648065, 6.29285308902091, 6.327716807822551, 6.362389488234747, 6.3968742366877915, 6.431174076325411, 6.465291950097845, 6.499230723708769, 6.532993188424431, 6.566582063752802, 6.600000000000001, 6.6332495807108005, 6.666333324999584], [0.0, 0.6708203932499369, 0.9486832980505137, 1.161895003862225, 1.3416407864998738, 1.5, 1.6431676725154982, 1.7748239349298847, 1.8973665961010273, 2.0124611797498106, 2.1213203435596424, 2.224859546128699, 2.32379000772445, 2.4186773244895647, 2.5099800796022262, 2.5980762113533156, 2.6832815729997477, 2.765863337187866, 2.846049894151541, 2.924038303442689, 3.0, 3.0740852297878796, 3.1464265445104544, 3.2171415884290826, 3.2863353450309964, 3.3541019662496843, 3.420526275297414, 3.4856850115866753, 3.5496478698597693, 3.6124783736376886, 3.674234614174767, 3.7349698793966195, 3.7947331922020546, 3.853569773599539, 3.911521443121589, 3.9686269665968856, 4.024922359499621, 4.080441152620633, 4.135214625627066, 4.189272013130682, 4.242640687119285, 4.295346318982906, 4.347413023856832, 4.398863489584553, 4.449719092257398, 4.499999999999999, 4.54972526643093, 4.598912915026768, 4.6475800154489, 4.695742752749558, 4.743416490252569, 4.790615826801393, 4.8373546489791295, 4.883646178829912, 4.9295030175464944, 4.9749371855331, 5.0199601592044525, 5.064582904840239, 5.10881590977792, 5.1526692111953, 5.196152422706631, 5.239274758971893, 5.282045058497702, 5.324471804789654, 5.366563145999495, 5.4083269131959835, 5.449770637375485, 5.490901565316937, 5.531726674375732, 5.572252686302012, 5.612486080160912, 5.652433104425031, 5.692099788303082, 5.731491952362839, 5.770615218501403, 5.809475019311125, 5.848076606885378, 5.886425061104575, 5.92452529743945, 5.962382074305537, 6.0, 6.037383539249432, 6.074537019394977, 6.111464636239008, 6.148170459575759, 6.18465843842649, 6.220932405998316, 6.256996084384263, 6.292853089020909, 6.328506932918695, 6.363961030678928, 6.399218702310462, 6.434283176858165, 6.469157595854347, 6.5038450166036395, 6.53834841531101, 6.572670690061993, 6.606814663663572, 6.640783086353596, 6.674578638386096, 6.7082039324993685, 6.74166151627327], [0.0, 0.6782329983125268, 0.9591663046625439, 1.1747340124470733, 1.3564659966250536, 1.5165750888103102, 1.661324772583615, 1.7944358444926363, 1.9183326093250879, 2.0346989949375804, 2.1447610589527217, 2.249444375840399, 2.3494680248941466, 2.445403852127497, 2.5377155080899043, 2.626785107312739, 2.7129319932501073, 2.7964262908219126, 2.877498913987632, 2.956349099818897, 3.0331501776206204, 3.108054053584011, 3.1811947441173736, 3.252691193458119, 3.32264954516723, 3.3911649915626345, 3.458323293158117, 3.5242020373412197, 3.5888716889852725, 3.6523964735499352, 3.714835124201342, 3.7762415176998414, 3.8366652186501757, 3.896151947755632, 3.954743986657038, 4.012480529547776, 4.069397989875161, 4.125530268947254, 4.180908992073375, 4.235563716909475, 4.2895221179054435, 4.342810150121693, 4.3954521951671826, 4.447471191587417, 4.498888751680798, 4.54972526643093, 4.6000000000000005, 4.649731175025068, 4.698936049788293, 4.747630988187688, 4.79583152331272, 4.843552415324934, 4.890807704254994, 4.937610758251404, 4.983974317750845, 5.029910535983717, 5.075431016179809, 5.120546845796843, 5.165268628057984, 5.209606511052442, 5.253570214625478, 5.297169055259611, 5.340411969127476, 5.383307533477908, 5.4258639865002145, 5.468089245796926, 5.509990925582365, 5.551576352712804, 5.592852581643825, 5.63382640840131, 5.674504383644443, 5.71489282489182, 5.754997827975264, 5.794825277780168, 5.834380858325929, 5.873670062235366, 5.912698199637794, 5.951470406546605, 5.989991652748776, 6.028266749240615, 6.066300355241241, 6.104096984812742, 6.1416610131136355, 6.178996682310163, 6.216108107168022, 6.252999280345393, 6.289674077406556, 6.326136261573884, 6.362389488234747, 6.398437309218556, 6.434283176858165, 6.469930447848725, 6.505382386916238, 6.540642170307134, 6.57571288910944, 6.6105975524153635, 6.64529909033446, 6.679820356865895, 6.714164132637808, 6.748333127521196, 6.782329983125269, 6.81615727518079], [0.0, 0.6855654600401044, 0.9695359714832658, 1.187434208703792, 1.3711309200802089, 1.5329709716755893, 1.6792855623746665, 1.8138357147217055, 1.9390719429665315, 2.056696380120313, 2.16794833886788, 2.273763400180415, 2.374868417407584, 2.471841418861655, 2.565151067676132, 2.6551836094703507, 2.7422618401604177, 2.826658805020514, 2.9086079144497976, 2.9883105594967874, 3.0659419433511785, 3.1416556144810017, 3.2155870381627056, 3.2878564445547194, 3.358571124749333, 3.4278273002005224, 3.4957116585897072, 3.5623026261113755, 3.627671429443411, 3.691882988394947, 3.7549966711037173, 3.817066936798463, 3.878143885933063, 3.9382737335030438, 3.997499218261337, 4.05585995813465, 4.113392760240626, 4.170131892398609, 4.226109321823088, 4.281354925721529, 4.33589667773576, 4.389760813529594, 4.442971978304612, 4.495553358597804, 4.54752680036083, 4.598912915026768, 4.649731175025068, 4.7, 4.749736834815168, 4.798958220280731, 4.847679857416329, 4.89591666595746, 4.94368283772331, 4.990991885387113, 5.037856687124, 5.084289527554465, 5.130302135352264, 5.175905717843014, 5.221110992882646, 5.265928218272634, 5.310367218940701, 5.354437412091022, 5.3981478305063115, 5.441507144165117, 5.4845236803208355, 5.527205442174191, 5.569560126257728, 5.61159513863928, 5.653317610041028, 5.69473440996154, 5.735852159879995, 5.776677245614472, 5.817215828899595, 5.857473858242988, 5.897457079114692, 5.937171043518958, 5.976621118993575, 6.015812497078014, 6.054750201288242, 6.09343909463285, 6.131883886702357, 6.17008914036094, 6.208059278067503, 6.245798587850876, 6.2833112289620034, 6.320601237224193, 6.357672530100934, 6.394528911499267, 6.431174076325411, 6.4676116148080505, 6.5038450166036395, 6.539877674696982, 6.575712889109439, 6.611353870426239, 6.646803743153547, 6.682065548915245, 6.717142249498666, 6.7520367297579185, 6.786751800382861, 6.821290200541244, 6.855654600401045, 6.889847603539574], [0.0, 0.692820323027551, 0.9797958971132713, 1.2000000000000004, 1.385640646055102, 1.549193338482967, 1.6970562748477143, 1.8330302779823362, 1.9595917942265426, 2.078460969082653, 2.1908902300206647, 2.297825058615212, 2.400000000000001, 2.4979991993593598, 2.5922962793631443, 2.6832815729997477, 2.771281292110204, 2.8565713714171403, 2.9393876913398143, 3.0199337741083006, 3.098386676965934, 3.174901573277509, 3.2496153618543846, 3.3226495451672307, 3.3941125496954285, 3.4641016151377553, 3.5327043465311396, 3.6000000000000005, 3.6660605559646724, 3.7309516212355267, 3.7947331922020555, 3.8574603043971827, 3.9191835884530852, 3.9799497484264807, 4.039801975344832, 4.09878030638384, 4.156921938165306, 4.214261501141096, 4.270831300812525, 4.326661530556788, 4.3817804600413295, 4.436214602563767, 4.489988864128731, 4.543126676640219, 4.595650117230424, 4.6475800154489, 4.698936049788293, 4.749736834815168, 4.800000000000002, 4.849742261192857, 4.898979485566357, 4.947726750741194, 4.9959983987187195, 5.043808085167398, 5.091168824543143, 5.1380930314660525, 5.184592558726289, 5.230678732248809, 5.276362383309169, 5.321653878260029, 5.366563145999495, 5.411099703387474, 5.455272678794342, 5.499090833947009, 5.542562584220408, 5.585696017507577, 5.628498911788117, 5.670978751503131, 5.713142742834281, 5.754997827975265, 5.796550698475777, 5.83780780773057, 5.8787753826796285, 5.9194594347794975, 5.959865770300536, 6.000000000000001, 6.039867548216601, 6.079473661428266, 6.1188234163113435, 6.157921727336262, 6.196773353931868, 6.235382907247959, 6.27375485654325, 6.311893535223801, 6.349803146555018, 6.387487769068526, 6.424951361683605, 6.462197768561406, 6.499230723708769, 6.536053855347277, 6.572670690061994, 6.609084656743323, 6.645299090334461, 6.681317235396028, 6.717142249498667, 6.752777206453653, 6.788225099390857, 6.823488843692794, 6.8585712797928995, 6.893475175845635, 6.9282032302755105, 6.962758074211686], [0.0, 0.7000000000000001, 0.9899494936611665, 1.2124355652982142, 1.4000000000000001, 1.565247584249853, 1.7146428199482247, 1.8520259177452134, 1.979898987322333, 2.1, 2.2135943621178655, 2.32163735324878, 2.4248711305964283, 2.5238858928247927, 2.619160170741759, 2.7110883423451915, 2.8000000000000003, 2.8861739379323623, 2.9698484809834995, 3.051229260478472, 3.130495168499706, 3.2078029864690882, 3.283291031876401, 3.357082066318904, 3.4292856398964493, 3.5, 3.5693136595149495, 3.6373066958946425, 3.704051835490427, 3.769615364994153, 3.8340579025361627, 3.8974350539810154, 3.959797974644666, 4.02119385257662, 4.08166632639171, 4.141255848169731, 4.2, 4.257933771208754, 4.315089802078284, 4.371498598878879, 4.427188724235731, 4.4821869662029945, 4.536518488885503, 4.5902069670114, 4.64327470649756, 4.695742752749558, 4.747630988187688, 4.798958220280731, 4.849742261192857, 4.9, 4.949747468305833, 4.998999899979996, 5.047771785649585, 5.096076922496363, 5.143928459844674, 5.191338940966964, 5.238320341483518, 5.2848841046895245, 5.331041174104736, 5.376802023508025, 5.422176684690383, 5.467174773134658, 5.511805511808268, 5.55607775323564, 5.6000000000000005, 5.643580423808984, 5.686826883245172, 5.729746940310715, 5.772347875864725, 5.814636704042653, 5.856620185738529, 5.898304841223451, 5.939696961966999, 5.980802621722272, 6.021627686929839, 6.06217782649107, 6.102458520956944, 6.142475071174486, 6.182232606429493, 6.221736092120913, 6.260990336999412, 6.300000000000001, 6.338769596696192, 6.377303505401009, 6.4156059729381765, 6.4536811201050215, 6.491532946846993, 6.529165337162171, 6.566582063752802, 6.603786792439623, 6.640783086353597, 6.67757440991862, 6.714164132637808, 6.750555532695069, 6.786751800382861, 6.822756041366274, 6.858571279792899, 6.894200461257274, 6.929646455628165, 6.96491205974634, 7.0, 7.034912934784624], [0.0, 0.7071067811865476, 1.0, 1.2247448713915892, 1.4142135623730951, 1.5811388300841898, 1.7320508075688774, 1.8708286933869709, 2.0, 2.1213203435596424, 2.23606797749979, 2.345207879911715, 2.4494897427831783, 2.5495097567963927, 2.6457513110645907, 2.7386127875258306, 2.8284271247461903, 2.9154759474226504, 3.0, 3.082207001484489, 3.1622776601683795, 3.2403703492039306, 3.3166247903554003, 3.3911649915626345, 3.464101615137755, 3.535533905932738, 3.6055512754639896, 3.6742346141747677, 3.7416573867739418, 3.8078865529319548, 3.872983346207417, 3.9370039370059056, 4.0, 4.06201920231798, 4.123105625617661, 4.183300132670378, 4.242640687119285, 4.301162633521314, 4.358898943540674, 4.415880433163924, 4.47213595499958, 4.527692569068709, 4.582575694955841, 4.636809247747852, 4.69041575982343, 4.743416490252569, 4.79583152331272, 4.847679857416329, 4.898979485566357, 4.949747468305833, 5.000000000000001, 5.04975246918104, 5.099019513592785, 5.147815070493501, 5.196152422706632, 5.244044240850759, 5.291502622129181, 5.338539126015656, 5.385164807134505, 5.431390245600108, 5.477225575051661, 5.522680508593631, 5.5677643628300215, 5.612486080160912, 5.656854249492381, 5.70087712549569, 5.744562646538029, 5.787918451395113, 5.830951894845301, 5.873670062235366, 5.916079783099617, 5.958187643906493, 6.0, 6.041522986797286, 6.082762530298219, 6.123724356957946, 6.164414002968978, 6.2048368229954285, 6.244997998398399, 6.284902544988268, 6.324555320336759, 6.3639610306789285, 6.403124237432849, 6.442049363362563, 6.480740698407861, 6.519202405202649, 6.557438524302001, 6.59545297913646, 6.6332495807108005, 6.670832032063167, 6.708203932499369, 6.745368781616021, 6.782329983125269, 6.8190908484929285, 6.855654600401045, 6.892024376045111, 6.92820323027551, 6.9641941385920605, 7.0, 7.035623639735145, 7.071067811865476, 7.1063352017759485], [0.0, 0.7141428428542851, 1.0099504938362078, 1.2369316876852985, 1.4282856857085702, 1.5968719422671316, 1.7492855684535904, 1.8894443627691186, 2.0199009876724157, 2.142428528562855, 2.2583179581272432, 2.368543856465403, 2.473863375370597, 2.574878637916747, 2.672077843177478, 2.765863337187866, 2.8565713714171403, 2.944486372867092, 3.029851481508624, 3.1128764832546767, 3.193743884534263, 3.272613634390715, 3.3496268448888458, 3.4249087579087423, 3.498571136907181, 3.5707142142714257, 3.6414282912066254, 3.7107950630558952, 3.7788887255382373, 3.845776904605883, 3.9115214431215892, 3.9761790704142093, 4.039801975344831, 4.102438299353204, 4.164132562731403, 4.224926034855522, 4.28485705712571, 4.343961325794695, 4.402272140611029, 4.459820624195553, 4.5166359162544865, 4.572745346069471, 4.628174586162455, 4.682947789587239, 4.737087712930806, 4.790615826801393, 4.843552415324934, 4.89591666595746, 4.947726750741194, 4.998999899979996, 5.04975246918104, 5.100000000000001, 5.149757275833494, 5.199038372622384, 5.247856705360771, 5.296225070746145, 5.344155686354956, 5.391660226683429, 5.43874985635486, 5.485435260760991, 5.531726674375732, 5.577633906953737, 5.62316636780382, 5.668333088307356, 5.713142742834281, 5.757603668193913, 5.801723881744115, 5.845511098270194, 5.888972745734184, 5.932115979985557, 5.974947698515863, 6.017474553332154, 6.059702963017248, 6.101639124038721, 6.143289021363068, 6.184658438426491, 6.225752966509353, 6.266578013557321, 6.307138812488593, 6.347440429023341, 6.387487769068526, 6.427285585688566, 6.466838485689898, 6.506150935845249, 6.54522726878143, 6.584071688552609, 6.62268827591938, 6.661080993352356, 6.6992536897776915, 6.73721010508059, 6.77495387438173, 6.81248853210044, 6.8498175158174845, 6.886944169949399, 6.923871749245506, 6.960603422117942, 6.997142273814362, 7.033491309442276, 7.069653456853455, 7.105631569396208, 7.141428428542851, 7.177046746399247], [0.0, 0.7211102550927979, 1.019803902718557, 1.2489995996796799, 1.4422205101855958, 1.61245154965971, 1.7663521732655696, 1.9078784028338915, 2.039607805437114, 2.1633307652783937, 2.280350850198276, 2.3916521486202797, 2.4979991993593598, 2.6000000000000005, 2.6981475126464085, 2.792848008753788, 2.8844410203711917, 2.973213749463701, 3.0594117081556713, 3.1432467291003428, 3.22490309931942, 3.3045423283716615, 3.3823069050575527, 3.458323293158117, 3.532704346531139, 3.6055512754639896, 3.6769552621700474, 3.7469987990390394, 3.815756805667783, 3.88329756778952, 3.9496835316262997, 4.014971979976947, 4.079215610874228, 4.1424630354415966, 4.204759208325728, 4.266145801540309, 4.3266615305567875, 4.386342439892262, 4.445222154178574, 4.503332099679081, 4.560701700396552, 4.617358552246079, 4.67332857821917, 4.728636167014756, 4.7833042972405595, 4.8373546489791295, 4.890807704254994, 4.94368283772331, 4.9959983987187195, 5.047771785649585, 5.099019513592785, 5.149757275833494, 5.200000000000001, 5.249761899362676, 5.299056519796709, 5.347896782848376, 5.396295025292817, 5.44426303552648, 5.491812087098393, 5.5389529696504916, 5.585696017507576, 5.63205113613149, 5.678027826631356, 5.723635208501674, 5.768882040742383, 5.813776741499453, 5.858327406350725, 5.902541825349482, 5.946427498927402, 5.989991652748776, 6.033241251599343, 6.076183012385325, 6.118823416311343, 6.161168720299745, 6.203224967708329, 6.244997998398398, 6.2864934582006855, 6.327716807822551, 6.3686733312362644, 6.409368143584826, 6.44980619863884, 6.489992295835181, 6.529931086925804, 6.569627082262737, 6.609084656743323, 6.648308055437865, 6.687301398920196, 6.726068688320096, 6.764613810115105, 6.802940540677979, 6.841052550594828, 6.878953408767936, 6.916646586316234, 6.954135460285485, 6.9914233171794145, 7.0285133563222315, 7.065408693062278, 7.102112361825883, 7.138627319029899, 7.17495644586084, 7.211102550927979, 7.247068372797377], [0.0, 0.7280109889280519, 1.0295630140987002, 1.2609520212918495, 1.4560219778561039, 1.627882059609971, 1.7832554500127011, 1.9261360284258224, 2.0591260281974004, 2.1840329667841556, 2.302172886644268, 2.4145392935299275, 2.521904042583699, 2.624880949681338, 2.7239676943752476, 2.819574435974337, 2.9120439557122078, 3.001666203960727, 3.0886890422961004, 3.1733263305244868, 3.255764119219942, 3.336165463522456, 3.414674215792775, 3.491418050019219, 3.5665109000254023, 3.64005494464026, 3.712142238654118, 3.782856063875548, 3.852272056851645, 3.9204591567825324, 3.9874804074753776, 4.053393639902249, 4.118252056394801, 4.182104733265298, 4.244997055358225, 4.306971093471606, 4.368065933568311, 4.428317965096906, 4.487761134463376, 4.546427168667723, 4.604345773288536, 4.661544808322667, 4.718050444834181, 4.773887304912004, 4.829078587059855, 4.883646178829912, 4.937610758251404, 4.990991885387113, 5.043808085167398, 5.096076922496363, 5.147815070493501, 5.199038372622384, 5.249761899362676, 5.300000000000001, 5.349766350038103, 5.399073994677236, 5.447935388750495, 5.496362433464519, 5.5443665102516455, 5.591958512006326, 5.639148871948674, 5.6859475903318, 5.732364259186606, 5.7784080852774675, 5.8240879114244155, 5.869412236331676, 5.914389233048499, 5.959026766175833, 6.003332407921454, 6.047313453096343, 6.090976933136425, 6.134329629226001, 6.177378084592201, 6.220128616033596, 6.262587324740471, 6.304760106459247, 6.3466526610489735, 6.388270501473776, 6.429618962271405, 6.470703207534712, 6.511528238439884, 6.552098900352467, 6.592419889539805, 6.632495759516172, 6.672330927044912, 6.711929677819935, 6.751296171847301, 6.790434448545985, 6.82934843158555, 6.868041933477111, 6.906518659932804, 6.944782214007867, 6.982836100038438, 7.020683727387242, 7.058328414008519, 7.095773389842717, 7.1330218000508046, 7.170076708097342, 7.206941098690901, 7.243617880589783, 7.28010988928052, 7.31641988953614], [0.0, 0.7348469228349535, 1.0392304845413265, 1.2727922061357857, 1.469693845669907, 1.6431676725154984, 1.8, 1.9442222095223582, 2.078460969082653, 2.2045407685048604, 2.32379000772445, 2.4372115213907883, 2.5455844122715714, 2.6495282598983545, 2.749545416973504, 2.846049894151541, 2.939387691339814, 3.0298514815086235, 3.1176914536239795, 3.203123475609394, 3.286335345030997, 3.3674916480965478, 3.4467375879228173, 3.5242020373412197, 3.6, 3.6742346141747677, 3.7469987990390394, 3.818376618407357, 3.8884444190447165, 3.957271787481876, 4.024922359499621, 4.091454509095757, 4.156921938165306, 4.221374183841087, 4.28485705712571, 4.347413023856832, 4.409081537009721, 4.469899327725402, 4.529900661162451, 4.589117562233507, 4.6475800154489, 4.705316142407437, 4.762352359916264, 4.818713521262703, 4.874423042781577, 4.9295030175464944, 4.983974317750845, 5.037856687124, 5.091168824543143, 5.143928459844674, 5.196152422706632, 5.247856705360771, 5.299056519796709, 5.349766350038103, 5.4, 5.449770637375486, 5.499090833947008, 5.547972602672079, 5.596427431853289, 5.644466316668034, 5.692099788303082, 5.739337940912697, 5.786190456595773, 5.8326666285670745, 5.878775382679628, 5.924525297439449, 5.96992462263972, 6.014981296729027, 6.059702963017247, 6.104096984812742, 6.148170459575759, 6.191930232165088, 6.235382907247959, 6.278534860936905, 6.321392251711643, 6.363961030678928, 6.406246951218788, 6.448255578061404, 6.489992295835182, 6.5314623171231725, 6.572670690061994, 6.613622305514581, 6.654321903845651, 6.694774081326419, 6.7349832961930955, 6.77495387438173, 6.814690014960329, 6.854195795277518, 6.8934751758456345, 6.932532004974806, 6.971370023173351, 7.009992867328754, 7.0484040746824395, 7.0866070866106305, 7.124605252222751, 7.162401831787993, 7.2, 7.237402849088892, 7.274613391789285, 7.3116345641723655, 7.348469228349535, 7.385120175054704], [0.0, 0.7416198487095663, 1.0488088481701516, 1.2845232578665131, 1.4832396974191326, 1.6583123951777001, 1.8165902124584952, 1.9621416870348585, 2.0976176963403033, 2.224859546128699, 2.345207879911715, 2.459674775249769, 2.5690465157330262, 2.673948391424188, 2.7748873851023217, 2.8722813232690143, 2.9664793948382653, 3.0577769702841313, 3.146426544510455, 3.232645975048923, 3.3166247903554003, 3.398529093593286, 3.4785054261852175, 3.5566838487557484, 3.6331804249169903, 3.708099243547832, 3.7815340802378077, 3.853569773599539, 3.924283374069717, 3.993745109543172, 4.06201920231798, 4.129164564412516, 4.1952353926806065, 4.260281680828159, 4.324349662087931, 4.387482193696061, 4.449719092257398, 4.511097427455985, 4.571651780264984, 4.631414470763765, 4.69041575982343, 4.748684028233507, 4.806245936279167, 4.863126566315131, 4.919349550499538, 4.9749371855331, 5.029910535983717, 5.084289527554465, 5.1380930314660525, 5.191338940966964, 5.244044240850759, 5.296225070746145, 5.347896782848376, 5.399073994677236, 5.449770637375486, 5.5, 5.549774770204643, 5.599107071667768, 5.648008498577176, 5.6964901474504455, 5.744562646538029, 5.792236183029832, 5.839520528262573, 5.886425061104576, 5.932958789676531, 5.979130371550699, 6.024948132556827, 6.070420084310475, 6.115553940568263, 6.1603571325045765, 6.2048368229954285, 6.248999919987198, 6.29285308902091, 6.336402764976356, 6.3796551630946325, 6.422616289332565, 6.465291950097846, 6.507687761409578, 6.549809157525127, 6.591661399070799, 6.6332495807108005, 6.674578638386097, 6.715653356152327, 6.756478372643548, 6.797058187186572, 6.837397165588672, 6.87749954561976, 6.917369442208505, 6.957010852370435, 6.996427659884722, 7.035623639735144, 7.074602462329597, 7.113367697511497, 7.15192281837549, 7.1902712048990205, 7.2284161474004796, 7.266360849833981, 7.30410843293006, 7.341661937191061, 7.379024325749307, 7.416198487095664, 7.4531872376856345], [0.0, 0.7483314773547883, 1.058300524425836, 1.2961481396815722, 1.4966629547095767, 1.6733200530681511, 1.833030277982336, 1.9798989873223332, 2.116601048851672, 2.244994432064365, 2.3664319132398464, 2.4819347291981715, 2.5922962793631443, 2.6981475126464085, 2.8, 2.8982753492378874, 2.9933259094191533, 3.0854497241083023, 3.1749015732775088, 3.2619012860600183, 3.3466401061363023, 3.4292856398964493, 3.509985754956849, 3.5888716889852725, 3.666060555964672, 3.7416573867739413, 3.8157568056677826, 3.8884444190447165, 3.9597979746446663, 4.029888335921977, 4.098780306383839, 4.166533331199932, 4.233202097703344, 4.298837052040936, 4.363484845854286, 4.427188724235731, 4.48998886412873, 4.551922670696417, 4.613025037868319, 4.673328578219169, 4.732863826479693, 4.791659420284376, 4.849742261192857, 4.907137658554118, 4.963869458396343, 5.0199601592044525, 5.075431016179809, 5.130302135352264, 5.184592558726289, 5.238320341483518, 5.291502622129181, 5.344155686354956, 5.396295025292817, 5.447935388750495, 5.499090833947008, 5.549774770204643, 5.6, 5.649778756730214, 5.6991227395100035, 5.748043145279965, 5.796550698475775, 5.844655678480983, 5.892367945062493, 5.939696961966999, 5.986651818838307, 6.033241251599342, 6.079473661428265, 6.125357132445422, 6.170899448216605, 6.216108107168021, 6.260990336999411, 6.305553108173778, 6.3498031465550175, 6.393746945258312, 6.437390775772432, 6.48074069840786, 6.523802572120037, 6.566582063752802, 6.609084656743323, 6.6513156593263565, 6.6932802122726045, 6.734983296193095, 6.776429738438967, 6.817624219623724, 6.858571279792899, 6.899275324264136, 6.939740629158989, 6.979971346646059, 7.019971509913698, 7.059745037889116, 7.099295739719539, 7.138627319029899, 7.177743377970545, 7.216647421067487, 7.255342858886822, 7.293833011524187, 7.332121111929344, 7.370210309075312, 7.408103670980854, 7.445804187594514, 7.483314773547883, 7.520638270785267], [0.0, 0.754983443527075, 1.0677078252031311, 1.3076696830622023, 1.50996688705415, 1.6881943016134133, 1.849324200890693, 1.997498435543818, 2.1354156504062622, 2.264950330581225, 2.3874672772626644, 2.503996805109783, 2.6153393661244047, 2.72213151776324, 2.824889378365107, 2.924038303442689, 3.0199337741083, 3.1128764832546763, 3.2031234756093934, 3.290896534380867, 3.3763886032268267, 3.459768778401239, 3.5411862419251547, 3.620773398046335, 3.698648401781386, 3.774917217635375, 3.849675310984032, 3.9230090491866063, 3.994996871087636, 4.065710270051224, 4.135214625627066, 4.20356991139674, 4.2708313008125245, 4.337049688440288, 4.402272140611028, 4.466542286825459, 4.52990066116245, 4.592385001282014, 4.654030511288038, 4.7148700936505135, 4.774934554525329, 4.8342527861087286, 4.892851929090027, 4.950757517794625, 5.007993610219566, 5.064582904840239, 5.120546845796843, 5.175905717843014, 5.230678732248809, 5.2848841046895245, 5.338539126015656, 5.391660226683429, 5.44426303552648, 5.496362433464519, 5.547972602672079, 5.599107071667768, 5.649778756730214, 5.7, 5.749782604586021, 5.799137866959191, 5.848076606885378, 5.8966091951222275, 5.944745579080739, 5.9924953066314535, 6.0398675482166, 6.08687111741328, 6.133514490078261, 6.17980582219215, 6.2257529665093525, 6.271363488110062, 6.316644678941503, 6.361603571427569, 6.406246951218787, 6.450581369148055, 6.494613152451807, 6.5383484153110105, 6.581793068761734, 6.624952830020755, 6.667833231267862, 6.710439627923047, 6.752777206453653, 6.794850991743675, 6.836665854054885, 6.878226515607057, 6.919537556802478, 6.960603422117942, 7.001428425685718, 7.042016756583302, 7.0823724838503095, 7.122499561249548, 7.162401831787993, 7.202083032012336, 7.24154679609267, 7.280796659706959, 7.31983606373804, 7.358668357794092, 7.397296803562772, 7.4357245780085215, 7.473954776421918, 7.5119904153293495, 7.54983443527075, 7.587489703452652], [0.0, 0.7615773105863909, 1.0770329614269007, 1.3190905958272923, 1.5231546211727818, 1.7029386365926404, 1.8654758106177631, 2.0149441679609885, 2.1540659228538015, 2.2847319317591723, 2.4083189157584592, 2.525866188063018, 2.6381811916545845, 2.7459060435491964, 2.8495613697550017, 2.9495762407505253, 3.0463092423455636, 3.1400636936215167, 3.2310988842807027, 3.319638534539567, 3.405877273185281, 3.48998567332303, 3.5721142198983507, 3.6523964735499352, 3.7309516212355263, 3.8078865529319548, 3.8832975677895205, 3.957271787481876, 4.029888335921977, 4.101219330881976, 4.171330722922842, 4.240283009422838, 4.308131845707603, 4.374928570845472, 4.440720662234904, 4.505552130427525, 4.569463863518345, 4.632493928760188, 4.694677837722201, 4.756048780237647, 4.8166378315169185, 4.876474136094644, 4.935585071701227, 4.993996395673509, 5.051732376126036, 5.10881590977792, 5.165268628057984, 5.221110992882646, 5.276362383309169, 5.331041174104736, 5.385164807134505, 5.43874985635486, 5.491812087098393, 5.5443665102516455, 5.596427431853289, 5.648008498577176, 5.6991227395100035, 5.749782604586021, 5.800000000000001, 5.849786320883866, 5.8991524815010505, 5.948108943185221, 5.99666574022598, 6.044832503882966, 6.092618484691127, 6.1400325732035, 6.187083319303208, 6.23377895020348, 6.280127387243033, 6.326136261573885, 6.3718129288295975, 6.417164482853779, 6.462197768561405, 6.5069193939989765, 6.55133574166368, 6.59545297913646, 6.639277069079134, 6.682813778641449, 6.726068688320096, 6.76904720030818, 6.811754546370562, 6.854195795277518, 6.8963758598266685, 6.938299503480662, 6.97997134664606, 7.021395872616784, 7.062577433203831, 7.103520254071217, 7.144228439796701, 7.184705978674423, 7.224956747275378, 7.264984514780469, 7.3047929470998705, 7.3443856107914165, 7.383765976789894, 7.4229374239582535, 7.4619032424710525, 7.5006666370396715, 7.539230729988306, 7.577598564189055, 7.6157731058639095, 7.653757247260983], [0.0, 0.7681145747868608, 1.0862780491200215, 1.3304134695650072, 1.5362291495737217, 1.7175564037317668, 1.8814887722226779, 2.0322401432901573, 2.172556098240043, 2.3043437243605824, 2.4289915602982237, 2.5475478405713994, 2.6608269391300143, 2.7694764848252458, 2.8740215726399825, 2.974894956128703, 3.0724582991474434, 3.167017524422623, 3.2588341473600644, 3.3481338085566414, 3.4351128074635335, 3.5199431813596083, 3.602776706930364, 3.6837480912787726, 3.7629775444453557, 3.840572873934304, 3.916631205513228, 3.9912404086950213, 4.064480286580315, 4.136423575989287, 4.207136793592525, 4.276680956068619, 4.345112196480086, 4.412482294582042, 4.4788391353117385, 4.544227107000705, 4.608687448721165, 4.672258554489466, 4.734976240700686, 4.796873982084583, 4.857983120596447, 4.9183330509431755, 4.9779513858614575, 5.03686410378521, 5.095095681142799, 5.1526692111953, 5.209606511052442, 5.265928218272634, 5.321653878260029, 5.376802023508025, 5.431390245600108, 5.485435260760991, 5.5389529696504916, 5.591958512006326, 5.644466316668034, 5.6964901474504455, 5.748043145279965, 5.799137866959191, 5.849786320883866, 5.8999999999999995, 5.949789912257406, 5.999166608788257, 6.048140210014975, 6.096720429870472, 6.144916598294887, 6.192737682156413, 6.240192304729077, 6.287288763847259, 6.334035048845246, 6.380438856379708, 6.4265076052238514, 6.472248450113762, 6.517668294720129, 6.562773803811921, 6.607571414672716, 6.652067347825035, 6.696267617113283, 6.740178039191546, 6.783804242458652, 6.827151675479314, 6.870225614927067, 6.913031173081747, 6.955573304911681, 6.997856814768361, 7.0398863627192165, 7.0816664705420855, 7.123201527403251, 7.164495795239188, 7.205553413860728, 7.246378405796926, 7.286974680894671, 7.327346040688948, 7.367496182557545, 7.407428703673091, 7.447147104764348, 7.486654793697916, 7.525955088890711, 7.565051222562872, 7.603946343840151, 7.642643521714199, 7.681145747868608, 7.719455939378112], [0.0, 0.7745966692414833, 1.0954451150103321, 1.3416407864998738, 1.5491933384829666, 1.7320508075688772, 1.8973665961010275, 2.0493901531919194, 2.1908902300206643, 2.3237900077244498, 2.449489742783178, 2.569046515733026, 2.6832815729997477, 2.792848008753788, 2.8982753492378874, 2.9999999999999996, 3.098386676965933, 3.1937438845342623, 3.2863353450309964, 3.3763886032268267, 3.4641016151377544, 3.5496478698597693, 3.63318042491699, 3.714835124201342, 3.794733192202055, 3.8729833462074166, 3.9496835316262997, 4.024922359499621, 4.098780306383839, 4.171330722922842, 4.242640687119285, 4.3127717305695645, 4.381780460041329, 4.449719092257398, 4.516635916254486, 4.58257569495584, 4.6475800154488995, 4.711687595755898, 4.774934554525329, 4.8373546489791295, 4.898979485566356, 4.959838707054898, 5.019960159204453, 5.079370039680117, 5.138093031466052, 5.196152422706631, 5.253570214625478, 5.310367218940701, 5.366563145999495, 5.422176684690383, 5.477225575051661, 5.531726674375732, 5.585696017507576, 5.639148871948674, 5.692099788303082, 5.744562646538029, 5.796550698475775, 5.848076606885378, 5.8991524815010505, 5.949789912257406, 5.999999999999999, 6.049793384901669, 6.099180272790762, 6.148170459575758, 6.196773353931866, 6.244997998398397, 6.292853089020909, 6.340346993658943, 6.387487769068525, 6.434283176858164, 6.48074069840786, 6.526867548832287, 6.572670690061993, 6.618156843109718, 6.663332499583071, 6.7082039324993685, 6.752777206453653, 6.797058187186571, 6.841052550594828, 6.884765791223402, 6.928203230275509, 6.97137002317335, 7.014271166700073, 7.056911505750939, 7.099295739719539, 7.1414284285428495, 7.183313998427188, 7.224956747275377, 7.26636084983398, 7.307530362578043, 7.348469228349534, 7.389181280764466, 7.429670248402684, 7.469939758793239, 7.5099933422074345, 7.549834435270749, 7.58946638440411, 7.628892449104261, 7.668115805072325, 7.707139547199078, 7.745966692414833, 7.784600182411426], [0.0, 0.7810249675906654, 1.104536101718726, 1.3527749258468684, 1.5620499351813308, 1.746424919657298, 1.9131126469708992, 2.0663978319771825, 2.209072203437452, 2.3430749027719964, 2.4698178070456938, 2.5903667693977237, 2.705549851693737, 2.816025568065745, 2.9223278392404914, 3.0248966924508345, 3.1240998703626617, 3.2202484376209237, 3.3136083051561784, 3.4044089061098406, 3.492849839314596, 3.5791060336346563, 3.6633318168028404, 3.745664160065609, 3.8262252939417984, 3.9051248379533274, 3.9824615503479754, 4.058324777540605, 4.132795663954365, 4.205948168962618, 4.277849927241487, 4.34856298103178, 4.418144406874904, 4.486646854834912, 4.5541190146942805, 4.620606020859168, 4.686149805543993, 4.750789408087881, 4.814561246884289, 4.87749935930288, 4.9396356140913875, 5.000999900019996, 5.061620293937506, 5.121523210920751, 5.180733538795447, 5.239274758971893, 5.297169055259611, 5.354437412091022, 5.411099703387474, 5.467174773134658, 5.522680508593631, 5.577633906953737, 5.63205113613149, 5.6859475903318, 5.739337940912697, 5.792236183029832, 5.844655678480983, 5.8966091951222275, 5.948108943185221, 5.999166608788257, 6.049793384901669, 6.1, 6.149796744608719, 6.199193495931548, 6.248199740725323, 6.296824596572465, 6.345076831686122, 6.392964883369843, 6.440496875241847, 6.487680633323437, 6.534523701081817, 6.5810333535091585, 6.627216610312357, 6.673080248281149, 6.71863081289633, 6.7638746292343415, 6.808817812219681, 6.853466276272176, 6.897825744392215, 6.941901756723442, 6.985699678629192, 7.029224708315989, 7.07248188403477, 7.115476090888086, 7.158212067269313, 7.200694410957877, 7.242927584892728, 7.284915922644544, 7.326663633605681, 7.368174807915458, 7.409453421137082, 7.450503338701353, 7.491328320131218, 7.531932023060219, 7.572318007057021, 7.6124897372673015, 7.652450587883597, 7.692203845452876, 7.731752712031082, 7.771100308193172, 7.810249675906655, 7.849203781276163], [0.0, 0.787400787401181, 1.1135528725660042, 1.3638181696985856, 1.574801574802362, 1.760681686165901, 1.928730152198591, 2.083266665599966, 2.2271057451320084, 2.362202362203543, 2.4899799195977463, 2.6115129714401193, 2.727636339397171, 2.839013913315678, 2.9461839725312466, 3.049590136395381, 3.149603149604724, 3.246536616149585, 3.340658617698013, 3.432200460346103, 3.521363372331802, 3.608323710533743, 3.6932370625238775, 3.7762415176998414, 3.857460304397182, 3.9370039370059056, 4.014971979976946, 4.091454509095756, 4.166533331199932, 4.240283009422838, 4.3127717305695645, 4.384062043356595, 4.454211490264017, 4.523273151159457, 4.591296113299598, 4.658325879540846, 4.724404724407086, 4.789572005931219, 4.853864439804639, 4.917316341257699, 4.979959839195493, 5.041825066382213, 5.10294032886923, 5.163332257370234, 5.223025942880239, 5.282045058497702, 5.340411969127476, 5.3981478305063115, 5.455272678794342, 5.511805511808268, 5.5677643628300215, 5.62316636780382, 5.678027826631356, 5.732364259186606, 5.786190456595773, 5.839520528262573, 5.892367945062493, 5.944745579080739, 5.99666574022598, 6.048140210014975, 6.099180272790762, 6.149796744608719, 6.199999999999999, 6.249799996799897, 6.299206299209448, 6.348228099241551, 6.39687423668779, 6.445153217728807, 6.49307323229917, 6.540642170307133, 6.587867636800241, 6.6347569661593475, 6.681317235396026, 6.727555276621664, 6.773477688750439, 6.819090848492928, 6.864400920692206, 6.90941386804988, 6.954135460285484, 6.998571282769077, 7.042726744663604, 7.08660708661063, 7.130217387990355, 7.173562573784381, 7.216647421067486, 7.259476565152615, 7.302054505411474, 7.344385610791416, 7.386474125047755, 7.428324171709255, 7.469939758793239, 7.511324783285569, 7.552483035399683, 7.593418202627852, 7.634133873596926, 7.674633541739956, 7.714920608794364, 7.754998388136519, 7.79487010796203, 7.834538914320357, 7.874007874011811, 7.913279977354524], [0.0, 0.7937253933193772, 1.1224972160321824, 1.3747727084867523, 1.5874507866387544, 1.7748239349298849, 1.9442222095223582, 2.1, 2.244994432064365, 2.3811761799581315, 2.5099800796022267, 2.632489316217637, 2.7495454169735045, 2.861817604250837, 2.9698484809834995, 3.074085229787879, 3.1749015732775088, 3.2726136343907144, 3.3674916480965473, 3.4597687784012394, 3.5496478698597698, 3.6373066958946425, 3.722902093797257, 3.8065732621348563, 3.8884444190447165, 3.968626966596886, 4.047221268969613, 4.124318125460256, 4.2, 4.274342054632503, 4.347413023856832, 4.419275958796871, 4.48998886412873, 4.559605246071199, 4.628174586162454, 4.695742752749559, 4.762352359916263, 4.828043081829325, 4.892851929090027, 4.956813492557492, 5.019960159204453, 5.082322303829225, 5.143928459844674, 5.204805471869242, 5.264978632435274, 5.324471804789654, 5.383307533477908, 5.441507144165117, 5.499090833947009, 5.55607775323564, 5.612486080160912, 5.668333088307356, 5.723635208501674, 5.7784080852774675, 5.8326666285670745, 5.886425061104576, 5.939696961966999, 5.9924953066314535, 6.044832503882966, 6.096720429870472, 6.148170459575758, 6.199193495931548, 6.249799996799897, 6.3, 6.3498031465550175, 6.3992187023104625, 6.448255578061403, 6.496922348312315, 6.545227268781429, 6.593178292750774, 6.640783086353597, 6.688049042882386, 6.734983296193095, 6.7815927332743895, 6.827884006044625, 6.87386354243376, 6.919537556802479, 6.96491205974634, 7.009992867328754, 7.0547856097829085, 7.0992957397195395, 7.143528539874395, 7.187489130426565, 7.23118247591637, 7.274613391789285, 7.317786550590281, 7.3607064878311785, 7.40337760755184, 7.445804187594514, 7.487990384609211, 7.52994023880668, 7.571657678474378, 7.6131465242697125, 7.654410493303845, 7.695453203028396, 7.736278174936576, 7.776888838089433, 7.817288532477231, 7.857480512225277, 7.897467948652911, 7.937253933193772, 7.976841480185], [0.0, 0.8, 1.131370849898476, 1.385640646055102, 1.6, 1.788854381999832, 1.9595917942265426, 2.1166010488516727, 2.262741699796952, 2.4, 2.5298221281347035, 2.65329983228432, 2.771281292110204, 2.8844410203711917, 2.9933259094191533, 3.098386676965933, 3.2, 3.2984845004941286, 3.394112549695428, 3.4871191548325395, 3.577708763999664, 3.6660605559646724, 3.752332607858744, 3.836665218650176, 3.9191835884530852, 4.0, 4.079215610874228, 4.156921938165306, 4.233202097703345, 4.308131845707604, 4.381780460041329, 4.454211490264018, 4.525483399593904, 4.595650117230424, 4.664761515876241, 4.732863826479693, 4.8, 4.866210024238576, 4.931531202375181, 4.9959983987187195, 5.059644256269407, 5.122499389946279, 5.184592558726289, 5.2459508194416005, 5.30659966456864, 5.366563145999495, 5.4258639865002145, 5.4845236803208355, 5.542562584220408, 5.6000000000000005, 5.656854249492381, 5.713142742834281, 5.768882040742383, 5.8240879114244155, 5.878775382679628, 5.932958789676531, 5.986651818838307, 6.0398675482166, 6.092618484691127, 6.144916598294887, 6.196773353931866, 6.248199740725323, 6.299206299209448, 6.3498031465550175, 6.4, 6.449806198638839, 6.499230723708768, 6.5482822174979605, 6.596969000988257, 6.64529909033446, 6.6932802122726045, 6.740919818541087, 6.788225099390856, 6.835202996254025, 6.881860213634101, 6.92820323027551, 6.974238309665079, 7.019971509913698, 7.065408693062278, 7.110555533852471, 7.155417527999328, 7.2, 7.244308110509934, 7.288346863315439, 7.332121111929345, 7.37563556583431, 7.418894796396564, 7.4619032424710525, 7.504665215717488, 7.547184905645283, 7.58946638440411, 7.631513611335565, 7.673330437300352, 7.7149206087943645, 7.756287771866127, 7.797435475847171, 7.8383671769061705, 7.879086241436885, 7.919595949289333, 7.959899496852961, 8.0, 8.039900496896713], [0.0, 0.8062257748298549, 1.1401754250991378, 1.3964240043768943, 1.6124515496597098, 1.8027756377319946, 1.9748417658131499, 2.133072900770154, 2.2803508501982757, 2.4186773244895647, 2.5495097567963922, 2.6739483914241875, 2.7928480087537886, 2.9068883707497264, 3.016620625799671, 3.1224989991991987, 3.2249030993194197, 3.324154027718932, 3.420526275297414, 3.5142566781611158, 3.605551275463989, 3.6945906403822333, 3.7815340802378072, 3.866522985836241, 3.9496835316262997, 4.031128874149275, 4.110960958218893, 4.189272013130682, 4.266145801540308, 4.341658669218482, 4.415880433163923, 4.488875137492688, 4.560701700396551, 4.631414470763764, 4.701063709417263, 4.769696007084728, 4.8373546489791295, 4.904079934095691, 4.969909455915671, 5.034878350069642, 5.0990195135927845, 5.162363799656123, 5.224940191045253, 5.28677595515452, 5.347896782848375, 5.4083269131959835, 5.468089245796926, 5.527205442174191, 5.585696017507577, 5.643580423808984, 5.70087712549569, 5.757603668193913, 5.813776741499453, 5.869412236331676, 5.924525297439449, 5.979130371550699, 6.033241251599342, 6.08687111741328, 6.1400325732035, 6.192737682156413, 6.244997998398397, 6.296824596572465, 6.348228099241551, 6.3992187023104625, 6.449806198638839, 6.499999999999999, 6.549809157525125, 6.599242380758566, 6.648308055437864, 6.697014260101287, 6.745368781616021, 6.793379129711516, 6.841052550594828, 6.888396039717809, 6.93541635375988, 6.98212002188447, 7.0285133563222315, 7.074602462329597, 7.12039324756716, 7.165891430938652, 7.211102550927978, 7.256031973468694, 7.300684899377592, 7.345066371381541, 7.389181280764467, 7.433034373659253, 7.476630257007497, 7.519973404208288, 7.5630681604756145, 7.6059187479225665, 7.648529270389177, 7.6909037180295, 7.733045971672482, 7.774959806970066, 7.816648898345122, 7.858116822750854, 7.899367063252599, 7.940403012442127, 7.981227975693965, 8.021845174272563, 8.06225774829855, 8.10246875958186], [0.0, 0.812403840463596, 1.1489125293076057, 1.4071247279470291, 1.624807680927192, 1.8165902124584952, 1.98997487421324, 2.149418526020468, 2.2978250586152114, 2.437211521390788, 2.569046515733026, 2.6944387170614963, 2.8142494558940583, 2.9291637031753623, 3.0397368307141326, 3.1464265445104544, 3.249615361854384, 3.3496268448888453, 3.4467375879228173, 3.541186241925155, 3.6331804249169903, 3.722902093797257, 3.81051177665153, 3.8961519477556315, 3.97994974842648, 4.06201920231798, 4.142463035441596, 4.221374183841087, 4.298837052040936, 4.374928570845472, 4.449719092257397, 4.523273151159456, 4.595650117230423, 4.666904755831214, 4.737087712930805, 4.806245936279166, 4.874423042781576, 4.941659640242335, 5.007993610219566, 5.073460357586329, 5.138093031466052, 5.201922721455982, 5.264978632435274, 5.3272882407468805, 5.388877434122993, 5.449770637375485, 5.509990925582365, 5.569560126257728, 5.628498911788117, 5.686826883245172, 5.744562646538029, 5.801723881744115, 5.858327406350725, 5.914389233048499, 5.96992462263972, 6.024948132556827, 6.079473661428265, 6.133514490078261, 6.187083319303208, 6.240192304729077, 6.292853089020909, 6.345076831686122, 6.39687423668779, 6.448255578061403, 6.499230723708768, 6.549809157525125, 6.6, 6.649812027418519, 6.699253689777691, 6.748333127521196, 6.797058187186572, 6.8454364360499325, 6.8934751758456345, 6.941181455631311, 6.988562083862459, 7.035623639735144, 7.08237248385031, 7.128814768248646, 7.17495644586084, 7.2208032794142785, 7.266360849833981, 7.311634564172365, 7.356629663099809, 7.401351227985333, 7.445804187594514, 7.489993324429602, 7.533923280734945, 7.577598564189054, 7.62102355330306, 7.664202502543888, 7.707139547199077, 7.749838707999025, 7.792303895511263, 7.834538914320357, 7.8765474670060875, 7.918333157931661, 7.95989949685296, 8.001249902359007, 8.04238770515324, 8.083316151184489, 8.12403840463596, 8.16455755078008], [0.0, 0.8185352771872451, 1.1575836902790224, 1.4177446878757827, 1.6370705543744901, 1.8303005217723127, 2.004993765576342, 2.1656407827707715, 2.315167380558045, 2.455605831561735, 2.588435821108957, 2.714774392099646, 2.8354893757515653, 2.951270912674741, 3.062678566222711, 3.1701734968294715, 3.2741411087489802, 3.374907406137241, 3.4727510708370675, 3.567912554982255, 3.6606010435446255, 3.7509998667022106, 3.8392707640904935, 3.9255572852781047, 4.009987531152684, 4.092676385936225, 4.173727350941841, 4.253234063627348, 4.331281565541543, 4.407947368106838, 4.483302354291978, 4.557411546042337, 4.63033476111609, 4.702127178203499, 4.77283982551269, 4.8425200051213, 4.91121166312347, 4.978955713801841, 5.045790324617146, 5.111751167652823, 5.176871642217914, 5.241183072551464, 5.304714883949938, 5.367494760127856, 5.429548784199292, 5.490901565316937, 5.551576352712804, 5.61159513863928, 5.670978751503131, 5.729746940310715, 5.787918451395113, 5.845511098270194, 5.902541825349482, 5.959026766175833, 6.014981296729027, 6.070420084310475, 6.125357132445422, 6.17980582219215, 6.23377895020348, 6.287288763847259, 6.340346993658943, 6.392964883369843, 6.445153217728807, 6.496922348312315, 6.5482822174979605, 6.599242380758566, 6.649812027418519, 6.7, 6.749814812274482, 6.79926466612383, 6.848357467305573, 6.897100840208152, 6.945502141674135, 6.993568473962345, 7.041306696913577, 7.088723439378913, 7.13582510996451, 7.182617907142214, 7.229107828771128, 7.275300681071539, 7.321202087089251, 7.366817494685205, 7.4121521840825695, 7.457211275000863, 7.501999733404421, 7.546522377890362, 7.590783885739338, 7.634788798650556, 7.678541528180987, 7.722046360907191, 7.76530746332687, 7.808328886515987, 7.851114570556209, 7.893668348746355, 7.935993951610599, 7.978095010715276, 8.019975062305368, 8.061637550770936, 8.103085831953157, 8.144323176298936, 8.18535277187245, 8.226177727231525], [0.0, 0.8246211251235321, 1.16619037896906, 1.4282856857085702, 1.6492422502470643, 1.8439088914585775, 2.0199009876724157, 2.181742422927143, 2.33238075793812, 2.473863375370596, 2.6076809620810595, 2.734958866235469, 2.8565713714171403, 2.973213749463701, 3.0854497241083023, 3.1937438845342623, 3.2984845004941286, 3.4, 3.4985711369071804, 3.594440151122286, 3.687817782917155, 3.778888725538237, 3.867815921162743, 3.954743986657038, 4.039801975344831, 4.123105625617661, 4.204759208325728, 4.28485705712571, 4.363484845854286, 4.440720662234904, 4.516635916254486, 4.591296113299599, 4.66476151587624, 4.737087712930805, 4.8083261120685235, 4.878524367060187, 4.947726750741192, 5.015974481593781, 5.083306010855534, 5.149757275833494, 5.215361924162119, 5.280151512977635, 5.344155686354956, 5.407402333838309, 5.469917732470938, 5.531726674375732, 5.592852581643825, 5.653317610041028, 5.713142742834281, 5.772347875864725, 5.830951894845301, 5.888972745734184, 5.946427498927402, 6.003332407921454, 6.059702963017247, 6.115553940568263, 6.170899448216605, 6.2257529665093525, 6.280127387243033, 6.334035048845246, 6.387487769068525, 6.440496875241847, 6.49307323229917, 6.545227268781429, 6.596969000988257, 6.648308055437864, 6.699253689777691, 6.749814812274482, 6.8, 6.849817515817484, 6.899275324264137, 6.948381106416083, 6.997142273814361, 7.045565981523414, 7.093659140387279, 7.14142842854285, 7.188880302244572, 7.236021006050217, 7.282856582413251, 7.329392880723478, 7.37563556583431, 7.42159012611179, 7.467261881037788, 7.512655988397179, 7.557777451076474, 7.602631123499285, 7.647221717722065, 7.691553809211764, 7.735631842325486, 7.779460135510689, 7.8230428862431785, 7.866384175718855, 7.909487973314076, 7.952358140828418, 7.994998436522675, 8.037412518964047, 8.079603950689663, 8.121576201698781, 8.16333265278342, 8.204876598706406, 8.246211251235321, 8.287339742040265], [0.0, 0.8306623862918076, 1.174734012447073, 1.4387494569938162, 1.661324772583615, 1.8574175621006712, 2.0346989949375804, 2.1977260975835913, 2.349468024894146, 2.4919871588754225, 2.6267851073127395, 2.7549954627911823, 2.8774989139876324, 2.994995826374388, 3.1080540535840107, 3.217141588429082, 3.32264954516723, 3.424908757908742, 3.5242020373412193, 3.6207733980463352, 3.7148351242013424, 3.8065732621348563, 3.8961519477556315, 3.9837168574084183, 4.069397989875161, 4.153311931459037, 4.235563716909475, 4.316248370981448, 4.3954521951671826, 4.473253849269009, 4.54972526643093, 4.624932431938872, 4.698936049788292, 4.77179211617606, 4.843552415324934, 4.914264950122246, 4.983974317750845, 5.052722038663912, 5.120546845796843, 5.187484939737176, 5.253570214625479, 5.3188344587888805, 5.383307533477909, 5.447017532558529, 5.509990925582365, 5.572252686302012, 5.63382640840131, 5.69473440996154, 5.754997827975265, 5.814636704042653, 5.873670062235366, 5.932115979985557, 5.989991652748776, 6.047313453096343, 6.104096984812742, 6.1603571325045765, 6.216108107168021, 6.271363488110062, 6.326136261573885, 6.380438856379708, 6.434283176858164, 6.487680633323437, 6.540642170307133, 6.593178292750774, 6.64529909033446, 6.697014260101287, 6.748333127521196, 6.79926466612383, 6.849817515817484, 6.9, 6.949820141557622, 6.999285677838847, 7.048404074682439, 7.097182539571601, 7.145628033979938, 7.19374728496908, 7.2415467960926705, 7.289032857656769, 7.336211556382492, 7.383088784512889, 7.429670248402685, 7.475961476626268, 7.521967827636597, 7.567694497005016, 7.6131465242697125, 7.658328799418317, 7.703246069028303, 7.747902942086975, 7.792303895511263, 7.836453279386026, 7.880355321938218, 7.924014134263013, 7.967433714816837, 8.010617953691215, 8.053570636680355, 8.096295449154509, 8.138795979750322, 8.18107572388864, 8.223138087129511, 8.264986388373547, 8.306623862918075, 8.34805366537614], [0.0, 0.8366600265340756, 1.1832159566199232, 1.4491376746189442, 1.6733200530681511, 1.8708286933869709, 2.04939015319192, 2.2135943621178655, 2.3664319132398464, 2.5099800796022267, 2.6457513110645907, 2.774887385102322, 2.8982753492378883, 3.0166206257996717, 3.1304951684997055, 3.24037034920393, 3.3466401061363023, 3.4496376621320683, 3.5496478698597698, 3.6469165057620945, 3.7416573867739418, 3.834057902536163, 3.924283374069717, 4.012480529547776, 4.09878030638384, 4.183300132670378, 4.266145801540309, 4.3474130238568325, 4.427188724235731, 4.505552130427525, 4.58257569495584, 4.658325879540847, 4.732863826479693, 4.806245936279167, 4.878524367060187, 4.949747468305833, 5.019960159204453, 5.089204259999789, 5.157518783291051, 5.2249401910452535, 5.291502622129181, 5.35723809439155, 5.422176684690385, 5.486346689738081, 5.549774770204644, 5.612486080160912, 5.674504383644443, 5.735852159879995, 5.796550698475777, 5.856620185738529, 5.916079783099617, 5.974947698515863, 6.033241251599343, 6.090976933136425, 6.148170459575759, 6.2048368229954285, 6.260990336999411, 6.316644678941503, 6.3718129288295975, 6.4265076052238514, 6.48074069840786, 6.534523701081817, 6.587867636800241, 6.640783086353597, 6.6932802122726045, 6.745368781616021, 6.797058187186572, 6.848357467305573, 6.899275324264137, 6.949820141557622, 7.000000000000001, 7.049822692805827, 7.0992957397195395, 7.148426400264607, 7.197221686178633, 7.24568837309472, 7.293833011524189, 7.341661937191062, 7.3891812807644675, 7.436396977031284, 7.4833147735478835, 7.529940238806681, 7.576278769950325, 7.622335600063802, 7.668115805072326, 7.713624310270757, 7.75886589650833, 7.803845206050669, 7.848566748139434, 7.893034904268446, 7.937253933193772, 7.981227975693966, 8.024961059095553, 8.068457101577724, 8.1117199162693, 8.154753215150045, 8.19756061276768, 8.240145629781066, 8.282511696339462, 8.324662155306966, 8.366600265340756, 8.408329203831164], [0.0, 0.8426149773176359, 1.1916375287812984, 1.4594519519326425, 1.6852299546352718, 1.8841443681416774, 2.0639767440550294, 2.2293496809607953, 2.3832750575625967, 2.5278449319529073, 2.6645825188948455, 2.7946377224964243, 2.918903903865285, 3.0380915061926625, 3.152776554086889, 3.2634337744161437, 3.3704599092705436, 3.4741905532080417, 3.5749125863438955, 3.672873534441392, 3.768288736283355, 3.861346915261565, 3.952214569073901, 4.041039470235351, 4.127953488110059, 4.2130748865881795, 4.296510211788167, 4.378355855797928, 4.458699361921591, 4.537620521815371, 4.61519230368573, 4.69148164229596, 4.766550115125193, 4.8404545241123795, 4.913247398615299, 4.984977432245807, 5.0556898639058145, 5.1254268114957995, 5.194227565288221, 5.262128846769148, 5.329165037789691, 5.395368384086485, 5.46076917659042, 5.525395913416522, 5.589275444992849, 5.652433104425031, 5.71489282489182, 5.776677245614472, 5.83780780773057, 5.898304841223451, 5.958187643906493, 6.017474553332154, 6.076183012385325, 6.134329629226001, 6.191930232165088, 6.248999919987198, 6.305553108173778, 6.361603571427569, 6.417164482853779, 6.472248450113762, 6.526867548832287, 6.5810333535091585, 6.6347569661593475, 6.688049042882386, 6.740919818541087, 6.793379129711516, 6.8454364360499325, 6.897100840208152, 6.948381106416083, 6.999285677838847, 7.049822692805827, 7.1, 7.149825172687791, 7.199305522062527, 7.248448109768049, 7.297259759663212, 7.345747068882784, 7.3939164182454755, 7.441773982055624, 7.489325737341113, 7.53657747256671, 7.583534795858723, 7.630203142774117, 7.676587783644501, 7.72269383052313, 7.768526243760782, 7.814089838234521, 7.859389289251424, 7.904429138147802, 7.949213797602879, 7.993747556684537, 8.038034585643434, 8.082078940470701, 8.125884567233282, 8.16945530620004, 8.212794895770866, 8.255906976220118, 8.298795093265047, 8.341462701469089, 8.383913167489272, 8.426149773176359, 8.468175718535841], [0.0, 0.848528137423857, 1.2, 1.4696938456699071, 1.697056274847714, 1.8973665961010278, 2.078460969082653, 2.244994432064365, 2.4, 2.545584412271571, 2.6832815729997477, 2.814249455894058, 2.9393876913398143, 3.0594117081556713, 3.1749015732775088, 3.2863353450309964, 3.394112549695428, 3.4985711369071804, 3.6, 3.6986484017813863, 3.7947331922020555, 3.8884444190447165, 3.97994974842648, 4.069397989875161, 4.156921938165306, 4.242640687119286, 4.3266615305567875, 4.409081537009721, 4.48998886412873, 4.5694638635183455, 4.6475800154489, 4.724404724407087, 4.8, 4.874423042781577, 4.947726750741193, 5.019960159204453, 5.091168824543142, 5.1613951602255765, 5.230678732248808, 5.299056519796709, 5.366563145999495, 5.43323108288245, 5.499090833947008, 5.564171097297422, 5.628498911788116, 5.692099788303082, 5.754997827975264, 5.817215828899595, 5.8787753826796285, 5.939696961966999, 6.0, 6.059702963017248, 6.118823416311343, 6.177378084592201, 6.235382907247959, 6.29285308902091, 6.3498031465550175, 6.406246951218787, 6.462197768561405, 6.517668294720129, 6.572670690061993, 6.627216610312357, 6.681317235396026, 6.734983296193095, 6.788225099390856, 6.841052550594828, 6.8934751758456345, 6.945502141674135, 6.997142273814361, 7.048404074682439, 7.0992957397195395, 7.149825172687791, 7.2, 7.249827584156743, 7.299315036357863, 7.3484692283495345, 7.397296803562773, 7.445804187594514, 7.493997598078079, 7.541883053985921, 7.589466384404111, 7.636753236814713, 7.68374908491942, 7.730459236035075, 7.776888838089433, 7.823042886243179, 7.868926229162401, 7.914543574963752, 7.95989949685296, 8.0049984384758, 8.049844718999243, 8.094442537939225, 8.138795979750322, 8.182909018191515, 8.226785520481254, 8.270429251254132, 8.313843876330612, 8.357032966310472, 8.4, 8.442748367682174, 8.485281374238571, 8.527602242131138], [0.0, 0.8544003745317531, 1.2083045973594573, 1.4798648586948744, 1.7088007490635062, 1.91049731745428, 2.092844953645635, 2.260530911091463, 2.4166091947189146, 2.563201123595259, 2.701851217221259, 2.833725463060951, 2.9597297173897488, 3.0805843601498726, 3.196873472629156, 3.309078421554859, 3.4176014981270124, 3.522782990761707, 3.6249137920783716, 3.7242448899072147, 3.82099463490856, 3.915354390090379, 4.007492981902776, 4.097560249709576, 4.18568990729127, 4.272001872658766, 4.356604182158393, 4.439594576084623, 4.521061822182926, 4.601086828130937, 4.679743582719036, 4.757099956906519, 4.833218389437829, 4.908156476723211, 4.98196748283246, 5.054700782440045, 5.126402247190518, 5.197114584074513, 5.266877632905477, 5.335728628781641, 5.403702434442518, 5.470831746635972, 5.537147279962851, 5.602677931132575, 5.667450926121902, 5.731491952362839, 5.794825277780168, 5.857473858242988, 5.9194594347794975, 5.980802621722272, 6.041522986797286, 6.101639124038721, 6.161168720299745, 6.220128616033596, 6.278534860936905, 6.336402764976356, 6.393746945258312, 6.450581369148055, 6.5069193939989765, 6.562773803811921, 6.618156843109718, 6.673080248281149, 6.727555276621664, 6.7815927332743895, 6.835202996254025, 6.888396039717809, 6.941181455631311, 6.993568473962345, 7.045565981523414, 7.097182539571601, 7.148426400264607, 7.199305522062527, 7.249827584156743, 7.3, 7.349829930005183, 7.399324293474371, 7.448489779814429, 7.4973328590906245, 7.545859791965394, 7.594076639065476, 7.64198926981712, 7.689603370785778, 7.736924453553881, 7.783957862167549, 7.830708780180758, 7.877182237323192, 7.923383115816122, 7.969316156358713, 8.014985963805552, 8.060397012554654, 8.105553651663778, 8.150460109711599, 8.195120499419152, 8.239538822045807, 8.283718971573094, 8.327664738688751, 8.37137981458254, 8.414867794564572, 8.4581321815162, 8.501176389182852, 8.544003745317532, 8.586617494683225], [0.0, 0.8602325267042626, 1.2165525060596438, 1.489966442575134, 1.7204650534085253, 1.9235384061671346, 2.1071307505705477, 2.2759613353482084, 2.4331050121192876, 2.580697580112788, 2.7202941017470885, 2.8530685235374214, 2.979932885150268, 3.1016124838541645, 3.218695387886216, 3.3316662497915357, 3.4409301068170506, 3.5468295701936396, 3.6496575181789317, 3.749666651850535, 3.847076812334269, 3.9420806688854046, 4.034848200366403, 4.125530268947254, 4.214261501141095, 4.301162633521313, 4.386342439892262, 4.469899327725402, 4.551922670696417, 4.632493928760188, 4.711687595755898, 4.789572005931219, 4.866210024238575, 4.941659640242335, 5.015974481593781, 5.089204259999788, 5.161395160225576, 5.232590180780452, 5.302829433425141, 5.372150407425317, 5.440588203494177, 5.508175741568165, 5.574943945906542, 5.6409219104681805, 5.706137047074843, 5.770615218501403, 5.834380858325929, 5.897457079114692, 5.959865770300536, 6.021627686929839, 6.082762530298219, 6.143289021363068, 6.203224967708329, 6.262587324740471, 6.321392251711643, 6.3796551630946325, 6.437390775772432, 6.494613152451807, 6.55133574166368, 6.607571414672716, 6.663332499583071, 6.71863081289633, 6.773477688750439, 6.827884006044625, 6.881860213634101, 6.93541635375988, 6.988562083862459, 7.041306696913577, 7.093659140387279, 7.145628033979938, 7.197221686178633, 7.248448109768049, 7.299315036357863, 7.349829930005183, 7.3999999999999995, 7.44983221287567, 7.49933330370107, 7.548509786706248, 7.597367965289032, 7.645913941446111, 7.694153624668538, 7.742092740338364, 7.789736837660179, 7.837091297158659, 7.884161337770809, 7.930952023559341, 7.977468270071652, 8.023714850367003, 8.069696400732806, 8.115417426109392, 8.160882305241266, 8.206095295571457, 8.251060537894508, 8.295782060782456, 8.340263784797218, 8.384509526501832, 8.42852300228219, 8.472307831990054, 8.515867542417507, 8.559205570612264, 8.602325267042627, 8.645229898620395], [0.0, 0.8660254037844387, 1.224744871391589, 1.5000000000000002, 1.7320508075688774, 1.9364916731037085, 2.121320343559643, 2.29128784747792, 2.449489742783178, 2.598076211353316, 2.7386127875258306, 2.8722813232690148, 3.0000000000000004, 3.122498999199199, 3.24037034920393, 3.3541019662496843, 3.464101615137755, 3.570714214271425, 3.6742346141747673, 3.7749172176353754, 3.872983346207417, 3.968626966596886, 4.06201920231798, 4.153311931459037, 4.242640687119286, 4.330127018922194, 4.415880433163924, 4.5, 4.58257569495584, 4.663689526544408, 4.743416490252569, 4.8218253804964775, 4.898979485566356, 4.974937185533101, 5.049752469181039, 5.123475382979799, 5.196152422706632, 5.26782687642637, 5.338539126015656, 5.408326913195984, 5.477225575051661, 5.545268253204709, 5.612486080160912, 5.678908345800274, 5.7445626465380295, 5.809475019311125, 5.873670062235366, 5.937171043518958, 6.000000000000001, 6.06217782649107, 6.123724356957946, 6.184658438426491, 6.244997998398398, 6.304760106459247, 6.363961030678928, 6.422616289332565, 6.48074069840786, 6.5383484153110105, 6.59545297913646, 6.652067347825035, 6.7082039324993685, 6.7638746292343415, 6.819090848492928, 6.87386354243376, 6.92820323027551, 6.98212002188447, 7.035623639735144, 7.088723439378913, 7.14142842854285, 7.19374728496908, 7.24568837309472, 7.297259759663212, 7.3484692283495345, 7.399324293474371, 7.44983221287567, 7.5, 7.549834435270751, 7.599342076785332, 7.6485292703891785, 7.697402159170327, 7.745966692414834, 7.794228634059948, 7.842193570679062, 7.88986691902975, 7.937253933193772, 7.984359711335657, 8.031189202104505, 8.077747210701757, 8.12403840463596, 8.170067319184096, 8.215838362577491, 8.261355820929154, 8.306623862918075, 8.351646544245034, 8.396427811873334, 8.440971508067065, 8.485281374238571, 8.529361054615991, 8.573214099741124, 8.616843969807043, 8.660254037844387, 8.703447592764606], [0.0, 0.8717797887081349, 1.2328828005937953, 1.5099668870541503, 1.7435595774162698, 1.9493588689617931, 2.1354156504062627, 2.3065125189341593, 2.4657656011875906, 2.615339366124404, 2.7568097504180447, 2.8913664589601926, 3.0199337741083006, 3.1432467291003428, 3.2619012860600183, 3.3763886032268267, 3.4871191548325395, 3.594440151122286, 3.6986484017813863, 3.8000000000000007, 3.8987177379235862, 3.9949968710876362, 4.0890096600521755, 4.180908992073375, 4.270831300812525, 4.358898943540674, 4.445222154178575, 4.529900661162451, 4.613025037868319, 4.694677837722201, 4.774934554525329, 4.8538644398046396, 4.931531202375181, 5.007993610219566, 5.083306010855535, 5.157518783291051, 5.230678732248808, 5.302829433425142, 5.374011537017762, 5.444263035526481, 5.513619500836089, 5.582114294781146, 5.649778756730215, 5.716642371182581, 5.782732917920385, 5.848076606885378, 5.912698199637794, 5.976621118993575, 6.039867548216601, 6.102458520956944, 6.164414002968978, 6.225752966509353, 6.2864934582006855, 6.3466526610489735, 6.406246951218788, 6.465291950097846, 6.523802572120037, 6.581793068761734, 6.639277069079134, 6.696267617113283, 6.752777206453653, 6.808817812219681, 6.864400920692206, 6.919537556802479, 6.974238309665079, 7.0285133563222315, 7.08237248385031, 7.13582510996451, 7.188880302244572, 7.2415467960926705, 7.293833011524189, 7.345747068882784, 7.397296803562773, 7.448489779814429, 7.49933330370107, 7.549834435270751, 7.600000000000001, 7.649836599562112, 7.6993506219680645, 7.748548251124208, 7.7974354758471724, 7.8460180983732135, 7.894301742396222, 7.942291860665913, 7.9899937421752725, 8.037412518964048, 8.084553172563096, 8.13142054010245, 8.178019320104351, 8.224354077980836, 8.270429251254134, 8.316249154516717, 8.36181798414675, 8.407139822793482, 8.452218643646177, 8.497058314499201, 8.54166260162505, 8.586035173466273, 8.630179604156568, 8.674099376880578, 8.717797887081348, 8.761278445523805], [0.0, 0.8774964387392122, 1.2409673645990857, 1.5198684153570665, 1.7549928774784245, 1.9621416870348585, 2.149418526020468, 2.32163735324878, 2.4819347291981715, 2.6324893162176366, 2.7748873851023217, 2.91032644217105, 3.039736830714133, 3.1638584039112754, 3.283291031876401, 3.3985290935932855, 3.509985754956849, 3.6180105030251086, 3.722902093797257, 3.824918299781056, 3.924283374069717, 4.02119385257662, 4.115823125451336, 4.2083250825001635, 4.298837052040936, 4.387482193696061, 4.474371464239419, 4.559605246071199, 4.64327470649756, 4.725462940284264, 4.806245936279166, 4.8856934001224435, 4.963869458396343, 5.040833264451424, 5.1166395221864125, 5.191338940966964, 5.264978632435273, 5.3376024580330075, 5.409251334519409, 5.479963503528103, 5.549774770204643, 5.61871871515206, 5.686826883245173, 5.754128952326321, 5.8206528843421, 5.886425061104575, 5.951470406546605, 6.015812497078014, 6.079473661428266, 6.142475071174486, 6.2048368229954285, 6.266578013557321, 6.327716807822551, 6.388270501473776, 6.448255578061404, 6.507687761409578, 6.566582063752802, 6.624952830020755, 6.682813778641449, 6.740178039191546, 6.797058187186571, 6.853466276272176, 6.90941386804988, 6.96491205974634, 7.019971509913698, 7.074602462329597, 7.128814768248646, 7.182617907142214, 7.236021006050217, 7.289032857656769, 7.341661937191062, 7.3939164182454755, 7.445804187594514, 7.4973328590906245, 7.548509786706248, 7.599342076785332, 7.649836599562112, 7.7, 7.749838707999026, 7.799358948016177, 7.848566748139434, 7.897467948652911, 7.9460682101275735, 7.994373021069257, 8.04238770515324, 8.090117428072352, 8.137567204023572, 8.184741901856162, 8.231646250902672, 8.278284846512591, 8.324662155306966, 8.370782520170978, 8.416650165000327, 8.462269199216012, 8.507643622061282, 8.55277732669336, 8.597674104081872, 8.64233764672499, 8.6867715521936, 8.73097932651315, 8.774964387392123, 8.81873006730561], [0.0, 0.8831760866327848, 1.2489995996796797, 1.5297058540778359, 1.7663521732655696, 1.9748417658131503, 2.1633307652783937, 2.336664289109585, 2.4979991993593593, 2.6495282598983545, 2.7928480087537886, 2.9291637031753623, 3.0594117081556718, 3.1843366656181322, 3.3045423283716615, 3.420526275297414, 3.532704346531139, 3.6414282912066254, 3.7469987990390394, 3.8496753109840323, 3.9496835316263006, 4.047221268969613, 4.1424630354415966, 4.235563716909475, 4.3266615305567875, 4.415880433163924, 4.503332099679082, 4.589117562233508, 4.67332857821917, 4.756048780237647, 4.83735464897913, 4.917316341257699, 4.995998398718719, 5.07346035758633, 5.149757275833494, 5.2249401910452535, 5.299056519796709, 5.372150407425318, 5.444263035526481, 5.515432893255072, 5.585696017507577, 5.655086206239478, 5.723635208501675, 5.791372894228104, 5.858327406350725, 5.92452529743945, 5.989991652748776, 6.054750201288242, 6.1188234163113435, 6.182232606429493, 6.244997998398399, 6.307138812488593, 6.3686733312362644, 6.429618962271405, 6.489992295835182, 6.549809157525127, 6.609084656743323, 6.667833231267862, 6.726068688320096, 6.783804242458652, 6.841052550594828, 6.897825744392215, 6.954135460285484, 7.009992867328754, 7.065408693062278, 7.12039324756716, 7.17495644586084, 7.229107828771128, 7.282856582413251, 7.336211556382492, 7.3891812807644675, 7.441773982055624, 7.493997598078079, 7.545859791965394, 7.597367965289032, 7.6485292703891785, 7.6993506219680645, 7.749838707999026, 7.800000000000002, 7.849840762716147, 7.899367063252601, 7.9485847796950635, 7.997499609252884, 8.046117075956577, 8.094442537939226, 8.142481194328914, 8.19023809177731, 8.23771813064759, 8.284926070883193, 8.33186653757728, 8.378544026261366, 8.424962907930219, 8.47112743381895, 8.517041739947036, 8.56270985144306, 8.608135686662937, 8.653323061113575, 8.698275691193055, 8.742997197757758, 8.787491109526087, 8.831760866327848, 8.875809822207776], [0.0, 0.8888194417315589, 1.2569805089976536, 1.5394804318340656, 1.7776388834631178, 1.9874606914351793, 2.177154105707724, 2.3515952032609695, 2.513961017995307, 2.6664583251946765, 2.8106938645110393, 2.9478805945967355, 3.078960863668131, 3.204684071792413, 3.3256578296631782, 3.442382895611701, 3.5552777669262356, 3.664696440361739, 3.7709415269929605, 3.874274125562104, 3.9749213828703587, 4.07308237088326, 4.168932717135166, 4.262628297189424, 4.354308211415448, 4.444097208657795, 4.532107677449864, 4.618441295502196, 4.703190406521939, 4.786439177509728, 4.868264577855234, 4.948737212663449, 5.027922035990614, 5.105878964487898, 5.182663407939976, 5.2583267300539625, 5.332916650389353, 5.406477596365309, 5.47905101272109, 5.550675634551168, 5.621387729022079, 5.691221310052879, 5.760208329565868, 5.8283788483591215, 5.895761189193471, 5.962382074305537, 6.028266749240615, 6.09343909463285, 6.157921727336262, 6.221736092120913, 6.284902544988268, 6.347440429023341, 6.409368143584826, 6.470703207534712, 6.5314623171231725, 6.591661399070799, 6.6513156593263565, 6.710439627923047, 6.76904720030818, 6.827151675479314, 6.884765791223402, 6.941901756723442, 6.998571282769077, 7.0547856097829085, 7.110555533852471, 7.165891430938652, 7.2208032794142785, 7.275300681071539, 7.329392880723478, 7.383088784512889, 7.436396977031284, 7.489325737341113, 7.541883053985921, 7.594076639065476, 7.645913941446111, 7.697402159170327, 7.748548251124208, 7.799358948016177, 7.849840762716147, 7.9, 7.949842765740717, 7.999374975584031, 8.048602363143555, 8.097530487747484, 8.14616474176652, 8.194510357550353, 8.242572413997951, 8.290355842785038, 8.337865434270332, 8.385105843100611, 8.432081593533118, 8.478797084492587, 8.525256594378847, 8.571464285639882, 8.61742420912421, 8.663140308225419, 8.708616422830897, 8.753856293085923, 8.798863562983575, 8.843641783790206, 8.88819441731559, 8.932524839036274], [0.0, 0.894427190999916, 1.2649110640673518, 1.549193338482967, 1.788854381999832, 2.0000000000000004, 2.1908902300206647, 2.366431913239847, 2.5298221281347035, 2.6832815729997477, 2.8284271247461903, 2.9664793948382657, 3.098386676965934, 3.22490309931942, 3.3466401061363023, 3.4641016151377544, 3.577708763999664, 3.687817782917155, 3.7947331922020555, 3.8987177379235862, 4.000000000000001, 4.09878030638384, 4.1952353926806065, 4.289522117905444, 4.3817804600413295, 4.47213595499958, 4.560701700396552, 4.647580015448901, 4.732863826479694, 4.8166378315169185, 4.898979485566357, 4.979959839195494, 5.059644256269407, 5.1380930314660525, 5.21536192416212, 5.291502622129181, 5.366563145999495, 5.440588203494178, 5.513619500836089, 5.585696017507577, 5.656854249492381, 5.727128425310542, 5.796550698475777, 5.865151319446072, 5.9329587896765315, 6.0, 6.066300355241241, 6.131883886702357, 6.196773353931868, 6.260990336999412, 6.324555320336759, 6.387487769068526, 6.44980619863884, 6.511528238439884, 6.572670690061994, 6.6332495807108005, 6.6932802122726045, 6.752777206453653, 6.811754546370562, 6.870225614927067, 6.928203230275509, 6.985699678629192, 7.042726744663604, 7.0992957397195395, 7.155417527999328, 7.211102550927978, 7.266360849833981, 7.321202087089251, 7.37563556583431, 7.429670248402685, 7.4833147735478835, 7.53657747256671, 7.589466384404111, 7.64198926981712, 7.694153624668538, 7.745966692414834, 7.7974354758471724, 7.848566748139434, 7.899367063252601, 7.949842765740717, 8.000000000000002, 8.049844718999244, 8.099382692526635, 8.148619514985345, 8.19756061276768, 8.246211251235321, 8.29457654133109, 8.342661445845685, 8.390470785361213, 8.438009243891594, 8.485281374238571, 8.532291603080617, 8.579044235810889, 8.62554346113913, 8.671793355471522, 8.717797887081348, 8.763560920082659, 8.809086218218098, 8.854377448471462, 8.899438184514796, 8.94427190999916, 8.988882021697695], [0.0, 0.9, 1.2727922061357855, 1.5588457268119897, 1.8, 2.012461179749811, 2.2045407685048604, 2.3811761799581315, 2.545584412271571, 2.7, 2.8460498941515415, 2.9849623113198605, 3.1176914536239795, 3.2449961479175906, 3.3674916480965473, 3.485685011586675, 3.6, 3.710795063055895, 3.8183766184073566, 3.9230090491866068, 4.024922359499622, 4.124318125460256, 4.221374183841087, 4.316248370981448, 4.409081537009721, 4.500000000000001, 4.589117562233507, 4.676537180435969, 4.762352359916263, 4.846648326421054, 4.929503017546495, 5.01098792654702, 5.091168824543142, 5.170106381884226, 5.247856705360771, 5.324471804789654, 5.4, 5.474486277268398, 5.547972602672079, 5.620498198558559, 5.692099788303083, 5.762811813689565, 5.832666628567075, 5.9016946718718, 5.969924622639721, 6.037383539249432, 6.104096984812742, 6.17008914036094, 6.235382907247959, 6.300000000000001, 6.3639610306789285, 6.427285585688566, 6.489992295835181, 6.552098900352467, 6.613622305514581, 6.674578638386097, 6.734983296193095, 6.794850991743675, 6.854195795277518, 6.913031173081747, 6.97137002317335, 7.029224708315989, 7.08660708661063, 7.143528539874395, 7.2, 7.256031973468694, 7.311634564172365, 7.366817494685205, 7.42159012611179, 7.475961476626268, 7.529940238806681, 7.583534795858723, 7.636753236814713, 7.689603370785778, 7.742092740338364, 7.794228634059948, 7.8460180983732135, 7.897467948652911, 7.9485847796950635, 7.999374975584031, 8.049844718999244, 8.100000000000001, 8.149846624323676, 8.19939022122987, 8.248636250920512, 8.2975900115636, 8.346256645946134, 8.394641147779934, 8.442748367682174, 8.490583018850943, 8.538149682454625, 8.58545281275251, 8.632496741962896, 8.67928568489366, 8.725823743349393, 8.772114910328067, 8.818163074019441, 8.863972021616496, 8.909545442950499, 8.95488693395958, 9.000000000000002, 9.044888059008803], [0.0, 0.9055385138137417, 1.2806248474865698, 1.5684387141358125, 1.8110770276274835, 2.024845673131659, 2.2181073012818837, 2.395829710142188, 2.5612496949731396, 2.716615541441225, 2.863564212655271, 3.003331483536242, 3.136877428271625, 3.264965543462902, 3.3882148692194836, 3.5071355833500366, 3.622154055254967, 3.733630940518894, 3.84187454245971, 3.947150871198111, 4.049691346263318, 4.149698784249287, 4.247352116319061, 4.342810150121694, 4.436214602563767, 4.527692569068709, 4.617358552246079, 4.705316142407438, 4.791659420284376, 4.876474136094644, 4.959838707054898, 5.041825066382213, 5.122499389946279, 5.201922721455982, 5.280151512977635, 5.35723809439155, 5.43323108288245, 5.508175741568166, 5.582114294781146, 5.655086206239478, 5.727128425310542, 5.798275605729691, 5.868560300448485, 5.938013135721409, 6.006662967072484, 6.074537019394977, 6.1416610131136355, 6.208059278067503, 6.27375485654325, 6.338769596696192, 6.403124237432849, 6.466838485689898, 6.529931086925804, 6.592419889539805, 6.654321903845651, 6.715653356152327, 6.776429738438967, 6.836665854054885, 6.8963758598266685, 6.955573304911681, 7.014271166700073, 7.07248188403477, 7.130217387990355, 7.187489130426565, 7.244308110509934, 7.300684899377592, 7.356629663099809, 7.4121521840825695, 7.467261881037788, 7.521967827636597, 7.576278769950325, 7.630203142774117, 7.68374908491942, 7.736924453553881, 7.789736837660179, 7.842193570679062, 7.894301742396222, 7.9460682101275735, 7.997499609252884, 8.048602363143555, 8.099382692526635, 8.149846624323676, 8.200000000000001, 8.249848483457136, 8.299397568498573, 8.348652585896723, 8.397618710086808, 8.446300965511472, 8.494704232638123, 8.542833253669418, 8.590692637965812, 8.638286867197687, 8.685620300243388, 8.732697177848321, 8.77952162705919, 8.826097665446492, 8.872429205127535, 8.918520056601322, 8.964373932405989, 9.009994450608726, 9.055385138137417, 9.100549433962767], [0.0, 0.9110433579144299, 1.2884098726725124, 1.5779733838059502, 1.8220867158288598, 2.0371548787463363, 2.2315913604421396, 2.41039415863879, 2.576819745345025, 2.7331300737432893, 2.8809720581775866, 3.0215889859476257, 3.1559467676119004, 3.2848135411313684, 3.408812109811862, 3.5284557528754696, 3.6441734316577197, 3.7563279941985894, 3.8652296180175374, 3.9711459303329564, 4.0743097574926725, 4.174925149029621, 4.273172123844299, 4.369210454990696, 4.463182720884279, 4.55521678957215, 4.645427859734774, 4.73392015141785, 4.82078831727758, 4.906118628814432, 4.9899899799498595, 5.072474741188959, 5.15363949069005, 5.23354564325181, 5.31224999411737, 5.389805191284746, 5.466260147486579, 5.541660400998964, 5.616048432839589, 5.68946394662977, 5.761944116355173, 5.833523806414096, 5.904235767650205, 5.974110812497538, 6.043177971895251, 6.111464636239008, 6.178996682310163, 6.245798587850876, 6.311893535223801, 6.377303505401009, 6.442049363362563, 6.506150935845249, 6.569627082262737, 6.632495759516172, 6.694774081326419, 6.756478372643548, 6.817624219623724, 6.878226515607057, 6.938299503480662, 6.997856814768361, 7.056911505750939, 7.115476090888086, 7.173562573784381, 7.23118247591637, 7.288346863315439, 7.345066371381541, 7.401351227985333, 7.457211275000863, 7.512655988397179, 7.567694497005016, 7.622335600063802, 7.676587783644501, 7.730459236035075, 7.783957862167549, 7.837091297158659, 7.88986691902975, 7.942291860665913, 7.994373021069257, 8.046117075956577, 8.097530487747484, 8.148619514985345, 8.19939022122987, 8.249848483457136, 8.299999999999999, 8.349850298059241, 8.399404740813482, 8.44866853415377, 8.49764673306675, 8.546344247688598, 8.594765849050223, 8.64291617453276, 8.690799733051039, 8.738420909981391, 8.78578397184907, 8.832893070789435, 8.879752248796134, 8.926365441768558, 8.972736483370054, 9.018869108707587, 9.064766957842878, 9.1104335791443, 9.155872432488342], [0.0, 0.9165151389911681, 1.2961481396815722, 1.5874507866387546, 1.8330302779823362, 2.04939015319192, 2.244994432064365, 2.4248711305964283, 2.5922962793631443, 2.749545416973504, 2.898275349237888, 3.039736830714133, 3.174901573277509, 3.3045423283716615, 3.4292856398964493, 3.5496478698597693, 3.6660605559646724, 3.778888725538237, 3.8884444190447165, 3.9949968710876362, 4.09878030638384, 4.2, 4.298837052040936, 4.3954521951671826, 4.48998886412873, 4.582575694955841, 4.67332857821917, 4.762352359916264, 4.849742261192857, 4.935585071701227, 5.019960159204453, 5.10294032886923, 5.184592558726289, 5.264978632435274, 5.344155686354956, 5.422176684690384, 5.499090833947008, 5.574943945906542, 5.649778756730214, 5.723635208501674, 5.796550698475776, 5.868560300448484, 5.939696961967, 6.009991680526688, 6.079473661428266, 6.148170459575759, 6.216108107168022, 6.2833112289620034, 6.349803146555018, 6.4156059729381765, 6.480740698407861, 6.54522726878143, 6.609084656743323, 6.672330927044912, 6.7349832961930955, 6.797058187186572, 6.858571279792899, 6.919537556802478, 6.97997134664606, 7.0398863627192165, 7.099295739719539, 7.158212067269313, 7.216647421067486, 7.274613391789285, 7.332121111929345, 7.389181280764467, 7.445804187594514, 7.501999733404421, 7.557777451076474, 7.6131465242697125, 7.668115805072326, 7.72269383052313, 7.776888838089433, 7.830708780180758, 7.884161337770809, 7.937253933193772, 7.9899937421752725, 8.04238770515324, 8.094442537939226, 8.14616474176652, 8.19756061276768, 8.248636250920512, 8.299397568498573, 8.349850298059241, 8.4, 8.449852069711044, 8.499411744350311, 8.548684109265006, 8.597674104081872, 8.646386528486914, 8.694826047713663, 8.742997197757758, 8.790904390334365, 8.838551917593742, 8.885943956609225, 8.933084573650918, 8.97997772825746, 9.026627277117408, 9.073036977771006, 9.119210492142399, 9.165151389911681, 9.210863151735564], [0.0, 0.9219544457292888, 1.3038404810405297, 1.5968719422671316, 1.8439088914585775, 2.0615528128088303, 2.2583179581272432, 2.4392621835300936, 2.6076809620810595, 2.765863337187866, 2.9154759474226504, 3.0577769702841313, 3.193743884534263, 3.3241540277189325, 3.449637662132068, 3.5707142142714248, 3.687817782917155, 3.8013155617496426, 3.9115214431215897, 4.018706259482024, 4.123105625617661, 4.224926034855522, 4.324349662087931, 4.421538193886829, 4.5166359162544865, 4.609772228646444, 4.701063709417264, 4.790615826801394, 4.878524367060187, 4.964876634922565, 5.049752469181039, 5.13322510708424, 5.215361924162119, 5.296225070746145, 5.375872022286245, 5.454356057317858, 5.531726674375732, 5.608029957123981, 5.68330889535313, 5.757603668193913, 5.830951894845301, 5.903388857258177, 5.974947698515863, 6.0456596000767355, 6.115553940568263, 6.18465843842649, 6.252999280345393, 6.320601237224193, 6.387487769068526, 6.4536811201050215, 6.519202405202649, 6.584071688552609, 6.648308055437865, 6.711929677819935, 6.77495387438173, 6.837397165588672, 6.899275324264136, 6.960603422117942, 7.021395872616784, 7.0816664705420855, 7.1414284285428495, 7.200694410957877, 7.259476565152615, 7.317786550590281, 7.37563556583431, 7.433034373659253, 7.489993324429602, 7.546522377890362, 7.602631123499285, 7.658328799418317, 7.713624310270757, 7.768526243760782, 7.823042886243179, 7.877182237323192, 7.930952023559341, 7.984359711335657, 8.037412518964048, 8.090117428072352, 8.142481194328914, 8.194510357550353, 8.246211251235321, 8.2975900115636, 8.348652585896723, 8.399404740813482, 8.449852069711044, 8.5, 8.549853799919623, 8.599418584997478, 8.648699324175862, 8.697700845625814, 8.746427842267952, 8.794884877018005, 8.843076387773658, 8.891006692158093, 8.938679992034618, 8.986100377805714, 9.033271832508973, 9.080198235721511, 9.126883367283709, 9.173330910852394, 9.219544457292889, 9.265527507918803], [0.0, 0.9273618495495705, 1.3114877048604001, 1.6062378404209012, 1.854723699099141, 2.0736441353327724, 2.2715633383201097, 2.4535688292770597, 2.6229754097208002, 2.7820855486487113, 2.932575659723036, 3.07571129984594, 3.2124756808418025, 3.343650699460098, 3.4698703145794947, 3.591656999213594, 3.709447398198282, 3.8236108588610325, 3.9344631145812006, 4.042276586281548, 4.147288270665545, 4.249705872175156, 4.349712634186309, 4.447471191587417, 4.543126676640219, 4.636809247747852, 4.7286361670147565, 4.818713521262704, 4.907137658554119, 4.993996395673509, 5.079370039680118, 5.163332257370235, 5.2459508194416005, 5.327288240746882, 5.40740233383831, 5.486346689738081, 5.5641710972974225, 5.640921910468182, 5.716642371182581, 5.791372894228104, 5.865151319446072, 5.93801313572141, 6.009991680526689, 6.081118318204308, 6.15142259969188, 6.220932405998316, 6.289674077406556, 6.357672530100934, 6.424951361683605, 6.491532946846993, 6.557438524302001, 6.62268827591938, 6.687301398920196, 6.751296171847301, 6.814690014960329, 6.87749954561976, 6.939740629158989, 7.001428425685718, 7.062577433203831, 7.123201527403251, 7.183313998427188, 7.242927584892728, 7.302054505411474, 7.3607064878311785, 7.418894796396564, 7.476630257007497, 7.533923280734945, 7.590783885739338, 7.647221717722065, 7.703246069028303, 7.75886589650833, 7.814089838234521, 7.868926229162401, 7.923383115816122, 7.977468270071652, 8.031189202104505, 8.084553172563096, 8.137567204023572, 8.19023809177731, 8.242572413997951, 8.29457654133109, 8.346256645946134, 8.397618710086808, 8.44866853415377, 8.499411744350311, 8.549853799919623, 8.600000000000001, 8.649855490122365, 8.699425268372618, 8.748714191239761, 8.79772697916911, 8.84646822183859, 8.894942383174834, 8.943153806124549, 8.99110671719561, 9.038805230781334, 9.086253353280439, 9.133454987024352, 9.180413934022802, 9.22713389953782, 9.273618495495704, 9.319871243745807], [0.0, 0.9327379053088816, 1.3190905958272918, 1.6155494421403516, 1.8654758106177631, 2.0856653614614213, 2.2847319317591728, 2.4677925358506134, 2.6381811916545836, 2.7982137159266447, 2.9495762407505253, 3.093541659651604, 3.231098884280703, 3.363034344160048, 3.4899856733230297, 3.6124783736376886, 3.7309516212355263, 3.845776904605882, 3.957271787481876, 4.065710270051225, 4.171330722922843, 4.274342054632503, 4.374928570845472, 4.473253849269009, 4.5694638635183455, 4.663689526544408, 4.756048780237647, 4.846648326421054, 4.935585071701227, 5.022947341949744, 5.10881590977792, 5.193264869039514, 5.276362383309167, 5.358171329847526, 5.4387498563548595, 5.518151864528558, 5.596427431853289, 5.673623181001714, 5.749782604586021, 5.8249463516842805, 5.8991524815010505, 5.9724366886556455, 6.044832503882966, 6.1163714733492105, 6.187083319303208, 6.256996084384263, 6.326136261573884, 6.394528911499267, 6.462197768561406, 6.529165337162171, 6.59545297913646, 6.661080993352356, 6.726068688320096, 6.790434448545985, 6.854195795277518, 6.917369442208505, 6.979971346646059, 7.042016756583302, 7.103520254071217, 7.164495795239188, 7.224956747275377, 7.284915922644544, 7.344385610791416, 7.40337760755184, 7.4619032424710525, 7.519973404208288, 7.577598564189054, 7.634788798650556, 7.691553809211764, 7.747902942086975, 7.803845206050669, 7.859389289251424, 7.914543574963752, 7.969316156358713, 8.023714850367003, 8.077747210701757, 8.13142054010245, 8.184741901856162, 8.23771813064759, 8.290355842785038, 8.342661445845685, 8.394641147779934, 8.446300965511472, 8.49764673306675, 8.548684109265006, 8.599418584997478, 8.649855490122365, 8.700000000000001, 8.749857141690944, 8.799431799837988, 8.848728722251575, 8.897752525216692, 8.946507698538017, 8.994998610338971, 9.043229511629129, 9.091204540653564, 9.138927727036691, 9.186402995732335, 9.233634170791044, 9.280624978954814, 9.327379053088816, 9.373899935459095], [0.0, 0.938083151964686, 1.3266499161421599, 1.6248076809271923, 1.876166303929372, 2.0976176963403033, 2.297825058615212, 2.4819347291981715, 2.6532998322843198, 2.814249455894058, 2.9664793948382653, 3.1112698372208096, 3.2496153618543846, 3.3823069050575527, 3.509985754956849, 3.63318042491699, 3.752332607858744, 3.867815921162743, 3.97994974842648, 4.0890096600521755, 4.1952353926806065, 4.298837052040936, 4.4, 4.498888751680798, 4.595650117230424, 4.69041575982343, 4.7833042972405595, 4.874423042781577, 4.963869458396343, 5.0517323761260355, 5.138093031466052, 5.223025942880239, 5.3065996645686395, 5.388877434122993, 5.469917732470938, 5.549774770204643, 5.628498911788116, 5.706137047074843, 5.782732917920384, 5.858327406350725, 5.932958789676531, 6.006662967072483, 6.079473661428266, 6.151422599691879, 6.222539674441619, 6.292853089020909, 6.362389488234747, 6.431174076325411, 6.499230723708769, 6.566582063752802, 6.6332495807108005, 6.6992536897776915, 6.764613810115105, 6.82934843158555, 6.8934751758456345, 6.957010852370435, 7.019971509913698, 7.0823724838503095, 7.144228439796701, 7.205553413860728, 7.26636084983398, 7.326663633605681, 7.386474125047755, 7.445804187594514, 7.504665215717488, 7.5630681604756145, 7.62102355330306, 7.678541528180987, 7.735631842325486, 7.792303895511263, 7.848566748139434, 7.904429138147802, 7.95989949685296, 8.014985963805552, 8.069696400732806, 8.12403840463596, 8.178019320104351, 8.231646250902672, 8.284926070883193, 8.337865434270332, 8.390470785361213, 8.442748367682174, 8.494704232638123, 8.546344247688598, 8.597674104081872, 8.648699324175862, 8.699425268372618, 8.749857141690944, 8.8, 8.849858755935035, 8.899438184514796, 8.948742928478838, 8.997777503361595, 9.046546302318914, 9.09505360072166, 9.143303560529969, 9.191300234460847, 9.23904756996088, 9.28654941299512, 9.333809511662428, 9.38083151964686, 9.427618999514142], [0.0, 0.9433981132056604, 1.3341664064126333, 1.6340134638368193, 1.8867962264113207, 2.1095023109728985, 2.3108440016582685, 2.495996794869737, 2.6683328128252666, 2.830194339616981, 2.9832867780352594, 3.1288975694324033, 3.2680269276736387, 3.4014702703389896, 3.529872518944558, 3.6537651812890215, 3.7735924528226414, 3.8897300677553446, 4.0024992192379, 4.112177038990418, 4.219004621945797, 4.323193264243457, 4.424929377967517, 4.524378410345448, 4.621688003316537, 4.716990566028302, 4.810405388322278, 4.902040391510457, 4.991993589739474, 5.0803543183522155, 5.167204273105525, 5.252618394667558, 5.336665625650533, 5.419409561935692, 5.500909015790026, 5.58121850495033, 5.660388679233962, 5.7384666941614295, 5.815496539419485, 5.8915193286621745, 5.966573556070519, 6.040695324215583, 6.113918547053109, 6.186275131288617, 6.2577951388648065, 6.328506932918695, 6.398437309218556, 6.4676116148080505, 6.536053855347277, 6.603786792439623, 6.670832032063167, 6.73721010508059, 6.802940540677979, 6.868041933477111, 6.932532004974806, 6.996427659884722, 7.059745037889116, 7.122499561249548, 7.184705978674423, 7.246378405796926, 7.307530362578043, 7.368174807915458, 7.428324171709255, 7.487990384609211, 7.547184905645283, 7.6059187479225665, 7.664202502543888, 7.722046360907191, 7.779460135510689, 7.836453279386026, 7.893034904268446, 7.949213797602879, 8.0049984384758, 8.060397012554654, 8.115417426109392, 8.170067319184096, 8.224354077980836, 8.278284846512591, 8.33186653757728, 8.385105843100611, 8.438009243891594, 8.490583018850943, 8.542833253669418, 8.594765849050223, 8.646386528486914, 8.697700845625814, 8.748714191239761, 8.799431799837988, 8.849858755935035, 8.899999999999999, 8.949860334105779, 8.99944442729661, 9.048756820690896, 9.097801932335084, 9.1465840618233, 9.195107394696377, 9.243376006633074, 9.291393867445294, 9.339164844888433, 9.38669270829721, 9.433981132056603, 9.481033698917013], [0.0, 0.9486832980505138, 1.3416407864998738, 1.6431676725154984, 1.8973665961010275, 2.121320343559643, 2.32379000772445, 2.5099800796022267, 2.6832815729997477, 2.846049894151541, 3.0, 3.146426544510455, 3.286335345030997, 3.420526275297414, 3.5496478698597693, 3.674234614174767, 3.794733192202055, 3.9115214431215892, 4.024922359499621, 4.135214625627067, 4.242640687119286, 4.347413023856832, 4.449719092257398, 4.549725266430931, 4.6475800154489, 4.743416490252569, 4.83735464897913, 4.929503017546495, 5.019960159204453, 5.10881590977792, 5.196152422706632, 5.282045058497703, 5.366563145999495, 5.449770637375486, 5.531726674375733, 5.612486080160912, 5.692099788303082, 5.770615218501404, 5.848076606885378, 5.92452529743945, 6.0, 6.074537019394977, 6.148170459575759, 6.220932405998315, 6.29285308902091, 6.363961030678928, 6.434283176858165, 6.5038450166036395, 6.572670690061994, 6.640783086353597, 6.708203932499369, 6.77495387438173, 6.841052550594828, 6.906518659932804, 6.971370023173351, 7.035623639735144, 7.099295739719539, 7.162401831787993, 7.224956747275378, 7.286974680894671, 7.348469228349534, 7.409453421137082, 7.469939758793239, 7.52994023880668, 7.58946638440411, 7.648529270389177, 7.707139547199077, 7.76530746332687, 7.8230428862431785, 7.880355321938218, 7.937253933193772, 7.993747556684537, 8.049844718999243, 8.105553651663778, 8.160882305241266, 8.215838362577491, 8.270429251254134, 8.324662155306966, 8.378544026261366, 8.432081593533118, 8.485281374238571, 8.538149682454625, 8.590692637965812, 8.64291617453276, 8.694826047713663, 8.746427842267952, 8.79772697916911, 8.848728722251575, 8.899438184514796, 8.949860334105779, 9.0, 9.049861877399014, 9.099450532861862, 9.148770409186145, 9.197825830053535, 9.246621004453464, 9.2951600308978, 9.343446901438464, 9.391485505499116, 9.439279633531365, 9.486832980505138, 9.534149149242424], [0.0, 0.9539392014169457, 1.349073756323204, 1.6522711641858308, 1.9078784028338913, 2.1330729007701543, 2.3366642891095846, 2.5238858928247927, 2.698147512646408, 2.8618176042508368, 3.0166206257996713, 3.1638584039112754, 3.3045423283716615, 3.439476704383968, 3.5693136595149495, 3.694590640382233, 3.8157568056677826, 3.9331920878594273, 4.047221268969612, 4.158124577258358, 4.266145801540309, 4.371498598878879, 4.474371464239419, 4.57493169347915, 4.673328578219169, 4.769696007084729, 4.864154602806124, 4.956813492557492, 5.047771785649585, 5.137119815616529, 5.224940191045253, 5.3113086899558, 5.396295025292816, 5.479963503528103, 5.562373594069352, 5.643580423808984, 5.7236352085016735, 5.8025856305616035, 5.880476171195663, 5.957348403442593, 6.0332412515993425, 6.1081912216301815, 6.182232606429493, 6.255397669213365, 6.327716807822551, 6.399218702310462, 6.469930447848725, 6.539877674696982, 6.609084656743323, 6.67757440991862, 6.745368781616021, 6.81248853210044, 6.878953408767936, 6.944782214007867, 7.009992867328754, 7.074602462329597, 7.138627319029899, 7.202083032012336, 7.264984514780469, 7.327346040688948, 7.389181280764466, 7.450503338701353, 7.511324783285569, 7.571657678474378, 7.631513611335565, 7.6909037180295, 7.749838707999025, 7.808328886515987, 7.866384175718855, 7.924014134263013, 7.981227975693966, 8.038034585643434, 8.094442537939225, 8.150460109711599, 8.206095295571457, 8.261355820929154, 8.316249154516717, 8.370782520170978, 8.424962907930219, 8.478797084492587, 8.532291603080617, 8.58545281275251, 8.638286867197687, 8.690799733051039, 8.742997197757758, 8.794884877018005, 8.84646822183859, 8.897752525216692, 8.948742928478838, 8.99944442729661, 9.049861877399014, 9.1, 9.1498633869583, 9.199456505685541, 9.248783703817493, 9.297849213662264, 9.346657156438338, 9.395211546314432, 9.443516294262428, 9.491575211733826, 9.539392014169458, 9.586970324351693], [0.0, 0.959166304662544, 1.3564659966250536, 1.6613247725836153, 1.918332609325088, 2.144761058952722, 2.349468024894146, 2.5377155080899043, 2.7129319932501073, 2.877498913987632, 3.0331501776206204, 3.1811947441173736, 3.3226495451672307, 3.458323293158117, 3.5888716889852725, 3.714835124201342, 3.836665218650176, 3.954743986657038, 4.069397989875161, 4.180908992073375, 4.289522117905444, 4.3954521951671826, 4.498888751680798, 4.6000000000000005, 4.698936049788292, 4.79583152331272, 4.8908077042549944, 4.983974317750846, 5.075431016179809, 5.165268628057984, 5.253570214625479, 5.340411969127476, 5.4258639865002145, 5.509990925582366, 5.592852581643825, 5.674504383644443, 5.754997827975264, 5.83438085832593, 5.912698199637794, 5.989991652748776, 6.066300355241241, 6.1416610131136355, 6.216108107168022, 6.289674077406555, 6.362389488234747, 6.434283176858165, 6.505382386916238, 6.575712889109439, 6.645299090334461, 6.714164132637808, 6.782329983125269, 6.8498175158174845, 6.916646586316234, 6.982836100038438, 7.0484040746824395, 7.113367697511497, 7.177743377970545, 7.24154679609267, 7.3047929470998705, 7.367496182557545, 7.429670248402684, 7.491328320131218, 7.552483035399683, 7.6131465242697125, 7.673330437300352, 7.733045971672482, 7.792303895511263, 7.851114570556209, 7.909487973314076, 7.967433714816837, 8.024961059095553, 8.082078940470701, 8.138795979750322, 8.195120499419152, 8.251060537894508, 8.306623862918075, 8.36181798414675, 8.416650165000327, 8.47112743381895, 8.525256594378847, 8.579044235810889, 8.632496741962896, 8.685620300243388, 8.738420909981391, 8.790904390334365, 8.843076387773658, 8.894942383174834, 8.946507698538017, 8.997777503361595, 9.048756820690896, 9.099450532861862, 9.1498633869583, 9.200000000000001, 9.249864863877743, 9.299462350050137, 9.348796714016196, 9.397872099576585, 9.446692542895637, 9.495261976375376, 9.54358423235212, 9.59166304662544, 9.639502061828715], [0.0, 0.9643650760992956, 1.3638181696985856, 1.670329308849007, 1.9287301521985911, 2.1563858652847827, 2.3622023622035435, 2.551470164434615, 2.727636339397171, 2.8930952282978866, 3.0495901363953815, 3.1984371183438958, 3.340658617698014, 3.4770677301427426, 3.6083237105337433, 3.7349698793966195, 3.8574603043971822, 3.976179070414209, 4.091454509095757, 4.203569911396741, 4.312771730569565, 4.419275958796871, 4.523273151159457, 4.624932431938872, 4.724404724407087, 4.821825380496478, 4.917316341257699, 5.0109879265470205, 5.10294032886923, 5.193264869039514, 5.282045058497703, 5.36935750346352, 5.455272678794342, 5.539855593785817, 5.62316636780382, 5.705260730238365, 5.786190456595773, 5.866003750424986, 5.944745579080741, 6.02245796996542, 6.099180272790763, 6.174949392505174, 6.249799996799899, 6.323764701504951, 6.3968742366877915, 6.469157595854347, 6.540642170307134, 6.611353870426239, 6.681317235396028, 6.750555532695069, 6.8190908484929285, 6.886944169949399, 6.954135460285485, 7.020683727387242, 7.0866070866106305, 7.15192281837549, 7.216647421067487, 7.280796659706959, 7.3443856107914165, 7.407428703673091, 7.469939758793239, 7.531932023060219, 7.593418202627852, 7.654410493303845, 7.7149206087943645, 7.774959806970066, 7.834538914320357, 7.893668348746355, 7.952358140828418, 8.010617953691215, 8.068457101577724, 8.125884567233282, 8.182909018191515, 8.239538822045807, 8.295782060782456, 8.351646544245034, 8.407139822793482, 8.462269199216012, 8.517041739947036, 8.571464285639882, 8.62554346113913, 8.67928568489366, 8.732697177848321, 8.78578397184907, 8.838551917593742, 8.891006692158093, 8.943153806124549, 8.994998610338971, 9.046546302318914, 9.097801932335084, 9.148770409186145, 9.199456505685541, 9.249864863877743, 9.3, 9.349866309204641, 9.39946807005588, 9.448809448814174, 9.497894503520243, 9.5467271878901, 9.595311355031686, 9.643650760992957, 9.691749068150704], [0.0, 0.9695359714832659, 1.3711309200802089, 1.6792855623746668, 1.9390719429665317, 2.1679483388678804, 2.374868417407584, 2.5651510676761324, 2.7422618401604177, 2.9086079144497976, 3.0659419433511785, 3.2155870381627056, 3.3585711247493335, 3.4957116585897072, 3.627671429443411, 3.7549966711037173, 3.8781438859330635, 3.9974992182613374, 4.113392760240627, 4.226109321823088, 4.335896677735761, 4.442971978304612, 4.54752680036083, 4.649731175025068, 4.749736834815168, 4.847679857416329, 4.943682837723311, 5.037856687124, 5.130302135352265, 5.221110992882646, 5.310367218940701, 5.398147830506312, 5.4845236803208355, 5.569560126257729, 5.653317610041029, 5.735852159879995, 5.817215828899595, 5.897457079114693, 5.976621118993575, 6.054750201288242, 6.131883886702357, 6.208059278067504, 6.283311228962004, 6.357672530100933, 6.431174076325411, 6.5038450166036395, 6.57571288910944, 6.646803743153547, 6.717142249498667, 6.786751800382861, 6.855654600401045, 6.923871749245506, 6.9914233171794145, 7.058328414008519, 7.124605252222751, 7.1902712048990205, 7.255342858886822, 7.31983606373804, 7.383765976789894, 7.447147104764348, 7.5099933422074345, 7.572318007057021, 7.634133873596926, 7.695453203028396, 7.756287771866127, 7.816648898345122, 7.8765474670060875, 7.935993951610599, 7.994998436522675, 8.053570636680355, 8.1117199162693, 8.16945530620004, 8.226785520481254, 8.283718971573094, 8.340263784797218, 8.396427811873334, 8.452218643646177, 8.507643622061282, 8.56270985144306, 8.61742420912421, 8.671793355471522, 8.725823743349393, 8.77952162705919, 8.832893070789435, 8.885943956609225, 8.938679992034618, 8.99110671719561, 9.043229511629129, 9.09505360072166, 9.1465840618233, 9.197825830053535, 9.248783703817493, 9.299462350050137, 9.349866309204641, 9.4, 9.44986772394196, 9.499473669630335, 9.548821916864929, 9.597916440561463, 9.646761114488118, 9.695359714832659, 9.743715923609434], [0.0, 0.9746794344808963, 1.378404875209022, 1.6881943016134133, 1.9493588689617927, 2.179449471770337, 2.3874672772626644, 2.578759391645525, 2.756809750418044, 2.9240383034426887, 3.082207001484488, 3.2326459750489227, 3.3763886032268267, 3.5142566781611158, 3.6469165057620936, 3.7749172176353745, 3.8987177379235853, 4.018706259482023, 4.135214625627066, 4.2485291572496005, 4.358898943540674, 4.466542286825459, 4.571651780264984, 4.674398357008098, 4.774934554525329, 4.873397172404482, 4.969909455915671, 5.06458290484024, 5.15751878329105, 5.2488093888042835, 5.338539126015655, 5.426785420486054, 5.513619500836088, 5.599107071667768, 5.683308895353129, 5.766281297335397, 5.848076606885377, 5.928743543112655, 6.008327554319921, 6.08687111741328, 6.164414002968976, 6.24099351065197, 6.316644678941503, 6.3914004725099165, 6.465291950097845, 6.53834841531101, 6.6105975524153635, 6.682065548915245, 6.752777206453653, 6.822756041366274, 6.892024376045111, 6.960603422117942, 7.0285133563222315, 7.095773389842717, 7.162401831787993, 7.2284161474004796, 7.293833011524187, 7.358668357794092, 7.4229374239582535, 7.486654793697916, 7.549834435270749, 7.6124897372673015, 7.674633541739956, 7.736278174936576, 7.797435475847171, 7.858116822750854, 7.918333157931661, 7.978095010715276, 8.037412518964047, 8.096295449154509, 8.154753215150045, 8.212794895770866, 8.270429251254132, 8.327664738688751, 8.384509526501832, 8.440971508067065, 8.497058314499201, 8.55277732669336, 8.608135686662937, 8.663140308225419, 8.717797887081348, 8.772114910328067, 8.826097665446492, 8.879752248796134, 8.933084573650918, 8.986100377805714, 9.038805230781334, 9.091204540653564, 9.143303560529969, 9.195107394696377, 9.246621004453464, 9.297849213662264, 9.348796714016196, 9.39946807005588, 9.44986772394196, 9.499999999999998, 9.549869109050658, 9.599479152537391, 9.648834126463154, 9.697937925146768, 9.746794344808963, 9.795407086997457], [0.0, 0.9797958971132713, 1.3856406460551018, 1.6970562748477143, 1.9595917942265426, 2.1908902300206647, 2.4000000000000004, 2.5922962793631443, 2.7712812921102037, 2.939387691339814, 3.0983866769659336, 3.2496153618543846, 3.3941125496954285, 3.532704346531139, 3.666060555964672, 3.794733192202055, 3.9191835884530852, 4.039801975344831, 4.156921938165306, 4.270831300812525, 4.3817804600413295, 4.48998886412873, 4.595650117230424, 4.698936049788292, 4.800000000000001, 4.898979485566357, 4.9959983987187195, 5.091168824543143, 5.184592558726289, 5.276362383309168, 5.366563145999495, 5.455272678794342, 5.542562584220407, 5.628498911788117, 5.713142742834281, 5.796550698475776, 5.878775382679628, 5.959865770300536, 6.0398675482166, 6.118823416311343, 6.196773353931867, 6.27375485654325, 6.349803146555018, 6.424951361683604, 6.499230723708769, 6.572670690061993, 6.64529909033446, 6.717142249498666, 6.788225099390857, 6.858571279792899, 6.92820323027551, 6.997142273814362, 7.065408693062278, 7.1330218000508046, 7.2, 7.266360849833981, 7.332121111929344, 7.397296803562772, 7.4619032424710525, 7.525955088890711, 7.58946638440411, 7.652450587883597, 7.714920608794364, 7.776888838089433, 7.8383671769061705, 7.899367063252599, 7.95989949685296, 8.019975062305368, 8.079603950689663, 8.138795979750322, 8.19756061276768, 8.255906976220118, 8.313843876330612, 8.37137981458254, 8.42852300228219, 8.485281374238571, 8.54166260162505, 8.597674104081872, 8.653323061113575, 8.708616422830897, 8.763560920082659, 8.818163074019441, 8.872429205127535, 8.926365441768558, 8.97997772825746, 9.033271832508973, 9.086253353280439, 9.138927727036691, 9.191300234460847, 9.243376006633074, 9.2951600308978, 9.346657156438338, 9.397872099576585, 9.448809448814174, 9.499473669630335, 9.549869109050658, 9.600000000000001, 9.649870465451857, 9.699484522385713, 9.748846085563153, 9.797958971132713, 9.846826900072939], [0.0, 0.9848857801796106, 1.392838827718412, 1.7058722109231985, 1.9697715603592212, 2.2022715545545246, 2.412467616362964, 2.6057628441590768, 2.785677655436824, 2.9546573405388314, 3.1144823004794877, 3.2664965942122155, 3.411744421846397, 3.5510561809129415, 3.685105154537656, 3.8144462245521304, 3.9395431207184424, 4.060788100849391, 4.178516483155236, 4.293017586733137, 4.404543109109049, 4.513313638558704, 4.61952378498044, 4.723346271447818, 4.824935232725928, 4.924428900898053, 5.021951811795889, 5.117616632769595, 5.2115256883181535, 5.3037722424704485, 5.394441583704471, 5.483611948342078, 5.571355310873648, 5.657738063926256, 5.742821606144492, 5.826662852782887, 5.909314681077663, 5.990826320300065, 6.071243694664217, 6.150609725872713, 6.228964600958975, 6.306346010171025, 6.38278935889318, 6.458327956987009, 6.532993188424431, 6.606814663663572, 6.679820356865895, 6.7520367297579185, 6.823488843692794, 6.894200461257274, 6.9641941385920605, 7.033491309442276, 7.102112361825883, 7.170076708097342, 7.237402849088892, 7.30410843293006, 7.370210309075312, 7.4357245780085215, 7.5006666370396715, 7.565051222562872, 7.628892449104261, 7.692203845452876, 7.754998388136519, 7.817288532477231, 7.879086241436885, 7.940403012442127, 8.001249902359007, 8.061637550770936, 8.121576201698781, 8.18107572388864, 8.240145629781066, 8.298795093265047, 8.357032966310472, 8.414867794564572, 8.472307831990054, 8.529361054615991, 8.586035173466273, 8.64233764672499, 8.698275691193055, 8.753856293085923, 8.809086218218098, 8.863972021616496, 8.918520056601322, 8.972736483370054, 9.026627277117408, 9.080198235721511, 9.133454987024352, 9.186402995732335, 9.23904756996088, 9.291393867445294, 9.343446901438464, 9.395211546314432, 9.446692542895637, 9.497894503520243, 9.548821916864929, 9.599479152537391, 9.649870465451857, 9.700000000000003, 9.749871794028884, 9.799489782636646, 9.848857801796106, 9.897979591815698], [0.0, 0.9899494936611666, 1.4, 1.7146428199482249, 1.9798989873223332, 2.2135943621178655, 2.4248711305964283, 2.619160170741759, 2.8, 2.9698484809834995, 3.1304951684997055, 3.283291031876401, 3.4292856398964497, 3.5693136595149495, 3.704051835490427, 3.8340579025361623, 3.9597979746446663, 4.08166632639171, 4.2, 4.315089802078284, 4.427188724235731, 4.536518488885503, 4.64327470649756, 4.747630988187688, 4.849742261192857, 4.949747468305833, 5.047771785649585, 5.143928459844674, 5.238320341483518, 5.331041174104736, 5.422176684690383, 5.511805511808268, 5.6, 5.686826883245173, 5.772347875864725, 5.856620185738529, 5.939696961966999, 6.021627686929839, 6.102458520956943, 6.182232606429493, 6.260990336999411, 6.338769596696192, 6.4156059729381765, 6.491532946846992, 6.566582063752802, 6.640783086353596, 6.714164132637808, 6.786751800382861, 6.8585712797928995, 6.929646455628165, 7.0, 7.069653456853455, 7.138627319029899, 7.206941098690901, 7.274613391789285, 7.341661937191061, 7.408103670980854, 7.473954776421918, 7.539230729988306, 7.603946343840151, 7.668115805072325, 7.731752712031082, 7.79487010796203, 7.857480512225277, 7.919595949289333, 7.981227975693965, 8.04238770515324, 8.103085831953157, 8.16333265278342, 8.223138087129511, 8.282511696339462, 8.341462701469089, 8.4, 8.4581321815162, 8.515867542417507, 8.573214099741124, 8.630179604156568, 8.6867715521936, 8.742997197757758, 8.798863562983575, 8.854377448471462, 8.909545442950499, 8.964373932405989, 9.018869108707587, 9.073036977771006, 9.126883367283709, 9.180413934022802, 9.233634170791044, 9.28654941299512, 9.339164844888433, 9.391485505499116, 9.443516294262428, 9.495261976375376, 9.5467271878901, 9.597916440561463, 9.648834126463154, 9.699484522385713, 9.749871794028884, 9.8, 9.849873095629203, 9.899494936611665, 9.948869282486328], [0.0, 0.9949874371066201, 1.407124727947029, 1.7233687939614089, 1.9899748742132402, 2.224859546128699, 2.4372115213907883, 2.632489316217637, 2.814249455894058, 2.98496231131986, 3.146426544510455, 3.3000000000000007, 3.4467375879228177, 3.58747822293042, 3.722902093797257, 3.853569773599539, 3.9799497484264803, 4.102438299353203, 4.221374183841087, 4.337049688440289, 4.449719092257398, 4.559605246071199, 4.666904755831214, 4.77179211617606, 4.874423042781577, 4.974937185533101, 5.073460357586329, 5.170106381884226, 5.264978632435274, 5.358171329847527, 5.449770637375485, 5.539855593785817, 5.628498911788116, 5.715767664977296, 5.801723881744115, 5.886425061104576, 5.96992462263972, 6.052272300549605, 6.133514490078262, 6.213694553162394, 6.29285308902091, 6.3710281744785915, 6.448255578061405, 6.524568951279464, 6.600000000000001, 6.674578638386096, 6.748333127521196, 6.821290200541244, 6.893475175845635, 6.96491205974634, 7.035623639735145, 7.105631569396208, 7.17495644586084, 7.243617880589783, 7.3116345641723655, 7.379024325749307, 7.445804187594514, 7.5119904153293495, 7.577598564189055, 7.642643521714199, 7.707139547199078, 7.771100308193172, 7.834538914320357, 7.897467948652911, 7.959899496852961, 8.021845174272563, 8.083316151184489, 8.144323176298936, 8.204876598706406, 8.264986388373547, 8.324662155306966, 8.383913167489272, 8.442748367682174, 8.501176389182852, 8.559205570612264, 8.616843969807043, 8.674099376880578, 8.73097932651315, 8.787491109526087, 8.843641783790206, 8.899438184514796, 8.95488693395958, 9.009994450608726, 9.064766957842878, 9.119210492142399, 9.173330910852394, 9.22713389953782, 9.280624978954814, 9.333809511662428, 9.38669270829721, 9.439279633531365, 9.491575211733826, 9.54358423235212, 9.595311355031686, 9.646761114488118, 9.697937925146768, 9.748846085563153, 9.799489782636646, 9.849873095629203, 9.900000000000002, 9.949874371066201, 9.999499987499377], [0.0, 1.0, 1.4142135623730951, 1.7320508075688776, 2.0, 2.23606797749979, 2.4494897427831783, 2.6457513110645907, 2.8284271247461903, 3.0, 3.1622776601683795, 3.3166247903554003, 3.4641016151377553, 3.6055512754639896, 3.7416573867739413, 3.8729833462074166, 4.0, 4.123105625617661, 4.242640687119286, 4.358898943540674, 4.47213595499958, 4.582575694955841, 4.69041575982343, 4.79583152331272, 4.898979485566357, 5.000000000000001, 5.099019513592785, 5.196152422706633, 5.291502622129181, 5.385164807134505, 5.477225575051661, 5.567764362830022, 5.656854249492381, 5.7445626465380295, 5.830951894845301, 5.916079783099616, 6.0, 6.08276253029822, 6.164414002968977, 6.244997998398399, 6.324555320336759, 6.403124237432849, 6.480740698407861, 6.557438524302, 6.6332495807108005, 6.7082039324993685, 6.782329983125269, 6.855654600401045, 6.9282032302755105, 7.0, 7.071067811865476, 7.141428428542851, 7.211102550927979, 7.28010988928052, 7.348469228349535, 7.416198487095664, 7.483314773547883, 7.54983443527075, 7.6157731058639095, 7.681145747868608, 7.745966692414833, 7.810249675906655, 7.874007874011811, 7.937253933193772, 8.0, 8.06225774829855, 8.12403840463596, 8.18535277187245, 8.246211251235321, 8.306623862918075, 8.366600265340756, 8.426149773176359, 8.485281374238571, 8.544003745317532, 8.602325267042627, 8.660254037844387, 8.717797887081348, 8.774964387392123, 8.831760866327848, 8.88819441731559, 8.94427190999916, 9.000000000000002, 9.055385138137417, 9.1104335791443, 9.165151389911681, 9.219544457292889, 9.273618495495704, 9.327379053088816, 9.38083151964686, 9.433981132056603, 9.486832980505138, 9.539392014169458, 9.59166304662544, 9.643650760992957, 9.695359714832659, 9.746794344808963, 9.797958971132713, 9.848857801796106, 9.899494936611665, 9.949874371066201, 10.000000000000002, 10.049875621120892], [0.0, 1.0049875621120892, 1.4212670403551897, 1.7406895185529214, 2.0099751242241783, 2.2472205054244236, 2.4617067250182347, 2.6589471600616665, 2.8425340807103794, 3.0149626863362675, 3.178049716414141, 3.333166662499792, 3.481379037105843, 3.6235341863986883, 3.7603191353926335, 3.892300091205713, 4.019950248448357, 4.1436698710201325, 4.263801121065569, 4.380639222761903, 4.494441010848847, 4.605431575867782, 4.713809499757071, 4.819751030914357, 4.9234134500364695, 5.024937810560446, 5.1244511901275835, 5.222068555658764, 5.317894320123333, 5.412023651093924, 5.504543577809154, 5.595533933415113, 5.685068161420759, 5.773214009544425, 5.860034129593445, 5.9455865984779, 6.029925372672535, 6.113100686231171, 6.1951594006934165, 6.276145313805283, 6.356099432828282, 6.435060217278469, 6.5130637951735135, 6.590144156238162, 6.666333324999584, 6.74166151627327, 6.81615727518079, 6.889847603539574, 6.962758074211686, 7.034912934784624, 7.1063352017759485, 7.177046746399247, 7.247068372797377, 7.31641988953614, 7.385120175054704, 7.4531872376856345, 7.520638270785267, 7.587489703452652, 7.653757247260983, 7.719455939378112, 7.784600182411426, 7.849203781276163, 7.913279977354524, 7.976841480185, 8.039900496896713, 8.10246875958186, 8.16455755078008, 8.226177727231525, 8.287339742040265, 8.34805366537614, 8.408329203831164, 8.468175718535841, 8.527602242131138, 8.586617494683225, 8.645229898620395, 8.703447592764606, 8.761278445523805, 8.81873006730561, 8.875809822207776, 8.932524839036274, 8.988882021697695, 9.044888059008803, 9.100549433962767, 9.155872432488342, 9.210863151735564, 9.265527507918803, 9.319871243745807, 9.373899935459095, 9.427618999514142, 9.481033698917013, 9.534149149242424, 9.586970324351693, 9.639502061828715, 9.691749068150704, 9.743715923609434, 9.795407086997457, 9.846826900072939, 9.897979591815698, 9.948869282486328, 9.999499987499377, 10.049875621120892, 10.100000000000001]]}],\n",
       "                        {\"autosize\": false, \"height\": 600, \"margin\": {\"b\": 65, \"l\": 65, \"r\": 50, \"t\": 90}, \"scene\": {\"xaxis\": {\"title\": {\"text\": \"K\"}}, \"yaxis\": {\"title\": {\"text\": \"L\"}}, \"zaxis\": {\"title\": {\"text\": \"Y\"}}}, \"sliders\": [{\"active\": 4, \"currentvalue\": {\"prefix\": \"\"}, \"pad\": {\"t\": 50}, \"steps\": [{\"args\": [{\"visible\": [true, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"alpha = 0.1\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, true, false, false, false, false, false, false, false, false, true]}], \"label\": \"alpha = 0.2\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, true, false, false, false, false, false, false, false, true]}], \"label\": \"alpha = 0.30000000000000004\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, true, false, false, false, false, false, false, true]}], \"label\": \"alpha = 0.4\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, true, false, false, false, false, false, true]}], \"label\": \"alpha = 0.5\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, true, false, false, false, false, true]}], \"label\": \"alpha = 0.6\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, true, false, false, false, true]}], \"label\": \"alpha = 0.7000000000000001\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, true, false, false, true]}], \"label\": \"alpha = 0.8\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, true, false, true]}], \"label\": \"alpha = 0.9\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, true, true]}], \"label\": \"alpha = 1.0\", \"method\": \"update\"}]}], \"template\": {\"data\": {\"bar\": [{\"error_x\": {\"color\": \"#2a3f5f\"}, \"error_y\": {\"color\": \"#2a3f5f\"}, \"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"bar\"}], \"barpolar\": [{\"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"barpolar\"}], \"carpet\": [{\"aaxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"baxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"type\": \"carpet\"}], \"choropleth\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"choropleth\"}], \"contour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"contour\"}], \"contourcarpet\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"contourcarpet\"}], \"heatmap\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmap\"}], \"heatmapgl\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmapgl\"}], \"histogram\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"histogram\"}], \"histogram2d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2d\"}], \"histogram2dcontour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2dcontour\"}], \"mesh3d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"mesh3d\"}], \"parcoords\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"parcoords\"}], \"scatter\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter\"}], \"scatter3d\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter3d\"}], \"scattercarpet\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattercarpet\"}], \"scattergeo\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergeo\"}], \"scattergl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergl\"}], \"scattermapbox\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattermapbox\"}], \"scatterpolar\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolar\"}], \"scatterpolargl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolargl\"}], \"scatterternary\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterternary\"}], \"surface\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"surface\"}], \"table\": [{\"cells\": {\"fill\": {\"color\": \"#EBF0F8\"}, \"line\": {\"color\": \"white\"}}, \"header\": {\"fill\": {\"color\": \"#C8D4E3\"}, \"line\": {\"color\": \"white\"}}, \"type\": \"table\"}]}, \"layout\": {\"annotationdefaults\": {\"arrowcolor\": \"#2a3f5f\", \"arrowhead\": 0, \"arrowwidth\": 1}, \"colorscale\": {\"diverging\": [[0, \"#8e0152\"], [0.1, \"#c51b7d\"], [0.2, \"#de77ae\"], [0.3, \"#f1b6da\"], [0.4, \"#fde0ef\"], [0.5, \"#f7f7f7\"], [0.6, \"#e6f5d0\"], [0.7, \"#b8e186\"], [0.8, \"#7fbc41\"], [0.9, \"#4d9221\"], [1, \"#276419\"]], \"sequential\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"sequentialminus\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]]}, \"colorway\": [\"#636efa\", \"#EF553B\", \"#00cc96\", \"#ab63fa\", \"#FFA15A\", \"#19d3f3\", \"#FF6692\", \"#B6E880\", \"#FF97FF\", \"#FECB52\"], \"font\": {\"color\": \"#2a3f5f\"}, \"geo\": {\"bgcolor\": \"white\", \"lakecolor\": \"white\", \"landcolor\": \"#E5ECF6\", \"showlakes\": true, \"showland\": true, \"subunitcolor\": \"white\"}, \"hoverlabel\": {\"align\": \"left\"}, \"hovermode\": \"closest\", \"mapbox\": {\"style\": \"light\"}, \"paper_bgcolor\": \"white\", \"plot_bgcolor\": \"#E5ECF6\", \"polar\": {\"angularaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"radialaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"scene\": {\"xaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"yaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"zaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}}, \"shapedefaults\": {\"line\": {\"color\": \"#2a3f5f\"}}, \"ternary\": {\"aaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"baxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"caxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"title\": {\"x\": 0.05}, \"xaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}, \"yaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}}}, \"title\": {\"text\": \"Cobb-Douglas Production Function\"}, \"width\": 500},\n",
       "                        {\"responsive\": true}\n",
       "                    )\n",
       "                };\n",
       "                \n",
       "            </script>\n",
       "        </div>\n",
       "</body>\n",
       "</html>"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "filename = \"fig7.html\"\n",
    "\n",
    "L_s = np.arange(0, 10.11, 0.1)\n",
    "K_s = np.arange(0, 10.11, 0.1)\n",
    "A = 1\n",
    "xx, yy = np.meshgrid(K_s, L_s)\n",
    "\n",
    "layout = go.Layout(\n",
    "    title = \"Cobb-Douglas Production Function\", autosize=False, width=500, height=500, margin = dict(l = 65, r = 50, b = 65, t = 90),\n",
    "    scene = dict(xaxis = dict(title = 'K'), yaxis = dict(title = 'L'), zaxis = dict(title = 'Y'))\n",
    ")\n",
    "\n",
    "fig = go.Figure(layout = layout)\n",
    "\n",
    "active = None\n",
    "alphas = []\n",
    "for i, alpha in enumerate(np.arange(0.1, 1.01, 0.1)):\n",
    "    alphas.append(alpha)\n",
    "    if alpha == 0.5:\n",
    "        active = i\n",
    "    V = cobb_douglas(A, xx, yy, alpha)\n",
    "    fig.add_trace(go.Surface(\n",
    "        z = V, contours = go.surface.Contours(\n",
    "            z = go.surface.contours.Z(\n",
    "                show = False, project = dict(z = True)\n",
    "            )\n",
    "        ), colorscale = \"Electric\", showscale = False, name=f\"alpha = {alpha}\", visible=False\n",
    "    ))\n",
    "    \n",
    "fig.data[active].visible = True\n",
    "\n",
    "steps = []\n",
    "for i in range(len(fig.data)):\n",
    "    step = dict(\n",
    "        method=\"update\", args=[\n",
    "            {\"visible\": [False] * len(fig.data) + [True]},\n",
    "        ], label=f\"alpha = {alphas[i]}\"\n",
    "    )\n",
    "    step[\"args\"][0][\"visible\"][i] = True\n",
    "    steps.append(step)\n",
    "    \n",
    "sliders = [dict(\n",
    "    active=active,\n",
    "    currentvalue={\"prefix\": \"\"},\n",
    "    pad={\"t\": 50},\n",
    "    steps=steps\n",
    ")]\n",
    "\n",
    "fig.update_layout(sliders=sliders, width=500, height=600)\n",
    "\n",
    "orig_V = orig_cobb_douglas()\n",
    "fig.add_trace(go.Surface(\n",
    "    z = orig_V, contours = go.surface.Contours(\n",
    "        z = go.surface.contours.Z(\n",
    "            show = False, project = dict(z = True)\n",
    "        )\n",
    "    ), colorscale = \"Viridis\", showscale = False, name=\"alpha = 0.5\"\n",
    "))\n",
    "\n",
    "plot(fig, filename=filename, auto_open=False, include_mathjax='cdn')\n",
    "\n",
    "display(HTML(filename))"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "$\\alpha$ and $\\beta$ are called the output elasticities of capital and labor, respectively. They measure the responsiveness of output to a change in the levels of either labor or capital, holding all else constant. This means that if $\\alpha$ or $\\beta$ were high, then any small increase in their respective input would lead to a relatively large increase in output. As an example, if $\\alpha$ was 0.4, then a 1% increase in capital would lead to a 0.4% increase in output.\n",
    "\n",
    "Note, we assume that there are constant returns to scale. Thus, an increase in $\\alpha$ necessarily means $\\beta$ decreases. This reveals something important when comparing countries: the higher the $\\alpha$, the more capital-intensive the country's production is. This means that $\\alpha$ and $\\beta$ give economists and policymakers insight as to how resources are allocated across nations."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Returns to Scale\n",
    "\n",
    "The significance of the exponents adding up to 1 ($\\alpha + \\beta = 1$) is that this implies constant returns to scale. If all inputs are scaled by a common non-zero factor, the output will be scaled by that same factor. Below is a generalization of this:\n",
    "\n",
    "$$\\begin{aligned}\n",
    "Y &= A (c \\cdot K)^\\alpha (c \\cdot L)^{1 - \\alpha} \\\\\n",
    "&= A c^\\alpha K ^ \\alpha c^{1 - \\alpha}L^{1 - \\alpha} \\\\\n",
    "&= A c^{\\alpha + 1 - \\alpha}K^\\alpha L^{1 - \\alpha} \\\\\n",
    "&= c \\cdot A K^\\alpha L^{1 - \\alpha}\n",
    "\\end{aligned}$$\n",
    "\n",
    "Thus, any increase in either of the inputs will lead to a 1-1 increase in output. This is a significant assumption to make, as it essentially incentivizes companies to continue to \"scale\" their production inputs. They are not losing out on how much return is produced - they are getting output that matches exactly what they put into production.\n",
    "\n",
    "The alternative case is when $\\alpha + \\beta < 1$. This is called decreasing returns to scale, and occurs when a company scales their production inputs by a factor of c, but gets a scaling in output that is less than c.\n",
    "\n",
    "The last case is the most profitable one, when $\\alpha + \\beta > 1$. This is called increasing returns to scale, and occurs when a company increases their production inputs by c, but gets an increase in output that is greater than c.\n",
    "\n",
    "Let us visually examine how values of $\\alpha$ and $\\beta$ affect output."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "metadata": {
    "tags": [
     "remove_input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<html>\n",
       "<head><meta charset=\"utf-8\" /></head>\n",
       "<body>\n",
       "    <div>\n",
       "            <script src=\"https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.5/MathJax.js?config=TeX-AMS-MML_SVG\"></script><script type=\"text/javascript\">if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}</script>\n",
       "                <script type=\"text/javascript\">window.PlotlyConfig = {MathJaxConfig: 'local'};</script>\n",
       "        <script type=\"text/javascript\">/**\n",
       "* plotly.js v1.49.1\n",
       "* Copyright 2012-2019, Plotly, Inc.\n",
       "* All rights reserved.\n",
       "* Licensed under the MIT license\n",
       "*/\n",
       "!function(t){if(\"object\"==typeof exports&&\"undefined\"!=typeof module)module.exports=t();else if(\"function\"==typeof define&&define.amd)define([],t);else{(\"undefined\"!=typeof window?window:\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:this).Plotly=t()}}(function(){return function(){return function t(e,r,n){function i(o,s){if(!r[o]){if(!e[o]){var l=\"function\"==typeof require&&require;if(!s&&l)return l(o,!0);if(a)return a(o,!0);var c=new Error(\"Cannot find module '\"+o+\"'\");throw c.code=\"MODULE_NOT_FOUND\",c}var u=r[o]={exports:{}};e[o][0].call(u.exports,function(t){return i(e[o][1][t]||t)},u,u.exports,t,e,r,n)}return r[o].exports}for(var a=\"function\"==typeof require&&require,o=0;o<n.length;o++)i(n[o]);return i}}()({1:[function(t,e,r){\"use strict\";var n=t(\"../src/lib\"),i={\"X,X div\":\"direction:ltr;font-family:'Open Sans', verdana, arial, sans-serif;margin:0;padding:0;\",\"X input,X button\":\"font-family:'Open Sans', verdana, arial, sans-serif;\",\"X input:focus,X button:focus\":\"outline:none;\",\"X a\":\"text-decoration:none;\",\"X a:hover\":\"text-decoration:none;\",\"X .crisp\":\"shape-rendering:crispEdges;\",\"X .user-select-none\":\"-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;\",\"X svg\":\"overflow:hidden;\",\"X svg a\":\"fill:#447adb;\",\"X svg a:hover\":\"fill:#3c6dc5;\",\"X .main-svg\":\"position:absolute;top:0;left:0;pointer-events:none;\",\"X .main-svg .draglayer\":\"pointer-events:all;\",\"X .cursor-default\":\"cursor:default;\",\"X .cursor-pointer\":\"cursor:pointer;\",\"X .cursor-crosshair\":\"cursor:crosshair;\",\"X .cursor-move\":\"cursor:move;\",\"X .cursor-col-resize\":\"cursor:col-resize;\",\"X .cursor-row-resize\":\"cursor:row-resize;\",\"X .cursor-ns-resize\":\"cursor:ns-resize;\",\"X .cursor-ew-resize\":\"cursor:ew-resize;\",\"X .cursor-sw-resize\":\"cursor:sw-resize;\",\"X .cursor-s-resize\":\"cursor:s-resize;\",\"X .cursor-se-resize\":\"cursor:se-resize;\",\"X .cursor-w-resize\":\"cursor:w-resize;\",\"X .cursor-e-resize\":\"cursor:e-resize;\",\"X .cursor-nw-resize\":\"cursor:nw-resize;\",\"X .cursor-n-resize\":\"cursor:n-resize;\",\"X .cursor-ne-resize\":\"cursor:ne-resize;\",\"X .cursor-grab\":\"cursor:-webkit-grab;cursor:grab;\",\"X .modebar\":\"position:absolute;top:2px;right:2px;\",\"X .ease-bg\":\"-webkit-transition:background-color 0.3s ease 0s;-moz-transition:background-color 0.3s ease 0s;-ms-transition:background-color 0.3s ease 0s;-o-transition:background-color 0.3s ease 0s;transition:background-color 0.3s ease 0s;\",\"X .modebar--hover>:not(.watermark)\":\"opacity:0;-webkit-transition:opacity 0.3s ease 0s;-moz-transition:opacity 0.3s ease 0s;-ms-transition:opacity 0.3s ease 0s;-o-transition:opacity 0.3s ease 0s;transition:opacity 0.3s ease 0s;\",\"X:hover .modebar--hover .modebar-group\":\"opacity:1;\",\"X .modebar-group\":\"float:left;display:inline-block;box-sizing:border-box;padding-left:8px;position:relative;vertical-align:middle;white-space:nowrap;\",\"X .modebar-btn\":\"position:relative;font-size:16px;padding:3px 4px;height:22px;cursor:pointer;line-height:normal;box-sizing:border-box;\",\"X .modebar-btn svg\":\"position:relative;top:2px;\",\"X .modebar.vertical\":\"display:flex;flex-direction:column;flex-wrap:wrap;align-content:flex-end;max-height:100%;\",\"X .modebar.vertical svg\":\"top:-1px;\",\"X .modebar.vertical .modebar-group\":\"display:block;float:none;padding-left:0px;padding-bottom:8px;\",\"X .modebar.vertical .modebar-group .modebar-btn\":\"display:block;text-align:center;\",\"X [data-title]:before,X [data-title]:after\":\"position:absolute;-webkit-transform:translate3d(0, 0, 0);-moz-transform:translate3d(0, 0, 0);-ms-transform:translate3d(0, 0, 0);-o-transform:translate3d(0, 0, 0);transform:translate3d(0, 0, 0);display:none;opacity:0;z-index:1001;pointer-events:none;top:110%;right:50%;\",\"X [data-title]:hover:before,X [data-title]:hover:after\":\"display:block;opacity:1;\",\"X [data-title]:before\":\"content:'';position:absolute;background:transparent;border:6px solid transparent;z-index:1002;margin-top:-12px;border-bottom-color:#69738a;margin-right:-6px;\",\"X [data-title]:after\":\"content:attr(data-title);background:#69738a;color:white;padding:8px 10px;font-size:12px;line-height:12px;white-space:nowrap;margin-right:-18px;border-radius:2px;\",\"X .vertical [data-title]:before,X .vertical [data-title]:after\":\"top:0%;right:200%;\",\"X .vertical [data-title]:before\":\"border:6px solid transparent;border-left-color:#69738a;margin-top:8px;margin-right:-30px;\",\"X .select-outline\":\"fill:none;stroke-width:1;shape-rendering:crispEdges;\",\"X .select-outline-1\":\"stroke:white;\",\"X .select-outline-2\":\"stroke:black;stroke-dasharray:2px 2px;\",Y:\"font-family:'Open Sans';position:fixed;top:50px;right:20px;z-index:10000;font-size:10pt;max-width:180px;\",\"Y p\":\"margin:0;\",\"Y .notifier-note\":\"min-width:180px;max-width:250px;border:1px solid #fff;z-index:3000;margin:0;background-color:#8c97af;background-color:rgba(140,151,175,0.9);color:#fff;padding:10px;overflow-wrap:break-word;word-wrap:break-word;-ms-hyphens:auto;-webkit-hyphens:auto;hyphens:auto;\",\"Y .notifier-close\":\"color:#fff;opacity:0.8;float:right;padding:0 5px;background:none;border:none;font-size:20px;font-weight:bold;line-height:20px;\",\"Y .notifier-close:hover\":\"color:#444;text-decoration:none;cursor:pointer;\"};for(var a in i){var o=a.replace(/^,/,\" ,\").replace(/X/g,\".js-plotly-plot .plotly\").replace(/Y/g,\".plotly-notifier\");n.addStyleRule(o,i[a])}},{\"../src/lib\":719}],2:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/aggregate\")},{\"../src/transforms/aggregate\":1265}],3:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/bar\")},{\"../src/traces/bar\":864}],4:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/barpolar\")},{\"../src/traces/barpolar\":876}],5:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/box\")},{\"../src/traces/box\":886}],6:[function(t,e,r){\"use strict\";e.exports=t(\"../src/components/calendars\")},{\"../src/components/calendars\":591}],7:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/candlestick\")},{\"../src/traces/candlestick\":895}],8:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/carpet\")},{\"../src/traces/carpet\":914}],9:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choropleth\")},{\"../src/traces/choropleth\":928}],10:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choroplethmapbox\")},{\"../src/traces/choroplethmapbox\":935}],11:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/cone\")},{\"../src/traces/cone\":941}],12:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contour\")},{\"../src/traces/contour\":956}],13:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contourcarpet\")},{\"../src/traces/contourcarpet\":967}],14:[function(t,e,r){\"use strict\";e.exports=t(\"../src/core\")},{\"../src/core\":697}],15:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/densitymapbox\")},{\"../src/traces/densitymapbox\":977}],16:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/filter\")},{\"../src/transforms/filter\":1266}],17:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnel\")},{\"../src/traces/funnel\":987}],18:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnelarea\")},{\"../src/traces/funnelarea\":996}],19:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/groupby\")},{\"../src/transforms/groupby\":1267}],20:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmap\")},{\"../src/traces/heatmap\":1009}],21:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmapgl\")},{\"../src/traces/heatmapgl\":1018}],22:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram\")},{\"../src/traces/histogram\":1030}],23:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2d\")},{\"../src/traces/histogram2d\":1036}],24:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2dcontour\")},{\"../src/traces/histogram2dcontour\":1040}],25:[function(t,e,r){\"use strict\";var n=t(\"./core\");n.register([t(\"./bar\"),t(\"./box\"),t(\"./heatmap\"),t(\"./histogram\"),t(\"./histogram2d\"),t(\"./histogram2dcontour\"),t(\"./contour\"),t(\"./scatterternary\"),t(\"./violin\"),t(\"./funnel\"),t(\"./waterfall\"),t(\"./pie\"),t(\"./sunburst\"),t(\"./funnelarea\"),t(\"./scatter3d\"),t(\"./surface\"),t(\"./isosurface\"),t(\"./volume\"),t(\"./mesh3d\"),t(\"./cone\"),t(\"./streamtube\"),t(\"./scattergeo\"),t(\"./choropleth\"),t(\"./scattergl\"),t(\"./splom\"),t(\"./pointcloud\"),t(\"./heatmapgl\"),t(\"./parcoords\"),t(\"./parcats\"),t(\"./scattermapbox\"),t(\"./choroplethmapbox\"),t(\"./densitymapbox\"),t(\"./sankey\"),t(\"./indicator\"),t(\"./table\"),t(\"./carpet\"),t(\"./scattercarpet\"),t(\"./contourcarpet\"),t(\"./ohlc\"),t(\"./candlestick\"),t(\"./scatterpolar\"),t(\"./scatterpolargl\"),t(\"./barpolar\")]),n.register([t(\"./aggregate\"),t(\"./filter\"),t(\"./groupby\"),t(\"./sort\")]),n.register([t(\"./calendars\")]),e.exports=n},{\"./aggregate\":2,\"./bar\":3,\"./barpolar\":4,\"./box\":5,\"./calendars\":6,\"./candlestick\":7,\"./carpet\":8,\"./choropleth\":9,\"./choroplethmapbox\":10,\"./cone\":11,\"./contour\":12,\"./contourcarpet\":13,\"./core\":14,\"./densitymapbox\":15,\"./filter\":16,\"./funnel\":17,\"./funnelarea\":18,\"./groupby\":19,\"./heatmap\":20,\"./heatmapgl\":21,\"./histogram\":22,\"./histogram2d\":23,\"./histogram2dcontour\":24,\"./indicator\":26,\"./isosurface\":27,\"./mesh3d\":28,\"./ohlc\":29,\"./parcats\":30,\"./parcoords\":31,\"./pie\":32,\"./pointcloud\":33,\"./sankey\":34,\"./scatter3d\":35,\"./scattercarpet\":36,\"./scattergeo\":37,\"./scattergl\":38,\"./scattermapbox\":39,\"./scatterpolar\":40,\"./scatterpolargl\":41,\"./scatterternary\":42,\"./sort\":43,\"./splom\":44,\"./streamtube\":45,\"./sunburst\":46,\"./surface\":47,\"./table\":48,\"./violin\":49,\"./volume\":50,\"./waterfall\":51}],26:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/indicator\")},{\"../src/traces/indicator\":1046}],27:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/isosurface\")},{\"../src/traces/isosurface\":1052}],28:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/mesh3d\")},{\"../src/traces/mesh3d\":1057}],29:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/ohlc\")},{\"../src/traces/ohlc\":1062}],30:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcats\")},{\"../src/traces/parcats\":1071}],31:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcoords\")},{\"../src/traces/parcoords\":1081}],32:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pie\")},{\"../src/traces/pie\":1092}],33:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pointcloud\")},{\"../src/traces/pointcloud\":1101}],34:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sankey\")},{\"../src/traces/sankey\":1107}],35:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatter3d\")},{\"../src/traces/scatter3d\":1143}],36:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattercarpet\")},{\"../src/traces/scattercarpet\":1149}],37:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergeo\")},{\"../src/traces/scattergeo\":1156}],38:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergl\")},{\"../src/traces/scattergl\":1167}],39:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattermapbox\")},{\"../src/traces/scattermapbox\":1176}],40:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolar\")},{\"../src/traces/scatterpolar\":1183}],41:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolargl\")},{\"../src/traces/scatterpolargl\":1189}],42:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterternary\")},{\"../src/traces/scatterternary\":1196}],43:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/sort\")},{\"../src/transforms/sort\":1269}],44:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/splom\")},{\"../src/traces/splom\":1205}],45:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/streamtube\")},{\"../src/traces/streamtube\":1213}],46:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sunburst\")},{\"../src/traces/sunburst\":1219}],47:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/surface\")},{\"../src/traces/surface\":1228}],48:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/table\")},{\"../src/traces/table\":1236}],49:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/violin\")},{\"../src/traces/violin\":1244}],50:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/volume\")},{\"../src/traces/volume\":1252}],51:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/waterfall\")},{\"../src/traces/waterfall\":1260}],52:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).eye||[0,0,1],r=t.center||[0,0,0],s=t.up||[0,1,0],l=t.distanceLimits||[0,1/0],c=t.mode||\"turntable\",u=n(),h=i(),f=a();return u.setDistanceLimits(l[0],l[1]),u.lookAt(0,e,r,s),h.setDistanceLimits(l[0],l[1]),h.lookAt(0,e,r,s),f.setDistanceLimits(l[0],l[1]),f.lookAt(0,e,r,s),new o({turntable:u,orbit:h,matrix:f},c)};var n=t(\"turntable-camera-controller\"),i=t(\"orbit-camera-controller\"),a=t(\"matrix-camera-controller\");function o(t,e){this._controllerNames=Object.keys(t),this._controllerList=this._controllerNames.map(function(e){return t[e]}),this._mode=e,this._active=t[e],this._active||(this._mode=\"turntable\",this._active=t.turntable),this.modes=this._controllerNames,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}var s=o.prototype;[[\"flush\",1],[\"idle\",1],[\"lookAt\",4],[\"rotate\",4],[\"pan\",4],[\"translate\",4],[\"setMatrix\",2],[\"setDistanceLimits\",2],[\"setDistance\",2]].forEach(function(t){for(var e=t[0],r=[],n=0;n<t[1];++n)r.push(\"a\"+n);var i=\"var cc=this._controllerList;for(var i=0;i<cc.length;++i){cc[i].\"+t[0]+\"(\"+r.join()+\")}\";s[e]=Function.apply(null,r.concat(i))}),s.recalcMatrix=function(t){this._active.recalcMatrix(t)},s.getDistance=function(t){return this._active.getDistance(t)},s.getDistanceLimits=function(t){return this._active.getDistanceLimits(t)},s.lastT=function(){return this._active.lastT()},s.setMode=function(t){if(t!==this._mode){var e=this._controllerNames.indexOf(t);if(!(e<0)){var r=this._active,n=this._controllerList[e],i=Math.max(r.lastT(),n.lastT());r.recalcMatrix(i),n.setMatrix(i,r.computedMatrix),this._active=n,this._mode=t,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}}},s.getMode=function(){return this._mode}},{\"matrix-camera-controller\":433,\"orbit-camera-controller\":456,\"turntable-camera-controller\":542}],53:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n,i){\"use strict\";function a(t){return t.target.depth}function o(t,e){return t.sourceLinks.length?t.depth:e-1}function s(t){return function(){return t}}i=i&&i.hasOwnProperty(\"default\")?i.default:i;var l=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&\"function\"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?\"symbol\":typeof t};function c(t,e){return h(t.source,e.source)||t.index-e.index}function u(t,e){return h(t.target,e.target)||t.index-e.index}function h(t,e){return t.partOfCycle===e.partOfCycle?t.y0-e.y0:\"top\"===t.circularLinkType||\"bottom\"===e.circularLinkType?-1:1}function f(t){return t.value}function p(t){return(t.y0+t.y1)/2}function d(t){return p(t.source)}function g(t){return p(t.target)}function v(t){return t.index}function m(t){return t.nodes}function y(t){return t.links}function x(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function b(t,e){return e(t)}var _=25,w=10,k=.3;function T(t,e){var r=0,n=0;t.links.forEach(function(i){i.circular&&(i.source.circularLinkType||i.target.circularLinkType?i.circularLinkType=i.source.circularLinkType?i.source.circularLinkType:i.target.circularLinkType:i.circularLinkType=r<n?\"top\":\"bottom\",\"top\"==i.circularLinkType?r+=1:n+=1,t.nodes.forEach(function(t){b(t,e)!=b(i.source,e)&&b(t,e)!=b(i.target,e)||(t.circularLinkType=i.circularLinkType)}))}),t.links.forEach(function(t){t.circular&&(t.source.circularLinkType==t.target.circularLinkType&&(t.circularLinkType=t.source.circularLinkType),Y(t,e)&&(t.circularLinkType=t.source.circularLinkType))})}function A(t){var e=Math.abs(t.y1-t.y0),r=Math.abs(t.target.x0-t.source.x1);return Math.atan(r/e)}function M(t,e){var r=0;t.sourceLinks.forEach(function(t){r=t.circular&&!Y(t,e)?r+1:r});var n=0;return t.targetLinks.forEach(function(t){n=t.circular&&!Y(t,e)?n+1:n}),r+n}function S(t){var e=t.source.sourceLinks,r=0;e.forEach(function(t){r=t.circular?r+1:r});var n=t.target.targetLinks,i=0;return n.forEach(function(t){i=t.circular?i+1:i}),!(r>1||i>1)}function E(t,e,r){return t.sort(L),t.forEach(function(n,i){var a,o,s=0;if(Y(n,r)&&S(n))n.circularPathData.verticalBuffer=s+n.width/2;else{for(var l=0;l<i;l++)if(a=t[i],o=t[l],!(a.source.column<o.target.column||a.target.column>o.source.column)){var c=t[l].circularPathData.verticalBuffer+t[l].width/2+e;s=c>s?c:s}n.circularPathData.verticalBuffer=s+n.width/2}}),t}function C(t,r,i,a){var o=e.min(t.links,function(t){return t.source.y0});t.links.forEach(function(t){t.circular&&(t.circularPathData={})}),E(t.links.filter(function(t){return\"top\"==t.circularLinkType}),r,a),E(t.links.filter(function(t){return\"bottom\"==t.circularLinkType}),r,a),t.links.forEach(function(e){if(e.circular){if(e.circularPathData.arcRadius=e.width+w,e.circularPathData.leftNodeBuffer=5,e.circularPathData.rightNodeBuffer=5,e.circularPathData.sourceWidth=e.source.x1-e.source.x0,e.circularPathData.sourceX=e.source.x0+e.circularPathData.sourceWidth,e.circularPathData.targetX=e.target.x0,e.circularPathData.sourceY=e.y0,e.circularPathData.targetY=e.y1,Y(e,a)&&S(e))e.circularPathData.leftSmallArcRadius=w+e.width/2,e.circularPathData.leftLargeArcRadius=w+e.width/2,e.circularPathData.rightSmallArcRadius=w+e.width/2,e.circularPathData.rightLargeArcRadius=w+e.width/2,\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=e.source.y1+_+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=e.source.y0-_-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius);else{var s=e.source.column,l=e.circularLinkType,c=t.links.filter(function(t){return t.source.column==s&&t.circularLinkType==l});\"bottom\"==e.circularLinkType?c.sort(O):c.sort(P);var u=0;c.forEach(function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.leftSmallArcRadius=w+e.width/2+u,e.circularPathData.leftLargeArcRadius=w+e.width/2+n*r+u),u+=t.width}),s=e.target.column,c=t.links.filter(function(t){return t.target.column==s&&t.circularLinkType==l}),\"bottom\"==e.circularLinkType?c.sort(I):c.sort(z),u=0,c.forEach(function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.rightSmallArcRadius=w+e.width/2+u,e.circularPathData.rightLargeArcRadius=w+e.width/2+n*r+u),u+=t.width}),\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=Math.max(i,e.source.y1,e.target.y1)+_+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=o-_-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius)}e.circularPathData.leftInnerExtent=e.circularPathData.sourceX+e.circularPathData.leftNodeBuffer,e.circularPathData.rightInnerExtent=e.circularPathData.targetX-e.circularPathData.rightNodeBuffer,e.circularPathData.leftFullExtent=e.circularPathData.sourceX+e.circularPathData.leftLargeArcRadius+e.circularPathData.leftNodeBuffer,e.circularPathData.rightFullExtent=e.circularPathData.targetX-e.circularPathData.rightLargeArcRadius-e.circularPathData.rightNodeBuffer}if(e.circular)e.path=function(t){var e=\"\";e=\"top\"==t.circularLinkType?\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 0 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY-t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 0 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 0 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY-t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 0 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY:\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 1 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY+t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 1 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 1 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY+t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 1 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY;return e}(e);else{var h=n.linkHorizontal().source(function(t){return[t.source.x0+(t.source.x1-t.source.x0),t.y0]}).target(function(t){return[t.target.x0,t.y1]});e.path=h(e)}})}function L(t,e){return D(t)==D(e)?\"bottom\"==t.circularLinkType?O(t,e):P(t,e):D(e)-D(t)}function P(t,e){return t.y0-e.y0}function O(t,e){return e.y0-t.y0}function z(t,e){return t.y1-e.y1}function I(t,e){return e.y1-t.y1}function D(t){return t.target.column-t.source.column}function R(t){return t.target.x0-t.source.x1}function F(t,e){var r=A(t),n=R(e)/Math.tan(r);return\"up\"==G(t)?t.y1+n:t.y1-n}function B(t,e){var r=A(t),n=R(e)/Math.tan(r);return\"up\"==G(t)?t.y1-n:t.y1+n}function N(t,e,r,n){t.links.forEach(function(i){if(!i.circular&&i.target.column-i.source.column>1){var a=i.source.column+1,o=i.target.column-1,s=1,l=o-a+1;for(s=1;a<=o;a++,s++)t.nodes.forEach(function(o){if(o.column==a){var c,u=s/(l+1),h=Math.pow(1-u,3),f=3*u*Math.pow(1-u,2),p=3*Math.pow(u,2)*(1-u),d=Math.pow(u,3),g=h*i.y0+f*i.y0+p*i.y1+d*i.y1,v=g-i.width/2,m=g+i.width/2;v>o.y0&&v<o.y1?(c=o.y1-v+10,c=\"bottom\"==o.circularLinkType?c:-c,o=U(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&j(o,t)&&U(t,c,e,r)})):m>o.y0&&m<o.y1?(c=m-o.y0+10,o=U(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&U(t,c,e,r)})):v<o.y0&&m>o.y1&&(c=m-o.y0+10,o=U(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&U(t,c,e,r)}))}})}})}function j(t,e){return t.y0>e.y0&&t.y0<e.y1||(t.y1>e.y0&&t.y1<e.y1||t.y0<e.y0&&t.y1>e.y1)}function U(t,e,r,n){return t.y0+e>=r&&t.y1+e<=n&&(t.y0=t.y0+e,t.y1=t.y1+e,t.targetLinks.forEach(function(t){t.y1=t.y1+e}),t.sourceLinks.forEach(function(t){t.y0=t.y0+e})),t}function V(t,e,r,n){t.nodes.forEach(function(i){n&&i.y+(i.y1-i.y0)>e&&(i.y=i.y-(i.y+(i.y1-i.y0)-e));var a=t.links.filter(function(t){return b(t.source,r)==b(i,r)}),o=a.length;o>1&&a.sort(function(t,e){if(!t.circular&&!e.circular){if(t.target.column==e.target.column)return t.y1-e.y1;if(!H(t,e))return t.y1-e.y1;if(t.target.column>e.target.column){var r=B(e,t);return t.y1-r}if(e.target.column>t.target.column)return B(t,e)-e.y1}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.target.column===e.target.column?t.target.y1-e.target.y1:e.target.column-t.target.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.target.column===e.target.column?e.target.y1-t.target.y1:t.target.column-e.target.column:\"top\"==t.circularLinkType?-1:1:void 0});var s=i.y0;a.forEach(function(t){t.y0=s+t.width/2,s+=t.width}),a.forEach(function(t,e){if(\"bottom\"==t.circularLinkType){for(var r=e+1,n=0;r<o;r++)n+=a[r].width;t.y0=i.y1-n-t.width/2}})})}function q(t,e,r){t.nodes.forEach(function(e){var n=t.links.filter(function(t){return b(t.target,r)==b(e,r)}),i=n.length;i>1&&n.sort(function(t,e){if(!t.circular&&!e.circular){if(t.source.column==e.source.column)return t.y0-e.y0;if(!H(t,e))return t.y0-e.y0;if(e.source.column<t.source.column){var r=F(e,t);return t.y0-r}if(t.source.column<e.source.column)return F(t,e)-e.y0}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:t.source.column-e.source.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:e.source.column-t.source.column:\"top\"==t.circularLinkType?-1:1:void 0});var a=e.y0;n.forEach(function(t){t.y1=a+t.width/2,a+=t.width}),n.forEach(function(t,r){if(\"bottom\"==t.circularLinkType){for(var a=r+1,o=0;a<i;a++)o+=n[a].width;t.y1=e.y1-o-t.width/2}})})}function H(t,e){return G(t)==G(e)}function G(t){return t.y0-t.y1>0?\"up\":\"down\"}function Y(t,e){return b(t.source,e)==b(t.target,e)}t.sankeyCircular=function(){var t,n,a=0,b=0,A=1,S=1,E=24,L=v,P=o,O=m,z=y,I=32,D=2,R=null;function F(){var o={nodes:O.apply(null,arguments),links:z.apply(null,arguments)};!function(t){t.nodes.forEach(function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]});var e=r.map(t.nodes,L);t.links.forEach(function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!==(\"undefined\"==typeof n?\"undefined\":l(n))&&(n=t.source=x(e,n)),\"object\"!==(\"undefined\"==typeof i?\"undefined\":l(i))&&(i=t.target=x(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)})}(o),function(t,e,r){var n=0;if(null===r){for(var a=[],o=0;o<t.links.length;o++){var s=t.links[o],l=s.source.index,c=s.target.index;a[l]||(a[l]=[]),a[c]||(a[c]=[]),-1===a[l].indexOf(c)&&a[l].push(c)}var u=i(a);u.sort(function(t,e){return t.length-e.length});var h={};for(o=0;o<u.length;o++){var f=u[o],p=f.slice(-2);h[p[0]]||(h[p[0]]={}),h[p[0]][p[1]]=!0}t.links.forEach(function(t){var e=t.target.index,r=t.source.index;e===r||h[r]&&h[r][e]?(t.circular=!0,t.circularLinkID=n,n+=1):t.circular=!1})}else t.links.forEach(function(t){t.source[r]<t.target[r]?t.circular=!1:(t.circular=!0,t.circularLinkID=n,n+=1)})}(o,0,R),function(t){t.nodes.forEach(function(t){t.partOfCycle=!1,t.value=Math.max(e.sum(t.sourceLinks,f),e.sum(t.targetLinks,f)),t.sourceLinks.forEach(function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)}),t.targetLinks.forEach(function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)})})}(o),function(t){var e,r,n;for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach(function(t){t.depth=n,t.sourceLinks.forEach(function(t){r.indexOf(t.target)<0&&!t.circular&&r.push(t.target)})});for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach(function(t){t.height=n,t.targetLinks.forEach(function(t){r.indexOf(t.source)<0&&!t.circular&&r.push(t.source)})});t.nodes.forEach(function(t){t.column=Math.floor(P.call(null,t,n))})}(o),T(o,L),function(i,o,s){var l=r.nest().key(function(t){return t.column}).sortKeys(e.ascending).entries(i.nodes).map(function(t){return t.values});(function(r){if(n){var o=1/0;l.forEach(function(t){var e=S*n/(t.length+1);o=e<o?e:o}),t=o}var s=e.min(l,function(r){return(S-b-(r.length-1)*t)/e.sum(r,f)});s*=k,i.links.forEach(function(t){t.width=t.value*s});var c=function(t){var r=0,n=0,i=0,a=0,o=e.max(t.nodes,function(t){return t.column});return t.links.forEach(function(t){t.circular&&(\"top\"==t.circularLinkType?r+=t.width:n+=t.width,0==t.target.column&&(a+=t.width),t.source.column==o&&(i+=t.width))}),{top:r=r>0?r+_+w:r,bottom:n=n>0?n+_+w:n,left:a=a>0?a+_+w:a,right:i=i>0?i+_+w:i}}(i),u=function(t,r){var n=e.max(t.nodes,function(t){return t.column}),i=A-a,o=S-b,s=i+r.right+r.left,l=o+r.top+r.bottom,c=i/s,u=o/l;return a=a*c+r.left,A=0==r.right?A:A*c,b=b*u+r.top,S*=u,t.nodes.forEach(function(t){t.x0=a+t.column*((A-a-E)/n),t.x1=t.x0+E}),u}(i,c);s*=u,i.links.forEach(function(t){t.width=t.value*s}),l.forEach(function(t){var e=t.length;t.forEach(function(t,n){t.depth==l.length-1&&1==e?(t.y0=S/2-t.value*s,t.y1=t.y0+t.value*s):0==t.depth&&1==e?(t.y0=S/2-t.value*s,t.y1=t.y0+t.value*s):t.partOfCycle?0==M(t,r)?(t.y0=S/2+n,t.y1=t.y0+t.value*s):\"top\"==t.circularLinkType?(t.y0=b+n,t.y1=t.y0+t.value*s):(t.y0=S-t.value*s-n,t.y1=t.y0+t.value*s):0==c.top||0==c.bottom?(t.y0=(S-b)/e*n,t.y1=t.y0+t.value*s):(t.y0=(S-b)/2-e/2+n,t.y1=t.y0+t.value*s)})})})(s),m();for(var c=1,u=o;u>0;--u)v(c*=.99,s),m();function v(t,r){var n=l.length;l.forEach(function(i){var a=i.length,o=i[0].depth;i.forEach(function(i){var s;if(i.sourceLinks.length||i.targetLinks.length)if(i.partOfCycle&&M(i,r)>0);else if(0==o&&1==a)s=i.y1-i.y0,i.y0=S/2-s/2,i.y1=S/2+s/2;else if(o==n-1&&1==a)s=i.y1-i.y0,i.y0=S/2-s/2,i.y1=S/2+s/2;else{var l=e.mean(i.sourceLinks,g),c=e.mean(i.targetLinks,d),u=((l&&c?(l+c)/2:l||c)-p(i))*t;i.y0+=u,i.y1+=u}})})}function m(){l.forEach(function(e){var r,n,i,a=b,o=e.length;for(e.sort(h),i=0;i<o;++i)r=e[i],(n=a-r.y0)>0&&(r.y0+=n,r.y1+=n),a=r.y1+t;if((n=a-t-S)>0)for(a=r.y0-=n,r.y1-=n,i=o-2;i>=0;--i)r=e[i],(n=r.y1+t-a)>0&&(r.y0-=n,r.y1-=n),a=r.y0})}}(o,I,L),B(o);for(var s=0;s<4;s++)V(o,S,L),q(o,0,L),N(o,b,S,L),V(o,S,L),q(o,0,L);return function(t,r,n){var i=t.nodes,a=t.links,o=!1,s=!1;if(a.forEach(function(t){\"top\"==t.circularLinkType?o=!0:\"bottom\"==t.circularLinkType&&(s=!0)}),0==o||0==s){var l=e.min(i,function(t){return t.y0}),c=e.max(i,function(t){return t.y1}),u=c-l,h=n-r,f=h/u;i.forEach(function(t){var e=(t.y1-t.y0)*f;t.y0=(t.y0-l)*f,t.y1=t.y0+e}),a.forEach(function(t){t.y0=(t.y0-l)*f,t.y1=(t.y1-l)*f,t.width=t.width*f})}}(o,b,S),C(o,D,S,L),o}function B(t){t.nodes.forEach(function(t){t.sourceLinks.sort(u),t.targetLinks.sort(c)}),t.nodes.forEach(function(t){var e=t.y0,r=e,n=t.y1,i=n;t.sourceLinks.forEach(function(t){t.circular?(t.y0=n-t.width/2,n-=t.width):(t.y0=e+t.width/2,e+=t.width)}),t.targetLinks.forEach(function(t){t.circular?(t.y1=i-t.width/2,i-=t.width):(t.y1=r+t.width/2,r+=t.width)})})}return F.nodeId=function(t){return arguments.length?(L=\"function\"==typeof t?t:s(t),F):L},F.nodeAlign=function(t){return arguments.length?(P=\"function\"==typeof t?t:s(t),F):P},F.nodeWidth=function(t){return arguments.length?(E=+t,F):E},F.nodePadding=function(e){return arguments.length?(t=+e,F):t},F.nodes=function(t){return arguments.length?(O=\"function\"==typeof t?t:s(t),F):O},F.links=function(t){return arguments.length?(z=\"function\"==typeof t?t:s(t),F):z},F.size=function(t){return arguments.length?(a=b=0,A=+t[0],S=+t[1],F):[A-a,S-b]},F.extent=function(t){return arguments.length?(a=+t[0][0],A=+t[1][0],b=+t[0][1],S=+t[1][1],F):[[a,b],[A,S]]},F.iterations=function(t){return arguments.length?(I=+t,F):I},F.circularLinkGap=function(t){return arguments.length?(D=+t,F):D},F.nodePaddingRatio=function(t){return arguments.length?(n=+t,F):n},F.sortNodes=function(t){return arguments.length?(R=t,F):R},F.update=function(t){return T(t,L),B(t),t.links.forEach(function(t){t.circular&&(t.circularLinkType=t.y0+t.y1<S?\"top\":\"bottom\",t.source.circularLinkType=t.circularLinkType,t.target.circularLinkType=t.circularLinkType)}),V(t,S,L,!1),q(t,0,L),C(t,D,S,L),t},F},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,a)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=o,Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\"),t(\"elementary-circuits-directed-graph\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,null)},{\"d3-array\":152,\"d3-collection\":153,\"d3-shape\":161,\"elementary-circuits-directed-graph\":172}],54:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n){\"use strict\";function i(t){return t.target.depth}function a(t,e){return t.sourceLinks.length?t.depth:e-1}function o(t){return function(){return t}}function s(t,e){return c(t.source,e.source)||t.index-e.index}function l(t,e){return c(t.target,e.target)||t.index-e.index}function c(t,e){return t.y0-e.y0}function u(t){return t.value}function h(t){return(t.y0+t.y1)/2}function f(t){return h(t.source)*t.value}function p(t){return h(t.target)*t.value}function d(t){return t.index}function g(t){return t.nodes}function v(t){return t.links}function m(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function y(t){return[t.source.x1,t.y0]}function x(t){return[t.target.x0,t.y1]}t.sankey=function(){var t=0,n=0,i=1,y=1,x=24,b=8,_=d,w=a,k=g,T=v,A=32,M=2/3;function S(){var a={nodes:k.apply(null,arguments),links:T.apply(null,arguments)};return function(t){t.nodes.forEach(function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]});var e=r.map(t.nodes,_);t.links.forEach(function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!=typeof n&&(n=t.source=m(e,n)),\"object\"!=typeof i&&(i=t.target=m(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)})}(a),function(t){t.nodes.forEach(function(t){t.value=Math.max(e.sum(t.sourceLinks,u),e.sum(t.targetLinks,u))})}(a),function(e){var r,n,a;for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach(function(t){t.depth=a,t.sourceLinks.forEach(function(t){n.indexOf(t.target)<0&&n.push(t.target)})});for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach(function(t){t.height=a,t.targetLinks.forEach(function(t){n.indexOf(t.source)<0&&n.push(t.source)})});var o=(i-t-x)/(a-1);e.nodes.forEach(function(e){e.x1=(e.x0=t+Math.max(0,Math.min(a-1,Math.floor(w.call(null,e,a))))*o)+x})}(a),function(t){var i=r.nest().key(function(t){return t.x0}).sortKeys(e.ascending).entries(t.nodes).map(function(t){return t.values});(function(){var r=e.max(i,function(t){return t.length}),a=M*(y-n)/(r-1);b>a&&(b=a);var o=e.min(i,function(t){return(y-n-(t.length-1)*b)/e.sum(t,u)});i.forEach(function(t){t.forEach(function(t,e){t.y1=(t.y0=e)+t.value*o})}),t.links.forEach(function(t){t.width=t.value*o})})(),d();for(var a=1,o=A;o>0;--o)l(a*=.99),d(),s(a),d();function s(t){i.forEach(function(r){r.forEach(function(r){if(r.targetLinks.length){var n=(e.sum(r.targetLinks,f)/e.sum(r.targetLinks,u)-h(r))*t;r.y0+=n,r.y1+=n}})})}function l(t){i.slice().reverse().forEach(function(r){r.forEach(function(r){if(r.sourceLinks.length){var n=(e.sum(r.sourceLinks,p)/e.sum(r.sourceLinks,u)-h(r))*t;r.y0+=n,r.y1+=n}})})}function d(){i.forEach(function(t){var e,r,i,a=n,o=t.length;for(t.sort(c),i=0;i<o;++i)e=t[i],(r=a-e.y0)>0&&(e.y0+=r,e.y1+=r),a=e.y1+b;if((r=a-b-y)>0)for(a=e.y0-=r,e.y1-=r,i=o-2;i>=0;--i)e=t[i],(r=e.y1+b-a)>0&&(e.y0-=r,e.y1-=r),a=e.y0})}}(a),E(a),a}function E(t){t.nodes.forEach(function(t){t.sourceLinks.sort(l),t.targetLinks.sort(s)}),t.nodes.forEach(function(t){var e=t.y0,r=e;t.sourceLinks.forEach(function(t){t.y0=e+t.width/2,e+=t.width}),t.targetLinks.forEach(function(t){t.y1=r+t.width/2,r+=t.width})})}return S.update=function(t){return E(t),t},S.nodeId=function(t){return arguments.length?(_=\"function\"==typeof t?t:o(t),S):_},S.nodeAlign=function(t){return arguments.length?(w=\"function\"==typeof t?t:o(t),S):w},S.nodeWidth=function(t){return arguments.length?(x=+t,S):x},S.nodePadding=function(t){return arguments.length?(b=+t,S):b},S.nodes=function(t){return arguments.length?(k=\"function\"==typeof t?t:o(t),S):k},S.links=function(t){return arguments.length?(T=\"function\"==typeof t?t:o(t),S):T},S.size=function(e){return arguments.length?(t=n=0,i=+e[0],y=+e[1],S):[i-t,y-n]},S.extent=function(e){return arguments.length?(t=+e[0][0],i=+e[1][0],n=+e[0][1],y=+e[1][1],S):[[t,n],[i,y]]},S.iterations=function(t){return arguments.length?(A=+t,S):A},S},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,i)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=a,t.sankeyLinkHorizontal=function(){return n.linkHorizontal().source(y).target(x)},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3)},{\"d3-array\":152,\"d3-collection\":153,\"d3-shape\":161}],55:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\"),i=6378137;function a(t){var e=0;if(t&&t.length>0){e+=Math.abs(o(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(o(t[r]))}return e}function o(t){var e,r,n,a,o,l,c=0,u=t.length;if(u>2){for(l=0;l<u;l++)l===u-2?(n=u-2,a=u-1,o=0):l===u-1?(n=u-1,a=0,o=1):(n=l,a=l+1,o=l+2),e=t[n],r=t[a],c+=(s(t[o][0])-s(e[0]))*Math.sin(s(r[1]));c=c*i*i/2}return c}function s(t){return t*Math.PI/180}r.default=function(t){return n.geomReduce(t,function(t,e){return t+function(t){var e,r=0;switch(t.type){case\"Polygon\":return a(t.coordinates);case\"MultiPolygon\":for(e=0;e<t.coordinates.length;e++)r+=a(t.coordinates[e]);return r;case\"Point\":case\"MultiPoint\":case\"LineString\":case\"MultiLineString\":return 0}return 0}(e)},0)}},{\"@turf/meta\":58}],56:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\"),i=t(\"@turf/helpers\");r.default=function(t,e){void 0===e&&(e={});var r=0,a=0,o=0;return n.coordEach(t,function(t){r+=t[0],a+=t[1],o++}),i.point([r/o,a/o],e.properties)}},{\"@turf/helpers\":57,\"@turf/meta\":58}],57:[function(t,e,r){\"use strict\";function n(t,e,r){void 0===r&&(r={});var n={type:\"Feature\"};return(0===r.id||r.id)&&(n.id=r.id),r.bbox&&(n.bbox=r.bbox),n.properties=e||{},n.geometry=t,n}function i(t,e,r){return void 0===r&&(r={}),n({type:\"Point\",coordinates:t},e,r)}function a(t,e,r){void 0===r&&(r={});for(var i=0,a=t;i<a.length;i++){var o=a[i];if(o.length<4)throw new Error(\"Each LinearRing of a Polygon must have 4 or more Positions.\");for(var s=0;s<o[o.length-1].length;s++)if(o[o.length-1][s]!==o[0][s])throw new Error(\"First and last Position are not equivalent.\")}return n({type:\"Polygon\",coordinates:t},e,r)}function o(t,e,r){if(void 0===r&&(r={}),t.length<2)throw new Error(\"coordinates must be an array of two or more positions\");return n({type:\"LineString\",coordinates:t},e,r)}function s(t,e){void 0===e&&(e={});var r={type:\"FeatureCollection\"};return e.id&&(r.id=e.id),e.bbox&&(r.bbox=e.bbox),r.features=t,r}function l(t,e,r){return void 0===r&&(r={}),n({type:\"MultiLineString\",coordinates:t},e,r)}function c(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPoint\",coordinates:t},e,r)}function u(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPolygon\",coordinates:t},e,r)}function h(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t*n}function f(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t/n}function p(t){return 180*(t%(2*Math.PI))/Math.PI}function d(t){return!isNaN(t)&&null!==t&&!Array.isArray(t)&&!/^\\s*$/.test(t)}Object.defineProperty(r,\"__esModule\",{value:!0}),r.earthRadius=6371008.8,r.factors={centimeters:100*r.earthRadius,centimetres:100*r.earthRadius,degrees:r.earthRadius/111325,feet:3.28084*r.earthRadius,inches:39.37*r.earthRadius,kilometers:r.earthRadius/1e3,kilometres:r.earthRadius/1e3,meters:r.earthRadius,metres:r.earthRadius,miles:r.earthRadius/1609.344,millimeters:1e3*r.earthRadius,millimetres:1e3*r.earthRadius,nauticalmiles:r.earthRadius/1852,radians:1,yards:r.earthRadius/1.0936},r.unitsFactors={centimeters:100,centimetres:100,degrees:1/111325,feet:3.28084,inches:39.37,kilometers:.001,kilometres:.001,meters:1,metres:1,miles:1/1609.344,millimeters:1e3,millimetres:1e3,nauticalmiles:1/1852,radians:1/r.earthRadius,yards:1/1.0936},r.areaFactors={acres:247105e-9,centimeters:1e4,centimetres:1e4,feet:10.763910417,inches:1550.003100006,kilometers:1e-6,kilometres:1e-6,meters:1,metres:1,miles:3.86e-7,millimeters:1e6,millimetres:1e6,yards:1.195990046},r.feature=n,r.geometry=function(t,e,r){switch(void 0===r&&(r={}),t){case\"Point\":return i(e).geometry;case\"LineString\":return o(e).geometry;case\"Polygon\":return a(e).geometry;case\"MultiPoint\":return c(e).geometry;case\"MultiLineString\":return l(e).geometry;case\"MultiPolygon\":return u(e).geometry;default:throw new Error(t+\" is invalid\")}},r.point=i,r.points=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return i(t,e)}),r)},r.polygon=a,r.polygons=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return a(t,e)}),r)},r.lineString=o,r.lineStrings=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return o(t,e)}),r)},r.featureCollection=s,r.multiLineString=l,r.multiPoint=c,r.multiPolygon=u,r.geometryCollection=function(t,e,r){return void 0===r&&(r={}),n({type:\"GeometryCollection\",geometries:t},e,r)},r.round=function(t,e){if(void 0===e&&(e=0),e&&!(e>=0))throw new Error(\"precision must be a positive number\");var r=Math.pow(10,e||0);return Math.round(t*r)/r},r.radiansToLength=h,r.lengthToRadians=f,r.lengthToDegrees=function(t,e){return p(f(t,e))},r.bearingToAzimuth=function(t){var e=t%360;return e<0&&(e+=360),e},r.radiansToDegrees=p,r.degreesToRadians=function(t){return t%360*Math.PI/180},r.convertLength=function(t,e,r){if(void 0===e&&(e=\"kilometers\"),void 0===r&&(r=\"kilometers\"),!(t>=0))throw new Error(\"length must be a positive number\");return h(f(t,e),r)},r.convertArea=function(t,e,n){if(void 0===e&&(e=\"meters\"),void 0===n&&(n=\"kilometers\"),!(t>=0))throw new Error(\"area must be a positive number\");var i=r.areaFactors[e];if(!i)throw new Error(\"invalid original units\");var a=r.areaFactors[n];if(!a)throw new Error(\"invalid final units\");return t/i*a},r.isNumber=d,r.isObject=function(t){return!!t&&t.constructor===Object},r.validateBBox=function(t){if(!t)throw new Error(\"bbox is required\");if(!Array.isArray(t))throw new Error(\"bbox must be an Array\");if(4!==t.length&&6!==t.length)throw new Error(\"bbox must be an Array of 4 or 6 numbers\");t.forEach(function(t){if(!d(t))throw new Error(\"bbox must only contain numbers\")})},r.validateId=function(t){if(!t)throw new Error(\"id is required\");if(-1===[\"string\",\"number\"].indexOf(typeof t))throw new Error(\"id must be a number or a string\")},r.radians2degrees=function(){throw new Error(\"method has been renamed to `radiansToDegrees`\")},r.degrees2radians=function(){throw new Error(\"method has been renamed to `degreesToRadians`\")},r.distanceToDegrees=function(){throw new Error(\"method has been renamed to `lengthToDegrees`\")},r.distanceToRadians=function(){throw new Error(\"method has been renamed to `lengthToRadians`\")},r.radiansToDistance=function(){throw new Error(\"method has been renamed to `radiansToLength`\")},r.bearingToAngle=function(){throw new Error(\"method has been renamed to `bearingToAzimuth`\")},r.convertDistance=function(){throw new Error(\"method has been renamed to `convertLength`\")}},{}],58:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/helpers\");function i(t,e,r){if(null!==t)for(var n,a,o,s,l,c,u,h,f=0,p=0,d=t.type,g=\"FeatureCollection\"===d,v=\"Feature\"===d,m=g?t.features.length:1,y=0;y<m;y++){l=(h=!!(u=g?t.features[y].geometry:v?t.geometry:t)&&\"GeometryCollection\"===u.type)?u.geometries.length:1;for(var x=0;x<l;x++){var b=0,_=0;if(null!==(s=h?u.geometries[x]:u)){c=s.coordinates;var w=s.type;switch(f=!r||\"Polygon\"!==w&&\"MultiPolygon\"!==w?0:1,w){case null:break;case\"Point\":if(!1===e(c,p,y,b,_))return!1;p++,b++;break;case\"LineString\":case\"MultiPoint\":for(n=0;n<c.length;n++){if(!1===e(c[n],p,y,b,_))return!1;p++,\"MultiPoint\"===w&&b++}\"LineString\"===w&&b++;break;case\"Polygon\":case\"MultiLineString\":for(n=0;n<c.length;n++){for(a=0;a<c[n].length-f;a++){if(!1===e(c[n][a],p,y,b,_))return!1;p++}\"MultiLineString\"===w&&b++,\"Polygon\"===w&&_++}\"Polygon\"===w&&b++;break;case\"MultiPolygon\":for(n=0;n<c.length;n++){for(_=0,a=0;a<c[n].length;a++){for(o=0;o<c[n][a].length-f;o++){if(!1===e(c[n][a][o],p,y,b,_))return!1;p++}_++}b++}break;case\"GeometryCollection\":for(n=0;n<s.geometries.length;n++)if(!1===i(s.geometries[n],e,r))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}}}}}function a(t,e){var r;switch(t.type){case\"FeatureCollection\":for(r=0;r<t.features.length&&!1!==e(t.features[r].properties,r);r++);break;case\"Feature\":e(t.properties,0)}}function o(t,e){if(\"Feature\"===t.type)e(t,0);else if(\"FeatureCollection\"===t.type)for(var r=0;r<t.features.length&&!1!==e(t.features[r],r);r++);}function s(t,e){var r,n,i,a,o,s,l,c,u,h,f=0,p=\"FeatureCollection\"===t.type,d=\"Feature\"===t.type,g=p?t.features.length:1;for(r=0;r<g;r++){for(s=p?t.features[r].geometry:d?t.geometry:t,c=p?t.features[r].properties:d?t.properties:{},u=p?t.features[r].bbox:d?t.bbox:void 0,h=p?t.features[r].id:d?t.id:void 0,o=(l=!!s&&\"GeometryCollection\"===s.type)?s.geometries.length:1,i=0;i<o;i++)if(null!==(a=l?s.geometries[i]:s))switch(a.type){case\"Point\":case\"LineString\":case\"MultiPoint\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":if(!1===e(a,f,c,u,h))return!1;break;case\"GeometryCollection\":for(n=0;n<a.geometries.length;n++)if(!1===e(a.geometries[n],f,c,u,h))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}else if(!1===e(null,f,c,u,h))return!1;f++}}function l(t,e){s(t,function(t,r,i,a,o){var s,l=null===t?null:t.type;switch(l){case null:case\"Point\":case\"LineString\":case\"Polygon\":return!1!==e(n.feature(t,i,{bbox:a,id:o}),r,0)&&void 0}switch(l){case\"MultiPoint\":s=\"Point\";break;case\"MultiLineString\":s=\"LineString\";break;case\"MultiPolygon\":s=\"Polygon\"}for(var c=0;c<t.coordinates.length;c++){var u={type:s,coordinates:t.coordinates[c]};if(!1===e(n.feature(u,i),r,c))return!1}})}function c(t,e){l(t,function(t,r,a){var o=0;if(t.geometry){var s=t.geometry.type;if(\"Point\"!==s&&\"MultiPoint\"!==s){var l,c=0,u=0,h=0;return!1!==i(t,function(i,s,f,p,d){if(void 0===l||r>c||p>u||d>h)return l=i,c=r,u=p,h=d,void(o=0);var g=n.lineString([l,i],t.properties);if(!1===e(g,r,a,d,o))return!1;o++,l=i})&&void 0}}})}function u(t,e){if(!t)throw new Error(\"geojson is required\");l(t,function(t,r,i){if(null!==t.geometry){var a=t.geometry.type,o=t.geometry.coordinates;switch(a){case\"LineString\":if(!1===e(t,r,i,0,0))return!1;break;case\"Polygon\":for(var s=0;s<o.length;s++)if(!1===e(n.lineString(o[s],t.properties),r,i,s))return!1}}})}r.coordEach=i,r.coordReduce=function(t,e,r,n){var a=r;return i(t,function(t,n,i,o,s){a=0===n&&void 0===r?t:e(a,t,n,i,o,s)},n),a},r.propEach=a,r.propReduce=function(t,e,r){var n=r;return a(t,function(t,i){n=0===i&&void 0===r?t:e(n,t,i)}),n},r.featureEach=o,r.featureReduce=function(t,e,r){var n=r;return o(t,function(t,i){n=0===i&&void 0===r?t:e(n,t,i)}),n},r.coordAll=function(t){var e=[];return i(t,function(t){e.push(t)}),e},r.geomEach=s,r.geomReduce=function(t,e,r){var n=r;return s(t,function(t,i,a,o,s){n=0===i&&void 0===r?t:e(n,t,i,a,o,s)}),n},r.flattenEach=l,r.flattenReduce=function(t,e,r){var n=r;return l(t,function(t,i,a){n=0===i&&0===a&&void 0===r?t:e(n,t,i,a)}),n},r.segmentEach=c,r.segmentReduce=function(t,e,r){var n=r,i=!1;return c(t,function(t,a,o,s,l){n=!1===i&&void 0===r?t:e(n,t,a,o,s,l),i=!0}),n},r.lineEach=u,r.lineReduce=function(t,e,r){var n=r;return u(t,function(t,i,a,o){n=0===i&&void 0===r?t:e(n,t,i,a,o)}),n},r.findSegment=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.segmentIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":case\"MultiPoint\":return null;case\"LineString\":return s<0&&(s=c.length+s-1),n.lineString([c[s],c[s+1]],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s-1),n.lineString([c[o][s],c[o][s+1]],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s-1),n.lineString([c[a][s],c[a][s+1]],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s-1),n.lineString([c[a][o][s],c[a][o][s+1]],l,e)}throw new Error(\"geojson is invalid\")},r.findPoint=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.coordIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":return n.point(c,l,e);case\"MultiPoint\":return a<0&&(a=c.length+a),n.point(c[a],l,e);case\"LineString\":return s<0&&(s=c.length+s),n.point(c[s],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s),n.point(c[o][s],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s),n.point(c[a][s],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s),n.point(c[a][o][s],l,e)}throw new Error(\"geojson is invalid\")}},{\"@turf/helpers\":57}],59:[function(t,e,r){\"use strict\";var n=\"undefined\"==typeof WeakMap?t(\"weak-map\"):WeakMap,i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=new n;e.exports=function(t){var e=o.get(t),r=e&&(e._triangleBuffer.handle||e._triangleBuffer.buffer);if(!r||!t.isBuffer(r)){var n=i(t,new Float32Array([-1,-1,-1,4,4,-1]));(e=a(t,[{buffer:n,type:t.FLOAT,size:2}]))._triangleBuffer=n,o.set(t,e)}e.bind(),t.drawArrays(t.TRIANGLES,0,3),e.unbind()}},{\"gl-buffer\":241,\"gl-vao\":327,\"weak-map\":552}],60:[function(t,e,r){e.exports=function(t){var e=0,r=0,n=0,i=0;return t.map(function(t){var a=(t=t.slice())[0],o=a.toUpperCase();if(a!=o)switch(t[0]=o,a){case\"a\":t[6]+=n,t[7]+=i;break;case\"v\":t[1]+=i;break;case\"h\":t[1]+=n;break;default:for(var s=1;s<t.length;)t[s++]+=n,t[s++]+=i}switch(o){case\"Z\":n=e,i=r;break;case\"H\":n=t[1];break;case\"V\":i=t[1];break;case\"M\":n=e=t[1],i=r=t[2];break;default:n=t[t.length-2],i=t[t.length-1]}return t})}},{}],61:[function(t,e,r){var n=t(\"pad-left\");e.exports=function(t,e,r){e=\"number\"==typeof e?e:1,r=r||\": \";var i=t.split(/\\r?\\n/),a=String(i.length+e-1).length;return i.map(function(t,i){var o=i+e,s=String(o).length,l=n(o,a-s);return l+r+t}).join(\"\\n\")}},{\"pad-left\":457}],62:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[0];for(var r=t[0].length,n=[t[0]],a=[0],o=1;o<e;++o)if(n.push(t[o]),i(n,r)){if(a.push(o),a.length===r+1)return a}else n.pop();return a};var n=t(\"robust-orientation\");function i(t,e){for(var r=new Array(e+1),i=0;i<t.length;++i)r[i]=t[i];for(i=0;i<=t.length;++i){for(var a=t.length;a<=e;++a){for(var o=new Array(e),s=0;s<e;++s)o[s]=Math.pow(a+1-i,s);r[a]=o}if(n.apply(void 0,r))return!0}return!1}},{\"robust-orientation\":510}],63:[function(t,e,r){\"use strict\";e.exports=function(t,e){return n(e).filter(function(r){for(var n=new Array(r.length),a=0;a<r.length;++a)n[a]=e[r[a]];return i(n)*t<1})};var n=t(\"delaunay-triangulate\"),i=t(\"circumradius\")},{circumradius:114,\"delaunay-triangulate\":165}],64:[function(t,e,r){e.exports=function(t,e){return i(n(t,e))};var n=t(\"alpha-complex\"),i=t(\"simplicial-complex-boundary\")},{\"alpha-complex\":63,\"simplicial-complex-boundary\":517}],65:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(!t||null==t.length)throw Error(\"Argument should be an array\");e=null==e?1:Math.floor(e);for(var r=Array(2*e),n=0;n<e;n++){for(var i=-1/0,a=1/0,o=n,s=t.length;o<s;o+=e)t[o]>i&&(i=t[o]),t[o]<a&&(a=t[o]);r[n]=a,r[e+n]=i}return r}},{}],66:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\");e.exports=function(t,e,r){if(!t||null==t.length)throw Error(\"Argument should be an array\");null==e&&(e=1);null==r&&(r=n(t,e));for(var i=0;i<e;i++){var a=r[e+i],o=r[i],s=i,l=t.length;if(a===1/0&&o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:t[s]===o?0:.5;else if(a===1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:0;else if(o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===o?0:1;else{var c=a-o;for(s=i;s<l;s+=e)t[s]=0===c?.5:(t[s]-o)/c}}return t}},{\"array-bounds\":65}],67:[function(t,e,r){e.exports=function(t,e){var r=\"number\"==typeof t,n=\"number\"==typeof e;r&&!n?(e=t,t=0):r||n||(t=0,e=0);var i=(e|=0)-(t|=0);if(i<0)throw new Error(\"array length must be positive\");for(var a=new Array(i),o=0,s=t;o<i;o++,s++)a[o]=s;return a}},{}],68:[function(t,e,r){(function(r){\"use strict\";var n=t(\"object-assign\");function i(t,e){if(t===e)return 0;for(var r=t.length,n=e.length,i=0,a=Math.min(r,n);i<a;++i)if(t[i]!==e[i]){r=t[i],n=e[i];break}return r<n?-1:n<r?1:0}function a(t){return r.Buffer&&\"function\"==typeof r.Buffer.isBuffer?r.Buffer.isBuffer(t):!(null==t||!t._isBuffer)}var o=t(\"util/\"),s=Object.prototype.hasOwnProperty,l=Array.prototype.slice,c=\"foo\"===function(){}.name;function u(t){return Object.prototype.toString.call(t)}function h(t){return!a(t)&&(\"function\"==typeof r.ArrayBuffer&&(\"function\"==typeof ArrayBuffer.isView?ArrayBuffer.isView(t):!!t&&(t instanceof DataView||!!(t.buffer&&t.buffer instanceof ArrayBuffer))))}var f=e.exports=y,p=/\\s*function\\s+([^\\(\\s]*)\\s*/;function d(t){if(o.isFunction(t)){if(c)return t.name;var e=t.toString().match(p);return e&&e[1]}}function g(t,e){return\"string\"==typeof t?t.length<e?t:t.slice(0,e):t}function v(t){if(c||!o.isFunction(t))return o.inspect(t);var e=d(t);return\"[Function\"+(e?\": \"+e:\"\")+\"]\"}function m(t,e,r,n,i){throw new f.AssertionError({message:r,actual:t,expected:e,operator:n,stackStartFunction:i})}function y(t,e){t||m(t,!0,e,\"==\",f.ok)}function x(t,e,r,n){if(t===e)return!0;if(a(t)&&a(e))return 0===i(t,e);if(o.isDate(t)&&o.isDate(e))return t.getTime()===e.getTime();if(o.isRegExp(t)&&o.isRegExp(e))return t.source===e.source&&t.global===e.global&&t.multiline===e.multiline&&t.lastIndex===e.lastIndex&&t.ignoreCase===e.ignoreCase;if(null!==t&&\"object\"==typeof t||null!==e&&\"object\"==typeof e){if(h(t)&&h(e)&&u(t)===u(e)&&!(t instanceof Float32Array||t instanceof Float64Array))return 0===i(new Uint8Array(t.buffer),new Uint8Array(e.buffer));if(a(t)!==a(e))return!1;var s=(n=n||{actual:[],expected:[]}).actual.indexOf(t);return-1!==s&&s===n.expected.indexOf(e)||(n.actual.push(t),n.expected.push(e),function(t,e,r,n){if(null==t||null==e)return!1;if(o.isPrimitive(t)||o.isPrimitive(e))return t===e;if(r&&Object.getPrototypeOf(t)!==Object.getPrototypeOf(e))return!1;var i=b(t),a=b(e);if(i&&!a||!i&&a)return!1;if(i)return t=l.call(t),e=l.call(e),x(t,e,r);var s,c,u=k(t),h=k(e);if(u.length!==h.length)return!1;for(u.sort(),h.sort(),c=u.length-1;c>=0;c--)if(u[c]!==h[c])return!1;for(c=u.length-1;c>=0;c--)if(s=u[c],!x(t[s],e[s],r,n))return!1;return!0}(t,e,r,n))}return r?t===e:t==e}function b(t){return\"[object Arguments]\"==Object.prototype.toString.call(t)}function _(t,e){if(!t||!e)return!1;if(\"[object RegExp]\"==Object.prototype.toString.call(e))return e.test(t);try{if(t instanceof e)return!0}catch(t){}return!Error.isPrototypeOf(e)&&!0===e.call({},t)}function w(t,e,r,n){var i;if(\"function\"!=typeof e)throw new TypeError('\"block\" argument must be a function');\"string\"==typeof r&&(n=r,r=null),i=function(t){var e;try{t()}catch(t){e=t}return e}(e),n=(r&&r.name?\" (\"+r.name+\").\":\".\")+(n?\" \"+n:\".\"),t&&!i&&m(i,r,\"Missing expected exception\"+n);var a=\"string\"==typeof n,s=!t&&i&&!r;if((!t&&o.isError(i)&&a&&_(i,r)||s)&&m(i,r,\"Got unwanted exception\"+n),t&&i&&r&&!_(i,r)||!t&&i)throw i}f.AssertionError=function(t){var e;this.name=\"AssertionError\",this.actual=t.actual,this.expected=t.expected,this.operator=t.operator,t.message?(this.message=t.message,this.generatedMessage=!1):(this.message=g(v((e=this).actual),128)+\" \"+e.operator+\" \"+g(v(e.expected),128),this.generatedMessage=!0);var r=t.stackStartFunction||m;if(Error.captureStackTrace)Error.captureStackTrace(this,r);else{var n=new Error;if(n.stack){var i=n.stack,a=d(r),o=i.indexOf(\"\\n\"+a);if(o>=0){var s=i.indexOf(\"\\n\",o+1);i=i.substring(s+1)}this.stack=i}}},o.inherits(f.AssertionError,Error),f.fail=m,f.ok=y,f.equal=function(t,e,r){t!=e&&m(t,e,r,\"==\",f.equal)},f.notEqual=function(t,e,r){t==e&&m(t,e,r,\"!=\",f.notEqual)},f.deepEqual=function(t,e,r){x(t,e,!1)||m(t,e,r,\"deepEqual\",f.deepEqual)},f.deepStrictEqual=function(t,e,r){x(t,e,!0)||m(t,e,r,\"deepStrictEqual\",f.deepStrictEqual)},f.notDeepEqual=function(t,e,r){x(t,e,!1)&&m(t,e,r,\"notDeepEqual\",f.notDeepEqual)},f.notDeepStrictEqual=function t(e,r,n){x(e,r,!0)&&m(e,r,n,\"notDeepStrictEqual\",t)},f.strictEqual=function(t,e,r){t!==e&&m(t,e,r,\"===\",f.strictEqual)},f.notStrictEqual=function(t,e,r){t===e&&m(t,e,r,\"!==\",f.notStrictEqual)},f.throws=function(t,e,r){w(!0,t,e,r)},f.doesNotThrow=function(t,e,r){w(!1,t,e,r)},f.ifError=function(t){if(t)throw t},f.strict=n(function t(e,r){e||m(e,!0,r,\"==\",t)},f,{equal:f.strictEqual,deepEqual:f.deepStrictEqual,notEqual:f.notStrictEqual,notDeepEqual:f.notDeepStrictEqual}),f.strict.strict=f.strict;var k=Object.keys||function(t){var e=[];for(var r in t)s.call(t,r)&&e.push(r);return e}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"object-assign\":454,\"util/\":71}],69:[function(t,e,r){\"function\"==typeof Object.create?e.exports=function(t,e){t.super_=e,t.prototype=Object.create(e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}})}:e.exports=function(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}},{}],70:[function(t,e,r){e.exports=function(t){return t&&\"object\"==typeof t&&\"function\"==typeof t.copy&&\"function\"==typeof t.fill&&\"function\"==typeof t.readUInt8}},{}],71:[function(t,e,r){(function(e,n){var i=/%[sdj%]/g;r.format=function(t){if(!m(t)){for(var e=[],r=0;r<arguments.length;r++)e.push(s(arguments[r]));return e.join(\" \")}r=1;for(var n=arguments,a=n.length,o=String(t).replace(i,function(t){if(\"%%\"===t)return\"%\";if(r>=a)return t;switch(t){case\"%s\":return String(n[r++]);case\"%d\":return Number(n[r++]);case\"%j\":try{return JSON.stringify(n[r++])}catch(t){return\"[Circular]\"}default:return t}}),l=n[r];r<a;l=n[++r])g(l)||!b(l)?o+=\" \"+l:o+=\" \"+s(l);return o},r.deprecate=function(t,i){if(y(n.process))return function(){return r.deprecate(t,i).apply(this,arguments)};if(!0===e.noDeprecation)return t;var a=!1;return function(){if(!a){if(e.throwDeprecation)throw new Error(i);e.traceDeprecation?console.trace(i):console.error(i),a=!0}return t.apply(this,arguments)}};var a,o={};function s(t,e){var n={seen:[],stylize:c};return arguments.length>=3&&(n.depth=arguments[2]),arguments.length>=4&&(n.colors=arguments[3]),d(e)?n.showHidden=e:e&&r._extend(n,e),y(n.showHidden)&&(n.showHidden=!1),y(n.depth)&&(n.depth=2),y(n.colors)&&(n.colors=!1),y(n.customInspect)&&(n.customInspect=!0),n.colors&&(n.stylize=l),u(n,t,n.depth)}function l(t,e){var r=s.styles[e];return r?\"\\x1b[\"+s.colors[r][0]+\"m\"+t+\"\\x1b[\"+s.colors[r][1]+\"m\":t}function c(t,e){return t}function u(t,e,n){if(t.customInspect&&e&&k(e.inspect)&&e.inspect!==r.inspect&&(!e.constructor||e.constructor.prototype!==e)){var i=e.inspect(n,t);return m(i)||(i=u(t,i,n)),i}var a=function(t,e){if(y(e))return t.stylize(\"undefined\",\"undefined\");if(m(e)){var r=\"'\"+JSON.stringify(e).replace(/^\"|\"$/g,\"\").replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"')+\"'\";return t.stylize(r,\"string\")}if(v(e))return t.stylize(\"\"+e,\"number\");if(d(e))return t.stylize(\"\"+e,\"boolean\");if(g(e))return t.stylize(\"null\",\"null\")}(t,e);if(a)return a;var o=Object.keys(e),s=function(t){var e={};return t.forEach(function(t,r){e[t]=!0}),e}(o);if(t.showHidden&&(o=Object.getOwnPropertyNames(e)),w(e)&&(o.indexOf(\"message\")>=0||o.indexOf(\"description\")>=0))return h(e);if(0===o.length){if(k(e)){var l=e.name?\": \"+e.name:\"\";return t.stylize(\"[Function\"+l+\"]\",\"special\")}if(x(e))return t.stylize(RegExp.prototype.toString.call(e),\"regexp\");if(_(e))return t.stylize(Date.prototype.toString.call(e),\"date\");if(w(e))return h(e)}var c,b=\"\",T=!1,A=[\"{\",\"}\"];(p(e)&&(T=!0,A=[\"[\",\"]\"]),k(e))&&(b=\" [Function\"+(e.name?\": \"+e.name:\"\")+\"]\");return x(e)&&(b=\" \"+RegExp.prototype.toString.call(e)),_(e)&&(b=\" \"+Date.prototype.toUTCString.call(e)),w(e)&&(b=\" \"+h(e)),0!==o.length||T&&0!=e.length?n<0?x(e)?t.stylize(RegExp.prototype.toString.call(e),\"regexp\"):t.stylize(\"[Object]\",\"special\"):(t.seen.push(e),c=T?function(t,e,r,n,i){for(var a=[],o=0,s=e.length;o<s;++o)S(e,String(o))?a.push(f(t,e,r,n,String(o),!0)):a.push(\"\");return i.forEach(function(i){i.match(/^\\d+$/)||a.push(f(t,e,r,n,i,!0))}),a}(t,e,n,s,o):o.map(function(r){return f(t,e,n,s,r,T)}),t.seen.pop(),function(t,e,r){if(t.reduce(function(t,e){return 0,e.indexOf(\"\\n\")>=0&&0,t+e.replace(/\\u001b\\[\\d\\d?m/g,\"\").length+1},0)>60)return r[0]+(\"\"===e?\"\":e+\"\\n \")+\" \"+t.join(\",\\n  \")+\" \"+r[1];return r[0]+e+\" \"+t.join(\", \")+\" \"+r[1]}(c,b,A)):A[0]+b+A[1]}function h(t){return\"[\"+Error.prototype.toString.call(t)+\"]\"}function f(t,e,r,n,i,a){var o,s,l;if((l=Object.getOwnPropertyDescriptor(e,i)||{value:e[i]}).get?s=l.set?t.stylize(\"[Getter/Setter]\",\"special\"):t.stylize(\"[Getter]\",\"special\"):l.set&&(s=t.stylize(\"[Setter]\",\"special\")),S(n,i)||(o=\"[\"+i+\"]\"),s||(t.seen.indexOf(l.value)<0?(s=g(r)?u(t,l.value,null):u(t,l.value,r-1)).indexOf(\"\\n\")>-1&&(s=a?s.split(\"\\n\").map(function(t){return\"  \"+t}).join(\"\\n\").substr(2):\"\\n\"+s.split(\"\\n\").map(function(t){return\"   \"+t}).join(\"\\n\")):s=t.stylize(\"[Circular]\",\"special\")),y(o)){if(a&&i.match(/^\\d+$/))return s;(o=JSON.stringify(\"\"+i)).match(/^\"([a-zA-Z_][a-zA-Z_0-9]*)\"$/)?(o=o.substr(1,o.length-2),o=t.stylize(o,\"name\")):(o=o.replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"').replace(/(^\"|\"$)/g,\"'\"),o=t.stylize(o,\"string\"))}return o+\": \"+s}function p(t){return Array.isArray(t)}function d(t){return\"boolean\"==typeof t}function g(t){return null===t}function v(t){return\"number\"==typeof t}function m(t){return\"string\"==typeof t}function y(t){return void 0===t}function x(t){return b(t)&&\"[object RegExp]\"===T(t)}function b(t){return\"object\"==typeof t&&null!==t}function _(t){return b(t)&&\"[object Date]\"===T(t)}function w(t){return b(t)&&(\"[object Error]\"===T(t)||t instanceof Error)}function k(t){return\"function\"==typeof t}function T(t){return Object.prototype.toString.call(t)}function A(t){return t<10?\"0\"+t.toString(10):t.toString(10)}r.debuglog=function(t){if(y(a)&&(a=e.env.NODE_DEBUG||\"\"),t=t.toUpperCase(),!o[t])if(new RegExp(\"\\\\b\"+t+\"\\\\b\",\"i\").test(a)){var n=e.pid;o[t]=function(){var e=r.format.apply(r,arguments);console.error(\"%s %d: %s\",t,n,e)}}else o[t]=function(){};return o[t]},r.inspect=s,s.colors={bold:[1,22],italic:[3,23],underline:[4,24],inverse:[7,27],white:[37,39],grey:[90,39],black:[30,39],blue:[34,39],cyan:[36,39],green:[32,39],magenta:[35,39],red:[31,39],yellow:[33,39]},s.styles={special:\"cyan\",number:\"yellow\",boolean:\"yellow\",undefined:\"grey\",null:\"bold\",string:\"green\",date:\"magenta\",regexp:\"red\"},r.isArray=p,r.isBoolean=d,r.isNull=g,r.isNullOrUndefined=function(t){return null==t},r.isNumber=v,r.isString=m,r.isSymbol=function(t){return\"symbol\"==typeof t},r.isUndefined=y,r.isRegExp=x,r.isObject=b,r.isDate=_,r.isError=w,r.isFunction=k,r.isPrimitive=function(t){return null===t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||\"symbol\"==typeof t||\"undefined\"==typeof t},r.isBuffer=t(\"./support/isBuffer\");var M=[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"];function S(t,e){return Object.prototype.hasOwnProperty.call(t,e)}r.log=function(){var t,e;console.log(\"%s - %s\",(t=new Date,e=[A(t.getHours()),A(t.getMinutes()),A(t.getSeconds())].join(\":\"),[t.getDate(),M[t.getMonth()],e].join(\" \")),r.format.apply(r,arguments))},r.inherits=t(\"inherits\"),r._extend=function(t,e){if(!e||!b(e))return t;for(var r=Object.keys(e),n=r.length;n--;)t[r[n]]=e[r[n]];return t}}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./support/isBuffer\":70,_process:482,inherits:69}],72:[function(t,e,r){e.exports=function(t){return atob(t)}},{}],73:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=e.length,a=new Array(r+1),o=0;o<r;++o){for(var s=new Array(r+1),l=0;l<=r;++l)s[l]=t[l][o];a[o]=s}a[r]=new Array(r+1);for(var o=0;o<=r;++o)a[r][o]=1;for(var c=new Array(r+1),o=0;o<r;++o)c[o]=e[o];c[r]=1;var u=n(a,c),h=i(u[r+1]);0===h&&(h=1);for(var f=new Array(r+1),o=0;o<=r;++o)f[o]=i(u[o])/h;return f};var n=t(\"robust-linear-solve\");function i(t){for(var e=0,r=0;r<t.length;++r)e+=t[r];return e}},{\"robust-linear-solve\":509}],74:[function(t,e,r){\"use strict\";r.byteLength=function(t){var e=c(t),r=e[0],n=e[1];return 3*(r+n)/4-n},r.toByteArray=function(t){for(var e,r=c(t),n=r[0],o=r[1],s=new a(function(t,e,r){return 3*(e+r)/4-r}(0,n,o)),l=0,u=o>0?n-4:n,h=0;h<u;h+=4)e=i[t.charCodeAt(h)]<<18|i[t.charCodeAt(h+1)]<<12|i[t.charCodeAt(h+2)]<<6|i[t.charCodeAt(h+3)],s[l++]=e>>16&255,s[l++]=e>>8&255,s[l++]=255&e;2===o&&(e=i[t.charCodeAt(h)]<<2|i[t.charCodeAt(h+1)]>>4,s[l++]=255&e);1===o&&(e=i[t.charCodeAt(h)]<<10|i[t.charCodeAt(h+1)]<<4|i[t.charCodeAt(h+2)]>>2,s[l++]=e>>8&255,s[l++]=255&e);return s},r.fromByteArray=function(t){for(var e,r=t.length,i=r%3,a=[],o=0,s=r-i;o<s;o+=16383)a.push(u(t,o,o+16383>s?s:o+16383));1===i?(e=t[r-1],a.push(n[e>>2]+n[e<<4&63]+\"==\")):2===i&&(e=(t[r-2]<<8)+t[r-1],a.push(n[e>>10]+n[e>>4&63]+n[e<<2&63]+\"=\"));return a.join(\"\")};for(var n=[],i=[],a=\"undefined\"!=typeof Uint8Array?Uint8Array:Array,o=\"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/\",s=0,l=o.length;s<l;++s)n[s]=o[s],i[o.charCodeAt(s)]=s;function c(t){var e=t.length;if(e%4>0)throw new Error(\"Invalid string. Length must be a multiple of 4\");var r=t.indexOf(\"=\");return-1===r&&(r=e),[r,r===e?0:4-r%4]}function u(t,e,r){for(var i,a,o=[],s=e;s<r;s+=3)i=(t[s]<<16&16711680)+(t[s+1]<<8&65280)+(255&t[s+2]),o.push(n[(a=i)>>18&63]+n[a>>12&63]+n[a>>6&63]+n[63&a]);return o.join(\"\")}i[\"-\".charCodeAt(0)]=62,i[\"_\".charCodeAt(0)]=63},{}],75:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).add(e[0].mul(t[1])),t[1].mul(e[1]))}},{\"./lib/rationalize\":85}],76:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t[0].mul(e[1]).cmp(e[0].mul(t[1]))}},{}],77:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]),t[1].mul(e[0]))}},{\"./lib/rationalize\":85}],78:[function(t,e,r){\"use strict\";var n=t(\"./is-rat\"),i=t(\"./lib/is-bn\"),a=t(\"./lib/num-to-bn\"),o=t(\"./lib/str-to-bn\"),s=t(\"./lib/rationalize\"),l=t(\"./div\");e.exports=function t(e,r){if(n(e))return r?l(e,t(r)):[e[0].clone(),e[1].clone()];var c=0;var u,h;if(i(e))u=e.clone();else if(\"string\"==typeof e)u=o(e);else{if(0===e)return[a(0),a(1)];if(e===Math.floor(e))u=a(e);else{for(;e!==Math.floor(e);)e*=Math.pow(2,256),c-=256;u=a(e)}}if(n(r))u.mul(r[1]),h=r[0].clone();else if(i(r))h=r.clone();else if(\"string\"==typeof r)h=o(r);else if(r)if(r===Math.floor(r))h=a(r);else{for(;r!==Math.floor(r);)r*=Math.pow(2,256),c+=256;h=a(r)}else h=a(1);c>0?u=u.ushln(c):c<0&&(h=h.ushln(-c));return s(u,h)}},{\"./div\":77,\"./is-rat\":79,\"./lib/is-bn\":83,\"./lib/num-to-bn\":84,\"./lib/rationalize\":85,\"./lib/str-to-bn\":86}],79:[function(t,e,r){\"use strict\";var n=t(\"./lib/is-bn\");e.exports=function(t){return Array.isArray(t)&&2===t.length&&n(t[0])&&n(t[1])}},{\"./lib/is-bn\":83}],80:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return t.cmp(new n(0))}},{\"bn.js\":94}],81:[function(t,e,r){\"use strict\";var n=t(\"./bn-sign\");e.exports=function(t){var e=t.length,r=t.words,i=0;if(1===e)i=r[0];else if(2===e)i=r[0]+67108864*r[1];else for(var a=0;a<e;a++){var o=r[a];i+=o*Math.pow(67108864,a)}return n(t)*i}},{\"./bn-sign\":80}],82:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=t(\"bit-twiddle\").countTrailingZeros;e.exports=function(t){var e=i(n.lo(t));if(e<32)return e;var r=i(n.hi(t));if(r>20)return 52;return r+32}},{\"bit-twiddle\":92,\"double-bits\":167}],83:[function(t,e,r){\"use strict\";t(\"bn.js\");e.exports=function(t){return t&&\"object\"==typeof t&&Boolean(t.words)}},{\"bn.js\":94}],84:[function(t,e,r){\"use strict\";var n=t(\"bn.js\"),i=t(\"double-bits\");e.exports=function(t){var e=i.exponent(t);return e<52?new n(t):new n(t*Math.pow(2,52-e)).ushln(e-52)}},{\"bn.js\":94,\"double-bits\":167}],85:[function(t,e,r){\"use strict\";var n=t(\"./num-to-bn\"),i=t(\"./bn-sign\");e.exports=function(t,e){var r=i(t),a=i(e);if(0===r)return[n(0),n(1)];if(0===a)return[n(0),n(0)];a<0&&(t=t.neg(),e=e.neg());var o=t.gcd(e);if(o.cmpn(1))return[t.div(o),e.div(o)];return[t,e]}},{\"./bn-sign\":80,\"./num-to-bn\":84}],86:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return new n(t)}},{\"bn.js\":94}],87:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[0]),t[1].mul(e[1]))}},{\"./lib/rationalize\":85}],88:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-sign\");e.exports=function(t){return n(t[0])*n(t[1])}},{\"./lib/bn-sign\":80}],89:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).sub(t[1].mul(e[0])),t[1].mul(e[1]))}},{\"./lib/rationalize\":85}],90:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-to-num\"),i=t(\"./lib/ctz\");e.exports=function(t){var e=t[0],r=t[1];if(0===e.cmpn(0))return 0;var a=e.abs().divmod(r.abs()),o=a.div,s=n(o),l=a.mod,c=e.negative!==r.negative?-1:1;if(0===l.cmpn(0))return c*s;if(s){var u=i(s)+4,h=n(l.ushln(u).divRound(r));return c*(s+h*Math.pow(2,-u))}var f=r.bitLength()-l.bitLength()+53,h=n(l.ushln(f).divRound(r));return f<1023?c*h*Math.pow(2,-f):(h*=Math.pow(2,-1023),c*h*Math.pow(2,1023-f))}},{\"./lib/bn-to-num\":81,\"./lib/ctz\":82}],91:[function(t,e,r){\"use strict\";function n(t,e,r,n,i,a){var o=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",a?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a\",i?\".get(m)\":\"[m]\"];return a?e.indexOf(\"c\")<0?o.push(\";if(x===y){return m}else if(x<=y){\"):o.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):o.push(\";if(\",e,\"){i=m;\"),r?o.push(\"l=m+1}else{h=m-1}\"):o.push(\"h=m-1}else{l=m+1}\"),o.push(\"}\"),a?o.push(\"return -1};\"):o.push(\"return i};\"),o.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],!1,i),n(\"B\",\"x\"+t+\"y\",e,[\"y\"],!0,i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!1,i),n(\"Q\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!0,i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(a.shape){if(typeof(c)==='function'){return Q(a,(l===undefined)?0:l|0,(h===undefined)?a.shape[0]-1:h|0,y,c)}else{return B(a,(c===undefined)?0:c|0,(l===undefined)?a.shape[0]-1:l|0,y)}}else{if(typeof(c)==='function'){return P(a,(l===undefined)?0:l|0,(h===undefined)?a.length-1:h|0,y,c)}else{return A(a,(c===undefined)?0:c|0,(l===undefined)?a.length-1:l|0,y)}}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],92:[function(t,e,r){\"use strict\";function n(t){var e=32;return(t&=-t)&&e--,65535&t&&(e-=16),16711935&t&&(e-=8),252645135&t&&(e-=4),858993459&t&&(e-=2),1431655765&t&&(e-=1),e}r.INT_BITS=32,r.INT_MAX=2147483647,r.INT_MIN=-1<<31,r.sign=function(t){return(t>0)-(t<0)},r.abs=function(t){var e=t>>31;return(t^e)-e},r.min=function(t,e){return e^(t^e)&-(t<e)},r.max=function(t,e){return t^(t^e)&-(t<e)},r.isPow2=function(t){return!(t&t-1||!t)},r.log2=function(t){var e,r;return e=(t>65535)<<4,e|=r=((t>>>=e)>255)<<3,e|=r=((t>>>=r)>15)<<2,(e|=r=((t>>>=r)>3)<<1)|(t>>>=r)>>1},r.log10=function(t){return t>=1e9?9:t>=1e8?8:t>=1e7?7:t>=1e6?6:t>=1e5?5:t>=1e4?4:t>=1e3?3:t>=100?2:t>=10?1:0},r.popCount=function(t){return 16843009*((t=(858993459&(t-=t>>>1&1431655765))+(t>>>2&858993459))+(t>>>4)&252645135)>>>24},r.countTrailingZeros=n,r.nextPow2=function(t){return t+=0===t,--t,t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)+1},r.prevPow2=function(t){return t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)-(t>>>1)},r.parity=function(t){return t^=t>>>16,t^=t>>>8,t^=t>>>4,27030>>>(t&=15)&1};var i=new Array(256);!function(t){for(var e=0;e<256;++e){var r=e,n=e,i=7;for(r>>>=1;r;r>>>=1)n<<=1,n|=1&r,--i;t[e]=n<<i&255}}(i),r.reverse=function(t){return i[255&t]<<24|i[t>>>8&255]<<16|i[t>>>16&255]<<8|i[t>>>24&255]},r.interleave2=function(t,e){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t&=65535)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e&=65535)|e<<8))|e<<4))|e<<2))|e<<1))<<1},r.deinterleave2=function(t,e){return(t=65535&((t=16711935&((t=252645135&((t=858993459&((t=t>>>e&1431655765)|t>>>1))|t>>>2))|t>>>4))|t>>>16))<<16>>16},r.interleave3=function(t,e,r){return t=1227133513&((t=3272356035&((t=251719695&((t=4278190335&((t&=1023)|t<<16))|t<<8))|t<<4))|t<<2),(t|=(e=1227133513&((e=3272356035&((e=251719695&((e=4278190335&((e&=1023)|e<<16))|e<<8))|e<<4))|e<<2))<<1)|(r=1227133513&((r=3272356035&((r=251719695&((r=4278190335&((r&=1023)|r<<16))|r<<8))|r<<4))|r<<2))<<2},r.deinterleave3=function(t,e){return(t=1023&((t=4278190335&((t=251719695&((t=3272356035&((t=t>>>e&1227133513)|t>>>2))|t>>>4))|t>>>8))|t>>>16))<<22>>22},r.nextCombination=function(t){var e=t|t-1;return e+1|(~e&-~e)-1>>>n(t)+1}},{}],93:[function(t,e,r){\"use strict\";var n=t(\"clamp\");e.exports=function(t,e){e||(e={});var r,o,s,l,c,u,h,f,p,d,g,v=null==e.cutoff?.25:e.cutoff,m=null==e.radius?8:e.radius,y=e.channel||0;if(ArrayBuffer.isView(t)||Array.isArray(t)){if(!e.width||!e.height)throw Error(\"For raw data width and height should be provided by options\");r=e.width,o=e.height,l=t,u=e.stride?e.stride:Math.floor(t.length/r/o)}else window.HTMLCanvasElement&&t instanceof window.HTMLCanvasElement?(h=(f=t).getContext(\"2d\"),r=f.width,o=f.height,p=h.getImageData(0,0,r,o),l=p.data,u=4):window.CanvasRenderingContext2D&&t instanceof window.CanvasRenderingContext2D?(f=t.canvas,h=t,r=f.width,o=f.height,p=h.getImageData(0,0,r,o),l=p.data,u=4):window.ImageData&&t instanceof window.ImageData&&(p=t,r=t.width,o=t.height,l=p.data,u=4);if(s=Math.max(r,o),window.Uint8ClampedArray&&l instanceof window.Uint8ClampedArray||window.Uint8Array&&l instanceof window.Uint8Array)for(c=l,l=Array(r*o),d=0,g=c.length;d<g;d++)l[d]=c[d*u+y]/255;else if(1!==u)throw Error(\"Raw data can have only 1 value per pixel\");var x=Array(r*o),b=Array(r*o),_=Array(s),w=Array(s),k=Array(s+1),T=Array(s);for(d=0,g=r*o;d<g;d++){var A=l[d];x[d]=1===A?0:0===A?i:Math.pow(Math.max(0,.5-A),2),b[d]=1===A?i:0===A?0:Math.pow(Math.max(0,A-.5),2)}a(x,r,o,_,w,T,k),a(b,r,o,_,w,T,k);var M=window.Float32Array?new Float32Array(r*o):new Array(r*o);for(d=0,g=r*o;d<g;d++)M[d]=n(1-((x[d]-b[d])/m+v),0,1);return M};var i=1e20;function a(t,e,r,n,i,a,s){for(var l=0;l<e;l++){for(var c=0;c<r;c++)n[c]=t[c*e+l];for(o(n,i,a,s,r),c=0;c<r;c++)t[c*e+l]=i[c]}for(c=0;c<r;c++){for(l=0;l<e;l++)n[l]=t[c*e+l];for(o(n,i,a,s,e),l=0;l<e;l++)t[c*e+l]=Math.sqrt(i[l])}}function o(t,e,r,n,a){r[0]=0,n[0]=-i,n[1]=+i;for(var o=1,s=0;o<a;o++){for(var l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);l<=n[s];)s--,l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);r[++s]=o,n[s]=l,n[s+1]=+i}for(o=0,s=0;o<a;o++){for(;n[s+1]<o;)s++;e[o]=(o-r[s])*(o-r[s])+t[r[s]]}}},{clamp:115}],94:[function(t,e,r){!function(e,r){\"use strict\";function n(t,e){if(!t)throw new Error(e||\"Assertion failed\")}function i(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}function a(t,e,r){if(a.isBN(t))return t;this.negative=0,this.words=null,this.length=0,this.red=null,null!==t&&(\"le\"!==e&&\"be\"!==e||(r=e,e=10),this._init(t||0,e||10,r||\"be\"))}var o;\"object\"==typeof e?e.exports=a:r.BN=a,a.BN=a,a.wordSize=26;try{o=t(\"buffer\").Buffer}catch(t){}function s(t,e,r){for(var n=0,i=Math.min(t.length,r),a=e;a<i;a++){var o=t.charCodeAt(a)-48;n<<=4,n|=o>=49&&o<=54?o-49+10:o>=17&&o<=22?o-17+10:15&o}return n}function l(t,e,r,n){for(var i=0,a=Math.min(t.length,r),o=e;o<a;o++){var s=t.charCodeAt(o)-48;i*=n,i+=s>=49?s-49+10:s>=17?s-17+10:s}return i}a.isBN=function(t){return t instanceof a||null!==t&&\"object\"==typeof t&&t.constructor.wordSize===a.wordSize&&Array.isArray(t.words)},a.max=function(t,e){return t.cmp(e)>0?t:e},a.min=function(t,e){return t.cmp(e)<0?t:e},a.prototype._init=function(t,e,r){if(\"number\"==typeof t)return this._initNumber(t,e,r);if(\"object\"==typeof t)return this._initArray(t,e,r);\"hex\"===e&&(e=16),n(e===(0|e)&&e>=2&&e<=36);var i=0;\"-\"===(t=t.toString().replace(/\\s+/g,\"\"))[0]&&i++,16===e?this._parseHex(t,i):this._parseBase(t,e,i),\"-\"===t[0]&&(this.negative=1),this.strip(),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initNumber=function(t,e,r){t<0&&(this.negative=1,t=-t),t<67108864?(this.words=[67108863&t],this.length=1):t<4503599627370496?(this.words=[67108863&t,t/67108864&67108863],this.length=2):(n(t<9007199254740992),this.words=[67108863&t,t/67108864&67108863,1],this.length=3),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initArray=function(t,e,r){if(n(\"number\"==typeof t.length),t.length<=0)return this.words=[0],this.length=1,this;this.length=Math.ceil(t.length/3),this.words=new Array(this.length);for(var i=0;i<this.length;i++)this.words[i]=0;var a,o,s=0;if(\"be\"===r)for(i=t.length-1,a=0;i>=0;i-=3)o=t[i]|t[i-1]<<8|t[i-2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);else if(\"le\"===r)for(i=0,a=0;i<t.length;i+=3)o=t[i]|t[i+1]<<8|t[i+2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);return this.strip()},a.prototype._parseHex=function(t,e){this.length=Math.ceil((t.length-e)/6),this.words=new Array(this.length);for(var r=0;r<this.length;r++)this.words[r]=0;var n,i,a=0;for(r=t.length-6,n=0;r>=e;r-=6)i=s(t,r,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303,(a+=24)>=26&&(a-=26,n++);r+6!==e&&(i=s(t,e,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303),this.strip()},a.prototype._parseBase=function(t,e,r){this.words=[0],this.length=1;for(var n=0,i=1;i<=67108863;i*=e)n++;n--,i=i/e|0;for(var a=t.length-r,o=a%n,s=Math.min(a,a-o)+r,c=0,u=r;u<s;u+=n)c=l(t,u,u+n,e),this.imuln(i),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c);if(0!==o){var h=1;for(c=l(t,u,t.length,e),u=0;u<o;u++)h*=e;this.imuln(h),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c)}},a.prototype.copy=function(t){t.words=new Array(this.length);for(var e=0;e<this.length;e++)t.words[e]=this.words[e];t.length=this.length,t.negative=this.negative,t.red=this.red},a.prototype.clone=function(){var t=new a(null);return this.copy(t),t},a.prototype._expand=function(t){for(;this.length<t;)this.words[this.length++]=0;return this},a.prototype.strip=function(){for(;this.length>1&&0===this.words[this.length-1];)this.length--;return this._normSign()},a.prototype._normSign=function(){return 1===this.length&&0===this.words[0]&&(this.negative=0),this},a.prototype.inspect=function(){return(this.red?\"<BN-R: \":\"<BN: \")+this.toString(16)+\">\"};var c=[\"\",\"0\",\"00\",\"000\",\"0000\",\"00000\",\"000000\",\"0000000\",\"00000000\",\"000000000\",\"0000000000\",\"00000000000\",\"000000000000\",\"0000000000000\",\"00000000000000\",\"000000000000000\",\"0000000000000000\",\"00000000000000000\",\"000000000000000000\",\"0000000000000000000\",\"00000000000000000000\",\"000000000000000000000\",\"0000000000000000000000\",\"00000000000000000000000\",\"000000000000000000000000\",\"0000000000000000000000000\"],u=[0,0,25,16,12,11,10,9,8,8,7,7,7,7,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5],h=[0,0,33554432,43046721,16777216,48828125,60466176,40353607,16777216,43046721,1e7,19487171,35831808,62748517,7529536,11390625,16777216,24137569,34012224,47045881,64e6,4084101,5153632,6436343,7962624,9765625,11881376,14348907,17210368,20511149,243e5,28629151,33554432,39135393,45435424,52521875,60466176];function f(t,e,r){r.negative=e.negative^t.negative;var n=t.length+e.length|0;r.length=n,n=n-1|0;var i=0|t.words[0],a=0|e.words[0],o=i*a,s=67108863&o,l=o/67108864|0;r.words[0]=s;for(var c=1;c<n;c++){for(var u=l>>>26,h=67108863&l,f=Math.min(c,e.length-1),p=Math.max(0,c-t.length+1);p<=f;p++){var d=c-p|0;u+=(o=(i=0|t.words[d])*(a=0|e.words[p])+h)/67108864|0,h=67108863&o}r.words[c]=0|h,l=0|u}return 0!==l?r.words[c]=0|l:r.length--,r.strip()}a.prototype.toString=function(t,e){var r;if(e=0|e||1,16===(t=t||10)||\"hex\"===t){r=\"\";for(var i=0,a=0,o=0;o<this.length;o++){var s=this.words[o],l=(16777215&(s<<i|a)).toString(16);r=0!==(a=s>>>24-i&16777215)||o!==this.length-1?c[6-l.length]+l+r:l+r,(i+=2)>=26&&(i-=26,o--)}for(0!==a&&(r=a.toString(16)+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}if(t===(0|t)&&t>=2&&t<=36){var f=u[t],p=h[t];r=\"\";var d=this.clone();for(d.negative=0;!d.isZero();){var g=d.modn(p).toString(t);r=(d=d.idivn(p)).isZero()?g+r:c[f-g.length]+g+r}for(this.isZero()&&(r=\"0\"+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}n(!1,\"Base should be between 2 and 36\")},a.prototype.toNumber=function(){var t=this.words[0];return 2===this.length?t+=67108864*this.words[1]:3===this.length&&1===this.words[2]?t+=4503599627370496+67108864*this.words[1]:this.length>2&&n(!1,\"Number can only safely store up to 53 bits\"),0!==this.negative?-t:t},a.prototype.toJSON=function(){return this.toString(16)},a.prototype.toBuffer=function(t,e){return n(\"undefined\"!=typeof o),this.toArrayLike(o,t,e)},a.prototype.toArray=function(t,e){return this.toArrayLike(Array,t,e)},a.prototype.toArrayLike=function(t,e,r){var i=this.byteLength(),a=r||Math.max(1,i);n(i<=a,\"byte array longer than desired length\"),n(a>0,\"Requested array length <= 0\"),this.strip();var o,s,l=\"le\"===e,c=new t(a),u=this.clone();if(l){for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[s]=o;for(;s<a;s++)c[s]=0}else{for(s=0;s<a-i;s++)c[s]=0;for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[a-s-1]=o}return c},Math.clz32?a.prototype._countBits=function(t){return 32-Math.clz32(t)}:a.prototype._countBits=function(t){var e=t,r=0;return e>=4096&&(r+=13,e>>>=13),e>=64&&(r+=7,e>>>=7),e>=8&&(r+=4,e>>>=4),e>=2&&(r+=2,e>>>=2),r+e},a.prototype._zeroBits=function(t){if(0===t)return 26;var e=t,r=0;return 0==(8191&e)&&(r+=13,e>>>=13),0==(127&e)&&(r+=7,e>>>=7),0==(15&e)&&(r+=4,e>>>=4),0==(3&e)&&(r+=2,e>>>=2),0==(1&e)&&r++,r},a.prototype.bitLength=function(){var t=this.words[this.length-1],e=this._countBits(t);return 26*(this.length-1)+e},a.prototype.zeroBits=function(){if(this.isZero())return 0;for(var t=0,e=0;e<this.length;e++){var r=this._zeroBits(this.words[e]);if(t+=r,26!==r)break}return t},a.prototype.byteLength=function(){return Math.ceil(this.bitLength()/8)},a.prototype.toTwos=function(t){return 0!==this.negative?this.abs().inotn(t).iaddn(1):this.clone()},a.prototype.fromTwos=function(t){return this.testn(t-1)?this.notn(t).iaddn(1).ineg():this.clone()},a.prototype.isNeg=function(){return 0!==this.negative},a.prototype.neg=function(){return this.clone().ineg()},a.prototype.ineg=function(){return this.isZero()||(this.negative^=1),this},a.prototype.iuor=function(t){for(;this.length<t.length;)this.words[this.length++]=0;for(var e=0;e<t.length;e++)this.words[e]=this.words[e]|t.words[e];return this.strip()},a.prototype.ior=function(t){return n(0==(this.negative|t.negative)),this.iuor(t)},a.prototype.or=function(t){return this.length>t.length?this.clone().ior(t):t.clone().ior(this)},a.prototype.uor=function(t){return this.length>t.length?this.clone().iuor(t):t.clone().iuor(this)},a.prototype.iuand=function(t){var e;e=this.length>t.length?t:this;for(var r=0;r<e.length;r++)this.words[r]=this.words[r]&t.words[r];return this.length=e.length,this.strip()},a.prototype.iand=function(t){return n(0==(this.negative|t.negative)),this.iuand(t)},a.prototype.and=function(t){return this.length>t.length?this.clone().iand(t):t.clone().iand(this)},a.prototype.uand=function(t){return this.length>t.length?this.clone().iuand(t):t.clone().iuand(this)},a.prototype.iuxor=function(t){var e,r;this.length>t.length?(e=this,r=t):(e=t,r=this);for(var n=0;n<r.length;n++)this.words[n]=e.words[n]^r.words[n];if(this!==e)for(;n<e.length;n++)this.words[n]=e.words[n];return this.length=e.length,this.strip()},a.prototype.ixor=function(t){return n(0==(this.negative|t.negative)),this.iuxor(t)},a.prototype.xor=function(t){return this.length>t.length?this.clone().ixor(t):t.clone().ixor(this)},a.prototype.uxor=function(t){return this.length>t.length?this.clone().iuxor(t):t.clone().iuxor(this)},a.prototype.inotn=function(t){n(\"number\"==typeof t&&t>=0);var e=0|Math.ceil(t/26),r=t%26;this._expand(e),r>0&&e--;for(var i=0;i<e;i++)this.words[i]=67108863&~this.words[i];return r>0&&(this.words[i]=~this.words[i]&67108863>>26-r),this.strip()},a.prototype.notn=function(t){return this.clone().inotn(t)},a.prototype.setn=function(t,e){n(\"number\"==typeof t&&t>=0);var r=t/26|0,i=t%26;return this._expand(r+1),this.words[r]=e?this.words[r]|1<<i:this.words[r]&~(1<<i),this.strip()},a.prototype.iadd=function(t){var e,r,n;if(0!==this.negative&&0===t.negative)return this.negative=0,e=this.isub(t),this.negative^=1,this._normSign();if(0===this.negative&&0!==t.negative)return t.negative=0,e=this.isub(t),t.negative=1,e._normSign();this.length>t.length?(r=this,n=t):(r=t,n=this);for(var i=0,a=0;a<n.length;a++)e=(0|r.words[a])+(0|n.words[a])+i,this.words[a]=67108863&e,i=e>>>26;for(;0!==i&&a<r.length;a++)e=(0|r.words[a])+i,this.words[a]=67108863&e,i=e>>>26;if(this.length=r.length,0!==i)this.words[this.length]=i,this.length++;else if(r!==this)for(;a<r.length;a++)this.words[a]=r.words[a];return this},a.prototype.add=function(t){var e;return 0!==t.negative&&0===this.negative?(t.negative=0,e=this.sub(t),t.negative^=1,e):0===t.negative&&0!==this.negative?(this.negative=0,e=t.sub(this),this.negative=1,e):this.length>t.length?this.clone().iadd(t):t.clone().iadd(this)},a.prototype.isub=function(t){if(0!==t.negative){t.negative=0;var e=this.iadd(t);return t.negative=1,e._normSign()}if(0!==this.negative)return this.negative=0,this.iadd(t),this.negative=1,this._normSign();var r,n,i=this.cmp(t);if(0===i)return this.negative=0,this.length=1,this.words[0]=0,this;i>0?(r=this,n=t):(r=t,n=this);for(var a=0,o=0;o<n.length;o++)a=(e=(0|r.words[o])-(0|n.words[o])+a)>>26,this.words[o]=67108863&e;for(;0!==a&&o<r.length;o++)a=(e=(0|r.words[o])+a)>>26,this.words[o]=67108863&e;if(0===a&&o<r.length&&r!==this)for(;o<r.length;o++)this.words[o]=r.words[o];return this.length=Math.max(this.length,o),r!==this&&(this.negative=1),this.strip()},a.prototype.sub=function(t){return this.clone().isub(t)};var p=function(t,e,r){var n,i,a,o=t.words,s=e.words,l=r.words,c=0,u=0|o[0],h=8191&u,f=u>>>13,p=0|o[1],d=8191&p,g=p>>>13,v=0|o[2],m=8191&v,y=v>>>13,x=0|o[3],b=8191&x,_=x>>>13,w=0|o[4],k=8191&w,T=w>>>13,A=0|o[5],M=8191&A,S=A>>>13,E=0|o[6],C=8191&E,L=E>>>13,P=0|o[7],O=8191&P,z=P>>>13,I=0|o[8],D=8191&I,R=I>>>13,F=0|o[9],B=8191&F,N=F>>>13,j=0|s[0],U=8191&j,V=j>>>13,q=0|s[1],H=8191&q,G=q>>>13,Y=0|s[2],W=8191&Y,X=Y>>>13,Z=0|s[3],J=8191&Z,K=Z>>>13,$=0|s[4],Q=8191&$,tt=$>>>13,et=0|s[5],rt=8191&et,nt=et>>>13,it=0|s[6],at=8191&it,ot=it>>>13,st=0|s[7],lt=8191&st,ct=st>>>13,ut=0|s[8],ht=8191&ut,ft=ut>>>13,pt=0|s[9],dt=8191&pt,gt=pt>>>13;r.negative=t.negative^e.negative,r.length=19;var vt=(c+(n=Math.imul(h,U))|0)+((8191&(i=(i=Math.imul(h,V))+Math.imul(f,U)|0))<<13)|0;c=((a=Math.imul(f,V))+(i>>>13)|0)+(vt>>>26)|0,vt&=67108863,n=Math.imul(d,U),i=(i=Math.imul(d,V))+Math.imul(g,U)|0,a=Math.imul(g,V);var mt=(c+(n=n+Math.imul(h,H)|0)|0)+((8191&(i=(i=i+Math.imul(h,G)|0)+Math.imul(f,H)|0))<<13)|0;c=((a=a+Math.imul(f,G)|0)+(i>>>13)|0)+(mt>>>26)|0,mt&=67108863,n=Math.imul(m,U),i=(i=Math.imul(m,V))+Math.imul(y,U)|0,a=Math.imul(y,V),n=n+Math.imul(d,H)|0,i=(i=i+Math.imul(d,G)|0)+Math.imul(g,H)|0,a=a+Math.imul(g,G)|0;var yt=(c+(n=n+Math.imul(h,W)|0)|0)+((8191&(i=(i=i+Math.imul(h,X)|0)+Math.imul(f,W)|0))<<13)|0;c=((a=a+Math.imul(f,X)|0)+(i>>>13)|0)+(yt>>>26)|0,yt&=67108863,n=Math.imul(b,U),i=(i=Math.imul(b,V))+Math.imul(_,U)|0,a=Math.imul(_,V),n=n+Math.imul(m,H)|0,i=(i=i+Math.imul(m,G)|0)+Math.imul(y,H)|0,a=a+Math.imul(y,G)|0,n=n+Math.imul(d,W)|0,i=(i=i+Math.imul(d,X)|0)+Math.imul(g,W)|0,a=a+Math.imul(g,X)|0;var xt=(c+(n=n+Math.imul(h,J)|0)|0)+((8191&(i=(i=i+Math.imul(h,K)|0)+Math.imul(f,J)|0))<<13)|0;c=((a=a+Math.imul(f,K)|0)+(i>>>13)|0)+(xt>>>26)|0,xt&=67108863,n=Math.imul(k,U),i=(i=Math.imul(k,V))+Math.imul(T,U)|0,a=Math.imul(T,V),n=n+Math.imul(b,H)|0,i=(i=i+Math.imul(b,G)|0)+Math.imul(_,H)|0,a=a+Math.imul(_,G)|0,n=n+Math.imul(m,W)|0,i=(i=i+Math.imul(m,X)|0)+Math.imul(y,W)|0,a=a+Math.imul(y,X)|0,n=n+Math.imul(d,J)|0,i=(i=i+Math.imul(d,K)|0)+Math.imul(g,J)|0,a=a+Math.imul(g,K)|0;var bt=(c+(n=n+Math.imul(h,Q)|0)|0)+((8191&(i=(i=i+Math.imul(h,tt)|0)+Math.imul(f,Q)|0))<<13)|0;c=((a=a+Math.imul(f,tt)|0)+(i>>>13)|0)+(bt>>>26)|0,bt&=67108863,n=Math.imul(M,U),i=(i=Math.imul(M,V))+Math.imul(S,U)|0,a=Math.imul(S,V),n=n+Math.imul(k,H)|0,i=(i=i+Math.imul(k,G)|0)+Math.imul(T,H)|0,a=a+Math.imul(T,G)|0,n=n+Math.imul(b,W)|0,i=(i=i+Math.imul(b,X)|0)+Math.imul(_,W)|0,a=a+Math.imul(_,X)|0,n=n+Math.imul(m,J)|0,i=(i=i+Math.imul(m,K)|0)+Math.imul(y,J)|0,a=a+Math.imul(y,K)|0,n=n+Math.imul(d,Q)|0,i=(i=i+Math.imul(d,tt)|0)+Math.imul(g,Q)|0,a=a+Math.imul(g,tt)|0;var _t=(c+(n=n+Math.imul(h,rt)|0)|0)+((8191&(i=(i=i+Math.imul(h,nt)|0)+Math.imul(f,rt)|0))<<13)|0;c=((a=a+Math.imul(f,nt)|0)+(i>>>13)|0)+(_t>>>26)|0,_t&=67108863,n=Math.imul(C,U),i=(i=Math.imul(C,V))+Math.imul(L,U)|0,a=Math.imul(L,V),n=n+Math.imul(M,H)|0,i=(i=i+Math.imul(M,G)|0)+Math.imul(S,H)|0,a=a+Math.imul(S,G)|0,n=n+Math.imul(k,W)|0,i=(i=i+Math.imul(k,X)|0)+Math.imul(T,W)|0,a=a+Math.imul(T,X)|0,n=n+Math.imul(b,J)|0,i=(i=i+Math.imul(b,K)|0)+Math.imul(_,J)|0,a=a+Math.imul(_,K)|0,n=n+Math.imul(m,Q)|0,i=(i=i+Math.imul(m,tt)|0)+Math.imul(y,Q)|0,a=a+Math.imul(y,tt)|0,n=n+Math.imul(d,rt)|0,i=(i=i+Math.imul(d,nt)|0)+Math.imul(g,rt)|0,a=a+Math.imul(g,nt)|0;var wt=(c+(n=n+Math.imul(h,at)|0)|0)+((8191&(i=(i=i+Math.imul(h,ot)|0)+Math.imul(f,at)|0))<<13)|0;c=((a=a+Math.imul(f,ot)|0)+(i>>>13)|0)+(wt>>>26)|0,wt&=67108863,n=Math.imul(O,U),i=(i=Math.imul(O,V))+Math.imul(z,U)|0,a=Math.imul(z,V),n=n+Math.imul(C,H)|0,i=(i=i+Math.imul(C,G)|0)+Math.imul(L,H)|0,a=a+Math.imul(L,G)|0,n=n+Math.imul(M,W)|0,i=(i=i+Math.imul(M,X)|0)+Math.imul(S,W)|0,a=a+Math.imul(S,X)|0,n=n+Math.imul(k,J)|0,i=(i=i+Math.imul(k,K)|0)+Math.imul(T,J)|0,a=a+Math.imul(T,K)|0,n=n+Math.imul(b,Q)|0,i=(i=i+Math.imul(b,tt)|0)+Math.imul(_,Q)|0,a=a+Math.imul(_,tt)|0,n=n+Math.imul(m,rt)|0,i=(i=i+Math.imul(m,nt)|0)+Math.imul(y,rt)|0,a=a+Math.imul(y,nt)|0,n=n+Math.imul(d,at)|0,i=(i=i+Math.imul(d,ot)|0)+Math.imul(g,at)|0,a=a+Math.imul(g,ot)|0;var kt=(c+(n=n+Math.imul(h,lt)|0)|0)+((8191&(i=(i=i+Math.imul(h,ct)|0)+Math.imul(f,lt)|0))<<13)|0;c=((a=a+Math.imul(f,ct)|0)+(i>>>13)|0)+(kt>>>26)|0,kt&=67108863,n=Math.imul(D,U),i=(i=Math.imul(D,V))+Math.imul(R,U)|0,a=Math.imul(R,V),n=n+Math.imul(O,H)|0,i=(i=i+Math.imul(O,G)|0)+Math.imul(z,H)|0,a=a+Math.imul(z,G)|0,n=n+Math.imul(C,W)|0,i=(i=i+Math.imul(C,X)|0)+Math.imul(L,W)|0,a=a+Math.imul(L,X)|0,n=n+Math.imul(M,J)|0,i=(i=i+Math.imul(M,K)|0)+Math.imul(S,J)|0,a=a+Math.imul(S,K)|0,n=n+Math.imul(k,Q)|0,i=(i=i+Math.imul(k,tt)|0)+Math.imul(T,Q)|0,a=a+Math.imul(T,tt)|0,n=n+Math.imul(b,rt)|0,i=(i=i+Math.imul(b,nt)|0)+Math.imul(_,rt)|0,a=a+Math.imul(_,nt)|0,n=n+Math.imul(m,at)|0,i=(i=i+Math.imul(m,ot)|0)+Math.imul(y,at)|0,a=a+Math.imul(y,ot)|0,n=n+Math.imul(d,lt)|0,i=(i=i+Math.imul(d,ct)|0)+Math.imul(g,lt)|0,a=a+Math.imul(g,ct)|0;var Tt=(c+(n=n+Math.imul(h,ht)|0)|0)+((8191&(i=(i=i+Math.imul(h,ft)|0)+Math.imul(f,ht)|0))<<13)|0;c=((a=a+Math.imul(f,ft)|0)+(i>>>13)|0)+(Tt>>>26)|0,Tt&=67108863,n=Math.imul(B,U),i=(i=Math.imul(B,V))+Math.imul(N,U)|0,a=Math.imul(N,V),n=n+Math.imul(D,H)|0,i=(i=i+Math.imul(D,G)|0)+Math.imul(R,H)|0,a=a+Math.imul(R,G)|0,n=n+Math.imul(O,W)|0,i=(i=i+Math.imul(O,X)|0)+Math.imul(z,W)|0,a=a+Math.imul(z,X)|0,n=n+Math.imul(C,J)|0,i=(i=i+Math.imul(C,K)|0)+Math.imul(L,J)|0,a=a+Math.imul(L,K)|0,n=n+Math.imul(M,Q)|0,i=(i=i+Math.imul(M,tt)|0)+Math.imul(S,Q)|0,a=a+Math.imul(S,tt)|0,n=n+Math.imul(k,rt)|0,i=(i=i+Math.imul(k,nt)|0)+Math.imul(T,rt)|0,a=a+Math.imul(T,nt)|0,n=n+Math.imul(b,at)|0,i=(i=i+Math.imul(b,ot)|0)+Math.imul(_,at)|0,a=a+Math.imul(_,ot)|0,n=n+Math.imul(m,lt)|0,i=(i=i+Math.imul(m,ct)|0)+Math.imul(y,lt)|0,a=a+Math.imul(y,ct)|0,n=n+Math.imul(d,ht)|0,i=(i=i+Math.imul(d,ft)|0)+Math.imul(g,ht)|0,a=a+Math.imul(g,ft)|0;var At=(c+(n=n+Math.imul(h,dt)|0)|0)+((8191&(i=(i=i+Math.imul(h,gt)|0)+Math.imul(f,dt)|0))<<13)|0;c=((a=a+Math.imul(f,gt)|0)+(i>>>13)|0)+(At>>>26)|0,At&=67108863,n=Math.imul(B,H),i=(i=Math.imul(B,G))+Math.imul(N,H)|0,a=Math.imul(N,G),n=n+Math.imul(D,W)|0,i=(i=i+Math.imul(D,X)|0)+Math.imul(R,W)|0,a=a+Math.imul(R,X)|0,n=n+Math.imul(O,J)|0,i=(i=i+Math.imul(O,K)|0)+Math.imul(z,J)|0,a=a+Math.imul(z,K)|0,n=n+Math.imul(C,Q)|0,i=(i=i+Math.imul(C,tt)|0)+Math.imul(L,Q)|0,a=a+Math.imul(L,tt)|0,n=n+Math.imul(M,rt)|0,i=(i=i+Math.imul(M,nt)|0)+Math.imul(S,rt)|0,a=a+Math.imul(S,nt)|0,n=n+Math.imul(k,at)|0,i=(i=i+Math.imul(k,ot)|0)+Math.imul(T,at)|0,a=a+Math.imul(T,ot)|0,n=n+Math.imul(b,lt)|0,i=(i=i+Math.imul(b,ct)|0)+Math.imul(_,lt)|0,a=a+Math.imul(_,ct)|0,n=n+Math.imul(m,ht)|0,i=(i=i+Math.imul(m,ft)|0)+Math.imul(y,ht)|0,a=a+Math.imul(y,ft)|0;var Mt=(c+(n=n+Math.imul(d,dt)|0)|0)+((8191&(i=(i=i+Math.imul(d,gt)|0)+Math.imul(g,dt)|0))<<13)|0;c=((a=a+Math.imul(g,gt)|0)+(i>>>13)|0)+(Mt>>>26)|0,Mt&=67108863,n=Math.imul(B,W),i=(i=Math.imul(B,X))+Math.imul(N,W)|0,a=Math.imul(N,X),n=n+Math.imul(D,J)|0,i=(i=i+Math.imul(D,K)|0)+Math.imul(R,J)|0,a=a+Math.imul(R,K)|0,n=n+Math.imul(O,Q)|0,i=(i=i+Math.imul(O,tt)|0)+Math.imul(z,Q)|0,a=a+Math.imul(z,tt)|0,n=n+Math.imul(C,rt)|0,i=(i=i+Math.imul(C,nt)|0)+Math.imul(L,rt)|0,a=a+Math.imul(L,nt)|0,n=n+Math.imul(M,at)|0,i=(i=i+Math.imul(M,ot)|0)+Math.imul(S,at)|0,a=a+Math.imul(S,ot)|0,n=n+Math.imul(k,lt)|0,i=(i=i+Math.imul(k,ct)|0)+Math.imul(T,lt)|0,a=a+Math.imul(T,ct)|0,n=n+Math.imul(b,ht)|0,i=(i=i+Math.imul(b,ft)|0)+Math.imul(_,ht)|0,a=a+Math.imul(_,ft)|0;var St=(c+(n=n+Math.imul(m,dt)|0)|0)+((8191&(i=(i=i+Math.imul(m,gt)|0)+Math.imul(y,dt)|0))<<13)|0;c=((a=a+Math.imul(y,gt)|0)+(i>>>13)|0)+(St>>>26)|0,St&=67108863,n=Math.imul(B,J),i=(i=Math.imul(B,K))+Math.imul(N,J)|0,a=Math.imul(N,K),n=n+Math.imul(D,Q)|0,i=(i=i+Math.imul(D,tt)|0)+Math.imul(R,Q)|0,a=a+Math.imul(R,tt)|0,n=n+Math.imul(O,rt)|0,i=(i=i+Math.imul(O,nt)|0)+Math.imul(z,rt)|0,a=a+Math.imul(z,nt)|0,n=n+Math.imul(C,at)|0,i=(i=i+Math.imul(C,ot)|0)+Math.imul(L,at)|0,a=a+Math.imul(L,ot)|0,n=n+Math.imul(M,lt)|0,i=(i=i+Math.imul(M,ct)|0)+Math.imul(S,lt)|0,a=a+Math.imul(S,ct)|0,n=n+Math.imul(k,ht)|0,i=(i=i+Math.imul(k,ft)|0)+Math.imul(T,ht)|0,a=a+Math.imul(T,ft)|0;var Et=(c+(n=n+Math.imul(b,dt)|0)|0)+((8191&(i=(i=i+Math.imul(b,gt)|0)+Math.imul(_,dt)|0))<<13)|0;c=((a=a+Math.imul(_,gt)|0)+(i>>>13)|0)+(Et>>>26)|0,Et&=67108863,n=Math.imul(B,Q),i=(i=Math.imul(B,tt))+Math.imul(N,Q)|0,a=Math.imul(N,tt),n=n+Math.imul(D,rt)|0,i=(i=i+Math.imul(D,nt)|0)+Math.imul(R,rt)|0,a=a+Math.imul(R,nt)|0,n=n+Math.imul(O,at)|0,i=(i=i+Math.imul(O,ot)|0)+Math.imul(z,at)|0,a=a+Math.imul(z,ot)|0,n=n+Math.imul(C,lt)|0,i=(i=i+Math.imul(C,ct)|0)+Math.imul(L,lt)|0,a=a+Math.imul(L,ct)|0,n=n+Math.imul(M,ht)|0,i=(i=i+Math.imul(M,ft)|0)+Math.imul(S,ht)|0,a=a+Math.imul(S,ft)|0;var Ct=(c+(n=n+Math.imul(k,dt)|0)|0)+((8191&(i=(i=i+Math.imul(k,gt)|0)+Math.imul(T,dt)|0))<<13)|0;c=((a=a+Math.imul(T,gt)|0)+(i>>>13)|0)+(Ct>>>26)|0,Ct&=67108863,n=Math.imul(B,rt),i=(i=Math.imul(B,nt))+Math.imul(N,rt)|0,a=Math.imul(N,nt),n=n+Math.imul(D,at)|0,i=(i=i+Math.imul(D,ot)|0)+Math.imul(R,at)|0,a=a+Math.imul(R,ot)|0,n=n+Math.imul(O,lt)|0,i=(i=i+Math.imul(O,ct)|0)+Math.imul(z,lt)|0,a=a+Math.imul(z,ct)|0,n=n+Math.imul(C,ht)|0,i=(i=i+Math.imul(C,ft)|0)+Math.imul(L,ht)|0,a=a+Math.imul(L,ft)|0;var Lt=(c+(n=n+Math.imul(M,dt)|0)|0)+((8191&(i=(i=i+Math.imul(M,gt)|0)+Math.imul(S,dt)|0))<<13)|0;c=((a=a+Math.imul(S,gt)|0)+(i>>>13)|0)+(Lt>>>26)|0,Lt&=67108863,n=Math.imul(B,at),i=(i=Math.imul(B,ot))+Math.imul(N,at)|0,a=Math.imul(N,ot),n=n+Math.imul(D,lt)|0,i=(i=i+Math.imul(D,ct)|0)+Math.imul(R,lt)|0,a=a+Math.imul(R,ct)|0,n=n+Math.imul(O,ht)|0,i=(i=i+Math.imul(O,ft)|0)+Math.imul(z,ht)|0,a=a+Math.imul(z,ft)|0;var Pt=(c+(n=n+Math.imul(C,dt)|0)|0)+((8191&(i=(i=i+Math.imul(C,gt)|0)+Math.imul(L,dt)|0))<<13)|0;c=((a=a+Math.imul(L,gt)|0)+(i>>>13)|0)+(Pt>>>26)|0,Pt&=67108863,n=Math.imul(B,lt),i=(i=Math.imul(B,ct))+Math.imul(N,lt)|0,a=Math.imul(N,ct),n=n+Math.imul(D,ht)|0,i=(i=i+Math.imul(D,ft)|0)+Math.imul(R,ht)|0,a=a+Math.imul(R,ft)|0;var Ot=(c+(n=n+Math.imul(O,dt)|0)|0)+((8191&(i=(i=i+Math.imul(O,gt)|0)+Math.imul(z,dt)|0))<<13)|0;c=((a=a+Math.imul(z,gt)|0)+(i>>>13)|0)+(Ot>>>26)|0,Ot&=67108863,n=Math.imul(B,ht),i=(i=Math.imul(B,ft))+Math.imul(N,ht)|0,a=Math.imul(N,ft);var zt=(c+(n=n+Math.imul(D,dt)|0)|0)+((8191&(i=(i=i+Math.imul(D,gt)|0)+Math.imul(R,dt)|0))<<13)|0;c=((a=a+Math.imul(R,gt)|0)+(i>>>13)|0)+(zt>>>26)|0,zt&=67108863;var It=(c+(n=Math.imul(B,dt))|0)+((8191&(i=(i=Math.imul(B,gt))+Math.imul(N,dt)|0))<<13)|0;return c=((a=Math.imul(N,gt))+(i>>>13)|0)+(It>>>26)|0,It&=67108863,l[0]=vt,l[1]=mt,l[2]=yt,l[3]=xt,l[4]=bt,l[5]=_t,l[6]=wt,l[7]=kt,l[8]=Tt,l[9]=At,l[10]=Mt,l[11]=St,l[12]=Et,l[13]=Ct,l[14]=Lt,l[15]=Pt,l[16]=Ot,l[17]=zt,l[18]=It,0!==c&&(l[19]=c,r.length++),r};function d(t,e,r){return(new g).mulp(t,e,r)}function g(t,e){this.x=t,this.y=e}Math.imul||(p=f),a.prototype.mulTo=function(t,e){var r=this.length+t.length;return 10===this.length&&10===t.length?p(this,t,e):r<63?f(this,t,e):r<1024?function(t,e,r){r.negative=e.negative^t.negative,r.length=t.length+e.length;for(var n=0,i=0,a=0;a<r.length-1;a++){var o=i;i=0;for(var s=67108863&n,l=Math.min(a,e.length-1),c=Math.max(0,a-t.length+1);c<=l;c++){var u=a-c,h=(0|t.words[u])*(0|e.words[c]),f=67108863&h;s=67108863&(f=f+s|0),i+=(o=(o=o+(h/67108864|0)|0)+(f>>>26)|0)>>>26,o&=67108863}r.words[a]=s,n=o,o=i}return 0!==n?r.words[a]=n:r.length--,r.strip()}(this,t,e):d(this,t,e)},g.prototype.makeRBT=function(t){for(var e=new Array(t),r=a.prototype._countBits(t)-1,n=0;n<t;n++)e[n]=this.revBin(n,r,t);return e},g.prototype.revBin=function(t,e,r){if(0===t||t===r-1)return t;for(var n=0,i=0;i<e;i++)n|=(1&t)<<e-i-1,t>>=1;return n},g.prototype.permute=function(t,e,r,n,i,a){for(var o=0;o<a;o++)n[o]=e[t[o]],i[o]=r[t[o]]},g.prototype.transform=function(t,e,r,n,i,a){this.permute(a,t,e,r,n,i);for(var o=1;o<i;o<<=1)for(var s=o<<1,l=Math.cos(2*Math.PI/s),c=Math.sin(2*Math.PI/s),u=0;u<i;u+=s)for(var h=l,f=c,p=0;p<o;p++){var d=r[u+p],g=n[u+p],v=r[u+p+o],m=n[u+p+o],y=h*v-f*m;m=h*m+f*v,v=y,r[u+p]=d+v,n[u+p]=g+m,r[u+p+o]=d-v,n[u+p+o]=g-m,p!==s&&(y=l*h-c*f,f=l*f+c*h,h=y)}},g.prototype.guessLen13b=function(t,e){var r=1|Math.max(e,t),n=1&r,i=0;for(r=r/2|0;r;r>>>=1)i++;return 1<<i+1+n},g.prototype.conjugate=function(t,e,r){if(!(r<=1))for(var n=0;n<r/2;n++){var i=t[n];t[n]=t[r-n-1],t[r-n-1]=i,i=e[n],e[n]=-e[r-n-1],e[r-n-1]=-i}},g.prototype.normalize13b=function(t,e){for(var r=0,n=0;n<e/2;n++){var i=8192*Math.round(t[2*n+1]/e)+Math.round(t[2*n]/e)+r;t[n]=67108863&i,r=i<67108864?0:i/67108864|0}return t},g.prototype.convert13b=function(t,e,r,i){for(var a=0,o=0;o<e;o++)a+=0|t[o],r[2*o]=8191&a,a>>>=13,r[2*o+1]=8191&a,a>>>=13;for(o=2*e;o<i;++o)r[o]=0;n(0===a),n(0==(-8192&a))},g.prototype.stub=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=0;return e},g.prototype.mulp=function(t,e,r){var n=2*this.guessLen13b(t.length,e.length),i=this.makeRBT(n),a=this.stub(n),o=new Array(n),s=new Array(n),l=new Array(n),c=new Array(n),u=new Array(n),h=new Array(n),f=r.words;f.length=n,this.convert13b(t.words,t.length,o,n),this.convert13b(e.words,e.length,c,n),this.transform(o,a,s,l,n,i),this.transform(c,a,u,h,n,i);for(var p=0;p<n;p++){var d=s[p]*u[p]-l[p]*h[p];l[p]=s[p]*h[p]+l[p]*u[p],s[p]=d}return this.conjugate(s,l,n),this.transform(s,l,f,a,n,i),this.conjugate(f,a,n),this.normalize13b(f,n),r.negative=t.negative^e.negative,r.length=t.length+e.length,r.strip()},a.prototype.mul=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),this.mulTo(t,e)},a.prototype.mulf=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),d(this,t,e)},a.prototype.imul=function(t){return this.clone().mulTo(t,this)},a.prototype.imuln=function(t){n(\"number\"==typeof t),n(t<67108864);for(var e=0,r=0;r<this.length;r++){var i=(0|this.words[r])*t,a=(67108863&i)+(67108863&e);e>>=26,e+=i/67108864|0,e+=a>>>26,this.words[r]=67108863&a}return 0!==e&&(this.words[r]=e,this.length++),this},a.prototype.muln=function(t){return this.clone().imuln(t)},a.prototype.sqr=function(){return this.mul(this)},a.prototype.isqr=function(){return this.imul(this.clone())},a.prototype.pow=function(t){var e=function(t){for(var e=new Array(t.bitLength()),r=0;r<e.length;r++){var n=r/26|0,i=r%26;e[r]=(t.words[n]&1<<i)>>>i}return e}(t);if(0===e.length)return new a(1);for(var r=this,n=0;n<e.length&&0===e[n];n++,r=r.sqr());if(++n<e.length)for(var i=r.sqr();n<e.length;n++,i=i.sqr())0!==e[n]&&(r=r.mul(i));return r},a.prototype.iushln=function(t){n(\"number\"==typeof t&&t>=0);var e,r=t%26,i=(t-r)/26,a=67108863>>>26-r<<26-r;if(0!==r){var o=0;for(e=0;e<this.length;e++){var s=this.words[e]&a,l=(0|this.words[e])-s<<r;this.words[e]=l|o,o=s>>>26-r}o&&(this.words[e]=o,this.length++)}if(0!==i){for(e=this.length-1;e>=0;e--)this.words[e+i]=this.words[e];for(e=0;e<i;e++)this.words[e]=0;this.length+=i}return this.strip()},a.prototype.ishln=function(t){return n(0===this.negative),this.iushln(t)},a.prototype.iushrn=function(t,e,r){var i;n(\"number\"==typeof t&&t>=0),i=e?(e-e%26)/26:0;var a=t%26,o=Math.min((t-a)/26,this.length),s=67108863^67108863>>>a<<a,l=r;if(i-=o,i=Math.max(0,i),l){for(var c=0;c<o;c++)l.words[c]=this.words[c];l.length=o}if(0===o);else if(this.length>o)for(this.length-=o,c=0;c<this.length;c++)this.words[c]=this.words[c+o];else this.words[0]=0,this.length=1;var u=0;for(c=this.length-1;c>=0&&(0!==u||c>=i);c--){var h=0|this.words[c];this.words[c]=u<<26-a|h>>>a,u=h&s}return l&&0!==u&&(l.words[l.length++]=u),0===this.length&&(this.words[0]=0,this.length=1),this.strip()},a.prototype.ishrn=function(t,e,r){return n(0===this.negative),this.iushrn(t,e,r)},a.prototype.shln=function(t){return this.clone().ishln(t)},a.prototype.ushln=function(t){return this.clone().iushln(t)},a.prototype.shrn=function(t){return this.clone().ishrn(t)},a.prototype.ushrn=function(t){return this.clone().iushrn(t)},a.prototype.testn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26,i=1<<e;return!(this.length<=r)&&!!(this.words[r]&i)},a.prototype.imaskn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26;if(n(0===this.negative,\"imaskn works only with positive numbers\"),this.length<=r)return this;if(0!==e&&r++,this.length=Math.min(r,this.length),0!==e){var i=67108863^67108863>>>e<<e;this.words[this.length-1]&=i}return this.strip()},a.prototype.maskn=function(t){return this.clone().imaskn(t)},a.prototype.iaddn=function(t){return n(\"number\"==typeof t),n(t<67108864),t<0?this.isubn(-t):0!==this.negative?1===this.length&&(0|this.words[0])<t?(this.words[0]=t-(0|this.words[0]),this.negative=0,this):(this.negative=0,this.isubn(t),this.negative=1,this):this._iaddn(t)},a.prototype._iaddn=function(t){this.words[0]+=t;for(var e=0;e<this.length&&this.words[e]>=67108864;e++)this.words[e]-=67108864,e===this.length-1?this.words[e+1]=1:this.words[e+1]++;return this.length=Math.max(this.length,e+1),this},a.prototype.isubn=function(t){if(n(\"number\"==typeof t),n(t<67108864),t<0)return this.iaddn(-t);if(0!==this.negative)return this.negative=0,this.iaddn(t),this.negative=1,this;if(this.words[0]-=t,1===this.length&&this.words[0]<0)this.words[0]=-this.words[0],this.negative=1;else for(var e=0;e<this.length&&this.words[e]<0;e++)this.words[e]+=67108864,this.words[e+1]-=1;return this.strip()},a.prototype.addn=function(t){return this.clone().iaddn(t)},a.prototype.subn=function(t){return this.clone().isubn(t)},a.prototype.iabs=function(){return this.negative=0,this},a.prototype.abs=function(){return this.clone().iabs()},a.prototype._ishlnsubmul=function(t,e,r){var i,a,o=t.length+r;this._expand(o);var s=0;for(i=0;i<t.length;i++){a=(0|this.words[i+r])+s;var l=(0|t.words[i])*e;s=((a-=67108863&l)>>26)-(l/67108864|0),this.words[i+r]=67108863&a}for(;i<this.length-r;i++)s=(a=(0|this.words[i+r])+s)>>26,this.words[i+r]=67108863&a;if(0===s)return this.strip();for(n(-1===s),s=0,i=0;i<this.length;i++)s=(a=-(0|this.words[i])+s)>>26,this.words[i]=67108863&a;return this.negative=1,this.strip()},a.prototype._wordDiv=function(t,e){var r=(this.length,t.length),n=this.clone(),i=t,o=0|i.words[i.length-1];0!==(r=26-this._countBits(o))&&(i=i.ushln(r),n.iushln(r),o=0|i.words[i.length-1]);var s,l=n.length-i.length;if(\"mod\"!==e){(s=new a(null)).length=l+1,s.words=new Array(s.length);for(var c=0;c<s.length;c++)s.words[c]=0}var u=n.clone()._ishlnsubmul(i,1,l);0===u.negative&&(n=u,s&&(s.words[l]=1));for(var h=l-1;h>=0;h--){var f=67108864*(0|n.words[i.length+h])+(0|n.words[i.length+h-1]);for(f=Math.min(f/o|0,67108863),n._ishlnsubmul(i,f,h);0!==n.negative;)f--,n.negative=0,n._ishlnsubmul(i,1,h),n.isZero()||(n.negative^=1);s&&(s.words[h]=f)}return s&&s.strip(),n.strip(),\"div\"!==e&&0!==r&&n.iushrn(r),{div:s||null,mod:n}},a.prototype.divmod=function(t,e,r){return n(!t.isZero()),this.isZero()?{div:new a(0),mod:new a(0)}:0!==this.negative&&0===t.negative?(s=this.neg().divmod(t,e),\"mod\"!==e&&(i=s.div.neg()),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.iadd(t)),{div:i,mod:o}):0===this.negative&&0!==t.negative?(s=this.divmod(t.neg(),e),\"mod\"!==e&&(i=s.div.neg()),{div:i,mod:s.mod}):0!=(this.negative&t.negative)?(s=this.neg().divmod(t.neg(),e),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.isub(t)),{div:s.div,mod:o}):t.length>this.length||this.cmp(t)<0?{div:new a(0),mod:this}:1===t.length?\"div\"===e?{div:this.divn(t.words[0]),mod:null}:\"mod\"===e?{div:null,mod:new a(this.modn(t.words[0]))}:{div:this.divn(t.words[0]),mod:new a(this.modn(t.words[0]))}:this._wordDiv(t,e);var i,o,s},a.prototype.div=function(t){return this.divmod(t,\"div\",!1).div},a.prototype.mod=function(t){return this.divmod(t,\"mod\",!1).mod},a.prototype.umod=function(t){return this.divmod(t,\"mod\",!0).mod},a.prototype.divRound=function(t){var e=this.divmod(t);if(e.mod.isZero())return e.div;var r=0!==e.div.negative?e.mod.isub(t):e.mod,n=t.ushrn(1),i=t.andln(1),a=r.cmp(n);return a<0||1===i&&0===a?e.div:0!==e.div.negative?e.div.isubn(1):e.div.iaddn(1)},a.prototype.modn=function(t){n(t<=67108863);for(var e=(1<<26)%t,r=0,i=this.length-1;i>=0;i--)r=(e*r+(0|this.words[i]))%t;return r},a.prototype.idivn=function(t){n(t<=67108863);for(var e=0,r=this.length-1;r>=0;r--){var i=(0|this.words[r])+67108864*e;this.words[r]=i/t|0,e=i%t}return this.strip()},a.prototype.divn=function(t){return this.clone().idivn(t)},a.prototype.egcd=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i=new a(1),o=new a(0),s=new a(0),l=new a(1),c=0;e.isEven()&&r.isEven();)e.iushrn(1),r.iushrn(1),++c;for(var u=r.clone(),h=e.clone();!e.isZero();){for(var f=0,p=1;0==(e.words[0]&p)&&f<26;++f,p<<=1);if(f>0)for(e.iushrn(f);f-- >0;)(i.isOdd()||o.isOdd())&&(i.iadd(u),o.isub(h)),i.iushrn(1),o.iushrn(1);for(var d=0,g=1;0==(r.words[0]&g)&&d<26;++d,g<<=1);if(d>0)for(r.iushrn(d);d-- >0;)(s.isOdd()||l.isOdd())&&(s.iadd(u),l.isub(h)),s.iushrn(1),l.iushrn(1);e.cmp(r)>=0?(e.isub(r),i.isub(s),o.isub(l)):(r.isub(e),s.isub(i),l.isub(o))}return{a:s,b:l,gcd:r.iushln(c)}},a.prototype._invmp=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i,o=new a(1),s=new a(0),l=r.clone();e.cmpn(1)>0&&r.cmpn(1)>0;){for(var c=0,u=1;0==(e.words[0]&u)&&c<26;++c,u<<=1);if(c>0)for(e.iushrn(c);c-- >0;)o.isOdd()&&o.iadd(l),o.iushrn(1);for(var h=0,f=1;0==(r.words[0]&f)&&h<26;++h,f<<=1);if(h>0)for(r.iushrn(h);h-- >0;)s.isOdd()&&s.iadd(l),s.iushrn(1);e.cmp(r)>=0?(e.isub(r),o.isub(s)):(r.isub(e),s.isub(o))}return(i=0===e.cmpn(1)?o:s).cmpn(0)<0&&i.iadd(t),i},a.prototype.gcd=function(t){if(this.isZero())return t.abs();if(t.isZero())return this.abs();var e=this.clone(),r=t.clone();e.negative=0,r.negative=0;for(var n=0;e.isEven()&&r.isEven();n++)e.iushrn(1),r.iushrn(1);for(;;){for(;e.isEven();)e.iushrn(1);for(;r.isEven();)r.iushrn(1);var i=e.cmp(r);if(i<0){var a=e;e=r,r=a}else if(0===i||0===r.cmpn(1))break;e.isub(r)}return r.iushln(n)},a.prototype.invm=function(t){return this.egcd(t).a.umod(t)},a.prototype.isEven=function(){return 0==(1&this.words[0])},a.prototype.isOdd=function(){return 1==(1&this.words[0])},a.prototype.andln=function(t){return this.words[0]&t},a.prototype.bincn=function(t){n(\"number\"==typeof t);var e=t%26,r=(t-e)/26,i=1<<e;if(this.length<=r)return this._expand(r+1),this.words[r]|=i,this;for(var a=i,o=r;0!==a&&o<this.length;o++){var s=0|this.words[o];a=(s+=a)>>>26,s&=67108863,this.words[o]=s}return 0!==a&&(this.words[o]=a,this.length++),this},a.prototype.isZero=function(){return 1===this.length&&0===this.words[0]},a.prototype.cmpn=function(t){var e,r=t<0;if(0!==this.negative&&!r)return-1;if(0===this.negative&&r)return 1;if(this.strip(),this.length>1)e=1;else{r&&(t=-t),n(t<=67108863,\"Number is too big\");var i=0|this.words[0];e=i===t?0:i<t?-1:1}return 0!==this.negative?0|-e:e},a.prototype.cmp=function(t){if(0!==this.negative&&0===t.negative)return-1;if(0===this.negative&&0!==t.negative)return 1;var e=this.ucmp(t);return 0!==this.negative?0|-e:e},a.prototype.ucmp=function(t){if(this.length>t.length)return 1;if(this.length<t.length)return-1;for(var e=0,r=this.length-1;r>=0;r--){var n=0|this.words[r],i=0|t.words[r];if(n!==i){n<i?e=-1:n>i&&(e=1);break}}return e},a.prototype.gtn=function(t){return 1===this.cmpn(t)},a.prototype.gt=function(t){return 1===this.cmp(t)},a.prototype.gten=function(t){return this.cmpn(t)>=0},a.prototype.gte=function(t){return this.cmp(t)>=0},a.prototype.ltn=function(t){return-1===this.cmpn(t)},a.prototype.lt=function(t){return-1===this.cmp(t)},a.prototype.lten=function(t){return this.cmpn(t)<=0},a.prototype.lte=function(t){return this.cmp(t)<=0},a.prototype.eqn=function(t){return 0===this.cmpn(t)},a.prototype.eq=function(t){return 0===this.cmp(t)},a.red=function(t){return new w(t)},a.prototype.toRed=function(t){return n(!this.red,\"Already a number in reduction context\"),n(0===this.negative,\"red works only with positives\"),t.convertTo(this)._forceRed(t)},a.prototype.fromRed=function(){return n(this.red,\"fromRed works only with numbers in reduction context\"),this.red.convertFrom(this)},a.prototype._forceRed=function(t){return this.red=t,this},a.prototype.forceRed=function(t){return n(!this.red,\"Already a number in reduction context\"),this._forceRed(t)},a.prototype.redAdd=function(t){return n(this.red,\"redAdd works only with red numbers\"),this.red.add(this,t)},a.prototype.redIAdd=function(t){return n(this.red,\"redIAdd works only with red numbers\"),this.red.iadd(this,t)},a.prototype.redSub=function(t){return n(this.red,\"redSub works only with red numbers\"),this.red.sub(this,t)},a.prototype.redISub=function(t){return n(this.red,\"redISub works only with red numbers\"),this.red.isub(this,t)},a.prototype.redShl=function(t){return n(this.red,\"redShl works only with red numbers\"),this.red.shl(this,t)},a.prototype.redMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.mul(this,t)},a.prototype.redIMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.imul(this,t)},a.prototype.redSqr=function(){return n(this.red,\"redSqr works only with red numbers\"),this.red._verify1(this),this.red.sqr(this)},a.prototype.redISqr=function(){return n(this.red,\"redISqr works only with red numbers\"),this.red._verify1(this),this.red.isqr(this)},a.prototype.redSqrt=function(){return n(this.red,\"redSqrt works only with red numbers\"),this.red._verify1(this),this.red.sqrt(this)},a.prototype.redInvm=function(){return n(this.red,\"redInvm works only with red numbers\"),this.red._verify1(this),this.red.invm(this)},a.prototype.redNeg=function(){return n(this.red,\"redNeg works only with red numbers\"),this.red._verify1(this),this.red.neg(this)},a.prototype.redPow=function(t){return n(this.red&&!t.red,\"redPow(normalNum)\"),this.red._verify1(this),this.red.pow(this,t)};var v={k256:null,p224:null,p192:null,p25519:null};function m(t,e){this.name=t,this.p=new a(e,16),this.n=this.p.bitLength(),this.k=new a(1).iushln(this.n).isub(this.p),this.tmp=this._tmp()}function y(){m.call(this,\"k256\",\"ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffe fffffc2f\")}function x(){m.call(this,\"p224\",\"ffffffff ffffffff ffffffff ffffffff 00000000 00000000 00000001\")}function b(){m.call(this,\"p192\",\"ffffffff ffffffff ffffffff fffffffe ffffffff ffffffff\")}function _(){m.call(this,\"25519\",\"7fffffffffffffff ffffffffffffffff ffffffffffffffff ffffffffffffffed\")}function w(t){if(\"string\"==typeof t){var e=a._prime(t);this.m=e.p,this.prime=e}else n(t.gtn(1),\"modulus must be greater than 1\"),this.m=t,this.prime=null}function k(t){w.call(this,t),this.shift=this.m.bitLength(),this.shift%26!=0&&(this.shift+=26-this.shift%26),this.r=new a(1).iushln(this.shift),this.r2=this.imod(this.r.sqr()),this.rinv=this.r._invmp(this.m),this.minv=this.rinv.mul(this.r).isubn(1).div(this.m),this.minv=this.minv.umod(this.r),this.minv=this.r.sub(this.minv)}m.prototype._tmp=function(){var t=new a(null);return t.words=new Array(Math.ceil(this.n/13)),t},m.prototype.ireduce=function(t){var e,r=t;do{this.split(r,this.tmp),e=(r=(r=this.imulK(r)).iadd(this.tmp)).bitLength()}while(e>this.n);var n=e<this.n?-1:r.ucmp(this.p);return 0===n?(r.words[0]=0,r.length=1):n>0?r.isub(this.p):r.strip(),r},m.prototype.split=function(t,e){t.iushrn(this.n,0,e)},m.prototype.imulK=function(t){return t.imul(this.k)},i(y,m),y.prototype.split=function(t,e){for(var r=Math.min(t.length,9),n=0;n<r;n++)e.words[n]=t.words[n];if(e.length=r,t.length<=9)return t.words[0]=0,void(t.length=1);var i=t.words[9];for(e.words[e.length++]=4194303&i,n=10;n<t.length;n++){var a=0|t.words[n];t.words[n-10]=(4194303&a)<<4|i>>>22,i=a}i>>>=22,t.words[n-10]=i,0===i&&t.length>10?t.length-=10:t.length-=9},y.prototype.imulK=function(t){t.words[t.length]=0,t.words[t.length+1]=0,t.length+=2;for(var e=0,r=0;r<t.length;r++){var n=0|t.words[r];e+=977*n,t.words[r]=67108863&e,e=64*n+(e/67108864|0)}return 0===t.words[t.length-1]&&(t.length--,0===t.words[t.length-1]&&t.length--),t},i(x,m),i(b,m),i(_,m),_.prototype.imulK=function(t){for(var e=0,r=0;r<t.length;r++){var n=19*(0|t.words[r])+e,i=67108863&n;n>>>=26,t.words[r]=i,e=n}return 0!==e&&(t.words[t.length++]=e),t},a._prime=function(t){if(v[t])return v[t];var e;if(\"k256\"===t)e=new y;else if(\"p224\"===t)e=new x;else if(\"p192\"===t)e=new b;else{if(\"p25519\"!==t)throw new Error(\"Unknown prime \"+t);e=new _}return v[t]=e,e},w.prototype._verify1=function(t){n(0===t.negative,\"red works only with positives\"),n(t.red,\"red works only with red numbers\")},w.prototype._verify2=function(t,e){n(0==(t.negative|e.negative),\"red works only with positives\"),n(t.red&&t.red===e.red,\"red works only with red numbers\")},w.prototype.imod=function(t){return this.prime?this.prime.ireduce(t)._forceRed(this):t.umod(this.m)._forceRed(this)},w.prototype.neg=function(t){return t.isZero()?t.clone():this.m.sub(t)._forceRed(this)},w.prototype.add=function(t,e){this._verify2(t,e);var r=t.add(e);return r.cmp(this.m)>=0&&r.isub(this.m),r._forceRed(this)},w.prototype.iadd=function(t,e){this._verify2(t,e);var r=t.iadd(e);return r.cmp(this.m)>=0&&r.isub(this.m),r},w.prototype.sub=function(t,e){this._verify2(t,e);var r=t.sub(e);return r.cmpn(0)<0&&r.iadd(this.m),r._forceRed(this)},w.prototype.isub=function(t,e){this._verify2(t,e);var r=t.isub(e);return r.cmpn(0)<0&&r.iadd(this.m),r},w.prototype.shl=function(t,e){return this._verify1(t),this.imod(t.ushln(e))},w.prototype.imul=function(t,e){return this._verify2(t,e),this.imod(t.imul(e))},w.prototype.mul=function(t,e){return this._verify2(t,e),this.imod(t.mul(e))},w.prototype.isqr=function(t){return this.imul(t,t.clone())},w.prototype.sqr=function(t){return this.mul(t,t)},w.prototype.sqrt=function(t){if(t.isZero())return t.clone();var e=this.m.andln(3);if(n(e%2==1),3===e){var r=this.m.add(new a(1)).iushrn(2);return this.pow(t,r)}for(var i=this.m.subn(1),o=0;!i.isZero()&&0===i.andln(1);)o++,i.iushrn(1);n(!i.isZero());var s=new a(1).toRed(this),l=s.redNeg(),c=this.m.subn(1).iushrn(1),u=this.m.bitLength();for(u=new a(2*u*u).toRed(this);0!==this.pow(u,c).cmp(l);)u.redIAdd(l);for(var h=this.pow(u,i),f=this.pow(t,i.addn(1).iushrn(1)),p=this.pow(t,i),d=o;0!==p.cmp(s);){for(var g=p,v=0;0!==g.cmp(s);v++)g=g.redSqr();n(v<d);var m=this.pow(h,new a(1).iushln(d-v-1));f=f.redMul(m),h=m.redSqr(),p=p.redMul(h),d=v}return f},w.prototype.invm=function(t){var e=t._invmp(this.m);return 0!==e.negative?(e.negative=0,this.imod(e).redNeg()):this.imod(e)},w.prototype.pow=function(t,e){if(e.isZero())return new a(1).toRed(this);if(0===e.cmpn(1))return t.clone();var r=new Array(16);r[0]=new a(1).toRed(this),r[1]=t;for(var n=2;n<r.length;n++)r[n]=this.mul(r[n-1],t);var i=r[0],o=0,s=0,l=e.bitLength()%26;for(0===l&&(l=26),n=e.length-1;n>=0;n--){for(var c=e.words[n],u=l-1;u>=0;u--){var h=c>>u&1;i!==r[0]&&(i=this.sqr(i)),0!==h||0!==o?(o<<=1,o|=h,(4===++s||0===n&&0===u)&&(i=this.mul(i,r[o]),s=0,o=0)):s=0}l=26}return i},w.prototype.convertTo=function(t){var e=t.umod(this.m);return e===t?e.clone():e},w.prototype.convertFrom=function(t){var e=t.clone();return e.red=null,e},a.mont=function(t){return new k(t)},i(k,w),k.prototype.convertTo=function(t){return this.imod(t.ushln(this.shift))},k.prototype.convertFrom=function(t){var e=this.imod(t.mul(this.rinv));return e.red=null,e},k.prototype.imul=function(t,e){if(t.isZero()||e.isZero())return t.words[0]=0,t.length=1,t;var r=t.imul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),a=i;return i.cmp(this.m)>=0?a=i.isub(this.m):i.cmpn(0)<0&&(a=i.iadd(this.m)),a._forceRed(this)},k.prototype.mul=function(t,e){if(t.isZero()||e.isZero())return new a(0)._forceRed(this);var r=t.mul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),o=i;return i.cmp(this.m)>=0?o=i.isub(this.m):i.cmpn(0)<0&&(o=i.iadd(this.m)),o._forceRed(this)},k.prototype.invm=function(t){return this.imod(t._invmp(this.m).mul(this.r2))._forceRed(this)}}(\"undefined\"==typeof e||e,this)},{buffer:103}],95:[function(t,e,r){\"use strict\";e.exports=function(t){var e,r,n,i=t.length,a=0;for(e=0;e<i;++e)a+=t[e].length;var o=new Array(a),s=0;for(e=0;e<i;++e){var l=t[e],c=l.length;for(r=0;r<c;++r){var u=o[s++]=new Array(c-1),h=0;for(n=0;n<c;++n)n!==r&&(u[h++]=l[n]);if(1&r){var f=u[1];u[1]=u[0],u[0]=f}}}return o}},{}],96:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 1:return n=[],c(i=t,i,u,!0),n;case 2:return\"function\"==typeof e?c(t,t,e,!0):function(t,e){return n=[],c(t,e,u,!1),n}(t,e);case 3:return c(t,e,r,!1);default:throw new Error(\"box-intersect: Invalid arguments\")}var i};var n,i=t(\"typedarray-pool\"),a=t(\"./lib/sweep\"),o=t(\"./lib/intersect\");function s(t,e){for(var r=0;r<t;++r)if(!(e[r]<=e[r+t]))return!0;return!1}function l(t,e,r,n){for(var i=0,a=0,o=0,l=t.length;o<l;++o){var c=t[o];if(!s(e,c)){for(var u=0;u<2*e;++u)r[i++]=c[u];n[a++]=o}}return a}function c(t,e,r,n){var s=t.length,c=e.length;if(!(s<=0||c<=0)){var u=t[0].length>>>1;if(!(u<=0)){var h,f=i.mallocDouble(2*u*s),p=i.mallocInt32(s);if((s=l(t,u,f,p))>0){if(1===u&&n)a.init(s),h=a.sweepComplete(u,r,0,s,f,p,0,s,f,p);else{var d=i.mallocDouble(2*u*c),g=i.mallocInt32(c);(c=l(e,u,d,g))>0&&(a.init(s+c),h=1===u?a.sweepBipartite(u,r,0,s,f,p,0,c,d,g):o(u,r,n,s,f,p,c,d,g),i.free(d),i.free(g))}i.free(f),i.free(p)}return h}}}function u(t,e){n.push([t,e])}},{\"./lib/intersect\":98,\"./lib/sweep\":102,\"typedarray-pool\":545}],97:[function(t,e,r){\"use strict\";var n=\"d\",i=\"ax\",a=\"vv\",o=\"fp\",s=\"es\",l=\"rs\",c=\"re\",u=\"rb\",h=\"ri\",f=\"rp\",p=\"bs\",d=\"be\",g=\"bb\",v=\"bi\",m=\"bp\",y=\"rv\",x=\"Q\",b=[n,i,a,l,c,u,h,p,d,g,v];function _(t){var e=\"bruteForce\"+(t?\"Full\":\"Partial\"),r=[],_=b.slice();t||_.splice(3,0,o);var w=[\"function \"+e+\"(\"+_.join()+\"){\"];function k(e,o){var _=function(t,e,r){var o=\"bruteForce\"+(t?\"Red\":\"Blue\")+(e?\"Flip\":\"\")+(r?\"Full\":\"\"),_=[\"function \",o,\"(\",b.join(),\"){\",\"var \",s,\"=2*\",n,\";\"],w=\"for(var i=\"+l+\",\"+f+\"=\"+s+\"*\"+l+\";i<\"+c+\";++i,\"+f+\"+=\"+s+\"){var x0=\"+u+\"[\"+i+\"+\"+f+\"],x1=\"+u+\"[\"+i+\"+\"+f+\"+\"+n+\"],xi=\"+h+\"[i];\",k=\"for(var j=\"+p+\",\"+m+\"=\"+s+\"*\"+p+\";j<\"+d+\";++j,\"+m+\"+=\"+s+\"){var y0=\"+g+\"[\"+i+\"+\"+m+\"],\"+(r?\"y1=\"+g+\"[\"+i+\"+\"+m+\"+\"+n+\"],\":\"\")+\"yi=\"+v+\"[j];\";return t?_.push(w,x,\":\",k):_.push(k,x,\":\",w),r?_.push(\"if(y1<x0||x1<y0)continue;\"):e?_.push(\"if(y0<=x0||x1<y0)continue;\"):_.push(\"if(y0<x0||x1<y0)continue;\"),_.push(\"for(var k=\"+i+\"+1;k<\"+n+\";++k){var r0=\"+u+\"[k+\"+f+\"],r1=\"+u+\"[k+\"+n+\"+\"+f+\"],b0=\"+g+\"[k+\"+m+\"],b1=\"+g+\"[k+\"+n+\"+\"+m+\"];if(r1<b0||b1<r0)continue \"+x+\";}var \"+y+\"=\"+a+\"(\"),e?_.push(\"yi,xi\"):_.push(\"xi,yi\"),_.push(\");if(\"+y+\"!==void 0)return \"+y+\";}}}\"),{name:o,code:_.join(\"\")}}(e,o,t);r.push(_.code),w.push(\"return \"+_.name+\"(\"+b.join()+\");\")}w.push(\"if(\"+c+\"-\"+l+\">\"+d+\"-\"+p+\"){\"),t?(k(!0,!1),w.push(\"}else{\"),k(!1,!1)):(w.push(\"if(\"+o+\"){\"),k(!0,!0),w.push(\"}else{\"),k(!0,!1),w.push(\"}}else{if(\"+o+\"){\"),k(!1,!0),w.push(\"}else{\"),k(!1,!1),w.push(\"}\")),w.push(\"}}return \"+e);var T=r.join(\"\")+w.join(\"\");return new Function(T)()}r.partial=_(!1),r.full=_(!0)},{}],98:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,u,S,E,C,L){!function(t,e){var r=8*i.log2(e+1)*(t+1)|0,a=i.nextPow2(b*r);w.length<a&&(n.free(w),w=n.mallocInt32(a));var o=i.nextPow2(_*r);k<o&&(n.free(k),k=n.mallocDouble(o))}(t,a+E);var P,O=0,z=2*t;T(O++,0,0,a,0,E,r?16:0,-1/0,1/0),r||T(O++,0,0,E,0,a,1,-1/0,1/0);for(;O>0;){var I=(O-=1)*b,D=w[I],R=w[I+1],F=w[I+2],B=w[I+3],N=w[I+4],j=w[I+5],U=O*_,V=k[U],q=k[U+1],H=1&j,G=!!(16&j),Y=u,W=S,X=C,Z=L;if(H&&(Y=C,W=L,X=u,Z=S),!(2&j&&(F=v(t,D,R,F,Y,W,q),R>=F)||4&j&&(R=m(t,D,R,F,Y,W,V))>=F)){var J=F-R,K=N-B;if(G){if(t*J*(J+K)<p){if(void 0!==(P=l.scanComplete(t,D,e,R,F,Y,W,B,N,X,Z)))return P;continue}}else{if(t*Math.min(J,K)<h){if(void 0!==(P=o(t,D,e,H,R,F,Y,W,B,N,X,Z)))return P;continue}if(t*J*K<f){if(void 0!==(P=l.scanBipartite(t,D,e,H,R,F,Y,W,B,N,X,Z)))return P;continue}}var $=d(t,D,R,F,Y,W,V,q);if(R<$)if(t*($-R)<h){if(void 0!==(P=s(t,D+1,e,R,$,Y,W,B,N,X,Z)))return P}else if(D===t-2){if(void 0!==(P=H?l.sweepBipartite(t,e,B,N,X,Z,R,$,Y,W):l.sweepBipartite(t,e,R,$,Y,W,B,N,X,Z)))return P}else T(O++,D+1,R,$,B,N,H,-1/0,1/0),T(O++,D+1,B,N,R,$,1^H,-1/0,1/0);if($<F){var Q=c(t,D,B,N,X,Z),tt=X[z*Q+D],et=g(t,D,Q,N,X,Z,tt);if(et<N&&T(O++,D,$,F,et,N,(4|H)+(G?16:0),tt,q),B<Q&&T(O++,D,$,F,B,Q,(2|H)+(G?16:0),V,tt),Q+1===et){if(void 0!==(P=G?M(t,D,e,$,F,Y,W,Q,X,Z[Q]):A(t,D,e,H,$,F,Y,W,Q,X,Z[Q])))return P}else if(Q<et){var rt;if(G){if(rt=y(t,D,$,F,Y,W,tt),$<rt){var nt=g(t,D,$,rt,Y,W,tt);if(D===t-2){if($<nt&&void 0!==(P=l.sweepComplete(t,e,$,nt,Y,W,Q,et,X,Z)))return P;if(nt<rt&&void 0!==(P=l.sweepBipartite(t,e,nt,rt,Y,W,Q,et,X,Z)))return P}else $<nt&&T(O++,D+1,$,nt,Q,et,16,-1/0,1/0),nt<rt&&(T(O++,D+1,nt,rt,Q,et,0,-1/0,1/0),T(O++,D+1,Q,et,nt,rt,1,-1/0,1/0))}}else rt=H?x(t,D,$,F,Y,W,tt):y(t,D,$,F,Y,W,tt),$<rt&&(D===t-2?P=H?l.sweepBipartite(t,e,Q,et,X,Z,$,rt,Y,W):l.sweepBipartite(t,e,$,rt,Y,W,Q,et,X,Z):(T(O++,D+1,$,rt,Q,et,H,-1/0,1/0),T(O++,D+1,Q,et,$,rt,1^H,-1/0,1/0)))}}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./brute\"),o=a.partial,s=a.full,l=t(\"./sweep\"),c=t(\"./median\"),u=t(\"./partition\"),h=128,f=1<<22,p=1<<22,d=u(\"!(lo>=p0)&&!(p1>=hi)\",[\"p0\",\"p1\"]),g=u(\"lo===p0\",[\"p0\"]),v=u(\"lo<p0\",[\"p0\"]),m=u(\"hi<=p0\",[\"p0\"]),y=u(\"lo<=p0&&p0<=hi\",[\"p0\"]),x=u(\"lo<p0&&p0<=hi\",[\"p0\"]),b=6,_=2,w=n.mallocInt32(1024),k=n.mallocDouble(1024);function T(t,e,r,n,i,a,o,s,l){var c=b*t;w[c]=e,w[c+1]=r,w[c+2]=n,w[c+3]=i,w[c+4]=a,w[c+5]=o;var u=_*t;k[u]=s,k[u+1]=l}function A(t,e,r,n,i,a,o,s,l,c,u){var h=2*t,f=l*h,p=c[f+e];t:for(var d=i,g=i*h;d<a;++d,g+=h){var v=o[g+e],m=o[g+e+t];if(!(p<v||m<p)&&(!n||p!==v)){for(var y,x=s[d],b=e+1;b<t;++b){v=o[g+b],m=o[g+b+t];var _=c[f+b],w=c[f+b+t];if(m<_||w<v)continue t}if(void 0!==(y=n?r(u,x):r(x,u)))return y}}}function M(t,e,r,n,i,a,o,s,l,c){var u=2*t,h=s*u,f=l[h+e];t:for(var p=n,d=n*u;p<i;++p,d+=u){var g=o[p];if(g!==c){var v=a[d+e],m=a[d+e+t];if(!(f<v||m<f)){for(var y=e+1;y<t;++y){v=a[d+y],m=a[d+y+t];var x=l[h+y],b=l[h+y+t];if(m<x||b<v)continue t}var _=r(g,c);if(void 0!==_)return _}}}}},{\"./brute\":97,\"./median\":99,\"./partition\":100,\"./sweep\":102,\"bit-twiddle\":92,\"typedarray-pool\":545}],99:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,o,s,l){if(o<=r+1)return r;var c=r,u=o,h=o+r>>>1,f=2*t,p=h,d=s[f*h+e];for(;c<u;){if(u-c<i){a(t,e,c,u,s,l),d=s[f*h+e];break}var g=u-c,v=Math.random()*g+c|0,m=s[f*v+e],y=Math.random()*g+c|0,x=s[f*y+e],b=Math.random()*g+c|0,_=s[f*b+e];m<=x?_>=x?(p=y,d=x):m>=_?(p=v,d=m):(p=b,d=_):x>=_?(p=y,d=x):_>=m?(p=v,d=m):(p=b,d=_);for(var w=f*(u-1),k=f*p,T=0;T<f;++T,++w,++k){var A=s[w];s[w]=s[k],s[k]=A}var M=l[u-1];l[u-1]=l[p],l[p]=M,p=n(t,e,c,u-1,s,l,d);for(var w=f*(u-1),k=f*p,T=0;T<f;++T,++w,++k){var A=s[w];s[w]=s[k],s[k]=A}var M=l[u-1];if(l[u-1]=l[p],l[p]=M,h<p){for(u=p-1;c<u&&s[f*(u-1)+e]===d;)u-=1;u+=1}else{if(!(p<h))break;for(c=p+1;c<u&&s[f*c+e]===d;)c+=1}}return n(t,e,r,h,s,l,s[f*h+e])};var n=t(\"./partition\")(\"lo<p0\",[\"p0\"]),i=8;function a(t,e,r,n,i,a){for(var o=2*t,s=o*(r+1)+e,l=r+1;l<n;++l,s+=o)for(var c=i[s],u=l,h=o*(l-1);u>r&&i[h+e]>c;--u,h-=o){for(var f=h,p=h+o,d=0;d<o;++d,++f,++p){var g=i[f];i[f]=i[p],i[p]=g}var v=a[u];a[u]=a[u-1],a[u-1]=v}}},{\"./partition\":100}],100:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=\"abcdef\".split(\"\").concat(e),i=[];t.indexOf(\"lo\")>=0&&i.push(\"lo=e[k+n]\");t.indexOf(\"hi\")>=0&&i.push(\"hi=e[k+o]\");return r.push(n.replace(\"_\",i.join()).replace(\"$\",t)),Function.apply(void 0,r)};var n=\"for(var j=2*a,k=j*c,l=k,m=c,n=b,o=a+b,p=c;d>p;++p,k+=j){var _;if($)if(m===p)m+=1,l+=j;else{for(var s=0;j>s;++s){var t=e[k+s];e[k+s]=e[l],e[l++]=t}var u=f[p];f[p]=f[m],f[m++]=u}}return m\"},{}],101:[function(t,e,r){\"use strict\";e.exports=function(t,e){e<=4*n?i(0,e-1,t):function t(e,r,h){var f=(r-e+1)/6|0,p=e+f,d=r-f,g=e+r>>1,v=g-f,m=g+f,y=p,x=v,b=g,_=m,w=d,k=e+1,T=r-1,A=0;c(y,x,h)&&(A=y,y=x,x=A);c(_,w,h)&&(A=_,_=w,w=A);c(y,b,h)&&(A=y,y=b,b=A);c(x,b,h)&&(A=x,x=b,b=A);c(y,_,h)&&(A=y,y=_,_=A);c(b,_,h)&&(A=b,b=_,_=A);c(x,w,h)&&(A=x,x=w,w=A);c(x,b,h)&&(A=x,x=b,b=A);c(_,w,h)&&(A=_,_=w,w=A);var M=h[2*x];var S=h[2*x+1];var E=h[2*_];var C=h[2*_+1];var L=2*y;var P=2*b;var O=2*w;var z=2*p;var I=2*g;var D=2*d;for(var R=0;R<2;++R){var F=h[L+R],B=h[P+R],N=h[O+R];h[z+R]=F,h[I+R]=B,h[D+R]=N}o(v,e,h);o(m,r,h);for(var j=k;j<=T;++j)if(u(j,M,S,h))j!==k&&a(j,k,h),++k;else if(!u(j,E,C,h))for(;;){if(u(T,E,C,h)){u(T,M,S,h)?(s(j,k,T,h),++k,--T):(a(j,T,h),--T);break}if(--T<j)break}l(e,k-1,M,S,h);l(r,T+1,E,C,h);k-2-e<=n?i(e,k-2,h):t(e,k-2,h);r-(T+2)<=n?i(T+2,r,h):t(T+2,r,h);T-k<=n?i(k,T,h):t(k,T,h)}(0,e-1,t)};var n=32;function i(t,e,r){for(var n=2*(t+1),i=t+1;i<=e;++i){for(var a=r[n++],o=r[n++],s=i,l=n-2;s-- >t;){var c=r[l-2],u=r[l-1];if(c<a)break;if(c===a&&u<o)break;r[l]=c,r[l+1]=u,l-=2}r[l]=a,r[l+1]=o}}function a(t,e,r){e*=2;var n=r[t*=2],i=r[t+1];r[t]=r[e],r[t+1]=r[e+1],r[e]=n,r[e+1]=i}function o(t,e,r){e*=2,r[t*=2]=r[e],r[t+1]=r[e+1]}function s(t,e,r,n){e*=2,r*=2;var i=n[t*=2],a=n[t+1];n[t]=n[e],n[t+1]=n[e+1],n[e]=n[r],n[e+1]=n[r+1],n[r]=i,n[r+1]=a}function l(t,e,r,n,i){e*=2,i[t*=2]=i[e],i[e]=r,i[t+1]=i[e+1],i[e+1]=n}function c(t,e,r){e*=2;var n=r[t*=2],i=r[e];return!(n<i)&&(n!==i||r[t+1]>r[e+1])}function u(t,e,r,n){var i=n[t*=2];return i<e||i===e&&n[t+1]<r}},{}],102:[function(t,e,r){\"use strict\";e.exports={init:function(t){var e=i.nextPow2(t);s.length<e&&(n.free(s),s=n.mallocInt32(e));l.length<e&&(n.free(l),l=n.mallocInt32(e));c.length<e&&(n.free(c),c=n.mallocInt32(e));u.length<e&&(n.free(u),u=n.mallocInt32(e));h.length<e&&(n.free(h),h=n.mallocInt32(e));f.length<e&&(n.free(f),f=n.mallocInt32(e));var r=8*e;p.length<r&&(n.free(p),p=n.mallocDouble(r))},sweepBipartite:function(t,e,r,n,i,h,f,v,m,y){for(var x=0,b=2*t,_=t-1,w=b-1,k=r;k<n;++k){var T=h[k],A=b*k;p[x++]=i[A+_],p[x++]=-(T+1),p[x++]=i[A+w],p[x++]=T}for(var k=f;k<v;++k){var T=y[k]+o,M=b*k;p[x++]=m[M+_],p[x++]=-T,p[x++]=m[M+w],p[x++]=T}var S=x>>>1;a(p,S);for(var E=0,C=0,k=0;k<S;++k){var L=0|p[2*k+1];if(L>=o)d(c,u,C--,L=L-o|0);else if(L>=0)d(s,l,E--,L);else if(L<=-o){L=-L-o|0;for(var P=0;P<E;++P){var O=e(s[P],L);if(void 0!==O)return O}g(c,u,C++,L)}else{L=-L-1|0;for(var P=0;P<C;++P){var O=e(L,c[P]);if(void 0!==O)return O}g(s,l,E++,L)}}},sweepComplete:function(t,e,r,n,i,o,v,m,y,x){for(var b=0,_=2*t,w=t-1,k=_-1,T=r;T<n;++T){var A=o[T]+1<<1,M=_*T;p[b++]=i[M+w],p[b++]=-A,p[b++]=i[M+k],p[b++]=A}for(var T=v;T<m;++T){var A=x[T]+1<<1,S=_*T;p[b++]=y[S+w],p[b++]=1|-A,p[b++]=y[S+k],p[b++]=1|A}var E=b>>>1;a(p,E);for(var C=0,L=0,P=0,T=0;T<E;++T){var O=0|p[2*T+1],z=1&O;if(T<E-1&&O>>1==p[2*T+3]>>1&&(z=2,T+=1),O<0){for(var I=-(O>>1)-1,D=0;D<P;++D){var R=e(h[D],I);if(void 0!==R)return R}if(0!==z)for(var D=0;D<C;++D){var R=e(s[D],I);if(void 0!==R)return R}if(1!==z)for(var D=0;D<L;++D){var R=e(c[D],I);if(void 0!==R)return R}0===z?g(s,l,C++,I):1===z?g(c,u,L++,I):2===z&&g(h,f,P++,I)}else{var I=(O>>1)-1;0===z?d(s,l,C--,I):1===z?d(c,u,L--,I):2===z&&d(h,f,P--,I)}}},scanBipartite:function(t,e,r,n,i,c,u,h,f,v,m,y){var x=0,b=2*t,_=e,w=e+t,k=1,T=1;n?T=o:k=o;for(var A=i;A<c;++A){var M=A+k,S=b*A;p[x++]=u[S+_],p[x++]=-M,p[x++]=u[S+w],p[x++]=M}for(var A=f;A<v;++A){var M=A+T,E=b*A;p[x++]=m[E+_],p[x++]=-M}var C=x>>>1;a(p,C);for(var L=0,A=0;A<C;++A){var P=0|p[2*A+1];if(P<0){var M=-P,O=!1;if(M>=o?(O=!n,M-=o):(O=!!n,M-=1),O)g(s,l,L++,M);else{var z=y[M],I=b*M,D=m[I+e+1],R=m[I+e+1+t];t:for(var F=0;F<L;++F){var B=s[F],N=b*B;if(!(R<u[N+e+1]||u[N+e+1+t]<D)){for(var j=e+2;j<t;++j)if(m[I+j+t]<u[N+j]||u[N+j+t]<m[I+j])continue t;var U,V=h[B];if(void 0!==(U=n?r(z,V):r(V,z)))return U}}}}else d(s,l,L--,P-k)}},scanComplete:function(t,e,r,n,i,l,c,u,h,f,d){for(var g=0,v=2*t,m=e,y=e+t,x=n;x<i;++x){var b=x+o,_=v*x;p[g++]=l[_+m],p[g++]=-b,p[g++]=l[_+y],p[g++]=b}for(var x=u;x<h;++x){var b=x+1,w=v*x;p[g++]=f[w+m],p[g++]=-b}var k=g>>>1;a(p,k);for(var T=0,x=0;x<k;++x){var A=0|p[2*x+1];if(A<0){var b=-A;if(b>=o)s[T++]=b-o;else{var M=d[b-=1],S=v*b,E=f[S+e+1],C=f[S+e+1+t];t:for(var L=0;L<T;++L){var P=s[L],O=c[P];if(O===M)break;var z=v*P;if(!(C<l[z+e+1]||l[z+e+1+t]<E)){for(var I=e+2;I<t;++I)if(f[S+I+t]<l[z+I]||l[z+I+t]<f[S+I])continue t;var D=r(O,M);if(void 0!==D)return D}}}}else{for(var b=A-o,L=T-1;L>=0;--L)if(s[L]===b){for(var I=L+1;I<T;++I)s[I-1]=s[I];break}--T}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./sort\"),o=1<<28,s=n.mallocInt32(1024),l=n.mallocInt32(1024),c=n.mallocInt32(1024),u=n.mallocInt32(1024),h=n.mallocInt32(1024),f=n.mallocInt32(1024),p=n.mallocDouble(8192);function d(t,e,r,n){var i=e[n],a=t[r-1];t[i]=a,e[a]=i}function g(t,e,r,n){t[r]=n,e[n]=r}},{\"./sort\":101,\"bit-twiddle\":92,\"typedarray-pool\":545}],103:[function(t,e,r){},{}],104:[function(t,e,r){var n=Object.create||function(t){var e=function(){};return e.prototype=t,new e},i=Object.keys||function(t){var e=[];for(var r in t)Object.prototype.hasOwnProperty.call(t,r)&&e.push(r);return r},a=Function.prototype.bind||function(t){var e=this;return function(){return e.apply(t,arguments)}};function o(){this._events&&Object.prototype.hasOwnProperty.call(this,\"_events\")||(this._events=n(null),this._eventsCount=0),this._maxListeners=this._maxListeners||void 0}e.exports=o,o.EventEmitter=o,o.prototype._events=void 0,o.prototype._maxListeners=void 0;var s,l=10;try{var c={};Object.defineProperty&&Object.defineProperty(c,\"x\",{value:0}),s=0===c.x}catch(t){s=!1}function u(t){return void 0===t._maxListeners?o.defaultMaxListeners:t._maxListeners}function h(t,e,r,i){var a,o,s;if(\"function\"!=typeof r)throw new TypeError('\"listener\" argument must be a function');if((o=t._events)?(o.newListener&&(t.emit(\"newListener\",e,r.listener?r.listener:r),o=t._events),s=o[e]):(o=t._events=n(null),t._eventsCount=0),s){if(\"function\"==typeof s?s=o[e]=i?[r,s]:[s,r]:i?s.unshift(r):s.push(r),!s.warned&&(a=u(t))&&a>0&&s.length>a){s.warned=!0;var l=new Error(\"Possible EventEmitter memory leak detected. \"+s.length+' \"'+String(e)+'\" listeners added. Use emitter.setMaxListeners() to increase limit.');l.name=\"MaxListenersExceededWarning\",l.emitter=t,l.type=e,l.count=s.length,\"object\"==typeof console&&console.warn&&console.warn(\"%s: %s\",l.name,l.message)}}else s=o[e]=r,++t._eventsCount;return t}function f(){if(!this.fired)switch(this.target.removeListener(this.type,this.wrapFn),this.fired=!0,arguments.length){case 0:return this.listener.call(this.target);case 1:return this.listener.call(this.target,arguments[0]);case 2:return this.listener.call(this.target,arguments[0],arguments[1]);case 3:return this.listener.call(this.target,arguments[0],arguments[1],arguments[2]);default:for(var t=new Array(arguments.length),e=0;e<t.length;++e)t[e]=arguments[e];this.listener.apply(this.target,t)}}function p(t,e,r){var n={fired:!1,wrapFn:void 0,target:t,type:e,listener:r},i=a.call(f,n);return i.listener=r,n.wrapFn=i,i}function d(t,e,r){var n=t._events;if(!n)return[];var i=n[e];return i?\"function\"==typeof i?r?[i.listener||i]:[i]:r?function(t){for(var e=new Array(t.length),r=0;r<e.length;++r)e[r]=t[r].listener||t[r];return e}(i):v(i,i.length):[]}function g(t){var e=this._events;if(e){var r=e[t];if(\"function\"==typeof r)return 1;if(r)return r.length}return 0}function v(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t[n];return r}s?Object.defineProperty(o,\"defaultMaxListeners\",{enumerable:!0,get:function(){return l},set:function(t){if(\"number\"!=typeof t||t<0||t!=t)throw new TypeError('\"defaultMaxListeners\" must be a positive number');l=t}}):o.defaultMaxListeners=l,o.prototype.setMaxListeners=function(t){if(\"number\"!=typeof t||t<0||isNaN(t))throw new TypeError('\"n\" argument must be a positive number');return this._maxListeners=t,this},o.prototype.getMaxListeners=function(){return u(this)},o.prototype.emit=function(t){var e,r,n,i,a,o,s=\"error\"===t;if(o=this._events)s=s&&null==o.error;else if(!s)return!1;if(s){if(arguments.length>1&&(e=arguments[1]),e instanceof Error)throw e;var l=new Error('Unhandled \"error\" event. ('+e+\")\");throw l.context=e,l}if(!(r=o[t]))return!1;var c=\"function\"==typeof r;switch(n=arguments.length){case 1:!function(t,e,r){if(e)t.call(r);else for(var n=t.length,i=v(t,n),a=0;a<n;++a)i[a].call(r)}(r,c,this);break;case 2:!function(t,e,r,n){if(e)t.call(r,n);else for(var i=t.length,a=v(t,i),o=0;o<i;++o)a[o].call(r,n)}(r,c,this,arguments[1]);break;case 3:!function(t,e,r,n,i){if(e)t.call(r,n,i);else for(var a=t.length,o=v(t,a),s=0;s<a;++s)o[s].call(r,n,i)}(r,c,this,arguments[1],arguments[2]);break;case 4:!function(t,e,r,n,i,a){if(e)t.call(r,n,i,a);else for(var o=t.length,s=v(t,o),l=0;l<o;++l)s[l].call(r,n,i,a)}(r,c,this,arguments[1],arguments[2],arguments[3]);break;default:for(i=new Array(n-1),a=1;a<n;a++)i[a-1]=arguments[a];!function(t,e,r,n){if(e)t.apply(r,n);else for(var i=t.length,a=v(t,i),o=0;o<i;++o)a[o].apply(r,n)}(r,c,this,i)}return!0},o.prototype.addListener=function(t,e){return h(this,t,e,!1)},o.prototype.on=o.prototype.addListener,o.prototype.prependListener=function(t,e){return h(this,t,e,!0)},o.prototype.once=function(t,e){if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');return this.on(t,p(this,t,e)),this},o.prototype.prependOnceListener=function(t,e){if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');return this.prependListener(t,p(this,t,e)),this},o.prototype.removeListener=function(t,e){var r,i,a,o,s;if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');if(!(i=this._events))return this;if(!(r=i[t]))return this;if(r===e||r.listener===e)0==--this._eventsCount?this._events=n(null):(delete i[t],i.removeListener&&this.emit(\"removeListener\",t,r.listener||e));else if(\"function\"!=typeof r){for(a=-1,o=r.length-1;o>=0;o--)if(r[o]===e||r[o].listener===e){s=r[o].listener,a=o;break}if(a<0)return this;0===a?r.shift():function(t,e){for(var r=e,n=r+1,i=t.length;n<i;r+=1,n+=1)t[r]=t[n];t.pop()}(r,a),1===r.length&&(i[t]=r[0]),i.removeListener&&this.emit(\"removeListener\",t,s||e)}return this},o.prototype.removeAllListeners=function(t){var e,r,a;if(!(r=this._events))return this;if(!r.removeListener)return 0===arguments.length?(this._events=n(null),this._eventsCount=0):r[t]&&(0==--this._eventsCount?this._events=n(null):delete r[t]),this;if(0===arguments.length){var o,s=i(r);for(a=0;a<s.length;++a)\"removeListener\"!==(o=s[a])&&this.removeAllListeners(o);return this.removeAllListeners(\"removeListener\"),this._events=n(null),this._eventsCount=0,this}if(\"function\"==typeof(e=r[t]))this.removeListener(t,e);else if(e)for(a=e.length-1;a>=0;a--)this.removeListener(t,e[a]);return this},o.prototype.listeners=function(t){return d(this,t,!0)},o.prototype.rawListeners=function(t){return d(this,t,!1)},o.listenerCount=function(t,e){return\"function\"==typeof t.listenerCount?t.listenerCount(e):g.call(t,e)},o.prototype.listenerCount=g,o.prototype.eventNames=function(){return this._eventsCount>0?Reflect.ownKeys(this._events):[]}},{}],105:[function(t,e,r){(function(e){\"use strict\";var n=t(\"base64-js\"),i=t(\"ieee754\");r.Buffer=e,r.SlowBuffer=function(t){+t!=t&&(t=0);return e.alloc(+t)},r.INSPECT_MAX_BYTES=50;var a=2147483647;function o(t){if(t>a)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"');var r=new Uint8Array(t);return r.__proto__=e.prototype,r}function e(t,e,r){if(\"number\"==typeof t){if(\"string\"==typeof e)throw new TypeError('The \"string\" argument must be of type string. Received type number');return c(t)}return s(t,e,r)}function s(t,r,n){if(\"string\"==typeof t)return function(t,r){\"string\"==typeof r&&\"\"!==r||(r=\"utf8\");if(!e.isEncoding(r))throw new TypeError(\"Unknown encoding: \"+r);var n=0|f(t,r),i=o(n),a=i.write(t,r);a!==n&&(i=i.slice(0,a));return i}(t,r);if(ArrayBuffer.isView(t))return u(t);if(null==t)throw TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t);if(N(t,ArrayBuffer)||t&&N(t.buffer,ArrayBuffer))return function(t,r,n){if(r<0||t.byteLength<r)throw new RangeError('\"offset\" is outside of buffer bounds');if(t.byteLength<r+(n||0))throw new RangeError('\"length\" is outside of buffer bounds');var i;i=void 0===r&&void 0===n?new Uint8Array(t):void 0===n?new Uint8Array(t,r):new Uint8Array(t,r,n);return i.__proto__=e.prototype,i}(t,r,n);if(\"number\"==typeof t)throw new TypeError('The \"value\" argument must not be of type number. Received type number');var i=t.valueOf&&t.valueOf();if(null!=i&&i!==t)return e.from(i,r,n);var a=function(t){if(e.isBuffer(t)){var r=0|h(t.length),n=o(r);return 0===n.length?n:(t.copy(n,0,0,r),n)}if(void 0!==t.length)return\"number\"!=typeof t.length||j(t.length)?o(0):u(t);if(\"Buffer\"===t.type&&Array.isArray(t.data))return u(t.data)}(t);if(a)return a;if(\"undefined\"!=typeof Symbol&&null!=Symbol.toPrimitive&&\"function\"==typeof t[Symbol.toPrimitive])return e.from(t[Symbol.toPrimitive](\"string\"),r,n);throw new TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t)}function l(t){if(\"number\"!=typeof t)throw new TypeError('\"size\" argument must be of type number');if(t<0)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"')}function c(t){return l(t),o(t<0?0:0|h(t))}function u(t){for(var e=t.length<0?0:0|h(t.length),r=o(e),n=0;n<e;n+=1)r[n]=255&t[n];return r}function h(t){if(t>=a)throw new RangeError(\"Attempt to allocate Buffer larger than maximum size: 0x\"+a.toString(16)+\" bytes\");return 0|t}function f(t,r){if(e.isBuffer(t))return t.length;if(ArrayBuffer.isView(t)||N(t,ArrayBuffer))return t.byteLength;if(\"string\"!=typeof t)throw new TypeError('The \"string\" argument must be one of type string, Buffer, or ArrayBuffer. Received type '+typeof t);var n=t.length,i=arguments.length>2&&!0===arguments[2];if(!i&&0===n)return 0;for(var a=!1;;)switch(r){case\"ascii\":case\"latin1\":case\"binary\":return n;case\"utf8\":case\"utf-8\":return R(t).length;case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return 2*n;case\"hex\":return n>>>1;case\"base64\":return F(t).length;default:if(a)return i?-1:R(t).length;r=(\"\"+r).toLowerCase(),a=!0}}function p(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function d(t,r,n,i,a){if(0===t.length)return-1;if(\"string\"==typeof n?(i=n,n=0):n>2147483647?n=2147483647:n<-2147483648&&(n=-2147483648),j(n=+n)&&(n=a?0:t.length-1),n<0&&(n=t.length+n),n>=t.length){if(a)return-1;n=t.length-1}else if(n<0){if(!a)return-1;n=0}if(\"string\"==typeof r&&(r=e.from(r,i)),e.isBuffer(r))return 0===r.length?-1:g(t,r,n,i,a);if(\"number\"==typeof r)return r&=255,\"function\"==typeof Uint8Array.prototype.indexOf?a?Uint8Array.prototype.indexOf.call(t,r,n):Uint8Array.prototype.lastIndexOf.call(t,r,n):g(t,[r],n,i,a);throw new TypeError(\"val must be string, number or Buffer\")}function g(t,e,r,n,i){var a,o=1,s=t.length,l=e.length;if(void 0!==n&&(\"ucs2\"===(n=String(n).toLowerCase())||\"ucs-2\"===n||\"utf16le\"===n||\"utf-16le\"===n)){if(t.length<2||e.length<2)return-1;o=2,s/=2,l/=2,r/=2}function c(t,e){return 1===o?t[e]:t.readUInt16BE(e*o)}if(i){var u=-1;for(a=r;a<s;a++)if(c(t,a)===c(e,-1===u?0:a-u)){if(-1===u&&(u=a),a-u+1===l)return u*o}else-1!==u&&(a-=a-u),u=-1}else for(r+l>s&&(r=s-l),a=r;a>=0;a--){for(var h=!0,f=0;f<l;f++)if(c(t,a+f)!==c(e,f)){h=!1;break}if(h)return a}return-1}function v(t,e,r,n){r=Number(r)||0;var i=t.length-r;n?(n=Number(n))>i&&(n=i):n=i;var a=e.length;n>a/2&&(n=a/2);for(var o=0;o<n;++o){var s=parseInt(e.substr(2*o,2),16);if(j(s))return o;t[r+o]=s}return o}function m(t,e,r,n){return B(R(e,t.length-r),t,r,n)}function y(t,e,r,n){return B(function(t){for(var e=[],r=0;r<t.length;++r)e.push(255&t.charCodeAt(r));return e}(e),t,r,n)}function x(t,e,r,n){return y(t,e,r,n)}function b(t,e,r,n){return B(F(e),t,r,n)}function _(t,e,r,n){return B(function(t,e){for(var r,n,i,a=[],o=0;o<t.length&&!((e-=2)<0);++o)r=t.charCodeAt(o),n=r>>8,i=r%256,a.push(i),a.push(n);return a}(e,t.length-r),t,r,n)}function w(t,e,r){return 0===e&&r===t.length?n.fromByteArray(t):n.fromByteArray(t.slice(e,r))}function k(t,e,r){r=Math.min(t.length,r);for(var n=[],i=e;i<r;){var a,o,s,l,c=t[i],u=null,h=c>239?4:c>223?3:c>191?2:1;if(i+h<=r)switch(h){case 1:c<128&&(u=c);break;case 2:128==(192&(a=t[i+1]))&&(l=(31&c)<<6|63&a)>127&&(u=l);break;case 3:a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&(l=(15&c)<<12|(63&a)<<6|63&o)>2047&&(l<55296||l>57343)&&(u=l);break;case 4:a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&(l=(15&c)<<18|(63&a)<<12|(63&o)<<6|63&s)>65535&&l<1114112&&(u=l)}null===u?(u=65533,h=1):u>65535&&(u-=65536,n.push(u>>>10&1023|55296),u=56320|1023&u),n.push(u),i+=h}return function(t){var e=t.length;if(e<=T)return String.fromCharCode.apply(String,t);var r=\"\",n=0;for(;n<e;)r+=String.fromCharCode.apply(String,t.slice(n,n+=T));return r}(n)}r.kMaxLength=a,e.TYPED_ARRAY_SUPPORT=function(){try{var t=new Uint8Array(1);return t.__proto__={__proto__:Uint8Array.prototype,foo:function(){return 42}},42===t.foo()}catch(t){return!1}}(),e.TYPED_ARRAY_SUPPORT||\"undefined\"==typeof console||\"function\"!=typeof console.error||console.error(\"This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support.\"),Object.defineProperty(e.prototype,\"parent\",{enumerable:!0,get:function(){if(e.isBuffer(this))return this.buffer}}),Object.defineProperty(e.prototype,\"offset\",{enumerable:!0,get:function(){if(e.isBuffer(this))return this.byteOffset}}),\"undefined\"!=typeof Symbol&&null!=Symbol.species&&e[Symbol.species]===e&&Object.defineProperty(e,Symbol.species,{value:null,configurable:!0,enumerable:!1,writable:!1}),e.poolSize=8192,e.from=function(t,e,r){return s(t,e,r)},e.prototype.__proto__=Uint8Array.prototype,e.__proto__=Uint8Array,e.alloc=function(t,e,r){return function(t,e,r){return l(t),t<=0?o(t):void 0!==e?\"string\"==typeof r?o(t).fill(e,r):o(t).fill(e):o(t)}(t,e,r)},e.allocUnsafe=function(t){return c(t)},e.allocUnsafeSlow=function(t){return c(t)},e.isBuffer=function(t){return null!=t&&!0===t._isBuffer&&t!==e.prototype},e.compare=function(t,r){if(N(t,Uint8Array)&&(t=e.from(t,t.offset,t.byteLength)),N(r,Uint8Array)&&(r=e.from(r,r.offset,r.byteLength)),!e.isBuffer(t)||!e.isBuffer(r))throw new TypeError('The \"buf1\", \"buf2\" arguments must be one of type Buffer or Uint8Array');if(t===r)return 0;for(var n=t.length,i=r.length,a=0,o=Math.min(n,i);a<o;++a)if(t[a]!==r[a]){n=t[a],i=r[a];break}return n<i?-1:i<n?1:0},e.isEncoding=function(t){switch(String(t).toLowerCase()){case\"hex\":case\"utf8\":case\"utf-8\":case\"ascii\":case\"latin1\":case\"binary\":case\"base64\":case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return!0;default:return!1}},e.concat=function(t,r){if(!Array.isArray(t))throw new TypeError('\"list\" argument must be an Array of Buffers');if(0===t.length)return e.alloc(0);var n;if(void 0===r)for(r=0,n=0;n<t.length;++n)r+=t[n].length;var i=e.allocUnsafe(r),a=0;for(n=0;n<t.length;++n){var o=t[n];if(N(o,Uint8Array)&&(o=e.from(o)),!e.isBuffer(o))throw new TypeError('\"list\" argument must be an Array of Buffers');o.copy(i,a),a+=o.length}return i},e.byteLength=f,e.prototype._isBuffer=!0,e.prototype.swap16=function(){var t=this.length;if(t%2!=0)throw new RangeError(\"Buffer size must be a multiple of 16-bits\");for(var e=0;e<t;e+=2)p(this,e,e+1);return this},e.prototype.swap32=function(){var t=this.length;if(t%4!=0)throw new RangeError(\"Buffer size must be a multiple of 32-bits\");for(var e=0;e<t;e+=4)p(this,e,e+3),p(this,e+1,e+2);return this},e.prototype.swap64=function(){var t=this.length;if(t%8!=0)throw new RangeError(\"Buffer size must be a multiple of 64-bits\");for(var e=0;e<t;e+=8)p(this,e,e+7),p(this,e+1,e+6),p(this,e+2,e+5),p(this,e+3,e+4);return this},e.prototype.toString=function(){var t=this.length;return 0===t?\"\":0===arguments.length?k(this,0,t):function(t,e,r){var n=!1;if((void 0===e||e<0)&&(e=0),e>this.length)return\"\";if((void 0===r||r>this.length)&&(r=this.length),r<=0)return\"\";if((r>>>=0)<=(e>>>=0))return\"\";for(t||(t=\"utf8\");;)switch(t){case\"hex\":return S(this,e,r);case\"utf8\":case\"utf-8\":return k(this,e,r);case\"ascii\":return A(this,e,r);case\"latin1\":case\"binary\":return M(this,e,r);case\"base64\":return w(this,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return E(this,e,r);default:if(n)throw new TypeError(\"Unknown encoding: \"+t);t=(t+\"\").toLowerCase(),n=!0}}.apply(this,arguments)},e.prototype.toLocaleString=e.prototype.toString,e.prototype.equals=function(t){if(!e.isBuffer(t))throw new TypeError(\"Argument must be a Buffer\");return this===t||0===e.compare(this,t)},e.prototype.inspect=function(){var t=\"\",e=r.INSPECT_MAX_BYTES;return t=this.toString(\"hex\",0,e).replace(/(.{2})/g,\"$1 \").trim(),this.length>e&&(t+=\" ... \"),\"<Buffer \"+t+\">\"},e.prototype.compare=function(t,r,n,i,a){if(N(t,Uint8Array)&&(t=e.from(t,t.offset,t.byteLength)),!e.isBuffer(t))throw new TypeError('The \"target\" argument must be one of type Buffer or Uint8Array. Received type '+typeof t);if(void 0===r&&(r=0),void 0===n&&(n=t?t.length:0),void 0===i&&(i=0),void 0===a&&(a=this.length),r<0||n>t.length||i<0||a>this.length)throw new RangeError(\"out of range index\");if(i>=a&&r>=n)return 0;if(i>=a)return-1;if(r>=n)return 1;if(this===t)return 0;for(var o=(a>>>=0)-(i>>>=0),s=(n>>>=0)-(r>>>=0),l=Math.min(o,s),c=this.slice(i,a),u=t.slice(r,n),h=0;h<l;++h)if(c[h]!==u[h]){o=c[h],s=u[h];break}return o<s?-1:s<o?1:0},e.prototype.includes=function(t,e,r){return-1!==this.indexOf(t,e,r)},e.prototype.indexOf=function(t,e,r){return d(this,t,e,r,!0)},e.prototype.lastIndexOf=function(t,e,r){return d(this,t,e,r,!1)},e.prototype.write=function(t,e,r,n){if(void 0===e)n=\"utf8\",r=this.length,e=0;else if(void 0===r&&\"string\"==typeof e)n=e,r=this.length,e=0;else{if(!isFinite(e))throw new Error(\"Buffer.write(string, encoding, offset[, length]) is no longer supported\");e>>>=0,isFinite(r)?(r>>>=0,void 0===n&&(n=\"utf8\")):(n=r,r=void 0)}var i=this.length-e;if((void 0===r||r>i)&&(r=i),t.length>0&&(r<0||e<0)||e>this.length)throw new RangeError(\"Attempt to write outside buffer bounds\");n||(n=\"utf8\");for(var a=!1;;)switch(n){case\"hex\":return v(this,t,e,r);case\"utf8\":case\"utf-8\":return m(this,t,e,r);case\"ascii\":return y(this,t,e,r);case\"latin1\":case\"binary\":return x(this,t,e,r);case\"base64\":return b(this,t,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return _(this,t,e,r);default:if(a)throw new TypeError(\"Unknown encoding: \"+n);n=(\"\"+n).toLowerCase(),a=!0}},e.prototype.toJSON=function(){return{type:\"Buffer\",data:Array.prototype.slice.call(this._arr||this,0)}};var T=4096;function A(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(127&t[i]);return n}function M(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(t[i]);return n}function S(t,e,r){var n=t.length;(!e||e<0)&&(e=0),(!r||r<0||r>n)&&(r=n);for(var i=\"\",a=e;a<r;++a)i+=D(t[a]);return i}function E(t,e,r){for(var n=t.slice(e,r),i=\"\",a=0;a<n.length;a+=2)i+=String.fromCharCode(n[a]+256*n[a+1]);return i}function C(t,e,r){if(t%1!=0||t<0)throw new RangeError(\"offset is not uint\");if(t+e>r)throw new RangeError(\"Trying to access beyond buffer length\")}function L(t,r,n,i,a,o){if(!e.isBuffer(t))throw new TypeError('\"buffer\" argument must be a Buffer instance');if(r>a||r<o)throw new RangeError('\"value\" argument is out of bounds');if(n+i>t.length)throw new RangeError(\"Index out of range\")}function P(t,e,r,n,i,a){if(r+n>t.length)throw new RangeError(\"Index out of range\");if(r<0)throw new RangeError(\"Index out of range\")}function O(t,e,r,n,a){return e=+e,r>>>=0,a||P(t,0,r,4),i.write(t,e,r,n,23,4),r+4}function z(t,e,r,n,a){return e=+e,r>>>=0,a||P(t,0,r,8),i.write(t,e,r,n,52,8),r+8}e.prototype.slice=function(t,r){var n=this.length;(t=~~t)<0?(t+=n)<0&&(t=0):t>n&&(t=n),(r=void 0===r?n:~~r)<0?(r+=n)<0&&(r=0):r>n&&(r=n),r<t&&(r=t);var i=this.subarray(t,r);return i.__proto__=e.prototype,i},e.prototype.readUIntLE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n},e.prototype.readUIntBE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t+--e],i=1;e>0&&(i*=256);)n+=this[t+--e]*i;return n},e.prototype.readUInt8=function(t,e){return t>>>=0,e||C(t,1,this.length),this[t]},e.prototype.readUInt16LE=function(t,e){return t>>>=0,e||C(t,2,this.length),this[t]|this[t+1]<<8},e.prototype.readUInt16BE=function(t,e){return t>>>=0,e||C(t,2,this.length),this[t]<<8|this[t+1]},e.prototype.readUInt32LE=function(t,e){return t>>>=0,e||C(t,4,this.length),(this[t]|this[t+1]<<8|this[t+2]<<16)+16777216*this[t+3]},e.prototype.readUInt32BE=function(t,e){return t>>>=0,e||C(t,4,this.length),16777216*this[t]+(this[t+1]<<16|this[t+2]<<8|this[t+3])},e.prototype.readIntLE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n>=(i*=128)&&(n-=Math.pow(2,8*e)),n},e.prototype.readIntBE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=e,i=1,a=this[t+--n];n>0&&(i*=256);)a+=this[t+--n]*i;return a>=(i*=128)&&(a-=Math.pow(2,8*e)),a},e.prototype.readInt8=function(t,e){return t>>>=0,e||C(t,1,this.length),128&this[t]?-1*(255-this[t]+1):this[t]},e.prototype.readInt16LE=function(t,e){t>>>=0,e||C(t,2,this.length);var r=this[t]|this[t+1]<<8;return 32768&r?4294901760|r:r},e.prototype.readInt16BE=function(t,e){t>>>=0,e||C(t,2,this.length);var r=this[t+1]|this[t]<<8;return 32768&r?4294901760|r:r},e.prototype.readInt32LE=function(t,e){return t>>>=0,e||C(t,4,this.length),this[t]|this[t+1]<<8|this[t+2]<<16|this[t+3]<<24},e.prototype.readInt32BE=function(t,e){return t>>>=0,e||C(t,4,this.length),this[t]<<24|this[t+1]<<16|this[t+2]<<8|this[t+3]},e.prototype.readFloatLE=function(t,e){return t>>>=0,e||C(t,4,this.length),i.read(this,t,!0,23,4)},e.prototype.readFloatBE=function(t,e){return t>>>=0,e||C(t,4,this.length),i.read(this,t,!1,23,4)},e.prototype.readDoubleLE=function(t,e){return t>>>=0,e||C(t,8,this.length),i.read(this,t,!0,52,8)},e.prototype.readDoubleBE=function(t,e){return t>>>=0,e||C(t,8,this.length),i.read(this,t,!1,52,8)},e.prototype.writeUIntLE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||L(this,t,e,r,Math.pow(2,8*r)-1,0);var i=1,a=0;for(this[e]=255&t;++a<r&&(i*=256);)this[e+a]=t/i&255;return e+r},e.prototype.writeUIntBE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||L(this,t,e,r,Math.pow(2,8*r)-1,0);var i=r-1,a=1;for(this[e+i]=255&t;--i>=0&&(a*=256);)this[e+i]=t/a&255;return e+r},e.prototype.writeUInt8=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,1,255,0),this[e]=255&t,e+1},e.prototype.writeUInt16LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,65535,0),this[e]=255&t,this[e+1]=t>>>8,e+2},e.prototype.writeUInt16BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,65535,0),this[e]=t>>>8,this[e+1]=255&t,e+2},e.prototype.writeUInt32LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,4294967295,0),this[e+3]=t>>>24,this[e+2]=t>>>16,this[e+1]=t>>>8,this[e]=255&t,e+4},e.prototype.writeUInt32BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,4294967295,0),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},e.prototype.writeIntLE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);L(this,t,e,r,i-1,-i)}var a=0,o=1,s=0;for(this[e]=255&t;++a<r&&(o*=256);)t<0&&0===s&&0!==this[e+a-1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},e.prototype.writeIntBE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);L(this,t,e,r,i-1,-i)}var a=r-1,o=1,s=0;for(this[e+a]=255&t;--a>=0&&(o*=256);)t<0&&0===s&&0!==this[e+a+1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},e.prototype.writeInt8=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,1,127,-128),t<0&&(t=255+t+1),this[e]=255&t,e+1},e.prototype.writeInt16LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,32767,-32768),this[e]=255&t,this[e+1]=t>>>8,e+2},e.prototype.writeInt16BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,32767,-32768),this[e]=t>>>8,this[e+1]=255&t,e+2},e.prototype.writeInt32LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,2147483647,-2147483648),this[e]=255&t,this[e+1]=t>>>8,this[e+2]=t>>>16,this[e+3]=t>>>24,e+4},e.prototype.writeInt32BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,2147483647,-2147483648),t<0&&(t=4294967295+t+1),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},e.prototype.writeFloatLE=function(t,e,r){return O(this,t,e,!0,r)},e.prototype.writeFloatBE=function(t,e,r){return O(this,t,e,!1,r)},e.prototype.writeDoubleLE=function(t,e,r){return z(this,t,e,!0,r)},e.prototype.writeDoubleBE=function(t,e,r){return z(this,t,e,!1,r)},e.prototype.copy=function(t,r,n,i){if(!e.isBuffer(t))throw new TypeError(\"argument should be a Buffer\");if(n||(n=0),i||0===i||(i=this.length),r>=t.length&&(r=t.length),r||(r=0),i>0&&i<n&&(i=n),i===n)return 0;if(0===t.length||0===this.length)return 0;if(r<0)throw new RangeError(\"targetStart out of bounds\");if(n<0||n>=this.length)throw new RangeError(\"Index out of range\");if(i<0)throw new RangeError(\"sourceEnd out of bounds\");i>this.length&&(i=this.length),t.length-r<i-n&&(i=t.length-r+n);var a=i-n;if(this===t&&\"function\"==typeof Uint8Array.prototype.copyWithin)this.copyWithin(r,n,i);else if(this===t&&n<r&&r<i)for(var o=a-1;o>=0;--o)t[o+r]=this[o+n];else Uint8Array.prototype.set.call(t,this.subarray(n,i),r);return a},e.prototype.fill=function(t,r,n,i){if(\"string\"==typeof t){if(\"string\"==typeof r?(i=r,r=0,n=this.length):\"string\"==typeof n&&(i=n,n=this.length),void 0!==i&&\"string\"!=typeof i)throw new TypeError(\"encoding must be a string\");if(\"string\"==typeof i&&!e.isEncoding(i))throw new TypeError(\"Unknown encoding: \"+i);if(1===t.length){var a=t.charCodeAt(0);(\"utf8\"===i&&a<128||\"latin1\"===i)&&(t=a)}}else\"number\"==typeof t&&(t&=255);if(r<0||this.length<r||this.length<n)throw new RangeError(\"Out of range index\");if(n<=r)return this;var o;if(r>>>=0,n=void 0===n?this.length:n>>>0,t||(t=0),\"number\"==typeof t)for(o=r;o<n;++o)this[o]=t;else{var s=e.isBuffer(t)?t:e.from(t,i),l=s.length;if(0===l)throw new TypeError('The value \"'+t+'\" is invalid for argument \"value\"');for(o=0;o<n-r;++o)this[o+r]=s[o%l]}return this};var I=/[^+\\/0-9A-Za-z-_]/g;function D(t){return t<16?\"0\"+t.toString(16):t.toString(16)}function R(t,e){var r;e=e||1/0;for(var n=t.length,i=null,a=[],o=0;o<n;++o){if((r=t.charCodeAt(o))>55295&&r<57344){if(!i){if(r>56319){(e-=3)>-1&&a.push(239,191,189);continue}if(o+1===n){(e-=3)>-1&&a.push(239,191,189);continue}i=r;continue}if(r<56320){(e-=3)>-1&&a.push(239,191,189),i=r;continue}r=65536+(i-55296<<10|r-56320)}else i&&(e-=3)>-1&&a.push(239,191,189);if(i=null,r<128){if((e-=1)<0)break;a.push(r)}else if(r<2048){if((e-=2)<0)break;a.push(r>>6|192,63&r|128)}else if(r<65536){if((e-=3)<0)break;a.push(r>>12|224,r>>6&63|128,63&r|128)}else{if(!(r<1114112))throw new Error(\"Invalid code point\");if((e-=4)<0)break;a.push(r>>18|240,r>>12&63|128,r>>6&63|128,63&r|128)}}return a}function F(t){return n.toByteArray(function(t){if((t=(t=t.split(\"=\")[0]).trim().replace(I,\"\")).length<2)return\"\";for(;t.length%4!=0;)t+=\"=\";return t}(t))}function B(t,e,r,n){for(var i=0;i<n&&!(i+r>=e.length||i>=t.length);++i)e[i+r]=t[i];return i}function N(t,e){return t instanceof e||null!=t&&null!=t.constructor&&null!=t.constructor.name&&t.constructor.name===e.name}function j(t){return t!=t}}).call(this,t(\"buffer\").Buffer)},{\"base64-js\":74,buffer:105,ieee754:412}],106:[function(t,e,r){\"use strict\";var n=t(\"./lib/monotone\"),i=t(\"./lib/triangulation\"),a=t(\"./lib/delaunay\"),o=t(\"./lib/filter\");function s(t){return[Math.min(t[0],t[1]),Math.max(t[0],t[1])]}function l(t,e){return t[0]-e[0]||t[1]-e[1]}function c(t,e,r){return e in t?t[e]:r}e.exports=function(t,e,r){Array.isArray(e)?(r=r||{},e=e||[]):(r=e||{},e=[]);var u=!!c(r,\"delaunay\",!0),h=!!c(r,\"interior\",!0),f=!!c(r,\"exterior\",!0),p=!!c(r,\"infinity\",!1);if(!h&&!f||0===t.length)return[];var d=n(t,e);if(u||h!==f||p){for(var g=i(t.length,function(t){return t.map(s).sort(l)}(e)),v=0;v<d.length;++v){var m=d[v];g.addTriangle(m[0],m[1],m[2])}return u&&a(t,g),f?h?p?o(g,0,p):g.cells():o(g,1,p):o(g,-1)}return d}},{\"./lib/delaunay\":107,\"./lib/filter\":108,\"./lib/monotone\":109,\"./lib/triangulation\":110}],107:[function(t,e,r){\"use strict\";var n=t(\"robust-in-sphere\")[4];t(\"binary-search-bounds\");function i(t,e,r,i,a,o){var s=e.opposite(i,a);if(!(s<0)){if(a<i){var l=i;i=a,a=l,l=o,o=s,s=l}e.isConstraint(i,a)||n(t[i],t[a],t[o],t[s])<0&&r.push(i,a)}}e.exports=function(t,e){for(var r=[],a=t.length,o=e.stars,s=0;s<a;++s)for(var l=o[s],c=1;c<l.length;c+=2){var u=l[c];if(!(u<s)&&!e.isConstraint(s,u)){for(var h=l[c-1],f=-1,p=1;p<l.length;p+=2)if(l[p-1]===u){f=l[p];break}f<0||n(t[s],t[u],t[h],t[f])<0&&r.push(s,u)}}for(;r.length>0;){for(var u=r.pop(),s=r.pop(),h=-1,f=-1,l=o[s],d=1;d<l.length;d+=2){var g=l[d-1],v=l[d];g===u?f=v:v===u&&(h=g)}h<0||f<0||(n(t[s],t[u],t[h],t[f])>=0||(e.flip(s,u),i(t,e,r,h,s,f),i(t,e,r,s,f,h),i(t,e,r,f,u,h),i(t,e,r,u,h,f)))}}},{\"binary-search-bounds\":111,\"robust-in-sphere\":508}],108:[function(t,e,r){\"use strict\";var n,i=t(\"binary-search-bounds\");function a(t,e,r,n,i,a,o){this.cells=t,this.neighbor=e,this.flags=n,this.constraint=r,this.active=i,this.next=a,this.boundary=o}function o(t,e){return t[0]-e[0]||t[1]-e[1]||t[2]-e[2]}e.exports=function(t,e,r){var n=function(t,e){for(var r=t.cells(),n=r.length,i=0;i<n;++i){var s=r[i],l=s[0],c=s[1],u=s[2];c<u?c<l&&(s[0]=c,s[1]=u,s[2]=l):u<l&&(s[0]=u,s[1]=l,s[2]=c)}r.sort(o);for(var h=new Array(n),i=0;i<h.length;++i)h[i]=0;var f=[],p=[],d=new Array(3*n),g=new Array(3*n),v=null;e&&(v=[]);for(var m=new a(r,d,g,h,f,p,v),i=0;i<n;++i)for(var s=r[i],y=0;y<3;++y){var l=s[y],c=s[(y+1)%3],x=d[3*i+y]=m.locate(c,l,t.opposite(c,l)),b=g[3*i+y]=t.isConstraint(l,c);x<0&&(b?p.push(i):(f.push(i),h[i]=1),e&&v.push([c,l,-1]))}return m}(t,r);if(0===e)return r?n.cells.concat(n.boundary):n.cells;var i=1,s=n.active,l=n.next,c=n.flags,u=n.cells,h=n.constraint,f=n.neighbor;for(;s.length>0||l.length>0;){for(;s.length>0;){var p=s.pop();if(c[p]!==-i){c[p]=i;u[p];for(var d=0;d<3;++d){var g=f[3*p+d];g>=0&&0===c[g]&&(h[3*p+d]?l.push(g):(s.push(g),c[g]=i))}}}var v=l;l=s,s=v,l.length=0,i=-i}var m=function(t,e,r){for(var n=0,i=0;i<t.length;++i)e[i]===r&&(t[n++]=t[i]);return t.length=n,t}(u,c,e);if(r)return m.concat(n.boundary);return m},a.prototype.locate=(n=[0,0,0],function(t,e,r){var a=t,s=e,l=r;return e<r?e<t&&(a=e,s=r,l=t):r<t&&(a=r,s=t,l=e),a<0?-1:(n[0]=a,n[1]=s,n[2]=l,i.eq(this.cells,n,o))})},{\"binary-search-bounds\":111}],109:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"robust-orientation\")[3],a=0,o=1,s=2;function l(t,e,r,n,i){this.a=t,this.b=e,this.idx=r,this.lowerIds=n,this.upperIds=i}function c(t,e,r,n){this.a=t,this.b=e,this.type=r,this.idx=n}function u(t,e){var r=t.a[0]-e.a[0]||t.a[1]-e.a[1]||t.type-e.type;return r||(t.type!==a&&(r=i(t.a,t.b,e.b))?r:t.idx-e.idx)}function h(t,e){return i(t.a,t.b,e)}function f(t,e,r,a,o){for(var s=n.lt(e,a,h),l=n.gt(e,a,h),c=s;c<l;++c){for(var u=e[c],f=u.lowerIds,p=f.length;p>1&&i(r[f[p-2]],r[f[p-1]],a)>0;)t.push([f[p-1],f[p-2],o]),p-=1;f.length=p,f.push(o);var d=u.upperIds;for(p=d.length;p>1&&i(r[d[p-2]],r[d[p-1]],a)<0;)t.push([d[p-2],d[p-1],o]),p-=1;d.length=p,d.push(o)}}function p(t,e){var r;return(r=t.a[0]<e.a[0]?i(t.a,t.b,e.a):i(e.b,e.a,t.a))?r:(r=e.b[0]<t.b[0]?i(t.a,t.b,e.b):i(e.b,e.a,t.b))||t.idx-e.idx}function d(t,e,r){var i=n.le(t,r,p),a=t[i],o=a.upperIds,s=o[o.length-1];a.upperIds=[s],t.splice(i+1,0,new l(r.a,r.b,r.idx,[s],o))}function g(t,e,r){var i=r.a;r.a=r.b,r.b=i;var a=n.eq(t,r,p),o=t[a];t[a-1].upperIds=o.upperIds,t.splice(a,1)}e.exports=function(t,e){for(var r=t.length,n=e.length,i=[],h=0;h<r;++h)i.push(new c(t[h],null,a,h));for(var h=0;h<n;++h){var p=e[h],v=t[p[0]],m=t[p[1]];v[0]<m[0]?i.push(new c(v,m,s,h),new c(m,v,o,h)):v[0]>m[0]&&i.push(new c(m,v,s,h),new c(v,m,o,h))}i.sort(u);for(var y=i[0].a[0]-(1+Math.abs(i[0].a[0]))*Math.pow(2,-52),x=[new l([y,1],[y,0],-1,[],[],[],[])],b=[],h=0,_=i.length;h<_;++h){var w=i[h],k=w.type;k===a?f(b,x,t,w.a,w.idx):k===s?d(x,t,w):g(x,t,w)}return b}},{\"binary-search-bounds\":111,\"robust-orientation\":510}],110:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\");function i(t,e){this.stars=t,this.edges=e}e.exports=function(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=[];return new i(r,e)};var a=i.prototype;function o(t,e,r){for(var n=1,i=t.length;n<i;n+=2)if(t[n-1]===e&&t[n]===r)return t[n-1]=t[i-2],t[n]=t[i-1],void(t.length=i-2)}a.isConstraint=function(){var t=[0,0];function e(t,e){return t[0]-e[0]||t[1]-e[1]}return function(r,i){return t[0]=Math.min(r,i),t[1]=Math.max(r,i),n.eq(this.edges,t,e)>=0}}(),a.removeTriangle=function(t,e,r){var n=this.stars;o(n[t],e,r),o(n[e],r,t),o(n[r],t,e)},a.addTriangle=function(t,e,r){var n=this.stars;n[t].push(e,r),n[e].push(r,t),n[r].push(t,e)},a.opposite=function(t,e){for(var r=this.stars[e],n=1,i=r.length;n<i;n+=2)if(r[n]===t)return r[n-1];return-1},a.flip=function(t,e){var r=this.opposite(t,e),n=this.opposite(e,t);this.removeTriangle(t,e,r),this.removeTriangle(e,t,n),this.addTriangle(t,n,r),this.addTriangle(e,r,n)},a.edges=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2)e.push([i[a],i[a+1]]);return e},a.cells=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2){var s=i[a],l=i[a+1];r<Math.min(s,l)&&e.push([r,s,l])}return e}},{\"binary-search-bounds\":111}],111:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",i?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a[m]\"];return i?e.indexOf(\"c\")<0?a.push(\";if(x===y){return m}else if(x<=y){\"):a.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):a.push(\";if(\",e,\"){i=m;\"),r?a.push(\"l=m+1}else{h=m-1}\"):a.push(\"h=m-1}else{l=m+1}\"),a.push(\"}\"),i?a.push(\"return -1};\"):a.push(\"return i};\"),a.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(typeof(c)==='function'){return P(a,(l===void 0)?0:l|0,(h===void 0)?a.length-1:h|0,y,c)}else{return A(a,(c===void 0)?0:c|0,(l===void 0)?a.length-1:l|0,y)}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],112:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1,r=1;r<t.length;++r)for(var n=0;n<r;++n)if(t[r]<t[n])e=-e;else if(t[n]===t[r])return 0;return e}},{}],113:[function(t,e,r){\"use strict\";var n=t(\"dup\"),i=t(\"robust-linear-solve\");function a(t,e){for(var r=0,n=t.length,i=0;i<n;++i)r+=t[i]*e[i];return r}function o(t){var e=t.length;if(0===e)return[];t[0].length;var r=n([t.length+1,t.length+1],1),o=n([t.length+1],1);r[e][e]=0;for(var s=0;s<e;++s){for(var l=0;l<=s;++l)r[l][s]=r[s][l]=2*a(t[s],t[l]);o[s]=a(t[s],t[s])}var c=i(r,o),u=0,h=c[e+1];for(s=0;s<h.length;++s)u+=h[s];var f=new Array(e);for(s=0;s<e;++s){h=c[s];var p=0;for(l=0;l<h.length;++l)p+=h[l];f[s]=p/u}return f}function s(t){if(0===t.length)return[];for(var e=t[0].length,r=n([e]),i=o(t),a=0;a<t.length;++a)for(var s=0;s<e;++s)r[s]+=t[a][s]*i[a];return r}s.barycenetric=o,e.exports=s},{dup:170,\"robust-linear-solve\":509}],114:[function(t,e,r){e.exports=function(t){for(var e=n(t),r=0,i=0;i<t.length;++i)for(var a=t[i],o=0;o<e.length;++o)r+=Math.pow(a[o]-e[o],2);return Math.sqrt(r/t.length)};var n=t(\"circumcenter\")},{circumcenter:113}],115:[function(t,e,r){e.exports=function(t,e,r){return e<r?t<e?e:t>r?r:t:t<r?r:t>e?e:t}},{}],116:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n;if(r){n=e;for(var i=new Array(e.length),a=0;a<e.length;++a){var o=e[a];i[a]=[o[0],o[1],r[a]]}e=i}var s=function(t,e,r){var n=d(t,[],p(t));return m(e,n,r),!!n}(t,e,!!r);for(;y(t,e,!!r);)s=!0;if(r&&s){n.length=0,r.length=0;for(var a=0;a<e.length;++a){var o=e[a];n.push([o[0],o[1]]),r.push(o[2])}}return s};var n=t(\"union-find\"),i=t(\"box-intersect\"),a=t(\"robust-segment-intersect\"),o=t(\"big-rat\"),s=t(\"big-rat/cmp\"),l=t(\"big-rat/to-float\"),c=t(\"rat-vec\"),u=t(\"nextafter\"),h=t(\"./lib/rat-seg-intersect\");function f(t){var e=l(t);return[u(e,-1/0),u(e,1/0)]}function p(t){for(var e=new Array(t.length),r=0;r<t.length;++r){var n=t[r];e[r]=[u(n[0],-1/0),u(n[1],-1/0),u(n[0],1/0),u(n[1],1/0)]}return e}function d(t,e,r){for(var a=e.length,o=new n(a),s=[],l=0;l<e.length;++l){var c=e[l],h=f(c[0]),p=f(c[1]);s.push([u(h[0],-1/0),u(p[0],-1/0),u(h[1],1/0),u(p[1],1/0)])}i(s,function(t,e){o.link(t,e)});var d=!0,g=new Array(a);for(l=0;l<a;++l){(m=o.find(l))!==l&&(d=!1,t[m]=[Math.min(t[l][0],t[m][0]),Math.min(t[l][1],t[m][1])])}if(d)return null;var v=0;for(l=0;l<a;++l){var m;(m=o.find(l))===l?(g[l]=v,t[v++]=t[l]):g[l]=-1}t.length=v;for(l=0;l<a;++l)g[l]<0&&(g[l]=g[o.find(l)]);return g}function g(t,e){return t[0]-e[0]||t[1]-e[1]}function v(t,e){var r=t[0]-e[0]||t[1]-e[1];return r||(t[2]<e[2]?-1:t[2]>e[2]?1:0)}function m(t,e,r){if(0!==t.length){if(e)for(var n=0;n<t.length;++n){var i=e[(o=t[n])[0]],a=e[o[1]];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}else for(n=0;n<t.length;++n){var o;i=(o=t[n])[0],a=o[1];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}r?t.sort(v):t.sort(g);var s=1;for(n=1;n<t.length;++n){var l=t[n-1],c=t[n];(c[0]!==l[0]||c[1]!==l[1]||r&&c[2]!==l[2])&&(t[s++]=c)}t.length=s}}function y(t,e,r){var n=function(t,e){for(var r=new Array(e.length),n=0;n<e.length;++n){var i=e[n],a=t[i[0]],o=t[i[1]];r[n]=[u(Math.min(a[0],o[0]),-1/0),u(Math.min(a[1],o[1]),-1/0),u(Math.max(a[0],o[0]),1/0),u(Math.max(a[1],o[1]),1/0)]}return r}(t,e),f=function(t,e,r){var n=[];return i(r,function(r,i){var o=e[r],s=e[i];if(o[0]!==s[0]&&o[0]!==s[1]&&o[1]!==s[0]&&o[1]!==s[1]){var l=t[o[0]],c=t[o[1]],u=t[s[0]],h=t[s[1]];a(l,c,u,h)&&n.push([r,i])}}),n}(t,e,n),g=p(t),v=function(t,e,r,n){var o=[];return i(r,n,function(r,n){var i=e[r];if(i[0]!==n&&i[1]!==n){var s=t[n],l=t[i[0]],c=t[i[1]];a(l,c,s,s)&&o.push([r,n])}}),o}(t,e,n,g),y=d(t,function(t,e,r,n,i){var a,u,f=t.map(function(t){return[o(t[0]),o(t[1])]});for(a=0;a<r.length;++a){var p=r[a];u=p[0];var d=p[1],g=e[u],v=e[d],m=h(c(t[g[0]]),c(t[g[1]]),c(t[v[0]]),c(t[v[1]]));if(m){var y=t.length;t.push([l(m[0]),l(m[1])]),f.push(m),n.push([u,y],[d,y])}}for(n.sort(function(t,e){if(t[0]!==e[0])return t[0]-e[0];var r=f[t[1]],n=f[e[1]];return s(r[0],n[0])||s(r[1],n[1])}),a=n.length-1;a>=0;--a){var x=e[u=(S=n[a])[0]],b=x[0],_=x[1],w=t[b],k=t[_];if((w[0]-k[0]||w[1]-k[1])<0){var T=b;b=_,_=T}x[0]=b;var A,M=x[1]=S[1];for(i&&(A=x[2]);a>0&&n[a-1][0]===u;){var S,E=(S=n[--a])[1];i?e.push([M,E,A]):e.push([M,E]),M=E}i?e.push([M,_,A]):e.push([M,_])}return f}(t,e,f,v,r));return m(e,y,r),!!y||(f.length>0||v.length>0)}},{\"./lib/rat-seg-intersect\":117,\"big-rat\":78,\"big-rat/cmp\":76,\"big-rat/to-float\":90,\"box-intersect\":96,nextafter:451,\"rat-vec\":486,\"robust-segment-intersect\":513,\"union-find\":546}],117:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var a=s(e,t),h=s(n,r),f=u(a,h);if(0===o(f))return null;var p=s(t,r),d=u(h,p),g=i(d,f),v=c(a,g);return l(t,v)};var n=t(\"big-rat/mul\"),i=t(\"big-rat/div\"),a=t(\"big-rat/sub\"),o=t(\"big-rat/sign\"),s=t(\"rat-vec/sub\"),l=t(\"rat-vec/add\"),c=t(\"rat-vec/muls\");function u(t,e){return a(n(t[0],e[1]),n(t[1],e[0]))}},{\"big-rat/div\":77,\"big-rat/mul\":87,\"big-rat/sign\":88,\"big-rat/sub\":89,\"rat-vec/add\":485,\"rat-vec/muls\":487,\"rat-vec/sub\":488}],118:[function(t,e,r){\"use strict\";var n=t(\"clamp\");function i(t,e){null==e&&(e=!0);var r=t[0],i=t[1],a=t[2],o=t[3];return null==o&&(o=e?1:255),e&&(r*=255,i*=255,a*=255,o*=255),16777216*(r=255&n(r,0,255))+((i=255&n(i,0,255))<<16)+((a=255&n(a,0,255))<<8)+(o=255&n(o,0,255))}e.exports=i,e.exports.to=i,e.exports.from=function(t,e){var r=(t=+t)>>>24,n=(16711680&t)>>>16,i=(65280&t)>>>8,a=255&t;return!1===e?[r,n,i,a]:[r/255,n/255,i/255,a/255]}},{clamp:115}],119:[function(t,e,r){\"use strict\";e.exports={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]}},{}],120:[function(t,e,r){\"use strict\";var n=t(\"color-rgba\"),i=t(\"clamp\"),a=t(\"dtype\");e.exports=function(t,e){\"float\"!==e&&e||(e=\"array\"),\"uint\"===e&&(e=\"uint8\"),\"uint_clamped\"===e&&(e=\"uint8_clamped\");var r=new(a(e))(4),o=\"uint8\"!==e&&\"uint8_clamped\"!==e;return t.length&&\"string\"!=typeof t||((t=n(t))[0]/=255,t[1]/=255,t[2]/=255),function(t){return t instanceof Uint8Array||t instanceof Uint8ClampedArray||!!(Array.isArray(t)&&(t[0]>1||0===t[0])&&(t[1]>1||0===t[1])&&(t[2]>1||0===t[2])&&(!t[3]||t[3]>1))}(t)?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:255,o&&(r[0]/=255,r[1]/=255,r[2]/=255,r[3]/=255),r):(o?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:1):(r[0]=i(Math.floor(255*t[0]),0,255),r[1]=i(Math.floor(255*t[1]),0,255),r[2]=i(Math.floor(255*t[2]),0,255),r[3]=null==t[3]?255:i(Math.floor(255*t[3]),0,255)),r)}},{clamp:115,\"color-rgba\":122,dtype:169}],121:[function(t,e,r){(function(r){\"use strict\";var n=t(\"color-name\"),i=t(\"is-plain-obj\"),a=t(\"defined\");e.exports=function(t){var e,s,l=[],c=1;if(\"string\"==typeof t)if(n[t])l=n[t].slice(),s=\"rgb\";else if(\"transparent\"===t)c=0,s=\"rgb\",l=[0,0,0];else if(/^#[A-Fa-f0-9]+$/.test(t)){var u=t.slice(1),h=u.length,f=h<=4;c=1,f?(l=[parseInt(u[0]+u[0],16),parseInt(u[1]+u[1],16),parseInt(u[2]+u[2],16)],4===h&&(c=parseInt(u[3]+u[3],16)/255)):(l=[parseInt(u[0]+u[1],16),parseInt(u[2]+u[3],16),parseInt(u[4]+u[5],16)],8===h&&(c=parseInt(u[6]+u[7],16)/255)),l[0]||(l[0]=0),l[1]||(l[1]=0),l[2]||(l[2]=0),s=\"rgb\"}else if(e=/^((?:rgb|hs[lvb]|hwb|cmyk?|xy[zy]|gray|lab|lchu?v?|[ly]uv|lms)a?)\\s*\\(([^\\)]*)\\)/.exec(t)){var p=e[1],d=\"rgb\"===p,u=p.replace(/a$/,\"\");s=u;var h=\"cmyk\"===u?4:\"gray\"===u?1:3;l=e[2].trim().split(/\\s*,\\s*/).map(function(t,e){if(/%$/.test(t))return e===h?parseFloat(t)/100:\"rgb\"===u?255*parseFloat(t)/100:parseFloat(t);if(\"h\"===u[e]){if(/deg$/.test(t))return parseFloat(t);if(void 0!==o[t])return o[t]}return parseFloat(t)}),p===u&&l.push(1),c=d?1:void 0===l[h]?1:l[h],l=l.slice(0,h)}else t.length>10&&/[0-9](?:\\s|\\/)/.test(t)&&(l=t.match(/([0-9]+)/g).map(function(t){return parseFloat(t)}),s=t.match(/([a-z])/gi).join(\"\").toLowerCase());else if(isNaN(t))if(i(t)){var g=a(t.r,t.red,t.R,null);null!==g?(s=\"rgb\",l=[g,a(t.g,t.green,t.G),a(t.b,t.blue,t.B)]):(s=\"hsl\",l=[a(t.h,t.hue,t.H),a(t.s,t.saturation,t.S),a(t.l,t.lightness,t.L,t.b,t.brightness)]),c=a(t.a,t.alpha,t.opacity,1),null!=t.opacity&&(c/=100)}else(Array.isArray(t)||r.ArrayBuffer&&ArrayBuffer.isView&&ArrayBuffer.isView(t))&&(l=[t[0],t[1],t[2]],s=\"rgb\",c=4===t.length?t[3]:1);else s=\"rgb\",l=[t>>>16,(65280&t)>>>8,255&t];return{space:s,values:l,alpha:c}};var o={red:0,orange:60,yellow:120,green:180,blue:240,purple:300}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"color-name\":119,defined:164,\"is-plain-obj\":422}],122:[function(t,e,r){\"use strict\";var n=t(\"color-parse\"),i=t(\"color-space/hsl\"),a=t(\"clamp\");e.exports=function(t){var e,r=n(t);return r.space?((e=Array(3))[0]=a(r.values[0],0,255),e[1]=a(r.values[1],0,255),e[2]=a(r.values[2],0,255),\"h\"===r.space[0]&&(e=i.rgb(e)),e.push(a(r.alpha,0,1)),e):[]}},{clamp:115,\"color-parse\":121,\"color-space/hsl\":123}],123:[function(t,e,r){\"use strict\";var n=t(\"./rgb\");e.exports={name:\"hsl\",min:[0,0,0],max:[360,100,100],channel:[\"hue\",\"saturation\",\"lightness\"],alias:[\"HSL\"],rgb:function(t){var e,r,n,i,a,o=t[0]/360,s=t[1]/100,l=t[2]/100;if(0===s)return[a=255*l,a,a];e=2*l-(r=l<.5?l*(1+s):l+s-l*s),i=[0,0,0];for(var c=0;c<3;c++)(n=o+1/3*-(c-1))<0?n++:n>1&&n--,a=6*n<1?e+6*(r-e)*n:2*n<1?r:3*n<2?e+(r-e)*(2/3-n)*6:e,i[c]=255*a;return i}},n.hsl=function(t){var e,r,n=t[0]/255,i=t[1]/255,a=t[2]/255,o=Math.min(n,i,a),s=Math.max(n,i,a),l=s-o;return s===o?e=0:n===s?e=(i-a)/l:i===s?e=2+(a-n)/l:a===s&&(e=4+(n-i)/l),(e=Math.min(60*e,360))<0&&(e+=360),r=(o+s)/2,[e,100*(s===o?0:r<=.5?l/(s+o):l/(2-s-o)),100*r]}},{\"./rgb\":124}],124:[function(t,e,r){\"use strict\";e.exports={name:\"rgb\",min:[0,0,0],max:[255,255,255],channel:[\"red\",\"green\",\"blue\"],alias:[\"RGB\"]}},{}],125:[function(t,e,r){e.exports={jet:[{index:0,rgb:[0,0,131]},{index:.125,rgb:[0,60,170]},{index:.375,rgb:[5,255,255]},{index:.625,rgb:[255,255,0]},{index:.875,rgb:[250,0,0]},{index:1,rgb:[128,0,0]}],hsv:[{index:0,rgb:[255,0,0]},{index:.169,rgb:[253,255,2]},{index:.173,rgb:[247,255,2]},{index:.337,rgb:[0,252,4]},{index:.341,rgb:[0,252,10]},{index:.506,rgb:[1,249,255]},{index:.671,rgb:[2,0,253]},{index:.675,rgb:[8,0,253]},{index:.839,rgb:[255,0,251]},{index:.843,rgb:[255,0,245]},{index:1,rgb:[255,0,6]}],hot:[{index:0,rgb:[0,0,0]},{index:.3,rgb:[230,0,0]},{index:.6,rgb:[255,210,0]},{index:1,rgb:[255,255,255]}],cool:[{index:0,rgb:[0,255,255]},{index:1,rgb:[255,0,255]}],spring:[{index:0,rgb:[255,0,255]},{index:1,rgb:[255,255,0]}],summer:[{index:0,rgb:[0,128,102]},{index:1,rgb:[255,255,102]}],autumn:[{index:0,rgb:[255,0,0]},{index:1,rgb:[255,255,0]}],winter:[{index:0,rgb:[0,0,255]},{index:1,rgb:[0,255,128]}],bone:[{index:0,rgb:[0,0,0]},{index:.376,rgb:[84,84,116]},{index:.753,rgb:[169,200,200]},{index:1,rgb:[255,255,255]}],copper:[{index:0,rgb:[0,0,0]},{index:.804,rgb:[255,160,102]},{index:1,rgb:[255,199,127]}],greys:[{index:0,rgb:[0,0,0]},{index:1,rgb:[255,255,255]}],yignbu:[{index:0,rgb:[8,29,88]},{index:.125,rgb:[37,52,148]},{index:.25,rgb:[34,94,168]},{index:.375,rgb:[29,145,192]},{index:.5,rgb:[65,182,196]},{index:.625,rgb:[127,205,187]},{index:.75,rgb:[199,233,180]},{index:.875,rgb:[237,248,217]},{index:1,rgb:[255,255,217]}],greens:[{index:0,rgb:[0,68,27]},{index:.125,rgb:[0,109,44]},{index:.25,rgb:[35,139,69]},{index:.375,rgb:[65,171,93]},{index:.5,rgb:[116,196,118]},{index:.625,rgb:[161,217,155]},{index:.75,rgb:[199,233,192]},{index:.875,rgb:[229,245,224]},{index:1,rgb:[247,252,245]}],yiorrd:[{index:0,rgb:[128,0,38]},{index:.125,rgb:[189,0,38]},{index:.25,rgb:[227,26,28]},{index:.375,rgb:[252,78,42]},{index:.5,rgb:[253,141,60]},{index:.625,rgb:[254,178,76]},{index:.75,rgb:[254,217,118]},{index:.875,rgb:[255,237,160]},{index:1,rgb:[255,255,204]}],bluered:[{index:0,rgb:[0,0,255]},{index:1,rgb:[255,0,0]}],rdbu:[{index:0,rgb:[5,10,172]},{index:.35,rgb:[106,137,247]},{index:.5,rgb:[190,190,190]},{index:.6,rgb:[220,170,132]},{index:.7,rgb:[230,145,90]},{index:1,rgb:[178,10,28]}],picnic:[{index:0,rgb:[0,0,255]},{index:.1,rgb:[51,153,255]},{index:.2,rgb:[102,204,255]},{index:.3,rgb:[153,204,255]},{index:.4,rgb:[204,204,255]},{index:.5,rgb:[255,255,255]},{index:.6,rgb:[255,204,255]},{index:.7,rgb:[255,153,255]},{index:.8,rgb:[255,102,204]},{index:.9,rgb:[255,102,102]},{index:1,rgb:[255,0,0]}],rainbow:[{index:0,rgb:[150,0,90]},{index:.125,rgb:[0,0,200]},{index:.25,rgb:[0,25,255]},{index:.375,rgb:[0,152,255]},{index:.5,rgb:[44,255,150]},{index:.625,rgb:[151,255,0]},{index:.75,rgb:[255,234,0]},{index:.875,rgb:[255,111,0]},{index:1,rgb:[255,0,0]}],portland:[{index:0,rgb:[12,51,131]},{index:.25,rgb:[10,136,186]},{index:.5,rgb:[242,211,56]},{index:.75,rgb:[242,143,56]},{index:1,rgb:[217,30,30]}],blackbody:[{index:0,rgb:[0,0,0]},{index:.2,rgb:[230,0,0]},{index:.4,rgb:[230,210,0]},{index:.7,rgb:[255,255,255]},{index:1,rgb:[160,200,255]}],earth:[{index:0,rgb:[0,0,130]},{index:.1,rgb:[0,180,180]},{index:.2,rgb:[40,210,40]},{index:.4,rgb:[230,230,50]},{index:.6,rgb:[120,70,20]},{index:1,rgb:[255,255,255]}],electric:[{index:0,rgb:[0,0,0]},{index:.15,rgb:[30,0,100]},{index:.4,rgb:[120,0,100]},{index:.6,rgb:[160,90,0]},{index:.8,rgb:[230,200,0]},{index:1,rgb:[255,250,220]}],alpha:[{index:0,rgb:[255,255,255,0]},{index:1,rgb:[255,255,255,1]}],viridis:[{index:0,rgb:[68,1,84]},{index:.13,rgb:[71,44,122]},{index:.25,rgb:[59,81,139]},{index:.38,rgb:[44,113,142]},{index:.5,rgb:[33,144,141]},{index:.63,rgb:[39,173,129]},{index:.75,rgb:[92,200,99]},{index:.88,rgb:[170,220,50]},{index:1,rgb:[253,231,37]}],inferno:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[31,12,72]},{index:.25,rgb:[85,15,109]},{index:.38,rgb:[136,34,106]},{index:.5,rgb:[186,54,85]},{index:.63,rgb:[227,89,51]},{index:.75,rgb:[249,140,10]},{index:.88,rgb:[249,201,50]},{index:1,rgb:[252,255,164]}],magma:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[28,16,68]},{index:.25,rgb:[79,18,123]},{index:.38,rgb:[129,37,129]},{index:.5,rgb:[181,54,122]},{index:.63,rgb:[229,80,100]},{index:.75,rgb:[251,135,97]},{index:.88,rgb:[254,194,135]},{index:1,rgb:[252,253,191]}],plasma:[{index:0,rgb:[13,8,135]},{index:.13,rgb:[75,3,161]},{index:.25,rgb:[125,3,168]},{index:.38,rgb:[168,34,150]},{index:.5,rgb:[203,70,121]},{index:.63,rgb:[229,107,93]},{index:.75,rgb:[248,148,65]},{index:.88,rgb:[253,195,40]},{index:1,rgb:[240,249,33]}],warm:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[172,0,187]},{index:.25,rgb:[219,0,170]},{index:.38,rgb:[255,0,130]},{index:.5,rgb:[255,63,74]},{index:.63,rgb:[255,123,0]},{index:.75,rgb:[234,176,0]},{index:.88,rgb:[190,228,0]},{index:1,rgb:[147,255,0]}],cool:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[116,0,218]},{index:.25,rgb:[98,74,237]},{index:.38,rgb:[68,146,231]},{index:.5,rgb:[0,204,197]},{index:.63,rgb:[0,247,146]},{index:.75,rgb:[0,255,88]},{index:.88,rgb:[40,255,8]},{index:1,rgb:[147,255,0]}],\"rainbow-soft\":[{index:0,rgb:[125,0,179]},{index:.1,rgb:[199,0,180]},{index:.2,rgb:[255,0,121]},{index:.3,rgb:[255,108,0]},{index:.4,rgb:[222,194,0]},{index:.5,rgb:[150,255,0]},{index:.6,rgb:[0,255,55]},{index:.7,rgb:[0,246,150]},{index:.8,rgb:[50,167,222]},{index:.9,rgb:[103,51,235]},{index:1,rgb:[124,0,186]}],bathymetry:[{index:0,rgb:[40,26,44]},{index:.13,rgb:[59,49,90]},{index:.25,rgb:[64,76,139]},{index:.38,rgb:[63,110,151]},{index:.5,rgb:[72,142,158]},{index:.63,rgb:[85,174,163]},{index:.75,rgb:[120,206,163]},{index:.88,rgb:[187,230,172]},{index:1,rgb:[253,254,204]}],cdom:[{index:0,rgb:[47,15,62]},{index:.13,rgb:[87,23,86]},{index:.25,rgb:[130,28,99]},{index:.38,rgb:[171,41,96]},{index:.5,rgb:[206,67,86]},{index:.63,rgb:[230,106,84]},{index:.75,rgb:[242,149,103]},{index:.88,rgb:[249,193,135]},{index:1,rgb:[254,237,176]}],chlorophyll:[{index:0,rgb:[18,36,20]},{index:.13,rgb:[25,63,41]},{index:.25,rgb:[24,91,59]},{index:.38,rgb:[13,119,72]},{index:.5,rgb:[18,148,80]},{index:.63,rgb:[80,173,89]},{index:.75,rgb:[132,196,122]},{index:.88,rgb:[175,221,162]},{index:1,rgb:[215,249,208]}],density:[{index:0,rgb:[54,14,36]},{index:.13,rgb:[89,23,80]},{index:.25,rgb:[110,45,132]},{index:.38,rgb:[120,77,178]},{index:.5,rgb:[120,113,213]},{index:.63,rgb:[115,151,228]},{index:.75,rgb:[134,185,227]},{index:.88,rgb:[177,214,227]},{index:1,rgb:[230,241,241]}],\"freesurface-blue\":[{index:0,rgb:[30,4,110]},{index:.13,rgb:[47,14,176]},{index:.25,rgb:[41,45,236]},{index:.38,rgb:[25,99,212]},{index:.5,rgb:[68,131,200]},{index:.63,rgb:[114,156,197]},{index:.75,rgb:[157,181,203]},{index:.88,rgb:[200,208,216]},{index:1,rgb:[241,237,236]}],\"freesurface-red\":[{index:0,rgb:[60,9,18]},{index:.13,rgb:[100,17,27]},{index:.25,rgb:[142,20,29]},{index:.38,rgb:[177,43,27]},{index:.5,rgb:[192,87,63]},{index:.63,rgb:[205,125,105]},{index:.75,rgb:[216,162,148]},{index:.88,rgb:[227,199,193]},{index:1,rgb:[241,237,236]}],oxygen:[{index:0,rgb:[64,5,5]},{index:.13,rgb:[106,6,15]},{index:.25,rgb:[144,26,7]},{index:.38,rgb:[168,64,3]},{index:.5,rgb:[188,100,4]},{index:.63,rgb:[206,136,11]},{index:.75,rgb:[220,174,25]},{index:.88,rgb:[231,215,44]},{index:1,rgb:[248,254,105]}],par:[{index:0,rgb:[51,20,24]},{index:.13,rgb:[90,32,35]},{index:.25,rgb:[129,44,34]},{index:.38,rgb:[159,68,25]},{index:.5,rgb:[182,99,19]},{index:.63,rgb:[199,134,22]},{index:.75,rgb:[212,171,35]},{index:.88,rgb:[221,210,54]},{index:1,rgb:[225,253,75]}],phase:[{index:0,rgb:[145,105,18]},{index:.13,rgb:[184,71,38]},{index:.25,rgb:[186,58,115]},{index:.38,rgb:[160,71,185]},{index:.5,rgb:[110,97,218]},{index:.63,rgb:[50,123,164]},{index:.75,rgb:[31,131,110]},{index:.88,rgb:[77,129,34]},{index:1,rgb:[145,105,18]}],salinity:[{index:0,rgb:[42,24,108]},{index:.13,rgb:[33,50,162]},{index:.25,rgb:[15,90,145]},{index:.38,rgb:[40,118,137]},{index:.5,rgb:[59,146,135]},{index:.63,rgb:[79,175,126]},{index:.75,rgb:[120,203,104]},{index:.88,rgb:[193,221,100]},{index:1,rgb:[253,239,154]}],temperature:[{index:0,rgb:[4,35,51]},{index:.13,rgb:[23,51,122]},{index:.25,rgb:[85,59,157]},{index:.38,rgb:[129,79,143]},{index:.5,rgb:[175,95,130]},{index:.63,rgb:[222,112,101]},{index:.75,rgb:[249,146,66]},{index:.88,rgb:[249,196,65]},{index:1,rgb:[232,250,91]}],turbidity:[{index:0,rgb:[34,31,27]},{index:.13,rgb:[65,50,41]},{index:.25,rgb:[98,69,52]},{index:.38,rgb:[131,89,57]},{index:.5,rgb:[161,112,59]},{index:.63,rgb:[185,140,66]},{index:.75,rgb:[202,174,88]},{index:.88,rgb:[216,209,126]},{index:1,rgb:[233,246,171]}],\"velocity-blue\":[{index:0,rgb:[17,32,64]},{index:.13,rgb:[35,52,116]},{index:.25,rgb:[29,81,156]},{index:.38,rgb:[31,113,162]},{index:.5,rgb:[50,144,169]},{index:.63,rgb:[87,173,176]},{index:.75,rgb:[149,196,189]},{index:.88,rgb:[203,221,211]},{index:1,rgb:[254,251,230]}],\"velocity-green\":[{index:0,rgb:[23,35,19]},{index:.13,rgb:[24,64,38]},{index:.25,rgb:[11,95,45]},{index:.38,rgb:[39,123,35]},{index:.5,rgb:[95,146,12]},{index:.63,rgb:[152,165,18]},{index:.75,rgb:[201,186,69]},{index:.88,rgb:[233,216,137]},{index:1,rgb:[255,253,205]}],cubehelix:[{index:0,rgb:[0,0,0]},{index:.07,rgb:[22,5,59]},{index:.13,rgb:[60,4,105]},{index:.2,rgb:[109,1,135]},{index:.27,rgb:[161,0,147]},{index:.33,rgb:[210,2,142]},{index:.4,rgb:[251,11,123]},{index:.47,rgb:[255,29,97]},{index:.53,rgb:[255,54,69]},{index:.6,rgb:[255,85,46]},{index:.67,rgb:[255,120,34]},{index:.73,rgb:[255,157,37]},{index:.8,rgb:[241,191,57]},{index:.87,rgb:[224,220,93]},{index:.93,rgb:[218,241,142]},{index:1,rgb:[227,253,198]}]}},{}],126:[function(t,e,r){\"use strict\";var n=t(\"./colorScale\"),i=t(\"lerp\");function a(t){return[t[0]/255,t[1]/255,t[2]/255,t[3]]}function o(t){for(var e,r=\"#\",n=0;n<3;++n)r+=(\"00\"+(e=(e=t[n]).toString(16))).substr(e.length);return r}function s(t){return\"rgba(\"+t.join(\",\")+\")\"}e.exports=function(t){var e,r,l,c,u,h,f,p,d,g;t||(t={});p=(t.nshades||72)-1,f=t.format||\"hex\",(h=t.colormap)||(h=\"jet\");if(\"string\"==typeof h){if(h=h.toLowerCase(),!n[h])throw Error(h+\" not a supported colorscale\");u=n[h]}else{if(!Array.isArray(h))throw Error(\"unsupported colormap option\",h);u=h.slice()}if(u.length>p+1)throw new Error(h+\" map requires nshades to be at least size \"+u.length);d=Array.isArray(t.alpha)?2!==t.alpha.length?[1,1]:t.alpha.slice():\"number\"==typeof t.alpha?[t.alpha,t.alpha]:[1,1];e=u.map(function(t){return Math.round(t.index*p)}),d[0]=Math.min(Math.max(d[0],0),1),d[1]=Math.min(Math.max(d[1],0),1);var v=u.map(function(t,e){var r=u[e].index,n=u[e].rgb.slice();return 4===n.length&&n[3]>=0&&n[3]<=1?n:(n[3]=d[0]+(d[1]-d[0])*r,n)}),m=[];for(g=0;g<e.length-1;++g){c=e[g+1]-e[g],r=v[g],l=v[g+1];for(var y=0;y<c;y++){var x=y/c;m.push([Math.round(i(r[0],l[0],x)),Math.round(i(r[1],l[1],x)),Math.round(i(r[2],l[2],x)),i(r[3],l[3],x)])}}m.push(u[u.length-1].rgb.concat(d[1])),\"hex\"===f?m=m.map(o):\"rgbaString\"===f?m=m.map(s):\"float\"===f&&(m=m.map(a));return m}},{\"./colorScale\":125,lerp:425}],127:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a){var o=n(e,r,a);if(0===o){var s=i(n(t,e,r)),c=i(n(t,e,a));if(s===c){if(0===s){var u=l(t,e,r),h=l(t,e,a);return u===h?0:u?1:-1}return 0}return 0===c?s>0?-1:l(t,e,a)?-1:1:0===s?c>0?1:l(t,e,r)?1:-1:i(c-s)}var f=n(t,e,r);if(f>0)return o>0&&n(t,e,a)>0?1:-1;if(f<0)return o>0||n(t,e,a)>0?1:-1;var p=n(t,e,a);return p>0?1:l(t,e,r)?1:-1};var n=t(\"robust-orientation\"),i=t(\"signum\"),a=t(\"two-sum\"),o=t(\"robust-product\"),s=t(\"robust-sum\");function l(t,e,r){var n=a(t[0],-e[0]),i=a(t[1],-e[1]),l=a(r[0],-e[0]),c=a(r[1],-e[1]),u=s(o(n,l),o(i,c));return u[u.length-1]>=0}},{\"robust-orientation\":510,\"robust-product\":511,\"robust-sum\":515,signum:516,\"two-sum\":544}],128:[function(t,e,r){e.exports=function(t,e){var r=t.length,a=t.length-e.length;if(a)return a;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return t[0]+t[1]-e[0]-e[1]||n(t[0],t[1])-n(e[0],e[1]);case 3:var o=t[0]+t[1],s=e[0]+e[1];if(a=o+t[2]-(s+e[2]))return a;var l=n(t[0],t[1]),c=n(e[0],e[1]);return n(l,t[2])-n(c,e[2])||n(l+t[2],o)-n(c+e[2],s);case 4:var u=t[0],h=t[1],f=t[2],p=t[3],d=e[0],g=e[1],v=e[2],m=e[3];return u+h+f+p-(d+g+v+m)||n(u,h,f,p)-n(d,g,v,m,d)||n(u+h,u+f,u+p,h+f,h+p,f+p)-n(d+g,d+v,d+m,g+v,g+m,v+m)||n(u+h+f,u+h+p,u+f+p,h+f+p)-n(d+g+v,d+g+m,d+v+m,g+v+m);default:for(var y=t.slice().sort(i),x=e.slice().sort(i),b=0;b<r;++b)if(a=y[b]-x[b])return a;return 0}};var n=Math.min;function i(t,e){return t-e}},{}],129:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"cell-orientation\");e.exports=function(t,e){return n(t,e)||i(t)-i(e)}},{\"cell-orientation\":112,\"compare-cell\":128}],130:[function(t,e,r){\"use strict\";var n=t(\"./lib/ch1d\"),i=t(\"./lib/ch2d\"),a=t(\"./lib/chnd\");e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[[0]];var r=t[0].length;if(0===r)return[];if(1===r)return n(t);if(2===r)return i(t);return a(t,r)}},{\"./lib/ch1d\":131,\"./lib/ch2d\":132,\"./lib/chnd\":133}],131:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0,r=0,n=1;n<t.length;++n)t[n][0]<t[e][0]&&(e=n),t[n][0]>t[r][0]&&(r=n);return e<r?[[e],[r]]:e>r?[[r],[e]]:[[e]]}},{}],132:[function(t,e,r){\"use strict\";e.exports=function(t){var e=n(t),r=e.length;if(r<=2)return[];for(var i=new Array(r),a=e[r-1],o=0;o<r;++o){var s=e[o];i[o]=[a,s],a=s}return i};var n=t(\"monotone-convex-hull-2d\")},{\"monotone-convex-hull-2d\":434}],133:[function(t,e,r){\"use strict\";e.exports=function(t,e){try{return n(t,!0)}catch(s){var r=i(t);if(r.length<=e)return[];var a=function(t,e){for(var r=t.length,n=new Array(r),i=0;i<e.length;++i)n[i]=t[e[i]];for(var a=e.length,i=0;i<r;++i)e.indexOf(i)<0&&(n[a++]=t[i]);return n}(t,r),o=n(a,!0);return function(t,e){for(var r=t.length,n=e.length,i=0;i<r;++i)for(var a=t[i],o=0;o<a.length;++o){var s=a[o];if(s<n)a[o]=e[s];else{s-=n;for(var l=0;l<n;++l)s>=e[l]&&(s+=1);a[o]=s}}return t}(o,r)}};var n=t(\"incremental-convex-hull\"),i=t(\"affine-hull\")},{\"affine-hull\":62,\"incremental-convex-hull\":413}],134:[function(t,e,r){e.exports={AFG:\"afghan\",ALA:\"\\\\b\\\\wland\",ALB:\"albania\",DZA:\"algeria\",ASM:\"^(?=.*americ).*samoa\",AND:\"andorra\",AGO:\"angola\",AIA:\"anguill?a\",ATA:\"antarctica\",ATG:\"antigua\",ARG:\"argentin\",ARM:\"armenia\",ABW:\"^(?!.*bonaire).*\\\\baruba\",AUS:\"australia\",AUT:\"^(?!.*hungary).*austria|\\\\baustri.*\\\\bemp\",AZE:\"azerbaijan\",BHS:\"bahamas\",BHR:\"bahrain\",BGD:\"bangladesh|^(?=.*east).*paki?stan\",BRB:\"barbados\",BLR:\"belarus|byelo\",BEL:\"^(?!.*luxem).*belgium\",BLZ:\"belize|^(?=.*british).*honduras\",BEN:\"benin|dahome\",BMU:\"bermuda\",BTN:\"bhutan\",BOL:\"bolivia\",BES:\"^(?=.*bonaire).*eustatius|^(?=.*carib).*netherlands|\\\\bbes.?islands\",BIH:\"herzegovina|bosnia\",BWA:\"botswana|bechuana\",BVT:\"bouvet\",BRA:\"brazil\",IOT:\"british.?indian.?ocean\",BRN:\"brunei\",BGR:\"bulgaria\",BFA:\"burkina|\\\\bfaso|upper.?volta\",BDI:\"burundi\",CPV:\"verde\",KHM:\"cambodia|kampuchea|khmer\",CMR:\"cameroon\",CAN:\"canada\",CYM:\"cayman\",CAF:\"\\\\bcentral.african.republic\",TCD:\"\\\\bchad\",CHL:\"\\\\bchile\",CHN:\"^(?!.*\\\\bmac)(?!.*\\\\bhong)(?!.*\\\\btai)(?!.*\\\\brep).*china|^(?=.*peo)(?=.*rep).*china\",CXR:\"christmas\",CCK:\"\\\\bcocos|keeling\",COL:\"colombia\",COM:\"comoro\",COG:\"^(?!.*\\\\bdem)(?!.*\\\\bd[\\\\.]?r)(?!.*kinshasa)(?!.*zaire)(?!.*belg)(?!.*l.opoldville)(?!.*free).*\\\\bcongo\",COK:\"\\\\bcook\",CRI:\"costa.?rica\",CIV:\"ivoire|ivory\",HRV:\"croatia\",CUB:\"\\\\bcuba\",CUW:\"^(?!.*bonaire).*\\\\bcura(c|\\xe7)ao\",CYP:\"cyprus\",CSK:\"czechoslovakia\",CZE:\"^(?=.*rep).*czech|czechia|bohemia\",COD:\"\\\\bdem.*congo|congo.*\\\\bdem|congo.*\\\\bd[\\\\.]?r|\\\\bd[\\\\.]?r.*congo|belgian.?congo|congo.?free.?state|kinshasa|zaire|l.opoldville|drc|droc|rdc\",DNK:\"denmark\",DJI:\"djibouti\",DMA:\"dominica(?!n)\",DOM:\"dominican.rep\",ECU:\"ecuador\",EGY:\"egypt\",SLV:\"el.?salvador\",GNQ:\"guine.*eq|eq.*guine|^(?=.*span).*guinea\",ERI:\"eritrea\",EST:\"estonia\",ETH:\"ethiopia|abyssinia\",FLK:\"falkland|malvinas\",FRO:\"faroe|faeroe\",FJI:\"fiji\",FIN:\"finland\",FRA:\"^(?!.*\\\\bdep)(?!.*martinique).*france|french.?republic|\\\\bgaul\",GUF:\"^(?=.*french).*guiana\",PYF:\"french.?polynesia|tahiti\",ATF:\"french.?southern\",GAB:\"gabon\",GMB:\"gambia\",GEO:\"^(?!.*south).*georgia\",DDR:\"german.?democratic.?republic|democratic.?republic.*germany|east.germany\",DEU:\"^(?!.*east).*germany|^(?=.*\\\\bfed.*\\\\brep).*german\",GHA:\"ghana|gold.?coast\",GIB:\"gibraltar\",GRC:\"greece|hellenic|hellas\",GRL:\"greenland\",GRD:\"grenada\",GLP:\"guadeloupe\",GUM:\"\\\\bguam\",GTM:\"guatemala\",GGY:\"guernsey\",GIN:\"^(?!.*eq)(?!.*span)(?!.*bissau)(?!.*portu)(?!.*new).*guinea\",GNB:\"bissau|^(?=.*portu).*guinea\",GUY:\"guyana|british.?guiana\",HTI:\"haiti\",HMD:\"heard.*mcdonald\",VAT:\"holy.?see|vatican|papal.?st\",HND:\"^(?!.*brit).*honduras\",HKG:\"hong.?kong\",HUN:\"^(?!.*austr).*hungary\",ISL:\"iceland\",IND:\"india(?!.*ocea)\",IDN:\"indonesia\",IRN:\"\\\\biran|persia\",IRQ:\"\\\\biraq|mesopotamia\",IRL:\"(^ireland)|(^republic.*ireland)\",IMN:\"^(?=.*isle).*\\\\bman\",ISR:\"israel\",ITA:\"italy\",JAM:\"jamaica\",JPN:\"japan\",JEY:\"jersey\",JOR:\"jordan\",KAZ:\"kazak\",KEN:\"kenya|british.?east.?africa|east.?africa.?prot\",KIR:\"kiribati\",PRK:\"^(?=.*democrat|people|north|d.*p.*.r).*\\\\bkorea|dprk|korea.*(d.*p.*r)\",KWT:\"kuwait\",KGZ:\"kyrgyz|kirghiz\",LAO:\"\\\\blaos?\\\\b\",LVA:\"latvia\",LBN:\"lebanon\",LSO:\"lesotho|basuto\",LBR:\"liberia\",LBY:\"libya\",LIE:\"liechtenstein\",LTU:\"lithuania\",LUX:\"^(?!.*belg).*luxem\",MAC:\"maca(o|u)\",MDG:\"madagascar|malagasy\",MWI:\"malawi|nyasa\",MYS:\"malaysia\",MDV:\"maldive\",MLI:\"\\\\bmali\\\\b\",MLT:\"\\\\bmalta\",MHL:\"marshall\",MTQ:\"martinique\",MRT:\"mauritania\",MUS:\"mauritius\",MYT:\"\\\\bmayotte\",MEX:\"\\\\bmexic\",FSM:\"fed.*micronesia|micronesia.*fed\",MCO:\"monaco\",MNG:\"mongolia\",MNE:\"^(?!.*serbia).*montenegro\",MSR:\"montserrat\",MAR:\"morocco|\\\\bmaroc\",MOZ:\"mozambique\",MMR:\"myanmar|burma\",NAM:\"namibia\",NRU:\"nauru\",NPL:\"nepal\",NLD:\"^(?!.*\\\\bant)(?!.*\\\\bcarib).*netherlands\",ANT:\"^(?=.*\\\\bant).*(nether|dutch)\",NCL:\"new.?caledonia\",NZL:\"new.?zealand\",NIC:\"nicaragua\",NER:\"\\\\bniger(?!ia)\",NGA:\"nigeria\",NIU:\"niue\",NFK:\"norfolk\",MNP:\"mariana\",NOR:\"norway\",OMN:\"\\\\boman|trucial\",PAK:\"^(?!.*east).*paki?stan\",PLW:\"palau\",PSE:\"palestin|\\\\bgaza|west.?bank\",PAN:\"panama\",PNG:\"papua|new.?guinea\",PRY:\"paraguay\",PER:\"peru\",PHL:\"philippines\",PCN:\"pitcairn\",POL:\"poland\",PRT:\"portugal\",PRI:\"puerto.?rico\",QAT:\"qatar\",KOR:\"^(?!.*d.*p.*r)(?!.*democrat)(?!.*people)(?!.*north).*\\\\bkorea(?!.*d.*p.*r)\",MDA:\"moldov|b(a|e)ssarabia\",REU:\"r(e|\\xe9)union\",ROU:\"r(o|u|ou)mania\",RUS:\"\\\\brussia|soviet.?union|u\\\\.?s\\\\.?s\\\\.?r|socialist.?republics\",RWA:\"rwanda\",BLM:\"barth(e|\\xe9)lemy\",SHN:\"helena\",KNA:\"kitts|\\\\bnevis\",LCA:\"\\\\blucia\",MAF:\"^(?=.*collectivity).*martin|^(?=.*france).*martin(?!ique)|^(?=.*french).*martin(?!ique)\",SPM:\"miquelon\",VCT:\"vincent\",WSM:\"^(?!.*amer).*samoa\",SMR:\"san.?marino\",STP:\"\\\\bs(a|\\xe3)o.?tom(e|\\xe9)\",SAU:\"\\\\bsa\\\\w*.?arabia\",SEN:\"senegal\",SRB:\"^(?!.*monte).*serbia\",SYC:\"seychell\",SLE:\"sierra\",SGP:\"singapore\",SXM:\"^(?!.*martin)(?!.*saba).*maarten\",SVK:\"^(?!.*cze).*slovak\",SVN:\"slovenia\",SLB:\"solomon\",SOM:\"somali\",ZAF:\"south.africa|s\\\\\\\\..?africa\",SGS:\"south.?georgia|sandwich\",SSD:\"\\\\bs\\\\w*.?sudan\",ESP:\"spain\",LKA:\"sri.?lanka|ceylon\",SDN:\"^(?!.*\\\\bs(?!u)).*sudan\",SUR:\"surinam|dutch.?guiana\",SJM:\"svalbard\",SWZ:\"swaziland\",SWE:\"sweden\",CHE:\"switz|swiss\",SYR:\"syria\",TWN:\"taiwan|taipei|formosa|^(?!.*peo)(?=.*rep).*china\",TJK:\"tajik\",THA:\"thailand|\\\\bsiam\",MKD:\"macedonia|fyrom\",TLS:\"^(?=.*leste).*timor|^(?=.*east).*timor\",TGO:\"togo\",TKL:\"tokelau\",TON:\"tonga\",TTO:\"trinidad|tobago\",TUN:\"tunisia\",TUR:\"turkey\",TKM:\"turkmen\",TCA:\"turks\",TUV:\"tuvalu\",UGA:\"uganda\",UKR:\"ukrain\",ARE:\"emirates|^u\\\\.?a\\\\.?e\\\\.?$|united.?arab.?em\",GBR:\"united.?kingdom|britain|^u\\\\.?k\\\\.?$\",TZA:\"tanzania\",USA:\"united.?states\\\\b(?!.*islands)|\\\\bu\\\\.?s\\\\.?a\\\\.?\\\\b|^\\\\s*u\\\\.?s\\\\.?\\\\b(?!.*islands)\",UMI:\"minor.?outlying.?is\",URY:\"uruguay\",UZB:\"uzbek\",VUT:\"vanuatu|new.?hebrides\",VEN:\"venezuela\",VNM:\"^(?!.*republic).*viet.?nam|^(?=.*socialist).*viet.?nam\",VGB:\"^(?=.*\\\\bu\\\\.?\\\\s?k).*virgin|^(?=.*brit).*virgin|^(?=.*kingdom).*virgin\",VIR:\"^(?=.*\\\\bu\\\\.?\\\\s?s).*virgin|^(?=.*states).*virgin\",WLF:\"futuna|wallis\",ESH:\"western.sahara\",YEM:\"^(?!.*arab)(?!.*north)(?!.*sana)(?!.*peo)(?!.*dem)(?!.*south)(?!.*aden)(?!.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YMD:\"^(?=.*peo).*yemen|^(?!.*rep)(?=.*dem).*yemen|^(?=.*south).*yemen|^(?=.*aden).*yemen|^(?=.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YUG:\"yugoslavia\",ZMB:\"zambia|northern.?rhodesia\",EAZ:\"zanzibar\",ZWE:\"zimbabwe|^(?!.*northern).*rhodesia\"}},{}],135:[function(t,e,r){e.exports=[\"xx-small\",\"x-small\",\"small\",\"medium\",\"large\",\"x-large\",\"xx-large\",\"larger\",\"smaller\"]},{}],136:[function(t,e,r){e.exports=[\"normal\",\"condensed\",\"semi-condensed\",\"extra-condensed\",\"ultra-condensed\",\"expanded\",\"semi-expanded\",\"extra-expanded\",\"ultra-expanded\"]},{}],137:[function(t,e,r){e.exports=[\"normal\",\"italic\",\"oblique\"]},{}],138:[function(t,e,r){e.exports=[\"normal\",\"bold\",\"bolder\",\"lighter\",\"100\",\"200\",\"300\",\"400\",\"500\",\"600\",\"700\",\"800\",\"900\"]},{}],139:[function(t,e,r){\"use strict\";e.exports={parse:t(\"./parse\"),stringify:t(\"./stringify\")}},{\"./parse\":141,\"./stringify\":142}],140:[function(t,e,r){\"use strict\";var n=t(\"css-font-size-keywords\");e.exports={isSize:function(t){return/^[\\d\\.]/.test(t)||-1!==t.indexOf(\"/\")||-1!==n.indexOf(t)}}},{\"css-font-size-keywords\":135}],141:[function(t,e,r){\"use strict\";var n=t(\"unquote\"),i=t(\"css-global-keywords\"),a=t(\"css-system-font-keywords\"),o=t(\"css-font-weight-keywords\"),s=t(\"css-font-style-keywords\"),l=t(\"css-font-stretch-keywords\"),c=t(\"string-split-by\"),u=t(\"./lib/util\").isSize;e.exports=f;var h=f.cache={};function f(t){if(\"string\"!=typeof t)throw new Error(\"Font argument must be a string.\");if(h[t])return h[t];if(\"\"===t)throw new Error(\"Cannot parse an empty string.\");if(-1!==a.indexOf(t))return h[t]={system:t};for(var e,r={style:\"normal\",variant:\"normal\",weight:\"normal\",stretch:\"normal\",lineHeight:\"normal\",size:\"1rem\",family:[\"serif\"]},f=c(t,/\\s+/);e=f.shift();){if(-1!==i.indexOf(e))return[\"style\",\"variant\",\"weight\",\"stretch\"].forEach(function(t){r[t]=e}),h[t]=r;if(-1===s.indexOf(e))if(\"normal\"!==e&&\"small-caps\"!==e)if(-1===l.indexOf(e)){if(-1===o.indexOf(e)){if(u(e)){var d=c(e,\"/\");if(r.size=d[0],null!=d[1]?r.lineHeight=p(d[1]):\"/\"===f[0]&&(f.shift(),r.lineHeight=p(f.shift())),!f.length)throw new Error(\"Missing required font-family.\");return r.family=c(f.join(\" \"),/\\s*,\\s*/).map(n),h[t]=r}throw new Error(\"Unknown or unsupported font token: \"+e)}r.weight=e}else r.stretch=e;else r.variant=e;else r.style=e}throw new Error(\"Missing required font-size.\")}function p(t){var e=parseFloat(t);return e.toString()===t?e:t}},{\"./lib/util\":140,\"css-font-stretch-keywords\":136,\"css-font-style-keywords\":137,\"css-font-weight-keywords\":138,\"css-global-keywords\":143,\"css-system-font-keywords\":144,\"string-split-by\":529,unquote:548}],142:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\"),i=t(\"./lib/util\").isSize,a=g(t(\"css-global-keywords\")),o=g(t(\"css-system-font-keywords\")),s=g(t(\"css-font-weight-keywords\")),l=g(t(\"css-font-style-keywords\")),c=g(t(\"css-font-stretch-keywords\")),u={normal:1,\"small-caps\":1},h={serif:1,\"sans-serif\":1,monospace:1,cursive:1,fantasy:1,\"system-ui\":1},f=\"1rem\",p=\"serif\";function d(t,e){if(t&&!e[t]&&!a[t])throw Error(\"Unknown keyword `\"+t+\"`\");return t}function g(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=1;return e}e.exports=function(t){if((t=n(t,{style:\"style fontstyle fontStyle font-style slope distinction\",variant:\"variant font-variant fontVariant fontvariant var capitalization\",weight:\"weight w font-weight fontWeight fontweight\",stretch:\"stretch font-stretch fontStretch fontstretch width\",size:\"size s font-size fontSize fontsize height em emSize\",lineHeight:\"lh line-height lineHeight lineheight leading\",family:\"font family fontFamily font-family fontfamily type typeface face\",system:\"system reserved default global\"})).system)return t.system&&d(t.system,o),t.system;if(d(t.style,l),d(t.variant,u),d(t.weight,s),d(t.stretch,c),null==t.size&&(t.size=f),\"number\"==typeof t.size&&(t.size+=\"px\"),!i)throw Error(\"Bad size value `\"+t.size+\"`\");t.family||(t.family=p),Array.isArray(t.family)&&(t.family.length||(t.family=[p]),t.family=t.family.map(function(t){return h[t]?t:'\"'+t+'\"'}).join(\", \"));var e=[];return e.push(t.style),t.variant!==t.style&&e.push(t.variant),t.weight!==t.variant&&t.weight!==t.style&&e.push(t.weight),t.stretch!==t.weight&&t.stretch!==t.variant&&t.stretch!==t.style&&e.push(t.stretch),e.push(t.size+(null==t.lineHeight||\"normal\"===t.lineHeight||t.lineHeight+\"\"==\"1\"?\"\":\"/\"+t.lineHeight)),e.push(t.family),e.filter(Boolean).join(\" \")}},{\"./lib/util\":140,\"css-font-stretch-keywords\":136,\"css-font-style-keywords\":137,\"css-font-weight-keywords\":138,\"css-global-keywords\":143,\"css-system-font-keywords\":144,\"pick-by-alias\":465}],143:[function(t,e,r){e.exports=[\"inherit\",\"initial\",\"unset\"]},{}],144:[function(t,e,r){e.exports=[\"caption\",\"icon\",\"menu\",\"message-box\",\"small-caption\",\"status-bar\"]},{}],145:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i-1,s=i*i,l=o*o,c=(1+2*i)*l,u=i*l,h=s*(3-2*i),f=s*o;if(t.length){a||(a=new Array(t.length));for(var p=t.length-1;p>=0;--p)a[p]=c*t[p]+u*e[p]+h*r[p]+f*n[p];return a}return c*t+u*e+h*r+f*n},e.exports.derivative=function(t,e,r,n,i,a){var o=6*i*i-6*i,s=3*i*i-4*i+1,l=-6*i*i+6*i,c=3*i*i-2*i;if(t.length){a||(a=new Array(t.length));for(var u=t.length-1;u>=0;--u)a[u]=o*t[u]+s*e[u]+l*r[u]+c*n[u];return a}return o*t+s*e+l*r[u]+c*n}},{}],146:[function(t,e,r){\"use strict\";var n=t(\"./lib/thunk.js\");function i(){this.argTypes=[],this.shimArgs=[],this.arrayArgs=[],this.arrayBlockIndices=[],this.scalarArgs=[],this.offsetArgs=[],this.offsetArgIndex=[],this.indexArgs=[],this.shapeArgs=[],this.funcName=\"\",this.pre=null,this.body=null,this.post=null,this.debug=!1}e.exports=function(t){var e=new i;e.pre=t.pre,e.body=t.body,e.post=t.post;var r=t.args.slice(0);e.argTypes=r;for(var a=0;a<r.length;++a){var o=r[a];if(\"array\"===o||\"object\"==typeof o&&o.blockIndices){if(e.argTypes[a]=\"array\",e.arrayArgs.push(a),e.arrayBlockIndices.push(o.blockIndices?o.blockIndices:0),e.shimArgs.push(\"array\"+a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array args\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array args\")}else if(\"scalar\"===o)e.scalarArgs.push(a),e.shimArgs.push(\"scalar\"+a);else if(\"index\"===o){if(e.indexArgs.push(a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array index\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array index\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array index\")}else if(\"shape\"===o){if(e.shapeArgs.push(a),a<e.pre.args.length&&e.pre.args[a].lvalue)throw new Error(\"cwise: pre() block may not write to array shape\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array shape\");if(a<e.post.args.length&&e.post.args[a].lvalue)throw new Error(\"cwise: post() block may not write to array shape\")}else{if(\"object\"!=typeof o||!o.offset)throw new Error(\"cwise: Unknown argument type \"+r[a]);e.argTypes[a]=\"offset\",e.offsetArgs.push({array:o.array,offset:o.offset}),e.offsetArgIndex.push(a)}}if(e.arrayArgs.length<=0)throw new Error(\"cwise: No array arguments specified\");if(e.pre.args.length>r.length)throw new Error(\"cwise: Too many arguments in pre() block\");if(e.body.args.length>r.length)throw new Error(\"cwise: Too many arguments in body() block\");if(e.post.args.length>r.length)throw new Error(\"cwise: Too many arguments in post() block\");return e.debug=!!t.printCode||!!t.debug,e.funcName=t.funcName||\"cwise\",e.blockSize=t.blockSize||64,n(e)}},{\"./lib/thunk.js\":148}],147:[function(t,e,r){\"use strict\";var n=t(\"uniq\");function i(t,e,r){var n,i,a=t.length,o=e.arrayArgs.length,s=e.indexArgs.length>0,l=[],c=[],u=0,h=0;for(n=0;n<a;++n)c.push([\"i\",n,\"=0\"].join(\"\"));for(i=0;i<o;++i)for(n=0;n<a;++n)h=u,u=t[n],0===n?c.push([\"d\",i,\"s\",n,\"=t\",i,\"p\",u].join(\"\")):c.push([\"d\",i,\"s\",n,\"=(t\",i,\"p\",u,\"-s\",h,\"*t\",i,\"p\",h,\")\"].join(\"\"));for(c.length>0&&l.push(\"var \"+c.join(\",\")),n=a-1;n>=0;--n)u=t[n],l.push([\"for(i\",n,\"=0;i\",n,\"<s\",u,\";++i\",n,\"){\"].join(\"\"));for(l.push(r),n=0;n<a;++n){for(h=u,u=t[n],i=0;i<o;++i)l.push([\"p\",i,\"+=d\",i,\"s\",n].join(\"\"));s&&(n>0&&l.push([\"index[\",h,\"]-=s\",h].join(\"\")),l.push([\"++index[\",u,\"]\"].join(\"\"))),l.push(\"}\")}return l.join(\"\\n\")}function a(t,e,r){for(var n=t.body,i=[],a=[],o=0;o<t.args.length;++o){var s=t.args[o];if(!(s.count<=0)){var l=new RegExp(s.name,\"g\"),c=\"\",u=e.arrayArgs.indexOf(o);switch(e.argTypes[o]){case\"offset\":var h=e.offsetArgIndex.indexOf(o);u=e.offsetArgs[h].array,c=\"+q\"+h;case\"array\":c=\"p\"+u+c;var f=\"l\"+o,p=\"a\"+u;if(0===e.arrayBlockIndices[u])1===s.count?\"generic\"===r[u]?s.lvalue?(i.push([\"var \",f,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,f),a.push([p,\".set(\",c,\",\",f,\")\"].join(\"\"))):n=n.replace(l,[p,\".get(\",c,\")\"].join(\"\")):n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\")):\"generic\"===r[u]?(i.push([\"var \",f,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,f),s.lvalue&&a.push([p,\".set(\",c,\",\",f,\")\"].join(\"\"))):(i.push([\"var \",f,\"=\",p,\"[\",c,\"]\"].join(\"\")),n=n.replace(l,f),s.lvalue&&a.push([p,\"[\",c,\"]=\",f].join(\"\")));else{for(var d=[s.name],g=[c],v=0;v<Math.abs(e.arrayBlockIndices[u]);v++)d.push(\"\\\\s*\\\\[([^\\\\]]+)\\\\]\"),g.push(\"$\"+(v+1)+\"*t\"+u+\"b\"+v);if(l=new RegExp(d.join(\"\"),\"g\"),c=g.join(\"+\"),\"generic\"===r[u])throw new Error(\"cwise: Generic arrays not supported in combination with blocks!\");n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\"))}break;case\"scalar\":n=n.replace(l,\"Y\"+e.scalarArgs.indexOf(o));break;case\"index\":n=n.replace(l,\"index\");break;case\"shape\":n=n.replace(l,\"shape\")}}}return[i.join(\"\\n\"),n,a.join(\"\\n\")].join(\"\\n\").trim()}e.exports=function(t,e){for(var r=e[1].length-Math.abs(t.arrayBlockIndices[0])|0,o=new Array(t.arrayArgs.length),s=new Array(t.arrayArgs.length),l=0;l<t.arrayArgs.length;++l)s[l]=e[2*l],o[l]=e[2*l+1];var c=[],u=[],h=[],f=[],p=[];for(l=0;l<t.arrayArgs.length;++l){t.arrayBlockIndices[l]<0?(h.push(0),f.push(r),c.push(r),u.push(r+t.arrayBlockIndices[l])):(h.push(t.arrayBlockIndices[l]),f.push(t.arrayBlockIndices[l]+r),c.push(0),u.push(t.arrayBlockIndices[l]));for(var d=[],g=0;g<o[l].length;g++)h[l]<=o[l][g]&&o[l][g]<f[l]&&d.push(o[l][g]-h[l]);p.push(d)}var v=[\"SS\"],m=[\"'use strict'\"],y=[];for(g=0;g<r;++g)y.push([\"s\",g,\"=SS[\",g,\"]\"].join(\"\"));for(l=0;l<t.arrayArgs.length;++l){for(v.push(\"a\"+l),v.push(\"t\"+l),v.push(\"p\"+l),g=0;g<r;++g)y.push([\"t\",l,\"p\",g,\"=t\",l,\"[\",h[l]+g,\"]\"].join(\"\"));for(g=0;g<Math.abs(t.arrayBlockIndices[l]);++g)y.push([\"t\",l,\"b\",g,\"=t\",l,\"[\",c[l]+g,\"]\"].join(\"\"))}for(l=0;l<t.scalarArgs.length;++l)v.push(\"Y\"+l);if(t.shapeArgs.length>0&&y.push(\"shape=SS.slice(0)\"),t.indexArgs.length>0){var x=new Array(r);for(l=0;l<r;++l)x[l]=\"0\";y.push([\"index=[\",x.join(\",\"),\"]\"].join(\"\"))}for(l=0;l<t.offsetArgs.length;++l){var b=t.offsetArgs[l],_=[];for(g=0;g<b.offset.length;++g)0!==b.offset[g]&&(1===b.offset[g]?_.push([\"t\",b.array,\"p\",g].join(\"\")):_.push([b.offset[g],\"*t\",b.array,\"p\",g].join(\"\")));0===_.length?y.push(\"q\"+l+\"=0\"):y.push([\"q\",l,\"=\",_.join(\"+\")].join(\"\"))}var w=n([].concat(t.pre.thisVars).concat(t.body.thisVars).concat(t.post.thisVars));for((y=y.concat(w)).length>0&&m.push(\"var \"+y.join(\",\")),l=0;l<t.arrayArgs.length;++l)m.push(\"p\"+l+\"|=0\");t.pre.body.length>3&&m.push(a(t.pre,t,s));var k=a(t.body,t,s),T=function(t){for(var e=0,r=t[0].length;e<r;){for(var n=1;n<t.length;++n)if(t[n][e]!==t[0][e])return e;++e}return e}(p);T<r?m.push(function(t,e,r,n){for(var a=e.length,o=r.arrayArgs.length,s=r.blockSize,l=r.indexArgs.length>0,c=[],u=0;u<o;++u)c.push([\"var offset\",u,\"=p\",u].join(\"\"));for(u=t;u<a;++u)c.push([\"for(var j\"+u+\"=SS[\",e[u],\"]|0;j\",u,\">0;){\"].join(\"\")),c.push([\"if(j\",u,\"<\",s,\"){\"].join(\"\")),c.push([\"s\",e[u],\"=j\",u].join(\"\")),c.push([\"j\",u,\"=0\"].join(\"\")),c.push([\"}else{s\",e[u],\"=\",s].join(\"\")),c.push([\"j\",u,\"-=\",s,\"}\"].join(\"\")),l&&c.push([\"index[\",e[u],\"]=j\",u].join(\"\"));for(u=0;u<o;++u){for(var h=[\"offset\"+u],f=t;f<a;++f)h.push([\"j\",f,\"*t\",u,\"p\",e[f]].join(\"\"));c.push([\"p\",u,\"=(\",h.join(\"+\"),\")\"].join(\"\"))}for(c.push(i(e,r,n)),u=t;u<a;++u)c.push(\"}\");return c.join(\"\\n\")}(T,p[0],t,k)):m.push(i(p[0],t,k)),t.post.body.length>3&&m.push(a(t.post,t,s)),t.debug&&console.log(\"-----Generated cwise routine for \",e,\":\\n\"+m.join(\"\\n\")+\"\\n----------\");var A=[t.funcName||\"unnamed\",\"_cwise_loop_\",o[0].join(\"s\"),\"m\",T,function(t){for(var e=new Array(t.length),r=!0,n=0;n<t.length;++n){var i=t[n],a=i.match(/\\d+/);a=a?a[0]:\"\",0===i.charAt(0)?e[n]=\"u\"+i.charAt(1)+a:e[n]=i.charAt(0)+a,n>0&&(r=r&&e[n]===e[n-1])}return r?e[0]:e.join(\"\")}(s)].join(\"\");return new Function([\"function \",A,\"(\",v.join(\",\"),\"){\",m.join(\"\\n\"),\"} return \",A].join(\"\"))()}},{uniq:547}],148:[function(t,e,r){\"use strict\";var n=t(\"./compile.js\");e.exports=function(t){var e=[\"'use strict'\",\"var CACHED={}\"],r=[],i=t.funcName+\"_cwise_thunk\";e.push([\"return function \",i,\"(\",t.shimArgs.join(\",\"),\"){\"].join(\"\"));for(var a=[],o=[],s=[[\"array\",t.arrayArgs[0],\".shape.slice(\",Math.max(0,t.arrayBlockIndices[0]),t.arrayBlockIndices[0]<0?\",\"+t.arrayBlockIndices[0]+\")\":\")\"].join(\"\")],l=[],c=[],u=0;u<t.arrayArgs.length;++u){var h=t.arrayArgs[u];r.push([\"t\",h,\"=array\",h,\".dtype,\",\"r\",h,\"=array\",h,\".order\"].join(\"\")),a.push(\"t\"+h),a.push(\"r\"+h),o.push(\"t\"+h),o.push(\"r\"+h+\".join()\"),s.push(\"array\"+h+\".data\"),s.push(\"array\"+h+\".stride\"),s.push(\"array\"+h+\".offset|0\"),u>0&&(l.push(\"array\"+t.arrayArgs[0]+\".shape.length===array\"+h+\".shape.length+\"+(Math.abs(t.arrayBlockIndices[0])-Math.abs(t.arrayBlockIndices[u]))),c.push(\"array\"+t.arrayArgs[0]+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[0])+\"]===array\"+h+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[u])+\"]\"))}for(t.arrayArgs.length>1&&(e.push(\"if (!(\"+l.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same dimensionality!')\"),e.push(\"for(var shapeIndex=array\"+t.arrayArgs[0]+\".shape.length-\"+Math.abs(t.arrayBlockIndices[0])+\"; shapeIndex--\\x3e0;) {\"),e.push(\"if (!(\"+c.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same shape!')\"),e.push(\"}\")),u=0;u<t.scalarArgs.length;++u)s.push(\"scalar\"+t.scalarArgs[u]);return r.push([\"type=[\",o.join(\",\"),\"].join()\"].join(\"\")),r.push(\"proc=CACHED[type]\"),e.push(\"var \"+r.join(\",\")),e.push([\"if(!proc){\",\"CACHED[type]=proc=compile([\",a.join(\",\"),\"])}\",\"return proc(\",s.join(\",\"),\")}\"].join(\"\")),t.debug&&console.log(\"-----Generated thunk:\\n\"+e.join(\"\\n\")+\"\\n----------\"),new Function(\"compile\",e.join(\"\\n\"))(n.bind(void 0,t))}},{\"./compile.js\":147}],149:[function(t,e,r){e.exports=t(\"cwise-compiler\")},{\"cwise-compiler\":146}],150:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/copy\"),a=t(\"es5-ext/object/normalize-options\"),o=t(\"es5-ext/object/valid-callable\"),s=t(\"es5-ext/object/map\"),l=t(\"es5-ext/object/valid-callable\"),c=t(\"es5-ext/object/valid-value\"),u=Function.prototype.bind,h=Object.defineProperty,f=Object.prototype.hasOwnProperty;n=function(t,e,r){var n,a=c(e)&&l(e.value);return delete(n=i(e)).writable,delete n.value,n.get=function(){return!r.overwriteDefinition&&f.call(this,t)?a:(e.value=u.call(a,r.resolveContext?r.resolveContext(this):this),h(this,t,e),this[t])},n},e.exports=function(t){var e=a(arguments[1]);return null!=e.resolveContext&&o(e.resolveContext),s(t,function(t,r){return n(r,t,e)})}},{\"es5-ext/object/copy\":189,\"es5-ext/object/map\":198,\"es5-ext/object/normalize-options\":199,\"es5-ext/object/valid-callable\":203,\"es5-ext/object/valid-value\":205}],151:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/object/assign\"),i=t(\"es5-ext/object/normalize-options\"),a=t(\"es5-ext/object/is-callable\"),o=t(\"es5-ext/string/#/contains\");(e.exports=function(t,e){var r,a,s,l,c;return arguments.length<2||\"string\"!=typeof t?(l=e,e=t,t=null):l=arguments[2],null==t?(r=s=!0,a=!1):(r=o.call(t,\"c\"),a=o.call(t,\"e\"),s=o.call(t,\"w\")),c={value:e,configurable:r,enumerable:a,writable:s},l?n(i(l),c):c}).gs=function(t,e,r){var s,l,c,u;return\"string\"!=typeof t?(c=r,r=e,e=t,t=null):c=arguments[3],null==e?e=void 0:a(e)?null==r?r=void 0:a(r)||(c=r,r=void 0):(c=e,e=r=void 0),null==t?(s=!0,l=!1):(s=o.call(t,\"c\"),l=o.call(t,\"e\")),u={get:e,set:r,configurable:s,enumerable:l},c?n(i(c),u):u}},{\"es5-ext/object/assign\":186,\"es5-ext/object/is-callable\":192,\"es5-ext/object/normalize-options\":199,\"es5-ext/string/#/contains\":206}],152:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function r(t){var r;return 1===t.length&&(r=t,t=function(t,n){return e(r(t),n)}),{left:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}var n=r(e),i=n.right,a=n.left;function o(t,e){return[t,e]}function s(t){return null===t?NaN:+t}function l(t,e){var r,n,i=t.length,a=0,o=-1,l=0,c=0;if(null==e)for(;++o<i;)isNaN(r=s(t[o]))||(c+=(n=r-l)*(r-(l+=n/++a)));else for(;++o<i;)isNaN(r=s(e(t[o],o,t)))||(c+=(n=r-l)*(r-(l+=n/++a)));if(a>1)return c/(a-1)}function c(t,e){var r=l(t,e);return r?Math.sqrt(r):r}function u(t,e){var r,n,i,a=t.length,o=-1;if(null==e){for(;++o<a;)if(null!=(r=t[o])&&r>=r)for(n=i=r;++o<a;)null!=(r=t[o])&&(n>r&&(n=r),i<r&&(i=r))}else for(;++o<a;)if(null!=(r=e(t[o],o,t))&&r>=r)for(n=i=r;++o<a;)null!=(r=e(t[o],o,t))&&(n>r&&(n=r),i<r&&(i=r));return[n,i]}var h=Array.prototype,f=h.slice,p=h.map;function d(t){return function(){return t}}function g(t){return t}function v(t,e,r){t=+t,e=+e,r=(i=arguments.length)<2?(e=t,t=0,1):i<3?1:+r;for(var n=-1,i=0|Math.max(0,Math.ceil((e-t)/r)),a=new Array(i);++n<i;)a[n]=t+n*r;return a}var m=Math.sqrt(50),y=Math.sqrt(10),x=Math.sqrt(2);function b(t,e,r){var n=(e-t)/Math.max(0,r),i=Math.floor(Math.log(n)/Math.LN10),a=n/Math.pow(10,i);return i>=0?(a>=m?10:a>=y?5:a>=x?2:1)*Math.pow(10,i):-Math.pow(10,-i)/(a>=m?10:a>=y?5:a>=x?2:1)}function _(t,e,r){var n=Math.abs(e-t)/Math.max(0,r),i=Math.pow(10,Math.floor(Math.log(n)/Math.LN10)),a=n/i;return a>=m?i*=10:a>=y?i*=5:a>=x&&(i*=2),e<t?-i:i}function w(t){return Math.ceil(Math.log(t.length)/Math.LN2)+1}function k(t,e,r){if(null==r&&(r=s),n=t.length){if((e=+e)<=0||n<2)return+r(t[0],0,t);if(e>=1)return+r(t[n-1],n-1,t);var n,i=(n-1)*e,a=Math.floor(i),o=+r(t[a],a,t);return o+(+r(t[a+1],a+1,t)-o)*(i-a)}}function T(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&n>r&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&n>r&&(n=r);return n}function A(t){if(!(i=t.length))return[];for(var e=-1,r=T(t,M),n=new Array(r);++e<r;)for(var i,a=-1,o=n[e]=new Array(i);++a<i;)o[a]=t[a][e];return n}function M(t){return t.length}t.bisect=i,t.bisectRight=i,t.bisectLeft=a,t.ascending=e,t.bisector=r,t.cross=function(t,e,r){var n,i,a,s,l=t.length,c=e.length,u=new Array(l*c);for(null==r&&(r=o),n=a=0;n<l;++n)for(s=t[n],i=0;i<c;++i,++a)u[a]=r(s,e[i]);return u},t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.deviation=c,t.extent=u,t.histogram=function(){var t=g,e=u,r=w;function n(n){var a,o,s=n.length,l=new Array(s);for(a=0;a<s;++a)l[a]=t(n[a],a,n);var c=e(l),u=c[0],h=c[1],f=r(l,u,h);Array.isArray(f)||(f=_(u,h,f),f=v(Math.ceil(u/f)*f,h,f));for(var p=f.length;f[0]<=u;)f.shift(),--p;for(;f[p-1]>h;)f.pop(),--p;var d,g=new Array(p+1);for(a=0;a<=p;++a)(d=g[a]=[]).x0=a>0?f[a-1]:u,d.x1=a<p?f[a]:h;for(a=0;a<s;++a)u<=(o=l[a])&&o<=h&&g[i(f,o,0,p)].push(n[a]);return g}return n.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:d(e),n):t},n.domain=function(t){return arguments.length?(e=\"function\"==typeof t?t:d([t[0],t[1]]),n):e},n.thresholds=function(t){return arguments.length?(r=\"function\"==typeof t?t:Array.isArray(t)?d(f.call(t)):d(t),n):r},n},t.thresholdFreedmanDiaconis=function(t,r,n){return t=p.call(t,s).sort(e),Math.ceil((n-r)/(2*(k(t,.75)-k(t,.25))*Math.pow(t.length,-1/3)))},t.thresholdScott=function(t,e,r){return Math.ceil((r-e)/(3.5*c(t)*Math.pow(t.length,-1/3)))},t.thresholdSturges=w,t.max=function(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&r>n&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&r>n&&(n=r);return n},t.mean=function(t,e){var r,n=t.length,i=n,a=-1,o=0;if(null==e)for(;++a<n;)isNaN(r=s(t[a]))?--i:o+=r;else for(;++a<n;)isNaN(r=s(e(t[a],a,t)))?--i:o+=r;if(i)return o/i},t.median=function(t,r){var n,i=t.length,a=-1,o=[];if(null==r)for(;++a<i;)isNaN(n=s(t[a]))||o.push(n);else for(;++a<i;)isNaN(n=s(r(t[a],a,t)))||o.push(n);return k(o.sort(e),.5)},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r},t.min=T,t.pairs=function(t,e){null==e&&(e=o);for(var r=0,n=t.length-1,i=t[0],a=new Array(n<0?0:n);r<n;)a[r]=e(i,i=t[++r]);return a},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.quantile=k,t.range=v,t.scan=function(t,r){if(n=t.length){var n,i,a=0,o=0,s=t[o];for(null==r&&(r=e);++a<n;)(r(i=t[a],s)<0||0!==r(s,s))&&(s=i,o=a);return 0===r(s,s)?o:void 0}},t.shuffle=function(t,e,r){for(var n,i,a=(null==r?t.length:r)-(e=null==e?0:+e);a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.sum=function(t,e){var r,n=t.length,i=-1,a=0;if(null==e)for(;++i<n;)(r=+t[i])&&(a+=r);else for(;++i<n;)(r=+e(t[i],i,t))&&(a+=r);return a},t.ticks=function(t,e,r){var n,i,a,o,s=-1;if(r=+r,(t=+t)==(e=+e)&&r>0)return[t];if((n=e<t)&&(i=t,t=e,e=i),0===(o=b(t,e,r))||!isFinite(o))return[];if(o>0)for(t=Math.ceil(t/o),e=Math.floor(e/o),a=new Array(i=Math.ceil(e-t+1));++s<i;)a[s]=(t+s)*o;else for(t=Math.floor(t*o),e=Math.ceil(e*o),a=new Array(i=Math.ceil(t-e+1));++s<i;)a[s]=(t-s)/o;return n&&a.reverse(),a},t.tickIncrement=b,t.tickStep=_,t.transpose=A,t.variance=l,t.zip=function(){return A(arguments)},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],153:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(){}function r(t,r){var n=new e;if(t instanceof e)t.each(function(t,e){n.set(e,t)});else if(Array.isArray(t)){var i,a=-1,o=t.length;if(null==r)for(;++a<o;)n.set(a,t[a]);else for(;++a<o;)n.set(r(i=t[a],a,t),i)}else if(t)for(var s in t)n.set(s,t[s]);return n}e.prototype=r.prototype={constructor:e,has:function(t){return\"$\"+t in this},get:function(t){return this[\"$\"+t]},set:function(t,e){return this[\"$\"+t]=e,this},remove:function(t){var e=\"$\"+t;return e in this&&delete this[e]},clear:function(){for(var t in this)\"$\"===t[0]&&delete this[t]},keys:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(e.slice(1));return t},values:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(this[e]);return t},entries:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push({key:e.slice(1),value:this[e]});return t},size:function(){var t=0;for(var e in this)\"$\"===e[0]&&++t;return t},empty:function(){for(var t in this)if(\"$\"===t[0])return!1;return!0},each:function(t){for(var e in this)\"$\"===e[0]&&t(this[e],e.slice(1),this)}};function n(){return{}}function i(t,e,r){t[e]=r}function a(){return r()}function o(t,e,r){t.set(e,r)}function s(){}var l=r.prototype;function c(t,e){var r=new s;if(t instanceof s)t.each(function(t){r.add(t)});else if(t){var n=-1,i=t.length;if(null==e)for(;++n<i;)r.add(t[n]);else for(;++n<i;)r.add(e(t[n],n,t))}return r}s.prototype=c.prototype={constructor:s,has:l.has,add:function(t){return this[\"$\"+(t+=\"\")]=t,this},remove:l.remove,clear:l.clear,values:l.keys,size:l.size,empty:l.empty,each:l.each};t.nest=function(){var t,e,s,l=[],c=[];function u(n,i,a,o){if(i>=l.length)return null!=t&&n.sort(t),null!=e?e(n):n;for(var s,c,h,f=-1,p=n.length,d=l[i++],g=r(),v=a();++f<p;)(h=g.get(s=d(c=n[f])+\"\"))?h.push(c):g.set(s,[c]);return g.each(function(t,e){o(v,e,u(t,i,a,o))}),v}return s={object:function(t){return u(t,0,n,i)},map:function(t){return u(t,0,a,o)},entries:function(t){return function t(r,n){if(++n>l.length)return r;var i,a=c[n-1];return null!=e&&n>=l.length?i=r.entries():(i=[],r.each(function(e,r){i.push({key:r,values:t(e,n)})})),null!=a?i.sort(function(t,e){return a(t.key,e.key)}):i}(u(t,0,a,o),0)},key:function(t){return l.push(t),s},sortKeys:function(t){return c[l.length-1]=t,s},sortValues:function(e){return t=e,s},rollup:function(t){return e=t,s}}},t.set=c,t.map=r,t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],154:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e,r){t.prototype=e.prototype=r,r.constructor=t}function r(t,e){var r=Object.create(t.prototype);for(var n in e)r[n]=e[n];return r}function n(){}var i=\"\\\\s*([+-]?\\\\d+)\\\\s*\",a=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)\\\\s*\",o=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)%\\\\s*\",s=/^#([0-9a-f]{3})$/,l=/^#([0-9a-f]{6})$/,c=new RegExp(\"^rgb\\\\(\"+[i,i,i]+\"\\\\)$\"),u=new RegExp(\"^rgb\\\\(\"+[o,o,o]+\"\\\\)$\"),h=new RegExp(\"^rgba\\\\(\"+[i,i,i,a]+\"\\\\)$\"),f=new RegExp(\"^rgba\\\\(\"+[o,o,o,a]+\"\\\\)$\"),p=new RegExp(\"^hsl\\\\(\"+[a,o,o]+\"\\\\)$\"),d=new RegExp(\"^hsla\\\\(\"+[a,o,o,a]+\"\\\\)$\"),g={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};function v(t){var e;return t=(t+\"\").trim().toLowerCase(),(e=s.exec(t))?new _((e=parseInt(e[1],16))>>8&15|e>>4&240,e>>4&15|240&e,(15&e)<<4|15&e,1):(e=l.exec(t))?m(parseInt(e[1],16)):(e=c.exec(t))?new _(e[1],e[2],e[3],1):(e=u.exec(t))?new _(255*e[1]/100,255*e[2]/100,255*e[3]/100,1):(e=h.exec(t))?y(e[1],e[2],e[3],e[4]):(e=f.exec(t))?y(255*e[1]/100,255*e[2]/100,255*e[3]/100,e[4]):(e=p.exec(t))?k(e[1],e[2]/100,e[3]/100,1):(e=d.exec(t))?k(e[1],e[2]/100,e[3]/100,e[4]):g.hasOwnProperty(t)?m(g[t]):\"transparent\"===t?new _(NaN,NaN,NaN,0):null}function m(t){return new _(t>>16&255,t>>8&255,255&t,1)}function y(t,e,r,n){return n<=0&&(t=e=r=NaN),new _(t,e,r,n)}function x(t){return t instanceof n||(t=v(t)),t?new _((t=t.rgb()).r,t.g,t.b,t.opacity):new _}function b(t,e,r,n){return 1===arguments.length?x(t):new _(t,e,r,null==n?1:n)}function _(t,e,r,n){this.r=+t,this.g=+e,this.b=+r,this.opacity=+n}function w(t){return((t=Math.max(0,Math.min(255,Math.round(t)||0)))<16?\"0\":\"\")+t.toString(16)}function k(t,e,r,n){return n<=0?t=e=r=NaN:r<=0||r>=1?t=e=NaN:e<=0&&(t=NaN),new A(t,e,r,n)}function T(t,e,r,i){return 1===arguments.length?function(t){if(t instanceof A)return new A(t.h,t.s,t.l,t.opacity);if(t instanceof n||(t=v(t)),!t)return new A;if(t instanceof A)return t;var e=(t=t.rgb()).r/255,r=t.g/255,i=t.b/255,a=Math.min(e,r,i),o=Math.max(e,r,i),s=NaN,l=o-a,c=(o+a)/2;return l?(s=e===o?(r-i)/l+6*(r<i):r===o?(i-e)/l+2:(e-r)/l+4,l/=c<.5?o+a:2-o-a,s*=60):l=c>0&&c<1?0:s,new A(s,l,c,t.opacity)}(t):new A(t,e,r,null==i?1:i)}function A(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}function M(t,e,r){return 255*(t<60?e+(r-e)*t/60:t<180?r:t<240?e+(r-e)*(240-t)/60:e)}e(n,v,{displayable:function(){return this.rgb().displayable()},hex:function(){return this.rgb().hex()},toString:function(){return this.rgb()+\"\"}}),e(_,b,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new _(this.r*t,this.g*t,this.b*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new _(this.r*t,this.g*t,this.b*t,this.opacity)},rgb:function(){return this},displayable:function(){return 0<=this.r&&this.r<=255&&0<=this.g&&this.g<=255&&0<=this.b&&this.b<=255&&0<=this.opacity&&this.opacity<=1},hex:function(){return\"#\"+w(this.r)+w(this.g)+w(this.b)},toString:function(){var t=this.opacity;return(1===(t=isNaN(t)?1:Math.max(0,Math.min(1,t)))?\"rgb(\":\"rgba(\")+Math.max(0,Math.min(255,Math.round(this.r)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.g)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.b)||0))+(1===t?\")\":\", \"+t+\")\")}})),e(A,T,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new A(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new A(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=this.h%360+360*(this.h<0),e=isNaN(t)||isNaN(this.s)?0:this.s,r=this.l,n=r+(r<.5?r:1-r)*e,i=2*r-n;return new _(M(t>=240?t-240:t+120,i,n),M(t,i,n),M(t<120?t+240:t-120,i,n),this.opacity)},displayable:function(){return(0<=this.s&&this.s<=1||isNaN(this.s))&&0<=this.l&&this.l<=1&&0<=this.opacity&&this.opacity<=1}}));var S=Math.PI/180,E=180/Math.PI,C=.96422,L=1,P=.82521,O=4/29,z=6/29,I=3*z*z,D=z*z*z;function R(t){if(t instanceof B)return new B(t.l,t.a,t.b,t.opacity);if(t instanceof G){if(isNaN(t.h))return new B(t.l,0,0,t.opacity);var e=t.h*S;return new B(t.l,Math.cos(e)*t.c,Math.sin(e)*t.c,t.opacity)}t instanceof _||(t=x(t));var r,n,i=V(t.r),a=V(t.g),o=V(t.b),s=N((.2225045*i+.7168786*a+.0606169*o)/L);return i===a&&a===o?r=n=s:(r=N((.4360747*i+.3850649*a+.1430804*o)/C),n=N((.0139322*i+.0971045*a+.7141733*o)/P)),new B(116*s-16,500*(r-s),200*(s-n),t.opacity)}function F(t,e,r,n){return 1===arguments.length?R(t):new B(t,e,r,null==n?1:n)}function B(t,e,r,n){this.l=+t,this.a=+e,this.b=+r,this.opacity=+n}function N(t){return t>D?Math.pow(t,1/3):t/I+O}function j(t){return t>z?t*t*t:I*(t-O)}function U(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function V(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function q(t){if(t instanceof G)return new G(t.h,t.c,t.l,t.opacity);if(t instanceof B||(t=R(t)),0===t.a&&0===t.b)return new G(NaN,0,t.l,t.opacity);var e=Math.atan2(t.b,t.a)*E;return new G(e<0?e+360:e,Math.sqrt(t.a*t.a+t.b*t.b),t.l,t.opacity)}function H(t,e,r,n){return 1===arguments.length?q(t):new G(t,e,r,null==n?1:n)}function G(t,e,r,n){this.h=+t,this.c=+e,this.l=+r,this.opacity=+n}e(B,F,r(n,{brighter:function(t){return new B(this.l+18*(null==t?1:t),this.a,this.b,this.opacity)},darker:function(t){return new B(this.l-18*(null==t?1:t),this.a,this.b,this.opacity)},rgb:function(){var t=(this.l+16)/116,e=isNaN(this.a)?t:t+this.a/500,r=isNaN(this.b)?t:t-this.b/200;return new _(U(3.1338561*(e=C*j(e))-1.6168667*(t=L*j(t))-.4906146*(r=P*j(r))),U(-.9787684*e+1.9161415*t+.033454*r),U(.0719453*e-.2289914*t+1.4052427*r),this.opacity)}})),e(G,H,r(n,{brighter:function(t){return new G(this.h,this.c,this.l+18*(null==t?1:t),this.opacity)},darker:function(t){return new G(this.h,this.c,this.l-18*(null==t?1:t),this.opacity)},rgb:function(){return R(this).rgb()}}));var Y=-.14861,W=1.78277,X=-.29227,Z=-.90649,J=1.97294,K=J*Z,$=J*W,Q=W*X-Z*Y;function tt(t,e,r,n){return 1===arguments.length?function(t){if(t instanceof et)return new et(t.h,t.s,t.l,t.opacity);t instanceof _||(t=x(t));var e=t.r/255,r=t.g/255,n=t.b/255,i=(Q*n+K*e-$*r)/(Q+K-$),a=n-i,o=(J*(r-i)-X*a)/Z,s=Math.sqrt(o*o+a*a)/(J*i*(1-i)),l=s?Math.atan2(o,a)*E-120:NaN;return new et(l<0?l+360:l,s,i,t.opacity)}(t):new et(t,e,r,null==n?1:n)}function et(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}e(et,tt,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new et(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new et(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=isNaN(this.h)?0:(this.h+120)*S,e=+this.l,r=isNaN(this.s)?0:this.s*e*(1-e),n=Math.cos(t),i=Math.sin(t);return new _(255*(e+r*(Y*n+W*i)),255*(e+r*(X*n+Z*i)),255*(e+r*(J*n)),this.opacity)}})),t.color=v,t.rgb=b,t.hsl=T,t.lab=F,t.hcl=H,t.lch=function(t,e,r,n){return 1===arguments.length?q(t):new G(r,e,t,null==n?1:n)},t.gray=function(t,e){return new B(t,0,0,null==e?1:e)},t.cubehelix=tt,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],155:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e={value:function(){}};function r(){for(var t,e=0,r=arguments.length,i={};e<r;++e){if(!(t=arguments[e]+\"\")||t in i)throw new Error(\"illegal type: \"+t);i[t]=[]}return new n(i)}function n(t){this._=t}function i(t,e){for(var r,n=0,i=t.length;n<i;++n)if((r=t[n]).name===e)return r.value}function a(t,r,n){for(var i=0,a=t.length;i<a;++i)if(t[i].name===r){t[i]=e,t=t.slice(0,i).concat(t.slice(i+1));break}return null!=n&&t.push({name:r,value:n}),t}n.prototype=r.prototype={constructor:n,on:function(t,e){var r,n,o=this._,s=(n=o,(t+\"\").trim().split(/^|\\s+/).map(function(t){var e=\"\",r=t.indexOf(\".\");if(r>=0&&(e=t.slice(r+1),t=t.slice(0,r)),t&&!n.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);return{type:t,name:e}})),l=-1,c=s.length;if(!(arguments.length<2)){if(null!=e&&\"function\"!=typeof e)throw new Error(\"invalid callback: \"+e);for(;++l<c;)if(r=(t=s[l]).type)o[r]=a(o[r],t.name,e);else if(null==e)for(r in o)o[r]=a(o[r],t.name,null);return this}for(;++l<c;)if((r=(t=s[l]).type)&&(r=i(o[r],t.name)))return r},copy:function(){var t={},e=this._;for(var r in e)t[r]=e[r].slice();return new n(t)},call:function(t,e){if((r=arguments.length-2)>0)for(var r,n,i=new Array(r),a=0;a<r;++a)i[a]=arguments[a+2];if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(a=0,r=(n=this._[t]).length;a<r;++a)n[a].value.apply(e,i)},apply:function(t,e,r){if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(var n=this._[t],i=0,a=n.length;i<a;++i)n[i].value.apply(e,r)}},t.dispatch=r,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],156:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n,i){\"use strict\";var a=function(t){return function(){return t}},o=function(){return 1e-6*(Math.random()-.5)};function s(t){return t.x+t.vx}function l(t){return t.y+t.vy}function c(t){return t.index}function u(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function h(t){return t.x}function f(t){return t.y}var p=10,d=Math.PI*(3-Math.sqrt(5));t.forceCenter=function(t,e){var r;function n(){var n,i,a=r.length,o=0,s=0;for(n=0;n<a;++n)o+=(i=r[n]).x,s+=i.y;for(o=o/a-t,s=s/a-e,n=0;n<a;++n)(i=r[n]).x-=o,i.y-=s}return null==t&&(t=0),null==e&&(e=0),n.initialize=function(t){r=t},n.x=function(e){return arguments.length?(t=+e,n):t},n.y=function(t){return arguments.length?(e=+t,n):e},n},t.forceCollide=function(t){var r,n,i=1,c=1;function u(){for(var t,a,u,f,p,d,g,v=r.length,m=0;m<c;++m)for(a=e.quadtree(r,s,l).visitAfter(h),t=0;t<v;++t)u=r[t],d=n[u.index],g=d*d,f=u.x+u.vx,p=u.y+u.vy,a.visit(y);function y(t,e,r,n,a){var s=t.data,l=t.r,c=d+l;if(!s)return e>f+c||n<f-c||r>p+c||a<p-c;if(s.index>u.index){var h=f-s.x-s.vx,v=p-s.y-s.vy,m=h*h+v*v;m<c*c&&(0===h&&(m+=(h=o())*h),0===v&&(m+=(v=o())*v),m=(c-(m=Math.sqrt(m)))/m*i,u.vx+=(h*=m)*(c=(l*=l)/(g+l)),u.vy+=(v*=m)*c,s.vx-=h*(c=1-c),s.vy-=v*c)}}}function h(t){if(t.data)return t.r=n[t.data.index];for(var e=t.r=0;e<4;++e)t[e]&&t[e].r>t.r&&(t.r=t[e].r)}function f(){if(r){var e,i,a=r.length;for(n=new Array(a),e=0;e<a;++e)i=r[e],n[i.index]=+t(i,e,r)}}return\"function\"!=typeof t&&(t=a(null==t?1:+t)),u.initialize=function(t){r=t,f()},u.iterations=function(t){return arguments.length?(c=+t,u):c},u.strength=function(t){return arguments.length?(i=+t,u):i},u.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),f(),u):t},u},t.forceLink=function(t){var e,n,i,s,l,h=c,f=function(t){return 1/Math.min(s[t.source.index],s[t.target.index])},p=a(30),d=1;function g(r){for(var i=0,a=t.length;i<d;++i)for(var s,c,u,h,f,p,g,v=0;v<a;++v)c=(s=t[v]).source,h=(u=s.target).x+u.vx-c.x-c.vx||o(),f=u.y+u.vy-c.y-c.vy||o(),h*=p=((p=Math.sqrt(h*h+f*f))-n[v])/p*r*e[v],f*=p,u.vx-=h*(g=l[v]),u.vy-=f*g,c.vx+=h*(g=1-g),c.vy+=f*g}function v(){if(i){var a,o,c=i.length,f=t.length,p=r.map(i,h);for(a=0,s=new Array(c);a<f;++a)(o=t[a]).index=a,\"object\"!=typeof o.source&&(o.source=u(p,o.source)),\"object\"!=typeof o.target&&(o.target=u(p,o.target)),s[o.source.index]=(s[o.source.index]||0)+1,s[o.target.index]=(s[o.target.index]||0)+1;for(a=0,l=new Array(f);a<f;++a)o=t[a],l[a]=s[o.source.index]/(s[o.source.index]+s[o.target.index]);e=new Array(f),m(),n=new Array(f),y()}}function m(){if(i)for(var r=0,n=t.length;r<n;++r)e[r]=+f(t[r],r,t)}function y(){if(i)for(var e=0,r=t.length;e<r;++e)n[e]=+p(t[e],e,t)}return null==t&&(t=[]),g.initialize=function(t){i=t,v()},g.links=function(e){return arguments.length?(t=e,v(),g):t},g.id=function(t){return arguments.length?(h=t,g):h},g.iterations=function(t){return arguments.length?(d=+t,g):d},g.strength=function(t){return arguments.length?(f=\"function\"==typeof t?t:a(+t),m(),g):f},g.distance=function(t){return arguments.length?(p=\"function\"==typeof t?t:a(+t),y(),g):p},g},t.forceManyBody=function(){var t,r,n,i,s=a(-30),l=1,c=1/0,u=.81;function p(i){var a,o=t.length,s=e.quadtree(t,h,f).visitAfter(g);for(n=i,a=0;a<o;++a)r=t[a],s.visit(v)}function d(){if(t){var e,r,n=t.length;for(i=new Array(n),e=0;e<n;++e)r=t[e],i[r.index]=+s(r,e,t)}}function g(t){var e,r,n,a,o,s=0,l=0;if(t.length){for(n=a=o=0;o<4;++o)(e=t[o])&&(r=Math.abs(e.value))&&(s+=e.value,l+=r,n+=r*e.x,a+=r*e.y);t.x=n/l,t.y=a/l}else{(e=t).x=e.data.x,e.y=e.data.y;do{s+=i[e.data.index]}while(e=e.next)}t.value=s}function v(t,e,a,s){if(!t.value)return!0;var h=t.x-r.x,f=t.y-r.y,p=s-e,d=h*h+f*f;if(p*p/u<d)return d<c&&(0===h&&(d+=(h=o())*h),0===f&&(d+=(f=o())*f),d<l&&(d=Math.sqrt(l*d)),r.vx+=h*t.value*n/d,r.vy+=f*t.value*n/d),!0;if(!(t.length||d>=c)){(t.data!==r||t.next)&&(0===h&&(d+=(h=o())*h),0===f&&(d+=(f=o())*f),d<l&&(d=Math.sqrt(l*d)));do{t.data!==r&&(p=i[t.data.index]*n/d,r.vx+=h*p,r.vy+=f*p)}while(t=t.next)}}return p.initialize=function(e){t=e,d()},p.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),d(),p):s},p.distanceMin=function(t){return arguments.length?(l=t*t,p):Math.sqrt(l)},p.distanceMax=function(t){return arguments.length?(c=t*t,p):Math.sqrt(c)},p.theta=function(t){return arguments.length?(u=t*t,p):Math.sqrt(u)},p},t.forceRadial=function(t,e,r){var n,i,o,s=a(.1);function l(t){for(var a=0,s=n.length;a<s;++a){var l=n[a],c=l.x-e||1e-6,u=l.y-r||1e-6,h=Math.sqrt(c*c+u*u),f=(o[a]-h)*i[a]*t/h;l.vx+=c*f,l.vy+=u*f}}function c(){if(n){var e,r=n.length;for(i=new Array(r),o=new Array(r),e=0;e<r;++e)o[e]=+t(n[e],e,n),i[e]=isNaN(o[e])?0:+s(n[e],e,n)}}return\"function\"!=typeof t&&(t=a(+t)),null==e&&(e=0),null==r&&(r=0),l.initialize=function(t){n=t,c()},l.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),c(),l):s},l.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),c(),l):t},l.x=function(t){return arguments.length?(e=+t,l):e},l.y=function(t){return arguments.length?(r=+t,l):r},l},t.forceSimulation=function(t){var e,a=1,o=.001,s=1-Math.pow(o,1/300),l=0,c=.6,u=r.map(),h=i.timer(g),f=n.dispatch(\"tick\",\"end\");function g(){v(),f.call(\"tick\",e),a<o&&(h.stop(),f.call(\"end\",e))}function v(){var e,r,n=t.length;for(a+=(l-a)*s,u.each(function(t){t(a)}),e=0;e<n;++e)null==(r=t[e]).fx?r.x+=r.vx*=c:(r.x=r.fx,r.vx=0),null==r.fy?r.y+=r.vy*=c:(r.y=r.fy,r.vy=0)}function m(){for(var e,r=0,n=t.length;r<n;++r){if((e=t[r]).index=r,isNaN(e.x)||isNaN(e.y)){var i=p*Math.sqrt(r),a=r*d;e.x=i*Math.cos(a),e.y=i*Math.sin(a)}(isNaN(e.vx)||isNaN(e.vy))&&(e.vx=e.vy=0)}}function y(e){return e.initialize&&e.initialize(t),e}return null==t&&(t=[]),m(),e={tick:v,restart:function(){return h.restart(g),e},stop:function(){return h.stop(),e},nodes:function(r){return arguments.length?(t=r,m(),u.each(y),e):t},alpha:function(t){return arguments.length?(a=+t,e):a},alphaMin:function(t){return arguments.length?(o=+t,e):o},alphaDecay:function(t){return arguments.length?(s=+t,e):+s},alphaTarget:function(t){return arguments.length?(l=+t,e):l},velocityDecay:function(t){return arguments.length?(c=1-t,e):1-c},force:function(t,r){return arguments.length>1?(null==r?u.remove(t):u.set(t,y(r)),e):u.get(t)},find:function(e,r,n){var i,a,o,s,l,c=0,u=t.length;for(null==n?n=1/0:n*=n,c=0;c<u;++c)(o=(i=e-(s=t[c]).x)*i+(a=r-s.y)*a)<n&&(l=s,n=o);return l},on:function(t,r){return arguments.length>1?(f.on(t,r),e):f.on(t)}}},t.forceX=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vx+=(n[a]-i.x)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},t.forceY=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vy+=(n[a]-i.y)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.y=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-quadtree\"),t(\"d3-collection\"),t(\"d3-dispatch\"),t(\"d3-timer\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,n.d3)},{\"d3-collection\":153,\"d3-dispatch\":155,\"d3-quadtree\":160,\"d3-timer\":162}],157:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e){return t.parent===e.parent?1:2}function r(t,e){return t+e.x}function n(t,e){return Math.max(t,e.y)}function i(t){var e=0,r=t.children,n=r&&r.length;if(n)for(;--n>=0;)e+=r[n].value;else e=1;t.value=e}function a(t,e){var r,n,i,a,s,u=new c(t),h=+t.value&&(u.value=t.value),f=[u];for(null==e&&(e=o);r=f.pop();)if(h&&(r.value=+r.data.value),(i=e(r.data))&&(s=i.length))for(r.children=new Array(s),a=s-1;a>=0;--a)f.push(n=r.children[a]=new c(i[a])),n.parent=r,n.depth=r.depth+1;return u.eachBefore(l)}function o(t){return t.children}function s(t){t.data=t.data.data}function l(t){var e=0;do{t.height=e}while((t=t.parent)&&t.height<++e)}function c(t){this.data=t,this.depth=this.height=0,this.parent=null}c.prototype=a.prototype={constructor:c,count:function(){return this.eachAfter(i)},each:function(t){var e,r,n,i,a=this,o=[a];do{for(e=o.reverse(),o=[];a=e.pop();)if(t(a),r=a.children)for(n=0,i=r.length;n<i;++n)o.push(r[n])}while(o.length);return this},eachAfter:function(t){for(var e,r,n,i=this,a=[i],o=[];i=a.pop();)if(o.push(i),e=i.children)for(r=0,n=e.length;r<n;++r)a.push(e[r]);for(;i=o.pop();)t(i);return this},eachBefore:function(t){for(var e,r,n=this,i=[n];n=i.pop();)if(t(n),e=n.children)for(r=e.length-1;r>=0;--r)i.push(e[r]);return this},sum:function(t){return this.eachAfter(function(e){for(var r=+t(e.data)||0,n=e.children,i=n&&n.length;--i>=0;)r+=n[i].value;e.value=r})},sort:function(t){return this.eachBefore(function(e){e.children&&e.children.sort(t)})},path:function(t){for(var e=this,r=function(t,e){if(t===e)return t;var r=t.ancestors(),n=e.ancestors(),i=null;for(t=r.pop(),e=n.pop();t===e;)i=t,t=r.pop(),e=n.pop();return i}(e,t),n=[e];e!==r;)e=e.parent,n.push(e);for(var i=n.length;t!==r;)n.splice(i,0,t),t=t.parent;return n},ancestors:function(){for(var t=this,e=[t];t=t.parent;)e.push(t);return e},descendants:function(){var t=[];return this.each(function(e){t.push(e)}),t},leaves:function(){var t=[];return this.eachBefore(function(e){e.children||t.push(e)}),t},links:function(){var t=this,e=[];return t.each(function(r){r!==t&&e.push({source:r.parent,target:r})}),e},copy:function(){return a(this).eachBefore(s)}};var u=Array.prototype.slice;function h(t){for(var e,r,n=0,i=(t=function(t){for(var e,r,n=t.length;n;)r=Math.random()*n--|0,e=t[n],t[n]=t[r],t[r]=e;return t}(u.call(t))).length,a=[];n<i;)e=t[n],r&&d(r,e)?++n:(r=v(a=f(a,e)),n=0);return r}function f(t,e){var r,n;if(g(e,t))return[e];for(r=0;r<t.length;++r)if(p(e,t[r])&&g(m(t[r],e),t))return[t[r],e];for(r=0;r<t.length-1;++r)for(n=r+1;n<t.length;++n)if(p(m(t[r],t[n]),e)&&p(m(t[r],e),t[n])&&p(m(t[n],e),t[r])&&g(y(t[r],t[n],e),t))return[t[r],t[n],e];throw new Error}function p(t,e){var r=t.r-e.r,n=e.x-t.x,i=e.y-t.y;return r<0||r*r<n*n+i*i}function d(t,e){var r=t.r-e.r+1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function g(t,e){for(var r=0;r<e.length;++r)if(!d(t,e[r]))return!1;return!0}function v(t){switch(t.length){case 1:return{x:(e=t[0]).x,y:e.y,r:e.r};case 2:return m(t[0],t[1]);case 3:return y(t[0],t[1],t[2])}var e}function m(t,e){var r=t.x,n=t.y,i=t.r,a=e.x,o=e.y,s=e.r,l=a-r,c=o-n,u=s-i,h=Math.sqrt(l*l+c*c);return{x:(r+a+l/h*u)/2,y:(n+o+c/h*u)/2,r:(h+i+s)/2}}function y(t,e,r){var n=t.x,i=t.y,a=t.r,o=e.x,s=e.y,l=e.r,c=r.x,u=r.y,h=r.r,f=n-o,p=n-c,d=i-s,g=i-u,v=l-a,m=h-a,y=n*n+i*i-a*a,x=y-o*o-s*s+l*l,b=y-c*c-u*u+h*h,_=p*d-f*g,w=(d*b-g*x)/(2*_)-n,k=(g*v-d*m)/_,T=(p*x-f*b)/(2*_)-i,A=(f*m-p*v)/_,M=k*k+A*A-1,S=2*(a+w*k+T*A),E=w*w+T*T-a*a,C=-(M?(S+Math.sqrt(S*S-4*M*E))/(2*M):E/S);return{x:n+w+k*C,y:i+T+A*C,r:C}}function x(t,e,r){var n,i,a,o,s=t.x-e.x,l=t.y-e.y,c=s*s+l*l;c?(i=e.r+r.r,i*=i,o=t.r+r.r,i>(o*=o)?(n=(c+o-i)/(2*c),a=Math.sqrt(Math.max(0,o/c-n*n)),r.x=t.x-n*s-a*l,r.y=t.y-n*l+a*s):(n=(c+i-o)/(2*c),a=Math.sqrt(Math.max(0,i/c-n*n)),r.x=e.x+n*s-a*l,r.y=e.y+n*l+a*s)):(r.x=e.x+r.r,r.y=e.y)}function b(t,e){var r=t.r+e.r-1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function _(t){var e=t._,r=t.next._,n=e.r+r.r,i=(e.x*r.r+r.x*e.r)/n,a=(e.y*r.r+r.y*e.r)/n;return i*i+a*a}function w(t){this._=t,this.next=null,this.previous=null}function k(t){if(!(i=t.length))return 0;var e,r,n,i,a,o,s,l,c,u,f;if((e=t[0]).x=0,e.y=0,!(i>1))return e.r;if(r=t[1],e.x=-r.r,r.x=e.r,r.y=0,!(i>2))return e.r+r.r;x(r,e,n=t[2]),e=new w(e),r=new w(r),n=new w(n),e.next=n.previous=r,r.next=e.previous=n,n.next=r.previous=e;t:for(s=3;s<i;++s){x(e._,r._,n=t[s]),n=new w(n),l=r.next,c=e.previous,u=r._.r,f=e._.r;do{if(u<=f){if(b(l._,n._)){r=l,e.next=r,r.previous=e,--s;continue t}u+=l._.r,l=l.next}else{if(b(c._,n._)){(e=c).next=r,r.previous=e,--s;continue t}f+=c._.r,c=c.previous}}while(l!==c.next);for(n.previous=e,n.next=r,e.next=r.previous=r=n,a=_(e);(n=n.next)!==r;)(o=_(n))<a&&(e=n,a=o);r=e.next}for(e=[r._],n=r;(n=n.next)!==r;)e.push(n._);for(n=h(e),s=0;s<i;++s)(e=t[s]).x-=n.x,e.y-=n.y;return n.r}function T(t){if(\"function\"!=typeof t)throw new Error;return t}function A(){return 0}function M(t){return function(){return t}}function S(t){return Math.sqrt(t.value)}function E(t){return function(e){e.children||(e.r=Math.max(0,+t(e)||0))}}function C(t,e){return function(r){if(n=r.children){var n,i,a,o=n.length,s=t(r)*e||0;if(s)for(i=0;i<o;++i)n[i].r+=s;if(a=k(n),s)for(i=0;i<o;++i)n[i].r-=s;r.r=a+s}}}function L(t){return function(e){var r=e.parent;e.r*=t,r&&(e.x=r.x+t*e.x,e.y=r.y+t*e.y)}}function P(t){t.x0=Math.round(t.x0),t.y0=Math.round(t.y0),t.x1=Math.round(t.x1),t.y1=Math.round(t.y1)}function O(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(n-e)/t.value;++s<l;)(a=o[s]).y0=r,a.y1=i,a.x0=e,a.x1=e+=a.value*c}var z=\"$\",I={depth:-1},D={};function R(t){return t.id}function F(t){return t.parentId}function B(t,e){return t.parent===e.parent?1:2}function N(t){var e=t.children;return e?e[0]:t.t}function j(t){var e=t.children;return e?e[e.length-1]:t.t}function U(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function V(t,e,r){return t.a.parent===e.parent?t.a:r}function q(t,e){this._=t,this.parent=null,this.children=null,this.A=null,this.a=this,this.z=0,this.m=0,this.c=0,this.s=0,this.t=null,this.i=e}function H(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(i-r)/t.value;++s<l;)(a=o[s]).x0=e,a.x1=n,a.y0=r,a.y1=r+=a.value*c}q.prototype=Object.create(c.prototype);var G=(1+Math.sqrt(5))/2;function Y(t,e,r,n,i,a){for(var o,s,l,c,u,h,f,p,d,g,v,m=[],y=e.children,x=0,b=0,_=y.length,w=e.value;x<_;){l=i-r,c=a-n;do{u=y[b++].value}while(!u&&b<_);for(h=f=u,v=u*u*(g=Math.max(c/l,l/c)/(w*t)),d=Math.max(f/v,v/h);b<_;++b){if(u+=s=y[b].value,s<h&&(h=s),s>f&&(f=s),v=u*u*g,(p=Math.max(f/v,v/h))>d){u-=s;break}d=p}m.push(o={value:u,dice:l<c,children:y.slice(x,b)}),o.dice?O(o,r,n,i,w?n+=c*u/w:a):H(o,r,n,w?r+=l*u/w:i,a),w-=u,x=b}return m}var W=function t(e){function r(t,r,n,i,a){Y(e,t,r,n,i,a)}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);var X=function t(e){function r(t,r,n,i,a){if((o=t._squarify)&&o.ratio===e)for(var o,s,l,c,u,h=-1,f=o.length,p=t.value;++h<f;){for(l=(s=o[h]).children,c=s.value=0,u=l.length;c<u;++c)s.value+=l[c].value;s.dice?O(s,r,n,i,n+=(a-n)*s.value/p):H(s,r,n,r+=(i-r)*s.value/p,a),p-=s.value}else t._squarify=o=Y(e,t,r,n,i,a),o.ratio=e}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);t.cluster=function(){var t=e,i=1,a=1,o=!1;function s(e){var s,l=0;e.eachAfter(function(e){var i=e.children;i?(e.x=function(t){return t.reduce(r,0)/t.length}(i),e.y=function(t){return 1+t.reduce(n,0)}(i)):(e.x=s?l+=t(e,s):0,e.y=0,s=e)});var c=function(t){for(var e;e=t.children;)t=e[0];return t}(e),u=function(t){for(var e;e=t.children;)t=e[e.length-1];return t}(e),h=c.x-t(c,u)/2,f=u.x+t(u,c)/2;return e.eachAfter(o?function(t){t.x=(t.x-e.x)*i,t.y=(e.y-t.y)*a}:function(t){t.x=(t.x-h)/(f-h)*i,t.y=(1-(e.y?t.y/e.y:1))*a})}return s.separation=function(e){return arguments.length?(t=e,s):t},s.size=function(t){return arguments.length?(o=!1,i=+t[0],a=+t[1],s):o?null:[i,a]},s.nodeSize=function(t){return arguments.length?(o=!0,i=+t[0],a=+t[1],s):o?[i,a]:null},s},t.hierarchy=a,t.pack=function(){var t=null,e=1,r=1,n=A;function i(i){return i.x=e/2,i.y=r/2,t?i.eachBefore(E(t)).eachAfter(C(n,.5)).eachBefore(L(1)):i.eachBefore(E(S)).eachAfter(C(A,1)).eachAfter(C(n,i.r/Math.min(e,r))).eachBefore(L(Math.min(e,r)/(2*i.r))),i}return i.radius=function(e){return arguments.length?(t=null==(r=e)?null:T(r),i):t;var r},i.size=function(t){return arguments.length?(e=+t[0],r=+t[1],i):[e,r]},i.padding=function(t){return arguments.length?(n=\"function\"==typeof t?t:M(+t),i):n},i},t.packSiblings=function(t){return k(t),t},t.packEnclose=h,t.partition=function(){var t=1,e=1,r=0,n=!1;function i(i){var a=i.height+1;return i.x0=i.y0=r,i.x1=t,i.y1=e/a,i.eachBefore(function(t,e){return function(n){n.children&&O(n,n.x0,t*(n.depth+1)/e,n.x1,t*(n.depth+2)/e);var i=n.x0,a=n.y0,o=n.x1-r,s=n.y1-r;o<i&&(i=o=(i+o)/2),s<a&&(a=s=(a+s)/2),n.x0=i,n.y0=a,n.x1=o,n.y1=s}}(e,a)),n&&i.eachBefore(P),i}return i.round=function(t){return arguments.length?(n=!!t,i):n},i.size=function(r){return arguments.length?(t=+r[0],e=+r[1],i):[t,e]},i.padding=function(t){return arguments.length?(r=+t,i):r},i},t.stratify=function(){var t=R,e=F;function r(r){var n,i,a,o,s,u,h,f=r.length,p=new Array(f),d={};for(i=0;i<f;++i)n=r[i],s=p[i]=new c(n),null!=(u=t(n,i,r))&&(u+=\"\")&&(d[h=z+(s.id=u)]=h in d?D:s);for(i=0;i<f;++i)if(s=p[i],null!=(u=e(r[i],i,r))&&(u+=\"\")){if(!(o=d[z+u]))throw new Error(\"missing: \"+u);if(o===D)throw new Error(\"ambiguous: \"+u);o.children?o.children.push(s):o.children=[s],s.parent=o}else{if(a)throw new Error(\"multiple roots\");a=s}if(!a)throw new Error(\"no root\");if(a.parent=I,a.eachBefore(function(t){t.depth=t.parent.depth+1,--f}).eachBefore(l),a.parent=null,f>0)throw new Error(\"cycle\");return a}return r.id=function(e){return arguments.length?(t=T(e),r):t},r.parentId=function(t){return arguments.length?(e=T(t),r):e},r},t.tree=function(){var t=B,e=1,r=1,n=null;function i(i){var l=function(t){for(var e,r,n,i,a,o=new q(t,0),s=[o];e=s.pop();)if(n=e._.children)for(e.children=new Array(a=n.length),i=a-1;i>=0;--i)s.push(r=e.children[i]=new q(n[i],i)),r.parent=e;return(o.parent=new q(null,0)).children=[o],o}(i);if(l.eachAfter(a),l.parent.m=-l.z,l.eachBefore(o),n)i.eachBefore(s);else{var c=i,u=i,h=i;i.eachBefore(function(t){t.x<c.x&&(c=t),t.x>u.x&&(u=t),t.depth>h.depth&&(h=t)});var f=c===u?1:t(c,u)/2,p=f-c.x,d=e/(u.x+f+p),g=r/(h.depth||1);i.eachBefore(function(t){t.x=(t.x+p)*d,t.y=t.depth*g})}return i}function a(e){var r=e.children,n=e.parent.children,i=e.i?n[e.i-1]:null;if(r){!function(t){for(var e,r=0,n=0,i=t.children,a=i.length;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(e);var a=(r[0].z+r[r.length-1].z)/2;i?(e.z=i.z+t(e._,i._),e.m=e.z-a):e.z=a}else i&&(e.z=i.z+t(e._,i._));e.parent.A=function(e,r,n){if(r){for(var i,a=e,o=e,s=r,l=a.parent.children[0],c=a.m,u=o.m,h=s.m,f=l.m;s=j(s),a=N(a),s&&a;)l=N(l),(o=j(o)).a=e,(i=s.z+h-a.z-c+t(s._,a._))>0&&(U(V(s,e,n),e,i),c+=i,u+=i),h+=s.m,c+=a.m,f+=l.m,u+=o.m;s&&!j(o)&&(o.t=s,o.m+=h-u),a&&!N(l)&&(l.t=a,l.m+=c-f,n=e)}return n}(e,i,e.parent.A||n[0])}function o(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function s(t){t.x*=e,t.y=t.depth*r}return i.separation=function(e){return arguments.length?(t=e,i):t},i.size=function(t){return arguments.length?(n=!1,e=+t[0],r=+t[1],i):n?null:[e,r]},i.nodeSize=function(t){return arguments.length?(n=!0,e=+t[0],r=+t[1],i):n?[e,r]:null},i},t.treemap=function(){var t=W,e=!1,r=1,n=1,i=[0],a=A,o=A,s=A,l=A,c=A;function u(t){return t.x0=t.y0=0,t.x1=r,t.y1=n,t.eachBefore(h),i=[0],e&&t.eachBefore(P),t}function h(e){var r=i[e.depth],n=e.x0+r,u=e.y0+r,h=e.x1-r,f=e.y1-r;h<n&&(n=h=(n+h)/2),f<u&&(u=f=(u+f)/2),e.x0=n,e.y0=u,e.x1=h,e.y1=f,e.children&&(r=i[e.depth+1]=a(e)/2,n+=c(e)-r,u+=o(e)-r,(h-=s(e)-r)<n&&(n=h=(n+h)/2),(f-=l(e)-r)<u&&(u=f=(u+f)/2),t(e,n,u,h,f))}return u.round=function(t){return arguments.length?(e=!!t,u):e},u.size=function(t){return arguments.length?(r=+t[0],n=+t[1],u):[r,n]},u.tile=function(e){return arguments.length?(t=T(e),u):t},u.padding=function(t){return arguments.length?u.paddingInner(t).paddingOuter(t):u.paddingInner()},u.paddingInner=function(t){return arguments.length?(a=\"function\"==typeof t?t:M(+t),u):a},u.paddingOuter=function(t){return arguments.length?u.paddingTop(t).paddingRight(t).paddingBottom(t).paddingLeft(t):u.paddingTop()},u.paddingTop=function(t){return arguments.length?(o=\"function\"==typeof t?t:M(+t),u):o},u.paddingRight=function(t){return arguments.length?(s=\"function\"==typeof t?t:M(+t),u):s},u.paddingBottom=function(t){return arguments.length?(l=\"function\"==typeof t?t:M(+t),u):l},u.paddingLeft=function(t){return arguments.length?(c=\"function\"==typeof t?t:M(+t),u):c},u},t.treemapBinary=function(t,e,r,n,i){var a,o,s=t.children,l=s.length,c=new Array(l+1);for(c[0]=o=a=0;a<l;++a)c[a+1]=o+=s[a].value;!function t(e,r,n,i,a,o,l){if(e>=r-1){var u=s[e];return u.x0=i,u.y0=a,u.x1=o,void(u.y1=l)}for(var h=c[e],f=n/2+h,p=e+1,d=r-1;p<d;){var g=p+d>>>1;c[g]<f?p=g+1:d=g}f-c[p-1]<c[p]-f&&e+1<p&&--p;var v=c[p]-h,m=n-v;if(o-i>l-a){var y=(i*m+o*v)/n;t(e,p,v,i,a,y,l),t(p,r,m,y,a,o,l)}else{var x=(a*m+l*v)/n;t(e,p,v,i,a,o,x),t(p,r,m,i,x,o,l)}}(0,l,t.value,e,r,n,i)},t.treemapDice=O,t.treemapSlice=H,t.treemapSliceDice=function(t,e,r,n,i){(1&t.depth?H:O)(t,e,r,n,i)},t.treemapSquarify=W,t.treemapResquarify=X,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],158:[function(t,e,r){var n,i;n=this,i=function(t,e){\"use strict\";function r(t,e,r,n,i){var a=t*t,o=a*t;return((1-3*t+3*a-o)*e+(4-6*a+3*o)*r+(1+3*t+3*a-3*o)*n+o*i)/6}function n(t){var e=t.length-1;return function(n){var i=n<=0?n=0:n>=1?(n=1,e-1):Math.floor(n*e),a=t[i],o=t[i+1],s=i>0?t[i-1]:2*a-o,l=i<e-1?t[i+2]:2*o-a;return r((n-i/e)*e,s,a,o,l)}}function i(t){var e=t.length;return function(n){var i=Math.floor(((n%=1)<0?++n:n)*e),a=t[(i+e-1)%e],o=t[i%e],s=t[(i+1)%e],l=t[(i+2)%e];return r((n-i/e)*e,a,o,s,l)}}function a(t){return function(){return t}}function o(t,e){return function(r){return t+r*e}}function s(t,e){var r=e-t;return r?o(t,r>180||r<-180?r-360*Math.round(r/360):r):a(isNaN(t)?e:t)}function l(t){return 1==(t=+t)?c:function(e,r){return r-e?function(t,e,r){return t=Math.pow(t,r),e=Math.pow(e,r)-t,r=1/r,function(n){return Math.pow(t+n*e,r)}}(e,r,t):a(isNaN(e)?r:e)}}function c(t,e){var r=e-t;return r?o(t,r):a(isNaN(t)?e:t)}var u=function t(r){var n=l(r);function i(t,r){var i=n((t=e.rgb(t)).r,(r=e.rgb(r)).r),a=n(t.g,r.g),o=n(t.b,r.b),s=c(t.opacity,r.opacity);return function(e){return t.r=i(e),t.g=a(e),t.b=o(e),t.opacity=s(e),t+\"\"}}return i.gamma=t,i}(1);function h(t){return function(r){var n,i,a=r.length,o=new Array(a),s=new Array(a),l=new Array(a);for(n=0;n<a;++n)i=e.rgb(r[n]),o[n]=i.r||0,s[n]=i.g||0,l[n]=i.b||0;return o=t(o),s=t(s),l=t(l),i.opacity=1,function(t){return i.r=o(t),i.g=s(t),i.b=l(t),i+\"\"}}}var f=h(n),p=h(i);function d(t,e){var r,n=e?e.length:0,i=t?Math.min(n,t.length):0,a=new Array(i),o=new Array(n);for(r=0;r<i;++r)a[r]=_(t[r],e[r]);for(;r<n;++r)o[r]=e[r];return function(t){for(r=0;r<i;++r)o[r]=a[r](t);return o}}function g(t,e){var r=new Date;return e-=t=+t,function(n){return r.setTime(t+e*n),r}}function v(t,e){return e-=t=+t,function(r){return t+e*r}}function m(t,e){var r,n={},i={};for(r in null!==t&&\"object\"==typeof t||(t={}),null!==e&&\"object\"==typeof e||(e={}),e)r in t?n[r]=_(t[r],e[r]):i[r]=e[r];return function(t){for(r in n)i[r]=n[r](t);return i}}var y=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,x=new RegExp(y.source,\"g\");function b(t,e){var r,n,i,a=y.lastIndex=x.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=y.exec(t))&&(n=x.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:v(r,n)})),a=x.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?function(t){return function(e){return t(e)+\"\"}}(l[0].x):function(t){return function(){return t}}(e):(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}function _(t,r){var n,i=typeof r;return null==r||\"boolean\"===i?a(r):(\"number\"===i?v:\"string\"===i?(n=e.color(r))?(r=n,u):b:r instanceof e.color?u:r instanceof Date?g:Array.isArray(r)?d:\"function\"!=typeof r.valueOf&&\"function\"!=typeof r.toString||isNaN(r)?m:v)(t,r)}var w,k,T,A,M=180/Math.PI,S={translateX:0,translateY:0,rotate:0,skewX:0,scaleX:1,scaleY:1};function E(t,e,r,n,i,a){var o,s,l;return(o=Math.sqrt(t*t+e*e))&&(t/=o,e/=o),(l=t*r+e*n)&&(r-=t*l,n-=e*l),(s=Math.sqrt(r*r+n*n))&&(r/=s,n/=s,l/=s),t*n<e*r&&(t=-t,e=-e,l=-l,o=-o),{translateX:i,translateY:a,rotate:Math.atan2(e,t)*M,skewX:Math.atan(l)*M,scaleX:o,scaleY:s}}function C(t,e,r,n){function i(t){return t.length?t.pop()+\" \":\"\"}return function(a,o){var s=[],l=[];return a=t(a),o=t(o),function(t,n,i,a,o,s){if(t!==i||n!==a){var l=o.push(\"translate(\",null,e,null,r);s.push({i:l-4,x:v(t,i)},{i:l-2,x:v(n,a)})}else(i||a)&&o.push(\"translate(\"+i+e+a+r)}(a.translateX,a.translateY,o.translateX,o.translateY,s,l),function(t,e,r,a){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),a.push({i:r.push(i(r)+\"rotate(\",null,n)-2,x:v(t,e)})):e&&r.push(i(r)+\"rotate(\"+e+n)}(a.rotate,o.rotate,s,l),function(t,e,r,a){t!==e?a.push({i:r.push(i(r)+\"skewX(\",null,n)-2,x:v(t,e)}):e&&r.push(i(r)+\"skewX(\"+e+n)}(a.skewX,o.skewX,s,l),function(t,e,r,n,a,o){if(t!==r||e!==n){var s=a.push(i(a)+\"scale(\",null,\",\",null,\")\");o.push({i:s-4,x:v(t,r)},{i:s-2,x:v(e,n)})}else 1===r&&1===n||a.push(i(a)+\"scale(\"+r+\",\"+n+\")\")}(a.scaleX,a.scaleY,o.scaleX,o.scaleY,s,l),a=o=null,function(t){for(var e,r=-1,n=l.length;++r<n;)s[(e=l[r]).i]=e.x(t);return s.join(\"\")}}}var L=C(function(t){return\"none\"===t?S:(w||(w=document.createElement(\"DIV\"),k=document.documentElement,T=document.defaultView),w.style.transform=t,t=T.getComputedStyle(k.appendChild(w),null).getPropertyValue(\"transform\"),k.removeChild(w),E(+(t=t.slice(7,-1).split(\",\"))[0],+t[1],+t[2],+t[3],+t[4],+t[5]))},\"px, \",\"px)\",\"deg)\"),P=C(function(t){return null==t?S:(A||(A=document.createElementNS(\"http://www.w3.org/2000/svg\",\"g\")),A.setAttribute(\"transform\",t),(t=A.transform.baseVal.consolidate())?E((t=t.matrix).a,t.b,t.c,t.d,t.e,t.f):S)},\", \",\")\",\")\"),O=Math.SQRT2,z=2,I=4,D=1e-12;function R(t){return((t=Math.exp(t))+1/t)/2}function F(t){return function(r,n){var i=t((r=e.hsl(r)).h,(n=e.hsl(n)).h),a=c(r.s,n.s),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.s=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var B=F(s),N=F(c);function j(t){return function(r,n){var i=t((r=e.hcl(r)).h,(n=e.hcl(n)).h),a=c(r.c,n.c),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.c=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var U=j(s),V=j(c);function q(t){return function r(n){function i(r,i){var a=t((r=e.cubehelix(r)).h,(i=e.cubehelix(i)).h),o=c(r.s,i.s),s=c(r.l,i.l),l=c(r.opacity,i.opacity);return function(t){return r.h=a(t),r.s=o(t),r.l=s(Math.pow(t,n)),r.opacity=l(t),r+\"\"}}return n=+n,i.gamma=r,i}(1)}var H=q(s),G=q(c);t.interpolate=_,t.interpolateArray=d,t.interpolateBasis=n,t.interpolateBasisClosed=i,t.interpolateDate=g,t.interpolateDiscrete=function(t){var e=t.length;return function(r){return t[Math.max(0,Math.min(e-1,Math.floor(r*e)))]}},t.interpolateHue=function(t,e){var r=s(+t,+e);return function(t){var e=r(t);return e-360*Math.floor(e/360)}},t.interpolateNumber=v,t.interpolateObject=m,t.interpolateRound=function(t,e){return e-=t=+t,function(r){return Math.round(t+e*r)}},t.interpolateString=b,t.interpolateTransformCss=L,t.interpolateTransformSvg=P,t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,h=l-a,f=u*u+h*h;if(f<D)n=Math.log(c/o)/O,r=function(t){return[i+t*u,a+t*h,o*Math.exp(O*t*n)]};else{var p=Math.sqrt(f),d=(c*c-o*o+I*f)/(2*o*z*p),g=(c*c-o*o-I*f)/(2*c*z*p),v=Math.log(Math.sqrt(d*d+1)-d),m=Math.log(Math.sqrt(g*g+1)-g);n=(m-v)/O,r=function(t){var e,r=t*n,s=R(v),l=o/(z*p)*(s*(e=O*r+v,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(v));return[i+l*u,a+l*h,o*s/R(O*r+v)]}}return r.duration=1e3*n,r},t.interpolateRgb=u,t.interpolateRgbBasis=f,t.interpolateRgbBasisClosed=p,t.interpolateHsl=B,t.interpolateHslLong=N,t.interpolateLab=function(t,r){var n=c((t=e.lab(t)).l,(r=e.lab(r)).l),i=c(t.a,r.a),a=c(t.b,r.b),o=c(t.opacity,r.opacity);return function(e){return t.l=n(e),t.a=i(e),t.b=a(e),t.opacity=o(e),t+\"\"}},t.interpolateHcl=U,t.interpolateHclLong=V,t.interpolateCubehelix=H,t.interpolateCubehelixLong=G,t.piecewise=function(t,e){for(var r=0,n=e.length-1,i=e[0],a=new Array(n<0?0:n);r<n;)a[r]=t(i,i=e[++r]);return function(t){var e=Math.max(0,Math.min(n-1,Math.floor(t*=n)));return a[e](t-e)}},t.quantize=function(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t(n/(e-1));return r},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-color\")):i(n.d3=n.d3||{},n.d3)},{\"d3-color\":154}],159:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e=Math.PI,r=2*e,n=r-1e-6;function i(){this._x0=this._y0=this._x1=this._y1=null,this._=\"\"}function a(){return new i}i.prototype=a.prototype={constructor:i,moveTo:function(t,e){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)},closePath:function(){null!==this._x1&&(this._x1=this._x0,this._y1=this._y0,this._+=\"Z\")},lineTo:function(t,e){this._+=\"L\"+(this._x1=+t)+\",\"+(this._y1=+e)},quadraticCurveTo:function(t,e,r,n){this._+=\"Q\"+ +t+\",\"+ +e+\",\"+(this._x1=+r)+\",\"+(this._y1=+n)},bezierCurveTo:function(t,e,r,n,i,a){this._+=\"C\"+ +t+\",\"+ +e+\",\"+ +r+\",\"+ +n+\",\"+(this._x1=+i)+\",\"+(this._y1=+a)},arcTo:function(t,r,n,i,a){t=+t,r=+r,n=+n,i=+i,a=+a;var o=this._x1,s=this._y1,l=n-t,c=i-r,u=o-t,h=s-r,f=u*u+h*h;if(a<0)throw new Error(\"negative radius: \"+a);if(null===this._x1)this._+=\"M\"+(this._x1=t)+\",\"+(this._y1=r);else if(f>1e-6)if(Math.abs(h*l-c*u)>1e-6&&a){var p=n-o,d=i-s,g=l*l+c*c,v=p*p+d*d,m=Math.sqrt(g),y=Math.sqrt(f),x=a*Math.tan((e-Math.acos((g+f-v)/(2*m*y)))/2),b=x/y,_=x/m;Math.abs(b-1)>1e-6&&(this._+=\"L\"+(t+b*u)+\",\"+(r+b*h)),this._+=\"A\"+a+\",\"+a+\",0,0,\"+ +(h*p>u*d)+\",\"+(this._x1=t+_*l)+\",\"+(this._y1=r+_*c)}else this._+=\"L\"+(this._x1=t)+\",\"+(this._y1=r);else;},arc:function(t,i,a,o,s,l){t=+t,i=+i;var c=(a=+a)*Math.cos(o),u=a*Math.sin(o),h=t+c,f=i+u,p=1^l,d=l?o-s:s-o;if(a<0)throw new Error(\"negative radius: \"+a);null===this._x1?this._+=\"M\"+h+\",\"+f:(Math.abs(this._x1-h)>1e-6||Math.abs(this._y1-f)>1e-6)&&(this._+=\"L\"+h+\",\"+f),a&&(d<0&&(d=d%r+r),d>n?this._+=\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(t-c)+\",\"+(i-u)+\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(this._x1=h)+\",\"+(this._y1=f):d>1e-6&&(this._+=\"A\"+a+\",\"+a+\",0,\"+ +(d>=e)+\",\"+p+\",\"+(this._x1=t+a*Math.cos(s))+\",\"+(this._y1=i+a*Math.sin(s))))},rect:function(t,e,r,n){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)+\"h\"+ +r+\"v\"+ +n+\"h\"+-r+\"Z\"},toString:function(){return this._}},t.path=a,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],160:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e,r,n){if(isNaN(e)||isNaN(r))return t;var i,a,o,s,l,c,u,h,f,p=t._root,d={data:n},g=t._x0,v=t._y0,m=t._x1,y=t._y1;if(!p)return t._root=d,t;for(;p.length;)if((c=e>=(a=(g+m)/2))?g=a:m=a,(u=r>=(o=(v+y)/2))?v=o:y=o,i=p,!(p=p[h=u<<1|c]))return i[h]=d,t;if(s=+t._x.call(null,p.data),l=+t._y.call(null,p.data),e===s&&r===l)return d.next=p,i?i[h]=d:t._root=d,t;do{i=i?i[h]=new Array(4):t._root=new Array(4),(c=e>=(a=(g+m)/2))?g=a:m=a,(u=r>=(o=(v+y)/2))?v=o:y=o}while((h=u<<1|c)==(f=(l>=o)<<1|s>=a));return i[f]=p,i[h]=d,t}var r=function(t,e,r,n,i){this.node=t,this.x0=e,this.y0=r,this.x1=n,this.y1=i};function n(t){return t[0]}function i(t){return t[1]}function a(t,e,r){var a=new o(null==e?n:e,null==r?i:r,NaN,NaN,NaN,NaN);return null==t?a:a.addAll(t)}function o(t,e,r,n,i,a){this._x=t,this._y=e,this._x0=r,this._y0=n,this._x1=i,this._y1=a,this._root=void 0}function s(t){for(var e={data:t.data},r=e;t=t.next;)r=r.next={data:t.data};return e}var l=a.prototype=o.prototype;l.copy=function(){var t,e,r=new o(this._x,this._y,this._x0,this._y0,this._x1,this._y1),n=this._root;if(!n)return r;if(!n.length)return r._root=s(n),r;for(t=[{source:n,target:r._root=new Array(4)}];n=t.pop();)for(var i=0;i<4;++i)(e=n.source[i])&&(e.length?t.push({source:e,target:n.target[i]=new Array(4)}):n.target[i]=s(e));return r},l.add=function(t){var r=+this._x.call(null,t),n=+this._y.call(null,t);return e(this.cover(r,n),r,n,t)},l.addAll=function(t){var r,n,i,a,o=t.length,s=new Array(o),l=new Array(o),c=1/0,u=1/0,h=-1/0,f=-1/0;for(n=0;n<o;++n)isNaN(i=+this._x.call(null,r=t[n]))||isNaN(a=+this._y.call(null,r))||(s[n]=i,l[n]=a,i<c&&(c=i),i>h&&(h=i),a<u&&(u=a),a>f&&(f=a));for(h<c&&(c=this._x0,h=this._x1),f<u&&(u=this._y0,f=this._y1),this.cover(c,u).cover(h,f),n=0;n<o;++n)e(this,s[n],l[n],t[n]);return this},l.cover=function(t,e){if(isNaN(t=+t)||isNaN(e=+e))return this;var r=this._x0,n=this._y0,i=this._x1,a=this._y1;if(isNaN(r))i=(r=Math.floor(t))+1,a=(n=Math.floor(e))+1;else{if(!(r>t||t>i||n>e||e>a))return this;var o,s,l=i-r,c=this._root;switch(s=(e<(n+a)/2)<<1|t<(r+i)/2){case 0:do{(o=new Array(4))[s]=c,c=o}while(a=n+(l*=2),t>(i=r+l)||e>a);break;case 1:do{(o=new Array(4))[s]=c,c=o}while(a=n+(l*=2),(r=i-l)>t||e>a);break;case 2:do{(o=new Array(4))[s]=c,c=o}while(n=a-(l*=2),t>(i=r+l)||n>e);break;case 3:do{(o=new Array(4))[s]=c,c=o}while(n=a-(l*=2),(r=i-l)>t||n>e)}this._root&&this._root.length&&(this._root=c)}return this._x0=r,this._y0=n,this._x1=i,this._y1=a,this},l.data=function(){var t=[];return this.visit(function(e){if(!e.length)do{t.push(e.data)}while(e=e.next)}),t},l.extent=function(t){return arguments.length?this.cover(+t[0][0],+t[0][1]).cover(+t[1][0],+t[1][1]):isNaN(this._x0)?void 0:[[this._x0,this._y0],[this._x1,this._y1]]},l.find=function(t,e,n){var i,a,o,s,l,c,u,h=this._x0,f=this._y0,p=this._x1,d=this._y1,g=[],v=this._root;for(v&&g.push(new r(v,h,f,p,d)),null==n?n=1/0:(h=t-n,f=e-n,p=t+n,d=e+n,n*=n);c=g.pop();)if(!(!(v=c.node)||(a=c.x0)>p||(o=c.y0)>d||(s=c.x1)<h||(l=c.y1)<f))if(v.length){var m=(a+s)/2,y=(o+l)/2;g.push(new r(v[3],m,y,s,l),new r(v[2],a,y,m,l),new r(v[1],m,o,s,y),new r(v[0],a,o,m,y)),(u=(e>=y)<<1|t>=m)&&(c=g[g.length-1],g[g.length-1]=g[g.length-1-u],g[g.length-1-u]=c)}else{var x=t-+this._x.call(null,v.data),b=e-+this._y.call(null,v.data),_=x*x+b*b;if(_<n){var w=Math.sqrt(n=_);h=t-w,f=e-w,p=t+w,d=e+w,i=v.data}}return i},l.remove=function(t){if(isNaN(a=+this._x.call(null,t))||isNaN(o=+this._y.call(null,t)))return this;var e,r,n,i,a,o,s,l,c,u,h,f,p=this._root,d=this._x0,g=this._y0,v=this._x1,m=this._y1;if(!p)return this;if(p.length)for(;;){if((c=a>=(s=(d+v)/2))?d=s:v=s,(u=o>=(l=(g+m)/2))?g=l:m=l,e=p,!(p=p[h=u<<1|c]))return this;if(!p.length)break;(e[h+1&3]||e[h+2&3]||e[h+3&3])&&(r=e,f=h)}for(;p.data!==t;)if(n=p,!(p=p.next))return this;return(i=p.next)&&delete p.next,n?(i?n.next=i:delete n.next,this):e?(i?e[h]=i:delete e[h],(p=e[0]||e[1]||e[2]||e[3])&&p===(e[3]||e[2]||e[1]||e[0])&&!p.length&&(r?r[f]=p:this._root=p),this):(this._root=i,this)},l.removeAll=function(t){for(var e=0,r=t.length;e<r;++e)this.remove(t[e]);return this},l.root=function(){return this._root},l.size=function(){var t=0;return this.visit(function(e){if(!e.length)do{++t}while(e=e.next)}),t},l.visit=function(t){var e,n,i,a,o,s,l=[],c=this._root;for(c&&l.push(new r(c,this._x0,this._y0,this._x1,this._y1));e=l.pop();)if(!t(c=e.node,i=e.x0,a=e.y0,o=e.x1,s=e.y1)&&c.length){var u=(i+o)/2,h=(a+s)/2;(n=c[3])&&l.push(new r(n,u,h,o,s)),(n=c[2])&&l.push(new r(n,i,h,u,s)),(n=c[1])&&l.push(new r(n,u,a,o,h)),(n=c[0])&&l.push(new r(n,i,a,u,h))}return this},l.visitAfter=function(t){var e,n=[],i=[];for(this._root&&n.push(new r(this._root,this._x0,this._y0,this._x1,this._y1));e=n.pop();){var a=e.node;if(a.length){var o,s=e.x0,l=e.y0,c=e.x1,u=e.y1,h=(s+c)/2,f=(l+u)/2;(o=a[0])&&n.push(new r(o,s,l,h,f)),(o=a[1])&&n.push(new r(o,h,l,c,f)),(o=a[2])&&n.push(new r(o,s,f,h,u)),(o=a[3])&&n.push(new r(o,h,f,c,u))}i.push(e)}for(;e=i.pop();)t(e.node,e.x0,e.y0,e.x1,e.y1);return this},l.x=function(t){return arguments.length?(this._x=t,this):this._x},l.y=function(t){return arguments.length?(this._y=t,this):this._y},t.quadtree=a,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],161:[function(t,e,r){var n,i;n=this,i=function(t,e){\"use strict\";function r(t){return function(){return t}}var n=Math.abs,i=Math.atan2,a=Math.cos,o=Math.max,s=Math.min,l=Math.sin,c=Math.sqrt,u=1e-12,h=Math.PI,f=h/2,p=2*h;function d(t){return t>=1?f:t<=-1?-f:Math.asin(t)}function g(t){return t.innerRadius}function v(t){return t.outerRadius}function m(t){return t.startAngle}function y(t){return t.endAngle}function x(t){return t&&t.padAngle}function b(t,e,r,n,i,a,s){var l=t-r,u=e-n,h=(s?a:-a)/c(l*l+u*u),f=h*u,p=-h*l,d=t+f,g=e+p,v=r+f,m=n+p,y=(d+v)/2,x=(g+m)/2,b=v-d,_=m-g,w=b*b+_*_,k=i-a,T=d*m-v*g,A=(_<0?-1:1)*c(o(0,k*k*w-T*T)),M=(T*_-b*A)/w,S=(-T*b-_*A)/w,E=(T*_+b*A)/w,C=(-T*b+_*A)/w,L=M-y,P=S-x,O=E-y,z=C-x;return L*L+P*P>O*O+z*z&&(M=E,S=C),{cx:M,cy:S,x01:-f,y01:-p,x11:M*(i/k-1),y11:S*(i/k-1)}}function _(t){this._context=t}function w(t){return new _(t)}function k(t){return t[0]}function T(t){return t[1]}function A(){var t=k,n=T,i=r(!0),a=null,o=w,s=null;function l(r){var l,c,u,h=r.length,f=!1;for(null==a&&(s=o(u=e.path())),l=0;l<=h;++l)!(l<h&&i(c=r[l],l,r))===f&&((f=!f)?s.lineStart():s.lineEnd()),f&&s.point(+t(c,l,r),+n(c,l,r));if(u)return s=null,u+\"\"||null}return l.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),l):t},l.y=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),l):n},l.defined=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(!!t),l):i},l.curve=function(t){return arguments.length?(o=t,null!=a&&(s=o(a)),l):o},l.context=function(t){return arguments.length?(null==t?a=s=null:s=o(a=t),l):a},l}function M(){var t=k,n=null,i=r(0),a=T,o=r(!0),s=null,l=w,c=null;function u(r){var u,h,f,p,d,g=r.length,v=!1,m=new Array(g),y=new Array(g);for(null==s&&(c=l(d=e.path())),u=0;u<=g;++u){if(!(u<g&&o(p=r[u],u,r))===v)if(v=!v)h=u,c.areaStart(),c.lineStart();else{for(c.lineEnd(),c.lineStart(),f=u-1;f>=h;--f)c.point(m[f],y[f]);c.lineEnd(),c.areaEnd()}v&&(m[u]=+t(p,u,r),y[u]=+i(p,u,r),c.point(n?+n(p,u,r):m[u],a?+a(p,u,r):y[u]))}if(d)return c=null,d+\"\"||null}function h(){return A().defined(o).curve(l).context(s)}return u.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),n=null,u):t},u.x0=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),u):t},u.x1=function(t){return arguments.length?(n=null==t?null:\"function\"==typeof t?t:r(+t),u):n},u.y=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a=null,u):i},u.y0=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),u):i},u.y1=function(t){return arguments.length?(a=null==t?null:\"function\"==typeof t?t:r(+t),u):a},u.lineX0=u.lineY0=function(){return h().x(t).y(i)},u.lineY1=function(){return h().x(t).y(a)},u.lineX1=function(){return h().x(n).y(i)},u.defined=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(!!t),u):o},u.curve=function(t){return arguments.length?(l=t,null!=s&&(c=l(s)),u):l},u.context=function(t){return arguments.length?(null==t?s=c=null:c=l(s=t),u):s},u}function S(t,e){return e<t?-1:e>t?1:e>=t?0:NaN}function E(t){return t}_.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._point=0},lineEnd:function(){(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:this._context.lineTo(t,e)}}};var C=P(w);function L(t){this._curve=t}function P(t){function e(e){return new L(t(e))}return e._curve=t,e}function O(t){var e=t.curve;return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function z(){return O(A().curve(C))}function I(){var t=M().curve(C),e=t.curve,r=t.lineX0,n=t.lineX1,i=t.lineY0,a=t.lineY1;return t.angle=t.x,delete t.x,t.startAngle=t.x0,delete t.x0,t.endAngle=t.x1,delete t.x1,t.radius=t.y,delete t.y,t.innerRadius=t.y0,delete t.y0,t.outerRadius=t.y1,delete t.y1,t.lineStartAngle=function(){return O(r())},delete t.lineX0,t.lineEndAngle=function(){return O(n())},delete t.lineX1,t.lineInnerRadius=function(){return O(i())},delete t.lineY0,t.lineOuterRadius=function(){return O(a())},delete t.lineY1,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function D(t,e){return[(e=+e)*Math.cos(t-=Math.PI/2),e*Math.sin(t)]}L.prototype={areaStart:function(){this._curve.areaStart()},areaEnd:function(){this._curve.areaEnd()},lineStart:function(){this._curve.lineStart()},lineEnd:function(){this._curve.lineEnd()},point:function(t,e){this._curve.point(e*Math.sin(t),e*-Math.cos(t))}};var R=Array.prototype.slice;function F(t){return t.source}function B(t){return t.target}function N(t){var n=F,i=B,a=k,o=T,s=null;function l(){var r,l=R.call(arguments),c=n.apply(this,l),u=i.apply(this,l);if(s||(s=r=e.path()),t(s,+a.apply(this,(l[0]=c,l)),+o.apply(this,l),+a.apply(this,(l[0]=u,l)),+o.apply(this,l)),r)return s=null,r+\"\"||null}return l.source=function(t){return arguments.length?(n=t,l):n},l.target=function(t){return arguments.length?(i=t,l):i},l.x=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),l):a},l.y=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),l):o},l.context=function(t){return arguments.length?(s=null==t?null:t,l):s},l}function j(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e=(e+n)/2,r,e,i,n,i)}function U(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e,r=(r+i)/2,n,r,n,i)}function V(t,e,r,n,i){var a=D(e,r),o=D(e,r=(r+i)/2),s=D(n,r),l=D(n,i);t.moveTo(a[0],a[1]),t.bezierCurveTo(o[0],o[1],s[0],s[1],l[0],l[1])}var q={draw:function(t,e){var r=Math.sqrt(e/h);t.moveTo(r,0),t.arc(0,0,r,0,p)}},H={draw:function(t,e){var r=Math.sqrt(e/5)/2;t.moveTo(-3*r,-r),t.lineTo(-r,-r),t.lineTo(-r,-3*r),t.lineTo(r,-3*r),t.lineTo(r,-r),t.lineTo(3*r,-r),t.lineTo(3*r,r),t.lineTo(r,r),t.lineTo(r,3*r),t.lineTo(-r,3*r),t.lineTo(-r,r),t.lineTo(-3*r,r),t.closePath()}},G=Math.sqrt(1/3),Y=2*G,W={draw:function(t,e){var r=Math.sqrt(e/Y),n=r*G;t.moveTo(0,-r),t.lineTo(n,0),t.lineTo(0,r),t.lineTo(-n,0),t.closePath()}},X=Math.sin(h/10)/Math.sin(7*h/10),Z=Math.sin(p/10)*X,J=-Math.cos(p/10)*X,K={draw:function(t,e){var r=Math.sqrt(.8908130915292852*e),n=Z*r,i=J*r;t.moveTo(0,-r),t.lineTo(n,i);for(var a=1;a<5;++a){var o=p*a/5,s=Math.cos(o),l=Math.sin(o);t.lineTo(l*r,-s*r),t.lineTo(s*n-l*i,l*n+s*i)}t.closePath()}},$={draw:function(t,e){var r=Math.sqrt(e),n=-r/2;t.rect(n,n,r,r)}},Q=Math.sqrt(3),tt={draw:function(t,e){var r=-Math.sqrt(e/(3*Q));t.moveTo(0,2*r),t.lineTo(-Q*r,-r),t.lineTo(Q*r,-r),t.closePath()}},et=-.5,rt=Math.sqrt(3)/2,nt=1/Math.sqrt(12),it=3*(nt/2+1),at={draw:function(t,e){var r=Math.sqrt(e/it),n=r/2,i=r*nt,a=n,o=r*nt+r,s=-a,l=o;t.moveTo(n,i),t.lineTo(a,o),t.lineTo(s,l),t.lineTo(et*n-rt*i,rt*n+et*i),t.lineTo(et*a-rt*o,rt*a+et*o),t.lineTo(et*s-rt*l,rt*s+et*l),t.lineTo(et*n+rt*i,et*i-rt*n),t.lineTo(et*a+rt*o,et*o-rt*a),t.lineTo(et*s+rt*l,et*l-rt*s),t.closePath()}},ot=[q,H,W,$,K,tt,at];function st(){}function lt(t,e,r){t._context.bezierCurveTo((2*t._x0+t._x1)/3,(2*t._y0+t._y1)/3,(t._x0+2*t._x1)/3,(t._y0+2*t._y1)/3,(t._x0+4*t._x1+e)/6,(t._y0+4*t._y1+r)/6)}function ct(t){this._context=t}function ut(t){this._context=t}function ht(t){this._context=t}function ft(t,e){this._basis=new ct(t),this._beta=e}ct.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){switch(this._point){case 3:lt(this,this._x1,this._y1);case 2:this._context.lineTo(this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,this._context.lineTo((5*this._x0+this._x1)/6,(5*this._y0+this._y1)/6);default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ut.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._y0=this._y1=this._y2=this._y3=this._y4=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x2,this._y2),this._context.closePath();break;case 2:this._context.moveTo((this._x2+2*this._x3)/3,(this._y2+2*this._y3)/3),this._context.lineTo((this._x3+2*this._x2)/3,(this._y3+2*this._y2)/3),this._context.closePath();break;case 3:this.point(this._x2,this._y2),this.point(this._x3,this._y3),this.point(this._x4,this._y4)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x2=t,this._y2=e;break;case 1:this._point=2,this._x3=t,this._y3=e;break;case 2:this._point=3,this._x4=t,this._y4=e,this._context.moveTo((this._x0+4*this._x1+t)/6,(this._y0+4*this._y1+e)/6);break;default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ht.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3;var r=(this._x0+4*this._x1+t)/6,n=(this._y0+4*this._y1+e)/6;this._line?this._context.lineTo(r,n):this._context.moveTo(r,n);break;case 3:this._point=4;default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ft.prototype={lineStart:function(){this._x=[],this._y=[],this._basis.lineStart()},lineEnd:function(){var t=this._x,e=this._y,r=t.length-1;if(r>0)for(var n,i=t[0],a=e[0],o=t[r]-i,s=e[r]-a,l=-1;++l<=r;)n=l/r,this._basis.point(this._beta*t[l]+(1-this._beta)*(i+n*o),this._beta*e[l]+(1-this._beta)*(a+n*s));this._x=this._y=null,this._basis.lineEnd()},point:function(t,e){this._x.push(+t),this._y.push(+e)}};var pt=function t(e){function r(t){return 1===e?new ct(t):new ft(t,e)}return r.beta=function(e){return t(+e)},r}(.85);function dt(t,e,r){t._context.bezierCurveTo(t._x1+t._k*(t._x2-t._x0),t._y1+t._k*(t._y2-t._y0),t._x2+t._k*(t._x1-e),t._y2+t._k*(t._y1-r),t._x2,t._y2)}function gt(t,e){this._context=t,this._k=(1-e)/6}gt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:dt(this,this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2,this._x1=t,this._y1=e;break;case 2:this._point=3;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var vt=function t(e){function r(t){return new gt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function mt(t,e){this._context=t,this._k=(1-e)/6}mt.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var yt=function t(e){function r(t){return new mt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function xt(t,e){this._context=t,this._k=(1-e)/6}xt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var bt=function t(e){function r(t){return new xt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function _t(t,e,r){var n=t._x1,i=t._y1,a=t._x2,o=t._y2;if(t._l01_a>u){var s=2*t._l01_2a+3*t._l01_a*t._l12_a+t._l12_2a,l=3*t._l01_a*(t._l01_a+t._l12_a);n=(n*s-t._x0*t._l12_2a+t._x2*t._l01_2a)/l,i=(i*s-t._y0*t._l12_2a+t._y2*t._l01_2a)/l}if(t._l23_a>u){var c=2*t._l23_2a+3*t._l23_a*t._l12_a+t._l12_2a,h=3*t._l23_a*(t._l23_a+t._l12_a);a=(a*c+t._x1*t._l23_2a-e*t._l12_2a)/h,o=(o*c+t._y1*t._l23_2a-r*t._l12_2a)/h}t._context.bezierCurveTo(n,i,a,o,t._x2,t._y2)}function wt(t,e){this._context=t,this._alpha=e}wt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:this.point(this._x2,this._y2)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var kt=function t(e){function r(t){return e?new wt(t,e):new gt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Tt(t,e){this._context=t,this._alpha=e}Tt.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var At=function t(e){function r(t){return e?new Tt(t,e):new mt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Mt(t,e){this._context=t,this._alpha=e}Mt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var St=function t(e){function r(t){return e?new Mt(t,e):new xt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Et(t){this._context=t}function Ct(t){return t<0?-1:1}function Lt(t,e,r){var n=t._x1-t._x0,i=e-t._x1,a=(t._y1-t._y0)/(n||i<0&&-0),o=(r-t._y1)/(i||n<0&&-0),s=(a*i+o*n)/(n+i);return(Ct(a)+Ct(o))*Math.min(Math.abs(a),Math.abs(o),.5*Math.abs(s))||0}function Pt(t,e){var r=t._x1-t._x0;return r?(3*(t._y1-t._y0)/r-e)/2:e}function Ot(t,e,r){var n=t._x0,i=t._y0,a=t._x1,o=t._y1,s=(a-n)/3;t._context.bezierCurveTo(n+s,i+s*e,a-s,o-s*r,a,o)}function zt(t){this._context=t}function It(t){this._context=new Dt(t)}function Dt(t){this._context=t}function Rt(t){this._context=t}function Ft(t){var e,r,n=t.length-1,i=new Array(n),a=new Array(n),o=new Array(n);for(i[0]=0,a[0]=2,o[0]=t[0]+2*t[1],e=1;e<n-1;++e)i[e]=1,a[e]=4,o[e]=4*t[e]+2*t[e+1];for(i[n-1]=2,a[n-1]=7,o[n-1]=8*t[n-1]+t[n],e=1;e<n;++e)r=i[e]/a[e-1],a[e]-=r,o[e]-=r*o[e-1];for(i[n-1]=o[n-1]/a[n-1],e=n-2;e>=0;--e)i[e]=(o[e]-i[e+1])/a[e];for(a[n-1]=(t[n]+i[n-1])/2,e=0;e<n-1;++e)a[e]=2*t[e+1]-i[e+1];return[i,a]}function Bt(t,e){this._context=t,this._t=e}function Nt(t,e){if((i=t.length)>1)for(var r,n,i,a=1,o=t[e[0]],s=o.length;a<i;++a)for(n=o,o=t[e[a]],r=0;r<s;++r)o[r][1]+=o[r][0]=isNaN(n[r][1])?n[r][0]:n[r][1]}function jt(t){for(var e=t.length,r=new Array(e);--e>=0;)r[e]=e;return r}function Ut(t,e){return t[e]}function Vt(t){var e=t.map(qt);return jt(t).sort(function(t,r){return e[t]-e[r]})}function qt(t){for(var e,r=-1,n=0,i=t.length,a=-1/0;++r<i;)(e=+t[r][1])>a&&(a=e,n=r);return n}function Ht(t){var e=t.map(Gt);return jt(t).sort(function(t,r){return e[t]-e[r]})}function Gt(t){for(var e,r=0,n=-1,i=t.length;++n<i;)(e=+t[n][1])&&(r+=e);return r}Et.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._point=0},lineEnd:function(){this._point&&this._context.closePath()},point:function(t,e){t=+t,e=+e,this._point?this._context.lineTo(t,e):(this._point=1,this._context.moveTo(t,e))}},zt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=this._t0=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x1,this._y1);break;case 3:Ot(this,this._t0,Pt(this,this._t0))}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){var r=NaN;if(e=+e,(t=+t)!==this._x1||e!==this._y1){switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,Ot(this,Pt(this,r=Lt(this,t,e)),r);break;default:Ot(this,this._t0,r=Lt(this,t,e))}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e,this._t0=r}}},(It.prototype=Object.create(zt.prototype)).point=function(t,e){zt.prototype.point.call(this,e,t)},Dt.prototype={moveTo:function(t,e){this._context.moveTo(e,t)},closePath:function(){this._context.closePath()},lineTo:function(t,e){this._context.lineTo(e,t)},bezierCurveTo:function(t,e,r,n,i,a){this._context.bezierCurveTo(e,t,n,r,a,i)}},Rt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=[],this._y=[]},lineEnd:function(){var t=this._x,e=this._y,r=t.length;if(r)if(this._line?this._context.lineTo(t[0],e[0]):this._context.moveTo(t[0],e[0]),2===r)this._context.lineTo(t[1],e[1]);else for(var n=Ft(t),i=Ft(e),a=0,o=1;o<r;++a,++o)this._context.bezierCurveTo(n[0][a],i[0][a],n[1][a],i[1][a],t[o],e[o]);(this._line||0!==this._line&&1===r)&&this._context.closePath(),this._line=1-this._line,this._x=this._y=null},point:function(t,e){this._x.push(+t),this._y.push(+e)}},Bt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=this._y=NaN,this._point=0},lineEnd:function(){0<this._t&&this._t<1&&2===this._point&&this._context.lineTo(this._x,this._y),(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line>=0&&(this._t=1-this._t,this._line=1-this._line)},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:if(this._t<=0)this._context.lineTo(this._x,e),this._context.lineTo(t,e);else{var r=this._x*(1-this._t)+t*this._t;this._context.lineTo(r,this._y),this._context.lineTo(r,e)}}this._x=t,this._y=e}},t.arc=function(){var t=g,o=v,_=r(0),w=null,k=m,T=y,A=x,M=null;function S(){var r,g,v,m=+t.apply(this,arguments),y=+o.apply(this,arguments),x=k.apply(this,arguments)-f,S=T.apply(this,arguments)-f,E=n(S-x),C=S>x;if(M||(M=r=e.path()),y<m&&(g=y,y=m,m=g),y>u)if(E>p-u)M.moveTo(y*a(x),y*l(x)),M.arc(0,0,y,x,S,!C),m>u&&(M.moveTo(m*a(S),m*l(S)),M.arc(0,0,m,S,x,C));else{var L,P,O=x,z=S,I=x,D=S,R=E,F=E,B=A.apply(this,arguments)/2,N=B>u&&(w?+w.apply(this,arguments):c(m*m+y*y)),j=s(n(y-m)/2,+_.apply(this,arguments)),U=j,V=j;if(N>u){var q=d(N/m*l(B)),H=d(N/y*l(B));(R-=2*q)>u?(I+=q*=C?1:-1,D-=q):(R=0,I=D=(x+S)/2),(F-=2*H)>u?(O+=H*=C?1:-1,z-=H):(F=0,O=z=(x+S)/2)}var G=y*a(O),Y=y*l(O),W=m*a(D),X=m*l(D);if(j>u){var Z,J=y*a(z),K=y*l(z),$=m*a(I),Q=m*l(I);if(E<h&&(Z=function(t,e,r,n,i,a,o,s){var l=r-t,c=n-e,h=o-i,f=s-a,p=f*l-h*c;if(!(p*p<u))return[t+(p=(h*(e-a)-f*(t-i))/p)*l,e+p*c]}(G,Y,$,Q,J,K,W,X))){var tt=G-Z[0],et=Y-Z[1],rt=J-Z[0],nt=K-Z[1],it=1/l(((v=(tt*rt+et*nt)/(c(tt*tt+et*et)*c(rt*rt+nt*nt)))>1?0:v<-1?h:Math.acos(v))/2),at=c(Z[0]*Z[0]+Z[1]*Z[1]);U=s(j,(m-at)/(it-1)),V=s(j,(y-at)/(it+1))}}F>u?V>u?(L=b($,Q,G,Y,y,V,C),P=b(J,K,W,X,y,V,C),M.moveTo(L.cx+L.x01,L.cy+L.y01),V<j?M.arc(L.cx,L.cy,V,i(L.y01,L.x01),i(P.y01,P.x01),!C):(M.arc(L.cx,L.cy,V,i(L.y01,L.x01),i(L.y11,L.x11),!C),M.arc(0,0,y,i(L.cy+L.y11,L.cx+L.x11),i(P.cy+P.y11,P.cx+P.x11),!C),M.arc(P.cx,P.cy,V,i(P.y11,P.x11),i(P.y01,P.x01),!C))):(M.moveTo(G,Y),M.arc(0,0,y,O,z,!C)):M.moveTo(G,Y),m>u&&R>u?U>u?(L=b(W,X,J,K,m,-U,C),P=b(G,Y,$,Q,m,-U,C),M.lineTo(L.cx+L.x01,L.cy+L.y01),U<j?M.arc(L.cx,L.cy,U,i(L.y01,L.x01),i(P.y01,P.x01),!C):(M.arc(L.cx,L.cy,U,i(L.y01,L.x01),i(L.y11,L.x11),!C),M.arc(0,0,m,i(L.cy+L.y11,L.cx+L.x11),i(P.cy+P.y11,P.cx+P.x11),C),M.arc(P.cx,P.cy,U,i(P.y11,P.x11),i(P.y01,P.x01),!C))):M.arc(0,0,m,D,I,C):M.lineTo(W,X)}else M.moveTo(0,0);if(M.closePath(),r)return M=null,r+\"\"||null}return S.centroid=function(){var e=(+t.apply(this,arguments)+ +o.apply(this,arguments))/2,r=(+k.apply(this,arguments)+ +T.apply(this,arguments))/2-h/2;return[a(r)*e,l(r)*e]},S.innerRadius=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),S):t},S.outerRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),S):o},S.cornerRadius=function(t){return arguments.length?(_=\"function\"==typeof t?t:r(+t),S):_},S.padRadius=function(t){return arguments.length?(w=null==t?null:\"function\"==typeof t?t:r(+t),S):w},S.startAngle=function(t){return arguments.length?(k=\"function\"==typeof t?t:r(+t),S):k},S.endAngle=function(t){return arguments.length?(T=\"function\"==typeof t?t:r(+t),S):T},S.padAngle=function(t){return arguments.length?(A=\"function\"==typeof t?t:r(+t),S):A},S.context=function(t){return arguments.length?(M=null==t?null:t,S):M},S},t.area=M,t.line=A,t.pie=function(){var t=E,e=S,n=null,i=r(0),a=r(p),o=r(0);function s(r){var s,l,c,u,h,f=r.length,d=0,g=new Array(f),v=new Array(f),m=+i.apply(this,arguments),y=Math.min(p,Math.max(-p,a.apply(this,arguments)-m)),x=Math.min(Math.abs(y)/f,o.apply(this,arguments)),b=x*(y<0?-1:1);for(s=0;s<f;++s)(h=v[g[s]=s]=+t(r[s],s,r))>0&&(d+=h);for(null!=e?g.sort(function(t,r){return e(v[t],v[r])}):null!=n&&g.sort(function(t,e){return n(r[t],r[e])}),s=0,c=d?(y-f*b)/d:0;s<f;++s,m=u)l=g[s],u=m+((h=v[l])>0?h*c:0)+b,v[l]={data:r[l],index:s,value:h,startAngle:m,endAngle:u,padAngle:x};return v}return s.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),s):t},s.sortValues=function(t){return arguments.length?(e=t,n=null,s):e},s.sort=function(t){return arguments.length?(n=t,e=null,s):n},s.startAngle=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),s):i},s.endAngle=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),s):a},s.padAngle=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),s):o},s},t.areaRadial=I,t.radialArea=I,t.lineRadial=z,t.radialLine=z,t.pointRadial=D,t.linkHorizontal=function(){return N(j)},t.linkVertical=function(){return N(U)},t.linkRadial=function(){var t=N(V);return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t},t.symbol=function(){var t=r(q),n=r(64),i=null;function a(){var r;if(i||(i=r=e.path()),t.apply(this,arguments).draw(i,+n.apply(this,arguments)),r)return i=null,r+\"\"||null}return a.type=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(e),a):t},a.size=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),a):n},a.context=function(t){return arguments.length?(i=null==t?null:t,a):i},a},t.symbols=ot,t.symbolCircle=q,t.symbolCross=H,t.symbolDiamond=W,t.symbolSquare=$,t.symbolStar=K,t.symbolTriangle=tt,t.symbolWye=at,t.curveBasisClosed=function(t){return new ut(t)},t.curveBasisOpen=function(t){return new ht(t)},t.curveBasis=function(t){return new ct(t)},t.curveBundle=pt,t.curveCardinalClosed=yt,t.curveCardinalOpen=bt,t.curveCardinal=vt,t.curveCatmullRomClosed=At,t.curveCatmullRomOpen=St,t.curveCatmullRom=kt,t.curveLinearClosed=function(t){return new Et(t)},t.curveLinear=w,t.curveMonotoneX=function(t){return new zt(t)},t.curveMonotoneY=function(t){return new It(t)},t.curveNatural=function(t){return new Rt(t)},t.curveStep=function(t){return new Bt(t,.5)},t.curveStepAfter=function(t){return new Bt(t,1)},t.curveStepBefore=function(t){return new Bt(t,0)},t.stack=function(){var t=r([]),e=jt,n=Nt,i=Ut;function a(r){var a,o,s=t.apply(this,arguments),l=r.length,c=s.length,u=new Array(c);for(a=0;a<c;++a){for(var h,f=s[a],p=u[a]=new Array(l),d=0;d<l;++d)p[d]=h=[0,+i(r[d],f,d,r)],h.data=r[d];p.key=f}for(a=0,o=e(u);a<c;++a)u[o[a]].index=a;return n(u,o),u}return a.keys=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(R.call(e)),a):t},a.value=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a):i},a.order=function(t){return arguments.length?(e=null==t?jt:\"function\"==typeof t?t:r(R.call(t)),a):e},a.offset=function(t){return arguments.length?(n=null==t?Nt:t,a):n},a},t.stackOffsetExpand=function(t,e){if((n=t.length)>0){for(var r,n,i,a=0,o=t[0].length;a<o;++a){for(i=r=0;r<n;++r)i+=t[r][a][1]||0;if(i)for(r=0;r<n;++r)t[r][a][1]/=i}Nt(t,e)}},t.stackOffsetDiverging=function(t,e){if((s=t.length)>1)for(var r,n,i,a,o,s,l=0,c=t[e[0]].length;l<c;++l)for(a=o=0,r=0;r<s;++r)(i=(n=t[e[r]][l])[1]-n[0])>=0?(n[0]=a,n[1]=a+=i):i<0?(n[1]=o,n[0]=o+=i):n[0]=a},t.stackOffsetNone=Nt,t.stackOffsetSilhouette=function(t,e){if((r=t.length)>0){for(var r,n=0,i=t[e[0]],a=i.length;n<a;++n){for(var o=0,s=0;o<r;++o)s+=t[o][n][1]||0;i[n][1]+=i[n][0]=-s/2}Nt(t,e)}},t.stackOffsetWiggle=function(t,e){if((i=t.length)>0&&(n=(r=t[e[0]]).length)>0){for(var r,n,i,a=0,o=1;o<n;++o){for(var s=0,l=0,c=0;s<i;++s){for(var u=t[e[s]],h=u[o][1]||0,f=(h-(u[o-1][1]||0))/2,p=0;p<s;++p){var d=t[e[p]];f+=(d[o][1]||0)-(d[o-1][1]||0)}l+=h,c+=f*h}r[o-1][1]+=r[o-1][0]=a,l&&(a-=c/l)}r[o-1][1]+=r[o-1][0]=a,Nt(t,e)}},t.stackOrderAppearance=Vt,t.stackOrderAscending=Ht,t.stackOrderDescending=function(t){return Ht(t).reverse()},t.stackOrderInsideOut=function(t){var e,r,n=t.length,i=t.map(Gt),a=Vt(t),o=0,s=0,l=[],c=[];for(e=0;e<n;++e)r=a[e],o<s?(o+=i[r],l.push(r)):(s+=i[r],c.push(r));return c.reverse().concat(l)},t.stackOrderNone=jt,t.stackOrderReverse=function(t){return jt(t).reverse()},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-path\")):i(n.d3=n.d3||{},n.d3)},{\"d3-path\":159}],162:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e,r,n=0,i=0,a=0,o=1e3,s=0,l=0,c=0,u=\"object\"==typeof performance&&performance.now?performance:Date,h=\"object\"==typeof window&&window.requestAnimationFrame?window.requestAnimationFrame.bind(window):function(t){setTimeout(t,17)};function f(){return l||(h(p),l=u.now()+c)}function p(){l=0}function d(){this._call=this._time=this._next=null}function g(t,e,r){var n=new d;return n.restart(t,e,r),n}function v(){f(),++n;for(var t,r=e;r;)(t=l-r._time)>=0&&r._call.call(null,t),r=r._next;--n}function m(){l=(s=u.now())+c,n=i=0;try{v()}finally{n=0,function(){var t,n,i=e,a=1/0;for(;i;)i._call?(a>i._time&&(a=i._time),t=i,i=i._next):(n=i._next,i._next=null,i=t?t._next=n:e=n);r=t,x(a)}(),l=0}}function y(){var t=u.now(),e=t-s;e>o&&(c-=e,s=t)}function x(t){n||(i&&(i=clearTimeout(i)),t-l>24?(t<1/0&&(i=setTimeout(m,t-u.now()-c)),a&&(a=clearInterval(a))):(a||(s=u.now(),a=setInterval(y,o)),n=1,h(m)))}d.prototype=g.prototype={constructor:d,restart:function(t,n,i){if(\"function\"!=typeof t)throw new TypeError(\"callback is not a function\");i=(null==i?f():+i)+(null==n?0:+n),this._next||r===this||(r?r._next=this:e=this,r=this),this._call=t,this._time=i,x()},stop:function(){this._call&&(this._call=null,this._time=1/0,x())}};t.now=f,t.timer=g,t.timerFlush=v,t.timeout=function(t,e,r){var n=new d;return e=null==e?0:+e,n.restart(function(r){n.stop(),t(r+e)},e,r),n},t.interval=function(t,e,r){var n=new d,i=e;return null==e?(n.restart(t,e,r),n):(e=+e,r=null==r?f():+r,n.restart(function a(o){o+=i,n.restart(a,i+=e,r),t(o)},e,r),n)},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],163:[function(t,e,r){!function(){var t={version:\"3.5.17\"},r=[].slice,n=function(t){return r.call(t)},i=this.document;function a(t){return t&&(t.ownerDocument||t.document||t).documentElement}function o(t){return t&&(t.ownerDocument&&t.ownerDocument.defaultView||t.document&&t||t.defaultView)}if(i)try{n(i.documentElement.childNodes)[0].nodeType}catch(t){n=function(t){for(var e=t.length,r=new Array(e);e--;)r[e]=t[e];return r}}if(Date.now||(Date.now=function(){return+new Date}),i)try{i.createElement(\"DIV\").style.setProperty(\"opacity\",0,\"\")}catch(t){var s=this.Element.prototype,l=s.setAttribute,c=s.setAttributeNS,u=this.CSSStyleDeclaration.prototype,h=u.setProperty;s.setAttribute=function(t,e){l.call(this,t,e+\"\")},s.setAttributeNS=function(t,e,r){c.call(this,t,e,r+\"\")},u.setProperty=function(t,e,r){h.call(this,t,e+\"\",r)}}function f(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function p(t){return null===t?NaN:+t}function d(t){return!isNaN(t)}function g(t){return{left:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}t.ascending=f,t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.min=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&r>n&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&r>n&&(r=n)}return r},t.max=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&n>r&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&n>r&&(r=n)}return r},t.extent=function(t,e){var r,n,i,a=-1,o=t.length;if(1===arguments.length){for(;++a<o;)if(null!=(n=t[a])&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=t[a])&&(r>n&&(r=n),i<n&&(i=n))}else{for(;++a<o;)if(null!=(n=e.call(t,t[a],a))&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=e.call(t,t[a],a))&&(r>n&&(r=n),i<n&&(i=n))}return[r,i]},t.sum=function(t,e){var r,n=0,i=t.length,a=-1;if(1===arguments.length)for(;++a<i;)d(r=+t[a])&&(n+=r);else for(;++a<i;)d(r=+e.call(t,t[a],a))&&(n+=r);return n},t.mean=function(t,e){var r,n=0,i=t.length,a=-1,o=i;if(1===arguments.length)for(;++a<i;)d(r=p(t[a]))?n+=r:--o;else for(;++a<i;)d(r=p(e.call(t,t[a],a)))?n+=r:--o;if(o)return n/o},t.quantile=function(t,e){var r=(t.length-1)*e+1,n=Math.floor(r),i=+t[n-1],a=r-n;return a?i+a*(t[n]-i):i},t.median=function(e,r){var n,i=[],a=e.length,o=-1;if(1===arguments.length)for(;++o<a;)d(n=p(e[o]))&&i.push(n);else for(;++o<a;)d(n=p(r.call(e,e[o],o)))&&i.push(n);if(i.length)return t.quantile(i.sort(f),.5)},t.variance=function(t,e){var r,n,i=t.length,a=0,o=0,s=-1,l=0;if(1===arguments.length)for(;++s<i;)d(r=p(t[s]))&&(o+=(n=r-a)*(r-(a+=n/++l)));else for(;++s<i;)d(r=p(e.call(t,t[s],s)))&&(o+=(n=r-a)*(r-(a+=n/++l)));if(l>1)return o/(l-1)},t.deviation=function(){var e=t.variance.apply(this,arguments);return e?Math.sqrt(e):e};var v=g(f);function m(t){return t.length}t.bisectLeft=v.left,t.bisect=t.bisectRight=v.right,t.bisector=function(t){return g(1===t.length?function(e,r){return f(t(e),r)}:t)},t.shuffle=function(t,e,r){(a=arguments.length)<3&&(r=t.length,a<2&&(e=0));for(var n,i,a=r-e;a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.pairs=function(t){for(var e=0,r=t.length-1,n=t[0],i=new Array(r<0?0:r);e<r;)i[e]=[n,n=t[++e]];return i},t.transpose=function(e){if(!(a=e.length))return[];for(var r=-1,n=t.min(e,m),i=new Array(n);++r<n;)for(var a,o=-1,s=i[r]=new Array(a);++o<a;)s[o]=e[o][r];return i},t.zip=function(){return t.transpose(arguments)},t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r};var y=Math.abs;function x(t,e){for(var r in e)Object.defineProperty(t.prototype,r,{value:e[r],enumerable:!1})}function b(){this._=Object.create(null)}t.range=function(t,e,r){if(arguments.length<3&&(r=1,arguments.length<2&&(e=t,t=0)),(e-t)/r==1/0)throw new Error(\"infinite range\");var n,i=[],a=function(t){var e=1;for(;t*e%1;)e*=10;return e}(y(r)),o=-1;if(t*=a,e*=a,(r*=a)<0)for(;(n=t+r*++o)>e;)i.push(n/a);else for(;(n=t+r*++o)<e;)i.push(n/a);return i},t.map=function(t,e){var r=new b;if(t instanceof b)t.forEach(function(t,e){r.set(t,e)});else if(Array.isArray(t)){var n,i=-1,a=t.length;if(1===arguments.length)for(;++i<a;)r.set(i,t[i]);else for(;++i<a;)r.set(e.call(t,n=t[i],i),n)}else for(var o in t)r.set(o,t[o]);return r};var _=\"__proto__\",w=\"\\0\";function k(t){return(t+=\"\")===_||t[0]===w?w+t:t}function T(t){return(t+=\"\")[0]===w?t.slice(1):t}function A(t){return k(t)in this._}function M(t){return(t=k(t))in this._&&delete this._[t]}function S(){var t=[];for(var e in this._)t.push(T(e));return t}function E(){var t=0;for(var e in this._)++t;return t}function C(){for(var t in this._)return!1;return!0}function L(){this._=Object.create(null)}function P(t){return t}function O(t,e,r){return function(){var n=r.apply(e,arguments);return n===e?t:n}}function z(t,e){if(e in t)return e;e=e.charAt(0).toUpperCase()+e.slice(1);for(var r=0,n=I.length;r<n;++r){var i=I[r]+e;if(i in t)return i}}x(b,{has:A,get:function(t){return this._[k(t)]},set:function(t,e){return this._[k(t)]=e},remove:M,keys:S,values:function(){var t=[];for(var e in this._)t.push(this._[e]);return t},entries:function(){var t=[];for(var e in this._)t.push({key:T(e),value:this._[e]});return t},size:E,empty:C,forEach:function(t){for(var e in this._)t.call(this,T(e),this._[e])}}),t.nest=function(){var e,r,n={},i=[],a=[];function o(t,a,s){if(s>=i.length)return r?r.call(n,a):e?a.sort(e):a;for(var l,c,u,h,f=-1,p=a.length,d=i[s++],g=new b;++f<p;)(h=g.get(l=d(c=a[f])))?h.push(c):g.set(l,[c]);return t?(c=t(),u=function(e,r){c.set(e,o(t,r,s))}):(c={},u=function(e,r){c[e]=o(t,r,s)}),g.forEach(u),c}return n.map=function(t,e){return o(e,t,0)},n.entries=function(e){return function t(e,r){if(r>=i.length)return e;var n=[],o=a[r++];return e.forEach(function(e,i){n.push({key:e,values:t(i,r)})}),o?n.sort(function(t,e){return o(t.key,e.key)}):n}(o(t.map,e,0),0)},n.key=function(t){return i.push(t),n},n.sortKeys=function(t){return a[i.length-1]=t,n},n.sortValues=function(t){return e=t,n},n.rollup=function(t){return r=t,n},n},t.set=function(t){var e=new L;if(t)for(var r=0,n=t.length;r<n;++r)e.add(t[r]);return e},x(L,{has:A,add:function(t){return this._[k(t+=\"\")]=!0,t},remove:M,values:S,size:E,empty:C,forEach:function(t){for(var e in this._)t.call(this,T(e))}}),t.behavior={},t.rebind=function(t,e){for(var r,n=1,i=arguments.length;++n<i;)t[r=arguments[n]]=O(t,e,e[r]);return t};var I=[\"webkit\",\"ms\",\"moz\",\"Moz\",\"o\",\"O\"];function D(){}function R(){}function F(t){var e=[],r=new b;function n(){for(var r,n=e,i=-1,a=n.length;++i<a;)(r=n[i].on)&&r.apply(this,arguments);return t}return n.on=function(n,i){var a,o=r.get(n);return arguments.length<2?o&&o.on:(o&&(o.on=null,e=e.slice(0,a=e.indexOf(o)).concat(e.slice(a+1)),r.remove(n)),i&&e.push(r.set(n,{on:i})),t)},n}function B(){t.event.preventDefault()}function N(){for(var e,r=t.event;e=r.sourceEvent;)r=e;return r}function j(e){for(var r=new R,n=0,i=arguments.length;++n<i;)r[arguments[n]]=F(r);return r.of=function(n,i){return function(a){try{var o=a.sourceEvent=t.event;a.target=e,t.event=a,r[a.type].apply(n,i)}finally{t.event=o}}},r}t.dispatch=function(){for(var t=new R,e=-1,r=arguments.length;++e<r;)t[arguments[e]]=F(t);return t},R.prototype.on=function(t,e){var r=t.indexOf(\".\"),n=\"\";if(r>=0&&(n=t.slice(r+1),t=t.slice(0,r)),t)return arguments.length<2?this[t].on(n):this[t].on(n,e);if(2===arguments.length){if(null==e)for(t in this)this.hasOwnProperty(t)&&this[t].on(n,null);return this}},t.event=null,t.requote=function(t){return t.replace(U,\"\\\\$&\")};var U=/[\\\\\\^\\$\\*\\+\\?\\|\\[\\]\\(\\)\\.\\{\\}]/g,V={}.__proto__?function(t,e){t.__proto__=e}:function(t,e){for(var r in e)t[r]=e[r]};function q(t){return V(t,W),t}var H=function(t,e){return e.querySelector(t)},G=function(t,e){return e.querySelectorAll(t)},Y=function(t,e){var r=t.matches||t[z(t,\"matchesSelector\")];return(Y=function(t,e){return r.call(t,e)})(t,e)};\"function\"==typeof Sizzle&&(H=function(t,e){return Sizzle(t,e)[0]||null},G=Sizzle,Y=Sizzle.matchesSelector),t.selection=function(){return t.select(i.documentElement)};var W=t.selection.prototype=[];function X(t){return\"function\"==typeof t?t:function(){return H(t,this)}}function Z(t){return\"function\"==typeof t?t:function(){return G(t,this)}}W.select=function(t){var e,r,n,i,a=[];t=X(t);for(var o=-1,s=this.length;++o<s;){a.push(e=[]),e.parentNode=(n=this[o]).parentNode;for(var l=-1,c=n.length;++l<c;)(i=n[l])?(e.push(r=t.call(i,i.__data__,l,o)),r&&\"__data__\"in i&&(r.__data__=i.__data__)):e.push(null)}return q(a)},W.selectAll=function(t){var e,r,i=[];t=Z(t);for(var a=-1,o=this.length;++a<o;)for(var s=this[a],l=-1,c=s.length;++l<c;)(r=s[l])&&(i.push(e=n(t.call(r,r.__data__,l,a))),e.parentNode=r);return q(i)};var J=\"http://www.w3.org/1999/xhtml\",K={svg:\"http://www.w3.org/2000/svg\",xhtml:J,xlink:\"http://www.w3.org/1999/xlink\",xml:\"http://www.w3.org/XML/1998/namespace\",xmlns:\"http://www.w3.org/2000/xmlns/\"};function $(e,r){return e=t.ns.qualify(e),null==r?e.local?function(){this.removeAttributeNS(e.space,e.local)}:function(){this.removeAttribute(e)}:\"function\"==typeof r?e.local?function(){var t=r.apply(this,arguments);null==t?this.removeAttributeNS(e.space,e.local):this.setAttributeNS(e.space,e.local,t)}:function(){var t=r.apply(this,arguments);null==t?this.removeAttribute(e):this.setAttribute(e,t)}:e.local?function(){this.setAttributeNS(e.space,e.local,r)}:function(){this.setAttribute(e,r)}}function Q(t){return t.trim().replace(/\\s+/g,\" \")}function tt(e){return new RegExp(\"(?:^|\\\\s+)\"+t.requote(e)+\"(?:\\\\s+|$)\",\"g\")}function et(t){return(t+\"\").trim().split(/^|\\s+/)}function rt(t,e){var r=(t=et(t).map(nt)).length;return\"function\"==typeof e?function(){for(var n=-1,i=e.apply(this,arguments);++n<r;)t[n](this,i)}:function(){for(var n=-1;++n<r;)t[n](this,e)}}function nt(t){var e=tt(t);return function(r,n){if(i=r.classList)return n?i.add(t):i.remove(t);var i=r.getAttribute(\"class\")||\"\";n?(e.lastIndex=0,e.test(i)||r.setAttribute(\"class\",Q(i+\" \"+t))):r.setAttribute(\"class\",Q(i.replace(e,\" \")))}}function it(t,e,r){return null==e?function(){this.style.removeProperty(t)}:\"function\"==typeof e?function(){var n=e.apply(this,arguments);null==n?this.style.removeProperty(t):this.style.setProperty(t,n,r)}:function(){this.style.setProperty(t,e,r)}}function at(t,e){return null==e?function(){delete this[t]}:\"function\"==typeof e?function(){var r=e.apply(this,arguments);null==r?delete this[t]:this[t]=r}:function(){this[t]=e}}function ot(e){return\"function\"==typeof e?e:(e=t.ns.qualify(e)).local?function(){return this.ownerDocument.createElementNS(e.space,e.local)}:function(){var t=this.ownerDocument,r=this.namespaceURI;return r===J&&t.documentElement.namespaceURI===J?t.createElement(e):t.createElementNS(r,e)}}function st(){var t=this.parentNode;t&&t.removeChild(this)}function lt(t){return{__data__:t}}function ct(t){return function(){return Y(this,t)}}function ut(t,e){for(var r=0,n=t.length;r<n;r++)for(var i,a=t[r],o=0,s=a.length;o<s;o++)(i=a[o])&&e(i,o,r);return t}function ht(t){return V(t,ft),t}t.ns={prefix:K,qualify:function(t){var e=t.indexOf(\":\"),r=t;return e>=0&&\"xmlns\"!==(r=t.slice(0,e))&&(t=t.slice(e+1)),K.hasOwnProperty(r)?{space:K[r],local:t}:t}},W.attr=function(e,r){if(arguments.length<2){if(\"string\"==typeof e){var n=this.node();return(e=t.ns.qualify(e)).local?n.getAttributeNS(e.space,e.local):n.getAttribute(e)}for(r in e)this.each($(r,e[r]));return this}return this.each($(e,r))},W.classed=function(t,e){if(arguments.length<2){if(\"string\"==typeof t){var r=this.node(),n=(t=et(t)).length,i=-1;if(e=r.classList){for(;++i<n;)if(!e.contains(t[i]))return!1}else for(e=r.getAttribute(\"class\");++i<n;)if(!tt(t[i]).test(e))return!1;return!0}for(e in t)this.each(rt(e,t[e]));return this}return this.each(rt(t,e))},W.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.each(it(r,t[r],e));return this}if(n<2){var i=this.node();return o(i).getComputedStyle(i,null).getPropertyValue(t)}r=\"\"}return this.each(it(t,e,r))},W.property=function(t,e){if(arguments.length<2){if(\"string\"==typeof t)return this.node()[t];for(e in t)this.each(at(e,t[e]));return this}return this.each(at(t,e))},W.text=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.textContent=null==e?\"\":e}:null==t?function(){this.textContent=\"\"}:function(){this.textContent=t}):this.node().textContent},W.html=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.innerHTML=null==e?\"\":e}:null==t?function(){this.innerHTML=\"\"}:function(){this.innerHTML=t}):this.node().innerHTML},W.append=function(t){return t=ot(t),this.select(function(){return this.appendChild(t.apply(this,arguments))})},W.insert=function(t,e){return t=ot(t),e=X(e),this.select(function(){return this.insertBefore(t.apply(this,arguments),e.apply(this,arguments)||null)})},W.remove=function(){return this.each(st)},W.data=function(t,e){var r,n,i=-1,a=this.length;if(!arguments.length){for(t=new Array(a=(r=this[0]).length);++i<a;)(n=r[i])&&(t[i]=n.__data__);return t}function o(t,r){var n,i,a,o=t.length,u=r.length,h=Math.min(o,u),f=new Array(u),p=new Array(u),d=new Array(o);if(e){var g,v=new b,m=new Array(o);for(n=-1;++n<o;)(i=t[n])&&(v.has(g=e.call(i,i.__data__,n))?d[n]=i:v.set(g,i),m[n]=g);for(n=-1;++n<u;)(i=v.get(g=e.call(r,a=r[n],n)))?!0!==i&&(f[n]=i,i.__data__=a):p[n]=lt(a),v.set(g,!0);for(n=-1;++n<o;)n in m&&!0!==v.get(m[n])&&(d[n]=t[n])}else{for(n=-1;++n<h;)i=t[n],a=r[n],i?(i.__data__=a,f[n]=i):p[n]=lt(a);for(;n<u;++n)p[n]=lt(r[n]);for(;n<o;++n)d[n]=t[n]}p.update=f,p.parentNode=f.parentNode=d.parentNode=t.parentNode,s.push(p),l.push(f),c.push(d)}var s=ht([]),l=q([]),c=q([]);if(\"function\"==typeof t)for(;++i<a;)o(r=this[i],t.call(r,r.parentNode.__data__,i));else for(;++i<a;)o(r=this[i],t);return l.enter=function(){return s},l.exit=function(){return c},l},W.datum=function(t){return arguments.length?this.property(\"__data__\",t):this.property(\"__data__\")},W.filter=function(t){var e,r,n,i=[];\"function\"!=typeof t&&(t=ct(t));for(var a=0,o=this.length;a<o;a++){i.push(e=[]),e.parentNode=(r=this[a]).parentNode;for(var s=0,l=r.length;s<l;s++)(n=r[s])&&t.call(n,n.__data__,s,a)&&e.push(n)}return q(i)},W.order=function(){for(var t=-1,e=this.length;++t<e;)for(var r,n=this[t],i=n.length-1,a=n[i];--i>=0;)(r=n[i])&&(a&&a!==r.nextSibling&&a.parentNode.insertBefore(r,a),a=r);return this},W.sort=function(t){t=function(t){arguments.length||(t=f);return function(e,r){return e&&r?t(e.__data__,r.__data__):!e-!r}}.apply(this,arguments);for(var e=-1,r=this.length;++e<r;)this[e].sort(t);return this.order()},W.each=function(t){return ut(this,function(e,r,n){t.call(e,e.__data__,r,n)})},W.call=function(t){var e=n(arguments);return t.apply(e[0]=this,e),this},W.empty=function(){return!this.node()},W.node=function(){for(var t=0,e=this.length;t<e;t++)for(var r=this[t],n=0,i=r.length;n<i;n++){var a=r[n];if(a)return a}return null},W.size=function(){var t=0;return ut(this,function(){++t}),t};var ft=[];function pt(e,r,i){var a=\"__on\"+e,o=e.indexOf(\".\"),s=gt;o>0&&(e=e.slice(0,o));var l=dt.get(e);function c(){var t=this[a];t&&(this.removeEventListener(e,t,t.$),delete this[a])}return l&&(e=l,s=vt),o?r?function(){var t=s(r,n(arguments));c.call(this),this.addEventListener(e,this[a]=t,t.$=i),t._=r}:c:r?D:function(){var r,n=new RegExp(\"^__on([^.]+)\"+t.requote(e)+\"$\");for(var i in this)if(r=i.match(n)){var a=this[i];this.removeEventListener(r[1],a,a.$),delete this[i]}}}t.selection.enter=ht,t.selection.enter.prototype=ft,ft.append=W.append,ft.empty=W.empty,ft.node=W.node,ft.call=W.call,ft.size=W.size,ft.select=function(t){for(var e,r,n,i,a,o=[],s=-1,l=this.length;++s<l;){n=(i=this[s]).update,o.push(e=[]),e.parentNode=i.parentNode;for(var c=-1,u=i.length;++c<u;)(a=i[c])?(e.push(n[c]=r=t.call(i.parentNode,a.__data__,c,s)),r.__data__=a.__data__):e.push(null)}return q(o)},ft.insert=function(t,e){var r,n,i;return arguments.length<2&&(r=this,e=function(t,e,a){var o,s=r[a].update,l=s.length;for(a!=i&&(i=a,n=0),e>=n&&(n=e+1);!(o=s[n])&&++n<l;);return o}),W.insert.call(this,t,e)},t.select=function(t){var e;return\"string\"==typeof t?(e=[H(t,i)]).parentNode=i.documentElement:(e=[t]).parentNode=a(t),q([e])},t.selectAll=function(t){var e;return\"string\"==typeof t?(e=n(G(t,i))).parentNode=i.documentElement:(e=n(t)).parentNode=null,q([e])},W.on=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=!1),t)this.each(pt(r,t[r],e));return this}if(n<2)return(n=this.node()[\"__on\"+t])&&n._;r=!1}return this.each(pt(t,e,r))};var dt=t.map({mouseenter:\"mouseover\",mouseleave:\"mouseout\"});function gt(e,r){return function(n){var i=t.event;t.event=n,r[0]=this.__data__;try{e.apply(this,r)}finally{t.event=i}}}function vt(t,e){var r=gt(t,e);return function(t){var e=t.relatedTarget;e&&(e===this||8&e.compareDocumentPosition(this))||r.call(this,t)}}i&&dt.forEach(function(t){\"on\"+t in i&&dt.remove(t)});var mt,yt=0;function xt(e){var r=\".dragsuppress-\"+ ++yt,n=\"click\"+r,i=t.select(o(e)).on(\"touchmove\"+r,B).on(\"dragstart\"+r,B).on(\"selectstart\"+r,B);if(null==mt&&(mt=!(\"onselectstart\"in e)&&z(e.style,\"userSelect\")),mt){var s=a(e).style,l=s[mt];s[mt]=\"none\"}return function(t){if(i.on(r,null),mt&&(s[mt]=l),t){var e=function(){i.on(n,null)};i.on(n,function(){B(),e()},!0),setTimeout(e,0)}}}t.mouse=function(t){return _t(t,N())};var bt=this.navigator&&/WebKit/.test(this.navigator.userAgent)?-1:0;function _t(e,r){r.changedTouches&&(r=r.changedTouches[0]);var n=e.ownerSVGElement||e;if(n.createSVGPoint){var i=n.createSVGPoint();if(bt<0){var a=o(e);if(a.scrollX||a.scrollY){var s=(n=t.select(\"body\").append(\"svg\").style({position:\"absolute\",top:0,left:0,margin:0,padding:0,border:\"none\"},\"important\"))[0][0].getScreenCTM();bt=!(s.f||s.e),n.remove()}}return bt?(i.x=r.pageX,i.y=r.pageY):(i.x=r.clientX,i.y=r.clientY),[(i=i.matrixTransform(e.getScreenCTM().inverse())).x,i.y]}var l=e.getBoundingClientRect();return[r.clientX-l.left-e.clientLeft,r.clientY-l.top-e.clientTop]}function wt(){return t.event.changedTouches[0].identifier}t.touch=function(t,e,r){if(arguments.length<3&&(r=e,e=N().changedTouches),e)for(var n,i=0,a=e.length;i<a;++i)if((n=e[i]).identifier===r)return _t(t,n)},t.behavior.drag=function(){var e=j(a,\"drag\",\"dragstart\",\"dragend\"),r=null,n=s(D,t.mouse,o,\"mousemove\",\"mouseup\"),i=s(wt,t.touch,P,\"touchmove\",\"touchend\");function a(){this.on(\"mousedown.drag\",n).on(\"touchstart.drag\",i)}function s(n,i,a,o,s){return function(){var l,c=t.event.target.correspondingElement||t.event.target,u=this.parentNode,h=e.of(this,arguments),f=0,p=n(),d=\".drag\"+(null==p?\"\":\"-\"+p),g=t.select(a(c)).on(o+d,function(){var t,e,r=i(u,p);if(!r)return;t=r[0]-m[0],e=r[1]-m[1],f|=t|e,m=r,h({type:\"drag\",x:r[0]+l[0],y:r[1]+l[1],dx:t,dy:e})}).on(s+d,function(){if(!i(u,p))return;g.on(o+d,null).on(s+d,null),v(f),h({type:\"dragend\"})}),v=xt(c),m=i(u,p);l=r?[(l=r.apply(this,arguments)).x-m[0],l.y-m[1]]:[0,0],h({type:\"dragstart\"})}}return a.origin=function(t){return arguments.length?(r=t,a):r},t.rebind(a,e,\"on\")},t.touches=function(t,e){return arguments.length<2&&(e=N().touches),e?n(e).map(function(e){var r=_t(t,e);return r.identifier=e.identifier,r}):[]};var kt=1e-6,Tt=kt*kt,At=Math.PI,Mt=2*At,St=Mt-kt,Et=At/2,Ct=At/180,Lt=180/At;function Pt(t){return t>0?1:t<0?-1:0}function Ot(t,e,r){return(e[0]-t[0])*(r[1]-t[1])-(e[1]-t[1])*(r[0]-t[0])}function zt(t){return t>1?0:t<-1?At:Math.acos(t)}function It(t){return t>1?Et:t<-1?-Et:Math.asin(t)}function Dt(t){return((t=Math.exp(t))+1/t)/2}function Rt(t){return(t=Math.sin(t/2))*t}var Ft=Math.SQRT2;t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,h=l-a,f=u*u+h*h;if(f<Tt)n=Math.log(c/o)/Ft,r=function(t){return[i+t*u,a+t*h,o*Math.exp(Ft*t*n)]};else{var p=Math.sqrt(f),d=(c*c-o*o+4*f)/(2*o*2*p),g=(c*c-o*o-4*f)/(2*c*2*p),v=Math.log(Math.sqrt(d*d+1)-d),m=Math.log(Math.sqrt(g*g+1)-g);n=(m-v)/Ft,r=function(t){var e,r=t*n,s=Dt(v),l=o/(2*p)*(s*(e=Ft*r+v,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(v));return[i+l*u,a+l*h,o*s/Dt(Ft*r+v)]}}return r.duration=1e3*n,r},t.behavior.zoom=function(){var e,r,n,a,s,l,c,u,h,f={x:0,y:0,k:1},p=[960,500],d=jt,g=250,v=0,m=\"mousedown.zoom\",y=\"mousemove.zoom\",x=\"mouseup.zoom\",b=\"touchstart.zoom\",_=j(w,\"zoomstart\",\"zoom\",\"zoomend\");function w(t){t.on(m,P).on(Nt+\".zoom\",z).on(\"dblclick.zoom\",I).on(b,O)}function k(t){return[(t[0]-f.x)/f.k,(t[1]-f.y)/f.k]}function T(t){f.k=Math.max(d[0],Math.min(d[1],t))}function A(t,e){e=function(t){return[t[0]*f.k+f.x,t[1]*f.k+f.y]}(e),f.x+=t[0]-e[0],f.y+=t[1]-e[1]}function M(e,n,i,a){e.__chart__={x:f.x,y:f.y,k:f.k},T(Math.pow(2,a)),A(r=n,i),e=t.select(e),g>0&&(e=e.transition().duration(g)),e.call(w.event)}function S(){c&&c.domain(l.range().map(function(t){return(t-f.x)/f.k}).map(l.invert)),h&&h.domain(u.range().map(function(t){return(t-f.y)/f.k}).map(u.invert))}function E(t){v++||t({type:\"zoomstart\"})}function C(t){S(),t({type:\"zoom\",scale:f.k,translate:[f.x,f.y]})}function L(t){--v||(t({type:\"zoomend\"}),r=null)}function P(){var e=this,r=_.of(e,arguments),n=0,i=t.select(o(e)).on(y,function(){n=1,A(t.mouse(e),a),C(r)}).on(x,function(){i.on(y,null).on(x,null),s(n),L(r)}),a=k(t.mouse(e)),s=xt(e);hs.call(e),E(r)}function O(){var e,r=this,n=_.of(r,arguments),i={},a=0,o=\".zoom-\"+t.event.changedTouches[0].identifier,l=\"touchmove\"+o,c=\"touchend\"+o,u=[],h=t.select(r),p=xt(r);function d(){var n=t.touches(r);return e=f.k,n.forEach(function(t){t.identifier in i&&(i[t.identifier]=k(t))}),n}function g(){var e=t.event.target;t.select(e).on(l,v).on(c,y),u.push(e);for(var n=t.event.changedTouches,o=0,h=n.length;o<h;++o)i[n[o].identifier]=null;var p=d(),g=Date.now();if(1===p.length){if(g-s<500){var m=p[0];M(r,m,i[m.identifier],Math.floor(Math.log(f.k)/Math.LN2)+1),B()}s=g}else if(p.length>1){m=p[0];var x=p[1],b=m[0]-x[0],_=m[1]-x[1];a=b*b+_*_}}function v(){var o,l,c,u,h=t.touches(r);hs.call(r);for(var f=0,p=h.length;f<p;++f,u=null)if(c=h[f],u=i[c.identifier]){if(l)break;o=c,l=u}if(u){var d=(d=c[0]-o[0])*d+(d=c[1]-o[1])*d,g=a&&Math.sqrt(d/a);o=[(o[0]+c[0])/2,(o[1]+c[1])/2],l=[(l[0]+u[0])/2,(l[1]+u[1])/2],T(g*e)}s=null,A(o,l),C(n)}function y(){if(t.event.touches.length){for(var e=t.event.changedTouches,r=0,a=e.length;r<a;++r)delete i[e[r].identifier];for(var s in i)return void d()}t.selectAll(u).on(o,null),h.on(m,P).on(b,O),p(),L(n)}g(),E(n),h.on(m,null).on(b,g)}function z(){var i=_.of(this,arguments);a?clearTimeout(a):(hs.call(this),e=k(r=n||t.mouse(this)),E(i)),a=setTimeout(function(){a=null,L(i)},50),B(),T(Math.pow(2,.002*Bt())*f.k),A(r,e),C(i)}function I(){var e=t.mouse(this),r=Math.log(f.k)/Math.LN2;M(this,e,k(e),t.event.shiftKey?Math.ceil(r)-1:Math.floor(r)+1)}return Nt||(Nt=\"onwheel\"in i?(Bt=function(){return-t.event.deltaY*(t.event.deltaMode?120:1)},\"wheel\"):\"onmousewheel\"in i?(Bt=function(){return t.event.wheelDelta},\"mousewheel\"):(Bt=function(){return-t.event.detail},\"MozMousePixelScroll\")),w.event=function(e){e.each(function(){var e=_.of(this,arguments),n=f;ds?t.select(this).transition().each(\"start.zoom\",function(){f=this.__chart__||{x:0,y:0,k:1},E(e)}).tween(\"zoom:zoom\",function(){var i=p[0],a=p[1],o=r?r[0]:i/2,s=r?r[1]:a/2,l=t.interpolateZoom([(o-f.x)/f.k,(s-f.y)/f.k,i/f.k],[(o-n.x)/n.k,(s-n.y)/n.k,i/n.k]);return function(t){var r=l(t),n=i/r[2];this.__chart__=f={x:o-r[0]*n,y:s-r[1]*n,k:n},C(e)}}).each(\"interrupt.zoom\",function(){L(e)}).each(\"end.zoom\",function(){L(e)}):(this.__chart__=f,E(e),C(e),L(e))})},w.translate=function(t){return arguments.length?(f={x:+t[0],y:+t[1],k:f.k},S(),w):[f.x,f.y]},w.scale=function(t){return arguments.length?(f={x:f.x,y:f.y,k:null},T(+t),S(),w):f.k},w.scaleExtent=function(t){return arguments.length?(d=null==t?jt:[+t[0],+t[1]],w):d},w.center=function(t){return arguments.length?(n=t&&[+t[0],+t[1]],w):n},w.size=function(t){return arguments.length?(p=t&&[+t[0],+t[1]],w):p},w.duration=function(t){return arguments.length?(g=+t,w):g},w.x=function(t){return arguments.length?(c=t,l=t.copy(),f={x:0,y:0,k:1},w):c},w.y=function(t){return arguments.length?(h=t,u=t.copy(),f={x:0,y:0,k:1},w):h},t.rebind(w,_,\"on\")};var Bt,Nt,jt=[0,1/0];function Ut(){}function Vt(t,e,r){return this instanceof Vt?(this.h=+t,this.s=+e,void(this.l=+r)):arguments.length<2?t instanceof Vt?new Vt(t.h,t.s,t.l):ue(\"\"+t,he,Vt):new Vt(t,e,r)}t.color=Ut,Ut.prototype.toString=function(){return this.rgb()+\"\"},t.hsl=Vt;var qt=Vt.prototype=new Ut;function Ht(t,e,r){var n,i;function a(t){return Math.round(255*function(t){return t>360?t-=360:t<0&&(t+=360),t<60?n+(i-n)*t/60:t<180?i:t<240?n+(i-n)*(240-t)/60:n}(t))}return t=isNaN(t)?0:(t%=360)<0?t+360:t,e=isNaN(e)?0:e<0?0:e>1?1:e,n=2*(r=r<0?0:r>1?1:r)-(i=r<=.5?r*(1+e):r+e-r*e),new ae(a(t+120),a(t),a(t-120))}function Gt(e,r,n){return this instanceof Gt?(this.h=+e,this.c=+r,void(this.l=+n)):arguments.length<2?e instanceof Gt?new Gt(e.h,e.c,e.l):ee(e instanceof Xt?e.l:(e=fe((e=t.rgb(e)).r,e.g,e.b)).l,e.a,e.b):new Gt(e,r,n)}qt.brighter=function(t){return t=Math.pow(.7,arguments.length?t:1),new Vt(this.h,this.s,this.l/t)},qt.darker=function(t){return t=Math.pow(.7,arguments.length?t:1),new Vt(this.h,this.s,t*this.l)},qt.rgb=function(){return Ht(this.h,this.s,this.l)},t.hcl=Gt;var Yt=Gt.prototype=new Ut;function Wt(t,e,r){return isNaN(t)&&(t=0),isNaN(e)&&(e=0),new Xt(r,Math.cos(t*=Ct)*e,Math.sin(t)*e)}function Xt(t,e,r){return this instanceof Xt?(this.l=+t,this.a=+e,void(this.b=+r)):arguments.length<2?t instanceof Xt?new Xt(t.l,t.a,t.b):t instanceof Gt?Wt(t.h,t.c,t.l):fe((t=ae(t)).r,t.g,t.b):new Xt(t,e,r)}Yt.brighter=function(t){return new Gt(this.h,this.c,Math.min(100,this.l+Zt*(arguments.length?t:1)))},Yt.darker=function(t){return new Gt(this.h,this.c,Math.max(0,this.l-Zt*(arguments.length?t:1)))},Yt.rgb=function(){return Wt(this.h,this.c,this.l).rgb()},t.lab=Xt;var Zt=18,Jt=.95047,Kt=1,$t=1.08883,Qt=Xt.prototype=new Ut;function te(t,e,r){var n=(t+16)/116,i=n+e/500,a=n-r/200;return new ae(ie(3.2404542*(i=re(i)*Jt)-1.5371385*(n=re(n)*Kt)-.4985314*(a=re(a)*$t)),ie(-.969266*i+1.8760108*n+.041556*a),ie(.0556434*i-.2040259*n+1.0572252*a))}function ee(t,e,r){return t>0?new Gt(Math.atan2(r,e)*Lt,Math.sqrt(e*e+r*r),t):new Gt(NaN,NaN,t)}function re(t){return t>.206893034?t*t*t:(t-4/29)/7.787037}function ne(t){return t>.008856?Math.pow(t,1/3):7.787037*t+4/29}function ie(t){return Math.round(255*(t<=.00304?12.92*t:1.055*Math.pow(t,1/2.4)-.055))}function ae(t,e,r){return this instanceof ae?(this.r=~~t,this.g=~~e,void(this.b=~~r)):arguments.length<2?t instanceof ae?new ae(t.r,t.g,t.b):ue(\"\"+t,ae,Ht):new ae(t,e,r)}function oe(t){return new ae(t>>16,t>>8&255,255&t)}function se(t){return oe(t)+\"\"}Qt.brighter=function(t){return new Xt(Math.min(100,this.l+Zt*(arguments.length?t:1)),this.a,this.b)},Qt.darker=function(t){return new Xt(Math.max(0,this.l-Zt*(arguments.length?t:1)),this.a,this.b)},Qt.rgb=function(){return te(this.l,this.a,this.b)},t.rgb=ae;var le=ae.prototype=new Ut;function ce(t){return t<16?\"0\"+Math.max(0,t).toString(16):Math.min(255,t).toString(16)}function ue(t,e,r){var n,i,a,o=0,s=0,l=0;if(n=/([a-z]+)\\((.*)\\)/.exec(t=t.toLowerCase()))switch(i=n[2].split(\",\"),n[1]){case\"hsl\":return r(parseFloat(i[0]),parseFloat(i[1])/100,parseFloat(i[2])/100);case\"rgb\":return e(de(i[0]),de(i[1]),de(i[2]))}return(a=ge.get(t))?e(a.r,a.g,a.b):(null==t||\"#\"!==t.charAt(0)||isNaN(a=parseInt(t.slice(1),16))||(4===t.length?(o=(3840&a)>>4,o|=o>>4,s=240&a,s|=s>>4,l=15&a,l|=l<<4):7===t.length&&(o=(16711680&a)>>16,s=(65280&a)>>8,l=255&a)),e(o,s,l))}function he(t,e,r){var n,i,a=Math.min(t/=255,e/=255,r/=255),o=Math.max(t,e,r),s=o-a,l=(o+a)/2;return s?(i=l<.5?s/(o+a):s/(2-o-a),n=t==o?(e-r)/s+(e<r?6:0):e==o?(r-t)/s+2:(t-e)/s+4,n*=60):(n=NaN,i=l>0&&l<1?0:n),new Vt(n,i,l)}function fe(t,e,r){var n=ne((.4124564*(t=pe(t))+.3575761*(e=pe(e))+.1804375*(r=pe(r)))/Jt),i=ne((.2126729*t+.7151522*e+.072175*r)/Kt);return Xt(116*i-16,500*(n-i),200*(i-ne((.0193339*t+.119192*e+.9503041*r)/$t)))}function pe(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function de(t){var e=parseFloat(t);return\"%\"===t.charAt(t.length-1)?Math.round(2.55*e):e}le.brighter=function(t){t=Math.pow(.7,arguments.length?t:1);var e=this.r,r=this.g,n=this.b,i=30;return e||r||n?(e&&e<i&&(e=i),r&&r<i&&(r=i),n&&n<i&&(n=i),new ae(Math.min(255,e/t),Math.min(255,r/t),Math.min(255,n/t))):new ae(i,i,i)},le.darker=function(t){return new ae((t=Math.pow(.7,arguments.length?t:1))*this.r,t*this.g,t*this.b)},le.hsl=function(){return he(this.r,this.g,this.b)},le.toString=function(){return\"#\"+ce(this.r)+ce(this.g)+ce(this.b)};var ge=t.map({aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074});function ve(t){return\"function\"==typeof t?t:function(){return t}}function me(t){return function(e,r,n){return 2===arguments.length&&\"function\"==typeof r&&(n=r,r=null),ye(e,r,t,n)}}function ye(e,r,i,a){var o={},s=t.dispatch(\"beforesend\",\"progress\",\"load\",\"error\"),l={},c=new XMLHttpRequest,u=null;function h(){var t,e=c.status;if(!e&&function(t){var e=t.responseType;return e&&\"text\"!==e?t.response:t.responseText}(c)||e>=200&&e<300||304===e){try{t=i.call(o,c)}catch(t){return void s.error.call(o,t)}s.load.call(o,t)}else s.error.call(o,c)}return!this.XDomainRequest||\"withCredentials\"in c||!/^(http(s)?:)?\\/\\//.test(e)||(c=new XDomainRequest),\"onload\"in c?c.onload=c.onerror=h:c.onreadystatechange=function(){c.readyState>3&&h()},c.onprogress=function(e){var r=t.event;t.event=e;try{s.progress.call(o,c)}finally{t.event=r}},o.header=function(t,e){return t=(t+\"\").toLowerCase(),arguments.length<2?l[t]:(null==e?delete l[t]:l[t]=e+\"\",o)},o.mimeType=function(t){return arguments.length?(r=null==t?null:t+\"\",o):r},o.responseType=function(t){return arguments.length?(u=t,o):u},o.response=function(t){return i=t,o},[\"get\",\"post\"].forEach(function(t){o[t]=function(){return o.send.apply(o,[t].concat(n(arguments)))}}),o.send=function(t,n,i){if(2===arguments.length&&\"function\"==typeof n&&(i=n,n=null),c.open(t,e,!0),null==r||\"accept\"in l||(l.accept=r+\",*/*\"),c.setRequestHeader)for(var a in l)c.setRequestHeader(a,l[a]);return null!=r&&c.overrideMimeType&&c.overrideMimeType(r),null!=u&&(c.responseType=u),null!=i&&o.on(\"error\",i).on(\"load\",function(t){i(null,t)}),s.beforesend.call(o,c),c.send(null==n?null:n),o},o.abort=function(){return c.abort(),o},t.rebind(o,s,\"on\"),null==a?o:o.get(function(t){return 1===t.length?function(e,r){t(null==e?r:null)}:t}(a))}ge.forEach(function(t,e){ge.set(t,oe(e))}),t.functor=ve,t.xhr=me(P),t.dsv=function(t,e){var r=new RegExp('[\"'+t+\"\\n]\"),n=t.charCodeAt(0);function i(t,r,n){arguments.length<3&&(n=r,r=null);var i=ye(t,e,null==r?a:o(r),n);return i.row=function(t){return arguments.length?i.response(null==(r=t)?a:o(t)):r},i}function a(t){return i.parse(t.responseText)}function o(t){return function(e){return i.parse(e.responseText,t)}}function s(e){return e.map(l).join(t)}function l(t){return r.test(t)?'\"'+t.replace(/\\\"/g,'\"\"')+'\"':t}return i.parse=function(t,e){var r;return i.parseRows(t,function(t,n){if(r)return r(t,n-1);var i=new Function(\"d\",\"return {\"+t.map(function(t,e){return JSON.stringify(t)+\": d[\"+e+\"]\"}).join(\",\")+\"}\");r=e?function(t,r){return e(i(t),r)}:i})},i.parseRows=function(t,e){var r,i,a={},o={},s=[],l=t.length,c=0,u=0;function h(){if(c>=l)return o;if(i)return i=!1,a;var e=c;if(34===t.charCodeAt(e)){for(var r=e;r++<l;)if(34===t.charCodeAt(r)){if(34!==t.charCodeAt(r+1))break;++r}return c=r+2,13===(s=t.charCodeAt(r+1))?(i=!0,10===t.charCodeAt(r+2)&&++c):10===s&&(i=!0),t.slice(e+1,r).replace(/\"\"/g,'\"')}for(;c<l;){var s,u=1;if(10===(s=t.charCodeAt(c++)))i=!0;else if(13===s)i=!0,10===t.charCodeAt(c)&&(++c,++u);else if(s!==n)continue;return t.slice(e,c-u)}return t.slice(e)}for(;(r=h())!==o;){for(var f=[];r!==a&&r!==o;)f.push(r),r=h();e&&null==(f=e(f,u++))||s.push(f)}return s},i.format=function(e){if(Array.isArray(e[0]))return i.formatRows(e);var r=new L,n=[];return e.forEach(function(t){for(var e in t)r.has(e)||n.push(r.add(e))}),[n.map(l).join(t)].concat(e.map(function(e){return n.map(function(t){return l(e[t])}).join(t)})).join(\"\\n\")},i.formatRows=function(t){return t.map(s).join(\"\\n\")},i},t.csv=t.dsv(\",\",\"text/csv\"),t.tsv=t.dsv(\"\\t\",\"text/tab-separated-values\");var xe,be,_e,we,ke=this[z(this,\"requestAnimationFrame\")]||function(t){setTimeout(t,17)};function Te(t,e,r){var n=arguments.length;n<2&&(e=0),n<3&&(r=Date.now());var i={c:t,t:r+e,n:null};return be?be.n=i:xe=i,be=i,_e||(we=clearTimeout(we),_e=1,ke(Ae)),i}function Ae(){var t=Me(),e=Se()-t;e>24?(isFinite(e)&&(clearTimeout(we),we=setTimeout(Ae,e)),_e=0):(_e=1,ke(Ae))}function Me(){for(var t=Date.now(),e=xe;e;)t>=e.t&&e.c(t-e.t)&&(e.c=null),e=e.n;return t}function Se(){for(var t,e=xe,r=1/0;e;)e.c?(e.t<r&&(r=e.t),e=(t=e).n):e=t?t.n=e.n:xe=e.n;return be=t,r}function Ee(t,e){return e-(t?Math.ceil(Math.log(t)/Math.LN10):1)}t.timer=function(){Te.apply(this,arguments)},t.timer.flush=function(){Me(),Se()},t.round=function(t,e){return e?Math.round(t*(e=Math.pow(10,e)))/e:Math.round(t)};var Ce=[\"y\",\"z\",\"a\",\"f\",\"p\",\"n\",\"\\xb5\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\",\"P\",\"E\",\"Z\",\"Y\"].map(function(t,e){var r=Math.pow(10,3*y(8-e));return{scale:e>8?function(t){return t/r}:function(t){return t*r},symbol:t}});t.formatPrefix=function(e,r){var n=0;return(e=+e)&&(e<0&&(e*=-1),r&&(e=t.round(e,Ee(e,r))),n=1+Math.floor(1e-12+Math.log(e)/Math.LN10),n=Math.max(-24,Math.min(24,3*Math.floor((n-1)/3)))),Ce[8+n/3]};var Le=/(?:([^{])?([<>=^]))?([+\\- ])?([$#])?(0)?(\\d+)?(,)?(\\.-?\\d+)?([a-z%])?/i,Pe=t.map({b:function(t){return t.toString(2)},c:function(t){return String.fromCharCode(t)},o:function(t){return t.toString(8)},x:function(t){return t.toString(16)},X:function(t){return t.toString(16).toUpperCase()},g:function(t,e){return t.toPrecision(e)},e:function(t,e){return t.toExponential(e)},f:function(t,e){return t.toFixed(e)},r:function(e,r){return(e=t.round(e,Ee(e,r))).toFixed(Math.max(0,Math.min(20,Ee(e*(1+1e-15),r))))}});function Oe(t){return t+\"\"}var ze=t.time={},Ie=Date;function De(){this._=new Date(arguments.length>1?Date.UTC.apply(this,arguments):arguments[0])}De.prototype={getDate:function(){return this._.getUTCDate()},getDay:function(){return this._.getUTCDay()},getFullYear:function(){return this._.getUTCFullYear()},getHours:function(){return this._.getUTCHours()},getMilliseconds:function(){return this._.getUTCMilliseconds()},getMinutes:function(){return this._.getUTCMinutes()},getMonth:function(){return this._.getUTCMonth()},getSeconds:function(){return this._.getUTCSeconds()},getTime:function(){return this._.getTime()},getTimezoneOffset:function(){return 0},valueOf:function(){return this._.valueOf()},setDate:function(){Re.setUTCDate.apply(this._,arguments)},setDay:function(){Re.setUTCDay.apply(this._,arguments)},setFullYear:function(){Re.setUTCFullYear.apply(this._,arguments)},setHours:function(){Re.setUTCHours.apply(this._,arguments)},setMilliseconds:function(){Re.setUTCMilliseconds.apply(this._,arguments)},setMinutes:function(){Re.setUTCMinutes.apply(this._,arguments)},setMonth:function(){Re.setUTCMonth.apply(this._,arguments)},setSeconds:function(){Re.setUTCSeconds.apply(this._,arguments)},setTime:function(){Re.setTime.apply(this._,arguments)}};var Re=Date.prototype;function Fe(t,e,r){function n(e){var r=t(e),n=a(r,1);return e-r<n-e?r:n}function i(r){return e(r=t(new Ie(r-1)),1),r}function a(t,r){return e(t=new Ie(+t),r),t}function o(t,n,a){var o=i(t),s=[];if(a>1)for(;o<n;)r(o)%a||s.push(new Date(+o)),e(o,1);else for(;o<n;)s.push(new Date(+o)),e(o,1);return s}t.floor=t,t.round=n,t.ceil=i,t.offset=a,t.range=o;var s=t.utc=Be(t);return s.floor=s,s.round=Be(n),s.ceil=Be(i),s.offset=Be(a),s.range=function(t,e,r){try{Ie=De;var n=new De;return n._=t,o(n,e,r)}finally{Ie=Date}},t}function Be(t){return function(e,r){try{Ie=De;var n=new De;return n._=e,t(n,r)._}finally{Ie=Date}}}ze.year=Fe(function(t){return(t=ze.day(t)).setMonth(0,1),t},function(t,e){t.setFullYear(t.getFullYear()+e)},function(t){return t.getFullYear()}),ze.years=ze.year.range,ze.years.utc=ze.year.utc.range,ze.day=Fe(function(t){var e=new Ie(2e3,0);return e.setFullYear(t.getFullYear(),t.getMonth(),t.getDate()),e},function(t,e){t.setDate(t.getDate()+e)},function(t){return t.getDate()-1}),ze.days=ze.day.range,ze.days.utc=ze.day.utc.range,ze.dayOfYear=function(t){var e=ze.year(t);return Math.floor((t-e-6e4*(t.getTimezoneOffset()-e.getTimezoneOffset()))/864e5)},[\"sunday\",\"monday\",\"tuesday\",\"wednesday\",\"thursday\",\"friday\",\"saturday\"].forEach(function(t,e){e=7-e;var r=ze[t]=Fe(function(t){return(t=ze.day(t)).setDate(t.getDate()-(t.getDay()+e)%7),t},function(t,e){t.setDate(t.getDate()+7*Math.floor(e))},function(t){var r=ze.year(t).getDay();return Math.floor((ze.dayOfYear(t)+(r+e)%7)/7)-(r!==e)});ze[t+\"s\"]=r.range,ze[t+\"s\"].utc=r.utc.range,ze[t+\"OfYear\"]=function(t){var r=ze.year(t).getDay();return Math.floor((ze.dayOfYear(t)+(r+e)%7)/7)}}),ze.week=ze.sunday,ze.weeks=ze.sunday.range,ze.weeks.utc=ze.sunday.utc.range,ze.weekOfYear=ze.sundayOfYear;var Ne={\"-\":\"\",_:\" \",0:\"0\"},je=/^\\s*\\d+/,Ue=/^%/;function Ve(t,e,r){var n=t<0?\"-\":\"\",i=(n?-t:t)+\"\",a=i.length;return n+(a<r?new Array(r-a+1).join(e)+i:i)}function qe(e){return new RegExp(\"^(?:\"+e.map(t.requote).join(\"|\")+\")\",\"i\")}function He(t){for(var e=new b,r=-1,n=t.length;++r<n;)e.set(t[r].toLowerCase(),r);return e}function Ge(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+1));return n?(t.w=+n[0],r+n[0].length):-1}function Ye(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.U=+n[0],r+n[0].length):-1}function We(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.W=+n[0],r+n[0].length):-1}function Xe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+4));return n?(t.y=+n[0],r+n[0].length):-1}function Ze(t,e,r){je.lastIndex=0;var n,i=je.exec(e.slice(r,r+2));return i?(t.y=(n=+i[0])+(n>68?1900:2e3),r+i[0].length):-1}function Je(t,e,r){return/^[+-]\\d{4}$/.test(e=e.slice(r,r+5))?(t.Z=-e,r+5):-1}function Ke(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.m=n[0]-1,r+n[0].length):-1}function $e(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.d=+n[0],r+n[0].length):-1}function Qe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.j=+n[0],r+n[0].length):-1}function tr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.H=+n[0],r+n[0].length):-1}function er(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.M=+n[0],r+n[0].length):-1}function rr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.S=+n[0],r+n[0].length):-1}function nr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.L=+n[0],r+n[0].length):-1}function ir(t){var e=t.getTimezoneOffset(),r=e>0?\"-\":\"+\",n=y(e)/60|0,i=y(e)%60;return r+Ve(n,\"0\",2)+Ve(i,\"0\",2)}function ar(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r,r+1));return n?r+n[0].length:-1}function or(t){for(var e=t.length,r=-1;++r<e;)t[r][0]=this(t[r][0]);return function(e){for(var r=0,n=t[r];!n[1](e);)n=t[++r];return n[0](e)}}t.locale=function(e){return{numberFormat:function(e){var r=e.decimal,n=e.thousands,i=e.grouping,a=e.currency,o=i&&n?function(t,e){for(var r=t.length,a=[],o=0,s=i[0],l=0;r>0&&s>0&&(l+s+1>e&&(s=Math.max(1,e-l)),a.push(t.substring(r-=s,r+s)),!((l+=s+1)>e));)s=i[o=(o+1)%i.length];return a.reverse().join(n)}:P;return function(e){var n=Le.exec(e),i=n[1]||\" \",s=n[2]||\">\",l=n[3]||\"-\",c=n[4]||\"\",u=n[5],h=+n[6],f=n[7],p=n[8],d=n[9],g=1,v=\"\",m=\"\",y=!1,x=!0;switch(p&&(p=+p.substring(1)),(u||\"0\"===i&&\"=\"===s)&&(u=i=\"0\",s=\"=\"),d){case\"n\":f=!0,d=\"g\";break;case\"%\":g=100,m=\"%\",d=\"f\";break;case\"p\":g=100,m=\"%\",d=\"r\";break;case\"b\":case\"o\":case\"x\":case\"X\":\"#\"===c&&(v=\"0\"+d.toLowerCase());case\"c\":x=!1;case\"d\":y=!0,p=0;break;case\"s\":g=-1,d=\"r\"}\"$\"===c&&(v=a[0],m=a[1]),\"r\"!=d||p||(d=\"g\"),null!=p&&(\"g\"==d?p=Math.max(1,Math.min(21,p)):\"e\"!=d&&\"f\"!=d||(p=Math.max(0,Math.min(20,p)))),d=Pe.get(d)||Oe;var b=u&&f;return function(e){var n=m;if(y&&e%1)return\"\";var a=e<0||0===e&&1/e<0?(e=-e,\"-\"):\"-\"===l?\"\":l;if(g<0){var c=t.formatPrefix(e,p);e=c.scale(e),n=c.symbol+m}else e*=g;var _,w,k=(e=d(e,p)).lastIndexOf(\".\");if(k<0){var T=x?e.lastIndexOf(\"e\"):-1;T<0?(_=e,w=\"\"):(_=e.substring(0,T),w=e.substring(T))}else _=e.substring(0,k),w=r+e.substring(k+1);!u&&f&&(_=o(_,1/0));var A=v.length+_.length+w.length+(b?0:a.length),M=A<h?new Array(A=h-A+1).join(i):\"\";return b&&(_=o(M+_,M.length?h-w.length:1/0)),a+=v,e=_+w,(\"<\"===s?a+e+M:\">\"===s?M+a+e:\"^\"===s?M.substring(0,A>>=1)+a+e+M.substring(A):a+(b?e:M+e))+n}}}(e),timeFormat:function(e){var r=e.dateTime,n=e.date,i=e.time,a=e.periods,o=e.days,s=e.shortDays,l=e.months,c=e.shortMonths;function u(t){var e=t.length;function r(r){for(var n,i,a,o=[],s=-1,l=0;++s<e;)37===t.charCodeAt(s)&&(o.push(t.slice(l,s)),null!=(i=Ne[n=t.charAt(++s)])&&(n=t.charAt(++s)),(a=_[n])&&(n=a(r,null==i?\"e\"===n?\" \":\"0\":i)),o.push(n),l=s+1);return o.push(t.slice(l,s)),o.join(\"\")}return r.parse=function(e){var r={y:1900,m:0,d:1,H:0,M:0,S:0,L:0,Z:null};if(h(r,t,e,0)!=e.length)return null;\"p\"in r&&(r.H=r.H%12+12*r.p);var n=null!=r.Z&&Ie!==De,i=new(n?De:Ie);return\"j\"in r?i.setFullYear(r.y,0,r.j):\"W\"in r||\"U\"in r?(\"w\"in r||(r.w=\"W\"in r?1:0),i.setFullYear(r.y,0,1),i.setFullYear(r.y,0,\"W\"in r?(r.w+6)%7+7*r.W-(i.getDay()+5)%7:r.w+7*r.U-(i.getDay()+6)%7)):i.setFullYear(r.y,r.m,r.d),i.setHours(r.H+(r.Z/100|0),r.M+r.Z%100,r.S,r.L),n?i._:i},r.toString=function(){return t},r}function h(t,e,r,n){for(var i,a,o,s=0,l=e.length,c=r.length;s<l;){if(n>=c)return-1;if(37===(i=e.charCodeAt(s++))){if(o=e.charAt(s++),!(a=w[o in Ne?e.charAt(s++):o])||(n=a(t,r,n))<0)return-1}else if(i!=r.charCodeAt(n++))return-1}return n}u.utc=function(t){var e=u(t);function r(t){try{var r=new(Ie=De);return r._=t,e(r)}finally{Ie=Date}}return r.parse=function(t){try{Ie=De;var r=e.parse(t);return r&&r._}finally{Ie=Date}},r.toString=e.toString,r},u.multi=u.utc.multi=or;var f=t.map(),p=qe(o),d=He(o),g=qe(s),v=He(s),m=qe(l),y=He(l),x=qe(c),b=He(c);a.forEach(function(t,e){f.set(t.toLowerCase(),e)});var _={a:function(t){return s[t.getDay()]},A:function(t){return o[t.getDay()]},b:function(t){return c[t.getMonth()]},B:function(t){return l[t.getMonth()]},c:u(r),d:function(t,e){return Ve(t.getDate(),e,2)},e:function(t,e){return Ve(t.getDate(),e,2)},H:function(t,e){return Ve(t.getHours(),e,2)},I:function(t,e){return Ve(t.getHours()%12||12,e,2)},j:function(t,e){return Ve(1+ze.dayOfYear(t),e,3)},L:function(t,e){return Ve(t.getMilliseconds(),e,3)},m:function(t,e){return Ve(t.getMonth()+1,e,2)},M:function(t,e){return Ve(t.getMinutes(),e,2)},p:function(t){return a[+(t.getHours()>=12)]},S:function(t,e){return Ve(t.getSeconds(),e,2)},U:function(t,e){return Ve(ze.sundayOfYear(t),e,2)},w:function(t){return t.getDay()},W:function(t,e){return Ve(ze.mondayOfYear(t),e,2)},x:u(n),X:u(i),y:function(t,e){return Ve(t.getFullYear()%100,e,2)},Y:function(t,e){return Ve(t.getFullYear()%1e4,e,4)},Z:ir,\"%\":function(){return\"%\"}},w={a:function(t,e,r){g.lastIndex=0;var n=g.exec(e.slice(r));return n?(t.w=v.get(n[0].toLowerCase()),r+n[0].length):-1},A:function(t,e,r){p.lastIndex=0;var n=p.exec(e.slice(r));return n?(t.w=d.get(n[0].toLowerCase()),r+n[0].length):-1},b:function(t,e,r){x.lastIndex=0;var n=x.exec(e.slice(r));return n?(t.m=b.get(n[0].toLowerCase()),r+n[0].length):-1},B:function(t,e,r){m.lastIndex=0;var n=m.exec(e.slice(r));return n?(t.m=y.get(n[0].toLowerCase()),r+n[0].length):-1},c:function(t,e,r){return h(t,_.c.toString(),e,r)},d:$e,e:$e,H:tr,I:tr,j:Qe,L:nr,m:Ke,M:er,p:function(t,e,r){var n=f.get(e.slice(r,r+=2).toLowerCase());return null==n?-1:(t.p=n,r)},S:rr,U:Ye,w:Ge,W:We,x:function(t,e,r){return h(t,_.x.toString(),e,r)},X:function(t,e,r){return h(t,_.X.toString(),e,r)},y:Ze,Y:Xe,Z:Je,\"%\":ar};return u}(e)}};var sr=t.locale({decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],dateTime:\"%a %b %e %X %Y\",date:\"%m/%d/%Y\",time:\"%H:%M:%S\",periods:[\"AM\",\"PM\"],days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"]});function lr(){}t.format=sr.numberFormat,t.geo={},lr.prototype={s:0,t:0,add:function(t){ur(t,this.t,cr),ur(cr.s,this.s,this),this.s?this.t+=cr.t:this.s=cr.t},reset:function(){this.s=this.t=0},valueOf:function(){return this.s}};var cr=new lr;function ur(t,e,r){var n=r.s=t+e,i=n-t,a=n-i;r.t=t-a+(e-i)}function hr(t,e){t&&pr.hasOwnProperty(t.type)&&pr[t.type](t,e)}t.geo.stream=function(t,e){t&&fr.hasOwnProperty(t.type)?fr[t.type](t,e):hr(t,e)};var fr={Feature:function(t,e){hr(t.geometry,e)},FeatureCollection:function(t,e){for(var r=t.features,n=-1,i=r.length;++n<i;)hr(r[n].geometry,e)}},pr={Sphere:function(t,e){e.sphere()},Point:function(t,e){t=t.coordinates,e.point(t[0],t[1],t[2])},MultiPoint:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)t=r[n],e.point(t[0],t[1],t[2])},LineString:function(t,e){dr(t.coordinates,e,0)},MultiLineString:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)dr(r[n],e,0)},Polygon:function(t,e){gr(t.coordinates,e)},MultiPolygon:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)gr(r[n],e)},GeometryCollection:function(t,e){for(var r=t.geometries,n=-1,i=r.length;++n<i;)hr(r[n],e)}};function dr(t,e,r){var n,i=-1,a=t.length-r;for(e.lineStart();++i<a;)n=t[i],e.point(n[0],n[1],n[2]);e.lineEnd()}function gr(t,e){var r=-1,n=t.length;for(e.polygonStart();++r<n;)dr(t[r],e,1);e.polygonEnd()}t.geo.area=function(e){return vr=0,t.geo.stream(e,Cr),vr};var vr,mr,yr,xr,br,_r,wr,kr,Tr,Ar,Mr,Sr,Er=new lr,Cr={sphere:function(){vr+=4*At},point:D,lineStart:D,lineEnd:D,polygonStart:function(){Er.reset(),Cr.lineStart=Lr},polygonEnd:function(){var t=2*Er;vr+=t<0?4*At+t:t,Cr.lineStart=Cr.lineEnd=Cr.point=D}};function Lr(){var t,e,r,n,i;function a(t,e){e=e*Ct/2+At/4;var a=(t*=Ct)-r,o=a>=0?1:-1,s=o*a,l=Math.cos(e),c=Math.sin(e),u=i*c,h=n*l+u*Math.cos(s),f=u*o*Math.sin(s);Er.add(Math.atan2(f,h)),r=t,n=l,i=c}Cr.point=function(o,s){Cr.point=a,r=(t=o)*Ct,n=Math.cos(s=(e=s)*Ct/2+At/4),i=Math.sin(s)},Cr.lineEnd=function(){a(t,e)}}function Pr(t){var e=t[0],r=t[1],n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}function Or(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}function zr(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}function Ir(t,e){t[0]+=e[0],t[1]+=e[1],t[2]+=e[2]}function Dr(t,e){return[t[0]*e,t[1]*e,t[2]*e]}function Rr(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]+t[2]*t[2]);t[0]/=e,t[1]/=e,t[2]/=e}function Fr(t){return[Math.atan2(t[1],t[0]),It(t[2])]}function Br(t,e){return y(t[0]-e[0])<kt&&y(t[1]-e[1])<kt}t.geo.bounds=function(){var e,r,n,i,a,o,s,l,c,u,h,f={point:p,lineStart:g,lineEnd:v,polygonStart:function(){f.point=m,f.lineStart=x,f.lineEnd=b,c=0,Cr.polygonStart()},polygonEnd:function(){Cr.polygonEnd(),f.point=p,f.lineStart=g,f.lineEnd=v,Er<0?(e=-(n=180),r=-(i=90)):c>kt?i=90:c<-kt&&(r=-90),h[0]=e,h[1]=n}};function p(t,a){u.push(h=[e=t,n=t]),a<r&&(r=a),a>i&&(i=a)}function d(t,o){var s=Pr([t*Ct,o*Ct]);if(l){var c=zr(l,s),u=zr([c[1],-c[0],0],c);Rr(u),u=Fr(u);var h=t-a,f=h>0?1:-1,d=u[0]*Lt*f,g=y(h)>180;if(g^(f*a<d&&d<f*t))(v=u[1]*Lt)>i&&(i=v);else if(g^(f*a<(d=(d+360)%360-180)&&d<f*t)){var v;(v=-u[1]*Lt)<r&&(r=v)}else o<r&&(r=o),o>i&&(i=o);g?t<a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t):n>=e?(t<e&&(e=t),t>n&&(n=t)):t>a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t)}else p(t,o);l=s,a=t}function g(){f.point=d}function v(){h[0]=e,h[1]=n,f.point=p,l=null}function m(t,e){if(l){var r=t-a;c+=y(r)>180?r+(r>0?360:-360):r}else o=t,s=e;Cr.point(t,e),d(t,e)}function x(){Cr.lineStart()}function b(){m(o,s),Cr.lineEnd(),y(c)>kt&&(e=-(n=180)),h[0]=e,h[1]=n,l=null}function _(t,e){return(e-=t)<0?e+360:e}function w(t,e){return t[0]-e[0]}function k(t,e){return e[0]<=e[1]?e[0]<=t&&t<=e[1]:t<e[0]||e[1]<t}return function(a){if(i=n=-(e=r=1/0),u=[],t.geo.stream(a,f),c=u.length){u.sort(w);for(var o=1,s=[g=u[0]];o<c;++o)k((p=u[o])[0],g)||k(p[1],g)?(_(g[0],p[1])>_(g[0],g[1])&&(g[1]=p[1]),_(p[0],g[1])>_(g[0],g[1])&&(g[0]=p[0])):s.push(g=p);for(var l,c,p,d=-1/0,g=(o=0,s[c=s.length-1]);o<=c;g=p,++o)p=s[o],(l=_(g[1],p[0]))>d&&(d=l,e=p[0],n=g[1])}return u=h=null,e===1/0||r===1/0?[[NaN,NaN],[NaN,NaN]]:[[e,r],[n,i]]}}(),t.geo.centroid=function(e){mr=yr=xr=br=_r=wr=kr=Tr=Ar=Mr=Sr=0,t.geo.stream(e,Nr);var r=Ar,n=Mr,i=Sr,a=r*r+n*n+i*i;return a<Tt&&(r=wr,n=kr,i=Tr,yr<kt&&(r=xr,n=br,i=_r),(a=r*r+n*n+i*i)<Tt)?[NaN,NaN]:[Math.atan2(n,r)*Lt,It(i/Math.sqrt(a))*Lt]};var Nr={sphere:D,point:jr,lineStart:Vr,lineEnd:qr,polygonStart:function(){Nr.lineStart=Hr},polygonEnd:function(){Nr.lineStart=Vr}};function jr(t,e){t*=Ct;var r=Math.cos(e*=Ct);Ur(r*Math.cos(t),r*Math.sin(t),Math.sin(e))}function Ur(t,e,r){xr+=(t-xr)/++mr,br+=(e-br)/mr,_r+=(r-_r)/mr}function Vr(){var t,e,r;function n(n,i){n*=Ct;var a=Math.cos(i*=Ct),o=a*Math.cos(n),s=a*Math.sin(n),l=Math.sin(i),c=Math.atan2(Math.sqrt((c=e*l-r*s)*c+(c=r*o-t*l)*c+(c=t*s-e*o)*c),t*o+e*s+r*l);yr+=c,wr+=c*(t+(t=o)),kr+=c*(e+(e=s)),Tr+=c*(r+(r=l)),Ur(t,e,r)}Nr.point=function(i,a){i*=Ct;var o=Math.cos(a*=Ct);t=o*Math.cos(i),e=o*Math.sin(i),r=Math.sin(a),Nr.point=n,Ur(t,e,r)}}function qr(){Nr.point=jr}function Hr(){var t,e,r,n,i;function a(t,e){t*=Ct;var a=Math.cos(e*=Ct),o=a*Math.cos(t),s=a*Math.sin(t),l=Math.sin(e),c=n*l-i*s,u=i*o-r*l,h=r*s-n*o,f=Math.sqrt(c*c+u*u+h*h),p=r*o+n*s+i*l,d=f&&-zt(p)/f,g=Math.atan2(f,p);Ar+=d*c,Mr+=d*u,Sr+=d*h,yr+=g,wr+=g*(r+(r=o)),kr+=g*(n+(n=s)),Tr+=g*(i+(i=l)),Ur(r,n,i)}Nr.point=function(o,s){t=o,e=s,Nr.point=a,o*=Ct;var l=Math.cos(s*=Ct);r=l*Math.cos(o),n=l*Math.sin(o),i=Math.sin(s),Ur(r,n,i)},Nr.lineEnd=function(){a(t,e),Nr.lineEnd=qr,Nr.point=jr}}function Gr(t,e){function r(r,n){return r=t(r,n),e(r[0],r[1])}return t.invert&&e.invert&&(r.invert=function(r,n){return(r=e.invert(r,n))&&t.invert(r[0],r[1])}),r}function Yr(){return!0}function Wr(t,e,r,n,i){var a=[],o=[];if(t.forEach(function(t){if(!((e=t.length-1)<=0)){var e,r=t[0],n=t[e];if(Br(r,n)){i.lineStart();for(var s=0;s<e;++s)i.point((r=t[s])[0],r[1]);i.lineEnd()}else{var l=new Zr(r,t,null,!0),c=new Zr(r,null,l,!1);l.o=c,a.push(l),o.push(c),l=new Zr(n,t,null,!1),c=new Zr(n,null,l,!0),l.o=c,a.push(l),o.push(c)}}}),o.sort(e),Xr(a),Xr(o),a.length){for(var s=0,l=r,c=o.length;s<c;++s)o[s].e=l=!l;for(var u,h,f=a[0];;){for(var p=f,d=!0;p.v;)if((p=p.n)===f)return;u=p.z,i.lineStart();do{if(p.v=p.o.v=!0,p.e){if(d)for(s=0,c=u.length;s<c;++s)i.point((h=u[s])[0],h[1]);else n(p.x,p.n.x,1,i);p=p.n}else{if(d)for(s=(u=p.p.z).length-1;s>=0;--s)i.point((h=u[s])[0],h[1]);else n(p.x,p.p.x,-1,i);p=p.p}u=(p=p.o).z,d=!d}while(!p.v);i.lineEnd()}}}function Xr(t){if(e=t.length){for(var e,r,n=0,i=t[0];++n<e;)i.n=r=t[n],r.p=i,i=r;i.n=r=t[0],r.p=i}}function Zr(t,e,r,n){this.x=t,this.z=e,this.o=r,this.e=n,this.v=!1,this.n=this.p=null}function Jr(e,r,n,i){return function(a,o){var s,l=r(o),c=a.invert(i[0],i[1]),u={point:h,lineStart:p,lineEnd:d,polygonStart:function(){u.point=b,u.lineStart=_,u.lineEnd=w,s=[],g=[]},polygonEnd:function(){u.point=h,u.lineStart=p,u.lineEnd=d,s=t.merge(s);var e=function(t,e){var r=t[0],n=t[1],i=[Math.sin(r),-Math.cos(r),0],a=0,o=0;Er.reset();for(var s=0,l=e.length;s<l;++s){var c=e[s],u=c.length;if(u)for(var h=c[0],f=h[0],p=h[1]/2+At/4,d=Math.sin(p),g=Math.cos(p),v=1;;){v===u&&(v=0);var m=(t=c[v])[0],y=t[1]/2+At/4,x=Math.sin(y),b=Math.cos(y),_=m-f,w=_>=0?1:-1,k=w*_,T=k>At,A=d*x;if(Er.add(Math.atan2(A*w*Math.sin(k),g*b+A*Math.cos(k))),a+=T?_+w*Mt:_,T^f>=r^m>=r){var M=zr(Pr(h),Pr(t));Rr(M);var S=zr(i,M);Rr(S);var E=(T^_>=0?-1:1)*It(S[2]);(n>E||n===E&&(M[0]||M[1]))&&(o+=T^_>=0?1:-1)}if(!v++)break;f=m,d=x,g=b,h=t}}return(a<-kt||a<kt&&Er<-kt)^1&o}(c,g);s.length?(x||(o.polygonStart(),x=!0),Wr(s,Qr,e,n,o)):e&&(x||(o.polygonStart(),x=!0),o.lineStart(),n(null,null,1,o),o.lineEnd()),x&&(o.polygonEnd(),x=!1),s=g=null},sphere:function(){o.polygonStart(),o.lineStart(),n(null,null,1,o),o.lineEnd(),o.polygonEnd()}};function h(t,r){var n=a(t,r);e(t=n[0],r=n[1])&&o.point(t,r)}function f(t,e){var r=a(t,e);l.point(r[0],r[1])}function p(){u.point=f,l.lineStart()}function d(){u.point=h,l.lineEnd()}var g,v,m=$r(),y=r(m),x=!1;function b(t,e){v.push([t,e]);var r=a(t,e);y.point(r[0],r[1])}function _(){y.lineStart(),v=[]}function w(){b(v[0][0],v[0][1]),y.lineEnd();var t,e=y.clean(),r=m.buffer(),n=r.length;if(v.pop(),g.push(v),v=null,n)if(1&e){var i,a=-1;if((n=(t=r[0]).length-1)>0){for(x||(o.polygonStart(),x=!0),o.lineStart();++a<n;)o.point((i=t[a])[0],i[1]);o.lineEnd()}}else n>1&&2&e&&r.push(r.pop().concat(r.shift())),s.push(r.filter(Kr))}return u}}function Kr(t){return t.length>1}function $r(){var t,e=[];return{lineStart:function(){e.push(t=[])},point:function(e,r){t.push([e,r])},lineEnd:D,buffer:function(){var r=e;return e=[],t=null,r},rejoin:function(){e.length>1&&e.push(e.pop().concat(e.shift()))}}}function Qr(t,e){return((t=t.x)[0]<0?t[1]-Et-kt:Et-t[1])-((e=e.x)[0]<0?e[1]-Et-kt:Et-e[1])}var tn=Jr(Yr,function(t){var e,r=NaN,n=NaN,i=NaN;return{lineStart:function(){t.lineStart(),e=1},point:function(a,o){var s=a>0?At:-At,l=y(a-r);y(l-At)<kt?(t.point(r,n=(n+o)/2>0?Et:-Et),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),t.point(a,n),e=0):i!==s&&l>=At&&(y(r-i)<kt&&(r-=i*kt),y(a-s)<kt&&(a-=s*kt),n=function(t,e,r,n){var i,a,o=Math.sin(t-r);return y(o)>kt?Math.atan((Math.sin(e)*(a=Math.cos(n))*Math.sin(r)-Math.sin(n)*(i=Math.cos(e))*Math.sin(t))/(i*a*o)):(e+n)/2}(r,n,a,o),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),e=0),t.point(r=a,n=o),i=s},lineEnd:function(){t.lineEnd(),r=n=NaN},clean:function(){return 2-e}}},function(t,e,r,n){var i;if(null==t)i=r*Et,n.point(-At,i),n.point(0,i),n.point(At,i),n.point(At,0),n.point(At,-i),n.point(0,-i),n.point(-At,-i),n.point(-At,0),n.point(-At,i);else if(y(t[0]-e[0])>kt){var a=t[0]<e[0]?At:-At;i=r*a/2,n.point(-a,i),n.point(0,i),n.point(a,i)}else n.point(e[0],e[1])},[-At,-At/2]);function en(t,e,r,n){return function(i){var a,o=i.a,s=i.b,l=o.x,c=o.y,u=0,h=1,f=s.x-l,p=s.y-c;if(a=t-l,f||!(a>0)){if(a/=f,f<0){if(a<u)return;a<h&&(h=a)}else if(f>0){if(a>h)return;a>u&&(u=a)}if(a=r-l,f||!(a<0)){if(a/=f,f<0){if(a>h)return;a>u&&(u=a)}else if(f>0){if(a<u)return;a<h&&(h=a)}if(a=e-c,p||!(a>0)){if(a/=p,p<0){if(a<u)return;a<h&&(h=a)}else if(p>0){if(a>h)return;a>u&&(u=a)}if(a=n-c,p||!(a<0)){if(a/=p,p<0){if(a>h)return;a>u&&(u=a)}else if(p>0){if(a<u)return;a<h&&(h=a)}return u>0&&(i.a={x:l+u*f,y:c+u*p}),h<1&&(i.b={x:l+h*f,y:c+h*p}),i}}}}}}var rn=1e9;function nn(e,r,n,i){return function(l){var c,u,h,f,p,d,g,v,m,y,x,b=l,_=$r(),w=en(e,r,n,i),k={point:M,lineStart:function(){k.point=S,u&&u.push(h=[]);y=!0,m=!1,g=v=NaN},lineEnd:function(){c&&(S(f,p),d&&m&&_.rejoin(),c.push(_.buffer()));k.point=M,m&&l.lineEnd()},polygonStart:function(){l=_,c=[],u=[],x=!0},polygonEnd:function(){l=b,c=t.merge(c);var r=function(t){for(var e=0,r=u.length,n=t[1],i=0;i<r;++i)for(var a,o=1,s=u[i],l=s.length,c=s[0];o<l;++o)a=s[o],c[1]<=n?a[1]>n&&Ot(c,a,t)>0&&++e:a[1]<=n&&Ot(c,a,t)<0&&--e,c=a;return 0!==e}([e,i]),n=x&&r,a=c.length;(n||a)&&(l.polygonStart(),n&&(l.lineStart(),T(null,null,1,l),l.lineEnd()),a&&Wr(c,o,r,T,l),l.polygonEnd()),c=u=h=null}};function T(t,o,l,c){var u=0,h=0;if(null==t||(u=a(t,l))!==(h=a(o,l))||s(t,o)<0^l>0)do{c.point(0===u||3===u?e:n,u>1?i:r)}while((u=(u+l+4)%4)!==h);else c.point(o[0],o[1])}function A(t,a){return e<=t&&t<=n&&r<=a&&a<=i}function M(t,e){A(t,e)&&l.point(t,e)}function S(t,e){var r=A(t=Math.max(-rn,Math.min(rn,t)),e=Math.max(-rn,Math.min(rn,e)));if(u&&h.push([t,e]),y)f=t,p=e,d=r,y=!1,r&&(l.lineStart(),l.point(t,e));else if(r&&m)l.point(t,e);else{var n={a:{x:g,y:v},b:{x:t,y:e}};w(n)?(m||(l.lineStart(),l.point(n.a.x,n.a.y)),l.point(n.b.x,n.b.y),r||l.lineEnd(),x=!1):r&&(l.lineStart(),l.point(t,e),x=!1)}g=t,v=e,m=r}return k};function a(t,i){return y(t[0]-e)<kt?i>0?0:3:y(t[0]-n)<kt?i>0?2:1:y(t[1]-r)<kt?i>0?1:0:i>0?3:2}function o(t,e){return s(t.x,e.x)}function s(t,e){var r=a(t,1),n=a(e,1);return r!==n?r-n:0===r?e[1]-t[1]:1===r?t[0]-e[0]:2===r?t[1]-e[1]:e[0]-t[0]}}function an(t){var e=0,r=At/3,n=Cn(t),i=n(e,r);return i.parallels=function(t){return arguments.length?n(e=t[0]*At/180,r=t[1]*At/180):[e/At*180,r/At*180]},i}function on(t,e){var r=Math.sin(t),n=(r+Math.sin(e))/2,i=1+r*(2*n-r),a=Math.sqrt(i)/n;function o(t,e){var r=Math.sqrt(i-2*n*Math.sin(e))/n;return[r*Math.sin(t*=n),a-r*Math.cos(t)]}return o.invert=function(t,e){var r=a-e;return[Math.atan2(t,r)/n,It((i-(t*t+r*r)*n*n)/(2*n))]},o}t.geo.clipExtent=function(){var t,e,r,n,i,a,o={stream:function(t){return i&&(i.valid=!1),(i=a(t)).valid=!0,i},extent:function(s){return arguments.length?(a=nn(t=+s[0][0],e=+s[0][1],r=+s[1][0],n=+s[1][1]),i&&(i.valid=!1,i=null),o):[[t,e],[r,n]]}};return o.extent([[0,0],[960,500]])},(t.geo.conicEqualArea=function(){return an(on)}).raw=on,t.geo.albers=function(){return t.geo.conicEqualArea().rotate([96,0]).center([-.6,38.7]).parallels([29.5,45.5]).scale(1070)},t.geo.albersUsa=function(){var e,r,n,i,a=t.geo.albers(),o=t.geo.conicEqualArea().rotate([154,0]).center([-2,58.5]).parallels([55,65]),s=t.geo.conicEqualArea().rotate([157,0]).center([-3,19.9]).parallels([8,18]),l={point:function(t,r){e=[t,r]}};function c(t){var a=t[0],o=t[1];return e=null,r(a,o),e||(n(a,o),e)||i(a,o),e}return c.invert=function(t){var e=a.scale(),r=a.translate(),n=(t[0]-r[0])/e,i=(t[1]-r[1])/e;return(i>=.12&&i<.234&&n>=-.425&&n<-.214?o:i>=.166&&i<.234&&n>=-.214&&n<-.115?s:a).invert(t)},c.stream=function(t){var e=a.stream(t),r=o.stream(t),n=s.stream(t);return{point:function(t,i){e.point(t,i),r.point(t,i),n.point(t,i)},sphere:function(){e.sphere(),r.sphere(),n.sphere()},lineStart:function(){e.lineStart(),r.lineStart(),n.lineStart()},lineEnd:function(){e.lineEnd(),r.lineEnd(),n.lineEnd()},polygonStart:function(){e.polygonStart(),r.polygonStart(),n.polygonStart()},polygonEnd:function(){e.polygonEnd(),r.polygonEnd(),n.polygonEnd()}}},c.precision=function(t){return arguments.length?(a.precision(t),o.precision(t),s.precision(t),c):a.precision()},c.scale=function(t){return arguments.length?(a.scale(t),o.scale(.35*t),s.scale(t),c.translate(a.translate())):a.scale()},c.translate=function(t){if(!arguments.length)return a.translate();var e=a.scale(),u=+t[0],h=+t[1];return r=a.translate(t).clipExtent([[u-.455*e,h-.238*e],[u+.455*e,h+.238*e]]).stream(l).point,n=o.translate([u-.307*e,h+.201*e]).clipExtent([[u-.425*e+kt,h+.12*e+kt],[u-.214*e-kt,h+.234*e-kt]]).stream(l).point,i=s.translate([u-.205*e,h+.212*e]).clipExtent([[u-.214*e+kt,h+.166*e+kt],[u-.115*e-kt,h+.234*e-kt]]).stream(l).point,c},c.scale(1070)};var sn,ln,cn,un,hn,fn,pn={point:D,lineStart:D,lineEnd:D,polygonStart:function(){ln=0,pn.lineStart=dn},polygonEnd:function(){pn.lineStart=pn.lineEnd=pn.point=D,sn+=y(ln/2)}};function dn(){var t,e,r,n;function i(t,e){ln+=n*t-r*e,r=t,n=e}pn.point=function(a,o){pn.point=i,t=r=a,e=n=o},pn.lineEnd=function(){i(t,e)}}var gn={point:function(t,e){t<cn&&(cn=t);t>hn&&(hn=t);e<un&&(un=e);e>fn&&(fn=e)},lineStart:D,lineEnd:D,polygonStart:D,polygonEnd:D};function vn(){var t=mn(4.5),e=[],r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(e){return t=mn(e),r},result:function(){if(e.length){var t=e.join(\"\");return e=[],t}}};function n(r,n){e.push(\"M\",r,\",\",n,t)}function i(t,n){e.push(\"M\",t,\",\",n),r.point=a}function a(t,r){e.push(\"L\",t,\",\",r)}function o(){r.point=n}function s(){e.push(\"Z\")}return r}function mn(t){return\"m0,\"+t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+-2*t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+2*t+\"z\"}var yn,xn={point:bn,lineStart:_n,lineEnd:wn,polygonStart:function(){xn.lineStart=kn},polygonEnd:function(){xn.point=bn,xn.lineStart=_n,xn.lineEnd=wn}};function bn(t,e){xr+=t,br+=e,++_r}function _n(){var t,e;function r(r,n){var i=r-t,a=n-e,o=Math.sqrt(i*i+a*a);wr+=o*(t+r)/2,kr+=o*(e+n)/2,Tr+=o,bn(t=r,e=n)}xn.point=function(n,i){xn.point=r,bn(t=n,e=i)}}function wn(){xn.point=bn}function kn(){var t,e,r,n;function i(t,e){var i=t-r,a=e-n,o=Math.sqrt(i*i+a*a);wr+=o*(r+t)/2,kr+=o*(n+e)/2,Tr+=o,Ar+=(o=n*t-r*e)*(r+t),Mr+=o*(n+e),Sr+=3*o,bn(r=t,n=e)}xn.point=function(a,o){xn.point=i,bn(t=r=a,e=n=o)},xn.lineEnd=function(){i(t,e)}}function Tn(t){var e=4.5,r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(t){return e=t,r},result:D};function n(r,n){t.moveTo(r+e,n),t.arc(r,n,e,0,Mt)}function i(e,n){t.moveTo(e,n),r.point=a}function a(e,r){t.lineTo(e,r)}function o(){r.point=n}function s(){t.closePath()}return r}function An(t){var e=.5,r=Math.cos(30*Ct),n=16;function i(e){return(n?function(e){var r,i,o,s,l,c,u,h,f,p,d,g,v={point:m,lineStart:y,lineEnd:b,polygonStart:function(){e.polygonStart(),v.lineStart=_},polygonEnd:function(){e.polygonEnd(),v.lineStart=y}};function m(r,n){r=t(r,n),e.point(r[0],r[1])}function y(){h=NaN,v.point=x,e.lineStart()}function x(r,i){var o=Pr([r,i]),s=t(r,i);a(h,f,u,p,d,g,h=s[0],f=s[1],u=r,p=o[0],d=o[1],g=o[2],n,e),e.point(h,f)}function b(){v.point=m,e.lineEnd()}function _(){y(),v.point=w,v.lineEnd=k}function w(t,e){x(r=t,e),i=h,o=f,s=p,l=d,c=g,v.point=x}function k(){a(h,f,u,p,d,g,i,o,r,s,l,c,n,e),v.lineEnd=b,b()}return v}:function(e){return Sn(e,function(r,n){r=t(r,n),e.point(r[0],r[1])})})(e)}function a(n,i,o,s,l,c,u,h,f,p,d,g,v,m){var x=u-n,b=h-i,_=x*x+b*b;if(_>4*e&&v--){var w=s+p,k=l+d,T=c+g,A=Math.sqrt(w*w+k*k+T*T),M=Math.asin(T/=A),S=y(y(T)-1)<kt||y(o-f)<kt?(o+f)/2:Math.atan2(k,w),E=t(S,M),C=E[0],L=E[1],P=C-n,O=L-i,z=b*P-x*O;(z*z/_>e||y((x*P+b*O)/_-.5)>.3||s*p+l*d+c*g<r)&&(a(n,i,o,s,l,c,C,L,S,w/=A,k/=A,T,v,m),m.point(C,L),a(C,L,S,w,k,T,u,h,f,p,d,g,v,m))}}return i.precision=function(t){return arguments.length?(n=(e=t*t)>0&&16,i):Math.sqrt(e)},i}function Mn(t){this.stream=t}function Sn(t,e){return{point:e,sphere:function(){t.sphere()},lineStart:function(){t.lineStart()},lineEnd:function(){t.lineEnd()},polygonStart:function(){t.polygonStart()},polygonEnd:function(){t.polygonEnd()}}}function En(t){return Cn(function(){return t})()}function Cn(e){var r,n,i,a,o,s,l=An(function(t,e){return[(t=r(t,e))[0]*c+a,o-t[1]*c]}),c=150,u=480,h=250,f=0,p=0,d=0,g=0,v=0,m=tn,x=P,b=null,_=null;function w(t){return[(t=i(t[0]*Ct,t[1]*Ct))[0]*c+a,o-t[1]*c]}function k(t){return(t=i.invert((t[0]-a)/c,(o-t[1])/c))&&[t[0]*Lt,t[1]*Lt]}function T(){i=Gr(n=zn(d,g,v),r);var t=r(f,p);return a=u-t[0]*c,o=h+t[1]*c,A()}function A(){return s&&(s.valid=!1,s=null),w}return w.stream=function(t){return s&&(s.valid=!1),(s=Ln(m(n,l(x(t))))).valid=!0,s},w.clipAngle=function(t){return arguments.length?(m=null==t?(b=t,tn):function(t){var e=Math.cos(t),r=e>0,n=y(e)>kt;return Jr(i,function(t){var e,s,l,c,u;return{lineStart:function(){c=l=!1,u=1},point:function(h,f){var p,d=[h,f],g=i(h,f),v=r?g?0:o(h,f):g?o(h+(h<0?At:-At),f):0;if(!e&&(c=l=g)&&t.lineStart(),g!==l&&(p=a(e,d),(Br(e,p)||Br(d,p))&&(d[0]+=kt,d[1]+=kt,g=i(d[0],d[1]))),g!==l)u=0,g?(t.lineStart(),p=a(d,e),t.point(p[0],p[1])):(p=a(e,d),t.point(p[0],p[1]),t.lineEnd()),e=p;else if(n&&e&&r^g){var m;v&s||!(m=a(d,e,!0))||(u=0,r?(t.lineStart(),t.point(m[0][0],m[0][1]),t.point(m[1][0],m[1][1]),t.lineEnd()):(t.point(m[1][0],m[1][1]),t.lineEnd(),t.lineStart(),t.point(m[0][0],m[0][1])))}!g||e&&Br(e,d)||t.point(d[0],d[1]),e=d,l=g,s=v},lineEnd:function(){l&&t.lineEnd(),e=null},clean:function(){return u|(c&&l)<<1}}},Fn(t,6*Ct),r?[0,-t]:[-At,t-At]);function i(t,r){return Math.cos(t)*Math.cos(r)>e}function a(t,r,n){var i=[1,0,0],a=zr(Pr(t),Pr(r)),o=Or(a,a),s=a[0],l=o-s*s;if(!l)return!n&&t;var c=e*o/l,u=-e*s/l,h=zr(i,a),f=Dr(i,c);Ir(f,Dr(a,u));var p=h,d=Or(f,p),g=Or(p,p),v=d*d-g*(Or(f,f)-1);if(!(v<0)){var m=Math.sqrt(v),x=Dr(p,(-d-m)/g);if(Ir(x,f),x=Fr(x),!n)return x;var b,_=t[0],w=r[0],k=t[1],T=r[1];w<_&&(b=_,_=w,w=b);var A=w-_,M=y(A-At)<kt;if(!M&&T<k&&(b=k,k=T,T=b),M||A<kt?M?k+T>0^x[1]<(y(x[0]-_)<kt?k:T):k<=x[1]&&x[1]<=T:A>At^(_<=x[0]&&x[0]<=w)){var S=Dr(p,(-d+m)/g);return Ir(S,f),[x,Fr(S)]}}}function o(e,n){var i=r?t:At-t,a=0;return e<-i?a|=1:e>i&&(a|=2),n<-i?a|=4:n>i&&(a|=8),a}}((b=+t)*Ct),A()):b},w.clipExtent=function(t){return arguments.length?(_=t,x=t?nn(t[0][0],t[0][1],t[1][0],t[1][1]):P,A()):_},w.scale=function(t){return arguments.length?(c=+t,T()):c},w.translate=function(t){return arguments.length?(u=+t[0],h=+t[1],T()):[u,h]},w.center=function(t){return arguments.length?(f=t[0]%360*Ct,p=t[1]%360*Ct,T()):[f*Lt,p*Lt]},w.rotate=function(t){return arguments.length?(d=t[0]%360*Ct,g=t[1]%360*Ct,v=t.length>2?t[2]%360*Ct:0,T()):[d*Lt,g*Lt,v*Lt]},t.rebind(w,l,\"precision\"),function(){return r=e.apply(this,arguments),w.invert=r.invert&&k,T()}}function Ln(t){return Sn(t,function(e,r){t.point(e*Ct,r*Ct)})}function Pn(t,e){return[t,e]}function On(t,e){return[t>At?t-Mt:t<-At?t+Mt:t,e]}function zn(t,e,r){return t?e||r?Gr(Dn(t),Rn(e,r)):Dn(t):e||r?Rn(e,r):On}function In(t){return function(e,r){return[(e+=t)>At?e-Mt:e<-At?e+Mt:e,r]}}function Dn(t){var e=In(t);return e.invert=In(-t),e}function Rn(t,e){var r=Math.cos(t),n=Math.sin(t),i=Math.cos(e),a=Math.sin(e);function o(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*r+s*n;return[Math.atan2(l*i-u*a,s*r-c*n),It(u*i+l*a)]}return o.invert=function(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*i-l*a;return[Math.atan2(l*i+c*a,s*r+u*n),It(u*r-s*n)]},o}function Fn(t,e){var r=Math.cos(t),n=Math.sin(t);return function(i,a,o,s){var l=o*e;null!=i?(i=Bn(r,i),a=Bn(r,a),(o>0?i<a:i>a)&&(i+=o*Mt)):(i=t+o*Mt,a=t-.5*l);for(var c,u=i;o>0?u>a:u<a;u-=l)s.point((c=Fr([r,-n*Math.cos(u),-n*Math.sin(u)]))[0],c[1])}}function Bn(t,e){var r=Pr(e);r[0]-=t,Rr(r);var n=zt(-r[1]);return((-r[2]<0?-n:n)+2*Math.PI-kt)%(2*Math.PI)}function Nn(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map(function(e){return[t,e]})}}function jn(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map(function(e){return[e,t]})}}function Un(t){return t.source}function Vn(t){return t.target}t.geo.path=function(){var e,r,n,i,a,o=4.5;function s(e){return e&&(\"function\"==typeof o&&i.pointRadius(+o.apply(this,arguments)),a&&a.valid||(a=n(i)),t.geo.stream(e,a)),i.result()}function l(){return a=null,s}return s.area=function(e){return sn=0,t.geo.stream(e,n(pn)),sn},s.centroid=function(e){return xr=br=_r=wr=kr=Tr=Ar=Mr=Sr=0,t.geo.stream(e,n(xn)),Sr?[Ar/Sr,Mr/Sr]:Tr?[wr/Tr,kr/Tr]:_r?[xr/_r,br/_r]:[NaN,NaN]},s.bounds=function(e){return hn=fn=-(cn=un=1/0),t.geo.stream(e,n(gn)),[[cn,un],[hn,fn]]},s.projection=function(t){return arguments.length?(n=(e=t)?t.stream||(r=t,i=An(function(t,e){return r([t*Lt,e*Lt])}),function(t){return Ln(i(t))}):P,l()):e;var r,i},s.context=function(t){return arguments.length?(i=null==(r=t)?new vn:new Tn(t),\"function\"!=typeof o&&i.pointRadius(o),l()):r},s.pointRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:(i.pointRadius(+t),+t),s):o},s.projection(t.geo.albersUsa()).context(null)},t.geo.transform=function(t){return{stream:function(e){var r=new Mn(e);for(var n in t)r[n]=t[n];return r}}},Mn.prototype={point:function(t,e){this.stream.point(t,e)},sphere:function(){this.stream.sphere()},lineStart:function(){this.stream.lineStart()},lineEnd:function(){this.stream.lineEnd()},polygonStart:function(){this.stream.polygonStart()},polygonEnd:function(){this.stream.polygonEnd()}},t.geo.projection=En,t.geo.projectionMutator=Cn,(t.geo.equirectangular=function(){return En(Pn)}).raw=Pn.invert=Pn,t.geo.rotation=function(t){function e(e){return(e=t(e[0]*Ct,e[1]*Ct))[0]*=Lt,e[1]*=Lt,e}return t=zn(t[0]%360*Ct,t[1]*Ct,t.length>2?t[2]*Ct:0),e.invert=function(e){return(e=t.invert(e[0]*Ct,e[1]*Ct))[0]*=Lt,e[1]*=Lt,e},e},On.invert=Pn,t.geo.circle=function(){var t,e,r=[0,0],n=6;function i(){var t=\"function\"==typeof r?r.apply(this,arguments):r,n=zn(-t[0]*Ct,-t[1]*Ct,0).invert,i=[];return e(null,null,1,{point:function(t,e){i.push(t=n(t,e)),t[0]*=Lt,t[1]*=Lt}}),{type:\"Polygon\",coordinates:[i]}}return i.origin=function(t){return arguments.length?(r=t,i):r},i.angle=function(r){return arguments.length?(e=Fn((t=+r)*Ct,n*Ct),i):t},i.precision=function(r){return arguments.length?(e=Fn(t*Ct,(n=+r)*Ct),i):n},i.angle(90)},t.geo.distance=function(t,e){var r,n=(e[0]-t[0])*Ct,i=t[1]*Ct,a=e[1]*Ct,o=Math.sin(n),s=Math.cos(n),l=Math.sin(i),c=Math.cos(i),u=Math.sin(a),h=Math.cos(a);return Math.atan2(Math.sqrt((r=h*o)*r+(r=c*u-l*h*s)*r),l*u+c*h*s)},t.geo.graticule=function(){var e,r,n,i,a,o,s,l,c,u,h,f,p=10,d=p,g=90,v=360,m=2.5;function x(){return{type:\"MultiLineString\",coordinates:b()}}function b(){return t.range(Math.ceil(i/g)*g,n,g).map(h).concat(t.range(Math.ceil(l/v)*v,s,v).map(f)).concat(t.range(Math.ceil(r/p)*p,e,p).filter(function(t){return y(t%g)>kt}).map(c)).concat(t.range(Math.ceil(o/d)*d,a,d).filter(function(t){return y(t%v)>kt}).map(u))}return x.lines=function(){return b().map(function(t){return{type:\"LineString\",coordinates:t}})},x.outline=function(){return{type:\"Polygon\",coordinates:[h(i).concat(f(s).slice(1),h(n).reverse().slice(1),f(l).reverse().slice(1))]}},x.extent=function(t){return arguments.length?x.majorExtent(t).minorExtent(t):x.minorExtent()},x.majorExtent=function(t){return arguments.length?(i=+t[0][0],n=+t[1][0],l=+t[0][1],s=+t[1][1],i>n&&(t=i,i=n,n=t),l>s&&(t=l,l=s,s=t),x.precision(m)):[[i,l],[n,s]]},x.minorExtent=function(t){return arguments.length?(r=+t[0][0],e=+t[1][0],o=+t[0][1],a=+t[1][1],r>e&&(t=r,r=e,e=t),o>a&&(t=o,o=a,a=t),x.precision(m)):[[r,o],[e,a]]},x.step=function(t){return arguments.length?x.majorStep(t).minorStep(t):x.minorStep()},x.majorStep=function(t){return arguments.length?(g=+t[0],v=+t[1],x):[g,v]},x.minorStep=function(t){return arguments.length?(p=+t[0],d=+t[1],x):[p,d]},x.precision=function(t){return arguments.length?(m=+t,c=Nn(o,a,90),u=jn(r,e,m),h=Nn(l,s,90),f=jn(i,n,m),x):m},x.majorExtent([[-180,-90+kt],[180,90-kt]]).minorExtent([[-180,-80-kt],[180,80+kt]])},t.geo.greatArc=function(){var e,r,n=Un,i=Vn;function a(){return{type:\"LineString\",coordinates:[e||n.apply(this,arguments),r||i.apply(this,arguments)]}}return a.distance=function(){return t.geo.distance(e||n.apply(this,arguments),r||i.apply(this,arguments))},a.source=function(t){return arguments.length?(n=t,e=\"function\"==typeof t?null:t,a):n},a.target=function(t){return arguments.length?(i=t,r=\"function\"==typeof t?null:t,a):i},a.precision=function(){return arguments.length?a:0},a},t.geo.interpolate=function(t,e){return r=t[0]*Ct,n=t[1]*Ct,i=e[0]*Ct,a=e[1]*Ct,o=Math.cos(n),s=Math.sin(n),l=Math.cos(a),c=Math.sin(a),u=o*Math.cos(r),h=o*Math.sin(r),f=l*Math.cos(i),p=l*Math.sin(i),d=2*Math.asin(Math.sqrt(Rt(a-n)+o*l*Rt(i-r))),g=1/Math.sin(d),(v=d?function(t){var e=Math.sin(t*=d)*g,r=Math.sin(d-t)*g,n=r*u+e*f,i=r*h+e*p,a=r*s+e*c;return[Math.atan2(i,n)*Lt,Math.atan2(a,Math.sqrt(n*n+i*i))*Lt]}:function(){return[r*Lt,n*Lt]}).distance=d,v;var r,n,i,a,o,s,l,c,u,h,f,p,d,g,v},t.geo.length=function(e){return yn=0,t.geo.stream(e,qn),yn};var qn={sphere:D,point:D,lineStart:function(){var t,e,r;function n(n,i){var a=Math.sin(i*=Ct),o=Math.cos(i),s=y((n*=Ct)-t),l=Math.cos(s);yn+=Math.atan2(Math.sqrt((s=o*Math.sin(s))*s+(s=r*a-e*o*l)*s),e*a+r*o*l),t=n,e=a,r=o}qn.point=function(i,a){t=i*Ct,e=Math.sin(a*=Ct),r=Math.cos(a),qn.point=n},qn.lineEnd=function(){qn.point=qn.lineEnd=D}},lineEnd:D,polygonStart:D,polygonEnd:D};function Hn(t,e){function r(e,r){var n=Math.cos(e),i=Math.cos(r),a=t(n*i);return[a*i*Math.sin(e),a*Math.sin(r)]}return r.invert=function(t,r){var n=Math.sqrt(t*t+r*r),i=e(n),a=Math.sin(i),o=Math.cos(i);return[Math.atan2(t*a,n*o),Math.asin(n&&r*a/n)]},r}var Gn=Hn(function(t){return Math.sqrt(2/(1+t))},function(t){return 2*Math.asin(t/2)});(t.geo.azimuthalEqualArea=function(){return En(Gn)}).raw=Gn;var Yn=Hn(function(t){var e=Math.acos(t);return e&&e/Math.sin(e)},P);function Wn(t,e){var r=Math.cos(t),n=function(t){return Math.tan(At/4+t/2)},i=t===e?Math.sin(t):Math.log(r/Math.cos(e))/Math.log(n(e)/n(t)),a=r*Math.pow(n(t),i)/i;if(!i)return Jn;function o(t,e){a>0?e<-Et+kt&&(e=-Et+kt):e>Et-kt&&(e=Et-kt);var r=a/Math.pow(n(e),i);return[r*Math.sin(i*t),a-r*Math.cos(i*t)]}return o.invert=function(t,e){var r=a-e,n=Pt(i)*Math.sqrt(t*t+r*r);return[Math.atan2(t,r)/i,2*Math.atan(Math.pow(a/n,1/i))-Et]},o}function Xn(t,e){var r=Math.cos(t),n=t===e?Math.sin(t):(r-Math.cos(e))/(e-t),i=r/n+t;if(y(n)<kt)return Pn;function a(t,e){var r=i-e;return[r*Math.sin(n*t),i-r*Math.cos(n*t)]}return a.invert=function(t,e){var r=i-e;return[Math.atan2(t,r)/n,i-Pt(n)*Math.sqrt(t*t+r*r)]},a}(t.geo.azimuthalEquidistant=function(){return En(Yn)}).raw=Yn,(t.geo.conicConformal=function(){return an(Wn)}).raw=Wn,(t.geo.conicEquidistant=function(){return an(Xn)}).raw=Xn;var Zn=Hn(function(t){return 1/t},Math.atan);function Jn(t,e){return[t,Math.log(Math.tan(At/4+e/2))]}function Kn(t){var e,r=En(t),n=r.scale,i=r.translate,a=r.clipExtent;return r.scale=function(){var t=n.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.translate=function(){var t=i.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.clipExtent=function(t){var o=a.apply(r,arguments);if(o===r){if(e=null==t){var s=At*n(),l=i();a([[l[0]-s,l[1]-s],[l[0]+s,l[1]+s]])}}else e&&(o=null);return o},r.clipExtent(null)}(t.geo.gnomonic=function(){return En(Zn)}).raw=Zn,Jn.invert=function(t,e){return[t,2*Math.atan(Math.exp(e))-Et]},(t.geo.mercator=function(){return Kn(Jn)}).raw=Jn;var $n=Hn(function(){return 1},Math.asin);(t.geo.orthographic=function(){return En($n)}).raw=$n;var Qn=Hn(function(t){return 1/(1+t)},function(t){return 2*Math.atan(t)});function ti(t,e){return[Math.log(Math.tan(At/4+e/2)),-t]}function ei(t){return t[0]}function ri(t){return t[1]}function ni(t){for(var e=t.length,r=[0,1],n=2,i=2;i<e;i++){for(;n>1&&Ot(t[r[n-2]],t[r[n-1]],t[i])<=0;)--n;r[n++]=i}return r.slice(0,n)}function ii(t,e){return t[0]-e[0]||t[1]-e[1]}(t.geo.stereographic=function(){return En(Qn)}).raw=Qn,ti.invert=function(t,e){return[-e,2*Math.atan(Math.exp(t))-Et]},(t.geo.transverseMercator=function(){var t=Kn(ti),e=t.center,r=t.rotate;return t.center=function(t){return t?e([-t[1],t[0]]):[(t=e())[1],-t[0]]},t.rotate=function(t){return t?r([t[0],t[1],t.length>2?t[2]+90:90]):[(t=r())[0],t[1],t[2]-90]},r([0,0,90])}).raw=ti,t.geom={},t.geom.hull=function(t){var e=ei,r=ri;if(arguments.length)return n(t);function n(t){if(t.length<3)return[];var n,i=ve(e),a=ve(r),o=t.length,s=[],l=[];for(n=0;n<o;n++)s.push([+i.call(this,t[n],n),+a.call(this,t[n],n),n]);for(s.sort(ii),n=0;n<o;n++)l.push([s[n][0],-s[n][1]]);var c=ni(s),u=ni(l),h=u[0]===c[0],f=u[u.length-1]===c[c.length-1],p=[];for(n=c.length-1;n>=0;--n)p.push(t[s[c[n]][2]]);for(n=+h;n<u.length-f;++n)p.push(t[s[u[n]][2]]);return p}return n.x=function(t){return arguments.length?(e=t,n):e},n.y=function(t){return arguments.length?(r=t,n):r},n},t.geom.polygon=function(t){return V(t,ai),t};var ai=t.geom.polygon.prototype=[];function oi(t,e,r){return(r[0]-e[0])*(t[1]-e[1])<(r[1]-e[1])*(t[0]-e[0])}function si(t,e,r,n){var i=t[0],a=r[0],o=e[0]-i,s=n[0]-a,l=t[1],c=r[1],u=e[1]-l,h=n[1]-c,f=(s*(l-c)-h*(i-a))/(h*o-s*u);return[i+f*o,l+f*u]}function li(t){var e=t[0],r=t[t.length-1];return!(e[0]-r[0]||e[1]-r[1])}ai.area=function(){for(var t,e=-1,r=this.length,n=this[r-1],i=0;++e<r;)t=n,n=this[e],i+=t[1]*n[0]-t[0]*n[1];return.5*i},ai.centroid=function(t){var e,r,n=-1,i=this.length,a=0,o=0,s=this[i-1];for(arguments.length||(t=-1/(6*this.area()));++n<i;)e=s,s=this[n],r=e[0]*s[1]-s[0]*e[1],a+=(e[0]+s[0])*r,o+=(e[1]+s[1])*r;return[a*t,o*t]},ai.clip=function(t){for(var e,r,n,i,a,o,s=li(t),l=-1,c=this.length-li(this),u=this[c-1];++l<c;){for(e=t.slice(),t.length=0,i=this[l],a=e[(n=e.length-s)-1],r=-1;++r<n;)oi(o=e[r],u,i)?(oi(a,u,i)||t.push(si(a,o,u,i)),t.push(o)):oi(a,u,i)&&t.push(si(a,o,u,i)),a=o;s&&t.push(t[0]),u=i}return t};var ci,ui,hi,fi,pi,di=[],gi=[];function vi(){Ii(this),this.edge=this.site=this.circle=null}function mi(t){var e=di.pop()||new vi;return e.site=t,e}function yi(t){Si(t),hi.remove(t),di.push(t),Ii(t)}function xi(t){var e=t.circle,r=e.x,n=e.cy,i={x:r,y:n},a=t.P,o=t.N,s=[t];yi(t);for(var l=a;l.circle&&y(r-l.circle.x)<kt&&y(n-l.circle.cy)<kt;)a=l.P,s.unshift(l),yi(l),l=a;s.unshift(l),Si(l);for(var c=o;c.circle&&y(r-c.circle.x)<kt&&y(n-c.circle.cy)<kt;)o=c.N,s.push(c),yi(c),c=o;s.push(c),Si(c);var u,h=s.length;for(u=1;u<h;++u)c=s[u],l=s[u-1],Pi(c.edge,l.site,c.site,i);l=s[0],(c=s[h-1]).edge=Li(l.site,c.site,null,i),Mi(l),Mi(c)}function bi(t){for(var e,r,n,i,a=t.x,o=t.y,s=hi._;s;)if((n=_i(s,o)-a)>kt)s=s.L;else{if(!((i=a-wi(s,o))>kt)){n>-kt?(e=s.P,r=s):i>-kt?(e=s,r=s.N):e=r=s;break}if(!s.R){e=s;break}s=s.R}var l=mi(t);if(hi.insert(e,l),e||r){if(e===r)return Si(e),r=mi(e.site),hi.insert(l,r),l.edge=r.edge=Li(e.site,l.site),Mi(e),void Mi(r);if(r){Si(e),Si(r);var c=e.site,u=c.x,h=c.y,f=t.x-u,p=t.y-h,d=r.site,g=d.x-u,v=d.y-h,m=2*(f*v-p*g),y=f*f+p*p,x=g*g+v*v,b={x:(v*y-p*x)/m+u,y:(f*x-g*y)/m+h};Pi(r.edge,c,d,b),l.edge=Li(c,t,null,b),r.edge=Li(t,d,null,b),Mi(e),Mi(r)}else l.edge=Li(e.site,l.site)}}function _i(t,e){var r=t.site,n=r.x,i=r.y,a=i-e;if(!a)return n;var o=t.P;if(!o)return-1/0;var s=(r=o.site).x,l=r.y,c=l-e;if(!c)return s;var u=s-n,h=1/a-1/c,f=u/c;return h?(-f+Math.sqrt(f*f-2*h*(u*u/(-2*c)-l+c/2+i-a/2)))/h+n:(n+s)/2}function wi(t,e){var r=t.N;if(r)return _i(r,e);var n=t.site;return n.y===e?n.x:1/0}function ki(t){this.site=t,this.edges=[]}function Ti(t,e){return e.angle-t.angle}function Ai(){Ii(this),this.x=this.y=this.arc=this.site=this.cy=null}function Mi(t){var e=t.P,r=t.N;if(e&&r){var n=e.site,i=t.site,a=r.site;if(n!==a){var o=i.x,s=i.y,l=n.x-o,c=n.y-s,u=a.x-o,h=2*(l*(v=a.y-s)-c*u);if(!(h>=-Tt)){var f=l*l+c*c,p=u*u+v*v,d=(v*f-c*p)/h,g=(l*p-u*f)/h,v=g+s,m=gi.pop()||new Ai;m.arc=t,m.site=i,m.x=d+o,m.y=v+Math.sqrt(d*d+g*g),m.cy=v,t.circle=m;for(var y=null,x=pi._;x;)if(m.y<x.y||m.y===x.y&&m.x<=x.x){if(!x.L){y=x.P;break}x=x.L}else{if(!x.R){y=x;break}x=x.R}pi.insert(y,m),y||(fi=m)}}}}function Si(t){var e=t.circle;e&&(e.P||(fi=e.N),pi.remove(e),gi.push(e),Ii(e),t.circle=null)}function Ei(t,e){var r=t.b;if(r)return!0;var n,i,a=t.a,o=e[0][0],s=e[1][0],l=e[0][1],c=e[1][1],u=t.l,h=t.r,f=u.x,p=u.y,d=h.x,g=h.y,v=(f+d)/2,m=(p+g)/2;if(g===p){if(v<o||v>=s)return;if(f>d){if(a){if(a.y>=c)return}else a={x:v,y:l};r={x:v,y:c}}else{if(a){if(a.y<l)return}else a={x:v,y:c};r={x:v,y:l}}}else if(i=m-(n=(f-d)/(g-p))*v,n<-1||n>1)if(f>d){if(a){if(a.y>=c)return}else a={x:(l-i)/n,y:l};r={x:(c-i)/n,y:c}}else{if(a){if(a.y<l)return}else a={x:(c-i)/n,y:c};r={x:(l-i)/n,y:l}}else if(p<g){if(a){if(a.x>=s)return}else a={x:o,y:n*o+i};r={x:s,y:n*s+i}}else{if(a){if(a.x<o)return}else a={x:s,y:n*s+i};r={x:o,y:n*o+i}}return t.a=a,t.b=r,!0}function Ci(t,e){this.l=t,this.r=e,this.a=this.b=null}function Li(t,e,r,n){var i=new Ci(t,e);return ci.push(i),r&&Pi(i,t,e,r),n&&Pi(i,e,t,n),ui[t.i].edges.push(new Oi(i,t,e)),ui[e.i].edges.push(new Oi(i,e,t)),i}function Pi(t,e,r,n){t.a||t.b?t.l===r?t.b=n:t.a=n:(t.a=n,t.l=e,t.r=r)}function Oi(t,e,r){var n=t.a,i=t.b;this.edge=t,this.site=e,this.angle=r?Math.atan2(r.y-e.y,r.x-e.x):t.l===e?Math.atan2(i.x-n.x,n.y-i.y):Math.atan2(n.x-i.x,i.y-n.y)}function zi(){this._=null}function Ii(t){t.U=t.C=t.L=t.R=t.P=t.N=null}function Di(t,e){var r=e,n=e.R,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.R=n.L,r.R&&(r.R.U=r),n.L=r}function Ri(t,e){var r=e,n=e.L,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.L=n.R,r.L&&(r.L.U=r),n.R=r}function Fi(t){for(;t.L;)t=t.L;return t}function Bi(t,e){var r,n,i,a=t.sort(Ni).pop();for(ci=[],ui=new Array(t.length),hi=new zi,pi=new zi;;)if(i=fi,a&&(!i||a.y<i.y||a.y===i.y&&a.x<i.x))a.x===r&&a.y===n||(ui[a.i]=new ki(a),bi(a),r=a.x,n=a.y),a=t.pop();else{if(!i)break;xi(i.arc)}e&&(function(t){for(var e,r=ci,n=en(t[0][0],t[0][1],t[1][0],t[1][1]),i=r.length;i--;)(!Ei(e=r[i],t)||!n(e)||y(e.a.x-e.b.x)<kt&&y(e.a.y-e.b.y)<kt)&&(e.a=e.b=null,r.splice(i,1))}(e),function(t){for(var e,r,n,i,a,o,s,l,c,u,h=t[0][0],f=t[1][0],p=t[0][1],d=t[1][1],g=ui,v=g.length;v--;)if((a=g[v])&&a.prepare())for(l=(s=a.edges).length,o=0;o<l;)n=(u=s[o].end()).x,i=u.y,e=(c=s[++o%l].start()).x,r=c.y,(y(n-e)>kt||y(i-r)>kt)&&(s.splice(o,0,new Oi((m=a.site,x=u,b=y(n-h)<kt&&d-i>kt?{x:h,y:y(e-h)<kt?r:d}:y(i-d)<kt&&f-n>kt?{x:y(r-d)<kt?e:f,y:d}:y(n-f)<kt&&i-p>kt?{x:f,y:y(e-f)<kt?r:p}:y(i-p)<kt&&n-h>kt?{x:y(r-p)<kt?e:h,y:p}:null,_=void 0,_=new Ci(m,null),_.a=x,_.b=b,ci.push(_),_),a.site,null)),++l);var m,x,b,_}(e));var o={cells:ui,edges:ci};return hi=pi=ci=ui=null,o}function Ni(t,e){return e.y-t.y||e.x-t.x}ki.prototype.prepare=function(){for(var t,e=this.edges,r=e.length;r--;)(t=e[r].edge).b&&t.a||e.splice(r,1);return e.sort(Ti),e.length},Oi.prototype={start:function(){return this.edge.l===this.site?this.edge.a:this.edge.b},end:function(){return this.edge.l===this.site?this.edge.b:this.edge.a}},zi.prototype={insert:function(t,e){var r,n,i;if(t){if(e.P=t,e.N=t.N,t.N&&(t.N.P=e),t.N=e,t.R){for(t=t.R;t.L;)t=t.L;t.L=e}else t.R=e;r=t}else this._?(t=Fi(this._),e.P=null,e.N=t,t.P=t.L=e,r=t):(e.P=e.N=null,this._=e,r=null);for(e.L=e.R=null,e.U=r,e.C=!0,t=e;r&&r.C;)r===(n=r.U).L?(i=n.R)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.R&&(Di(this,r),r=(t=r).U),r.C=!1,n.C=!0,Ri(this,n)):(i=n.L)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.L&&(Ri(this,r),r=(t=r).U),r.C=!1,n.C=!0,Di(this,n)),r=t.U;this._.C=!1},remove:function(t){t.N&&(t.N.P=t.P),t.P&&(t.P.N=t.N),t.N=t.P=null;var e,r,n,i=t.U,a=t.L,o=t.R;if(r=a?o?Fi(o):a:o,i?i.L===t?i.L=r:i.R=r:this._=r,a&&o?(n=r.C,r.C=t.C,r.L=a,a.U=r,r!==o?(i=r.U,r.U=t.U,t=r.R,i.L=t,r.R=o,o.U=r):(r.U=i,i=r,t=r.R)):(n=t.C,t=r),t&&(t.U=i),!n)if(t&&t.C)t.C=!1;else{do{if(t===this._)break;if(t===i.L){if((e=i.R).C&&(e.C=!1,i.C=!0,Di(this,i),e=i.R),e.L&&e.L.C||e.R&&e.R.C){e.R&&e.R.C||(e.L.C=!1,e.C=!0,Ri(this,e),e=i.R),e.C=i.C,i.C=e.R.C=!1,Di(this,i),t=this._;break}}else if((e=i.L).C&&(e.C=!1,i.C=!0,Ri(this,i),e=i.L),e.L&&e.L.C||e.R&&e.R.C){e.L&&e.L.C||(e.R.C=!1,e.C=!0,Di(this,e),e=i.L),e.C=i.C,i.C=e.L.C=!1,Ri(this,i),t=this._;break}e.C=!0,t=i,i=i.U}while(!t.C);t&&(t.C=!1)}}},t.geom.voronoi=function(t){var e=ei,r=ri,n=e,i=r,a=ji;if(t)return o(t);function o(t){var e=new Array(t.length),r=a[0][0],n=a[0][1],i=a[1][0],o=a[1][1];return Bi(s(t),a).cells.forEach(function(a,s){var l=a.edges,c=a.site;(e[s]=l.length?l.map(function(t){var e=t.start();return[e.x,e.y]}):c.x>=r&&c.x<=i&&c.y>=n&&c.y<=o?[[r,o],[i,o],[i,n],[r,n]]:[]).point=t[s]}),e}function s(t){return t.map(function(t,e){return{x:Math.round(n(t,e)/kt)*kt,y:Math.round(i(t,e)/kt)*kt,i:e}})}return o.links=function(t){return Bi(s(t)).edges.filter(function(t){return t.l&&t.r}).map(function(e){return{source:t[e.l.i],target:t[e.r.i]}})},o.triangles=function(t){var e=[];return Bi(s(t)).cells.forEach(function(r,n){for(var i,a,o,s,l=r.site,c=r.edges.sort(Ti),u=-1,h=c.length,f=c[h-1].edge,p=f.l===l?f.r:f.l;++u<h;)f,i=p,p=(f=c[u].edge).l===l?f.r:f.l,n<i.i&&n<p.i&&(o=i,s=p,((a=l).x-s.x)*(o.y-a.y)-(a.x-o.x)*(s.y-a.y)<0)&&e.push([t[n],t[i.i],t[p.i]])}),e},o.x=function(t){return arguments.length?(n=ve(e=t),o):e},o.y=function(t){return arguments.length?(i=ve(r=t),o):r},o.clipExtent=function(t){return arguments.length?(a=null==t?ji:t,o):a===ji?null:a},o.size=function(t){return arguments.length?o.clipExtent(t&&[[0,0],t]):a===ji?null:a&&a[1]},o};var ji=[[-1e6,-1e6],[1e6,1e6]];function Ui(t){return t.x}function Vi(t){return t.y}function qi(e,r){e=t.rgb(e),r=t.rgb(r);var n=e.r,i=e.g,a=e.b,o=r.r-n,s=r.g-i,l=r.b-a;return function(t){return\"#\"+ce(Math.round(n+o*t))+ce(Math.round(i+s*t))+ce(Math.round(a+l*t))}}function Hi(t,e){var r,n={},i={};for(r in t)r in e?n[r]=Zi(t[r],e[r]):i[r]=t[r];for(r in e)r in t||(i[r]=e[r]);return function(t){for(r in n)i[r]=n[r](t);return i}}function Gi(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function Yi(t,e){var r,n,i,a=Wi.lastIndex=Xi.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=Wi.exec(t))&&(n=Xi.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:Gi(r,n)})),a=Xi.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?(e=l[0].x,function(t){return e(t)+\"\"}):function(){return e}:(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}t.geom.delaunay=function(e){return t.geom.voronoi().triangles(e)},t.geom.quadtree=function(t,e,r,n,i){var a,o=ei,s=ri;if(a=arguments.length)return o=Ui,s=Vi,3===a&&(i=r,n=e,r=e=0),l(t);function l(t){var l,c,u,h,f,p,d,g,v,m=ve(o),x=ve(s);if(null!=e)p=e,d=r,g=n,v=i;else if(g=v=-(p=d=1/0),c=[],u=[],f=t.length,a)for(h=0;h<f;++h)(l=t[h]).x<p&&(p=l.x),l.y<d&&(d=l.y),l.x>g&&(g=l.x),l.y>v&&(v=l.y),c.push(l.x),u.push(l.y);else for(h=0;h<f;++h){var b=+m(l=t[h],h),_=+x(l,h);b<p&&(p=b),_<d&&(d=_),b>g&&(g=b),_>v&&(v=_),c.push(b),u.push(_)}var w=g-p,k=v-d;function T(t,e,r,n,i,a,o,s){if(!isNaN(r)&&!isNaN(n))if(t.leaf){var l=t.x,c=t.y;if(null!=l)if(y(l-r)+y(c-n)<.01)A(t,e,r,n,i,a,o,s);else{var u=t.point;t.x=t.y=t.point=null,A(t,u,l,c,i,a,o,s),A(t,e,r,n,i,a,o,s)}else t.x=r,t.y=n,t.point=e}else A(t,e,r,n,i,a,o,s)}function A(t,e,r,n,i,a,o,s){var l=.5*(i+o),c=.5*(a+s),u=r>=l,h=n>=c,f=h<<1|u;t.leaf=!1,u?i=l:o=l,h?a=c:s=c,T(t=t.nodes[f]||(t.nodes[f]={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){T(M,t,+m(t,++h),+x(t,h),p,d,g,v)}}),e,r,n,i,a,o,s)}w>k?v=d+w:g=p+k;var M={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){T(M,t,+m(t,++h),+x(t,h),p,d,g,v)}};if(M.visit=function(t){!function t(e,r,n,i,a,o){if(!e(r,n,i,a,o)){var s=.5*(n+a),l=.5*(i+o),c=r.nodes;c[0]&&t(e,c[0],n,i,s,l),c[1]&&t(e,c[1],s,i,a,l),c[2]&&t(e,c[2],n,l,s,o),c[3]&&t(e,c[3],s,l,a,o)}}(t,M,p,d,g,v)},M.find=function(t){return function(t,e,r,n,i,a,o){var s,l=1/0;return function t(c,u,h,f,p){if(!(u>a||h>o||f<n||p<i)){if(d=c.point){var d,g=e-c.x,v=r-c.y,m=g*g+v*v;if(m<l){var y=Math.sqrt(l=m);n=e-y,i=r-y,a=e+y,o=r+y,s=d}}for(var x=c.nodes,b=.5*(u+f),_=.5*(h+p),w=(r>=_)<<1|e>=b,k=w+4;w<k;++w)if(c=x[3&w])switch(3&w){case 0:t(c,u,h,b,_);break;case 1:t(c,b,h,f,_);break;case 2:t(c,u,_,b,p);break;case 3:t(c,b,_,f,p)}}}(t,n,i,a,o),s}(M,t[0],t[1],p,d,g,v)},h=-1,null==e){for(;++h<f;)T(M,t[h],c[h],u[h],p,d,g,v);--h}else t.forEach(M.add);return c=u=t=l=null,M}return l.x=function(t){return arguments.length?(o=t,l):o},l.y=function(t){return arguments.length?(s=t,l):s},l.extent=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=+t[0][0],r=+t[0][1],n=+t[1][0],i=+t[1][1]),l):null==e?null:[[e,r],[n,i]]},l.size=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=r=0,n=+t[0],i=+t[1]),l):null==e?null:[n-e,i-r]},l},t.interpolateRgb=qi,t.interpolateObject=Hi,t.interpolateNumber=Gi,t.interpolateString=Yi;var Wi=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,Xi=new RegExp(Wi.source,\"g\");function Zi(e,r){for(var n,i=t.interpolators.length;--i>=0&&!(n=t.interpolators[i](e,r)););return n}function Ji(t,e){var r,n=[],i=[],a=t.length,o=e.length,s=Math.min(t.length,e.length);for(r=0;r<s;++r)n.push(Zi(t[r],e[r]));for(;r<a;++r)i[r]=t[r];for(;r<o;++r)i[r]=e[r];return function(t){for(r=0;r<s;++r)i[r]=n[r](t);return i}}t.interpolate=Zi,t.interpolators=[function(t,e){var r=typeof e;return(\"string\"===r?ge.has(e.toLowerCase())||/^(#|rgb\\(|hsl\\()/i.test(e)?qi:Yi:e instanceof Ut?qi:Array.isArray(e)?Ji:\"object\"===r&&isNaN(e)?Hi:Gi)(t,e)}],t.interpolateArray=Ji;var Ki=function(){return P},$i=t.map({linear:Ki,poly:function(t){return function(e){return Math.pow(e,t)}},quad:function(){return ra},cubic:function(){return na},sin:function(){return aa},exp:function(){return oa},circle:function(){return sa},elastic:function(t,e){var r;arguments.length<2&&(e=.45);arguments.length?r=e/Mt*Math.asin(1/t):(t=1,r=e/4);return function(n){return 1+t*Math.pow(2,-10*n)*Math.sin((n-r)*Mt/e)}},back:function(t){t||(t=1.70158);return function(e){return e*e*((t+1)*e-t)}},bounce:function(){return la}}),Qi=t.map({in:P,out:ta,\"in-out\":ea,\"out-in\":function(t){return ea(ta(t))}});function ta(t){return function(e){return 1-t(1-e)}}function ea(t){return function(e){return.5*(e<.5?t(2*e):2-t(2-2*e))}}function ra(t){return t*t}function na(t){return t*t*t}function ia(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}function aa(t){return 1-Math.cos(t*Et)}function oa(t){return Math.pow(2,10*(t-1))}function sa(t){return 1-Math.sqrt(1-t*t)}function la(t){return t<1/2.75?7.5625*t*t:t<2/2.75?7.5625*(t-=1.5/2.75)*t+.75:t<2.5/2.75?7.5625*(t-=2.25/2.75)*t+.9375:7.5625*(t-=2.625/2.75)*t+.984375}function ca(t,e){return e-=t,function(r){return Math.round(t+e*r)}}function ua(t){var e,r,n,i=[t.a,t.b],a=[t.c,t.d],o=fa(i),s=ha(i,a),l=fa(((e=a)[0]+=(n=-s)*(r=i)[0],e[1]+=n*r[1],e))||0;i[0]*a[1]<a[0]*i[1]&&(i[0]*=-1,i[1]*=-1,o*=-1,s*=-1),this.rotate=(o?Math.atan2(i[1],i[0]):Math.atan2(-a[0],a[1]))*Lt,this.translate=[t.e,t.f],this.scale=[o,l],this.skew=l?Math.atan2(s,l)*Lt:0}function ha(t,e){return t[0]*e[0]+t[1]*e[1]}function fa(t){var e=Math.sqrt(ha(t,t));return e&&(t[0]/=e,t[1]/=e),e}t.ease=function(t){var e,n=t.indexOf(\"-\"),i=n>=0?t.slice(0,n):t,a=n>=0?t.slice(n+1):\"in\";return i=$i.get(i)||Ki,a=Qi.get(a)||P,e=a(i.apply(null,r.call(arguments,1))),function(t){return t<=0?0:t>=1?1:e(t)}},t.interpolateHcl=function(e,r){e=t.hcl(e),r=t.hcl(r);var n=e.h,i=e.c,a=e.l,o=r.h-n,s=r.c-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.c:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Wt(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateHsl=function(e,r){e=t.hsl(e),r=t.hsl(r);var n=e.h,i=e.s,a=e.l,o=r.h-n,s=r.s-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.s:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Ht(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateLab=function(e,r){e=t.lab(e),r=t.lab(r);var n=e.l,i=e.a,a=e.b,o=r.l-n,s=r.a-i,l=r.b-a;return function(t){return te(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateRound=ca,t.transform=function(e){var r=i.createElementNS(t.ns.prefix.svg,\"g\");return(t.transform=function(t){if(null!=t){r.setAttribute(\"transform\",t);var e=r.transform.baseVal.consolidate()}return new ua(e?e.matrix:pa)})(e)},ua.prototype.toString=function(){return\"translate(\"+this.translate+\")rotate(\"+this.rotate+\")skewX(\"+this.skew+\")scale(\"+this.scale+\")\"};var pa={a:1,b:0,c:0,d:1,e:0,f:0};function da(t){return t.length?t.pop()+\",\":\"\"}function ga(e,r){var n=[],i=[];return e=t.transform(e),r=t.transform(r),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(\"translate(\",null,\",\",null,\")\");n.push({i:i-4,x:Gi(t[0],e[0])},{i:i-2,x:Gi(t[1],e[1])})}else(e[0]||e[1])&&r.push(\"translate(\"+e+\")\")}(e.translate,r.translate,n,i),function(t,e,r,n){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),n.push({i:r.push(da(r)+\"rotate(\",null,\")\")-2,x:Gi(t,e)})):e&&r.push(da(r)+\"rotate(\"+e+\")\")}(e.rotate,r.rotate,n,i),function(t,e,r,n){t!==e?n.push({i:r.push(da(r)+\"skewX(\",null,\")\")-2,x:Gi(t,e)}):e&&r.push(da(r)+\"skewX(\"+e+\")\")}(e.skew,r.skew,n,i),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(da(r)+\"scale(\",null,\",\",null,\")\");n.push({i:i-4,x:Gi(t[0],e[0])},{i:i-2,x:Gi(t[1],e[1])})}else 1===e[0]&&1===e[1]||r.push(da(r)+\"scale(\"+e+\")\")}(e.scale,r.scale,n,i),e=r=null,function(t){for(var e,r=-1,a=i.length;++r<a;)n[(e=i[r]).i]=e.x(t);return n.join(\"\")}}function va(t,e){return e=(e-=t=+t)||1/e,function(r){return(r-t)/e}}function ma(t,e){return e=(e-=t=+t)||1/e,function(r){return Math.max(0,Math.min(1,(r-t)/e))}}function ya(t){for(var e=t.source,r=t.target,n=function(t,e){if(t===e)return t;var r=xa(t),n=xa(e),i=r.pop(),a=n.pop(),o=null;for(;i===a;)o=i,i=r.pop(),a=n.pop();return o}(e,r),i=[e];e!==n;)e=e.parent,i.push(e);for(var a=i.length;r!==n;)i.splice(a,0,r),r=r.parent;return i}function xa(t){for(var e=[],r=t.parent;null!=r;)e.push(t),t=r,r=r.parent;return e.push(t),e}function ba(t){t.fixed|=2}function _a(t){t.fixed&=-7}function wa(t){t.fixed|=4,t.px=t.x,t.py=t.y}function ka(t){t.fixed&=-5}t.interpolateTransform=ga,t.layout={},t.layout.bundle=function(){return function(t){for(var e=[],r=-1,n=t.length;++r<n;)e.push(ya(t[r]));return e}},t.layout.chord=function(){var e,r,n,i,a,o,s,l={},c=0;function u(){var l,u,f,p,d,g={},v=[],m=t.range(i),y=[];for(e=[],r=[],l=0,p=-1;++p<i;){for(u=0,d=-1;++d<i;)u+=n[p][d];v.push(u),y.push(t.range(i)),l+=u}for(a&&m.sort(function(t,e){return a(v[t],v[e])}),o&&y.forEach(function(t,e){t.sort(function(t,r){return o(n[e][t],n[e][r])})}),l=(Mt-c*i)/l,u=0,p=-1;++p<i;){for(f=u,d=-1;++d<i;){var x=m[p],b=y[x][d],_=n[x][b],w=u,k=u+=_*l;g[x+\"-\"+b]={index:x,subindex:b,startAngle:w,endAngle:k,value:_}}r[x]={index:x,startAngle:f,endAngle:u,value:v[x]},u+=c}for(p=-1;++p<i;)for(d=p-1;++d<i;){var T=g[p+\"-\"+d],A=g[d+\"-\"+p];(T.value||A.value)&&e.push(T.value<A.value?{source:A,target:T}:{source:T,target:A})}s&&h()}function h(){e.sort(function(t,e){return s((t.source.value+t.target.value)/2,(e.source.value+e.target.value)/2)})}return l.matrix=function(t){return arguments.length?(i=(n=t)&&n.length,e=r=null,l):n},l.padding=function(t){return arguments.length?(c=t,e=r=null,l):c},l.sortGroups=function(t){return arguments.length?(a=t,e=r=null,l):a},l.sortSubgroups=function(t){return arguments.length?(o=t,e=null,l):o},l.sortChords=function(t){return arguments.length?(s=t,e&&h(),l):s},l.chords=function(){return e||u(),e},l.groups=function(){return r||u(),r},l},t.layout.force=function(){var e,r,n,i,a,o,s={},l=t.dispatch(\"start\",\"tick\",\"end\"),c=[1,1],u=.9,h=Ta,f=Aa,p=-30,d=Ma,g=.1,v=.64,m=[],y=[];function x(t){return function(e,r,n,i){if(e.point!==t){var a=e.cx-t.x,o=e.cy-t.y,s=i-r,l=a*a+o*o;if(s*s/v<l){if(l<d){var c=e.charge/l;t.px-=a*c,t.py-=o*c}return!0}if(e.point&&l&&l<d){c=e.pointCharge/l;t.px-=a*c,t.py-=o*c}}return!e.charge}}function b(e){e.px=t.event.x,e.py=t.event.y,s.resume()}return s.tick=function(){if((n*=.99)<.005)return e=null,l.end({type:\"end\",alpha:n=0}),!0;var r,s,h,f,d,v,b,_,w,k=m.length,T=y.length;for(s=0;s<T;++s)f=(h=y[s]).source,(v=(_=(d=h.target).x-f.x)*_+(w=d.y-f.y)*w)&&(_*=v=n*a[s]*((v=Math.sqrt(v))-i[s])/v,w*=v,d.x-=_*(b=f.weight+d.weight?f.weight/(f.weight+d.weight):.5),d.y-=w*b,f.x+=_*(b=1-b),f.y+=w*b);if((b=n*g)&&(_=c[0]/2,w=c[1]/2,s=-1,b))for(;++s<k;)(h=m[s]).x+=(_-h.x)*b,h.y+=(w-h.y)*b;if(p)for(!function t(e,r,n){var i=0,a=0;e.charge=0;if(!e.leaf)for(var o,s=e.nodes,l=s.length,c=-1;++c<l;)null!=(o=s[c])&&(t(o,r,n),e.charge+=o.charge,i+=o.charge*o.cx,a+=o.charge*o.cy);if(e.point){e.leaf||(e.point.x+=Math.random()-.5,e.point.y+=Math.random()-.5);var u=r*n[e.point.index];e.charge+=e.pointCharge=u,i+=u*e.point.x,a+=u*e.point.y}e.cx=i/e.charge;e.cy=a/e.charge}(r=t.geom.quadtree(m),n,o),s=-1;++s<k;)(h=m[s]).fixed||r.visit(x(h));for(s=-1;++s<k;)(h=m[s]).fixed?(h.x=h.px,h.y=h.py):(h.x-=(h.px-(h.px=h.x))*u,h.y-=(h.py-(h.py=h.y))*u);l.tick({type:\"tick\",alpha:n})},s.nodes=function(t){return arguments.length?(m=t,s):m},s.links=function(t){return arguments.length?(y=t,s):y},s.size=function(t){return arguments.length?(c=t,s):c},s.linkDistance=function(t){return arguments.length?(h=\"function\"==typeof t?t:+t,s):h},s.distance=s.linkDistance,s.linkStrength=function(t){return arguments.length?(f=\"function\"==typeof t?t:+t,s):f},s.friction=function(t){return arguments.length?(u=+t,s):u},s.charge=function(t){return arguments.length?(p=\"function\"==typeof t?t:+t,s):p},s.chargeDistance=function(t){return arguments.length?(d=t*t,s):Math.sqrt(d)},s.gravity=function(t){return arguments.length?(g=+t,s):g},s.theta=function(t){return arguments.length?(v=t*t,s):Math.sqrt(v)},s.alpha=function(t){return arguments.length?(t=+t,n?t>0?n=t:(e.c=null,e.t=NaN,e=null,l.end({type:\"end\",alpha:n=0})):t>0&&(l.start({type:\"start\",alpha:n=t}),e=Te(s.tick)),s):n},s.start=function(){var t,e,r,n=m.length,l=y.length,u=c[0],d=c[1];for(t=0;t<n;++t)(r=m[t]).index=t,r.weight=0;for(t=0;t<l;++t)\"number\"==typeof(r=y[t]).source&&(r.source=m[r.source]),\"number\"==typeof r.target&&(r.target=m[r.target]),++r.source.weight,++r.target.weight;for(t=0;t<n;++t)r=m[t],isNaN(r.x)&&(r.x=g(\"x\",u)),isNaN(r.y)&&(r.y=g(\"y\",d)),isNaN(r.px)&&(r.px=r.x),isNaN(r.py)&&(r.py=r.y);if(i=[],\"function\"==typeof h)for(t=0;t<l;++t)i[t]=+h.call(this,y[t],t);else for(t=0;t<l;++t)i[t]=h;if(a=[],\"function\"==typeof f)for(t=0;t<l;++t)a[t]=+f.call(this,y[t],t);else for(t=0;t<l;++t)a[t]=f;if(o=[],\"function\"==typeof p)for(t=0;t<n;++t)o[t]=+p.call(this,m[t],t);else for(t=0;t<n;++t)o[t]=p;function g(r,i){if(!e){for(e=new Array(n),c=0;c<n;++c)e[c]=[];for(c=0;c<l;++c){var a=y[c];e[a.source.index].push(a.target),e[a.target.index].push(a.source)}}for(var o,s=e[t],c=-1,u=s.length;++c<u;)if(!isNaN(o=s[c][r]))return o;return Math.random()*i}return s.resume()},s.resume=function(){return s.alpha(.1)},s.stop=function(){return s.alpha(0)},s.drag=function(){if(r||(r=t.behavior.drag().origin(P).on(\"dragstart.force\",ba).on(\"drag.force\",b).on(\"dragend.force\",_a)),!arguments.length)return r;this.on(\"mouseover.force\",wa).on(\"mouseout.force\",ka).call(r)},t.rebind(s,l,\"on\")};var Ta=20,Aa=1,Ma=1/0;function Sa(e,r){return t.rebind(e,r,\"sort\",\"children\",\"value\"),e.nodes=e,e.links=za,e}function Ea(t,e){for(var r=[t];null!=(t=r.pop());)if(e(t),(i=t.children)&&(n=i.length))for(var n,i;--n>=0;)r.push(i[n])}function Ca(t,e){for(var r=[t],n=[];null!=(t=r.pop());)if(n.push(t),(a=t.children)&&(i=a.length))for(var i,a,o=-1;++o<i;)r.push(a[o]);for(;null!=(t=n.pop());)e(t)}function La(t){return t.children}function Pa(t){return t.value}function Oa(t,e){return e.value-t.value}function za(e){return t.merge(e.map(function(t){return(t.children||[]).map(function(e){return{source:t,target:e}})}))}t.layout.hierarchy=function(){var t=Oa,e=La,r=Pa;function n(i){var a,o=[i],s=[];for(i.depth=0;null!=(a=o.pop());)if(s.push(a),(c=e.call(n,a,a.depth))&&(l=c.length)){for(var l,c,u;--l>=0;)o.push(u=c[l]),u.parent=a,u.depth=a.depth+1;r&&(a.value=0),a.children=c}else r&&(a.value=+r.call(n,a,a.depth)||0),delete a.children;return Ca(i,function(e){var n,i;t&&(n=e.children)&&n.sort(t),r&&(i=e.parent)&&(i.value+=e.value)}),s}return n.sort=function(e){return arguments.length?(t=e,n):t},n.children=function(t){return arguments.length?(e=t,n):e},n.value=function(t){return arguments.length?(r=t,n):r},n.revalue=function(t){return r&&(Ea(t,function(t){t.children&&(t.value=0)}),Ca(t,function(t){var e;t.children||(t.value=+r.call(n,t,t.depth)||0),(e=t.parent)&&(e.value+=t.value)})),t},n},t.layout.partition=function(){var e=t.layout.hierarchy(),r=[1,1];function n(t,n){var i=e.call(this,t,n);return function t(e,r,n,i){var a=e.children;if(e.x=r,e.y=e.depth*i,e.dx=n,e.dy=i,a&&(o=a.length)){var o,s,l,c=-1;for(n=e.value?n/e.value:0;++c<o;)t(s=a[c],r,l=s.value*n,i),r+=l}}(i[0],0,r[0],r[1]/function t(e){var r=e.children,n=0;if(r&&(i=r.length))for(var i,a=-1;++a<i;)n=Math.max(n,t(r[a]));return 1+n}(i[0])),i}return n.size=function(t){return arguments.length?(r=t,n):r},Sa(n,e)},t.layout.pie=function(){var e=Number,r=Ia,n=0,i=Mt,a=0;function o(s){var l,c=s.length,u=s.map(function(t,r){return+e.call(o,t,r)}),h=+(\"function\"==typeof n?n.apply(this,arguments):n),f=(\"function\"==typeof i?i.apply(this,arguments):i)-h,p=Math.min(Math.abs(f)/c,+(\"function\"==typeof a?a.apply(this,arguments):a)),d=p*(f<0?-1:1),g=t.sum(u),v=g?(f-c*d)/g:0,m=t.range(c),y=[];return null!=r&&m.sort(r===Ia?function(t,e){return u[e]-u[t]}:function(t,e){return r(s[t],s[e])}),m.forEach(function(t){y[t]={data:s[t],value:l=u[t],startAngle:h,endAngle:h+=l*v+d,padAngle:p}}),y}return o.value=function(t){return arguments.length?(e=t,o):e},o.sort=function(t){return arguments.length?(r=t,o):r},o.startAngle=function(t){return arguments.length?(n=t,o):n},o.endAngle=function(t){return arguments.length?(i=t,o):i},o.padAngle=function(t){return arguments.length?(a=t,o):a},o};var Ia={};function Da(t){return t.x}function Ra(t){return t.y}function Fa(t,e,r){t.y0=e,t.y=r}t.layout.stack=function(){var e=P,r=ja,n=Ua,i=Fa,a=Da,o=Ra;function s(l,c){if(!(p=l.length))return l;var u=l.map(function(t,r){return e.call(s,t,r)}),h=u.map(function(t){return t.map(function(t,e){return[a.call(s,t,e),o.call(s,t,e)]})}),f=r.call(s,h,c);u=t.permute(u,f),h=t.permute(h,f);var p,d,g,v,m=n.call(s,h,c),y=u[0].length;for(g=0;g<y;++g)for(i.call(s,u[0][g],v=m[g],h[0][g][1]),d=1;d<p;++d)i.call(s,u[d][g],v+=h[d-1][g][1],h[d][g][1]);return l}return s.values=function(t){return arguments.length?(e=t,s):e},s.order=function(t){return arguments.length?(r=\"function\"==typeof t?t:Ba.get(t)||ja,s):r},s.offset=function(t){return arguments.length?(n=\"function\"==typeof t?t:Na.get(t)||Ua,s):n},s.x=function(t){return arguments.length?(a=t,s):a},s.y=function(t){return arguments.length?(o=t,s):o},s.out=function(t){return arguments.length?(i=t,s):i},s};var Ba=t.map({\"inside-out\":function(e){var r,n,i=e.length,a=e.map(Va),o=e.map(qa),s=t.range(i).sort(function(t,e){return a[t]-a[e]}),l=0,c=0,u=[],h=[];for(r=0;r<i;++r)n=s[r],l<c?(l+=o[n],u.push(n)):(c+=o[n],h.push(n));return h.reverse().concat(u)},reverse:function(e){return t.range(e.length).reverse()},default:ja}),Na=t.map({silhouette:function(t){var e,r,n,i=t.length,a=t[0].length,o=[],s=0,l=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];n>s&&(s=n),o.push(n)}for(r=0;r<a;++r)l[r]=(s-o[r])/2;return l},wiggle:function(t){var e,r,n,i,a,o,s,l,c,u=t.length,h=t[0],f=h.length,p=[];for(p[0]=l=c=0,r=1;r<f;++r){for(e=0,i=0;e<u;++e)i+=t[e][r][1];for(e=0,a=0,s=h[r][0]-h[r-1][0];e<u;++e){for(n=0,o=(t[e][r][1]-t[e][r-1][1])/(2*s);n<e;++n)o+=(t[n][r][1]-t[n][r-1][1])/s;a+=o*t[e][r][1]}p[r]=l-=i?a/i*s:0,l<c&&(c=l)}for(r=0;r<f;++r)p[r]-=c;return p},expand:function(t){var e,r,n,i=t.length,a=t[0].length,o=1/i,s=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];if(n)for(e=0;e<i;e++)t[e][r][1]/=n;else for(e=0;e<i;e++)t[e][r][1]=o}for(r=0;r<a;++r)s[r]=0;return s},zero:Ua});function ja(e){return t.range(e.length)}function Ua(t){for(var e=-1,r=t[0].length,n=[];++e<r;)n[e]=0;return n}function Va(t){for(var e,r=1,n=0,i=t[0][1],a=t.length;r<a;++r)(e=t[r][1])>i&&(n=r,i=e);return n}function qa(t){return t.reduce(Ha,0)}function Ha(t,e){return t+e[1]}function Ga(t,e){return Ya(t,Math.ceil(Math.log(e.length)/Math.LN2+1))}function Ya(t,e){for(var r=-1,n=+t[0],i=(t[1]-n)/e,a=[];++r<=e;)a[r]=i*r+n;return a}function Wa(e){return[t.min(e),t.max(e)]}function Xa(t,e){return t.value-e.value}function Za(t,e){var r=t._pack_next;t._pack_next=e,e._pack_prev=t,e._pack_next=r,r._pack_prev=e}function Ja(t,e){t._pack_next=e,e._pack_prev=t}function Ka(t,e){var r=e.x-t.x,n=e.y-t.y,i=t.r+e.r;return.999*i*i>r*r+n*n}function $a(t){if((e=t.children)&&(l=e.length)){var e,r,n,i,a,o,s,l,c=1/0,u=-1/0,h=1/0,f=-1/0;if(e.forEach(Qa),(r=e[0]).x=-r.r,r.y=0,x(r),l>1&&((n=e[1]).x=n.r,n.y=0,x(n),l>2))for(eo(r,n,i=e[2]),x(i),Za(r,i),r._pack_prev=i,Za(i,n),n=r._pack_next,a=3;a<l;a++){eo(r,n,i=e[a]);var p=0,d=1,g=1;for(o=n._pack_next;o!==n;o=o._pack_next,d++)if(Ka(o,i)){p=1;break}if(1==p)for(s=r._pack_prev;s!==o._pack_prev&&!Ka(s,i);s=s._pack_prev,g++);p?(d<g||d==g&&n.r<r.r?Ja(r,n=o):Ja(r=s,n),a--):(Za(r,i),n=i,x(i))}var v=(c+u)/2,m=(h+f)/2,y=0;for(a=0;a<l;a++)(i=e[a]).x-=v,i.y-=m,y=Math.max(y,i.r+Math.sqrt(i.x*i.x+i.y*i.y));t.r=y,e.forEach(to)}function x(t){c=Math.min(t.x-t.r,c),u=Math.max(t.x+t.r,u),h=Math.min(t.y-t.r,h),f=Math.max(t.y+t.r,f)}}function Qa(t){t._pack_next=t._pack_prev=t}function to(t){delete t._pack_next,delete t._pack_prev}function eo(t,e,r){var n=t.r+r.r,i=e.x-t.x,a=e.y-t.y;if(n&&(i||a)){var o=e.r+r.r,s=i*i+a*a,l=.5+((n*=n)-(o*=o))/(2*s),c=Math.sqrt(Math.max(0,2*o*(n+s)-(n-=s)*n-o*o))/(2*s);r.x=t.x+l*i+c*a,r.y=t.y+l*a-c*i}else r.x=t.x+n,r.y=t.y}function ro(t,e){return t.parent==e.parent?1:2}function no(t){var e=t.children;return e.length?e[0]:t.t}function io(t){var e,r=t.children;return(e=r.length)?r[e-1]:t.t}function ao(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function oo(t,e,r){return t.a.parent===e.parent?t.a:r}function so(t){return{x:t.x,y:t.y,dx:t.dx,dy:t.dy}}function lo(t,e){var r=t.x+e[3],n=t.y+e[0],i=t.dx-e[1]-e[3],a=t.dy-e[0]-e[2];return i<0&&(r+=i/2,i=0),a<0&&(n+=a/2,a=0),{x:r,y:n,dx:i,dy:a}}function co(t){var e=t[0],r=t[t.length-1];return e<r?[e,r]:[r,e]}function uo(t){return t.rangeExtent?t.rangeExtent():co(t.range())}function ho(t,e,r,n){var i=r(t[0],t[1]),a=n(e[0],e[1]);return function(t){return a(i(t))}}function fo(t,e){var r,n=0,i=t.length-1,a=t[n],o=t[i];return o<a&&(r=n,n=i,i=r,r=a,a=o,o=r),t[n]=e.floor(a),t[i]=e.ceil(o),t}function po(t){return t?{floor:function(e){return Math.floor(e/t)*t},ceil:function(e){return Math.ceil(e/t)*t}}:go}t.layout.histogram=function(){var e=!0,r=Number,n=Wa,i=Ga;function a(a,o){for(var s,l,c=[],u=a.map(r,this),h=n.call(this,u,o),f=i.call(this,h,u,o),p=(o=-1,u.length),d=f.length-1,g=e?1:1/p;++o<d;)(s=c[o]=[]).dx=f[o+1]-(s.x=f[o]),s.y=0;if(d>0)for(o=-1;++o<p;)(l=u[o])>=h[0]&&l<=h[1]&&((s=c[t.bisect(f,l,1,d)-1]).y+=g,s.push(a[o]));return c}return a.value=function(t){return arguments.length?(r=t,a):r},a.range=function(t){return arguments.length?(n=ve(t),a):n},a.bins=function(t){return arguments.length?(i=\"number\"==typeof t?function(e){return Ya(e,t)}:ve(t),a):i},a.frequency=function(t){return arguments.length?(e=!!t,a):e},a},t.layout.pack=function(){var e,r=t.layout.hierarchy().sort(Xa),n=0,i=[1,1];function a(t,a){var o=r.call(this,t,a),s=o[0],l=i[0],c=i[1],u=null==e?Math.sqrt:\"function\"==typeof e?e:function(){return e};if(s.x=s.y=0,Ca(s,function(t){t.r=+u(t.value)}),Ca(s,$a),n){var h=n*(e?1:Math.max(2*s.r/l,2*s.r/c))/2;Ca(s,function(t){t.r+=h}),Ca(s,$a),Ca(s,function(t){t.r-=h})}return function t(e,r,n,i){var a=e.children;e.x=r+=i*e.x;e.y=n+=i*e.y;e.r*=i;if(a)for(var o=-1,s=a.length;++o<s;)t(a[o],r,n,i)}(s,l/2,c/2,e?1:1/Math.max(2*s.r/l,2*s.r/c)),o}return a.size=function(t){return arguments.length?(i=t,a):i},a.radius=function(t){return arguments.length?(e=null==t||\"function\"==typeof t?t:+t,a):e},a.padding=function(t){return arguments.length?(n=+t,a):n},Sa(a,r)},t.layout.tree=function(){var e=t.layout.hierarchy().sort(null).value(null),r=ro,n=[1,1],i=null;function a(t,a){var c=e.call(this,t,a),u=c[0],h=function(t){var e,r={A:null,children:[t]},n=[r];for(;null!=(e=n.pop());)for(var i,a=e.children,o=0,s=a.length;o<s;++o)n.push((a[o]=i={_:a[o],parent:e,children:(i=a[o].children)&&i.slice()||[],A:null,a:null,z:0,m:0,c:0,s:0,t:null,i:o}).a=i);return r.children[0]}(u);if(Ca(h,o),h.parent.m=-h.z,Ea(h,s),i)Ea(u,l);else{var f=u,p=u,d=u;Ea(u,function(t){t.x<f.x&&(f=t),t.x>p.x&&(p=t),t.depth>d.depth&&(d=t)});var g=r(f,p)/2-f.x,v=n[0]/(p.x+r(p,f)/2+g),m=n[1]/(d.depth||1);Ea(u,function(t){t.x=(t.x+g)*v,t.y=t.depth*m})}return c}function o(t){var e=t.children,n=t.parent.children,i=t.i?n[t.i-1]:null;if(e.length){!function(t){var e,r=0,n=0,i=t.children,a=i.length;for(;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(t);var a=(e[0].z+e[e.length-1].z)/2;i?(t.z=i.z+r(t._,i._),t.m=t.z-a):t.z=a}else i&&(t.z=i.z+r(t._,i._));t.parent.A=function(t,e,n){if(e){for(var i,a=t,o=t,s=e,l=a.parent.children[0],c=a.m,u=o.m,h=s.m,f=l.m;s=io(s),a=no(a),s&&a;)l=no(l),(o=io(o)).a=t,(i=s.z+h-a.z-c+r(s._,a._))>0&&(ao(oo(s,t,n),t,i),c+=i,u+=i),h+=s.m,c+=a.m,f+=l.m,u+=o.m;s&&!io(o)&&(o.t=s,o.m+=h-u),a&&!no(l)&&(l.t=a,l.m+=c-f,n=t)}return n}(t,i,t.parent.A||n[0])}function s(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function l(t){t.x*=n[0],t.y=t.depth*n[1]}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t)?l:null,a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null==(n=t)?null:l,a):i?n:null},Sa(a,e)},t.layout.cluster=function(){var e=t.layout.hierarchy().sort(null).value(null),r=ro,n=[1,1],i=!1;function a(a,o){var s,l=e.call(this,a,o),c=l[0],u=0;Ca(c,function(e){var n=e.children;n&&n.length?(e.x=function(t){return t.reduce(function(t,e){return t+e.x},0)/t.length}(n),e.y=function(e){return 1+t.max(e,function(t){return t.y})}(n)):(e.x=s?u+=r(e,s):0,e.y=0,s=e)});var h=function t(e){var r=e.children;return r&&r.length?t(r[0]):e}(c),f=function t(e){var r,n=e.children;return n&&(r=n.length)?t(n[r-1]):e}(c),p=h.x-r(h,f)/2,d=f.x+r(f,h)/2;return Ca(c,i?function(t){t.x=(t.x-c.x)*n[0],t.y=(c.y-t.y)*n[1]}:function(t){t.x=(t.x-p)/(d-p)*n[0],t.y=(1-(c.y?t.y/c.y:1))*n[1]}),l}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t),a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null!=(n=t),a):i?n:null},Sa(a,e)},t.layout.treemap=function(){var e,r=t.layout.hierarchy(),n=Math.round,i=[1,1],a=null,o=so,s=!1,l=\"squarify\",c=.5*(1+Math.sqrt(5));function u(t,e){for(var r,n,i=-1,a=t.length;++i<a;)n=(r=t[i]).value*(e<0?0:e),r.area=isNaN(n)||n<=0?0:n}function h(t){var e=t.children;if(e&&e.length){var r,n,i,a=o(t),s=[],c=e.slice(),f=1/0,g=\"slice\"===l?a.dx:\"dice\"===l?a.dy:\"slice-dice\"===l?1&t.depth?a.dy:a.dx:Math.min(a.dx,a.dy);for(u(c,a.dx*a.dy/t.value),s.area=0;(i=c.length)>0;)s.push(r=c[i-1]),s.area+=r.area,\"squarify\"!==l||(n=p(s,g))<=f?(c.pop(),f=n):(s.area-=s.pop().area,d(s,g,a,!1),g=Math.min(a.dx,a.dy),s.length=s.area=0,f=1/0);s.length&&(d(s,g,a,!0),s.length=s.area=0),e.forEach(h)}}function f(t){var e=t.children;if(e&&e.length){var r,n=o(t),i=e.slice(),a=[];for(u(i,n.dx*n.dy/t.value),a.area=0;r=i.pop();)a.push(r),a.area+=r.area,null!=r.z&&(d(a,r.z?n.dx:n.dy,n,!i.length),a.length=a.area=0);e.forEach(f)}}function p(t,e){for(var r,n=t.area,i=0,a=1/0,o=-1,s=t.length;++o<s;)(r=t[o].area)&&(r<a&&(a=r),r>i&&(i=r));return e*=e,(n*=n)?Math.max(e*i*c/n,n/(e*a*c)):1/0}function d(t,e,r,i){var a,o=-1,s=t.length,l=r.x,c=r.y,u=e?n(t.area/e):0;if(e==r.dx){for((i||u>r.dy)&&(u=r.dy);++o<s;)(a=t[o]).x=l,a.y=c,a.dy=u,l+=a.dx=Math.min(r.x+r.dx-l,u?n(a.area/u):0);a.z=!0,a.dx+=r.x+r.dx-l,r.y+=u,r.dy-=u}else{for((i||u>r.dx)&&(u=r.dx);++o<s;)(a=t[o]).x=l,a.y=c,a.dx=u,c+=a.dy=Math.min(r.y+r.dy-c,u?n(a.area/u):0);a.z=!1,a.dy+=r.y+r.dy-c,r.x+=u,r.dx-=u}}function g(t){var n=e||r(t),a=n[0];return a.x=a.y=0,a.value?(a.dx=i[0],a.dy=i[1]):a.dx=a.dy=0,e&&r.revalue(a),u([a],a.dx*a.dy/a.value),(e?f:h)(a),s&&(e=n),n}return g.size=function(t){return arguments.length?(i=t,g):i},g.padding=function(t){if(!arguments.length)return a;function e(e){return lo(e,t)}var r;return o=null==(a=t)?so:\"function\"==(r=typeof t)?function(e){var r=t.call(g,e,e.depth);return null==r?so(e):lo(e,\"number\"==typeof r?[r,r,r,r]:r)}:\"number\"===r?(t=[t,t,t,t],e):e,g},g.round=function(t){return arguments.length?(n=t?Math.round:Number,g):n!=Number},g.sticky=function(t){return arguments.length?(s=t,e=null,g):s},g.ratio=function(t){return arguments.length?(c=t,g):c},g.mode=function(t){return arguments.length?(l=t+\"\",g):l},Sa(g,r)},t.random={normal:function(t,e){var r=arguments.length;return r<2&&(e=1),r<1&&(t=0),function(){var r,n,i;do{i=(r=2*Math.random()-1)*r+(n=2*Math.random()-1)*n}while(!i||i>1);return t+e*r*Math.sqrt(-2*Math.log(i)/i)}},logNormal:function(){var e=t.random.normal.apply(t,arguments);return function(){return Math.exp(e())}},bates:function(e){var r=t.random.irwinHall(e);return function(){return r()/e}},irwinHall:function(t){return function(){for(var e=0,r=0;r<t;r++)e+=Math.random();return e}}},t.scale={};var go={floor:P,ceil:P};function vo(e,r,n,i){var a=[],o=[],s=0,l=Math.min(e.length,r.length)-1;for(e[l]<e[0]&&(e=e.slice().reverse(),r=r.slice().reverse());++s<=l;)a.push(n(e[s-1],e[s])),o.push(i(r[s-1],r[s]));return function(r){var n=t.bisect(e,r,1,l)-1;return o[n](a[n](r))}}function mo(e,r){return t.rebind(e,r,\"range\",\"rangeRound\",\"interpolate\",\"clamp\")}function yo(t,e){return fo(t,po(xo(t,e)[2])),fo(t,po(xo(t,e)[2])),t}function xo(t,e){null==e&&(e=10);var r=co(t),n=r[1]-r[0],i=Math.pow(10,Math.floor(Math.log(n/e)/Math.LN10)),a=e/n*i;return a<=.15?i*=10:a<=.35?i*=5:a<=.75&&(i*=2),r[0]=Math.ceil(r[0]/i)*i,r[1]=Math.floor(r[1]/i)*i+.5*i,r[2]=i,r}function bo(e,r){return t.range.apply(t,xo(e,r))}function _o(e,r,n){var i=xo(e,r);if(n){var a=Le.exec(n);if(a.shift(),\"s\"===a[8]){var o=t.formatPrefix(Math.max(y(i[0]),y(i[1])));return a[7]||(a[7]=\".\"+ko(o.scale(i[2]))),a[8]=\"f\",n=t.format(a.join(\"\")),function(t){return n(o.scale(t))+o.symbol}}a[7]||(a[7]=\".\"+function(t,e){var r=ko(e[2]);return t in wo?Math.abs(r-ko(Math.max(y(e[0]),y(e[1]))))+ +(\"e\"!==t):r-2*(\"%\"===t)}(a[8],i)),n=a.join(\"\")}else n=\",.\"+ko(i[2])+\"f\";return t.format(n)}t.scale.linear=function(){return function t(e,r,n,i){var a,o;function s(){var t=Math.min(e.length,r.length)>2?vo:ho,s=i?ma:va;return a=t(e,r,s,n),o=t(r,e,s,Zi),l}function l(t){return a(t)}l.invert=function(t){return o(t)};l.domain=function(t){return arguments.length?(e=t.map(Number),s()):e};l.range=function(t){return arguments.length?(r=t,s()):r};l.rangeRound=function(t){return l.range(t).interpolate(ca)};l.clamp=function(t){return arguments.length?(i=t,s()):i};l.interpolate=function(t){return arguments.length?(n=t,s()):n};l.ticks=function(t){return bo(e,t)};l.tickFormat=function(t,r){return _o(e,t,r)};l.nice=function(t){return yo(e,t),s()};l.copy=function(){return t(e,r,n,i)};return s()}([0,1],[0,1],Zi,!1)};var wo={s:1,g:1,p:1,r:1,e:1};function ko(t){return-Math.floor(Math.log(t)/Math.LN10+.01)}t.scale.log=function(){return function e(r,n,i,a){function o(t){return(i?Math.log(t<0?0:t):-Math.log(t>0?0:-t))/Math.log(n)}function s(t){return i?Math.pow(n,t):-Math.pow(n,-t)}function l(t){return r(o(t))}l.invert=function(t){return s(r.invert(t))};l.domain=function(t){return arguments.length?(i=t[0]>=0,r.domain((a=t.map(Number)).map(o)),l):a};l.base=function(t){return arguments.length?(n=+t,r.domain(a.map(o)),l):n};l.nice=function(){var t=fo(a.map(o),i?Math:Ao);return r.domain(t),a=t.map(s),l};l.ticks=function(){var t=co(a),e=[],r=t[0],l=t[1],c=Math.floor(o(r)),u=Math.ceil(o(l)),h=n%1?2:n;if(isFinite(u-c)){if(i){for(;c<u;c++)for(var f=1;f<h;f++)e.push(s(c)*f);e.push(s(c))}else for(e.push(s(c));c++<u;)for(var f=h-1;f>0;f--)e.push(s(c)*f);for(c=0;e[c]<r;c++);for(u=e.length;e[u-1]>l;u--);e=e.slice(c,u)}return e};l.tickFormat=function(e,r){if(!arguments.length)return To;arguments.length<2?r=To:\"function\"!=typeof r&&(r=t.format(r));var i=Math.max(1,n*e/l.ticks().length);return function(t){var e=t/s(Math.round(o(t)));return e*n<n-.5&&(e*=n),e<=i?r(t):\"\"}};l.copy=function(){return e(r.copy(),n,i,a)};return mo(l,r)}(t.scale.linear().domain([0,1]),10,!0,[1,10])};var To=t.format(\".0e\"),Ao={floor:function(t){return-Math.ceil(-t)},ceil:function(t){return-Math.floor(-t)}};function Mo(t){return function(e){return e<0?-Math.pow(-e,t):Math.pow(e,t)}}t.scale.pow=function(){return function t(e,r,n){var i=Mo(r),a=Mo(1/r);function o(t){return e(i(t))}o.invert=function(t){return a(e.invert(t))};o.domain=function(t){return arguments.length?(e.domain((n=t.map(Number)).map(i)),o):n};o.ticks=function(t){return bo(n,t)};o.tickFormat=function(t,e){return _o(n,t,e)};o.nice=function(t){return o.domain(yo(n,t))};o.exponent=function(t){return arguments.length?(i=Mo(r=t),a=Mo(1/r),e.domain(n.map(i)),o):r};o.copy=function(){return t(e.copy(),r,n)};return mo(o,e)}(t.scale.linear(),1,[0,1])},t.scale.sqrt=function(){return t.scale.pow().exponent(.5)},t.scale.ordinal=function(){return function e(r,n){var i,a,o;function s(t){return a[((i.get(t)||(\"range\"===n.t?i.set(t,r.push(t)):NaN))-1)%a.length]}function l(e,n){return t.range(r.length).map(function(t){return e+n*t})}s.domain=function(t){if(!arguments.length)return r;r=[],i=new b;for(var e,a=-1,o=t.length;++a<o;)i.has(e=t[a])||i.set(e,r.push(e));return s[n.t].apply(s,n.a)};s.range=function(t){return arguments.length?(a=t,o=0,n={t:\"range\",a:arguments},s):a};s.rangePoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=(i+c)/2,0):(c-i)/(r.length-1+e);return a=l(i+u*e/2,u),o=0,n={t:\"rangePoints\",a:arguments},s};s.rangeRoundPoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=c=Math.round((i+c)/2),0):(c-i)/(r.length-1+e)|0;return a=l(i+Math.round(u*e/2+(c-i-(r.length-1+e)*u)/2),u),o=0,n={t:\"rangeRoundPoints\",a:arguments},s};s.rangeBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],h=t[1-c],f=(h-u)/(r.length-e+2*i);return a=l(u+f*i,f),c&&a.reverse(),o=f*(1-e),n={t:\"rangeBands\",a:arguments},s};s.rangeRoundBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],h=t[1-c],f=Math.floor((h-u)/(r.length-e+2*i));return a=l(u+Math.round((h-u-(r.length-e)*f)/2),f),c&&a.reverse(),o=Math.round(f*(1-e)),n={t:\"rangeRoundBands\",a:arguments},s};s.rangeBand=function(){return o};s.rangeExtent=function(){return co(n.a[0])};s.copy=function(){return e(r,n)};return s.domain(r)}([],{t:\"range\",a:[[]]})},t.scale.category10=function(){return t.scale.ordinal().range(So)},t.scale.category20=function(){return t.scale.ordinal().range(Eo)},t.scale.category20b=function(){return t.scale.ordinal().range(Co)},t.scale.category20c=function(){return t.scale.ordinal().range(Lo)};var So=[2062260,16744206,2924588,14034728,9725885,9197131,14907330,8355711,12369186,1556175].map(se),Eo=[2062260,11454440,16744206,16759672,2924588,10018698,14034728,16750742,9725885,12955861,9197131,12885140,14907330,16234194,8355711,13092807,12369186,14408589,1556175,10410725].map(se),Co=[3750777,5395619,7040719,10264286,6519097,9216594,11915115,13556636,9202993,12426809,15186514,15190932,8666169,11356490,14049643,15177372,8077683,10834324,13528509,14589654].map(se),Lo=[3244733,7057110,10406625,13032431,15095053,16616764,16625259,16634018,3253076,7652470,10607003,13101504,7695281,10394312,12369372,14342891,6513507,9868950,12434877,14277081].map(se);function Po(){return 0}t.scale.quantile=function(){return function e(r,n){var i;function a(){var e=0,a=n.length;for(i=[];++e<a;)i[e-1]=t.quantile(r,e/a);return o}function o(e){if(!isNaN(e=+e))return n[t.bisect(i,e)]}o.domain=function(t){return arguments.length?(r=t.map(p).filter(d).sort(f),a()):r};o.range=function(t){return arguments.length?(n=t,a()):n};o.quantiles=function(){return i};o.invertExtent=function(t){return(t=n.indexOf(t))<0?[NaN,NaN]:[t>0?i[t-1]:r[0],t<i.length?i[t]:r[r.length-1]]};o.copy=function(){return e(r,n)};return a()}([],[])},t.scale.quantize=function(){return function t(e,r,n){var i,a;function o(t){return n[Math.max(0,Math.min(a,Math.floor(i*(t-e))))]}function s(){return i=n.length/(r-e),a=n.length-1,o}o.domain=function(t){return arguments.length?(e=+t[0],r=+t[t.length-1],s()):[e,r]};o.range=function(t){return arguments.length?(n=t,s()):n};o.invertExtent=function(t){return[t=(t=n.indexOf(t))<0?NaN:t/i+e,t+1/i]};o.copy=function(){return t(e,r,n)};return s()}(0,1,[0,1])},t.scale.threshold=function(){return function e(r,n){function i(e){if(e<=e)return n[t.bisect(r,e)]}i.domain=function(t){return arguments.length?(r=t,i):r};i.range=function(t){return arguments.length?(n=t,i):n};i.invertExtent=function(t){return t=n.indexOf(t),[r[t-1],r[t]]};i.copy=function(){return e(r,n)};return i}([.5],[0,1])},t.scale.identity=function(){return function t(e){function r(t){return+t}r.invert=r;r.domain=r.range=function(t){return arguments.length?(e=t.map(r),r):e};r.ticks=function(t){return bo(e,t)};r.tickFormat=function(t,r){return _o(e,t,r)};r.copy=function(){return t(e)};return r}([0,1])},t.svg={},t.svg.arc=function(){var t=zo,e=Io,r=Po,n=Oo,i=Do,a=Ro,o=Fo;function s(){var s=Math.max(0,+t.apply(this,arguments)),c=Math.max(0,+e.apply(this,arguments)),u=i.apply(this,arguments)-Et,h=a.apply(this,arguments)-Et,f=Math.abs(h-u),p=u>h?0:1;if(c<s&&(d=c,c=s,s=d),f>=St)return l(c,p)+(s?l(s,1-p):\"\")+\"Z\";var d,g,v,m,y,x,b,_,w,k,T,A,M=0,S=0,E=[];if((m=(+o.apply(this,arguments)||0)/2)&&(v=n===Oo?Math.sqrt(s*s+c*c):+n.apply(this,arguments),p||(S*=-1),c&&(S=It(v/c*Math.sin(m))),s&&(M=It(v/s*Math.sin(m)))),c){y=c*Math.cos(u+S),x=c*Math.sin(u+S),b=c*Math.cos(h-S),_=c*Math.sin(h-S);var C=Math.abs(h-u-2*S)<=At?0:1;if(S&&Bo(y,x,b,_)===p^C){var L=(u+h)/2;y=c*Math.cos(L),x=c*Math.sin(L),b=_=null}}else y=x=0;if(s){w=s*Math.cos(h-M),k=s*Math.sin(h-M),T=s*Math.cos(u+M),A=s*Math.sin(u+M);var P=Math.abs(u-h+2*M)<=At?0:1;if(M&&Bo(w,k,T,A)===1-p^P){var O=(u+h)/2;w=s*Math.cos(O),k=s*Math.sin(O),T=A=null}}else w=k=0;if(f>kt&&(d=Math.min(Math.abs(c-s)/2,+r.apply(this,arguments)))>.001){g=s<c^p?0:1;var z=d,I=d;if(f<At){var D=null==T?[w,k]:null==b?[y,x]:si([y,x],[T,A],[b,_],[w,k]),R=y-D[0],F=x-D[1],B=b-D[0],N=_-D[1],j=1/Math.sin(Math.acos((R*B+F*N)/(Math.sqrt(R*R+F*F)*Math.sqrt(B*B+N*N)))/2),U=Math.sqrt(D[0]*D[0]+D[1]*D[1]);I=Math.min(d,(s-U)/(j-1)),z=Math.min(d,(c-U)/(j+1))}if(null!=b){var V=No(null==T?[w,k]:[T,A],[y,x],c,z,p),q=No([b,_],[w,k],c,z,p);d===z?E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 0,\",g,\" \",V[1],\"A\",c,\",\",c,\" 0 \",1-p^Bo(V[1][0],V[1][1],q[1][0],q[1][1]),\",\",p,\" \",q[1],\"A\",z,\",\",z,\" 0 0,\",g,\" \",q[0]):E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 1,\",g,\" \",q[0])}else E.push(\"M\",y,\",\",x);if(null!=T){var H=No([y,x],[T,A],s,-I,p),G=No([w,k],null==b?[y,x]:[b,_],s,-I,p);d===I?E.push(\"L\",G[0],\"A\",I,\",\",I,\" 0 0,\",g,\" \",G[1],\"A\",s,\",\",s,\" 0 \",p^Bo(G[1][0],G[1][1],H[1][0],H[1][1]),\",\",1-p,\" \",H[1],\"A\",I,\",\",I,\" 0 0,\",g,\" \",H[0]):E.push(\"L\",G[0],\"A\",I,\",\",I,\" 0 0,\",g,\" \",H[0])}else E.push(\"L\",w,\",\",k)}else E.push(\"M\",y,\",\",x),null!=b&&E.push(\"A\",c,\",\",c,\" 0 \",C,\",\",p,\" \",b,\",\",_),E.push(\"L\",w,\",\",k),null!=T&&E.push(\"A\",s,\",\",s,\" 0 \",P,\",\",1-p,\" \",T,\",\",A);return E.push(\"Z\"),E.join(\"\")}function l(t,e){return\"M0,\"+t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+-t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+t}return s.innerRadius=function(e){return arguments.length?(t=ve(e),s):t},s.outerRadius=function(t){return arguments.length?(e=ve(t),s):e},s.cornerRadius=function(t){return arguments.length?(r=ve(t),s):r},s.padRadius=function(t){return arguments.length?(n=t==Oo?Oo:ve(t),s):n},s.startAngle=function(t){return arguments.length?(i=ve(t),s):i},s.endAngle=function(t){return arguments.length?(a=ve(t),s):a},s.padAngle=function(t){return arguments.length?(o=ve(t),s):o},s.centroid=function(){var r=(+t.apply(this,arguments)+ +e.apply(this,arguments))/2,n=(+i.apply(this,arguments)+ +a.apply(this,arguments))/2-Et;return[Math.cos(n)*r,Math.sin(n)*r]},s};var Oo=\"auto\";function zo(t){return t.innerRadius}function Io(t){return t.outerRadius}function Do(t){return t.startAngle}function Ro(t){return t.endAngle}function Fo(t){return t&&t.padAngle}function Bo(t,e,r,n){return(t-r)*e-(e-n)*t>0?0:1}function No(t,e,r,n,i){var a=t[0]-e[0],o=t[1]-e[1],s=(i?n:-n)/Math.sqrt(a*a+o*o),l=s*o,c=-s*a,u=t[0]+l,h=t[1]+c,f=e[0]+l,p=e[1]+c,d=(u+f)/2,g=(h+p)/2,v=f-u,m=p-h,y=v*v+m*m,x=r-n,b=u*p-f*h,_=(m<0?-1:1)*Math.sqrt(Math.max(0,x*x*y-b*b)),w=(b*m-v*_)/y,k=(-b*v-m*_)/y,T=(b*m+v*_)/y,A=(-b*v+m*_)/y,M=w-d,S=k-g,E=T-d,C=A-g;return M*M+S*S>E*E+C*C&&(w=T,k=A),[[w-l,k-c],[w*r/x,k*r/x]]}function jo(t){var e=ei,r=ri,n=Yr,i=Vo,a=i.key,o=.7;function s(a){var s,l=[],c=[],u=-1,h=a.length,f=ve(e),p=ve(r);function d(){l.push(\"M\",i(t(c),o))}for(;++u<h;)n.call(this,s=a[u],u)?c.push([+f.call(this,s,u),+p.call(this,s,u)]):c.length&&(d(),c=[]);return c.length&&d(),l.length?l.join(\"\"):null}return s.x=function(t){return arguments.length?(e=t,s):e},s.y=function(t){return arguments.length?(r=t,s):r},s.defined=function(t){return arguments.length?(n=t,s):n},s.interpolate=function(t){return arguments.length?(a=\"function\"==typeof t?i=t:(i=Uo.get(t)||Vo).key,s):a},s.tension=function(t){return arguments.length?(o=t,s):o},s}t.svg.line=function(){return jo(P)};var Uo=t.map({linear:Vo,\"linear-closed\":qo,step:function(t){var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];for(;++e<r;)i.push(\"H\",(n[0]+(n=t[e])[0])/2,\"V\",n[1]);r>1&&i.push(\"H\",n[0]);return i.join(\"\")},\"step-before\":Ho,\"step-after\":Go,basis:Xo,\"basis-open\":function(t){if(t.length<4)return Vo(t);var e,r=[],n=-1,i=t.length,a=[0],o=[0];for(;++n<3;)e=t[n],a.push(e[0]),o.push(e[1]);r.push(Zo($o,a)+\",\"+Zo($o,o)),--n;for(;++n<i;)e=t[n],a.shift(),a.push(e[0]),o.shift(),o.push(e[1]),Qo(r,a,o);return r.join(\"\")},\"basis-closed\":function(t){var e,r,n=-1,i=t.length,a=i+4,o=[],s=[];for(;++n<4;)r=t[n%i],o.push(r[0]),s.push(r[1]);e=[Zo($o,o),\",\",Zo($o,s)],--n;for(;++n<a;)r=t[n%i],o.shift(),o.push(r[0]),s.shift(),s.push(r[1]),Qo(e,o,s);return e.join(\"\")},bundle:function(t,e){var r=t.length-1;if(r)for(var n,i,a=t[0][0],o=t[0][1],s=t[r][0]-a,l=t[r][1]-o,c=-1;++c<=r;)n=t[c],i=c/r,n[0]=e*n[0]+(1-e)*(a+i*s),n[1]=e*n[1]+(1-e)*(o+i*l);return Xo(t)},cardinal:function(t,e){return t.length<3?Vo(t):t[0]+Yo(t,Wo(t,e))},\"cardinal-open\":function(t,e){return t.length<4?Vo(t):t[1]+Yo(t.slice(1,-1),Wo(t,e))},\"cardinal-closed\":function(t,e){return t.length<3?qo(t):t[0]+Yo((t.push(t[0]),t),Wo([t[t.length-2]].concat(t,[t[1]]),e))},monotone:function(t){return t.length<3?Vo(t):t[0]+Yo(t,function(t){var e,r,n,i,a=[],o=function(t){var e=0,r=t.length-1,n=[],i=t[0],a=t[1],o=n[0]=ts(i,a);for(;++e<r;)n[e]=(o+(o=ts(i=a,a=t[e+1])))/2;return n[e]=o,n}(t),s=-1,l=t.length-1;for(;++s<l;)e=ts(t[s],t[s+1]),y(e)<kt?o[s]=o[s+1]=0:(r=o[s]/e,n=o[s+1]/e,(i=r*r+n*n)>9&&(i=3*e/Math.sqrt(i),o[s]=i*r,o[s+1]=i*n));s=-1;for(;++s<=l;)i=(t[Math.min(l,s+1)][0]-t[Math.max(0,s-1)][0])/(6*(1+o[s]*o[s])),a.push([i||0,o[s]*i||0]);return a}(t))}});function Vo(t){return t.length>1?t.join(\"L\"):t+\"Z\"}function qo(t){return t.join(\"L\")+\"Z\"}function Ho(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"V\",(n=t[e])[1],\"H\",n[0]);return i.join(\"\")}function Go(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"H\",(n=t[e])[0],\"V\",n[1]);return i.join(\"\")}function Yo(t,e){if(e.length<1||t.length!=e.length&&t.length!=e.length+2)return Vo(t);var r=t.length!=e.length,n=\"\",i=t[0],a=t[1],o=e[0],s=o,l=1;if(r&&(n+=\"Q\"+(a[0]-2*o[0]/3)+\",\"+(a[1]-2*o[1]/3)+\",\"+a[0]+\",\"+a[1],i=t[1],l=2),e.length>1){s=e[1],a=t[l],l++,n+=\"C\"+(i[0]+o[0])+\",\"+(i[1]+o[1])+\",\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1];for(var c=2;c<e.length;c++,l++)a=t[l],s=e[c],n+=\"S\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1]}if(r){var u=t[l];n+=\"Q\"+(a[0]+2*s[0]/3)+\",\"+(a[1]+2*s[1]/3)+\",\"+u[0]+\",\"+u[1]}return n}function Wo(t,e){for(var r,n=[],i=(1-e)/2,a=t[0],o=t[1],s=1,l=t.length;++s<l;)r=a,a=o,o=t[s],n.push([i*(o[0]-r[0]),i*(o[1]-r[1])]);return n}function Xo(t){if(t.length<3)return Vo(t);var e=1,r=t.length,n=t[0],i=n[0],a=n[1],o=[i,i,i,(n=t[1])[0]],s=[a,a,a,n[1]],l=[i,\",\",a,\"L\",Zo($o,o),\",\",Zo($o,s)];for(t.push(t[r-1]);++e<=r;)n=t[e],o.shift(),o.push(n[0]),s.shift(),s.push(n[1]),Qo(l,o,s);return t.pop(),l.push(\"L\",n),l.join(\"\")}function Zo(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}Uo.forEach(function(t,e){e.key=t,e.closed=/-closed$/.test(t)});var Jo=[0,2/3,1/3,0],Ko=[0,1/3,2/3,0],$o=[0,1/6,2/3,1/6];function Qo(t,e,r){t.push(\"C\",Zo(Jo,e),\",\",Zo(Jo,r),\",\",Zo(Ko,e),\",\",Zo(Ko,r),\",\",Zo($o,e),\",\",Zo($o,r))}function ts(t,e){return(e[1]-t[1])/(e[0]-t[0])}function es(t){for(var e,r,n,i=-1,a=t.length;++i<a;)r=(e=t[i])[0],n=e[1]-Et,e[0]=r*Math.cos(n),e[1]=r*Math.sin(n);return t}function rs(t){var e=ei,r=ei,n=0,i=ri,a=Yr,o=Vo,s=o.key,l=o,c=\"L\",u=.7;function h(s){var h,f,p,d=[],g=[],v=[],m=-1,y=s.length,x=ve(e),b=ve(n),_=e===r?function(){return f}:ve(r),w=n===i?function(){return p}:ve(i);function k(){d.push(\"M\",o(t(v),u),c,l(t(g.reverse()),u),\"Z\")}for(;++m<y;)a.call(this,h=s[m],m)?(g.push([f=+x.call(this,h,m),p=+b.call(this,h,m)]),v.push([+_.call(this,h,m),+w.call(this,h,m)])):g.length&&(k(),g=[],v=[]);return g.length&&k(),d.length?d.join(\"\"):null}return h.x=function(t){return arguments.length?(e=r=t,h):r},h.x0=function(t){return arguments.length?(e=t,h):e},h.x1=function(t){return arguments.length?(r=t,h):r},h.y=function(t){return arguments.length?(n=i=t,h):i},h.y0=function(t){return arguments.length?(n=t,h):n},h.y1=function(t){return arguments.length?(i=t,h):i},h.defined=function(t){return arguments.length?(a=t,h):a},h.interpolate=function(t){return arguments.length?(s=\"function\"==typeof t?o=t:(o=Uo.get(t)||Vo).key,l=o.reverse||o,c=o.closed?\"M\":\"L\",h):s},h.tension=function(t){return arguments.length?(u=t,h):u},h}function ns(t){return t.radius}function is(t){return[t.x,t.y]}function as(){return 64}function os(){return\"circle\"}function ss(t){var e=Math.sqrt(t/At);return\"M0,\"+e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+-e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+e+\"Z\"}t.svg.line.radial=function(){var t=jo(es);return t.radius=t.x,delete t.x,t.angle=t.y,delete t.y,t},Ho.reverse=Go,Go.reverse=Ho,t.svg.area=function(){return rs(P)},t.svg.area.radial=function(){var t=rs(es);return t.radius=t.x,delete t.x,t.innerRadius=t.x0,delete t.x0,t.outerRadius=t.x1,delete t.x1,t.angle=t.y,delete t.y,t.startAngle=t.y0,delete t.y0,t.endAngle=t.y1,delete t.y1,t},t.svg.chord=function(){var t=Un,e=Vn,r=ns,n=Do,i=Ro;function a(r,n){var i,a,c=o(this,t,r,n),u=o(this,e,r,n);return\"M\"+c.p0+s(c.r,c.p1,c.a1-c.a0)+(a=u,(i=c).a0==a.a0&&i.a1==a.a1?l(c.r,c.p1,c.r,c.p0):l(c.r,c.p1,u.r,u.p0)+s(u.r,u.p1,u.a1-u.a0)+l(u.r,u.p1,c.r,c.p0))+\"Z\"}function o(t,e,a,o){var s=e.call(t,a,o),l=r.call(t,s,o),c=n.call(t,s,o)-Et,u=i.call(t,s,o)-Et;return{r:l,a0:c,a1:u,p0:[l*Math.cos(c),l*Math.sin(c)],p1:[l*Math.cos(u),l*Math.sin(u)]}}function s(t,e,r){return\"A\"+t+\",\"+t+\" 0 \"+ +(r>At)+\",1 \"+e}function l(t,e,r,n){return\"Q 0,0 \"+n}return a.radius=function(t){return arguments.length?(r=ve(t),a):r},a.source=function(e){return arguments.length?(t=ve(e),a):t},a.target=function(t){return arguments.length?(e=ve(t),a):e},a.startAngle=function(t){return arguments.length?(n=ve(t),a):n},a.endAngle=function(t){return arguments.length?(i=ve(t),a):i},a},t.svg.diagonal=function(){var t=Un,e=Vn,r=is;function n(n,i){var a=t.call(this,n,i),o=e.call(this,n,i),s=(a.y+o.y)/2,l=[a,{x:a.x,y:s},{x:o.x,y:s},o];return\"M\"+(l=l.map(r))[0]+\"C\"+l[1]+\" \"+l[2]+\" \"+l[3]}return n.source=function(e){return arguments.length?(t=ve(e),n):t},n.target=function(t){return arguments.length?(e=ve(t),n):e},n.projection=function(t){return arguments.length?(r=t,n):r},n},t.svg.diagonal.radial=function(){var e=t.svg.diagonal(),r=is,n=e.projection;return e.projection=function(t){return arguments.length?n(function(t){return function(){var e=t.apply(this,arguments),r=e[0],n=e[1]-Et;return[r*Math.cos(n),r*Math.sin(n)]}}(r=t)):r},e},t.svg.symbol=function(){var t=os,e=as;function r(r,n){return(ls.get(t.call(this,r,n))||ss)(e.call(this,r,n))}return r.type=function(e){return arguments.length?(t=ve(e),r):t},r.size=function(t){return arguments.length?(e=ve(t),r):e},r};var ls=t.map({circle:ss,cross:function(t){var e=Math.sqrt(t/5)/2;return\"M\"+-3*e+\",\"+-e+\"H\"+-e+\"V\"+-3*e+\"H\"+e+\"V\"+-e+\"H\"+3*e+\"V\"+e+\"H\"+e+\"V\"+3*e+\"H\"+-e+\"V\"+e+\"H\"+-3*e+\"Z\"},diamond:function(t){var e=Math.sqrt(t/(2*us)),r=e*us;return\"M0,\"+-e+\"L\"+r+\",0 0,\"+e+\" \"+-r+\",0Z\"},square:function(t){var e=Math.sqrt(t)/2;return\"M\"+-e+\",\"+-e+\"L\"+e+\",\"+-e+\" \"+e+\",\"+e+\" \"+-e+\",\"+e+\"Z\"},\"triangle-down\":function(t){var e=Math.sqrt(t/cs),r=e*cs/2;return\"M0,\"+r+\"L\"+e+\",\"+-r+\" \"+-e+\",\"+-r+\"Z\"},\"triangle-up\":function(t){var e=Math.sqrt(t/cs),r=e*cs/2;return\"M0,\"+-r+\"L\"+e+\",\"+r+\" \"+-e+\",\"+r+\"Z\"}});t.svg.symbolTypes=ls.keys();var cs=Math.sqrt(3),us=Math.tan(30*Ct);W.transition=function(t){for(var e,r,n=ds||++ms,i=bs(t),a=[],o=gs||{time:Date.now(),ease:ia,delay:0,duration:250},s=-1,l=this.length;++s<l;){a.push(e=[]);for(var c=this[s],u=-1,h=c.length;++u<h;)(r=c[u])&&_s(r,u,i,n,o),e.push(r)}return ps(a,i,n)},W.interrupt=function(t){return this.each(null==t?hs:fs(bs(t)))};var hs=fs(bs());function fs(t){return function(){var e,r,n;(e=this[t])&&(n=e[r=e.active])&&(n.timer.c=null,n.timer.t=NaN,--e.count?delete e[r]:delete this[t],e.active+=.5,n.event&&n.event.interrupt.call(this,this.__data__,n.index))}}function ps(t,e,r){return V(t,vs),t.namespace=e,t.id=r,t}var ds,gs,vs=[],ms=0;function ys(t,e,r,n){var i=t.id,a=t.namespace;return ut(t,\"function\"==typeof r?function(t,o,s){t[a][i].tween.set(e,n(r.call(t,t.__data__,o,s)))}:(r=n(r),function(t){t[a][i].tween.set(e,r)}))}function xs(t){return null==t&&(t=\"\"),function(){this.textContent=t}}function bs(t){return null==t?\"__transition__\":\"__transition_\"+t+\"__\"}function _s(t,e,r,n,i){var a,o,s,l,c,u=t[r]||(t[r]={active:0,count:0}),h=u[n];function f(r){var i=u.active,f=u[i];for(var d in f&&(f.timer.c=null,f.timer.t=NaN,--u.count,delete u[i],f.event&&f.event.interrupt.call(t,t.__data__,f.index)),u)if(+d<n){var g=u[d];g.timer.c=null,g.timer.t=NaN,--u.count,delete u[d]}o.c=p,Te(function(){return o.c&&p(r||1)&&(o.c=null,o.t=NaN),1},0,a),u.active=n,h.event&&h.event.start.call(t,t.__data__,e),c=[],h.tween.forEach(function(r,n){(n=n.call(t,t.__data__,e))&&c.push(n)}),l=h.ease,s=h.duration}function p(i){for(var a=i/s,o=l(a),f=c.length;f>0;)c[--f].call(t,o);if(a>=1)return h.event&&h.event.end.call(t,t.__data__,e),--u.count?delete u[n]:delete t[r],1}h||(a=i.time,o=Te(function(t){var e=h.delay;if(o.t=e+a,e<=t)return f(t-e);o.c=f},0,a),h=u[n]={tween:new b,time:a,timer:o,delay:i.delay,duration:i.duration,ease:i.ease,index:e},i=null,++u.count)}vs.call=W.call,vs.empty=W.empty,vs.node=W.node,vs.size=W.size,t.transition=function(e,r){return e&&e.transition?ds?e.transition(r):e:t.selection().transition(e)},t.transition.prototype=vs,vs.select=function(t){var e,r,n,i=this.id,a=this.namespace,o=[];t=X(t);for(var s=-1,l=this.length;++s<l;){o.push(e=[]);for(var c=this[s],u=-1,h=c.length;++u<h;)(n=c[u])&&(r=t.call(n,n.__data__,u,s))?(\"__data__\"in n&&(r.__data__=n.__data__),_s(r,u,a,i,n[a][i]),e.push(r)):e.push(null)}return ps(o,a,i)},vs.selectAll=function(t){var e,r,n,i,a,o=this.id,s=this.namespace,l=[];t=Z(t);for(var c=-1,u=this.length;++c<u;)for(var h=this[c],f=-1,p=h.length;++f<p;)if(n=h[f]){a=n[s][o],r=t.call(n,n.__data__,f,c),l.push(e=[]);for(var d=-1,g=r.length;++d<g;)(i=r[d])&&_s(i,d,s,o,a),e.push(i)}return ps(l,s,o)},vs.filter=function(t){var e,r,n=[];\"function\"!=typeof t&&(t=ct(t));for(var i=0,a=this.length;i<a;i++){n.push(e=[]);for(var o,s=0,l=(o=this[i]).length;s<l;s++)(r=o[s])&&t.call(r,r.__data__,s,i)&&e.push(r)}return ps(n,this.namespace,this.id)},vs.tween=function(t,e){var r=this.id,n=this.namespace;return arguments.length<2?this.node()[n][r].tween.get(t):ut(this,null==e?function(e){e[n][r].tween.remove(t)}:function(i){i[n][r].tween.set(t,e)})},vs.attr=function(e,r){if(arguments.length<2){for(r in e)this.attr(r,e[r]);return this}var n=\"transform\"==e?ga:Zi,i=t.ns.qualify(e);function a(){this.removeAttribute(i)}function o(){this.removeAttributeNS(i.space,i.local)}return ys(this,\"attr.\"+e,r,i.local?function(t){return null==t?o:(t+=\"\",function(){var e,r=this.getAttributeNS(i.space,i.local);return r!==t&&(e=n(r,t),function(t){this.setAttributeNS(i.space,i.local,e(t))})})}:function(t){return null==t?a:(t+=\"\",function(){var e,r=this.getAttribute(i);return r!==t&&(e=n(r,t),function(t){this.setAttribute(i,e(t))})})})},vs.attrTween=function(e,r){var n=t.ns.qualify(e);return this.tween(\"attr.\"+e,n.local?function(t,e){var i=r.call(this,t,e,this.getAttributeNS(n.space,n.local));return i&&function(t){this.setAttributeNS(n.space,n.local,i(t))}}:function(t,e){var i=r.call(this,t,e,this.getAttribute(n));return i&&function(t){this.setAttribute(n,i(t))}})},vs.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.style(r,t[r],e);return this}r=\"\"}function i(){this.style.removeProperty(t)}return ys(this,\"style.\"+t,e,function(e){return null==e?i:(e+=\"\",function(){var n,i=o(this).getComputedStyle(this,null).getPropertyValue(t);return i!==e&&(n=Zi(i,e),function(e){this.style.setProperty(t,n(e),r)})})})},vs.styleTween=function(t,e,r){return arguments.length<3&&(r=\"\"),this.tween(\"style.\"+t,function(n,i){var a=e.call(this,n,i,o(this).getComputedStyle(this,null).getPropertyValue(t));return a&&function(e){this.style.setProperty(t,a(e),r)}})},vs.text=function(t){return ys(this,\"text\",t,xs)},vs.remove=function(){var t=this.namespace;return this.each(\"end.transition\",function(){var e;this[t].count<2&&(e=this.parentNode)&&e.removeChild(this)})},vs.ease=function(e){var r=this.id,n=this.namespace;return arguments.length<1?this.node()[n][r].ease:(\"function\"!=typeof e&&(e=t.ease.apply(t,arguments)),ut(this,function(t){t[n][r].ease=e}))},vs.delay=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].delay:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].delay=+t.call(n,n.__data__,i,a)}:(t=+t,function(n){n[r][e].delay=t}))},vs.duration=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].duration:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].duration=Math.max(1,t.call(n,n.__data__,i,a))}:(t=Math.max(1,t),function(n){n[r][e].duration=t}))},vs.each=function(e,r){var n=this.id,i=this.namespace;if(arguments.length<2){var a=gs,o=ds;try{ds=n,ut(this,function(t,r,a){gs=t[i][n],e.call(t,t.__data__,r,a)})}finally{gs=a,ds=o}}else ut(this,function(a){var o=a[i][n];(o.event||(o.event=t.dispatch(\"start\",\"end\",\"interrupt\"))).on(e,r)});return this},vs.transition=function(){for(var t,e,r,n=this.id,i=++ms,a=this.namespace,o=[],s=0,l=this.length;s<l;s++){o.push(t=[]);for(var c,u=0,h=(c=this[s]).length;u<h;u++)(e=c[u])&&_s(e,u,a,i,{time:(r=e[a][n]).time,ease:r.ease,delay:r.delay+r.duration,duration:r.duration}),t.push(e)}return ps(o,a,i)},t.svg.axis=function(){var e,r=t.scale.linear(),i=ws,a=6,o=6,s=3,l=[10],c=null;function u(n){n.each(function(){var n,u=t.select(this),h=this.__chart__||r,f=this.__chart__=r.copy(),p=null==c?f.ticks?f.ticks.apply(f,l):f.domain():c,d=null==e?f.tickFormat?f.tickFormat.apply(f,l):P:e,g=u.selectAll(\".tick\").data(p,f),v=g.enter().insert(\"g\",\".domain\").attr(\"class\",\"tick\").style(\"opacity\",kt),m=t.transition(g.exit()).style(\"opacity\",kt).remove(),y=t.transition(g.order()).style(\"opacity\",1),x=Math.max(a,0)+s,b=uo(f),_=u.selectAll(\".domain\").data([0]),w=(_.enter().append(\"path\").attr(\"class\",\"domain\"),t.transition(_));v.append(\"line\"),v.append(\"text\");var k,T,A,M,S=v.select(\"line\"),E=y.select(\"line\"),C=g.select(\"text\").text(d),L=v.select(\"text\"),O=y.select(\"text\"),z=\"top\"===i||\"left\"===i?-1:1;if(\"bottom\"===i||\"top\"===i?(n=Ts,k=\"x\",A=\"y\",T=\"x2\",M=\"y2\",C.attr(\"dy\",z<0?\"0em\":\".71em\").style(\"text-anchor\",\"middle\"),w.attr(\"d\",\"M\"+b[0]+\",\"+z*o+\"V0H\"+b[1]+\"V\"+z*o)):(n=As,k=\"y\",A=\"x\",T=\"y2\",M=\"x2\",C.attr(\"dy\",\".32em\").style(\"text-anchor\",z<0?\"end\":\"start\"),w.attr(\"d\",\"M\"+z*o+\",\"+b[0]+\"H0V\"+b[1]+\"H\"+z*o)),S.attr(M,z*a),L.attr(A,z*x),E.attr(T,0).attr(M,z*a),O.attr(k,0).attr(A,z*x),f.rangeBand){var I=f,D=I.rangeBand()/2;h=f=function(t){return I(t)+D}}else h.rangeBand?h=f:m.call(n,f,h);v.call(n,h,f),y.call(n,f,f)})}return u.scale=function(t){return arguments.length?(r=t,u):r},u.orient=function(t){return arguments.length?(i=t in ks?t+\"\":ws,u):i},u.ticks=function(){return arguments.length?(l=n(arguments),u):l},u.tickValues=function(t){return arguments.length?(c=t,u):c},u.tickFormat=function(t){return arguments.length?(e=t,u):e},u.tickSize=function(t){var e=arguments.length;return e?(a=+t,o=+arguments[e-1],u):a},u.innerTickSize=function(t){return arguments.length?(a=+t,u):a},u.outerTickSize=function(t){return arguments.length?(o=+t,u):o},u.tickPadding=function(t){return arguments.length?(s=+t,u):s},u.tickSubdivide=function(){return arguments.length&&u},u};var ws=\"bottom\",ks={top:1,right:1,bottom:1,left:1};function Ts(t,e,r){t.attr(\"transform\",function(t){var n=e(t);return\"translate(\"+(isFinite(n)?n:r(t))+\",0)\"})}function As(t,e,r){t.attr(\"transform\",function(t){var n=e(t);return\"translate(0,\"+(isFinite(n)?n:r(t))+\")\"})}t.svg.brush=function(){var e,r,n=j(f,\"brushstart\",\"brush\",\"brushend\"),i=null,a=null,s=[0,0],l=[0,0],c=!0,u=!0,h=Ss[0];function f(e){e.each(function(){var e=t.select(this).style(\"pointer-events\",\"all\").style(\"-webkit-tap-highlight-color\",\"rgba(0,0,0,0)\").on(\"mousedown.brush\",v).on(\"touchstart.brush\",v),r=e.selectAll(\".background\").data([0]);r.enter().append(\"rect\").attr(\"class\",\"background\").style(\"visibility\",\"hidden\").style(\"cursor\",\"crosshair\"),e.selectAll(\".extent\").data([0]).enter().append(\"rect\").attr(\"class\",\"extent\").style(\"cursor\",\"move\");var n=e.selectAll(\".resize\").data(h,P);n.exit().remove(),n.enter().append(\"g\").attr(\"class\",function(t){return\"resize \"+t}).style(\"cursor\",function(t){return Ms[t]}).append(\"rect\").attr(\"x\",function(t){return/[ew]$/.test(t)?-3:null}).attr(\"y\",function(t){return/^[ns]/.test(t)?-3:null}).attr(\"width\",6).attr(\"height\",6).style(\"visibility\",\"hidden\"),n.style(\"display\",f.empty()?\"none\":null);var o,s=t.transition(e),l=t.transition(r);i&&(o=uo(i),l.attr(\"x\",o[0]).attr(\"width\",o[1]-o[0]),d(s)),a&&(o=uo(a),l.attr(\"y\",o[0]).attr(\"height\",o[1]-o[0]),g(s)),p(s)})}function p(t){t.selectAll(\".resize\").attr(\"transform\",function(t){return\"translate(\"+s[+/e$/.test(t)]+\",\"+l[+/^s/.test(t)]+\")\"})}function d(t){t.select(\".extent\").attr(\"x\",s[0]),t.selectAll(\".extent,.n>rect,.s>rect\").attr(\"width\",s[1]-s[0])}function g(t){t.select(\".extent\").attr(\"y\",l[0]),t.selectAll(\".extent,.e>rect,.w>rect\").attr(\"height\",l[1]-l[0])}function v(){var h,v,m=this,y=t.select(t.event.target),x=n.of(m,arguments),b=t.select(m),_=y.datum(),w=!/^(n|s)$/.test(_)&&i,k=!/^(e|w)$/.test(_)&&a,T=y.classed(\"extent\"),A=xt(m),M=t.mouse(m),S=t.select(o(m)).on(\"keydown.brush\",function(){32==t.event.keyCode&&(T||(h=null,M[0]-=s[1],M[1]-=l[1],T=2),B())}).on(\"keyup.brush\",function(){32==t.event.keyCode&&2==T&&(M[0]+=s[1],M[1]+=l[1],T=0,B())});if(t.event.changedTouches?S.on(\"touchmove.brush\",L).on(\"touchend.brush\",O):S.on(\"mousemove.brush\",L).on(\"mouseup.brush\",O),b.interrupt().selectAll(\"*\").interrupt(),T)M[0]=s[0]-M[0],M[1]=l[0]-M[1];else if(_){var E=+/w$/.test(_),C=+/^n/.test(_);v=[s[1-E]-M[0],l[1-C]-M[1]],M[0]=s[E],M[1]=l[C]}else t.event.altKey&&(h=M.slice());function L(){var e=t.mouse(m),r=!1;v&&(e[0]+=v[0],e[1]+=v[1]),T||(t.event.altKey?(h||(h=[(s[0]+s[1])/2,(l[0]+l[1])/2]),M[0]=s[+(e[0]<h[0])],M[1]=l[+(e[1]<h[1])]):h=null),w&&P(e,i,0)&&(d(b),r=!0),k&&P(e,a,1)&&(g(b),r=!0),r&&(p(b),x({type:\"brush\",mode:T?\"move\":\"resize\"}))}function P(t,n,i){var a,o,f=uo(n),p=f[0],d=f[1],g=M[i],v=i?l:s,m=v[1]-v[0];if(T&&(p-=g,d-=m+g),a=(i?u:c)?Math.max(p,Math.min(d,t[i])):t[i],T?o=(a+=g)+m:(h&&(g=Math.max(p,Math.min(d,2*h[i]-a))),g<a?(o=a,a=g):o=g),v[0]!=a||v[1]!=o)return i?r=null:e=null,v[0]=a,v[1]=o,!0}function O(){L(),b.style(\"pointer-events\",\"all\").selectAll(\".resize\").style(\"display\",f.empty()?\"none\":null),t.select(\"body\").style(\"cursor\",null),S.on(\"mousemove.brush\",null).on(\"mouseup.brush\",null).on(\"touchmove.brush\",null).on(\"touchend.brush\",null).on(\"keydown.brush\",null).on(\"keyup.brush\",null),A(),x({type:\"brushend\"})}b.style(\"pointer-events\",\"none\").selectAll(\".resize\").style(\"display\",null),t.select(\"body\").style(\"cursor\",y.style(\"cursor\")),x({type:\"brushstart\"}),L()}return f.event=function(i){i.each(function(){var i=n.of(this,arguments),a={x:s,y:l,i:e,j:r},o=this.__chart__||a;this.__chart__=a,ds?t.select(this).transition().each(\"start.brush\",function(){e=o.i,r=o.j,s=o.x,l=o.y,i({type:\"brushstart\"})}).tween(\"brush:brush\",function(){var t=Ji(s,a.x),n=Ji(l,a.y);return e=r=null,function(e){s=a.x=t(e),l=a.y=n(e),i({type:\"brush\",mode:\"resize\"})}}).each(\"end.brush\",function(){e=a.i,r=a.j,i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"})}):(i({type:\"brushstart\"}),i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"}))})},f.x=function(t){return arguments.length?(h=Ss[!(i=t)<<1|!a],f):i},f.y=function(t){return arguments.length?(h=Ss[!i<<1|!(a=t)],f):a},f.clamp=function(t){return arguments.length?(i&&a?(c=!!t[0],u=!!t[1]):i?c=!!t:a&&(u=!!t),f):i&&a?[c,u]:i?c:a?u:null},f.extent=function(t){var n,o,c,u,h;return arguments.length?(i&&(n=t[0],o=t[1],a&&(n=n[0],o=o[0]),e=[n,o],i.invert&&(n=i(n),o=i(o)),o<n&&(h=n,n=o,o=h),n==s[0]&&o==s[1]||(s=[n,o])),a&&(c=t[0],u=t[1],i&&(c=c[1],u=u[1]),r=[c,u],a.invert&&(c=a(c),u=a(u)),u<c&&(h=c,c=u,u=h),c==l[0]&&u==l[1]||(l=[c,u])),f):(i&&(e?(n=e[0],o=e[1]):(n=s[0],o=s[1],i.invert&&(n=i.invert(n),o=i.invert(o)),o<n&&(h=n,n=o,o=h))),a&&(r?(c=r[0],u=r[1]):(c=l[0],u=l[1],a.invert&&(c=a.invert(c),u=a.invert(u)),u<c&&(h=c,c=u,u=h))),i&&a?[[n,c],[o,u]]:i?[n,o]:a&&[c,u])},f.clear=function(){return f.empty()||(s=[0,0],l=[0,0],e=r=null),f},f.empty=function(){return!!i&&s[0]==s[1]||!!a&&l[0]==l[1]},t.rebind(f,n,\"on\")};var Ms={n:\"ns-resize\",e:\"ew-resize\",s:\"ns-resize\",w:\"ew-resize\",nw:\"nwse-resize\",ne:\"nesw-resize\",se:\"nwse-resize\",sw:\"nesw-resize\"},Ss=[[\"n\",\"e\",\"s\",\"w\",\"nw\",\"ne\",\"se\",\"sw\"],[\"e\",\"w\"],[\"n\",\"s\"],[]],Es=ze.format=sr.timeFormat,Cs=Es.utc,Ls=Cs(\"%Y-%m-%dT%H:%M:%S.%LZ\");function Ps(t){return t.toISOString()}function Os(e,r,n){function i(t){return e(t)}function a(e,n){var i=(e[1]-e[0])/n,a=t.bisect(Is,i);return a==Is.length?[r.year,xo(e.map(function(t){return t/31536e6}),n)[2]]:a?r[i/Is[a-1]<Is[a]/i?a-1:a]:[Fs,xo(e,n)[2]]}return i.invert=function(t){return zs(e.invert(t))},i.domain=function(t){return arguments.length?(e.domain(t),i):e.domain().map(zs)},i.nice=function(t,e){var r=i.domain(),n=co(r),o=null==t?a(n,10):\"number\"==typeof t&&a(n,t);function s(r){return!isNaN(r)&&!t.range(r,zs(+r+1),e).length}return o&&(t=o[0],e=o[1]),i.domain(fo(r,e>1?{floor:function(e){for(;s(e=t.floor(e));)e=zs(e-1);return e},ceil:function(e){for(;s(e=t.ceil(e));)e=zs(+e+1);return e}}:t))},i.ticks=function(t,e){var r=co(i.domain()),n=null==t?a(r,10):\"number\"==typeof t?a(r,t):!t.range&&[{range:t},e];return n&&(t=n[0],e=n[1]),t.range(r[0],zs(+r[1]+1),e<1?1:e)},i.tickFormat=function(){return n},i.copy=function(){return Os(e.copy(),r,n)},mo(i,e)}function zs(t){return new Date(t)}Es.iso=Date.prototype.toISOString&&+new Date(\"2000-01-01T00:00:00.000Z\")?Ps:Ls,Ps.parse=function(t){var e=new Date(t);return isNaN(e)?null:e},Ps.toString=Ls.toString,ze.second=Fe(function(t){return new Ie(1e3*Math.floor(t/1e3))},function(t,e){t.setTime(t.getTime()+1e3*Math.floor(e))},function(t){return t.getSeconds()}),ze.seconds=ze.second.range,ze.seconds.utc=ze.second.utc.range,ze.minute=Fe(function(t){return new Ie(6e4*Math.floor(t/6e4))},function(t,e){t.setTime(t.getTime()+6e4*Math.floor(e))},function(t){return t.getMinutes()}),ze.minutes=ze.minute.range,ze.minutes.utc=ze.minute.utc.range,ze.hour=Fe(function(t){var e=t.getTimezoneOffset()/60;return new Ie(36e5*(Math.floor(t/36e5-e)+e))},function(t,e){t.setTime(t.getTime()+36e5*Math.floor(e))},function(t){return t.getHours()}),ze.hours=ze.hour.range,ze.hours.utc=ze.hour.utc.range,ze.month=Fe(function(t){return(t=ze.day(t)).setDate(1),t},function(t,e){t.setMonth(t.getMonth()+e)},function(t){return t.getMonth()}),ze.months=ze.month.range,ze.months.utc=ze.month.utc.range;var Is=[1e3,5e3,15e3,3e4,6e4,3e5,9e5,18e5,36e5,108e5,216e5,432e5,864e5,1728e5,6048e5,2592e6,7776e6,31536e6],Ds=[[ze.second,1],[ze.second,5],[ze.second,15],[ze.second,30],[ze.minute,1],[ze.minute,5],[ze.minute,15],[ze.minute,30],[ze.hour,1],[ze.hour,3],[ze.hour,6],[ze.hour,12],[ze.day,1],[ze.day,2],[ze.week,1],[ze.month,1],[ze.month,3],[ze.year,1]],Rs=Es.multi([[\".%L\",function(t){return t.getMilliseconds()}],[\":%S\",function(t){return t.getSeconds()}],[\"%I:%M\",function(t){return t.getMinutes()}],[\"%I %p\",function(t){return t.getHours()}],[\"%a %d\",function(t){return t.getDay()&&1!=t.getDate()}],[\"%b %d\",function(t){return 1!=t.getDate()}],[\"%B\",function(t){return t.getMonth()}],[\"%Y\",Yr]]),Fs={range:function(e,r,n){return t.range(Math.ceil(e/n)*n,+r,n).map(zs)},floor:P,ceil:P};Ds.year=ze.year,ze.scale=function(){return Os(t.scale.linear(),Ds,Rs)};var Bs=Ds.map(function(t){return[t[0].utc,t[1]]}),Ns=Cs.multi([[\".%L\",function(t){return t.getUTCMilliseconds()}],[\":%S\",function(t){return t.getUTCSeconds()}],[\"%I:%M\",function(t){return t.getUTCMinutes()}],[\"%I %p\",function(t){return t.getUTCHours()}],[\"%a %d\",function(t){return t.getUTCDay()&&1!=t.getUTCDate()}],[\"%b %d\",function(t){return 1!=t.getUTCDate()}],[\"%B\",function(t){return t.getUTCMonth()}],[\"%Y\",Yr]]);function js(t){return JSON.parse(t.responseText)}function Us(t){var e=i.createRange();return e.selectNode(i.body),e.createContextualFragment(t.responseText)}Bs.year=ze.year.utc,ze.scale.utc=function(){return Os(t.scale.linear(),Bs,Ns)},t.text=me(function(t){return t.responseText}),t.json=function(t,e){return ye(t,\"application/json\",js,e)},t.html=function(t,e){return ye(t,\"text/html\",Us,e)},t.xml=me(function(t){return t.responseXML}),\"object\"==typeof e&&e.exports?e.exports=t:this.d3=t}()},{}],164:[function(t,e,r){e.exports=function(){for(var t=0;t<arguments.length;t++)if(void 0!==arguments[t])return arguments[t]}},{}],165:[function(t,e,r){\"use strict\";var n=t(\"incremental-convex-hull\"),i=t(\"uniq\");function a(t,e){this.point=t,this.index=e}function o(t,e){for(var r=t.point,n=e.point,i=r.length,a=0;a<i;++a){var o=n[a]-r[a];if(o)return o}return 0}e.exports=function(t,e){var r=t.length;if(0===r)return[];var s=t[0].length;if(s<1)return[];if(1===s)return function(t,e,r){if(1===t)return r?[[-1,0]]:[];var n=e.map(function(t,e){return[t[0],e]});n.sort(function(t,e){return t[0]-e[0]});for(var i=new Array(t-1),a=1;a<t;++a){var o=n[a-1],s=n[a];i[a-1]=[o[1],s[1]]}r&&i.push([-1,i[0][1]],[i[t-1][1],-1]);return i}(r,t,e);for(var l=new Array(r),c=1,u=0;u<r;++u){for(var h=t[u],f=new Array(s+1),p=0,d=0;d<s;++d){var g=h[d];f[d]=g,p+=g*g}f[s]=p,l[u]=new a(f,u),c=Math.max(p,c)}i(l,o),r=l.length;for(var v=new Array(r+s+1),m=new Array(r+s+1),y=(s+1)*(s+1)*c,x=new Array(s+1),u=0;u<=s;++u)x[u]=0;x[s]=y,v[0]=x.slice(),m[0]=-1;for(var u=0;u<=s;++u){var f=x.slice();f[u]=1,v[u+1]=f,m[u+1]=-1}for(var u=0;u<r;++u){var b=l[u];v[u+s+1]=b.point,m[u+s+1]=b.index}var _=n(v,!1);_=e?_.filter(function(t){for(var e=0,r=0;r<=s;++r){var n=m[t[r]];if(n<0&&++e>=2)return!1;t[r]=n}return!0}):_.filter(function(t){for(var e=0;e<=s;++e){var r=m[t[e]];if(r<0)return!1;t[e]=r}return!0});if(1&s)for(var u=0;u<_.length;++u){var b=_[u],f=b[0];b[0]=b[1],b[1]=f}return _}},{\"incremental-convex-hull\":413,uniq:547}],166:[function(t,e,r){\"use strict\";e.exports=a;var n=(a.canvas=document.createElement(\"canvas\")).getContext(\"2d\"),i=o([32,126]);function a(t,e){Array.isArray(t)&&(t=t.join(\", \"));var r,a={},s=16,l=.05;e&&(2===e.length&&\"number\"==typeof e[0]?r=o(e):Array.isArray(e)?r=e:(e.o?r=o(e.o):e.pairs&&(r=e.pairs),e.fontSize&&(s=e.fontSize),null!=e.threshold&&(l=e.threshold))),r||(r=i),n.font=s+\"px \"+t;for(var c=0;c<r.length;c++){var u=r[c],h=n.measureText(u[0]).width+n.measureText(u[1]).width,f=n.measureText(u).width;if(Math.abs(h-f)>s*l){var p=(f-h)/s;a[u]=1e3*p}}return a}function o(t){for(var e=[],r=t[0];r<=t[1];r++)for(var n=String.fromCharCode(r),i=t[0];i<t[1];i++){var a=n+String.fromCharCode(i);e.push(a)}return e}a.createPairs=o,a.ascii=i},{}],167:[function(t,e,r){(function(t){var r=!1;if(\"undefined\"!=typeof Float64Array){var n=new Float64Array(1),i=new Uint32Array(n.buffer);if(n[0]=1,r=!0,1072693248===i[1]){e.exports=function(t){return n[0]=t,[i[0],i[1]]},e.exports.pack=function(t,e){return i[0]=t,i[1]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[0]},e.exports.hi=function(t){return n[0]=t,i[1]}}else if(1072693248===i[0]){e.exports=function(t){return n[0]=t,[i[1],i[0]]},e.exports.pack=function(t,e){return i[1]=t,i[0]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[1]},e.exports.hi=function(t){return n[0]=t,i[0]}}else r=!1}if(!r){var a=new t(8);e.exports=function(t){return a.writeDoubleLE(t,0,!0),[a.readUInt32LE(0,!0),a.readUInt32LE(4,!0)]},e.exports.pack=function(t,e){return a.writeUInt32LE(t,0,!0),a.writeUInt32LE(e,4,!0),a.readDoubleLE(0,!0)},e.exports.lo=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(0,!0)},e.exports.hi=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(4,!0)}}e.exports.sign=function(t){return e.exports.hi(t)>>>31},e.exports.exponent=function(t){return(e.exports.hi(t)<<1>>>21)-1023},e.exports.fraction=function(t){var r=e.exports.lo(t),n=e.exports.hi(t),i=1048575&n;return 2146435072&n&&(i+=1<<20),[r,i]},e.exports.denormalized=function(t){return!(2146435072&e.exports.hi(t))}}).call(this,t(\"buffer\").Buffer)},{buffer:105}],168:[function(t,e,r){var n=t(\"abs-svg-path\"),i=t(\"normalize-svg-path\"),a={M:\"moveTo\",C:\"bezierCurveTo\"};e.exports=function(t,e){t.beginPath(),i(n(e)).forEach(function(e){var r=e[0],n=e.slice(1);t[a[r]].apply(t,n)}),t.closePath()}},{\"abs-svg-path\":60,\"normalize-svg-path\":452}],169:[function(t,e,r){e.exports=function(t){switch(t){case\"int8\":return Int8Array;case\"int16\":return Int16Array;case\"int32\":return Int32Array;case\"uint8\":return Uint8Array;case\"uint16\":return Uint16Array;case\"uint32\":return Uint32Array;case\"float32\":return Float32Array;case\"float64\":return Float64Array;case\"array\":return Array;case\"uint8_clamped\":return Uint8ClampedArray}}},{}],170:[function(t,e,r){\"use strict\";e.exports=function(t,e){switch(\"undefined\"==typeof e&&(e=0),typeof t){case\"number\":if(t>0)return function(t,e){var r,n;for(r=new Array(t),n=0;n<t;++n)r[n]=e;return r}(0|t,e);break;case\"object\":if(\"number\"==typeof t.length)return function t(e,r,n){var i=0|e[n];if(i<=0)return[];var a,o=new Array(i);if(n===e.length-1)for(a=0;a<i;++a)o[a]=r;else for(a=0;a<i;++a)o[a]=t(e,r,n+1);return o}(t,e,0)}return[]}},{}],171:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(\"number\"!=typeof e){e=0;for(var i=0;i<r;++i){var a=t[i];e=Math.max(e,a[0],a[1])}e=1+(0|e)}e|=0;for(var o=new Array(e),i=0;i<e;++i)o[i]=[];for(var i=0;i<r;++i){var a=t[i];o[a[0]].push(a[1]),o[a[1]].push(a[0])}for(var s=0;s<e;++s)n(o[s],function(t,e){return t-e});return o};var n=t(\"uniq\")},{uniq:547}],172:[function(t,e,r){var n=t(\"strongly-connected-components\");e.exports=function(t){var e,r=[],i=[],a=[],o={},s=[];function l(t){var r,n,u=!1;for(i.push(t),a[t]=!0,r=0;r<s[t].length;r++)(n=s[t][r])===e?(c(e,i),u=!0):a[n]||(u=l(n));if(u)!function t(e){a[e]=!1,o.hasOwnProperty(e)&&Object.keys(o[e]).forEach(function(r){delete o[e][r],a[r]&&t(r)})}(t);else for(r=0;r<s[t].length;r++){n=s[t][r];var h=o[n];h||(h={},o[n]=h),h[n]=!0}return i.pop(),u}function c(t,e){var n=[].concat(e).concat(t);r.push(n)}function u(e){!function(e){for(var r=0;r<t.length;r++)r<e&&(t[r]=[]),t[r]=t[r].filter(function(t){return t>=e})}(e);for(var r,i=n(t).components.filter(function(t){return t.length>1}),a=1/0,o=0;o<i.length;o++)for(var s=0;s<i[o].length;s++)i[o][s]<a&&(a=i[o][s],r=o);var l=i[r];return!!l&&{leastVertex:a,adjList:t.map(function(t,e){return-1===l.indexOf(e)?[]:t.filter(function(t){return-1!==l.indexOf(t)})})}}e=0;for(var h=t.length;e<h;){var f=u(e);if(e=f.leastVertex,s=f.adjList){for(var p=0;p<s.length;p++)for(var d=0;d<s[p].length;d++){var g=s[p][d];a[+g]=!1,o[g]={}}l(e),e+=1}else e=h}return r}},{\"strongly-connected-components\":530}],173:[function(t,e,r){\"use strict\";var n=t(\"../../object/valid-value\");e.exports=function(){return n(this).length=0,this}},{\"../../object/valid-value\":205}],174:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Array.from:t(\"./shim\")},{\"./is-implemented\":175,\"./shim\":176}],175:[function(t,e,r){\"use strict\";e.exports=function(){var t,e,r=Array.from;return\"function\"==typeof r&&(e=r(t=[\"raz\",\"dwa\"]),Boolean(e&&e!==t&&\"dwa\"===e[1]))}},{}],176:[function(t,e,r){\"use strict\";var n=t(\"es6-symbol\").iterator,i=t(\"../../function/is-arguments\"),a=t(\"../../function/is-function\"),o=t(\"../../number/to-pos-integer\"),s=t(\"../../object/valid-callable\"),l=t(\"../../object/valid-value\"),c=t(\"../../object/is-value\"),u=t(\"../../string/is-string\"),h=Array.isArray,f=Function.prototype.call,p={configurable:!0,enumerable:!0,writable:!0,value:null},d=Object.defineProperty;e.exports=function(t){var e,r,g,v,m,y,x,b,_,w,k=arguments[1],T=arguments[2];if(t=Object(l(t)),c(k)&&s(k),this&&this!==Array&&a(this))e=this;else{if(!k){if(i(t))return 1!==(m=t.length)?Array.apply(null,t):((v=new Array(1))[0]=t[0],v);if(h(t)){for(v=new Array(m=t.length),r=0;r<m;++r)v[r]=t[r];return v}}v=[]}if(!h(t))if(void 0!==(_=t[n])){for(x=s(_).call(t),e&&(v=new e),b=x.next(),r=0;!b.done;)w=k?f.call(k,T,b.value,r):b.value,e?(p.value=w,d(v,r,p)):v[r]=w,b=x.next(),++r;m=r}else if(u(t)){for(m=t.length,e&&(v=new e),r=0,g=0;r<m;++r)w=t[r],r+1<m&&(y=w.charCodeAt(0))>=55296&&y<=56319&&(w+=t[++r]),w=k?f.call(k,T,w,g):w,e?(p.value=w,d(v,g,p)):v[g]=w,++g;m=g}if(void 0===m)for(m=o(t.length),e&&(v=new e(m)),r=0;r<m;++r)w=k?f.call(k,T,t[r],r):t[r],e?(p.value=w,d(v,r,p)):v[r]=w;return e&&(p.value=null,v.length=m),v}},{\"../../function/is-arguments\":177,\"../../function/is-function\":178,\"../../number/to-pos-integer\":184,\"../../object/is-value\":194,\"../../object/valid-callable\":203,\"../../object/valid-value\":205,\"../../string/is-string\":209,\"es6-symbol\":219}],177:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(function(){return arguments}());e.exports=function(t){return n.call(t)===i}},{}],178:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(t(\"./noop\"));e.exports=function(t){return\"function\"==typeof t&&n.call(t)===i}},{\"./noop\":179}],179:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],180:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Math.sign:t(\"./shim\")},{\"./is-implemented\":181,\"./shim\":182}],181:[function(t,e,r){\"use strict\";e.exports=function(){var t=Math.sign;return\"function\"==typeof t&&(1===t(10)&&-1===t(-20))}},{}],182:[function(t,e,r){\"use strict\";e.exports=function(t){return t=Number(t),isNaN(t)||0===t?t:t>0?1:-1}},{}],183:[function(t,e,r){\"use strict\";var n=t(\"../math/sign\"),i=Math.abs,a=Math.floor;e.exports=function(t){return isNaN(t)?0:0!==(t=Number(t))&&isFinite(t)?n(t)*a(i(t)):t}},{\"../math/sign\":180}],184:[function(t,e,r){\"use strict\";var n=t(\"./to-integer\"),i=Math.max;e.exports=function(t){return i(0,n(t))}},{\"./to-integer\":183}],185:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./valid-value\"),a=Function.prototype.bind,o=Function.prototype.call,s=Object.keys,l=Object.prototype.propertyIsEnumerable;e.exports=function(t,e){return function(r,c){var u,h=arguments[2],f=arguments[3];return r=Object(i(r)),n(c),u=s(r),f&&u.sort(\"function\"==typeof f?a.call(f,r):void 0),\"function\"!=typeof t&&(t=u[t]),o.call(t,u,function(t,n){return l.call(r,t)?o.call(c,h,r[t],t,r,n):e})}}},{\"./valid-callable\":203,\"./valid-value\":205}],186:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.assign:t(\"./shim\")},{\"./is-implemented\":187,\"./shim\":188}],187:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=Object.assign;return\"function\"==typeof e&&(e(t={foo:\"raz\"},{bar:\"dwa\"},{trzy:\"trzy\"}),t.foo+t.bar+t.trzy===\"razdwatrzy\")}},{}],188:[function(t,e,r){\"use strict\";var n=t(\"../keys\"),i=t(\"../valid-value\"),a=Math.max;e.exports=function(t,e){var r,o,s,l=a(arguments.length,2);for(t=Object(i(t)),s=function(n){try{t[n]=e[n]}catch(t){r||(r=t)}},o=1;o<l;++o)e=arguments[o],n(e).forEach(s);if(void 0!==r)throw r;return t}},{\"../keys\":195,\"../valid-value\":205}],189:[function(t,e,r){\"use strict\";var n=t(\"../array/from\"),i=t(\"./assign\"),a=t(\"./valid-value\");e.exports=function(t){var e=Object(a(t)),r=arguments[1],o=Object(arguments[2]);if(e!==t&&!r)return e;var s={};return r?n(r,function(e){(o.ensure||e in t)&&(s[e]=t[e])}):i(s,t),s}},{\"../array/from\":174,\"./assign\":186,\"./valid-value\":205}],190:[function(t,e,r){\"use strict\";var n,i,a,o,s=Object.create;t(\"./set-prototype-of/is-implemented\")()||(n=t(\"./set-prototype-of/shim\")),e.exports=n?1!==n.level?s:(i={},a={},o={configurable:!1,enumerable:!1,writable:!0,value:void 0},Object.getOwnPropertyNames(Object.prototype).forEach(function(t){a[t]=\"__proto__\"!==t?o:{configurable:!0,enumerable:!1,writable:!0,value:void 0}}),Object.defineProperties(i,a),Object.defineProperty(n,\"nullPolyfill\",{configurable:!1,enumerable:!1,writable:!1,value:i}),function(t,e){return s(null===t?i:t,e)}):s},{\"./set-prototype-of/is-implemented\":201,\"./set-prototype-of/shim\":202}],191:[function(t,e,r){\"use strict\";e.exports=t(\"./_iterate\")(\"forEach\")},{\"./_iterate\":185}],192:[function(t,e,r){\"use strict\";e.exports=function(t){return\"function\"==typeof t}},{}],193:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i={function:!0,object:!0};e.exports=function(t){return n(t)&&i[typeof t]||!1}},{\"./is-value\":194}],194:[function(t,e,r){\"use strict\";var n=t(\"../function/noop\")();e.exports=function(t){return t!==n&&null!==t}},{\"../function/noop\":179}],195:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.keys:t(\"./shim\")},{\"./is-implemented\":196,\"./shim\":197}],196:[function(t,e,r){\"use strict\";e.exports=function(){try{return Object.keys(\"primitive\"),!0}catch(t){return!1}}},{}],197:[function(t,e,r){\"use strict\";var n=t(\"../is-value\"),i=Object.keys;e.exports=function(t){return i(n(t)?Object(t):t)}},{\"../is-value\":194}],198:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./for-each\"),a=Function.prototype.call;e.exports=function(t,e){var r={},o=arguments[2];return n(e),i(t,function(t,n,i,s){r[n]=a.call(e,o,t,n,i,s)}),r}},{\"./for-each\":191,\"./valid-callable\":203}],199:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i=Array.prototype.forEach,a=Object.create;e.exports=function(t){var e=a(null);return i.call(arguments,function(t){n(t)&&function(t,e){var r;for(r in t)e[r]=t[r]}(Object(t),e)}),e}},{\"./is-value\":194}],200:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.setPrototypeOf:t(\"./shim\")},{\"./is-implemented\":201,\"./shim\":202}],201:[function(t,e,r){\"use strict\";var n=Object.create,i=Object.getPrototypeOf,a={};e.exports=function(){var t=Object.setPrototypeOf,e=arguments[0]||n;return\"function\"==typeof t&&i(t(e(null),a))===a}},{}],202:[function(t,e,r){\"use strict\";var n,i,a,o,s=t(\"../is-object\"),l=t(\"../valid-value\"),c=Object.prototype.isPrototypeOf,u=Object.defineProperty,h={configurable:!0,enumerable:!1,writable:!0,value:void 0};n=function(t,e){if(l(t),null===e||s(e))return t;throw new TypeError(\"Prototype must be null or an object\")},e.exports=(i=function(){var t,e=Object.create(null),r={},n=Object.getOwnPropertyDescriptor(Object.prototype,\"__proto__\");if(n){try{(t=n.set).call(e,r)}catch(t){}if(Object.getPrototypeOf(e)===r)return{set:t,level:2}}return e.__proto__=r,Object.getPrototypeOf(e)===r?{level:2}:((e={}).__proto__=r,Object.getPrototypeOf(e)===r&&{level:1})}())?(2===i.level?i.set?(o=i.set,a=function(t,e){return o.call(n(t,e),e),t}):a=function(t,e){return n(t,e).__proto__=e,t}:a=function t(e,r){var i;return n(e,r),(i=c.call(t.nullPolyfill,e))&&delete t.nullPolyfill.__proto__,null===r&&(r=t.nullPolyfill),e.__proto__=r,i&&u(t.nullPolyfill,\"__proto__\",h),e},Object.defineProperty(a,\"level\",{configurable:!1,enumerable:!1,writable:!1,value:i.level})):null,t(\"../create\")},{\"../create\":190,\"../is-object\":193,\"../valid-value\":205}],203:[function(t,e,r){\"use strict\";e.exports=function(t){if(\"function\"!=typeof t)throw new TypeError(t+\" is not a function\");return t}},{}],204:[function(t,e,r){\"use strict\";var n=t(\"./is-object\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not an Object\");return t}},{\"./is-object\":193}],205:[function(t,e,r){\"use strict\";var n=t(\"./is-value\");e.exports=function(t){if(!n(t))throw new TypeError(\"Cannot use null or undefined\");return t}},{\"./is-value\":194}],206:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?String.prototype.contains:t(\"./shim\")},{\"./is-implemented\":207,\"./shim\":208}],207:[function(t,e,r){\"use strict\";var n=\"razdwatrzy\";e.exports=function(){return\"function\"==typeof n.contains&&(!0===n.contains(\"dwa\")&&!1===n.contains(\"foo\"))}},{}],208:[function(t,e,r){\"use strict\";var n=String.prototype.indexOf;e.exports=function(t){return n.call(this,t,arguments[1])>-1}},{}],209:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(\"\");e.exports=function(t){return\"string\"==typeof t||t&&\"object\"==typeof t&&(t instanceof String||n.call(t)===i)||!1}},{}],210:[function(t,e,r){\"use strict\";var n=Object.create(null),i=Math.random;e.exports=function(){var t;do{t=i().toString(36).slice(2)}while(n[t]);return t}},{}],211:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"es5-ext/string/#/contains\"),o=t(\"d\"),s=t(\"es6-symbol\"),l=t(\"./\"),c=Object.defineProperty;n=e.exports=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");l.call(this,t),e=e?a.call(e,\"key+value\")?\"key+value\":a.call(e,\"key\")?\"key\":\"value\":\"value\",c(this,\"__kind__\",o(\"\",e))},i&&i(n,l),delete n.prototype.constructor,n.prototype=Object.create(l.prototype,{_resolve:o(function(t){return\"value\"===this.__kind__?this.__list__[t]:\"key+value\"===this.__kind__?[t,this.__list__[t]]:t})}),c(n.prototype,s.toStringTag,o(\"c\",\"Array Iterator\"))},{\"./\":214,d:151,\"es5-ext/object/set-prototype-of\":200,\"es5-ext/string/#/contains\":206,\"es6-symbol\":219}],212:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/valid-callable\"),a=t(\"es5-ext/string/is-string\"),o=t(\"./get\"),s=Array.isArray,l=Function.prototype.call,c=Array.prototype.some;e.exports=function(t,e){var r,u,h,f,p,d,g,v,m=arguments[2];if(s(t)||n(t)?r=\"array\":a(t)?r=\"string\":t=o(t),i(e),h=function(){f=!0},\"array\"!==r)if(\"string\"!==r)for(u=t.next();!u.done;){if(l.call(e,m,u.value,h),f)return;u=t.next()}else for(d=t.length,p=0;p<d&&(g=t[p],p+1<d&&(v=g.charCodeAt(0))>=55296&&v<=56319&&(g+=t[++p]),l.call(e,m,g,h),!f);++p);else c.call(t,function(t){return l.call(e,m,t,h),f})}},{\"./get\":213,\"es5-ext/function/is-arguments\":177,\"es5-ext/object/valid-callable\":203,\"es5-ext/string/is-string\":209}],213:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/string/is-string\"),a=t(\"./array\"),o=t(\"./string\"),s=t(\"./valid-iterable\"),l=t(\"es6-symbol\").iterator;e.exports=function(t){return\"function\"==typeof s(t)[l]?t[l]():n(t)?new a(t):i(t)?new o(t):new a(t)}},{\"./array\":211,\"./string\":216,\"./valid-iterable\":217,\"es5-ext/function/is-arguments\":177,\"es5-ext/string/is-string\":209,\"es6-symbol\":219}],214:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/array/#/clear\"),a=t(\"es5-ext/object/assign\"),o=t(\"es5-ext/object/valid-callable\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"d\"),c=t(\"d/auto-bind\"),u=t(\"es6-symbol\"),h=Object.defineProperty,f=Object.defineProperties;e.exports=n=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");f(this,{__list__:l(\"w\",s(t)),__context__:l(\"w\",e),__nextIndex__:l(\"w\",0)}),e&&(o(e.on),e.on(\"_add\",this._onAdd),e.on(\"_delete\",this._onDelete),e.on(\"_clear\",this._onClear))},delete n.prototype.constructor,f(n.prototype,a({_next:l(function(){var t;if(this.__list__)return this.__redo__&&void 0!==(t=this.__redo__.shift())?t:this.__nextIndex__<this.__list__.length?this.__nextIndex__++:void this._unBind()}),next:l(function(){return this._createResult(this._next())}),_createResult:l(function(t){return void 0===t?{done:!0,value:void 0}:{done:!1,value:this._resolve(t)}}),_resolve:l(function(t){return this.__list__[t]}),_unBind:l(function(){this.__list__=null,delete this.__redo__,this.__context__&&(this.__context__.off(\"_add\",this._onAdd),this.__context__.off(\"_delete\",this._onDelete),this.__context__.off(\"_clear\",this._onClear),this.__context__=null)}),toString:l(function(){return\"[object \"+(this[u.toStringTag]||\"Object\")+\"]\"})},c({_onAdd:l(function(t){t>=this.__nextIndex__||(++this.__nextIndex__,this.__redo__?(this.__redo__.forEach(function(e,r){e>=t&&(this.__redo__[r]=++e)},this),this.__redo__.push(t)):h(this,\"__redo__\",l(\"c\",[t])))}),_onDelete:l(function(t){var e;t>=this.__nextIndex__||(--this.__nextIndex__,this.__redo__&&(-1!==(e=this.__redo__.indexOf(t))&&this.__redo__.splice(e,1),this.__redo__.forEach(function(e,r){e>t&&(this.__redo__[r]=--e)},this)))}),_onClear:l(function(){this.__redo__&&i.call(this.__redo__),this.__nextIndex__=0})}))),h(n.prototype,u.iterator,l(function(){return this}))},{d:151,\"d/auto-bind\":150,\"es5-ext/array/#/clear\":173,\"es5-ext/object/assign\":186,\"es5-ext/object/valid-callable\":203,\"es5-ext/object/valid-value\":205,\"es6-symbol\":219}],215:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/string/is-string\"),o=t(\"es6-symbol\").iterator,s=Array.isArray;e.exports=function(t){return!!i(t)&&(!!s(t)||(!!a(t)||(!!n(t)||\"function\"==typeof t[o])))}},{\"es5-ext/function/is-arguments\":177,\"es5-ext/object/is-value\":194,\"es5-ext/string/is-string\":209,\"es6-symbol\":219}],216:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"d\"),o=t(\"es6-symbol\"),s=t(\"./\"),l=Object.defineProperty;n=e.exports=function(t){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");t=String(t),s.call(this,t),l(this,\"__length__\",a(\"\",t.length))},i&&i(n,s),delete n.prototype.constructor,n.prototype=Object.create(s.prototype,{_next:a(function(){if(this.__list__)return this.__nextIndex__<this.__length__?this.__nextIndex__++:void this._unBind()}),_resolve:a(function(t){var e,r=this.__list__[t];return this.__nextIndex__===this.__length__?r:(e=r.charCodeAt(0))>=55296&&e<=56319?r+this.__list__[this.__nextIndex__++]:r})}),l(n.prototype,o.toStringTag,a(\"c\",\"String Iterator\"))},{\"./\":214,d:151,\"es5-ext/object/set-prototype-of\":200,\"es6-symbol\":219}],217:[function(t,e,r){\"use strict\";var n=t(\"./is-iterable\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not iterable\");return t}},{\"./is-iterable\":215}],218:[function(t,e,r){(function(n,i){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():t.ES6Promise=n()}(this,function(){\"use strict\";function e(t){return\"function\"==typeof t}var r=Array.isArray?Array.isArray:function(t){return\"[object Array]\"===Object.prototype.toString.call(t)},a=0,o=void 0,s=void 0,l=function(t,e){g[a]=t,g[a+1]=e,2===(a+=2)&&(s?s(v):_())};var c=\"undefined\"!=typeof window?window:void 0,u=c||{},h=u.MutationObserver||u.WebKitMutationObserver,f=\"undefined\"==typeof self&&\"undefined\"!=typeof n&&\"[object process]\"==={}.toString.call(n),p=\"undefined\"!=typeof Uint8ClampedArray&&\"undefined\"!=typeof importScripts&&\"undefined\"!=typeof MessageChannel;function d(){var t=setTimeout;return function(){return t(v,1)}}var g=new Array(1e3);function v(){for(var t=0;t<a;t+=2){(0,g[t])(g[t+1]),g[t]=void 0,g[t+1]=void 0}a=0}var m,y,x,b,_=void 0;function w(t,e){var r=arguments,n=this,i=new this.constructor(A);void 0===i[T]&&V(i);var a,o=n._state;return o?(a=r[o-1],l(function(){return j(o,i,a,n._result)})):R(n,i,t,e),i}function k(t){if(t&&\"object\"==typeof t&&t.constructor===this)return t;var e=new this(A);return O(e,t),e}f?_=function(){return n.nextTick(v)}:h?(y=0,x=new h(v),b=document.createTextNode(\"\"),x.observe(b,{characterData:!0}),_=function(){b.data=y=++y%2}):p?((m=new MessageChannel).port1.onmessage=v,_=function(){return m.port2.postMessage(0)}):_=void 0===c&&\"function\"==typeof t?function(){try{var e=t(\"vertx\");return o=e.runOnLoop||e.runOnContext,function(){o(v)}}catch(t){return d()}}():d();var T=Math.random().toString(36).substring(16);function A(){}var M=void 0,S=1,E=2,C=new B;function L(t){try{return t.then}catch(t){return C.error=t,C}}function P(t,r,n){r.constructor===t.constructor&&n===w&&r.constructor.resolve===k?function(t,e){e._state===S?I(t,e._result):e._state===E?D(t,e._result):R(e,void 0,function(e){return O(t,e)},function(e){return D(t,e)})}(t,r):n===C?D(t,C.error):void 0===n?I(t,r):e(n)?function(t,e,r){l(function(t){var n=!1,i=function(t,e,r,n){try{t.call(e,r,n)}catch(t){return t}}(r,e,function(r){n||(n=!0,e!==r?O(t,r):I(t,r))},function(e){n||(n=!0,D(t,e))},t._label);!n&&i&&(n=!0,D(t,i))},t)}(t,r,n):I(t,r)}function O(t,e){var r;t===e?D(t,new TypeError(\"You cannot resolve a promise with itself\")):\"function\"==typeof(r=e)||\"object\"==typeof r&&null!==r?P(t,e,L(e)):I(t,e)}function z(t){t._onerror&&t._onerror(t._result),F(t)}function I(t,e){t._state===M&&(t._result=e,t._state=S,0!==t._subscribers.length&&l(F,t))}function D(t,e){t._state===M&&(t._state=E,t._result=e,l(z,t))}function R(t,e,r,n){var i=t._subscribers,a=i.length;t._onerror=null,i[a]=e,i[a+S]=r,i[a+E]=n,0===a&&t._state&&l(F,t)}function F(t){var e=t._subscribers,r=t._state;if(0!==e.length){for(var n=void 0,i=void 0,a=t._result,o=0;o<e.length;o+=3)n=e[o],i=e[o+r],n?j(r,n,i,a):i(a);t._subscribers.length=0}}function B(){this.error=null}var N=new B;function j(t,r,n,i){var a=e(n),o=void 0,s=void 0,l=void 0,c=void 0;if(a){if((o=function(t,e){try{return t(e)}catch(t){return N.error=t,N}}(n,i))===N?(c=!0,s=o.error,o=null):l=!0,r===o)return void D(r,new TypeError(\"A promises callback cannot return that same promise.\"))}else o=i,l=!0;r._state!==M||(a&&l?O(r,o):c?D(r,s):t===S?I(r,o):t===E&&D(r,o))}var U=0;function V(t){t[T]=U++,t._state=void 0,t._result=void 0,t._subscribers=[]}function q(t,e){this._instanceConstructor=t,this.promise=new t(A),this.promise[T]||V(this.promise),r(e)?(this._input=e,this.length=e.length,this._remaining=e.length,this._result=new Array(this.length),0===this.length?I(this.promise,this._result):(this.length=this.length||0,this._enumerate(),0===this._remaining&&I(this.promise,this._result))):D(this.promise,new Error(\"Array Methods must be provided an Array\"))}function H(t){this[T]=U++,this._result=this._state=void 0,this._subscribers=[],A!==t&&(\"function\"!=typeof t&&function(){throw new TypeError(\"You must pass a resolver function as the first argument to the promise constructor\")}(),this instanceof H?function(t,e){try{e(function(e){O(t,e)},function(e){D(t,e)})}catch(e){D(t,e)}}(this,t):function(){throw new TypeError(\"Failed to construct 'Promise': Please use the 'new' operator, this object constructor cannot be called as a function.\")}())}function G(){var t=void 0;if(\"undefined\"!=typeof i)t=i;else if(\"undefined\"!=typeof self)t=self;else try{t=Function(\"return this\")()}catch(t){throw new Error(\"polyfill failed because global object is unavailable in this environment\")}var e=t.Promise;if(e){var r=null;try{r=Object.prototype.toString.call(e.resolve())}catch(t){}if(\"[object Promise]\"===r&&!e.cast)return}t.Promise=H}return q.prototype._enumerate=function(){for(var t=this.length,e=this._input,r=0;this._state===M&&r<t;r++)this._eachEntry(e[r],r)},q.prototype._eachEntry=function(t,e){var r=this._instanceConstructor,n=r.resolve;if(n===k){var i=L(t);if(i===w&&t._state!==M)this._settledAt(t._state,e,t._result);else if(\"function\"!=typeof i)this._remaining--,this._result[e]=t;else if(r===H){var a=new r(A);P(a,t,i),this._willSettleAt(a,e)}else this._willSettleAt(new r(function(e){return e(t)}),e)}else this._willSettleAt(n(t),e)},q.prototype._settledAt=function(t,e,r){var n=this.promise;n._state===M&&(this._remaining--,t===E?D(n,r):this._result[e]=r),0===this._remaining&&I(n,this._result)},q.prototype._willSettleAt=function(t,e){var r=this;R(t,void 0,function(t){return r._settledAt(S,e,t)},function(t){return r._settledAt(E,e,t)})},H.all=function(t){return new q(this,t).promise},H.race=function(t){var e=this;return r(t)?new e(function(r,n){for(var i=t.length,a=0;a<i;a++)e.resolve(t[a]).then(r,n)}):new e(function(t,e){return e(new TypeError(\"You must pass an array to race.\"))})},H.resolve=k,H.reject=function(t){var e=new this(A);return D(e,t),e},H._setScheduler=function(t){s=t},H._setAsap=function(t){l=t},H._asap=l,H.prototype={constructor:H,then:w,catch:function(t){return this.then(null,t)}},G(),H.polyfill=G,H.Promise=H,H})}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{_process:482}],219:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Symbol:t(\"./polyfill\")},{\"./is-implemented\":220,\"./polyfill\":222}],220:[function(t,e,r){\"use strict\";var n={object:!0,symbol:!0};e.exports=function(){var t;if(\"function\"!=typeof Symbol)return!1;t=Symbol(\"test symbol\");try{String(t)}catch(t){return!1}return!!n[typeof Symbol.iterator]&&(!!n[typeof Symbol.toPrimitive]&&!!n[typeof Symbol.toStringTag])}},{}],221:[function(t,e,r){\"use strict\";e.exports=function(t){return!!t&&(\"symbol\"==typeof t||!!t.constructor&&(\"Symbol\"===t.constructor.name&&\"Symbol\"===t[t.constructor.toStringTag]))}},{}],222:[function(t,e,r){\"use strict\";var n,i,a,o,s=t(\"d\"),l=t(\"./validate-symbol\"),c=Object.create,u=Object.defineProperties,h=Object.defineProperty,f=Object.prototype,p=c(null);if(\"function\"==typeof Symbol){n=Symbol;try{String(n()),o=!0}catch(t){}}var d,g=(d=c(null),function(t){for(var e,r,n=0;d[t+(n||\"\")];)++n;return d[t+=n||\"\"]=!0,h(f,e=\"@@\"+t,s.gs(null,function(t){r||(r=!0,h(this,e,s(t)),r=!1)})),e});a=function(t){if(this instanceof a)throw new TypeError(\"Symbol is not a constructor\");return i(t)},e.exports=i=function t(e){var r;if(this instanceof t)throw new TypeError(\"Symbol is not a constructor\");return o?n(e):(r=c(a.prototype),e=void 0===e?\"\":String(e),u(r,{__description__:s(\"\",e),__name__:s(\"\",g(e))}))},u(i,{for:s(function(t){return p[t]?p[t]:p[t]=i(String(t))}),keyFor:s(function(t){var e;for(e in l(t),p)if(p[e]===t)return e}),hasInstance:s(\"\",n&&n.hasInstance||i(\"hasInstance\")),isConcatSpreadable:s(\"\",n&&n.isConcatSpreadable||i(\"isConcatSpreadable\")),iterator:s(\"\",n&&n.iterator||i(\"iterator\")),match:s(\"\",n&&n.match||i(\"match\")),replace:s(\"\",n&&n.replace||i(\"replace\")),search:s(\"\",n&&n.search||i(\"search\")),species:s(\"\",n&&n.species||i(\"species\")),split:s(\"\",n&&n.split||i(\"split\")),toPrimitive:s(\"\",n&&n.toPrimitive||i(\"toPrimitive\")),toStringTag:s(\"\",n&&n.toStringTag||i(\"toStringTag\")),unscopables:s(\"\",n&&n.unscopables||i(\"unscopables\"))}),u(a.prototype,{constructor:s(i),toString:s(\"\",function(){return this.__name__})}),u(i.prototype,{toString:s(function(){return\"Symbol (\"+l(this).__description__+\")\"}),valueOf:s(function(){return l(this)})}),h(i.prototype,i.toPrimitive,s(\"\",function(){var t=l(this);return\"symbol\"==typeof t?t:t.toString()})),h(i.prototype,i.toStringTag,s(\"c\",\"Symbol\")),h(a.prototype,i.toStringTag,s(\"c\",i.prototype[i.toStringTag])),h(a.prototype,i.toPrimitive,s(\"c\",i.prototype[i.toPrimitive]))},{\"./validate-symbol\":223,d:151}],223:[function(t,e,r){\"use strict\";var n=t(\"./is-symbol\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not a symbol\");return t}},{\"./is-symbol\":221}],224:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=e||0,i=r||1;return[[t[12]+t[0],t[13]+t[1],t[14]+t[2],t[15]+t[3]],[t[12]-t[0],t[13]-t[1],t[14]-t[2],t[15]-t[3]],[t[12]+t[4],t[13]+t[5],t[14]+t[6],t[15]+t[7]],[t[12]-t[4],t[13]-t[5],t[14]-t[6],t[15]-t[7]],[n*t[12]+t[8],n*t[13]+t[9],n*t[14]+t[10],n*t[15]+t[11]],[i*t[12]-t[8],i*t[13]-t[9],i*t[14]-t[10],i*t[15]-t[11]]]}},{}],225:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\");e.exports=function(t){var e=typeof t;if(\"string\"===e){var r=t;if(0===(t=+t)&&n(r))return!1}else if(\"number\"!==e)return!1;return t-t<1}},{\"is-string-blank\":423}],226:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 0:return new o([0],[0],0);case 1:if(\"number\"==typeof t){var n=l(t);return new o(n,n,0)}return new o(t,l(t.length),0);case 2:if(\"number\"==typeof e){var n=l(t.length);return new o(t,n,+e)}r=0;case 3:if(t.length!==e.length)throw new Error(\"state and velocity lengths must match\");return new o(t,e,r)}};var n=t(\"cubic-hermite\"),i=t(\"binary-search-bounds\");function a(t,e,r){return Math.min(e,Math.max(t,r))}function o(t,e,r){this.dimension=t.length,this.bounds=[new Array(this.dimension),new Array(this.dimension)];for(var n=0;n<this.dimension;++n)this.bounds[0][n]=-1/0,this.bounds[1][n]=1/0;this._state=t.slice().reverse(),this._velocity=e.slice().reverse(),this._time=[r],this._scratch=[t.slice(),t.slice(),t.slice(),t.slice(),t.slice()]}var s=o.prototype;function l(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=0;return e}s.flush=function(t){var e=i.gt(this._time,t)-1;e<=0||(this._time.splice(0,e),this._state.splice(0,e*this.dimension),this._velocity.splice(0,e*this.dimension))},s.curve=function(t){var e=this._time,r=e.length,o=i.le(e,t),s=this._scratch[0],l=this._state,c=this._velocity,u=this.dimension,h=this.bounds;if(o<0)for(var f=u-1,p=0;p<u;++p,--f)s[p]=l[f];else if(o>=r-1){f=l.length-1;var d=t-e[r-1];for(p=0;p<u;++p,--f)s[p]=l[f]+d*c[f]}else{f=u*(o+1)-1;var g=e[o],v=e[o+1]-g||1,m=this._scratch[1],y=this._scratch[2],x=this._scratch[3],b=this._scratch[4],_=!0;for(p=0;p<u;++p,--f)m[p]=l[f],x[p]=c[f]*v,y[p]=l[f+u],b[p]=c[f+u]*v,_=_&&m[p]===y[p]&&x[p]===b[p]&&0===x[p];if(_)for(p=0;p<u;++p)s[p]=m[p];else n(m,x,y,b,(t-g)/v,s)}var w=h[0],k=h[1];for(p=0;p<u;++p)s[p]=a(w[p],k[p],s[p]);return s},s.dcurve=function(t){var e=this._time,r=e.length,a=i.le(e,t),o=this._scratch[0],s=this._state,l=this._velocity,c=this.dimension;if(a>=r-1)for(var u=s.length-1,h=(e[r-1],0);h<c;++h,--u)o[h]=l[u];else{u=c*(a+1)-1;var f=e[a],p=e[a+1]-f||1,d=this._scratch[1],g=this._scratch[2],v=this._scratch[3],m=this._scratch[4],y=!0;for(h=0;h<c;++h,--u)d[h]=s[u],v[h]=l[u]*p,g[h]=s[u+c],m[h]=l[u+c]*p,y=y&&d[h]===g[h]&&v[h]===m[h]&&0===v[h];if(y)for(h=0;h<c;++h)o[h]=0;else{n.derivative(d,v,g,m,(t-f)/p,o);for(h=0;h<c;++h)o[h]/=p}}return o},s.lastT=function(){var t=this._time;return t[t.length-1]},s.stable=function(){for(var t=this._velocity,e=t.length,r=this.dimension-1;r>=0;--r)if(t[--e])return!1;return!0},s.jump=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1];this._time.push(e,t);for(var u=0;u<2;++u)for(var h=0;h<r;++h)n.push(n[o++]),i.push(0);this._time.push(t);for(h=r;h>0;--h)n.push(a(l[h-1],c[h-1],arguments[h])),i.push(0)}},s.push=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=t-e,l=this.bounds,c=l[0],u=l[1],h=s>1e-6?1/s:0;this._time.push(t);for(var f=r;f>0;--f){var p=a(c[f-1],u[f-1],arguments[f]);n.push(p),i.push((p-n[o++])*h)}}},s.set=function(t){var e=this.dimension;if(!(t<this.lastT()||arguments.length!==e+1)){var r=this._state,n=this._velocity,i=this.bounds,o=i[0],s=i[1];this._time.push(t);for(var l=e;l>0;--l)r.push(a(o[l-1],s[l-1],arguments[l])),n.push(0)}},s.move=function(t){var e=this.lastT(),r=this.dimension;if(!(t<=e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1],u=t-e,h=u>1e-6?1/u:0;this._time.push(t);for(var f=r;f>0;--f){var p=arguments[f];n.push(a(l[f-1],c[f-1],n[o++]+p)),i.push(p*h)}}},s.idle=function(t){var e=this.lastT();if(!(t<e)){var r=this.dimension,n=this._state,i=this._velocity,o=n.length-r,s=this.bounds,l=s[0],c=s[1],u=t-e;this._time.push(t);for(var h=r-1;h>=0;--h)n.push(a(l[h],c[h],n[o]+u*i[o])),i.push(0),o+=1}}},{\"binary-search-bounds\":91,\"cubic-hermite\":145}],227:[function(t,e,r){var n=t(\"dtype\");e.exports=function(t,e,r){if(!t)throw new TypeError(\"must specify data as first parameter\");if(r=0|+(r||0),Array.isArray(t)&&t[0]&&\"number\"==typeof t[0][0]){var i,a,o,s,l=t[0].length,c=t.length*l;e&&\"string\"!=typeof e||(e=new(n(e||\"float32\"))(c+r));var u=e.length-r;if(c!==u)throw new Error(\"source length \"+c+\" (\"+l+\"x\"+t.length+\") does not match destination length \"+u);for(i=0,o=r;i<t.length;i++)for(a=0;a<l;a++)e[o++]=null===t[i][a]?NaN:t[i][a]}else if(e&&\"string\"!=typeof e)e.set(t,r);else{var h=n(e||\"float32\");if(Array.isArray(t)||\"array\"===e)for(e=new h(t.length+r),i=0,o=r,s=e.length;o<s;o++,i++)e[o]=null===t[i]?NaN:t[i];else 0===r?e=new h(t):(e=new h(t.length+r)).set(t,r)}return e}},{dtype:169}],228:[function(t,e,r){\"use strict\";var n=t(\"css-font/stringify\"),i=[32,126];e.exports=function(t){var e=(t=t||{}).shape?t.shape:t.canvas?[t.canvas.width,t.canvas.height]:[512,512],r=t.canvas||document.createElement(\"canvas\"),a=t.font,o=\"number\"==typeof t.step?[t.step,t.step]:t.step||[32,32],s=t.chars||i;a&&\"string\"!=typeof a&&(a=n(a));if(Array.isArray(s)){if(2===s.length&&\"number\"==typeof s[0]&&\"number\"==typeof s[1]){for(var l=[],c=s[0],u=0;c<=s[1];c++)l[u++]=String.fromCharCode(c);s=l}}else s=String(s).split(\"\");e=e.slice(),r.width=e[0],r.height=e[1];var h=r.getContext(\"2d\");h.fillStyle=\"#000\",h.fillRect(0,0,r.width,r.height),h.font=a,h.textAlign=\"center\",h.textBaseline=\"middle\",h.fillStyle=\"#fff\";for(var f=o[0]/2,p=o[1]/2,c=0;c<s.length;c++)h.fillText(s[c],f,p),(f+=o[0])>e[0]-o[0]/2&&(f=o[0]/2,p+=o[1]);return r}},{\"css-font/stringify\":142}],229:[function(t,e,r){\"use strict\";function n(t,e){e||(e={}),(\"string\"==typeof t||Array.isArray(t))&&(e.family=t);var r=Array.isArray(e.family)?e.family.join(\", \"):e.family;if(!r)throw Error(\"`family` must be defined\");var s=e.size||e.fontSize||e.em||48,l=e.weight||e.fontWeight||\"\",c=(t=[e.style||e.fontStyle||\"\",l,s].join(\" \")+\"px \"+r,e.origin||\"top\");if(n.cache[r]&&s<=n.cache[r].em)return i(n.cache[r],c);var u=e.canvas||n.canvas,h=u.getContext(\"2d\"),f={upper:void 0!==e.upper?e.upper:\"H\",lower:void 0!==e.lower?e.lower:\"x\",descent:void 0!==e.descent?e.descent:\"p\",ascent:void 0!==e.ascent?e.ascent:\"h\",tittle:void 0!==e.tittle?e.tittle:\"i\",overshoot:void 0!==e.overshoot?e.overshoot:\"O\"},p=Math.ceil(1.5*s);u.height=p,u.width=.5*p,h.font=t;var d={top:0};h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillStyle=\"black\",h.fillText(\"H\",0,0);var g=a(h.getImageData(0,0,p,p));h.clearRect(0,0,p,p),h.textBaseline=\"bottom\",h.fillText(\"H\",0,p);var v=a(h.getImageData(0,0,p,p));d.lineHeight=d.bottom=p-v+g,h.clearRect(0,0,p,p),h.textBaseline=\"alphabetic\",h.fillText(\"H\",0,p);var m=p-a(h.getImageData(0,0,p,p))-1+g;d.baseline=d.alphabetic=m,h.clearRect(0,0,p,p),h.textBaseline=\"middle\",h.fillText(\"H\",0,.5*p);var y=a(h.getImageData(0,0,p,p));d.median=d.middle=p-y-1+g-.5*p,h.clearRect(0,0,p,p),h.textBaseline=\"hanging\",h.fillText(\"H\",0,.5*p);var x=a(h.getImageData(0,0,p,p));d.hanging=p-x-1+g-.5*p,h.clearRect(0,0,p,p),h.textBaseline=\"ideographic\",h.fillText(\"H\",0,p);var b=a(h.getImageData(0,0,p,p));if(d.ideographic=p-b-1+g,f.upper&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.upper,0,0),d.upper=a(h.getImageData(0,0,p,p)),d.capHeight=d.baseline-d.upper),f.lower&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.lower,0,0),d.lower=a(h.getImageData(0,0,p,p)),d.xHeight=d.baseline-d.lower),f.tittle&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.tittle,0,0),d.tittle=a(h.getImageData(0,0,p,p))),f.ascent&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.ascent,0,0),d.ascent=a(h.getImageData(0,0,p,p))),f.descent&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.descent,0,0),d.descent=o(h.getImageData(0,0,p,p))),f.overshoot){h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.overshoot,0,0);var _=o(h.getImageData(0,0,p,p));d.overshoot=_-m}for(var w in d)d[w]/=s;return d.em=s,n.cache[r]=d,i(d,c)}function i(t,e){var r={};for(var n in\"string\"==typeof e&&(e=t[e]),t)\"em\"!==n&&(r[n]=t[n]-e);return r}function a(t){for(var e=t.height,r=t.data,n=3;n<r.length;n+=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}function o(t){for(var e=t.height,r=t.data,n=r.length-1;n>0;n-=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}e.exports=n,n.canvas=document.createElement(\"canvas\"),n.cache={}},{}],230:[function(t,e,r){\"use strict\";e.exports=function(t){return new c(t||d,null)};var n=0,i=1;function a(t,e,r,n,i,a){this._color=t,this.key=e,this.value=r,this.left=n,this.right=i,this._count=a}function o(t){return new a(t._color,t.key,t.value,t.left,t.right,t._count)}function s(t,e){return new a(t,e.key,e.value,e.left,e.right,e._count)}function l(t){t._count=1+(t.left?t.left._count:0)+(t.right?t.right._count:0)}function c(t,e){this._compare=t,this.root=e}var u=c.prototype;function h(t,e){this.tree=t,this._stack=e}Object.defineProperty(u,\"keys\",{get:function(){var t=[];return this.forEach(function(e,r){t.push(e)}),t}}),Object.defineProperty(u,\"values\",{get:function(){var t=[];return this.forEach(function(e,r){t.push(r)}),t}}),Object.defineProperty(u,\"length\",{get:function(){return this.root?this.root._count:0}}),u.insert=function(t,e){for(var r=this._compare,o=this.root,u=[],h=[];o;){var f=r(t,o.key);u.push(o),h.push(f),o=f<=0?o.left:o.right}u.push(new a(n,t,e,null,null,1));for(var p=u.length-2;p>=0;--p){o=u[p];h[p]<=0?u[p]=new a(o._color,o.key,o.value,u[p+1],o.right,o._count+1):u[p]=new a(o._color,o.key,o.value,o.left,u[p+1],o._count+1)}for(p=u.length-1;p>1;--p){var d=u[p-1];o=u[p];if(d._color===i||o._color===i)break;var g=u[p-2];if(g.left===d)if(d.left===o){if(!(v=g.right)||v._color!==n){if(g._color=n,g.left=d.right,d._color=i,d.right=g,u[p-2]=d,u[p-1]=o,l(g),l(d),p>=3)(m=u[p-3]).left===g?m.left=d:m.right=d;break}d._color=i,g.right=s(i,v),g._color=n,p-=1}else{if(!(v=g.right)||v._color!==n){if(d.right=o.left,g._color=n,g.left=o.right,o._color=i,o.left=d,o.right=g,u[p-2]=o,u[p-1]=d,l(g),l(d),l(o),p>=3)(m=u[p-3]).left===g?m.left=o:m.right=o;break}d._color=i,g.right=s(i,v),g._color=n,p-=1}else if(d.right===o){if(!(v=g.left)||v._color!==n){if(g._color=n,g.right=d.left,d._color=i,d.left=g,u[p-2]=d,u[p-1]=o,l(g),l(d),p>=3)(m=u[p-3]).right===g?m.right=d:m.left=d;break}d._color=i,g.left=s(i,v),g._color=n,p-=1}else{var v;if(!(v=g.left)||v._color!==n){var m;if(d.left=o.right,g._color=n,g.right=o.left,o._color=i,o.right=d,o.left=g,u[p-2]=o,u[p-1]=d,l(g),l(d),l(o),p>=3)(m=u[p-3]).right===g?m.right=o:m.left=o;break}d._color=i,g.left=s(i,v),g._color=n,p-=1}}return u[0]._color=i,new c(r,u[0])},u.forEach=function(t,e,r){if(this.root)switch(arguments.length){case 1:return function t(e,r){var n;if(r.left&&(n=t(e,r.left)))return n;return(n=e(r.key,r.value))||(r.right?t(e,r.right):void 0)}(t,this.root);case 2:return function t(e,r,n,i){if(r(e,i.key)<=0){var a;if(i.left&&(a=t(e,r,n,i.left)))return a;if(a=n(i.key,i.value))return a}if(i.right)return t(e,r,n,i.right)}(e,this._compare,t,this.root);case 3:if(this._compare(e,r)>=0)return;return function t(e,r,n,i,a){var o,s=n(e,a.key),l=n(r,a.key);if(s<=0){if(a.left&&(o=t(e,r,n,i,a.left)))return o;if(l>0&&(o=i(a.key,a.value)))return o}if(l>0&&a.right)return t(e,r,n,i,a.right)}(e,r,this._compare,t,this.root)}},Object.defineProperty(u,\"begin\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.left;return new h(this,t)}}),Object.defineProperty(u,\"end\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.right;return new h(this,t)}}),u.at=function(t){if(t<0)return new h(this,[]);for(var e=this.root,r=[];;){if(r.push(e),e.left){if(t<e.left._count){e=e.left;continue}t-=e.left._count}if(!t)return new h(this,r);if(t-=1,!e.right)break;if(t>=e.right._count)break;e=e.right}return new h(this,[])},u.ge=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<=0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},u.gt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},u.lt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},u.le=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>=0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},u.find=function(t){for(var e=this._compare,r=this.root,n=[];r;){var i=e(t,r.key);if(n.push(r),0===i)return new h(this,n);r=i<=0?r.left:r.right}return new h(this,[])},u.remove=function(t){var e=this.find(t);return e?e.remove():this},u.get=function(t){for(var e=this._compare,r=this.root;r;){var n=e(t,r.key);if(0===n)return r.value;r=n<=0?r.left:r.right}};var f=h.prototype;function p(t,e){t.key=e.key,t.value=e.value,t.left=e.left,t.right=e.right,t._color=e._color,t._count=e._count}function d(t,e){return t<e?-1:t>e?1:0}Object.defineProperty(f,\"valid\",{get:function(){return this._stack.length>0}}),Object.defineProperty(f,\"node\",{get:function(){return this._stack.length>0?this._stack[this._stack.length-1]:null},enumerable:!0}),f.clone=function(){return new h(this.tree,this._stack.slice())},f.remove=function(){var t=this._stack;if(0===t.length)return this.tree;var e=new Array(t.length),r=t[t.length-1];e[e.length-1]=new a(r._color,r.key,r.value,r.left,r.right,r._count);for(var u=t.length-2;u>=0;--u){(r=t[u]).left===t[u+1]?e[u]=new a(r._color,r.key,r.value,e[u+1],r.right,r._count):e[u]=new a(r._color,r.key,r.value,r.left,e[u+1],r._count)}if((r=e[e.length-1]).left&&r.right){var h=e.length;for(r=r.left;r.right;)e.push(r),r=r.right;var f=e[h-1];e.push(new a(r._color,f.key,f.value,r.left,r.right,r._count)),e[h-1].key=r.key,e[h-1].value=r.value;for(u=e.length-2;u>=h;--u)r=e[u],e[u]=new a(r._color,r.key,r.value,r.left,e[u+1],r._count);e[h-1].left=e[h]}if((r=e[e.length-1])._color===n){var d=e[e.length-2];d.left===r?d.left=null:d.right===r&&(d.right=null),e.pop();for(u=0;u<e.length;++u)e[u]._count--;return new c(this.tree._compare,e[0])}if(r.left||r.right){r.left?p(r,r.left):r.right&&p(r,r.right),r._color=i;for(u=0;u<e.length-1;++u)e[u]._count--;return new c(this.tree._compare,e[0])}if(1===e.length)return new c(this.tree._compare,null);for(u=0;u<e.length;++u)e[u]._count--;var g=e[e.length-2];return function(t){for(var e,r,a,c,u=t.length-1;u>=0;--u){if(e=t[u],0===u)return void(e._color=i);if((r=t[u-1]).left===e){if((a=r.right).right&&a.right._color===n)return c=(a=r.right=o(a)).right=o(a.right),r.right=a.left,a.left=r,a.right=c,a._color=r._color,e._color=i,r._color=i,c._color=i,l(r),l(a),u>1&&((h=t[u-2]).left===r?h.left=a:h.right=a),void(t[u-1]=a);if(a.left&&a.left._color===n)return c=(a=r.right=o(a)).left=o(a.left),r.right=c.left,a.left=c.right,c.left=r,c.right=a,c._color=r._color,r._color=i,a._color=i,e._color=i,l(r),l(a),l(c),u>1&&((h=t[u-2]).left===r?h.left=c:h.right=c),void(t[u-1]=c);if(a._color===i){if(r._color===n)return r._color=i,void(r.right=s(n,a));r.right=s(n,a);continue}a=o(a),r.right=a.left,a.left=r,a._color=r._color,r._color=n,l(r),l(a),u>1&&((h=t[u-2]).left===r?h.left=a:h.right=a),t[u-1]=a,t[u]=r,u+1<t.length?t[u+1]=e:t.push(e),u+=2}else{if((a=r.left).left&&a.left._color===n)return c=(a=r.left=o(a)).left=o(a.left),r.left=a.right,a.right=r,a.left=c,a._color=r._color,e._color=i,r._color=i,c._color=i,l(r),l(a),u>1&&((h=t[u-2]).right===r?h.right=a:h.left=a),void(t[u-1]=a);if(a.right&&a.right._color===n)return c=(a=r.left=o(a)).right=o(a.right),r.left=c.right,a.right=c.left,c.right=r,c.left=a,c._color=r._color,r._color=i,a._color=i,e._color=i,l(r),l(a),l(c),u>1&&((h=t[u-2]).right===r?h.right=c:h.left=c),void(t[u-1]=c);if(a._color===i){if(r._color===n)return r._color=i,void(r.left=s(n,a));r.left=s(n,a);continue}var h;a=o(a),r.left=a.right,a.right=r,a._color=r._color,r._color=n,l(r),l(a),u>1&&((h=t[u-2]).right===r?h.right=a:h.left=a),t[u-1]=a,t[u]=r,u+1<t.length?t[u+1]=e:t.push(e),u+=2}}}(e),g.left===r?g.left=null:g.right=null,new c(this.tree._compare,e[0])},Object.defineProperty(f,\"key\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].key},enumerable:!0}),Object.defineProperty(f,\"value\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].value},enumerable:!0}),Object.defineProperty(f,\"index\",{get:function(){var t=0,e=this._stack;if(0===e.length){var r=this.tree.root;return r?r._count:0}e[e.length-1].left&&(t=e[e.length-1].left._count);for(var n=e.length-2;n>=0;--n)e[n+1]===e[n].right&&(++t,e[n].left&&(t+=e[n].left._count));return t},enumerable:!0}),f.next=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.right)for(e=e.right;e;)t.push(e),e=e.left;else for(t.pop();t.length>0&&t[t.length-1].right===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(f,\"hasNext\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].right)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].left===t[e])return!0;return!1}}),f.update=function(t){var e=this._stack;if(0===e.length)throw new Error(\"Can't update empty node!\");var r=new Array(e.length),n=e[e.length-1];r[r.length-1]=new a(n._color,n.key,t,n.left,n.right,n._count);for(var i=e.length-2;i>=0;--i)(n=e[i]).left===e[i+1]?r[i]=new a(n._color,n.key,n.value,r[i+1],n.right,n._count):r[i]=new a(n._color,n.key,n.value,n.left,r[i+1],n._count);return new c(this.tree._compare,r[0])},f.prev=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.left)for(e=e.left;e;)t.push(e),e=e.right;else for(t.pop();t.length>0&&t[t.length-1].left===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(f,\"hasPrev\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].left)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].right===t[e])return!0;return!1}})},{}],231:[function(t,e,r){var n=[.9999999999998099,676.5203681218851,-1259.1392167224028,771.3234287776531,-176.6150291621406,12.507343278686905,-.13857109526572012,9984369578019572e-21,1.5056327351493116e-7],i=607/128,a=[.9999999999999971,57.15623566586292,-59.59796035547549,14.136097974741746,-.4919138160976202,3399464998481189e-20,4652362892704858e-20,-9837447530487956e-20,.0001580887032249125,-.00021026444172410488,.00021743961811521265,-.0001643181065367639,8441822398385275e-20,-26190838401581408e-21,36899182659531625e-22];function o(t){if(t<0)return Number(\"0/0\");for(var e=a[0],r=a.length-1;r>0;--r)e+=a[r]/(t+r);var n=t+i+.5;return.5*Math.log(2*Math.PI)+(t+.5)*Math.log(n)-n+Math.log(e)-Math.log(t)}e.exports=function t(e){if(e<.5)return Math.PI/(Math.sin(Math.PI*e)*t(1-e));if(e>100)return Math.exp(o(e));e-=1;for(var r=n[0],i=1;i<9;i++)r+=n[i]/(e+i);var a=e+7+.5;return Math.sqrt(2*Math.PI)*Math.pow(a,e+.5)*Math.exp(-a)*r},e.exports.log=o},{}],232:[function(t,e,r){e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"must specify type string\");if(e=e||{},\"undefined\"==typeof document&&!e.canvas)return null;var r=e.canvas||document.createElement(\"canvas\");\"number\"==typeof e.width&&(r.width=e.width);\"number\"==typeof e.height&&(r.height=e.height);var n,i=e;try{var a=[t];0===t.indexOf(\"webgl\")&&a.push(\"experimental-\"+t);for(var o=0;o<a.length;o++)if(n=r.getContext(a[o],i))return n}catch(t){n=null}return n||null}},{}],233:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=new u(t);return r.update(e),r};var n=t(\"./lib/text.js\"),i=t(\"./lib/lines.js\"),a=t(\"./lib/background.js\"),o=t(\"./lib/cube.js\"),s=t(\"./lib/ticks.js\"),l=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]);function c(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function u(t){this.gl=t,this.pixelRatio=1,this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.autoTicks=!0,this.tickSpacing=[1,1,1],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickAlign=[\"auto\",\"auto\",\"auto\"],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[10,10,10],this.lastCubeProps={cubeEdges:[0,0,0],axis:[0,0,0]},this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=\"sans-serif\",this.labelSize=[20,20,20],this.labelAngle=[0,0,0],this.labelAlign=[\"auto\",\"auto\",\"auto\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[10,10,10],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[0,0,0],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!1,!1,!1],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._firstInit=!0,this._text=null,this._lines=null,this._background=a(t)}var h=u.prototype;function f(){this.primalOffset=[0,0,0],this.primalMinor=[0,0,0],this.mirrorOffset=[0,0,0],this.mirrorMinor=[0,0,0]}h.update=function(t){function e(e,r,n){if(n in t){var i,a=t[n],o=this[n];(e?Array.isArray(a)&&Array.isArray(a[0]):Array.isArray(a))?this[n]=i=[r(a[0]),r(a[1]),r(a[2])]:this[n]=i=[r(a),r(a),r(a)];for(var s=0;s<3;++s)if(i[s]!==o[s])return!0}return!1}t=t||{};var r,a=e.bind(this,!1,Number),o=e.bind(this,!1,Boolean),l=e.bind(this,!1,String),c=e.bind(this,!0,function(t){if(Array.isArray(t)){if(3===t.length)return[+t[0],+t[1],+t[2],1];if(4===t.length)return[+t[0],+t[1],+t[2],+t[3]]}return[0,0,0,1]}),u=!1,h=!1;if(\"bounds\"in t)for(var f=t.bounds,p=0;p<2;++p)for(var d=0;d<3;++d)f[p][d]!==this.bounds[p][d]&&(h=!0),this.bounds[p][d]=f[p][d];if(\"ticks\"in t){r=t.ticks,u=!0,this.autoTicks=!1;for(p=0;p<3;++p)this.tickSpacing[p]=0}else a(\"tickSpacing\")&&(this.autoTicks=!0,h=!0);if(this._firstInit&&(\"ticks\"in t||\"tickSpacing\"in t||(this.autoTicks=!0),h=!0,u=!0,this._firstInit=!1),h&&this.autoTicks&&(r=s.create(this.bounds,this.tickSpacing),u=!0),u){for(p=0;p<3;++p)r[p].sort(function(t,e){return t.x-e.x});s.equal(r,this.ticks)?u=!1:this.ticks=r}o(\"tickEnable\"),l(\"tickFont\")&&(u=!0),a(\"tickSize\"),a(\"tickAngle\"),a(\"tickPad\"),c(\"tickColor\");var g=l(\"labels\");l(\"labelFont\")&&(g=!0),o(\"labelEnable\"),a(\"labelSize\"),a(\"labelPad\"),c(\"labelColor\"),o(\"lineEnable\"),o(\"lineMirror\"),a(\"lineWidth\"),c(\"lineColor\"),o(\"lineTickEnable\"),o(\"lineTickMirror\"),a(\"lineTickLength\"),a(\"lineTickWidth\"),c(\"lineTickColor\"),o(\"gridEnable\"),a(\"gridWidth\"),c(\"gridColor\"),o(\"zeroEnable\"),c(\"zeroLineColor\"),a(\"zeroLineWidth\"),o(\"backgroundEnable\"),c(\"backgroundColor\"),this._text?this._text&&(g||u)&&this._text.update(this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont):this._text=n(this.gl,this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont),this._lines&&u&&(this._lines.dispose(),this._lines=null),this._lines||(this._lines=i(this.gl,this.bounds,this.ticks))};var p=[new f,new f,new f];function d(t,e,r,n,i){for(var a=t.primalOffset,o=t.primalMinor,s=t.mirrorOffset,l=t.mirrorMinor,c=n[e],u=0;u<3;++u)if(e!==u){var h=a,f=s,p=o,d=l;c&1<<u&&(h=s,f=a,p=l,d=o),h[u]=r[0][u],f[u]=r[1][u],i[u]>0?(p[u]=-1,d[u]=0):(p[u]=0,d[u]=1)}}var g=[0,0,0],v={model:l,view:l,projection:l,_ortho:!1};h.isOpaque=function(){return!0},h.isTransparent=function(){return!1},h.drawTransparent=function(t){};var m=[0,0,0],y=[0,0,0],x=[0,0,0];h.draw=function(t){t=t||v;for(var e=this.gl,r=t.model||l,n=t.view||l,i=t.projection||l,a=this.bounds,s=t._ortho||!1,u=o(r,n,i,a,s),h=u.cubeEdges,f=u.axis,b=n[12],_=n[13],w=n[14],k=n[15],T=(s?2:1)*this.pixelRatio*(i[3]*b+i[7]*_+i[11]*w+i[15]*k)/e.drawingBufferHeight,A=0;A<3;++A)this.lastCubeProps.cubeEdges[A]=h[A],this.lastCubeProps.axis[A]=f[A];var M=p;for(A=0;A<3;++A)d(p[A],A,this.bounds,h,f);e=this.gl;var S,E=g;for(A=0;A<3;++A)this.backgroundEnable[A]?E[A]=f[A]:E[A]=0;this._background.draw(r,n,i,a,E,this.backgroundColor),this._lines.bind(r,n,i,this);for(A=0;A<3;++A){var C=[0,0,0];f[A]>0?C[A]=a[1][A]:C[A]=a[0][A];for(var L=0;L<2;++L){var P=(A+1+L)%3,O=(A+1+(1^L))%3;this.gridEnable[P]&&this._lines.drawGrid(P,O,this.bounds,C,this.gridColor[P],this.gridWidth[P]*this.pixelRatio)}for(L=0;L<2;++L){P=(A+1+L)%3,O=(A+1+(1^L))%3;this.zeroEnable[O]&&Math.min(a[0][O],a[1][O])<=0&&Math.max(a[0][O],a[1][O])>=0&&this._lines.drawZero(P,O,this.bounds,C,this.zeroLineColor[O],this.zeroLineWidth[O]*this.pixelRatio)}}for(A=0;A<3;++A){this.lineEnable[A]&&this._lines.drawAxisLine(A,this.bounds,M[A].primalOffset,this.lineColor[A],this.lineWidth[A]*this.pixelRatio),this.lineMirror[A]&&this._lines.drawAxisLine(A,this.bounds,M[A].mirrorOffset,this.lineColor[A],this.lineWidth[A]*this.pixelRatio);var z=c(m,M[A].primalMinor),I=c(y,M[A].mirrorMinor),D=this.lineTickLength;for(L=0;L<3;++L){var R=T/r[5*L];z[L]*=D[L]*R,I[L]*=D[L]*R}this.lineTickEnable[A]&&this._lines.drawAxisTicks(A,M[A].primalOffset,z,this.lineTickColor[A],this.lineTickWidth[A]*this.pixelRatio),this.lineTickMirror[A]&&this._lines.drawAxisTicks(A,M[A].mirrorOffset,I,this.lineTickColor[A],this.lineTickWidth[A]*this.pixelRatio)}this._lines.unbind(),this._text.bind(r,n,i,this.pixelRatio);var F,B;function N(t){(B=[0,0,0])[t]=1}function j(t,e,r){var n=(t+1)%3,i=(t+2)%3,a=e[n],o=e[i],s=r[n],l=r[i];a>0&&l>0?N(n):a>0&&l<0?N(n):a<0&&l>0?N(n):a<0&&l<0?N(n):o>0&&s>0?N(i):o>0&&s<0?N(i):o<0&&s>0?N(i):o<0&&s<0&&N(i)}for(A=0;A<3;++A){var U=M[A].primalMinor,V=M[A].mirrorMinor,q=c(x,M[A].primalOffset);for(L=0;L<3;++L)this.lineTickEnable[A]&&(q[L]+=T*U[L]*Math.max(this.lineTickLength[L],0)/r[5*L]);var H=[0,0,0];if(H[A]=1,this.tickEnable[A]){-3600===this.tickAngle[A]?(this.tickAngle[A]=0,this.tickAlign[A]=\"auto\"):this.tickAlign[A]=-1,F=1,\"auto\"===(S=[this.tickAlign[A],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]),B=[0,0,0],j(A,U,V);for(L=0;L<3;++L)q[L]+=T*U[L]*this.tickPad[L]/r[5*L];this._text.drawTicks(A,this.tickSize[A],this.tickAngle[A],q,this.tickColor[A],H,B,S)}if(this.labelEnable[A]){F=0,B=[0,0,0],this.labels[A].length>4&&(N(A),F=1),\"auto\"===(S=[this.labelAlign[A],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]);for(L=0;L<3;++L)q[L]+=T*U[L]*this.labelPad[L]/r[5*L];q[A]+=.5*(a[0][A]+a[1][A]),this._text.drawLabel(A,this.labelSize[A],this.labelAngle[A],q,this.labelColor[A],[0,0,0],B,S)}}this._text.unbind()},h.dispose=function(){this._text.dispose(),this._lines.dispose(),this._background.dispose(),this._lines=null,this._text=null,this._background=null,this.gl=null}},{\"./lib/background.js\":234,\"./lib/cube.js\":235,\"./lib/lines.js\":236,\"./lib/text.js\":238,\"./lib/ticks.js\":239}],234:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=[],r=[],s=0,l=0;l<3;++l)for(var c=(l+1)%3,u=(l+2)%3,h=[0,0,0],f=[0,0,0],p=-1;p<=1;p+=2){r.push(s,s+2,s+1,s+1,s+2,s+3),h[l]=p,f[l]=p;for(var d=-1;d<=1;d+=2){h[c]=d;for(var g=-1;g<=1;g+=2)h[u]=g,e.push(h[0],h[1],h[2],f[0],f[1],f[2]),s+=1}var v=c;c=u,u=v}var m=n(t,new Float32Array(e)),y=n(t,new Uint16Array(r),t.ELEMENT_ARRAY_BUFFER),x=i(t,[{buffer:m,type:t.FLOAT,size:3,offset:0,stride:24},{buffer:m,type:t.FLOAT,size:3,offset:12,stride:24}],y),b=a(t);return b.attributes.position.location=0,b.attributes.normal.location=1,new o(t,m,x,b)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").bg;function o(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n}var s=o.prototype;s.draw=function(t,e,r,n,i,a){for(var o=!1,s=0;s<3;++s)o=o||i[s];if(o){var l=this.gl;l.enable(l.POLYGON_OFFSET_FILL),l.polygonOffset(1,2),this.shader.bind(),this.shader.uniforms={model:t,view:e,projection:r,bounds:n,enable:i,colors:a},this.vao.bind(),this.vao.draw(this.gl.TRIANGLES,36),this.vao.unbind(),l.disable(l.POLYGON_OFFSET_FILL)}},s.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders\":237,\"gl-buffer\":241,\"gl-vao\":327}],235:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,p){i(s,e,t),i(s,r,s);for(var y=0,x=0;x<2;++x){u[2]=a[x][2];for(var b=0;b<2;++b){u[1]=a[b][1];for(var _=0;_<2;++_)u[0]=a[_][0],f(l[y],u,s),y+=1}}for(var w=-1,x=0;x<8;++x){for(var k=l[x][3],T=0;T<3;++T)c[x][T]=l[x][T]/k;p&&(c[x][2]*=-1),k<0&&(w<0?w=x:c[x][2]<c[w][2]&&(w=x))}if(w<0){w=0;for(var A=0;A<3;++A){for(var M=(A+2)%3,S=(A+1)%3,E=-1,C=-1,L=0;L<2;++L){var P=L<<A,O=P+(L<<M)+(1-L<<S),z=P+(1-L<<M)+(L<<S);o(c[P],c[O],c[z],h)<0||(L?E=1:C=1)}if(E<0||C<0)C>E&&(w|=1<<A);else{for(var L=0;L<2;++L){var P=L<<A,O=P+(L<<M)+(1-L<<S),z=P+(1-L<<M)+(L<<S),I=d([l[P],l[O],l[z],l[P+(1<<M)+(1<<S)]]);L?E=I:C=I}C>E&&(w|=1<<A)}}}for(var D=7^w,R=-1,x=0;x<8;++x)x!==w&&x!==D&&(R<0?R=x:c[R][1]>c[x][1]&&(R=x));for(var F=-1,x=0;x<3;++x){var B=R^1<<x;if(B!==w&&B!==D){F<0&&(F=B);var S=c[B];S[0]<c[F][0]&&(F=B)}}for(var N=-1,x=0;x<3;++x){var B=R^1<<x;if(B!==w&&B!==D&&B!==F){N<0&&(N=B);var S=c[B];S[0]>c[N][0]&&(N=B)}}var j=g;j[0]=j[1]=j[2]=0,j[n.log2(F^R)]=R&F,j[n.log2(R^N)]=R&N;var U=7^N;U===w||U===D?(U=7^F,j[n.log2(N^U)]=U&N):j[n.log2(F^U)]=U&F;for(var V=v,q=w,A=0;A<3;++A)V[A]=q&1<<A?-1:1;return m};var n=t(\"bit-twiddle\"),i=t(\"gl-mat4/multiply\"),a=t(\"split-polygon\"),o=t(\"robust-orientation\"),s=new Array(16),l=new Array(8),c=new Array(8),u=new Array(3),h=[0,0,0];function f(t,e,r){for(var n=0;n<4;++n){t[n]=r[12+n];for(var i=0;i<3;++i)t[n]+=e[i]*r[4*i+n]}}!function(){for(var t=0;t<8;++t)l[t]=[1,1,1,1],c[t]=[1,1,1]}();var p=[[0,0,1,0,0],[0,0,-1,1,0],[0,-1,0,1,0],[0,1,0,1,0],[-1,0,0,1,0],[1,0,0,1,0]];function d(t){for(var e=0;e<p.length;++e)if((t=a.positive(t,p[e])).length<3)return 0;var r=t[0],n=r[0]/r[3],i=r[1]/r[3],o=0;for(e=1;e+1<t.length;++e){var s=t[e],l=t[e+1],c=s[0]/s[3]-n,u=s[1]/s[3]-i,h=l[0]/l[3]-n,f=l[1]/l[3]-i;o+=Math.abs(c*f-u*h)}return o}var g=[1,1,1],v=[0,0,0],m={cubeEdges:g,axis:v}},{\"bit-twiddle\":92,\"gl-mat4/multiply\":267,\"robust-orientation\":510,\"split-polygon\":527}],236:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var o=[],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[0,0,0];o.push(0,0,1,0,1,1,0,0,-1,0,0,-1,0,1,1,0,1,-1);for(var h=0;h<3;++h){for(var f=o.length/3|0,d=0;d<r[h].length;++d){var g=+r[h][d].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var v=o.length/3|0;s[h]=f,l[h]=v-f;for(var f=o.length/3|0,m=0;m<r[h].length;++m){var g=+r[h][m].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var v=o.length/3|0;c[h]=f,u[h]=v-f}var y=n(t,new Float32Array(o)),x=i(t,[{buffer:y,type:t.FLOAT,size:3,stride:0,offset:0}]),b=a(t);return b.attributes.position.location=0,new p(t,y,x,b,l,s,u,c)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").line,o=[0,0,0],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[1,1];function h(t){return t[0]=t[1]=t[2]=0,t}function f(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function p(t,e,r,n,i,a,o,s){this.gl=t,this.vertBuffer=e,this.vao=r,this.shader=n,this.tickCount=i,this.tickOffset=a,this.gridCount=o,this.gridOffset=s}var d=p.prototype;d.bind=function(t,e,r){this.shader.bind(),this.shader.uniforms.model=t,this.shader.uniforms.view=e,this.shader.uniforms.projection=r,u[0]=this.gl.drawingBufferWidth,u[1]=this.gl.drawingBufferHeight,this.shader.uniforms.screenShape=u,this.vao.bind()},d.unbind=function(){this.vao.unbind()},d.drawAxisLine=function(t,e,r,n,i){var a=h(s);this.shader.uniforms.majorAxis=s,a[t]=e[1][t]-e[0][t],this.shader.uniforms.minorAxis=a;var o,u=f(c,r);u[t]+=e[0][t],this.shader.uniforms.offset=u,this.shader.uniforms.lineWidth=i,this.shader.uniforms.color=n,(o=h(l))[(t+2)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6),(o=h(l))[(t+1)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6)},d.drawAxisTicks=function(t,e,r,n,i){if(this.tickCount[t]){var a=h(o);a[t]=1,this.shader.uniforms.majorAxis=a,this.shader.uniforms.offset=e,this.shader.uniforms.minorAxis=r,this.shader.uniforms.color=n,this.shader.uniforms.lineWidth=i;var s=h(l);s[t]=1,this.shader.uniforms.screenAxis=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t])}},d.drawGrid=function(t,e,r,n,i,a){if(this.gridCount[t]){var u=h(s);u[e]=r[1][e]-r[0][e],this.shader.uniforms.minorAxis=u;var p=f(c,n);p[e]+=r[0][e],this.shader.uniforms.offset=p;var d=h(o);d[t]=1,this.shader.uniforms.majorAxis=d;var g=h(l);g[t]=1,this.shader.uniforms.screenAxis=g,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,this.gridCount[t],this.gridOffset[t])}},d.drawZero=function(t,e,r,n,i,a){var o=h(s);this.shader.uniforms.majorAxis=o,o[t]=r[1][t]-r[0][t],this.shader.uniforms.minorAxis=o;var u=f(c,n);u[t]+=r[0][t],this.shader.uniforms.offset=u;var p=h(l);p[e]=1,this.shader.uniforms.screenAxis=p,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,6)},d.dispose=function(){this.vao.dispose(),this.vertBuffer.dispose(),this.shader.dispose()}},{\"./shaders\":237,\"gl-buffer\":241,\"gl-vao\":327}],237:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, majorAxis, minorAxis, screenAxis;\\nuniform float lineWidth;\\nuniform vec2 screenShape;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nvoid main() {\\n  vec3 major = position.x * majorAxis;\\n  vec3 minor = position.y * minorAxis;\\n\\n  vec3 vPosition = major + minor + offset;\\n  vec3 pPosition = project(vPosition);\\n  vec3 offset = project(vPosition + screenAxis * position.z);\\n\\n  vec2 screen = normalize((offset - pPosition).xy * screenShape) / screenShape;\\n\\n  gl_Position = vec4(pPosition + vec3(0.5 * screen * lineWidth, 0), 1.0);\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.line=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"}])};var s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, axis, alignDir, alignOpt;\\nuniform float scale, angle, pixelScale;\\nuniform vec2 resolution;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nfloat computeViewAngle(vec3 a, vec3 b) {\\n  vec3 A = project(a);\\n  vec3 B = project(b);\\n\\n  return atan(\\n    (B.y - A.y) * resolution.y,\\n    (B.x - A.x) * resolution.x\\n  );\\n}\\n\\nconst float PI = 3.141592;\\nconst float TWO_PI = 2.0 * PI;\\nconst float HALF_PI = 0.5 * PI;\\nconst float ONE_AND_HALF_PI = 1.5 * PI;\\n\\nint option = int(floor(alignOpt.x + 0.001));\\nfloat hv_ratio =       alignOpt.y;\\nbool enableAlign =    (alignOpt.z != 0.0);\\n\\nfloat mod_angle(float a) {\\n  return mod(a, PI);\\n}\\n\\nfloat positive_angle(float a) {\\n  return mod_angle((a < 0.0) ?\\n    a + TWO_PI :\\n    a\\n  );\\n}\\n\\nfloat look_upwards(float a) {\\n  float b = positive_angle(a);\\n  return ((b > HALF_PI) && (b <= ONE_AND_HALF_PI)) ?\\n    b - PI :\\n    b;\\n}\\n\\nfloat look_horizontal_or_vertical(float a, float ratio) {\\n  // ratio controls the ratio between being horizontal to (vertical + horizontal)\\n  // if ratio is set to 0.5 then it is 50%, 50%.\\n  // when using a higher ratio e.g. 0.75 the result would\\n  // likely be more horizontal than vertical.\\n\\n  float b = positive_angle(a);\\n\\n  return\\n    (b < (      ratio) * HALF_PI) ? 0.0 :\\n    (b < (2.0 - ratio) * HALF_PI) ? -HALF_PI :\\n    (b < (2.0 + ratio) * HALF_PI) ? 0.0 :\\n    (b < (4.0 - ratio) * HALF_PI) ? HALF_PI :\\n                                    0.0;\\n}\\n\\nfloat roundTo(float a, float b) {\\n  return float(b * floor((a + 0.5 * b) / b));\\n}\\n\\nfloat look_round_n_directions(float a, int n) {\\n  float b = positive_angle(a);\\n  float div = TWO_PI / float(n);\\n  float c = roundTo(b, div);\\n  return look_upwards(c);\\n}\\n\\nfloat applyAlignOption(float rawAngle, float delta) {\\n  return\\n    (option >  2) ? look_round_n_directions(rawAngle + delta, option) :       // option 3-n: round to n directions\\n    (option == 2) ? look_horizontal_or_vertical(rawAngle + delta, hv_ratio) : // horizontal or vertical\\n    (option == 1) ? rawAngle + delta :       // use free angle, and flip to align with one direction of the axis\\n    (option == 0) ? look_upwards(rawAngle) : // use free angle, and stay upwards\\n    (option ==-1) ? 0.0 :                    // useful for backward compatibility, all texts remains horizontal\\n                    rawAngle;                // otherwise return back raw input angle\\n}\\n\\nbool isAxisTitle = (axis.x == 0.0) &&\\n                   (axis.y == 0.0) &&\\n                   (axis.z == 0.0);\\n\\nvoid main() {\\n  //Compute world offset\\n  float axisDistance = position.z;\\n  vec3 dataPosition = axisDistance * axis + offset;\\n\\n  float beta = angle; // i.e. user defined attributes for each tick\\n\\n  float axisAngle;\\n  float clipAngle;\\n  float flip;\\n\\n  if (enableAlign) {\\n    axisAngle = (isAxisTitle) ? HALF_PI :\\n                      computeViewAngle(dataPosition, dataPosition + axis);\\n    clipAngle = computeViewAngle(dataPosition, dataPosition + alignDir);\\n\\n    axisAngle += (sin(axisAngle) < 0.0) ? PI : 0.0;\\n    clipAngle += (sin(clipAngle) < 0.0) ? PI : 0.0;\\n\\n    flip = (dot(vec2(cos(axisAngle), sin(axisAngle)),\\n                vec2(sin(clipAngle),-cos(clipAngle))) > 0.0) ? 1.0 : 0.0;\\n\\n    beta += applyAlignOption(clipAngle, flip * PI);\\n  }\\n\\n  //Compute plane offset\\n  vec2 planeCoord = position.xy * pixelScale;\\n\\n  mat2 planeXform = scale * mat2(\\n     cos(beta), sin(beta),\\n    -sin(beta), cos(beta)\\n  );\\n\\n  vec2 viewOffset = 2.0 * planeXform * planeCoord / resolution;\\n\\n  //Compute clip position\\n  vec3 clipPosition = project(dataPosition);\\n\\n  //Apply text offset in clip coordinates\\n  clipPosition += vec3(viewOffset, 0.0);\\n\\n  //Done\\n  gl_Position = vec4(clipPosition, 1.0);\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.text=function(t){return i(t,s,l,null,[{name:\"position\",type:\"vec3\"}])};var c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec3 normal;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 enable;\\nuniform vec3 bounds[2];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n\\n  vec3 signAxis = sign(bounds[1] - bounds[0]);\\n\\n  vec3 realNormal = signAxis * normal;\\n\\n  if(dot(realNormal, enable) > 0.0) {\\n    vec3 minRange = min(bounds[0], bounds[1]);\\n    vec3 maxRange = max(bounds[0], bounds[1]);\\n    vec3 nPosition = mix(minRange, maxRange, 0.5 * (position + 1.0));\\n    gl_Position = projection * view * model * vec4(nPosition, 1.0);\\n  } else {\\n    gl_Position = vec4(0,0,0,0);\\n  }\\n\\n  colorChannel = abs(realNormal);\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 colors[3];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n  gl_FragColor = colorChannel.x * colors[0] +\\n                 colorChannel.y * colors[1] +\\n                 colorChannel.z * colors[2];\\n}\"]);r.bg=function(t){return i(t,c,u,null,[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}])}},{\"gl-shader\":301,glslify:409}],238:[function(t,e,r){(function(r){\"use strict\";e.exports=function(t,e,r,a,s,l){var u=n(t),h=i(t,[{buffer:u,size:3}]),f=o(t);f.attributes.position.location=0;var p=new c(t,f,u,h);return p.update(e,r,a,s,l),p};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"vectorize-text\"),o=t(\"./shaders\").text,s=window||r.global||{},l=s.__TEXT_CACHE||{};s.__TEXT_CACHE={};function c(t,e,r,n){this.gl=t,this.shader=e,this.buffer=r,this.vao=n,this.tickOffset=this.tickCount=this.labelOffset=this.labelCount=null}var u=c.prototype,h=[0,0];u.bind=function(t,e,r,n){this.vao.bind(),this.shader.bind();var i=this.shader.uniforms;i.model=t,i.view=e,i.projection=r,i.pixelScale=n,h[0]=this.gl.drawingBufferWidth,h[1]=this.gl.drawingBufferHeight,this.shader.uniforms.resolution=h},u.unbind=function(){this.vao.unbind()},u.update=function(t,e,r,n,i){var o=[];function s(t,e,r,n,i,s){var c=l[r];c||(c=l[r]={});var u=c[e];u||(u=c[e]=function(t,e){try{return a(t,e)}catch(e){return console.warn('error vectorizing text:\"'+t+'\" error:',e),{cells:[],positions:[]}}}(e,{triangles:!0,font:r,textAlign:\"center\",textBaseline:\"middle\",lineSpacing:i,styletags:s}));for(var h=(n||12)/12,f=u.positions,p=u.cells,d=0,g=p.length;d<g;++d)for(var v=p[d],m=2;m>=0;--m){var y=f[v[m]];o.push(h*y[0],-h*y[1],t)}}for(var c=[0,0,0],u=[0,0,0],h=[0,0,0],f=[0,0,0],p={breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},d=0;d<3;++d){h[d]=o.length/3|0,s(.5*(t[0][d]+t[1][d]),e[d],r[d],12,1.25,p),f[d]=(o.length/3|0)-h[d],c[d]=o.length/3|0;for(var g=0;g<n[d].length;++g)n[d][g].text&&s(n[d][g].x,n[d][g].text,n[d][g].font||i,n[d][g].fontSize||12,1.25,p);u[d]=(o.length/3|0)-c[d]}this.buffer.update(o),this.tickOffset=c,this.tickCount=u,this.labelOffset=h,this.labelCount=f},u.drawTicks=function(t,e,r,n,i,a,o,s){this.tickCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t]))},u.drawLabel=function(t,e,r,n,i,a,o,s){this.labelCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.labelCount[t],this.labelOffset[t]))},u.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()}}).call(this,t(\"_process\"))},{\"./shaders\":237,_process:482,\"gl-buffer\":241,\"gl-vao\":327,\"vectorize-text\":550}],239:[function(t,e,r){\"use strict\";function n(t,e){var r=t+\"\",n=r.indexOf(\".\"),i=0;n>=0&&(i=r.length-n-1);var a=Math.pow(10,i),o=Math.round(t*e*a),s=o+\"\";if(s.indexOf(\"e\")>=0)return s;var l=o/a,c=o%a;o<0?(l=0|-Math.ceil(l),c=0|-c):(l=0|Math.floor(l),c|=0);var u=\"\"+l;if(o<0&&(u=\"-\"+u),i){for(var h=\"\"+c;h.length<i;)h=\"0\"+h;return u+\".\"+h}return u}r.create=function(t,e){for(var r=[],i=0;i<3;++i){for(var a=[],o=(t[0][i],t[1][i],0);o*e[i]<=t[1][i];++o)a.push({x:o*e[i],text:n(e[i],o)});for(var o=-1;o*e[i]>=t[0][i];--o)a.push({x:o*e[i],text:n(e[i],o)});r.push(a)}return r},r.equal=function(t,e){for(var r=0;r<3;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;++n){var i=t[r][n],a=e[r][n];if(i.x!==a.x||i.text!==a.text||i.font!==a.font||i.fontColor!==a.fontColor||i.fontSize!==a.fontSize||i.dx!==a.dx||i.dy!==a.dy)return!1}}return!0}},{}],240:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,l,h){var f=e.model||c,p=e.view||c,m=e.projection||c,y=e._ortho||!1,x=t.bounds,b=(h=h||a(f,p,m,x,y)).axis;o(u,p,f),o(u,m,u);for(var _=g,w=0;w<3;++w)_[w].lo=1/0,_[w].hi=-1/0,_[w].pixelsPerDataUnit=1/0;var k=n(s(u,u));s(u,u);for(var T=0;T<3;++T){var A=(T+1)%3,M=(T+2)%3,S=v;t:for(var w=0;w<2;++w){var E=[];if(b[T]<0!=!!w){S[T]=x[w][T];for(var C=0;C<2;++C){S[A]=x[C^w][A];for(var L=0;L<2;++L)S[M]=x[L^C^w][M],E.push(S.slice())}for(var P=y?5:4,C=P;C===P;++C){if(0===E.length)continue t;E=i.positive(E,k[C])}for(var C=0;C<E.length;++C)for(var M=E[C],O=d(v,u,M,r,l),L=0;L<3;++L)_[L].lo=Math.min(_[L].lo,M[L]),_[L].hi=Math.max(_[L].hi,M[L]),L!==T&&(_[L].pixelsPerDataUnit=Math.min(_[L].pixelsPerDataUnit,Math.abs(O[L])))}}}return _};var n=t(\"extract-frustum-planes\"),i=t(\"split-polygon\"),a=t(\"./lib/cube.js\"),o=t(\"gl-mat4/multiply\"),s=t(\"gl-mat4/transpose\"),l=t(\"gl-vec4/transformMat4\"),c=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]),u=new Float32Array(16);function h(t,e,r){this.lo=t,this.hi=e,this.pixelsPerDataUnit=r}var f=[0,0,0,1],p=[0,0,0,1];function d(t,e,r,n,i){for(var a=0;a<3;++a){for(var o=f,s=p,c=0;c<3;++c)s[c]=o[c]=r[c];s[3]=o[3]=1,s[a]+=1,l(s,s,e),s[3]<0&&(t[a]=1/0),o[a]-=1,l(o,o,e),o[3]<0&&(t[a]=1/0);var u=(o[0]/o[3]-s[0]/s[3])*n,h=(o[1]/o[3]-s[1]/s[3])*i;t[a]=.25*Math.sqrt(u*u+h*h)}return t}var g=[new h(1/0,-1/0,1/0),new h(1/0,-1/0,1/0),new h(1/0,-1/0,1/0)],v=[0,0,0]},{\"./lib/cube.js\":235,\"extract-frustum-planes\":224,\"gl-mat4/multiply\":267,\"gl-mat4/transpose\":276,\"gl-vec4/transformMat4\":398,\"split-polygon\":527}],241:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"ndarray-ops\"),a=t(\"ndarray\"),o=[\"uint8\",\"uint8_clamped\",\"uint16\",\"uint32\",\"int8\",\"int16\",\"int32\",\"float32\"];function s(t,e,r,n,i){this.gl=t,this.type=e,this.handle=r,this.length=n,this.usage=i}var l=s.prototype;function c(t,e,r,n,i,a){var o=i.length*i.BYTES_PER_ELEMENT;if(a<0)return t.bufferData(e,i,n),o;if(o+a>r)throw new Error(\"gl-buffer: If resizing buffer, must not specify offset\");return t.bufferSubData(e,a,i),r}function u(t,e){for(var r=n.malloc(t.length,e),i=t.length,a=0;a<i;++a)r[a]=t[a];return r}l.bind=function(){this.gl.bindBuffer(this.type,this.handle)},l.unbind=function(){this.gl.bindBuffer(this.type,null)},l.dispose=function(){this.gl.deleteBuffer(this.handle)},l.update=function(t,e){if(\"number\"!=typeof e&&(e=-1),this.bind(),\"object\"==typeof t&&\"undefined\"!=typeof t.shape){var r=t.dtype;if(o.indexOf(r)<0&&(r=\"float32\"),this.type===this.gl.ELEMENT_ARRAY_BUFFER)r=gl.getExtension(\"OES_element_index_uint\")&&\"uint16\"!==r?\"uint32\":\"uint16\";if(r===t.dtype&&function(t,e){for(var r=1,n=e.length-1;n>=0;--n){if(e[n]!==r)return!1;r*=t[n]}return!0}(t.shape,t.stride))0===t.offset&&t.data.length===t.shape[0]?this.length=c(this.gl,this.type,this.length,this.usage,t.data,e):this.length=c(this.gl,this.type,this.length,this.usage,t.data.subarray(t.offset,t.shape[0]),e);else{var s=n.malloc(t.size,r),l=a(s,t.shape);i.assign(l,t),this.length=c(this.gl,this.type,this.length,this.usage,e<0?s:s.subarray(0,t.size),e),n.free(s)}}else if(Array.isArray(t)){var h;h=this.type===this.gl.ELEMENT_ARRAY_BUFFER?u(t,\"uint16\"):u(t,\"float32\"),this.length=c(this.gl,this.type,this.length,this.usage,e<0?h:h.subarray(0,t.length),e),n.free(h)}else if(\"object\"==typeof t&&\"number\"==typeof t.length)this.length=c(this.gl,this.type,this.length,this.usage,t,e);else{if(\"number\"!=typeof t&&void 0!==t)throw new Error(\"gl-buffer: Invalid data type\");if(e>=0)throw new Error(\"gl-buffer: Cannot specify offset when resizing buffer\");(t|=0)<=0&&(t=1),this.gl.bufferData(this.type,0|t,this.usage),this.length=t}},e.exports=function(t,e,r,n){if(r=r||t.ARRAY_BUFFER,n=n||t.DYNAMIC_DRAW,r!==t.ARRAY_BUFFER&&r!==t.ELEMENT_ARRAY_BUFFER)throw new Error(\"gl-buffer: Invalid type for webgl buffer, must be either gl.ARRAY_BUFFER or gl.ELEMENT_ARRAY_BUFFER\");if(n!==t.DYNAMIC_DRAW&&n!==t.STATIC_DRAW&&n!==t.STREAM_DRAW)throw new Error(\"gl-buffer: Invalid usage for buffer, must be either gl.DYNAMIC_DRAW, gl.STATIC_DRAW or gl.STREAM_DRAW\");var i=t.createBuffer(),a=new s(t,r,i,0,n);return a.update(e),a}},{ndarray:450,\"ndarray-ops\":444,\"typedarray-pool\":545}],242:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\"),i=function(t,e){for(var r=0;r<t.length;r++)if(t[r]>=e)return r-1;return r},a=n.create(),o=n.create(),s=function(t,e,r){return t<e?e:t>r?r:t},l=function(t,e,r,l){var c=t[0],u=t[1],h=t[2],f=r[0].length,p=r[1].length,d=r[2].length,g=i(r[0],c),v=i(r[1],u),m=i(r[2],h),y=g+1,x=v+1,b=m+1;if(l&&(g=s(g,0,f-1),y=s(y,0,f-1),v=s(v,0,p-1),x=s(x,0,p-1),m=s(m,0,d-1),b=s(b,0,d-1)),g<0||v<0||m<0||y>=f||x>=p||b>=d)return n.create();var _=(c-r[0][g])/(r[0][y]-r[0][g]),w=(u-r[1][v])/(r[1][x]-r[1][v]),k=(h-r[2][m])/(r[2][b]-r[2][m]);(_<0||_>1||isNaN(_))&&(_=0),(w<0||w>1||isNaN(w))&&(w=0),(k<0||k>1||isNaN(k))&&(k=0);var T=m*f*p,A=b*f*p,M=v*f,S=x*f,E=g,C=y,L=e[M+T+E],P=e[M+T+C],O=e[S+T+E],z=e[S+T+C],I=e[M+A+E],D=e[M+A+C],R=e[S+A+E],F=e[S+A+C],B=n.create();return n.lerp(B,L,P,_),n.lerp(a,O,z,_),n.lerp(B,B,a,w),n.lerp(a,I,D,_),n.lerp(o,R,F,_),n.lerp(a,a,o,w),n.lerp(B,B,a,k),B};e.exports=function(t,e){var r;r=t.positions?t.positions:function(t){for(var e=t[0],r=t[1],n=t[2],i=[],a=0;a<n.length;a++)for(var o=0;o<r.length;o++)for(var s=0;s<e.length;s++)i.push([n[a],r[o],e[s]]);return i}(t.meshgrid);var i=t.meshgrid,a=t.vectors,o={positions:[],vertexIntensity:[],vertexIntensityBounds:t.vertexIntensityBounds,vertexNormals:[],vectors:[],cells:[],coneOffset:t.coneOffset,colormap:t.colormap};if(0===t.positions.length)return e&&(e[0]=[0,0,0],e[1]=[0,0,0]),o;for(var s=0,c=1/0,u=-1/0,h=1/0,f=-1/0,p=1/0,d=-1/0,g=null,v=null,m=[],y=1/0,x=0;x<r.length;x++){var b,_=r[x];c=Math.min(_[0],c),u=Math.max(_[0],u),h=Math.min(_[1],h),f=Math.max(_[1],f),p=Math.min(_[2],p),d=Math.max(_[2],d),b=i?l(_,a,i,!0):a[x],n.length(b)>s&&(s=n.length(b)),x&&(y=Math.min(y,2*n.distance(g,_)/(n.length(v)+n.length(b)))),g=_,v=b,m.push(b)}var w=[c,h,p],k=[u,f,d];e&&(e[0]=w,e[1]=k),0===s&&(s=1);var T=1/s;isFinite(y)&&!isNaN(y)||(y=1),o.vectorScale=y;var A=function(t,e,r){var i=n.create();return void 0!==t&&n.set(i,t,e,r),i}(0,1,0),M=t.coneSize||.5;t.absoluteConeSize&&(M=t.absoluteConeSize*T),o.coneScale=M;x=0;for(var S=0;x<r.length;x++)for(var E=(_=r[x])[0],C=_[1],L=_[2],P=m[x],O=n.length(P)*T,z=0;z<8;z++){o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vertexIntensity.push(O,O,O),o.vertexIntensity.push(O,O,O),o.vertexNormals.push(A,A,A),o.vertexNormals.push(A,A,A);var I=o.positions.length;o.cells.push([I-6,I-5,I-4],[I-3,I-2,I-1])}return o},e.exports.createConeMesh=t(\"./lib/conemesh\")},{\"./lib/conemesh\":243,\"gl-vec3\":346}],243:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./shaders\"),g=d.meshShader,v=d.pickShader,m=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function y(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,y,x,b,_,w,k,T){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=i,this.triangleVectors=a,this.triangleColors=s,this.triangleNormals=c,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=u,this.triangleCount=0,this.lineWidth=1,this.edgePositions=h,this.edgeColors=p,this.edgeUVs=d,this.edgeIds=f,this.edgeVAO=g,this.edgeCount=0,this.pointPositions=v,this.pointColors=x,this.pointUVs=b,this.pointSizes=_,this.pointIds=y,this.pointVAO=w,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=k,this.contourVAO=T,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.coneScale=2,this.vectorScale=1,this.coneOffset=.25,this._model=m,this._view=m,this._projection=m,this._resolution=[1,1]}var x=y.prototype;function b(t){var e=n(t,v.vertex,v.fragment,null,v.attributes);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.vector.location=5,e}x.isOpaque=function(){return this.opacity>=1},x.isTransparent=function(){return this.opacity<1},x.pickSlots=1,x.setPickBase=function(t){this.pickId=t},x.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=i[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},x.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),void 0!==t.vectorScale&&(this.vectorScale=t.vectorScale),void 0!==t.coneScale&&(this.coneScale=t.coneScale),void 0!==t.coneOffset&&(this.coneOffset=t.coneOffset),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=h({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return u(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,i=t.vectors;if(n&&r&&i){var a=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[],w=[],k=[];this.cells=r,this.positions=n;var T=t.vertexNormals,A=t.cellNormals,M=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,S=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!A&&(A=s.faceNormals(r,n,S)),A||T||(T=s.vertexNormals(r,n,M));var E=t.vertexColors,C=t.cellColors,L=t.meshColor||[1,1,1,1],P=t.vertexUVs,O=t.vertexIntensity,z=t.cellUVs,I=t.cellIntensity,D=1/0,R=-1/0;if(!P&&!z)if(O)if(t.vertexIntensityBounds)D=+t.vertexIntensityBounds[0],R=+t.vertexIntensityBounds[1];else for(var F=0;F<O.length;++F){var B=O[F];D=Math.min(D,B),R=Math.max(R,B)}else if(I)for(F=0;F<I.length;++F){B=I[F];D=Math.min(D,B),R=Math.max(R,B)}else for(F=0;F<n.length;++F){B=n[F][2];D=Math.min(D,B),R=Math.max(R,B)}this.intensity=O||(I?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,I):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var N=t.pointSizes,j=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(F=0;F<n.length;++F)for(var U=n[F],V=0;V<3;++V)!isNaN(U[V])&&isFinite(U[V])&&(this.bounds[0][V]=Math.min(this.bounds[0][V],U[V]),this.bounds[1][V]=Math.max(this.bounds[1][V],U[V]));var q=0,H=0,G=0;t:for(F=0;F<r.length;++F){var Y=r[F];switch(Y.length){case 1:for(U=n[X=Y[0]],V=0;V<3;++V)if(isNaN(U[V])||!isFinite(U[V]))continue t;x.push(U[0],U[1],U[2],U[3]),3===(Z=E?E[X]:C?C[F]:L).length?b.push(Z[0],Z[1],Z[2],1):b.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],_.push(J[0],J[1]),N?w.push(N[X]):w.push(j),k.push(F),G+=1;break;case 2:for(V=0;V<2;++V){U=n[X=Y[V]];for(var W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t}for(V=0;V<2;++V){U=n[X=Y[V]];g.push(U[0],U[1],U[2]),3===(Z=E?E[X]:C?C[F]:L).length?v.push(Z[0],Z[1],Z[2],1):v.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],m.push(J[0],J[1]),y.push(F)}H+=1;break;case 3:for(V=0;V<3;++V)for(U=n[X=Y[V]],W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t;for(V=0;V<3;++V){var X;U=n[X=Y[2-V]];a.push(U[0],U[1],U[2],U[3]);var Z,J,K,$=i[X];l.push($[0],$[1],$[2]),3===(Z=E?E[X]:C?C[F]:L).length?c.push(Z[0],Z[1],Z[2],1):c.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],p.push(J[0],J[1]),K=T?T[X]:A[F],f.push(K[0],K[1],K[2]),d.push(F)}q+=1}}this.pointCount=G,this.edgeCount=H,this.triangleCount=q,this.pointPositions.update(x),this.pointColors.update(b),this.pointUVs.update(_),this.pointSizes.update(w),this.pointIds.update(new Uint32Array(k)),this.edgePositions.update(g),this.edgeColors.update(v),this.edgeUVs.update(m),this.edgeIds.update(new Uint32Array(y)),this.trianglePositions.update(a),this.triangleVectors.update(l),this.triangleColors.update(c),this.triangleUVs.update(p),this.triangleNormals.update(f),this.triangleIds.update(new Uint32Array(d))}},x.drawTransparent=x.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:m.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var f=u[12+o],p=0;p<3;++p)f+=u[4*p+o]*this.lightPosition[p];s.lightPosition[o]=f/h}if(this.triangleCount>0){var d=this.triShader;d.bind(),d.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},x.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:i,clipBounds:a,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind())},x.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3);return{index:Math.floor(r[1]/48),position:n,dataCoordinate:n}},x.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose()},e.exports=function(t,e){1===arguments.length&&(t=(e=t).gl);var r=e.triShader||function(t){var e=n(t,g.vertex,g.fragment,null,g.attributes);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.vector.location=5,e}(t),s=b(t),l=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));l.generateMipmap(),l.minFilter=t.LINEAR_MIPMAP_LINEAR,l.magFilter=t.LINEAR;var c=i(t),h=i(t),f=i(t),p=i(t),d=i(t),v=i(t),m=a(t,[{buffer:c,type:t.FLOAT,size:4},{buffer:v,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:f,type:t.FLOAT,size:4},{buffer:p,type:t.FLOAT,size:2},{buffer:d,type:t.FLOAT,size:3},{buffer:h,type:t.FLOAT,size:3}]),x=i(t),_=i(t),w=i(t),k=i(t),T=a(t,[{buffer:x,type:t.FLOAT,size:3},{buffer:k,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:_,type:t.FLOAT,size:4},{buffer:w,type:t.FLOAT,size:2}]),A=i(t),M=i(t),S=i(t),E=i(t),C=i(t),L=a(t,[{buffer:A,type:t.FLOAT,size:3},{buffer:C,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:M,type:t.FLOAT,size:4},{buffer:S,type:t.FLOAT,size:2},{buffer:E,type:t.FLOAT,size:1}]),P=i(t),O=new y(t,l,r,s,c,h,v,f,p,d,m,x,k,_,w,T,A,C,M,S,E,L,P,a(t,[{buffer:P,type:t.FLOAT,size:3}]));return O.update(e),O}},{\"./shaders\":244,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-shader\":301,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,normals:453,\"simplicial-complex-contour\":518,\"typedarray-pool\":545}],244:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\nuniform float vectorScale;\\nuniform float coneScale;\\n\\nuniform float coneOffset;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * conePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal,0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(conePosition, 1.0);\\n  vec4 t_position  = view * conePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = conePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular\\n            , opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nuniform float vectorScale;\\nuniform float coneScale;\\nuniform float coneOffset;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n  gl_Position = projection * view * conePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec3\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec3\"}]}},{glslify:409}],245:[function(t,e,r){e.exports={0:\"NONE\",1:\"ONE\",2:\"LINE_LOOP\",3:\"LINE_STRIP\",4:\"TRIANGLES\",5:\"TRIANGLE_STRIP\",6:\"TRIANGLE_FAN\",256:\"DEPTH_BUFFER_BIT\",512:\"NEVER\",513:\"LESS\",514:\"EQUAL\",515:\"LEQUAL\",516:\"GREATER\",517:\"NOTEQUAL\",518:\"GEQUAL\",519:\"ALWAYS\",768:\"SRC_COLOR\",769:\"ONE_MINUS_SRC_COLOR\",770:\"SRC_ALPHA\",771:\"ONE_MINUS_SRC_ALPHA\",772:\"DST_ALPHA\",773:\"ONE_MINUS_DST_ALPHA\",774:\"DST_COLOR\",775:\"ONE_MINUS_DST_COLOR\",776:\"SRC_ALPHA_SATURATE\",1024:\"STENCIL_BUFFER_BIT\",1028:\"FRONT\",1029:\"BACK\",1032:\"FRONT_AND_BACK\",1280:\"INVALID_ENUM\",1281:\"INVALID_VALUE\",1282:\"INVALID_OPERATION\",1285:\"OUT_OF_MEMORY\",1286:\"INVALID_FRAMEBUFFER_OPERATION\",2304:\"CW\",2305:\"CCW\",2849:\"LINE_WIDTH\",2884:\"CULL_FACE\",2885:\"CULL_FACE_MODE\",2886:\"FRONT_FACE\",2928:\"DEPTH_RANGE\",2929:\"DEPTH_TEST\",2930:\"DEPTH_WRITEMASK\",2931:\"DEPTH_CLEAR_VALUE\",2932:\"DEPTH_FUNC\",2960:\"STENCIL_TEST\",2961:\"STENCIL_CLEAR_VALUE\",2962:\"STENCIL_FUNC\",2963:\"STENCIL_VALUE_MASK\",2964:\"STENCIL_FAIL\",2965:\"STENCIL_PASS_DEPTH_FAIL\",2966:\"STENCIL_PASS_DEPTH_PASS\",2967:\"STENCIL_REF\",2968:\"STENCIL_WRITEMASK\",2978:\"VIEWPORT\",3024:\"DITHER\",3042:\"BLEND\",3088:\"SCISSOR_BOX\",3089:\"SCISSOR_TEST\",3106:\"COLOR_CLEAR_VALUE\",3107:\"COLOR_WRITEMASK\",3317:\"UNPACK_ALIGNMENT\",3333:\"PACK_ALIGNMENT\",3379:\"MAX_TEXTURE_SIZE\",3386:\"MAX_VIEWPORT_DIMS\",3408:\"SUBPIXEL_BITS\",3410:\"RED_BITS\",3411:\"GREEN_BITS\",3412:\"BLUE_BITS\",3413:\"ALPHA_BITS\",3414:\"DEPTH_BITS\",3415:\"STENCIL_BITS\",3553:\"TEXTURE_2D\",4352:\"DONT_CARE\",4353:\"FASTEST\",4354:\"NICEST\",5120:\"BYTE\",5121:\"UNSIGNED_BYTE\",5122:\"SHORT\",5123:\"UNSIGNED_SHORT\",5124:\"INT\",5125:\"UNSIGNED_INT\",5126:\"FLOAT\",5386:\"INVERT\",5890:\"TEXTURE\",6401:\"STENCIL_INDEX\",6402:\"DEPTH_COMPONENT\",6406:\"ALPHA\",6407:\"RGB\",6408:\"RGBA\",6409:\"LUMINANCE\",6410:\"LUMINANCE_ALPHA\",7680:\"KEEP\",7681:\"REPLACE\",7682:\"INCR\",7683:\"DECR\",7936:\"VENDOR\",7937:\"RENDERER\",7938:\"VERSION\",9728:\"NEAREST\",9729:\"LINEAR\",9984:\"NEAREST_MIPMAP_NEAREST\",9985:\"LINEAR_MIPMAP_NEAREST\",9986:\"NEAREST_MIPMAP_LINEAR\",9987:\"LINEAR_MIPMAP_LINEAR\",10240:\"TEXTURE_MAG_FILTER\",10241:\"TEXTURE_MIN_FILTER\",10242:\"TEXTURE_WRAP_S\",10243:\"TEXTURE_WRAP_T\",10497:\"REPEAT\",10752:\"POLYGON_OFFSET_UNITS\",16384:\"COLOR_BUFFER_BIT\",32769:\"CONSTANT_COLOR\",32770:\"ONE_MINUS_CONSTANT_COLOR\",32771:\"CONSTANT_ALPHA\",32772:\"ONE_MINUS_CONSTANT_ALPHA\",32773:\"BLEND_COLOR\",32774:\"FUNC_ADD\",32777:\"BLEND_EQUATION_RGB\",32778:\"FUNC_SUBTRACT\",32779:\"FUNC_REVERSE_SUBTRACT\",32819:\"UNSIGNED_SHORT_4_4_4_4\",32820:\"UNSIGNED_SHORT_5_5_5_1\",32823:\"POLYGON_OFFSET_FILL\",32824:\"POLYGON_OFFSET_FACTOR\",32854:\"RGBA4\",32855:\"RGB5_A1\",32873:\"TEXTURE_BINDING_2D\",32926:\"SAMPLE_ALPHA_TO_COVERAGE\",32928:\"SAMPLE_COVERAGE\",32936:\"SAMPLE_BUFFERS\",32937:\"SAMPLES\",32938:\"SAMPLE_COVERAGE_VALUE\",32939:\"SAMPLE_COVERAGE_INVERT\",32968:\"BLEND_DST_RGB\",32969:\"BLEND_SRC_RGB\",32970:\"BLEND_DST_ALPHA\",32971:\"BLEND_SRC_ALPHA\",33071:\"CLAMP_TO_EDGE\",33170:\"GENERATE_MIPMAP_HINT\",33189:\"DEPTH_COMPONENT16\",33306:\"DEPTH_STENCIL_ATTACHMENT\",33635:\"UNSIGNED_SHORT_5_6_5\",33648:\"MIRRORED_REPEAT\",33901:\"ALIASED_POINT_SIZE_RANGE\",33902:\"ALIASED_LINE_WIDTH_RANGE\",33984:\"TEXTURE0\",33985:\"TEXTURE1\",33986:\"TEXTURE2\",33987:\"TEXTURE3\",33988:\"TEXTURE4\",33989:\"TEXTURE5\",33990:\"TEXTURE6\",33991:\"TEXTURE7\",33992:\"TEXTURE8\",33993:\"TEXTURE9\",33994:\"TEXTURE10\",33995:\"TEXTURE11\",33996:\"TEXTURE12\",33997:\"TEXTURE13\",33998:\"TEXTURE14\",33999:\"TEXTURE15\",34000:\"TEXTURE16\",34001:\"TEXTURE17\",34002:\"TEXTURE18\",34003:\"TEXTURE19\",34004:\"TEXTURE20\",34005:\"TEXTURE21\",34006:\"TEXTURE22\",34007:\"TEXTURE23\",34008:\"TEXTURE24\",34009:\"TEXTURE25\",34010:\"TEXTURE26\",34011:\"TEXTURE27\",34012:\"TEXTURE28\",34013:\"TEXTURE29\",34014:\"TEXTURE30\",34015:\"TEXTURE31\",34016:\"ACTIVE_TEXTURE\",34024:\"MAX_RENDERBUFFER_SIZE\",34041:\"DEPTH_STENCIL\",34055:\"INCR_WRAP\",34056:\"DECR_WRAP\",34067:\"TEXTURE_CUBE_MAP\",34068:\"TEXTURE_BINDING_CUBE_MAP\",34069:\"TEXTURE_CUBE_MAP_POSITIVE_X\",34070:\"TEXTURE_CUBE_MAP_NEGATIVE_X\",34071:\"TEXTURE_CUBE_MAP_POSITIVE_Y\",34072:\"TEXTURE_CUBE_MAP_NEGATIVE_Y\",34073:\"TEXTURE_CUBE_MAP_POSITIVE_Z\",34074:\"TEXTURE_CUBE_MAP_NEGATIVE_Z\",34076:\"MAX_CUBE_MAP_TEXTURE_SIZE\",34338:\"VERTEX_ATTRIB_ARRAY_ENABLED\",34339:\"VERTEX_ATTRIB_ARRAY_SIZE\",34340:\"VERTEX_ATTRIB_ARRAY_STRIDE\",34341:\"VERTEX_ATTRIB_ARRAY_TYPE\",34342:\"CURRENT_VERTEX_ATTRIB\",34373:\"VERTEX_ATTRIB_ARRAY_POINTER\",34466:\"NUM_COMPRESSED_TEXTURE_FORMATS\",34467:\"COMPRESSED_TEXTURE_FORMATS\",34660:\"BUFFER_SIZE\",34661:\"BUFFER_USAGE\",34816:\"STENCIL_BACK_FUNC\",34817:\"STENCIL_BACK_FAIL\",34818:\"STENCIL_BACK_PASS_DEPTH_FAIL\",34819:\"STENCIL_BACK_PASS_DEPTH_PASS\",34877:\"BLEND_EQUATION_ALPHA\",34921:\"MAX_VERTEX_ATTRIBS\",34922:\"VERTEX_ATTRIB_ARRAY_NORMALIZED\",34930:\"MAX_TEXTURE_IMAGE_UNITS\",34962:\"ARRAY_BUFFER\",34963:\"ELEMENT_ARRAY_BUFFER\",34964:\"ARRAY_BUFFER_BINDING\",34965:\"ELEMENT_ARRAY_BUFFER_BINDING\",34975:\"VERTEX_ATTRIB_ARRAY_BUFFER_BINDING\",35040:\"STREAM_DRAW\",35044:\"STATIC_DRAW\",35048:\"DYNAMIC_DRAW\",35632:\"FRAGMENT_SHADER\",35633:\"VERTEX_SHADER\",35660:\"MAX_VERTEX_TEXTURE_IMAGE_UNITS\",35661:\"MAX_COMBINED_TEXTURE_IMAGE_UNITS\",35663:\"SHADER_TYPE\",35664:\"FLOAT_VEC2\",35665:\"FLOAT_VEC3\",35666:\"FLOAT_VEC4\",35667:\"INT_VEC2\",35668:\"INT_VEC3\",35669:\"INT_VEC4\",35670:\"BOOL\",35671:\"BOOL_VEC2\",35672:\"BOOL_VEC3\",35673:\"BOOL_VEC4\",35674:\"FLOAT_MAT2\",35675:\"FLOAT_MAT3\",35676:\"FLOAT_MAT4\",35678:\"SAMPLER_2D\",35680:\"SAMPLER_CUBE\",35712:\"DELETE_STATUS\",35713:\"COMPILE_STATUS\",35714:\"LINK_STATUS\",35715:\"VALIDATE_STATUS\",35716:\"INFO_LOG_LENGTH\",35717:\"ATTACHED_SHADERS\",35718:\"ACTIVE_UNIFORMS\",35719:\"ACTIVE_UNIFORM_MAX_LENGTH\",35720:\"SHADER_SOURCE_LENGTH\",35721:\"ACTIVE_ATTRIBUTES\",35722:\"ACTIVE_ATTRIBUTE_MAX_LENGTH\",35724:\"SHADING_LANGUAGE_VERSION\",35725:\"CURRENT_PROGRAM\",36003:\"STENCIL_BACK_REF\",36004:\"STENCIL_BACK_VALUE_MASK\",36005:\"STENCIL_BACK_WRITEMASK\",36006:\"FRAMEBUFFER_BINDING\",36007:\"RENDERBUFFER_BINDING\",36048:\"FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE\",36049:\"FRAMEBUFFER_ATTACHMENT_OBJECT_NAME\",36050:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL\",36051:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE\",36053:\"FRAMEBUFFER_COMPLETE\",36054:\"FRAMEBUFFER_INCOMPLETE_ATTACHMENT\",36055:\"FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT\",36057:\"FRAMEBUFFER_INCOMPLETE_DIMENSIONS\",36061:\"FRAMEBUFFER_UNSUPPORTED\",36064:\"COLOR_ATTACHMENT0\",36096:\"DEPTH_ATTACHMENT\",36128:\"STENCIL_ATTACHMENT\",36160:\"FRAMEBUFFER\",36161:\"RENDERBUFFER\",36162:\"RENDERBUFFER_WIDTH\",36163:\"RENDERBUFFER_HEIGHT\",36164:\"RENDERBUFFER_INTERNAL_FORMAT\",36168:\"STENCIL_INDEX8\",36176:\"RENDERBUFFER_RED_SIZE\",36177:\"RENDERBUFFER_GREEN_SIZE\",36178:\"RENDERBUFFER_BLUE_SIZE\",36179:\"RENDERBUFFER_ALPHA_SIZE\",36180:\"RENDERBUFFER_DEPTH_SIZE\",36181:\"RENDERBUFFER_STENCIL_SIZE\",36194:\"RGB565\",36336:\"LOW_FLOAT\",36337:\"MEDIUM_FLOAT\",36338:\"HIGH_FLOAT\",36339:\"LOW_INT\",36340:\"MEDIUM_INT\",36341:\"HIGH_INT\",36346:\"SHADER_COMPILER\",36347:\"MAX_VERTEX_UNIFORM_VECTORS\",36348:\"MAX_VARYING_VECTORS\",36349:\"MAX_FRAGMENT_UNIFORM_VECTORS\",37440:\"UNPACK_FLIP_Y_WEBGL\",37441:\"UNPACK_PREMULTIPLY_ALPHA_WEBGL\",37442:\"CONTEXT_LOST_WEBGL\",37443:\"UNPACK_COLORSPACE_CONVERSION_WEBGL\",37444:\"BROWSER_DEFAULT_WEBGL\"}},{}],246:[function(t,e,r){var n=t(\"./1.0/numbers\");e.exports=function(t){return n[t]}},{\"./1.0/numbers\":245}],247:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),o=i(e,[{buffer:r,type:e.FLOAT,size:3,offset:0,stride:40},{buffer:r,type:e.FLOAT,size:4,offset:12,stride:40},{buffer:r,type:e.FLOAT,size:3,offset:28,stride:40}]),l=a(e);l.attributes.position.location=0,l.attributes.color.location=1,l.attributes.offset.location=2;var c=new s(e,r,o,l);return c.update(t),c};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\"),o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.shader=n,this.buffer=e,this.vao=r,this.pixelRatio=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lineWidth=[1,1,1],this.capSize=[10,10,10],this.lineCount=[0,0,0],this.lineOffset=[0,0,0],this.opacity=1,this.hasAlpha=!1}var l=s.prototype;function c(t,e){for(var r=0;r<3;++r)t[0][r]=Math.min(t[0][r],e[r]),t[1][r]=Math.max(t[1][r],e[r])}l.isOpaque=function(){return!this.hasAlpha},l.isTransparent=function(){return this.hasAlpha},l.drawTransparent=l.draw=function(t){var e=this.gl,r=this.shader.uniforms;this.shader.bind();var n=r.view=t.view||o,i=r.projection=t.projection||o;r.model=t.model||o,r.clipBounds=this.clipBounds,r.opacity=this.opacity;var a=n[12],s=n[13],l=n[14],c=n[15],u=(t._ortho||!1?2:1)*this.pixelRatio*(i[3]*a+i[7]*s+i[11]*l+i[15]*c)/e.drawingBufferHeight;this.vao.bind();for(var h=0;h<3;++h)e.lineWidth(this.lineWidth[h]*this.pixelRatio),r.capSize=this.capSize[h]*u,this.lineCount[h]&&e.drawArrays(e.LINES,this.lineOffset[h],this.lineCount[h]);this.vao.unbind()};var u=function(){for(var t=new Array(3),e=0;e<3;++e){for(var r=[],n=1;n<=2;++n)for(var i=-1;i<=1;i+=2){var a=[0,0,0];a[(n+e)%3]=i,r.push(a)}t[e]=r}return t}();function h(t,e,r,n){for(var i=u[n],a=0;a<i.length;++a){var o=i[a];t.push(e[0],e[1],e[2],r[0],r[1],r[2],r[3],o[0],o[1],o[2])}return i.length}l.update=function(t){\"lineWidth\"in(t=t||{})&&(this.lineWidth=t.lineWidth,Array.isArray(this.lineWidth)||(this.lineWidth=[this.lineWidth,this.lineWidth,this.lineWidth])),\"capSize\"in t&&(this.capSize=t.capSize,Array.isArray(this.capSize)||(this.capSize=[this.capSize,this.capSize,this.capSize])),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var e=t.color||[[0,0,0],[0,0,0],[0,0,0]],r=t.position,n=t.error;if(Array.isArray(e[0])||(e=[e,e,e]),r&&n){var i=[],a=r.length,o=0;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.lineCount=[0,0,0];for(var s=0;s<3;++s){this.lineOffset[s]=o;t:for(var l=0;l<a;++l){for(var u=r[l],f=0;f<3;++f)if(isNaN(u[f])||!isFinite(u[f]))continue t;var p=n[l],d=e[s];if(Array.isArray(d[0])&&(d=e[l]),3===d.length?d=[d[0],d[1],d[2],1]:4===d.length&&(d=[d[0],d[1],d[2],d[3]],!this.hasAlpha&&d[3]<1&&(this.hasAlpha=!0)),!isNaN(p[0][s])&&!isNaN(p[1][s])){var g;if(p[0][s]<0)(g=u.slice())[s]+=p[0][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+h(i,g,d,s);if(p[1][s]>0)(g=u.slice())[s]+=p[1][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+h(i,g,d,s)}}this.lineCount[s]=o-this.lineOffset[s]}this.buffer.update(i)}},l.dispose=function(){this.shader.dispose(),this.buffer.dispose(),this.vao.dispose()}},{\"./shaders/index\":248,\"gl-buffer\":241,\"gl-vao\":327}],248:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, offset;\\nattribute vec4 color;\\nuniform mat4 model, view, projection;\\nuniform float capSize;\\nvarying vec4 fragColor;\\nvarying vec3 fragPosition;\\n\\nvoid main() {\\n  vec4 worldPosition  = model * vec4(position, 1.0);\\n  worldPosition       = (worldPosition / worldPosition.w) + vec4(capSize * offset, 0.0);\\n  gl_Position         = projection * view * worldPosition;\\n  fragColor           = color;\\n  fragPosition        = position;\\n}\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float opacity;\\nvarying vec3 fragPosition;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], fragPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  gl_FragColor = opacity * fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"offset\",type:\"vec3\"}])}},{\"gl-shader\":301,glslify:409}],249:[function(t,e,r){\"use strict\";var n=t(\"gl-texture2d\");e.exports=function(t,e,r,n){i||(i=t.FRAMEBUFFER_UNSUPPORTED,a=t.FRAMEBUFFER_INCOMPLETE_ATTACHMENT,o=t.FRAMEBUFFER_INCOMPLETE_DIMENSIONS,s=t.FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT);var c=t.getExtension(\"WEBGL_draw_buffers\");!l&&c&&function(t,e){var r=t.getParameter(e.MAX_COLOR_ATTACHMENTS_WEBGL);l=new Array(r+1);for(var n=0;n<=r;++n){for(var i=new Array(r),a=0;a<n;++a)i[a]=t.COLOR_ATTACHMENT0+a;for(var a=n;a<r;++a)i[a]=t.NONE;l[n]=i}}(t,c);Array.isArray(e)&&(n=r,r=0|e[1],e=0|e[0]);if(\"number\"!=typeof e)throw new Error(\"gl-fbo: Missing shape parameter\");var u=t.getParameter(t.MAX_RENDERBUFFER_SIZE);if(e<0||e>u||r<0||r>u)throw new Error(\"gl-fbo: Parameters are too large for FBO\");var h=1;if(\"color\"in(n=n||{})){if((h=Math.max(0|n.color,0))<0)throw new Error(\"gl-fbo: Must specify a nonnegative number of colors\");if(h>1){if(!c)throw new Error(\"gl-fbo: Multiple draw buffer extension not supported\");if(h>t.getParameter(c.MAX_COLOR_ATTACHMENTS_WEBGL))throw new Error(\"gl-fbo: Context does not support \"+h+\" draw buffers\")}}var f=t.UNSIGNED_BYTE,p=t.getExtension(\"OES_texture_float\");if(n.float&&h>0){if(!p)throw new Error(\"gl-fbo: Context does not support floating point textures\");f=t.FLOAT}else n.preferFloat&&h>0&&p&&(f=t.FLOAT);var g=!0;\"depth\"in n&&(g=!!n.depth);var v=!1;\"stencil\"in n&&(v=!!n.stencil);return new d(t,e,r,f,h,g,v,c)};var i,a,o,s,l=null;function c(t){return[t.getParameter(t.FRAMEBUFFER_BINDING),t.getParameter(t.RENDERBUFFER_BINDING),t.getParameter(t.TEXTURE_BINDING_2D)]}function u(t,e){t.bindFramebuffer(t.FRAMEBUFFER,e[0]),t.bindRenderbuffer(t.RENDERBUFFER,e[1]),t.bindTexture(t.TEXTURE_2D,e[2])}function h(t){switch(t){case i:throw new Error(\"gl-fbo: Framebuffer unsupported\");case a:throw new Error(\"gl-fbo: Framebuffer incomplete attachment\");case o:throw new Error(\"gl-fbo: Framebuffer incomplete dimensions\");case s:throw new Error(\"gl-fbo: Framebuffer incomplete missing attachment\");default:throw new Error(\"gl-fbo: Framebuffer failed for unspecified reason\")}}function f(t,e,r,i,a,o){if(!i)return null;var s=n(t,e,r,a,i);return s.magFilter=t.NEAREST,s.minFilter=t.NEAREST,s.mipSamples=1,s.bind(),t.framebufferTexture2D(t.FRAMEBUFFER,o,t.TEXTURE_2D,s.handle,0),s}function p(t,e,r,n,i){var a=t.createRenderbuffer();return t.bindRenderbuffer(t.RENDERBUFFER,a),t.renderbufferStorage(t.RENDERBUFFER,n,e,r),t.framebufferRenderbuffer(t.FRAMEBUFFER,i,t.RENDERBUFFER,a),a}function d(t,e,r,n,i,a,o,s){this.gl=t,this._shape=[0|e,0|r],this._destroyed=!1,this._ext=s,this.color=new Array(i);for(var d=0;d<i;++d)this.color[d]=null;this._color_rb=null,this.depth=null,this._depth_rb=null,this._colorType=n,this._useDepth=a,this._useStencil=o;var g=this,v=[0|e,0|r];Object.defineProperties(v,{0:{get:function(){return g._shape[0]},set:function(t){return g.width=t}},1:{get:function(){return g._shape[1]},set:function(t){return g.height=t}}}),this._shapeVector=v,function(t){var e=c(t.gl),r=t.gl,n=t.handle=r.createFramebuffer(),i=t._shape[0],a=t._shape[1],o=t.color.length,s=t._ext,d=t._useStencil,g=t._useDepth,v=t._colorType;r.bindFramebuffer(r.FRAMEBUFFER,n);for(var m=0;m<o;++m)t.color[m]=f(r,i,a,v,r.RGBA,r.COLOR_ATTACHMENT0+m);0===o?(t._color_rb=p(r,i,a,r.RGBA4,r.COLOR_ATTACHMENT0),s&&s.drawBuffersWEBGL(l[0])):o>1&&s.drawBuffersWEBGL(l[o]);var y=r.getExtension(\"WEBGL_depth_texture\");y?d?t.depth=f(r,i,a,y.UNSIGNED_INT_24_8_WEBGL,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g&&(t.depth=f(r,i,a,r.UNSIGNED_SHORT,r.DEPTH_COMPONENT,r.DEPTH_ATTACHMENT)):g&&d?t._depth_rb=p(r,i,a,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g?t._depth_rb=p(r,i,a,r.DEPTH_COMPONENT16,r.DEPTH_ATTACHMENT):d&&(t._depth_rb=p(r,i,a,r.STENCIL_INDEX,r.STENCIL_ATTACHMENT));var x=r.checkFramebufferStatus(r.FRAMEBUFFER);if(x!==r.FRAMEBUFFER_COMPLETE){for(t._destroyed=!0,r.bindFramebuffer(r.FRAMEBUFFER,null),r.deleteFramebuffer(t.handle),t.handle=null,t.depth&&(t.depth.dispose(),t.depth=null),t._depth_rb&&(r.deleteRenderbuffer(t._depth_rb),t._depth_rb=null),m=0;m<t.color.length;++m)t.color[m].dispose(),t.color[m]=null;t._color_rb&&(r.deleteRenderbuffer(t._color_rb),t._color_rb=null),u(r,e),h(x)}u(r,e)}(this)}var g=d.prototype;function v(t,e,r){if(t._destroyed)throw new Error(\"gl-fbo: Can't resize destroyed FBO\");if(t._shape[0]!==e||t._shape[1]!==r){var n=t.gl,i=n.getParameter(n.MAX_RENDERBUFFER_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-fbo: Can't resize FBO, invalid dimensions\");t._shape[0]=e,t._shape[1]=r;for(var a=c(n),o=0;o<t.color.length;++o)t.color[o].shape=t._shape;t._color_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._color_rb),n.renderbufferStorage(n.RENDERBUFFER,n.RGBA4,t._shape[0],t._shape[1])),t.depth&&(t.depth.shape=t._shape),t._depth_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._depth_rb),t._useDepth&&t._useStencil?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_STENCIL,t._shape[0],t._shape[1]):t._useDepth?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_COMPONENT16,t._shape[0],t._shape[1]):t._useStencil&&n.renderbufferStorage(n.RENDERBUFFER,n.STENCIL_INDEX,t._shape[0],t._shape[1])),n.bindFramebuffer(n.FRAMEBUFFER,t.handle);var s=n.checkFramebufferStatus(n.FRAMEBUFFER);s!==n.FRAMEBUFFER_COMPLETE&&(t.dispose(),u(n,a),h(s)),u(n,a)}}Object.defineProperties(g,{shape:{get:function(){return this._destroyed?[0,0]:this._shapeVector},set:function(t){if(Array.isArray(t)||(t=[0|t,0|t]),2!==t.length)throw new Error(\"gl-fbo: Shape vector must be length 2\");var e=0|t[0],r=0|t[1];return v(this,e,r),[e,r]},enumerable:!1},width:{get:function(){return this._destroyed?0:this._shape[0]},set:function(t){return v(this,t|=0,this._shape[1]),t},enumerable:!1},height:{get:function(){return this._destroyed?0:this._shape[1]},set:function(t){return t|=0,v(this,this._shape[0],t),t},enumerable:!1}}),g.bind=function(){if(!this._destroyed){var t=this.gl;t.bindFramebuffer(t.FRAMEBUFFER,this.handle),t.viewport(0,0,this._shape[0],this._shape[1])}},g.dispose=function(){if(!this._destroyed){this._destroyed=!0;var t=this.gl;t.deleteFramebuffer(this.handle),this.handle=null,this.depth&&(this.depth.dispose(),this.depth=null),this._depth_rb&&(t.deleteRenderbuffer(this._depth_rb),this._depth_rb=null);for(var e=0;e<this.color.length;++e)this.color[e].dispose(),this.color[e]=null;this._color_rb&&(t.deleteRenderbuffer(this._color_rb),this._color_rb=null)}}},{\"gl-texture2d\":322}],250:[function(t,e,r){var n=t(\"sprintf-js\").sprintf,i=t(\"gl-constants/lookup\"),a=t(\"glsl-shader-name\"),o=t(\"add-line-numbers\");e.exports=function(t,e,r){\"use strict\";var s=a(e)||\"of unknown name (see npm glsl-shader-name)\",l=\"unknown type\";void 0!==r&&(l=r===i.FRAGMENT_SHADER?\"fragment\":\"vertex\");for(var c=n(\"Error compiling %s shader %s:\\n\",l,s),u=n(\"%s%s\",c,t),h=t.split(\"\\n\"),f={},p=0;p<h.length;p++){var d=h[p];if(\"\"!==d&&\"\\0\"!==d){var g=parseInt(d.split(\":\")[2]);if(isNaN(g))throw new Error(n(\"Could not parse error: %s\",d));f[g]=d}}for(var v=o(e).split(\"\\n\"),p=0;p<v.length;p++)if(f[p+3]||f[p+2]||f[p+1]){var m=v[p];if(c+=m+\"\\n\",f[p+1]){var y=f[p+1];y=y.substr(y.split(\":\",3).join(\":\").length+1).trim(),c+=n(\"^^^ %s\\n\\n\",y)}}return{long:c.trim(),short:u.trim()}}},{\"add-line-numbers\":61,\"gl-constants/lookup\":246,\"glsl-shader-name\":401,\"sprintf-js\":528}],251:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.gl,n=o(r,l.vertex,l.fragment),i=o(r,l.pickVertex,l.pickFragment),a=s(r),u=s(r),h=s(r),f=s(r),p=new c(t,n,i,a,u,h,f);return p.update(e),t.addObject(p),p};var n=t(\"binary-search-bounds\"),i=t(\"iota-array\"),a=t(\"typedarray-pool\"),o=t(\"gl-shader\"),s=t(\"gl-buffer\"),l=t(\"./lib/shaders\");function c(t,e,r,n,i,a,o){this.plot=t,this.shader=e,this.pickShader=r,this.positionBuffer=n,this.weightBuffer=i,this.colorBuffer=a,this.idBuffer=o,this.xData=[],this.yData=[],this.shape=[0,0],this.bounds=[1/0,1/0,-1/0,-1/0],this.pickOffset=0}var u,h=c.prototype,f=[0,0,1,0,0,1,1,0,1,1,0,1];h.draw=(u=[1,0,0,0,1,0,0,0,1],function(){var t=this.plot,e=this.shader,r=this.bounds,n=this.numVertices;if(!(n<=0)){var i=t.gl,a=t.dataBox,o=r[2]-r[0],s=r[3]-r[1],l=a[2]-a[0],c=a[3]-a[1];u[0]=2*o/l,u[4]=2*s/c,u[6]=2*(r[0]-a[0])/l-1,u[7]=2*(r[1]-a[1])/c-1,e.bind();var h=e.uniforms;h.viewTransform=u,h.shape=this.shape;var f=e.attributes;this.positionBuffer.bind(),f.position.pointer(),this.weightBuffer.bind(),f.weight.pointer(i.UNSIGNED_BYTE,!1),this.colorBuffer.bind(),f.color.pointer(i.UNSIGNED_BYTE,!0),i.drawArrays(i.TRIANGLES,0,n)}}),h.drawPick=function(){var t=[1,0,0,0,1,0,0,0,1],e=[0,0,0,0];return function(r){var n=this.plot,i=this.pickShader,a=this.bounds,o=this.numVertices;if(!(o<=0)){var s=n.gl,l=n.dataBox,c=a[2]-a[0],u=a[3]-a[1],h=l[2]-l[0],f=l[3]-l[1];t[0]=2*c/h,t[4]=2*u/f,t[6]=2*(a[0]-l[0])/h-1,t[7]=2*(a[1]-l[1])/f-1;for(var p=0;p<4;++p)e[p]=r>>8*p&255;this.pickOffset=r,i.bind();var d=i.uniforms;d.viewTransform=t,d.pickOffset=e,d.shape=this.shape;var g=i.attributes;return this.positionBuffer.bind(),g.position.pointer(),this.weightBuffer.bind(),g.weight.pointer(s.UNSIGNED_BYTE,!1),this.idBuffer.bind(),g.pickId.pointer(s.UNSIGNED_BYTE,!1),s.drawArrays(s.TRIANGLES,0,o),r+this.shape[0]*this.shape[1]}}}(),h.pick=function(t,e,r){var n=this.pickOffset,i=this.shape[0]*this.shape[1];if(r<n||r>=n+i)return null;var a=r-n,o=this.xData,s=this.yData;return{object:this,pointId:a,dataCoord:[o[a%this.shape[0]],s[a/this.shape[0]|0]]}},h.update=function(t){var e=(t=t||{}).shape||[0,0],r=t.x||i(e[0]),o=t.y||i(e[1]),s=t.z||new Float32Array(e[0]*e[1]);this.xData=r,this.yData=o;var l=t.colorLevels||[0],c=t.colorValues||[0,0,0,1],u=l.length,h=this.bounds,p=h[0]=r[0],d=h[1]=o[0],g=1/((h[2]=r[r.length-1])-p),v=1/((h[3]=o[o.length-1])-d),m=e[0],y=e[1];this.shape=[m,y];var x=(m-1)*(y-1)*(f.length>>>1);this.numVertices=x;for(var b=a.mallocUint8(4*x),_=a.mallocFloat32(2*x),w=a.mallocUint8(2*x),k=a.mallocUint32(x),T=0,A=0;A<y-1;++A)for(var M=v*(o[A]-d),S=v*(o[A+1]-d),E=0;E<m-1;++E)for(var C=g*(r[E]-p),L=g*(r[E+1]-p),P=0;P<f.length;P+=2){var O,z,I,D,R=f[P],F=f[P+1],B=s[(A+F)*m+(E+R)],N=n.le(l,B);if(N<0)O=c[0],z=c[1],I=c[2],D=c[3];else if(N===u-1)O=c[4*u-4],z=c[4*u-3],I=c[4*u-2],D=c[4*u-1];else{var j=(B-l[N])/(l[N+1]-l[N]),U=1-j,V=4*N,q=4*(N+1);O=U*c[V]+j*c[q],z=U*c[V+1]+j*c[q+1],I=U*c[V+2]+j*c[q+2],D=U*c[V+3]+j*c[q+3]}b[4*T]=255*O,b[4*T+1]=255*z,b[4*T+2]=255*I,b[4*T+3]=255*D,_[2*T]=.5*C+.5*L,_[2*T+1]=.5*M+.5*S,w[2*T]=R,w[2*T+1]=F,k[T]=A*m+E,T+=1}this.positionBuffer.update(_),this.weightBuffer.update(w),this.colorBuffer.update(b),this.idBuffer.update(k),a.free(_),a.free(b),a.free(w),a.free(k)},h.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.positionBuffer.dispose(),this.weightBuffer.dispose(),this.colorBuffer.dispose(),this.idBuffer.dispose(),this.plot.removeObject(this)}},{\"./lib/shaders\":252,\"binary-search-bounds\":253,\"gl-buffer\":241,\"gl-shader\":301,\"iota-array\":416,\"typedarray-pool\":545}],252:[function(t,e,r){\"use strict\";var n=t(\"glslify\");e.exports={fragment:n([\"precision lowp float;\\n#define GLSLIFY 1\\nvarying vec4 fragColor;\\nvoid main() {\\n  gl_FragColor = vec4(fragColor.rgb * fragColor.a, fragColor.a);\\n}\\n\"]),vertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 color;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  fragColor = color;\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"]),pickFragment:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nuniform vec2 shape;\\nuniform vec4 pickOffset;\\n\\nvoid main() {\\n  vec2 d = step(.5, vWeight);\\n  vec4 id = fragId + pickOffset;\\n  id.x += d.x + d.y*shape.x;\\n\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  gl_FragColor = id/255.;\\n}\\n\"]),pickVertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nvoid main() {\\n  vWeight = weight;\\n\\n  fragId = pickId;\\n\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"])}},{glslify:409}],253:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],254:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, nextPosition;\\nattribute float arcLength, lineWidth;\\nattribute vec4 color;\\n\\nuniform vec2 screenShape;\\nuniform float pixelRatio;\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 fragColor;\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  vec4 startPoint = project(position);\\n  vec4 endPoint   = project(nextPosition);\\n\\n  vec2 A = startPoint.xy / startPoint.w;\\n  vec2 B =   endPoint.xy /   endPoint.w;\\n\\n  float clipAngle = atan(\\n    (B.y - A.y) * screenShape.y,\\n    (B.x - A.x) * screenShape.x\\n  );\\n\\n  vec2 offset = 0.5 * pixelRatio * lineWidth * vec2(\\n    sin(clipAngle),\\n    -cos(clipAngle)\\n  ) / screenShape;\\n\\n  gl_Position = vec4(startPoint.xy + startPoint.w * offset, startPoint.zw);\\n\\n  worldPosition = position;\\n  pixelArcLength = arcLength;\\n  fragColor = color;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3      clipBounds[2];\\nuniform sampler2D dashTexture;\\nuniform float     dashScale;\\nuniform float     opacity;\\n\\nvarying vec3    worldPosition;\\nvarying float   pixelArcLength;\\nvarying vec4    fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], worldPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  float dashWeight = texture2D(dashTexture, vec2(dashScale * pixelArcLength, 0)).r;\\n  if(dashWeight < 0.5) {\\n    discard;\\n  }\\n  gl_FragColor = fragColor * opacity;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\n#define FLOAT_MAX  1.70141184e38\\n#define FLOAT_MIN  1.17549435e-38\\n\\nlowp vec4 encode_float_1540259130(highp float v) {\\n  highp float av = abs(v);\\n\\n  //Handle special cases\\n  if(av < FLOAT_MIN) {\\n    return vec4(0.0, 0.0, 0.0, 0.0);\\n  } else if(v > FLOAT_MAX) {\\n    return vec4(127.0, 128.0, 0.0, 0.0) / 255.0;\\n  } else if(v < -FLOAT_MAX) {\\n    return vec4(255.0, 128.0, 0.0, 0.0) / 255.0;\\n  }\\n\\n  highp vec4 c = vec4(0,0,0,0);\\n\\n  //Compute exponent and mantissa\\n  highp float e = floor(log2(av));\\n  highp float m = av * pow(2.0, -e) - 1.0;\\n  \\n  //Unpack mantissa\\n  c[1] = floor(128.0 * m);\\n  m -= c[1] / 128.0;\\n  c[2] = floor(32768.0 * m);\\n  m -= c[2] / 32768.0;\\n  c[3] = floor(8388608.0 * m);\\n  \\n  //Unpack exponent\\n  highp float ebias = e + 127.0;\\n  c[0] = floor(ebias / 2.0);\\n  ebias -= c[0] * 2.0;\\n  c[1] += floor(ebias) * 128.0; \\n\\n  //Unpack sign bit\\n  c[0] += 128.0 * step(0.0, -v);\\n\\n  //Scale back to range\\n  return c / 255.0;\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform float pickId;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], worldPosition)) discard;\\n\\n  gl_FragColor = vec4(pickId/255.0, encode_float_1540259130(pixelArcLength).xyz);\\n}\"]),l=[{name:\"position\",type:\"vec3\"},{name:\"nextPosition\",type:\"vec3\"},{name:\"arcLength\",type:\"float\"},{name:\"lineWidth\",type:\"float\"},{name:\"color\",type:\"vec4\"}];r.createShader=function(t){return i(t,a,o,null,l)},r.createPickShader=function(t){return i(t,a,s,null,l)}},{\"gl-shader\":301,glslify:409}],255:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl||t.scene&&t.scene.gl,r=u(e);r.attributes.position.location=0,r.attributes.nextPosition.location=1,r.attributes.arcLength.location=2,r.attributes.lineWidth.location=3,r.attributes.color.location=4;var o=h(e);o.attributes.position.location=0,o.attributes.nextPosition.location=1,o.attributes.arcLength.location=2,o.attributes.lineWidth.location=3,o.attributes.color.location=4;for(var s=n(e),c=i(e,[{buffer:s,size:3,offset:0,stride:48},{buffer:s,size:3,offset:12,stride:48},{buffer:s,size:1,offset:24,stride:48},{buffer:s,size:1,offset:28,stride:48},{buffer:s,size:4,offset:32,stride:48}]),f=l(new Array(1024),[256,1,4]),p=0;p<1024;++p)f.data[p]=255;var d=a(e,f);d.wrap=e.REPEAT;var g=new v(e,r,o,s,c,d);return g.update(t),g};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"gl-texture2d\"),o=t(\"glsl-read-float\"),s=t(\"binary-search-bounds\"),l=t(\"ndarray\"),c=t(\"./lib/shaders\"),u=c.createShader,h=c.createPickShader,f=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function p(t,e){for(var r=0,n=0;n<3;++n){var i=t[n]-e[n];r+=i*i}return Math.sqrt(r)}function d(t){for(var e=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],r=0;r<3;++r)e[0][r]=Math.max(t[0][r],e[0][r]),e[1][r]=Math.min(t[1][r],e[1][r]);return e}function g(t,e,r,n){this.arcLength=t,this.position=e,this.index=r,this.dataCoordinate=n}function v(t,e,r,n,i,a){this.gl=t,this.shader=e,this.pickShader=r,this.buffer=n,this.vao=i,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.points=[],this.arcLength=[],this.vertexCount=0,this.bounds=[[0,0,0],[0,0,0]],this.pickId=0,this.lineWidth=1,this.texture=a,this.dashScale=1,this.opacity=1,this.hasAlpha=!1,this.dirty=!0,this.pixelRatio=1}var m=v.prototype;m.isTransparent=function(){return this.hasAlpha},m.isOpaque=function(){return!this.hasAlpha},m.pickSlots=1,m.setPickBase=function(t){this.pickId=t},m.drawTransparent=m.draw=function(t){if(this.vertexCount){var e=this.gl,r=this.shader,n=this.vao;r.bind(),r.uniforms={model:t.model||f,view:t.view||f,projection:t.projection||f,clipBounds:d(this.clipBounds),dashTexture:this.texture.bind(),dashScale:this.dashScale/this.arcLength[this.arcLength.length-1],opacity:this.opacity,screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},m.drawPick=function(t){if(this.vertexCount){var e=this.gl,r=this.pickShader,n=this.vao;r.bind(),r.uniforms={model:t.model||f,view:t.view||f,projection:t.projection||f,pickId:this.pickId,clipBounds:d(this.clipBounds),screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},m.update=function(t){var e,r;this.dirty=!0;var n=!!t.connectGaps;\"dashScale\"in t&&(this.dashScale=t.dashScale),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var i=[],a=[],o=[],c=0,u=0,h=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],f=t.position||t.positions;if(f){var d=t.color||t.colors||[0,0,0,1],g=t.lineWidth||1,v=!1;t:for(e=1;e<f.length;++e){var m,y,x,b=f[e-1],_=f[e];for(a.push(c),o.push(b.slice()),r=0;r<3;++r){if(isNaN(b[r])||isNaN(_[r])||!isFinite(b[r])||!isFinite(_[r])){if(!n&&i.length>0){for(var w=0;w<24;++w)i.push(i[i.length-12]);u+=2,v=!0}continue t}h[0][r]=Math.min(h[0][r],b[r],_[r]),h[1][r]=Math.max(h[1][r],b[r],_[r])}Array.isArray(d[0])?(m=d.length>e-1?d[e-1]:d.length>0?d[d.length-1]:[0,0,0,1],y=d.length>e?d[e]:d.length>0?d[d.length-1]:[0,0,0,1]):m=y=d,3===m.length&&(m=[m[0],m[1],m[2],1]),3===y.length&&(y=[y[0],y[1],y[2],1]),!this.hasAlpha&&m[3]<1&&(this.hasAlpha=!0),x=Array.isArray(g)?g.length>e-1?g[e-1]:g.length>0?g[g.length-1]:[0,0,0,1]:g;var k=c;if(c+=p(b,_),v){for(r=0;r<2;++r)i.push(b[0],b[1],b[2],_[0],_[1],_[2],k,x,m[0],m[1],m[2],m[3]);u+=2,v=!1}i.push(b[0],b[1],b[2],_[0],_[1],_[2],k,x,m[0],m[1],m[2],m[3],b[0],b[1],b[2],_[0],_[1],_[2],k,-x,m[0],m[1],m[2],m[3],_[0],_[1],_[2],b[0],b[1],b[2],c,-x,y[0],y[1],y[2],y[3],_[0],_[1],_[2],b[0],b[1],b[2],c,x,y[0],y[1],y[2],y[3]),u+=4}}if(this.buffer.update(i),a.push(c),o.push(f[f.length-1].slice()),this.bounds=h,this.vertexCount=u,this.points=o,this.arcLength=a,\"dashes\"in t){var T=t.dashes.slice();for(T.unshift(0),e=1;e<T.length;++e)T[e]=T[e-1]+T[e];var A=l(new Array(1024),[256,1,4]);for(e=0;e<256;++e){for(r=0;r<4;++r)A.set(e,0,r,0);1&s.le(T,T[T.length-1]*e/255)?A.set(e,0,0,0):A.set(e,0,0,255)}this.texture.setPixels(A)}},m.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()},m.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=o(t.value[0],t.value[1],t.value[2],0),r=s.le(this.arcLength,e);if(r<0)return null;if(r===this.arcLength.length-1)return new g(this.arcLength[this.arcLength.length-1],this.points[this.points.length-1].slice(),r);for(var n=this.points[r],i=this.points[Math.min(r+1,this.points.length-1)],a=(e-this.arcLength[r])/(this.arcLength[r+1]-this.arcLength[r]),l=1-a,c=[0,0,0],u=0;u<3;++u)c[u]=l*n[u]+a*i[u];var h=Math.min(a<.5?r:r+1,this.points.length-1);return new g(e,c,h,this.points[h])}},{\"./lib/shaders\":254,\"binary-search-bounds\":256,\"gl-buffer\":241,\"gl-texture2d\":322,\"gl-vao\":327,\"glsl-read-float\":400,ndarray:450}],256:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],257:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r*a-i*n;return o?(o=1/o,t[0]=a*o,t[1]=-n*o,t[2]=-i*o,t[3]=r*o,t):null}},{}],258:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=u*o-s*c,f=-u*a+s*l,p=c*a-o*l,d=r*h+n*f+i*p;return d?(d=1/d,t[0]=h*d,t[1]=(-u*n+i*c)*d,t[2]=(s*n-i*o)*d,t[3]=f*d,t[4]=(u*r-i*l)*d,t[5]=(-s*r+i*a)*d,t[6]=p*d,t[7]=(-c*r+n*l)*d,t[8]=(o*r-n*a)*d,t):null}},{}],259:[function(t,e,r){e.exports=function(t){var e=new Float32Array(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e}},{}],260:[function(t,e,r){e.exports=function(){var t=new Float32Array(16);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],261:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3],a=t[4],o=t[5],s=t[6],l=t[7],c=t[8],u=t[9],h=t[10],f=t[11],p=t[12],d=t[13],g=t[14],v=t[15];return(e*o-r*a)*(h*v-f*g)-(e*s-n*a)*(u*v-f*d)+(e*l-i*a)*(u*g-h*d)+(r*s-n*o)*(c*v-f*p)-(r*l-i*o)*(c*g-h*p)+(n*l-i*s)*(c*d-u*p)}},{}],262:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r+r,s=n+n,l=i+i,c=r*o,u=n*o,h=n*s,f=i*o,p=i*s,d=i*l,g=a*o,v=a*s,m=a*l;return t[0]=1-h-d,t[1]=u+m,t[2]=f-v,t[3]=0,t[4]=u-m,t[5]=1-c-d,t[6]=p+g,t[7]=0,t[8]=f+v,t[9]=p-g,t[10]=1-c-h,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],263:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=n+n,l=i+i,c=a+a,u=n*s,h=n*l,f=n*c,p=i*l,d=i*c,g=a*c,v=o*s,m=o*l,y=o*c;return t[0]=1-(p+g),t[1]=h+y,t[2]=f-m,t[3]=0,t[4]=h-y,t[5]=1-(u+g),t[6]=d+v,t[7]=0,t[8]=f+m,t[9]=d-v,t[10]=1-(u+p),t[11]=0,t[12]=r[0],t[13]=r[1],t[14]=r[2],t[15]=1,t}},{}],264:[function(t,e,r){e.exports=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],265:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],g=e[13],v=e[14],m=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,k=i*c-a*l,T=u*g-h*d,A=u*v-f*d,M=u*m-p*d,S=h*v-f*g,E=h*m-p*g,C=f*m-p*v,L=y*C-x*E+b*S+_*M-w*A+k*T;if(!L)return null;return L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(i*E-n*C-a*S)*L,t[2]=(g*k-v*w+m*_)*L,t[3]=(f*w-h*k-p*_)*L,t[4]=(l*M-o*C-c*A)*L,t[5]=(r*C-i*M+a*A)*L,t[6]=(v*b-d*k-m*x)*L,t[7]=(u*k-f*b+p*x)*L,t[8]=(o*E-s*M+c*T)*L,t[9]=(n*M-r*E-a*T)*L,t[10]=(d*w-g*b+m*y)*L,t[11]=(h*b-u*w-p*y)*L,t[12]=(s*A-o*S-l*T)*L,t[13]=(r*S-n*A+i*T)*L,t[14]=(g*x-d*_-v*y)*L,t[15]=(u*_-h*x+f*y)*L,t}},{}],266:[function(t,e,r){var n=t(\"./identity\");e.exports=function(t,e,r,i){var a,o,s,l,c,u,h,f,p,d,g=e[0],v=e[1],m=e[2],y=i[0],x=i[1],b=i[2],_=r[0],w=r[1],k=r[2];if(Math.abs(g-_)<1e-6&&Math.abs(v-w)<1e-6&&Math.abs(m-k)<1e-6)return n(t);h=g-_,f=v-w,p=m-k,d=1/Math.sqrt(h*h+f*f+p*p),a=x*(p*=d)-b*(f*=d),o=b*(h*=d)-y*p,s=y*f-x*h,(d=Math.sqrt(a*a+o*o+s*s))?(a*=d=1/d,o*=d,s*=d):(a=0,o=0,s=0);l=f*s-p*o,c=p*a-h*s,u=h*o-f*a,(d=Math.sqrt(l*l+c*c+u*u))?(l*=d=1/d,c*=d,u*=d):(l=0,c=0,u=0);return t[0]=a,t[1]=l,t[2]=h,t[3]=0,t[4]=o,t[5]=c,t[6]=f,t[7]=0,t[8]=s,t[9]=u,t[10]=p,t[11]=0,t[12]=-(a*g+o*v+s*m),t[13]=-(l*g+c*v+u*m),t[14]=-(h*g+f*v+p*m),t[15]=1,t}},{\"./identity\":264}],267:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],g=e[12],v=e[13],m=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*h+w*g,t[1]=x*i+b*l+_*f+w*v,t[2]=x*a+b*c+_*p+w*m,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*h+w*g,t[5]=x*i+b*l+_*f+w*v,t[6]=x*a+b*c+_*p+w*m,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*h+w*g,t[9]=x*i+b*l+_*f+w*v,t[10]=x*a+b*c+_*p+w*m,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*h+w*g,t[13]=x*i+b*l+_*f+w*v,t[14]=x*a+b*c+_*p+w*m,t[15]=x*o+b*u+_*d+w*y,t}},{}],268:[function(t,e,r){e.exports=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t}},{}],269:[function(t,e,r){e.exports=function(t,e,r,n,i){var a=1/Math.tan(e/2),o=1/(n-i);return t[0]=a/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=a,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=(i+n)*o,t[11]=-1,t[12]=0,t[13]=0,t[14]=2*i*n*o,t[15]=0,t}},{}],270:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_,w,k,T,A,M,S,E=n[0],C=n[1],L=n[2],P=Math.sqrt(E*E+C*C+L*L);if(Math.abs(P)<1e-6)return null;E*=P=1/P,C*=P,L*=P,i=Math.sin(r),a=Math.cos(r),o=1-a,s=e[0],l=e[1],c=e[2],u=e[3],h=e[4],f=e[5],p=e[6],d=e[7],g=e[8],v=e[9],m=e[10],y=e[11],x=E*E*o+a,b=C*E*o+L*i,_=L*E*o-C*i,w=E*C*o-L*i,k=C*C*o+a,T=L*C*o+E*i,A=E*L*o+C*i,M=C*L*o-E*i,S=L*L*o+a,t[0]=s*x+h*b+g*_,t[1]=l*x+f*b+v*_,t[2]=c*x+p*b+m*_,t[3]=u*x+d*b+y*_,t[4]=s*w+h*k+g*T,t[5]=l*w+f*k+v*T,t[6]=c*w+p*k+m*T,t[7]=u*w+d*k+y*T,t[8]=s*A+h*M+g*S,t[9]=l*A+f*M+v*S,t[10]=c*A+p*M+m*S,t[11]=u*A+d*M+y*S,e!==t&&(t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t}},{}],271:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+h*n,t[7]=l*i+f*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=h*i-s*n,t[11]=f*i-l*n,t}},{}],272:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[8],u=e[9],h=e[10],f=e[11];e!==t&&(t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i-c*n,t[1]=o*i-u*n,t[2]=s*i-h*n,t[3]=l*i-f*n,t[8]=a*n+c*i,t[9]=o*n+u*i,t[10]=s*n+h*i,t[11]=l*n+f*i,t}},{}],273:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+h*n,t[3]=l*i+f*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=h*i-s*n,t[7]=f*i-l*n,t}},{}],274:[function(t,e,r){e.exports=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},{}],275:[function(t,e,r){e.exports=function(t,e,r){var n,i,a,o,s,l,c,u,h,f,p,d,g=r[0],v=r[1],m=r[2];e===t?(t[12]=e[0]*g+e[4]*v+e[8]*m+e[12],t[13]=e[1]*g+e[5]*v+e[9]*m+e[13],t[14]=e[2]*g+e[6]*v+e[10]*m+e[14],t[15]=e[3]*g+e[7]*v+e[11]*m+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*g+s*v+h*m+e[12],t[13]=i*g+l*v+f*m+e[13],t[14]=a*g+c*v+p*m+e[14],t[15]=o*g+u*v+d*m+e[15]);return t}},{}],276:[function(t,e,r){e.exports=function(t,e){if(t===e){var r=e[1],n=e[2],i=e[3],a=e[6],o=e[7],s=e[11];t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=r,t[6]=e[9],t[7]=e[13],t[8]=n,t[9]=a,t[11]=e[14],t[12]=i,t[13]=o,t[14]=s}else t[0]=e[0],t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=e[1],t[5]=e[5],t[6]=e[9],t[7]=e[13],t[8]=e[2],t[9]=e[6],t[10]=e[10],t[11]=e[14],t[12]=e[3],t[13]=e[7],t[14]=e[11],t[15]=e[15];return t}},{}],277:[function(t,e,r){\"use strict\";e.exports=function(t,e){switch(e.length){case 0:break;case 1:t[0]=1/e[0];break;case 4:n(t,e);break;case 9:i(t,e);break;case 16:a(t,e);break;default:throw new Error(\"currently supports matrices up to 4x4\")}return t};var n=t(\"gl-mat2/invert\"),i=t(\"gl-mat3/invert\"),a=t(\"gl-mat4/invert\")},{\"gl-mat2/invert\":257,\"gl-mat3/invert\":258,\"gl-mat4/invert\":265}],278:[function(t,e,r){\"use strict\";var n=t(\"barycentric\"),i=t(\"polytope-closest-point/lib/closest_point_2d.js\");function a(t,e){for(var r=[0,0,0,0],n=0;n<4;++n)for(var i=0;i<4;++i)r[i]+=t[4*n+i]*e[n];return r}function o(t,e,r,n,i){for(var o=a(n,a(r,a(e,[t[0],t[1],t[2],1]))),s=0;s<3;++s)o[s]/=o[3];return[.5*i[0]*(1+o[0]),.5*i[1]*(1-o[1])]}e.exports=function(t,e,r,a,s,l){if(1===t.length)return[0,t[0].slice()];for(var c=new Array(t.length),u=0;u<t.length;++u)c[u]=o(t[u],r,a,s,l);for(var h=0,f=1/0,u=0;u<c.length;++u){for(var p=0,d=0;d<2;++d)p+=Math.pow(c[u][d]-e[d],2);p<f&&(f=p,h=u)}for(var g=function(t,e){if(2===t.length){for(var r=0,a=0,o=0;o<2;++o)r+=Math.pow(e[o]-t[0][o],2),a+=Math.pow(e[o]-t[1][o],2);return r=Math.sqrt(r),a=Math.sqrt(a),r+a<1e-6?[1,0]:[a/(r+a),r/(a+r)]}if(3===t.length){var s=[0,0];return i(t[0],t[1],t[2],e,s),n(t,s)}return[]}(c,e),v=0,u=0;u<3;++u){if(g[u]<-.001||g[u]>1.0001)return null;v+=g[u]}if(Math.abs(v-1)>.001)return null;return[h,function(t,e){for(var r=[0,0,0],n=0;n<t.length;++n)for(var i=t[n],a=e[n],o=0;o<3;++o)r[o]+=a*i[o];return r}(t,g),g]}},{barycentric:73,\"polytope-closest-point/lib/closest_point_2d.js\":481}],279:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, normal;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  gl_Position      = project(position);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * vec4(position , 1.0);\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal  = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  f_color          = color;\\n  f_data           = position;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\n//#pragma glslify: beckmann = require(glsl-specular-beckmann) // used in gl-surface3d\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (f_color.a == 0.0 ||\\n    outOfRange(clipBounds[0], clipBounds[1], f_data)\\n  ) discard;\\n\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  //float specular = max(0.0, beckmann(L, V, N, roughness)); // used in gl-surface3d\\n\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = vec4(f_color.rgb, 1.0) * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * f_color.a;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_color = color;\\n  f_data  = position;\\n  f_uv    = uv;\\n}\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_data)) discard;\\n\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\nattribute float pointSize;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0 ,0.0 ,0.0);\\n  } else {\\n    gl_Position = projection * view * model * vec4(position, 1.0);\\n  }\\n  gl_PointSize = pointSize;\\n  f_color = color;\\n  f_uv = uv;\\n}\"]),c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  vec2 pointR = gl_PointCoord.xy - vec2(0.5, 0.5);\\n  if(dot(pointR, pointR) > 0.25) {\\n    discard;\\n  }\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_id        = id;\\n  f_position  = position;\\n}\"]),h=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]),f=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3  position;\\nattribute float pointSize;\\nattribute vec4  id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0, 0.0, 0.0);\\n  } else {\\n    gl_Position  = projection * view * model * vec4(position, 1.0);\\n    gl_PointSize = pointSize;\\n  }\\n  f_id         = id;\\n  f_position   = position;\\n}\"]),p=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n}\"]),d=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec3 contourColor;\\n\\nvoid main() {\\n  gl_FragColor = vec4(contourColor, 1.0);\\n}\\n\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.wireShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.pointShader={vertex:l,fragment:c,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"pointSize\",type:\"float\"}]},r.pickShader={vertex:u,fragment:h,attributes:[{name:\"position\",type:\"vec3\"},{name:\"id\",type:\"vec4\"}]},r.pointPickShader={vertex:f,fragment:h,attributes:[{name:\"position\",type:\"vec3\"},{name:\"pointSize\",type:\"float\"},{name:\"id\",type:\"vec4\"}]},r.contourShader={vertex:p,fragment:d,attributes:[{name:\"position\",type:\"vec3\"}]}},{glslify:409}],280:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./lib/shaders\"),g=t(\"./lib/closest-point\"),v=d.meshShader,m=d.wireShader,y=d.pointShader,x=d.pickShader,b=d.pointPickShader,_=d.contourShader,w=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function k(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_,k,T,A,M,S){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.lineShader=n,this.pointShader=i,this.pickShader=a,this.pointPickShader=o,this.contourShader=s,this.trianglePositions=l,this.triangleColors=u,this.triangleNormals=f,this.triangleUVs=h,this.triangleIds=c,this.triangleVAO=p,this.triangleCount=0,this.lineWidth=1,this.edgePositions=d,this.edgeColors=v,this.edgeUVs=m,this.edgeIds=g,this.edgeVAO=y,this.edgeCount=0,this.pointPositions=x,this.pointColors=_,this.pointUVs=k,this.pointSizes=T,this.pointIds=b,this.pointVAO=A,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=M,this.contourVAO=S,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.hasAlpha=!1,this.opacityscale=!1,this._model=w,this._view=w,this._projection=w,this._resolution=[1,1]}var T=k.prototype;function A(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}function M(t){var e=n(t,y.vertex,y.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.pointSize.location=4,e}function S(t){var e=n(t,x.vertex,x.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e}function E(t){var e=n(t,b.vertex,b.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.pointSize.location=4,e}function C(t){var e=n(t,_.vertex,_.fragment);return e.attributes.position.location=0,e}T.isOpaque=function(){return!this.hasAlpha},T.isTransparent=function(){return this.hasAlpha},T.pickSlots=1,T.setPickBase=function(t){this.pickId=t},T.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=i[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},T.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=t.opacity,this.opacity<1&&(this.hasAlpha=!0)),\"opacityscale\"in t&&(this.opacityscale=t.opacityscale,this.hasAlpha=!0),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t,e){for(var r=h({colormap:t,nshades:256,format:\"rgba\"}),n=new Uint8Array(1024),i=0;i<256;++i){for(var a=r[i],o=0;o<3;++o)n[4*i+o]=a[o];n[4*i+3]=e?255*A(i/255,e):255*a[3]}return u(n,[256,256,4],[4,0,1])}(t.colormap,this.opacityscale)),this.texture.generateMipmap());var r=t.cells,n=t.positions;if(n&&r){var i=[],a=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[];this.cells=r,this.positions=n;var w=t.vertexNormals,k=t.cellNormals,T=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,M=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!k&&(k=s.faceNormals(r,n,M)),k||w||(w=s.vertexNormals(r,n,T));var S=t.vertexColors,E=t.cellColors,C=t.meshColor||[1,1,1,1],L=t.vertexUVs,P=t.vertexIntensity,O=t.cellUVs,z=t.cellIntensity,I=1/0,D=-1/0;if(!L&&!O)if(P)if(t.vertexIntensityBounds)I=+t.vertexIntensityBounds[0],D=+t.vertexIntensityBounds[1];else for(var R=0;R<P.length;++R){var F=P[R];I=Math.min(I,F),D=Math.max(D,F)}else if(z)for(R=0;R<z.length;++R){F=z[R];I=Math.min(I,F),D=Math.max(D,F)}else for(R=0;R<n.length;++R){F=n[R][2];I=Math.min(I,F),D=Math.max(D,F)}this.intensity=P||(z?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,z):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var B=t.pointSizes,N=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(R=0;R<n.length;++R)for(var j=n[R],U=0;U<3;++U)!isNaN(j[U])&&isFinite(j[U])&&(this.bounds[0][U]=Math.min(this.bounds[0][U],j[U]),this.bounds[1][U]=Math.max(this.bounds[1][U],j[U]));var V=0,q=0,H=0;t:for(R=0;R<r.length;++R){var G=r[R];switch(G.length){case 1:for(j=n[W=G[0]],U=0;U<3;++U)if(isNaN(j[U])||!isFinite(j[U]))continue t;m.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?y.push(X[0],X[1],X[2],this.opacity):(y.push(X[0],X[1],X[2],X[3]*this.opacity),!this.hasAlpha&&X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],x.push(Z[0],Z[1]),B?b.push(B[W]):b.push(N),_.push(R),H+=1;break;case 2:for(U=0;U<2;++U){j=n[W=G[U]];for(var Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t}for(U=0;U<2;++U){j=n[W=G[U]];p.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?d.push(X[0],X[1],X[2],this.opacity):(d.push(X[0],X[1],X[2],X[3]*this.opacity),!this.hasAlpha&&X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],g.push(Z[0],Z[1]),v.push(R)}q+=1;break;case 3:for(U=0;U<3;++U)for(j=n[W=G[U]],Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t;for(U=0;U<3;++U){var W,X,Z,J;j=n[W=G[2-U]];i.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?a.push(X[0],X[1],X[2],this.opacity):(a.push(X[0],X[1],X[2],X[3]*this.opacity),!this.hasAlpha&&X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],c.push(Z[0],Z[1]),J=w?w[W]:k[R],l.push(J[0],J[1],J[2]),f.push(R)}V+=1}}this.pointCount=H,this.edgeCount=q,this.triangleCount=V,this.pointPositions.update(m),this.pointColors.update(y),this.pointUVs.update(x),this.pointSizes.update(b),this.pointIds.update(new Uint32Array(_)),this.edgePositions.update(p),this.edgeColors.update(d),this.edgeUVs.update(g),this.edgeIds.update(new Uint32Array(v)),this.trianglePositions.update(i),this.triangleColors.update(a),this.triangleUVs.update(c),this.triangleNormals.update(l),this.triangleIds.update(new Uint32Array(f))}},T.drawTransparent=T.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:w.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h,f=u[15];for(o=0;o<3;++o)f+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];s.lightPosition[o]=p/f}this.triangleCount>0&&((h=this.triShader).bind(),h.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind());this.edgeCount>0&&this.lineWidth>0&&((h=this.lineShader).bind(),h.uniforms=s,this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind());this.pointCount>0&&((h=this.pointShader).bind(),h.uniforms=s,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind());this.contourEnable&&this.contourCount>0&&this.contourLineWidth>0&&((h=this.contourShader).bind(),h.uniforms=s,this.contourVAO.bind(),e.drawArrays(e.LINES,0,this.contourCount),this.contourVAO.unbind())},T.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s,l={model:r,view:n,projection:i,clipBounds:a,pickId:this.pickId/255};((s=this.pickShader).bind(),s.uniforms=l,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind()),this.pointCount>0)&&((s=this.pointPickShader).bind(),s.uniforms=l,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind())},T.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;for(var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions,i=new Array(r.length),a=0;a<r.length;++a)i[a]=n[r[a]];var o=g(i,[t.coord[0],this._resolution[1]-t.coord[1]],this._model,this._view,this._projection,this._resolution);if(!o)return null;var s=o[2],l=0;for(a=0;a<r.length;++a)l+=s[a]*this.intensity[r[a]];return{position:o[1],index:r[o[0]],cell:r,cellId:e,intensity:l,dataCoordinate:this.positions[r[o[0]]]}},T.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.lineShader.dispose(),this.pointShader.dispose(),this.pickShader.dispose(),this.pointPickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose(),this.contourShader.dispose()},e.exports=function(t,e){if(1===arguments.length&&(t=(e=t).gl),!(t.getExtension(\"OES_standard_derivatives\")||t.getExtension(\"MOZ_OES_standard_derivatives\")||t.getExtension(\"WEBKIT_OES_standard_derivatives\")))throw new Error(\"derivatives not supported\");var r=function(t){var e=n(t,v.vertex,v.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.normal.location=4,e}(t),s=function(t){var e=n(t,m.vertex,m.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e}(t),l=M(t),c=S(t),h=E(t),f=C(t),p=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));p.generateMipmap(),p.minFilter=t.LINEAR_MIPMAP_LINEAR,p.magFilter=t.LINEAR;var d=i(t),g=i(t),y=i(t),x=i(t),b=i(t),_=a(t,[{buffer:d,type:t.FLOAT,size:3},{buffer:b,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:g,type:t.FLOAT,size:4},{buffer:y,type:t.FLOAT,size:2},{buffer:x,type:t.FLOAT,size:3}]),w=i(t),T=i(t),A=i(t),L=i(t),P=a(t,[{buffer:w,type:t.FLOAT,size:3},{buffer:L,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:T,type:t.FLOAT,size:4},{buffer:A,type:t.FLOAT,size:2}]),O=i(t),z=i(t),I=i(t),D=i(t),R=i(t),F=a(t,[{buffer:O,type:t.FLOAT,size:3},{buffer:R,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:z,type:t.FLOAT,size:4},{buffer:I,type:t.FLOAT,size:2},{buffer:D,type:t.FLOAT,size:1}]),B=i(t),N=new k(t,p,r,s,l,c,h,f,d,b,g,y,x,_,w,L,T,A,P,O,R,z,I,D,F,B,a(t,[{buffer:B,type:t.FLOAT,size:3}]));return N.update(e),N}},{\"./lib/closest-point\":278,\"./lib/shaders\":279,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-shader\":301,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,normals:453,\"simplicial-complex-contour\":518,\"typedarray-pool\":545}],281:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[0,0,0,1,1,0,1,1]),s=i(e,a.boxVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawBox=(s=[0,0],l=[0,0],function(t,e,r,n,i){var a=this.plot,o=this.shader,c=a.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,o.uniforms.lo=s,o.uniforms.hi=l,o.uniforms.color=i,c.drawArrays(c.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":284,\"gl-buffer\":241,\"gl-shader\":301}],282:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,o.gridVert,o.gridFrag),l=i(e,o.tickVert,o.gridFrag);return new s(t,r,a,l)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"binary-search-bounds\"),o=t(\"./shaders\");function s(t,e,r,n){this.plot=t,this.vbo=e,this.shader=r,this.tickShader=n,this.ticks=[[],[]]}function l(t,e){return t-e}var c,u,h,f,p,d=s.prototype;d.draw=(c=[0,0],u=[0,0],h=[0,0],function(){for(var t=this.plot,e=this.vbo,r=this.shader,n=this.ticks,i=t.gl,a=t._tickBounds,o=t.dataBox,s=t.viewBox,l=t.gridLineWidth,f=t.gridLineColor,p=t.gridLineEnable,d=t.pixelRatio,g=0;g<2;++g){var v=a[g],m=a[g+2]-v,y=.5*(o[g+2]+o[g]),x=o[g+2]-o[g];u[g]=2*m/x,c[g]=2*(v-y)/x}r.bind(),e.bind(),r.attributes.dataCoord.pointer(),r.uniforms.dataShift=c,r.uniforms.dataScale=u;var b=0;for(g=0;g<2;++g){h[0]=h[1]=0,h[g]=1,r.uniforms.dataAxis=h,r.uniforms.lineWidth=l[g]/(s[g+2]-s[g])*d,r.uniforms.color=f[g];var _=6*n[g].length;p[g]&&_&&i.drawArrays(i.TRIANGLES,b,_),b+=_}}),d.drawTickMarks=function(){var t=[0,0],e=[0,0],r=[1,0],n=[0,1],i=[0,0],o=[0,0];return function(){for(var s=this.plot,c=this.vbo,u=this.tickShader,h=this.ticks,f=s.gl,p=s._tickBounds,d=s.dataBox,g=s.viewBox,v=s.pixelRatio,m=s.screenBox,y=m[2]-m[0],x=m[3]-m[1],b=g[2]-g[0],_=g[3]-g[1],w=0;w<2;++w){var k=p[w],T=p[w+2]-k,A=.5*(d[w+2]+d[w]),M=d[w+2]-d[w];e[w]=2*T/M,t[w]=2*(k-A)/M}e[0]*=b/y,t[0]*=b/y,e[1]*=_/x,t[1]*=_/x,u.bind(),c.bind(),u.attributes.dataCoord.pointer();var S=u.uniforms;S.dataShift=t,S.dataScale=e;var E=s.tickMarkLength,C=s.tickMarkWidth,L=s.tickMarkColor,P=6*h[0].length,O=Math.min(a.ge(h[0],(d[0]-p[0])/(p[2]-p[0]),l),h[0].length),z=Math.min(a.gt(h[0],(d[2]-p[0])/(p[2]-p[0]),l),h[0].length),I=0+6*O,D=6*Math.max(0,z-O),R=Math.min(a.ge(h[1],(d[1]-p[1])/(p[3]-p[1]),l),h[1].length),F=Math.min(a.gt(h[1],(d[3]-p[1])/(p[3]-p[1]),l),h[1].length),B=P+6*R,N=6*Math.max(0,F-R);i[0]=2*(g[0]-E[1])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=E[1]*v/y,o[1]=C[1]*v/x,N&&(S.color=L[1],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,f.drawArrays(f.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[1]-E[0])/x-1,o[0]=C[0]*v/y,o[1]=E[0]*v/x,D&&(S.color=L[0],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,f.drawArrays(f.TRIANGLES,I,D)),i[0]=2*(g[2]+E[3])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=E[3]*v/y,o[1]=C[3]*v/x,N&&(S.color=L[3],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,f.drawArrays(f.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[3]+E[2])/x-1,o[0]=C[2]*v/y,o[1]=E[2]*v/x,D&&(S.color=L[2],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,f.drawArrays(f.TRIANGLES,I,D))}}(),d.update=(f=[1,1,-1,-1,1,-1],p=[1,-1,1,1,-1,-1],function(t){for(var e=t.ticks,r=t.bounds,n=new Float32Array(18*(e[0].length+e[1].length)),i=(this.plot.zeroLineEnable,0),a=[[],[]],o=0;o<2;++o)for(var s=a[o],l=e[o],c=r[o],u=r[o+2],h=0;h<l.length;++h){var d=(l[h].x-c)/(u-c);s.push(d);for(var g=0;g<6;++g)n[i++]=d,n[i++]=f[g],n[i++]=p[g]}this.ticks=a,this.vbo.update(n)}),d.dispose=function(){this.vbo.dispose(),this.shader.dispose(),this.tickShader.dispose()}},{\"./shaders\":284,\"binary-search-bounds\":286,\"gl-buffer\":241,\"gl-shader\":301}],283:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[-1,-1,-1,1,1,-1,1,1]),s=i(e,a.lineVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawLine=(s=[0,0],l=[0,0],function(t,e,r,n,i,a){var o=this.plot,c=this.shader,u=o.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,c.uniforms.start=s,c.uniforms.end=l,c.uniforms.width=i*o.pixelRatio,c.uniforms.color=a,u.drawArrays(u.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":284,\"gl-buffer\":241,\"gl-shader\":301}],284:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision lowp float;\\n#define GLSLIFY 1\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = vec4(color.xyz * color.w, color.w);\\n}\\n\"]);e.exports={lineVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 start, end;\\nuniform float width;\\n\\nvec2 perp(vec2 v) {\\n  return vec2(v.y, -v.x);\\n}\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  vec2 delta = normalize(perp(start - end));\\n  vec2 offset = mix(start, end, 0.5 * (coord.y+1.0));\\n  gl_Position = vec4(screen(offset + 0.5 * width * delta * coord.x), 0, 1);\\n}\\n\"]),lineFrag:i,textVert:n([\"#define GLSLIFY 1\\nattribute vec3 textCoordinate;\\n\\nuniform vec2 dataScale, dataShift, dataAxis, screenOffset, textScale;\\nuniform float angle;\\n\\nvoid main() {\\n  float dataOffset  = textCoordinate.z;\\n  vec2 glyphOffset  = textCoordinate.xy;\\n  mat2 glyphMatrix = mat2(cos(angle), sin(angle), -sin(angle), cos(angle));\\n  vec2 screenCoordinate = dataAxis * (dataScale * dataOffset + dataShift) +\\n    glyphMatrix * glyphOffset * textScale + screenOffset;\\n  gl_Position = vec4(screenCoordinate, 0, 1);\\n}\\n\"]),textFrag:i,gridVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale;\\nuniform float lineWidth;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  pos += 10.0 * dataCoord.y * vec2(dataAxis.y, -dataAxis.x) + dataCoord.z * lineWidth;\\n  gl_Position = vec4(pos, 0, 1);\\n}\\n\"]),gridFrag:i,boxVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 lo, hi;\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  gl_Position = vec4(screen(mix(lo, hi, coord)), 0, 1);\\n}\\n\"]),tickVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale, screenOffset, tickScale;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  gl_Position = vec4(pos + tickScale*dataCoord.yz + screenOffset, 0, 1);\\n}\\n\"])}},{glslify:409}],285:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,s.textVert,s.textFrag);return new l(t,r,a)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"text-cache\"),o=t(\"binary-search-bounds\"),s=t(\"./shaders\");function l(t,e,r){this.plot=t,this.vbo=e,this.shader=r,this.tickOffset=[[],[]],this.tickX=[[],[]],this.labelOffset=[0,0],this.labelCount=[0,0]}var c,u,h,f,p,d,g=l.prototype;g.drawTicks=(c=[0,0],u=[0,0],h=[0,0],function(t){var e=this.plot,r=this.shader,n=this.tickX[t],i=this.tickOffset[t],a=e.gl,s=e.viewBox,l=e.dataBox,f=e.screenBox,p=e.pixelRatio,d=e.tickEnable,g=e.tickPad,v=e.tickColor,m=e.tickAngle,y=e.labelEnable,x=e.labelPad,b=e.labelColor,_=e.labelAngle,w=this.labelOffset[t],k=this.labelCount[t],T=o.lt(n,l[t]),A=o.le(n,l[t+2]);c[0]=c[1]=0,c[t]=1,u[t]=(s[2+t]+s[t])/(f[2+t]-f[t])-1;var M=2/f[2+(1^t)]-f[1^t];u[1^t]=M*s[1^t]-1,d[t]&&(u[1^t]-=M*p*g[t],T<A&&i[A]>i[T]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=v[t],r.uniforms.angle=m[t],a.drawArrays(a.TRIANGLES,i[T],i[A]-i[T]))),y[t]&&k&&(u[1^t]-=M*p*x[t],r.uniforms.dataAxis=h,r.uniforms.screenOffset=u,r.uniforms.color=b[t],r.uniforms.angle=_[t],a.drawArrays(a.TRIANGLES,w,k)),u[1^t]=M*s[2+(1^t)]-1,d[t+2]&&(u[1^t]+=M*p*g[t+2],T<A&&i[A]>i[T]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=v[t+2],r.uniforms.angle=m[t+2],a.drawArrays(a.TRIANGLES,i[T],i[A]-i[T]))),y[t+2]&&k&&(u[1^t]+=M*p*x[t+2],r.uniforms.dataAxis=h,r.uniforms.screenOffset=u,r.uniforms.color=b[t+2],r.uniforms.angle=_[t+2],a.drawArrays(a.TRIANGLES,w,k))}),g.drawTitle=function(){var t=[0,0],e=[0,0];return function(){var r=this.plot,n=this.shader,i=r.gl,a=r.screenBox,o=r.titleCenter,s=r.titleAngle,l=r.titleColor,c=r.pixelRatio;if(this.titleCount){for(var u=0;u<2;++u)e[u]=2*(o[u]*c-a[u])/(a[2+u]-a[u])-1;n.bind(),n.uniforms.dataAxis=t,n.uniforms.screenOffset=e,n.uniforms.angle=s,n.uniforms.color=l,i.drawArrays(i.TRIANGLES,this.titleOffset,this.titleCount)}}}(),g.bind=(f=[0,0],p=[0,0],d=[0,0],function(){var t=this.plot,e=this.shader,r=t._tickBounds,n=t.dataBox,i=t.screenBox,a=t.viewBox;e.bind();for(var o=0;o<2;++o){var s=r[o],l=r[o+2]-s,c=.5*(n[o+2]+n[o]),u=n[o+2]-n[o],h=a[o],g=a[o+2]-h,v=i[o],m=i[o+2]-v;p[o]=2*l/u*g/m,f[o]=2*(s-c)/u*g/m}d[1]=2*t.pixelRatio/(i[3]-i[1]),d[0]=d[1]*(i[3]-i[1])/(i[2]-i[0]),e.uniforms.dataScale=p,e.uniforms.dataShift=f,e.uniforms.textScale=d,this.vbo.bind(),e.attributes.textCoordinate.pointer()}),g.update=function(t){var e,r,n,i,o,s=[],l=t.ticks,c=t.bounds;for(o=0;o<2;++o){var u=[Math.floor(s.length/3)],h=[-1/0],f=l[o];for(e=0;e<f.length;++e){var p=f[e],d=p.x,g=p.text,v=p.font||\"sans-serif\";i=p.fontSize||12;for(var m=1/(c[o+2]-c[o]),y=c[o],x=g.split(\"\\n\"),b=0;b<x.length;b++)for(n=a(v,x[b]).data,r=0;r<n.length;r+=2)s.push(n[r]*i,-n[r+1]*i-b*i*1.2,(d-y)*m);u.push(Math.floor(s.length/3)),h.push(d)}this.tickOffset[o]=u,this.tickX[o]=h}for(o=0;o<2;++o){for(this.labelOffset[o]=Math.floor(s.length/3),n=a(t.labelFont[o],t.labels[o],{textAlign:\"center\"}).data,i=t.labelSize[o],e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.labelCount[o]=Math.floor(s.length/3)-this.labelOffset[o]}for(this.titleOffset=Math.floor(s.length/3),n=a(t.titleFont,t.title).data,i=t.titleSize,e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.titleCount=Math.floor(s.length/3)-this.titleOffset,this.vbo.update(s)},g.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":284,\"binary-search-bounds\":286,\"gl-buffer\":241,\"gl-shader\":301,\"text-cache\":536}],286:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],287:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[e.drawingBufferWidth,e.drawingBufferHeight]),c=new l(e,r);return c.grid=i(c),c.text=a(c),c.line=o(c),c.box=s(c),c.update(t),c};var n=t(\"gl-select-static\"),i=t(\"./lib/grid\"),a=t(\"./lib/text\"),o=t(\"./lib/line\"),s=t(\"./lib/box\");function l(t,e){this.gl=t,this.pickBuffer=e,this.screenBox=[0,0,t.drawingBufferWidth,t.drawingBufferHeight],this.viewBox=[0,0,0,0],this.dataBox=[-10,-10,10,10],this.gridLineEnable=[!0,!0],this.gridLineWidth=[1,1],this.gridLineColor=[[0,0,0,1],[0,0,0,1]],this.pixelRatio=1,this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickEnable=[!0,!0,!0,!0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[15,15,15,15],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelEnable=[!0,!0,!0,!0],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.titleCenter=[0,0],this.titleEnable=!0,this.titleAngle=0,this.titleColor=[0,0,0,1],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[4,4],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderLineEnable=[!0,!0,!0,!0],this.borderLineWidth=[2,2,2,2],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.grid=null,this.text=null,this.line=null,this.box=null,this.objects=[],this.overlays=[],this._tickBounds=[1/0,1/0,-1/0,-1/0],this.static=!1,this.dirty=!1,this.pickDirty=!1,this.pickDelay=120,this.pickRadius=10,this._pickTimeout=null,this._drawPick=this.drawPick.bind(this),this._depthCounter=0}var c=l.prototype;function u(t){for(var e=t.slice(),r=0;r<e.length;++r)e[r]=e[r].slice();return e}function h(t,e){return t.x-e.x}c.setDirty=function(){this.dirty=this.pickDirty=!0},c.setOverlayDirty=function(){this.dirty=!0},c.nextDepthValue=function(){return this._depthCounter++/65536},c.draw=function(){var t=this.gl,e=this.screenBox,r=this.viewBox,n=this.dataBox,i=this.pixelRatio,a=this.grid,o=this.line,s=this.text,l=this.objects;if(this._depthCounter=0,this.pickDirty&&(this._pickTimeout&&clearTimeout(this._pickTimeout),this.pickDirty=!1,this._pickTimeout=setTimeout(this._drawPick,this.pickDelay)),this.dirty){if(this.dirty=!1,t.bindFramebuffer(t.FRAMEBUFFER,null),t.enable(t.SCISSOR_TEST),t.disable(t.DEPTH_TEST),t.depthFunc(t.LESS),t.depthMask(!1),t.enable(t.BLEND),t.blendEquation(t.FUNC_ADD,t.FUNC_ADD),t.blendFunc(t.ONE,t.ONE_MINUS_SRC_ALPHA),this.borderColor){t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]);var c=this.borderColor;t.clearColor(c[0]*c[3],c[1]*c[3],c[2]*c[3],c[3]),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT)}t.scissor(r[0],r[1],r[2]-r[0],r[3]-r[1]),t.viewport(r[0],r[1],r[2]-r[0],r[3]-r[1]);var u=this.backgroundColor;t.clearColor(u[0]*u[3],u[1]*u[3],u[2]*u[3],u[3]),t.clear(t.COLOR_BUFFER_BIT),a.draw();var h=this.zeroLineEnable,f=this.zeroLineColor,p=this.zeroLineWidth;if(h[0]||h[1]){o.bind();for(var d=0;d<2;++d)if(h[d]&&n[d]<=0&&n[d+2]>=0){var g=e[d]-n[d]*(e[d+2]-e[d])/(n[d+2]-n[d]);0===d?o.drawLine(g,e[1],g,e[3],p[d],f[d]):o.drawLine(e[0],g,e[2],g,p[d],f[d])}}for(d=0;d<l.length;++d)l[d].draw();t.viewport(e[0],e[1],e[2]-e[0],e[3]-e[1]),t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]),this.grid.drawTickMarks(),o.bind();var v=this.borderLineEnable,m=this.borderLineWidth,y=this.borderLineColor;for(v[1]&&o.drawLine(r[0],r[1]-.5*m[1]*i,r[0],r[3]+.5*m[3]*i,m[1],y[1]),v[0]&&o.drawLine(r[0]-.5*m[0]*i,r[1],r[2]+.5*m[2]*i,r[1],m[0],y[0]),v[3]&&o.drawLine(r[2],r[1]-.5*m[1]*i,r[2],r[3]+.5*m[3]*i,m[3],y[3]),v[2]&&o.drawLine(r[0]-.5*m[0]*i,r[3],r[2]+.5*m[2]*i,r[3],m[2],y[2]),s.bind(),d=0;d<2;++d)s.drawTicks(d);this.titleEnable&&s.drawTitle();var x=this.overlays;for(d=0;d<x.length;++d)x[d].draw();t.disable(t.SCISSOR_TEST),t.disable(t.BLEND),t.depthMask(!0)}},c.drawPick=function(){if(!this.static){var t=this.pickBuffer;this.gl;this._pickTimeout=null,t.begin();for(var e=1,r=this.objects,n=0;n<r.length;++n)e=r[n].drawPick(e);t.end()}},c.pick=function(t,e){if(!this.static){var r=this.pixelRatio,n=this.pickPixelRatio,i=this.viewBox,a=0|Math.round((t-i[0]/r)*n),o=0|Math.round((e-i[1]/r)*n),s=this.pickBuffer.query(a,o,this.pickRadius);if(!s)return null;for(var l=s.id+(s.value[0]<<8)+(s.value[1]<<16)+(s.value[2]<<24),c=this.objects,u=0;u<c.length;++u){var h=c[u].pick(a,o,l);if(h)return h}return null}},c.setScreenBox=function(t){var e=this.screenBox,r=this.pixelRatio;e[0]=0|Math.round(t[0]*r),e[1]=0|Math.round(t[1]*r),e[2]=0|Math.round(t[2]*r),e[3]=0|Math.round(t[3]*r),this.setDirty()},c.setDataBox=function(t){var e=this.dataBox;(e[0]!==t[0]||e[1]!==t[1]||e[2]!==t[2]||e[3]!==t[3])&&(e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],this.setDirty())},c.setViewBox=function(t){var e=this.pixelRatio,r=this.viewBox;r[0]=0|Math.round(t[0]*e),r[1]=0|Math.round(t[1]*e),r[2]=0|Math.round(t[2]*e),r[3]=0|Math.round(t[3]*e);var n=this.pickPixelRatio;this.pickBuffer.shape=[0|Math.round((t[2]-t[0])*n),0|Math.round((t[3]-t[1])*n)],this.setDirty()},c.update=function(t){t=t||{};var e=this.gl;this.pixelRatio=t.pixelRatio||1;var r=this.pixelRatio;this.pickPixelRatio=Math.max(r,1),this.setScreenBox(t.screenBox||[0,0,e.drawingBufferWidth/r,e.drawingBufferHeight/r]);this.screenBox;this.setViewBox(t.viewBox||[.125*(this.screenBox[2]-this.screenBox[0])/r,.125*(this.screenBox[3]-this.screenBox[1])/r,.875*(this.screenBox[2]-this.screenBox[0])/r,.875*(this.screenBox[3]-this.screenBox[1])/r]);var n=this.viewBox,i=(n[2]-n[0])/(n[3]-n[1]);this.setDataBox(t.dataBox||[-10,-10/i,10,10/i]),this.borderColor=!1!==t.borderColor&&(t.borderColor||[0,0,0,0]).slice(),this.backgroundColor=(t.backgroundColor||[0,0,0,0]).slice(),this.gridLineEnable=(t.gridLineEnable||[!0,!0]).slice(),this.gridLineWidth=(t.gridLineWidth||[1,1]).slice(),this.gridLineColor=u(t.gridLineColor||[[.5,.5,.5,1],[.5,.5,.5,1]]),this.zeroLineEnable=(t.zeroLineEnable||[!0,!0]).slice(),this.zeroLineWidth=(t.zeroLineWidth||[4,4]).slice(),this.zeroLineColor=u(t.zeroLineColor||[[0,0,0,1],[0,0,0,1]]),this.tickMarkLength=(t.tickMarkLength||[0,0,0,0]).slice(),this.tickMarkWidth=(t.tickMarkWidth||[0,0,0,0]).slice(),this.tickMarkColor=u(t.tickMarkColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.titleCenter=(t.titleCenter||[.5*(n[0]+n[2])/r,(n[3]+120)/r]).slice(),this.titleEnable=!(\"titleEnable\"in t&&!t.titleEnable),this.titleAngle=t.titleAngle||0,this.titleColor=(t.titleColor||[0,0,0,1]).slice(),this.labelPad=(t.labelPad||[15,15,15,15]).slice(),this.labelAngle=(t.labelAngle||[0,Math.PI/2,0,3*Math.PI/2]).slice(),this.labelEnable=(t.labelEnable||[!0,!0,!0,!0]).slice(),this.labelColor=u(t.labelColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.tickPad=(t.tickPad||[15,15,15,15]).slice(),this.tickAngle=(t.tickAngle||[0,0,0,0]).slice(),this.tickEnable=(t.tickEnable||[!0,!0,!0,!0]).slice(),this.tickColor=u(t.tickColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.borderLineEnable=(t.borderLineEnable||[!0,!0,!0,!0]).slice(),this.borderLineWidth=(t.borderLineWidth||[2,2,2,2]).slice(),this.borderLineColor=u(t.borderLineColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]);var a=t.ticks||[[],[]],o=this._tickBounds;o[0]=o[1]=1/0,o[2]=o[3]=-1/0;for(var s=0;s<2;++s){var l=a[s].slice(0);0!==l.length&&(l.sort(h),o[s]=Math.min(o[s],l[0].x),o[s+2]=Math.max(o[s+2],l[l.length-1].x))}this.grid.update({bounds:o,ticks:a}),this.text.update({bounds:o,ticks:a,labels:t.labels||[\"x\",\"y\"],labelSize:t.labelSize||[12,12],labelFont:t.labelFont||[\"sans-serif\",\"sans-serif\"],title:t.title||\"\",titleSize:t.titleSize||18,titleFont:t.titleFont||\"sans-serif\"}),this.static=!!t.static,this.setDirty()},c.dispose=function(){this.box.dispose(),this.grid.dispose(),this.text.dispose(),this.line.dispose();for(var t=this.objects.length-1;t>=0;--t)this.objects[t].dispose();this.objects.length=0;for(t=this.overlays.length-1;t>=0;--t)this.overlays[t].dispose();this.overlays.length=0,this.gl=null},c.addObject=function(t){this.objects.indexOf(t)<0&&(this.objects.push(t),this.setDirty())},c.removeObject=function(t){for(var e=this.objects,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setDirty();break}},c.addOverlay=function(t){this.overlays.indexOf(t)<0&&(this.overlays.push(t),this.setOverlayDirty())},c.removeOverlay=function(t){for(var e=this.overlays,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setOverlayDirty();break}}},{\"./lib/box\":281,\"./lib/grid\":282,\"./lib/line\":283,\"./lib/text\":285,\"gl-select-static\":300}],288:[function(t,e,r){\"use strict\";e.exports=function(t,e){t=t||document.body,e=e||{};var r=[.01,1/0];\"distanceLimits\"in e&&(r[0]=e.distanceLimits[0],r[1]=e.distanceLimits[1]);\"zoomMin\"in e&&(r[0]=e.zoomMin);\"zoomMax\"in e&&(r[1]=e.zoomMax);var c=i({center:e.center||[0,0,0],up:e.up||[0,1,0],eye:e.eye||[0,0,10],mode:e.mode||\"orbit\",distanceLimits:r}),u=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],h=0,f=t.clientWidth,p=t.clientHeight,d={keyBindingMode:\"rotate\",enableWheel:!0,view:c,element:t,delay:e.delay||16,rotateSpeed:e.rotateSpeed||1,zoomSpeed:e.zoomSpeed||1,translateSpeed:e.translateSpeed||1,flipX:!!e.flipX,flipY:!!e.flipY,modes:c.modes,_ortho:e._ortho||e.projection&&\"orthographic\"===e.projection.type||!1,tick:function(){var e=n(),r=this.delay,i=e-2*r;c.idle(e-r),c.recalcMatrix(i),c.flush(e-(100+2*r));for(var a=!0,o=c.computedMatrix,s=0;s<16;++s)a=a&&u[s]===o[s],u[s]=o[s];var l=t.clientWidth===f&&t.clientHeight===p;return f=t.clientWidth,p=t.clientHeight,a?!l:(h=Math.exp(c.computedRadius[0]),!0)},lookAt:function(t,e,r){c.lookAt(c.lastT(),t,e,r)},rotate:function(t,e,r){c.rotate(c.lastT(),t,e,r)},pan:function(t,e,r){c.pan(c.lastT(),t,e,r)},translate:function(t,e,r){c.translate(c.lastT(),t,e,r)}};return Object.defineProperties(d,{matrix:{get:function(){return c.computedMatrix},set:function(t){return c.setMatrix(c.lastT(),t),c.computedMatrix},enumerable:!0},mode:{get:function(){return c.getMode()},set:function(t){var e=c.computedUp.slice(),r=c.computedEye.slice(),i=c.computedCenter.slice();if(c.setMode(t),\"turntable\"===t){var a=n();c._active.lookAt(a,r,i,e),c._active.lookAt(a+500,r,i,[0,0,1]),c._active.flush(a)}return c.getMode()},enumerable:!0},center:{get:function(){return c.computedCenter},set:function(t){return c.lookAt(c.lastT(),null,t),c.computedCenter},enumerable:!0},eye:{get:function(){return c.computedEye},set:function(t){return c.lookAt(c.lastT(),t),c.computedEye},enumerable:!0},up:{get:function(){return c.computedUp},set:function(t){return c.lookAt(c.lastT(),null,null,t),c.computedUp},enumerable:!0},distance:{get:function(){return h},set:function(t){return c.setDistance(c.lastT(),t),t},enumerable:!0},distanceLimits:{get:function(){return c.getDistanceLimits(r)},set:function(t){return c.setDistanceLimits(t),t},enumerable:!0}}),t.addEventListener(\"contextmenu\",function(t){return t.preventDefault(),!1}),d._lastX=-1,d._lastY=-1,d._lastMods={shift:!1,control:!1,alt:!1,meta:!1},d.enableMouseListeners=function(){function e(e,r,i,a){var o=d.keyBindingMode;if(!1!==o){var s=\"rotate\"===o,l=\"pan\"===o,u=\"zoom\"===o,f=!!a.control,p=!!a.alt,g=!!a.shift,v=!!(1&e),m=!!(2&e),y=!!(4&e),x=1/t.clientHeight,b=x*(r-d._lastX),_=x*(i-d._lastY),w=d.flipX?1:-1,k=d.flipY?1:-1,T=Math.PI*d.rotateSpeed,A=n();if(-1!==d._lastX&&-1!==d._lastY&&((s&&v&&!f&&!p&&!g||v&&!f&&!p&&g)&&c.rotate(A,w*T*b,-k*T*_,0),(l&&v&&!f&&!p&&!g||m||v&&f&&!p&&!g)&&c.pan(A,-d.translateSpeed*b*h,d.translateSpeed*_*h,0),u&&v&&!f&&!p&&!g||y||v&&!f&&p&&!g)){var M=-d.zoomSpeed*_/window.innerHeight*(A-c.lastT())*100;c.pan(A,0,0,h*(Math.exp(M)-1))}return d._lastX=r,d._lastY=i,d._lastMods=a,!0}}d.mouseListener=a(t,e),t.addEventListener(\"touchstart\",function(r){var n=s(r.changedTouches[0],t);e(0,n[0],n[1],d._lastMods),e(1,n[0],n[1],d._lastMods),r.preventDefault()},!!l&&{passive:!1}),t.addEventListener(\"touchmove\",function(r){var n=s(r.changedTouches[0],t);e(1,n[0],n[1],d._lastMods),r.preventDefault()},!!l&&{passive:!1}),t.addEventListener(\"touchend\",function(t){e(0,d._lastX,d._lastY,d._lastMods),t.preventDefault()},!!l&&{passive:!1}),d.wheelListener=o(t,function(t,e){if(!1!==d.keyBindingMode&&d.enableWheel){var r=d.flipX?1:-1,i=d.flipY?1:-1,a=n();if(Math.abs(t)>Math.abs(e))c.rotate(a,0,0,-t*r*Math.PI*d.rotateSpeed/window.innerWidth);else if(!d._ortho){var o=-d.zoomSpeed*i*e/window.innerHeight*(a-c.lastT())/20;c.pan(a,0,0,h*(Math.exp(o)-1))}}},!0)},d.enableMouseListeners(),d};var n=t(\"right-now\"),i=t(\"3d-view\"),a=t(\"mouse-change\"),o=t(\"mouse-wheel\"),s=t(\"mouse-event-offset\"),l=t(\"has-passive-events\")},{\"3d-view\":52,\"has-passive-events\":411,\"mouse-change\":435,\"mouse-event-offset\":436,\"mouse-wheel\":438,\"right-now\":504}],289:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\nattribute vec2 position;\\nvarying vec2 uv;\\nvoid main() {\\n  uv = position;\\n  gl_Position = vec4(position, 0, 1);\\n}\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D accumBuffer;\\nvarying vec2 uv;\\n\\nvoid main() {\\n  vec4 accum = texture2D(accumBuffer, 0.5 * (uv + 1.0));\\n  gl_FragColor = min(vec4(1,1,1,1), accum);\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec2\"}])}},{\"gl-shader\":301,glslify:409}],290:[function(t,e,r){\"use strict\";var n=t(\"./camera.js\"),i=t(\"gl-axes3d\"),a=t(\"gl-axes3d/properties\"),o=t(\"gl-spikes3d\"),s=t(\"gl-select-static\"),l=t(\"gl-fbo\"),c=t(\"a-big-triangle\"),u=t(\"mouse-change\"),h=t(\"mouse-wheel\"),f=t(\"gl-mat4/perspective\"),p=t(\"gl-mat4/ortho\"),d=t(\"./lib/shader\"),g=t(\"is-mobile\")({tablet:!0});function v(){this.mouse=[-1,-1],this.screen=null,this.distance=1/0,this.index=null,this.dataCoordinate=null,this.dataPosition=null,this.object=null,this.data=null}function m(t){var e=Math.round(Math.log(Math.abs(t))/Math.log(10));if(e<0){var r=Math.round(Math.pow(10,-e));return Math.ceil(t*r)/r}if(e>0){r=Math.round(Math.pow(10,e));return Math.ceil(t/r)*r}return Math.ceil(t)}function y(t){return\"boolean\"!=typeof t||t}e.exports={createScene:function(t){(t=t||{}).camera=t.camera||{};var e=t.canvas;if(!e)if(e=document.createElement(\"canvas\"),t.container){var r=t.container;r.appendChild(e)}else document.body.appendChild(e);var x=t.gl;x||(x=function(t,e){var r=null;try{(r=t.getContext(\"webgl\",e))||(r=t.getContext(\"experimental-webgl\",e))}catch(t){return null}return r}(e,t.glOptions||{premultipliedAlpha:!0,antialias:!0,preserveDrawingBuffer:g}));if(!x)throw new Error(\"webgl not supported\");var b=t.bounds||[[-10,-10,-10],[10,10,10]],_=new v,w=l(x,[x.drawingBufferWidth,x.drawingBufferHeight],{preferFloat:!g}),k=d(x),T=t.cameraObject&&!0===t.cameraObject._ortho||t.camera.projection&&\"orthographic\"===t.camera.projection.type||!1,A={eye:t.camera.eye||[2,0,0],center:t.camera.center||[0,0,0],up:t.camera.up||[0,1,0],zoomMin:t.camera.zoomMax||.1,zoomMax:t.camera.zoomMin||100,mode:t.camera.mode||\"turntable\",_ortho:T},M=t.axes||{},S=i(x,M);S.enable=!M.disable;var E=t.spikes||{},C=o(x,E),L=[],P=[],O=[],z=[],I=!0,D=!0,R=new Array(16),F=new Array(16),B={view:null,projection:R,model:F,_ortho:!1},D=!0,N=[x.drawingBufferWidth,x.drawingBufferHeight],j=t.cameraObject||n(e,A),U={gl:x,contextLost:!1,pixelRatio:t.pixelRatio||1,canvas:e,selection:_,camera:j,axes:S,axesPixels:null,spikes:C,bounds:b,objects:L,shape:N,aspect:t.aspectRatio||[1,1,1],pickRadius:t.pickRadius||10,zNear:t.zNear||.01,zFar:t.zFar||1e3,fovy:t.fovy||Math.PI/4,clearColor:t.clearColor||[0,0,0,0],autoResize:y(t.autoResize),autoBounds:y(t.autoBounds),autoScale:!!t.autoScale,autoCenter:y(t.autoCenter),clipToBounds:y(t.clipToBounds),snapToData:!!t.snapToData,onselect:t.onselect||null,onrender:t.onrender||null,onclick:t.onclick||null,cameraParams:B,oncontextloss:null,mouseListener:null,_stopped:!1},V=[x.drawingBufferWidth/U.pixelRatio|0,x.drawingBufferHeight/U.pixelRatio|0];function q(){if(!U._stopped&&U.autoResize){var t=e.parentNode,r=1,n=1;t&&t!==document.body?(r=t.clientWidth,n=t.clientHeight):(r=window.innerWidth,n=window.innerHeight);var i=0|Math.ceil(r*U.pixelRatio),a=0|Math.ceil(n*U.pixelRatio);if(i!==e.width||a!==e.height){e.width=i,e.height=a;var o=e.style;o.position=o.position||\"absolute\",o.left=\"0px\",o.top=\"0px\",o.width=r+\"px\",o.height=n+\"px\",I=!0}}}U.autoResize&&q();function H(){for(var t=L.length,e=z.length,r=0;r<e;++r)O[r]=0;t:for(var r=0;r<t;++r){var n=L[r],i=n.pickSlots;if(i){for(var a=0;a<e;++a)if(O[a]+i<255){P[r]=a,n.setPickBase(O[a]+1),O[a]+=i;continue t}var o=s(x,N);P[r]=e,z.push(o),O.push(i),n.setPickBase(1),e+=1}else P[r]=-1}for(;e>0&&0===O[e-1];)O.pop(),z.pop().dispose()}function G(){if(U.contextLost)return!0;x.isContextLost()&&(U.contextLost=!0,U.mouseListener.enabled=!1,U.selection.object=null,U.oncontextloss&&U.oncontextloss())}window.addEventListener(\"resize\",q),U.update=function(t){U._stopped||(t=t||{},I=!0,D=!0)},U.add=function(t){U._stopped||(t.axes=S,L.push(t),P.push(-1),I=!0,D=!0,H())},U.remove=function(t){if(!U._stopped){var e=L.indexOf(t);e<0||(L.splice(e,1),P.pop(),I=!0,D=!0,H())}},U.dispose=function(){if(!U._stopped&&(U._stopped=!0,window.removeEventListener(\"resize\",q),e.removeEventListener(\"webglcontextlost\",G),U.mouseListener.enabled=!1,!U.contextLost)){S.dispose(),C.dispose();for(var t=0;t<L.length;++t)L[t].dispose();w.dispose();for(var t=0;t<z.length;++t)z[t].dispose();k.dispose(),x=null,S=null,C=null,L=[]}},U.wheelListener=h(e,function(t,e){if(!1!==j.keyBindingMode&&j.enableWheel&&j._ortho){var r=t>e?1.1:1/1.1;U.aspect[0]*=r,U.aspect[1]*=r,U.aspect[2]*=r,U.redraw()}},!0),U._mouseRotating=!1,U._prevButtons=0,U.enableMouseListeners=function(){U.mouseListener=u(e,function(t,e,r){if(!U._stopped){var n=z.length,i=L.length,a=_.object;_.distance=1/0,_.mouse[0]=e,_.mouse[1]=r,_.object=null,_.screen=null,_.dataCoordinate=_.dataPosition=null;var o=!1;if(t&&U._prevButtons)U._mouseRotating=!0;else{U._mouseRotating&&(D=!0),U._mouseRotating=!1;for(var s=0;s<n;++s){var l=z[s].query(e,V[1]-r-1,U.pickRadius);if(l){if(l.distance>_.distance)continue;for(var c=0;c<i;++c){var u=L[c];if(P[c]===s){var h=u.pick(l);h&&(_.buttons=t,_.screen=l.coord,_.distance=l.distance,_.object=u,_.index=h.distance,_.dataPosition=h.position,_.dataCoordinate=h.dataCoordinate,_.data=h,o=!0)}}}}}a&&a!==_.object&&(a.highlight&&a.highlight(null),I=!0),_.object&&(_.object.highlight&&_.object.highlight(_.data),I=!0),(o=o||_.object!==a)&&U.onselect&&U.onselect(_),1&t&&!(1&U._prevButtons)&&U.onclick&&U.onclick(_),U._prevButtons=t}})},e.addEventListener(\"webglcontextlost\",G);var Y=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],W=[Y[0].slice(),Y[1].slice()];function X(){if(!G()){q();var t=U.camera.tick();B.view=U.camera.matrix,I=I||t,D=D||t,S.pixelRatio=U.pixelRatio,C.pixelRatio=U.pixelRatio;var e=L.length,r=Y[0],n=Y[1];r[0]=r[1]=r[2]=1/0,n[0]=n[1]=n[2]=-1/0;for(var i=0;i<e;++i){var o=L[i];o.pixelRatio=U.pixelRatio,o.axes=U.axes,I=I||!!o.dirty,D=D||!!o.dirty;var s=o.bounds;if(s)for(var l=s[0],u=s[1],h=0;h<3;++h)r[h]=Math.min(r[h],l[h]),n[h]=Math.max(n[h],u[h])}var d=U.bounds;if(U.autoBounds)for(var h=0;h<3;++h){if(n[h]<r[h])r[h]=-1,n[h]=1;else{r[h]===n[h]&&(r[h]-=1,n[h]+=1);var g=.05*(n[h]-r[h]);r[h]=r[h]-g,n[h]=n[h]+g}d[0][h]=r[h],d[1][h]=n[h]}for(var v=!1,h=0;h<3;++h)v=v||W[0][h]!==d[0][h]||W[1][h]!==d[1][h],W[0][h]=d[0][h],W[1][h]=d[1][h];if(D=D||v,I=I||v){if(v){for(var y=[0,0,0],i=0;i<3;++i)y[i]=m((d[1][i]-d[0][i])/10);S.autoTicks?S.update({bounds:d,tickSpacing:y}):S.update({bounds:d})}var b=x.drawingBufferWidth,A=x.drawingBufferHeight;N[0]=b,N[1]=A,V[0]=0|Math.max(b/U.pixelRatio,1),V[1]=0|Math.max(A/U.pixelRatio,1),T?(p(R,-b/A,b/A,-1,1,U.zNear,U.zFar),B._ortho=!0):(f(R,U.fovy,b/A,U.zNear,U.zFar),B._ortho=!1);for(var i=0;i<16;++i)F[i]=0;F[15]=1;for(var M=0,i=0;i<3;++i)M=Math.max(M,d[1][i]-d[0][i]);for(var i=0;i<3;++i)U.autoScale?F[5*i]=U.aspect[i]/(d[1][i]-d[0][i]):F[5*i]=1/M,U.autoCenter&&(F[12+i]=.5*-F[5*i]*(d[0][i]+d[1][i]));for(var i=0;i<e;++i){var o=L[i];o.axesBounds=d,U.clipToBounds&&(o.clipBounds=d)}_.object&&(U.snapToData?C.position=_.dataCoordinate:C.position=_.dataPosition,C.bounds=d),D&&(D=!1,function(){if(G())return;x.colorMask(!0,!0,!0,!0),x.depthMask(!0),x.disable(x.BLEND),x.enable(x.DEPTH_TEST);for(var t=L.length,e=z.length,r=0;r<e;++r){var n=z[r];n.shape=V,n.begin();for(var i=0;i<t;++i)if(P[i]===r){var a=L[i];a.drawPick&&(a.pixelRatio=1,a.drawPick(B))}n.end()}}()),U.axesPixels=a(U.axes,B,b,A),U.onrender&&U.onrender(),x.bindFramebuffer(x.FRAMEBUFFER,null),x.viewport(0,0,b,A);var E=U.clearColor;x.clearColor(E[0],E[1],E[2],E[3]),x.clear(x.COLOR_BUFFER_BIT|x.DEPTH_BUFFER_BIT),x.depthMask(!0),x.colorMask(!0,!0,!0,!0),x.enable(x.DEPTH_TEST),x.depthFunc(x.LEQUAL),x.disable(x.BLEND),x.disable(x.CULL_FACE);var O=!1;S.enable&&(O=O||S.isTransparent(),S.draw(B)),C.axes=S,_.object&&C.draw(B),x.disable(x.CULL_FACE);for(var i=0;i<e;++i){var o=L[i];o.axes=S,o.pixelRatio=U.pixelRatio,o.isOpaque&&o.isOpaque()&&o.draw(B),o.isTransparent&&o.isTransparent()&&(O=!0)}if(O){w.shape=N,w.bind(),x.clear(x.DEPTH_BUFFER_BIT),x.colorMask(!1,!1,!1,!1),x.depthMask(!0),x.depthFunc(x.LESS),S.enable&&S.isTransparent()&&S.drawTransparent(B);for(var i=0;i<e;++i){var o=L[i];o.isOpaque&&o.isOpaque()&&o.draw(B)}x.enable(x.BLEND),x.blendEquation(x.FUNC_ADD),x.blendFunc(x.ONE,x.ONE_MINUS_SRC_ALPHA),x.colorMask(!0,!0,!0,!0),x.depthMask(!1),x.clearColor(0,0,0,0),x.clear(x.COLOR_BUFFER_BIT),S.isTransparent()&&S.drawTransparent(B);for(var i=0;i<e;++i){var o=L[i];o.isTransparent&&o.isTransparent()&&o.drawTransparent(B)}x.bindFramebuffer(x.FRAMEBUFFER,null),x.blendFunc(x.ONE,x.ONE_MINUS_SRC_ALPHA),x.disable(x.DEPTH_TEST),k.bind(),w.color[0].bind(0),k.uniforms.accumBuffer=0,c(x),x.disable(x.BLEND)}I=!1;for(var i=0;i<e;++i)L[i].dirty=!1}}}return U.enableMouseListeners(),function t(){U._stopped||U.contextLost||(X(),requestAnimationFrame(t))}(),U.redraw=function(){U._stopped||(I=!0,X())},U},createCamera:n}},{\"./camera.js\":288,\"./lib/shader\":289,\"a-big-triangle\":59,\"gl-axes3d\":233,\"gl-axes3d/properties\":240,\"gl-fbo\":249,\"gl-mat4/ortho\":268,\"gl-mat4/perspective\":269,\"gl-select-static\":300,\"gl-spikes3d\":310,\"is-mobile\":420,\"mouse-change\":435,\"mouse-wheel\":438}],291:[function(t,e,r){var n=t(\"glslify\");r.pointVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform float pointCloud;\\n\\nhighp float rand(vec2 co) {\\n  highp float a = 12.9898;\\n  highp float b = 78.233;\\n  highp float c = 43758.5453;\\n  highp float d = dot(co.xy, vec2(a, b));\\n  highp float e = mod(d, 3.14);\\n  return fract(sin(e) * c);\\n}\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n    // if we don't jitter the point size a bit, overall point cloud\\n    // saturation 'jumps' on zooming, which is disturbing and confusing\\n  gl_PointSize = pointSize * ((19.5 + rand(position)) / 20.0);\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    // get the same square surface as circle would be\\n    gl_PointSize *= 0.886;\\n  }\\n}\"]),r.pointFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color, borderColor;\\nuniform float centerFraction;\\nuniform float pointCloud;\\n\\nvoid main() {\\n  float radius;\\n  vec4 baseColor;\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    if(centerFraction == 1.0) {\\n      gl_FragColor = color;\\n    } else {\\n      gl_FragColor = mix(borderColor, color, centerFraction);\\n    }\\n  } else {\\n    radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n    if(radius > 1.0) {\\n      discard;\\n    }\\n    baseColor = mix(borderColor, color, step(radius, centerFraction));\\n    gl_FragColor = vec4(baseColor.rgb * baseColor.a, baseColor.a);\\n  }\\n}\\n\"]),r.pickVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform vec4 pickOffset;\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n  gl_PointSize = pointSize;\\n\\n  vec4 id = pickId + pickOffset;\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  fragId = id;\\n}\\n\"]),r.pickFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  float radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n  if(radius > 1.0) {\\n    discard;\\n  }\\n  gl_FragColor = fragId / 255.0;\\n}\\n\"])},{glslify:409}],292:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"typedarray-pool\"),o=t(\"./lib/shader\");function s(t,e,r,n,i){this.plot=t,this.offsetBuffer=e,this.pickBuffer=r,this.shader=n,this.pickShader=i,this.sizeMin=.5,this.sizeMinCap=2,this.sizeMax=20,this.areaRatio=1,this.pointCount=0,this.color=[1,0,0,1],this.borderColor=[0,0,0,1],this.blend=!1,this.pickOffset=0,this.points=null}e.exports=function(t,e){var r=t.gl,a=i(r),l=i(r),c=n(r,o.pointVertex,o.pointFragment),u=n(r,o.pickVertex,o.pickFragment),h=new s(t,a,l,c,u);return h.update(e),t.addObject(h),h};var l,c,u=s.prototype;u.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.offsetBuffer.dispose(),this.pickBuffer.dispose(),this.plot.removeObject(this)},u.update=function(t){var e;function r(e,r){return e in t?t[e]:r}t=t||{},this.sizeMin=r(\"sizeMin\",.5),this.sizeMax=r(\"sizeMax\",20),this.color=r(\"color\",[1,0,0,1]).slice(),this.areaRatio=r(\"areaRatio\",1),this.borderColor=r(\"borderColor\",[0,0,0,1]).slice(),this.blend=r(\"blend\",!1);var n=t.positions.length>>>1,i=t.positions instanceof Float32Array,o=t.idToIndex instanceof Int32Array&&t.idToIndex.length>=n,s=t.positions,l=i?s:a.mallocFloat32(s.length),c=o?t.idToIndex:a.mallocInt32(n);if(i||l.set(s),!o)for(l.set(s),e=0;e<n;e++)c[e]=e;this.points=s,this.offsetBuffer.update(l),this.pickBuffer.update(c),i||a.free(l),o||a.free(c),this.pointCount=n,this.pickOffset=0},u.unifiedDraw=(l=[1,0,0,0,1,0,0,0,1],c=[0,0,0,0],function(t){var e=void 0!==t,r=e?this.pickShader:this.shader,n=this.plot.gl,i=this.plot.dataBox;if(0===this.pointCount)return t;var a=i[2]-i[0],o=i[3]-i[1],s=function(t,e){var r,n=0,i=t.length>>>1;for(r=0;r<i;r++){var a=t[2*r],o=t[2*r+1];a>=e[0]&&a<=e[2]&&o>=e[1]&&o<=e[3]&&n++}return n}(this.points,i),u=this.plot.pickPixelRatio*Math.max(Math.min(this.sizeMinCap,this.sizeMin),Math.min(this.sizeMax,this.sizeMax/Math.pow(s,.33333)));l[0]=2/a,l[4]=2/o,l[6]=-2*i[0]/a-1,l[7]=-2*i[1]/o-1,this.offsetBuffer.bind(),r.bind(),r.attributes.position.pointer(),r.uniforms.matrix=l,r.uniforms.color=this.color,r.uniforms.borderColor=this.borderColor,r.uniforms.pointCloud=u<5,r.uniforms.pointSize=u,r.uniforms.centerFraction=Math.min(1,Math.max(0,Math.sqrt(1-this.areaRatio))),e&&(c[0]=255&t,c[1]=t>>8&255,c[2]=t>>16&255,c[3]=t>>24&255,this.pickBuffer.bind(),r.attributes.pickId.pointer(n.UNSIGNED_BYTE),r.uniforms.pickOffset=c,this.pickOffset=t);var h=n.getParameter(n.BLEND),f=n.getParameter(n.DITHER);return h&&!this.blend&&n.disable(n.BLEND),f&&n.disable(n.DITHER),n.drawArrays(n.POINTS,0,this.pointCount),h&&!this.blend&&n.enable(n.BLEND),f&&n.enable(n.DITHER),t+this.pointCount}),u.draw=u.unifiedDraw,u.drawPick=u.unifiedDraw,u.pick=function(t,e,r){var n=this.pickOffset,i=this.pointCount;if(r<n||r>=n+i)return null;var a=r-n,o=this.points;return{object:this,pointId:a,dataCoord:[o[2*a],o[2*a+1]]}}},{\"./lib/shader\":291,\"gl-buffer\":241,\"gl-shader\":301,\"typedarray-pool\":545}],293:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c=e[0],u=e[1],h=e[2],f=e[3],p=r[0],d=r[1],g=r[2],v=r[3];(a=c*p+u*d+h*g+f*v)<0&&(a=-a,p=-p,d=-d,g=-g,v=-v);1-a>1e-6?(i=Math.acos(a),o=Math.sin(i),s=Math.sin((1-n)*i)/o,l=Math.sin(n*i)/o):(s=1-n,l=n);return t[0]=s*c+l*p,t[1]=s*u+l*d,t[2]=s*h+l*g,t[3]=s*f+l*v,t}},{}],294:[function(t,e,r){\"use strict\";e.exports=function(t){return t||0===t?t.toString():\"\"}},{}],295:[function(t,e,r){\"use strict\";var n=t(\"vectorize-text\");e.exports=function(t,e,r){var a=i[e];a||(a=i[e]={});if(t in a)return a[t];var o={textAlign:\"center\",textBaseline:\"middle\",lineHeight:1,font:e,lineSpacing:1.25,styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},triangles:!0},s=n(t,o);o.triangles=!1;var l,c,u=n(t,o);if(r&&1!==r){for(l=0;l<s.positions.length;++l)for(c=0;c<s.positions[l].length;++c)s.positions[l][c]/=r;for(l=0;l<u.positions.length;++l)for(c=0;c<u.positions[l].length;++c)u.positions[l][c]/=r}var h=[[1/0,1/0],[-1/0,-1/0]],f=u.positions.length;for(l=0;l<f;++l){var p=u.positions[l];for(c=0;c<2;++c)h[0][c]=Math.min(h[0][c],p[c]),h[1][c]=Math.max(h[1][c],p[c])}return a[t]=[s,u,h]};var i={}},{\"vectorize-text\":550}],296:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform vec4 highlightId;\\nuniform float highlightScale;\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = 1.0;\\n    if(distance(highlightId, id) < 0.0001) {\\n      scale = highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1);\\n    vec4 viewPosition = view * worldPosition;\\n    viewPosition = viewPosition / viewPosition.w;\\n    vec4 clipPosition = projection * (viewPosition + scale * vec4(glyph.x, -glyph.y, 0, 0));\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float highlightScale, pixelRatio;\\nuniform vec4 highlightId;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = pixelRatio;\\n    if(distance(highlightId.bgr, id.bgr) < 0.001) {\\n      scale *= highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1.0);\\n    vec4 viewPosition = view * worldPosition;\\n    vec4 clipPosition = projection * viewPosition;\\n    clipPosition /= clipPosition.w;\\n\\n    gl_Position = clipPosition + vec4(screenSize * scale * vec2(glyph.x, -glyph.y), 0.0, 0.0);\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform float highlightScale;\\nuniform vec4 highlightId;\\nuniform vec3 axes[2];\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float scale, pixelRatio;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float lscale = pixelRatio * scale;\\n    if(distance(highlightId, id) < 0.0001) {\\n      lscale *= highlightScale;\\n    }\\n\\n    vec4 clipCenter   = projection * view * model * vec4(position, 1);\\n    vec3 dataPosition = position + 0.5*lscale*(axes[0] * glyph.x + axes[1] * glyph.y) * clipCenter.w * screenSize.y;\\n    vec4 clipPosition = projection * view * model * vec4(dataPosition, 1);\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = dataPosition;\\n  }\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float opacity;\\n\\nvarying vec4 interpColor;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (\\n    outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate) ||\\n    interpColor.a * opacity == 0.\\n  ) discard;\\n  gl_FragColor = interpColor * opacity;\\n}\\n\"]),c=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float pickGroup;\\n\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate)) discard;\\n\\n  gl_FragColor = vec4(pickGroup, pickId.bgr);\\n}\"]),u=[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"glyph\",type:\"vec2\"},{name:\"id\",type:\"vec4\"}],h={vertex:a,fragment:l,attributes:u},f={vertex:o,fragment:l,attributes:u},p={vertex:s,fragment:l,attributes:u},d={vertex:a,fragment:c,attributes:u},g={vertex:o,fragment:c,attributes:u},v={vertex:s,fragment:c,attributes:u};function m(t,e){var r=n(t,e),i=r.attributes;return i.position.location=0,i.color.location=1,i.glyph.location=2,i.id.location=3,r}r.createPerspective=function(t){return m(t,h)},r.createOrtho=function(t){return m(t,f)},r.createProject=function(t){return m(t,p)},r.createPickPerspective=function(t){return m(t,d)},r.createPickOrtho=function(t){return m(t,g)},r.createPickProject=function(t){return m(t,v)}},{\"gl-shader\":301,glslify:409}],297:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"typedarray-pool\"),s=t(\"gl-mat4/multiply\"),l=t(\"./lib/shaders\"),c=t(\"./lib/glyphs\"),u=t(\"./lib/get-simple-string\"),h=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function f(t,e){var r=t[0],n=t[1],i=t[2],a=t[3];return t[0]=e[0]*r+e[4]*n+e[8]*i+e[12]*a,t[1]=e[1]*r+e[5]*n+e[9]*i+e[13]*a,t[2]=e[2]*r+e[6]*n+e[10]*i+e[14]*a,t[3]=e[3]*r+e[7]*n+e[11]*i+e[15]*a,t}function p(t,e,r,n){return f(n,n),f(n,n),f(n,n)}function d(t,e){this.index=t,this.dataCoordinate=this.position=e}function g(t){return!0===t?1:t>1?1:t}function v(t,e,r,n,i,a,o,s,l,c,u,h){this.gl=t,this.pixelRatio=1,this.shader=e,this.orthoShader=r,this.projectShader=n,this.pointBuffer=i,this.colorBuffer=a,this.glyphBuffer=o,this.idBuffer=s,this.vao=l,this.vertexCount=0,this.lineVertexCount=0,this.opacity=1,this.hasAlpha=!1,this.lineWidth=0,this.projectScale=[2/3,2/3,2/3],this.projectOpacity=[1,1,1],this.projectHasAlpha=!1,this.pickId=0,this.pickPerspectiveShader=c,this.pickOrthoShader=u,this.pickProjectShader=h,this.points=[],this._selectResult=new d(0,[0,0,0]),this.useOrtho=!0,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.axesProject=[!0,!0,!0],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.highlightId=[1,1,1,1],this.highlightScale=2,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.dirty=!0}e.exports=function(t){var e=t.gl,r=l.createPerspective(e),n=l.createOrtho(e),o=l.createProject(e),s=l.createPickPerspective(e),c=l.createPickOrtho(e),u=l.createPickProject(e),h=i(e),f=i(e),p=i(e),d=i(e),g=a(e,[{buffer:h,size:3,type:e.FLOAT},{buffer:f,size:4,type:e.FLOAT},{buffer:p,size:2,type:e.FLOAT},{buffer:d,size:4,type:e.UNSIGNED_BYTE,normalized:!0}]),m=new v(e,r,n,o,h,f,p,d,g,s,c,u);return m.update(t),m};var m=v.prototype;m.pickSlots=1,m.setPickBase=function(t){this.pickId=t},m.isTransparent=function(){if(this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&this.projectHasAlpha)return!0;return!1},m.isOpaque=function(){if(!this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&!this.projectHasAlpha)return!0;return!1};var y=[0,0],x=[0,0,0],b=[0,0,0],_=[0,0,0,1],w=[0,0,0,1],k=h.slice(),T=[0,0,0],A=[[0,0,0],[0,0,0]];function M(t){return t[0]=t[1]=t[2]=0,t}function S(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=1,t}function E(t,e,r,n){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[r]=n,t}function C(t,e,r,n){var i,a=e.axesProject,o=e.gl,l=t.uniforms,c=r.model||h,u=r.view||h,f=r.projection||h,d=e.axesBounds,g=function(t){for(var e=A,r=0;r<2;++r)for(var n=0;n<3;++n)e[r][n]=Math.max(Math.min(t[r][n],1e8),-1e8);return e}(e.clipBounds);i=e.axes&&e.axes.lastCubeProps?e.axes.lastCubeProps.axis:[1,1,1],y[0]=2/o.drawingBufferWidth,y[1]=2/o.drawingBufferHeight,t.bind(),l.view=u,l.projection=f,l.screenSize=y,l.highlightId=e.highlightId,l.highlightScale=e.highlightScale,l.clipBounds=g,l.pickGroup=e.pickId/255,l.pixelRatio=n;for(var v=0;v<3;++v)if(a[v]){l.scale=e.projectScale[v],l.opacity=e.projectOpacity[v];for(var m=k,C=0;C<16;++C)m[C]=0;for(C=0;C<4;++C)m[5*C]=1;m[5*v]=0,i[v]<0?m[12+v]=d[0][v]:m[12+v]=d[1][v],s(m,c,m),l.model=m;var L=(v+1)%3,P=(v+2)%3,O=M(x),z=M(b);O[L]=1,z[P]=1;var I=p(0,0,0,S(_,O)),D=p(0,0,0,S(w,z));if(Math.abs(I[1])>Math.abs(D[1])){var R=I;I=D,D=R,R=O,O=z,z=R;var F=L;L=P,P=F}I[0]<0&&(O[L]=-1),D[1]>0&&(z[P]=-1);var B=0,N=0;for(C=0;C<4;++C)B+=Math.pow(c[4*L+C],2),N+=Math.pow(c[4*P+C],2);O[L]/=Math.sqrt(B),z[P]/=Math.sqrt(N),l.axes[0]=O,l.axes[1]=z,l.fragClipBounds[0]=E(T,g[0],v,-1e8),l.fragClipBounds[1]=E(T,g[1],v,1e8),e.vao.bind(),e.vao.draw(o.TRIANGLES,e.vertexCount),e.lineWidth>0&&(o.lineWidth(e.lineWidth*n),e.vao.draw(o.LINES,e.lineVertexCount,e.vertexCount)),e.vao.unbind()}}var L=[[-1e8,-1e8,-1e8],[1e8,1e8,1e8]];function P(t,e,r,n,i,a,o){var s=r.gl;if((a===r.projectHasAlpha||o)&&C(e,r,n,i),a===r.hasAlpha||o){t.bind();var l=t.uniforms;l.model=n.model||h,l.view=n.view||h,l.projection=n.projection||h,y[0]=2/s.drawingBufferWidth,y[1]=2/s.drawingBufferHeight,l.screenSize=y,l.highlightId=r.highlightId,l.highlightScale=r.highlightScale,l.fragClipBounds=L,l.clipBounds=r.axes.bounds,l.opacity=r.opacity,l.pickGroup=r.pickId/255,l.pixelRatio=i,r.vao.bind(),r.vao.draw(s.TRIANGLES,r.vertexCount),r.lineWidth>0&&(s.lineWidth(r.lineWidth*i),r.vao.draw(s.LINES,r.lineVertexCount,r.vertexCount)),r.vao.unbind()}}function O(t,e,r,i){var a;a=Array.isArray(t)?e<t.length?t[e]:void 0:t,a=u(a);var o=!0;n(a)&&(a=\"\\u25bc\",o=!1);var s=c(a,r,i);return{mesh:s[0],lines:s[1],bounds:s[2],visible:o}}m.draw=function(t){P(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!1,!1)},m.drawTransparent=function(t){P(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!0,!1)},m.drawPick=function(t){P(this.useOrtho?this.pickOrthoShader:this.pickPerspectiveShader,this.pickProjectShader,this,t,1,!0,!0)},m.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[2]+(t.value[1]<<8)+(t.value[0]<<16);if(e>=this.pointCount||e<0)return null;var r=this.points[e],n=this._selectResult;n.index=e;for(var i=0;i<3;++i)n.position[i]=n.dataCoordinate[i]=r[i];return n},m.highlight=function(t){if(t){var e=t.index,r=255&e,n=e>>8&255,i=e>>16&255;this.highlightId=[r/255,n/255,i/255,0]}else this.highlightId=[1,1,1,1]},m.update=function(t){if(\"perspective\"in(t=t||{})&&(this.useOrtho=!t.perspective),\"orthographic\"in t&&(this.useOrtho=!!t.orthographic),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"project\"in t)if(Array.isArray(t.project))this.axesProject=t.project;else{var e=!!t.project;this.axesProject=[e,e,e]}if(\"projectScale\"in t)if(Array.isArray(t.projectScale))this.projectScale=t.projectScale.slice();else{var r=+t.projectScale;this.projectScale=[r,r,r]}if(this.projectHasAlpha=!1,\"projectOpacity\"in t){if(Array.isArray(t.projectOpacity))this.projectOpacity=t.projectOpacity.slice();else{r=+t.projectOpacity;this.projectOpacity=[r,r,r]}for(var n=0;n<3;++n)this.projectOpacity[n]=g(this.projectOpacity[n]),this.projectOpacity[n]<1&&(this.projectHasAlpha=!0)}this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=g(t.opacity),this.opacity<1&&(this.hasAlpha=!0)),this.dirty=!0;var i,a,s=t.position,l=t.font||\"normal\",c=t.alignment||[0,0];if(2===c.length)i=c[0],a=c[1];else{i=[],a=[];for(n=0;n<c.length;++n)i[n]=c[n][0],a[n]=c[n][1]}var u=[1/0,1/0,1/0],h=[-1/0,-1/0,-1/0],f=t.glyph,p=t.color,d=t.size,v=t.angle,m=t.lineColor,y=-1,x=0,b=0,_=0;if(s.length){_=s.length;t:for(n=0;n<_;++n){for(var w=s[n],k=0;k<3;++k)if(isNaN(w[k])||!isFinite(w[k]))continue t;var T=(N=O(f,n,l,this.pixelRatio)).mesh,A=N.lines,M=N.bounds;x+=3*T.cells.length,b+=2*A.edges.length}}var S=x+b,E=o.mallocFloat(3*S),C=o.mallocFloat(4*S),L=o.mallocFloat(2*S),P=o.mallocUint32(S);if(S>0){var z=0,I=x,D=[0,0,0,1],R=[0,0,0,1],F=Array.isArray(p)&&Array.isArray(p[0]),B=Array.isArray(m)&&Array.isArray(m[0]);t:for(n=0;n<_;++n){y+=1;for(w=s[n],k=0;k<3;++k){if(isNaN(w[k])||!isFinite(w[k]))continue t;h[k]=Math.max(h[k],w[k]),u[k]=Math.min(u[k],w[k])}T=(N=O(f,n,l,this.pixelRatio)).mesh,A=N.lines,M=N.bounds;var N,j=N.visible;if(j)if(Array.isArray(p)){if(3===(U=F?n<p.length?p[n]:[0,0,0,0]:p).length){for(k=0;k<3;++k)D[k]=U[k];D[3]=1}else if(4===U.length){for(k=0;k<4;++k)D[k]=U[k];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else D[0]=D[1]=D[2]=0,D[3]=1;else D=[1,1,1,0];if(j)if(Array.isArray(m)){var U;if(3===(U=B?n<m.length?m[n]:[0,0,0,0]:m).length){for(k=0;k<3;++k)R[k]=U[k];R[k]=1}else if(4===U.length){for(k=0;k<4;++k)R[k]=U[k];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else R[0]=R[1]=R[2]=0,R[3]=1;else R=[1,1,1,0];var V=.5;j?Array.isArray(d)?V=n<d.length?+d[n]:12:d?V=+d:this.useOrtho&&(V=12):V=0;var q=0;Array.isArray(v)?q=n<v.length?+v[n]:0:v&&(q=+v);var H=Math.cos(q),G=Math.sin(q);for(w=s[n],k=0;k<3;++k)h[k]=Math.max(h[k],w[k]),u[k]=Math.min(u[k],w[k]);var Y=i,W=a;Y=0;Array.isArray(i)?Y=n<i.length?i[n]:0:i&&(Y=i);W=0;Array.isArray(a)?W=n<a.length?a[n]:0:a&&(W=a);var X=[Y*=Y>0?1-M[0][0]:Y<0?1+M[1][0]:1,W*=W>0?1-M[0][1]:W<0?1+M[1][1]:1],Z=T.cells||[],J=T.positions||[];for(k=0;k<Z.length;++k)for(var K=Z[k],$=0;$<3;++$){for(var Q=0;Q<3;++Q)E[3*z+Q]=w[Q];for(Q=0;Q<4;++Q)C[4*z+Q]=D[Q];P[z]=y;var tt=J[K[$]];L[2*z]=V*(H*tt[0]-G*tt[1]+X[0]),L[2*z+1]=V*(G*tt[0]+H*tt[1]+X[1]),z+=1}for(Z=A.edges,J=A.positions,k=0;k<Z.length;++k)for(K=Z[k],$=0;$<2;++$){for(Q=0;Q<3;++Q)E[3*I+Q]=w[Q];for(Q=0;Q<4;++Q)C[4*I+Q]=R[Q];P[I]=y;tt=J[K[$]];L[2*I]=V*(H*tt[0]-G*tt[1]+X[0]),L[2*I+1]=V*(G*tt[0]+H*tt[1]+X[1]),I+=1}}}this.bounds=[u,h],this.points=s,this.pointCount=s.length,this.vertexCount=x,this.lineVertexCount=b,this.pointBuffer.update(E),this.colorBuffer.update(C),this.glyphBuffer.update(L),this.idBuffer.update(P),o.free(E),o.free(C),o.free(L),o.free(P)},m.dispose=function(){this.shader.dispose(),this.orthoShader.dispose(),this.pickPerspectiveShader.dispose(),this.pickOrthoShader.dispose(),this.vao.dispose(),this.pointBuffer.dispose(),this.colorBuffer.dispose(),this.glyphBuffer.dispose(),this.idBuffer.dispose()}},{\"./lib/get-simple-string\":294,\"./lib/glyphs\":295,\"./lib/shaders\":296,\"gl-buffer\":241,\"gl-mat4/multiply\":267,\"gl-vao\":327,\"is-string-blank\":423,\"typedarray-pool\":545}],298:[function(t,e,r){\"use strict\";var n=t(\"glslify\");r.boxVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 vertex;\\n\\nuniform vec2 cornerA, cornerB;\\n\\nvoid main() {\\n  gl_Position = vec4(mix(cornerA, cornerB, vertex), 0, 1);\\n}\\n\"]),r.boxFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\n\\nvoid main() {\\n  gl_FragColor = color;\\n}\\n\"])},{glslify:409}],299:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"./lib/shaders\");function o(t,e,r){this.plot=t,this.boxBuffer=e,this.boxShader=r,this.enabled=!0,this.selectBox=[1/0,1/0,-1/0,-1/0],this.borderColor=[0,0,0,1],this.innerFill=!1,this.innerColor=[0,0,0,.25],this.outerFill=!0,this.outerColor=[0,0,0,.5],this.borderWidth=10}e.exports=function(t,e){var r=t.gl,s=i(r,[0,0,0,1,1,0,1,1]),l=n(r,a.boxVertex,a.boxFragment),c=new o(t,s,l);return c.update(e),t.addOverlay(c),c};var s=o.prototype;s.draw=function(){if(this.enabled){var t=this.plot,e=this.selectBox,r=this.borderWidth,n=(this.innerFill,this.innerColor),i=(this.outerFill,this.outerColor),a=this.borderColor,o=t.box,s=t.screenBox,l=t.dataBox,c=t.viewBox,u=t.pixelRatio,h=(e[0]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],f=(e[1]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1],p=(e[2]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],d=(e[3]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1];if(h=Math.max(h,c[0]),f=Math.max(f,c[1]),p=Math.min(p,c[2]),d=Math.min(d,c[3]),!(p<h||d<f)){o.bind();var g=s[2]-s[0],v=s[3]-s[1];if(this.outerFill&&(o.drawBox(0,0,g,f,i),o.drawBox(0,f,h,d,i),o.drawBox(0,d,g,v,i),o.drawBox(p,f,g,d,i)),this.innerFill&&o.drawBox(h,f,p,d,n),r>0){var m=r*u;o.drawBox(h-m,f-m,p+m,f+m,a),o.drawBox(h-m,d-m,p+m,d+m,a),o.drawBox(h-m,f-m,h+m,d+m,a),o.drawBox(p-m,f-m,p+m,d+m,a)}}}},s.update=function(t){t=t||{},this.innerFill=!!t.innerFill,this.outerFill=!!t.outerFill,this.innerColor=(t.innerColor||[0,0,0,.5]).slice(),this.outerColor=(t.outerColor||[0,0,0,.5]).slice(),this.borderColor=(t.borderColor||[0,0,0,1]).slice(),this.borderWidth=t.borderWidth||0,this.selectBox=(t.selectBox||this.selectBox).slice()},s.dispose=function(){this.boxBuffer.dispose(),this.boxShader.dispose(),this.plot.removeOverlay(this)}},{\"./lib/shaders\":298,\"gl-buffer\":241,\"gl-shader\":301}],300:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=n(t,e),a=i.mallocUint8(e[0]*e[1]*4);return new c(t,r,a)};var n=t(\"gl-fbo\"),i=t(\"typedarray-pool\"),a=t(\"ndarray\"),o=t(\"bit-twiddle\").nextPow2,s=t(\"cwise/lib/wrapper\")({args:[\"array\",{offset:[0,0,1],array:0},{offset:[0,0,2],array:0},{offset:[0,0,3],array:0},\"scalar\",\"scalar\",\"index\"],pre:{body:\"{this_closestD2=1e8,this_closestX=-1,this_closestY=-1}\",args:[],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[]},body:{body:\"{if(_inline_16_arg0_<255||_inline_16_arg1_<255||_inline_16_arg2_<255||_inline_16_arg3_<255){var _inline_16_l=_inline_16_arg4_-_inline_16_arg6_[0],_inline_16_a=_inline_16_arg5_-_inline_16_arg6_[1],_inline_16_f=_inline_16_l*_inline_16_l+_inline_16_a*_inline_16_a;_inline_16_f<this_closestD2&&(this_closestD2=_inline_16_f,this_closestX=_inline_16_arg6_[0],this_closestY=_inline_16_arg6_[1])}}\",args:[{name:\"_inline_16_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg4_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg5_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg6_\",lvalue:!1,rvalue:!0,count:4}],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[\"_inline_16_a\",\"_inline_16_f\",\"_inline_16_l\"]},post:{body:\"{return[this_closestX,this_closestY,this_closestD2]}\",args:[],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[]},debug:!1,funcName:\"cwise\",blockSize:64});function l(t,e,r,n,i){this.coord=[t,e],this.id=r,this.value=n,this.distance=i}function c(t,e,r){this.gl=t,this.fbo=e,this.buffer=r,this._readTimeout=null;var n=this;this._readCallback=function(){n.gl&&(e.bind(),t.readPixels(0,0,e.shape[0],e.shape[1],t.RGBA,t.UNSIGNED_BYTE,n.buffer),n._readTimeout=null)}}var u=c.prototype;Object.defineProperty(u,\"shape\",{get:function(){return this.gl?this.fbo.shape.slice():[0,0]},set:function(t){if(this.gl){this.fbo.shape=t;var e=this.fbo.shape[0],r=this.fbo.shape[1];if(r*e*4>this.buffer.length){i.free(this.buffer);for(var n=this.buffer=i.mallocUint8(o(r*e*4)),a=0;a<r*e*4;++a)n[a]=255}return t}}}),u.begin=function(){var t=this.gl;this.shape;t&&(this.fbo.bind(),t.clearColor(1,1,1,1),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT))},u.end=function(){var t=this.gl;t&&(t.bindFramebuffer(t.FRAMEBUFFER,null),this._readTimeout||clearTimeout(this._readTimeout),this._readTimeout=setTimeout(this._readCallback,1))},u.query=function(t,e,r){if(!this.gl)return null;var n=this.fbo.shape.slice();t|=0,e|=0,\"number\"!=typeof r&&(r=1);var i=0|Math.min(Math.max(t-r,0),n[0]),o=0|Math.min(Math.max(t+r,0),n[0]),c=0|Math.min(Math.max(e-r,0),n[1]),u=0|Math.min(Math.max(e+r,0),n[1]);if(o<=i||u<=c)return null;var h=[o-i,u-c],f=a(this.buffer,[h[0],h[1],4],[4,4*n[0],1],4*(i+n[0]*c)),p=s(f.hi(h[0],h[1],1),r,r),d=p[0],g=p[1];return d<0||Math.pow(this.radius,2)<p[2]?null:new l(d+i|0,g+c|0,f.get(d,g,0),[f.get(d,g,1),f.get(d,g,2),f.get(d,g,3)],Math.sqrt(p[2]))},u.dispose=function(){this.gl&&(this.fbo.dispose(),i.free(this.buffer),this.gl=null,this._readTimeout&&clearTimeout(this._readTimeout))}},{\"bit-twiddle\":92,\"cwise/lib/wrapper\":149,\"gl-fbo\":249,ndarray:450,\"typedarray-pool\":545}],301:[function(t,e,r){\"use strict\";var n=t(\"./lib/create-uniforms\"),i=t(\"./lib/create-attributes\"),a=t(\"./lib/reflect\"),o=t(\"./lib/shader-cache\"),s=t(\"./lib/runtime-reflect\"),l=t(\"./lib/GLError\");function c(t){this.gl=t,this.gl.lastAttribCount=0,this._vref=this._fref=this._relink=this.vertShader=this.fragShader=this.program=this.attributes=this.uniforms=this.types=null}var u=c.prototype;function h(t,e){return t.name<e.name?-1:1}u.bind=function(){var t;this.program||this._relink();var e=this.gl.getProgramParameter(this.program,this.gl.ACTIVE_ATTRIBUTES),r=this.gl.lastAttribCount;if(e>r)for(t=r;t<e;t++)this.gl.enableVertexAttribArray(t);else if(r>e)for(t=e;t<r;t++)this.gl.disableVertexAttribArray(t);this.gl.lastAttribCount=e,this.gl.useProgram(this.program)},u.dispose=function(){for(var t=this.gl.lastAttribCount,e=0;e<t;e++)this.gl.disableVertexAttribArray(e);this.gl.lastAttribCount=0,this._fref&&this._fref.dispose(),this._vref&&this._vref.dispose(),this.attributes=this.types=this.vertShader=this.fragShader=this.program=this._relink=this._fref=this._vref=null},u.update=function(t,e,r,c){if(!e||1===arguments.length){var u=t;t=u.vertex,e=u.fragment,r=u.uniforms,c=u.attributes}var f=this,p=f.gl,d=f._vref;f._vref=o.shader(p,p.VERTEX_SHADER,t),d&&d.dispose(),f.vertShader=f._vref.shader;var g=this._fref;if(f._fref=o.shader(p,p.FRAGMENT_SHADER,e),g&&g.dispose(),f.fragShader=f._fref.shader,!r||!c){var v=p.createProgram();if(p.attachShader(v,f.fragShader),p.attachShader(v,f.vertShader),p.linkProgram(v),!p.getProgramParameter(v,p.LINK_STATUS)){var m=p.getProgramInfoLog(v);throw new l(m,\"Error linking program:\"+m)}r=r||s.uniforms(p,v),c=c||s.attributes(p,v),p.deleteProgram(v)}(c=c.slice()).sort(h);var y,x=[],b=[],_=[];for(y=0;y<c.length;++y){var w=c[y];if(w.type.indexOf(\"mat\")>=0){for(var k=0|w.type.charAt(w.type.length-1),T=new Array(k),A=0;A<k;++A)T[A]=_.length,b.push(w.name+\"[\"+A+\"]\"),\"number\"==typeof w.location?_.push(w.location+A):Array.isArray(w.location)&&w.location.length===k&&\"number\"==typeof w.location[A]?_.push(0|w.location[A]):_.push(-1);x.push({name:w.name,type:w.type,locations:T})}else x.push({name:w.name,type:w.type,locations:[_.length]}),b.push(w.name),\"number\"==typeof w.location?_.push(0|w.location):_.push(-1)}var M=0;for(y=0;y<_.length;++y)if(_[y]<0){for(;_.indexOf(M)>=0;)M+=1;_[y]=M}var S=new Array(r.length);function E(){f.program=o.program(p,f._vref,f._fref,b,_);for(var t=0;t<r.length;++t)S[t]=p.getUniformLocation(f.program,r[t].name)}E(),f._relink=E,f.types={uniforms:a(r),attributes:a(c)},f.attributes=i(p,f,x,_),Object.defineProperty(f,\"uniforms\",n(p,f,r,S))},e.exports=function(t,e,r,n,i){var a=new c(t);return a.update(e,r,n,i),a}},{\"./lib/GLError\":302,\"./lib/create-attributes\":303,\"./lib/create-uniforms\":304,\"./lib/reflect\":305,\"./lib/runtime-reflect\":306,\"./lib/shader-cache\":307}],302:[function(t,e,r){function n(t,e,r){this.shortMessage=e||\"\",this.longMessage=r||\"\",this.rawError=t||\"\",this.message=\"gl-shader: \"+(e||t||\"\")+(r?\"\\n\"+r:\"\"),this.stack=(new Error).stack}n.prototype=new Error,n.prototype.name=\"GLError\",n.prototype.constructor=n,e.exports=n},{}],303:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){for(var a={},l=0,c=r.length;l<c;++l){var u=r[l],h=u.name,f=u.type,p=u.locations;switch(f){case\"bool\":case\"int\":case\"float\":o(t,e,p[0],i,1,a,h);break;default:if(f.indexOf(\"vec\")>=0){var d=f.charCodeAt(f.length-1)-48;if(d<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+h+\": \"+f);o(t,e,p[0],i,d,a,h)}else{if(!(f.indexOf(\"mat\")>=0))throw new n(\"\",\"Unknown data type for attribute \"+h+\": \"+f);var d=f.charCodeAt(f.length-1)-48;if(d<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+h+\": \"+f);s(t,e,p,i,d,a,h)}}}return a};var n=t(\"./GLError\");function i(t,e,r,n,i,a){this._gl=t,this._wrapper=e,this._index=r,this._locations=n,this._dimension=i,this._constFunc=a}var a=i.prototype;function o(t,e,r,n,a,o,s){for(var l=[\"gl\",\"v\"],c=[],u=0;u<a;++u)l.push(\"x\"+u),c.push(\"x\"+u);l.push(\"if(x0.length===void 0){return gl.vertexAttrib\"+a+\"f(v,\"+c.join()+\")}else{return gl.vertexAttrib\"+a+\"fv(v,x0)}\");var h=Function.apply(null,l),f=new i(t,e,r,n,a,h);Object.defineProperty(o,s,{set:function(e){return t.disableVertexAttribArray(n[r]),h(t,n[r],e),e},get:function(){return f},enumerable:!0})}function s(t,e,r,n,i,a,s){for(var l=new Array(i),c=new Array(i),u=0;u<i;++u)o(t,e,r[u],n,i,l,u),c[u]=l[u];Object.defineProperty(l,\"location\",{set:function(t){if(Array.isArray(t))for(var e=0;e<i;++e)c[e].location=t[e];else for(e=0;e<i;++e)c[e].location=t+e;return t},get:function(){for(var t=new Array(i),e=0;e<i;++e)t[e]=n[r[e]];return t},enumerable:!0}),l.pointer=function(e,a,o,s){e=e||t.FLOAT,a=!!a,o=o||i*i,s=s||0;for(var l=0;l<i;++l){var c=n[r[l]];t.vertexAttribPointer(c,i,e,a,o,s+l*i),t.enableVertexAttribArray(c)}};var h=new Array(i),f=t[\"vertexAttrib\"+i+\"fv\"];Object.defineProperty(a,s,{set:function(e){for(var a=0;a<i;++a){var o=n[r[a]];if(t.disableVertexAttribArray(o),Array.isArray(e[0]))f.call(t,o,e[a]);else{for(var s=0;s<i;++s)h[s]=e[i*a+s];f.call(t,o,h)}}return e},get:function(){return l},enumerable:!0})}a.pointer=function(t,e,r,n){var i=this._gl,a=this._locations[this._index];i.vertexAttribPointer(a,this._dimension,t||i.FLOAT,!!e,r||0,n||0),i.enableVertexAttribArray(a)},a.set=function(t,e,r,n){return this._constFunc(this._locations[this._index],t,e,r,n)},Object.defineProperty(a,\"location\",{get:function(){return this._locations[this._index]},set:function(t){return t!==this._locations[this._index]&&(this._locations[this._index]=0|t,this._wrapper.program=null),0|t}})},{\"./GLError\":302}],304:[function(t,e,r){\"use strict\";var n=t(\"./reflect\"),i=t(\"./GLError\");function a(t){return new Function(\"y\",\"return function(){return y}\")(t)}function o(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}e.exports=function(t,e,r,s){function l(t,e,r){switch(r){case\"bool\":case\"int\":case\"sampler2D\":case\"samplerCube\":return\"gl.uniform1i(locations[\"+e+\"],obj\"+t+\")\";case\"float\":return\"gl.uniform1f(locations[\"+e+\"],obj\"+t+\")\";default:var n=r.indexOf(\"vec\");if(!(0<=n&&n<=1&&r.length===4+n)){if(0===r.indexOf(\"mat\")&&4===r.length){var a=r.charCodeAt(r.length-1)-48;if(a<2||a>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+r);return\"gl.uniformMatrix\"+a+\"fv(locations[\"+e+\"],false,obj\"+t+\")\"}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+r)}var a=r.charCodeAt(r.length-1)-48;if(a<2||a>4)throw new i(\"\",\"Invalid data type\");switch(r.charAt(0)){case\"b\":case\"i\":return\"gl.uniform\"+a+\"iv(locations[\"+e+\"],obj\"+t+\")\";case\"v\":return\"gl.uniform\"+a+\"fv(locations[\"+e+\"],obj\"+t+\")\";default:throw new i(\"\",\"Unrecognized data type for vector \"+name+\": \"+r)}}}function c(e){for(var n=[\"return function updateProperty(obj){\"],i=function t(e,r){if(\"object\"!=typeof r)return[[e,r]];var n=[];for(var i in r){var a=r[i],o=e;parseInt(i)+\"\"===i?o+=\"[\"+i+\"]\":o+=\".\"+i,\"object\"==typeof a?n.push.apply(n,t(o,a)):n.push([o,a])}return n}(\"\",e),a=0;a<i.length;++a){var o=i[a],c=o[0],u=o[1];s[u]&&n.push(l(c,u,r[u].type))}n.push(\"return obj}\");var h=new Function(\"gl\",\"locations\",n.join(\"\\n\"));return h(t,s)}function u(n,l,u){if(\"object\"==typeof u){var f=h(u);Object.defineProperty(n,l,{get:a(f),set:c(u),enumerable:!0,configurable:!1})}else s[u]?Object.defineProperty(n,l,{get:(p=u,new Function(\"gl\",\"wrapper\",\"locations\",\"return function(){return gl.getUniform(wrapper.program,locations[\"+p+\"])}\")(t,e,s)),set:c(u),enumerable:!0,configurable:!1}):n[l]=function(t){switch(t){case\"bool\":return!1;case\"int\":case\"sampler2D\":case\"samplerCube\":case\"float\":return 0;default:var e=t.indexOf(\"vec\");if(0<=e&&e<=1&&t.length===4+e){var r=t.charCodeAt(t.length-1)-48;if(r<2||r>4)throw new i(\"\",\"Invalid data type\");return\"b\"===t.charAt(0)?o(r,!1):o(r,0)}if(0===t.indexOf(\"mat\")&&4===t.length){var r=t.charCodeAt(t.length-1)-48;if(r<2||r>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+t);return o(r*r,0)}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+t)}}(r[u].type);var p}function h(t){var e;if(Array.isArray(t)){e=new Array(t.length);for(var r=0;r<t.length;++r)u(e,r,t[r])}else for(var n in e={},t)u(e,n,t[n]);return e}var f=n(r,!0);return{get:a(h(f)),set:c(f),enumerable:!0,configurable:!0}}},{\"./GLError\":302,\"./reflect\":305}],305:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r={},n=0;n<t.length;++n)for(var i=t[n].name,a=i.split(\".\"),o=r,s=0;s<a.length;++s){var l=a[s].split(\"[\");if(l.length>1){l[0]in o||(o[l[0]]=[]),o=o[l[0]];for(var c=1;c<l.length;++c){var u=parseInt(l[c]);c<l.length-1||s<a.length-1?(u in o||(c<l.length-1?o[u]=[]:o[u]={}),o=o[u]):o[u]=e?n:t[n].type}}else s<a.length-1?(l[0]in o||(o[l[0]]={}),o=o[l[0]]):o[l[0]]=e?n:t[n].type}return r}},{}],306:[function(t,e,r){\"use strict\";r.uniforms=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_UNIFORMS),n=[],i=0;i<r;++i){var o=t.getActiveUniform(e,i);if(o){var s=a(t,o.type);if(o.size>1)for(var l=0;l<o.size;++l)n.push({name:o.name.replace(\"[0]\",\"[\"+l+\"]\"),type:s});else n.push({name:o.name,type:s})}}return n},r.attributes=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_ATTRIBUTES),n=[],i=0;i<r;++i){var o=t.getActiveAttrib(e,i);o&&n.push({name:o.name,type:a(t,o.type)})}return n};var n={FLOAT:\"float\",FLOAT_VEC2:\"vec2\",FLOAT_VEC3:\"vec3\",FLOAT_VEC4:\"vec4\",INT:\"int\",INT_VEC2:\"ivec2\",INT_VEC3:\"ivec3\",INT_VEC4:\"ivec4\",BOOL:\"bool\",BOOL_VEC2:\"bvec2\",BOOL_VEC3:\"bvec3\",BOOL_VEC4:\"bvec4\",FLOAT_MAT2:\"mat2\",FLOAT_MAT3:\"mat3\",FLOAT_MAT4:\"mat4\",SAMPLER_2D:\"sampler2D\",SAMPLER_CUBE:\"samplerCube\"},i=null;function a(t,e){if(!i){var r=Object.keys(n);i={};for(var a=0;a<r.length;++a){var o=r[a];i[t[o]]=n[o]}}return i[e]}},{}],307:[function(t,e,r){\"use strict\";r.shader=function(t,e,r){return u(t).getShaderReference(e,r)},r.program=function(t,e,r,n,i){return u(t).getProgram(e,r,n,i)};var n=t(\"./GLError\"),i=t(\"gl-format-compiler-error\"),a=new(\"undefined\"==typeof WeakMap?t(\"weakmap-shim\"):WeakMap),o=0;function s(t,e,r,n,i,a,o){this.id=t,this.src=e,this.type=r,this.shader=n,this.count=a,this.programs=[],this.cache=o}function l(t){this.gl=t,this.shaders=[{},{}],this.programs={}}s.prototype.dispose=function(){if(0==--this.count){for(var t=this.cache,e=t.gl,r=this.programs,n=0,i=r.length;n<i;++n){var a=t.programs[r[n]];a&&(delete t.programs[n],e.deleteProgram(a))}e.deleteShader(this.shader),delete t.shaders[this.type===e.FRAGMENT_SHADER|0][this.src]}};var c=l.prototype;function u(t){var e=a.get(t);return e||(e=new l(t),a.set(t,e)),e}c.getShaderReference=function(t,e){var r=this.gl,a=this.shaders[t===r.FRAGMENT_SHADER|0],l=a[e];if(l&&r.isShader(l.shader))l.count+=1;else{var c=function(t,e,r){var a=t.createShader(e);if(t.shaderSource(a,r),t.compileShader(a),!t.getShaderParameter(a,t.COMPILE_STATUS)){var o=t.getShaderInfoLog(a);try{var s=i(o,r,e)}catch(t){throw console.warn(\"Failed to format compiler error: \"+t),new n(o,\"Error compiling shader:\\n\"+o)}throw new n(o,s.short,s.long)}return a}(r,t,e);l=a[e]=new s(o++,e,t,c,[],1,this)}return l},c.getProgram=function(t,e,r,i){var a=[t.id,e.id,r.join(\":\"),i.join(\":\")].join(\"@\"),o=this.programs[a];return o&&this.gl.isProgram(o)||(this.programs[a]=o=function(t,e,r,i,a){var o=t.createProgram();t.attachShader(o,e),t.attachShader(o,r);for(var s=0;s<i.length;++s)t.bindAttribLocation(o,a[s],i[s]);if(t.linkProgram(o),!t.getProgramParameter(o,t.LINK_STATUS)){var l=t.getProgramInfoLog(o);throw new n(l,\"Error linking program: \"+l)}return o}(this.gl,t.shader,e.shader,r,i),t.programs.push(a),e.programs.push(a)),o}},{\"./GLError\":302,\"gl-format-compiler-error\":250,\"weakmap-shim\":555}],308:[function(t,e,r){\"use strict\";function n(t){this.plot=t,this.enable=[!0,!0,!1,!1],this.width=[1,1,1,1],this.color=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.center=[1/0,1/0]}e.exports=function(t,e){var r=new n(t);return r.update(e),t.addOverlay(r),r};var i=n.prototype;i.update=function(t){t=t||{},this.enable=(t.enable||[!0,!0,!1,!1]).slice(),this.width=(t.width||[1,1,1,1]).slice(),this.color=(t.color||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]).map(function(t){return t.slice()}),this.center=(t.center||[1/0,1/0]).slice(),this.plot.setOverlayDirty()},i.draw=function(){var t=this.enable,e=this.width,r=this.color,n=this.center,i=this.plot,a=i.line,o=i.dataBox,s=i.viewBox;if(a.bind(),o[0]<=n[0]&&n[0]<=o[2]&&o[1]<=n[1]&&n[1]<=o[3]){var l=s[0]+(n[0]-o[0])/(o[2]-o[0])*(s[2]-s[0]),c=s[1]+(n[1]-o[1])/(o[3]-o[1])*(s[3]-s[1]);t[0]&&a.drawLine(l,c,s[0],c,e[0],r[0]),t[1]&&a.drawLine(l,c,l,s[1],e[1],r[1]),t[2]&&a.drawLine(l,c,s[2],c,e[2],r[2]),t[3]&&a.drawLine(l,c,l,s[3],e[3],r[3])}},i.dispose=function(){this.plot.removeOverlay(this)}},{}],309:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, color;\\nattribute float weight;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 coordinates[3];\\nuniform vec4 colors[3];\\nuniform vec2 screenShape;\\nuniform float lineWidth;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vertexPosition = mix(coordinates[0],\\n    mix(coordinates[2], coordinates[1], 0.5 * (position + 1.0)), abs(position));\\n\\n  vec4 clipPos = projection * view * model * vec4(vertexPosition, 1.0);\\n  vec2 clipOffset = (projection * view * model * vec4(color, 0.0)).xy;\\n  vec2 delta = weight * clipOffset * screenShape;\\n  vec2 lineOffset = normalize(vec2(delta.y, -delta.x)) / screenShape;\\n\\n  gl_Position   = vec4(clipPos.xy + clipPos.w * 0.5 * lineWidth * lineOffset, clipPos.z, clipPos.w);\\n  fragColor     = color.x * colors[0] + color.y * colors[1] + color.z * colors[2];\\n}\\n\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  gl_FragColor = fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec3\"},{name:\"weight\",type:\"float\"}])}},{\"gl-shader\":301,glslify:409}],310:[function(t,e,r){\"use strict\";var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\");e.exports=function(t,e){var r=[];function o(t,e,n,i,a,o){var s=[t,e,n,0,0,0,1];s[i+3]=1,s[i]=a,r.push.apply(r,s),s[6]=-1,r.push.apply(r,s),s[i]=o,r.push.apply(r,s),r.push.apply(r,s),s[6]=1,r.push.apply(r,s),s[i]=a,r.push.apply(r,s)}o(0,0,0,0,0,1),o(0,0,0,1,0,1),o(0,0,0,2,0,1),o(1,0,0,1,-1,1),o(1,0,0,2,-1,1),o(0,1,0,0,-1,1),o(0,1,0,2,-1,1),o(0,0,1,0,-1,1),o(0,0,1,1,-1,1);var l=n(t,r),c=i(t,[{type:t.FLOAT,buffer:l,size:3,offset:0,stride:28},{type:t.FLOAT,buffer:l,size:3,offset:12,stride:28},{type:t.FLOAT,buffer:l,size:1,offset:24,stride:28}]),u=a(t);u.attributes.position.location=0,u.attributes.color.location=1,u.attributes.weight.location=2;var h=new s(t,l,c,u);return h.update(e),h};var o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n,this.pixelRatio=1,this.bounds=[[-1e3,-1e3,-1e3],[1e3,1e3,1e3]],this.position=[0,0,0],this.lineWidth=[2,2,2],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.enabled=[!0,!0,!0],this.drawSides=[!0,!0,!0],this.axes=null}var l=s.prototype,c=[0,0,0],u=[0,0,0],h=[0,0];l.isTransparent=function(){return!1},l.drawTransparent=function(t){},l.draw=function(t){var e=this.gl,r=this.vao,n=this.shader;r.bind(),n.bind();var i,a=t.model||o,s=t.view||o,l=t.projection||o;this.axes&&(i=this.axes.lastCubeProps.axis);for(var f=c,p=u,d=0;d<3;++d)i&&i[d]<0?(f[d]=this.bounds[0][d],p[d]=this.bounds[1][d]):(f[d]=this.bounds[1][d],p[d]=this.bounds[0][d]);h[0]=e.drawingBufferWidth,h[1]=e.drawingBufferHeight,n.uniforms.model=a,n.uniforms.view=s,n.uniforms.projection=l,n.uniforms.coordinates=[this.position,f,p],n.uniforms.colors=this.colors,n.uniforms.screenShape=h;for(d=0;d<3;++d)n.uniforms.lineWidth=this.lineWidth[d]*this.pixelRatio,this.enabled[d]&&(r.draw(e.TRIANGLES,6,6*d),this.drawSides[d]&&r.draw(e.TRIANGLES,12,18+12*d));r.unbind()},l.update=function(t){t&&(\"bounds\"in t&&(this.bounds=t.bounds),\"position\"in t&&(this.position=t.position),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"colors\"in t&&(this.colors=t.colors),\"enabled\"in t&&(this.enabled=t.enabled),\"drawSides\"in t&&(this.drawSides=t.drawSides))},l.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders/index\":309,\"gl-buffer\":241,\"gl-vao\":327}],311:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\nuniform float vectorScale;\\nuniform float tubeScale;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * tubePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal,0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(tubePosition, 1.0);\\n  vec4 t_position  = view * tubePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = tubePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular\\n            , opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform float tubeScale;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  gl_Position = projection * view * tubePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec4\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec4\"}]}},{glslify:409}],312:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./shaders\"),g=d.meshShader,v=d.pickShader,m=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function y(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,y,x,b,_,w,k,T){this.gl=t,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=i,this.triangleVectors=a,this.triangleColors=s,this.triangleNormals=c,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=u,this.triangleCount=0,this.lineWidth=1,this.edgePositions=h,this.edgeColors=p,this.edgeUVs=d,this.edgeIds=f,this.edgeVAO=g,this.edgeCount=0,this.pointPositions=v,this.pointColors=x,this.pointUVs=b,this.pointSizes=_,this.pointIds=y,this.pointVAO=w,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=k,this.contourVAO=T,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!1,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.tubeScale=1,this._model=m,this._view=m,this._projection=m,this._resolution=[1,1],this.pixelRatio=1}var x=y.prototype;function b(t){var e=n(t,v.vertex,v.fragment,null,v.attributes);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.vector.location=5,e}x.isOpaque=function(){return this.opacity>=1},x.isTransparent=function(){return this.opacity<1},x.pickSlots=1,x.setPickBase=function(t){this.pickId=t},x.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=i[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},x.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=h({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return u(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,i=t.vectors;if(n&&r&&i){void 0!==t.tubeScale&&(this.tubeScale=t.tubeScale);var a=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[],w=[],k=[];this.cells=r,this.positions=n,this.vectors=i;var T=t.vertexNormals,A=t.cellNormals,M=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,S=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!A&&(A=s.faceNormals(r,n,S)),A||T||(T=s.vertexNormals(r,n,M));var E=t.vertexColors,C=t.cellColors,L=t.meshColor||[1,1,1,1],P=t.vertexUVs,O=t.vertexIntensity,z=t.cellUVs,I=t.cellIntensity,D=1/0,R=-1/0;if(!P&&!z)if(O)if(t.vertexIntensityBounds)D=+t.vertexIntensityBounds[0],R=+t.vertexIntensityBounds[1];else for(var F=0;F<O.length;++F){var B=O[F];D=Math.min(D,B),R=Math.max(R,B)}else if(I)for(F=0;F<I.length;++F){B=I[F];D=Math.min(D,B),R=Math.max(R,B)}else for(F=0;F<n.length;++F){B=n[F][2];D=Math.min(D,B),R=Math.max(R,B)}this.intensity=O||(I?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,I):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var N=t.pointSizes,j=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(F=0;F<n.length;++F)for(var U=n[F],V=0;V<3;++V)!isNaN(U[V])&&isFinite(U[V])&&(this.bounds[0][V]=Math.min(this.bounds[0][V],U[V]),this.bounds[1][V]=Math.max(this.bounds[1][V],U[V]));var q=0,H=0,G=0;t:for(F=0;F<r.length;++F){var Y=r[F];switch(Y.length){case 1:for(U=n[X=Y[0]],V=0;V<3;++V)if(isNaN(U[V])||!isFinite(U[V]))continue t;x.push(U[0],U[1],U[2],U[3]),3===(Z=E?E[X]:C?C[F]:L).length?b.push(Z[0],Z[1],Z[2],1):b.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],_.push(J[0],J[1]),N?w.push(N[X]):w.push(j),k.push(F),G+=1;break;case 2:for(V=0;V<2;++V){U=n[X=Y[V]];for(var W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t}for(V=0;V<2;++V){U=n[X=Y[V]];g.push(U[0],U[1],U[2]),3===(Z=E?E[X]:C?C[F]:L).length?v.push(Z[0],Z[1],Z[2],1):v.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],m.push(J[0],J[1]),y.push(F)}H+=1;break;case 3:for(V=0;V<3;++V)for(U=n[X=Y[V]],W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t;for(V=0;V<3;++V){var X;U=n[X=Y[2-V]];a.push(U[0],U[1],U[2],U[3]);var Z,J,K,$=i[X];l.push($[0],$[1],$[2],$[3]),3===(Z=E?E[X]:C?C[F]:L).length?c.push(Z[0],Z[1],Z[2],1):c.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],p.push(J[0],J[1]),K=T?T[X]:A[F],f.push(K[0],K[1],K[2]),d.push(F)}q+=1}}this.pointCount=G,this.edgeCount=H,this.triangleCount=q,this.pointPositions.update(x),this.pointColors.update(b),this.pointUVs.update(_),this.pointSizes.update(w),this.pointIds.update(new Uint32Array(k)),this.edgePositions.update(g),this.edgeColors.update(v),this.edgeUVs.update(m),this.edgeIds.update(new Uint32Array(y)),this.trianglePositions.update(a),this.triangleVectors.update(l),this.triangleColors.update(c),this.triangleUVs.update(p),this.triangleNormals.update(f),this.triangleIds.update(new Uint32Array(d))}},x.drawTransparent=x.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:m.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,tubeScale:this.tubeScale,contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var f=u[12+o],p=0;p<3;++p)f+=u[4*p+o]*this.lightPosition[p];s.lightPosition[o]=f/h}if(this.triangleCount>0){var d=this.triShader;d.bind(),d.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},x.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:i,clipBounds:a,tubeScale:this.tubeScale,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind())},x.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3);return{index:e,position:n,intensity:this.intensity[r[1]],velocity:this.vectors[r[1]].slice(0,3),divergence:this.vectors[r[1]][3],dataCoordinate:n}},x.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose()},e.exports=function(t,e){1===arguments.length&&(t=(e=t).gl);var r=e.triShader||function(t){var e=n(t,g.vertex,g.fragment,null,g.attributes);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.vector.location=5,e}(t),s=b(t),l=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));l.generateMipmap(),l.minFilter=t.LINEAR_MIPMAP_LINEAR,l.magFilter=t.LINEAR;var c=i(t),h=i(t),f=i(t),p=i(t),d=i(t),v=i(t),m=a(t,[{buffer:c,type:t.FLOAT,size:4},{buffer:v,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:f,type:t.FLOAT,size:4},{buffer:p,type:t.FLOAT,size:2},{buffer:d,type:t.FLOAT,size:3},{buffer:h,type:t.FLOAT,size:4}]),x=i(t),_=i(t),w=i(t),k=i(t),T=a(t,[{buffer:x,type:t.FLOAT,size:3},{buffer:k,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:_,type:t.FLOAT,size:4},{buffer:w,type:t.FLOAT,size:2}]),A=i(t),M=i(t),S=i(t),E=i(t),C=i(t),L=a(t,[{buffer:A,type:t.FLOAT,size:3},{buffer:C,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:M,type:t.FLOAT,size:4},{buffer:S,type:t.FLOAT,size:2},{buffer:E,type:t.FLOAT,size:1}]),P=i(t),O=new y(t,l,r,s,c,h,v,f,p,d,m,x,k,_,w,T,A,C,M,S,E,L,P,a(t,[{buffer:P,type:t.FLOAT,size:3}]));return O.update(e),O}},{\"./shaders\":311,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-shader\":301,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,normals:453,\"simplicial-complex-contour\":518,\"typedarray-pool\":545}],313:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\"),i=t(\"gl-vec4\"),a=function(t,e,r,a){for(var o=0,s=0;s<t.length;s++)for(var l=t[s].velocities,c=0;c<l.length;c++){var u=n.length(l[c]);u>o&&(o=u)}var h=t.map(function(t){return function(t,e,r,a){var o,s,l,c=t.points,u=t.velocities,h=t.divergences;n.set(n.create(),0,1,0),n.create(),n.create();n.create();for(var f=[],p=[],d=[],g=[],v=[],m=[],y=0,x=0,b=i.create(),_=i.create(),w=0;w<c.length;w++){o=c[w],s=u[w],l=h[w],0===e&&(l=.05*r),x=n.length(s)/a,b=i.create(),n.copy(b,s),b[3]=l;for(var k=0;k<8;k++)v[k]=[o[0],o[1],o[2],k];if(g.length>0)for(k=0;k<8;k++){var T=(k+1)%8;f.push(g[k],v[k],v[T],v[T],g[T],g[k]),d.push(_,b,b,b,_,_),m.push(y,x,x,x,y,y),p.push([f.length-6,f.length-5,f.length-4],[f.length-3,f.length-2,f.length-1])}var A=g;g=v,v=A,A=_,_=b,b=A,A=y,y=x,x=A}return{positions:f,cells:p,vectors:d,vertexIntensity:m}}(t,r,a,o)}),f=[],p=[],d=[],g=[];for(s=0;s<h.length;s++){var v=h[s],m=f.length;f=f.concat(v.positions),d=d.concat(v.vectors),g=g.concat(v.vertexIntensity);for(c=0;c<v.cells.length;c++){var y=v.cells[c],x=[];p.push(x);for(var b=0;b<y.length;b++)x.push(y[b]+m)}}return{positions:f,cells:p,vectors:d,vertexIntensity:g,colormap:e}},o=function(t,e){var r=n.create(),i=1e-4;n.add(r,t,[i,0,0]);var a=this.getVelocity(r);n.subtract(a,a,e),n.scale(a,a,1e4),n.add(r,t,[0,i,0]);var o=this.getVelocity(r);n.subtract(o,o,e),n.scale(o,o,1e4),n.add(r,t,[0,0,i]);var s=this.getVelocity(r);return n.subtract(s,s,e),n.scale(s,s,1e4),n.add(r,a,o),n.add(r,r,s),r},s=function(t){return f(t,this.vectors,this.meshgrid,this.clampBorders)},l=function(t,e){for(var r=0;r<t.length;r++){var n=t[r];if(n===e)return r;if(n>e)return r-1}return r},c=n.create(),u=n.create(),h=function(t,e,r){return t<e?e:t>r?r:t},f=function(t,e,r,i){var a=t[0],o=t[1],s=t[2],f=r[0].length,p=r[1].length,d=r[2].length,g=l(r[0],a),v=l(r[1],o),m=l(r[2],s),y=g+1,x=v+1,b=m+1;if(r[0][g]===a&&(y=g),r[1][v]===o&&(x=v),r[2][m]===s&&(b=m),i&&(g=h(g,0,f-1),y=h(y,0,f-1),v=h(v,0,p-1),x=h(x,0,p-1),m=h(m,0,d-1),b=h(b,0,d-1)),g<0||v<0||m<0||y>=f||x>=p||b>=d)return n.create();var _=(a-r[0][g])/(r[0][y]-r[0][g]),w=(o-r[1][v])/(r[1][x]-r[1][v]),k=(s-r[2][m])/(r[2][b]-r[2][m]);(_<0||_>1||isNaN(_))&&(_=0),(w<0||w>1||isNaN(w))&&(w=0),(k<0||k>1||isNaN(k))&&(k=0);var T=m*f*p,A=b*f*p,M=v*f,S=x*f,E=g,C=y,L=e[M+T+E],P=e[M+T+C],O=e[S+T+E],z=e[S+T+C],I=e[M+A+E],D=e[M+A+C],R=e[S+A+E],F=e[S+A+C],B=n.create();return n.lerp(B,L,P,_),n.lerp(c,O,z,_),n.lerp(B,B,c,w),n.lerp(c,I,D,_),n.lerp(u,R,F,_),n.lerp(c,c,u,w),n.lerp(B,B,c,k),B},p=function(t){var e=1/0;t.sort(function(t,e){return t-e});for(var r=1;r<t.length;r++){var n=Math.abs(t[r]-t[r-1]);n<e&&(e=n)}return e};e.exports=function(t,e){var r=t.startingPositions,i=t.maxLength||1e3,l=t.tubeSize||1,c=t.absoluteTubeSize;t.getDivergence||(t.getDivergence=o),t.getVelocity||(t.getVelocity=s),void 0===t.clampBorders&&(t.clampBorders=!0);var u=[],h=e[0][0],f=e[0][1],d=e[0][2],g=e[1][0],v=e[1][1],m=e[1][2],y=function(t,e){var r=e[0],n=e[1],i=e[2];return r>=h&&r<=g&&n>=f&&n<=v&&i>=d&&i<=m},x=10*n.distance(e[0],e[1])/i,b=x*x,_=1,w=0;n.create();r.length>=2&&(_=function(t){for(var e=[],r=[],n=[],i={},a={},o={},s=0;s<t.length;s++){var l=t[s],c=l[0],u=l[1],h=l[2];i[c]||(e.push(c),i[c]=!0),a[u]||(r.push(u),a[u]=!0),o[h]||(n.push(h),o[h]=!0)}var f=p(e),d=p(r),g=p(n),v=Math.min(f,d,g);return isFinite(v)?v:1}(r));for(var k=0;k<r.length;k++){var T=n.create();n.copy(T,r[k]);var A=[T],M=[],S=t.getVelocity(T),E=T;M.push(S);var C=[],L=t.getDivergence(T,S);(I=n.length(L))>w&&!isNaN(I)&&isFinite(I)&&(w=I),C.push(I),u.push({points:A,velocities:M,divergences:C});for(var P=0;P<100*i&&A.length<i&&y(0,T);){P++;var O=n.clone(S),z=n.squaredLength(O);if(0===z)break;if(z>b&&n.scale(O,O,x/Math.sqrt(z)),n.add(O,O,T),S=t.getVelocity(O),n.squaredDistance(E,O)-b>-1e-4*b){A.push(O),E=O,M.push(S);L=t.getDivergence(O,S);(I=n.length(L))>w&&!isNaN(I)&&isFinite(I)&&(w=I),C.push(I)}T=O}}for(k=0;k<C.length;k++){var I=C[k];!isNaN(I)&&isFinite(I)||(C[k]=w)}var D=a(u,t.colormap,w,_);return c?D.tubeScale=c:(0===w&&(w=1),D.tubeScale=.5*l*_/w),D},e.exports.createTubeMesh=t(\"./lib/tubemesh\")},{\"./lib/tubemesh\":312,\"gl-vec3\":346,\"gl-vec4\":382}],314:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute vec3 f;\\nattribute vec3 normal;\\n\\nuniform vec3 objectOffset;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 lightPosition, eyePosition;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 localCoordinate = vec3(uv.zw, f.x);\\n  worldCoordinate = objectOffset + localCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n  vec4 clipPosition = projection * view * worldPosition;\\n  gl_Position = clipPosition;\\n  kill = f.y;\\n  value = f.z;\\n  planeCoordinate = uv.xy;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * worldPosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  lightDirection = lightPosition - cameraCoordinate.xyz;\\n  eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  surfaceNormal  = normalize((vec4(normal,0) * inverseModel).xyz);\\n}\\n\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat beckmannSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness) {\\n  return beckmannDistribution(dot(surfaceNormal, normalize(lightDirection + viewDirection)), roughness);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 lowerBound, upperBound;\\nuniform float contourTint;\\nuniform vec4 contourColor;\\nuniform sampler2D colormap;\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform float vertexColor;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec3 N = normalize(surfaceNormal);\\n  vec3 V = normalize(eyeDirection);\\n  vec3 L = normalize(lightDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = max(beckmannSpecular(L, V, N, roughness), 0.);\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  //decide how to interpolate color \\u2014 in vertex or in fragment\\n  vec4 surfaceColor =\\n    step(vertexColor, .5) * texture2D(colormap, vec2(value, value)) +\\n    step(.5, vertexColor) * vColor;\\n\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = mix(litColor, contourColor, contourTint) * opacity;\\n}\\n\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute float f;\\n\\nuniform vec3 objectOffset;\\nuniform mat3 permutation;\\nuniform mat4 model, view, projection;\\nuniform float height, zOffset;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 dataCoordinate = permutation * vec3(uv.xy, height);\\n  worldCoordinate = objectOffset + dataCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n\\n  vec4 clipPosition = projection * view * worldPosition;\\n  clipPosition.z += zOffset;\\n\\n  gl_Position = clipPosition;\\n  value = f + objectOffset.z;\\n  kill = -1.0;\\n  planeCoordinate = uv.zw;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Don't do lighting for contours\\n  surfaceNormal   = vec3(1,0,0);\\n  eyeDirection    = vec3(0,1,0);\\n  lightDirection  = vec3(0,0,1);\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec2 shape;\\nuniform vec3 clipBounds[2];\\nuniform float pickId;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 surfaceNormal;\\n\\nvec2 splitFloat(float v) {\\n  float vh = 255.0 * v;\\n  float upper = floor(vh);\\n  float lower = fract(vh);\\n  return vec2(upper / 255.0, floor(lower * 16.0) / 16.0);\\n}\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec2 ux = splitFloat(planeCoordinate.x / shape.x);\\n  vec2 uy = splitFloat(planeCoordinate.y / shape.y);\\n  gl_FragColor = vec4(pickId, ux.x, uy.x, ux.y + (uy.y/16.0));\\n}\\n\"]);r.createShader=function(t){var e=n(t,a,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createPickShader=function(t){var e=n(t,a,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createContourShader=function(t){var e=n(t,s,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e},r.createPickContourShader=function(t){var e=n(t,s,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e}},{\"gl-shader\":301,glslify:409}],315:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],316:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=y(e),n=b(e),s=x(e),l=_(e),c=i(e),u=a(e,[{buffer:c,size:4,stride:w,offset:0},{buffer:c,size:3,stride:w,offset:16},{buffer:c,size:3,stride:w,offset:28}]),h=i(e),f=a(e,[{buffer:h,size:4,stride:20,offset:0},{buffer:h,size:1,stride:20,offset:16}]),p=i(e),d=a(e,[{buffer:p,size:2,type:e.FLOAT}]),g=o(e,1,S,e.RGBA,e.UNSIGNED_BYTE);g.minFilter=e.LINEAR,g.magFilter=e.LINEAR;var v=new E(e,[0,0],[[0,0,0],[0,0,0]],r,n,c,u,g,s,l,h,f,p,d,[0,0,0]),m={levels:[[],[],[]]};for(var k in t)m[k]=t[k];return m.colormap=m.colormap||\"jet\",v.update(m),v};var n=t(\"bit-twiddle\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"typedarray-pool\"),l=t(\"colormap\"),c=t(\"ndarray-ops\"),u=t(\"ndarray-pack\"),h=t(\"ndarray\"),f=t(\"surface-nets\"),p=t(\"gl-mat4/multiply\"),d=t(\"gl-mat4/invert\"),g=t(\"binary-search-bounds\"),v=t(\"ndarray-gradient\"),m=t(\"./lib/shaders\"),y=m.createShader,x=m.createContourShader,b=m.createPickShader,_=m.createPickContourShader,w=40,k=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1],T=[[0,0],[0,1],[1,0],[1,1],[1,0],[0,1]],A=[[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0]];function M(t,e,r,n,i){this.position=t,this.index=e,this.uv=r,this.level=n,this.dataCoordinate=i}!function(){for(var t=0;t<3;++t){var e=A[t],r=(t+2)%3;e[(t+1)%3+0]=1,e[r+3]=1,e[t+6]=1}}();var S=256;function E(t,e,r,n,i,a,o,l,c,u,f,p,d,g,v){this.gl=t,this.shape=e,this.bounds=r,this.objectOffset=v,this.intensityBounds=[],this._shader=n,this._pickShader=i,this._coordinateBuffer=a,this._vao=o,this._colorMap=l,this._contourShader=c,this._contourPickShader=u,this._contourBuffer=f,this._contourVAO=p,this._contourOffsets=[[],[],[]],this._contourCounts=[[],[],[]],this._vertexCount=0,this._pickResult=new M([0,0,0],[0,0],[0,0],[0,0,0],[0,0,0]),this._dynamicBuffer=d,this._dynamicVAO=g,this._dynamicOffsets=[0,0,0],this._dynamicCounts=[0,0,0],this.contourWidth=[1,1,1],this.contourLevels=[[1],[1],[1]],this.contourTint=[0,0,0],this.contourColor=[[.5,.5,.5,1],[.5,.5,.5,1],[.5,.5,.5,1]],this.showContour=!0,this.showSurface=!0,this.enableHighlight=[!0,!0,!0],this.highlightColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.highlightTint=[1,1,1],this.highlightLevel=[-1,-1,-1],this.enableDynamic=[!0,!0,!0],this.dynamicLevel=[NaN,NaN,NaN],this.dynamicColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.dynamicTint=[1,1,1],this.dynamicWidth=[1,1,1],this.axesBounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.surfaceProject=[!1,!1,!1],this.contourProject=[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],this.colorBounds=[!1,!1],this._field=[h(s.mallocFloat(1024),[0,0]),h(s.mallocFloat(1024),[0,0]),h(s.mallocFloat(1024),[0,0])],this.pickId=1,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.snapToData=!1,this.pixelRatio=1,this.opacity=1,this.lightPosition=[10,1e4,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.vertexColor=0,this.dirty=!0}var C=E.prototype;C.isTransparent=function(){return this.opacity<1},C.isOpaque=function(){if(this.opacity>=1)return!0;for(var t=0;t<3;++t)if(this._contourCounts[t].length>0||this._dynamicCounts[t]>0)return!0;return!1},C.pickSlots=1,C.setPickBase=function(t){this.pickId=t};var L=[0,0,0],P={showSurface:!1,showContour:!1,projections:[k.slice(),k.slice(),k.slice()],clipBounds:[[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]]]};function O(t,e){var r,n,i,a=e.axes&&e.axes.lastCubeProps.axis||L,o=e.showSurface,s=e.showContour;for(r=0;r<3;++r)for(o=o||e.surfaceProject[r],n=0;n<3;++n)s=s||e.contourProject[r][n];for(r=0;r<3;++r){var l=P.projections[r];for(n=0;n<16;++n)l[n]=0;for(n=0;n<4;++n)l[5*n]=1;l[5*r]=0,l[12+r]=e.axesBounds[+(a[r]>0)][r],p(l,t.model,l);var c=P.clipBounds[r];for(i=0;i<2;++i)for(n=0;n<3;++n)c[i][n]=t.clipBounds[i][n];c[0][r]=-1e8,c[1][r]=1e8}return P.showSurface=o,P.showContour=s,P}var z={model:k,view:k,projection:k,inverseModel:k.slice(),lowerBound:[0,0,0],upperBound:[0,0,0],colorMap:0,clipBounds:[[0,0,0],[0,0,0]],height:0,contourTint:0,contourColor:[0,0,0,1],permutation:[1,0,0,0,1,0,0,0,1],zOffset:-1e-4,objectOffset:[0,0,0],kambient:1,kdiffuse:1,kspecular:1,lightPosition:[1e3,1e3,1e3],eyePosition:[0,0,0],roughness:1,fresnel:1,opacity:1,vertexColor:0},I=k.slice(),D=[1,0,0,0,1,0,0,0,1];function R(t,e){t=t||{};var r=this.gl;r.disable(r.CULL_FACE),this._colorMap.bind(0);var n=z;n.model=t.model||k,n.view=t.view||k,n.projection=t.projection||k,n.lowerBound=[this.bounds[0][0],this.bounds[0][1],this.colorBounds[0]||this.bounds[0][2]],n.upperBound=[this.bounds[1][0],this.bounds[1][1],this.colorBounds[1]||this.bounds[1][2]],n.objectOffset=this.objectOffset,n.contourColor=this.contourColor[0],n.inverseModel=d(n.inverseModel,n.model);for(var i=0;i<2;++i)for(var a=n.clipBounds[i],o=0;o<3;++o)a[o]=Math.min(Math.max(this.clipBounds[i][o],-1e8),1e8);n.kambient=this.ambientLight,n.kdiffuse=this.diffuseLight,n.kspecular=this.specularLight,n.roughness=this.roughness,n.fresnel=this.fresnel,n.opacity=this.opacity,n.height=0,n.permutation=D,n.vertexColor=this.vertexColor;var s=I;for(p(s,n.view,n.model),p(s,n.projection,s),d(s,s),i=0;i<3;++i)n.eyePosition[i]=s[12+i]/s[15];var l=s[15];for(i=0;i<3;++i)l+=this.lightPosition[i]*s[4*i+3];for(i=0;i<3;++i){var c=s[12+i];for(o=0;o<3;++o)c+=s[4*o+i]*this.lightPosition[o];n.lightPosition[i]=c/l}var u=O(n,this);if(u.showSurface&&e===this.opacity<1){for(this._shader.bind(),this._shader.uniforms=n,this._vao.bind(),this.showSurface&&this._vertexCount&&this._vao.draw(r.TRIANGLES,this._vertexCount),i=0;i<3;++i)this.surfaceProject[i]&&this.vertexCount&&(this._shader.uniforms.model=u.projections[i],this._shader.uniforms.clipBounds=u.clipBounds[i],this._vao.draw(r.TRIANGLES,this._vertexCount));this._vao.unbind()}if(u.showContour&&!e){var h=this._contourShader;n.kambient=1,n.kdiffuse=0,n.kspecular=0,n.opacity=1,h.bind(),h.uniforms=n;var f=this._contourVAO;for(f.bind(),i=0;i<3;++i)for(h.uniforms.permutation=A[i],r.lineWidth(this.contourWidth[i]*this.pixelRatio),o=0;o<this.contourLevels[i].length;++o)o===this.highlightLevel[i]?(h.uniforms.contourColor=this.highlightColor[i],h.uniforms.contourTint=this.highlightTint[i]):0!==o&&o-1!==this.highlightLevel[i]||(h.uniforms.contourColor=this.contourColor[i],h.uniforms.contourTint=this.contourTint[i]),this._contourCounts[i][o]&&(h.uniforms.height=this.contourLevels[i][o],f.draw(r.LINES,this._contourCounts[i][o],this._contourOffsets[i][o]));for(i=0;i<3;++i)for(h.uniforms.model=u.projections[i],h.uniforms.clipBounds=u.clipBounds[i],o=0;o<3;++o)if(this.contourProject[i][o]){h.uniforms.permutation=A[o],r.lineWidth(this.contourWidth[o]*this.pixelRatio);for(var g=0;g<this.contourLevels[o].length;++g)g===this.highlightLevel[o]?(h.uniforms.contourColor=this.highlightColor[o],h.uniforms.contourTint=this.highlightTint[o]):0!==g&&g-1!==this.highlightLevel[o]||(h.uniforms.contourColor=this.contourColor[o],h.uniforms.contourTint=this.contourTint[o]),this._contourCounts[o][g]&&(h.uniforms.height=this.contourLevels[o][g],f.draw(r.LINES,this._contourCounts[o][g],this._contourOffsets[o][g]))}for(f.unbind(),(f=this._dynamicVAO).bind(),i=0;i<3;++i)if(0!==this._dynamicCounts[i])for(h.uniforms.model=n.model,h.uniforms.clipBounds=n.clipBounds,h.uniforms.permutation=A[i],r.lineWidth(this.dynamicWidth[i]*this.pixelRatio),h.uniforms.contourColor=this.dynamicColor[i],h.uniforms.contourTint=this.dynamicTint[i],h.uniforms.height=this.dynamicLevel[i],f.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]),o=0;o<3;++o)this.contourProject[o][i]&&(h.uniforms.model=u.projections[o],h.uniforms.clipBounds=u.clipBounds[o],f.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]));f.unbind()}}C.draw=function(t){return R.call(this,t,!1)},C.drawTransparent=function(t){return R.call(this,t,!0)};var F={model:k,view:k,projection:k,inverseModel:k,clipBounds:[[0,0,0],[0,0,0]],height:0,shape:[0,0],pickId:0,lowerBound:[0,0,0],upperBound:[0,0,0],zOffset:0,objectOffset:[0,0,0],permutation:[1,0,0,0,1,0,0,0,1],lightPosition:[0,0,0],eyePosition:[0,0,0]};function B(t,e){return Array.isArray(t)?[e(t[0]),e(t[1]),e(t[2])]:[e(t),e(t),e(t)]}function N(t){return Array.isArray(t)?3===t.length?[t[0],t[1],t[2],1]:[t[0],t[1],t[2],t[3]]:[0,0,0,1]}function j(t){if(Array.isArray(t)){if(Array.isArray(t))return[N(t[0]),N(t[1]),N(t[2])];var e=N(t);return[e.slice(),e.slice(),e.slice()]}}C.drawPick=function(t){t=t||{};var e=this.gl;e.disable(e.CULL_FACE);var r=F;r.model=t.model||k,r.view=t.view||k,r.projection=t.projection||k,r.shape=this._field[2].shape,r.pickId=this.pickId/255,r.lowerBound=this.bounds[0],r.upperBound=this.bounds[1],r.objectOffset=this.objectOffset,r.permutation=D;for(var n=0;n<2;++n)for(var i=r.clipBounds[n],a=0;a<3;++a)i[a]=Math.min(Math.max(this.clipBounds[n][a],-1e8),1e8);var o=O(r,this);if(o.showSurface){for(this._pickShader.bind(),this._pickShader.uniforms=r,this._vao.bind(),this._vao.draw(e.TRIANGLES,this._vertexCount),n=0;n<3;++n)this.surfaceProject[n]&&(this._pickShader.uniforms.model=o.projections[n],this._pickShader.uniforms.clipBounds=o.clipBounds[n],this._vao.draw(e.TRIANGLES,this._vertexCount));this._vao.unbind()}if(o.showContour){var s=this._contourPickShader;s.bind(),s.uniforms=r;var l=this._contourVAO;for(l.bind(),a=0;a<3;++a)for(e.lineWidth(this.contourWidth[a]*this.pixelRatio),s.uniforms.permutation=A[a],n=0;n<this.contourLevels[a].length;++n)this._contourCounts[a][n]&&(s.uniforms.height=this.contourLevels[a][n],l.draw(e.LINES,this._contourCounts[a][n],this._contourOffsets[a][n]));for(n=0;n<3;++n)for(s.uniforms.model=o.projections[n],s.uniforms.clipBounds=o.clipBounds[n],a=0;a<3;++a)if(this.contourProject[n][a]){s.uniforms.permutation=A[a],e.lineWidth(this.contourWidth[a]*this.pixelRatio);for(var c=0;c<this.contourLevels[a].length;++c)this._contourCounts[a][c]&&(s.uniforms.height=this.contourLevels[a][c],l.draw(e.LINES,this._contourCounts[a][c],this._contourOffsets[a][c]))}l.unbind()}},C.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=this._field[2].shape,r=this._pickResult,n=e[0]*(t.value[0]+(t.value[2]>>4)/16)/255,i=Math.floor(n),a=n-i,o=e[1]*(t.value[1]+(15&t.value[2])/16)/255,s=Math.floor(o),l=o-s;i+=1,s+=1;var c=r.position;c[0]=c[1]=c[2]=0;for(var u=0;u<2;++u)for(var h=u?a:1-a,f=0;f<2;++f)for(var p=i+u,d=s+f,v=h*(f?l:1-l),m=0;m<3;++m)c[m]+=this._field[m].get(p,d)*v;for(var y=this._pickResult.level,x=0;x<3;++x)if(y[x]=g.le(this.contourLevels[x],c[x]),y[x]<0)this.contourLevels[x].length>0&&(y[x]=0);else if(y[x]<this.contourLevels[x].length-1){var b=this.contourLevels[x][y[x]],_=this.contourLevels[x][y[x]+1];Math.abs(b-c[x])>Math.abs(_-c[x])&&(y[x]+=1)}for(r.index[0]=a<.5?i:i+1,r.index[1]=l<.5?s:s+1,r.uv[0]=n/e[0],r.uv[1]=o/e[1],m=0;m<3;++m)r.dataCoordinate[m]=this._field[m].get(r.index[0],r.index[1]);return r},C.padField=function(t,e){var r=e.shape.slice(),n=t.shape.slice();c.assign(t.lo(1,1).hi(r[0],r[1]),e),c.assign(t.lo(1).hi(r[0],1),e.hi(r[0],1)),c.assign(t.lo(1,n[1]-1).hi(r[0],1),e.lo(0,r[1]-1).hi(r[0],1)),c.assign(t.lo(0,1).hi(1,r[1]),e.hi(1)),c.assign(t.lo(n[0]-1,1).hi(1,r[1]),e.lo(r[0]-1)),t.set(0,0,e.get(0,0)),t.set(0,n[1]-1,e.get(0,r[1]-1)),t.set(n[0]-1,0,e.get(r[0]-1,0)),t.set(n[0]-1,n[1]-1,e.get(r[0]-1,r[1]-1))},C.update=function(t){t=t||{},this.objectOffset=t.objectOffset||this.objectOffset,this.dirty=!0,\"contourWidth\"in t&&(this.contourWidth=B(t.contourWidth,Number)),\"showContour\"in t&&(this.showContour=B(t.showContour,Boolean)),\"showSurface\"in t&&(this.showSurface=!!t.showSurface),\"contourTint\"in t&&(this.contourTint=B(t.contourTint,Boolean)),\"contourColor\"in t&&(this.contourColor=j(t.contourColor)),\"contourProject\"in t&&(this.contourProject=B(t.contourProject,function(t){return B(t,Boolean)})),\"surfaceProject\"in t&&(this.surfaceProject=t.surfaceProject),\"dynamicColor\"in t&&(this.dynamicColor=j(t.dynamicColor)),\"dynamicTint\"in t&&(this.dynamicTint=B(t.dynamicTint,Number)),\"dynamicWidth\"in t&&(this.dynamicWidth=B(t.dynamicWidth,Number)),\"opacity\"in t&&(this.opacity=t.opacity),\"colorBounds\"in t&&(this.colorBounds=t.colorBounds),\"vertexColor\"in t&&(this.vertexColor=t.vertexColor?1:0);var e=t.field||t.coords&&t.coords[2]||null,r=!1;if(e||(e=this._field[2].shape[0]||this._field[2].shape[2]?this._field[2].lo(1,1).hi(this._field[2].shape[0]-2,this._field[2].shape[1]-2):this._field[2].hi(0,0)),\"field\"in t||\"coords\"in t){var i=(e.shape[0]+2)*(e.shape[1]+2);i>this._field[2].data.length&&(s.freeFloat(this._field[2].data),this._field[2].data=s.mallocFloat(n.nextPow2(i))),this._field[2]=h(this._field[2].data,[e.shape[0]+2,e.shape[1]+2]),this.padField(this._field[2],e),this.shape=e.shape.slice();for(var a=this.shape,o=0;o<2;++o)this._field[2].size>this._field[o].data.length&&(s.freeFloat(this._field[o].data),this._field[o].data=s.mallocFloat(this._field[2].size)),this._field[o]=h(this._field[o].data,[a[0]+2,a[1]+2]);if(t.coords){var p=t.coords;if(!Array.isArray(p)||3!==p.length)throw new Error(\"gl-surface: invalid coordinates for x/y\");for(o=0;o<2;++o){var d=p[o];for(b=0;b<2;++b)if(d.shape[b]!==a[b])throw new Error(\"gl-surface: coords have incorrect shape\");this.padField(this._field[o],d)}}else if(t.ticks){var g=t.ticks;if(!Array.isArray(g)||2!==g.length)throw new Error(\"gl-surface: invalid ticks\");for(o=0;o<2;++o){var m=g[o];if((Array.isArray(m)||m.length)&&(m=h(m)),m.shape[0]!==a[o])throw new Error(\"gl-surface: invalid tick length\");var y=h(m.data,a);y.stride[o]=m.stride[0],y.stride[1^o]=0,this.padField(this._field[o],y)}}else{for(o=0;o<2;++o){var x=[0,0];x[o]=1,this._field[o]=h(this._field[o].data,[a[0]+2,a[1]+2],x,0)}this._field[0].set(0,0,0);for(var b=0;b<a[0];++b)this._field[0].set(b+1,0,b);for(this._field[0].set(a[0]+1,0,a[0]-1),this._field[1].set(0,0,0),b=0;b<a[1];++b)this._field[1].set(0,b+1,b);this._field[1].set(0,a[1]+1,a[1]-1)}var _=this._field,w=h(s.mallocFloat(3*_[2].size*2),[3,a[0]+2,a[1]+2,2]);for(o=0;o<3;++o)v(w.pick(o),_[o],\"mirror\");var k=h(s.mallocFloat(3*_[2].size),[a[0]+2,a[1]+2,3]);for(o=0;o<a[0]+2;++o)for(b=0;b<a[1]+2;++b){var A=w.get(0,o,b,0),M=w.get(0,o,b,1),E=w.get(1,o,b,0),C=w.get(1,o,b,1),L=w.get(2,o,b,0),P=w.get(2,o,b,1),O=E*P-C*L,z=L*M-P*A,I=A*C-M*E,D=Math.sqrt(O*O+z*z+I*I);D<1e-8?(D=Math.max(Math.abs(O),Math.abs(z),Math.abs(I)))<1e-8?(I=1,z=O=0,D=1):D=1/D:D=1/Math.sqrt(D),k.set(o,b,0,O*D),k.set(o,b,1,z*D),k.set(o,b,2,I*D)}s.free(w.data);var R=[1/0,1/0,1/0],F=[-1/0,-1/0,-1/0],N=1/0,U=-1/0,V=(a[0]-1)*(a[1]-1)*6,q=s.mallocFloat(n.nextPow2(10*V)),H=0,G=0;for(o=0;o<a[0]-1;++o)t:for(b=0;b<a[1]-1;++b){for(var Y=0;Y<2;++Y)for(var W=0;W<2;++W)for(var X=0;X<3;++X){var Z=this._field[X].get(1+o+Y,1+b+W);if(isNaN(Z)||!isFinite(Z))continue t}for(X=0;X<6;++X){var J=o+T[X][0],K=b+T[X][1],$=this._field[0].get(J+1,K+1),Q=this._field[1].get(J+1,K+1);Z=this._field[2].get(J+1,K+1),O=k.get(J+1,K+1,0),z=k.get(J+1,K+1,1),I=k.get(J+1,K+1,2),t.intensity&&(tt=t.intensity.get(J,K));var tt=t.intensity?t.intensity.get(J,K):Z+this.objectOffset[2];q[H++]=J,q[H++]=K,q[H++]=$,q[H++]=Q,q[H++]=Z,q[H++]=0,q[H++]=tt,q[H++]=O,q[H++]=z,q[H++]=I,R[0]=Math.min(R[0],$+this.objectOffset[0]),R[1]=Math.min(R[1],Q+this.objectOffset[1]),R[2]=Math.min(R[2],Z+this.objectOffset[2]),N=Math.min(N,tt),F[0]=Math.max(F[0],$+this.objectOffset[0]),F[1]=Math.max(F[1],Q+this.objectOffset[1]),F[2]=Math.max(F[2],Z+this.objectOffset[2]),U=Math.max(U,tt),G+=1}}for(t.intensityBounds&&(N=+t.intensityBounds[0],U=+t.intensityBounds[1]),o=6;o<H;o+=10)q[o]=(q[o]-N)/(U-N);this._vertexCount=G,this._coordinateBuffer.update(q.subarray(0,H)),s.freeFloat(q),s.free(k.data),this.bounds=[R,F],this.intensity=t.intensity||this._field[2],this.intensityBounds[0]===N&&this.intensityBounds[1]===U||(r=!0),this.intensityBounds=[N,U]}if(\"levels\"in t){var et=t.levels;for(et=Array.isArray(et[0])?et.slice():[[],[],et],o=0;o<3;++o)et[o]=et[o].slice(),et[o].sort(function(t,e){return t-e});for(o=0;o<3;++o)for(b=0;b<et[o].length;++b)et[o][b]-=this.objectOffset[o];t:for(o=0;o<3;++o){if(et[o].length!==this.contourLevels[o].length){r=!0;break}for(b=0;b<et[o].length;++b)if(et[o][b]!==this.contourLevels[o][b]){r=!0;break t}}this.contourLevels=et}if(r){_=this._field,a=this.shape;for(var rt=[],nt=0;nt<3;++nt){var it=this.contourLevels[nt],at=[],ot=[],st=[0,0,0];for(o=0;o<it.length;++o){var lt=f(this._field[nt],it[o]);at.push(rt.length/5|0),G=0;t:for(b=0;b<lt.cells.length;++b){var ct=lt.cells[b];for(X=0;X<2;++X){var ut=lt.positions[ct[X]],ht=ut[0],ft=0|Math.floor(ht),pt=ht-ft,dt=ut[1],gt=0|Math.floor(dt),vt=dt-gt,mt=!1;e:for(var yt=0;yt<3;++yt){st[yt]=0;var xt=(nt+yt+1)%3;for(Y=0;Y<2;++Y){var bt=Y?pt:1-pt;for(J=0|Math.min(Math.max(ft+Y,0),a[0]),W=0;W<2;++W){var _t=W?vt:1-vt;if(K=0|Math.min(Math.max(gt+W,0),a[1]),Z=yt<2?this._field[xt].get(J,K):(this.intensity.get(J,K)-this.intensityBounds[0])/(this.intensityBounds[1]-this.intensityBounds[0]),!isFinite(Z)||isNaN(Z)){mt=!0;break e}var wt=bt*_t;st[yt]+=wt*Z}}}if(mt){if(X>0){for(var kt=0;kt<5;++kt)rt.pop();G-=1}continue t}rt.push(st[0],st[1],ut[0],ut[1],st[2]),G+=1}}ot.push(G)}this._contourOffsets[nt]=at,this._contourCounts[nt]=ot}var Tt=s.mallocFloat(rt.length);for(o=0;o<rt.length;++o)Tt[o]=rt[o];this._contourBuffer.update(Tt),s.freeFloat(Tt)}t.colormap&&this._colorMap.setPixels(function(t){var e=u([l({colormap:t,nshades:S,format:\"rgba\"}).map(function(t){return[t[0],t[1],t[2],255*t[3]]})]);return c.divseq(e,255),e}(t.colormap))},C.dispose=function(){this._shader.dispose(),this._vao.dispose(),this._coordinateBuffer.dispose(),this._colorMap.dispose(),this._contourBuffer.dispose(),this._contourVAO.dispose(),this._contourShader.dispose(),this._contourPickShader.dispose(),this._dynamicBuffer.dispose(),this._dynamicVAO.dispose();for(var t=0;t<3;++t)s.freeFloat(this._field[t].data)},C.highlight=function(t){var e,r;if(!t)return this._dynamicCounts=[0,0,0],this.dyanamicLevel=[NaN,NaN,NaN],void(this.highlightLevel=[-1,-1,-1]);for(e=0;e<3;++e)this.enableHighlight[e]?this.highlightLevel[e]=t.level[e]:this.highlightLevel[e]=-1;for(r=this.snapToData?t.dataCoordinate:t.position,e=0;e<3;++e)r[e]-=this.objectOffset[e];if(this.enableDynamic[0]&&r[0]!==this.dynamicLevel[0]||this.enableDynamic[1]&&r[1]!==this.dynamicLevel[1]||this.enableDynamic[2]&&r[2]!==this.dynamicLevel[2]){for(var n=0,i=this.shape,a=s.mallocFloat(12*i[0]*i[1]),o=0;o<3;++o)if(this.enableDynamic[o]){this.dynamicLevel[o]=r[o];var l=(o+1)%3,c=(o+2)%3,u=this._field[o],h=this._field[l],p=this._field[c],d=f(u,r[o]),g=d.cells,v=d.positions;for(this._dynamicOffsets[o]=n,e=0;e<g.length;++e)for(var m=g[e],y=0;y<2;++y){var x=v[m[y]],b=+x[0],_=0|b,w=0|Math.min(_+1,i[0]),k=b-_,T=1-k,A=+x[1],M=0|A,S=0|Math.min(M+1,i[1]),E=A-M,C=1-E,L=T*C,P=T*E,O=k*C,z=k*E,I=L*h.get(_,M)+P*h.get(_,S)+O*h.get(w,M)+z*h.get(w,S),D=L*p.get(_,M)+P*p.get(_,S)+O*p.get(w,M)+z*p.get(w,S);if(isNaN(I)||isNaN(D)){y&&(n-=1);break}a[2*n+0]=I,a[2*n+1]=D,n+=1}this._dynamicCounts[o]=n-this._dynamicOffsets[o]}else this.dynamicLevel[o]=NaN,this._dynamicCounts[o]=0;this._dynamicBuffer.update(a.subarray(0,2*n)),s.freeFloat(a)}}},{\"./lib/shaders\":314,\"binary-search-bounds\":315,\"bit-twiddle\":92,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,\"ndarray-gradient\":441,\"ndarray-ops\":444,\"ndarray-pack\":445,\"surface-nets\":531,\"typedarray-pool\":545}],317:[function(t,e,r){\"use strict\";var n=t(\"css-font\"),i=t(\"pick-by-alias\"),a=t(\"regl\"),o=t(\"gl-util/context\"),s=t(\"es6-weak-map\"),l=t(\"color-normalize\"),c=t(\"font-atlas\"),u=t(\"typedarray-pool\"),h=t(\"parse-rect\"),f=t(\"is-plain-obj\"),p=t(\"parse-unit\"),d=t(\"to-px\"),g=t(\"detect-kerning\"),v=t(\"object-assign\"),m=t(\"font-measure\"),y=t(\"flatten-vertex-data\"),x=t(\"bit-twiddle\").nextPow2,b=new s,_=!1;if(document.body){var w=document.body.appendChild(document.createElement(\"div\"));w.style.font=\"italic small-caps bold condensed 16px/2 cursive\",getComputedStyle(w).fontStretch&&(_=!0),document.body.removeChild(w)}var k=function(t){!function(t){return\"function\"==typeof t&&t._gl&&t.prop&&t.texture&&t.buffer}(t)?this.gl=o(t):(t={regl:t},this.gl=t.regl._gl),this.shader=b.get(this.gl),this.shader?this.regl=this.shader.regl:this.regl=t.regl||a({gl:this.gl}),this.charBuffer=this.regl.buffer({type:\"uint8\",usage:\"stream\"}),this.sizeBuffer=this.regl.buffer({type:\"float\",usage:\"stream\"}),this.shader||(this.shader=this.createShader(),b.set(this.gl,this.shader)),this.batch=[],this.fontSize=[],this.font=[],this.fontAtlas=[],this.draw=this.shader.draw.bind(this),this.render=function(){this.regl._refresh(),this.draw(this.batch)},this.canvas=this.gl.canvas,this.update(f(t)?t:{})};k.prototype.createShader=function(){var t=this.regl,e=t({blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},stencil:{enable:!1},depth:{enable:!1},count:t.prop(\"count\"),offset:t.prop(\"offset\"),attributes:{charOffset:{offset:4,stride:8,buffer:t.this(\"sizeBuffer\")},width:{offset:0,stride:8,buffer:t.this(\"sizeBuffer\")},char:t.this(\"charBuffer\"),position:t.this(\"position\")},uniforms:{atlasSize:function(t,e){return[e.atlas.width,e.atlas.height]},atlasDim:function(t,e){return[e.atlas.cols,e.atlas.rows]},atlas:function(t,e){return e.atlas.texture},charStep:function(t,e){return e.atlas.step},em:function(t,e){return e.atlas.em},color:t.prop(\"color\"),opacity:t.prop(\"opacity\"),viewport:t.this(\"viewportArray\"),scale:t.this(\"scale\"),align:t.prop(\"align\"),baseline:t.prop(\"baseline\"),translate:t.this(\"translate\"),positionOffset:t.prop(\"positionOffset\")},primitive:\"points\",viewport:t.this(\"viewport\"),vert:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tattribute float width, charOffset, char;\\n\\t\\t\\tattribute vec2 position;\\n\\t\\t\\tuniform float fontSize, charStep, em, align, baseline;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tuniform vec4 color;\\n\\t\\t\\tuniform vec2 atlasSize, atlasDim, scale, translate, positionOffset;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\t\"+(k.normalViewport?\"\":\"vec2 positionOffset = vec2(positionOffset.x,- positionOffset.y);\")+\"\\n\\n\\t\\t\\t\\tvec2 offset = floor(em * (vec2(align + charOffset, baseline)\\n\\t\\t\\t\\t\\t+ positionOffset))\\n\\t\\t\\t\\t\\t/ (viewport.zw * scale.xy);\\n\\n\\t\\t\\t\\tvec2 position = (position + translate) * scale;\\n\\t\\t\\t\\tposition += offset * scale;\\n\\n\\t\\t\\t\\t\"+(k.normalViewport?\"position.y = 1. - position.y;\":\"\")+\"\\n\\n\\t\\t\\t\\tcharCoord = position * viewport.zw + viewport.xy;\\n\\n\\t\\t\\t\\tgl_Position = vec4(position * 2. - 1., 0, 1);\\n\\n\\t\\t\\t\\tgl_PointSize = charStep;\\n\\n\\t\\t\\t\\tcharId.x = mod(char, atlasDim.x);\\n\\t\\t\\t\\tcharId.y = floor(char / atlasDim.x);\\n\\n\\t\\t\\t\\tcharWidth = width * em;\\n\\n\\t\\t\\t\\tfontColor = color / 255.;\\n\\t\\t\\t}\",frag:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tuniform sampler2D atlas;\\n\\t\\t\\tuniform float fontSize, charStep, opacity;\\n\\t\\t\\tuniform vec2 atlasSize;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\n\\t\\t\\tfloat lightness(vec4 color) {\\n\\t\\t\\t\\treturn color.r * 0.299 + color.g * 0.587 + color.b * 0.114;\\n\\t\\t\\t}\\n\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\tvec2 uv = gl_FragCoord.xy - charCoord + charStep * .5;\\n\\t\\t\\t\\tfloat halfCharStep = floor(charStep * .5 + .5);\\n\\n\\t\\t\\t\\t// invert y and shift by 1px (FF expecially needs that)\\n\\t\\t\\t\\tuv.y = charStep - uv.y;\\n\\n\\t\\t\\t\\t// ignore points outside of character bounding box\\n\\t\\t\\t\\tfloat halfCharWidth = ceil(charWidth * .5);\\n\\t\\t\\t\\tif (floor(uv.x) > halfCharStep + halfCharWidth ||\\n\\t\\t\\t\\t\\tfloor(uv.x) < halfCharStep - halfCharWidth) return;\\n\\n\\t\\t\\t\\tuv += charId * charStep;\\n\\t\\t\\t\\tuv = uv / atlasSize;\\n\\n\\t\\t\\t\\tvec4 color = fontColor;\\n\\t\\t\\t\\tvec4 mask = texture2D(atlas, uv);\\n\\n\\t\\t\\t\\tfloat maskY = lightness(mask);\\n\\t\\t\\t\\t// float colorY = lightness(color);\\n\\t\\t\\t\\tcolor.a *= maskY;\\n\\t\\t\\t\\tcolor.a *= opacity;\\n\\n\\t\\t\\t\\t// color.a += .1;\\n\\n\\t\\t\\t\\t// antialiasing, see yiq color space y-channel formula\\n\\t\\t\\t\\t// color.rgb += (1. - color.rgb) * (1. - mask.rgb);\\n\\n\\t\\t\\t\\tgl_FragColor = color;\\n\\t\\t\\t}\"});return{regl:t,draw:e,atlas:{}}},k.prototype.update=function(t){var e=this;if(\"string\"==typeof t)t={text:t};else if(!t)return;null!=(t=i(t,{position:\"position positions coord coords coordinates\",font:\"font fontFace fontface typeface cssFont css-font family fontFamily\",fontSize:\"fontSize fontsize size font-size\",text:\"text texts chars characters value values symbols\",align:\"align alignment textAlign textbaseline\",baseline:\"baseline textBaseline textbaseline\",direction:\"dir direction textDirection\",color:\"color colour fill fill-color fillColor textColor textcolor\",kerning:\"kerning kern\",range:\"range dataBox\",viewport:\"vp viewport viewBox viewbox viewPort\",opacity:\"opacity alpha transparency visible visibility opaque\",offset:\"offset positionOffset padding shift indent indentation\"},!0)).opacity&&(Array.isArray(t.opacity)?this.opacity=t.opacity.map(function(t){return parseFloat(t)}):this.opacity=parseFloat(t.opacity)),null!=t.viewport&&(this.viewport=h(t.viewport),k.normalViewport&&(this.viewport.y=this.canvas.height-this.viewport.y-this.viewport.height),this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null==this.viewport&&(this.viewport={x:0,y:0,width:this.gl.drawingBufferWidth,height:this.gl.drawingBufferHeight},this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null!=t.kerning&&(this.kerning=t.kerning),null!=t.offset&&(\"number\"==typeof t.offset&&(t.offset=[t.offset,0]),this.positionOffset=y(t.offset)),t.direction&&(this.direction=t.direction),t.range&&(this.range=t.range,this.scale=[1/(t.range[2]-t.range[0]),1/(t.range[3]-t.range[1])],this.translate=[-t.range[0],-t.range[1]]),t.scale&&(this.scale=t.scale),t.translate&&(this.translate=t.translate),this.scale||(this.scale=[1/this.viewport.width,1/this.viewport.height]),this.translate||(this.translate=[0,0]),this.font.length||t.font||(t.font=k.baseFontSize+\"px sans-serif\");var r,a=!1,o=!1;if(t.font&&(Array.isArray(t.font)?t.font:[t.font]).forEach(function(t,r){if(\"string\"==typeof t)try{t=n.parse(t)}catch(e){t=n.parse(k.baseFontSize+\"px \"+t)}else t=n.parse(n.stringify(t));var i=n.stringify({size:k.baseFontSize,family:t.family,stretch:_?t.stretch:void 0,variant:t.variant,weight:t.weight,style:t.style}),s=p(t.size),l=Math.round(s[0]*d(s[1]));if(l!==e.fontSize[r]&&(o=!0,e.fontSize[r]=l),!(e.font[r]&&i==e.font[r].baseString||(a=!0,e.font[r]=k.fonts[i],e.font[r]))){var c=t.family.join(\", \"),u=[t.style];t.style!=t.variant&&u.push(t.variant),t.variant!=t.weight&&u.push(t.weight),_&&t.weight!=t.stretch&&u.push(t.stretch),e.font[r]={baseString:i,family:c,weight:t.weight,stretch:t.stretch,style:t.style,variant:t.variant,width:{},kerning:{},metrics:m(c,{origin:\"top\",fontSize:k.baseFontSize,fontStyle:u.join(\" \")})},k.fonts[i]=e.font[r]}}),(a||o)&&this.font.forEach(function(r,i){var a=n.stringify({size:e.fontSize[i],family:r.family,stretch:_?r.stretch:void 0,variant:r.variant,weight:r.weight,style:r.style});if(e.fontAtlas[i]=e.shader.atlas[a],!e.fontAtlas[i]){var o=r.metrics;e.shader.atlas[a]=e.fontAtlas[i]={fontString:a,step:2*Math.ceil(e.fontSize[i]*o.bottom*.5),em:e.fontSize[i],cols:0,rows:0,height:0,width:0,chars:[],ids:{},texture:e.regl.texture()}}null==t.text&&(t.text=e.text)}),\"string\"==typeof t.text&&t.position&&t.position.length>2){for(var s=Array(.5*t.position.length),f=0;f<s.length;f++)s[f]=t.text;t.text=s}if(null!=t.text||a){if(this.textOffsets=[0],Array.isArray(t.text)){this.count=t.text[0].length,this.counts=[this.count];for(var b=1;b<t.text.length;b++)this.textOffsets[b]=this.textOffsets[b-1]+t.text[b-1].length,this.count+=t.text[b].length,this.counts.push(t.text[b].length);this.text=t.text.join(\"\")}else this.text=t.text,this.count=this.text.length,this.counts=[this.count];r=[],this.font.forEach(function(t,n){k.atlasContext.font=t.baseString;for(var i=e.fontAtlas[n],a=0;a<e.text.length;a++){var o=e.text.charAt(a);if(null==i.ids[o]&&(i.ids[o]=i.chars.length,i.chars.push(o),r.push(o)),null==t.width[o]&&(t.width[o]=k.atlasContext.measureText(o).width/k.baseFontSize,e.kerning)){var s=[];for(var l in t.width)s.push(l+o,o+l);v(t.kerning,g(t.family,{pairs:s}))}}})}if(t.position)if(t.position.length>2){for(var w=!t.position[0].length,T=u.mallocFloat(2*this.count),A=0,M=0;A<this.counts.length;A++){var S=this.counts[A];if(w)for(var E=0;E<S;E++)T[M++]=t.position[2*A],T[M++]=t.position[2*A+1];else for(var C=0;C<S;C++)T[M++]=t.position[A][0],T[M++]=t.position[A][1]}this.position.call?this.position({type:\"float\",data:T}):this.position=this.regl.buffer({type:\"float\",data:T}),u.freeFloat(T)}else this.position.destroy&&this.position.destroy(),this.position={constant:t.position};if(t.text||a){var L=u.mallocUint8(this.count),P=u.mallocFloat(2*this.count);this.textWidth=[];for(var O=0,z=0;O<this.counts.length;O++){for(var I=this.counts[O],D=this.font[O]||this.font[0],R=this.fontAtlas[O]||this.fontAtlas[0],F=0;F<I;F++){var B=this.text.charAt(z),N=this.text.charAt(z-1);if(L[z]=R.ids[B],P[2*z]=D.width[B],F){var j=P[2*z-2],U=P[2*z],V=P[2*z-1]+.5*j+.5*U;if(this.kerning){var q=D.kerning[N+B];q&&(V+=.001*q)}P[2*z+1]=V}else P[2*z+1]=.5*P[2*z];z++}this.textWidth.push(P.length?.5*P[2*z-2]+P[2*z-1]:0)}t.align||(t.align=this.align),this.charBuffer({data:L,type:\"uint8\",usage:\"stream\"}),this.sizeBuffer({data:P,type:\"float\",usage:\"stream\"}),u.freeUint8(L),u.freeFloat(P),r.length&&this.font.forEach(function(t,r){var n=e.fontAtlas[r],i=n.step,a=Math.floor(k.maxAtlasSize/i),o=Math.min(a,n.chars.length),s=Math.ceil(n.chars.length/o),l=x(o*i),u=x(s*i);n.width=l,n.height=u,n.rows=s,n.cols=o,n.em&&n.texture({data:c({canvas:k.atlasCanvas,font:n.fontString,chars:n.chars,shape:[l,u],step:[i,i]})})})}if(t.align&&(this.align=t.align,this.alignOffset=this.textWidth.map(function(t,r){var n=Array.isArray(e.align)?e.align.length>1?e.align[r]:e.align[0]:e.align;if(\"number\"==typeof n)return n;switch(n){case\"right\":case\"end\":return-t;case\"center\":case\"centre\":case\"middle\":return.5*-t}return 0})),null==this.baseline&&null==t.baseline&&(t.baseline=0),null!=t.baseline&&(this.baseline=t.baseline,Array.isArray(this.baseline)||(this.baseline=[this.baseline]),this.baselineOffset=this.baseline.map(function(t,r){var n=(e.font[r]||e.font[0]).metrics,i=0;return i+=.5*n.bottom,i+=\"number\"==typeof t?t-n.baseline:-n[t],k.normalViewport||(i*=-1),i})),null!=t.color)if(t.color||(t.color=\"transparent\"),\"string\"!=typeof t.color&&isNaN(t.color)){var H;if(\"number\"==typeof t.color[0]&&t.color.length>this.counts.length){var G=t.color.length;H=u.mallocUint8(G);for(var Y=(t.color.subarray||t.color.slice).bind(t.color),W=0;W<G;W+=4)H.set(l(Y(W,W+4),\"uint8\"),W)}else{var X=t.color.length;H=u.mallocUint8(4*X);for(var Z=0;Z<X;Z++)H.set(l(t.color[Z]||0,\"uint8\"),4*Z)}this.color=H}else this.color=l(t.color,\"uint8\");if(t.position||t.text||t.color||t.baseline||t.align||t.font||t.offset||t.opacity)if(this.color.length>4||this.baselineOffset.length>1||this.align&&this.align.length>1||this.fontAtlas.length>1||this.positionOffset.length>2){var J=Math.max(.5*this.position.length||0,.25*this.color.length||0,this.baselineOffset.length||0,this.alignOffset.length||0,this.font.length||0,this.opacity.length||0,.5*this.positionOffset.length||0);this.batch=Array(J);for(var K=0;K<this.batch.length;K++)this.batch[K]={count:this.counts.length>1?this.counts[K]:this.counts[0],offset:this.textOffsets.length>1?this.textOffsets[K]:this.textOffsets[0],color:this.color?this.color.length<=4?this.color:this.color.subarray(4*K,4*K+4):[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[K]:this.opacity,baseline:null!=this.baselineOffset[K]?this.baselineOffset[K]:this.baselineOffset[0],align:this.align?null!=this.alignOffset[K]?this.alignOffset[K]:this.alignOffset[0]:0,atlas:this.fontAtlas[K]||this.fontAtlas[0],positionOffset:this.positionOffset.length>2?this.positionOffset.subarray(2*K,2*K+2):this.positionOffset}}else this.count?this.batch=[{count:this.count,offset:0,color:this.color||[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[0]:this.opacity,baseline:this.baselineOffset[0],align:this.alignOffset?this.alignOffset[0]:0,atlas:this.fontAtlas[0],positionOffset:this.positionOffset}]:this.batch=[]},k.prototype.destroy=function(){},k.prototype.kerning=!0,k.prototype.position={constant:new Float32Array(2)},k.prototype.translate=null,k.prototype.scale=null,k.prototype.font=null,k.prototype.text=\"\",k.prototype.positionOffset=[0,0],k.prototype.opacity=1,k.prototype.color=new Uint8Array([0,0,0,255]),k.prototype.alignOffset=[0,0],k.normalViewport=!1,k.maxAtlasSize=1024,k.atlasCanvas=document.createElement(\"canvas\"),k.atlasContext=k.atlasCanvas.getContext(\"2d\",{alpha:!1}),k.baseFontSize=64,k.fonts={},e.exports=k},{\"bit-twiddle\":92,\"color-normalize\":120,\"css-font\":139,\"detect-kerning\":166,\"es6-weak-map\":318,\"flatten-vertex-data\":227,\"font-atlas\":228,\"font-measure\":229,\"gl-util/context\":323,\"is-plain-obj\":422,\"object-assign\":454,\"parse-rect\":459,\"parse-unit\":461,\"pick-by-alias\":465,regl:502,\"to-px\":539,\"typedarray-pool\":545}],318:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?WeakMap:t(\"./polyfill\")},{\"./is-implemented\":319,\"./polyfill\":321}],319:[function(t,e,r){\"use strict\";e.exports=function(){var t,e;if(\"function\"!=typeof WeakMap)return!1;try{t=new WeakMap([[e={},\"one\"],[{},\"two\"],[{},\"three\"]])}catch(t){return!1}return\"[object WeakMap]\"===String(t)&&(\"function\"==typeof t.set&&(t.set({},1)===t&&(\"function\"==typeof t.delete&&(\"function\"==typeof t.has&&\"one\"===t.get(e)))))}},{}],320:[function(t,e,r){\"use strict\";e.exports=\"function\"==typeof WeakMap&&\"[object WeakMap]\"===Object.prototype.toString.call(new WeakMap)},{}],321:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/object/set-prototype-of\"),o=t(\"es5-ext/object/valid-object\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"es5-ext/string/random-uniq\"),c=t(\"d\"),u=t(\"es6-iterator/get\"),h=t(\"es6-iterator/for-of\"),f=t(\"es6-symbol\").toStringTag,p=t(\"./is-native-implemented\"),d=Array.isArray,g=Object.defineProperty,v=Object.prototype.hasOwnProperty,m=Object.getPrototypeOf;e.exports=n=function(){var t,e=arguments[0];if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");return t=p&&a&&WeakMap!==n?a(new WeakMap,m(this)):this,i(e)&&(d(e)||(e=u(e))),g(t,\"__weakMapData__\",c(\"c\",\"$weakMap$\"+l())),e?(h(e,function(e){s(e),t.set(e[0],e[1])}),t):t},p&&(a&&a(n,WeakMap),n.prototype=Object.create(WeakMap.prototype,{constructor:c(n)})),Object.defineProperties(n.prototype,{delete:c(function(t){return!!v.call(o(t),this.__weakMapData__)&&(delete t[this.__weakMapData__],!0)}),get:c(function(t){if(v.call(o(t),this.__weakMapData__))return t[this.__weakMapData__]}),has:c(function(t){return v.call(o(t),this.__weakMapData__)}),set:c(function(t,e){return g(o(t),this.__weakMapData__,c(\"c\",e)),this}),toString:c(function(){return\"[object WeakMap]\"})}),g(n.prototype,f,c(\"c\",\"WeakMap\"))},{\"./is-native-implemented\":320,d:151,\"es5-ext/object/is-value\":194,\"es5-ext/object/set-prototype-of\":200,\"es5-ext/object/valid-object\":204,\"es5-ext/object/valid-value\":205,\"es5-ext/string/random-uniq\":210,\"es6-iterator/for-of\":212,\"es6-iterator/get\":213,\"es6-symbol\":219}],322:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"ndarray-ops\"),a=t(\"typedarray-pool\");e.exports=function(t){if(arguments.length<=1)throw new Error(\"gl-texture2d: Missing arguments for texture2d constructor\");o||function(t){o=[t.LINEAR,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_NEAREST],s=[t.NEAREST,t.LINEAR,t.NEAREST_MIPMAP_NEAREST,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_LINEAR],l=[t.REPEAT,t.CLAMP_TO_EDGE,t.MIRRORED_REPEAT]}(t);if(\"number\"==typeof arguments[1])return v(t,arguments[1],arguments[2],arguments[3]||t.RGBA,arguments[4]||t.UNSIGNED_BYTE);if(Array.isArray(arguments[1]))return v(t,0|arguments[1][0],0|arguments[1][1],arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(\"object\"==typeof arguments[1]){var e=arguments[1],r=c(e)?e:e.raw;if(r)return function(t,e,r,n,i,a){var o=g(t);return t.texImage2D(t.TEXTURE_2D,0,i,i,a,e),new f(t,o,r,n,i,a)}(t,r,0|e.width,0|e.height,arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(e.shape&&e.data&&e.stride)return function(t,e){var r=e.dtype,o=e.shape.slice(),s=t.getParameter(t.MAX_TEXTURE_SIZE);if(o[0]<0||o[0]>s||o[1]<0||o[1]>s)throw new Error(\"gl-texture2d: Invalid texture size\");var l=d(o,e.stride.slice()),c=0;\"float32\"===r?c=t.FLOAT:\"float64\"===r?(c=t.FLOAT,l=!1,r=\"float32\"):\"uint8\"===r?c=t.UNSIGNED_BYTE:(c=t.UNSIGNED_BYTE,l=!1,r=\"uint8\");var h,p,v=0;if(2===o.length)v=t.LUMINANCE,o=[o[0],o[1],1],e=n(e.data,o,[e.stride[0],e.stride[1],1],e.offset);else{if(3!==o.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===o[2])v=t.ALPHA;else if(2===o[2])v=t.LUMINANCE_ALPHA;else if(3===o[2])v=t.RGB;else{if(4!==o[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");v=t.RGBA}}c!==t.FLOAT||t.getExtension(\"OES_texture_float\")||(c=t.UNSIGNED_BYTE,l=!1);var m=e.size;if(l)h=0===e.offset&&e.data.length===m?e.data:e.data.subarray(e.offset,e.offset+m);else{var y=[o[2],o[2]*o[0],1];p=a.malloc(m,r);var x=n(p,o,y,0);\"float32\"!==r&&\"float64\"!==r||c!==t.UNSIGNED_BYTE?i.assign(x,e):u(x,e),h=p.subarray(0,m)}var b=g(t);t.texImage2D(t.TEXTURE_2D,0,v,o[0],o[1],0,v,c,h),l||a.free(p);return new f(t,b,o[0],o[1],v,c)}(t,e)}throw new Error(\"gl-texture2d: Invalid arguments for texture2d constructor\")};var o=null,s=null,l=null;function c(t){return\"undefined\"!=typeof HTMLCanvasElement&&t instanceof HTMLCanvasElement||\"undefined\"!=typeof HTMLImageElement&&t instanceof HTMLImageElement||\"undefined\"!=typeof HTMLVideoElement&&t instanceof HTMLVideoElement||\"undefined\"!=typeof ImageData&&t instanceof ImageData}var u=function(t,e){i.muls(t,e,255)};function h(t,e,r){var n=t.gl,i=n.getParameter(n.MAX_TEXTURE_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-texture2d: Invalid texture size\");return t._shape=[e,r],t.bind(),n.texImage2D(n.TEXTURE_2D,0,t.format,e,r,0,t.format,t.type,null),t._mipLevels=[0],t}function f(t,e,r,n,i,a){this.gl=t,this.handle=e,this.format=i,this.type=a,this._shape=[r,n],this._mipLevels=[0],this._magFilter=t.NEAREST,this._minFilter=t.NEAREST,this._wrapS=t.CLAMP_TO_EDGE,this._wrapT=t.CLAMP_TO_EDGE,this._anisoSamples=1;var o=this,s=[this._wrapS,this._wrapT];Object.defineProperties(s,[{get:function(){return o._wrapS},set:function(t){return o.wrapS=t}},{get:function(){return o._wrapT},set:function(t){return o.wrapT=t}}]),this._wrapVector=s;var l=[this._shape[0],this._shape[1]];Object.defineProperties(l,[{get:function(){return o._shape[0]},set:function(t){return o.width=t}},{get:function(){return o._shape[1]},set:function(t){return o.height=t}}]),this._shapeVector=l}var p=f.prototype;function d(t,e){return 3===t.length?1===e[2]&&e[1]===t[0]*t[2]&&e[0]===t[2]:1===e[0]&&e[1]===t[0]}function g(t){var e=t.createTexture();return t.bindTexture(t.TEXTURE_2D,e),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MIN_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MAG_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_S,t.CLAMP_TO_EDGE),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_T,t.CLAMP_TO_EDGE),e}function v(t,e,r,n,i){var a=t.getParameter(t.MAX_TEXTURE_SIZE);if(e<0||e>a||r<0||r>a)throw new Error(\"gl-texture2d: Invalid texture shape\");if(i===t.FLOAT&&!t.getExtension(\"OES_texture_float\"))throw new Error(\"gl-texture2d: Floating point textures not supported on this platform\");var o=g(t);return t.texImage2D(t.TEXTURE_2D,0,n,e,r,0,n,i,null),new f(t,o,e,r,n,i)}Object.defineProperties(p,{minFilter:{get:function(){return this._minFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,t),this._minFilter=t}},magFilter:{get:function(){return this._magFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,t),this._magFilter=t}},mipSamples:{get:function(){return this._anisoSamples},set:function(t){var e=this._anisoSamples;if(this._anisoSamples=0|Math.max(t,1),e!==this._anisoSamples){var r=this.gl.getExtension(\"EXT_texture_filter_anisotropic\");r&&this.gl.texParameterf(this.gl.TEXTURE_2D,r.TEXTURE_MAX_ANISOTROPY_EXT,this._anisoSamples)}return this._anisoSamples}},wrapS:{get:function(){return this._wrapS},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_S,t),this._wrapS=t}},wrapT:{get:function(){return this._wrapT},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_T,t),this._wrapT=t}},wrap:{get:function(){return this._wrapVector},set:function(t){if(Array.isArray(t)||(t=[t,t]),2!==t.length)throw new Error(\"gl-texture2d: Must specify wrap mode for rows and columns\");for(var e=0;e<2;++e)if(l.indexOf(t[e])<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);this._wrapS=t[0],this._wrapT=t[1];var r=this.gl;return this.bind(),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_S,this._wrapS),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_T,this._wrapT),t}},shape:{get:function(){return this._shapeVector},set:function(t){if(Array.isArray(t)){if(2!==t.length)throw new Error(\"gl-texture2d: Invalid texture shape\")}else t=[0|t,0|t];return h(this,0|t[0],0|t[1]),[0|t[0],0|t[1]]}},width:{get:function(){return this._shape[0]},set:function(t){return h(this,t|=0,this._shape[1]),t}},height:{get:function(){return this._shape[1]},set:function(t){return t|=0,h(this,this._shape[0],t),t}}}),p.bind=function(t){var e=this.gl;return void 0!==t&&e.activeTexture(e.TEXTURE0+(0|t)),e.bindTexture(e.TEXTURE_2D,this.handle),void 0!==t?0|t:e.getParameter(e.ACTIVE_TEXTURE)-e.TEXTURE0},p.dispose=function(){this.gl.deleteTexture(this.handle)},p.generateMipmap=function(){this.bind(),this.gl.generateMipmap(this.gl.TEXTURE_2D);for(var t=Math.min(this._shape[0],this._shape[1]),e=0;t>0;++e,t>>>=1)this._mipLevels.indexOf(e)<0&&this._mipLevels.push(e)},p.setPixels=function(t,e,r,o){var s=this.gl;this.bind(),Array.isArray(e)?(o=r,r=0|e[1],e=0|e[0]):(e=e||0,r=r||0),o=o||0;var l=c(t)?t:t.raw;if(l){this._mipLevels.indexOf(o)<0?(s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,this.type,l),this._mipLevels.push(o)):s.texSubImage2D(s.TEXTURE_2D,o,e,r,this.format,this.type,l)}else{if(!(t.shape&&t.stride&&t.data))throw new Error(\"gl-texture2d: Unsupported data type\");if(t.shape.length<2||e+t.shape[1]>this._shape[1]>>>o||r+t.shape[0]>this._shape[0]>>>o||e<0||r<0)throw new Error(\"gl-texture2d: Texture dimensions are out of bounds\");!function(t,e,r,o,s,l,c,h){var f=h.dtype,p=h.shape.slice();if(p.length<2||p.length>3)throw new Error(\"gl-texture2d: Invalid ndarray, must be 2d or 3d\");var g=0,v=0,m=d(p,h.stride.slice());\"float32\"===f?g=t.FLOAT:\"float64\"===f?(g=t.FLOAT,m=!1,f=\"float32\"):\"uint8\"===f?g=t.UNSIGNED_BYTE:(g=t.UNSIGNED_BYTE,m=!1,f=\"uint8\");if(2===p.length)v=t.LUMINANCE,p=[p[0],p[1],1],h=n(h.data,p,[h.stride[0],h.stride[1],1],h.offset);else{if(3!==p.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===p[2])v=t.ALPHA;else if(2===p[2])v=t.LUMINANCE_ALPHA;else if(3===p[2])v=t.RGB;else{if(4!==p[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");v=t.RGBA}p[2]}v!==t.LUMINANCE&&v!==t.ALPHA||s!==t.LUMINANCE&&s!==t.ALPHA||(v=s);if(v!==s)throw new Error(\"gl-texture2d: Incompatible texture format for setPixels\");var y=h.size,x=c.indexOf(o)<0;x&&c.push(o);if(g===l&&m)0===h.offset&&h.data.length===y?x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,h.data):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,h.data):x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,h.data.subarray(h.offset,h.offset+y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,h.data.subarray(h.offset,h.offset+y));else{var b;b=l===t.FLOAT?a.mallocFloat32(y):a.mallocUint8(y);var _=n(b,p,[p[2],p[2]*p[0],1]);g===t.FLOAT&&l===t.UNSIGNED_BYTE?u(_,h):i.assign(_,h),x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,b.subarray(0,y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,b.subarray(0,y)),l===t.FLOAT?a.freeFloat32(b):a.freeUint8(b)}}(s,e,r,o,this.format,this.type,this._mipLevels,t)}}},{ndarray:450,\"ndarray-ops\":444,\"typedarray-pool\":545}],323:[function(t,e,r){(function(r){\"use strict\";var n=t(\"pick-by-alias\");function i(t){if(t.container)if(t.container==document.body)document.body.style.width||(t.canvas.width=t.width||t.pixelRatio*r.innerWidth),document.body.style.height||(t.canvas.height=t.height||t.pixelRatio*r.innerHeight);else{var e=t.container.getBoundingClientRect();t.canvas.width=t.width||e.right-e.left,t.canvas.height=t.height||e.bottom-e.top}}function a(t){return\"function\"==typeof t.getContext&&\"width\"in t&&\"height\"in t}function o(){var t=document.createElement(\"canvas\");return t.style.position=\"absolute\",t.style.top=0,t.style.left=0,t}e.exports=function(t){var e;if(t?\"string\"==typeof t&&(t={container:t}):t={},a(t)?t={container:t}:t=\"string\"==typeof(e=t).nodeName&&\"function\"==typeof e.appendChild&&\"function\"==typeof e.getBoundingClientRect?{container:t}:function(t){return\"function\"==typeof t.drawArrays||\"function\"==typeof t.drawElements}(t)?{gl:t}:n(t,{container:\"container target element el canvas holder parent parentNode wrapper use ref root node\",gl:\"gl context webgl glContext\",attrs:\"attributes attrs contextAttributes\",pixelRatio:\"pixelRatio pxRatio px ratio pxratio pixelratio\",width:\"w width\",height:\"h height\"},!0),t.pixelRatio||(t.pixelRatio=r.pixelRatio||1),t.gl)return t.gl;if(t.canvas&&(t.container=t.canvas.parentNode),t.container){if(\"string\"==typeof t.container){var s=document.querySelector(t.container);if(!s)throw Error(\"Element \"+t.container+\" is not found\");t.container=s}a(t.container)?(t.canvas=t.container,t.container=t.canvas.parentNode):t.canvas||(t.canvas=o(),t.container.appendChild(t.canvas),i(t))}else if(!t.canvas){if(\"undefined\"==typeof document)throw Error(\"Not DOM environment. Use headless-gl.\");t.container=document.body||document.documentElement,t.canvas=o(),t.container.appendChild(t.canvas),i(t)}if(!t.gl)try{t.gl=t.canvas.getContext(\"webgl\",t.attrs)}catch(e){try{t.gl=t.canvas.getContext(\"experimental-webgl\",t.attrs)}catch(e){t.gl=t.canvas.getContext(\"webgl-experimental\",t.attrs)}}return t.gl}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"pick-by-alias\":465}],324:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){e?e.bind():t.bindBuffer(t.ELEMENT_ARRAY_BUFFER,null);var n=0|t.getParameter(t.MAX_VERTEX_ATTRIBS);if(r){if(r.length>n)throw new Error(\"gl-vao: Too many vertex attributes\");for(var i=0;i<r.length;++i){var a=r[i];if(a.buffer){var o=a.buffer,s=a.size||4,l=a.type||t.FLOAT,c=!!a.normalized,u=a.stride||0,h=a.offset||0;o.bind(),t.enableVertexAttribArray(i),t.vertexAttribPointer(i,s,l,c,u,h)}else{if(\"number\"==typeof a)t.vertexAttrib1f(i,a);else if(1===a.length)t.vertexAttrib1f(i,a[0]);else if(2===a.length)t.vertexAttrib2f(i,a[0],a[1]);else if(3===a.length)t.vertexAttrib3f(i,a[0],a[1],a[2]);else{if(4!==a.length)throw new Error(\"gl-vao: Invalid vertex attribute\");t.vertexAttrib4f(i,a[0],a[1],a[2],a[3])}t.disableVertexAttribArray(i)}}for(;i<n;++i)t.disableVertexAttribArray(i)}else for(t.bindBuffer(t.ARRAY_BUFFER,null),i=0;i<n;++i)t.disableVertexAttribArray(i)}},{}],325:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t){this.gl=t,this._elements=null,this._attributes=null,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(){n(this.gl,this._elements,this._attributes)},i.prototype.update=function(t,e,r){this._elements=e,this._attributes=t,this._elementsType=r||this.gl.UNSIGNED_SHORT},i.prototype.dispose=function(){},i.prototype.unbind=function(){},i.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._elements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t){return new i(t)}},{\"./do-bind.js\":324}],326:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t,e,r,n,i,a){this.location=t,this.dimension=e,this.a=r,this.b=n,this.c=i,this.d=a}function a(t,e,r){this.gl=t,this._ext=e,this.handle=r,this._attribs=[],this._useElements=!1,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(t){switch(this.dimension){case 1:t.vertexAttrib1f(this.location,this.a);break;case 2:t.vertexAttrib2f(this.location,this.a,this.b);break;case 3:t.vertexAttrib3f(this.location,this.a,this.b,this.c);break;case 4:t.vertexAttrib4f(this.location,this.a,this.b,this.c,this.d)}},a.prototype.bind=function(){this._ext.bindVertexArrayOES(this.handle);for(var t=0;t<this._attribs.length;++t)this._attribs[t].bind(this.gl)},a.prototype.unbind=function(){this._ext.bindVertexArrayOES(null)},a.prototype.dispose=function(){this._ext.deleteVertexArrayOES(this.handle)},a.prototype.update=function(t,e,r){if(this.bind(),n(this.gl,e,t),this.unbind(),this._attribs.length=0,t)for(var a=0;a<t.length;++a){var o=t[a];\"number\"==typeof o?this._attribs.push(new i(a,1,o)):Array.isArray(o)&&this._attribs.push(new i(a,o.length,o[0],o[1],o[2],o[3]))}this._useElements=!!e,this._elementsType=r||this.gl.UNSIGNED_SHORT},a.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._useElements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t,e){return new a(t,e,e.createVertexArrayOES())}},{\"./do-bind.js\":324}],327:[function(t,e,r){\"use strict\";var n=t(\"./lib/vao-native.js\"),i=t(\"./lib/vao-emulated.js\");function a(t){this.bindVertexArrayOES=t.bindVertexArray.bind(t),this.createVertexArrayOES=t.createVertexArray.bind(t),this.deleteVertexArrayOES=t.deleteVertexArray.bind(t)}e.exports=function(t,e,r,o){var s,l=t.createVertexArray?new a(t):t.getExtension(\"OES_vertex_array_object\");return(s=l?n(t,l):i(t)).update(e,r,o),s}},{\"./lib/vao-emulated.js\":325,\"./lib/vao-native.js\":326}],328:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t}},{}],329:[function(t,e,r){e.exports=function(t,e){var r=n(t[0],t[1],t[2]),o=n(e[0],e[1],e[2]);i(r,r),i(o,o);var s=a(r,o);return s>1?0:Math.acos(s)};var n=t(\"./fromValues\"),i=t(\"./normalize\"),a=t(\"./dot\")},{\"./dot\":339,\"./fromValues\":345,\"./normalize\":356}],330:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.ceil(e[0]),t[1]=Math.ceil(e[1]),t[2]=Math.ceil(e[2]),t}},{}],331:[function(t,e,r){e.exports=function(t){var e=new Float32Array(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e}},{}],332:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}},{}],333:[function(t,e,r){e.exports=function(){var t=new Float32Array(3);return t[0]=0,t[1]=0,t[2]=0,t}},{}],334:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2];return t[0]=i*l-a*s,t[1]=a*o-n*l,t[2]=n*s-i*o,t}},{}],335:[function(t,e,r){e.exports=t(\"./distance\")},{\"./distance\":336}],336:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return Math.sqrt(r*r+n*n+i*i)}},{}],337:[function(t,e,r){e.exports=t(\"./divide\")},{\"./divide\":338}],338:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t}},{}],339:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}},{}],340:[function(t,e,r){e.exports=1e-6},{}],341:[function(t,e,r){e.exports=function(t,e){var r=t[0],i=t[1],a=t[2],o=e[0],s=e[1],l=e[2];return Math.abs(r-o)<=n*Math.max(1,Math.abs(r),Math.abs(o))&&Math.abs(i-s)<=n*Math.max(1,Math.abs(i),Math.abs(s))&&Math.abs(a-l)<=n*Math.max(1,Math.abs(a),Math.abs(l))};var n=t(\"./epsilon\")},{\"./epsilon\":340}],342:[function(t,e,r){e.exports=function(t,e){return t[0]===e[0]&&t[1]===e[1]&&t[2]===e[2]}},{}],343:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.floor(e[0]),t[1]=Math.floor(e[1]),t[2]=Math.floor(e[2]),t}},{}],344:[function(t,e,r){e.exports=function(t,e,r,i,a,o){var s,l;e||(e=3);r||(r=0);l=i?Math.min(i*e+r,t.length):t.length;for(s=r;s<l;s+=e)n[0]=t[s],n[1]=t[s+1],n[2]=t[s+2],a(n,n,o),t[s]=n[0],t[s+1]=n[1],t[s+2]=n[2];return t};var n=t(\"./create\")()},{\"./create\":333}],345:[function(t,e,r){e.exports=function(t,e,r){var n=new Float32Array(3);return n[0]=t,n[1]=e,n[2]=r,n}},{}],346:[function(t,e,r){e.exports={EPSILON:t(\"./epsilon\"),create:t(\"./create\"),clone:t(\"./clone\"),angle:t(\"./angle\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),equals:t(\"./equals\"),exactEquals:t(\"./exactEquals\"),add:t(\"./add\"),subtract:t(\"./subtract\"),sub:t(\"./sub\"),multiply:t(\"./multiply\"),mul:t(\"./mul\"),divide:t(\"./divide\"),div:t(\"./div\"),min:t(\"./min\"),max:t(\"./max\"),floor:t(\"./floor\"),ceil:t(\"./ceil\"),round:t(\"./round\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),dist:t(\"./dist\"),squaredDistance:t(\"./squaredDistance\"),sqrDist:t(\"./sqrDist\"),length:t(\"./length\"),len:t(\"./len\"),squaredLength:t(\"./squaredLength\"),sqrLen:t(\"./sqrLen\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),cross:t(\"./cross\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformMat3:t(\"./transformMat3\"),transformQuat:t(\"./transformQuat\"),rotateX:t(\"./rotateX\"),rotateY:t(\"./rotateY\"),rotateZ:t(\"./rotateZ\"),forEach:t(\"./forEach\")}},{\"./add\":328,\"./angle\":329,\"./ceil\":330,\"./clone\":331,\"./copy\":332,\"./create\":333,\"./cross\":334,\"./dist\":335,\"./distance\":336,\"./div\":337,\"./divide\":338,\"./dot\":339,\"./epsilon\":340,\"./equals\":341,\"./exactEquals\":342,\"./floor\":343,\"./forEach\":344,\"./fromValues\":345,\"./inverse\":347,\"./len\":348,\"./length\":349,\"./lerp\":350,\"./max\":351,\"./min\":352,\"./mul\":353,\"./multiply\":354,\"./negate\":355,\"./normalize\":356,\"./random\":357,\"./rotateX\":358,\"./rotateY\":359,\"./rotateZ\":360,\"./round\":361,\"./scale\":362,\"./scaleAndAdd\":363,\"./set\":364,\"./sqrDist\":365,\"./sqrLen\":366,\"./squaredDistance\":367,\"./squaredLength\":368,\"./sub\":369,\"./subtract\":370,\"./transformMat3\":371,\"./transformMat4\":372,\"./transformQuat\":373}],347:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t}},{}],348:[function(t,e,r){e.exports=t(\"./length\")},{\"./length\":349}],349:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return Math.sqrt(e*e+r*r+n*n)}},{}],350:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t}},{}],351:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t}},{}],352:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t}},{}],353:[function(t,e,r){e.exports=t(\"./multiply\")},{\"./multiply\":354}],354:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t}},{}],355:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t}},{}],356:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=r*r+n*n+i*i;a>0&&(a=1/Math.sqrt(a),t[0]=e[0]*a,t[1]=e[1]*a,t[2]=e[2]*a);return t}},{}],357:[function(t,e,r){e.exports=function(t,e){e=e||1;var r=2*Math.random()*Math.PI,n=2*Math.random()-1,i=Math.sqrt(1-n*n)*e;return t[0]=Math.cos(r)*i,t[1]=Math.sin(r)*i,t[2]=n*e,t}},{}],358:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[1],a=r[2],o=e[1]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=e[0],t[1]=i+o*c-s*l,t[2]=a+o*l+s*c,t}},{}],359:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[2],o=e[0]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+s*l+o*c,t[1]=e[1],t[2]=a+s*c-o*l,t}},{}],360:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[1],o=e[0]-i,s=e[1]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+o*c-s*l,t[1]=a+o*l+s*c,t[2]=e[2],t}},{}],361:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.round(e[0]),t[1]=Math.round(e[1]),t[2]=Math.round(e[2]),t}},{}],362:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t}},{}],363:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t}},{}],364:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e,t[1]=r,t[2]=n,t}},{}],365:[function(t,e,r){e.exports=t(\"./squaredDistance\")},{\"./squaredDistance\":367}],366:[function(t,e,r){e.exports=t(\"./squaredLength\")},{\"./squaredLength\":368}],367:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return r*r+n*n+i*i}},{}],368:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return e*e+r*r+n*n}},{}],369:[function(t,e,r){e.exports=t(\"./subtract\")},{\"./subtract\":370}],370:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t}},{}],371:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t}},{}],372:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[3]*n+r[7]*i+r[11]*a+r[15];return o=o||1,t[0]=(r[0]*n+r[4]*i+r[8]*a+r[12])/o,t[1]=(r[1]*n+r[5]*i+r[9]*a+r[13])/o,t[2]=(r[2]*n+r[6]*i+r[10]*a+r[14])/o,t}},{}],373:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,h=c*i+l*n-o*a,f=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+h*-l-f*-s,t[1]=h*c+p*-s+f*-o-u*-l,t[2]=f*c+p*-l+u*-s-h*-o,t}},{}],374:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t[3]=e[3]+r[3],t}},{}],375:[function(t,e,r){e.exports=function(t){var e=new Float32Array(4);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e}},{}],376:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t}},{}],377:[function(t,e,r){e.exports=function(){var t=new Float32Array(4);return t[0]=0,t[1]=0,t[2]=0,t[3]=0,t}},{}],378:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return Math.sqrt(r*r+n*n+i*i+a*a)}},{}],379:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t[3]=e[3]/r[3],t}},{}],380:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}},{}],381:[function(t,e,r){e.exports=function(t,e,r,n){var i=new Float32Array(4);return i[0]=t,i[1]=e,i[2]=r,i[3]=n,i}},{}],382:[function(t,e,r){e.exports={create:t(\"./create\"),clone:t(\"./clone\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),add:t(\"./add\"),subtract:t(\"./subtract\"),multiply:t(\"./multiply\"),divide:t(\"./divide\"),min:t(\"./min\"),max:t(\"./max\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),squaredDistance:t(\"./squaredDistance\"),length:t(\"./length\"),squaredLength:t(\"./squaredLength\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformQuat:t(\"./transformQuat\")}},{\"./add\":374,\"./clone\":375,\"./copy\":376,\"./create\":377,\"./distance\":378,\"./divide\":379,\"./dot\":380,\"./fromValues\":381,\"./inverse\":383,\"./length\":384,\"./lerp\":385,\"./max\":386,\"./min\":387,\"./multiply\":388,\"./negate\":389,\"./normalize\":390,\"./random\":391,\"./scale\":392,\"./scaleAndAdd\":393,\"./set\":394,\"./squaredDistance\":395,\"./squaredLength\":396,\"./subtract\":397,\"./transformMat4\":398,\"./transformQuat\":399}],383:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t[3]=1/e[3],t}},{}],384:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return Math.sqrt(e*e+r*r+n*n+i*i)}},{}],385:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2],s=e[3];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t[3]=s+n*(r[3]-s),t}},{}],386:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t[3]=Math.max(e[3],r[3]),t}},{}],387:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t[3]=Math.min(e[3],r[3]),t}},{}],388:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t[3]=e[3]*r[3],t}},{}],389:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t[3]=-e[3],t}},{}],390:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r*r+n*n+i*i+a*a;o>0&&(o=1/Math.sqrt(o),t[0]=r*o,t[1]=n*o,t[2]=i*o,t[3]=a*o);return t}},{}],391:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"./scale\");e.exports=function(t,e){return e=e||1,t[0]=Math.random(),t[1]=Math.random(),t[2]=Math.random(),t[3]=Math.random(),n(t,t),i(t,t,e),t}},{\"./normalize\":390,\"./scale\":392}],392:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t}},{}],393:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t[3]=e[3]+r[3]*n,t}},{}],394:[function(t,e,r){e.exports=function(t,e,r,n,i){return t[0]=e,t[1]=r,t[2]=n,t[3]=i,t}},{}],395:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return r*r+n*n+i*i+a*a}},{}],396:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return e*e+r*r+n*n+i*i}},{}],397:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t[3]=e[3]-r[3],t}},{}],398:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}},{}],399:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,h=c*i+l*n-o*a,f=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+h*-l-f*-s,t[1]=h*c+p*-s+f*-o-u*-l,t[2]=f*c+p*-l+u*-s-h*-o,t[3]=e[3],t}},{}],400:[function(t,e,r){e.exports=function(t,e,r,a){return n[0]=a,n[1]=r,n[2]=e,n[3]=t,i[0]};var n=new Uint8Array(4),i=new Float32Array(n.buffer)},{}],401:[function(t,e,r){var n=t(\"glsl-tokenizer\"),i=t(\"atob-lite\");e.exports=function(t){for(var e=Array.isArray(t)?t:n(t),r=0;r<e.length;r++){var a=e[r];if(\"preprocessor\"===a.type){var o=a.data.match(/\\#define\\s+SHADER_NAME(_B64)?\\s+(.+)$/);if(o&&o[2]){var s=o[1],l=o[2];return(s?i(l):l).trim()}}}}},{\"atob-lite\":72,\"glsl-tokenizer\":408}],402:[function(t,e,r){e.exports=function(t){var e,r,k,T=0,A=0,M=l,S=[],E=[],C=1,L=0,P=0,O=!1,z=!1,I=\"\",D=a,R=n;\"300 es\"===(t=t||{}).version&&(D=s,R=o);return function(t){return E=[],null!==t?function(t){var r;T=0,k=(I+=t).length;for(;e=I[T],T<k;){switch(r=T,M){case u:T=U();break;case h:case f:T=j();break;case p:T=V();break;case d:T=G();break;case _:T=H();break;case g:T=Y();break;case c:T=W();break;case x:T=N();break;case l:T=B()}if(r!==T)switch(I[r]){case\"\\n\":L=0,++C;break;default:++L}}return A+=T,I=I.slice(T),E}(t.replace?t.replace(/\\r\\n/g,\"\\n\"):t):function(t){S.length&&F(S.join(\"\"));return M=b,F(\"(eof)\"),E}()};function F(t){t.length&&E.push({type:w[M],data:t,position:P,line:C,column:L})}function B(){return S=S.length?[]:S,\"/\"===r&&\"*\"===e?(P=A+T-1,M=u,r=e,T+1):\"/\"===r&&\"/\"===e?(P=A+T-1,M=h,r=e,T+1):\"#\"===e?(M=f,P=A+T,T):/\\s/.test(e)?(M=x,P=A+T,T):(O=/\\d/.test(e),z=/[^\\w_]/.test(e),P=A+T,M=O?d:z?p:c,T)}function N(){return/[^\\s]/g.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function j(){return\"\\r\"!==e&&\"\\n\"!==e||\"\\\\\"===r?(S.push(e),r=e,T+1):(F(S.join(\"\")),M=l,T)}function U(){return\"/\"===e&&\"*\"===r?(S.push(e),F(S.join(\"\")),M=l,T+1):(S.push(e),r=e,T+1)}function V(){if(\".\"===r&&/\\d/.test(e))return M=g,T;if(\"/\"===r&&\"*\"===e)return M=u,T;if(\"/\"===r&&\"/\"===e)return M=h,T;if(\".\"===e&&S.length){for(;q(S););return M=g,T}if(\";\"===e||\")\"===e||\"(\"===e){if(S.length)for(;q(S););return F(e),M=l,T+1}var t=2===S.length&&\"=\"!==e;if(/[\\w_\\d\\s]/.test(e)||t){for(;q(S););return M=l,T}return S.push(e),r=e,T+1}function q(t){for(var e,r,n=0;;){if(e=i.indexOf(t.slice(0,t.length+n).join(\"\")),r=i[e],-1===e){if(n--+t.length>0)continue;r=t.slice(0,1).join(\"\")}return F(r),P+=r.length,(S=S.slice(r.length)).length}}function H(){return/[^a-fA-F0-9]/.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function G(){return\".\"===e?(S.push(e),M=g,r=e,T+1):/[eE]/.test(e)?(S.push(e),M=g,r=e,T+1):\"x\"===e&&1===S.length&&\"0\"===S[0]?(M=_,S.push(e),r=e,T+1):/[^\\d]/.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function Y(){return\"f\"===e&&(S.push(e),r=e,T+=1),/[eE]/.test(e)?(S.push(e),r=e,T+1):\"-\"===e&&/[eE]/.test(r)?(S.push(e),r=e,T+1):/[^\\d]/.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function W(){if(/[^\\d\\w_]/.test(e)){var t=S.join(\"\");return M=R.indexOf(t)>-1?y:D.indexOf(t)>-1?m:v,F(S.join(\"\")),M=l,T}return S.push(e),r=e,T+1}};var n=t(\"./lib/literals\"),i=t(\"./lib/operators\"),a=t(\"./lib/builtins\"),o=t(\"./lib/literals-300es\"),s=t(\"./lib/builtins-300es\"),l=999,c=9999,u=0,h=1,f=2,p=3,d=4,g=5,v=6,m=7,y=8,x=9,b=10,_=11,w=[\"block-comment\",\"line-comment\",\"preprocessor\",\"operator\",\"integer\",\"float\",\"ident\",\"builtin\",\"keyword\",\"whitespace\",\"eof\",\"integer\"]},{\"./lib/builtins\":404,\"./lib/builtins-300es\":403,\"./lib/literals\":406,\"./lib/literals-300es\":405,\"./lib/operators\":407}],403:[function(t,e,r){var n=t(\"./builtins\");n=n.slice().filter(function(t){return!/^(gl\\_|texture)/.test(t)}),e.exports=n.concat([\"gl_VertexID\",\"gl_InstanceID\",\"gl_Position\",\"gl_PointSize\",\"gl_FragCoord\",\"gl_FrontFacing\",\"gl_FragDepth\",\"gl_PointCoord\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexUniformVectors\",\"gl_MaxVertexOutputVectors\",\"gl_MaxFragmentInputVectors\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxTextureImageUnits\",\"gl_MaxFragmentUniformVectors\",\"gl_MaxDrawBuffers\",\"gl_MinProgramTexelOffset\",\"gl_MaxProgramTexelOffset\",\"gl_DepthRangeParameters\",\"gl_DepthRange\",\"trunc\",\"round\",\"roundEven\",\"isnan\",\"isinf\",\"floatBitsToInt\",\"floatBitsToUint\",\"intBitsToFloat\",\"uintBitsToFloat\",\"packSnorm2x16\",\"unpackSnorm2x16\",\"packUnorm2x16\",\"unpackUnorm2x16\",\"packHalf2x16\",\"unpackHalf2x16\",\"outerProduct\",\"transpose\",\"determinant\",\"inverse\",\"texture\",\"textureSize\",\"textureProj\",\"textureLod\",\"textureOffset\",\"texelFetch\",\"texelFetchOffset\",\"textureProjOffset\",\"textureLodOffset\",\"textureProjLod\",\"textureProjLodOffset\",\"textureGrad\",\"textureGradOffset\",\"textureProjGrad\",\"textureProjGradOffset\"])},{\"./builtins\":404}],404:[function(t,e,r){e.exports=[\"abs\",\"acos\",\"all\",\"any\",\"asin\",\"atan\",\"ceil\",\"clamp\",\"cos\",\"cross\",\"dFdx\",\"dFdy\",\"degrees\",\"distance\",\"dot\",\"equal\",\"exp\",\"exp2\",\"faceforward\",\"floor\",\"fract\",\"gl_BackColor\",\"gl_BackLightModelProduct\",\"gl_BackLightProduct\",\"gl_BackMaterial\",\"gl_BackSecondaryColor\",\"gl_ClipPlane\",\"gl_ClipVertex\",\"gl_Color\",\"gl_DepthRange\",\"gl_DepthRangeParameters\",\"gl_EyePlaneQ\",\"gl_EyePlaneR\",\"gl_EyePlaneS\",\"gl_EyePlaneT\",\"gl_Fog\",\"gl_FogCoord\",\"gl_FogFragCoord\",\"gl_FogParameters\",\"gl_FragColor\",\"gl_FragCoord\",\"gl_FragData\",\"gl_FragDepth\",\"gl_FragDepthEXT\",\"gl_FrontColor\",\"gl_FrontFacing\",\"gl_FrontLightModelProduct\",\"gl_FrontLightProduct\",\"gl_FrontMaterial\",\"gl_FrontSecondaryColor\",\"gl_LightModel\",\"gl_LightModelParameters\",\"gl_LightModelProducts\",\"gl_LightProducts\",\"gl_LightSource\",\"gl_LightSourceParameters\",\"gl_MaterialParameters\",\"gl_MaxClipPlanes\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxDrawBuffers\",\"gl_MaxFragmentUniformComponents\",\"gl_MaxLights\",\"gl_MaxTextureCoords\",\"gl_MaxTextureImageUnits\",\"gl_MaxTextureUnits\",\"gl_MaxVaryingFloats\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxVertexUniformComponents\",\"gl_ModelViewMatrix\",\"gl_ModelViewMatrixInverse\",\"gl_ModelViewMatrixInverseTranspose\",\"gl_ModelViewMatrixTranspose\",\"gl_ModelViewProjectionMatrix\",\"gl_ModelViewProjectionMatrixInverse\",\"gl_ModelViewProjectionMatrixInverseTranspose\",\"gl_ModelViewProjectionMatrixTranspose\",\"gl_MultiTexCoord0\",\"gl_MultiTexCoord1\",\"gl_MultiTexCoord2\",\"gl_MultiTexCoord3\",\"gl_MultiTexCoord4\",\"gl_MultiTexCoord5\",\"gl_MultiTexCoord6\",\"gl_MultiTexCoord7\",\"gl_Normal\",\"gl_NormalMatrix\",\"gl_NormalScale\",\"gl_ObjectPlaneQ\",\"gl_ObjectPlaneR\",\"gl_ObjectPlaneS\",\"gl_ObjectPlaneT\",\"gl_Point\",\"gl_PointCoord\",\"gl_PointParameters\",\"gl_PointSize\",\"gl_Position\",\"gl_ProjectionMatrix\",\"gl_ProjectionMatrixInverse\",\"gl_ProjectionMatrixInverseTranspose\",\"gl_ProjectionMatrixTranspose\",\"gl_SecondaryColor\",\"gl_TexCoord\",\"gl_TextureEnvColor\",\"gl_TextureMatrix\",\"gl_TextureMatrixInverse\",\"gl_TextureMatrixInverseTranspose\",\"gl_TextureMatrixTranspose\",\"gl_Vertex\",\"greaterThan\",\"greaterThanEqual\",\"inversesqrt\",\"length\",\"lessThan\",\"lessThanEqual\",\"log\",\"log2\",\"matrixCompMult\",\"max\",\"min\",\"mix\",\"mod\",\"normalize\",\"not\",\"notEqual\",\"pow\",\"radians\",\"reflect\",\"refract\",\"sign\",\"sin\",\"smoothstep\",\"sqrt\",\"step\",\"tan\",\"texture2D\",\"texture2DLod\",\"texture2DProj\",\"texture2DProjLod\",\"textureCube\",\"textureCubeLod\",\"texture2DLodEXT\",\"texture2DProjLodEXT\",\"textureCubeLodEXT\",\"texture2DGradEXT\",\"texture2DProjGradEXT\",\"textureCubeGradEXT\"]},{}],405:[function(t,e,r){var n=t(\"./literals\");e.exports=n.slice().concat([\"layout\",\"centroid\",\"smooth\",\"case\",\"mat2x2\",\"mat2x3\",\"mat2x4\",\"mat3x2\",\"mat3x3\",\"mat3x4\",\"mat4x2\",\"mat4x3\",\"mat4x4\",\"uint\",\"uvec2\",\"uvec3\",\"uvec4\",\"samplerCubeShadow\",\"sampler2DArray\",\"sampler2DArrayShadow\",\"isampler2D\",\"isampler3D\",\"isamplerCube\",\"isampler2DArray\",\"usampler2D\",\"usampler3D\",\"usamplerCube\",\"usampler2DArray\",\"coherent\",\"restrict\",\"readonly\",\"writeonly\",\"resource\",\"atomic_uint\",\"noperspective\",\"patch\",\"sample\",\"subroutine\",\"common\",\"partition\",\"active\",\"filter\",\"image1D\",\"image2D\",\"image3D\",\"imageCube\",\"iimage1D\",\"iimage2D\",\"iimage3D\",\"iimageCube\",\"uimage1D\",\"uimage2D\",\"uimage3D\",\"uimageCube\",\"image1DArray\",\"image2DArray\",\"iimage1DArray\",\"iimage2DArray\",\"uimage1DArray\",\"uimage2DArray\",\"image1DShadow\",\"image2DShadow\",\"image1DArrayShadow\",\"image2DArrayShadow\",\"imageBuffer\",\"iimageBuffer\",\"uimageBuffer\",\"sampler1DArray\",\"sampler1DArrayShadow\",\"isampler1D\",\"isampler1DArray\",\"usampler1D\",\"usampler1DArray\",\"isampler2DRect\",\"usampler2DRect\",\"samplerBuffer\",\"isamplerBuffer\",\"usamplerBuffer\",\"sampler2DMS\",\"isampler2DMS\",\"usampler2DMS\",\"sampler2DMSArray\",\"isampler2DMSArray\",\"usampler2DMSArray\"])},{\"./literals\":406}],406:[function(t,e,r){e.exports=[\"precision\",\"highp\",\"mediump\",\"lowp\",\"attribute\",\"const\",\"uniform\",\"varying\",\"break\",\"continue\",\"do\",\"for\",\"while\",\"if\",\"else\",\"in\",\"out\",\"inout\",\"float\",\"int\",\"void\",\"bool\",\"true\",\"false\",\"discard\",\"return\",\"mat2\",\"mat3\",\"mat4\",\"vec2\",\"vec3\",\"vec4\",\"ivec2\",\"ivec3\",\"ivec4\",\"bvec2\",\"bvec3\",\"bvec4\",\"sampler1D\",\"sampler2D\",\"sampler3D\",\"samplerCube\",\"sampler1DShadow\",\"sampler2DShadow\",\"struct\",\"asm\",\"class\",\"union\",\"enum\",\"typedef\",\"template\",\"this\",\"packed\",\"goto\",\"switch\",\"default\",\"inline\",\"noinline\",\"volatile\",\"public\",\"static\",\"extern\",\"external\",\"interface\",\"long\",\"short\",\"double\",\"half\",\"fixed\",\"unsigned\",\"input\",\"output\",\"hvec2\",\"hvec3\",\"hvec4\",\"dvec2\",\"dvec3\",\"dvec4\",\"fvec2\",\"fvec3\",\"fvec4\",\"sampler2DRect\",\"sampler3DRect\",\"sampler2DRectShadow\",\"sizeof\",\"cast\",\"namespace\",\"using\"]},{}],407:[function(t,e,r){e.exports=[\"<<=\",\">>=\",\"++\",\"--\",\"<<\",\">>\",\"<=\",\">=\",\"==\",\"!=\",\"&&\",\"||\",\"+=\",\"-=\",\"*=\",\"/=\",\"%=\",\"&=\",\"^^\",\"^=\",\"|=\",\"(\",\")\",\"[\",\"]\",\".\",\"!\",\"~\",\"*\",\"/\",\"%\",\"+\",\"-\",\"<\",\">\",\"&\",\"^\",\"|\",\"?\",\":\",\"=\",\",\",\";\",\"{\",\"}\"]},{}],408:[function(t,e,r){var n=t(\"./index\");e.exports=function(t,e){var r=n(e),i=[];return i=(i=i.concat(r(t))).concat(r(null))}},{\"./index\":402}],409:[function(t,e,r){e.exports=function(t){\"string\"==typeof t&&(t=[t]);for(var e=[].slice.call(arguments,1),r=[],n=0;n<t.length-1;n++)r.push(t[n],e[n]||\"\");return r.push(t[n]),r.join(\"\")}},{}],410:[function(t,e,r){(function(r){\"use strict\";var n,i=t(\"is-browser\");n=\"function\"==typeof r.matchMedia?!r.matchMedia(\"(hover: none)\").matches:i,e.exports=n}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"is-browser\":417}],411:[function(t,e,r){\"use strict\";var n=t(\"is-browser\");e.exports=n&&function(){var t=!1;try{var e=Object.defineProperty({},\"passive\",{get:function(){t=!0}});window.addEventListener(\"test\",null,e),window.removeEventListener(\"test\",null,e)}catch(e){t=!1}return t}()},{\"is-browser\":417}],412:[function(t,e,r){r.read=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?i-1:0,f=r?-1:1,p=t[e+h];for(h+=f,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+h],h+=f,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},r.write=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,h=u>>1,f=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,i),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g}},{}],413:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(0===r)throw new Error(\"Must have at least d+1 points\");var i=t[0].length;if(r<=i)throw new Error(\"Must input at least d+1 points\");var o=t.slice(0,i+1),s=n.apply(void 0,o);if(0===s)throw new Error(\"Input not in general position\");for(var l=new Array(i+1),u=0;u<=i;++u)l[u]=u;s<0&&(l[0]=1,l[1]=0);for(var h=new a(l,new Array(i+1),!1),f=h.adjacent,p=new Array(i+2),u=0;u<=i;++u){for(var d=l.slice(),g=0;g<=i;++g)g===u&&(d[g]=-1);var v=d[0];d[0]=d[1],d[1]=v;var m=new a(d,new Array(i+1),!0);f[u]=m,p[u]=m}p[i+1]=h;for(var u=0;u<=i;++u)for(var d=f[u].vertices,y=f[u].adjacent,g=0;g<=i;++g){var x=d[g];if(x<0)y[g]=h;else for(var b=0;b<=i;++b)f[b].vertices.indexOf(x)<0&&(y[g]=f[b])}for(var _=new c(i,o,p),w=!!e,u=i+1;u<r;++u)_.insert(t[u],w);return _.boundary()};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\").compareCells;function a(t,e,r){this.vertices=t,this.adjacent=e,this.boundary=r,this.lastVisited=-1}function o(t,e,r){this.vertices=t,this.cell=e,this.index=r}function s(t,e){return i(t.vertices,e.vertices)}a.prototype.flip=function(){var t=this.vertices[0];this.vertices[0]=this.vertices[1],this.vertices[1]=t;var e=this.adjacent[0];this.adjacent[0]=this.adjacent[1],this.adjacent[1]=e};var l=[];function c(t,e,r){this.dimension=t,this.vertices=e,this.simplices=r,this.interior=r.filter(function(t){return!t.boundary}),this.tuple=new Array(t+1);for(var i=0;i<=t;++i)this.tuple[i]=this.vertices[i];var a=l[t];a||(a=l[t]=function(t){for(var e=[\"function orient(){var tuple=this.tuple;return test(\"],r=0;r<=t;++r)r>0&&e.push(\",\"),e.push(\"tuple[\",r,\"]\");e.push(\")}return orient\");var i=new Function(\"test\",e.join(\"\")),a=n[t+1];return a||(a=n),i(a)}(t)),this.orient=a}var u=c.prototype;u.handleBoundaryDegeneracy=function(t,e){var r=this.dimension,n=this.vertices.length-1,i=this.tuple,a=this.vertices,o=[t];for(t.lastVisited=-n;o.length>0;){(t=o.pop()).vertices;for(var s=t.adjacent,l=0;l<=r;++l){var c=s[l];if(c.boundary&&!(c.lastVisited<=-n)){for(var u=c.vertices,h=0;h<=r;++h){var f=u[h];i[h]=f<0?e:a[f]}var p=this.orient();if(p>0)return c;c.lastVisited=-n,0===p&&o.push(c)}}}return null},u.walk=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,a=this.tuple,o=e?this.interior.length*Math.random()|0:this.interior.length-1,s=this.interior[o];t:for(;!s.boundary;){for(var l=s.vertices,c=s.adjacent,u=0;u<=n;++u)a[u]=i[l[u]];s.lastVisited=r;for(u=0;u<=n;++u){var h=c[u];if(!(h.lastVisited>=r)){var f=a[u];a[u]=t;var p=this.orient();if(a[u]=f,p<0){s=h;continue t}h.boundary?h.lastVisited=-r:h.lastVisited=r}}return}return s},u.addPeaks=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,l=this.tuple,c=this.interior,u=this.simplices,h=[e];e.lastVisited=r,e.vertices[e.vertices.indexOf(-1)]=r,e.boundary=!1,c.push(e);for(var f=[];h.length>0;){var p=(e=h.pop()).vertices,d=e.adjacent,g=p.indexOf(r);if(!(g<0))for(var v=0;v<=n;++v)if(v!==g){var m=d[v];if(m.boundary&&!(m.lastVisited>=r)){var y=m.vertices;if(m.lastVisited!==-r){for(var x=0,b=0;b<=n;++b)y[b]<0?(x=b,l[b]=t):l[b]=i[y[b]];if(this.orient()>0){y[x]=r,m.boundary=!1,c.push(m),h.push(m),m.lastVisited=r;continue}m.lastVisited=-r}var _=m.adjacent,w=p.slice(),k=d.slice(),T=new a(w,k,!0);u.push(T);var A=_.indexOf(e);if(!(A<0)){_[A]=T,k[g]=m,w[v]=-1,k[v]=e,d[v]=T,T.flip();for(b=0;b<=n;++b){var M=w[b];if(!(M<0||M===r)){for(var S=new Array(n-1),E=0,C=0;C<=n;++C){var L=w[C];L<0||C===b||(S[E++]=L)}f.push(new o(S,T,b))}}}}}}f.sort(s);for(v=0;v+1<f.length;v+=2){var P=f[v],O=f[v+1],z=P.index,I=O.index;z<0||I<0||(P.cell.adjacent[P.index]=O.cell,O.cell.adjacent[O.index]=P.cell)}},u.insert=function(t,e){var r=this.vertices;r.push(t);var n=this.walk(t,e);if(n){for(var i=this.dimension,a=this.tuple,o=0;o<=i;++o){var s=n.vertices[o];a[o]=s<0?t:r[s]}var l=this.orient(a);l<0||(0!==l||(n=this.handleBoundaryDegeneracy(n,t)))&&this.addPeaks(t,n)}},u.boundary=function(){for(var t=this.dimension,e=[],r=this.simplices,n=r.length,i=0;i<n;++i){var a=r[i];if(a.boundary){for(var o=new Array(t),s=a.vertices,l=0,c=0,u=0;u<=t;++u)s[u]>=0?o[l++]=s[u]:c=1&u;if(c===(1&t)){var h=o[0];o[0]=o[1],o[1]=h}e.push(o)}}return e}},{\"robust-orientation\":510,\"simplicial-complex\":520}],414:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=0,a=1;function o(t,e,r,n,i){this.mid=t,this.left=e,this.right=r,this.leftPoints=n,this.rightPoints=i,this.count=(e?e.count:0)+(r?r.count:0)+n.length}e.exports=function(t){if(!t||0===t.length)return new x(null);return new x(y(t))};var s=o.prototype;function l(t,e){t.mid=e.mid,t.left=e.left,t.right=e.right,t.leftPoints=e.leftPoints,t.rightPoints=e.rightPoints,t.count=e.count}function c(t,e){var r=y(e);t.mid=r.mid,t.left=r.left,t.right=r.right,t.leftPoints=r.leftPoints,t.rightPoints=r.rightPoints,t.count=r.count}function u(t,e){var r=t.intervals([]);r.push(e),c(t,r)}function h(t,e){var r=t.intervals([]),n=r.indexOf(e);return n<0?i:(r.splice(n,1),c(t,r),a)}function f(t,e,r){for(var n=0;n<t.length&&t[n][0]<=e;++n){var i=r(t[n]);if(i)return i}}function p(t,e,r){for(var n=t.length-1;n>=0&&t[n][1]>=e;--n){var i=r(t[n]);if(i)return i}}function d(t,e){for(var r=0;r<t.length;++r){var n=e(t[r]);if(n)return n}}function g(t,e){return t-e}function v(t,e){var r=t[0]-e[0];return r||t[1]-e[1]}function m(t,e){var r=t[1]-e[1];return r||t[0]-e[0]}function y(t){if(0===t.length)return null;for(var e=[],r=0;r<t.length;++r)e.push(t[r][0],t[r][1]);e.sort(g);var n=e[e.length>>1],i=[],a=[],s=[];for(r=0;r<t.length;++r){var l=t[r];l[1]<n?i.push(l):n<l[0]?a.push(l):s.push(l)}var c=s,u=s.slice();return c.sort(v),u.sort(m),new o(n,y(i),y(a),c,u)}function x(t){this.root=t}s.intervals=function(t){return t.push.apply(t,this.leftPoints),this.left&&this.left.intervals(t),this.right&&this.right.intervals(t),t},s.insert=function(t){var e=this.count-this.leftPoints.length;if(this.count+=1,t[1]<this.mid)this.left?4*(this.left.count+1)>3*(e+1)?u(this,t):this.left.insert(t):this.left=y([t]);else if(t[0]>this.mid)this.right?4*(this.right.count+1)>3*(e+1)?u(this,t):this.right.insert(t):this.right=y([t]);else{var r=n.ge(this.leftPoints,t,v),i=n.ge(this.rightPoints,t,m);this.leftPoints.splice(r,0,t),this.rightPoints.splice(i,0,t)}},s.remove=function(t){var e=this.count-this.leftPoints;if(t[1]<this.mid)return this.left?4*(this.right?this.right.count:0)>3*(e-1)?h(this,t):2===(c=this.left.remove(t))?(this.left=null,this.count-=1,a):(c===a&&(this.count-=1),c):i;if(t[0]>this.mid)return this.right?4*(this.left?this.left.count:0)>3*(e-1)?h(this,t):2===(c=this.right.remove(t))?(this.right=null,this.count-=1,a):(c===a&&(this.count-=1),c):i;if(1===this.count)return this.leftPoints[0]===t?2:i;if(1===this.leftPoints.length&&this.leftPoints[0]===t){if(this.left&&this.right){for(var r=this,o=this.left;o.right;)r=o,o=o.right;if(r===this)o.right=this.right;else{var s=this.left,c=this.right;r.count-=o.count,r.right=o.left,o.left=s,o.right=c}l(this,o),this.count=(this.left?this.left.count:0)+(this.right?this.right.count:0)+this.leftPoints.length}else this.left?l(this,this.left):l(this,this.right);return a}for(s=n.ge(this.leftPoints,t,v);s<this.leftPoints.length&&this.leftPoints[s][0]===t[0];++s)if(this.leftPoints[s]===t){this.count-=1,this.leftPoints.splice(s,1);for(c=n.ge(this.rightPoints,t,m);c<this.rightPoints.length&&this.rightPoints[c][1]===t[1];++c)if(this.rightPoints[c]===t)return this.rightPoints.splice(c,1),a}return i},s.queryPoint=function(t,e){if(t<this.mid){if(this.left)if(r=this.left.queryPoint(t,e))return r;return f(this.leftPoints,t,e)}if(t>this.mid){var r;if(this.right)if(r=this.right.queryPoint(t,e))return r;return p(this.rightPoints,t,e)}return d(this.leftPoints,e)},s.queryInterval=function(t,e,r){var n;if(t<this.mid&&this.left&&(n=this.left.queryInterval(t,e,r)))return n;if(e>this.mid&&this.right&&(n=this.right.queryInterval(t,e,r)))return n;return e<this.mid?f(this.leftPoints,e,r):t>this.mid?p(this.rightPoints,t,r):d(this.leftPoints,r)};var b=x.prototype;b.insert=function(t){this.root?this.root.insert(t):this.root=new o(t[0],null,null,[t],[t])},b.remove=function(t){if(this.root){var e=this.root.remove(t);return 2===e&&(this.root=null),e!==i}return!1},b.queryPoint=function(t,e){if(this.root)return this.root.queryPoint(t,e)},b.queryInterval=function(t,e,r){if(t<=e&&this.root)return this.root.queryInterval(t,e,r)},Object.defineProperty(b,\"count\",{get:function(){return this.root?this.root.count:0}}),Object.defineProperty(b,\"intervals\",{get:function(){return this.root?this.root.intervals([]):[]}})},{\"binary-search-bounds\":91}],415:[function(t,e,r){\"use strict\";e.exports=function(t,e){e=e||new Array(t.length);for(var r=0;r<t.length;++r)e[t[r]]=r;return e}},{}],416:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=r;return e}},{}],417:[function(t,e,r){e.exports=!0},{}],418:[function(t,e,r){function n(t){return!!t.constructor&&\"function\"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}e.exports=function(t){return null!=t&&(n(t)||function(t){return\"function\"==typeof t.readFloatLE&&\"function\"==typeof t.slice&&n(t.slice(0,0))}(t)||!!t._isBuffer)}},{}],419:[function(t,e,r){\"use strict\";e.exports=\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion))},{}],420:[function(t,e,r){\"use strict\";e.exports=a,e.exports.isMobile=a;var n=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i,i=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino|android|ipad|playbook|silk/i;function a(t){t||(t={});var e=t.ua;return e||\"undefined\"==typeof navigator||(e=navigator.userAgent),e&&e.headers&&\"string\"==typeof e.headers[\"user-agent\"]&&(e=e.headers[\"user-agent\"]),\"string\"==typeof e&&(t.tablet?i.test(e):n.test(e))}},{}],421:[function(t,e,r){\"use strict\";e.exports=function(t){var e=typeof t;return null!==t&&(\"object\"===e||\"function\"===e)}},{}],422:[function(t,e,r){\"use strict\";var n=Object.prototype.toString;e.exports=function(t){var e;return\"[object Object]\"===n.call(t)&&(null===(e=Object.getPrototypeOf(t))||e===Object.getPrototypeOf({}))}},{}],423:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=t.length,n=0;n<r;n++)if(((e=t.charCodeAt(n))<9||e>13)&&32!==e&&133!==e&&160!==e&&5760!==e&&6158!==e&&(e<8192||e>8205)&&8232!==e&&8233!==e&&8239!==e&&8287!==e&&8288!==e&&12288!==e&&65279!==e)return!1;return!0}},{}],424:[function(t,e,r){\"use strict\";e.exports=function(t){return\"string\"==typeof t&&(t=t.trim(),!!(/^[mzlhvcsqta]\\s*[-+.0-9][^mlhvzcsqta]+/i.test(t)&&/[\\dz]$/i.test(t)&&t.length>4))}},{}],425:[function(t,e,r){e.exports=function(t,e,r){return t*(1-r)+e*r}},{}],426:[function(t,e,r){var n,i;n=this,i=function(){\"use strict\";var t,e,r;function n(n,i){if(t)if(e){var a=\"var sharedChunk = {}; (\"+t+\")(sharedChunk); (\"+e+\")(sharedChunk);\",o={};t(o),(r=i(o)).workerUrl=window.URL.createObjectURL(new Blob([a],{type:\"text/javascript\"}))}else e=i;else t=i}return n(0,function(t){function e(t,e){return t(e={exports:{}},e.exports),e.exports}var r=n;function n(t,e,r,n){this.cx=3*t,this.bx=3*(r-t)-this.cx,this.ax=1-this.cx-this.bx,this.cy=3*e,this.by=3*(n-e)-this.cy,this.ay=1-this.cy-this.by,this.p1x=t,this.p1y=n,this.p2x=r,this.p2y=n}n.prototype.sampleCurveX=function(t){return((this.ax*t+this.bx)*t+this.cx)*t},n.prototype.sampleCurveY=function(t){return((this.ay*t+this.by)*t+this.cy)*t},n.prototype.sampleCurveDerivativeX=function(t){return(3*this.ax*t+2*this.bx)*t+this.cx},n.prototype.solveCurveX=function(t,e){var r,n,i,a,o;for(void 0===e&&(e=1e-6),i=t,o=0;o<8;o++){if(a=this.sampleCurveX(i)-t,Math.abs(a)<e)return i;var s=this.sampleCurveDerivativeX(i);if(Math.abs(s)<1e-6)break;i-=a/s}if((i=t)<(r=0))return r;if(i>(n=1))return n;for(;r<n;){if(a=this.sampleCurveX(i),Math.abs(a-t)<e)return i;t>a?r=i:n=i,i=.5*(n-r)+r}return i},n.prototype.solve=function(t,e){return this.sampleCurveY(this.solveCurveX(t,e))};var i=a;function a(t,e){this.x=t,this.y=e}function o(t,e){if(Array.isArray(t)){if(!Array.isArray(e)||t.length!==e.length)return!1;for(var r=0;r<t.length;r++)if(!o(t[r],e[r]))return!1;return!0}if(\"object\"==typeof t&&null!==t&&null!==e){if(\"object\"!=typeof e)return!1;if(Object.keys(t).length!==Object.keys(e).length)return!1;for(var n in t)if(!o(t[n],e[n]))return!1;return!0}return t===e}function s(t,e,n,i){var a=new r(t,e,n,i);return function(t){return a.solve(t)}}a.prototype={clone:function(){return new a(this.x,this.y)},add:function(t){return this.clone()._add(t)},sub:function(t){return this.clone()._sub(t)},multByPoint:function(t){return this.clone()._multByPoint(t)},divByPoint:function(t){return this.clone()._divByPoint(t)},mult:function(t){return this.clone()._mult(t)},div:function(t){return this.clone()._div(t)},rotate:function(t){return this.clone()._rotate(t)},rotateAround:function(t,e){return this.clone()._rotateAround(t,e)},matMult:function(t){return this.clone()._matMult(t)},unit:function(){return this.clone()._unit()},perp:function(){return this.clone()._perp()},round:function(){return this.clone()._round()},mag:function(){return Math.sqrt(this.x*this.x+this.y*this.y)},equals:function(t){return this.x===t.x&&this.y===t.y},dist:function(t){return Math.sqrt(this.distSqr(t))},distSqr:function(t){var e=t.x-this.x,r=t.y-this.y;return e*e+r*r},angle:function(){return Math.atan2(this.y,this.x)},angleTo:function(t){return Math.atan2(this.y-t.y,this.x-t.x)},angleWith:function(t){return this.angleWithSep(t.x,t.y)},angleWithSep:function(t,e){return Math.atan2(this.x*e-this.y*t,this.x*t+this.y*e)},_matMult:function(t){var e=t[0]*this.x+t[1]*this.y,r=t[2]*this.x+t[3]*this.y;return this.x=e,this.y=r,this},_add:function(t){return this.x+=t.x,this.y+=t.y,this},_sub:function(t){return this.x-=t.x,this.y-=t.y,this},_mult:function(t){return this.x*=t,this.y*=t,this},_div:function(t){return this.x/=t,this.y/=t,this},_multByPoint:function(t){return this.x*=t.x,this.y*=t.y,this},_divByPoint:function(t){return this.x/=t.x,this.y/=t.y,this},_unit:function(){return this._div(this.mag()),this},_perp:function(){var t=this.y;return this.y=this.x,this.x=-t,this},_rotate:function(t){var e=Math.cos(t),r=Math.sin(t),n=e*this.x-r*this.y,i=r*this.x+e*this.y;return this.x=n,this.y=i,this},_rotateAround:function(t,e){var r=Math.cos(t),n=Math.sin(t),i=e.x+r*(this.x-e.x)-n*(this.y-e.y),a=e.y+n*(this.x-e.x)+r*(this.y-e.y);return this.x=i,this.y=a,this},_round:function(){return this.x=Math.round(this.x),this.y=Math.round(this.y),this}},a.convert=function(t){return t instanceof a?t:Array.isArray(t)?new a(t[0],t[1]):t};var l=s(.25,.1,.25,1);function c(t,e,r){return Math.min(r,Math.max(e,t))}function u(t,e,r){var n=r-e,i=((t-e)%n+n)%n+e;return i===e?r:i}function h(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}var f=1;function p(){return f++}function d(){return function t(e){return e?(e^16*Math.random()>>e/4).toString(16):([1e7]+-[1e3]+-4e3+-8e3+-1e11).replace(/[018]/g,t)}()}function g(t){return!!t&&/^[0-9a-f]{8}-[0-9a-f]{4}-[4][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$/i.test(t)}function v(t,e){t.forEach(function(t){e[t]&&(e[t]=e[t].bind(e))})}function m(t,e){return-1!==t.indexOf(e,t.length-e.length)}function y(t,e,r){var n={};for(var i in t)n[i]=e.call(r||this,t[i],i,t);return n}function x(t,e,r){var n={};for(var i in t)e.call(r||this,t[i],i,t)&&(n[i]=t[i]);return n}function b(t){return Array.isArray(t)?t.map(b):\"object\"==typeof t&&t?y(t,b):t}var _={};function w(t){_[t]||(\"undefined\"!=typeof console&&console.warn(t),_[t]=!0)}function k(t,e,r){return(r.y-t.y)*(e.x-t.x)>(e.y-t.y)*(r.x-t.x)}function T(t){for(var e=0,r=0,n=t.length,i=n-1,a=void 0,o=void 0;r<n;i=r++)a=t[r],e+=((o=t[i]).x-a.x)*(a.y+o.y);return e}function A(t){var e={};if(t.replace(/(?:^|(?:\\s*\\,\\s*))([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)(?:\\=(?:([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)|(?:\\\"((?:[^\"\\\\]|\\\\.)*)\\\")))?/g,function(t,r,n,i){var a=n||i;return e[r]=!a||a.toLowerCase(),\"\"}),e[\"max-age\"]){var r=parseInt(e[\"max-age\"],10);isNaN(r)?delete e[\"max-age\"]:e[\"max-age\"]=r}return e}function M(t){try{var e=self[t];return e.setItem(\"_mapbox_test_\",1),e.removeItem(\"_mapbox_test_\"),!0}catch(t){return!1}}var S,E,C,L=self.performance&&self.performance.now?self.performance.now.bind(self.performance):Date.now.bind(Date),P=self.requestAnimationFrame||self.mozRequestAnimationFrame||self.webkitRequestAnimationFrame||self.msRequestAnimationFrame,O=self.cancelAnimationFrame||self.mozCancelAnimationFrame||self.webkitCancelAnimationFrame||self.msCancelAnimationFrame,z={now:L,frame:function(t){var e=P(t);return{cancel:function(){return O(e)}}},getImageData:function(t){var e=self.document.createElement(\"canvas\"),r=e.getContext(\"2d\");if(!r)throw new Error(\"failed to create canvas 2d context\");return e.width=t.width,e.height=t.height,r.drawImage(t,0,0,t.width,t.height),r.getImageData(0,0,t.width,t.height)},resolveURL:function(t){return S||(S=self.document.createElement(\"a\")),S.href=t,S.href},hardwareConcurrency:self.navigator.hardwareConcurrency||4,get devicePixelRatio(){return self.devicePixelRatio}},I={API_URL:\"https://api.mapbox.com\",get EVENTS_URL(){return this.API_URL?0===this.API_URL.indexOf(\"https://api.mapbox.cn\")?\"https://events.mapbox.cn/events/v2\":0===this.API_URL.indexOf(\"https://api.mapbox.com\")?\"https://events.mapbox.com/events/v2\":null:null},FEEDBACK_URL:\"https://apps.mapbox.com/feedback\",REQUIRE_ACCESS_TOKEN:!0,ACCESS_TOKEN:null,MAX_PARALLEL_IMAGE_REQUESTS:16},D={supported:!1,testSupport:function(t){!R&&C&&(F?B(t):E=t)}},R=!1,F=!1;function B(t){var e=t.createTexture();t.bindTexture(t.TEXTURE_2D,e);try{if(t.texImage2D(t.TEXTURE_2D,0,t.RGBA,t.RGBA,t.UNSIGNED_BYTE,C),t.isContextLost())return;D.supported=!0}catch(t){}t.deleteTexture(e),R=!0}self.document&&((C=self.document.createElement(\"img\")).onload=function(){E&&B(E),E=null,F=!0},C.onerror=function(){R=!0,E=null},C.src=\"data:image/webp;base64,UklGRh4AAABXRUJQVlA4TBEAAAAvAQAAAAfQ//73v/+BiOh/AAA=\");var N=\"01\",j=function(t){this._transformRequestFn=t,this._createSkuToken()};j.prototype._createSkuToken=function(){var t=function(){for(var t=\"\",e=0;e<10;e++)t+=\"0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ\"[Math.floor(62*Math.random())];return{token:[\"1\",N,t].join(\"\"),tokenExpiresAt:Date.now()+432e5}}();this._skuToken=t.token,this._skuTokenExpiresAt=t.tokenExpiresAt},j.prototype._isSkuTokenExpired=function(){return Date.now()>this._skuTokenExpiresAt},j.prototype.transformRequest=function(t,e){return this._transformRequestFn&&this._transformRequestFn(t,e)||{url:t}},j.prototype.normalizeStyleURL=function(t,e){return Y(t,e)},j.prototype.normalizeGlyphsURL=function(t,e){return W(t,e)},j.prototype.normalizeSourceURL=function(t,e){return X(t,e)},j.prototype.normalizeSpriteURL=function(t,e,r,n){return Z(t,e,r,n)},j.prototype.normalizeTileURL=function(t,e,r){return this._isSkuTokenExpired()&&this._createSkuToken(),K(t,e,r,this._skuToken)},j.prototype.canonicalizeTileURL=function(t){return Q(t)},j.prototype.canonicalizeTileset=function(t,e){return tt(t,e)};var U=\"See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\";function V(t,e){var r=rt(I.API_URL);if(t.protocol=r.protocol,t.authority=r.authority,\"/\"!==r.path&&(t.path=\"\"+r.path+t.path),!I.REQUIRE_ACCESS_TOKEN)return nt(t);if(!(e=e||I.ACCESS_TOKEN))throw new Error(\"An API access token is required to use Mapbox GL. \"+U);if(\"s\"===e[0])throw new Error(\"Use a public access token (pk.*) with Mapbox GL, not a secret access token (sk.*). \"+U);return t.params.push(\"access_token=\"+e),nt(t)}function q(t){return 0===t.indexOf(\"mapbox:\")}var H=/^((https?:)?\\/\\/)?([^\\/]+\\.)?mapbox\\.c(n|om)(\\/|\\?|$)/i;function G(t){return H.test(t)}var Y=function(t,e){if(!q(t))return t;var r=rt(t);return r.path=\"/styles/v1\"+r.path,V(r,e)},W=function(t,e){if(!q(t))return t;var r=rt(t);return r.path=\"/fonts/v1\"+r.path,V(r,e)},X=function(t,e){if(!q(t))return t;var r=rt(t);return r.path=\"/v4/\"+r.authority+\".json\",r.params.push(\"secure\"),V(r,e)},Z=function(t,e,r,n){var i=rt(t);return q(t)?(i.path=\"/styles/v1\"+i.path+\"/sprite\"+e+r,V(i,n)):(i.path+=\"\"+e+r,nt(i))},J=/(\\.(png|jpg)\\d*)(?=$)/,K=function(t,e,r,n){if(!e||!q(e))return t;var i=rt(t),a=z.devicePixelRatio>=2||512===r?\"@2x\":\"\",o=D.supported?\".webp\":\"$1\";return i.path=i.path.replace(J,\"\"+a+o),i.path=\"/v4\"+i.path,I.REQUIRE_ACCESS_TOKEN&&I.ACCESS_TOKEN&&n&&i.params.push(\"sku=\"+n),V(i)},$=/\\.[\\w]+$/,Q=function(t){var e=rt(t);if(!e.path.match(/(^\\/v4\\/)/)||!e.path.match($))return t;var r=\"mapbox://tiles/\";r+=e.path.replace(\"/v4/\",\"\");var n=e.params.filter(function(t){return!t.match(/^access_token=/)});return n.length&&(r+=\"?\"+n.join(\"&\")),r},tt=function(t,e){if(!q(e))return t.tiles||[];for(var r=[],n=0,i=t.tiles;n<i.length;n+=1){var a=i[n],o=Q(a);r.push(o)}return r},et=/^(\\w+):\\/\\/([^\\/?]*)(\\/[^?]+)?\\??(.+)?/;function rt(t){var e=t.match(et);if(!e)throw new Error(\"Unable to parse URL object\");return{protocol:e[1],authority:e[2],path:e[3]||\"/\",params:e[4]?e[4].split(\"&\"):[]}}function nt(t){var e=t.params.length?\"?\"+t.params.join(\"&\"):\"\";return t.protocol+\"://\"+t.authority+t.path+e}function it(t){if(!t)return null;var e,r=t.split(\".\");if(!r||3!==r.length)return null;try{return JSON.parse((e=r[1],decodeURIComponent(self.atob(e).split(\"\").map(function(t){return\"%\"+(\"00\"+t.charCodeAt(0).toString(16)).slice(-2)}).join(\"\"))))}catch(t){return null}}var at=function(t){this.type=t,this.anonId=null,this.eventData={},this.queue=[],this.pendingRequest=null};at.prototype.getStorageKey=function(t){var e,r=it(I.ACCESS_TOKEN),n=\"\";return r&&r.u?(e=r.u,n=self.btoa(encodeURIComponent(e).replace(/%([0-9A-F]{2})/g,function(t,e){return String.fromCharCode(Number(\"0x\"+e))}))):n=I.ACCESS_TOKEN||\"\",t?\"mapbox.eventData.\"+t+\":\"+n:\"mapbox.eventData:\"+n},at.prototype.fetchEventData=function(){var t=M(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{var n=self.localStorage.getItem(e);n&&(this.eventData=JSON.parse(n));var i=self.localStorage.getItem(r);i&&(this.anonId=i)}catch(t){w(\"Unable to read from LocalStorage\")}},at.prototype.saveEventData=function(){var t=M(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{self.localStorage.setItem(r,this.anonId),Object.keys(this.eventData).length>=1&&self.localStorage.setItem(e,JSON.stringify(this.eventData))}catch(t){w(\"Unable to write to LocalStorage\")}},at.prototype.processRequests=function(){},at.prototype.postEvent=function(t,e,r){var n=this;if(I.EVENTS_URL){var i=rt(I.EVENTS_URL);i.params.push(\"access_token=\"+(I.ACCESS_TOKEN||\"\"));var a={event:this.type,created:new Date(t).toISOString(),sdkIdentifier:\"mapbox-gl-js\",sdkVersion:\"1.1.1\",skuId:N,userId:this.anonId},o=e?h(a,e):a,s={url:nt(i),headers:{\"Content-Type\":\"text/plain\"},body:JSON.stringify([o])};this.pendingRequest=St(s,function(t){n.pendingRequest=null,r(t),n.saveEventData(),n.processRequests()})}},at.prototype.queueRequest=function(t){this.queue.push(t),this.processRequests()};var ot,st=function(t){function e(){t.call(this,\"map.load\"),this.success={},this.skuToken=\"\"}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.postMapLoadEvent=function(t,e,r){this.skuToken=r,I.EVENTS_URL&&I.ACCESS_TOKEN&&Array.isArray(t)&&t.some(function(t){return q(t)||G(t)})&&this.queueRequest({id:e,timestamp:Date.now()})},e.prototype.processRequests=function(){var t=this;if(!this.pendingRequest&&0!==this.queue.length){var e=this.queue.shift(),r=e.id,n=e.timestamp;r&&this.success[r]||(this.anonId||this.fetchEventData(),g(this.anonId)||(this.anonId=d()),this.postEvent(n,{skuToken:this.skuToken},function(e){e||r&&(t.success[r]=!0)}))}},e}(at),lt=new(function(t){function e(){t.call(this,\"appUserTurnstile\")}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.postTurnstileEvent=function(t){I.EVENTS_URL&&I.ACCESS_TOKEN&&Array.isArray(t)&&t.some(function(t){return q(t)||G(t)})&&this.queueRequest(Date.now())},e.prototype.processRequests=function(){var t=this;if(!this.pendingRequest&&0!==this.queue.length){this.anonId&&this.eventData.lastSuccess&&this.eventData.tokenU||this.fetchEventData();var e=it(I.ACCESS_TOKEN),r=e?e.u:I.ACCESS_TOKEN,n=r!==this.eventData.tokenU;g(this.anonId)||(this.anonId=d(),n=!0);var i=this.queue.shift();if(this.eventData.lastSuccess){var a=new Date(this.eventData.lastSuccess),o=new Date(i),s=(i-this.eventData.lastSuccess)/864e5;n=n||s>=1||s<-1||a.getDate()!==o.getDate()}else n=!0;if(!n)return this.processRequests();this.postEvent(i,{\"enabled.telemetry\":!1},function(e){e||(t.eventData.lastSuccess=i,t.eventData.tokenU=r)})}},e}(at)),ct=lt.postTurnstileEvent.bind(lt),ut=new st,ht=ut.postMapLoadEvent.bind(ut),ft=\"mapbox-tiles\",pt=500,dt=50,gt=42e4;function vt(t){var e=t.indexOf(\"?\");return e<0?t:t.slice(0,e)}var mt=1/0,yt={Unknown:\"Unknown\",Style:\"Style\",Source:\"Source\",Tile:\"Tile\",Glyphs:\"Glyphs\",SpriteImage:\"SpriteImage\",SpriteJSON:\"SpriteJSON\",Image:\"Image\"};\"function\"==typeof Object.freeze&&Object.freeze(yt);var xt=function(t){function e(e,r,n){401===r&&G(n)&&(e+=\": you may have provided an invalid Mapbox access token. See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\"),t.call(this,e),this.status=r,this.url=n,this.name=this.constructor.name,this.message=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.toString=function(){return this.name+\": \"+this.message+\" (\"+this.status+\"): \"+this.url},e}(Error);function bt(){return\"undefined\"!=typeof WorkerGlobalScope&&\"undefined\"!=typeof self&&self instanceof WorkerGlobalScope}var _t=bt()?function(){return self.worker&&self.worker.referrer}:function(){var t=self.location.origin;if(t&&\"null\"!==t&&\"file://\"!==t)return t+self.location.pathname};function wt(t,e){var r,n=new self.AbortController,i=new self.Request(t.url,{method:t.method||\"GET\",body:t.body,credentials:t.credentials,headers:t.headers,referrer:_t(),signal:n.signal}),a=!1,o=!1,s=(r=i.url).indexOf(\"sku=\")>0&&G(r);\"json\"===t.type&&i.headers.set(\"Accept\",\"application/json\");var l=function(r,n,a){if(!o){if(r&&\"SecurityError\"!==r.message&&w(r),n&&a)return c(n);var l=Date.now();self.fetch(i).then(function(r){if(r.ok){var n=s?r.clone():null;return c(r,n,l)}return e(new xt(r.statusText,r.status,t.url))}).catch(function(t){20!==t.code&&e(new Error(t.message))})}},c=function(r,n,s){(\"arrayBuffer\"===t.type?r.arrayBuffer():\"json\"===t.type?r.json():r.text()).then(function(t){o||(n&&s&&function(t,e,r){if(self.caches){var n={status:e.status,statusText:e.statusText,headers:new self.Headers};e.headers.forEach(function(t,e){return n.headers.set(e,t)});var i=A(e.headers.get(\"Cache-Control\")||\"\");i[\"no-store\"]||(i[\"max-age\"]&&n.headers.set(\"Expires\",new Date(r+1e3*i[\"max-age\"]).toUTCString()),new Date(n.headers.get(\"Expires\")).getTime()-r<gt||function(t,e){if(void 0===ot)try{new Response(new ReadableStream),ot=!0}catch(t){ot=!1}ot?e(t.body):t.blob().then(e)}(e,function(e){var r=new self.Response(e,n);self.caches.open(ft).then(function(e){return e.put(vt(t.url),r)})}))}}(i,n,s),a=!0,e(null,t,r.headers.get(\"Cache-Control\"),r.headers.get(\"Expires\")))}).catch(function(t){return e(new Error(t.message))})};return s?function(t,e){if(!self.caches)return e(null);var r=vt(t.url);self.caches.open(ft).catch(e).then(function(t){t.match(r).catch(e).then(function(n){var i=function(t){if(!t)return!1;var e=new Date(t.headers.get(\"Expires\")),r=A(t.headers.get(\"Cache-Control\")||\"\");return e>Date.now()&&!r[\"no-cache\"]}(n);t.delete(r),i&&t.put(r,n.clone()),e(null,n,i)})})}(i,l):l(null,null),{cancel:function(){o=!0,a||n.abort()}}}var kt,Tt,At=function(t,e){if(!/^file:/.test(t.url)){if(self.fetch&&self.Request&&self.AbortController&&self.Request.prototype.hasOwnProperty(\"signal\"))return wt(t,e);if(bt()&&self.worker&&self.worker.actor)return self.worker.actor.send(\"getResource\",t,e)}return function(t,e){var r=new self.XMLHttpRequest;for(var n in r.open(t.method||\"GET\",t.url,!0),\"arrayBuffer\"===t.type&&(r.responseType=\"arraybuffer\"),t.headers)r.setRequestHeader(n,t.headers[n]);return\"json\"===t.type&&r.setRequestHeader(\"Accept\",\"application/json\"),r.withCredentials=\"include\"===t.credentials,r.onerror=function(){e(new Error(r.statusText))},r.onload=function(){if((r.status>=200&&r.status<300||0===r.status)&&null!==r.response){var n=r.response;if(\"json\"===t.type)try{n=JSON.parse(r.response)}catch(t){return e(t)}e(null,n,r.getResponseHeader(\"Cache-Control\"),r.getResponseHeader(\"Expires\"))}else e(new xt(r.statusText,r.status,t.url))},r.send(t.body),{cancel:function(){return r.abort()}}}(t,e)},Mt=function(t,e){return At(h(t,{type:\"arrayBuffer\"}),e)},St=function(t,e){return At(h(t,{method:\"POST\"}),e)};kt=[],Tt=0;var Et=function(t,e){if(Tt>=I.MAX_PARALLEL_IMAGE_REQUESTS){var r={requestParameters:t,callback:e,cancelled:!1,cancel:function(){this.cancelled=!0}};return kt.push(r),r}Tt++;var n=!1,i=function(){if(!n)for(n=!0,Tt--;kt.length&&Tt<I.MAX_PARALLEL_IMAGE_REQUESTS;){var t=kt.shift(),e=t.requestParameters,r=t.callback;t.cancelled||(t.cancel=Et(e,r).cancel)}},a=Mt(t,function(t,r,n,a){if(i(),t)e(t);else if(r){var o=new self.Image,s=self.URL||self.webkitURL;o.onload=function(){e(null,o),s.revokeObjectURL(o.src)},o.onerror=function(){return e(new Error(\"Could not load image. Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.\"))};var l=new self.Blob([new Uint8Array(r)],{type:\"image/png\"});o.cacheControl=n,o.expires=a,o.src=r.byteLength?s.createObjectURL(l):\"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAC0lEQVQYV2NgAAIAAAUAAarVyFEAAAAASUVORK5CYII=\"}});return{cancel:function(){a.cancel(),i()}}};function Ct(t,e,r){r[t]&&-1!==r[t].indexOf(e)||(r[t]=r[t]||[],r[t].push(e))}function Lt(t,e,r){if(r&&r[t]){var n=r[t].indexOf(e);-1!==n&&r[t].splice(n,1)}}var Pt=function(t,e){void 0===e&&(e={}),h(this,e),this.type=t},Ot=function(t){function e(e,r){void 0===r&&(r={}),t.call(this,\"error\",h({error:e},r))}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Pt),zt=function(){};zt.prototype.on=function(t,e){return this._listeners=this._listeners||{},Ct(t,e,this._listeners),this},zt.prototype.off=function(t,e){return Lt(t,e,this._listeners),Lt(t,e,this._oneTimeListeners),this},zt.prototype.once=function(t,e){return this._oneTimeListeners=this._oneTimeListeners||{},Ct(t,e,this._oneTimeListeners),this},zt.prototype.fire=function(t,e){\"string\"==typeof t&&(t=new Pt(t,e||{}));var r=t.type;if(this.listens(r)){t.target=this;for(var n=0,i=this._listeners&&this._listeners[r]?this._listeners[r].slice():[];n<i.length;n+=1)i[n].call(this,t);for(var a=0,o=this._oneTimeListeners&&this._oneTimeListeners[r]?this._oneTimeListeners[r].slice():[];a<o.length;a+=1){var s=o[a];Lt(r,s,this._oneTimeListeners),s.call(this,t)}var l=this._eventedParent;l&&(h(t,\"function\"==typeof this._eventedParentData?this._eventedParentData():this._eventedParentData),l.fire(t))}else t instanceof Ot&&console.error(t.error);return this},zt.prototype.listens=function(t){return this._listeners&&this._listeners[t]&&this._listeners[t].length>0||this._oneTimeListeners&&this._oneTimeListeners[t]&&this._oneTimeListeners[t].length>0||this._eventedParent&&this._eventedParent.listens(t)},zt.prototype.setEventedParent=function(t,e){return this._eventedParent=t,this._eventedParentData=e,this};var It={$version:8,$root:{version:{required:!0,type:\"enum\",values:[8]},name:{type:\"string\"},metadata:{type:\"*\"},center:{type:\"array\",value:\"number\"},zoom:{type:\"number\"},bearing:{type:\"number\",default:0,period:360,units:\"degrees\"},pitch:{type:\"number\",default:0,units:\"degrees\"},light:{type:\"light\"},sources:{required:!0,type:\"sources\"},sprite:{type:\"string\"},glyphs:{type:\"string\"},transition:{type:\"transition\"},layers:{required:!0,type:\"array\",value:\"layer\"}},sources:{\"*\":{type:\"source\"}},source:[\"source_vector\",\"source_raster\",\"source_raster_dem\",\"source_geojson\",\"source_video\",\"source_image\"],source_vector:{type:{required:!0,type:\"enum\",values:{vector:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},attribution:{type:\"string\"},\"*\":{type:\"*\"}},source_raster:{type:{required:!0,type:\"enum\",values:{raster:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},attribution:{type:\"string\"},\"*\":{type:\"*\"}},source_raster_dem:{type:{required:!0,type:\"enum\",values:{\"raster-dem\":{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},attribution:{type:\"string\"},encoding:{type:\"enum\",values:{terrarium:{},mapbox:{}},default:\"mapbox\"},\"*\":{type:\"*\"}},source_geojson:{type:{required:!0,type:\"enum\",values:{geojson:{}}},data:{type:\"*\"},maxzoom:{type:\"number\",default:18},attribution:{type:\"string\"},buffer:{type:\"number\",default:128,maximum:512,minimum:0},tolerance:{type:\"number\",default:.375},cluster:{type:\"boolean\",default:!1},clusterRadius:{type:\"number\",default:50,minimum:0},clusterMaxZoom:{type:\"number\"},clusterProperties:{type:\"*\"},lineMetrics:{type:\"boolean\",default:!1},generateId:{type:\"boolean\",default:!1}},source_video:{type:{required:!0,type:\"enum\",values:{video:{}}},urls:{required:!0,type:\"array\",value:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},source_image:{type:{required:!0,type:\"enum\",values:{image:{}}},url:{required:!0,type:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},layer:{id:{type:\"string\",required:!0},type:{type:\"enum\",values:{fill:{},line:{},symbol:{},circle:{},heatmap:{},\"fill-extrusion\":{},raster:{},hillshade:{},background:{}},required:!0},metadata:{type:\"*\"},source:{type:\"string\"},\"source-layer\":{type:\"string\"},minzoom:{type:\"number\",minimum:0,maximum:24},maxzoom:{type:\"number\",minimum:0,maximum:24},filter:{type:\"filter\"},layout:{type:\"layout\"},paint:{type:\"paint\"}},layout:[\"layout_fill\",\"layout_line\",\"layout_circle\",\"layout_heatmap\",\"layout_fill-extrusion\",\"layout_symbol\",\"layout_raster\",\"layout_hillshade\",\"layout_background\"],layout_background:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_fill:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_circle:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_heatmap:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},\"layout_fill-extrusion\":{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_line:{\"line-cap\":{type:\"enum\",values:{butt:{},round:{},square:{}},default:\"butt\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-join\":{type:\"enum\",values:{bevel:{},round:{},miter:{}},default:\"miter\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"line-miter-limit\":{type:\"number\",default:2,requires:[{\"line-join\":\"miter\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-round-limit\":{type:\"number\",default:1.05,requires:[{\"line-join\":\"round\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_symbol:{\"symbol-placement\":{type:\"enum\",values:{point:{},line:{},\"line-center\":{}},default:\"point\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-spacing\":{type:\"number\",default:250,minimum:1,units:\"pixels\",requires:[{\"symbol-placement\":\"line\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-avoid-edges\":{type:\"boolean\",default:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"symbol-z-order\":{type:\"enum\",values:{auto:{},\"viewport-y\":{},source:{}},default:\"auto\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-optional\":{type:\"boolean\",default:!1,requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-size\":{type:\"number\",default:1,minimum:0,units:\"factor of the original icon size\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-text-fit\":{type:\"enum\",values:{none:{},width:{},height:{},both:{}},default:\"none\",requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-text-fit-padding\":{type:\"array\",value:\"number\",length:4,default:[0,0,0,0],units:\"pixels\",requires:[\"icon-image\",\"text-field\",{\"icon-text-fit\":[\"both\",\"width\",\"height\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-image\":{type:\"string\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-keep-upright\":{type:\"boolean\",default:!1,requires:[\"icon-image\",{\"icon-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-offset\":{type:\"array\",value:\"number\",length:2,default:[0,0],requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-anchor\":{type:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-field\":{type:\"formatted\",default:\"\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-font\":{type:\"array\",value:\"string\",default:[\"Open Sans Regular\",\"Arial Unicode MS Regular\"],requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-size\":{type:\"number\",default:16,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-width\":{type:\"number\",default:10,minimum:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-line-height\":{type:\"number\",default:1.2,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-letter-spacing\":{type:\"number\",default:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-justify\":{type:\"enum\",values:{auto:{},left:{},center:{},right:{}},default:\"center\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-radial-offset\":{type:\"number\",units:\"ems\",default:0,requires:[{\"!\":\"text-offset\"}],\"property-type\":\"data-driven\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]}},\"text-variable-anchor\":{type:\"array\",value:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},requires:[{\"!\":\"text-anchor\"},{\"!\":\"text-offset\"},{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-anchor\":{type:\"enum\",requires:[\"text-field\"],values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-angle\":{type:\"number\",default:45,units:\"degrees\",requires:[\"text-field\",{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-keep-upright\":{type:\"boolean\",default:!0,requires:[\"text-field\",{\"text-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-transform\":{type:\"enum\",values:{none:{},uppercase:{},lowercase:{}},default:\"none\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-offset\":{type:\"array\",value:\"number\",units:\"ems\",length:2,default:[0,0],requires:[\"text-field\",{\"!\":\"text-radial-offset\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-optional\":{type:\"boolean\",default:!1,requires:[\"text-field\",\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_raster:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_hillshade:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},filter:{type:\"array\",value:\"*\"},filter_operator:{type:\"enum\",values:{\"==\":{},\"!=\":{},\">\":{},\">=\":{},\"<\":{},\"<=\":{},in:{},\"!in\":{},all:{},any:{},none:{},has:{},\"!has\":{}}},geometry_type:{type:\"enum\",values:{Point:{},LineString:{},Polygon:{}}},function:{expression:{type:\"expression\"},stops:{type:\"array\",value:\"function_stop\"},base:{type:\"number\",default:1,minimum:0},property:{type:\"string\",default:\"$zoom\"},type:{type:\"enum\",values:{identity:{},exponential:{},interval:{},categorical:{}},default:\"exponential\"},colorSpace:{type:\"enum\",values:{rgb:{},lab:{},hcl:{}},default:\"rgb\"},default:{type:\"*\",required:!1}},function_stop:{type:\"array\",minimum:0,maximum:22,value:[\"number\",\"color\"],length:2},expression:{type:\"array\",value:\"*\",minimum:1},expression_name:{type:\"enum\",values:{let:{group:\"Variable binding\"},var:{group:\"Variable binding\"},literal:{group:\"Types\"},array:{group:\"Types\"},at:{group:\"Lookup\"},case:{group:\"Decision\"},match:{group:\"Decision\"},coalesce:{group:\"Decision\"},step:{group:\"Ramps, scales, curves\"},interpolate:{group:\"Ramps, scales, curves\"},\"interpolate-hcl\":{group:\"Ramps, scales, curves\"},\"interpolate-lab\":{group:\"Ramps, scales, curves\"},ln2:{group:\"Math\"},pi:{group:\"Math\"},e:{group:\"Math\"},typeof:{group:\"Types\"},string:{group:\"Types\"},number:{group:\"Types\"},boolean:{group:\"Types\"},object:{group:\"Types\"},collator:{group:\"Types\"},format:{group:\"Types\"},\"number-format\":{group:\"Types\"},\"to-string\":{group:\"Types\"},\"to-number\":{group:\"Types\"},\"to-boolean\":{group:\"Types\"},\"to-rgba\":{group:\"Color\"},\"to-color\":{group:\"Types\"},rgb:{group:\"Color\"},rgba:{group:\"Color\"},get:{group:\"Lookup\"},has:{group:\"Lookup\"},length:{group:\"Lookup\"},properties:{group:\"Feature data\"},\"feature-state\":{group:\"Feature data\"},\"geometry-type\":{group:\"Feature data\"},id:{group:\"Feature data\"},zoom:{group:\"Zoom\"},\"heatmap-density\":{group:\"Heatmap\"},\"line-progress\":{group:\"Feature data\"},accumulated:{group:\"Feature data\"},\"+\":{group:\"Math\"},\"*\":{group:\"Math\"},\"-\":{group:\"Math\"},\"/\":{group:\"Math\"},\"%\":{group:\"Math\"},\"^\":{group:\"Math\"},sqrt:{group:\"Math\"},log10:{group:\"Math\"},ln:{group:\"Math\"},log2:{group:\"Math\"},sin:{group:\"Math\"},cos:{group:\"Math\"},tan:{group:\"Math\"},asin:{group:\"Math\"},acos:{group:\"Math\"},atan:{group:\"Math\"},min:{group:\"Math\"},max:{group:\"Math\"},round:{group:\"Math\"},abs:{group:\"Math\"},ceil:{group:\"Math\"},floor:{group:\"Math\"},\"==\":{group:\"Decision\"},\"!=\":{group:\"Decision\"},\">\":{group:\"Decision\"},\"<\":{group:\"Decision\"},\">=\":{group:\"Decision\"},\"<=\":{group:\"Decision\"},all:{group:\"Decision\"},any:{group:\"Decision\"},\"!\":{group:\"Decision\"},\"is-supported-script\":{group:\"String\"},upcase:{group:\"String\"},downcase:{group:\"String\"},concat:{group:\"String\"},\"resolved-locale\":{group:\"String\"}}},light:{anchor:{type:\"enum\",default:\"viewport\",values:{map:{},viewport:{}},\"property-type\":\"data-constant\",transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]}},position:{type:\"array\",default:[1.15,210,30],length:3,value:\"number\",\"property-type\":\"data-constant\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]}},color:{type:\"color\",\"property-type\":\"data-constant\",default:\"#ffffff\",expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0},intensity:{type:\"number\",\"property-type\":\"data-constant\",default:.5,minimum:0,maximum:1,expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0}},paint:[\"paint_fill\",\"paint_line\",\"paint_circle\",\"paint_heatmap\",\"paint_fill-extrusion\",\"paint_symbol\",\"paint_raster\",\"paint_hillshade\",\"paint_background\"],paint_fill:{\"fill-antialias\":{type:\"boolean\",default:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-outline-color\":{type:\"color\",transition:!0,requires:[{\"!\":\"fill-pattern\"},{\"fill-antialias\":!0}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"}},\"paint_fill-extrusion\":{\"fill-extrusion-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-extrusion-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-extrusion-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"fill-extrusion-height\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-base\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,requires:[\"fill-extrusion-height\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-vertical-gradient\":{type:\"boolean\",default:!0,transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_line:{\"line-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"line-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-width\":{type:\"number\",default:1,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-gap-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-offset\":{type:\"number\",default:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-dasharray\":{type:\"array\",value:\"number\",minimum:0,transition:!0,units:\"line widths\",requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"line-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"line-gradient\":{type:\"color\",transition:!1,requires:[{\"!\":\"line-dasharray\"},{\"!\":\"line-pattern\"},{source:\"geojson\",has:{lineMetrics:!0}}],expression:{interpolated:!0,parameters:[\"line-progress\"]},\"property-type\":\"color-ramp\"}},paint_circle:{\"circle-radius\":{type:\"number\",default:5,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-blur\":{type:\"number\",default:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"circle-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-scale\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-stroke-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"}},paint_heatmap:{\"heatmap-radius\":{type:\"number\",default:30,minimum:1,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-weight\":{type:\"number\",default:1,minimum:0,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-intensity\":{type:\"number\",default:1,minimum:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"heatmap-color\":{type:\"color\",default:[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,\"rgba(0, 0, 255, 0)\",.1,\"royalblue\",.3,\"cyan\",.5,\"lime\",.7,\"yellow\",1,\"red\"],transition:!1,expression:{interpolated:!0,parameters:[\"heatmap-density\"]},\"property-type\":\"color-ramp\"},\"heatmap-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_symbol:{\"icon-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"icon-image\",\"icon-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"text-field\",\"text-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_raster:{\"raster-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-hue-rotate\":{type:\"number\",default:0,period:360,transition:!0,units:\"degrees\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-min\":{type:\"number\",default:0,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-max\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-saturation\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-contrast\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-resampling\":{type:\"enum\",values:{linear:{},nearest:{}},default:\"linear\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-fade-duration\":{type:\"number\",default:300,minimum:0,transition:!1,units:\"milliseconds\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_hillshade:{\"hillshade-illumination-direction\":{type:\"number\",default:335,minimum:0,maximum:359,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-illumination-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-exaggeration\":{type:\"number\",default:.5,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-shadow-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-highlight-color\":{type:\"color\",default:\"#FFFFFF\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-accent-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_background:{\"background-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"background-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"background-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"background-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},transition:{duration:{type:\"number\",default:300,minimum:0,units:\"milliseconds\"},delay:{type:\"number\",default:0,minimum:0,units:\"milliseconds\"}},\"property-type\":{\"data-driven\":{type:\"property-type\"},\"cross-faded\":{type:\"property-type\"},\"cross-faded-data-driven\":{type:\"property-type\"},\"color-ramp\":{type:\"property-type\"},\"data-constant\":{type:\"property-type\"},constant:{type:\"property-type\"}}},Dt=function(t,e,r,n){this.message=(t?t+\": \":\"\")+r,n&&(this.identifier=n),null!=e&&e.__line__&&(this.line=e.__line__)};function Rt(t){var e=t.key,r=t.value;return r?[new Dt(e,r,\"constants have been deprecated as of v8\")]:[]}function Ft(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}function Bt(t){return t instanceof Number||t instanceof String||t instanceof Boolean}function Nt(t){return Bt(t)?t.valueOf():t}function jt(t){if(Array.isArray(t))return t.map(jt);if(t instanceof Object&&!Bt(t)){var e={};for(var r in t)e[r]=jt(t[r]);return e}return Nt(t)}var Ut=function(t){function e(e,r){t.call(this,r),this.message=r,this.key=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Error),Vt=function(t,e){void 0===e&&(e=[]),this.parent=t,this.bindings={};for(var r=0,n=e;r<n.length;r+=1){var i=n[r],a=i[0],o=i[1];this.bindings[a]=o}};Vt.prototype.concat=function(t){return new Vt(this,t)},Vt.prototype.get=function(t){if(this.bindings[t])return this.bindings[t];if(this.parent)return this.parent.get(t);throw new Error(t+\" not found in scope.\")},Vt.prototype.has=function(t){return!!this.bindings[t]||!!this.parent&&this.parent.has(t)};var qt={kind:\"null\"},Ht={kind:\"number\"},Gt={kind:\"string\"},Yt={kind:\"boolean\"},Wt={kind:\"color\"},Xt={kind:\"object\"},Zt={kind:\"value\"},Jt={kind:\"collator\"},Kt={kind:\"formatted\"};function $t(t,e){return{kind:\"array\",itemType:t,N:e}}function Qt(t){if(\"array\"===t.kind){var e=Qt(t.itemType);return\"number\"==typeof t.N?\"array<\"+e+\", \"+t.N+\">\":\"value\"===t.itemType.kind?\"array\":\"array<\"+e+\">\"}return t.kind}var te=[qt,Ht,Gt,Yt,Wt,Kt,Xt,$t(Zt)];function ee(t,e){if(\"error\"===e.kind)return null;if(\"array\"===t.kind){if(\"array\"===e.kind&&(0===e.N&&\"value\"===e.itemType.kind||!ee(t.itemType,e.itemType))&&(\"number\"!=typeof t.N||t.N===e.N))return null}else{if(t.kind===e.kind)return null;if(\"value\"===t.kind)for(var r=0,n=te;r<n.length;r+=1)if(!ee(n[r],e))return null}return\"Expected \"+Qt(t)+\" but found \"+Qt(e)+\" instead.\"}var re=e(function(t,e){var r={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],rebeccapurple:[102,51,153,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function n(t){return(t=Math.round(t))<0?0:t>255?255:t}function i(t){return t<0?0:t>1?1:t}function a(t){return\"%\"===t[t.length-1]?n(parseFloat(t)/100*255):n(parseInt(t))}function o(t){return\"%\"===t[t.length-1]?i(parseFloat(t)/100):i(parseFloat(t))}function s(t,e,r){return r<0?r+=1:r>1&&(r-=1),6*r<1?t+(e-t)*r*6:2*r<1?e:3*r<2?t+(e-t)*(2/3-r)*6:t}try{e.parseCSSColor=function(t){var e,i=t.replace(/ /g,\"\").toLowerCase();if(i in r)return r[i].slice();if(\"#\"===i[0])return 4===i.length?(e=parseInt(i.substr(1),16))>=0&&e<=4095?[(3840&e)>>4|(3840&e)>>8,240&e|(240&e)>>4,15&e|(15&e)<<4,1]:null:7===i.length&&(e=parseInt(i.substr(1),16))>=0&&e<=16777215?[(16711680&e)>>16,(65280&e)>>8,255&e,1]:null;var l=i.indexOf(\"(\"),c=i.indexOf(\")\");if(-1!==l&&c+1===i.length){var u=i.substr(0,l),h=i.substr(l+1,c-(l+1)).split(\",\"),f=1;switch(u){case\"rgba\":if(4!==h.length)return null;f=o(h.pop());case\"rgb\":return 3!==h.length?null:[a(h[0]),a(h[1]),a(h[2]),f];case\"hsla\":if(4!==h.length)return null;f=o(h.pop());case\"hsl\":if(3!==h.length)return null;var p=(parseFloat(h[0])%360+360)%360/360,d=o(h[1]),g=o(h[2]),v=g<=.5?g*(d+1):g+d-g*d,m=2*g-v;return[n(255*s(m,v,p+1/3)),n(255*s(m,v,p)),n(255*s(m,v,p-1/3)),f];default:return null}}return null}}catch(t){}}).parseCSSColor,ne=function(t,e,r,n){void 0===n&&(n=1),this.r=t,this.g=e,this.b=r,this.a=n};ne.parse=function(t){if(t){if(t instanceof ne)return t;if(\"string\"==typeof t){var e=re(t);if(e)return new ne(e[0]/255*e[3],e[1]/255*e[3],e[2]/255*e[3],e[3])}}},ne.prototype.toString=function(){var t=this.toArray(),e=t[0],r=t[1],n=t[2],i=t[3];return\"rgba(\"+Math.round(e)+\",\"+Math.round(r)+\",\"+Math.round(n)+\",\"+i+\")\"},ne.prototype.toArray=function(){var t=this.r,e=this.g,r=this.b,n=this.a;return 0===n?[0,0,0,0]:[255*t/n,255*e/n,255*r/n,n]},ne.black=new ne(0,0,0,1),ne.white=new ne(1,1,1,1),ne.transparent=new ne(0,0,0,0),ne.red=new ne(1,0,0,1);var ie=function(t,e,r){this.sensitivity=t?e?\"variant\":\"case\":e?\"accent\":\"base\",this.locale=r,this.collator=new Intl.Collator(this.locale?this.locale:[],{sensitivity:this.sensitivity,usage:\"search\"})};ie.prototype.compare=function(t,e){return this.collator.compare(t,e)},ie.prototype.resolvedLocale=function(){return new Intl.Collator(this.locale?this.locale:[]).resolvedOptions().locale};var ae=function(t,e,r){this.text=t,this.scale=e,this.fontStack=r},oe=function(t){this.sections=t};function se(t,e,r,n){return\"number\"==typeof t&&t>=0&&t<=255&&\"number\"==typeof e&&e>=0&&e<=255&&\"number\"==typeof r&&r>=0&&r<=255?void 0===n||\"number\"==typeof n&&n>=0&&n<=1?null:\"Invalid rgba value [\"+[t,e,r,n].join(\", \")+\"]: 'a' must be between 0 and 1.\":\"Invalid rgba value [\"+(\"number\"==typeof n?[t,e,r,n]:[t,e,r]).join(\", \")+\"]: 'r', 'g', and 'b' must be between 0 and 255.\"}function le(t){if(null===t)return qt;if(\"string\"==typeof t)return Gt;if(\"boolean\"==typeof t)return Yt;if(\"number\"==typeof t)return Ht;if(t instanceof ne)return Wt;if(t instanceof ie)return Jt;if(t instanceof oe)return Kt;if(Array.isArray(t)){for(var e,r=t.length,n=0,i=t;n<i.length;n+=1){var a=le(i[n]);if(e){if(e===a)continue;e=Zt;break}e=a}return $t(e||Zt,r)}return Xt}function ce(t){var e=typeof t;return null===t?\"\":\"string\"===e||\"number\"===e||\"boolean\"===e?String(t):t instanceof ne||t instanceof oe?t.toString():JSON.stringify(t)}oe.fromString=function(t){return new oe([new ae(t,null,null)])},oe.prototype.toString=function(){return this.sections.map(function(t){return t.text}).join(\"\")},oe.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.text);var i={};n.fontStack&&(i[\"text-font\"]=[\"literal\",n.fontStack.split(\",\")]),n.scale&&(i[\"font-scale\"]=n.scale),t.push(i)}return t};var ue=function(t,e){this.type=t,this.value=e};ue.parse=function(t,e){if(2!==t.length)return e.error(\"'literal' expression requires exactly one argument, but found \"+(t.length-1)+\" instead.\");if(!function t(e){if(null===e)return!0;if(\"string\"==typeof e)return!0;if(\"boolean\"==typeof e)return!0;if(\"number\"==typeof e)return!0;if(e instanceof ne)return!0;if(e instanceof ie)return!0;if(e instanceof oe)return!0;if(Array.isArray(e)){for(var r=0,n=e;r<n.length;r+=1)if(!t(n[r]))return!1;return!0}if(\"object\"==typeof e){for(var i in e)if(!t(e[i]))return!1;return!0}return!1}(t[1]))return e.error(\"invalid value\");var r=t[1],n=le(r),i=e.expectedType;return\"array\"!==n.kind||0!==n.N||!i||\"array\"!==i.kind||\"number\"==typeof i.N&&0!==i.N||(n=i),new ue(n,r)},ue.prototype.evaluate=function(){return this.value},ue.prototype.eachChild=function(){},ue.prototype.possibleOutputs=function(){return[this.value]},ue.prototype.serialize=function(){return\"array\"===this.type.kind||\"object\"===this.type.kind?[\"literal\",this.value]:this.value instanceof ne?[\"rgba\"].concat(this.value.toArray()):this.value instanceof oe?this.value.serialize():this.value};var he=function(t){this.name=\"ExpressionEvaluationError\",this.message=t};he.prototype.toJSON=function(){return this.message};var fe={string:Gt,number:Ht,boolean:Yt,object:Xt},pe=function(t,e){this.type=t,this.args=e};pe.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r,n=1,i=t[0];if(\"array\"===i){var a,o;if(t.length>2){var s=t[1];if(\"string\"!=typeof s||!(s in fe)||\"object\"===s)return e.error('The item type argument of \"array\" must be one of string, number, boolean',1);a=fe[s],n++}else a=Zt;if(t.length>3){if(null!==t[2]&&(\"number\"!=typeof t[2]||t[2]<0||t[2]!==Math.floor(t[2])))return e.error('The length argument to \"array\" must be a positive integer literal',2);o=t[2],n++}r=$t(a,o)}else r=fe[i];for(var l=[];n<t.length;n++){var c=e.parse(t[n],n,Zt);if(!c)return null;l.push(c)}return new pe(r,l)},pe.prototype.evaluate=function(t){for(var e=0;e<this.args.length;e++){var r=this.args[e].evaluate(t);if(!ee(this.type,le(r)))return r;if(e===this.args.length-1)throw new he(\"Expected value to be of type \"+Qt(this.type)+\", but found \"+Qt(le(r))+\" instead.\")}return null},pe.prototype.eachChild=function(t){this.args.forEach(t)},pe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},pe.prototype.serialize=function(){var t=this.type,e=[t.kind];if(\"array\"===t.kind){var r=t.itemType;if(\"string\"===r.kind||\"number\"===r.kind||\"boolean\"===r.kind){e.push(r.kind);var n=t.N;(\"number\"==typeof n||this.args.length>1)&&e.push(n)}}return e.concat(this.args.map(function(t){return t.serialize()}))};var de=function(t){this.type=Kt,this.sections=t};de.parse=function(t,e){if(t.length<3)return e.error(\"Expected at least two arguments.\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");for(var r=[],n=1;n<t.length-1;n+=2){var i=e.parse(t[n],1,Zt);if(!i)return null;var a=i.type.kind;if(\"string\"!==a&&\"value\"!==a&&\"null\"!==a)return e.error(\"Formatted text type must be 'string', 'value', or 'null'.\");var o=t[n+1];if(\"object\"!=typeof o||Array.isArray(o))return e.error(\"Format options argument must be an object.\");var s=null;if(o[\"font-scale\"]&&!(s=e.parse(o[\"font-scale\"],1,Ht)))return null;var l=null;if(o[\"text-font\"]&&!(l=e.parse(o[\"text-font\"],1,$t(Gt))))return null;r.push({text:i,scale:s,font:l})}return new de(r)},de.prototype.evaluate=function(t){return new oe(this.sections.map(function(e){return new ae(ce(e.text.evaluate(t)),e.scale?e.scale.evaluate(t):null,e.font?e.font.evaluate(t).join(\",\"):null)}))},de.prototype.eachChild=function(t){for(var e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t(n.text),n.scale&&t(n.scale),n.font&&t(n.font)}},de.prototype.possibleOutputs=function(){return[void 0]},de.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.text.serialize());var i={};n.scale&&(i[\"font-scale\"]=n.scale.serialize()),n.font&&(i[\"text-font\"]=n.font.serialize()),t.push(i)}return t};var ge={\"to-boolean\":Yt,\"to-color\":Wt,\"to-number\":Ht,\"to-string\":Gt},ve=function(t,e){this.type=t,this.args=e};ve.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r=t[0];if((\"to-boolean\"===r||\"to-string\"===r)&&2!==t.length)return e.error(\"Expected one argument.\");for(var n=ge[r],i=[],a=1;a<t.length;a++){var o=e.parse(t[a],a,Zt);if(!o)return null;i.push(o)}return new ve(n,i)},ve.prototype.evaluate=function(t){if(\"boolean\"===this.type.kind)return Boolean(this.args[0].evaluate(t));if(\"color\"===this.type.kind){for(var e,r,n=0,i=this.args;n<i.length;n+=1){if(r=null,(e=i[n].evaluate(t))instanceof ne)return e;if(\"string\"==typeof e){var a=t.parseColor(e);if(a)return a}else if(Array.isArray(e)&&!(r=e.length<3||e.length>4?\"Invalid rbga value \"+JSON.stringify(e)+\": expected an array containing either three or four numeric values.\":se(e[0],e[1],e[2],e[3])))return new ne(e[0]/255,e[1]/255,e[2]/255,e[3])}throw new he(r||\"Could not parse color from value '\"+(\"string\"==typeof e?e:String(JSON.stringify(e)))+\"'\")}if(\"number\"===this.type.kind){for(var o=null,s=0,l=this.args;s<l.length;s+=1){if(null===(o=l[s].evaluate(t)))return 0;var c=Number(o);if(!isNaN(c))return c}throw new he(\"Could not convert \"+JSON.stringify(o)+\" to number.\")}return\"formatted\"===this.type.kind?oe.fromString(ce(this.args[0].evaluate(t))):ce(this.args[0].evaluate(t))},ve.prototype.eachChild=function(t){this.args.forEach(t)},ve.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},ve.prototype.serialize=function(){if(\"formatted\"===this.type.kind)return new de([{text:this.args[0],scale:null,font:null}]).serialize();var t=[\"to-\"+this.type.kind];return this.eachChild(function(e){t.push(e.serialize())}),t};var me=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],ye=function(){this.globals=null,this.feature=null,this.featureState=null,this._parseColorCache={}};ye.prototype.id=function(){return this.feature&&\"id\"in this.feature?this.feature.id:null},ye.prototype.geometryType=function(){return this.feature?\"number\"==typeof this.feature.type?me[this.feature.type]:this.feature.type:null},ye.prototype.properties=function(){return this.feature&&this.feature.properties||{}},ye.prototype.parseColor=function(t){var e=this._parseColorCache[t];return e||(e=this._parseColorCache[t]=ne.parse(t)),e};var xe=function(t,e,r,n){this.name=t,this.type=e,this._evaluate=r,this.args=n};xe.prototype.evaluate=function(t){return this._evaluate(t,this.args)},xe.prototype.eachChild=function(t){this.args.forEach(t)},xe.prototype.possibleOutputs=function(){return[void 0]},xe.prototype.serialize=function(){return[this.name].concat(this.args.map(function(t){return t.serialize()}))},xe.parse=function(t,e){var r,n=t[0],i=xe.definitions[n];if(!i)return e.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0);for(var a=Array.isArray(i)?i[0]:i.type,o=Array.isArray(i)?[[i[1],i[2]]]:i.overloads,s=o.filter(function(e){var r=e[0];return!Array.isArray(r)||r.length===t.length-1}),l=null,c=0,u=s;c<u.length;c+=1){var h=u[c],f=h[0],p=h[1];l=new Ae(e.registry,e.path,null,e.scope);for(var d=[],g=!1,v=1;v<t.length;v++){var m=t[v],y=Array.isArray(f)?f[v-1]:f.type,x=l.parse(m,1+d.length,y);if(!x){g=!0;break}d.push(x)}if(!g)if(Array.isArray(f)&&f.length!==d.length)l.error(\"Expected \"+f.length+\" arguments, but found \"+d.length+\" instead.\");else{for(var b=0;b<d.length;b++){var _=Array.isArray(f)?f[b]:f.type,w=d[b];l.concat(b+1).checkSubtype(_,w.type)}if(0===l.errors.length)return new xe(n,a,p,d)}}if(1===s.length)(r=e.errors).push.apply(r,l.errors);else{for(var k=(s.length?s:o).map(function(t){var e;return e=t[0],Array.isArray(e)?\"(\"+e.map(Qt).join(\", \")+\")\":\"(\"+Qt(e.type)+\"...)\"}).join(\" | \"),T=[],A=1;A<t.length;A++){var M=e.parse(t[A],1+T.length);if(!M)return null;T.push(Qt(M.type))}e.error(\"Expected arguments of type \"+k+\", but found (\"+T.join(\", \")+\") instead.\")}return null},xe.register=function(t,e){for(var r in xe.definitions=e,e)t[r]=xe};var be=function(t,e,r){this.type=Jt,this.locale=r,this.caseSensitive=t,this.diacriticSensitive=e};function _e(t){if(t instanceof xe){if(\"get\"===t.name&&1===t.args.length)return!1;if(\"feature-state\"===t.name)return!1;if(\"has\"===t.name&&1===t.args.length)return!1;if(\"properties\"===t.name||\"geometry-type\"===t.name||\"id\"===t.name)return!1;if(/^filter-/.test(t.name))return!1}var e=!0;return t.eachChild(function(t){e&&!_e(t)&&(e=!1)}),e}function we(t){if(t instanceof xe&&\"feature-state\"===t.name)return!1;var e=!0;return t.eachChild(function(t){e&&!we(t)&&(e=!1)}),e}function ke(t,e){if(t instanceof xe&&e.indexOf(t.name)>=0)return!1;var r=!0;return t.eachChild(function(t){r&&!ke(t,e)&&(r=!1)}),r}be.parse=function(t,e){if(2!==t.length)return e.error(\"Expected one argument.\");var r=t[1];if(\"object\"!=typeof r||Array.isArray(r))return e.error(\"Collator options argument must be an object.\");var n=e.parse(void 0!==r[\"case-sensitive\"]&&r[\"case-sensitive\"],1,Yt);if(!n)return null;var i=e.parse(void 0!==r[\"diacritic-sensitive\"]&&r[\"diacritic-sensitive\"],1,Yt);if(!i)return null;var a=null;return r.locale&&!(a=e.parse(r.locale,1,Gt))?null:new be(n,i,a)},be.prototype.evaluate=function(t){return new ie(this.caseSensitive.evaluate(t),this.diacriticSensitive.evaluate(t),this.locale?this.locale.evaluate(t):null)},be.prototype.eachChild=function(t){t(this.caseSensitive),t(this.diacriticSensitive),this.locale&&t(this.locale)},be.prototype.possibleOutputs=function(){return[void 0]},be.prototype.serialize=function(){var t={};return t[\"case-sensitive\"]=this.caseSensitive.serialize(),t[\"diacritic-sensitive\"]=this.diacriticSensitive.serialize(),this.locale&&(t.locale=this.locale.serialize()),[\"collator\",t]};var Te=function(t,e){this.type=e.type,this.name=t,this.boundExpression=e};Te.parse=function(t,e){if(2!==t.length||\"string\"!=typeof t[1])return e.error(\"'var' expression requires exactly one string literal argument.\");var r=t[1];return e.scope.has(r)?new Te(r,e.scope.get(r)):e.error('Unknown variable \"'+r+'\". Make sure \"'+r+'\" has been bound in an enclosing \"let\" expression before using it.',1)},Te.prototype.evaluate=function(t){return this.boundExpression.evaluate(t)},Te.prototype.eachChild=function(){},Te.prototype.possibleOutputs=function(){return[void 0]},Te.prototype.serialize=function(){return[\"var\",this.name]};var Ae=function(t,e,r,n,i){void 0===e&&(e=[]),void 0===n&&(n=new Vt),void 0===i&&(i=[]),this.registry=t,this.path=e,this.key=e.map(function(t){return\"[\"+t+\"]\"}).join(\"\"),this.scope=n,this.errors=i,this.expectedType=r};function Me(t,e){for(var r,n,i=t.length-1,a=0,o=i,s=0;a<=o;)if(r=t[s=Math.floor((a+o)/2)],n=t[s+1],r<=e){if(s===i||e<n)return s;a=s+1}else{if(!(r>e))throw new he(\"Input is not a number.\");o=s-1}return 0}Ae.prototype.parse=function(t,e,r,n,i){return void 0===i&&(i={}),e?this.concat(e,r,n)._parse(t,i):this._parse(t,i)},Ae.prototype._parse=function(t,e){function r(t,e,r){return\"assert\"===r?new pe(e,[t]):\"coerce\"===r?new ve(e,[t]):t}if(null!==t&&\"string\"!=typeof t&&\"boolean\"!=typeof t&&\"number\"!=typeof t||(t=[\"literal\",t]),Array.isArray(t)){if(0===t.length)return this.error('Expected an array with at least one element. If you wanted a literal array, use [\"literal\", []].');var n=t[0];if(\"string\"!=typeof n)return this.error(\"Expression name must be a string, but found \"+typeof n+' instead. If you wanted a literal array, use [\"literal\", [...]].',0),null;var i=this.registry[n];if(i){var a=i.parse(t,this);if(!a)return null;if(this.expectedType){var o=this.expectedType,s=a.type;if(\"string\"!==o.kind&&\"number\"!==o.kind&&\"boolean\"!==o.kind&&\"object\"!==o.kind&&\"array\"!==o.kind||\"value\"!==s.kind)if(\"color\"!==o.kind&&\"formatted\"!==o.kind||\"value\"!==s.kind&&\"string\"!==s.kind){if(this.checkSubtype(o,s))return null}else a=r(a,o,e.typeAnnotation||\"coerce\");else a=r(a,o,e.typeAnnotation||\"assert\")}if(!(a instanceof ue)&&function t(e){if(e instanceof Te)return t(e.boundExpression);if(e instanceof xe&&\"error\"===e.name)return!1;if(e instanceof be)return!1;var r=e instanceof ve||e instanceof pe,n=!0;return e.eachChild(function(e){n=r?n&&t(e):n&&e instanceof ue}),!!n&&(_e(e)&&ke(e,[\"zoom\",\"heatmap-density\",\"line-progress\",\"accumulated\",\"is-supported-script\"]))}(a)){var l=new ye;try{a=new ue(a.type,a.evaluate(l))}catch(t){return this.error(t.message),null}}return a}return this.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0)}return void 0===t?this.error(\"'undefined' value invalid. Use null instead.\"):\"object\"==typeof t?this.error('Bare objects invalid. Use [\"literal\", {...}] instead.'):this.error(\"Expected an array, but found \"+typeof t+\" instead.\")},Ae.prototype.concat=function(t,e,r){var n=\"number\"==typeof t?this.path.concat(t):this.path,i=r?this.scope.concat(r):this.scope;return new Ae(this.registry,n,e||null,i,this.errors)},Ae.prototype.error=function(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];var n=\"\"+this.key+e.map(function(t){return\"[\"+t+\"]\"}).join(\"\");this.errors.push(new Ut(n,t))},Ae.prototype.checkSubtype=function(t,e){var r=ee(t,e);return r&&this.error(r),r};var Se=function(t,e,r){this.type=t,this.input=e,this.labels=[],this.outputs=[];for(var n=0,i=r;n<i.length;n+=1){var a=i[n],o=a[0],s=a[1];this.labels.push(o),this.outputs.push(s)}};function Ee(t,e,r){return t*(1-r)+e*r}Se.parse=function(t,e){if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");var r=e.parse(t[1],1,Ht);if(!r)return null;var n=[],i=null;e.expectedType&&\"value\"!==e.expectedType.kind&&(i=e.expectedType);for(var a=1;a<t.length;a+=2){var o=1===a?-1/0:t[a],s=t[a+1],l=a,c=a+1;if(\"number\"!=typeof o)return e.error('Input/output pairs for \"step\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',l);if(n.length&&n[n.length-1][0]>=o)return e.error('Input/output pairs for \"step\" expressions must be arranged with input values in strictly ascending order.',l);var u=e.parse(s,c,i);if(!u)return null;i=i||u.type,n.push([o,u])}return new Se(i,r,n)},Se.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;return n>=e[i-1]?r[i-1].evaluate(t):r[Me(e,n)].evaluate(t)},Se.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},Se.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()}))},Se.prototype.serialize=function(){for(var t=[\"step\",this.input.serialize()],e=0;e<this.labels.length;e++)e>0&&t.push(this.labels[e]),t.push(this.outputs[e].serialize());return t};var Ce=Object.freeze({number:Ee,color:function(t,e,r){return new ne(Ee(t.r,e.r,r),Ee(t.g,e.g,r),Ee(t.b,e.b,r),Ee(t.a,e.a,r))},array:function(t,e,r){return t.map(function(t,n){return Ee(t,e[n],r)})}}),Le=.95047,Pe=1,Oe=1.08883,ze=4/29,Ie=6/29,De=3*Ie*Ie,Re=Ie*Ie*Ie,Fe=Math.PI/180,Be=180/Math.PI;function Ne(t){return t>Re?Math.pow(t,1/3):t/De+ze}function je(t){return t>Ie?t*t*t:De*(t-ze)}function Ue(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function Ve(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function qe(t){var e=Ve(t.r),r=Ve(t.g),n=Ve(t.b),i=Ne((.4124564*e+.3575761*r+.1804375*n)/Le),a=Ne((.2126729*e+.7151522*r+.072175*n)/Pe);return{l:116*a-16,a:500*(i-a),b:200*(a-Ne((.0193339*e+.119192*r+.9503041*n)/Oe)),alpha:t.a}}function He(t){var e=(t.l+16)/116,r=isNaN(t.a)?e:e+t.a/500,n=isNaN(t.b)?e:e-t.b/200;return e=Pe*je(e),r=Le*je(r),n=Oe*je(n),new ne(Ue(3.2404542*r-1.5371385*e-.4985314*n),Ue(-.969266*r+1.8760108*e+.041556*n),Ue(.0556434*r-.2040259*e+1.0572252*n),t.alpha)}var Ge={forward:qe,reverse:He,interpolate:function(t,e,r){return{l:Ee(t.l,e.l,r),a:Ee(t.a,e.a,r),b:Ee(t.b,e.b,r),alpha:Ee(t.alpha,e.alpha,r)}}},Ye={forward:function(t){var e=qe(t),r=e.l,n=e.a,i=e.b,a=Math.atan2(i,n)*Be;return{h:a<0?a+360:a,c:Math.sqrt(n*n+i*i),l:r,alpha:t.a}},reverse:function(t){var e=t.h*Fe,r=t.c;return He({l:t.l,a:Math.cos(e)*r,b:Math.sin(e)*r,alpha:t.alpha})},interpolate:function(t,e,r){return{h:function(t,e,r){var n=e-t;return t+r*(n>180||n<-180?n-360*Math.round(n/360):n)}(t.h,e.h,r),c:Ee(t.c,e.c,r),l:Ee(t.l,e.l,r),alpha:Ee(t.alpha,e.alpha,r)}}},We=Object.freeze({lab:Ge,hcl:Ye}),Xe=function(t,e,r,n,i){this.type=t,this.operator=e,this.interpolation=r,this.input=n,this.labels=[],this.outputs=[];for(var a=0,o=i;a<o.length;a+=1){var s=o[a],l=s[0],c=s[1];this.labels.push(l),this.outputs.push(c)}};function Ze(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}Xe.interpolationFactor=function(t,e,n,i){var a=0;if(\"exponential\"===t.name)a=Ze(e,t.base,n,i);else if(\"linear\"===t.name)a=Ze(e,1,n,i);else if(\"cubic-bezier\"===t.name){var o=t.controlPoints;a=new r(o[0],o[1],o[2],o[3]).solve(Ze(e,1,n,i))}return a},Xe.parse=function(t,e){var r=t[0],n=t[1],i=t[2],a=t.slice(3);if(!Array.isArray(n)||0===n.length)return e.error(\"Expected an interpolation type expression.\",1);if(\"linear\"===n[0])n={name:\"linear\"};else if(\"exponential\"===n[0]){var o=n[1];if(\"number\"!=typeof o)return e.error(\"Exponential interpolation requires a numeric base.\",1,1);n={name:\"exponential\",base:o}}else{if(\"cubic-bezier\"!==n[0])return e.error(\"Unknown interpolation type \"+String(n[0]),1,0);var s=n.slice(1);if(4!==s.length||s.some(function(t){return\"number\"!=typeof t||t<0||t>1}))return e.error(\"Cubic bezier interpolation requires four numeric arguments with values between 0 and 1.\",1);n={name:\"cubic-bezier\",controlPoints:s}}if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");if(!(i=e.parse(i,2,Ht)))return null;var l=[],c=null;\"interpolate-hcl\"===r||\"interpolate-lab\"===r?c=Wt:e.expectedType&&\"value\"!==e.expectedType.kind&&(c=e.expectedType);for(var u=0;u<a.length;u+=2){var h=a[u],f=a[u+1],p=u+3,d=u+4;if(\"number\"!=typeof h)return e.error('Input/output pairs for \"interpolate\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',p);if(l.length&&l[l.length-1][0]>=h)return e.error('Input/output pairs for \"interpolate\" expressions must be arranged with input values in strictly ascending order.',p);var g=e.parse(f,d,c);if(!g)return null;c=c||g.type,l.push([h,g])}return\"number\"===c.kind||\"color\"===c.kind||\"array\"===c.kind&&\"number\"===c.itemType.kind&&\"number\"==typeof c.N?new Xe(c,r,n,i,l):e.error(\"Type \"+Qt(c)+\" is not interpolatable.\")},Xe.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;if(n>=e[i-1])return r[i-1].evaluate(t);var a=Me(e,n),o=e[a],s=e[a+1],l=Xe.interpolationFactor(this.interpolation,n,o,s),c=r[a].evaluate(t),u=r[a+1].evaluate(t);return\"interpolate\"===this.operator?Ce[this.type.kind.toLowerCase()](c,u,l):\"interpolate-hcl\"===this.operator?Ye.reverse(Ye.interpolate(Ye.forward(c),Ye.forward(u),l)):Ge.reverse(Ge.interpolate(Ge.forward(c),Ge.forward(u),l))},Xe.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},Xe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()}))},Xe.prototype.serialize=function(){var t;t=\"linear\"===this.interpolation.name?[\"linear\"]:\"exponential\"===this.interpolation.name?1===this.interpolation.base?[\"linear\"]:[\"exponential\",this.interpolation.base]:[\"cubic-bezier\"].concat(this.interpolation.controlPoints);for(var e=[this.operator,t,this.input.serialize()],r=0;r<this.labels.length;r++)e.push(this.labels[r],this.outputs[r].serialize());return e};var Je=function(t,e){this.type=t,this.args=e};Je.parse=function(t,e){if(t.length<2)return e.error(\"Expectected at least one argument.\");var r=null,n=e.expectedType;n&&\"value\"!==n.kind&&(r=n);for(var i=[],a=0,o=t.slice(1);a<o.length;a+=1){var s=o[a],l=e.parse(s,1+i.length,r,void 0,{typeAnnotation:\"omit\"});if(!l)return null;r=r||l.type,i.push(l)}var c=n&&i.some(function(t){return ee(n,t.type)});return new Je(c?Zt:r,i)},Je.prototype.evaluate=function(t){for(var e=null,r=0,n=this.args;r<n.length&&null===(e=n[r].evaluate(t));r+=1);return e},Je.prototype.eachChild=function(t){this.args.forEach(t)},Je.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},Je.prototype.serialize=function(){var t=[\"coalesce\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var Ke=function(t,e){this.type=e.type,this.bindings=[].concat(t),this.result=e};Ke.prototype.evaluate=function(t){return this.result.evaluate(t)},Ke.prototype.eachChild=function(t){for(var e=0,r=this.bindings;e<r.length;e+=1)t(r[e][1]);t(this.result)},Ke.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found \"+(t.length-1)+\" instead.\");for(var r=[],n=1;n<t.length-1;n+=2){var i=t[n];if(\"string\"!=typeof i)return e.error(\"Expected string, but found \"+typeof i+\" instead.\",n);if(/[^a-zA-Z0-9_]/.test(i))return e.error(\"Variable names must contain only alphanumeric characters or '_'.\",n);var a=e.parse(t[n+1],n+1);if(!a)return null;r.push([i,a])}var o=e.parse(t[t.length-1],t.length-1,e.expectedType,r);return o?new Ke(r,o):null},Ke.prototype.possibleOutputs=function(){return this.result.possibleOutputs()},Ke.prototype.serialize=function(){for(var t=[\"let\"],e=0,r=this.bindings;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];t.push(i,a.serialize())}return t.push(this.result.serialize()),t};var $e=function(t,e,r){this.type=t,this.index=e,this.input=r};$e.parse=function(t,e){if(3!==t.length)return e.error(\"Expected 2 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,Ht),n=e.parse(t[2],2,$t(e.expectedType||Zt));if(!r||!n)return null;var i=n.type;return new $e(i.itemType,r,n)},$e.prototype.evaluate=function(t){var e=this.index.evaluate(t),r=this.input.evaluate(t);if(e<0)throw new he(\"Array index out of bounds: \"+e+\" < 0.\");if(e>=r.length)throw new he(\"Array index out of bounds: \"+e+\" > \"+(r.length-1)+\".\");if(e!==Math.floor(e))throw new he(\"Array index must be an integer, but found \"+e+\" instead.\");return r[e]},$e.prototype.eachChild=function(t){t(this.index),t(this.input)},$e.prototype.possibleOutputs=function(){return[void 0]},$e.prototype.serialize=function(){return[\"at\",this.index.serialize(),this.input.serialize()]};var Qe=function(t,e,r,n,i,a){this.inputType=t,this.type=e,this.input=r,this.cases=n,this.outputs=i,this.otherwise=a};Qe.parse=function(t,e){if(t.length<5)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=1)return e.error(\"Expected an even number of arguments.\");var r,n;e.expectedType&&\"value\"!==e.expectedType.kind&&(n=e.expectedType);for(var i={},a=[],o=2;o<t.length-1;o+=2){var s=t[o],l=t[o+1];Array.isArray(s)||(s=[s]);var c=e.concat(o);if(0===s.length)return c.error(\"Expected at least one branch label.\");for(var u=0,h=s;u<h.length;u+=1){var f=h[u];if(\"number\"!=typeof f&&\"string\"!=typeof f)return c.error(\"Branch labels must be numbers or strings.\");if(\"number\"==typeof f&&Math.abs(f)>Number.MAX_SAFE_INTEGER)return c.error(\"Branch labels must be integers no larger than \"+Number.MAX_SAFE_INTEGER+\".\");if(\"number\"==typeof f&&Math.floor(f)!==f)return c.error(\"Numeric branch labels must be integer values.\");if(r){if(c.checkSubtype(r,le(f)))return null}else r=le(f);if(void 0!==i[String(f)])return c.error(\"Branch labels must be unique.\");i[String(f)]=a.length}var p=e.parse(l,o,n);if(!p)return null;n=n||p.type,a.push(p)}var d=e.parse(t[1],1,Zt);if(!d)return null;var g=e.parse(t[t.length-1],t.length-1,n);return g?\"value\"!==d.type.kind&&e.concat(1).checkSubtype(r,d.type)?null:new Qe(r,n,d,i,a,g):null},Qe.prototype.evaluate=function(t){var e=this.input.evaluate(t);return(le(e)===this.inputType&&this.outputs[this.cases[e]]||this.otherwise).evaluate(t)},Qe.prototype.eachChild=function(t){t(this.input),this.outputs.forEach(t),t(this.otherwise)},Qe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()})).concat(this.otherwise.possibleOutputs())},Qe.prototype.serialize=function(){for(var t=this,e=[\"match\",this.input.serialize()],r=[],n={},i=0,a=Object.keys(this.cases).sort();i<a.length;i+=1){var o=a[i];void 0===(h=n[this.cases[o]])?(n[this.cases[o]]=r.length,r.push([this.cases[o],[o]])):r[h][1].push(o)}for(var s=function(e){return\"number\"===t.inputType.kind?Number(e):e},l=0,c=r;l<c.length;l+=1){var u=c[l],h=u[0],f=u[1];1===f.length?e.push(s(f[0])):e.push(f.map(s)),e.push(this.outputs[outputIndex$1].serialize())}return e.push(this.otherwise.serialize()),e};var tr=function(t,e,r){this.type=t,this.branches=e,this.otherwise=r};function er(t,e){return\"==\"===t||\"!=\"===t?\"boolean\"===e.kind||\"string\"===e.kind||\"number\"===e.kind||\"null\"===e.kind||\"value\"===e.kind:\"string\"===e.kind||\"number\"===e.kind||\"value\"===e.kind}function rr(t,e,r,n){return 0===n.compare(e,r)}function nr(t,e,r){var n=\"==\"!==t&&\"!=\"!==t;return function(){function i(t,e,r){this.type=Yt,this.lhs=t,this.rhs=e,this.collator=r,this.hasUntypedArgument=\"value\"===t.type.kind||\"value\"===e.type.kind}return i.parse=function(t,e){if(3!==t.length&&4!==t.length)return e.error(\"Expected two or three arguments.\");var r=t[0],a=e.parse(t[1],1,Zt);if(!a)return null;if(!er(r,a.type))return e.concat(1).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Qt(a.type)+\"'.\");var o=e.parse(t[2],2,Zt);if(!o)return null;if(!er(r,o.type))return e.concat(2).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Qt(o.type)+\"'.\");if(a.type.kind!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot compare types '\"+Qt(a.type)+\"' and '\"+Qt(o.type)+\"'.\");n&&(\"value\"===a.type.kind&&\"value\"!==o.type.kind?a=new pe(o.type,[a]):\"value\"!==a.type.kind&&\"value\"===o.type.kind&&(o=new pe(a.type,[o])));var s=null;if(4===t.length){if(\"string\"!==a.type.kind&&\"string\"!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot use collator to compare non-string types.\");if(!(s=e.parse(t[3],3,Jt)))return null}return new i(a,o,s)},i.prototype.evaluate=function(i){var a=this.lhs.evaluate(i),o=this.rhs.evaluate(i);if(n&&this.hasUntypedArgument){var s=le(a),l=le(o);if(s.kind!==l.kind||\"string\"!==s.kind&&\"number\"!==s.kind)throw new he('Expected arguments for \"'+t+'\" to be (string, string) or (number, number), but found ('+s.kind+\", \"+l.kind+\") instead.\")}if(this.collator&&!n&&this.hasUntypedArgument){var c=le(a),u=le(o);if(\"string\"!==c.kind||\"string\"!==u.kind)return e(i,a,o)}return this.collator?r(i,a,o,this.collator.evaluate(i)):e(i,a,o)},i.prototype.eachChild=function(t){t(this.lhs),t(this.rhs),this.collator&&t(this.collator)},i.prototype.possibleOutputs=function(){return[!0,!1]},i.prototype.serialize=function(){var e=[t];return this.eachChild(function(t){e.push(t.serialize())}),e},i}()}tr.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=0)return e.error(\"Expected an odd number of arguments.\");var r;e.expectedType&&\"value\"!==e.expectedType.kind&&(r=e.expectedType);for(var n=[],i=1;i<t.length-1;i+=2){var a=e.parse(t[i],i,Yt);if(!a)return null;var o=e.parse(t[i+1],i+1,r);if(!o)return null;n.push([a,o]),r=r||o.type}var s=e.parse(t[t.length-1],t.length-1,r);return s?new tr(r,n,s):null},tr.prototype.evaluate=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];if(i.evaluate(t))return a.evaluate(t)}return this.otherwise.evaluate(t)},tr.prototype.eachChild=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];t(i),t(a)}t(this.otherwise)},tr.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.branches.map(function(t){return t[0],t[1].possibleOutputs()})).concat(this.otherwise.possibleOutputs())},tr.prototype.serialize=function(){var t=[\"case\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var ir=nr(\"==\",function(t,e,r){return e===r},rr),ar=nr(\"!=\",function(t,e,r){return e!==r},function(t,e,r,n){return!rr(0,e,r,n)}),or=nr(\"<\",function(t,e,r){return e<r},function(t,e,r,n){return n.compare(e,r)<0}),sr=nr(\">\",function(t,e,r){return e>r},function(t,e,r,n){return n.compare(e,r)>0}),lr=nr(\"<=\",function(t,e,r){return e<=r},function(t,e,r,n){return n.compare(e,r)<=0}),cr=nr(\">=\",function(t,e,r){return e>=r},function(t,e,r,n){return n.compare(e,r)>=0}),ur=function(t,e,r,n,i){this.type=Gt,this.number=t,this.locale=e,this.currency=r,this.minFractionDigits=n,this.maxFractionDigits=i};ur.parse=function(t,e){if(3!==t.length)return e.error(\"Expected two arguments.\");var r=e.parse(t[1],1,Ht);if(!r)return null;var n=t[2];if(\"object\"!=typeof n||Array.isArray(n))return e.error(\"NumberFormat options argument must be an object.\");var i=null;if(n.locale&&!(i=e.parse(n.locale,1,Gt)))return null;var a=null;if(n.currency&&!(a=e.parse(n.currency,1,Gt)))return null;var o=null;if(n[\"min-fraction-digits\"]&&!(o=e.parse(n[\"min-fraction-digits\"],1,Ht)))return null;var s=null;return n[\"max-fraction-digits\"]&&!(s=e.parse(n[\"max-fraction-digits\"],1,Ht))?null:new ur(r,i,a,o,s)},ur.prototype.evaluate=function(t){return new Intl.NumberFormat(this.locale?this.locale.evaluate(t):[],{style:this.currency?\"currency\":\"decimal\",currency:this.currency?this.currency.evaluate(t):void 0,minimumFractionDigits:this.minFractionDigits?this.minFractionDigits.evaluate(t):void 0,maximumFractionDigits:this.maxFractionDigits?this.maxFractionDigits.evaluate(t):void 0}).format(this.number.evaluate(t))},ur.prototype.eachChild=function(t){t(this.number),this.locale&&t(this.locale),this.currency&&t(this.currency),this.minFractionDigits&&t(this.minFractionDigits),this.maxFractionDigits&&t(this.maxFractionDigits)},ur.prototype.possibleOutputs=function(){return[void 0]},ur.prototype.serialize=function(){var t={};return this.locale&&(t.locale=this.locale.serialize()),this.currency&&(t.currency=this.currency.serialize()),this.minFractionDigits&&(t[\"min-fraction-digits\"]=this.minFractionDigits.serialize()),this.maxFractionDigits&&(t[\"max-fraction-digits\"]=this.maxFractionDigits.serialize()),[\"number-format\",this.number.serialize(),t]};var hr=function(t){this.type=Ht,this.input=t};hr.parse=function(t,e){if(2!==t.length)return e.error(\"Expected 1 argument, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1);return r?\"array\"!==r.type.kind&&\"string\"!==r.type.kind&&\"value\"!==r.type.kind?e.error(\"Expected argument of type string or array, but found \"+Qt(r.type)+\" instead.\"):new hr(r):null},hr.prototype.evaluate=function(t){var e=this.input.evaluate(t);if(\"string\"==typeof e)return e.length;if(Array.isArray(e))return e.length;throw new he(\"Expected value to be of type string or array, but found \"+Qt(le(e))+\" instead.\")},hr.prototype.eachChild=function(t){t(this.input)},hr.prototype.possibleOutputs=function(){return[void 0]},hr.prototype.serialize=function(){var t=[\"length\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var fr={\"==\":ir,\"!=\":ar,\">\":sr,\"<\":or,\">=\":cr,\"<=\":lr,array:pe,at:$e,boolean:pe,case:tr,coalesce:Je,collator:be,format:de,interpolate:Xe,\"interpolate-hcl\":Xe,\"interpolate-lab\":Xe,length:hr,let:Ke,literal:ue,match:Qe,number:pe,\"number-format\":ur,object:pe,step:Se,string:pe,\"to-boolean\":ve,\"to-color\":ve,\"to-number\":ve,\"to-string\":ve,var:Te};function pr(t,e){var r=e[0],n=e[1],i=e[2],a=e[3];r=r.evaluate(t),n=n.evaluate(t),i=i.evaluate(t);var o=a?a.evaluate(t):1,s=se(r,n,i,o);if(s)throw new he(s);return new ne(r/255*o,n/255*o,i/255*o,o)}function dr(t,e){return t in e}function gr(t,e){var r=e[t];return void 0===r?null:r}function vr(t){return{type:t}}function mr(t){return{result:\"success\",value:t}}function yr(t){return{result:\"error\",value:t}}function xr(t){return\"data-driven\"===t[\"property-type\"]||\"cross-faded-data-driven\"===t[\"property-type\"]}function br(t){return!!t.expression&&t.expression.parameters.indexOf(\"zoom\")>-1}function _r(t){return!!t.expression&&t.expression.interpolated}function wr(t){return t instanceof Number?\"number\":t instanceof String?\"string\":t instanceof Boolean?\"boolean\":Array.isArray(t)?\"array\":null===t?\"null\":typeof t}function kr(t){return\"object\"==typeof t&&null!==t&&!Array.isArray(t)}function Tr(t){return t}function Ar(t,e,r){return void 0!==t?t:void 0!==e?e:void 0!==r?r:void 0}function Mr(t,e,r,n,i){return Ar(typeof r===i?n[r]:void 0,t.default,e.default)}function Sr(t,e,r){if(\"number\"!==wr(r))return Ar(t.default,e.default);var n=t.stops.length;if(1===n)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[n-1][0])return t.stops[n-1][1];var i=Me(t.stops.map(function(t){return t[0]}),r);return t.stops[i][1]}function Er(t,e,r){var n=void 0!==t.base?t.base:1;if(\"number\"!==wr(r))return Ar(t.default,e.default);var i=t.stops.length;if(1===i)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[i-1][0])return t.stops[i-1][1];var a=Me(t.stops.map(function(t){return t[0]}),r),o=function(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}(r,n,t.stops[a][0],t.stops[a+1][0]),s=t.stops[a][1],l=t.stops[a+1][1],c=Ce[e.type]||Tr;if(t.colorSpace&&\"rgb\"!==t.colorSpace){var u=We[t.colorSpace];c=function(t,e){return u.reverse(u.interpolate(u.forward(t),u.forward(e),o))}}return\"function\"==typeof s.evaluate?{evaluate:function(){for(var t=[],e=arguments.length;e--;)t[e]=arguments[e];var r=s.evaluate.apply(void 0,t),n=l.evaluate.apply(void 0,t);if(void 0!==r&&void 0!==n)return c(r,n,o)}}:c(s,l,o)}function Cr(t,e,r){return\"color\"===e.type?r=ne.parse(r):\"formatted\"===e.type?r=oe.fromString(r.toString()):wr(r)===e.type||\"enum\"===e.type&&e.values[r]||(r=void 0),Ar(r,t.default,e.default)}xe.register(fr,{error:[{kind:\"error\"},[Gt],function(t,e){var r=e[0];throw new he(r.evaluate(t))}],typeof:[Gt,[Zt],function(t,e){return Qt(le(e[0].evaluate(t)))}],\"to-rgba\":[$t(Ht,4),[Wt],function(t,e){return e[0].evaluate(t).toArray()}],rgb:[Wt,[Ht,Ht,Ht],pr],rgba:[Wt,[Ht,Ht,Ht,Ht],pr],has:{type:Yt,overloads:[[[Gt],function(t,e){return dr(e[0].evaluate(t),t.properties())}],[[Gt,Xt],function(t,e){var r=e[0],n=e[1];return dr(r.evaluate(t),n.evaluate(t))}]]},get:{type:Zt,overloads:[[[Gt],function(t,e){return gr(e[0].evaluate(t),t.properties())}],[[Gt,Xt],function(t,e){var r=e[0],n=e[1];return gr(r.evaluate(t),n.evaluate(t))}]]},\"feature-state\":[Zt,[Gt],function(t,e){return gr(e[0].evaluate(t),t.featureState||{})}],properties:[Xt,[],function(t){return t.properties()}],\"geometry-type\":[Gt,[],function(t){return t.geometryType()}],id:[Zt,[],function(t){return t.id()}],zoom:[Ht,[],function(t){return t.globals.zoom}],\"heatmap-density\":[Ht,[],function(t){return t.globals.heatmapDensity||0}],\"line-progress\":[Ht,[],function(t){return t.globals.lineProgress||0}],accumulated:[Zt,[],function(t){return void 0===t.globals.accumulated?null:t.globals.accumulated}],\"+\":[Ht,vr(Ht),function(t,e){for(var r=0,n=0,i=e;n<i.length;n+=1)r+=i[n].evaluate(t);return r}],\"*\":[Ht,vr(Ht),function(t,e){for(var r=1,n=0,i=e;n<i.length;n+=1)r*=i[n].evaluate(t);return r}],\"-\":{type:Ht,overloads:[[[Ht,Ht],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)-n.evaluate(t)}],[[Ht],function(t,e){return-e[0].evaluate(t)}]]},\"/\":[Ht,[Ht,Ht],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)/n.evaluate(t)}],\"%\":[Ht,[Ht,Ht],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)%n.evaluate(t)}],ln2:[Ht,[],function(){return Math.LN2}],pi:[Ht,[],function(){return Math.PI}],e:[Ht,[],function(){return Math.E}],\"^\":[Ht,[Ht,Ht],function(t,e){var r=e[0],n=e[1];return Math.pow(r.evaluate(t),n.evaluate(t))}],sqrt:[Ht,[Ht],function(t,e){var r=e[0];return Math.sqrt(r.evaluate(t))}],log10:[Ht,[Ht],function(t,e){var r=e[0];return Math.log(r.evaluate(t))/Math.LN10}],ln:[Ht,[Ht],function(t,e){var r=e[0];return Math.log(r.evaluate(t))}],log2:[Ht,[Ht],function(t,e){var r=e[0];return Math.log(r.evaluate(t))/Math.LN2}],sin:[Ht,[Ht],function(t,e){var r=e[0];return Math.sin(r.evaluate(t))}],cos:[Ht,[Ht],function(t,e){var r=e[0];return Math.cos(r.evaluate(t))}],tan:[Ht,[Ht],function(t,e){var r=e[0];return Math.tan(r.evaluate(t))}],asin:[Ht,[Ht],function(t,e){var r=e[0];return Math.asin(r.evaluate(t))}],acos:[Ht,[Ht],function(t,e){var r=e[0];return Math.acos(r.evaluate(t))}],atan:[Ht,[Ht],function(t,e){var r=e[0];return Math.atan(r.evaluate(t))}],min:[Ht,vr(Ht),function(t,e){return Math.min.apply(Math,e.map(function(e){return e.evaluate(t)}))}],max:[Ht,vr(Ht),function(t,e){return Math.max.apply(Math,e.map(function(e){return e.evaluate(t)}))}],abs:[Ht,[Ht],function(t,e){var r=e[0];return Math.abs(r.evaluate(t))}],round:[Ht,[Ht],function(t,e){var r=e[0].evaluate(t);return r<0?-Math.round(-r):Math.round(r)}],floor:[Ht,[Ht],function(t,e){var r=e[0];return Math.floor(r.evaluate(t))}],ceil:[Ht,[Ht],function(t,e){var r=e[0];return Math.ceil(r.evaluate(t))}],\"filter-==\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1];return t.properties()[r.value]===n.value}],\"filter-id-==\":[Yt,[Zt],function(t,e){var r=e[0];return t.id()===r.value}],\"filter-type-==\":[Yt,[Gt],function(t,e){var r=e[0];return t.geometryType()===r.value}],\"filter-<\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<a}],\"filter-id-<\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<i}],\"filter->\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>a}],\"filter-id->\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>i}],\"filter-<=\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<=a}],\"filter-id-<=\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<=i}],\"filter->=\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>=a}],\"filter-id->=\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>=i}],\"filter-has\":[Yt,[Zt],function(t,e){return e[0].value in t.properties()}],\"filter-has-id\":[Yt,[],function(t){return null!==t.id()}],\"filter-type-in\":[Yt,[$t(Gt)],function(t,e){return e[0].value.indexOf(t.geometryType())>=0}],\"filter-id-in\":[Yt,[$t(Zt)],function(t,e){return e[0].value.indexOf(t.id())>=0}],\"filter-in-small\":[Yt,[Gt,$t(Zt)],function(t,e){var r=e[0];return e[1].value.indexOf(t.properties()[r.value])>=0}],\"filter-in-large\":[Yt,[Gt,$t(Zt)],function(t,e){var r=e[0],n=e[1];return function(t,e,r,n){for(;r<=n;){var i=r+n>>1;if(e[i]===t)return!0;e[i]>t?n=i-1:r=i+1}return!1}(t.properties()[r.value],n.value,0,n.value.length-1)}],all:{type:Yt,overloads:[[[Yt,Yt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)&&n.evaluate(t)}],[vr(Yt),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(!n[r].evaluate(t))return!1;return!0}]]},any:{type:Yt,overloads:[[[Yt,Yt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)||n.evaluate(t)}],[vr(Yt),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(n[r].evaluate(t))return!0;return!1}]]},\"!\":[Yt,[Yt],function(t,e){return!e[0].evaluate(t)}],\"is-supported-script\":[Yt,[Gt],function(t,e){var r=e[0],n=t.globals&&t.globals.isSupportedScript;return!n||n(r.evaluate(t))}],upcase:[Gt,[Gt],function(t,e){return e[0].evaluate(t).toUpperCase()}],downcase:[Gt,[Gt],function(t,e){return e[0].evaluate(t).toLowerCase()}],concat:[Gt,vr(Zt),function(t,e){return e.map(function(e){return ce(e.evaluate(t))}).join(\"\")}],\"resolved-locale\":[Gt,[Jt],function(t,e){return e[0].evaluate(t).resolvedLocale()}]});var Lr=function(t,e){var r;this.expression=t,this._warningHistory={},this._evaluator=new ye,this._defaultValue=e?\"color\"===(r=e).type&&kr(r.default)?new ne(0,0,0,0):\"color\"===r.type?ne.parse(r.default)||null:void 0===r.default?null:r.default:null,this._enumValues=e&&\"enum\"===e.type?e.values:null};function Pr(t){return Array.isArray(t)&&t.length>0&&\"string\"==typeof t[0]&&t[0]in fr}function Or(t,e){var r=new Ae(fr,[],e?function(t){var e={color:Wt,string:Gt,number:Ht,enum:Gt,boolean:Yt,formatted:Kt};return\"array\"===t.type?$t(e[t.value]||Zt,t.length):e[t.type]}(e):void 0),n=r.parse(t,void 0,void 0,void 0,e&&\"string\"===e.type?{typeAnnotation:\"coerce\"}:void 0);return n?mr(new Lr(n,e)):yr(r.errors)}Lr.prototype.evaluateWithoutErrorHandling=function(t,e,r){return this._evaluator.globals=t,this._evaluator.feature=e,this._evaluator.featureState=r,this.expression.evaluate(this._evaluator)},Lr.prototype.evaluate=function(t,e,r){this._evaluator.globals=t,this._evaluator.feature=e||null,this._evaluator.featureState=r||null;try{var n=this.expression.evaluate(this._evaluator);if(null==n)return this._defaultValue;if(this._enumValues&&!(n in this._enumValues))throw new he(\"Expected value to be one of \"+Object.keys(this._enumValues).map(function(t){return JSON.stringify(t)}).join(\", \")+\", but found \"+JSON.stringify(n)+\" instead.\");return n}catch(t){return this._warningHistory[t.message]||(this._warningHistory[t.message]=!0,\"undefined\"!=typeof console&&console.warn(t.message)),this._defaultValue}};var zr=function(t,e){this.kind=t,this._styleExpression=e,this.isStateDependent=\"constant\"!==t&&!we(e.expression)};zr.prototype.evaluateWithoutErrorHandling=function(t,e,r){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r)},zr.prototype.evaluate=function(t,e,r){return this._styleExpression.evaluate(t,e,r)};var Ir=function(t,e,r){this.kind=t,this.zoomStops=r.labels,this._styleExpression=e,this.isStateDependent=\"camera\"!==t&&!we(e.expression),r instanceof Xe&&(this.interpolationType=r.interpolation)};function Dr(t,e){if(\"error\"===(t=Or(t,e)).result)return t;var r=t.value.expression,n=_e(r);if(!n&&!xr(e))return yr([new Ut(\"\",\"data expressions not supported\")]);var i=ke(r,[\"zoom\"]);if(!i&&!br(e))return yr([new Ut(\"\",\"zoom expressions not supported\")]);var a=function t(e){var r=null;if(e instanceof Ke)r=t(e.result);else if(e instanceof Je)for(var n=0,i=e.args;n<i.length;n+=1){var a=i[n];if(r=t(a))break}else(e instanceof Se||e instanceof Xe)&&e.input instanceof xe&&\"zoom\"===e.input.name&&(r=e);return r instanceof Ut?r:(e.eachChild(function(e){var n=t(e);n instanceof Ut?r=n:!r&&n?r=new Ut(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.'):r&&n&&r!==n&&(r=new Ut(\"\",'Only one zoom-based \"step\" or \"interpolate\" subexpression may be used in an expression.'))}),r)}(r);return a||i?a instanceof Ut?yr([a]):a instanceof Xe&&!_r(e)?yr([new Ut(\"\",'\"interpolate\" expressions cannot be used with this property')]):mr(a?new Ir(n?\"camera\":\"composite\",t.value,a):new zr(n?\"constant\":\"source\",t.value)):yr([new Ut(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.')])}Ir.prototype.evaluateWithoutErrorHandling=function(t,e,r){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r)},Ir.prototype.evaluate=function(t,e,r){return this._styleExpression.evaluate(t,e,r)},Ir.prototype.interpolationFactor=function(t,e,r){return this.interpolationType?Xe.interpolationFactor(this.interpolationType,t,e,r):0};var Rr=function(t,e){this._parameters=t,this._specification=e,Ft(this,function t(e,r){var n,i,a,o=\"color\"===r.type,s=e.stops&&\"object\"==typeof e.stops[0][0],l=s||void 0!==e.property,c=s||!l,u=e.type||(_r(r)?\"exponential\":\"interval\");if(o&&((e=Ft({},e)).stops&&(e.stops=e.stops.map(function(t){return[t[0],ne.parse(t[1])]})),e.default?e.default=ne.parse(e.default):e.default=ne.parse(r.default)),e.colorSpace&&\"rgb\"!==e.colorSpace&&!We[e.colorSpace])throw new Error(\"Unknown color space: \"+e.colorSpace);if(\"exponential\"===u)n=Er;else if(\"interval\"===u)n=Sr;else if(\"categorical\"===u){n=Mr,i=Object.create(null);for(var h=0,f=e.stops;h<f.length;h+=1){var p=f[h];i[p[0]]=p[1]}a=typeof e.stops[0][0]}else{if(\"identity\"!==u)throw new Error('Unknown function type \"'+u+'\"');n=Cr}if(s){for(var d={},g=[],v=0;v<e.stops.length;v++){var m=e.stops[v],y=m[0].zoom;void 0===d[y]&&(d[y]={zoom:y,type:e.type,property:e.property,default:e.default,stops:[]},g.push(y)),d[y].stops.push([m[0].value,m[1]])}for(var x=[],b=0,_=g;b<_.length;b+=1){var w=_[b];x.push([d[w].zoom,t(d[w],r)])}var k={name:\"linear\"};return{kind:\"composite\",interpolationType:k,interpolationFactor:Xe.interpolationFactor.bind(void 0,k),zoomStops:x.map(function(t){return t[0]}),evaluate:function(t,n){var i=t.zoom;return Er({stops:x,base:e.base},r,i).evaluate(i,n)}}}if(c){var T=\"exponential\"===u?{name:\"exponential\",base:void 0!==e.base?e.base:1}:null;return{kind:\"camera\",interpolationType:T,interpolationFactor:Xe.interpolationFactor.bind(void 0,T),zoomStops:e.stops.map(function(t){return t[0]}),evaluate:function(t){var o=t.zoom;return n(e,r,o,i,a)}}}return{kind:\"source\",evaluate:function(t,o){var s=o&&o.properties?o.properties[e.property]:void 0;return void 0===s?Ar(e.default,r.default):n(e,r,s,i,a)}}}(this._parameters,this._specification))};function Fr(t){var e=t.key,r=t.value,n=t.valueSpec||{},i=t.objectElementValidators||{},a=t.style,o=t.styleSpec,s=[],l=wr(r);if(\"object\"!==l)return[new Dt(e,r,\"object expected, \"+l+\" found\")];for(var c in r){var u=c.split(\".\")[0],h=n[u]||n[\"*\"],f=void 0;if(i[u])f=i[u];else if(n[u])f=ln;else if(i[\"*\"])f=i[\"*\"];else{if(!n[\"*\"]){s.push(new Dt(e,r[c],'unknown property \"'+c+'\"'));continue}f=ln}s=s.concat(f({key:(e?e+\".\":e)+c,value:r[c],valueSpec:h,style:a,styleSpec:o,object:r,objectKey:c},r))}for(var p in n)i[p]||n[p].required&&void 0===n[p].default&&void 0===r[p]&&s.push(new Dt(e,r,'missing required property \"'+p+'\"'));return s}function Br(t){var e=t.value,r=t.valueSpec,n=t.style,i=t.styleSpec,a=t.key,o=t.arrayElementValidator||ln;if(\"array\"!==wr(e))return[new Dt(a,e,\"array expected, \"+wr(e)+\" found\")];if(r.length&&e.length!==r.length)return[new Dt(a,e,\"array length \"+r.length+\" expected, length \"+e.length+\" found\")];if(r[\"min-length\"]&&e.length<r[\"min-length\"])return[new Dt(a,e,\"array length at least \"+r[\"min-length\"]+\" expected, length \"+e.length+\" found\")];var s={type:r.value,values:r.values};i.$version<7&&(s.function=r.function),\"object\"===wr(r.value)&&(s=r.value);for(var l=[],c=0;c<e.length;c++)l=l.concat(o({array:e,arrayIndex:c,value:e[c],valueSpec:s,style:n,styleSpec:i,key:a+\"[\"+c+\"]\"}));return l}function Nr(t){var e=t.key,r=t.value,n=t.valueSpec,i=wr(r);return\"number\"!==i?[new Dt(e,r,\"number expected, \"+i+\" found\")]:\"minimum\"in n&&r<n.minimum?[new Dt(e,r,r+\" is less than the minimum value \"+n.minimum)]:\"maximum\"in n&&r>n.maximum?[new Dt(e,r,r+\" is greater than the maximum value \"+n.maximum)]:[]}function jr(t){var e,r,n,i=t.valueSpec,a=Nt(t.value.type),o={},s=\"categorical\"!==a&&void 0===t.value.property,l=!s,c=\"array\"===wr(t.value.stops)&&\"array\"===wr(t.value.stops[0])&&\"object\"===wr(t.value.stops[0][0]),u=Fr({key:t.key,value:t.value,valueSpec:t.styleSpec.function,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{stops:function(t){if(\"identity\"===a)return[new Dt(t.key,t.value,'identity function may not have a \"stops\" property')];var e=[],r=t.value;return e=e.concat(Br({key:t.key,value:r,valueSpec:t.valueSpec,style:t.style,styleSpec:t.styleSpec,arrayElementValidator:h})),\"array\"===wr(r)&&0===r.length&&e.push(new Dt(t.key,r,\"array must have at least one stop\")),e},default:function(t){return ln({key:t.key,value:t.value,valueSpec:i,style:t.style,styleSpec:t.styleSpec})}}});return\"identity\"===a&&s&&u.push(new Dt(t.key,t.value,'missing required property \"property\"')),\"identity\"===a||t.value.stops||u.push(new Dt(t.key,t.value,'missing required property \"stops\"')),\"exponential\"===a&&t.valueSpec.expression&&!_r(t.valueSpec)&&u.push(new Dt(t.key,t.value,\"exponential functions not supported\")),t.styleSpec.$version>=8&&(l&&!xr(t.valueSpec)?u.push(new Dt(t.key,t.value,\"property functions not supported\")):s&&!br(t.valueSpec)&&u.push(new Dt(t.key,t.value,\"zoom functions not supported\"))),\"categorical\"!==a&&!c||void 0!==t.value.property||u.push(new Dt(t.key,t.value,'\"property\" property is required')),u;function h(t){var e=[],a=t.value,s=t.key;if(\"array\"!==wr(a))return[new Dt(s,a,\"array expected, \"+wr(a)+\" found\")];if(2!==a.length)return[new Dt(s,a,\"array length 2 expected, length \"+a.length+\" found\")];if(c){if(\"object\"!==wr(a[0]))return[new Dt(s,a,\"object expected, \"+wr(a[0])+\" found\")];if(void 0===a[0].zoom)return[new Dt(s,a,\"object stop key must have zoom\")];if(void 0===a[0].value)return[new Dt(s,a,\"object stop key must have value\")];if(n&&n>Nt(a[0].zoom))return[new Dt(s,a[0].zoom,\"stop zoom values must appear in ascending order\")];Nt(a[0].zoom)!==n&&(n=Nt(a[0].zoom),r=void 0,o={}),e=e.concat(Fr({key:s+\"[0]\",value:a[0],valueSpec:{zoom:{}},style:t.style,styleSpec:t.styleSpec,objectElementValidators:{zoom:Nr,value:f}}))}else e=e.concat(f({key:s+\"[0]\",value:a[0],valueSpec:{},style:t.style,styleSpec:t.styleSpec},a));return Pr(jt(a[1]))?e.concat([new Dt(s+\"[1]\",a[1],\"expressions are not allowed in function stops.\")]):e.concat(ln({key:s+\"[1]\",value:a[1],valueSpec:i,style:t.style,styleSpec:t.styleSpec}))}function f(t,n){var s=wr(t.value),l=Nt(t.value),c=null!==t.value?t.value:n;if(e){if(s!==e)return[new Dt(t.key,c,s+\" stop domain type must match previous stop domain type \"+e)]}else e=s;if(\"number\"!==s&&\"string\"!==s&&\"boolean\"!==s)return[new Dt(t.key,c,\"stop domain value must be a number, string, or boolean\")];if(\"number\"!==s&&\"categorical\"!==a){var u=\"number expected, \"+s+\" found\";return xr(i)&&void 0===a&&(u+='\\nIf you intended to use a categorical function, specify `\"type\": \"categorical\"`.'),[new Dt(t.key,c,u)]}return\"categorical\"!==a||\"number\"!==s||isFinite(l)&&Math.floor(l)===l?\"categorical\"!==a&&\"number\"===s&&void 0!==r&&l<r?[new Dt(t.key,c,\"stop domain values must appear in ascending order\")]:(r=l,\"categorical\"===a&&l in o?[new Dt(t.key,c,\"stop domain values must be unique\")]:(o[l]=!0,[])):[new Dt(t.key,c,\"integer expected, found \"+l)]}}function Ur(t){var e=(\"property\"===t.expressionContext?Dr:Or)(jt(t.value),t.valueSpec);if(\"error\"===e.result)return e.value.map(function(e){return new Dt(\"\"+t.key+e.key,t.value,e.message)});var r=e.value.expression||e.value._styleExpression.expression;if(\"property\"===t.expressionContext&&\"text-font\"===t.propertyKey&&-1!==r.possibleOutputs().indexOf(void 0))return[new Dt(t.key,t.value,'Invalid data expression for \"'+t.propertyKey+'\". Output values must be contained as literals within the expression.')];if(\"property\"===t.expressionContext&&\"layout\"===t.propertyType&&!we(r))return[new Dt(t.key,t.value,'\"feature-state\" data expressions are not supported with layout properties.')];if(\"filter\"===t.expressionContext&&!we(r))return[new Dt(t.key,t.value,'\"feature-state\" data expressions are not supported with filters.')];if(t.expressionContext&&0===t.expressionContext.indexOf(\"cluster\")){if(!ke(r,[\"zoom\",\"feature-state\"]))return[new Dt(t.key,t.value,'\"zoom\" and \"feature-state\" expressions are not supported with cluster properties.')];if(\"cluster-initial\"===t.expressionContext&&!_e(r))return[new Dt(t.key,t.value,\"Feature data expressions are not supported with initial expression part of cluster properties.\")]}return[]}function Vr(t){var e=t.key,r=t.value,n=t.valueSpec,i=[];return Array.isArray(n.values)?-1===n.values.indexOf(Nt(r))&&i.push(new Dt(e,r,\"expected one of [\"+n.values.join(\", \")+\"], \"+JSON.stringify(r)+\" found\")):-1===Object.keys(n.values).indexOf(Nt(r))&&i.push(new Dt(e,r,\"expected one of [\"+Object.keys(n.values).join(\", \")+\"], \"+JSON.stringify(r)+\" found\")),i}function qr(t){if(!0===t||!1===t)return!0;if(!Array.isArray(t)||0===t.length)return!1;switch(t[0]){case\"has\":return t.length>=2&&\"$id\"!==t[1]&&\"$type\"!==t[1];case\"in\":case\"!in\":case\"!has\":case\"none\":return!1;case\"==\":case\"!=\":case\">\":case\">=\":case\"<\":case\"<=\":return 3!==t.length||Array.isArray(t[1])||Array.isArray(t[2]);case\"any\":case\"all\":for(var e=0,r=t.slice(1);e<r.length;e+=1){var n=r[e];if(!qr(n)&&\"boolean\"!=typeof n)return!1}return!0;default:return!0}}Rr.deserialize=function(t){return new Rr(t._parameters,t._specification)},Rr.serialize=function(t){return{_parameters:t._parameters,_specification:t._specification}};var Hr={type:\"boolean\",default:!1,transition:!1,\"property-type\":\"data-driven\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]}};function Gr(t){if(null==t)return function(){return!0};qr(t)||(t=Wr(t));var e=Or(t,Hr);if(\"error\"===e.result)throw new Error(e.value.map(function(t){return t.key+\": \"+t.message}).join(\", \"));return function(t,r){return e.value.evaluate(t,r)}}function Yr(t,e){return t<e?-1:t>e?1:0}function Wr(t){if(!t)return!0;var e,r=t[0];return t.length<=1?\"any\"!==r:\"==\"===r?Xr(t[1],t[2],\"==\"):\"!=\"===r?Kr(Xr(t[1],t[2],\"==\")):\"<\"===r||\">\"===r||\"<=\"===r||\">=\"===r?Xr(t[1],t[2],r):\"any\"===r?(e=t.slice(1),[\"any\"].concat(e.map(Wr))):\"all\"===r?[\"all\"].concat(t.slice(1).map(Wr)):\"none\"===r?[\"all\"].concat(t.slice(1).map(Wr).map(Kr)):\"in\"===r?Zr(t[1],t.slice(2)):\"!in\"===r?Kr(Zr(t[1],t.slice(2))):\"has\"===r?Jr(t[1]):\"!has\"!==r||Kr(Jr(t[1]))}function Xr(t,e,r){switch(t){case\"$type\":return[\"filter-type-\"+r,e];case\"$id\":return[\"filter-id-\"+r,e];default:return[\"filter-\"+r,t,e]}}function Zr(t,e){if(0===e.length)return!1;switch(t){case\"$type\":return[\"filter-type-in\",[\"literal\",e]];case\"$id\":return[\"filter-id-in\",[\"literal\",e]];default:return e.length>200&&!e.some(function(t){return typeof t!=typeof e[0]})?[\"filter-in-large\",t,[\"literal\",e.sort(Yr)]]:[\"filter-in-small\",t,[\"literal\",e]]}}function Jr(t){switch(t){case\"$type\":return!0;case\"$id\":return[\"filter-has-id\"];default:return[\"filter-has\",t]}}function Kr(t){return[\"!\",t]}function $r(t){return qr(jt(t.value))?Ur(Ft({},t,{expressionContext:\"filter\",valueSpec:{value:\"boolean\"}})):function t(e){var r=e.value,n=e.key;if(\"array\"!==wr(r))return[new Dt(n,r,\"array expected, \"+wr(r)+\" found\")];var i,a=e.styleSpec,o=[];if(r.length<1)return[new Dt(n,r,\"filter array must have at least 1 element\")];switch(o=o.concat(Vr({key:n+\"[0]\",value:r[0],valueSpec:a.filter_operator,style:e.style,styleSpec:e.styleSpec})),Nt(r[0])){case\"<\":case\"<=\":case\">\":case\">=\":r.length>=2&&\"$type\"===Nt(r[1])&&o.push(new Dt(n,r,'\"$type\" cannot be use with operator \"'+r[0]+'\"'));case\"==\":case\"!=\":3!==r.length&&o.push(new Dt(n,r,'filter array for operator \"'+r[0]+'\" must have 3 elements'));case\"in\":case\"!in\":r.length>=2&&\"string\"!==(i=wr(r[1]))&&o.push(new Dt(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"));for(var s=2;s<r.length;s++)i=wr(r[s]),\"$type\"===Nt(r[1])?o=o.concat(Vr({key:n+\"[\"+s+\"]\",value:r[s],valueSpec:a.geometry_type,style:e.style,styleSpec:e.styleSpec})):\"string\"!==i&&\"number\"!==i&&\"boolean\"!==i&&o.push(new Dt(n+\"[\"+s+\"]\",r[s],\"string, number, or boolean expected, \"+i+\" found\"));break;case\"any\":case\"all\":case\"none\":for(var l=1;l<r.length;l++)o=o.concat(t({key:n+\"[\"+l+\"]\",value:r[l],style:e.style,styleSpec:e.styleSpec}));break;case\"has\":case\"!has\":i=wr(r[1]),2!==r.length?o.push(new Dt(n,r,'filter array for \"'+r[0]+'\" operator must have 2 elements')):\"string\"!==i&&o.push(new Dt(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"))}return o}(t)}function Qr(t,e){var r=t.key,n=t.style,i=t.styleSpec,a=t.value,o=t.objectKey,s=i[e+\"_\"+t.layerType];if(!s)return[];var l=o.match(/^(.*)-transition$/);if(\"paint\"===e&&l&&s[l[1]]&&s[l[1]].transition)return ln({key:r,value:a,valueSpec:i.transition,style:n,styleSpec:i});var c,u=t.valueSpec||s[o];if(!u)return[new Dt(r,a,'unknown property \"'+o+'\"')];if(\"string\"===wr(a)&&xr(u)&&!u.tokens&&(c=/^{([^}]+)}$/.exec(a)))return[new Dt(r,a,'\"'+o+'\" does not support interpolation syntax\\nUse an identity property function instead: `{ \"type\": \"identity\", \"property\": '+JSON.stringify(c[1])+\" }`.\")];var h=[];return\"symbol\"===t.layerType&&(\"text-field\"===o&&n&&!n.glyphs&&h.push(new Dt(r,a,'use of \"text-field\" requires a style \"glyphs\" property')),\"text-font\"===o&&kr(jt(a))&&\"identity\"===Nt(a.type)&&h.push(new Dt(r,a,'\"text-font\" does not support identity functions'))),h.concat(ln({key:t.key,value:a,valueSpec:u,style:n,styleSpec:i,expressionContext:\"property\",propertyType:e,propertyKey:o}))}function tn(t){return Qr(t,\"paint\")}function en(t){return Qr(t,\"layout\")}function rn(t){var e=[],r=t.value,n=t.key,i=t.style,a=t.styleSpec;r.type||r.ref||e.push(new Dt(n,r,'either \"type\" or \"ref\" is required'));var o,s=Nt(r.type),l=Nt(r.ref);if(r.id)for(var c=Nt(r.id),u=0;u<t.arrayIndex;u++){var h=i.layers[u];Nt(h.id)===c&&e.push(new Dt(n,r.id,'duplicate layer id \"'+r.id+'\", previously used at line '+h.id.__line__))}if(\"ref\"in r)[\"type\",\"source\",\"source-layer\",\"filter\",\"layout\"].forEach(function(t){t in r&&e.push(new Dt(n,r[t],'\"'+t+'\" is prohibited for ref layers'))}),i.layers.forEach(function(t){Nt(t.id)===l&&(o=t)}),o?o.ref?e.push(new Dt(n,r.ref,\"ref cannot reference another ref layer\")):s=Nt(o.type):e.push(new Dt(n,r.ref,'ref layer \"'+l+'\" not found'));else if(\"background\"!==s)if(r.source){var f=i.sources&&i.sources[r.source],p=f&&Nt(f.type);f?\"vector\"===p&&\"raster\"===s?e.push(new Dt(n,r.source,'layer \"'+r.id+'\" requires a raster source')):\"raster\"===p&&\"raster\"!==s?e.push(new Dt(n,r.source,'layer \"'+r.id+'\" requires a vector source')):\"vector\"!==p||r[\"source-layer\"]?\"raster-dem\"===p&&\"hillshade\"!==s?e.push(new Dt(n,r.source,\"raster-dem source can only be used with layer type 'hillshade'.\")):\"line\"!==s||!r.paint||!r.paint[\"line-gradient\"]||\"geojson\"===p&&f.lineMetrics||e.push(new Dt(n,r,'layer \"'+r.id+'\" specifies a line-gradient, which requires a GeoJSON source with `lineMetrics` enabled.')):e.push(new Dt(n,r,'layer \"'+r.id+'\" must specify a \"source-layer\"')):e.push(new Dt(n,r.source,'source \"'+r.source+'\" not found'))}else e.push(new Dt(n,r,'missing required property \"source\"'));return e=e.concat(Fr({key:n,value:r,valueSpec:a.layer,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(){return[]},type:function(){return ln({key:n+\".type\",value:r.type,valueSpec:a.layer.type,style:t.style,styleSpec:t.styleSpec,object:r,objectKey:\"type\"})},filter:$r,layout:function(t){return Fr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return en(Ft({layerType:s},t))}}})},paint:function(t){return Fr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return tn(Ft({layerType:s},t))}}})}}}))}function nn(t){var e=t.value,r=t.key,n=t.styleSpec,i=t.style;if(!e.type)return[new Dt(r,e,'\"type\" is required')];var a,o=Nt(e.type);switch(o){case\"vector\":case\"raster\":case\"raster-dem\":if(a=Fr({key:r,value:e,valueSpec:n[\"source_\"+o.replace(\"-\",\"_\")],style:t.style,styleSpec:n}),\"url\"in e)for(var s in e)[\"type\",\"url\",\"tileSize\"].indexOf(s)<0&&a.push(new Dt(r+\".\"+s,e[s],'a source with a \"url\" property may not include a \"'+s+'\" property'));return a;case\"geojson\":if(a=Fr({key:r,value:e,valueSpec:n.source_geojson,style:i,styleSpec:n}),e.cluster)for(var l in e.clusterProperties){var c=e.clusterProperties[l],u=c[0],h=c[1],f=\"string\"==typeof u?[u,[\"accumulated\"],[\"get\",l]]:u;a.push.apply(a,Ur({key:r+\".\"+l+\".map\",value:h,expressionContext:\"cluster-map\"})),a.push.apply(a,Ur({key:r+\".\"+l+\".reduce\",value:f,expressionContext:\"cluster-reduce\"}))}return a;case\"video\":return Fr({key:r,value:e,valueSpec:n.source_video,style:i,styleSpec:n});case\"image\":return Fr({key:r,value:e,valueSpec:n.source_image,style:i,styleSpec:n});case\"canvas\":return[new Dt(r,null,\"Please use runtime APIs to add canvas sources, rather than including them in stylesheets.\",\"source.canvas\")];default:return Vr({key:r+\".type\",value:e.type,valueSpec:{values:[\"vector\",\"raster\",\"raster-dem\",\"geojson\",\"video\",\"image\"]},style:i,styleSpec:n})}}function an(t){var e=t.value,r=t.styleSpec,n=r.light,i=t.style,a=[],o=wr(e);if(void 0===e)return a;if(\"object\"!==o)return a.concat([new Dt(\"light\",e,\"object expected, \"+o+\" found\")]);for(var s in e){var l=s.match(/^(.*)-transition$/);a=l&&n[l[1]]&&n[l[1]].transition?a.concat(ln({key:s,value:e[s],valueSpec:r.transition,style:i,styleSpec:r})):n[s]?a.concat(ln({key:s,value:e[s],valueSpec:n[s],style:i,styleSpec:r})):a.concat([new Dt(s,e[s],'unknown property \"'+s+'\"')])}return a}function on(t){var e=t.value,r=t.key,n=wr(e);return\"string\"!==n?[new Dt(r,e,\"string expected, \"+n+\" found\")]:[]}var sn={\"*\":function(){return[]},array:Br,boolean:function(t){var e=t.value,r=t.key,n=wr(e);return\"boolean\"!==n?[new Dt(r,e,\"boolean expected, \"+n+\" found\")]:[]},number:Nr,color:function(t){var e=t.key,r=t.value,n=wr(r);return\"string\"!==n?[new Dt(e,r,\"color expected, \"+n+\" found\")]:null===re(r)?[new Dt(e,r,'color expected, \"'+r+'\" found')]:[]},constants:Rt,enum:Vr,filter:$r,function:jr,layer:rn,object:Fr,source:nn,light:an,string:on,formatted:function(t){return 0===on(t).length?[]:Ur(t)}};function ln(t){var e=t.value,r=t.valueSpec,n=t.styleSpec;return r.expression&&kr(Nt(e))?jr(t):r.expression&&Pr(jt(e))?Ur(t):r.type&&sn[r.type]?sn[r.type](t):Fr(Ft({},t,{valueSpec:r.type?n[r.type]:r}))}function cn(t){var e=t.value,r=t.key,n=on(t);return n.length?n:(-1===e.indexOf(\"{fontstack}\")&&n.push(new Dt(r,e,'\"glyphs\" url must include a \"{fontstack}\" token')),-1===e.indexOf(\"{range}\")&&n.push(new Dt(r,e,'\"glyphs\" url must include a \"{range}\" token')),n)}function un(t,e){e=e||It;var r=[];return r=r.concat(ln({key:\"\",value:t,valueSpec:e.$root,styleSpec:e,style:t,objectElementValidators:{glyphs:cn,\"*\":function(){return[]}}})),t.constants&&(r=r.concat(Rt({key:\"constants\",value:t.constants,style:t,styleSpec:e}))),hn(r)}function hn(t){return[].concat(t).sort(function(t,e){return t.line-e.line})}function fn(t){return function(){for(var e=[],r=arguments.length;r--;)e[r]=arguments[r];return hn(t.apply(this,e))}}un.source=fn(nn),un.light=fn(an),un.layer=fn(rn),un.filter=fn($r),un.paintProperty=fn(tn),un.layoutProperty=fn(en);var pn=un,dn=pn.light,gn=pn.paintProperty,vn=pn.layoutProperty;function mn(t,e){var r=!1;if(e&&e.length)for(var n=0,i=e;n<i.length;n+=1){var a=i[n];t.fire(new Ot(new Error(a.message))),r=!0}return r}var yn=bn,xn=3;function bn(t,e,r){var n=this.cells=[];if(t instanceof ArrayBuffer){this.arrayBuffer=t;var i=new Int32Array(this.arrayBuffer);t=i[0],e=i[1],r=i[2],this.d=e+2*r;for(var a=0;a<this.d*this.d;a++){var o=i[xn+a],s=i[xn+a+1];n.push(o===s?null:i.subarray(o,s))}var l=i[xn+n.length],c=i[xn+n.length+1];this.keys=i.subarray(l,c),this.bboxes=i.subarray(c),this.insert=this._insertReadonly}else{this.d=e+2*r;for(var u=0;u<this.d*this.d;u++)n.push([]);this.keys=[],this.bboxes=[]}this.n=e,this.extent=t,this.padding=r,this.scale=e/t,this.uid=0;var h=r/e*t;this.min=-h,this.max=t+h}bn.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertCell,this.uid++),this.keys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},bn.prototype._insertReadonly=function(){throw\"Cannot insert into a GridIndex created from an ArrayBuffer.\"},bn.prototype._insertCell=function(t,e,r,n,i,a){this.cells[i].push(a)},bn.prototype.query=function(t,e,r,n,i){var a=this.min,o=this.max;if(t<=a&&e<=a&&o<=r&&o<=n&&!i)return Array.prototype.slice.call(this.keys);var s=[];return this._forEachCell(t,e,r,n,this._queryCell,s,{},i),s},bn.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=this.cells[i];if(null!==l)for(var c=this.keys,u=this.bboxes,h=0;h<l.length;h++){var f=l[h];if(void 0===o[f]){var p=4*f;(s?s(u[p+0],u[p+1],u[p+2],u[p+3]):t<=u[p+2]&&e<=u[p+3]&&r>=u[p+0]&&n>=u[p+1])?(o[f]=!0,a.push(c[f])):o[f]=!1}}},bn.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToCellCoord(t),c=this._convertToCellCoord(e),u=this._convertToCellCoord(r),h=this._convertToCellCoord(n),f=l;f<=u;f++)for(var p=c;p<=h;p++){var d=this.d*p+f;if((!s||s(this._convertFromCellCoord(f),this._convertFromCellCoord(p),this._convertFromCellCoord(f+1),this._convertFromCellCoord(p+1)))&&i.call(this,t,e,r,n,d,a,o,s))return}},bn.prototype._convertFromCellCoord=function(t){return(t-this.padding)/this.scale},bn.prototype._convertToCellCoord=function(t){return Math.max(0,Math.min(this.d-1,Math.floor(t*this.scale)+this.padding))},bn.prototype.toArrayBuffer=function(){if(this.arrayBuffer)return this.arrayBuffer;for(var t=this.cells,e=xn+this.cells.length+1+1,r=0,n=0;n<this.cells.length;n++)r+=this.cells[n].length;var i=new Int32Array(e+r+this.keys.length+this.bboxes.length);i[0]=this.extent,i[1]=this.n,i[2]=this.padding;for(var a=e,o=0;o<t.length;o++){var s=t[o];i[xn+o]=a,i.set(s,a),a+=s.length}return i[xn+t.length]=a,i.set(this.keys,a),a+=this.keys.length,i[xn+t.length+1]=a,i.set(this.bboxes,a),a+=this.bboxes.length,i.buffer};var _n=self.ImageData,wn={};function kn(t,e,r){void 0===r&&(r={}),Object.defineProperty(e,\"_classRegistryKey\",{value:t,writeable:!1}),wn[t]={klass:e,omit:r.omit||[],shallow:r.shallow||[]}}for(var Tn in kn(\"Object\",Object),yn.serialize=function(t,e){var r=t.toArrayBuffer();return e&&e.push(r),{buffer:r}},yn.deserialize=function(t){return new yn(t.buffer)},kn(\"Grid\",yn),kn(\"Color\",ne),kn(\"Error\",Error),kn(\"StylePropertyFunction\",Rr),kn(\"StyleExpression\",Lr,{omit:[\"_evaluator\"]}),kn(\"ZoomDependentExpression\",Ir),kn(\"ZoomConstantExpression\",zr),kn(\"CompoundExpression\",xe,{omit:[\"_evaluate\"]}),fr)fr[Tn]._classRegistryKey||kn(\"Expression_\"+Tn,fr[Tn]);function An(t,e){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp)return t;if(t instanceof ArrayBuffer)return e&&e.push(t),t;if(ArrayBuffer.isView(t)){var r=t;return e&&e.push(r.buffer),r}if(t instanceof _n)return e&&e.push(t.data.buffer),t;if(Array.isArray(t)){for(var n=[],i=0,a=t;i<a.length;i+=1){var o=a[i];n.push(An(o,e))}return n}if(\"object\"==typeof t){var s=t.constructor,l=s._classRegistryKey;if(!l)throw new Error(\"can't serialize object of unregistered class\");var c=s.serialize?s.serialize(t,e):{};if(!s.serialize){for(var u in t)if(t.hasOwnProperty(u)&&!(wn[l].omit.indexOf(u)>=0)){var h=t[u];c[u]=wn[l].shallow.indexOf(u)>=0?h:An(h,e)}t instanceof Error&&(c.message=t.message)}if(c.$name)throw new Error(\"$name property is reserved for worker serialization logic.\");return\"Object\"!==l&&(c.$name=l),c}throw new Error(\"can't serialize object of type \"+typeof t)}function Mn(t){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp||t instanceof ArrayBuffer||ArrayBuffer.isView(t)||t instanceof _n)return t;if(Array.isArray(t))return t.map(Mn);if(\"object\"==typeof t){var e=t.$name||\"Object\",r=wn[e].klass;if(!r)throw new Error(\"can't deserialize unregistered class \"+e);if(r.deserialize)return r.deserialize(t);for(var n=Object.create(r.prototype),i=0,a=Object.keys(t);i<a.length;i+=1){var o=a[i];if(\"$name\"!==o){var s=t[o];n[o]=wn[e].shallow.indexOf(o)>=0?s:Mn(s)}}return n}throw new Error(\"can't deserialize object of type \"+typeof t)}var Sn=function(){this.first=!0};Sn.prototype.update=function(t,e){var r=Math.floor(t);return this.first?(this.first=!1,this.lastIntegerZoom=r,this.lastIntegerZoomTime=0,this.lastZoom=t,this.lastFloorZoom=r,!0):(this.lastFloorZoom>r?(this.lastIntegerZoom=r+1,this.lastIntegerZoomTime=e):this.lastFloorZoom<r&&(this.lastIntegerZoom=r,this.lastIntegerZoomTime=e),t!==this.lastZoom&&(this.lastZoom=t,this.lastFloorZoom=r,!0))};var En={\"Latin-1 Supplement\":function(t){return t>=128&&t<=255},Arabic:function(t){return t>=1536&&t<=1791},\"Arabic Supplement\":function(t){return t>=1872&&t<=1919},\"Arabic Extended-A\":function(t){return t>=2208&&t<=2303},\"Hangul Jamo\":function(t){return t>=4352&&t<=4607},\"Unified Canadian Aboriginal Syllabics\":function(t){return t>=5120&&t<=5759},Khmer:function(t){return t>=6016&&t<=6143},\"Unified Canadian Aboriginal Syllabics Extended\":function(t){return t>=6320&&t<=6399},\"General Punctuation\":function(t){return t>=8192&&t<=8303},\"Letterlike Symbols\":function(t){return t>=8448&&t<=8527},\"Number Forms\":function(t){return t>=8528&&t<=8591},\"Miscellaneous Technical\":function(t){return t>=8960&&t<=9215},\"Control Pictures\":function(t){return t>=9216&&t<=9279},\"Optical Character Recognition\":function(t){return t>=9280&&t<=9311},\"Enclosed Alphanumerics\":function(t){return t>=9312&&t<=9471},\"Geometric Shapes\":function(t){return t>=9632&&t<=9727},\"Miscellaneous Symbols\":function(t){return t>=9728&&t<=9983},\"Miscellaneous Symbols and Arrows\":function(t){return t>=11008&&t<=11263},\"CJK Radicals Supplement\":function(t){return t>=11904&&t<=12031},\"Kangxi Radicals\":function(t){return t>=12032&&t<=12255},\"Ideographic Description Characters\":function(t){return t>=12272&&t<=12287},\"CJK Symbols and Punctuation\":function(t){return t>=12288&&t<=12351},Hiragana:function(t){return t>=12352&&t<=12447},Katakana:function(t){return t>=12448&&t<=12543},Bopomofo:function(t){return t>=12544&&t<=12591},\"Hangul Compatibility Jamo\":function(t){return t>=12592&&t<=12687},Kanbun:function(t){return t>=12688&&t<=12703},\"Bopomofo Extended\":function(t){return t>=12704&&t<=12735},\"CJK Strokes\":function(t){return t>=12736&&t<=12783},\"Katakana Phonetic Extensions\":function(t){return t>=12784&&t<=12799},\"Enclosed CJK Letters and Months\":function(t){return t>=12800&&t<=13055},\"CJK Compatibility\":function(t){return t>=13056&&t<=13311},\"CJK Unified Ideographs Extension A\":function(t){return t>=13312&&t<=19903},\"Yijing Hexagram Symbols\":function(t){return t>=19904&&t<=19967},\"CJK Unified Ideographs\":function(t){return t>=19968&&t<=40959},\"Yi Syllables\":function(t){return t>=40960&&t<=42127},\"Yi Radicals\":function(t){return t>=42128&&t<=42191},\"Hangul Jamo Extended-A\":function(t){return t>=43360&&t<=43391},\"Hangul Syllables\":function(t){return t>=44032&&t<=55215},\"Hangul Jamo Extended-B\":function(t){return t>=55216&&t<=55295},\"Private Use Area\":function(t){return t>=57344&&t<=63743},\"CJK Compatibility Ideographs\":function(t){return t>=63744&&t<=64255},\"Arabic Presentation Forms-A\":function(t){return t>=64336&&t<=65023},\"Vertical Forms\":function(t){return t>=65040&&t<=65055},\"CJK Compatibility Forms\":function(t){return t>=65072&&t<=65103},\"Small Form Variants\":function(t){return t>=65104&&t<=65135},\"Arabic Presentation Forms-B\":function(t){return t>=65136&&t<=65279},\"Halfwidth and Fullwidth Forms\":function(t){return t>=65280&&t<=65519}};function Cn(t){for(var e=0,r=t;e<r.length;e+=1)if(On(r[e].charCodeAt(0)))return!0;return!1}function Ln(t){for(var e=0,r=t;e<r.length;e+=1)if(!Pn(r[e].charCodeAt(0)))return!1;return!0}function Pn(t){return!(En.Arabic(t)||En[\"Arabic Supplement\"](t)||En[\"Arabic Extended-A\"](t)||En[\"Arabic Presentation Forms-A\"](t)||En[\"Arabic Presentation Forms-B\"](t))}function On(t){return!!(746===t||747===t||!(t<4352)&&(En[\"Bopomofo Extended\"](t)||En.Bopomofo(t)||En[\"CJK Compatibility Forms\"](t)&&!(t>=65097&&t<=65103)||En[\"CJK Compatibility Ideographs\"](t)||En[\"CJK Compatibility\"](t)||En[\"CJK Radicals Supplement\"](t)||En[\"CJK Strokes\"](t)||!(!En[\"CJK Symbols and Punctuation\"](t)||t>=12296&&t<=12305||t>=12308&&t<=12319||12336===t)||En[\"CJK Unified Ideographs Extension A\"](t)||En[\"CJK Unified Ideographs\"](t)||En[\"Enclosed CJK Letters and Months\"](t)||En[\"Hangul Compatibility Jamo\"](t)||En[\"Hangul Jamo Extended-A\"](t)||En[\"Hangul Jamo Extended-B\"](t)||En[\"Hangul Jamo\"](t)||En[\"Hangul Syllables\"](t)||En.Hiragana(t)||En[\"Ideographic Description Characters\"](t)||En.Kanbun(t)||En[\"Kangxi Radicals\"](t)||En[\"Katakana Phonetic Extensions\"](t)||En.Katakana(t)&&12540!==t||!(!En[\"Halfwidth and Fullwidth Forms\"](t)||65288===t||65289===t||65293===t||t>=65306&&t<=65310||65339===t||65341===t||65343===t||t>=65371&&t<=65503||65507===t||t>=65512&&t<=65519)||!(!En[\"Small Form Variants\"](t)||t>=65112&&t<=65118||t>=65123&&t<=65126)||En[\"Unified Canadian Aboriginal Syllabics\"](t)||En[\"Unified Canadian Aboriginal Syllabics Extended\"](t)||En[\"Vertical Forms\"](t)||En[\"Yijing Hexagram Symbols\"](t)||En[\"Yi Syllables\"](t)||En[\"Yi Radicals\"](t)))}function zn(t){return!(On(t)||function(t){return!!(En[\"Latin-1 Supplement\"](t)&&(167===t||169===t||174===t||177===t||188===t||189===t||190===t||215===t||247===t)||En[\"General Punctuation\"](t)&&(8214===t||8224===t||8225===t||8240===t||8241===t||8251===t||8252===t||8258===t||8263===t||8264===t||8265===t||8273===t)||En[\"Letterlike Symbols\"](t)||En[\"Number Forms\"](t)||En[\"Miscellaneous Technical\"](t)&&(t>=8960&&t<=8967||t>=8972&&t<=8991||t>=8996&&t<=9e3||9003===t||t>=9085&&t<=9114||t>=9150&&t<=9165||9167===t||t>=9169&&t<=9179||t>=9186&&t<=9215)||En[\"Control Pictures\"](t)&&9251!==t||En[\"Optical Character Recognition\"](t)||En[\"Enclosed Alphanumerics\"](t)||En[\"Geometric Shapes\"](t)||En[\"Miscellaneous Symbols\"](t)&&!(t>=9754&&t<=9759)||En[\"Miscellaneous Symbols and Arrows\"](t)&&(t>=11026&&t<=11055||t>=11088&&t<=11097||t>=11192&&t<=11243)||En[\"CJK Symbols and Punctuation\"](t)||En.Katakana(t)||En[\"Private Use Area\"](t)||En[\"CJK Compatibility Forms\"](t)||En[\"Small Form Variants\"](t)||En[\"Halfwidth and Fullwidth Forms\"](t)||8734===t||8756===t||8757===t||t>=9984&&t<=10087||t>=10102&&t<=10131||65532===t||65533===t)}(t))}function In(t,e){return!(!e&&(t>=1424&&t<=2303||En[\"Arabic Presentation Forms-A\"](t)||En[\"Arabic Presentation Forms-B\"](t))||t>=2304&&t<=3583||t>=3840&&t<=4255||En.Khmer(t))}var Dn,Rn=!1,Fn=null,Bn=!1,Nn=new zt,jn={applyArabicShaping:null,processBidirectionalText:null,processStyledBidirectionalText:null,isLoaded:function(){return Bn||null!=jn.applyArabicShaping}},Un=function(t,e){this.zoom=t,e?(this.now=e.now,this.fadeDuration=e.fadeDuration,this.zoomHistory=e.zoomHistory,this.transition=e.transition):(this.now=0,this.fadeDuration=0,this.zoomHistory=new Sn,this.transition={})};Un.prototype.isSupportedScript=function(t){return function(t,e){for(var r=0,n=t;r<n.length;r+=1)if(!In(n[r].charCodeAt(0),e))return!1;return!0}(t,jn.isLoaded())},Un.prototype.crossFadingFactor=function(){return 0===this.fadeDuration?1:Math.min((this.now-this.zoomHistory.lastIntegerZoomTime)/this.fadeDuration,1)},Un.prototype.getCrossfadeParameters=function(){var t=this.zoom,e=t-Math.floor(t),r=this.crossFadingFactor();return t>this.zoomHistory.lastIntegerZoom?{fromScale:2,toScale:1,t:e+(1-e)*r}:{fromScale:.5,toScale:1,t:1-(1-r)*e}};var Vn=function(t,e){this.property=t,this.value=e,this.expression=function(t,e){if(kr(t))return new Rr(t,e);if(Pr(t)){var r=Dr(t,e);if(\"error\"===r.result)throw new Error(r.value.map(function(t){return t.key+\": \"+t.message}).join(\", \"));return r.value}var n=t;return\"string\"==typeof t&&\"color\"===e.type&&(n=ne.parse(t)),{kind:\"constant\",evaluate:function(){return n}}}(void 0===e?t.specification.default:e,t.specification)};Vn.prototype.isDataDriven=function(){return\"source\"===this.expression.kind||\"composite\"===this.expression.kind},Vn.prototype.possiblyEvaluate=function(t){return this.property.possiblyEvaluate(this,t)};var qn=function(t){this.property=t,this.value=new Vn(t,void 0)};qn.prototype.transitioned=function(t,e){return new Gn(this.property,this.value,e,h({},t.transition,this.transition),t.now)},qn.prototype.untransitioned=function(){return new Gn(this.property,this.value,null,{},0)};var Hn=function(t){this._properties=t,this._values=Object.create(t.defaultTransitionablePropertyValues)};Hn.prototype.getValue=function(t){return b(this._values[t].value.value)},Hn.prototype.setValue=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new qn(this._values[t].property)),this._values[t].value=new Vn(this._values[t].property,null===e?void 0:b(e))},Hn.prototype.getTransition=function(t){return b(this._values[t].transition)},Hn.prototype.setTransition=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new qn(this._values[t].property)),this._values[t].transition=b(e)||void 0},Hn.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i);var a=this.getTransition(n);void 0!==a&&(t[n+\"-transition\"]=a)}return t},Hn.prototype.transitioned=function(t,e){for(var r=new Yn(this._properties),n=0,i=Object.keys(this._values);n<i.length;n+=1){var a=i[n];r._values[a]=this._values[a].transitioned(t,e._values[a])}return r},Hn.prototype.untransitioned=function(){for(var t=new Yn(this._properties),e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e];t._values[n]=this._values[n].untransitioned()}return t};var Gn=function(t,e,r,n,i){this.property=t,this.value=e,this.begin=i+n.delay||0,this.end=this.begin+n.duration||0,t.specification.transition&&(n.delay||n.duration)&&(this.prior=r)};Gn.prototype.possiblyEvaluate=function(t){var e=t.now||0,r=this.value.possiblyEvaluate(t),n=this.prior;if(n){if(e>this.end)return this.prior=null,r;if(this.value.isDataDriven())return this.prior=null,r;if(e<this.begin)return n.possiblyEvaluate(t);var i=(e-this.begin)/(this.end-this.begin);return this.property.interpolate(n.possiblyEvaluate(t),r,function(t){if(i<=0)return 0;if(i>=1)return 1;var e=i*i,r=e*i;return 4*(i<.5?r:3*(i-e)+r-.75)}())}return r};var Yn=function(t){this._properties=t,this._values=Object.create(t.defaultTransitioningPropertyValues)};Yn.prototype.possiblyEvaluate=function(t){for(var e=new Zn(this._properties),r=0,n=Object.keys(this._values);r<n.length;r+=1){var i=n[r];e._values[i]=this._values[i].possiblyEvaluate(t)}return e},Yn.prototype.hasTransition=function(){for(var t=0,e=Object.keys(this._values);t<e.length;t+=1){var r=e[t];if(this._values[r].prior)return!0}return!1};var Wn=function(t){this._properties=t,this._values=Object.create(t.defaultPropertyValues)};Wn.prototype.getValue=function(t){return b(this._values[t].value)},Wn.prototype.setValue=function(t,e){this._values[t]=new Vn(this._values[t].property,null===e?void 0:b(e))},Wn.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i)}return t},Wn.prototype.possiblyEvaluate=function(t){for(var e=new Zn(this._properties),r=0,n=Object.keys(this._values);r<n.length;r+=1){var i=n[r];e._values[i]=this._values[i].possiblyEvaluate(t)}return e};var Xn=function(t,e,r){this.property=t,this.value=e,this.parameters=r};Xn.prototype.isConstant=function(){return\"constant\"===this.value.kind},Xn.prototype.constantOr=function(t){return\"constant\"===this.value.kind?this.value.value:t},Xn.prototype.evaluate=function(t,e){return this.property.evaluate(this.value,this.parameters,t,e)};var Zn=function(t){this._properties=t,this._values=Object.create(t.defaultPossiblyEvaluatedValues)};Zn.prototype.get=function(t){return this._values[t]};var Jn=function(t){this.specification=t};Jn.prototype.possiblyEvaluate=function(t,e){return t.expression.evaluate(e)},Jn.prototype.interpolate=function(t,e,r){var n=Ce[this.specification.type];return n?n(t,e,r):t};var Kn=function(t){this.specification=t};Kn.prototype.possiblyEvaluate=function(t,e){return\"constant\"===t.expression.kind||\"camera\"===t.expression.kind?new Xn(this,{kind:\"constant\",value:t.expression.evaluate(e)},e):new Xn(this,t.expression,e)},Kn.prototype.interpolate=function(t,e,r){if(\"constant\"!==t.value.kind||\"constant\"!==e.value.kind)return t;if(void 0===t.value.value||void 0===e.value.value)return new Xn(this,{kind:\"constant\",value:void 0},t.parameters);var n=Ce[this.specification.type];return n?new Xn(this,{kind:\"constant\",value:n(t.value.value,e.value.value,r)},t.parameters):t},Kn.prototype.evaluate=function(t,e,r,n){return\"constant\"===t.kind?t.value:t.evaluate(e,r,n)};var $n=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(t,e){if(void 0===t.value)return new Xn(this,{kind:\"constant\",value:void 0},e);if(\"constant\"===t.expression.kind){var r=t.expression.evaluate(e),n=this._calculate(r,r,r,e);return new Xn(this,{kind:\"constant\",value:n},e)}if(\"camera\"===t.expression.kind){var i=this._calculate(t.expression.evaluate({zoom:e.zoom-1}),t.expression.evaluate({zoom:e.zoom}),t.expression.evaluate({zoom:e.zoom+1}),e);return new Xn(this,{kind:\"constant\",value:i},e)}return new Xn(this,t.expression,e)},e.prototype.evaluate=function(t,e,r,n){if(\"source\"===t.kind){var i=t.evaluate(e,r,n);return this._calculate(i,i,i,e)}return\"composite\"===t.kind?this._calculate(t.evaluate({zoom:Math.floor(e.zoom)-1},r,n),t.evaluate({zoom:Math.floor(e.zoom)},r,n),t.evaluate({zoom:Math.floor(e.zoom)+1},r,n),e):t.value},e.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},e.prototype.interpolate=function(t){return t},e}(Kn),Qn=function(t){this.specification=t};Qn.prototype.possiblyEvaluate=function(t,e){if(void 0!==t.value){if(\"constant\"===t.expression.kind){var r=t.expression.evaluate(e);return this._calculate(r,r,r,e)}return this._calculate(t.expression.evaluate(new Un(Math.floor(e.zoom-1),e)),t.expression.evaluate(new Un(Math.floor(e.zoom),e)),t.expression.evaluate(new Un(Math.floor(e.zoom+1),e)),e)}},Qn.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},Qn.prototype.interpolate=function(t){return t};var ti=function(t){this.specification=t};ti.prototype.possiblyEvaluate=function(t,e){return!!t.expression.evaluate(e)},ti.prototype.interpolate=function(){return!1};var ei=function(t){for(var e in this.properties=t,this.defaultPropertyValues={},this.defaultTransitionablePropertyValues={},this.defaultTransitioningPropertyValues={},this.defaultPossiblyEvaluatedValues={},t){var r=t[e],n=this.defaultPropertyValues[e]=new Vn(r,void 0),i=this.defaultTransitionablePropertyValues[e]=new qn(r);this.defaultTransitioningPropertyValues[e]=i.untransitioned(),this.defaultPossiblyEvaluatedValues[e]=n.possiblyEvaluate({})}};kn(\"DataDrivenProperty\",Kn),kn(\"DataConstantProperty\",Jn),kn(\"CrossFadedDataDrivenProperty\",$n),kn(\"CrossFadedProperty\",Qn),kn(\"ColorRampProperty\",ti);var ri=function(t){function e(e,r){if(t.call(this),this.id=e.id,this.type=e.type,this._featureFilter=function(){return!0},\"custom\"!==e.type&&(e=e,this.metadata=e.metadata,this.minzoom=e.minzoom,this.maxzoom=e.maxzoom,\"background\"!==e.type&&(this.source=e.source,this.sourceLayer=e[\"source-layer\"],this.filter=e.filter),r.layout&&(this._unevaluatedLayout=new Wn(r.layout)),r.paint)){for(var n in this._transitionablePaint=new Hn(r.paint),e.paint)this.setPaintProperty(n,e.paint[n],{validate:!1});for(var i in e.layout)this.setLayoutProperty(i,e.layout[i],{validate:!1});this._transitioningPaint=this._transitionablePaint.untransitioned()}}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getCrossfadeParameters=function(){return this._crossfadeParameters},e.prototype.getLayoutProperty=function(t){return\"visibility\"===t?this.visibility:this._unevaluatedLayout.getValue(t)},e.prototype.setLayoutProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e){var n=\"layers.\"+this.id+\".layout.\"+t;if(this._validate(vn,n,t,e,r))return}\"visibility\"!==t?this._unevaluatedLayout.setValue(t,e):this.visibility=e},e.prototype.getPaintProperty=function(t){return m(t,\"-transition\")?this._transitionablePaint.getTransition(t.slice(0,-\"-transition\".length)):this._transitionablePaint.getValue(t)},e.prototype.setPaintProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e){var n=\"layers.\"+this.id+\".paint.\"+t;if(this._validate(gn,n,t,e,r))return!1}if(m(t,\"-transition\"))return this._transitionablePaint.setTransition(t.slice(0,-\"-transition\".length),e||void 0),!1;var i=this._transitionablePaint._values[t],a=\"cross-faded-data-driven\"===i.property.specification[\"property-type\"],o=i.value.isDataDriven();return this._transitionablePaint.setValue(t,e),this._handleSpecialPaintPropertyUpdate(t),this._transitionablePaint._values[t].value.isDataDriven()||o||a},e.prototype._handleSpecialPaintPropertyUpdate=function(t){},e.prototype.isHidden=function(t){return!!(this.minzoom&&t<this.minzoom)||!!(this.maxzoom&&t>=this.maxzoom)||\"none\"===this.visibility},e.prototype.updateTransitions=function(t){this._transitioningPaint=this._transitionablePaint.transitioned(t,this._transitioningPaint)},e.prototype.hasTransition=function(){return this._transitioningPaint.hasTransition()},e.prototype.recalculate=function(t){t.getCrossfadeParameters&&(this._crossfadeParameters=t.getCrossfadeParameters()),this._unevaluatedLayout&&(this.layout=this._unevaluatedLayout.possiblyEvaluate(t)),this.paint=this._transitioningPaint.possiblyEvaluate(t)},e.prototype.serialize=function(){var t={id:this.id,type:this.type,source:this.source,\"source-layer\":this.sourceLayer,metadata:this.metadata,minzoom:this.minzoom,maxzoom:this.maxzoom,filter:this.filter,layout:this._unevaluatedLayout&&this._unevaluatedLayout.serialize(),paint:this._transitionablePaint&&this._transitionablePaint.serialize()};return this.visibility&&(t.layout=t.layout||{},t.layout.visibility=this.visibility),x(t,function(t,e){return!(void 0===t||\"layout\"===e&&!Object.keys(t).length||\"paint\"===e&&!Object.keys(t).length)})},e.prototype._validate=function(t,e,r,n,i){return void 0===i&&(i={}),(!i||!1!==i.validate)&&mn(this,t.call(pn,{key:e,layerType:this.type,objectKey:r,value:n,styleSpec:It,style:{glyphs:!0,sprite:!0}}))},e.prototype.is3D=function(){return!1},e.prototype.isTileClipped=function(){return!1},e.prototype.hasOffscreenPass=function(){return!1},e.prototype.resize=function(){},e.prototype.isStateDependent=function(){for(var t in this.paint._values){var e=this.paint.get(t);if(e instanceof Xn&&xr(e.property.specification)&&(\"source\"===e.value.kind||\"composite\"===e.value.kind)&&e.value.isStateDependent)return!0}return!1},e}(zt),ni={Int8:Int8Array,Uint8:Uint8Array,Int16:Int16Array,Uint16:Uint16Array,Int32:Int32Array,Uint32:Uint32Array,Float32:Float32Array},ii=function(t,e){this._structArray=t,this._pos1=e*this.size,this._pos2=this._pos1/2,this._pos4=this._pos1/4,this._pos8=this._pos1/8},ai=function(){this.isTransferred=!1,this.capacity=-1,this.resize(0)};function oi(t,e){void 0===e&&(e=1);var r=0,n=0;return{members:t.map(function(t){var i,a=(i=t.type,ni[i].BYTES_PER_ELEMENT),o=r=si(r,Math.max(e,a)),s=t.components||1;return n=Math.max(n,a),r+=a*s,{name:t.name,type:t.type,components:s,offset:o}}),size:si(r,Math.max(n,e)),alignment:e}}function si(t,e){return Math.ceil(t/e)*e}ai.serialize=function(t,e){return t._trim(),e&&(t.isTransferred=!0,e.push(t.arrayBuffer)),{length:t.length,arrayBuffer:t.arrayBuffer}},ai.deserialize=function(t){var e=Object.create(this.prototype);return e.arrayBuffer=t.arrayBuffer,e.length=t.length,e.capacity=t.arrayBuffer.byteLength/e.bytesPerElement,e._refreshViews(),e},ai.prototype._trim=function(){this.length!==this.capacity&&(this.capacity=this.length,this.arrayBuffer=this.arrayBuffer.slice(0,this.length*this.bytesPerElement),this._refreshViews())},ai.prototype.clear=function(){this.length=0},ai.prototype.resize=function(t){this.reserve(t),this.length=t},ai.prototype.reserve=function(t){if(t>this.capacity){this.capacity=Math.max(t,Math.floor(5*this.capacity),128),this.arrayBuffer=new ArrayBuffer(this.capacity*this.bytesPerElement);var e=this.uint8;this._refreshViews(),e&&this.uint8.set(e)}},ai.prototype._refreshViews=function(){throw new Error(\"_refreshViews() must be implemented by each concrete StructArray layout\")};var li=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.int16[n+0]=e,this.int16[n+1]=r,t},e}(ai);li.prototype.bytesPerElement=4,kn(\"StructArrayLayout2i4\",li);var ci=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.int16[a+0]=e,this.int16[a+1]=r,this.int16[a+2]=n,this.int16[a+3]=i,t},e}(ai);ci.prototype.bytesPerElement=8,kn(\"StructArrayLayout4i8\",ci);var ui=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(ai);ui.prototype.bytesPerElement=12,kn(\"StructArrayLayout2i4i12\",ui);var hi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=4*t,l=8*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.uint8[l+4]=n,this.uint8[l+5]=i,this.uint8[l+6]=a,this.uint8[l+7]=o,t},e}(ai);hi.prototype.bytesPerElement=8,kn(\"StructArrayLayout2i4ub8\",hi);var fi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s){var l=this.length;return this.resize(l+1),this.emplace(l,t,e,r,n,i,a,o,s)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l){var c=8*t;return this.uint16[c+0]=e,this.uint16[c+1]=r,this.uint16[c+2]=n,this.uint16[c+3]=i,this.uint16[c+4]=a,this.uint16[c+5]=o,this.uint16[c+6]=s,this.uint16[c+7]=l,t},e}(ai);fi.prototype.bytesPerElement=16,kn(\"StructArrayLayout8ui16\",fi);var pi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s){var l=this.length;return this.resize(l+1),this.emplace(l,t,e,r,n,i,a,o,s)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l){var c=8*t;return this.int16[c+0]=e,this.int16[c+1]=r,this.int16[c+2]=n,this.int16[c+3]=i,this.uint16[c+4]=a,this.uint16[c+5]=o,this.uint16[c+6]=s,this.uint16[c+7]=l,t},e}(ai);pi.prototype.bytesPerElement=16,kn(\"StructArrayLayout4i4ui16\",pi);var di=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.float32[i+0]=e,this.float32[i+1]=r,this.float32[i+2]=n,t},e}(ai);di.prototype.bytesPerElement=12,kn(\"StructArrayLayout3f12\",di);var gi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.uint32[r+0]=e,t},e}(ai);gi.prototype.bytesPerElement=4,kn(\"StructArrayLayout1ul4\",gi);var vi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u){var h=this.length;return this.resize(h+1),this.emplace(h,t,e,r,n,i,a,o,s,l,c,u)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h){var f=12*t,p=6*t;return this.int16[f+0]=e,this.int16[f+1]=r,this.int16[f+2]=n,this.int16[f+3]=i,this.int16[f+4]=a,this.int16[f+5]=o,this.uint32[p+3]=s,this.uint16[f+8]=l,this.uint16[f+9]=c,this.int16[f+10]=u,this.int16[f+11]=h,t},e}(ai);vi.prototype.bytesPerElement=24,kn(\"StructArrayLayout6i1ul2ui2i24\",vi);var mi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(ai);mi.prototype.bytesPerElement=12,kn(\"StructArrayLayout2i2i2i12\",mi);var yi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=12*t,o=3*t;return this.uint8[a+0]=e,this.uint8[a+1]=r,this.float32[o+1]=n,this.float32[o+2]=i,t},e}(ai);yi.prototype.bytesPerElement=12,kn(\"StructArrayLayout2ub2f12\",yi);var xi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d){var g=this.length;return this.resize(g+1),this.emplace(g,t,e,r,n,i,a,o,s,l,c,u,h,f,p,d)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g){var v=22*t,m=11*t,y=44*t;return this.int16[v+0]=e,this.int16[v+1]=r,this.uint16[v+2]=n,this.uint16[v+3]=i,this.uint32[m+2]=a,this.uint32[m+3]=o,this.uint32[m+4]=s,this.uint16[v+10]=l,this.uint16[v+11]=c,this.uint16[v+12]=u,this.float32[m+7]=h,this.float32[m+8]=f,this.uint8[y+36]=p,this.uint8[y+37]=d,this.uint32[m+10]=g,t},e}(ai);xi.prototype.bytesPerElement=44,kn(\"StructArrayLayout2i2ui3ul3ui2f2ub1ul44\",xi);var bi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m){var y=this.length;return this.resize(y+1),this.emplace(y,t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m,y){var x=22*t,b=11*t;return this.int16[x+0]=e,this.int16[x+1]=r,this.int16[x+2]=n,this.int16[x+3]=i,this.int16[x+4]=a,this.int16[x+5]=o,this.uint16[x+6]=s,this.uint16[x+7]=l,this.uint16[x+8]=c,this.uint16[x+9]=u,this.uint16[x+10]=h,this.uint16[x+11]=f,this.uint16[x+12]=p,this.uint16[x+13]=d,this.uint16[x+14]=g,this.uint32[b+8]=v,this.float32[b+9]=m,this.float32[b+10]=y,t},e}(ai);bi.prototype.bytesPerElement=44,kn(\"StructArrayLayout6i9ui1ul2f44\",bi);var _i=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.float32[r+0]=e,t},e}(ai);_i.prototype.bytesPerElement=4,kn(\"StructArrayLayout1f4\",_i);var wi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.int16[i+0]=e,this.int16[i+1]=r,this.int16[i+2]=n,t},e}(ai);wi.prototype.bytesPerElement=6,kn(\"StructArrayLayout3i6\",wi);var ki=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=2*t,a=4*t;return this.uint32[i+0]=e,this.uint16[a+2]=r,this.uint16[a+3]=n,t},e}(ai);ki.prototype.bytesPerElement=8,kn(\"StructArrayLayout1ul2ui8\",ki);var Ti=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.uint16[i+0]=e,this.uint16[i+1]=r,this.uint16[i+2]=n,t},e}(ai);Ti.prototype.bytesPerElement=6,kn(\"StructArrayLayout3ui6\",Ti);var Ai=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.uint16[n+0]=e,this.uint16[n+1]=r,t},e}(ai);Ai.prototype.bytesPerElement=4,kn(\"StructArrayLayout2ui4\",Ai);var Mi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.uint16[r+0]=e,t},e}(ai);Mi.prototype.bytesPerElement=2,kn(\"StructArrayLayout1ui2\",Mi);var Si=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.float32[n+0]=e,this.float32[n+1]=r,t},e}(ai);Si.prototype.bytesPerElement=8,kn(\"StructArrayLayout2f8\",Si);var Ei=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.float32[a+0]=e,this.float32[a+1]=r,this.float32[a+2]=n,this.float32[a+3]=i,t},e}(ai);Ei.prototype.bytesPerElement=16,kn(\"StructArrayLayout4f16\",Ei);var Ci=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorPointX:{configurable:!0},anchorPointY:{configurable:!0},x1:{configurable:!0},y1:{configurable:!0},x2:{configurable:!0},y2:{configurable:!0},featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0},radius:{configurable:!0},signedDistanceFromAnchor:{configurable:!0},anchorPoint:{configurable:!0}};return r.anchorPointX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorPointX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorPointY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorPointY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.x1.get=function(){return this._structArray.int16[this._pos2+2]},r.x1.set=function(t){this._structArray.int16[this._pos2+2]=t},r.y1.get=function(){return this._structArray.int16[this._pos2+3]},r.y1.set=function(t){this._structArray.int16[this._pos2+3]=t},r.x2.get=function(){return this._structArray.int16[this._pos2+4]},r.x2.set=function(t){this._structArray.int16[this._pos2+4]=t},r.y2.get=function(){return this._structArray.int16[this._pos2+5]},r.y2.set=function(t){this._structArray.int16[this._pos2+5]=t},r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.featureIndex.set=function(t){this._structArray.uint32[this._pos4+3]=t},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.sourceLayerIndex.set=function(t){this._structArray.uint16[this._pos2+8]=t},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.bucketIndex.set=function(t){this._structArray.uint16[this._pos2+9]=t},r.radius.get=function(){return this._structArray.int16[this._pos2+10]},r.radius.set=function(t){this._structArray.int16[this._pos2+10]=t},r.signedDistanceFromAnchor.get=function(){return this._structArray.int16[this._pos2+11]},r.signedDistanceFromAnchor.set=function(t){this._structArray.int16[this._pos2+11]=t},r.anchorPoint.get=function(){return new i(this.anchorPointX,this.anchorPointY)},Object.defineProperties(e.prototype,r),e}(ii);Ci.prototype.size=24;var Li=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Ci(this,t)},e}(vi);kn(\"CollisionBoxArray\",Li);var Pi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},glyphStartIndex:{configurable:!0},numGlyphs:{configurable:!0},vertexStartIndex:{configurable:!0},lineStartIndex:{configurable:!0},lineLength:{configurable:!0},segment:{configurable:!0},lowerSize:{configurable:!0},upperSize:{configurable:!0},lineOffsetX:{configurable:!0},lineOffsetY:{configurable:!0},writingMode:{configurable:!0},hidden:{configurable:!0},crossTileID:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.glyphStartIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.glyphStartIndex.set=function(t){this._structArray.uint16[this._pos2+2]=t},r.numGlyphs.get=function(){return this._structArray.uint16[this._pos2+3]},r.numGlyphs.set=function(t){this._structArray.uint16[this._pos2+3]=t},r.vertexStartIndex.get=function(){return this._structArray.uint32[this._pos4+2]},r.vertexStartIndex.set=function(t){this._structArray.uint32[this._pos4+2]=t},r.lineStartIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.lineStartIndex.set=function(t){this._structArray.uint32[this._pos4+3]=t},r.lineLength.get=function(){return this._structArray.uint32[this._pos4+4]},r.lineLength.set=function(t){this._structArray.uint32[this._pos4+4]=t},r.segment.get=function(){return this._structArray.uint16[this._pos2+10]},r.segment.set=function(t){this._structArray.uint16[this._pos2+10]=t},r.lowerSize.get=function(){return this._structArray.uint16[this._pos2+11]},r.lowerSize.set=function(t){this._structArray.uint16[this._pos2+11]=t},r.upperSize.get=function(){return this._structArray.uint16[this._pos2+12]},r.upperSize.set=function(t){this._structArray.uint16[this._pos2+12]=t},r.lineOffsetX.get=function(){return this._structArray.float32[this._pos4+7]},r.lineOffsetX.set=function(t){this._structArray.float32[this._pos4+7]=t},r.lineOffsetY.get=function(){return this._structArray.float32[this._pos4+8]},r.lineOffsetY.set=function(t){this._structArray.float32[this._pos4+8]=t},r.writingMode.get=function(){return this._structArray.uint8[this._pos1+36]},r.writingMode.set=function(t){this._structArray.uint8[this._pos1+36]=t},r.hidden.get=function(){return this._structArray.uint8[this._pos1+37]},r.hidden.set=function(t){this._structArray.uint8[this._pos1+37]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+10]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+10]=t},Object.defineProperties(e.prototype,r),e}(ii);Pi.prototype.size=44;var Oi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Pi(this,t)},e}(xi);kn(\"PlacedSymbolArray\",Oi);var zi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},rightJustifiedTextSymbolIndex:{configurable:!0},centerJustifiedTextSymbolIndex:{configurable:!0},leftJustifiedTextSymbolIndex:{configurable:!0},verticalPlacedTextSymbolIndex:{configurable:!0},key:{configurable:!0},textBoxStartIndex:{configurable:!0},textBoxEndIndex:{configurable:!0},iconBoxStartIndex:{configurable:!0},iconBoxEndIndex:{configurable:!0},featureIndex:{configurable:!0},numHorizontalGlyphVertices:{configurable:!0},numVerticalGlyphVertices:{configurable:!0},numIconVertices:{configurable:!0},crossTileID:{configurable:!0},textBoxScale:{configurable:!0},radialTextOffset:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.rightJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+2]},r.rightJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+2]=t},r.centerJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+3]},r.centerJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+3]=t},r.leftJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+4]},r.leftJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+4]=t},r.verticalPlacedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+5]},r.verticalPlacedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+5]=t},r.key.get=function(){return this._structArray.uint16[this._pos2+6]},r.key.set=function(t){this._structArray.uint16[this._pos2+6]=t},r.textBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+7]},r.textBoxStartIndex.set=function(t){this._structArray.uint16[this._pos2+7]=t},r.textBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.textBoxEndIndex.set=function(t){this._structArray.uint16[this._pos2+8]=t},r.iconBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.iconBoxStartIndex.set=function(t){this._structArray.uint16[this._pos2+9]=t},r.iconBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+10]},r.iconBoxEndIndex.set=function(t){this._structArray.uint16[this._pos2+10]=t},r.featureIndex.get=function(){return this._structArray.uint16[this._pos2+11]},r.featureIndex.set=function(t){this._structArray.uint16[this._pos2+11]=t},r.numHorizontalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+12]},r.numHorizontalGlyphVertices.set=function(t){this._structArray.uint16[this._pos2+12]=t},r.numVerticalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+13]},r.numVerticalGlyphVertices.set=function(t){this._structArray.uint16[this._pos2+13]=t},r.numIconVertices.get=function(){return this._structArray.uint16[this._pos2+14]},r.numIconVertices.set=function(t){this._structArray.uint16[this._pos2+14]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+8]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+8]=t},r.textBoxScale.get=function(){return this._structArray.float32[this._pos4+9]},r.textBoxScale.set=function(t){this._structArray.float32[this._pos4+9]=t},r.radialTextOffset.get=function(){return this._structArray.float32[this._pos4+10]},r.radialTextOffset.set=function(t){this._structArray.float32[this._pos4+10]=t},Object.defineProperties(e.prototype,r),e}(ii);zi.prototype.size=44;var Ii=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new zi(this,t)},e}(bi);kn(\"SymbolInstanceArray\",Ii);var Di=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={offsetX:{configurable:!0}};return r.offsetX.get=function(){return this._structArray.float32[this._pos4+0]},r.offsetX.set=function(t){this._structArray.float32[this._pos4+0]=t},Object.defineProperties(e.prototype,r),e}(ii);Di.prototype.size=4;var Ri=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getoffsetX=function(t){return this.float32[1*t+0]},e.prototype.get=function(t){return new Di(this,t)},e}(_i);kn(\"GlyphOffsetArray\",Ri);var Fi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={x:{configurable:!0},y:{configurable:!0},tileUnitDistanceFromAnchor:{configurable:!0}};return r.x.get=function(){return this._structArray.int16[this._pos2+0]},r.x.set=function(t){this._structArray.int16[this._pos2+0]=t},r.y.get=function(){return this._structArray.int16[this._pos2+1]},r.y.set=function(t){this._structArray.int16[this._pos2+1]=t},r.tileUnitDistanceFromAnchor.get=function(){return this._structArray.int16[this._pos2+2]},r.tileUnitDistanceFromAnchor.set=function(t){this._structArray.int16[this._pos2+2]=t},Object.defineProperties(e.prototype,r),e}(ii);Fi.prototype.size=6;var Bi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getx=function(t){return this.int16[3*t+0]},e.prototype.gety=function(t){return this.int16[3*t+1]},e.prototype.gettileUnitDistanceFromAnchor=function(t){return this.int16[3*t+2]},e.prototype.get=function(t){return new Fi(this,t)},e}(wi);kn(\"SymbolLineVertexArray\",Bi);var Ni=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0}};return r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+0]},r.featureIndex.set=function(t){this._structArray.uint32[this._pos4+0]=t},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.sourceLayerIndex.set=function(t){this._structArray.uint16[this._pos2+2]=t},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+3]},r.bucketIndex.set=function(t){this._structArray.uint16[this._pos2+3]=t},Object.defineProperties(e.prototype,r),e}(ii);Ni.prototype.size=8;var ji=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Ni(this,t)},e}(ki);kn(\"FeatureIndexArray\",ji);var Ui=oi([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,Vi=function(t){void 0===t&&(t=[]),this.segments=t};function qi(t,e){return 256*(t=c(Math.floor(t),0,255))+c(Math.floor(e),0,255)}Vi.prototype.prepareSegment=function(t,e,r,n){var i=this.segments[this.segments.length-1];return t>Vi.MAX_VERTEX_ARRAY_LENGTH&&w(\"Max vertices per segment is \"+Vi.MAX_VERTEX_ARRAY_LENGTH+\": bucket requested \"+t),(!i||i.vertexLength+t>Vi.MAX_VERTEX_ARRAY_LENGTH||i.sortKey!==n)&&(i={vertexOffset:e.length,primitiveOffset:r.length,vertexLength:0,primitiveLength:0},void 0!==n&&(i.sortKey=n),this.segments.push(i)),i},Vi.prototype.get=function(){return this.segments},Vi.prototype.destroy=function(){for(var t=0,e=this.segments;t<e.length;t+=1){var r=e[t];for(var n in r.vaos)r.vaos[n].destroy()}},Vi.simpleSegment=function(t,e,r,n){return new Vi([{vertexOffset:t,primitiveOffset:e,vertexLength:r,primitiveLength:n,vaos:{},sortKey:0}])},Vi.MAX_VERTEX_ARRAY_LENGTH=Math.pow(2,16)-1,kn(\"SegmentVector\",Vi);var Hi=function(){this.ids=[],this.positions=[],this.indexed=!1};function Gi(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}Hi.prototype.add=function(t,e,r,n){this.ids.push(t),this.positions.push(e,r,n)},Hi.prototype.getPositions=function(t){for(var e=0,r=this.ids.length-1;e<r;){var n=e+r>>1;this.ids[n]>=t?r=n:e=n+1}for(var i=[];this.ids[e]===t;){var a=this.positions[3*e],o=this.positions[3*e+1],s=this.positions[3*e+2];i.push({index:a,start:o,end:s}),e++}return i},Hi.serialize=function(t,e){var r=new Float64Array(t.ids),n=new Uint32Array(t.positions);return function t(e,r,n,i){if(!(n>=i)){for(var a=e[n+i>>1],o=n-1,s=i+1;;){do{o++}while(e[o]<a);do{s--}while(e[s]>a);if(o>=s)break;Gi(e,o,s),Gi(r,3*o,3*s),Gi(r,3*o+1,3*s+1),Gi(r,3*o+2,3*s+2)}t(e,r,n,s),t(e,r,s+1,i)}}(r,n,0,r.length-1),e.push(r.buffer,n.buffer),{ids:r,positions:n}},Hi.deserialize=function(t){var e=new Hi;return e.ids=t.ids,e.positions=t.positions,e.indexed=!0,e},kn(\"FeaturePositionMap\",Hi);var Yi=function(t,e){this.gl=t.gl,this.location=e},Wi=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1i(this.location,t))},e}(Yi),Xi=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1f(this.location,t))},e}(Yi),Zi=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]||(this.current=t,this.gl.uniform2f(this.location,t[0],t[1]))},e}(Yi),Ji=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]||(this.current=t,this.gl.uniform3f(this.location,t[0],t[1],t[2]))},e}(Yi),Ki=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]&&t[3]===this.current[3]||(this.current=t,this.gl.uniform4f(this.location,t[0],t[1],t[2],t[3]))},e}(Yi),$i=function(t){function e(e,r){t.call(this,e,r),this.current=ne.transparent}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t.r===this.current.r&&t.g===this.current.g&&t.b===this.current.b&&t.a===this.current.a||(this.current=t,this.gl.uniform4f(this.location,t.r,t.g,t.b,t.a))},e}(Yi),Qi=new Float32Array(16),ta=function(t){function e(e,r){t.call(this,e,r),this.current=Qi}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(t[12]!==this.current[12]||t[0]!==this.current[0])return this.current=t,void this.gl.uniformMatrix4fv(this.location,!1,t);for(var e=1;e<16;e++)if(t[e]!==this.current[e]){this.current=t,this.gl.uniformMatrix4fv(this.location,!1,t);break}},e}(Yi);function ea(t){return[qi(255*t.r,255*t.g),qi(255*t.b,255*t.a)]}var ra=function(t,e,r){this.value=t,this.names=e,this.uniformNames=this.names.map(function(t){return\"u_\"+t}),this.type=r,this.maxValue=-1/0};ra.prototype.defines=function(){return this.names.map(function(t){return\"#define HAS_UNIFORM_u_\"+t})},ra.prototype.setConstantPatternPositions=function(){},ra.prototype.populatePaintArray=function(){},ra.prototype.updatePaintArray=function(){},ra.prototype.upload=function(){},ra.prototype.destroy=function(){},ra.prototype.setUniforms=function(t,e,r,n){e.set(n.constantOr(this.value))},ra.prototype.getBinding=function(t,e){return\"color\"===this.type?new $i(t,e):new Xi(t,e)},ra.serialize=function(t){var e=t.value,r=t.names,n=t.type;return{value:An(e),names:r,type:n}},ra.deserialize=function(t){var e=t.value,r=t.names,n=t.type;return new ra(Mn(e),r,n)};var na=function(t,e,r){this.value=t,this.names=e,this.uniformNames=this.names.map(function(t){return\"u_\"+t}),this.type=r,this.maxValue=-1/0,this.patternPositions={patternTo:null,patternFrom:null}};na.prototype.defines=function(){return this.names.map(function(t){return\"#define HAS_UNIFORM_u_\"+t})},na.prototype.populatePaintArray=function(){},na.prototype.updatePaintArray=function(){},na.prototype.upload=function(){},na.prototype.destroy=function(){},na.prototype.setConstantPatternPositions=function(t,e){this.patternPositions.patternTo=t.tlbr,this.patternPositions.patternFrom=e.tlbr},na.prototype.setUniforms=function(t,e,r,n,i){var a=this.patternPositions;\"u_pattern_to\"===i&&a.patternTo&&e.set(a.patternTo),\"u_pattern_from\"===i&&a.patternFrom&&e.set(a.patternFrom)},na.prototype.getBinding=function(t,e){return new Ki(t,e)};var ia=function(t,e,r,n){this.expression=t,this.names=e,this.type=r,this.uniformNames=this.names.map(function(t){return\"a_\"+t}),this.maxValue=-1/0,this.paintVertexAttributes=e.map(function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?2:1,offset:0}}),this.paintVertexArray=new n};ia.prototype.defines=function(){return[]},ia.prototype.setConstantPatternPositions=function(){},ia.prototype.populatePaintArray=function(t,e){var r=this.paintVertexArray,n=r.length;r.reserve(t);var i=this.expression.evaluate(new Un(0),e,{});if(\"color\"===this.type)for(var a=ea(i),o=n;o<t;o++)r.emplaceBack(a[0],a[1]);else{for(var s=n;s<t;s++)r.emplaceBack(i);this.maxValue=Math.max(this.maxValue,i)}},ia.prototype.updatePaintArray=function(t,e,r,n){var i=this.paintVertexArray,a=this.expression.evaluate({zoom:0},r,n);if(\"color\"===this.type)for(var o=ea(a),s=t;s<e;s++)i.emplace(s,o[0],o[1]);else{for(var l=t;l<e;l++)i.emplace(l,a);this.maxValue=Math.max(this.maxValue,a)}},ia.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},ia.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},ia.prototype.setUniforms=function(t,e){e.set(0)},ia.prototype.getBinding=function(t,e){return new Xi(t,e)};var aa=function(t,e,r,n,i,a){this.expression=t,this.names=e,this.uniformNames=this.names.map(function(t){return\"u_\"+t+\"_t\"}),this.type=r,this.useIntegerZoom=n,this.zoom=i,this.maxValue=-1/0;var o=a;this.paintVertexAttributes=e.map(function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?4:2,offset:0}}),this.paintVertexArray=new o};aa.prototype.defines=function(){return[]},aa.prototype.setConstantPatternPositions=function(){},aa.prototype.populatePaintArray=function(t,e){var r=this.paintVertexArray,n=r.length;r.reserve(t);var i=this.expression.evaluate(new Un(this.zoom),e,{}),a=this.expression.evaluate(new Un(this.zoom+1),e,{});if(\"color\"===this.type)for(var o=ea(i),s=ea(a),l=n;l<t;l++)r.emplaceBack(o[0],o[1],s[0],s[1]);else{for(var c=n;c<t;c++)r.emplaceBack(i,a);this.maxValue=Math.max(this.maxValue,i,a)}},aa.prototype.updatePaintArray=function(t,e,r,n){var i=this.paintVertexArray,a=this.expression.evaluate({zoom:this.zoom},r,n),o=this.expression.evaluate({zoom:this.zoom+1},r,n);if(\"color\"===this.type)for(var s=ea(a),l=ea(o),c=t;c<e;c++)i.emplace(c,s[0],s[1],l[0],l[1]);else{for(var u=t;u<e;u++)i.emplace(u,a,o);this.maxValue=Math.max(this.maxValue,a,o)}},aa.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},aa.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},aa.prototype.interpolationFactor=function(t){return this.useIntegerZoom?this.expression.interpolationFactor(Math.floor(t),this.zoom,this.zoom+1):this.expression.interpolationFactor(t,this.zoom,this.zoom+1)},aa.prototype.setUniforms=function(t,e,r){e.set(this.interpolationFactor(r.zoom))},aa.prototype.getBinding=function(t,e){return new Xi(t,e)};var oa=function(t,e,r,n,i,a,o){this.expression=t,this.names=e,this.type=r,this.uniformNames=this.names.map(function(t){return\"u_\"+t+\"_t\"}),this.useIntegerZoom=n,this.zoom=i,this.maxValue=-1/0,this.layerId=o,this.paintVertexAttributes=e.map(function(t){return{name:\"a_\"+t,type:\"Uint16\",components:4,offset:0}}),this.zoomInPaintVertexArray=new a,this.zoomOutPaintVertexArray=new a};oa.prototype.defines=function(){return[]},oa.prototype.setConstantPatternPositions=function(){},oa.prototype.populatePaintArray=function(t,e,r){var n=this.zoomInPaintVertexArray,i=this.zoomOutPaintVertexArray,a=this.layerId,o=n.length;if(n.reserve(t),i.reserve(t),r&&e.patterns&&e.patterns[a]){var s=e.patterns[a],l=s.min,c=s.mid,u=s.max,h=r[l],f=r[c],p=r[u];if(!h||!f||!p)return;for(var d=o;d<t;d++)n.emplaceBack(f.tl[0],f.tl[1],f.br[0],f.br[1],h.tl[0],h.tl[1],h.br[0],h.br[1]),i.emplaceBack(f.tl[0],f.tl[1],f.br[0],f.br[1],p.tl[0],p.tl[1],p.br[0],p.br[1])}},oa.prototype.updatePaintArray=function(t,e,r,n,i){var a=this.zoomInPaintVertexArray,o=this.zoomOutPaintVertexArray,s=this.layerId;if(i&&r.patterns&&r.patterns[s]){var l=r.patterns[s],c=l.min,u=l.mid,h=l.max,f=i[c],p=i[u],d=i[h];if(!f||!p||!d)return;for(var g=t;g<e;g++)a.emplace(g,p.tl[0],p.tl[1],p.br[0],p.br[1],f.tl[0],f.tl[1],f.br[0],f.br[1]),o.emplace(g,p.tl[0],p.tl[1],p.br[0],p.br[1],d.tl[0],d.tl[1],d.br[0],d.br[1])}},oa.prototype.upload=function(t){this.zoomInPaintVertexArray&&this.zoomInPaintVertexArray.arrayBuffer&&this.zoomOutPaintVertexArray&&this.zoomOutPaintVertexArray.arrayBuffer&&(this.zoomInPaintVertexBuffer=t.createVertexBuffer(this.zoomInPaintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent),this.zoomOutPaintVertexBuffer=t.createVertexBuffer(this.zoomOutPaintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},oa.prototype.destroy=function(){this.zoomOutPaintVertexBuffer&&this.zoomOutPaintVertexBuffer.destroy(),this.zoomInPaintVertexBuffer&&this.zoomInPaintVertexBuffer.destroy()},oa.prototype.setUniforms=function(t,e){e.set(0)},oa.prototype.getBinding=function(t,e){return new Xi(t,e)};var sa=function(){this.binders={},this.cacheKey=\"\",this._buffers=[],this._featureMap=new Hi,this._bufferOffset=0};sa.createDynamic=function(t,e,r){var n=new sa,i=[];for(var a in t.paint._values)if(r(a)){var o=t.paint.get(a);if(o instanceof Xn&&xr(o.property.specification)){var s=ca(a,t.type),l=o.property.specification.type,c=o.property.useIntegerZoom;if(\"cross-faded\"===o.property.specification[\"property-type\"]||\"cross-faded-data-driven\"===o.property.specification[\"property-type\"])if(\"constant\"===o.value.kind)n.binders[a]=new na(o.value.value,s,l),i.push(\"/u_\"+a);else{var u=ua(a,l,\"source\");n.binders[a]=new oa(o.value,s,l,c,e,u,t.id),i.push(\"/a_\"+a)}else if(\"constant\"===o.value.kind)n.binders[a]=new ra(o.value.value,s,l),i.push(\"/u_\"+a);else if(\"source\"===o.value.kind){var h=ua(a,l,\"source\");n.binders[a]=new ia(o.value,s,l,h),i.push(\"/a_\"+a)}else{var f=ua(a,l,\"composite\");n.binders[a]=new aa(o.value,s,l,c,e,f),i.push(\"/z_\"+a)}}}return n.cacheKey=i.sort().join(\"\"),n},sa.prototype.populatePaintArrays=function(t,e,r,n){for(var i in this.binders)this.binders[i].populatePaintArray(t,e,n);void 0!==e.id&&this._featureMap.add(+e.id,r,this._bufferOffset,t),this._bufferOffset=t},sa.prototype.setConstantPatternPositions=function(t,e){for(var r in this.binders)this.binders[r].setConstantPatternPositions(t,e)},sa.prototype.updatePaintArrays=function(t,e,r,n){var i=!1;for(var a in t)for(var o=0,s=this._featureMap.getPositions(+a);o<s.length;o+=1){var l=s[o],c=e.feature(l.index);for(var u in this.binders){var h=this.binders[u];if(!(h instanceof ra||h instanceof na)&&!0===h.expression.isStateDependent){var f=r.paint.get(u);h.expression=f.value,h.updatePaintArray(l.start,l.end,c,t[a],n),i=!0}}}return i},sa.prototype.defines=function(){var t=[];for(var e in this.binders)t.push.apply(t,this.binders[e].defines());return t},sa.prototype.getPaintVertexBuffers=function(){return this._buffers},sa.prototype.getUniforms=function(t,e){var r=[];for(var n in this.binders)for(var i=this.binders[n],a=0,o=i.uniformNames;a<o.length;a+=1){var s=o[a];if(e[s]){var l=i.getBinding(t,e[s]);r.push({name:s,property:n,binding:l})}}return r},sa.prototype.setUniforms=function(t,e,r,n){for(var i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.name,l=o.property,c=o.binding;this.binders[l].setUniforms(t,c,n,r.get(l),s)}},sa.prototype.updatePatternPaintBuffers=function(t){var e=[];for(var r in this.binders){var n=this.binders[r];if(n instanceof oa){var i=2===t.fromScale?n.zoomInPaintVertexBuffer:n.zoomOutPaintVertexBuffer;i&&e.push(i)}else(n instanceof ia||n instanceof aa)&&n.paintVertexBuffer&&e.push(n.paintVertexBuffer)}this._buffers=e},sa.prototype.upload=function(t){for(var e in this.binders)this.binders[e].upload(t);var r=[];for(var n in this.binders){var i=this.binders[n];(i instanceof ia||i instanceof aa)&&i.paintVertexBuffer&&r.push(i.paintVertexBuffer)}this._buffers=r},sa.prototype.destroy=function(){for(var t in this.binders)this.binders[t].destroy()};var la=function(t,e,r,n){void 0===n&&(n=function(){return!0}),this.programConfigurations={};for(var i=0,a=e;i<a.length;i+=1){var o=a[i];this.programConfigurations[o.id]=sa.createDynamic(o,r,n),this.programConfigurations[o.id].layoutAttributes=t}this.needsUpload=!1};function ca(t,e){return{\"text-opacity\":[\"opacity\"],\"icon-opacity\":[\"opacity\"],\"text-color\":[\"fill_color\"],\"icon-color\":[\"fill_color\"],\"text-halo-color\":[\"halo_color\"],\"icon-halo-color\":[\"halo_color\"],\"text-halo-blur\":[\"halo_blur\"],\"icon-halo-blur\":[\"halo_blur\"],\"text-halo-width\":[\"halo_width\"],\"icon-halo-width\":[\"halo_width\"],\"line-gap-width\":[\"gapwidth\"],\"line-pattern\":[\"pattern_to\",\"pattern_from\"],\"fill-pattern\":[\"pattern_to\",\"pattern_from\"],\"fill-extrusion-pattern\":[\"pattern_to\",\"pattern_from\"]}[t]||[t.replace(e+\"-\",\"\").replace(/-/g,\"_\")]}function ua(t,e,r){var n={color:{source:Si,composite:Ei},number:{source:_i,composite:Si}},i=function(t){return{\"line-pattern\":{source:fi,composite:fi},\"fill-pattern\":{source:fi,composite:fi},\"fill-extrusion-pattern\":{source:fi,composite:fi}}[t]}(t);return i&&i[r]||n[e][r]}la.prototype.populatePaintArrays=function(t,e,r,n){for(var i in this.programConfigurations)this.programConfigurations[i].populatePaintArrays(t,e,r,n);this.needsUpload=!0},la.prototype.updatePaintArrays=function(t,e,r,n){for(var i=0,a=r;i<a.length;i+=1){var o=a[i];this.needsUpload=this.programConfigurations[o.id].updatePaintArrays(t,e,o,n)||this.needsUpload}},la.prototype.get=function(t){return this.programConfigurations[t]},la.prototype.upload=function(t){if(this.needsUpload){for(var e in this.programConfigurations)this.programConfigurations[e].upload(t);this.needsUpload=!1}},la.prototype.destroy=function(){for(var t in this.programConfigurations)this.programConfigurations[t].destroy()},kn(\"ConstantBinder\",ra),kn(\"CrossFadedConstantBinder\",na),kn(\"SourceExpressionBinder\",ia),kn(\"CrossFadedCompositeBinder\",oa),kn(\"CompositeExpressionBinder\",aa),kn(\"ProgramConfiguration\",sa,{omit:[\"_buffers\"]}),kn(\"ProgramConfigurationSet\",la);var ha=8192,fa=(16,{min:-1*Math.pow(2,15),max:Math.pow(2,15)-1});function pa(t){for(var e=ha/t.extent,r=t.loadGeometry(),n=0;n<r.length;n++)for(var i=r[n],a=0;a<i.length;a++){var o=i[a];o.x=Math.round(o.x*e),o.y=Math.round(o.y*e),(o.x<fa.min||o.x>fa.max||o.y<fa.min||o.y>fa.max)&&w(\"Geometry exceeds allowed extent, reduce your vector tile buffer size\")}return r}function da(t,e,r,n,i){t.emplaceBack(2*e+(n+1)/2,2*r+(i+1)/2)}var ga=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new li,this.indexArray=new Ti,this.segments=new Vi,this.programConfigurations=new la(Ui,t.layers,t.zoom),this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function va(t,e){for(var r=0;r<t.length;r++)if(Aa(e,t[r]))return!0;for(var n=0;n<e.length;n++)if(Aa(t,e[n]))return!0;return!!ba(t,e)}function ma(t,e,r){return!!Aa(t,e)||!!wa(e,t,r)}function ya(t,e){if(1===t.length)return Ta(e,t[0]);for(var r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++)if(Aa(t,n[i]))return!0;for(var a=0;a<t.length;a++)if(Ta(e,t[a]))return!0;for(var o=0;o<e.length;o++)if(ba(t,e[o]))return!0;return!1}function xa(t,e,r){if(t.length>1){if(ba(t,e))return!0;for(var n=0;n<e.length;n++)if(wa(e[n],t,r))return!0}for(var i=0;i<t.length;i++)if(wa(t[i],e,r))return!0;return!1}function ba(t,e){if(0===t.length||0===e.length)return!1;for(var r=0;r<t.length-1;r++)for(var n=t[r],i=t[r+1],a=0;a<e.length-1;a++)if(_a(n,i,e[a],e[a+1]))return!0;return!1}function _a(t,e,r,n){return k(t,r,n)!==k(e,r,n)&&k(t,e,r)!==k(t,e,n)}function wa(t,e,r){var n=r*r;if(1===e.length)return t.distSqr(e[0])<n;for(var i=1;i<e.length;i++)if(ka(t,e[i-1],e[i])<n)return!0;return!1}function ka(t,e,r){var n=e.distSqr(r);if(0===n)return t.distSqr(e);var i=((t.x-e.x)*(r.x-e.x)+(t.y-e.y)*(r.y-e.y))/n;return i<0?t.distSqr(e):i>1?t.distSqr(r):t.distSqr(r.sub(e)._mult(i)._add(e))}function Ta(t,e){for(var r,n,i,a=!1,o=0;o<t.length;o++)for(var s=0,l=(r=t[o]).length-1;s<r.length;l=s++)n=r[s],i=r[l],n.y>e.y!=i.y>e.y&&e.x<(i.x-n.x)*(e.y-n.y)/(i.y-n.y)+n.x&&(a=!a);return a}function Aa(t,e){for(var r=!1,n=0,i=t.length-1;n<t.length;i=n++){var a=t[n],o=t[i];a.y>e.y!=o.y>e.y&&e.x<(o.x-a.x)*(e.y-a.y)/(o.y-a.y)+a.x&&(r=!r)}return r}function Ma(t,e,r){var n=r[0],i=r[2];if(t.x<n.x&&e.x<n.x||t.x>i.x&&e.x>i.x||t.y<n.y&&e.y<n.y||t.y>i.y&&e.y>i.y)return!1;var a=k(t,e,r[0]);return a!==k(t,e,r[1])||a!==k(t,e,r[2])||a!==k(t,e,r[3])}function Sa(t,e,r){var n=e.paint.get(t).value;return\"constant\"===n.kind?n.value:r.programConfigurations.get(e.id).binders[t].maxValue}function Ea(t){return Math.sqrt(t[0]*t[0]+t[1]*t[1])}function Ca(t,e,r,n,a){if(!e[0]&&!e[1])return t;var o=i.convert(e)._mult(a);\"viewport\"===r&&o._rotate(-n);for(var s=[],l=0;l<t.length;l++){var c=t[l];s.push(c.sub(o))}return s}ga.prototype.populate=function(t,e){for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a);this.addFeature(a,l,o),e.featureIndex.insert(a,l,o,s,this.index)}}},ga.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},ga.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},ga.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},ga.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ui),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},ga.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},ga.prototype.addFeature=function(t,e,r){for(var n=0,i=e;n<i.length;n+=1)for(var a=0,o=i[n];a<o.length;a+=1){var s=o[a],l=s.x,c=s.y;if(!(l<0||l>=ha||c<0||c>=ha)){var u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),h=u.vertexLength;da(this.layoutVertexArray,l,c,-1,-1),da(this.layoutVertexArray,l,c,1,-1),da(this.layoutVertexArray,l,c,1,1),da(this.layoutVertexArray,l,c,-1,1),this.indexArray.emplaceBack(h,h+1,h+2),this.indexArray.emplaceBack(h,h+3,h+2),u.vertexLength+=4,u.primitiveLength+=2}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,{})},kn(\"CircleBucket\",ga,{omit:[\"layers\"]});var La={paint:new ei({\"circle-radius\":new Kn(It.paint_circle[\"circle-radius\"]),\"circle-color\":new Kn(It.paint_circle[\"circle-color\"]),\"circle-blur\":new Kn(It.paint_circle[\"circle-blur\"]),\"circle-opacity\":new Kn(It.paint_circle[\"circle-opacity\"]),\"circle-translate\":new Jn(It.paint_circle[\"circle-translate\"]),\"circle-translate-anchor\":new Jn(It.paint_circle[\"circle-translate-anchor\"]),\"circle-pitch-scale\":new Jn(It.paint_circle[\"circle-pitch-scale\"]),\"circle-pitch-alignment\":new Jn(It.paint_circle[\"circle-pitch-alignment\"]),\"circle-stroke-width\":new Kn(It.paint_circle[\"circle-stroke-width\"]),\"circle-stroke-color\":new Kn(It.paint_circle[\"circle-stroke-color\"]),\"circle-stroke-opacity\":new Kn(It.paint_circle[\"circle-stroke-opacity\"])})},Pa=\"undefined\"!=typeof Float32Array?Float32Array:Array;function Oa(){var t=new Pa(9);return Pa!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[5]=0,t[6]=0,t[7]=0),t[0]=1,t[4]=1,t[8]=1,t}function za(){var t=new Pa(3);return Pa!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0),t}function Ia(t,e,r){var n=new Pa(3);return n[0]=t,n[1]=e,n[2]=r,n}Math.PI;function Da(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}function Ra(){var t=new Pa(4);return Pa!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0),t[3]=1,t}za(),function(){var t;t=new Pa(4),Pa!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0,t[3]=0)}();za(),Ia(1,0,0),Ia(0,1,0),Ra(),Ra(),Oa(),function(){var t;t=new Pa(2),Pa!=Float32Array&&(t[0]=0,t[1]=0)}();var Fa=function(t){function e(e){t.call(this,e,La)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new ga(t)},e.prototype.queryRadius=function(t){var e=t;return Sa(\"circle-radius\",this,e)+Sa(\"circle-stroke-width\",this,e)+Ea(this.paint.get(\"circle-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o,s){for(var l=Ca(t,this.paint.get(\"circle-translate\"),this.paint.get(\"circle-translate-anchor\"),a.angle,o),c=this.paint.get(\"circle-radius\").evaluate(e,r)+this.paint.get(\"circle-stroke-width\").evaluate(e,r),u=\"map\"===this.paint.get(\"circle-pitch-alignment\"),h=u?l:function(t,e){return l.map(function(t){return Ba(t,e)})}(0,s),f=u?c*o:c,p=0,d=n;p<d.length;p+=1)for(var g=0,v=d[p];g<v.length;g+=1){var m=v[g],y=u?m:Ba(m,s),x=f,b=Da([],[m.x,m.y,0,1],s);if(\"viewport\"===this.paint.get(\"circle-pitch-scale\")&&\"map\"===this.paint.get(\"circle-pitch-alignment\")?x*=b[3]/a.cameraToCenterDistance:\"map\"===this.paint.get(\"circle-pitch-scale\")&&\"viewport\"===this.paint.get(\"circle-pitch-alignment\")&&(x*=a.cameraToCenterDistance/b[3]),ma(h,y,x))return!0}return!1},e}(ri);function Ba(t,e){var r=Da([],[t.x,t.y,0,1],e);return new i(r[0]/r[3],r[1]/r[3])}var Na=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ga);function ja(t,e,r,n){var i=e.width,a=e.height;if(n){if(n instanceof Uint8ClampedArray)n=new Uint8Array(n.buffer);else if(n.length!==i*a*r)throw new RangeError(\"mismatched image size\")}else n=new Uint8Array(i*a*r);return t.width=i,t.height=a,t.data=n,t}function Ua(t,e,r){var n=e.width,i=e.height;if(n!==t.width||i!==t.height){var a=ja({},{width:n,height:i},r);Va(t,a,{x:0,y:0},{x:0,y:0},{width:Math.min(t.width,n),height:Math.min(t.height,i)},r),t.width=n,t.height=i,t.data=a.data}}function Va(t,e,r,n,i,a){if(0===i.width||0===i.height)return e;if(i.width>t.width||i.height>t.height||r.x>t.width-i.width||r.y>t.height-i.height)throw new RangeError(\"out of range source coordinates for image copy\");if(i.width>e.width||i.height>e.height||n.x>e.width-i.width||n.y>e.height-i.height)throw new RangeError(\"out of range destination coordinates for image copy\");for(var o=t.data,s=e.data,l=0;l<i.height;l++)for(var c=((r.y+l)*t.width+r.x)*a,u=((n.y+l)*e.width+n.x)*a,h=0;h<i.width*a;h++)s[u+h]=o[c+h];return e}kn(\"HeatmapBucket\",Na,{omit:[\"layers\"]});var qa=function(t,e){ja(this,t,1,e)};qa.prototype.resize=function(t){Ua(this,t,1)},qa.prototype.clone=function(){return new qa({width:this.width,height:this.height},new Uint8Array(this.data))},qa.copy=function(t,e,r,n,i){Va(t,e,r,n,i,1)};var Ha=function(t,e){ja(this,t,4,e)};Ha.prototype.resize=function(t){Ua(this,t,4)},Ha.prototype.replace=function(t,e){e?this.data.set(t):t instanceof Uint8ClampedArray?this.data=new Uint8Array(t.buffer):this.data=t},Ha.prototype.clone=function(){return new Ha({width:this.width,height:this.height},new Uint8Array(this.data))},Ha.copy=function(t,e,r,n,i){Va(t,e,r,n,i,4)},kn(\"AlphaImage\",qa),kn(\"RGBAImage\",Ha);var Ga={paint:new ei({\"heatmap-radius\":new Kn(It.paint_heatmap[\"heatmap-radius\"]),\"heatmap-weight\":new Kn(It.paint_heatmap[\"heatmap-weight\"]),\"heatmap-intensity\":new Jn(It.paint_heatmap[\"heatmap-intensity\"]),\"heatmap-color\":new ti(It.paint_heatmap[\"heatmap-color\"]),\"heatmap-opacity\":new Jn(It.paint_heatmap[\"heatmap-opacity\"])})};function Ya(t,e){for(var r=new Uint8Array(1024),n={},i=0,a=0;i<256;i++,a+=4){n[e]=i/255;var o=t.evaluate(n);r[a+0]=Math.floor(255*o.r/o.a),r[a+1]=Math.floor(255*o.g/o.a),r[a+2]=Math.floor(255*o.b/o.a),r[a+3]=Math.floor(255*o.a)}return new Ha({width:256,height:1},r)}var Wa=function(t){function e(e){t.call(this,e,Ga),this._updateColorRamp()}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new Na(t)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"heatmap-color\"===t&&this._updateColorRamp()},e.prototype._updateColorRamp=function(){var t=this._transitionablePaint._values[\"heatmap-color\"].value.expression;this.colorRamp=Ya(t,\"heatmapDensity\"),this.colorRampTexture=null},e.prototype.resize=function(){this.heatmapFbo&&(this.heatmapFbo.destroy(),this.heatmapFbo=null)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"heatmap-opacity\")&&\"none\"!==this.visibility},e}(ri),Xa={paint:new ei({\"hillshade-illumination-direction\":new Jn(It.paint_hillshade[\"hillshade-illumination-direction\"]),\"hillshade-illumination-anchor\":new Jn(It.paint_hillshade[\"hillshade-illumination-anchor\"]),\"hillshade-exaggeration\":new Jn(It.paint_hillshade[\"hillshade-exaggeration\"]),\"hillshade-shadow-color\":new Jn(It.paint_hillshade[\"hillshade-shadow-color\"]),\"hillshade-highlight-color\":new Jn(It.paint_hillshade[\"hillshade-highlight-color\"]),\"hillshade-accent-color\":new Jn(It.paint_hillshade[\"hillshade-accent-color\"])})},Za=function(t){function e(e){t.call(this,e,Xa)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"hillshade-exaggeration\")&&\"none\"!==this.visibility},e}(ri),Ja=oi([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,Ka=Qa,$a=Qa;function Qa(t,e,r){r=r||2;var n,i,a,o,s,l,c,u=e&&e.length,h=u?e[0]*r:t.length,f=to(t,0,h,r,!0),p=[];if(!f||f.next===f.prev)return p;if(u&&(f=function(t,e,r,n){var i,a,o,s=[];for(i=0,a=e.length;i<a;i++)(o=to(t,e[i]*n,i<a-1?e[i+1]*n:t.length,n,!1))===o.next&&(o.steiner=!0),s.push(uo(o));for(s.sort(so),i=0;i<s.length;i++)lo(s[i],r),r=eo(r,r.next);return r}(t,e,f,r)),t.length>80*r){n=a=t[0],i=o=t[1];for(var d=r;d<h;d+=r)(s=t[d])<n&&(n=s),(l=t[d+1])<i&&(i=l),s>a&&(a=s),l>o&&(o=l);c=0!==(c=Math.max(a-n,o-i))?1/c:0}return ro(f,p,r,n,i,c),p}function to(t,e,r,n,i){var a,o;if(i===wo(t,e,r,n)>0)for(a=e;a<r;a+=n)o=xo(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=xo(a,t[a],t[a+1],o);return o&&go(o,o.next)&&(bo(o),o=o.next),o}function eo(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!go(n,n.next)&&0!==po(n.prev,n,n.next))n=n.next;else{if(bo(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function ro(t,e,r,n,i,a,o){if(t){!o&&a&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=co(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,a);for(var s,l,c=t;t.prev!==t.next;)if(s=t.prev,l=t.next,a?io(t,n,i,a):no(t))e.push(s.i/r),e.push(t.i/r),e.push(l.i/r),bo(t),t=l.next,c=l.next;else if((t=l)===c){o?1===o?ro(t=ao(t,e,r),e,r,n,i,a,2):2===o&&oo(t,e,r,n,i,a):ro(eo(t),e,r,n,i,a,1);break}}}function no(t){var e=t.prev,r=t,n=t.next;if(po(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(ho(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&po(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function io(t,e,r,n){var i=t.prev,a=t,o=t.next;if(po(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,h=co(s,l,e,r,n),f=co(c,u,e,r,n),p=t.prevZ,d=t.nextZ;p&&p.z>=h&&d&&d.z<=f;){if(p!==t.prev&&p!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&po(p.prev,p,p.next)>=0)return!1;if(p=p.prevZ,d!==t.prev&&d!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&po(d.prev,d,d.next)>=0)return!1;d=d.nextZ}for(;p&&p.z>=h;){if(p!==t.prev&&p!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&po(p.prev,p,p.next)>=0)return!1;p=p.prevZ}for(;d&&d.z<=f;){if(d!==t.prev&&d!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&po(d.prev,d,d.next)>=0)return!1;d=d.nextZ}return!0}function ao(t,e,r){var n=t;do{var i=n.prev,a=n.next.next;!go(i,a)&&vo(i,n,n.next,a)&&mo(i,a)&&mo(a,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(a.i/r),bo(n),bo(n.next),n=t=a),n=n.next}while(n!==t);return n}function oo(t,e,r,n,i,a){var o=t;do{for(var s=o.next.next;s!==o.prev;){if(o.i!==s.i&&fo(o,s)){var l=yo(o,s);return o=eo(o,o.next),l=eo(l,l.next),ro(o,e,r,n,i,a),void ro(l,e,r,n,i,a)}s=s.next}o=o.next}while(o!==t)}function so(t,e){return t.x-e.x}function lo(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r.prev;var l,c=r,u=r.x,h=r.y,f=1/0;for(n=r.next;n!==c;)i>=n.x&&n.x>=u&&i!==n.x&&ho(a<h?i:o,a,u,h,a<h?o:i,a,n.x,n.y)&&((l=Math.abs(a-n.y)/(i-n.x))<f||l===f&&n.x>r.x)&&mo(n,t)&&(r=n,f=l),n=n.next;return r}(t,e)){var r=yo(e,t);eo(r,r.next)}}function co(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function uo(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function ho(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function fo(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&vo(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&mo(t,e)&&mo(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)}function po(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function go(t,e){return t.x===e.x&&t.y===e.y}function vo(t,e,r,n){return!!(go(t,e)&&go(r,n)||go(t,n)&&go(r,e))||po(t,e,r)>0!=po(t,e,n)>0&&po(r,n,t)>0!=po(r,n,e)>0}function mo(t,e){return po(t.prev,t,t.next)<0?po(t,e,t.next)>=0&&po(t,t.prev,e)>=0:po(t,e,t.prev)<0||po(t,t.next,e)<0}function yo(t,e){var r=new _o(t.i,t.x,t.y),n=new _o(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function xo(t,e,r,n){var i=new _o(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function bo(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function _o(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function wo(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}function ko(t,e,r,n,i){!function t(e,r,n,i,a){for(;i>n;){if(i-n>600){var o=i-n+1,s=r-n+1,l=Math.log(o),c=.5*Math.exp(2*l/3),u=.5*Math.sqrt(l*c*(o-c)/o)*(s-o/2<0?-1:1);t(e,r,Math.max(n,Math.floor(r-s*c/o+u)),Math.min(i,Math.floor(r+(o-s)*c/o+u)),a)}var h=e[r],f=n,p=i;for(To(e,n,r),a(e[i],h)>0&&To(e,n,i);f<p;){for(To(e,f,p),f++,p--;a(e[f],h)<0;)f++;for(;a(e[p],h)>0;)p--}0===a(e[n],h)?To(e,n,p):To(e,++p,i),p<=r&&(n=p+1),r<=p&&(i=p-1)}}(t,e,r||0,n||t.length-1,i||Ao)}function To(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function Ao(t,e){return t<e?-1:t>e?1:0}function Mo(t,e){var r=t.length;if(r<=1)return[t];for(var n,i,a=[],o=0;o<r;o++){var s=T(t[o]);0!==s&&(t[o].area=Math.abs(s),void 0===i&&(i=s<0),i===s<0?(n&&a.push(n),n=[t[o]]):n.push(t[o]))}if(n&&a.push(n),e>1)for(var l=0;l<a.length;l++)a[l].length<=e||(ko(a[l],e,1,a[l].length-1,So),a[l]=a[l].slice(0,e));return a}function So(t,e){return e.area-t.area}function Eo(t,e,r){for(var n=r.patternDependencies,i=!1,a=0,o=e;a<o.length;a+=1){var s=o[a].paint.get(t+\"-pattern\");s.isConstant()||(i=!0);var l=s.constantOr(null);l&&(i=!0,n[l.to]=!0,n[l.from]=!0)}return i}function Co(t,e,r,n,i){for(var a=i.patternDependencies,o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.paint.get(t+\"-pattern\").value;if(\"constant\"!==c.kind){var u=c.evaluate({zoom:n-1},r,{}),h=c.evaluate({zoom:n},r,{}),f=c.evaluate({zoom:n+1},r,{});a[u]=!0,a[h]=!0,a[f]=!0,r.patterns[l.id]={min:u,mid:h,max:f}}}return r}Qa.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(wo(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(wo(t,c,u,r))}var h=0;for(s=0;s<n.length;s+=3){var f=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;h+=Math.abs((t[f]-t[d])*(t[p+1]-t[f+1])-(t[f]-t[p])*(t[d+1]-t[f+1]))}return 0===o&&0===h?0:Math.abs((h-o)/o)},Qa.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r},Ka.default=$a;var Lo=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new li,this.indexArray=new Ti,this.indexArray2=new Ai,this.programConfigurations=new la(Ja,t.layers,t.zoom),this.segments=new Vi,this.segments2=new Vi,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};Lo.prototype.populate=function(t,e){this.features=[],this.hasPattern=Eo(\"fill\",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a),c={sourceLayerIndex:s,index:o,geometry:l,properties:a.properties,type:a.type,patterns:{}};void 0!==a.id&&(c.id=a.id),this.hasPattern?this.features.push(Co(\"fill\",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(a,l,o,s,this.index)}}},Lo.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Lo.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var i=n[r],a=i.geometry;this.addFeature(i,a,i.index,e)}},Lo.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Lo.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Lo.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ja),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.indexBuffer2=t.createIndexBuffer(this.indexArray2)),this.programConfigurations.upload(t),this.uploaded=!0},Lo.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.indexBuffer2.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.segments2.destroy())},Lo.prototype.addFeature=function(t,e,r,n){for(var i=0,a=Mo(e,500);i<a.length;i+=1){for(var o=a[i],s=0,l=0,c=o;l<c.length;l+=1)s+=c[l].length;for(var u=this.segments.prepareSegment(s,this.layoutVertexArray,this.indexArray),h=u.vertexLength,f=[],p=[],d=0,g=o;d<g.length;d+=1){var v=g[d];if(0!==v.length){v!==o[0]&&p.push(f.length/2);var m=this.segments2.prepareSegment(v.length,this.layoutVertexArray,this.indexArray2),y=m.vertexLength;this.layoutVertexArray.emplaceBack(v[0].x,v[0].y),this.indexArray2.emplaceBack(y+v.length-1,y),f.push(v[0].x),f.push(v[0].y);for(var x=1;x<v.length;x++)this.layoutVertexArray.emplaceBack(v[x].x,v[x].y),this.indexArray2.emplaceBack(y+x-1,y+x),f.push(v[x].x),f.push(v[x].y);m.vertexLength+=v.length,m.primitiveLength+=v.length}}for(var b=Ka(f,p),_=0;_<b.length;_+=3)this.indexArray.emplaceBack(h+b[_],h+b[_+1],h+b[_+2]);u.vertexLength+=s,u.primitiveLength+=b.length/3}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,n)},kn(\"FillBucket\",Lo,{omit:[\"layers\",\"features\"]});var Po={paint:new ei({\"fill-antialias\":new Jn(It.paint_fill[\"fill-antialias\"]),\"fill-opacity\":new Kn(It.paint_fill[\"fill-opacity\"]),\"fill-color\":new Kn(It.paint_fill[\"fill-color\"]),\"fill-outline-color\":new Kn(It.paint_fill[\"fill-outline-color\"]),\"fill-translate\":new Jn(It.paint_fill[\"fill-translate\"]),\"fill-translate-anchor\":new Jn(It.paint_fill[\"fill-translate-anchor\"]),\"fill-pattern\":new $n(It.paint_fill[\"fill-pattern\"])})},Oo=function(t){function e(e){t.call(this,e,Po)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e);var r=this.paint._values[\"fill-outline-color\"];\"constant\"===r.value.kind&&void 0===r.value.value&&(this.paint._values[\"fill-outline-color\"]=this.paint._values[\"fill-color\"])},e.prototype.createBucket=function(t){return new Lo(t)},e.prototype.queryRadius=function(){return Ea(this.paint.get(\"fill-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o){return ya(Ca(t,this.paint.get(\"fill-translate\"),this.paint.get(\"fill-translate-anchor\"),a.angle,o),n)},e.prototype.isTileClipped=function(){return!0},e}(ri),zo=oi([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_normal_ed\",components:4,type:\"Int16\"}],4).members,Io=Do;function Do(t,e,r,n,i){this.properties={},this.extent=r,this.type=0,this._pbf=t,this._geometry=-1,this._keys=n,this._values=i,t.readFields(Ro,this,e)}function Ro(t,e,r){1==t?e.id=r.readVarint():2==t?function(t,e){for(var r=t.readVarint()+t.pos;t.pos<r;){var n=e._keys[t.readVarint()],i=e._values[t.readVarint()];e.properties[n]=i}}(r,e):3==t?e.type=r.readVarint():4==t&&(e._geometry=r.pos)}function Fo(t){for(var e,r,n=0,i=0,a=t.length,o=a-1;i<a;o=i++)e=t[i],n+=((r=t[o]).x-e.x)*(e.y+r.y);return n}Do.types=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],Do.prototype.loadGeometry=function(){var t=this._pbf;t.pos=this._geometry;for(var e,r=t.readVarint()+t.pos,n=1,a=0,o=0,s=0,l=[];t.pos<r;){if(a<=0){var c=t.readVarint();n=7&c,a=c>>3}if(a--,1===n||2===n)o+=t.readSVarint(),s+=t.readSVarint(),1===n&&(e&&l.push(e),e=[]),e.push(new i(o,s));else{if(7!==n)throw new Error(\"unknown command \"+n);e&&e.push(e[0].clone())}}return e&&l.push(e),l},Do.prototype.bbox=function(){var t=this._pbf;t.pos=this._geometry;for(var e=t.readVarint()+t.pos,r=1,n=0,i=0,a=0,o=1/0,s=-1/0,l=1/0,c=-1/0;t.pos<e;){if(n<=0){var u=t.readVarint();r=7&u,n=u>>3}if(n--,1===r||2===r)(i+=t.readSVarint())<o&&(o=i),i>s&&(s=i),(a+=t.readSVarint())<l&&(l=a),a>c&&(c=a);else if(7!==r)throw new Error(\"unknown command \"+r)}return[o,l,s,c]},Do.prototype.toGeoJSON=function(t,e,r){var n,i,a=this.extent*Math.pow(2,r),o=this.extent*t,s=this.extent*e,l=this.loadGeometry(),c=Do.types[this.type];function u(t){for(var e=0;e<t.length;e++){var r=t[e],n=180-360*(r.y+s)/a;t[e]=[360*(r.x+o)/a-180,360/Math.PI*Math.atan(Math.exp(n*Math.PI/180))-90]}}switch(this.type){case 1:var h=[];for(n=0;n<l.length;n++)h[n]=l[n][0];u(l=h);break;case 2:for(n=0;n<l.length;n++)u(l[n]);break;case 3:for(l=function(t){var e=t.length;if(e<=1)return[t];for(var r,n,i=[],a=0;a<e;a++){var o=Fo(t[a]);0!==o&&(void 0===n&&(n=o<0),n===o<0?(r&&i.push(r),r=[t[a]]):r.push(t[a]))}return r&&i.push(r),i}(l),n=0;n<l.length;n++)for(i=0;i<l[n].length;i++)u(l[n][i])}1===l.length?l=l[0]:c=\"Multi\"+c;var f={type:\"Feature\",geometry:{type:c,coordinates:l},properties:this.properties};return\"id\"in this&&(f.id=this.id),f};var Bo=No;function No(t,e){this.version=1,this.name=null,this.extent=4096,this.length=0,this._pbf=t,this._keys=[],this._values=[],this._features=[],t.readFields(jo,this,e),this.length=this._features.length}function jo(t,e,r){15===t?e.version=r.readVarint():1===t?e.name=r.readString():5===t?e.extent=r.readVarint():2===t?e._features.push(r.pos):3===t?e._keys.push(r.readString()):4===t&&e._values.push(function(t){for(var e=null,r=t.readVarint()+t.pos;t.pos<r;){var n=t.readVarint()>>3;e=1===n?t.readString():2===n?t.readFloat():3===n?t.readDouble():4===n?t.readVarint64():5===n?t.readVarint():6===n?t.readSVarint():7===n?t.readBoolean():null}return e}(r))}function Uo(t,e,r){if(3===t){var n=new Bo(r,r.readVarint()+r.pos);n.length&&(e[n.name]=n)}}No.prototype.feature=function(t){if(t<0||t>=this._features.length)throw new Error(\"feature index out of bounds\");this._pbf.pos=this._features[t];var e=this._pbf.readVarint()+this._pbf.pos;return new Io(this._pbf,e,this.extent,this._keys,this._values)};var Vo={VectorTile:function(t,e){this.layers=t.readFields(Uo,{},e)},VectorTileFeature:Io,VectorTileLayer:Bo},qo=Vo.VectorTileFeature.types,Ho=Math.pow(2,13);function Go(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,2*Math.floor(n*Ho)+o,i*Ho*2,a*Ho*2,Math.round(s))}var Yo=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new ui,this.indexArray=new Ti,this.programConfigurations=new la(zo,t.layers,t.zoom),this.segments=new Vi,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function Wo(t,e){return t.x===e.x&&(t.x<0||t.x>ha)||t.y===e.y&&(t.y<0||t.y>ha)}function Xo(t){return t.every(function(t){return t.x<0})||t.every(function(t){return t.x>ha})||t.every(function(t){return t.y<0})||t.every(function(t){return t.y>ha})}Yo.prototype.populate=function(t,e){this.features=[],this.hasPattern=Eo(\"fill-extrusion\",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a),c={sourceLayerIndex:s,index:o,geometry:l,properties:a.properties,type:a.type,patterns:{}};void 0!==a.id&&(c.id=a.id),this.hasPattern?this.features.push(Co(\"fill-extrusion\",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(a,l,o,s,this.index,!0)}}},Yo.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var i=n[r],a=i.geometry;this.addFeature(i,a,i.index,e)}},Yo.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Yo.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Yo.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Yo.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,zo),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Yo.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Yo.prototype.addFeature=function(t,e,r,n){for(var i=0,a=Mo(e,500);i<a.length;i+=1){for(var o=a[i],s=0,l=0,c=o;l<c.length;l+=1)s+=c[l].length;for(var u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),h=0,f=o;h<f.length;h+=1){var p=f[h];if(0!==p.length&&!Xo(p))for(var d=0,g=0;g<p.length;g++){var v=p[g];if(g>=1){var m=p[g-1];if(!Wo(v,m)){u.vertexLength+4>Vi.MAX_VERTEX_ARRAY_LENGTH&&(u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray));var y=v.sub(m)._perp()._unit(),x=m.dist(v);d+x>32768&&(d=0),Go(this.layoutVertexArray,v.x,v.y,y.x,y.y,0,0,d),Go(this.layoutVertexArray,v.x,v.y,y.x,y.y,0,1,d),d+=x,Go(this.layoutVertexArray,m.x,m.y,y.x,y.y,0,0,d),Go(this.layoutVertexArray,m.x,m.y,y.x,y.y,0,1,d);var b=u.vertexLength;this.indexArray.emplaceBack(b,b+2,b+1),this.indexArray.emplaceBack(b+1,b+2,b+3),u.vertexLength+=4,u.primitiveLength+=2}}}}if(u.vertexLength+s>Vi.MAX_VERTEX_ARRAY_LENGTH&&(u=this.segments.prepareSegment(s,this.layoutVertexArray,this.indexArray)),\"Polygon\"===qo[t.type]){for(var _=[],w=[],k=u.vertexLength,T=0,A=o;T<A.length;T+=1){var M=A[T];if(0!==M.length){M!==o[0]&&w.push(_.length/2);for(var S=0;S<M.length;S++){var E=M[S];Go(this.layoutVertexArray,E.x,E.y,0,0,1,1,0),_.push(E.x),_.push(E.y)}}}for(var C=Ka(_,w),L=0;L<C.length;L+=3)this.indexArray.emplaceBack(k+C[L],k+C[L+2],k+C[L+1]);u.primitiveLength+=C.length/3,u.vertexLength+=s}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,n)},kn(\"FillExtrusionBucket\",Yo,{omit:[\"layers\",\"features\"]});var Zo={paint:new ei({\"fill-extrusion-opacity\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-opacity\"]),\"fill-extrusion-color\":new Kn(It[\"paint_fill-extrusion\"][\"fill-extrusion-color\"]),\"fill-extrusion-translate\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-translate\"]),\"fill-extrusion-translate-anchor\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-translate-anchor\"]),\"fill-extrusion-pattern\":new $n(It[\"paint_fill-extrusion\"][\"fill-extrusion-pattern\"]),\"fill-extrusion-height\":new Kn(It[\"paint_fill-extrusion\"][\"fill-extrusion-height\"]),\"fill-extrusion-base\":new Kn(It[\"paint_fill-extrusion\"][\"fill-extrusion-base\"]),\"fill-extrusion-vertical-gradient\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-vertical-gradient\"])})},Jo=function(t){function e(e){t.call(this,e,Zo)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new Yo(t)},e.prototype.queryRadius=function(){return Ea(this.paint.get(\"fill-extrusion-translate\"))},e.prototype.is3D=function(){return!0},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s,l){var c=Ca(t,this.paint.get(\"fill-extrusion-translate\"),this.paint.get(\"fill-extrusion-translate-anchor\"),o.angle,s),u=this.paint.get(\"fill-extrusion-height\").evaluate(e,r),h=this.paint.get(\"fill-extrusion-base\").evaluate(e,r),f=function(t,e,r,n){for(var a=[],o=0,s=t;o<s.length;o+=1){var l=s[o],c=[l.x,l.y,0,1];Da(c,c,e),a.push(new i(c[0]/c[3],c[1]/c[3]))}return a}(c,l),p=function(t,e,r,n){for(var a=[],o=[],s=n[8]*e,l=n[9]*e,c=n[10]*e,u=n[11]*e,h=n[8]*r,f=n[9]*r,p=n[10]*r,d=n[11]*r,g=0,v=t;g<v.length;g+=1){for(var m=[],y=[],x=0,b=v[g];x<b.length;x+=1){var _=b[x],w=_.x,k=_.y,T=n[0]*w+n[4]*k+n[12],A=n[1]*w+n[5]*k+n[13],M=n[2]*w+n[6]*k+n[14],S=n[3]*w+n[7]*k+n[15],E=M+c,C=S+u,L=T+h,P=A+f,O=M+p,z=S+d,I=new i((T+s)/C,(A+l)/C);I.z=E/C,m.push(I);var D=new i(L/z,P/z);D.z=O/z,y.push(D)}a.push(m),o.push(y)}return[a,o]}(n,h,u,l);return function(t,e,r){var n=1/0;ya(r,e)&&(n=$o(r,e[0]));for(var i=0;i<e.length;i++)for(var a=e[i],o=t[i],s=0;s<a.length-1;s++){var l=a[s],c=a[s+1],u=o[s],h=[l,c,o[s+1],u,l];va(r,h)&&(n=Math.min(n,$o(r,h)))}return n!==1/0&&n}(p[0],p[1],f)},e}(ri);function Ko(t,e){return t.x*e.x+t.y*e.y}function $o(t,e){if(1===t.length){var r=e[0],n=e[1],i=e[3],a=t[0],o=n.sub(r),s=i.sub(r),l=a.sub(r),c=Ko(o,o),u=Ko(o,s),h=Ko(s,s),f=Ko(l,o),p=Ko(l,s),d=c*h-u*u,g=(h*f-u*p)/d,v=(c*p-u*f)/d,m=1-g-v;return r.z*m+n.z*g+i.z*v}for(var y=1/0,x=0,b=e;x<b.length;x+=1){var _=b[x];y=Math.min(y,_.z)}return y}var Qo=oi([{name:\"a_pos_normal\",components:2,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint8\"}],4).members,ts=Vo.VectorTileFeature.types,es=63,rs=Math.cos(Math.PI/180*37.5),ns=.5,is=Math.pow(2,14)/ns;function as(t,e,r,n,i,a,o){t.emplaceBack((e.x<<1)+(n?1:0),(e.y<<1)+(i?1:0),Math.round(es*r.x)+128,Math.round(es*r.y)+128,1+(0===a?0:a<0?-1:1)|(o*ns&63)<<2,o*ns>>6)}var os=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.features=[],this.hasPattern=!1,this.layoutVertexArray=new hi,this.indexArray=new Ti,this.programConfigurations=new la(Qo,t.layers,t.zoom),this.segments=new Vi,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function ss(t,e){return(t/e.tileTotal*(e.end-e.start)+e.start)*(is-1)}os.prototype.populate=function(t,e){this.features=[],this.hasPattern=Eo(\"line\",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a),c={sourceLayerIndex:s,index:o,geometry:l,properties:a.properties,type:a.type,patterns:{}};void 0!==a.id&&(c.id=a.id),this.hasPattern?this.features.push(Co(\"line\",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(a,l,o,s,this.index)}}},os.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},os.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var i=n[r],a=i.geometry;this.addFeature(i,a,i.index,e)}},os.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},os.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},os.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Qo),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},os.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},os.prototype.addFeature=function(t,e,r,n){for(var i=this.layers[0].layout,a=i.get(\"line-join\").evaluate(t,{}),o=i.get(\"line-cap\"),s=i.get(\"line-miter-limit\"),l=i.get(\"line-round-limit\"),c=0,u=e;c<u.length;c+=1){var h=u[c];this.addLine(h,t,a,o,s,l,r,n)}},os.prototype.addLine=function(t,e,r,n,i,a,o,s){var l=null;e.properties&&e.properties.hasOwnProperty(\"mapbox_clip_start\")&&e.properties.hasOwnProperty(\"mapbox_clip_end\")&&(l={start:e.properties.mapbox_clip_start,end:e.properties.mapbox_clip_end,tileTotal:void 0});for(var c=\"Polygon\"===ts[e.type],u=t.length;u>=2&&t[u-1].equals(t[u-2]);)u--;for(var h=0;h<u-1&&t[h].equals(t[h+1]);)h++;if(!(u<(c?3:2))){l&&(l.tileTotal=function(t,e,r){for(var n,i,a=0,o=h;o<r-1;o++)n=t[o],i=t[o+1],a+=n.dist(i);return a}(t,0,u)),\"bevel\"===r&&(i=1.05);var f=ha/(512*this.overscaling)*15,p=t[h],d=this.segments.prepareSegment(10*u,this.layoutVertexArray,this.indexArray);this.distance=0;var g,v,m,y=n,x=c?\"butt\":n,b=!0,_=void 0,w=void 0,k=void 0,T=void 0;this.e1=this.e2=this.e3=-1,c&&(g=t[u-2],T=p.sub(g)._unit()._perp());for(var A=h;A<u;A++)if(!(w=c&&A===u-1?t[h+1]:t[A+1])||!t[A].equals(w)){T&&(k=T),g&&(_=g),g=t[A],T=w?w.sub(g)._unit()._perp():k;var M=(k=k||T).add(T);0===M.x&&0===M.y||M._unit();var S=M.x*T.x+M.y*T.y,E=0!==S?1/S:1/0,C=S<rs&&_&&w;if(C&&A>h){var L=g.dist(_);if(L>2*f){var P=g.sub(g.sub(_)._mult(f/L)._round());this.distance+=P.dist(_),this.addCurrentVertex(P,this.distance,k.mult(1),0,0,!1,d,l),_=P}}var O=_&&w,z=O?r:w?y:x;if(O&&\"round\"===z&&(E<a?z=\"miter\":E<=2&&(z=\"fakeround\")),\"miter\"===z&&E>i&&(z=\"bevel\"),\"bevel\"===z&&(E>2&&(z=\"flipbevel\"),E<i&&(z=\"miter\")),_&&(this.distance+=g.dist(_)),\"miter\"===z)M._mult(E),this.addCurrentVertex(g,this.distance,M,0,0,!1,d,l);else if(\"flipbevel\"===z){if(E>100)M=T.clone().mult(-1);else{var I=k.x*T.y-k.y*T.x>0?-1:1,D=E*k.add(T).mag()/k.sub(T).mag();M._perp()._mult(D*I)}this.addCurrentVertex(g,this.distance,M,0,0,!1,d,l),this.addCurrentVertex(g,this.distance,M.mult(-1),0,0,!1,d,l)}else if(\"bevel\"===z||\"fakeround\"===z){var R=k.x*T.y-k.y*T.x>0,F=-Math.sqrt(E*E-1);if(R?(m=0,v=F):(v=0,m=F),b||this.addCurrentVertex(g,this.distance,k,v,m,!1,d,l),\"fakeround\"===z){for(var B=Math.floor(8*(.5-(S-.5))),N=void 0,j=0;j<B;j++)N=T.mult((j+1)/(B+1))._add(k)._unit(),this.addPieSliceVertex(g,this.distance,N,R,d,l);this.addPieSliceVertex(g,this.distance,M,R,d,l);for(var U=B-1;U>=0;U--)N=k.mult((U+1)/(B+1))._add(T)._unit(),this.addPieSliceVertex(g,this.distance,N,R,d,l)}w&&this.addCurrentVertex(g,this.distance,T,-v,-m,!1,d,l)}else\"butt\"===z?(b||this.addCurrentVertex(g,this.distance,k,0,0,!1,d,l),w&&this.addCurrentVertex(g,this.distance,T,0,0,!1,d,l)):\"square\"===z?(b||(this.addCurrentVertex(g,this.distance,k,1,1,!1,d,l),this.e1=this.e2=-1),w&&this.addCurrentVertex(g,this.distance,T,-1,-1,!1,d,l)):\"round\"===z&&(b||(this.addCurrentVertex(g,this.distance,k,0,0,!1,d,l),this.addCurrentVertex(g,this.distance,k,1,1,!0,d,l),this.e1=this.e2=-1),w&&(this.addCurrentVertex(g,this.distance,T,-1,-1,!0,d,l),this.addCurrentVertex(g,this.distance,T,0,0,!1,d,l)));if(C&&A<u-1){var V=g.dist(w);if(V>2*f){var q=g.add(w.sub(g)._mult(f/V)._round());this.distance+=q.dist(g),this.addCurrentVertex(q,this.distance,T.mult(1),0,0,!1,d,l),g=q}}b=!1}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,e,o,s)}},os.prototype.addCurrentVertex=function(t,e,r,n,i,a,o,s){var l,c=this.layoutVertexArray,u=this.indexArray;s&&(e=ss(e,s)),l=r.clone(),n&&l._sub(r.perp()._mult(n)),as(c,t,l,a,!1,n,e),this.e3=o.vertexLength++,this.e1>=0&&this.e2>=0&&(u.emplaceBack(this.e1,this.e2,this.e3),o.primitiveLength++),this.e1=this.e2,this.e2=this.e3,l=r.mult(-1),i&&l._sub(r.perp()._mult(i)),as(c,t,l,a,!0,-i,e),this.e3=o.vertexLength++,this.e1>=0&&this.e2>=0&&(u.emplaceBack(this.e1,this.e2,this.e3),o.primitiveLength++),this.e1=this.e2,this.e2=this.e3,e>is/2&&!s&&(this.distance=0,this.addCurrentVertex(t,this.distance,r,n,i,a,o))},os.prototype.addPieSliceVertex=function(t,e,r,n,i,a){r=r.mult(n?-1:1);var o=this.layoutVertexArray,s=this.indexArray;a&&(e=ss(e,a)),as(o,t,r,!1,n,0,e),this.e3=i.vertexLength++,this.e1>=0&&this.e2>=0&&(s.emplaceBack(this.e1,this.e2,this.e3),i.primitiveLength++),n?this.e2=this.e3:this.e1=this.e3},kn(\"LineBucket\",os,{omit:[\"layers\",\"features\"]});var ls=new ei({\"line-cap\":new Jn(It.layout_line[\"line-cap\"]),\"line-join\":new Kn(It.layout_line[\"line-join\"]),\"line-miter-limit\":new Jn(It.layout_line[\"line-miter-limit\"]),\"line-round-limit\":new Jn(It.layout_line[\"line-round-limit\"])}),cs={paint:new ei({\"line-opacity\":new Kn(It.paint_line[\"line-opacity\"]),\"line-color\":new Kn(It.paint_line[\"line-color\"]),\"line-translate\":new Jn(It.paint_line[\"line-translate\"]),\"line-translate-anchor\":new Jn(It.paint_line[\"line-translate-anchor\"]),\"line-width\":new Kn(It.paint_line[\"line-width\"]),\"line-gap-width\":new Kn(It.paint_line[\"line-gap-width\"]),\"line-offset\":new Kn(It.paint_line[\"line-offset\"]),\"line-blur\":new Kn(It.paint_line[\"line-blur\"]),\"line-dasharray\":new Qn(It.paint_line[\"line-dasharray\"]),\"line-pattern\":new $n(It.paint_line[\"line-pattern\"]),\"line-gradient\":new ti(It.paint_line[\"line-gradient\"])}),layout:ls},us=new(function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(e,r){return r=new Un(Math.floor(r.zoom),{now:r.now,fadeDuration:r.fadeDuration,zoomHistory:r.zoomHistory,transition:r.transition}),t.prototype.possiblyEvaluate.call(this,e,r)},e.prototype.evaluate=function(e,r,n,i){return r=h({},r,{zoom:Math.floor(r.zoom)}),t.prototype.evaluate.call(this,e,r,n,i)},e}(Kn))(cs.paint.properties[\"line-width\"].specification);us.useIntegerZoom=!0;var hs=function(t){function e(e){t.call(this,e,cs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"line-gradient\"===t&&this._updateGradient()},e.prototype._updateGradient=function(){var t=this._transitionablePaint._values[\"line-gradient\"].value.expression;this.gradient=Ya(t,\"lineProgress\"),this.gradientTexture=null},e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e),this.paint._values[\"line-floorwidth\"]=us.possiblyEvaluate(this._transitioningPaint._values[\"line-width\"].value,e)},e.prototype.createBucket=function(t){return new os(t)},e.prototype.queryRadius=function(t){var e=t,r=fs(Sa(\"line-width\",this,e),Sa(\"line-gap-width\",this,e)),n=Sa(\"line-offset\",this,e);return r/2+Math.abs(n)+Ea(this.paint.get(\"line-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s){var l=Ca(t,this.paint.get(\"line-translate\"),this.paint.get(\"line-translate-anchor\"),o.angle,s),c=s/2*fs(this.paint.get(\"line-width\").evaluate(e,r),this.paint.get(\"line-gap-width\").evaluate(e,r)),u=this.paint.get(\"line-offset\").evaluate(e,r);return u&&(n=function(t,e){for(var r=[],n=new i(0,0),a=0;a<t.length;a++){for(var o=t[a],s=[],l=0;l<o.length;l++){var c=o[l-1],u=o[l],h=o[l+1],f=0===l?n:u.sub(c)._unit()._perp(),p=l===o.length-1?n:h.sub(u)._unit()._perp(),d=f._add(p)._unit(),g=d.x*p.x+d.y*p.y;d._mult(1/g),s.push(d._mult(e)._add(u))}r.push(s)}return r}(n,u*s)),function(t,e,r){for(var n=0;n<e.length;n++){var i=e[n];if(t.length>=3)for(var a=0;a<i.length;a++)if(Aa(t,i[a]))return!0;if(xa(t,i,r))return!0}return!1}(l,n,c)},e.prototype.isTileClipped=function(){return!0},e}(ri);function fs(t,e){return e>0?e+2*t:t}var ps=oi([{name:\"a_pos_offset\",components:4,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint16\"}]),ds=oi([{name:\"a_projected_pos\",components:3,type:\"Float32\"}],4),gs=(oi([{name:\"a_fade_opacity\",components:1,type:\"Uint32\"}],4),oi([{name:\"a_placed\",components:2,type:\"Uint8\"},{name:\"a_shift\",components:2,type:\"Float32\"}])),vs=(oi([{type:\"Int16\",name:\"anchorPointX\"},{type:\"Int16\",name:\"anchorPointY\"},{type:\"Int16\",name:\"x1\"},{type:\"Int16\",name:\"y1\"},{type:\"Int16\",name:\"x2\"},{type:\"Int16\",name:\"y2\"},{type:\"Uint32\",name:\"featureIndex\"},{type:\"Uint16\",name:\"sourceLayerIndex\"},{type:\"Uint16\",name:\"bucketIndex\"},{type:\"Int16\",name:\"radius\"},{type:\"Int16\",name:\"signedDistanceFromAnchor\"}]),oi([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4)),ms=oi([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4);function ys(t,e,r){return t.sections.forEach(function(t){t.text=function(t,e,r){var n=e.layout.get(\"text-transform\").evaluate(r,{});return\"uppercase\"===n?t=t.toLocaleUpperCase():\"lowercase\"===n&&(t=t.toLocaleLowerCase()),jn.applyArabicShaping&&(t=jn.applyArabicShaping(t)),t}(t.text,e,r)}),t}oi([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Uint16\",name:\"glyphStartIndex\"},{type:\"Uint16\",name:\"numGlyphs\"},{type:\"Uint32\",name:\"vertexStartIndex\"},{type:\"Uint32\",name:\"lineStartIndex\"},{type:\"Uint32\",name:\"lineLength\"},{type:\"Uint16\",name:\"segment\"},{type:\"Uint16\",name:\"lowerSize\"},{type:\"Uint16\",name:\"upperSize\"},{type:\"Float32\",name:\"lineOffsetX\"},{type:\"Float32\",name:\"lineOffsetY\"},{type:\"Uint8\",name:\"writingMode\"},{type:\"Uint8\",name:\"hidden\"},{type:\"Uint32\",name:\"crossTileID\"}]),oi([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Int16\",name:\"rightJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"centerJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"leftJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"verticalPlacedTextSymbolIndex\"},{type:\"Uint16\",name:\"key\"},{type:\"Uint16\",name:\"textBoxStartIndex\"},{type:\"Uint16\",name:\"textBoxEndIndex\"},{type:\"Uint16\",name:\"iconBoxStartIndex\"},{type:\"Uint16\",name:\"iconBoxEndIndex\"},{type:\"Uint16\",name:\"featureIndex\"},{type:\"Uint16\",name:\"numHorizontalGlyphVertices\"},{type:\"Uint16\",name:\"numVerticalGlyphVertices\"},{type:\"Uint16\",name:\"numIconVertices\"},{type:\"Uint32\",name:\"crossTileID\"},{type:\"Float32\",name:\"textBoxScale\"},{type:\"Float32\",name:\"radialTextOffset\"}]),oi([{type:\"Float32\",name:\"offsetX\"}]),oi([{type:\"Int16\",name:\"x\"},{type:\"Int16\",name:\"y\"},{type:\"Int16\",name:\"tileUnitDistanceFromAnchor\"}]);var xs={\"!\":\"\\ufe15\",\"#\":\"\\uff03\",$:\"\\uff04\",\"%\":\"\\uff05\",\"&\":\"\\uff06\",\"(\":\"\\ufe35\",\")\":\"\\ufe36\",\"*\":\"\\uff0a\",\"+\":\"\\uff0b\",\",\":\"\\ufe10\",\"-\":\"\\ufe32\",\".\":\"\\u30fb\",\"/\":\"\\uff0f\",\":\":\"\\ufe13\",\";\":\"\\ufe14\",\"<\":\"\\ufe3f\",\"=\":\"\\uff1d\",\">\":\"\\ufe40\",\"?\":\"\\ufe16\",\"@\":\"\\uff20\",\"[\":\"\\ufe47\",\"\\\\\":\"\\uff3c\",\"]\":\"\\ufe48\",\"^\":\"\\uff3e\",_:\"\\ufe33\",\"`\":\"\\uff40\",\"{\":\"\\ufe37\",\"|\":\"\\u2015\",\"}\":\"\\ufe38\",\"~\":\"\\uff5e\",\"\\xa2\":\"\\uffe0\",\"\\xa3\":\"\\uffe1\",\"\\xa5\":\"\\uffe5\",\"\\xa6\":\"\\uffe4\",\"\\xac\":\"\\uffe2\",\"\\xaf\":\"\\uffe3\",\"\\u2013\":\"\\ufe32\",\"\\u2014\":\"\\ufe31\",\"\\u2018\":\"\\ufe43\",\"\\u2019\":\"\\ufe44\",\"\\u201c\":\"\\ufe41\",\"\\u201d\":\"\\ufe42\",\"\\u2026\":\"\\ufe19\",\"\\u2027\":\"\\u30fb\",\"\\u20a9\":\"\\uffe6\",\"\\u3001\":\"\\ufe11\",\"\\u3002\":\"\\ufe12\",\"\\u3008\":\"\\ufe3f\",\"\\u3009\":\"\\ufe40\",\"\\u300a\":\"\\ufe3d\",\"\\u300b\":\"\\ufe3e\",\"\\u300c\":\"\\ufe41\",\"\\u300d\":\"\\ufe42\",\"\\u300e\":\"\\ufe43\",\"\\u300f\":\"\\ufe44\",\"\\u3010\":\"\\ufe3b\",\"\\u3011\":\"\\ufe3c\",\"\\u3014\":\"\\ufe39\",\"\\u3015\":\"\\ufe3a\",\"\\u3016\":\"\\ufe17\",\"\\u3017\":\"\\ufe18\",\"\\uff01\":\"\\ufe15\",\"\\uff08\":\"\\ufe35\",\"\\uff09\":\"\\ufe36\",\"\\uff0c\":\"\\ufe10\",\"\\uff0d\":\"\\ufe32\",\"\\uff0e\":\"\\u30fb\",\"\\uff1a\":\"\\ufe13\",\"\\uff1b\":\"\\ufe14\",\"\\uff1c\":\"\\ufe3f\",\"\\uff1e\":\"\\ufe40\",\"\\uff1f\":\"\\ufe16\",\"\\uff3b\":\"\\ufe47\",\"\\uff3d\":\"\\ufe48\",\"\\uff3f\":\"\\ufe33\",\"\\uff5b\":\"\\ufe37\",\"\\uff5c\":\"\\u2015\",\"\\uff5d\":\"\\ufe38\",\"\\uff5f\":\"\\ufe35\",\"\\uff60\":\"\\ufe36\",\"\\uff61\":\"\\ufe12\",\"\\uff62\":\"\\ufe41\",\"\\uff63\":\"\\ufe42\"},bs=function(t){function e(e,r,n,i){t.call(this,e,r),this.angle=n,void 0!==i&&(this.segment=i)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.clone=function(){return new e(this.x,this.y,this.angle,this.segment)},e}(i);kn(\"Anchor\",bs);var _s=256;function ws(t,e){var r=e.expression;if(\"constant\"===r.kind)return{kind:\"constant\",layoutSize:r.evaluate(new Un(t+1))};if(\"source\"===r.kind)return{kind:\"source\"};for(var n=r.zoomStops,i=r.interpolationType,a=0;a<n.length&&n[a]<=t;)a++;for(var o=a=Math.max(0,a-1);o<n.length&&n[o]<t+1;)o++;o=Math.min(n.length-1,o);var s=n[a],l=n[o];return\"composite\"===r.kind?{kind:\"composite\",minZoom:s,maxZoom:l,interpolationType:i}:{kind:\"camera\",minZoom:s,maxZoom:l,minSize:r.evaluate(new Un(s)),maxSize:r.evaluate(new Un(l)),interpolationType:i}}function ks(t,e,r){var n=e.uSize,i=e.uSizeT,a=r.lowerSize,o=r.upperSize;return\"source\"===t.kind?a/_s:\"composite\"===t.kind?Ee(a/_s,o/_s,i):n}function Ts(t,e){var r=0,n=0;if(\"constant\"===t.kind)n=t.layoutSize;else if(\"source\"!==t.kind){var i=t.interpolationType,a=t.minZoom,o=t.maxZoom,s=i?c(Xe.interpolationFactor(i,e,a,o),0,1):0;\"camera\"===t.kind?n=Ee(t.minSize,t.maxSize,s):r=s}return{uSizeT:r,uSize:n}}var As=Object.freeze({getSizeData:ws,evaluateSizeForFeature:ks,evaluateSizeForZoom:Ts,SIZE_PACK_FACTOR:_s}),Ms=Vo.VectorTileFeature.types,Ss=[{name:\"a_fade_opacity\",components:1,type:\"Uint8\",offset:0}];function Es(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,Math.round(32*n),Math.round(32*i),a,o,s?s[0]:0,s?s[1]:0)}function Cs(t,e,r){t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r)}var Ls=function(t){this.layoutVertexArray=new pi,this.indexArray=new Ti,this.programConfigurations=t,this.segments=new Vi,this.dynamicLayoutVertexArray=new di,this.opacityVertexArray=new gi,this.placedSymbolArray=new Oi};Ls.prototype.upload=function(t,e,r,n){r&&(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,ps.members),this.indexBuffer=t.createIndexBuffer(this.indexArray,e),this.dynamicLayoutVertexBuffer=t.createVertexBuffer(this.dynamicLayoutVertexArray,ds.members,!0),this.opacityVertexBuffer=t.createVertexBuffer(this.opacityVertexArray,Ss,!0),this.opacityVertexBuffer.itemSize=1),(r||n)&&this.programConfigurations.upload(t)},Ls.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.dynamicLayoutVertexBuffer.destroy(),this.opacityVertexBuffer.destroy())},kn(\"SymbolBuffers\",Ls);var Ps=function(t,e,r){this.layoutVertexArray=new t,this.layoutAttributes=e,this.indexArray=new r,this.segments=new Vi,this.collisionVertexArray=new yi};Ps.prototype.upload=function(t){this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,this.layoutAttributes),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.collisionVertexBuffer=t.createVertexBuffer(this.collisionVertexArray,gs.members,!0)},Ps.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.segments.destroy(),this.collisionVertexBuffer.destroy())},kn(\"CollisionBuffers\",Ps);var Os=function(t){this.collisionBoxArray=t.collisionBoxArray,this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.pixelRatio=t.pixelRatio,this.sourceLayerIndex=t.sourceLayerIndex,this.hasPattern=!1;var e=this.layers[0]._unevaluatedLayout._values;this.textSizeData=ws(this.zoom,e[\"text-size\"]),this.iconSizeData=ws(this.zoom,e[\"icon-size\"]);var r=this.layers[0].layout,n=r.get(\"symbol-sort-key\"),i=r.get(\"symbol-z-order\");this.sortFeaturesByKey=\"viewport-y\"!==i&&void 0!==n.constantOr(1);var a=\"viewport-y\"===i||\"auto\"===i&&!this.sortFeaturesByKey;this.sortFeaturesByY=a&&(r.get(\"text-allow-overlap\")||r.get(\"icon-allow-overlap\")||r.get(\"text-ignore-placement\")||r.get(\"icon-ignore-placement\")),this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id}),this.sourceID=t.sourceID};Os.prototype.createArrays=function(){this.text=new Ls(new la(ps.members,this.layers,this.zoom,function(t){return/^text/.test(t)})),this.icon=new Ls(new la(ps.members,this.layers,this.zoom,function(t){return/^icon/.test(t)})),this.collisionBox=new Ps(mi,vs.members,Ai),this.collisionCircle=new Ps(mi,ms.members,Ti),this.glyphOffsetArray=new Ri,this.lineVertexArray=new Bi,this.symbolInstances=new Ii},Os.prototype.calculateGlyphDependencies=function(t,e,r,n){for(var i=0;i<t.length;i++)if(e[t.charCodeAt(i)]=!0,r&&n){var a=xs[t.charAt(i)];a&&(e[a.charCodeAt(0)]=!0)}},Os.prototype.populate=function(t,e){var r=this.layers[0],n=r.layout,i=n.get(\"text-font\"),a=n.get(\"text-field\"),o=n.get(\"icon-image\"),s=(\"constant\"!==a.value.kind||a.value.value.toString().length>0)&&(\"constant\"!==i.value.kind||i.value.value.length>0),l=\"constant\"!==o.value.kind||o.value.value&&o.value.value.length>0,c=n.get(\"symbol-sort-key\");if(this.features=[],s||l){for(var u=e.iconDependencies,h=e.glyphDependencies,f=new Un(this.zoom),p=0,d=t;p<d.length;p+=1){var g=d[p],v=g.feature,m=g.index,y=g.sourceLayerIndex;if(r._featureFilter(f,v)){var x=void 0;if(s){var b=r.getValueAndResolveTokens(\"text-field\",v);x=ys(b instanceof oe?b:oe.fromString(b),r,v)}var _=void 0;if(l&&(_=r.getValueAndResolveTokens(\"icon-image\",v)),x||_){var w=this.sortFeaturesByKey?c.evaluate(v,{}):void 0,k={text:x,icon:_,index:m,sourceLayerIndex:y,geometry:pa(v),properties:v.properties,type:Ms[v.type],sortKey:w};if(void 0!==v.id&&(k.id=v.id),this.features.push(k),_&&(u[_]=!0),x)for(var T=i.evaluate(v,{}).join(\",\"),A=\"map\"===n.get(\"text-rotation-alignment\")&&\"point\"!==n.get(\"symbol-placement\"),M=0,S=x.sections;M<S.length;M+=1){var E=S[M],C=Cn(x.toString()),L=E.fontStack||T,P=h[L]=h[L]||{};this.calculateGlyphDependencies(E.text,P,A,C)}}}}\"line\"===n.get(\"symbol-placement\")&&(this.features=function(t){var e={},r={},n=[],i=0;function a(e){n.push(t[e]),i++}function o(t,e,i){var a=r[t];return delete r[t],r[e]=a,n[a].geometry[0].pop(),n[a].geometry[0]=n[a].geometry[0].concat(i[0]),a}function s(t,r,i){var a=e[r];return delete e[r],e[t]=a,n[a].geometry[0].shift(),n[a].geometry[0]=i[0].concat(n[a].geometry[0]),a}function l(t,e,r){var n=r?e[0][e[0].length-1]:e[0][0];return t+\":\"+n.x+\":\"+n.y}for(var c=0;c<t.length;c++){var u=t[c],h=u.geometry,f=u.text?u.text.toString():null;if(f){var p=l(f,h),d=l(f,h,!0);if(p in r&&d in e&&r[p]!==e[d]){var g=s(p,d,h),v=o(p,d,n[g].geometry);delete e[p],delete r[d],r[l(f,n[v].geometry,!0)]=v,n[g].geometry=null}else p in r?o(p,d,h):d in e?s(p,d,h):(a(c),e[p]=i-1,r[d]=i-1)}else a(c)}return n.filter(function(t){return t.geometry})}(this.features)),this.sortFeaturesByKey&&this.features.sort(function(t,e){return t.sortKey-e.sortKey})}},Os.prototype.update=function(t,e,r){this.stateDependentLayers.length&&(this.text.programConfigurations.updatePaintArrays(t,e,this.layers,r),this.icon.programConfigurations.updatePaintArrays(t,e,this.layers,r))},Os.prototype.isEmpty=function(){return 0===this.symbolInstances.length},Os.prototype.uploadPending=function(){return!this.uploaded||this.text.programConfigurations.needsUpload||this.icon.programConfigurations.needsUpload},Os.prototype.upload=function(t){this.uploaded||(this.collisionBox.upload(t),this.collisionCircle.upload(t)),this.text.upload(t,this.sortFeaturesByY,!this.uploaded,this.text.programConfigurations.needsUpload),this.icon.upload(t,this.sortFeaturesByY,!this.uploaded,this.icon.programConfigurations.needsUpload),this.uploaded=!0},Os.prototype.destroy=function(){this.text.destroy(),this.icon.destroy(),this.collisionBox.destroy(),this.collisionCircle.destroy()},Os.prototype.addToLineVertexArray=function(t,e){var r=this.lineVertexArray.length;if(void 0!==t.segment){for(var n=t.dist(e[t.segment+1]),i=t.dist(e[t.segment]),a={},o=t.segment+1;o<e.length;o++)a[o]={x:e[o].x,y:e[o].y,tileUnitDistanceFromAnchor:n},o<e.length-1&&(n+=e[o+1].dist(e[o]));for(var s=t.segment||0;s>=0;s--)a[s]={x:e[s].x,y:e[s].y,tileUnitDistanceFromAnchor:i},s>0&&(i+=e[s-1].dist(e[s]));for(var l=0;l<e.length;l++){var c=a[l];this.lineVertexArray.emplaceBack(c.x,c.y,c.tileUnitDistanceFromAnchor)}}return{lineStartIndex:r,lineLength:this.lineVertexArray.length-r}},Os.prototype.addSymbols=function(t,e,r,n,i,a,o,s,l,c){for(var u=t.indexArray,h=t.layoutVertexArray,f=t.dynamicLayoutVertexArray,p=t.segments.prepareSegment(4*e.length,t.layoutVertexArray,t.indexArray,a.sortKey),d=this.glyphOffsetArray.length,g=p.vertexLength,v=0,m=e;v<m.length;v+=1){var y=m[v],x=y.tl,b=y.tr,_=y.bl,w=y.br,k=y.tex,T=p.vertexLength,A=y.glyphOffset[1];Es(h,s.x,s.y,x.x,A+x.y,k.x,k.y,r),Es(h,s.x,s.y,b.x,A+b.y,k.x+k.w,k.y,r),Es(h,s.x,s.y,_.x,A+_.y,k.x,k.y+k.h,r),Es(h,s.x,s.y,w.x,A+w.y,k.x+k.w,k.y+k.h,r),Cs(f,s,0),u.emplaceBack(T,T+1,T+2),u.emplaceBack(T+1,T+2,T+3),p.vertexLength+=4,p.primitiveLength+=2,this.glyphOffsetArray.emplaceBack(y.glyphOffset[0])}t.placedSymbolArray.emplaceBack(s.x,s.y,d,this.glyphOffsetArray.length-d,g,l,c,s.segment,r?r[0]:0,r?r[1]:0,n[0],n[1],o,!1,0),t.programConfigurations.populatePaintArrays(t.layoutVertexArray.length,a,a.index,{})},Os.prototype._addCollisionDebugVertex=function(t,e,r,n,i,a){return e.emplaceBack(0,0),t.emplaceBack(r.x,r.y,n,i,Math.round(a.x),Math.round(a.y))},Os.prototype.addCollisionDebugVertices=function(t,e,r,n,a,o,s,l){var c=a.segments.prepareSegment(4,a.layoutVertexArray,a.indexArray),u=c.vertexLength,h=a.layoutVertexArray,f=a.collisionVertexArray,p=s.anchorX,d=s.anchorY;if(this._addCollisionDebugVertex(h,f,o,p,d,new i(t,e)),this._addCollisionDebugVertex(h,f,o,p,d,new i(r,e)),this._addCollisionDebugVertex(h,f,o,p,d,new i(r,n)),this._addCollisionDebugVertex(h,f,o,p,d,new i(t,n)),c.vertexLength+=4,l){var g=a.indexArray;g.emplaceBack(u,u+1,u+2),g.emplaceBack(u,u+2,u+3),c.primitiveLength+=2}else{var v=a.indexArray;v.emplaceBack(u,u+1),v.emplaceBack(u+1,u+2),v.emplaceBack(u+2,u+3),v.emplaceBack(u+3,u),c.primitiveLength+=4}},Os.prototype.addDebugCollisionBoxes=function(t,e,r){for(var n=t;n<e;n++){var i=this.collisionBoxArray.get(n),a=i.x1,o=i.y1,s=i.x2,l=i.y2,c=i.radius>0;this.addCollisionDebugVertices(a,o,s,l,c?this.collisionCircle:this.collisionBox,i.anchorPoint,r,c)}},Os.prototype.generateCollisionDebugBuffers=function(){for(var t=0;t<this.symbolInstances.length;t++){var e=this.symbolInstances.get(t);this.addDebugCollisionBoxes(e.textBoxStartIndex,e.textBoxEndIndex,e),this.addDebugCollisionBoxes(e.iconBoxStartIndex,e.iconBoxEndIndex,e)}},Os.prototype._deserializeCollisionBoxesForSymbol=function(t,e,r,n,i){for(var a={},o=e;o<r;o++){var s=t.get(o);if(0===s.radius){a.textBox={x1:s.x1,y1:s.y1,x2:s.x2,y2:s.y2,anchorPointX:s.anchorPointX,anchorPointY:s.anchorPointY},a.textFeatureIndex=s.featureIndex;break}a.textCircles||(a.textCircles=[],a.textFeatureIndex=s.featureIndex),a.textCircles.push(s.anchorPointX,s.anchorPointY,s.radius,s.signedDistanceFromAnchor,1)}for(var l=n;l<i;l++){var c=t.get(l);if(0===c.radius){a.iconBox={x1:c.x1,y1:c.y1,x2:c.x2,y2:c.y2,anchorPointX:c.anchorPointX,anchorPointY:c.anchorPointY},a.iconFeatureIndex=c.featureIndex;break}}return a},Os.prototype.deserializeCollisionBoxes=function(t){this.collisionArrays=[];for(var e=0;e<this.symbolInstances.length;e++){var r=this.symbolInstances.get(e);this.collisionArrays.push(this._deserializeCollisionBoxesForSymbol(t,r.textBoxStartIndex,r.textBoxEndIndex,r.iconBoxStartIndex,r.iconBoxEndIndex))}},Os.prototype.hasTextData=function(){return this.text.segments.get().length>0},Os.prototype.hasIconData=function(){return this.icon.segments.get().length>0},Os.prototype.hasCollisionBoxData=function(){return this.collisionBox.segments.get().length>0},Os.prototype.hasCollisionCircleData=function(){return this.collisionCircle.segments.get().length>0},Os.prototype.addIndicesForPlacedTextSymbol=function(t){for(var e=this.text.placedSymbolArray.get(t),r=e.vertexStartIndex+4*e.numGlyphs,n=e.vertexStartIndex;n<r;n+=4)this.text.indexArray.emplaceBack(n,n+1,n+2),this.text.indexArray.emplaceBack(n+1,n+2,n+3)},Os.prototype.getSortedSymbolIndexes=function(t){if(this.sortedAngle===t&&void 0!==this.symbolInstanceIndexes)return this.symbolInstanceIndexes;for(var e=Math.sin(t),r=Math.cos(t),n=[],i=[],a=[],o=0;o<this.symbolInstances.length;++o){a.push(o);var s=this.symbolInstances.get(o);n.push(0|Math.round(e*s.anchorX+r*s.anchorY)),i.push(s.featureIndex)}return a.sort(function(t,e){return n[t]-n[e]||i[e]-i[t]}),a},Os.prototype.sortFeatures=function(t){var e=this;if(this.sortFeaturesByY&&this.sortedAngle!==t&&!(this.text.segments.get().length>1||this.icon.segments.get().length>1)){this.symbolInstanceIndexes=this.getSortedSymbolIndexes(t),this.sortedAngle=t,this.text.indexArray.clear(),this.icon.indexArray.clear(),this.featureSortOrder=[];for(var r=0,n=this.symbolInstanceIndexes;r<n.length;r+=1){var i=n[r],a=this.symbolInstances.get(i);this.featureSortOrder.push(a.featureIndex),[a.rightJustifiedTextSymbolIndex,a.centerJustifiedTextSymbolIndex,a.leftJustifiedTextSymbolIndex].forEach(function(t,r,n){t>=0&&n.indexOf(t)===r&&e.addIndicesForPlacedTextSymbol(t)}),a.verticalPlacedTextSymbolIndex>=0&&this.addIndicesForPlacedTextSymbol(a.verticalPlacedTextSymbolIndex);var o=this.icon.placedSymbolArray.get(i);if(o.numGlyphs){var s=o.vertexStartIndex;this.icon.indexArray.emplaceBack(s,s+1,s+2),this.icon.indexArray.emplaceBack(s+1,s+2,s+3)}}this.text.indexBuffer&&this.text.indexBuffer.updateData(this.text.indexArray),this.icon.indexBuffer&&this.icon.indexBuffer.updateData(this.icon.indexArray)}},kn(\"SymbolBucket\",Os,{omit:[\"layers\",\"collisionBoxArray\",\"features\",\"compareText\"]}),Os.MAX_GLYPHS=65535,Os.addDynamicAttributes=Cs;var zs=new ei({\"symbol-placement\":new Jn(It.layout_symbol[\"symbol-placement\"]),\"symbol-spacing\":new Jn(It.layout_symbol[\"symbol-spacing\"]),\"symbol-avoid-edges\":new Jn(It.layout_symbol[\"symbol-avoid-edges\"]),\"symbol-sort-key\":new Kn(It.layout_symbol[\"symbol-sort-key\"]),\"symbol-z-order\":new Jn(It.layout_symbol[\"symbol-z-order\"]),\"icon-allow-overlap\":new Jn(It.layout_symbol[\"icon-allow-overlap\"]),\"icon-ignore-placement\":new Jn(It.layout_symbol[\"icon-ignore-placement\"]),\"icon-optional\":new Jn(It.layout_symbol[\"icon-optional\"]),\"icon-rotation-alignment\":new Jn(It.layout_symbol[\"icon-rotation-alignment\"]),\"icon-size\":new Kn(It.layout_symbol[\"icon-size\"]),\"icon-text-fit\":new Jn(It.layout_symbol[\"icon-text-fit\"]),\"icon-text-fit-padding\":new Jn(It.layout_symbol[\"icon-text-fit-padding\"]),\"icon-image\":new Kn(It.layout_symbol[\"icon-image\"]),\"icon-rotate\":new Kn(It.layout_symbol[\"icon-rotate\"]),\"icon-padding\":new Jn(It.layout_symbol[\"icon-padding\"]),\"icon-keep-upright\":new Jn(It.layout_symbol[\"icon-keep-upright\"]),\"icon-offset\":new Kn(It.layout_symbol[\"icon-offset\"]),\"icon-anchor\":new Kn(It.layout_symbol[\"icon-anchor\"]),\"icon-pitch-alignment\":new Jn(It.layout_symbol[\"icon-pitch-alignment\"]),\"text-pitch-alignment\":new Jn(It.layout_symbol[\"text-pitch-alignment\"]),\"text-rotation-alignment\":new Jn(It.layout_symbol[\"text-rotation-alignment\"]),\"text-field\":new Kn(It.layout_symbol[\"text-field\"]),\"text-font\":new Kn(It.layout_symbol[\"text-font\"]),\"text-size\":new Kn(It.layout_symbol[\"text-size\"]),\"text-max-width\":new Kn(It.layout_symbol[\"text-max-width\"]),\"text-line-height\":new Jn(It.layout_symbol[\"text-line-height\"]),\"text-letter-spacing\":new Kn(It.layout_symbol[\"text-letter-spacing\"]),\"text-justify\":new Kn(It.layout_symbol[\"text-justify\"]),\"text-radial-offset\":new Kn(It.layout_symbol[\"text-radial-offset\"]),\"text-variable-anchor\":new Jn(It.layout_symbol[\"text-variable-anchor\"]),\"text-anchor\":new Kn(It.layout_symbol[\"text-anchor\"]),\"text-max-angle\":new Jn(It.layout_symbol[\"text-max-angle\"]),\"text-rotate\":new Kn(It.layout_symbol[\"text-rotate\"]),\"text-padding\":new Jn(It.layout_symbol[\"text-padding\"]),\"text-keep-upright\":new Jn(It.layout_symbol[\"text-keep-upright\"]),\"text-transform\":new Kn(It.layout_symbol[\"text-transform\"]),\"text-offset\":new Kn(It.layout_symbol[\"text-offset\"]),\"text-allow-overlap\":new Jn(It.layout_symbol[\"text-allow-overlap\"]),\"text-ignore-placement\":new Jn(It.layout_symbol[\"text-ignore-placement\"]),\"text-optional\":new Jn(It.layout_symbol[\"text-optional\"])}),Is={paint:new ei({\"icon-opacity\":new Kn(It.paint_symbol[\"icon-opacity\"]),\"icon-color\":new Kn(It.paint_symbol[\"icon-color\"]),\"icon-halo-color\":new Kn(It.paint_symbol[\"icon-halo-color\"]),\"icon-halo-width\":new Kn(It.paint_symbol[\"icon-halo-width\"]),\"icon-halo-blur\":new Kn(It.paint_symbol[\"icon-halo-blur\"]),\"icon-translate\":new Jn(It.paint_symbol[\"icon-translate\"]),\"icon-translate-anchor\":new Jn(It.paint_symbol[\"icon-translate-anchor\"]),\"text-opacity\":new Kn(It.paint_symbol[\"text-opacity\"]),\"text-color\":new Kn(It.paint_symbol[\"text-color\"]),\"text-halo-color\":new Kn(It.paint_symbol[\"text-halo-color\"]),\"text-halo-width\":new Kn(It.paint_symbol[\"text-halo-width\"]),\"text-halo-blur\":new Kn(It.paint_symbol[\"text-halo-blur\"]),\"text-translate\":new Jn(It.paint_symbol[\"text-translate\"]),\"text-translate-anchor\":new Jn(It.paint_symbol[\"text-translate-anchor\"])}),layout:zs},Ds=function(t){function e(e){t.call(this,e,Is)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e),\"auto\"===this.layout.get(\"icon-rotation-alignment\")&&(\"point\"!==this.layout.get(\"symbol-placement\")?this.layout._values[\"icon-rotation-alignment\"]=\"map\":this.layout._values[\"icon-rotation-alignment\"]=\"viewport\"),\"auto\"===this.layout.get(\"text-rotation-alignment\")&&(\"point\"!==this.layout.get(\"symbol-placement\")?this.layout._values[\"text-rotation-alignment\"]=\"map\":this.layout._values[\"text-rotation-alignment\"]=\"viewport\"),\"auto\"===this.layout.get(\"text-pitch-alignment\")&&(this.layout._values[\"text-pitch-alignment\"]=this.layout.get(\"text-rotation-alignment\")),\"auto\"===this.layout.get(\"icon-pitch-alignment\")&&(this.layout._values[\"icon-pitch-alignment\"]=this.layout.get(\"icon-rotation-alignment\"))},e.prototype.getValueAndResolveTokens=function(t,e){var r,n=this.layout.get(t).evaluate(e,{}),i=this._unevaluatedLayout._values[t];return i.isDataDriven()||Pr(i.value)?n:(r=e.properties,n.replace(/{([^{}]+)}/g,function(t,e){return e in r?String(r[e]):\"\"}))},e.prototype.createBucket=function(t){return new Os(t)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e}(ri),Rs={paint:new ei({\"background-color\":new Jn(It.paint_background[\"background-color\"]),\"background-pattern\":new Qn(It.paint_background[\"background-pattern\"]),\"background-opacity\":new Jn(It.paint_background[\"background-opacity\"])})},Fs=function(t){function e(e){t.call(this,e,Rs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ri),Bs={paint:new ei({\"raster-opacity\":new Jn(It.paint_raster[\"raster-opacity\"]),\"raster-hue-rotate\":new Jn(It.paint_raster[\"raster-hue-rotate\"]),\"raster-brightness-min\":new Jn(It.paint_raster[\"raster-brightness-min\"]),\"raster-brightness-max\":new Jn(It.paint_raster[\"raster-brightness-max\"]),\"raster-saturation\":new Jn(It.paint_raster[\"raster-saturation\"]),\"raster-contrast\":new Jn(It.paint_raster[\"raster-contrast\"]),\"raster-resampling\":new Jn(It.paint_raster[\"raster-resampling\"]),\"raster-fade-duration\":new Jn(It.paint_raster[\"raster-fade-duration\"])})},Ns=function(t){function e(e){t.call(this,e,Bs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ri),js=function(t){function e(e){t.call(this,e,{}),this.implementation=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.is3D=function(){return\"3d\"===this.implementation.renderingMode},e.prototype.hasOffscreenPass=function(){return void 0!==this.implementation.prerender},e.prototype.recalculate=function(){},e.prototype.updateTransitions=function(){},e.prototype.hasTransition=function(){},e.prototype.serialize=function(){},e.prototype.onAdd=function(t){this.implementation.onAdd&&this.implementation.onAdd(t,t.painter.context.gl)},e.prototype.onRemove=function(t){this.implementation.onRemove&&this.implementation.onRemove(t,t.painter.context.gl)},e}(ri),Us={circle:Fa,heatmap:Wa,hillshade:Za,fill:Oo,\"fill-extrusion\":Jo,line:hs,symbol:Ds,background:Fs,raster:Ns};function Vs(t){for(var e=0,r=0,n=0,i=t;n<i.length;n+=1){var a=i[n];e+=a.w*a.h,r=Math.max(r,a.w)}t.sort(function(t,e){return e.h-t.h});for(var o=[{x:0,y:0,w:Math.max(Math.ceil(Math.sqrt(e/.95)),r),h:1/0}],s=0,l=0,c=0,u=t;c<u.length;c+=1)for(var h=u[c],f=o.length-1;f>=0;f--){var p=o[f];if(!(h.w>p.w||h.h>p.h)){if(h.x=p.x,h.y=p.y,l=Math.max(l,h.y+h.h),s=Math.max(s,h.x+h.w),h.w===p.w&&h.h===p.h){var d=o.pop();f<o.length&&(o[f]=d)}else h.h===p.h?(p.x+=h.w,p.w-=h.w):h.w===p.w?(p.y+=h.h,p.h-=h.h):(o.push({x:p.x+h.w,y:p.y,w:p.w-h.w,h:h.h}),p.y+=h.h,p.h-=h.h);break}}return{w:s,h:l,fill:e/(s*l)||0}}var qs=function(t,e){var r=e.pixelRatio,n=e.version;this.paddedRect=t,this.pixelRatio=r,this.version=n},Hs={tl:{configurable:!0},br:{configurable:!0},tlbr:{configurable:!0},displaySize:{configurable:!0}};Hs.tl.get=function(){return[this.paddedRect.x+1,this.paddedRect.y+1]},Hs.br.get=function(){return[this.paddedRect.x+this.paddedRect.w-1,this.paddedRect.y+this.paddedRect.h-1]},Hs.tlbr.get=function(){return this.tl.concat(this.br)},Hs.displaySize.get=function(){return[(this.paddedRect.w-2)/this.pixelRatio,(this.paddedRect.h-2)/this.pixelRatio]},Object.defineProperties(qs.prototype,Hs);var Gs=function(t,e){var r={},n={};this.haveRenderCallbacks=[];var i=[];this.addImages(t,r,i),this.addImages(e,n,i);var a=Vs(i),o=a.w,s=a.h,l=new Ha({width:o||1,height:s||1});for(var c in t){var u=t[c],h=r[c].paddedRect;Ha.copy(u.data,l,{x:0,y:0},{x:h.x+1,y:h.y+1},u.data)}for(var f in e){var p=e[f],d=n[f].paddedRect,g=d.x+1,v=d.y+1,m=p.data.width,y=p.data.height;Ha.copy(p.data,l,{x:0,y:0},{x:g,y:v},p.data),Ha.copy(p.data,l,{x:0,y:y-1},{x:g,y:v-1},{width:m,height:1}),Ha.copy(p.data,l,{x:0,y:0},{x:g,y:v+y},{width:m,height:1}),Ha.copy(p.data,l,{x:m-1,y:0},{x:g-1,y:v},{width:1,height:y}),Ha.copy(p.data,l,{x:0,y:0},{x:g+m,y:v},{width:1,height:y})}this.image=l,this.iconPositions=r,this.patternPositions=n};Gs.prototype.addImages=function(t,e,r){for(var n in t){var i=t[n],a={x:0,y:0,w:i.data.width+2,h:i.data.height+2};r.push(a),e[n]=new qs(a,i),i.hasRenderCallback&&this.haveRenderCallbacks.push(n)}},Gs.prototype.patchUpdatedImages=function(t,e){for(var r in t.dispatchRenderCallbacks(this.haveRenderCallbacks),t.updatedImages)this.patchUpdatedImage(this.iconPositions[r],t.getImage(r),e),this.patchUpdatedImage(this.patternPositions[r],t.getImage(r),e)},Gs.prototype.patchUpdatedImage=function(t,e,r){if(t&&e&&t.version!==e.version){t.version=e.version;var n=t.tl,i=n[0],a=n[1];r.update(e.data,void 0,{x:i,y:a})}},kn(\"ImagePosition\",qs),kn(\"ImageAtlas\",Gs);var Ys=self.HTMLImageElement,Ws=self.HTMLCanvasElement,Xs=self.HTMLVideoElement,Zs=self.ImageData,Js=function(t,e,r,n){this.context=t,this.format=r,this.texture=t.gl.createTexture(),this.update(e,n)};Js.prototype.update=function(t,e,r){var n=t.width,i=t.height,a=!(this.size&&this.size[0]===n&&this.size[1]===i||r),o=this.context,s=o.gl;if(this.useMipmap=Boolean(e&&e.useMipmap),s.bindTexture(s.TEXTURE_2D,this.texture),o.pixelStoreUnpackFlipY.set(!1),o.pixelStoreUnpack.set(1),o.pixelStoreUnpackPremultiplyAlpha.set(this.format===s.RGBA&&(!e||!1!==e.premultiply)),a)this.size=[n,i],t instanceof Ys||t instanceof Ws||t instanceof Xs||t instanceof Zs?s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,s.UNSIGNED_BYTE,t):s.texImage2D(s.TEXTURE_2D,0,this.format,n,i,0,this.format,s.UNSIGNED_BYTE,t.data);else{var l=r||{x:0,y:0},c=l.x,u=l.y;t instanceof Ys||t instanceof Ws||t instanceof Xs||t instanceof Zs?s.texSubImage2D(s.TEXTURE_2D,0,c,u,s.RGBA,s.UNSIGNED_BYTE,t):s.texSubImage2D(s.TEXTURE_2D,0,c,u,n,i,s.RGBA,s.UNSIGNED_BYTE,t.data)}this.useMipmap&&this.isSizePowerOfTwo()&&s.generateMipmap(s.TEXTURE_2D)},Js.prototype.bind=function(t,e,r){var n=this.context.gl;n.bindTexture(n.TEXTURE_2D,this.texture),r!==n.LINEAR_MIPMAP_NEAREST||this.isSizePowerOfTwo()||(r=n.LINEAR),t!==this.filter&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,t),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,r||t),this.filter=t),e!==this.wrap&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,e),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,e),this.wrap=e)},Js.prototype.isSizePowerOfTwo=function(){return this.size[0]===this.size[1]&&Math.log(this.size[0])/Math.LN2%1==0},Js.prototype.destroy=function(){this.context.gl.deleteTexture(this.texture),this.texture=null};var Ks=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?i-1:0,f=r?-1:1,p=t[e+h];for(h+=f,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+h],h+=f,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},$s=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,h=u>>1,f=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,i),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g},Qs=tl;function tl(t){this.buf=ArrayBuffer.isView&&ArrayBuffer.isView(t)?t:new Uint8Array(t||0),this.pos=0,this.type=0,this.length=this.buf.length}function el(t){return t.type===tl.Bytes?t.readVarint()+t.pos:t.pos+1}function rl(t,e,r){return r?4294967296*e+(t>>>0):4294967296*(e>>>0)+(t>>>0)}function nl(t,e,r){var n=e<=16383?1:e<=2097151?2:e<=268435455?3:Math.floor(Math.log(e)/(7*Math.LN2));r.realloc(n);for(var i=r.pos-1;i>=t;i--)r.buf[i+n]=r.buf[i]}function il(t,e){for(var r=0;r<t.length;r++)e.writeVarint(t[r])}function al(t,e){for(var r=0;r<t.length;r++)e.writeSVarint(t[r])}function ol(t,e){for(var r=0;r<t.length;r++)e.writeFloat(t[r])}function sl(t,e){for(var r=0;r<t.length;r++)e.writeDouble(t[r])}function ll(t,e){for(var r=0;r<t.length;r++)e.writeBoolean(t[r])}function cl(t,e){for(var r=0;r<t.length;r++)e.writeFixed32(t[r])}function ul(t,e){for(var r=0;r<t.length;r++)e.writeSFixed32(t[r])}function hl(t,e){for(var r=0;r<t.length;r++)e.writeFixed64(t[r])}function fl(t,e){for(var r=0;r<t.length;r++)e.writeSFixed64(t[r])}function pl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+16777216*t[e+3]}function dl(t,e,r){t[r]=e,t[r+1]=e>>>8,t[r+2]=e>>>16,t[r+3]=e>>>24}function gl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+(t[e+3]<<24)}tl.Varint=0,tl.Fixed64=1,tl.Bytes=2,tl.Fixed32=5,tl.prototype={destroy:function(){this.buf=null},readFields:function(t,e,r){for(r=r||this.length;this.pos<r;){var n=this.readVarint(),i=n>>3,a=this.pos;this.type=7&n,t(i,e,this),this.pos===a&&this.skip(n)}return e},readMessage:function(t,e){return this.readFields(t,e,this.readVarint()+this.pos)},readFixed32:function(){var t=pl(this.buf,this.pos);return this.pos+=4,t},readSFixed32:function(){var t=gl(this.buf,this.pos);return this.pos+=4,t},readFixed64:function(){var t=pl(this.buf,this.pos)+4294967296*pl(this.buf,this.pos+4);return this.pos+=8,t},readSFixed64:function(){var t=pl(this.buf,this.pos)+4294967296*gl(this.buf,this.pos+4);return this.pos+=8,t},readFloat:function(){var t=Ks(this.buf,this.pos,!0,23,4);return this.pos+=4,t},readDouble:function(){var t=Ks(this.buf,this.pos,!0,52,8);return this.pos+=8,t},readVarint:function(t){var e,r,n=this.buf;return e=127&(r=n[this.pos++]),r<128?e:(e|=(127&(r=n[this.pos++]))<<7,r<128?e:(e|=(127&(r=n[this.pos++]))<<14,r<128?e:(e|=(127&(r=n[this.pos++]))<<21,r<128?e:function(t,e,r){var n,i,a=r.buf;if(n=(112&(i=a[r.pos++]))>>4,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<3,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<10,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<17,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<24,i<128)return rl(t,n,e);if(n|=(1&(i=a[r.pos++]))<<31,i<128)return rl(t,n,e);throw new Error(\"Expected varint not more than 10 bytes\")}(e|=(15&(r=n[this.pos]))<<28,t,this))))},readVarint64:function(){return this.readVarint(!0)},readSVarint:function(){var t=this.readVarint();return t%2==1?(t+1)/-2:t/2},readBoolean:function(){return Boolean(this.readVarint())},readString:function(){var t=this.readVarint()+this.pos,e=function(t,e,r){for(var n=\"\",i=e;i<r;){var a,o,s,l=t[i],c=null,u=l>239?4:l>223?3:l>191?2:1;if(i+u>r)break;1===u?l<128&&(c=l):2===u?128==(192&(a=t[i+1]))&&(c=(31&l)<<6|63&a)<=127&&(c=null):3===u?(a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&((c=(15&l)<<12|(63&a)<<6|63&o)<=2047||c>=55296&&c<=57343)&&(c=null)):4===u&&(a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&((c=(15&l)<<18|(63&a)<<12|(63&o)<<6|63&s)<=65535||c>=1114112)&&(c=null)),null===c?(c=65533,u=1):c>65535&&(c-=65536,n+=String.fromCharCode(c>>>10&1023|55296),c=56320|1023&c),n+=String.fromCharCode(c),i+=u}return n}(this.buf,this.pos,t);return this.pos=t,e},readBytes:function(){var t=this.readVarint()+this.pos,e=this.buf.subarray(this.pos,t);return this.pos=t,e},readPackedVarint:function(t,e){if(this.type!==tl.Bytes)return t.push(this.readVarint(e));var r=el(this);for(t=t||[];this.pos<r;)t.push(this.readVarint(e));return t},readPackedSVarint:function(t){if(this.type!==tl.Bytes)return t.push(this.readSVarint());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSVarint());return t},readPackedBoolean:function(t){if(this.type!==tl.Bytes)return t.push(this.readBoolean());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readBoolean());return t},readPackedFloat:function(t){if(this.type!==tl.Bytes)return t.push(this.readFloat());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFloat());return t},readPackedDouble:function(t){if(this.type!==tl.Bytes)return t.push(this.readDouble());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readDouble());return t},readPackedFixed32:function(t){if(this.type!==tl.Bytes)return t.push(this.readFixed32());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFixed32());return t},readPackedSFixed32:function(t){if(this.type!==tl.Bytes)return t.push(this.readSFixed32());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed32());return t},readPackedFixed64:function(t){if(this.type!==tl.Bytes)return t.push(this.readFixed64());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFixed64());return t},readPackedSFixed64:function(t){if(this.type!==tl.Bytes)return t.push(this.readSFixed64());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed64());return t},skip:function(t){var e=7&t;if(e===tl.Varint)for(;this.buf[this.pos++]>127;);else if(e===tl.Bytes)this.pos=this.readVarint()+this.pos;else if(e===tl.Fixed32)this.pos+=4;else{if(e!==tl.Fixed64)throw new Error(\"Unimplemented type: \"+e);this.pos+=8}},writeTag:function(t,e){this.writeVarint(t<<3|e)},realloc:function(t){for(var e=this.length||16;e<this.pos+t;)e*=2;if(e!==this.length){var r=new Uint8Array(e);r.set(this.buf),this.buf=r,this.length=e}},finish:function(){return this.length=this.pos,this.pos=0,this.buf.subarray(0,this.length)},writeFixed32:function(t){this.realloc(4),dl(this.buf,t,this.pos),this.pos+=4},writeSFixed32:function(t){this.realloc(4),dl(this.buf,t,this.pos),this.pos+=4},writeFixed64:function(t){this.realloc(8),dl(this.buf,-1&t,this.pos),dl(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeSFixed64:function(t){this.realloc(8),dl(this.buf,-1&t,this.pos),dl(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeVarint:function(t){(t=+t||0)>268435455||t<0?function(t,e){var r,n;if(t>=0?(r=t%4294967296|0,n=t/4294967296|0):(n=~(-t/4294967296),4294967295^(r=~(-t%4294967296))?r=r+1|0:(r=0,n=n+1|0)),t>=0x10000000000000000||t<-0x10000000000000000)throw new Error(\"Given varint doesn't fit into 10 bytes\");e.realloc(10),function(t,e,r){r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos]=127&t}(r,0,e),function(t,e){var r=(7&t)<<4;e.buf[e.pos++]|=r|((t>>>=3)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t)))))}(n,e)}(t,this):(this.realloc(4),this.buf[this.pos++]=127&t|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=t>>>7&127))))},writeSVarint:function(t){this.writeVarint(t<0?2*-t-1:2*t)},writeBoolean:function(t){this.writeVarint(Boolean(t))},writeString:function(t){t=String(t),this.realloc(4*t.length),this.pos++;var e=this.pos;this.pos=function(t,e,r){for(var n,i,a=0;a<e.length;a++){if((n=e.charCodeAt(a))>55295&&n<57344){if(!i){n>56319||a+1===e.length?(t[r++]=239,t[r++]=191,t[r++]=189):i=n;continue}if(n<56320){t[r++]=239,t[r++]=191,t[r++]=189,i=n;continue}n=i-55296<<10|n-56320|65536,i=null}else i&&(t[r++]=239,t[r++]=191,t[r++]=189,i=null);n<128?t[r++]=n:(n<2048?t[r++]=n>>6|192:(n<65536?t[r++]=n>>12|224:(t[r++]=n>>18|240,t[r++]=n>>12&63|128),t[r++]=n>>6&63|128),t[r++]=63&n|128)}return r}(this.buf,t,this.pos);var r=this.pos-e;r>=128&&nl(e,r,this),this.pos=e-1,this.writeVarint(r),this.pos+=r},writeFloat:function(t){this.realloc(4),$s(this.buf,t,this.pos,!0,23,4),this.pos+=4},writeDouble:function(t){this.realloc(8),$s(this.buf,t,this.pos,!0,52,8),this.pos+=8},writeBytes:function(t){var e=t.length;this.writeVarint(e),this.realloc(e);for(var r=0;r<e;r++)this.buf[this.pos++]=t[r]},writeRawMessage:function(t,e){this.pos++;var r=this.pos;t(e,this);var n=this.pos-r;n>=128&&nl(r,n,this),this.pos=r-1,this.writeVarint(n),this.pos+=n},writeMessage:function(t,e,r){this.writeTag(t,tl.Bytes),this.writeRawMessage(e,r)},writePackedVarint:function(t,e){e.length&&this.writeMessage(t,il,e)},writePackedSVarint:function(t,e){e.length&&this.writeMessage(t,al,e)},writePackedBoolean:function(t,e){e.length&&this.writeMessage(t,ll,e)},writePackedFloat:function(t,e){e.length&&this.writeMessage(t,ol,e)},writePackedDouble:function(t,e){e.length&&this.writeMessage(t,sl,e)},writePackedFixed32:function(t,e){e.length&&this.writeMessage(t,cl,e)},writePackedSFixed32:function(t,e){e.length&&this.writeMessage(t,ul,e)},writePackedFixed64:function(t,e){e.length&&this.writeMessage(t,hl,e)},writePackedSFixed64:function(t,e){e.length&&this.writeMessage(t,fl,e)},writeBytesField:function(t,e){this.writeTag(t,tl.Bytes),this.writeBytes(e)},writeFixed32Field:function(t,e){this.writeTag(t,tl.Fixed32),this.writeFixed32(e)},writeSFixed32Field:function(t,e){this.writeTag(t,tl.Fixed32),this.writeSFixed32(e)},writeFixed64Field:function(t,e){this.writeTag(t,tl.Fixed64),this.writeFixed64(e)},writeSFixed64Field:function(t,e){this.writeTag(t,tl.Fixed64),this.writeSFixed64(e)},writeVarintField:function(t,e){this.writeTag(t,tl.Varint),this.writeVarint(e)},writeSVarintField:function(t,e){this.writeTag(t,tl.Varint),this.writeSVarint(e)},writeStringField:function(t,e){this.writeTag(t,tl.Bytes),this.writeString(e)},writeFloatField:function(t,e){this.writeTag(t,tl.Fixed32),this.writeFloat(e)},writeDoubleField:function(t,e){this.writeTag(t,tl.Fixed64),this.writeDouble(e)},writeBooleanField:function(t,e){this.writeVarintField(t,Boolean(e))}};var vl=3;function ml(t,e,r){1===t&&r.readMessage(yl,e)}function yl(t,e,r){if(3===t){var n=r.readMessage(xl,{}),i=n.id,a=n.bitmap,o=n.width,s=n.height,l=n.left,c=n.top,u=n.advance;e.push({id:i,bitmap:new qa({width:o+2*vl,height:s+2*vl},a),metrics:{width:o,height:s,left:l,top:c,advance:u}})}}function xl(t,e,r){1===t?e.id=r.readVarint():2===t?e.bitmap=r.readBytes():3===t?e.width=r.readVarint():4===t?e.height=r.readVarint():5===t?e.left=r.readSVarint():6===t?e.top=r.readSVarint():7===t&&(e.advance=r.readVarint())}var bl=vl,_l=function(t,e,r){this.target=t,this.parent=e,this.mapId=r,this.callbacks={},this.callbackID=0,v([\"receive\"],this),this.target.addEventListener(\"message\",this.receive,!1)};function wl(t,e,r){var n=2*Math.PI*6378137/256/Math.pow(2,r);return[t*n-2*Math.PI*6378137/2,e*n-2*Math.PI*6378137/2]}_l.prototype.send=function(t,e,r,n){var i=this,a=r?this.mapId+\":\"+this.callbackID++:null;r&&(this.callbacks[a]=r);var o=[];if(this.target.postMessage({targetMapId:n,sourceMapId:this.mapId,type:t,id:String(a),data:An(e,o)},o),r)return{cancel:function(){i.callbacks[a]=null,i.target.postMessage({targetMapId:n,sourceMapId:i.mapId,type:\"<cancel>\",id:String(a)})}}},_l.prototype.receive=function(t){var e,r=this,n=t.data,i=n.id;if(!n.targetMapId||this.mapId===n.targetMapId){var a=function(t,e){delete r.callbacks[i];var n=[];r.target.postMessage({sourceMapId:r.mapId,type:\"<response>\",id:String(i),error:t?An(t):null,data:An(e,n)},n)};if(\"<response>\"===n.type||\"<cancel>\"===n.type)e=this.callbacks[n.id],delete this.callbacks[n.id],e&&n.error?e(Mn(n.error)):e&&e(null,Mn(n.data));else if(void 0!==n.id&&this.parent[n.type]){this.callbacks[n.id]=null;var o=this.parent[n.type](n.sourceMapId,Mn(n.data),a);o&&null===this.callbacks[n.id]&&(this.callbacks[n.id]=o.cancel)}else if(void 0!==n.id&&this.parent.getWorkerSource){var s=n.type.split(\".\"),l=Mn(n.data);this.parent.getWorkerSource(n.sourceMapId,s[0],l.source)[s[1]](l,a)}else this.parent[n.type](Mn(n.data))}},_l.prototype.remove=function(){this.target.removeEventListener(\"message\",this.receive,!1)};var kl=function(t,e){t&&(e?this.setSouthWest(t).setNorthEast(e):4===t.length?this.setSouthWest([t[0],t[1]]).setNorthEast([t[2],t[3]]):this.setSouthWest(t[0]).setNorthEast(t[1]))};kl.prototype.setNorthEast=function(t){return this._ne=t instanceof Tl?new Tl(t.lng,t.lat):Tl.convert(t),this},kl.prototype.setSouthWest=function(t){return this._sw=t instanceof Tl?new Tl(t.lng,t.lat):Tl.convert(t),this},kl.prototype.extend=function(t){var e,r,n=this._sw,i=this._ne;if(t instanceof Tl)e=t,r=t;else{if(!(t instanceof kl))return Array.isArray(t)?t.every(Array.isArray)?this.extend(kl.convert(t)):this.extend(Tl.convert(t)):this;if(e=t._sw,r=t._ne,!e||!r)return this}return n||i?(n.lng=Math.min(e.lng,n.lng),n.lat=Math.min(e.lat,n.lat),i.lng=Math.max(r.lng,i.lng),i.lat=Math.max(r.lat,i.lat)):(this._sw=new Tl(e.lng,e.lat),this._ne=new Tl(r.lng,r.lat)),this},kl.prototype.getCenter=function(){return new Tl((this._sw.lng+this._ne.lng)/2,(this._sw.lat+this._ne.lat)/2)},kl.prototype.getSouthWest=function(){return this._sw},kl.prototype.getNorthEast=function(){return this._ne},kl.prototype.getNorthWest=function(){return new Tl(this.getWest(),this.getNorth())},kl.prototype.getSouthEast=function(){return new Tl(this.getEast(),this.getSouth())},kl.prototype.getWest=function(){return this._sw.lng},kl.prototype.getSouth=function(){return this._sw.lat},kl.prototype.getEast=function(){return this._ne.lng},kl.prototype.getNorth=function(){return this._ne.lat},kl.prototype.toArray=function(){return[this._sw.toArray(),this._ne.toArray()]},kl.prototype.toString=function(){return\"LngLatBounds(\"+this._sw.toString()+\", \"+this._ne.toString()+\")\"},kl.prototype.isEmpty=function(){return!(this._sw&&this._ne)},kl.convert=function(t){return!t||t instanceof kl?t:new kl(t)};var Tl=function(t,e){if(isNaN(t)||isNaN(e))throw new Error(\"Invalid LngLat object: (\"+t+\", \"+e+\")\");if(this.lng=+t,this.lat=+e,this.lat>90||this.lat<-90)throw new Error(\"Invalid LngLat latitude value: must be between -90 and 90\")};function Al(t){return 2*Math.PI*6378137*Math.cos(t*Math.PI/180)}function Ml(t){return(180+t)/360}function Sl(t){return(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+t*Math.PI/360)))/360}function El(t,e){return t/Al(e)}function Cl(t){var e=180-360*t;return 360/Math.PI*Math.atan(Math.exp(e*Math.PI/180))-90}Tl.prototype.wrap=function(){return new Tl(u(this.lng,-180,180),this.lat)},Tl.prototype.toArray=function(){return[this.lng,this.lat]},Tl.prototype.toString=function(){return\"LngLat(\"+this.lng+\", \"+this.lat+\")\"},Tl.prototype.toBounds=function(t){void 0===t&&(t=0);var e=360*t/40075017,r=e/Math.cos(Math.PI/180*this.lat);return new kl(new Tl(this.lng-r,this.lat-e),new Tl(this.lng+r,this.lat+e))},Tl.convert=function(t){if(t instanceof Tl)return t;if(Array.isArray(t)&&(2===t.length||3===t.length))return new Tl(Number(t[0]),Number(t[1]));if(!Array.isArray(t)&&\"object\"==typeof t&&null!==t)return new Tl(Number(\"lng\"in t?t.lng:t.lon),Number(t.lat));throw new Error(\"`LngLatLike` argument must be specified as a LngLat instance, an object {lng: <lng>, lat: <lat>}, an object {lon: <lng>, lat: <lat>}, or an array of [<lng>, <lat>]\")};var Ll=function(t,e,r){void 0===r&&(r=0),this.x=+t,this.y=+e,this.z=+r};Ll.fromLngLat=function(t,e){void 0===e&&(e=0);var r=Tl.convert(t);return new Ll(Ml(r.lng),Sl(r.lat),El(e,r.lat))},Ll.prototype.toLngLat=function(){return new Tl(360*this.x-180,Cl(this.y))},Ll.prototype.toAltitude=function(){return this.z*Al(Cl(this.y))};var Pl=function(t,e,r){this.z=t,this.x=e,this.y=r,this.key=Il(0,t,e,r)};Pl.prototype.equals=function(t){return this.z===t.z&&this.x===t.x&&this.y===t.y},Pl.prototype.url=function(t,e){var r,n,i,a,o,s=(r=this.x,n=this.y,i=this.z,a=wl(256*r,256*(n=Math.pow(2,i)-n-1),i),o=wl(256*(r+1),256*(n+1),i),a[0]+\",\"+a[1]+\",\"+o[0]+\",\"+o[1]),l=function(t,e,r){for(var n,i=\"\",a=t;a>0;a--)i+=(e&(n=1<<a-1)?1:0)+(r&n?2:0);return i}(this.z,this.x,this.y);return t[(this.x+this.y)%t.length].replace(\"{prefix}\",(this.x%16).toString(16)+(this.y%16).toString(16)).replace(\"{z}\",String(this.z)).replace(\"{x}\",String(this.x)).replace(\"{y}\",String(\"tms\"===e?Math.pow(2,this.z)-this.y-1:this.y)).replace(\"{quadkey}\",l).replace(\"{bbox-epsg-3857}\",s)},Pl.prototype.getTilePoint=function(t){var e=Math.pow(2,this.z);return new i((t.x*e-this.x)*ha,(t.y*e-this.y)*ha)};var Ol=function(t,e){this.wrap=t,this.canonical=e,this.key=Il(t,e.z,e.x,e.y)},zl=function(t,e,r,n,i){this.overscaledZ=t,this.wrap=e,this.canonical=new Pl(r,+n,+i),this.key=Il(e,t,n,i)};function Il(t,e,r,n){(t*=2)<0&&(t=-1*t-1);var i=1<<e;return 32*(i*i*t+i*n+r)+e}zl.prototype.equals=function(t){return this.overscaledZ===t.overscaledZ&&this.wrap===t.wrap&&this.canonical.equals(t.canonical)},zl.prototype.scaledTo=function(t){var e=this.canonical.z-t;return t>this.canonical.z?new zl(t,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y):new zl(t,this.wrap,t,this.canonical.x>>e,this.canonical.y>>e)},zl.prototype.isChildOf=function(t){if(t.wrap!==this.wrap)return!1;var e=this.canonical.z-t.canonical.z;return 0===t.overscaledZ||t.overscaledZ<this.overscaledZ&&t.canonical.x===this.canonical.x>>e&&t.canonical.y===this.canonical.y>>e},zl.prototype.children=function(t){if(this.overscaledZ>=t)return[new zl(this.overscaledZ+1,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y)];var e=this.canonical.z+1,r=2*this.canonical.x,n=2*this.canonical.y;return[new zl(e,this.wrap,e,r,n),new zl(e,this.wrap,e,r+1,n),new zl(e,this.wrap,e,r,n+1),new zl(e,this.wrap,e,r+1,n+1)]},zl.prototype.isLessThan=function(t){return this.wrap<t.wrap||!(this.wrap>t.wrap)&&(this.overscaledZ<t.overscaledZ||!(this.overscaledZ>t.overscaledZ)&&(this.canonical.x<t.canonical.x||!(this.canonical.x>t.canonical.x)&&this.canonical.y<t.canonical.y))},zl.prototype.wrapped=function(){return new zl(this.overscaledZ,0,this.canonical.z,this.canonical.x,this.canonical.y)},zl.prototype.unwrapTo=function(t){return new zl(this.overscaledZ,t,this.canonical.z,this.canonical.x,this.canonical.y)},zl.prototype.overscaleFactor=function(){return Math.pow(2,this.overscaledZ-this.canonical.z)},zl.prototype.toUnwrapped=function(){return new Ol(this.wrap,this.canonical)},zl.prototype.toString=function(){return this.overscaledZ+\"/\"+this.canonical.x+\"/\"+this.canonical.y},zl.prototype.getTilePoint=function(t){return this.canonical.getTilePoint(new Ll(t.x-this.wrap,t.y))},kn(\"CanonicalTileID\",Pl),kn(\"OverscaledTileID\",zl,{omit:[\"posMatrix\"]});var Dl=function(t,e,r){if(this.uid=t,e.height!==e.width)throw new RangeError(\"DEM tiles must be square\");if(r&&\"mapbox\"!==r&&\"terrarium\"!==r)return w('\"'+r+'\" is not a valid encoding type. Valid types include \"mapbox\" and \"terrarium\".');var n=this.dim=e.height;this.stride=this.dim+2,this.data=new Int32Array(this.stride*this.stride);for(var i=e.data,a=\"terrarium\"===r?this._unpackTerrarium:this._unpackMapbox,o=0;o<n;o++)for(var s=0;s<n;s++){var l=4*(o*n+s);this.set(s,o,a(i[l],i[l+1],i[l+2]))}for(var c=0;c<n;c++)this.set(-1,c,this.get(0,c)),this.set(n,c,this.get(n-1,c)),this.set(c,-1,this.get(c,0)),this.set(c,n,this.get(c,n-1));this.set(-1,-1,this.get(0,0)),this.set(n,-1,this.get(n-1,0)),this.set(-1,n,this.get(0,n-1)),this.set(n,n,this.get(n-1,n-1))};Dl.prototype.set=function(t,e,r){this.data[this._idx(t,e)]=r+65536},Dl.prototype.get=function(t,e){return this.data[this._idx(t,e)]-65536},Dl.prototype._idx=function(t,e){if(t<-1||t>=this.dim+1||e<-1||e>=this.dim+1)throw new RangeError(\"out of range source coordinates for DEM data\");return(e+1)*this.stride+(t+1)},Dl.prototype._unpackMapbox=function(t,e,r){return(256*t*256+256*e+r)/10-1e4},Dl.prototype._unpackTerrarium=function(t,e,r){return 256*t+e+r/256-32768},Dl.prototype.getPixels=function(){return new Ha({width:this.stride,height:this.stride},new Uint8Array(this.data.buffer))},Dl.prototype.backfillBorder=function(t,e,r){if(this.dim!==t.dim)throw new Error(\"dem dimension mismatch\");var n=e*this.dim,i=e*this.dim+this.dim,a=r*this.dim,o=r*this.dim+this.dim;switch(e){case-1:n=i-1;break;case 1:i=n+1}switch(r){case-1:a=o-1;break;case 1:o=a+1}for(var s=-e*this.dim,l=-r*this.dim,c=a;c<o;c++)for(var u=n;u<i;u++)this.set(u,c,t.get(u+s,c+l))},kn(\"DEMData\",Dl);var Rl=oi([{name:\"a_pos\",type:\"Int16\",components:2},{name:\"a_texture_pos\",type:\"Int16\",components:2}]),Fl=function(t){this._stringToNumber={},this._numberToString=[];for(var e=0;e<t.length;e++){var r=t[e];this._stringToNumber[r]=e,this._numberToString[e]=r}};Fl.prototype.encode=function(t){return this._stringToNumber[t]},Fl.prototype.decode=function(t){return this._numberToString[t]};var Bl=function(t,e,r,n){this.type=\"Feature\",this._vectorTileFeature=t,t._z=e,t._x=r,t._y=n,this.properties=t.properties,null!=t.id&&(this.id=t.id)},Nl={geometry:{configurable:!0}};Nl.geometry.get=function(){return void 0===this._geometry&&(this._geometry=this._vectorTileFeature.toGeoJSON(this._vectorTileFeature._x,this._vectorTileFeature._y,this._vectorTileFeature._z).geometry),this._geometry},Nl.geometry.set=function(t){this._geometry=t},Bl.prototype.toJSON=function(){var t={geometry:this.geometry};for(var e in this)\"_geometry\"!==e&&\"_vectorTileFeature\"!==e&&(t[e]=this[e]);return t},Object.defineProperties(Bl.prototype,Nl);var jl=function(){this.state={},this.stateChanges={},this.deletedStates={}};jl.prototype.updateState=function(t,e,r){var n=String(e);if(this.stateChanges[t]=this.stateChanges[t]||{},this.stateChanges[t][n]=this.stateChanges[t][n]||{},h(this.stateChanges[t][n],r),null===this.deletedStates[t])for(var i in this.deletedStates[t]={},this.state[t])i!==n&&(this.deletedStates[t][i]=null);else if(this.deletedStates[t]&&null===this.deletedStates[t][n])for(var a in this.deletedStates[t][n]={},this.state[t][n])r[a]||(this.deletedStates[t][n][a]=null);else for(var o in r)this.deletedStates[t]&&this.deletedStates[t][n]&&null===this.deletedStates[t][n][o]&&delete this.deletedStates[t][n][o]},jl.prototype.removeFeatureState=function(t,e,r){if(null!==this.deletedStates[t]){var n=String(e);if(this.deletedStates[t]=this.deletedStates[t]||{},r&&void 0!==e&&e>=0)null!==this.deletedStates[t][n]&&(this.deletedStates[t][n]=this.deletedStates[t][n]||{},this.deletedStates[t][n][r]=null);else if(void 0!==e&&e>=0)if(this.stateChanges[t]&&this.stateChanges[t][n])for(r in this.deletedStates[t][n]={},this.stateChanges[t][n])this.deletedStates[t][n][r]=null;else this.deletedStates[t][n]=null;else this.deletedStates[t]=null}},jl.prototype.getState=function(t,e){var r=String(e),n=this.state[t]||{},i=this.stateChanges[t]||{},a=h({},n[r],i[r]);if(null===this.deletedStates[t])return{};if(this.deletedStates[t]){var o=this.deletedStates[t][e];if(null===o)return{};for(var s in o)delete a[s]}return a},jl.prototype.initializeTileState=function(t,e){t.setFeatureState(this.state,e)},jl.prototype.coalesceChanges=function(t,e){var r={};for(var n in this.stateChanges){this.state[n]=this.state[n]||{};var i={};for(var a in this.stateChanges[n])this.state[n][a]||(this.state[n][a]={}),h(this.state[n][a],this.stateChanges[n][a]),i[a]=this.state[n][a];r[n]=i}for(var o in this.deletedStates){this.state[o]=this.state[o]||{};var s={};if(null===this.deletedStates[o])for(var l in this.state[o])s[l]={},this.state[o][l]={};else for(var c in this.deletedStates[o]){if(null===this.deletedStates[o][c])this.state[o][c]={};else for(var u=0,f=Object.keys(this.deletedStates[o][c]);u<f.length;u+=1){var p=f[u];delete this.state[o][c][p]}s[c]=this.state[o][c]}r[o]=r[o]||{},h(r[o],s)}if(this.stateChanges={},this.deletedStates={},0!==Object.keys(r).length)for(var d in t)t[d].setFeatureState(r,e)};var Ul=function(t,e,r){this.tileID=t,this.x=t.canonical.x,this.y=t.canonical.y,this.z=t.canonical.z,this.grid=e||new yn(ha,16,0),this.grid3D=new yn(ha,16,0),this.featureIndexArray=r||new ji};function Vl(t){for(var e=1/0,r=1/0,n=-1/0,i=-1/0,a=0,o=t;a<o.length;a+=1){var s=o[a];e=Math.min(e,s.x),r=Math.min(r,s.y),n=Math.max(n,s.x),i=Math.max(i,s.y)}return{minX:e,minY:r,maxX:n,maxY:i}}function ql(t,e){return e-t}Ul.prototype.insert=function(t,e,r,n,i,a){var o=this.featureIndexArray.length;this.featureIndexArray.emplaceBack(r,n,i);for(var s=a?this.grid3D:this.grid,l=0;l<e.length;l++){for(var c=e[l],u=[1/0,1/0,-1/0,-1/0],h=0;h<c.length;h++){var f=c[h];u[0]=Math.min(u[0],f.x),u[1]=Math.min(u[1],f.y),u[2]=Math.max(u[2],f.x),u[3]=Math.max(u[3],f.y)}u[0]<ha&&u[1]<ha&&u[2]>=0&&u[3]>=0&&s.insert(o,u[0],u[1],u[2],u[3])}},Ul.prototype.loadVTLayers=function(){return this.vtLayers||(this.vtLayers=new Vo.VectorTile(new Qs(this.rawTileData)).layers,this.sourceLayerCoder=new Fl(this.vtLayers?Object.keys(this.vtLayers).sort():[\"_geojsonTileLayer\"])),this.vtLayers},Ul.prototype.query=function(t,e,r){var n=this;this.loadVTLayers();for(var a=t.params||{},o=ha/t.tileSize/t.scale,s=Gr(a.filter),l=t.queryGeometry,c=t.queryPadding*o,u=Vl(l),h=this.grid.query(u.minX-c,u.minY-c,u.maxX+c,u.maxY+c),f=Vl(t.cameraQueryGeometry),p=0,d=this.grid3D.query(f.minX-c,f.minY-c,f.maxX+c,f.maxY+c,function(e,r,n,a){return function(t,e,r,n,a){for(var o=0,s=t;o<s.length;o+=1){var l=s[o];if(e<=l.x&&r<=l.y&&n>=l.x&&a>=l.y)return!0}var c=[new i(e,r),new i(e,a),new i(n,a),new i(n,r)];if(t.length>2)for(var u=0,h=c;u<h.length;u+=1)if(Aa(t,h[u]))return!0;for(var f=0;f<t.length-1;f++)if(Ma(t[f],t[f+1],c))return!0;return!1}(t.cameraQueryGeometry,e-c,r-c,n+c,a+c)});p<d.length;p+=1){var g=d[p];h.push(g)}h.sort(ql);for(var v,m={},y=function(i){var c=h[i];if(c!==v){v=c;var u=n.featureIndexArray.get(c),f=null;n.loadMatchingFeature(m,u.bucketIndex,u.sourceLayerIndex,u.featureIndex,s,a.layers,e,function(e,i){f||(f=pa(e));var a={};return e.id&&(a=r.getState(i.sourceLayer||\"_geojsonTileLayer\",e.id)),i.queryIntersectsFeature(l,e,a,f,n.z,t.transform,o,t.pixelPosMatrix)})}},x=0;x<h.length;x++)y(x);return m},Ul.prototype.loadMatchingFeature=function(t,e,r,n,i,a,o,s){var l=this.bucketLayerIDs[e];if(!a||function(t,e){for(var r=0;r<t.length;r++)if(e.indexOf(t[r])>=0)return!0;return!1}(a,l)){var c=this.sourceLayerCoder.decode(r),u=this.vtLayers[c].feature(n);if(i(new Un(this.tileID.overscaledZ),u))for(var h=0;h<l.length;h++){var f=l[h];if(!(a&&a.indexOf(f)<0)){var p=o[f];if(p){var d=!s||s(u,p);if(d){var g=new Bl(u,this.z,this.x,this.y);g.layer=p.serialize();var v=t[f];void 0===v&&(v=t[f]=[]),v.push({featureIndex:n,feature:g,intersectionZ:d})}}}}}},Ul.prototype.lookupSymbolFeatures=function(t,e,r,n,i,a){var o={};this.loadVTLayers();for(var s=Gr(n),l=0,c=t;l<c.length;l+=1){var u=c[l];this.loadMatchingFeature(o,e,r,u,s,i,a)}return o},Ul.prototype.hasLayer=function(t){for(var e=0,r=this.bucketLayerIDs;e<r.length;e+=1)for(var n=0,i=r[e];n<i.length;n+=1)if(t===i[n])return!0;return!1},kn(\"FeatureIndex\",Ul,{omit:[\"rawTileData\",\"sourceLayerCoder\"]});var Hl=function(t,e){this.tileID=t,this.uid=p(),this.uses=0,this.tileSize=e,this.buckets={},this.expirationTime=null,this.queryPadding=0,this.hasSymbolBuckets=!1,this.expiredRequestCount=0,this.state=\"loading\"};Hl.prototype.registerFadeDuration=function(t){var e=t+this.timeAdded;e<z.now()||this.fadeEndTime&&e<this.fadeEndTime||(this.fadeEndTime=e)},Hl.prototype.wasRequested=function(){return\"errored\"===this.state||\"loaded\"===this.state||\"reloading\"===this.state},Hl.prototype.loadVectorData=function(t,e,r){if(this.hasData()&&this.unloadVectorData(),this.state=\"loaded\",t){for(var n in t.featureIndex&&(this.latestFeatureIndex=t.featureIndex,t.rawTileData?(this.latestRawTileData=t.rawTileData,this.latestFeatureIndex.rawTileData=t.rawTileData):this.latestRawTileData&&(this.latestFeatureIndex.rawTileData=this.latestRawTileData)),this.collisionBoxArray=t.collisionBoxArray,this.buckets=function(t,e){var r={};if(!e)return r;for(var n=function(){var t=a[i],n=t.layerIds.map(function(t){return e.getLayer(t)}).filter(Boolean);if(0!==n.length){t.layers=n,t.stateDependentLayerIds&&(t.stateDependentLayers=t.stateDependentLayerIds.map(function(t){return n.filter(function(e){return e.id===t})[0]}));for(var o=0,s=n;o<s.length;o+=1){var l=s[o];r[l.id]=t}}},i=0,a=t;i<a.length;i+=1)n();return r}(t.buckets,e.style),this.hasSymbolBuckets=!1,this.buckets){var i=this.buckets[n];if(i instanceof Os){if(this.hasSymbolBuckets=!0,!r)break;i.justReloaded=!0}}for(var a in this.queryPadding=0,this.buckets){var o=this.buckets[a];this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(a).queryRadius(o))}t.imageAtlas&&(this.imageAtlas=t.imageAtlas),t.glyphAtlasImage&&(this.glyphAtlasImage=t.glyphAtlasImage)}else this.collisionBoxArray=new Li},Hl.prototype.unloadVectorData=function(){for(var t in this.buckets)this.buckets[t].destroy();this.buckets={},this.imageAtlasTexture&&this.imageAtlasTexture.destroy(),this.imageAtlas&&(this.imageAtlas=null),this.glyphAtlasTexture&&this.glyphAtlasTexture.destroy(),this.latestFeatureIndex=null,this.state=\"unloaded\"},Hl.prototype.unloadDEMData=function(){this.dem=null,this.neighboringTiles=null,this.state=\"unloaded\"},Hl.prototype.getBucket=function(t){return this.buckets[t.id]},Hl.prototype.upload=function(t){for(var e in this.buckets){var r=this.buckets[e];r.uploadPending()&&r.upload(t)}var n=t.gl;this.imageAtlas&&!this.imageAtlas.uploaded&&(this.imageAtlasTexture=new Js(t,this.imageAtlas.image,n.RGBA),this.imageAtlas.uploaded=!0),this.glyphAtlasImage&&(this.glyphAtlasTexture=new Js(t,this.glyphAtlasImage,n.ALPHA),this.glyphAtlasImage=null)},Hl.prototype.prepare=function(t){this.imageAtlas&&this.imageAtlas.patchUpdatedImages(t,this.imageAtlasTexture)},Hl.prototype.queryRenderedFeatures=function(t,e,r,n,i,a,o,s,l){return this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData?this.latestFeatureIndex.query({queryGeometry:r,cameraQueryGeometry:n,scale:i,tileSize:this.tileSize,pixelPosMatrix:l,transform:o,params:a,queryPadding:this.queryPadding*s},t,e):{}},Hl.prototype.querySourceFeatures=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData){var r=this.latestFeatureIndex.loadVTLayers(),n=e?e.sourceLayer:\"\",i=r._geojsonTileLayer||r[n];if(i)for(var a=Gr(e&&e.filter),o=this.tileID.canonical,s=o.z,l=o.x,c=o.y,u={z:s,x:l,y:c},h=0;h<i.length;h++){var f=i.feature(h);if(a(new Un(this.tileID.overscaledZ),f)){var p=new Bl(f,s,l,c);p.tile=u,t.push(p)}}}},Hl.prototype.clearMask=function(){this.segments&&(this.segments.destroy(),delete this.segments),this.maskedBoundsBuffer&&(this.maskedBoundsBuffer.destroy(),delete this.maskedBoundsBuffer),this.maskedIndexBuffer&&(this.maskedIndexBuffer.destroy(),delete this.maskedIndexBuffer)},Hl.prototype.setMask=function(t,e){if(!o(this.mask,t)&&(this.mask=t,this.clearMask(),!o(t,{0:!0}))){var r=new ci,n=new Ti;this.segments=new Vi,this.segments.prepareSegment(0,r,n);for(var a=Object.keys(t),s=0;s<a.length;s++){var l=t[+a[s]],c=ha>>l.z,u=new i(l.x*c,l.y*c),h=new i(u.x+c,u.y+c),f=this.segments.prepareSegment(4,r,n);r.emplaceBack(u.x,u.y,u.x,u.y),r.emplaceBack(h.x,u.y,h.x,u.y),r.emplaceBack(u.x,h.y,u.x,h.y),r.emplaceBack(h.x,h.y,h.x,h.y);var p=f.vertexLength;n.emplaceBack(p,p+1,p+2),n.emplaceBack(p+1,p+2,p+3),f.vertexLength+=4,f.primitiveLength+=2}this.maskedBoundsBuffer=e.createVertexBuffer(r,Rl.members),this.maskedIndexBuffer=e.createIndexBuffer(n)}},Hl.prototype.hasData=function(){return\"loaded\"===this.state||\"reloading\"===this.state||\"expired\"===this.state},Hl.prototype.patternsLoaded=function(){return this.imageAtlas&&!!Object.keys(this.imageAtlas.patternPositions).length},Hl.prototype.setExpiryData=function(t){var e=this.expirationTime;if(t.cacheControl){var r=A(t.cacheControl);r[\"max-age\"]&&(this.expirationTime=Date.now()+1e3*r[\"max-age\"])}else t.expires&&(this.expirationTime=new Date(t.expires).getTime());if(this.expirationTime){var n=Date.now(),i=!1;if(this.expirationTime>n)i=!1;else if(e)if(this.expirationTime<e)i=!0;else{var a=this.expirationTime-e;a?this.expirationTime=n+Math.max(a,3e4):i=!0}else i=!0;i?(this.expiredRequestCount++,this.state=\"expired\"):this.expiredRequestCount=0}},Hl.prototype.getExpiryTimeout=function(){if(this.expirationTime)return this.expiredRequestCount?1e3*(1<<Math.min(this.expiredRequestCount-1,31)):Math.min(this.expirationTime-(new Date).getTime(),Math.pow(2,31)-1)},Hl.prototype.setFeatureState=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData&&0!==Object.keys(t).length){var r=this.latestFeatureIndex.loadVTLayers();for(var n in this.buckets){var i=this.buckets[n],a=i.layers[0].sourceLayer||\"_geojsonTileLayer\",o=r[a],s=t[a];o&&s&&0!==Object.keys(s).length&&(i.update(s,o,this.imageAtlas&&this.imageAtlas.patternPositions||{}),e&&e.style&&(this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(n).queryRadius(i))))}}},Hl.prototype.holdingForFade=function(){return void 0!==this.symbolFadeHoldUntil},Hl.prototype.symbolFadeFinished=function(){return!this.symbolFadeHoldUntil||this.symbolFadeHoldUntil<z.now()},Hl.prototype.clearFadeHold=function(){this.symbolFadeHoldUntil=void 0},Hl.prototype.setHoldDuration=function(t){this.symbolFadeHoldUntil=z.now()+t};var Gl=24,Yl={horizontal:1,vertical:2,horizontalOnly:3},Wl=function(){this.text=\"\",this.sectionIndex=[],this.sections=[]};function Xl(t,e,r,n,i,a,o,s,l,c){var u,h=Wl.fromFeature(t,r);c===Yl.vertical&&h.verticalizePunctuation();var f=jn.processBidirectionalText,p=jn.processStyledBidirectionalText;if(f&&1===h.sections.length){u=[];for(var d=0,g=f(h.toString(),tc(h,s,n,e));d<g.length;d+=1){var v=g[d],m=new Wl;m.text=v,m.sections=h.sections;for(var y=0;y<v.length;y++)m.sectionIndex.push(0);u.push(m)}}else if(p){u=[];for(var x=0,b=p(h.text,h.sectionIndex,tc(h,s,n,e));x<b.length;x+=1){var _=b[x],w=new Wl;w.text=_[0],w.sectionIndex=_[1],w.sections=h.sections,u.push(w)}}else u=function(t,e){for(var r=[],n=t.text,i=0,a=0,o=e;a<o.length;a+=1){var s=o[a];r.push(t.substring(i,s)),i=s}return i<n.length&&r.push(t.substring(i,n.length)),r}(h,tc(h,s,n,e));var k=[],T={positionedGlyphs:k,text:h.toString(),top:l[1],bottom:l[1],left:l[0],right:l[0],writingMode:c,lineCount:u.length};return function(t,e,r,n,i,a,o,s){for(var l=0,c=-17,u=0,h=t.positionedGlyphs,f=\"right\"===a?1:\"left\"===a?0:.5,p=0,d=r;p<d.length;p+=1){var g=d[p];g.trim();var v=g.getMaxScale();if(g.length()){for(var m=h.length,y=0;y<g.length();y++){var x=g.getSection(y),b=g.getCharCode(y),_=24*(v-x.scale),w=e[x.fontStack],k=w&&w[b];k&&(On(b)&&o!==Yl.horizontal?(h.push({glyph:b,x:l,y:_,vertical:!0,scale:x.scale,fontStack:x.fontStack}),l+=Gl*x.scale+s):(h.push({glyph:b,x:l,y:c+_,vertical:!1,scale:x.scale,fontStack:x.fontStack}),l+=k.metrics.advance*x.scale+s))}if(h.length!==m){var T=l-s;u=Math.max(T,u),rc(h,e,m,h.length-1,f)}l=0,c+=n*v}else c+=n}var A=ec(i),M=A.horizontalAlign,S=A.verticalAlign;!function(t,e,r,n,i,a,o){for(var s=(e-r)*i,l=(-n*o+.5)*a,c=0;c<t.length;c++)t[c].x+=s,t[c].y+=l}(h,f,M,S,u,n,r.length);var E=c- -17;t.top+=-S*E,t.bottom=t.top+E,t.left+=-M*u,t.right=t.left+u}(T,e,u,i,a,o,c,s),!!k.length&&T}Wl.fromFeature=function(t,e){for(var r=new Wl,n=0;n<t.sections.length;n++){var i=t.sections[n];r.sections.push({scale:i.scale||1,fontStack:i.fontStack||e}),r.text+=i.text;for(var a=0;a<i.text.length;a++)r.sectionIndex.push(n)}return r},Wl.prototype.length=function(){return this.text.length},Wl.prototype.getSection=function(t){return this.sections[this.sectionIndex[t]]},Wl.prototype.getCharCode=function(t){return this.text.charCodeAt(t)},Wl.prototype.verticalizePunctuation=function(){this.text=function(t){for(var e=\"\",r=0;r<t.length;r++){var n=t.charCodeAt(r+1)||null,i=t.charCodeAt(r-1)||null;n&&zn(n)&&!xs[t[r+1]]||i&&zn(i)&&!xs[t[r-1]]||!xs[t[r]]?e+=t[r]:e+=xs[t[r]]}return e}(this.text)},Wl.prototype.trim=function(){for(var t=0,e=0;e<this.text.length&&Zl[this.text.charCodeAt(e)];e++)t++;for(var r=this.text.length,n=this.text.length-1;n>=0&&n>=t&&Zl[this.text.charCodeAt(n)];n--)r--;this.text=this.text.substring(t,r),this.sectionIndex=this.sectionIndex.slice(t,r)},Wl.prototype.substring=function(t,e){var r=new Wl;return r.text=this.text.substring(t,e),r.sectionIndex=this.sectionIndex.slice(t,e),r.sections=this.sections,r},Wl.prototype.toString=function(){return this.text},Wl.prototype.getMaxScale=function(){var t=this;return this.sectionIndex.reduce(function(e,r){return Math.max(e,t.sections[r].scale)},0)};var Zl={9:!0,10:!0,11:!0,12:!0,13:!0,32:!0},Jl={};function Kl(t,e,r,n){var i=Math.pow(t-e,2);return n?t<e?i/2:2*i:i+Math.abs(r)*r}function $l(t,e,r){var n=0;return 10===t&&(n-=1e4),r&&(n+=150),40!==t&&65288!==t||(n+=50),41!==e&&65289!==e||(n+=50),n}function Ql(t,e,r,n,i,a){for(var o=null,s=Kl(e,r,i,a),l=0,c=n;l<c.length;l+=1){var u=c[l],h=Kl(e-u.x,r,i,a)+u.badness;h<=s&&(o=u,s=h)}return{index:t,x:e,priorBreak:o,badness:s}}function tc(t,e,r,n){if(!r)return[];if(!t)return[];for(var i,a=[],o=function(t,e,r,n){for(var i=0,a=0;a<t.length();a++){var o=t.getSection(a),s=n[o.fontStack],l=s&&s[t.getCharCode(a)];l&&(i+=l.metrics.advance*o.scale+e)}return i/Math.max(1,Math.ceil(i/r))}(t,e,r,n),s=t.text.indexOf(\"\\u200b\")>=0,l=0,c=0;c<t.length();c++){var u=t.getSection(c),h=t.getCharCode(c),f=n[u.fontStack],p=f&&f[h];if(p&&!Zl[h]&&(l+=p.metrics.advance*u.scale+e),c<t.length()-1){var d=!((i=h)<11904||!(En[\"Bopomofo Extended\"](i)||En.Bopomofo(i)||En[\"CJK Compatibility Forms\"](i)||En[\"CJK Compatibility Ideographs\"](i)||En[\"CJK Compatibility\"](i)||En[\"CJK Radicals Supplement\"](i)||En[\"CJK Strokes\"](i)||En[\"CJK Symbols and Punctuation\"](i)||En[\"CJK Unified Ideographs Extension A\"](i)||En[\"CJK Unified Ideographs\"](i)||En[\"Enclosed CJK Letters and Months\"](i)||En[\"Halfwidth and Fullwidth Forms\"](i)||En.Hiragana(i)||En[\"Ideographic Description Characters\"](i)||En[\"Kangxi Radicals\"](i)||En[\"Katakana Phonetic Extensions\"](i)||En.Katakana(i)||En[\"Vertical Forms\"](i)||En[\"Yi Radicals\"](i)||En[\"Yi Syllables\"](i)));(Jl[h]||d)&&a.push(Ql(c+1,l,o,a,$l(h,t.getCharCode(c+1),d&&s),!1))}}return function t(e){return e?t(e.priorBreak).concat(e.index):[]}(Ql(t.length(),l,o,a,0,!0))}function ec(t){var e=.5,r=.5;switch(t){case\"right\":case\"top-right\":case\"bottom-right\":e=1;break;case\"left\":case\"top-left\":case\"bottom-left\":e=0}switch(t){case\"bottom\":case\"bottom-right\":case\"bottom-left\":r=1;break;case\"top\":case\"top-right\":case\"top-left\":r=0}return{horizontalAlign:e,verticalAlign:r}}function rc(t,e,r,n,i){if(i){var a=t[n],o=e[a.fontStack],s=o&&o[a.glyph];if(s)for(var l=s.metrics.advance*a.scale,c=(t[n].x+l)*i,u=r;u<=n;u++)t[u].x-=c}}function nc(t,e,r){var n=ec(r),i=n.horizontalAlign,a=n.verticalAlign,o=e[0],s=e[1],l=o-t.displaySize[0]*i,c=l+t.displaySize[0],u=s-t.displaySize[1]*a;return{image:t,top:u,bottom:u+t.displaySize[1],left:l,right:c}}function ic(t,e,r,n,i){if(void 0===e.segment)return!0;for(var a=e,o=e.segment+1,s=0;s>-r/2;){if(--o<0)return!1;s-=t[o].dist(a),a=t[o]}s+=t[o].dist(t[o+1]),o++;for(var l=[],c=0;s<r/2;){var u=t[o-1],h=t[o],f=t[o+1];if(!f)return!1;var p=u.angleTo(h)-h.angleTo(f);for(p=Math.abs((p+3*Math.PI)%(2*Math.PI)-Math.PI),l.push({distance:s,angleDelta:p}),c+=p;s-l[0].distance>n;)c-=l.shift().angleDelta;if(c>i)return!1;o++,s+=h.dist(f)}return!0}function ac(t){for(var e=0,r=0;r<t.length-1;r++)e+=t[r].dist(t[r+1]);return e}function oc(t,e,r){return t?.6*e*r:0}function sc(t,e){return Math.max(t?t.right-t.left:0,e?e.right-e.left:0)}function lc(t,e,r,n,i,a){for(var o=oc(r,i,a),s=sc(r,n)*a,l=0,c=ac(t)/2,u=0;u<t.length-1;u++){var h=t[u],f=t[u+1],p=h.dist(f);if(l+p>c){var d=(c-l)/p,g=Ee(h.x,f.x,d),v=Ee(h.y,f.y,d),m=new bs(g,v,f.angleTo(h),u);return m._round(),!o||ic(t,m,s,o,e)?m:void 0}l+=p}}function cc(t,e,r,n,i,a,o,s,l){var c=oc(n,a,o),u=sc(n,i),h=u*o,f=0===t[0].x||t[0].x===l||0===t[0].y||t[0].y===l;return e-h<e/4&&(e=h+e/4),function t(e,r,n,i,a,o,s,l,c){for(var u=o/2,h=ac(e),f=0,p=r-n,d=[],g=0;g<e.length-1;g++){for(var v=e[g],m=e[g+1],y=v.dist(m),x=m.angleTo(v);p+n<f+y;){var b=((p+=n)-f)/y,_=Ee(v.x,m.x,b),w=Ee(v.y,m.y,b);if(_>=0&&_<c&&w>=0&&w<c&&p-u>=0&&p+u<=h){var k=new bs(_,w,x,g);k._round(),i&&!ic(e,k,o,i,a)||d.push(k)}}f+=y}return l||d.length||s||(d=t(e,f/2,n,i,a,o,s,!0,c)),d}(t,f?e/2*s%e:(u/2+2*a)*o*s%e,e,c,r,h,f,!1,l)}Jl[10]=!0,Jl[32]=!0,Jl[38]=!0,Jl[40]=!0,Jl[41]=!0,Jl[43]=!0,Jl[45]=!0,Jl[47]=!0,Jl[173]=!0,Jl[183]=!0,Jl[8203]=!0,Jl[8208]=!0,Jl[8211]=!0,Jl[8231]=!0;var uc=function(t,e,r,n,a,o,s,l,c,u,h,f){var p=s.top*l-c,d=s.bottom*l+c,g=s.left*l-c,v=s.right*l+c;if(this.boxStartIndex=t.length,u){var m=d-p,y=v-g;m>0&&(m=Math.max(10*l,m),this._addLineCollisionCircles(t,e,r,r.segment,y,m,n,a,o,h))}else{if(f){var x=new i(g,p),b=new i(v,p),_=new i(g,d),w=new i(v,d),k=f*Math.PI/180;x._rotate(k),b._rotate(k),_._rotate(k),w._rotate(k),g=Math.min(x.x,b.x,_.x,w.x),v=Math.max(x.x,b.x,_.x,w.x),p=Math.min(x.y,b.y,_.y,w.y),d=Math.max(x.y,b.y,_.y,w.y)}t.emplaceBack(r.x,r.y,g,p,v,d,n,a,o,0,0)}this.boxEndIndex=t.length};uc.prototype._addLineCollisionCircles=function(t,e,r,n,i,a,o,s,l,c){var u=a/2,h=Math.floor(i/u)||1,f=1+.4*Math.log(c)/Math.LN2,p=Math.floor(h*f/2),d=-a/2,g=r,v=n+1,m=d,y=-i/2,x=y-i/4;do{if(--v<0){if(m>y)return;v=0;break}m-=e[v].dist(g),g=e[v]}while(m>x);for(var b=e[v].dist(e[v+1]),_=-p;_<h+p;_++){var w=_*u,k=y+w;if(w<0&&(k+=w),w>i&&(k+=w-i),!(k<m)){for(;m+b<k;){if(m+=b,++v+1>=e.length)return;b=e[v].dist(e[v+1])}var T=k-m,A=e[v],M=e[v+1].sub(A)._unit()._mult(T)._add(A)._round(),S=Math.abs(k-d)<u?0:.8*(k-d);t.emplaceBack(M.x,M.y,-a/2,-a/2,a/2,a/2,o,s,l,a/2,S)}}};var hc=function(t,e){if(void 0===t&&(t=[]),void 0===e&&(e=fc),this.data=t,this.length=this.data.length,this.compare=e,this.length>0)for(var r=(this.length>>1)-1;r>=0;r--)this._down(r)};function fc(t,e){return t<e?-1:t>e?1:0}function pc(t,e,r){void 0===e&&(e=1),void 0===r&&(r=!1);for(var n=1/0,a=1/0,o=-1/0,s=-1/0,l=t[0],c=0;c<l.length;c++){var u=l[c];(!c||u.x<n)&&(n=u.x),(!c||u.y<a)&&(a=u.y),(!c||u.x>o)&&(o=u.x),(!c||u.y>s)&&(s=u.y)}var h=o-n,f=s-a,p=Math.min(h,f),d=p/2,g=new hc([],dc);if(0===p)return new i(n,a);for(var v=n;v<o;v+=p)for(var m=a;m<s;m+=p)g.push(new gc(v+d,m+d,d,t));for(var y=function(t){for(var e=0,r=0,n=0,i=t[0],a=0,o=i.length,s=o-1;a<o;s=a++){var l=i[a],c=i[s],u=l.x*c.y-c.x*l.y;r+=(l.x+c.x)*u,n+=(l.y+c.y)*u,e+=3*u}return new gc(r/e,n/e,0,t)}(t),x=g.length;g.length;){var b=g.pop();(b.d>y.d||!y.d)&&(y=b,r&&console.log(\"found best %d after %d probes\",Math.round(1e4*b.d)/1e4,x)),b.max-y.d<=e||(d=b.h/2,g.push(new gc(b.p.x-d,b.p.y-d,d,t)),g.push(new gc(b.p.x+d,b.p.y-d,d,t)),g.push(new gc(b.p.x-d,b.p.y+d,d,t)),g.push(new gc(b.p.x+d,b.p.y+d,d,t)),x+=4)}return r&&(console.log(\"num probes: \"+x),console.log(\"best distance: \"+y.d)),y.p}function dc(t,e){return e.max-t.max}function gc(t,e,r,n){this.p=new i(t,e),this.h=r,this.d=function(t,e){for(var r=!1,n=1/0,i=0;i<e.length;i++)for(var a=e[i],o=0,s=a.length,l=s-1;o<s;l=o++){var c=a[o],u=a[l];c.y>t.y!=u.y>t.y&&t.x<(u.x-c.x)*(t.y-c.y)/(u.y-c.y)+c.x&&(r=!r),n=Math.min(n,ka(t,c,u))}return(r?1:-1)*Math.sqrt(n)}(this.p,n),this.max=this.d+this.h*Math.SQRT2}hc.prototype.push=function(t){this.data.push(t),this.length++,this._up(this.length-1)},hc.prototype.pop=function(){if(0!==this.length){var t=this.data[0];return this.length--,this.length>0&&(this.data[0]=this.data[this.length],this._down(0)),this.data.pop(),t}},hc.prototype.peek=function(){return this.data[0]},hc.prototype._up=function(t){for(var e=this.data,r=this.compare,n=e[t];t>0;){var i=t-1>>1,a=e[i];if(r(n,a)>=0)break;e[t]=a,t=i}e[t]=n},hc.prototype._down=function(t){for(var e=this.data,r=this.compare,n=this.length>>1,i=e[t];t<n;){var a=1+(t<<1),o=e[a],s=a+1;if(s<this.length&&r(e[s],o)<0&&(a=s,o=e[s]),r(o,i)>=0)break;e[t]=o,t=a}e[t]=i};var vc=e(function(t){t.exports=function(t,e){var r,n,i,a,o,s,l,c;for(r=3&t.length,n=t.length-r,i=e,o=3432918353,s=461845907,c=0;c<n;)l=255&t.charCodeAt(c)|(255&t.charCodeAt(++c))<<8|(255&t.charCodeAt(++c))<<16|(255&t.charCodeAt(++c))<<24,++c,i=27492+(65535&(a=5*(65535&(i=(i^=l=(65535&(l=(l=(65535&l)*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295)<<13|i>>>19))+((5*(i>>>16)&65535)<<16)&4294967295))+((58964+(a>>>16)&65535)<<16);switch(l=0,r){case 3:l^=(255&t.charCodeAt(c+2))<<16;case 2:l^=(255&t.charCodeAt(c+1))<<8;case 1:i^=l=(65535&(l=(l=(65535&(l^=255&t.charCodeAt(c)))*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295}return i^=t.length,i=2246822507*(65535&(i^=i>>>16))+((2246822507*(i>>>16)&65535)<<16)&4294967295,i=3266489909*(65535&(i^=i>>>13))+((3266489909*(i>>>16)&65535)<<16)&4294967295,(i^=i>>>16)>>>0}}),mc=e(function(t){t.exports=function(t,e){for(var r,n=t.length,i=e^n,a=0;n>=4;)r=1540483477*(65535&(r=255&t.charCodeAt(a)|(255&t.charCodeAt(++a))<<8|(255&t.charCodeAt(++a))<<16|(255&t.charCodeAt(++a))<<24))+((1540483477*(r>>>16)&65535)<<16),i=1540483477*(65535&i)+((1540483477*(i>>>16)&65535)<<16)^(r=1540483477*(65535&(r^=r>>>24))+((1540483477*(r>>>16)&65535)<<16)),n-=4,++a;switch(n){case 3:i^=(255&t.charCodeAt(a+2))<<16;case 2:i^=(255&t.charCodeAt(a+1))<<8;case 1:i=1540483477*(65535&(i^=255&t.charCodeAt(a)))+((1540483477*(i>>>16)&65535)<<16)}return i=1540483477*(65535&(i^=i>>>13))+((1540483477*(i>>>16)&65535)<<16),(i^=i>>>15)>>>0}}),yc=vc,xc=vc,bc=mc;yc.murmur3=xc,yc.murmur2=bc;var _c=7;function wc(t,e){var r=0,n=0,i=e/Math.sqrt(2);switch(t){case\"top-right\":case\"top-left\":n=i-_c;break;case\"bottom-right\":case\"bottom-left\":n=-i+_c;break;case\"bottom\":n=-e+_c;break;case\"top\":n=e-_c}switch(t){case\"top-right\":case\"bottom-right\":r=-i;break;case\"top-left\":case\"bottom-left\":r=i;break;case\"left\":r=e;break;case\"right\":r=-e}return[r,n]}function kc(t){switch(t){case\"right\":case\"top-right\":case\"bottom-right\":return\"right\";case\"left\":case\"top-left\":case\"bottom-left\":return\"left\"}return\"center\"}function Tc(t,e,r,n,a,o,s){var l=o.layoutTextSize.evaluate(e,{}),c=o.layoutIconSize.evaluate(e,{}),u=o.textMaxSize.evaluate(e,{});void 0===u&&(u=l);var h=t.layers[0].layout,f=h.get(\"icon-offset\").evaluate(e,{}),p=Sc(r.horizontal),d=l/24,g=t.tilePixelRatio*d,v=t.tilePixelRatio*u/24,m=t.tilePixelRatio*c,y=t.tilePixelRatio*h.get(\"symbol-spacing\"),x=h.get(\"text-padding\")*t.tilePixelRatio,b=h.get(\"icon-padding\")*t.tilePixelRatio,_=h.get(\"text-max-angle\")/180*Math.PI,k=\"map\"===h.get(\"text-rotation-alignment\")&&\"point\"!==h.get(\"symbol-placement\"),T=\"map\"===h.get(\"icon-rotation-alignment\")&&\"point\"!==h.get(\"symbol-placement\"),A=h.get(\"symbol-placement\"),M=y/2,S=function(l,c){c.x<0||c.x>=ha||c.y<0||c.y>=ha||function(t,e,r,n,a,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_){var k,T,A=t.addToLineVertexArray(e,r),M=0,S=0,E=0,C={},L=yc(\"\"),P=(o.layout.get(\"text-radial-offset\").evaluate(x,{})||0)*Gl;for(var O in n.horizontal){var z=n.horizontal[O];if(!k){L=yc(z.text);var I=o.layout.get(\"text-rotate\").evaluate(x,{});k=new uc(s,r,e,l,c,u,z,h,f,p,t.overscaling,I)}var D=1===z.lineCount;if(S+=Mc(t,e,z,o,p,x,d,A,n.vertical?Yl.horizontal:Yl.horizontalOnly,D?Object.keys(n.horizontal):[O],C,b,_),D)break}n.vertical&&(E+=Mc(t,e,n.vertical,o,p,x,d,A,Yl.vertical,[\"vertical\"],C,b,_));var R=k?k.boxStartIndex:t.collisionBoxArray.length,F=k?k.boxEndIndex:t.collisionBoxArray.length;if(a){var B=function(t,e,r,n,a,o){var s,l,c,u,h=e.image,f=r.layout,p=e.top-1/h.pixelRatio,d=e.left-1/h.pixelRatio,g=e.bottom+1/h.pixelRatio,v=e.right+1/h.pixelRatio;if(\"none\"!==f.get(\"icon-text-fit\")&&a){var m=v-d,y=g-p,x=f.get(\"text-size\").evaluate(o,{})/24,b=a.left*x,_=a.right*x,w=a.top*x,k=_-b,T=a.bottom*x-w,A=f.get(\"icon-text-fit-padding\")[0],M=f.get(\"icon-text-fit-padding\")[1],S=f.get(\"icon-text-fit-padding\")[2],E=f.get(\"icon-text-fit-padding\")[3],C=\"width\"===f.get(\"icon-text-fit\")?.5*(T-y):0,L=\"height\"===f.get(\"icon-text-fit\")?.5*(k-m):0,P=\"width\"===f.get(\"icon-text-fit\")||\"both\"===f.get(\"icon-text-fit\")?k:m,O=\"height\"===f.get(\"icon-text-fit\")||\"both\"===f.get(\"icon-text-fit\")?T:y;s=new i(b+L-E,w+C-A),l=new i(b+L+M+P,w+C-A),c=new i(b+L+M+P,w+C+S+O),u=new i(b+L-E,w+C+S+O)}else s=new i(d,p),l=new i(v,p),c=new i(v,g),u=new i(d,g);var z=r.layout.get(\"icon-rotate\").evaluate(o,{})*Math.PI/180;if(z){var I=Math.sin(z),D=Math.cos(z),R=[D,-I,I,D];s._matMult(R),l._matMult(R),u._matMult(R),c._matMult(R)}return[{tl:s,tr:l,bl:u,br:c,tex:h.paddedRect,writingMode:void 0,glyphOffset:[0,0]}]}(0,a,o,0,Sc(n.horizontal),x),N=o.layout.get(\"icon-rotate\").evaluate(x,{});T=new uc(s,r,e,l,c,u,a,g,v,!1,t.overscaling,N),M=4*B.length;var j=t.iconSizeData,U=null;\"source\"===j.kind?(U=[_s*o.layout.get(\"icon-size\").evaluate(x,{})])[0]>Ac&&w(t.layerIds[0]+': Value for \"icon-size\" is >= 256. Reduce your \"icon-size\".'):\"composite\"===j.kind&&((U=[_s*_.compositeIconSizes[0].evaluate(x,{}),_s*_.compositeIconSizes[1].evaluate(x,{})])[0]>Ac||U[1]>Ac)&&w(t.layerIds[0]+': Value for \"icon-size\" is >= 256. Reduce your \"icon-size\".'),t.addSymbols(t.icon,B,U,y,m,x,!1,e,A.lineStartIndex,A.lineLength)}var V=T?T.boxStartIndex:t.collisionBoxArray.length,q=T?T.boxEndIndex:t.collisionBoxArray.length;t.glyphOffsetArray.length>=Os.MAX_GLYPHS&&w(\"Too many glyphs being rendered in a tile. See https://github.com/mapbox/mapbox-gl-js/issues/2907\"),t.symbolInstances.emplaceBack(e.x,e.y,C.right>=0?C.right:-1,C.center>=0?C.center:-1,C.left>=0?C.left:-1,C.vertical||-1,L,R,F,V,q,l,S,E,M,0,h,P)}(t,c,l,r,n,t.layers[0],t.collisionBoxArray,e.index,e.sourceLayerIndex,t.index,g,x,k,s,m,b,T,f,e,a,o)};if(\"line\"===A)for(var E=0,C=function(t,e,r,n,a){for(var o=[],s=0;s<t.length;s++)for(var l=t[s],c=void 0,u=0;u<l.length-1;u++){var h=l[u],f=l[u+1];h.x<0&&f.x<0||(h.x<0?h=new i(0,h.y+(f.y-h.y)*((0-h.x)/(f.x-h.x)))._round():f.x<0&&(f=new i(0,h.y+(f.y-h.y)*((0-h.x)/(f.x-h.x)))._round()),h.y<0&&f.y<0||(h.y<0?h=new i(h.x+(f.x-h.x)*((0-h.y)/(f.y-h.y)),0)._round():f.y<0&&(f=new i(h.x+(f.x-h.x)*((0-h.y)/(f.y-h.y)),0)._round()),h.x>=n&&f.x>=n||(h.x>=n?h=new i(n,h.y+(f.y-h.y)*((n-h.x)/(f.x-h.x)))._round():f.x>=n&&(f=new i(n,h.y+(f.y-h.y)*((n-h.x)/(f.x-h.x)))._round()),h.y>=a&&f.y>=a||(h.y>=a?h=new i(h.x+(f.x-h.x)*((a-h.y)/(f.y-h.y)),a)._round():f.y>=a&&(f=new i(h.x+(f.x-h.x)*((a-h.y)/(f.y-h.y)),a)._round()),c&&h.equals(c[c.length-1])||(c=[h],o.push(c)),c.push(f)))))}return o}(e.geometry,0,0,ha,ha);E<C.length;E+=1)for(var L=C[E],P=0,O=cc(L,y,_,r.vertical||p,n,24,v,t.overscaling,ha);P<O.length;P+=1){var z=O[P];p&&Ec(t,p.text,M,z)||S(L,z)}else if(\"line-center\"===A)for(var I=0,D=e.geometry;I<D.length;I+=1){var R=D[I];if(R.length>1){var F=lc(R,_,r.vertical||p,n,24,v);F&&S(R,F)}}else if(\"Polygon\"===e.type)for(var B=0,N=Mo(e.geometry,0);B<N.length;B+=1){var j=N[B],U=pc(j,16);S(j[0],new bs(U.x,U.y,0))}else if(\"LineString\"===e.type)for(var V=0,q=e.geometry;V<q.length;V+=1){var H=q[V];S(H,new bs(H[0].x,H[0].y,0))}else if(\"Point\"===e.type)for(var G=0,Y=e.geometry;G<Y.length;G+=1)for(var W=0,X=Y[G];W<X.length;W+=1){var Z=X[W];S([Z],new bs(Z.x,Z.y,0))}}var Ac=65535;function Mc(t,e,r,n,a,o,s,l,c,u,h,f,p){var d=function(t,e,r,n,a,o,s){for(var l=n.layout.get(\"text-rotate\").evaluate(o,{})*Math.PI/180,c=e.positionedGlyphs,u=[],h=0;h<c.length;h++){var f=c[h],p=s[f.fontStack],d=p&&p[f.glyph];if(d){var g=d.rect;if(g){var v=bl+1,m=d.metrics.advance*f.scale/2,y=a?[f.x+m,f.y]:[0,0],x=a?[0,0]:[f.x+m+r[0],f.y+r[1]],b=(d.metrics.left-v)*f.scale-m+x[0],_=(-d.metrics.top-v)*f.scale+x[1],w=b+g.w*f.scale,k=_+g.h*f.scale,T=new i(b,_),A=new i(w,_),M=new i(b,k),S=new i(w,k);if(a&&f.vertical){var E=new i(-m,m),C=-Math.PI/2,L=new i(5,0);T._rotateAround(C,E)._add(L),A._rotateAround(C,E)._add(L),M._rotateAround(C,E)._add(L),S._rotateAround(C,E)._add(L)}if(l){var P=Math.sin(l),O=Math.cos(l),z=[O,-P,P,O];T._matMult(z),A._matMult(z),M._matMult(z),S._matMult(z)}u.push({tl:T,tr:A,bl:M,br:S,tex:g,writingMode:e.writingMode,glyphOffset:y})}}}return u}(0,r,s,n,a,o,f),g=t.textSizeData,v=null;\"source\"===g.kind?(v=[_s*n.layout.get(\"text-size\").evaluate(o,{})])[0]>Ac&&w(t.layerIds[0]+': Value for \"text-size\" is >= 256. Reduce your \"text-size\".'):\"composite\"===g.kind&&((v=[_s*p.compositeTextSizes[0].evaluate(o,{}),_s*p.compositeTextSizes[1].evaluate(o,{})])[0]>Ac||v[1]>Ac)&&w(t.layerIds[0]+': Value for \"text-size\" is >= 256. Reduce your \"text-size\".'),t.addSymbols(t.text,d,v,s,a,o,c,e,l.lineStartIndex,l.lineLength);for(var m=0,y=u;m<y.length;m+=1)h[y[m]]=t.text.placedSymbolArray.length-1;return 4*d.length}function Sc(t){for(var e in t)return t[e];return null}function Ec(t,e,r,n){var i=t.compareText;if(e in i){for(var a=i[e],o=a.length-1;o>=0;o--)if(n.dist(a[o])<r)return!0}else i[e]=[];return i[e].push(n),!1}t.Actor=_l,t.AlphaImage=qa,t.CanonicalTileID=Pl,t.CollisionBoxArray=Li,t.Color=ne,t.DEMData=Dl,t.DataConstantProperty=Jn,t.DictionaryCoder=Fl,t.EXTENT=ha,t.ErrorEvent=Ot,t.EvaluationParameters=Un,t.Event=Pt,t.Evented=zt,t.FeatureIndex=Ul,t.FillBucket=Lo,t.FillExtrusionBucket=Yo,t.ImageAtlas=Gs,t.ImagePosition=qs,t.LineBucket=os,t.LngLat=Tl,t.LngLatBounds=kl,t.MercatorCoordinate=Ll,t.ONE_EM=Gl,t.OverscaledTileID=zl,t.Point=i,t.Point$1=i,t.ProgramConfiguration=sa,t.Properties=ei,t.Protobuf=Qs,t.RGBAImage=Ha,t.RequestManager=j,t.ResourceType=yt,t.SegmentVector=Vi,t.SourceFeatureState=jl,t.StructArrayLayout1ui2=Mi,t.StructArrayLayout2i4=li,t.StructArrayLayout2ui4=Ai,t.StructArrayLayout3ui6=Ti,t.StructArrayLayout4i8=ci,t.SymbolBucket=Os,t.Texture=Js,t.Tile=Hl,t.Transitionable=Hn,t.Uniform1f=Xi,t.Uniform1i=Wi,t.Uniform2f=Zi,t.Uniform3f=Ji,t.Uniform4f=Ki,t.UniformColor=$i,t.UniformMatrix4f=ta,t.UnwrappedTileID=Ol,t.ValidationError=Dt,t.WritingMode=Yl,t.ZoomHistory=Sn,t.addDynamicAttributes=Cs,t.asyncAll=function(t,e,r){if(!t.length)return r(null,[]);var n=t.length,i=new Array(t.length),a=null;t.forEach(function(t,o){e(t,function(t,e){t&&(a=t),i[o]=e,0==--n&&r(a,i)})})},t.bezier=s,t.bindAll=v,t.browser=z,t.cacheEntryPossiblyAdded=function(t){++mt>dt&&(t.send(\"enforceCacheSizeLimit\",pt),mt=0)},t.clamp=c,t.clearTileCache=function(t){var e=self.caches.delete(ft);t&&e.catch(t).then(function(){return t()})},t.clone=function(t){var e=new Pa(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e},t.clone$1=b,t.config=I,t.create=function(){var t=new Pa(16);return Pa!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=0,t[12]=0,t[13]=0,t[14]=0),t[0]=1,t[5]=1,t[10]=1,t[15]=1,t},t.create$1=Oa,t.create$2=function(){var t=new Pa(4);return Pa!=Float32Array&&(t[1]=0,t[2]=0),t[0]=1,t[3]=1,t},t.createCommonjsModule=e,t.createExpression=Or,t.createLayout=oi,t.createStyleLayer=function(t){return\"custom\"===t.type?new js(t):new Us[t.type](t)},t.deepEqual=o,t.ease=l,t.emitValidationErrors=mn,t.endsWith=m,t.enforceCacheSizeLimit=function(t){self.caches&&self.caches.open(ft).then(function(e){e.keys().then(function(r){for(var n=0;n<r.length-t;n++)e.delete(r[n])})})},t.evaluateRadialOffset=wc,t.evaluateSizeForFeature=ks,t.evaluateSizeForZoom=Ts,t.evented=Nn,t.extend=h,t.featureFilter=Gr,t.filterObject=x,t.fromRotation=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=r,t[2]=0,t[3]=-r,t[4]=n,t[5]=0,t[6]=0,t[7]=0,t[8]=1,t},t.getAnchorAlignment=ec,t.getAnchorJustification=kc,t.getArrayBuffer=Mt,t.getImage=Et,t.getJSON=function(t,e){return At(h(t,{type:\"json\"}),e)},t.getReferrer=_t,t.getVideo=function(t,e){var r,n,i=self.document.createElement(\"video\");i.muted=!0,i.onloadstart=function(){e(null,i)};for(var a=0;a<t.length;a++){var o=self.document.createElement(\"source\");r=t[a],n=void 0,(n=self.document.createElement(\"a\")).href=r,(n.protocol!==self.document.location.protocol||n.host!==self.document.location.host)&&(i.crossOrigin=\"Anonymous\"),o.src=t[a],i.appendChild(o)}return{cancel:function(){}}},t.identity=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t},t.invert=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],g=e[13],v=e[14],m=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,k=i*c-a*l,T=u*g-h*d,A=u*v-f*d,M=u*m-p*d,S=h*v-f*g,E=h*m-p*g,C=f*m-p*v,L=y*C-x*E+b*S+_*M-w*A+k*T;return L?(L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(i*E-n*C-a*S)*L,t[2]=(g*k-v*w+m*_)*L,t[3]=(f*w-h*k-p*_)*L,t[4]=(l*M-o*C-c*A)*L,t[5]=(r*C-i*M+a*A)*L,t[6]=(v*b-d*k-m*x)*L,t[7]=(u*k-f*b+p*x)*L,t[8]=(o*E-s*M+c*T)*L,t[9]=(n*M-r*E-a*T)*L,t[10]=(d*w-g*b+m*y)*L,t[11]=(h*b-u*w-p*y)*L,t[12]=(s*A-o*S-l*T)*L,t[13]=(r*S-n*A+i*T)*L,t[14]=(g*x-d*_-v*y)*L,t[15]=(u*_-h*x+f*y)*L,t):null},t.isChar=En,t.isMapboxURL=q,t.keysDifference=function(t,e){var r=[];for(var n in t)n in e||r.push(n);return r},t.makeRequest=At,t.mapObject=y,t.mercatorXfromLng=Ml,t.mercatorYfromLat=Sl,t.mercatorZfromAltitude=El,t.multiply=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],g=e[12],v=e[13],m=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*h+w*g,t[1]=x*i+b*l+_*f+w*v,t[2]=x*a+b*c+_*p+w*m,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*h+w*g,t[5]=x*i+b*l+_*f+w*v,t[6]=x*a+b*c+_*p+w*m,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*h+w*g,t[9]=x*i+b*l+_*f+w*v,t[10]=x*a+b*c+_*p+w*m,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*h+w*g,t[13]=x*i+b*l+_*f+w*v,t[14]=x*a+b*c+_*p+w*m,t[15]=x*o+b*u+_*d+w*y,t},t.mvt=Vo,t.number=Ee,t.ortho=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t},t.parseGlyphPBF=function(t){return new Qs(t).readFields(ml,[])},t.pbf=Qs,t.performSymbolLayout=function(t,e,r,n,i,a){t.createArrays();var o=512*t.overscaling;t.tilePixelRatio=ha/o,t.compareText={},t.iconsNeedLinear=!1;var s=t.layers[0].layout,l=t.layers[0]._unevaluatedLayout._values,c={};if(\"composite\"===t.textSizeData.kind){var u=t.textSizeData,h=u.minZoom,f=u.maxZoom;c.compositeTextSizes=[l[\"text-size\"].possiblyEvaluate(new Un(h)),l[\"text-size\"].possiblyEvaluate(new Un(f))]}if(\"composite\"===t.iconSizeData.kind){var p=t.iconSizeData,d=p.minZoom,g=p.maxZoom;c.compositeIconSizes=[l[\"icon-size\"].possiblyEvaluate(new Un(d)),l[\"icon-size\"].possiblyEvaluate(new Un(g))]}c.layoutTextSize=l[\"text-size\"].possiblyEvaluate(new Un(t.zoom+1)),c.layoutIconSize=l[\"icon-size\"].possiblyEvaluate(new Un(t.zoom+1)),c.textMaxSize=l[\"text-size\"].possiblyEvaluate(new Un(18));for(var v=s.get(\"text-line-height\")*Gl,m=\"map\"===s.get(\"text-rotation-alignment\")&&\"point\"!==s.get(\"symbol-placement\"),y=s.get(\"text-keep-upright\"),x=0,b=t.features;x<b.length;x+=1){var _=b[x],k=s.get(\"text-font\").evaluate(_,{}).join(\",\"),T=r,A={horizontal:{},vertical:void 0},M=_.text,S=[0,0];if(M){var E=M.toString(),C=s.get(\"text-letter-spacing\").evaluate(_,{})*Gl,L=Ln(E)?C:0,P=s.get(\"text-anchor\").evaluate(_,{}),O=s.get(\"text-variable-anchor\"),z=s.get(\"text-radial-offset\").evaluate(_,{});O||(S=z?wc(P,z*Gl):s.get(\"text-offset\").evaluate(_,{}).map(function(t){return t*Gl}));var I=m?\"center\":s.get(\"text-justify\").evaluate(_,{}),D=\"point\"===s.get(\"symbol-placement\")?s.get(\"text-max-width\").evaluate(_,{})*Gl:0;if(!m&&O)for(var R=\"auto\"===I?O.map(function(t){return kc(t)}):[I],F=!1,B=0;B<R.length;B++){var N=R[B];if(!A.horizontal[N])if(F)A.horizontal[N]=A.horizontal[0];else{var j=Xl(M,e,k,D,v,\"center\",N,L,S,Yl.horizontal);j&&(A.horizontal[N]=j,F=1===j.lineCount)}}else{\"auto\"===I&&(I=kc(P));var U=Xl(M,e,k,D,v,P,I,L,S,Yl.horizontal);U&&(A.horizontal[I]=U),Cn(E)&&m&&y&&(A.vertical=Xl(M,e,k,D,v,P,I,L,S,Yl.vertical))}}var V=void 0;if(_.icon){var q=n[_.icon];q&&(V=nc(i[_.icon],s.get(\"icon-offset\").evaluate(_,{}),s.get(\"icon-anchor\").evaluate(_,{})),void 0===t.sdfIcons?t.sdfIcons=q.sdf:t.sdfIcons!==q.sdf&&w(\"Style sheet warning: Cannot mix SDF and non-SDF icons in one buffer\"),q.pixelRatio!==t.pixelRatio?t.iconsNeedLinear=!0:0!==s.get(\"icon-rotate\").constantOr(1)&&(t.iconsNeedLinear=!0))}(Object.keys(A.horizontal).length||V)&&Tc(t,_,A,V,T,c,S)}a&&t.generateCollisionDebugBuffers()},t.perspective=function(t,e,r,n,i){var a,o=1/Math.tan(e/2);return t[0]=o/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=o,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=-1,t[12]=0,t[13]=0,t[15]=0,null!=i&&i!==1/0?(a=1/(n-i),t[10]=(i+n)*a,t[14]=2*i*n*a):(t[10]=-1,t[14]=-2*n),t},t.pick=function(t,e){for(var r={},n=0;n<e.length;n++){var i=e[n];i in t&&(r[i]=t[i])}return r},t.plugin=jn,t.polygonIntersectsPolygon=va,t.postMapLoadEvent=ht,t.postTurnstileEvent=ct,t.potpack=Vs,t.rasterBoundsAttributes=Rl,t.refProperties=[\"type\",\"source\",\"source-layer\",\"minzoom\",\"maxzoom\",\"filter\",\"layout\"],t.register=kn,t.registerForPluginAvailability=function(t){return Fn?t({pluginURL:Fn,completionCallback:Dn}):Nn.once(\"pluginAvailable\",t),t},t.rotate=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=Math.sin(r),l=Math.cos(r);return t[0]=n*l+a*s,t[1]=i*l+o*s,t[2]=n*-s+a*l,t[3]=i*-s+o*l,t},t.rotateX=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];return e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+h*n,t[7]=l*i+f*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=h*i-s*n,t[11]=f*i-l*n,t},t.rotateZ=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];return e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+h*n,t[3]=l*i+f*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=h*i-s*n,t[7]=f*i-l*n,t},t.scale=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t},t.setCacheLimits=function(t,e){pt=t,dt=e},t.setRTLTextPlugin=function(t,e){if(Rn)throw new Error(\"setRTLTextPlugin cannot be called multiple times.\");Rn=!0,Fn=z.resolveURL(t),Dn=function(t){t?(Rn=!1,Fn=null,e&&e(t)):Bn=!0},Nn.fire(new Pt(\"pluginAvailable\",{pluginURL:Fn,completionCallback:Dn}))},t.sphericalToCartesian=function(t){var e=t[0],r=t[1],n=t[2];return r+=90,r*=Math.PI/180,n*=Math.PI/180,{x:e*Math.cos(r)*Math.sin(n),y:e*Math.sin(r)*Math.sin(n),z:e*Math.cos(n)}},t.styleSpec=It,t.symbolSize=As,t.transformMat3=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t},t.transformMat4=Da,t.translate=function(t,e,r){var n,i,a,o,s,l,c,u,h,f,p,d,g=r[0],v=r[1],m=r[2];return e===t?(t[12]=e[0]*g+e[4]*v+e[8]*m+e[12],t[13]=e[1]*g+e[5]*v+e[9]*m+e[13],t[14]=e[2]*g+e[6]*v+e[10]*m+e[14],t[15]=e[3]*g+e[7]*v+e[11]*m+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*g+s*v+h*m+e[12],t[13]=i*g+l*v+f*m+e[13],t[14]=a*g+c*v+p*m+e[14],t[15]=o*g+u*v+d*m+e[15]),t},t.uniqueId=p,t.validateCustomStyleLayer=function(t){var e=[],r=t.id;return void 0===r&&e.push({message:\"layers.\"+r+': missing required property \"id\"'}),void 0===t.render&&e.push({message:\"layers.\"+r+': missing required method \"render\"'}),t.renderingMode&&\"2d\"!==t.renderingMode&&\"3d\"!==t.renderingMode&&e.push({message:\"layers.\"+r+': property \"renderingMode\" must be either \"2d\" or \"3d\"'}),e},t.validateLight=dn,t.validateStyle=pn,t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.vectorTile=Vo,t.version=\"1.1.1\",t.warnOnce=w,t.webpSupported=D,t.window=self,t.wrap=u}),n(0,function(t){function e(t){var r=typeof t;if(\"number\"===r||\"boolean\"===r||\"string\"===r||null==t)return JSON.stringify(t);if(Array.isArray(t)){for(var n=\"[\",i=0,a=t;i<a.length;i+=1)n+=e(a[i])+\",\";return n+\"]\"}for(var o=Object.keys(t).sort(),s=\"{\",l=0;l<o.length;l++)s+=JSON.stringify(o[l])+\":\"+e(t[o[l]])+\",\";return s+\"}\"}function r(r){for(var n=\"\",i=0,a=t.refProperties;i<a.length;i+=1)n+=\"/\"+e(r[a[i]]);return n}var n=function(t){this.keyCache={},t&&this.replace(t)};n.prototype.replace=function(t){this._layerConfigs={},this._layers={},this.update(t,[])},n.prototype.update=function(e,n){for(var i=this,a=0,o=e;a<o.length;a+=1){var s=o[a];this._layerConfigs[s.id]=s;var l=this._layers[s.id]=t.createStyleLayer(s);l._featureFilter=t.featureFilter(l.filter),this.keyCache[s.id]&&delete this.keyCache[s.id]}for(var c=0,u=n;c<u.length;c+=1){var h=u[c];delete this.keyCache[h],delete this._layerConfigs[h],delete this._layers[h]}this.familiesBySource={};for(var f=0,p=function(t,e){for(var n={},i=0;i<t.length;i++){var a=e&&e[t[i].id]||r(t[i]);e&&(e[t[i].id]=a);var o=n[a];o||(o=n[a]=[]),o.push(t[i])}var s=[];for(var l in n)s.push(n[l]);return s}(t.values(this._layerConfigs),this.keyCache);f<p.length;f+=1){var d=p[f].map(function(t){return i._layers[t.id]}),g=d[0];if(\"none\"!==g.visibility){var v=g.source||\"\",m=this.familiesBySource[v];m||(m=this.familiesBySource[v]={});var y=g.sourceLayer||\"_geojsonTileLayer\",x=m[y];x||(x=m[y]=[]),x.push(d)}}};var i=function(e){var r={},n=[];for(var i in e){var a=e[i],o=r[i]={};for(var s in a){var l=a[+s];if(l&&0!==l.bitmap.width&&0!==l.bitmap.height){var c={x:0,y:0,w:l.bitmap.width+2,h:l.bitmap.height+2};n.push(c),o[s]={rect:c,metrics:l.metrics}}}}var u=t.potpack(n),h=u.w,f=u.h,p=new t.AlphaImage({width:h||1,height:f||1});for(var d in e){var g=e[d];for(var v in g){var m=g[+v];if(m&&0!==m.bitmap.width&&0!==m.bitmap.height){var y=r[d][v].rect;t.AlphaImage.copy(m.bitmap,p,{x:0,y:0},{x:y.x+1,y:y.y+1},m.bitmap)}}}this.image=p,this.positions=r};t.register(\"GlyphAtlas\",i);var a=function(e){this.tileID=new t.OverscaledTileID(e.tileID.overscaledZ,e.tileID.wrap,e.tileID.canonical.z,e.tileID.canonical.x,e.tileID.canonical.y),this.uid=e.uid,this.zoom=e.zoom,this.pixelRatio=e.pixelRatio,this.tileSize=e.tileSize,this.source=e.source,this.overscaling=this.tileID.overscaleFactor(),this.showCollisionBoxes=e.showCollisionBoxes,this.collectResourceTiming=!!e.collectResourceTiming,this.returnDependencies=!!e.returnDependencies};function o(e,r){for(var n=new t.EvaluationParameters(r),i=0,a=e;i<a.length;i+=1)a[i].recalculate(n)}a.prototype.parse=function(e,r,n,a){var s=this;this.status=\"parsing\",this.data=e,this.collisionBoxArray=new t.CollisionBoxArray;var l=new t.DictionaryCoder(Object.keys(e.layers).sort()),c=new t.FeatureIndex(this.tileID);c.bucketLayerIDs=[];var u,h,f,p,d={},g={featureIndex:c,iconDependencies:{},patternDependencies:{},glyphDependencies:{}},v=r.familiesBySource[this.source];for(var m in v){var y=e.layers[m];if(y){1===y.version&&t.warnOnce('Vector tile source \"'+this.source+'\" layer \"'+m+'\" does not use vector tile spec v2 and therefore may have some rendering errors.');for(var x=l.encode(m),b=[],_=0;_<y.length;_++){var w=y.feature(_);b.push({feature:w,index:_,sourceLayerIndex:x})}for(var k=0,T=v[m];k<T.length;k+=1){var A=T[k],M=A[0];M.minzoom&&this.zoom<Math.floor(M.minzoom)||M.maxzoom&&this.zoom>=M.maxzoom||\"none\"!==M.visibility&&(o(A,this.zoom),(d[M.id]=M.createBucket({index:c.bucketLayerIDs.length,layers:A,zoom:this.zoom,pixelRatio:this.pixelRatio,overscaling:this.overscaling,collisionBoxArray:this.collisionBoxArray,sourceLayerIndex:x,sourceID:this.source})).populate(b,g),c.bucketLayerIDs.push(A.map(function(t){return t.id})))}}}var S=t.mapObject(g.glyphDependencies,function(t){return Object.keys(t).map(Number)});Object.keys(S).length?n.send(\"getGlyphs\",{uid:this.uid,stacks:S},function(t,e){u||(u=t,h=e,L.call(s))}):h={};var E=Object.keys(g.iconDependencies);E.length?n.send(\"getImages\",{icons:E},function(t,e){u||(u=t,f=e,L.call(s))}):f={};var C=Object.keys(g.patternDependencies);function L(){if(u)return a(u);if(h&&f&&p){var e=new i(h),r=new t.ImageAtlas(f,p);for(var n in d){var s=d[n];s instanceof t.SymbolBucket?(o(s.layers,this.zoom),t.performSymbolLayout(s,h,e.positions,f,r.iconPositions,this.showCollisionBoxes)):s.hasPattern&&(s instanceof t.LineBucket||s instanceof t.FillBucket||s instanceof t.FillExtrusionBucket)&&(o(s.layers,this.zoom),s.addFeatures(g,r.patternPositions))}this.status=\"done\",a(null,{buckets:t.values(d).filter(function(t){return!t.isEmpty()}),featureIndex:c,collisionBoxArray:this.collisionBoxArray,glyphAtlasImage:e.image,imageAtlas:r,glyphMap:this.returnDependencies?h:null,iconMap:this.returnDependencies?f:null,glyphPositions:this.returnDependencies?e.positions:null})}}C.length?n.send(\"getImages\",{icons:C},function(t,e){u||(u=t,p=e,L.call(s))}):p={},L.call(this)};var s=\"undefined\"!=typeof performance,l={getEntriesByName:function(t){return!!(s&&performance&&performance.getEntriesByName)&&performance.getEntriesByName(t)},mark:function(t){return!!(s&&performance&&performance.mark)&&performance.mark(t)},measure:function(t,e,r){return!!(s&&performance&&performance.measure)&&performance.measure(t,e,r)},clearMarks:function(t){return!!(s&&performance&&performance.clearMarks)&&performance.clearMarks(t)},clearMeasures:function(t){return!!(s&&performance&&performance.clearMeasures)&&performance.clearMeasures(t)}},c=function(t){this._marks={start:[t.url,\"start\"].join(\"#\"),end:[t.url,\"end\"].join(\"#\"),measure:t.url.toString()},l.mark(this._marks.start)};function u(e,r){var n=t.getArrayBuffer(e.request,function(e,n,i,a){e?r(e):n&&r(null,{vectorTile:new t.vectorTile.VectorTile(new t.pbf(n)),rawData:n,cacheControl:i,expires:a})});return function(){n.cancel(),r()}}c.prototype.finish=function(){l.mark(this._marks.end);var t=l.getEntriesByName(this._marks.measure);return 0===t.length&&(l.measure(this._marks.measure,this._marks.start,this._marks.end),t=l.getEntriesByName(this._marks.measure),l.clearMarks(this._marks.start),l.clearMarks(this._marks.end),l.clearMeasures(this._marks.measure)),t},l.Performance=c;var h=function(t,e,r){this.actor=t,this.layerIndex=e,this.loadVectorData=r||u,this.loading={},this.loaded={}};h.prototype.loadTile=function(e,r){var n=this,i=e.uid;this.loading||(this.loading={});var o=!!(e&&e.request&&e.request.collectResourceTiming)&&new l.Performance(e.request),s=this.loading[i]=new a(e);s.abort=this.loadVectorData(e,function(e,a){if(delete n.loading[i],e||!a)return s.status=\"done\",n.loaded[i]=s,r(e);var l=a.rawData,c={};a.expires&&(c.expires=a.expires),a.cacheControl&&(c.cacheControl=a.cacheControl);var u={};if(o){var h=o.finish();h&&(u.resourceTiming=JSON.parse(JSON.stringify(h)))}s.vectorTile=a.vectorTile,s.parse(a.vectorTile,n.layerIndex,n.actor,function(e,n){if(e||!n)return r(e);r(null,t.extend({rawTileData:l.slice(0)},n,c,u))}),n.loaded=n.loaded||{},n.loaded[i]=s})},h.prototype.reloadTile=function(t,e){var r=this.loaded,n=t.uid,i=this;if(r&&r[n]){var a=r[n];a.showCollisionBoxes=t.showCollisionBoxes;var o=function(t,r){var n=a.reloadCallback;n&&(delete a.reloadCallback,a.parse(a.vectorTile,i.layerIndex,i.actor,n)),e(t,r)};\"parsing\"===a.status?a.reloadCallback=o:\"done\"===a.status&&(a.vectorTile?a.parse(a.vectorTile,this.layerIndex,this.actor,o):o())}},h.prototype.abortTile=function(t,e){var r=this.loading,n=t.uid;r&&r[n]&&r[n].abort&&(r[n].abort(),delete r[n]),e()},h.prototype.removeTile=function(t,e){var r=this.loaded,n=t.uid;r&&r[n]&&delete r[n],e()};var f=function(){this.loaded={}};f.prototype.loadTile=function(e,r){var n=e.uid,i=e.encoding,a=e.rawImageData,o=new t.DEMData(n,a,i);this.loaded=this.loaded||{},this.loaded[n]=o,r(null,o)},f.prototype.removeTile=function(t){var e=this.loaded,r=t.uid;e&&e[r]&&delete e[r]};var p={RADIUS:6378137,FLATTENING:1/298.257223563,POLAR_RADIUS:6356752.3142};function d(t){var e=0;if(t&&t.length>0){e+=Math.abs(g(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(g(t[r]))}return e}function g(t){var e,r,n,i,a,o,s=0,l=t.length;if(l>2){for(o=0;o<l;o++)o===l-2?(n=l-2,i=l-1,a=0):o===l-1?(n=l-1,i=0,a=1):(n=o,i=o+1,a=o+2),e=t[n],r=t[i],s+=(v(t[a][0])-v(e[0]))*Math.sin(v(r[1]));s=s*p.RADIUS*p.RADIUS/2}return s}function v(t){return t*Math.PI/180}var m={geometry:function t(e){var r,n=0;switch(e.type){case\"Polygon\":return d(e.coordinates);case\"MultiPolygon\":for(r=0;r<e.coordinates.length;r++)n+=d(e.coordinates[r]);return n;case\"Point\":case\"MultiPoint\":case\"LineString\":case\"MultiLineString\":return 0;case\"GeometryCollection\":for(r=0;r<e.geometries.length;r++)n+=t(e.geometries[r]);return n}},ring:g};function y(t,e){return function(r){return t(r,e)}}function x(t,e){e=!!e,t[0]=b(t[0],e);for(var r=1;r<t.length;r++)t[r]=b(t[r],!e);return t}function b(t,e){return function(t){return m.ring(t)>=0}(t)===e?t:t.reverse()}var _=t.vectorTile.VectorTileFeature.prototype.toGeoJSON,w=function(e){this._feature=e,this.extent=t.EXTENT,this.type=e.type,this.properties=e.tags,\"id\"in e&&!isNaN(e.id)&&(this.id=parseInt(e.id,10))};w.prototype.loadGeometry=function(){if(1===this._feature.type){for(var e=[],r=0,n=this._feature.geometry;r<n.length;r+=1){var i=n[r];e.push([new t.Point$1(i[0],i[1])])}return e}for(var a=[],o=0,s=this._feature.geometry;o<s.length;o+=1){for(var l=[],c=0,u=s[o];c<u.length;c+=1){var h=u[c];l.push(new t.Point$1(h[0],h[1]))}a.push(l)}return a},w.prototype.toGeoJSON=function(t,e,r){return _.call(this,t,e,r)};var k=function(e){this.layers={_geojsonTileLayer:this},this.name=\"_geojsonTileLayer\",this.extent=t.EXTENT,this.length=e.length,this._features=e};k.prototype.feature=function(t){return new w(this._features[t])};var T=t.vectorTile.VectorTileFeature,A=M;function M(t,e){this.options=e||{},this.features=t,this.length=t.length}function S(t,e){this.id=\"number\"==typeof t.id?t.id:void 0,this.type=t.type,this.rawGeometry=1===t.type?[t.geometry]:t.geometry,this.properties=t.tags,this.extent=e||4096}M.prototype.feature=function(t){return new S(this.features[t],this.options.extent)},S.prototype.loadGeometry=function(){var e=this.rawGeometry;this.geometry=[];for(var r=0;r<e.length;r++){for(var n=e[r],i=[],a=0;a<n.length;a++)i.push(new t.Point$1(n[a][0],n[a][1]));this.geometry.push(i)}return this.geometry},S.prototype.bbox=function(){this.geometry||this.loadGeometry();for(var t=this.geometry,e=1/0,r=-1/0,n=1/0,i=-1/0,a=0;a<t.length;a++)for(var o=t[a],s=0;s<o.length;s++){var l=o[s];e=Math.min(e,l.x),r=Math.max(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.y)}return[e,n,r,i]},S.prototype.toGeoJSON=T.prototype.toGeoJSON;var E=P,C=P,L=A;function P(e){var r=new t.pbf;return function(t,e){for(var r in t.layers)e.writeMessage(3,O,t.layers[r])}(e,r),r.finish()}function O(t,e){var r;e.writeVarintField(15,t.version||1),e.writeStringField(1,t.name||\"\"),e.writeVarintField(5,t.extent||4096);var n={keys:[],values:[],keycache:{},valuecache:{}};for(r=0;r<t.length;r++)n.feature=t.feature(r),e.writeMessage(2,z,n);var i=n.keys;for(r=0;r<i.length;r++)e.writeStringField(3,i[r]);var a=n.values;for(r=0;r<a.length;r++)e.writeMessage(4,B,a[r])}function z(t,e){var r=t.feature;void 0!==r.id&&e.writeVarintField(1,r.id),e.writeMessage(2,I,t),e.writeVarintField(3,r.type),e.writeMessage(4,F,r)}function I(t,e){var r=t.feature,n=t.keys,i=t.values,a=t.keycache,o=t.valuecache;for(var s in r.properties){var l=a[s];void 0===l&&(n.push(s),l=n.length-1,a[s]=l),e.writeVarint(l);var c=r.properties[s],u=typeof c;\"string\"!==u&&\"boolean\"!==u&&\"number\"!==u&&(c=JSON.stringify(c));var h=u+\":\"+c,f=o[h];void 0===f&&(i.push(c),f=i.length-1,o[h]=f),e.writeVarint(f)}}function D(t,e){return(e<<3)+(7&t)}function R(t){return t<<1^t>>31}function F(t,e){for(var r=t.loadGeometry(),n=t.type,i=0,a=0,o=r.length,s=0;s<o;s++){var l=r[s],c=1;1===n&&(c=l.length),e.writeVarint(D(1,c));for(var u=3===n?l.length-1:l.length,h=0;h<u;h++){1===h&&1!==n&&e.writeVarint(D(2,u-1));var f=l[h].x-i,p=l[h].y-a;e.writeVarint(R(f)),e.writeVarint(R(p)),i+=f,a+=p}3===n&&e.writeVarint(D(7,1))}}function B(t,e){var r=typeof t;\"string\"===r?e.writeStringField(1,t):\"boolean\"===r?e.writeBooleanField(7,t):\"number\"===r&&(t%1!=0?e.writeDoubleField(3,t):t<0?e.writeSVarintField(6,t):e.writeVarintField(5,t))}function N(t,e,r,n){j(t,r,n),j(e,2*r,2*n),j(e,2*r+1,2*n+1)}function j(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function U(t,e,r,n){var i=t-r,a=e-n;return i*i+a*a}E.fromVectorTileJs=C,E.fromGeojsonVt=function(t,e){e=e||{};var r={};for(var n in t)r[n]=new A(t[n].features,e),r[n].name=n,r[n].version=e.version,r[n].extent=e.extent;return P({layers:r})},E.GeoJSONWrapper=L;var V=function(t){return t[0]},q=function(t){return t[1]},H=function(t,e,r,n,i){void 0===e&&(e=V),void 0===r&&(r=q),void 0===n&&(n=64),void 0===i&&(i=Float64Array),this.nodeSize=n,this.points=t;for(var a=t.length<65536?Uint16Array:Uint32Array,o=this.ids=new a(t.length),s=this.coords=new i(2*t.length),l=0;l<t.length;l++)o[l]=l,s[2*l]=e(t[l]),s[2*l+1]=r(t[l]);!function t(e,r,n,i,a,o){if(!(a-i<=n)){var s=i+a>>1;!function t(e,r,n,i,a,o){for(;a>i;){if(a-i>600){var s=a-i+1,l=n-i+1,c=Math.log(s),u=.5*Math.exp(2*c/3),h=.5*Math.sqrt(c*u*(s-u)/s)*(l-s/2<0?-1:1);t(e,r,n,Math.max(i,Math.floor(n-l*u/s+h)),Math.min(a,Math.floor(n+(s-l)*u/s+h)),o)}var f=r[2*n+o],p=i,d=a;for(N(e,r,i,n),r[2*a+o]>f&&N(e,r,i,a);p<d;){for(N(e,r,p,d),p++,d--;r[2*p+o]<f;)p++;for(;r[2*d+o]>f;)d--}r[2*i+o]===f?N(e,r,i,d):N(e,r,++d,a),d<=n&&(i=d+1),n<=d&&(a=d-1)}}(e,r,s,i,a,o%2),t(e,r,n,i,s-1,o+1),t(e,r,n,s+1,a,o+1)}}(o,s,n,0,o.length-1,0)};H.prototype.range=function(t,e,r,n){return function(t,e,r,n,i,a,o){for(var s,l,c=[0,t.length-1,0],u=[];c.length;){var h=c.pop(),f=c.pop(),p=c.pop();if(f-p<=o)for(var d=p;d<=f;d++)s=e[2*d],l=e[2*d+1],s>=r&&s<=i&&l>=n&&l<=a&&u.push(t[d]);else{var g=Math.floor((p+f)/2);s=e[2*g],l=e[2*g+1],s>=r&&s<=i&&l>=n&&l<=a&&u.push(t[g]);var v=(h+1)%2;(0===h?r<=s:n<=l)&&(c.push(p),c.push(g-1),c.push(v)),(0===h?i>=s:a>=l)&&(c.push(g+1),c.push(f),c.push(v))}}return u}(this.ids,this.coords,t,e,r,n,this.nodeSize)},H.prototype.within=function(t,e,r){return function(t,e,r,n,i,a){for(var o=[0,t.length-1,0],s=[],l=i*i;o.length;){var c=o.pop(),u=o.pop(),h=o.pop();if(u-h<=a)for(var f=h;f<=u;f++)U(e[2*f],e[2*f+1],r,n)<=l&&s.push(t[f]);else{var p=Math.floor((h+u)/2),d=e[2*p],g=e[2*p+1];U(d,g,r,n)<=l&&s.push(t[p]);var v=(c+1)%2;(0===c?r-i<=d:n-i<=g)&&(o.push(h),o.push(p-1),o.push(v)),(0===c?r+i>=d:n+i>=g)&&(o.push(p+1),o.push(u),o.push(v))}}return s}(this.ids,this.coords,t,e,r,this.nodeSize)};var G={minZoom:0,maxZoom:16,radius:40,extent:512,nodeSize:64,log:!1,reduce:null,map:function(t){return t}},Y=function(t){this.options=Q(Object.create(G),t),this.trees=new Array(this.options.maxZoom+1)};function W(t,e,r,n,i){return{x:t,y:e,zoom:1/0,id:r,parentId:-1,numPoints:n,properties:i}}function X(t,e){var r=t.geometry.coordinates,n=r[0],i=r[1];return{x:K(n),y:$(i),zoom:1/0,index:e,parentId:-1}}function Z(t){return{type:\"Feature\",id:t.id,properties:J(t),geometry:{type:\"Point\",coordinates:[(n=t.x,360*(n-.5)),(e=t.y,r=(180-360*e)*Math.PI/180,360*Math.atan(Math.exp(r))/Math.PI-90)]}};var e,r,n}function J(t){var e=t.numPoints,r=e>=1e4?Math.round(e/1e3)+\"k\":e>=1e3?Math.round(e/100)/10+\"k\":e;return Q(Q({},t.properties),{cluster:!0,cluster_id:t.id,point_count:e,point_count_abbreviated:r})}function K(t){return t/360+.5}function $(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function Q(t,e){for(var r in e)t[r]=e[r];return t}function tt(t){return t.x}function et(t){return t.y}function rt(t,e,r,n,i,a){var o=i-r,s=a-n;if(0!==o||0!==s){var l=((t-r)*o+(e-n)*s)/(o*o+s*s);l>1?(r=i,n=a):l>0&&(r+=o*l,n+=s*l)}return(o=t-r)*o+(s=e-n)*s}function nt(t,e,r,n){var i={id:void 0===t?null:t,type:e,geometry:r,tags:n,minX:1/0,minY:1/0,maxX:-1/0,maxY:-1/0};return function(t){var e=t.geometry,r=t.type;if(\"Point\"===r||\"MultiPoint\"===r||\"LineString\"===r)it(t,e);else if(\"Polygon\"===r||\"MultiLineString\"===r)for(var n=0;n<e.length;n++)it(t,e[n]);else if(\"MultiPolygon\"===r)for(n=0;n<e.length;n++)for(var i=0;i<e[n].length;i++)it(t,e[n][i])}(i),i}function it(t,e){for(var r=0;r<e.length;r+=3)t.minX=Math.min(t.minX,e[r]),t.minY=Math.min(t.minY,e[r+1]),t.maxX=Math.max(t.maxX,e[r]),t.maxY=Math.max(t.maxY,e[r+1])}function at(t,e,r,n){if(e.geometry){var i=e.geometry.coordinates,a=e.geometry.type,o=Math.pow(r.tolerance/((1<<r.maxZoom)*r.extent),2),s=[],l=e.id;if(r.promoteId?l=e.properties[r.promoteId]:r.generateId&&(l=n||0),\"Point\"===a)ot(i,s);else if(\"MultiPoint\"===a)for(var c=0;c<i.length;c++)ot(i[c],s);else if(\"LineString\"===a)st(i,s,o,!1);else if(\"MultiLineString\"===a){if(r.lineMetrics){for(c=0;c<i.length;c++)s=[],st(i[c],s,o,!1),t.push(nt(l,\"LineString\",s,e.properties));return}lt(i,s,o,!1)}else if(\"Polygon\"===a)lt(i,s,o,!0);else{if(\"MultiPolygon\"!==a){if(\"GeometryCollection\"===a){for(c=0;c<e.geometry.geometries.length;c++)at(t,{id:l,geometry:e.geometry.geometries[c],properties:e.properties},r,n);return}throw new Error(\"Input data is not a valid GeoJSON object.\")}for(c=0;c<i.length;c++){var u=[];lt(i[c],u,o,!0),s.push(u)}}t.push(nt(l,a,s,e.properties))}}function ot(t,e){e.push(ct(t[0])),e.push(ut(t[1])),e.push(0)}function st(t,e,r,n){for(var i,a,o=0,s=0;s<t.length;s++){var l=ct(t[s][0]),c=ut(t[s][1]);e.push(l),e.push(c),e.push(0),s>0&&(o+=n?(i*c-l*a)/2:Math.sqrt(Math.pow(l-i,2)+Math.pow(c-a,2))),i=l,a=c}var u=e.length-3;e[2]=1,function t(e,r,n,i){for(var a,o=i,s=n-r>>1,l=n-r,c=e[r],u=e[r+1],h=e[n],f=e[n+1],p=r+3;p<n;p+=3){var d=rt(e[p],e[p+1],c,u,h,f);if(d>o)a=p,o=d;else if(d===o){var g=Math.abs(p-s);g<l&&(a=p,l=g)}}o>i&&(a-r>3&&t(e,r,a,i),e[a+2]=o,n-a>3&&t(e,a,n,i))}(e,0,u,r),e[u+2]=1,e.size=Math.abs(o),e.start=0,e.end=e.size}function lt(t,e,r,n){for(var i=0;i<t.length;i++){var a=[];st(t[i],a,r,n),e.push(a)}}function ct(t){return t/360+.5}function ut(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function ht(t,e,r,n,i,a,o,s){if(n/=e,a>=(r/=e)&&o<n)return t;if(o<r||a>=n)return null;for(var l=[],c=0;c<t.length;c++){var u=t[c],h=u.geometry,f=u.type,p=0===i?u.minX:u.minY,d=0===i?u.maxX:u.maxY;if(p>=r&&d<n)l.push(u);else if(!(d<r||p>=n)){var g=[];if(\"Point\"===f||\"MultiPoint\"===f)ft(h,g,r,n,i);else if(\"LineString\"===f)pt(h,g,r,n,i,!1,s.lineMetrics);else if(\"MultiLineString\"===f)gt(h,g,r,n,i,!1);else if(\"Polygon\"===f)gt(h,g,r,n,i,!0);else if(\"MultiPolygon\"===f)for(var v=0;v<h.length;v++){var m=[];gt(h[v],m,r,n,i,!0),m.length&&g.push(m)}if(g.length){if(s.lineMetrics&&\"LineString\"===f){for(v=0;v<g.length;v++)l.push(nt(u.id,f,g[v],u.tags));continue}\"LineString\"!==f&&\"MultiLineString\"!==f||(1===g.length?(f=\"LineString\",g=g[0]):f=\"MultiLineString\"),\"Point\"!==f&&\"MultiPoint\"!==f||(f=3===g.length?\"Point\":\"MultiPoint\"),l.push(nt(u.id,f,g,u.tags))}}}return l.length?l:null}function ft(t,e,r,n,i){for(var a=0;a<t.length;a+=3){var o=t[a+i];o>=r&&o<=n&&(e.push(t[a]),e.push(t[a+1]),e.push(t[a+2]))}}function pt(t,e,r,n,i,a,o){for(var s,l,c=dt(t),u=0===i?mt:yt,h=t.start,f=0;f<t.length-3;f+=3){var p=t[f],d=t[f+1],g=t[f+2],v=t[f+3],m=t[f+4],y=0===i?p:d,x=0===i?v:m,b=!1;o&&(s=Math.sqrt(Math.pow(p-v,2)+Math.pow(d-m,2))),y<r?x>r&&(l=u(c,p,d,v,m,r),o&&(c.start=h+s*l)):y>n?x<n&&(l=u(c,p,d,v,m,n),o&&(c.start=h+s*l)):vt(c,p,d,g),x<r&&y>=r&&(l=u(c,p,d,v,m,r),b=!0),x>n&&y<=n&&(l=u(c,p,d,v,m,n),b=!0),!a&&b&&(o&&(c.end=h+s*l),e.push(c),c=dt(t)),o&&(h+=s)}var _=t.length-3;p=t[_],d=t[_+1],g=t[_+2],(y=0===i?p:d)>=r&&y<=n&&vt(c,p,d,g),_=c.length-3,a&&_>=3&&(c[_]!==c[0]||c[_+1]!==c[1])&&vt(c,c[0],c[1],c[2]),c.length&&e.push(c)}function dt(t){var e=[];return e.size=t.size,e.start=t.start,e.end=t.end,e}function gt(t,e,r,n,i,a){for(var o=0;o<t.length;o++)pt(t[o],e,r,n,i,a,!1)}function vt(t,e,r,n){t.push(e),t.push(r),t.push(n)}function mt(t,e,r,n,i,a){var o=(a-e)/(n-e);return t.push(a),t.push(r+(i-r)*o),t.push(1),o}function yt(t,e,r,n,i,a){var o=(a-r)/(i-r);return t.push(e+(n-e)*o),t.push(a),t.push(1),o}function xt(t,e){for(var r=[],n=0;n<t.length;n++){var i,a=t[n],o=a.type;if(\"Point\"===o||\"MultiPoint\"===o||\"LineString\"===o)i=bt(a.geometry,e);else if(\"MultiLineString\"===o||\"Polygon\"===o){i=[];for(var s=0;s<a.geometry.length;s++)i.push(bt(a.geometry[s],e))}else if(\"MultiPolygon\"===o)for(i=[],s=0;s<a.geometry.length;s++){for(var l=[],c=0;c<a.geometry[s].length;c++)l.push(bt(a.geometry[s][c],e));i.push(l)}r.push(nt(a.id,o,i,a.tags))}return r}function bt(t,e){var r=[];r.size=t.size,void 0!==t.start&&(r.start=t.start,r.end=t.end);for(var n=0;n<t.length;n+=3)r.push(t[n]+e,t[n+1],t[n+2]);return r}function _t(t,e){if(t.transformed)return t;var r,n,i,a=1<<t.z,o=t.x,s=t.y;for(r=0;r<t.features.length;r++){var l=t.features[r],c=l.geometry,u=l.type;if(l.geometry=[],1===u)for(n=0;n<c.length;n+=2)l.geometry.push(wt(c[n],c[n+1],e,a,o,s));else for(n=0;n<c.length;n++){var h=[];for(i=0;i<c[n].length;i+=2)h.push(wt(c[n][i],c[n][i+1],e,a,o,s));l.geometry.push(h)}}return t.transformed=!0,t}function wt(t,e,r,n,i,a){return[Math.round(r*(t*n-i)),Math.round(r*(e*n-a))]}function kt(t,e,r,n,i){for(var a=e===i.maxZoom?0:i.tolerance/((1<<e)*i.extent),o={features:[],numPoints:0,numSimplified:0,numFeatures:0,source:null,x:r,y:n,z:e,transformed:!1,minX:2,minY:1,maxX:-1,maxY:0},s=0;s<t.length;s++){o.numFeatures++,Tt(o,t[s],a,i);var l=t[s].minX,c=t[s].minY,u=t[s].maxX,h=t[s].maxY;l<o.minX&&(o.minX=l),c<o.minY&&(o.minY=c),u>o.maxX&&(o.maxX=u),h>o.maxY&&(o.maxY=h)}return o}function Tt(t,e,r,n){var i=e.geometry,a=e.type,o=[];if(\"Point\"===a||\"MultiPoint\"===a)for(var s=0;s<i.length;s+=3)o.push(i[s]),o.push(i[s+1]),t.numPoints++,t.numSimplified++;else if(\"LineString\"===a)At(o,i,t,r,!1,!1);else if(\"MultiLineString\"===a||\"Polygon\"===a)for(s=0;s<i.length;s++)At(o,i[s],t,r,\"Polygon\"===a,0===s);else if(\"MultiPolygon\"===a)for(var l=0;l<i.length;l++){var c=i[l];for(s=0;s<c.length;s++)At(o,c[s],t,r,!0,0===s)}if(o.length){var u=e.tags||null;if(\"LineString\"===a&&n.lineMetrics){for(var h in u={},e.tags)u[h]=e.tags[h];u.mapbox_clip_start=i.start/i.size,u.mapbox_clip_end=i.end/i.size}var f={geometry:o,type:\"Polygon\"===a||\"MultiPolygon\"===a?3:\"LineString\"===a||\"MultiLineString\"===a?2:1,tags:u};null!==e.id&&(f.id=e.id),t.features.push(f)}}function At(t,e,r,n,i,a){var o=n*n;if(n>0&&e.size<(i?o:n))r.numPoints+=e.length/3;else{for(var s=[],l=0;l<e.length;l+=3)(0===n||e[l+2]>o)&&(r.numSimplified++,s.push(e[l]),s.push(e[l+1])),r.numPoints++;i&&function(t,e){for(var r=0,n=0,i=t.length,a=i-2;n<i;a=n,n+=2)r+=(t[n]-t[a])*(t[n+1]+t[a+1]);if(r>0===e)for(n=0,i=t.length;n<i/2;n+=2){var o=t[n],s=t[n+1];t[n]=t[i-2-n],t[n+1]=t[i-1-n],t[i-2-n]=o,t[i-1-n]=s}}(s,a),t.push(s)}}function Mt(t,e){var r=(e=this.options=function(t,e){for(var r in e)t[r]=e[r];return t}(Object.create(this.options),e)).debug;if(r&&console.time(\"preprocess data\"),e.maxZoom<0||e.maxZoom>24)throw new Error(\"maxZoom should be in the 0-24 range\");if(e.promoteId&&e.generateId)throw new Error(\"promoteId and generateId cannot be used together.\");var n=function(t,e){var r=[];if(\"FeatureCollection\"===t.type)for(var n=0;n<t.features.length;n++)at(r,t.features[n],e,n);else\"Feature\"===t.type?at(r,t,e):at(r,{geometry:t},e);return r}(t,e);this.tiles={},this.tileCoords=[],r&&(console.timeEnd(\"preprocess data\"),console.log(\"index: maxZoom: %d, maxPoints: %d\",e.indexMaxZoom,e.indexMaxPoints),console.time(\"generate tiles\"),this.stats={},this.total=0),(n=function(t,e){var r=e.buffer/e.extent,n=t,i=ht(t,1,-1-r,r,0,-1,2,e),a=ht(t,1,1-r,2+r,0,-1,2,e);return(i||a)&&(n=ht(t,1,-r,1+r,0,-1,2,e)||[],i&&(n=xt(i,1).concat(n)),a&&(n=n.concat(xt(a,-1)))),n}(n,e)).length&&this.splitTile(n,0,0,0),r&&(n.length&&console.log(\"features: %d, points: %d\",this.tiles[0].numFeatures,this.tiles[0].numPoints),console.timeEnd(\"generate tiles\"),console.log(\"tiles generated:\",this.total,JSON.stringify(this.stats)))}function St(t,e,r){return 32*((1<<t)*r+e)+t}function Et(t,e){var r=t.tileID.canonical;if(!this._geoJSONIndex)return e(null,null);var n=this._geoJSONIndex.getTile(r.z,r.x,r.y);if(!n)return e(null,null);var i=new k(n.features),a=E(i);0===a.byteOffset&&a.byteLength===a.buffer.byteLength||(a=new Uint8Array(a)),e(null,{vectorTile:i,rawData:a.buffer})}Y.prototype.load=function(t){var e=this.options,r=e.log,n=e.minZoom,i=e.maxZoom,a=e.nodeSize;r&&console.time(\"total time\");var o=\"prepare \"+t.length+\" points\";r&&console.time(o),this.points=t;for(var s=[],l=0;l<t.length;l++)t[l].geometry&&s.push(X(t[l],l));this.trees[i+1]=new H(s,tt,et,a,Float32Array),r&&console.timeEnd(o);for(var c=i;c>=n;c--){var u=+Date.now();s=this._cluster(s,c),this.trees[c]=new H(s,tt,et,a,Float32Array),r&&console.log(\"z%d: %d clusters in %dms\",c,s.length,+Date.now()-u)}return r&&console.timeEnd(\"total time\"),this},Y.prototype.getClusters=function(t,e){var r=((t[0]+180)%360+360)%360-180,n=Math.max(-90,Math.min(90,t[1])),i=180===t[2]?180:((t[2]+180)%360+360)%360-180,a=Math.max(-90,Math.min(90,t[3]));if(t[2]-t[0]>=360)r=-180,i=180;else if(r>i){var o=this.getClusters([r,n,180,a],e),s=this.getClusters([-180,n,i,a],e);return o.concat(s)}for(var l=this.trees[this._limitZoom(e)],c=[],u=0,h=l.range(K(r),$(a),K(i),$(n));u<h.length;u+=1){var f=h[u],p=l.points[f];c.push(p.numPoints?Z(p):this.points[p.index])}return c},Y.prototype.getChildren=function(t){var e=t>>5,r=t%32,n=\"No cluster with the specified id.\",i=this.trees[r];if(!i)throw new Error(n);var a=i.points[e];if(!a)throw new Error(n);for(var o=this.options.radius/(this.options.extent*Math.pow(2,r-1)),s=[],l=0,c=i.within(a.x,a.y,o);l<c.length;l+=1){var u=c[l],h=i.points[u];h.parentId===t&&s.push(h.numPoints?Z(h):this.points[h.index])}if(0===s.length)throw new Error(n);return s},Y.prototype.getLeaves=function(t,e,r){e=e||10,r=r||0;var n=[];return this._appendLeaves(n,t,e,r,0),n},Y.prototype.getTile=function(t,e,r){var n=this.trees[this._limitZoom(t)],i=Math.pow(2,t),a=this.options,o=a.extent,s=a.radius/o,l=(r-s)/i,c=(r+1+s)/i,u={features:[]};return this._addTileFeatures(n.range((e-s)/i,l,(e+1+s)/i,c),n.points,e,r,i,u),0===e&&this._addTileFeatures(n.range(1-s/i,l,1,c),n.points,i,r,i,u),e===i-1&&this._addTileFeatures(n.range(0,l,s/i,c),n.points,-1,r,i,u),u.features.length?u:null},Y.prototype.getClusterExpansionZoom=function(t){for(var e=t%32-1;e<=this.options.maxZoom;){var r=this.getChildren(t);if(e++,1!==r.length)break;t=r[0].properties.cluster_id}return e},Y.prototype._appendLeaves=function(t,e,r,n,i){for(var a=0,o=this.getChildren(e);a<o.length;a+=1){var s=o[a],l=s.properties;if(l&&l.cluster?i+l.point_count<=n?i+=l.point_count:i=this._appendLeaves(t,l.cluster_id,r,n,i):i<n?i++:t.push(s),t.length===r)break}return i},Y.prototype._addTileFeatures=function(t,e,r,n,i,a){for(var o=0,s=t;o<s.length;o+=1){var l=e[s[o]],c={type:1,geometry:[[Math.round(this.options.extent*(l.x*i-r)),Math.round(this.options.extent*(l.y*i-n))]],tags:l.numPoints?J(l):this.points[l.index].properties},u=l.numPoints?l.id:this.points[l.index].id;void 0!==u&&(c.id=u),a.features.push(c)}},Y.prototype._limitZoom=function(t){return Math.max(this.options.minZoom,Math.min(t,this.options.maxZoom+1))},Y.prototype._cluster=function(t,e){for(var r=[],n=this.options,i=n.radius,a=n.extent,o=n.reduce,s=i/(a*Math.pow(2,e)),l=0;l<t.length;l++){var c=t[l];if(!(c.zoom<=e)){c.zoom=e;for(var u=this.trees[e+1],h=u.within(c.x,c.y,s),f=c.numPoints||1,p=c.x*f,d=c.y*f,g=o?this._map(c,!0):null,v=(l<<5)+(e+1),m=0,y=h;m<y.length;m+=1){var x=y[m],b=u.points[x];if(!(b.zoom<=e)){b.zoom=e;var _=b.numPoints||1;p+=b.x*_,d+=b.y*_,f+=_,b.parentId=v,o&&o(g,this._map(b))}}1===f?r.push(c):(c.parentId=v,r.push(W(p/f,d/f,v,f,g)))}}return r},Y.prototype._map=function(t,e){if(t.numPoints)return e?Q({},t.properties):t.properties;var r=this.points[t.index].properties,n=this.options.map(r);return e&&n===r?Q({},n):n},Mt.prototype.options={maxZoom:14,indexMaxZoom:5,indexMaxPoints:1e5,tolerance:3,extent:4096,buffer:64,lineMetrics:!1,promoteId:null,generateId:!1,debug:0},Mt.prototype.splitTile=function(t,e,r,n,i,a,o){for(var s=[t,e,r,n],l=this.options,c=l.debug;s.length;){n=s.pop(),r=s.pop(),e=s.pop(),t=s.pop();var u=1<<e,h=St(e,r,n),f=this.tiles[h];if(!f&&(c>1&&console.time(\"creation\"),f=this.tiles[h]=kt(t,e,r,n,l),this.tileCoords.push({z:e,x:r,y:n}),c)){c>1&&(console.log(\"tile z%d-%d-%d (features: %d, points: %d, simplified: %d)\",e,r,n,f.numFeatures,f.numPoints,f.numSimplified),console.timeEnd(\"creation\"));var p=\"z\"+e;this.stats[p]=(this.stats[p]||0)+1,this.total++}if(f.source=t,i){if(e===l.maxZoom||e===i)continue;var d=1<<i-e;if(r!==Math.floor(a/d)||n!==Math.floor(o/d))continue}else if(e===l.indexMaxZoom||f.numPoints<=l.indexMaxPoints)continue;if(f.source=null,0!==t.length){c>1&&console.time(\"clipping\");var g,v,m,y,x,b,_=.5*l.buffer/l.extent,w=.5-_,k=.5+_,T=1+_;g=v=m=y=null,x=ht(t,u,r-_,r+k,0,f.minX,f.maxX,l),b=ht(t,u,r+w,r+T,0,f.minX,f.maxX,l),t=null,x&&(g=ht(x,u,n-_,n+k,1,f.minY,f.maxY,l),v=ht(x,u,n+w,n+T,1,f.minY,f.maxY,l),x=null),b&&(m=ht(b,u,n-_,n+k,1,f.minY,f.maxY,l),y=ht(b,u,n+w,n+T,1,f.minY,f.maxY,l),b=null),c>1&&console.timeEnd(\"clipping\"),s.push(g||[],e+1,2*r,2*n),s.push(v||[],e+1,2*r,2*n+1),s.push(m||[],e+1,2*r+1,2*n),s.push(y||[],e+1,2*r+1,2*n+1)}}},Mt.prototype.getTile=function(t,e,r){var n=this.options,i=n.extent,a=n.debug;if(t<0||t>24)return null;var o=1<<t,s=St(t,e=(e%o+o)%o,r);if(this.tiles[s])return _t(this.tiles[s],i);a>1&&console.log(\"drilling down to z%d-%d-%d\",t,e,r);for(var l,c=t,u=e,h=r;!l&&c>0;)c--,u=Math.floor(u/2),h=Math.floor(h/2),l=this.tiles[St(c,u,h)];return l&&l.source?(a>1&&console.log(\"found parent tile z%d-%d-%d\",c,u,h),a>1&&console.time(\"drilling down\"),this.splitTile(l.source,c,u,h,t,e,r),a>1&&console.timeEnd(\"drilling down\"),this.tiles[s]?_t(this.tiles[s],i):null):null};var Ct=function(e){function r(t,r,n){e.call(this,t,r,Et),n&&(this.loadGeoJSON=n)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadData=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),this._pendingCallback=e,this._pendingLoadDataParams=t,this._state&&\"Idle\"!==this._state?this._state=\"NeedsLoadData\":(this._state=\"Coalescing\",this._loadData())},r.prototype._loadData=function(){var e=this;if(this._pendingCallback&&this._pendingLoadDataParams){var r=this._pendingCallback,n=this._pendingLoadDataParams;delete this._pendingCallback,delete this._pendingLoadDataParams;var i=!!(n&&n.request&&n.request.collectResourceTiming)&&new l.Performance(n.request);this.loadGeoJSON(n,function(a,o){if(a||!o)return r(a);if(\"object\"!=typeof o)return r(new Error(\"Input data given to '\"+n.source+\"' is not a valid GeoJSON object.\"));!function t(e,r){switch(e&&e.type||null){case\"FeatureCollection\":return e.features=e.features.map(y(t,r)),e;case\"GeometryCollection\":return e.geometries=e.geometries.map(y(t,r)),e;case\"Feature\":return e.geometry=t(e.geometry,r),e;case\"Polygon\":case\"MultiPolygon\":return function(t,e){return\"Polygon\"===t.type?t.coordinates=x(t.coordinates,e):\"MultiPolygon\"===t.type&&(t.coordinates=t.coordinates.map(y(x,e))),t}(e,r);default:return e}}(o,!0);try{e._geoJSONIndex=n.cluster?new Y(function(e){var r=e.superclusterOptions,n=e.clusterProperties;if(!n||!r)return r;for(var i={},a={},o={accumulated:null,zoom:0},s={properties:null},l=Object.keys(n),c=0,u=l;c<u.length;c+=1){var h=u[c],f=n[h],p=f[0],d=f[1],g=t.createExpression(d),v=t.createExpression(\"string\"==typeof p?[p,[\"accumulated\"],[\"get\",h]]:p);i[h]=g.value,a[h]=v.value}return r.map=function(t){s.properties=t;for(var e={},r=0,n=l;r<n.length;r+=1){var a=n[r];e[a]=i[a].evaluate(o,s)}return e},r.reduce=function(t,e){s.properties=e;for(var r=0,n=l;r<n.length;r+=1){var i=n[r];o.accumulated=t[i],t[i]=a[i].evaluate(o,s)}},r}(n)).load(o.features):new Mt(o,n.geojsonVtOptions)}catch(a){return r(a)}e.loaded={};var s={};if(i){var l=i.finish();l&&(s.resourceTiming={},s.resourceTiming[n.source]=JSON.parse(JSON.stringify(l)))}r(null,s)})}},r.prototype.coalesce=function(){\"Coalescing\"===this._state?this._state=\"Idle\":\"NeedsLoadData\"===this._state&&(this._state=\"Coalescing\",this._loadData())},r.prototype.reloadTile=function(t,r){var n=this.loaded,i=t.uid;return n&&n[i]?e.prototype.reloadTile.call(this,t,r):this.loadTile(t,r)},r.prototype.loadGeoJSON=function(e,r){if(e.request)t.getJSON(e.request,r);else{if(\"string\"!=typeof e.data)return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"));try{return r(null,JSON.parse(e.data))}catch(t){return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"))}}},r.prototype.removeSource=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),e()},r.prototype.getClusterExpansionZoom=function(t,e){e(null,this._geoJSONIndex.getClusterExpansionZoom(t.clusterId))},r.prototype.getClusterChildren=function(t,e){e(null,this._geoJSONIndex.getChildren(t.clusterId))},r.prototype.getClusterLeaves=function(t,e){e(null,this._geoJSONIndex.getLeaves(t.clusterId,t.limit,t.offset))},r}(h),Lt=function(e){var r=this;this.self=e,this.actor=new t.Actor(e,this),this.layerIndexes={},this.workerSourceTypes={vector:h,geojson:Ct},this.workerSources={},this.demWorkerSources={},this.self.registerWorkerSource=function(t,e){if(r.workerSourceTypes[t])throw new Error('Worker source with name \"'+t+'\" already registered.');r.workerSourceTypes[t]=e},this.self.registerRTLTextPlugin=function(e){if(t.plugin.isLoaded())throw new Error(\"RTL text plugin already registered.\");t.plugin.applyArabicShaping=e.applyArabicShaping,t.plugin.processBidirectionalText=e.processBidirectionalText,t.plugin.processStyledBidirectionalText=e.processStyledBidirectionalText}};return Lt.prototype.setReferrer=function(t,e){this.referrer=e},Lt.prototype.setLayers=function(t,e,r){this.getLayerIndex(t).replace(e),r()},Lt.prototype.updateLayers=function(t,e,r){this.getLayerIndex(t).update(e.layers,e.removedIds),r()},Lt.prototype.loadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).loadTile(e,r)},Lt.prototype.loadDEMTile=function(t,e,r){this.getDEMWorkerSource(t,e.source).loadTile(e,r)},Lt.prototype.reloadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).reloadTile(e,r)},Lt.prototype.abortTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).abortTile(e,r)},Lt.prototype.removeTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).removeTile(e,r)},Lt.prototype.removeDEMTile=function(t,e){this.getDEMWorkerSource(t,e.source).removeTile(e)},Lt.prototype.removeSource=function(t,e,r){if(this.workerSources[t]&&this.workerSources[t][e.type]&&this.workerSources[t][e.type][e.source]){var n=this.workerSources[t][e.type][e.source];delete this.workerSources[t][e.type][e.source],void 0!==n.removeSource?n.removeSource(e,r):r()}},Lt.prototype.loadWorkerSource=function(t,e,r){try{this.self.importScripts(e.url),r()}catch(t){r(t.toString())}},Lt.prototype.loadRTLTextPlugin=function(e,r,n){try{t.plugin.isLoaded()||(this.self.importScripts(r),n(t.plugin.isLoaded()?null:new Error(\"RTL Text Plugin failed to import scripts from \"+r)))}catch(t){n(t.toString())}},Lt.prototype.getLayerIndex=function(t){var e=this.layerIndexes[t];return e||(e=this.layerIndexes[t]=new n),e},Lt.prototype.getWorkerSource=function(t,e,r){var n=this;if(this.workerSources[t]||(this.workerSources[t]={}),this.workerSources[t][e]||(this.workerSources[t][e]={}),!this.workerSources[t][e][r]){var i={send:function(e,r,i){n.actor.send(e,r,i,t)}};this.workerSources[t][e][r]=new this.workerSourceTypes[e](i,this.getLayerIndex(t))}return this.workerSources[t][e][r]},Lt.prototype.getDEMWorkerSource=function(t,e){return this.demWorkerSources[t]||(this.demWorkerSources[t]={}),this.demWorkerSources[t][e]||(this.demWorkerSources[t][e]=new f),this.demWorkerSources[t][e]},Lt.prototype.enforceCacheSizeLimit=function(e,r){t.enforceCacheSizeLimit(r)},\"undefined\"!=typeof WorkerGlobalScope&&void 0!==t.window&&t.window instanceof WorkerGlobalScope&&(t.window.worker=new Lt(t.window)),Lt}),n(0,function(t){var e=t.createCommonjsModule(function(t){function e(t){return!!(\"undefined\"!=typeof window&&\"undefined\"!=typeof document&&Array.prototype&&Array.prototype.every&&Array.prototype.filter&&Array.prototype.forEach&&Array.prototype.indexOf&&Array.prototype.lastIndexOf&&Array.prototype.map&&Array.prototype.some&&Array.prototype.reduce&&Array.prototype.reduceRight&&Array.isArray&&Function.prototype&&Function.prototype.bind&&Object.keys&&Object.create&&Object.getPrototypeOf&&Object.getOwnPropertyNames&&Object.isSealed&&Object.isFrozen&&Object.isExtensible&&Object.getOwnPropertyDescriptor&&Object.defineProperty&&Object.defineProperties&&Object.seal&&Object.freeze&&Object.preventExtensions&&\"JSON\"in window&&\"parse\"in JSON&&\"stringify\"in JSON&&function(){if(!(\"Worker\"in window&&\"Blob\"in window&&\"URL\"in window))return!1;var t,e,r=new Blob([\"\"],{type:\"text/javascript\"}),n=URL.createObjectURL(r);try{e=new Worker(n),t=!0}catch(e){t=!1}return e&&e.terminate(),URL.revokeObjectURL(n),t}()&&\"Uint8ClampedArray\"in window&&ArrayBuffer.isView&&function(t){return void 0===r[t]&&(r[t]=function(t){var r=document.createElement(\"canvas\"),n=Object.create(e.webGLContextAttributes);return n.failIfMajorPerformanceCaveat=t,r.probablySupportsContext?r.probablySupportsContext(\"webgl\",n)||r.probablySupportsContext(\"experimental-webgl\",n):r.supportsContext?r.supportsContext(\"webgl\",n)||r.supportsContext(\"experimental-webgl\",n):r.getContext(\"webgl\",n)||r.getContext(\"experimental-webgl\",n)}(t)),r[t]}(t&&t.failIfMajorPerformanceCaveat))}t.exports?t.exports=e:window&&(window.mapboxgl=window.mapboxgl||{},window.mapboxgl.supported=e);var r={};e.webGLContextAttributes={antialias:!1,alpha:!0,stencil:!0,depth:!0}}),r={create:function(e,r,n){var i=t.window.document.createElement(e);return void 0!==r&&(i.className=r),n&&n.appendChild(i),i},createNS:function(e,r){return t.window.document.createElementNS(e,r)}},n=t.window.document.documentElement.style;function i(t){if(!n)return t[0];for(var e=0;e<t.length;e++)if(t[e]in n)return t[e];return t[0]}var a,o=i([\"userSelect\",\"MozUserSelect\",\"WebkitUserSelect\",\"msUserSelect\"]);r.disableDrag=function(){n&&o&&(a=n[o],n[o]=\"none\")},r.enableDrag=function(){n&&o&&(n[o]=a)};var s=i([\"transform\",\"WebkitTransform\"]);r.setTransform=function(t,e){t.style[s]=e};var l=!1;try{var c=Object.defineProperty({},\"passive\",{get:function(){l=!0}});t.window.addEventListener(\"test\",c,c),t.window.removeEventListener(\"test\",c,c)}catch(t){l=!1}r.addEventListener=function(t,e,r,n){void 0===n&&(n={}),\"passive\"in n&&l?t.addEventListener(e,r,n):t.addEventListener(e,r,n.capture)},r.removeEventListener=function(t,e,r,n){void 0===n&&(n={}),\"passive\"in n&&l?t.removeEventListener(e,r,n):t.removeEventListener(e,r,n.capture)};var u=function(e){e.preventDefault(),e.stopPropagation(),t.window.removeEventListener(\"click\",u,!0)};function h(t){var e=t.userImage;return!!(e&&e.render&&e.render())&&(t.data.replace(new Uint8Array(e.data.buffer)),!0)}r.suppressClick=function(){t.window.addEventListener(\"click\",u,!0),t.window.setTimeout(function(){t.window.removeEventListener(\"click\",u,!0)},0)},r.mousePos=function(e,r){var n=e.getBoundingClientRect(),i=t.window.TouchEvent&&r instanceof t.window.TouchEvent?r.touches[0]:r;return new t.Point(i.clientX-n.left-e.clientLeft,i.clientY-n.top-e.clientTop)},r.touchPos=function(e,r){for(var n=e.getBoundingClientRect(),i=[],a=\"touchend\"===r.type?r.changedTouches:r.touches,o=0;o<a.length;o++)i.push(new t.Point(a[o].clientX-n.left-e.clientLeft,a[o].clientY-n.top-e.clientTop));return i},r.mouseButton=function(e){return void 0!==t.window.InstallTrigger&&2===e.button&&e.ctrlKey&&t.window.navigator.platform.toUpperCase().indexOf(\"MAC\")>=0?0:e.button},r.remove=function(t){t.parentNode&&t.parentNode.removeChild(t)};var f=function(e){function r(){e.call(this),this.images={},this.updatedImages={},this.callbackDispatchedThisFrame={},this.loaded=!1,this.requestors=[],this.patterns={},this.atlasImage=new t.RGBAImage({width:1,height:1}),this.dirty=!0}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.isLoaded=function(){return this.loaded},r.prototype.setLoaded=function(t){if(this.loaded!==t&&(this.loaded=t,t)){for(var e=0,r=this.requestors;e<r.length;e+=1){var n=r[e],i=n.ids,a=n.callback;this._notify(i,a)}this.requestors=[]}},r.prototype.getImage=function(t){return this.images[t]},r.prototype.addImage=function(t,e){this.images[t]=e},r.prototype.updateImage=function(t,e){var r=this.images[t];e.version=r.version+1,this.images[t]=e,this.updatedImages[t]=!0},r.prototype.removeImage=function(t){var e=this.images[t];delete this.images[t],delete this.patterns[t],e.userImage&&e.userImage.onRemove&&e.userImage.onRemove()},r.prototype.listImages=function(){return Object.keys(this.images)},r.prototype.getImages=function(t,e){var r=!0;if(!this.isLoaded())for(var n=0,i=t;n<i.length;n+=1){var a=i[n];this.images[a]||(r=!1)}this.isLoaded()||r?this._notify(t,e):this.requestors.push({ids:t,callback:e})},r.prototype._notify=function(e,r){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i];this.images[o]||this.fire(new t.Event(\"styleimagemissing\",{id:o}));var s=this.images[o];s?n[o]={data:s.data.clone(),pixelRatio:s.pixelRatio,sdf:s.sdf,version:s.version,hasRenderCallback:Boolean(s.userImage&&s.userImage.render)}:t.warnOnce('Image \"'+o+'\" could not be loaded. Please make sure you have added the image with map.addImage() or a \"sprite\" property in your style. You can provide missing images by listening for the \"styleimagemissing\" map event.')}r(null,n)},r.prototype.getPixelSize=function(){var t=this.atlasImage;return{width:t.width,height:t.height}},r.prototype.getPattern=function(e){var r=this.patterns[e],n=this.getImage(e);if(!n)return null;if(r&&r.position.version===n.version)return r.position;if(r)r.position.version=n.version;else{var i={w:n.data.width+2,h:n.data.height+2,x:0,y:0},a=new t.ImagePosition(i,n);this.patterns[e]={bin:i,position:a}}return this._updatePatternAtlas(),this.patterns[e].position},r.prototype.bind=function(e){var r=e.gl;this.atlasTexture?this.dirty&&(this.atlasTexture.update(this.atlasImage),this.dirty=!1):this.atlasTexture=new t.Texture(e,this.atlasImage,r.RGBA),this.atlasTexture.bind(r.LINEAR,r.CLAMP_TO_EDGE)},r.prototype._updatePatternAtlas=function(){var e=[];for(var r in this.patterns)e.push(this.patterns[r].bin);var n=t.potpack(e),i=n.w,a=n.h,o=this.atlasImage;for(var s in o.resize({width:i||1,height:a||1}),this.patterns){var l=this.patterns[s].bin,c=l.x+1,u=l.y+1,h=this.images[s].data,f=h.width,p=h.height;t.RGBAImage.copy(h,o,{x:0,y:0},{x:c,y:u},{width:f,height:p}),t.RGBAImage.copy(h,o,{x:0,y:p-1},{x:c,y:u-1},{width:f,height:1}),t.RGBAImage.copy(h,o,{x:0,y:0},{x:c,y:u+p},{width:f,height:1}),t.RGBAImage.copy(h,o,{x:f-1,y:0},{x:c-1,y:u},{width:1,height:p}),t.RGBAImage.copy(h,o,{x:0,y:0},{x:c+f,y:u},{width:1,height:p})}this.dirty=!0},r.prototype.beginFrame=function(){this.callbackDispatchedThisFrame={}},r.prototype.dispatchRenderCallbacks=function(t){for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!this.callbackDispatchedThisFrame[n]){this.callbackDispatchedThisFrame[n]=!0;var i=this.images[n];h(i)&&this.updateImage(n,i)}}},r}(t.Evented),p=g,d=1e20;function g(t,e,r,n,i,a){this.fontSize=t||24,this.buffer=void 0===e?3:e,this.cutoff=n||.25,this.fontFamily=i||\"sans-serif\",this.fontWeight=a||\"normal\",this.radius=r||8;var o=this.size=this.fontSize+2*this.buffer;this.canvas=document.createElement(\"canvas\"),this.canvas.width=this.canvas.height=o,this.ctx=this.canvas.getContext(\"2d\"),this.ctx.font=this.fontWeight+\" \"+this.fontSize+\"px \"+this.fontFamily,this.ctx.textBaseline=\"middle\",this.ctx.fillStyle=\"black\",this.gridOuter=new Float64Array(o*o),this.gridInner=new Float64Array(o*o),this.f=new Float64Array(o),this.d=new Float64Array(o),this.z=new Float64Array(o+1),this.v=new Int16Array(o),this.middle=Math.round(o/2*(navigator.userAgent.indexOf(\"Gecko/\")>=0?1.2:1))}function v(t,e,r,n,i,a,o){for(var s=0;s<e;s++){for(var l=0;l<r;l++)n[l]=t[l*e+s];for(m(n,i,a,o,r),l=0;l<r;l++)t[l*e+s]=i[l]}for(l=0;l<r;l++){for(s=0;s<e;s++)n[s]=t[l*e+s];for(m(n,i,a,o,e),s=0;s<e;s++)t[l*e+s]=Math.sqrt(i[s])}}function m(t,e,r,n,i){r[0]=0,n[0]=-d,n[1]=+d;for(var a=1,o=0;a<i;a++){for(var s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);s<=n[o];)o--,s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);r[++o]=a,n[o]=s,n[o+1]=+d}for(a=0,o=0;a<i;a++){for(;n[o+1]<a;)o++;e[a]=(a-r[o])*(a-r[o])+t[r[o]]}}g.prototype.draw=function(t){this.ctx.clearRect(0,0,this.size,this.size),this.ctx.fillText(t,this.buffer,this.middle);for(var e=this.ctx.getImageData(0,0,this.size,this.size),r=new Uint8ClampedArray(this.size*this.size),n=0;n<this.size*this.size;n++){var i=e.data[4*n+3]/255;this.gridOuter[n]=1===i?0:0===i?d:Math.pow(Math.max(0,.5-i),2),this.gridInner[n]=1===i?d:0===i?0:Math.pow(Math.max(0,i-.5),2)}for(v(this.gridOuter,this.size,this.size,this.f,this.d,this.v,this.z),v(this.gridInner,this.size,this.size,this.f,this.d,this.v,this.z),n=0;n<this.size*this.size;n++){var a=this.gridOuter[n]-this.gridInner[n];r[n]=Math.max(0,Math.min(255,Math.round(255-255*(a/this.radius+this.cutoff))))}return r};var y=function(t,e){this.requestManager=t,this.localIdeographFontFamily=e,this.entries={}};y.prototype.setURL=function(t){this.url=t},y.prototype.getGlyphs=function(e,r){var n=this,i=[];for(var a in e)for(var o=0,s=e[a];o<s.length;o+=1){var l=s[o];i.push({stack:a,id:l})}t.asyncAll(i,function(t,e){var r=t.stack,i=t.id,a=n.entries[r];a||(a=n.entries[r]={glyphs:{},requests:{}});var o=a.glyphs[i];if(void 0===o)if(o=n._tinySDF(a,r,i))e(null,{stack:r,id:i,glyph:o});else{var s=Math.floor(i/256);if(256*s>65535)e(new Error(\"glyphs > 65535 not supported\"));else{var l=a.requests[s];l||(l=a.requests[s]=[],y.loadGlyphRange(r,s,n.url,n.requestManager,function(t,e){if(e)for(var r in e)a.glyphs[+r]=e[+r];for(var n=0,i=l;n<i.length;n+=1)(0,i[n])(t,e);delete a.requests[s]})),l.push(function(t,n){t?e(t):n&&e(null,{stack:r,id:i,glyph:n[i]||null})})}}else e(null,{stack:r,id:i,glyph:o})},function(t,e){if(t)r(t);else if(e){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.stack,l=o.id,c=o.glyph;(n[s]||(n[s]={}))[l]=c&&{id:c.id,bitmap:c.bitmap.clone(),metrics:c.metrics}}r(null,n)}})},y.prototype._tinySDF=function(e,r,n){var i=this.localIdeographFontFamily;if(i&&(t.isChar[\"CJK Unified Ideographs\"](n)||t.isChar[\"Hangul Syllables\"](n)||t.isChar.Hiragana(n)||t.isChar.Katakana(n))){var a=e.tinySDF;if(!a){var o=\"400\";/bold/i.test(r)?o=\"900\":/medium/i.test(r)?o=\"500\":/light/i.test(r)&&(o=\"200\"),a=e.tinySDF=new y.TinySDF(24,3,8,.25,i,o)}return{id:n,bitmap:new t.AlphaImage({width:30,height:30},a.draw(String.fromCharCode(n))),metrics:{width:24,height:24,left:0,top:-8,advance:24}}}},y.loadGlyphRange=function(e,r,n,i,a){var o=256*r,s=o+255,l=i.transformRequest(i.normalizeGlyphsURL(n).replace(\"{fontstack}\",e).replace(\"{range}\",o+\"-\"+s),t.ResourceType.Glyphs);t.getArrayBuffer(l,function(e,r){if(e)a(e);else if(r){for(var n={},i=0,o=t.parseGlyphPBF(r);i<o.length;i+=1){var s=o[i];n[s.id]=s}a(null,n)}})},y.TinySDF=p;var x=function(){this.specification=t.styleSpec.light.position};x.prototype.possiblyEvaluate=function(e,r){return t.sphericalToCartesian(e.expression.evaluate(r))},x.prototype.interpolate=function(e,r,n){return{x:t.number(e.x,r.x,n),y:t.number(e.y,r.y,n),z:t.number(e.z,r.z,n)}};var b=new t.Properties({anchor:new t.DataConstantProperty(t.styleSpec.light.anchor),position:new x,color:new t.DataConstantProperty(t.styleSpec.light.color),intensity:new t.DataConstantProperty(t.styleSpec.light.intensity)}),_=function(e){function r(r){e.call(this),this._transitionable=new t.Transitionable(b),this.setLight(r),this._transitioning=this._transitionable.untransitioned()}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getLight=function(){return this._transitionable.serialize()},r.prototype.setLight=function(e,r){if(void 0===r&&(r={}),!this._validate(t.validateLight,e,r))for(var n in e){var i=e[n];t.endsWith(n,\"-transition\")?this._transitionable.setTransition(n.slice(0,-\"-transition\".length),i):this._transitionable.setValue(n,i)}},r.prototype.updateTransitions=function(t){this._transitioning=this._transitionable.transitioned(t,this._transitioning)},r.prototype.hasTransition=function(){return this._transitioning.hasTransition()},r.prototype.recalculate=function(t){this.properties=this._transitioning.possiblyEvaluate(t)},r.prototype._validate=function(e,r,n){return(!n||!1!==n.validate)&&t.emitValidationErrors(this,e.call(t.validateStyle,t.extend({value:r,style:{glyphs:!0,sprite:!0},styleSpec:t.styleSpec})))},r}(t.Evented),w=function(t,e){this.width=t,this.height=e,this.nextRow=0,this.bytes=4,this.data=new Uint8Array(this.width*this.height*this.bytes),this.positions={}};w.prototype.getDash=function(t,e){var r=t.join(\",\")+String(e);return this.positions[r]||(this.positions[r]=this.addDash(t,e)),this.positions[r]},w.prototype.addDash=function(e,r){var n=r?7:0,i=2*n+1;if(this.nextRow+i>this.height)return t.warnOnce(\"LineAtlas out of space\"),null;for(var a=0,o=0;o<e.length;o++)a+=e[o];for(var s=this.width/a,l=s/2,c=e.length%2==1,u=-n;u<=n;u++)for(var h=this.nextRow+n+u,f=this.width*h,p=c?-e[e.length-1]:0,d=e[0],g=1,v=0;v<this.width;v++){for(;d<v/s;)p=d,d+=e[g],c&&g===e.length-1&&(d+=e[0]),g++;var m=Math.abs(v-p*s),y=Math.abs(v-d*s),x=Math.min(m,y),b=g%2==1,_=void 0;if(r){var w=n?u/n*(l+1):0;if(b){var k=l-Math.abs(w);_=Math.sqrt(x*x+k*k)}else _=l-Math.sqrt(x*x+w*w)}else _=(b?1:-1)*x;this.data[3+4*(f+v)]=Math.max(0,Math.min(255,_+128))}var T={y:(this.nextRow+n+.5)/this.height,height:2*n/this.height,width:a};return this.nextRow+=i,this.dirty=!0,T},w.prototype.bind=function(t){var e=t.gl;this.texture?(e.bindTexture(e.TEXTURE_2D,this.texture),this.dirty&&(this.dirty=!1,e.texSubImage2D(e.TEXTURE_2D,0,0,0,this.width,this.height,e.RGBA,e.UNSIGNED_BYTE,this.data))):(this.texture=e.createTexture(),e.bindTexture(e.TEXTURE_2D,this.texture),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_S,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_T,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,e.LINEAR),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,e.LINEAR),e.texImage2D(e.TEXTURE_2D,0,e.RGBA,this.width,this.height,0,e.RGBA,e.UNSIGNED_BYTE,this.data))};var k=function e(r,n){this.workerPool=r,this.actors=[],this.currentActor=0,this.id=t.uniqueId();for(var i=this.workerPool.acquire(this.id),a=0;a<i.length;a++){var o=i[a],s=new e.Actor(o,n,this.id);s.name=\"Worker \"+a,this.actors.push(s)}};function T(e,r,n){var i=function(i,a){if(i)return n(i);if(a){var o=t.pick(a,[\"tiles\",\"minzoom\",\"maxzoom\",\"attribution\",\"mapbox_logo\",\"bounds\"]);a.vector_layers&&(o.vectorLayers=a.vector_layers,o.vectorLayerIds=o.vectorLayers.map(function(t){return t.id})),e.url&&(o.tiles=r.canonicalizeTileset(o,e.url)),n(null,o)}};return e.url?t.getJSON(r.transformRequest(r.normalizeSourceURL(e.url),t.ResourceType.Source),i):t.browser.frame(function(){return i(null,e)})}k.prototype.broadcast=function(e,r,n){n=n||function(){},t.asyncAll(this.actors,function(t,n){t.send(e,r,n)},n)},k.prototype.send=function(t,e,r,n){return(\"number\"!=typeof n||isNaN(n))&&(n=this.currentActor=(this.currentActor+1)%this.actors.length),this.actors[n].send(t,e,r),n},k.prototype.remove=function(){this.actors.forEach(function(t){t.remove()}),this.actors=[],this.workerPool.release(this.id)},k.Actor=t.Actor;var A=function(e,r,n){this.bounds=t.LngLatBounds.convert(this.validateBounds(e)),this.minzoom=r||0,this.maxzoom=n||24};A.prototype.validateBounds=function(t){return Array.isArray(t)&&4===t.length?[Math.max(-180,t[0]),Math.max(-90,t[1]),Math.min(180,t[2]),Math.min(90,t[3])]:[-180,-90,180,90]},A.prototype.contains=function(e){var r=Math.pow(2,e.z),n=Math.floor(t.mercatorXfromLng(this.bounds.getWest())*r),i=Math.floor(t.mercatorYfromLat(this.bounds.getNorth())*r),a=Math.ceil(t.mercatorXfromLng(this.bounds.getEast())*r),o=Math.ceil(t.mercatorYfromLat(this.bounds.getSouth())*r);return e.x>=n&&e.x<a&&e.y>=i&&e.y<o};var M=function(e){function r(r,n,i,a){if(e.call(this),this.id=r,this.dispatcher=i,this.type=\"vector\",this.minzoom=0,this.maxzoom=22,this.scheme=\"xyz\",this.tileSize=512,this.reparseOverscaled=!0,this.isTileClipped=!0,t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"])),this._options=t.extend({type:\"vector\"},n),this._collectResourceTiming=n.collectResourceTiming,512!==this.tileSize)throw new Error(\"vector tile sources must have a tileSize of 512\");this.setEventedParent(a)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=T(this._options,this.map._requestManager,function(r,n){e._tileJSONRequest=null,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))})},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,null),i={request:this.map._requestManager.transformRequest(n,t.ResourceType.Tile),uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,tileSize:this.tileSize*e.tileID.overscaleFactor(),type:this.type,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes};function a(n,i){return e.aborted?r(null):n&&404!==n.status?r(n):(i&&i.resourceTiming&&(e.resourceTiming=i.resourceTiming),this.map._refreshExpiredTiles&&i&&e.setExpiryData(i),e.loadVectorData(i,this.map.painter),t.cacheEntryPossiblyAdded(this.dispatcher),r(null),void(e.reloadCallback&&(this.loadTile(e,e.reloadCallback),e.reloadCallback=null)))}i.request.collectResourceTiming=this._collectResourceTiming,void 0===e.workerID||\"expired\"===e.state?e.workerID=this.dispatcher.send(\"loadTile\",i,a.bind(this)):\"loading\"===e.state?e.reloadCallback=r:this.dispatcher.send(\"reloadTile\",i,a.bind(this),e.workerID)},r.prototype.abortTile=function(t){this.dispatcher.send(\"abortTile\",{uid:t.uid,type:this.type,source:this.id},void 0,t.workerID)},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.dispatcher.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},void 0,t.workerID)},r.prototype.hasTransition=function(){return!1},r}(t.Evented),S=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.dispatcher=i,this.setEventedParent(a),this.type=\"raster\",this.minzoom=0,this.maxzoom=22,this.roundZoom=!0,this.scheme=\"xyz\",this.tileSize=512,this._loaded=!1,this._options=t.extend({},n),t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"]))}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=T(this._options,this.map._requestManager,function(r,n){e._tileJSONRequest=null,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))})},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.loadTile=function(e,r){var n=this,i=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(i,t.ResourceType.Tile),function(i,a){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(i)e.state=\"errored\",r(i);else if(a){n.map._refreshExpiredTiles&&e.setExpiryData(a),delete a.cacheControl,delete a.expires;var o=n.map.painter.context,s=o.gl;e.texture=n.map.painter.getTileTexture(a.width),e.texture?e.texture.update(a,{useMipmap:!0}):(e.texture=new t.Texture(o,a,s.RGBA,{useMipmap:!0}),e.texture.bind(s.LINEAR,s.CLAMP_TO_EDGE,s.LINEAR_MIPMAP_NEAREST),o.extTextureFilterAnisotropic&&s.texParameterf(s.TEXTURE_2D,o.extTextureFilterAnisotropic.TEXTURE_MAX_ANISOTROPY_EXT,o.extTextureFilterAnisotropicMax)),e.state=\"loaded\",t.cacheEntryPossiblyAdded(n.dispatcher),r(null)}})},r.prototype.abortTile=function(t,e){t.request&&(t.request.cancel(),delete t.request),e()},r.prototype.unloadTile=function(t,e){t.texture&&this.map.painter.saveTileTexture(t.texture),e()},r.prototype.hasTransition=function(){return!1},r}(t.Evented),E=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),this.type=\"raster-dem\",this.maxzoom=22,this._options=t.extend({},n),this.encoding=n.encoding||\"mapbox\"}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.serialize=function(){return{type:\"raster-dem\",url:this.url,tileSize:this.tileSize,tiles:this.tiles,bounds:this.bounds,encoding:this.encoding}},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(n,t.ResourceType.Tile),function(n,i){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(n)e.state=\"errored\",r(n);else if(i){this.map._refreshExpiredTiles&&e.setExpiryData(i),delete i.cacheControl,delete i.expires;var a=t.browser.getImageData(i),o={uid:e.uid,coord:e.tileID,source:this.id,rawImageData:a,encoding:this.encoding};e.workerID&&\"expired\"!==e.state||(e.workerID=this.dispatcher.send(\"loadDEMTile\",o,function(t,n){t&&(e.state=\"errored\",r(t)),n&&(e.dem=n,e.needsHillshadePrepare=!0,e.state=\"loaded\",r(null))}.bind(this)))}}.bind(this)),e.neighboringTiles=this._getNeighboringTiles(e.tileID)},r.prototype._getNeighboringTiles=function(e){var r=e.canonical,n=Math.pow(2,r.z),i=(r.x-1+n)%n,a=0===r.x?e.wrap-1:e.wrap,o=(r.x+1+n)%n,s=r.x+1===n?e.wrap+1:e.wrap,l={};return l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y).key]={backfilled:!1},r.y>0&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y-1).key]={backfilled:!1}),r.y+1<n&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y+1).key]={backfilled:!1}),l},r.prototype.unloadTile=function(t){t.demTexture&&this.map.painter.saveTileTexture(t.demTexture),t.fbo&&(t.fbo.destroy(),delete t.fbo),t.dem&&delete t.dem,delete t.neighboringTiles,t.state=\"unloaded\",this.dispatcher.send(\"removeDEMTile\",{uid:t.uid,source:this.id},void 0,t.workerID)},r}(S),C=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.type=\"geojson\",this.minzoom=0,this.maxzoom=18,this.tileSize=512,this.isTileClipped=!0,this.reparseOverscaled=!0,this._removed=!1,this.dispatcher=i,this.setEventedParent(a),this._data=n.data,this._options=t.extend({},n),this._collectResourceTiming=n.collectResourceTiming,this._resourceTiming=[],void 0!==n.maxzoom&&(this.maxzoom=n.maxzoom),n.type&&(this.type=n.type),n.attribution&&(this.attribution=n.attribution);var o=t.EXTENT/this.tileSize;this.workerOptions=t.extend({source:this.id,cluster:n.cluster||!1,geojsonVtOptions:{buffer:(void 0!==n.buffer?n.buffer:128)*o,tolerance:(void 0!==n.tolerance?n.tolerance:.375)*o,extent:t.EXTENT,maxZoom:this.maxzoom,lineMetrics:n.lineMetrics||!1,generateId:n.generateId||!1},superclusterOptions:{maxZoom:void 0!==n.clusterMaxZoom?Math.min(n.clusterMaxZoom,this.maxzoom-1):this.maxzoom-1,extent:t.EXTENT,radius:(n.clusterRadius||50)*o,log:!1},clusterProperties:n.clusterProperties},n.workerOptions)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData(function(r){if(r)e.fire(new t.ErrorEvent(r));else{var n={dataType:\"source\",sourceDataType:\"metadata\"};e._collectResourceTiming&&e._resourceTiming&&e._resourceTiming.length>0&&(n.resourceTiming=e._resourceTiming,e._resourceTiming=[]),e.fire(new t.Event(\"data\",n))}})},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setData=function(e){var r=this;return this._data=e,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData(function(e){if(e)r.fire(new t.ErrorEvent(e));else{var n={dataType:\"source\",sourceDataType:\"content\"};r._collectResourceTiming&&r._resourceTiming&&r._resourceTiming.length>0&&(n.resourceTiming=r._resourceTiming,r._resourceTiming=[]),r.fire(new t.Event(\"data\",n))}}),this},r.prototype.getClusterExpansionZoom=function(t,e){return this.dispatcher.send(\"geojson.getClusterExpansionZoom\",{clusterId:t,source:this.id},e,this.workerID),this},r.prototype.getClusterChildren=function(t,e){return this.dispatcher.send(\"geojson.getClusterChildren\",{clusterId:t,source:this.id},e,this.workerID),this},r.prototype.getClusterLeaves=function(t,e,r,n){return this.dispatcher.send(\"geojson.getClusterLeaves\",{source:this.id,clusterId:t,limit:e,offset:r},n,this.workerID),this},r.prototype._updateWorkerData=function(e){var r=this,n=t.extend({},this.workerOptions),i=this._data;\"string\"==typeof i?(n.request=this.map._requestManager.transformRequest(t.browser.resolveURL(i),t.ResourceType.Source),n.request.collectResourceTiming=this._collectResourceTiming):n.data=JSON.stringify(i),this.workerID=this.dispatcher.send(this.type+\".loadData\",n,function(t,i){r._removed||i&&i.abandoned||(r._loaded=!0,i&&i.resourceTiming&&i.resourceTiming[r.id]&&(r._resourceTiming=i.resourceTiming[r.id].slice(0)),r.dispatcher.send(r.type+\".coalesce\",{source:n.source},null,r.workerID),e(t))},this.workerID)},r.prototype.loadTile=function(e,r){var n=this,i=void 0===e.workerID?\"loadTile\":\"reloadTile\",a={type:this.type,uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,maxZoom:this.maxzoom,tileSize:this.tileSize,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes};e.workerID=this.dispatcher.send(i,a,function(t,a){return e.unloadVectorData(),e.aborted?r(null):t?r(t):(e.loadVectorData(a,n.map.painter,\"reloadTile\"===i),r(null))},this.workerID)},r.prototype.abortTile=function(t){t.aborted=!0},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.dispatcher.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},null,t.workerID)},r.prototype.onRemove=function(){this._removed=!0,this.dispatcher.send(\"removeSource\",{type:this.type,source:this.id},null,this.workerID)},r.prototype.serialize=function(){return t.extend({},this._options,{type:this.type,data:this._data})},r.prototype.hasTransition=function(){return!1},r}(t.Evented),L=function(e){function r(t,r,n,i){e.call(this),this.id=t,this.dispatcher=n,this.coordinates=r.coordinates,this.type=\"image\",this.minzoom=0,this.maxzoom=22,this.tileSize=512,this.tiles={},this.setEventedParent(i),this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(e,r){var n=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this.url=this.options.url,t.getImage(this.map._requestManager.transformRequest(this.url,t.ResourceType.Image),function(i,a){i?n.fire(new t.ErrorEvent(i)):a&&(n.image=a,e&&(n.coordinates=e),r&&r(),n._finishLoading())})},r.prototype.updateImage=function(t){var e=this;return this.image&&t.url?(this.options.url=t.url,this.load(t.coordinates,function(){e.texture=null}),this):this},r.prototype._finishLoading=function(){this.map&&(this.setCoordinates(this.coordinates),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setCoordinates=function(e){var r=this;this.coordinates=e;var n=e.map(t.MercatorCoordinate.fromLngLat);this.tileID=function(e){for(var r=1/0,n=1/0,i=-1/0,a=-1/0,o=0,s=e;o<s.length;o+=1){var l=s[o];r=Math.min(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.x),a=Math.max(a,l.y)}var c=i-r,u=a-n,h=Math.max(c,u),f=Math.max(0,Math.floor(-Math.log(h)/Math.LN2)),p=Math.pow(2,f);return new t.CanonicalTileID(f,Math.floor((r+i)/2*p),Math.floor((n+a)/2*p))}(n),this.minzoom=this.maxzoom=this.tileID.z;var i=n.map(function(t){return r.tileID.getTilePoint(t)._round()});return this._boundsArray=new t.StructArrayLayout4i8,this._boundsArray.emplaceBack(i[0].x,i[0].y,0,0),this._boundsArray.emplaceBack(i[1].x,i[1].y,t.EXTENT,0),this._boundsArray.emplaceBack(i[3].x,i[3].y,0,t.EXTENT),this._boundsArray.emplaceBack(i[2].x,i[2].y,t.EXTENT,t.EXTENT),this.boundsBuffer&&(this.boundsBuffer.destroy(),delete this.boundsBuffer),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})),this},r.prototype.prepare=function(){if(0!==Object.keys(this.tiles).length&&this.image){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture||(this.texture=new t.Texture(e,this.image,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.loadTile=function(t,e){this.tileID&&this.tileID.equals(t.tileID.canonical)?(this.tiles[String(t.tileID.wrap)]=t,t.buckets={},e(null)):(t.state=\"errored\",e(null))},r.prototype.serialize=function(){return{type:\"image\",url:this.options.url,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return!1},r}(t.Evented),P=function(e){function r(t,r,n,i){e.call(this,t,r,n,i),this.roundZoom=!0,this.type=\"video\",this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this,r=this.options;this.urls=[];for(var n=0,i=r.urls;n<i.length;n+=1){var a=i[n];this.urls.push(this.map._requestManager.transformRequest(a,t.ResourceType.Source).url)}t.getVideo(this.urls,function(r,n){r?e.fire(new t.ErrorEvent(r)):n&&(e.video=n,e.video.loop=!0,e.video.addEventListener(\"playing\",function(){e.map.triggerRepaint()}),e.map&&e.video.play(),e._finishLoading())})},r.prototype.getVideo=function(){return this.video},r.prototype.onAdd=function(t){this.map||(this.map=t,this.load(),this.video&&(this.video.play(),this.setCoordinates(this.coordinates)))},r.prototype.prepare=function(){if(!(0===Object.keys(this.tiles).length||this.video.readyState<2)){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?this.video.paused||(this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE),r.texSubImage2D(r.TEXTURE_2D,0,0,0,r.RGBA,r.UNSIGNED_BYTE,this.video)):(this.texture=new t.Texture(e,this.video,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"video\",urls:this.urls,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this.video&&!this.video.paused},r}(L),O=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),n.coordinates?Array.isArray(n.coordinates)&&4===n.coordinates.length&&!n.coordinates.some(function(t){return!Array.isArray(t)||2!==t.length||t.some(function(t){return\"number\"!=typeof t})})||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"coordinates\" property must be an array of 4 longitude/latitude array pairs'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"coordinates\"'))),n.animate&&\"boolean\"!=typeof n.animate&&this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'optional \"animate\" property must be a boolean value'))),n.canvas?\"string\"==typeof n.canvas||n.canvas instanceof t.window.HTMLCanvasElement||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"canvas\" must be either a string representing the ID of the canvas element from which to read, or an HTMLCanvasElement instance'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"canvas\"'))),this.options=n,this.animate=void 0===n.animate||n.animate}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){this.canvas||(this.canvas=this.options.canvas instanceof t.window.HTMLCanvasElement?this.options.canvas:t.window.document.getElementById(this.options.canvas)),this.width=this.canvas.width,this.height=this.canvas.height,this._hasInvalidDimensions()?this.fire(new t.ErrorEvent(new Error(\"Canvas dimensions cannot be less than or equal to zero.\"))):(this.play=function(){this._playing=!0,this.map.triggerRepaint()},this.pause=function(){this._playing&&(this.prepare(),this._playing=!1)},this._finishLoading())},r.prototype.getCanvas=function(){return this.canvas},r.prototype.onAdd=function(t){this.map=t,this.load(),this.canvas&&this.animate&&this.play()},r.prototype.onRemove=function(){this.pause()},r.prototype.prepare=function(){var e=!1;if(this.canvas.width!==this.width&&(this.width=this.canvas.width,e=!0),this.canvas.height!==this.height&&(this.height=this.canvas.height,e=!0),!this._hasInvalidDimensions()&&0!==Object.keys(this.tiles).length){var r=this.map.painter.context,n=r.gl;for(var i in this.boundsBuffer||(this.boundsBuffer=r.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?(e||this._playing)&&this.texture.update(this.canvas,{premultiply:!0}):this.texture=new t.Texture(r,this.canvas,n.RGBA,{premultiply:!0}),this.tiles){var a=this.tiles[i];\"loaded\"!==a.state&&(a.state=\"loaded\",a.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"canvas\",coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this._playing},r.prototype._hasInvalidDimensions=function(){for(var t=0,e=[this.canvas.width,this.canvas.height];t<e.length;t+=1){var r=e[t];if(isNaN(r)||r<=0)return!0}return!1},r}(L),z={vector:M,raster:S,\"raster-dem\":E,geojson:C,video:P,image:L,canvas:O},I=function(e,r,n,i){var a=new z[r.type](e,r,n,i);if(a.id!==e)throw new Error(\"Expected Source id to be \"+e+\" instead of \"+a.id);return t.bindAll([\"load\",\"abort\",\"unload\",\"serialize\",\"prepare\"],a),a};function D(e,r){var n=t.identity([]);return t.translate(n,n,[1,1,0]),t.scale(n,n,[.5*e.width,.5*e.height,1]),t.multiply(n,n,e.calculatePosMatrix(r.toUnwrapped()))}function R(t,e,r,n,i){var a=function(t,e,r){if(t)for(var n=0,i=t;n<i.length;n+=1){var a=e[i[n]];if(a&&a.source===r&&\"fill-extrusion\"===a.type)return!0}else for(var o in e){var s=e[o];if(s.source===r&&\"fill-extrusion\"===s.type)return!0}return!1}(n&&n.layers,e,t.id),o=i.maxPitchScaleFactor(),s=t.tilesIn(r,o,a);s.sort(F);for(var l=[],c=0,u=s;c<u.length;c+=1){var h=u[c];l.push({wrappedTileID:h.tileID.wrapped().key,queryResults:h.tile.queryRenderedFeatures(e,t._state,h.queryGeometry,h.cameraQueryGeometry,h.scale,n,i,o,D(t.transform,h.tileID))})}var f=function(t){for(var e={},r={},n=0,i=t;n<i.length;n+=1){var a=i[n],o=a.queryResults,s=a.wrappedTileID,l=r[s]=r[s]||{};for(var c in o)for(var u=o[c],h=l[c]=l[c]||{},f=e[c]=e[c]||[],p=0,d=u;p<d.length;p+=1){var g=d[p];h[g.featureIndex]||(h[g.featureIndex]=!0,f.push(g))}}return e}(l);for(var p in f)f[p].forEach(function(e){var r=e.feature,n=t.getFeatureState(r.layer[\"source-layer\"],r.id);r.source=r.layer.source,r.layer[\"source-layer\"]&&(r.sourceLayer=r.layer[\"source-layer\"]),r.state=n});return f}function F(t,e){var r=t.tileID,n=e.tileID;return r.overscaledZ-n.overscaledZ||r.canonical.y-n.canonical.y||r.wrap-n.wrap||r.canonical.x-n.canonical.x}var B=function(t,e){this.max=t,this.onRemove=e,this.reset()};B.prototype.reset=function(){for(var t in this.data)for(var e=0,r=this.data[t];e<r.length;e+=1){var n=r[e];n.timeout&&clearTimeout(n.timeout),this.onRemove(n.value)}return this.data={},this.order=[],this},B.prototype.add=function(t,e,r){var n=this,i=t.wrapped().key;void 0===this.data[i]&&(this.data[i]=[]);var a={value:e,timeout:void 0};if(void 0!==r&&(a.timeout=setTimeout(function(){n.remove(t,a)},r)),this.data[i].push(a),this.order.push(i),this.order.length>this.max){var o=this._getAndRemoveByKey(this.order[0]);o&&this.onRemove(o)}return this},B.prototype.has=function(t){return t.wrapped().key in this.data},B.prototype.getAndRemove=function(t){return this.has(t)?this._getAndRemoveByKey(t.wrapped().key):null},B.prototype._getAndRemoveByKey=function(t){var e=this.data[t].shift();return e.timeout&&clearTimeout(e.timeout),0===this.data[t].length&&delete this.data[t],this.order.splice(this.order.indexOf(t),1),e.value},B.prototype.get=function(t){return this.has(t)?this.data[t.wrapped().key][0].value:null},B.prototype.remove=function(t,e){if(!this.has(t))return this;var r=t.wrapped().key,n=void 0===e?0:this.data[r].indexOf(e),i=this.data[r][n];return this.data[r].splice(n,1),i.timeout&&clearTimeout(i.timeout),0===this.data[r].length&&delete this.data[r],this.onRemove(i.value),this.order.splice(this.order.indexOf(r),1),this},B.prototype.setMaxSize=function(t){for(this.max=t;this.order.length>this.max;){var e=this._getAndRemoveByKey(this.order[0]);e&&this.onRemove(e)}return this};var N=function(t,e,r){this.context=t;var n=t.gl;this.buffer=n.createBuffer(),this.dynamicDraw=Boolean(r),this.context.unbindVAO(),t.bindElementBuffer.set(this.buffer),n.bufferData(n.ELEMENT_ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?n.DYNAMIC_DRAW:n.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};N.prototype.bind=function(){this.context.bindElementBuffer.set(this.buffer)},N.prototype.updateData=function(t){var e=this.context.gl;this.context.unbindVAO(),this.bind(),e.bufferSubData(e.ELEMENT_ARRAY_BUFFER,0,t.arrayBuffer)},N.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var j={Int8:\"BYTE\",Uint8:\"UNSIGNED_BYTE\",Int16:\"SHORT\",Uint16:\"UNSIGNED_SHORT\",Int32:\"INT\",Uint32:\"UNSIGNED_INT\",Float32:\"FLOAT\"},U=function(t,e,r,n){this.length=e.length,this.attributes=r,this.itemSize=e.bytesPerElement,this.dynamicDraw=n,this.context=t;var i=t.gl;this.buffer=i.createBuffer(),t.bindVertexBuffer.set(this.buffer),i.bufferData(i.ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?i.DYNAMIC_DRAW:i.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};U.prototype.bind=function(){this.context.bindVertexBuffer.set(this.buffer)},U.prototype.updateData=function(t){var e=this.context.gl;this.bind(),e.bufferSubData(e.ARRAY_BUFFER,0,t.arrayBuffer)},U.prototype.enableAttributes=function(t,e){for(var r=0;r<this.attributes.length;r++){var n=this.attributes[r],i=e.attributes[n.name];void 0!==i&&t.enableVertexAttribArray(i)}},U.prototype.setVertexAttribPointers=function(t,e,r){for(var n=0;n<this.attributes.length;n++){var i=this.attributes[n],a=e.attributes[i.name];void 0!==a&&t.vertexAttribPointer(a,i.components,t[j[i.type]],!1,this.itemSize,i.offset+this.itemSize*(r||0))}},U.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var V=function(t){this.gl=t.gl,this.default=this.getDefault(),this.current=this.default,this.dirty=!1};V.prototype.get=function(){return this.current},V.prototype.set=function(t){},V.prototype.getDefault=function(){return this.default},V.prototype.setDefault=function(){this.set(this.default)};var q=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.clearColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(V),H=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 1},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearDepth(t),this.current=t,this.dirty=!1)},e}(V),G=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearStencil(t),this.current=t,this.dirty=!1)},e}(V),Y=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return[!0,!0,!0,!0]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.colorMask(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(V),W=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthMask(t),this.current=t,this.dirty=!1)},e}(V),X=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 255},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.stencilMask(t),this.current=t,this.dirty=!1)},e}(V),Z=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return{func:this.gl.ALWAYS,ref:0,mask:255}},e.prototype.set=function(t){var e=this.current;(t.func!==e.func||t.ref!==e.ref||t.mask!==e.mask||this.dirty)&&(this.gl.stencilFunc(t.func,t.ref,t.mask),this.current=t,this.dirty=!1)},e}(V),J=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.KEEP,t.KEEP,t.KEEP]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||this.dirty)&&(this.gl.stencilOp(t[0],t[1],t[2]),this.current=t,this.dirty=!1)},e}(V),K=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.STENCIL_TEST):e.disable(e.STENCIL_TEST),this.current=t,this.dirty=!1}},e}(V),$=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return[0,1]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.depthRange(t[0],t[1]),this.current=t,this.dirty=!1)},e}(V),Q=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.DEPTH_TEST):e.disable(e.DEPTH_TEST),this.current=t,this.dirty=!1}},e}(V),tt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.LESS},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthFunc(t),this.current=t,this.dirty=!1)},e}(V),et=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.BLEND):e.disable(e.BLEND),this.current=t,this.dirty=!1}},e}(V),rt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.ONE,t.ZERO]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.blendFunc(t[0],t[1]),this.current=t,this.dirty=!1)},e}(V),nt=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.blendColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(V),it=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.FUNC_ADD},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.blendEquation(t),this.current=t,this.dirty=!1)},e}(V),at=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.CULL_FACE):e.disable(e.CULL_FACE),this.current=t,this.dirty=!1}},e}(V),ot=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.BACK},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.cullFace(t),this.current=t,this.dirty=!1)},e}(V),st=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.CCW},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.frontFace(t),this.current=t,this.dirty=!1)},e}(V),lt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.useProgram(t),this.current=t,this.dirty=!1)},e}(V),ct=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.TEXTURE0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.activeTexture(t),this.current=t,this.dirty=!1)},e}(V),ut=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[0,0,t.drawingBufferWidth,t.drawingBufferHeight]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.viewport(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(V),ht=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindFramebuffer(e.FRAMEBUFFER,t),this.current=t,this.dirty=!1}},e}(V),ft=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindRenderbuffer(e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(V),pt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindTexture(e.TEXTURE_2D,t),this.current=t,this.dirty=!1}},e}(V),dt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindBuffer(e.ARRAY_BUFFER,t),this.current=t,this.dirty=!1}},e}(V),gt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){var e=this.gl;e.bindBuffer(e.ELEMENT_ARRAY_BUFFER,t),this.current=t,this.dirty=!1},e}(V),vt=function(t){function e(e){t.call(this,e),this.vao=e.extVertexArrayObject}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){this.vao&&(t!==this.current||this.dirty)&&(this.vao.bindVertexArrayOES(t),this.current=t,this.dirty=!1)},e}(V),mt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 4},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_ALIGNMENT,t),this.current=t,this.dirty=!1}},e}(V),yt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_PREMULTIPLY_ALPHA_WEBGL,t),this.current=t,this.dirty=!1}},e}(V),xt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_FLIP_Y_WEBGL,t),this.current=t,this.dirty=!1}},e}(V),bt=function(t){function e(e,r){t.call(this,e),this.context=e,this.parent=r}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e}(V),_t=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.setDirty=function(){this.dirty=!0},e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferTexture2D(e.FRAMEBUFFER,e.COLOR_ATTACHMENT0,e.TEXTURE_2D,t,0),this.current=t,this.dirty=!1}},e}(bt),wt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferRenderbuffer(e.FRAMEBUFFER,e.DEPTH_ATTACHMENT,e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(bt),kt=function(t,e,r){this.context=t,this.width=e,this.height=r;var n=t.gl,i=this.framebuffer=n.createFramebuffer();this.colorAttachment=new _t(t,i),this.depthAttachment=new wt(t,i)};kt.prototype.destroy=function(){var t=this.context.gl,e=this.colorAttachment.get();e&&t.deleteTexture(e);var r=this.depthAttachment.get();r&&t.deleteRenderbuffer(r),t.deleteFramebuffer(this.framebuffer)};var Tt=function(t,e,r){this.func=t,this.mask=e,this.range=r};Tt.ReadOnly=!1,Tt.ReadWrite=!0,Tt.disabled=new Tt(519,Tt.ReadOnly,[0,1]);var At=function(t,e,r,n,i,a){this.test=t,this.ref=e,this.mask=r,this.fail=n,this.depthFail=i,this.pass=a};At.disabled=new At({func:519,mask:0},0,0,7680,7680,7680);var Mt=function(t,e,r){this.blendFunction=t,this.blendColor=e,this.mask=r};Mt.disabled=new Mt(Mt.Replace=[1,0],t.Color.transparent,[!1,!1,!1,!1]),Mt.unblended=new Mt(Mt.Replace,t.Color.transparent,[!0,!0,!0,!0]),Mt.alphaBlended=new Mt([1,771],t.Color.transparent,[!0,!0,!0,!0]);var St=function(t,e,r){this.enable=t,this.mode=e,this.frontFace=r};St.disabled=new St(!1,1029,2305),St.backCCW=new St(!0,1029,2305);var Et=function(t){this.gl=t,this.extVertexArrayObject=this.gl.getExtension(\"OES_vertex_array_object\"),this.clearColor=new q(this),this.clearDepth=new H(this),this.clearStencil=new G(this),this.colorMask=new Y(this),this.depthMask=new W(this),this.stencilMask=new X(this),this.stencilFunc=new Z(this),this.stencilOp=new J(this),this.stencilTest=new K(this),this.depthRange=new $(this),this.depthTest=new Q(this),this.depthFunc=new tt(this),this.blend=new et(this),this.blendFunc=new rt(this),this.blendColor=new nt(this),this.blendEquation=new it(this),this.cullFace=new at(this),this.cullFaceSide=new ot(this),this.frontFace=new st(this),this.program=new lt(this),this.activeTexture=new ct(this),this.viewport=new ut(this),this.bindFramebuffer=new ht(this),this.bindRenderbuffer=new ft(this),this.bindTexture=new pt(this),this.bindVertexBuffer=new dt(this),this.bindElementBuffer=new gt(this),this.bindVertexArrayOES=this.extVertexArrayObject&&new vt(this),this.pixelStoreUnpack=new mt(this),this.pixelStoreUnpackPremultiplyAlpha=new yt(this),this.pixelStoreUnpackFlipY=new xt(this),this.extTextureFilterAnisotropic=t.getExtension(\"EXT_texture_filter_anisotropic\")||t.getExtension(\"MOZ_EXT_texture_filter_anisotropic\")||t.getExtension(\"WEBKIT_EXT_texture_filter_anisotropic\"),this.extTextureFilterAnisotropic&&(this.extTextureFilterAnisotropicMax=t.getParameter(this.extTextureFilterAnisotropic.MAX_TEXTURE_MAX_ANISOTROPY_EXT)),this.extTextureHalfFloat=t.getExtension(\"OES_texture_half_float\"),this.extTextureHalfFloat&&t.getExtension(\"OES_texture_half_float_linear\")};Et.prototype.setDefault=function(){this.unbindVAO(),this.clearColor.setDefault(),this.clearDepth.setDefault(),this.clearStencil.setDefault(),this.colorMask.setDefault(),this.depthMask.setDefault(),this.stencilMask.setDefault(),this.stencilFunc.setDefault(),this.stencilOp.setDefault(),this.stencilTest.setDefault(),this.depthRange.setDefault(),this.depthTest.setDefault(),this.depthFunc.setDefault(),this.blend.setDefault(),this.blendFunc.setDefault(),this.blendColor.setDefault(),this.blendEquation.setDefault(),this.cullFace.setDefault(),this.cullFaceSide.setDefault(),this.frontFace.setDefault(),this.program.setDefault(),this.activeTexture.setDefault(),this.bindFramebuffer.setDefault(),this.pixelStoreUnpack.setDefault(),this.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.pixelStoreUnpackFlipY.setDefault()},Et.prototype.setDirty=function(){this.clearColor.dirty=!0,this.clearDepth.dirty=!0,this.clearStencil.dirty=!0,this.colorMask.dirty=!0,this.depthMask.dirty=!0,this.stencilMask.dirty=!0,this.stencilFunc.dirty=!0,this.stencilOp.dirty=!0,this.stencilTest.dirty=!0,this.depthRange.dirty=!0,this.depthTest.dirty=!0,this.depthFunc.dirty=!0,this.blend.dirty=!0,this.blendFunc.dirty=!0,this.blendColor.dirty=!0,this.blendEquation.dirty=!0,this.cullFace.dirty=!0,this.cullFaceSide.dirty=!0,this.frontFace.dirty=!0,this.program.dirty=!0,this.activeTexture.dirty=!0,this.viewport.dirty=!0,this.bindFramebuffer.dirty=!0,this.bindRenderbuffer.dirty=!0,this.bindTexture.dirty=!0,this.bindVertexBuffer.dirty=!0,this.bindElementBuffer.dirty=!0,this.extVertexArrayObject&&(this.bindVertexArrayOES.dirty=!0),this.pixelStoreUnpack.dirty=!0,this.pixelStoreUnpackPremultiplyAlpha.dirty=!0,this.pixelStoreUnpackFlipY.dirty=!0},Et.prototype.createIndexBuffer=function(t,e){return new N(this,t,e)},Et.prototype.createVertexBuffer=function(t,e,r){return new U(this,t,e,r)},Et.prototype.createRenderbuffer=function(t,e,r){var n=this.gl,i=n.createRenderbuffer();return this.bindRenderbuffer.set(i),n.renderbufferStorage(n.RENDERBUFFER,t,e,r),this.bindRenderbuffer.set(null),i},Et.prototype.createFramebuffer=function(t,e){return new kt(this,t,e)},Et.prototype.clear=function(t){var e=t.color,r=t.depth,n=this.gl,i=0;e&&(i|=n.COLOR_BUFFER_BIT,this.clearColor.set(e),this.colorMask.set([!0,!0,!0,!0])),void 0!==r&&(i|=n.DEPTH_BUFFER_BIT,this.depthRange.set([0,1]),this.clearDepth.set(r),this.depthMask.set(!0)),n.clear(i)},Et.prototype.setCullFace=function(t){!1===t.enable?this.cullFace.set(!1):(this.cullFace.set(!0),this.cullFaceSide.set(t.mode),this.frontFace.set(t.frontFace))},Et.prototype.setDepthMode=function(t){t.func!==this.gl.ALWAYS||t.mask?(this.depthTest.set(!0),this.depthFunc.set(t.func),this.depthMask.set(t.mask),this.depthRange.set(t.range)):this.depthTest.set(!1)},Et.prototype.setStencilMode=function(t){t.test.func!==this.gl.ALWAYS||t.mask?(this.stencilTest.set(!0),this.stencilMask.set(t.mask),this.stencilOp.set([t.fail,t.depthFail,t.pass]),this.stencilFunc.set({func:t.test.func,ref:t.ref,mask:t.test.mask})):this.stencilTest.set(!1)},Et.prototype.setColorMode=function(e){t.deepEqual(e.blendFunction,Mt.Replace)?this.blend.set(!1):(this.blend.set(!0),this.blendFunc.set(e.blendFunction),this.blendColor.set(e.blendColor)),this.colorMask.set(e.mask)},Et.prototype.unbindVAO=function(){this.extVertexArrayObject&&this.bindVertexArrayOES.set(null)};var Ct=function(e){function r(r,n,i){var a=this;e.call(this),this.id=r,this.dispatcher=i,this.on(\"data\",function(t){\"source\"===t.dataType&&\"metadata\"===t.sourceDataType&&(a._sourceLoaded=!0),a._sourceLoaded&&!a._paused&&\"source\"===t.dataType&&\"content\"===t.sourceDataType&&(a.reload(),a.transform&&a.update(a.transform))}),this.on(\"error\",function(){a._sourceErrored=!0}),this._source=I(r,n,i,this),this._tiles={},this._cache=new B(0,this._unloadTile.bind(this)),this._timers={},this._cacheTimers={},this._maxTileCacheSize=null,this._coveredTiles={},this._state=new t.SourceFeatureState}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.onAdd=function(t){this.map=t,this._maxTileCacheSize=t?t._maxTileCacheSize:null,this._source&&this._source.onAdd&&this._source.onAdd(t)},r.prototype.onRemove=function(t){this._source&&this._source.onRemove&&this._source.onRemove(t)},r.prototype.loaded=function(){if(this._sourceErrored)return!0;if(!this._sourceLoaded)return!1;for(var t in this._tiles){var e=this._tiles[t];if(\"loaded\"!==e.state&&\"errored\"!==e.state)return!1}return!0},r.prototype.getSource=function(){return this._source},r.prototype.pause=function(){this._paused=!0},r.prototype.resume=function(){if(this._paused){var t=this._shouldReloadOnResume;this._paused=!1,this._shouldReloadOnResume=!1,t&&this.reload(),this.transform&&this.update(this.transform)}},r.prototype._loadTile=function(t,e){return this._source.loadTile(t,e)},r.prototype._unloadTile=function(t){if(this._source.unloadTile)return this._source.unloadTile(t,function(){})},r.prototype._abortTile=function(t){if(this._source.abortTile)return this._source.abortTile(t,function(){})},r.prototype.serialize=function(){return this._source.serialize()},r.prototype.prepare=function(t){for(var e in this._source.prepare&&this._source.prepare(),this._state.coalesceChanges(this._tiles,this.map?this.map.painter:null),this._tiles){var r=this._tiles[e];r.upload(t),r.prepare(this.map.style.imageManager)}},r.prototype.getIds=function(){return Object.keys(this._tiles).map(Number).sort(Lt)},r.prototype.getRenderableIds=function(e){var r=this,n=[];for(var i in this._tiles)this._isIdRenderable(+i,e)&&n.push(+i);return e?n.sort(function(e,n){var i=r._tiles[e].tileID,a=r._tiles[n].tileID,o=new t.Point(i.canonical.x,i.canonical.y)._rotate(r.transform.angle),s=new t.Point(a.canonical.x,a.canonical.y)._rotate(r.transform.angle);return i.overscaledZ-a.overscaledZ||s.y-o.y||s.x-o.x}):n.sort(Lt)},r.prototype.hasRenderableParent=function(t){var e=this.findLoadedParent(t,0);return!!e&&this._isIdRenderable(e.tileID.key)},r.prototype._isIdRenderable=function(t,e){return this._tiles[t]&&this._tiles[t].hasData()&&!this._coveredTiles[t]&&(e||!this._tiles[t].holdingForFade())},r.prototype.reload=function(){if(this._paused)this._shouldReloadOnResume=!0;else for(var t in this._cache.reset(),this._tiles)\"errored\"!==this._tiles[t].state&&this._reloadTile(t,\"reloading\")},r.prototype._reloadTile=function(t,e){var r=this._tiles[t];r&&(\"loading\"!==r.state&&(r.state=e),this._loadTile(r,this._tileLoaded.bind(this,r,t,e)))},r.prototype._tileLoaded=function(e,r,n,i){if(i)return e.state=\"errored\",void(404!==i.status?this._source.fire(new t.ErrorEvent(i,{tile:e})):this.update(this.transform));e.timeAdded=t.browser.now(),\"expired\"===n&&(e.refreshedUponExpiration=!0),this._setTileReloadTimer(r,e),\"raster-dem\"===this.getSource().type&&e.dem&&this._backfillDEM(e),this._state.initializeTileState(e,this.map?this.map.painter:null),this._source.fire(new t.Event(\"data\",{dataType:\"source\",tile:e,coord:e.tileID}))},r.prototype._backfillDEM=function(t){for(var e=this.getRenderableIds(),r=0;r<e.length;r++){var n=e[r];if(t.neighboringTiles&&t.neighboringTiles[n]){var i=this.getTileByID(n);a(t,i),a(i,t)}}function a(t,e){t.needsHillshadePrepare=!0;var r=e.tileID.canonical.x-t.tileID.canonical.x,n=e.tileID.canonical.y-t.tileID.canonical.y,i=Math.pow(2,t.tileID.canonical.z),a=e.tileID.key;0===r&&0===n||Math.abs(n)>1||(Math.abs(r)>1&&(1===Math.abs(r+i)?r+=i:1===Math.abs(r-i)&&(r-=i)),e.dem&&t.dem&&(t.dem.backfillBorder(e.dem,r,n),t.neighboringTiles&&t.neighboringTiles[a]&&(t.neighboringTiles[a].backfilled=!0)))}},r.prototype.getTile=function(t){return this.getTileByID(t.key)},r.prototype.getTileByID=function(t){return this._tiles[t]},r.prototype.getZoom=function(t){return t.zoom+t.scaleZoom(t.tileSize/this._source.tileSize)},r.prototype._retainLoadedChildren=function(t,e,r,n){for(var i in this._tiles){var a=this._tiles[i];if(!(n[i]||!a.hasData()||a.tileID.overscaledZ<=e||a.tileID.overscaledZ>r)){for(var o=a.tileID;a&&a.tileID.overscaledZ>e+1;){var s=a.tileID.scaledTo(a.tileID.overscaledZ-1);(a=this._tiles[s.key])&&a.hasData()&&(o=s)}for(var l=o;l.overscaledZ>e;)if(t[(l=l.scaledTo(l.overscaledZ-1)).key]){n[o.key]=o;break}}}},r.prototype.findLoadedParent=function(t,e){for(var r=t.overscaledZ-1;r>=e;r--){var n=t.scaledTo(r);if(!n)return;var i=String(n.key),a=this._tiles[i];if(a&&a.hasData())return a;if(this._cache.has(n))return this._cache.get(n)}},r.prototype.updateCacheSize=function(t){var e=(Math.ceil(t.width/this._source.tileSize)+1)*(Math.ceil(t.height/this._source.tileSize)+1),r=Math.floor(5*e),n=\"number\"==typeof this._maxTileCacheSize?Math.min(this._maxTileCacheSize,r):r;this._cache.setMaxSize(n)},r.prototype.handleWrapJump=function(t){var e=(t-(void 0===this._prevLng?t:this._prevLng))/360,r=Math.round(e);if(this._prevLng=t,r){var n={};for(var i in this._tiles){var a=this._tiles[i];a.tileID=a.tileID.unwrapTo(a.tileID.wrap+r),n[a.tileID.key]=a}for(var o in this._tiles=n,this._timers)clearTimeout(this._timers[o]),delete this._timers[o];for(var s in this._tiles){var l=this._tiles[s];this._setTileReloadTimer(s,l)}}},r.prototype.update=function(e){var n=this;if(this.transform=e,this._sourceLoaded&&!this._paused){var i;this.updateCacheSize(e),this.handleWrapJump(this.transform.center.lng),this._coveredTiles={},this.used?this._source.tileID?i=e.getVisibleUnwrappedCoordinates(this._source.tileID).map(function(e){return new t.OverscaledTileID(e.canonical.z,e.wrap,e.canonical.z,e.canonical.x,e.canonical.y)}):(i=e.coveringTiles({tileSize:this._source.tileSize,minzoom:this._source.minzoom,maxzoom:this._source.maxzoom,roundZoom:this._source.roundZoom,reparseOverscaled:this._source.reparseOverscaled}),this._source.hasTile&&(i=i.filter(function(t){return n._source.hasTile(t)}))):i=[];var a=(this._source.roundZoom?Math.round:Math.floor)(this.getZoom(e)),o=Math.max(a-r.maxOverzooming,this._source.minzoom),s=Math.max(a+r.maxUnderzooming,this._source.minzoom),l=this._updateRetainedTiles(i,a);if(Pt(this._source.type)){for(var c={},u={},h=0,f=Object.keys(l);h<f.length;h+=1){var p=f[h],d=l[p],g=this._tiles[p];if(g&&!(g.fadeEndTime&&g.fadeEndTime<=t.browser.now())){var v=this.findLoadedParent(d,o);v&&(this._addTile(v.tileID),c[v.tileID.key]=v.tileID),u[p]=d}}for(var m in this._retainLoadedChildren(u,a,s,l),c)l[m]||(this._coveredTiles[m]=!0,l[m]=c[m])}for(var y in l)this._tiles[y].clearFadeHold();for(var x=0,b=t.keysDifference(this._tiles,l);x<b.length;x+=1){var _=b[x],w=this._tiles[_];w.hasSymbolBuckets&&!w.holdingForFade()?w.setHoldDuration(this.map._fadeDuration):w.hasSymbolBuckets&&!w.symbolFadeFinished()||this._removeTile(_)}}},r.prototype.releaseSymbolFadeTiles=function(){for(var t in this._tiles)this._tiles[t].holdingForFade()&&this._removeTile(t)},r.prototype._updateRetainedTiles=function(t,e){for(var n={},i={},a=Math.max(e-r.maxOverzooming,this._source.minzoom),o=Math.max(e+r.maxUnderzooming,this._source.minzoom),s={},l=0,c=t;l<c.length;l+=1){var u=c[l],h=this._addTile(u);n[u.key]=u,h.hasData()||e<this._source.maxzoom&&(s[u.key]=u)}this._retainLoadedChildren(s,e,o,n);for(var f=0,p=t;f<p.length;f+=1){var d=p[f],g=this._tiles[d.key];if(!g.hasData()){if(e+1>this._source.maxzoom){var v=d.children(this._source.maxzoom)[0],m=this.getTile(v);if(m&&m.hasData()){n[v.key]=v;continue}}else{var y=d.children(this._source.maxzoom);if(n[y[0].key]&&n[y[1].key]&&n[y[2].key]&&n[y[3].key])continue}for(var x=g.wasRequested(),b=d.overscaledZ-1;b>=a;--b){var _=d.scaledTo(b);if(i[_.key])break;if(i[_.key]=!0,!(g=this.getTile(_))&&x&&(g=this._addTile(_)),g&&(n[_.key]=_,x=g.wasRequested(),g.hasData()))break}}}return n},r.prototype._addTile=function(e){var r=this._tiles[e.key];if(r)return r;(r=this._cache.getAndRemove(e))&&(this._setTileReloadTimer(e.key,r),r.tileID=e,this._state.initializeTileState(r,this.map?this.map.painter:null),this._cacheTimers[e.key]&&(clearTimeout(this._cacheTimers[e.key]),delete this._cacheTimers[e.key],this._setTileReloadTimer(e.key,r)));var n=Boolean(r);return n||(r=new t.Tile(e,this._source.tileSize*e.overscaleFactor()),this._loadTile(r,this._tileLoaded.bind(this,r,e.key,r.state))),r?(r.uses++,this._tiles[e.key]=r,n||this._source.fire(new t.Event(\"dataloading\",{tile:r,coord:r.tileID,dataType:\"source\"})),r):null},r.prototype._setTileReloadTimer=function(t,e){var r=this;t in this._timers&&(clearTimeout(this._timers[t]),delete this._timers[t]);var n=e.getExpiryTimeout();n&&(this._timers[t]=setTimeout(function(){r._reloadTile(t,\"expired\"),delete r._timers[t]},n))},r.prototype._removeTile=function(t){var e=this._tiles[t];e&&(e.uses--,delete this._tiles[t],this._timers[t]&&(clearTimeout(this._timers[t]),delete this._timers[t]),e.uses>0||(e.hasData()?this._cache.add(e.tileID,e,e.getExpiryTimeout()):(e.aborted=!0,this._abortTile(e),this._unloadTile(e))))},r.prototype.clearTiles=function(){for(var t in this._shouldReloadOnResume=!1,this._paused=!1,this._tiles)this._removeTile(t);this._cache.reset()},r.prototype.tilesIn=function(e,r,n){var i=this,a=[],o=this.transform;if(!o)return a;for(var s=n?o.getCameraQueryGeometry(e):e,l=e.map(function(t){return o.pointCoordinate(t)}),c=s.map(function(t){return o.pointCoordinate(t)}),u=this.getIds(),h=1/0,f=1/0,p=-1/0,d=-1/0,g=0,v=c;g<v.length;g+=1){var m=v[g];h=Math.min(h,m.x),f=Math.min(f,m.y),p=Math.max(p,m.x),d=Math.max(d,m.y)}for(var y=function(e){var n=i._tiles[u[e]];if(!n.holdingForFade()){var s=n.tileID,g=Math.pow(2,o.zoom-n.tileID.overscaledZ),v=r*n.queryPadding*t.EXTENT/n.tileSize/g,m=[s.getTilePoint(new t.MercatorCoordinate(h,f)),s.getTilePoint(new t.MercatorCoordinate(p,d))];if(m[0].x-v<t.EXTENT&&m[0].y-v<t.EXTENT&&m[1].x+v>=0&&m[1].y+v>=0){var y=l.map(function(t){return s.getTilePoint(t)}),x=c.map(function(t){return s.getTilePoint(t)});a.push({tile:n,tileID:s,queryGeometry:y,cameraQueryGeometry:x,scale:g})}}},x=0;x<u.length;x++)y(x);return a},r.prototype.getVisibleCoordinates=function(t){for(var e=this,r=this.getRenderableIds(t).map(function(t){return e._tiles[t].tileID}),n=0,i=r;n<i.length;n+=1){var a=i[n];a.posMatrix=this.transform.calculatePosMatrix(a.toUnwrapped())}return r},r.prototype.hasTransition=function(){if(this._source.hasTransition())return!0;if(Pt(this._source.type))for(var e in this._tiles){var r=this._tiles[e];if(void 0!==r.fadeEndTime&&r.fadeEndTime>=t.browser.now())return!0}return!1},r.prototype.setFeatureState=function(t,e,r){t=t||\"_geojsonTileLayer\",this._state.updateState(t,e,r)},r.prototype.removeFeatureState=function(t,e,r){t=t||\"_geojsonTileLayer\",this._state.removeFeatureState(t,e,r)},r.prototype.getFeatureState=function(t,e){return t=t||\"_geojsonTileLayer\",this._state.getState(t,e)},r}(t.Evented);function Lt(t,e){return t%32-e%32||e-t}function Pt(t){return\"raster\"===t||\"image\"===t||\"video\"===t}function Ot(){return new t.window.Worker(Jn.workerUrl)}Ct.maxOverzooming=10,Ct.maxUnderzooming=3;var zt=function(){this.active={}};zt.prototype.acquire=function(t){if(!this.workers)for(this.workers=[];this.workers.length<zt.workerCount;)this.workers.push(new Ot);return this.active[t]=!0,this.workers.slice()},zt.prototype.release=function(t){delete this.active[t],0===Object.keys(this.active).length&&(this.workers.forEach(function(t){t.terminate()}),this.workers=null)};var It,Dt=Math.floor(t.browser.hardwareConcurrency/2);function Rt(e,r){var n={};for(var i in e)\"ref\"!==i&&(n[i]=e[i]);return t.refProperties.forEach(function(t){t in r&&(n[t]=r[t])}),n}function Ft(t){t=t.slice();for(var e=Object.create(null),r=0;r<t.length;r++)e[t[r].id]=t[r];for(var n=0;n<t.length;n++)\"ref\"in t[n]&&(t[n]=Rt(t[n],e[t[n].ref]));return t}zt.workerCount=Math.max(Math.min(Dt,6),1);var Bt={setStyle:\"setStyle\",addLayer:\"addLayer\",removeLayer:\"removeLayer\",setPaintProperty:\"setPaintProperty\",setLayoutProperty:\"setLayoutProperty\",setFilter:\"setFilter\",addSource:\"addSource\",removeSource:\"removeSource\",setGeoJSONSourceData:\"setGeoJSONSourceData\",setLayerZoomRange:\"setLayerZoomRange\",setLayerProperty:\"setLayerProperty\",setCenter:\"setCenter\",setZoom:\"setZoom\",setBearing:\"setBearing\",setPitch:\"setPitch\",setSprite:\"setSprite\",setGlyphs:\"setGlyphs\",setTransition:\"setTransition\",setLight:\"setLight\"};function Nt(t,e,r){r.push({command:Bt.addSource,args:[t,e[t]]})}function jt(t,e,r){e.push({command:Bt.removeSource,args:[t]}),r[t]=!0}function Ut(t,e,r,n){jt(t,r,n),Nt(t,e,r)}function Vt(e,r,n){var i;for(i in e[n])if(e[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;for(i in r[n])if(r[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;return!0}function qt(e,r,n,i,a,o){var s;for(s in r=r||{},e=e||{})e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}));for(s in r)r.hasOwnProperty(s)&&!e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}))}function Ht(t){return t.id}function Gt(t,e){return t[e.id]=e,t}var Yt=function(t,e,r){var n=this.boxCells=[],i=this.circleCells=[];this.xCellCount=Math.ceil(t/r),this.yCellCount=Math.ceil(e/r);for(var a=0;a<this.xCellCount*this.yCellCount;a++)n.push([]),i.push([]);this.circleKeys=[],this.boxKeys=[],this.bboxes=[],this.circles=[],this.width=t,this.height=e,this.xScale=this.xCellCount/t,this.yScale=this.yCellCount/e,this.boxUid=0,this.circleUid=0};function Wt(e,r,n,i,a){var o=t.create();return r?(t.scale(o,o,[1/a,1/a,1]),n||t.rotateZ(o,o,i.angle)):t.multiply(o,i.labelPlaneMatrix,e),o}function Xt(e,r,n,i,a){if(r){var o=t.clone(e);return t.scale(o,o,[a,a,1]),n||t.rotateZ(o,o,-i.angle),o}return i.glCoordMatrix}function Zt(e,r){var n=[e.x,e.y,0,1];ae(n,n,r);var i=n[3];return{point:new t.Point(n[0]/i,n[1]/i),signedDistanceFromCamera:i}}function Jt(t,e){var r=t[0]/t[3],n=t[1]/t[3];return r>=-e[0]&&r<=e[0]&&n>=-e[1]&&n<=e[1]}function Kt(e,r,n,i,a,o,s,l){var c=i?e.textSizeData:e.iconSizeData,u=t.evaluateSizeForZoom(c,n.transform.zoom),h=[256/n.width*2+1,256/n.height*2+1],f=i?e.text.dynamicLayoutVertexArray:e.icon.dynamicLayoutVertexArray;f.clear();for(var p=e.lineVertexArray,d=i?e.text.placedSymbolArray:e.icon.placedSymbolArray,g=n.transform.width/n.transform.height,v=!1,m=0;m<d.length;m++){var y=d.get(m);if(y.hidden||y.writingMode===t.WritingMode.vertical&&!v)ie(y.numGlyphs,f);else{v=!1;var x=[y.anchorX,y.anchorY,0,1];if(t.transformMat4(x,x,r),Jt(x,h)){var b=.5+x[3]/n.transform.cameraToCenterDistance*.5,_=t.evaluateSizeForFeature(c,u,y),w=s?_*b:_/b,k=new t.Point(y.anchorX,y.anchorY),T=Zt(k,a).point,A={},M=te(y,w,!1,l,r,a,o,e.glyphOffsetArray,p,f,T,k,A,g);v=M.useVertical,(M.notEnoughRoom||v||M.needsFlipping&&te(y,w,!0,l,r,a,o,e.glyphOffsetArray,p,f,T,k,A,g).notEnoughRoom)&&ie(y.numGlyphs,f)}else ie(y.numGlyphs,f)}}i?e.text.dynamicLayoutVertexBuffer.updateData(f):e.icon.dynamicLayoutVertexBuffer.updateData(f)}function $t(t,e,r,n,i,a,o,s,l,c,u,h){var f=s.glyphStartIndex+s.numGlyphs,p=s.lineStartIndex,d=s.lineStartIndex+s.lineLength,g=e.getoffsetX(s.glyphStartIndex),v=e.getoffsetX(f-1),m=re(t*g,r,n,i,a,o,s.segment,p,d,l,c,u,h);if(!m)return null;var y=re(t*v,r,n,i,a,o,s.segment,p,d,l,c,u,h);return y?{first:m,last:y}:null}function Qt(e,r,n,i){return e===t.WritingMode.horizontal&&Math.abs(n.y-r.y)>Math.abs(n.x-r.x)*i?{useVertical:!0}:(e===t.WritingMode.vertical?r.y<n.y:r.x>n.x)?{needsFlipping:!0}:null}function te(e,r,n,i,a,o,s,l,c,u,h,f,p,d){var g,v=r/24,m=e.lineOffsetX*v,y=e.lineOffsetY*v;if(e.numGlyphs>1){var x=e.glyphStartIndex+e.numGlyphs,b=e.lineStartIndex,_=e.lineStartIndex+e.lineLength,w=$t(v,l,m,y,n,h,f,e,c,o,p,!1);if(!w)return{notEnoughRoom:!0};var k=Zt(w.first.point,s).point,T=Zt(w.last.point,s).point;if(i&&!n){var A=Qt(e.writingMode,k,T,d);if(A)return A}g=[w.first];for(var M=e.glyphStartIndex+1;M<x-1;M++)g.push(re(v*l.getoffsetX(M),m,y,n,h,f,e.segment,b,_,c,o,p,!1));g.push(w.last)}else{if(i&&!n){var S=Zt(f,a).point,E=e.lineStartIndex+e.segment+1,C=new t.Point(c.getx(E),c.gety(E)),L=Zt(C,a),P=L.signedDistanceFromCamera>0?L.point:ee(f,C,S,1,a),O=Qt(e.writingMode,S,P,d);if(O)return O}var z=re(v*l.getoffsetX(e.glyphStartIndex),m,y,n,h,f,e.segment,e.lineStartIndex,e.lineStartIndex+e.lineLength,c,o,p,!1);if(!z)return{notEnoughRoom:!0};g=[z]}for(var I=0,D=g;I<D.length;I+=1){var R=D[I];t.addDynamicAttributes(u,R.point,R.angle)}return{}}function ee(t,e,r,n,i){var a=Zt(t.add(t.sub(e)._unit()),i).point,o=r.sub(a);return r.add(o._mult(n/o.mag()))}function re(e,r,n,i,a,o,s,l,c,u,h,f,p){var d=i?e-r:e+r,g=d>0?1:-1,v=0;i&&(g*=-1,v=Math.PI),g<0&&(v+=Math.PI);for(var m=g>0?l+s:l+s+1,y=m,x=a,b=a,_=0,w=0,k=Math.abs(d);_+w<=k;){if((m+=g)<l||m>=c)return null;if(b=x,void 0===(x=f[m])){var T=new t.Point(u.getx(m),u.gety(m)),A=Zt(T,h);if(A.signedDistanceFromCamera>0)x=f[m]=A.point;else{var M=m-g;x=ee(0===_?o:new t.Point(u.getx(M),u.gety(M)),T,b,k-_+1,h)}}_+=w,w=b.dist(x)}var S=(k-_)/w,E=x.sub(b),C=E.mult(S)._add(b);return C._add(E._unit()._perp()._mult(n*g)),{point:C,angle:v+Math.atan2(x.y-b.y,x.x-b.x),tileDistance:p?{prevTileDistance:m-g===y?0:u.gettileUnitDistanceFromAnchor(m-g),lastSegmentViewportDistance:k-_}:null}}Yt.prototype.keysLength=function(){return this.boxKeys.length+this.circleKeys.length},Yt.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertBoxCell,this.boxUid++),this.boxKeys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},Yt.prototype.insertCircle=function(t,e,r,n){this._forEachCell(e-n,r-n,e+n,r+n,this._insertCircleCell,this.circleUid++),this.circleKeys.push(t),this.circles.push(e),this.circles.push(r),this.circles.push(n)},Yt.prototype._insertBoxCell=function(t,e,r,n,i,a){this.boxCells[i].push(a)},Yt.prototype._insertCircleCell=function(t,e,r,n,i,a){this.circleCells[i].push(a)},Yt.prototype._query=function(t,e,r,n,i,a){if(r<0||t>this.width||n<0||e>this.height)return!i&&[];var o=[];if(t<=0&&e<=0&&this.width<=r&&this.height<=n){if(i)return!0;for(var s=0;s<this.boxKeys.length;s++)o.push({key:this.boxKeys[s],x1:this.bboxes[4*s],y1:this.bboxes[4*s+1],x2:this.bboxes[4*s+2],y2:this.bboxes[4*s+3]});for(var l=0;l<this.circleKeys.length;l++){var c=this.circles[3*l],u=this.circles[3*l+1],h=this.circles[3*l+2];o.push({key:this.circleKeys[l],x1:c-h,y1:u-h,x2:c+h,y2:u+h})}return a?o.filter(a):o}var f={hitTest:i,seenUids:{box:{},circle:{}}};return this._forEachCell(t,e,r,n,this._queryCell,o,f,a),i?o.length>0:o},Yt.prototype._queryCircle=function(t,e,r,n,i){var a=t-r,o=t+r,s=e-r,l=e+r;if(o<0||a>this.width||l<0||s>this.height)return!n&&[];var c=[],u={hitTest:n,circle:{x:t,y:e,radius:r},seenUids:{box:{},circle:{}}};return this._forEachCell(a,s,o,l,this._queryCellCircle,c,u,i),n?c.length>0:c},Yt.prototype.query=function(t,e,r,n,i){return this._query(t,e,r,n,!1,i)},Yt.prototype.hitTest=function(t,e,r,n,i){return this._query(t,e,r,n,!0,i)},Yt.prototype.hitTestCircle=function(t,e,r,n){return this._queryCircle(t,e,r,!0,n)},Yt.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=o.seenUids,c=this.boxCells[i];if(null!==c)for(var u=this.bboxes,h=0,f=c;h<f.length;h+=1){var p=f[h];if(!l.box[p]){l.box[p]=!0;var d=4*p;if(t<=u[d+2]&&e<=u[d+3]&&r>=u[d+0]&&n>=u[d+1]&&(!s||s(this.boxKeys[p]))){if(o.hitTest)return a.push(!0),!0;a.push({key:this.boxKeys[p],x1:u[d],y1:u[d+1],x2:u[d+2],y2:u[d+3]})}}}var g=this.circleCells[i];if(null!==g)for(var v=this.circles,m=0,y=g;m<y.length;m+=1){var x=y[m];if(!l.circle[x]){l.circle[x]=!0;var b=3*x;if(this._circleAndRectCollide(v[b],v[b+1],v[b+2],t,e,r,n)&&(!s||s(this.circleKeys[x]))){if(o.hitTest)return a.push(!0),!0;var _=v[b],w=v[b+1],k=v[b+2];a.push({key:this.circleKeys[x],x1:_-k,y1:w-k,x2:_+k,y2:w+k})}}}},Yt.prototype._queryCellCircle=function(t,e,r,n,i,a,o,s){var l=o.circle,c=o.seenUids,u=this.boxCells[i];if(null!==u)for(var h=this.bboxes,f=0,p=u;f<p.length;f+=1){var d=p[f];if(!c.box[d]){c.box[d]=!0;var g=4*d;if(this._circleAndRectCollide(l.x,l.y,l.radius,h[g+0],h[g+1],h[g+2],h[g+3])&&(!s||s(this.boxKeys[d])))return a.push(!0),!0}}var v=this.circleCells[i];if(null!==v)for(var m=this.circles,y=0,x=v;y<x.length;y+=1){var b=x[y];if(!c.circle[b]){c.circle[b]=!0;var _=3*b;if(this._circlesCollide(m[_],m[_+1],m[_+2],l.x,l.y,l.radius)&&(!s||s(this.circleKeys[b])))return a.push(!0),!0}}},Yt.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToXCellCoord(t),c=this._convertToYCellCoord(e),u=this._convertToXCellCoord(r),h=this._convertToYCellCoord(n),f=l;f<=u;f++)for(var p=c;p<=h;p++){var d=this.xCellCount*p+f;if(i.call(this,t,e,r,n,d,a,o,s))return}},Yt.prototype._convertToXCellCoord=function(t){return Math.max(0,Math.min(this.xCellCount-1,Math.floor(t*this.xScale)))},Yt.prototype._convertToYCellCoord=function(t){return Math.max(0,Math.min(this.yCellCount-1,Math.floor(t*this.yScale)))},Yt.prototype._circlesCollide=function(t,e,r,n,i,a){var o=n-t,s=i-e,l=r+a;return l*l>o*o+s*s},Yt.prototype._circleAndRectCollide=function(t,e,r,n,i,a,o){var s=(a-n)/2,l=Math.abs(t-(n+s));if(l>s+r)return!1;var c=(o-i)/2,u=Math.abs(e-(i+c));if(u>c+r)return!1;if(l<=s||u<=c)return!0;var h=l-s,f=u-c;return h*h+f*f<=r*r};var ne=new Float32Array([-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0]);function ie(t,e){for(var r=0;r<t;r++){var n=e.length;e.resize(n+4),e.float32.set(ne,3*n)}}function ae(t,e,r){var n=e[0],i=e[1];return t[0]=r[0]*n+r[4]*i+r[12],t[1]=r[1]*n+r[5]*i+r[13],t[3]=r[3]*n+r[7]*i+r[15],t}var oe=function(t,e,r){void 0===e&&(e=new Yt(t.width+200,t.height+200,25)),void 0===r&&(r=new Yt(t.width+200,t.height+200,25)),this.transform=t,this.grid=e,this.ignoredGrid=r,this.pitchfactor=Math.cos(t._pitch)*t.cameraToCenterDistance,this.screenRightBoundary=t.width+100,this.screenBottomBoundary=t.height+100,this.gridRightBoundary=t.width+200,this.gridBottomBoundary=t.height+200};function se(t,e,r){t[e+4]=r?1:0}function le(e,r,n){return r*(t.EXTENT/(e.tileSize*Math.pow(2,n-e.tileID.overscaledZ)))}oe.prototype.placeCollisionBox=function(t,e,r,n,i){var a=this.projectAndGetPerspectiveRatio(n,t.anchorPointX,t.anchorPointY),o=r*a.perspectiveRatio,s=t.x1*o+a.point.x,l=t.y1*o+a.point.y,c=t.x2*o+a.point.x,u=t.y2*o+a.point.y;return!this.isInsideGrid(s,l,c,u)||!e&&this.grid.hitTest(s,l,c,u,i)?{box:[],offscreen:!1}:{box:[s,l,c,u],offscreen:this.isOffscreen(s,l,c,u)}},oe.prototype.approximateTileDistance=function(t,e,r,n,i){var a=i?1:n/this.pitchfactor,o=t.lastSegmentViewportDistance*r;return t.prevTileDistance+o+(a-1)*o*Math.abs(Math.sin(e))},oe.prototype.placeCollisionCircles=function(e,r,n,i,a,o,s,l,c,u,h,f,p){var d=[],g=this.projectAnchor(c,a.anchorX,a.anchorY),v=l/24,m=a.lineOffsetX*l,y=a.lineOffsetY*l,x=new t.Point(a.anchorX,a.anchorY),b=$t(v,s,m,y,!1,Zt(x,u).point,x,a,o,u,{},!0),_=!1,w=!1,k=!0,T=g.perspectiveRatio*i,A=1/(i*n),M=0,S=0;b&&(M=this.approximateTileDistance(b.first.tileDistance,b.first.angle,A,g.cameraDistance,f),S=this.approximateTileDistance(b.last.tileDistance,b.last.angle,A,g.cameraDistance,f));for(var E=0;E<e.length;E+=5){var C=e[E],L=e[E+1],P=e[E+2],O=e[E+3];if(!b||O<-M||O>S)se(e,E,!1);else{var z=this.projectPoint(c,C,L),I=P*T;if(d.length>0){var D=z.x-d[d.length-4],R=z.y-d[d.length-3];if(I*I*2>D*D+R*R&&E+8<e.length){var F=e[E+8];if(F>-M&&F<S){se(e,E,!1);continue}}}var B=E/5;d.push(z.x,z.y,I,B),se(e,E,!0);var N=z.x-I,j=z.y-I,U=z.x+I,V=z.y+I;if(k=k&&this.isOffscreen(N,j,U,V),w=w||this.isInsideGrid(N,j,U,V),!r&&this.grid.hitTestCircle(z.x,z.y,I,p)){if(!h)return{circles:[],offscreen:!1};_=!0}}}return{circles:_||!w?[]:d,offscreen:k}},oe.prototype.queryRenderedSymbols=function(e){if(0===e.length||0===this.grid.keysLength()&&0===this.ignoredGrid.keysLength())return{};for(var r=[],n=1/0,i=1/0,a=-1/0,o=-1/0,s=0,l=e;s<l.length;s+=1){var c=l[s],u=new t.Point(c.x+100,c.y+100);n=Math.min(n,u.x),i=Math.min(i,u.y),a=Math.max(a,u.x),o=Math.max(o,u.y),r.push(u)}for(var h={},f={},p=0,d=this.grid.query(n,i,a,o).concat(this.ignoredGrid.query(n,i,a,o));p<d.length;p+=1){var g=d[p],v=g.key;if(void 0===h[v.bucketInstanceId]&&(h[v.bucketInstanceId]={}),!h[v.bucketInstanceId][v.featureIndex]){var m=[new t.Point(g.x1,g.y1),new t.Point(g.x2,g.y1),new t.Point(g.x2,g.y2),new t.Point(g.x1,g.y2)];t.polygonIntersectsPolygon(r,m)&&(h[v.bucketInstanceId][v.featureIndex]=!0,void 0===f[v.bucketInstanceId]&&(f[v.bucketInstanceId]=[]),f[v.bucketInstanceId].push(v.featureIndex))}}return f},oe.prototype.insertCollisionBox=function(t,e,r,n,i){var a={bucketInstanceId:r,featureIndex:n,collisionGroupID:i};(e?this.ignoredGrid:this.grid).insert(a,t[0],t[1],t[2],t[3])},oe.prototype.insertCollisionCircles=function(t,e,r,n,i){for(var a=e?this.ignoredGrid:this.grid,o={bucketInstanceId:r,featureIndex:n,collisionGroupID:i},s=0;s<t.length;s+=4)a.insertCircle(o,t[s],t[s+1],t[s+2])},oe.prototype.projectAnchor=function(t,e,r){var n=[e,r,0,1];return ae(n,n,t),{perspectiveRatio:.5+this.transform.cameraToCenterDistance/n[3]*.5,cameraDistance:n[3]}},oe.prototype.projectPoint=function(e,r,n){var i=[r,n,0,1];return ae(i,i,e),new t.Point((i[0]/i[3]+1)/2*this.transform.width+100,(-i[1]/i[3]+1)/2*this.transform.height+100)},oe.prototype.projectAndGetPerspectiveRatio=function(e,r,n){var i=[r,n,0,1];return ae(i,i,e),{point:new t.Point((i[0]/i[3]+1)/2*this.transform.width+100,(-i[1]/i[3]+1)/2*this.transform.height+100),perspectiveRatio:.5+this.transform.cameraToCenterDistance/i[3]*.5}},oe.prototype.isOffscreen=function(t,e,r,n){return r<100||t>=this.screenRightBoundary||n<100||e>this.screenBottomBoundary},oe.prototype.isInsideGrid=function(t,e,r,n){return r>=0&&t<this.gridRightBoundary&&n>=0&&e<this.gridBottomBoundary};var ce=function(t,e,r,n){this.opacity=t?Math.max(0,Math.min(1,t.opacity+(t.placed?e:-e))):n&&r?1:0,this.placed=r};ce.prototype.isHidden=function(){return 0===this.opacity&&!this.placed};var ue=function(t,e,r,n,i){this.text=new ce(t?t.text:null,e,r,i),this.icon=new ce(t?t.icon:null,e,n,i)};ue.prototype.isHidden=function(){return this.text.isHidden()&&this.icon.isHidden()};var he=function(t,e,r){this.text=t,this.icon=e,this.skipFade=r},fe=function(t,e,r,n,i){this.bucketInstanceId=t,this.featureIndex=e,this.sourceLayerIndex=r,this.bucketIndex=n,this.tileID=i},pe=function(t){this.crossSourceCollisions=t,this.maxGroupID=0,this.collisionGroups={}};function de(e,r,n,i,a){var o=t.getAnchorAlignment(e),s=-(o.horizontalAlign-.5)*r,l=-(o.verticalAlign-.5)*n,c=t.evaluateRadialOffset(e,i);return new t.Point(s+c[0]*a,l+c[1]*a)}pe.prototype.get=function(t){if(this.crossSourceCollisions)return{ID:0,predicate:null};if(!this.collisionGroups[t]){var e=++this.maxGroupID;this.collisionGroups[t]={ID:e,predicate:function(t){return t.collisionGroupID===e}}}return this.collisionGroups[t]};var ge=function(t,e,r,n){this.transform=t.clone(),this.collisionIndex=new oe(this.transform),this.placements={},this.opacities={},this.variableOffsets={},this.stale=!1,this.commitTime=0,this.fadeDuration=e,this.retainedQueryData={},this.collisionGroups=new pe(r),this.prevPlacement=n,n&&(n.prevPlacement=void 0)};function ve(t,e,r,n,i){t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0)}ge.prototype.placeLayerTile=function(e,r,n,i){var a=r.getBucket(e),o=r.latestFeatureIndex;if(a&&o&&e.id===a.layerIds[0]){var s=r.collisionBoxArray,l=a.layers[0].layout,c=Math.pow(2,this.transform.zoom-r.tileID.overscaledZ),u=r.tileSize/t.EXTENT,h=this.transform.calculatePosMatrix(r.tileID.toUnwrapped()),f=Wt(h,\"map\"===l.get(\"text-pitch-alignment\"),\"map\"===l.get(\"text-rotation-alignment\"),this.transform,le(r,1,this.transform.zoom)),p=Wt(h,\"map\"===l.get(\"icon-pitch-alignment\"),\"map\"===l.get(\"icon-rotation-alignment\"),this.transform,le(r,1,this.transform.zoom));this.retainedQueryData[a.bucketInstanceId]=new fe(a.bucketInstanceId,o,a.sourceLayerIndex,a.index,r.tileID),this.placeLayerBucket(a,h,f,p,c,u,n,r.holdingForFade(),i,s)}},ge.prototype.attemptAnchorPlacement=function(e,r,n,i,a,o,s,l,c,u,h,f,p,d){var g,v=de(e,n,i,a,o),m=this.collisionIndex.placeCollisionBox(function(e,r,n,i,a,o){var s=e.x1,l=e.x2,c=e.y1,u=e.y2,h=e.anchorPointX,f=e.anchorPointY,p=new t.Point(r,n);return i&&p._rotate(a?o:-o),{x1:s+p.x,y1:c+p.y,x2:l+p.x,y2:u+p.y,anchorPointX:h,anchorPointY:f}}(r,v.x,v.y,s,l,this.transform.angle),f,c,u,h.predicate);if(m.box.length>0)return this.prevPlacement&&this.prevPlacement.variableOffsets[p.crossTileID]&&this.prevPlacement.placements[p.crossTileID]&&this.prevPlacement.placements[p.crossTileID].text&&(g=this.prevPlacement.variableOffsets[p.crossTileID].anchor),this.variableOffsets[p.crossTileID]={radialOffset:a,width:n,height:i,anchor:e,textBoxScale:o,prevAnchor:g},this.markUsedJustification(d,e,p),m},ge.prototype.placeLayerBucket=function(e,r,n,i,a,o,s,l,c,u){var h=this,f=e.layers[0].layout,p=t.evaluateSizeForZoom(e.textSizeData,this.transform.zoom),d=f.get(\"text-optional\"),g=f.get(\"icon-optional\"),v=f.get(\"text-allow-overlap\"),m=f.get(\"icon-allow-overlap\"),y=v&&(m||!e.hasIconData()||g),x=m&&(v||!e.hasTextData()||d),b=this.collisionGroups.get(e.sourceID),_=\"map\"===f.get(\"text-rotation-alignment\"),w=\"map\"===f.get(\"text-pitch-alignment\"),k=\"viewport-y\"===f.get(\"symbol-z-order\");!e.collisionArrays&&u&&e.deserializeCollisionBoxes(u);var T=function(i,u){if(!c[i.crossTileID])if(l)h.placements[i.crossTileID]=new he(!1,!1,!1);else{var m=!1,k=!1,T=!0,A=null,M=null,S=null,E=0,C=0;u.textFeatureIndex&&(E=u.textFeatureIndex);var L=u.textBox;if(L)if(f.get(\"text-variable-anchor\")){var P=L.x2-L.x1,O=L.y2-L.y1,z=i.textBoxScale,I=f.get(\"text-variable-anchor\");if(h.prevPlacement&&h.prevPlacement.variableOffsets[i.crossTileID]){var D=h.prevPlacement.variableOffsets[i.crossTileID];I[0]!==D.anchor&&(I=I.filter(function(t){return t!==D.anchor})).unshift(D.anchor)}for(var R=0,F=I;R<F.length;R+=1){var B=F[R];if(A=h.attemptAnchorPlacement(B,L,P,O,i.radialTextOffset,z,_,w,o,r,b,v,i,e)){m=!0;break}}if(!h.variableOffsets[i.crossTileID]&&h.prevPlacement){var N=h.prevPlacement.variableOffsets[i.crossTileID];N&&(h.variableOffsets[i.crossTileID]=N,h.markUsedJustification(e,N.anchor,i))}}else m=(A=h.collisionIndex.placeCollisionBox(L,f.get(\"text-allow-overlap\"),o,r,b.predicate)).box.length>0;T=A&&A.offscreen;var j=u.textCircles;if(j){var U=e.text.placedSymbolArray.get(i.centerJustifiedTextSymbolIndex),V=t.evaluateSizeForFeature(e.textSizeData,p,U);M=h.collisionIndex.placeCollisionCircles(j,f.get(\"text-allow-overlap\"),a,o,U,e.lineVertexArray,e.glyphOffsetArray,V,r,n,s,w,b.predicate),m=f.get(\"text-allow-overlap\")||M.circles.length>0,T=T&&M.offscreen}u.iconFeatureIndex&&(C=u.iconFeatureIndex),u.iconBox&&(k=(S=h.collisionIndex.placeCollisionBox(u.iconBox,f.get(\"icon-allow-overlap\"),o,r,b.predicate)).box.length>0,T=T&&S.offscreen);var q=d||0===i.numHorizontalGlyphVertices&&0===i.numVerticalGlyphVertices,H=g||0===i.numIconVertices;q||H?H?q||(k=k&&m):m=k&&m:k=m=k&&m,m&&A&&h.collisionIndex.insertCollisionBox(A.box,f.get(\"text-ignore-placement\"),e.bucketInstanceId,E,b.ID),k&&S&&h.collisionIndex.insertCollisionBox(S.box,f.get(\"icon-ignore-placement\"),e.bucketInstanceId,C,b.ID),m&&M&&h.collisionIndex.insertCollisionCircles(M.circles,f.get(\"text-ignore-placement\"),e.bucketInstanceId,E,b.ID),h.placements[i.crossTileID]=new he(m||y,k||x,T||e.justReloaded),c[i.crossTileID]=!0}};if(k)for(var A=e.getSortedSymbolIndexes(this.transform.angle),M=A.length-1;M>=0;--M){var S=A[M];T(e.symbolInstances.get(S),e.collisionArrays[S])}else for(var E=0;E<e.symbolInstances.length;++E)T(e.symbolInstances.get(E),e.collisionArrays[E]);e.justReloaded=!1},ge.prototype.markUsedJustification=function(e,r,n){var i={left:n.leftJustifiedTextSymbolIndex,center:n.centerJustifiedTextSymbolIndex,right:n.rightJustifiedTextSymbolIndex},a=i[t.getAnchorJustification(r)];for(var o in i){var s=i[o];s>=0&&(e.text.placedSymbolArray.get(s).crossTileID=a>=0&&s!==a?0:n.crossTileID)}},ge.prototype.commit=function(t){this.commitTime=t;var e=this.prevPlacement,r=!1,n=e&&0!==this.fadeDuration?(this.commitTime-e.commitTime)/this.fadeDuration:1,i=e?e.opacities:{},a=e?e.variableOffsets:{};for(var o in this.placements){var s=this.placements[o],l=i[o];l?(this.opacities[o]=new ue(l,n,s.text,s.icon),r=r||s.text!==l.text.placed||s.icon!==l.icon.placed):(this.opacities[o]=new ue(null,n,s.text,s.icon,s.skipFade),r=r||s.text||s.icon)}for(var c in i){var u=i[c];if(!this.opacities[c]){var h=new ue(u,n,!1,!1);h.isHidden()||(this.opacities[c]=h,r=r||u.text.placed||u.icon.placed)}}for(var f in a)this.variableOffsets[f]||!this.opacities[f]||this.opacities[f].isHidden()||(this.variableOffsets[f]=a[f]);r?this.lastPlacementChangeTime=t:\"number\"!=typeof this.lastPlacementChangeTime&&(this.lastPlacementChangeTime=e?e.lastPlacementChangeTime:t)},ge.prototype.updateLayerOpacities=function(t,e){for(var r={},n=0,i=e;n<i.length;n+=1){var a=i[n],o=a.getBucket(t);o&&a.latestFeatureIndex&&t.id===o.layerIds[0]&&this.updateBucketOpacities(o,r,a.collisionBoxArray)}},ge.prototype.updateBucketOpacities=function(e,r,n){e.hasTextData()&&e.text.opacityVertexArray.clear(),e.hasIconData()&&e.icon.opacityVertexArray.clear(),e.hasCollisionBoxData()&&e.collisionBox.collisionVertexArray.clear(),e.hasCollisionCircleData()&&e.collisionCircle.collisionVertexArray.clear();var i=e.layers[0].layout,a=new ue(null,0,!1,!1,!0),o=i.get(\"text-allow-overlap\"),s=i.get(\"icon-allow-overlap\"),l=i.get(\"text-variable-anchor\"),c=\"map\"===i.get(\"text-rotation-alignment\"),u=\"map\"===i.get(\"text-pitch-alignment\"),h=new ue(null,0,o&&(s||!e.hasIconData()||i.get(\"icon-optional\")),s&&(o||!e.hasTextData()||i.get(\"text-optional\")),!0);!e.collisionArrays&&n&&(e.hasCollisionBoxData()||e.hasCollisionCircleData())&&e.deserializeCollisionBoxes(n);for(var f=0;f<e.symbolInstances.length;f++){var p=e.symbolInstances.get(f),d=p.numHorizontalGlyphVertices,g=p.numVerticalGlyphVertices,v=p.crossTileID,m=r[v],y=this.opacities[v];m?y=a:y||(y=h,this.opacities[v]=y),r[v]=!0;var x=d>0||g>0,b=p.numIconVertices>0;if(x){for(var _=Te(y.text),w=(d+g)/4,k=0;k<w;k++)e.text.opacityVertexArray.emplaceBack(_);var T=y.text.isHidden()?1:0;[p.rightJustifiedTextSymbolIndex,p.centerJustifiedTextSymbolIndex,p.leftJustifiedTextSymbolIndex,p.verticalPlacedTextSymbolIndex].forEach(function(t){t>=0&&(e.text.placedSymbolArray.get(t).hidden=T)});var A=this.variableOffsets[p.crossTileID];A&&this.markUsedJustification(e,A.anchor,p)}if(b){for(var M=Te(y.icon),S=0;S<p.numIconVertices/4;S++)e.icon.opacityVertexArray.emplaceBack(M);e.icon.placedSymbolArray.get(f).hidden=y.icon.isHidden()}if(e.hasCollisionBoxData()||e.hasCollisionCircleData()){var E=e.collisionArrays[f];if(E){if(E.textBox){var C=new t.Point(0,0),L=!0;if(l){var P=this.variableOffsets[v];P?(C=de(P.anchor,P.width,P.height,P.radialOffset,P.textBoxScale),c&&C._rotate(u?this.transform.angle:-this.transform.angle)):L=!1}ve(e.collisionBox.collisionVertexArray,y.text.placed,!L,C.x,C.y)}E.iconBox&&ve(e.collisionBox.collisionVertexArray,y.icon.placed,!1);var O=E.textCircles;if(O&&e.hasCollisionCircleData())for(var z=0;z<O.length;z+=5){var I=m||0===O[z+4];ve(e.collisionCircle.collisionVertexArray,y.text.placed,I)}}}}e.sortFeatures(this.transform.angle),this.retainedQueryData[e.bucketInstanceId]&&(this.retainedQueryData[e.bucketInstanceId].featureSortOrder=e.featureSortOrder),e.hasTextData()&&e.text.opacityVertexBuffer&&e.text.opacityVertexBuffer.updateData(e.text.opacityVertexArray),e.hasIconData()&&e.icon.opacityVertexBuffer&&e.icon.opacityVertexBuffer.updateData(e.icon.opacityVertexArray),e.hasCollisionBoxData()&&e.collisionBox.collisionVertexBuffer&&e.collisionBox.collisionVertexBuffer.updateData(e.collisionBox.collisionVertexArray),e.hasCollisionCircleData()&&e.collisionCircle.collisionVertexBuffer&&e.collisionCircle.collisionVertexBuffer.updateData(e.collisionCircle.collisionVertexArray)},ge.prototype.symbolFadeChange=function(t){return 0===this.fadeDuration?1:(t-this.commitTime)/this.fadeDuration},ge.prototype.hasTransitions=function(t){return this.stale||t-this.lastPlacementChangeTime<this.fadeDuration},ge.prototype.stillRecent=function(t){return this.commitTime+this.fadeDuration>t},ge.prototype.setStale=function(){this.stale=!0};var me=Math.pow(2,25),ye=Math.pow(2,24),xe=Math.pow(2,17),be=Math.pow(2,16),_e=Math.pow(2,9),we=Math.pow(2,8),ke=Math.pow(2,1);function Te(t){if(0===t.opacity&&!t.placed)return 0;if(1===t.opacity&&t.placed)return 4294967295;var e=t.placed?1:0,r=Math.floor(127*t.opacity);return r*me+e*ye+r*xe+e*be+r*_e+e*we+r*ke+e}var Ae=function(){this._currentTileIndex=0,this._seenCrossTileIDs={}};Ae.prototype.continuePlacement=function(t,e,r,n,i){for(;this._currentTileIndex<t.length;){var a=t[this._currentTileIndex];if(e.placeLayerTile(n,a,r,this._seenCrossTileIDs),this._currentTileIndex++,i())return!0}};var Me=function(t,e,r,n,i,a,o){this.placement=new ge(t,i,a,o),this._currentPlacementIndex=e.length-1,this._forceFullPlacement=r,this._showCollisionBoxes=n,this._done=!1};Me.prototype.isDone=function(){return this._done},Me.prototype.continuePlacement=function(e,r,n){for(var i=this,a=t.browser.now(),o=function(){var e=t.browser.now()-a;return!i._forceFullPlacement&&e>2};this._currentPlacementIndex>=0;){var s=r[e[this._currentPlacementIndex]],l=this.placement.collisionIndex.transform.zoom;if(\"symbol\"===s.type&&(!s.minzoom||s.minzoom<=l)&&(!s.maxzoom||s.maxzoom>l)){if(this._inProgressLayer||(this._inProgressLayer=new Ae),this._inProgressLayer.continuePlacement(n[s.source],this.placement,this._showCollisionBoxes,s,o))return;delete this._inProgressLayer}this._currentPlacementIndex--}this._done=!0},Me.prototype.commit=function(t){return this.placement.commit(t),this.placement};var Se=512/t.EXTENT/2,Ee=function(t,e,r){this.tileID=t,this.indexedSymbolInstances={},this.bucketInstanceId=r;for(var n=0;n<e.length;n++){var i=e.get(n),a=i.key;this.indexedSymbolInstances[a]||(this.indexedSymbolInstances[a]=[]),this.indexedSymbolInstances[a].push({crossTileID:i.crossTileID,coord:this.getScaledCoordinates(i,t)})}};Ee.prototype.getScaledCoordinates=function(e,r){var n=r.canonical.z-this.tileID.canonical.z,i=Se/Math.pow(2,n);return{x:Math.floor((r.canonical.x*t.EXTENT+e.anchorX)*i),y:Math.floor((r.canonical.y*t.EXTENT+e.anchorY)*i)}},Ee.prototype.findMatches=function(t,e,r){for(var n=this.tileID.canonical.z<e.canonical.z?1:Math.pow(2,this.tileID.canonical.z-e.canonical.z),i=0;i<t.length;i++){var a=t.get(i);if(!a.crossTileID){var o=this.indexedSymbolInstances[a.key];if(o)for(var s=this.getScaledCoordinates(a,e),l=0,c=o;l<c.length;l+=1){var u=c[l];if(Math.abs(u.coord.x-s.x)<=n&&Math.abs(u.coord.y-s.y)<=n&&!r[u.crossTileID]){r[u.crossTileID]=!0,a.crossTileID=u.crossTileID;break}}}}};var Ce=function(){this.maxCrossTileID=0};Ce.prototype.generate=function(){return++this.maxCrossTileID};var Le=function(){this.indexes={},this.usedCrossTileIDs={},this.lng=0};Le.prototype.handleWrapJump=function(t){var e=Math.round((t-this.lng)/360);if(0!==e)for(var r in this.indexes){var n=this.indexes[r],i={};for(var a in n){var o=n[a];o.tileID=o.tileID.unwrapTo(o.tileID.wrap+e),i[o.tileID.key]=o}this.indexes[r]=i}this.lng=t},Le.prototype.addBucket=function(t,e,r){if(this.indexes[t.overscaledZ]&&this.indexes[t.overscaledZ][t.key]){if(this.indexes[t.overscaledZ][t.key].bucketInstanceId===e.bucketInstanceId)return!1;this.removeBucketCrossTileIDs(t.overscaledZ,this.indexes[t.overscaledZ][t.key])}for(var n=0;n<e.symbolInstances.length;n++)e.symbolInstances.get(n).crossTileID=0;this.usedCrossTileIDs[t.overscaledZ]||(this.usedCrossTileIDs[t.overscaledZ]={});var i=this.usedCrossTileIDs[t.overscaledZ];for(var a in this.indexes){var o=this.indexes[a];if(Number(a)>t.overscaledZ)for(var s in o){var l=o[s];l.tileID.isChildOf(t)&&l.findMatches(e.symbolInstances,t,i)}else{var c=o[t.scaledTo(Number(a)).key];c&&c.findMatches(e.symbolInstances,t,i)}}for(var u=0;u<e.symbolInstances.length;u++){var h=e.symbolInstances.get(u);h.crossTileID||(h.crossTileID=r.generate(),i[h.crossTileID]=!0)}return void 0===this.indexes[t.overscaledZ]&&(this.indexes[t.overscaledZ]={}),this.indexes[t.overscaledZ][t.key]=new Ee(t,e.symbolInstances,e.bucketInstanceId),!0},Le.prototype.removeBucketCrossTileIDs=function(t,e){for(var r in e.indexedSymbolInstances)for(var n=0,i=e.indexedSymbolInstances[r];n<i.length;n+=1){var a=i[n];delete this.usedCrossTileIDs[t][a.crossTileID]}},Le.prototype.removeStaleBuckets=function(t){var e=!1;for(var r in this.indexes){var n=this.indexes[r];for(var i in n)t[n[i].bucketInstanceId]||(this.removeBucketCrossTileIDs(r,n[i]),delete n[i],e=!0)}return e};var Pe=function(){this.layerIndexes={},this.crossTileIDs=new Ce,this.maxBucketInstanceId=0,this.bucketsInCurrentPlacement={}};Pe.prototype.addLayer=function(t,e,r){var n=this.layerIndexes[t.id];void 0===n&&(n=this.layerIndexes[t.id]=new Le);var i=!1,a={};n.handleWrapJump(r);for(var o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.getBucket(t);c&&t.id===c.layerIds[0]&&(c.bucketInstanceId||(c.bucketInstanceId=++this.maxBucketInstanceId),n.addBucket(l.tileID,c,this.crossTileIDs)&&(i=!0),a[c.bucketInstanceId]=!0)}return n.removeStaleBuckets(a)&&(i=!0),i},Pe.prototype.pruneUnusedLayers=function(t){var e={};for(var r in t.forEach(function(t){e[t]=!0}),this.layerIndexes)e[r]||delete this.layerIndexes[r]};var Oe=function(e,r){return t.emitValidationErrors(e,r&&r.filter(function(t){return\"source.canvas\"!==t.identifier}))},ze=t.pick(Bt,[\"addLayer\",\"removeLayer\",\"setPaintProperty\",\"setLayoutProperty\",\"setFilter\",\"addSource\",\"removeSource\",\"setLayerZoomRange\",\"setLight\",\"setTransition\",\"setGeoJSONSourceData\"]),Ie=t.pick(Bt,[\"setCenter\",\"setZoom\",\"setBearing\",\"setPitch\"]),De=function(e){function r(n,i){var a=this;void 0===i&&(i={}),e.call(this),this.map=n,this.dispatcher=new k((It||(It=new zt),It),this),this.imageManager=new f,this.imageManager.setEventedParent(this),this.glyphManager=new y(n._requestManager,i.localIdeographFontFamily),this.lineAtlas=new w(256,512),this.crossTileSymbolIndex=new Pe,this._layers={},this._order=[],this.sourceCaches={},this.zoomHistory=new t.ZoomHistory,this._loaded=!1,this._resetUpdates(),this.dispatcher.broadcast(\"setReferrer\",t.getReferrer());var o=this;this._rtlTextPluginCallback=r.registerForPluginAvailability(function(t){for(var e in o.dispatcher.broadcast(\"loadRTLTextPlugin\",t.pluginURL,t.completionCallback),o.sourceCaches)o.sourceCaches[e].reload()}),this.on(\"data\",function(t){if(\"source\"===t.dataType&&\"metadata\"===t.sourceDataType){var e=a.sourceCaches[t.sourceId];if(e){var r=e.getSource();if(r&&r.vectorLayerIds)for(var n in a._layers){var i=a._layers[n];i.source===r.id&&a._validateLayer(i)}}}})}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadURL=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"}));var i=\"boolean\"==typeof r.validate?r.validate:!t.isMapboxURL(e);e=this.map._requestManager.normalizeStyleURL(e,r.accessToken);var a=this.map._requestManager.transformRequest(e,t.ResourceType.Style);this._request=t.getJSON(a,function(e,r){n._request=null,e?n.fire(new t.ErrorEvent(e)):r&&n._load(r,i)})},r.prototype.loadJSON=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"})),this._request=t.browser.frame(function(){n._request=null,n._load(e,!1!==r.validate)})},r.prototype._load=function(e,r){var n=this;if(!r||!Oe(this,t.validateStyle(e))){for(var i in this._loaded=!0,this.stylesheet=e,e.sources)this.addSource(i,e.sources[i],{validate:!1});e.sprite?this._spriteRequest=function(e,r,n){var i,a,o,s=t.browser.devicePixelRatio>1?\"@2x\":\"\",l=t.getJSON(r.transformRequest(r.normalizeSpriteURL(e,s,\".json\"),t.ResourceType.SpriteJSON),function(t,e){l=null,o||(o=t,i=e,u())}),c=t.getImage(r.transformRequest(r.normalizeSpriteURL(e,s,\".png\"),t.ResourceType.SpriteImage),function(t,e){c=null,o||(o=t,a=e,u())});function u(){if(o)n(o);else if(i&&a){var e=t.browser.getImageData(a),r={};for(var s in i){var l=i[s],c=l.width,u=l.height,h=l.x,f=l.y,p=l.sdf,d=l.pixelRatio,g=new t.RGBAImage({width:c,height:u});t.RGBAImage.copy(e,g,{x:h,y:f},{x:0,y:0},{width:c,height:u}),r[s]={data:g,pixelRatio:d,sdf:p}}n(null,r)}}return{cancel:function(){l&&(l.cancel(),l=null),c&&(c.cancel(),c=null)}}}(e.sprite,this.map._requestManager,function(e,r){if(n._spriteRequest=null,e)n.fire(new t.ErrorEvent(e));else if(r)for(var i in r)n.imageManager.addImage(i,r[i]);n.imageManager.setLoaded(!0),n.fire(new t.Event(\"data\",{dataType:\"style\"}))}):this.imageManager.setLoaded(!0),this.glyphManager.setURL(e.glyphs);var a=Ft(this.stylesheet.layers);this._order=a.map(function(t){return t.id}),this._layers={};for(var o=0,s=a;o<s.length;o+=1){var l=s[o];(l=t.createStyleLayer(l)).setEventedParent(this,{layer:{id:l.id}}),this._layers[l.id]=l}this.dispatcher.broadcast(\"setLayers\",this._serializeLayers(this._order)),this.light=new _(this.stylesheet.light),this.fire(new t.Event(\"data\",{dataType:\"style\"})),this.fire(new t.Event(\"style.load\"))}},r.prototype._validateLayer=function(e){var r=this.sourceCaches[e.source];if(r){var n=e.sourceLayer;if(n){var i=r.getSource();(\"geojson\"===i.type||i.vectorLayerIds&&-1===i.vectorLayerIds.indexOf(n))&&this.fire(new t.ErrorEvent(new Error('Source layer \"'+n+'\" does not exist on source \"'+i.id+'\" as specified by style layer \"'+e.id+'\"')))}}},r.prototype.loaded=function(){if(!this._loaded)return!1;if(Object.keys(this._updatedSources).length)return!1;for(var t in this.sourceCaches)if(!this.sourceCaches[t].loaded())return!1;return!!this.imageManager.isLoaded()},r.prototype._serializeLayers=function(t){for(var e=[],r=0,n=t;r<n.length;r+=1){var i=n[r],a=this._layers[i];\"custom\"!==a.type&&e.push(a.serialize())}return e},r.prototype.hasTransitions=function(){if(this.light&&this.light.hasTransition())return!0;for(var t in this.sourceCaches)if(this.sourceCaches[t].hasTransition())return!0;for(var e in this._layers)if(this._layers[e].hasTransition())return!0;return!1},r.prototype._checkLoaded=function(){if(!this._loaded)throw new Error(\"Style is not done loading\")},r.prototype.update=function(e){if(this._loaded){var r=this._changed;if(this._changed){var n=Object.keys(this._updatedLayers),i=Object.keys(this._removedLayers);for(var a in(n.length||i.length)&&this._updateWorkerLayers(n,i),this._updatedSources){var o=this._updatedSources[a];\"reload\"===o?this._reloadSource(a):\"clear\"===o&&this._clearSource(a)}for(var s in this._updatedPaintProps)this._layers[s].updateTransitions(e);this.light.updateTransitions(e),this._resetUpdates()}for(var l in this.sourceCaches)this.sourceCaches[l].used=!1;for(var c=0,u=this._order;c<u.length;c+=1){var h=u[c],f=this._layers[h];f.recalculate(e),!f.isHidden(e.zoom)&&f.source&&(this.sourceCaches[f.source].used=!0)}this.light.recalculate(e),this.z=e.zoom,r&&this.fire(new t.Event(\"data\",{dataType:\"style\"}))}},r.prototype._updateWorkerLayers=function(t,e){this.dispatcher.broadcast(\"updateLayers\",{layers:this._serializeLayers(t),removedIds:e})},r.prototype._resetUpdates=function(){this._changed=!1,this._updatedLayers={},this._removedLayers={},this._updatedSources={},this._updatedPaintProps={}},r.prototype.setState=function(e){var r=this;if(this._checkLoaded(),Oe(this,t.validateStyle(e)))return!1;(e=t.clone$1(e)).layers=Ft(e.layers);var n=function(e,r){if(!e)return[{command:Bt.setStyle,args:[r]}];var n=[];try{if(!t.deepEqual(e.version,r.version))return[{command:Bt.setStyle,args:[r]}];t.deepEqual(e.center,r.center)||n.push({command:Bt.setCenter,args:[r.center]}),t.deepEqual(e.zoom,r.zoom)||n.push({command:Bt.setZoom,args:[r.zoom]}),t.deepEqual(e.bearing,r.bearing)||n.push({command:Bt.setBearing,args:[r.bearing]}),t.deepEqual(e.pitch,r.pitch)||n.push({command:Bt.setPitch,args:[r.pitch]}),t.deepEqual(e.sprite,r.sprite)||n.push({command:Bt.setSprite,args:[r.sprite]}),t.deepEqual(e.glyphs,r.glyphs)||n.push({command:Bt.setGlyphs,args:[r.glyphs]}),t.deepEqual(e.transition,r.transition)||n.push({command:Bt.setTransition,args:[r.transition]}),t.deepEqual(e.light,r.light)||n.push({command:Bt.setLight,args:[r.light]});var i={},a=[];!function(e,r,n,i){var a;for(a in r=r||{},e=e||{})e.hasOwnProperty(a)&&(r.hasOwnProperty(a)||jt(a,n,i));for(a in r)r.hasOwnProperty(a)&&(e.hasOwnProperty(a)?t.deepEqual(e[a],r[a])||(\"geojson\"===e[a].type&&\"geojson\"===r[a].type&&Vt(e,r,a)?n.push({command:Bt.setGeoJSONSourceData,args:[a,r[a].data]}):Ut(a,r,n,i)):Nt(a,r,n))}(e.sources,r.sources,a,i);var o=[];e.layers&&e.layers.forEach(function(t){i[t.source]?n.push({command:Bt.removeLayer,args:[t.id]}):o.push(t)}),n=n.concat(a),function(e,r,n){r=r||[];var i,a,o,s,l,c,u,h=(e=e||[]).map(Ht),f=r.map(Ht),p=e.reduce(Gt,{}),d=r.reduce(Gt,{}),g=h.slice(),v=Object.create(null);for(i=0,a=0;i<h.length;i++)o=h[i],d.hasOwnProperty(o)?a++:(n.push({command:Bt.removeLayer,args:[o]}),g.splice(g.indexOf(o,a),1));for(i=0,a=0;i<f.length;i++)o=f[f.length-1-i],g[g.length-1-i]!==o&&(p.hasOwnProperty(o)?(n.push({command:Bt.removeLayer,args:[o]}),g.splice(g.lastIndexOf(o,g.length-a),1)):a++,c=g[g.length-i],n.push({command:Bt.addLayer,args:[d[o],c]}),g.splice(g.length-i,0,o),v[o]=!0);for(i=0;i<f.length;i++)if(s=p[o=f[i]],l=d[o],!v[o]&&!t.deepEqual(s,l))if(t.deepEqual(s.source,l.source)&&t.deepEqual(s[\"source-layer\"],l[\"source-layer\"])&&t.deepEqual(s.type,l.type)){for(u in qt(s.layout,l.layout,n,o,null,Bt.setLayoutProperty),qt(s.paint,l.paint,n,o,null,Bt.setPaintProperty),t.deepEqual(s.filter,l.filter)||n.push({command:Bt.setFilter,args:[o,l.filter]}),t.deepEqual(s.minzoom,l.minzoom)&&t.deepEqual(s.maxzoom,l.maxzoom)||n.push({command:Bt.setLayerZoomRange,args:[o,l.minzoom,l.maxzoom]}),s)s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?qt(s[u],l[u],n,o,u.slice(6),Bt.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Bt.setLayerProperty,args:[o,u,l[u]]}));for(u in l)l.hasOwnProperty(u)&&!s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?qt(s[u],l[u],n,o,u.slice(6),Bt.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Bt.setLayerProperty,args:[o,u,l[u]]}))}else n.push({command:Bt.removeLayer,args:[o]}),c=g[g.lastIndexOf(o)+1],n.push({command:Bt.addLayer,args:[l,c]})}(o,r.layers,n)}catch(t){console.warn(\"Unable to compute style diff:\",t),n=[{command:Bt.setStyle,args:[r]}]}return n}(this.serialize(),e).filter(function(t){return!(t.command in Ie)});if(0===n.length)return!1;var i=n.filter(function(t){return!(t.command in ze)});if(i.length>0)throw new Error(\"Unimplemented: \"+i.map(function(t){return t.command}).join(\", \")+\".\");return n.forEach(function(t){\"setTransition\"!==t.command&&r[t.command].apply(r,t.args)}),this.stylesheet=e,!0},r.prototype.addImage=function(e,r){if(this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"An image with this name already exists.\")));this.imageManager.addImage(e,r),this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.updateImage=function(t,e){this.imageManager.updateImage(t,e)},r.prototype.getImage=function(t){return this.imageManager.getImage(t)},r.prototype.removeImage=function(e){if(!this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"No image with this name exists.\")));this.imageManager.removeImage(e),this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.listImages=function(){return this._checkLoaded(),this.imageManager.listImages()},r.prototype.addSource=function(e,r,n){var i=this;if(void 0===n&&(n={}),this._checkLoaded(),void 0!==this.sourceCaches[e])throw new Error(\"There is already a source with this ID\");if(!r.type)throw new Error(\"The type property must be defined, but the only the following properties were given: \"+Object.keys(r).join(\", \")+\".\");if(!([\"vector\",\"raster\",\"geojson\",\"video\",\"image\"].indexOf(r.type)>=0&&this._validate(t.validateStyle.source,\"sources.\"+e,r,null,n))){this.map&&this.map._collectResourceTiming&&(r.collectResourceTiming=!0);var a=this.sourceCaches[e]=new Ct(e,r,this.dispatcher);a.style=this,a.setEventedParent(this,function(){return{isSourceLoaded:i.loaded(),source:a.serialize(),sourceId:e}}),a.onAdd(this.map),this._changed=!0}},r.prototype.removeSource=function(e){if(this._checkLoaded(),void 0===this.sourceCaches[e])throw new Error(\"There is no source with this ID\");for(var r in this._layers)if(this._layers[r].source===e)return this.fire(new t.ErrorEvent(new Error('Source \"'+e+'\" cannot be removed while layer \"'+r+'\" is using it.')));var n=this.sourceCaches[e];delete this.sourceCaches[e],delete this._updatedSources[e],n.fire(new t.Event(\"data\",{sourceDataType:\"metadata\",dataType:\"source\",sourceId:e})),n.setEventedParent(null),n.clearTiles(),n.onRemove&&n.onRemove(this.map),this._changed=!0},r.prototype.setGeoJSONSourceData=function(t,e){this._checkLoaded(),this.sourceCaches[t].getSource().setData(e),this._changed=!0},r.prototype.getSource=function(t){return this.sourceCaches[t]&&this.sourceCaches[t].getSource()},r.prototype.addLayer=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=e.id;if(this.getLayer(i))this.fire(new t.ErrorEvent(new Error('Layer with id \"'+i+'\" already exists on this map')));else{var a;if(\"custom\"===e.type){if(Oe(this,t.validateCustomStyleLayer(e)))return;a=t.createStyleLayer(e)}else{if(\"object\"==typeof e.source&&(this.addSource(i,e.source),e=t.clone$1(e),e=t.extend(e,{source:i})),this._validate(t.validateStyle.layer,\"layers.\"+i,e,{arrayIndex:-1},n))return;a=t.createStyleLayer(e),this._validateLayer(a),a.setEventedParent(this,{layer:{id:i}})}var o=r?this._order.indexOf(r):this._order.length;if(r&&-1===o)this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.')));else{if(this._order.splice(o,0,i),this._layerOrderChanged=!0,this._layers[i]=a,this._removedLayers[i]&&a.source&&\"custom\"!==a.type){var s=this._removedLayers[i];delete this._removedLayers[i],s.type!==a.type?this._updatedSources[a.source]=\"clear\":(this._updatedSources[a.source]=\"reload\",this.sourceCaches[a.source].pause())}this._updateLayer(a),a.onAdd&&a.onAdd(this.map)}}},r.prototype.moveLayer=function(e,r){if(this._checkLoaded(),this._changed=!0,this._layers[e]){if(e!==r){var n=this._order.indexOf(e);this._order.splice(n,1);var i=r?this._order.indexOf(r):this._order.length;r&&-1===i?this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.'))):(this._order.splice(i,0,e),this._layerOrderChanged=!0)}}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be moved.\")))},r.prototype.removeLayer=function(e){this._checkLoaded();var r=this._layers[e];if(r){r.setEventedParent(null);var n=this._order.indexOf(e);this._order.splice(n,1),this._layerOrderChanged=!0,this._changed=!0,this._removedLayers[e]=r,delete this._layers[e],delete this._updatedLayers[e],delete this._updatedPaintProps[e],r.onRemove&&r.onRemove(this.map)}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be removed.\")))},r.prototype.getLayer=function(t){return this._layers[t]},r.prototype.setLayerZoomRange=function(e,r,n){this._checkLoaded();var i=this.getLayer(e);i?i.minzoom===r&&i.maxzoom===n||(null!=r&&(i.minzoom=r),null!=n&&(i.maxzoom=n),this._updateLayer(i)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot have zoom extent.\")))},r.prototype.setFilter=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=this.getLayer(e);if(i){if(!t.deepEqual(i.filter,r))return null==r?(i.filter=void 0,void this._updateLayer(i)):void(this._validate(t.validateStyle.filter,\"layers.\"+i.id+\".filter\",r,null,n)||(i.filter=t.clone$1(r),this._updateLayer(i)))}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be filtered.\")))},r.prototype.getFilter=function(e){return t.clone$1(this.getLayer(e).filter)},r.prototype.setLayoutProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getLayoutProperty(r),n)||(a.setLayoutProperty(r,n,i),this._updateLayer(a)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getLayoutProperty=function(e,r){var n=this.getLayer(e);if(n)return n.getLayoutProperty(r);this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style.\")))},r.prototype.setPaintProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getPaintProperty(r),n)||(a.setPaintProperty(r,n,i)&&this._updateLayer(a),this._changed=!0,this._updatedPaintProps[e]=!0):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getPaintProperty=function(t,e){return this.getLayer(t).getPaintProperty(e)},r.prototype.setFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=e.sourceLayer,a=this.sourceCaches[n],o=parseInt(e.id,10);if(void 0!==a){var s=a.getSource().type;\"geojson\"===s&&i?this.fire(new t.ErrorEvent(new Error(\"GeoJSON sources cannot have a sourceLayer parameter.\"))):\"vector\"!==s||i?isNaN(o)||o<0?this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided and non-negative.\"))):a.setFeatureState(i,o,r):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.removeFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=this.sourceCaches[n];if(void 0!==i){var a=i.getSource().type,o=\"vector\"===a?e.sourceLayer:void 0,s=parseInt(e.id,10);\"vector\"!==a||o?void 0!==e.id&&isNaN(s)||s<0?this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be non-negative.\"))):r&&\"string\"!=typeof e.id&&\"number\"!=typeof e.id?this.fire(new t.ErrorEvent(new Error(\"A feature id is requred to remove its specific state property.\"))):i.removeFeatureState(o,s,r):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.getFeatureState=function(e){this._checkLoaded();var r=e.source,n=e.sourceLayer,i=this.sourceCaches[r],a=parseInt(e.id,10);if(void 0!==i)if(\"vector\"!==i.getSource().type||n){if(!(isNaN(a)||a<0))return i.getFeatureState(n,a);this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided and non-negative.\")))}else this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")));else this.fire(new t.ErrorEvent(new Error(\"The source '\"+r+\"' does not exist in the map's style.\")))},r.prototype.getTransition=function(){return t.extend({duration:300,delay:0},this.stylesheet&&this.stylesheet.transition)},r.prototype.serialize=function(){return t.filterObject({version:this.stylesheet.version,name:this.stylesheet.name,metadata:this.stylesheet.metadata,light:this.stylesheet.light,center:this.stylesheet.center,zoom:this.stylesheet.zoom,bearing:this.stylesheet.bearing,pitch:this.stylesheet.pitch,sprite:this.stylesheet.sprite,glyphs:this.stylesheet.glyphs,transition:this.stylesheet.transition,sources:t.mapObject(this.sourceCaches,function(t){return t.serialize()}),layers:this._serializeLayers(this._order)},function(t){return void 0!==t})},r.prototype._updateLayer=function(t){this._updatedLayers[t.id]=!0,t.source&&!this._updatedSources[t.source]&&(this._updatedSources[t.source]=\"reload\",this.sourceCaches[t.source].pause()),this._changed=!0},r.prototype._flattenAndSortRenderedFeatures=function(t){for(var e=this,r=function(t){return\"fill-extrusion\"===e._layers[t].type},n={},i=[],a=this._order.length-1;a>=0;a--){var o=this._order[a];if(r(o)){n[o]=a;for(var s=0,l=t;s<l.length;s+=1){var c=l[s][o];if(c)for(var u=0,h=c;u<h.length;u+=1){var f=h[u];i.push(f)}}}}i.sort(function(t,e){return e.intersectionZ-t.intersectionZ});for(var p=[],d=this._order.length-1;d>=0;d--){var g=this._order[d];if(r(g))for(var v=i.length-1;v>=0;v--){var m=i[v].feature;if(n[m.layer.id]<d)break;p.push(m),i.pop()}else for(var y=0,x=t;y<x.length;y+=1){var b=x[y][g];if(b)for(var _=0,w=b;_<w.length;_+=1){var k=w[_];p.push(k.feature)}}}return p},r.prototype.queryRenderedFeatures=function(e,r,n){r&&r.filter&&this._validate(t.validateStyle.filter,\"queryRenderedFeatures.filter\",r.filter,null,r);var i={};if(r&&r.layers){if(!Array.isArray(r.layers))return this.fire(new t.ErrorEvent(new Error(\"parameters.layers must be an Array.\"))),[];for(var a=0,o=r.layers;a<o.length;a+=1){var s=o[a],l=this._layers[s];if(!l)return this.fire(new t.ErrorEvent(new Error(\"The layer '\"+s+\"' does not exist in the map's style and cannot be queried for features.\"))),[];i[l.source]=!0}}var c=[];for(var u in this.sourceCaches)r.layers&&!i[u]||c.push(R(this.sourceCaches[u],this._layers,e,r,n));return this.placement&&c.push(function(t,e,r,n,i,a){for(var o={},s=i.queryRenderedSymbols(r),l=[],c=0,u=Object.keys(s).map(Number);c<u.length;c+=1){var h=u[c];l.push(a[h])}l.sort(F);for(var f=function(){var e=d[p],r=e.featureIndex.lookupSymbolFeatures(s[e.bucketInstanceId],e.bucketIndex,e.sourceLayerIndex,n.filter,n.layers,t);for(var i in r){var a=o[i]=o[i]||[],l=r[i];l.sort(function(t,r){var n=e.featureSortOrder;if(n){var i=n.indexOf(t.featureIndex);return n.indexOf(r.featureIndex)-i}return r.featureIndex-t.featureIndex});for(var c=0,u=l;c<u.length;c+=1){var h=u[c];a.push(h)}}},p=0,d=l;p<d.length;p+=1)f();var g=function(r){o[r].forEach(function(n){var i=n.feature,a=t[r],o=e[a.source].getFeatureState(i.layer[\"source-layer\"],i.id);i.source=i.layer.source,i.layer[\"source-layer\"]&&(i.sourceLayer=i.layer[\"source-layer\"]),i.state=o})};for(var v in o)g(v);return o}(this._layers,this.sourceCaches,e,r,this.placement.collisionIndex,this.placement.retainedQueryData)),this._flattenAndSortRenderedFeatures(c)},r.prototype.querySourceFeatures=function(e,r){r&&r.filter&&this._validate(t.validateStyle.filter,\"querySourceFeatures.filter\",r.filter,null,r);var n=this.sourceCaches[e];return n?function(t,e){for(var r=t.getRenderableIds().map(function(e){return t.getTileByID(e)}),n=[],i={},a=0;a<r.length;a++){var o=r[a],s=o.tileID.canonical.key;i[s]||(i[s]=!0,o.querySourceFeatures(n,e))}return n}(n,r):[]},r.prototype.addSourceType=function(t,e,n){return r.getSourceType(t)?n(new Error('A source type called \"'+t+'\" already exists.')):(r.setSourceType(t,e),e.workerSourceURL?void this.dispatcher.broadcast(\"loadWorkerSource\",{name:t,url:e.workerSourceURL},n):n(null,null))},r.prototype.getLight=function(){return this.light.getLight()},r.prototype.setLight=function(e,r){void 0===r&&(r={}),this._checkLoaded();var n=this.light.getLight(),i=!1;for(var a in e)if(!t.deepEqual(e[a],n[a])){i=!0;break}if(i){var o={now:t.browser.now(),transition:t.extend({duration:300,delay:0},this.stylesheet.transition)};this.light.setLight(e,r),this.light.updateTransitions(o)}},r.prototype._validate=function(e,r,n,i,a){return void 0===a&&(a={}),(!a||!1!==a.validate)&&Oe(this,e.call(t.validateStyle,t.extend({key:r,style:this.serialize(),value:n,styleSpec:t.styleSpec},i)))},r.prototype._remove=function(){for(var e in this._request&&(this._request.cancel(),this._request=null),this._spriteRequest&&(this._spriteRequest.cancel(),this._spriteRequest=null),t.evented.off(\"pluginAvailable\",this._rtlTextPluginCallback),this.sourceCaches)this.sourceCaches[e].clearTiles();this.dispatcher.remove()},r.prototype._clearSource=function(t){this.sourceCaches[t].clearTiles()},r.prototype._reloadSource=function(t){this.sourceCaches[t].resume(),this.sourceCaches[t].reload()},r.prototype._updateSources=function(t){for(var e in this.sourceCaches)this.sourceCaches[e].update(t)},r.prototype._generateCollisionBoxes=function(){for(var t in this.sourceCaches)this._reloadSource(t)},r.prototype._updatePlacement=function(e,r,n,i){for(var a=!1,o=!1,s={},l=0,c=this._order;l<c.length;l+=1){var u=c[l],h=this._layers[u];if(\"symbol\"===h.type){if(!s[h.source]){var f=this.sourceCaches[h.source];s[h.source]=f.getRenderableIds(!0).map(function(t){return f.getTileByID(t)}).sort(function(t,e){return e.tileID.overscaledZ-t.tileID.overscaledZ||(t.tileID.isLessThan(e.tileID)?-1:1)})}var p=this.crossTileSymbolIndex.addLayer(h,s[h.source],e.center.lng);a=a||p}}this.crossTileSymbolIndex.pruneUnusedLayers(this._order);var d=this._layerOrderChanged||0===n;if((d||!this.pauseablePlacement||this.pauseablePlacement.isDone()&&!this.placement.stillRecent(t.browser.now()))&&(this.pauseablePlacement=new Me(e,this._order,d,r,n,i,this.placement),this._layerOrderChanged=!1),this.pauseablePlacement.isDone()?this.placement.setStale():(this.pauseablePlacement.continuePlacement(this._order,this._layers,s),this.pauseablePlacement.isDone()&&(this.placement=this.pauseablePlacement.commit(t.browser.now()),o=!0),a&&this.pauseablePlacement.placement.setStale()),o||a)for(var g=0,v=this._order;g<v.length;g+=1){var m=v[g],y=this._layers[m];\"symbol\"===y.type&&this.placement.updateLayerOpacities(y,s[y.source])}return!this.pauseablePlacement.isDone()||this.placement.hasTransitions(t.browser.now())},r.prototype._releaseSymbolFadeTiles=function(){for(var t in this.sourceCaches)this.sourceCaches[t].releaseSymbolFadeTiles()},r.prototype.getImages=function(t,e,r){this.imageManager.getImages(e.icons,r)},r.prototype.getGlyphs=function(t,e,r){this.glyphManager.getGlyphs(e.stacks,r)},r.prototype.getResource=function(e,r,n){return t.makeRequest(r,n)},r}(t.Evented);De.getSourceType=function(t){return z[t]},De.setSourceType=function(t,e){z[t]=e},De.registerForPluginAvailability=t.registerForPluginAvailability;var Re=t.createLayout([{name:\"a_pos\",type:\"Int16\",components:2}]),Fe=lr(\"#ifdef GL_ES\\nprecision mediump float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\",\"#ifdef GL_ES\\nprecision highp float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\\nvec2 unpack_float(const float packedValue) {int packedIntValue=int(packedValue);int v0=packedIntValue/256;return vec2(v0,packedIntValue-v0*256);}vec2 unpack_opacity(const float packedOpacity) {int intOpacity=int(packedOpacity)/2;return vec2(float(intOpacity)/127.0,mod(packedOpacity,2.0));}vec4 decode_color(const vec2 encodedColor) {return vec4(unpack_float(encodedColor[0])/255.0,unpack_float(encodedColor[1])/255.0\\n);}float unpack_mix_vec2(const vec2 packedValue,const float t) {return mix(packedValue[0],packedValue[1],t);}vec4 unpack_mix_color(const vec4 packedColors,const float t) {vec4 minColor=decode_color(vec2(packedColors[0],packedColors[1]));vec4 maxColor=decode_color(vec2(packedColors[2],packedColors[3]));return mix(minColor,maxColor,t);}vec2 get_pattern_pos(const vec2 pixel_coord_upper,const vec2 pixel_coord_lower,const vec2 pattern_size,const float tile_units_to_pixels,const vec2 pos) {vec2 offset=mod(mod(mod(pixel_coord_upper,pattern_size)*256.0,pattern_size)*256.0+pixel_coord_lower,pattern_size);return (tile_units_to_pixels*pos+offset)/pattern_size;}\"),Be=lr(\"uniform vec4 u_color;uniform float u_opacity;void main() {gl_FragColor=u_color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),Ne=lr(\"uniform vec2 u_pattern_tl_a;uniform vec2 u_pattern_br_a;uniform vec2 u_pattern_tl_b;uniform vec2 u_pattern_br_b;uniform vec2 u_texsize;uniform float u_mix;uniform float u_opacity;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(u_pattern_tl_a/u_texsize,u_pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(u_pattern_tl_b/u_texsize,u_pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_mix)*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pattern_size_a;uniform vec2 u_pattern_size_b;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_scale_a;uniform float u_scale_b;uniform float u_tile_units_to_pixels;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_a*u_pattern_size_a,u_tile_units_to_pixels,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_b*u_pattern_size_b,u_tile_units_to_pixels,a_pos);}\"),je=lr(\"varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=v_data.xy;float extrude_length=length(extrude);lowp float antialiasblur=v_data.z;float antialiased_blur=-max(blur,antialiasblur);float opacity_t=smoothstep(0.0,antialiased_blur,extrude_length-1.0);float color_t=stroke_width < 0.01 ? 0.0 : smoothstep(antialiased_blur,0.0,extrude_length-radius/(radius+stroke_width));gl_FragColor=opacity_t*mix(color*opacity,stroke_color*stroke_opacity,color_t);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform bool u_scale_with_map;uniform bool u_pitch_with_map;uniform vec2 u_extrude_scale;uniform lowp float u_device_pixel_ratio;uniform highp float u_camera_to_center_distance;attribute vec2 a_pos;varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main(void) {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=vec2(mod(a_pos,2.0)*2.0-1.0);vec2 circle_center=floor(a_pos*0.5);if (u_pitch_with_map) {vec2 corner_position=circle_center;if (u_scale_with_map) {corner_position+=extrude*(radius+stroke_width)*u_extrude_scale;} else {vec4 projected_center=u_matrix*vec4(circle_center,0,1);corner_position+=extrude*(radius+stroke_width)*u_extrude_scale*(projected_center.w/u_camera_to_center_distance);}gl_Position=u_matrix*vec4(corner_position,0,1);} else {gl_Position=u_matrix*vec4(circle_center,0,1);if (u_scale_with_map) {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*u_camera_to_center_distance;} else {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*gl_Position.w;}}lowp float antialiasblur=1.0/u_device_pixel_ratio/(radius+stroke_width);v_data=vec3(extrude.x,extrude.y,antialiasblur);}\"),Ue=lr(\"void main() {gl_FragColor=vec4(1.0);}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),Ve=lr(\"uniform highp float u_intensity;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main() {\\n#pragma mapbox: initialize highp float weight\\nfloat d=-0.5*3.0*3.0*dot(v_extrude,v_extrude);float val=weight*u_intensity*GAUSS_COEF*exp(d);gl_FragColor=vec4(val,1.0,1.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform float u_extrude_scale;uniform float u_opacity;uniform float u_intensity;attribute vec2 a_pos;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#pragma mapbox: define mediump float radius\\nconst highp float ZERO=1.0/255.0/16.0;\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main(void) {\\n#pragma mapbox: initialize highp float weight\\n#pragma mapbox: initialize mediump float radius\\nvec2 unscaled_extrude=vec2(mod(a_pos,2.0)*2.0-1.0);float S=sqrt(-2.0*log(ZERO/weight/u_intensity/GAUSS_COEF))/3.0;v_extrude=S*unscaled_extrude;vec2 extrude=v_extrude*radius*u_extrude_scale;vec4 pos=vec4(floor(a_pos*0.5)+extrude,0,1);gl_Position=u_matrix*pos;}\"),qe=lr(\"uniform sampler2D u_image;uniform sampler2D u_color_ramp;uniform float u_opacity;varying vec2 v_pos;void main() {float t=texture2D(u_image,v_pos).r;vec4 color=texture2D(u_color_ramp,vec2(t,0.5));gl_FragColor=color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(0.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;attribute vec2 a_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos*u_world,0,1);v_pos.x=a_pos.x;v_pos.y=1.0-a_pos.y;}\"),He=lr(\"varying float v_placed;varying float v_notUsed;void main() {float alpha=0.5;gl_FragColor=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {gl_FragColor=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {gl_FragColor*=.1;}}\",\"attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;attribute vec2 a_shift;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);gl_Position.xy+=(a_extrude+a_shift)*u_extrude_scale*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;}\"),Ge=lr(\"uniform float u_overscale_factor;varying float v_placed;varying float v_notUsed;varying float v_radius;varying vec2 v_extrude;varying vec2 v_extrude_scale;void main() {float alpha=0.5;vec4 color=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {color=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {color*=.2;}float extrude_scale_length=length(v_extrude_scale);float extrude_length=length(v_extrude)*extrude_scale_length;float stroke_width=15.0*extrude_scale_length/u_overscale_factor;float radius=v_radius*extrude_scale_length;float distance_to_edge=abs(extrude_length-radius);float opacity_t=smoothstep(-stroke_width,0.0,-distance_to_edge);gl_FragColor=opacity_t*color;}\",\"attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;varying float v_radius;varying vec2 v_extrude;varying vec2 v_extrude_scale;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);highp float padding_factor=1.2;gl_Position.xy+=a_extrude*u_extrude_scale*padding_factor*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;v_radius=abs(a_extrude.y);v_extrude=a_extrude*padding_factor;v_extrude_scale=u_extrude_scale*u_camera_to_center_distance*collision_perspective_ratio;}\"),Ye=lr(\"uniform highp vec4 u_color;void main() {gl_FragColor=u_color;}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),We=lr(\"#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_FragColor=color*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);}\"),Xe=lr(\"varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=outline_color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;uniform vec2 u_world;varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),Ze=lr(\"uniform vec2 u_texsize;uniform sampler2D u_image;uniform float u_fade;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);float dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=mix(color1,color2,u_fade)*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec4 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;gl_Position=u_matrix*vec4(a_pos,0,1);vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,a_pos);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),Je=lr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_fade)*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec4 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileZoomRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileZoomRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileZoomRatio,a_pos);}\"),Ke=lr(\"varying vec4 v_color;void main() {gl_FragColor=v_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;uniform float u_vertical_gradient;uniform lowp float u_opacity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec4 v_color;\\n#pragma mapbox: define highp float base\\n#pragma mapbox: define highp float height\\n#pragma mapbox: define highp vec4 color\\nvoid main() {\\n#pragma mapbox: initialize highp float base\\n#pragma mapbox: initialize highp float height\\n#pragma mapbox: initialize highp vec4 color\\nvec3 normal=a_normal_ed.xyz;base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);gl_Position=u_matrix*vec4(a_pos,t > 0.0 ? height : base,1);float colorvalue=color.r*0.2126+color.g*0.7152+color.b*0.0722;v_color=vec4(0.0,0.0,0.0,1.0);vec4 ambientlight=vec4(0.03,0.03,0.03,1.0);color+=ambientlight;float directional=clamp(dot(normal/16384.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((1.0-colorvalue+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_color.r+=clamp(color.r*directional*u_lightcolor.r,mix(0.0,0.3,1.0-u_lightcolor.r),1.0);v_color.g+=clamp(color.g*directional*u_lightcolor.g,mix(0.0,0.3,1.0-u_lightcolor.g),1.0);v_color.b+=clamp(color.b*directional*u_lightcolor.b,mix(0.0,0.3,1.0-u_lightcolor.b),1.0);v_color*=u_opacity;}\"),$e=lr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);vec4 mixedColor=mix(color1,color2,u_fade);gl_FragColor=mixedColor*v_lighting;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_height_factor;uniform vec4 u_scale;uniform float u_vertical_gradient;uniform lowp float u_opacity;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec3 normal=a_normal_ed.xyz;float edgedistance=a_normal_ed.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);float z=t > 0.0 ? height : base;gl_Position=u_matrix*vec4(a_pos,z,1);vec2 pos=normal.x==1.0 && normal.y==0.0 && normal.z==16384.0\\n? a_pos\\n: vec2(edgedistance,z*u_height_factor);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,pos);v_lighting=vec4(0.0,0.0,0.0,1.0);float directional=clamp(dot(normal/16383.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((0.5+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_lighting.rgb+=clamp(directional*u_lightcolor,mix(vec3(0.0),vec3(0.3),1.0-u_lightcolor),vec3(1.0));v_lighting*=u_opacity;}\"),Qe=lr(\"#ifdef GL_ES\\nprecision highp float;\\n#endif\\nuniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_dimension;uniform float u_zoom;uniform float u_maxzoom;float getElevation(vec2 coord,float bias) {vec4 data=texture2D(u_image,coord)*255.0;return (data.r+data.g*256.0+data.b*256.0*256.0)/4.0;}void main() {vec2 epsilon=1.0/u_dimension;float a=getElevation(v_pos+vec2(-epsilon.x,-epsilon.y),0.0);float b=getElevation(v_pos+vec2(0,-epsilon.y),0.0);float c=getElevation(v_pos+vec2(epsilon.x,-epsilon.y),0.0);float d=getElevation(v_pos+vec2(-epsilon.x,0),0.0);float e=getElevation(v_pos,0.0);float f=getElevation(v_pos+vec2(epsilon.x,0),0.0);float g=getElevation(v_pos+vec2(-epsilon.x,epsilon.y),0.0);float h=getElevation(v_pos+vec2(0,epsilon.y),0.0);float i=getElevation(v_pos+vec2(epsilon.x,epsilon.y),0.0);float exaggeration=u_zoom < 2.0 ? 0.4 : u_zoom < 4.5 ? 0.35 : 0.3;vec2 deriv=vec2((c+f+f+i)-(a+d+d+g),(g+h+h+i)-(a+b+b+c))/ pow(2.0,(u_zoom-u_maxzoom)*exaggeration+19.2562-u_zoom);gl_FragColor=clamp(vec4(deriv.x/2.0+0.5,deriv.y/2.0+0.5,1.0,1.0),0.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_dimension;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);highp vec2 epsilon=1.0/u_dimension;float scale=(u_dimension.x-2.0)/u_dimension.x;v_pos=(a_texture_pos/8192.0)*scale+epsilon;}\"),tr=lr(\"uniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_latrange;uniform vec2 u_light;uniform vec4 u_shadow;uniform vec4 u_highlight;uniform vec4 u_accent;\\n#define PI 3.141592653589793\\nvoid main() {vec4 pixel=texture2D(u_image,v_pos);vec2 deriv=((pixel.rg*2.0)-1.0);float scaleFactor=cos(radians((u_latrange[0]-u_latrange[1])*(1.0-v_pos.y)+u_latrange[1]));float slope=atan(1.25*length(deriv)/scaleFactor);float aspect=deriv.x !=0.0 ? atan(deriv.y,-deriv.x) : PI/2.0*(deriv.y > 0.0 ? 1.0 :-1.0);float intensity=u_light.x;float azimuth=u_light.y+PI;float base=1.875-intensity*1.75;float maxValue=0.5*PI;float scaledSlope=intensity !=0.5 ? ((pow(base,slope)-1.0)/(pow(base,maxValue)-1.0))*maxValue : slope;float accent=cos(scaledSlope);vec4 accent_color=(1.0-accent)*u_accent*clamp(intensity*2.0,0.0,1.0);float shade=abs(mod((aspect+azimuth)/PI+0.5,2.0)-1.0);vec4 shade_color=mix(u_shadow,u_highlight,shade)*sin(scaledSlope)*clamp(intensity*2.0,0.0,1.0);gl_FragColor=accent_color*(1.0-shade_color.a)+shade_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos=a_texture_pos/8192.0;}\"),er=lr(\"uniform lowp float u_device_pixel_ratio;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform vec2 u_units_to_pixels;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_linesofar;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),rr=lr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);vec4 color=texture2D(u_image,vec2(v_lineprogress,0.5));gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define MAX_LINE_DISTANCE 32767.0\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_lineprogress=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0/MAX_LINE_DISTANCE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),nr=lr(\"uniform lowp float u_device_pixel_ratio;uniform vec2 u_texsize;uniform float u_fade;uniform mediump vec4 u_scale;uniform sampler2D u_image;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileZoomRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);vec2 pattern_size_a=vec2(display_size_a.x*fromScale/tileZoomRatio,display_size_a.y);vec2 pattern_size_b=vec2(display_size_b.x*toScale/tileZoomRatio,display_size_b.y);float dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float x_a=mod(v_linesofar/pattern_size_a.x,1.0);float x_b=mod(v_linesofar/pattern_size_b.x,1.0);float y_a=0.5+(v_normal.y*clamp(v_width2.s,0.0,(pattern_size_a.y+2.0)/2.0)/pattern_size_a.y);float y_b=0.5+(v_normal.y*clamp(v_width2.s,0.0,(pattern_size_b.y+2.0)/2.0)/pattern_size_b.y);vec2 pos_a=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,vec2(x_a,y_a));vec2 pos_b=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,vec2(x_b,y_b));vec4 color=mix(texture2D(u_image,pos_a),texture2D(u_image,pos_b),u_fade);gl_FragColor=color*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform vec2 u_units_to_pixels;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_linesofar=a_linesofar;v_width2=vec2(outset,inset);}\"),ir=lr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;uniform float u_sdfgamma;uniform float u_mix;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float sdfdist_a=texture2D(u_image,v_tex_a).a;float sdfdist_b=texture2D(u_image,v_tex_b).a;float sdfdist=mix(sdfdist_a,sdfdist_b,u_mix);alpha*=smoothstep(0.5-u_sdfgamma/floorwidth,0.5+u_sdfgamma/floorwidth,sdfdist);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_patternscale_a;uniform float u_tex_y_a;uniform vec2 u_patternscale_b;uniform float u_tex_y_b;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_tex_a=vec2(a_linesofar*u_patternscale_a.x/floorwidth,normal.y*u_patternscale_a.y+u_tex_y_a);v_tex_b=vec2(a_linesofar*u_patternscale_b.x/floorwidth,normal.y*u_patternscale_b.y+u_tex_y_b);v_width2=vec2(outset,inset);}\"),ar=lr(\"uniform float u_fade_t;uniform float u_opacity;uniform sampler2D u_image0;uniform sampler2D u_image1;varying vec2 v_pos0;varying vec2 v_pos1;uniform float u_brightness_low;uniform float u_brightness_high;uniform float u_saturation_factor;uniform float u_contrast_factor;uniform vec3 u_spin_weights;void main() {vec4 color0=texture2D(u_image0,v_pos0);vec4 color1=texture2D(u_image1,v_pos1);if (color0.a > 0.0) {color0.rgb=color0.rgb/color0.a;}if (color1.a > 0.0) {color1.rgb=color1.rgb/color1.a;}vec4 color=mix(color0,color1,u_fade_t);color.a*=u_opacity;vec3 rgb=color.rgb;rgb=vec3(dot(rgb,u_spin_weights.xyz),dot(rgb,u_spin_weights.zxy),dot(rgb,u_spin_weights.yzx));float average=(color.r+color.g+color.b)/3.0;rgb+=(average-rgb)*u_saturation_factor;rgb=(rgb-0.5)*u_contrast_factor+0.5;vec3 u_high_vec=vec3(u_brightness_low,u_brightness_low,u_brightness_low);vec3 u_low_vec=vec3(u_brightness_high,u_brightness_high,u_brightness_high);gl_FragColor=vec4(mix(u_high_vec,u_low_vec,rgb)*color.a,color.a);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_tl_parent;uniform float u_scale_parent;uniform float u_buffer_scale;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos0;varying vec2 v_pos1;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos0=(((a_texture_pos/8192.0)-0.5)/u_buffer_scale )+0.5;v_pos1=(v_pos0*u_scale_parent)+u_tl_parent;}\"),or=lr(\"uniform sampler2D u_texture;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nlowp float alpha=opacity*v_fade_opacity;gl_FragColor=texture2D(u_texture,v_tex)*alpha;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform highp float u_camera_to_center_distance;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform float u_fade_change;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform vec2 u_texsize;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size[0],a_size[1],u_size_t)/256.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size[0]/256.0;} else if (!u_is_size_zoom_constant && u_is_size_feature_constant) {size=u_size;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);v_tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;v_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));}\"),sr=lr(\"#define SDF_PX 8.0\\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;uniform bool u_is_text;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nfloat EDGE_GAMMA=0.105/u_device_pixel_ratio;vec2 tex=v_data0.xy;float gamma_scale=v_data1.x;float size=v_data1.y;float fade_opacity=v_data1[2];float fontScale=u_is_text ? size/24.0 : size;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size[0],a_size[1],u_size_t)/256.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size[0]/256.0;} else if (!u_is_size_zoom_constant && u_is_size_feature_constant) {size=u_size;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);float gamma_scale=gl_Position.w;vec2 tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));v_data0=vec2(tex.x,tex.y);v_data1=vec3(gamma_scale,size,interpolated_fade_opacity);}\");function lr(t,e){var r=/#pragma mapbox: ([\\w]+) ([\\w]+) ([\\w]+) ([\\w]+)/g,n={};return{fragmentSource:t=t.replace(r,function(t,e,r,i,a){return n[a]=!0,\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"\\n#ifdef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"}),vertexSource:e=e.replace(r,function(t,e,r,i,a){var o=\"float\"===i?\"vec2\":\"vec4\",s=a.match(/color/)?\"color\":o;return n[a]?\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"})}}var cr=Object.freeze({prelude:Fe,background:Be,backgroundPattern:Ne,circle:je,clippingMask:Ue,heatmap:Ve,heatmapTexture:qe,collisionBox:He,collisionCircle:Ge,debug:Ye,fill:We,fillOutline:Xe,fillOutlinePattern:Ze,fillPattern:Je,fillExtrusion:Ke,fillExtrusionPattern:$e,hillshadePrepare:Qe,hillshade:tr,line:er,lineGradient:rr,linePattern:nr,lineSDF:ir,raster:ar,symbolIcon:or,symbolSDF:sr}),ur=function(){this.boundProgram=null,this.boundLayoutVertexBuffer=null,this.boundPaintVertexBuffers=[],this.boundIndexBuffer=null,this.boundVertexOffset=null,this.boundDynamicVertexBuffer=null,this.vao=null};ur.prototype.bind=function(t,e,r,n,i,a,o,s){this.context=t;for(var l=this.boundPaintVertexBuffers.length!==n.length,c=0;!l&&c<n.length;c++)this.boundPaintVertexBuffers[c]!==n[c]&&(l=!0);var u=!this.vao||this.boundProgram!==e||this.boundLayoutVertexBuffer!==r||l||this.boundIndexBuffer!==i||this.boundVertexOffset!==a||this.boundDynamicVertexBuffer!==o||this.boundDynamicVertexBuffer2!==s;!t.extVertexArrayObject||u?this.freshBind(e,r,n,i,a,o,s):(t.bindVertexArrayOES.set(this.vao),o&&o.bind(),i&&i.dynamicDraw&&i.bind(),s&&s.bind())},ur.prototype.freshBind=function(t,e,r,n,i,a,o){var s,l=t.numAttributes,c=this.context,u=c.gl;if(c.extVertexArrayObject)this.vao&&this.destroy(),this.vao=c.extVertexArrayObject.createVertexArrayOES(),c.bindVertexArrayOES.set(this.vao),s=0,this.boundProgram=t,this.boundLayoutVertexBuffer=e,this.boundPaintVertexBuffers=r,this.boundIndexBuffer=n,this.boundVertexOffset=i,this.boundDynamicVertexBuffer=a,this.boundDynamicVertexBuffer2=o;else{s=c.currentNumAttributes||0;for(var h=l;h<s;h++)u.disableVertexAttribArray(h)}e.enableAttributes(u,t);for(var f=0,p=r;f<p.length;f+=1)p[f].enableAttributes(u,t);a&&a.enableAttributes(u,t),o&&o.enableAttributes(u,t),e.bind(),e.setVertexAttribPointers(u,t,i);for(var d=0,g=r;d<g.length;d+=1){var v=g[d];v.bind(),v.setVertexAttribPointers(u,t,i)}a&&(a.bind(),a.setVertexAttribPointers(u,t,i)),n&&n.bind(),o&&(o.bind(),o.setVertexAttribPointers(u,t,i)),c.currentNumAttributes=l},ur.prototype.destroy=function(){this.vao&&(this.context.extVertexArrayObject.deleteVertexArrayOES(this.vao),this.vao=null)};var hr=function(t,e,r,n,i){var a=t.gl;this.program=a.createProgram();var o=r.defines();i&&o.push(\"#define OVERDRAW_INSPECTOR;\");var s=o.concat(Fe.fragmentSource,e.fragmentSource).join(\"\\n\"),l=o.concat(Fe.vertexSource,e.vertexSource).join(\"\\n\"),c=a.createShader(a.FRAGMENT_SHADER);a.shaderSource(c,s),a.compileShader(c),a.attachShader(this.program,c);var u=a.createShader(a.VERTEX_SHADER);a.shaderSource(u,l),a.compileShader(u),a.attachShader(this.program,u);for(var h=r.layoutAttributes||[],f=0;f<h.length;f++)a.bindAttribLocation(this.program,f,h[f].name);a.linkProgram(this.program),this.numAttributes=a.getProgramParameter(this.program,a.ACTIVE_ATTRIBUTES),this.attributes={};for(var p={},d=0;d<this.numAttributes;d++){var g=a.getActiveAttrib(this.program,d);g&&(this.attributes[g.name]=a.getAttribLocation(this.program,g.name))}for(var v=a.getProgramParameter(this.program,a.ACTIVE_UNIFORMS),m=0;m<v;m++){var y=a.getActiveUniform(this.program,m);y&&(p[y.name]=a.getUniformLocation(this.program,y.name))}this.fixedUniforms=n(t,p),this.binderUniforms=r.getUniforms(t,p)};function fr(e,r,n){var i=1/le(n,1,r.transform.tileZoom),a=Math.pow(2,n.tileID.overscaledZ),o=n.tileSize*Math.pow(2,r.transform.tileZoom)/a,s=o*(n.tileID.canonical.x+n.tileID.wrap*a),l=o*n.tileID.canonical.y;return{u_image:0,u_texsize:n.imageAtlasTexture.size,u_scale:[t.browser.devicePixelRatio,i,e.fromScale,e.toScale],u_fade:e.t,u_pixel_coord_upper:[s>>16,l>>16],u_pixel_coord_lower:[65535&s,65535&l]}}hr.prototype.draw=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g){var v,m=t.gl;for(var y in t.program.set(this.program),t.setDepthMode(r),t.setStencilMode(n),t.setColorMode(i),t.setCullFace(a),this.fixedUniforms)this.fixedUniforms[y].set(o[y]);p&&p.setUniforms(t,this.binderUniforms,h,{zoom:f});for(var x=(v={},v[m.LINES]=2,v[m.TRIANGLES]=3,v[m.LINE_STRIP]=1,v)[e],b=0,_=u.get();b<_.length;b+=1){var w=_[b],k=w.vaos||(w.vaos={});(k[s]||(k[s]=new ur)).bind(t,this,l,p?p.getPaintVertexBuffers():[],c,w.vertexOffset,d,g),m.drawElements(e,w.primitiveLength*x,m.UNSIGNED_SHORT,w.primitiveOffset*x*2)}};var pr=function(e,r,n,i){var a=r.style.light,o=a.properties.get(\"position\"),s=[o.x,o.y,o.z],l=t.create$1();\"viewport\"===a.properties.get(\"anchor\")&&t.fromRotation(l,-r.transform.angle),t.transformMat3(s,s,l);var c=a.properties.get(\"color\");return{u_matrix:e,u_lightpos:s,u_lightintensity:a.properties.get(\"intensity\"),u_lightcolor:[c.r,c.g,c.b],u_vertical_gradient:+n,u_opacity:i}},dr=function(e,r,n,i,a,o,s){return t.extend(pr(e,r,n,i),fr(o,r,s),{u_height_factor:-Math.pow(2,a.overscaledZ)/s.tileSize/8})},gr=function(t){return{u_matrix:t}},vr=function(e,r,n,i){return t.extend(gr(e),fr(n,r,i))},mr=function(t,e){return{u_matrix:t,u_world:e}},yr=function(e,r,n,i,a){return t.extend(vr(e,r,n,i),{u_world:a})},xr=function(e,r,n,i){var a,o,s=e.transform;if(\"map\"===i.paint.get(\"circle-pitch-alignment\")){var l=le(n,1,s.zoom);a=!0,o=[l,l]}else a=!1,o=s.pixelsToGLUnits;return{u_camera_to_center_distance:s.cameraToCenterDistance,u_scale_with_map:+(\"map\"===i.paint.get(\"circle-pitch-scale\")),u_matrix:e.translatePosMatrix(r.posMatrix,n,i.paint.get(\"circle-translate\"),i.paint.get(\"circle-translate-anchor\")),u_pitch_with_map:+a,u_device_pixel_ratio:t.browser.devicePixelRatio,u_extrude_scale:o}},br=function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pixels_to_tile_units:new t.Uniform1f(e,r.u_pixels_to_tile_units),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_overscale_factor:new t.Uniform1f(e,r.u_overscale_factor)}},_r=function(t,e,r){var n=le(r,1,e.zoom),i=Math.pow(2,e.zoom-r.tileID.overscaledZ),a=r.tileID.overscaleFactor();return{u_matrix:t,u_camera_to_center_distance:e.cameraToCenterDistance,u_pixels_to_tile_units:n,u_extrude_scale:[e.pixelsToGLUnits[0]/(n*i),e.pixelsToGLUnits[1]/(n*i)],u_overscale_factor:a}},wr=function(t,e){return{u_matrix:t,u_color:e}},kr=function(t){return{u_matrix:t}},Tr=function(t,e,r,n){return{u_matrix:t,u_extrude_scale:le(e,1,r),u_intensity:n}},Ar=function(t,e,r){var n=r.paint.get(\"hillshade-shadow-color\"),i=r.paint.get(\"hillshade-highlight-color\"),a=r.paint.get(\"hillshade-accent-color\"),o=r.paint.get(\"hillshade-illumination-direction\")*(Math.PI/180);\"viewport\"===r.paint.get(\"hillshade-illumination-anchor\")&&(o-=t.transform.angle);var s=!t.options.moving;return{u_matrix:t.transform.calculatePosMatrix(e.tileID.toUnwrapped(),s),u_image:0,u_latrange:Sr(t,e.tileID),u_light:[r.paint.get(\"hillshade-exaggeration\"),o],u_shadow:n,u_highlight:i,u_accent:a}},Mr=function(e,r){var n=e.dem.stride,i=t.create();return t.ortho(i,0,t.EXTENT,-t.EXTENT,0,0,1),t.translate(i,i,[0,-t.EXTENT,0]),{u_matrix:i,u_image:1,u_dimension:[n,n],u_zoom:e.tileID.overscaledZ,u_maxzoom:r}};function Sr(e,r){var n=Math.pow(2,r.canonical.z),i=r.canonical.y;return[new t.MercatorCoordinate(0,i/n).toLngLat().lat,new t.MercatorCoordinate(0,(i+1)/n).toLngLat().lat]}var Er=function(e,r,n){var i=e.transform;return{u_matrix:zr(e,r,n),u_ratio:1/le(r,1,i.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_units_to_pixels:[1/i.pixelsToGLUnits[0],1/i.pixelsToGLUnits[1]]}},Cr=function(e,r,n){return t.extend(Er(e,r,n),{u_image:0})},Lr=function(e,r,n,i){var a=e.transform,o=Or(r,a);return{u_matrix:zr(e,r,n),u_texsize:r.imageAtlasTexture.size,u_ratio:1/le(r,1,a.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_image:0,u_scale:[t.browser.devicePixelRatio,o,i.fromScale,i.toScale],u_fade:i.t,u_units_to_pixels:[1/a.pixelsToGLUnits[0],1/a.pixelsToGLUnits[1]]}},Pr=function(e,r,n,i,a){var o=e.transform,s=e.lineAtlas,l=Or(r,o),c=\"round\"===n.layout.get(\"line-cap\"),u=s.getDash(i.from,c),h=s.getDash(i.to,c),f=u.width*a.fromScale,p=h.width*a.toScale;return t.extend(Er(e,r,n),{u_patternscale_a:[l/f,-u.height/2],u_patternscale_b:[l/p,-h.height/2],u_sdfgamma:s.width/(256*Math.min(f,p)*t.browser.devicePixelRatio)/2,u_image:0,u_tex_y_a:u.y,u_tex_y_b:h.y,u_mix:a.t})};function Or(t,e){return 1/le(t,1,e.tileZoom)}function zr(t,e,r){return t.translatePosMatrix(e.tileID.posMatrix,e,r.paint.get(\"line-translate\"),r.paint.get(\"line-translate-anchor\"))}var Ir=function(t,e,r,n,i){return{u_matrix:t,u_tl_parent:e,u_scale_parent:r,u_buffer_scale:1,u_fade_t:n.mix,u_opacity:n.opacity*i.paint.get(\"raster-opacity\"),u_image0:0,u_image1:1,u_brightness_low:i.paint.get(\"raster-brightness-min\"),u_brightness_high:i.paint.get(\"raster-brightness-max\"),u_saturation_factor:(o=i.paint.get(\"raster-saturation\"),o>0?1-1/(1.001-o):-o),u_contrast_factor:(a=i.paint.get(\"raster-contrast\"),a>0?1/(1-a):1+a),u_spin_weights:function(t){t*=Math.PI/180;var e=Math.sin(t),r=Math.cos(t);return[(2*r+1)/3,(-Math.sqrt(3)*e-r+1)/3,(Math.sqrt(3)*e-r+1)/3]}(i.paint.get(\"raster-hue-rotate\"))};var a,o};var Dr=function(t,e,r,n,i,a,o,s,l,c){var u=i.transform;return{u_is_size_zoom_constant:+(\"constant\"===t||\"source\"===t),u_is_size_feature_constant:+(\"constant\"===t||\"camera\"===t),u_size_t:e?e.uSizeT:0,u_size:e?e.uSize:0,u_camera_to_center_distance:u.cameraToCenterDistance,u_pitch:u.pitch/360*2*Math.PI,u_rotate_symbol:+r,u_aspect_ratio:u.width/u.height,u_fade_change:i.options.fadeDuration?i.symbolFadeChange:1,u_matrix:a,u_label_plane_matrix:o,u_coord_matrix:s,u_is_text:+l,u_pitch_with_map:+n,u_texsize:c,u_texture:0}},Rr=function(e,r,n,i,a,o,s,l,c,u,h){var f=a.transform;return t.extend(Dr(e,r,n,i,a,o,s,l,c,u),{u_gamma_scale:i?Math.cos(f._pitch)*f.cameraToCenterDistance:1,u_device_pixel_ratio:t.browser.devicePixelRatio,u_is_halo:+h})},Fr=function(t,e,r){return{u_matrix:t,u_opacity:e,u_color:r}},Br=function(e,r,n,i,a,o){return t.extend(function(t,e,r,n){var i=r.imageManager.getPattern(t.from),a=r.imageManager.getPattern(t.to),o=r.imageManager.getPixelSize(),s=o.width,l=o.height,c=Math.pow(2,n.tileID.overscaledZ),u=n.tileSize*Math.pow(2,r.transform.tileZoom)/c,h=u*(n.tileID.canonical.x+n.tileID.wrap*c),f=u*n.tileID.canonical.y;return{u_image:0,u_pattern_tl_a:i.tl,u_pattern_br_a:i.br,u_pattern_tl_b:a.tl,u_pattern_br_b:a.br,u_texsize:[s,l],u_mix:e.t,u_pattern_size_a:i.displaySize,u_pattern_size_b:a.displaySize,u_scale_a:e.fromScale,u_scale_b:e.toScale,u_tile_units_to_pixels:1/le(n,1,r.transform.tileZoom),u_pixel_coord_upper:[h>>16,f>>16],u_pixel_coord_lower:[65535&h,65535&f]}}(i,o,n,a),{u_matrix:e,u_opacity:r})},Nr={fillExtrusion:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fillExtrusionPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_height_factor:new t.Uniform1f(e,r.u_height_factor),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fill:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},fillPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},fillOutline:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world)}},fillOutlinePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},circle:function(e,r){return{u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_scale_with_map:new t.Uniform1i(e,r.u_scale_with_map),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},collisionBox:br,collisionCircle:br,debug:function(e,r){return{u_color:new t.UniformColor(e,r.u_color),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},clippingMask:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmap:function(e,r){return{u_extrude_scale:new t.Uniform1f(e,r.u_extrude_scale),u_intensity:new t.Uniform1f(e,r.u_intensity),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmapTexture:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_color_ramp:new t.Uniform1i(e,r.u_color_ramp),u_opacity:new t.Uniform1f(e,r.u_opacity)}},hillshade:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_latrange:new t.Uniform2f(e,r.u_latrange),u_light:new t.Uniform2f(e,r.u_light),u_shadow:new t.UniformColor(e,r.u_shadow),u_highlight:new t.UniformColor(e,r.u_highlight),u_accent:new t.UniformColor(e,r.u_accent)}},hillshadePrepare:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_dimension:new t.Uniform2f(e,r.u_dimension),u_zoom:new t.Uniform1f(e,r.u_zoom),u_maxzoom:new t.Uniform1f(e,r.u_maxzoom)}},line:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels)}},lineGradient:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_image:new t.Uniform1i(e,r.u_image)}},linePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_texsize:new t.Uniform2f(e,r.u_texsize),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_image:new t.Uniform1i(e,r.u_image),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},lineSDF:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_patternscale_a:new t.Uniform2f(e,r.u_patternscale_a),u_patternscale_b:new t.Uniform2f(e,r.u_patternscale_b),u_sdfgamma:new t.Uniform1f(e,r.u_sdfgamma),u_image:new t.Uniform1i(e,r.u_image),u_tex_y_a:new t.Uniform1f(e,r.u_tex_y_a),u_tex_y_b:new t.Uniform1f(e,r.u_tex_y_b),u_mix:new t.Uniform1f(e,r.u_mix)}},raster:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_tl_parent:new t.Uniform2f(e,r.u_tl_parent),u_scale_parent:new t.Uniform1f(e,r.u_scale_parent),u_buffer_scale:new t.Uniform1f(e,r.u_buffer_scale),u_fade_t:new t.Uniform1f(e,r.u_fade_t),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image0:new t.Uniform1i(e,r.u_image0),u_image1:new t.Uniform1i(e,r.u_image1),u_brightness_low:new t.Uniform1f(e,r.u_brightness_low),u_brightness_high:new t.Uniform1f(e,r.u_brightness_high),u_saturation_factor:new t.Uniform1f(e,r.u_saturation_factor),u_contrast_factor:new t.Uniform1f(e,r.u_contrast_factor),u_spin_weights:new t.Uniform3f(e,r.u_spin_weights)}},symbolIcon:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1f(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture)}},symbolSDF:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1f(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture),u_gamma_scale:new t.Uniform1f(e,r.u_gamma_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_is_halo:new t.Uniform1f(e,r.u_is_halo)}},background:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_color:new t.UniformColor(e,r.u_color)}},backgroundPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image:new t.Uniform1i(e,r.u_image),u_pattern_tl_a:new t.Uniform2f(e,r.u_pattern_tl_a),u_pattern_br_a:new t.Uniform2f(e,r.u_pattern_br_a),u_pattern_tl_b:new t.Uniform2f(e,r.u_pattern_tl_b),u_pattern_br_b:new t.Uniform2f(e,r.u_pattern_br_b),u_texsize:new t.Uniform2f(e,r.u_texsize),u_mix:new t.Uniform1f(e,r.u_mix),u_pattern_size_a:new t.Uniform2f(e,r.u_pattern_size_a),u_pattern_size_b:new t.Uniform2f(e,r.u_pattern_size_b),u_scale_a:new t.Uniform1f(e,r.u_scale_a),u_scale_b:new t.Uniform1f(e,r.u_scale_b),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_tile_units_to_pixels:new t.Uniform1f(e,r.u_tile_units_to_pixels)}}};function jr(e,r){for(var n=e.sort(function(t,e){return t.tileID.isLessThan(e.tileID)?-1:e.tileID.isLessThan(t.tileID)?1:0}),i=0;i<n.length;i++){var a={},o=n[i],s=n.slice(i+1);Ur(o.tileID.wrapped(),o.tileID,s,new t.OverscaledTileID(0,o.tileID.wrap+1,0,0,0),a),o.setMask(a,r)}}function Ur(e,r,n,i,a){for(var o=0;o<n.length;o++){var s=n[o];if(i.isLessThan(s.tileID))break;if(r.key===s.tileID.key)return;if(s.tileID.isChildOf(r)){for(var l=r.children(1/0),c=0;c<l.length;c++)Ur(e,l[c],n.slice(o),i,a);return}}var u=r.overscaledZ-e.overscaledZ,h=new t.CanonicalTileID(u,r.canonical.x-(e.canonical.x<<u),r.canonical.y-(e.canonical.y<<u));a[h.key]=a[h.key]||h}function Vr(t,e,r,n,i){for(var a=t.context,o=a.gl,s=i?t.useProgram(\"collisionCircle\"):t.useProgram(\"collisionBox\"),l=0;l<n.length;l++){var c=n[l],u=e.getTile(c),h=u.getBucket(r);if(h){var f=i?h.collisionCircle:h.collisionBox;f&&s.draw(a,i?o.TRIANGLES:o.LINES,Tt.disabled,At.disabled,t.colorModeForRenderPass(),St.disabled,_r(c.posMatrix,t.transform,u),r.id,f.layoutVertexBuffer,f.indexBuffer,f.segments,null,t.transform.zoom,null,null,f.collisionVertexBuffer)}}}var qr=t.identity(new Float32Array(16));function Hr(e,r,n,i,a,o){var s=t.getAnchorAlignment(e),l=-(s.horizontalAlign-.5)*r,c=-(s.verticalAlign-.5)*n,u=t.evaluateRadialOffset(e,i);return new t.Point((l/a+u[0])*o,(c/a+u[1])*o)}function Gr(e,r,n,i,a,o,s,l,c,u){var h=e.text.placedSymbolArray,f=e.text.dynamicLayoutVertexArray;f.clear();for(var p=0;p<h.length;p++){var d=h.get(p),g=!d.hidden&&d.crossTileID?i[d.crossTileID]:null;if(g){var v=new t.Point(d.anchorX,d.anchorY),m=Zt(v,n?l:s),y=.5+o.cameraToCenterDistance/m.signedDistanceFromCamera*.5,x=a.evaluateSizeForFeature(e.textSizeData,u,d)*y/t.ONE_EM;n&&(x*=e.tilePixelRatio/c);for(var b=g.width,_=g.height,w=g.radialOffset,k=g.textBoxScale,T=Hr(g.anchor,b,_,w,k,x),A=n?Zt(v.add(T),s).point:m.point.add(r?T.rotate(-o.angle):T),M=0;M<d.numGlyphs;M++)t.addDynamicAttributes(f,A,0)}else ie(d.numGlyphs,f)}e.text.dynamicLayoutVertexBuffer.updateData(f)}function Yr(e,r,n,i,a,o,s,l,c,u,h,f,p){for(var d,g,v=e.context,m=v.gl,y=e.transform,x=\"map\"===l,b=\"map\"===c,_=x&&\"point\"!==n.layout.get(\"symbol-placement\"),w=x&&!b&&!_,k=void 0!==n.layout.get(\"symbol-sort-key\").constantOr(1),T=e.depthModeForSublayer(0,Tt.ReadOnly),A=n.layout.get(\"text-variable-anchor\"),M=[],S=0,E=i;S<E.length;S+=1){var C=E[S],L=r.getTile(C),P=L.getBucket(n);if(P){var O=a?P.text:P.icon;if(O&&O.segments.get().length){var z=O.programConfigurations.get(n.id),I=a||P.sdfIcons,D=a?P.textSizeData:P.iconSizeData;d||(d=e.useProgram(I?\"symbolSDF\":\"symbolIcon\",z),g=t.evaluateSizeForZoom(D,y.zoom)),v.activeTexture.set(m.TEXTURE0);var R=void 0,F=void 0,B=void 0;if(a)F=L.glyphAtlasTexture,B=m.LINEAR,R=L.glyphAtlasTexture.size;else{var N=1!==n.layout.get(\"icon-size\").constantOr(0)||P.iconsNeedLinear,j=b||0!==y.pitch;F=L.imageAtlasTexture,B=I||e.options.rotating||e.options.zooming||N||j?m.LINEAR:m.NEAREST,R=L.imageAtlasTexture.size}var U=le(L,1,e.transform.zoom),V=Wt(C.posMatrix,b,x,e.transform,U),q=Xt(C.posMatrix,b,x,e.transform,U);if(_)Kt(P,C.posMatrix,e,a,V,q,b,u);else if(a&&g&&A){var H=Math.pow(2,y.zoom-L.tileID.overscaledZ);Gr(P,x,b,p,t.symbolSize,y,V,C.posMatrix,H,g)}var G=e.translatePosMatrix(C.posMatrix,L,o,s),Y=_||a&&A?qr:V,W=e.translatePosMatrix(q,L,o,s,!0),X=I&&0!==n.paint.get(a?\"text-halo-width\":\"icon-halo-width\").constantOr(1),Z={program:d,buffers:O,uniformValues:I?Rr(D.kind,g,w,b,e,G,Y,W,a,R,!0):Dr(D.kind,g,w,b,e,G,Y,W,a,R),atlasTexture:F,atlasInterpolation:B,isSDF:I,hasHalo:X};if(k)for(var J=0,K=O.segments.get();J<K.length;J+=1){var $=K[J];M.push({segments:new t.SegmentVector([$]),sortKey:$.sortKey,state:Z})}else M.push({segments:O.segments,sortKey:0,state:Z})}}}k&&M.sort(function(t,e){return t.sortKey-e.sortKey});for(var Q=0,tt=M;Q<tt.length;Q+=1){var et=tt[Q],rt=et.state;if(rt.atlasTexture.bind(rt.atlasInterpolation,m.CLAMP_TO_EDGE),rt.isSDF){var nt=rt.uniformValues;rt.hasHalo&&(nt.u_is_halo=1,Wr(rt.buffers,et.segments,n,e,rt.program,T,h,f,nt)),nt.u_is_halo=0}Wr(rt.buffers,et.segments,n,e,rt.program,T,h,f,rt.uniformValues)}}function Wr(t,e,r,n,i,a,o,s,l){var c=n.context,u=c.gl;i.draw(c,u.TRIANGLES,a,o,s,St.disabled,l,r.id,t.layoutVertexBuffer,t.indexBuffer,e,r.paint,n.transform.zoom,t.programConfigurations.get(r.id),t.dynamicLayoutVertexBuffer,t.opacityVertexBuffer)}function Xr(t,e,r,n,i,a,o){var s,l,c,u,h,f=t.context.gl,p=r.paint.get(\"fill-pattern\"),d=p&&p.constantOr(1),g=r.getCrossfadeParameters();o?(l=d&&!r.getPaintProperty(\"fill-outline-color\")?\"fillOutlinePattern\":\"fillOutline\",s=f.LINES):(l=d?\"fillPattern\":\"fill\",s=f.TRIANGLES);for(var v=0,m=n;v<m.length;v+=1){var y=m[v],x=e.getTile(y);if(!d||x.patternsLoaded()){var b=x.getBucket(r);if(b){var _=b.programConfigurations.get(r.id),w=t.useProgram(l,_);d&&(t.context.activeTexture.set(f.TEXTURE0),x.imageAtlasTexture.bind(f.LINEAR,f.CLAMP_TO_EDGE),_.updatePatternPaintBuffers(g));var k=p.constantOr(null);if(k&&x.imageAtlas){var T=x.imageAtlas.patternPositions[k.to],A=x.imageAtlas.patternPositions[k.from];T&&A&&_.setConstantPatternPositions(T,A)}var M=t.translatePosMatrix(y.posMatrix,x,r.paint.get(\"fill-translate\"),r.paint.get(\"fill-translate-anchor\"));if(o){u=b.indexBuffer2,h=b.segments2;var S=[f.drawingBufferWidth,f.drawingBufferHeight];c=\"fillOutlinePattern\"===l&&d?yr(M,t,g,x,S):mr(M,S)}else u=b.indexBuffer,h=b.segments,c=d?vr(M,t,g,x):gr(M);w.draw(t.context,s,i,t.stencilModeForClipping(y),a,St.disabled,c,r.id,b.layoutVertexBuffer,u,h,r.paint,t.transform.zoom,_)}}}}function Zr(t,e,r,n,i,a,o){for(var s=t.context,l=s.gl,c=r.paint.get(\"fill-extrusion-pattern\"),u=c.constantOr(1),h=r.getCrossfadeParameters(),f=r.paint.get(\"fill-extrusion-opacity\"),p=0,d=n;p<d.length;p+=1){var g=d[p],v=e.getTile(g),m=v.getBucket(r);if(m){var y=m.programConfigurations.get(r.id),x=t.useProgram(u?\"fillExtrusionPattern\":\"fillExtrusion\",y);u&&(t.context.activeTexture.set(l.TEXTURE0),v.imageAtlasTexture.bind(l.LINEAR,l.CLAMP_TO_EDGE),y.updatePatternPaintBuffers(h));var b=c.constantOr(null);if(b&&v.imageAtlas){var _=v.imageAtlas.patternPositions[b.to],w=v.imageAtlas.patternPositions[b.from];_&&w&&y.setConstantPatternPositions(_,w)}var k=t.translatePosMatrix(g.posMatrix,v,r.paint.get(\"fill-extrusion-translate\"),r.paint.get(\"fill-extrusion-translate-anchor\")),T=r.paint.get(\"fill-extrusion-vertical-gradient\"),A=u?dr(k,t,T,f,g,h,v):pr(k,t,T,f);x.draw(s,s.gl.TRIANGLES,i,a,o,St.backCCW,A,r.id,m.layoutVertexBuffer,m.indexBuffer,m.segments,r.paint,t.transform.zoom,y)}}}function Jr(t,e,r,n,i,a){var o=t.context,s=o.gl,l=e.fbo;if(l){var c=t.useProgram(\"hillshade\");o.activeTexture.set(s.TEXTURE0),s.bindTexture(s.TEXTURE_2D,l.colorAttachment.get());var u=Ar(t,e,r);e.maskedBoundsBuffer&&e.maskedIndexBuffer&&e.segments?c.draw(o,s.TRIANGLES,n,i,a,St.disabled,u,r.id,e.maskedBoundsBuffer,e.maskedIndexBuffer,e.segments):c.draw(o,s.TRIANGLES,n,i,a,St.disabled,u,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}}function Kr(e,r,n,i,a,o,s){var l=e.context,c=l.gl;if(r.dem&&r.dem.data){var u=r.dem.dim,h=r.dem.stride,f=r.dem.getPixels();if(l.activeTexture.set(c.TEXTURE1),l.pixelStoreUnpackPremultiplyAlpha.set(!1),r.demTexture=r.demTexture||e.getTileTexture(h),r.demTexture){var p=r.demTexture;p.update(f,{premultiply:!1}),p.bind(c.NEAREST,c.CLAMP_TO_EDGE)}else r.demTexture=new t.Texture(l,f,c.RGBA,{premultiply:!1}),r.demTexture.bind(c.NEAREST,c.CLAMP_TO_EDGE);l.activeTexture.set(c.TEXTURE0);var d=r.fbo;if(!d){var g=new t.Texture(l,{width:u,height:u,data:null},c.RGBA);g.bind(c.LINEAR,c.CLAMP_TO_EDGE),(d=r.fbo=l.createFramebuffer(u,u)).colorAttachment.set(g.texture)}l.bindFramebuffer.set(d.framebuffer),l.viewport.set([0,0,u,u]),e.useProgram(\"hillshadePrepare\").draw(l,c.TRIANGLES,a,o,s,St.disabled,Mr(r,i),n.id,e.rasterBoundsBuffer,e.quadTriangleIndexBuffer,e.rasterBoundsSegments),r.needsHillshadePrepare=!1}}function $r(e,r,n,i,a){var o=i.paint.get(\"raster-fade-duration\");if(o>0){var s=t.browser.now(),l=(s-e.timeAdded)/o,c=r?(s-r.timeAdded)/o:-1,u=n.getSource(),h=a.coveringZoomLevel({tileSize:u.tileSize,roundZoom:u.roundZoom}),f=!r||Math.abs(r.tileID.overscaledZ-h)>Math.abs(e.tileID.overscaledZ-h),p=f&&e.refreshedUponExpiration?1:t.clamp(f?l:1-c,0,1);return e.refreshedUponExpiration&&l>=1&&(e.refreshedUponExpiration=!1),r?{opacity:1,mix:1-p}:{opacity:p,mix:0}}return{opacity:1,mix:0}}function Qr(e,r,n){var i=e.context,a=i.gl,o=n.posMatrix,s=e.useProgram(\"debug\"),l=Tt.disabled,c=At.disabled,u=e.colorModeForRenderPass(),h=\"$debug\";s.draw(i,a.LINE_STRIP,l,c,u,St.disabled,wr(o,t.Color.red),h,e.debugBuffer,e.tileBorderIndexBuffer,e.debugSegments);for(var f=r.getTileByID(n.key).latestRawTileData,p=f&&f.byteLength||0,d=Math.floor(p/1024),g=function(t,e,r,n){n=n||1;var i,a,o,s,l,c,u,h,f=[];for(i=0,a=t.length;i<a;i++)if(l=tn[t[i]]){for(h=null,o=0,s=l[1].length;o<s;o+=2)-1===l[1][o]&&-1===l[1][o+1]?h=null:(c=e+l[1][o]*n,u=200-l[1][o+1]*n,h&&f.push(h.x,h.y,c,u),h={x:c,y:u});e+=l[0]*n}return f}(n.toString()+\" \"+d+\"kb\",50,0,5),v=new t.StructArrayLayout2i4,m=new t.StructArrayLayout2ui4,y=0;y<g.length;y+=2)v.emplaceBack(g[y],g[y+1]),m.emplaceBack(y,y+1);for(var x=i.createVertexBuffer(v,Re.members),b=i.createIndexBuffer(m),_=t.SegmentVector.simpleSegment(0,0,v.length/2,v.length/2),w=r.getTile(n).tileSize,k=t.EXTENT/(Math.pow(2,e.transform.zoom-n.overscaledZ)*w),T=[[-1,-1],[-1,1],[1,-1],[1,1]],A=0;A<T.length;A++){var M=T[A];s.draw(i,a.LINES,l,c,u,St.disabled,wr(t.translate([],o,[k*M[0],k*M[1],0]),t.Color.white),h,x,b,_)}s.draw(i,a.LINES,l,c,u,St.disabled,wr(o,t.Color.black),h,x,b,_)}var tn={\" \":[16,[]],\"!\":[10,[5,21,5,7,-1,-1,5,2,4,1,5,0,6,1,5,2]],'\"':[16,[4,21,4,14,-1,-1,12,21,12,14]],\"#\":[21,[11,25,4,-7,-1,-1,17,25,10,-7,-1,-1,4,12,18,12,-1,-1,3,6,17,6]],$:[20,[8,25,8,-4,-1,-1,12,25,12,-4,-1,-1,17,18,15,20,12,21,8,21,5,20,3,18,3,16,4,14,5,13,7,12,13,10,15,9,16,8,17,6,17,3,15,1,12,0,8,0,5,1,3,3]],\"%\":[24,[21,21,3,0,-1,-1,8,21,10,19,10,17,9,15,7,14,5,14,3,16,3,18,4,20,6,21,8,21,10,20,13,19,16,19,19,20,21,21,-1,-1,17,7,15,6,14,4,14,2,16,0,18,0,20,1,21,3,21,5,19,7,17,7]],\"&\":[26,[23,12,23,13,22,14,21,14,20,13,19,11,17,6,15,3,13,1,11,0,7,0,5,1,4,2,3,4,3,6,4,8,5,9,12,13,13,14,14,16,14,18,13,20,11,21,9,20,8,18,8,16,9,13,11,10,16,3,18,1,20,0,22,0,23,1,23,2]],\"'\":[10,[5,19,4,20,5,21,6,20,6,18,5,16,4,15]],\"(\":[14,[11,25,9,23,7,20,5,16,4,11,4,7,5,2,7,-2,9,-5,11,-7]],\")\":[14,[3,25,5,23,7,20,9,16,10,11,10,7,9,2,7,-2,5,-5,3,-7]],\"*\":[16,[8,21,8,9,-1,-1,3,18,13,12,-1,-1,13,18,3,12]],\"+\":[26,[13,18,13,0,-1,-1,4,9,22,9]],\",\":[10,[6,1,5,0,4,1,5,2,6,1,6,-1,5,-3,4,-4]],\"-\":[26,[4,9,22,9]],\".\":[10,[5,2,4,1,5,0,6,1,5,2]],\"/\":[22,[20,25,2,-7]],0:[20,[9,21,6,20,4,17,3,12,3,9,4,4,6,1,9,0,11,0,14,1,16,4,17,9,17,12,16,17,14,20,11,21,9,21]],1:[20,[6,17,8,18,11,21,11,0]],2:[20,[4,16,4,17,5,19,6,20,8,21,12,21,14,20,15,19,16,17,16,15,15,13,13,10,3,0,17,0]],3:[20,[5,21,16,21,10,13,13,13,15,12,16,11,17,8,17,6,16,3,14,1,11,0,8,0,5,1,4,2,3,4]],4:[20,[13,21,3,7,18,7,-1,-1,13,21,13,0]],5:[20,[15,21,5,21,4,12,5,13,8,14,11,14,14,13,16,11,17,8,17,6,16,3,14,1,11,0,8,0,5,1,4,2,3,4]],6:[20,[16,18,15,20,12,21,10,21,7,20,5,17,4,12,4,7,5,3,7,1,10,0,11,0,14,1,16,3,17,6,17,7,16,10,14,12,11,13,10,13,7,12,5,10,4,7]],7:[20,[17,21,7,0,-1,-1,3,21,17,21]],8:[20,[8,21,5,20,4,18,4,16,5,14,7,13,11,12,14,11,16,9,17,7,17,4,16,2,15,1,12,0,8,0,5,1,4,2,3,4,3,7,4,9,6,11,9,12,13,13,15,14,16,16,16,18,15,20,12,21,8,21]],9:[20,[16,14,15,11,13,9,10,8,9,8,6,9,4,11,3,14,3,15,4,18,6,20,9,21,10,21,13,20,15,18,16,14,16,9,15,4,13,1,10,0,8,0,5,1,4,3]],\":\":[10,[5,14,4,13,5,12,6,13,5,14,-1,-1,5,2,4,1,5,0,6,1,5,2]],\";\":[10,[5,14,4,13,5,12,6,13,5,14,-1,-1,6,1,5,0,4,1,5,2,6,1,6,-1,5,-3,4,-4]],\"<\":[24,[20,18,4,9,20,0]],\"=\":[26,[4,12,22,12,-1,-1,4,6,22,6]],\">\":[24,[4,18,20,9,4,0]],\"?\":[18,[3,16,3,17,4,19,5,20,7,21,11,21,13,20,14,19,15,17,15,15,14,13,13,12,9,10,9,7,-1,-1,9,2,8,1,9,0,10,1,9,2]],\"@\":[27,[18,13,17,15,15,16,12,16,10,15,9,14,8,11,8,8,9,6,11,5,14,5,16,6,17,8,-1,-1,12,16,10,14,9,11,9,8,10,6,11,5,-1,-1,18,16,17,8,17,6,19,5,21,5,23,7,24,10,24,12,23,15,22,17,20,19,18,20,15,21,12,21,9,20,7,19,5,17,4,15,3,12,3,9,4,6,5,4,7,2,9,1,12,0,15,0,18,1,20,2,21,3,-1,-1,19,16,18,8,18,6,19,5]],A:[18,[9,21,1,0,-1,-1,9,21,17,0,-1,-1,4,7,14,7]],B:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,15,17,13,16,12,13,11,-1,-1,4,11,13,11,16,10,17,9,18,7,18,4,17,2,16,1,13,0,4,0]],C:[21,[18,16,17,18,15,20,13,21,9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5]],D:[21,[4,21,4,0,-1,-1,4,21,11,21,14,20,16,18,17,16,18,13,18,8,17,5,16,3,14,1,11,0,4,0]],E:[19,[4,21,4,0,-1,-1,4,21,17,21,-1,-1,4,11,12,11,-1,-1,4,0,17,0]],F:[18,[4,21,4,0,-1,-1,4,21,17,21,-1,-1,4,11,12,11]],G:[21,[18,16,17,18,15,20,13,21,9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,18,8,-1,-1,13,8,18,8]],H:[22,[4,21,4,0,-1,-1,18,21,18,0,-1,-1,4,11,18,11]],I:[8,[4,21,4,0]],J:[16,[12,21,12,5,11,2,10,1,8,0,6,0,4,1,3,2,2,5,2,7]],K:[21,[4,21,4,0,-1,-1,18,21,4,7,-1,-1,9,12,18,0]],L:[17,[4,21,4,0,-1,-1,4,0,16,0]],M:[24,[4,21,4,0,-1,-1,4,21,12,0,-1,-1,20,21,12,0,-1,-1,20,21,20,0]],N:[22,[4,21,4,0,-1,-1,4,21,18,0,-1,-1,18,21,18,0]],O:[22,[9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,19,8,19,13,18,16,17,18,15,20,13,21,9,21]],P:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,14,17,12,16,11,13,10,4,10]],Q:[22,[9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,19,8,19,13,18,16,17,18,15,20,13,21,9,21,-1,-1,12,4,18,-2]],R:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,15,17,13,16,12,13,11,4,11,-1,-1,11,11,18,0]],S:[20,[17,18,15,20,12,21,8,21,5,20,3,18,3,16,4,14,5,13,7,12,13,10,15,9,16,8,17,6,17,3,15,1,12,0,8,0,5,1,3,3]],T:[16,[8,21,8,0,-1,-1,1,21,15,21]],U:[22,[4,21,4,6,5,3,7,1,10,0,12,0,15,1,17,3,18,6,18,21]],V:[18,[1,21,9,0,-1,-1,17,21,9,0]],W:[24,[2,21,7,0,-1,-1,12,21,7,0,-1,-1,12,21,17,0,-1,-1,22,21,17,0]],X:[20,[3,21,17,0,-1,-1,17,21,3,0]],Y:[18,[1,21,9,11,9,0,-1,-1,17,21,9,11]],Z:[20,[17,21,3,0,-1,-1,3,21,17,21,-1,-1,3,0,17,0]],\"[\":[14,[4,25,4,-7,-1,-1,5,25,5,-7,-1,-1,4,25,11,25,-1,-1,4,-7,11,-7]],\"\\\\\":[14,[0,21,14,-3]],\"]\":[14,[9,25,9,-7,-1,-1,10,25,10,-7,-1,-1,3,25,10,25,-1,-1,3,-7,10,-7]],\"^\":[16,[6,15,8,18,10,15,-1,-1,3,12,8,17,13,12,-1,-1,8,17,8,0]],_:[16,[0,-2,16,-2]],\"`\":[10,[6,21,5,20,4,18,4,16,5,15,6,16,5,17]],a:[19,[15,14,15,0,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],b:[19,[4,21,4,0,-1,-1,4,11,6,13,8,14,11,14,13,13,15,11,16,8,16,6,15,3,13,1,11,0,8,0,6,1,4,3]],c:[18,[15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],d:[19,[15,21,15,0,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],e:[18,[3,8,15,8,15,10,14,12,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],f:[12,[10,21,8,21,6,20,5,17,5,0,-1,-1,2,14,9,14]],g:[19,[15,14,15,-2,14,-5,13,-6,11,-7,8,-7,6,-6,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],h:[19,[4,21,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0]],i:[8,[3,21,4,20,5,21,4,22,3,21,-1,-1,4,14,4,0]],j:[10,[5,21,6,20,7,21,6,22,5,21,-1,-1,6,14,6,-3,5,-6,3,-7,1,-7]],k:[17,[4,21,4,0,-1,-1,14,14,4,4,-1,-1,8,8,15,0]],l:[8,[4,21,4,0]],m:[30,[4,14,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0,-1,-1,15,10,18,13,20,14,23,14,25,13,26,10,26,0]],n:[19,[4,14,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0]],o:[19,[8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3,16,6,16,8,15,11,13,13,11,14,8,14]],p:[19,[4,14,4,-7,-1,-1,4,11,6,13,8,14,11,14,13,13,15,11,16,8,16,6,15,3,13,1,11,0,8,0,6,1,4,3]],q:[19,[15,14,15,-7,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],r:[13,[4,14,4,0,-1,-1,4,8,5,11,7,13,9,14,12,14]],s:[17,[14,11,13,13,10,14,7,14,4,13,3,11,4,9,6,8,11,7,13,6,14,4,14,3,13,1,10,0,7,0,4,1,3,3]],t:[12,[5,21,5,4,6,1,8,0,10,0,-1,-1,2,14,9,14]],u:[19,[4,14,4,4,5,1,7,0,10,0,12,1,15,4,-1,-1,15,14,15,0]],v:[16,[2,14,8,0,-1,-1,14,14,8,0]],w:[22,[3,14,7,0,-1,-1,11,14,7,0,-1,-1,11,14,15,0,-1,-1,19,14,15,0]],x:[17,[3,14,14,0,-1,-1,14,14,3,0]],y:[16,[2,14,8,0,-1,-1,14,14,8,0,6,-4,4,-6,2,-7,1,-7]],z:[17,[14,14,3,0,-1,-1,3,14,14,14,-1,-1,3,0,14,0]],\"{\":[14,[9,25,7,24,6,23,5,21,5,19,6,17,7,16,8,14,8,12,6,10,-1,-1,7,24,6,22,6,20,7,18,8,17,9,15,9,13,8,11,4,9,8,7,9,5,9,3,8,1,7,0,6,-2,6,-4,7,-6,-1,-1,6,8,8,6,8,4,7,2,6,1,5,-1,5,-3,6,-5,7,-6,9,-7]],\"|\":[8,[4,25,4,-7]],\"}\":[14,[5,25,7,24,8,23,9,21,9,19,8,17,7,16,6,14,6,12,8,10,-1,-1,7,24,8,22,8,20,7,18,6,17,5,15,5,13,6,11,10,9,6,7,5,5,5,3,6,1,7,0,8,-2,8,-4,7,-6,-1,-1,8,8,6,6,6,4,7,2,8,1,9,-1,9,-3,8,-5,7,-6,5,-7]],\"~\":[24,[3,6,3,8,4,11,6,12,8,12,10,11,14,8,16,7,18,7,20,8,21,10,-1,-1,3,8,4,10,6,11,8,11,10,10,14,7,16,6,18,6,20,7,21,10,21,12]]},en={symbol:function(t,e,r,n,i){if(\"translucent\"===t.renderPass){var a=At.disabled,o=t.colorModeForRenderPass();0!==r.paint.get(\"icon-opacity\").constantOr(1)&&Yr(t,e,r,n,!1,r.paint.get(\"icon-translate\"),r.paint.get(\"icon-translate-anchor\"),r.layout.get(\"icon-rotation-alignment\"),r.layout.get(\"icon-pitch-alignment\"),r.layout.get(\"icon-keep-upright\"),a,o,i),0!==r.paint.get(\"text-opacity\").constantOr(1)&&Yr(t,e,r,n,!0,r.paint.get(\"text-translate\"),r.paint.get(\"text-translate-anchor\"),r.layout.get(\"text-rotation-alignment\"),r.layout.get(\"text-pitch-alignment\"),r.layout.get(\"text-keep-upright\"),a,o,i),e.map.showCollisionBoxes&&function(t,e,r,n){Vr(t,e,r,n,!1),Vr(t,e,r,n,!0)}(t,e,r,n)}},circle:function(t,e,r,n){if(\"translucent\"===t.renderPass){var i=r.paint.get(\"circle-opacity\"),a=r.paint.get(\"circle-stroke-width\"),o=r.paint.get(\"circle-stroke-opacity\");if(0!==i.constantOr(1)||0!==a.constantOr(1)&&0!==o.constantOr(1))for(var s=t.context,l=s.gl,c=t.depthModeForSublayer(0,Tt.ReadOnly),u=At.disabled,h=t.colorModeForRenderPass(),f=0;f<n.length;f++){var p=n[f],d=e.getTile(p),g=d.getBucket(r);if(g){var v=g.programConfigurations.get(r.id);t.useProgram(\"circle\",v).draw(s,l.TRIANGLES,c,u,h,St.disabled,xr(t,p,d,r),r.id,g.layoutVertexBuffer,g.indexBuffer,g.segments,r.paint,t.transform.zoom,v)}}}},heatmap:function(e,r,n,i){if(0!==n.paint.get(\"heatmap-opacity\"))if(\"offscreen\"===e.renderPass){var a=e.context,o=a.gl,s=e.depthModeForSublayer(0,Tt.ReadOnly),l=At.disabled,c=new Mt([o.ONE,o.ONE],t.Color.transparent,[!0,!0,!0,!0]);!function(t,e,r){var n=t.gl;t.activeTexture.set(n.TEXTURE1),t.viewport.set([0,0,e.width/4,e.height/4]);var i=r.heatmapFbo;if(i)n.bindTexture(n.TEXTURE_2D,i.colorAttachment.get()),t.bindFramebuffer.set(i.framebuffer);else{var a=n.createTexture();n.bindTexture(n.TEXTURE_2D,a),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,n.LINEAR),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,n.LINEAR),i=r.heatmapFbo=t.createFramebuffer(e.width/4,e.height/4),function t(e,r,n,i){var a=e.gl;a.texImage2D(a.TEXTURE_2D,0,a.RGBA,r.width/4,r.height/4,0,a.RGBA,e.extTextureHalfFloat?e.extTextureHalfFloat.HALF_FLOAT_OES:a.UNSIGNED_BYTE,null),i.colorAttachment.set(n),e.extTextureHalfFloat&&a.checkFramebufferStatus(a.FRAMEBUFFER)!==a.FRAMEBUFFER_COMPLETE&&(e.extTextureHalfFloat=null,i.colorAttachment.setDirty(),t(e,r,n,i))}(t,e,a,i)}}(a,e,n),a.clear({color:t.Color.transparent});for(var u=0;u<i.length;u++){var h=i[u];if(!r.hasRenderableParent(h)){var f=r.getTile(h),p=f.getBucket(n);if(p){var d=p.programConfigurations.get(n.id),g=e.useProgram(\"heatmap\",d),v=e.transform.zoom;g.draw(a,o.TRIANGLES,s,l,c,St.disabled,Tr(h.posMatrix,f,v,n.paint.get(\"heatmap-intensity\")),n.id,p.layoutVertexBuffer,p.indexBuffer,p.segments,n.paint,e.transform.zoom,d)}}}a.viewport.set([0,0,e.width,e.height])}else\"translucent\"===e.renderPass&&(e.context.setColorMode(e.colorModeForRenderPass()),function(e,r){var n=e.context,i=n.gl,a=r.heatmapFbo;if(a){n.activeTexture.set(i.TEXTURE0),i.bindTexture(i.TEXTURE_2D,a.colorAttachment.get()),n.activeTexture.set(i.TEXTURE1);var o=r.colorRampTexture;o||(o=r.colorRampTexture=new t.Texture(n,r.colorRamp,i.RGBA)),o.bind(i.LINEAR,i.CLAMP_TO_EDGE),e.useProgram(\"heatmapTexture\").draw(n,i.TRIANGLES,Tt.disabled,At.disabled,e.colorModeForRenderPass(),St.disabled,function(e,r,n,i){var a=t.create();t.ortho(a,0,e.width,e.height,0,0,1);var o=e.context.gl;return{u_matrix:a,u_world:[o.drawingBufferWidth,o.drawingBufferHeight],u_image:n,u_color_ramp:i,u_opacity:r.paint.get(\"heatmap-opacity\")}}(e,r,0,1),r.id,e.viewportBuffer,e.quadTriangleIndexBuffer,e.viewportSegments,r.paint,e.transform.zoom)}}(e,n))},line:function(e,r,n,i){if(\"translucent\"===e.renderPass){var a=n.paint.get(\"line-opacity\"),o=n.paint.get(\"line-width\");if(0!==a.constantOr(1)&&0!==o.constantOr(1)){var s=e.depthModeForSublayer(0,Tt.ReadOnly),l=e.colorModeForRenderPass(),c=n.paint.get(\"line-dasharray\"),u=n.paint.get(\"line-pattern\"),h=u.constantOr(1),f=n.paint.get(\"line-gradient\"),p=n.getCrossfadeParameters(),d=c?\"lineSDF\":h?\"linePattern\":f?\"lineGradient\":\"line\",g=e.context,v=g.gl,m=!0;if(f){g.activeTexture.set(v.TEXTURE0);var y=n.gradientTexture;if(!n.gradient)return;y||(y=n.gradientTexture=new t.Texture(g,n.gradient,v.RGBA)),y.bind(v.LINEAR,v.CLAMP_TO_EDGE)}for(var x=0,b=i;x<b.length;x+=1){var _=b[x],w=r.getTile(_);if(!h||w.patternsLoaded()){var k=w.getBucket(n);if(k){var T=k.programConfigurations.get(n.id),A=e.context.program.get(),M=e.useProgram(d,T),S=m||M.program!==A,E=u.constantOr(null);if(E&&w.imageAtlas){var C=w.imageAtlas.patternPositions[E.to],L=w.imageAtlas.patternPositions[E.from];C&&L&&T.setConstantPatternPositions(C,L)}var P=c?Pr(e,w,n,c,p):h?Lr(e,w,n,p):f?Cr(e,w,n):Er(e,w,n);c&&(S||e.lineAtlas.dirty)?(g.activeTexture.set(v.TEXTURE0),e.lineAtlas.bind(g)):h&&(g.activeTexture.set(v.TEXTURE0),w.imageAtlasTexture.bind(v.LINEAR,v.CLAMP_TO_EDGE),T.updatePatternPaintBuffers(p)),M.draw(g,v.TRIANGLES,s,e.stencilModeForClipping(_),l,St.disabled,P,n.id,k.layoutVertexBuffer,k.indexBuffer,k.segments,n.paint,e.transform.zoom,T),m=!1}}}}}},fill:function(e,r,n,i){var a=n.paint.get(\"fill-color\"),o=n.paint.get(\"fill-opacity\");if(0!==o.constantOr(1)){var s=e.colorModeForRenderPass(),l=n.paint.get(\"fill-pattern\"),c=e.opaquePassEnabledForLayer()&&!l.constantOr(1)&&1===a.constantOr(t.Color.transparent).a&&1===o.constantOr(0)?\"opaque\":\"translucent\";if(e.renderPass===c){var u=e.depthModeForSublayer(1,\"opaque\"===e.renderPass?Tt.ReadWrite:Tt.ReadOnly);Xr(e,r,n,i,u,s,!1)}if(\"translucent\"===e.renderPass&&n.paint.get(\"fill-antialias\")){var h=e.depthModeForSublayer(n.getPaintProperty(\"fill-outline-color\")?2:0,Tt.ReadOnly);Xr(e,r,n,i,h,s,!0)}}},\"fill-extrusion\":function(t,e,r,n){var i=r.paint.get(\"fill-extrusion-opacity\");if(0!==i&&\"translucent\"===t.renderPass){var a=new Tt(t.context.gl.LEQUAL,Tt.ReadWrite,t.depthRangeFor3D);if(1!==i||r.paint.get(\"fill-extrusion-pattern\").constantOr(1))Zr(t,e,r,n,a,At.disabled,Mt.disabled),Zr(t,e,r,n,a,t.stencilModeFor3D(),t.colorModeForRenderPass());else{var o=t.colorModeForRenderPass();Zr(t,e,r,n,a,At.disabled,o)}}},hillshade:function(t,e,r,n){if(\"offscreen\"===t.renderPass||\"translucent\"===t.renderPass){for(var i=t.context,a=e.getSource().maxzoom,o=t.depthModeForSublayer(0,Tt.ReadOnly),s=At.disabled,l=t.colorModeForRenderPass(),c=0,u=n;c<u.length;c+=1){var h=u[c],f=e.getTile(h);f.needsHillshadePrepare&&\"offscreen\"===t.renderPass?Kr(t,f,r,a,o,s,l):\"translucent\"===t.renderPass&&Jr(t,f,r,o,s,l)}i.viewport.set([0,0,t.width,t.height])}},raster:function(t,e,r,n){if(\"translucent\"===t.renderPass&&0!==r.paint.get(\"raster-opacity\"))for(var i=t.context,a=i.gl,o=e.getSource(),s=t.useProgram(\"raster\"),l=At.disabled,c=t.colorModeForRenderPass(),u=n.length&&n[0].overscaledZ,h=!t.options.moving,f=0,p=n;f<p.length;f+=1){var d=p[f],g=t.depthModeForSublayer(d.overscaledZ-u,1===r.paint.get(\"raster-opacity\")?Tt.ReadWrite:Tt.ReadOnly,a.LESS),v=e.getTile(d),m=t.transform.calculatePosMatrix(d.toUnwrapped(),h);v.registerFadeDuration(r.paint.get(\"raster-fade-duration\"));var y=e.findLoadedParent(d,0),x=$r(v,y,e,r,t.transform),b=void 0,_=void 0,w=\"nearest\"===r.paint.get(\"raster-resampling\")?a.NEAREST:a.LINEAR;i.activeTexture.set(a.TEXTURE0),v.texture.bind(w,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),i.activeTexture.set(a.TEXTURE1),y?(y.texture.bind(w,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),b=Math.pow(2,y.tileID.overscaledZ-v.tileID.overscaledZ),_=[v.tileID.canonical.x*b%1,v.tileID.canonical.y*b%1]):v.texture.bind(w,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST);var k=Ir(m,_||[0,0],b||1,x,r);o instanceof L?s.draw(i,a.TRIANGLES,g,l,c,St.disabled,k,r.id,o.boundsBuffer,t.quadTriangleIndexBuffer,o.boundsSegments):v.maskedBoundsBuffer&&v.maskedIndexBuffer&&v.segments?s.draw(i,a.TRIANGLES,g,l,c,St.disabled,k,r.id,v.maskedBoundsBuffer,v.maskedIndexBuffer,v.segments,r.paint,t.transform.zoom):s.draw(i,a.TRIANGLES,g,l,c,St.disabled,k,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}},background:function(t,e,r){var n=r.paint.get(\"background-color\"),i=r.paint.get(\"background-opacity\");if(0!==i){var a=t.context,o=a.gl,s=t.transform,l=s.tileSize,c=r.paint.get(\"background-pattern\");if(!t.isPatternMissing(c)){var u=c||1!==n.a||1!==i?\"translucent\":\"opaque\";if(t.renderPass===u){var h=At.disabled,f=t.depthModeForSublayer(0,\"opaque\"===u?Tt.ReadWrite:Tt.ReadOnly),p=t.colorModeForRenderPass(),d=t.useProgram(c?\"backgroundPattern\":\"background\"),g=s.coveringTiles({tileSize:l});c&&(a.activeTexture.set(o.TEXTURE0),t.imageManager.bind(t.context));for(var v=r.getCrossfadeParameters(),m=0,y=g;m<y.length;m+=1){var x=y[m],b=t.transform.calculatePosMatrix(x.toUnwrapped()),_=c?Br(b,i,t,c,{tileID:x,tileSize:l},v):Fr(b,i,n);d.draw(a,o.TRIANGLES,f,h,p,St.disabled,_,r.id,t.tileExtentBuffer,t.quadTriangleIndexBuffer,t.tileExtentSegments)}}}}},debug:function(t,e,r){for(var n=0;n<r.length;n++)Qr(t,e,r[n])},custom:function(t,e,r){var n=t.context,i=r.implementation;if(\"offscreen\"===t.renderPass){var a=i.prerender;a&&(t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),a.call(i,n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState())}else if(\"translucent\"===t.renderPass){t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),n.setStencilMode(At.disabled);var o=\"3d\"===i.renderingMode?new Tt(t.context.gl.LEQUAL,Tt.ReadWrite,t.depthRangeFor3D):t.depthModeForSublayer(0,Tt.ReadOnly);n.setDepthMode(o),i.render(n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState(),n.bindFramebuffer.set(null)}}},rn=function(e,r){this.context=new Et(e),this.transform=r,this._tileTextures={},this.setup(),this.numSublayers=Ct.maxUnderzooming+Ct.maxOverzooming+1,this.depthEpsilon=1/Math.pow(2,16),this.depthRboNeedsClear=!0,this.emptyProgramConfiguration=new t.ProgramConfiguration,this.crossTileSymbolIndex=new Pe};function nn(t,e){if(t.y>e.y){var r=t;t=e,e=r}return{x0:t.x,y0:t.y,x1:e.x,y1:e.y,dx:e.x-t.x,dy:e.y-t.y}}function an(t,e,r,n,i){var a=Math.max(r,Math.floor(e.y0)),o=Math.min(n,Math.ceil(e.y1));if(t.x0===e.x0&&t.y0===e.y0?t.x0+e.dy/t.dy*t.dx<e.x1:t.x1-e.dy/t.dy*t.dx<e.x0){var s=t;t=e,e=s}for(var l=t.dx/t.dy,c=e.dx/e.dy,u=t.dx>0,h=e.dx<0,f=a;f<o;f++){var p=l*Math.max(0,Math.min(t.dy,f+u-t.y0))+t.x0,d=c*Math.max(0,Math.min(e.dy,f+h-e.y0))+e.x0;i(Math.floor(d),Math.ceil(p),f)}}function on(t,e,r,n,i,a){var o,s=nn(t,e),l=nn(e,r),c=nn(r,t);s.dy>l.dy&&(o=s,s=l,l=o),s.dy>c.dy&&(o=s,s=c,c=o),l.dy>c.dy&&(o=l,l=c,c=o),s.dy&&an(c,s,n,i,a),l.dy&&an(c,l,n,i,a)}rn.prototype.resize=function(e,r){var n=this.context.gl;if(this.width=e*t.browser.devicePixelRatio,this.height=r*t.browser.devicePixelRatio,this.context.viewport.set([0,0,this.width,this.height]),this.style)for(var i=0,a=this.style._order;i<a.length;i+=1){var o=a[i];this.style._layers[o].resize()}this.depthRbo&&(n.deleteRenderbuffer(this.depthRbo),this.depthRbo=null)},rn.prototype.setup=function(){var e=this.context,r=new t.StructArrayLayout2i4;r.emplaceBack(0,0),r.emplaceBack(t.EXTENT,0),r.emplaceBack(0,t.EXTENT),r.emplaceBack(t.EXTENT,t.EXTENT),this.tileExtentBuffer=e.createVertexBuffer(r,Re.members),this.tileExtentSegments=t.SegmentVector.simpleSegment(0,0,4,2);var n=new t.StructArrayLayout2i4;n.emplaceBack(0,0),n.emplaceBack(t.EXTENT,0),n.emplaceBack(0,t.EXTENT),n.emplaceBack(t.EXTENT,t.EXTENT),this.debugBuffer=e.createVertexBuffer(n,Re.members),this.debugSegments=t.SegmentVector.simpleSegment(0,0,4,5);var i=new t.StructArrayLayout4i8;i.emplaceBack(0,0,0,0),i.emplaceBack(t.EXTENT,0,t.EXTENT,0),i.emplaceBack(0,t.EXTENT,0,t.EXTENT),i.emplaceBack(t.EXTENT,t.EXTENT,t.EXTENT,t.EXTENT),this.rasterBoundsBuffer=e.createVertexBuffer(i,t.rasterBoundsAttributes.members),this.rasterBoundsSegments=t.SegmentVector.simpleSegment(0,0,4,2);var a=new t.StructArrayLayout2i4;a.emplaceBack(0,0),a.emplaceBack(1,0),a.emplaceBack(0,1),a.emplaceBack(1,1),this.viewportBuffer=e.createVertexBuffer(a,Re.members),this.viewportSegments=t.SegmentVector.simpleSegment(0,0,4,2);var o=new t.StructArrayLayout1ui2;o.emplaceBack(0),o.emplaceBack(1),o.emplaceBack(3),o.emplaceBack(2),o.emplaceBack(0),this.tileBorderIndexBuffer=e.createIndexBuffer(o);var s=new t.StructArrayLayout3ui6;s.emplaceBack(0,1,2),s.emplaceBack(2,1,3),this.quadTriangleIndexBuffer=e.createIndexBuffer(s);var l=this.context.gl;this.stencilClearMode=new At({func:l.ALWAYS,mask:0},0,255,l.ZERO,l.ZERO,l.ZERO)},rn.prototype.clearStencil=function(){var e=this.context,r=e.gl;this.nextStencilID=1,this.currentStencilSource=void 0;var n=t.create();t.ortho(n,0,this.width,this.height,0,0,1),t.scale(n,n,[r.drawingBufferWidth,r.drawingBufferHeight,0]),this.useProgram(\"clippingMask\").draw(e,r.TRIANGLES,Tt.disabled,this.stencilClearMode,Mt.disabled,St.disabled,kr(n),\"$clipping\",this.viewportBuffer,this.quadTriangleIndexBuffer,this.viewportSegments)},rn.prototype._renderTileClippingMasks=function(t,e){if(this.currentStencilSource!==t.source&&t.isTileClipped()&&e&&e.length){this.currentStencilSource=t.source;var r=this.context,n=r.gl;this.nextStencilID+e.length>256&&this.clearStencil(),r.setColorMode(Mt.disabled),r.setDepthMode(Tt.disabled);var i=this.useProgram(\"clippingMask\");this._tileClippingMaskIDs={};for(var a=0,o=e;a<o.length;a+=1){var s=o[a],l=this._tileClippingMaskIDs[s.key]=this.nextStencilID++;i.draw(r,n.TRIANGLES,Tt.disabled,new At({func:n.ALWAYS,mask:0},l,255,n.KEEP,n.KEEP,n.REPLACE),Mt.disabled,St.disabled,kr(s.posMatrix),\"$clipping\",this.tileExtentBuffer,this.quadTriangleIndexBuffer,this.tileExtentSegments)}}},rn.prototype.stencilModeFor3D=function(){this.nextStencilID+1>256&&this.clearStencil();var t=this.nextStencilID++,e=this.context.gl;return new At({func:e.NOTEQUAL,mask:255},t,255,e.KEEP,e.KEEP,e.REPLACE)},rn.prototype.stencilModeForClipping=function(t){var e=this.context.gl;return new At({func:e.EQUAL,mask:255},this._tileClippingMaskIDs[t.key],0,e.KEEP,e.KEEP,e.REPLACE)},rn.prototype.colorModeForRenderPass=function(){var e=this.context.gl;return this._showOverdrawInspector?new Mt([e.CONSTANT_COLOR,e.ONE],new t.Color(1/8,1/8,1/8,0),[!0,!0,!0,!0]):\"opaque\"===this.renderPass?Mt.unblended:Mt.alphaBlended},rn.prototype.depthModeForSublayer=function(t,e,r){if(!this.opaquePassEnabledForLayer())return Tt.disabled;var n=1-((1+this.currentLayer)*this.numSublayers+t)*this.depthEpsilon;return new Tt(r||this.context.gl.LEQUAL,e,[n,n])},rn.prototype.opaquePassEnabledForLayer=function(){return this.currentLayer<this.opaquePassCutoff},rn.prototype.render=function(e,r){this.style=e,this.options=r,this.lineAtlas=e.lineAtlas,this.imageManager=e.imageManager,this.glyphManager=e.glyphManager,this.symbolFadeChange=e.placement.symbolFadeChange(t.browser.now()),this.imageManager.beginFrame();var n=this.style._order,i=this.style.sourceCaches;for(var a in i){var o=i[a];o.used&&o.prepare(this.context)}var s={},l={},c={};for(var u in i){var h=i[u];s[u]=h.getVisibleCoordinates(),l[u]=s[u].slice().reverse(),c[u]=h.getVisibleCoordinates(!0).reverse()}for(var f in i){var p=i[f],d=p.getSource();if(\"raster\"===d.type||\"raster-dem\"===d.type){for(var g=[],v=0,m=s[f];v<m.length;v+=1){var y=m[v];g.push(p.getTile(y))}jr(g,this.context)}}this.opaquePassCutoff=1/0;for(var x=0;x<n.length;x++){var b=n[x];if(this.style._layers[b].is3D()){this.opaquePassCutoff=x;break}}this.renderPass=\"offscreen\",this.depthRboNeedsClear=!0;for(var _=0,w=n;_<w.length;_+=1){var k=w[_],T=this.style._layers[k];if(T.hasOffscreenPass()&&!T.isHidden(this.transform.zoom)){var A=l[T.source];(\"custom\"===T.type||A.length)&&this.renderLayer(this,i[T.source],T,A)}}for(this.context.bindFramebuffer.set(null),this.context.clear({color:r.showOverdrawInspector?t.Color.black:t.Color.transparent,depth:1}),this.clearStencil(),this._showOverdrawInspector=r.showOverdrawInspector,this.depthRangeFor3D=[0,1-(e._order.length+2)*this.numSublayers*this.depthEpsilon],this.renderPass=\"opaque\",this.currentLayer=n.length-1;this.currentLayer>=0;this.currentLayer--){var M=this.style._layers[n[this.currentLayer]],S=i[M.source],E=s[M.source];this._renderTileClippingMasks(M,E),this.renderLayer(this,S,M,E)}for(this.renderPass=\"translucent\",this.currentLayer=0;this.currentLayer<n.length;this.currentLayer++){var C=this.style._layers[n[this.currentLayer]],L=i[C.source],P=(\"symbol\"===C.type?c:l)[C.source];this._renderTileClippingMasks(C,s[C.source]),this.renderLayer(this,L,C,P)}if(this.options.showTileBoundaries)for(var O in i){en.debug(this,i[O],s[O]);break}this.context.setDefault()},rn.prototype.setupOffscreenDepthRenderbuffer=function(){var t=this.context;this.depthRbo||(this.depthRbo=t.createRenderbuffer(t.gl.DEPTH_COMPONENT16,this.width,this.height))},rn.prototype.renderLayer=function(t,e,r,n){r.isHidden(this.transform.zoom)||(\"background\"===r.type||\"custom\"===r.type||n.length)&&(this.id=r.id,en[r.type](t,e,r,n,this.style.placement.variableOffsets))},rn.prototype.translatePosMatrix=function(e,r,n,i,a){if(!n[0]&&!n[1])return e;var o=a?\"map\"===i?this.transform.angle:0:\"viewport\"===i?-this.transform.angle:0;if(o){var s=Math.sin(o),l=Math.cos(o);n=[n[0]*l-n[1]*s,n[0]*s+n[1]*l]}var c=[a?n[0]:le(r,n[0],this.transform.zoom),a?n[1]:le(r,n[1],this.transform.zoom),0],u=new Float32Array(16);return t.translate(u,e,c),u},rn.prototype.saveTileTexture=function(t){var e=this._tileTextures[t.size[0]];e?e.push(t):this._tileTextures[t.size[0]]=[t]},rn.prototype.getTileTexture=function(t){var e=this._tileTextures[t];return e&&e.length>0?e.pop():null},rn.prototype.isPatternMissing=function(t){if(!t)return!1;var e=this.imageManager.getPattern(t.from),r=this.imageManager.getPattern(t.to);return!e||!r},rn.prototype.useProgram=function(t,e){void 0===e&&(e=this.emptyProgramConfiguration),this.cache=this.cache||{};var r=\"\"+t+(e.cacheKey||\"\")+(this._showOverdrawInspector?\"/overdraw\":\"\");return this.cache[r]||(this.cache[r]=new hr(this.context,cr[t],e,Nr[t],this._showOverdrawInspector)),this.cache[r]},rn.prototype.setCustomLayerDefaults=function(){this.context.unbindVAO(),this.context.cullFace.setDefault(),this.context.activeTexture.setDefault(),this.context.pixelStoreUnpack.setDefault(),this.context.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.context.pixelStoreUnpackFlipY.setDefault()},rn.prototype.setBaseState=function(){var t=this.context.gl;this.context.cullFace.set(!1),this.context.viewport.set([0,0,this.width,this.height]),this.context.blendEquation.set(t.FUNC_ADD)};var sn=function(e,r,n){this.tileSize=512,this.maxValidLatitude=85.051129,this._renderWorldCopies=void 0===n||n,this._minZoom=e||0,this._maxZoom=r||22,this.setMaxBounds(),this.width=0,this.height=0,this._center=new t.LngLat(0,0),this.zoom=0,this.angle=0,this._fov=.6435011087932844,this._pitch=0,this._unmodified=!0,this._posMatrixCache={},this._alignedPosMatrixCache={}},ln={minZoom:{configurable:!0},maxZoom:{configurable:!0},renderWorldCopies:{configurable:!0},worldSize:{configurable:!0},centerPoint:{configurable:!0},size:{configurable:!0},bearing:{configurable:!0},pitch:{configurable:!0},fov:{configurable:!0},zoom:{configurable:!0},center:{configurable:!0},unmodified:{configurable:!0},point:{configurable:!0}};sn.prototype.clone=function(){var t=new sn(this._minZoom,this._maxZoom,this._renderWorldCopies);return t.tileSize=this.tileSize,t.latRange=this.latRange,t.width=this.width,t.height=this.height,t._center=this._center,t.zoom=this.zoom,t.angle=this.angle,t._fov=this._fov,t._pitch=this._pitch,t._unmodified=this._unmodified,t._calcMatrices(),t},ln.minZoom.get=function(){return this._minZoom},ln.minZoom.set=function(t){this._minZoom!==t&&(this._minZoom=t,this.zoom=Math.max(this.zoom,t))},ln.maxZoom.get=function(){return this._maxZoom},ln.maxZoom.set=function(t){this._maxZoom!==t&&(this._maxZoom=t,this.zoom=Math.min(this.zoom,t))},ln.renderWorldCopies.get=function(){return this._renderWorldCopies},ln.renderWorldCopies.set=function(t){void 0===t?t=!0:null===t&&(t=!1),this._renderWorldCopies=t},ln.worldSize.get=function(){return this.tileSize*this.scale},ln.centerPoint.get=function(){return this.size._div(2)},ln.size.get=function(){return new t.Point(this.width,this.height)},ln.bearing.get=function(){return-this.angle/Math.PI*180},ln.bearing.set=function(e){var r=-t.wrap(e,-180,180)*Math.PI/180;this.angle!==r&&(this._unmodified=!1,this.angle=r,this._calcMatrices(),this.rotationMatrix=t.create$2(),t.rotate(this.rotationMatrix,this.rotationMatrix,this.angle))},ln.pitch.get=function(){return this._pitch/Math.PI*180},ln.pitch.set=function(e){var r=t.clamp(e,0,60)/180*Math.PI;this._pitch!==r&&(this._unmodified=!1,this._pitch=r,this._calcMatrices())},ln.fov.get=function(){return this._fov/Math.PI*180},ln.fov.set=function(t){t=Math.max(.01,Math.min(60,t)),this._fov!==t&&(this._unmodified=!1,this._fov=t/180*Math.PI,this._calcMatrices())},ln.zoom.get=function(){return this._zoom},ln.zoom.set=function(t){var e=Math.min(Math.max(t,this.minZoom),this.maxZoom);this._zoom!==e&&(this._unmodified=!1,this._zoom=e,this.scale=this.zoomScale(e),this.tileZoom=Math.floor(e),this.zoomFraction=e-this.tileZoom,this._constrain(),this._calcMatrices())},ln.center.get=function(){return this._center},ln.center.set=function(t){t.lat===this._center.lat&&t.lng===this._center.lng||(this._unmodified=!1,this._center=t,this._constrain(),this._calcMatrices())},sn.prototype.coveringZoomLevel=function(t){return(t.roundZoom?Math.round:Math.floor)(this.zoom+this.scaleZoom(this.tileSize/t.tileSize))},sn.prototype.getVisibleUnwrappedCoordinates=function(e){var r=[new t.UnwrappedTileID(0,e)];if(this._renderWorldCopies)for(var n=this.pointCoordinate(new t.Point(0,0)),i=this.pointCoordinate(new t.Point(this.width,0)),a=this.pointCoordinate(new t.Point(this.width,this.height)),o=this.pointCoordinate(new t.Point(0,this.height)),s=Math.floor(Math.min(n.x,i.x,a.x,o.x)),l=Math.floor(Math.max(n.x,i.x,a.x,o.x)),c=s-1;c<=l+1;c++)0!==c&&r.push(new t.UnwrappedTileID(c,e));return r},sn.prototype.coveringTiles=function(e){var r=this.coveringZoomLevel(e),n=r;if(void 0!==e.minzoom&&r<e.minzoom)return[];void 0!==e.maxzoom&&r>e.maxzoom&&(r=e.maxzoom);var i=t.MercatorCoordinate.fromLngLat(this.center),a=Math.pow(2,r),o=new t.Point(a*i.x-.5,a*i.y-.5);return function(e,r,n,i){void 0===i&&(i=!0);var a=1<<e,o={};function s(r,s,l){var c,u,h,f;if(l>=0&&l<=a)for(c=r;c<s;c++)u=Math.floor(c/a),h=(c%a+a)%a,0!==u&&!0!==i||(f=new t.OverscaledTileID(n,u,e,h,l),o[f.key]=f)}var l=r.map(function(e){return new t.Point(e.x,e.y)._mult(a)});return on(l[0],l[1],l[2],0,a,s),on(l[2],l[3],l[0],0,a,s),Object.keys(o).map(function(t){return o[t]})}(r,[this.pointCoordinate(new t.Point(0,0)),this.pointCoordinate(new t.Point(this.width,0)),this.pointCoordinate(new t.Point(this.width,this.height)),this.pointCoordinate(new t.Point(0,this.height))],e.reparseOverscaled?n:r,this._renderWorldCopies).sort(function(t,e){return o.dist(t.canonical)-o.dist(e.canonical)})},sn.prototype.resize=function(t,e){this.width=t,this.height=e,this.pixelsToGLUnits=[2/t,-2/e],this._constrain(),this._calcMatrices()},ln.unmodified.get=function(){return this._unmodified},sn.prototype.zoomScale=function(t){return Math.pow(2,t)},sn.prototype.scaleZoom=function(t){return Math.log(t)/Math.LN2},sn.prototype.project=function(e){var r=t.clamp(e.lat,-this.maxValidLatitude,this.maxValidLatitude);return new t.Point(t.mercatorXfromLng(e.lng)*this.worldSize,t.mercatorYfromLat(r)*this.worldSize)},sn.prototype.unproject=function(e){return new t.MercatorCoordinate(e.x/this.worldSize,e.y/this.worldSize).toLngLat()},ln.point.get=function(){return this.project(this.center)},sn.prototype.setLocationAtPoint=function(e,r){var n=this.pointCoordinate(r),i=this.pointCoordinate(this.centerPoint),a=this.locationCoordinate(e),o=new t.MercatorCoordinate(a.x-(n.x-i.x),a.y-(n.y-i.y));this.center=this.coordinateLocation(o),this._renderWorldCopies&&(this.center=this.center.wrap())},sn.prototype.locationPoint=function(t){return this.coordinatePoint(this.locationCoordinate(t))},sn.prototype.pointLocation=function(t){return this.coordinateLocation(this.pointCoordinate(t))},sn.prototype.locationCoordinate=function(e){return t.MercatorCoordinate.fromLngLat(e)},sn.prototype.coordinateLocation=function(t){return t.toLngLat()},sn.prototype.pointCoordinate=function(e){var r=[e.x,e.y,0,1],n=[e.x,e.y,1,1];t.transformMat4(r,r,this.pixelMatrixInverse),t.transformMat4(n,n,this.pixelMatrixInverse);var i=r[3],a=n[3],o=r[0]/i,s=n[0]/a,l=r[1]/i,c=n[1]/a,u=r[2]/i,h=n[2]/a,f=u===h?0:(0-u)/(h-u);return new t.MercatorCoordinate(t.number(o,s,f)/this.worldSize,t.number(l,c,f)/this.worldSize)},sn.prototype.coordinatePoint=function(e){var r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix),new t.Point(r[0]/r[3],r[1]/r[3])},sn.prototype.getBounds=function(){return(new t.LngLatBounds).extend(this.pointLocation(new t.Point(0,0))).extend(this.pointLocation(new t.Point(this.width,0))).extend(this.pointLocation(new t.Point(this.width,this.height))).extend(this.pointLocation(new t.Point(0,this.height)))},sn.prototype.getMaxBounds=function(){return this.latRange&&2===this.latRange.length&&this.lngRange&&2===this.lngRange.length?new t.LngLatBounds([this.lngRange[0],this.latRange[0]],[this.lngRange[1],this.latRange[1]]):null},sn.prototype.setMaxBounds=function(t){t?(this.lngRange=[t.getWest(),t.getEast()],this.latRange=[t.getSouth(),t.getNorth()],this._constrain()):(this.lngRange=null,this.latRange=[-this.maxValidLatitude,this.maxValidLatitude])},sn.prototype.calculatePosMatrix=function(e,r){void 0===r&&(r=!1);var n=e.key,i=r?this._alignedPosMatrixCache:this._posMatrixCache;if(i[n])return i[n];var a=e.canonical,o=this.worldSize/this.zoomScale(a.z),s=a.x+Math.pow(2,a.z)*e.wrap,l=t.identity(new Float64Array(16));return t.translate(l,l,[s*o,a.y*o,0]),t.scale(l,l,[o/t.EXTENT,o/t.EXTENT,1]),t.multiply(l,r?this.alignedProjMatrix:this.projMatrix,l),i[n]=new Float32Array(l),i[n]},sn.prototype.customLayerMatrix=function(){return this.mercatorMatrix.slice()},sn.prototype._constrain=function(){if(this.center&&this.width&&this.height&&!this._constraining){this._constraining=!0;var e,r,n,i,a=-90,o=90,s=-180,l=180,c=this.size,u=this._unmodified;if(this.latRange){var h=this.latRange;a=t.mercatorYfromLat(h[1])*this.worldSize,e=(o=t.mercatorYfromLat(h[0])*this.worldSize)-a<c.y?c.y/(o-a):0}if(this.lngRange){var f=this.lngRange;s=t.mercatorXfromLng(f[0])*this.worldSize,r=(l=t.mercatorXfromLng(f[1])*this.worldSize)-s<c.x?c.x/(l-s):0}var p=this.point,d=Math.max(r||0,e||0);if(d)return this.center=this.unproject(new t.Point(r?(l+s)/2:p.x,e?(o+a)/2:p.y)),this.zoom+=this.scaleZoom(d),this._unmodified=u,void(this._constraining=!1);if(this.latRange){var g=p.y,v=c.y/2;g-v<a&&(i=a+v),g+v>o&&(i=o-v)}if(this.lngRange){var m=p.x,y=c.x/2;m-y<s&&(n=s+y),m+y>l&&(n=l-y)}void 0===n&&void 0===i||(this.center=this.unproject(new t.Point(void 0!==n?n:p.x,void 0!==i?i:p.y))),this._unmodified=u,this._constraining=!1}},sn.prototype._calcMatrices=function(){if(this.height){this.cameraToCenterDistance=.5/Math.tan(this._fov/2)*this.height;var e=this._fov/2,r=Math.PI/2+this._pitch,n=Math.sin(e)*this.cameraToCenterDistance/Math.sin(Math.PI-r-e),i=this.point,a=i.x,o=i.y,s=1.01*(Math.cos(Math.PI/2-this._pitch)*n+this.cameraToCenterDistance),l=new Float64Array(16);t.perspective(l,this._fov,this.width/this.height,1,s),t.scale(l,l,[1,-1,1]),t.translate(l,l,[0,0,-this.cameraToCenterDistance]),t.rotateX(l,l,this._pitch),t.rotateZ(l,l,this.angle),t.translate(l,l,[-a,-o,0]),this.mercatorMatrix=t.scale([],l,[this.worldSize,this.worldSize,this.worldSize]),t.scale(l,l,[1,1,t.mercatorZfromAltitude(1,this.center.lat)*this.worldSize,1]),this.projMatrix=l;var c=this.width%2/2,u=this.height%2/2,h=Math.cos(this.angle),f=Math.sin(this.angle),p=a-Math.round(a)+h*c+f*u,d=o-Math.round(o)+h*u+f*c,g=new Float64Array(l);if(t.translate(g,g,[p>.5?p-1:p,d>.5?d-1:d,0]),this.alignedProjMatrix=g,l=t.create(),t.scale(l,l,[this.width/2,-this.height/2,1]),t.translate(l,l,[1,-1,0]),this.labelPlaneMatrix=l,l=t.create(),t.scale(l,l,[1,-1,1]),t.translate(l,l,[-1,-1,0]),t.scale(l,l,[2/this.width,2/this.height,1]),this.glCoordMatrix=l,this.pixelMatrix=t.multiply(new Float64Array(16),this.labelPlaneMatrix,this.projMatrix),!(l=t.invert(new Float64Array(16),this.pixelMatrix)))throw new Error(\"failed to invert matrix\");this.pixelMatrixInverse=l,this._posMatrixCache={},this._alignedPosMatrixCache={}}},sn.prototype.maxPitchScaleFactor=function(){if(!this.pixelMatrixInverse)return 1;var e=this.pointCoordinate(new t.Point(0,0)),r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix)[3]/this.cameraToCenterDistance},sn.prototype.getCameraPoint=function(){var e=this._pitch,r=Math.tan(e)*(this.cameraToCenterDistance||1);return this.centerPoint.add(new t.Point(0,r))},sn.prototype.getCameraQueryGeometry=function(e){var r=this.getCameraPoint();if(1===e.length)return[e[0],r];for(var n=r.x,i=r.y,a=r.x,o=r.y,s=0,l=e;s<l.length;s+=1){var c=l[s];n=Math.min(n,c.x),i=Math.min(i,c.y),a=Math.max(a,c.x),o=Math.max(o,c.y)}return[new t.Point(n,i),new t.Point(a,i),new t.Point(a,o),new t.Point(n,o),new t.Point(n,i)]},Object.defineProperties(sn.prototype,ln);var cn=function(){var e,r,n,i;t.bindAll([\"_onHashChange\",\"_updateHash\"],this),this._updateHash=(e=this._updateHashUnthrottled.bind(this),300,r=!1,n=null,i=function(){n=null,r&&(e(),n=setTimeout(i,300),r=!1)},function(){return r=!0,n||i(),n})};cn.prototype.addTo=function(e){return this._map=e,t.window.addEventListener(\"hashchange\",this._onHashChange,!1),this._map.on(\"moveend\",this._updateHash),this},cn.prototype.remove=function(){return t.window.removeEventListener(\"hashchange\",this._onHashChange,!1),this._map.off(\"moveend\",this._updateHash),clearTimeout(this._updateHash()),delete this._map,this},cn.prototype.getHashString=function(t){var e=this._map.getCenter(),r=Math.round(100*this._map.getZoom())/100,n=Math.ceil((r*Math.LN2+Math.log(512/360/.5))/Math.LN10),i=Math.pow(10,n),a=Math.round(e.lng*i)/i,o=Math.round(e.lat*i)/i,s=this._map.getBearing(),l=this._map.getPitch(),c=\"\";return c+=t?\"#/\"+a+\"/\"+o+\"/\"+r:\"#\"+r+\"/\"+o+\"/\"+a,(s||l)&&(c+=\"/\"+Math.round(10*s)/10),l&&(c+=\"/\"+Math.round(l)),c},cn.prototype._onHashChange=function(){var e=t.window.location.hash.replace(\"#\",\"\").split(\"/\");return e.length>=3&&(this._map.jumpTo({center:[+e[2],+e[1]],zoom:+e[0],bearing:+(e[3]||0),pitch:+(e[4]||0)}),!0)},cn.prototype._updateHashUnthrottled=function(){var e=this.getHashString();try{t.window.history.replaceState(t.window.history.state,\"\",e)}catch(t){}};var un=function(e){function n(n,i,a,o){void 0===o&&(o={});var s=r.mousePos(i.getCanvasContainer(),a),l=i.unproject(s);e.call(this,n,t.extend({point:s,lngLat:l,originalEvent:a},o)),this._defaultPrevented=!1,this.target=i}e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),hn=function(e){function n(n,i,a){var o=r.touchPos(i.getCanvasContainer(),a),s=o.map(function(t){return i.unproject(t)}),l=o.reduce(function(t,e,r,n){return t.add(e.div(n.length))},new t.Point(0,0)),c=i.unproject(l);e.call(this,n,{points:o,point:l,lngLats:s,lngLat:c,originalEvent:a}),this._defaultPrevented=!1}e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),fn=function(t){function e(e,r,n){t.call(this,e,{originalEvent:n}),this._defaultPrevented=!1}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={defaultPrevented:{configurable:!0}};return e.prototype.preventDefault=function(){this._defaultPrevented=!0},r.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(e.prototype,r),e}(t.Event),pn=function(e){this._map=e,this._el=e.getCanvasContainer(),this._delta=0,this._defaultZoomRate=.01,this._wheelZoomRate=1/450,t.bindAll([\"_onWheel\",\"_onTimeout\",\"_onScrollFrame\",\"_onScrollFinished\"],this)};pn.prototype.setZoomRate=function(t){this._defaultZoomRate=t},pn.prototype.setWheelZoomRate=function(t){this._wheelZoomRate=t},pn.prototype.isEnabled=function(){return!!this._enabled},pn.prototype.isActive=function(){return!!this._active},pn.prototype.isZooming=function(){return!!this._zooming},pn.prototype.enable=function(t){this.isEnabled()||(this._enabled=!0,this._aroundCenter=t&&\"center\"===t.around)},pn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},pn.prototype.onWheel=function(e){if(this.isEnabled()){var r=e.deltaMode===t.window.WheelEvent.DOM_DELTA_LINE?40*e.deltaY:e.deltaY,n=t.browser.now(),i=n-(this._lastWheelEventTime||0);this._lastWheelEventTime=n,0!==r&&r%4.000244140625==0?this._type=\"wheel\":0!==r&&Math.abs(r)<4?this._type=\"trackpad\":i>400?(this._type=null,this._lastValue=r,this._timeout=setTimeout(this._onTimeout,40,e)):this._type||(this._type=Math.abs(i*r)<200?\"trackpad\":\"wheel\",this._timeout&&(clearTimeout(this._timeout),this._timeout=null,r+=this._lastValue)),e.shiftKey&&r&&(r/=4),this._type&&(this._lastWheelEvent=e,this._delta-=r,this.isActive()||this._start(e)),e.preventDefault()}},pn.prototype._onTimeout=function(t){this._type=\"wheel\",this._delta-=this._lastValue,this.isActive()||this._start(t)},pn.prototype._start=function(e){if(this._delta){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),this._active=!0,this.isZooming()||(this._zooming=!0,this._map.fire(new t.Event(\"movestart\",{originalEvent:e})),this._map.fire(new t.Event(\"zoomstart\",{originalEvent:e}))),this._finishTimeout&&clearTimeout(this._finishTimeout);var n=r.mousePos(this._el,e);this._around=t.LngLat.convert(this._aroundCenter?this._map.getCenter():this._map.unproject(n)),this._aroundPoint=this._map.transform.locationPoint(this._around),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onScrollFrame))}},pn.prototype._onScrollFrame=function(){var e=this;if(this._frameId=null,this.isActive()){var r=this._map.transform;if(0!==this._delta){var n=\"wheel\"===this._type&&Math.abs(this._delta)>4.000244140625?this._wheelZoomRate:this._defaultZoomRate,i=2/(1+Math.exp(-Math.abs(this._delta*n)));this._delta<0&&0!==i&&(i=1/i);var a=\"number\"==typeof this._targetZoom?r.zoomScale(this._targetZoom):r.scale;this._targetZoom=Math.min(r.maxZoom,Math.max(r.minZoom,r.scaleZoom(a*i))),\"wheel\"===this._type&&(this._startZoom=r.zoom,this._easing=this._smoothOutEasing(200)),this._delta=0}var o=\"number\"==typeof this._targetZoom?this._targetZoom:r.zoom,s=this._startZoom,l=this._easing,c=!1;if(\"wheel\"===this._type&&s&&l){var u=Math.min((t.browser.now()-this._lastWheelEventTime)/200,1),h=l(u);r.zoom=t.number(s,o,h),u<1?this._frameId||(this._frameId=this._map._requestRenderFrame(this._onScrollFrame)):c=!0}else r.zoom=o,c=!0;r.setLocationAtPoint(this._around,this._aroundPoint),this._map.fire(new t.Event(\"move\",{originalEvent:this._lastWheelEvent})),this._map.fire(new t.Event(\"zoom\",{originalEvent:this._lastWheelEvent})),c&&(this._active=!1,this._finishTimeout=setTimeout(function(){e._zooming=!1,e._map.fire(new t.Event(\"zoomend\",{originalEvent:e._lastWheelEvent})),e._map.fire(new t.Event(\"moveend\",{originalEvent:e._lastWheelEvent})),delete e._targetZoom},200))}},pn.prototype._smoothOutEasing=function(e){var r=t.ease;if(this._prevEase){var n=this._prevEase,i=(t.browser.now()-n.start)/n.duration,a=n.easing(i+.01)-n.easing(i),o=.27/Math.sqrt(a*a+1e-4)*.01,s=Math.sqrt(.0729-o*o);r=t.bezier(o,s,.25,1)}return this._prevEase={start:t.browser.now(),duration:e,easing:r},r};var dn=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._container=e.getContainer(),this._clickTolerance=r.clickTolerance||1,t.bindAll([\"_onMouseMove\",\"_onMouseUp\",\"_onKeyDown\"],this)};dn.prototype.isEnabled=function(){return!!this._enabled},dn.prototype.isActive=function(){return!!this._active},dn.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},dn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},dn.prototype.onMouseDown=function(e){this.isEnabled()&&e.shiftKey&&0===e.button&&(t.window.document.addEventListener(\"mousemove\",this._onMouseMove,!1),t.window.document.addEventListener(\"keydown\",this._onKeyDown,!1),t.window.document.addEventListener(\"mouseup\",this._onMouseUp,!1),r.disableDrag(),this._startPos=this._lastPos=r.mousePos(this._el,e),this._active=!0)},dn.prototype._onMouseMove=function(t){var e=r.mousePos(this._el,t);if(!(this._lastPos.equals(e)||!this._box&&e.dist(this._startPos)<this._clickTolerance)){var n=this._startPos;this._lastPos=e,this._box||(this._box=r.create(\"div\",\"mapboxgl-boxzoom\",this._container),this._container.classList.add(\"mapboxgl-crosshair\"),this._fireEvent(\"boxzoomstart\",t));var i=Math.min(n.x,e.x),a=Math.max(n.x,e.x),o=Math.min(n.y,e.y),s=Math.max(n.y,e.y);r.setTransform(this._box,\"translate(\"+i+\"px,\"+o+\"px)\"),this._box.style.width=a-i+\"px\",this._box.style.height=s-o+\"px\"}},dn.prototype._onMouseUp=function(e){if(0===e.button){var n=this._startPos,i=r.mousePos(this._el,e);this._finish(),r.suppressClick(),n.x===i.x&&n.y===i.y?this._fireEvent(\"boxzoomcancel\",e):this._map.fitScreenCoordinates(n,i,this._map.getBearing(),{linear:!0}).fire(new t.Event(\"boxzoomend\",{originalEvent:e}))}},dn.prototype._onKeyDown=function(t){27===t.keyCode&&(this._finish(),this._fireEvent(\"boxzoomcancel\",t))},dn.prototype._finish=function(){this._active=!1,t.window.document.removeEventListener(\"mousemove\",this._onMouseMove,!1),t.window.document.removeEventListener(\"keydown\",this._onKeyDown,!1),t.window.document.removeEventListener(\"mouseup\",this._onMouseUp,!1),this._container.classList.remove(\"mapboxgl-crosshair\"),this._box&&(r.remove(this._box),this._box=null),r.enableDrag(),delete this._startPos,delete this._lastPos},dn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,{originalEvent:r}))};var gn=t.bezier(0,0,.25,1),vn=function(e,r){this._map=e,this._el=r.element||e.getCanvasContainer(),this._state=\"disabled\",this._button=r.button||\"right\",this._bearingSnap=r.bearingSnap||0,this._pitchWithRotate=!1!==r.pitchWithRotate,t.bindAll([\"onMouseDown\",\"_onMouseMove\",\"_onMouseUp\",\"_onBlur\",\"_onDragFrame\"],this)};vn.prototype.isEnabled=function(){return\"disabled\"!==this._state},vn.prototype.isActive=function(){return\"active\"===this._state},vn.prototype.enable=function(){this.isEnabled()||(this._state=\"enabled\")},vn.prototype.disable=function(){if(this.isEnabled())switch(this._state){case\"active\":this._state=\"disabled\",this._unbind(),this._deactivate(),this._fireEvent(\"rotateend\"),this._pitchWithRotate&&this._fireEvent(\"pitchend\"),this._fireEvent(\"moveend\");break;case\"pending\":this._state=\"disabled\",this._unbind();break;default:this._state=\"disabled\"}},vn.prototype.onMouseDown=function(e){if(\"enabled\"===this._state){if(\"right\"===this._button){if(this._eventButton=r.mouseButton(e),this._eventButton!==(e.ctrlKey?0:2))return}else{if(e.ctrlKey||0!==r.mouseButton(e))return;this._eventButton=0}r.disableDrag(),t.window.document.addEventListener(\"mousemove\",this._onMouseMove,{capture:!0}),t.window.document.addEventListener(\"mouseup\",this._onMouseUp),t.window.addEventListener(\"blur\",this._onBlur),this._state=\"pending\",this._inertia=[[t.browser.now(),this._map.getBearing()]],this._startPos=this._lastPos=r.mousePos(this._el,e),this._center=this._map.transform.centerPoint,e.preventDefault()}},vn.prototype._onMouseMove=function(t){var e=r.mousePos(this._el,t);this._lastPos.equals(e)||(this._lastMoveEvent=t,this._lastPos=e,\"pending\"===this._state&&(this._state=\"active\",this._fireEvent(\"rotatestart\",t),this._fireEvent(\"movestart\",t),this._pitchWithRotate&&this._fireEvent(\"pitchstart\",t)),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onDragFrame)))},vn.prototype._onDragFrame=function(){this._frameId=null;var e=this._lastMoveEvent;if(e){var r=this._map.transform,n=this._startPos,i=this._lastPos,a=.8*(n.x-i.x),o=-.5*(n.y-i.y),s=r.bearing-a,l=r.pitch-o,c=this._inertia,u=c[c.length-1];this._drainInertiaBuffer(),c.push([t.browser.now(),this._map._normalizeBearing(s,u[1])]),r.bearing=s,this._pitchWithRotate&&(this._fireEvent(\"pitch\",e),r.pitch=l),this._fireEvent(\"rotate\",e),this._fireEvent(\"move\",e),delete this._lastMoveEvent,this._startPos=this._lastPos}},vn.prototype._onMouseUp=function(t){if(r.mouseButton(t)===this._eventButton)switch(this._state){case\"active\":this._state=\"enabled\",r.suppressClick(),this._unbind(),this._deactivate(),this._inertialRotate(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},vn.prototype._onBlur=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._fireEvent(\"rotateend\",t),this._pitchWithRotate&&this._fireEvent(\"pitchend\",t),this._fireEvent(\"moveend\",t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},vn.prototype._unbind=function(){t.window.document.removeEventListener(\"mousemove\",this._onMouseMove,{capture:!0}),t.window.document.removeEventListener(\"mouseup\",this._onMouseUp),t.window.removeEventListener(\"blur\",this._onBlur),r.enableDrag()},vn.prototype._deactivate=function(){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._lastMoveEvent,delete this._startPos,delete this._lastPos},vn.prototype._inertialRotate=function(t){var e=this;this._fireEvent(\"rotateend\",t),this._drainInertiaBuffer();var r=this._map,n=r.getBearing(),i=this._inertia,a=function(){Math.abs(n)<e._bearingSnap?r.resetNorth({noMoveStart:!0},{originalEvent:t}):e._fireEvent(\"moveend\",t),e._pitchWithRotate&&e._fireEvent(\"pitchend\",t)};if(i.length<2)a();else{var o=i[0],s=i[i.length-1],l=i[i.length-2],c=r._normalizeBearing(n,l[1]),u=s[1]-o[1],h=u<0?-1:1,f=(s[0]-o[0])/1e3;if(0!==u&&0!==f){var p=Math.abs(u*(.25/f));p>180&&(p=180);var d=p/180;c+=h*p*(d/2),Math.abs(r._normalizeBearing(c,0))<this._bearingSnap&&(c=r._normalizeBearing(0,c)),r.rotateTo(c,{duration:1e3*d,easing:gn,noMoveStart:!0},{originalEvent:t})}else a()}},vn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},vn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>0&&r-e[0][0]>160;)e.shift()};var mn=t.bezier(0,0,.3,1),yn=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._state=\"disabled\",this._clickTolerance=r.clickTolerance||1,t.bindAll([\"_onMove\",\"_onMouseUp\",\"_onTouchEnd\",\"_onBlur\",\"_onDragFrame\"],this)};yn.prototype.isEnabled=function(){return\"disabled\"!==this._state},yn.prototype.isActive=function(){return\"active\"===this._state},yn.prototype.enable=function(){this.isEnabled()||(this._el.classList.add(\"mapboxgl-touch-drag-pan\"),this._state=\"enabled\")},yn.prototype.disable=function(){if(this.isEnabled())switch(this._el.classList.remove(\"mapboxgl-touch-drag-pan\"),this._state){case\"active\":this._state=\"disabled\",this._unbind(),this._deactivate(),this._fireEvent(\"dragend\"),this._fireEvent(\"moveend\");break;case\"pending\":this._state=\"disabled\",this._unbind();break;default:this._state=\"disabled\"}},yn.prototype.onMouseDown=function(e){\"enabled\"===this._state&&(e.ctrlKey||0!==r.mouseButton(e)||(r.addEventListener(t.window.document,\"mousemove\",this._onMove,{capture:!0}),r.addEventListener(t.window.document,\"mouseup\",this._onMouseUp),this._start(e)))},yn.prototype.onTouchStart=function(e){\"enabled\"===this._state&&(e.touches.length>1||(r.addEventListener(t.window.document,\"touchmove\",this._onMove,{capture:!0,passive:!1}),r.addEventListener(t.window.document,\"touchend\",this._onTouchEnd),this._start(e)))},yn.prototype._start=function(e){t.window.addEventListener(\"blur\",this._onBlur),this._state=\"pending\",this._startPos=this._mouseDownPos=this._lastPos=r.mousePos(this._el,e),this._inertia=[[t.browser.now(),this._startPos]]},yn.prototype._onMove=function(e){e.preventDefault();var n=r.mousePos(this._el,e);this._lastPos.equals(n)||\"pending\"===this._state&&n.dist(this._mouseDownPos)<this._clickTolerance||(this._lastMoveEvent=e,this._lastPos=n,this._drainInertiaBuffer(),this._inertia.push([t.browser.now(),this._lastPos]),\"pending\"===this._state&&(this._state=\"active\",this._fireEvent(\"dragstart\",e),this._fireEvent(\"movestart\",e)),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onDragFrame)))},yn.prototype._onDragFrame=function(){this._frameId=null;var t=this._lastMoveEvent;if(t){var e=this._map.transform;e.setLocationAtPoint(e.pointLocation(this._startPos),this._lastPos),this._fireEvent(\"drag\",t),this._fireEvent(\"move\",t),this._startPos=this._lastPos,delete this._lastMoveEvent}},yn.prototype._onMouseUp=function(t){if(0===r.mouseButton(t))switch(this._state){case\"active\":this._state=\"enabled\",r.suppressClick(),this._unbind(),this._deactivate(),this._inertialPan(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},yn.prototype._onTouchEnd=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._inertialPan(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},yn.prototype._onBlur=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._fireEvent(\"dragend\",t),this._fireEvent(\"moveend\",t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},yn.prototype._unbind=function(){r.removeEventListener(t.window.document,\"touchmove\",this._onMove,{capture:!0,passive:!1}),r.removeEventListener(t.window.document,\"touchend\",this._onTouchEnd),r.removeEventListener(t.window.document,\"mousemove\",this._onMove,{capture:!0}),r.removeEventListener(t.window.document,\"mouseup\",this._onMouseUp),r.removeEventListener(t.window,\"blur\",this._onBlur)},yn.prototype._deactivate=function(){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._lastMoveEvent,delete this._startPos,delete this._mouseDownPos,delete this._lastPos},yn.prototype._inertialPan=function(t){this._fireEvent(\"dragend\",t),this._drainInertiaBuffer();var e=this._inertia;if(e.length<2)this._fireEvent(\"moveend\",t);else{var r=e[e.length-1],n=e[0],i=r[1].sub(n[1]),a=(r[0]-n[0])/1e3;if(0===a||r[1].equals(n[1]))this._fireEvent(\"moveend\",t);else{var o=i.mult(.3/a),s=o.mag();s>1400&&(s=1400,o._unit()._mult(s));var l=s/750,c=o.mult(-l/2);this._map.panBy(c,{duration:1e3*l,easing:mn,noMoveStart:!0},{originalEvent:t})}}},yn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},yn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>0&&r-e[0][0]>160;)e.shift()};var xn=function(e){this._map=e,this._el=e.getCanvasContainer(),t.bindAll([\"_onKeyDown\"],this)};function bn(t){return t*(2-t)}xn.prototype.isEnabled=function(){return!!this._enabled},xn.prototype.enable=function(){this.isEnabled()||(this._el.addEventListener(\"keydown\",this._onKeyDown,!1),this._enabled=!0)},xn.prototype.disable=function(){this.isEnabled()&&(this._el.removeEventListener(\"keydown\",this._onKeyDown),this._enabled=!1)},xn.prototype._onKeyDown=function(t){if(!(t.altKey||t.ctrlKey||t.metaKey)){var e=0,r=0,n=0,i=0,a=0;switch(t.keyCode){case 61:case 107:case 171:case 187:e=1;break;case 189:case 109:case 173:e=-1;break;case 37:t.shiftKey?r=-1:(t.preventDefault(),i=-1);break;case 39:t.shiftKey?r=1:(t.preventDefault(),i=1);break;case 38:t.shiftKey?n=1:(t.preventDefault(),a=-1);break;case 40:t.shiftKey?n=-1:(a=1,t.preventDefault());break;default:return}var o=this._map,s=o.getZoom(),l={duration:300,delayEndEvents:500,easing:bn,zoom:e?Math.round(s)+e*(t.shiftKey?2:1):s,bearing:o.getBearing()+15*r,pitch:o.getPitch()+10*n,offset:[100*-i,100*-a],center:o.getCenter()};o.easeTo(l,{originalEvent:t})}};var _n=function(e){this._map=e,t.bindAll([\"_onDblClick\",\"_onZoomEnd\"],this)};_n.prototype.isEnabled=function(){return!!this._enabled},_n.prototype.isActive=function(){return!!this._active},_n.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},_n.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},_n.prototype.onTouchStart=function(t){var e=this;if(this.isEnabled()&&!(t.points.length>1))if(this._tapped){var r=t.points[0],n=this._tappedPoint;if(n&&n.dist(r)<=30){t.originalEvent.preventDefault();var i=function(){e._tapped&&e._zoom(t),e._map.off(\"touchcancel\",a),e._resetTapped()},a=function(){e._map.off(\"touchend\",i),e._resetTapped()};this._map.once(\"touchend\",i),this._map.once(\"touchcancel\",a)}else this._resetTapped()}else this._tappedPoint=t.points[0],this._tapped=setTimeout(function(){e._tapped=null,e._tappedPoint=null},300)},_n.prototype._resetTapped=function(){clearTimeout(this._tapped),this._tapped=null,this._tappedPoint=null},_n.prototype.onDblClick=function(t){this.isEnabled()&&(t.originalEvent.preventDefault(),this._zoom(t))},_n.prototype._zoom=function(t){this._active=!0,this._map.on(\"zoomend\",this._onZoomEnd),this._map.zoomTo(this._map.getZoom()+(t.originalEvent.shiftKey?-1:1),{around:t.lngLat},t)},_n.prototype._onZoomEnd=function(){this._active=!1,this._map.off(\"zoomend\",this._onZoomEnd)};var wn=t.bezier(0,0,.15,1),kn=function(e){this._map=e,this._el=e.getCanvasContainer(),t.bindAll([\"_onMove\",\"_onEnd\",\"_onTouchFrame\"],this)};kn.prototype.isEnabled=function(){return!!this._enabled},kn.prototype.enable=function(t){this.isEnabled()||(this._el.classList.add(\"mapboxgl-touch-zoom-rotate\"),this._enabled=!0,this._aroundCenter=!!t&&\"center\"===t.around)},kn.prototype.disable=function(){this.isEnabled()&&(this._el.classList.remove(\"mapboxgl-touch-zoom-rotate\"),this._enabled=!1)},kn.prototype.disableRotation=function(){this._rotationDisabled=!0},kn.prototype.enableRotation=function(){this._rotationDisabled=!1},kn.prototype.onStart=function(e){if(this.isEnabled()&&2===e.touches.length){var n=r.mousePos(this._el,e.touches[0]),i=r.mousePos(this._el,e.touches[1]),a=n.add(i).div(2);this._startVec=n.sub(i),this._startAround=this._map.transform.pointLocation(a),this._gestureIntent=void 0,this._inertia=[],r.addEventListener(t.window.document,\"touchmove\",this._onMove,{passive:!1}),r.addEventListener(t.window.document,\"touchend\",this._onEnd)}},kn.prototype._getTouchEventData=function(t){var e=r.mousePos(this._el,t.touches[0]),n=r.mousePos(this._el,t.touches[1]),i=e.sub(n);return{vec:i,center:e.add(n).div(2),scale:i.mag()/this._startVec.mag(),bearing:this._rotationDisabled?0:180*i.angleWith(this._startVec)/Math.PI}},kn.prototype._onMove=function(e){if(2===e.touches.length){var r=this._getTouchEventData(e),n=r.vec,i=r.scale,a=r.bearing;if(!this._gestureIntent){var o=this._rotationDisabled&&1!==i||Math.abs(1-i)>.15;Math.abs(a)>10?this._gestureIntent=\"rotate\":o&&(this._gestureIntent=\"zoom\"),this._gestureIntent&&(this._map.fire(new t.Event(this._gestureIntent+\"start\",{originalEvent:e})),this._map.fire(new t.Event(\"movestart\",{originalEvent:e})),this._startVec=n)}this._lastTouchEvent=e,this._frameId||(this._frameId=this._map._requestRenderFrame(this._onTouchFrame)),e.preventDefault()}},kn.prototype._onTouchFrame=function(){this._frameId=null;var e=this._gestureIntent;if(e){var r=this._map.transform;this._startScale||(this._startScale=r.scale,this._startBearing=r.bearing);var n=this._getTouchEventData(this._lastTouchEvent),i=n.center,a=n.bearing,o=n.scale,s=r.pointLocation(i),l=r.locationPoint(s);\"rotate\"===e&&(r.bearing=this._startBearing+a),r.zoom=r.scaleZoom(this._startScale*o),r.setLocationAtPoint(this._startAround,l),this._map.fire(new t.Event(e,{originalEvent:this._lastTouchEvent})),this._map.fire(new t.Event(\"move\",{originalEvent:this._lastTouchEvent})),this._drainInertiaBuffer(),this._inertia.push([t.browser.now(),o,i])}},kn.prototype._onEnd=function(e){r.removeEventListener(t.window.document,\"touchmove\",this._onMove,{passive:!1}),r.removeEventListener(t.window.document,\"touchend\",this._onEnd);var n=this._gestureIntent,i=this._startScale;if(this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._gestureIntent,delete this._startScale,delete this._startBearing,delete this._lastTouchEvent,n){this._map.fire(new t.Event(n+\"end\",{originalEvent:e})),this._drainInertiaBuffer();var a=this._inertia,o=this._map;if(a.length<2)o.snapToNorth({},{originalEvent:e});else{var s=a[a.length-1],l=a[0],c=o.transform.scaleZoom(i*s[1]),u=o.transform.scaleZoom(i*l[1]),h=c-u,f=(s[0]-l[0])/1e3,p=s[2];if(0!==f&&c!==u){var d=.15*h/f;Math.abs(d)>2.5&&(d=d>0?2.5:-2.5);var g=1e3*Math.abs(d/(12*.15)),v=c+d*g/2e3;v<0&&(v=0),o.easeTo({zoom:v,duration:g,easing:wn,around:this._aroundCenter?o.getCenter():o.unproject(p),noMoveStart:!0},{originalEvent:e})}else o.snapToNorth({},{originalEvent:e})}}},kn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>2&&r-e[0][0]>160;)e.shift()};var Tn={scrollZoom:pn,boxZoom:dn,dragRotate:vn,dragPan:yn,keyboard:xn,doubleClickZoom:_n,touchZoomRotate:kn},An=function(e){function r(r,n){e.call(this),this._moving=!1,this._zooming=!1,this.transform=r,this._bearingSnap=n.bearingSnap,t.bindAll([\"_renderFrameCallback\"],this)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getCenter=function(){return new t.LngLat(this.transform.center.lng,this.transform.center.lat)},r.prototype.setCenter=function(t,e){return this.jumpTo({center:t},e)},r.prototype.panBy=function(e,r,n){return e=t.Point.convert(e).mult(-1),this.panTo(this.transform.center,t.extend({offset:e},r),n)},r.prototype.panTo=function(e,r,n){return this.easeTo(t.extend({center:e},r),n)},r.prototype.getZoom=function(){return this.transform.zoom},r.prototype.setZoom=function(t,e){return this.jumpTo({zoom:t},e),this},r.prototype.zoomTo=function(e,r,n){return this.easeTo(t.extend({zoom:e},r),n)},r.prototype.zoomIn=function(t,e){return this.zoomTo(this.getZoom()+1,t,e),this},r.prototype.zoomOut=function(t,e){return this.zoomTo(this.getZoom()-1,t,e),this},r.prototype.getBearing=function(){return this.transform.bearing},r.prototype.setBearing=function(t,e){return this.jumpTo({bearing:t},e),this},r.prototype.rotateTo=function(e,r,n){return this.easeTo(t.extend({bearing:e},r),n)},r.prototype.resetNorth=function(e,r){return this.rotateTo(0,t.extend({duration:1e3},e),r),this},r.prototype.snapToNorth=function(t,e){return Math.abs(this.getBearing())<this._bearingSnap?this.resetNorth(t,e):this},r.prototype.getPitch=function(){return this.transform.pitch},r.prototype.setPitch=function(t,e){return this.jumpTo({pitch:t},e),this},r.prototype.cameraForBounds=function(e,r){return e=t.LngLatBounds.convert(e),this._cameraForBoxAndBearing(e.getNorthWest(),e.getSouthEast(),0,r)},r.prototype._cameraForBoxAndBearing=function(e,r,n,i){if(\"number\"==typeof(i=t.extend({padding:{top:0,bottom:0,right:0,left:0},offset:[0,0],maxZoom:this.transform.maxZoom},i)).padding){var a=i.padding;i.padding={top:a,bottom:a,right:a,left:a}}if(t.deepEqual(Object.keys(i.padding).sort(function(t,e){return t<e?-1:t>e?1:0}),[\"bottom\",\"left\",\"right\",\"top\"])){var o=this.transform,s=o.project(t.LngLat.convert(e)),l=o.project(t.LngLat.convert(r)),c=s.rotate(-n*Math.PI/180),u=l.rotate(-n*Math.PI/180),h=new t.Point(Math.max(c.x,u.x),Math.max(c.y,u.y)),f=new t.Point(Math.min(c.x,u.x),Math.min(c.y,u.y)),p=h.sub(f),d=(o.width-i.padding.left-i.padding.right)/p.x,g=(o.height-i.padding.top-i.padding.bottom)/p.y;if(!(g<0||d<0)){var v=Math.min(o.scaleZoom(o.scale*Math.min(d,g)),i.maxZoom),m=t.Point.convert(i.offset),y=(i.padding.left-i.padding.right)/2,x=(i.padding.top-i.padding.bottom)/2,b=new t.Point(m.x+y,m.y+x).mult(o.scale/o.zoomScale(v));return{center:o.unproject(s.add(l).div(2).sub(b)),zoom:v,bearing:n}}t.warnOnce(\"Map cannot fit within canvas with the given bounds, padding, and/or offset.\")}else t.warnOnce(\"options.padding must be a positive number, or an Object with keys 'bottom', 'left', 'right', 'top'\")},r.prototype.fitBounds=function(t,e,r){return this._fitInternal(this.cameraForBounds(t,e),e,r)},r.prototype.fitScreenCoordinates=function(e,r,n,i,a){return this._fitInternal(this._cameraForBoxAndBearing(this.transform.pointLocation(t.Point.convert(e)),this.transform.pointLocation(t.Point.convert(r)),n,i),i,a)},r.prototype._fitInternal=function(e,r,n){return e?(r=t.extend(e,r)).linear?this.easeTo(r,n):this.flyTo(r,n):this},r.prototype.jumpTo=function(e,r){this.stop();var n=this.transform,i=!1,a=!1,o=!1;return\"zoom\"in e&&n.zoom!==+e.zoom&&(i=!0,n.zoom=+e.zoom),void 0!==e.center&&(n.center=t.LngLat.convert(e.center)),\"bearing\"in e&&n.bearing!==+e.bearing&&(a=!0,n.bearing=+e.bearing),\"pitch\"in e&&n.pitch!==+e.pitch&&(o=!0,n.pitch=+e.pitch),this.fire(new t.Event(\"movestart\",r)).fire(new t.Event(\"move\",r)),i&&this.fire(new t.Event(\"zoomstart\",r)).fire(new t.Event(\"zoom\",r)).fire(new t.Event(\"zoomend\",r)),a&&this.fire(new t.Event(\"rotatestart\",r)).fire(new t.Event(\"rotate\",r)).fire(new t.Event(\"rotateend\",r)),o&&this.fire(new t.Event(\"pitchstart\",r)).fire(new t.Event(\"pitch\",r)).fire(new t.Event(\"pitchend\",r)),this.fire(new t.Event(\"moveend\",r))},r.prototype.easeTo=function(e,r){var n=this;this.stop(),!1===(e=t.extend({offset:[0,0],duration:500,easing:t.ease},e)).animate&&(e.duration=0);var i=this.transform,a=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=\"zoom\"in e?+e.zoom:a,c=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,u=\"pitch\"in e?+e.pitch:s,h=i.centerPoint.add(t.Point.convert(e.offset)),f=i.pointLocation(h),p=t.LngLat.convert(e.center||f);this._normalizeCenter(p);var d,g,v=i.project(f),m=i.project(p).sub(v),y=i.zoomScale(l-a);return e.around&&(d=t.LngLat.convert(e.around),g=i.locationPoint(d)),this._zooming=l!==a,this._rotating=o!==c,this._pitching=u!==s,this._prepareEase(r,e.noMoveStart),clearTimeout(this._easeEndTimeoutID),this._ease(function(e){if(n._zooming&&(i.zoom=t.number(a,l,e)),n._rotating&&(i.bearing=t.number(o,c,e)),n._pitching&&(i.pitch=t.number(s,u,e)),d)i.setLocationAtPoint(d,g);else{var f=i.zoomScale(i.zoom-a),p=l>a?Math.min(2,y):Math.max(.5,y),x=Math.pow(p,1-e),b=i.unproject(v.add(m.mult(e*x)).mult(f));i.setLocationAtPoint(i.renderWorldCopies?b.wrap():b,h)}n._fireMoveEvents(r)},function(){e.delayEndEvents?n._easeEndTimeoutID=setTimeout(function(){return n._afterEase(r)},e.delayEndEvents):n._afterEase(r)},e),this},r.prototype._prepareEase=function(e,r){this._moving=!0,r||this.fire(new t.Event(\"movestart\",e)),this._zooming&&this.fire(new t.Event(\"zoomstart\",e)),this._rotating&&this.fire(new t.Event(\"rotatestart\",e)),this._pitching&&this.fire(new t.Event(\"pitchstart\",e))},r.prototype._fireMoveEvents=function(e){this.fire(new t.Event(\"move\",e)),this._zooming&&this.fire(new t.Event(\"zoom\",e)),this._rotating&&this.fire(new t.Event(\"rotate\",e)),this._pitching&&this.fire(new t.Event(\"pitch\",e))},r.prototype._afterEase=function(e){var r=this._zooming,n=this._rotating,i=this._pitching;this._moving=!1,this._zooming=!1,this._rotating=!1,this._pitching=!1,r&&this.fire(new t.Event(\"zoomend\",e)),n&&this.fire(new t.Event(\"rotateend\",e)),i&&this.fire(new t.Event(\"pitchend\",e)),this.fire(new t.Event(\"moveend\",e))},r.prototype.flyTo=function(e,r){var n=this;this.stop(),e=t.extend({offset:[0,0],speed:1.2,curve:1.42,easing:t.ease},e);var i=this.transform,a=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=\"zoom\"in e?t.clamp(+e.zoom,i.minZoom,i.maxZoom):a,c=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,u=\"pitch\"in e?+e.pitch:s,h=i.zoomScale(l-a),f=i.centerPoint.add(t.Point.convert(e.offset)),p=i.pointLocation(f),d=t.LngLat.convert(e.center||p);this._normalizeCenter(d);var g=i.project(p),v=i.project(d).sub(g),m=e.curve,y=Math.max(i.width,i.height),x=y/h,b=v.mag();if(\"minZoom\"in e){var _=t.clamp(Math.min(e.minZoom,a,l),i.minZoom,i.maxZoom),w=y/i.zoomScale(_-a);m=Math.sqrt(w/b*2)}var k=m*m;function T(t){var e=(x*x-y*y+(t?-1:1)*k*k*b*b)/(2*(t?x:y)*k*b);return Math.log(Math.sqrt(e*e+1)-e)}function A(t){return(Math.exp(t)-Math.exp(-t))/2}function M(t){return(Math.exp(t)+Math.exp(-t))/2}var S=T(0),E=function(t){return M(S)/M(S+m*t)},C=function(t){return y*((M(S)*(A(e=S+m*t)/M(e))-A(S))/k)/b;var e},L=(T(1)-S)/m;if(Math.abs(b)<1e-6||!isFinite(L)){if(Math.abs(y-x)<1e-6)return this.easeTo(e,r);var P=x<y?-1:1;L=Math.abs(Math.log(x/y))/m,C=function(){return 0},E=function(t){return Math.exp(P*m*t)}}if(\"duration\"in e)e.duration=+e.duration;else{var O=\"screenSpeed\"in e?+e.screenSpeed/m:+e.speed;e.duration=1e3*L/O}return e.maxDuration&&e.duration>e.maxDuration&&(e.duration=0),this._zooming=!0,this._rotating=o!==c,this._pitching=u!==s,this._prepareEase(r,!1),this._ease(function(e){var h=e*L,p=1/E(h);i.zoom=1===e?l:a+i.scaleZoom(p),n._rotating&&(i.bearing=t.number(o,c,e)),n._pitching&&(i.pitch=t.number(s,u,e));var m=1===e?d:i.unproject(g.add(v.mult(C(h))).mult(p));i.setLocationAtPoint(i.renderWorldCopies?m.wrap():m,f),n._fireMoveEvents(r)},function(){return n._afterEase(r)},e),this},r.prototype.isEasing=function(){return!!this._easeFrameId},r.prototype.stop=function(){if(this._easeFrameId&&(this._cancelRenderFrame(this._easeFrameId),delete this._easeFrameId,delete this._onEaseFrame),this._onEaseEnd){var t=this._onEaseEnd;delete this._onEaseEnd,t.call(this)}return this},r.prototype._ease=function(e,r,n){!1===n.animate||0===n.duration?(e(1),r()):(this._easeStart=t.browser.now(),this._easeOptions=n,this._onEaseFrame=e,this._onEaseEnd=r,this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback))},r.prototype._renderFrameCallback=function(){var e=Math.min((t.browser.now()-this._easeStart)/this._easeOptions.duration,1);this._onEaseFrame(this._easeOptions.easing(e)),e<1?this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback):this.stop()},r.prototype._normalizeBearing=function(e,r){e=t.wrap(e,-180,180);var n=Math.abs(e-r);return Math.abs(e-360-r)<n&&(e-=360),Math.abs(e+360-r)<n&&(e+=360),e},r.prototype._normalizeCenter=function(t){var e=this.transform;if(e.renderWorldCopies&&!e.lngRange){var r=t.lng-e.center.lng;t.lng+=r>180?-360:r<-180?360:0}},r}(t.Evented),Mn=function(e){void 0===e&&(e={}),this.options=e,t.bindAll([\"_updateEditLink\",\"_updateData\",\"_updateCompact\"],this)};Mn.prototype.getDefaultPosition=function(){return\"bottom-right\"},Mn.prototype.onAdd=function(t){var e=this.options&&this.options.compact;return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-attrib\"),this._innerContainer=r.create(\"div\",\"mapboxgl-ctrl-attrib-inner\",this._container),e&&this._container.classList.add(\"mapboxgl-compact\"),this._updateAttributions(),this._updateEditLink(),this._map.on(\"styledata\",this._updateData),this._map.on(\"sourcedata\",this._updateData),this._map.on(\"moveend\",this._updateEditLink),void 0===e&&(this._map.on(\"resize\",this._updateCompact),this._updateCompact()),this._container},Mn.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"styledata\",this._updateData),this._map.off(\"sourcedata\",this._updateData),this._map.off(\"moveend\",this._updateEditLink),this._map.off(\"resize\",this._updateCompact),this._map=void 0},Mn.prototype._updateEditLink=function(){var e=this._editLink;e||(e=this._editLink=this._container.querySelector(\".mapbox-improve-map\"));var r=[{key:\"owner\",value:this.styleOwner},{key:\"id\",value:this.styleId},{key:\"access_token\",value:t.config.ACCESS_TOKEN}];if(e){var n=r.reduce(function(t,e,n){return e.value&&(t+=e.key+\"=\"+e.value+(n<r.length-1?\"&\":\"\")),t},\"?\");e.href=t.config.FEEDBACK_URL+\"/\"+n+(this._map._hash?this._map._hash.getHashString(!0):\"\"),e.rel=\"noopener nofollow\"}},Mn.prototype._updateData=function(t){!t||\"metadata\"!==t.sourceDataType&&\"style\"!==t.dataType||(this._updateAttributions(),this._updateEditLink())},Mn.prototype._updateAttributions=function(){if(this._map.style){var t=[];if(this.options.customAttribution&&(Array.isArray(this.options.customAttribution)?t=t.concat(this.options.customAttribution.map(function(t){return\"string\"!=typeof t?\"\":t})):\"string\"==typeof this.options.customAttribution&&t.push(this.options.customAttribution)),this._map.style.stylesheet){var e=this._map.style.stylesheet;this.styleOwner=e.owner,this.styleId=e.id}var r=this._map.style.sourceCaches;for(var n in r){var i=r[n];if(i.used){var a=i.getSource();a.attribution&&t.indexOf(a.attribution)<0&&t.push(a.attribution)}}t.sort(function(t,e){return t.length-e.length});var o=(t=t.filter(function(e,r){for(var n=r+1;n<t.length;n++)if(t[n].indexOf(e)>=0)return!1;return!0})).join(\" | \");o!==this._attribHTML&&(this._attribHTML=o,t.length?(this._innerContainer.innerHTML=o,this._container.classList.remove(\"mapboxgl-attrib-empty\")):this._container.classList.add(\"mapboxgl-attrib-empty\"),this._editLink=null)}},Mn.prototype._updateCompact=function(){this._map.getCanvasContainer().offsetWidth<=640?this._container.classList.add(\"mapboxgl-compact\"):this._container.classList.remove(\"mapboxgl-compact\")};var Sn=function(){t.bindAll([\"_updateLogo\"],this),t.bindAll([\"_updateCompact\"],this)};Sn.prototype.onAdd=function(t){this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl\");var e=r.create(\"a\",\"mapboxgl-ctrl-logo\");return e.target=\"_blank\",e.rel=\"noopener nofollow\",e.href=\"https://www.mapbox.com/\",e.setAttribute(\"aria-label\",\"Mapbox logo\"),e.setAttribute(\"rel\",\"noopener nofollow\"),this._container.appendChild(e),this._container.style.display=\"none\",this._map.on(\"sourcedata\",this._updateLogo),this._updateLogo(),this._map.on(\"resize\",this._updateCompact),this._updateCompact(),this._container},Sn.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"sourcedata\",this._updateLogo),this._map.off(\"resize\",this._updateCompact)},Sn.prototype.getDefaultPosition=function(){return\"bottom-left\"},Sn.prototype._updateLogo=function(t){t&&\"metadata\"!==t.sourceDataType||(this._container.style.display=this._logoRequired()?\"block\":\"none\")},Sn.prototype._logoRequired=function(){if(this._map.style){var t=this._map.style.sourceCaches;for(var e in t)if(t[e].getSource().mapbox_logo)return!0;return!1}},Sn.prototype._updateCompact=function(){var t=this._container.children;if(t.length){var e=t[0];this._map.getCanvasContainer().offsetWidth<250?e.classList.add(\"mapboxgl-compact\"):e.classList.remove(\"mapboxgl-compact\")}};var En=function(){this._queue=[],this._id=0,this._cleared=!1,this._currentlyRunning=!1};En.prototype.add=function(t){var e=++this._id;return this._queue.push({callback:t,id:e,cancelled:!1}),e},En.prototype.remove=function(t){for(var e=this._currentlyRunning,r=0,n=e?this._queue.concat(e):this._queue;r<n.length;r+=1){var i=n[r];if(i.id===t)return void(i.cancelled=!0)}},En.prototype.run=function(){var t=this._currentlyRunning=this._queue;this._queue=[];for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!n.cancelled&&(n.callback(),this._cleared))break}this._cleared=!1,this._currentlyRunning=!1},En.prototype.clear=function(){this._currentlyRunning&&(this._cleared=!0),this._queue=[]};var Cn=t.window.HTMLImageElement,Ln=t.window.HTMLElement,Pn={center:[0,0],zoom:0,bearing:0,pitch:0,minZoom:0,maxZoom:22,interactive:!0,scrollZoom:!0,boxZoom:!0,dragRotate:!0,dragPan:!0,keyboard:!0,doubleClickZoom:!0,touchZoomRotate:!0,bearingSnap:7,clickTolerance:3,hash:!1,attributionControl:!0,failIfMajorPerformanceCaveat:!1,preserveDrawingBuffer:!1,trackResize:!0,renderWorldCopies:!0,refreshExpiredTiles:!0,maxTileCacheSize:null,localIdeographFontFamily:\"sans-serif\",transformRequest:null,fadeDuration:300,crossSourceCollisions:!0},On=function(n){function i(e){var i=this;if(null!=(e=t.extend({},Pn,e)).minZoom&&null!=e.maxZoom&&e.minZoom>e.maxZoom)throw new Error(\"maxZoom must be greater than minZoom\");var a=new sn(e.minZoom,e.maxZoom,e.renderWorldCopies);if(n.call(this,a,e),this._interactive=e.interactive,this._maxTileCacheSize=e.maxTileCacheSize,this._failIfMajorPerformanceCaveat=e.failIfMajorPerformanceCaveat,this._preserveDrawingBuffer=e.preserveDrawingBuffer,this._antialias=e.antialias,this._trackResize=e.trackResize,this._bearingSnap=e.bearingSnap,this._refreshExpiredTiles=e.refreshExpiredTiles,this._fadeDuration=e.fadeDuration,this._crossSourceCollisions=e.crossSourceCollisions,this._crossFadingFactor=1,this._collectResourceTiming=e.collectResourceTiming,this._renderTaskQueue=new En,this._controls=[],this._mapId=t.uniqueId(),this._requestManager=new t.RequestManager(e.transformRequest),\"string\"==typeof e.container){if(this._container=t.window.document.getElementById(e.container),!this._container)throw new Error(\"Container '\"+e.container+\"' not found.\")}else{if(!(e.container instanceof Ln))throw new Error(\"Invalid type: 'container' must be a String or HTMLElement.\");this._container=e.container}if(e.maxBounds&&this.setMaxBounds(e.maxBounds),t.bindAll([\"_onWindowOnline\",\"_onWindowResize\",\"_contextLost\",\"_contextRestored\"],this),this._setupContainer(),this._setupPainter(),void 0===this.painter)throw new Error(\"Failed to initialize WebGL.\");this.on(\"move\",function(){return i._update(!1)}),this.on(\"moveend\",function(){return i._update(!1)}),this.on(\"zoom\",function(){return i._update(!0)}),void 0!==t.window&&(t.window.addEventListener(\"online\",this._onWindowOnline,!1),t.window.addEventListener(\"resize\",this._onWindowResize,!1)),function(t,e){var n=t.getCanvasContainer(),i=null,a=!1,o=null;for(var s in Tn)t[s]=new Tn[s](t,e),e.interactive&&e[s]&&t[s].enable(e[s]);r.addEventListener(n,\"mouseout\",function(e){t.fire(new un(\"mouseout\",t,e))}),r.addEventListener(n,\"mousedown\",function(i){a=!0,o=r.mousePos(n,i);var s=new un(\"mousedown\",t,i);t.fire(s),s.defaultPrevented||(e.interactive&&!t.doubleClickZoom.isActive()&&t.stop(),t.boxZoom.onMouseDown(i),t.boxZoom.isActive()||t.dragPan.isActive()||t.dragRotate.onMouseDown(i),t.boxZoom.isActive()||t.dragRotate.isActive()||t.dragPan.onMouseDown(i))}),r.addEventListener(n,\"mouseup\",function(e){var r=t.dragRotate.isActive();i&&!r&&t.fire(new un(\"contextmenu\",t,i)),i=null,a=!1,t.fire(new un(\"mouseup\",t,e))}),r.addEventListener(n,\"mousemove\",function(e){if(!t.dragPan.isActive()&&!t.dragRotate.isActive()){for(var r=e.target;r&&r!==n;)r=r.parentNode;r===n&&t.fire(new un(\"mousemove\",t,e))}}),r.addEventListener(n,\"mouseover\",function(e){for(var r=e.target;r&&r!==n;)r=r.parentNode;r===n&&t.fire(new un(\"mouseover\",t,e))}),r.addEventListener(n,\"touchstart\",function(r){var n=new hn(\"touchstart\",t,r);t.fire(n),n.defaultPrevented||(e.interactive&&t.stop(),t.boxZoom.isActive()||t.dragRotate.isActive()||t.dragPan.onTouchStart(r),t.touchZoomRotate.onStart(r),t.doubleClickZoom.onTouchStart(n))},{passive:!1}),r.addEventListener(n,\"touchmove\",function(e){t.fire(new hn(\"touchmove\",t,e))},{passive:!1}),r.addEventListener(n,\"touchend\",function(e){t.fire(new hn(\"touchend\",t,e))}),r.addEventListener(n,\"touchcancel\",function(e){t.fire(new hn(\"touchcancel\",t,e))}),r.addEventListener(n,\"click\",function(i){var a=r.mousePos(n,i);(a.equals(o)||a.dist(o)<e.clickTolerance)&&t.fire(new un(\"click\",t,i))}),r.addEventListener(n,\"dblclick\",function(e){var r=new un(\"dblclick\",t,e);t.fire(r),r.defaultPrevented||t.doubleClickZoom.onDblClick(r)}),r.addEventListener(n,\"contextmenu\",function(e){var r=t.dragRotate.isActive();a||r?a&&(i=e):t.fire(new un(\"contextmenu\",t,e)),(t.dragRotate.isEnabled()||t.listens(\"contextmenu\"))&&e.preventDefault()}),r.addEventListener(n,\"wheel\",function(r){e.interactive&&t.stop();var n=new fn(\"wheel\",t,r);t.fire(n),n.defaultPrevented||t.scrollZoom.onWheel(r)},{passive:!1})}(this,e),this._hash=e.hash&&(new cn).addTo(this),this._hash&&this._hash._onHashChange()||(this.jumpTo({center:e.center,zoom:e.zoom,bearing:e.bearing,pitch:e.pitch}),e.bounds&&(this.resize(),this.fitBounds(e.bounds,t.extend({},e.fitBoundsOptions,{duration:0})))),this.resize(),this._localIdeographFontFamily=e.localIdeographFontFamily,e.style&&this.setStyle(e.style,{localIdeographFontFamily:e.localIdeographFontFamily}),e.attributionControl&&this.addControl(new Mn({customAttribution:e.customAttribution})),this.addControl(new Sn,e.logoPosition),this.on(\"style.load\",function(){i.transform.unmodified&&i.jumpTo(i.style.stylesheet)}),this.on(\"data\",function(e){i._update(\"style\"===e.dataType),i.fire(new t.Event(e.dataType+\"data\",e))}),this.on(\"dataloading\",function(e){i.fire(new t.Event(e.dataType+\"dataloading\",e))})}n&&(i.__proto__=n),i.prototype=Object.create(n&&n.prototype),i.prototype.constructor=i;var a={showTileBoundaries:{configurable:!0},showCollisionBoxes:{configurable:!0},showOverdrawInspector:{configurable:!0},repaint:{configurable:!0},vertices:{configurable:!0}};return i.prototype._getMapId=function(){return this._mapId},i.prototype.addControl=function(e,r){if(void 0===r&&e.getDefaultPosition&&(r=e.getDefaultPosition()),void 0===r&&(r=\"top-right\"),!e||!e.onAdd)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.addControl(). Argument must be a control with onAdd and onRemove methods.\")));var n=e.onAdd(this);this._controls.push(e);var i=this._controlPositions[r];return-1!==r.indexOf(\"bottom\")?i.insertBefore(n,i.firstChild):i.appendChild(n),this},i.prototype.removeControl=function(e){if(!e||!e.onRemove)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.removeControl(). Argument must be a control with onAdd and onRemove methods.\")));var r=this._controls.indexOf(e);return r>-1&&this._controls.splice(r,1),e.onRemove(this),this},i.prototype.resize=function(e){var r=this._containerDimensions(),n=r[0],i=r[1];return this._resizeCanvas(n,i),this.transform.resize(n,i),this.painter.resize(n,i),this.fire(new t.Event(\"movestart\",e)).fire(new t.Event(\"move\",e)).fire(new t.Event(\"resize\",e)).fire(new t.Event(\"moveend\",e)),this},i.prototype.getBounds=function(){return this.transform.getBounds()},i.prototype.getMaxBounds=function(){return this.transform.getMaxBounds()},i.prototype.setMaxBounds=function(e){return this.transform.setMaxBounds(t.LngLatBounds.convert(e)),this._update()},i.prototype.setMinZoom=function(t){if((t=null==t?0:t)>=0&&t<=this.transform.maxZoom)return this.transform.minZoom=t,this._update(),this.getZoom()<t&&this.setZoom(t),this;throw new Error(\"minZoom must be between 0 and the current maxZoom, inclusive\")},i.prototype.getMinZoom=function(){return this.transform.minZoom},i.prototype.setMaxZoom=function(t){if((t=null==t?22:t)>=this.transform.minZoom)return this.transform.maxZoom=t,this._update(),this.getZoom()>t&&this.setZoom(t),this;throw new Error(\"maxZoom must be greater than the current minZoom\")},i.prototype.getRenderWorldCopies=function(){return this.transform.renderWorldCopies},i.prototype.setRenderWorldCopies=function(t){return this.transform.renderWorldCopies=t,this._update()},i.prototype.getMaxZoom=function(){return this.transform.maxZoom},i.prototype.project=function(e){return this.transform.locationPoint(t.LngLat.convert(e))},i.prototype.unproject=function(e){return this.transform.pointLocation(t.Point.convert(e))},i.prototype.isMoving=function(){return this._moving||this.dragPan.isActive()||this.dragRotate.isActive()||this.scrollZoom.isActive()},i.prototype.isZooming=function(){return this._zooming||this.scrollZoom.isZooming()},i.prototype.isRotating=function(){return this._rotating||this.dragRotate.isActive()},i.prototype.on=function(t,e,r){var i=this;if(void 0===r)return n.prototype.on.call(this,t,e);var a=function(){var n;if(\"mouseenter\"===t||\"mouseover\"===t){var a=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){var o=i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[];o.length?a||(a=!0,r.call(i,new un(t,i,n.originalEvent,{features:o}))):a=!1},mouseout:function(){a=!1}}}}if(\"mouseleave\"===t||\"mouseout\"===t){var o=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){(i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[]).length?o=!0:o&&(o=!1,r.call(i,new un(t,i,n.originalEvent)))},mouseout:function(e){o&&(o=!1,r.call(i,new un(t,i,e.originalEvent)))}}}}return{layer:e,listener:r,delegates:(n={},n[t]=function(t){var n=i.getLayer(e)?i.queryRenderedFeatures(t.point,{layers:[e]}):[];n.length&&(t.features=n,r.call(i,t),delete t.features)},n)}}();for(var o in this._delegatedListeners=this._delegatedListeners||{},this._delegatedListeners[t]=this._delegatedListeners[t]||[],this._delegatedListeners[t].push(a),a.delegates)this.on(o,a.delegates[o]);return this},i.prototype.off=function(t,e,r){if(void 0===r)return n.prototype.off.call(this,t,e);if(this._delegatedListeners&&this._delegatedListeners[t])for(var i=this._delegatedListeners[t],a=0;a<i.length;a++){var o=i[a];if(o.layer===e&&o.listener===r){for(var s in o.delegates)this.off(s,o.delegates[s]);return i.splice(a,1),this}}return this},i.prototype.queryRenderedFeatures=function(e,r){if(!this.style)return[];var n;if(void 0!==r||void 0===e||e instanceof t.Point||Array.isArray(e)||(r=e,e=void 0),r=r||{},(e=e||[[0,0],[this.transform.width,this.transform.height]])instanceof t.Point||\"number\"==typeof e[0])n=[t.Point.convert(e)];else{var i=t.Point.convert(e[0]),a=t.Point.convert(e[1]);n=[i,new t.Point(a.x,i.y),a,new t.Point(i.x,a.y),i]}return this.style.queryRenderedFeatures(n,r,this.transform)},i.prototype.querySourceFeatures=function(t,e){return this.style.querySourceFeatures(t,e)},i.prototype.setStyle=function(e,r){return!1!==(r=t.extend({},{localIdeographFontFamily:Pn.localIdeographFontFamily},r)).diff&&r.localIdeographFontFamily===this._localIdeographFontFamily&&this.style&&e?(this._diffStyle(e,r),this):(this._localIdeographFontFamily=r.localIdeographFontFamily,this._updateStyle(e,r))},i.prototype._updateStyle=function(t,e){return this.style&&(this.style.setEventedParent(null),this.style._remove()),t?(this.style=new De(this,e||{}),this.style.setEventedParent(this,{style:this.style}),\"string\"==typeof t?this.style.loadURL(t):this.style.loadJSON(t),this):(delete this.style,this)},i.prototype._diffStyle=function(e,r){var n=this;if(\"string\"==typeof e){var i=this._requestManager.normalizeStyleURL(e),a=this._requestManager.transformRequest(i,t.ResourceType.Style);t.getJSON(a,function(e,i){e?n.fire(new t.ErrorEvent(e)):i&&n._updateDiff(i,r)})}else\"object\"==typeof e&&this._updateDiff(e,r)},i.prototype._updateDiff=function(e,r){try{this.style.setState(e)&&this._update(!0)}catch(n){t.warnOnce(\"Unable to perform style diff: \"+(n.message||n.error||n)+\".  Rebuilding the style from scratch.\"),this._updateStyle(e,r)}},i.prototype.getStyle=function(){if(this.style)return this.style.serialize()},i.prototype.isStyleLoaded=function(){return this.style?this.style.loaded():t.warnOnce(\"There is no style added to the map.\")},i.prototype.addSource=function(t,e){return this.style.addSource(t,e),this._update(!0)},i.prototype.isSourceLoaded=function(e){var r=this.style&&this.style.sourceCaches[e];if(void 0!==r)return r.loaded();this.fire(new t.ErrorEvent(new Error(\"There is no source with ID '\"+e+\"'\")))},i.prototype.areTilesLoaded=function(){var t=this.style&&this.style.sourceCaches;for(var e in t){var r=t[e]._tiles;for(var n in r){var i=r[n];if(\"loaded\"!==i.state&&\"errored\"!==i.state)return!1}}return!0},i.prototype.addSourceType=function(t,e,r){return this.style.addSourceType(t,e,r)},i.prototype.removeSource=function(t){return this.style.removeSource(t),this._update(!0)},i.prototype.getSource=function(t){return this.style.getSource(t)},i.prototype.addImage=function(e,r,n){void 0===n&&(n={});var i=n.pixelRatio;void 0===i&&(i=1);var a=n.sdf;if(void 0===a&&(a=!1),r instanceof Cn){var o=t.browser.getImageData(r),s=o.width,l=o.height,c=o.data;this.style.addImage(e,{data:new t.RGBAImage({width:s,height:l},c),pixelRatio:i,sdf:a,version:0})}else{if(void 0===r.width||void 0===r.height)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.addImage(). The second argument must be an `HTMLImageElement`, `ImageData`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));var u=r.width,h=r.height,f=r.data,p=r;this.style.addImage(e,{data:new t.RGBAImage({width:u,height:h},new Uint8Array(f)),pixelRatio:i,sdf:a,version:0,userImage:p}),p.onAdd&&p.onAdd(this,e)}},i.prototype.updateImage=function(e,r){var n=this.style.getImage(e);if(!n)return this.fire(new t.ErrorEvent(new Error(\"The map has no image with that id. If you are adding a new image use `map.addImage(...)` instead.\")));var i=r instanceof Cn?t.browser.getImageData(r):r,a=i.width,o=i.height,s=i.data;if(void 0===a||void 0===o)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.updateImage(). The second argument must be an `HTMLImageElement`, `ImageData`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));if(a!==n.data.width||o!==n.data.height)return this.fire(new t.ErrorEvent(new Error(\"The width and height of the updated image must be that same as the previous version of the image\")));var l=!(r instanceof Cn);n.data.replace(s,l),this.style.updateImage(e,n)},i.prototype.hasImage=function(e){return e?!!this.style.getImage(e):(this.fire(new t.ErrorEvent(new Error(\"Missing required image id\"))),!1)},i.prototype.removeImage=function(t){this.style.removeImage(t)},i.prototype.loadImage=function(e,r){t.getImage(this._requestManager.transformRequest(e,t.ResourceType.Image),r)},i.prototype.listImages=function(){return this.style.listImages()},i.prototype.addLayer=function(t,e){return this.style.addLayer(t,e),this._update(!0)},i.prototype.moveLayer=function(t,e){return this.style.moveLayer(t,e),this._update(!0)},i.prototype.removeLayer=function(t){return this.style.removeLayer(t),this._update(!0)},i.prototype.getLayer=function(t){return this.style.getLayer(t)},i.prototype.setFilter=function(t,e,r){return void 0===r&&(r={}),this.style.setFilter(t,e,r),this._update(!0)},i.prototype.setLayerZoomRange=function(t,e,r){return this.style.setLayerZoomRange(t,e,r),this._update(!0)},i.prototype.getFilter=function(t){return this.style.getFilter(t)},i.prototype.setPaintProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setPaintProperty(t,e,r,n),this._update(!0)},i.prototype.getPaintProperty=function(t,e){return this.style.getPaintProperty(t,e)},i.prototype.setLayoutProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setLayoutProperty(t,e,r,n),this._update(!0)},i.prototype.getLayoutProperty=function(t,e){return this.style.getLayoutProperty(t,e)},i.prototype.setLight=function(t,e){return void 0===e&&(e={}),this.style.setLight(t,e),this._update(!0)},i.prototype.getLight=function(){return this.style.getLight()},i.prototype.setFeatureState=function(t,e){return this.style.setFeatureState(t,e),this._update()},i.prototype.removeFeatureState=function(t,e){return this.style.removeFeatureState(t,e),this._update()},i.prototype.getFeatureState=function(t){return this.style.getFeatureState(t)},i.prototype.getContainer=function(){return this._container},i.prototype.getCanvasContainer=function(){return this._canvasContainer},i.prototype.getCanvas=function(){return this._canvas},i.prototype._containerDimensions=function(){var t=0,e=0;return this._container&&(t=this._container.clientWidth||400,e=this._container.clientHeight||300),[t,e]},i.prototype._detectMissingCSS=function(){\"rgb(250, 128, 114)\"!==t.window.getComputedStyle(this._missingCSSCanary).getPropertyValue(\"background-color\")&&t.warnOnce(\"This page appears to be missing CSS declarations for Mapbox GL JS, which may cause the map to display incorrectly. Please ensure your page includes mapbox-gl.css, as described in https://www.mapbox.com/mapbox-gl-js/api/.\")},i.prototype._setupContainer=function(){var t=this._container;t.classList.add(\"mapboxgl-map\"),(this._missingCSSCanary=r.create(\"div\",\"mapboxgl-canary\",t)).style.visibility=\"hidden\",this._detectMissingCSS();var e=this._canvasContainer=r.create(\"div\",\"mapboxgl-canvas-container\",t);this._interactive&&e.classList.add(\"mapboxgl-interactive\"),this._canvas=r.create(\"canvas\",\"mapboxgl-canvas\",e),this._canvas.style.position=\"absolute\",this._canvas.addEventListener(\"webglcontextlost\",this._contextLost,!1),this._canvas.addEventListener(\"webglcontextrestored\",this._contextRestored,!1),this._canvas.setAttribute(\"tabindex\",\"0\"),this._canvas.setAttribute(\"aria-label\",\"Map\");var n=this._containerDimensions();this._resizeCanvas(n[0],n[1]);var i=this._controlContainer=r.create(\"div\",\"mapboxgl-control-container\",t),a=this._controlPositions={};[\"top-left\",\"top-right\",\"bottom-left\",\"bottom-right\"].forEach(function(t){a[t]=r.create(\"div\",\"mapboxgl-ctrl-\"+t,i)})},i.prototype._resizeCanvas=function(e,r){var n=t.window.devicePixelRatio||1;this._canvas.width=n*e,this._canvas.height=n*r,this._canvas.style.width=e+\"px\",this._canvas.style.height=r+\"px\"},i.prototype._setupPainter=function(){var r=t.extend({},e.webGLContextAttributes,{failIfMajorPerformanceCaveat:this._failIfMajorPerformanceCaveat,preserveDrawingBuffer:this._preserveDrawingBuffer,antialias:this._antialias||!1}),n=this._canvas.getContext(\"webgl\",r)||this._canvas.getContext(\"experimental-webgl\",r);n?(this.painter=new rn(n,this.transform),t.webpSupported.testSupport(n)):this.fire(new t.ErrorEvent(new Error(\"Failed to initialize WebGL\")))},i.prototype._contextLost=function(e){e.preventDefault(),this._frame&&(this._frame.cancel(),this._frame=null),this.fire(new t.Event(\"webglcontextlost\",{originalEvent:e}))},i.prototype._contextRestored=function(e){this._setupPainter(),this.resize(),this._update(),this.fire(new t.Event(\"webglcontextrestored\",{originalEvent:e}))},i.prototype.loaded=function(){return!this._styleDirty&&!this._sourcesDirty&&!!this.style&&this.style.loaded()},i.prototype._update=function(t){return this.style?(this._styleDirty=this._styleDirty||t,this._sourcesDirty=!0,this.triggerRepaint(),this):this},i.prototype._requestRenderFrame=function(t){return this._update(),this._renderTaskQueue.add(t)},i.prototype._cancelRenderFrame=function(t){this._renderTaskQueue.remove(t)},i.prototype._render=function(){this.painter.context.setDirty(),this.painter.setBaseState(),this._renderTaskQueue.run();var e=!1;if(this.style&&this._styleDirty){this._styleDirty=!1;var r=this.transform.zoom,n=t.browser.now();this.style.zoomHistory.update(r,n);var i=new t.EvaluationParameters(r,{now:n,fadeDuration:this._fadeDuration,zoomHistory:this.style.zoomHistory,transition:this.style.getTransition()}),a=i.crossFadingFactor();1===a&&a===this._crossFadingFactor||(e=!0,this._crossFadingFactor=a),this.style.update(i)}return this.style&&this._sourcesDirty&&(this._sourcesDirty=!1,this.style._updateSources(this.transform)),this._placementDirty=this.style&&this.style._updatePlacement(this.painter.transform,this.showCollisionBoxes,this._fadeDuration,this._crossSourceCollisions),this.painter.render(this.style,{showTileBoundaries:this.showTileBoundaries,showOverdrawInspector:this._showOverdrawInspector,rotating:this.isRotating(),zooming:this.isZooming(),moving:this.isMoving(),fadeDuration:this._fadeDuration}),this.fire(new t.Event(\"render\")),this.loaded()&&!this._loaded&&(this._loaded=!0,this.fire(new t.Event(\"load\"))),this.style&&(this.style.hasTransitions()||e)&&(this._styleDirty=!0),this.style&&!this._placementDirty&&this.style._releaseSymbolFadeTiles(),this._sourcesDirty||this._repaint||this._styleDirty||this._placementDirty?this.triggerRepaint():!this.isMoving()&&this.loaded()&&this.fire(new t.Event(\"idle\")),this},i.prototype.remove=function(){this._hash&&this._hash.remove();for(var e=0,r=this._controls;e<r.length;e+=1)r[e].onRemove(this);this._controls=[],this._frame&&(this._frame.cancel(),this._frame=null),this._renderTaskQueue.clear(),this.setStyle(null),void 0!==t.window&&(t.window.removeEventListener(\"resize\",this._onWindowResize,!1),t.window.removeEventListener(\"online\",this._onWindowOnline,!1));var n=this.painter.context.gl.getExtension(\"WEBGL_lose_context\");n&&n.loseContext(),zn(this._canvasContainer),zn(this._controlContainer),zn(this._missingCSSCanary),this._container.classList.remove(\"mapboxgl-map\"),this.fire(new t.Event(\"remove\"))},i.prototype.triggerRepaint=function(){var e=this;this.style&&!this._frame&&(this._frame=t.browser.frame(function(){e._frame=null,e._render()}))},i.prototype._onWindowOnline=function(){this._update()},i.prototype._onWindowResize=function(){this._trackResize&&this.resize()._update()},a.showTileBoundaries.get=function(){return!!this._showTileBoundaries},a.showTileBoundaries.set=function(t){this._showTileBoundaries!==t&&(this._showTileBoundaries=t,this._update())},a.showCollisionBoxes.get=function(){return!!this._showCollisionBoxes},a.showCollisionBoxes.set=function(t){this._showCollisionBoxes!==t&&(this._showCollisionBoxes=t,t?this.style._generateCollisionBoxes():this._update())},a.showOverdrawInspector.get=function(){return!!this._showOverdrawInspector},a.showOverdrawInspector.set=function(t){this._showOverdrawInspector!==t&&(this._showOverdrawInspector=t,this._update())},a.repaint.get=function(){return!!this._repaint},a.repaint.set=function(t){this._repaint!==t&&(this._repaint=t,this.triggerRepaint())},a.vertices.get=function(){return!!this._vertices},a.vertices.set=function(t){this._vertices=t,this._update()},i.prototype._setCacheLimits=function(e,r){t.setCacheLimits(e,r)},Object.defineProperties(i.prototype,a),i}(An);function zn(t){t.parentNode&&t.parentNode.removeChild(t)}var In={showCompass:!0,showZoom:!0},Dn=function(e){var n=this;this.options=t.extend({},In,e),this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),this._container.addEventListener(\"contextmenu\",function(t){return t.preventDefault()}),this.options.showZoom&&(t.bindAll([\"_updateZoomButtons\"],this),this._zoomInButton=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-zoom-in\",\"Zoom in\",function(){return n._map.zoomIn()}),this._zoomOutButton=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-zoom-out\",\"Zoom out\",function(){return n._map.zoomOut()})),this.options.showCompass&&(t.bindAll([\"_rotateCompassArrow\"],this),this._compass=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-compass\",\"Reset bearing to north\",function(){return n._map.resetNorth()}),this._compassArrow=r.create(\"span\",\"mapboxgl-ctrl-compass-arrow\",this._compass))};function Rn(e,r,n){if(e=new t.LngLat(e.lng,e.lat),r){var i=new t.LngLat(e.lng-360,e.lat),a=new t.LngLat(e.lng+360,e.lat),o=n.locationPoint(e).distSqr(r);n.locationPoint(i).distSqr(r)<o?e=i:n.locationPoint(a).distSqr(r)<o&&(e=a)}for(;Math.abs(e.lng-n.center.lng)>180;){var s=n.locationPoint(e);if(s.x>=0&&s.y>=0&&s.x<=n.width&&s.y<=n.height)break;e.lng>n.center.lng?e.lng-=360:e.lng+=360}return e}Dn.prototype._updateZoomButtons=function(){var t=this._map.getZoom();this._zoomInButton.classList.toggle(\"mapboxgl-ctrl-icon-disabled\",t===this._map.getMaxZoom()),this._zoomOutButton.classList.toggle(\"mapboxgl-ctrl-icon-disabled\",t===this._map.getMinZoom())},Dn.prototype._rotateCompassArrow=function(){var t=\"rotate(\"+this._map.transform.angle*(180/Math.PI)+\"deg)\";this._compassArrow.style.transform=t},Dn.prototype.onAdd=function(t){return this._map=t,this.options.showZoom&&(this._map.on(\"zoom\",this._updateZoomButtons),this._updateZoomButtons()),this.options.showCompass&&(this._map.on(\"rotate\",this._rotateCompassArrow),this._rotateCompassArrow(),this._handler=new vn(t,{button:\"left\",element:this._compass}),r.addEventListener(this._compass,\"mousedown\",this._handler.onMouseDown),this._handler.enable()),this._container},Dn.prototype.onRemove=function(){r.remove(this._container),this.options.showZoom&&this._map.off(\"zoom\",this._updateZoomButtons),this.options.showCompass&&(this._map.off(\"rotate\",this._rotateCompassArrow),r.removeEventListener(this._compass,\"mousedown\",this._handler.onMouseDown),this._handler.disable(),delete this._handler),delete this._map},Dn.prototype._createButton=function(t,e,n){var i=r.create(\"button\",t,this._container);return i.type=\"button\",i.title=e,i.setAttribute(\"aria-label\",e),i.addEventListener(\"click\",n),i};var Fn={center:\"translate(-50%,-50%)\",top:\"translate(-50%,0)\",\"top-left\":\"translate(0,0)\",\"top-right\":\"translate(-100%,0)\",bottom:\"translate(-50%,-100%)\",\"bottom-left\":\"translate(0,-100%)\",\"bottom-right\":\"translate(-100%,-100%)\",left:\"translate(0,-50%)\",right:\"translate(-100%,-50%)\"};function Bn(t,e,r){var n=t.classList;for(var i in Fn)n.remove(\"mapboxgl-\"+r+\"-anchor-\"+i);n.add(\"mapboxgl-\"+r+\"-anchor-\"+e)}var Nn,jn=function(e){function n(n,i){if(e.call(this),(n instanceof t.window.HTMLElement||i)&&(n=t.extend({element:n},i)),t.bindAll([\"_update\",\"_onMove\",\"_onUp\",\"_addDragHandler\",\"_onMapClick\"],this),this._anchor=n&&n.anchor||\"center\",this._color=n&&n.color||\"#3FB1CE\",this._draggable=n&&n.draggable||!1,this._state=\"inactive\",n&&n.element)this._element=n.element,this._offset=t.Point.convert(n&&n.offset||[0,0]);else{this._defaultMarker=!0,this._element=r.create(\"div\");var a=r.createNS(\"http://www.w3.org/2000/svg\",\"svg\");a.setAttributeNS(null,\"display\",\"block\"),a.setAttributeNS(null,\"height\",\"41px\"),a.setAttributeNS(null,\"width\",\"27px\"),a.setAttributeNS(null,\"viewBox\",\"0 0 27 41\");var o=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");o.setAttributeNS(null,\"stroke\",\"none\"),o.setAttributeNS(null,\"stroke-width\",\"1\"),o.setAttributeNS(null,\"fill\",\"none\"),o.setAttributeNS(null,\"fill-rule\",\"evenodd\");var s=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");s.setAttributeNS(null,\"fill-rule\",\"nonzero\");var l=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");l.setAttributeNS(null,\"transform\",\"translate(3.0, 29.0)\"),l.setAttributeNS(null,\"fill\",\"#000000\");for(var c=0,u=[{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"9.5\",ry:\"4.77275007\"},{rx:\"8.5\",ry:\"4.29549936\"},{rx:\"7.5\",ry:\"3.81822308\"},{rx:\"6.5\",ry:\"3.34094679\"},{rx:\"5.5\",ry:\"2.86367051\"},{rx:\"4.5\",ry:\"2.38636864\"}];c<u.length;c+=1){var h=u[c],f=r.createNS(\"http://www.w3.org/2000/svg\",\"ellipse\");f.setAttributeNS(null,\"opacity\",\"0.04\"),f.setAttributeNS(null,\"cx\",\"10.5\"),f.setAttributeNS(null,\"cy\",\"5.80029008\"),f.setAttributeNS(null,\"rx\",h.rx),f.setAttributeNS(null,\"ry\",h.ry),l.appendChild(f)}var p=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");p.setAttributeNS(null,\"fill\",this._color);var d=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");d.setAttributeNS(null,\"d\",\"M27,13.5 C27,19.074644 20.250001,27.000002 14.75,34.500002 C14.016665,35.500004 12.983335,35.500004 12.25,34.500002 C6.7499993,27.000002 0,19.222562 0,13.5 C0,6.0441559 6.0441559,0 13.5,0 C20.955844,0 27,6.0441559 27,13.5 Z\"),p.appendChild(d);var g=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");g.setAttributeNS(null,\"opacity\",\"0.25\"),g.setAttributeNS(null,\"fill\",\"#000000\");var v=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");v.setAttributeNS(null,\"d\",\"M13.5,0 C6.0441559,0 0,6.0441559 0,13.5 C0,19.222562 6.7499993,27 12.25,34.5 C13,35.522727 14.016664,35.500004 14.75,34.5 C20.250001,27 27,19.074644 27,13.5 C27,6.0441559 20.955844,0 13.5,0 Z M13.5,1 C20.415404,1 26,6.584596 26,13.5 C26,15.898657 24.495584,19.181431 22.220703,22.738281 C19.945823,26.295132 16.705119,30.142167 13.943359,33.908203 C13.743445,34.180814 13.612715,34.322738 13.5,34.441406 C13.387285,34.322738 13.256555,34.180814 13.056641,33.908203 C10.284481,30.127985 7.4148684,26.314159 5.015625,22.773438 C2.6163816,19.232715 1,15.953538 1,13.5 C1,6.584596 6.584596,1 13.5,1 Z\"),g.appendChild(v);var m=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");m.setAttributeNS(null,\"transform\",\"translate(6.0, 7.0)\"),m.setAttributeNS(null,\"fill\",\"#FFFFFF\");var y=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");y.setAttributeNS(null,\"transform\",\"translate(8.0, 8.0)\");var x=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");x.setAttributeNS(null,\"fill\",\"#000000\"),x.setAttributeNS(null,\"opacity\",\"0.25\"),x.setAttributeNS(null,\"cx\",\"5.5\"),x.setAttributeNS(null,\"cy\",\"5.5\"),x.setAttributeNS(null,\"r\",\"5.4999962\");var b=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");b.setAttributeNS(null,\"fill\",\"#FFFFFF\"),b.setAttributeNS(null,\"cx\",\"5.5\"),b.setAttributeNS(null,\"cy\",\"5.5\"),b.setAttributeNS(null,\"r\",\"5.4999962\"),y.appendChild(x),y.appendChild(b),s.appendChild(l),s.appendChild(p),s.appendChild(g),s.appendChild(m),s.appendChild(y),a.appendChild(s),this._element.appendChild(a),this._offset=t.Point.convert(n&&n.offset||[0,-14])}this._element.classList.add(\"mapboxgl-marker\"),this._element.addEventListener(\"dragstart\",function(t){t.preventDefault()}),Bn(this._element,this._anchor,\"marker\"),this._popup=null}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.addTo=function(t){return this.remove(),this._map=t,t.getCanvasContainer().appendChild(this._element),t.on(\"move\",this._update),t.on(\"moveend\",this._update),this.setDraggable(this._draggable),this._update(),this._map.on(\"click\",this._onMapClick),this},n.prototype.remove=function(){return this._map&&(this._map.off(\"click\",this._onMapClick),this._map.off(\"move\",this._update),this._map.off(\"moveend\",this._update),this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler),this._map.off(\"mouseup\",this._onUp),this._map.off(\"touchend\",this._onUp),delete this._map),r.remove(this._element),this._popup&&this._popup.remove(),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._popup&&this._popup.setLngLat(this._lngLat),this._update(),this},n.prototype.getElement=function(){return this._element},n.prototype.setPopup=function(t){if(this._popup&&(this._popup.remove(),this._popup=null),t){if(!(\"offset\"in t.options)){var e=Math.sqrt(Math.pow(13.5,2)/2);t.options.offset=this._defaultMarker?{top:[0,0],\"top-left\":[0,0],\"top-right\":[0,0],bottom:[0,-38.1],\"bottom-left\":[e,-1*(24.6+e)],\"bottom-right\":[-e,-1*(24.6+e)],left:[13.5,-24.6],right:[-13.5,-24.6]}:this._offset}this._popup=t,this._lngLat&&this._popup.setLngLat(this._lngLat)}return this},n.prototype._onMapClick=function(t){var e=t.originalEvent.target,r=this._element;this._popup&&(e===r||r.contains(e))&&this.togglePopup()},n.prototype.getPopup=function(){return this._popup},n.prototype.togglePopup=function(){var t=this._popup;return t?(t.isOpen()?t.remove():t.addTo(this._map),this):this},n.prototype._update=function(t){this._map&&(this._map.transform.renderWorldCopies&&(this._lngLat=Rn(this._lngLat,this._pos,this._map.transform)),this._pos=this._map.project(this._lngLat)._add(this._offset),t&&\"moveend\"!==t.type||(this._pos=this._pos.round()),r.setTransform(this._element,Fn[this._anchor]+\" translate(\"+this._pos.x+\"px, \"+this._pos.y+\"px)\"))},n.prototype.getOffset=function(){return this._offset},n.prototype.setOffset=function(e){return this._offset=t.Point.convert(e),this._update(),this},n.prototype._onMove=function(e){this._pos=e.point.sub(this._positionDelta),this._lngLat=this._map.unproject(this._pos),this.setLngLat(this._lngLat),this._element.style.pointerEvents=\"none\",\"pending\"===this._state&&(this._state=\"active\",this.fire(new t.Event(\"dragstart\"))),this.fire(new t.Event(\"drag\"))},n.prototype._onUp=function(){this._element.style.pointerEvents=\"auto\",this._positionDelta=null,this._map.off(\"mousemove\",this._onMove),this._map.off(\"touchmove\",this._onMove),\"active\"===this._state&&this.fire(new t.Event(\"dragend\")),this._state=\"inactive\"},n.prototype._addDragHandler=function(t){this._element.contains(t.originalEvent.target)&&(t.preventDefault(),this._positionDelta=t.point.sub(this._pos).add(this._offset),this._state=\"pending\",this._map.on(\"mousemove\",this._onMove),this._map.on(\"touchmove\",this._onMove),this._map.once(\"mouseup\",this._onUp),this._map.once(\"touchend\",this._onUp))},n.prototype.setDraggable=function(t){return this._draggable=!!t,this._map&&(t?(this._map.on(\"mousedown\",this._addDragHandler),this._map.on(\"touchstart\",this._addDragHandler)):(this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler))),this},n.prototype.isDraggable=function(){return this._draggable},n}(t.Evented),Un={positionOptions:{enableHighAccuracy:!1,maximumAge:0,timeout:6e3},fitBoundsOptions:{maxZoom:15},trackUserLocation:!1,showUserLocation:!0},Vn=function(e){function n(r){e.call(this),this.options=t.extend({},Un,r),t.bindAll([\"_onSuccess\",\"_onError\",\"_finish\",\"_setupUI\",\"_updateCamera\",\"_updateMarker\"],this)}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.onAdd=function(e){var n;return this._map=e,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),n=this._setupUI,void 0!==Nn?n(Nn):void 0!==t.window.navigator.permissions?t.window.navigator.permissions.query({name:\"geolocation\"}).then(function(t){Nn=\"denied\"!==t.state,n(Nn)}):(Nn=!!t.window.navigator.geolocation,n(Nn)),this._container},n.prototype.onRemove=function(){void 0!==this._geolocationWatchID&&(t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0),this.options.showUserLocation&&this._userLocationDotMarker&&this._userLocationDotMarker.remove(),r.remove(this._container),this._map=void 0},n.prototype._onSuccess=function(e){if(this.options.trackUserLocation)switch(this._lastKnownPosition=e,this._watchState){case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"BACKGROUND\":case\"BACKGROUND_ERROR\":this._watchState=\"BACKGROUND\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\")}this.options.showUserLocation&&\"OFF\"!==this._watchState&&this._updateMarker(e),this.options.trackUserLocation&&\"ACTIVE_LOCK\"!==this._watchState||this._updateCamera(e),this.options.showUserLocation&&this._dotElement.classList.remove(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"geolocate\",e)),this._finish()},n.prototype._updateCamera=function(e){var r=new t.LngLat(e.coords.longitude,e.coords.latitude),n=e.coords.accuracy,i=this._map.getBearing(),a=t.extend({bearing:i},this.options.fitBoundsOptions);this._map.fitBounds(r.toBounds(n),a,{geolocateSource:!0})},n.prototype._updateMarker=function(t){t?this._userLocationDotMarker.setLngLat([t.coords.longitude,t.coords.latitude]).addTo(this._map):this._userLocationDotMarker.remove()},n.prototype._onError=function(e){if(this.options.trackUserLocation)if(1===e.code)this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),void 0!==this._geolocationWatchID&&this._clearWatch();else switch(this._watchState){case\"WAITING_ACTIVE\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"ACTIVE_LOCK\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\");break;case\"BACKGROUND\":this._watchState=\"BACKGROUND_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\")}\"OFF\"!==this._watchState&&this.options.showUserLocation&&this._dotElement.classList.add(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"error\",e)),this._finish()},n.prototype._finish=function(){this._timeoutId&&clearTimeout(this._timeoutId),this._timeoutId=void 0},n.prototype._setupUI=function(e){var n=this;!1!==e?(this._container.addEventListener(\"contextmenu\",function(t){return t.preventDefault()}),this._geolocateButton=r.create(\"button\",\"mapboxgl-ctrl-icon mapboxgl-ctrl-geolocate\",this._container),this._geolocateButton.type=\"button\",this._geolocateButton.setAttribute(\"aria-label\",\"Geolocate\"),this.options.trackUserLocation&&(this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this._watchState=\"OFF\"),this.options.showUserLocation&&(this._dotElement=r.create(\"div\",\"mapboxgl-user-location-dot\"),this._userLocationDotMarker=new jn(this._dotElement),this.options.trackUserLocation&&(this._watchState=\"OFF\")),this._geolocateButton.addEventListener(\"click\",this.trigger.bind(this)),this._setup=!0,this.options.trackUserLocation&&this._map.on(\"movestart\",function(e){e.geolocateSource||\"ACTIVE_LOCK\"!==n._watchState||(n._watchState=\"BACKGROUND\",n._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\"),n._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),n.fire(new t.Event(\"trackuserlocationend\")))})):t.warnOnce(\"Geolocation support is not available, the GeolocateControl will not be visible.\")},n.prototype.trigger=function(){if(!this._setup)return t.warnOnce(\"Geolocate control triggered before added to a map\"),!1;if(this.options.trackUserLocation){switch(this._watchState){case\"OFF\":this._watchState=\"WAITING_ACTIVE\",this.fire(new t.Event(\"trackuserlocationstart\"));break;case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":case\"BACKGROUND_ERROR\":this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this.fire(new t.Event(\"trackuserlocationend\"));break;case\"BACKGROUND\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._lastKnownPosition&&this._updateCamera(this._lastKnownPosition),this.fire(new t.Event(\"trackuserlocationstart\"))}switch(this._watchState){case\"WAITING_ACTIVE\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_LOCK\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"BACKGROUND\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\");break;case\"BACKGROUND_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\")}\"OFF\"===this._watchState&&void 0!==this._geolocationWatchID?this._clearWatch():void 0===this._geolocationWatchID&&(this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"true\"),this._geolocationWatchID=t.window.navigator.geolocation.watchPosition(this._onSuccess,this._onError,this.options.positionOptions))}else t.window.navigator.geolocation.getCurrentPosition(this._onSuccess,this._onError,this.options.positionOptions),this._timeoutId=setTimeout(this._finish,1e4);return!0},n.prototype._clearWatch=function(){t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0,this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this.options.showUserLocation&&this._updateMarker(null)},n}(t.Evented),qn={maxWidth:100,unit:\"metric\"},Hn=function(e){this.options=t.extend({},qn,e),t.bindAll([\"_onMove\",\"setUnit\"],this)};function Gn(t,e,r){var n,i,a,o,s,l,c=r&&r.maxWidth||100,u=t._container.clientHeight/2,h=(n=t.unproject([0,u]),i=t.unproject([c,u]),a=Math.PI/180,o=n.lat*a,s=i.lat*a,l=Math.sin(o)*Math.sin(s)+Math.cos(o)*Math.cos(s)*Math.cos((i.lng-n.lng)*a),6371e3*Math.acos(Math.min(l,1)));if(r&&\"imperial\"===r.unit){var f=3.2808*h;f>5280?Yn(e,c,f/5280,\"mi\"):Yn(e,c,f,\"ft\")}else r&&\"nautical\"===r.unit?Yn(e,c,h/1852,\"nm\"):Yn(e,c,h,\"m\")}function Yn(t,e,r,n){var i,a,o,s=(i=r,(a=Math.pow(10,(\"\"+Math.floor(i)).length-1))*(o=(o=i/a)>=10?10:o>=5?5:o>=3?3:o>=2?2:o>=1?1:function(t){var e=Math.pow(10,Math.ceil(-Math.log(t)/Math.LN10));return Math.round(t*e)/e}(o))),l=s/r;\"m\"===n&&s>=1e3&&(s/=1e3,n=\"km\"),t.style.width=e*l+\"px\",t.innerHTML=s+n}Hn.prototype.getDefaultPosition=function(){return\"bottom-left\"},Hn.prototype._onMove=function(){Gn(this._map,this._container,this.options)},Hn.prototype.onAdd=function(t){return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-scale\",t.getContainer()),this._map.on(\"move\",this._onMove),this._onMove(),this._container},Hn.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"move\",this._onMove),this._map=void 0},Hn.prototype.setUnit=function(t){this.options.unit=t,Gn(this._map,this._container,this.options)};var Wn=function(e){this._fullscreen=!1,e&&e.container&&(e.container instanceof t.window.HTMLElement?this._container=e.container:t.warnOnce(\"Full screen control 'container' must be a DOM element.\")),t.bindAll([\"_onClickFullscreen\",\"_changeIcon\"],this),\"onfullscreenchange\"in t.window.document?this._fullscreenchange=\"fullscreenchange\":\"onmozfullscreenchange\"in t.window.document?this._fullscreenchange=\"mozfullscreenchange\":\"onwebkitfullscreenchange\"in t.window.document?this._fullscreenchange=\"webkitfullscreenchange\":\"onmsfullscreenchange\"in t.window.document&&(this._fullscreenchange=\"MSFullscreenChange\"),this._className=\"mapboxgl-ctrl\"};Wn.prototype.onAdd=function(e){return this._map=e,this._container||(this._container=this._map.getContainer()),this._controlContainer=r.create(\"div\",this._className+\" mapboxgl-ctrl-group\"),this._checkFullscreenSupport()?this._setupUI():(this._controlContainer.style.display=\"none\",t.warnOnce(\"This device does not support fullscreen mode.\")),this._controlContainer},Wn.prototype.onRemove=function(){r.remove(this._controlContainer),this._map=null,t.window.document.removeEventListener(this._fullscreenchange,this._changeIcon)},Wn.prototype._checkFullscreenSupport=function(){return!!(t.window.document.fullscreenEnabled||t.window.document.mozFullScreenEnabled||t.window.document.msFullscreenEnabled||t.window.document.webkitFullscreenEnabled)},Wn.prototype._setupUI=function(){(this._fullscreenButton=r.create(\"button\",this._className+\"-icon \"+this._className+\"-fullscreen\",this._controlContainer)).type=\"button\",this._updateTitle(),this._fullscreenButton.addEventListener(\"click\",this._onClickFullscreen),t.window.document.addEventListener(this._fullscreenchange,this._changeIcon)},Wn.prototype._updateTitle=function(){var t=this._isFullscreen()?\"Exit fullscreen\":\"Enter fullscreen\";this._fullscreenButton.setAttribute(\"aria-label\",t),this._fullscreenButton.title=t},Wn.prototype._isFullscreen=function(){return this._fullscreen},Wn.prototype._changeIcon=function(){(t.window.document.fullscreenElement||t.window.document.mozFullScreenElement||t.window.document.webkitFullscreenElement||t.window.document.msFullscreenElement)===this._container!==this._fullscreen&&(this._fullscreen=!this._fullscreen,this._fullscreenButton.classList.toggle(this._className+\"-shrink\"),this._fullscreenButton.classList.toggle(this._className+\"-fullscreen\"),this._updateTitle())},Wn.prototype._onClickFullscreen=function(){this._isFullscreen()?t.window.document.exitFullscreen?t.window.document.exitFullscreen():t.window.document.mozCancelFullScreen?t.window.document.mozCancelFullScreen():t.window.document.msExitFullscreen?t.window.document.msExitFullscreen():t.window.document.webkitCancelFullScreen&&t.window.document.webkitCancelFullScreen():this._container.requestFullscreen?this._container.requestFullscreen():this._container.mozRequestFullScreen?this._container.mozRequestFullScreen():this._container.msRequestFullscreen?this._container.msRequestFullscreen():this._container.webkitRequestFullscreen&&this._container.webkitRequestFullscreen()};var Xn={closeButton:!0,closeOnClick:!0,className:\"\",maxWidth:\"240px\"},Zn=function(e){function n(r){e.call(this),this.options=t.extend(Object.create(Xn),r),t.bindAll([\"_update\",\"_onClickClose\",\"remove\"],this)}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.addTo=function(e){var r=this;return this._map=e,this.options.closeOnClick&&this._map.on(\"click\",this._onClickClose),this._map.on(\"remove\",this.remove),this._update(),this._trackPointer?(this._map.on(\"mousemove\",function(t){r._update(t.point)}),this._map.on(\"mouseup\",function(t){r._update(t.point)}),this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")):this._map.on(\"move\",this._update),this.fire(new t.Event(\"open\")),this},n.prototype.isOpen=function(){return!!this._map},n.prototype.remove=function(){return this._content&&r.remove(this._content),this._container&&(r.remove(this._container),delete this._container),this._map&&(this._map.off(\"move\",this._update),this._map.off(\"click\",this._onClickClose),this._map.off(\"remove\",this.remove),this._map.off(\"mousemove\"),delete this._map),this.fire(new t.Event(\"close\")),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._map&&(this._map.on(\"move\",this._update),this._map.off(\"mousemove\"),this._container.classList.remove(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.remove(\"mapboxgl-track-pointer\")),this._trackPointer=!1,this._update(),this},n.prototype.trackPointer=function(){var t=this;return this._trackPointer=!0,this._pos=null,this._map&&(this._map.off(\"move\",this._update),this._map.on(\"mousemove\",function(e){t._update(e.point)}),this._map.on(\"drag\",function(e){t._update(e.point)}),this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")),this},n.prototype.getElement=function(){return this._container},n.prototype.setText=function(e){return this.setDOMContent(t.window.document.createTextNode(e))},n.prototype.setHTML=function(e){var r,n=t.window.document.createDocumentFragment(),i=t.window.document.createElement(\"body\");for(i.innerHTML=e;r=i.firstChild;)n.appendChild(r);return this.setDOMContent(n)},n.prototype.getMaxWidth=function(){return this._container.style.maxWidth},n.prototype.setMaxWidth=function(t){return this.options.maxWidth=t,this._update(),this},n.prototype.setDOMContent=function(t){return this._createContent(),this._content.appendChild(t),this._update(),this},n.prototype._createContent=function(){this._content&&r.remove(this._content),this._content=r.create(\"div\",\"mapboxgl-popup-content\",this._container),this.options.closeButton&&(this._closeButton=r.create(\"button\",\"mapboxgl-popup-close-button\",this._content),this._closeButton.type=\"button\",this._closeButton.setAttribute(\"aria-label\",\"Close popup\"),this._closeButton.innerHTML=\"&#215;\",this._closeButton.addEventListener(\"click\",this._onClickClose))},n.prototype._update=function(e){var n=this,i=this._lngLat||this._trackPointer;if(this._map&&i&&this._content&&(this._container||(this._container=r.create(\"div\",\"mapboxgl-popup\",this._map.getContainer()),this._tip=r.create(\"div\",\"mapboxgl-popup-tip\",this._container),this._container.appendChild(this._content),this.options.className&&this.options.className.split(\" \").forEach(function(t){return n._container.classList.add(t)})),this.options.maxWidth&&this._container.style.maxWidth!==this.options.maxWidth&&(this._container.style.maxWidth=this.options.maxWidth),this._map.transform.renderWorldCopies&&!this._trackPointer&&(this._lngLat=Rn(this._lngLat,this._pos,this._map.transform)),!this._trackPointer||e)){var a=this._pos=this._trackPointer&&e?e:this._map.project(this._lngLat),o=this.options.anchor,s=function e(r){if(r){if(\"number\"==typeof r){var n=Math.round(Math.sqrt(.5*Math.pow(r,2)));return{center:new t.Point(0,0),top:new t.Point(0,r),\"top-left\":new t.Point(n,n),\"top-right\":new t.Point(-n,n),bottom:new t.Point(0,-r),\"bottom-left\":new t.Point(n,-n),\"bottom-right\":new t.Point(-n,-n),left:new t.Point(r,0),right:new t.Point(-r,0)}}if(r instanceof t.Point||Array.isArray(r)){var i=t.Point.convert(r);return{center:i,top:i,\"top-left\":i,\"top-right\":i,bottom:i,\"bottom-left\":i,\"bottom-right\":i,left:i,right:i}}return{center:t.Point.convert(r.center||[0,0]),top:t.Point.convert(r.top||[0,0]),\"top-left\":t.Point.convert(r[\"top-left\"]||[0,0]),\"top-right\":t.Point.convert(r[\"top-right\"]||[0,0]),bottom:t.Point.convert(r.bottom||[0,0]),\"bottom-left\":t.Point.convert(r[\"bottom-left\"]||[0,0]),\"bottom-right\":t.Point.convert(r[\"bottom-right\"]||[0,0]),left:t.Point.convert(r.left||[0,0]),right:t.Point.convert(r.right||[0,0])}}return e(new t.Point(0,0))}(this.options.offset);if(!o){var l,c=this._container.offsetWidth,u=this._container.offsetHeight;l=a.y+s.bottom.y<u?[\"top\"]:a.y>this._map.transform.height-u?[\"bottom\"]:[],a.x<c/2?l.push(\"left\"):a.x>this._map.transform.width-c/2&&l.push(\"right\"),o=0===l.length?\"bottom\":l.join(\"-\")}var h=a.add(s[o]).round();r.setTransform(this._container,Fn[o]+\" translate(\"+h.x+\"px,\"+h.y+\"px)\"),Bn(this._container,o,\"popup\")}},n.prototype._onClickClose=function(){this.remove()},n}(t.Evented),Jn={version:t.version,supported:e,setRTLTextPlugin:t.setRTLTextPlugin,Map:On,NavigationControl:Dn,GeolocateControl:Vn,AttributionControl:Mn,ScaleControl:Hn,FullscreenControl:Wn,Popup:Zn,Marker:jn,Style:De,LngLat:t.LngLat,LngLatBounds:t.LngLatBounds,Point:t.Point,MercatorCoordinate:t.MercatorCoordinate,Evented:t.Evented,config:t.config,get accessToken(){return t.config.ACCESS_TOKEN},set accessToken(e){t.config.ACCESS_TOKEN=e},get baseApiUrl(){return t.config.API_URL},set baseApiUrl(e){t.config.API_URL=e},get workerCount(){return zt.workerCount},set workerCount(t){zt.workerCount=t},get maxParallelImageRequests(){return t.config.MAX_PARALLEL_IMAGE_REQUESTS},set maxParallelImageRequests(e){t.config.MAX_PARALLEL_IMAGE_REQUESTS=e},clearStorage:function(e){t.clearTileCache(e)},workerUrl:\"\"};return Jn}),r},\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=i():(n=n||self).mapboxgl=i()},{}],427:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1<<t+1,r=new Array(e),n=0;n<e;++n)r[n]=a(t,n);return r};var n=t(\"convex-hull\");function i(t,e,r){for(var n=new Array(t),i=0;i<t;++i)n[i]=0,i===e&&(n[i]+=.5),i===r&&(n[i]+=.5);return n}function a(t,e){if(0===e||e===(1<<t+1)-1)return[];for(var r=[],a=[],o=0;o<=t;++o)if(e&1<<o){r.push(i(t,o-1,o-1)),a.push(null);for(var s=0;s<=t;++s)~e&1<<s&&(r.push(i(t,o-1,s-1)),a.push([o,s]))}var l=n(r),c=[];t:for(o=0;o<l.length;++o){var u=l[o],h=[];for(s=0;s<u.length;++s){if(!a[u[s]])continue t;h.push(a[u[s]].slice())}c.push(h)}return c}},{\"convex-hull\":130}],428:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"gl-mat4/create\"),a=t(\"gl-mat4/clone\"),o=t(\"gl-mat4/determinant\"),s=t(\"gl-mat4/invert\"),l=t(\"gl-mat4/transpose\"),c={length:t(\"gl-vec3/length\"),normalize:t(\"gl-vec3/normalize\"),dot:t(\"gl-vec3/dot\"),cross:t(\"gl-vec3/cross\")},u=i(),h=i(),f=[0,0,0,0],p=[[0,0,0],[0,0,0],[0,0,0]],d=[0,0,0];function g(t,e,r,n,i){t[0]=e[0]*n+r[0]*i,t[1]=e[1]*n+r[1]*i,t[2]=e[2]*n+r[2]*i}e.exports=function(t,e,r,i,v,m){if(e||(e=[0,0,0]),r||(r=[0,0,0]),i||(i=[0,0,0]),v||(v=[0,0,0,1]),m||(m=[0,0,0,1]),!n(u,t))return!1;if(a(h,u),h[3]=0,h[7]=0,h[11]=0,h[15]=1,Math.abs(o(h)<1e-8))return!1;var y,x,b,_,w,k,T,A=u[3],M=u[7],S=u[11],E=u[12],C=u[13],L=u[14],P=u[15];if(0!==A||0!==M||0!==S){if(f[0]=A,f[1]=M,f[2]=S,f[3]=P,!s(h,h))return!1;l(h,h),y=v,b=h,_=(x=f)[0],w=x[1],k=x[2],T=x[3],y[0]=b[0]*_+b[4]*w+b[8]*k+b[12]*T,y[1]=b[1]*_+b[5]*w+b[9]*k+b[13]*T,y[2]=b[2]*_+b[6]*w+b[10]*k+b[14]*T,y[3]=b[3]*_+b[7]*w+b[11]*k+b[15]*T}else v[0]=v[1]=v[2]=0,v[3]=1;if(e[0]=E,e[1]=C,e[2]=L,function(t,e){t[0][0]=e[0],t[0][1]=e[1],t[0][2]=e[2],t[1][0]=e[4],t[1][1]=e[5],t[1][2]=e[6],t[2][0]=e[8],t[2][1]=e[9],t[2][2]=e[10]}(p,u),r[0]=c.length(p[0]),c.normalize(p[0],p[0]),i[0]=c.dot(p[0],p[1]),g(p[1],p[1],p[0],1,-i[0]),r[1]=c.length(p[1]),c.normalize(p[1],p[1]),i[0]/=r[1],i[1]=c.dot(p[0],p[2]),g(p[2],p[2],p[0],1,-i[1]),i[2]=c.dot(p[1],p[2]),g(p[2],p[2],p[1],1,-i[2]),r[2]=c.length(p[2]),c.normalize(p[2],p[2]),i[1]/=r[2],i[2]/=r[2],c.cross(d,p[1],p[2]),c.dot(p[0],d)<0)for(var O=0;O<3;O++)r[O]*=-1,p[O][0]*=-1,p[O][1]*=-1,p[O][2]*=-1;return m[0]=.5*Math.sqrt(Math.max(1+p[0][0]-p[1][1]-p[2][2],0)),m[1]=.5*Math.sqrt(Math.max(1-p[0][0]+p[1][1]-p[2][2],0)),m[2]=.5*Math.sqrt(Math.max(1-p[0][0]-p[1][1]+p[2][2],0)),m[3]=.5*Math.sqrt(Math.max(1+p[0][0]+p[1][1]+p[2][2],0)),p[2][1]>p[1][2]&&(m[0]=-m[0]),p[0][2]>p[2][0]&&(m[1]=-m[1]),p[1][0]>p[0][1]&&(m[2]=-m[2]),!0}},{\"./normalize\":429,\"gl-mat4/clone\":259,\"gl-mat4/create\":260,\"gl-mat4/determinant\":261,\"gl-mat4/invert\":265,\"gl-mat4/transpose\":276,\"gl-vec3/cross\":334,\"gl-vec3/dot\":339,\"gl-vec3/length\":349,\"gl-vec3/normalize\":356}],429:[function(t,e,r){e.exports=function(t,e){var r=e[15];if(0===r)return!1;for(var n=1/r,i=0;i<16;i++)t[i]=e[i]*n;return!0}},{}],430:[function(t,e,r){var n=t(\"gl-vec3/lerp\"),i=t(\"mat4-recompose\"),a=t(\"mat4-decompose\"),o=t(\"gl-mat4/determinant\"),s=t(\"quat-slerp\"),l=h(),c=h(),u=h();function h(){return{translate:f(),scale:f(1),skew:f(),perspective:[0,0,0,1],quaternion:[0,0,0,1]}}function f(t){return[t||0,t||0,t||0]}e.exports=function(t,e,r,h){if(0===o(e)||0===o(r))return!1;var f=a(e,l.translate,l.scale,l.skew,l.perspective,l.quaternion),p=a(r,c.translate,c.scale,c.skew,c.perspective,c.quaternion);return!(!f||!p||(n(u.translate,l.translate,c.translate,h),n(u.skew,l.skew,c.skew,h),n(u.scale,l.scale,c.scale,h),n(u.perspective,l.perspective,c.perspective,h),s(u.quaternion,l.quaternion,c.quaternion,h),i(t,u.translate,u.scale,u.skew,u.perspective,u.quaternion),0))}},{\"gl-mat4/determinant\":261,\"gl-vec3/lerp\":350,\"mat4-decompose\":428,\"mat4-recompose\":431,\"quat-slerp\":483}],431:[function(t,e,r){var n={identity:t(\"gl-mat4/identity\"),translate:t(\"gl-mat4/translate\"),multiply:t(\"gl-mat4/multiply\"),create:t(\"gl-mat4/create\"),scale:t(\"gl-mat4/scale\"),fromRotationTranslation:t(\"gl-mat4/fromRotationTranslation\")},i=(n.create(),n.create());e.exports=function(t,e,r,a,o,s){return n.identity(t),n.fromRotationTranslation(t,s,e),t[3]=o[0],t[7]=o[1],t[11]=o[2],t[15]=o[3],n.identity(i),0!==a[2]&&(i[9]=a[2],n.multiply(t,t,i)),0!==a[1]&&(i[9]=0,i[8]=a[1],n.multiply(t,t,i)),0!==a[0]&&(i[8]=0,i[4]=a[0],n.multiply(t,t,i)),n.scale(t,t,r),t}},{\"gl-mat4/create\":260,\"gl-mat4/fromRotationTranslation\":263,\"gl-mat4/identity\":264,\"gl-mat4/multiply\":267,\"gl-mat4/scale\":274,\"gl-mat4/translate\":275}],432:[function(t,e,r){\"use strict\";e.exports=Math.log2||function(t){return Math.log(t)*Math.LOG2E}},{}],433:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"mat4-interpolate\"),a=t(\"gl-mat4/invert\"),o=t(\"gl-mat4/rotateX\"),s=t(\"gl-mat4/rotateY\"),l=t(\"gl-mat4/rotateZ\"),c=t(\"gl-mat4/lookAt\"),u=t(\"gl-mat4/translate\"),h=(t(\"gl-mat4/scale\"),t(\"gl-vec3/normalize\")),f=[0,0,0];function p(t){this._components=t.slice(),this._time=[0],this.prevMatrix=t.slice(),this.nextMatrix=t.slice(),this.computedMatrix=t.slice(),this.computedInverse=t.slice(),this.computedEye=[0,0,0],this.computedUp=[0,0,0],this.computedCenter=[0,0,0],this.computedRadius=[0],this._limits=[-1/0,1/0]}e.exports=function(t){return new p((t=t||{}).matrix||[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1])};var d=p.prototype;d.recalcMatrix=function(t){var e=this._time,r=n.le(e,t),o=this.computedMatrix;if(!(r<0)){var s=this._components;if(r===e.length-1)for(var l=16*r,c=0;c<16;++c)o[c]=s[l++];else{var u=e[r+1]-e[r],f=(l=16*r,this.prevMatrix),p=!0;for(c=0;c<16;++c)f[c]=s[l++];var d=this.nextMatrix;for(c=0;c<16;++c)d[c]=s[l++],p=p&&f[c]===d[c];if(u<1e-6||p)for(c=0;c<16;++c)o[c]=f[c];else i(o,f,d,(t-e[r])/u)}var g=this.computedUp;g[0]=o[1],g[1]=o[5],g[2]=o[9],h(g,g);var v=this.computedInverse;a(v,o);var m=this.computedEye,y=v[15];m[0]=v[12]/y,m[1]=v[13]/y,m[2]=v[14]/y;var x=this.computedCenter,b=Math.exp(this.computedRadius[0]);for(c=0;c<3;++c)x[c]=m[c]-o[2+4*c]*b}},d.idle=function(t){if(!(t<this.lastT())){for(var e=this._components,r=e.length-16,n=0;n<16;++n)e.push(e[r++]);this._time.push(t)}},d.flush=function(t){var e=n.gt(this._time,t)-2;e<0||(this._time.splice(0,e),this._components.splice(0,16*e))},d.lastT=function(){return this._time[this._time.length-1]},d.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||f,n=n||this.computedUp,this.setMatrix(t,c(this.computedMatrix,e,r,n));for(var i=0,a=0;a<3;++a)i+=Math.pow(r[a]-e[a],2);i=Math.log(Math.sqrt(i)),this.computedRadius[0]=i},d.rotate=function(t,e,r,n){this.recalcMatrix(t);var i=this.computedInverse;e&&s(i,i,e),r&&o(i,i,r),n&&l(i,i,n),this.setMatrix(t,a(this.computedMatrix,i))};var g=[0,0,0];d.pan=function(t,e,r,n){g[0]=-(e||0),g[1]=-(r||0),g[2]=-(n||0),this.recalcMatrix(t);var i=this.computedInverse;u(i,i,g),this.setMatrix(t,a(i,i))},d.translate=function(t,e,r,n){g[0]=e||0,g[1]=r||0,g[2]=n||0,this.recalcMatrix(t);var i=this.computedMatrix;u(i,i,g),this.setMatrix(t,i)},d.setMatrix=function(t,e){if(!(t<this.lastT())){this._time.push(t);for(var r=0;r<16;++r)this._components.push(e[r])}},d.setDistance=function(t,e){this.computedRadius[0]=e},d.setDistanceLimits=function(t,e){var r=this._limits;r[0]=t,r[1]=e},d.getDistanceLimits=function(t){var e=this._limits;return t?(t[0]=e[0],t[1]=e[1],t):e}},{\"binary-search-bounds\":91,\"gl-mat4/invert\":265,\"gl-mat4/lookAt\":266,\"gl-mat4/rotateX\":271,\"gl-mat4/rotateY\":272,\"gl-mat4/rotateZ\":273,\"gl-mat4/scale\":274,\"gl-mat4/translate\":275,\"gl-vec3/normalize\":356,\"mat4-interpolate\":430}],434:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<3){for(var r=new Array(e),i=0;i<e;++i)r[i]=i;return 2===e&&t[0][0]===t[1][0]&&t[0][1]===t[1][1]?[0]:r}for(var a=new Array(e),i=0;i<e;++i)a[i]=i;a.sort(function(e,r){var n=t[e][0]-t[r][0];return n||t[e][1]-t[r][1]});for(var o=[a[0],a[1]],s=[a[0],a[1]],i=2;i<e;++i){for(var l=a[i],c=t[l],u=o.length;u>1&&n(t[o[u-2]],t[o[u-1]],c)<=0;)u-=1,o.pop();for(o.push(l),u=s.length;u>1&&n(t[s[u-2]],t[s[u-1]],c)>=0;)u-=1,s.pop();s.push(l)}for(var r=new Array(s.length+o.length-2),h=0,i=0,f=o.length;i<f;++i)r[h++]=o[i];for(var p=s.length-2;p>0;--p)r[h++]=s[p];return r};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":510}],435:[function(t,e,r){\"use strict\";e.exports=function(t,e){e||(e=t,t=window);var r=0,i=0,a=0,o={shift:!1,alt:!1,control:!1,meta:!1},s=!1;function l(t){var e=!1;return\"altKey\"in t&&(e=e||t.altKey!==o.alt,o.alt=!!t.altKey),\"shiftKey\"in t&&(e=e||t.shiftKey!==o.shift,o.shift=!!t.shiftKey),\"ctrlKey\"in t&&(e=e||t.ctrlKey!==o.control,o.control=!!t.ctrlKey),\"metaKey\"in t&&(e=e||t.metaKey!==o.meta,o.meta=!!t.metaKey),e}function c(t,s){var c=n.x(s),u=n.y(s);\"buttons\"in s&&(t=0|s.buttons),(t!==r||c!==i||u!==a||l(s))&&(r=0|t,i=c||0,a=u||0,e&&e(r,i,a,o))}function u(t){c(0,t)}function h(){(r||i||a||o.shift||o.alt||o.meta||o.control)&&(i=a=0,r=0,o.shift=o.alt=o.control=o.meta=!1,e&&e(0,0,0,o))}function f(t){l(t)&&e&&e(r,i,a,o)}function p(t){0===n.buttons(t)?c(0,t):c(r,t)}function d(t){c(r|n.buttons(t),t)}function g(t){c(r&~n.buttons(t),t)}function v(){s||(s=!0,t.addEventListener(\"mousemove\",p),t.addEventListener(\"mousedown\",d),t.addEventListener(\"mouseup\",g),t.addEventListener(\"mouseleave\",u),t.addEventListener(\"mouseenter\",u),t.addEventListener(\"mouseout\",u),t.addEventListener(\"mouseover\",u),t.addEventListener(\"blur\",h),t.addEventListener(\"keyup\",f),t.addEventListener(\"keydown\",f),t.addEventListener(\"keypress\",f),t!==window&&(window.addEventListener(\"blur\",h),window.addEventListener(\"keyup\",f),window.addEventListener(\"keydown\",f),window.addEventListener(\"keypress\",f)))}v();var m={element:t};return Object.defineProperties(m,{enabled:{get:function(){return s},set:function(e){e?v():s&&(s=!1,t.removeEventListener(\"mousemove\",p),t.removeEventListener(\"mousedown\",d),t.removeEventListener(\"mouseup\",g),t.removeEventListener(\"mouseleave\",u),t.removeEventListener(\"mouseenter\",u),t.removeEventListener(\"mouseout\",u),t.removeEventListener(\"mouseover\",u),t.removeEventListener(\"blur\",h),t.removeEventListener(\"keyup\",f),t.removeEventListener(\"keydown\",f),t.removeEventListener(\"keypress\",f),t!==window&&(window.removeEventListener(\"blur\",h),window.removeEventListener(\"keyup\",f),window.removeEventListener(\"keydown\",f),window.removeEventListener(\"keypress\",f)))},enumerable:!0},buttons:{get:function(){return r},enumerable:!0},x:{get:function(){return i},enumerable:!0},y:{get:function(){return a},enumerable:!0},mods:{get:function(){return o},enumerable:!0}}),m};var n=t(\"mouse-event\")},{\"mouse-event\":437}],436:[function(t,e,r){var n={left:0,top:0};e.exports=function(t,e,r){e=e||t.currentTarget||t.srcElement,Array.isArray(r)||(r=[0,0]);var i=t.clientX||0,a=t.clientY||0,o=(s=e,s===window||s===document||s===document.body?n:s.getBoundingClientRect());var s;return r[0]=i-o.left,r[1]=a-o.top,r}},{}],437:[function(t,e,r){\"use strict\";function n(t){return t.target||t.srcElement||window}r.buttons=function(t){if(\"object\"==typeof t){if(\"buttons\"in t)return t.buttons;if(\"which\"in t){if(2===(e=t.which))return 4;if(3===e)return 2;if(e>0)return 1<<e-1}else if(\"button\"in t){var e;if(1===(e=t.button))return 4;if(2===e)return 2;if(e>=0)return 1<<e}}return 0},r.element=n,r.x=function(t){if(\"object\"==typeof t){if(\"offsetX\"in t)return t.offsetX;var e=n(t).getBoundingClientRect();return t.clientX-e.left}return 0},r.y=function(t){if(\"object\"==typeof t){if(\"offsetY\"in t)return t.offsetY;var e=n(t).getBoundingClientRect();return t.clientY-e.top}return 0}},{}],438:[function(t,e,r){\"use strict\";var n=t(\"to-px\");e.exports=function(t,e,r){\"function\"==typeof t&&(r=!!e,e=t,t=window);var i=n(\"ex\",t),a=function(t){r&&t.preventDefault();var n=t.deltaX||0,a=t.deltaY||0,o=t.deltaZ||0,s=t.deltaMode,l=1;switch(s){case 1:l=i;break;case 2:l=window.innerHeight}if(a*=l,o*=l,(n*=l)||a||o)return e(n,a,o,t)};return t.addEventListener(\"wheel\",a),a}},{\"to-px\":539}],439:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\");function i(t){return\"a\"+t}function a(t){return\"d\"+t}function o(t,e){return\"c\"+t+\"_\"+e}function s(t){return\"s\"+t}function l(t,e){return\"t\"+t+\"_\"+e}function c(t){return\"o\"+t}function u(t){return\"x\"+t}function h(t){return\"p\"+t}function f(t,e){return\"d\"+t+\"_\"+e}function p(t){return\"i\"+t}function d(t,e){return\"u\"+t+\"_\"+e}function g(t){return\"b\"+t}function v(t){return\"y\"+t}function m(t){return\"e\"+t}function y(t){return\"v\"+t}e.exports=function(t){function e(t){throw new Error(\"ndarray-extract-contour: \"+t)}\"object\"!=typeof t&&e(\"Must specify arguments\");var r=t.order;Array.isArray(r)||e(\"Must specify order\");var M=t.arrayArguments||1;M<1&&e(\"Must have at least one array argument\");var S=t.scalarArguments||0;S<0&&e(\"Scalar arg count must be > 0\");\"function\"!=typeof t.vertex&&e(\"Must specify vertex creation function\");\"function\"!=typeof t.cell&&e(\"Must specify cell creation function\");\"function\"!=typeof t.phase&&e(\"Must specify phase function\");for(var E=t.getters||[],C=new Array(M),L=0;L<M;++L)E.indexOf(L)>=0?C[L]=!0:C[L]=!1;return function(t,e,r,M,S,E){var C=E.length,L=S.length;if(L<2)throw new Error(\"ndarray-extract-contour: Dimension must be at least 2\");for(var P=\"extractContour\"+S.join(\"_\"),O=[],z=[],I=[],D=0;D<C;++D)I.push(i(D));for(var D=0;D<M;++D)I.push(u(D));for(var D=0;D<L;++D)z.push(s(D)+\"=\"+i(0)+\".shape[\"+D+\"]|0\");for(var D=0;D<C;++D){z.push(a(D)+\"=\"+i(D)+\".data\",c(D)+\"=\"+i(D)+\".offset|0\");for(var R=0;R<L;++R)z.push(l(D,R)+\"=\"+i(D)+\".stride[\"+R+\"]|0\")}for(var D=0;D<C;++D){z.push(h(D)+\"=\"+c(D)),z.push(o(D,0));for(var R=1;R<1<<L;++R){for(var F=[],B=0;B<L;++B)R&1<<B&&F.push(\"-\"+l(D,B));z.push(f(D,R)+\"=(\"+F.join(\"\")+\")|0\"),z.push(o(D,R)+\"=0\")}}for(var D=0;D<C;++D)for(var R=0;R<L;++R){var N=[l(D,S[R])];R>0&&N.push(l(D,S[R-1])+\"*\"+s(S[R-1])),z.push(d(D,S[R])+\"=(\"+N.join(\"-\")+\")|0\")}for(var D=0;D<L;++D)z.push(p(D)+\"=0\");z.push(_+\"=0\");for(var j=[\"2\"],D=L-2;D>=0;--D)j.push(s(S[D]));z.push(w+\"=(\"+j.join(\"*\")+\")|0\",b+\"=mallocUint32(\"+w+\")\",x+\"=mallocUint32(\"+w+\")\",k+\"=0\"),z.push(g(0)+\"=0\");for(var R=1;R<1<<L;++R){for(var U=[],V=[],B=0;B<L;++B)R&1<<B&&(0===V.length?U.push(\"1\"):U.unshift(V.join(\"*\"))),V.push(s(S[B]));var q=\"\";U[0].indexOf(s(S[L-2]))<0&&(q=\"-\");var H=A(L,R,S);z.push(m(H)+\"=(-\"+U.join(\"-\")+\")|0\",v(H)+\"=(\"+q+U.join(\"-\")+\")|0\",g(H)+\"=0\")}function G(t,e){O.push(\"for(\",p(S[t]),\"=\",e,\";\",p(S[t]),\"<\",s(S[t]),\";\",\"++\",p(S[t]),\"){\")}function Y(t){for(var e=0;e<C;++e)O.push(h(e),\"+=\",d(e,S[t]),\";\");O.push(\"}\")}function W(){for(var t=1;t<1<<L;++t)O.push(T,\"=\",m(t),\";\",m(t),\"=\",v(t),\";\",v(t),\"=\",T,\";\")}z.push(y(0)+\"=0\",T+\"=0\"),function t(e,r){if(e<0)return void function(t){for(var e=0;e<C;++e)E[e]?O.push(o(e,0),\"=\",a(e),\".get(\",h(e),\");\"):O.push(o(e,0),\"=\",a(e),\"[\",h(e),\"];\");for(var r=[],e=0;e<C;++e)r.push(o(e,0));for(var e=0;e<M;++e)r.push(u(e));O.push(g(0),\"=\",b,\"[\",k,\"]=phase(\",r.join(),\");\");for(var n=1;n<1<<L;++n)O.push(g(n),\"=\",b,\"[\",k,\"+\",m(n),\"];\");for(var i=[],n=1;n<1<<L;++n)i.push(\"(\"+g(0)+\"!==\"+g(n)+\")\");O.push(\"if(\",i.join(\"||\"),\"){\");for(var s=[],e=0;e<L;++e)s.push(p(e));for(var e=0;e<C;++e){s.push(o(e,0));for(var n=1;n<1<<L;++n)E[e]?O.push(o(e,n),\"=\",a(e),\".get(\",h(e),\"+\",f(e,n),\");\"):O.push(o(e,n),\"=\",a(e),\"[\",h(e),\"+\",f(e,n),\"];\"),s.push(o(e,n))}for(var e=0;e<1<<L;++e)s.push(g(e));for(var e=0;e<M;++e)s.push(u(e));O.push(\"vertex(\",s.join(),\");\",y(0),\"=\",x,\"[\",k,\"]=\",_,\"++;\");for(var l=(1<<L)-1,c=g(l),n=0;n<L;++n)if(0==(t&~(1<<n))){for(var d=l^1<<n,v=g(d),w=[],T=d;T>0;T=T-1&d)w.push(x+\"[\"+k+\"+\"+m(T)+\"]\");w.push(y(0));for(var T=0;T<C;++T)1&n?w.push(o(T,l),o(T,d)):w.push(o(T,d),o(T,l));1&n?w.push(c,v):w.push(v,c);for(var T=0;T<M;++T)w.push(u(T));O.push(\"if(\",c,\"!==\",v,\"){\",\"face(\",w.join(),\")}\")}O.push(\"}\",k,\"+=1;\")}(r);!function(t){for(var e=t-1;e>=0;--e)G(e,0);for(var r=[],e=0;e<C;++e)E[e]?r.push(a(e)+\".get(\"+h(e)+\")\"):r.push(a(e)+\"[\"+h(e)+\"]\");for(var e=0;e<M;++e)r.push(u(e));O.push(b,\"[\",k,\"++]=phase(\",r.join(),\");\");for(var e=0;e<t;++e)Y(e);for(var n=0;n<C;++n)O.push(h(n),\"+=\",d(n,S[t]),\";\")}(e);O.push(\"if(\",s(S[e]),\">0){\",p(S[e]),\"=1;\");t(e-1,r|1<<S[e]);for(var n=0;n<C;++n)O.push(h(n),\"+=\",d(n,S[e]),\";\");e===L-1&&(O.push(k,\"=0;\"),W());G(e,2);t(e-1,r);e===L-1&&(O.push(\"if(\",p(S[L-1]),\"&1){\",k,\"=0;}\"),W());Y(e);O.push(\"}\")}(L-1,0),O.push(\"freeUint32(\",x,\");freeUint32(\",b,\");\");var X=[\"'use strict';\",\"function \",P,\"(\",I.join(),\"){\",\"var \",z.join(),\";\",O.join(\"\"),\"}\",\"return \",P].join(\"\");return new Function(\"vertex\",\"face\",\"phase\",\"mallocUint32\",\"freeUint32\",X)(t,e,r,n.mallocUint32,n.freeUint32)}(t.vertex,t.cell,t.phase,S,r,C)};var x=\"V\",b=\"P\",_=\"N\",w=\"Q\",k=\"X\",T=\"T\";function A(t,e,r){for(var n=0,i=0;i<t;++i)e&1<<i&&(n|=1<<r[i]);return n}},{\"typedarray-pool\":545}],440:[function(t,e,r){\"use strict\";var n=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{_inline_1_arg1_=_inline_1_arg2_.apply(void 0,_inline_1_arg0_)}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"cwise\",blockSize:64});e.exports=function(t,e){return n(t,e),t}},{\"cwise/lib/wrapper\":149}],441:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(Array.isArray(r)){if(r.length!==e.dimension)throw new Error(\"ndarray-gradient: invalid boundary conditions\")}else r=n(e.dimension,\"string\"==typeof r?r:\"clamp\");if(t.dimension!==e.dimension+1)throw new Error(\"ndarray-gradient: output dimension must be +1 input dimension\");if(t.shape[e.dimension]!==e.dimension)throw new Error(\"ndarray-gradient: output shape must match input shape\");for(var i=0;i<e.dimension;++i)if(t.shape[i]!==e.shape[i])throw new Error(\"ndarray-gradient: shape mismatch\");if(0===e.size)return t;if(e.dimension<=0)return t.set(0),t;return function(t){var e=t.join();if(m=o[e])return m;var r=t.length,n=[\"function gradient(dst,src){var s=src.shape.slice();\"];function i(e){for(var i=r-e.length,a=[],o=[],s=[],l=0;l<r;++l)e.indexOf(l+1)>=0?s.push(\"0\"):e.indexOf(-(l+1))>=0?s.push(\"s[\"+l+\"]-1\"):(s.push(\"-1\"),a.push(\"1\"),o.push(\"s[\"+l+\"]-2\"));var c=\".lo(\"+a.join()+\").hi(\"+o.join()+\")\";if(0===a.length&&(c=\"\"),i>0){n.push(\"if(1\");for(var l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\"&&s[\",l,\"]>2\");n.push(\"){grad\",i,\"(src.pick(\",s.join(),\")\",c);for(var l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\",dst.pick(\",s.join(),\",\",l,\")\",c);n.push(\");\")}for(var l=0;l<e.length;++l){var u=Math.abs(e[l])-1,h=\"dst.pick(\"+s.join()+\",\"+u+\")\"+c;switch(t[u]){case\"clamp\":var f=s.slice(),p=s.slice();e[l]<0?f[u]=\"s[\"+u+\"]-2\":p[u]=\"1\",0===i?n.push(\"if(s[\",u,\"]>1){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",f.join(),\")-src.get(\",p.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>1){diff(\",h,\",src.pick(\",f.join(),\")\",c,\",src.pick(\",p.join(),\")\",c,\");}else{zero(\",h,\");};\");break;case\"mirror\":0===i?n.push(\"dst.set(\",s.join(),\",\",u,\",0);\"):n.push(\"zero(\",h,\");\");break;case\"wrap\":var d=s.slice(),g=s.slice();e[l]<0?(d[u]=\"s[\"+u+\"]-2\",g[u]=\"0\"):(d[u]=\"s[\"+u+\"]-1\",g[u]=\"1\"),0===i?n.push(\"if(s[\",u,\"]>2){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",d.join(),\")-src.get(\",g.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>2){diff(\",h,\",src.pick(\",d.join(),\")\",c,\",src.pick(\",g.join(),\")\",c,\");}else{zero(\",h,\");};\");break;default:throw new Error(\"ndarray-gradient: Invalid boundary condition\")}}i>0&&n.push(\"};\")}for(var s=0;s<1<<r;++s){for(var h=[],f=0;f<r;++f)s&1<<f&&h.push(f+1);for(var p=0;p<1<<h.length;++p){for(var d=h.slice(),f=0;f<h.length;++f)p&1<<f&&(d[f]=-d[f]);i(d)}}n.push(\"return dst;};return gradient\");for(var g=[\"diff\",\"zero\"],v=[l,c],s=1;s<=r;++s)g.push(\"grad\"+s),v.push(u(s));g.push(n.join(\"\"));var m=Function.apply(void 0,g).apply(void 0,v);return a[e]=m,m}(r)(t,e)};var n=t(\"dup\"),i=t(\"cwise-compiler\"),a={},o={},s={body:\"\",args:[],thisVars:[],localVars:[]},l=i({args:[\"array\",\"array\",\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1},{name:\"left\",lvalue:!1,rvalue:!0,count:1},{name:\"right\",lvalue:!1,rvalue:!0,count:1}],body:\"out=0.5*(left-right)\",thisVars:[],localVars:[]},funcName:\"cdiff\"}),c=i({args:[\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1}],body:\"out=0\",thisVars:[],localVars:[]},funcName:\"zero\"});function u(t){if(t in a)return a[t];for(var e=[],r=0;r<t;++r)e.push(\"out\",r,\"s=0.5*(inp\",r,\"l-inp\",r,\"r);\");var o=[\"array\"],l=[\"junk\"];for(r=0;r<t;++r){o.push(\"array\"),l.push(\"out\"+r+\"s\");var c=n(t);c[r]=-1,o.push({array:0,offset:c.slice()}),c[r]=1,o.push({array:0,offset:c.slice()}),l.push(\"inp\"+r+\"l\",\"inp\"+r+\"r\")}return a[t]=i({args:o,pre:s,post:s,body:{body:e.join(\"\"),args:l.map(function(t){return{name:t,lvalue:0===t.indexOf(\"out\"),rvalue:0===t.indexOf(\"inp\"),count:\"junk\"!==t|0}}),thisVars:[],localVars:[]},funcName:\"fdTemplate\"+t})}},{\"cwise-compiler\":146,dup:170}],442:[function(t,e,r){\"use strict\";var n=t(\"ndarray-warp\"),i=t(\"gl-matrix-invert\");e.exports=function(t,e,r){var a=e.dimension,o=i([],r);return n(t,e,function(t,e){for(var r=0;r<a;++r){t[r]=o[(a+1)*a+r];for(var n=0;n<a;++n)t[r]+=o[(a+1)*n+r]*e[n]}var i=o[(a+1)*(a+1)-1];for(n=0;n<a;++n)i+=o[(a+1)*n+a]*e[n];var s=1/i;for(r=0;r<a;++r)t[r]*=s;return t}),t}},{\"gl-matrix-invert\":277,\"ndarray-warp\":449}],443:[function(t,e,r){\"use strict\";function n(t,e){var r=Math.floor(e),n=e-r,i=0<=r&&r<t.shape[0],a=0<=r+1&&r+1<t.shape[0];return(1-n)*(i?+t.get(r):0)+n*(a?+t.get(r+1):0)}function i(t,e,r){var n=Math.floor(e),i=e-n,a=0<=n&&n<t.shape[0],o=0<=n+1&&n+1<t.shape[0],s=Math.floor(r),l=r-s,c=0<=s&&s<t.shape[1],u=0<=s+1&&s+1<t.shape[1],h=a&&c?t.get(n,s):0,f=a&&u?t.get(n,s+1):0;return(1-l)*((1-i)*h+i*(o&&c?t.get(n+1,s):0))+l*((1-i)*f+i*(o&&u?t.get(n+1,s+1):0))}function a(t,e,r,n){var i=Math.floor(e),a=e-i,o=0<=i&&i<t.shape[0],s=0<=i+1&&i+1<t.shape[0],l=Math.floor(r),c=r-l,u=0<=l&&l<t.shape[1],h=0<=l+1&&l+1<t.shape[1],f=Math.floor(n),p=n-f,d=0<=f&&f<t.shape[2],g=0<=f+1&&f+1<t.shape[2],v=o&&u&&d?t.get(i,l,f):0,m=o&&h&&d?t.get(i,l+1,f):0,y=s&&u&&d?t.get(i+1,l,f):0,x=s&&h&&d?t.get(i+1,l+1,f):0,b=o&&u&&g?t.get(i,l,f+1):0,_=o&&h&&g?t.get(i,l+1,f+1):0;return(1-p)*((1-c)*((1-a)*v+a*y)+c*((1-a)*m+a*x))+p*((1-c)*((1-a)*b+a*(s&&u&&g?t.get(i+1,l,f+1):0))+c*((1-a)*_+a*(s&&h&&g?t.get(i+1,l+1,f+1):0)))}e.exports=function(t,e,r,o){switch(t.shape.length){case 0:return 0;case 1:return n(t,e);case 2:return i(t,e,r);case 3:return a(t,e,r,o);default:return function(t){var e,r,n=0|t.shape.length,i=new Array(n),a=new Array(n),o=new Array(n),s=new Array(n);for(e=0;e<n;++e)r=+arguments[e+1],i[e]=Math.floor(r),a[e]=r-i[e],o[e]=0<=i[e]&&i[e]<t.shape[e],s[e]=0<=i[e]+1&&i[e]+1<t.shape[e];var l,c,u,h=0;t:for(e=0;e<1<<n;++e){for(c=1,u=t.offset,l=0;l<n;++l)if(e&1<<l){if(!s[l])continue t;c*=a[l],u+=t.stride[l]*(i[l]+1)}else{if(!o[l])continue t;c*=1-a[l],u+=t.stride[l]*i[l]}h+=c*t.data[u]}return h}.apply(void 0,arguments)}},e.exports.d1=n,e.exports.d2=i,e.exports.d3=a},{}],444:[function(t,e,r){\"use strict\";var n=t(\"cwise-compiler\"),i={body:\"\",args:[],thisVars:[],localVars:[]};function a(t){if(!t)return i;for(var e=0;e<t.args.length;++e){var r=t.args[e];t.args[e]=0===e?{name:r,lvalue:!0,rvalue:!!t.rvalue,count:t.count||1}:{name:r,lvalue:!1,rvalue:!0,count:1}}return t.thisVars||(t.thisVars=[]),t.localVars||(t.localVars=[]),t}function o(t){for(var e=[],r=0;r<t.args.length;++r)e.push(\"a\"+r);return new Function(\"P\",[\"return function \",t.funcName,\"_ndarrayops(\",e.join(\",\"),\") {P(\",e.join(\",\"),\");return a0}\"].join(\"\"))(function(t){return n({args:t.args,pre:a(t.pre),body:a(t.body),post:a(t.proc),funcName:t.funcName})}(t))}var s={add:\"+\",sub:\"-\",mul:\"*\",div:\"/\",mod:\"%\",band:\"&\",bor:\"|\",bxor:\"^\",lshift:\"<<\",rshift:\">>\",rrshift:\">>>\"};!function(){for(var t in s){var e=s[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a\"+e+\"=b\"},rvalue:!0,funcName:t+\"eq\"}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a\"+e+\"=s\"},rvalue:!0,funcName:t+\"seq\"})}}();var l={not:\"!\",bnot:\"~\",neg:\"-\",recip:\"1.0/\"};!function(){for(var t in l){var e=l[t];r[t]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=\"+e+\"b\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\"],body:{args:[\"a\"],body:\"a=\"+e+\"a\"},rvalue:!0,count:2,funcName:t+\"eq\"})}}();var c={and:\"&&\",or:\"||\",eq:\"===\",neq:\"!==\",lt:\"<\",gt:\">\",leq:\"<=\",geq:\">=\"};!function(){for(var t in c){var e=c[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=a\"+e+\"b\"},rvalue:!0,count:2,funcName:t+\"eq\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a=a\"+e+\"s\"},rvalue:!0,count:2,funcName:t+\"seq\"})}}();var u=[\"abs\",\"acos\",\"asin\",\"atan\",\"ceil\",\"cos\",\"exp\",\"floor\",\"log\",\"round\",\"sin\",\"sqrt\",\"tan\"];!function(){for(var t=0;t<u.length;++t){var e=u[t];r[e]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"eq\"]=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f(a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"})}}();var h=[\"max\",\"min\",\"atan2\",\"pow\"];!function(){for(var t=0;t<h.length;++t){var e=h[t];r[e]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e+\"s\"}),r[e+\"eq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"}),r[e+\"seq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"seq\"})}}();var f=[\"atan2\",\"pow\"];!function(){for(var t=0;t<f.length;++t){var e=f[t];r[e+\"op\"]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"op\"}),r[e+\"ops\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"ops\"}),r[e+\"opeq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opeq\"}),r[e+\"opseq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opseq\"})}}(),r.any=n({args:[\"array\"],pre:i,body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"if(a){return true}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return false\"},funcName:\"any\"}),r.all=n({args:[\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1}],body:\"if(!x){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"all\"}),r.sum=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s+=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"sum\"}),r.prod=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=1\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s*=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"prod\"}),r.norm2squared=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm2squared\"}),r.norm2=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return Math.sqrt(this_s)\"},funcName:\"norm2\"}),r.norminf=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:4}],body:\"if(-a>this_s){this_s=-a}else if(a>this_s){this_s=a}\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norminf\"}),r.norm1=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:3}],body:\"this_s+=a<0?-a:a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm1\"}),r.sup=n({args:[\"array\"],pre:{body:\"this_h=-Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_>this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.inf=n({args:[\"array\"],pre:{body:\"this_h=Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_<this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.argmin=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_<this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.argmax=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=-Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_>this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.random=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.random\",thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f()\",thisVars:[\"this_f\"]},funcName:\"random\"}),r.assign=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assign\"}),r.assigns=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assigns\"}),r.equals=n({args:[\"array\",\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1},{name:\"y\",lvalue:!1,rvalue:!0,count:1}],body:\"if(x!==y){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"equals\"})},{\"cwise-compiler\":146}],445:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"./doConvert.js\");e.exports=function(t,e){for(var r=[],a=t,o=1;Array.isArray(a);)r.push(a.length),o*=a.length,a=a[0];return 0===r.length?n():(e||(e=n(new Float64Array(o),r)),i(e,t),e)}},{\"./doConvert.js\":446,ndarray:450}],446:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\nvar _inline_1_v=_inline_1_arg1_,_inline_1_i\\nfor(_inline_1_i=0;_inline_1_i<_inline_1_arg2_.length-1;++_inline_1_i) {\\n_inline_1_v=_inline_1_v[_inline_1_arg2_[_inline_1_i]]\\n}\\n_inline_1_arg0_=_inline_1_v[_inline_1_arg2_[_inline_1_arg2_.length-1]]\\n}\",args:[{name:\"_inline_1_arg0_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:4}],thisVars:[],localVars:[\"_inline_1_i\",\"_inline_1_v\"]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},funcName:\"convert\",blockSize:64})},{\"cwise-compiler\":146}],447:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=32;function a(t){switch(t){case\"uint8\":return[n.mallocUint8,n.freeUint8];case\"uint16\":return[n.mallocUint16,n.freeUint16];case\"uint32\":return[n.mallocUint32,n.freeUint32];case\"int8\":return[n.mallocInt8,n.freeInt8];case\"int16\":return[n.mallocInt16,n.freeInt16];case\"int32\":return[n.mallocInt32,n.freeInt32];case\"float32\":return[n.mallocFloat,n.freeFloat];case\"float64\":return[n.mallocDouble,n.freeDouble];default:return null}}function o(t){for(var e=[],r=0;r<t;++r)e.push(\"s\"+r);for(r=0;r<t;++r)e.push(\"n\"+r);for(r=1;r<t;++r)e.push(\"d\"+r);for(r=1;r<t;++r)e.push(\"e\"+r);for(r=1;r<t;++r)e.push(\"f\"+r);return e}e.exports=function(t,e){var r=[\"'use strict'\"],n=[\"ndarraySortWrapper\",t.join(\"d\"),e].join(\"\");r.push([\"function \",n,\"(\",[\"array\"].join(\",\"),\"){\"].join(\"\"));for(var s=[\"data=array.data,offset=array.offset|0,shape=array.shape,stride=array.stride\"],l=0;l<t.length;++l)s.push([\"s\",l,\"=stride[\",l,\"]|0,n\",l,\"=shape[\",l,\"]|0\"].join(\"\"));var c=new Array(t.length),u=[];for(l=0;l<t.length;++l)0!==(p=t[l])&&(0===u.length?c[p]=\"1\":c[p]=u.join(\"*\"),u.push(\"n\"+p));var h=-1,f=-1;for(l=0;l<t.length;++l){var p,d=t[l];0!==d&&(h>0?s.push([\"d\",d,\"=s\",d,\"-d\",h,\"*n\",h].join(\"\")):s.push([\"d\",d,\"=s\",d].join(\"\")),h=d),0!=(p=t.length-1-l)&&(f>0?s.push([\"e\",p,\"=s\",p,\"-e\",f,\"*n\",f,\",f\",p,\"=\",c[p],\"-f\",f,\"*n\",f].join(\"\")):s.push([\"e\",p,\"=s\",p,\",f\",p,\"=\",c[p]].join(\"\")),f=p)}r.push(\"var \"+s.join(\",\"));var g=[\"0\",\"n0-1\",\"data\",\"offset\"].concat(o(t.length));r.push([\"if(n0<=\",i,\"){\",\"insertionSort(\",g.join(\",\"),\")}else{\",\"quickSort(\",g.join(\",\"),\")}\"].join(\"\")),r.push(\"}return \"+n);var v=new Function(\"insertionSort\",\"quickSort\",r.join(\"\\n\")),m=function(t,e){var r=[\"'use strict'\"],n=[\"ndarrayInsertionSort\",t.join(\"d\"),e].join(\"\"),i=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),s=a(e),l=[\"i,j,cptr,ptr=left*s0+offset\"];if(t.length>1){for(var c=[],u=1;u<t.length;++u)l.push(\"i\"+u),c.push(\"n\"+u);s?l.push(\"scratch=malloc(\"+c.join(\"*\")+\")\"):l.push(\"scratch=new Array(\"+c.join(\"*\")+\")\"),l.push(\"dptr\",\"sptr\",\"a\",\"b\")}else l.push(\"scratch\");function h(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function f(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}if(r.push([\"function \",n,\"(\",i.join(\",\"),\"){var \",l.join(\",\")].join(\"\"),\"for(i=left+1;i<=right;++i){\",\"j=i;ptr+=s0\",\"cptr=ptr\"),t.length>1){for(r.push(\"dptr=0;sptr=ptr\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(\"scratch[dptr++]=\",h(\"sptr\")),u=0;u<t.length;++u)0!==(p=t[u])&&r.push(\"sptr+=d\"+p,\"}\");for(r.push(\"__g:while(j--\\x3eleft){\",\"dptr=0\",\"sptr=cptr-s0\"),u=1;u<t.length;++u)1===u&&r.push(\"__l:\"),r.push([\"for(i\",u,\"=0;i\",u,\"<n\",u,\";++i\",u,\"){\"].join(\"\"));for(r.push([\"a=\",h(\"sptr\"),\"\\nb=scratch[dptr]\\nif(a<b){break __g}\\nif(a>b){break __l}\"].join(\"\")),u=t.length-1;u>=1;--u)r.push(\"sptr+=e\"+u,\"dptr+=f\"+u,\"}\");for(r.push(\"dptr=cptr;sptr=cptr-s0\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(f(\"dptr\",h(\"sptr\"))),u=0;u<t.length;++u)0!==(p=t[u])&&r.push([\"dptr+=d\",p,\";sptr+=d\",p].join(\"\"),\"}\");for(r.push(\"cptr-=s0\\n}\"),r.push(\"dptr=cptr;sptr=0\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(f(\"dptr\",\"scratch[sptr++]\")),u=0;u<t.length;++u){var p;0!==(p=t[u])&&r.push(\"dptr+=d\"+p,\"}\")}}else r.push(\"scratch=\"+h(\"ptr\"),\"while((j--\\x3eleft)&&(\"+h(\"cptr-s0\")+\">scratch)){\",f(\"cptr\",h(\"cptr-s0\")),\"cptr-=s0\",\"}\",f(\"cptr\",\"scratch\"));return r.push(\"}\"),t.length>1&&s&&r.push(\"free(scratch)\"),r.push(\"} return \"+n),s?new Function(\"malloc\",\"free\",r.join(\"\\n\"))(s[0],s[1]):new Function(r.join(\"\\n\"))()}(t,e),y=function(t,e,r){var n=[\"'use strict'\"],s=[\"ndarrayQuickSort\",t.join(\"d\"),e].join(\"\"),l=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),c=a(e),u=0;n.push([\"function \",s,\"(\",l.join(\",\"),\"){\"].join(\"\"));var h=[\"sixth=((right-left+1)/6)|0\",\"index1=left+sixth\",\"index5=right-sixth\",\"index3=(left+right)>>1\",\"index2=index3-sixth\",\"index4=index3+sixth\",\"el1=index1\",\"el2=index2\",\"el3=index3\",\"el4=index4\",\"el5=index5\",\"less=left+1\",\"great=right-1\",\"pivots_are_equal=true\",\"tmp\",\"tmp0\",\"x\",\"y\",\"z\",\"k\",\"ptr0\",\"ptr1\",\"ptr2\",\"comp_pivot1=0\",\"comp_pivot2=0\",\"comp=0\"];if(t.length>1){for(var f=[],p=1;p<t.length;++p)f.push(\"n\"+p),h.push(\"i\"+p);for(p=0;p<8;++p)h.push(\"b_ptr\"+p);h.push(\"ptr3\",\"ptr4\",\"ptr5\",\"ptr6\",\"ptr7\",\"pivot_ptr\",\"ptr_shift\",\"elementSize=\"+f.join(\"*\")),c?h.push(\"pivot1=malloc(elementSize)\",\"pivot2=malloc(elementSize)\"):h.push(\"pivot1=new Array(elementSize),pivot2=new Array(elementSize)\")}else h.push(\"pivot1\",\"pivot2\");function d(t){return[\"(offset+\",t,\"*s0)\"].join(\"\")}function g(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function v(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}function m(e,r,i){if(1===e.length)n.push(\"ptr0=\"+d(e[0]));else for(var a=0;a<e.length;++a)n.push([\"b_ptr\",a,\"=s0*\",e[a]].join(\"\"));for(r&&n.push(\"pivot_ptr=0\"),n.push(\"ptr_shift=offset\"),a=t.length-1;a>=0;--a)0!==(o=t[a])&&n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"));if(e.length>1)for(a=0;a<e.length;++a)n.push([\"ptr\",a,\"=b_ptr\",a,\"+ptr_shift\"].join(\"\"));for(n.push(i),r&&n.push(\"++pivot_ptr\"),a=0;a<t.length;++a){var o;0!==(o=t[a])&&(e.length>1?n.push(\"ptr_shift+=d\"+o):n.push(\"ptr0+=d\"+o),n.push(\"}\"))}}function y(e,r,i,a){if(1===r.length)n.push(\"ptr0=\"+d(r[0]));else{for(var o=0;o<r.length;++o)n.push([\"b_ptr\",o,\"=s0*\",r[o]].join(\"\"));n.push(\"ptr_shift=offset\")}for(i&&n.push(\"pivot_ptr=0\"),e&&n.push(e+\":\"),o=1;o<t.length;++o)n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"));if(r.length>1)for(o=0;o<r.length;++o)n.push([\"ptr\",o,\"=b_ptr\",o,\"+ptr_shift\"].join(\"\"));for(n.push(a),o=t.length-1;o>=1;--o)i&&n.push(\"pivot_ptr+=f\"+o),r.length>1?n.push(\"ptr_shift+=e\"+o):n.push(\"ptr0+=e\"+o),n.push(\"}\")}function x(){t.length>1&&c&&n.push(\"free(pivot1)\",\"free(pivot2)\")}function b(e,r){var i=\"el\"+e,a=\"el\"+r;if(t.length>1){var o=\"__l\"+ ++u;y(o,[i,a],!1,[\"comp=\",g(\"ptr0\"),\"-\",g(\"ptr1\"),\"\\n\",\"if(comp>0){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0;break \",o,\"}\\n\",\"if(comp<0){break \",o,\"}\"].join(\"\"))}else n.push([\"if(\",g(d(i)),\">\",g(d(a)),\"){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0}\"].join(\"\"))}function _(e,r){t.length>1?m([e,r],!1,v(\"ptr0\",g(\"ptr1\"))):n.push(v(d(e),g(d(r))))}function w(e,r,i){if(t.length>1){var a=\"__l\"+ ++u;y(a,[r],!0,[e,\"=\",g(\"ptr0\"),\"-pivot\",i,\"[pivot_ptr]\\n\",\"if(\",e,\"!==0){break \",a,\"}\"].join(\"\"))}else n.push([e,\"=\",g(d(r)),\"-pivot\",i].join(\"\"))}function k(e,r){t.length>1?m([e,r],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",\"tmp\")].join(\"\")):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",\"tmp\")].join(\"\"))}function T(e,r,i){t.length>1?(m([e,r,i],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",g(\"ptr2\")),\"\\n\",v(\"ptr2\",\"tmp\")].join(\"\")),n.push(\"++\"+r,\"--\"+i)):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"ptr2=\",d(i),\"\\n\",\"++\",r,\"\\n\",\"--\",i,\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",g(\"ptr2\")),\"\\n\",v(\"ptr2\",\"tmp\")].join(\"\"))}function A(t,e){k(t,e),n.push(\"--\"+e)}function M(e,r,i){t.length>1?m([e,r],!0,[v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",[\"pivot\",i,\"[pivot_ptr]\"].join(\"\"))].join(\"\")):n.push(v(d(e),g(d(r))),v(d(r),\"pivot\"+i))}function S(e,r){n.push([\"if((\",r,\"-\",e,\")<=\",i,\"){\\n\",\"insertionSort(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}else{\\n\",s,\"(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}\"].join(\"\"))}function E(e,r,i){t.length>1?(n.push([\"__l\",++u,\":while(true){\"].join(\"\")),m([e],!0,[\"if(\",g(\"ptr0\"),\"!==pivot\",r,\"[pivot_ptr]){break __l\",u,\"}\"].join(\"\")),n.push(i,\"}\")):n.push([\"while(\",g(d(e)),\"===pivot\",r,\"){\",i,\"}\"].join(\"\"))}return n.push(\"var \"+h.join(\",\")),b(1,2),b(4,5),b(1,3),b(2,3),b(1,4),b(3,4),b(2,5),b(2,3),b(4,5),t.length>1?m([\"el1\",\"el2\",\"el3\",\"el4\",\"el5\",\"index1\",\"index3\",\"index5\"],!0,[\"pivot1[pivot_ptr]=\",g(\"ptr1\"),\"\\n\",\"pivot2[pivot_ptr]=\",g(\"ptr3\"),\"\\n\",\"pivots_are_equal=pivots_are_equal&&(pivot1[pivot_ptr]===pivot2[pivot_ptr])\\n\",\"x=\",g(\"ptr0\"),\"\\n\",\"y=\",g(\"ptr2\"),\"\\n\",\"z=\",g(\"ptr4\"),\"\\n\",v(\"ptr5\",\"x\"),\"\\n\",v(\"ptr6\",\"y\"),\"\\n\",v(\"ptr7\",\"z\")].join(\"\")):n.push([\"pivot1=\",g(d(\"el2\")),\"\\n\",\"pivot2=\",g(d(\"el4\")),\"\\n\",\"pivots_are_equal=pivot1===pivot2\\n\",\"x=\",g(d(\"el1\")),\"\\n\",\"y=\",g(d(\"el3\")),\"\\n\",\"z=\",g(d(\"el5\")),\"\\n\",v(d(\"index1\"),\"x\"),\"\\n\",v(d(\"index3\"),\"y\"),\"\\n\",v(d(\"index5\"),\"z\")].join(\"\")),_(\"index2\",\"left\"),_(\"index4\",\"right\"),n.push(\"if(pivots_are_equal){\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp\",\"k\",1),n.push(\"if(comp===0){continue}\"),n.push(\"if(comp<0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),n.push(\"while(true){\"),w(\"comp\",\"great\",1),n.push(\"if(comp>0){\"),n.push(\"great--\"),n.push(\"}else if(comp<0){\"),T(\"k\",\"less\",\"great\"),n.push(\"break\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}else{\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1<0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2>0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp>0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),T(\"k\",\"less\",\"great\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),M(\"left\",\"(less-1)\",1),M(\"right\",\"(great+1)\",2),S(\"left\",\"(less-2)\"),S(\"(great+2)\",\"right\"),n.push(\"if(pivots_are_equal){\"),x(),n.push(\"return\"),n.push(\"}\"),n.push(\"if(less<index1&&great>index5){\"),E(\"less\",1,\"++less\"),E(\"great\",2,\"--great\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1===0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2===0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp===0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),T(\"k\",\"less\",\"great\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),x(),S(\"less\",\"great\"),n.push(\"}return \"+s),t.length>1&&c?new Function(\"insertionSort\",\"malloc\",\"free\",n.join(\"\\n\"))(r,c[0],c[1]):new Function(\"insertionSort\",n.join(\"\\n\"))(r)}(t,e,m);return v(m,y)}},{\"typedarray-pool\":545}],448:[function(t,e,r){\"use strict\";var n=t(\"./lib/compile_sort.js\"),i={};e.exports=function(t){var e=t.order,r=t.dtype,a=[e,r].join(\":\"),o=i[a];return o||(i[a]=o=n(e,r)),o(t),t}},{\"./lib/compile_sort.js\":447}],449:[function(t,e,r){\"use strict\";var n=t(\"ndarray-linear-interpolate\"),i=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=new Array(_inline_3_arg4_)}\",args:[{name:\"_inline_3_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg2_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg3_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_4_arg2_(this_warped,_inline_4_arg0_),_inline_4_arg1_=_inline_4_arg3_.apply(void 0,this_warped)}\",args:[{name:\"_inline_4_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_4_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg4_\",lvalue:!1,rvalue:!1,count:0}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warpND\",blockSize:64}),a=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_7_arg2_(this_warped,_inline_7_arg0_),_inline_7_arg1_=_inline_7_arg3_(_inline_7_arg4_,this_warped[0])}\",args:[{name:\"_inline_7_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_7_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp1D\",blockSize:64}),o=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0,0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_10_arg2_(this_warped,_inline_10_arg0_),_inline_10_arg1_=_inline_10_arg3_(_inline_10_arg4_,this_warped[0],this_warped[1])}\",args:[{name:\"_inline_10_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_10_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp2D\",blockSize:64}),s=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0,0,0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_13_arg2_(this_warped,_inline_13_arg0_),_inline_13_arg1_=_inline_13_arg3_(_inline_13_arg4_,this_warped[0],this_warped[1],this_warped[2])}\",args:[{name:\"_inline_13_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_13_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp3D\",blockSize:64});e.exports=function(t,e,r){switch(e.shape.length){case 1:a(t,r,n.d1,e);break;case 2:o(t,r,n.d2,e);break;case 3:s(t,r,n.d3,e);break;default:i(t,r,n.bind(void 0,e),e.shape.length)}return t}},{\"cwise/lib/wrapper\":149,\"ndarray-linear-interpolate\":443}],450:[function(t,e,r){var n=t(\"iota-array\"),i=t(\"is-buffer\"),a=\"undefined\"!=typeof Float64Array;function o(t,e){return t[0]-e[0]}function s(){var t,e=this.stride,r=new Array(e.length);for(t=0;t<r.length;++t)r[t]=[Math.abs(e[t]),t];r.sort(o);var n=new Array(r.length);for(t=0;t<n.length;++t)n[t]=r[t][1];return n}function l(t,e){var r=[\"View\",e,\"d\",t].join(\"\");e<0&&(r=\"View_Nil\"+t);var i=\"generic\"===t;if(-1===e){var a=\"function \"+r+\"(a){this.data=a;};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return -1};proto.size=0;proto.dimension=-1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function(){return new \"+r+\"(this.data);};proto.get=proto.set=function(){};proto.pick=function(){return null};return function construct_\"+r+\"(a){return new \"+r+\"(a);}\";return new Function(a)()}if(0===e){a=\"function \"+r+\"(a,d) {this.data = a;this.offset = d};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return this.offset};proto.dimension=0;proto.size=1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function \"+r+\"_copy() {return new \"+r+\"(this.data,this.offset)};proto.pick=function \"+r+\"_pick(){return TrivialArray(this.data);};proto.valueOf=proto.get=function \"+r+\"_get(){return \"+(i?\"this.data.get(this.offset)\":\"this.data[this.offset]\")+\"};proto.set=function \"+r+\"_set(v){return \"+(i?\"this.data.set(this.offset,v)\":\"this.data[this.offset]=v\")+\"};return function construct_\"+r+\"(a,b,c,d){return new \"+r+\"(a,d)}\";return new Function(\"TrivialArray\",a)(c[t][0])}a=[\"'use strict'\"];var o=n(e),l=o.map(function(t){return\"i\"+t}),u=\"this.offset+\"+o.map(function(t){return\"this.stride[\"+t+\"]*i\"+t}).join(\"+\"),h=o.map(function(t){return\"b\"+t}).join(\",\"),f=o.map(function(t){return\"c\"+t}).join(\",\");a.push(\"function \"+r+\"(a,\"+h+\",\"+f+\",d){this.data=a\",\"this.shape=[\"+h+\"]\",\"this.stride=[\"+f+\"]\",\"this.offset=d|0}\",\"var proto=\"+r+\".prototype\",\"proto.dtype='\"+t+\"'\",\"proto.dimension=\"+e),a.push(\"Object.defineProperty(proto,'size',{get:function \"+r+\"_size(){return \"+o.map(function(t){return\"this.shape[\"+t+\"]\"}).join(\"*\"),\"}})\"),1===e?a.push(\"proto.order=[0]\"):(a.push(\"Object.defineProperty(proto,'order',{get:\"),e<4?(a.push(\"function \"+r+\"_order(){\"),2===e?a.push(\"return (Math.abs(this.stride[0])>Math.abs(this.stride[1]))?[1,0]:[0,1]}})\"):3===e&&a.push(\"var s0=Math.abs(this.stride[0]),s1=Math.abs(this.stride[1]),s2=Math.abs(this.stride[2]);if(s0>s1){if(s1>s2){return [2,1,0];}else if(s0>s2){return [1,2,0];}else{return [1,0,2];}}else if(s0>s2){return [2,0,1];}else if(s2>s1){return [0,1,2];}else{return [0,2,1];}}})\")):a.push(\"ORDER})\")),a.push(\"proto.set=function \"+r+\"_set(\"+l.join(\",\")+\",v){\"),i?a.push(\"return this.data.set(\"+u+\",v)}\"):a.push(\"return this.data[\"+u+\"]=v}\"),a.push(\"proto.get=function \"+r+\"_get(\"+l.join(\",\")+\"){\"),i?a.push(\"return this.data.get(\"+u+\")}\"):a.push(\"return this.data[\"+u+\"]}\"),a.push(\"proto.index=function \"+r+\"_index(\",l.join(),\"){return \"+u+\"}\"),a.push(\"proto.hi=function \"+r+\"_hi(\"+l.join(\",\")+\"){return new \"+r+\"(this.data,\"+o.map(function(t){return[\"(typeof i\",t,\"!=='number'||i\",t,\"<0)?this.shape[\",t,\"]:i\",t,\"|0\"].join(\"\")}).join(\",\")+\",\"+o.map(function(t){return\"this.stride[\"+t+\"]\"}).join(\",\")+\",this.offset)}\");var p=o.map(function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"}),d=o.map(function(t){return\"c\"+t+\"=this.stride[\"+t+\"]\"});a.push(\"proto.lo=function \"+r+\"_lo(\"+l.join(\",\")+\"){var b=this.offset,d=0,\"+p.join(\",\")+\",\"+d.join(\",\"));for(var g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){d=i\"+g+\"|0;b+=c\"+g+\"*d;a\"+g+\"-=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map(function(t){return\"a\"+t}).join(\",\")+\",\"+o.map(function(t){return\"c\"+t}).join(\",\")+\",b)}\"),a.push(\"proto.step=function \"+r+\"_step(\"+l.join(\",\")+\"){var \"+o.map(function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"}).join(\",\")+\",\"+o.map(function(t){return\"b\"+t+\"=this.stride[\"+t+\"]\"}).join(\",\")+\",c=this.offset,d=0,ceil=Math.ceil\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'){d=i\"+g+\"|0;if(d<0){c+=b\"+g+\"*(a\"+g+\"-1);a\"+g+\"=ceil(-a\"+g+\"/d)}else{a\"+g+\"=ceil(a\"+g+\"/d)}b\"+g+\"*=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map(function(t){return\"a\"+t}).join(\",\")+\",\"+o.map(function(t){return\"b\"+t}).join(\",\")+\",c)}\");var v=new Array(e),m=new Array(e);for(g=0;g<e;++g)v[g]=\"a[i\"+g+\"]\",m[g]=\"b[i\"+g+\"]\";a.push(\"proto.transpose=function \"+r+\"_transpose(\"+l+\"){\"+l.map(function(t,e){return t+\"=(\"+t+\"===undefined?\"+e+\":\"+t+\"|0)\"}).join(\";\"),\"var a=this.shape,b=this.stride;return new \"+r+\"(this.data,\"+v.join(\",\")+\",\"+m.join(\",\")+\",this.offset)}\"),a.push(\"proto.pick=function \"+r+\"_pick(\"+l+\"){var a=[],b=[],c=this.offset\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){c=(c+this.stride[\"+g+\"]*i\"+g+\")|0}else{a.push(this.shape[\"+g+\"]);b.push(this.stride[\"+g+\"])}\");return a.push(\"var ctor=CTOR_LIST[a.length+1];return ctor(this.data,a,b,c)}\"),a.push(\"return function construct_\"+r+\"(data,shape,stride,offset){return new \"+r+\"(data,\"+o.map(function(t){return\"shape[\"+t+\"]\"}).join(\",\")+\",\"+o.map(function(t){return\"stride[\"+t+\"]\"}).join(\",\")+\",offset)}\"),new Function(\"CTOR_LIST\",\"ORDER\",a.join(\"\\n\"))(c[t],s)}var c={float32:[],float64:[],int8:[],int16:[],int32:[],uint8:[],uint16:[],uint32:[],array:[],uint8_clamped:[],buffer:[],generic:[]};e.exports=function(t,e,r,n){if(void 0===t)return(0,c.array[0])([]);\"number\"==typeof t&&(t=[t]),void 0===e&&(e=[t.length]);var o=e.length;if(void 0===r){r=new Array(o);for(var s=o-1,u=1;s>=0;--s)r[s]=u,u*=e[s]}if(void 0===n)for(n=0,s=0;s<o;++s)r[s]<0&&(n-=(e[s]-1)*r[s]);for(var h=function(t){if(i(t))return\"buffer\";if(a)switch(Object.prototype.toString.call(t)){case\"[object Float64Array]\":return\"float64\";case\"[object Float32Array]\":return\"float32\";case\"[object Int8Array]\":return\"int8\";case\"[object Int16Array]\":return\"int16\";case\"[object Int32Array]\":return\"int32\";case\"[object Uint8Array]\":return\"uint8\";case\"[object Uint16Array]\":return\"uint16\";case\"[object Uint32Array]\":return\"uint32\";case\"[object Uint8ClampedArray]\":return\"uint8_clamped\"}return Array.isArray(t)?\"array\":\"generic\"}(t),f=c[h];f.length<=o+1;)f.push(l(h,f.length-1));return(0,f[o+1])(t,e,r,n)}},{\"iota-array\":416,\"is-buffer\":418}],451:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=Math.pow(2,-1074),a=-1>>>0;e.exports=function(t,e){if(isNaN(t)||isNaN(e))return NaN;if(t===e)return t;if(0===t)return e<0?-i:i;var r=n.hi(t),o=n.lo(t);e>t==t>0?o===a?(r+=1,o=0):o+=1:0===o?(o=a,r-=1):o-=1;return n.pack(o,r)}},{\"double-bits\":167}],452:[function(t,e,r){var n=Math.PI,i=c(120);function a(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function o(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}function s(t,e,r,a,o,c,u,h,f,p){if(p)k=p[0],T=p[1],_=p[2],w=p[3];else{var d=l(t,e,-o);t=d.x,e=d.y;var g=(t-(h=(d=l(h,f,-o)).x))/2,v=(e-(f=d.y))/2,m=g*g/(r*r)+v*v/(a*a);m>1&&(r*=m=Math.sqrt(m),a*=m);var y=r*r,x=a*a,b=(c==u?-1:1)*Math.sqrt(Math.abs((y*x-y*v*v-x*g*g)/(y*v*v+x*g*g)));b==1/0&&(b=1);var _=b*r*v/a+(t+h)/2,w=b*-a*g/r+(e+f)/2,k=Math.asin(((e-w)/a).toFixed(9)),T=Math.asin(((f-w)/a).toFixed(9));(k=t<_?n-k:k)<0&&(k=2*n+k),(T=h<_?n-T:T)<0&&(T=2*n+T),u&&k>T&&(k-=2*n),!u&&T>k&&(T-=2*n)}if(Math.abs(T-k)>i){var A=T,M=h,S=f;T=k+i*(u&&T>k?1:-1);var E=s(h=_+r*Math.cos(T),f=w+a*Math.sin(T),r,a,o,0,u,M,S,[T,A,_,w])}var C=Math.tan((T-k)/4),L=4/3*r*C,P=4/3*a*C,O=[2*t-(t+L*Math.sin(k)),2*e-(e-P*Math.cos(k)),h+L*Math.sin(T),f-P*Math.cos(T),h,f];if(p)return O;E&&(O=O.concat(E));for(var z=0;z<O.length;){var I=l(O[z],O[z+1],o);O[z++]=I.x,O[z++]=I.y}return O}function l(t,e,r){return{x:t*Math.cos(r)-e*Math.sin(r),y:t*Math.sin(r)+e*Math.cos(r)}}function c(t){return t*(n/180)}e.exports=function(t){for(var e,r=[],n=0,i=0,l=0,u=0,h=null,f=null,p=0,d=0,g=0,v=t.length;g<v;g++){var m=t[g],y=m[0];switch(y){case\"M\":l=m[1],u=m[2];break;case\"A\":(m=s(p,d,m[1],m[2],c(m[3]),m[4],m[5],m[6],m[7])).unshift(\"C\"),m.length>7&&(r.push(m.splice(0,7)),m.unshift(\"C\"));break;case\"S\":var x=p,b=d;\"C\"!=e&&\"S\"!=e||(x+=x-n,b+=b-i),m=[\"C\",x,b,m[1],m[2],m[3],m[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(h=2*p-h,f=2*d-f):(h=p,f=d),m=o(p,d,h,f,m[1],m[2]);break;case\"Q\":h=m[1],f=m[2],m=o(p,d,m[1],m[2],m[3],m[4]);break;case\"L\":m=a(p,d,m[1],m[2]);break;case\"H\":m=a(p,d,m[1],d);break;case\"V\":m=a(p,d,p,m[1]);break;case\"Z\":m=a(p,d,l,u)}e=y,p=m[m.length-2],d=m[m.length-1],m.length>4?(n=m[m.length-4],i=m[m.length-3]):(n=p,i=d),r.push(m)}return r}},{}],453:[function(t,e,r){r.vertexNormals=function(t,e,r){for(var n=e.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o)i[o]=[0,0,0];for(o=0;o<t.length;++o)for(var s=t[o],l=0,c=s[s.length-1],u=s[0],h=0;h<s.length;++h){l=c,c=u,u=s[(h+1)%s.length];for(var f=e[l],p=e[c],d=e[u],g=new Array(3),v=0,m=new Array(3),y=0,x=0;x<3;++x)g[x]=f[x]-p[x],v+=g[x]*g[x],m[x]=d[x]-p[x],y+=m[x]*m[x];if(v*y>a){var b=i[c],_=1/Math.sqrt(v*y);for(x=0;x<3;++x){var w=(x+1)%3,k=(x+2)%3;b[x]+=_*(m[w]*g[k]-m[k]*g[w])}}}for(o=0;o<n;++o){b=i[o];var T=0;for(x=0;x<3;++x)T+=b[x]*b[x];if(T>a)for(_=1/Math.sqrt(T),x=0;x<3;++x)b[x]*=_;else for(x=0;x<3;++x)b[x]=0}return i},r.faceNormals=function(t,e,r){for(var n=t.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o){for(var s=t[o],l=new Array(3),c=0;c<3;++c)l[c]=e[s[c]];var u=new Array(3),h=new Array(3);for(c=0;c<3;++c)u[c]=l[1][c]-l[0][c],h[c]=l[2][c]-l[0][c];var f=new Array(3),p=0;for(c=0;c<3;++c){var d=(c+1)%3,g=(c+2)%3;f[c]=u[d]*h[g]-u[g]*h[d],p+=f[c]*f[c]}p=p>a?1/Math.sqrt(p):0;for(c=0;c<3;++c)f[c]*=p;i[o]=f}return i}},{}],454:[function(t,e,r){\"use strict\";var n=Object.getOwnPropertySymbols,i=Object.prototype.hasOwnProperty,a=Object.prototype.propertyIsEnumerable;e.exports=function(){try{if(!Object.assign)return!1;var t=new String(\"abc\");if(t[5]=\"de\",\"5\"===Object.getOwnPropertyNames(t)[0])return!1;for(var e={},r=0;r<10;r++)e[\"_\"+String.fromCharCode(r)]=r;if(\"0123456789\"!==Object.getOwnPropertyNames(e).map(function(t){return e[t]}).join(\"\"))return!1;var n={};return\"abcdefghijklmnopqrst\".split(\"\").forEach(function(t){n[t]=t}),\"abcdefghijklmnopqrst\"===Object.keys(Object.assign({},n)).join(\"\")}catch(t){return!1}}()?Object.assign:function(t,e){for(var r,o,s=function(t){if(null==t)throw new TypeError(\"Object.assign cannot be called with null or undefined\");return Object(t)}(t),l=1;l<arguments.length;l++){for(var c in r=Object(arguments[l]))i.call(r,c)&&(s[c]=r[c]);if(n){o=n(r);for(var u=0;u<o.length;u++)a.call(r,o[u])&&(s[o[u]]=r[o[u]])}}return s}},{}],455:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a,o,s,l,c){var u=e+a+c;if(h>0){var h=Math.sqrt(u+1);t[0]=.5*(o-l)/h,t[1]=.5*(s-n)/h,t[2]=.5*(r-a)/h,t[3]=.5*h}else{var f=Math.max(e,a,c),h=Math.sqrt(2*f-u+1);e>=f?(t[0]=.5*h,t[1]=.5*(i+r)/h,t[2]=.5*(s+n)/h,t[3]=.5*(o-l)/h):a>=f?(t[0]=.5*(r+i)/h,t[1]=.5*h,t[2]=.5*(l+o)/h,t[3]=.5*(s-n)/h):(t[0]=.5*(n+s)/h,t[1]=.5*(o+l)/h,t[2]=.5*h,t[3]=.5*(r-i)/h)}return t}},{}],456:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.rotation||[0,0,0,1],n=t.radius||1;e=[].slice.call(e,0,3),u(r=[].slice.call(r,0,4),r);var i=new h(r,e,Math.log(n));i.setDistanceLimits(t.zoomMin,t.zoomMax),(\"eye\"in t||\"up\"in t)&&i.lookAt(0,t.eye,t.center,t.up);return i};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/lookAt\"),a=t(\"gl-mat4/fromQuat\"),o=t(\"gl-mat4/invert\"),s=t(\"./lib/quatFromFrame\");function l(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function c(t,e,r,n){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2)+Math.pow(n,2))}function u(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=c(r,n,i,a);o>1e-6?(t[0]=r/o,t[1]=n/o,t[2]=i/o,t[3]=a/o):(t[0]=t[1]=t[2]=0,t[3]=1)}function h(t,e,r){this.radius=n([r]),this.center=n(e),this.rotation=n(t),this.computedRadius=this.radius.curve(0),this.computedCenter=this.center.curve(0),this.computedRotation=this.rotation.curve(0),this.computedUp=[.1,0,0],this.computedEye=[.1,0,0],this.computedMatrix=[.1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],this.recalcMatrix(0)}var f=h.prototype;f.lastT=function(){return Math.max(this.radius.lastT(),this.center.lastT(),this.rotation.lastT())},f.recalcMatrix=function(t){this.radius.curve(t),this.center.curve(t),this.rotation.curve(t);var e=this.computedRotation;u(e,e);var r=this.computedMatrix;a(r,e);var n=this.computedCenter,i=this.computedEye,o=this.computedUp,s=Math.exp(this.computedRadius[0]);i[0]=n[0]+s*r[2],i[1]=n[1]+s*r[6],i[2]=n[2]+s*r[10],o[0]=r[1],o[1]=r[5],o[2]=r[9];for(var l=0;l<3;++l){for(var c=0,h=0;h<3;++h)c+=r[l+4*h]*i[h];r[12+l]=-c}},f.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r},f.idle=function(t){this.center.idle(t),this.radius.idle(t),this.rotation.idle(t)},f.flush=function(t){this.center.flush(t),this.radius.flush(t),this.rotation.flush(t)},f.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=i[1],o=i[5],s=i[9],c=l(a,o,s);a/=c,o/=c,s/=c;var u=i[0],h=i[4],f=i[8],p=u*a+h*o+f*s,d=l(u-=a*p,h-=o*p,f-=s*p);u/=d,h/=d,f/=d;var g=i[2],v=i[6],m=i[10],y=g*a+v*o+m*s,x=g*u+v*h+m*f,b=l(g-=y*a+x*u,v-=y*o+x*h,m-=y*s+x*f);g/=b,v/=b,m/=b;var _=u*e+a*r,w=h*e+o*r,k=f*e+s*r;this.center.move(t,_,w,k);var T=Math.exp(this.computedRadius[0]);T=Math.max(1e-4,T+n),this.radius.set(t,Math.log(T))},f.rotate=function(t,e,r,n){this.recalcMatrix(t),e=e||0,r=r||0;var i=this.computedMatrix,a=i[0],o=i[4],s=i[8],u=i[1],h=i[5],f=i[9],p=i[2],d=i[6],g=i[10],v=e*a+r*u,m=e*o+r*h,y=e*s+r*f,x=-(d*y-g*m),b=-(g*v-p*y),_=-(p*m-d*v),w=Math.sqrt(Math.max(0,1-Math.pow(x,2)-Math.pow(b,2)-Math.pow(_,2))),k=c(x,b,_,w);k>1e-6?(x/=k,b/=k,_/=k,w/=k):(x=b=_=0,w=1);var T=this.computedRotation,A=T[0],M=T[1],S=T[2],E=T[3],C=A*w+E*x+M*_-S*b,L=M*w+E*b+S*x-A*_,P=S*w+E*_+A*b-M*x,O=E*w-A*x-M*b-S*_;if(n){x=p,b=d,_=g;var z=Math.sin(n)/l(x,b,_);x*=z,b*=z,_*=z,O=O*(w=Math.cos(e))-(C=C*w+O*x+L*_-P*b)*x-(L=L*w+O*b+P*x-C*_)*b-(P=P*w+O*_+C*b-L*x)*_}var I=c(C,L,P,O);I>1e-6?(C/=I,L/=I,P/=I,O/=I):(C=L=P=0,O=1),this.rotation.set(t,C,L,P,O)},f.lookAt=function(t,e,r,n){this.recalcMatrix(t),r=r||this.computedCenter,e=e||this.computedEye,n=n||this.computedUp;var a=this.computedMatrix;i(a,e,r,n);var o=this.computedRotation;s(o,a[0],a[1],a[2],a[4],a[5],a[6],a[8],a[9],a[10]),u(o,o),this.rotation.set(t,o[0],o[1],o[2],o[3]);for(var l=0,c=0;c<3;++c)l+=Math.pow(r[c]-e[c],2);this.radius.set(t,.5*Math.log(Math.max(l,1e-6))),this.center.set(t,r[0],r[1],r[2])},f.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},f.setMatrix=function(t,e){var r=this.computedRotation;s(r,e[0],e[1],e[2],e[4],e[5],e[6],e[8],e[9],e[10]),u(r,r),this.rotation.set(t,r[0],r[1],r[2],r[3]);var n=this.computedMatrix;o(n,e);var i=n[15];if(Math.abs(i)>1e-6){var a=n[12]/i,l=n[13]/i,c=n[14]/i;this.recalcMatrix(t);var h=Math.exp(this.computedRadius[0]);this.center.set(t,a-n[2]*h,l-n[6]*h,c-n[10]*h),this.radius.idle(t)}else this.center.idle(t),this.radius.idle(t)},f.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},f.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},f.getDistanceLimits=function(t){var e=this.radius.bounds;return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},f.toJSON=function(){return this.recalcMatrix(this.lastT()),{center:this.computedCenter.slice(),rotation:this.computedRotation.slice(),distance:Math.log(this.computedRadius[0]),zoomMin:this.radius.bounds[0][0],zoomMax:this.radius.bounds[1][0]}},f.fromJSON=function(t){var e=this.lastT(),r=t.center;r&&this.center.set(e,r[0],r[1],r[2]);var n=t.rotation;n&&this.rotation.set(e,n[0],n[1],n[2],n[3]);var i=t.distance;i&&i>0&&this.radius.set(e,Math.log(i)),this.setDistanceLimits(t.zoomMin,t.zoomMax)}},{\"./lib/quatFromFrame\":455,\"filtered-vector\":226,\"gl-mat4/fromQuat\":262,\"gl-mat4/invert\":265,\"gl-mat4/lookAt\":266}],457:[function(t,e,r){\"use strict\";var n=t(\"repeat-string\");e.exports=function(t,e,r){return n(r=\"undefined\"!=typeof r?r+\"\":\" \",e)+t}},{\"repeat-string\":503}],458:[function(t,e,r){\"use strict\";function n(t,e){if(\"string\"!=typeof t)return[t];var r=[t];\"string\"==typeof e||Array.isArray(e)?e={brackets:e}:e||(e={});var n=e.brackets?Array.isArray(e.brackets)?e.brackets:[e.brackets]:[\"{}\",\"[]\",\"()\"],i=e.escape||\"___\",a=!!e.flat;n.forEach(function(t){var e=new RegExp([\"\\\\\",t[0],\"[^\\\\\",t[0],\"\\\\\",t[1],\"]*\\\\\",t[1]].join(\"\")),n=[];function a(e,a,o){var s=r.push(e.slice(t[0].length,-t[1].length))-1;return n.push(s),i+s+i}r.forEach(function(t,n){for(var i,o=0;t!=i;)if(i=t,t=t.replace(e,a),o++>1e4)throw Error(\"References have circular dependency. Please, check them.\");r[n]=t}),n=n.reverse(),r=r.map(function(e){return n.forEach(function(r){e=e.replace(new RegExp(\"(\\\\\"+i+r+\"\\\\\"+i+\")\",\"g\"),t[0]+\"$1\"+t[1])}),e})});var o=new RegExp(\"\\\\\"+i+\"([0-9]+)\\\\\"+i);return a?r:function t(e,r,n){for(var i,a=[],s=0;i=o.exec(e);){if(s++>1e4)throw Error(\"Circular references in parenthesis\");a.push(e.slice(0,i.index)),a.push(t(r[i[1]],r)),e=e.slice(i.index+i[0].length)}return a.push(e),a}(r[0],r)}function i(t,e){if(e&&e.flat){var r,n=e&&e.escape||\"___\",i=t[0];if(!i)return\"\";for(var a=new RegExp(\"\\\\\"+n+\"([0-9]+)\\\\\"+n),o=0;i!=r;){if(o++>1e4)throw Error(\"Circular references in \"+t);r=i,i=i.replace(a,s)}return i}return t.reduce(function t(e,r){return Array.isArray(r)&&(r=r.reduce(t,\"\")),e+r},\"\");function s(e,r){if(null==t[r])throw Error(\"Reference \"+r+\"is undefined\");return t[r]}}function a(t,e){return Array.isArray(t)?i(t,e):n(t,e)}a.parse=n,a.stringify=i,e.exports=a},{}],459:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\");e.exports=function(t){var e;arguments.length>1&&(t=arguments);\"string\"==typeof t?t=t.split(/\\s/).map(parseFloat):\"number\"==typeof t&&(t=[t]);t.length&&\"number\"==typeof t[0]?e=1===t.length?{width:t[0],height:t[0],x:0,y:0}:2===t.length?{width:t[0],height:t[1],x:0,y:0}:{x:t[0],y:t[1],width:t[2]-t[0]||0,height:t[3]-t[1]||0}:t&&(t=n(t,{left:\"x l left Left\",top:\"y t top Top\",width:\"w width W Width\",height:\"h height W Width\",bottom:\"b bottom Bottom\",right:\"r right Right\"}),e={x:t.left||0,y:t.top||0},null==t.width?t.right?e.width=t.right-e.x:e.width=0:e.width=t.width,null==t.height?t.bottom?e.height=t.bottom-e.y:e.height=0:e.height=t.height);return e}},{\"pick-by-alias\":465}],460:[function(t,e,r){e.exports=function(t){var e=[];return t.replace(i,function(t,r,i){var o=r.toLowerCase();for(i=function(t){var e=t.match(a);return e?e.map(Number):[]}(i),\"m\"==o&&i.length>2&&(e.push([r].concat(i.splice(0,2))),o=\"l\",r=\"m\"==r?\"l\":\"L\");;){if(i.length==n[o])return i.unshift(r),e.push(i);if(i.length<n[o])throw new Error(\"malformed path data\");e.push([r].concat(i.splice(0,n[o])))}}),e};var n={a:7,c:6,h:1,l:2,m:2,q:4,s:4,t:2,v:1,z:0},i=/([astvzqmhlc])([^astvzqmhlc]*)/gi;var a=/-?[0-9]*\\.?[0-9]+(?:e[-+]?\\d+)?/gi},{}],461:[function(t,e,r){e.exports=function(t,e){e||(e=[0,\"\"]),t=String(t);var r=parseFloat(t,10);return e[0]=r,e[1]=t.match(/[\\d.\\-\\+]*\\s*(.*)/)[1]||\"\",e}},{}],462:[function(t,e,r){(function(t){(function(){var r,n,i,a,o,s;\"undefined\"!=typeof performance&&null!==performance&&performance.now?e.exports=function(){return performance.now()}:\"undefined\"!=typeof t&&null!==t&&t.hrtime?(e.exports=function(){return(r()-o)/1e6},n=t.hrtime,a=(r=function(){var t;return 1e9*(t=n())[0]+t[1]})(),s=1e9*t.uptime(),o=a-s):Date.now?(e.exports=function(){return Date.now()-i},i=Date.now()):(e.exports=function(){return(new Date).getTime()-i},i=(new Date).getTime())}).call(this)}).call(this,t(\"_process\"))},{_process:482}],463:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<n){for(var r=1,a=0;a<e;++a)for(var o=0;o<a;++o)if(t[a]<t[o])r=-r;else if(t[a]===t[o])return 0;return r}for(var s=i.mallocUint8(e),a=0;a<e;++a)s[a]=0;for(var r=1,a=0;a<e;++a)if(!s[a]){var l=1;s[a]=1;for(var o=t[a];o!==a;o=t[o]){if(s[o])return i.freeUint8(s),0;l+=1,s[o]=1}1&l||(r=-r)}return i.freeUint8(s),r};var n=32,i=t(\"typedarray-pool\")},{\"typedarray-pool\":545}],464:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"invert-permutation\");r.rank=function(t){var e=t.length;switch(e){case 0:case 1:return 0;case 2:return t[1]}var r,a,o,s=n.mallocUint32(e),l=n.mallocUint32(e),c=0;for(i(t,l),o=0;o<e;++o)s[o]=t[o];for(o=e-1;o>0;--o)a=l[o],r=s[o],s[o]=s[a],s[a]=r,l[o]=l[r],l[r]=a,c=(c+r)*o;return n.freeUint32(l),n.freeUint32(s),c},r.unrank=function(t,e,r){switch(t){case 0:return r||[];case 1:return r?(r[0]=0,r):[0];case 2:return r?(e?(r[0]=0,r[1]=1):(r[0]=1,r[1]=0),r):e?[0,1]:[1,0]}var n,i,a,o=1;for((r=r||new Array(t))[0]=0,a=1;a<t;++a)r[a]=a,o=o*a|0;for(a=t-1;a>0;--a)e=e-(n=e/o|0)*o|0,o=o/a|0,i=0|r[a],r[a]=0|r[n],r[n]=0|i;return r}},{\"invert-permutation\":415,\"typedarray-pool\":545}],465:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n,a,o={};if(\"string\"==typeof e&&(e=i(e)),Array.isArray(e)){var s={};for(a=0;a<e.length;a++)s[e[a]]=!0;e=s}for(n in e)e[n]=i(e[n]);var l={};for(n in e){var c=e[n];if(Array.isArray(c))for(a=0;a<c.length;a++){var u=c[a];if(r&&(l[u]=!0),u in t){if(o[n]=t[u],r)for(var h=a;h<c.length;h++)l[c[h]]=!0;break}}else n in t&&(e[n]&&(o[n]=t[n]),r&&(l[n]=!0))}if(r)for(n in t)l[n]||(o[n]=t[n]);return o};var n={};function i(t){return n[t]?n[t]:(\"string\"==typeof t&&(t=n[t]=t.split(/\\s*,\\s*|\\s+/)),t)}},{}],466:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=0|e.length,i=t.length,a=[new Array(r),new Array(r)],o=0;o<r;++o)a[0][o]=[],a[1][o]=[];for(var o=0;o<i;++o){var s=t[o];a[0][s[0]].push(s),a[1][s[1]].push(s)}for(var l=[],o=0;o<r;++o)a[0][o].length+a[1][o].length===0&&l.push([o]);function c(t,e){var r=a[e][t[e]];r.splice(r.indexOf(t),1)}function u(t,r,i){for(var o,s,l,u=0;u<2;++u)if(a[u][r].length>0){o=a[u][r][0],l=u;break}s=o[1^l];for(var h=0;h<2;++h)for(var f=a[h][r],p=0;p<f.length;++p){var d=f[p],g=d[1^h],v=n(e[t],e[r],e[s],e[g]);v>0&&(o=d,s=g,l=h)}return i?s:(o&&c(o,l),s)}function h(t,r){var i=a[r][t][0],o=[t];c(i,r);for(var s=i[1^r];;){for(;s!==t;)o.push(s),s=u(o[o.length-2],s,!1);if(a[0][t].length+a[1][t].length===0)break;var l=o[o.length-1],h=t,f=o[1],p=u(l,h,!0);if(n(e[l],e[h],e[f],e[p])<0)break;o.push(t),s=u(l,h)}return o}function f(t,e){return e[1]===e[e.length-1]}for(var o=0;o<r;++o)for(var p=0;p<2;++p){for(var d=[];a[p][o].length>0;){a[0][o].length;var g=h(o,p);f(d,g)?d.push.apply(d,g):(d.length>0&&l.push(d),d=g)}d.length>0&&l.push(d)}return l};var n=t(\"compare-angle\")},{\"compare-angle\":127}],467:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=n(t,e.length),i=new Array(e.length),a=new Array(e.length),o=[],s=0;s<e.length;++s){var l=r[s].length;a[s]=l,i[s]=!0,l<=1&&o.push(s)}for(;o.length>0;){var c=o.pop();i[c]=!1;for(var u=r[c],s=0;s<u.length;++s){var h=u[s];0==--a[h]&&o.push(h)}}for(var f=new Array(e.length),p=[],s=0;s<e.length;++s)if(i[s]){var c=p.length;f[s]=c,p.push(e[s])}else f[s]=-1;for(var d=[],s=0;s<t.length;++s){var g=t[s];i[g[0]]&&i[g[1]]&&d.push([f[g[0]],f[g[1]]])}return[d,p]};var n=t(\"edges-to-adjacency-list\")},{\"edges-to-adjacency-list\":171}],468:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=c(t,e);t=r[0];for(var h=(e=r[1]).length,f=(t.length,n(t,e.length)),p=0;p<h;++p)if(f[p].length%2==1)throw new Error(\"planar-graph-to-polyline: graph must be manifold\");var d=i(t,e);for(var g=(d=d.filter(function(t){for(var r=t.length,n=[0],i=0;i<r;++i){var a=e[t[i]],l=e[t[(i+1)%r]],c=o(-a[0],a[1]),u=o(-a[0],l[1]),h=o(l[0],a[1]),f=o(l[0],l[1]);n=s(n,s(s(c,u),s(h,f)))}return n[n.length-1]>0})).length,v=new Array(g),m=new Array(g),p=0;p<g;++p){v[p]=p;var y=new Array(g),x=d[p].map(function(t){return e[t]}),b=a([x]),_=0;t:for(var w=0;w<g;++w)if(y[w]=0,p!==w){for(var k=d[w],T=k.length,A=0;A<T;++A){var M=b(e[k[A]]);if(0!==M){M<0&&(y[w]=1,_+=1);continue t}}y[w]=1,_+=1}m[p]=[_,p,y]}m.sort(function(t,e){return e[0]-t[0]});for(var p=0;p<g;++p)for(var y=m[p],S=y[1],E=y[2],w=0;w<g;++w)E[w]&&(v[w]=S);for(var C=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=[];return e}(g),p=0;p<g;++p)C[p].push(v[p]),C[v[p]].push(p);for(var L={},P=u(h,!1),p=0;p<g;++p)for(var k=d[p],T=k.length,w=0;w<T;++w){var O=k[w],z=k[(w+1)%T],I=Math.min(O,z)+\":\"+Math.max(O,z);if(I in L){var D=L[I];C[D].push(p),C[p].push(D),P[O]=P[z]=!0}else L[I]=p}function R(t){for(var e=t.length,r=0;r<e;++r)if(!P[t[r]])return!1;return!0}for(var F=[],B=u(g,-1),p=0;p<g;++p)v[p]!==p||R(d[p])?B[p]=-1:(F.push(p),B[p]=0);var r=[];for(;F.length>0;){var N=F.pop(),j=C[N];l(j,function(t,e){return t-e});var U,V=j.length,q=B[N];if(0===q){var k=d[N];U=[k]}for(var p=0;p<V;++p){var H=j[p];if(!(B[H]>=0)&&(B[H]=1^q,F.push(H),0===q)){var k=d[H];R(k)||(k.reverse(),U.push(k))}}0===q&&r.push(U)}return r};var n=t(\"edges-to-adjacency-list\"),i=t(\"planar-dual\"),a=t(\"point-in-big-polygon\"),o=t(\"two-product\"),s=t(\"robust-sum\"),l=t(\"uniq\"),c=t(\"./lib/trim-leaves\");function u(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}},{\"./lib/trim-leaves\":467,\"edges-to-adjacency-list\":171,\"planar-dual\":466,\"point-in-big-polygon\":472,\"robust-sum\":515,\"two-product\":543,uniq:547}],469:[function(t,e,r){\"use strict\";e.exports=t(\"./quad\")},{\"./quad\":471}],470:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],471:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"clamp\"),a=t(\"parse-rect\"),o=t(\"array-bounds\"),s=t(\"pick-by-alias\"),l=t(\"defined\"),c=t(\"flatten-vertex-data\"),u=t(\"is-obj\"),h=t(\"dtype\"),f=t(\"math-log2\");function p(t,e){for(var r=e[0],n=e[1],a=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=i((t[2*l]-r)*a,0,1),s[2*l+1]=i((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,\"float64\"),e=s(e,{bounds:\"range bounds dataBox databox\",maxDepth:\"depth maxDepth maxdepth level maxLevel maxlevel levels\",dtype:\"type dtype format out dst output destination\"});var r=l(e.maxDepth,255),i=l(e.bounds,o(t,2));i[0]===i[2]&&i[2]++,i[1]===i[3]&&i[3]++;var d,g=p(t,i),v=t.length>>>1;e.dtype||(e.dtype=\"array\"),\"string\"==typeof e.dtype?d=new(h(e.dtype))(v):e.dtype&&(d=e.dtype,Array.isArray(d)&&(d.length=v));for(var m=0;m<v;++m)d[m]=m;var y=[],x=[],b=[],_=[];!function t(e,n,i,a,o,s){if(!a.length)return null;var l=y[o]||(y[o]=[]);var c=b[o]||(b[o]=[]);var u=x[o]||(x[o]=[]);var h=l.length;o++;if(o>r){for(var f=0;f<a.length;f++)l.push(a[f]),c.push(s),u.push(null,null,null,null);return h}l.push(a[0]);c.push(s);if(a.length<=1)return u.push(null,null,null,null),h;var p=.5*i;var d=e+p,v=n+p;var m=[],_=[],w=[],k=[];for(var T=1,A=a.length;T<A;T++){var M=a[T],S=g[2*M],E=g[2*M+1];S<d?E<v?m.push(M):_.push(M):E<v?w.push(M):k.push(M)}s<<=2;u.push(t(e,n,p,m,o,s),t(e,v,p,_,o,s+1),t(d,n,p,w,o,s+2),t(d,v,p,k,o,s+3));return h}(0,0,1,d,0,1);for(var w=0,k=0;k<y.length;k++){var T=y[k];if(d.set)d.set(T,w);else for(var A=0,M=T.length;A<M;A++)d[A+w]=T[A];var S=w+y[k].length;_[k]=[w,S],w=S}return d.range=function(){var e,r=[],o=arguments.length;for(;o--;)r[o]=arguments[o];if(u(r[r.length-1])){var c=r.pop();r.length||null==c.x&&null==c.l&&null==c.left||(r=[c],e={}),e=s(c,{level:\"level maxLevel\",d:\"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize\",lod:\"lod details ranges offsets\"})}else e={};r.length||(r=i);var h=a.apply(void 0,r),d=[Math.min(h.x,h.x+h.width),Math.min(h.y,h.y+h.height),Math.max(h.x,h.x+h.width),Math.max(h.y,h.y+h.height)],g=d[0],v=d[1],m=d[2],w=d[3],k=p([g,v,m,w],i),T=k[0],A=k[1],M=k[2],S=k[3],C=l(e.level,y.length);if(null!=e.d){var L;\"number\"==typeof e.d?L=[e.d,e.d]:e.d.length&&(L=e.d),C=Math.min(Math.max(Math.ceil(-f(Math.abs(L[0])/(i[2]-i[0]))),Math.ceil(-f(Math.abs(L[1])/(i[3]-i[1])))),C)}if(C=Math.min(C,y.length),e.lod)return function(t,e,r,i,a){for(var o=[],s=0;s<a;s++){var l=b[s],c=_[s][0],u=E(t,e,s),h=E(r,i,s),f=n.ge(l,u),p=n.gt(l,h,f,l.length-1);o[s]=[f+c,p+c]}return o}(T,A,M,S,C);var P=[];return function e(r,n,i,a,o,s){if(null!==o&&null!==s){var l=r+i,c=n+i;if(!(T>l||A>c||M<r||S<n||a>=C||o===s)){var u=y[a];void 0===s&&(s=u.length);for(var h=o;h<s;h++){var f=u[h],p=t[2*f],d=t[2*f+1];p>=g&&p<=m&&d>=v&&d<=w&&P.push(f)}var b=x[a],_=b[4*o+0],k=b[4*o+1],E=b[4*o+2],L=b[4*o+3],O=function(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}(b,o+1),z=.5*i,I=a+1;e(r,n,z,I,_,k||E||L||O),e(r,n+z,z,I,k,E||L||O),e(r+z,n,z,I,E,L||O),e(r+z,n+z,z,I,L,O)}}}(0,0,1,0,0,1),P},d;function E(t,e,r){for(var n=1,i=.5,a=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<i?e<a?0:1:e<a?2:3,o*=.5,i+=t<i?-o:o,a+=e<a?-o:o;return n}}},{\"array-bounds\":65,\"binary-search-bounds\":470,clamp:115,defined:164,dtype:169,\"flatten-vertex-data\":227,\"is-obj\":421,\"math-log2\":432,\"parse-rect\":459,\"pick-by-alias\":465}],472:[function(t,e,r){e.exports=function(t){for(var e=t.length,r=[],a=[],s=0;s<e;++s)for(var u=t[s],h=u.length,f=h-1,p=0;p<h;f=p++){var d=u[f],g=u[p];d[0]===g[0]?a.push([d,g]):r.push([d,g])}if(0===r.length)return 0===a.length?c:(v=l(a),function(t){return v(t[0],t[1])?0:1});var v;var m=i(r),y=function(t,e){return function(r){var i=o.le(e,r[0]);if(i<0)return 1;var a=t[i];if(!a){if(!(i>0&&e[i]===r[0]))return 1;a=t[i-1]}for(var s=1;a;){var l=a.key,c=n(r,l[0],l[1]);if(l[0][0]<l[1][0])if(c<0)a=a.left;else{if(!(c>0))return 0;s=-1,a=a.right}else if(c>0)a=a.left;else{if(!(c<0))return 0;s=1,a=a.right}}return s}}(m.slabs,m.coordinates);return 0===a.length?y:function(t,e){return function(r){return t(r[0],r[1])?0:e(r)}}(l(a),y)};var n=t(\"robust-orientation\")[3],i=t(\"slab-decomposition\"),a=t(\"interval-tree-1d\"),o=t(\"binary-search-bounds\");function s(){return!0}function l(t){for(var e={},r=0;r<t.length;++r){var n=t[r],i=n[0][0],o=n[0][1],l=n[1][1],c=[Math.min(o,l),Math.max(o,l)];i in e?e[i].push(c):e[i]=[c]}var u={},h=Object.keys(e);for(r=0;r<h.length;++r){var f=e[h[r]];u[h[r]]=a(f)}return function(t){return function(e,r){var n=t[e];return!!n&&!!n.queryPoint(r,s)}}(u)}function c(t){return 1}},{\"binary-search-bounds\":91,\"interval-tree-1d\":414,\"robust-orientation\":510,\"slab-decomposition\":526}],473:[function(t,e,r){var n,i=t(\"./lib/build-log\"),a=t(\"./lib/epsilon\"),o=t(\"./lib/intersecter\"),s=t(\"./lib/segment-chainer\"),l=t(\"./lib/segment-selector\"),c=t(\"./lib/geojson\"),u=!1,h=a();function f(t,e,r){var i=n.segments(t),a=n.segments(e),o=r(n.combine(i,a));return n.polygon(o)}n={buildLog:function(t){return!0===t?u=i():!1===t&&(u=!1),!1!==u&&u.list},epsilon:function(t){return h.epsilon(t)},segments:function(t){var e=o(!0,h,u);return t.regions.forEach(e.addRegion),{segments:e.calculate(t.inverted),inverted:t.inverted}},combine:function(t,e){return{combined:o(!1,h,u).calculate(t.segments,t.inverted,e.segments,e.inverted),inverted1:t.inverted,inverted2:e.inverted}},selectUnion:function(t){return{segments:l.union(t.combined,u),inverted:t.inverted1||t.inverted2}},selectIntersect:function(t){return{segments:l.intersect(t.combined,u),inverted:t.inverted1&&t.inverted2}},selectDifference:function(t){return{segments:l.difference(t.combined,u),inverted:t.inverted1&&!t.inverted2}},selectDifferenceRev:function(t){return{segments:l.differenceRev(t.combined,u),inverted:!t.inverted1&&t.inverted2}},selectXor:function(t){return{segments:l.xor(t.combined,u),inverted:t.inverted1!==t.inverted2}},polygon:function(t){return{regions:s(t.segments,h,u),inverted:t.inverted}},polygonFromGeoJSON:function(t){return c.toPolygon(n,t)},polygonToGeoJSON:function(t){return c.fromPolygon(n,h,t)},union:function(t,e){return f(t,e,n.selectUnion)},intersect:function(t,e){return f(t,e,n.selectIntersect)},difference:function(t,e){return f(t,e,n.selectDifference)},differenceRev:function(t,e){return f(t,e,n.selectDifferenceRev)},xor:function(t,e){return f(t,e,n.selectXor)}},\"object\"==typeof window&&(window.PolyBool=n),e.exports=n},{\"./lib/build-log\":474,\"./lib/epsilon\":475,\"./lib/geojson\":476,\"./lib/intersecter\":477,\"./lib/segment-chainer\":479,\"./lib/segment-selector\":480}],474:[function(t,e,r){e.exports=function(){var t,e=0,r=!1;function n(e,r){return t.list.push({type:e,data:r?JSON.parse(JSON.stringify(r)):void 0}),t}return t={list:[],segmentId:function(){return e++},checkIntersection:function(t,e){return n(\"check\",{seg1:t,seg2:e})},segmentChop:function(t,e){return n(\"div_seg\",{seg:t,pt:e}),n(\"chop\",{seg:t,pt:e})},statusRemove:function(t){return n(\"pop_seg\",{seg:t})},segmentUpdate:function(t){return n(\"seg_update\",{seg:t})},segmentNew:function(t,e){return n(\"new_seg\",{seg:t,primary:e})},segmentRemove:function(t){return n(\"rem_seg\",{seg:t})},tempStatus:function(t,e,r){return n(\"temp_status\",{seg:t,above:e,below:r})},rewind:function(t){return n(\"rewind\",{seg:t})},status:function(t,e,r){return n(\"status\",{seg:t,above:e,below:r})},vert:function(e){return e===r?t:(r=e,n(\"vert\",{x:e}))},log:function(t){return\"string\"!=typeof t&&(t=JSON.stringify(t,!1,\"  \")),n(\"log\",{txt:t})},reset:function(){return n(\"reset\")},selected:function(t){return n(\"selected\",{segs:t})},chainStart:function(t){return n(\"chain_start\",{seg:t})},chainRemoveHead:function(t,e){return n(\"chain_rem_head\",{index:t,pt:e})},chainRemoveTail:function(t,e){return n(\"chain_rem_tail\",{index:t,pt:e})},chainNew:function(t,e){return n(\"chain_new\",{pt1:t,pt2:e})},chainMatch:function(t){return n(\"chain_match\",{index:t})},chainClose:function(t){return n(\"chain_close\",{index:t})},chainAddHead:function(t,e){return n(\"chain_add_head\",{index:t,pt:e})},chainAddTail:function(t,e){return n(\"chain_add_tail\",{index:t,pt:e})},chainConnect:function(t,e){return n(\"chain_con\",{index1:t,index2:e})},chainReverse:function(t){return n(\"chain_rev\",{index:t})},chainJoin:function(t,e){return n(\"chain_join\",{index1:t,index2:e})},done:function(){return n(\"done\")}}}},{}],475:[function(t,e,r){e.exports=function(t){\"number\"!=typeof t&&(t=1e-10);var e={epsilon:function(e){return\"number\"==typeof e&&(t=e),t},pointAboveOrOnLine:function(e,r,n){var i=r[0],a=r[1],o=n[0],s=n[1],l=e[0];return(o-i)*(e[1]-a)-(s-a)*(l-i)>=-t},pointBetween:function(e,r,n){var i=e[1]-r[1],a=n[0]-r[0],o=e[0]-r[0],s=n[1]-r[1],l=o*a+i*s;return!(l<t||l-(a*a+s*s)>-t)},pointsSameX:function(e,r){return Math.abs(e[0]-r[0])<t},pointsSameY:function(e,r){return Math.abs(e[1]-r[1])<t},pointsSame:function(t,r){return e.pointsSameX(t,r)&&e.pointsSameY(t,r)},pointsCompare:function(t,r){return e.pointsSameX(t,r)?e.pointsSameY(t,r)?0:t[1]<r[1]?-1:1:t[0]<r[0]?-1:1},pointsCollinear:function(e,r,n){var i=e[0]-r[0],a=e[1]-r[1],o=r[0]-n[0],s=r[1]-n[1];return Math.abs(i*s-o*a)<t},linesIntersect:function(e,r,n,i){var a=r[0]-e[0],o=r[1]-e[1],s=i[0]-n[0],l=i[1]-n[1],c=a*l-o*s;if(Math.abs(c)<t)return!1;var u=e[0]-n[0],h=e[1]-n[1],f=(s*h-l*u)/c,p=(a*h-o*u)/c,d={alongA:0,alongB:0,pt:[e[0]+f*a,e[1]+f*o]};return d.alongA=f<=-t?-2:f<t?-1:f-1<=-t?0:f-1<t?1:2,d.alongB=p<=-t?-2:p<t?-1:p-1<=-t?0:p-1<t?1:2,d},pointInsideRegion:function(e,r){for(var n=e[0],i=e[1],a=r[r.length-1][0],o=r[r.length-1][1],s=!1,l=0;l<r.length;l++){var c=r[l][0],u=r[l][1];u-i>t!=o-i>t&&(a-c)*(i-u)/(o-u)+c-n>t&&(s=!s),a=c,o=u}return s}};return e}},{}],476:[function(t,e,r){var n={toPolygon:function(t,e){function r(e){if(e.length<=0)return t.segments({inverted:!1,regions:[]});function r(e){var r=e.slice(0,e.length-1);return t.segments({inverted:!1,regions:[r]})}for(var n=r(e[0]),i=1;i<e.length;i++)n=t.selectDifference(t.combine(n,r(e[i])));return n}if(\"Polygon\"===e.type)return t.polygon(r(e.coordinates));if(\"MultiPolygon\"===e.type){for(var n=t.segments({inverted:!1,regions:[]}),i=0;i<e.coordinates.length;i++)n=t.selectUnion(t.combine(n,r(e.coordinates[i])));return t.polygon(n)}throw new Error(\"PolyBool: Cannot convert GeoJSON object to PolyBool polygon\")},fromPolygon:function(t,e,r){function n(t,r){return e.pointInsideRegion([.5*(t[0][0]+t[1][0]),.5*(t[0][1]+t[1][1])],r)}function i(t){return{region:t,children:[]}}r=t.polygon(t.segments(r));var a=i(null);function o(t,e){for(var r=0;r<t.children.length;r++){if(n(e,(s=t.children[r]).region))return void o(s,e)}var a=i(e);for(r=0;r<t.children.length;r++){var s;n((s=t.children[r]).region,e)&&(a.children.push(s),t.children.splice(r,1),r--)}t.children.push(a)}for(var s=0;s<r.regions.length;s++){var l=r.regions[s];l.length<3||o(a,l)}function c(t,e){for(var r=0,n=t[t.length-1][0],i=t[t.length-1][1],a=[],o=0;o<t.length;o++){var s=t[o][0],l=t[o][1];a.push([s,l]),r+=l*n-s*i,n=s,i=l}return r<0!==e&&a.reverse(),a.push([a[0][0],a[0][1]]),a}var u=[];function h(t){var e=[c(t.region,!1)];u.push(e);for(var r=0;r<t.children.length;r++)e.push(f(t.children[r]))}function f(t){for(var e=0;e<t.children.length;e++)h(t.children[e]);return c(t.region,!0)}for(s=0;s<a.children.length;s++)h(a.children[s]);return u.length<=0?{type:\"Polygon\",coordinates:[]}:1==u.length?{type:\"Polygon\",coordinates:u[0]}:{type:\"MultiPolygon\",coordinates:u}}};e.exports=n},{}],477:[function(t,e,r){var n=t(\"./linked-list\");e.exports=function(t,e,r){function i(t,e,n){return{id:r?r.segmentId():-1,start:t,end:e,myFill:{above:n.myFill.above,below:n.myFill.below},otherFill:null}}var a=n.create();function o(t,r){a.insertBefore(t,function(n){return function(t,r,n,i,a,o){var s=e.pointsCompare(r,a);return 0!==s?s:e.pointsSame(n,o)?0:t!==i?t?1:-1:e.pointAboveOrOnLine(n,i?a:o,i?o:a)?1:-1}(t.isStart,t.pt,r,n.isStart,n.pt,n.other.pt)<0})}function s(t,e){var r=function(t,e){var r=n.node({isStart:!0,pt:t.start,seg:t,primary:e,other:null,status:null});return o(r,t.end),r}(t,e);return function(t,e,r){var i=n.node({isStart:!1,pt:e.end,seg:e,primary:r,other:t,status:null});t.other=i,o(i,t.pt)}(r,t,e),r}function l(t,e){var n=i(e,t.seg.end,t.seg);return function(t,e){r&&r.segmentChop(t.seg,e),t.other.remove(),t.seg.end=e,t.other.pt=e,o(t.other,t.pt)}(t,e),s(n,t.primary)}function c(i,o){var s=n.create();function c(t){return s.findTransition(function(r){var n,i,a,o,s,l;return n=t,i=r.ev,a=n.seg.start,o=n.seg.end,s=i.seg.start,l=i.seg.end,(e.pointsCollinear(a,s,l)?e.pointsCollinear(o,s,l)?1:e.pointAboveOrOnLine(o,s,l)?1:-1:e.pointAboveOrOnLine(a,s,l)?1:-1)>0})}function u(t,n){var i=t.seg,a=n.seg,o=i.start,s=i.end,c=a.start,u=a.end;r&&r.checkIntersection(i,a);var h=e.linesIntersect(o,s,c,u);if(!1===h){if(!e.pointsCollinear(o,s,c))return!1;if(e.pointsSame(o,u)||e.pointsSame(s,c))return!1;var f=e.pointsSame(o,c),p=e.pointsSame(s,u);if(f&&p)return n;var d=!f&&e.pointBetween(o,c,u),g=!p&&e.pointBetween(s,c,u);if(f)return g?l(n,s):l(t,u),n;d&&(p||(g?l(n,s):l(t,u)),l(n,o))}else 0===h.alongA&&(-1===h.alongB?l(t,c):0===h.alongB?l(t,h.pt):1===h.alongB&&l(t,u)),0===h.alongB&&(-1===h.alongA?l(n,o):0===h.alongA?l(n,h.pt):1===h.alongA&&l(n,s));return!1}for(var h=[];!a.isEmpty();){var f=a.getHead();if(r&&r.vert(f.pt[0]),f.isStart){r&&r.segmentNew(f.seg,f.primary);var p=c(f),d=p.before?p.before.ev:null,g=p.after?p.after.ev:null;function v(){if(d){var t=u(f,d);if(t)return t}return!!g&&u(f,g)}r&&r.tempStatus(f.seg,!!d&&d.seg,!!g&&g.seg);var m,y,x=v();if(x)t?(y=null===f.seg.myFill.below||f.seg.myFill.above!==f.seg.myFill.below)&&(x.seg.myFill.above=!x.seg.myFill.above):x.seg.otherFill=f.seg.myFill,r&&r.segmentUpdate(x.seg),f.other.remove(),f.remove();if(a.getHead()!==f){r&&r.rewind(f.seg);continue}t?(y=null===f.seg.myFill.below||f.seg.myFill.above!==f.seg.myFill.below,f.seg.myFill.below=g?g.seg.myFill.above:i,f.seg.myFill.above=y?!f.seg.myFill.below:f.seg.myFill.below):null===f.seg.otherFill&&(m=g?f.primary===g.primary?g.seg.otherFill.above:g.seg.myFill.above:f.primary?o:i,f.seg.otherFill={above:m,below:m}),r&&r.status(f.seg,!!d&&d.seg,!!g&&g.seg),f.other.status=p.insert(n.node({ev:f}))}else{var b=f.status;if(null===b)throw new Error(\"PolyBool: Zero-length segment detected; your epsilon is probably too small or too large\");if(s.exists(b.prev)&&s.exists(b.next)&&u(b.prev.ev,b.next.ev),r&&r.statusRemove(b.ev.seg),b.remove(),!f.primary){var _=f.seg.myFill;f.seg.myFill=f.seg.otherFill,f.seg.otherFill=_}h.push(f.seg)}a.getHead().remove()}return r&&r.done(),h}return t?{addRegion:function(t){for(var n,i,a,o=t[t.length-1],l=0;l<t.length;l++){n=o,o=t[l];var c=e.pointsCompare(n,o);0!==c&&s((i=c<0?n:o,a=c<0?o:n,{id:r?r.segmentId():-1,start:i,end:a,myFill:{above:null,below:null},otherFill:null}),!0)}},calculate:function(t){return c(t,!1)}}:{calculate:function(t,e,r,n){return t.forEach(function(t){s(i(t.start,t.end,t),!0)}),r.forEach(function(t){s(i(t.start,t.end,t),!1)}),c(e,n)}}}},{\"./linked-list\":478}],478:[function(t,e,r){e.exports={create:function(){var t={root:{root:!0,next:null},exists:function(e){return null!==e&&e!==t.root},isEmpty:function(){return null===t.root.next},getHead:function(){return t.root.next},insertBefore:function(e,r){for(var n=t.root,i=t.root.next;null!==i;){if(r(i))return e.prev=i.prev,e.next=i,i.prev.next=e,void(i.prev=e);n=i,i=i.next}n.next=e,e.prev=n,e.next=null},findTransition:function(e){for(var r=t.root,n=t.root.next;null!==n&&!e(n);)r=n,n=n.next;return{before:r===t.root?null:r,after:n,insert:function(t){return t.prev=r,t.next=n,r.next=t,null!==n&&(n.prev=t),t}}}};return t},node:function(t){return t.prev=null,t.next=null,t.remove=function(){t.prev.next=t.next,t.next&&(t.next.prev=t.prev),t.prev=null,t.next=null},t}}},{}],479:[function(t,e,r){e.exports=function(t,e,r){var n=[],i=[];return t.forEach(function(t){var a=t.start,o=t.end;if(e.pointsSame(a,o))console.warn(\"PolyBool: Warning: Zero-length segment detected; your epsilon is probably too small or too large\");else{r&&r.chainStart(t);for(var s={index:0,matches_head:!1,matches_pt1:!1},l={index:0,matches_head:!1,matches_pt1:!1},c=s,u=0;u<n.length;u++){var h=(v=n[u])[0],f=(v[1],v[v.length-1]);if(v[v.length-2],e.pointsSame(h,a)){if(T(u,!0,!0))break}else if(e.pointsSame(h,o)){if(T(u,!0,!1))break}else if(e.pointsSame(f,a)){if(T(u,!1,!0))break}else if(e.pointsSame(f,o)&&T(u,!1,!1))break}if(c===s)return n.push([a,o]),void(r&&r.chainNew(a,o));if(c===l){r&&r.chainMatch(s.index);var p=s.index,d=s.matches_pt1?o:a,g=s.matches_head,v=n[p],m=g?v[0]:v[v.length-1],y=g?v[1]:v[v.length-2],x=g?v[v.length-1]:v[0],b=g?v[v.length-2]:v[1];return e.pointsCollinear(y,m,d)&&(g?(r&&r.chainRemoveHead(s.index,d),v.shift()):(r&&r.chainRemoveTail(s.index,d),v.pop()),m=y),e.pointsSame(x,d)?(n.splice(p,1),e.pointsCollinear(b,x,m)&&(g?(r&&r.chainRemoveTail(s.index,m),v.pop()):(r&&r.chainRemoveHead(s.index,m),v.shift())),r&&r.chainClose(s.index),void i.push(v)):void(g?(r&&r.chainAddHead(s.index,d),v.unshift(d)):(r&&r.chainAddTail(s.index,d),v.push(d)))}var _=s.index,w=l.index;r&&r.chainConnect(_,w);var k=n[_].length<n[w].length;s.matches_head?l.matches_head?k?(A(_),M(_,w)):(A(w),M(w,_)):M(w,_):l.matches_head?M(_,w):k?(A(_),M(w,_)):(A(w),M(_,w))}function T(t,e,r){return c.index=t,c.matches_head=e,c.matches_pt1=r,c===s?(c=l,!1):(c=null,!0)}function A(t){r&&r.chainReverse(t),n[t].reverse()}function M(t,i){var a=n[t],o=n[i],s=a[a.length-1],l=a[a.length-2],c=o[0],u=o[1];e.pointsCollinear(l,s,c)&&(r&&r.chainRemoveTail(t,s),a.pop(),s=l),e.pointsCollinear(s,c,u)&&(r&&r.chainRemoveHead(i,c),o.shift()),r&&r.chainJoin(t,i),n[t]=a.concat(o),n.splice(i,1)}}),i}},{}],480:[function(t,e,r){function n(t,e,r){var n=[];return t.forEach(function(t){var i=(t.myFill.above?8:0)+(t.myFill.below?4:0)+(t.otherFill&&t.otherFill.above?2:0)+(t.otherFill&&t.otherFill.below?1:0);0!==e[i]&&n.push({id:r?r.segmentId():-1,start:t.start,end:t.end,myFill:{above:1===e[i],below:2===e[i]},otherFill:null})}),r&&r.selected(n),n}var i={union:function(t,e){return n(t,[0,2,1,0,2,2,0,0,1,0,1,0,0,0,0,0],e)},intersect:function(t,e){return n(t,[0,0,0,0,0,2,0,2,0,0,1,1,0,2,1,0],e)},difference:function(t,e){return n(t,[0,0,0,0,2,0,2,0,1,1,0,0,0,1,2,0],e)},differenceRev:function(t,e){return n(t,[0,2,1,0,0,0,1,1,0,2,0,2,0,0,0,0],e)},xor:function(t,e){return n(t,[0,2,1,0,2,0,0,1,1,0,0,2,0,1,2,0],e)}};e.exports=i},{}],481:[function(t,e,r){\"use strict\";var n=new Float64Array(4),i=new Float64Array(4),a=new Float64Array(4);e.exports=function(t,e,r,o,s){n.length<o.length&&(n=new Float64Array(o.length),i=new Float64Array(o.length),a=new Float64Array(o.length));for(var l=0;l<o.length;++l)n[l]=t[l]-o[l],i[l]=e[l]-t[l],a[l]=r[l]-t[l];var c=0,u=0,h=0,f=0,p=0,d=0;for(l=0;l<o.length;++l){var g=i[l],v=a[l],m=n[l];c+=g*g,u+=g*v,h+=v*v,f+=m*g,p+=m*v,d+=m*m}var y,x,b,_,w,k=Math.abs(c*h-u*u),T=u*p-h*f,A=u*f-c*p;if(T+A<=k)if(T<0)A<0&&f<0?(A=0,-f>=c?(T=1,y=c+2*f+d):y=f*(T=-f/c)+d):(T=0,p>=0?(A=0,y=d):-p>=h?(A=1,y=h+2*p+d):y=p*(A=-p/h)+d);else if(A<0)A=0,f>=0?(T=0,y=d):-f>=c?(T=1,y=c+2*f+d):y=f*(T=-f/c)+d;else{var M=1/k;y=(T*=M)*(c*T+u*(A*=M)+2*f)+A*(u*T+h*A+2*p)+d}else T<0?(b=h+p)>(x=u+f)?(_=b-x)>=(w=c-2*u+h)?(T=1,A=0,y=c+2*f+d):y=(T=_/w)*(c*T+u*(A=1-T)+2*f)+A*(u*T+h*A+2*p)+d:(T=0,b<=0?(A=1,y=h+2*p+d):p>=0?(A=0,y=d):y=p*(A=-p/h)+d):A<0?(b=c+f)>(x=u+p)?(_=b-x)>=(w=c-2*u+h)?(A=1,T=0,y=h+2*p+d):y=(T=1-(A=_/w))*(c*T+u*A+2*f)+A*(u*T+h*A+2*p)+d:(A=0,b<=0?(T=1,y=c+2*f+d):f>=0?(T=0,y=d):y=f*(T=-f/c)+d):(_=h+p-u-f)<=0?(T=0,A=1,y=h+2*p+d):_>=(w=c-2*u+h)?(T=1,A=0,y=c+2*f+d):y=(T=_/w)*(c*T+u*(A=1-T)+2*f)+A*(u*T+h*A+2*p)+d;var S=1-T-A;for(l=0;l<o.length;++l)s[l]=S*t[l]+T*e[l]+A*r[l];return y<0?0:y}},{}],482:[function(t,e,r){var n,i,a=e.exports={};function o(){throw new Error(\"setTimeout has not been defined\")}function s(){throw new Error(\"clearTimeout has not been defined\")}function l(t){if(n===setTimeout)return setTimeout(t,0);if((n===o||!n)&&setTimeout)return n=setTimeout,setTimeout(t,0);try{return n(t,0)}catch(e){try{return n.call(null,t,0)}catch(e){return n.call(this,t,0)}}}!function(){try{n=\"function\"==typeof setTimeout?setTimeout:o}catch(t){n=o}try{i=\"function\"==typeof clearTimeout?clearTimeout:s}catch(t){i=s}}();var c,u=[],h=!1,f=-1;function p(){h&&c&&(h=!1,c.length?u=c.concat(u):f=-1,u.length&&d())}function d(){if(!h){var t=l(p);h=!0;for(var e=u.length;e;){for(c=u,u=[];++f<e;)c&&c[f].run();f=-1,e=u.length}c=null,h=!1,function(t){if(i===clearTimeout)return clearTimeout(t);if((i===s||!i)&&clearTimeout)return i=clearTimeout,clearTimeout(t);try{i(t)}catch(e){try{return i.call(null,t)}catch(e){return i.call(this,t)}}}(t)}}function g(t,e){this.fun=t,this.array=e}function v(){}a.nextTick=function(t){var e=new Array(arguments.length-1);if(arguments.length>1)for(var r=1;r<arguments.length;r++)e[r-1]=arguments[r];u.push(new g(t,e)),1!==u.length||h||l(d)},g.prototype.run=function(){this.fun.apply(null,this.array)},a.title=\"browser\",a.browser=!0,a.env={},a.argv=[],a.version=\"\",a.versions={},a.on=v,a.addListener=v,a.once=v,a.off=v,a.removeListener=v,a.removeAllListeners=v,a.emit=v,a.prependListener=v,a.prependOnceListener=v,a.listeners=function(t){return[]},a.binding=function(t){throw new Error(\"process.binding is not supported\")},a.cwd=function(){return\"/\"},a.chdir=function(t){throw new Error(\"process.chdir is not supported\")},a.umask=function(){return 0}},{}],483:[function(t,e,r){e.exports=t(\"gl-quat/slerp\")},{\"gl-quat/slerp\":293}],484:[function(t,e,r){(function(r){for(var n=t(\"performance-now\"),i=\"undefined\"==typeof window?r:window,a=[\"moz\",\"webkit\"],o=\"AnimationFrame\",s=i[\"request\"+o],l=i[\"cancel\"+o]||i[\"cancelRequest\"+o],c=0;!s&&c<a.length;c++)s=i[a[c]+\"Request\"+o],l=i[a[c]+\"Cancel\"+o]||i[a[c]+\"CancelRequest\"+o];if(!s||!l){var u=0,h=0,f=[];s=function(t){if(0===f.length){var e=n(),r=Math.max(0,1e3/60-(e-u));u=r+e,setTimeout(function(){var t=f.slice(0);f.length=0;for(var e=0;e<t.length;e++)if(!t[e].cancelled)try{t[e].callback(u)}catch(t){setTimeout(function(){throw t},0)}},Math.round(r))}return f.push({handle:++h,callback:t,cancelled:!1}),h},l=function(t){for(var e=0;e<f.length;e++)f[e].handle===t&&(f[e].cancelled=!0)}}e.exports=function(t){return s.call(i,t)},e.exports.cancel=function(){l.apply(i,arguments)},e.exports.polyfill=function(t){t||(t=i),t.requestAnimationFrame=s,t.cancelAnimationFrame=l}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"performance-now\":462}],485:[function(t,e,r){\"use strict\";var n=t(\"big-rat/add\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/add\":75}],486:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t.length),r=0;r<t.length;++r)e[r]=n(t[r]);return e};var n=t(\"big-rat\")},{\"big-rat\":78}],487:[function(t,e,r){\"use strict\";var n=t(\"big-rat\"),i=t(\"big-rat/mul\");e.exports=function(t,e){for(var r=n(e),a=t.length,o=new Array(a),s=0;s<a;++s)o[s]=i(t[s],r);return o}},{\"big-rat\":78,\"big-rat/mul\":87}],488:[function(t,e,r){\"use strict\";var n=t(\"big-rat/sub\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/sub\":89}],489:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"compare-oriented-cell\"),a=t(\"cell-orientation\");e.exports=function(t){t.sort(i);for(var e=t.length,r=0,o=0;o<e;++o){var s=t[o],l=a(s);if(0!==l){if(r>0){var c=t[r-1];if(0===n(s,c)&&a(c)!==l){r-=1;continue}}t[r++]=s}}return t.length=r,t}},{\"cell-orientation\":112,\"compare-cell\":128,\"compare-oriented-cell\":129}],490:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\"),i=t(\"color-normalize\"),a=t(\"update-diff\"),o=t(\"pick-by-alias\"),s=t(\"object-assign\"),l=t(\"flatten-vertex-data\"),c=t(\"to-float32\"),u=c.float32,h=c.fract32;e.exports=function(t,e){\"function\"==typeof t?(e||(e={}),e.regl=t):e=t;e.length&&(e.positions=e);if(!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");var r,c,p,d,g,v,m=t._gl,y={color:\"black\",capSize:5,lineWidth:1,opacity:1,viewport:null,range:null,offset:0,count:0,bounds:null,positions:[],errors:[]},x=[];return d=t.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array(0)}),c=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),p=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),g=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),v=t.buffer({usage:\"static\",type:\"float\",data:f}),k(e),r=t({vert:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tattribute vec2 position, positionFract;\\n\\t\\tattribute vec4 error;\\n\\t\\tattribute vec4 color;\\n\\n\\t\\tattribute vec2 direction, lineOffset, capOffset;\\n\\n\\t\\tuniform vec4 viewport;\\n\\t\\tuniform float lineWidth, capSize;\\n\\t\\tuniform vec2 scale, scaleFract, translate, translateFract;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tfragColor = color / 255.;\\n\\n\\t\\t\\tvec2 pixelOffset = lineWidth * lineOffset + (capSize + lineWidth) * capOffset;\\n\\n\\t\\t\\tvec2 dxy = -step(.5, direction.xy) * error.xz + step(direction.xy, vec2(-.5)) * error.yw;\\n\\n\\t\\t\\tvec2 position = position + dxy;\\n\\n\\t\\t\\tvec2 pos = (position + translate) * scale\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scale\\n\\t\\t\\t\\t+ (position + translate) * scaleFract\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scaleFract;\\n\\n\\t\\t\\tpos += pixelOffset / viewport.zw;\\n\\n\\t\\t\\tgl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\t\\t}\\n\\t\\t\",frag:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tuniform float opacity;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tgl_FragColor = fragColor;\\n\\t\\t\\tgl_FragColor.a *= opacity;\\n\\t\\t}\\n\\t\\t\",uniforms:{range:t.prop(\"range\"),lineWidth:t.prop(\"lineWidth\"),capSize:t.prop(\"capSize\"),opacity:t.prop(\"opacity\"),scale:t.prop(\"scale\"),translate:t.prop(\"translate\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{color:{buffer:d,offset:function(t,e){return 4*e.offset},divisor:1},position:{buffer:c,offset:function(t,e){return 8*e.offset},divisor:1},positionFract:{buffer:p,offset:function(t,e){return 8*e.offset},divisor:1},error:{buffer:g,offset:function(t,e){return 16*e.offset},divisor:1},direction:{buffer:v,stride:24,offset:0},lineOffset:{buffer:v,stride:24,offset:8},capOffset:{buffer:v,stride:24,offset:16}},primitive:\"triangles\",blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:!1,instances:t.prop(\"count\"),count:f.length}),s(b,{update:k,draw:_,destroy:T,regl:t,gl:m,canvas:m.canvas,groups:x}),b;function b(t){t?k(t):null===t&&T(),_()}function _(e){if(\"number\"==typeof e)return w(e);e&&!Array.isArray(e)&&(e=[e]),t._refresh(),x.forEach(function(t,r){t&&(e&&(e[r]?t.draw=!0:t.draw=!1),t.draw?w(r):t.draw=!0)})}function w(t){\"number\"==typeof t&&(t=x[t]),null!=t&&t&&t.count&&t.color&&t.opacity&&t.positions&&t.positions.length>1&&(t.scaleRatio=[t.scale[0]*t.viewport.width,t.scale[1]*t.viewport.height],r(t),t.after&&t.after(t))}function k(t){if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var e=0,r=0;if(b.groups=x=t.map(function(t,c){var u=x[c];return t?(\"function\"==typeof t?t={after:t}:\"number\"==typeof t[0]&&(t={positions:t}),t=o(t,{color:\"color colors fill\",capSize:\"capSize cap capsize cap-size\",lineWidth:\"lineWidth line-width width line thickness\",opacity:\"opacity alpha\",range:\"range dataBox\",viewport:\"viewport viewBox\",errors:\"errors error\",positions:\"positions position data points\"}),u||(x[c]=u={id:c,scale:null,translate:null,scaleFract:null,translateFract:null,draw:!0},t=s({},y,t)),a(u,t,[{lineWidth:function(t){return.5*+t},capSize:function(t){return.5*+t},opacity:parseFloat,errors:function(t){return t=l(t),r+=t.length,t},positions:function(t,r){return t=l(t,\"float64\"),r.count=Math.floor(t.length/2),r.bounds=n(t,2),r.offset=e,e+=r.count,t}},{color:function(t,e){var r=e.count;if(t||(t=\"transparent\"),!Array.isArray(t)||\"number\"==typeof t[0]){var n=t;t=Array(r);for(var a=0;a<r;a++)t[a]=n}if(t.length<r)throw Error(\"Not enough colors\");for(var o=new Uint8Array(4*r),s=0;s<r;s++){var l=i(t[s],\"uint8\");o.set(l,4*s)}return o},range:function(t,e,r){var n=e.bounds;return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=h(e.scale),e.translateFract=h(e.translate),t},viewport:function(t){var e;return Array.isArray(t)?e={x:t[0],y:t[1],width:t[2]-t[0],height:t[3]-t[1]}:t?(e={x:t.x||t.left||0,y:t.y||t.top||0},t.right?e.width=t.right-e.x:e.width=t.w||t.width||0,t.bottom?e.height=t.bottom-e.y:e.height=t.h||t.height||0):e={x:0,y:0,width:m.drawingBufferWidth,height:m.drawingBufferHeight},e}}]),u):u}),e||r){var f=x.reduce(function(t,e,r){return t+(e?e.count:0)},0),v=new Float64Array(2*f),_=new Uint8Array(4*f),w=new Float32Array(4*f);x.forEach(function(t,e){if(t){var r=t.positions,n=t.count,i=t.offset,a=t.color,o=t.errors;n&&(_.set(a,4*i),w.set(o,4*i),v.set(r,2*i))}}),c(u(v)),p(h(v)),d(_),g(w)}}}function T(){c.destroy(),p.destroy(),d.destroy(),g.destroy(),v.destroy()}};var f=[[1,0,0,1,0,0],[1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,1,0,0],[1,0,0,1,0,0],[1,0,-1,0,0,1],[1,0,-1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,1],[1,0,-1,0,0,1],[-1,0,-1,0,0,1],[-1,0,-1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,1],[-1,0,-1,0,0,1],[0,1,1,0,0,0],[0,1,-1,0,0,0],[0,-1,-1,0,0,0],[0,-1,-1,0,0,0],[0,1,1,0,0,0],[0,-1,1,0,0,0],[0,1,0,-1,1,0],[0,1,0,-1,-1,0],[0,1,0,1,-1,0],[0,1,0,1,1,0],[0,1,0,-1,1,0],[0,1,0,1,-1,0],[0,-1,0,-1,1,0],[0,-1,0,-1,-1,0],[0,-1,0,1,-1,0],[0,-1,0,1,1,0],[0,-1,0,-1,1,0],[0,-1,0,1,-1,0]]},{\"array-bounds\":65,\"color-normalize\":120,\"flatten-vertex-data\":227,\"object-assign\":454,\"pick-by-alias\":465,\"to-float32\":538,\"update-diff\":549}],491:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\"),i=t(\"array-bounds\"),a=t(\"object-assign\"),o=t(\"glslify\"),s=t(\"pick-by-alias\"),l=t(\"flatten-vertex-data\"),c=t(\"earcut\"),u=t(\"array-normalize\"),h=t(\"to-float32\"),f=h.float32,p=h.fract32,d=t(\"es6-weak-map\"),g=t(\"parse-rect\");function v(t,e){if(!(this instanceof v))return new v(t,e);if(\"function\"==typeof t?(e||(e={}),e.regl=t):e=t,e.length&&(e.positions=e),!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");this.gl=t._gl,this.regl=t,this.passes=[],this.shaders=v.shaders.has(t)?v.shaders.get(t):v.shaders.set(t,v.createShaders(t)).get(t),this.update(e)}e.exports=v,v.dashMult=2,v.maxPatternLength=256,v.precisionThreshold=3e6,v.maxPoints=1e4,v.maxLines=2048,v.shaders=new d,v.createShaders=function(t){var e,r=t.buffer({usage:\"static\",type:\"float\",data:[0,1,0,0,1,1,1,0]}),n={primitive:\"triangle strip\",instances:t.prop(\"count\"),count:4,offset:0,uniforms:{miterMode:function(t,e){return\"round\"===e.join?2:1},miterLimit:t.prop(\"miterLimit\"),scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),thickness:t.prop(\"thickness\"),dashPattern:t.prop(\"dashTexture\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),dashSize:t.prop(\"dashLength\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]},depth:t.prop(\"depth\")},blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:function(t,e){return!e.overlay}},stencil:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\")},i=t(a({vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, aCoordFract, bCoordFract;\\nattribute vec4 color;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvec2 project(vec2 position, vec2 positionFract, vec2 scale, vec2 scaleFract, vec2 translate, vec2 translateFract) {\\n\\t// the order is important\\n\\treturn position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n}\\n\\nvoid main() {\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineOffset = lineTop * 2. - 1.;\\n\\n\\tvec2 diff = (bCoord + bCoordFract - aCoord - aCoordFract);\\n\\ttangent = normalize(diff * scale * viewport.zw);\\n\\tvec2 normal = vec2(-tangent.y, tangent.x);\\n\\n\\tvec2 position = project(aCoord, aCoordFract, scale, scaleFract, translate, translateFract) * lineStart\\n\\t\\t+ project(bCoord, bCoordFract, scale, scaleFract, translate, translateFract) * lineEnd\\n\\n\\t\\t+ thickness * normal * .5 * lineOffset / viewport.zw;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\n\\nuniform float dashSize, pixelRatio, thickness, opacity, id;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvoid main() {\\n\\tfloat alpha = 1.;\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},aCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8,divisor:1},bCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:16,divisor:1},color:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1}}},n));try{e=t(a({cull:{enable:!0,face:\"back\"},vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, nextCoord, prevCoord;\\nattribute vec4 aColor, bColor;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, translate;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\nuniform float miterLimit, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 tangent;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nconst float REVERSE_THRESHOLD = -.875;\\nconst float MIN_DIFF = 1e-6;\\n\\n// TODO: possible optimizations: avoid overcalculating all for vertices and calc just one instead\\n// TODO: precalculate dot products, normalize things beforehead etc.\\n// TODO: refactor to rectangular algorithm\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nbool isNaN( float val ){\\n  return ( val < 0.0 || 0.0 < val || val == 0.0 ) ? false : true;\\n}\\n\\nvoid main() {\\n\\tvec2 aCoord = aCoord, bCoord = bCoord, prevCoord = prevCoord, nextCoord = nextCoord;\\n\\n  vec2 adjustedScale;\\n  adjustedScale.x = (abs(scale.x) < MIN_DIFF) ? MIN_DIFF : scale.x;\\n  adjustedScale.y = (abs(scale.y) < MIN_DIFF) ? MIN_DIFF : scale.y;\\n\\n  vec2 scaleRatio = adjustedScale * viewport.zw;\\n\\tvec2 normalWidth = thickness / scaleRatio;\\n\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineBot = 1. - lineTop;\\n\\n\\tfragColor = (lineStart * aColor + lineEnd * bColor) / 255.;\\n\\n\\tif (isNaN(aCoord.x) || isNaN(aCoord.y) || isNaN(bCoord.x) || isNaN(bCoord.y)) return;\\n\\n\\tif (aCoord == prevCoord) prevCoord = aCoord + normalize(bCoord - aCoord);\\n\\tif (bCoord == nextCoord) nextCoord = bCoord - normalize(bCoord - aCoord);\\n\\n\\tvec2 prevDiff = aCoord - prevCoord;\\n\\tvec2 currDiff = bCoord - aCoord;\\n\\tvec2 nextDiff = nextCoord - bCoord;\\n\\n\\tvec2 prevTangent = normalize(prevDiff * scaleRatio);\\n\\tvec2 currTangent = normalize(currDiff * scaleRatio);\\n\\tvec2 nextTangent = normalize(nextDiff * scaleRatio);\\n\\n\\tvec2 prevNormal = vec2(-prevTangent.y, prevTangent.x);\\n\\tvec2 currNormal = vec2(-currTangent.y, currTangent.x);\\n\\tvec2 nextNormal = vec2(-nextTangent.y, nextTangent.x);\\n\\n\\tvec2 startJoinDirection = normalize(prevTangent - currTangent);\\n\\tvec2 endJoinDirection = normalize(currTangent - nextTangent);\\n\\n\\t// collapsed/unidirectional segment cases\\n\\t// FIXME: there should be more elegant solution\\n\\tvec2 prevTanDiff = abs(prevTangent - currTangent);\\n\\tvec2 nextTanDiff = abs(nextTangent - currTangent);\\n\\tif (max(prevTanDiff.x, prevTanDiff.y) < MIN_DIFF) {\\n\\t\\tstartJoinDirection = currNormal;\\n\\t}\\n\\tif (max(nextTanDiff.x, nextTanDiff.y) < MIN_DIFF) {\\n\\t\\tendJoinDirection = currNormal;\\n\\t}\\n\\tif (aCoord == bCoord) {\\n\\t\\tendJoinDirection = startJoinDirection;\\n\\t\\tcurrNormal = prevNormal;\\n\\t\\tcurrTangent = prevTangent;\\n\\t}\\n\\n\\ttangent = currTangent;\\n\\n\\t//calculate join shifts relative to normals\\n\\tfloat startJoinShift = dot(currNormal, startJoinDirection);\\n\\tfloat endJoinShift = dot(currNormal, endJoinDirection);\\n\\n\\tfloat startMiterRatio = abs(1. / startJoinShift);\\n\\tfloat endMiterRatio = abs(1. / endJoinShift);\\n\\n\\tvec2 startJoin = startJoinDirection * startMiterRatio;\\n\\tvec2 endJoin = endJoinDirection * endMiterRatio;\\n\\n\\tvec2 startTopJoin, startBotJoin, endTopJoin, endBotJoin;\\n\\tstartTopJoin = sign(startJoinShift) * startJoin * .5;\\n\\tstartBotJoin = -startTopJoin;\\n\\n\\tendTopJoin = sign(endJoinShift) * endJoin * .5;\\n\\tendBotJoin = -endTopJoin;\\n\\n\\tvec2 aTopCoord = aCoord + normalWidth * startTopJoin;\\n\\tvec2 bTopCoord = bCoord + normalWidth * endTopJoin;\\n\\tvec2 aBotCoord = aCoord + normalWidth * startBotJoin;\\n\\tvec2 bBotCoord = bCoord + normalWidth * endBotJoin;\\n\\n\\t//miter anti-clipping\\n\\tfloat baClipping = distToLine(bCoord, aCoord, aBotCoord) / dot(normalize(normalWidth * endBotJoin), normalize(normalWidth.yx * vec2(-startBotJoin.y, startBotJoin.x)));\\n\\tfloat abClipping = distToLine(aCoord, bCoord, bTopCoord) / dot(normalize(normalWidth * startBotJoin), normalize(normalWidth.yx * vec2(-endBotJoin.y, endBotJoin.x)));\\n\\n\\t//prevent close to reverse direction switch\\n\\tbool prevReverse = dot(currTangent, prevTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, prevNormal)) * min(length(prevDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\tbool nextReverse = dot(currTangent, nextTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, nextNormal)) * min(length(nextDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\n\\tif (prevReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * startJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / startMiterRatio, 1.);\\n\\t\\taBotCoord = aCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\taTopCoord = aCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!nextReverse && baClipping > 0. && baClipping < length(normalWidth * endBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\tbTopCoord -= normalWidth * endTopJoin;\\n\\t\\tbTopCoord += normalize(endTopJoin * normalWidth) * baClipping;\\n\\t}\\n\\n\\tif (nextReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * endJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / endMiterRatio, 1.);\\n\\t\\tbBotCoord = bCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\tbTopCoord = bCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!prevReverse && abClipping > 0. && abClipping < length(normalWidth * startBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\taBotCoord -= normalWidth * startBotJoin;\\n\\t\\taBotCoord += normalize(startBotJoin * normalWidth) * abClipping;\\n\\t}\\n\\n\\tvec2 aTopPosition = (aTopCoord) * adjustedScale + translate;\\n\\tvec2 aBotPosition = (aBotCoord) * adjustedScale + translate;\\n\\n\\tvec2 bTopPosition = (bTopCoord) * adjustedScale + translate;\\n\\tvec2 bBotPosition = (bBotCoord) * adjustedScale + translate;\\n\\n\\t//position is normalized 0..1 coord on the screen\\n\\tvec2 position = (aTopPosition * lineTop + aBotPosition * lineBot) * lineStart + (bTopPosition * lineTop + bBotPosition * lineBot) * lineEnd;\\n\\n\\tstartCoord = aCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\tendCoord = bCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\n\\tgl_Position = vec4(position  * 2.0 - 1.0, depth, 1);\\n\\n\\tenableStartMiter = step(dot(currTangent, prevTangent), .5);\\n\\tenableEndMiter = step(dot(currTangent, nextTangent), .5);\\n\\n\\t//bevel miter cutoffs\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n\\n\\t//round miter cutoffs\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * abs(dot(startJoinDirection, currNormal)) * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * abs(dot(endJoinDirection, currNormal)) * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\nuniform float dashSize, pixelRatio, thickness, opacity, id, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nvoid main() {\\n\\tfloat alpha = 1., distToStart, distToEnd;\\n\\tfloat cutoff = thickness * .5;\\n\\n\\t//bevel miter\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToStart + 1., 0.), 1.);\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToEnd + 1., 0.), 1.);\\n\\t\\t}\\n\\t}\\n\\n\\t// round miter\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - startCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - endCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\t}\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1},bColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:4,divisor:1},prevCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:0,divisor:1},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},nextCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:24,divisor:1}}},n))}catch(t){e=i}return{fill:t({primitive:\"triangle\",elements:function(t,e){return e.triangles},offset:0,vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position, positionFract;\\n\\nuniform vec4 color;\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio, id;\\nuniform vec4 viewport;\\nuniform float opacity;\\n\\nvarying vec4 fragColor;\\n\\nconst float MAX_LINES = 256.;\\n\\nvoid main() {\\n\\tfloat depth = (MAX_LINES - 4. - id) / (MAX_LINES);\\n\\n\\tvec2 position = position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n\\tfragColor.a *= opacity;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n\\tgl_FragColor = fragColor;\\n}\\n\"]),uniforms:{scale:t.prop(\"scale\"),color:t.prop(\"fill\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{position:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8},positionFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8}},blend:n.blend,depth:{enable:!1},scissor:n.scissor,stencil:n.stencil,viewport:n.viewport}),rect:i,miter:e}},v.defaults={dashes:null,join:\"miter\",miterLimit:1,thickness:10,cap:\"square\",color:\"black\",opacity:1,overlay:!1,viewport:null,range:null,close:!1,fill:null},v.prototype.render=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];e.length&&(t=this).update.apply(t,e),this.draw()},v.prototype.draw=function(){for(var t=this,e=[],r=arguments.length;r--;)e[r]=arguments[r];return(e.length?e:this.passes).forEach(function(e,r){var n;if(e&&Array.isArray(e))return(n=t).draw.apply(n,e);\"number\"==typeof e&&(e=t.passes[e]),e&&e.count>1&&e.opacity&&(t.regl._refresh(),e.fill&&e.triangles&&e.triangles.length>2&&t.shaders.fill(e),e.thickness&&(e.scale[0]*e.viewport.width>v.precisionThreshold||e.scale[1]*e.viewport.height>v.precisionThreshold?t.shaders.rect(e):\"rect\"===e.join||!e.join&&(e.thickness<=2||e.count>=v.maxPoints)?t.shaders.rect(e):t.shaders.miter(e)))}),this},v.prototype.update=function(t){var e=this;if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var r=this.regl,o=this.gl;if(t.forEach(function(t,h){var d=e.passes[h];if(void 0!==t)if(null!==t){if(\"number\"==typeof t[0]&&(t={positions:t}),t=s(t,{positions:\"positions points data coords\",thickness:\"thickness lineWidth lineWidths line-width linewidth width stroke-width strokewidth strokeWidth\",join:\"lineJoin linejoin join type mode\",miterLimit:\"miterlimit miterLimit\",dashes:\"dash dashes dasharray dash-array dashArray\",color:\"color colour stroke colors colours stroke-color strokeColor\",fill:\"fill fill-color fillColor\",opacity:\"alpha opacity\",overlay:\"overlay crease overlap intersect\",close:\"closed close closed-path closePath\",range:\"range dataBox\",viewport:\"viewport viewBox\",hole:\"holes hole hollow\"}),d||(e.passes[h]=d={id:h,scale:null,scaleFract:null,translate:null,translateFract:null,count:0,hole:[],depth:0,dashLength:1,dashTexture:r.texture({channels:1,data:new Uint8Array([255]),width:1,height:1,mag:\"linear\",min:\"linear\"}),colorBuffer:r.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array}),positionBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),positionFractBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array})},t=a({},v.defaults,t)),null!=t.thickness&&(d.thickness=parseFloat(t.thickness)),null!=t.opacity&&(d.opacity=parseFloat(t.opacity)),null!=t.miterLimit&&(d.miterLimit=parseFloat(t.miterLimit)),null!=t.overlay&&(d.overlay=!!t.overlay,h<v.maxLines&&(d.depth=2*(v.maxLines-1-h%v.maxLines)/v.maxLines-1)),null!=t.join&&(d.join=t.join),null!=t.hole&&(d.hole=t.hole),null!=t.fill&&(d.fill=t.fill?n(t.fill,\"uint8\"):null),null!=t.viewport&&(d.viewport=g(t.viewport)),d.viewport||(d.viewport=g([o.drawingBufferWidth,o.drawingBufferHeight])),null!=t.close&&(d.close=t.close),null===t.positions&&(t.positions=[]),t.positions){var m,y;if(t.positions.x&&t.positions.y){var x=t.positions.x,b=t.positions.y;y=d.count=Math.max(x.length,b.length),m=new Float64Array(2*y);for(var _=0;_<y;_++)m[2*_]=x[_],m[2*_+1]=b[_]}else m=l(t.positions,\"float64\"),y=d.count=Math.floor(m.length/2);var w=d.bounds=i(m,2);if(d.fill){for(var k=[],T={},A=0,M=0,S=0,E=d.count;M<E;M++){var C=m[2*M],L=m[2*M+1];isNaN(C)||isNaN(L)||null==C||null==L?(C=m[2*A],L=m[2*A+1],T[M]=A):A=M,k[S++]=C,k[S++]=L}for(var P=c(k,d.hole||[]),O=0,z=P.length;O<z;O++)null!=T[P[O]]&&(P[O]=T[P[O]]);d.triangles=P}var I=new Float64Array(m);u(I,2,w);var D=new Float64Array(2*y+6);d.close?m[0]===m[2*y-2]&&m[1]===m[2*y-1]?(D[0]=I[2*y-4],D[1]=I[2*y-3]):(D[0]=I[2*y-2],D[1]=I[2*y-1]):(D[0]=I[0],D[1]=I[1]),D.set(I,2),d.close?m[0]===m[2*y-2]&&m[1]===m[2*y-1]?(D[2*y+2]=I[2],D[2*y+3]=I[3],d.count-=1):(D[2*y+2]=I[0],D[2*y+3]=I[1],D[2*y+4]=I[2],D[2*y+5]=I[3]):(D[2*y+2]=I[2*y-2],D[2*y+3]=I[2*y-1],D[2*y+4]=I[2*y-2],D[2*y+5]=I[2*y-1]),d.positionBuffer(f(D)),d.positionFractBuffer(p(D))}if(t.range?d.range=t.range:d.range||(d.range=d.bounds),(t.range||t.positions)&&d.count){var R=d.bounds,F=R[2]-R[0],B=R[3]-R[1],N=d.range[2]-d.range[0],j=d.range[3]-d.range[1];d.scale=[F/N,B/j],d.translate=[-d.range[0]/N+R[0]/N||0,-d.range[1]/j+R[1]/j||0],d.scaleFract=p(d.scale),d.translateFract=p(d.translate)}if(t.dashes){var U,V=0;if(!t.dashes||t.dashes.length<2)V=1,U=new Uint8Array([255,255,255,255,255,255,255,255]);else{V=0;for(var q=0;q<t.dashes.length;++q)V+=t.dashes[q];U=new Uint8Array(V*v.dashMult);for(var H=0,G=255,Y=0;Y<2;Y++)for(var W=0;W<t.dashes.length;++W){for(var X=0,Z=t.dashes[W]*v.dashMult*.5;X<Z;++X)U[H++]=G;G^=255}}d.dashLength=V,d.dashTexture({channels:1,data:U,width:U.length,height:1,mag:\"linear\",min:\"linear\"},0,0)}if(t.color){var J=d.count,K=t.color;K||(K=\"transparent\");var $=new Uint8Array(4*J+4);if(Array.isArray(K)&&\"number\"!=typeof K[0]){for(var Q=0;Q<J;Q++){var tt=n(K[Q],\"uint8\");$.set(tt,4*Q)}$.set(n(K[0],\"uint8\"),4*J)}else for(var et=n(K,\"uint8\"),rt=0;rt<J+1;rt++)$.set(et,4*rt);d.colorBuffer({usage:\"dynamic\",type:\"uint8\",data:$})}}else e.passes[h]=null}),t.length<this.passes.length){for(var h=t.length;h<this.passes.length;h++){var d=e.passes[h];d&&(d.colorBuffer.destroy(),d.positionBuffer.destroy(),d.dashTexture.destroy())}this.passes.length=t.length}for(var m=[],y=0;y<this.passes.length;y++)null!==e.passes[y]&&m.push(e.passes[y]);return this.passes=m,this}},v.prototype.destroy=function(){return this.passes.forEach(function(t){t.colorBuffer.destroy(),t.positionBuffer.destroy(),t.dashTexture.destroy()}),this.passes.length=0,this}},{\"array-bounds\":65,\"array-normalize\":66,\"color-normalize\":120,earcut:492,\"es6-weak-map\":493,\"flatten-vertex-data\":227,glslify:409,\"object-assign\":454,\"parse-rect\":459,\"pick-by-alias\":465,\"to-float32\":538}],492:[function(t,e,r){\"use strict\";function n(t,e,r){r=r||2;var n,s,l,c,u,p,g,v=e&&e.length,m=v?e[0]*r:t.length,y=i(t,0,m,r,!0),x=[];if(!y||y.next===y.prev)return x;if(v&&(y=function(t,e,r,n){var o,s,l,c,u,p=[];for(o=0,s=e.length;o<s;o++)l=e[o]*n,c=o<s-1?e[o+1]*n:t.length,(u=i(t,l,c,n,!1))===u.next&&(u.steiner=!0),p.push(d(u));for(p.sort(h),o=0;o<p.length;o++)f(p[o],r),r=a(r,r.next);return r}(t,e,y,r)),t.length>80*r){n=l=t[0],s=c=t[1];for(var b=r;b<m;b+=r)(u=t[b])<n&&(n=u),(p=t[b+1])<s&&(s=p),u>l&&(l=u),p>c&&(c=p);g=0!==(g=Math.max(l-n,c-s))?1/g:0}return o(y,x,r,n,s,g),x}function i(t,e,r,n,i){var a,o;if(i===A(t,e,r,n)>0)for(a=e;a<r;a+=n)o=w(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=w(a,t[a],t[a+1],o);return o&&y(o,o.next)&&(k(o),o=o.next),o}function a(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!y(n,n.next)&&0!==m(n.prev,n,n.next))n=n.next;else{if(k(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function o(t,e,r,n,i,h,f){if(t){!f&&h&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=p(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,h);for(var d,g,v=t;t.prev!==t.next;)if(d=t.prev,g=t.next,h?l(t,n,i,h):s(t))e.push(d.i/r),e.push(t.i/r),e.push(g.i/r),k(t),t=g.next,v=g.next;else if((t=g)===v){f?1===f?o(t=c(t,e,r),e,r,n,i,h,2):2===f&&u(t,e,r,n,i,h):o(a(t),e,r,n,i,h,1);break}}}function s(t){var e=t.prev,r=t,n=t.next;if(m(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(g(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&m(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function l(t,e,r,n){var i=t.prev,a=t,o=t.next;if(m(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,h=p(s,l,e,r,n),f=p(c,u,e,r,n),d=t.prevZ,v=t.nextZ;d&&d.z>=h&&v&&v.z<=f;){if(d!==t.prev&&d!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&m(d.prev,d,d.next)>=0)return!1;if(d=d.prevZ,v!==t.prev&&v!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,v.x,v.y)&&m(v.prev,v,v.next)>=0)return!1;v=v.nextZ}for(;d&&d.z>=h;){if(d!==t.prev&&d!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&m(d.prev,d,d.next)>=0)return!1;d=d.prevZ}for(;v&&v.z<=f;){if(v!==t.prev&&v!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,v.x,v.y)&&m(v.prev,v,v.next)>=0)return!1;v=v.nextZ}return!0}function c(t,e,r){var n=t;do{var i=n.prev,a=n.next.next;!y(i,a)&&x(i,n,n.next,a)&&b(i,a)&&b(a,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(a.i/r),k(n),k(n.next),n=t=a),n=n.next}while(n!==t);return n}function u(t,e,r,n,i,s){var l=t;do{for(var c=l.next.next;c!==l.prev;){if(l.i!==c.i&&v(l,c)){var u=_(l,c);return l=a(l,l.next),u=a(u,u.next),o(l,e,r,n,i,s),void o(u,e,r,n,i,s)}c=c.next}l=l.next}while(l!==t)}function h(t,e){return t.x-e.x}function f(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r.prev;var l,c=r,u=r.x,h=r.y,f=1/0;n=r.next;for(;n!==c;)i>=n.x&&n.x>=u&&i!==n.x&&g(a<h?i:o,a,u,h,a<h?o:i,a,n.x,n.y)&&((l=Math.abs(a-n.y)/(i-n.x))<f||l===f&&n.x>r.x)&&b(n,t)&&(r=n,f=l),n=n.next;return r}(t,e)){var r=_(e,t);a(r,r.next)}}function p(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function d(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function g(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function v(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&x(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&b(t,e)&&b(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)}function m(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function y(t,e){return t.x===e.x&&t.y===e.y}function x(t,e,r,n){return!!(y(t,e)&&y(r,n)||y(t,n)&&y(r,e))||m(t,e,r)>0!=m(t,e,n)>0&&m(r,n,t)>0!=m(r,n,e)>0}function b(t,e){return m(t.prev,t,t.next)<0?m(t,e,t.next)>=0&&m(t,t.prev,e)>=0:m(t,e,t.prev)<0||m(t,t.next,e)<0}function _(t,e){var r=new T(t.i,t.x,t.y),n=new T(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function w(t,e,r,n){var i=new T(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function k(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function T(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function A(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}e.exports=n,e.exports.default=n,n.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(A(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(A(t,c,u,r))}var h=0;for(s=0;s<n.length;s+=3){var f=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;h+=Math.abs((t[f]-t[d])*(t[p+1]-t[f+1])-(t[f]-t[p])*(t[d+1]-t[f+1]))}return 0===o&&0===h?0:Math.abs((h-o)/o)},n.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r}},{}],493:[function(t,e,r){arguments[4][318][0].apply(r,arguments)},{\"./is-implemented\":494,\"./polyfill\":496,dup:318}],494:[function(t,e,r){arguments[4][319][0].apply(r,arguments)},{dup:319}],495:[function(t,e,r){arguments[4][320][0].apply(r,arguments)},{dup:320}],496:[function(t,e,r){arguments[4][321][0].apply(r,arguments)},{\"./is-native-implemented\":495,d:151,dup:321,\"es5-ext/object/is-value\":194,\"es5-ext/object/set-prototype-of\":200,\"es5-ext/object/valid-object\":204,\"es5-ext/object/valid-value\":205,\"es5-ext/string/random-uniq\":210,\"es6-iterator/for-of\":212,\"es6-iterator/get\":213,\"es6-symbol\":219}],497:[function(t,e,r){\"use strict\";function n(t,e){return function(t){if(Array.isArray(t))return t}(t)||function(t,e){var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{n||null==s.return||s.return()}finally{if(i)throw a}}return r}(t,e)||function(){throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")}()}function i(t){return function(t){if(Array.isArray(t)){for(var e=0,r=new Array(t.length);e<t.length;e++)r[e]=t[e];return r}}(t)||function(t){if(Symbol.iterator in Object(t)||\"[object Arguments]\"===Object.prototype.toString.call(t))return Array.from(t)}(t)||function(){throw new TypeError(\"Invalid attempt to spread non-iterable instance\")}()}var a=t(\"color-normalize\"),o=t(\"array-bounds\"),s=t(\"color-id\"),l=t(\"point-cluster\"),c=t(\"object-assign\"),u=t(\"glslify\"),h=t(\"pick-by-alias\"),f=t(\"update-diff\"),p=t(\"flatten-vertex-data\"),d=t(\"is-iexplorer\"),g=t(\"to-float32\"),v=t(\"parse-rect\"),m=y;function y(t,e){var r=this;if(!(this instanceof y))return new y(t,e);\"function\"==typeof t?(e||(e={}),e.regl=t):(e=t,t=null),e&&e.length&&(e.positions=e);var n,i=(t=e.regl)._gl,a=[];this.tooManyColors=d,n=t.texture({data:new Uint8Array(1020),width:255,height:1,type:\"uint8\",format:\"rgba\",wrapS:\"clamp\",wrapT:\"clamp\",mag:\"nearest\",min:\"nearest\"}),c(this,{regl:t,gl:i,groups:[],markerCache:[null],markerTextures:[null],palette:a,paletteIds:{},paletteTexture:n,maxColors:255,maxSize:100,canvas:i.canvas}),this.update(e);var o={uniforms:{pixelRatio:t.context(\"pixelRatio\"),palette:n,paletteSize:function(t,e){return[r.tooManyColors?0:255,n.height]},scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translate:t.prop(\"translate\"),translateFract:t.prop(\"translateFract\"),opacity:t.prop(\"opacity\"),marker:t.prop(\"markerTexture\")},attributes:{x:function(t,e){return e.xAttr||{buffer:e.positionBuffer,stride:8,offset:0}},y:function(t,e){return e.yAttr||{buffer:e.positionBuffer,stride:8,offset:4}},xFract:function(t,e){return e.xAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:0}},yFract:function(t,e){return e.yAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:4}},size:function(t,e){return e.size.length?{buffer:e.sizeBuffer,stride:2,offset:0}:{constant:[Math.round(255*e.size/r.maxSize)]}},borderSize:function(t,e){return e.borderSize.length?{buffer:e.sizeBuffer,stride:2,offset:1}:{constant:[Math.round(255*e.borderSize/r.maxSize)]}},colorId:function(t,e){return e.color.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:0}:{constant:r.tooManyColors?a.slice(4*e.color,4*e.color+4):[e.color]}},borderColorId:function(t,e){return e.borderColor.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:r.tooManyColors?4:2}:{constant:r.tooManyColors?a.slice(4*e.borderColor,4*e.borderColor+4):[e.borderColor]}},isActive:function(t,e){return!0===e.activation?{constant:[1]}:e.activation?e.activation:{constant:[0]}}},blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:{enable:!1},depth:{enable:!1},elements:t.prop(\"elements\"),count:t.prop(\"count\"),offset:t.prop(\"offset\"),primitive:\"points\"},s=c({},o);s.frag=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nuniform sampler2D marker;\\nuniform float pixelRatio, opacity;\\n\\nfloat smoothStep(float x, float y) {\\n  return 1.0 / (1.0 + exp(50.0*(x - y)));\\n}\\n\\nvoid main() {\\n  float dist = texture2D(marker, gl_PointCoord).r, delta = fragWidth;\\n\\n  // max-distance alpha\\n  if (dist < 0.003) discard;\\n\\n  // null-border case\\n  if (fragBorderColorLevel == fragColorLevel || fragBorderColor.a == 0.) {\\n    float colorAmt = smoothstep(.5 - delta, .5 + delta, dist);\\n    gl_FragColor = vec4(fragColor.rgb, colorAmt * fragColor.a * opacity);\\n  }\\n  else {\\n    float borderColorAmt = smoothstep(fragBorderColorLevel - delta, fragBorderColorLevel + delta, dist);\\n    float colorAmt = smoothstep(fragColorLevel - delta, fragColorLevel + delta, dist);\\n\\n    vec4 color = fragBorderColor;\\n    color.a *= borderColorAmt;\\n    color = mix(color, fragColor, colorAmt);\\n    color.a *= opacity;\\n\\n    gl_FragColor = color;\\n  }\\n\\n}\\n\"]),s.vert=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract, paletteSize;\\nuniform float pixelRatio;\\nuniform sampler2D palette;\\n\\nconst float maxSize = 100.;\\nconst float borderLevel = .5;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragPointSize, fragBorderRadius, fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = 2. * size * pixelRatio;\\n  fragPointSize = size * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\n  fragColor = color;\\n  fragBorderColor = borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n\\n  fragBorderColorLevel = clamp(borderLevel - borderLevel * borderSize / size, 0., 1.);\\n  fragColorLevel = clamp(borderLevel + (1. - borderLevel) * borderSize / size, 0., 1.);\\n}\"]),this.drawMarker=t(s);var l=c({},o);l.frag=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\n\\nuniform float opacity;\\nvarying float fragBorderRadius, fragWidth;\\n\\nfloat smoothStep(float edge0, float edge1, float x) {\\n\\tfloat t;\\n\\tt = clamp((x - edge0) / (edge1 - edge0), 0.0, 1.0);\\n\\treturn t * t * (3.0 - 2.0 * t);\\n}\\n\\nvoid main() {\\n\\tfloat radius, alpha = 1.0, delta = fragWidth;\\n\\n\\tradius = length(2.0 * gl_PointCoord.xy - 1.0);\\n\\n\\tif (radius > 1.0 + delta) {\\n\\t\\tdiscard;\\n\\t}\\n\\n\\talpha -= smoothstep(1.0 - delta, 1.0 + delta, radius);\\n\\n\\tfloat borderRadius = fragBorderRadius;\\n\\tfloat ratio = smoothstep(borderRadius - delta, borderRadius + delta, radius);\\n\\tvec4 color = mix(fragColor, fragBorderColor, ratio);\\n\\tcolor.a *= alpha * opacity;\\n\\tgl_FragColor = color;\\n}\\n\"]),l.vert=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio;\\nuniform sampler2D palette;\\nuniform vec2 paletteSize;\\n\\nconst float maxSize = 100.;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragBorderRadius, fragWidth;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  // ignore inactive points\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = (size + borderSize) * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\n  fragBorderRadius = 1. - 2. * borderSize / (size + borderSize);\\n  fragColor = color;\\n  fragBorderColor = borderColor.a == 0. || borderSize == 0. ? vec4(color.rgb, 0.) : borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n}\\n\"]),d&&(l.frag=l.frag.replace(\"smoothstep\",\"smoothStep\"),s.frag=s.frag.replace(\"smoothstep\",\"smoothStep\")),this.drawCircle=t(l)}y.defaults={color:\"black\",borderColor:\"transparent\",borderSize:0,size:12,opacity:1,marker:void 0,viewport:null,range:null,pixelSize:null,count:0,offset:0,bounds:null,positions:[],snap:1e4},y.prototype.render=function(){return arguments.length&&this.update.apply(this,arguments),this.draw(),this},y.prototype.draw=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var i=this.groups;if(1===r.length&&Array.isArray(r[0])&&(null===r[0][0]||Array.isArray(r[0][0]))&&(r=r[0]),this.regl._refresh(),r.length)for(var a=0;a<r.length;a++)this.drawItem(a,r[a]);else i.forEach(function(e,r){t.drawItem(r)});return this},y.prototype.drawItem=function(t,e){var r=this.groups,n=r[t];if(\"number\"==typeof e&&(t=e,n=r[e],e=null),n&&n.count&&n.opacity){n.activation[0]&&this.drawCircle(this.getMarkerDrawOptions(0,n,e));for(var a=[],o=1;o<n.activation.length;o++)n.activation[o]&&(!0===n.activation[o]||n.activation[o].data.length)&&a.push.apply(a,i(this.getMarkerDrawOptions(o,n,e)));a.length&&this.drawMarker(a)}},y.prototype.getMarkerDrawOptions=function(t,e,r){var i=e.range,a=e.tree,o=e.viewport,s=e.activation,l=e.selectionBuffer,u=e.count;this.regl;if(!a)return r?[c({},e,{markerTexture:this.markerTextures[t],activation:s[t],count:r.length,elements:r,offset:0})]:[c({},e,{markerTexture:this.markerTextures[t],activation:s[t],offset:0})];var h=[],f=a.range(i,{lod:!0,px:[(i[2]-i[0])/o.width,(i[3]-i[1])/o.height]});if(r){for(var p=s[t].data,d=new Uint8Array(u),g=0;g<r.length;g++){var v=r[g];d[v]=p?p[v]:1}l.subdata(d)}for(var m=f.length;m--;){var y=n(f[m],2),x=y[0],b=y[1];h.push(c({},e,{markerTexture:this.markerTextures[t],activation:r?l:s[t],offset:x,count:b-x}))}return h},y.prototype.update=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];if(r.length){1===r.length&&Array.isArray(r[0])&&(r=r[0]);var i=this.groups,a=this.gl,s=this.regl,u=this.maxSize,d=this.maxColors,m=this.palette;this.groups=i=r.map(function(e,r){var n=i[r];if(void 0===e)return n;null===e?e={positions:null}:\"function\"==typeof e?e={ondraw:e}:\"number\"==typeof e[0]&&(e={positions:e}),null===(e=h(e,{positions:\"positions data points\",snap:\"snap cluster lod tree\",size:\"sizes size radius\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",color:\"colors color fill fill-color fillColor\",borderColor:\"borderColors borderColor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range dataBox databox\",viewport:\"viewport viewPort viewBox viewbox\",opacity:\"opacity alpha transparency\",bounds:\"bound bounds boundaries limits\",tooManyColors:\"tooManyColors palette paletteMode optimizePalette enablePalette\"})).positions&&(e.positions=[]),null!=e.tooManyColors&&(t.tooManyColors=e.tooManyColors),n||(i[r]=n={id:r,scale:null,translate:null,scaleFract:null,translateFract:null,activation:[],selectionBuffer:s.buffer({data:new Uint8Array(0),usage:\"stream\",type:\"uint8\"}),sizeBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),colorBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),positionBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"}),positionFractBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"})},e=c({},y.defaults,e)),!e.positions||\"marker\"in e||(e.marker=n.marker,delete n.marker),!e.marker||\"positions\"in e||(e.positions=n.positions,delete n.positions);var x=0,b=0;if(f(n,e,[{snap:!0,size:function(t,e){return null==t&&(t=y.defaults.size),x+=t&&t.length?1:0,t},borderSize:function(t,e){return null==t&&(t=y.defaults.borderSize),x+=t&&t.length?1:0,t},opacity:parseFloat,color:function(e,r){return null==e&&(e=y.defaults.color),e=t.updateColor(e),b++,e},borderColor:function(e,r){return null==e&&(e=y.defaults.borderColor),e=t.updateColor(e),b++,e},bounds:function(t,e,r){return\"range\"in r||(r.range=null),t},positions:function(t,e,r){var n=e.snap,i=e.positionBuffer,a=e.positionFractBuffer,c=e.selectionBuffer;if(t.x||t.y)return t.x.length?e.xAttr={buffer:s.buffer(t.x),offset:0,stride:4,count:t.x.length}:e.xAttr={buffer:t.x.buffer,offset:4*t.x.offset||0,stride:4*(t.x.stride||1),count:t.x.count},t.y.length?e.yAttr={buffer:s.buffer(t.y),offset:0,stride:4,count:t.y.length}:e.yAttr={buffer:t.y.buffer,offset:4*t.y.offset||0,stride:4*(t.y.stride||1),count:t.y.count},e.count=Math.max(e.xAttr.count,e.yAttr.count),t;t=p(t,\"float64\");var u=e.count=Math.floor(t.length/2),h=e.bounds=u?o(t,2):null;if(r.range||e.range||(delete e.range,r.range=h),r.marker||e.marker||(delete e.marker,r.marker=null),n&&(!0===n||u>n)?e.tree=l(t,{bounds:h}):n&&n.length&&(e.tree=n),e.tree){var f={primitive:\"points\",usage:\"static\",data:e.tree,type:\"uint32\"};e.elements?e.elements(f):e.elements=s.elements(f)}return i({data:g.float(t),usage:\"dynamic\"}),a({data:g.fract(t),usage:\"dynamic\"}),c({data:new Uint8Array(u),type:\"uint8\",usage:\"stream\"}),t}},{marker:function(e,r,n){var i=r.activation;if(i.forEach(function(t){return t&&t.destroy&&t.destroy()}),i.length=0,e&&\"number\"!=typeof e[0]){for(var a=[],o=0,l=Math.min(e.length,r.count);o<l;o++){var c=t.addMarker(e[o]);a[c]||(a[c]=new Uint8Array(r.count)),a[c][o]=1}for(var u=0;u<a.length;u++)if(a[u]){var h={data:a[u],type:\"uint8\",usage:\"static\"};i[u]?i[u](h):i[u]=s.buffer(h),i[u].data=a[u]}}else{i[t.addMarker(e)]=!0}return e},range:function(t,e,r){var n=e.bounds;if(n)return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=g.fract(e.scale),e.translateFract=g.fract(e.translate),t},viewport:function(t){return v(t||[a.drawingBufferWidth,a.drawingBufferHeight])}}]),x){var _=n,w=_.count,k=_.size,T=_.borderSize,A=_.sizeBuffer,M=new Uint8Array(2*w);if(k.length||T.length)for(var S=0;S<w;S++)M[2*S]=Math.round(255*(null==k[S]?k:k[S])/u),M[2*S+1]=Math.round(255*(null==T[S]?T:T[S])/u);A({data:M,usage:\"dynamic\"})}if(b){var E,C=n,L=C.count,P=C.color,O=C.borderColor,z=C.colorBuffer;if(t.tooManyColors){if(P.length||O.length){E=new Uint8Array(8*L);for(var I=0;I<L;I++){var D=P[I];E[8*I]=m[4*D],E[8*I+1]=m[4*D+1],E[8*I+2]=m[4*D+2],E[8*I+3]=m[4*D+3];var R=O[I];E[8*I+4]=m[4*R],E[8*I+5]=m[4*R+1],E[8*I+6]=m[4*R+2],E[8*I+7]=m[4*R+3]}}}else if(P.length||O.length){E=new Uint8Array(4*L+2);for(var F=0;F<L;F++)null!=P[F]&&(E[4*F]=P[F]%d,E[4*F+1]=Math.floor(P[F]/d)),null!=O[F]&&(E[4*F+2]=O[F]%d,E[4*F+3]=Math.floor(O[F]/d))}z({data:E||new Uint8Array(0),type:\"uint8\",usage:\"dynamic\"})}return n})}},y.prototype.addMarker=function(t){var e,r=this.markerTextures,n=this.regl,i=this.markerCache,a=null==t?0:i.indexOf(t);if(a>=0)return a;if(t instanceof Uint8Array||t instanceof Uint8ClampedArray)e=t;else{e=new Uint8Array(t.length);for(var o=0,s=t.length;o<s;o++)e[o]=255*t[o]}var l=Math.floor(Math.sqrt(e.length));return a=r.length,i.push(t),r.push(n.texture({channels:1,data:e,radius:l,mag:\"linear\",min:\"linear\"})),a},y.prototype.updateColor=function(t){var e=this.paletteIds,r=this.palette,n=this.maxColors;Array.isArray(t)||(t=[t]);var i=[];if(\"number\"==typeof t[0]){var o=[];if(Array.isArray(t))for(var l=0;l<t.length;l+=4)o.push(t.slice(l,l+4));else for(var c=0;c<t.length;c+=4)o.push(t.subarray(c,c+4));t=o}for(var u=0;u<t.length;u++){var h=t[u];h=a(h,\"uint8\");var f=s(h,!1);if(null==e[f]){var p=r.length;e[f]=Math.floor(p/4),r[p]=h[0],r[p+1]=h[1],r[p+2]=h[2],r[p+3]=h[3]}i[u]=e[f]}return!this.tooManyColors&&r.length>4*n&&(this.tooManyColors=!0),this.updatePalette(r),1===i.length?i[0]:i},y.prototype.updatePalette=function(t){if(!this.tooManyColors){var e=this.maxColors,r=this.paletteTexture,n=Math.ceil(.25*t.length/e);if(n>1)for(var i=.25*(t=t.slice()).length%e;i<n*e;i++)t.push(0,0,0,0);r.height<n&&r.resize(e,n),r.subimage({width:Math.min(.25*t.length,e),height:n,data:t},0,0)}},y.prototype.destroy=function(){return this.groups.forEach(function(t){t.sizeBuffer.destroy(),t.positionBuffer.destroy(),t.positionFractBuffer.destroy(),t.colorBuffer.destroy(),t.activation.forEach(function(t){return t&&t.destroy&&t.destroy()}),t.selectionBuffer.destroy(),t.elements&&t.elements.destroy()}),this.groups.length=0,this.paletteTexture.destroy(),this.markerTextures.forEach(function(t){return t&&t.destroy&&t.destroy()}),this};var x=t(\"object-assign\");e.exports=function(t,e){var r=new m(t,e),n=r.render.bind(r);return x(n,{render:n,update:r.update.bind(r),draw:r.draw.bind(r),destroy:r.destroy.bind(r),regl:r.regl,gl:r.gl,canvas:r.gl.canvas,groups:r.groups,markers:r.markerCache,palette:r.palette}),n}},{\"array-bounds\":65,\"color-id\":118,\"color-normalize\":120,\"flatten-vertex-data\":227,glslify:409,\"is-iexplorer\":419,\"object-assign\":454,\"parse-rect\":459,\"pick-by-alias\":465,\"point-cluster\":499,\"to-float32\":538,\"update-diff\":549}],498:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],499:[function(t,e,r){\"use strict\";e.exports=t(\"./quad\")},{\"./quad\":500}],500:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"clamp\"),a=t(\"parse-rect\"),o=t(\"array-bounds\"),s=t(\"pick-by-alias\"),l=t(\"defined\"),c=t(\"flatten-vertex-data\"),u=t(\"is-obj\"),h=t(\"dtype\"),f=t(\"math-log2\"),p=1073741824;function d(t,e){for(var r=e[0],n=e[1],a=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=i((t[2*l]-r)*a,0,1),s[2*l+1]=i((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,\"float64\"),e=s(e,{bounds:\"range bounds dataBox databox\",maxDepth:\"depth maxDepth maxdepth level maxLevel maxlevel levels\",dtype:\"type dtype format out dst output destination\"});var r=l(e.maxDepth,255),i=l(e.bounds,o(t,2));i[0]===i[2]&&i[2]++,i[1]===i[3]&&i[3]++;var g,v=d(t,i),m=t.length>>>1;e.dtype||(e.dtype=\"array\"),\"string\"==typeof e.dtype?g=new(h(e.dtype))(m):e.dtype&&(g=e.dtype,Array.isArray(g)&&(g.length=m));for(var y=0;y<m;++y)g[y]=y;var x=[],b=[],_=[],w=[];!function t(e,n,i,a,o,s){if(!a.length)return null;var l=x[o]||(x[o]=[]);var c=_[o]||(_[o]=[]);var u=b[o]||(b[o]=[]);var h=l.length;o++;if(o>r||s>p){for(var f=0;f<a.length;f++)l.push(a[f]),c.push(s),u.push(null,null,null,null);return h}l.push(a[0]);c.push(s);if(a.length<=1)return u.push(null,null,null,null),h;var d=.5*i;var g=e+d,m=n+d;var y=[],w=[],k=[],T=[];for(var A=1,M=a.length;A<M;A++){var S=a[A],E=v[2*S],C=v[2*S+1];E<g?C<m?y.push(S):w.push(S):C<m?k.push(S):T.push(S)}s<<=2;u.push(t(e,n,d,y,o,s),t(e,m,d,w,o,s+1),t(g,n,d,k,o,s+2),t(g,m,d,T,o,s+3));return h}(0,0,1,g,0,1);for(var k=0,T=0;T<x.length;T++){var A=x[T];if(g.set)g.set(A,k);else for(var M=0,S=A.length;M<S;M++)g[M+k]=A[M];var E=k+x[T].length;w[T]=[k,E],k=E}return g.range=function(){var e,r=[],o=arguments.length;for(;o--;)r[o]=arguments[o];if(u(r[r.length-1])){var c=r.pop();r.length||null==c.x&&null==c.l&&null==c.left||(r=[c],e={}),e=s(c,{level:\"level maxLevel\",d:\"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize\",lod:\"lod details ranges offsets\"})}else e={};r.length||(r=i);var h=a.apply(void 0,r),p=[Math.min(h.x,h.x+h.width),Math.min(h.y,h.y+h.height),Math.max(h.x,h.x+h.width),Math.max(h.y,h.y+h.height)],g=p[0],v=p[1],m=p[2],y=p[3],k=d([g,v,m,y],i),T=k[0],A=k[1],M=k[2],S=k[3],E=l(e.level,x.length);if(null!=e.d){var L;\"number\"==typeof e.d?L=[e.d,e.d]:e.d.length&&(L=e.d),E=Math.min(Math.max(Math.ceil(-f(Math.abs(L[0])/(i[2]-i[0]))),Math.ceil(-f(Math.abs(L[1])/(i[3]-i[1])))),E)}if(E=Math.min(E,x.length),e.lod)return function(t,e,r,i,a){for(var o=[],s=0;s<a;s++){var l=_[s],c=w[s][0],u=C(t,e,s),h=C(r,i,s),f=n.ge(l,u),p=n.gt(l,h,f,l.length-1);o[s]=[f+c,p+c]}return o}(T,A,M,S,E);var P=[];return function e(r,n,i,a,o,s){if(null!==o&&null!==s){var l=r+i,c=n+i;if(!(T>l||A>c||M<r||S<n||a>=E||o===s)){var u=x[a];void 0===s&&(s=u.length);for(var h=o;h<s;h++){var f=u[h],p=t[2*f],d=t[2*f+1];p>=g&&p<=m&&d>=v&&d<=y&&P.push(f)}var _=b[a],w=_[4*o+0],k=_[4*o+1],C=_[4*o+2],L=_[4*o+3],O=function(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}(_,o+1),z=.5*i,I=a+1;e(r,n,z,I,w,k||C||L||O),e(r,n+z,z,I,k,C||L||O),e(r+z,n,z,I,C,L||O),e(r+z,n+z,z,I,L,O)}}}(0,0,1,0,0,1),P},g;function C(t,e,r){for(var n=1,i=.5,a=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<i?e<a?0:1:e<a?2:3,o*=.5,i+=t<i?-o:o,a+=e<a?-o:o;return n}}},{\"array-bounds\":65,\"binary-search-bounds\":498,clamp:115,defined:164,dtype:169,\"flatten-vertex-data\":227,\"is-obj\":421,\"math-log2\":432,\"parse-rect\":459,\"pick-by-alias\":465}],501:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"pick-by-alias\"),a=t(\"array-bounds\"),o=t(\"raf\"),s=t(\"array-range\"),l=t(\"parse-rect\"),c=t(\"flatten-vertex-data\");function u(t,e){if(!(this instanceof u))return new u(t,e);this.traces=[],this.passes={},this.regl=t,this.scatter=n(t),this.canvas=this.scatter.canvas}function h(t,e,r){return(null!=t.id?t.id:t)<<16|(255&e)<<8|255&r}function f(t,e,r){var n,i,a,o,s=t[e],l=t[r];return s.length>2?(s[0],s[2],n=s[1],i=s[3]):s.length?(n=s[0],i=s[1]):(s.x,n=s.y,s.x+s.width,i=s.y+s.height),l.length>2?(a=l[0],o=l[2],l[1],l[3]):l.length?(a=l[0],o=l[1]):(a=l.x,l.y,o=l.x+l.width,l.y+l.height),[a,n,o,i]}function p(t){if(\"number\"==typeof t)return[t,t,t,t];if(2===t.length)return[t[0],t[1],t[0],t[1]];var e=l(t);return[e.x,e.y,e.x+e.width,e.y+e.height]}e.exports=u,u.prototype.render=function(){for(var t,e=this,r=[],n=arguments.length;n--;)r[n]=arguments[n];return r.length&&(t=this).update.apply(t,r),this.regl.attributes.preserveDrawingBuffer?this.draw():(this.dirty?null==this.planned&&(this.planned=o(function(){e.draw(),e.dirty=!0,e.planned=null})):(this.draw(),this.dirty=!0,o(function(){e.dirty=!1})),this)},u.prototype.update=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=0;n<e.length;n++)this.updateItem(n,e[n]);this.traces=this.traces.filter(Boolean);for(var i=[],a=0,o=0;o<this.traces.length;o++){for(var s=this.traces[o],l=this.traces[o].passes,c=0;c<l.length;c++)i.push(this.passes[l[c]]);s.passOffset=a,a+=s.passes.length}return(t=this.scatter).update.apply(t,i),this}},u.prototype.updateItem=function(t,e){var r=this.regl;if(null===e)return this.traces[t]=null,this;if(!e)return this;var n,o=i(e,{data:\"data items columns rows values dimensions samples x\",snap:\"snap cluster\",size:\"sizes size radius\",color:\"colors color fill fill-color fillColor\",opacity:\"opacity alpha transparency opaque\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",borderColor:\"borderColors borderColor bordercolor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range ranges databox dataBox\",viewport:\"viewport viewBox viewbox\",domain:\"domain domains area areas\",padding:\"pad padding paddings pads margin margins\",transpose:\"transpose transposed\",diagonal:\"diagonal diag showDiagonal\",upper:\"upper up top upperhalf upperHalf showupperhalf showUpper showUpperHalf\",lower:\"lower low bottom lowerhalf lowerHalf showlowerhalf showLowerHalf showLower\"}),s=this.traces[t]||(this.traces[t]={id:t,buffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),color:\"black\",marker:null,size:12,borderColor:\"transparent\",borderSize:1,viewport:l([r._gl.drawingBufferWidth,r._gl.drawingBufferHeight]),padding:[0,0,0,0],opacity:1,diagonal:!0,upper:!0,lower:!0});if(null!=o.color&&(s.color=o.color),null!=o.size&&(s.size=o.size),null!=o.marker&&(s.marker=o.marker),null!=o.borderColor&&(s.borderColor=o.borderColor),null!=o.borderSize&&(s.borderSize=o.borderSize),null!=o.opacity&&(s.opacity=o.opacity),o.viewport&&(s.viewport=l(o.viewport)),null!=o.diagonal&&(s.diagonal=o.diagonal),null!=o.upper&&(s.upper=o.upper),null!=o.lower&&(s.lower=o.lower),o.data){s.buffer(c(o.data)),s.columns=o.data.length,s.count=o.data[0].length,s.bounds=[];for(var u=0;u<s.columns;u++)s.bounds[u]=a(o.data[u],1)}o.range&&(s.range=o.range,n=s.range&&\"number\"!=typeof s.range[0]),o.domain&&(s.domain=o.domain);var d=!1;null!=o.padding&&(Array.isArray(o.padding)&&o.padding.length===s.columns&&\"number\"==typeof o.padding[o.padding.length-1]?(s.padding=o.padding.map(p),d=!0):s.padding=p(o.padding));var g=s.columns,v=s.count,m=s.viewport.width,y=s.viewport.height,x=s.viewport.x,b=s.viewport.y,_=m/g,w=y/g;s.passes=[];for(var k=0;k<g;k++)for(var T=0;T<g;T++)if((s.diagonal||T!==k)&&(s.upper||!(k>T))&&(s.lower||!(k<T))){var A=h(s.id,k,T),M=this.passes[A]||(this.passes[A]={});if(o.data&&(o.transpose?M.positions={x:{buffer:s.buffer,offset:T,count:v,stride:g},y:{buffer:s.buffer,offset:k,count:v,stride:g}}:M.positions={x:{buffer:s.buffer,offset:T*v,count:v},y:{buffer:s.buffer,offset:k*v,count:v}},M.bounds=f(s.bounds,k,T)),o.domain||o.viewport||o.data){var S=d?f(s.padding,k,T):s.padding;if(s.domain){var E=f(s.domain,k,T),C=E[0],L=E[1],P=E[2],O=E[3];M.viewport=[x+C*m+S[0],b+L*y+S[1],x+P*m-S[2],b+O*y-S[3]]}else M.viewport=[x+T*_+_*S[0],b+k*w+w*S[1],x+(T+1)*_-_*S[2],b+(k+1)*w-w*S[3]]}o.color&&(M.color=s.color),o.size&&(M.size=s.size),o.marker&&(M.marker=s.marker),o.borderSize&&(M.borderSize=s.borderSize),o.borderColor&&(M.borderColor=s.borderColor),o.opacity&&(M.opacity=s.opacity),o.range&&(M.range=n?f(s.range,k,T):s.range||M.bounds),s.passes.push(A)}return this},u.prototype.draw=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=[],i=0;i<e.length;i++)if(\"number\"==typeof e[i]){var a=this.traces[e[i]],o=a.passes,l=a.passOffset;n.push.apply(n,s(l,l+o.length))}else if(e[i].length){var c=e[i],u=this.traces[i],h=u.passes,f=u.passOffset;h=h.map(function(t,e){n[f+e]=c})}(t=this.scatter).draw.apply(t,n)}else this.scatter.draw();return this},u.prototype.destroy=function(){return this.traces.forEach(function(t){t.buffer&&t.buffer.destroy&&t.buffer.destroy()}),this.traces=null,this.passes=null,this.scatter.destroy(),this}},{\"array-bounds\":65,\"array-range\":67,\"flatten-vertex-data\":227,\"parse-rect\":459,\"pick-by-alias\":465,raf:484,\"regl-scatter2d\":497}],502:[function(t,e,r){var n,i;n=this,i=function(){function t(t,e){this.id=U++,this.type=t,this.data=e}function e(t){return\"[\"+function t(e){if(0===e.length)return[];var r=e.charAt(0),n=e.charAt(e.length-1);if(1<e.length&&r===n&&('\"'===r||\"'\"===r))return['\"'+e.substr(1,e.length-2).replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];if(r=/\\[(false|true|null|\\d+|'[^']*'|\"[^\"]*\")\\]/.exec(e))return t(e.substr(0,r.index)).concat(t(r[1])).concat(t(e.substr(r.index+r[0].length)));if(1===(r=e.split(\".\")).length)return['\"'+e.replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];for(e=[],n=0;n<r.length;++n)e=e.concat(t(r[n]));return e}(t).join(\"][\")+\"]\"}function r(t){return\"string\"==typeof t?t.split():t}function n(t){return\"string\"==typeof t?document.querySelector(t):t}function i(t){var e,i,a,o,s=t||{};t={};var l=[],c=[],u=\"undefined\"==typeof window?1:window.devicePixelRatio,h=!1,f=function(t){},p=function(){};if(\"string\"==typeof s?e=document.querySelector(s):\"object\"==typeof s&&(\"string\"==typeof s.nodeName&&\"function\"==typeof s.appendChild&&\"function\"==typeof s.getBoundingClientRect?e=s:\"function\"==typeof s.drawArrays||\"function\"==typeof s.drawElements?a=(o=s).canvas:(\"gl\"in s?o=s.gl:\"canvas\"in s?a=n(s.canvas):\"container\"in s&&(i=n(s.container)),\"attributes\"in s&&(t=s.attributes),\"extensions\"in s&&(l=r(s.extensions)),\"optionalExtensions\"in s&&(c=r(s.optionalExtensions)),\"onDone\"in s&&(f=s.onDone),\"profile\"in s&&(h=!!s.profile),\"pixelRatio\"in s&&(u=+s.pixelRatio))),e&&(\"canvas\"===e.nodeName.toLowerCase()?a=e:i=e),!o){if(!a){if(!(e=function(t,e,r){function n(){var e=window.innerWidth,n=window.innerHeight;t!==document.body&&(e=(n=t.getBoundingClientRect()).right-n.left,n=n.bottom-n.top),i.width=r*e,i.height=r*n,j(i.style,{width:e+\"px\",height:n+\"px\"})}var i=document.createElement(\"canvas\");return j(i.style,{border:0,margin:0,padding:0,top:0,left:0}),t.appendChild(i),t===document.body&&(i.style.position=\"absolute\",j(t.style,{margin:0,padding:0})),window.addEventListener(\"resize\",n,!1),n(),{canvas:i,onDestroy:function(){window.removeEventListener(\"resize\",n),t.removeChild(i)}}}(i||document.body,0,u)))return null;a=e.canvas,p=e.onDestroy}o=function(t,e){function r(r){try{return t.getContext(r,e)}catch(t){return null}}return r(\"webgl\")||r(\"experimental-webgl\")||r(\"webgl-experimental\")}(a,t)}return o?{gl:o,canvas:a,container:i,extensions:l,optionalExtensions:c,pixelRatio:u,profile:h,onDone:f,onDestroy:p}:(p(),f(\"webgl not supported, try upgrading your browser or graphics drivers http://get.webgl.org\"),null)}function a(t,e){for(var r=Array(t),n=0;n<t;++n)r[n]=e(n);return r}function o(t){var e,r;return e=(65535<t)<<4,e|=r=(255<(t>>>=e))<<3,(e|=r=(15<(t>>>=r))<<2)|(r=(3<(t>>>=r))<<1)|t>>>r>>1}function s(){function t(t){t:{for(var e=16;268435456>=e;e*=16)if(t<=e){t=e;break t}t=0}return 0<(e=r[o(t)>>2]).length?e.pop():new ArrayBuffer(t)}function e(t){r[o(t.byteLength)>>2].push(t)}var r=a(8,function(){return[]});return{alloc:t,free:e,allocType:function(e,r){var n=null;switch(e){case 5120:n=new Int8Array(t(r),0,r);break;case 5121:n=new Uint8Array(t(r),0,r);break;case 5122:n=new Int16Array(t(2*r),0,r);break;case 5123:n=new Uint16Array(t(2*r),0,r);break;case 5124:n=new Int32Array(t(4*r),0,r);break;case 5125:n=new Uint32Array(t(4*r),0,r);break;case 5126:n=new Float32Array(t(4*r),0,r);break;default:return null}return n.length!==r?n.subarray(0,r):n},freeType:function(t){e(t.buffer)}}}function l(t){return!!t&&\"object\"==typeof t&&Array.isArray(t.shape)&&Array.isArray(t.stride)&&\"number\"==typeof t.offset&&t.shape.length===t.stride.length&&(Array.isArray(t.data)||W(t.data))}function c(t,e,r,n,i,a){for(var o=0;o<e;++o)for(var s=t[o],l=0;l<r;++l)for(var c=s[l],u=0;u<n;++u)i[a++]=c[u]}function u(t){return 0|J[Object.prototype.toString.call(t)]}function h(t,e){for(var r=0;r<e.length;++r)t[r]=e[r]}function f(t,e,r,n,i,a,o){for(var s=0,l=0;l<r;++l)for(var c=0;c<n;++c)t[s++]=e[i*l+a*c+o]}function p(t,e,r,n){function i(e){this.id=c++,this.buffer=t.createBuffer(),this.type=e,this.usage=35044,this.byteLength=0,this.dimension=1,this.dtype=5121,this.persistentData=null,r.profile&&(this.stats={size:0})}function a(e,r,n){e.byteLength=r.byteLength,t.bufferData(e.type,r,n)}function o(t,e,r,n,i,o){if(t.usage=r,Array.isArray(e)){if(t.dtype=n||5126,0<e.length)if(Array.isArray(e[0])){i=tt(e);for(var s=n=1;s<i.length;++s)n*=i[s];t.dimension=n,a(t,e=Q(e,i,t.dtype),r),o?t.persistentData=e:G.freeType(e)}else\"number\"==typeof e[0]?(t.dimension=i,h(i=G.allocType(t.dtype,e.length),e),a(t,i,r),o?t.persistentData=i:G.freeType(i)):W(e[0])&&(t.dimension=e[0].length,t.dtype=n||u(e[0])||5126,a(t,e=Q(e,[e.length,e[0].length],t.dtype),r),o?t.persistentData=e:G.freeType(e))}else if(W(e))t.dtype=n||u(e),t.dimension=i,a(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e.buffer)));else if(l(e)){i=e.shape;var c=e.stride,p=(s=e.offset,0),d=0,g=0,v=0;1===i.length?(p=i[0],d=1,g=c[0],v=0):2===i.length&&(p=i[0],d=i[1],g=c[0],v=c[1]),t.dtype=n||u(e.data)||5126,t.dimension=d,f(i=G.allocType(t.dtype,p*d),e.data,p,d,g,v,s),a(t,i,r),o?t.persistentData=i:G.freeType(i)}}function s(r){e.bufferCount--;for(var i=0;i<n.state.length;++i){var a=n.state[i];a.buffer===r&&(t.disableVertexAttribArray(i),a.buffer=null)}t.deleteBuffer(r.buffer),r.buffer=null,delete p[r.id]}var c=0,p={};i.prototype.bind=function(){t.bindBuffer(this.type,this.buffer)},i.prototype.destroy=function(){s(this)};var d=[];return r.profile&&(e.getTotalBufferSize=function(){var t=0;return Object.keys(p).forEach(function(e){t+=p[e].stats.size}),t}),{create:function(n,a,c,d){function g(e){var n=35044,i=null,a=0,s=0,c=1;return Array.isArray(e)||W(e)||l(e)?i=e:\"number\"==typeof e?a=0|e:e&&(\"data\"in e&&(i=e.data),\"usage\"in e&&(n=$[e.usage]),\"type\"in e&&(s=K[e.type]),\"dimension\"in e&&(c=0|e.dimension),\"length\"in e&&(a=0|e.length)),v.bind(),i?o(v,i,n,s,c,d):(a&&t.bufferData(v.type,a,n),v.dtype=s||5121,v.usage=n,v.dimension=c,v.byteLength=a),r.profile&&(v.stats.size=v.byteLength*et[v.dtype]),g}e.bufferCount++;var v=new i(a);return p[v.id]=v,c||g(n),g._reglType=\"buffer\",g._buffer=v,g.subdata=function(e,r){var n,i=0|(r||0);if(v.bind(),W(e))t.bufferSubData(v.type,i,e);else if(Array.isArray(e)){if(0<e.length)if(\"number\"==typeof e[0]){var a=G.allocType(v.dtype,e.length);h(a,e),t.bufferSubData(v.type,i,a),G.freeType(a)}else(Array.isArray(e[0])||W(e[0]))&&(n=tt(e),a=Q(e,n,v.dtype),t.bufferSubData(v.type,i,a),G.freeType(a))}else if(l(e)){n=e.shape;var o=e.stride,s=a=0,c=0,p=0;1===n.length?(a=n[0],s=1,c=o[0],p=0):2===n.length&&(a=n[0],s=n[1],c=o[0],p=o[1]),n=Array.isArray(e.data)?v.dtype:u(e.data),f(n=G.allocType(n,a*s),e.data,a,s,c,p,e.offset),t.bufferSubData(v.type,i,n),G.freeType(n)}return g},r.profile&&(g.stats=v.stats),g.destroy=function(){s(v)},g},createStream:function(t,e){var r=d.pop();return r||(r=new i(t)),r.bind(),o(r,e,35040,0,1,!1),r},destroyStream:function(t){d.push(t)},clear:function(){X(p).forEach(s),d.forEach(s)},getBuffer:function(t){return t&&t._buffer instanceof i?t._buffer:null},restore:function(){X(p).forEach(function(e){e.buffer=t.createBuffer(),t.bindBuffer(e.type,e.buffer),t.bufferData(e.type,e.persistentData||e.byteLength,e.usage)})},_initBuffer:o}}function d(t,e,r,n){function i(t){this.id=c++,s[this.id]=this,this.buffer=t,this.primType=4,this.type=this.vertCount=0}function a(n,i,a,o,s,c,u){if(n.buffer.bind(),i){var h=u;u||W(i)&&(!l(i)||W(i.data))||(h=e.oes_element_index_uint?5125:5123),r._initBuffer(n.buffer,i,a,h,3)}else t.bufferData(34963,c,a),n.buffer.dtype=h||5121,n.buffer.usage=a,n.buffer.dimension=3,n.buffer.byteLength=c;if(h=u,!u){switch(n.buffer.dtype){case 5121:case 5120:h=5121;break;case 5123:case 5122:h=5123;break;case 5125:case 5124:h=5125}n.buffer.dtype=h}n.type=h,0>(i=s)&&(i=n.buffer.byteLength,5123===h?i>>=1:5125===h&&(i>>=2)),n.vertCount=i,i=o,0>o&&(i=4,1===(o=n.buffer.dimension)&&(i=0),2===o&&(i=1),3===o&&(i=4)),n.primType=i}function o(t){n.elementsCount--,delete s[t.id],t.buffer.destroy(),t.buffer=null}var s={},c=0,u={uint8:5121,uint16:5123};e.oes_element_index_uint&&(u.uint32=5125),i.prototype.bind=function(){this.buffer.bind()};var h=[];return{create:function(t,e){function s(t){if(t)if(\"number\"==typeof t)c(t),h.primType=4,h.vertCount=0|t,h.type=5121;else{var e=null,r=35044,n=-1,i=-1,o=0,f=0;Array.isArray(t)||W(t)||l(t)?e=t:(\"data\"in t&&(e=t.data),\"usage\"in t&&(r=$[t.usage]),\"primitive\"in t&&(n=rt[t.primitive]),\"count\"in t&&(i=0|t.count),\"type\"in t&&(f=u[t.type]),\"length\"in t?o=0|t.length:(o=i,5123===f||5122===f?o*=2:5125!==f&&5124!==f||(o*=4))),a(h,e,r,n,i,o,f)}else c(),h.primType=4,h.vertCount=0,h.type=5121;return s}var c=r.create(null,34963,!0),h=new i(c._buffer);return n.elementsCount++,s(t),s._reglType=\"elements\",s._elements=h,s.subdata=function(t,e){return c.subdata(t,e),s},s.destroy=function(){o(h)},s},createStream:function(t){var e=h.pop();return e||(e=new i(r.create(null,34963,!0,!1)._buffer)),a(e,t,35040,-1,-1,0,0),e},destroyStream:function(t){h.push(t)},getElements:function(t){return\"function\"==typeof t&&t._elements instanceof i?t._elements:null},clear:function(){X(s).forEach(o)}}}function g(t){for(var e=G.allocType(5123,t.length),r=0;r<t.length;++r)if(isNaN(t[r]))e[r]=65535;else if(1/0===t[r])e[r]=31744;else if(-1/0===t[r])e[r]=64512;else{nt[0]=t[r];var n=(a=it[0])>>>31<<15,i=(a<<1>>>24)-127,a=a>>13&1023;e[r]=-24>i?n:-14>i?n+(a+1024>>-14-i):15<i?n+31744:n+(i+15<<10)+a}return e}function v(t){return Array.isArray(t)||W(t)}function m(t){return\"[object \"+t+\"]\"}function y(t){return Array.isArray(t)&&(0===t.length||\"number\"==typeof t[0])}function x(t){return!(!Array.isArray(t)||0===t.length||!v(t[0]))}function b(t){return Object.prototype.toString.call(t)}function _(t){if(!t)return!1;var e=b(t);return 0<=pt.indexOf(e)||(y(t)||x(t)||l(t))}function w(t,e){36193===t.type?(t.data=g(e),G.freeType(e)):t.data=e}function k(t,e,r,n,i,a){if(t=\"undefined\"!=typeof gt[t]?gt[t]:st[t]*dt[e],a&&(t*=6),i){for(n=0;1<=r;)n+=t*r*r,r/=2;return n}return t*r*n}function T(t,e,r,n,i,a,o){function s(){this.format=this.internalformat=6408,this.type=5121,this.flipY=this.premultiplyAlpha=this.compressed=!1,this.unpackAlignment=1,this.colorSpace=37444,this.channels=this.height=this.width=0}function c(t,e){t.internalformat=e.internalformat,t.format=e.format,t.type=e.type,t.compressed=e.compressed,t.premultiplyAlpha=e.premultiplyAlpha,t.flipY=e.flipY,t.unpackAlignment=e.unpackAlignment,t.colorSpace=e.colorSpace,t.width=e.width,t.height=e.height,t.channels=e.channels}function u(t,e){if(\"object\"==typeof e&&e){\"premultiplyAlpha\"in e&&(t.premultiplyAlpha=e.premultiplyAlpha),\"flipY\"in e&&(t.flipY=e.flipY),\"alignment\"in e&&(t.unpackAlignment=e.alignment),\"colorSpace\"in e&&(t.colorSpace=q[e.colorSpace]),\"type\"in e&&(t.type=H[e.type]);var r=t.width,n=t.height,i=t.channels,a=!1;\"shape\"in e?(r=e.shape[0],n=e.shape[1],3===e.shape.length&&(i=e.shape[2],a=!0)):(\"radius\"in e&&(r=n=e.radius),\"width\"in e&&(r=e.width),\"height\"in e&&(n=e.height),\"channels\"in e&&(i=e.channels,a=!0)),t.width=0|r,t.height=0|n,t.channels=0|i,r=!1,\"format\"in e&&(r=e.format,n=t.internalformat=Y[r],t.format=pt[n],r in H&&!(\"type\"in e)&&(t.type=H[r]),r in K&&(t.compressed=!0),r=!0),!a&&r?t.channels=st[t.format]:a&&!r&&t.channels!==ot[t.format]&&(t.format=t.internalformat=ot[t.channels])}}function h(e){t.pixelStorei(37440,e.flipY),t.pixelStorei(37441,e.premultiplyAlpha),t.pixelStorei(37443,e.colorSpace),t.pixelStorei(3317,e.unpackAlignment)}function f(){s.call(this),this.yOffset=this.xOffset=0,this.data=null,this.needsFree=!1,this.element=null,this.needsCopy=!1}function p(t,e){var r=null;if(_(e)?r=e:e&&(u(t,e),\"x\"in e&&(t.xOffset=0|e.x),\"y\"in e&&(t.yOffset=0|e.y),_(e.data)&&(r=e.data)),e.copy){var n=i.viewportWidth,a=i.viewportHeight;t.width=t.width||n-t.xOffset,t.height=t.height||a-t.yOffset,t.needsCopy=!0}else if(r){if(W(r))t.channels=t.channels||4,t.data=r,\"type\"in e||5121!==t.type||(t.type=0|J[Object.prototype.toString.call(r)]);else if(y(r)){switch(t.channels=t.channels||4,a=(n=r).length,t.type){case 5121:case 5123:case 5125:case 5126:(a=G.allocType(t.type,a)).set(n),t.data=a;break;case 36193:t.data=g(n)}t.alignment=1,t.needsFree=!0}else if(l(r)){n=r.data,Array.isArray(n)||5121!==t.type||(t.type=0|J[Object.prototype.toString.call(n)]);a=r.shape;var o,s,c,h,f=r.stride;3===a.length?(c=a[2],h=f[2]):h=c=1,o=a[0],s=a[1],a=f[0],f=f[1],t.alignment=1,t.width=o,t.height=s,t.channels=c,t.format=t.internalformat=ot[c],t.needsFree=!0,o=h,r=r.offset,c=t.width,h=t.height,s=t.channels;for(var p=G.allocType(36193===t.type?5126:t.type,c*h*s),d=0,m=0;m<h;++m)for(var k=0;k<c;++k)for(var T=0;T<s;++T)p[d++]=n[a*k+f*m+o*T+r];w(t,p)}else if(b(r)===lt||b(r)===ct)b(r)===lt?t.element=r:t.element=r.canvas,t.width=t.element.width,t.height=t.element.height,t.channels=4;else if(b(r)===ut)t.element=r,t.width=r.width,t.height=r.height,t.channels=4;else if(b(r)===ht)t.element=r,t.width=r.naturalWidth,t.height=r.naturalHeight,t.channels=4;else if(b(r)===ft)t.element=r,t.width=r.videoWidth,t.height=r.videoHeight,t.channels=4;else if(x(r)){for(n=t.width||r[0].length,a=t.height||r.length,f=t.channels,f=v(r[0][0])?f||r[0][0].length:f||1,o=Z.shape(r),c=1,h=0;h<o.length;++h)c*=o[h];c=G.allocType(36193===t.type?5126:t.type,c),Z.flatten(r,o,\"\",c),w(t,c),t.alignment=1,t.width=n,t.height=a,t.channels=f,t.format=t.internalformat=ot[f],t.needsFree=!0}}else t.width=t.width||1,t.height=t.height||1,t.channels=t.channels||4}function d(e,r,i,a,o){var s=e.element,l=e.data,c=e.internalformat,u=e.format,f=e.type,p=e.width,d=e.height;h(e),s?t.texSubImage2D(r,o,i,a,u,f,s):e.compressed?t.compressedTexSubImage2D(r,o,i,a,c,p,d,l):e.needsCopy?(n(),t.copyTexSubImage2D(r,o,i,a,e.xOffset,e.yOffset,p,d)):t.texSubImage2D(r,o,i,a,p,d,u,f,l)}function m(){return dt.pop()||new f}function T(t){t.needsFree&&G.freeType(t.data),f.call(t),dt.push(t)}function A(){s.call(this),this.genMipmaps=!1,this.mipmapHint=4352,this.mipmask=0,this.images=Array(16)}function M(t,e,r){var n=t.images[0]=m();t.mipmask=1,n.width=t.width=e,n.height=t.height=r,n.channels=t.channels=4}function S(t,e){var r=null;if(_(e))c(r=t.images[0]=m(),t),p(r,e),t.mipmask=1;else if(u(t,e),Array.isArray(e.mipmap))for(var n=e.mipmap,i=0;i<n.length;++i)c(r=t.images[i]=m(),t),r.width>>=i,r.height>>=i,p(r,n[i]),t.mipmask|=1<<i;else c(r=t.images[0]=m(),t),p(r,e),t.mipmask=1;c(t,t.images[0])}function E(e,r){for(var i=e.images,a=0;a<i.length&&i[a];++a){var o=i[a],s=r,l=a,c=o.element,u=o.data,f=o.internalformat,p=o.format,d=o.type,g=o.width,v=o.height,m=o.channels;h(o),c?t.texImage2D(s,l,p,p,d,c):o.compressed?t.compressedTexImage2D(s,l,f,g,v,0,u):o.needsCopy?(n(),t.copyTexImage2D(s,l,p,o.xOffset,o.yOffset,g,v,0)):((o=!u)&&(u=G.zero.allocType(d,g*v*m)),t.texImage2D(s,l,p,g,v,0,p,d,u),o&&u&&G.zero.freeType(u))}}function C(){var t=gt.pop()||new A;s.call(t);for(var e=t.mipmask=0;16>e;++e)t.images[e]=null;return t}function L(t){for(var e=t.images,r=0;r<e.length;++r)e[r]&&T(e[r]),e[r]=null;gt.push(t)}function P(){this.magFilter=this.minFilter=9728,this.wrapT=this.wrapS=33071,this.anisotropic=1,this.genMipmaps=!1,this.mipmapHint=4352}function O(t,e){\"min\"in e&&(t.minFilter=V[e.min],0<=at.indexOf(t.minFilter)&&!(\"faces\"in e)&&(t.genMipmaps=!0)),\"mag\"in e&&(t.magFilter=U[e.mag]);var r=t.wrapS,n=t.wrapT;if(\"wrap\"in e){var i=e.wrap;\"string\"==typeof i?r=n=N[i]:Array.isArray(i)&&(r=N[i[0]],n=N[i[1]])}else\"wrapS\"in e&&(r=N[e.wrapS]),\"wrapT\"in e&&(n=N[e.wrapT]);if(t.wrapS=r,t.wrapT=n,\"anisotropic\"in e&&(t.anisotropic=e.anisotropic),\"mipmap\"in e){switch(r=!1,typeof e.mipmap){case\"string\":t.mipmapHint=B[e.mipmap],r=t.genMipmaps=!0;break;case\"boolean\":r=t.genMipmaps=e.mipmap;break;case\"object\":t.genMipmaps=!1,r=!0}!r||\"min\"in e||(t.minFilter=9984)}}function z(r,n){t.texParameteri(n,10241,r.minFilter),t.texParameteri(n,10240,r.magFilter),t.texParameteri(n,10242,r.wrapS),t.texParameteri(n,10243,r.wrapT),e.ext_texture_filter_anisotropic&&t.texParameteri(n,34046,r.anisotropic),r.genMipmaps&&(t.hint(33170,r.mipmapHint),t.generateMipmap(n))}function I(e){s.call(this),this.mipmask=0,this.internalformat=6408,this.id=vt++,this.refCount=1,this.target=e,this.texture=t.createTexture(),this.unit=-1,this.bindCount=0,this.texInfo=new P,o.profile&&(this.stats={size:0})}function D(e){t.activeTexture(33984),t.bindTexture(e.target,e.texture)}function R(){var e=xt[0];e?t.bindTexture(e.target,e.texture):t.bindTexture(3553,null)}function F(e){var r=e.texture,n=e.unit,i=e.target;0<=n&&(t.activeTexture(33984+n),t.bindTexture(i,null),xt[n]=null),t.deleteTexture(r),e.texture=null,e.params=null,e.pixels=null,e.refCount=0,delete mt[e.id],a.textureCount--}var B={\"don't care\":4352,\"dont care\":4352,nice:4354,fast:4353},N={repeat:10497,clamp:33071,mirror:33648},U={nearest:9728,linear:9729},V=j({mipmap:9987,\"nearest mipmap nearest\":9984,\"linear mipmap nearest\":9985,\"nearest mipmap linear\":9986,\"linear mipmap linear\":9987},U),q={none:0,browser:37444},H={uint8:5121,rgba4:32819,rgb565:33635,\"rgb5 a1\":32820},Y={alpha:6406,luminance:6409,\"luminance alpha\":6410,rgb:6407,rgba:6408,rgba4:32854,\"rgb5 a1\":32855,rgb565:36194},K={};e.ext_srgb&&(Y.srgb=35904,Y.srgba=35906),e.oes_texture_float&&(H.float32=H.float=5126),e.oes_texture_half_float&&(H.float16=H[\"half float\"]=36193),e.webgl_depth_texture&&(j(Y,{depth:6402,\"depth stencil\":34041}),j(H,{uint16:5123,uint32:5125,\"depth stencil\":34042})),e.webgl_compressed_texture_s3tc&&j(K,{\"rgb s3tc dxt1\":33776,\"rgba s3tc dxt1\":33777,\"rgba s3tc dxt3\":33778,\"rgba s3tc dxt5\":33779}),e.webgl_compressed_texture_atc&&j(K,{\"rgb atc\":35986,\"rgba atc explicit alpha\":35987,\"rgba atc interpolated alpha\":34798}),e.webgl_compressed_texture_pvrtc&&j(K,{\"rgb pvrtc 4bppv1\":35840,\"rgb pvrtc 2bppv1\":35841,\"rgba pvrtc 4bppv1\":35842,\"rgba pvrtc 2bppv1\":35843}),e.webgl_compressed_texture_etc1&&(K[\"rgb etc1\"]=36196);var $=Array.prototype.slice.call(t.getParameter(34467));Object.keys(K).forEach(function(t){var e=K[t];0<=$.indexOf(e)&&(Y[t]=e)});var Q=Object.keys(Y);r.textureFormats=Q;var tt=[];Object.keys(Y).forEach(function(t){tt[Y[t]]=t});var et=[];Object.keys(H).forEach(function(t){et[H[t]]=t});var rt=[];Object.keys(U).forEach(function(t){rt[U[t]]=t});var nt=[];Object.keys(V).forEach(function(t){nt[V[t]]=t});var it=[];Object.keys(N).forEach(function(t){it[N[t]]=t});var pt=Q.reduce(function(t,e){var r=Y[e];return 6409===r||6406===r||6409===r||6410===r||6402===r||34041===r?t[r]=r:32855===r||0<=e.indexOf(\"rgba\")?t[r]=6408:t[r]=6407,t},{}),dt=[],gt=[],vt=0,mt={},yt=r.maxTextureUnits,xt=Array(yt).map(function(){return null});return j(I.prototype,{bind:function(){this.bindCount+=1;var e=this.unit;if(0>e){for(var r=0;r<yt;++r){var n=xt[r];if(n){if(0<n.bindCount)continue;n.unit=-1}xt[r]=this,e=r;break}o.profile&&a.maxTextureUnits<e+1&&(a.maxTextureUnits=e+1),this.unit=e,t.activeTexture(33984+e),t.bindTexture(this.target,this.texture)}return e},unbind:function(){--this.bindCount},decRef:function(){0>=--this.refCount&&F(this)}}),o.profile&&(a.getTotalTextureSize=function(){var t=0;return Object.keys(mt).forEach(function(e){t+=mt[e].stats.size}),t}),{create2D:function(e,r){function n(t,e){var r=i.texInfo;P.call(r);var a=C();return\"number\"==typeof t?M(a,0|t,\"number\"==typeof e?0|e:0|t):t?(O(r,t),S(a,t)):M(a,1,1),r.genMipmaps&&(a.mipmask=(a.width<<1)-1),i.mipmask=a.mipmask,c(i,a),i.internalformat=a.internalformat,n.width=a.width,n.height=a.height,D(i),E(a,3553),z(r,3553),R(),L(a),o.profile&&(i.stats.size=k(i.internalformat,i.type,a.width,a.height,r.genMipmaps,!1)),n.format=tt[i.internalformat],n.type=et[i.type],n.mag=rt[r.magFilter],n.min=nt[r.minFilter],n.wrapS=it[r.wrapS],n.wrapT=it[r.wrapT],n}var i=new I(3553);return mt[i.id]=i,a.textureCount++,n(e,r),n.subimage=function(t,e,r,a){e|=0,r|=0,a|=0;var o=m();return c(o,i),o.width=0,o.height=0,p(o,t),o.width=o.width||(i.width>>a)-e,o.height=o.height||(i.height>>a)-r,D(i),d(o,3553,e,r,a),R(),T(o),n},n.resize=function(e,r){var a=0|e,s=0|r||a;if(a===i.width&&s===i.height)return n;n.width=i.width=a,n.height=i.height=s,D(i);for(var l,c=i.channels,u=i.type,h=0;i.mipmask>>h;++h){var f=a>>h,p=s>>h;if(!f||!p)break;l=G.zero.allocType(u,f*p*c),t.texImage2D(3553,h,i.format,f,p,0,i.format,i.type,l),l&&G.zero.freeType(l)}return R(),o.profile&&(i.stats.size=k(i.internalformat,i.type,a,s,!1,!1)),n},n._reglType=\"texture2d\",n._texture=i,o.profile&&(n.stats=i.stats),n.destroy=function(){i.decRef()},n},createCube:function(e,r,n,i,s,l){function h(t,e,r,n,i,a){var s,l=f.texInfo;for(P.call(l),s=0;6>s;++s)g[s]=C();if(\"number\"!=typeof t&&t){if(\"object\"==typeof t)if(e)S(g[0],t),S(g[1],e),S(g[2],r),S(g[3],n),S(g[4],i),S(g[5],a);else if(O(l,t),u(f,t),\"faces\"in t)for(t=t.faces,s=0;6>s;++s)c(g[s],f),S(g[s],t[s]);else for(s=0;6>s;++s)S(g[s],t)}else for(t=0|t||1,s=0;6>s;++s)M(g[s],t,t);for(c(f,g[0]),f.mipmask=l.genMipmaps?(g[0].width<<1)-1:g[0].mipmask,f.internalformat=g[0].internalformat,h.width=g[0].width,h.height=g[0].height,D(f),s=0;6>s;++s)E(g[s],34069+s);for(z(l,34067),R(),o.profile&&(f.stats.size=k(f.internalformat,f.type,h.width,h.height,l.genMipmaps,!0)),h.format=tt[f.internalformat],h.type=et[f.type],h.mag=rt[l.magFilter],h.min=nt[l.minFilter],h.wrapS=it[l.wrapS],h.wrapT=it[l.wrapT],s=0;6>s;++s)L(g[s]);return h}var f=new I(34067);mt[f.id]=f,a.cubeCount++;var g=Array(6);return h(e,r,n,i,s,l),h.subimage=function(t,e,r,n,i){r|=0,n|=0,i|=0;var a=m();return c(a,f),a.width=0,a.height=0,p(a,e),a.width=a.width||(f.width>>i)-r,a.height=a.height||(f.height>>i)-n,D(f),d(a,34069+t,r,n,i),R(),T(a),h},h.resize=function(e){if((e|=0)!==f.width){h.width=f.width=e,h.height=f.height=e,D(f);for(var r=0;6>r;++r)for(var n=0;f.mipmask>>n;++n)t.texImage2D(34069+r,n,f.format,e>>n,e>>n,0,f.format,f.type,null);return R(),o.profile&&(f.stats.size=k(f.internalformat,f.type,h.width,h.height,!1,!0)),h}},h._reglType=\"textureCube\",h._texture=f,o.profile&&(h.stats=f.stats),h.destroy=function(){f.decRef()},h},clear:function(){for(var e=0;e<yt;++e)t.activeTexture(33984+e),t.bindTexture(3553,null),xt[e]=null;X(mt).forEach(F),a.cubeCount=0,a.textureCount=0},getTexture:function(t){return null},restore:function(){for(var e=0;e<yt;++e){var r=xt[e];r&&(r.bindCount=0,r.unit=-1,xt[e]=null)}X(mt).forEach(function(e){e.texture=t.createTexture(),t.bindTexture(e.target,e.texture);for(var r=0;32>r;++r)if(0!=(e.mipmask&1<<r))if(3553===e.target)t.texImage2D(3553,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);else for(var n=0;6>n;++n)t.texImage2D(34069+n,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);z(e.texInfo,e.target)})}}}function A(t,e,r,n,i,a){function o(t,e,r){this.target=t,this.texture=e,this.renderbuffer=r;var n=t=0;e?(t=e.width,n=e.height):r&&(t=r.width,n=r.height),this.width=t,this.height=n}function s(t){t&&(t.texture&&t.texture._texture.decRef(),t.renderbuffer&&t.renderbuffer._renderbuffer.decRef())}function l(t,e,r){t&&(t.texture?t.texture._texture.refCount+=1:t.renderbuffer._renderbuffer.refCount+=1)}function c(e,r){r&&(r.texture?t.framebufferTexture2D(36160,e,r.target,r.texture._texture.texture,0):t.framebufferRenderbuffer(36160,e,36161,r.renderbuffer._renderbuffer.renderbuffer))}function u(t){var e=3553,r=null,n=null,i=t;return\"object\"==typeof t&&(i=t.data,\"target\"in t&&(e=0|t.target)),\"texture2d\"===(t=i._reglType)?r=i:\"textureCube\"===t?r=i:\"renderbuffer\"===t&&(n=i,e=36161),new o(e,r,n)}function h(t,e,r,a,s){return r?((t=n.create2D({width:t,height:e,format:a,type:s}))._texture.refCount=0,new o(3553,t,null)):((t=i.create({width:t,height:e,format:a}))._renderbuffer.refCount=0,new o(36161,null,t))}function f(t){return t&&(t.texture||t.renderbuffer)}function p(t,e,r){t&&(t.texture?t.texture.resize(e,r):t.renderbuffer&&t.renderbuffer.resize(e,r),t.width=e,t.height=r)}function d(){this.id=k++,T[this.id]=this,this.framebuffer=t.createFramebuffer(),this.height=this.width=0,this.colorAttachments=[],this.depthStencilAttachment=this.stencilAttachment=this.depthAttachment=null}function g(t){t.colorAttachments.forEach(s),s(t.depthAttachment),s(t.stencilAttachment),s(t.depthStencilAttachment)}function v(e){t.deleteFramebuffer(e.framebuffer),e.framebuffer=null,a.framebufferCount--,delete T[e.id]}function m(e){var n;t.bindFramebuffer(36160,e.framebuffer);var i=e.colorAttachments;for(n=0;n<i.length;++n)c(36064+n,i[n]);for(n=i.length;n<r.maxColorAttachments;++n)t.framebufferTexture2D(36160,36064+n,3553,null,0);t.framebufferTexture2D(36160,33306,3553,null,0),t.framebufferTexture2D(36160,36096,3553,null,0),t.framebufferTexture2D(36160,36128,3553,null,0),c(36096,e.depthAttachment),c(36128,e.stencilAttachment),c(33306,e.depthStencilAttachment),t.checkFramebufferStatus(36160),t.isContextLost(),t.bindFramebuffer(36160,x.next?x.next.framebuffer:null),x.cur=x.next,t.getError()}function y(t,e){function r(t,e){var i,a=0,o=0,s=!0,c=!0;i=null;var p=!0,d=\"rgba\",v=\"uint8\",y=1,x=null,w=null,k=null,T=!1;\"number\"==typeof t?(a=0|t,o=0|e||a):t?(\"shape\"in t?(a=(o=t.shape)[0],o=o[1]):(\"radius\"in t&&(a=o=t.radius),\"width\"in t&&(a=t.width),\"height\"in t&&(o=t.height)),(\"color\"in t||\"colors\"in t)&&(i=t.color||t.colors,Array.isArray(i)),i||(\"colorCount\"in t&&(y=0|t.colorCount),\"colorTexture\"in t&&(p=!!t.colorTexture,d=\"rgba4\"),\"colorType\"in t&&(v=t.colorType,!p)&&(\"half float\"===v||\"float16\"===v?d=\"rgba16f\":\"float\"!==v&&\"float32\"!==v||(d=\"rgba32f\")),\"colorFormat\"in t&&(d=t.colorFormat,0<=b.indexOf(d)?p=!0:0<=_.indexOf(d)&&(p=!1))),(\"depthTexture\"in t||\"depthStencilTexture\"in t)&&(T=!(!t.depthTexture&&!t.depthStencilTexture)),\"depth\"in t&&(\"boolean\"==typeof t.depth?s=t.depth:(x=t.depth,c=!1)),\"stencil\"in t&&(\"boolean\"==typeof t.stencil?c=t.stencil:(w=t.stencil,s=!1)),\"depthStencil\"in t&&(\"boolean\"==typeof t.depthStencil?s=c=t.depthStencil:(k=t.depthStencil,c=s=!1))):a=o=1;var A=null,M=null,S=null,E=null;if(Array.isArray(i))A=i.map(u);else if(i)A=[u(i)];else for(A=Array(y),i=0;i<y;++i)A[i]=h(a,o,p,d,v);for(a=a||A[0].width,o=o||A[0].height,x?M=u(x):s&&!c&&(M=h(a,o,T,\"depth\",\"uint32\")),w?S=u(w):c&&!s&&(S=h(a,o,!1,\"stencil\",\"uint8\")),k?E=u(k):!x&&!w&&c&&s&&(E=h(a,o,T,\"depth stencil\",\"depth stencil\")),s=null,i=0;i<A.length;++i)l(A[i]),A[i]&&A[i].texture&&(c=yt[A[i].texture._texture.format]*xt[A[i].texture._texture.type],null===s&&(s=c));return l(M),l(S),l(E),g(n),n.width=a,n.height=o,n.colorAttachments=A,n.depthAttachment=M,n.stencilAttachment=S,n.depthStencilAttachment=E,r.color=A.map(f),r.depth=f(M),r.stencil=f(S),r.depthStencil=f(E),r.width=n.width,r.height=n.height,m(n),r}var n=new d;return a.framebufferCount++,r(t,e),j(r,{resize:function(t,e){var i=Math.max(0|t,1),a=Math.max(0|e||i,1);if(i===n.width&&a===n.height)return r;for(var o=n.colorAttachments,s=0;s<o.length;++s)p(o[s],i,a);return p(n.depthAttachment,i,a),p(n.stencilAttachment,i,a),p(n.depthStencilAttachment,i,a),n.width=r.width=i,n.height=r.height=a,m(n),r},_reglType:\"framebuffer\",_framebuffer:n,destroy:function(){v(n),g(n)},use:function(t){x.setFBO({framebuffer:r},t)}})}var x={cur:null,next:null,dirty:!1,setFBO:null},b=[\"rgba\"],_=[\"rgba4\",\"rgb565\",\"rgb5 a1\"];e.ext_srgb&&_.push(\"srgba\"),e.ext_color_buffer_half_float&&_.push(\"rgba16f\",\"rgb16f\"),e.webgl_color_buffer_float&&_.push(\"rgba32f\");var w=[\"uint8\"];e.oes_texture_half_float&&w.push(\"half float\",\"float16\"),e.oes_texture_float&&w.push(\"float\",\"float32\");var k=0,T={};return j(x,{getFramebuffer:function(t){return\"function\"==typeof t&&\"framebuffer\"===t._reglType&&(t=t._framebuffer)instanceof d?t:null},create:y,createCube:function(t){function e(t){var i,a={color:null},o=0,s=null;i=\"rgba\";var l=\"uint8\",c=1;if(\"number\"==typeof t?o=0|t:t?(\"shape\"in t?o=t.shape[0]:(\"radius\"in t&&(o=0|t.radius),\"width\"in t?o=0|t.width:\"height\"in t&&(o=0|t.height)),(\"color\"in t||\"colors\"in t)&&(s=t.color||t.colors,Array.isArray(s)),s||(\"colorCount\"in t&&(c=0|t.colorCount),\"colorType\"in t&&(l=t.colorType),\"colorFormat\"in t&&(i=t.colorFormat)),\"depth\"in t&&(a.depth=t.depth),\"stencil\"in t&&(a.stencil=t.stencil),\"depthStencil\"in t&&(a.depthStencil=t.depthStencil)):o=1,s)if(Array.isArray(s))for(t=[],i=0;i<s.length;++i)t[i]=s[i];else t=[s];else for(t=Array(c),s={radius:o,format:i,type:l},i=0;i<c;++i)t[i]=n.createCube(s);for(a.color=Array(t.length),i=0;i<t.length;++i)c=t[i],o=o||c.width,a.color[i]={target:34069,data:t[i]};for(i=0;6>i;++i){for(c=0;c<t.length;++c)a.color[c].target=34069+i;0<i&&(a.depth=r[0].depth,a.stencil=r[0].stencil,a.depthStencil=r[0].depthStencil),r[i]?r[i](a):r[i]=y(a)}return j(e,{width:o,height:o,color:t})}var r=Array(6);return e(t),j(e,{faces:r,resize:function(t){var n=0|t;if(n===e.width)return e;var i=e.color;for(t=0;t<i.length;++t)i[t].resize(n);for(t=0;6>t;++t)r[t].resize(n);return e.width=e.height=n,e},_reglType:\"framebufferCube\",destroy:function(){r.forEach(function(t){t.destroy()})}})},clear:function(){X(T).forEach(v)},restore:function(){x.cur=null,x.next=null,x.dirty=!0,X(T).forEach(function(e){e.framebuffer=t.createFramebuffer(),m(e)})}})}function M(){this.w=this.z=this.y=this.x=this.state=0,this.buffer=null,this.size=0,this.normalized=!1,this.type=5126,this.divisor=this.stride=this.offset=0}function S(t,e,r,n){function i(t,e,r,n){this.name=t,this.id=e,this.location=r,this.info=n}function a(t,e){for(var r=0;r<t.length;++r)if(t[r].id===e.id)return void(t[r].location=e.location);t.push(e)}function o(r,n,i){if(!(o=(i=35632===r?c:u)[n])){var a=e.str(n),o=t.createShader(r);t.shaderSource(o,a),t.compileShader(o),i[n]=o}return o}function s(t,e){this.id=p++,this.fragId=t,this.vertId=e,this.program=null,this.uniforms=[],this.attributes=[],n.profile&&(this.stats={uniformsCount:0,attributesCount:0})}function l(r,s){var l,c;l=o(35632,r.fragId),c=o(35633,r.vertId);var u=r.program=t.createProgram();t.attachShader(u,l),t.attachShader(u,c),t.linkProgram(u);var h=t.getProgramParameter(u,35718);n.profile&&(r.stats.uniformsCount=h);var f=r.uniforms;for(l=0;l<h;++l)if(c=t.getActiveUniform(u,l))if(1<c.size)for(var p=0;p<c.size;++p){var d=c.name.replace(\"[0]\",\"[\"+p+\"]\");a(f,new i(d,e.id(d),t.getUniformLocation(u,d),c))}else a(f,new i(c.name,e.id(c.name),t.getUniformLocation(u,c.name),c));for(h=t.getProgramParameter(u,35721),n.profile&&(r.stats.attributesCount=h),f=r.attributes,l=0;l<h;++l)(c=t.getActiveAttrib(u,l))&&a(f,new i(c.name,e.id(c.name),t.getAttribLocation(u,c.name),c))}var c={},u={},h={},f=[],p=0;return n.profile&&(r.getMaxUniformsCount=function(){var t=0;return f.forEach(function(e){e.stats.uniformsCount>t&&(t=e.stats.uniformsCount)}),t},r.getMaxAttributesCount=function(){var t=0;return f.forEach(function(e){e.stats.attributesCount>t&&(t=e.stats.attributesCount)}),t}),{clear:function(){var e=t.deleteShader.bind(t);X(c).forEach(e),c={},X(u).forEach(e),u={},f.forEach(function(e){t.deleteProgram(e.program)}),f.length=0,h={},r.shaderCount=0},program:function(t,e,n){var i=h[e];i||(i=h[e]={});var a=i[t];return a||(a=new s(e,t),r.shaderCount++,l(a),i[t]=a,f.push(a)),a},restore:function(){c={},u={};for(var t=0;t<f.length;++t)l(f[t])},shader:o,frag:-1,vert:-1}}function E(t,e,r,n,i,a,o){function s(i){var a;a=null===e.next?5121:e.next.colorAttachments[0].texture._texture.type;var o=0,s=0,l=n.framebufferWidth,c=n.framebufferHeight,u=null;return W(i)?u=i:i&&(o=0|i.x,s=0|i.y,l=0|(i.width||n.framebufferWidth-o),c=0|(i.height||n.framebufferHeight-s),u=i.data||null),r(),i=l*c*4,u||(5121===a?u=new Uint8Array(i):5126===a&&(u=u||new Float32Array(i))),t.pixelStorei(3333,4),t.readPixels(o,s,l,c,6408,a,u),u}return function(t){return t&&\"framebuffer\"in t?function(t){var r;return e.setFBO({framebuffer:t.framebuffer},function(){r=s(t)}),r}(t):s(t)}}function C(t){return Array.prototype.slice.call(t)}function L(t){return C(t).join(\"\")}function P(){function t(){var t=[],e=[];return j(function(){t.push.apply(t,C(arguments))},{def:function(){var n=\"v\"+r++;return e.push(n),0<arguments.length&&(t.push(n,\"=\"),t.push.apply(t,C(arguments)),t.push(\";\")),n},toString:function(){return L([0<e.length?\"var \"+e+\";\":\"\",L(t)])}})}function e(){function e(t,e){n(t,e,\"=\",r.def(t,e),\";\")}var r=t(),n=t(),i=r.toString,a=n.toString;return j(function(){r.apply(r,C(arguments))},{def:r.def,entry:r,exit:n,save:e,set:function(t,n,i){e(t,n),r(t,n,\"=\",i,\";\")},toString:function(){return i()+a()}})}var r=0,n=[],i=[],a=t(),o={};return{global:a,link:function(t){for(var e=0;e<i.length;++e)if(i[e]===t)return n[e];return e=\"g\"+r++,n.push(e),i.push(t),e},block:t,proc:function(t,r){function n(){var t=\"a\"+i.length;return i.push(t),t}var i=[];r=r||0;for(var a=0;a<r;++a)n();var s=(a=e()).toString;return o[t]=j(a,{arg:n,toString:function(){return L([\"function(\",i.join(),\"){\",s(),\"}\"])}})},scope:e,cond:function(){var t=L(arguments),r=e(),n=e(),i=r.toString,a=n.toString;return j(r,{then:function(){return r.apply(r,C(arguments)),this},else:function(){return n.apply(n,C(arguments)),this},toString:function(){var e=a();return e&&(e=\"else{\"+e+\"}\"),L([\"if(\",t,\"){\",i(),\"}\",e])}})},compile:function(){var t=['\"use strict\";',a,\"return {\"];Object.keys(o).forEach(function(e){t.push('\"',e,'\":',o[e].toString(),\",\")}),t.push(\"}\");var e=L(t).replace(/;/g,\";\\n\").replace(/}/g,\"}\\n\").replace(/{/g,\"{\\n\");return Function.apply(null,n.concat(e)).apply(null,i)}}}function O(t){return Array.isArray(t)||W(t)||l(t)}function z(t){return t.sort(function(t,e){return\"viewport\"===t?-1:\"viewport\"===e?1:t<e?-1:1})}function I(t,e,r,n){this.thisDep=t,this.contextDep=e,this.propDep=r,this.append=n}function D(t){return t&&!(t.thisDep||t.contextDep||t.propDep)}function R(t){return new I(!1,!1,!1,t)}function F(t,e){var r=t.type;return 0===r?new I(!0,1<=(r=t.data.length),2<=r,e):4===r?new I((r=t.data).thisDep,r.contextDep,r.propDep,e):new I(3===r,2===r,1===r,e)}function B(t,e,r,n,i,o,s,l,c,u,h,f,p,d,g){function m(t){return t.replace(\".\",\"_\")}function y(t,e,r){var n=m(t);nt.push(t),et[n]=tt[n]=!!r,it[n]=e}function x(t,e,r){var n=m(t);nt.push(t),Array.isArray(r)?(tt[n]=r.slice(),et[n]=r.slice()):tt[n]=et[n]=r,at[n]=e}function b(){var t=P(),r=t.link,n=t.global;t.id=lt++,t.batchId=\"0\";var i=r(ot),a=t.shared={props:\"a0\"};Object.keys(ot).forEach(function(t){a[t]=n.def(i,\".\",t)});var o=t.next={},s=t.current={};Object.keys(at).forEach(function(t){Array.isArray(tt[t])&&(o[t]=n.def(a.next,\".\",t),s[t]=n.def(a.current,\".\",t))});var l=t.constants={};Object.keys(st).forEach(function(t){l[t]=n.def(JSON.stringify(st[t]))}),t.invoke=function(e,n){switch(n.type){case 0:var i=[\"this\",a.context,a.props,t.batchId];return e.def(r(n.data),\".call(\",i.slice(0,Math.max(n.data.length+1,4)),\")\");case 1:return e.def(a.props,n.data);case 2:return e.def(a.context,n.data);case 3:return e.def(\"this\",n.data);case 4:return n.data.append(t,e),n.data.ref}},t.attribCache={};var c={};return t.scopeAttrib=function(t){if((t=e.id(t))in c)return c[t];var n=u.scope[t];return n||(n=u.scope[t]=new Z),c[t]=r(n)},t}function _(t,e){var r=t.static,n=t.dynamic;if(\"framebuffer\"in r){var i=r.framebuffer;return i?(i=l.getFramebuffer(i),R(function(t,e){var r=t.link(i),n=t.shared;return e.set(n.framebuffer,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\".width\"),e.set(n,\".framebufferHeight\",r+\".height\"),r})):R(function(t,e){var r=t.shared;return e.set(r.framebuffer,\".next\",\"null\"),r=r.context,e.set(r,\".framebufferWidth\",r+\".drawingBufferWidth\"),e.set(r,\".framebufferHeight\",r+\".drawingBufferHeight\"),\"null\"})}if(\"framebuffer\"in n){var a=n.framebuffer;return F(a,function(t,e){var r=t.invoke(e,a),n=t.shared,i=n.framebuffer;r=e.def(i,\".getFramebuffer(\",r,\")\");return e.set(i,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\"?\"+r+\".width:\"+n+\".drawingBufferWidth\"),e.set(n,\".framebufferHeight\",r+\"?\"+r+\".height:\"+n+\".drawingBufferHeight\"),r})}return null}function w(t){function r(t){if(t in n){var r=e.id(n[t]);return(t=R(function(){return r})).id=r,t}if(t in i){var a=i[t];return F(a,function(t,e){var r=t.invoke(e,a);return e.def(t.shared.strings,\".id(\",r,\")\")})}return null}var n=t.static,i=t.dynamic,a=r(\"frag\"),o=r(\"vert\"),s=null;return D(a)&&D(o)?(s=h.program(o.id,a.id),t=R(function(t,e){return t.link(s)})):t=new I(a&&a.thisDep||o&&o.thisDep,a&&a.contextDep||o&&o.contextDep,a&&a.propDep||o&&o.propDep,function(t,e){var r,n,i=t.shared.shader;return r=a?a.append(t,e):e.def(i,\".\",\"frag\"),n=o?o.append(t,e):e.def(i,\".\",\"vert\"),e.def(i+\".program(\"+n+\",\"+r+\")\")}),{frag:a,vert:o,progVar:t,program:s}}function k(t,e){function r(t,e){if(t in n){var r=0|n[t];return R(function(t,n){return e&&(t.OFFSET=r),r})}if(t in i){var o=i[t];return F(o,function(t,r){var n=t.invoke(r,o);return e&&(t.OFFSET=n),n})}return e&&a?R(function(t,e){return t.OFFSET=\"0\",0}):null}var n=t.static,i=t.dynamic,a=function(){if(\"elements\"in n){var t=n.elements;O(t)?t=o.getElements(o.create(t,!0)):t&&(t=o.getElements(t));var e=R(function(e,r){if(t){var n=e.link(t);return e.ELEMENTS=n}return e.ELEMENTS=null});return e.value=t,e}if(\"elements\"in i){var r=i.elements;return F(r,function(t,e){var n=(i=t.shared).isBufferArgs,i=i.elements,a=t.invoke(e,r),o=e.def(\"null\");n=e.def(n,\"(\",a,\")\"),a=t.cond(n).then(o,\"=\",i,\".createStream(\",a,\");\").else(o,\"=\",i,\".getElements(\",a,\");\");return e.entry(a),e.exit(t.cond(n).then(i,\".destroyStream(\",o,\");\")),t.ELEMENTS=o})}return null}(),s=r(\"offset\",!0);return{elements:a,primitive:function(){if(\"primitive\"in n){var t=n.primitive;return R(function(e,r){return rt[t]})}if(\"primitive\"in i){var e=i.primitive;return F(e,function(t,r){var n=t.constants.primTypes,i=t.invoke(r,e);return r.def(n,\"[\",i,\"]\")})}return a?D(a)?a.value?R(function(t,e){return e.def(t.ELEMENTS,\".primType\")}):R(function(){return 4}):new I(a.thisDep,a.contextDep,a.propDep,function(t,e){var r=t.ELEMENTS;return e.def(r,\"?\",r,\".primType:\",4)}):null}(),count:function(){if(\"count\"in n){var t=0|n.count;return R(function(){return t})}if(\"count\"in i){var e=i.count;return F(e,function(t,r){return t.invoke(r,e)})}return a?D(a)?a?s?new I(s.thisDep,s.contextDep,s.propDep,function(t,e){return e.def(t.ELEMENTS,\".vertCount-\",t.OFFSET)}):R(function(t,e){return e.def(t.ELEMENTS,\".vertCount\")}):R(function(){return-1}):new I(a.thisDep||s.thisDep,a.contextDep||s.contextDep,a.propDep||s.propDep,function(t,e){var r=t.ELEMENTS;return t.OFFSET?e.def(r,\"?\",r,\".vertCount-\",t.OFFSET,\":-1\"):e.def(r,\"?\",r,\".vertCount:-1\")}):null}(),instances:r(\"instances\",!1),offset:s}}function T(t,r){var n=t.static,a=t.dynamic,o={};return Object.keys(n).forEach(function(t){var r=n[t],a=e.id(t),s=new Z;if(O(r))s.state=1,s.buffer=i.getBuffer(i.create(r,34962,!1,!0)),s.type=0;else if(c=i.getBuffer(r))s.state=1,s.buffer=c,s.type=0;else if(\"constant\"in r){var l=r.constant;s.buffer=\"null\",s.state=2,\"number\"==typeof l?s.x=l:bt.forEach(function(t,e){e<l.length&&(s[t]=l[e])})}else{var c=O(r.buffer)?i.getBuffer(i.create(r.buffer,34962,!1,!0)):i.getBuffer(r.buffer),u=0|r.offset,h=0|r.stride,f=0|r.size,p=!!r.normalized,d=0;\"type\"in r&&(d=K[r.type]),r=0|r.divisor,s.buffer=c,s.state=1,s.size=f,s.normalized=p,s.type=d||c.dtype,s.offset=u,s.stride=h,s.divisor=r}o[t]=R(function(t,e){var r=t.attribCache;if(a in r)return r[a];var n={isStream:!1};return Object.keys(s).forEach(function(t){n[t]=s[t]}),s.buffer&&(n.buffer=t.link(s.buffer),n.type=n.type||n.buffer+\".dtype\"),r[a]=n})}),Object.keys(a).forEach(function(t){var e=a[t];o[t]=F(e,function(t,r){function n(t){r(l[t],\"=\",i,\".\",t,\"|0;\")}var i=t.invoke(r,e),a=t.shared,o=a.isBufferArgs,s=a.buffer,l={isStream:r.def(!1)},c=new Z;c.state=1,Object.keys(c).forEach(function(t){l[t]=r.def(\"\"+c[t])});var u=l.buffer,h=l.type;return r(\"if(\",o,\"(\",i,\")){\",l.isStream,\"=true;\",u,\"=\",s,\".createStream(\",34962,\",\",i,\");\",h,\"=\",u,\".dtype;\",\"}else{\",u,\"=\",s,\".getBuffer(\",i,\");\",\"if(\",u,\"){\",h,\"=\",u,\".dtype;\",'}else if(\"constant\" in ',i,\"){\",l.state,\"=\",2,\";\",\"if(typeof \"+i+'.constant === \"number\"){',l[bt[0]],\"=\",i,\".constant;\",bt.slice(1).map(function(t){return l[t]}).join(\"=\"),\"=0;\",\"}else{\",bt.map(function(t,e){return l[t]+\"=\"+i+\".constant.length>\"+e+\"?\"+i+\".constant[\"+e+\"]:0;\"}).join(\"\"),\"}}else{\",\"if(\",o,\"(\",i,\".buffer)){\",u,\"=\",s,\".createStream(\",34962,\",\",i,\".buffer);\",\"}else{\",u,\"=\",s,\".getBuffer(\",i,\".buffer);\",\"}\",h,'=\"type\" in ',i,\"?\",a.glTypes,\"[\",i,\".type]:\",u,\".dtype;\",l.normalized,\"=!!\",i,\".normalized;\"),n(\"size\"),n(\"offset\"),n(\"stride\"),n(\"divisor\"),r(\"}}\"),r.exit(\"if(\",l.isStream,\"){\",s,\".destroyStream(\",u,\");\",\"}\"),l})}),o}function A(t,e,r,n,i){var o=_(t),s=function(t,e,r){function n(t){if(t in i){var r=i[t];t=!0;var n,o,s=0|r.x,l=0|r.y;return\"width\"in r?n=0|r.width:t=!1,\"height\"in r?o=0|r.height:t=!1,new I(!t&&e&&e.thisDep,!t&&e&&e.contextDep,!t&&e&&e.propDep,function(t,e){var i=t.shared.context,a=n;\"width\"in r||(a=e.def(i,\".\",\"framebufferWidth\",\"-\",s));var c=o;return\"height\"in r||(c=e.def(i,\".\",\"framebufferHeight\",\"-\",l)),[s,l,a,c]})}if(t in a){var c=a[t];return t=F(c,function(t,e){var r=t.invoke(e,c),n=t.shared.context,i=e.def(r,\".x|0\"),a=e.def(r,\".y|0\");return[i,a,e.def('\"width\" in ',r,\"?\",r,\".width|0:\",\"(\",n,\".\",\"framebufferWidth\",\"-\",i,\")\"),r=e.def('\"height\" in ',r,\"?\",r,\".height|0:\",\"(\",n,\".\",\"framebufferHeight\",\"-\",a,\")\")]}),e&&(t.thisDep=t.thisDep||e.thisDep,t.contextDep=t.contextDep||e.contextDep,t.propDep=t.propDep||e.propDep),t}return e?new I(e.thisDep,e.contextDep,e.propDep,function(t,e){var r=t.shared.context;return[0,0,e.def(r,\".\",\"framebufferWidth\"),e.def(r,\".\",\"framebufferHeight\")]}):null}var i=t.static,a=t.dynamic;if(t=n(\"viewport\")){var o=t;t=new I(t.thisDep,t.contextDep,t.propDep,function(t,e){var r=o.append(t,e),n=t.shared.context;return e.set(n,\".viewportWidth\",r[2]),e.set(n,\".viewportHeight\",r[3]),r})}return{viewport:t,scissor_box:n(\"scissor.box\")}}(t,o),l=k(t),c=function(t,e){var r=t.static,n=t.dynamic,i={};return nt.forEach(function(t){function e(e,a){if(t in r){var s=e(r[t]);i[o]=R(function(){return s})}else if(t in n){var l=n[t];i[o]=F(l,function(t,e){return a(t,e,t.invoke(e,l))})}}var o=m(t);switch(t){case\"cull.enable\":case\"blend.enable\":case\"dither\":case\"stencil.enable\":case\"depth.enable\":case\"scissor.enable\":case\"polygonOffset.enable\":case\"sample.alpha\":case\"sample.enable\":case\"depth.mask\":return e(function(t){return t},function(t,e,r){return r});case\"depth.func\":return e(function(t){return kt[t]},function(t,e,r){return e.def(t.constants.compareFuncs,\"[\",r,\"]\")});case\"depth.range\":return e(function(t){return t},function(t,e,r){return[e.def(\"+\",r,\"[0]\"),e=e.def(\"+\",r,\"[1]\")]});case\"blend.func\":return e(function(t){return[wt[\"srcRGB\"in t?t.srcRGB:t.src],wt[\"dstRGB\"in t?t.dstRGB:t.dst],wt[\"srcAlpha\"in t?t.srcAlpha:t.src],wt[\"dstAlpha\"in t?t.dstAlpha:t.dst]]},function(t,e,r){function n(t,n){return e.def('\"',t,n,'\" in ',r,\"?\",r,\".\",t,n,\":\",r,\".\",t)}t=t.constants.blendFuncs;var i=n(\"src\",\"RGB\"),a=n(\"dst\",\"RGB\"),o=(i=e.def(t,\"[\",i,\"]\"),e.def(t,\"[\",n(\"src\",\"Alpha\"),\"]\"));return[i,a=e.def(t,\"[\",a,\"]\"),o,t=e.def(t,\"[\",n(\"dst\",\"Alpha\"),\"]\")]});case\"blend.equation\":return e(function(t){return\"string\"==typeof t?[J[t],J[t]]:\"object\"==typeof t?[J[t.rgb],J[t.alpha]]:void 0},function(t,e,r){var n=t.constants.blendEquations,i=e.def(),a=e.def();return(t=t.cond(\"typeof \",r,'===\"string\"')).then(i,\"=\",a,\"=\",n,\"[\",r,\"];\"),t.else(i,\"=\",n,\"[\",r,\".rgb];\",a,\"=\",n,\"[\",r,\".alpha];\"),e(t),[i,a]});case\"blend.color\":return e(function(t){return a(4,function(e){return+t[e]})},function(t,e,r){return a(4,function(t){return e.def(\"+\",r,\"[\",t,\"]\")})});case\"stencil.mask\":return e(function(t){return 0|t},function(t,e,r){return e.def(r,\"|0\")});case\"stencil.func\":return e(function(t){return[kt[t.cmp||\"keep\"],t.ref||0,\"mask\"in t?t.mask:-1]},function(t,e,r){return[t=e.def('\"cmp\" in ',r,\"?\",t.constants.compareFuncs,\"[\",r,\".cmp]\",\":\",7680),e.def(r,\".ref|0\"),e=e.def('\"mask\" in ',r,\"?\",r,\".mask|0:-1\")]});case\"stencil.opFront\":case\"stencil.opBack\":return e(function(e){return[\"stencil.opBack\"===t?1029:1028,Tt[e.fail||\"keep\"],Tt[e.zfail||\"keep\"],Tt[e.zpass||\"keep\"]]},function(e,r,n){function i(t){return r.def('\"',t,'\" in ',n,\"?\",a,\"[\",n,\".\",t,\"]:\",7680)}var a=e.constants.stencilOps;return[\"stencil.opBack\"===t?1029:1028,i(\"fail\"),i(\"zfail\"),i(\"zpass\")]});case\"polygonOffset.offset\":return e(function(t){return[0|t.factor,0|t.units]},function(t,e,r){return[e.def(r,\".factor|0\"),e=e.def(r,\".units|0\")]});case\"cull.face\":return e(function(t){var e=0;return\"front\"===t?e=1028:\"back\"===t&&(e=1029),e},function(t,e,r){return e.def(r,'===\"front\"?',1028,\":\",1029)});case\"lineWidth\":return e(function(t){return t},function(t,e,r){return r});case\"frontFace\":return e(function(t){return At[t]},function(t,e,r){return e.def(r+'===\"cw\"?2304:2305')});case\"colorMask\":return e(function(t){return t.map(function(t){return!!t})},function(t,e,r){return a(4,function(t){return\"!!\"+r+\"[\"+t+\"]\"})});case\"sample.coverage\":return e(function(t){return[\"value\"in t?t.value:1,!!t.invert]},function(t,e,r){return[e.def('\"value\" in ',r,\"?+\",r,\".value:1\"),e=e.def(\"!!\",r,\".invert\")]})}}),i}(t),u=w(t),h=s.viewport;return h&&(c.viewport=h),(s=s[h=m(\"scissor.box\")])&&(c[h]=s),(o={framebuffer:o,draw:l,shader:u,state:c,dirty:s=0<Object.keys(c).length}).profile=function(t){var e,r=t.static;if(t=t.dynamic,\"profile\"in r){var n=!!r.profile;(e=R(function(t,e){return n})).enable=n}else if(\"profile\"in t){var i=t.profile;e=F(i,function(t,e){return t.invoke(e,i)})}return e}(t),o.uniforms=function(t,e){var r=t.static,n=t.dynamic,i={};return Object.keys(r).forEach(function(t){var e,n=r[t];if(\"number\"==typeof n||\"boolean\"==typeof n)e=R(function(){return n});else if(\"function\"==typeof n){var o=n._reglType;\"texture2d\"===o||\"textureCube\"===o?e=R(function(t){return t.link(n)}):\"framebuffer\"!==o&&\"framebufferCube\"!==o||(e=R(function(t){return t.link(n.color[0])}))}else v(n)&&(e=R(function(t){return t.global.def(\"[\",a(n.length,function(t){return n[t]}),\"]\")}));e.value=n,i[t]=e}),Object.keys(n).forEach(function(t){var e=n[t];i[t]=F(e,function(t,r){return t.invoke(r,e)})}),i}(r),o.attributes=T(e),o.context=function(t){var e=t.static,r=t.dynamic,n={};return Object.keys(e).forEach(function(t){var r=e[t];n[t]=R(function(t,e){return\"number\"==typeof r||\"boolean\"==typeof r?\"\"+r:t.link(r)})}),Object.keys(r).forEach(function(t){var e=r[t];n[t]=F(e,function(t,r){return t.invoke(r,e)})}),n}(n),o}function M(t,e,r){var n=t.shared.context,i=t.scope();Object.keys(r).forEach(function(a){e.save(n,\".\"+a),i(n,\".\",a,\"=\",r[a].append(t,e),\";\")}),e(i)}function S(t,e,r,n){var i,a=(s=t.shared).gl,o=s.framebuffer;Q&&(i=e.def(s.extensions,\".webgl_draw_buffers\"));var s=(l=t.constants).drawBuffer,l=l.backBuffer;t=r?r.append(t,e):e.def(o,\".next\"),n||e(\"if(\",t,\"!==\",o,\".cur){\"),e(\"if(\",t,\"){\",a,\".bindFramebuffer(\",36160,\",\",t,\".framebuffer);\"),Q&&e(i,\".drawBuffersWEBGL(\",s,\"[\",t,\".colorAttachments.length]);\"),e(\"}else{\",a,\".bindFramebuffer(\",36160,\",null);\"),Q&&e(i,\".drawBuffersWEBGL(\",l,\");\"),e(\"}\",o,\".cur=\",t,\";\"),n||e(\"}\")}function E(t,e,r){var n=t.shared,i=n.gl,o=t.current,s=t.next,l=n.current,c=n.next,u=t.cond(l,\".dirty\");nt.forEach(function(e){var n,h;if(!((e=m(e))in r.state))if(e in s){n=s[e],h=o[e];var f=a(tt[e].length,function(t){return u.def(n,\"[\",t,\"]\")});u(t.cond(f.map(function(t,e){return t+\"!==\"+h+\"[\"+e+\"]\"}).join(\"||\")).then(i,\".\",at[e],\"(\",f,\");\",f.map(function(t,e){return h+\"[\"+e+\"]=\"+t}).join(\";\"),\";\"))}else n=u.def(c,\".\",e),f=t.cond(n,\"!==\",l,\".\",e),u(f),e in it?f(t.cond(n).then(i,\".enable(\",it[e],\");\").else(i,\".disable(\",it[e],\");\"),l,\".\",e,\"=\",n,\";\"):f(i,\".\",at[e],\"(\",n,\");\",l,\".\",e,\"=\",n,\";\")}),0===Object.keys(r.state).length&&u(l,\".dirty=false;\"),e(u)}function C(t,e,r,n){var i=t.shared,a=t.current,o=i.current,s=i.gl;z(Object.keys(r)).forEach(function(i){var l=r[i];if(!n||n(l)){var c=l.append(t,e);if(it[i]){var u=it[i];D(l)?e(s,c?\".enable(\":\".disable(\",u,\");\"):e(t.cond(c).then(s,\".enable(\",u,\");\").else(s,\".disable(\",u,\");\")),e(o,\".\",i,\"=\",c,\";\")}else if(v(c)){var h=a[i];e(s,\".\",at[i],\"(\",c,\");\",c.map(function(t,e){return h+\"[\"+e+\"]=\"+t}).join(\";\"),\";\")}else e(s,\".\",at[i],\"(\",c,\");\",o,\".\",i,\"=\",c,\";\")}})}function L(t,e){$&&(t.instancing=e.def(t.shared.extensions,\".angle_instanced_arrays\"))}function B(t,e,r,n,i){function a(){return\"undefined\"==typeof performance?\"Date.now()\":\"performance.now()\"}function o(t){t(c=e.def(),\"=\",a(),\";\"),\"string\"==typeof i?t(f,\".count+=\",i,\";\"):t(f,\".count++;\"),d&&(n?t(u=e.def(),\"=\",g,\".getNumPendingQueries();\"):t(g,\".beginQuery(\",f,\");\"))}function s(t){t(f,\".cpuTime+=\",a(),\"-\",c,\";\"),d&&(n?t(g,\".pushScopeStats(\",u,\",\",g,\".getNumPendingQueries(),\",f,\");\"):t(g,\".endQuery();\"))}function l(t){var r=e.def(p,\".profile\");e(p,\".profile=\",t,\";\"),e.exit(p,\".profile=\",r,\";\")}var c,u,h=t.shared,f=t.stats,p=h.current,g=h.timer;if(r=r.profile){if(D(r))return void(r.enable?(o(e),s(e.exit),l(\"true\")):l(\"false\"));l(r=r.append(t,e))}else r=e.def(p,\".profile\");o(h=t.block()),e(\"if(\",r,\"){\",h,\"}\"),s(t=t.block()),e.exit(\"if(\",r,\"){\",t,\"}\")}function N(t,e,r,n,i){function a(r,n,i){function a(){e(\"if(!\",u,\".buffer){\",l,\".enableVertexAttribArray(\",c,\");}\");var r,a=i.type;r=i.size?e.def(i.size,\"||\",n):n,e(\"if(\",u,\".type!==\",a,\"||\",u,\".size!==\",r,\"||\",p.map(function(t){return u+\".\"+t+\"!==\"+i[t]}).join(\"||\"),\"){\",l,\".bindBuffer(\",34962,\",\",h,\".buffer);\",l,\".vertexAttribPointer(\",[c,r,a,i.normalized,i.stride,i.offset],\");\",u,\".type=\",a,\";\",u,\".size=\",r,\";\",p.map(function(t){return u+\".\"+t+\"=\"+i[t]+\";\"}).join(\"\"),\"}\"),$&&(a=i.divisor,e(\"if(\",u,\".divisor!==\",a,\"){\",t.instancing,\".vertexAttribDivisorANGLE(\",[c,a],\");\",u,\".divisor=\",a,\";}\"))}function s(){e(\"if(\",u,\".buffer){\",l,\".disableVertexAttribArray(\",c,\");\",\"}if(\",bt.map(function(t,e){return u+\".\"+t+\"!==\"+f[e]}).join(\"||\"),\"){\",l,\".vertexAttrib4f(\",c,\",\",f,\");\",bt.map(function(t,e){return u+\".\"+t+\"=\"+f[e]+\";\"}).join(\"\"),\"}\")}var l=o.gl,c=e.def(r,\".location\"),u=e.def(o.attributes,\"[\",c,\"]\");r=i.state;var h=i.buffer,f=[i.x,i.y,i.z,i.w],p=[\"buffer\",\"normalized\",\"offset\",\"stride\"];1===r?a():2===r?s():(e(\"if(\",r,\"===\",1,\"){\"),a(),e(\"}else{\"),s(),e(\"}\"))}var o=t.shared;n.forEach(function(n){var o,s=n.name,l=r.attributes[s];if(l){if(!i(l))return;o=l.append(t,e)}else{if(!i(Mt))return;var c=t.scopeAttrib(s);o={},Object.keys(new Z).forEach(function(t){o[t]=e.def(c,\".\",t)})}a(t.link(n),function(t){switch(t){case 35664:case 35667:case 35671:return 2;case 35665:case 35668:case 35672:return 3;case 35666:case 35669:case 35673:return 4;default:return 1}}(n.info.type),o)})}function j(t,r,n,i,o){for(var s,l=t.shared,c=l.gl,u=0;u<i.length;++u){var h,f=(g=i[u]).name,p=g.info.type,d=n.uniforms[f],g=t.link(g)+\".location\";if(d){if(!o(d))continue;if(D(d)){if(f=d.value,35678===p||35680===p)r(c,\".uniform1i(\",g,\",\",(p=t.link(f._texture||f.color[0]._texture))+\".bind());\"),r.exit(p,\".unbind();\");else if(35674===p||35675===p||35676===p)d=2,35675===p?d=3:35676===p&&(d=4),r(c,\".uniformMatrix\",d,\"fv(\",g,\",false,\",f=t.global.def(\"new Float32Array([\"+Array.prototype.slice.call(f)+\"])\"),\");\");else{switch(p){case 5126:s=\"1f\";break;case 35664:s=\"2f\";break;case 35665:s=\"3f\";break;case 35666:s=\"4f\";break;case 35670:case 5124:s=\"1i\";break;case 35671:case 35667:s=\"2i\";break;case 35672:case 35668:s=\"3i\";break;case 35673:s=\"4i\";break;case 35669:s=\"4i\"}r(c,\".uniform\",s,\"(\",g,\",\",v(f)?Array.prototype.slice.call(f):f,\");\")}continue}h=d.append(t,r)}else{if(!o(Mt))continue;h=r.def(l.uniforms,\"[\",e.id(f),\"]\")}switch(35678===p?r(\"if(\",h,\"&&\",h,'._reglType===\"framebuffer\"){',h,\"=\",h,\".color[0];\",\"}\"):35680===p&&r(\"if(\",h,\"&&\",h,'._reglType===\"framebufferCube\"){',h,\"=\",h,\".color[0];\",\"}\"),f=1,p){case 35678:case 35680:p=r.def(h,\"._texture\"),r(c,\".uniform1i(\",g,\",\",p,\".bind());\"),r.exit(p,\".unbind();\");continue;case 5124:case 35670:s=\"1i\";break;case 35667:case 35671:s=\"2i\",f=2;break;case 35668:case 35672:s=\"3i\",f=3;break;case 35669:case 35673:s=\"4i\",f=4;break;case 5126:s=\"1f\";break;case 35664:s=\"2f\",f=2;break;case 35665:s=\"3f\",f=3;break;case 35666:s=\"4f\",f=4;break;case 35674:s=\"Matrix2fv\";break;case 35675:s=\"Matrix3fv\";break;case 35676:s=\"Matrix4fv\"}if(r(c,\".uniform\",s,\"(\",g,\",\"),\"M\"===s.charAt(0)){g=Math.pow(p-35674+2,2);var m=t.global.def(\"new Float32Array(\",g,\")\");r(\"false,(Array.isArray(\",h,\")||\",h,\" instanceof Float32Array)?\",h,\":(\",a(g,function(t){return m+\"[\"+t+\"]=\"+h+\"[\"+t+\"]\"}),\",\",m,\")\")}else r(1<f?a(f,function(t){return h+\"[\"+t+\"]\"}):h);r(\");\")}}function U(t,e,r,n){function i(i){var a=f[i];return a?a.contextDep&&n.contextDynamic||a.propDep?a.append(t,r):a.append(t,e):e.def(h,\".\",i)}function a(){function t(){r(l,\".drawElementsInstancedANGLE(\",[d,v,m,g+\"<<((\"+m+\"-5121)>>1)\",s],\");\")}function e(){r(l,\".drawArraysInstancedANGLE(\",[d,g,v,s],\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}function o(){function t(){r(u+\".drawElements(\"+[d,v,m,g+\"<<((\"+m+\"-5121)>>1)\"]+\");\")}function e(){r(u+\".drawArrays(\"+[d,g,v]+\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}var s,l,c=t.shared,u=c.gl,h=c.draw,f=n.draw,p=function(){var i=f.elements,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(h,\".\",\"elements\"),i&&a(\"if(\"+i+\")\"+u+\".bindBuffer(34963,\"+i+\".buffer.buffer);\"),i}(),d=i(\"primitive\"),g=i(\"offset\"),v=function(){var i=f.count,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(h,\".\",\"count\"),i}();if(\"number\"==typeof v){if(0===v)return}else r(\"if(\",v,\"){\"),r.exit(\"}\");$&&(s=i(\"instances\"),l=t.instancing);var m=p+\".type\",y=f.elements&&D(f.elements);$&&(\"number\"!=typeof s||0<=s)?\"string\"==typeof s?(r(\"if(\",s,\">0){\"),a(),r(\"}else if(\",s,\"<0){\"),o(),r(\"}\")):a():o()}function q(t,e,r,n,i){return i=(e=b()).proc(\"body\",i),$&&(e.instancing=i.def(e.shared.extensions,\".angle_instanced_arrays\")),t(e,i,r,n),e.compile().body}function H(t,e,r,n){L(t,e),N(t,e,r,n.attributes,function(){return!0}),j(t,e,r,n.uniforms,function(){return!0}),U(t,e,e,r)}function G(t,e,r,n){function i(){return!0}t.batchId=\"a1\",L(t,e),N(t,e,r,n.attributes,i),j(t,e,r,n.uniforms,i),U(t,e,e,r)}function Y(t,e,r,n){function i(t){return t.contextDep&&o||t.propDep}function a(t){return!i(t)}L(t,e);var o=r.contextDep,s=e.def(),l=e.def();t.shared.props=l,t.batchId=s;var c=t.scope(),u=t.scope();e(c.entry,\"for(\",s,\"=0;\",s,\"<\",\"a1\",\";++\",s,\"){\",l,\"=\",\"a0\",\"[\",s,\"];\",u,\"}\",c.exit),r.needsContext&&M(t,u,r.context),r.needsFramebuffer&&S(t,u,r.framebuffer),C(t,u,r.state,i),r.profile&&i(r.profile)&&B(t,u,r,!1,!0),n?(N(t,c,r,n.attributes,a),N(t,u,r,n.attributes,i),j(t,c,r,n.uniforms,a),j(t,u,r,n.uniforms,i),U(t,c,u,r)):(e=t.global.def(\"{}\"),n=r.shader.progVar.append(t,u),l=u.def(n,\".id\"),c=u.def(e,\"[\",l,\"]\"),u(t.shared.gl,\".useProgram(\",n,\".program);\",\"if(!\",c,\"){\",c,\"=\",e,\"[\",l,\"]=\",t.link(function(e){return q(G,t,r,e,2)}),\"(\",n,\");}\",c,\".call(this,a0[\",s,\"],\",s,\");\"))}function W(t,r){function n(e){var n=r.shader[e];n&&i.set(a.shader,\".\"+e,n.append(t,i))}var i=t.proc(\"scope\",3);t.batchId=\"a2\";var a=t.shared,o=a.current;M(t,i,r.context),r.framebuffer&&r.framebuffer.append(t,i),z(Object.keys(r.state)).forEach(function(e){var n=r.state[e].append(t,i);v(n)?n.forEach(function(r,n){i.set(t.next[e],\"[\"+n+\"]\",r)}):i.set(a.next,\".\"+e,n)}),B(t,i,r,!0,!0),[\"elements\",\"offset\",\"count\",\"instances\",\"primitive\"].forEach(function(e){var n=r.draw[e];n&&i.set(a.draw,\".\"+e,\"\"+n.append(t,i))}),Object.keys(r.uniforms).forEach(function(n){i.set(a.uniforms,\"[\"+e.id(n)+\"]\",r.uniforms[n].append(t,i))}),Object.keys(r.attributes).forEach(function(e){var n=r.attributes[e].append(t,i),a=t.scopeAttrib(e);Object.keys(new Z).forEach(function(t){i.set(a,\".\"+t,n[t])})}),n(\"vert\"),n(\"frag\"),0<Object.keys(r.state).length&&(i(o,\".dirty=true;\"),i.exit(o,\".dirty=true;\")),i(\"a1(\",t.shared.context,\",a0,\",t.batchId,\");\")}function X(t,e,r){var n=e.static[r];if(n&&function(t){if(\"object\"==typeof t&&!v(t)){for(var e=Object.keys(t),r=0;r<e.length;++r)if(V.isDynamic(t[e[r]]))return!0;return!1}}(n)){var i=t.global,a=Object.keys(n),o=!1,s=!1,l=!1,c=t.global.def(\"{}\");a.forEach(function(e){var r=n[e];if(V.isDynamic(r))\"function\"==typeof r&&(r=n[e]=V.unbox(r)),e=F(r,null),o=o||e.thisDep,l=l||e.propDep,s=s||e.contextDep;else{switch(i(c,\".\",e,\"=\"),typeof r){case\"number\":i(r);break;case\"string\":i('\"',r,'\"');break;case\"object\":Array.isArray(r)&&i(\"[\",r.join(),\"]\");break;default:i(t.link(r))}i(\";\")}}),e.dynamic[r]=new V.DynamicVariable(4,{thisDep:o,contextDep:s,propDep:l,ref:c,append:function(t,e){a.forEach(function(r){var i=n[r];V.isDynamic(i)&&(i=t.invoke(e,i),e(c,\".\",r,\"=\",i,\";\"))})}}),delete e.static[r]}}var Z=u.Record,J={add:32774,subtract:32778,\"reverse subtract\":32779};r.ext_blend_minmax&&(J.min=32775,J.max=32776);var $=r.angle_instanced_arrays,Q=r.webgl_draw_buffers,tt={dirty:!0,profile:g.profile},et={},nt=[],it={},at={};y(\"dither\",3024),y(\"blend.enable\",3042),x(\"blend.color\",\"blendColor\",[0,0,0,0]),x(\"blend.equation\",\"blendEquationSeparate\",[32774,32774]),x(\"blend.func\",\"blendFuncSeparate\",[1,0,1,0]),y(\"depth.enable\",2929,!0),x(\"depth.func\",\"depthFunc\",513),x(\"depth.range\",\"depthRange\",[0,1]),x(\"depth.mask\",\"depthMask\",!0),x(\"colorMask\",\"colorMask\",[!0,!0,!0,!0]),y(\"cull.enable\",2884),x(\"cull.face\",\"cullFace\",1029),x(\"frontFace\",\"frontFace\",2305),x(\"lineWidth\",\"lineWidth\",1),y(\"polygonOffset.enable\",32823),x(\"polygonOffset.offset\",\"polygonOffset\",[0,0]),y(\"sample.alpha\",32926),y(\"sample.enable\",32928),x(\"sample.coverage\",\"sampleCoverage\",[1,!1]),y(\"stencil.enable\",2960),x(\"stencil.mask\",\"stencilMask\",-1),x(\"stencil.func\",\"stencilFunc\",[519,0,-1]),x(\"stencil.opFront\",\"stencilOpSeparate\",[1028,7680,7680,7680]),x(\"stencil.opBack\",\"stencilOpSeparate\",[1029,7680,7680,7680]),y(\"scissor.enable\",3089),x(\"scissor.box\",\"scissor\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]),x(\"viewport\",\"viewport\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]);var ot={gl:t,context:p,strings:e,next:et,current:tt,draw:f,elements:o,buffer:i,shader:h,attributes:u.state,uniforms:c,framebuffer:l,extensions:r,timer:d,isBufferArgs:O},st={primTypes:rt,compareFuncs:kt,blendFuncs:wt,blendEquations:J,stencilOps:Tt,glTypes:K,orientationType:At};Q&&(st.backBuffer=[1029],st.drawBuffer=a(n.maxDrawbuffers,function(t){return 0===t?[0]:a(t,function(t){return 36064+t})}));var lt=0;return{next:et,current:tt,procs:function(){var t=b(),e=t.proc(\"poll\"),r=t.proc(\"refresh\"),i=t.block();e(i),r(i);var o,s=t.shared,l=s.gl,c=s.next,u=s.current;i(u,\".dirty=false;\"),S(t,e),S(t,r,null,!0),$&&(o=t.link($));for(var h=0;h<n.maxAttributes;++h){var f=r.def(s.attributes,\"[\",h,\"]\"),p=t.cond(f,\".buffer\");p.then(l,\".enableVertexAttribArray(\",h,\");\",l,\".bindBuffer(\",34962,\",\",f,\".buffer.buffer);\",l,\".vertexAttribPointer(\",h,\",\",f,\".size,\",f,\".type,\",f,\".normalized,\",f,\".stride,\",f,\".offset);\").else(l,\".disableVertexAttribArray(\",h,\");\",l,\".vertexAttrib4f(\",h,\",\",f,\".x,\",f,\".y,\",f,\".z,\",f,\".w);\",f,\".buffer=null;\"),r(p),$&&r(o,\".vertexAttribDivisorANGLE(\",h,\",\",f,\".divisor);\")}return Object.keys(it).forEach(function(n){var a=it[n],o=i.def(c,\".\",n),s=t.block();s(\"if(\",o,\"){\",l,\".enable(\",a,\")}else{\",l,\".disable(\",a,\")}\",u,\".\",n,\"=\",o,\";\"),r(s),e(\"if(\",o,\"!==\",u,\".\",n,\"){\",s,\"}\")}),Object.keys(at).forEach(function(n){var o,s,h=at[n],f=tt[n],p=t.block();p(l,\".\",h,\"(\"),v(f)?(h=f.length,o=t.global.def(c,\".\",n),s=t.global.def(u,\".\",n),p(a(h,function(t){return o+\"[\"+t+\"]\"}),\");\",a(h,function(t){return s+\"[\"+t+\"]=\"+o+\"[\"+t+\"];\"}).join(\"\")),e(\"if(\",a(h,function(t){return o+\"[\"+t+\"]!==\"+s+\"[\"+t+\"]\"}).join(\"||\"),\"){\",p,\"}\")):(o=i.def(c,\".\",n),s=i.def(u,\".\",n),p(o,\");\",u,\".\",n,\"=\",o,\";\"),e(\"if(\",o,\"!==\",s,\"){\",p,\"}\")),r(p)}),t.compile()}(),compile:function(t,e,r,n,i){var a=b();return a.stats=a.link(i),Object.keys(e.static).forEach(function(t){X(a,e,t)}),_t.forEach(function(e){X(a,t,e)}),r=A(t,e,r,n),function(t,e){var r=t.proc(\"draw\",1);L(t,r),M(t,r,e.context),S(t,r,e.framebuffer),E(t,r,e),C(t,r,e.state),B(t,r,e,!1,!0);var n=e.shader.progVar.append(t,r);if(r(t.shared.gl,\".useProgram(\",n,\".program);\"),e.shader.program)H(t,r,e,e.shader.program);else{var i=t.global.def(\"{}\"),a=r.def(n,\".id\"),o=r.def(i,\"[\",a,\"]\");r(t.cond(o).then(o,\".call(this,a0);\").else(o,\"=\",i,\"[\",a,\"]=\",t.link(function(r){return q(H,t,e,r,1)}),\"(\",n,\");\",o,\".call(this,a0);\"))}0<Object.keys(e.state).length&&r(t.shared.current,\".dirty=true;\")}(a,r),W(a,r),function(t,e){function r(t){return t.contextDep&&i||t.propDep}var n=t.proc(\"batch\",2);t.batchId=\"0\",L(t,n);var i=!1,a=!0;Object.keys(e.context).forEach(function(t){i=i||e.context[t].propDep}),i||(M(t,n,e.context),a=!1);var o=!1;if((s=e.framebuffer)?(s.propDep?i=o=!0:s.contextDep&&i&&(o=!0),o||S(t,n,s)):S(t,n,null),e.state.viewport&&e.state.viewport.propDep&&(i=!0),E(t,n,e),C(t,n,e.state,function(t){return!r(t)}),e.profile&&r(e.profile)||B(t,n,e,!1,\"a1\"),e.contextDep=i,e.needsContext=a,e.needsFramebuffer=o,(a=e.shader.progVar).contextDep&&i||a.propDep)Y(t,n,e,null);else if(a=a.append(t,n),n(t.shared.gl,\".useProgram(\",a,\".program);\"),e.shader.program)Y(t,n,e,e.shader.program);else{var s=t.global.def(\"{}\"),l=(o=n.def(a,\".id\"),n.def(s,\"[\",o,\"]\"));n(t.cond(l).then(l,\".call(this,a0,a1);\").else(l,\"=\",s,\"[\",o,\"]=\",t.link(function(r){return q(Y,t,e,r,2)}),\"(\",a,\");\",l,\".call(this,a0,a1);\"))}0<Object.keys(e.state).length&&n(t.shared.current,\".dirty=true;\")}(a,r),a.compile()}}}function N(t,e){for(var r=0;r<t.length;++r)if(t[r]===e)return r;return-1}var j=function(t,e){for(var r=Object.keys(e),n=0;n<r.length;++n)t[r[n]]=e[r[n]];return t},U=0,V={DynamicVariable:t,define:function(r,n){return new t(r,e(n+\"\"))},isDynamic:function(e){return\"function\"==typeof e&&!e._reglType||e instanceof t},unbox:function(e,r){return\"function\"==typeof e?new t(0,e):e},accessor:e},q={next:\"function\"==typeof requestAnimationFrame?function(t){return requestAnimationFrame(t)}:function(t){return setTimeout(t,16)},cancel:\"function\"==typeof cancelAnimationFrame?function(t){return cancelAnimationFrame(t)}:clearTimeout},H=\"undefined\"!=typeof performance&&performance.now?function(){return performance.now()}:function(){return+new Date},G=s();G.zero=s();var Y=function(t,e){var r=1;e.ext_texture_filter_anisotropic&&(r=t.getParameter(34047));var n=1,i=1;e.webgl_draw_buffers&&(n=t.getParameter(34852),i=t.getParameter(36063));var a=!!e.oes_texture_float;if(a){a=t.createTexture(),t.bindTexture(3553,a),t.texImage2D(3553,0,6408,1,1,0,6408,5126,null);var o=t.createFramebuffer();if(t.bindFramebuffer(36160,o),t.framebufferTexture2D(36160,36064,3553,a,0),t.bindTexture(3553,null),36053!==t.checkFramebufferStatus(36160))a=!1;else{t.viewport(0,0,1,1),t.clearColor(1,0,0,1),t.clear(16384);var s=G.allocType(5126,4);t.readPixels(0,0,1,1,6408,5126,s),t.getError()?a=!1:(t.deleteFramebuffer(o),t.deleteTexture(a),a=1===s[0]),G.freeType(s)}}return s=!0,\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion)||/Edge/.test(navigator.userAgent))||(s=t.createTexture(),o=G.allocType(5121,36),t.activeTexture(33984),t.bindTexture(34067,s),t.texImage2D(34069,0,6408,3,3,0,6408,5121,o),G.freeType(o),t.bindTexture(34067,null),t.deleteTexture(s),s=!t.getError()),{colorBits:[t.getParameter(3410),t.getParameter(3411),t.getParameter(3412),t.getParameter(3413)],depthBits:t.getParameter(3414),stencilBits:t.getParameter(3415),subpixelBits:t.getParameter(3408),extensions:Object.keys(e).filter(function(t){return!!e[t]}),maxAnisotropic:r,maxDrawbuffers:n,maxColorAttachments:i,pointSizeDims:t.getParameter(33901),lineWidthDims:t.getParameter(33902),maxViewportDims:t.getParameter(3386),maxCombinedTextureUnits:t.getParameter(35661),maxCubeMapSize:t.getParameter(34076),maxRenderbufferSize:t.getParameter(34024),maxTextureUnits:t.getParameter(34930),maxTextureSize:t.getParameter(3379),maxAttributes:t.getParameter(34921),maxVertexUniforms:t.getParameter(36347),maxVertexTextureUnits:t.getParameter(35660),maxVaryingVectors:t.getParameter(36348),maxFragmentUniforms:t.getParameter(36349),glsl:t.getParameter(35724),renderer:t.getParameter(7937),vendor:t.getParameter(7936),version:t.getParameter(7938),readFloat:a,npotTextureCube:s}},W=function(t){return t instanceof Uint8Array||t instanceof Uint16Array||t instanceof Uint32Array||t instanceof Int8Array||t instanceof Int16Array||t instanceof Int32Array||t instanceof Float32Array||t instanceof Float64Array||t instanceof Uint8ClampedArray},X=function(t){return Object.keys(t).map(function(e){return t[e]})},Z={shape:function(t){for(var e=[];t.length;t=t[0])e.push(t.length);return e},flatten:function(t,e,r,n){var i=1;if(e.length)for(var a=0;a<e.length;++a)i*=e[a];else i=0;switch(r=n||G.allocType(r,i),e.length){case 0:break;case 1:for(n=e[0],e=0;e<n;++e)r[e]=t[e];break;case 2:for(n=e[0],e=e[1],a=i=0;a<n;++a)for(var o=t[a],s=0;s<e;++s)r[i++]=o[s];break;case 3:c(t,e[0],e[1],e[2],r,0);break;default:!function t(e,r,n,i,a){for(var o=1,s=n+1;s<r.length;++s)o*=r[s];var l=r[n];if(4==r.length-n){var u=r[n+1],h=r[n+2];for(r=r[n+3],s=0;s<l;++s)c(e[s],u,h,r,i,a),a+=o}else for(s=0;s<l;++s)t(e[s],r,n+1,i,a),a+=o}(t,e,0,r,0)}return r}},J={\"[object Int8Array]\":5120,\"[object Int16Array]\":5122,\"[object Int32Array]\":5124,\"[object Uint8Array]\":5121,\"[object Uint8ClampedArray]\":5121,\"[object Uint16Array]\":5123,\"[object Uint32Array]\":5125,\"[object Float32Array]\":5126,\"[object Float64Array]\":5121,\"[object ArrayBuffer]\":5121},K={int8:5120,int16:5122,int32:5124,uint8:5121,uint16:5123,uint32:5125,float:5126,float32:5126},$={dynamic:35048,stream:35040,static:35044},Q=Z.flatten,tt=Z.shape,et=[];et[5120]=1,et[5122]=2,et[5124]=4,et[5121]=1,et[5123]=2,et[5125]=4,et[5126]=4;var rt={points:0,point:0,lines:1,line:1,triangles:4,triangle:4,\"line loop\":2,\"line strip\":3,\"triangle strip\":5,\"triangle fan\":6},nt=new Float32Array(1),it=new Uint32Array(nt.buffer),at=[9984,9986,9985,9987],ot=[0,6409,6410,6407,6408],st={};st[6409]=st[6406]=st[6402]=1,st[34041]=st[6410]=2,st[6407]=st[35904]=3,st[6408]=st[35906]=4;var lt=m(\"HTMLCanvasElement\"),ct=m(\"CanvasRenderingContext2D\"),ut=m(\"ImageBitmap\"),ht=m(\"HTMLImageElement\"),ft=m(\"HTMLVideoElement\"),pt=Object.keys(J).concat([lt,ct,ut,ht,ft]),dt=[];dt[5121]=1,dt[5126]=4,dt[36193]=2,dt[5123]=2,dt[5125]=4;var gt=[];gt[32854]=2,gt[32855]=2,gt[36194]=2,gt[34041]=4,gt[33776]=.5,gt[33777]=.5,gt[33778]=1,gt[33779]=1,gt[35986]=.5,gt[35987]=1,gt[34798]=1,gt[35840]=.5,gt[35841]=.25,gt[35842]=.5,gt[35843]=.25,gt[36196]=.5;var vt=[];vt[32854]=2,vt[32855]=2,vt[36194]=2,vt[33189]=2,vt[36168]=1,vt[34041]=4,vt[35907]=4,vt[34836]=16,vt[34842]=8,vt[34843]=6;var mt=function(t,e,r,n,i){function a(t){this.id=c++,this.refCount=1,this.renderbuffer=t,this.format=32854,this.height=this.width=0,i.profile&&(this.stats={size:0})}function o(e){var r=e.renderbuffer;t.bindRenderbuffer(36161,null),t.deleteRenderbuffer(r),e.renderbuffer=null,e.refCount=0,delete u[e.id],n.renderbufferCount--}var s={rgba4:32854,rgb565:36194,\"rgb5 a1\":32855,depth:33189,stencil:36168,\"depth stencil\":34041};e.ext_srgb&&(s.srgba=35907),e.ext_color_buffer_half_float&&(s.rgba16f=34842,s.rgb16f=34843),e.webgl_color_buffer_float&&(s.rgba32f=34836);var l=[];Object.keys(s).forEach(function(t){l[s[t]]=t});var c=0,u={};return a.prototype.decRef=function(){0>=--this.refCount&&o(this)},i.profile&&(n.getTotalRenderbufferSize=function(){var t=0;return Object.keys(u).forEach(function(e){t+=u[e].stats.size}),t}),{create:function(e,r){function o(e,r){var n=0,a=0,u=32854;if(\"object\"==typeof e&&e?(\"shape\"in e?(n=0|(a=e.shape)[0],a=0|a[1]):(\"radius\"in e&&(n=a=0|e.radius),\"width\"in e&&(n=0|e.width),\"height\"in e&&(a=0|e.height)),\"format\"in e&&(u=s[e.format])):\"number\"==typeof e?(n=0|e,a=\"number\"==typeof r?0|r:n):e||(n=a=1),n!==c.width||a!==c.height||u!==c.format)return o.width=c.width=n,o.height=c.height=a,c.format=u,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,u,n,a),i.profile&&(c.stats.size=vt[c.format]*c.width*c.height),o.format=l[c.format],o}var c=new a(t.createRenderbuffer());return u[c.id]=c,n.renderbufferCount++,o(e,r),o.resize=function(e,r){var n=0|e,a=0|r||n;return n===c.width&&a===c.height?o:(o.width=c.width=n,o.height=c.height=a,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,c.format,n,a),i.profile&&(c.stats.size=vt[c.format]*c.width*c.height),o)},o._reglType=\"renderbuffer\",o._renderbuffer=c,i.profile&&(o.stats=c.stats),o.destroy=function(){c.decRef()},o},clear:function(){X(u).forEach(o)},restore:function(){X(u).forEach(function(e){e.renderbuffer=t.createRenderbuffer(),t.bindRenderbuffer(36161,e.renderbuffer),t.renderbufferStorage(36161,e.format,e.width,e.height)}),t.bindRenderbuffer(36161,null)}}},yt=[];yt[6408]=4,yt[6407]=3;var xt=[];xt[5121]=1,xt[5126]=4,xt[36193]=2;var bt=[\"x\",\"y\",\"z\",\"w\"],_t=\"blend.func blend.equation stencil.func stencil.opFront stencil.opBack sample.coverage viewport scissor.box polygonOffset.offset\".split(\" \"),wt={0:0,1:1,zero:0,one:1,\"src color\":768,\"one minus src color\":769,\"src alpha\":770,\"one minus src alpha\":771,\"dst color\":774,\"one minus dst color\":775,\"dst alpha\":772,\"one minus dst alpha\":773,\"constant color\":32769,\"one minus constant color\":32770,\"constant alpha\":32771,\"one minus constant alpha\":32772,\"src alpha saturate\":776},kt={never:512,less:513,\"<\":513,equal:514,\"=\":514,\"==\":514,\"===\":514,lequal:515,\"<=\":515,greater:516,\">\":516,notequal:517,\"!=\":517,\"!==\":517,gequal:518,\">=\":518,always:519},Tt={0:0,zero:0,keep:7680,replace:7681,increment:7682,decrement:7683,\"increment wrap\":34055,\"decrement wrap\":34056,invert:5386},At={cw:2304,ccw:2305},Mt=new I(!1,!1,!1,function(){});return function(t){function e(){if(0===Z.length)w&&w.update(),Q=null;else{Q=q.next(e),h();for(var t=Z.length-1;0<=t;--t){var r=Z[t];r&&r(P,null,0)}v.flush(),w&&w.update()}}function r(){!Q&&0<Z.length&&(Q=q.next(e))}function n(){Q&&(q.cancel(e),Q=null)}function a(t){t.preventDefault(),n(),J.forEach(function(t){t()})}function o(t){v.getError(),y.restore(),D.restore(),z.restore(),R.restore(),F.restore(),U.restore(),w&&w.restore(),G.procs.refresh(),r(),K.forEach(function(t){t()})}function s(t){function e(t){var e={},r={};return Object.keys(t).forEach(function(n){var i=t[n];V.isDynamic(i)?r[n]=V.unbox(i,n):e[n]=i}),{dynamic:r,static:e}}var r=e(t.context||{}),n=e(t.uniforms||{}),i=e(t.attributes||{}),a=e(function(t){function e(t){if(t in r){var e=r[t];delete r[t],Object.keys(e).forEach(function(n){r[t+\".\"+n]=e[n]})}}var r=j({},t);return delete r.uniforms,delete r.attributes,delete r.context,\"stencil\"in r&&r.stencil.op&&(r.stencil.opBack=r.stencil.opFront=r.stencil.op,delete r.stencil.op),e(\"blend\"),e(\"depth\"),e(\"cull\"),e(\"stencil\"),e(\"polygonOffset\"),e(\"scissor\"),e(\"sample\"),r}(t));t={gpuTime:0,cpuTime:0,count:0};var o=(r=G.compile(a,i,n,r,t)).draw,s=r.batch,l=r.scope,c=[];return j(function(t,e){var r;if(\"function\"==typeof t)return l.call(this,null,t,0);if(\"function\"==typeof e)if(\"number\"==typeof t)for(r=0;r<t;++r)l.call(this,null,e,r);else{if(!Array.isArray(t))return l.call(this,t,e,0);for(r=0;r<t.length;++r)l.call(this,t[r],e,r)}else if(\"number\"==typeof t){if(0<t)return s.call(this,function(t){for(;c.length<t;)c.push(null);return c}(0|t),0|t)}else{if(!Array.isArray(t))return o.call(this,t);if(t.length)return s.call(this,t,t.length)}},{stats:t})}function l(t,e){var r=0;G.procs.poll();var n=e.color;n&&(v.clearColor(+n[0]||0,+n[1]||0,+n[2]||0,+n[3]||0),r|=16384),\"depth\"in e&&(v.clearDepth(+e.depth),r|=256),\"stencil\"in e&&(v.clearStencil(0|e.stencil),r|=1024),v.clear(r)}function c(t){return Z.push(t),r(),{cancel:function(){var e=N(Z,t);Z[e]=function t(){var e=N(Z,t);Z[e]=Z[Z.length-1],--Z.length,0>=Z.length&&n()}}}}function u(){var t=W.viewport,e=W.scissor_box;t[0]=t[1]=e[0]=e[1]=0,P.viewportWidth=P.framebufferWidth=P.drawingBufferWidth=t[2]=e[2]=v.drawingBufferWidth,P.viewportHeight=P.framebufferHeight=P.drawingBufferHeight=t[3]=e[3]=v.drawingBufferHeight}function h(){P.tick+=1,P.time=g(),u(),G.procs.poll()}function f(){u(),G.procs.refresh(),w&&w.update()}function g(){return(H()-k)/1e3}if(!(t=i(t)))return null;var v=t.gl,m=v.getContextAttributes();v.isContextLost();var y=function(t,e){function r(e){var r;e=e.toLowerCase();try{r=n[e]=t.getExtension(e)}catch(t){}return!!r}for(var n={},i=0;i<e.extensions.length;++i){var a=e.extensions[i];if(!r(a))return e.onDestroy(),e.onDone('\"'+a+'\" extension is not supported by the current WebGL context, try upgrading your system or a different browser'),null}return e.optionalExtensions.forEach(r),{extensions:n,restore:function(){Object.keys(n).forEach(function(t){if(n[t]&&!r(t))throw Error(\"(regl): error restoring extension \"+t)})}}}(v,t);if(!y)return null;var x=function(){var t={\"\":0},e=[\"\"];return{id:function(r){var n=t[r];return n||(n=t[r]=e.length,e.push(r),n)},str:function(t){return e[t]}}}(),b={bufferCount:0,elementsCount:0,framebufferCount:0,shaderCount:0,textureCount:0,cubeCount:0,renderbufferCount:0,maxTextureUnits:0},_=y.extensions,w=function(t,e){function r(){this.endQueryIndex=this.startQueryIndex=-1,this.sum=0,this.stats=null}function n(t,e,n){var i=o.pop()||new r;i.startQueryIndex=t,i.endQueryIndex=e,i.sum=0,i.stats=n,s.push(i)}if(!e.ext_disjoint_timer_query)return null;var i=[],a=[],o=[],s=[],l=[],c=[];return{beginQuery:function(t){var r=i.pop()||e.ext_disjoint_timer_query.createQueryEXT();e.ext_disjoint_timer_query.beginQueryEXT(35007,r),a.push(r),n(a.length-1,a.length,t)},endQuery:function(){e.ext_disjoint_timer_query.endQueryEXT(35007)},pushScopeStats:n,update:function(){var t,r;if(0!==(t=a.length)){c.length=Math.max(c.length,t+1),l.length=Math.max(l.length,t+1),l[0]=0;var n=c[0]=0;for(r=t=0;r<a.length;++r){var u=a[r];e.ext_disjoint_timer_query.getQueryObjectEXT(u,34919)?(n+=e.ext_disjoint_timer_query.getQueryObjectEXT(u,34918),i.push(u)):a[t++]=u,l[r+1]=n,c[r+1]=t}for(a.length=t,r=t=0;r<s.length;++r){var h=(n=s[r]).startQueryIndex;u=n.endQueryIndex,n.sum+=l[u]-l[h],h=c[h],(u=c[u])===h?(n.stats.gpuTime+=n.sum/1e6,o.push(n)):(n.startQueryIndex=h,n.endQueryIndex=u,s[t++]=n)}s.length=t}},getNumPendingQueries:function(){return a.length},clear:function(){i.push.apply(i,a);for(var t=0;t<i.length;t++)e.ext_disjoint_timer_query.deleteQueryEXT(i[t]);a.length=0,i.length=0},restore:function(){a.length=0,i.length=0}}}(0,_),k=H(),C=v.drawingBufferWidth,L=v.drawingBufferHeight,P={tick:0,time:0,viewportWidth:C,viewportHeight:L,framebufferWidth:C,framebufferHeight:L,drawingBufferWidth:C,drawingBufferHeight:L,pixelRatio:t.pixelRatio},O=Y(v,_),z=(C=function(t,e,r,n){for(t=r.maxAttributes,e=Array(t),r=0;r<t;++r)e[r]=new M;return{Record:M,scope:{},state:e}}(v,_,O),p(v,b,t,C)),I=d(v,_,z,b),D=S(v,x,b,t),R=T(v,_,O,function(){G.procs.poll()},P,b,t),F=mt(v,_,0,b,t),U=A(v,_,O,R,F,b),G=B(v,x,_,O,z,I,0,U,{},C,D,{elements:null,primitive:4,count:-1,offset:0,instances:-1},P,w,t),W=(x=E(v,U,G.procs.poll,P),G.next),X=v.canvas,Z=[],J=[],K=[],$=[t.onDestroy],Q=null;X&&(X.addEventListener(\"webglcontextlost\",a,!1),X.addEventListener(\"webglcontextrestored\",o,!1));var tt=U.setFBO=s({framebuffer:V.define.call(null,1,\"framebuffer\")});return f(),m=j(s,{clear:function(t){if(\"framebuffer\"in t)if(t.framebuffer&&\"framebufferCube\"===t.framebuffer_reglType)for(var e=0;6>e;++e)tt(j({framebuffer:t.framebuffer.faces[e]},t),l);else tt(t,l);else l(0,t)},prop:V.define.bind(null,1),context:V.define.bind(null,2),this:V.define.bind(null,3),draw:s({}),buffer:function(t){return z.create(t,34962,!1,!1)},elements:function(t){return I.create(t,!1)},texture:R.create2D,cube:R.createCube,renderbuffer:F.create,framebuffer:U.create,framebufferCube:U.createCube,attributes:m,frame:c,on:function(t,e){var r;switch(t){case\"frame\":return c(e);case\"lost\":r=J;break;case\"restore\":r=K;break;case\"destroy\":r=$}return r.push(e),{cancel:function(){for(var t=0;t<r.length;++t)if(r[t]===e){r[t]=r[r.length-1],r.pop();break}}}},limits:O,hasExtension:function(t){return 0<=O.extensions.indexOf(t.toLowerCase())},read:x,destroy:function(){Z.length=0,n(),X&&(X.removeEventListener(\"webglcontextlost\",a),X.removeEventListener(\"webglcontextrestored\",o)),D.clear(),U.clear(),F.clear(),R.clear(),I.clear(),z.clear(),w&&w.clear(),$.forEach(function(t){t()})},_gl:v,_refresh:f,poll:function(){h(),w&&w.update()},now:g,stats:b}),t.onDone(null,m),m}},\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=i():n.createREGL=i()},{}],503:[function(t,e,r){\"use strict\";var n,i=\"\";e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"expected a string\");if(1===e)return t;if(2===e)return t+t;var r=t.length*e;if(n!==t||\"undefined\"==typeof n)n=t,i=\"\";else if(i.length>=r)return i.substr(0,r);for(;r>i.length&&e>1;)1&e&&(i+=t),e>>=1,t+=t;return i=(i+=t).substr(0,r)}},{}],504:[function(t,e,r){(function(t){e.exports=t.performance&&t.performance.now?function(){return performance.now()}:Date.now||function(){return+new Date}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{}],505:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=t[t.length-1],n=e,i=e-2;i>=0;--i){var a=r,o=t[i],s=(r=a+o)-a,l=o-s;l&&(t[--n]=r,r=l)}for(var c=0,i=n;i<e;++i){var a=t[i],o=r,s=(r=a+o)-a,l=o-s;l&&(t[c++]=l)}return t[c++]=r,t.length=c,t}},{}],506:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-compress\"),s=6;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(2===t.length)return[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\");for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(l(t,r)),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return function t(e){if(1===e.length)return e[0];if(2===e.length)return[\"sum(\",e[0],\",\",e[1],\")\"].join(\"\");var r=e.length>>1;return[\"sum(\",t(e.slice(0,r)),\",\",t(e.slice(r)),\")\"].join(\"\")}(e);var n}function u(t){return new Function(\"sum\",\"scale\",\"prod\",\"compress\",[\"function robustDeterminant\",t,\"(m){return compress(\",c(function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m[\",r,\"][\",n,\"]\"].join(\"\")}return e}(t)),\")};return robustDeterminant\",t].join(\"\"))(i,a,n,o)}var h=[function(){return[0]},function(t){return[t[0][0]]}];!function(){for(;h.length<s;)h.push(u(h.length));for(var t=[],r=[\"function robustDeterminant(m){switch(m.length){\"],n=0;n<s;++n)t.push(\"det\"+n),r.push(\"case \",n,\":return det\",n,\"(m);\");r.push(\"}var det=CACHE[m.length];if(!det)det=CACHE[m.length]=gen(m.length);return det(m);}return robustDeterminant\"),t.push(\"CACHE\",\"gen\",r.join(\"\"));var i=Function.apply(void 0,t);for(e.exports=i.apply(void 0,h.concat([h,u])),n=0;n<h.length;++n)e.exports[n]=h[n]}()},{\"robust-compress\":505,\"robust-scale\":512,\"robust-sum\":515,\"two-product\":543}],507:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\");e.exports=function(t,e){for(var r=n(t[0],e[0]),a=1;a<t.length;++a)r=i(r,n(t[a],e[a]));return r}},{\"robust-sum\":515,\"two-product\":543}],508:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-subtract\"),o=t(\"robust-scale\"),s=6;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",c(t.slice(0,e)),\",\",c(t.slice(e)),\")\"].join(\"\")}function u(t,e){if(\"m\"===t.charAt(0)){if(\"w\"===e.charAt(0)){var r=t.split(\"[\");return[\"w\",e.substr(1),\"m\",r[0].substr(1)].join(\"\")}return[\"prod(\",t,\",\",e,\")\"].join(\"\")}return u(e,t)}function h(t){if(2===t.length)return[[\"diff(\",u(t[0][0],t[1][1]),\",\",u(t[1][0],t[0][1]),\")\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(h(l(t,r))),\",\",(n=r,!0&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function f(t,e){for(var r=[],n=0;n<e-2;++n)r.push([\"prod(m\",t,\"[\",n,\"],m\",t,\"[\",n,\"])\"].join(\"\"));return c(r)}function p(t){for(var e=[],r=[],s=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-2,\"]\"].join(\"\")}return e}(t),u=0;u<t;++u)s[0][u]=\"1\",s[t-1][u]=\"w\"+u;for(u=0;u<t;++u)0==(1&u)?e.push.apply(e,h(l(s,u))):r.push.apply(r,h(l(s,u)));var p=c(e),d=c(r),g=\"exactInSphere\"+t,v=[];for(u=0;u<t;++u)v.push(\"m\"+u);var m=[\"function \",g,\"(\",v.join(),\"){\"];for(u=0;u<t;++u){m.push(\"var w\",u,\"=\",f(u,t),\";\");for(var y=0;y<t;++y)y!==u&&m.push(\"var w\",u,\"m\",y,\"=scale(w\",u,\",m\",y,\"[0]);\")}return m.push(\"var p=\",p,\",n=\",d,\",d=diff(p,n);return d[d.length-1];}return \",g),new Function(\"sum\",\"diff\",\"prod\",\"scale\",m.join(\"\"))(i,a,n,o)}var d=[function(){return 0},function(){return 0},function(){return 0}];!function(){for(;d.length<=s;)d.push(p(d.length));for(var t=[],r=[\"slow\"],n=0;n<=s;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function testInSphere(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=s;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return testInSphere\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[function(t){var e=d[t.length];return e||(e=d[t.length]=p(t.length)),e.apply(void 0,t)}].concat(d)),n=0;n<=s;++n)e.exports[n]=d[n]}()},{\"robust-scale\":512,\"robust-subtract\":514,\"robust-sum\":515,\"two-product\":543}],509:[function(t,e,r){\"use strict\";var n=t(\"robust-determinant\"),i=6;function a(t){for(var e=\"robustLinearSolve\"+t+\"d\",r=[\"function \",e,\"(A,b){return [\"],i=0;i<t;++i){r.push(\"det([\");for(var a=0;a<t;++a){a>0&&r.push(\",\"),r.push(\"[\");for(var o=0;o<t;++o)o>0&&r.push(\",\"),o===i?r.push(\"+b[\",a,\"]\"):r.push(\"+A[\",a,\"][\",o,\"]\");r.push(\"]\")}r.push(\"]),\")}r.push(\"det(A)]}return \",e);var s=new Function(\"det\",r.join(\"\"));return s(t<6?n[t]:n)}var o=[function(){return[0]},function(t,e){return[[e[0]],[t[0][0]]]}];!function(){for(;o.length<i;)o.push(a(o.length));for(var t=[],r=[\"function dispatchLinearSolve(A,b){switch(A.length){\"],n=0;n<i;++n)t.push(\"s\"+n),r.push(\"case \",n,\":return s\",n,\"(A,b);\");r.push(\"}var s=CACHE[A.length];if(!s)s=CACHE[A.length]=g(A.length);return s(A,b)}return dispatchLinearSolve\"),t.push(\"CACHE\",\"g\",r.join(\"\"));var s=Function.apply(void 0,t);for(e.exports=s.apply(void 0,o.concat([o,a])),n=0;n<i;++n)e.exports[n]=o[n]}()},{\"robust-determinant\":506}],510:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-subtract\"),s=5;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",c(t.slice(0,e)),\",\",c(t.slice(e)),\")\"].join(\"\")}function u(t){if(2===t.length)return[[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(u(l(t,r))),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function h(t){for(var e=[],r=[],s=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-1,\"]\"].join(\"\")}return e}(t),h=[],f=0;f<t;++f)0==(1&f)?e.push.apply(e,u(l(s,f))):r.push.apply(r,u(l(s,f))),h.push(\"m\"+f);var p=c(e),d=c(r),g=\"orientation\"+t+\"Exact\",v=[\"function \",g,\"(\",h.join(),\"){var p=\",p,\",n=\",d,\",d=sub(p,n);return d[d.length-1];};return \",g].join(\"\");return new Function(\"sum\",\"prod\",\"scale\",\"sub\",v)(i,n,a,o)}var f=h(3),p=h(4),d=[function(){return 0},function(){return 0},function(t,e){return e[0]-t[0]},function(t,e,r){var n,i=(t[1]-r[1])*(e[0]-r[0]),a=(t[0]-r[0])*(e[1]-r[1]),o=i-a;if(i>0){if(a<=0)return o;n=i+a}else{if(!(i<0))return o;if(a>=0)return o;n=-(i+a)}var s=3.3306690738754716e-16*n;return o>=s||o<=-s?o:f(t,e,r)},function(t,e,r,n){var i=t[0]-n[0],a=e[0]-n[0],o=r[0]-n[0],s=t[1]-n[1],l=e[1]-n[1],c=r[1]-n[1],u=t[2]-n[2],h=e[2]-n[2],f=r[2]-n[2],d=a*c,g=o*l,v=o*s,m=i*c,y=i*l,x=a*s,b=u*(d-g)+h*(v-m)+f*(y-x),_=7.771561172376103e-16*((Math.abs(d)+Math.abs(g))*Math.abs(u)+(Math.abs(v)+Math.abs(m))*Math.abs(h)+(Math.abs(y)+Math.abs(x))*Math.abs(f));return b>_||-b>_?b:p(t,e,r,n)}];!function(){for(;d.length<=s;)d.push(h(d.length));for(var t=[],r=[\"slow\"],n=0;n<=s;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function getOrientation(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=s;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return getOrientation\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[function(t){var e=d[t.length];return e||(e=d[t.length]=h(t.length)),e.apply(void 0,t)}].concat(d)),n=0;n<=s;++n)e.exports[n]=d[n]}()},{\"robust-scale\":512,\"robust-subtract\":514,\"robust-sum\":515,\"two-product\":543}],511:[function(t,e,r){\"use strict\";var n=t(\"robust-sum\"),i=t(\"robust-scale\");e.exports=function(t,e){if(1===t.length)return i(e,t[0]);if(1===e.length)return i(t,e[0]);if(0===t.length||0===e.length)return[0];var r=[0];if(t.length<e.length)for(var a=0;a<t.length;++a)r=n(r,i(e,t[a]));else for(var a=0;a<e.length;++a)r=n(r,i(t,e[a]));return r}},{\"robust-scale\":512,\"robust-sum\":515}],512:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"two-sum\");e.exports=function(t,e){var r=t.length;if(1===r){var a=n(t[0],e);return a[0]?a:[a[1]]}var o=new Array(2*r),s=[.1,.1],l=[.1,.1],c=0;n(t[0],e,s),s[0]&&(o[c++]=s[0]);for(var u=1;u<r;++u){n(t[u],e,l);var h=s[1];i(h,l[0],s),s[0]&&(o[c++]=s[0]);var f=l[1],p=s[1],d=f+p,g=d-f,v=p-g;s[1]=d,v&&(o[c++]=v)}s[1]&&(o[c++]=s[1]);0===c&&(o[c++]=0);return o.length=c,o}},{\"two-product\":543,\"two-sum\":544}],513:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){var a=n(t,r,i),o=n(e,r,i);if(a>0&&o>0||a<0&&o<0)return!1;var s=n(r,t,e),l=n(i,t,e);if(s>0&&l>0||s<0&&l<0)return!1;if(0===a&&0===o&&0===s&&0===l)return function(t,e,r,n){for(var i=0;i<2;++i){var a=t[i],o=e[i],s=Math.min(a,o),l=Math.max(a,o),c=r[i],u=n[i],h=Math.min(c,u),f=Math.max(c,u);if(f<s||l<h)return!1}return!0}(t,e,r,i);return!0};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":510}],514:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],-e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,h=t[l],f=u(h),p=-e[c],d=u(p);f<d?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=-e[c],d=u(p)));l<r&&f<d||c>=n?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p)));var g,v,m=i+a,y=m-i,x=a-y,b=x,_=m;for(;l<r&&c<n;)f<d?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p))),(x=(a=b)-(y=(m=i+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g;for(;l<r;)(x=(a=b)-(y=(m=(i=h)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(l+=1)<r&&(h=t[l]);for(;c<n;)(x=(a=b)-(y=(m=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(c+=1)<n&&(p=-e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],515:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,h=t[l],f=u(h),p=e[c],d=u(p);f<d?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=e[c],d=u(p)));l<r&&f<d||c>=n?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=e[c],d=u(p)));var g,v,m=i+a,y=m-i,x=a-y,b=x,_=m;for(;l<r&&c<n;)f<d?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=e[c],d=u(p))),(x=(a=b)-(y=(m=i+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g;for(;l<r;)(x=(a=b)-(y=(m=(i=h)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(l+=1)<r&&(h=t[l]);for(;c<n;)(x=(a=b)-(y=(m=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(c+=1)<n&&(p=e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],516:[function(t,e,r){\"use strict\";e.exports=function(t){return t<0?-1:t>0?1:0}},{}],517:[function(t,e,r){\"use strict\";e.exports=function(t){return i(n(t))};var n=t(\"boundary-cells\"),i=t(\"reduce-simplicial-complex\")},{\"boundary-cells\":95,\"reduce-simplicial-complex\":489}],518:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,s){r=r||0,\"undefined\"==typeof s&&(s=function(t){for(var e=t.length,r=0,n=0;n<e;++n)r=0|Math.max(r,t[n].length);return r-1}(t));if(0===t.length||s<1)return{cells:[],vertexIds:[],vertexWeights:[]};var l=function(t,e){for(var r=t.length,n=i.mallocUint8(r),a=0;a<r;++a)n[a]=t[a]<e|0;return n}(e,+r),c=function(t,e){for(var r=t.length,o=e*(e+1)/2*r|0,s=i.mallocUint32(2*o),l=0,c=0;c<r;++c)for(var u=t[c],e=u.length,h=0;h<e;++h)for(var f=0;f<h;++f){var p=u[f],d=u[h];s[l++]=0|Math.min(p,d),s[l++]=0|Math.max(p,d)}a(n(s,[l/2|0,2]));for(var g=2,c=2;c<l;c+=2)s[c-2]===s[c]&&s[c-1]===s[c+1]||(s[g++]=s[c],s[g++]=s[c+1]);return n(s,[g/2|0,2])}(t,s),u=function(t,e,r,a){for(var o=t.data,s=t.shape[0],l=i.mallocDouble(s),c=0,u=0;u<s;++u){var h=o[2*u],f=o[2*u+1];if(r[h]!==r[f]){var p=e[h],d=e[f];o[2*c]=h,o[2*c+1]=f,l[c++]=(d-a)/(d-p)}}return t.shape[0]=c,n(l,[c])}(c,e,l,+r),h=function(t,e){var r=i.mallocInt32(2*e),n=t.shape[0],a=t.data;r[0]=0;for(var o=0,s=0;s<n;++s){var l=a[2*s];if(l!==o){for(r[2*o+1]=s;++o<l;)r[2*o]=s,r[2*o+1]=s;r[2*o]=s}}r[2*o+1]=n;for(;++o<e;)r[2*o]=r[2*o+1]=n;return r}(c,0|e.length),f=o(s)(t,c.data,h,l),p=function(t){for(var e=0|t.shape[0],r=t.data,n=new Array(e),i=0;i<e;++i)n[i]=[r[2*i],r[2*i+1]];return n}(c),d=[].slice.call(u.data,0,u.shape[0]);return i.free(l),i.free(c.data),i.free(u.data),i.free(h),{cells:f,vertexIds:p,vertexWeights:d}};var n=t(\"ndarray\"),i=t(\"typedarray-pool\"),a=t(\"ndarray-sort\"),o=t(\"./lib/codegen\")},{\"./lib/codegen\":519,ndarray:450,\"ndarray-sort\":448,\"typedarray-pool\":545}],519:[function(t,e,r){\"use strict\";e.exports=function(t){var e=a[t];e||(e=a[t]=function(t){var e=0,r=new Array(t+1);r[0]=[[]];for(var a=1;a<=t;++a)for(var o=r[a]=i(a),s=0;s<o.length;++s)e=Math.max(e,o[a].length);var l=[\"function B(C,E,i,j){\",\"var a=Math.min(i,j)|0,b=Math.max(i,j)|0,l=C[2*a],h=C[2*a+1];\",\"while(l<h){\",\"var m=(l+h)>>1,v=E[2*m+1];\",\"if(v===b){return m}\",\"if(b<v){h=m}else{l=m+1}\",\"}\",\"return l;\",\"};\",\"function getContour\",t,\"d(F,E,C,S){\",\"var n=F.length,R=[];\",\"for(var i=0;i<n;++i){var c=F[i],l=c.length;\"];function c(t){if(!(t.length<=0)){l.push(\"R.push(\");for(var e=0;e<t.length;++e){var r=t[e];e>0&&l.push(\",\"),l.push(\"[\");for(var n=0;n<r.length;++n){var i=r[n];n>0&&l.push(\",\"),l.push(\"B(C,E,c[\",i[0],\"],c[\",i[1],\"])\")}l.push(\"]\")}l.push(\");\")}}for(var a=t+1;a>1;--a){a<t+1&&l.push(\"else \"),l.push(\"if(l===\",a,\"){\");for(var u=[],s=0;s<a;++s)u.push(\"(S[c[\"+s+\"]]<<\"+s+\")\");l.push(\"var M=\",u.join(\"+\"),\";if(M===0||M===\",(1<<a)-1,\"){continue}switch(M){\");for(var o=r[a-1],s=0;s<o.length;++s)l.push(\"case \",s,\":\"),c(o[s]),l.push(\"break;\");l.push(\"}}\")}return l.push(\"}return R;};return getContour\",t,\"d\"),new Function(\"pool\",l.join(\"\"))(n)}(t));return e};var n=t(\"typedarray-pool\"),i=t(\"marching-simplex-table\"),a={}},{\"marching-simplex-table\":427,\"typedarray-pool\":545}],520:[function(t,e,r){\"use strict\";var n=t(\"bit-twiddle\"),i=t(\"union-find\");function a(t,e){var r=t.length,n=t.length-e.length,i=Math.min;if(n)return n;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return(s=t[0]+t[1]-e[0]-e[1])||i(t[0],t[1])-i(e[0],e[1]);case 3:var a=t[0]+t[1],o=e[0]+e[1];if(s=a+t[2]-(o+e[2]))return s;var s,l=i(t[0],t[1]),c=i(e[0],e[1]);return(s=i(l,t[2])-i(c,e[2]))||i(l+t[2],a)-i(c+e[2],o);default:var u=t.slice(0);u.sort();var h=e.slice(0);h.sort();for(var f=0;f<r;++f)if(n=u[f]-h[f])return n;return 0}}function o(t,e){return a(t[0],e[0])}function s(t,e){if(e){for(var r=t.length,n=new Array(r),i=0;i<r;++i)n[i]=[t[i],e[i]];n.sort(o);for(i=0;i<r;++i)t[i]=n[i][0],e[i]=n[i][1];return t}return t.sort(a),t}function l(t){if(0===t.length)return[];for(var e=1,r=t.length,n=1;n<r;++n){var i=t[n];if(a(i,t[n-1])){if(n===e){e++;continue}t[e++]=i}}return t.length=e,t}function c(t,e){for(var r=0,n=t.length-1,i=-1;r<=n;){var o=r+n>>1,s=a(t[o],e);s<=0?(0===s&&(i=o),r=o+1):s>0&&(n=o-1)}return i}function u(t,e){for(var r=new Array(t.length),i=0,o=r.length;i<o;++i)r[i]=[];for(var s=[],l=(i=0,e.length);i<l;++i)for(var u=e[i],h=u.length,f=1,p=1<<h;f<p;++f){s.length=n.popCount(f);for(var d=0,g=0;g<h;++g)f&1<<g&&(s[d++]=u[g]);var v=c(t,s);if(!(v<0))for(;r[v++].push(i),!(v>=t.length||0!==a(t[v],s)););}return r}function h(t,e){if(e<0)return[];for(var r=[],i=(1<<e+1)-1,a=0;a<t.length;++a)for(var o=t[a],l=i;l<1<<o.length;l=n.nextCombination(l)){for(var c=new Array(e+1),u=0,h=0;h<o.length;++h)l&1<<h&&(c[u++]=o[h]);r.push(c)}return s(r)}r.dimension=function(t){for(var e=0,r=Math.max,n=0,i=t.length;n<i;++n)e=r(e,t[n].length);return e-1},r.countVertices=function(t){for(var e=-1,r=Math.max,n=0,i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)e=r(e,a[o]);return e+1},r.cloneCells=function(t){for(var e=new Array(t.length),r=0,n=t.length;r<n;++r)e[r]=t[r].slice(0);return e},r.compareCells=a,r.normalize=s,r.unique=l,r.findCell=c,r.incidence=u,r.dual=function(t,e){if(!e)return u(l(h(t,0)),t);for(var r=new Array(e),n=0;n<e;++n)r[n]=[];n=0;for(var i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)r[a[o]].push(n);return r},r.explode=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0|i.length,o=1,l=1<<a;o<l;++o){for(var c=[],u=0;u<a;++u)o>>>u&1&&c.push(i[u]);e.push(c)}return s(e)},r.skeleton=h,r.boundary=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;++a){for(var l=new Array(i.length-1),c=0,u=0;c<o;++c)c!==a&&(l[u++]=i[c]);e.push(l)}return s(e)},r.connectedComponents=function(t,e){return e?function(t,e){for(var r=new i(e),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var s=o+1;s<a.length;++s)r.link(a[o],a[s]);var l=[],c=r.ranks;for(n=0;n<c.length;++n)c[n]=-1;for(n=0;n<t.length;++n){var u=r.find(t[n][0]);c[u]<0?(c[u]=l.length,l.push([t[n].slice(0)])):l[c[u]].push(t[n].slice(0))}return l}(t,e):function(t){for(var e=l(s(h(t,0))),r=new i(e.length),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var u=c(e,[a[o]]),f=o+1;f<a.length;++f)r.link(u,c(e,[a[f]]));var p=[],d=r.ranks;for(n=0;n<d.length;++n)d[n]=-1;for(n=0;n<t.length;++n){var g=r.find(c(e,[t[n][0]]));d[g]<0?(d[g]=p.length,p.push([t[n].slice(0)])):p[d[g]].push(t[n].slice(0))}return p}(t)}},{\"bit-twiddle\":92,\"union-find\":546}],521:[function(t,e,r){arguments[4][92][0].apply(r,arguments)},{dup:92}],522:[function(t,e,r){arguments[4][520][0].apply(r,arguments)},{\"bit-twiddle\":521,dup:520,\"union-find\":523}],523:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n,n.prototype.length=function(){return this.roots.length},n.prototype.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},n.prototype.find=function(t){for(var e=this.roots;e[t]!==t;){var r=e[t];e[t]=e[r],t=r}return t},n.prototype.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],524:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){for(var a=e.length,o=t.length,s=new Array(a),l=new Array(a),c=new Array(a),u=new Array(a),h=0;h<a;++h)s[h]=l[h]=-1,c[h]=1/0,u[h]=!1;for(var h=0;h<o;++h){var f=t[h];if(2!==f.length)throw new Error(\"Input must be a graph\");var p=f[1],d=f[0];-1!==l[d]?l[d]=-2:l[d]=p,-1!==s[p]?s[p]=-2:s[p]=d}function g(t){if(u[t])return 1/0;var r,i,a,o,c,h=s[t],f=l[t];return h<0||f<0?1/0:(r=e[t],i=e[h],a=e[f],o=Math.abs(n(r,i,a)),c=Math.sqrt(Math.pow(i[0]-a[0],2)+Math.pow(i[1]-a[1],2)),o/c)}function v(t,e){var r=T[t],n=T[e];T[t]=n,T[e]=r,A[r]=e,A[n]=t}function m(t){return c[T[t]]}function y(t){return 1&t?t-1>>1:(t>>1)-1}function x(t){for(var e=m(t);;){var r=e,n=2*t+1,i=2*(t+1),a=t;if(n<S){var o=m(n);o<r&&(a=n,r=o)}if(i<S){var s=m(i);s<r&&(a=i)}if(a===t)return t;v(t,a),t=a}}function b(t){for(var e=m(t);t>0;){var r=y(t);if(r>=0){var n=m(r);if(e<n){v(t,r),t=r;continue}}return t}}function _(){if(S>0){var t=T[0];return v(0,S-1),S-=1,x(0),t}return-1}function w(t,e){var r=T[t];return c[r]===e?t:(c[r]=-1/0,b(t),_(),c[r]=e,b((S+=1)-1))}function k(t){if(!u[t]){u[t]=!0;var e=s[t],r=l[t];s[r]>=0&&(s[r]=e),l[e]>=0&&(l[e]=r),A[e]>=0&&w(A[e],g(e)),A[r]>=0&&w(A[r],g(r))}}for(var T=[],A=new Array(a),h=0;h<a;++h){var M=c[h]=g(h);M<1/0?(A[h]=T.length,T.push(h)):A[h]=-1}for(var S=T.length,h=S>>1;h>=0;--h)x(h);for(;;){var E=_();if(E<0||c[E]>r)break;k(E)}for(var C=[],h=0;h<a;++h)u[h]||(A[h]=C.length,C.push(e[h].slice()));C.length;function L(t,e){if(t[e]<0)return e;var r=e,n=e;do{var i=t[n];if(!u[n]||i<0||i===n)break;if(i=t[n=i],!u[n]||i<0||i===n)break;n=i,r=t[r]}while(r!==n);for(var a=e;a!==n;a=t[a])t[a]=n;return n}var P=[];return t.forEach(function(t){var e=L(s,t[0]),r=L(l,t[1]);if(e>=0&&r>=0&&e!==r){var n=A[e],i=A[r];n!==i&&P.push([n,i])}}),i.unique(i.normalize(P)),{positions:C,edges:P}};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\")},{\"robust-orientation\":510,\"simplicial-complex\":522}],525:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,a,o,s;if(e[0][0]<e[1][0])r=e[0],a=e[1];else{if(!(e[0][0]>e[1][0]))return i(e,t);r=e[1],a=e[0]}if(t[0][0]<t[1][0])o=t[0],s=t[1];else{if(!(t[0][0]>t[1][0]))return-i(t,e);o=t[1],s=t[0]}var l=n(r,a,s),c=n(r,a,o);if(l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;if(l=n(s,o,a),c=n(s,o,r),l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;return a[0]-s[0]};var n=t(\"robust-orientation\");function i(t,e){var r,i,a,o;if(e[0][0]<e[1][0])r=e[0],i=e[1];else{if(!(e[0][0]>e[1][0])){var s=Math.min(t[0][1],t[1][1]),l=Math.max(t[0][1],t[1][1]),c=Math.min(e[0][1],e[1][1]),u=Math.max(e[0][1],e[1][1]);return l<c?l-c:s>u?s-u:l-u}r=e[1],i=e[0]}t[0][1]<t[1][1]?(a=t[0],o=t[1]):(a=t[1],o=t[0]);var h=n(i,r,a);return h||((h=n(i,r,o))||o-i)}},{\"robust-orientation\":510}],526:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=2*e,n=new Array(r),a=0;a<e;++a){var l=t[a],c=l[0][0]<l[1][0];n[2*a]=new h(l[0][0],l,c,a),n[2*a+1]=new h(l[1][0],l,!c,a)}n.sort(function(t,e){var r=t.x-e.x;return r||((r=t.create-e.create)||Math.min(t.segment[0][1],t.segment[1][1])-Math.min(e.segment[0][1],e.segment[1][1]))});for(var f=i(o),p=[],d=[],g=[],a=0;a<r;){for(var v=n[a].x,m=[];a<r;){var y=n[a];if(y.x!==v)break;a+=1,y.segment[0][0]===y.x&&y.segment[1][0]===y.x?y.create&&(y.segment[0][1]<y.segment[1][1]?(m.push(new u(y.segment[0][1],y.index,!0,!0)),m.push(new u(y.segment[1][1],y.index,!1,!1))):(m.push(new u(y.segment[1][1],y.index,!0,!1)),m.push(new u(y.segment[0][1],y.index,!1,!0)))):f=y.create?f.insert(y.segment,y.index):f.remove(y.segment)}p.push(f.root),d.push(v),g.push(m)}return new s(p,d,g)};var n=t(\"binary-search-bounds\"),i=t(\"functional-red-black-tree\"),a=t(\"robust-orientation\"),o=t(\"./lib/order-segments\");function s(t,e,r){this.slabs=t,this.coordinates=e,this.horizontal=r}function l(t,e){return t.y-e}function c(t,e){for(var r=null;t;){var n,i,o=t.key;o[0][0]<o[1][0]?(n=o[0],i=o[1]):(n=o[1],i=o[0]);var s=a(n,i,e);if(s<0)t=t.left;else if(s>0)if(e[0]!==o[1][0])r=t,t=t.right;else{if(l=c(t.right,e))return l;t=t.left}else{if(e[0]!==o[1][0])return t;var l;if(l=c(t.right,e))return l;t=t.left}}return r}function u(t,e,r,n){this.y=t,this.index=e,this.start=r,this.closed=n}function h(t,e,r,n){this.x=t,this.segment=e,this.create=r,this.index=n}s.prototype.castUp=function(t){var e=n.le(this.coordinates,t[0]);if(e<0)return-1;this.slabs[e];var r=c(this.slabs[e],t),i=-1;if(r&&(i=r.value),this.coordinates[e]===t[0]){var s=null;if(r&&(s=r.key),e>0){var u=c(this.slabs[e-1],t);u&&(s?o(u.key,s)>0&&(s=u.key,i=u.value):(i=u.value,s=u.key))}var h=this.horizontal[e];if(h.length>0){var f=n.ge(h,t[1],l);if(f<h.length){var p=h[f];if(t[1]===p.y){if(p.closed)return p.index;for(;f<h.length-1&&h[f+1].y===t[1];)if((p=h[f+=1]).closed)return p.index;if(p.y===t[1]&&!p.start){if((f+=1)>=h.length)return i;p=h[f]}}if(p.start)if(s){var d=a(s[0],s[1],[t[0],p.y]);s[0][0]>s[1][0]&&(d=-d),d>0&&(i=p.index)}else i=p.index;else p.y!==t[1]&&(i=p.index)}}}return i}},{\"./lib/order-segments\":525,\"binary-search-bounds\":91,\"functional-red-black-tree\":230,\"robust-orientation\":510}],527:[function(t,e,r){\"use strict\";var n=t(\"robust-dot-product\"),i=t(\"robust-sum\");function a(t,e){var r=i(n(t,e),[e[e.length-1]]);return r[r.length-1]}function o(t,e,r,n){var i=-e/(n-e);i<0?i=0:i>1&&(i=1);for(var a=1-i,o=t.length,s=new Array(o),l=0;l<o;++l)s[l]=i*t[l]+a*r[l];return s}e.exports=function(t,e){for(var r=[],n=[],i=a(t[t.length-1],e),s=t[t.length-1],l=t[0],c=0;c<t.length;++c,s=l){var u=a(l=t[c],e);if(i<0&&u>0||i>0&&u<0){var h=o(s,u,l,i);r.push(h),n.push(h.slice())}u<0?n.push(l.slice()):u>0?r.push(l.slice()):(r.push(l.slice()),n.push(l.slice())),i=u}return{positive:r,negative:n}},e.exports.positive=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c>=0&&r.push(s.slice()),n=c}return r},e.exports.negative=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c<=0&&r.push(s.slice()),n=c}return r}},{\"robust-dot-product\":507,\"robust-sum\":515}],528:[function(t,e,r){!function(){\"use strict\";var t={not_string:/[^s]/,not_bool:/[^t]/,not_type:/[^T]/,not_primitive:/[^v]/,number:/[diefg]/,numeric_arg:/[bcdiefguxX]/,json:/[j]/,not_json:/[^j]/,text:/^[^\\x25]+/,modulo:/^\\x25{2}/,placeholder:/^\\x25(?:([1-9]\\d*)\\$|\\(([^)]+)\\))?(\\+)?(0|'[^$])?(-)?(\\d+)?(?:\\.(\\d+))?([b-gijostTuvxX])/,key:/^([a-z_][a-z_\\d]*)/i,key_access:/^\\.([a-z_][a-z_\\d]*)/i,index_access:/^\\[(\\d+)\\]/,sign:/^[+-]/};function e(r){return function(r,n){var i,a,o,s,l,c,u,h,f,p=1,d=r.length,g=\"\";for(a=0;a<d;a++)if(\"string\"==typeof r[a])g+=r[a];else if(\"object\"==typeof r[a]){if((s=r[a]).keys)for(i=n[p],o=0;o<s.keys.length;o++){if(null==i)throw new Error(e('[sprintf] Cannot access property \"%s\" of undefined value \"%s\"',s.keys[o],s.keys[o-1]));i=i[s.keys[o]]}else i=s.param_no?n[s.param_no]:n[p++];if(t.not_type.test(s.type)&&t.not_primitive.test(s.type)&&i instanceof Function&&(i=i()),t.numeric_arg.test(s.type)&&\"number\"!=typeof i&&isNaN(i))throw new TypeError(e(\"[sprintf] expecting number but found %T\",i));switch(t.number.test(s.type)&&(h=i>=0),s.type){case\"b\":i=parseInt(i,10).toString(2);break;case\"c\":i=String.fromCharCode(parseInt(i,10));break;case\"d\":case\"i\":i=parseInt(i,10);break;case\"j\":i=JSON.stringify(i,null,s.width?parseInt(s.width):0);break;case\"e\":i=s.precision?parseFloat(i).toExponential(s.precision):parseFloat(i).toExponential();break;case\"f\":i=s.precision?parseFloat(i).toFixed(s.precision):parseFloat(i);break;case\"g\":i=s.precision?String(Number(i.toPrecision(s.precision))):parseFloat(i);break;case\"o\":i=(parseInt(i,10)>>>0).toString(8);break;case\"s\":i=String(i),i=s.precision?i.substring(0,s.precision):i;break;case\"t\":i=String(!!i),i=s.precision?i.substring(0,s.precision):i;break;case\"T\":i=Object.prototype.toString.call(i).slice(8,-1).toLowerCase(),i=s.precision?i.substring(0,s.precision):i;break;case\"u\":i=parseInt(i,10)>>>0;break;case\"v\":i=i.valueOf(),i=s.precision?i.substring(0,s.precision):i;break;case\"x\":i=(parseInt(i,10)>>>0).toString(16);break;case\"X\":i=(parseInt(i,10)>>>0).toString(16).toUpperCase()}t.json.test(s.type)?g+=i:(!t.number.test(s.type)||h&&!s.sign?f=\"\":(f=h?\"+\":\"-\",i=i.toString().replace(t.sign,\"\")),c=s.pad_char?\"0\"===s.pad_char?\"0\":s.pad_char.charAt(1):\" \",u=s.width-(f+i).length,l=s.width&&u>0?c.repeat(u):\"\",g+=s.align?f+i+l:\"0\"===c?f+l+i:l+f+i)}return g}(function(e){if(i[e])return i[e];var r,n=e,a=[],o=0;for(;n;){if(null!==(r=t.text.exec(n)))a.push(r[0]);else if(null!==(r=t.modulo.exec(n)))a.push(\"%\");else{if(null===(r=t.placeholder.exec(n)))throw new SyntaxError(\"[sprintf] unexpected placeholder\");if(r[2]){o|=1;var s=[],l=r[2],c=[];if(null===(c=t.key.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");for(s.push(c[1]);\"\"!==(l=l.substring(c[0].length));)if(null!==(c=t.key_access.exec(l)))s.push(c[1]);else{if(null===(c=t.index_access.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");s.push(c[1])}r[2]=s}else o|=2;if(3===o)throw new Error(\"[sprintf] mixing positional and named placeholders is not (yet) supported\");a.push({placeholder:r[0],param_no:r[1],keys:r[2],sign:r[3],pad_char:r[4],align:r[5],width:r[6],precision:r[7],type:r[8]})}n=n.substring(r[0].length)}return i[e]=a}(r),arguments)}function n(t,r){return e.apply(null,[t].concat(r||[]))}var i=Object.create(null);\"undefined\"!=typeof r&&(r.sprintf=e,r.vsprintf=n),\"undefined\"!=typeof window&&(window.sprintf=e,window.vsprintf=n)}()},{}],529:[function(t,e,r){\"use strict\";var n=t(\"parenthesis\");e.exports=function(t,e,r){if(null==t)throw Error(\"First argument should be a string\");if(null==e)throw Error(\"Separator should be a string or a RegExp\");r?(\"string\"==typeof r||Array.isArray(r))&&(r={ignore:r}):r={},null==r.escape&&(r.escape=!0),null==r.ignore?r.ignore=[\"[]\",\"()\",\"{}\",\"<>\",'\"\"',\"''\",\"``\",\"\\u201c\\u201d\",\"\\xab\\xbb\"]:(\"string\"==typeof r.ignore&&(r.ignore=[r.ignore]),r.ignore=r.ignore.map(function(t){return 1===t.length&&(t+=t),t}));var i=n.parse(t,{flat:!0,brackets:r.ignore}),a=i[0].split(e);if(r.escape){for(var o=[],s=0;s<a.length;s++){var l=a[s],c=a[s+1];\"\\\\\"===l[l.length-1]&&\"\\\\\"!==l[l.length-2]?(o.push(l+e+c),s++):o.push(l)}a=o}for(s=0;s<a.length;s++)i[0]=a[s],a[s]=n.stringify(i,{flat:!0});return a}},{parenthesis:458}],530:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=new Array(e),n=new Array(e),i=new Array(e),a=new Array(e),o=new Array(e),s=new Array(e),l=0;l<e;++l)r[l]=-1,n[l]=0,i[l]=!1,a[l]=0,o[l]=-1,s[l]=[];var c,u=0,h=[],f=[];function p(e){var l=[e],c=[e];for(r[e]=n[e]=u,i[e]=!0,u+=1;c.length>0;){e=c[c.length-1];var p=t[e];if(a[e]<p.length){for(var d=a[e];d<p.length;++d){var g=p[d];if(r[g]<0){r[g]=n[g]=u,i[g]=!0,u+=1,l.push(g),c.push(g);break}i[g]&&(n[e]=0|Math.min(n[e],n[g])),o[g]>=0&&s[e].push(o[g])}a[e]=d}else{if(n[e]===r[e]){for(var v=[],m=[],y=0,d=l.length-1;d>=0;--d){var x=l[d];if(i[x]=!1,v.push(x),m.push(s[x]),y+=s[x].length,o[x]=h.length,x===e){l.length=d;break}}h.push(v);for(var b=new Array(y),d=0;d<m.length;d++)for(var _=0;_<m[d].length;_++)b[--y]=m[d][_];f.push(b)}c.pop()}}}for(var l=0;l<e;++l)r[l]<0&&p(l);for(var l=0;l<f.length;l++){var d=f[l];if(0!==d.length){d.sort(function(t,e){return t-e}),c=[d[0]];for(var g=1;g<d.length;g++)d[g]!==d[g-1]&&c.push(d[g]);f[l]=c}}return{components:h,adjacencyList:f}}},{}],531:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(t.dimension<=0)return{positions:[],cells:[]};if(1===t.dimension)return function(t,e){for(var r=a(t,e),n=r.length,i=new Array(n),o=new Array(n),s=0;s<n;++s)i[s]=[r[s]],o[s]=[s];return{positions:i,cells:o}}(t,e);var r=t.order.join()+\"-\"+t.dtype,s=o[r],e=+e||0;s||(s=o[r]=function(t,e){var r=t.length,a=[\"'use strict';\"],o=\"surfaceNets\"+t.join(\"_\")+\"d\"+e;a.push(\"var contour=genContour({\",\"order:[\",t.join(),\"],\",\"scalarArguments: 3,\",\"phase:function phaseFunc(p,a,b,c) { return (p > c)|0 },\"),\"generic\"===e&&a.push(\"getters:[0],\");for(var s=[],l=[],c=0;c<r;++c)s.push(\"d\"+c),l.push(\"d\"+c);for(var c=0;c<1<<r;++c)s.push(\"v\"+c),l.push(\"v\"+c);for(var c=0;c<1<<r;++c)s.push(\"p\"+c),l.push(\"p\"+c);s.push(\"a\",\"b\",\"c\"),l.push(\"a\",\"c\"),a.push(\"vertex:function vertexFunc(\",s.join(),\"){\");for(var u=[],c=0;c<1<<r;++c)u.push(\"(p\"+c+\"<<\"+c+\")\");a.push(\"var m=(\",u.join(\"+\"),\")|0;if(m===0||m===\",(1<<(1<<r))-1,\"){return}\");var h=[],f=[];1<<(1<<r)<=128?(a.push(\"switch(m){\"),f=a):a.push(\"switch(m>>>7){\");for(var c=0;c<1<<(1<<r);++c){if(1<<(1<<r)>128&&c%128==0){h.length>0&&f.push(\"}}\");var p=\"vExtra\"+h.length;a.push(\"case \",c>>>7,\":\",p,\"(m&0x7f,\",l.join(),\");break;\"),f=[\"function \",p,\"(m,\",l.join(),\"){switch(m){\"],h.push(f)}f.push(\"case \",127&c,\":\");for(var d=new Array(r),g=new Array(r),v=new Array(r),m=new Array(r),y=0,x=0;x<r;++x)d[x]=[],g[x]=[],v[x]=0,m[x]=0;for(var x=0;x<1<<r;++x)for(var b=0;b<r;++b){var _=x^1<<b;if(!(_>x)&&!(c&1<<_)!=!(c&1<<x)){var w=1;c&1<<_?g[b].push(\"v\"+_+\"-v\"+x):(g[b].push(\"v\"+x+\"-v\"+_),w=-w),w<0?(d[b].push(\"-v\"+x+\"-v\"+_),v[b]+=2):(d[b].push(\"v\"+x+\"+v\"+_),v[b]-=2),y+=1;for(var k=0;k<r;++k)k!==b&&(_&1<<k?m[k]+=1:m[k]-=1)}}for(var T=[],b=0;b<r;++b)if(0===d[b].length)T.push(\"d\"+b+\"-0.5\");else{var A=\"\";v[b]<0?A=v[b]+\"*c\":v[b]>0&&(A=\"+\"+v[b]+\"*c\");var M=d[b].length/y*.5,S=.5+m[b]/y*.5;T.push(\"d\"+b+\"-\"+S+\"-\"+M+\"*(\"+d[b].join(\"+\")+A+\")/(\"+g[b].join(\"+\")+\")\")}f.push(\"a.push([\",T.join(),\"]);\",\"break;\")}a.push(\"}},\"),h.length>0&&f.push(\"}}\");for(var E=[],c=0;c<1<<r-1;++c)E.push(\"v\"+c);E.push(\"c0\",\"c1\",\"p0\",\"p1\",\"a\",\"b\",\"c\"),a.push(\"cell:function cellFunc(\",E.join(),\"){\");var C=i(r-1);a.push(\"if(p0){b.push(\",C.map(function(t){return\"[\"+t.map(function(t){return\"v\"+t})+\"]\"}).join(),\")}else{b.push(\",C.map(function(t){var e=t.slice();return e.reverse(),\"[\"+e.map(function(t){return\"v\"+t})+\"]\"}).join(),\")}}});function \",o,\"(array,level){var verts=[],cells=[];contour(array,verts,cells,level);return {positions:verts,cells:cells};} return \",o,\";\");for(var c=0;c<h.length;++c)a.push(h[c].join(\"\"));return new Function(\"genContour\",a.join(\"\"))(n)}(t.order,t.dtype));return s(t,e)};var n=t(\"ndarray-extract-contour\"),i=t(\"triangulate-hypercube\"),a=t(\"zero-crossings\");var o={}},{\"ndarray-extract-contour\":439,\"triangulate-hypercube\":541,\"zero-crossings\":574}],532:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=function(){return function(t,e){if(Array.isArray(t))return t;if(Symbol.iterator in Object(t))return function(t,e){var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{!n&&s.return&&s.return()}finally{if(i)throw a}}return r}(t,e);throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")}}(),i=2*Math.PI,a=function(t,e,r,n,i,a,o){var s=t.x,l=t.y;return{x:n*(s*=e)-i*(l*=r)+a,y:i*s+n*l+o}},o=function(t,e){var r=.551915024494*(e<0?-1:1),n=Math.cos(t),i=Math.sin(t),a=Math.cos(t+e),o=Math.sin(t+e);return[{x:n-i*r,y:i+n*r},{x:a+o*r,y:o-a*r},{x:a,y:o}]},s=function(t,e,r,n){var i=t*n-e*r<0?-1:1,a=(t*r+e*n)/(Math.sqrt(t*t+e*e)*Math.sqrt(t*t+e*e));return a>1&&(a=1),a<-1&&(a=-1),i*Math.acos(a)};r.default=function(t){var e=t.px,r=t.py,l=t.cx,c=t.cy,u=t.rx,h=t.ry,f=t.xAxisRotation,p=void 0===f?0:f,d=t.largeArcFlag,g=void 0===d?0:d,v=t.sweepFlag,m=void 0===v?0:v,y=[];if(0===u||0===h)return[];var x=Math.sin(p*i/360),b=Math.cos(p*i/360),_=b*(e-l)/2+x*(r-c)/2,w=-x*(e-l)/2+b*(r-c)/2;if(0===_&&0===w)return[];u=Math.abs(u),h=Math.abs(h);var k=Math.pow(_,2)/Math.pow(u,2)+Math.pow(w,2)/Math.pow(h,2);k>1&&(u*=Math.sqrt(k),h*=Math.sqrt(k));var T=function(t,e,r,n,a,o,l,c,u,h,f,p){var d=Math.pow(a,2),g=Math.pow(o,2),v=Math.pow(f,2),m=Math.pow(p,2),y=d*g-d*m-g*v;y<0&&(y=0),y/=d*m+g*v;var x=(y=Math.sqrt(y)*(l===c?-1:1))*a/o*p,b=y*-o/a*f,_=h*x-u*b+(t+r)/2,w=u*x+h*b+(e+n)/2,k=(f-x)/a,T=(p-b)/o,A=(-f-x)/a,M=(-p-b)/o,S=s(1,0,k,T),E=s(k,T,A,M);return 0===c&&E>0&&(E-=i),1===c&&E<0&&(E+=i),[_,w,S,E]}(e,r,l,c,u,h,g,m,x,b,_,w),A=n(T,4),M=A[0],S=A[1],E=A[2],C=A[3],L=Math.abs(C)/(i/4);Math.abs(1-L)<1e-7&&(L=1);var P=Math.max(Math.ceil(L),1);C/=P;for(var O=0;O<P;O++)y.push(o(E,C)),E+=C;return y.map(function(t){var e=a(t[0],u,h,b,x,M,S),r=e.x,n=e.y,i=a(t[1],u,h,b,x,M,S),o=i.x,s=i.y,l=a(t[2],u,h,b,x,M,S);return{x1:r,y1:n,x2:o,y2:s,x:l.x,y:l.y}})},e.exports=r.default},{}],533:[function(t,e,r){\"use strict\";var n=t(\"parse-svg-path\"),i=t(\"abs-svg-path\"),a=t(\"normalize-svg-path\"),o=t(\"is-svg-path\"),s=t(\"assert\");e.exports=function(t){Array.isArray(t)&&1===t.length&&\"string\"==typeof t[0]&&(t=t[0]);\"string\"==typeof t&&(s(o(t),\"String is not an SVG path.\"),t=n(t));if(s(Array.isArray(t),\"Argument should be a string or an array of path segments.\"),t=i(t),!(t=a(t)).length)return[0,0,0,0];for(var e=[1/0,1/0,-1/0,-1/0],r=0,l=t.length;r<l;r++)for(var c=t[r].slice(1),u=0;u<c.length;u+=2)c[u+0]<e[0]&&(e[0]=c[u+0]),c[u+1]<e[1]&&(e[1]=c[u+1]),c[u+0]>e[2]&&(e[2]=c[u+0]),c[u+1]>e[3]&&(e[3]=c[u+1]);return e}},{\"abs-svg-path\":60,assert:68,\"is-svg-path\":424,\"normalize-svg-path\":534,\"parse-svg-path\":460}],534:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=[],o=0,s=0,l=0,c=0,u=null,h=null,f=0,p=0,d=0,g=t.length;d<g;d++){var v=t[d],m=v[0];switch(m){case\"M\":l=v[1],c=v[2];break;case\"A\":var y=n({px:f,py:p,cx:v[6],cy:v[7],rx:v[1],ry:v[2],xAxisRotation:v[3],largeArcFlag:v[4],sweepFlag:v[5]});if(!y.length)continue;for(var x,b=0;b<y.length;b++)x=y[b],v=[\"C\",x.x1,x.y1,x.x2,x.y2,x.x,x.y],b<y.length-1&&r.push(v);break;case\"S\":var _=f,w=p;\"C\"!=e&&\"S\"!=e||(_+=_-o,w+=w-s),v=[\"C\",_,w,v[1],v[2],v[3],v[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(u=2*f-u,h=2*p-h):(u=f,h=p),v=a(f,p,u,h,v[1],v[2]);break;case\"Q\":u=v[1],h=v[2],v=a(f,p,v[1],v[2],v[3],v[4]);break;case\"L\":v=i(f,p,v[1],v[2]);break;case\"H\":v=i(f,p,v[1],p);break;case\"V\":v=i(f,p,f,v[1]);break;case\"Z\":v=i(f,p,l,c)}e=m,f=v[v.length-2],p=v[v.length-1],v.length>4?(o=v[v.length-4],s=v[v.length-3]):(o=f,s=p),r.push(v)}return r};var n=t(\"svg-arc-to-cubic-bezier\");function i(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function a(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}},{\"svg-arc-to-cubic-bezier\":532}],535:[function(t,e,r){\"use strict\";var n,i=t(\"svg-path-bounds\"),a=t(\"parse-svg-path\"),o=t(\"draw-svg-path\"),s=t(\"is-svg-path\"),l=t(\"bitmap-sdf\"),c=document.createElement(\"canvas\"),u=c.getContext(\"2d\");e.exports=function(t,e){if(!s(t))throw Error(\"Argument should be valid svg path string\");e||(e={});var r,h;e.shape?(r=e.shape[0],h=e.shape[1]):(r=c.width=e.w||e.width||200,h=c.height=e.h||e.height||200);var f=Math.min(r,h),p=e.stroke||0,d=e.viewbox||e.viewBox||i(t),g=[r/(d[2]-d[0]),h/(d[3]-d[1])],v=Math.min(g[0]||0,g[1]||0)/2;u.fillStyle=\"black\",u.fillRect(0,0,r,h),u.fillStyle=\"white\",p&&(\"number\"!=typeof p&&(p=1),u.strokeStyle=p>0?\"white\":\"black\",u.lineWidth=Math.abs(p));if(u.translate(.5*r,.5*h),u.scale(v,v),function(){if(null!=n)return n;var t=document.createElement(\"canvas\").getContext(\"2d\");if(t.canvas.width=t.canvas.height=1,!window.Path2D)return n=!1;var e=new Path2D(\"M0,0h1v1h-1v-1Z\");t.fillStyle=\"black\",t.fill(e);var r=t.getImageData(0,0,1,1);return n=r&&r.data&&255===r.data[3]}()){var m=new Path2D(t);u.fill(m),p&&u.stroke(m)}else{var y=a(t);o(u,y),u.fill(),p&&u.stroke()}return u.setTransform(1,0,0,1,0,0),l(u,{cutoff:null!=e.cutoff?e.cutoff:.5,radius:null!=e.radius?e.radius:.5*f})}},{\"bitmap-sdf\":93,\"draw-svg-path\":168,\"is-svg-path\":424,\"parse-svg-path\":460,\"svg-path-bounds\":533}],536:[function(t,e,r){(function(r){\"use strict\";e.exports=function t(e,r,i){var i=i||{};var o=a[e];o||(o=a[e]={\" \":{data:new Float32Array(0),shape:.2}});var s=o[r];if(!s)if(r.length<=1||!/\\d/.test(r))s=o[r]=function(t){for(var e=t.cells,r=t.positions,n=new Float32Array(6*e.length),i=0,a=0,o=0;o<e.length;++o)for(var s=e[o],l=0;l<3;++l){var c=r[s[l]];n[i++]=c[0],n[i++]=c[1]+1.4,a=Math.max(c[0],a)}return{data:n,shape:a}}(n(r,{triangles:!0,font:e,textAlign:i.textAlign||\"left\",textBaseline:\"alphabetic\",styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0}}));else{for(var l=r.split(/(\\d|\\s)/),c=new Array(l.length),u=0,h=0,f=0;f<l.length;++f)c[f]=t(e,l[f]),u+=c[f].data.length,h+=c[f].shape,f>0&&(h+=.02);for(var p=new Float32Array(u),d=0,g=-.5*h,f=0;f<c.length;++f){for(var v=c[f].data,m=0;m<v.length;m+=2)p[d++]=v[m]+g,p[d++]=v[m+1];g+=c[f].shape+.02}s=o[r]={data:p,shape:h}}return s};var n=t(\"vectorize-text\"),i=window||r.global||{},a=i.__TEXT_CACHE||{};i.__TEXT_CACHE={}}).call(this,t(\"_process\"))},{_process:482,\"vectorize-text\":550}],537:[function(t,e,r){!function(t){var r=/^\\s+/,n=/\\s+$/,i=0,a=t.round,o=t.min,s=t.max,l=t.random;function c(e,l){if(l=l||{},(e=e||\"\")instanceof c)return e;if(!(this instanceof c))return new c(e,l);var u=function(e){var i={r:0,g:0,b:0},a=1,l=null,c=null,u=null,h=!1,f=!1;\"string\"==typeof e&&(e=function(t){t=t.replace(r,\"\").replace(n,\"\").toLowerCase();var e,i=!1;if(S[t])t=S[t],i=!0;else if(\"transparent\"==t)return{r:0,g:0,b:0,a:0,format:\"name\"};if(e=j.rgb.exec(t))return{r:e[1],g:e[2],b:e[3]};if(e=j.rgba.exec(t))return{r:e[1],g:e[2],b:e[3],a:e[4]};if(e=j.hsl.exec(t))return{h:e[1],s:e[2],l:e[3]};if(e=j.hsla.exec(t))return{h:e[1],s:e[2],l:e[3],a:e[4]};if(e=j.hsv.exec(t))return{h:e[1],s:e[2],v:e[3]};if(e=j.hsva.exec(t))return{h:e[1],s:e[2],v:e[3],a:e[4]};if(e=j.hex8.exec(t))return{r:O(e[1]),g:O(e[2]),b:O(e[3]),a:R(e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex6.exec(t))return{r:O(e[1]),g:O(e[2]),b:O(e[3]),format:i?\"name\":\"hex\"};if(e=j.hex4.exec(t))return{r:O(e[1]+\"\"+e[1]),g:O(e[2]+\"\"+e[2]),b:O(e[3]+\"\"+e[3]),a:R(e[4]+\"\"+e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex3.exec(t))return{r:O(e[1]+\"\"+e[1]),g:O(e[2]+\"\"+e[2]),b:O(e[3]+\"\"+e[3]),format:i?\"name\":\"hex\"};return!1}(e));\"object\"==typeof e&&(U(e.r)&&U(e.g)&&U(e.b)?(p=e.r,d=e.g,g=e.b,i={r:255*L(p,255),g:255*L(d,255),b:255*L(g,255)},h=!0,f=\"%\"===String(e.r).substr(-1)?\"prgb\":\"rgb\"):U(e.h)&&U(e.s)&&U(e.v)?(l=I(e.s),c=I(e.v),i=function(e,r,n){e=6*L(e,360),r=L(r,100),n=L(n,100);var i=t.floor(e),a=e-i,o=n*(1-r),s=n*(1-a*r),l=n*(1-(1-a)*r),c=i%6;return{r:255*[n,s,o,o,l,n][c],g:255*[l,n,n,s,o,o][c],b:255*[o,o,l,n,n,s][c]}}(e.h,l,c),h=!0,f=\"hsv\"):U(e.h)&&U(e.s)&&U(e.l)&&(l=I(e.s),u=I(e.l),i=function(t,e,r){var n,i,a;function o(t,e,r){return r<0&&(r+=1),r>1&&(r-=1),r<1/6?t+6*(e-t)*r:r<.5?e:r<2/3?t+(e-t)*(2/3-r)*6:t}if(t=L(t,360),e=L(e,100),r=L(r,100),0===e)n=i=a=r;else{var s=r<.5?r*(1+e):r+e-r*e,l=2*r-s;n=o(l,s,t+1/3),i=o(l,s,t),a=o(l,s,t-1/3)}return{r:255*n,g:255*i,b:255*a}}(e.h,l,u),h=!0,f=\"hsl\"),e.hasOwnProperty(\"a\")&&(a=e.a));var p,d,g;return a=C(a),{ok:h,format:e.format||f,r:o(255,s(i.r,0)),g:o(255,s(i.g,0)),b:o(255,s(i.b,0)),a:a}}(e);this._originalInput=e,this._r=u.r,this._g=u.g,this._b=u.b,this._a=u.a,this._roundA=a(100*this._a)/100,this._format=l.format||u.format,this._gradientType=l.gradientType,this._r<1&&(this._r=a(this._r)),this._g<1&&(this._g=a(this._g)),this._b<1&&(this._b=a(this._b)),this._ok=u.ok,this._tc_id=i++}function u(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=(a+l)/2;if(a==l)n=i=0;else{var u=a-l;switch(i=c>.5?u/(2-a-l):u/(a+l),a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,l:c}}function h(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=a,u=a-l;if(i=0===a?0:u/a,a==l)n=0;else{switch(a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,v:c}}function f(t,e,r,n){var i=[z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16))];return n&&i[0].charAt(0)==i[0].charAt(1)&&i[1].charAt(0)==i[1].charAt(1)&&i[2].charAt(0)==i[2].charAt(1)?i[0].charAt(0)+i[1].charAt(0)+i[2].charAt(0):i.join(\"\")}function p(t,e,r,n){return[z(D(n)),z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16))].join(\"\")}function d(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s-=e/100,r.s=P(r.s),c(r)}function g(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s+=e/100,r.s=P(r.s),c(r)}function v(t){return c(t).desaturate(100)}function m(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l+=e/100,r.l=P(r.l),c(r)}function y(t,e){e=0===e?0:e||10;var r=c(t).toRgb();return r.r=s(0,o(255,r.r-a(-e/100*255))),r.g=s(0,o(255,r.g-a(-e/100*255))),r.b=s(0,o(255,r.b-a(-e/100*255))),c(r)}function x(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l-=e/100,r.l=P(r.l),c(r)}function b(t,e){var r=c(t).toHsl(),n=(r.h+e)%360;return r.h=n<0?360+n:n,c(r)}function _(t){var e=c(t).toHsl();return e.h=(e.h+180)%360,c(e)}function w(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+120)%360,s:e.s,l:e.l}),c({h:(r+240)%360,s:e.s,l:e.l})]}function k(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+90)%360,s:e.s,l:e.l}),c({h:(r+180)%360,s:e.s,l:e.l}),c({h:(r+270)%360,s:e.s,l:e.l})]}function T(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+72)%360,s:e.s,l:e.l}),c({h:(r+216)%360,s:e.s,l:e.l})]}function A(t,e,r){e=e||6,r=r||30;var n=c(t).toHsl(),i=360/r,a=[c(t)];for(n.h=(n.h-(i*e>>1)+720)%360;--e;)n.h=(n.h+i)%360,a.push(c(n));return a}function M(t,e){e=e||6;for(var r=c(t).toHsv(),n=r.h,i=r.s,a=r.v,o=[],s=1/e;e--;)o.push(c({h:n,s:i,v:a})),a=(a+s)%1;return o}c.prototype={isDark:function(){return this.getBrightness()<128},isLight:function(){return!this.isDark()},isValid:function(){return this._ok},getOriginalInput:function(){return this._originalInput},getFormat:function(){return this._format},getAlpha:function(){return this._a},getBrightness:function(){var t=this.toRgb();return(299*t.r+587*t.g+114*t.b)/1e3},getLuminance:function(){var e,r,n,i=this.toRgb();return e=i.r/255,r=i.g/255,n=i.b/255,.2126*(e<=.03928?e/12.92:t.pow((e+.055)/1.055,2.4))+.7152*(r<=.03928?r/12.92:t.pow((r+.055)/1.055,2.4))+.0722*(n<=.03928?n/12.92:t.pow((n+.055)/1.055,2.4))},setAlpha:function(t){return this._a=C(t),this._roundA=a(100*this._a)/100,this},toHsv:function(){var t=h(this._r,this._g,this._b);return{h:360*t.h,s:t.s,v:t.v,a:this._a}},toHsvString:function(){var t=h(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.v);return 1==this._a?\"hsv(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsva(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHsl:function(){var t=u(this._r,this._g,this._b);return{h:360*t.h,s:t.s,l:t.l,a:this._a}},toHslString:function(){var t=u(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.l);return 1==this._a?\"hsl(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsla(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHex:function(t){return f(this._r,this._g,this._b,t)},toHexString:function(t){return\"#\"+this.toHex(t)},toHex8:function(t){return function(t,e,r,n,i){var o=[z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16)),z(D(n))];if(i&&o[0].charAt(0)==o[0].charAt(1)&&o[1].charAt(0)==o[1].charAt(1)&&o[2].charAt(0)==o[2].charAt(1)&&o[3].charAt(0)==o[3].charAt(1))return o[0].charAt(0)+o[1].charAt(0)+o[2].charAt(0)+o[3].charAt(0);return o.join(\"\")}(this._r,this._g,this._b,this._a,t)},toHex8String:function(t){return\"#\"+this.toHex8(t)},toRgb:function(){return{r:a(this._r),g:a(this._g),b:a(this._b),a:this._a}},toRgbString:function(){return 1==this._a?\"rgb(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\")\":\"rgba(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\", \"+this._roundA+\")\"},toPercentageRgb:function(){return{r:a(100*L(this._r,255))+\"%\",g:a(100*L(this._g,255))+\"%\",b:a(100*L(this._b,255))+\"%\",a:this._a}},toPercentageRgbString:function(){return 1==this._a?\"rgb(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%)\":\"rgba(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%, \"+this._roundA+\")\"},toName:function(){return 0===this._a?\"transparent\":!(this._a<1)&&(E[f(this._r,this._g,this._b,!0)]||!1)},toFilter:function(t){var e=\"#\"+p(this._r,this._g,this._b,this._a),r=e,n=this._gradientType?\"GradientType = 1, \":\"\";if(t){var i=c(t);r=\"#\"+p(i._r,i._g,i._b,i._a)}return\"progid:DXImageTransform.Microsoft.gradient(\"+n+\"startColorstr=\"+e+\",endColorstr=\"+r+\")\"},toString:function(t){var e=!!t;t=t||this._format;var r=!1,n=this._a<1&&this._a>=0;return e||!n||\"hex\"!==t&&\"hex6\"!==t&&\"hex3\"!==t&&\"hex4\"!==t&&\"hex8\"!==t&&\"name\"!==t?(\"rgb\"===t&&(r=this.toRgbString()),\"prgb\"===t&&(r=this.toPercentageRgbString()),\"hex\"!==t&&\"hex6\"!==t||(r=this.toHexString()),\"hex3\"===t&&(r=this.toHexString(!0)),\"hex4\"===t&&(r=this.toHex8String(!0)),\"hex8\"===t&&(r=this.toHex8String()),\"name\"===t&&(r=this.toName()),\"hsl\"===t&&(r=this.toHslString()),\"hsv\"===t&&(r=this.toHsvString()),r||this.toHexString()):\"name\"===t&&0===this._a?this.toName():this.toRgbString()},clone:function(){return c(this.toString())},_applyModification:function(t,e){var r=t.apply(null,[this].concat([].slice.call(e)));return this._r=r._r,this._g=r._g,this._b=r._b,this.setAlpha(r._a),this},lighten:function(){return this._applyModification(m,arguments)},brighten:function(){return this._applyModification(y,arguments)},darken:function(){return this._applyModification(x,arguments)},desaturate:function(){return this._applyModification(d,arguments)},saturate:function(){return this._applyModification(g,arguments)},greyscale:function(){return this._applyModification(v,arguments)},spin:function(){return this._applyModification(b,arguments)},_applyCombination:function(t,e){return t.apply(null,[this].concat([].slice.call(e)))},analogous:function(){return this._applyCombination(A,arguments)},complement:function(){return this._applyCombination(_,arguments)},monochromatic:function(){return this._applyCombination(M,arguments)},splitcomplement:function(){return this._applyCombination(T,arguments)},triad:function(){return this._applyCombination(w,arguments)},tetrad:function(){return this._applyCombination(k,arguments)}},c.fromRatio=function(t,e){if(\"object\"==typeof t){var r={};for(var n in t)t.hasOwnProperty(n)&&(r[n]=\"a\"===n?t[n]:I(t[n]));t=r}return c(t,e)},c.equals=function(t,e){return!(!t||!e)&&c(t).toRgbString()==c(e).toRgbString()},c.random=function(){return c.fromRatio({r:l(),g:l(),b:l()})},c.mix=function(t,e,r){r=0===r?0:r||50;var n=c(t).toRgb(),i=c(e).toRgb(),a=r/100;return c({r:(i.r-n.r)*a+n.r,g:(i.g-n.g)*a+n.g,b:(i.b-n.b)*a+n.b,a:(i.a-n.a)*a+n.a})},c.readability=function(e,r){var n=c(e),i=c(r);return(t.max(n.getLuminance(),i.getLuminance())+.05)/(t.min(n.getLuminance(),i.getLuminance())+.05)},c.isReadable=function(t,e,r){var n,i,a=c.readability(t,e);switch(i=!1,(n=function(t){var e,r;e=((t=t||{level:\"AA\",size:\"small\"}).level||\"AA\").toUpperCase(),r=(t.size||\"small\").toLowerCase(),\"AA\"!==e&&\"AAA\"!==e&&(e=\"AA\");\"small\"!==r&&\"large\"!==r&&(r=\"small\");return{level:e,size:r}}(r)).level+n.size){case\"AAsmall\":case\"AAAlarge\":i=a>=4.5;break;case\"AAlarge\":i=a>=3;break;case\"AAAsmall\":i=a>=7}return i},c.mostReadable=function(t,e,r){var n,i,a,o,s=null,l=0;i=(r=r||{}).includeFallbackColors,a=r.level,o=r.size;for(var u=0;u<e.length;u++)(n=c.readability(t,e[u]))>l&&(l=n,s=c(e[u]));return c.isReadable(t,s,{level:a,size:o})||!i?s:(r.includeFallbackColors=!1,c.mostReadable(t,[\"#fff\",\"#000\"],r))};var S=c.names={aliceblue:\"f0f8ff\",antiquewhite:\"faebd7\",aqua:\"0ff\",aquamarine:\"7fffd4\",azure:\"f0ffff\",beige:\"f5f5dc\",bisque:\"ffe4c4\",black:\"000\",blanchedalmond:\"ffebcd\",blue:\"00f\",blueviolet:\"8a2be2\",brown:\"a52a2a\",burlywood:\"deb887\",burntsienna:\"ea7e5d\",cadetblue:\"5f9ea0\",chartreuse:\"7fff00\",chocolate:\"d2691e\",coral:\"ff7f50\",cornflowerblue:\"6495ed\",cornsilk:\"fff8dc\",crimson:\"dc143c\",cyan:\"0ff\",darkblue:\"00008b\",darkcyan:\"008b8b\",darkgoldenrod:\"b8860b\",darkgray:\"a9a9a9\",darkgreen:\"006400\",darkgrey:\"a9a9a9\",darkkhaki:\"bdb76b\",darkmagenta:\"8b008b\",darkolivegreen:\"556b2f\",darkorange:\"ff8c00\",darkorchid:\"9932cc\",darkred:\"8b0000\",darksalmon:\"e9967a\",darkseagreen:\"8fbc8f\",darkslateblue:\"483d8b\",darkslategray:\"2f4f4f\",darkslategrey:\"2f4f4f\",darkturquoise:\"00ced1\",darkviolet:\"9400d3\",deeppink:\"ff1493\",deepskyblue:\"00bfff\",dimgray:\"696969\",dimgrey:\"696969\",dodgerblue:\"1e90ff\",firebrick:\"b22222\",floralwhite:\"fffaf0\",forestgreen:\"228b22\",fuchsia:\"f0f\",gainsboro:\"dcdcdc\",ghostwhite:\"f8f8ff\",gold:\"ffd700\",goldenrod:\"daa520\",gray:\"808080\",green:\"008000\",greenyellow:\"adff2f\",grey:\"808080\",honeydew:\"f0fff0\",hotpink:\"ff69b4\",indianred:\"cd5c5c\",indigo:\"4b0082\",ivory:\"fffff0\",khaki:\"f0e68c\",lavender:\"e6e6fa\",lavenderblush:\"fff0f5\",lawngreen:\"7cfc00\",lemonchiffon:\"fffacd\",lightblue:\"add8e6\",lightcoral:\"f08080\",lightcyan:\"e0ffff\",lightgoldenrodyellow:\"fafad2\",lightgray:\"d3d3d3\",lightgreen:\"90ee90\",lightgrey:\"d3d3d3\",lightpink:\"ffb6c1\",lightsalmon:\"ffa07a\",lightseagreen:\"20b2aa\",lightskyblue:\"87cefa\",lightslategray:\"789\",lightslategrey:\"789\",lightsteelblue:\"b0c4de\",lightyellow:\"ffffe0\",lime:\"0f0\",limegreen:\"32cd32\",linen:\"faf0e6\",magenta:\"f0f\",maroon:\"800000\",mediumaquamarine:\"66cdaa\",mediumblue:\"0000cd\",mediumorchid:\"ba55d3\",mediumpurple:\"9370db\",mediumseagreen:\"3cb371\",mediumslateblue:\"7b68ee\",mediumspringgreen:\"00fa9a\",mediumturquoise:\"48d1cc\",mediumvioletred:\"c71585\",midnightblue:\"191970\",mintcream:\"f5fffa\",mistyrose:\"ffe4e1\",moccasin:\"ffe4b5\",navajowhite:\"ffdead\",navy:\"000080\",oldlace:\"fdf5e6\",olive:\"808000\",olivedrab:\"6b8e23\",orange:\"ffa500\",orangered:\"ff4500\",orchid:\"da70d6\",palegoldenrod:\"eee8aa\",palegreen:\"98fb98\",paleturquoise:\"afeeee\",palevioletred:\"db7093\",papayawhip:\"ffefd5\",peachpuff:\"ffdab9\",peru:\"cd853f\",pink:\"ffc0cb\",plum:\"dda0dd\",powderblue:\"b0e0e6\",purple:\"800080\",rebeccapurple:\"663399\",red:\"f00\",rosybrown:\"bc8f8f\",royalblue:\"4169e1\",saddlebrown:\"8b4513\",salmon:\"fa8072\",sandybrown:\"f4a460\",seagreen:\"2e8b57\",seashell:\"fff5ee\",sienna:\"a0522d\",silver:\"c0c0c0\",skyblue:\"87ceeb\",slateblue:\"6a5acd\",slategray:\"708090\",slategrey:\"708090\",snow:\"fffafa\",springgreen:\"00ff7f\",steelblue:\"4682b4\",tan:\"d2b48c\",teal:\"008080\",thistle:\"d8bfd8\",tomato:\"ff6347\",turquoise:\"40e0d0\",violet:\"ee82ee\",wheat:\"f5deb3\",white:\"fff\",whitesmoke:\"f5f5f5\",yellow:\"ff0\",yellowgreen:\"9acd32\"},E=c.hexNames=function(t){var e={};for(var r in t)t.hasOwnProperty(r)&&(e[t[r]]=r);return e}(S);function C(t){return t=parseFloat(t),(isNaN(t)||t<0||t>1)&&(t=1),t}function L(e,r){(function(t){return\"string\"==typeof t&&-1!=t.indexOf(\".\")&&1===parseFloat(t)})(e)&&(e=\"100%\");var n=function(t){return\"string\"==typeof t&&-1!=t.indexOf(\"%\")}(e);return e=o(r,s(0,parseFloat(e))),n&&(e=parseInt(e*r,10)/100),t.abs(e-r)<1e-6?1:e%r/parseFloat(r)}function P(t){return o(1,s(0,t))}function O(t){return parseInt(t,16)}function z(t){return 1==t.length?\"0\"+t:\"\"+t}function I(t){return t<=1&&(t=100*t+\"%\"),t}function D(e){return t.round(255*parseFloat(e)).toString(16)}function R(t){return O(t)/255}var F,B,N,j=(B=\"[\\\\s|\\\\(]+(\"+(F=\"(?:[-\\\\+]?\\\\d*\\\\.\\\\d+%?)|(?:[-\\\\+]?\\\\d+%?)\")+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",N=\"[\\\\s|\\\\(]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",{CSS_UNIT:new RegExp(F),rgb:new RegExp(\"rgb\"+B),rgba:new RegExp(\"rgba\"+N),hsl:new RegExp(\"hsl\"+B),hsla:new RegExp(\"hsla\"+N),hsv:new RegExp(\"hsv\"+B),hsva:new RegExp(\"hsva\"+N),hex3:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex6:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/,hex4:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex8:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/});function U(t){return!!j.CSS_UNIT.exec(t)}\"undefined\"!=typeof e&&e.exports?e.exports=c:window.tinycolor=c}(Math)},{}],538:[function(t,e,r){\"use strict\";e.exports=i,e.exports.float32=e.exports.float=i,e.exports.fract32=e.exports.fract=function(t){if(t.length){for(var e=i(t),r=0,n=e.length;r<n;r++)e[r]=t[r]-e[r];return e}return i(t-i(t))};var n=new Float32Array(1);function i(t){if(t.length){if(t instanceof Float32Array)return t;var e=new Float32Array(t);return e.set(t),e}return n[0]=t,n[0]}},{}],539:[function(t,e,r){\"use strict\";var n=t(\"parse-unit\");e.exports=o;var i=96;function a(t,e){var r=n(getComputedStyle(t).getPropertyValue(e));return r[0]*o(r[1],t)}function o(t,e){switch(e=e||document.body,t=(t||\"px\").trim().toLowerCase(),e!==window&&e!==document||(e=document.body),t){case\"%\":return e.clientHeight/100;case\"ch\":case\"ex\":return function(t,e){var r=document.createElement(\"div\");r.style[\"font-size\"]=\"128\"+t,e.appendChild(r);var n=a(r,\"font-size\")/128;return e.removeChild(r),n}(t,e);case\"em\":return a(e,\"font-size\");case\"rem\":return a(document.body,\"font-size\");case\"vw\":return window.innerWidth/100;case\"vh\":return window.innerHeight/100;case\"vmin\":return Math.min(window.innerWidth,window.innerHeight)/100;case\"vmax\":return Math.max(window.innerWidth,window.innerHeight)/100;case\"in\":return i;case\"cm\":return i/2.54;case\"mm\":return i/25.4;case\"pt\":return i/72;case\"pc\":return i/6}return 1}},{\"parse-unit\":461}],540:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e=function(t){return t},r=function(t){if(null==(r=t.transform))return e;var r,n,i,a=r.scale[0],o=r.scale[1],s=r.translate[0],l=r.translate[1];return function(t,e){return e||(n=i=0),t[0]=(n+=t[0])*a+s,t[1]=(i+=t[1])*o+l,t}},n=function(t){var e=t.bbox;function n(t){l[0]=t[0],l[1]=t[1],s(l),l[0]<c&&(c=l[0]),l[0]>h&&(h=l[0]),l[1]<u&&(u=l[1]),l[1]>f&&(f=l[1])}function i(t){switch(t.type){case\"GeometryCollection\":t.geometries.forEach(i);break;case\"Point\":n(t.coordinates);break;case\"MultiPoint\":t.coordinates.forEach(n)}}if(!e){var a,o,s=r(t),l=new Array(2),c=1/0,u=c,h=-c,f=-c;for(o in t.arcs.forEach(function(t){for(var e=-1,r=t.length;++e<r;)a=t[e],l[0]=a[0],l[1]=a[1],s(l,e),l[0]<c&&(c=l[0]),l[0]>h&&(h=l[0]),l[1]<u&&(u=l[1]),l[1]>f&&(f=l[1])}),t.objects)i(t.objects[o]);e=t.bbox=[c,u,h,f]}return e},i=function(t,e){for(var r,n=t.length,i=n-e;i<--n;)r=t[i],t[i++]=t[n],t[n]=r};function a(t,e){var r=e.id,n=e.bbox,i=null==e.properties?{}:e.properties,a=o(t,e);return null==r&&null==n?{type:\"Feature\",properties:i,geometry:a}:null==n?{type:\"Feature\",id:r,properties:i,geometry:a}:{type:\"Feature\",id:r,bbox:n,properties:i,geometry:a}}function o(t,e){var n=r(t),a=t.arcs;function o(t,e){e.length&&e.pop();for(var r=a[t<0?~t:t],o=0,s=r.length;o<s;++o)e.push(n(r[o].slice(),o));t<0&&i(e,s)}function s(t){return n(t.slice())}function l(t){for(var e=[],r=0,n=t.length;r<n;++r)o(t[r],e);return e.length<2&&e.push(e[0].slice()),e}function c(t){for(var e=l(t);e.length<4;)e.push(e[0].slice());return e}function u(t){return t.map(c)}return function t(e){var r,n=e.type;switch(n){case\"GeometryCollection\":return{type:n,geometries:e.geometries.map(t)};case\"Point\":r=s(e.coordinates);break;case\"MultiPoint\":r=e.coordinates.map(s);break;case\"LineString\":r=l(e.arcs);break;case\"MultiLineString\":r=e.arcs.map(l);break;case\"Polygon\":r=u(e.arcs);break;case\"MultiPolygon\":r=e.arcs.map(u);break;default:return null}return{type:n,coordinates:r}}(e)}var s=function(t,e){var r={},n={},i={},a=[],o=-1;function s(t,e){for(var n in t){var i=t[n];delete e[i.start],delete i.start,delete i.end,i.forEach(function(t){r[t<0?~t:t]=1}),a.push(i)}}return e.forEach(function(r,n){var i,a=t.arcs[r<0?~r:r];a.length<3&&!a[1][0]&&!a[1][1]&&(i=e[++o],e[o]=r,e[n]=i)}),e.forEach(function(e){var r,a,o=function(e){var r,n=t.arcs[e<0?~e:e],i=n[0];t.transform?(r=[0,0],n.forEach(function(t){r[0]+=t[0],r[1]+=t[1]})):r=n[n.length-1];return e<0?[r,i]:[i,r]}(e),s=o[0],l=o[1];if(r=i[s])if(delete i[r.end],r.push(e),r.end=l,a=n[l]){delete n[a.start];var c=a===r?r:r.concat(a);n[c.start=r.start]=i[c.end=a.end]=c}else n[r.start]=i[r.end]=r;else if(r=n[l])if(delete n[r.start],r.unshift(e),r.start=s,a=i[s]){delete i[a.end];var u=a===r?r:a.concat(r);n[u.start=a.start]=i[u.end=r.end]=u}else n[r.start]=i[r.end]=r;else n[(r=[e]).start=s]=i[r.end=l]=r}),s(i,n),s(n,i),e.forEach(function(t){r[t<0?~t:t]||a.push([t])}),a};function l(t,e,r){var n,i,a;if(arguments.length>1)n=function(t,e,r){var n,i=[],a=[];function o(t){var e=t<0?~t:t;(a[e]||(a[e]=[])).push({i:t,g:n})}function s(t){t.forEach(o)}function l(t){t.forEach(s)}return function t(e){switch(n=e,e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"LineString\":s(e.arcs);break;case\"MultiLineString\":case\"Polygon\":l(e.arcs);break;case\"MultiPolygon\":e.arcs.forEach(l)}}(e),a.forEach(null==r?function(t){i.push(t[0].i)}:function(t){r(t[0].g,t[t.length-1].g)&&i.push(t[0].i)}),i}(0,e,r);else for(i=0,n=new Array(a=t.arcs.length);i<a;++i)n[i]=i;return{type:\"MultiLineString\",arcs:s(t,n)}}function c(t,e){var r={},n=[],i=[];function a(t){t.forEach(function(e){e.forEach(function(e){(r[e=e<0?~e:e]||(r[e]=[])).push(t)})}),n.push(t)}function l(e){return function(t){for(var e,r=-1,n=t.length,i=t[n-1],a=0;++r<n;)e=i,i=t[r],a+=e[0]*i[1]-e[1]*i[0];return Math.abs(a)}(o(t,{type:\"Polygon\",arcs:[e]}).coordinates[0])}return e.forEach(function t(e){switch(e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"Polygon\":a(e.arcs);break;case\"MultiPolygon\":e.arcs.forEach(a)}}),n.forEach(function(t){if(!t._){var e=[],n=[t];for(t._=1,i.push(e);t=n.pop();)e.push(t),t.forEach(function(t){t.forEach(function(t){r[t<0?~t:t].forEach(function(t){t._||(t._=1,n.push(t))})})})}}),n.forEach(function(t){delete t._}),{type:\"MultiPolygon\",arcs:i.map(function(e){var n,i=[];if(e.forEach(function(t){t.forEach(function(t){t.forEach(function(t){r[t<0?~t:t].length<2&&i.push(t)})})}),(n=(i=s(t,i)).length)>1)for(var a,o,c=1,u=l(i[0]);c<n;++c)(a=l(i[c]))>u&&(o=i[0],i[0]=i[c],i[c]=o,u=a);return i})}}var u=function(t,e){for(var r=0,n=t.length;r<n;){var i=r+n>>>1;t[i]<e?r=i+1:n=i}return r};t.bbox=n,t.feature=function(t,e){return\"GeometryCollection\"===e.type?{type:\"FeatureCollection\",features:e.geometries.map(function(e){return a(t,e)})}:a(t,e)},t.mesh=function(t){return o(t,l.apply(this,arguments))},t.meshArcs=l,t.merge=function(t){return o(t,c.apply(this,arguments))},t.mergeArcs=c,t.neighbors=function(t){var e={},r=t.map(function(){return[]});function n(t,r){t.forEach(function(t){t<0&&(t=~t);var n=e[t];n?n.push(r):e[t]=[r]})}function i(t,e){t.forEach(function(t){n(t,e)})}var a={LineString:n,MultiLineString:i,Polygon:i,MultiPolygon:function(t,e){t.forEach(function(t){i(t,e)})}};for(var o in t.forEach(function t(e,r){\"GeometryCollection\"===e.type?e.geometries.forEach(function(e){t(e,r)}):e.type in a&&a[e.type](e.arcs,r)}),e)for(var s=e[o],l=s.length,c=0;c<l;++c)for(var h=c+1;h<l;++h){var f,p=s[c],d=s[h];(f=r[p])[o=u(f,d)]!==d&&f.splice(o,0,d),(f=r[d])[o=u(f,p)]!==p&&f.splice(o,0,p)}return r},t.quantize=function(t,e){if(!((e=Math.floor(e))>=2))throw new Error(\"n must be \\u22652\");if(t.transform)throw new Error(\"already quantized\");var r,i=n(t),a=i[0],o=(i[2]-a)/(e-1)||1,s=i[1],l=(i[3]-s)/(e-1)||1;function c(t){t[0]=Math.round((t[0]-a)/o),t[1]=Math.round((t[1]-s)/l)}function u(t){switch(t.type){case\"GeometryCollection\":t.geometries.forEach(u);break;case\"Point\":c(t.coordinates);break;case\"MultiPoint\":t.coordinates.forEach(c)}}for(r in t.arcs.forEach(function(t){for(var e,r,n,i=1,c=1,u=t.length,h=t[0],f=h[0]=Math.round((h[0]-a)/o),p=h[1]=Math.round((h[1]-s)/l);i<u;++i)h=t[i],r=Math.round((h[0]-a)/o),n=Math.round((h[1]-s)/l),r===f&&n===p||((e=t[c++])[0]=r-f,f=r,e[1]=n-p,p=n);c<2&&((e=t[c++])[0]=0,e[1]=0),t.length=c}),t.objects)u(t.objects[r]);return t.transform={scale:[o,l],translate:[a,s]},t},t.transform=r,t.untransform=function(t){if(null==(r=t.transform))return e;var r,n,i,a=r.scale[0],o=r.scale[1],s=r.translate[0],l=r.translate[1];return function(t,e){e||(n=i=0);var r=Math.round((t[0]-s)/a),c=Math.round((t[1]-l)/o);return t[0]=r-n,n=r,t[1]=c-i,i=c,t}},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.topojson=n.topojson||{})},{}],541:[function(t,e,r){\"use strict\";e.exports=function(t){if(t<0)return[];if(0===t)return[[0]];for(var e=0|Math.round(a(t+1)),r=[],o=0;o<e;++o){for(var s=n.unrank(t,o),l=[0],c=0,u=0;u<s.length;++u)c+=1<<s[u],l.push(c);i(s)<1&&(l[0]=c,l[t]=0),r.push(l)}return r};var n=t(\"permutation-rank\"),i=t(\"permutation-parity\"),a=t(\"gamma\")},{gamma:231,\"permutation-parity\":463,\"permutation-rank\":464}],542:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.up||[0,1,0],n=t.right||h(r),i=t.radius||1,a=t.theta||0,u=t.phi||0;if(e=[].slice.call(e,0,3),r=[].slice.call(r,0,3),s(r,r),n=[].slice.call(n,0,3),s(n,n),\"eye\"in t){var p=t.eye,d=[p[0]-e[0],p[1]-e[1],p[2]-e[2]];o(n,d,r),c(n[0],n[1],n[2])<1e-6?n=h(r):s(n,n),i=c(d[0],d[1],d[2]);var g=l(r,d)/i,v=l(n,d)/i;u=Math.acos(g),a=Math.acos(v)}return i=Math.log(i),new f(t.zoomMin,t.zoomMax,e,r,n,i,a,u)};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/invert\"),a=t(\"gl-mat4/rotate\"),o=t(\"gl-vec3/cross\"),s=t(\"gl-vec3/normalize\"),l=t(\"gl-vec3/dot\");function c(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function u(t){return Math.min(1,Math.max(-1,t))}function h(t){var e=Math.abs(t[0]),r=Math.abs(t[1]),n=Math.abs(t[2]),i=[0,0,0];e>Math.max(r,n)?i[2]=1:r>Math.max(e,n)?i[0]=1:i[1]=1;for(var a=0,o=0,l=0;l<3;++l)a+=t[l]*t[l],o+=i[l]*t[l];for(l=0;l<3;++l)i[l]-=o/a*t[l];return s(i,i),i}function f(t,e,r,i,a,o,s,l){this.center=n(r),this.up=n(i),this.right=n(a),this.radius=n([o]),this.angle=n([s,l]),this.angle.bounds=[[-1/0,-Math.PI/2],[1/0,Math.PI/2]],this.setDistanceLimits(t,e),this.computedCenter=this.center.curve(0),this.computedUp=this.up.curve(0),this.computedRight=this.right.curve(0),this.computedRadius=this.radius.curve(0),this.computedAngle=this.angle.curve(0),this.computedToward=[0,0,0],this.computedEye=[0,0,0],this.computedMatrix=new Array(16);for(var c=0;c<16;++c)this.computedMatrix[c]=.5;this.recalcMatrix(0)}var p=f.prototype;p.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},p.getDistanceLimits=function(t){var e=this.radius.bounds[0];return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},p.recalcMatrix=function(t){this.center.curve(t),this.up.curve(t),this.right.curve(t),this.radius.curve(t),this.angle.curve(t);for(var e=this.computedUp,r=this.computedRight,n=0,i=0,a=0;a<3;++a)i+=e[a]*r[a],n+=e[a]*e[a];var l=Math.sqrt(n),u=0;for(a=0;a<3;++a)r[a]-=e[a]*i/n,u+=r[a]*r[a],e[a]/=l;var h=Math.sqrt(u);for(a=0;a<3;++a)r[a]/=h;var f=this.computedToward;o(f,e,r),s(f,f);var p=Math.exp(this.computedRadius[0]),d=this.computedAngle[0],g=this.computedAngle[1],v=Math.cos(d),m=Math.sin(d),y=Math.cos(g),x=Math.sin(g),b=this.computedCenter,_=v*y,w=m*y,k=x,T=-v*x,A=-m*x,M=y,S=this.computedEye,E=this.computedMatrix;for(a=0;a<3;++a){var C=_*r[a]+w*f[a]+k*e[a];E[4*a+1]=T*r[a]+A*f[a]+M*e[a],E[4*a+2]=C,E[4*a+3]=0}var L=E[1],P=E[5],O=E[9],z=E[2],I=E[6],D=E[10],R=P*D-O*I,F=O*z-L*D,B=L*I-P*z,N=c(R,F,B);R/=N,F/=N,B/=N,E[0]=R,E[4]=F,E[8]=B;for(a=0;a<3;++a)S[a]=b[a]+E[2+4*a]*p;for(a=0;a<3;++a){u=0;for(var j=0;j<3;++j)u+=E[a+4*j]*S[j];E[12+a]=-u}E[15]=1},p.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r};var d=[0,0,0];p.rotate=function(t,e,r,n){if(this.angle.move(t,e,r),n){this.recalcMatrix(t);var i=this.computedMatrix;d[0]=i[2],d[1]=i[6],d[2]=i[10];for(var o=this.computedUp,s=this.computedRight,l=this.computedToward,c=0;c<3;++c)i[4*c]=o[c],i[4*c+1]=s[c],i[4*c+2]=l[c];a(i,i,n,d);for(c=0;c<3;++c)o[c]=i[4*c],s[c]=i[4*c+1];this.up.set(t,o[0],o[1],o[2]),this.right.set(t,s[0],s[1],s[2])}},p.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=(Math.exp(this.computedRadius[0]),i[1]),o=i[5],s=i[9],l=c(a,o,s);a/=l,o/=l,s/=l;var u=i[0],h=i[4],f=i[8],p=u*a+h*o+f*s,d=c(u-=a*p,h-=o*p,f-=s*p),g=(u/=d)*e+a*r,v=(h/=d)*e+o*r,m=(f/=d)*e+s*r;this.center.move(t,g,v,m);var y=Math.exp(this.computedRadius[0]);y=Math.max(1e-4,y+n),this.radius.set(t,Math.log(y))},p.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},p.setMatrix=function(t,e,r,n){var a=1;\"number\"==typeof r&&(a=0|r),(a<0||a>3)&&(a=1);var o=(a+2)%3;e||(this.recalcMatrix(t),e=this.computedMatrix);var s=e[a],l=e[a+4],h=e[a+8];if(n){var f=Math.abs(s),p=Math.abs(l),d=Math.abs(h),g=Math.max(f,p,d);f===g?(s=s<0?-1:1,l=h=0):d===g?(h=h<0?-1:1,s=l=0):(l=l<0?-1:1,s=h=0)}else{var v=c(s,l,h);s/=v,l/=v,h/=v}var m,y,x=e[o],b=e[o+4],_=e[o+8],w=x*s+b*l+_*h,k=c(x-=s*w,b-=l*w,_-=h*w),T=l*(_/=k)-h*(b/=k),A=h*(x/=k)-s*_,M=s*b-l*x,S=c(T,A,M);if(T/=S,A/=S,M/=S,this.center.jump(t,H,G,Y),this.radius.idle(t),this.up.jump(t,s,l,h),this.right.jump(t,x,b,_),2===a){var E=e[1],C=e[5],L=e[9],P=E*x+C*b+L*_,O=E*T+C*A+L*M;m=R<0?-Math.PI/2:Math.PI/2,y=Math.atan2(O,P)}else{var z=e[2],I=e[6],D=e[10],R=z*s+I*l+D*h,F=z*x+I*b+D*_,B=z*T+I*A+D*M;m=Math.asin(u(R)),y=Math.atan2(B,F)}this.angle.jump(t,y,m),this.recalcMatrix(t);var N=e[2],j=e[6],U=e[10],V=this.computedMatrix;i(V,e);var q=V[15],H=V[12]/q,G=V[13]/q,Y=V[14]/q,W=Math.exp(this.computedRadius[0]);this.center.jump(t,H-N*W,G-j*W,Y-U*W)},p.lastT=function(){return Math.max(this.center.lastT(),this.up.lastT(),this.right.lastT(),this.radius.lastT(),this.angle.lastT())},p.idle=function(t){this.center.idle(t),this.up.idle(t),this.right.idle(t),this.radius.idle(t),this.angle.idle(t)},p.flush=function(t){this.center.flush(t),this.up.flush(t),this.right.flush(t),this.radius.flush(t),this.angle.flush(t)},p.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},p.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||this.computedCenter;var i=(n=n||this.computedUp)[0],a=n[1],o=n[2],s=c(i,a,o);if(!(s<1e-6)){i/=s,a/=s,o/=s;var l=e[0]-r[0],h=e[1]-r[1],f=e[2]-r[2],p=c(l,h,f);if(!(p<1e-6)){l/=p,h/=p,f/=p;var d=this.computedRight,g=d[0],v=d[1],m=d[2],y=i*g+a*v+o*m,x=c(g-=y*i,v-=y*a,m-=y*o);if(!(x<.01&&(x=c(g=a*f-o*h,v=o*l-i*f,m=i*h-a*l))<1e-6)){g/=x,v/=x,m/=x,this.up.set(t,i,a,o),this.right.set(t,g,v,m),this.center.set(t,r[0],r[1],r[2]),this.radius.set(t,Math.log(p));var b=a*m-o*v,_=o*g-i*m,w=i*v-a*g,k=c(b,_,w),T=i*l+a*h+o*f,A=g*l+v*h+m*f,M=(b/=k)*l+(_/=k)*h+(w/=k)*f,S=Math.asin(u(T)),E=Math.atan2(M,A),C=this.angle._state,L=C[C.length-1],P=C[C.length-2];L%=2*Math.PI;var O=Math.abs(L+2*Math.PI-E),z=Math.abs(L-E),I=Math.abs(L-2*Math.PI-E);O<z&&(L+=2*Math.PI),I<z&&(L-=2*Math.PI),this.angle.jump(this.angle.lastT(),L,P),this.angle.set(t,E,S)}}}}},{\"filtered-vector\":226,\"gl-mat4/invert\":265,\"gl-mat4/rotate\":270,\"gl-vec3/cross\":334,\"gl-vec3/dot\":339,\"gl-vec3/normalize\":356}],543:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var i=t*e,a=n*t,o=a-(a-t),s=t-o,l=n*e,c=l-(l-e),u=e-c,h=s*u-(i-o*c-s*c-o*u);if(r)return r[0]=h,r[1]=i,r;return[h,i]};var n=+(Math.pow(2,27)+1)},{}],544:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=t+e,i=n-t,a=e-i,o=t-(n-i);if(r)return r[0]=o+a,r[1]=n,r;return[o+a,n]}},{}],545:[function(t,e,r){(function(e,n){\"use strict\";var i=t(\"bit-twiddle\"),a=t(\"dup\");e.__TYPEDARRAY_POOL||(e.__TYPEDARRAY_POOL={UINT8:a([32,0]),UINT16:a([32,0]),UINT32:a([32,0]),INT8:a([32,0]),INT16:a([32,0]),INT32:a([32,0]),FLOAT:a([32,0]),DOUBLE:a([32,0]),DATA:a([32,0]),UINT8C:a([32,0]),BUFFER:a([32,0])});var o=\"undefined\"!=typeof Uint8ClampedArray,s=e.__TYPEDARRAY_POOL;s.UINT8C||(s.UINT8C=a([32,0])),s.BUFFER||(s.BUFFER=a([32,0]));var l=s.DATA,c=s.BUFFER;function u(t){if(t){var e=t.length||t.byteLength,r=i.log2(e);l[r].push(t)}}function h(t){t=i.nextPow2(t);var e=i.log2(t),r=l[e];return r.length>0?r.pop():new ArrayBuffer(t)}function f(t){return new Uint8Array(h(t),0,t)}function p(t){return new Uint16Array(h(2*t),0,t)}function d(t){return new Uint32Array(h(4*t),0,t)}function g(t){return new Int8Array(h(t),0,t)}function v(t){return new Int16Array(h(2*t),0,t)}function m(t){return new Int32Array(h(4*t),0,t)}function y(t){return new Float32Array(h(4*t),0,t)}function x(t){return new Float64Array(h(8*t),0,t)}function b(t){return o?new Uint8ClampedArray(h(t),0,t):f(t)}function _(t){return new DataView(h(t),0,t)}function w(t){t=i.nextPow2(t);var e=i.log2(t),r=c[e];return r.length>0?r.pop():new n(t)}r.free=function(t){if(n.isBuffer(t))c[i.log2(t.length)].push(t);else{if(\"[object ArrayBuffer]\"!==Object.prototype.toString.call(t)&&(t=t.buffer),!t)return;var e=t.length||t.byteLength,r=0|i.log2(e);l[r].push(t)}},r.freeUint8=r.freeUint16=r.freeUint32=r.freeInt8=r.freeInt16=r.freeInt32=r.freeFloat32=r.freeFloat=r.freeFloat64=r.freeDouble=r.freeUint8Clamped=r.freeDataView=function(t){u(t.buffer)},r.freeArrayBuffer=u,r.freeBuffer=function(t){c[i.log2(t.length)].push(t)},r.malloc=function(t,e){if(void 0===e||\"arraybuffer\"===e)return h(t);switch(e){case\"uint8\":return f(t);case\"uint16\":return p(t);case\"uint32\":return d(t);case\"int8\":return g(t);case\"int16\":return v(t);case\"int32\":return m(t);case\"float\":case\"float32\":return y(t);case\"double\":case\"float64\":return x(t);case\"uint8_clamped\":return b(t);case\"buffer\":return w(t);case\"data\":case\"dataview\":return _(t);default:return null}return null},r.mallocArrayBuffer=h,r.mallocUint8=f,r.mallocUint16=p,r.mallocUint32=d,r.mallocInt8=g,r.mallocInt16=v,r.mallocInt32=m,r.mallocFloat32=r.mallocFloat=y,r.mallocFloat64=r.mallocDouble=x,r.mallocUint8Clamped=b,r.mallocDataView=_,r.mallocBuffer=w,r.clearCache=function(){for(var t=0;t<32;++t)s.UINT8[t].length=0,s.UINT16[t].length=0,s.UINT32[t].length=0,s.INT8[t].length=0,s.INT16[t].length=0,s.INT32[t].length=0,s.FLOAT[t].length=0,s.DOUBLE[t].length=0,s.UINT8C[t].length=0,l[t].length=0,c[t].length=0}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{},t(\"buffer\").Buffer)},{\"bit-twiddle\":92,buffer:105,dup:170}],546:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n;var i=n.prototype;Object.defineProperty(i,\"length\",{get:function(){return this.roots.length}}),i.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},i.find=function(t){for(var e=t,r=this.roots;r[t]!==t;)t=r[t];for(;r[e]!==t;){var n=r[e];r[e]=t,e=n}return t},i.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],547:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return 0===t.length?t:e?(r||t.sort(e),function(t,e){for(var r=1,n=t.length,i=t[0],a=t[0],o=1;o<n;++o)if(a=i,e(i=t[o],a)){if(o===r){r++;continue}t[r++]=i}return t.length=r,t}(t,e)):(r||t.sort(),function(t){for(var e=1,r=t.length,n=t[0],i=t[0],a=1;a<r;++a,i=n)if(i=n,(n=t[a])!==i){if(a===e){e++;continue}t[e++]=n}return t.length=e,t}(t))}},{}],548:[function(t,e,r){var n=/[\\'\\\"]/;e.exports=function(t){return t?(n.test(t.charAt(0))&&(t=t.substr(1)),n.test(t.charAt(t.length-1))&&(t=t.substr(0,t.length-1)),t):\"\"}},{}],549:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){Array.isArray(r)||(r=[].slice.call(arguments,2));for(var n=0,i=r.length;n<i;n++){var a=r[n];for(var o in a)if((void 0===e[o]||Array.isArray(e[o])||t[o]!==e[o])&&o in e){var s;if(!0===a[o])s=e[o];else{if(!1===a[o])continue;if(\"function\"==typeof a[o]&&void 0===(s=a[o](e[o],t,e)))continue}t[o]=s}}return t}},{}],550:[function(t,e,r){\"use strict\";e.exports=function(t,e){\"object\"==typeof e&&null!==e||(e={});return n(t,e.canvas||i,e.context||a,e)};var n=t(\"./lib/vtext\"),i=null,a=null;\"undefined\"!=typeof document&&((i=document.createElement(\"canvas\")).width=8192,i.height=1024,a=i.getContext(\"2d\"))},{\"./lib/vtext\":551}],551:[function(t,e,r){e.exports=function(t,e,r,n){var a=64,o=1.25,s={breaklines:!1,bolds:!1,italics:!1,subscripts:!1,superscripts:!1};n&&(n.size&&n.size>0&&(a=n.size),n.lineSpacing&&n.lineSpacing>0&&(o=n.lineSpacing),n.styletags&&n.styletags.breaklines&&(s.breaklines=!!n.styletags.breaklines),n.styletags&&n.styletags.bolds&&(s.bolds=!!n.styletags.bolds),n.styletags&&n.styletags.italics&&(s.italics=!!n.styletags.italics),n.styletags&&n.styletags.subscripts&&(s.subscripts=!!n.styletags.subscripts),n.styletags&&n.styletags.superscripts&&(s.superscripts=!!n.styletags.superscripts));return r.font=[n.fontStyle,n.fontVariant,n.fontWeight,a+\"px\",n.font].filter(function(t){return t}).join(\" \"),r.textAlign=\"start\",r.textBaseline=\"alphabetic\",r.direction=\"ltr\",w(function(t,e,r,n,a,o){r=r.replace(/\\n/g,\"\"),r=!0===o.breaklines?r.replace(/\\<br\\>/g,\"\\n\"):r.replace(/\\<br\\>/g,\" \");var s=\"\",l=[];for(k=0;k<r.length;++k)l[k]=s;!0===o.bolds&&(l=x(c,u,r,l)),!0===o.italics&&(l=x(h,f,r,l)),!0===o.superscripts&&(l=x(p,g,r,l)),!0===o.subscripts&&(l=x(v,y,r,l));var b=[],_=\"\";for(k=0;k<r.length;++k)null!==l[k]&&(_+=r[k],b.push(l[k]));var w,k,T,A,M,S=_.split(\"\\n\"),E=S.length,C=Math.round(a*n),L=n,P=2*n,O=0,z=E*C+P;t.height<z&&(t.height=z),e.fillStyle=\"#000\",e.fillRect(0,0,t.width,t.height),e.fillStyle=\"#fff\";var I=0,D=\"\";function R(){if(\"\"!==D){var t=e.measureText(D).width;e.fillText(D,L+T,P+A),T+=t}}function F(){return Math.round(M)+\"px \"}function B(t,r){var n=\"\"+e.font;if(!0===o.subscripts){var i=t.indexOf(m),a=r.indexOf(m),s=i>-1?parseInt(t[1+i]):0,l=a>-1?parseInt(r[1+a]):0;s!==l&&(n=n.replace(F(),\"?px \"),M*=Math.pow(.75,l-s),n=n.replace(\"?px \",F())),A+=.25*C*(l-s)}if(!0===o.superscripts){var c=t.indexOf(d),h=r.indexOf(d),p=c>-1?parseInt(t[1+c]):0,g=h>-1?parseInt(r[1+h]):0;p!==g&&(n=n.replace(F(),\"?px \"),M*=Math.pow(.75,g-p),n=n.replace(\"?px \",F())),A-=.25*C*(g-p)}if(!0===o.bolds){var v=t.indexOf(u)>-1,y=r.indexOf(u)>-1;!v&&y&&(n=x?n.replace(\"italic \",\"italic bold \"):\"bold \"+n),v&&!y&&(n=n.replace(\"bold \",\"\"))}if(!0===o.italics){var x=t.indexOf(f)>-1,b=r.indexOf(f)>-1;!x&&b&&(n=\"italic \"+n),x&&!b&&(n=n.replace(\"italic \",\"\"))}e.font=n}for(w=0;w<E;++w){var N=S[w]+\"\\n\";for(T=0,A=w*C,M=n,D=\"\",k=0;k<N.length;++k){var j=k+I<b.length?b[k+I]:b[b.length-1];s===j?D+=N[k]:(R(),D=N[k],void 0!==j&&(B(s,j),s=j))}R(),I+=N.length;var U=0|Math.round(T+2*L);O<U&&(O=U)}var V=O,q=P+C*E;return i(e.getImageData(0,0,V,q).data,[q,V,4]).pick(-1,-1,0).transpose(1,0)}(e,r,t,a,o,s),n,a)},e.exports.processPixels=w;var n=t(\"surface-nets\"),i=t(\"ndarray\"),a=t(\"simplify-planar-graph\"),o=t(\"clean-pslg\"),s=t(\"cdt2d\"),l=t(\"planar-graph-to-polyline\"),c=\"b\",u=\"b|\",h=\"i\",f=\"i|\",p=\"sup\",d=\"+\",g=\"+1\",v=\"sub\",m=\"-\",y=\"-1\";function x(t,e,r,n){for(var i=\"<\"+t+\">\",a=\"</\"+t+\">\",o=i.length,s=a.length,l=e[0]===d||e[0]===m,c=0,u=-s;c>-1&&-1!==(c=r.indexOf(i,c))&&-1!==(u=r.indexOf(a,c+o))&&!(u<=c);){for(var h=c;h<u+s;++h)if(h<c+o||h>=u)n[h]=null,r=r.substr(0,h)+\" \"+r.substr(h+1);else if(null!==n[h]){var f=n[h].indexOf(e[0]);-1===f?n[h]+=e:l&&(n[h]=n[h].substr(0,f+1)+(1+parseInt(n[h][f+1]))+n[h].substr(f+2))}var p=c+o,g=r.substr(p,u-p).indexOf(i);c=-1!==g?g:u+s}return n}function b(t,e){var r=n(t,128);return e?a(r.cells,r.positions,.25):{edges:r.cells,positions:r.positions}}function _(t,e,r,n){var i=b(t,n),a=function(t,e,r){for(var n=e.textAlign||\"start\",i=e.textBaseline||\"alphabetic\",a=[1<<30,1<<30],o=[0,0],s=t.length,l=0;l<s;++l)for(var c=t[l],u=0;u<2;++u)a[u]=0|Math.min(a[u],c[u]),o[u]=0|Math.max(o[u],c[u]);var h=0;switch(n){case\"center\":h=-.5*(a[0]+o[0]);break;case\"right\":case\"end\":h=-o[0];break;case\"left\":case\"start\":h=-a[0];break;default:throw new Error(\"vectorize-text: Unrecognized textAlign: '\"+n+\"'\")}var f=0;switch(i){case\"hanging\":case\"top\":f=-a[1];break;case\"middle\":f=-.5*(a[1]+o[1]);break;case\"alphabetic\":case\"ideographic\":f=-3*r;break;case\"bottom\":f=-o[1];break;default:throw new Error(\"vectorize-text: Unrecoginized textBaseline: '\"+i+\"'\")}var p=1/r;return\"lineHeight\"in e?p*=+e.lineHeight:\"width\"in e?p=e.width/(o[0]-a[0]):\"height\"in e&&(p=e.height/(o[1]-a[1])),t.map(function(t){return[p*(t[0]+h),p*(t[1]+f)]})}(i.positions,e,r),c=i.edges,u=\"ccw\"===e.orientation;if(o(a,c),e.polygons||e.polygon||e.polyline){for(var h=l(c,a),f=new Array(h.length),p=0;p<h.length;++p){for(var d=h[p],g=new Array(d.length),v=0;v<d.length;++v){for(var m=d[v],y=new Array(m.length),x=0;x<m.length;++x)y[x]=a[m[x]].slice();u&&y.reverse(),g[v]=y}f[p]=g}return f}return e.triangles||e.triangulate||e.triangle?{cells:s(a,c,{delaunay:!1,exterior:!1,interior:!0}),positions:a}:{edges:c,positions:a}}function w(t,e,r){try{return _(t,e,r,!0)}catch(t){}try{return _(t,e,r,!1)}catch(t){}return e.polygons||e.polyline||e.polygon?[]:e.triangles||e.triangulate||e.triangle?{cells:[],positions:[]}:{edges:[],positions:[]}}},{cdt2d:106,\"clean-pslg\":116,ndarray:450,\"planar-graph-to-polyline\":468,\"simplify-planar-graph\":524,\"surface-nets\":531}],552:[function(t,e,r){!function(){\"use strict\";if(\"undefined\"==typeof ses||!ses.ok||ses.ok()){\"undefined\"!=typeof ses&&(ses.weakMapPermitHostObjects=v);var t=!1;if(\"function\"==typeof WeakMap){var r=WeakMap;if(\"undefined\"!=typeof navigator&&/Firefox/.test(navigator.userAgent));else{var n=new r,i=Object.freeze({});if(n.set(i,1),1===n.get(i))return void(e.exports=WeakMap);t=!0}}Object.prototype.hasOwnProperty;var a=Object.getOwnPropertyNames,o=Object.defineProperty,s=Object.isExtensible,l=\"weakmap:\",c=l+\"ident:\"+Math.random()+\"___\";if(\"undefined\"!=typeof crypto&&\"function\"==typeof crypto.getRandomValues&&\"function\"==typeof ArrayBuffer&&\"function\"==typeof Uint8Array){var u=new ArrayBuffer(25),h=new Uint8Array(u);crypto.getRandomValues(h),c=l+\"rand:\"+Array.prototype.map.call(h,function(t){return(t%36).toString(36)}).join(\"\")+\"___\"}if(o(Object,\"getOwnPropertyNames\",{value:function(t){return a(t).filter(m)}}),\"getPropertyNames\"in Object){var f=Object.getPropertyNames;o(Object,\"getPropertyNames\",{value:function(t){return f(t).filter(m)}})}!function(){var t=Object.freeze;o(Object,\"freeze\",{value:function(e){return y(e),t(e)}});var e=Object.seal;o(Object,\"seal\",{value:function(t){return y(t),e(t)}});var r=Object.preventExtensions;o(Object,\"preventExtensions\",{value:function(t){return y(t),r(t)}})}();var p=!1,d=0,g=function(){this instanceof g||b();var t=[],e=[],r=d++;return Object.create(g.prototype,{get___:{value:x(function(n,i){var a,o=y(n);return o?r in o?o[r]:i:(a=t.indexOf(n))>=0?e[a]:i})},has___:{value:x(function(e){var n=y(e);return n?r in n:t.indexOf(e)>=0})},set___:{value:x(function(n,i){var a,o=y(n);return o?o[r]=i:(a=t.indexOf(n))>=0?e[a]=i:(a=t.length,e[a]=i,t[a]=n),this})},delete___:{value:x(function(n){var i,a,o=y(n);return o?r in o&&delete o[r]:!((i=t.indexOf(n))<0||(a=t.length-1,t[i]=void 0,e[i]=e[a],t[i]=t[a],t.length=a,e.length=a,0))})}})};g.prototype=Object.create(Object.prototype,{get:{value:function(t,e){return this.get___(t,e)},writable:!0,configurable:!0},has:{value:function(t){return this.has___(t)},writable:!0,configurable:!0},set:{value:function(t,e){return this.set___(t,e)},writable:!0,configurable:!0},delete:{value:function(t){return this.delete___(t)},writable:!0,configurable:!0}}),\"function\"==typeof r?function(){function n(){this instanceof g||b();var e,n=new r,i=void 0,a=!1;return e=t?function(t,e){return n.set(t,e),n.has(t)||(i||(i=new g),i.set(t,e)),this}:function(t,e){if(a)try{n.set(t,e)}catch(r){i||(i=new g),i.set___(t,e)}else n.set(t,e);return this},Object.create(g.prototype,{get___:{value:x(function(t,e){return i?n.has(t)?n.get(t):i.get___(t,e):n.get(t,e)})},has___:{value:x(function(t){return n.has(t)||!!i&&i.has___(t)})},set___:{value:x(e)},delete___:{value:x(function(t){var e=!!n.delete(t);return i&&i.delete___(t)||e})},permitHostObjects___:{value:x(function(t){if(t!==v)throw new Error(\"bogus call to permitHostObjects___\");a=!0})}})}t&&\"undefined\"!=typeof Proxy&&(Proxy=void 0),n.prototype=g.prototype,e.exports=n,Object.defineProperty(WeakMap.prototype,\"constructor\",{value:WeakMap,enumerable:!1,configurable:!0,writable:!0})}():(\"undefined\"!=typeof Proxy&&(Proxy=void 0),e.exports=g)}function v(t){t.permitHostObjects___&&t.permitHostObjects___(v)}function m(t){return!(t.substr(0,l.length)==l&&\"___\"===t.substr(t.length-3))}function y(t){if(t!==Object(t))throw new TypeError(\"Not an object: \"+t);var e=t[c];if(e&&e.key===t)return e;if(s(t)){e={key:t};try{return o(t,c,{value:e,writable:!1,enumerable:!1,configurable:!1}),e}catch(t){return}}}function x(t){return t.prototype=null,Object.freeze(t)}function b(){p||\"undefined\"==typeof console||(p=!0,console.warn(\"WeakMap should be invoked as new WeakMap(), not WeakMap(). This will be an error in the future.\"))}}()},{}],553:[function(t,e,r){var n=t(\"./hidden-store.js\");e.exports=function(){var t={};return function(e){if((\"object\"!=typeof e||null===e)&&\"function\"!=typeof e)throw new Error(\"Weakmap-shim: Key must be object\");var r=e.valueOf(t);return r&&r.identity===t?r:n(e,t)}}},{\"./hidden-store.js\":554}],554:[function(t,e,r){e.exports=function(t,e){var r={identity:e},n=t.valueOf;return Object.defineProperty(t,\"valueOf\",{value:function(t){return t!==e?n.apply(this,arguments):r},writable:!0}),r}},{}],555:[function(t,e,r){var n=t(\"./create-store.js\");e.exports=function(){var t=n();return{get:function(e,r){var n=t(e);return n.hasOwnProperty(\"value\")?n.value:r},set:function(e,r){return t(e).value=r,this},has:function(e){return\"value\"in t(e)},delete:function(e){return delete t(e).value}}}},{\"./create-store.js\":553}],556:[function(t,e,r){var n=t(\"get-canvas-context\");e.exports=function(t){return n(\"webgl\",t)}},{\"get-canvas-context\":232}],557:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Chinese\",jdEpoch:1721425.5,hasYearZero:!1,minMonth:0,firstMonth:0,minDay:1,regionalOptions:{\"\":{name:\"Chinese\",epochs:[\"BEC\",\"EC\"],monthNumbers:function(t,e){if(\"string\"==typeof t){var r=t.match(l);return r?r[0]:\"\"}var n=this._validateYear(t),i=t.month(),a=\"\"+this.toChineseMonth(n,i);return e&&a.length<2&&(a=\"0\"+a),this.isIntercalaryMonth(n,i)&&(a+=\"i\"),a},monthNames:function(t){if(\"string\"==typeof t){var e=t.match(c);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\\u6708\",\"\\u4e8c\\u6708\",\"\\u4e09\\u6708\",\"\\u56db\\u6708\",\"\\u4e94\\u6708\",\"\\u516d\\u6708\",\"\\u4e03\\u6708\",\"\\u516b\\u6708\",\"\\u4e5d\\u6708\",\"\\u5341\\u6708\",\"\\u5341\\u4e00\\u6708\",\"\\u5341\\u4e8c\\u6708\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},monthNamesShort:function(t){if(\"string\"==typeof t){var e=t.match(u);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},parseMonth:function(t,e){t=this._validateYear(t);var r,n=parseInt(e);if(isNaN(n))\"\\u95f0\"===e[0]&&(r=!0,e=e.substring(1)),\"\\u6708\"===e[e.length-1]&&(e=e.substring(0,e.length-1)),n=1+[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"].indexOf(e);else{var i=e[e.length-1];r=\"i\"===i||\"I\"===i}return this.toMonthIndex(t,n,r)},dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},_validateYear:function(t,e){if(t.year&&(t=t.year()),\"number\"!=typeof t||t<1888||t>2111)throw e.replace(/\\{0\\}/,this.local.name);return t},toMonthIndex:function(t,e,r){var i=this.intercalaryMonth(t);if(r&&e!==i||e<1||e>12)throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return i?!r&&e<=i?e-1:e:e-1},toChineseMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);if(e<0||e>(r?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r?e<r?e+1:e:e+1},intercalaryMonth:function(t){return t=this._validateYear(t),h[t-h[0]]>>13},isIntercalaryMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);return!!r&&r===e},leapYear:function(t){return 0!==this.intercalaryMonth(t)},weekOfYear:function(t,e,r){var i,o=this._validateYear(t,n.local.invalidyear),s=f[o-f[0]],l=s>>9&4095,c=s>>5&15,u=31&s;(i=a.newDate(l,c,u)).add(4-(i.dayOfWeek()||7),\"d\");var h=this.toJD(t,e,r)-i.toJD();return 1+Math.floor(h/7)},monthsInYear:function(t){return this.leapYear(t)?13:12},daysInMonth:function(t,e){t.year&&(e=t.month(),t=t.year()),t=this._validateYear(t);var r=h[t-h[0]];if(e>(r>>13?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r&1<<12-e?30:29},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,s,r,n.local.invalidDate);t=this._validateYear(i.year()),e=i.month(),r=i.day();var o=this.isIntercalaryMonth(t,e),s=this.toChineseMonth(t,e),l=function(t,e,r,n,i){var a,o,s;if(\"object\"==typeof t)o=t,a=e||{};else{var l=\"number\"==typeof t&&t>=1888&&t<=2111;if(!l)throw new Error(\"Lunar year outside range 1888-2111\");var c=\"number\"==typeof e&&e>=1&&e<=12;if(!c)throw new Error(\"Lunar month outside range 1 - 12\");var u,p=\"number\"==typeof r&&r>=1&&r<=30;if(!p)throw new Error(\"Lunar day outside range 1 - 30\");\"object\"==typeof n?(u=!1,a=n):(u=!!n,a=i||{}),o={year:t,month:e,day:r,isIntercalary:u}}s=o.day-1;var d,g=h[o.year-h[0]],v=g>>13;d=v?o.month>v?o.month:o.isIntercalary?o.month:o.month-1:o.month-1;for(var m=0;m<d;m++){var y=g&1<<12-m?30:29;s+=y}var x=f[o.year-f[0]],b=new Date(x>>9&4095,(x>>5&15)-1,(31&x)+s);return a.year=b.getFullYear(),a.month=1+b.getMonth(),a.day=b.getDate(),a}(t,s,r,o);return a.toJD(l.year,l.month,l.day)},fromJD:function(t){var e=a.fromJD(t),r=function(t,e,r,n){var i,a;if(\"object\"==typeof t)i=t,a=e||{};else{var o=\"number\"==typeof t&&t>=1888&&t<=2111;if(!o)throw new Error(\"Solar year outside range 1888-2111\");var s=\"number\"==typeof e&&e>=1&&e<=12;if(!s)throw new Error(\"Solar month outside range 1 - 12\");var l=\"number\"==typeof r&&r>=1&&r<=31;if(!l)throw new Error(\"Solar day outside range 1 - 31\");i={year:t,month:e,day:r},a=n||{}}var c=f[i.year-f[0]],u=i.year<<9|i.month<<5|i.day;a.year=u>=c?i.year:i.year-1,c=f[a.year-f[0]];var p,d=new Date(c>>9&4095,(c>>5&15)-1,31&c),g=new Date(i.year,i.month-1,i.day);p=Math.round((g-d)/864e5);var v,m=h[a.year-h[0]];for(v=0;v<13;v++){var y=m&1<<12-v?30:29;if(p<y)break;p-=y}var x=m>>13;!x||v<x?(a.isIntercalary=!1,a.month=1+v):v===x?(a.isIntercalary=!0,a.month=v):(a.isIntercalary=!1,a.month=v);return a.day=1+p,a}(e.year(),e.month(),e.day()),n=this.toMonthIndex(r.year,r.month,r.isIntercalary);return this.newDate(r.year,n,r.day)},fromString:function(t){var e=t.match(s),r=this._validateYear(+e[1]),n=+e[2],i=!!e[3],a=this.toMonthIndex(r,n,i),o=+e[4];return this.newDate(r,a,o)},add:function(t,e,r){var n=t.year(),i=t.month(),a=this.isIntercalaryMonth(n,i),s=this.toChineseMonth(n,i),l=Object.getPrototypeOf(o.prototype).add.call(this,t,e,r);if(\"y\"===r){var c=l.year(),u=l.month(),h=this.isIntercalaryMonth(c,s),f=a&&h?this.toMonthIndex(c,s,!0):this.toMonthIndex(c,s,!1);f!==u&&l.month(f)}return l}});var s=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)[-\\/](\\d?\\d)([iI]?)[-\\/](\\d?\\d)/m,l=/^\\d?\\d[iI]?/m,c=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?\\u6708/m,u=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?/m;n.calendars.chinese=o;var h=[1887,5780,5802,19157,2742,50359,1198,2646,46378,7466,3412,30122,5482,67949,2396,5294,43597,6732,6954,36181,2772,4954,18781,2396,54427,5274,6730,47781,5800,6868,21210,4790,59703,2350,5270,46667,3402,3496,38325,1388,4782,18735,2350,52374,6804,7498,44457,2906,1388,29294,4700,63789,6442,6804,56138,5802,2772,38235,1210,4698,22827,5418,63125,3476,5802,43701,2484,5302,27223,2646,70954,7466,3412,54698,5482,2412,38062,5294,2636,32038,6954,60245,2772,4826,43357,2394,5274,39501,6730,72357,5800,5844,53978,4790,2358,38039,5270,87627,3402,3496,54708,5484,4782,43311,2350,3222,27978,7498,68965,2904,5484,45677,4700,6444,39573,6804,6986,19285,2772,62811,1210,4698,47403,5418,5780,38570,5546,76469,2420,5302,51799,2646,5414,36501,3412,5546,18869,2412,54446,5276,6732,48422,6822,2900,28010,4826,92509,2394,5274,55883,6730,6820,47956,5812,2778,18779,2358,62615,5270,5450,46757,3492,5556,27318,4718,67887,2350,3222,52554,7498,3428,38252,5468,4700,31022,6444,64149,6804,6986,43861,2772,5338,35421,2650,70955,5418,5780,54954,5546,2740,38074,5302,2646,29991,3366,61011,3412,5546,43445,2412,5294,35406,6732,72998,6820,6996,52586,2778,2396,38045,5274,6698,23333,6820,64338,5812,2746,43355,2358,5270,39499,5450,79525,3492,5548],f=[1887,966732,967231,967733,968265,968766,969297,969798,970298,970829,971330,971830,972362,972863,973395,973896,974397,974928,975428,975929,976461,976962,977462,977994,978494,979026,979526,980026,980558,981059,981559,982091,982593,983124,983624,984124,984656,985157,985656,986189,986690,987191,987722,988222,988753,989254,989754,990286,990788,991288,991819,992319,992851,993352,993851,994383,994885,995385,995917,996418,996918,997450,997949,998481,998982,999483,1000014,1000515,1001016,1001548,1002047,1002578,1003080,1003580,1004111,1004613,1005113,1005645,1006146,1006645,1007177,1007678,1008209,1008710,1009211,1009743,1010243,1010743,1011275,1011775,1012306,1012807,1013308,1013840,1014341,1014841,1015373,1015874,1016404,1016905,1017405,1017937,1018438,1018939,1019471,1019972,1020471,1021002,1021503,1022035,1022535,1023036,1023568,1024069,1024568,1025100,1025601,1026102,1026633,1027133,1027666,1028167,1028666,1029198,1029699,1030199,1030730,1031231,1031763,1032264,1032764,1033296,1033797,1034297,1034828,1035329,1035830,1036362,1036861,1037393,1037894,1038394,1038925,1039427,1039927,1040459,1040959,1041491,1041992,1042492,1043023,1043524,1044024,1044556,1045057,1045558,1046090,1046590,1047121,1047622,1048122,1048654,1049154,1049655,1050187,1050689,1051219,1051720,1052220,1052751,1053252,1053752,1054284,1054786,1055285,1055817,1056317,1056849,1057349,1057850,1058382,1058883,1059383,1059915,1060415,1060947,1061447,1061947,1062479,1062981,1063480,1064012,1064514,1065014,1065545,1066045,1066577,1067078,1067578,1068110,1068611,1069112,1069642,1070142,1070674,1071175,1071675,1072207,1072709,1073209,1073740,1074241,1074741,1075273,1075773,1076305,1076807,1077308,1077839,1078340,1078840,1079372,1079871,1080403,1080904]},{\"../main\":571,\"object-assign\":454}],558:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Coptic\",jdEpoch:1825029.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Coptic\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Thout\",\"Paopi\",\"Hathor\",\"Koiak\",\"Tobi\",\"Meshir\",\"Paremhat\",\"Paremoude\",\"Pashons\",\"Paoni\",\"Epip\",\"Mesori\",\"Pi Kogi Enavot\"],monthNamesShort:[\"Tho\",\"Pao\",\"Hath\",\"Koi\",\"Tob\",\"Mesh\",\"Pat\",\"Pad\",\"Pash\",\"Pao\",\"Epi\",\"Meso\",\"PiK\"],dayNames:[\"Tkyriaka\",\"Pesnau\",\"Pshoment\",\"Peftoou\",\"Ptiou\",\"Psoou\",\"Psabbaton\"],dayNamesShort:[\"Tky\",\"Pes\",\"Psh\",\"Pef\",\"Pti\",\"Pso\",\"Psa\"],dayNamesMin:[\"Tk\",\"Pes\",\"Psh\",\"Pef\",\"Pt\",\"Pso\",\"Psa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.coptic=a},{\"../main\":571,\"object-assign\":454}],559:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Discworld\",jdEpoch:1721425.5,daysPerMonth:[16,32,32,32,32,32,32,32,32,32,32,32,32],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Discworld\",epochs:[\"BUC\",\"UC\"],monthNames:[\"Ick\",\"Offle\",\"February\",\"March\",\"April\",\"May\",\"June\",\"Grune\",\"August\",\"Spune\",\"Sektober\",\"Ember\",\"December\"],monthNamesShort:[\"Ick\",\"Off\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Gru\",\"Aug\",\"Spu\",\"Sek\",\"Emb\",\"Dec\"],dayNames:[\"Sunday\",\"Octeday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Oct\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Oc\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:2,isRTL:!1}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),13},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),400},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/8)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]},daysInWeek:function(){return 8},dayOfWeek:function(t,e,r){return(this._validate(t,e,r,n.local.invalidDate).day()+1)%8},weekDay:function(t,e,r){var n=this.dayOfWeek(t,e,r);return n>=2&&n<=6},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{century:o[Math.floor((i.year()-1)/100)+1]||\"\"}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year()+(i.year()<0?1:0),e=i.month(),(r=i.day())+(e>1?16:0)+(e>2?32*(e-2):0)+400*(t-1)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t+.5)-Math.floor(this.jdEpoch)-1;var e=Math.floor(t/400)+1;t-=400*(e-1),t+=t>15?16:0;var r=Math.floor(t/32)+1,n=t-32*(r-1)+1;return this.newDate(e<=0?e-1:e,r,n)}});var o={20:\"Fruitbat\",21:\"Anchovy\"};n.calendars.discworld=a},{\"../main\":571,\"object-assign\":454}],560:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Ethiopian\",jdEpoch:1724220.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Ethiopian\",epochs:[\"BEE\",\"EE\"],monthNames:[\"Meskerem\",\"Tikemet\",\"Hidar\",\"Tahesas\",\"Tir\",\"Yekatit\",\"Megabit\",\"Miazia\",\"Genbot\",\"Sene\",\"Hamle\",\"Nehase\",\"Pagume\"],monthNamesShort:[\"Mes\",\"Tik\",\"Hid\",\"Tah\",\"Tir\",\"Yek\",\"Meg\",\"Mia\",\"Gen\",\"Sen\",\"Ham\",\"Neh\",\"Pag\"],dayNames:[\"Ehud\",\"Segno\",\"Maksegno\",\"Irob\",\"Hamus\",\"Arb\",\"Kidame\"],dayNamesShort:[\"Ehu\",\"Seg\",\"Mak\",\"Iro\",\"Ham\",\"Arb\",\"Kid\"],dayNamesMin:[\"Eh\",\"Se\",\"Ma\",\"Ir\",\"Ha\",\"Ar\",\"Ki\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.ethiopian=a},{\"../main\":571,\"object-assign\":454}],561:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Hebrew\",jdEpoch:347995.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29,29],hasYearZero:!1,minMonth:1,firstMonth:7,minDay:1,regionalOptions:{\"\":{name:\"Hebrew\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Nisan\",\"Iyar\",\"Sivan\",\"Tammuz\",\"Av\",\"Elul\",\"Tishrei\",\"Cheshvan\",\"Kislev\",\"Tevet\",\"Shevat\",\"Adar\",\"Adar II\"],monthNamesShort:[\"Nis\",\"Iya\",\"Siv\",\"Tam\",\"Av\",\"Elu\",\"Tis\",\"Che\",\"Kis\",\"Tev\",\"She\",\"Ada\",\"Ad2\"],dayNames:[\"Yom Rishon\",\"Yom Sheni\",\"Yom Shlishi\",\"Yom Revi'i\",\"Yom Chamishi\",\"Yom Shishi\",\"Yom Shabbat\"],dayNamesShort:[\"Ris\",\"She\",\"Shl\",\"Rev\",\"Cha\",\"Shi\",\"Sha\"],dayNamesMin:[\"Ri\",\"She\",\"Shl\",\"Re\",\"Ch\",\"Shi\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return this._leapYear(e.year())},_leapYear:function(t){return o(7*(t=t<0?t+1:t)+1,19)<7},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),this._leapYear(t.year?t.year():t)?13:12},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),this.toJD(-1===t?1:t+1,7,1)-this.toJD(t,7,1)},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),12===e&&this.leapYear(t)?30:8===e&&5===o(this.daysInYear(t),10)?30:9===e&&3===o(this.daysInYear(t),10)?29:this.daysPerMonth[e-1]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{yearType:(this.leapYear(i)?\"embolismic\":\"common\")+\" \"+[\"deficient\",\"regular\",\"complete\"][this.daysInYear(i)%10-3]}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t<=0?t+1:t,o=this.jdEpoch+this._delay1(a)+this._delay2(a)+r+1;if(e<7){for(var s=7;s<=this.monthsInYear(t);s++)o+=this.daysInMonth(t,s);for(s=1;s<e;s++)o+=this.daysInMonth(t,s)}else for(s=7;s<e;s++)o+=this.daysInMonth(t,s);return o},_delay1:function(t){var e=Math.floor((235*t-234)/19),r=12084+13753*e,n=29*e+Math.floor(r/25920);return o(3*(n+1),7)<3&&n++,n},_delay2:function(t){var e=this._delay1(t-1),r=this._delay1(t);return this._delay1(t+1)-r==356?2:r-e==382?1:0},fromJD:function(t){t=Math.floor(t)+.5;for(var e=Math.floor(98496*(t-this.jdEpoch)/35975351)-1;t>=this.toJD(-1===e?1:e+1,7,1);)e++;for(var r=t<this.toJD(e,1,1)?7:1;t>this.toJD(e,r,this.daysInMonth(e,r));)r++;var n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.hebrew=a},{\"../main\":571,\"object-assign\":454}],562:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Islamic\",jdEpoch:1948439.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Islamic\",epochs:[\"BH\",\"AH\"],monthNames:[\"Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' al-thani\",\"Jumada al-awwal\",\"Jumada al-thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-ahad\",\"Yawm al-ithnayn\",\"Yawm ath-thulaathaa'\",\"Yawm al-arbi'aa'\",\"Yawm al-kham\\u012bs\",\"Yawm al-jum'a\",\"Yawm as-sabt\"],dayNamesShort:[\"Aha\",\"Ith\",\"Thu\",\"Arb\",\"Kha\",\"Jum\",\"Sab\"],dayNamesMin:[\"Ah\",\"It\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){return(11*this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year()+14)%30<11},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return this.leapYear(t)?355:354},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),t=t<=0?t+1:t,(r=i.day())+Math.ceil(29.5*(e-1))+354*(t-1)+Math.floor((3+11*t)/30)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t)+.5;var e=Math.floor((30*(t-this.jdEpoch)+10646)/10631);e=e<=0?e-1:e;var r=Math.min(12,Math.ceil((t-29-this.toJD(e,1,1))/29.5)+1),n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.islamic=a},{\"../main\":571,\"object-assign\":454}],563:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Julian\",jdEpoch:1721423.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Julian\",epochs:[\"BC\",\"AD\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()<0?e.year()+1:e.year())%4==0},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),r=i.day(),t<0&&t++,e<=2&&(t--,e+=12),Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r-1524.5},fromJD:function(t){var e=Math.floor(t+.5)+1524,r=Math.floor((e-122.1)/365.25),n=Math.floor(365.25*r),i=Math.floor((e-n)/30.6001),a=i-Math.floor(i<14?1:13),o=r-Math.floor(a>2?4716:4715),s=e-n-Math.floor(30.6001*i);return o<=0&&o--,this.newDate(o,a,s)}}),n.calendars.julian=a},{\"../main\":571,\"object-assign\":454}],564:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}function s(t,e){return o(t-1,e)+1}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Mayan\",jdEpoch:584282.5,hasYearZero:!0,minMonth:0,firstMonth:0,minDay:0,regionalOptions:{\"\":{name:\"Mayan\",epochs:[\"\",\"\"],monthNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],monthNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],dayNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesMin:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],digits:null,dateFormat:\"YYYY.m.d\",firstDay:0,isRTL:!1,haabMonths:[\"Pop\",\"Uo\",\"Zip\",\"Zotz\",\"Tzec\",\"Xul\",\"Yaxkin\",\"Mol\",\"Chen\",\"Yax\",\"Zac\",\"Ceh\",\"Mac\",\"Kankin\",\"Muan\",\"Pax\",\"Kayab\",\"Cumku\",\"Uayeb\"],tzolkinMonths:[\"Imix\",\"Ik\",\"Akbal\",\"Kan\",\"Chicchan\",\"Cimi\",\"Manik\",\"Lamat\",\"Muluc\",\"Oc\",\"Chuen\",\"Eb\",\"Ben\",\"Ix\",\"Men\",\"Cib\",\"Caban\",\"Etznab\",\"Cauac\",\"Ahau\"]}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},formatYear:function(t){t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year();var e=Math.floor(t/400);return t%=400,t+=t<0?400:0,e+\".\"+Math.floor(t/20)+\".\"+t%20},forYear:function(t){if((t=t.split(\".\")).length<3)throw\"Invalid Mayan year\";for(var e=0,r=0;r<t.length;r++){var n=parseInt(t[r],10);if(Math.abs(n)>19||r>0&&n<0)throw\"Invalid Mayan year\";e=20*e+n}return e},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),18},weekOfYear:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),0},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),360},daysInMonth:function(t,e){return this._validate(t,e,this.minDay,n.local.invalidMonth),20},daysInWeek:function(){return 5},dayOfWeek:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate).day()},weekDay:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),!0},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate).toJD(),a=this._toHaab(i),o=this._toTzolkin(i);return{haabMonthName:this.local.haabMonths[a[0]-1],haabMonth:a[0],haabDay:a[1],tzolkinDayName:this.local.tzolkinMonths[o[0]-1],tzolkinDay:o[0],tzolkinTrecena:o[1]}},_toHaab:function(t){var e=o((t-=this.jdEpoch)+8+340,365);return[Math.floor(e/20)+1,o(e,20)]},_toTzolkin:function(t){return[s((t-=this.jdEpoch)+20,20),s(t+4,13)]},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return i.day()+20*i.month()+360*i.year()+this.jdEpoch},fromJD:function(t){t=Math.floor(t)+.5-this.jdEpoch;var e=Math.floor(t/360);t%=360,t+=t<0?360:0;var r=Math.floor(t/20),n=t%20;return this.newDate(e,r,n)}}),n.calendars.mayan=a},{\"../main\":571,\"object-assign\":454}],565:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar;var o=n.instance(\"gregorian\");i(a.prototype,{name:\"Nanakshahi\",jdEpoch:2257673.5,daysPerMonth:[31,31,31,31,31,30,30,30,30,30,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Nanakshahi\",epochs:[\"BN\",\"AN\"],monthNames:[\"Chet\",\"Vaisakh\",\"Jeth\",\"Harh\",\"Sawan\",\"Bhadon\",\"Assu\",\"Katak\",\"Maghar\",\"Poh\",\"Magh\",\"Phagun\"],monthNamesShort:[\"Che\",\"Vai\",\"Jet\",\"Har\",\"Saw\",\"Bha\",\"Ass\",\"Kat\",\"Mgr\",\"Poh\",\"Mgh\",\"Pha\"],dayNames:[\"Somvaar\",\"Mangalvar\",\"Budhvaar\",\"Veervaar\",\"Shukarvaar\",\"Sanicharvaar\",\"Etvaar\"],dayNamesShort:[\"Som\",\"Mangal\",\"Budh\",\"Veer\",\"Shukar\",\"Sanichar\",\"Et\"],dayNamesMin:[\"So\",\"Ma\",\"Bu\",\"Ve\",\"Sh\",\"Sa\",\"Et\"],digits:null,dateFormat:\"dd-mm-yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear);return o.leapYear(e.year()+(e.year()<1?1:0)+1469)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(1-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidMonth);(t=i.year())<0&&t++;for(var a=i.day(),s=1;s<i.month();s++)a+=this.daysPerMonth[s-1];return a+o.toJD(t+1468,3,13)},fromJD:function(t){t=Math.floor(t+.5);for(var e=Math.floor((t-(this.jdEpoch-1))/366);t>=this.toJD(e+1,1,1);)e++;for(var r=t-Math.floor(this.toJD(e,1,1)+.5)+1,n=1;r>this.daysInMonth(e,n);)r-=this.daysInMonth(e,n),n++;return this.newDate(e,n,r)}}),n.calendars.nanakshahi=a},{\"../main\":571,\"object-assign\":454}],566:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Nepali\",jdEpoch:1700709.5,daysPerMonth:[31,31,32,32,31,30,30,29,30,29,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,daysPerYear:365,regionalOptions:{\"\":{name:\"Nepali\",epochs:[\"BBS\",\"ABS\"],monthNames:[\"Baisakh\",\"Jestha\",\"Ashadh\",\"Shrawan\",\"Bhadra\",\"Ashwin\",\"Kartik\",\"Mangsir\",\"Paush\",\"Mangh\",\"Falgun\",\"Chaitra\"],monthNamesShort:[\"Bai\",\"Je\",\"As\",\"Shra\",\"Bha\",\"Ash\",\"Kar\",\"Mang\",\"Pau\",\"Ma\",\"Fal\",\"Chai\"],dayNames:[\"Aaitabaar\",\"Sombaar\",\"Manglbaar\",\"Budhabaar\",\"Bihibaar\",\"Shukrabaar\",\"Shanibaar\"],dayNamesShort:[\"Aaita\",\"Som\",\"Mangl\",\"Budha\",\"Bihi\",\"Shukra\",\"Shani\"],dayNamesMin:[\"Aai\",\"So\",\"Man\",\"Bu\",\"Bi\",\"Shu\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:1,isRTL:!1}},leapYear:function(t){return this.daysInYear(t)!==this.daysPerYear},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){if(t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t])return this.daysPerYear;for(var e=0,r=this.minMonth;r<=12;r++)e+=this.NEPALI_CALENDAR_DATA[t][r];return e},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t]?this.daysPerMonth[e-1]:this.NEPALI_CALENDAR_DATA[t][e]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=n.instance(),o=0,s=e,l=t;this._createMissingCalendarData(t);var c=t-(s>9||9===s&&r>=this.NEPALI_CALENDAR_DATA[l][0]?56:57);for(9!==e&&(o=r,s--);9!==s;)s<=0&&(s=12,l--),o+=this.NEPALI_CALENDAR_DATA[l][s],s--;return 9===e?(o+=r-this.NEPALI_CALENDAR_DATA[l][0])<0&&(o+=a.daysInYear(c)):o+=this.NEPALI_CALENDAR_DATA[l][9]-this.NEPALI_CALENDAR_DATA[l][0],a.newDate(c,1,1).add(o,\"d\").toJD()},fromJD:function(t){var e=n.instance().fromJD(t),r=e.year(),i=e.dayOfYear(),a=r+56;this._createMissingCalendarData(a);for(var o=9,s=this.NEPALI_CALENDAR_DATA[a][0],l=this.NEPALI_CALENDAR_DATA[a][o]-s+1;i>l;)++o>12&&(o=1,a++),l+=this.NEPALI_CALENDAR_DATA[a][o];var c=this.NEPALI_CALENDAR_DATA[a][o]-(l-i);return this.newDate(a,o,c)},_createMissingCalendarData:function(t){var e=this.daysPerMonth.slice(0);e.unshift(17);for(var r=t-1;r<t+2;r++)\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[r]&&(this.NEPALI_CALENDAR_DATA[r]=e)},NEPALI_CALENDAR_DATA:{1970:[18,31,31,32,31,31,31,30,29,30,29,30,30],1971:[18,31,31,32,31,32,30,30,29,30,29,30,30],1972:[17,31,32,31,32,31,30,30,30,29,29,30,30],1973:[19,30,32,31,32,31,30,30,30,29,30,29,31],1974:[19,31,31,32,30,31,31,30,29,30,29,30,30],1975:[18,31,31,32,32,30,31,30,29,30,29,30,30],1976:[17,31,32,31,32,31,30,30,30,29,29,30,31],1977:[18,31,32,31,32,31,31,29,30,29,30,29,31],1978:[18,31,31,32,31,31,31,30,29,30,29,30,30],1979:[18,31,31,32,32,31,30,30,29,30,29,30,30],1980:[17,31,32,31,32,31,30,30,30,29,29,30,31],1981:[18,31,31,31,32,31,31,29,30,30,29,30,30],1982:[18,31,31,32,31,31,31,30,29,30,29,30,30],1983:[18,31,31,32,32,31,30,30,29,30,29,30,30],1984:[17,31,32,31,32,31,30,30,30,29,29,30,31],1985:[18,31,31,31,32,31,31,29,30,30,29,30,30],1986:[18,31,31,32,31,31,31,30,29,30,29,30,30],1987:[18,31,32,31,32,31,30,30,29,30,29,30,30],1988:[17,31,32,31,32,31,30,30,30,29,29,30,31],1989:[18,31,31,31,32,31,31,30,29,30,29,30,30],1990:[18,31,31,32,31,31,31,30,29,30,29,30,30],1991:[18,31,32,31,32,31,30,30,29,30,29,30,30],1992:[17,31,32,31,32,31,30,30,30,29,30,29,31],1993:[18,31,31,31,32,31,31,30,29,30,29,30,30],1994:[18,31,31,32,31,31,31,30,29,30,29,30,30],1995:[17,31,32,31,32,31,30,30,30,29,29,30,30],1996:[17,31,32,31,32,31,30,30,30,29,30,29,31],1997:[18,31,31,32,31,31,31,30,29,30,29,30,30],1998:[18,31,31,32,31,31,31,30,29,30,29,30,30],1999:[17,31,32,31,32,31,30,30,30,29,29,30,31],2000:[17,30,32,31,32,31,30,30,30,29,30,29,31],2001:[18,31,31,32,31,31,31,30,29,30,29,30,30],2002:[18,31,31,32,32,31,30,30,29,30,29,30,30],2003:[17,31,32,31,32,31,30,30,30,29,29,30,31],2004:[17,30,32,31,32,31,30,30,30,29,30,29,31],2005:[18,31,31,32,31,31,31,30,29,30,29,30,30],2006:[18,31,31,32,32,31,30,30,29,30,29,30,30],2007:[17,31,32,31,32,31,30,30,30,29,29,30,31],2008:[17,31,31,31,32,31,31,29,30,30,29,29,31],2009:[18,31,31,32,31,31,31,30,29,30,29,30,30],2010:[18,31,31,32,32,31,30,30,29,30,29,30,30],2011:[17,31,32,31,32,31,30,30,30,29,29,30,31],2012:[17,31,31,31,32,31,31,29,30,30,29,30,30],2013:[18,31,31,32,31,31,31,30,29,30,29,30,30],2014:[18,31,31,32,32,31,30,30,29,30,29,30,30],2015:[17,31,32,31,32,31,30,30,30,29,29,30,31],2016:[17,31,31,31,32,31,31,29,30,30,29,30,30],2017:[18,31,31,32,31,31,31,30,29,30,29,30,30],2018:[18,31,32,31,32,31,30,30,29,30,29,30,30],2019:[17,31,32,31,32,31,30,30,30,29,30,29,31],2020:[17,31,31,31,32,31,31,30,29,30,29,30,30],2021:[18,31,31,32,31,31,31,30,29,30,29,30,30],2022:[17,31,32,31,32,31,30,30,30,29,29,30,30],2023:[17,31,32,31,32,31,30,30,30,29,30,29,31],2024:[17,31,31,31,32,31,31,30,29,30,29,30,30],2025:[18,31,31,32,31,31,31,30,29,30,29,30,30],2026:[17,31,32,31,32,31,30,30,30,29,29,30,31],2027:[17,30,32,31,32,31,30,30,30,29,30,29,31],2028:[17,31,31,32,31,31,31,30,29,30,29,30,30],2029:[18,31,31,32,31,32,30,30,29,30,29,30,30],2030:[17,31,32,31,32,31,30,30,30,30,30,30,31],2031:[17,31,32,31,32,31,31,31,31,31,31,31,31],2032:[17,32,32,32,32,32,32,32,32,32,32,32,32],2033:[18,31,31,32,32,31,30,30,29,30,29,30,30],2034:[17,31,32,31,32,31,30,30,30,29,29,30,31],2035:[17,30,32,31,32,31,31,29,30,30,29,29,31],2036:[17,31,31,32,31,31,31,30,29,30,29,30,30],2037:[18,31,31,32,32,31,30,30,29,30,29,30,30],2038:[17,31,32,31,32,31,30,30,30,29,29,30,31],2039:[17,31,31,31,32,31,31,29,30,30,29,30,30],2040:[17,31,31,32,31,31,31,30,29,30,29,30,30],2041:[18,31,31,32,32,31,30,30,29,30,29,30,30],2042:[17,31,32,31,32,31,30,30,30,29,29,30,31],2043:[17,31,31,31,32,31,31,29,30,30,29,30,30],2044:[17,31,31,32,31,31,31,30,29,30,29,30,30],2045:[18,31,32,31,32,31,30,30,29,30,29,30,30],2046:[17,31,32,31,32,31,30,30,30,29,29,30,31],2047:[17,31,31,31,32,31,31,30,29,30,29,30,30],2048:[17,31,31,32,31,31,31,30,29,30,29,30,30],2049:[17,31,32,31,32,31,30,30,30,29,29,30,30],2050:[17,31,32,31,32,31,30,30,30,29,30,29,31],2051:[17,31,31,31,32,31,31,30,29,30,29,30,30],2052:[17,31,31,32,31,31,31,30,29,30,29,30,30],2053:[17,31,32,31,32,31,30,30,30,29,29,30,30],2054:[17,31,32,31,32,31,30,30,30,29,30,29,31],2055:[17,31,31,32,31,31,31,30,29,30,30,29,30],2056:[17,31,31,32,31,32,30,30,29,30,29,30,30],2057:[17,31,32,31,32,31,30,30,30,29,29,30,31],2058:[17,30,32,31,32,31,30,30,30,29,30,29,31],2059:[17,31,31,32,31,31,31,30,29,30,29,30,30],2060:[17,31,31,32,32,31,30,30,29,30,29,30,30],2061:[17,31,32,31,32,31,30,30,30,29,29,30,31],2062:[17,30,32,31,32,31,31,29,30,29,30,29,31],2063:[17,31,31,32,31,31,31,30,29,30,29,30,30],2064:[17,31,31,32,32,31,30,30,29,30,29,30,30],2065:[17,31,32,31,32,31,30,30,30,29,29,30,31],2066:[17,31,31,31,32,31,31,29,30,30,29,29,31],2067:[17,31,31,32,31,31,31,30,29,30,29,30,30],2068:[17,31,31,32,32,31,30,30,29,30,29,30,30],2069:[17,31,32,31,32,31,30,30,30,29,29,30,31],2070:[17,31,31,31,32,31,31,29,30,30,29,30,30],2071:[17,31,31,32,31,31,31,30,29,30,29,30,30],2072:[17,31,32,31,32,31,30,30,29,30,29,30,30],2073:[17,31,32,31,32,31,30,30,30,29,29,30,31],2074:[17,31,31,31,32,31,31,30,29,30,29,30,30],2075:[17,31,31,32,31,31,31,30,29,30,29,30,30],2076:[16,31,32,31,32,31,30,30,30,29,29,30,30],2077:[17,31,32,31,32,31,30,30,30,29,30,29,31],2078:[17,31,31,31,32,31,31,30,29,30,29,30,30],2079:[17,31,31,32,31,31,31,30,29,30,29,30,30],2080:[16,31,32,31,32,31,30,30,30,29,29,30,30],2081:[17,31,31,32,32,31,30,30,30,29,30,30,30],2082:[17,31,32,31,32,31,30,30,30,29,30,30,30],2083:[17,31,31,32,31,31,30,30,30,29,30,30,30],2084:[17,31,31,32,31,31,30,30,30,29,30,30,30],2085:[17,31,32,31,32,31,31,30,30,29,30,30,30],2086:[17,31,32,31,32,31,30,30,30,29,30,30,30],2087:[16,31,31,32,31,31,31,30,30,29,30,30,30],2088:[16,30,31,32,32,30,31,30,30,29,30,30,30],2089:[17,31,32,31,32,31,30,30,30,29,30,30,30],2090:[17,31,32,31,32,31,30,30,30,29,30,30,30],2091:[16,31,31,32,31,31,31,30,30,29,30,30,30],2092:[16,31,31,32,32,31,30,30,30,29,30,30,30],2093:[17,31,32,31,32,31,30,30,30,29,30,30,30],2094:[17,31,31,32,31,31,30,30,30,29,30,30,30],2095:[17,31,31,32,31,31,31,30,29,30,30,30,30],2096:[17,30,31,32,32,31,30,30,29,30,29,30,30],2097:[17,31,32,31,32,31,30,30,30,29,30,30,30],2098:[17,31,31,32,31,31,31,29,30,29,30,30,31],2099:[17,31,31,32,31,31,31,30,29,29,30,30,30],2100:[17,31,32,31,32,30,31,30,29,30,29,30,30]}}),n.calendars.nepali=a},{\"../main\":571,\"object-assign\":454}],567:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Persian\",jdEpoch:1948320.5,daysPerMonth:[31,31,31,31,31,31,30,30,30,30,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Persian\",epochs:[\"BP\",\"AP\"],monthNames:[\"Farvardin\",\"Ordibehesht\",\"Khordad\",\"Tir\",\"Mordad\",\"Shahrivar\",\"Mehr\",\"Aban\",\"Azar\",\"Day\",\"Bahman\",\"Esfand\"],monthNamesShort:[\"Far\",\"Ord\",\"Kho\",\"Tir\",\"Mor\",\"Sha\",\"Meh\",\"Aba\",\"Aza\",\"Day\",\"Bah\",\"Esf\"],dayNames:[\"Yekshambe\",\"Doshambe\",\"Seshambe\",\"Ch\\xe6harshambe\",\"Panjshambe\",\"Jom'e\",\"Shambe\"],dayNamesShort:[\"Yek\",\"Do\",\"Se\",\"Ch\\xe6\",\"Panj\",\"Jom\",\"Sha\"],dayNamesMin:[\"Ye\",\"Do\",\"Se\",\"Ch\",\"Pa\",\"Jo\",\"Sh\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 682*((e.year()-(e.year()>0?474:473))%2820+474+38)%2816<682},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-(n.dayOfWeek()+1)%7,\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t-(t>=0?474:473),s=474+o(a,2820);return r+(e<=7?31*(e-1):30*(e-1)+6)+Math.floor((682*s-110)/2816)+365*(s-1)+1029983*Math.floor(a/2820)+this.jdEpoch-1},fromJD:function(t){var e=(t=Math.floor(t)+.5)-this.toJD(475,1,1),r=Math.floor(e/1029983),n=o(e,1029983),i=2820;if(1029982!==n){var a=Math.floor(n/366),s=o(n,366);i=Math.floor((2134*a+2816*s+2815)/1028522)+a+1}var l=i+2820*r+474;l=l<=0?l-1:l;var c=t-this.toJD(l,1,1)+1,u=c<=186?Math.ceil(c/31):Math.ceil((c-6)/30),h=t-this.toJD(l,u,1)+1;return this.newDate(l,u,h)}}),n.calendars.persian=a,n.calendars.jalali=a},{\"../main\":571,\"object-assign\":454}],568:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Taiwan\",jdEpoch:2419402.5,yearsOffset:1911,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Taiwan\",epochs:[\"BROC\",\"ROC\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)},_g2tYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)}}),n.calendars.taiwan=o},{\"../main\":571,\"object-assign\":454}],569:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Thai\",jdEpoch:1523098.5,yearsOffset:543,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Thai\",epochs:[\"BBE\",\"BE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)},_g2tYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)}}),n.calendars.thai=o},{\"../main\":571,\"object-assign\":454}],570:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"UmmAlQura\",hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Umm al-Qura\",epochs:[\"BH\",\"AH\"],monthNames:[\"Al-Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' Al-Thani\",\"Jumada Al-Awwal\",\"Jumada Al-Thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-Ahad\",\"Yawm al-Ithnain\",\"Yawm al-Thal\\u0101th\\u0101\\u2019\",\"Yawm al-Arba\\u2018\\u0101\\u2019\",\"Yawm al-Kham\\u012bs\",\"Yawm al-Jum\\u2018a\",\"Yawm al-Sabt\"],dayNamesMin:[\"Ah\",\"Ith\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!0}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 355===this.daysInYear(e.year())},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){for(var e=0,r=1;r<=12;r++)e+=this.daysInMonth(t,r);return e},daysInMonth:function(t,e){for(var r=this._validate(t,e,this.minDay,n.local.invalidMonth).toJD()-24e5+.5,i=0,a=0;a<o.length;a++){if(o[a]>r)return o[i]-o[i-1];i++}return 30},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate),a=12*(i.year()-1)+i.month()-15292;return i.day()+o[a-1]-1+24e5-.5},fromJD:function(t){for(var e=t-24e5+.5,r=0,n=0;n<o.length&&!(o[n]>e);n++)r++;var i=r+15292,a=Math.floor((i-1)/12),s=a+1,l=i-12*a,c=e-o[r-1]+1;return this.newDate(s,l,c)},isValid:function(t,e,r){var i=n.baseCalendar.prototype.isValid.apply(this,arguments);return i&&(i=(t=null!=t.year?t.year:t)>=1276&&t<=1500),i},_validate:function(t,e,r,i){var a=n.baseCalendar.prototype._validate.apply(this,arguments);if(a.year<1276||a.year>1500)throw i.replace(/\\{0\\}/,this.local.name);return a}}),n.calendars.ummalqura=a;var o=[20,50,79,109,138,168,197,227,256,286,315,345,374,404,433,463,492,522,551,581,611,641,670,700,729,759,788,818,847,877,906,936,965,995,1024,1054,1083,1113,1142,1172,1201,1231,1260,1290,1320,1350,1379,1409,1438,1468,1497,1527,1556,1586,1615,1645,1674,1704,1733,1763,1792,1822,1851,1881,1910,1940,1969,1999,2028,2058,2087,2117,2146,2176,2205,2235,2264,2294,2323,2353,2383,2413,2442,2472,2501,2531,2560,2590,2619,2649,2678,2708,2737,2767,2796,2826,2855,2885,2914,2944,2973,3003,3032,3062,3091,3121,3150,3180,3209,3239,3268,3298,3327,3357,3386,3416,3446,3476,3505,3535,3564,3594,3623,3653,3682,3712,3741,3771,3800,3830,3859,3889,3918,3948,3977,4007,4036,4066,4095,4125,4155,4185,4214,4244,4273,4303,4332,4362,4391,4421,4450,4480,4509,4539,4568,4598,4627,4657,4686,4716,4745,4775,4804,4834,4863,4893,4922,4952,4981,5011,5040,5070,5099,5129,5158,5188,5218,5248,5277,5307,5336,5366,5395,5425,5454,5484,5513,5543,5572,5602,5631,5661,5690,5720,5749,5779,5808,5838,5867,5897,5926,5956,5985,6015,6044,6074,6103,6133,6162,6192,6221,6251,6281,6311,6340,6370,6399,6429,6458,6488,6517,6547,6576,6606,6635,6665,6694,6724,6753,6783,6812,6842,6871,6901,6930,6960,6989,7019,7048,7078,7107,7137,7166,7196,7225,7255,7284,7314,7344,7374,7403,7433,7462,7492,7521,7551,7580,7610,7639,7669,7698,7728,7757,7787,7816,7846,7875,7905,7934,7964,7993,8023,8053,8083,8112,8142,8171,8201,8230,8260,8289,8319,8348,8378,8407,8437,8466,8496,8525,8555,8584,8614,8643,8673,8702,8732,8761,8791,8821,8850,8880,8909,8938,8968,8997,9027,9056,9086,9115,9145,9175,9205,9234,9264,9293,9322,9352,9381,9410,9440,9470,9499,9529,9559,9589,9618,9648,9677,9706,9736,9765,9794,9824,9853,9883,9913,9943,9972,10002,10032,10061,10090,10120,10149,10178,10208,10237,10267,10297,10326,10356,10386,10415,10445,10474,10504,10533,10562,10592,10621,10651,10680,10710,10740,10770,10799,10829,10858,10888,10917,10947,10976,11005,11035,11064,11094,11124,11153,11183,11213,11242,11272,11301,11331,11360,11389,11419,11448,11478,11507,11537,11567,11596,11626,11655,11685,11715,11744,11774,11803,11832,11862,11891,11921,11950,11980,12010,12039,12069,12099,12128,12158,12187,12216,12246,12275,12304,12334,12364,12393,12423,12453,12483,12512,12542,12571,12600,12630,12659,12688,12718,12747,12777,12807,12837,12866,12896,12926,12955,12984,13014,13043,13072,13102,13131,13161,13191,13220,13250,13280,13310,13339,13368,13398,13427,13456,13486,13515,13545,13574,13604,13634,13664,13693,13723,13752,13782,13811,13840,13870,13899,13929,13958,13988,14018,14047,14077,14107,14136,14166,14195,14224,14254,14283,14313,14342,14372,14401,14431,14461,14490,14520,14550,14579,14609,14638,14667,14697,14726,14756,14785,14815,14844,14874,14904,14933,14963,14993,15021,15051,15081,15110,15140,15169,15199,15228,15258,15287,15317,15347,15377,15406,15436,15465,15494,15524,15553,15582,15612,15641,15671,15701,15731,15760,15790,15820,15849,15878,15908,15937,15966,15996,16025,16055,16085,16114,16144,16174,16204,16233,16262,16292,16321,16350,16380,16409,16439,16468,16498,16528,16558,16587,16617,16646,16676,16705,16734,16764,16793,16823,16852,16882,16912,16941,16971,17001,17030,17060,17089,17118,17148,17177,17207,17236,17266,17295,17325,17355,17384,17414,17444,17473,17502,17532,17561,17591,17620,17650,17679,17709,17738,17768,17798,17827,17857,17886,17916,17945,17975,18004,18034,18063,18093,18122,18152,18181,18211,18241,18270,18300,18330,18359,18388,18418,18447,18476,18506,18535,18565,18595,18625,18654,18684,18714,18743,18772,18802,18831,18860,18890,18919,18949,18979,19008,19038,19068,19098,19127,19156,19186,19215,19244,19274,19303,19333,19362,19392,19422,19452,19481,19511,19540,19570,19599,19628,19658,19687,19717,19746,19776,19806,19836,19865,19895,19924,19954,19983,20012,20042,20071,20101,20130,20160,20190,20219,20249,20279,20308,20338,20367,20396,20426,20455,20485,20514,20544,20573,20603,20633,20662,20692,20721,20751,20780,20810,20839,20869,20898,20928,20957,20987,21016,21046,21076,21105,21135,21164,21194,21223,21253,21282,21312,21341,21371,21400,21430,21459,21489,21519,21548,21578,21607,21637,21666,21696,21725,21754,21784,21813,21843,21873,21902,21932,21962,21991,22021,22050,22080,22109,22138,22168,22197,22227,22256,22286,22316,22346,22375,22405,22434,22464,22493,22522,22552,22581,22611,22640,22670,22700,22730,22759,22789,22818,22848,22877,22906,22936,22965,22994,23024,23054,23083,23113,23143,23173,23202,23232,23261,23290,23320,23349,23379,23408,23438,23467,23497,23527,23556,23586,23616,23645,23674,23704,23733,23763,23792,23822,23851,23881,23910,23940,23970,23999,24029,24058,24088,24117,24147,24176,24206,24235,24265,24294,24324,24353,24383,24413,24442,24472,24501,24531,24560,24590,24619,24648,24678,24707,24737,24767,24796,24826,24856,24885,24915,24944,24974,25003,25032,25062,25091,25121,25150,25180,25210,25240,25269,25299,25328,25358,25387,25416,25446,25475,25505,25534,25564,25594,25624,25653,25683,25712,25742,25771,25800,25830,25859,25888,25918,25948,25977,26007,26037,26067,26096,26126,26155,26184,26214,26243,26272,26302,26332,26361,26391,26421,26451,26480,26510,26539,26568,26598,26627,26656,26686,26715,26745,26775,26805,26834,26864,26893,26923,26952,26982,27011,27041,27070,27099,27129,27159,27188,27218,27248,27277,27307,27336,27366,27395,27425,27454,27484,27513,27542,27572,27602,27631,27661,27691,27720,27750,27779,27809,27838,27868,27897,27926,27956,27985,28015,28045,28074,28104,28134,28163,28193,28222,28252,28281,28310,28340,28369,28399,28428,28458,28488,28517,28547,28577,28607,28636,28665,28695,28724,28754,28783,28813,28843,28872,28901,28931,28960,28990,29019,29049,29078,29108,29137,29167,29196,29226,29255,29285,29315,29345,29375,29404,29434,29463,29492,29522,29551,29580,29610,29640,29669,29699,29729,29759,29788,29818,29847,29876,29906,29935,29964,29994,30023,30053,30082,30112,30141,30171,30200,30230,30259,30289,30318,30348,30378,30408,30437,30467,30496,30526,30555,30585,30614,30644,30673,30703,30732,30762,30791,30821,30850,30880,30909,30939,30968,30998,31027,31057,31086,31116,31145,31175,31204,31234,31263,31293,31322,31352,31381,31411,31441,31471,31500,31530,31559,31589,31618,31648,31676,31706,31736,31766,31795,31825,31854,31884,31913,31943,31972,32002,32031,32061,32090,32120,32150,32180,32209,32239,32268,32298,32327,32357,32386,32416,32445,32475,32504,32534,32563,32593,32622,32652,32681,32711,32740,32770,32799,32829,32858,32888,32917,32947,32976,33006,33035,33065,33094,33124,33153,33183,33213,33243,33272,33302,33331,33361,33390,33420,33450,33479,33509,33539,33568,33598,33627,33657,33686,33716,33745,33775,33804,33834,33863,33893,33922,33952,33981,34011,34040,34069,34099,34128,34158,34187,34217,34247,34277,34306,34336,34365,34395,34424,34454,34483,34512,34542,34571,34601,34631,34660,34690,34719,34749,34778,34808,34837,34867,34896,34926,34955,34985,35015,35044,35074,35103,35133,35162,35192,35222,35251,35280,35310,35340,35370,35399,35429,35458,35488,35517,35547,35576,35605,35635,35665,35694,35723,35753,35782,35811,35841,35871,35901,35930,35960,35989,36019,36048,36078,36107,36136,36166,36195,36225,36254,36284,36314,36343,36373,36403,36433,36462,36492,36521,36551,36580,36610,36639,36669,36698,36728,36757,36786,36816,36845,36875,36904,36934,36963,36993,37022,37052,37081,37111,37141,37170,37200,37229,37259,37288,37318,37347,37377,37406,37436,37465,37495,37524,37554,37584,37613,37643,37672,37701,37731,37760,37790,37819,37849,37878,37908,37938,37967,37997,38027,38056,38085,38115,38144,38174,38203,38233,38262,38292,38322,38351,38381,38410,38440,38469,38499,38528,38558,38587,38617,38646,38676,38705,38735,38764,38794,38823,38853,38882,38912,38941,38971,39001,39030,39059,39089,39118,39148,39178,39208,39237,39267,39297,39326,39355,39385,39414,39444,39473,39503,39532,39562,39592,39621,39650,39680,39709,39739,39768,39798,39827,39857,39886,39916,39946,39975,40005,40035,40064,40094,40123,40153,40182,40212,40241,40271,40300,40330,40359,40389,40418,40448,40477,40507,40536,40566,40595,40625,40655,40685,40714,40744,40773,40803,40832,40862,40892,40921,40951,40980,41009,41039,41068,41098,41127,41157,41186,41216,41245,41275,41304,41334,41364,41393,41422,41452,41481,41511,41540,41570,41599,41629,41658,41688,41718,41748,41777,41807,41836,41865,41894,41924,41953,41983,42012,42042,42072,42102,42131,42161,42190,42220,42249,42279,42308,42337,42367,42397,42426,42456,42485,42515,42545,42574,42604,42633,42662,42692,42721,42751,42780,42810,42839,42869,42899,42929,42958,42988,43017,43046,43076,43105,43135,43164,43194,43223,43253,43283,43312,43342,43371,43401,43430,43460,43489,43519,43548,43578,43607,43637,43666,43696,43726,43755,43785,43814,43844,43873,43903,43932,43962,43991,44021,44050,44080,44109,44139,44169,44198,44228,44258,44287,44317,44346,44375,44405,44434,44464,44493,44523,44553,44582,44612,44641,44671,44700,44730,44759,44788,44818,44847,44877,44906,44936,44966,44996,45025,45055,45084,45114,45143,45172,45202,45231,45261,45290,45320,45350,45380,45409,45439,45468,45498,45527,45556,45586,45615,45644,45674,45704,45733,45763,45793,45823,45852,45882,45911,45940,45970,45999,46028,46058,46088,46117,46147,46177,46206,46236,46265,46295,46324,46354,46383,46413,46442,46472,46501,46531,46560,46590,46620,46649,46679,46708,46738,46767,46797,46826,46856,46885,46915,46944,46974,47003,47033,47063,47092,47122,47151,47181,47210,47240,47269,47298,47328,47357,47387,47417,47446,47476,47506,47535,47565,47594,47624,47653,47682,47712,47741,47771,47800,47830,47860,47890,47919,47949,47978,48008,48037,48066,48096,48125,48155,48184,48214,48244,48273,48303,48333,48362,48392,48421,48450,48480,48509,48538,48568,48598,48627,48657,48687,48717,48746,48776,48805,48834,48864,48893,48922,48952,48982,49011,49041,49071,49100,49130,49160,49189,49218,49248,49277,49306,49336,49365,49395,49425,49455,49484,49514,49543,49573,49602,49632,49661,49690,49720,49749,49779,49809,49838,49868,49898,49927,49957,49986,50016,50045,50075,50104,50133,50163,50192,50222,50252,50281,50311,50340,50370,50400,50429,50459,50488,50518,50547,50576,50606,50635,50665,50694,50724,50754,50784,50813,50843,50872,50902,50931,50960,50990,51019,51049,51078,51108,51138,51167,51197,51227,51256,51286,51315,51345,51374,51403,51433,51462,51492,51522,51552,51582,51611,51641,51670,51699,51729,51758,51787,51816,51846,51876,51906,51936,51965,51995,52025,52054,52083,52113,52142,52171,52200,52230,52260,52290,52319,52349,52379,52408,52438,52467,52497,52526,52555,52585,52614,52644,52673,52703,52733,52762,52792,52822,52851,52881,52910,52939,52969,52998,53028,53057,53087,53116,53146,53176,53205,53235,53264,53294,53324,53353,53383,53412,53441,53471,53500,53530,53559,53589,53619,53648,53678,53708,53737,53767,53796,53825,53855,53884,53913,53943,53973,54003,54032,54062,54092,54121,54151,54180,54209,54239,54268,54297,54327,54357,54387,54416,54446,54476,54505,54535,54564,54593,54623,54652,54681,54711,54741,54770,54800,54830,54859,54889,54919,54948,54977,55007,55036,55066,55095,55125,55154,55184,55213,55243,55273,55302,55332,55361,55391,55420,55450,55479,55508,55538,55567,55597,55627,55657,55686,55716,55745,55775,55804,55834,55863,55892,55922,55951,55981,56011,56040,56070,56100,56129,56159,56188,56218,56247,56276,56306,56335,56365,56394,56424,56454,56483,56513,56543,56572,56601,56631,56660,56690,56719,56749,56778,56808,56837,56867,56897,56926,56956,56985,57015,57044,57074,57103,57133,57162,57192,57221,57251,57280,57310,57340,57369,57399,57429,57458,57487,57517,57546,57576,57605,57634,57664,57694,57723,57753,57783,57813,57842,57871,57901,57930,57959,57989,58018,58048,58077,58107,58137,58167,58196,58226,58255,58285,58314,58343,58373,58402,58432,58461,58491,58521,58551,58580,58610,58639,58669,58698,58727,58757,58786,58816,58845,58875,58905,58934,58964,58994,59023,59053,59082,59111,59141,59170,59200,59229,59259,59288,59318,59348,59377,59407,59436,59466,59495,59525,59554,59584,59613,59643,59672,59702,59731,59761,59791,59820,59850,59879,59909,59939,59968,59997,60027,60056,60086,60115,60145,60174,60204,60234,60264,60293,60323,60352,60381,60411,60440,60469,60499,60528,60558,60588,60618,60648,60677,60707,60736,60765,60795,60824,60853,60883,60912,60942,60972,61002,61031,61061,61090,61120,61149,61179,61208,61237,61267,61296,61326,61356,61385,61415,61445,61474,61504,61533,61563,61592,61621,61651,61680,61710,61739,61769,61799,61828,61858,61888,61917,61947,61976,62006,62035,62064,62094,62123,62153,62182,62212,62242,62271,62301,62331,62360,62390,62419,62448,62478,62507,62537,62566,62596,62625,62655,62685,62715,62744,62774,62803,62832,62862,62891,62921,62950,62980,63009,63039,63069,63099,63128,63157,63187,63216,63246,63275,63305,63334,63363,63393,63423,63453,63482,63512,63541,63571,63600,63630,63659,63689,63718,63747,63777,63807,63836,63866,63895,63925,63955,63984,64014,64043,64073,64102,64131,64161,64190,64220,64249,64279,64309,64339,64368,64398,64427,64457,64486,64515,64545,64574,64603,64633,64663,64692,64722,64752,64782,64811,64841,64870,64899,64929,64958,64987,65017,65047,65076,65106,65136,65166,65195,65225,65254,65283,65313,65342,65371,65401,65431,65460,65490,65520,65549,65579,65608,65638,65667,65697,65726,65755,65785,65815,65844,65874,65903,65933,65963,65992,66022,66051,66081,66110,66140,66169,66199,66228,66258,66287,66317,66346,66376,66405,66435,66465,66494,66524,66553,66583,66612,66641,66671,66700,66730,66760,66789,66819,66849,66878,66908,66937,66967,66996,67025,67055,67084,67114,67143,67173,67203,67233,67262,67292,67321,67351,67380,67409,67439,67468,67497,67527,67557,67587,67617,67646,67676,67705,67735,67764,67793,67823,67852,67882,67911,67941,67971,68e3,68030,68060,68089,68119,68148,68177,68207,68236,68266,68295,68325,68354,68384,68414,68443,68473,68502,68532,68561,68591,68620,68650,68679,68708,68738,68768,68797,68827,68857,68886,68916,68946,68975,69004,69034,69063,69092,69122,69152,69181,69211,69240,69270,69300,69330,69359,69388,69418,69447,69476,69506,69535,69565,69595,69624,69654,69684,69713,69743,69772,69802,69831,69861,69890,69919,69949,69978,70008,70038,70067,70097,70126,70156,70186,70215,70245,70274,70303,70333,70362,70392,70421,70451,70481,70510,70540,70570,70599,70629,70658,70687,70717,70746,70776,70805,70835,70864,70894,70924,70954,70983,71013,71042,71071,71101,71130,71159,71189,71218,71248,71278,71308,71337,71367,71397,71426,71455,71485,71514,71543,71573,71602,71632,71662,71691,71721,71751,71781,71810,71839,71869,71898,71927,71957,71986,72016,72046,72075,72105,72135,72164,72194,72223,72253,72282,72311,72341,72370,72400,72429,72459,72489,72518,72548,72577,72607,72637,72666,72695,72725,72754,72784,72813,72843,72872,72902,72931,72961,72991,73020,73050,73080,73109,73139,73168,73197,73227,73256,73286,73315,73345,73375,73404,73434,73464,73493,73523,73552,73581,73611,73640,73669,73699,73729,73758,73788,73818,73848,73877,73907,73936,73965,73995,74024,74053,74083,74113,74142,74172,74202,74231,74261,74291,74320,74349,74379,74408,74437,74467,74497,74526,74556,74586,74615,74645,74675,74704,74733,74763,74792,74822,74851,74881,74910,74940,74969,74999,75029,75058,75088,75117,75147,75176,75206,75235,75264,75294,75323,75353,75383,75412,75442,75472,75501,75531,75560,75590,75619,75648,75678,75707,75737,75766,75796,75826,75856,75885,75915,75944,75974,76003,76032,76062,76091,76121,76150,76180,76210,76239,76269,76299,76328,76358,76387,76416,76446,76475,76505,76534,76564,76593,76623,76653,76682,76712,76741,76771,76801,76830,76859,76889,76918,76948,76977,77007,77036,77066,77096,77125,77155,77185,77214,77243,77273,77302,77332,77361,77390,77420,77450,77479,77509,77539,77569,77598,77627,77657,77686,77715,77745,77774,77804,77833,77863,77893,77923,77952,77982,78011,78041,78070,78099,78129,78158,78188,78217,78247,78277,78307,78336,78366,78395,78425,78454,78483,78513,78542,78572,78601,78631,78661,78690,78720,78750,78779,78808,78838,78867,78897,78926,78956,78985,79015,79044,79074,79104,79133,79163,79192,79222,79251,79281,79310,79340,79369,79399,79428,79458,79487,79517,79546,79576,79606,79635,79665,79695,79724,79753,79783,79812,79841,79871,79900,79930,79960,79990]},{\"../main\":571,\"object-assign\":454}],571:[function(t,e,r){var n=t(\"object-assign\");function i(){this.regionalOptions=[],this.regionalOptions[\"\"]={invalidCalendar:\"Calendar {0} not found\",invalidDate:\"Invalid {0} date\",invalidMonth:\"Invalid {0} month\",invalidYear:\"Invalid {0} year\",differentCalendars:\"Cannot mix {0} and {1} dates\"},this.local=this.regionalOptions[\"\"],this.calendars={},this._localCals={}}function a(t,e,r,n){if(this._calendar=t,this._year=e,this._month=r,this._day=n,0===this._calendar._validateLevel&&!this._calendar.isValid(this._year,this._month,this._day))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name)}function o(t,e){return\"000000\".substring(0,e-(t=\"\"+t).length)+t}function s(){this.shortYearCutoff=\"+10\"}function l(t){this.local=this.regionalOptions[t]||this.regionalOptions[\"\"]}n(i.prototype,{instance:function(t,e){t=(t||\"gregorian\").toLowerCase(),e=e||\"\";var r=this._localCals[t+\"-\"+e];if(!r&&this.calendars[t]&&(r=new this.calendars[t](e),this._localCals[t+\"-\"+e]=r),!r)throw(this.local.invalidCalendar||this.regionalOptions[\"\"].invalidCalendar).replace(/\\{0\\}/,t);return r},newDate:function(t,e,r,n,i){return(n=(null!=t&&t.year?t.calendar():\"string\"==typeof n?this.instance(n,i):n)||this.instance()).newDate(t,e,r)},substituteDigits:function(t){return function(e){return(e+\"\").replace(/[0-9]/g,function(e){return t[e]})}},substituteChineseDigits:function(t,e){return function(r){for(var n=\"\",i=0;r>0;){var a=r%10;n=(0===a?\"\":t[a]+e[i])+n,i++,r=Math.floor(r/10)}return 0===n.indexOf(t[1]+e[1])&&(n=n.substr(1)),n||t[0]}}}),n(a.prototype,{newDate:function(t,e,r){return this._calendar.newDate(null==t?this:t,e,r)},year:function(t){return 0===arguments.length?this._year:this.set(t,\"y\")},month:function(t){return 0===arguments.length?this._month:this.set(t,\"m\")},day:function(t){return 0===arguments.length?this._day:this.set(t,\"d\")},date:function(t,e,r){if(!this._calendar.isValid(t,e,r))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name);return this._year=t,this._month=e,this._day=r,this},leapYear:function(){return this._calendar.leapYear(this)},epoch:function(){return this._calendar.epoch(this)},formatYear:function(){return this._calendar.formatYear(this)},monthOfYear:function(){return this._calendar.monthOfYear(this)},weekOfYear:function(){return this._calendar.weekOfYear(this)},daysInYear:function(){return this._calendar.daysInYear(this)},dayOfYear:function(){return this._calendar.dayOfYear(this)},daysInMonth:function(){return this._calendar.daysInMonth(this)},dayOfWeek:function(){return this._calendar.dayOfWeek(this)},weekDay:function(){return this._calendar.weekDay(this)},extraInfo:function(){return this._calendar.extraInfo(this)},add:function(t,e){return this._calendar.add(this,t,e)},set:function(t,e){return this._calendar.set(this,t,e)},compareTo:function(t){if(this._calendar.name!==t._calendar.name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this._calendar.local.name).replace(/\\{1\\}/,t._calendar.local.name);var e=this._year!==t._year?this._year-t._year:this._month!==t._month?this.monthOfYear()-t.monthOfYear():this._day-t._day;return 0===e?0:e<0?-1:1},calendar:function(){return this._calendar},toJD:function(){return this._calendar.toJD(this)},fromJD:function(t){return this._calendar.fromJD(t)},toJSDate:function(){return this._calendar.toJSDate(this)},fromJSDate:function(t){return this._calendar.fromJSDate(t)},toString:function(){return(this.year()<0?\"-\":\"\")+o(Math.abs(this.year()),4)+\"-\"+o(this.month(),2)+\"-\"+o(this.day(),2)}}),n(s.prototype,{_validateLevel:0,newDate:function(t,e,r){return null==t?this.today():(t.year&&(this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),r=t.day(),e=t.month(),t=t.year()),new a(this,t,e,r))},today:function(){return this.fromJSDate(new Date)},epoch:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear).year()<0?this.local.epochs[0]:this.local.epochs[1]},formatYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(e.year()<0?\"-\":\"\")+o(Math.abs(e.year()),4)},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear),12},monthOfYear:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return(r.month()+this.monthsInYear(r)-this.firstMonth)%this.monthsInYear(r)+this.minMonth},fromMonthOfYear:function(t,e){var r=(e+this.firstMonth-2*this.minMonth)%this.monthsInYear(t)+this.minMonth;return this._validate(t,r,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth),r},daysInYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return this.leapYear(e)?366:365},dayOfYear:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return n.toJD()-this.newDate(n.year(),this.fromMonthOfYear(n.year(),this.minMonth),this.minDay).toJD()+1},daysInWeek:function(){return 7},dayOfWeek:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return(Math.floor(this.toJD(n))+2)%this.daysInWeek()},extraInfo:function(t,e,r){return this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),{}},add:function(t,e,r){return this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),this._correctAdd(t,this._add(t,e,r),e,r)},_add:function(t,e,r){if(this._validateLevel++,\"d\"===r||\"w\"===r){var n=t.toJD()+e*(\"w\"===r?this.daysInWeek():1),i=t.calendar().fromJD(n);return this._validateLevel--,[i.year(),i.month(),i.day()]}try{var a=t.year()+(\"y\"===r?e:0),o=t.monthOfYear()+(\"m\"===r?e:0);i=t.day();\"y\"===r?(t.month()!==this.fromMonthOfYear(a,o)&&(o=this.newDate(a,t.month(),this.minDay).monthOfYear()),o=Math.min(o,this.monthsInYear(a)),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o)))):\"m\"===r&&(!function(t){for(;o<t.minMonth;)a--,o+=t.monthsInYear(a);for(var e=t.monthsInYear(a);o>e-1+t.minMonth;)a++,o-=e,e=t.monthsInYear(a)}(this),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o))));var s=[a,this.fromMonthOfYear(a,o),i];return this._validateLevel--,s}catch(t){throw this._validateLevel--,t}},_correctAdd:function(t,e,r,n){if(!(this.hasYearZero||\"y\"!==n&&\"m\"!==n||0!==e[0]&&t.year()>0==e[0]>0)){var i={y:[1,1,\"y\"],m:[1,this.monthsInYear(-1),\"m\"],w:[this.daysInWeek(),this.daysInYear(-1),\"d\"],d:[1,this.daysInYear(-1),\"d\"]}[n],a=r<0?-1:1;e=this._add(t,r*i[0]+a*i[1],i[2])}return t.date(e[0],e[1],e[2])},set:function(t,e,r){this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);var n=\"y\"===r?e:t.year(),i=\"m\"===r?e:t.month(),a=\"d\"===r?e:t.day();return\"y\"!==r&&\"m\"!==r||(a=Math.min(a,this.daysInMonth(n,i))),t.date(n,i,a)},isValid:function(t,e,r){this._validateLevel++;var n=this.hasYearZero||0!==t;if(n){var i=this.newDate(t,e,this.minDay);n=e>=this.minMonth&&e-this.minMonth<this.monthsInYear(i)&&r>=this.minDay&&r-this.minDay<this.daysInMonth(i)}return this._validateLevel--,n},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return c.instance().fromJD(this.toJD(n)).toJSDate()},fromJSDate:function(t){return this.fromJD(c.instance().fromJSDate(t).toJD())},_validate:function(t,e,r,n){if(t.year){if(0===this._validateLevel&&this.name!==t.calendar().name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this.local.name).replace(/\\{1\\}/,t.calendar().local.name);return t}try{if(this._validateLevel++,1===this._validateLevel&&!this.isValid(t,e,r))throw n.replace(/\\{0\\}/,this.local.name);var i=this.newDate(t,e,r);return this._validateLevel--,i}catch(t){throw this._validateLevel--,t}}}),l.prototype=new s,n(l.prototype,{name:\"Gregorian\",jdEpoch:1721425.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Gregorian\",epochs:[\"BCE\",\"CE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==0&&(t%100!=0||t%400==0)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);t=n.year(),e=n.month(),r=n.day(),t<0&&t++,e<3&&(e+=12,t--);var i=Math.floor(t/100),a=2-i+Math.floor(i/4);return Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r+a-1524.5},fromJD:function(t){var e=Math.floor(t+.5),r=Math.floor((e-1867216.25)/36524.25),n=(r=e+1+r-Math.floor(r/4))+1524,i=Math.floor((n-122.1)/365.25),a=Math.floor(365.25*i),o=Math.floor((n-a)/30.6001),s=n-a-Math.floor(30.6001*o),l=o-(o>13.5?13:1),c=i-(l>2.5?4716:4715);return c<=0&&c--,this.newDate(c,l,s)},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),i=new Date(n.year(),n.month()-1,n.day());return i.setHours(0),i.setMinutes(0),i.setSeconds(0),i.setMilliseconds(0),i.setHours(i.getHours()>12?i.getHours()+2:0),i},fromJSDate:function(t){return this.newDate(t.getFullYear(),t.getMonth()+1,t.getDate())}});var c=e.exports=new i;c.cdate=a,c.baseCalendar=s,c.calendars.gregorian=l},{\"object-assign\":454}],572:[function(t,e,r){var n=t(\"object-assign\"),i=t(\"./main\");n(i.regionalOptions[\"\"],{invalidArguments:\"Invalid arguments\",invalidFormat:\"Cannot format a date from another calendar\",missingNumberAt:\"Missing number at position {0}\",unknownNameAt:\"Unknown name at position {0}\",unexpectedLiteralAt:\"Unexpected literal at position {0}\",unexpectedText:\"Additional text found at end\"}),i.local=i.regionalOptions[\"\"],n(i.cdate.prototype,{formatDate:function(t,e){return\"string\"!=typeof t&&(e=t,t=\"\"),this._calendar.formatDate(t||\"\",this,e)}}),n(i.baseCalendar.prototype,{UNIX_EPOCH:i.instance().newDate(1970,1,1).toJD(),SECS_PER_DAY:86400,TICKS_EPOCH:i.instance().jdEpoch,TICKS_PER_DAY:864e9,ATOM:\"yyyy-mm-dd\",COOKIE:\"D, dd M yyyy\",FULL:\"DD, MM d, yyyy\",ISO_8601:\"yyyy-mm-dd\",JULIAN:\"J\",RFC_822:\"D, d M yy\",RFC_850:\"DD, dd-M-yy\",RFC_1036:\"D, d M yy\",RFC_1123:\"D, d M yyyy\",RFC_2822:\"D, d M yyyy\",RSS:\"D, d M yy\",TICKS:\"!\",TIMESTAMP:\"@\",W3C:\"yyyy-mm-dd\",formatDate:function(t,e,r){if(\"string\"!=typeof t&&(r=e,e=t,t=\"\"),!e)return\"\";if(e.calendar()!==this)throw i.local.invalidFormat||i.regionalOptions[\"\"].invalidFormat;t=t||this.local.dateFormat;for(var n,a,o,s,l=(r=r||{}).dayNamesShort||this.local.dayNamesShort,c=r.dayNames||this.local.dayNames,u=r.monthNumbers||this.local.monthNumbers,h=r.monthNamesShort||this.local.monthNamesShort,f=r.monthNames||this.local.monthNames,p=(r.calculateWeek||this.local.calculateWeek,function(e,r){for(var n=1;w+n<t.length&&t.charAt(w+n)===e;)n++;return w+=n-1,Math.floor(n/(r||1))>1}),d=function(t,e,r,n){var i=\"\"+e;if(p(t,n))for(;i.length<r;)i=\"0\"+i;return i},g=this,v=function(t){return\"function\"==typeof u?u.call(g,t,p(\"m\")):x(d(\"m\",t.month(),2))},m=function(t,e){return e?\"function\"==typeof f?f.call(g,t):f[t.month()-g.minMonth]:\"function\"==typeof h?h.call(g,t):h[t.month()-g.minMonth]},y=this.local.digits,x=function(t){return r.localNumbers&&y?y(t):t},b=\"\",_=!1,w=0;w<t.length;w++)if(_)\"'\"!==t.charAt(w)||p(\"'\")?b+=t.charAt(w):_=!1;else switch(t.charAt(w)){case\"d\":b+=x(d(\"d\",e.day(),2));break;case\"D\":b+=(n=\"D\",a=e.dayOfWeek(),o=l,s=c,p(n)?s[a]:o[a]);break;case\"o\":b+=d(\"o\",e.dayOfYear(),3);break;case\"w\":b+=d(\"w\",e.weekOfYear(),2);break;case\"m\":b+=v(e);break;case\"M\":b+=m(e,p(\"M\"));break;case\"y\":b+=p(\"y\",2)?e.year():(e.year()%100<10?\"0\":\"\")+e.year()%100;break;case\"Y\":p(\"Y\",2),b+=e.formatYear();break;case\"J\":b+=e.toJD();break;case\"@\":b+=(e.toJD()-this.UNIX_EPOCH)*this.SECS_PER_DAY;break;case\"!\":b+=(e.toJD()-this.TICKS_EPOCH)*this.TICKS_PER_DAY;break;case\"'\":p(\"'\")?b+=\"'\":_=!0;break;default:b+=t.charAt(w)}return b},parseDate:function(t,e,r){if(null==e)throw i.local.invalidArguments||i.regionalOptions[\"\"].invalidArguments;if(\"\"===(e=\"object\"==typeof e?e.toString():e+\"\"))return null;t=t||this.local.dateFormat;var n=(r=r||{}).shortYearCutoff||this.shortYearCutoff;n=\"string\"!=typeof n?n:this.today().year()%100+parseInt(n,10);for(var a=r.dayNamesShort||this.local.dayNamesShort,o=r.dayNames||this.local.dayNames,s=r.parseMonth||this.local.parseMonth,l=r.monthNumbers||this.local.monthNumbers,c=r.monthNamesShort||this.local.monthNamesShort,u=r.monthNames||this.local.monthNames,h=-1,f=-1,p=-1,d=-1,g=-1,v=!1,m=!1,y=function(e,r){for(var n=1;M+n<t.length&&t.charAt(M+n)===e;)n++;return M+=n-1,Math.floor(n/(r||1))>1},x=function(t,r){var n=y(t,r),a=[2,3,n?4:2,n?4:2,10,11,20][\"oyYJ@!\".indexOf(t)+1],o=new RegExp(\"^-?\\\\d{1,\"+a+\"}\"),s=e.substring(A).match(o);if(!s)throw(i.local.missingNumberAt||i.regionalOptions[\"\"].missingNumberAt).replace(/\\{0\\}/,A);return A+=s[0].length,parseInt(s[0],10)},b=this,_=function(){if(\"function\"==typeof l){y(\"m\");var t=l.call(b,e.substring(A));return A+=t.length,t}return x(\"m\")},w=function(t,r,n,a){for(var o=y(t,a)?n:r,s=0;s<o.length;s++)if(e.substr(A,o[s].length).toLowerCase()===o[s].toLowerCase())return A+=o[s].length,s+b.minMonth;throw(i.local.unknownNameAt||i.regionalOptions[\"\"].unknownNameAt).replace(/\\{0\\}/,A)},k=function(){if(\"function\"==typeof u){var t=y(\"M\")?u.call(b,e.substring(A)):c.call(b,e.substring(A));return A+=t.length,t}return w(\"M\",c,u)},T=function(){if(e.charAt(A)!==t.charAt(M))throw(i.local.unexpectedLiteralAt||i.regionalOptions[\"\"].unexpectedLiteralAt).replace(/\\{0\\}/,A);A++},A=0,M=0;M<t.length;M++)if(m)\"'\"!==t.charAt(M)||y(\"'\")?T():m=!1;else switch(t.charAt(M)){case\"d\":d=x(\"d\");break;case\"D\":w(\"D\",a,o);break;case\"o\":g=x(\"o\");break;case\"w\":x(\"w\");break;case\"m\":p=_();break;case\"M\":p=k();break;case\"y\":var S=M;v=!y(\"y\",2),M=S,f=x(\"y\",2);break;case\"Y\":f=x(\"Y\",2);break;case\"J\":h=x(\"J\")+.5,\".\"===e.charAt(A)&&(A++,x(\"J\"));break;case\"@\":h=x(\"@\")/this.SECS_PER_DAY+this.UNIX_EPOCH;break;case\"!\":h=x(\"!\")/this.TICKS_PER_DAY+this.TICKS_EPOCH;break;case\"*\":A=e.length;break;case\"'\":y(\"'\")?T():m=!0;break;default:T()}if(A<e.length)throw i.local.unexpectedText||i.regionalOptions[\"\"].unexpectedText;if(-1===f?f=this.today().year():f<100&&v&&(f+=-1===n?1900:this.today().year()-this.today().year()%100-(f<=n?0:100)),\"string\"==typeof p&&(p=s.call(this,f,p)),g>-1){p=1,d=g;for(var E=this.daysInMonth(f,p);d>E;E=this.daysInMonth(f,p))p++,d-=E}return h>-1?this.fromJD(h):this.newDate(f,p,d)},determineDate:function(t,e,r,n,i){r&&\"object\"!=typeof r&&(i=n,n=r,r=null),\"string\"!=typeof n&&(i=n,n=\"\");var a=this;return e=e?e.newDate():null,t=null==t?e:\"string\"==typeof t?function(t){try{return a.parseDate(n,t,i)}catch(t){}for(var e=((t=t.toLowerCase()).match(/^c/)&&r?r.newDate():null)||a.today(),o=/([+-]?[0-9]+)\\s*(d|w|m|y)?/g,s=o.exec(t);s;)e.add(parseInt(s[1],10),s[2]||\"d\"),s=o.exec(t);return e}(t):\"number\"==typeof t?isNaN(t)||t===1/0||t===-1/0?e:a.today().add(t,\"d\"):a.newDate(t)}})},{\"./main\":571,\"object-assign\":454}],573:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",{offset:[1],array:0},\"scalar\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\n        var _inline_1_da = _inline_1_arg0_ - _inline_1_arg3_\\n        var _inline_1_db = _inline_1_arg1_ - _inline_1_arg3_\\n        if((_inline_1_da >= 0) !== (_inline_1_db >= 0)) {\\n          _inline_1_arg2_.push(_inline_1_arg4_[0] + 0.5 + 0.5 * (_inline_1_da + _inline_1_db) / (_inline_1_da - _inline_1_db))\\n        }\\n      }\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg3_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[\"_inline_1_da\",\"_inline_1_db\"]},funcName:\"zeroCrossings\"})},{\"cwise-compiler\":146}],574:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=[];return e=+e||0,n(t.hi(t.shape[0]-1),r,e),r};var n=t(\"./lib/zc-core\")},{\"./lib/zc-core\":573}],575:[function(t,e,r){\"use strict\";e.exports=[{path:\"\",backoff:0},{path:\"M-2.4,-3V3L0.6,0Z\",backoff:.6},{path:\"M-3.7,-2.5V2.5L1.3,0Z\",backoff:1.3},{path:\"M-4.45,-3L-1.65,-0.2V0.2L-4.45,3L1.55,0Z\",backoff:1.55},{path:\"M-2.2,-2.2L-0.2,-0.2V0.2L-2.2,2.2L-1.4,3L1.6,0L-1.4,-3Z\",backoff:1.6},{path:\"M-4.4,-2.1L-0.6,-0.2V0.2L-4.4,2.1L-4,3L2,0L-4,-3Z\",backoff:2},{path:\"M2,0A2,2 0 1,1 0,-2A2,2 0 0,1 2,0Z\",backoff:0,noRotate:!0},{path:\"M2,2V-2H-2V2Z\",backoff:0,noRotate:!0}]},{}],576:[function(t,e,r){\"use strict\";var n=t(\"./arrow_paths\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../plots/cartesian/constants\"),o=t(\"../../plot_api/plot_template\").templatedArray;e.exports=o(\"annotation\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},text:{valType:\"string\",editType:\"calc+arraydraw\"},textangle:{valType:\"angle\",dflt:0,editType:\"calc+arraydraw\"},font:i({editType:\"calc+arraydraw\",colorEditType:\"arraydraw\"}),width:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},height:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"center\",editType:\"arraydraw\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"arraydraw\"},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},borderpad:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},showarrow:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},arrowcolor:{valType:\"color\",editType:\"arraydraw\"},arrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},startarrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},arrowside:{valType:\"flaglist\",flags:[\"end\",\"start\"],extras:[\"none\"],dflt:\"end\",editType:\"arraydraw\"},arrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},startarrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},arrowwidth:{valType:\"number\",min:.1,editType:\"calc+arraydraw\"},standoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},startstandoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},ax:{valType:\"any\",editType:\"calc+arraydraw\"},ay:{valType:\"any\",editType:\"calc+arraydraw\"},axref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.x.toString()],editType:\"calc\"},ayref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.y.toString()],editType:\"calc\"},xref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.x.toString()],editType:\"calc\"},x:{valType:\"any\",editType:\"calc+arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"auto\",editType:\"calc+arraydraw\"},xshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.y.toString()],editType:\"calc\"},y:{valType:\"any\",editType:\"calc+arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"calc+arraydraw\"},yshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},clicktoshow:{valType:\"enumerated\",values:[!1,\"onoff\",\"onout\"],dflt:!1,editType:\"arraydraw\"},xclick:{valType:\"any\",editType:\"arraydraw\"},yclick:{valType:\"any\",editType:\"arraydraw\"},hovertext:{valType:\"string\",editType:\"arraydraw\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",editType:\"arraydraw\"},font:i({editType:\"arraydraw\"}),editType:\"arraydraw\"},captureevents:{valType:\"boolean\",editType:\"arraydraw\"},editType:\"calc\",_deprecated:{ref:{valType:\"string\",editType:\"calc\"}}})},{\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773,\"../../plots/font_attributes\":793,\"./arrow_paths\":575}],577:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./draw\").draw;function o(t){var e=t._fullLayout;n.filterVisible(e.annotations).forEach(function(e){var r=i.getFromId(t,e.xref),n=i.getFromId(t,e.yref);e._extremes={},r&&s(e,r),n&&s(e,n)})}function s(t,e){var r,n=e._id,a=n.charAt(0),o=t[a],s=t[\"a\"+a],l=t[a+\"ref\"],c=t[\"a\"+a+\"ref\"],u=t[\"_\"+a+\"padplus\"],h=t[\"_\"+a+\"padminus\"],f={x:1,y:-1}[a]*t[a+\"shift\"],p=3*t.arrowsize*t.arrowwidth||0,d=p+f,g=p-f,v=3*t.startarrowsize*t.arrowwidth||0,m=v+f,y=v-f;if(c===l){var x=i.findExtremes(e,[e.r2c(o)],{ppadplus:d,ppadminus:g}),b=i.findExtremes(e,[e.r2c(s)],{ppadplus:Math.max(u,m),ppadminus:Math.max(h,y)});r={min:[x.min[0],b.min[0]],max:[x.max[0],b.max[0]]}}else m=s?m+s:m,y=s?y-s:y,r=i.findExtremes(e,[e.r2c(o)],{ppadplus:Math.max(u,d,m),ppadminus:Math.max(h,g,y)});t._extremes[n]=r}e.exports=function(t){var e=t._fullLayout;if(n.filterVisible(e.annotations).length&&t._fullData.length)return n.syncOrAsync([a,o],t)}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./draw\":582}],578:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../plot_api/plot_template\").arrayEditor;function o(t,e){var r,n,i,a,o,l,c,u=t._fullLayout.annotations,h=[],f=[],p=[],d=(e||[]).length;for(r=0;r<u.length;r++)if(a=(i=u[r]).clicktoshow){for(n=0;n<d;n++)if(l=(o=e[n]).xaxis,c=o.yaxis,l._id===i.xref&&c._id===i.yref&&l.d2r(o.x)===s(i._xclick,l)&&c.d2r(o.y)===s(i._yclick,c)){(i.visible?\"onout\"===a?f:p:h).push(r);break}n===d&&i.visible&&\"onout\"===a&&f.push(r)}return{on:h,off:f,explicitOff:p}}function s(t,e){return\"log\"===e.type?e.l2r(t):e.d2r(t)}e.exports={hasClickToShow:function(t,e){var r=o(t,e);return r.on.length>0||r.explicitOff.length>0},onClick:function(t,e){var r,s,l=o(t,e),c=l.on,u=l.off.concat(l.explicitOff),h={},f=t._fullLayout.annotations;if(!c.length&&!u.length)return;for(r=0;r<c.length;r++)(s=a(t.layout,\"annotations\",f[c[r]])).modifyItem(\"visible\",!0),n.extendFlat(h,s.getUpdateObj());for(r=0;r<u.length;r++)(s=a(t.layout,\"annotations\",f[u[r]])).modifyItem(\"visible\",!1),n.extendFlat(h,s.getUpdateObj());return i.call(\"update\",t,{},h)}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../registry\":847}],579:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\");e.exports=function(t,e,r,a){a(\"opacity\");var o=a(\"bgcolor\"),s=a(\"bordercolor\"),l=i.opacity(s);a(\"borderpad\");var c=a(\"borderwidth\"),u=a(\"showarrow\");if(a(\"text\",u?\" \":r._dfltTitle.annotation),a(\"textangle\"),n.coerceFont(a,\"font\",r.font),a(\"width\"),a(\"align\"),a(\"height\")&&a(\"valign\"),u){var h,f,p=a(\"arrowside\");-1!==p.indexOf(\"end\")&&(h=a(\"arrowhead\"),f=a(\"arrowsize\")),-1!==p.indexOf(\"start\")&&(a(\"startarrowhead\",h),a(\"startarrowsize\",f)),a(\"arrowcolor\",l?e.bordercolor:i.defaultLine),a(\"arrowwidth\",2*(l&&c||1)),a(\"standoff\"),a(\"startstandoff\")}var d=a(\"hovertext\"),g=r.hoverlabel||{};if(d){var v=a(\"hoverlabel.bgcolor\",g.bgcolor||(i.opacity(o)?i.rgb(o):i.defaultLine)),m=a(\"hoverlabel.bordercolor\",g.bordercolor||i.contrast(v));n.coerceFont(a,\"hoverlabel.font\",{family:g.font.family,size:g.font.size,color:g.font.color||m})}a(\"captureevents\",!!d)}},{\"../../lib\":719,\"../color\":593}],580:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.annotations,h=e._id.charAt(0),f=0;f<u.length;f++)l=u[f],c=\"annotations[\"+f+\"].\",l[h+\"ref\"]===e._id&&p(h),l[\"a\"+h+\"ref\"]===e._id&&p(\"a\"+h);function p(t){var r=l[t],s=null;s=o?i(r,e.range):Math.pow(10,r),n(s)||(s=null),a(c+t,s)}}},{\"../../lib/to_log_range\":745,\"fast-isnumeric\":225}],581:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./common_defaults\"),s=t(\"./attributes\");function l(t,e,r){function a(r,i){return n.coerce(t,e,s,r,i)}var l=a(\"visible\"),c=a(\"clicktoshow\");if(l||c){o(t,e,r,a);for(var u=e.showarrow,h=[\"x\",\"y\"],f=[-10,-30],p={_fullLayout:r},d=0;d<2;d++){var g=h[d],v=i.coerceRef(t,e,p,g,\"\",\"paper\");if(\"paper\"!==v)i.getFromId(p,v)._annIndices.push(e._index);if(i.coercePosition(e,p,a,v,g,.5),u){var m=\"a\"+g,y=i.coerceRef(t,e,p,m,\"pixel\");\"pixel\"!==y&&y!==v&&(y=e[m]=\"pixel\");var x=\"pixel\"===y?f[d]:.4;i.coercePosition(e,p,a,y,m,x)}a(g+\"anchor\"),a(g+\"shift\")}if(n.noneOrAll(t,e,[\"x\",\"y\"]),u&&n.noneOrAll(t,e,[\"ax\",\"ay\"]),c){var b=a(\"xclick\"),_=a(\"yclick\");e._xclick=void 0===b?e.x:i.cleanPosition(b,p,e.xref),e._yclick=void 0===_?e.y:i.cleanPosition(_,p,e.yref)}}}e.exports=function(t,e){a(t,e,{name:\"annotations\",handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"./attributes\":576,\"./common_defaults\":579}],582:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../color\"),c=t(\"../drawing\"),u=t(\"../fx\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"../../lib/setcursor\"),p=t(\"../dragelement\"),d=t(\"../../plot_api/plot_template\").arrayEditor,g=t(\"./draw_arrow_head\");function v(t,e){var r=t._fullLayout.annotations[e]||{},n=s.getFromId(t,r.xref),i=s.getFromId(t,r.yref);n&&n.setScale(),i&&i.setScale(),m(t,r,e,!1,n,i)}function m(t,e,r,a,s,v){var m,y,x=t._fullLayout,b=t._fullLayout._size,_=t._context.edits;a?(m=\"annotation-\"+a,y=a+\".annotations\"):(m=\"annotation\",y=\"annotations\");var w=d(t.layout,y,e),k=w.modifyBase,T=w.modifyItem,A=w.getUpdateObj;x._infolayer.selectAll(\".\"+m+'[data-index=\"'+r+'\"]').remove();var M=\"clip\"+x._uid+\"_ann\"+r;if(e._input&&!1!==e.visible){var S={x:{},y:{}},E=+e.textangle||0,C=x._infolayer.append(\"g\").classed(m,!0).attr(\"data-index\",String(r)).style(\"opacity\",e.opacity),L=C.append(\"g\").classed(\"annotation-text-g\",!0),P=_[e.showarrow?\"annotationTail\":\"annotationPosition\"],O=e.captureevents||_.annotationText||P,z=L.append(\"g\").style(\"pointer-events\",O?\"all\":null).call(f,\"pointer\").on(\"click\",function(){t._dragging=!1,t.emit(\"plotly_clickannotation\",q(n.event))});e.hovertext&&z.on(\"mouseover\",function(){var r=e.hoverlabel,n=r.font,i=this.getBoundingClientRect(),a=t.getBoundingClientRect();u.loneHover({x0:i.left-a.left,x1:i.right-a.left,y:(i.top+i.bottom)/2-a.top,text:e.hovertext,color:r.bgcolor,borderColor:r.bordercolor,fontFamily:n.family,fontSize:n.size,fontColor:n.color},{container:x._hoverlayer.node(),outerContainer:x._paper.node(),gd:t})}).on(\"mouseout\",function(){u.loneUnhover(x._hoverlayer.node())});var I=e.borderwidth,D=e.borderpad,R=I+D,F=z.append(\"rect\").attr(\"class\",\"bg\").style(\"stroke-width\",I+\"px\").call(l.stroke,e.bordercolor).call(l.fill,e.bgcolor),B=e.width||e.height,N=x._topclips.selectAll(\"#\"+M).data(B?[0]:[]);N.enter().append(\"clipPath\").classed(\"annclip\",!0).attr(\"id\",M).append(\"rect\"),N.exit().remove();var j=e.font,U=x._meta?o.templateString(e.text,x._meta):e.text,V=z.append(\"text\").classed(\"annotation-text\",!0).text(U);_.annotationText?V.call(h.makeEditable,{delegate:z,gd:t}).call(H).on(\"edit\",function(r){e.text=r,this.call(H),T(\"text\",r),s&&s.autorange&&k(s._name+\".autorange\",!0),v&&v.autorange&&k(v._name+\".autorange\",!0),i.call(\"_guiRelayout\",t,A())}):V.call(H)}else n.selectAll(\"#\"+M).remove();function q(t){var n={index:r,annotation:e._input,fullAnnotation:e,event:t};return a&&(n.subplotId=a),n}function H(r){return r.call(c.font,j).attr({\"text-anchor\":{left:\"start\",right:\"end\"}[e.align]||\"middle\"}),h.convertToTspans(r,t,G),r}function G(){var r=V.selectAll(\"a\");1===r.size()&&r.text()===V.text()&&z.insert(\"a\",\":first-child\").attr({\"xlink:xlink:href\":r.attr(\"xlink:href\"),\"xlink:xlink:show\":r.attr(\"xlink:show\")}).style({cursor:\"pointer\"}).node().appendChild(F.node());var n=z.select(\".annotation-text-math-group\"),u=!n.empty(),d=c.bBox((u?n:V).node()),m=d.width,y=d.height,w=e.width||m,O=e.height||y,D=Math.round(w+2*R),j=Math.round(O+2*R);function U(t,e){return\"auto\"===e&&(e=t<1/3?\"left\":t>2/3?\"right\":\"center\"),{center:0,middle:0,left:.5,bottom:-.5,right:-.5,top:.5}[e]}for(var H=!1,G=[\"x\",\"y\"],Y=0;Y<G.length;Y++){var W,X,Z,J,K,$=G[Y],Q=e[$+\"ref\"]||$,tt=e[\"a\"+$+\"ref\"],et={x:s,y:v}[$],rt=(E+(\"x\"===$?0:-90))*Math.PI/180,nt=D*Math.cos(rt),it=j*Math.sin(rt),at=Math.abs(nt)+Math.abs(it),ot=e[$+\"anchor\"],st=e[$+\"shift\"]*(\"x\"===$?1:-1),lt=S[$];if(et){var ct=et.r2fraction(e[$]);(ct<0||ct>1)&&(tt===Q?((ct=et.r2fraction(e[\"a\"+$]))<0||ct>1)&&(H=!0):H=!0),W=et._offset+et.r2p(e[$]),J=.5}else\"x\"===$?(Z=e[$],W=b.l+b.w*Z):(Z=1-e[$],W=b.t+b.h*Z),J=e.showarrow?.5:Z;if(e.showarrow){lt.head=W;var ut=e[\"a\"+$];K=nt*U(.5,e.xanchor)-it*U(.5,e.yanchor),tt===Q?(lt.tail=et._offset+et.r2p(ut),X=K):(lt.tail=W+ut,X=K+ut),lt.text=lt.tail+K;var ht=x[\"x\"===$?\"width\":\"height\"];if(\"paper\"===Q&&(lt.head=o.constrain(lt.head,1,ht-1)),\"pixel\"===tt){var ft=-Math.max(lt.tail-3,lt.text),pt=Math.min(lt.tail+3,lt.text)-ht;ft>0?(lt.tail+=ft,lt.text+=ft):pt>0&&(lt.tail-=pt,lt.text-=pt)}lt.tail+=st,lt.head+=st}else X=K=at*U(J,ot),lt.text=W+K;lt.text+=st,K+=st,X+=st,e[\"_\"+$+\"padplus\"]=at/2+X,e[\"_\"+$+\"padminus\"]=at/2-X,e[\"_\"+$+\"size\"]=at,e[\"_\"+$+\"shift\"]=K}if(t._dragging||!H){var dt=0,gt=0;if(\"left\"!==e.align&&(dt=(w-m)*(\"center\"===e.align?.5:1)),\"top\"!==e.valign&&(gt=(O-y)*(\"middle\"===e.valign?.5:1)),u)n.select(\"svg\").attr({x:R+dt-1,y:R+gt}).call(c.setClipUrl,B?M:null,t);else{var vt=R+gt-d.top,mt=R+dt-d.left;V.call(h.positionText,mt,vt).call(c.setClipUrl,B?M:null,t)}N.select(\"rect\").call(c.setRect,R,R,w,O),F.call(c.setRect,I/2,I/2,D-I,j-I),z.call(c.setTranslate,Math.round(S.x.text-D/2),Math.round(S.y.text-j/2)),L.attr({transform:\"rotate(\"+E+\",\"+S.x.text+\",\"+S.y.text+\")\"});var yt,xt=function(r,n){C.selectAll(\".annotation-arrow-g\").remove();var u=S.x.head,h=S.y.head,f=S.x.tail+r,d=S.y.tail+n,m=S.x.text+r,y=S.y.text+n,x=o.rotationXYMatrix(E,m,y),w=o.apply2DTransform(x),M=o.apply2DTransform2(x),P=+F.attr(\"width\"),O=+F.attr(\"height\"),I=m-.5*P,D=I+P,R=y-.5*O,B=R+O,N=[[I,R,I,B],[I,B,D,B],[D,B,D,R],[D,R,I,R]].map(M);if(!N.reduce(function(t,e){return t^!!o.segmentsIntersect(u,h,u+1e6,h+1e6,e[0],e[1],e[2],e[3])},!1)){N.forEach(function(t){var e=o.segmentsIntersect(f,d,u,h,t[0],t[1],t[2],t[3]);e&&(f=e.x,d=e.y)});var j=e.arrowwidth,U=e.arrowcolor,V=e.arrowside,q=C.append(\"g\").style({opacity:l.opacity(U)}).classed(\"annotation-arrow-g\",!0),H=q.append(\"path\").attr(\"d\",\"M\"+f+\",\"+d+\"L\"+u+\",\"+h).style(\"stroke-width\",j+\"px\").call(l.stroke,l.rgb(U));if(g(H,V,e),_.annotationPosition&&H.node().parentNode&&!a){var G=u,Y=h;if(e.standoff){var W=Math.sqrt(Math.pow(u-f,2)+Math.pow(h-d,2));G+=e.standoff*(f-u)/W,Y+=e.standoff*(d-h)/W}var X,Z,J=q.append(\"path\").classed(\"annotation-arrow\",!0).classed(\"anndrag\",!0).classed(\"cursor-move\",!0).attr({d:\"M3,3H-3V-3H3ZM0,0L\"+(f-G)+\",\"+(d-Y),transform:\"translate(\"+G+\",\"+Y+\")\"}).style(\"stroke-width\",j+6+\"px\").call(l.stroke,\"rgba(0,0,0,0)\").call(l.fill,\"rgba(0,0,0,0)\");p.init({element:J.node(),gd:t,prepFn:function(){var t=c.getTranslate(z);X=t.x,Z=t.y,s&&s.autorange&&k(s._name+\".autorange\",!0),v&&v.autorange&&k(v._name+\".autorange\",!0)},moveFn:function(t,r){var n=w(X,Z),i=n[0]+t,a=n[1]+r;z.call(c.setTranslate,i,a),T(\"x\",s?s.p2r(s.r2p(e.x)+t):e.x+t/b.w),T(\"y\",v?v.p2r(v.r2p(e.y)+r):e.y-r/b.h),e.axref===e.xref&&T(\"ax\",s.p2r(s.r2p(e.ax)+t)),e.ayref===e.yref&&T(\"ay\",v.p2r(v.r2p(e.ay)+r)),q.attr(\"transform\",\"translate(\"+t+\",\"+r+\")\"),L.attr({transform:\"rotate(\"+E+\",\"+i+\",\"+a+\")\"})},doneFn:function(){i.call(\"_guiRelayout\",t,A());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}}};if(e.showarrow&&xt(0,0),P)p.init({element:z.node(),gd:t,prepFn:function(){yt=L.attr(\"transform\")},moveFn:function(t,r){var n=\"pointer\";if(e.showarrow)e.axref===e.xref?T(\"ax\",s.p2r(s.r2p(e.ax)+t)):T(\"ax\",e.ax+t),e.ayref===e.yref?T(\"ay\",v.p2r(v.r2p(e.ay)+r)):T(\"ay\",e.ay+r),xt(t,r);else{if(a)return;var i,o;if(s)i=s.p2r(s.r2p(e.x)+t);else{var l=e._xsize/b.w,c=e.x+(e._xshift-e.xshift)/b.w-l/2;i=p.align(c+t/b.w,l,0,1,e.xanchor)}if(v)o=v.p2r(v.r2p(e.y)+r);else{var u=e._ysize/b.h,h=e.y-(e._yshift+e.yshift)/b.h-u/2;o=p.align(h-r/b.h,u,0,1,e.yanchor)}T(\"x\",i),T(\"y\",o),s&&v||(n=p.getCursor(s?.5:i,v?.5:o,e.xanchor,e.yanchor))}L.attr({transform:\"translate(\"+t+\",\"+r+\")\"+yt}),f(z,n)},clickFn:function(r,n){e.captureevents&&t.emit(\"plotly_clickannotation\",q(n))},doneFn:function(){f(z),i.call(\"_guiRelayout\",t,A());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}else z.remove()}}e.exports={draw:function(t){var e=t._fullLayout;e._infolayer.selectAll(\".annotation\").remove();for(var r=0;r<e.annotations.length;r++)e.annotations[r].visible&&v(t,r);return a.previousPromises(t)},drawOne:v,drawRaw:m}},{\"../../lib\":719,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/axes\":767,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"../fx\":632,\"./draw_arrow_head\":583,d3:163}],583:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\"),a=t(\"./arrow_paths\");e.exports=function(t,e,r){var o,s,l,c,u=t.node(),h=a[r.arrowhead||0],f=a[r.startarrowhead||0],p=(r.arrowwidth||1)*(r.arrowsize||1),d=(r.arrowwidth||1)*(r.startarrowsize||1),g=e.indexOf(\"start\")>=0,v=e.indexOf(\"end\")>=0,m=h.backoff*p+r.standoff,y=f.backoff*d+r.startstandoff;if(\"line\"===u.nodeName){o={x:+t.attr(\"x1\"),y:+t.attr(\"y1\")},s={x:+t.attr(\"x2\"),y:+t.attr(\"y2\")};var x=o.x-s.x,b=o.y-s.y;if(c=(l=Math.atan2(b,x))+Math.PI,m&&y&&m+y>Math.sqrt(x*x+b*b))return void P();if(m){if(m*m>x*x+b*b)return void P();var _=m*Math.cos(l),w=m*Math.sin(l);s.x+=_,s.y+=w,t.attr({x2:s.x,y2:s.y})}if(y){if(y*y>x*x+b*b)return void P();var k=y*Math.cos(l),T=y*Math.sin(l);o.x-=k,o.y-=T,t.attr({x1:o.x,y1:o.y})}}else if(\"path\"===u.nodeName){var A=u.getTotalLength(),M=\"\";if(A<m+y)return void P();var S=u.getPointAtLength(0),E=u.getPointAtLength(.1);l=Math.atan2(S.y-E.y,S.x-E.x),o=u.getPointAtLength(Math.min(y,A)),M=\"0px,\"+y+\"px,\";var C=u.getPointAtLength(A),L=u.getPointAtLength(A-.1);c=Math.atan2(C.y-L.y,C.x-L.x),s=u.getPointAtLength(Math.max(0,A-m)),M+=A-(M?y+m:m)+\"px,\"+A+\"px\",t.style(\"stroke-dasharray\",M)}function P(){t.style(\"stroke-dasharray\",\"0px,100px\")}function O(e,a,o,s){e.path&&(e.noRotate&&(o=0),n.select(u.parentNode).append(\"path\").attr({class:t.attr(\"class\"),d:e.path,transform:\"translate(\"+a.x+\",\"+a.y+\")\"+(o?\"rotate(\"+180*o/Math.PI+\")\":\"\")+\"scale(\"+s+\")\"}).style({fill:i.rgb(r.arrowcolor),\"stroke-width\":0}))}g&&O(f,o,l,d),v&&O(h,s,c,p)}},{\"../color\":593,\"./arrow_paths\":575,d3:163}],584:[function(t,e,r){\"use strict\";var n=t(\"./draw\"),i=t(\"./click\");e.exports={moduleType:\"component\",name:\"annotations\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"annotations\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne,drawRaw:n.drawRaw,hasClickToShow:i.hasClickToShow,onClick:i.onClick,convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":777,\"./attributes\":576,\"./calc_autorange\":577,\"./click\":578,\"./convert_coords\":580,\"./defaults\":581,\"./draw\":582}],585:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"../../plot_api/plot_template\").templatedArray;e.exports=i(a(\"annotation\",{visible:n.visible,x:{valType:\"any\"},y:{valType:\"any\"},z:{valType:\"any\"},ax:{valType:\"number\"},ay:{valType:\"number\"},xanchor:n.xanchor,xshift:n.xshift,yanchor:n.yanchor,yshift:n.yshift,text:n.text,textangle:n.textangle,font:n.font,width:n.width,height:n.height,opacity:n.opacity,align:n.align,valign:n.valign,bgcolor:n.bgcolor,bordercolor:n.bordercolor,borderpad:n.borderpad,borderwidth:n.borderwidth,showarrow:n.showarrow,arrowcolor:n.arrowcolor,arrowhead:n.arrowhead,startarrowhead:n.startarrowhead,arrowside:n.arrowside,arrowsize:n.arrowsize,startarrowsize:n.startarrowsize,arrowwidth:n.arrowwidth,standoff:n.standoff,startstandoff:n.startstandoff,hovertext:n.hovertext,hoverlabel:n.hoverlabel,captureevents:n.captureevents}),\"calc\",\"from-root\")},{\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../annotations/attributes\":576}],586:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\");function a(t,e){var r=e.fullSceneLayout.domain,a=e.fullLayout._size,o={pdata:null,type:\"linear\",autorange:!1,range:[-1/0,1/0]};t._xa={},n.extendFlat(t._xa,o),i.setConvert(t._xa),t._xa._offset=a.l+r.x[0]*a.w,t._xa.l2p=function(){return.5*(1+t._pdata[0]/t._pdata[3])*a.w*(r.x[1]-r.x[0])},t._ya={},n.extendFlat(t._ya,o),i.setConvert(t._ya),t._ya._offset=a.t+(1-r.y[1])*a.h,t._ya.l2p=function(){return.5*(1-t._pdata[1]/t._pdata[3])*a.h*(r.y[1]-r.y[0])}}e.exports=function(t){for(var e=t.fullSceneLayout.annotations,r=0;r<e.length;r++)a(e[r],t);t.fullLayout._infolayer.selectAll(\".annotation-\"+t.id).remove()}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767}],587:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"../annotations/common_defaults\"),s=t(\"./attributes\");function l(t,e,r,a){function l(r,i){return n.coerce(t,e,s,r,i)}function c(t){var n=t+\"axis\",a={_fullLayout:{}};return a._fullLayout[n]=r[n],i.coercePosition(e,a,l,t,t,.5)}l(\"visible\")&&(o(t,e,a.fullLayout,l),c(\"x\"),c(\"y\"),c(\"z\"),n.noneOrAll(t,e,[\"x\",\"y\",\"z\"]),e.xref=\"x\",e.yref=\"y\",e.zref=\"z\",l(\"xanchor\"),l(\"yanchor\"),l(\"xshift\"),l(\"yshift\"),e.showarrow&&(e.axref=\"pixel\",e.ayref=\"pixel\",l(\"ax\",-10),l(\"ay\",-30),n.noneOrAll(t,e,[\"ax\",\"ay\"])))}e.exports=function(t,e,r){a(t,e,{name:\"annotations\",handleItemDefaults:l,fullLayout:r.fullLayout})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"../annotations/common_defaults\":579,\"./attributes\":585}],588:[function(t,e,r){\"use strict\";var n=t(\"../annotations/draw\").drawRaw,i=t(\"../../plots/gl3d/project\"),a=[\"x\",\"y\",\"z\"];e.exports=function(t){for(var e=t.fullSceneLayout,r=t.dataScale,o=e.annotations,s=0;s<o.length;s++){for(var l=o[s],c=!1,u=0;u<3;u++){var h=a[u],f=l[h],p=e[h+\"axis\"].r2fraction(f);if(p<0||p>1){c=!0;break}}c?t.fullLayout._infolayer.select(\".annotation-\"+t.id+'[data-index=\"'+s+'\"]').remove():(l._pdata=i(t.glplot.cameraParams,[e.xaxis.r2l(l.x)*r[0],e.yaxis.r2l(l.y)*r[1],e.zaxis.r2l(l.z)*r[2]]),n(t.graphDiv,l,s,t.id,l._xa,l._ya))}}},{\"../../plots/gl3d/project\":816,\"../annotations/draw\":582}],589:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports={moduleType:\"component\",name:\"annotations3d\",schema:{subplots:{scene:{annotations:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),includeBasePlot:function(t,e){var r=n.subplotsRegistry.gl3d;if(!r)return;for(var a=r.attrRegex,o=Object.keys(t),s=0;s<o.length;s++){var l=o[s];a.test(l)&&(t[l].annotations||[]).length&&(i.pushUnique(e._basePlotModules,r),i.pushUnique(e._subplots.gl3d,l))}},convert:t(\"./convert\"),draw:t(\"./draw\")}},{\"../../lib\":719,\"../../registry\":847,\"./attributes\":585,\"./convert\":586,\"./defaults\":587,\"./draw\":588}],590:[function(t,e,r){\"use strict\";e.exports=t(\"world-calendars/dist/main\"),t(\"world-calendars/dist/plus\"),t(\"world-calendars/dist/calendars/chinese\"),t(\"world-calendars/dist/calendars/coptic\"),t(\"world-calendars/dist/calendars/discworld\"),t(\"world-calendars/dist/calendars/ethiopian\"),t(\"world-calendars/dist/calendars/hebrew\"),t(\"world-calendars/dist/calendars/islamic\"),t(\"world-calendars/dist/calendars/julian\"),t(\"world-calendars/dist/calendars/mayan\"),t(\"world-calendars/dist/calendars/nanakshahi\"),t(\"world-calendars/dist/calendars/nepali\"),t(\"world-calendars/dist/calendars/persian\"),t(\"world-calendars/dist/calendars/taiwan\"),t(\"world-calendars/dist/calendars/thai\"),t(\"world-calendars/dist/calendars/ummalqura\")},{\"world-calendars/dist/calendars/chinese\":557,\"world-calendars/dist/calendars/coptic\":558,\"world-calendars/dist/calendars/discworld\":559,\"world-calendars/dist/calendars/ethiopian\":560,\"world-calendars/dist/calendars/hebrew\":561,\"world-calendars/dist/calendars/islamic\":562,\"world-calendars/dist/calendars/julian\":563,\"world-calendars/dist/calendars/mayan\":564,\"world-calendars/dist/calendars/nanakshahi\":565,\"world-calendars/dist/calendars/nepali\":566,\"world-calendars/dist/calendars/persian\":567,\"world-calendars/dist/calendars/taiwan\":568,\"world-calendars/dist/calendars/thai\":569,\"world-calendars/dist/calendars/ummalqura\":570,\"world-calendars/dist/main\":571,\"world-calendars/dist/plus\":572}],591:[function(t,e,r){\"use strict\";var n=t(\"./calendars\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\"),o=a.EPOCHJD,s=a.ONEDAY,l={valType:\"enumerated\",values:Object.keys(n.calendars),editType:\"calc\",dflt:\"gregorian\"},c=function(t,e,r,n){var a={};return a[r]=l,i.coerce(t,e,a,r,n)},u=\"##\",h={d:{0:\"dd\",\"-\":\"d\"},e:{0:\"d\",\"-\":\"d\"},a:{0:\"D\",\"-\":\"D\"},A:{0:\"DD\",\"-\":\"DD\"},j:{0:\"oo\",\"-\":\"o\"},W:{0:\"ww\",\"-\":\"w\"},m:{0:\"mm\",\"-\":\"m\"},b:{0:\"M\",\"-\":\"M\"},B:{0:\"MM\",\"-\":\"MM\"},y:{0:\"yy\",\"-\":\"yy\"},Y:{0:\"yyyy\",\"-\":\"yyyy\"},U:u,w:u,c:{0:\"D M d %X yyyy\",\"-\":\"D M d %X yyyy\"},x:{0:\"mm/dd/yyyy\",\"-\":\"mm/dd/yyyy\"}};var f={};function p(t){var e=f[t];return e||(e=f[t]=n.instance(t))}function d(t){return i.extendFlat({},l,{description:t})}function g(t){return\"Sets the calendar system to use with `\"+t+\"` date data.\"}var v={xcalendar:d(g(\"x\"))},m=i.extendFlat({},v,{ycalendar:d(g(\"y\"))}),y=i.extendFlat({},m,{zcalendar:d(g(\"z\"))}),x=d([\"Sets the calendar system to use for `range` and `tick0`\",\"if this is a date axis. This does not set the calendar for\",\"interpreting data on this axis, that's specified in the trace\",\"or via the global `layout.calendar`\"].join(\" \"));e.exports={moduleType:\"component\",name:\"calendars\",schema:{traces:{scatter:m,bar:m,box:m,heatmap:m,contour:m,histogram:m,histogram2d:m,histogram2dcontour:m,scatter3d:y,surface:y,mesh3d:y,scattergl:m,ohlc:v,candlestick:v},layout:{calendar:d([\"Sets the default calendar system to use for interpreting and\",\"displaying dates throughout the plot.\"].join(\" \"))},subplots:{xaxis:{calendar:x},yaxis:{calendar:x},scene:{xaxis:{calendar:x},yaxis:{calendar:x},zaxis:{calendar:x}},polar:{radialaxis:{calendar:x}}},transforms:{filter:{valuecalendar:d([\"Sets the calendar system to use for `value`, if it is a date.\"].join(\" \")),targetcalendar:d([\"Sets the calendar system to use for `target`, if it is an\",\"array of dates. If `target` is a string (eg *x*) we use the\",\"corresponding trace attribute (eg `xcalendar`) if it exists,\",\"even if `targetcalendar` is provided.\"].join(\" \"))}}},layoutAttributes:l,handleDefaults:c,handleTraceDefaults:function(t,e,r,n){for(var i=0;i<r.length;i++)c(t,e,r[i]+\"calendar\",n.calendar)},CANONICAL_SUNDAY:{chinese:\"2000-01-02\",coptic:\"2000-01-03\",discworld:\"2000-01-03\",ethiopian:\"2000-01-05\",hebrew:\"5000-01-01\",islamic:\"1000-01-02\",julian:\"2000-01-03\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-05\",nepali:\"2000-01-05\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-04\",thai:\"2000-01-04\",ummalqura:\"1400-01-06\"},CANONICAL_TICK:{chinese:\"2000-01-01\",coptic:\"2000-01-01\",discworld:\"2000-01-01\",ethiopian:\"2000-01-01\",hebrew:\"5000-01-01\",islamic:\"1000-01-01\",julian:\"2000-01-01\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-01\",nepali:\"2000-01-01\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-01\",thai:\"2000-01-01\",ummalqura:\"1400-01-01\"},DFLTRANGE:{chinese:[\"2000-01-01\",\"2001-01-01\"],coptic:[\"1700-01-01\",\"1701-01-01\"],discworld:[\"1800-01-01\",\"1801-01-01\"],ethiopian:[\"2000-01-01\",\"2001-01-01\"],hebrew:[\"5700-01-01\",\"5701-01-01\"],islamic:[\"1400-01-01\",\"1401-01-01\"],julian:[\"2000-01-01\",\"2001-01-01\"],mayan:[\"5200-01-01\",\"5201-01-01\"],nanakshahi:[\"0500-01-01\",\"0501-01-01\"],nepali:[\"2000-01-01\",\"2001-01-01\"],persian:[\"1400-01-01\",\"1401-01-01\"],jalali:[\"1400-01-01\",\"1401-01-01\"],taiwan:[\"0100-01-01\",\"0101-01-01\"],thai:[\"2500-01-01\",\"2501-01-01\"],ummalqura:[\"1400-01-01\",\"1401-01-01\"]},getCal:p,worldCalFmt:function(t,e,r){for(var n,i,a,l,c,f=Math.floor((e+.05)/s)+o,d=p(r).fromJD(f),g=0;-1!==(g=t.indexOf(\"%\",g));)\"0\"===(n=t.charAt(g+1))||\"-\"===n||\"_\"===n?(a=3,i=t.charAt(g+2),\"_\"===n&&(n=\"-\")):(i=n,n=\"0\",a=2),(l=h[i])?(c=l===u?u:d.formatDate(l[n]),t=t.substr(0,g)+c+t.substr(g+a),g+=c.length):g+=a;return t}}},{\"../../constants/numerical\":695,\"../../lib\":719,\"./calendars\":590}],592:[function(t,e,r){\"use strict\";r.defaults=[\"#1f77b4\",\"#ff7f0e\",\"#2ca02c\",\"#d62728\",\"#9467bd\",\"#8c564b\",\"#e377c2\",\"#7f7f7f\",\"#bcbd22\",\"#17becf\"],r.defaultLine=\"#444\",r.lightLine=\"#eee\",r.background=\"#fff\",r.borderLine=\"#BEC8D9\",r.lightFraction=1e3/11},{}],593:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i=t(\"fast-isnumeric\"),a=e.exports={},o=t(\"./attributes\");a.defaults=o.defaults;var s=a.defaultLine=o.defaultLine;a.lightLine=o.lightLine;var l=a.background=o.background;function c(t){if(i(t)||\"string\"!=typeof t)return t;var e=t.trim();if(\"rgb\"!==e.substr(0,3))return t;var r=e.match(/^rgba?\\s*\\(([^()]*)\\)$/);if(!r)return t;var n=r[1].trim().split(/\\s*[\\s,]\\s*/),a=\"a\"===e.charAt(3)&&4===n.length;if(!a&&3!==n.length)return t;for(var o=0;o<n.length;o++){if(!n[o].length)return t;if(n[o]=Number(n[o]),!(n[o]>=0))return t;if(3===o)n[o]>1&&(n[o]=1);else if(n[o]>=1)return t}var s=Math.round(255*n[0])+\", \"+Math.round(255*n[1])+\", \"+Math.round(255*n[2]);return a?\"rgba(\"+s+\", \"+n[3]+\")\":\"rgb(\"+s+\")\"}a.tinyRGB=function(t){var e=t.toRgb();return\"rgb(\"+Math.round(e.r)+\", \"+Math.round(e.g)+\", \"+Math.round(e.b)+\")\"},a.rgb=function(t){return a.tinyRGB(n(t))},a.opacity=function(t){return t?n(t).getAlpha():0},a.addOpacity=function(t,e){var r=n(t).toRgb();return\"rgba(\"+Math.round(r.r)+\", \"+Math.round(r.g)+\", \"+Math.round(r.b)+\", \"+e+\")\"},a.combine=function(t,e){var r=n(t).toRgb();if(1===r.a)return n(t).toRgbString();var i=n(e||l).toRgb(),a=1===i.a?i:{r:255*(1-i.a)+i.r*i.a,g:255*(1-i.a)+i.g*i.a,b:255*(1-i.a)+i.b*i.a},o={r:a.r*(1-r.a)+r.r*r.a,g:a.g*(1-r.a)+r.g*r.a,b:a.b*(1-r.a)+r.b*r.a};return n(o).toRgbString()},a.contrast=function(t,e,r){var i=n(t);return 1!==i.getAlpha()&&(i=n(a.combine(t,l))),(i.isDark()?e?i.lighten(e):l:r?i.darken(r):s).toString()},a.stroke=function(t,e){var r=n(e);t.style({stroke:a.tinyRGB(r),\"stroke-opacity\":r.getAlpha()})},a.fill=function(t,e){var r=n(e);t.style({fill:a.tinyRGB(r),\"fill-opacity\":r.getAlpha()})},a.clean=function(t){if(t&&\"object\"==typeof t){var e,r,n,i,o=Object.keys(t);for(e=0;e<o.length;e++)if(i=t[n=o[e]],\"color\"===n.substr(n.length-5))if(Array.isArray(i))for(r=0;r<i.length;r++)i[r]=c(i[r]);else t[n]=c(i);else if(\"colorscale\"===n.substr(n.length-10)&&Array.isArray(i))for(r=0;r<i.length;r++)Array.isArray(i[r])&&(i[r][1]=c(i[r][1]));else if(Array.isArray(i)){var s=i[0];if(!Array.isArray(s)&&s&&\"object\"==typeof s)for(r=0;r<i.length;r++)a.clean(i[r])}else i&&\"object\"==typeof i&&a.clean(i)}}},{\"./attributes\":592,\"fast-isnumeric\":225,tinycolor2:537}],594:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/layout_attributes\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll;e.exports=o({thicknessmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"pixels\"},thickness:{valType:\"number\",min:0,dflt:30},lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",dflt:1.02,min:-2,max:3},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},xpad:{valType:\"number\",min:0,dflt:10},y:{valType:\"number\",dflt:.5,min:-2,max:3},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\"},ypad:{valType:\"number\",min:0,dflt:10},outlinecolor:n.linecolor,outlinewidth:n.linewidth,bordercolor:n.linecolor,borderwidth:{valType:\"number\",min:0,dflt:0},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\"},tickmode:n.tickmode,nticks:n.nticks,tick0:n.tick0,dtick:n.dtick,tickvals:n.tickvals,ticktext:n.ticktext,ticks:a({},n.ticks,{dflt:\"\"}),ticklen:n.ticklen,tickwidth:n.tickwidth,tickcolor:n.tickcolor,showticklabels:n.showticklabels,tickfont:i({}),tickangle:n.tickangle,tickformat:n.tickformat,tickformatstops:n.tickformatstops,tickprefix:n.tickprefix,showtickprefix:n.showtickprefix,ticksuffix:n.ticksuffix,showticksuffix:n.showticksuffix,separatethousands:n.separatethousands,exponentformat:n.exponentformat,showexponent:n.showexponent,title:{text:{valType:\"string\"},font:i({}),side:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}},_deprecated:{title:{valType:\"string\"},titlefont:i({}),titleside:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}}},\"colorbars\",\"from-root\")},{\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/font_attributes\":793}],595:[function(t,e,r){\"use strict\";e.exports={cn:{colorbar:\"colorbar\",cbbg:\"cbbg\",cbfill:\"cbfill\",cbfills:\"cbfills\",cbline:\"cbline\",cblines:\"cblines\",cbaxis:\"cbaxis\",cbtitleunshift:\"cbtitleunshift\",cbtitle:\"cbtitle\",cboutline:\"cboutline\",crisp:\"crisp\",jsPlaceholder:\"js-placeholder\"}}},{}],596:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/tick_value_defaults\"),o=t(\"../../plots/cartesian/tick_mark_defaults\"),s=t(\"../../plots/cartesian/tick_label_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r){var c=i.newContainer(e,\"colorbar\"),u=t.colorbar||{};function h(t,e){return n.coerce(u,c,l,t,e)}var f=h(\"thicknessmode\");h(\"thickness\",\"fraction\"===f?30/(r.width-r.margin.l-r.margin.r):30);var p=h(\"lenmode\");h(\"len\",\"fraction\"===p?1:r.height-r.margin.t-r.margin.b),h(\"x\"),h(\"xanchor\"),h(\"xpad\"),h(\"y\"),h(\"yanchor\"),h(\"ypad\"),n.noneOrAll(u,c,[\"x\",\"y\"]),h(\"outlinecolor\"),h(\"outlinewidth\"),h(\"bordercolor\"),h(\"borderwidth\"),h(\"bgcolor\"),a(u,c,h,\"linear\");var d={outerTicks:!1,font:r.font};s(u,c,h,\"linear\",d),o(u,c,h,\"linear\",d),h(\"title.text\",r._dfltTitle.colorbar),n.coerceFont(h,\"title.font\",r.font),h(\"title.side\")}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/tick_label_defaults\":786,\"../../plots/cartesian/tick_mark_defaults\":787,\"../../plots/cartesian/tick_value_defaults\":788,\"./attributes\":594}],597:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../dragelement\"),c=t(\"../../lib\"),u=t(\"../../lib/extend\").extendFlat,h=t(\"../../lib/setcursor\"),f=t(\"../drawing\"),p=t(\"../color\"),d=t(\"../titles\"),g=t(\"../../lib/svg_text_utils\"),v=t(\"../colorscale/helpers\").flipScale,m=t(\"../../plots/cartesian/axis_defaults\"),y=t(\"../../plots/cartesian/position_defaults\"),x=t(\"../../plots/cartesian/layout_attributes\"),b=t(\"../../constants/alignment\"),_=b.LINE_SPACING,w=b.FROM_TL,k=b.FROM_BR,T=t(\"./constants\").cn;e.exports={draw:function(t){var e=t._fullLayout._infolayer.selectAll(\"g.\"+T.colorbar).data(function(t){var e,r,n,i,a=t._fullLayout,o=t.calcdata,s=[];function l(t){return u(t,{_fillcolor:null,_line:{color:null,width:null,dash:null},_levels:{start:null,end:null,size:null},_filllevels:null,_fillgradient:null,_zrange:null})}function c(){\"function\"==typeof i.calc?i.calc(t,n,e):(e._fillgradient=r.reversescale?v(r.colorscale):r.colorscale,e._zrange=[r[i.min],r[i.max]])}for(var h=0;h<o.length;h++){var f=o[h],p=(n=f[0].trace)._module.colorbar;if(!0===n.visible&&p)for(var d=Array.isArray(p),g=d?p:[p],m=0;m<g.length;m++){var y=(i=g[m]).container;(r=y?n[y]:n)&&r.showscale&&((e=l(r.colorbar))._id=\"cb\"+n.uid+(d&&y?\"-\"+y:\"\"),e._traceIndex=n.index,e._propPrefix=(y?y+\".\":\"\")+\"colorbar.\",e._meta=n._meta,c(),s.push(e))}}for(var x in a._colorAxes)if((r=a[x]).showscale){var b=a._colorAxes[x];(e=l(r.colorbar))._id=\"cb\"+x,e._propPrefix=x+\".colorbar.\",e._meta=a._meta,i={min:\"cmin\",max:\"cmax\"},\"heatmap\"!==b[0]&&(n=b[1],i.calc=n._module.colorbar.calc),c(),s.push(e)}return s}(t),function(t){return t._id});e.enter().append(\"g\").attr(\"class\",function(t){return t._id}).classed(T.colorbar,!0),e.each(function(e){var r=n.select(this);c.ensureSingle(r,\"rect\",T.cbbg),c.ensureSingle(r,\"g\",T.cbfills),c.ensureSingle(r,\"g\",T.cblines),c.ensureSingle(r,\"g\",T.cbaxis,function(t){t.classed(T.crisp,!0)}),c.ensureSingle(r,\"g\",T.cbtitleunshift,function(t){t.append(\"g\").classed(T.cbtitle,!0)}),c.ensureSingle(r,\"rect\",T.cboutline);var v=function(t,e,r){var o=r._fullLayout,l=o._size,h=e._fillcolor,v=e._line,b=e.title,A=b.side,M=e._zrange||n.extent((\"function\"==typeof h?h:v.color).domain()),S=\"function\"==typeof v.color?v.color:function(){return v.color},E=\"function\"==typeof h?h:function(){return h},C=e._levels,L=function(t,e,r){var n,i,a=e._levels,o=[],s=[],l=a.end+a.size/100,c=a.size,u=1.001*r[0]-.001*r[1],h=1.001*r[1]-.001*r[0];for(i=0;i<1e5&&(n=a.start+i*c,!(c>0?n>=l:n<=l));i++)n>u&&n<h&&o.push(n);if(e._fillgradient)s=[0];else if(\"function\"==typeof e._fillcolor){var f=e._filllevels;if(f)for(l=f.end+f.size/100,c=f.size,i=0;i<1e5&&(n=f.start+i*c,!(c>0?n>=l:n<=l));i++)n>r[0]&&n<r[1]&&s.push(n);else(s=o.map(function(t){return t-a.size/2})).push(s[s.length-1]+a.size)}else e._fillcolor&&\"string\"==typeof e._fillcolor&&(s=[0]);return a.size<0&&(o.reverse(),s.reverse()),{line:o,fill:s}}(0,e,M),P=L.fill,O=L.line,z=Math.round(e.thickness*(\"fraction\"===e.thicknessmode?l.w:1)),I=z/l.w,D=Math.round(e.len*(\"fraction\"===e.lenmode?l.h:1)),R=D/l.h,F=e.xpad/l.w,B=(e.borderwidth+e.outlinewidth)/2,N=e.ypad/l.h,j=Math.round(e.x*l.w+e.xpad),U=e.x-I*({middle:.5,right:1}[e.xanchor]||0),V=e.y+R*(({top:-.5,bottom:.5}[e.yanchor]||0)-.5),q=Math.round(l.h*(1-V)),H=q-D;e._lenFrac=R,e._thickFrac=I,e._xLeftFrac=U,e._yBottomFrac=V;var G=function(t,e,r){var n=t._fullLayout,i={type:\"linear\",range:r,tickmode:e.tickmode,nticks:e.nticks,tick0:e.tick0,dtick:e.dtick,tickvals:e.tickvals,ticktext:e.ticktext,ticks:e.ticks,ticklen:e.ticklen,tickwidth:e.tickwidth,tickcolor:e.tickcolor,showticklabels:e.showticklabels,tickfont:e.tickfont,tickangle:e.tickangle,tickformat:e.tickformat,exponentformat:e.exponentformat,separatethousands:e.separatethousands,showexponent:e.showexponent,showtickprefix:e.showtickprefix,tickprefix:e.tickprefix,showticksuffix:e.showticksuffix,ticksuffix:e.ticksuffix,title:e.title,showline:!0,anchor:\"free\",side:\"right\",position:1},a={type:\"linear\",_id:\"y\"+e._id},o={letter:\"y\",font:n.font,noHover:!0,noTickson:!0,calendar:n.calendar};function s(t,e){return c.coerce(i,a,x,t,e)}return m(i,a,s,o,n),y(i,a,s,o),a}(r,e,M);if(G.position=e.x+F+I,-1!==[\"top\",\"bottom\"].indexOf(A)&&(G.title.side=A,G.titlex=e.x+F,G.titley=V+(\"top\"===b.side?R-N:N)),v.color&&\"auto\"===e.tickmode){G.tickmode=\"linear\",G.tick0=C.start;var Y=C.size,W=c.constrain((q-H)/50,4,15)+1,X=(M[1]-M[0])/((e.nticks||W)*Y);if(X>1){var Z=Math.pow(10,Math.floor(Math.log(X)/Math.LN10));Y*=Z*c.roundUp(X/Z,[2,5,10]),(Math.abs(C.start)/C.size+1e-6)%1<2e-6&&(G.tick0=0)}G.dtick=Y}G.domain=[V+N,V+R-N],G.setScale(),t.attr(\"transform\",\"translate(\"+Math.round(l.l)+\",\"+Math.round(l.t)+\")\");var J,K=t.select(\".\"+T.cbtitleunshift).attr(\"transform\",\"translate(-\"+Math.round(l.l)+\",-\"+Math.round(l.t)+\")\"),$=t.select(\".\"+T.cbaxis),Q=0;function tt(n,i){var a={propContainer:G,propName:e._propPrefix+\"title\",traceIndex:e._traceIndex,_meta:e._meta,placeholder:o._dfltTitle.colorbar,containerGroup:t.select(\".\"+T.cbtitle)},s=\"h\"===n.charAt(0)?n.substr(1):\"h\"+n;t.selectAll(\".\"+s+\",.\"+s+\"-math-group\").remove(),d.draw(r,n,u(a,i||{}))}return c.syncOrAsync([a.previousPromises,function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var t,r=l.l+(e.x+F)*l.w,n=G.title.font.size;t=\"top\"===A?(1-(V+R-N))*l.h+l.t+3+.75*n:(1-(V+N))*l.h+l.t-3-.25*n,tt(G._id+\"title\",{attributes:{x:r,y:t,\"text-anchor\":\"start\"}})}},function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var a=t.select(\".\"+T.cbtitle),o=a.select(\"text\"),u=[-e.outlinewidth/2,e.outlinewidth/2],h=a.select(\".h\"+G._id+\"title-math-group\").node(),p=15.6;if(o.node()&&(p=parseInt(o.node().style.fontSize,10)*_),h?(Q=f.bBox(h).height)>p&&(u[1]-=(Q-p)/2):o.node()&&!o.classed(T.jsPlaceholder)&&(Q=f.bBox(o.node()).height),Q){if(Q+=5,\"top\"===A)G.domain[1]-=Q/l.h,u[1]*=-1;else{G.domain[0]+=Q/l.h;var d=g.lineCount(o);u[1]+=(1-d)*p}a.attr(\"transform\",\"translate(\"+u+\")\"),G.setScale()}}t.selectAll(\".\"+T.cbfills+\",.\"+T.cblines).attr(\"transform\",\"translate(0,\"+Math.round(l.h*(1-G.domain[1]))+\")\"),$.attr(\"transform\",\"translate(0,\"+Math.round(-l.t)+\")\");var m=t.select(\".\"+T.cbfills).selectAll(\"rect.\"+T.cbfill).data(P);m.enter().append(\"rect\").classed(T.cbfill,!0).style(\"stroke\",\"none\"),m.exit().remove();var y=M.map(G.c2p).map(Math.round).sort(function(t,e){return t-e});m.each(function(t,a){var o=[0===a?M[0]:(P[a]+P[a-1])/2,a===P.length-1?M[1]:(P[a]+P[a+1])/2].map(G.c2p).map(Math.round);o[1]=c.constrain(o[1]+(o[1]>o[0])?1:-1,y[0],y[1]);var s=n.select(this).attr({x:j,width:Math.max(z,2),y:n.min(o),height:Math.max(n.max(o)-n.min(o),2)});if(e._fillgradient)f.gradient(s,r,e._id,\"vertical\",e._fillgradient,\"fill\");else{var l=E(t).replace(\"e-\",\"\");s.attr(\"fill\",i(l).toHexString())}});var x=t.select(\".\"+T.cblines).selectAll(\"path.\"+T.cbline).data(v.color&&v.width?O:[]);x.enter().append(\"path\").classed(T.cbline,!0),x.exit().remove(),x.each(function(t){n.select(this).attr(\"d\",\"M\"+j+\",\"+(Math.round(G.c2p(t))+v.width/2%1)+\"h\"+z).call(f.lineGroupStyle,v.width,S(t),v.dash)}),$.selectAll(\"g.\"+G._id+\"tick,path\").remove();var b=j+z+(e.outlinewidth||0)/2-(\"outside\"===e.ticks?1:0),w=s.calcTicks(G),k=s.makeTransFn(G),C=s.getTickSigns(G)[2];return s.drawTicks(r,G,{vals:\"inside\"===G.ticks?s.clipEnds(G,w):w,layer:$,path:s.makeTickPath(G,b,C),transFn:k}),s.drawLabels(r,G,{vals:w,layer:$,transFn:k,labelFns:s.makeLabelFns(G,b)})},function(){if(-1===[\"top\",\"bottom\"].indexOf(A)){var t=G.title.font.size,e=G._offset+G._length/2,i=l.l+(G.position||0)*l.w+(\"right\"===G.side?10+t*(G.showticklabels?1:.5):-10-t*(G.showticklabels?.5:0));tt(\"h\"+G._id+\"title\",{avoid:{selection:n.select(r).selectAll(\"g.\"+G._id+\"tick\"),side:A,offsetLeft:l.l,offsetTop:0,maxShift:o.width},attributes:{x:i,y:e,\"text-anchor\":\"middle\"},transform:{rotate:\"-90\",offset:0}})}},a.previousPromises,function(){var n=z+e.outlinewidth/2+f.bBox($.node()).width;if((J=K.select(\"text\")).node()&&!J.classed(T.jsPlaceholder)){var i,o=K.select(\".h\"+G._id+\"title-math-group\").node();i=o&&-1!==[\"top\",\"bottom\"].indexOf(A)?f.bBox(o).width:f.bBox(K.node()).right-j-l.l,n=Math.max(n,i)}var s=2*e.xpad+n+e.borderwidth+e.outlinewidth/2,c=q-H;t.select(\".\"+T.cbbg).attr({x:j-e.xpad-(e.borderwidth+e.outlinewidth)/2,y:H-B,width:Math.max(s,2),height:Math.max(c+2*B,2)}).call(p.fill,e.bgcolor).call(p.stroke,e.bordercolor).style(\"stroke-width\",e.borderwidth),t.selectAll(\".\"+T.cboutline).attr({x:j,y:H+e.ypad+(\"top\"===A?Q:0),width:Math.max(z,2),height:Math.max(c-2*e.ypad-Q,2)}).call(p.stroke,e.outlinecolor).style({fill:\"none\",\"stroke-width\":e.outlinewidth});var u=({center:.5,right:1}[e.xanchor]||0)*s;t.attr(\"transform\",\"translate(\"+(l.l-u)+\",\"+l.t+\")\");var h={},d=w[e.yanchor],g=k[e.yanchor];\"pixels\"===e.lenmode?(h.y=e.y,h.t=c*d,h.b=c*g):(h.t=h.b=0,h.yt=e.y+e.len*d,h.yb=e.y-e.len*g);var v=w[e.xanchor],m=k[e.xanchor];if(\"pixels\"===e.thicknessmode)h.x=e.x,h.l=s*v,h.r=s*m;else{var y=s-z;h.l=y*v,h.r=y*m,h.xl=e.x-e.thickness*v,h.xr=e.x+e.thickness*m}a.autoMargin(r,e._id,h)}],r)}(r,e,t);v&&v.then&&(t._promises||[]).push(v),t._context.edits.colorbarPosition&&function(t,e,r){var n,i,a,s=r._fullLayout._size;l.init({element:t.node(),gd:r,prepFn:function(){n=t.attr(\"transform\"),h(t)},moveFn:function(r,o){t.attr(\"transform\",n+\" translate(\"+r+\",\"+o+\")\"),i=l.align(e._xLeftFrac+r/s.w,e._thickFrac,0,1,e.xanchor),a=l.align(e._yBottomFrac-o/s.h,e._lenFrac,0,1,e.yanchor);var c=l.getCursor(i,a,e.xanchor,e.yanchor);h(t,c)},doneFn:function(){if(h(t),void 0!==i&&void 0!==a){var n={};n[e._propPrefix+\"x\"]=i,n[e._propPrefix+\"y\"]=a,void 0!==e._traceIndex?o.call(\"_guiRestyle\",r,n,e._traceIndex):o.call(\"_guiRelayout\",r,n)}}})}(r,e,t)}),e.exit().each(function(e){a.autoMargin(t,e._id)}).remove(),e.order()}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/extend\":710,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_defaults\":769,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/cartesian/position_defaults\":782,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../colorscale/helpers\":604,\"../dragelement\":611,\"../drawing\":614,\"../titles\":681,\"./constants\":595,d3:163,tinycolor2:537}],598:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t){return n.isPlainObject(t.colorbar)}},{\"../../lib\":719}],599:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"colorbar\",attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),draw:t(\"./draw\").draw,hasColorbar:t(\"./has_colorbar\")}},{\"./attributes\":594,\"./defaults\":596,\"./draw\":597,\"./has_colorbar\":598}],600:[function(t,e,r){\"use strict\";var n=t(\"../colorbar/attributes\"),i=t(\"../../lib/regex\").counter,a=t(\"./scales.js\").scales;Object.keys(a);function o(t){return\"`\"+t+\"`\"}e.exports=function(t,e){t=t||\"\";var r,s=(e=e||{}).cLetter||\"c\",l=(\"onlyIfNumerical\"in e?e.onlyIfNumerical:Boolean(t),\"noScale\"in e?e.noScale:\"marker.line\"===t),c=\"showScaleDflt\"in e?e.showScaleDflt:\"z\"===s,u=\"string\"==typeof e.colorscaleDflt?a[e.colorscaleDflt]:null,h=e.editTypeOverride||\"\",f=t?t+\".\":\"\";\"colorAttr\"in e?(r=e.colorAttr,e.colorAttr):o(f+(r={z:\"z\",c:\"color\"}[s]));var p=s+\"auto\",d=s+\"min\",g=s+\"max\",v=s+\"mid\",m=(o(f+p),o(f+d),o(f+g),{});m[d]=m[g]=void 0;var y={};y[p]=!1;var x={};return\"color\"===r&&(x.color={valType:\"color\",arrayOk:!0,editType:h||\"style\"},e.anim&&(x.color.anim=!0)),x[p]={valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:m},x[d]={valType:\"number\",dflt:null,editType:h||\"plot\",impliedEdits:y},x[g]={valType:\"number\",dflt:null,editType:h||\"plot\",impliedEdits:y},x[v]={valType:\"number\",dflt:null,editType:\"calc\",impliedEdits:m},x.colorscale={valType:\"colorscale\",editType:\"calc\",dflt:u,impliedEdits:{autocolorscale:!1}},x.autocolorscale={valType:\"boolean\",dflt:!1!==e.autoColorDflt,editType:\"calc\",impliedEdits:{colorscale:void 0}},x.reversescale={valType:\"boolean\",dflt:!1,editType:\"plot\"},l||(x.showscale={valType:\"boolean\",dflt:c,editType:\"calc\"},x.colorbar=n),e.noColorAxis||(x.coloraxis={valType:\"subplotid\",regex:i(\"coloraxis\"),dflt:null,editType:\"calc\"}),x}},{\"../../lib/regex\":735,\"../colorbar/attributes\":594,\"./scales.js\":608}],601:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"./helpers\").extractOpts;e.exports=function(t,e,r){var o,s=t._fullLayout,l=r.vals,c=r.containerStr,u=c?i.nestedProperty(e,c).get():e,h=a(u),f=!1!==h.auto,p=h.min,d=h.max,g=h.mid,v=function(){return i.aggNums(Math.min,null,l)},m=function(){return i.aggNums(Math.max,null,l)};(void 0===p?p=v():f&&(p=u._colorAx&&n(p)?Math.min(p,v()):v()),void 0===d?d=m():f&&(d=u._colorAx&&n(d)?Math.max(d,m()):m()),f&&void 0!==g&&(d-g>g-p?p=g-(d-g):d-g<g-p&&(d=g+(g-p))),p===d&&(p-=.5,d+=.5),h._sync(\"min\",p),h._sync(\"max\",d),h.autocolorscale)&&(o=p*d<0?s.colorscale.diverging:p>=0?s.colorscale.sequential:s.colorscale.sequentialminus,h._sync(\"colorscale\",o))}},{\"../../lib\":719,\"./helpers\":604,\"fast-isnumeric\":225}],602:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./helpers\").hasColorscale,a=t(\"./helpers\").extractOpts;e.exports=function(t,e){function r(t,e){var r=t[\"_\"+e];void 0!==r&&(t[e]=r)}function o(t,i){var o=i.container?n.nestedProperty(t,i.container).get():t;if(o)if(o.coloraxis)o._colorAx=e[o.coloraxis];else{var s=a(o),l=s.auto;(l||void 0===s.min)&&r(o,i.min),(l||void 0===s.max)&&r(o,i.max),s.autocolorscale&&r(o,\"colorscale\")}}for(var s=0;s<t.length;s++){var l=t[s],c=l._module.colorbar;if(c)if(Array.isArray(c))for(var u=0;u<c.length;u++)o(l,c[u]);else o(l,c);i(l,\"marker.line\")&&o(l,{container:\"marker.line\",min:\"cmin\",max:\"cmax\"})}for(var h in e._colorAxes)o(e[h],{min:\"cmin\",max:\"cmax\"})}},{\"../../lib\":719,\"./helpers\":604}],603:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../colorbar/has_colorbar\"),o=t(\"../colorbar/defaults\"),s=t(\"./scales\").isValid,l=t(\"../../registry\").traceIs;function c(t,e){var r=e.slice(0,e.length-1);return e?i.nestedProperty(t,r).get()||{}:t}e.exports=function t(e,r,u,h,f){var p=f.prefix,d=f.cLetter,g=\"_module\"in r,v=c(e,p),m=c(r,p),y=c(r._template||{},p)||{},x=function(){return delete e.coloraxis,delete r.coloraxis,t(e,r,u,h,f)};if(g){var b=u._colorAxes||{},_=h(p+\"coloraxis\");if(_){var w=l(r,\"contour\")&&i.nestedProperty(r,\"contours.coloring\").get()||\"heatmap\",k=b[_];return void(k?(k[2].push(x),k[0]!==w&&(k[0]=!1,i.warn([\"Ignoring coloraxis:\",_,\"setting\",\"as it is linked to incompatible colorscales.\"].join(\" \")))):b[_]=[w,r,[x]])}}var T=v[d+\"min\"],A=v[d+\"max\"],M=n(T)&&n(A)&&T<A;h(p+d+\"auto\",!M)?h(p+d+\"mid\"):(h(p+d+\"min\"),h(p+d+\"max\"));var S,E,C=v.colorscale,L=y.colorscale;(void 0!==C&&(S=!s(C)),void 0!==L&&(S=!s(L)),h(p+\"autocolorscale\",S),h(p+\"colorscale\"),h(p+\"reversescale\"),\"marker.line.\"!==p)&&(p&&g&&(E=a(v)),h(p+\"showscale\",E)&&o(v,m,u))}},{\"../../lib\":719,\"../../registry\":847,\"../colorbar/defaults\":596,\"../colorbar/has_colorbar\":598,\"./scales\":608,\"fast-isnumeric\":225}],604:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"fast-isnumeric\"),o=t(\"../../lib\"),s=t(\"../color\"),l=t(\"./scales\").isValid;var c=[\"showscale\",\"autocolorscale\",\"colorscale\",\"reversescale\",\"colorbar\"],u=[\"min\",\"max\",\"mid\",\"auto\"];function h(t){var e,r,n,i=t._colorAx,a=i||t,o={};for(r=0;r<c.length;r++)o[n=c[r]]=a[n];if(i)for(e=\"c\",r=0;r<u.length;r++)o[n=u[r]]=a[\"c\"+n];else{var s;for(r=0;r<u.length;r++)(s=\"c\"+(n=u[r]))in a?o[n]=a[s]:(s=\"z\"+n)in a&&(o[n]=a[s]);e=s.charAt(0)}return o._sync=function(t,r){var n=-1!==u.indexOf(t)?e+t:t;a[n]=a[\"_\"+n]=r},o}function f(t){for(var e=h(t),r=e.min,n=e.max,i=e.reversescale?p(e.colorscale):e.colorscale,a=i.length,o=new Array(a),s=new Array(a),l=0;l<a;l++){var c=i[l];o[l]=r+c[0]*(n-r),s[l]=c[1]}return{domain:o,range:s}}function p(t){for(var e=t.length,r=new Array(e),n=e-1,i=0;n>=0;n--,i++){var a=t[n];r[i]=[1-a[0],a[1]]}return r}function d(t,e){e=e||{};for(var r=t.domain,o=t.range,l=o.length,c=new Array(l),u=0;u<l;u++){var h=i(o[u]).toRgb();c[u]=[h.r,h.g,h.b,h.a]}var f,p=n.scale.linear().domain(r).range(c).clamp(!0),d=e.noNumericCheck,v=e.returnArray;return(f=d&&v?p:d?function(t){return g(p(t))}:v?function(t){return a(t)?p(t):i(t).isValid()?t:s.defaultLine}:function(t){return a(t)?g(p(t)):i(t).isValid()?t:s.defaultLine}).domain=p.domain,f.range=function(){return o},f}function g(t){var e={r:t[0],g:t[1],b:t[2],a:t[3]};return i(e).toRgbString()}e.exports={hasColorscale:function(t,e){var r=e?o.nestedProperty(t,e).get()||{}:t,n=r.color,i=!1;if(o.isArrayOrTypedArray(n))for(var s=0;s<n.length;s++)if(a(n[s])){i=!0;break}return o.isPlainObject(r)&&(i||!0===r.showscale||a(r.cmin)&&a(r.cmax)||l(r.colorscale)||o.isPlainObject(r.colorbar))},extractOpts:h,extractScale:f,flipScale:p,makeColorScaleFunc:d,makeColorScaleFuncFromTrace:function(t,e){return d(f(t),e)}}},{\"../../lib\":719,\"../color\":593,\"./scales\":608,d3:163,\"fast-isnumeric\":225,tinycolor2:537}],605:[function(t,e,r){\"use strict\";var n=t(\"./scales\"),i=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"colorscale\",attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),handleDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\"),scales:n.scales,defaultScale:n.defaultScale,getScale:n.get,isValidScale:n.isValid,hasColorscale:i.hasColorscale,extractOpts:i.extractOpts,extractScale:i.extractScale,flipScale:i.flipScale,makeColorScaleFunc:i.makeColorScaleFunc,makeColorScaleFuncFromTrace:i.makeColorScaleFuncFromTrace}},{\"./attributes\":600,\"./calc\":601,\"./cross_trace_defaults\":602,\"./defaults\":603,\"./helpers\":604,\"./layout_attributes\":606,\"./layout_defaults\":607,\"./scales\":608}],606:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"./attributes\"),a=t(\"./scales\").scales;e.exports={editType:\"calc\",colorscale:{editType:\"calc\",sequential:{valType:\"colorscale\",dflt:a.Reds,editType:\"calc\"},sequentialminus:{valType:\"colorscale\",dflt:a.Blues,editType:\"calc\"},diverging:{valType:\"colorscale\",dflt:a.RdBu,editType:\"calc\"}},coloraxis:n({_isSubplotObj:!0,editType:\"calc\"},i(\"\",{colorAttr:\"corresponding trace color array(s)\",noColorAxis:!0,showScaleDflt:!0}))}},{\"../../lib/extend\":710,\"./attributes\":600,\"./scales\":608}],607:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"./layout_attributes\"),o=t(\"./defaults\");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r(\"colorscale.sequential\"),r(\"colorscale.sequentialminus\"),r(\"colorscale.diverging\");var s,l,c=e._colorAxes;function u(t,e){return n.coerce(s,l,a.coloraxis,t,e)}for(var h in c){var f=c[h];if(f[0])s=t[h]||{},(l=i.newContainer(e,h,\"coloraxis\"))._name=h,o(s,l,e,u,{prefix:\"\",cLetter:\"c\"});else{for(var p=0;p<f[2].length;p++)f[2][p]();delete e._colorAxes[h]}}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"./defaults\":603,\"./layout_attributes\":606}],608:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i={Greys:[[0,\"rgb(0,0,0)\"],[1,\"rgb(255,255,255)\"]],YlGnBu:[[0,\"rgb(8,29,88)\"],[.125,\"rgb(37,52,148)\"],[.25,\"rgb(34,94,168)\"],[.375,\"rgb(29,145,192)\"],[.5,\"rgb(65,182,196)\"],[.625,\"rgb(127,205,187)\"],[.75,\"rgb(199,233,180)\"],[.875,\"rgb(237,248,217)\"],[1,\"rgb(255,255,217)\"]],Greens:[[0,\"rgb(0,68,27)\"],[.125,\"rgb(0,109,44)\"],[.25,\"rgb(35,139,69)\"],[.375,\"rgb(65,171,93)\"],[.5,\"rgb(116,196,118)\"],[.625,\"rgb(161,217,155)\"],[.75,\"rgb(199,233,192)\"],[.875,\"rgb(229,245,224)\"],[1,\"rgb(247,252,245)\"]],YlOrRd:[[0,\"rgb(128,0,38)\"],[.125,\"rgb(189,0,38)\"],[.25,\"rgb(227,26,28)\"],[.375,\"rgb(252,78,42)\"],[.5,\"rgb(253,141,60)\"],[.625,\"rgb(254,178,76)\"],[.75,\"rgb(254,217,118)\"],[.875,\"rgb(255,237,160)\"],[1,\"rgb(255,255,204)\"]],Bluered:[[0,\"rgb(0,0,255)\"],[1,\"rgb(255,0,0)\"]],RdBu:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(106,137,247)\"],[.5,\"rgb(190,190,190)\"],[.6,\"rgb(220,170,132)\"],[.7,\"rgb(230,145,90)\"],[1,\"rgb(178,10,28)\"]],Reds:[[0,\"rgb(220,220,220)\"],[.2,\"rgb(245,195,157)\"],[.4,\"rgb(245,160,105)\"],[1,\"rgb(178,10,28)\"]],Blues:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(40,60,190)\"],[.5,\"rgb(70,100,245)\"],[.6,\"rgb(90,120,245)\"],[.7,\"rgb(106,137,247)\"],[1,\"rgb(220,220,220)\"]],Picnic:[[0,\"rgb(0,0,255)\"],[.1,\"rgb(51,153,255)\"],[.2,\"rgb(102,204,255)\"],[.3,\"rgb(153,204,255)\"],[.4,\"rgb(204,204,255)\"],[.5,\"rgb(255,255,255)\"],[.6,\"rgb(255,204,255)\"],[.7,\"rgb(255,153,255)\"],[.8,\"rgb(255,102,204)\"],[.9,\"rgb(255,102,102)\"],[1,\"rgb(255,0,0)\"]],Rainbow:[[0,\"rgb(150,0,90)\"],[.125,\"rgb(0,0,200)\"],[.25,\"rgb(0,25,255)\"],[.375,\"rgb(0,152,255)\"],[.5,\"rgb(44,255,150)\"],[.625,\"rgb(151,255,0)\"],[.75,\"rgb(255,234,0)\"],[.875,\"rgb(255,111,0)\"],[1,\"rgb(255,0,0)\"]],Portland:[[0,\"rgb(12,51,131)\"],[.25,\"rgb(10,136,186)\"],[.5,\"rgb(242,211,56)\"],[.75,\"rgb(242,143,56)\"],[1,\"rgb(217,30,30)\"]],Jet:[[0,\"rgb(0,0,131)\"],[.125,\"rgb(0,60,170)\"],[.375,\"rgb(5,255,255)\"],[.625,\"rgb(255,255,0)\"],[.875,\"rgb(250,0,0)\"],[1,\"rgb(128,0,0)\"]],Hot:[[0,\"rgb(0,0,0)\"],[.3,\"rgb(230,0,0)\"],[.6,\"rgb(255,210,0)\"],[1,\"rgb(255,255,255)\"]],Blackbody:[[0,\"rgb(0,0,0)\"],[.2,\"rgb(230,0,0)\"],[.4,\"rgb(230,210,0)\"],[.7,\"rgb(255,255,255)\"],[1,\"rgb(160,200,255)\"]],Earth:[[0,\"rgb(0,0,130)\"],[.1,\"rgb(0,180,180)\"],[.2,\"rgb(40,210,40)\"],[.4,\"rgb(230,230,50)\"],[.6,\"rgb(120,70,20)\"],[1,\"rgb(255,255,255)\"]],Electric:[[0,\"rgb(0,0,0)\"],[.15,\"rgb(30,0,100)\"],[.4,\"rgb(120,0,100)\"],[.6,\"rgb(160,90,0)\"],[.8,\"rgb(230,200,0)\"],[1,\"rgb(255,250,220)\"]],Viridis:[[0,\"#440154\"],[.06274509803921569,\"#48186a\"],[.12549019607843137,\"#472d7b\"],[.18823529411764706,\"#424086\"],[.25098039215686274,\"#3b528b\"],[.3137254901960784,\"#33638d\"],[.3764705882352941,\"#2c728e\"],[.4392156862745098,\"#26828e\"],[.5019607843137255,\"#21918c\"],[.5647058823529412,\"#1fa088\"],[.6274509803921569,\"#28ae80\"],[.6901960784313725,\"#3fbc73\"],[.7529411764705882,\"#5ec962\"],[.8156862745098039,\"#84d44b\"],[.8784313725490196,\"#addc30\"],[.9411764705882353,\"#d8e219\"],[1,\"#fde725\"]],Cividis:[[0,\"rgb(0,32,76)\"],[.058824,\"rgb(0,42,102)\"],[.117647,\"rgb(0,52,110)\"],[.176471,\"rgb(39,63,108)\"],[.235294,\"rgb(60,74,107)\"],[.294118,\"rgb(76,85,107)\"],[.352941,\"rgb(91,95,109)\"],[.411765,\"rgb(104,106,112)\"],[.470588,\"rgb(117,117,117)\"],[.529412,\"rgb(131,129,120)\"],[.588235,\"rgb(146,140,120)\"],[.647059,\"rgb(161,152,118)\"],[.705882,\"rgb(176,165,114)\"],[.764706,\"rgb(192,177,109)\"],[.823529,\"rgb(209,191,102)\"],[.882353,\"rgb(225,204,92)\"],[.941176,\"rgb(243,219,79)\"],[1,\"rgb(255,233,69)\"]]},a=i.RdBu;function o(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var i=t[r];if(2!==i.length||+i[0]<e||!n(i[1]).isValid())return!1;e=+i[0]}return!0}e.exports={scales:i,defaultScale:a,get:function(t,e){if(e||(e=a),!t)return e;function r(){try{t=i[t]||JSON.parse(t)}catch(r){t=e}}return\"string\"==typeof t&&(r(),\"string\"==typeof t&&r()),o(t)?t:e},isValid:function(t){return void 0!==i[t]||o(t)}}},{tinycolor2:537}],609:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=(t-r)/(n-r),o=a+e/(n-r),s=(a+o)/2;return\"left\"===i||\"bottom\"===i?a:\"center\"===i||\"middle\"===i?s:\"right\"===i||\"top\"===i?o:a<2/3-s?a:o>4/3-s?o:s}},{}],610:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[\"sw-resize\",\"s-resize\",\"se-resize\"],[\"w-resize\",\"move\",\"e-resize\"],[\"nw-resize\",\"n-resize\",\"ne-resize\"]];e.exports=function(t,e,r,a){return t=\"left\"===r?0:\"center\"===r?1:\"right\"===r?2:n.constrain(Math.floor(3*t),0,2),e=\"bottom\"===a?0:\"middle\"===a?1:\"top\"===a?2:n.constrain(Math.floor(3*e),0,2),i[e][t]}},{\"../../lib\":719}],611:[function(t,e,r){\"use strict\";var n=t(\"mouse-event-offset\"),i=t(\"has-hover\"),a=t(\"has-passive-events\"),o=t(\"../../lib\").removeElement,s=t(\"../../plots/cartesian/constants\"),l=e.exports={};l.align=t(\"./align\"),l.getCursor=t(\"./cursor\");var c=t(\"./unhover\");function u(){var t=document.createElement(\"div\");t.className=\"dragcover\";var e=t.style;return e.position=\"fixed\",e.left=0,e.right=0,e.top=0,e.bottom=0,e.zIndex=999999999,e.background=\"none\",document.body.appendChild(t),t}function h(t){return n(t.changedTouches?t.changedTouches[0]:t,document.body)}l.unhover=c.wrapped,l.unhoverRaw=c.raw,l.init=function(t){var e,r,n,c,f,p,d,g,v=t.gd,m=1,y=v._context.doubleClickDelay,x=t.element;v._mouseDownTime||(v._mouseDownTime=0),x.style.pointerEvents=\"all\",x.onmousedown=_,a?(x._ontouchstart&&x.removeEventListener(\"touchstart\",x._ontouchstart),x._ontouchstart=_,x.addEventListener(\"touchstart\",_,{passive:!1})):x.ontouchstart=_;var b=t.clampFn||function(t,e,r){return Math.abs(t)<r&&(t=0),Math.abs(e)<r&&(e=0),[t,e]};function _(a){v._dragged=!1,v._dragging=!0;var o=h(a);e=o[0],r=o[1],d=a.target,p=a,g=2===a.buttons||a.ctrlKey,\"undefined\"==typeof a.clientX&&\"undefined\"==typeof a.clientY&&(a.clientX=e,a.clientY=r),(n=(new Date).getTime())-v._mouseDownTime<y?m+=1:(m=1,v._mouseDownTime=n),t.prepFn&&t.prepFn(a,e,r),i&&!g?(f=u()).style.cursor=window.getComputedStyle(x).cursor:i||(f=document,c=window.getComputedStyle(document.documentElement).cursor,document.documentElement.style.cursor=window.getComputedStyle(x).cursor),document.addEventListener(\"mouseup\",k),document.addEventListener(\"touchend\",k),!1!==t.dragmode&&(a.preventDefault(),document.addEventListener(\"mousemove\",w),document.addEventListener(\"touchmove\",w))}function w(n){n.preventDefault();var i=h(n),a=t.minDrag||s.MINDRAG,o=b(i[0]-e,i[1]-r,a),c=o[0],u=o[1];(c||u)&&(v._dragged=!0,l.unhover(v)),v._dragged&&t.moveFn&&!g&&(v._dragdata={element:x,dx:c,dy:u},t.moveFn(c,u))}function k(e){if(delete v._dragdata,!1!==t.dragmode&&(e.preventDefault(),document.removeEventListener(\"mousemove\",w),document.removeEventListener(\"touchmove\",w)),document.removeEventListener(\"mouseup\",k),document.removeEventListener(\"touchend\",k),i?o(f):c&&(f.documentElement.style.cursor=c,c=null),v._dragging){if(v._dragging=!1,(new Date).getTime()-v._mouseDownTime>y&&(m=Math.max(m-1,1)),v._dragged)t.doneFn&&t.doneFn();else if(t.clickFn&&t.clickFn(m,p),!g){var r;try{r=new MouseEvent(\"click\",e)}catch(t){var n=h(e);(r=document.createEvent(\"MouseEvents\")).initMouseEvent(\"click\",e.bubbles,e.cancelable,e.view,e.detail,e.screenX,e.screenY,n[0],n[1],e.ctrlKey,e.altKey,e.shiftKey,e.metaKey,e.button,e.relatedTarget)}d.dispatchEvent(r)}v._dragging=!1,v._dragged=!1}else v._dragged=!1}},l.coverSlip=u},{\"../../lib\":719,\"../../plots/cartesian/constants\":773,\"./align\":609,\"./cursor\":610,\"./unhover\":612,\"has-hover\":410,\"has-passive-events\":411,\"mouse-event-offset\":436}],612:[function(t,e,r){\"use strict\";var n=t(\"../../lib/events\"),i=t(\"../../lib/throttle\"),a=t(\"../../lib/dom\").getGraphDiv,o=t(\"../fx/constants\"),s=e.exports={};s.wrapped=function(t,e,r){(t=a(t))._fullLayout&&i.clear(t._fullLayout._uid+o.HOVERID),s.raw(t,e,r)},s.raw=function(t,e){var r=t._fullLayout,i=t._hoverdata;e||(e={}),e.target&&!1===n.triggerHandler(t,\"plotly_beforehover\",e)||(r._hoverlayer.selectAll(\"g\").remove(),r._hoverlayer.selectAll(\"line\").remove(),r._hoverlayer.selectAll(\"circle\").remove(),t._hoverdata=void 0,e.target&&i&&t.emit(\"plotly_unhover\",{event:e,points:i}))}},{\"../../lib/dom\":708,\"../../lib/events\":709,\"../../lib/throttle\":744,\"../fx/constants\":626}],613:[function(t,e,r){\"use strict\";r.dash={valType:\"string\",values:[\"solid\",\"dot\",\"dash\",\"longdash\",\"dashdot\",\"longdashdot\"],dflt:\"solid\",editType:\"style\"}},{}],614:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../registry\"),s=t(\"../color\"),l=t(\"../colorscale\"),c=t(\"../../lib\"),u=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/xmlns_namespaces\"),f=t(\"../../constants/alignment\").LINE_SPACING,p=t(\"../../constants/interactions\").DESELECTDIM,d=t(\"../../traces/scatter/subtypes\"),g=t(\"../../traces/scatter/make_bubble_size_func\"),v=e.exports={};v.font=function(t,e,r,n){c.isPlainObject(e)&&(n=e.color,r=e.size,e=e.family),e&&t.style(\"font-family\",e),r+1&&t.style(\"font-size\",r+\"px\"),n&&t.call(s.fill,n)},v.setPosition=function(t,e,r){t.attr(\"x\",e).attr(\"y\",r)},v.setSize=function(t,e,r){t.attr(\"width\",e).attr(\"height\",r)},v.setRect=function(t,e,r,n,i){t.call(v.setPosition,e,r).call(v.setSize,n,i)},v.translatePoint=function(t,e,r,n){var a=r.c2p(t.x),o=n.c2p(t.y);return!!(i(a)&&i(o)&&e.node())&&(\"text\"===e.node().nodeName?e.attr(\"x\",a).attr(\"y\",o):e.attr(\"transform\",\"translate(\"+a+\",\"+o+\")\"),!0)},v.translatePoints=function(t,e,r){t.each(function(t){var i=n.select(this);v.translatePoint(t,i,e,r)})},v.hideOutsideRangePoint=function(t,e,r,n,i,a){e.attr(\"display\",r.isPtWithinRange(t,i)&&n.isPtWithinRange(t,a)?null:\"none\")},v.hideOutsideRangePoints=function(t,e){if(e._hasClipOnAxisFalse){var r=e.xaxis,i=e.yaxis;t.each(function(e){var a=e[0].trace,s=a.xcalendar,l=a.ycalendar,c=o.traceIs(a,\"bar-like\")?\".bartext\":\".point,.textpoint\";t.selectAll(c).each(function(t){v.hideOutsideRangePoint(t,n.select(this),r,i,s,l)})})}},v.crispRound=function(t,e,r){return e&&i(e)?t._context.staticPlot?e:e<1?1:Math.round(e):r||0},v.singleLineStyle=function(t,e,r,n,i){e.style(\"fill\",\"none\");var a=(((t||[])[0]||{}).trace||{}).line||{},o=r||a.width||0,l=i||a.dash||\"\";s.stroke(e,n||a.color),v.dashLine(e,l,o)},v.lineGroupStyle=function(t,e,r,i){t.style(\"fill\",\"none\").each(function(t){var a=(((t||[])[0]||{}).trace||{}).line||{},o=e||a.width||0,l=i||a.dash||\"\";n.select(this).call(s.stroke,r||a.color).call(v.dashLine,l,o)})},v.dashLine=function(t,e,r){r=+r||0,e=v.dashStyle(e,r),t.style({\"stroke-dasharray\":e,\"stroke-width\":r+\"px\"})},v.dashStyle=function(t,e){e=+e||1;var r=Math.max(e,3);return\"solid\"===t?t=\"\":\"dot\"===t?t=r+\"px,\"+r+\"px\":\"dash\"===t?t=3*r+\"px,\"+3*r+\"px\":\"longdash\"===t?t=5*r+\"px,\"+5*r+\"px\":\"dashdot\"===t?t=3*r+\"px,\"+r+\"px,\"+r+\"px,\"+r+\"px\":\"longdashdot\"===t&&(t=5*r+\"px,\"+2*r+\"px,\"+r+\"px,\"+2*r+\"px\"),t},v.singleFillStyle=function(t){var e=(((n.select(t.node()).data()[0]||[])[0]||{}).trace||{}).fillcolor;e&&t.call(s.fill,e)},v.fillGroupStyle=function(t){t.style(\"stroke-width\",0).each(function(t){var e=n.select(this);t[0].trace&&e.call(s.fill,t[0].trace.fillcolor)})};var m=t(\"./symbol_defs\");v.symbolNames=[],v.symbolFuncs=[],v.symbolNeedLines={},v.symbolNoDot={},v.symbolNoFill={},v.symbolList=[],Object.keys(m).forEach(function(t){var e=m[t];v.symbolList=v.symbolList.concat([e.n,t,e.n+100,t+\"-open\"]),v.symbolNames[e.n]=t,v.symbolFuncs[e.n]=e.f,e.needLine&&(v.symbolNeedLines[e.n]=!0),e.noDot?v.symbolNoDot[e.n]=!0:v.symbolList=v.symbolList.concat([e.n+200,t+\"-dot\",e.n+300,t+\"-open-dot\"]),e.noFill&&(v.symbolNoFill[e.n]=!0)});var y=v.symbolNames.length,x=\"M0,0.5L0.5,0L0,-0.5L-0.5,0Z\";function b(t,e){var r=t%100;return v.symbolFuncs[r](e)+(t>=200?x:\"\")}v.symbolNumber=function(t){if(\"string\"==typeof t){var e=0;t.indexOf(\"-open\")>0&&(e=100,t=t.replace(\"-open\",\"\")),t.indexOf(\"-dot\")>0&&(e+=200,t=t.replace(\"-dot\",\"\")),(t=v.symbolNames.indexOf(t))>=0&&(t+=e)}return t%100>=y||t>=400?0:Math.floor(Math.max(t,0))};var _={x1:1,x2:0,y1:0,y2:0},w={x1:0,x2:0,y1:1,y2:0},k=n.format(\"~.1f\"),T={radial:{node:\"radialGradient\"},radialreversed:{node:\"radialGradient\",reversed:!0},horizontal:{node:\"linearGradient\",attrs:_},horizontalreversed:{node:\"linearGradient\",attrs:_,reversed:!0},vertical:{node:\"linearGradient\",attrs:w},verticalreversed:{node:\"linearGradient\",attrs:w,reversed:!0}};v.gradient=function(t,e,r,i,o,l){for(var u=o.length,h=T[i],f=new Array(u),p=0;p<u;p++)h.reversed?f[u-1-p]=[k(100*(1-o[p][0])),o[p][1]]:f[p]=[k(100*o[p][0]),o[p][1]];var d=\"g\"+e._fullLayout._uid+\"-\"+r,g=e._fullLayout._defs.select(\".gradients\").selectAll(\"#\"+d).data([i+f.join(\";\")],c.identity);g.exit().remove(),g.enter().append(h.node).each(function(){var t=n.select(this);h.attrs&&t.attr(h.attrs),t.attr(\"id\",d);var e=t.selectAll(\"stop\").data(f);e.exit().remove(),e.enter().append(\"stop\"),e.each(function(t){var e=a(t[1]);n.select(this).attr({offset:t[0]+\"%\",\"stop-color\":s.tinyRGB(e),\"stop-opacity\":e.getAlpha()})})}),t.style(l,I(d,e)).style(l+\"-opacity\",null)},v.initGradients=function(t){c.ensureSingle(t._fullLayout._defs,\"g\",\"gradients\").selectAll(\"linearGradient,radialGradient\").remove()},v.pointStyle=function(t,e,r){if(t.size()){var i=v.makePointStyleFns(e);t.each(function(t){v.singlePointStyle(t,n.select(this),e,i,r)})}},v.singlePointStyle=function(t,e,r,n,i){var a=r.marker,o=a.line;if(e.style(\"opacity\",n.selectedOpacityFn?n.selectedOpacityFn(t):void 0===t.mo?a.opacity:t.mo),n.ms2mrc){var l;l=\"various\"===t.ms||\"various\"===a.size?3:n.ms2mrc(t.ms),t.mrc=l,n.selectedSizeFn&&(l=t.mrc=n.selectedSizeFn(t));var u=v.symbolNumber(t.mx||a.symbol)||0;t.om=u%200>=100,e.attr(\"d\",b(u,l))}var h,f,p,d=!1;if(t.so)p=o.outlierwidth,f=o.outliercolor,h=a.outliercolor;else{var g=(o||{}).width;p=(t.mlw+1||g+1||(t.trace?(t.trace.marker.line||{}).width:0)+1)-1||0,f=\"mlc\"in t?t.mlcc=n.lineScale(t.mlc):c.isArrayOrTypedArray(o.color)?s.defaultLine:o.color,c.isArrayOrTypedArray(a.color)&&(h=s.defaultLine,d=!0),h=\"mc\"in t?t.mcc=n.markerScale(t.mc):a.color||\"rgba(0,0,0,0)\",n.selectedColorFn&&(h=n.selectedColorFn(t))}if(t.om)e.call(s.stroke,h).style({\"stroke-width\":(p||1)+\"px\",fill:\"none\"});else{e.style(\"stroke-width\",p+\"px\");var m=a.gradient,y=t.mgt;if(y?d=!0:y=m&&m.type,Array.isArray(y)&&(y=y[0],T[y]||(y=0)),y&&\"none\"!==y){var x=t.mgc;x?d=!0:x=m.color;var _=r.uid;d&&(_+=\"-\"+t.i),v.gradient(e,i,_,y,[[0,x],[1,h]],\"fill\")}else s.fill(e,h);p&&s.stroke(e,f)}},v.makePointStyleFns=function(t){var e={},r=t.marker;return e.markerScale=v.tryColorscale(r,\"\"),e.lineScale=v.tryColorscale(r,\"line\"),o.traceIs(t,\"symbols\")&&(e.ms2mrc=d.isBubble(t)?g(t):function(){return(r.size||6)/2}),t.selectedpoints&&c.extendFlat(e,v.makeSelectedPointStyleFns(t)),e},v.makeSelectedPointStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.marker||{},a=r.marker||{},s=n.marker||{},l=i.opacity,u=a.opacity,h=s.opacity,f=void 0!==u,d=void 0!==h;(c.isArrayOrTypedArray(l)||f||d)&&(e.selectedOpacityFn=function(t){var e=void 0===t.mo?i.opacity:t.mo;return t.selected?f?u:e:d?h:p*e});var g=i.color,v=a.color,m=s.color;(v||m)&&(e.selectedColorFn=function(t){var e=t.mcc||g;return t.selected?v||e:m||e});var y=i.size,x=a.size,b=s.size,_=void 0!==x,w=void 0!==b;return o.traceIs(t,\"symbols\")&&(_||w)&&(e.selectedSizeFn=function(t){var e=t.mrc||y/2;return t.selected?_?x/2:e:w?b/2:e}),e},v.makeSelectedTextStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.textfont||{},a=r.textfont||{},o=n.textfont||{},l=i.color,c=a.color,u=o.color;return e.selectedTextColorFn=function(t){var e=t.tc||l;return t.selected?c||e:u||(c?e:s.addOpacity(e,p))},e},v.selectedPointStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=v.makeSelectedPointStyleFns(e),i=e.marker||{},a=[];r.selectedOpacityFn&&a.push(function(t,e){t.style(\"opacity\",r.selectedOpacityFn(e))}),r.selectedColorFn&&a.push(function(t,e){s.fill(t,r.selectedColorFn(e))}),r.selectedSizeFn&&a.push(function(t,e){var n=e.mx||i.symbol||0,a=r.selectedSizeFn(e);t.attr(\"d\",b(v.symbolNumber(n),a)),e.mrc2=a}),a.length&&t.each(function(t){for(var e=n.select(this),r=0;r<a.length;r++)a[r](e,t)})}},v.tryColorscale=function(t,e){var r=e?c.nestedProperty(t,e).get():t;if(r){var n=r.color;if((r.colorscale||r._colorAx)&&c.isArrayOrTypedArray(n))return l.makeColorScaleFuncFromTrace(r)}return c.identity};var A={start:1,end:-1,middle:0,bottom:1,top:-1};function M(t,e,r,i){var a=n.select(t.node().parentNode),o=-1!==e.indexOf(\"top\")?\"top\":-1!==e.indexOf(\"bottom\")?\"bottom\":\"middle\",s=-1!==e.indexOf(\"left\")?\"end\":-1!==e.indexOf(\"right\")?\"start\":\"middle\",l=i?i/.8+1:0,c=(u.lineCount(t)-1)*f+1,h=A[s]*l,p=.75*r+A[o]*l+(A[o]-1)*c*r/2;t.attr(\"text-anchor\",s),a.attr(\"transform\",\"translate(\"+h+\",\"+p+\")\")}function S(t,e){var r=t.ts||e.textfont.size;return i(r)&&r>0?r:0}v.textPointStyle=function(t,e,r){if(t.size()){var i;if(e.selectedpoints){var a=v.makeSelectedTextStyleFns(e);i=a.selectedTextColorFn}t.each(function(t){var a=n.select(this),o=c.extractOption(t,e,\"tx\",\"text\");if(o||0===o){var s=t.tp||e.textposition,l=S(t,e),h=i?i(t):t.tc||e.textfont.color;a.call(v.font,t.tf||e.textfont.family,l,h).text(o).call(u.convertToTspans,r).call(M,s,l,t.mrc)}else a.remove()})}},v.selectedTextStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=v.makeSelectedTextStyleFns(e);t.each(function(t){var i=n.select(this),a=r.selectedTextColorFn(t),o=t.tp||e.textposition,l=S(t,e);s.fill(i,a),M(i,o,l,t.mrc2||t.mrc)})}};var E=.5;function C(t,e,r,i){var a=t[0]-e[0],o=t[1]-e[1],s=r[0]-e[0],l=r[1]-e[1],c=Math.pow(a*a+o*o,E/2),u=Math.pow(s*s+l*l,E/2),h=(u*u*a-c*c*s)*i,f=(u*u*o-c*c*l)*i,p=3*u*(c+u),d=3*c*(c+u);return[[n.round(e[0]+(p&&h/p),2),n.round(e[1]+(p&&f/p),2)],[n.round(e[0]-(d&&h/d),2),n.round(e[1]-(d&&f/d),2)]]}v.smoothopen=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\");var r,n=\"M\"+t[0],i=[];for(r=1;r<t.length-1;r++)i.push(C(t[r-1],t[r],t[r+1],e));for(n+=\"Q\"+i[0][0]+\" \"+t[1],r=2;r<t.length-1;r++)n+=\"C\"+i[r-2][1]+\" \"+i[r-1][0]+\" \"+t[r];return n+=\"Q\"+i[t.length-3][1]+\" \"+t[t.length-1]},v.smoothclosed=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\")+\"Z\";var r,n=\"M\"+t[0],i=t.length-1,a=[C(t[i],t[0],t[1],e)];for(r=1;r<i;r++)a.push(C(t[r-1],t[r],t[r+1],e));for(a.push(C(t[i-1],t[i],t[0],e)),r=1;r<=i;r++)n+=\"C\"+a[r-1][1]+\" \"+a[r][0]+\" \"+t[r];return n+=\"C\"+a[i][1]+\" \"+a[0][0]+\" \"+t[0]+\"Z\"};var L={hv:function(t,e){return\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)},vh:function(t,e){return\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},hvh:function(t,e){return\"H\"+n.round((t[0]+e[0])/2,2)+\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},vhv:function(t,e){return\"V\"+n.round((t[1]+e[1])/2,2)+\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)}},P=function(t,e){return\"L\"+n.round(e[0],2)+\",\"+n.round(e[1],2)};v.steps=function(t){var e=L[t]||P;return function(t){for(var r=\"M\"+n.round(t[0][0],2)+\",\"+n.round(t[0][1],2),i=1;i<t.length;i++)r+=e(t[i-1],t[i]);return r}},v.makeTester=function(){var t=c.ensureSingleById(n.select(\"body\"),\"svg\",\"js-plotly-tester\",function(t){t.attr(h.svgAttrs).style({position:\"absolute\",left:\"-10000px\",top:\"-10000px\",width:\"9000px\",height:\"9000px\",\"z-index\":\"1\"})}),e=c.ensureSingle(t,\"path\",\"js-reference-point\",function(t){t.attr(\"d\",\"M0,0H1V1H0Z\").style({\"stroke-width\":0,fill:\"black\"})});v.tester=t,v.testref=e},v.savedBBoxes={};var O=0;function z(t){var e=t.getAttribute(\"data-unformatted\");if(null!==e)return e+t.getAttribute(\"data-math\")+t.getAttribute(\"text-anchor\")+t.getAttribute(\"style\")}function I(t,e){if(!t)return null;var r=e._context;return\"url('\"+(r._exportedPlot?\"\":r._baseUrl||\"\")+\"#\"+t+\"')\"}v.bBox=function(t,e,r){var i,a,o;if(r||(r=z(t)),r){if(i=v.savedBBoxes[r])return c.extendFlat({},i)}else if(1===t.childNodes.length){var s=t.childNodes[0];if(r=z(s)){var l=+s.getAttribute(\"x\")||0,h=+s.getAttribute(\"y\")||0,f=s.getAttribute(\"transform\");if(!f){var p=v.bBox(s,!1,r);return l&&(p.left+=l,p.right+=l),h&&(p.top+=h,p.bottom+=h),p}if(r+=\"~\"+l+\"~\"+h+\"~\"+f,i=v.savedBBoxes[r])return c.extendFlat({},i)}}e?a=t:(o=v.tester.node(),a=t.cloneNode(!0),o.appendChild(a)),n.select(a).attr(\"transform\",null).call(u.positionText,0,0);var d=a.getBoundingClientRect(),g=v.testref.node().getBoundingClientRect();e||o.removeChild(a);var m={height:d.height,width:d.width,left:d.left-g.left,top:d.top-g.top,right:d.right-g.left,bottom:d.bottom-g.top};return O>=1e4&&(v.savedBBoxes={},O=0),r&&(v.savedBBoxes[r]=m),O++,c.extendFlat({},m)},v.setClipUrl=function(t,e,r){t.attr(\"clip-path\",I(e,r))},v.getTranslate=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\btranslate\\((-?\\d*\\.?\\d*)[^-\\d]*(-?\\d*\\.?\\d*)[^\\d].*/,function(t,e,r){return[e,r].join(\" \")}).split(\" \");return{x:+e[0]||0,y:+e[1]||0}},v.setTranslate=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||0,r=r||0,a=a.replace(/(\\btranslate\\(.*?\\);?)/,\"\").trim(),a=(a+=\" translate(\"+e+\", \"+r+\")\").trim(),t[i](\"transform\",a),a},v.getScale=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\bscale\\((\\d*\\.?\\d*)[^\\d]*(\\d*\\.?\\d*)[^\\d].*/,function(t,e,r){return[e,r].join(\" \")}).split(\" \");return{x:+e[0]||1,y:+e[1]||1}},v.setScale=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||1,r=r||1,a=a.replace(/(\\bscale\\(.*?\\);?)/,\"\").trim(),a=(a+=\" scale(\"+e+\", \"+r+\")\").trim(),t[i](\"transform\",a),a};var D=/\\s*sc.*/;v.setPointGroupScale=function(t,e,r){if(e=e||1,r=r||1,t){var n=1===e&&1===r?\"\":\" scale(\"+e+\",\"+r+\")\";t.each(function(){var t=(this.getAttribute(\"transform\")||\"\").replace(D,\"\");t=(t+=n).trim(),this.setAttribute(\"transform\",t)})}};var R=/translate\\([^)]*\\)\\s*$/;v.setTextPointsScale=function(t,e,r){t&&t.each(function(){var t,i=n.select(this),a=i.select(\"text\");if(a.node()){var o=parseFloat(a.attr(\"x\")||0),s=parseFloat(a.attr(\"y\")||0),l=(i.attr(\"transform\")||\"\").match(R);t=1===e&&1===r?[]:[\"translate(\"+o+\",\"+s+\")\",\"scale(\"+e+\",\"+r+\")\",\"translate(\"+-o+\",\"+-s+\")\"],l&&t.push(l),i.attr(\"transform\",t.join(\" \"))}})}},{\"../../constants/alignment\":688,\"../../constants/interactions\":694,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../registry\":847,\"../../traces/scatter/make_bubble_size_func\":1128,\"../../traces/scatter/subtypes\":1135,\"../color\":593,\"../colorscale\":605,\"./symbol_defs\":615,d3:163,\"fast-isnumeric\":225,tinycolor2:537}],615:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports={circle:{n:0,f:function(t){var e=n.round(t,2);return\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"}},square:{n:1,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"}},diamond:{n:2,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"Z\"}},cross:{n:3,f:function(t){var e=n.round(.4*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H\"+e+\"V\"+r+\"H-\"+e+\"V\"+e+\"H-\"+r+\"V-\"+e+\"H-\"+e+\"V-\"+r+\"H\"+e+\"V-\"+e+\"H\"+r+\"Z\"}},x:{n:4,f:function(t){var e=n.round(.8*t/Math.sqrt(2),2),r=\"l\"+e+\",\"+e,i=\"l\"+e+\",-\"+e,a=\"l-\"+e+\",-\"+e,o=\"l-\"+e+\",\"+e;return\"M0,\"+e+r+i+a+i+a+o+a+o+r+o+r+\"Z\"}},\"triangle-up\":{n:5,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",\"+n.round(t/2,2)+\"H\"+e+\"L0,-\"+n.round(t,2)+\"Z\"}},\"triangle-down\":{n:6,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",-\"+n.round(t/2,2)+\"H\"+e+\"L0,\"+n.round(t,2)+\"Z\"}},\"triangle-left\":{n:7,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L-\"+n.round(t,2)+\",0Z\"}},\"triangle-right\":{n:8,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L\"+n.round(t,2)+\",0Z\"}},\"triangle-ne\":{n:9,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+r+\",-\"+e+\"H\"+e+\"V\"+r+\"Z\"}},\"triangle-se\":{n:10,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+e+\",-\"+r+\"V\"+e+\"H-\"+r+\"Z\"}},\"triangle-sw\":{n:11,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H-\"+e+\"V-\"+r+\"Z\"}},\"triangle-nw\":{n:12,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+e+\",\"+r+\"V-\"+e+\"H\"+r+\"Z\"}},pentagon:{n:13,f:function(t){var e=n.round(.951*t,2),r=n.round(.588*t,2),i=n.round(-t,2),a=n.round(-.309*t,2);return\"M\"+e+\",\"+a+\"L\"+r+\",\"+n.round(.809*t,2)+\"H-\"+r+\"L-\"+e+\",\"+a+\"L0,\"+i+\"Z\"}},hexagon:{n:14,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M\"+i+\",-\"+r+\"V\"+r+\"L0,\"+e+\"L-\"+i+\",\"+r+\"V-\"+r+\"L0,-\"+e+\"Z\"}},hexagon2:{n:15,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M-\"+r+\",\"+i+\"H\"+r+\"L\"+e+\",0L\"+r+\",-\"+i+\"H-\"+r+\"L-\"+e+\",0Z\"}},octagon:{n:16,f:function(t){var e=n.round(.924*t,2),r=n.round(.383*t,2);return\"M-\"+r+\",-\"+e+\"H\"+r+\"L\"+e+\",-\"+r+\"V\"+r+\"L\"+r+\",\"+e+\"H-\"+r+\"L-\"+e+\",\"+r+\"V-\"+r+\"Z\"}},star:{n:17,f:function(t){var e=1.4*t,r=n.round(.225*e,2),i=n.round(.951*e,2),a=n.round(.363*e,2),o=n.round(.588*e,2),s=n.round(-e,2),l=n.round(-.309*e,2),c=n.round(.118*e,2),u=n.round(.809*e,2);return\"M\"+r+\",\"+l+\"H\"+i+\"L\"+a+\",\"+c+\"L\"+o+\",\"+u+\"L0,\"+n.round(.382*e,2)+\"L-\"+o+\",\"+u+\"L-\"+a+\",\"+c+\"L-\"+i+\",\"+l+\"H-\"+r+\"L0,\"+s+\"Z\"}},hexagram:{n:18,f:function(t){var e=n.round(.66*t,2),r=n.round(.38*t,2),i=n.round(.76*t,2);return\"M-\"+i+\",0l-\"+r+\",-\"+e+\"h\"+i+\"l\"+r+\",-\"+e+\"l\"+r+\",\"+e+\"h\"+i+\"l-\"+r+\",\"+e+\"l\"+r+\",\"+e+\"h-\"+i+\"l-\"+r+\",\"+e+\"l-\"+r+\",-\"+e+\"h-\"+i+\"Z\"}},\"star-triangle-up\":{n:19,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M-\"+e+\",\"+r+o+e+\",\"+r+o+\"0,-\"+i+o+\"-\"+e+\",\"+r+\"Z\"}},\"star-triangle-down\":{n:20,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M\"+e+\",-\"+r+o+\"-\"+e+\",-\"+r+o+\"0,\"+i+o+e+\",-\"+r+\"Z\"}},\"star-square\":{n:21,f:function(t){var e=n.round(1.1*t,2),r=n.round(2*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",-\"+e+i+\"-\"+e+\",\"+e+i+e+\",\"+e+i+e+\",-\"+e+i+\"-\"+e+\",-\"+e+\"Z\"}},\"star-diamond\":{n:22,f:function(t){var e=n.round(1.4*t,2),r=n.round(1.9*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",0\"+i+\"0,\"+e+i+e+\",0\"+i+\"0,-\"+e+i+\"-\"+e+\",0Z\"}},\"diamond-tall\":{n:23,f:function(t){var e=n.round(.7*t,2),r=n.round(1.4*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},\"diamond-wide\":{n:24,f:function(t){var e=n.round(1.4*t,2),r=n.round(.7*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},hourglass:{n:25,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"L\"+e+\",-\"+e+\"H-\"+e+\"Z\"},noDot:!0},bowtie:{n:26,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"V-\"+e+\"L-\"+e+\",\"+e+\"V-\"+e+\"Z\"},noDot:!0},\"circle-cross\":{n:27,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"circle-x\":{n:28,f:function(t){var e=n.round(t,2),r=n.round(t/Math.sqrt(2),2);return\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"square-cross\":{n:29,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"square-x\":{n:30,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"diamond-cross\":{n:31,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM0,-\"+e+\"V\"+e+\"M-\"+e+\",0H\"+e},needLine:!0,noDot:!0},\"diamond-x\":{n:32,f:function(t){var e=n.round(1.3*t,2),r=n.round(.65*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM-\"+r+\",-\"+r+\"L\"+r+\",\"+r+\"M-\"+r+\",\"+r+\"L\"+r+\",-\"+r},needLine:!0,noDot:!0},\"cross-thin\":{n:33,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"x-thin\":{n:34,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},asterisk:{n:35,f:function(t){var e=n.round(1.2*t,2),r=n.round(.85*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r},needLine:!0,noDot:!0,noFill:!0},hash:{n:36,f:function(t){var e=n.round(t/2,2),r=n.round(t,2);return\"M\"+e+\",\"+r+\"V-\"+r+\"m-\"+r+\",0V\"+r+\"M\"+r+\",\"+e+\"H-\"+r+\"m0,-\"+r+\"H\"+r},needLine:!0,noFill:!0},\"y-up\":{n:37,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",\"+i+\"L0,0M\"+e+\",\"+i+\"L0,0M0,-\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-down\":{n:38,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",-\"+i+\"L0,0M\"+e+\",-\"+i+\"L0,0M0,\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-left\":{n:39,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M\"+i+\",\"+e+\"L0,0M\"+i+\",-\"+e+\"L0,0M-\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-right\":{n:40,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+i+\",\"+e+\"L0,0M-\"+i+\",-\"+e+\"L0,0M\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"line-ew\":{n:41,f:function(t){var e=n.round(1.4*t,2);return\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ns\":{n:42,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ne\":{n:43,f:function(t){var e=n.round(t,2);return\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-nw\":{n:44,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e},needLine:!0,noDot:!0,noFill:!0}}},{d3:163}],616:[function(t,e,r){\"use strict\";e.exports={visible:{valType:\"boolean\",editType:\"calc\"},type:{valType:\"enumerated\",values:[\"percent\",\"constant\",\"sqrt\",\"data\"],editType:\"calc\"},symmetric:{valType:\"boolean\",editType:\"calc\"},array:{valType:\"data_array\",editType:\"calc\"},arrayminus:{valType:\"data_array\",editType:\"calc\"},value:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},valueminus:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},traceref:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},tracerefminus:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},copy_ystyle:{valType:\"boolean\",editType:\"plot\"},copy_zstyle:{valType:\"boolean\",editType:\"style\"},color:{valType:\"color\",editType:\"style\"},thickness:{valType:\"number\",min:0,dflt:2,editType:\"style\"},width:{valType:\"number\",min:0,editType:\"plot\"},editType:\"calc\",_deprecated:{opacity:{valType:\"number\",editType:\"style\"}}}},{}],617:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=t(\"./compute_error\");function l(t,e,r,i){var l=e[\"error_\"+i]||{},c=[];if(l.visible&&-1!==[\"linear\",\"log\"].indexOf(r.type)){for(var u=s(l),h=0;h<t.length;h++){var f=t[h],p=f.i;if(void 0===p)p=h;else if(null===p)continue;var d=f[i];if(n(r.c2l(d))){var g=u(d,p);if(n(g[0])&&n(g[1])){var v=f[i+\"s\"]=d-g[0],m=f[i+\"h\"]=d+g[1];c.push(v,m)}}}var y=r._id,x=e._extremes[y],b=a.findExtremes(r,c,o.extendFlat({tozero:x.opts.tozero},{padded:!0}));x.min=x.min.concat(b.min),x.max=x.max.concat(b.max)}}e.exports=function(t){for(var e=t.calcdata,r=0;r<e.length;r++){var n=e[r],o=n[0].trace;if(!0===o.visible&&i.traceIs(o,\"errorBarsOK\")){var s=a.getFromId(t,o.xaxis),c=a.getFromId(t,o.yaxis);l(n,o,s,\"x\"),l(n,o,c,\"y\")}}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./compute_error\":618,\"fast-isnumeric\":225}],618:[function(t,e,r){\"use strict\";function n(t,e){return\"percent\"===t?function(t){return Math.abs(t*e/100)}:\"constant\"===t?function(){return Math.abs(e)}:\"sqrt\"===t?function(t){return Math.sqrt(Math.abs(t))}:void 0}e.exports=function(t){var e=t.type,r=t.symmetric;if(\"data\"===e){var i=t.array||[];if(r)return function(t,e){var r=+i[e];return[r,r]};var a=t.arrayminus||[];return function(t,e){var r=+i[e],n=+a[e];return isNaN(r)&&isNaN(n)?[NaN,NaN]:[n||0,r||0]}}var o=n(e,t.value),s=n(e,t.valueminus);return r||void 0===t.valueminus?function(t){var e=o(t);return[e,e]}:function(t){return[s(t),o(t)]}}},{}],619:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../plot_api/plot_template\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){var c=\"error_\"+l.axis,u=o.newContainer(e,c),h=t[c]||{};function f(t,e){return a.coerce(h,u,s,t,e)}if(!1!==f(\"visible\",void 0!==h.array||void 0!==h.value||\"sqrt\"===h.type)){var p=f(\"type\",\"array\"in h?\"data\":\"percent\"),d=!0;\"sqrt\"!==p&&(d=f(\"symmetric\",!((\"data\"===p?\"arrayminus\":\"valueminus\")in h))),\"data\"===p?(f(\"array\"),f(\"traceref\"),d||(f(\"arrayminus\"),f(\"tracerefminus\"))):\"percent\"!==p&&\"constant\"!==p||(f(\"value\"),d||f(\"valueminus\"));var g=\"copy_\"+l.inherit+\"style\";if(l.inherit)(e[\"error_\"+l.inherit]||{}).visible&&f(g,!(h.color||n(h.thickness)||n(h.width)));l.inherit&&u[g]||(f(\"color\",r),f(\"thickness\"),f(\"width\",i.traceIs(e,\"gl3d\")?0:4))}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../registry\":847,\"./attributes\":616,\"fast-isnumeric\":225}],620:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"./attributes\"),o={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a)};delete o.error_x.copy_zstyle,delete o.error_y.copy_zstyle,delete o.error_y.copy_ystyle;var s={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a),error_z:n.extendFlat({},a)};delete s.error_x.copy_ystyle,delete s.error_y.copy_ystyle,delete s.error_z.copy_ystyle,delete s.error_z.copy_zstyle,e.exports={moduleType:\"component\",name:\"errorbars\",schema:{traces:{scatter:o,bar:o,histogram:o,scatter3d:i(s,\"calc\",\"nested\"),scattergl:i(o,\"calc\",\"nested\")}},supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),makeComputeError:t(\"./compute_error\"),plot:t(\"./plot\"),style:t(\"./style\"),hoverInfo:function(t,e,r){(e.error_y||{}).visible&&(r.yerr=t.yh-t.y,e.error_y.symmetric||(r.yerrneg=t.y-t.ys));(e.error_x||{}).visible&&(r.xerr=t.xh-t.x,e.error_x.symmetric||(r.xerrneg=t.x-t.xs))}}},{\"../../lib\":719,\"../../plot_api/edit_types\":750,\"./attributes\":616,\"./calc\":617,\"./compute_error\":618,\"./defaults\":619,\"./plot\":621,\"./style\":622}],621:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../drawing\"),o=t(\"../../traces/scatter/subtypes\");e.exports=function(t,e,r,s){var l=r.xaxis,c=r.yaxis,u=s&&s.duration>0;e.each(function(e){var h,f=e[0].trace,p=f.error_x||{},d=f.error_y||{};f.ids&&(h=function(t){return t.id});var g=o.hasMarkers(f)&&f.marker.maxdisplayed>0;d.visible||p.visible||(e=[]);var v=n.select(this).selectAll(\"g.errorbar\").data(e,h);if(v.exit().remove(),e.length){p.visible||v.selectAll(\"path.xerror\").remove(),d.visible||v.selectAll(\"path.yerror\").remove(),v.style(\"opacity\",1);var m=v.enter().append(\"g\").classed(\"errorbar\",!0);u&&m.style(\"opacity\",0).transition().duration(s.duration).style(\"opacity\",1),a.setClipUrl(v,r.layerClipId,t),v.each(function(t){var e=n.select(this),r=function(t,e,r){var n={x:e.c2p(t.x),y:r.c2p(t.y)};void 0!==t.yh&&(n.yh=r.c2p(t.yh),n.ys=r.c2p(t.ys),i(n.ys)||(n.noYS=!0,n.ys=r.c2p(t.ys,!0)));void 0!==t.xh&&(n.xh=e.c2p(t.xh),n.xs=e.c2p(t.xs),i(n.xs)||(n.noXS=!0,n.xs=e.c2p(t.xs,!0)));return n}(t,l,c);if(!g||t.vis){var a,o=e.select(\"path.yerror\");if(d.visible&&i(r.x)&&i(r.yh)&&i(r.ys)){var h=d.width;a=\"M\"+(r.x-h)+\",\"+r.yh+\"h\"+2*h+\"m-\"+h+\",0V\"+r.ys,r.noYS||(a+=\"m-\"+h+\",0h\"+2*h),!o.size()?o=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"yerror\",!0):u&&(o=o.transition().duration(s.duration).ease(s.easing)),o.attr(\"d\",a)}else o.remove();var f=e.select(\"path.xerror\");if(p.visible&&i(r.y)&&i(r.xh)&&i(r.xs)){var v=(p.copy_ystyle?d:p).width;a=\"M\"+r.xh+\",\"+(r.y-v)+\"v\"+2*v+\"m0,-\"+v+\"H\"+r.xs,r.noXS||(a+=\"m0,-\"+v+\"v\"+2*v),!f.size()?f=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"xerror\",!0):u&&(f=f.transition().duration(s.duration).ease(s.easing)),f.attr(\"d\",a)}else f.remove()}})}})}},{\"../../traces/scatter/subtypes\":1135,\"../drawing\":614,d3:163,\"fast-isnumeric\":225}],622:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\");e.exports=function(t){t.each(function(t){var e=t[0].trace,r=e.error_y||{},a=e.error_x||{},o=n.select(this);o.selectAll(\"path.yerror\").style(\"stroke-width\",r.thickness+\"px\").call(i.stroke,r.color),a.copy_ystyle&&(a=r),o.selectAll(\"path.xerror\").style(\"stroke-width\",a.thickness+\"px\").call(i.stroke,a.color)})}},{\"../color\":593,d3:163}],623:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./layout_attributes\").hoverlabel,a=t(\"../../lib/extend\").extendFlat;e.exports={hoverlabel:{bgcolor:a({},i.bgcolor,{arrayOk:!0}),bordercolor:a({},i.bordercolor,{arrayOk:!0}),font:n({arrayOk:!0,editType:\"none\"}),align:a({},i.align,{arrayOk:!0}),namelength:a({},i.namelength,{arrayOk:!0}),editType:\"none\"}}},{\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"./layout_attributes\":633}],624:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");function a(t,e,r,i){i=i||n.identity,Array.isArray(t)&&(e[0][r]=i(t))}e.exports=function(t){var e=t.calcdata,r=t._fullLayout;function o(t){return function(e){return n.coerceHoverinfo({hoverinfo:e},{_module:t._module},r)}}for(var s=0;s<e.length;s++){var l=e[s],c=l[0].trace;if(!i.traceIs(c,\"pie-like\")){var u=i.traceIs(c,\"2dMap\")?a:n.fillArray;u(c.hoverinfo,l,\"hi\",o(c)),c.hovertemplate&&u(c.hovertemplate,l,\"ht\"),c.hoverlabel&&(u(c.hoverlabel.bgcolor,l,\"hbg\"),u(c.hoverlabel.bordercolor,l,\"hbc\"),u(c.hoverlabel.font.size,l,\"hts\"),u(c.hoverlabel.font.color,l,\"htc\"),u(c.hoverlabel.font.family,l,\"htf\"),u(c.hoverlabel.namelength,l,\"hnl\"),u(c.hoverlabel.align,l,\"hta\"))}}}},{\"../../lib\":719,\"../../registry\":847}],625:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./hover\").hover;e.exports=function(t,e,r){var a=n.getComponentMethod(\"annotations\",\"onClick\")(t,t._hoverdata);function o(){t.emit(\"plotly_click\",{points:t._hoverdata,event:e})}void 0!==r&&i(t,e,r,!0),t._hoverdata&&e&&e.target&&(a&&a.then?a.then(o):o(),e.stopImmediatePropagation&&e.stopImmediatePropagation())}},{\"../../registry\":847,\"./hover\":629}],626:[function(t,e,r){\"use strict\";e.exports={YANGLE:60,HOVERARROWSIZE:6,HOVERTEXTPAD:3,HOVERFONTSIZE:13,HOVERFONT:\"Arial, sans-serif\",HOVERMINTIME:50,HOVERID:\"-hover\"}},{}],627:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./hoverlabel_defaults\");e.exports=function(t,e,r,o){var s=n.extendFlat({},o.hoverlabel);e.hovertemplate&&(s.namelength=-1),a(t,e,function(r,a){return n.coerce(t,e,i,r,a)},s)}},{\"../../lib\":719,\"./attributes\":623,\"./hoverlabel_defaults\":630}],628:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");r.getSubplot=function(t){return t.subplot||t.xaxis+t.yaxis||t.geo},r.isTraceInSubplots=function(t,e){if(\"splom\"===t.type){for(var n=t.xaxes||[],i=t.yaxes||[],a=0;a<n.length;a++)for(var o=0;o<i.length;o++)if(-1!==e.indexOf(n[a]+i[o]))return!0;return!1}return-1!==e.indexOf(r.getSubplot(t))},r.flat=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=e;return r},r.p2c=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=t[n].p2c(e);return r},r.getDistanceFunction=function(t,e,n,i){return\"closest\"===t?i||r.quadrature(e,n):\"x\"===t?e:n},r.getClosest=function(t,e,r){if(!1!==r.index)r.index>=0&&r.index<t.length?r.distance=0:r.index=!1;else for(var n=0;n<t.length;n++){var i=e(t[n]);i<=r.distance&&(r.index=n,r.distance=i)}return r},r.inbox=function(t,e,r){return t*e<0||0===t?r:1/0},r.quadrature=function(t,e){return function(r){var n=t(r),i=e(r);return Math.sqrt(n*n+i*i)}},r.makeEventData=function(t,e,n){var i=\"index\"in t?t.index:t.pointNumber,a={data:e._input,fullData:e,curveNumber:e.index,pointNumber:i};if(e._indexToPoints){var o=e._indexToPoints[i];1===o.length?a.pointIndex=o[0]:a.pointIndices=o}else a.pointIndex=i;return e._module.eventData?a=e._module.eventData(a,t,e,n,i):(\"xVal\"in t?a.x=t.xVal:\"x\"in t&&(a.x=t.x),\"yVal\"in t?a.y=t.yVal:\"y\"in t&&(a.y=t.y),t.xa&&(a.xaxis=t.xa),t.ya&&(a.yaxis=t.ya),void 0!==t.zLabelVal&&(a.z=t.zLabelVal)),r.appendArrayPointValue(a,e,i),a},r.appendArrayPointValue=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){var u=o(n.nestedProperty(e,l).get(),r);void 0!==u&&(t[c]=u)}}},r.appendArrayMultiPointValues=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){for(var u=n.nestedProperty(e,l).get(),h=new Array(r.length),f=0;f<r.length;f++)h[f]=o(u,r[f]);t[c]=h}}};var i={ids:\"id\",locations:\"location\",labels:\"label\",values:\"value\",\"marker.colors\":\"color\",parents:\"parent\"};function a(t){return i[t]||t}function o(t,e){return Array.isArray(e)?Array.isArray(t)&&Array.isArray(t[e[0]])?t[e[0]][e[1]]:void 0:t[e]}},{\"../../lib\":719}],629:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../lib\"),s=t(\"../../lib/events\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib/override_cursor\"),u=t(\"../drawing\"),h=t(\"../color\"),f=t(\"../dragelement\"),p=t(\"../../plots/cartesian/axes\"),d=t(\"../../registry\"),g=t(\"./helpers\"),v=t(\"./constants\"),m=v.YANGLE,y=Math.PI*m/180,x=1/Math.sin(y),b=Math.cos(y),_=Math.sin(y),w=v.HOVERARROWSIZE,k=v.HOVERTEXTPAD;r.hover=function(t,e,r,a){t=o.getGraphDiv(t),o.throttle(t._fullLayout._uid+v.HOVERID,v.HOVERMINTIME,function(){!function(t,e,r,a){r||(r=\"xy\");var l=Array.isArray(r)?r:[r],u=t._fullLayout,v=u._plots||[],m=v[r],y=u._has(\"cartesian\");if(m){var b=m.overlays.map(function(t){return t.id});l=l.concat(b)}for(var _=l.length,w=new Array(_),k=new Array(_),T=!1,L=0;L<_;L++){var P=l[L],O=v[P];if(O)T=!0,w[L]=p.getFromId(t,O.xaxis._id),k[L]=p.getFromId(t,O.yaxis._id);else{var z=u[P]._subplot;w[L]=z.xaxis,k[L]=z.yaxis}}var I=e.hovermode||u.hovermode;I&&!T&&(I=\"closest\");if(-1===[\"x\",\"y\",\"closest\"].indexOf(I)||!t.calcdata||t.querySelector(\".zoombox\")||t._dragging)return f.unhoverRaw(t,e);var D,R,F,B,N,j,U,V,q,H,G,Y,W,X=-1===u.hoverdistance?1/0:u.hoverdistance,Z=-1===u.spikedistance?1/0:u.spikedistance,J=[],K=[],$={hLinePoint:null,vLinePoint:null},Q=!1;if(Array.isArray(e))for(I=\"array\",F=0;F<e.length;F++)(N=t.calcdata[e[F].curveNumber||0])&&(j=N[0].trace,\"skip\"!==N[0].trace.hoverinfo&&(K.push(N),\"h\"===j.orientation&&(Q=!0)));else{for(B=0;B<t.calcdata.length;B++)N=t.calcdata[B],\"skip\"!==(j=N[0].trace).hoverinfo&&g.isTraceInSubplots(j,l)&&(K.push(N),\"h\"===j.orientation&&(Q=!0));var tt,et,rt=!e.target;if(rt)tt=\"xpx\"in e?e.xpx:w[0]._length/2,et=\"ypx\"in e?e.ypx:k[0]._length/2;else{if(!1===s.triggerHandler(t,\"plotly_beforehover\",e))return;var nt=e.target.getBoundingClientRect();if(tt=e.clientX-nt.left,et=e.clientY-nt.top,tt<0||tt>w[0]._length||et<0||et>k[0]._length)return f.unhoverRaw(t,e)}if(e.pointerX=tt+w[0]._offset,e.pointerY=et+k[0]._offset,D=\"xval\"in e?g.flat(l,e.xval):g.p2c(w,tt),R=\"yval\"in e?g.flat(l,e.yval):g.p2c(k,et),!i(D[0])||!i(R[0]))return o.warn(\"Fx.hover failed\",e,t),f.unhoverRaw(t,e)}var it=1/0;for(B=0;B<K.length;B++)if((N=K[B])&&N[0]&&N[0].trace&&!0===(j=N[0].trace).visible&&0!==j._length&&-1===[\"carpet\",\"contourcarpet\"].indexOf(j._module.name)){if(\"splom\"===j.type?U=l[V=0]:(U=g.getSubplot(j),V=l.indexOf(U)),q=I,Y={cd:N,trace:j,xa:w[V],ya:k[V],maxHoverDistance:X,maxSpikeDistance:Z,index:!1,distance:Math.min(it,X),spikeDistance:1/0,xSpike:void 0,ySpike:void 0,color:h.defaultLine,name:j.name,x0:void 0,x1:void 0,y0:void 0,y1:void 0,xLabelVal:void 0,yLabelVal:void 0,zLabelVal:void 0,text:void 0},u[U]&&(Y.subplot=u[U]._subplot),u._splomScenes&&u._splomScenes[j.uid]&&(Y.scene=u._splomScenes[j.uid]),W=J.length,\"array\"===q){var at=e[B];\"pointNumber\"in at?(Y.index=at.pointNumber,q=\"closest\"):(q=\"\",\"xval\"in at&&(H=at.xval,q=\"x\"),\"yval\"in at&&(G=at.yval,q=q?\"closest\":\"y\"))}else H=D[V],G=R[V];if(0!==X)if(j._module&&j._module.hoverPoints){var ot=j._module.hoverPoints(Y,H,G,q,u._hoverlayer);if(ot)for(var st,lt=0;lt<ot.length;lt++)st=ot[lt],i(st.x0)&&i(st.y0)&&J.push(S(st,I))}else o.log(\"Unrecognized trace type in hover:\",j);if(\"closest\"===I&&J.length>W&&(J.splice(0,W),it=J[0].distance),y&&0!==Z&&0===J.length){Y.distance=Z,Y.index=!1;var ct=j._module.hoverPoints(Y,H,G,\"closest\",u._hoverlayer);if(ct&&(ct=ct.filter(function(t){return t.spikeDistance<=Z})),ct&&ct.length){var ut,ht=ct.filter(function(t){return t.xa.showspikes});if(ht.length){var ft=ht[0];i(ft.x0)&&i(ft.y0)&&(ut=vt(ft),(!$.vLinePoint||$.vLinePoint.spikeDistance>ut.spikeDistance)&&($.vLinePoint=ut))}var pt=ct.filter(function(t){return t.ya.showspikes});if(pt.length){var dt=pt[0];i(dt.x0)&&i(dt.y0)&&(ut=vt(dt),(!$.hLinePoint||$.hLinePoint.spikeDistance>ut.spikeDistance)&&($.hLinePoint=ut))}}}}function gt(t,e){for(var r,n=null,i=1/0,a=0;a<t.length;a++)(r=t[a].spikeDistance)<i&&r<=e&&(n=t[a],i=r);return n}function vt(t){return t?{xa:t.xa,ya:t.ya,x:void 0!==t.xSpike?t.xSpike:(t.x0+t.x1)/2,y:void 0!==t.ySpike?t.ySpike:(t.y0+t.y1)/2,distance:t.distance,spikeDistance:t.spikeDistance,curveNumber:t.trace.index,color:t.color,pointNumber:t.index}:null}var mt={fullLayout:u,container:u._hoverlayer,outerContainer:u._paperdiv,event:e},yt=t._spikepoints,xt={vLinePoint:$.vLinePoint,hLinePoint:$.hLinePoint};if(t._spikepoints=xt,y&&0!==Z&&0!==J.length){var bt=J.filter(function(t){return t.ya.showspikes}),_t=gt(bt,Z);$.hLinePoint=vt(_t);var wt=J.filter(function(t){return t.xa.showspikes}),kt=gt(wt,Z);$.vLinePoint=vt(kt)}if(0===J.length){var Tt=f.unhoverRaw(t,e);return!y||null===$.hLinePoint&&null===$.vLinePoint||C(yt)&&E($,mt),Tt}y&&C(yt)&&E($,mt);J.sort(function(t,e){return t.distance-e.distance});var At=t._hoverdata,Mt=[];for(F=0;F<J.length;F++){var St=J[F],Et=g.makeEventData(St,St.trace,St.cd);if(!1!==St.hovertemplate){var Ct=!1;St.cd[St.index]&&St.cd[St.index].ht&&(Ct=St.cd[St.index].ht),St.hovertemplate=Ct||St.trace.hovertemplate||!1}St.eventData=[Et],Mt.push(Et)}t._hoverdata=Mt;var Lt=\"y\"===I&&(K.length>1||J.length>1)||\"closest\"===I&&Q&&J.length>1,Pt=h.combine(u.plot_bgcolor||h.background,u.paper_bgcolor),Ot={hovermode:I,rotateLabels:Lt,bgColor:Pt,container:u._hoverlayer,outerContainer:u._paperdiv,commonLabelOpts:u.hoverlabel,hoverdistance:u.hoverdistance},zt=A(J,Ot,t);if(function(t,e,r){var n,i,a,o,s,l,c,u=0,h=1,f=t.size(),p=new Array(f),d=0;function g(t){var e=t[0],r=t[t.length-1];if(i=e.pmin-e.pos-e.dp+e.size,a=r.pos+r.dp+r.size-e.pmax,i>.01){for(s=t.length-1;s>=0;s--)t[s].dp+=i;n=!1}if(!(a<.01)){if(i<-.01){for(s=t.length-1;s>=0;s--)t[s].dp-=a;n=!1}if(n){var c=0;for(o=0;o<t.length;o++)(l=t[o]).pos+l.dp+l.size>e.pmax&&c++;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos>e.pmax-1&&(l.del=!0,c--);for(o=0;o<t.length&&!(c<=0);o++)if((l=t[o]).pos<e.pmin+1)for(l.del=!0,c--,a=2*l.size,s=t.length-1;s>=0;s--)t[s].dp-=a;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos+l.dp+l.size>e.pmax&&(l.del=!0,c--)}}}for(t.each(function(t){var n=t[e],i=\"x\"===n._id.charAt(0),a=n.range;0===d&&a&&a[0]>a[1]!==i&&(h=-1),p[d++]=[{datum:t,traceIndex:t.trace.index,dp:0,pos:t.pos,posref:t.posref,size:t.by*(i?x:1)/2,pmin:0,pmax:i?r.width:r.height}]}),p.sort(function(t,e){return t[0].posref-e[0].posref||h*(e[0].traceIndex-t[0].traceIndex)});!n&&u<=f;){for(u++,n=!0,o=0;o<p.length-1;){var v=p[o],m=p[o+1],y=v[v.length-1],b=m[0];if((i=y.pos+y.dp+y.size-b.pos-b.dp+b.size)>.01&&y.pmin===b.pmin&&y.pmax===b.pmax){for(s=m.length-1;s>=0;s--)m[s].dp+=i;for(v.push.apply(v,m),p.splice(o+1,1),c=0,s=v.length-1;s>=0;s--)c+=v[s].dp;for(a=c/v.length,s=v.length-1;s>=0;s--)v[s].dp-=a;n=!1}else o++}p.forEach(g)}for(o=p.length-1;o>=0;o--){var _=p[o];for(s=_.length-1;s>=0;s--){var w=_[s],k=w.datum;k.offset=w.dp,k.del=w.del}}}(zt,Lt?\"xa\":\"ya\",u),M(zt,Lt),e.target&&e.target.tagName){var It=d.getComponentMethod(\"annotations\",\"hasClickToShow\")(t,Mt);c(n.select(e.target),It?\"pointer\":\"\")}if(!e.target||a||!function(t,e,r){if(!r||r.length!==t._hoverdata.length)return!0;for(var n=r.length-1;n>=0;n--){var i=r[n],a=t._hoverdata[n];if(i.curveNumber!==a.curveNumber||String(i.pointNumber)!==String(a.pointNumber)||String(i.pointNumbers)!==String(a.pointNumbers))return!0}return!1}(t,0,At))return;At&&t.emit(\"plotly_unhover\",{event:e,points:At});t.emit(\"plotly_hover\",{event:e,points:t._hoverdata,xaxes:w,yaxes:k,xvals:D,yvals:R})}(t,e,r,a)})},r.loneHover=function(t,e){var r=!0;Array.isArray(t)||(r=!1,t=[t]);var i=t.map(function(t){return{color:t.color||h.defaultLine,x0:t.x0||t.x||0,x1:t.x1||t.x||0,y0:t.y0||t.y||0,y1:t.y1||t.y||0,xLabel:t.xLabel,yLabel:t.yLabel,zLabel:t.zLabel,text:t.text,name:t.name,idealAlign:t.idealAlign,borderColor:t.borderColor,fontFamily:t.fontFamily,fontSize:t.fontSize,fontColor:t.fontColor,nameLength:t.nameLength,textAlign:t.textAlign,trace:t.trace||{index:0,hoverinfo:\"\"},xa:{_offset:0},ya:{_offset:0},index:0,hovertemplate:t.hovertemplate||!1,eventData:t.eventData||!1,hovertemplateLabels:t.hovertemplateLabels||!1}}),a=n.select(e.container),o=e.outerContainer?n.select(e.outerContainer):a,s={hovermode:\"closest\",rotateLabels:!1,bgColor:e.bgColor||h.background,container:a,outerContainer:o},l=A(i,s,e.gd),c=0,u=0;return l.sort(function(t,e){return t.y0-e.y0}).each(function(t,r){var n=t.y0-t.by/2;t.offset=n-5<c?c-n+5:0,c=n+t.by+t.offset,r===e.anchorIndex&&(u=t.offset)}).each(function(t){t.offset-=u}),M(l,s.rotateLabels),r?l:l.node()};var T=/<extra>([\\s\\S]*)<\\/extra>/;function A(t,e,r){var i=r._fullLayout,a=e.hovermode,s=e.rotateLabels,c=e.bgColor,f=e.container,p=e.outerContainer,d=e.commonLabelOpts||{},g=e.fontFamily||v.HOVERFONT,y=e.fontSize||v.HOVERFONTSIZE,x=t[0],b=x.xa,_=x.ya,A=\"y\"===a?\"yLabel\":\"xLabel\",M=x[A],S=(String(M)||\"\").split(\" \")[0],E=p.node().getBoundingClientRect(),C=E.top,P=E.width,O=E.height,z=void 0!==M&&x.distance<=e.hoverdistance&&(\"x\"===a||\"y\"===a);if(z){var I,D,R=!0;for(I=0;I<t.length;I++)if(R&&void 0===t[I].zLabel&&(R=!1),D=t[I].hoverinfo||t[I].trace.hoverinfo){var F=Array.isArray(D)?D:D.split(\"+\");if(-1===F.indexOf(\"all\")&&-1===F.indexOf(a)){z=!1;break}}R&&(z=!1)}var B=f.selectAll(\"g.axistext\").data(z?[0]:[]);B.enter().append(\"g\").classed(\"axistext\",!0),B.exit().remove(),B.each(function(){var e=n.select(this),i=o.ensureSingle(e,\"path\",\"\",function(t){t.style({\"stroke-width\":\"1px\"})}),s=o.ensureSingle(e,\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),c=d.bgcolor||h.defaultLine,f=d.bordercolor||h.contrast(c),p=h.contrast(c);i.style({fill:c,stroke:f}),s.text(M).call(u.font,d.font.family||g,d.font.size||y,d.font.color||p).call(l.positionText,0,0).call(l.convertToTspans,r),e.attr(\"transform\",\"\");var v=s.node().getBoundingClientRect();if(\"x\"===a){s.attr(\"text-anchor\",\"middle\").call(l.positionText,0,\"top\"===b.side?C-v.bottom-w-k:C-v.top+w+k);var m=\"top\"===b.side?\"-\":\"\";i.attr(\"d\",\"M0,0L\"+w+\",\"+m+w+\"H\"+(k+v.width/2)+\"v\"+m+(2*k+v.height)+\"H-\"+(k+v.width/2)+\"V\"+m+w+\"H-\"+w+\"Z\"),e.attr(\"transform\",\"translate(\"+(b._offset+(x.x0+x.x1)/2)+\",\"+(_._offset+(\"top\"===b.side?0:_._length))+\")\")}else{s.attr(\"text-anchor\",\"right\"===_.side?\"start\":\"end\").call(l.positionText,(\"right\"===_.side?1:-1)*(k+w),C-v.top-v.height/2);var T=\"right\"===_.side?\"\":\"-\";i.attr(\"d\",\"M0,0L\"+T+w+\",\"+w+\"V\"+(k+v.height/2)+\"h\"+T+(2*k+v.width)+\"V-\"+(k+v.height/2)+\"H\"+T+w+\"V-\"+w+\"Z\"),e.attr(\"transform\",\"translate(\"+(b._offset+(\"right\"===_.side?b._length:0))+\",\"+(_._offset+(x.y0+x.y1)/2)+\")\")}t=t.filter(function(t){return void 0!==t.zLabelVal||(t[A]||\"\").split(\" \")[0]===S})});var N=f.selectAll(\"g.hovertext\").data(t,function(t){return[t.trace.index,t.index,t.x0,t.y0,t.name,t.attr,t.xa,t.ya||\"\"].join(\",\")});return N.enter().append(\"g\").classed(\"hovertext\",!0).each(function(){var t=n.select(this);t.append(\"rect\").call(h.fill,h.addOpacity(c,.8)),t.append(\"text\").classed(\"name\",!0),t.append(\"path\").style(\"stroke-width\",\"1px\"),t.append(\"text\").classed(\"nums\",!0).call(u.font,g,y)}),N.exit().remove(),N.each(function(t){var e=n.select(this).attr(\"transform\",\"\"),f=\"\",p=\"\",d=t.bgcolor||t.color,v=h.combine(h.opacity(d)?d:h.defaultLine,c),x=h.combine(h.opacity(t.color)?t.color:h.defaultLine,c),b=t.borderColor||h.contrast(v);void 0!==t.nameOverride&&(t.name=t.nameOverride),t.name&&(t.trace._meta&&(t.name=o.templateString(t.name,t.trace._meta)),f=L(t.name,t.nameLength)),void 0!==t.zLabel?(void 0!==t.xLabel&&(p+=\"x: \"+t.xLabel+\"<br>\"),void 0!==t.yLabel&&(p+=\"y: \"+t.yLabel+\"<br>\"),\"choropleth\"!==t.trace.type&&\"choroplethmapbox\"!==t.trace.type&&(p+=(p?\"z: \":\"\")+t.zLabel)):z&&t[a+\"Label\"]===M?p=t[(\"x\"===a?\"y\":\"x\")+\"Label\"]||\"\":void 0===t.xLabel?void 0!==t.yLabel&&\"scattercarpet\"!==t.trace.type&&(p=t.yLabel):p=void 0===t.yLabel?t.xLabel:\"(\"+t.xLabel+\", \"+t.yLabel+\")\",!t.text&&0!==t.text||Array.isArray(t.text)||(p+=(p?\"<br>\":\"\")+t.text),void 0!==t.extraText&&(p+=(p?\"<br>\":\"\")+t.extraText),\"\"!==p||t.hovertemplate||(\"\"===f&&e.remove(),p=f);var _=i._d3locale,A=t.hovertemplate||!1,S=t.hovertemplateLabels||t,E=t.eventData[0]||{};A&&(p=(p=o.hovertemplateString(A,S,_,E,t.trace._meta)).replace(T,function(e,r){return f=L(r,t.nameLength),\"\"}));var I=e.select(\"text.nums\").call(u.font,t.fontFamily||g,t.fontSize||y,t.fontColor||b).text(p).attr(\"data-notex\",1).call(l.positionText,0,0).call(l.convertToTspans,r),D=e.select(\"text.name\"),R=0,F=0;if(f&&f!==p){D.call(u.font,t.fontFamily||g,t.fontSize||y,x).text(f).attr(\"data-notex\",1).call(l.positionText,0,0).call(l.convertToTspans,r);var B=D.node().getBoundingClientRect();R=B.width+2*k,F=B.height+2*k}else D.remove(),e.select(\"rect\").remove();e.select(\"path\").style({fill:v,stroke:b});var N,j,U=I.node().getBoundingClientRect(),V=t.xa._offset+(t.x0+t.x1)/2,q=t.ya._offset+(t.y0+t.y1)/2,H=Math.abs(t.x1-t.x0),G=Math.abs(t.y1-t.y0),Y=U.width+w+k+R;if(t.ty0=C-U.top,t.bx=U.width+2*k,t.by=Math.max(U.height+2*k,F),t.anchor=\"start\",t.txwidth=U.width,t.tx2width=R,t.offset=0,s)t.pos=V,N=q+G/2+Y<=O,j=q-G/2-Y>=0,\"top\"!==t.idealAlign&&N||!j?N?(q+=G/2,t.anchor=\"start\"):t.anchor=\"middle\":(q-=G/2,t.anchor=\"end\");else if(t.pos=q,N=V+H/2+Y<=P,j=V-H/2-Y>=0,\"left\"!==t.idealAlign&&N||!j)if(N)V+=H/2,t.anchor=\"start\";else{t.anchor=\"middle\";var W=Y/2,X=V+W-P,Z=V-W;X>0&&(V-=X),Z<0&&(V+=-Z)}else V-=H/2,t.anchor=\"end\";I.attr(\"text-anchor\",t.anchor),R&&D.attr(\"text-anchor\",t.anchor),e.attr(\"transform\",\"translate(\"+V+\",\"+q+\")\"+(s?\"rotate(\"+m+\")\":\"\"))}),N}function M(t,e){t.each(function(t){var r=n.select(this);if(t.del)return r.remove();var i=r.select(\"text.nums\"),a=t.anchor,o=\"end\"===a?-1:1,s={start:1,end:-1,middle:0}[a],c=s*(w+k),h=c+s*(t.txwidth+k),f=0,p=t.offset;\"middle\"===a&&(c-=t.tx2width/2,h+=t.txwidth/2+k),e&&(p*=-_,f=t.offset*b),r.select(\"path\").attr(\"d\",\"middle\"===a?\"M-\"+(t.bx/2+t.tx2width/2)+\",\"+(p-t.by/2)+\"h\"+t.bx+\"v\"+t.by+\"h-\"+t.bx+\"Z\":\"M0,0L\"+(o*w+f)+\",\"+(w+p)+\"v\"+(t.by/2-w)+\"h\"+o*t.bx+\"v-\"+t.by+\"H\"+(o*w+f)+\"V\"+(p-w)+\"Z\");var d=c+f,g=p+t.ty0-t.by/2+k,v=t.textAlign||\"auto\";\"auto\"!==v&&(\"left\"===v&&\"start\"!==a?(i.attr(\"text-anchor\",\"start\"),d=\"middle\"===a?-t.bx/2-t.tx2width/2+k:-t.bx-k):\"right\"===v&&\"end\"!==a&&(i.attr(\"text-anchor\",\"end\"),d=\"middle\"===a?t.bx/2-t.tx2width/2-k:t.bx+k)),i.call(l.positionText,d,g),t.tx2width&&(r.select(\"text.name\").call(l.positionText,h+s*k+f,p+t.ty0-t.by/2+k),r.select(\"rect\").call(u.setRect,h+(s-1)*t.tx2width/2+f,p-t.by/2-1,t.tx2width,t.by+2))})}function S(t,e){var r=t.index,n=t.trace||{},a=t.cd[0],s=t.cd[r]||{};function l(t){return t||i(t)&&0===t}var c=Array.isArray(r)?function(t,e){var i=o.castOption(a,r,t);return l(i)?i:o.extractOption({},n,\"\",e)}:function(t,e){return o.extractOption(s,n,t,e)};function u(e,r,n){var i=c(r,n);l(i)&&(t[e]=i)}if(u(\"hoverinfo\",\"hi\",\"hoverinfo\"),u(\"bgcolor\",\"hbg\",\"hoverlabel.bgcolor\"),u(\"borderColor\",\"hbc\",\"hoverlabel.bordercolor\"),u(\"fontFamily\",\"htf\",\"hoverlabel.font.family\"),u(\"fontSize\",\"hts\",\"hoverlabel.font.size\"),u(\"fontColor\",\"htc\",\"hoverlabel.font.color\"),u(\"nameLength\",\"hnl\",\"hoverlabel.namelength\"),u(\"textAlign\",\"hta\",\"hoverlabel.align\"),t.posref=\"y\"===e||\"closest\"===e&&\"h\"===n.orientation?t.xa._offset+(t.x0+t.x1)/2:t.ya._offset+(t.y0+t.y1)/2,t.x0=o.constrain(t.x0,0,t.xa._length),t.x1=o.constrain(t.x1,0,t.xa._length),t.y0=o.constrain(t.y0,0,t.ya._length),t.y1=o.constrain(t.y1,0,t.ya._length),void 0!==t.xLabelVal&&(t.xLabel=\"xLabel\"in t?t.xLabel:p.hoverLabelText(t.xa,t.xLabelVal),t.xVal=t.xa.c2d(t.xLabelVal)),void 0!==t.yLabelVal&&(t.yLabel=\"yLabel\"in t?t.yLabel:p.hoverLabelText(t.ya,t.yLabelVal),t.yVal=t.ya.c2d(t.yLabelVal)),void 0!==t.zLabelVal&&void 0===t.zLabel&&(t.zLabel=String(t.zLabelVal)),!(isNaN(t.xerr)||\"log\"===t.xa.type&&t.xerr<=0)){var h=p.tickText(t.xa,t.xa.c2l(t.xerr),\"hover\").text;void 0!==t.xerrneg?t.xLabel+=\" +\"+h+\" / -\"+p.tickText(t.xa,t.xa.c2l(t.xerrneg),\"hover\").text:t.xLabel+=\" \\xb1 \"+h,\"x\"===e&&(t.distance+=1)}if(!(isNaN(t.yerr)||\"log\"===t.ya.type&&t.yerr<=0)){var f=p.tickText(t.ya,t.ya.c2l(t.yerr),\"hover\").text;void 0!==t.yerrneg?t.yLabel+=\" +\"+f+\" / -\"+p.tickText(t.ya,t.ya.c2l(t.yerrneg),\"hover\").text:t.yLabel+=\" \\xb1 \"+f,\"y\"===e&&(t.distance+=1)}var d=t.hoverinfo||t.trace.hoverinfo;return d&&\"all\"!==d&&(-1===(d=Array.isArray(d)?d:d.split(\"+\")).indexOf(\"x\")&&(t.xLabel=void 0),-1===d.indexOf(\"y\")&&(t.yLabel=void 0),-1===d.indexOf(\"z\")&&(t.zLabel=void 0),-1===d.indexOf(\"text\")&&(t.text=void 0),-1===d.indexOf(\"name\")&&(t.name=void 0)),t}function E(t,e){var r,n,i=e.container,o=e.fullLayout,s=e.event,l=!!t.hLinePoint,c=!!t.vLinePoint;if(i.selectAll(\".spikeline\").remove(),c||l){var f=h.combine(o.plot_bgcolor,o.paper_bgcolor);if(l){var p,d,g=t.hLinePoint;r=g&&g.xa,\"cursor\"===(n=g&&g.ya).spikesnap?(p=s.pointerX,d=s.pointerY):(p=r._offset+g.x,d=n._offset+g.y);var v,m,y=a.readability(g.color,f)<1.5?h.contrast(f):g.color,x=n.spikemode,b=n.spikethickness,_=n.spikecolor||y,w=n._boundingBox,k=(w.left+w.right)/2<p?w.right:w.left;-1===x.indexOf(\"toaxis\")&&-1===x.indexOf(\"across\")||(-1!==x.indexOf(\"toaxis\")&&(v=k,m=p),-1!==x.indexOf(\"across\")&&(v=n._counterSpan[0],m=n._counterSpan[1]),i.insert(\"line\",\":first-child\").attr({x1:v,x2:m,y1:d,y2:d,\"stroke-width\":b,stroke:_,\"stroke-dasharray\":u.dashStyle(n.spikedash,b)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),i.insert(\"line\",\":first-child\").attr({x1:v,x2:m,y1:d,y2:d,\"stroke-width\":b+2,stroke:f}).classed(\"spikeline\",!0).classed(\"crisp\",!0)),-1!==x.indexOf(\"marker\")&&i.insert(\"circle\",\":first-child\").attr({cx:k+(\"right\"!==n.side?b:-b),cy:d,r:b,fill:_}).classed(\"spikeline\",!0)}if(c){var T,A,M=t.vLinePoint;r=M&&M.xa,n=M&&M.ya,\"cursor\"===r.spikesnap?(T=s.pointerX,A=s.pointerY):(T=r._offset+M.x,A=n._offset+M.y);var S,E,C=a.readability(M.color,f)<1.5?h.contrast(f):M.color,L=r.spikemode,P=r.spikethickness,O=r.spikecolor||C,z=r._boundingBox,I=(z.top+z.bottom)/2<A?z.bottom:z.top;-1===L.indexOf(\"toaxis\")&&-1===L.indexOf(\"across\")||(-1!==L.indexOf(\"toaxis\")&&(S=I,E=A),-1!==L.indexOf(\"across\")&&(S=r._counterSpan[0],E=r._counterSpan[1]),i.insert(\"line\",\":first-child\").attr({x1:T,x2:T,y1:S,y2:E,\"stroke-width\":P,stroke:O,\"stroke-dasharray\":u.dashStyle(r.spikedash,P)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),i.insert(\"line\",\":first-child\").attr({x1:T,x2:T,y1:S,y2:E,\"stroke-width\":P+2,stroke:f}).classed(\"spikeline\",!0).classed(\"crisp\",!0)),-1!==L.indexOf(\"marker\")&&i.insert(\"circle\",\":first-child\").attr({cx:T,cy:I-(\"top\"!==r.side?P:-P),r:P,fill:O}).classed(\"spikeline\",!0)}}}function C(t,e){return!e||(e.vLinePoint!==t._spikepoints.vLinePoint||e.hLinePoint!==t._spikepoints.hLinePoint)}function L(t,e){return l.plainText(t||\"\",{len:e,allowedTags:[\"br\",\"sub\",\"sup\",\"b\",\"i\",\"em\"]})}},{\"../../lib\":719,\"../../lib/events\":709,\"../../lib/override_cursor\":730,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"./constants\":626,\"./helpers\":628,d3:163,\"fast-isnumeric\":225,tinycolor2:537}],630:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i){r(\"hoverlabel.bgcolor\",(i=i||{}).bgcolor),r(\"hoverlabel.bordercolor\",i.bordercolor),r(\"hoverlabel.namelength\",i.namelength),n.coerceFont(r,\"hoverlabel.font\",i.font),r(\"hoverlabel.align\",i.align)}},{\"../../lib\":719}],631:[function(t,e,r){\"use strict\";t(\"../../constants/docs\").FORMAT_LINK;e.exports=function(t,e){t=t||{};(e=e||{}).description&&e.description;var r=e.keys||[];if(r.length>0){for(var n=[],i=0;i<r.length;i++)n[i]=\"`\"+r[i]+\"`\";\"Finally, the template string has access to \",1===r.length?\"variable \"+n[0]:\"variables \"+n.slice(0,-1).join(\", \")+\" and \"+n.slice(-1)+\".\"}var a={valType:\"string\",dflt:\"\",editType:t.editType||\"none\"};return!1!==t.arrayOk&&(a.arrayOk=!0),a}},{\"../../constants/docs\":690}],632:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../dragelement\"),o=t(\"./helpers\"),s=t(\"./layout_attributes\"),l=t(\"./hover\");e.exports={moduleType:\"component\",name:\"fx\",constants:t(\"./constants\"),schema:{layout:s},attributes:t(\"./attributes\"),layoutAttributes:s,supplyLayoutGlobalDefaults:t(\"./layout_global_defaults\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),getDistanceFunction:o.getDistanceFunction,getClosest:o.getClosest,inbox:o.inbox,quadrature:o.quadrature,appendArrayPointValue:o.appendArrayPointValue,castHoverOption:function(t,e,r){return i.castOption(t,e,\"hoverlabel.\"+r)},castHoverinfo:function(t,e,r){return i.castOption(t,r,\"hoverinfo\",function(r){return i.coerceHoverinfo({hoverinfo:r},{_module:t._module},e)})},hover:l.hover,unhover:a.unhover,loneHover:l.loneHover,loneUnhover:function(t){var e=i.isD3Selection(t)?t:n.select(t);e.selectAll(\"g.hovertext\").remove(),e.selectAll(\".spikeline\").remove()},click:t(\"./click\")}},{\"../../lib\":719,\"../dragelement\":611,\"./attributes\":623,\"./calc\":624,\"./click\":625,\"./constants\":626,\"./defaults\":627,\"./helpers\":628,\"./hover\":629,\"./layout_attributes\":633,\"./layout_defaults\":634,\"./layout_global_defaults\":635,d3:163}],633:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../plots/font_attributes\")({editType:\"none\"});i.family.dflt=n.HOVERFONT,i.size.dflt=n.HOVERFONTSIZE,e.exports={clickmode:{valType:\"flaglist\",flags:[\"event\",\"select\"],dflt:\"event\",editType:\"plot\",extras:[\"none\"]},dragmode:{valType:\"enumerated\",values:[\"zoom\",\"pan\",\"select\",\"lasso\",\"orbit\",\"turntable\",!1],dflt:\"zoom\",editType:\"modebar\"},hovermode:{valType:\"enumerated\",values:[\"x\",\"y\",\"closest\",!1],editType:\"modebar\"},hoverdistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},spikedistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"none\"},bordercolor:{valType:\"color\",editType:\"none\"},font:i,align:{valType:\"enumerated\",values:[\"left\",\"right\",\"auto\"],dflt:\"auto\",editType:\"none\"},namelength:{valType:\"integer\",min:-1,dflt:15,editType:\"none\"},editType:\"none\"},selectdirection:{valType:\"enumerated\",values:[\"h\",\"v\",\"d\",\"any\"],dflt:\"any\",editType:\"none\"}}},{\"../../plots/font_attributes\":793,\"./constants\":626}],634:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){function a(r,a){return n.coerce(t,e,i,r,a)}var o,s=a(\"clickmode\");\"select\"===a(\"dragmode\")&&a(\"selectdirection\"),e._has(\"cartesian\")?s.indexOf(\"select\")>-1?o=\"closest\":(e._isHoriz=function(t,e){for(var r=e._scatterStackOpts||{},n=0;n<t.length;n++){var i=t[n],a=i.xaxis+i.yaxis,o=r[a]||{},s=o[i.stackgroup]||{};if(\"h\"!==i.orientation&&\"h\"!==s.orientation)return!1}return!0}(r,e),o=e._isHoriz?\"y\":\"x\"):o=\"closest\",a(\"hovermode\",o)&&(a(\"hoverdistance\"),a(\"spikedistance\"));var l=e._has(\"mapbox\"),c=e._has(\"geo\"),u=e._basePlotModules.length;\"zoom\"===e.dragmode&&((l||c)&&1===u||l&&c&&2===u)&&(e.dragmode=\"pan\")}},{\"../../lib\":719,\"./layout_attributes\":633}],635:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./hoverlabel_defaults\"),a=t(\"./layout_attributes\");e.exports=function(t,e){i(t,e,function(r,i){return n.coerce(t,e,a,r,i)})}},{\"../../lib\":719,\"./hoverlabel_defaults\":630,\"./layout_attributes\":633}],636:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/regex\").counter,a=t(\"../../plots/domain\").attributes,o=t(\"../../plots/cartesian/constants\").idRegex,s=t(\"../../plot_api/plot_template\"),l={rows:{valType:\"integer\",min:1,editType:\"plot\"},roworder:{valType:\"enumerated\",values:[\"top to bottom\",\"bottom to top\"],dflt:\"top to bottom\",editType:\"plot\"},columns:{valType:\"integer\",min:1,editType:\"plot\"},subplots:{valType:\"info_array\",freeLength:!0,dimensions:2,items:{valType:\"enumerated\",values:[i(\"xy\").toString(),\"\"],editType:\"plot\"},editType:\"plot\"},xaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.x.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},yaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.y.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},pattern:{valType:\"enumerated\",values:[\"independent\",\"coupled\"],dflt:\"coupled\",editType:\"plot\"},xgap:{valType:\"number\",min:0,max:1,editType:\"plot\"},ygap:{valType:\"number\",min:0,max:1,editType:\"plot\"},domain:a({name:\"grid\",editType:\"plot\",noGridCell:!0},{}),xside:{valType:\"enumerated\",values:[\"bottom\",\"bottom plot\",\"top plot\",\"top\"],dflt:\"bottom plot\",editType:\"plot\"},yside:{valType:\"enumerated\",values:[\"left\",\"left plot\",\"right plot\",\"right\"],dflt:\"left plot\",editType:\"plot\"},editType:\"plot\"};function c(t,e,r){var n=e[r+\"axes\"],i=Object.keys((t._splomAxes||{})[r]||{});return Array.isArray(n)?n:i.length?i:void 0}function u(t,e,r,n,i,a){var o=e(t+\"gap\",r),s=e(\"domain.\"+t);e(t+\"side\",n);for(var l=new Array(i),c=s[0],u=(s[1]-c)/(i-o),h=u*(1-o),f=0;f<i;f++){var p=c+u*f;l[a?i-1-f:f]=[p,p+h]}return l}function h(t,e,r,n,i){var a,o=new Array(r);function s(t,r){-1!==e.indexOf(r)&&void 0===n[r]?(o[t]=r,n[r]=t):o[t]=\"\"}if(Array.isArray(t))for(a=0;a<r;a++)s(a,t[a]);else for(s(0,i),a=1;a<r;a++)s(a,i+(a+1));return o}e.exports={moduleType:\"component\",name:\"grid\",schema:{layout:{grid:l}},layoutAttributes:l,sizeDefaults:function(t,e){var r=t.grid||{},i=c(e,r,\"x\"),a=c(e,r,\"y\");if(t.grid||i||a){var o,h,f=Array.isArray(r.subplots)&&Array.isArray(r.subplots[0]),p=Array.isArray(i),d=Array.isArray(a),g=p&&i!==r.xaxes&&d&&a!==r.yaxes;f?(o=r.subplots.length,h=r.subplots[0].length):(d&&(o=a.length),p&&(h=i.length));var v=s.newContainer(e,\"grid\"),m=T(\"rows\",o),y=T(\"columns\",h);if(m*y>1){f||p||d||\"independent\"===T(\"pattern\")&&(f=!0),v._hasSubplotGrid=f;var x,b,_=\"top to bottom\"===T(\"roworder\"),w=f?.2:.1,k=f?.3:.1;g&&e._splomGridDflt&&(x=e._splomGridDflt.xside,b=e._splomGridDflt.yside),v._domains={x:u(\"x\",T,w,x,y),y:u(\"y\",T,k,b,m,_)}}else delete e.grid}function T(t,e){return n.coerce(r,v,l,t,e)}},contentDefaults:function(t,e){var r=e.grid;if(r&&r._domains){var n,i,a,o,s,l,u,f=t.grid||{},p=e._subplots,d=r._hasSubplotGrid,g=r.rows,v=r.columns,m=\"independent\"===r.pattern,y=r._axisMap={};if(d){var x=f.subplots||[];l=r.subplots=new Array(g);var b=1;for(n=0;n<g;n++){var _=l[n]=new Array(v),w=x[n]||[];for(i=0;i<v;i++)if(m?(s=1===b?\"xy\":\"x\"+b+\"y\"+b,b++):s=w[i],_[i]=\"\",-1!==p.cartesian.indexOf(s)){if(u=s.indexOf(\"y\"),a=s.slice(0,u),o=s.slice(u),void 0!==y[a]&&y[a]!==i||void 0!==y[o]&&y[o]!==n)continue;_[i]=s,y[a]=i,y[o]=n}}}else{var k=c(e,f,\"x\"),T=c(e,f,\"y\");r.xaxes=h(k,p.xaxis,v,y,\"x\"),r.yaxes=h(T,p.yaxis,g,y,\"y\")}var A=r._anchors={},M=\"top to bottom\"===r.roworder;for(var S in y){var E,C,L,P=S.charAt(0),O=r[P+\"side\"];if(O.length<8)A[S]=\"free\";else if(\"x\"===P){if(\"t\"===O.charAt(0)===M?(E=0,C=1,L=g):(E=g-1,C=-1,L=-1),d){var z=y[S];for(n=E;n!==L;n+=C)if((s=l[n][z])&&(u=s.indexOf(\"y\"),s.slice(0,u)===S)){A[S]=s.slice(u);break}}else for(n=E;n!==L;n+=C)if(o=r.yaxes[n],-1!==p.cartesian.indexOf(S+o)){A[S]=o;break}}else if(\"l\"===O.charAt(0)?(E=0,C=1,L=v):(E=v-1,C=-1,L=-1),d){var I=y[S];for(n=E;n!==L;n+=C)if((s=l[I][n])&&(u=s.indexOf(\"y\"),s.slice(u)===S)){A[S]=s.slice(0,u);break}}else for(n=E;n!==L;n+=C)if(a=r.xaxes[n],-1!==p.cartesian.indexOf(a+S)){A[S]=a;break}}}}}},{\"../../lib\":719,\"../../lib/regex\":735,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773,\"../../plots/domain\":792}],637:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/constants\"),i=t(\"../../plot_api/plot_template\").templatedArray;e.exports=i(\"image\",{visible:{valType:\"boolean\",dflt:!0,editType:\"arraydraw\"},source:{valType:\"string\",editType:\"arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},sizex:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizey:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizing:{valType:\"enumerated\",values:[\"fill\",\"contain\",\"stretch\"],dflt:\"contain\",editType:\"arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},x:{valType:\"any\",dflt:0,editType:\"arraydraw\"},y:{valType:\"any\",dflt:0,editType:\"arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"top\",editType:\"arraydraw\"},xref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.x.toString()],dflt:\"paper\",editType:\"arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.y.toString()],dflt:\"paper\",editType:\"arraydraw\"},editType:\"arraydraw\"})},{\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773}],638:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.images,h=e._id.charAt(0),f=0;f<u.length;f++)if(c=\"images[\"+f+\"].\",(l=u[f])[h+\"ref\"]===e._id){var p=l[h],d=l[\"size\"+h],g=null,v=null;if(o){g=i(p,e.range);var m=d/Math.pow(10,g)/2;v=2*Math.log(m+Math.sqrt(1+m*m))/Math.LN10}else v=(g=Math.pow(10,p))*(Math.pow(10,d/2)-Math.pow(10,-d/2));n(g)?n(v)||(v=null):(g=null,v=null),a(c+h,g),a(c+\"size\"+h,v)}}},{\"../../lib/to_log_range\":745,\"fast-isnumeric\":225}],639:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\");function s(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}var s=a(\"source\");if(!a(\"visible\",!!s))return e;a(\"layer\"),a(\"xanchor\"),a(\"yanchor\"),a(\"sizex\"),a(\"sizey\"),a(\"sizing\"),a(\"opacity\");for(var l={_fullLayout:r},c=[\"x\",\"y\"],u=0;u<2;u++){var h=c[u],f=i.coerceRef(t,e,l,h,\"paper\");if(\"paper\"!==f)i.getFromId(l,f)._imgIndices.push(e._index);i.coercePosition(e,l,a,f,h,0)}return e}e.exports=function(t,e){a(t,e,{name:\"images\",handleItemDefaults:s})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"./attributes\":637}],640:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../drawing\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/xmlns_namespaces\");e.exports=function(t){var e,r,s=t._fullLayout,l=[],c={},u=[];for(r=0;r<s.images.length;r++){var h=s.images[r];if(h.visible)if(\"below\"===h.layer&&\"paper\"!==h.xref&&\"paper\"!==h.yref){e=h.xref+h.yref;var f=s._plots[e];if(!f){u.push(h);continue}f.mainplot&&(e=f.mainplot.id),c[e]||(c[e]=[]),c[e].push(h)}else\"above\"===h.layer?l.push(h):u.push(h)}var p={x:{left:{sizing:\"xMin\",offset:0},center:{sizing:\"xMid\",offset:-.5},right:{sizing:\"xMax\",offset:-1}},y:{top:{sizing:\"YMin\",offset:0},middle:{sizing:\"YMid\",offset:-.5},bottom:{sizing:\"YMax\",offset:-1}}};function d(e){var r=n.select(this);if(!this.img||this.img.src!==e.source){r.attr(\"xmlns\",o.svg);var i=new Promise(function(t){var n=new Image;function i(){r.remove(),t()}this.img=n,n.setAttribute(\"crossOrigin\",\"anonymous\"),n.onerror=i,n.onload=function(){var e=document.createElement(\"canvas\");e.width=this.width,e.height=this.height,e.getContext(\"2d\").drawImage(this,0,0);var n=e.toDataURL(\"image/png\");r.attr(\"xlink:href\",n),t()},r.on(\"error\",i),n.src=e.source}.bind(this));t._promises.push(i)}}function g(e){var r=n.select(this),o=a.getFromId(t,e.xref),l=a.getFromId(t,e.yref),c=s._size,u=o?Math.abs(o.l2p(e.sizex)-o.l2p(0)):e.sizex*c.w,h=l?Math.abs(l.l2p(e.sizey)-l.l2p(0)):e.sizey*c.h,f=u*p.x[e.xanchor].offset,d=h*p.y[e.yanchor].offset,g=p.x[e.xanchor].sizing+p.y[e.yanchor].sizing,v=(o?o.r2p(e.x)+o._offset:e.x*c.w+c.l)+f,m=(l?l.r2p(e.y)+l._offset:c.h-e.y*c.h+c.t)+d;switch(e.sizing){case\"fill\":g+=\" slice\";break;case\"stretch\":g=\"none\"}r.attr({x:v,y:m,width:u,height:h,preserveAspectRatio:g,opacity:e.opacity});var y=(o?o._id:\"\")+(l?l._id:\"\");i.setClipUrl(r,y?\"clip\"+s._uid+y:null,t)}var v=s._imageLowerLayer.selectAll(\"image\").data(u),m=s._imageUpperLayer.selectAll(\"image\").data(l);v.enter().append(\"image\"),m.enter().append(\"image\"),v.exit().remove(),m.exit().remove(),v.each(function(t){d.bind(this)(t),g.bind(this)(t)}),m.each(function(t){d.bind(this)(t),g.bind(this)(t)});var y=Object.keys(s._plots);for(r=0;r<y.length;r++){e=y[r];var x=s._plots[e];if(x.imagelayer){var b=x.imagelayer.selectAll(\"image\").data(c[e]||[]);b.enter().append(\"image\"),b.exit().remove(),b.each(function(t){d.bind(this)(t),g.bind(this)(t)})}}}},{\"../../constants/xmlns_namespaces\":696,\"../../plots/cartesian/axes\":767,\"../drawing\":614,d3:163}],641:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"images\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"images\"),draw:t(\"./draw\"),convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":777,\"./attributes\":637,\"./convert_coords\":638,\"./defaults\":639,\"./draw\":640}],642:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",editType:\"legend\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"legend\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"legend\"},font:n({editType:\"legend\"}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"v\",editType:\"legend\"},traceorder:{valType:\"flaglist\",flags:[\"reversed\",\"grouped\"],extras:[\"normal\"],editType:\"legend\"},tracegroupgap:{valType:\"number\",min:0,dflt:10,editType:\"legend\"},itemsizing:{valType:\"enumerated\",values:[\"trace\",\"constant\"],dflt:\"trace\",editType:\"legend\"},itemclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggle\",editType:\"legend\"},itemdoubleclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggleothers\",editType:\"legend\"},x:{valType:\"number\",min:-2,max:3,dflt:1.02,editType:\"legend\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"legend\"},y:{valType:\"number\",min:-2,max:3,dflt:1,editType:\"legend\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"legend\"},uirevision:{valType:\"any\",editType:\"none\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"legend\"},editType:\"legend\"}},{\"../../plots/font_attributes\":793,\"../color/attributes\":592}],643:[function(t,e,r){\"use strict\";e.exports={scrollBarWidth:6,scrollBarMinHeight:20,scrollBarColor:\"#808BA4\",scrollBarMargin:4,textOffsetX:40}},{}],644:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plot_api/plot_template\"),o=t(\"./attributes\"),s=t(\"../../plots/layout_attributes\"),l=t(\"./helpers\");e.exports=function(t,e,r){for(var c,u,h,f,p=t.legend||{},d=0,g=!1,v=\"normal\",m=0;m<r.length;m++){var y=r[m];y.visible&&((y.showlegend||y._dfltShowLegend)&&(d++,y.showlegend&&(g=!0,(n.traceIs(y,\"pie-like\")||!0===y._input.showlegend)&&d++)),(n.traceIs(y,\"bar\")&&\"stack\"===e.barmode||-1!==[\"tonextx\",\"tonexty\"].indexOf(y.fill))&&(v=l.isGrouped({traceorder:v})?\"grouped+reversed\":\"reversed\"),void 0!==y.legendgroup&&\"\"!==y.legendgroup&&(v=l.isReversed({traceorder:v})?\"reversed+grouped\":\"grouped\"))}var x=i.coerce(t,e,s,\"showlegend\",g&&d>1);if(!1!==x||p.uirevision){var b=a.newContainer(e,\"legend\");if(w(\"uirevision\",e.uirevision),!1!==x){if(w(\"bgcolor\",e.paper_bgcolor),w(\"bordercolor\"),w(\"borderwidth\"),i.coerceFont(w,\"font\",e.font),w(\"orientation\"),\"h\"===b.orientation){var _=t.xaxis;n.getComponentMethod(\"rangeslider\",\"isVisible\")(_)?(c=0,h=\"left\",u=1.1,f=\"bottom\"):(c=0,h=\"left\",u=-.1,f=\"top\")}w(\"traceorder\",v),l.isGrouped(e.legend)&&w(\"tracegroupgap\"),w(\"itemsizing\"),w(\"itemclick\"),w(\"itemdoubleclick\"),w(\"x\",c),w(\"xanchor\",h),w(\"y\",u),w(\"yanchor\",f),w(\"valign\"),i.noneOrAll(p,b,[\"x\",\"y\"])}}function w(t,e){return i.coerce(p,b,o,t,e)}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/layout_attributes\":819,\"../../registry\":847,\"./attributes\":642,\"./helpers\":648}],645:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib/events\"),l=t(\"../dragelement\"),c=t(\"../drawing\"),u=t(\"../color\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"./handle_click\"),p=t(\"./constants\"),d=t(\"../../constants/alignment\"),g=d.LINE_SPACING,v=d.FROM_TL,m=d.FROM_BR,y=t(\"./get_legend_data\"),x=t(\"./style\"),b=t(\"./helpers\");function _(t,e,r,n,i){var a=r.data()[0][0].trace,l={event:i,node:r.node(),curveNumber:a.index,expandedIndex:a._expandedIndex,data:t.data,layout:t.layout,frames:t._transitionData._frames,config:t._context,fullData:t._fullData,fullLayout:t._fullLayout};if(a._group&&(l.group=a._group),o.traceIs(a,\"pie-like\")&&(l.label=r.datum()[0].label),!1!==s.triggerHandler(t,\"plotly_legendclick\",l))if(1===n)e._clickTimeout=setTimeout(function(){f(r,t,n)},t._context.doubleClickDelay);else if(2===n){e._clickTimeout&&clearTimeout(e._clickTimeout),t._legendMouseDownTime=0,!1!==s.triggerHandler(t,\"plotly_legenddoubleclick\",l)&&f(r,t,n)}}function w(t,e,r){var n=t.data()[0][0],a=e._fullLayout,s=n.trace,l=o.traceIs(s,\"pie-like\"),u=s.index,f=e._context.edits.legendText&&!l,d=l?n.label:s.name;s._meta&&(d=i.templateString(d,s._meta));var v=i.ensureSingle(t,\"text\",\"legendtext\");function m(r){h.convertToTspans(r,e,function(){!function(t,e){var r=t.data()[0][0];if(!r.trace.showlegend)return void t.remove();var n,i,a=t.select(\"g[class*=math-group]\"),o=a.node(),s=e._fullLayout.legend.font.size*g;if(o){var l=c.bBox(o);n=l.height,i=l.width,c.setTranslate(a,0,n/4)}else{var u=t.select(\".legendtext\"),f=h.lineCount(u),d=u.node();n=s*f,i=d?c.bBox(d).width:0;var v=s*(.3+(1-f)/2);h.positionText(u,p.textOffsetX,v)}r.lineHeight=s,r.height=Math.max(n,16)+3,r.width=i}(t,e)})}v.attr(\"text-anchor\",\"start\").classed(\"user-select-none\",!0).call(c.font,a.legend.font).text(f?k(d,r):d),h.positionText(v,p.textOffsetX,0),f?v.call(h.makeEditable,{gd:e,text:d}).call(m).on(\"edit\",function(t){this.text(k(t,r)).call(m);var a=n.trace._fullInput||{},s={};if(o.hasTransform(a,\"groupby\")){var l=o.getTransformIndices(a,\"groupby\"),c=l[l.length-1],h=i.keyedContainer(a,\"transforms[\"+c+\"].styles\",\"target\",\"value.name\");h.set(n.trace._group,t),s=h.constructUpdate()}else s.name=t;return o.call(\"_guiRestyle\",e,s,u)}):m(v)}function k(t,e){var r=Math.max(4,e);if(t&&t.trim().length>=r/2)return t;for(var n=r-(t=t||\"\").length;n>0;n--)t+=\" \";return t}function T(t,e){var r,a=e._context.doubleClickDelay,o=1,s=i.ensureSingle(t,\"rect\",\"legendtoggle\",function(t){t.style(\"cursor\",\"pointer\").attr(\"pointer-events\",\"all\").call(u.fill,\"rgba(0,0,0,0)\")});s.on(\"mousedown\",function(){(r=(new Date).getTime())-e._legendMouseDownTime<a?o+=1:(o=1,e._legendMouseDownTime=r)}),s.on(\"mouseup\",function(){if(!e._dragged&&!e._editing){var r=e._fullLayout.legend;(new Date).getTime()-e._legendMouseDownTime>a&&(o=Math.max(o-1,1)),_(e,r,t,o,n.event)}})}function A(t,e,r){var a=t._fullLayout,o=a.legend,s=o.borderwidth,l=b.isGrouped(o),u=0;if(o._width=0,o._height=0,b.isVertical(o))l&&e.each(function(t,e){c.setTranslate(this,0,e*o.tracegroupgap)}),r.each(function(t){var e=t[0],r=e.height,n=e.width;c.setTranslate(this,s,5+s+o._height+r/2),o._height+=r,o._width=Math.max(o._width,n)}),o._width+=45+2*s,o._height+=10+2*s,l&&(o._height+=(o._lgroupsLength-1)*o.tracegroupgap),u=40;else if(l){var h,f=0,p=0,d=e.data(),g=0;for(h=0;h<d.length;h++){var v=d[h],m=v.map(function(t){return t[0].width}),y=i.aggNums(Math.max,null,m),x=v.reduce(function(t,e){return t+e[0].height},0);p=Math.max(p,y),f=Math.max(f,x),g=Math.max(g,v.length)}p+=5,p+=40;var _=[o._width],w=[],k=0;for(h=0;h<d.length;h++){a._size.w<s+o._width+5+p?(_[_.length-1]=_[0],o._width=p,k++):o._width+=p+s;var T=k*f;T+=k>0?o.tracegroupgap:0,w.push(T),_.push(o._width)}e.each(function(t,e){c.setTranslate(this,_[e],w[e])}),e.each(function(){var t=n.select(this).selectAll(\"g.traces\"),e=0;t.each(function(t){var r=t[0].height;c.setTranslate(this,0,5+s+e+r/2),e+=r})});var A=w[w.length-1]+f;o._height=10+2*s+A;var M=Math.max.apply(null,_);o._width=M+p+40,o._width+=2*s}else{var S=0,E=0,C=0,L=0,P=0;r.each(function(t){C=Math.max(40+t[0].width,C),P+=40+t[0].width+5});var O=a._size.w>s+P-5;r.each(function(t){var e=t[0],r=O?40+t[0].width:C;s+L+5+r>a._size.w&&(L=0,S+=E,o._height+=E,E=0),c.setTranslate(this,s+L,5+s+e.height/2+S),o._width+=5+r,L+=5+r,E=Math.max(e.height,E)}),O?o._height=E:o._height+=E,o._width+=2*s,o._height+=10+2*s}o._width=Math.ceil(o._width),o._height=Math.ceil(o._height);var z=t._context.edits.legendText||t._context.edits.legendPosition;r.each(function(t){var e=t[0],r=n.select(this).select(\".legendtoggle\");c.setRect(r,0,-e.height/2,(z?0:o._width)+u,e.height)})}function M(t){var e=t._fullLayout.legend,r=\"left\";i.isRightAnchor(e)?r=\"right\":i.isCenterAnchor(e)&&(r=\"center\");var n=\"top\";i.isBottomAnchor(e)?n=\"bottom\":i.isMiddleAnchor(e)&&(n=\"middle\"),a.autoMargin(t,\"legend\",{x:e.x,y:e.y,l:e._width*v[r],r:e._width*m[r],b:e._height*m[n],t:e._height*v[n]})}e.exports=function(t){var e=t._fullLayout,r=\"legend\"+e._uid;if(e._infolayer&&t.calcdata){t._legendMouseDownTime||(t._legendMouseDownTime=0);var s=e.legend,h=e.showlegend&&y(t.calcdata,s),f=e.hiddenlabels||[];if(!e.showlegend||!h.length)return e._infolayer.selectAll(\".legend\").remove(),e._topdefs.select(\"#\"+r).remove(),void a.autoMargin(t,\"legend\");for(var d=0,g=0;g<h.length;g++)for(var b=0;b<h[g].length;b++){var k=h[g][b][0],S=k.trace,E=o.traceIs(S,\"pie-like\")?k.label:S.name;d=Math.max(d,E&&E.length||0)}var C=!1,L=i.ensureSingle(e._infolayer,\"g\",\"legend\",function(t){t.attr(\"pointer-events\",\"all\"),C=!0}),P=i.ensureSingleById(e._topdefs,\"clipPath\",r,function(t){t.append(\"rect\")}),O=i.ensureSingle(L,\"rect\",\"bg\",function(t){t.attr(\"shape-rendering\",\"crispEdges\")});O.call(u.stroke,s.bordercolor).call(u.fill,s.bgcolor).style(\"stroke-width\",s.borderwidth+\"px\");var z=i.ensureSingle(L,\"g\",\"scrollbox\"),I=i.ensureSingle(L,\"rect\",\"scrollbar\",function(t){t.attr({rx:20,ry:3,width:0,height:0}).call(u.fill,\"#808BA4\")}),D=z.selectAll(\"g.groups\").data(h);D.enter().append(\"g\").attr(\"class\",\"groups\"),D.exit().remove();var R=D.selectAll(\"g.traces\").data(i.identity);R.enter().append(\"g\").attr(\"class\",\"traces\"),R.exit().remove(),R.style(\"opacity\",function(t){var e=t[0].trace;return o.traceIs(e,\"pie-like\")?-1!==f.indexOf(t[0].label)?.5:1:\"legendonly\"===e.visible?.5:1}).each(function(){n.select(this).call(w,t,d)}).call(x,t).each(function(){n.select(this).call(T,t)}),i.syncOrAsync([a.previousPromises,function(){C&&(A(t,D,R),M(t));var u=e.width,h=e.height;A(t,D,R),s._height>h?function(t){var e=t._fullLayout.legend,r=\"left\";i.isRightAnchor(e)?r=\"right\":i.isCenterAnchor(e)&&(r=\"center\");a.autoMargin(t,\"legend\",{x:e.x,y:.5,l:e._width*v[r],r:e._width*m[r],b:0,t:0})}(t):M(t);var f=e._size,d=f.l+f.w*s.x,g=f.t+f.h*(1-s.y);i.isRightAnchor(s)?d-=s._width:i.isCenterAnchor(s)&&(d-=s._width/2),i.isBottomAnchor(s)?g-=s._height:i.isMiddleAnchor(s)&&(g-=s._height/2);var y=s._width,x=f.w;y>x?(d=f.l,y=x):(d+y>u&&(d=u-y),d<0&&(d=0),y=Math.min(u-d,s._width));var b,w,k,T,S=s._height,E=f.h;if(S>E?(g=f.t,S=E):(g+S>h&&(g=h-S),g<0&&(g=0),S=Math.min(h-g,s._height)),c.setTranslate(L,d,g),I.on(\".drag\",null),L.on(\"wheel\",null),s._height<=S||t._context.staticPlot)O.attr({width:y-s.borderwidth,height:S-s.borderwidth,x:s.borderwidth/2,y:s.borderwidth/2}),c.setTranslate(z,0,0),P.select(\"rect\").attr({width:y-2*s.borderwidth,height:S-2*s.borderwidth,x:s.borderwidth,y:s.borderwidth}),c.setClipUrl(z,r,t),c.setRect(I,0,0,0,0),delete s._scrollY;else{var F,B,N=Math.max(p.scrollBarMinHeight,S*S/s._height),j=S-N-2*p.scrollBarMargin,U=s._height-S,V=j/U,q=Math.min(s._scrollY||0,U);O.attr({width:y-2*s.borderwidth+p.scrollBarWidth+p.scrollBarMargin,height:S-s.borderwidth,x:s.borderwidth/2,y:s.borderwidth/2}),P.select(\"rect\").attr({width:y-2*s.borderwidth+p.scrollBarWidth+p.scrollBarMargin,height:S-2*s.borderwidth,x:s.borderwidth,y:s.borderwidth+q}),c.setClipUrl(z,r,t),G(q,N,V),L.on(\"wheel\",function(){G(q=i.constrain(s._scrollY+n.event.deltaY/j*U,0,U),N,V),0!==q&&q!==U&&n.event.preventDefault()});var H=n.behavior.drag().on(\"dragstart\",function(){F=n.event.sourceEvent.clientY,B=q}).on(\"drag\",function(){var t=n.event.sourceEvent;2===t.buttons||t.ctrlKey||G(q=i.constrain((t.clientY-F)/V+B,0,U),N,V)});I.call(H)}function G(e,r,n){s._scrollY=t._fullLayout.legend._scrollY=e,c.setTranslate(z,0,-e),c.setRect(I,y,p.scrollBarMargin+e*n,p.scrollBarWidth,r),P.select(\"rect\").attr({y:s.borderwidth+e})}t._context.edits.legendPosition&&(L.classed(\"cursor-move\",!0),l.init({element:L.node(),gd:t,prepFn:function(){var t=c.getTranslate(L);k=t.x,T=t.y},moveFn:function(t,e){var r=k+t,n=T+e;c.setTranslate(L,r,n),b=l.align(r,0,f.l,f.l+f.w,s.xanchor),w=l.align(n,0,f.t+f.h,f.t,s.yanchor)},doneFn:function(){void 0!==b&&void 0!==w&&o.call(\"_guiRelayout\",t,{\"legend.x\":b,\"legend.y\":w})},clickFn:function(r,n){var i=e._infolayer.selectAll(\"g.traces\").filter(function(){var t=this.getBoundingClientRect();return n.clientX>=t.left&&n.clientX<=t.right&&n.clientY>=t.top&&n.clientY<=t.bottom});i.size()>0&&_(t,L,i,r,n)}}))}],t)}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/events\":709,\"../../lib/svg_text_utils\":743,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"./constants\":643,\"./get_legend_data\":646,\"./handle_click\":647,\"./helpers\":648,\"./style\":650,d3:163}],646:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./helpers\");e.exports=function(t,e){var r,a,o={},s=[],l=!1,c={},u=0;function h(t,r){if(\"\"!==t&&i.isGrouped(e))-1===s.indexOf(t)?(s.push(t),l=!0,o[t]=[[r]]):o[t].push([r]);else{var n=\"~~i\"+u;s.push(n),o[n]=[[r]],u++}}for(r=0;r<t.length;r++){var f=t[r],p=f[0],d=p.trace,g=d.legendgroup;if(d.visible&&d.showlegend)if(n.traceIs(d,\"pie-like\"))for(c[g]||(c[g]={}),a=0;a<f.length;a++){var v=f[a].label;c[g][v]||(h(g,{label:v,color:f[a].color,i:f[a].i,trace:d,pts:f[a].pts}),c[g][v]=!0)}else h(g,p)}if(!s.length)return[];var m,y,x=s.length;if(l&&i.isGrouped(e))for(y=new Array(x),r=0;r<x;r++)m=o[s[r]],y[r]=i.isReversed(e)?m.reverse():m;else{for(y=[new Array(x)],r=0;r<x;r++)m=o[s[r]][0],y[0][i.isReversed(e)?x-r-1:r]=m;x=1}return e._lgroupsLength=x,y}},{\"../../registry\":847,\"./helpers\":648}],647:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=!0;e.exports=function(t,e,r){var o=e._fullLayout;if(!e._dragged&&!e._editing){var s,l=o.legend.itemclick,c=o.legend.itemdoubleclick;if(1===r&&\"toggle\"===l&&\"toggleothers\"===c&&a&&e.data&&e._context.showTips?(n.notifier(n._(e,\"Double-click on legend to isolate one trace\"),\"long\"),a=!1):a=!1,1===r?s=l:2===r&&(s=c),s){var u,h,f,p,d,g=o.hiddenlabels?o.hiddenlabels.slice():[],v=t.data()[0][0],m=e._fullData,y=v.trace,x=y.legendgroup,b={},_=[],w=[],k=[];if(i.traceIs(y,\"pie-like\")){var T=v.label,A=g.indexOf(T);\"toggle\"===s?-1===A?g.push(T):g.splice(A,1):\"toggleothers\"===s&&(g=[],e.calcdata[0].forEach(function(t){T!==t.label&&g.push(t.label)}),e._fullLayout.hiddenlabels&&e._fullLayout.hiddenlabels.length===g.length&&-1===A&&(g=[])),i.call(\"_guiRelayout\",e,\"hiddenlabels\",g)}else{var M,S=x&&x.length,E=[];if(S)for(u=0;u<m.length;u++)(M=m[u]).visible&&M.legendgroup===x&&E.push(u);if(\"toggle\"===s){var C;switch(y.visible){case!0:C=\"legendonly\";break;case!1:C=!1;break;case\"legendonly\":C=!0}if(S)for(u=0;u<m.length;u++)!1!==m[u].visible&&m[u].legendgroup===x&&R(m[u],C);else R(y,C)}else if(\"toggleothers\"===s){var L,P,O=!0;for(u=0;u<m.length;u++)if(!(m[u]===y)&&!(L=S&&m[u].legendgroup===x)&&!0===m[u].visible&&!i.traceIs(m[u],\"notLegendIsolatable\")){O=!1;break}for(u=0;u<m.length;u++)if(!1!==m[u].visible&&!i.traceIs(m[u],\"notLegendIsolatable\"))switch(y.visible){case\"legendonly\":R(m[u],!0);break;case!0:P=!!O||\"legendonly\",L=m[u]===y||S&&m[u].legendgroup===x,R(m[u],!!L||P)}}for(u=0;u<w.length;u++)if(f=w[u]){var z=f.constructUpdate(),I=Object.keys(z);for(h=0;h<I.length;h++)p=I[h],(b[p]=b[p]||[])[k[u]]=z[p]}for(d=Object.keys(b),u=0;u<d.length;u++)for(p=d[u],h=0;h<_.length;h++)b[p].hasOwnProperty(h)||(b[p][h]=void 0);i.call(\"_guiRestyle\",e,b,_)}}}function D(t,e,r){var n=_.indexOf(t),i=b[e];return i||(i=b[e]=[]),-1===_.indexOf(t)&&(_.push(t),n=_.length-1),i[n]=r,n}function R(t,e){var r=t._fullInput;if(i.hasTransform(r,\"groupby\")){var a=w[r.index];if(!a){var o=i.getTransformIndices(r,\"groupby\"),s=o[o.length-1];a=n.keyedContainer(r,\"transforms[\"+s+\"].styles\",\"target\",\"value.visible\"),w[r.index]=a}var l=a.get(t._group);void 0===l&&(l=!0),!1!==l&&a.set(t._group,e),k[r.index]=D(r.index,\"visible\",!1!==r.visible)}else{var c=!1!==r.visible&&e;D(r.index,\"visible\",c)}}}},{\"../../lib\":719,\"../../registry\":847}],648:[function(t,e,r){\"use strict\";r.isGrouped=function(t){return-1!==(t.traceorder||\"\").indexOf(\"grouped\")},r.isVertical=function(t){return\"h\"!==t.orientation},r.isReversed=function(t){return-1!==(t.traceorder||\"\").indexOf(\"reversed\")}},{}],649:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"legend\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\"),style:t(\"./style\")}},{\"./attributes\":642,\"./defaults\":644,\"./draw\":645,\"./style\":650}],650:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../drawing\"),s=t(\"../color\"),l=t(\"../../traces/scatter/subtypes\"),c=t(\"../../traces/pie/style_one\"),u=t(\"../../traces/pie/helpers\").castOption,h=12,f=5,p=2,d=10,g=5;e.exports=function(t,e){var r=e._fullLayout.legend,v=\"constant\"===r.itemsizing;function m(t,e,r,n){var i;if(t+1)i=t;else{if(!(e&&e.width>0))return 0;i=e.width}return v?n:Math.min(i,r)}function y(t,e,r){var a=t[0].trace,o=a.marker||{},l=o.line||{},c=r?a.type===r&&a.visible:i.traceIs(a,\"bar\"),u=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(c?[t]:[]);u.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),u.exit().remove(),u.each(function(t){var e=n.select(this),r=t[0],i=m(r.mlw,o.line,g,p);e.style(\"stroke-width\",i+\"px\").call(s.fill,r.mc||o.color),i&&s.stroke(e,r.mlc||l.color)})}function x(t,e,r){var o=t[0],s=o.trace,l=r?s.type===r&&s.visible:i.traceIs(s,r),h=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(l?[t]:[]);if(h.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),h.exit().remove(),h.size()){var f=(s.marker||{}).line,d=m(u(f.width,o.pts),f,g,p),v=a.minExtend(s,{marker:{line:{width:d}}});v.marker.line.color=f.color;var y=a.minExtend(o,{trace:v});c(h,y,v)}}t.each(function(t){var e=n.select(this),i=a.ensureSingle(e,\"g\",\"layers\");i.style(\"opacity\",t[0].trace.opacity);var o=r.valign,s=t[0].lineHeight,l=t[0].height;if(\"middle\"!==o&&s&&l){var c={top:1,bottom:-1}[o]*(.5*(s-l+3));i.attr(\"transform\",\"translate(0,\"+c+\")\")}else i.attr(\"transform\",null);i.selectAll(\"g.legendfill\").data([t]).enter().append(\"g\").classed(\"legendfill\",!0),i.selectAll(\"g.legendlines\").data([t]).enter().append(\"g\").classed(\"legendlines\",!0);var u=i.selectAll(\"g.legendsymbols\").data([t]);u.enter().append(\"g\").classed(\"legendsymbols\",!0),u.selectAll(\"g.legendpoints\").data([t]).enter().append(\"g\").classed(\"legendpoints\",!0)}).each(function(t){var e=t[0].trace,r=[];\"waterfall\"===e.type&&e.visible&&(r=t[0].hasTotals?[[\"increasing\",\"M-6,-6V6H0Z\"],[\"totals\",\"M6,6H0L-6,-6H-0Z\"],[\"decreasing\",\"M6,6V-6H0Z\"]]:[[\"increasing\",\"M-6,-6V6H6Z\"],[\"decreasing\",\"M6,6V-6H-6Z\"]]);var i=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendwaterfall\").data(r);i.enter().append(\"path\").classed(\"legendwaterfall\",!0).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),i.exit().remove(),i.each(function(t){var r=n.select(this),i=e[t[0]].marker,a=m(void 0,i.line,g,p);r.attr(\"d\",t[1]).style(\"stroke-width\",a+\"px\").call(s.fill,i.color),a&&r.call(s.stroke,i.line.color)})}).each(function(t){y(t,this,\"funnel\")}).each(function(t){y(t,this)}).each(function(t){var r=t[0].trace,l=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendbox\").data(i.traceIs(r,\"box-violin\")&&r.visible?[t]:[]);l.enter().append(\"path\").classed(\"legendbox\",!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),l.exit().remove(),l.each(function(){var t=n.select(this);if(\"all\"!==r.boxpoints&&\"all\"!==r.points||0!==s.opacity(r.fillcolor)||0!==s.opacity((r.line||{}).color)){var i=m(void 0,r.line,g,p);t.style(\"stroke-width\",i+\"px\").call(s.fill,r.fillcolor),i&&s.stroke(t,r.line.color)}else{var c=a.minExtend(r,{marker:{size:v?h:a.constrain(r.marker.size,2,16),sizeref:1,sizemin:1,sizemode:\"diameter\"}});l.call(o.pointStyle,c,e)}})}).each(function(t){x(t,this,\"funnelarea\")}).each(function(t){x(t,this,\"pie\")}).each(function(t){var r,i,s=t[0],c=s.trace,u=c.visible&&c.fill&&\"none\"!==c.fill,h=l.hasLines(c),p=c.contours,g=!1,v=!1;if(p){var y=p.coloring;\"lines\"===y?g=!0:h=\"none\"===y||\"heatmap\"===y||p.showlines,\"constraint\"===p.type?u=\"=\"!==p._operation:\"fill\"!==y&&\"heatmap\"!==y||(v=!0)}var x=l.hasMarkers(c)||l.hasText(c),b=u||v,_=h||g,w=x||!b?\"M5,0\":_?\"M5,-2\":\"M5,-3\",k=n.select(this),T=k.select(\".legendfill\").selectAll(\"path\").data(u||v?[t]:[]);if(T.enter().append(\"path\").classed(\"js-fill\",!0),T.exit().remove(),T.attr(\"d\",w+\"h30v6h-30z\").call(u?o.fillGroupStyle:function(t){if(t.size()){var r=\"legendfill-\"+c.uid;o.gradient(t,e,r,\"horizontalreversed\",c.colorscale,\"fill\")}}),h||g){var A=m(void 0,c.line,d,f);i=a.minExtend(c,{line:{width:A}}),r=[a.minExtend(s,{trace:i})]}var M=k.select(\".legendlines\").selectAll(\"path\").data(h||g?[r]:[]);M.enter().append(\"path\").classed(\"js-line\",!0),M.exit().remove(),M.attr(\"d\",w+(g?\"l30,0.0001\":\"h30\")).call(h?o.lineGroupStyle:function(t){if(t.size()){var r=\"legendline-\"+c.uid;o.lineGroupStyle(t),o.gradient(t,e,r,\"horizontalreversed\",c.colorscale,\"stroke\")}})}).each(function(t){var r,i,s=t[0],c=s.trace,u=l.hasMarkers(c),d=l.hasText(c),g=l.hasLines(c);function m(t,e,r,n){var i=a.nestedProperty(c,t).get(),o=a.isArrayOrTypedArray(i)&&e?e(i):i;if(v&&o&&void 0!==n&&(o=n),r){if(o<r[0])return r[0];if(o>r[1])return r[1]}return o}function y(t){return t[0]}if(u||d||g){var x={},b={};if(u){x.mc=m(\"marker.color\",y),x.mx=m(\"marker.symbol\",y),x.mo=m(\"marker.opacity\",a.mean,[.2,1]),x.mlc=m(\"marker.line.color\",y),x.mlw=m(\"marker.line.width\",a.mean,[0,5],p),b.marker={sizeref:1,sizemin:1,sizemode:\"diameter\"};var _=m(\"marker.size\",a.mean,[2,16],h);x.ms=_,b.marker.size=_}g&&(b.line={width:m(\"line.width\",y,[0,10],f)}),d&&(x.tx=\"Aa\",x.tp=m(\"textposition\",y),x.ts=10,x.tc=m(\"textfont.color\",y),x.tf=m(\"textfont.family\",y)),r=[a.minExtend(s,x)],(i=a.minExtend(c,b)).selectedpoints=null}var w=n.select(this).select(\"g.legendpoints\"),k=w.selectAll(\"path.scatterpts\").data(u?r:[]);k.enter().insert(\"path\",\":first-child\").classed(\"scatterpts\",!0).attr(\"transform\",\"translate(20,0)\"),k.exit().remove(),k.call(o.pointStyle,i,e),u&&(r[0].mrc=3);var T=w.selectAll(\"g.pointtext\").data(d?r:[]);T.enter().append(\"g\").classed(\"pointtext\",!0).append(\"text\").attr(\"transform\",\"translate(20,0)\"),T.exit().remove(),T.selectAll(\"text\").call(o.textPointStyle,i,e)}).each(function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendcandle\").data(\"candlestick\"===e.type&&e.visible?[t,t]:[]);r.enter().append(\"path\").classed(\"legendcandle\",!0).attr(\"d\",function(t,e){return e?\"M-15,0H-8M-8,6V-6H8Z\":\"M15,0H8M8,-6V6H-8Z\"}).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),r.exit().remove(),r.each(function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],o=m(void 0,a.line,g,p);i.style(\"stroke-width\",o+\"px\").call(s.fill,a.fillcolor),o&&s.stroke(i,a.line.color)})}).each(function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendohlc\").data(\"ohlc\"===e.type&&e.visible?[t,t]:[]);r.enter().append(\"path\").classed(\"legendohlc\",!0).attr(\"d\",function(t,e){return e?\"M-15,0H0M-8,-6V0\":\"M15,0H0M8,6V0\"}).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),r.exit().remove(),r.each(function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],l=m(void 0,a.line,g,p);i.style(\"fill\",\"none\").call(o.dashLine,a.line.dash,l),l&&s.stroke(i,a.line.color)})})}},{\"../../lib\":719,\"../../registry\":847,\"../../traces/pie/helpers\":1091,\"../../traces/pie/style_one\":1097,\"../../traces/scatter/subtypes\":1135,\"../color\":593,\"../drawing\":614,d3:163}],651:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/plots\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../lib\"),s=t(\"../../fonts/ploticon\"),l=o._,c=e.exports={};function u(t,e){var r,i,o=e.currentTarget,s=o.getAttribute(\"data-attr\"),l=o.getAttribute(\"data-val\")||!0,c=t._fullLayout,u={},h=a.list(t,null,!0),f=\"on\";if(\"zoom\"===s){var p,d=\"in\"===l?.5:2,g=(1+d)/2,v=(1-d)/2;for(i=0;i<h.length;i++)if(!(r=h[i]).fixedrange)if(p=r._name,\"auto\"===l)u[p+\".autorange\"]=!0;else if(\"reset\"===l){if(void 0===r._rangeInitial)u[p+\".autorange\"]=!0;else{var m=r._rangeInitial.slice();u[p+\".range[0]\"]=m[0],u[p+\".range[1]\"]=m[1]}void 0!==r._showSpikeInitial&&(u[p+\".showspikes\"]=r._showSpikeInitial,\"on\"!==f||r._showSpikeInitial||(f=\"off\"))}else{var y=[r.r2l(r.range[0]),r.r2l(r.range[1])],x=[g*y[0]+v*y[1],g*y[1]+v*y[0]];u[p+\".range[0]\"]=r.l2r(x[0]),u[p+\".range[1]\"]=r.l2r(x[1])}c._cartesianSpikesEnabled=f}else{if(\"hovermode\"!==s||\"x\"!==l&&\"y\"!==l){if(\"hovermode\"===s&&\"closest\"===l){for(i=0;i<h.length;i++)r=h[i],\"on\"!==f||r.showspikes||(f=\"off\");c._cartesianSpikesEnabled=f}}else l=c._isHoriz?\"y\":\"x\",o.setAttribute(\"data-val\",l);u[s]=l}n.call(\"_guiRelayout\",t,u)}function h(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout._subplots.gl3d,s={},l=i.split(\".\"),c=0;c<o.length;c++)s[o[c]+\".\"+l[1]]=a;var u=\"pan\"===a?a:\"zoom\";s.dragmode=u,n.call(\"_guiRelayout\",t,s)}function f(t,e){for(var r=e.currentTarget.getAttribute(\"data-attr\"),i=t._fullLayout,a=i._subplots.gl3d,o={},s=0;s<a.length;s++){var l=a[s],c=l+\".camera\",u=i[l]._scene;\"resetLastSave\"===r?(o[c+\".up\"]=u.viewInitial.up,o[c+\".eye\"]=u.viewInitial.eye,o[c+\".center\"]=u.viewInitial.center):\"resetDefault\"===r&&(o[c+\".up\"]=null,o[c+\".eye\"]=null,o[c+\".center\"]=null)}n.call(\"_guiRelayout\",t,o)}function p(t,e){var r=e.currentTarget,n=r._previousVal,i=t._fullLayout,a=i._subplots.gl3d,o=[\"xaxis\",\"yaxis\",\"zaxis\"],s={},l={};if(n)l=n,r._previousVal=null;else{for(var c=0;c<a.length;c++){var u=a[c],h=i[u],f=u+\".hovermode\";s[f]=h.hovermode,l[f]=!1;for(var p=0;p<3;p++){var d=o[p],g=u+\".\"+d+\".showspikes\";l[g]=!1,s[g]=h[d].showspikes}}r._previousVal=s}return l}function d(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout,s=o._subplots.geo,l=0;l<s.length;l++){var c=s[l],u=o[c];if(\"zoom\"===i){var h=u.projection.scale,f=\"in\"===a?2*h:.5*h;n.call(\"_guiRelayout\",t,c+\".projection.scale\",f)}else\"reset\"===i&&m(t,\"geo\")}}function g(t){var e=t._fullLayout;return!e.hovermode&&(e._has(\"cartesian\")?e._isHoriz?\"y\":\"x\":\"closest\")}function v(t){var e=g(t);n.call(\"_guiRelayout\",t,\"hovermode\",e)}function m(t,e){for(var r=t._fullLayout,i=r._subplots[e],a={},o=0;o<i.length;o++)for(var s=i[o],l=r[s]._subplot.viewInitial,c=Object.keys(l),u=0;u<c.length;u++){var h=c[u];a[s+\".\"+h]=l[h]}n.call(\"_guiRelayout\",t,a)}c.toImage={name:\"toImage\",title:function(t){var e=(t._context.toImageButtonOptions||{}).format||\"png\";return l(t,\"png\"===e?\"Download plot as a png\":\"Download plot\")},icon:s.camera,click:function(t){var e=t._context.toImageButtonOptions,r={format:e.format||\"png\"};o.notifier(l(t,\"Taking snapshot - this may take a few seconds\"),\"long\"),\"svg\"!==r.format&&o.isIE()&&(o.notifier(l(t,\"IE only supports svg.  Changing format to svg.\"),\"long\"),r.format=\"svg\"),[\"filename\",\"width\",\"height\",\"scale\"].forEach(function(t){t in e&&(r[t]=e[t])}),n.call(\"downloadImage\",t,r).then(function(e){o.notifier(l(t,\"Snapshot succeeded\")+\" - \"+e,\"long\")}).catch(function(){o.notifier(l(t,\"Sorry, there was a problem downloading your snapshot!\"),\"long\")})}},c.sendDataToCloud={name:\"sendDataToCloud\",title:function(t){return l(t,\"Edit in Chart Studio\")},icon:s.disk,click:function(t){i.sendDataToCloud(t)}},c.editInChartStudio={name:\"editInChartStudio\",title:function(t){return l(t,\"Edit in Chart Studio\")},icon:s.pencil,click:function(t){i.sendDataToCloud(t)}},c.zoom2d={name:\"zoom2d\",title:function(t){return l(t,\"Zoom\")},attr:\"dragmode\",val:\"zoom\",icon:s.zoombox,click:u},c.pan2d={name:\"pan2d\",title:function(t){return l(t,\"Pan\")},attr:\"dragmode\",val:\"pan\",icon:s.pan,click:u},c.select2d={name:\"select2d\",title:function(t){return l(t,\"Box Select\")},attr:\"dragmode\",val:\"select\",icon:s.selectbox,click:u},c.lasso2d={name:\"lasso2d\",title:function(t){return l(t,\"Lasso Select\")},attr:\"dragmode\",val:\"lasso\",icon:s.lasso,click:u},c.zoomIn2d={name:\"zoomIn2d\",title:function(t){return l(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:s.zoom_plus,click:u},c.zoomOut2d={name:\"zoomOut2d\",title:function(t){return l(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:s.zoom_minus,click:u},c.autoScale2d={name:\"autoScale2d\",title:function(t){return l(t,\"Autoscale\")},attr:\"zoom\",val:\"auto\",icon:s.autoscale,click:u},c.resetScale2d={name:\"resetScale2d\",title:function(t){return l(t,\"Reset axes\")},attr:\"zoom\",val:\"reset\",icon:s.home,click:u},c.hoverClosestCartesian={name:\"hoverClosestCartesian\",title:function(t){return l(t,\"Show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:s.tooltip_basic,gravity:\"ne\",click:u},c.hoverCompareCartesian={name:\"hoverCompareCartesian\",title:function(t){return l(t,\"Compare data on hover\")},attr:\"hovermode\",val:function(t){return t._fullLayout._isHoriz?\"y\":\"x\"},icon:s.tooltip_compare,gravity:\"ne\",click:u},c.zoom3d={name:\"zoom3d\",title:function(t){return l(t,\"Zoom\")},attr:\"scene.dragmode\",val:\"zoom\",icon:s.zoombox,click:h},c.pan3d={name:\"pan3d\",title:function(t){return l(t,\"Pan\")},attr:\"scene.dragmode\",val:\"pan\",icon:s.pan,click:h},c.orbitRotation={name:\"orbitRotation\",title:function(t){return l(t,\"Orbital rotation\")},attr:\"scene.dragmode\",val:\"orbit\",icon:s[\"3d_rotate\"],click:h},c.tableRotation={name:\"tableRotation\",title:function(t){return l(t,\"Turntable rotation\")},attr:\"scene.dragmode\",val:\"turntable\",icon:s[\"z-axis\"],click:h},c.resetCameraDefault3d={name:\"resetCameraDefault3d\",title:function(t){return l(t,\"Reset camera to default\")},attr:\"resetDefault\",icon:s.home,click:f},c.resetCameraLastSave3d={name:\"resetCameraLastSave3d\",title:function(t){return l(t,\"Reset camera to last save\")},attr:\"resetLastSave\",icon:s.movie,click:f},c.hoverClosest3d={name:\"hoverClosest3d\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=p(t,e);n.call(\"_guiRelayout\",t,r)}},c.zoomInGeo={name:\"zoomInGeo\",title:function(t){return l(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:s.zoom_plus,click:d},c.zoomOutGeo={name:\"zoomOutGeo\",title:function(t){return l(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:s.zoom_minus,click:d},c.resetGeo={name:\"resetGeo\",title:function(t){return l(t,\"Reset\")},attr:\"reset\",val:null,icon:s.autoscale,click:d},c.hoverClosestGeo={name:\"hoverClosestGeo\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:v},c.hoverClosestGl2d={name:\"hoverClosestGl2d\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:v},c.hoverClosestPie={name:\"hoverClosestPie\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:s.tooltip_basic,gravity:\"ne\",click:v},c.resetViewSankey={name:\"resetSankeyGroup\",title:function(t){return l(t,\"Reset view\")},icon:s.home,click:function(t){for(var e={\"node.groups\":[],\"node.x\":[],\"node.y\":[]},r=0;r<t._fullData.length;r++){var i=t._fullData[r]._viewInitial;e[\"node.groups\"].push(i.node.groups.slice()),e[\"node.x\"].push(i.node.x.slice()),e[\"node.y\"].push(i.node.y.slice())}n.call(\"restyle\",t,e)}},c.toggleHover={name:\"toggleHover\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=p(t,e);r.hovermode=g(t),n.call(\"_guiRelayout\",t,r)}},c.resetViews={name:\"resetViews\",title:function(t){return l(t,\"Reset views\")},icon:s.home,click:function(t,e){var r=e.currentTarget;r.setAttribute(\"data-attr\",\"zoom\"),r.setAttribute(\"data-val\",\"reset\"),u(t,e),r.setAttribute(\"data-attr\",\"resetLastSave\"),f(t,e),m(t,\"geo\"),m(t,\"mapbox\")}},c.toggleSpikelines={name:\"toggleSpikelines\",title:function(t){return l(t,\"Toggle Spike Lines\")},icon:s.spikeline,attr:\"_cartesianSpikesEnabled\",val:\"on\",click:function(t){var e=t._fullLayout;e._cartesianSpikesEnabled=\"on\"===e._cartesianSpikesEnabled?\"off\":\"on\";var r=function(t){for(var e,r,n=t._fullLayout,i=a.list(t,null,!0),o={},s=0;s<i.length;s++)e=i[s],r=e._name,o[r+\".showspikes\"]=\"on\"===n._cartesianSpikesEnabled||e._showSpikeInitial;return o}(t);n.call(\"_guiRelayout\",t,r)}},c.resetViewMapbox={name:\"resetViewMapbox\",title:function(t){return l(t,\"Reset view\")},attr:\"reset\",icon:s.home,click:function(t){m(t,\"mapbox\")}}},{\"../../fonts/ploticon\":699,\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../../plots/plots\":828,\"../../registry\":847}],652:[function(t,e,r){\"use strict\";r.manage=t(\"./manage\")},{\"./manage\":653}],653:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"../../traces/scatter/subtypes\"),a=t(\"../../registry\"),o=t(\"./modebar\"),s=t(\"./buttons\");e.exports=function(t){var e=t._fullLayout,r=t._context,l=e._modeBar;if(r.displayModeBar||r.watermark){if(!Array.isArray(r.modeBarButtonsToRemove))throw new Error([\"*modeBarButtonsToRemove* configuration options\",\"must be an array.\"].join(\" \"));if(!Array.isArray(r.modeBarButtonsToAdd))throw new Error([\"*modeBarButtonsToAdd* configuration options\",\"must be an array.\"].join(\" \"));var c,u=r.modeBarButtons;c=Array.isArray(u)&&u.length?function(t){for(var e=0;e<t.length;e++)for(var r=t[e],n=0;n<r.length;n++){var i=r[n];if(\"string\"==typeof i){if(void 0===s[i])throw new Error([\"*modeBarButtons* configuration options\",\"invalid button name\"].join(\" \"));t[e][n]=s[i]}}return t}(u):!r.displayModeBar&&r.watermark?[]:function(t){var e=t._fullLayout,r=t._fullData,o=t._context,l=o.modeBarButtonsToRemove,c=o.modeBarButtonsToAdd,u=e._has(\"cartesian\"),h=e._has(\"gl3d\"),f=e._has(\"geo\"),p=e._has(\"pie\"),d=e._has(\"funnelarea\"),g=e._has(\"gl2d\"),v=e._has(\"ternary\"),m=e._has(\"mapbox\"),y=e._has(\"polar\"),x=e._has(\"sankey\"),b=function(t){for(var e=n.list({_fullLayout:t},null,!0),r=0;r<e.length;r++)if(!e[r].fixedrange)return!1;return!0}(e),_=[];function w(t){if(t.length){for(var e=[],r=0;r<t.length;r++){var n=t[r];-1===l.indexOf(n)&&e.push(s[n])}_.push(e)}}var k=[\"toImage\"];o.showEditInChartStudio?k.push(\"editInChartStudio\"):o.showSendToCloud&&k.push(\"sendDataToCloud\");w(k);var T=[],A=[],M=[],S=[];(u||g||p||d||v)+f+h+m+y>1?(A=[\"toggleHover\"],M=[\"resetViews\"]):f?(T=[\"zoomInGeo\",\"zoomOutGeo\"],A=[\"hoverClosestGeo\"],M=[\"resetGeo\"]):h?(A=[\"hoverClosest3d\"],M=[\"resetCameraDefault3d\",\"resetCameraLastSave3d\"]):m?(A=[\"toggleHover\"],M=[\"resetViewMapbox\"]):g?A=[\"hoverClosestGl2d\"]:p?A=[\"hoverClosestPie\"]:x?(A=[\"hoverClosestCartesian\",\"hoverCompareCartesian\"],M=[\"resetViewSankey\"]):A=[\"toggleHover\"];u&&(A=[\"toggleSpikelines\",\"hoverClosestCartesian\",\"hoverCompareCartesian\"]);(function(t){for(var e=0;e<t.length;e++)if(!a.traceIs(t[e],\"noHover\"))return!1;return!0})(r)&&(A=[]);!u&&!g||b||(T=[\"zoomIn2d\",\"zoomOut2d\",\"autoScale2d\"],\"resetViews\"!==M[0]&&(M=[\"resetScale2d\"]));h?S=[\"zoom3d\",\"pan3d\",\"orbitRotation\",\"tableRotation\"]:(u||g)&&!b||v?S=[\"zoom2d\",\"pan2d\"]:m||f?S=[\"pan2d\"]:y&&(S=[\"zoom2d\"]);(function(t){for(var e=!1,r=0;r<t.length&&!e;r++){var n=t[r];n._module&&n._module.selectPoints&&(a.traceIs(n,\"scatter-like\")?(i.hasMarkers(n)||i.hasText(n))&&(e=!0):a.traceIs(n,\"box-violin\")&&\"all\"!==n.boxpoints&&\"all\"!==n.points||(e=!0))}return e})(r)&&S.push(\"select2d\",\"lasso2d\");return w(S),w(T.concat(M)),w(A),function(t,e){if(e.length)if(Array.isArray(e[0]))for(var r=0;r<e.length;r++)t.push(e[r]);else t.push(e);return t}(_,c)}(t),l?l.update(t,c):e._modeBar=o(t,c)}else l&&(l.destroy(),delete e._modeBar)}},{\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../../traces/scatter/subtypes\":1135,\"./buttons\":651,\"./modebar\":654}],654:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../fonts/ploticon\"),s=new DOMParser;function l(t){this.container=t.container,this.element=document.createElement(\"div\"),this.update(t.graphInfo,t.buttons),this.container.appendChild(this.element)}var c=l.prototype;c.update=function(t,e){this.graphInfo=t;var r=this.graphInfo._context,n=this.graphInfo._fullLayout,i=\"modebar-\"+n._uid;this.element.setAttribute(\"id\",i),this._uid=i,this.element.className=\"modebar\",\"hover\"===r.displayModeBar&&(this.element.className+=\" modebar--hover ease-bg\"),\"v\"===n.modebar.orientation&&(this.element.className+=\" vertical\",e=e.reverse());var o=n.modebar,s=\"hover\"===r.displayModeBar?\".js-plotly-plot .plotly:hover \":\"\";a.deleteRelatedStyleRule(i),a.addRelatedStyleRule(i,s+\"#\"+i+\" .modebar-group\",\"background-color: \"+o.bgcolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn .icon path\",\"fill: \"+o.color),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn:hover .icon path\",\"fill: \"+o.activecolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn.active .icon path\",\"fill: \"+o.activecolor);var l=!this.hasButtons(e),c=this.hasLogo!==r.displaylogo,u=this.locale!==r.locale;if(this.locale=r.locale,(l||c||u)&&(this.removeAllButtons(),this.updateButtons(e),r.watermark||r.displaylogo)){var h=this.getLogo();r.watermark&&(h.className=h.className+\" watermark\"),\"v\"===n.modebar.orientation?this.element.insertBefore(h,this.element.childNodes[0]):this.element.appendChild(h),this.hasLogo=!0}this.updateActiveButton()},c.updateButtons=function(t){var e=this;this.buttons=t,this.buttonElements=[],this.buttonsNames=[],this.buttons.forEach(function(t){var r=e.createGroup();t.forEach(function(t){var n=t.name;if(!n)throw new Error(\"must provide button 'name' in button config\");if(-1!==e.buttonsNames.indexOf(n))throw new Error(\"button name '\"+n+\"' is taken\");e.buttonsNames.push(n);var i=e.createButton(t);e.buttonElements.push(i),r.appendChild(i)}),e.element.appendChild(r)})},c.createGroup=function(){var t=document.createElement(\"div\");return t.className=\"modebar-group\",t},c.createButton=function(t){var e=this,r=document.createElement(\"a\");r.setAttribute(\"rel\",\"tooltip\"),r.className=\"modebar-btn\";var i=t.title;void 0===i?i=t.name:\"function\"==typeof i&&(i=i(this.graphInfo)),(i||0===i)&&r.setAttribute(\"data-title\",i),void 0!==t.attr&&r.setAttribute(\"data-attr\",t.attr);var a=t.val;if(void 0!==a&&(\"function\"==typeof a&&(a=a(this.graphInfo)),r.setAttribute(\"data-val\",a)),\"function\"!=typeof t.click)throw new Error(\"must provide button 'click' function in button config\");r.addEventListener(\"click\",function(r){t.click(e.graphInfo,r),e.updateActiveButton(r.currentTarget)}),r.setAttribute(\"data-toggle\",t.toggle||!1),t.toggle&&n.select(r).classed(\"active\",!0);var s=t.icon;return\"function\"==typeof s?r.appendChild(s()):r.appendChild(this.createIcon(s||o.question)),r.setAttribute(\"data-gravity\",t.gravity||\"n\"),r},c.createIcon=function(t){var e,r=i(t.height)?Number(t.height):t.ascent-t.descent,n=\"http://www.w3.org/2000/svg\";if(t.path){(e=document.createElementNS(n,\"svg\")).setAttribute(\"viewBox\",[0,0,t.width,r].join(\" \")),e.setAttribute(\"class\",\"icon\");var a=document.createElementNS(n,\"path\");a.setAttribute(\"d\",t.path),t.transform?a.setAttribute(\"transform\",t.transform):void 0!==t.ascent&&a.setAttribute(\"transform\",\"matrix(1 0 0 -1 0 \"+t.ascent+\")\"),e.appendChild(a)}t.svg&&(e=s.parseFromString(t.svg,\"application/xml\").childNodes[0]);return e.setAttribute(\"height\",\"1em\"),e.setAttribute(\"width\",\"1em\"),e},c.updateActiveButton=function(t){var e=this.graphInfo._fullLayout,r=void 0!==t?t.getAttribute(\"data-attr\"):null;this.buttonElements.forEach(function(t){var i=t.getAttribute(\"data-val\")||!0,o=t.getAttribute(\"data-attr\"),s=\"true\"===t.getAttribute(\"data-toggle\"),l=n.select(t);if(s)o===r&&l.classed(\"active\",!l.classed(\"active\"));else{var c=null===o?o:a.nestedProperty(e,o).get();l.classed(\"active\",c===i)}})},c.hasButtons=function(t){var e=this.buttons;if(!e)return!1;if(t.length!==e.length)return!1;for(var r=0;r<t.length;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;n++)if(t[r][n].name!==e[r][n].name)return!1}return!0},c.getLogo=function(){var t=this.createGroup(),e=document.createElement(\"a\");return e.href=\"https://plot.ly/\",e.target=\"_blank\",e.setAttribute(\"data-title\",a._(this.graphInfo,\"Produced with Plotly\")),e.className=\"modebar-btn plotlyjsicon modebar-btn--logo\",e.appendChild(this.createIcon(o.newplotlylogo)),t.appendChild(e),t},c.removeAllButtons=function(){for(;this.element.firstChild;)this.element.removeChild(this.element.firstChild);this.hasLogo=!1},c.destroy=function(){a.removeElement(this.container.querySelector(\".modebar\")),a.deleteRelatedStyleRule(this._uid)},e.exports=function(t,e){var r=t._fullLayout,i=new l({graphInfo:t,container:r._modebardiv.node(),buttons:e});return r._privateplot&&n.select(i.element).append(\"span\").classed(\"badge-private float--left\",!0).text(\"PRIVATE\"),i}},{\"../../fonts/ploticon\":699,\"../../lib\":719,d3:163,\"fast-isnumeric\":225}],655:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=(0,t(\"../../plot_api/plot_template\").templatedArray)(\"button\",{visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},step:{valType:\"enumerated\",values:[\"month\",\"year\",\"day\",\"hour\",\"minute\",\"second\",\"all\"],dflt:\"month\",editType:\"plot\"},stepmode:{valType:\"enumerated\",values:[\"backward\",\"todate\"],dflt:\"backward\",editType:\"plot\"},count:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},label:{valType:\"string\",editType:\"plot\"},editType:\"plot\"});e.exports={visible:{valType:\"boolean\",editType:\"plot\"},buttons:a,x:{valType:\"number\",min:-2,max:3,editType:\"plot\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"plot\"},y:{valType:\"number\",min:-2,max:3,editType:\"plot\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"bottom\",editType:\"plot\"},font:n({editType:\"plot\"}),bgcolor:{valType:\"color\",dflt:i.lightLine,editType:\"plot\"},activecolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"plot\"}},{\"../../plot_api/plot_template\":757,\"../../plots/font_attributes\":793,\"../color/attributes\":592}],656:[function(t,e,r){\"use strict\";e.exports={yPad:.02,minButtonWidth:30,rx:3,ry:3,lightAmount:25,darkAmount:10}},{}],657:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../../plots/array_container_defaults\"),s=t(\"./attributes\"),l=t(\"./constants\");function c(t,e,r,i){var a=i.calendar;function o(r,i){return n.coerce(t,e,s.buttons,r,i)}if(o(\"visible\")){var l=o(\"step\");\"all\"!==l&&(!a||\"gregorian\"===a||\"month\"!==l&&\"year\"!==l?o(\"stepmode\"):e.stepmode=\"backward\",o(\"count\")),o(\"label\")}}e.exports=function(t,e,r,u,h){var f=t.rangeselector||{},p=a.newContainer(e,\"rangeselector\");function d(t,e){return n.coerce(f,p,s,t,e)}if(d(\"visible\",o(f,p,{name:\"buttons\",handleItemDefaults:c,calendar:h}).length>0)){var g=function(t,e,r){for(var n=r.filter(function(r){return e[r].anchor===t._id}),i=0,a=0;a<n.length;a++){var o=e[n[a]].domain;o&&(i=Math.max(o[1],i))}return[t.domain[0],i+l.yPad]}(e,r,u);d(\"x\",g[0]),d(\"y\",g[1]),n.noneOrAll(t,e,[\"x\",\"y\"]),d(\"xanchor\"),d(\"yanchor\"),n.coerceFont(d,\"font\",r.font);var v=d(\"bgcolor\");d(\"activecolor\",i.contrast(v,l.lightAmount,l.darkAmount)),d(\"bordercolor\"),d(\"borderwidth\")}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/array_container_defaults\":763,\"../color\":593,\"./attributes\":655,\"./constants\":656}],658:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../color\"),s=t(\"../drawing\"),l=t(\"../../lib\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"../../plots/cartesian/axis_ids\"),h=t(\"../../constants/alignment\"),f=h.LINE_SPACING,p=h.FROM_TL,d=h.FROM_BR,g=t(\"./constants\"),v=t(\"./get_update_object\");function m(t){return t._id}function y(t,e,r){var n=l.ensureSingle(t,\"rect\",\"selector-rect\",function(t){t.attr(\"shape-rendering\",\"crispEdges\")});n.attr({rx:g.rx,ry:g.ry}),n.call(o.stroke,e.bordercolor).call(o.fill,function(t,e){return e._isActive||e._isHovered?t.activecolor:t.bgcolor}(e,r)).style(\"stroke-width\",e.borderwidth+\"px\")}function x(t,e,r,n){l.ensureSingle(t,\"text\",\"selector-text\",function(t){t.classed(\"user-select-none\",!0).attr(\"text-anchor\",\"middle\")}).call(s.font,e.font).text(function(t,e){if(t.label)return e?l.templateString(t.label,e):t.label;return\"all\"===t.step?\"all\":t.count+t.step.charAt(0)}(r,n._fullLayout._meta)).call(function(t){c.convertToTspans(t,n)})}e.exports=function(t){var e=t._fullLayout._infolayer.selectAll(\".rangeselector\").data(function(t){for(var e=u.list(t,\"x\",!0),r=[],n=0;n<e.length;n++){var i=e[n];i.rangeselector&&i.rangeselector.visible&&r.push(i)}return r}(t),m);e.enter().append(\"g\").classed(\"rangeselector\",!0),e.exit().remove(),e.style({cursor:\"pointer\",\"pointer-events\":\"all\"}),e.each(function(e){var r=n.select(this),o=e,u=o.rangeselector,h=r.selectAll(\"g.button\").data(l.filterVisible(u.buttons));h.enter().append(\"g\").classed(\"button\",!0),h.exit().remove(),h.each(function(e){var r=n.select(this),a=v(o,e);e._isActive=function(t,e,r){if(\"all\"===e.step)return!0===t.autorange;var n=Object.keys(r);return t.range[0]===r[n[0]]&&t.range[1]===r[n[1]]}(o,e,a),r.call(y,u,e),r.call(x,u,e,t),r.on(\"click\",function(){t._dragged||i.call(\"_guiRelayout\",t,a)}),r.on(\"mouseover\",function(){e._isHovered=!0,r.call(y,u,e)}),r.on(\"mouseout\",function(){e._isHovered=!1,r.call(y,u,e)})}),function(t,e,r,i,o){var u=0,h=0,v=r.borderwidth;e.each(function(){var t=n.select(this),e=t.select(\".selector-text\"),i=r.font.size*f,a=Math.max(i*c.lineCount(e),16)+3;h=Math.max(h,a)}),e.each(function(){var t=n.select(this),e=t.select(\".selector-rect\"),i=t.select(\".selector-text\"),a=i.node()&&s.bBox(i.node()).width,o=r.font.size*f,l=c.lineCount(i),p=Math.max(a+10,g.minButtonWidth);t.attr(\"transform\",\"translate(\"+(v+u)+\",\"+v+\")\"),e.attr({x:0,y:0,width:p,height:h}),c.positionText(i,p/2,h/2-(l-1)*o/2+3),u+=p+5});var m=t._fullLayout._size,y=m.l+m.w*r.x,x=m.t+m.h*(1-r.y),b=\"left\";l.isRightAnchor(r)&&(y-=u,b=\"right\");l.isCenterAnchor(r)&&(y-=u/2,b=\"center\");var _=\"top\";l.isBottomAnchor(r)&&(x-=h,_=\"bottom\");l.isMiddleAnchor(r)&&(x-=h/2,_=\"middle\");u=Math.ceil(u),h=Math.ceil(h),y=Math.round(y),x=Math.round(x),a.autoMargin(t,i+\"-range-selector\",{x:r.x,y:r.y,l:u*p[b],r:u*d[b],b:h*d[_],t:h*p[_]}),o.attr(\"transform\",\"translate(\"+y+\",\"+x+\")\")}(t,h,u,o._name,r)})}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axis_ids\":770,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../drawing\":614,\"./constants\":656,\"./get_update_object\":659,d3:163}],659:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e){var r=t._name,i={};if(\"all\"===e.step)i[r+\".autorange\"]=!0;else{var a=function(t,e){var r,i=t.range,a=new Date(t.r2l(i[1])),o=e.step,s=e.count;switch(e.stepmode){case\"backward\":r=t.l2r(+n.time[o].utc.offset(a,-s));break;case\"todate\":var l=n.time[o].utc.offset(a,-s);r=t.l2r(+n.time[o].utc.ceil(l))}var c=i[1];return[r,c]}(t,e);i[r+\".range[0]\"]=a[0],i[r+\".range[1]\"]=a[1]}return i}},{d3:163}],660:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"rangeselector\",schema:{subplots:{xaxis:{rangeselector:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":655,\"./defaults\":657,\"./draw\":658}],661:[function(t,e,r){\"use strict\";var n=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",dflt:n.background,editType:\"plot\"},bordercolor:{valType:\"color\",dflt:n.defaultLine,editType:\"plot\"},borderwidth:{valType:\"integer\",dflt:0,min:0,editType:\"plot\"},autorange:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}}],editType:\"calc\",impliedEdits:{autorange:!1}},thickness:{valType:\"number\",dflt:.15,min:0,max:1,editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"}},{\"../color/attributes\":592}],662:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\").list,i=t(\"../../plots/cartesian/autorange\").getAutoRange,a=t(\"./constants\");e.exports=function(t){for(var e=n(t,\"x\",!0),r=0;r<e.length;r++){var o=e[r],s=o[a.name];s&&s.visible&&s.autorange&&(s._input.autorange=!0,s._input.range=s.range=i(t,o))}}},{\"../../plots/cartesian/autorange\":766,\"../../plots/cartesian/axis_ids\":770,\"./constants\":663}],663:[function(t,e,r){\"use strict\";e.exports={name:\"rangeslider\",containerClassName:\"rangeslider-container\",bgClassName:\"rangeslider-bg\",rangePlotClassName:\"rangeslider-rangeplot\",maskMinClassName:\"rangeslider-mask-min\",maskMaxClassName:\"rangeslider-mask-max\",slideBoxClassName:\"rangeslider-slidebox\",grabberMinClassName:\"rangeslider-grabber-min\",grabAreaMinClassName:\"rangeslider-grabarea-min\",handleMinClassName:\"rangeslider-handle-min\",grabberMaxClassName:\"rangeslider-grabber-max\",grabAreaMaxClassName:\"rangeslider-grabarea-max\",handleMaxClassName:\"rangeslider-handle-max\",maskMinOppAxisClassName:\"rangeslider-mask-min-opp-axis\",maskMaxOppAxisClassName:\"rangeslider-mask-max-opp-axis\",maskColor:\"rgba(0,0,0,0.4)\",maskOppAxisColor:\"rgba(0,0,0,0.2)\",slideBoxFill:\"transparent\",slideBoxCursor:\"ew-resize\",grabAreaFill:\"transparent\",grabAreaCursor:\"col-resize\",grabAreaWidth:10,handleWidth:4,handleRadius:1,handleStrokeWidth:1,extraPad:15}},{}],664:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"./attributes\"),s=t(\"./oppaxis_attributes\");e.exports=function(t,e,r){var l=t[r],c=e[r];if(l.rangeslider||e._requestRangeslider[c._id]){n.isPlainObject(l.rangeslider)||(l.rangeslider={});var u,h,f=l.rangeslider,p=i.newContainer(c,\"rangeslider\");if(_(\"visible\")){_(\"bgcolor\",e.plot_bgcolor),_(\"bordercolor\"),_(\"borderwidth\"),_(\"thickness\"),_(\"autorange\",!c.isValidRange(f.range)),_(\"range\");var d=e._subplots;if(d)for(var g=d.cartesian.filter(function(t){return t.substr(0,t.indexOf(\"y\"))===a.name2id(r)}).map(function(t){return t.substr(t.indexOf(\"y\"),t.length)}),v=n.simpleMap(g,a.id2name),m=0;m<v.length;m++){var y=v[m];u=f[y]||{},h=i.newContainer(p,y,\"yaxis\");var x,b=e[y];u.range&&b.isValidRange(u.range)&&(x=\"fixed\"),\"match\"!==w(\"rangemode\",x)&&w(\"range\",b.range.slice())}p._input=f}}function _(t,e){return n.coerce(f,p,o,t,e)}function w(t,e){return n.coerce(u,h,s,t,e)}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/axis_ids\":770,\"./attributes\":661,\"./oppaxis_attributes\":668}],665:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=t(\"../drawing\"),l=t(\"../color\"),c=t(\"../titles\"),u=t(\"../../plots/cartesian\"),h=t(\"../../plots/cartesian/axis_ids\"),f=t(\"../dragelement\"),p=t(\"../../lib/setcursor\"),d=t(\"./constants\");function g(t,e,r,n){var i=o.ensureSingle(t,\"rect\",d.bgClassName,function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})}),a=n.borderwidth%2==0?n.borderwidth:n.borderwidth-1,l=-n._offsetShift,c=s.crispRound(e,n.borderwidth);i.attr({width:n._width+a,height:n._height+a,transform:\"translate(\"+l+\",\"+l+\")\",fill:n.bgcolor,stroke:n.bordercolor,\"stroke-width\":c})}function v(t,e,r,n){var i=e._fullLayout;o.ensureSingleById(i._topdefs,\"clipPath\",n._clipId,function(t){t.append(\"rect\").attr({x:0,y:0})}).select(\"rect\").attr({width:n._width,height:n._height})}function m(t,e,r,i){var l,c=e.calcdata,f=t.selectAll(\"g.\"+d.rangePlotClassName).data(r._subplotsWith,o.identity);f.enter().append(\"g\").attr(\"class\",function(t){return d.rangePlotClassName+\" \"+t}).call(s.setClipUrl,i._clipId,e),f.order(),f.exit().remove(),f.each(function(t,o){var s=n.select(this),f=0===o,p=h.getFromId(e,t,\"y\"),d=p._name,g=i[d],v={data:[],layout:{xaxis:{type:r.type,domain:[0,1],range:i.range.slice(),calendar:r.calendar},width:i._width,height:i._height,margin:{t:0,b:0,l:0,r:0}},_context:e._context};v.layout[d]={type:p.type,domain:[0,1],range:\"match\"!==g.rangemode?g.range.slice():p.range.slice(),calendar:p.calendar},a.supplyDefaults(v);var m=v._fullLayout.xaxis,y=v._fullLayout[d];m.clearCalc(),m.setScale(),y.clearCalc(),y.setScale();var x={id:t,plotgroup:s,xaxis:m,yaxis:y,isRangePlot:!0};f?l=x:(x.mainplot=\"xy\",x.mainplotinfo=l),u.rangePlot(e,x,function(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n],a=i[0].trace;a.xaxis+a.yaxis===e&&r.push(i)}return r}(c,t))})}function y(t,e,r,n,i){(o.ensureSingle(t,\"rect\",d.maskMinClassName,function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"height\",n._height).call(l.fill,d.maskColor),o.ensureSingle(t,\"rect\",d.maskMaxClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"height\",n._height).call(l.fill,d.maskColor),\"match\"!==i.rangemode)&&(o.ensureSingle(t,\"rect\",d.maskMinOppAxisClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"width\",n._width).call(l.fill,d.maskOppAxisColor),o.ensureSingle(t,\"rect\",d.maskMaxOppAxisClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"width\",n._width).style(\"border-top\",d.maskOppBorder).call(l.fill,d.maskOppAxisColor))}function x(t,e,r,n){e._context.staticPlot||o.ensureSingle(t,\"rect\",d.slideBoxClassName,function(t){t.attr({y:0,cursor:d.slideBoxCursor,\"shape-rendering\":\"crispEdges\"})}).attr({height:n._height,fill:d.slideBoxFill})}function b(t,e,r,n){var i=o.ensureSingle(t,\"g\",d.grabberMinClassName),a=o.ensureSingle(t,\"g\",d.grabberMaxClassName),s={x:0,width:d.handleWidth,rx:d.handleRadius,fill:l.background,stroke:l.defaultLine,\"stroke-width\":d.handleStrokeWidth,\"shape-rendering\":\"crispEdges\"},c={y:Math.round(n._height/4),height:Math.round(n._height/2)};if(o.ensureSingle(i,\"rect\",d.handleMinClassName,function(t){t.attr(s)}).attr(c),o.ensureSingle(a,\"rect\",d.handleMaxClassName,function(t){t.attr(s)}).attr(c),!e._context.staticPlot){var u={width:d.grabAreaWidth,x:0,y:0,fill:d.grabAreaFill,cursor:d.grabAreaCursor};o.ensureSingle(i,\"rect\",d.grabAreaMinClassName,function(t){t.attr(u)}).attr(\"height\",n._height),o.ensureSingle(a,\"rect\",d.grabAreaMaxClassName,function(t){t.attr(u)}).attr(\"height\",n._height)}}e.exports=function(t){for(var e=t._fullLayout,r=e._rangeSliderData,a=0;a<r.length;a++){var s=r[a][d.name];s._clipId=s._id+\"-\"+e._uid}var l=e._infolayer.selectAll(\"g.\"+d.containerClassName).data(r,function(t){return t._name});l.exit().each(function(t){var r=t[d.name];e._topdefs.select(\"#\"+r._clipId).remove()}).remove(),0!==r.length&&(l.enter().append(\"g\").classed(d.containerClassName,!0).attr(\"pointer-events\",\"all\"),l.each(function(r){var a=n.select(this),s=r[d.name],l=e[h.id2name(r.anchor)],u=s[h.id2name(r.anchor)];if(s.range){var _,w=o.simpleMap(s.range,r.r2l),k=o.simpleMap(r.range,r.r2l);_=k[0]<k[1]?[Math.min(w[0],k[0]),Math.max(w[1],k[1])]:[Math.max(w[0],k[0]),Math.min(w[1],k[1])],s.range=s._input.range=o.simpleMap(_,r.l2r)}r.cleanRange(\"rangeslider.range\");var T=e.margin,A=e._size,M=r.domain,S=s._tickHeight,E=s._oppBottom;s._width=A.w*(M[1]-M[0]);var C=Math.round(T.l+A.w*M[0]),L=Math.round(A.t+A.h*(1-E)+S+s._offsetShift+d.extraPad);a.attr(\"transform\",\"translate(\"+C+\",\"+L+\")\");var P=r.r2l(s.range[0]),O=r.r2l(s.range[1]),z=O-P;if(s.p2d=function(t){return t/s._width*z+P},s.d2p=function(t){return(t-P)/z*s._width},s._rl=[P,O],\"match\"!==u.rangemode){var I=l.r2l(u.range[0]),D=l.r2l(u.range[1])-I;s.d2pOppAxis=function(t){return(t-I)/D*s._height}}a.call(g,t,r,s).call(v,t,r,s).call(m,t,r,s).call(y,t,r,s,u).call(x,t,r,s).call(b,t,r,s),function(t,e,r,a){var s=t.select(\"rect.\"+d.slideBoxClassName).node(),l=t.select(\"rect.\"+d.grabAreaMinClassName).node(),c=t.select(\"rect.\"+d.grabAreaMaxClassName).node();t.on(\"mousedown\",function(){var u=n.event,h=u.target,d=u.clientX,g=d-t.node().getBoundingClientRect().left,v=a.d2p(r._rl[0]),m=a.d2p(r._rl[1]),y=f.coverSlip();function x(t){var u,f,x,b=+t.clientX-d;switch(h){case s:x=\"ew-resize\",u=v+b,f=m+b;break;case l:x=\"col-resize\",u=v+b,f=m;break;case c:x=\"col-resize\",u=v,f=m+b;break;default:x=\"ew-resize\",u=g,f=g+b}if(f<u){var _=f;f=u,u=_}a._pixelMin=u,a._pixelMax=f,p(n.select(y),x),function(t,e,r,n){function a(t){return r.l2r(o.constrain(t,n._rl[0],n._rl[1]))}var s=a(n.p2d(n._pixelMin)),l=a(n.p2d(n._pixelMax));window.requestAnimationFrame(function(){i.call(\"_guiRelayout\",e,r._name+\".range\",[s,l])})}(0,e,r,a)}y.addEventListener(\"mousemove\",x),y.addEventListener(\"mouseup\",function t(){y.removeEventListener(\"mousemove\",x);y.removeEventListener(\"mouseup\",t);o.removeElement(y)})})}(a,t,r,s),function(t,e,r,n,i,a){var s=d.handleWidth/2;function l(t){return o.constrain(t,0,n._width)}function c(t){return o.constrain(t,0,n._height)}function u(t){return o.constrain(t,-s,n._width+s)}var h=l(n.d2p(r._rl[0])),f=l(n.d2p(r._rl[1]));if(t.select(\"rect.\"+d.slideBoxClassName).attr(\"x\",h).attr(\"width\",f-h),t.select(\"rect.\"+d.maskMinClassName).attr(\"width\",h),t.select(\"rect.\"+d.maskMaxClassName).attr(\"x\",f).attr(\"width\",n._width-f),\"match\"!==a.rangemode){var p=n._height-c(n.d2pOppAxis(i._rl[1])),g=n._height-c(n.d2pOppAxis(i._rl[0]));t.select(\"rect.\"+d.maskMinOppAxisClassName).attr(\"x\",h).attr(\"height\",p).attr(\"width\",f-h),t.select(\"rect.\"+d.maskMaxOppAxisClassName).attr(\"x\",h).attr(\"y\",g).attr(\"height\",n._height-g).attr(\"width\",f-h),t.select(\"rect.\"+d.slideBoxClassName).attr(\"y\",p).attr(\"height\",g-p)}var v=Math.round(u(h-s))-.5,m=Math.round(u(f-s))+.5;t.select(\"g.\"+d.grabberMinClassName).attr(\"transform\",\"translate(\"+v+\",0.5)\"),t.select(\"g.\"+d.grabberMaxClassName).attr(\"transform\",\"translate(\"+m+\",0.5)\")}(a,0,r,s,l,u),\"bottom\"===r.side&&c.draw(t,r._id+\"title\",{propContainer:r,propName:r._name+\".title\",placeholder:e._dfltTitle.x,attributes:{x:r._offset+r._length/2,y:L+s._height+s._offsetShift+10+1.5*r.title.font.size,\"text-anchor\":\"middle\"}})}))}},{\"../../lib\":719,\"../../lib/setcursor\":739,\"../../plots/cartesian\":778,\"../../plots/cartesian/axis_ids\":770,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"../titles\":681,\"./constants\":663,d3:163}],666:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"./constants\"),a=i.name;function o(t){var e=t&&t[a];return e&&e.visible}r.isVisible=o,r.makeData=function(t){var e=n.list({_fullLayout:t},\"x\",!0),r=t.margin,i=[];if(!t._has(\"gl2d\"))for(var s=0;s<e.length;s++){var l=e[s];if(o(l)){i.push(l);var c=l[a];c._id=a+l._id,c._height=(t.height-r.b-r.t)*c.thickness,c._offsetShift=Math.floor(c.borderwidth/2)}}t._rangeSliderData=i},r.autoMarginOpts=function(t,e){for(var r=e[a],o=1/0,s=e._counterAxes,l=0;l<s.length;l++){var c=s[l],u=n.getFromId(t,c);o=Math.min(o,u.domain[0])}r._oppBottom=o;var h=\"bottom\"===e.side&&e._boundingBox.height||0;return r._tickHeight=h,{x:0,y:o,l:0,r:0,t:0,b:r._height+t._fullLayout.margin.b+h,pad:i.extraPad+2*r._offsetShift}}},{\"../../plots/cartesian/axis_ids\":770,\"./constants\":663}],667:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./oppaxis_attributes\"),o=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"rangeslider\",schema:{subplots:{xaxis:{rangeslider:n.extendFlat({},i,{yaxis:a})}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),calcAutorange:t(\"./calc_autorange\"),draw:t(\"./draw\"),isVisible:o.isVisible,makeData:o.makeData,autoMarginOpts:o.autoMarginOpts}},{\"../../lib\":719,\"./attributes\":661,\"./calc_autorange\":662,\"./defaults\":664,\"./draw\":665,\"./helpers\":666,\"./oppaxis_attributes\":668}],668:[function(t,e,r){\"use strict\";e.exports={_isSubplotObj:!0,rangemode:{valType:\"enumerated\",values:[\"auto\",\"fixed\",\"match\"],dflt:\"match\",editType:\"calc\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"plot\"},{valType:\"any\",editType:\"plot\"}],editType:\"plot\"},editType:\"calc\"}},{}],669:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../traces/scatter/attributes\").line,a=t(\"../drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray;e.exports=s(\"shape\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},type:{valType:\"enumerated\",values:[\"circle\",\"rect\",\"path\",\"line\"],editType:\"calc+arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},xref:o({},n.xref,{}),xsizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},xanchor:{valType:\"any\",editType:\"calc+arraydraw\"},x0:{valType:\"any\",editType:\"calc+arraydraw\"},x1:{valType:\"any\",editType:\"calc+arraydraw\"},yref:o({},n.yref,{}),ysizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},yanchor:{valType:\"any\",editType:\"calc+arraydraw\"},y0:{valType:\"any\",editType:\"calc+arraydraw\"},y1:{valType:\"any\",editType:\"calc+arraydraw\"},path:{valType:\"string\",editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},line:{color:o({},i.color,{editType:\"arraydraw\"}),width:o({},i.width,{editType:\"calc+arraydraw\"}),dash:o({},a,{editType:\"arraydraw\"}),editType:\"calc+arraydraw\"},fillcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},editType:\"arraydraw\"})},{\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../../traces/scatter/attributes\":1112,\"../annotations/attributes\":576,\"../drawing/attributes\":613}],670:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./constants\"),o=t(\"./helpers\");function s(t){return c(t.line.width,t.xsizemode,t.x0,t.x1,t.path,!1)}function l(t){return c(t.line.width,t.ysizemode,t.y0,t.y1,t.path,!0)}function c(t,e,r,i,s,l){var c=t/2,u=l;if(\"pixel\"===e){var h=s?o.extractPathCoords(s,l?a.paramIsY:a.paramIsX):[r,i],f=n.aggNums(Math.max,null,h),p=n.aggNums(Math.min,null,h),d=p<0?Math.abs(p)+c:c,g=f>0?f+c:c;return{ppad:c,ppadplus:u?d:g,ppadminus:u?g:d}}return{ppad:c}}function u(t,e,r,n,i){var s=\"category\"===t.type||\"multicategory\"===t.type?t.r2c:t.d2c;if(void 0!==e)return[s(e),s(r)];if(n){var l,c,u,h,f=1/0,p=-1/0,d=n.match(a.segmentRE);for(\"date\"===t.type&&(s=o.decodeDate(s)),l=0;l<d.length;l++)void 0!==(c=i[d[l].charAt(0)].drawn)&&(!(u=d[l].substr(1).match(a.paramRE))||u.length<c||((h=s(u[c]))<f&&(f=h),h>p&&(p=h)));return p>=f?[f,p]:void 0}}e.exports=function(t){var e=t._fullLayout,r=n.filterVisible(e.shapes);if(r.length&&t._fullData.length)for(var o=0;o<r.length;o++){var c,h,f=r[o];if(f._extremes={},\"paper\"!==f.xref){var p=\"pixel\"===f.xsizemode?f.xanchor:f.x0,d=\"pixel\"===f.xsizemode?f.xanchor:f.x1;(h=u(c=i.getFromId(t,f.xref),p,d,f.path,a.paramIsX))&&(f._extremes[c._id]=i.findExtremes(c,h,s(f)))}if(\"paper\"!==f.yref){var g=\"pixel\"===f.ysizemode?f.yanchor:f.y0,v=\"pixel\"===f.ysizemode?f.yanchor:f.y1;(h=u(c=i.getFromId(t,f.yref),g,v,f.path,a.paramIsY))&&(f._extremes[c._id]=i.findExtremes(c,h,l(f)))}}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./constants\":671,\"./helpers\":674}],671:[function(t,e,r){\"use strict\";e.exports={segmentRE:/[MLHVQCTSZ][^MLHVQCTSZ]*/g,paramRE:/[^\\s,]+/g,paramIsX:{M:{0:!0,drawn:0},L:{0:!0,drawn:0},H:{0:!0,drawn:0},V:{},Q:{0:!0,2:!0,drawn:2},C:{0:!0,2:!0,4:!0,drawn:4},T:{0:!0,drawn:0},S:{0:!0,2:!0,drawn:2},Z:{}},paramIsY:{M:{1:!0,drawn:1},L:{1:!0,drawn:1},H:{},V:{0:!0,drawn:0},Q:{1:!0,3:!0,drawn:3},C:{1:!0,3:!0,5:!0,drawn:5},T:{1:!0,drawn:1},S:{1:!0,3:!0,drawn:5},Z:{}},numParams:{M:2,L:2,H:1,V:1,Q:4,C:6,T:2,S:4,Z:0}}},{}],672:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\"),s=t(\"./helpers\");function l(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}if(a(\"visible\")){a(\"layer\"),a(\"opacity\"),a(\"fillcolor\"),a(\"line.color\"),a(\"line.width\"),a(\"line.dash\");for(var l=a(\"type\",t.path?\"path\":\"rect\"),c=a(\"xsizemode\"),u=a(\"ysizemode\"),h=[\"x\",\"y\"],f=0;f<2;f++){var p,d,g,v=h[f],m=v+\"anchor\",y=\"x\"===v?c:u,x={_fullLayout:r},b=i.coerceRef(t,e,x,v,\"\",\"paper\");if(\"paper\"!==b?((p=i.getFromId(x,b))._shapeIndices.push(e._index),g=s.rangeToShapePosition(p),d=s.shapePositionToRange(p)):d=g=n.identity,\"path\"!==l){var _=v+\"0\",w=v+\"1\",k=t[_],T=t[w];t[_]=d(t[_],!0),t[w]=d(t[w],!0),\"pixel\"===y?(a(_,0),a(w,10)):(i.coercePosition(e,x,a,b,_,.25),i.coercePosition(e,x,a,b,w,.75)),e[_]=g(e[_]),e[w]=g(e[w]),t[_]=k,t[w]=T}if(\"pixel\"===y){var A=t[m];t[m]=d(t[m],!0),i.coercePosition(e,x,a,b,m,.25),e[m]=g(e[m]),t[m]=A}}\"path\"===l?a(\"path\"):n.noneOrAll(t,e,[\"x0\",\"x1\",\"y0\",\"y1\"])}}e.exports=function(t,e){a(t,e,{name:\"shapes\",handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"./attributes\":669,\"./helpers\":674}],673:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../color\"),s=t(\"../drawing\"),l=t(\"../../plot_api/plot_template\").arrayEditor,c=t(\"../dragelement\"),u=t(\"../../lib/setcursor\"),h=t(\"./constants\"),f=t(\"./helpers\");function p(t,e){t._fullLayout._paperdiv.selectAll('.shapelayer [data-index=\"'+e+'\"]').remove();var r=t._fullLayout.shapes[e]||{};if(r._input&&!1!==r.visible)if(\"below\"!==r.layer)m(t._fullLayout._shapeUpperLayer);else if(\"paper\"===r.xref||\"paper\"===r.yref)m(t._fullLayout._shapeLowerLayer);else{var p=t._fullLayout._plots[r.xref+r.yref];if(p)m((p.mainplotinfo||p).shapelayer);else m(t._fullLayout._shapeLowerLayer)}function m(p){var m={\"data-index\":e,\"fill-rule\":\"evenodd\",d:g(t,r)},y=r.line.width?r.line.color:\"rgba(0,0,0,0)\",x=p.append(\"path\").attr(m).style(\"opacity\",r.opacity).call(o.stroke,y).call(o.fill,r.fillcolor).call(s.dashLine,r.line.dash,r.line.width);d(x,t,r),t._context.edits.shapePosition&&function(t,e,r,o,p){var m,y,x,b,_,w,k,T,A,M,S,E,C,L,P,O,z=10,I=10,D=\"pixel\"===r.xsizemode,R=\"pixel\"===r.ysizemode,F=\"line\"===r.type,B=\"path\"===r.type,N=l(t.layout,\"shapes\",r),j=N.modifyItem,U=a.getFromId(t,r.xref),V=a.getFromId(t,r.yref),q=f.getDataToPixel(t,U),H=f.getDataToPixel(t,V,!0),G=f.getPixelToData(t,U),Y=f.getPixelToData(t,V,!0),W=F?function(){var t=Math.max(r.line.width,10),n=p.append(\"g\").attr(\"data-index\",o);n.append(\"path\").attr(\"d\",e.attr(\"d\")).style({cursor:\"move\",\"stroke-width\":t,\"stroke-opacity\":\"0\"});var i={\"fill-opacity\":\"0\"},a=t/2>10?t/2:10;return n.append(\"circle\").attr({\"data-line-point\":\"start-point\",cx:D?q(r.xanchor)+r.x0:q(r.x0),cy:R?H(r.yanchor)-r.y0:H(r.y0),r:a}).style(i).classed(\"cursor-grab\",!0),n.append(\"circle\").attr({\"data-line-point\":\"end-point\",cx:D?q(r.xanchor)+r.x1:q(r.x1),cy:R?H(r.yanchor)-r.y1:H(r.y1),r:a}).style(i).classed(\"cursor-grab\",!0),n}():e,X={element:W.node(),gd:t,prepFn:function(n){D&&(_=q(r.xanchor));R&&(w=H(r.yanchor));\"path\"===r.type?P=r.path:(m=D?r.x0:q(r.x0),y=R?r.y0:H(r.y0),x=D?r.x1:q(r.x1),b=R?r.y1:H(r.y1));m<x?(A=m,C=\"x0\",M=x,L=\"x1\"):(A=x,C=\"x1\",M=m,L=\"x0\");!R&&y<b||R&&y>b?(k=y,S=\"y0\",T=b,E=\"y1\"):(k=b,S=\"y1\",T=y,E=\"y0\");Z(n),$(p,r),function(t,e,r){var n=e.xref,i=e.yref,o=a.getFromId(r,n),l=a.getFromId(r,i),c=\"\";\"paper\"===n||o.autorange||(c+=n);\"paper\"===i||l.autorange||(c+=i);s.setClipUrl(t,c?\"clip\"+r._fullLayout._uid+c:null,r)}(e,r,t),X.moveFn=\"move\"===O?J:K},doneFn:function(){u(e),Q(p),d(e,t,r),n.call(\"_guiRelayout\",t,N.getUpdateObj())},clickFn:function(){Q(p)}};function Z(t){if(F)O=\"path\"===t.target.tagName?\"move\":\"start-point\"===t.target.attributes[\"data-line-point\"].value?\"resize-over-start-point\":\"resize-over-end-point\";else{var r=X.element.getBoundingClientRect(),n=r.right-r.left,i=r.bottom-r.top,a=t.clientX-r.left,o=t.clientY-r.top,s=!B&&n>z&&i>I&&!t.shiftKey?c.getCursor(a/n,1-o/i):\"move\";u(e,s),O=s.split(\"-\")[0]}}function J(n,i){if(\"path\"===r.type){var a=function(t){return t},o=a,s=a;D?j(\"xanchor\",r.xanchor=G(_+n)):(o=function(t){return G(q(t)+n)},U&&\"date\"===U.type&&(o=f.encodeDate(o))),R?j(\"yanchor\",r.yanchor=Y(w+i)):(s=function(t){return Y(H(t)+i)},V&&\"date\"===V.type&&(s=f.encodeDate(s))),j(\"path\",r.path=v(P,o,s))}else D?j(\"xanchor\",r.xanchor=G(_+n)):(j(\"x0\",r.x0=G(m+n)),j(\"x1\",r.x1=G(x+n))),R?j(\"yanchor\",r.yanchor=Y(w+i)):(j(\"y0\",r.y0=Y(y+i)),j(\"y1\",r.y1=Y(b+i)));e.attr(\"d\",g(t,r)),$(p,r)}function K(n,i){if(B){var a=function(t){return t},o=a,s=a;D?j(\"xanchor\",r.xanchor=G(_+n)):(o=function(t){return G(q(t)+n)},U&&\"date\"===U.type&&(o=f.encodeDate(o))),R?j(\"yanchor\",r.yanchor=Y(w+i)):(s=function(t){return Y(H(t)+i)},V&&\"date\"===V.type&&(s=f.encodeDate(s))),j(\"path\",r.path=v(P,o,s))}else if(F){if(\"resize-over-start-point\"===O){var l=m+n,c=R?y-i:y+i;j(\"x0\",r.x0=D?l:G(l)),j(\"y0\",r.y0=R?c:Y(c))}else if(\"resize-over-end-point\"===O){var u=x+n,h=R?b-i:b+i;j(\"x1\",r.x1=D?u:G(u)),j(\"y1\",r.y1=R?h:Y(h))}}else{var d=~O.indexOf(\"n\")?k+i:k,N=~O.indexOf(\"s\")?T+i:T,W=~O.indexOf(\"w\")?A+n:A,X=~O.indexOf(\"e\")?M+n:M;~O.indexOf(\"n\")&&R&&(d=k-i),~O.indexOf(\"s\")&&R&&(N=T-i),(!R&&N-d>I||R&&d-N>I)&&(j(S,r[S]=R?d:Y(d)),j(E,r[E]=R?N:Y(N))),X-W>z&&(j(C,r[C]=D?W:G(W)),j(L,r[L]=D?X:G(X)))}e.attr(\"d\",g(t,r)),$(p,r)}function $(t,e){(D||R)&&function(){var r=\"path\"!==e.type,n=t.selectAll(\".visual-cue\").data([0]);n.enter().append(\"path\").attr({fill:\"#fff\",\"fill-rule\":\"evenodd\",stroke:\"#000\",\"stroke-width\":1}).classed(\"visual-cue\",!0);var a=q(D?e.xanchor:i.midRange(r?[e.x0,e.x1]:f.extractPathCoords(e.path,h.paramIsX))),o=H(R?e.yanchor:i.midRange(r?[e.y0,e.y1]:f.extractPathCoords(e.path,h.paramIsY)));if(a=f.roundPositionForSharpStrokeRendering(a,1),o=f.roundPositionForSharpStrokeRendering(o,1),D&&R){var s=\"M\"+(a-1-1)+\",\"+(o-1-1)+\"h-8v2h8 v8h2v-8 h8v-2h-8 v-8h-2 Z\";n.attr(\"d\",s)}else if(D){var l=\"M\"+(a-1-1)+\",\"+(o-9-1)+\"v18 h2 v-18 Z\";n.attr(\"d\",l)}else{var c=\"M\"+(a-9-1)+\",\"+(o-1-1)+\"h18 v2 h-18 Z\";n.attr(\"d\",c)}}()}function Q(t){t.selectAll(\".visual-cue\").remove()}c.init(X),W.node().onmousemove=Z}(t,x,r,e,p)}}function d(t,e,r){var n=(r.xref+r.yref).replace(/paper/g,\"\");s.setClipUrl(t,n?\"clip\"+e._fullLayout._uid+n:null,e)}function g(t,e){var r,n,o,s,l,c,u,p,d=e.type,g=a.getFromId(t,e.xref),v=a.getFromId(t,e.yref),m=t._fullLayout._size;if(g?(r=f.shapePositionToRange(g),n=function(t){return g._offset+g.r2p(r(t,!0))}):n=function(t){return m.l+m.w*t},v?(o=f.shapePositionToRange(v),s=function(t){return v._offset+v.r2p(o(t,!0))}):s=function(t){return m.t+m.h*(1-t)},\"path\"===d)return g&&\"date\"===g.type&&(n=f.decodeDate(n)),v&&\"date\"===v.type&&(s=f.decodeDate(s)),function(t,e,r){var n=t.path,a=t.xsizemode,o=t.ysizemode,s=t.xanchor,l=t.yanchor;return n.replace(h.segmentRE,function(t){var n=0,c=t.charAt(0),u=h.paramIsX[c],f=h.paramIsY[c],p=h.numParams[c],d=t.substr(1).replace(h.paramRE,function(t){return u[n]?t=\"pixel\"===a?e(s)+Number(t):e(t):f[n]&&(t=\"pixel\"===o?r(l)-Number(t):r(t)),++n>p&&(t=\"X\"),t});return n>p&&(d=d.replace(/[\\s,]*X.*/,\"\"),i.log(\"Ignoring extra params in segment \"+t)),c+d})}(e,n,s);if(\"pixel\"===e.xsizemode){var y=n(e.xanchor);l=y+e.x0,c=y+e.x1}else l=n(e.x0),c=n(e.x1);if(\"pixel\"===e.ysizemode){var x=s(e.yanchor);u=x-e.y0,p=x-e.y1}else u=s(e.y0),p=s(e.y1);if(\"line\"===d)return\"M\"+l+\",\"+u+\"L\"+c+\",\"+p;if(\"rect\"===d)return\"M\"+l+\",\"+u+\"H\"+c+\"V\"+p+\"H\"+l+\"Z\";var b=(l+c)/2,_=(u+p)/2,w=Math.abs(b-l),k=Math.abs(_-u),T=\"A\"+w+\",\"+k,A=b+w+\",\"+_;return\"M\"+A+T+\" 0 1,1 \"+(b+\",\"+(_-k))+T+\" 0 0,1 \"+A+\"Z\"}function v(t,e,r){return t.replace(h.segmentRE,function(t){var n=0,i=t.charAt(0),a=h.paramIsX[i],o=h.paramIsY[i],s=h.numParams[i];return i+t.substr(1).replace(h.paramRE,function(t){return n>=s?t:(a[n]?t=e(t):o[n]&&(t=r(t)),n++,t)})})}e.exports={draw:function(t){var e=t._fullLayout;for(var r in e._shapeUpperLayer.selectAll(\"path\").remove(),e._shapeLowerLayer.selectAll(\"path\").remove(),e._plots){var n=e._plots[r].shapelayer;n&&n.selectAll(\"path\").remove()}for(var i=0;i<e.shapes.length;i++)e.shapes[i].visible&&p(t,i)},drawOne:p}},{\"../../lib\":719,\"../../lib/setcursor\":739,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"./constants\":671,\"./helpers\":674}],674:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib\");r.rangeToShapePosition=function(t){return\"log\"===t.type?t.r2d:function(t){return t}},r.shapePositionToRange=function(t){return\"log\"===t.type?t.d2r:function(t){return t}},r.decodeDate=function(t){return function(e){return e.replace&&(e=e.replace(\"_\",\" \")),t(e)}},r.encodeDate=function(t){return function(e){return t(e).replace(\" \",\"_\")}},r.extractPathCoords=function(t,e){var r=[];return t.match(n.segmentRE).forEach(function(t){var a=e[t.charAt(0)].drawn;if(void 0!==a){var o=t.substr(1).match(n.paramRE);!o||o.length<a||r.push(i.cleanNumber(o[a]))}}),r},r.getDataToPixel=function(t,e,n){var i,a=t._fullLayout._size;if(e){var o=r.shapePositionToRange(e);i=function(t){return e._offset+e.r2p(o(t,!0))},\"date\"===e.type&&(i=r.decodeDate(i))}else i=n?function(t){return a.t+a.h*(1-t)}:function(t){return a.l+a.w*t};return i},r.getPixelToData=function(t,e,n){var i,a=t._fullLayout._size;if(e){var o=r.rangeToShapePosition(e);i=function(t){return o(e.p2r(t-e._offset))}}else i=n?function(t){return 1-(t-a.t)/a.h}:function(t){return(t-a.l)/a.w};return i},r.roundPositionForSharpStrokeRendering=function(t,e){var r=1===Math.round(e%2),n=Math.round(t);return r?n+.5:n}},{\"../../lib\":719,\"./constants\":671}],675:[function(t,e,r){\"use strict\";var n=t(\"./draw\");e.exports={moduleType:\"component\",name:\"shapes\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"shapes\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne}},{\"../../plots/cartesian/include_components\":777,\"./attributes\":669,\"./calc_autorange\":670,\"./defaults\":672,\"./draw\":673}],676:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/pad_attributes\"),a=t(\"../../lib/extend\").extendDeepAll,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/animation_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"./constants\"),u=l(\"step\",{visible:{valType:\"boolean\",dflt:!0},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\"},value:{valType:\"string\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"slider\",{visible:{valType:\"boolean\",dflt:!0},active:{valType:\"number\",min:0,dflt:0},steps:u,lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",min:-2,max:3,dflt:0},pad:a(i({editType:\"arraydraw\"}),{},{t:{dflt:20}}),xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\"},y:{valType:\"number\",min:-2,max:3,dflt:0},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},transition:{duration:{valType:\"number\",min:0,dflt:150},easing:{valType:\"enumerated\",values:s.transition.easing.values,dflt:\"cubic-in-out\"}},currentvalue:{visible:{valType:\"boolean\",dflt:!0},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},offset:{valType:\"number\",dflt:10},prefix:{valType:\"string\"},suffix:{valType:\"string\"},font:n({})},font:n({}),activebgcolor:{valType:\"color\",dflt:c.gripBgActiveColor},bgcolor:{valType:\"color\",dflt:c.railBgColor},bordercolor:{valType:\"color\",dflt:c.railBorderColor},borderwidth:{valType:\"number\",min:0,dflt:c.railBorderWidth},ticklen:{valType:\"number\",min:0,dflt:c.tickLength},tickcolor:{valType:\"color\",dflt:c.tickColor},tickwidth:{valType:\"number\",min:0,dflt:1},minorticklen:{valType:\"number\",min:0,dflt:c.minorTickLength}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/animation_attributes\":762,\"../../plots/font_attributes\":793,\"../../plots/pad_attributes\":827,\"./constants\":677}],677:[function(t,e,r){\"use strict\";e.exports={name:\"sliders\",containerClassName:\"slider-container\",groupClassName:\"slider-group\",inputAreaClass:\"slider-input-area\",railRectClass:\"slider-rail-rect\",railTouchRectClass:\"slider-rail-touch-rect\",gripRectClass:\"slider-grip-rect\",tickRectClass:\"slider-tick-rect\",inputProxyClass:\"slider-input-proxy\",labelsClass:\"slider-labels\",labelGroupClass:\"slider-label-group\",labelClass:\"slider-label\",currentValueClass:\"slider-current-value\",railHeight:5,menuIndexAttrName:\"slider-active-index\",autoMarginIdRoot:\"slider-\",minWidth:30,minHeight:30,textPadX:40,arrowOffsetX:4,railRadius:2,railWidth:5,railBorder:4,railBorderWidth:1,railBorderColor:\"#bec8d9\",railBgColor:\"#f8fafc\",railInset:8,stepInset:10,gripRadius:10,gripWidth:20,gripHeight:20,gripBorder:20,gripBorderWidth:1,gripBorderColor:\"#bec8d9\",gripBgColor:\"#f6f8fa\",gripBgActiveColor:\"#dbdde0\",labelPadding:8,labelOffset:0,tickWidth:1,tickColor:\"#333\",tickOffset:25,tickLength:7,minorTickOffset:25,minorTickColor:\"#333\",minorTickLength:4,currentValuePadding:8,currentValueInset:0}},{}],678:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.steps;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}for(var s=i(t,e,{name:\"steps\",handleItemDefaults:c}),l=0,u=0;u<s.length;u++)s[u].visible&&l++;if(l<2?e.visible=!1:o(\"visible\")){e._stepCount=l;var h=e._visibleSteps=n.filterVisible(s);(s[o(\"active\")]||{}).visible||(e.active=h[0]._index),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"len\"),o(\"lenmode\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"currentvalue.visible\")&&(o(\"currentvalue.xanchor\"),o(\"currentvalue.prefix\"),o(\"currentvalue.suffix\"),o(\"currentvalue.offset\"),n.coerceFont(o,\"currentvalue.font\",e.font)),o(\"transition.duration\"),o(\"transition.easing\"),o(\"bgcolor\"),o(\"activebgcolor\"),o(\"bordercolor\"),o(\"borderwidth\"),o(\"ticklen\"),o(\"tickwidth\"),o(\"tickcolor\"),o(\"minorticklen\")}}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}if(\"skip\"===t.method||Array.isArray(t.args)?r(\"visible\"):e.visible=!1){r(\"method\"),r(\"args\");var i=r(\"label\",\"step-\"+e._index);r(\"value\",i),r(\"execute\")}}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"./attributes\":676,\"./constants\":677}],679:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"./constants\"),h=t(\"../../constants/alignment\"),f=h.LINE_SPACING,p=h.FROM_TL,d=h.FROM_BR;function g(t){return u.autoMarginIdRoot+t._index}function v(t){return t._index}function m(t,e){var r=o.tester.selectAll(\"g.\"+u.labelGroupClass).data(e._visibleSteps);r.enter().append(\"g\").classed(u.labelGroupClass,!0);var a=0,c=0;r.each(function(t){var r=b(n.select(this),{step:t},e).node();if(r){var i=o.bBox(r);c=Math.max(c,i.height),a=Math.max(a,i.width)}}),r.remove();var h=e._dims={};h.inputAreaWidth=Math.max(u.railWidth,u.gripHeight);var f=t._fullLayout._size;h.lx=f.l+f.w*e.x,h.ly=f.t+f.h*(1-e.y),\"fraction\"===e.lenmode?h.outerLength=Math.round(f.w*e.len):h.outerLength=e.len,h.inputAreaStart=0,h.inputAreaLength=Math.round(h.outerLength-e.pad.l-e.pad.r);var v=(h.inputAreaLength-2*u.stepInset)/(e._stepCount-1),m=a+u.labelPadding;if(h.labelStride=Math.max(1,Math.ceil(m/v)),h.labelHeight=c,h.currentValueMaxWidth=0,h.currentValueHeight=0,h.currentValueTotalHeight=0,h.currentValueMaxLines=1,e.currentvalue.visible){var x=o.tester.append(\"g\");r.each(function(t){var r=y(x,e,t.label),n=r.node()&&o.bBox(r.node())||{width:0,height:0},i=l.lineCount(r);h.currentValueMaxWidth=Math.max(h.currentValueMaxWidth,Math.ceil(n.width)),h.currentValueHeight=Math.max(h.currentValueHeight,Math.ceil(n.height)),h.currentValueMaxLines=Math.max(h.currentValueMaxLines,i)}),h.currentValueTotalHeight=h.currentValueHeight+e.currentvalue.offset,x.remove()}h.height=h.currentValueTotalHeight+u.tickOffset+e.ticklen+u.labelOffset+h.labelHeight+e.pad.t+e.pad.b;var _=\"left\";s.isRightAnchor(e)&&(h.lx-=h.outerLength,_=\"right\"),s.isCenterAnchor(e)&&(h.lx-=h.outerLength/2,_=\"center\");var w=\"top\";s.isBottomAnchor(e)&&(h.ly-=h.height,w=\"bottom\"),s.isMiddleAnchor(e)&&(h.ly-=h.height/2,w=\"middle\"),h.outerLength=Math.ceil(h.outerLength),h.height=Math.ceil(h.height),h.lx=Math.round(h.lx),h.ly=Math.round(h.ly);var k={y:e.y,b:h.height*d[w],t:h.height*p[w]};\"fraction\"===e.lenmode?(k.l=0,k.xl=e.x-e.len*p[_],k.r=0,k.xr=e.x+e.len*d[_]):(k.x=e.x,k.l=h.outerLength*p[_],k.r=h.outerLength*d[_]),i.autoMargin(t,g(e),k)}function y(t,e,r){if(e.currentvalue.visible){var n,i,a=e._dims;switch(e.currentvalue.xanchor){case\"right\":n=a.inputAreaLength-u.currentValueInset-a.currentValueMaxWidth,i=\"left\";break;case\"center\":n=.5*a.inputAreaLength,i=\"middle\";break;default:n=u.currentValueInset,i=\"left\"}var c=s.ensureSingle(t,\"text\",u.labelClass,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":i,\"data-notex\":1})}),h=e.currentvalue.prefix?e.currentvalue.prefix:\"\";if(\"string\"==typeof r)h+=r;else{var p=e.steps[e.active].label,d=e._gd._fullLayout._meta;d&&(p=s.templateString(p,d)),h+=p}e.currentvalue.suffix&&(h+=e.currentvalue.suffix),c.call(o.font,e.currentvalue.font).text(h).call(l.convertToTspans,e._gd);var g=l.lineCount(c),v=(a.currentValueMaxLines+1-g)*e.currentvalue.font.size*f;return l.positionText(c,n,v),c}}function x(t,e,r){s.ensureSingle(t,\"rect\",u.gripRectClass,function(n){n.call(T,e,t,r).style(\"pointer-events\",\"all\")}).attr({width:u.gripWidth,height:u.gripHeight,rx:u.gripRadius,ry:u.gripRadius}).call(a.stroke,r.bordercolor).call(a.fill,r.bgcolor).style(\"stroke-width\",r.borderwidth+\"px\")}function b(t,e,r){var n=s.ensureSingle(t,\"text\",u.labelClass,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":\"middle\",\"data-notex\":1})}),i=e.step.label,a=r._gd._fullLayout._meta;return a&&(i=s.templateString(i,a)),n.call(o.font,r.font).text(i).call(l.convertToTspans,r._gd),n}function _(t,e){var r=s.ensureSingle(t,\"g\",u.labelsClass),i=e._dims,a=r.selectAll(\"g.\"+u.labelGroupClass).data(i.labelSteps);a.enter().append(\"g\").classed(u.labelGroupClass,!0),a.exit().remove(),a.each(function(t){var r=n.select(this);r.call(b,t,e),o.setTranslate(r,S(e,t.fraction),u.tickOffset+e.ticklen+e.font.size*f+u.labelOffset+i.currentValueTotalHeight)})}function w(t,e,r,n,i){var a=Math.round(n*(r._stepCount-1)),o=r._visibleSteps[a]._index;o!==r.active&&k(t,e,r,o,!0,i)}function k(t,e,r,n,a,o){var s=r.active;r.active=n,c(t.layout,u.name,r).applyUpdate(\"active\",n);var l=r.steps[r.active];e.call(M,r,o),e.call(y,r),t.emit(\"plotly_sliderchange\",{slider:r,step:r.steps[r.active],interaction:a,previousActive:s}),l&&l.method&&a&&(e._nextMethod?(e._nextMethod.step=l,e._nextMethod.doCallback=a,e._nextMethod.doTransition=o):(e._nextMethod={step:l,doCallback:a,doTransition:o},e._nextMethodRaf=window.requestAnimationFrame(function(){var r=e._nextMethod.step;r.method&&(r.execute&&i.executeAPICommand(t,r.method,r.args),e._nextMethod=null,e._nextMethodRaf=null)})))}function T(t,e,r){var i=r.node(),o=n.select(e);function s(){return r.data()[0]}t.on(\"mousedown\",function(){var t=s();e.emit(\"plotly_sliderstart\",{slider:t});var l=r.select(\".\"+u.gripRectClass);n.event.stopPropagation(),n.event.preventDefault(),l.call(a.fill,t.activebgcolor);var c=E(t,n.mouse(i)[0]);w(e,r,t,c,!0),t._dragging=!0,o.on(\"mousemove\",function(){var t=s(),a=E(t,n.mouse(i)[0]);w(e,r,t,a,!1)}),o.on(\"mouseup\",function(){var t=s();t._dragging=!1,l.call(a.fill,t.bgcolor),o.on(\"mouseup\",null),o.on(\"mousemove\",null),e.emit(\"plotly_sliderend\",{slider:t,step:t.steps[t.active]})})})}function A(t,e){var r=t.selectAll(\"rect.\"+u.tickRectClass).data(e._visibleSteps),i=e._dims;r.enter().append(\"rect\").classed(u.tickRectClass,!0),r.exit().remove(),r.attr({width:e.tickwidth+\"px\",\"shape-rendering\":\"crispEdges\"}),r.each(function(t,r){var s=r%i.labelStride==0,l=n.select(this);l.attr({height:s?e.ticklen:e.minorticklen}).call(a.fill,e.tickcolor),o.setTranslate(l,S(e,r/(e._stepCount-1))-.5*e.tickwidth,(s?u.tickOffset:u.minorTickOffset)+i.currentValueTotalHeight)})}function M(t,e,r){for(var n=t.select(\"rect.\"+u.gripRectClass),i=0,a=0;a<e._stepCount;a++)if(e._visibleSteps[a]._index===e.active){i=a;break}var o=S(e,i/(e._stepCount-1));if(!e._invokingCommand){var s=n;r&&e.transition.duration>0&&(s=s.transition().duration(e.transition.duration).ease(e.transition.easing)),s.attr(\"transform\",\"translate(\"+(o-.5*u.gripWidth)+\",\"+e._dims.currentValueTotalHeight+\")\")}}function S(t,e){var r=t._dims;return r.inputAreaStart+u.stepInset+(r.inputAreaLength-2*u.stepInset)*Math.min(1,Math.max(0,e))}function E(t,e){var r=t._dims;return Math.min(1,Math.max(0,(e-u.stepInset-r.inputAreaStart)/(r.inputAreaLength-2*u.stepInset-2*r.inputAreaStart)))}function C(t,e,r){var n=r._dims,i=s.ensureSingle(t,\"rect\",u.railTouchRectClass,function(n){n.call(T,e,t,r).style(\"pointer-events\",\"all\")});i.attr({width:n.inputAreaLength,height:Math.max(n.inputAreaWidth,u.tickOffset+r.ticklen+n.labelHeight)}).call(a.fill,r.bgcolor).attr(\"opacity\",0),o.setTranslate(i,0,n.currentValueTotalHeight)}function L(t,e){var r=e._dims,n=r.inputAreaLength-2*u.railInset,i=s.ensureSingle(t,\"rect\",u.railRectClass);i.attr({width:n,height:u.railWidth,rx:u.railRadius,ry:u.railRadius,\"shape-rendering\":\"crispEdges\"}).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\"),o.setTranslate(i,u.railInset,.5*(r.inputAreaWidth-u.railWidth)+r.currentValueTotalHeight)}e.exports=function(t){var e=t._fullLayout,r=function(t,e){for(var r=t[u.name],n=[],i=0;i<r.length;i++){var a=r[i];a.visible&&(a._gd=e,n.push(a))}return n}(e,t),a=e._infolayer.selectAll(\"g.\"+u.containerClassName).data(r.length>0?[0]:[]);function s(e){e._commandObserver&&(e._commandObserver.remove(),delete e._commandObserver),i.autoMargin(t,g(e))}if(a.enter().append(\"g\").classed(u.containerClassName,!0).style(\"cursor\",\"ew-resize\"),a.exit().each(function(){n.select(this).selectAll(\"g.\"+u.groupClassName).each(s)}).remove(),0!==r.length){var l=a.selectAll(\"g.\"+u.groupClassName).data(r,v);l.enter().append(\"g\").classed(u.groupClassName,!0),l.exit().each(s).remove();for(var c=0;c<r.length;c++){var h=r[c];m(t,h)}l.each(function(e){var r=n.select(this);!function(t){var e=t._dims;e.labelSteps=[];for(var r=t._stepCount,n=0;n<r;n+=e.labelStride)e.labelSteps.push({fraction:n/(r-1),step:t._visibleSteps[n]})}(e),i.manageCommandObserver(t,e,e._visibleSteps,function(e){var n=r.data()[0];n.active!==e.index&&(n._dragging||k(t,r,n,e.index,!1,!0))}),function(t,e,r){(r.steps[r.active]||{}).visible||(r.active=r._visibleSteps[0]._index);e.call(y,r).call(L,r).call(_,r).call(A,r).call(C,t,r).call(x,t,r);var n=r._dims;o.setTranslate(e,n.lx+r.pad.l,n.ly+r.pad.t),e.call(M,r,!1),e.call(y,r)}(t,n.select(this),e)})}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_template\":757,\"../../plots/plots\":828,\"../color\":593,\"../drawing\":614,\"./constants\":677,d3:163}],680:[function(t,e,r){\"use strict\";var n=t(\"./constants\");e.exports={moduleType:\"component\",name:n.name,layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":676,\"./constants\":677,\"./defaults\":678,\"./draw\":679}],681:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../drawing\"),c=t(\"../color\"),u=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/interactions\");e.exports={draw:function(t,e,r){var p,d=r.propContainer,g=r.propName,v=r.placeholder,m=r.traceIndex,y=r.avoid||{},x=r.attributes,b=r.transform,_=r.containerGroup,w=t._fullLayout,k=1,T=!1,A=d.title,M=(A&&A.text?A.text:\"\").trim(),S=A&&A.font?A.font:{},E=S.family,C=S.size,L=S.color;\"title.text\"===g?p=\"titleText\":-1!==g.indexOf(\"axis\")?p=\"axisTitleText\":g.indexOf(!0)&&(p=\"colorbarTitleText\");var P=t._context.edits[p];\"\"===M?k=0:M.replace(f,\" % \")===v.replace(f,\" % \")&&(k=.2,T=!0,P||(M=\"\"));r._meta?M=s.templateString(M,r._meta):w._meta&&(M=s.templateString(M,w._meta));var O=M||P;_||(_=s.ensureSingle(w._infolayer,\"g\",\"g-\"+e));var z=_.selectAll(\"text\").data(O?[0]:[]);if(z.enter().append(\"text\"),z.text(M).attr(\"class\",e),z.exit().remove(),!O)return _;function I(t){s.syncOrAsync([D,R],t)}function D(e){var r;return b?(r=\"\",b.rotate&&(r+=\"rotate(\"+[b.rotate,x.x,x.y]+\")\"),b.offset&&(r+=\"translate(0, \"+b.offset+\")\")):r=null,e.attr(\"transform\",r),e.style({\"font-family\":E,\"font-size\":n.round(C,2)+\"px\",fill:c.rgb(L),opacity:k*c.opacity(L),\"font-weight\":a.fontWeight}).attr(x).call(u.convertToTspans,t),a.previousPromises(t)}function R(t){var e=n.select(t.node().parentNode);if(y&&y.selection&&y.side&&M){e.attr(\"transform\",null);var r=0,a={left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}[y.side],o=-1!==[\"left\",\"top\"].indexOf(y.side)?-1:1,c=i(y.pad)?y.pad:2,u=l.bBox(e.node()),h={left:0,top:0,right:w.width,bottom:w.height},f=y.maxShift||(h[y.side]-u[y.side])*(\"left\"===y.side||\"top\"===y.side?-1:1);if(f<0)r=f;else{var p=y.offsetLeft||0,d=y.offsetTop||0;u.left-=p,u.right-=p,u.top-=d,u.bottom-=d,y.selection.each(function(){var t=l.bBox(this);s.bBoxIntersect(u,t,c)&&(r=Math.max(r,o*(t[y.side]-u[a])+c))}),r=Math.min(f,r)}if(r>0||f<0){var g={left:[-r,0],right:[r,0],top:[0,-r],bottom:[0,r]}[y.side];e.attr(\"transform\",\"translate(\"+g+\")\")}}}z.call(I),P&&(M?z.on(\".opacity\",null):(k=0,T=!0,z.text(v).on(\"mouseover.opacity\",function(){n.select(this).transition().duration(h.SHOW_PLACEHOLDER).style(\"opacity\",1)}).on(\"mouseout.opacity\",function(){n.select(this).transition().duration(h.HIDE_PLACEHOLDER).style(\"opacity\",0)})),z.call(u.makeEditable,{gd:t}).on(\"edit\",function(e){void 0!==m?o.call(\"_guiRestyle\",t,g,e,m):o.call(\"_guiRelayout\",t,g,e)}).on(\"cancel\",function(){this.text(this.attr(\"data-unformatted\")).call(I)}).on(\"input\",function(t){this.text(t||\" \").call(u.positionText,x.x,x.y)}));return z.classed(\"js-placeholder\",T),_}};var f=/ [XY][0-9]* /},{\"../../constants/interactions\":694,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../drawing\":614,d3:163,\"fast-isnumeric\":225}],682:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/pad_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=l(\"button\",{visible:{valType:\"boolean\"},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\",dflt:\"\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"updatemenu\",{_arrayAttrRegexps:[/^updatemenus\\[(0|[1-9][0-9]+)\\]\\.buttons/],visible:{valType:\"boolean\"},type:{valType:\"enumerated\",values:[\"dropdown\",\"buttons\"],dflt:\"dropdown\"},direction:{valType:\"enumerated\",values:[\"left\",\"right\",\"up\",\"down\"],dflt:\"down\"},active:{valType:\"integer\",min:-1,dflt:0},showactive:{valType:\"boolean\",dflt:!0},buttons:c,x:{valType:\"number\",min:-2,max:3,dflt:-.05},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"right\"},y:{valType:\"number\",min:-2,max:3,dflt:1},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},pad:a(s({editType:\"arraydraw\"}),{}),font:n({}),bgcolor:{valType:\"color\"},bordercolor:{valType:\"color\",dflt:i.borderLine},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"arraydraw\"}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/font_attributes\":793,\"../../plots/pad_attributes\":827,\"../color/attributes\":592}],683:[function(t,e,r){\"use strict\";e.exports={name:\"updatemenus\",containerClassName:\"updatemenu-container\",headerGroupClassName:\"updatemenu-header-group\",headerClassName:\"updatemenu-header\",headerArrowClassName:\"updatemenu-header-arrow\",dropdownButtonGroupClassName:\"updatemenu-dropdown-button-group\",dropdownButtonClassName:\"updatemenu-dropdown-button\",buttonClassName:\"updatemenu-button\",itemRectClassName:\"updatemenu-item-rect\",itemTextClassName:\"updatemenu-item-text\",menuIndexAttrName:\"updatemenu-active-index\",autoMarginIdRoot:\"updatemenu-\",blankHeaderOpts:{label:\"  \"},minWidth:30,minHeight:30,textPadX:24,arrowPadX:16,rx:2,ry:2,textOffsetX:12,textOffsetY:3,arrowOffsetX:4,gapButtonHeader:5,gapButton:2,activeColor:\"#F4FAFF\",hoverColor:\"#F4FAFF\",arrowSymbol:{left:\"\\u25c4\",right:\"\\u25ba\",up:\"\\u25b2\",down:\"\\u25bc\"}}},{}],684:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.buttons;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}o(\"visible\",i(t,e,{name:\"buttons\",handleItemDefaults:c}).length>0)&&(o(\"active\"),o(\"direction\"),o(\"type\"),o(\"showactive\"),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"bgcolor\",r.paper_bgcolor),o(\"bordercolor\"),o(\"borderwidth\"))}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}r(\"visible\",\"skip\"===t.method||Array.isArray(t.args))&&(r(\"method\"),r(\"args\"),r(\"label\"),r(\"execute\"))}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"./attributes\":682,\"./constants\":683}],685:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"../../constants/alignment\").LINE_SPACING,h=t(\"./constants\"),f=t(\"./scrollbox\");function p(t){return t._index}function d(t,e){return+t.attr(h.menuIndexAttrName)===e._index}function g(t,e,r,n,i,a,o,s){e.active=o,c(t.layout,h.name,e).applyUpdate(\"active\",o),\"buttons\"===e.type?m(t,n,null,null,e):\"dropdown\"===e.type&&(i.attr(h.menuIndexAttrName,\"-1\"),v(t,n,i,a,e),s||m(t,n,i,a,e))}function v(t,e,r,n,i){var a=s.ensureSingle(e,\"g\",h.headerClassName,function(t){t.style(\"pointer-events\",\"all\")}),l=i._dims,c=i.active,u=i.buttons[c]||h.blankHeaderOpts,f={y:i.pad.t,yPad:0,x:i.pad.l,xPad:0,index:0},p={width:l.headerWidth,height:l.headerHeight};a.call(y,i,u,t).call(M,i,f,p),s.ensureSingle(e,\"text\",h.headerArrowClassName,function(t){t.classed(\"user-select-none\",!0).attr(\"text-anchor\",\"end\").call(o.font,i.font).text(h.arrowSymbol[i.direction])}).attr({x:l.headerWidth-h.arrowOffsetX+i.pad.l,y:l.headerHeight/2+h.textOffsetY+i.pad.t}),a.on(\"click\",function(){r.call(S,String(d(r,i)?-1:i._index)),m(t,e,r,n,i)}),a.on(\"mouseover\",function(){a.call(w)}),a.on(\"mouseout\",function(){a.call(k,i)}),o.setTranslate(e,l.lx,l.ly)}function m(t,e,r,a,o){r||(r=e).attr(\"pointer-events\",\"all\");var l=function(t){return-1==+t.attr(h.menuIndexAttrName)}(r)&&\"buttons\"!==o.type?[]:o.buttons,c=\"dropdown\"===o.type?h.dropdownButtonClassName:h.buttonClassName,u=r.selectAll(\"g.\"+c).data(s.filterVisible(l)),f=u.enter().append(\"g\").classed(c,!0),p=u.exit();\"dropdown\"===o.type?(f.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\"),p.transition().attr(\"opacity\",\"0\").remove()):p.remove();var d=0,v=0,m=o._dims,x=-1!==[\"up\",\"down\"].indexOf(o.direction);\"dropdown\"===o.type&&(x?v=m.headerHeight+h.gapButtonHeader:d=m.headerWidth+h.gapButtonHeader),\"dropdown\"===o.type&&\"up\"===o.direction&&(v=-h.gapButtonHeader+h.gapButton-m.openHeight),\"dropdown\"===o.type&&\"left\"===o.direction&&(d=-h.gapButtonHeader+h.gapButton-m.openWidth);var b={x:m.lx+d+o.pad.l,y:m.ly+v+o.pad.t,yPad:h.gapButton,xPad:h.gapButton,index:0},T={l:b.x+o.borderwidth,t:b.y+o.borderwidth};u.each(function(s,l){var c=n.select(this);c.call(y,o,s,t).call(M,o,b),c.on(\"click\",function(){n.event.defaultPrevented||(g(t,o,0,e,r,a,l),s.execute&&i.executeAPICommand(t,s.method,s.args),t.emit(\"plotly_buttonclicked\",{menu:o,button:s,active:o.active}))}),c.on(\"mouseover\",function(){c.call(w)}),c.on(\"mouseout\",function(){c.call(k,o),u.call(_,o)})}),u.call(_,o),x?(T.w=Math.max(m.openWidth,m.headerWidth),T.h=b.y-T.t):(T.w=b.x-T.l,T.h=Math.max(m.openHeight,m.headerHeight)),T.direction=o.direction,a&&(u.size()?function(t,e,r,n,i,a){var o,s,l,c=i.direction,u=\"up\"===c||\"down\"===c,f=i._dims,p=i.active;if(u)for(s=0,l=0;l<p;l++)s+=f.heights[l]+h.gapButton;else for(o=0,l=0;l<p;l++)o+=f.widths[l]+h.gapButton;n.enable(a,o,s),n.hbar&&n.hbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\");n.vbar&&n.vbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\")}(0,0,0,a,o,T):function(t){var e=!!t.hbar,r=!!t.vbar;e&&t.hbar.transition().attr(\"opacity\",\"0\").each(\"end\",function(){e=!1,r||t.disable()});r&&t.vbar.transition().attr(\"opacity\",\"0\").each(\"end\",function(){r=!1,e||t.disable()})}(a))}function y(t,e,r,n){t.call(x,e).call(b,e,r,n)}function x(t,e){s.ensureSingle(t,\"rect\",h.itemRectClassName,function(t){t.attr({rx:h.rx,ry:h.ry,\"shape-rendering\":\"crispEdges\"})}).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\")}function b(t,e,r,n){var i=s.ensureSingle(t,\"text\",h.itemTextClassName,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":\"start\",\"data-notex\":1})}),a=r.label,c=n._fullLayout._meta;c&&(a=s.templateString(a,c)),i.call(o.font,e.font).text(a).call(l.convertToTspans,n)}function _(t,e){var r=e.active;t.each(function(t,i){var o=n.select(this);i===r&&e.showactive&&o.select(\"rect.\"+h.itemRectClassName).call(a.fill,h.activeColor)})}function w(t){t.select(\"rect.\"+h.itemRectClassName).call(a.fill,h.hoverColor)}function k(t,e){t.select(\"rect.\"+h.itemRectClassName).call(a.fill,e.bgcolor)}function T(t,e){var r=e._dims={width1:0,height1:0,heights:[],widths:[],totalWidth:0,totalHeight:0,openWidth:0,openHeight:0,lx:0,ly:0},a=o.tester.selectAll(\"g.\"+h.dropdownButtonClassName).data(s.filterVisible(e.buttons));a.enter().append(\"g\").classed(h.dropdownButtonClassName,!0);var c=-1!==[\"up\",\"down\"].indexOf(e.direction);a.each(function(i,a){var s=n.select(this);s.call(y,e,i,t);var f=s.select(\".\"+h.itemTextClassName),p=f.node()&&o.bBox(f.node()).width,d=Math.max(p+h.textPadX,h.minWidth),g=e.font.size*u,v=l.lineCount(f),m=Math.max(g*v,h.minHeight)+h.textOffsetY;m=Math.ceil(m),d=Math.ceil(d),r.widths[a]=d,r.heights[a]=m,r.height1=Math.max(r.height1,m),r.width1=Math.max(r.width1,d),c?(r.totalWidth=Math.max(r.totalWidth,d),r.openWidth=r.totalWidth,r.totalHeight+=m+h.gapButton,r.openHeight+=m+h.gapButton):(r.totalWidth+=d+h.gapButton,r.openWidth+=d+h.gapButton,r.totalHeight=Math.max(r.totalHeight,m),r.openHeight=r.totalHeight)}),c?r.totalHeight-=h.gapButton:r.totalWidth-=h.gapButton,r.headerWidth=r.width1+h.arrowPadX,r.headerHeight=r.height1,\"dropdown\"===e.type&&(c?(r.width1+=h.arrowPadX,r.totalHeight=r.height1):r.totalWidth=r.width1,r.totalWidth+=h.arrowPadX),a.remove();var f=r.totalWidth+e.pad.l+e.pad.r,p=r.totalHeight+e.pad.t+e.pad.b,d=t._fullLayout._size;r.lx=d.l+d.w*e.x,r.ly=d.t+d.h*(1-e.y);var g=\"left\";s.isRightAnchor(e)&&(r.lx-=f,g=\"right\"),s.isCenterAnchor(e)&&(r.lx-=f/2,g=\"center\");var v=\"top\";s.isBottomAnchor(e)&&(r.ly-=p,v=\"bottom\"),s.isMiddleAnchor(e)&&(r.ly-=p/2,v=\"middle\"),r.totalWidth=Math.ceil(r.totalWidth),r.totalHeight=Math.ceil(r.totalHeight),r.lx=Math.round(r.lx),r.ly=Math.round(r.ly),i.autoMargin(t,A(e),{x:e.x,y:e.y,l:f*({right:1,center:.5}[g]||0),r:f*({left:1,center:.5}[g]||0),b:p*({top:1,middle:.5}[v]||0),t:p*({bottom:1,middle:.5}[v]||0)})}function A(t){return h.autoMarginIdRoot+t._index}function M(t,e,r,n){n=n||{};var i=t.select(\".\"+h.itemRectClassName),a=t.select(\".\"+h.itemTextClassName),s=e.borderwidth,c=r.index,f=e._dims;o.setTranslate(t,s+r.x,s+r.y);var p=-1!==[\"up\",\"down\"].indexOf(e.direction),d=n.height||(p?f.heights[c]:f.height1);i.attr({x:0,y:0,width:n.width||(p?f.width1:f.widths[c]),height:d});var g=e.font.size*u,v=(l.lineCount(a)-1)*g/2;l.positionText(a,h.textOffsetX,d/2-v+h.textOffsetY),p?r.y+=f.heights[c]+r.yPad:r.x+=f.widths[c]+r.xPad,r.index++}function S(t,e){t.attr(h.menuIndexAttrName,e||\"-1\").selectAll(\"g.\"+h.dropdownButtonClassName).remove()}e.exports=function(t){var e=t._fullLayout,r=s.filterVisible(e[h.name]);function a(e){i.autoMargin(t,A(e))}var o=e._menulayer.selectAll(\"g.\"+h.containerClassName).data(r.length>0?[0]:[]);if(o.enter().append(\"g\").classed(h.containerClassName,!0).style(\"cursor\",\"pointer\"),o.exit().each(function(){n.select(this).selectAll(\"g.\"+h.headerGroupClassName).each(a)}).remove(),0!==r.length){var l=o.selectAll(\"g.\"+h.headerGroupClassName).data(r,p);l.enter().append(\"g\").classed(h.headerGroupClassName,!0);for(var c=s.ensureSingle(o,\"g\",h.dropdownButtonGroupClassName,function(t){t.style(\"pointer-events\",\"all\")}),u=0;u<r.length;u++){var y=r[u];T(t,y)}var x=\"updatemenus\"+e._uid,b=new f(t,c,x);l.enter().size()&&(c.node().parentNode.appendChild(c.node()),c.call(S)),l.exit().each(function(t){c.call(S),a(t)}).remove(),l.each(function(e){var r=n.select(this),a=\"dropdown\"===e.type?c:null;i.manageCommandObserver(t,e,e.buttons,function(n){g(t,e,e.buttons[n.index],r,a,b,n.index,!0)}),\"dropdown\"===e.type?(v(t,r,c,b,e),d(c,e)&&m(t,r,c,b,e)):m(t,r,null,null,e)})}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_template\":757,\"../../plots/plots\":828,\"../color\":593,\"../drawing\":614,\"./constants\":683,\"./scrollbox\":687,d3:163}],686:[function(t,e,r){arguments[4][680][0].apply(r,arguments)},{\"./attributes\":682,\"./constants\":683,\"./defaults\":684,\"./draw\":685,dup:680}],687:[function(t,e,r){\"use strict\";e.exports=s;var n=t(\"d3\"),i=t(\"../color\"),a=t(\"../drawing\"),o=t(\"../../lib\");function s(t,e,r){this.gd=t,this.container=e,this.id=r,this.position=null,this.translateX=null,this.translateY=null,this.hbar=null,this.vbar=null,this.bg=this.container.selectAll(\"rect.scrollbox-bg\").data([0]),this.bg.exit().on(\".drag\",null).on(\"wheel\",null).remove(),this.bg.enter().append(\"rect\").classed(\"scrollbox-bg\",!0).style(\"pointer-events\",\"all\").attr({opacity:0,x:0,y:0,width:0,height:0})}s.barWidth=2,s.barLength=20,s.barRadius=2,s.barPad=1,s.barColor=\"#808BA4\",s.prototype.enable=function(t,e,r){var o=this.gd._fullLayout,l=o.width,c=o.height;this.position=t;var u,h,f,p,d=this.position.l,g=this.position.w,v=this.position.t,m=this.position.h,y=this.position.direction,x=\"down\"===y,b=\"left\"===y,_=\"up\"===y,w=g,k=m;x||b||\"right\"===y||_||(this.position.direction=\"down\",x=!0),x||_?(h=(u=d)+w,x?(f=v,k=(p=Math.min(f+k,c))-f):k=(p=v+k)-(f=Math.max(p-k,0))):(p=(f=v)+k,b?w=(h=d+w)-(u=Math.max(h-w,0)):(u=d,w=(h=Math.min(u+w,l))-u)),this._box={l:u,t:f,w:w,h:k};var T=g>w,A=s.barLength+2*s.barPad,M=s.barWidth+2*s.barPad,S=d,E=v+m;E+M>c&&(E=c-M);var C=this.container.selectAll(\"rect.scrollbar-horizontal\").data(T?[0]:[]);C.exit().on(\".drag\",null).remove(),C.enter().append(\"rect\").classed(\"scrollbar-horizontal\",!0).call(i.fill,s.barColor),T?(this.hbar=C.attr({rx:s.barRadius,ry:s.barRadius,x:S,y:E,width:A,height:M}),this._hbarXMin=S+A/2,this._hbarTranslateMax=w-A):(delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax);var L=m>k,P=s.barWidth+2*s.barPad,O=s.barLength+2*s.barPad,z=d+g,I=v;z+P>l&&(z=l-P);var D=this.container.selectAll(\"rect.scrollbar-vertical\").data(L?[0]:[]);D.exit().on(\".drag\",null).remove(),D.enter().append(\"rect\").classed(\"scrollbar-vertical\",!0).call(i.fill,s.barColor),L?(this.vbar=D.attr({rx:s.barRadius,ry:s.barRadius,x:z,y:I,width:P,height:O}),this._vbarYMin=I+O/2,this._vbarTranslateMax=k-O):(delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax);var R=this.id,F=u-.5,B=L?h+P+.5:h+.5,N=f-.5,j=T?p+M+.5:p+.5,U=o._topdefs.selectAll(\"#\"+R).data(T||L?[0]:[]);if(U.exit().remove(),U.enter().append(\"clipPath\").attr(\"id\",R).append(\"rect\"),T||L?(this._clipRect=U.select(\"rect\").attr({x:Math.floor(F),y:Math.floor(N),width:Math.ceil(B)-Math.floor(F),height:Math.ceil(j)-Math.floor(N)}),this.container.call(a.setClipUrl,R,this.gd),this.bg.attr({x:d,y:v,width:g,height:m})):(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),T||L){var V=n.behavior.drag().on(\"dragstart\",function(){n.event.sourceEvent.preventDefault()}).on(\"drag\",this._onBoxDrag.bind(this));this.container.on(\"wheel\",null).on(\"wheel\",this._onBoxWheel.bind(this)).on(\".drag\",null).call(V);var q=n.behavior.drag().on(\"dragstart\",function(){n.event.sourceEvent.preventDefault(),n.event.sourceEvent.stopPropagation()}).on(\"drag\",this._onBarDrag.bind(this));T&&this.hbar.on(\".drag\",null).call(q),L&&this.vbar.on(\".drag\",null).call(q)}this.setTranslate(e,r)},s.prototype.disable=function(){(this.hbar||this.vbar)&&(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),this.hbar&&(this.hbar.on(\".drag\",null),this.hbar.remove(),delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax),this.vbar&&(this.vbar.on(\".drag\",null),this.vbar.remove(),delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax)},s.prototype._onBoxDrag=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t-=n.event.dx),this.vbar&&(e-=n.event.dy),this.setTranslate(t,e)},s.prototype._onBoxWheel=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t+=n.event.deltaY),this.vbar&&(e+=n.event.deltaY),this.setTranslate(t,e)},s.prototype._onBarDrag=function(){var t=this.translateX,e=this.translateY;if(this.hbar){var r=t+this._hbarXMin,i=r+this._hbarTranslateMax;t=(o.constrain(n.event.x,r,i)-r)/(i-r)*(this.position.w-this._box.w)}if(this.vbar){var a=e+this._vbarYMin,s=a+this._vbarTranslateMax;e=(o.constrain(n.event.y,a,s)-a)/(s-a)*(this.position.h-this._box.h)}this.setTranslate(t,e)},s.prototype.setTranslate=function(t,e){var r=this.position.w-this._box.w,n=this.position.h-this._box.h;if(t=o.constrain(t||0,0,r),e=o.constrain(e||0,0,n),this.translateX=t,this.translateY=e,this.container.call(a.setTranslate,this._box.l-this.position.l-t,this._box.t-this.position.t-e),this._clipRect&&this._clipRect.attr({x:Math.floor(this.position.l+t-.5),y:Math.floor(this.position.t+e-.5)}),this.hbar){var i=t/r;this.hbar.call(a.setTranslate,t+i*this._hbarTranslateMax,e)}if(this.vbar){var s=e/n;this.vbar.call(a.setTranslate,t,e+s*this._vbarTranslateMax)}}},{\"../../lib\":719,\"../color\":593,\"../drawing\":614,d3:163}],688:[function(t,e,r){\"use strict\";e.exports={FROM_BL:{left:0,center:.5,right:1,bottom:0,middle:.5,top:1},FROM_TL:{left:0,center:.5,right:1,bottom:1,middle:.5,top:0},FROM_BR:{left:1,center:.5,right:0,bottom:0,middle:.5,top:1},LINE_SPACING:1.3,CAP_SHIFT:.7,MID_SHIFT:.35,OPPOSITE_SIDE:{left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}}},{}],689:[function(t,e,r){\"use strict\";e.exports={INCREASING:{COLOR:\"#3D9970\",SYMBOL:\"\\u25b2\"},DECREASING:{COLOR:\"#FF4136\",SYMBOL:\"\\u25bc\"}}},{}],690:[function(t,e,r){\"use strict\";e.exports={FORMAT_LINK:\"https://github.com/d3/d3-3.x-api-reference/blob/master/Formatting.md#d3_format\",DATE_FORMAT_LINK:\"https://github.com/d3/d3-3.x-api-reference/blob/master/Time-Formatting.md#format\"}},{}],691:[function(t,e,r){\"use strict\";e.exports={COMPARISON_OPS:[\"=\",\"!=\",\"<\",\">=\",\">\",\"<=\"],COMPARISON_OPS2:[\"=\",\"<\",\">=\",\">\",\"<=\"],INTERVAL_OPS:[\"[]\",\"()\",\"[)\",\"(]\",\"][\",\")(\",\"](\",\")[\"],SET_OPS:[\"{}\",\"}{\"],CONSTRAINT_REDUCTION:{\"=\":\"=\",\"<\":\"<\",\"<=\":\"<\",\">\":\">\",\">=\":\">\",\"[]\":\"[]\",\"()\":\"[]\",\"[)\":\"[]\",\"(]\":\"[]\",\"][\":\"][\",\")(\":\"][\",\"](\":\"][\",\")[\":\"][\"}}},{}],692:[function(t,e,r){\"use strict\";e.exports={solid:[[],0],dot:[[.5,1],200],dash:[[.5,1],50],longdash:[[.5,1],10],dashdot:[[.5,.625,.875,1],50],longdashdot:[[.5,.7,.8,1],10]}},{}],693:[function(t,e,r){\"use strict\";e.exports={circle:\"\\u25cf\",\"circle-open\":\"\\u25cb\",square:\"\\u25a0\",\"square-open\":\"\\u25a1\",diamond:\"\\u25c6\",\"diamond-open\":\"\\u25c7\",cross:\"+\",x:\"\\u274c\"}},{}],694:[function(t,e,r){\"use strict\";e.exports={SHOW_PLACEHOLDER:100,HIDE_PLACEHOLDER:1e3,DESELECTDIM:.2}},{}],695:[function(t,e,r){\"use strict\";e.exports={BADNUM:void 0,FP_SAFE:Number.MAX_VALUE/1e4,ONEAVGYEAR:315576e5,ONEAVGMONTH:26298e5,ONEDAY:864e5,ONEHOUR:36e5,ONEMIN:6e4,ONESEC:1e3,EPOCHJD:2440587.5,ALMOST_EQUAL:1-1e-6,LOG_CLIP:10,MINUS_SIGN:\"\\u2212\"}},{}],696:[function(t,e,r){\"use strict\";r.xmlns=\"http://www.w3.org/2000/xmlns/\",r.svg=\"http://www.w3.org/2000/svg\",r.xlink=\"http://www.w3.org/1999/xlink\",r.svgAttrs={xmlns:r.svg,\"xmlns:xlink\":r.xlink}},{}],697:[function(t,e,r){\"use strict\";r.version=\"1.49.1\",t(\"es6-promise\").polyfill(),t(\"../build/plotcss\"),t(\"./fonts/mathjax_config\")();for(var n=t(\"./registry\"),i=r.register=n.register,a=t(\"./plot_api\"),o=Object.keys(a),s=0;s<o.length;s++){var l=o[s];\"_\"!==l.charAt(0)&&(r[l]=a[l]),i({moduleType:\"apiMethod\",name:l,fn:a[l]})}i(t(\"./traces/scatter\")),i([t(\"./components/fx\"),t(\"./components/legend\"),t(\"./components/annotations\"),t(\"./components/annotations3d\"),t(\"./components/shapes\"),t(\"./components/images\"),t(\"./components/updatemenus\"),t(\"./components/sliders\"),t(\"./components/rangeslider\"),t(\"./components/rangeselector\"),t(\"./components/grid\"),t(\"./components/errorbars\"),t(\"./components/colorscale\"),t(\"./components/colorbar\")]),i([t(\"./locale-en\"),t(\"./locale-en-us\")]),r.Icons=t(\"./fonts/ploticon\"),r.Plots=t(\"./plots/plots\"),r.Fx=t(\"./components/fx\"),r.Snapshot=t(\"./snapshot\"),r.PlotSchema=t(\"./plot_api/plot_schema\"),r.Queue=t(\"./lib/queue\"),r.d3=t(\"d3\")},{\"../build/plotcss\":1,\"./components/annotations\":584,\"./components/annotations3d\":589,\"./components/colorbar\":599,\"./components/colorscale\":605,\"./components/errorbars\":620,\"./components/fx\":632,\"./components/grid\":636,\"./components/images\":641,\"./components/legend\":649,\"./components/rangeselector\":660,\"./components/rangeslider\":667,\"./components/shapes\":675,\"./components/sliders\":680,\"./components/updatemenus\":686,\"./fonts/mathjax_config\":698,\"./fonts/ploticon\":699,\"./lib/queue\":734,\"./locale-en\":748,\"./locale-en-us\":747,\"./plot_api\":752,\"./plot_api/plot_schema\":756,\"./plots/plots\":828,\"./registry\":847,\"./snapshot\":852,\"./traces/scatter\":1123,d3:163,\"es6-promise\":218}],698:[function(t,e,r){\"use strict\";e.exports=function(){\"undefined\"!=typeof MathJax&&(\"local\"!==(window.PlotlyConfig||{}).MathJaxConfig&&(MathJax.Hub.Config({messageStyle:\"none\",skipStartupTypeset:!0,displayAlign:\"left\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]}}),MathJax.Hub.Configured()))}},{}],699:[function(t,e,r){\"use strict\";e.exports={undo:{width:857.1,height:1e3,path:\"m857 350q0-87-34-166t-91-137-137-92-166-34q-96 0-183 41t-147 114q-4 6-4 13t5 11l76 77q6 5 14 5 9-1 13-7 41-53 100-82t126-29q58 0 110 23t92 61 61 91 22 111-22 111-61 91-92 61-110 23q-55 0-105-20t-90-57l77-77q17-16 8-38-10-23-33-23h-250q-15 0-25 11t-11 25v250q0 24 22 33 22 10 39-8l72-72q60 57 137 88t159 31q87 0 166-34t137-92 91-137 34-166z\",transform:\"matrix(1 0 0 -1 0 850)\"},home:{width:928.6,height:1e3,path:\"m786 296v-267q0-15-11-26t-25-10h-214v214h-143v-214h-214q-15 0-25 10t-11 26v267q0 1 0 2t0 2l321 264 321-264q1-1 1-4z m124 39l-34-41q-5-5-12-6h-2q-7 0-12 3l-386 322-386-322q-7-4-13-4-7 2-12 7l-35 41q-4 5-3 13t6 12l401 334q18 15 42 15t43-15l136-114v109q0 8 5 13t13 5h107q8 0 13-5t5-13v-227l122-102q5-5 6-12t-4-13z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"camera-retro\":{width:1e3,height:1e3,path:\"m518 386q0 8-5 13t-13 5q-37 0-63-27t-26-63q0-8 5-13t13-5 12 5 5 13q0 23 16 38t38 16q8 0 13 5t5 13z m125-73q0-59-42-101t-101-42-101 42-42 101 42 101 101 42 101-42 42-101z m-572-320h858v71h-858v-71z m643 320q0 89-62 152t-152 62-151-62-63-152 63-151 151-63 152 63 62 151z m-571 358h214v72h-214v-72z m-72-107h858v143h-462l-36-71h-360v-72z m929 143v-714q0-30-21-51t-50-21h-858q-29 0-50 21t-21 51v714q0 30 21 51t50 21h858q29 0 50-21t21-51z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoombox:{width:1e3,height:1e3,path:\"m1000-25l-250 251c40 63 63 138 63 218 0 224-182 406-407 406-224 0-406-182-406-406s183-406 407-406c80 0 155 22 218 62l250-250 125 125z m-812 250l0 438 437 0 0-438-437 0z m62 375l313 0 0-312-313 0 0 312z\",transform:\"matrix(1 0 0 -1 0 850)\"},pan:{width:1e3,height:1e3,path:\"m1000 350l-187 188 0-125-250 0 0 250 125 0-188 187-187-187 125 0 0-250-250 0 0 125-188-188 186-187 0 125 252 0 0-250-125 0 187-188 188 188-125 0 0 250 250 0 0-126 187 188z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_plus:{width:875,height:1e3,path:\"m1 787l0-875 875 0 0 875-875 0z m687-500l-187 0 0-187-125 0 0 187-188 0 0 125 188 0 0 187 125 0 0-187 187 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_minus:{width:875,height:1e3,path:\"m0 788l0-876 875 0 0 876-875 0z m688-500l-500 0 0 125 500 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},autoscale:{width:1e3,height:1e3,path:\"m250 850l-187 0-63 0 0-62 0-188 63 0 0 188 187 0 0 62z m688 0l-188 0 0-62 188 0 0-188 62 0 0 188 0 62-62 0z m-875-938l0 188-63 0 0-188 0-62 63 0 187 0 0 62-187 0z m875 188l0-188-188 0 0-62 188 0 62 0 0 62 0 188-62 0z m-125 188l-1 0-93-94-156 156 156 156 92-93 2 0 0 250-250 0 0-2 93-92-156-156-156 156 94 92 0 2-250 0 0-250 0 0 93 93 157-156-157-156-93 94 0 0 0-250 250 0 0 0-94 93 156 157 156-157-93-93 0 0 250 0 0 250z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_basic:{width:1500,height:1e3,path:\"m375 725l0 0-375-375 375-374 0-1 1125 0 0 750-1125 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_compare:{width:1125,height:1e3,path:\"m187 786l0 2-187-188 188-187 0 0 937 0 0 373-938 0z m0-499l0 1-187-188 188-188 0 0 937 0 0 376-938-1z\",transform:\"matrix(1 0 0 -1 0 850)\"},plotlylogo:{width:1542,height:1e3,path:\"m0-10h182v-140h-182v140z m228 146h183v-286h-183v286z m225 714h182v-1000h-182v1000z m225-285h182v-715h-182v715z m225 142h183v-857h-183v857z m231-428h182v-429h-182v429z m225-291h183v-138h-183v138z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"z-axis\":{width:1e3,height:1e3,path:\"m833 5l-17 108v41l-130-65 130-66c0 0 0 38 0 39 0-1 36-14 39-25 4-15-6-22-16-30-15-12-39-16-56-20-90-22-187-23-279-23-261 0-341 34-353 59 3 60 228 110 228 110-140-8-351-35-351-116 0-120 293-142 474-142 155 0 477 22 477 142 0 50-74 79-163 96z m-374 94c-58-5-99-21-99-40 0-24 65-43 144-43 79 0 143 19 143 43 0 19-42 34-98 40v216h87l-132 135-133-135h88v-216z m167 515h-136v1c16 16 31 34 46 52l84 109v54h-230v-71h124v-1c-16-17-28-32-44-51l-89-114v-51h245v72z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"3d_rotate\":{width:1e3,height:1e3,path:\"m922 660c-5 4-9 7-14 11-359 263-580-31-580-31l-102 28 58-400c0 1 1 1 2 2 118 108 351 249 351 249s-62 27-100 42c88 83 222 183 347 122 16-8 30-17 44-27-2 1-4 2-6 4z m36-329c0 0 64 229-88 296-62 27-124 14-175-11 157-78 225-208 249-266 8-19 11-31 11-31 2 5 6 15 11 32-5-13-8-20-8-20z m-775-239c70-31 117-50 198-32-121 80-199 346-199 346l-96-15-58-12c0 0 55-226 155-287z m603 133l-317-139c0 0 4-4 19-14 7-5 24-15 24-15s-177-147-389 4c235-287 536-112 536-112l31-22 100 299-4-1z m-298-153c6-4 14-9 24-15 0 0-17 10-24 15z\",transform:\"matrix(1 0 0 -1 0 850)\"},camera:{width:1e3,height:1e3,path:\"m500 450c-83 0-150-67-150-150 0-83 67-150 150-150 83 0 150 67 150 150 0 83-67 150-150 150z m400 150h-120c-16 0-34 13-39 29l-31 93c-6 15-23 28-40 28h-340c-16 0-34-13-39-28l-31-94c-6-15-23-28-40-28h-120c-55 0-100-45-100-100v-450c0-55 45-100 100-100h800c55 0 100 45 100 100v450c0 55-45 100-100 100z m-400-550c-138 0-250 112-250 250 0 138 112 250 250 250 138 0 250-112 250-250 0-138-112-250-250-250z m365 380c-19 0-35 16-35 35 0 19 16 35 35 35 19 0 35-16 35-35 0-19-16-35-35-35z\",transform:\"matrix(1 0 0 -1 0 850)\"},movie:{width:1e3,height:1e3,path:\"m938 413l-188-125c0 37-17 71-44 94 64 38 107 107 107 187 0 121-98 219-219 219-121 0-219-98-219-219 0-61 25-117 66-156h-115c30 33 49 76 49 125 0 103-84 187-187 187s-188-84-188-187c0-57 26-107 65-141-38-22-65-62-65-109v-250c0-70 56-126 125-126h500c69 0 125 56 125 126l188-126c34 0 62 28 62 63v375c0 35-28 63-62 63z m-750 0c-69 0-125 56-125 125s56 125 125 125 125-56 125-125-56-125-125-125z m406-1c-87 0-157 70-157 157 0 86 70 156 157 156s156-70 156-156-70-157-156-157z\",transform:\"matrix(1 0 0 -1 0 850)\"},question:{width:857.1,height:1e3,path:\"m500 82v107q0 8-5 13t-13 5h-107q-8 0-13-5t-5-13v-107q0-8 5-13t13-5h107q8 0 13 5t5 13z m143 375q0 49-31 91t-77 65-95 23q-136 0-207-119-9-14 4-24l74-55q4-4 10-4 9 0 14 7 30 38 48 51 19 14 48 14 27 0 48-15t21-33q0-21-11-34t-38-25q-35-16-65-48t-29-70v-20q0-8 5-13t13-5h107q8 0 13 5t5 13q0 10 12 27t30 28q18 10 28 16t25 19 25 27 16 34 7 45z m214-107q0-117-57-215t-156-156-215-58-216 58-155 156-58 215 58 215 155 156 216 58 215-58 156-156 57-215z\",transform:\"matrix(1 0 0 -1 0 850)\"},disk:{width:857.1,height:1e3,path:\"m214-7h429v214h-429v-214z m500 0h72v500q0 8-6 21t-11 20l-157 156q-5 6-19 12t-22 5v-232q0-22-15-38t-38-16h-322q-22 0-37 16t-16 38v232h-72v-714h72v232q0 22 16 38t37 16h465q22 0 38-16t15-38v-232z m-214 518v178q0 8-5 13t-13 5h-107q-7 0-13-5t-5-13v-178q0-8 5-13t13-5h107q7 0 13 5t5 13z m357-18v-518q0-22-15-38t-38-16h-750q-23 0-38 16t-16 38v750q0 22 16 38t38 16h517q23 0 50-12t42-26l156-157q16-15 27-42t11-49z\",transform:\"matrix(1 0 0 -1 0 850)\"},lasso:{width:1031,height:1e3,path:\"m1018 538c-36 207-290 336-568 286-277-48-473-256-436-463 10-57 36-108 76-151-13-66 11-137 68-183 34-28 75-41 114-42l-55-70 0 0c-2-1-3-2-4-3-10-14-8-34 5-45 14-11 34-8 45 4 1 1 2 3 2 5l0 0 113 140c16 11 31 24 45 40 4 3 6 7 8 11 48-3 100 0 151 9 278 48 473 255 436 462z m-624-379c-80 14-149 48-197 96 42 42 109 47 156 9 33-26 47-66 41-105z m-187-74c-19 16-33 37-39 60 50-32 109-55 174-68-42-25-95-24-135 8z m360 75c-34-7-69-9-102-8 8 62-16 128-68 170-73 59-175 54-244-5-9 20-16 40-20 61-28 159 121 317 333 354s407-60 434-217c28-159-121-318-333-355z\",transform:\"matrix(1 0 0 -1 0 850)\"},selectbox:{width:1e3,height:1e3,path:\"m0 850l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-285l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},spikeline:{width:1e3,height:1e3,path:\"M512 409c0-57-46-104-103-104-57 0-104 47-104 104 0 57 47 103 104 103 57 0 103-46 103-103z m-327-39l92 0 0 92-92 0z m-185 0l92 0 0 92-92 0z m370-186l92 0 0 93-92 0z m0-184l92 0 0 92-92 0z\",transform:\"matrix(1.5 0 0 -1.5 0 850)\"},pencil:{width:1792,height:1792,path:\"M491 1536l91-91-235-235-91 91v107h128v128h107zm523-928q0-22-22-22-10 0-17 7l-542 542q-7 7-7 17 0 22 22 22 10 0 17-7l542-542q7-7 7-17zm-54-192l416 416-832 832h-416v-416zm683 96q0 53-37 90l-166 166-416-416 166-165q36-38 90-38 53 0 91 38l235 234q37 39 37 91z\",transform:\"matrix(1 0 0 1 0 1)\"},newplotlylogo:{name:\"newplotlylogo\",svg:\"<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 132 132'><defs><style>.cls-1 {fill: #119dff;} .cls-2 {fill: #25fefd;} .cls-3 {fill: #fff;}</style></defs><title>plotly-logomark</title><g id='symbol'><rect class='cls-1' width='132' height='132' rx='6' ry='6'/><circle class='cls-2' cx='78' cy='54' r='6'/><circle class='cls-2' cx='102' cy='30' r='6'/><circle class='cls-2' cx='78' cy='30' r='6'/><circle class='cls-2' cx='54' cy='30' r='6'/><circle class='cls-2' cx='30' cy='30' r='6'/><circle class='cls-2' cx='30' cy='54' r='6'/><path class='cls-3' d='M30,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,30,72Z'/><path class='cls-3' d='M78,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,78,72Z'/><path class='cls-3' d='M54,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,54,48Z'/><path class='cls-3' d='M102,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,102,48Z'/></g></svg>\"}}},{}],700:[function(t,e,r){\"use strict\";r.isLeftAnchor=function(t){return\"left\"===t.xanchor||\"auto\"===t.xanchor&&t.x<=1/3},r.isCenterAnchor=function(t){return\"center\"===t.xanchor||\"auto\"===t.xanchor&&t.x>1/3&&t.x<2/3},r.isRightAnchor=function(t){return\"right\"===t.xanchor||\"auto\"===t.xanchor&&t.x>=2/3},r.isTopAnchor=function(t){return\"top\"===t.yanchor||\"auto\"===t.yanchor&&t.y>=2/3},r.isMiddleAnchor=function(t){return\"middle\"===t.yanchor||\"auto\"===t.yanchor&&t.y>1/3&&t.y<2/3},r.isBottomAnchor=function(t){return\"bottom\"===t.yanchor||\"auto\"===t.yanchor&&t.y<=1/3}},{}],701:[function(t,e,r){\"use strict\";var n=t(\"./mod\"),i=n.mod,a=n.modHalf,o=Math.PI,s=2*o;function l(t){return Math.abs(t[1]-t[0])>s-1e-14}function c(t,e){return a(e-t,s)}function u(t,e){if(l(e))return!0;var r,n;e[0]<e[1]?(r=e[0],n=e[1]):(r=e[1],n=e[0]),(r=i(r,s))>(n=i(n,s))&&(n+=s);var a=i(t,s),o=a+s;return a>=r&&a<=n||o>=r&&o<=n}function h(t,e,r,n,i,a,c){i=i||0,a=a||0;var u,h,f,p,d,g=l([r,n]);function v(t,e){return[t*Math.cos(e)+i,a-t*Math.sin(e)]}g?(u=0,h=o,f=s):r<n?(u=r,f=n):(u=n,f=r),t<e?(p=t,d=e):(p=e,d=t);var m,y=Math.abs(f-u)<=o?0:1;function x(t,e,r){return\"A\"+[t,t]+\" \"+[0,y,r]+\" \"+v(t,e)}return g?m=null===p?\"M\"+v(d,u)+x(d,h,0)+x(d,f,0)+\"Z\":\"M\"+v(p,u)+x(p,h,0)+x(p,f,0)+\"ZM\"+v(d,u)+x(d,h,1)+x(d,f,1)+\"Z\":null===p?(m=\"M\"+v(d,u)+x(d,f,0),c&&(m+=\"L0,0Z\")):m=\"M\"+v(p,u)+\"L\"+v(d,u)+x(d,f,0)+\"L\"+v(p,f)+x(p,u,1)+\"Z\",m}e.exports={deg2rad:function(t){return t/180*o},rad2deg:function(t){return t/o*180},angleDelta:c,angleDist:function(t,e){return Math.abs(c(t,e))},isFullCircle:l,isAngleInsideSector:u,isPtInsideSector:function(t,e,r,n){return!!u(e,n)&&(r[0]<r[1]?(i=r[0],a=r[1]):(i=r[1],a=r[0]),t>=i&&t<=a);var i,a},pathArc:function(t,e,r,n,i){return h(null,t,e,r,n,i,0)},pathSector:function(t,e,r,n,i){return h(null,t,e,r,n,i,1)},pathAnnulus:function(t,e,r,n,i,a){return h(t,e,r,n,i,a,1)}}},{\"./mod\":726}],702:[function(t,e,r){\"use strict\";var n=Array.isArray,i=\"undefined\"!=typeof ArrayBuffer&&ArrayBuffer.isView?ArrayBuffer:{isView:function(){return!1}},a=\"undefined\"==typeof DataView?function(){}:DataView;function o(t){return i.isView(t)&&!(t instanceof a)}function s(t){return n(t)||o(t)}function l(t,e,r){if(s(t)){if(s(t[0])){for(var n=r,i=0;i<t.length;i++)n=e(n,t[i].length);return n}return t.length}return 0}r.isTypedArray=o,r.isArrayOrTypedArray=s,r.isArray1D=function(t){return!s(t[0])},r.ensureArray=function(t,e){return n(t)||(t=[]),t.length=e,t},r.concat=function(){var t,e,r,i,a,o,s,l,c=[],u=!0,h=0;for(r=0;r<arguments.length;r++)(o=(i=arguments[r]).length)&&(e?c.push(i):(e=i,a=o),n(i)?t=!1:(u=!1,h?t!==i.constructor&&(t=!1):t=i.constructor),h+=o);if(!h)return[];if(!c.length)return e;if(u)return e.concat.apply(e,c);if(t){for((s=new t(h)).set(e),r=0;r<c.length;r++)i=c[r],s.set(i,a),a+=i.length;return s}for(s=new Array(h),l=0;l<e.length;l++)s[l]=e[l];for(r=0;r<c.length;r++){for(i=c[r],l=0;l<i.length;l++)s[a+l]=i[l];a+=l}return s},r.maxRowLength=function(t){return l(t,Math.max,0)},r.minRowLength=function(t){return l(t,Math.min,1/0)}},{}],703:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../constants/numerical\").BADNUM,a=/^['\"%,$#\\s']+|[, ]|['\"%,$#\\s']+$/g;e.exports=function(t){return\"string\"==typeof t&&(t=t.replace(a,\"\")),n(t)?Number(t):i}},{\"../constants/numerical\":695,\"fast-isnumeric\":225}],704:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t._fullLayout;e._glcanvas&&e._glcanvas.size()&&e._glcanvas.each(function(t){t.regl&&t.regl.clear({color:!0,depth:!0})})}},{}],705:[function(t,e,r){\"use strict\";e.exports=function(t){t._responsiveChartHandler&&(window.removeEventListener(\"resize\",t._responsiveChartHandler),delete t._responsiveChartHandler)}},{}],706:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../plots/attributes\"),o=t(\"../components/colorscale/scales\"),s=t(\"../constants/interactions\").DESELECTDIM,l=t(\"./nested_property\"),c=t(\"./regex\").counter,u=t(\"./mod\").modHalf,h=t(\"./array\").isArrayOrTypedArray;function f(t,e){var n=r.valObjectMeta[e.valType];if(e.arrayOk&&h(t))return!0;if(n.validateFunction)return n.validateFunction(t,e);var i={},a=i,o={set:function(t){a=t}};return n.coerceFunction(t,o,i,e),a!==i}r.valObjectMeta={data_array:{coerceFunction:function(t,e,r){h(t)?e.set(t):void 0!==r&&e.set(r)}},enumerated:{coerceFunction:function(t,e,r,n){n.coerceNumber&&(t=+t),-1===n.values.indexOf(t)?e.set(r):e.set(t)},validateFunction:function(t,e){e.coerceNumber&&(t=+t);for(var r=e.values,n=0;n<r.length;n++){var i=String(r[n]);if(\"/\"===i.charAt(0)&&\"/\"===i.charAt(i.length-1)){if(new RegExp(i.substr(1,i.length-2)).test(t))return!0}else if(t===r[n])return!0}return!1}},boolean:{coerceFunction:function(t,e,r){!0===t||!1===t?e.set(t):e.set(r)}},number:{coerceFunction:function(t,e,r,i){!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},integer:{coerceFunction:function(t,e,r,i){t%1||!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},string:{coerceFunction:function(t,e,r,n){if(\"string\"!=typeof t){var i=\"number\"==typeof t;!0!==n.strict&&i?e.set(String(t)):e.set(r)}else n.noBlank&&!t?e.set(r):e.set(t)}},color:{coerceFunction:function(t,e,r){i(t).isValid()?e.set(t):e.set(r)}},colorlist:{coerceFunction:function(t,e,r){Array.isArray(t)&&t.length&&t.every(function(t){return i(t).isValid()})?e.set(t):e.set(r)}},colorscale:{coerceFunction:function(t,e,r){e.set(o.get(t,r))}},angle:{coerceFunction:function(t,e,r){\"auto\"===t?e.set(\"auto\"):n(t)?e.set(u(+t,360)):e.set(r)}},subplotid:{coerceFunction:function(t,e,r,n){var i=n.regex||c(r);\"string\"==typeof t&&i.test(t)?e.set(t):e.set(r)},validateFunction:function(t,e){var r=e.dflt;return t===r||\"string\"==typeof t&&!!c(r).test(t)}},flaglist:{coerceFunction:function(t,e,r,n){if(\"string\"==typeof t)if(-1===(n.extras||[]).indexOf(t)){for(var i=t.split(\"+\"),a=0;a<i.length;){var o=i[a];-1===n.flags.indexOf(o)||i.indexOf(o)<a?i.splice(a,1):a++}i.length?e.set(i.join(\"+\")):e.set(r)}else e.set(t);else e.set(r)}},any:{coerceFunction:function(t,e,r){void 0===t?e.set(r):e.set(t)}},info_array:{coerceFunction:function(t,e,n,i){function a(t,e,n){var i,a={set:function(t){i=t}};return void 0===n&&(n=e.dflt),r.valObjectMeta[e.valType].coerceFunction(t,a,n,e),i}var o=2===i.dimensions||\"1-2\"===i.dimensions&&Array.isArray(t)&&Array.isArray(t[0]);if(Array.isArray(t)){var s,l,c,u,h,f,p=i.items,d=[],g=Array.isArray(p),v=g&&o&&Array.isArray(p[0]),m=o&&g&&!v,y=g&&!m?p.length:t.length;if(n=Array.isArray(n)?n:[],o)for(s=0;s<y;s++)for(d[s]=[],c=Array.isArray(t[s])?t[s]:[],h=m?p.length:g?p[s].length:c.length,l=0;l<h;l++)u=m?p[l]:g?p[s][l]:p,void 0!==(f=a(c[l],u,(n[s]||[])[l]))&&(d[s][l]=f);else for(s=0;s<y;s++)void 0!==(f=a(t[s],g?p[s]:p,n[s]))&&(d[s]=f);e.set(d)}else e.set(n)},validateFunction:function(t,e){if(!Array.isArray(t))return!1;var r=e.items,n=Array.isArray(r),i=2===e.dimensions;if(!e.freeLength&&t.length!==r.length)return!1;for(var a=0;a<t.length;a++)if(i){if(!Array.isArray(t[a])||!e.freeLength&&t[a].length!==r[a].length)return!1;for(var o=0;o<t[a].length;o++)if(!f(t[a][o],n?r[a][o]:r))return!1}else if(!f(t[a],n?r[a]:r))return!1;return!0}}},r.coerce=function(t,e,n,i,a){var o=l(n,i).get(),s=l(t,i),c=l(e,i),u=s.get(),p=e._template;if(void 0===u&&p&&(u=l(p,i).get(),p=0),void 0===a&&(a=o.dflt),o.arrayOk&&h(u))return c.set(u),u;var d=r.valObjectMeta[o.valType].coerceFunction;d(u,c,a,o);var g=c.get();return p&&g===a&&!f(u,o)&&(d(u=l(p,i).get(),c,a,o),g=c.get()),g},r.coerce2=function(t,e,n,i,a){var o=l(t,i),s=r.coerce(t,e,n,i,a),c=o.get();return null!=c&&s},r.coerceFont=function(t,e,r){var n={};return r=r||{},n.family=t(e+\".family\",r.family),n.size=t(e+\".size\",r.size),n.color=t(e+\".color\",r.color),n},r.coerceHoverinfo=function(t,e,n){var i,o=e._module.attributes,s=o.hoverinfo?o:a,l=s.hoverinfo;if(1===n._dataLength){var c=\"all\"===l.dflt?l.flags.slice():l.dflt.split(\"+\");c.splice(c.indexOf(\"name\"),1),i=c.join(\"+\")}return r.coerce(t,e,s,\"hoverinfo\",i)},r.coerceSelectionMarkerOpacity=function(t,e){if(t.marker){var r,n,i=t.marker.opacity;if(void 0!==i)h(i)||t.selected||t.unselected||(r=i,n=s*i),e(\"selected.marker.opacity\",r),e(\"unselected.marker.opacity\",n)}},r.validate=f},{\"../components/colorscale/scales\":608,\"../constants/interactions\":694,\"../plots/attributes\":764,\"./array\":702,\"./mod\":726,\"./nested_property\":727,\"./regex\":735,\"fast-isnumeric\":225,tinycolor2:537}],707:[function(t,e,r){\"use strict\";var n,i,a=t(\"d3\"),o=t(\"fast-isnumeric\"),s=t(\"./loggers\"),l=t(\"./mod\").mod,c=t(\"../constants/numerical\"),u=c.BADNUM,h=c.ONEDAY,f=c.ONEHOUR,p=c.ONEMIN,d=c.ONESEC,g=c.EPOCHJD,v=t(\"../registry\"),m=a.time.format.utc,y=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\d)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d:?\\d\\d)?)?)?)?)?\\s*$/m,x=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\di?)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d:?\\d\\d)?)?)?)?)?\\s*$/m,b=(new Date).getFullYear()-70;function _(t){return t&&v.componentsRegistry.calendars&&\"string\"==typeof t&&\"gregorian\"!==t}function w(t,e){return String(t+Math.pow(10,e)).substr(1)}r.dateTick0=function(t,e){return _(t)?e?v.getComponentMethod(\"calendars\",\"CANONICAL_SUNDAY\")[t]:v.getComponentMethod(\"calendars\",\"CANONICAL_TICK\")[t]:e?\"2000-01-02\":\"2000-01-01\"},r.dfltRange=function(t){return _(t)?v.getComponentMethod(\"calendars\",\"DFLTRANGE\")[t]:[\"2000-01-01\",\"2001-01-01\"]},r.isJSDate=function(t){return\"object\"==typeof t&&null!==t&&\"function\"==typeof t.getTime},r.dateTime2ms=function(t,e){if(r.isJSDate(t)){var a=t.getTimezoneOffset()*p,o=(t.getUTCMinutes()-t.getMinutes())*p+(t.getUTCSeconds()-t.getSeconds())*d+(t.getUTCMilliseconds()-t.getMilliseconds());if(o){var s=3*p;a=a-s/2+l(o-a+s/2,s)}return(t=Number(t)-a)>=n&&t<=i?t:u}if(\"string\"!=typeof t&&\"number\"!=typeof t)return u;t=String(t);var c=_(e),m=t.charAt(0);!c||\"G\"!==m&&\"g\"!==m||(t=t.substr(1),e=\"\");var w=c&&\"chinese\"===e.substr(0,7),k=t.match(w?x:y);if(!k)return u;var T=k[1],A=k[3]||\"1\",M=Number(k[5]||1),S=Number(k[7]||0),E=Number(k[9]||0),C=Number(k[11]||0);if(c){if(2===T.length)return u;var L;T=Number(T);try{var P=v.getComponentMethod(\"calendars\",\"getCal\")(e);if(w){var O=\"i\"===A.charAt(A.length-1);A=parseInt(A,10),L=P.newDate(T,P.toMonthIndex(T,A,O),M)}else L=P.newDate(T,Number(A),M)}catch(t){return u}return L?(L.toJD()-g)*h+S*f+E*p+C*d:u}T=2===T.length?(Number(T)+2e3-b)%100+b:Number(T),A-=1;var z=new Date(Date.UTC(2e3,A,M,S,E));return z.setUTCFullYear(T),z.getUTCMonth()!==A?u:z.getUTCDate()!==M?u:z.getTime()+C*d},n=r.MIN_MS=r.dateTime2ms(\"-9999\"),i=r.MAX_MS=r.dateTime2ms(\"9999-12-31 23:59:59.9999\"),r.isDateTime=function(t,e){return r.dateTime2ms(t,e)!==u};var k=90*h,T=3*f,A=5*p;function M(t,e,r,n,i){if((e||r||n||i)&&(t+=\" \"+w(e,2)+\":\"+w(r,2),(n||i)&&(t+=\":\"+w(n,2),i))){for(var a=4;i%10==0;)a-=1,i/=10;t+=\".\"+w(i,a)}return t}r.ms2DateTime=function(t,e,r){if(\"number\"!=typeof t||!(t>=n&&t<=i))return u;e||(e=0);var a,o,s,c,y,x,b=Math.floor(10*l(t+.05,1)),w=Math.round(t-b/10);if(_(r)){var S=Math.floor(w/h)+g,E=Math.floor(l(t,h));try{a=v.getComponentMethod(\"calendars\",\"getCal\")(r).fromJD(S).formatDate(\"yyyy-mm-dd\")}catch(t){a=m(\"G%Y-%m-%d\")(new Date(w))}if(\"-\"===a.charAt(0))for(;a.length<11;)a=\"-0\"+a.substr(1);else for(;a.length<10;)a=\"0\"+a;o=e<k?Math.floor(E/f):0,s=e<k?Math.floor(E%f/p):0,c=e<T?Math.floor(E%p/d):0,y=e<A?E%d*10+b:0}else x=new Date(w),a=m(\"%Y-%m-%d\")(x),o=e<k?x.getUTCHours():0,s=e<k?x.getUTCMinutes():0,c=e<T?x.getUTCSeconds():0,y=e<A?10*x.getUTCMilliseconds()+b:0;return M(a,o,s,c,y)},r.ms2DateTimeLocal=function(t){if(!(t>=n+h&&t<=i-h))return u;var e=Math.floor(10*l(t+.05,1)),r=new Date(Math.round(t-e/10));return M(a.time.format(\"%Y-%m-%d\")(r),r.getHours(),r.getMinutes(),r.getSeconds(),10*r.getUTCMilliseconds()+e)},r.cleanDate=function(t,e,n){if(t===u)return e;if(r.isJSDate(t)||\"number\"==typeof t&&isFinite(t)){if(_(n))return s.error(\"JS Dates and milliseconds are incompatible with world calendars\",t),e;if(!(t=r.ms2DateTimeLocal(+t))&&void 0!==e)return e}else if(!r.isDateTime(t,n))return s.error(\"unrecognized date\",t),e;return t};var S=/%\\d?f/g;function E(t,e,r,n){t=t.replace(S,function(t){var r=Math.min(+t.charAt(1)||6,6);return(e/1e3%1+2).toFixed(r).substr(2).replace(/0+$/,\"\")||\"0\"});var i=new Date(Math.floor(e+.05));if(_(n))try{t=v.getComponentMethod(\"calendars\",\"worldCalFmt\")(t,e,n)}catch(t){return\"Invalid\"}return r(t)(i)}var C=[59,59.9,59.99,59.999,59.9999];r.formatDate=function(t,e,r,n,i,a){if(i=_(i)&&i,!e)if(\"y\"===r)e=a.year;else if(\"m\"===r)e=a.month;else{if(\"d\"!==r)return function(t,e){var r=l(t+.05,h),n=w(Math.floor(r/f),2)+\":\"+w(l(Math.floor(r/p),60),2);if(\"M\"!==e){o(e)||(e=0);var i=(100+Math.min(l(t/d,60),C[e])).toFixed(e).substr(1);e>0&&(i=i.replace(/0+$/,\"\").replace(/[\\.]$/,\"\")),n+=\":\"+i}return n}(t,r)+\"\\n\"+E(a.dayMonthYear,t,n,i);e=a.dayMonth+\"\\n\"+a.year}return E(e,t,n,i)};var L=3*h;r.incrementMonth=function(t,e,r){r=_(r)&&r;var n=l(t,h);if(t=Math.round(t-n),r)try{var i=Math.round(t/h)+g,a=v.getComponentMethod(\"calendars\",\"getCal\")(r),o=a.fromJD(i);return e%12?a.add(o,e,\"m\"):a.add(o,e/12,\"y\"),(o.toJD()-g)*h+n}catch(e){s.error(\"invalid ms \"+t+\" in calendar \"+r)}var c=new Date(t+L);return c.setUTCMonth(c.getUTCMonth()+e)+n-L},r.findExactDates=function(t,e){for(var r,n,i=0,a=0,s=0,l=0,c=_(e)&&v.getComponentMethod(\"calendars\",\"getCal\")(e),u=0;u<t.length;u++)if(n=t[u],o(n)){if(!(n%h))if(c)try{1===(r=c.fromJD(n/h+g)).day()?1===r.month()?i++:a++:s++}catch(t){}else 1===(r=new Date(n)).getUTCDate()?0===r.getUTCMonth()?i++:a++:s++}else l++;s+=a+=i;var f=t.length-l;return{exactYears:i/f,exactMonths:a/f,exactDays:s/f}}},{\"../constants/numerical\":695,\"../registry\":847,\"./loggers\":723,\"./mod\":726,d3:163,\"fast-isnumeric\":225}],708:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./loggers\");function a(t){var e=t&&t.parentNode;e&&e.removeChild(t)}function o(t,e,r){var n=\"plotly.js-style-\"+t,a=document.getElementById(n);a||((a=document.createElement(\"style\")).setAttribute(\"id\",n),a.appendChild(document.createTextNode(\"\")),document.head.appendChild(a));var o=a.sheet;o.insertRule?o.insertRule(e+\"{\"+r+\"}\",0):o.addRule?o.addRule(e,r,0):i.warn(\"addStyleRule failed\")}e.exports={getGraphDiv:function(t){var e;if(\"string\"==typeof t){if(null===(e=document.getElementById(t)))throw new Error(\"No DOM element with id '\"+t+\"' exists on the page.\");return e}if(null==t)throw new Error(\"DOM element provided is null or undefined\");return t},isPlotDiv:function(t){var e=n.select(t);return e.node()instanceof HTMLElement&&e.size()&&e.classed(\"js-plotly-plot\")},removeElement:a,addStyleRule:function(t,e){o(\"global\",t,e)},addRelatedStyleRule:o,deleteRelatedStyleRule:function(t){var e=\"plotly.js-style-\"+t,r=document.getElementById(e);r&&a(r)}}},{\"./loggers\":723,d3:163}],709:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i={init:function(t){if(t._ev instanceof n)return t;var e=new n,r=new n;return t._ev=e,t._internalEv=r,t.on=e.on.bind(e),t.once=e.once.bind(e),t.removeListener=e.removeListener.bind(e),t.removeAllListeners=e.removeAllListeners.bind(e),t._internalOn=r.on.bind(r),t._internalOnce=r.once.bind(r),t._removeInternalListener=r.removeListener.bind(r),t._removeAllInternalListeners=r.removeAllListeners.bind(r),t.emit=function(n,i){\"undefined\"!=typeof jQuery&&jQuery(t).trigger(n,i),e.emit(n,i),r.emit(n,i)},t},triggerHandler:function(t,e,r){var n,i;\"undefined\"!=typeof jQuery&&(n=jQuery(t).triggerHandler(e,r));var a=t._ev;if(!a)return n;var o,s=a._events[e];if(!s)return n;function l(t){return t.listener?(a.removeListener(e,t.listener),t.fired?void 0:(t.fired=!0,t.listener.apply(a,[r]))):t.apply(a,[r])}for(s=Array.isArray(s)?s:[s],o=0;o<s.length-1;o++)l(s[o]);return i=l(s[o]),void 0!==n?n:i},purge:function(t){return delete t._ev,delete t.on,delete t.once,delete t.removeListener,delete t.removeAllListeners,delete t.emit,delete t._ev,delete t._internalEv,delete t._internalOn,delete t._internalOnce,delete t._removeInternalListener,delete t._removeAllInternalListeners,t}};e.exports=i},{events:104}],710:[function(t,e,r){\"use strict\";var n=t(\"./is_plain_object.js\"),i=Array.isArray;function a(t,e,r,o){var s,l,c,u,h,f,p=t[0],d=t.length;if(2===d&&i(p)&&i(t[1])&&0===p.length){if(function(t,e){var r,n;for(r=0;r<t.length;r++){if(null!==(n=t[r])&&\"object\"==typeof n)return!1;void 0!==n&&(e[r]=n)}return!0}(t[1],p))return p;p.splice(0,p.length)}for(var g=1;g<d;g++)for(l in s=t[g])c=p[l],u=s[l],o&&i(u)?p[l]=u:e&&u&&(n(u)||(h=i(u)))?(h?(h=!1,f=c&&i(c)?c:[]):f=c&&n(c)?c:{},p[l]=a([f,u],e,r,o)):(\"undefined\"!=typeof u||r)&&(p[l]=u);return p}r.extendFlat=function(){return a(arguments,!1,!1,!1)},r.extendDeep=function(){return a(arguments,!0,!1,!1)},r.extendDeepAll=function(){return a(arguments,!0,!0,!1)},r.extendDeepNoArrays=function(){return a(arguments,!0,!1,!0)}},{\"./is_plain_object.js\":720}],711:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e={},r=[],n=0,i=0;i<t.length;i++){var a=t[i];1!==e[a]&&(e[a]=1,r[n++]=a)}return r}},{}],712:[function(t,e,r){\"use strict\";function n(t){return!0===t.visible}function i(t){var e=t[0].trace;return!0===e.visible&&0!==e._length}e.exports=function(t){for(var e,r=(e=t,Array.isArray(e)&&Array.isArray(e[0])&&e[0][0]&&e[0][0].trace?i:n),a=[],o=0;o<t.length;o++){var s=t[o];r(s)&&a.push(s)}return a}},{}],713:[function(t,e,r){\"use strict\";var n=t(\"country-regex\"),i=t(\"../lib\"),a=Object.keys(n),o={\"ISO-3\":i.identity,\"USA-states\":i.identity,\"country names\":function(t){for(var e=0;e<a.length;e++){var r=a[e],o=new RegExp(n[r]);if(o.test(t.trim().toLowerCase()))return r}return i.log(\"Unrecognized country name: \"+t+\".\"),!1}};e.exports={locationToFeature:function(t,e,r){if(!e||\"string\"!=typeof e)return!1;var n,a,s,l=o[t](e);if(l){if(\"USA-states\"===t)for(n=[],s=0;s<r.length;s++)(a=r[s]).properties&&a.properties.gu&&\"USA\"===a.properties.gu&&n.push(a);else n=r;for(s=0;s<n.length;s++)if((a=n[s]).id===l)return a;i.log([\"Location with id\",l,\"does not have a matching topojson feature at this resolution.\"].join(\" \"))}return!1}}},{\"../lib\":719,\"country-regex\":134}],714:[function(t,e,r){\"use strict\";var n=t(\"../constants/numerical\").BADNUM;r.calcTraceToLineCoords=function(t){for(var e=t[0].trace.connectgaps,r=[],i=[],a=0;a<t.length;a++){var o=t[a].lonlat;o[0]!==n?i.push(o):!e&&i.length>0&&(r.push(i),i=[])}return i.length>0&&r.push(i),r},r.makeLine=function(t){return 1===t.length?{type:\"LineString\",coordinates:t[0]}:{type:\"MultiLineString\",coordinates:t}},r.makePolygon=function(t){if(1===t.length)return{type:\"Polygon\",coordinates:t};for(var e=new Array(t.length),r=0;r<t.length;r++)e[r]=[t[r]];return{type:\"MultiPolygon\",coordinates:e}},r.makeBlank=function(){return{type:\"Point\",coordinates:[]}}},{\"../constants/numerical\":695}],715:[function(t,e,r){\"use strict\";var n,i,a,o=t(\"./mod\").mod;function s(t,e,r,n,i,a,o,s){var l=r-t,c=i-t,u=o-i,h=n-e,f=a-e,p=s-a,d=l*p-u*h;if(0===d)return null;var g=(c*p-u*f)/d,v=(c*h-l*f)/d;return v<0||v>1||g<0||g>1?null:{x:t+l*g,y:e+h*g}}function l(t,e,r,n,i){var a=n*t+i*e;if(a<0)return n*n+i*i;if(a>r){var o=n-t,s=i-e;return o*o+s*s}var l=n*e-i*t;return l*l/r}r.segmentsIntersect=s,r.segmentDistance=function(t,e,r,n,i,a,o,c){if(s(t,e,r,n,i,a,o,c))return 0;var u=r-t,h=n-e,f=o-i,p=c-a,d=u*u+h*h,g=f*f+p*p,v=Math.min(l(u,h,d,i-t,a-e),l(u,h,d,o-t,c-e),l(f,p,g,t-i,e-a),l(f,p,g,r-i,n-a));return Math.sqrt(v)},r.getTextLocation=function(t,e,r,s){if(t===i&&s===a||(n={},i=t,a=s),n[r])return n[r];var l=t.getPointAtLength(o(r-s/2,e)),c=t.getPointAtLength(o(r+s/2,e)),u=Math.atan((c.y-l.y)/(c.x-l.x)),h=t.getPointAtLength(o(r,e)),f={x:(4*h.x+l.x+c.x)/6,y:(4*h.y+l.y+c.y)/6,theta:u};return n[r]=f,f},r.clearLocationCache=function(){i=null},r.getVisibleSegment=function(t,e,r){var n,i,a=e.left,o=e.right,s=e.top,l=e.bottom,c=0,u=t.getTotalLength(),h=u;function f(e){var r=t.getPointAtLength(e);0===e?n=r:e===u&&(i=r);var c=r.x<a?a-r.x:r.x>o?r.x-o:0,h=r.y<s?s-r.y:r.y>l?r.y-l:0;return Math.sqrt(c*c+h*h)}for(var p=f(c);p;){if((c+=p+r)>h)return;p=f(c)}for(p=f(h);p;){if(c>(h-=p+r))return;p=f(h)}return{min:c,max:h,len:h-c,total:u,isClosed:0===c&&h===u&&Math.abs(n.x-i.x)<.1&&Math.abs(n.y-i.y)<.1}},r.findPointOnPath=function(t,e,r,n){for(var i,a,o,s=(n=n||{}).pathLength||t.getTotalLength(),l=n.tolerance||.001,c=n.iterationLimit||30,u=t.getPointAtLength(0)[r]>t.getPointAtLength(s)[r]?-1:1,h=0,f=0,p=s;h<c;){if(i=(f+p)/2,o=(a=t.getPointAtLength(i))[r]-e,Math.abs(o)<l)return a;u*o>0?p=i:f=i,h++}return a}},{\"./mod\":726}],716:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"color-normalize\"),o=t(\"../components/colorscale\"),s=t(\"../components/color/attributes\").defaultLine,l=t(\"./array\").isArrayOrTypedArray,c=a(s),u=1;function h(t,e){var r=t;return r[3]*=e,r}function f(t){if(n(t))return c;var e=a(t);return e.length?e:c}function p(t){return n(t)?t:u}e.exports={formatColor:function(t,e,r){var n,i,s,d,g,v=t.color,m=l(v),y=l(e),x=o.extractOpts(t),b=[];if(n=void 0!==x.colorscale?o.makeColorScaleFuncFromTrace(t):f,i=m?function(t,e){return void 0===t[e]?c:a(n(t[e]))}:f,s=y?function(t,e){return void 0===t[e]?u:p(t[e])}:p,m||y)for(var _=0;_<r;_++)d=i(v,_),g=s(e,_),b[_]=h(d,g);else b=h(a(v),e);return b},parseColorScale:function(t,e){void 0===e&&(e=1);var r=o.extractOpts(t);return(r.reversescale?o.flipScale(r.colorscale):r.colorscale).map(function(t){var r=t[0],n=i(t[1]).toRgb();return{index:r,rgb:[n.r,n.g,n.b,e]}})}}},{\"../components/color/attributes\":592,\"../components/colorscale\":605,\"./array\":702,\"color-normalize\":120,\"fast-isnumeric\":225,tinycolor2:537}],717:[function(t,e,r){\"use strict\";var n=t(\"./identity\");function i(t){return[t]}e.exports={keyFun:function(t){return t.key},repeat:i,descend:n,wrap:i,unwrap:function(t){return t[0]}}},{\"./identity\":718}],718:[function(t,e,r){\"use strict\";e.exports=function(t){return t}},{}],719:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../constants/numerical\"),o=a.FP_SAFE,s=a.BADNUM,l=e.exports={};l.nestedProperty=t(\"./nested_property\"),l.keyedContainer=t(\"./keyed_container\"),l.relativeAttr=t(\"./relative_attr\"),l.isPlainObject=t(\"./is_plain_object\"),l.toLogRange=t(\"./to_log_range\"),l.relinkPrivateKeys=t(\"./relink_private\");var c=t(\"./array\");l.isTypedArray=c.isTypedArray,l.isArrayOrTypedArray=c.isArrayOrTypedArray,l.isArray1D=c.isArray1D,l.ensureArray=c.ensureArray,l.concat=c.concat,l.maxRowLength=c.maxRowLength,l.minRowLength=c.minRowLength;var u=t(\"./mod\");l.mod=u.mod,l.modHalf=u.modHalf;var h=t(\"./coerce\");l.valObjectMeta=h.valObjectMeta,l.coerce=h.coerce,l.coerce2=h.coerce2,l.coerceFont=h.coerceFont,l.coerceHoverinfo=h.coerceHoverinfo,l.coerceSelectionMarkerOpacity=h.coerceSelectionMarkerOpacity,l.validate=h.validate;var f=t(\"./dates\");l.dateTime2ms=f.dateTime2ms,l.isDateTime=f.isDateTime,l.ms2DateTime=f.ms2DateTime,l.ms2DateTimeLocal=f.ms2DateTimeLocal,l.cleanDate=f.cleanDate,l.isJSDate=f.isJSDate,l.formatDate=f.formatDate,l.incrementMonth=f.incrementMonth,l.dateTick0=f.dateTick0,l.dfltRange=f.dfltRange,l.findExactDates=f.findExactDates,l.MIN_MS=f.MIN_MS,l.MAX_MS=f.MAX_MS;var p=t(\"./search\");l.findBin=p.findBin,l.sorterAsc=p.sorterAsc,l.sorterDes=p.sorterDes,l.distinctVals=p.distinctVals,l.roundUp=p.roundUp,l.sort=p.sort,l.findIndexOfMin=p.findIndexOfMin;var d=t(\"./stats\");l.aggNums=d.aggNums,l.len=d.len,l.mean=d.mean,l.median=d.median,l.midRange=d.midRange,l.variance=d.variance,l.stdev=d.stdev,l.interp=d.interp;var g=t(\"./matrix\");l.init2dArray=g.init2dArray,l.transposeRagged=g.transposeRagged,l.dot=g.dot,l.translationMatrix=g.translationMatrix,l.rotationMatrix=g.rotationMatrix,l.rotationXYMatrix=g.rotationXYMatrix,l.apply2DTransform=g.apply2DTransform,l.apply2DTransform2=g.apply2DTransform2;var v=t(\"./angles\");l.deg2rad=v.deg2rad,l.rad2deg=v.rad2deg,l.angleDelta=v.angleDelta,l.angleDist=v.angleDist,l.isFullCircle=v.isFullCircle,l.isAngleInsideSector=v.isAngleInsideSector,l.isPtInsideSector=v.isPtInsideSector,l.pathArc=v.pathArc,l.pathSector=v.pathSector,l.pathAnnulus=v.pathAnnulus;var m=t(\"./anchor_utils\");l.isLeftAnchor=m.isLeftAnchor,l.isCenterAnchor=m.isCenterAnchor,l.isRightAnchor=m.isRightAnchor,l.isTopAnchor=m.isTopAnchor,l.isMiddleAnchor=m.isMiddleAnchor,l.isBottomAnchor=m.isBottomAnchor;var y=t(\"./geometry2d\");l.segmentsIntersect=y.segmentsIntersect,l.segmentDistance=y.segmentDistance,l.getTextLocation=y.getTextLocation,l.clearLocationCache=y.clearLocationCache,l.getVisibleSegment=y.getVisibleSegment,l.findPointOnPath=y.findPointOnPath;var x=t(\"./extend\");l.extendFlat=x.extendFlat,l.extendDeep=x.extendDeep,l.extendDeepAll=x.extendDeepAll,l.extendDeepNoArrays=x.extendDeepNoArrays;var b=t(\"./loggers\");l.log=b.log,l.warn=b.warn,l.error=b.error;var _=t(\"./regex\");l.counterRegex=_.counter;var w=t(\"./throttle\");l.throttle=w.throttle,l.throttleDone=w.done,l.clearThrottle=w.clear;var k=t(\"./dom\");function T(t){var e={};for(var r in t)for(var n=t[r],i=0;i<n.length;i++)e[n[i]]=+r;return e}l.getGraphDiv=k.getGraphDiv,l.isPlotDiv=k.isPlotDiv,l.removeElement=k.removeElement,l.addStyleRule=k.addStyleRule,l.addRelatedStyleRule=k.addRelatedStyleRule,l.deleteRelatedStyleRule=k.deleteRelatedStyleRule,l.clearResponsive=t(\"./clear_responsive\"),l.makeTraceGroups=t(\"./make_trace_groups\"),l._=t(\"./localize\"),l.notifier=t(\"./notifier\"),l.filterUnique=t(\"./filter_unique\"),l.filterVisible=t(\"./filter_visible\"),l.pushUnique=t(\"./push_unique\"),l.cleanNumber=t(\"./clean_number\"),l.ensureNumber=function(t){return i(t)?(t=Number(t))<-o||t>o?s:i(t)?Number(t):s:s},l.isIndex=function(t,e){return!(void 0!==e&&t>=e)&&(i(t)&&t>=0&&t%1==0)},l.noop=t(\"./noop\"),l.identity=t(\"./identity\"),l.repeat=function(t,e){for(var r=new Array(e),n=0;n<e;n++)r[n]=t;return r},l.swapAttrs=function(t,e,r,n){r||(r=\"x\"),n||(n=\"y\");for(var i=0;i<e.length;i++){var a=e[i],o=l.nestedProperty(t,a.replace(\"?\",r)),s=l.nestedProperty(t,a.replace(\"?\",n)),c=o.get();o.set(s.get()),s.set(c)}},l.raiseToTop=function(t){t.parentNode.appendChild(t)},l.cancelTransition=function(t){return t.transition().duration(0)},l.constrain=function(t,e,r){return e>r?Math.max(r,Math.min(e,t)):Math.max(e,Math.min(r,t))},l.bBoxIntersect=function(t,e,r){return r=r||0,t.left<=e.right+r&&e.left<=t.right+r&&t.top<=e.bottom+r&&e.top<=t.bottom+r},l.simpleMap=function(t,e,r,n){for(var i=t.length,a=new Array(i),o=0;o<i;o++)a[o]=e(t[o],r,n);return a},l.randstr=function t(e,r,n,i){if(n||(n=16),void 0===r&&(r=24),r<=0)return\"0\";var a,o,s=Math.log(Math.pow(2,r))/Math.log(n),c=\"\";for(a=2;s===1/0;a*=2)s=Math.log(Math.pow(2,r/a))/Math.log(n)*a;var u=s-Math.floor(s);for(a=0;a<Math.floor(s);a++)c=Math.floor(Math.random()*n).toString(n)+c;u&&(o=Math.pow(n,u),c=Math.floor(Math.random()*o).toString(n)+c);var h=parseInt(c,n);return e&&e[c]||h!==1/0&&h>=Math.pow(2,r)?i>10?(l.warn(\"randstr failed uniqueness\"),c):t(e,r,n,(i||0)+1):c},l.OptionControl=function(t,e){t||(t={}),e||(e=\"opt\");var r={optionList:[],_newoption:function(n){n[e]=t,r[n.name]=n,r.optionList.push(n)}};return r[\"_\"+e]=t,r},l.smooth=function(t,e){if((e=Math.round(e)||0)<2)return t;var r,n,i,a,o=t.length,s=2*o,l=2*e-1,c=new Array(l),u=new Array(o);for(r=0;r<l;r++)c[r]=(1-Math.cos(Math.PI*(r+1)/e))/(2*e);for(r=0;r<o;r++){for(a=0,n=0;n<l;n++)(i=r+n+1-e)<-o?i-=s*Math.round(i/s):i>=s&&(i-=s*Math.floor(i/s)),i<0?i=-1-i:i>=o&&(i=s-1-i),a+=t[i]*c[n];u[r]=a}return u},l.syncOrAsync=function(t,e,r){var n;function i(){return l.syncOrAsync(t,e,r)}for(;t.length;)if((n=(0,t.splice(0,1)[0])(e))&&n.then)return n.then(i).then(void 0,l.promiseError);return r&&r(e)},l.stripTrailingSlash=function(t){return\"/\"===t.substr(-1)?t.substr(0,t.length-1):t},l.noneOrAll=function(t,e,r){if(t){var n,i=!1,a=!0;for(n=0;n<r.length;n++)null!=t[r[n]]?i=!0:a=!1;if(i&&!a)for(n=0;n<r.length;n++)t[r[n]]=e[r[n]]}},l.mergeArray=function(t,e,r,n){var i=\"function\"==typeof n;if(l.isArrayOrTypedArray(t))for(var a=Math.min(t.length,e.length),o=0;o<a;o++){var s=t[o];e[o][r]=i?n(s):s}},l.mergeArrayCastPositive=function(t,e,r){return l.mergeArray(t,e,r,function(t){var e=+t;return isFinite(e)&&e>0?e:0})},l.fillArray=function(t,e,r,n){if(n=n||l.identity,l.isArrayOrTypedArray(t))for(var i=0;i<e.length;i++)e[i][r]=n(t[i])},l.castOption=function(t,e,r,n){n=n||l.identity;var i=l.nestedProperty(t,r).get();return l.isArrayOrTypedArray(i)?Array.isArray(e)&&l.isArrayOrTypedArray(i[e[0]])?n(i[e[0]][e[1]]):n(i[e]):i},l.extractOption=function(t,e,r,n){if(r in t)return t[r];var i=l.nestedProperty(e,n).get();return Array.isArray(i)?void 0:i},l.tagSelected=function(t,e,r){var n,i,a=e.selectedpoints,o=e._indexToPoints;o&&(n=T(o));for(var s=0;s<a.length;s++){var c=a[s];if(l.isIndex(c)){var u=n?n[c]:c,h=r?r[u]:u;void 0!==(i=h)&&i<t.length&&(t[h].selected=1)}}},l.selIndices2selPoints=function(t){var e=t.selectedpoints,r=t._indexToPoints;if(r){for(var n=T(r),i=[],a=0;a<e.length;a++){var o=e[a];if(l.isIndex(o)){var s=n[o];l.isIndex(s)&&i.push(s)}}return i}return e},l.getTargetArray=function(t,e){var r=e.target;if(\"string\"==typeof r&&r){var n=l.nestedProperty(t,r).get();return!!Array.isArray(n)&&n}return!!Array.isArray(r)&&r},l.minExtend=function(t,e){var r={};\"object\"!=typeof e&&(e={});var n,i,a,o=Object.keys(t);for(n=0;n<o.length;n++)a=t[i=o[n]],\"_\"!==i.charAt(0)&&\"function\"!=typeof a&&(\"module\"===i?r[i]=a:Array.isArray(a)?r[i]=\"colorscale\"===i?a.slice():a.slice(0,3):r[i]=a&&\"object\"==typeof a?l.minExtend(t[i],e[i]):a);for(o=Object.keys(e),n=0;n<o.length;n++)\"object\"==typeof(a=e[i=o[n]])&&i in r&&\"object\"==typeof r[i]||(r[i]=a);return r},l.titleCase=function(t){return t.charAt(0).toUpperCase()+t.substr(1)},l.containsAny=function(t,e){for(var r=0;r<e.length;r++)if(-1!==t.indexOf(e[r]))return!0;return!1},l.isIE=function(){return\"undefined\"!=typeof window.navigator.msSaveBlob};var A=/MSIE [1-9]\\./;l.isIE9orBelow=function(){return l.isIE()&&A.test(window.navigator.userAgent)};var M=/Version\\/[\\d\\.]+.*Safari/;l.isSafari=function(){return M.test(window.navigator.userAgent)},l.isD3Selection=function(t){return t&&\"function\"==typeof t.classed},l.ensureSingle=function(t,e,r,n){var i=t.select(e+(r?\".\"+r:\"\"));if(i.size())return i;var a=t.append(e);return r&&a.classed(r,!0),n&&a.call(n),a},l.ensureSingleById=function(t,e,r,n){var i=t.select(e+\"#\"+r);if(i.size())return i;var a=t.append(e).attr(\"id\",r);return n&&a.call(n),a},l.objectFromPath=function(t,e){for(var r,n=t.split(\".\"),i=r={},a=0;a<n.length;a++){var o=n[a],s=null,l=n[a].match(/(.*)\\[([0-9]+)\\]/);l?(o=l[1],s=l[2],r=r[o]=[],a===n.length-1?r[s]=e:r[s]={},r=r[s]):(a===n.length-1?r[o]=e:r[o]={},r=r[o])}return i};var S=/^([^\\[\\.]+)\\.(.+)?/,E=/^([^\\.]+)\\[([0-9]+)\\](\\.)?(.+)?/;l.expandObjectPaths=function(t){var e,r,n,i,a,o,s;if(\"object\"==typeof t&&!Array.isArray(t))for(r in t)t.hasOwnProperty(r)&&((e=r.match(S))?(i=t[r],n=e[1],delete t[r],t[n]=l.extendDeepNoArrays(t[n]||{},l.objectFromPath(r,l.expandObjectPaths(i))[n])):(e=r.match(E))?(i=t[r],n=e[1],a=parseInt(e[2]),delete t[r],t[n]=t[n]||[],\".\"===e[3]?(s=e[4],o=t[n][a]=t[n][a]||{},l.extendDeepNoArrays(o,l.objectFromPath(s,l.expandObjectPaths(i)))):t[n][a]=l.expandObjectPaths(i)):t[r]=l.expandObjectPaths(t[r]));return t},l.numSeparate=function(t,e,r){if(r||(r=!1),\"string\"!=typeof e||0===e.length)throw new Error(\"Separator string required for formatting!\");\"number\"==typeof t&&(t=String(t));var n=/(\\d+)(\\d{3})/,i=e.charAt(0),a=e.charAt(1),o=t.split(\".\"),s=o[0],l=o.length>1?i+o[1]:\"\";if(a&&(o.length>1||s.length>4||r))for(;n.test(s);)s=s.replace(n,\"$1\"+a+\"$2\");return s+l},l.TEMPLATE_STRING_REGEX=/%{([^\\s%{}:]*)(:[^}]*)?}/g;var C=/^\\w*$/;l.templateString=function(t,e){var r={};return t.replace(l.TEMPLATE_STRING_REGEX,function(t,n){return C.test(n)?e[n]||\"\":(r[n]=r[n]||l.nestedProperty(e,n).get,r[n]()||\"\")})};var L=/^:/,P=0;l.hovertemplateString=function(t,e,r){var i=arguments,a={};return t.replace(l.TEMPLATE_STRING_REGEX,function(t,o,s){var c,u,h;for(h=3;h<i.length;h++){if((c=i[h]).hasOwnProperty(o)){u=c[o];break}if(C.test(o)||(u=a[o]||l.nestedProperty(c,o).get())&&(a[o]=u),void 0!==u)break}(void 0===u&&(P<10&&(l.warn(\"Variable '\"+o+\"' in hovertemplate could not be found!\"),u=t),10===P&&l.warn(\"Too many hovertemplate warnings - additional warnings will be suppressed\"),P++),s)?u=(r?r.numberFormat:n.format)(s.replace(L,\"\"))(u):e.hasOwnProperty(o+\"Label\")&&(u=e[o+\"Label\"]);return u})};l.subplotSort=function(t,e){for(var r=Math.min(t.length,e.length)+1,n=0,i=0,a=0;a<r;a++){var o=t.charCodeAt(a)||0,s=e.charCodeAt(a)||0,l=o>=48&&o<=57,c=s>=48&&s<=57;if(l&&(n=10*n+o-48),c&&(i=10*i+s-48),!l||!c){if(n!==i)return n-i;if(o!==s)return o-s}}return i-n};var O=2e9;l.seedPseudoRandom=function(){O=2e9},l.pseudoRandom=function(){var t=O;return O=(69069*O+1)%4294967296,Math.abs(O-t)<429496729?l.pseudoRandom():O/4294967296},l.fillText=function(t,e,r){var n=Array.isArray(r)?function(t){r.push(t)}:function(t){r.text=t},i=l.extractOption(t,e,\"htx\",\"hovertext\");if(l.isValidTextValue(i))return n(i);var a=l.extractOption(t,e,\"tx\",\"text\");return l.isValidTextValue(a)?n(a):void 0},l.isValidTextValue=function(t){return t||0===t},l.formatPercent=function(t,e){e=e||0;for(var r=(Math.round(100*t*Math.pow(10,e))*Math.pow(.1,e)).toFixed(e)+\"%\",n=0;n<e;n++)-1!==r.indexOf(\".\")&&(r=(r=r.replace(\"0%\",\"%\")).replace(\".%\",\"%\"));return r},l.isHidden=function(t){var e=window.getComputedStyle(t).display;return!e||\"none\"===e}},{\"../constants/numerical\":695,\"./anchor_utils\":700,\"./angles\":701,\"./array\":702,\"./clean_number\":703,\"./clear_responsive\":705,\"./coerce\":706,\"./dates\":707,\"./dom\":708,\"./extend\":710,\"./filter_unique\":711,\"./filter_visible\":712,\"./geometry2d\":715,\"./identity\":718,\"./is_plain_object\":720,\"./keyed_container\":721,\"./localize\":722,\"./loggers\":723,\"./make_trace_groups\":724,\"./matrix\":725,\"./mod\":726,\"./nested_property\":727,\"./noop\":728,\"./notifier\":729,\"./push_unique\":733,\"./regex\":735,\"./relative_attr\":736,\"./relink_private\":737,\"./search\":738,\"./stats\":741,\"./throttle\":744,\"./to_log_range\":745,d3:163,\"fast-isnumeric\":225}],720:[function(t,e,r){\"use strict\";e.exports=function(t){return window&&window.process&&window.process.versions?\"[object Object]\"===Object.prototype.toString.call(t):\"[object Object]\"===Object.prototype.toString.call(t)&&Object.getPrototypeOf(t)===Object.prototype}},{}],721:[function(t,e,r){\"use strict\";var n=t(\"./nested_property\"),i=/^\\w*$/;e.exports=function(t,e,r,a){var o,s,l;r=r||\"name\",a=a||\"value\";var c={};e&&e.length?(l=n(t,e),s=l.get()):s=t,e=e||\"\";var u={};if(s)for(o=0;o<s.length;o++)u[s[o][r]]=o;var h=i.test(a),f={set:function(t,e){var i=null===e?4:0;if(!s){if(!l||4===i)return;s=[],l.set(s)}var o=u[t];if(void 0===o){if(4===i)return;i|=3,o=s.length,u[t]=o}else e!==(h?s[o][a]:n(s[o],a).get())&&(i|=2);var p=s[o]=s[o]||{};return p[r]=t,h?p[a]=e:n(p,a).set(e),null!==e&&(i&=-5),c[o]=c[o]|i,f},get:function(t){if(s){var e=u[t];return void 0===e?void 0:h?s[e][a]:n(s[e],a).get()}},rename:function(t,e){var n=u[t];return void 0===n?f:(c[n]=1|c[n],u[e]=n,delete u[t],s[n][r]=e,f)},remove:function(t){var e=u[t];if(void 0===e)return f;var i=s[e];if(Object.keys(i).length>2)return c[e]=2|c[e],f.set(t,null);if(h){for(o=e;o<s.length;o++)c[o]=3|c[o];for(o=e;o<s.length;o++)u[s[o][r]]--;s.splice(e,1),delete u[t]}else n(i,a).set(null),c[e]=6|c[e];return f},constructUpdate:function(){for(var t,i,o={},l=Object.keys(c),u=0;u<l.length;u++)i=l[u],t=e+\"[\"+i+\"]\",s[i]?(1&c[i]&&(o[t+\".\"+r]=s[i][r]),2&c[i]&&(o[t+\".\"+a]=h?4&c[i]?null:s[i][a]:4&c[i]?null:n(s[i],a).get())):o[t]=null;return o}};return f}},{\"./nested_property\":727}],722:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t,e){for(var r=t._context.locale,i=0;i<2;i++){for(var a=t._context.locales,o=0;o<2;o++){var s=(a[r]||{}).dictionary;if(s){var l=s[e];if(l)return l}a=n.localeRegistry}var c=r.split(\"-\")[0];if(c===r)break;r=c}return e}},{\"../registry\":847}],723:[function(t,e,r){\"use strict\";var n=t(\"../plot_api/plot_config\").dfltConfig,i=e.exports={};function a(t,e){if(t&&t.apply)try{return void t.apply(console,e)}catch(t){}for(var r=0;r<e.length;r++)try{t(e[r])}catch(t){console.log(e[r])}}i.log=function(){if(n.logging>1){for(var t=[\"LOG:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.trace||console.log,t)}},i.warn=function(){if(n.logging>0){for(var t=[\"WARN:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.trace||console.log,t)}},i.error=function(){if(n.logging>0){for(var t=[\"ERROR:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.error,t)}}},{\"../plot_api/plot_config\":755}],724:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e,r){var i=t.selectAll(\"g.\"+r.replace(/\\s/g,\".\")).data(e,function(t){return t[0].trace.uid});i.exit().remove(),i.enter().append(\"g\").attr(\"class\",r),i.order();var a=t.classed(\"rangeplot\")?\"nodeRangePlot3\":\"node3\";return i.each(function(t){t[0][a]=n.select(this)}),i}},{d3:163}],725:[function(t,e,r){\"use strict\";r.init2dArray=function(t,e){for(var r=new Array(t),n=0;n<t;n++)r[n]=new Array(e);return r},r.transposeRagged=function(t){var e,r,n=0,i=t.length;for(e=0;e<i;e++)n=Math.max(n,t[e].length);var a=new Array(n);for(e=0;e<n;e++)for(a[e]=new Array(i),r=0;r<i;r++)a[e][r]=t[r][e];return a},r.dot=function(t,e){if(!t.length||!e.length||t.length!==e.length)return null;var n,i,a=t.length;if(t[0].length)for(n=new Array(a),i=0;i<a;i++)n[i]=r.dot(t[i],e);else if(e[0].length){var o=r.transposeRagged(e);for(n=new Array(o.length),i=0;i<o.length;i++)n[i]=r.dot(t,o[i])}else for(n=0,i=0;i<a;i++)n+=t[i]*e[i];return n},r.translationMatrix=function(t,e){return[[1,0,t],[0,1,e],[0,0,1]]},r.rotationMatrix=function(t){var e=t*Math.PI/180;return[[Math.cos(e),-Math.sin(e),0],[Math.sin(e),Math.cos(e),0],[0,0,1]]},r.rotationXYMatrix=function(t,e,n){return r.dot(r.dot(r.translationMatrix(e,n),r.rotationMatrix(t)),r.translationMatrix(-e,-n))},r.apply2DTransform=function(t){return function(){var e=arguments;3===e.length&&(e=e[0]);var n=1===arguments.length?e[0]:[e[0],e[1]];return r.dot(t,[n[0],n[1],1]).slice(0,2)}},r.apply2DTransform2=function(t){var e=r.apply2DTransform(t);return function(t){return e(t.slice(0,2)).concat(e(t.slice(2,4)))}}},{}],726:[function(t,e,r){\"use strict\";e.exports={mod:function(t,e){var r=t%e;return r<0?r+e:r},modHalf:function(t,e){return Math.abs(t)>e/2?t-Math.round(t/e)*e:t}}},{}],727:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;e.exports=function(t,e){if(n(e))e=String(e);else if(\"string\"!=typeof e||\"[-1]\"===e.substr(e.length-4))throw\"bad property string\";for(var r,a,o,l=0,c=e.split(\".\");l<c.length;){if(r=String(c[l]).match(/^([^\\[\\]]*)((\\[\\-?[0-9]*\\])+)$/)){if(r[1])c[l]=r[1];else{if(0!==l)throw\"bad property string\";c.splice(0,1)}for(a=r[2].substr(1,r[2].length-2).split(\"][\"),o=0;o<a.length;o++)l++,c.splice(l,0,Number(a[o]))}l++}return\"object\"!=typeof t?function(t,e,r){return{set:function(){throw\"bad container\"},get:function(){},astr:e,parts:r,obj:t}}(t,e,c):{set:s(t,c,e),get:function t(e,r){return function(){var n,a,o,s,l,c=e;for(s=0;s<r.length-1;s++){if(-1===(n=r[s])){for(a=!0,o=[],l=0;l<c.length;l++)o[l]=t(c[l],r.slice(s+1))(),o[l]!==o[0]&&(a=!1);return a?o[0]:o}if(\"number\"==typeof n&&!i(c))return;if(\"object\"!=typeof(c=c[n])||null===c)return}if(\"object\"==typeof c&&null!==c&&null!==(o=c[r[s]]))return o}}(t,c),astr:e,parts:c,obj:t}};var a=/(^|\\.)args\\[/;function o(t,e){return void 0===t||null===t&&!e.match(a)}function s(t,e,r){return function(n){var a,s,h=t,f=\"\",p=[[t,f]],d=o(n,r);for(s=0;s<e.length-1;s++){if(\"number\"==typeof(a=e[s])&&!i(h))throw\"array index but container is not an array\";if(-1===a){if(d=!c(h,e.slice(s+1),n,r))break;return}if(!u(h,a,e[s+1],d))break;if(\"object\"!=typeof(h=h[a])||null===h)throw\"container is not an object\";f=l(f,a),p.push([h,f])}if(d){if(s===e.length-1&&(delete h[e[s]],Array.isArray(h)&&+e[s]==h.length-1))for(;h.length&&void 0===h[h.length-1];)h.pop()}else h[e[s]]=n}}function l(t,e){var r=e;return n(e)?r=\"[\"+e+\"]\":t&&(r=\".\"+e),t+r}function c(t,e,r,n){var a,l=i(r),c=!0,h=r,f=n.replace(\"-1\",0),p=!l&&o(r,f),d=e[0];for(a=0;a<t.length;a++)f=n.replace(\"-1\",a),l&&(p=o(h=r[a%r.length],f)),p&&(c=!1),u(t,a,d,p)&&s(t[a],e,n.replace(\"-1\",a))(h);return c}function u(t,e,r,n){if(void 0===t[e]){if(n)return!1;t[e]=\"number\"==typeof r?[]:{}}return!0}},{\"./array\":702,\"fast-isnumeric\":225}],728:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],729:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=[];e.exports=function(t,e){if(-1===a.indexOf(t)){a.push(t);var r=1e3;i(e)?r=e:\"long\"===e&&(r=3e3);var o=n.select(\"body\").selectAll(\".plotly-notifier\").data([0]);o.enter().append(\"div\").classed(\"plotly-notifier\",!0),o.selectAll(\".notifier-note\").data(a).enter().append(\"div\").classed(\"notifier-note\",!0).style(\"opacity\",0).each(function(t){var e=n.select(this);e.append(\"button\").classed(\"notifier-close\",!0).html(\"&times;\").on(\"click\",function(){e.transition().call(s)});for(var i=e.append(\"p\"),a=t.split(/<br\\s*\\/?>/g),o=0;o<a.length;o++)o&&i.append(\"br\"),i.append(\"span\").text(a[o]);e.transition().duration(700).style(\"opacity\",1).transition().delay(r).call(s)})}function s(t){t.duration(700).style(\"opacity\",0).each(\"end\",function(t){var e=a.indexOf(t);-1!==e&&a.splice(e,1),n.select(this).remove()})}}},{d3:163,\"fast-isnumeric\":225}],730:[function(t,e,r){\"use strict\";var n=t(\"./setcursor\"),i=\"data-savedcursor\";e.exports=function(t,e){var r=t.attr(i);if(e){if(!r){for(var a=(t.attr(\"class\")||\"\").split(\" \"),o=0;o<a.length;o++){var s=a[o];0===s.indexOf(\"cursor-\")&&t.attr(i,s.substr(7)).classed(s,!1)}t.attr(i)||t.attr(i,\"!!\")}n(t,e)}else r&&(t.attr(i,null),\"!!\"===r?n(t):n(t,r))}},{\"./setcursor\":739}],731:[function(t,e,r){\"use strict\";var n=t(\"./matrix\").dot,i=t(\"../constants/numerical\").BADNUM,a=e.exports={};a.tester=function(t){var e,r=t.slice(),n=r[0][0],a=n,o=r[0][1],s=o;for(r.push(r[0]),e=1;e<r.length;e++)n=Math.min(n,r[e][0]),a=Math.max(a,r[e][0]),o=Math.min(o,r[e][1]),s=Math.max(s,r[e][1]);var l,c=!1;5===r.length&&(r[0][0]===r[1][0]?r[2][0]===r[3][0]&&r[0][1]===r[3][1]&&r[1][1]===r[2][1]&&(c=!0,l=function(t){return t[0]===r[0][0]}):r[0][1]===r[1][1]&&r[2][1]===r[3][1]&&r[0][0]===r[3][0]&&r[1][0]===r[2][0]&&(c=!0,l=function(t){return t[1]===r[0][1]}));var u=!0,h=r[0];for(e=1;e<r.length;e++)if(h[0]!==r[e][0]||h[1]!==r[e][1]){u=!1;break}return{xmin:n,xmax:a,ymin:o,ymax:s,pts:r,contains:c?function(t,e){var r=t[0],c=t[1];return!(r===i||r<n||r>a||c===i||c<o||c>s||e&&l(t))}:function(t,e){var l=t[0],c=t[1];if(l===i||l<n||l>a||c===i||c<o||c>s)return!1;var u,h,f,p,d,g=r.length,v=r[0][0],m=r[0][1],y=0;for(u=1;u<g;u++)if(h=v,f=m,v=r[u][0],m=r[u][1],!(l<(p=Math.min(h,v))||l>Math.max(h,v)||c>Math.max(f,m)))if(c<Math.min(f,m))l!==p&&y++;else{if(c===(d=v===h?c:f+(l-h)*(m-f)/(v-h)))return 1!==u||!e;c<=d&&l!==p&&y++}return y%2==1},isRect:c,degenerate:u}},a.isSegmentBent=function(t,e,r,i){var a,o,s,l=t[e],c=[t[r][0]-l[0],t[r][1]-l[1]],u=n(c,c),h=Math.sqrt(u),f=[-c[1]/h,c[0]/h];for(a=e+1;a<r;a++)if(o=[t[a][0]-l[0],t[a][1]-l[1]],(s=n(o,c))<0||s>u||Math.abs(n(o,f))>i)return!0;return!1},a.filter=function(t,e){var r=[t[0]],n=0,i=0;function o(o){t.push(o);var s=r.length,l=n;r.splice(i+1);for(var c=l+1;c<t.length;c++)(c===t.length-1||a.isSegmentBent(t,l,c+1,e))&&(r.push(t[c]),r.length<s-2&&(n=c,i=r.length-1),l=c)}t.length>1&&o(t.pop());return{addPt:o,raw:t,filtered:r}}},{\"../constants/numerical\":695,\"./matrix\":725}],732:[function(t,e,r){(function(r){\"use strict\";var n=t(\"./show_no_webgl_msg\"),i=t(\"regl\");e.exports=function(t,e){var a=t._fullLayout,o=!0;return a._glcanvas.each(function(n){if(!n.regl&&(!n.pick||a._has(\"parcoords\"))){try{n.regl=i({canvas:this,attributes:{antialias:!n.pick,preserveDrawingBuffer:!0},pixelRatio:t._context.plotGlPixelRatio||r.devicePixelRatio,extensions:e||[]})}catch(t){o=!1}o&&this.addEventListener(\"webglcontextlost\",function(e){t&&t.emit&&t.emit(\"plotly_webglcontextlost\",{event:e,layer:n.key})},!1)}}),o||n({container:a._glcontainer.node()}),o}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./show_no_webgl_msg\":740,regl:502}],733:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(e instanceof RegExp){for(var r=e.toString(),n=0;n<t.length;n++)if(t[n]instanceof RegExp&&t[n].toString()===r)return t;t.push(e)}else!e&&0!==e||-1!==t.indexOf(e)||t.push(e);return t}},{}],734:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_config\").dfltConfig;var a={add:function(t,e,r,n,a){var o,s;t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},s=t.undoQueue.index,t.autoplay?t.undoQueue.inSequence||(t.autoplay=!1):(!t.undoQueue.sequence||t.undoQueue.beginSequence?(o={undo:{calls:[],args:[]},redo:{calls:[],args:[]}},t.undoQueue.queue.splice(s,t.undoQueue.queue.length-s,o),t.undoQueue.index+=1):o=t.undoQueue.queue[s-1],t.undoQueue.beginSequence=!1,o&&(o.undo.calls.unshift(e),o.undo.args.unshift(r),o.redo.calls.push(n),o.redo.args.push(a)),t.undoQueue.queue.length>i.queueLength&&(t.undoQueue.queue.shift(),t.undoQueue.index--))},startSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!0,t.undoQueue.beginSequence=!0},stopSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!1,t.undoQueue.beginSequence=!1},undo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.undo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index<=0)){for(t.undoQueue.index--,e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.undo.calls.length;r++)a.plotDo(t,e.undo.calls[r],e.undo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1}},redo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.redo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index>=t.undoQueue.queue.length)){for(e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.redo.calls.length;r++)a.plotDo(t,e.redo.calls[r],e.redo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1,t.undoQueue.index++}}};a.plotDo=function(t,e,r){t.autoplay=!0,r=function(t,e){for(var r,i=[],a=0;a<e.length;a++)r=e[a],i[a]=r===t?r:\"object\"==typeof r?Array.isArray(r)?n.extendDeep([],r):n.extendDeepAll({},r):r;return i}(t,r),e.apply(null,r)},e.exports=a},{\"../lib\":719,\"../plot_api/plot_config\":755}],735:[function(t,e,r){\"use strict\";r.counter=function(t,e,r,n){var i=(e||\"\")+(r?\"\":\"$\"),a=!1===n?\"\":\"^\";return\"xy\"===t?new RegExp(a+\"x([2-9]|[1-9][0-9]+)?y([2-9]|[1-9][0-9]+)?\"+i):new RegExp(a+t+\"([2-9]|[1-9][0-9]+)?\"+i)}},{}],736:[function(t,e,r){\"use strict\";var n=/^(.*)(\\.[^\\.\\[\\]]+|\\[\\d\\])$/,i=/^[^\\.\\[\\]]+$/;e.exports=function(t,e){for(;e;){var r=t.match(n);if(r)t=r[1];else{if(!t.match(i))throw new Error(\"bad relativeAttr call:\"+[t,e]);t=\"\"}if(\"^\"!==e.charAt(0))break;e=e.slice(1)}return t&&\"[\"!==e.charAt(0)?t+\".\"+e:t+e}},{}],737:[function(t,e,r){\"use strict\";var n=t(\"./array\").isArrayOrTypedArray,i=t(\"./is_plain_object\");e.exports=function t(e,r){for(var a in r){var o=r[a],s=e[a];if(s!==o)if(\"_\"===a.charAt(0)||\"function\"==typeof o){if(a in e)continue;e[a]=o}else if(n(o)&&n(s)&&i(o[0])){if(\"customdata\"===a||\"ids\"===a)continue;for(var l=Math.min(o.length,s.length),c=0;c<l;c++)s[c]!==o[c]&&i(o[c])&&i(s[c])&&t(s[c],o[c])}else i(o)&&i(s)&&(t(s,o),Object.keys(s).length||delete e[a])}}},{\"./array\":702,\"./is_plain_object\":720}],738:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./loggers\"),a=t(\"./identity\");function o(t,e){return t<e}function s(t,e){return t<=e}function l(t,e){return t>e}function c(t,e){return t>=e}r.findBin=function(t,e,r){if(n(e.start))return r?Math.ceil((t-e.start)/e.size-1e-9)-1:Math.floor((t-e.start)/e.size+1e-9);var a,u,h=0,f=e.length,p=0,d=f>1?(e[f-1]-e[0])/(f-1):1;for(u=d>=0?r?o:s:r?c:l,t+=1e-9*d*(r?-1:1)*(d>=0?1:-1);h<f&&p++<100;)u(e[a=Math.floor((h+f)/2)],t)?h=a+1:f=a;return p>90&&i.log(\"Long binary search...\"),h-1},r.sorterAsc=function(t,e){return t-e},r.sorterDes=function(t,e){return e-t},r.distinctVals=function(t){var e=t.slice();e.sort(r.sorterAsc);for(var n=e.length-1,i=e[n]-e[0]||1,a=i/(n||1)/1e4,o=[e[0]],s=0;s<n;s++)e[s+1]>e[s]+a&&(i=Math.min(i,e[s+1]-e[s]),o.push(e[s+1]));return{vals:o,minDiff:i}},r.roundUp=function(t,e,r){for(var n,i=0,a=e.length-1,o=0,s=r?0:1,l=r?1:0,c=r?Math.ceil:Math.floor;i<a&&o++<100;)e[n=c((i+a)/2)]<=t?i=n+s:a=n-l;return e[i]},r.sort=function(t,e){for(var r=0,n=0,i=1;i<t.length;i++){var a=e(t[i],t[i-1]);if(a<0?r=1:a>0&&(n=1),r&&n)return t.sort(e)}return n?t:t.reverse()},r.findIndexOfMin=function(t,e){e=e||a;for(var r,n=1/0,i=0;i<t.length;i++){var o=e(t[i]);o<n&&(n=o,r=i)}return r}},{\"./identity\":718,\"./loggers\":723,\"fast-isnumeric\":225}],739:[function(t,e,r){\"use strict\";e.exports=function(t,e){(t.attr(\"class\")||\"\").split(\" \").forEach(function(e){0===e.indexOf(\"cursor-\")&&t.classed(e,!1)}),e&&t.classed(\"cursor-\"+e,!0)}},{}],740:[function(t,e,r){\"use strict\";var n=t(\"../components/color\"),i=function(){};e.exports=function(t){for(var e in t)\"function\"==typeof t[e]&&(t[e]=i);t.destroy=function(){t.container.parentNode.removeChild(t.container)};var r=document.createElement(\"div\");r.className=\"no-webgl\",r.style.cursor=\"pointer\",r.style.fontSize=\"24px\",r.style.color=n.defaults[0],r.style.position=\"absolute\",r.style.left=r.style.top=\"0px\",r.style.width=r.style.height=\"100%\",r.style[\"background-color\"]=n.lightLine,r.style[\"z-index\"]=30;var a=document.createElement(\"p\");return a.textContent=\"WebGL is not supported by your browser - visit https://get.webgl.org for more info\",a.style.position=\"relative\",a.style.top=\"50%\",a.style.left=\"50%\",a.style.height=\"30%\",a.style.width=\"50%\",a.style.margin=\"-15% 0 0 -25%\",r.appendChild(a),t.container.appendChild(r),t.container.style.background=\"#FFFFFF\",t.container.onclick=function(){window.open(\"https://get.webgl.org\")},!1}},{\"../components/color\":593}],741:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;r.aggNums=function(t,e,a,o){var s,l;if((!o||o>a.length)&&(o=a.length),n(e)||(e=!1),i(a[0])){for(l=new Array(o),s=0;s<o;s++)l[s]=r.aggNums(t,e,a[s]);a=l}for(s=0;s<o;s++)n(e)?n(a[s])&&(e=t(+e,+a[s])):e=a[s];return e},r.len=function(t){return r.aggNums(function(t){return t+1},0,t)},r.mean=function(t,e){return e||(e=r.len(t)),r.aggNums(function(t,e){return t+e},0,t)/e},r.midRange=function(t){if(void 0!==t&&0!==t.length)return(r.aggNums(Math.max,null,t)+r.aggNums(Math.min,null,t))/2},r.variance=function(t,e,i){return e||(e=r.len(t)),n(i)||(i=r.mean(t,e)),r.aggNums(function(t,e){return t+Math.pow(e-i,2)},0,t)/e},r.stdev=function(t,e,n){return Math.sqrt(r.variance(t,e,n))},r.median=function(t){var e=t.slice().sort();return r.interp(e,.5)},r.interp=function(t,e){if(!n(e))throw\"n should be a finite number\";if((e=e*t.length-.5)<0)return t[0];if(e>t.length-1)return t[t.length-1];var r=e%1;return r*t[Math.ceil(e)]+(1-r)*t[Math.floor(e)]}},{\"./array\":702,\"fast-isnumeric\":225}],742:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\");e.exports=function(t){return t?n(t):[0,0,0,1]}},{\"color-normalize\":120}],743:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=t(\"../constants/xmlns_namespaces\"),o=t(\"../constants/alignment\").LINE_SPACING;function s(t,e){return t.node().getBoundingClientRect()[e]}var l=/([^$]*)([$]+[^$]*[$]+)([^$]*)/;r.convertToTspans=function(t,e,M){var S=t.text(),C=!t.attr(\"data-notex\")&&\"undefined\"!=typeof MathJax&&S.match(l),L=n.select(t.node().parentNode);if(!L.empty()){var P=t.attr(\"class\")?t.attr(\"class\").split(\" \")[0]:\"text\";return P+=\"-math\",L.selectAll(\"svg.\"+P).remove(),L.selectAll(\"g.\"+P+\"-group\").remove(),t.style(\"display\",null).attr({\"data-unformatted\":S,\"data-math\":\"N\"}),C?(e&&e._promises||[]).push(new Promise(function(e){t.style(\"display\",\"none\");var r=parseInt(t.node().style.fontSize,10),a={fontSize:r};!function(t,e,r){var a,o,s,l;MathJax.Hub.Queue(function(){return o=i.extendDeepAll({},MathJax.Hub.config),s=MathJax.Hub.processSectionDelay,void 0!==MathJax.Hub.processSectionDelay&&(MathJax.Hub.processSectionDelay=0),MathJax.Hub.Config({messageStyle:\"none\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]},displayAlign:\"left\"})},function(){if(\"SVG\"!==(a=MathJax.Hub.config.menuSettings.renderer))return MathJax.Hub.setRenderer(\"SVG\")},function(){var r=\"math-output-\"+i.randstr({},64);return l=n.select(\"body\").append(\"div\").attr({id:r}).style({visibility:\"hidden\",position:\"absolute\"}).style({\"font-size\":e.fontSize+\"px\"}).text(t.replace(c,\"\\\\lt \").replace(u,\"\\\\gt \")),MathJax.Hub.Typeset(l.node())},function(){var e=n.select(\"body\").select(\"#MathJax_SVG_glyphs\");if(l.select(\".MathJax_SVG\").empty()||!l.select(\"svg\").node())i.log(\"There was an error in the tex syntax.\",t),r();else{var o=l.select(\"svg\").node().getBoundingClientRect();r(l.select(\".MathJax_SVG\"),e,o)}if(l.remove(),\"SVG\"!==a)return MathJax.Hub.setRenderer(a)},function(){return void 0!==s&&(MathJax.Hub.processSectionDelay=s),MathJax.Hub.Config(o)})}(C[2],a,function(n,i,a){L.selectAll(\"svg.\"+P).remove(),L.selectAll(\"g.\"+P+\"-group\").remove();var o=n&&n.select(\"svg\");if(!o||!o.node())return O(),void e();var l=L.append(\"g\").classed(P+\"-group\",!0).attr({\"pointer-events\":\"none\",\"data-unformatted\":S,\"data-math\":\"Y\"});l.node().appendChild(o.node()),i&&i.node()&&o.node().insertBefore(i.node().cloneNode(!0),o.node().firstChild),o.attr({class:P,height:a.height,preserveAspectRatio:\"xMinYMin meet\"}).style({overflow:\"visible\",\"pointer-events\":\"none\"});var c=t.node().style.fill||\"black\",u=o.select(\"g\");u.attr({fill:c,stroke:c});var h=s(u,\"width\"),f=s(u,\"height\"),p=+t.attr(\"x\")-h*{start:0,middle:.5,end:1}[t.attr(\"text-anchor\")||\"start\"],d=-(r||s(t,\"height\"))/4;\"y\"===P[0]?(l.attr({transform:\"rotate(\"+[-90,+t.attr(\"x\"),+t.attr(\"y\")]+\") translate(\"+[-h/2,d-f/2]+\")\"}),o.attr({x:+t.attr(\"x\"),y:+t.attr(\"y\")})):\"l\"===P[0]?o.attr({x:t.attr(\"x\"),y:d-f/2}):\"a\"===P[0]&&0!==P.indexOf(\"atitle\")?o.attr({x:0,y:d}):o.attr({x:p,y:+t.attr(\"y\")+d-f/2}),M&&M.call(t,l),e(l)})})):O(),t}function O(){L.empty()||(P=t.attr(\"class\")+\"-math\",L.select(\"svg.\"+P).remove()),t.text(\"\").style(\"white-space\",\"pre\"),function(t,e){e=e.replace(v,\" \");var r,s=!1,l=[],c=-1;function u(){c++;var e=document.createElementNS(a.svg,\"tspan\");n.select(e).attr({class:\"line\",dy:c*o+\"em\"}),t.appendChild(e),r=e;var i=l;if(l=[{node:e}],i.length>1)for(var s=1;s<i.length;s++)M(i[s])}function M(t){var e,i=t.type,o={};if(\"a\"===i){e=\"a\";var s=t.target,c=t.href,u=t.popup;c&&(o={\"xlink:xlink:show\":\"_blank\"===s||\"_\"!==s.charAt(0)?\"new\":\"replace\",target:s,\"xlink:xlink:href\":c},u&&(o.onclick='window.open(this.href.baseVal,this.target.baseVal,\"'+u+'\");return false;'))}else e=\"tspan\";t.style&&(o.style=t.style);var h=document.createElementNS(a.svg,e);if(\"sup\"===i||\"sub\"===i){S(r,d),r.appendChild(h);var g=document.createElementNS(a.svg,\"tspan\");S(g,d),n.select(g).attr(\"dy\",p[i]),o.dy=f[i],r.appendChild(h),r.appendChild(g)}else r.appendChild(h);n.select(h).attr(o),r=t.node=h,l.push(t)}function S(t,e){t.appendChild(document.createTextNode(e))}function C(t){if(1!==l.length){var n=l.pop();t!==n.type&&i.log(\"Start tag <\"+n.type+\"> doesnt match end tag <\"+t+\">. Pretending it did match.\",e),r=l[l.length-1].node}else i.log(\"Ignoring unexpected end tag </\"+t+\">.\",e)}x.test(e)?u():(r=t,l=[{node:t}]);for(var L=e.split(m),P=0;P<L.length;P++){var O=L[P],z=O.match(y),I=z&&z[2].toLowerCase(),D=h[I];if(\"br\"===I)u();else if(void 0===D)S(r,E(O));else if(z[1])C(I);else{var R=z[4],F={type:I},B=T(R,b);if(B?(B=B.replace(A,\"$1 fill:\"),D&&(B+=\";\"+D)):D&&(B=D),B&&(F.style=B),\"a\"===I){s=!0;var N=T(R,_);if(N){var j=document.createElement(\"a\");j.href=N,-1!==g.indexOf(j.protocol)&&(F.href=encodeURI(decodeURI(N)),F.target=T(R,w)||\"_blank\",F.popup=T(R,k))}}M(F)}}return s}(t.node(),S)&&t.style(\"pointer-events\",\"all\"),r.positionText(t),M&&M.call(t)}};var c=/(<|&lt;|&#60;)/g,u=/(>|&gt;|&#62;)/g;var h={sup:\"font-size:70%\",sub:\"font-size:70%\",b:\"font-weight:bold\",i:\"font-style:italic\",a:\"cursor:pointer\",span:\"\",em:\"font-style:italic;font-weight:bold\"},f={sub:\"0.3em\",sup:\"-0.6em\"},p={sub:\"-0.21em\",sup:\"0.42em\"},d=\"\\u200b\",g=[\"http:\",\"https:\",\"mailto:\",\"\",void 0,\":\"],v=/(\\r\\n?|\\n)/g,m=/(<[^<>]*>)/,y=/<(\\/?)([^ >]*)(\\s+(.*))?>/i,x=/<br(\\s+.*)?>/i,b=/(^|[\\s\"'])style\\s*=\\s*(\"([^\"]*);?\"|'([^']*);?')/i,_=/(^|[\\s\"'])href\\s*=\\s*(\"([^\"]*)\"|'([^']*)')/i,w=/(^|[\\s\"'])target\\s*=\\s*(\"([^\"\\s]*)\"|'([^'\\s]*)')/i,k=/(^|[\\s\"'])popup\\s*=\\s*(\"([\\w=,]*)\"|'([\\w=,]*)')/i;function T(t,e){if(!t)return null;var r=t.match(e),n=r&&(r[3]||r[4]);return n&&E(n)}var A=/(^|;)\\s*color:/;r.plainText=function(t,e){for(var r=void 0!==(e=e||{}).len&&-1!==e.len?e.len:1/0,n=void 0!==e.allowedTags?e.allowedTags:[\"br\"],i=\"...\".length,a=t.split(m),o=[],s=\"\",l=0,c=0;c<a.length;c++){var u=a[c],h=u.match(y),f=h&&h[2].toLowerCase();if(f)-1!==n.indexOf(f)&&(o.push(u),s=f);else{var p=u.length;if(l+p<r)o.push(u),l+=p;else if(l<r){var d=r-l;s&&(\"br\"!==s||d<=i||p<=i)&&o.pop(),r>i?o.push(u.substr(0,d-i)+\"...\"):o.push(u.substr(0,d));break}s=\"\"}}return o.join(\"\")};var M={mu:\"\\u03bc\",amp:\"&\",lt:\"<\",gt:\">\",nbsp:\"\\xa0\",times:\"\\xd7\",plusmn:\"\\xb1\",deg:\"\\xb0\"},S=/&(#\\d+|#x[\\da-fA-F]+|[a-z]+);/g;function E(t){return t.replace(S,function(t,e){return(\"#\"===e.charAt(0)?function(t){if(t>1114111)return;var e=String.fromCodePoint;if(e)return e(t);var r=String.fromCharCode;return t<=65535?r(t):r(55232+(t>>10),t%1024+56320)}(\"x\"===e.charAt(1)?parseInt(e.substr(2),16):parseInt(e.substr(1),10)):M[e])||t})}function C(t,e,r){var n,i,a,o=r.horizontalAlign,s=r.verticalAlign||\"top\",l=t.node().getBoundingClientRect(),c=e.node().getBoundingClientRect();return i=\"bottom\"===s?function(){return l.bottom-n.height}:\"middle\"===s?function(){return l.top+(l.height-n.height)/2}:function(){return l.top},a=\"right\"===o?function(){return l.right-n.width}:\"center\"===o?function(){return l.left+(l.width-n.width)/2}:function(){return l.left},function(){return n=this.node().getBoundingClientRect(),this.style({top:i()-c.top+\"px\",left:a()-c.left+\"px\",\"z-index\":1e3}),this}}r.convertEntities=E,r.lineCount=function(t){return t.selectAll(\"tspan.line\").size()||1},r.positionText=function(t,e,r){return t.each(function(){var t=n.select(this);function i(e,r){return void 0===r?null===(r=t.attr(e))&&(t.attr(e,0),r=0):t.attr(e,r),r}var a=i(\"x\",e),o=i(\"y\",r);\"text\"===this.nodeName&&t.selectAll(\"tspan.line\").attr({x:a,y:o})})},r.makeEditable=function(t,e){var r=e.gd,i=e.delegate,a=n.dispatch(\"edit\",\"input\",\"cancel\"),o=i||t;if(t.style({\"pointer-events\":i?\"none\":\"all\"}),1!==t.size())throw new Error(\"boo\");function s(){!function(){var i=n.select(r).select(\".svg-container\"),o=i.append(\"div\"),s=t.node().style,c=parseFloat(s.fontSize||12),u=e.text;void 0===u&&(u=t.attr(\"data-unformatted\"));o.classed(\"plugin-editable editable\",!0).style({position:\"absolute\",\"font-family\":s.fontFamily||\"Arial\",\"font-size\":c,color:e.fill||s.fill||\"black\",opacity:1,\"background-color\":e.background||\"transparent\",outline:\"#ffffff33 1px solid\",margin:[-c/8+1,0,0,-1].join(\"px \")+\"px\",padding:\"0\",\"box-sizing\":\"border-box\"}).attr({contenteditable:!0}).text(u).call(C(t,i,e)).on(\"blur\",function(){r._editing=!1,t.text(this.textContent).style({opacity:1});var e,i=n.select(this).attr(\"class\");(e=i?\".\"+i.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(e).style({opacity:0});var o=this.textContent;n.select(this).transition().duration(0).remove(),n.select(document).on(\"mouseup\",null),a.edit.call(t,o)}).on(\"focus\",function(){var t=this;r._editing=!0,n.select(document).on(\"mouseup\",function(){if(n.event.target===t)return!1;document.activeElement===o.node()&&o.node().blur()})}).on(\"keyup\",function(){27===n.event.which?(r._editing=!1,t.style({opacity:1}),n.select(this).style({opacity:0}).on(\"blur\",function(){return!1}).transition().remove(),a.cancel.call(t,this.textContent)):(a.input.call(t,this.textContent),n.select(this).call(C(t,i,e)))}).on(\"keydown\",function(){13===n.event.which&&this.blur()}).call(l)}(),t.style({opacity:0});var i,s=o.attr(\"class\");(i=s?\".\"+s.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(i).style({opacity:0})}function l(t){var e=t.node(),r=document.createRange();r.selectNodeContents(e);var n=window.getSelection();n.removeAllRanges(),n.addRange(r),e.focus()}return e.immediate?s():o.on(\"click\",s),n.rebind(t,a,\"on\")}},{\"../constants/alignment\":688,\"../constants/xmlns_namespaces\":696,\"../lib\":719,d3:163}],744:[function(t,e,r){\"use strict\";var n={};function i(t){t&&null!==t.timer&&(clearTimeout(t.timer),t.timer=null)}r.throttle=function(t,e,r){var a=n[t],o=Date.now();if(!a){for(var s in n)n[s].ts<o-6e4&&delete n[s];a=n[t]={ts:0,timer:null}}function l(){r(),a.ts=Date.now(),a.onDone&&(a.onDone(),a.onDone=null)}i(a),o>a.ts+e?l():a.timer=setTimeout(function(){l(),a.timer=null},e)},r.done=function(t){var e=n[t];return e&&e.timer?new Promise(function(t){var r=e.onDone;e.onDone=function(){r&&r(),t(),e.onDone=null}}):Promise.resolve()},r.clear=function(t){if(t)i(n[t]),delete n[t];else for(var e in n)r.clear(e)}},{}],745:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t,e){if(t>0)return Math.log(t)/Math.LN10;var r=Math.log(Math.min(e[0],e[1]))/Math.LN10;return n(r)||(r=Math.log(Math.max(e[0],e[1]))/Math.LN10-6),r}},{\"fast-isnumeric\":225}],746:[function(t,e,r){\"use strict\";var n=e.exports={},i=t(\"../plots/geo/constants\").locationmodeToLayer,a=t(\"topojson-client\").feature;n.getTopojsonName=function(t){return[t.scope.replace(/ /g,\"-\"),\"_\",t.resolution.toString(),\"m\"].join(\"\")},n.getTopojsonPath=function(t,e){return t+e+\".json\"},n.getTopojsonFeatures=function(t,e){var r=i[t.locationmode],n=e.objects[r];return a(e,n).features}},{\"../plots/geo/constants\":795,\"topojson-client\":540}],747:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en-US\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colorscale title\"},format:{date:\"%m/%d/%Y\"}}},{}],748:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colourscale title\"},format:{days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],periods:[\"AM\",\"PM\"],dateTime:\"%a %b %e %X %Y\",date:\"%d/%m/%Y\",time:\"%H:%M:%S\",decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],year:\"%Y\",month:\"%b %Y\",dayMonth:\"%b %-d\",dayMonthYear:\"%b %-d, %Y\"}}},{}],749:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t){for(var e,r,i=n.layoutArrayContainers,a=n.layoutArrayRegexes,o=t.split(\"[\")[0],s=0;s<a.length;s++)if((r=t.match(a[s]))&&0===r.index){e=r[0];break}if(e||(e=i[i.indexOf(o)]),!e)return!1;var l=t.substr(e.length);return l?!!(r=l.match(/^\\[(0|[1-9][0-9]*)\\](\\.(.+))?$/))&&{array:e,index:Number(r[1]),property:r[3]||\"\"}:{array:e,index:\"\",property:\"\"}}},{\"../registry\":847}],750:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.extendFlat,a=n.isPlainObject,o={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"clearAxisTypes\",\"plot\",\"style\",\"markerSize\",\"colorbars\"]},s={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"plot\",\"legend\",\"ticks\",\"axrange\",\"layoutstyle\",\"modebar\",\"camera\",\"arraydraw\",\"colorbars\"]},l=o.flags.slice().concat([\"fullReplot\"]),c=s.flags.slice().concat(\"layoutReplot\");function u(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=!1;return e}function h(t,e,r){var n=i({},t);for(var o in n){var s=n[o];a(s)&&(n[o]=f(s,e,r,o))}return\"from-root\"===r&&(n.editType=e),n}function f(t,e,r,n){if(t.valType){var a=i({},t);if(a.editType=e,Array.isArray(t.items)){a.items=new Array(t.items.length);for(var o=0;o<t.items.length;o++)a.items[o]=f(t.items[o],e,\"from-root\")}return a}return h(t,e,\"_\"===n.charAt(0)?\"nested\":\"from-root\")}e.exports={traces:o,layout:s,traceFlags:function(){return u(l)},layoutFlags:function(){return u(c)},update:function(t,e){var r=e.editType;if(r&&\"none\"!==r)for(var n=r.split(\"+\"),i=0;i<n.length;i++)t[n[i]]=!0},overrideAll:h}},{\"../lib\":719}],751:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"gl-mat4/fromQuat\"),a=t(\"../registry\"),o=t(\"../lib\"),s=t(\"../plots/plots\"),l=t(\"../plots/cartesian/axis_ids\"),c=t(\"../components/color\"),u=l.cleanId,h=l.getFromTrace,f=a.traceIs;function p(t,e){var r=t[e],n=e.charAt(0);r&&\"paper\"!==r&&(t[e]=u(r,n))}function d(t){function e(e,r){var n=t[e],i=t.title&&t.title[r];n&&!i&&(t.title||(t.title={}),t.title[r]=t[e],delete t[e])}t&&(\"string\"!=typeof t.title&&\"number\"!=typeof t.title||(t.title={text:t.title}),e(\"titlefont\",\"font\"),e(\"titleposition\",\"position\"),e(\"titleside\",\"side\"),e(\"titleoffset\",\"offset\"))}function g(t){if(!o.isPlainObject(t))return!1;var e=t.name;return delete t.name,delete t.showlegend,(\"string\"==typeof e||\"number\"==typeof e)&&String(e)}function v(t,e,r,n){if(r&&!n)return t;if(n&&!r)return e;if(!t.trim())return e;if(!e.trim())return t;var i,a=Math.min(t.length,e.length);for(i=0;i<a&&t.charAt(i)===e.charAt(i);i++);return t.substr(0,i).trim()}function m(t){var e=\"middle\",r=\"center\";return\"string\"==typeof t&&(-1!==t.indexOf(\"top\")?e=\"top\":-1!==t.indexOf(\"bottom\")&&(e=\"bottom\"),-1!==t.indexOf(\"left\")?r=\"left\":-1!==t.indexOf(\"right\")&&(r=\"right\")),e+\" \"+r}function y(t,e){return e in t&&\"object\"==typeof t[e]&&0===Object.keys(t[e]).length}r.clearPromiseQueue=function(t){Array.isArray(t._promises)&&t._promises.length>0&&o.log(\"Clearing previous rejected promises from queue.\"),t._promises=[]},r.cleanLayout=function(t){var e,n;t||(t={}),t.xaxis1&&(t.xaxis||(t.xaxis=t.xaxis1),delete t.xaxis1),t.yaxis1&&(t.yaxis||(t.yaxis=t.yaxis1),delete t.yaxis1),t.scene1&&(t.scene||(t.scene=t.scene1),delete t.scene1);var a=(s.subplotsRegistry.cartesian||{}).attrRegex,l=(s.subplotsRegistry.polar||{}).attrRegex,h=(s.subplotsRegistry.ternary||{}).attrRegex,f=(s.subplotsRegistry.gl3d||{}).attrRegex,g=Object.keys(t);for(e=0;e<g.length;e++){var v=g[e];if(a&&a.test(v)){var m=t[v];m.anchor&&\"free\"!==m.anchor&&(m.anchor=u(m.anchor)),m.overlaying&&(m.overlaying=u(m.overlaying)),m.type||(m.isdate?m.type=\"date\":m.islog?m.type=\"log\":!1===m.isdate&&!1===m.islog&&(m.type=\"linear\")),\"withzero\"!==m.autorange&&\"tozero\"!==m.autorange||(m.autorange=!0,m.rangemode=\"tozero\"),delete m.islog,delete m.isdate,delete m.categories,y(m,\"domain\")&&delete m.domain,void 0!==m.autotick&&(void 0===m.tickmode&&(m.tickmode=m.autotick?\"auto\":\"linear\"),delete m.autotick),d(m)}else if(l&&l.test(v)){d(t[v].radialaxis)}else if(h&&h.test(v)){var x=t[v];d(x.aaxis),d(x.baxis),d(x.caxis)}else if(f&&f.test(v)){var b=t[v],_=b.cameraposition;if(Array.isArray(_)&&4===_[0].length){var w=_[0],k=_[1],T=_[2],A=i([],w),M=[];for(n=0;n<3;++n)M[n]=k[n]+T*A[2+4*n];b.camera={eye:{x:M[0],y:M[1],z:M[2]},center:{x:k[0],y:k[1],z:k[2]},up:{x:0,y:0,z:1}},delete b.cameraposition}d(b.xaxis),d(b.yaxis),d(b.zaxis)}}var S=Array.isArray(t.annotations)?t.annotations.length:0;for(e=0;e<S;e++){var E=t.annotations[e];o.isPlainObject(E)&&(E.ref&&(\"paper\"===E.ref?(E.xref=\"paper\",E.yref=\"paper\"):\"data\"===E.ref&&(E.xref=\"x\",E.yref=\"y\"),delete E.ref),p(E,\"xref\"),p(E,\"yref\"))}var C=Array.isArray(t.shapes)?t.shapes.length:0;for(e=0;e<C;e++){var L=t.shapes[e];o.isPlainObject(L)&&(p(L,\"xref\"),p(L,\"yref\"))}var P=t.legend;return P&&(P.x>3?(P.x=1.02,P.xanchor=\"left\"):P.x<-2&&(P.x=-.02,P.xanchor=\"right\"),P.y>3?(P.y=1.02,P.yanchor=\"bottom\"):P.y<-2&&(P.y=-.02,P.yanchor=\"top\")),d(t),\"rotate\"===t.dragmode&&(t.dragmode=\"orbit\"),c.clean(t),t.template&&t.template.layout&&r.cleanLayout(t.template.layout),t},r.cleanData=function(t){for(var e=0;e<t.length;e++){var n,i=t[e];if(\"histogramy\"===i.type&&\"xbins\"in i&&!(\"ybins\"in i)&&(i.ybins=i.xbins,delete i.xbins),i.error_y&&\"opacity\"in i.error_y){var l=c.defaults,h=i.error_y.color||(f(i,\"bar\")?c.defaultLine:l[e%l.length]);i.error_y.color=c.addOpacity(c.rgb(h),c.opacity(h)*i.error_y.opacity),delete i.error_y.opacity}if(\"bardir\"in i&&(\"h\"!==i.bardir||!f(i,\"bar\")&&\"histogram\"!==i.type.substr(0,9)||(i.orientation=\"h\",r.swapXYData(i)),delete i.bardir),\"histogramy\"===i.type&&r.swapXYData(i),\"histogramx\"!==i.type&&\"histogramy\"!==i.type||(i.type=\"histogram\"),\"scl\"in i&&!(\"colorscale\"in i)&&(i.colorscale=i.scl,delete i.scl),\"reversescl\"in i&&!(\"reversescale\"in i)&&(i.reversescale=i.reversescl,delete i.reversescl),i.xaxis&&(i.xaxis=u(i.xaxis,\"x\")),i.yaxis&&(i.yaxis=u(i.yaxis,\"y\")),f(i,\"gl3d\")&&i.scene&&(i.scene=s.subplotsRegistry.gl3d.cleanId(i.scene)),!f(i,\"pie-like\")&&!f(i,\"bar-like\"))if(Array.isArray(i.textposition))for(n=0;n<i.textposition.length;n++)i.textposition[n]=m(i.textposition[n]);else i.textposition&&(i.textposition=m(i.textposition));var p=a.getModule(i);if(p&&p.colorbar){var x=p.colorbar.container,b=x?i[x]:i;b&&b.colorscale&&(\"YIGnBu\"===b.colorscale&&(b.colorscale=\"YlGnBu\"),\"YIOrRd\"===b.colorscale&&(b.colorscale=\"YlOrRd\"))}if(\"surface\"===i.type&&o.isPlainObject(i.contours)){var _=[\"x\",\"y\",\"z\"];for(n=0;n<_.length;n++){var w=i.contours[_[n]];o.isPlainObject(w)&&(w.highlightColor&&(w.highlightcolor=w.highlightColor,delete w.highlightColor),w.highlightWidth&&(w.highlightwidth=w.highlightWidth,delete w.highlightWidth))}}if(\"candlestick\"===i.type||\"ohlc\"===i.type){var k=!1!==(i.increasing||{}).showlegend,T=!1!==(i.decreasing||{}).showlegend,A=g(i.increasing),M=g(i.decreasing);if(!1!==A&&!1!==M){var S=v(A,M,k,T);S&&(i.name=S)}else!A&&!M||i.name||(i.name=A||M)}if(Array.isArray(i.transforms)){var E=i.transforms;for(n=0;n<E.length;n++){var C=E[n];if(o.isPlainObject(C))switch(C.type){case\"filter\":C.filtersrc&&(C.target=C.filtersrc,delete C.filtersrc),C.calendar&&(C.valuecalendar||(C.valuecalendar=C.calendar),delete C.calendar);break;case\"groupby\":if(C.styles=C.styles||C.style,C.styles&&!Array.isArray(C.styles)){var L=C.styles,P=Object.keys(L);C.styles=[];for(var O=0;O<P.length;O++)C.styles.push({target:P[O],value:L[P[O]]})}}}}y(i,\"line\")&&delete i.line,\"marker\"in i&&(y(i.marker,\"line\")&&delete i.marker.line,y(i,\"marker\")&&delete i.marker),c.clean(i),i.autobinx&&(delete i.autobinx,delete i.xbins),i.autobiny&&(delete i.autobiny,delete i.ybins),d(i),i.colorbar&&d(i.colorbar),i.marker&&i.marker.colorbar&&d(i.marker.colorbar),i.line&&i.line.colorbar&&d(i.line.colorbar),i.aaxis&&d(i.aaxis),i.baxis&&d(i.baxis)}},r.swapXYData=function(t){var e;if(o.swapAttrs(t,[\"?\",\"?0\",\"d?\",\"?bins\",\"nbins?\",\"autobin?\",\"?src\",\"error_?\"]),Array.isArray(t.z)&&Array.isArray(t.z[0])&&(t.transpose?delete t.transpose:t.transpose=!0),t.error_x&&t.error_y){var r=t.error_y,n=\"copy_ystyle\"in r?r.copy_ystyle:!(r.color||r.thickness||r.width);o.swapAttrs(t,[\"error_?.copy_ystyle\"]),n&&o.swapAttrs(t,[\"error_?.color\",\"error_?.thickness\",\"error_?.width\"])}if(\"string\"==typeof t.hoverinfo){var i=t.hoverinfo.split(\"+\");for(e=0;e<i.length;e++)\"x\"===i[e]?i[e]=\"y\":\"y\"===i[e]&&(i[e]=\"x\");t.hoverinfo=i.join(\"+\")}},r.coerceTraceIndices=function(t,e){if(n(e))return[e];if(!Array.isArray(e)||!e.length)return t.data.map(function(t,e){return e});if(Array.isArray(e)){for(var r=[],i=0;i<e.length;i++)o.isIndex(e[i],t.data.length)?r.push(e[i]):o.warn(\"trace index (\",e[i],\") is not a number or is out of bounds\");return r}return e},r.manageArrayContainers=function(t,e,r){var i=t.obj,a=t.parts,s=a.length,l=a[s-1],c=n(l);if(c&&null===e){var u=a.slice(0,s-1).join(\".\");o.nestedProperty(i,u).get().splice(l,1)}else c&&void 0===t.get()?(void 0===t.get()&&(r[t.astr]=null),t.set(e)):t.set(e)};var x=/(\\.[^\\[\\]\\.]+|\\[[^\\[\\]\\.]+\\])$/;function b(t){var e=t.search(x);if(e>0)return t.substr(0,e)}r.hasParent=function(t,e){for(var r=b(e);r;){if(r in t)return!0;r=b(r)}return!1};var _=[\"x\",\"y\",\"z\"];r.clearAxisTypes=function(t,e,r){for(var n=0;n<e.length;n++)for(var i=t._fullData[n],a=0;a<3;a++){var s=h(t,i,_[a]);if(s&&\"log\"!==s.type){var l=s._name,c=s._id.substr(1);if(\"scene\"===c.substr(0,5)){if(void 0!==r[c])continue;l=c+\".\"+l}var u=l+\".type\";void 0===r[l]&&void 0===r[u]&&o.nestedProperty(t.layout,u).set(null)}}}},{\"../components/color\":593,\"../lib\":719,\"../plots/cartesian/axis_ids\":770,\"../plots/plots\":828,\"../registry\":847,\"fast-isnumeric\":225,\"gl-mat4/fromQuat\":262}],752:[function(t,e,r){\"use strict\";var n=t(\"./plot_api\");r.plot=n.plot,r.newPlot=n.newPlot,r.restyle=n.restyle,r.relayout=n.relayout,r.redraw=n.redraw,r.update=n.update,r._guiRestyle=n._guiRestyle,r._guiRelayout=n._guiRelayout,r._guiUpdate=n._guiUpdate,r._storeDirectGUIEdit=n._storeDirectGUIEdit,r.react=n.react,r.extendTraces=n.extendTraces,r.prependTraces=n.prependTraces,r.addTraces=n.addTraces,r.deleteTraces=n.deleteTraces,r.moveTraces=n.moveTraces,r.purge=n.purge,r.addFrames=n.addFrames,r.deleteFrames=n.deleteFrames,r.animate=n.animate,r.setPlotConfig=n.setPlotConfig,r.toImage=t(\"./to_image\"),r.validate=t(\"./validate\"),r.downloadImage=t(\"../snapshot/download\");var i=t(\"./template_api\");r.makeTemplate=i.makeTemplate,r.validateTemplate=i.validateTemplate},{\"../snapshot/download\":849,\"./plot_api\":754,\"./template_api\":759,\"./to_image\":760,\"./validate\":761}],753:[function(t,e,r){\"use strict\";var n=t(\"../lib/is_plain_object\"),i=t(\"../lib/noop\"),a=t(\"../lib/loggers\"),o=t(\"../lib/search\").sorterAsc,s=t(\"../registry\");r.containerArrayMatch=t(\"./container_array_match\");var l=r.isAddVal=function(t){return\"add\"===t||n(t)},c=r.isRemoveVal=function(t){return null===t||\"remove\"===t};r.applyContainerArrayChanges=function(t,e,r,n,u){var h=e.astr,f=s.getComponentMethod(h,\"supplyLayoutDefaults\"),p=s.getComponentMethod(h,\"draw\"),d=s.getComponentMethod(h,\"drawOne\"),g=n.replot||n.recalc||f===i||p===i,v=t.layout,m=t._fullLayout;if(r[\"\"]){Object.keys(r).length>1&&a.warn(\"Full array edits are incompatible with other edits\",h);var y=r[\"\"][\"\"];if(c(y))e.set(null);else{if(!Array.isArray(y))return a.warn(\"Unrecognized full array edit value\",h,y),!0;e.set(y)}return!g&&(f(v,m),p(t),!0)}var x,b,_,w,k,T,A,M,S=Object.keys(r).map(Number).sort(o),E=e.get(),C=E||[],L=u(m,h).get(),P=[],O=-1,z=C.length;for(x=0;x<S.length;x++)if(w=r[_=S[x]],k=Object.keys(w),T=w[\"\"],A=l(T),_<0||_>C.length-(A?0:1))a.warn(\"index out of range\",h,_);else if(void 0!==T)k.length>1&&a.warn(\"Insertion & removal are incompatible with edits to the same index.\",h,_),c(T)?P.push(_):A?(\"add\"===T&&(T={}),C.splice(_,0,T),L&&L.splice(_,0,{})):a.warn(\"Unrecognized full object edit value\",h,_,T),-1===O&&(O=_);else for(b=0;b<k.length;b++)M=h+\"[\"+_+\"].\",u(C[_],k[b],M).set(w[k[b]]);for(x=P.length-1;x>=0;x--)C.splice(P[x],1),L&&L.splice(P[x],1);if(C.length?E||e.set(C):e.set(null),g)return!1;if(f(v,m),d!==i){var I;if(-1===O)I=S;else{for(z=Math.max(C.length,z),I=[],x=0;x<S.length&&!((_=S[x])>=O);x++)I.push(_);for(x=O;x<z;x++)I.push(x)}for(x=0;x<I.length;x++)d(t,I[x])}else p(t);return!0}},{\"../lib/is_plain_object\":720,\"../lib/loggers\":723,\"../lib/noop\":728,\"../lib/search\":738,\"../registry\":847,\"./container_array_match\":749}],754:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"has-hover\"),o=t(\"../lib\"),s=o.nestedProperty,l=t(\"../lib/events\"),c=t(\"../lib/queue\"),u=t(\"../registry\"),h=t(\"./plot_schema\"),f=t(\"../plots/plots\"),p=t(\"../plots/polar/legacy\"),d=t(\"../plots/cartesian/axes\"),g=t(\"../components/drawing\"),v=t(\"../components/color\"),m=t(\"../plots/cartesian/graph_interact\").initInteractions,y=t(\"../constants/xmlns_namespaces\"),x=t(\"../lib/svg_text_utils\"),b=t(\"../plots/cartesian/select\").clearSelect,_=t(\"./plot_config\").dfltConfig,w=t(\"./manage_arrays\"),k=t(\"./helpers\"),T=t(\"./subroutines\"),A=t(\"./edit_types\"),M=t(\"../plots/cartesian/constants\").AX_NAME_PATTERN,S=0,E=5;function C(t){var e=t._fullLayout;e._redrawFromAutoMarginCount?e._redrawFromAutoMarginCount--:t.emit(\"plotly_afterplot\")}function L(t,e){try{t._fullLayout._paper.style(\"background\",e)}catch(t){o.error(t)}}function P(t,e){L(t,v.combine(e,\"white\"))}function O(t,e){if(!t._context){t._context=o.extendDeep({},_);var r=n.select(\"base\");t._context._baseUrl=r.size()&&r.attr(\"href\")?window.location.href.split(\"#\")[0]:\"\"}var i,s,l,c=t._context;if(e){for(s=Object.keys(e),i=0;i<s.length;i++)\"editable\"!==(l=s[i])&&\"edits\"!==l&&l in c&&(\"setBackground\"===l&&\"opaque\"===e[l]?c[l]=P:c[l]=e[l]);e.plot3dPixelRatio&&!c.plotGlPixelRatio&&(c.plotGlPixelRatio=c.plot3dPixelRatio);var u=e.editable;if(void 0!==u)for(c.editable=u,s=Object.keys(c.edits),i=0;i<s.length;i++)c.edits[s[i]]=u;if(e.edits)for(s=Object.keys(e.edits),i=0;i<s.length;i++)(l=s[i])in c.edits&&(c.edits[l]=e.edits[l]);c._exportedPlot=e._exportedPlot}c.staticPlot&&(c.editable=!1,c.edits={},c.autosizable=!1,c.scrollZoom=!1,c.doubleClick=!1,c.showTips=!1,c.showLink=!1,c.displayModeBar=!1),\"hover\"!==c.displayModeBar||a||(c.displayModeBar=!0),\"transparent\"!==c.setBackground&&\"function\"==typeof c.setBackground||(c.setBackground=L),c._hasZeroHeight=c._hasZeroHeight||0===t.clientHeight,c._hasZeroWidth=c._hasZeroWidth||0===t.clientWidth;var h=c.scrollZoom,f=c._scrollZoom={};if(!0===h)f.cartesian=1,f.gl3d=1,f.geo=1,f.mapbox=1;else if(\"string\"==typeof h){var p=h.split(\"+\");for(i=0;i<p.length;i++)f[p[i]]=1}else!1!==h&&(f.gl3d=1,f.geo=1,f.mapbox=1)}function z(t,e){var r,n,i=e+1,a=[];for(r=0;r<t.length;r++)(n=t[r])<0?a.push(i+n):a.push(n);return a}function I(t,e,r){var n,i;for(n=0;n<e.length;n++){if((i=e[n])!==parseInt(i,10))throw new Error(\"all values in \"+r+\" must be integers\");if(i>=t.data.length||i<-t.data.length)throw new Error(r+\" must be valid indices for gd.data.\");if(e.indexOf(i,n+1)>-1||i>=0&&e.indexOf(-t.data.length+i)>-1||i<0&&e.indexOf(t.data.length+i)>-1)throw new Error(\"each index in \"+r+\" must be unique.\")}}function D(t,e,r){if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"currentIndices is a required argument.\");if(Array.isArray(e)||(e=[e]),I(t,e,\"currentIndices\"),\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&I(t,r,\"newIndices\"),\"undefined\"!=typeof r&&e.length!==r.length)throw new Error(\"current and new indices must be of equal length.\")}function R(t,e,r,n,a){!function(t,e,r,n){var i=o.isPlainObject(n);if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array\");if(!o.isPlainObject(e))throw new Error(\"update must be a key:value object\");if(\"undefined\"==typeof r)throw new Error(\"indices must be an integer or array of integers\");for(var a in I(t,r,\"indices\"),e){if(!Array.isArray(e[a])||e[a].length!==r.length)throw new Error(\"attribute \"+a+\" must be an array of length equal to indices array length\");if(i&&(!(a in n)||!Array.isArray(n[a])||n[a].length!==e[a].length))throw new Error(\"when maxPoints is set as a key:value object it must contain a 1:1 corrispondence with the keys and number of traces in the update object\")}}(t,e,r,n);for(var l=function(t,e,r,n){var a,l,c,u,h,f=o.isPlainObject(n),p=[];for(var d in Array.isArray(r)||(r=[r]),r=z(r,t.data.length-1),e)for(var g=0;g<r.length;g++){if(a=t.data[r[g]],l=(c=s(a,d)).get(),u=e[d][g],!o.isArrayOrTypedArray(u))throw new Error(\"attribute: \"+d+\" index: \"+g+\" must be an array\");if(!o.isArrayOrTypedArray(l))throw new Error(\"cannot extend missing or non-array attribute: \"+d);if(l.constructor!==u.constructor)throw new Error(\"cannot extend array with an array of a different type: \"+d);h=f?n[d][g]:n,i(h)||(h=-1),p.push({prop:c,target:l,insert:u,maxp:Math.floor(h)})}return p}(t,e,r,n),c={},u={},h=0;h<l.length;h++){var f=l[h].prop,p=l[h].maxp,d=a(l[h].target,l[h].insert,p);f.set(d[0]),Array.isArray(c[f.astr])||(c[f.astr]=[]),c[f.astr].push(d[1]),Array.isArray(u[f.astr])||(u[f.astr]=[]),u[f.astr].push(l[h].target.length)}return{update:c,maxPoints:u}}function F(t,e){var r=new t.constructor(t.length+e.length);return r.set(t),r.set(e,t.length),r}function B(t,e,n,i){t=o.getGraphDiv(t),k.clearPromiseQueue(t);var a={};if(\"string\"==typeof e)a[e]=n;else{if(!o.isPlainObject(e))return o.warn(\"Restyle fail.\",e,n,i),Promise.reject();a=o.extendFlat({},e),void 0===i&&(i=n)}Object.keys(a).length&&(t.changed=!0);var s=k.coerceTraceIndices(t,i),l=V(t,a,s),u=l.flags;u.calc&&(t.calcdata=void 0),u.clearAxisTypes&&k.clearAxisTypes(t,s,{});var h=[];u.fullReplot?h.push(r.plot):(h.push(f.previousPromises),f.supplyDefaults(t),u.markerSize&&(f.doCalcdata(t),Y(h)),u.style&&h.push(T.doTraceStyle),u.colorbars&&h.push(T.doColorBars),h.push(C)),h.push(f.rehover,f.redrag),c.add(t,B,[t,l.undoit,l.traces],B,[t,l.redoit,l.traces]);var p=o.syncOrAsync(h,t);return p&&p.then||(p=Promise.resolve()),p.then(function(){return t.emit(\"plotly_restyle\",l.eventData),t})}function N(t){return void 0===t?null:t}function j(t,e){return e?function(e,r,n){var i=s(e,r),a=i.set;return i.set=function(e){U((n||\"\")+r,i.get(),e,t),a(e)},i}:s}function U(t,e,r,n){if(Array.isArray(e)||Array.isArray(r))for(var i=Array.isArray(e)?e:[],a=Array.isArray(r)?r:[],s=Math.max(i.length,a.length),l=0;l<s;l++)U(t+\"[\"+l+\"]\",i[l],a[l],n);else if(o.isPlainObject(e)||o.isPlainObject(r)){var c=o.isPlainObject(e)?e:{},u=o.isPlainObject(r)?r:{},h=o.extendFlat({},c,u);for(var f in h)U(t+\".\"+f,c[f],u[f],n)}else void 0===n[t]&&(n[t]=N(e))}function V(t,e,r){var n,i=t._fullLayout,a=t._fullData,l=t.data,c=i._guiEditing,p=j(i._preGUI,c),g=o.extendDeepAll({},e);q(e);var v,m=A.traceFlags(),y={},x={};function b(){return r.map(function(){})}function _(t){var e=d.id2name(t);-1===v.indexOf(e)&&v.push(e)}function w(t){return\"LAYOUT\"+t+\".autorange\"}function T(t){return\"LAYOUT\"+t+\".range\"}function M(t){for(var e=t;e<a.length;e++)if(a[e]._input===l[t])return a[e]}function S(n,a,o){if(Array.isArray(n))n.forEach(function(t){S(t,a,o)});else if(!(n in e||k.hasParent(e,n))){var s;if(\"LAYOUT\"===n.substr(0,6))s=p(t.layout,n.replace(\"LAYOUT\",\"\"));else{var u=r[o];s=j(i._tracePreGUI[M(u)._fullInput.uid],c)(l[u],n)}n in x||(x[n]=b()),void 0===x[n][o]&&(x[n][o]=N(s.get())),void 0!==a&&s.set(a)}}function E(t){return function(e){return a[e][t]}}function C(t){return function(e,n){return!1===e?a[r[n]][t]:null}}for(var L in e){if(k.hasParent(e,L))throw new Error(\"cannot set \"+L+\" and a parent attribute simultaneously\");var P,O,z,I,D,R,F=e[L];if(\"autobinx\"!==L&&\"autobiny\"!==L||(L=L.charAt(L.length-1)+\"bins\",F=Array.isArray(F)?F.map(C(L)):!1===F?r.map(E(L)):null),y[L]=F,\"LAYOUT\"!==L.substr(0,6)){for(x[L]=b(),n=0;n<r.length;n++){if(P=l[r[n]],O=M(r[n]),I=(z=j(i._tracePreGUI[O._fullInput.uid],c)(P,L)).get(),void 0!==(D=Array.isArray(F)?F[n%F.length]:F)){var B=z.parts[z.parts.length-1],U=L.substr(0,L.length-B.length-1),V=U?U+\".\":\"\",H=U?s(O,U).get():O;if((R=h.getTraceValObject(O,z.parts))&&R.impliedEdits&&null!==D)for(var G in R.impliedEdits)S(o.relativeAttr(L,G),R.impliedEdits[G],n);else if(\"thicknessmode\"!==B&&\"lenmode\"!==B||I===D||\"fraction\"!==D&&\"pixels\"!==D||!H){if(\"type\"===L&&(\"pie\"===D!=(\"pie\"===I)||\"funnelarea\"===D!=(\"funnelarea\"===I))){var Y=\"x\",W=\"y\";\"bar\"!==D&&\"bar\"!==I||\"h\"!==P.orientation||(Y=\"y\",W=\"x\"),o.swapAttrs(P,[\"?\",\"?src\"],\"labels\",Y),o.swapAttrs(P,[\"d?\",\"?0\"],\"label\",Y),o.swapAttrs(P,[\"?\",\"?src\"],\"values\",W),\"pie\"===I||\"funnelarea\"===I?(s(P,\"marker.color\").set(s(P,\"marker.colors\").get()),i._pielayer.selectAll(\"g.trace\").remove()):u.traceIs(P,\"cartesian\")&&s(P,\"marker.colors\").set(s(P,\"marker.color\").get())}}else{var X=i._size,Z=H.orient,J=\"top\"===Z||\"bottom\"===Z;if(\"thicknessmode\"===B){var K=J?X.h:X.w;S(V+\"thickness\",H.thickness*(\"fraction\"===D?1/K:K),n)}else{var $=J?X.w:X.h;S(V+\"len\",H.len*(\"fraction\"===D?1/$:$),n)}}x[L][n]=N(I);if(-1!==[\"swapxy\",\"swapxyaxes\",\"orientation\",\"orientationaxes\"].indexOf(L)){if(\"orientation\"===L){z.set(D);var Q=P.x&&!P.y?\"h\":\"v\";if((z.get()||Q)===O.orientation)continue}else\"orientationaxes\"===L&&(P.orientation={v:\"h\",h:\"v\"}[O.orientation]);k.swapXYData(P),m.calc=m.clearAxisTypes=!0}else-1!==f.dataArrayContainers.indexOf(z.parts[0])?(k.manageArrayContainers(z,D,x),m.calc=!0):(R?R.arrayOk&&!u.traceIs(O,\"regl\")&&(o.isArrayOrTypedArray(D)||o.isArrayOrTypedArray(I))?m.calc=!0:A.update(m,R):m.calc=!0,z.set(D))}}if(-1!==[\"swapxyaxes\",\"orientationaxes\"].indexOf(L)&&d.swap(t,r),\"orientationaxes\"===L){var tt=s(t.layout,\"hovermode\");\"x\"===tt.get()?tt.set(\"y\"):\"y\"===tt.get()&&tt.set(\"x\")}if(-1!==[\"orientation\",\"type\"].indexOf(L)){for(v=[],n=0;n<r.length;n++){var et=l[r[n]];u.traceIs(et,\"cartesian\")&&(_(et.xaxis||\"x\"),_(et.yaxis||\"y\"))}S(v.map(w),!0,0),S(v.map(T),[0,1],0)}}else z=p(t.layout,L.replace(\"LAYOUT\",\"\")),x[L]=[N(z.get())],z.set(Array.isArray(F)?F[0]:F),m.calc=!0}return(m.calc||m.plot)&&(m.fullReplot=!0),{flags:m,undoit:x,redoit:y,traces:r,eventData:o.extendDeepNoArrays([],[g,r])}}function q(t){var e,r,n,i=o.counterRegex(\"axis\",\".title\",!1,!1),a=/colorbar\\.title$/,s=Object.keys(t);for(e=0;e<s.length;e++)r=s[e],n=t[r],\"title\"!==r&&!i.test(r)&&!a.test(r)||\"string\"!=typeof n&&\"number\"!=typeof n?r.indexOf(\"titlefont\")>-1?l(r,r.replace(\"titlefont\",\"title.font\")):r.indexOf(\"titleposition\")>-1?l(r,r.replace(\"titleposition\",\"title.position\")):r.indexOf(\"titleside\")>-1?l(r,r.replace(\"titleside\",\"title.side\")):r.indexOf(\"titleoffset\")>-1&&l(r,r.replace(\"titleoffset\",\"title.offset\")):l(r,r.replace(\"title\",\"title.text\"));function l(e,r){t[r]=t[e],delete t[e]}}function H(t,e,r){if(t=o.getGraphDiv(t),k.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);var n={};if(\"string\"==typeof e)n[e]=r;else{if(!o.isPlainObject(e))return o.warn(\"Relayout fail.\",e,r),Promise.reject();n=o.extendFlat({},e)}Object.keys(n).length&&(t.changed=!0);var i=J(t,n),a=i.flags;a.calc&&(t.calcdata=void 0);var s=[f.previousPromises];a.layoutReplot?s.push(T.layoutReplot):Object.keys(n).length&&(G(t,a,i)||f.supplyDefaults(t),a.legend&&s.push(T.doLegend),a.layoutstyle&&s.push(T.layoutStyles),a.axrange&&Y(s,i.rangesAltered),a.ticks&&s.push(T.doTicksRelayout),a.modebar&&s.push(T.doModeBar),a.camera&&s.push(T.doCamera),a.colorbars&&s.push(T.doColorBars),s.push(C)),s.push(f.rehover,f.redrag),c.add(t,H,[t,i.undoit],H,[t,i.redoit]);var l=o.syncOrAsync(s,t);return l&&l.then||(l=Promise.resolve(t)),l.then(function(){return t.emit(\"plotly_relayout\",i.eventData),t})}function G(t,e,r){var n=t._fullLayout;if(!e.axrange)return!1;for(var i in e)if(\"axrange\"!==i&&e[i])return!1;for(var a in r.rangesAltered){var o=d.id2name(a),s=t.layout[o],l=n[o];if(l.autorange=s.autorange,l.range=s.range.slice(),l.cleanRange(),l._matchGroup)for(var c in l._matchGroup)if(c!==a){var u=n[d.id2name(c)];u.autorange=l.autorange,u.range=l.range.slice(),u._input.range=l.range.slice()}}return!0}function Y(t,e){var r=e?function(t){var r=[],n=!0;for(var i in e){var a=d.getFromId(t,i);if(r.push(i),a._matchGroup)for(var o in a._matchGroup)e[o]||r.push(o);a.automargin&&(n=!1)}return d.draw(t,r,{skipTitle:n})}:function(t){return d.draw(t,\"redraw\")};t.push(b,T.doAutoRangeAndConstraints,r,T.drawData,T.finalDraw)}var W=/^[xyz]axis[0-9]*\\.range(\\[[0|1]\\])?$/,X=/^[xyz]axis[0-9]*\\.autorange$/,Z=/^[xyz]axis[0-9]*\\.domain(\\[[0|1]\\])?$/;function J(t,e){var r,n,i,a=t.layout,l=t._fullLayout,c=l._guiEditing,f=j(l._preGUI,c),p=Object.keys(e),g=d.list(t),v=o.extendDeepAll({},e),m={};for(q(e),p=Object.keys(e),n=0;n<p.length;n++)if(0===p[n].indexOf(\"allaxes\")){for(i=0;i<g.length;i++){var y=g[i]._id.substr(1),x=-1!==y.indexOf(\"scene\")?y+\".\":\"\",b=p[n].replace(\"allaxes\",x+g[i]._name);e[b]||(e[b]=e[p[n]])}delete e[p[n]]}var _=A.layoutFlags(),T={},S={};function E(t,r){if(Array.isArray(t))t.forEach(function(t){E(t,r)});else if(!(t in e||k.hasParent(e,t))){var n=f(a,t);t in S||(S[t]=N(n.get())),void 0!==r&&n.set(r)}}var C,L={};function P(t){var e=d.name2id(t.split(\".\")[0]);return L[e]=1,e}for(var O in e){if(k.hasParent(e,O))throw new Error(\"cannot set \"+O+\" and a parent attribute simultaneously\");for(var z=f(a,O),I=e[O],D=z.parts.length-1;D>0&&\"string\"!=typeof z.parts[D];)D--;var R=z.parts[D],F=z.parts[D-1]+\".\"+R,B=z.parts.slice(0,D).join(\".\"),U=s(t.layout,B).get(),V=s(l,B).get(),H=z.get();if(void 0!==I){T[O]=I,S[O]=\"reverse\"===R?I:N(H);var G=h.getLayoutValObject(l,z.parts);if(G&&G.impliedEdits&&null!==I)for(var Y in G.impliedEdits)E(o.relativeAttr(O,Y),G.impliedEdits[Y]);if(-1!==[\"width\",\"height\"].indexOf(O))if(I){E(\"autosize\",null);var J=\"height\"===O?\"width\":\"height\";E(J,l[J])}else l[O]=t._initialAutoSize[O];else if(\"autosize\"===O)E(\"width\",I?null:l.width),E(\"height\",I?null:l.height);else if(F.match(W))P(F),s(l,B+\"._inputRange\").set(null);else if(F.match(X)){P(F),s(l,B+\"._inputRange\").set(null);var $=s(l,B).get();$._inputDomain&&($._input.domain=$._inputDomain.slice())}else F.match(Z)&&s(l,B+\"._inputDomain\").set(null);if(\"type\"===R){var Q=U,tt=\"linear\"===V.type&&\"log\"===I,et=\"log\"===V.type&&\"linear\"===I;if(tt||et){if(Q&&Q.range)if(V.autorange)tt&&(Q.range=Q.range[1]>Q.range[0]?[1,2]:[2,1]);else{var rt=Q.range[0],nt=Q.range[1];tt?(rt<=0&&nt<=0&&E(B+\".autorange\",!0),rt<=0?rt=nt/1e6:nt<=0&&(nt=rt/1e6),E(B+\".range[0]\",Math.log(rt)/Math.LN10),E(B+\".range[1]\",Math.log(nt)/Math.LN10)):(E(B+\".range[0]\",Math.pow(10,rt)),E(B+\".range[1]\",Math.pow(10,nt)))}else E(B+\".autorange\",!0);Array.isArray(l._subplots.polar)&&l._subplots.polar.length&&l[z.parts[0]]&&\"radialaxis\"===z.parts[1]&&delete l[z.parts[0]]._subplot.viewInitial[\"radialaxis.range\"],u.getComponentMethod(\"annotations\",\"convertCoords\")(t,V,I,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,V,I,E)}else E(B+\".autorange\",!0),E(B+\".range\",null);s(l,B+\"._inputRange\").set(null)}else if(R.match(M)){var it=s(l,O).get(),at=(I||{}).type;at&&\"-\"!==at||(at=\"linear\"),u.getComponentMethod(\"annotations\",\"convertCoords\")(t,it,at,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,it,at,E)}var ot=w.containerArrayMatch(O);if(ot){r=ot.array,n=ot.index;var st=ot.property,lt=G||{editType:\"calc\"};\"\"!==n&&\"\"===st&&(w.isAddVal(I)?S[O]=null:w.isRemoveVal(I)?S[O]=(s(a,r).get()||[])[n]:o.warn(\"unrecognized full object value\",e)),A.update(_,lt),m[r]||(m[r]={});var ct=m[r][n];ct||(ct=m[r][n]={}),ct[st]=I,delete e[O]}else\"reverse\"===R?(U.range?U.range.reverse():(E(B+\".autorange\",!0),U.range=[1,0]),V.autorange?_.calc=!0:_.plot=!0):(l._has(\"scatter-like\")&&l._has(\"regl\")&&\"dragmode\"===O&&(\"lasso\"===I||\"select\"===I)&&\"lasso\"!==H&&\"select\"!==H?_.plot=!0:l._has(\"gl2d\")?_.plot=!0:G?A.update(_,G):_.calc=!0,z.set(I))}}for(r in m){w.applyContainerArrayChanges(t,f(a,r),m[r],_,f)||(_.plot=!0)}var ut=l._axisConstraintGroups||[];for(C in L)for(n=0;n<ut.length;n++){var ht=ut[n];if(ht[C])for(var ft in _.calc=!0,ht)L[ft]||(d.getFromId(t,ft)._constraintShrinkable=!0)}return(K(t)||e.height||e.width)&&(_.plot=!0),(_.plot||_.calc)&&(_.layoutReplot=!0),{flags:_,rangesAltered:L,undoit:S,redoit:T,eventData:v}}function K(t){var e=t._fullLayout,r=e.width,n=e.height;return t.layout.autosize&&f.plotAutoSize(t,t.layout,e),e.width!==r||e.height!==n}function $(t,e,n,i){if(t=o.getGraphDiv(t),k.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);o.isPlainObject(e)||(e={}),o.isPlainObject(n)||(n={}),Object.keys(e).length&&(t.changed=!0),Object.keys(n).length&&(t.changed=!0);var a=k.coerceTraceIndices(t,i),s=V(t,o.extendFlat({},e),a),l=s.flags,u=J(t,o.extendFlat({},n)),h=u.flags;(l.calc||h.calc)&&(t.calcdata=void 0),l.clearAxisTypes&&k.clearAxisTypes(t,a,n);var p=[];h.layoutReplot?p.push(T.layoutReplot):l.fullReplot?p.push(r.plot):(p.push(f.previousPromises),G(t,h,u)||f.supplyDefaults(t),l.style&&p.push(T.doTraceStyle),(l.colorbars||h.colorbars)&&p.push(T.doColorBars),h.legend&&p.push(T.doLegend),h.layoutstyle&&p.push(T.layoutStyles),h.axrange&&Y(p,u.rangesAltered),h.ticks&&p.push(T.doTicksRelayout),h.modebar&&p.push(T.doModeBar),h.camera&&p.push(T.doCamera),p.push(C)),p.push(f.rehover,f.redrag),c.add(t,$,[t,s.undoit,u.undoit,s.traces],$,[t,s.redoit,u.redoit,s.traces]);var d=o.syncOrAsync(p,t);return d&&d.then||(d=Promise.resolve(t)),d.then(function(){return t.emit(\"plotly_update\",{data:s.eventData,layout:u.eventData}),t})}function Q(t){return function(e){e._fullLayout._guiEditing=!0;var r=t.apply(null,arguments);return e._fullLayout._guiEditing=!1,r}}var tt=[{pattern:/^hiddenlabels/,attr:\"legend.uirevision\"},{pattern:/^((x|y)axis\\d*)\\.((auto)?range|title\\.text)/},{pattern:/axis\\d*\\.showspikes$/,attr:\"modebar.uirevision\"},{pattern:/(hover|drag)mode$/,attr:\"modebar.uirevision\"},{pattern:/^(scene\\d*)\\.camera/},{pattern:/^(geo\\d*)\\.(projection|center)/},{pattern:/^(ternary\\d*\\.[abc]axis)\\.(min|title\\.text)$/},{pattern:/^(polar\\d*\\.radialaxis)\\.((auto)?range|angle|title\\.text)/},{pattern:/^(polar\\d*\\.angularaxis)\\.rotation/},{pattern:/^(mapbox\\d*)\\.(center|zoom|bearing|pitch)/},{pattern:/^legend\\.(x|y)$/,attr:\"editrevision\"},{pattern:/^(shapes|annotations)/,attr:\"editrevision\"},{pattern:/^title\\.text$/,attr:\"editrevision\"}],et=[{pattern:/^selectedpoints$/,attr:\"selectionrevision\"},{pattern:/(^|value\\.)visible$/,attr:\"legend.uirevision\"},{pattern:/^dimensions\\[\\d+\\]\\.constraintrange/},{pattern:/^node\\.(x|y|groups)/},{pattern:/^level$/},{pattern:/(^|value\\.)name$/},{pattern:/colorbar\\.title\\.text$/},{pattern:/colorbar\\.(x|y)$/,attr:\"editrevision\"}];function rt(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=t.match(n.pattern);if(i)return{head:i[1],attr:n.attr}}}function nt(t,e){var r=s(e,t).get();if(void 0!==r)return r;var n=t.split(\".\");for(n.pop();n.length>1;)if(n.pop(),void 0!==(r=s(e,n.join(\".\")+\".uirevision\").get()))return r;return e.uirevision}function it(t,e){for(var r=0;r<e.length;r++)if(e[r]._fullInput.uid===t)return r;return-1}function at(t,e,r){for(var n=0;n<e.length;n++)if(e[n].uid===t)return n;return!e[r]||e[r].uid?-1:r}function ot(t,e){var r=o.isPlainObject(t),n=Array.isArray(t);return r||n?(r&&o.isPlainObject(e)||n&&Array.isArray(e))&&JSON.stringify(t)===JSON.stringify(e):t===e}function st(t,e,r,n){var i,a,l,c=n.getValObject,u=n.flags,h=n.immutable,f=n.inArray,p=n.arrayIndex;function d(){var t=i.editType;f&&-1!==t.indexOf(\"arraydraw\")?o.pushUnique(u.arrays[f],p):(A.update(u,i),\"none\"!==t&&u.nChanges++,n.transition&&i.anim&&u.nChangesAnim++,(W.test(l)||X.test(l))&&(u.rangesAltered[r[0]]=1),Z.test(l)&&s(e,\"_inputDomain\").set(null),\"datarevision\"===a&&(u.newDataRevision=1))}function g(t){return\"data_array\"===t.valType||t.arrayOk}for(a in t){if(u.calc&&!n.transition)return;var v=t[a],m=e[a],y=r.concat(a);if(l=y.join(\".\"),\"_\"!==a.charAt(0)&&\"function\"!=typeof v&&v!==m){if((\"tick0\"===a||\"dtick\"===a)&&\"geo\"!==r[0]){var x=e.tickmode;if(\"auto\"===x||\"array\"===x||!x)continue}if((\"range\"!==a||!e.autorange)&&(\"zmin\"!==a&&\"zmax\"!==a||\"contourcarpet\"!==e.type)&&(i=c(y))&&(!i._compareAsJSON||JSON.stringify(v)!==JSON.stringify(m))){var b,_=i.valType,w=g(i),k=Array.isArray(v),T=Array.isArray(m);if(k&&T){var M=\"_input_\"+a,S=t[M],E=e[M];if(Array.isArray(S)&&S===E)continue}if(void 0===m)w&&k?u.calc=!0:d();else if(i._isLinkedToArray){var C=[],L=!1;f||(u.arrays[a]=C);var P=Math.min(v.length,m.length),O=Math.max(v.length,m.length);if(P!==O){if(\"arraydraw\"!==i.editType){d();continue}L=!0}for(b=0;b<P;b++)st(v[b],m[b],y.concat(b),o.extendFlat({inArray:a,arrayIndex:b},n));if(L)for(b=P;b<O;b++)C.push(b)}else!_&&o.isPlainObject(v)?st(v,m,y,n):w?k&&T?(h&&(u.calc=!0),(h||n.newDataRevision)&&d()):k!==T?u.calc=!0:d():k&&T&&v.length===m.length&&String(v)===String(m)||d()}}}for(a in e)if(!(a in t||\"_\"===a.charAt(0)||\"function\"==typeof e[a])){if(g(i=c(r.concat(a)))&&Array.isArray(e[a]))return void(u.calc=!0);d()}}function lt(t){var e=n.select(t),r=t._fullLayout;if(r._container=e.selectAll(\".plot-container\").data([0]),r._container.enter().insert(\"div\",\":first-child\").classed(\"plot-container\",!0).classed(\"plotly\",!0),r._paperdiv=r._container.selectAll(\".svg-container\").data([0]),r._paperdiv.enter().append(\"div\").classed(\"svg-container\",!0).style(\"position\",\"relative\"),r._glcontainer=r._paperdiv.selectAll(\".gl-container\").data([{}]),r._glcontainer.enter().append(\"div\").classed(\"gl-container\",!0),r._paperdiv.selectAll(\".main-svg\").remove(),r._paperdiv.select(\".modebar-container\").remove(),r._paper=r._paperdiv.insert(\"svg\",\":first-child\").classed(\"main-svg\",!0),r._toppaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),r._modebardiv=r._paperdiv.append(\"div\"),r._hoverpaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),!r._uid){var i={};n.selectAll(\"defs\").each(function(){this.id&&(i[this.id.split(\"-\")[1]]=1)}),r._uid=o.randstr(i)}r._paperdiv.selectAll(\".main-svg\").attr(y.svgAttrs),r._defs=r._paper.append(\"defs\").attr(\"id\",\"defs-\"+r._uid),r._clips=r._defs.append(\"g\").classed(\"clips\",!0),r._topdefs=r._toppaper.append(\"defs\").attr(\"id\",\"topdefs-\"+r._uid),r._topclips=r._topdefs.append(\"g\").classed(\"clips\",!0),r._bgLayer=r._paper.append(\"g\").classed(\"bglayer\",!0),r._draggers=r._paper.append(\"g\").classed(\"draglayer\",!0);var a=r._paper.append(\"g\").classed(\"layer-below\",!0);r._imageLowerLayer=a.append(\"g\").classed(\"imagelayer\",!0),r._shapeLowerLayer=a.append(\"g\").classed(\"shapelayer\",!0),r._cartesianlayer=r._paper.append(\"g\").classed(\"cartesianlayer\",!0),r._polarlayer=r._paper.append(\"g\").classed(\"polarlayer\",!0),r._ternarylayer=r._paper.append(\"g\").classed(\"ternarylayer\",!0),r._geolayer=r._paper.append(\"g\").classed(\"geolayer\",!0),r._funnelarealayer=r._paper.append(\"g\").classed(\"funnelarealayer\",!0),r._pielayer=r._paper.append(\"g\").classed(\"pielayer\",!0),r._sunburstlayer=r._paper.append(\"g\").classed(\"sunburstlayer\",!0),r._indicatorlayer=r._toppaper.append(\"g\").classed(\"indicatorlayer\",!0),r._glimages=r._paper.append(\"g\").classed(\"glimages\",!0);var s=r._toppaper.append(\"g\").classed(\"layer-above\",!0);r._imageUpperLayer=s.append(\"g\").classed(\"imagelayer\",!0),r._shapeUpperLayer=s.append(\"g\").classed(\"shapelayer\",!0),r._infolayer=r._toppaper.append(\"g\").classed(\"infolayer\",!0),r._menulayer=r._toppaper.append(\"g\").classed(\"menulayer\",!0),r._zoomlayer=r._toppaper.append(\"g\").classed(\"zoomlayer\",!0),r._hoverlayer=r._hoverpaper.append(\"g\").classed(\"hoverlayer\",!0),r._modebardiv.classed(\"modebar-container\",!0).style(\"position\",\"absolute\").style(\"top\",\"0px\").style(\"right\",\"0px\"),t.emit(\"plotly_framework\")}r.animate=function(t,e,r){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before animating it. For more details, see https://plot.ly/javascript/animations/\");var n=t._transitionData;n._frameQueue||(n._frameQueue=[]);var i=(r=f.supplyAnimationDefaults(r)).transition,a=r.frame;function s(t){return Array.isArray(i)?t>=i.length?i[0]:i[t]:i}function l(t){return Array.isArray(a)?t>=a.length?a[0]:a[t]:a}function c(t,e){var r=0;return function(){if(t&&++r===e)return t()}}return void 0===n._frameWaitingCnt&&(n._frameWaitingCnt=0),new Promise(function(a,u){function h(){n._currentFrame&&n._currentFrame.onComplete&&n._currentFrame.onComplete();var e=n._currentFrame=n._frameQueue.shift();if(e){var r=e.name?e.name.toString():null;t._fullLayout._currentFrame=r,n._lastFrameAt=Date.now(),n._timeToNext=e.frameOpts.duration,f.transition(t,e.frame.data,e.frame.layout,k.coerceTraceIndices(t,e.frame.traces),e.frameOpts,e.transitionOpts).then(function(){e.onComplete&&e.onComplete()}),t.emit(\"plotly_animatingframe\",{name:r,frame:e.frame,animation:{frame:e.frameOpts,transition:e.transitionOpts}})}else t.emit(\"plotly_animated\"),window.cancelAnimationFrame(n._animationRaf),n._animationRaf=null}function p(){t.emit(\"plotly_animating\"),n._lastFrameAt=-1/0,n._timeToNext=0,n._runningTransitions=0,n._currentFrame=null;var e=function(){n._animationRaf=window.requestAnimationFrame(e),Date.now()-n._lastFrameAt>n._timeToNext&&h()};e()}var d,g,v=0;function m(t){return Array.isArray(i)?v>=i.length?t.transitionOpts=i[v]:t.transitionOpts=i[0]:t.transitionOpts=i,v++,t}var y=[],x=null==e,b=Array.isArray(e);if(x||b||!o.isPlainObject(e)){if(x||-1!==[\"string\",\"number\"].indexOf(typeof e))for(d=0;d<n._frames.length;d++)(g=n._frames[d])&&(x||String(g.group)===String(e))&&y.push({type:\"byname\",name:String(g.name),data:m({name:g.name})});else if(b)for(d=0;d<e.length;d++){var _=e[d];-1!==[\"number\",\"string\"].indexOf(typeof _)?(_=String(_),y.push({type:\"byname\",name:_,data:m({name:_})})):o.isPlainObject(_)&&y.push({type:\"object\",data:m(o.extendFlat({},_))})}}else y.push({type:\"object\",data:m(o.extendFlat({},e))});for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&!n._frameHash[g.data.name])return o.warn('animate failure: frame not found: \"'+g.data.name+'\"'),void u();-1!==[\"next\",\"immediate\"].indexOf(r.mode)&&function(){if(0!==n._frameQueue.length){for(;n._frameQueue.length;){var e=n._frameQueue.pop();e.onInterrupt&&e.onInterrupt()}t.emit(\"plotly_animationinterrupted\",[])}}(),\"reverse\"===r.direction&&y.reverse();var w=t._fullLayout._currentFrame;if(w&&r.fromcurrent){var T=-1;for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&g.name===w){T=d;break}if(T>0&&T<y.length-1){var A=[];for(d=0;d<y.length;d++)g=y[d],(\"byname\"!==y[d].type||d>T)&&A.push(g);y=A}}y.length>0?function(e){if(0!==e.length){for(var i=0;i<e.length;i++){var o;o=\"byname\"===e[i].type?f.computeFrame(t,e[i].name):e[i].data;var h=l(i),d=s(i);d.duration=Math.min(d.duration,h.duration);var g={frame:o,name:e[i].name,frameOpts:h,transitionOpts:d};i===e.length-1&&(g.onComplete=c(a,2),g.onInterrupt=u),n._frameQueue.push(g)}\"immediate\"===r.mode&&(n._lastFrameAt=-1/0),n._animationRaf||p()}}(y):(t.emit(\"plotly_animated\"),a())})},r.addFrames=function(t,e,r){if(t=o.getGraphDiv(t),null==e)return Promise.resolve();if(!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before adding frames. For more details, see https://plot.ly/javascript/animations/\");var n,i,a,s,l=t._transitionData._frames,u=t._transitionData._frameHash;if(!Array.isArray(e))throw new Error(\"addFrames failure: frameList must be an Array of frame definitions\"+e);var h=l.length+2*e.length,p=[],d={};for(n=e.length-1;n>=0;n--)if(o.isPlainObject(e[n])){var g=e[n].name,v=(u[g]||d[g]||{}).name,m=e[n].name,y=u[v]||d[v];v&&m&&\"number\"==typeof m&&y&&S<E&&(S++,o.warn('addFrames: overwriting frame \"'+(u[v]||d[v]).name+'\" with a frame whose name of type \"number\" also equates to \"'+v+'\". This is valid but may potentially lead to unexpected behavior since all plotly.js frame names are stored internally as strings.'),S===E&&o.warn(\"addFrames: This API call has yielded too many of these warnings. For the rest of this call, further warnings about numeric frame names will be suppressed.\")),d[g]={name:g},p.push({frame:f.supplyFrameDefaults(e[n]),index:r&&void 0!==r[n]&&null!==r[n]?r[n]:h+n})}p.sort(function(t,e){return t.index>e.index?-1:t.index<e.index?1:0});var x=[],b=[],_=l.length;for(n=p.length-1;n>=0;n--){if(\"number\"==typeof(i=p[n].frame).name&&o.warn(\"Warning: addFrames accepts frames with numeric names, but the numbers areimplicitly cast to strings\"),!i.name)for(;u[i.name=\"frame \"+t._transitionData._counter++];);if(u[i.name]){for(a=0;a<l.length&&(l[a]||{}).name!==i.name;a++);x.push({type:\"replace\",index:a,value:i}),b.unshift({type:\"replace\",index:a,value:l[a]})}else s=Math.max(0,Math.min(p[n].index,_)),x.push({type:\"insert\",index:s,value:i}),b.unshift({type:\"delete\",index:s}),_++}var w=f.modifyFrames,k=f.modifyFrames,T=[t,b],A=[t,x];return c&&c.add(t,w,T,k,A),f.modifyFrames(t,x)},r.deleteFrames=function(t,e){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);var r,n,i=t._transitionData._frames,a=[],s=[];if(!e)for(e=[],r=0;r<i.length;r++)e.push(r);for((e=e.slice()).sort(),r=e.length-1;r>=0;r--)n=e[r],a.push({type:\"delete\",index:n}),s.unshift({type:\"insert\",index:n,value:i[n]});var l=f.modifyFrames,u=f.modifyFrames,h=[t,s],p=[t,a];return c&&c.add(t,l,h,u,p),f.modifyFrames(t,a)},r.addTraces=function t(e,n,i){e=o.getGraphDiv(e);var a,s,l=[],u=r.deleteTraces,h=t,f=[e,l],p=[e,n];for(function(t,e,r){var n,i;if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"traces must be defined.\");for(Array.isArray(e)||(e=[e]),n=0;n<e.length;n++)if(\"object\"!=typeof(i=e[n])||Array.isArray(i)||null===i)throw new Error(\"all values in traces array must be non-array objects\");if(\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&r.length!==e.length)throw new Error(\"if indices is specified, traces.length must equal indices.length\")}(e,n,i),Array.isArray(n)||(n=[n]),n=n.map(function(t){return o.extendFlat({},t)}),k.cleanData(n),a=0;a<n.length;a++)e.data.push(n[a]);for(a=0;a<n.length;a++)l.push(-n.length+a);if(\"undefined\"==typeof i)return s=r.redraw(e),c.add(e,u,f,h,p),s;Array.isArray(i)||(i=[i]);try{D(e,l,i)}catch(t){throw e.data.splice(e.data.length-n.length,n.length),t}return c.startSequence(e),c.add(e,u,f,h,p),s=r.moveTraces(e,l,i),c.stopSequence(e),s},r.deleteTraces=function t(e,n){e=o.getGraphDiv(e);var i,a,s=[],l=r.addTraces,u=t,h=[e,s,n],f=[e,n];if(\"undefined\"==typeof n)throw new Error(\"indices must be an integer or array of integers.\");for(Array.isArray(n)||(n=[n]),I(e,n,\"indices\"),(n=z(n,e.data.length-1)).sort(o.sorterDes),i=0;i<n.length;i+=1)a=e.data.splice(n[i],1)[0],s.push(a);var p=r.redraw(e);return c.add(e,l,h,u,f),p},r.extendTraces=function t(e,n,i,a){var s=R(e=o.getGraphDiv(e),n,i,a,function(t,e,r){var n,i;if(o.isTypedArray(t))if(r<0){var a=new t.constructor(0),s=F(t,e);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(l)),i.set(t),i.set(e.subarray(0,l),t.length)}else{var c=r-e.length,u=t.length-c;n.set(t.subarray(u)),n.set(e,c),i.set(t.subarray(0,u))}else n=t.concat(e),i=r>=0&&r<n.length?n.splice(0,n.length-r):[];return[n,i]}),l=r.redraw(e),u=[e,s.update,i,s.maxPoints];return c.add(e,r.prependTraces,u,t,arguments),l},r.moveTraces=function t(e,n,i){var a,s=[],l=[],u=t,h=t,f=[e=o.getGraphDiv(e),i,n],p=[e,n,i];if(D(e,n,i),n=Array.isArray(n)?n:[n],\"undefined\"==typeof i)for(i=[],a=0;a<n.length;a++)i.push(-n.length+a);for(i=Array.isArray(i)?i:[i],n=z(n,e.data.length-1),i=z(i,e.data.length-1),a=0;a<e.data.length;a++)-1===n.indexOf(a)&&s.push(e.data[a]);for(a=0;a<n.length;a++)l.push({newIndex:i[a],trace:e.data[n[a]]});for(l.sort(function(t,e){return t.newIndex-e.newIndex}),a=0;a<l.length;a+=1)s.splice(l[a].newIndex,0,l[a].trace);e.data=s;var d=r.redraw(e);return c.add(e,u,f,h,p),d},r.prependTraces=function t(e,n,i,a){var s=R(e=o.getGraphDiv(e),n,i,a,function(t,e,r){var n,i;if(o.isTypedArray(t))if(r<=0){var a=new t.constructor(0),s=F(e,t);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(0,l)),i.set(e.subarray(l)),i.set(t,l)}else{var c=r-e.length;n.set(e),n.set(t.subarray(0,c),e.length),i.set(t.subarray(c))}else n=e.concat(t),i=r>=0&&r<n.length?n.splice(r,n.length):[];return[n,i]}),l=r.redraw(e),u=[e,s.update,i,s.maxPoints];return c.add(e,r.extendTraces,u,t,arguments),l},r.newPlot=function(t,e,n,i){return t=o.getGraphDiv(t),f.cleanPlot([],{},t._fullData||[],t._fullLayout||{}),f.purge(t),r.plot(t,e,n,i)},r.plot=function(t,e,i,a){var s;if(t=o.getGraphDiv(t),l.init(t),o.isPlainObject(e)){var c=e;e=c.data,i=c.layout,a=c.config,s=c.frames}if(!1===l.triggerHandler(t,\"plotly_beforeplot\",[e,i,a]))return Promise.reject();e||i||o.isPlotDiv(t)||o.warn(\"Calling Plotly.plot as if redrawing but this container doesn't yet have a plot.\",t),O(t,a),i||(i={}),n.select(t).classed(\"js-plotly-plot\",!0),g.makeTester(),Array.isArray(t._promises)||(t._promises=[]);var h=0===(t.data||[]).length&&Array.isArray(e);Array.isArray(e)&&(k.cleanData(e),h?t.data=e:t.data.push.apply(t.data,e),t.empty=!1),t.layout&&!h||(t.layout=k.cleanLayout(i)),f.supplyDefaults(t);var v=t._fullLayout,y=v._has(\"cartesian\");if(!v._has(\"polar\")&&e&&e[0]&&e[0].r)return o.log(\"Legacy polar charts are deprecated!\"),function(t,e,r){var i=n.select(t).selectAll(\".plot-container\").data([0]);i.enter().insert(\"div\",\":first-child\").classed(\"plot-container plotly\",!0);var a=i.selectAll(\".svg-container\").data([0]);a.enter().append(\"div\").classed(\"svg-container\",!0).style(\"position\",\"relative\"),a.html(\"\"),e&&(t.data=e),r&&(t.layout=r),p.manager.fillLayout(t),a.style({width:t._fullLayout.width+\"px\",height:t._fullLayout.height+\"px\"}),t.framework=p.manager.framework(t),t.framework({data:t.data,layout:t.layout},a.node()),t.framework.setUndoPoint();var s=t.framework.svg(),l=1,c=t._fullLayout.title?t._fullLayout.title.text:\"\";\"\"!==c&&c||(l=0);var u=function(){this.call(x.convertToTspans,t)},h=s.select(\".title-group text\").call(u);if(t._context.edits.titleText){var d=o._(t,\"Click to enter Plot title\");c&&c!==d||(l=.2,h.attr({\"data-unformatted\":d}).text(d).style({opacity:l}).on(\"mouseover.opacity\",function(){n.select(this).transition().duration(100).style(\"opacity\",1)}).on(\"mouseout.opacity\",function(){n.select(this).transition().duration(1e3).style(\"opacity\",0)}));var g=function(){this.call(x.makeEditable,{gd:t}).on(\"edit\",function(e){t.framework({layout:{title:{text:e}}}),this.text(e).call(u),this.call(g)}).on(\"cancel\",function(){var t=this.attr(\"data-unformatted\");this.text(t).call(u)})};h.call(g)}return t._context.setBackground(t,t._fullLayout.paper_bgcolor),f.addLinks(t),Promise.resolve()}(t,e,i);v._replotting=!0,h&&lt(t),t.framework!==lt&&(t.framework=lt,lt(t)),g.initGradients(t),h&&d.saveShowSpikeInitial(t);var b=!t.calcdata||t.calcdata.length!==(t._fullData||[]).length;b&&f.doCalcdata(t);for(var _=0;_<t.calcdata.length;_++)t.calcdata[_][0].trace=t._fullData[_];t._context.responsive?t._responsiveChartHandler||(t._responsiveChartHandler=function(){o.isHidden(t)||f.resize(t)},window.addEventListener(\"resize\",t._responsiveChartHandler)):o.clearResponsive(t);var w=o.extendFlat({},v._size),A=0;function M(){return f.clearAutoMarginIds(t),T.drawMarginPushers(t),d.allowAutoMargin(t),f.doAutoMargin(t),f.previousPromises(t)}function S(){t._transitioning||(T.doAutoRangeAndConstraints(t),h&&d.saveRangeInitial(t),u.getComponentMethod(\"rangeslider\",\"calcAutorange\")(t))}var E=[f.previousPromises,function(){if(s)return r.addFrames(t,s)},function e(){for(var r=v._basePlotModules,n=0;n<r.length;n++)r[n].drawFramework&&r[n].drawFramework(t);if(!v._glcanvas&&v._has(\"gl\")&&(v._glcanvas=v._glcontainer.selectAll(\".gl-canvas\").data([{key:\"contextLayer\",context:!0,pick:!1},{key:\"focusLayer\",context:!1,pick:!1},{key:\"pickLayer\",context:!1,pick:!0}],function(t){return t.key}),v._glcanvas.enter().append(\"canvas\").attr(\"class\",function(t){return\"gl-canvas gl-canvas-\"+t.key.replace(\"Layer\",\"\")}).style({position:\"absolute\",top:0,left:0,overflow:\"visible\",\"pointer-events\":\"none\"})),v._glcanvas){v._glcanvas.attr(\"width\",v.width).attr(\"height\",v.height);var i=v._glcanvas.data()[0].regl;if(i&&(Math.floor(v.width)!==i._gl.drawingBufferWidth||Math.floor(v.height)!==i._gl.drawingBufferHeight)){var a=\"WebGL context buffer and canvas dimensions do not match due to browser/WebGL bug.\";if(!A)return o.log(a+\" Clearing graph and plotting again.\"),f.cleanPlot([],{},t._fullData,v),f.supplyDefaults(t),v=t._fullLayout,f.doCalcdata(t),A++,e();o.error(a)}}return\"h\"===v.modebar.orientation?v._modebardiv.style(\"height\",null).style(\"width\",\"100%\"):v._modebardiv.style(\"width\",null).style(\"height\",v.height+\"px\"),f.previousPromises(t)},M,function(){if(f.didMarginChange(w,v._size))return o.syncOrAsync([M,T.layoutStyles],t)}];y&&E.push(function(){if(b)return o.syncOrAsync([u.getComponentMethod(\"shapes\",\"calcAutorange\"),u.getComponentMethod(\"annotations\",\"calcAutorange\"),S],t);S()}),E.push(T.layoutStyles),y&&E.push(function(){return d.draw(t,h?\"\":\"redraw\")}),E.push(T.drawData,T.finalDraw,m,f.addLinks,f.rehover,f.redrag,f.doAutoMargin,f.previousPromises);var L=o.syncOrAsync(E,t);return L&&L.then||(L=Promise.resolve()),L.then(function(){return C(t),t})},r.purge=function(t){var e=(t=o.getGraphDiv(t))._fullLayout||{},r=t._fullData||[];return f.cleanPlot([],{},r,e),f.purge(t),l.purge(t),e._container&&e._container.remove(),delete t._context,t},r.react=function(t,e,n,i){var a,l,c=(t=o.getGraphDiv(t))._fullData,p=t._fullLayout;if(o.isPlotDiv(t)&&c&&p){if(o.isPlainObject(e)){var d=e;e=d.data,n=d.layout,i=d.config,a=d.frames}var g=!1;if(i){var v=o.extendDeep({},t._context);t._context=void 0,O(t,i),g=function t(e,r){var n;for(n in e)if(\"_\"!==n.charAt(0)){var i=e[n],a=r[n];if(i!==a)if(o.isPlainObject(i)&&o.isPlainObject(a)){if(t(i,a))return!0}else{if(!Array.isArray(i)||!Array.isArray(a))return!0;if(i.length!==a.length)return!0;for(var s=0;s<i.length;s++)if(i[s]!==a[s]){if(!o.isPlainObject(i[s])||!o.isPlainObject(a[s]))return!0;if(t(i[s],a[s]))return!0}}}}(v,t._context)}t.data=e||[],k.cleanData(t.data),t.layout=n||{},k.cleanLayout(t.layout),function(t,e,r,n){var i,a,l,c,u,h,f,p,d=n._preGUI,g=[],v={};for(i in d){if(u=rt(i,tt)){if(a=u.attr||u.head+\".uirevision\",(c=(l=s(n,a).get())&&nt(a,e))&&c===l&&(null===(h=d[i])&&(h=void 0),ot(p=(f=s(e,i)).get(),h))){void 0===p&&\"autorange\"===i.substr(i.length-9)&&g.push(i.substr(0,i.length-10)),f.set(N(s(n,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i);delete d[i],\"range[\"===i.substr(i.length-8,6)&&(v[i.substr(0,i.length-9)]=1)}for(var m=0;m<g.length;m++){var y=g[m];if(v[y]){var x=s(e,y).get();x&&delete x.autorange}}var b=n._tracePreGUI;for(var _ in b){var w,k=b[_],T=null;for(i in k){if(!T){var A=it(_,r);if(A<0){delete b[_];break}var M=at(_,t,(w=r[A]._fullInput).index);if(M<0){delete b[_];break}T=t[M]}if(u=rt(i,et)){if(u.attr?c=(l=s(n,u.attr).get())&&nt(u.attr,e):(l=w.uirevision,void 0===(c=T.uirevision)&&(c=e.uirevision)),c&&c===l&&(null===(h=k[i])&&(h=void 0),ot(p=(f=s(T,i)).get(),h))){f.set(N(s(w,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i+\" in trace uid \"+_);delete k[i]}}}(t.data,t.layout,c,p),f.supplyDefaults(t,{skipUpdateCalc:!0});var m=t._fullData,y=t._fullLayout,x=void 0===y.datarevision,b=y.transition,_=function(t,e,r,n,i){var a=A.layoutFlags();return a.arrays={},a.rangesAltered={},a.nChanges=0,a.nChangesAnim=0,st(e,r,[],{getValObject:function(t){return h.getLayoutValObject(r,t)},flags:a,immutable:n,transition:i,gd:t}),(a.plot||a.calc)&&(a.layoutReplot=!0),i&&a.nChanges&&a.nChangesAnim&&(a.anim=a.nChanges===a.nChangesAnim?\"all\":\"some\"),a}(t,p,y,x,b),w=_.newDataRevision,M=function(t,e,r,n,i,a){var o=e.length===r.length;if(!i&&!o)return{fullReplot:!0,calc:!0};var s,l,c=A.traceFlags();c.arrays={},c.nChanges=0,c.nChangesAnim=0;var u={getValObject:function(t){var e=h.getTraceValObject(l,t);return!l._module.animatable&&e.anim&&(e.anim=!1),e},flags:c,immutable:n,transition:i,newDataRevision:a,gd:t},p={};for(s=0;s<e.length;s++)if(r[s]){if(l=r[s]._fullInput,f.hasMakesDataTransform(l)&&(l=r[s]),p[l.uid])continue;p[l.uid]=1,st(e[s]._fullInput,l,[],u)}return(c.calc||c.plot)&&(c.fullReplot=!0),i&&c.nChanges&&c.nChangesAnim&&(c.anim=c.nChanges===c.nChangesAnim&&o?\"all\":\"some\"),c}(t,c,m,x,b,w);K(t)&&(_.layoutReplot=!0),M.calc||_.calc?t.calcdata=void 0:f.supplyDefaultsUpdateCalc(t.calcdata,m);var S=[];if(a&&(t._transitionData={},f.createTransitionData(t),S.push(function(){return r.addFrames(t,a)})),y.transition&&!g&&(M.anim||_.anim))f.doCalcdata(t),T.doAutoRangeAndConstraints(t),S.push(function(){return f.transitionFromReact(t,M,_,p)});else if(M.fullReplot||_.layoutReplot||g)t._fullLayout._skipDefaults=!0,S.push(r.plot);else{for(var E in _.arrays){var L=_.arrays[E];if(L.length){var P=u.getComponentMethod(E,\"drawOne\");if(P!==o.noop)for(var z=0;z<L.length;z++)P(t,L[z]);else{var I=u.getComponentMethod(E,\"draw\");if(I===o.noop)throw new Error(\"cannot draw components: \"+E);I(t)}}}S.push(f.previousPromises),M.style&&S.push(T.doTraceStyle),(M.colorbars||_.colorbars)&&S.push(T.doColorBars),_.legend&&S.push(T.doLegend),_.layoutstyle&&S.push(T.layoutStyles),_.axrange&&Y(S),_.ticks&&S.push(T.doTicksRelayout),_.modebar&&S.push(T.doModeBar),_.camera&&S.push(T.doCamera),S.push(C)}S.push(f.rehover,f.redrag),(l=o.syncOrAsync(S,t))&&l.then||(l=Promise.resolve(t))}else l=r.newPlot(t,e,n,i);return l.then(function(){return t.emit(\"plotly_react\",{data:e,layout:n}),t})},r.redraw=function(t){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);return k.cleanData(t.data),k.cleanLayout(t.layout),t.calcdata=void 0,r.plot(t).then(function(){return t.emit(\"plotly_redraw\"),t})},r.relayout=H,r.restyle=B,r.setPlotConfig=function(t){return o.extendFlat(_,t)},r.update=$,r._guiRelayout=Q(H),r._guiRestyle=Q(B),r._guiUpdate=Q($),r._storeDirectGUIEdit=function(t,e,r){for(var n in r)U(n,s(t,n).get(),r[n],e)}},{\"../components/color\":593,\"../components/drawing\":614,\"../constants/xmlns_namespaces\":696,\"../lib\":719,\"../lib/events\":709,\"../lib/queue\":734,\"../lib/svg_text_utils\":743,\"../plots/cartesian/axes\":767,\"../plots/cartesian/constants\":773,\"../plots/cartesian/graph_interact\":776,\"../plots/cartesian/select\":784,\"../plots/plots\":828,\"../plots/polar/legacy\":836,\"../registry\":847,\"./edit_types\":750,\"./helpers\":751,\"./manage_arrays\":753,\"./plot_config\":755,\"./plot_schema\":756,\"./subroutines\":758,d3:163,\"fast-isnumeric\":225,\"has-hover\":410}],755:[function(t,e,r){\"use strict\";var n={staticPlot:{valType:\"boolean\",dflt:!1},plotlyServerURL:{valType:\"string\",dflt:\"https://plot.ly\"},editable:{valType:\"boolean\",dflt:!1},edits:{annotationPosition:{valType:\"boolean\",dflt:!1},annotationTail:{valType:\"boolean\",dflt:!1},annotationText:{valType:\"boolean\",dflt:!1},axisTitleText:{valType:\"boolean\",dflt:!1},colorbarPosition:{valType:\"boolean\",dflt:!1},colorbarTitleText:{valType:\"boolean\",dflt:!1},legendPosition:{valType:\"boolean\",dflt:!1},legendText:{valType:\"boolean\",dflt:!1},shapePosition:{valType:\"boolean\",dflt:!1},titleText:{valType:\"boolean\",dflt:!1}},autosizable:{valType:\"boolean\",dflt:!1},responsive:{valType:\"boolean\",dflt:!1},fillFrame:{valType:\"boolean\",dflt:!1},frameMargins:{valType:\"number\",dflt:0,min:0,max:.5},scrollZoom:{valType:\"flaglist\",flags:[\"cartesian\",\"gl3d\",\"geo\",\"mapbox\"],extras:[!0,!1],dflt:\"gl3d+geo+mapbox\"},doubleClick:{valType:\"enumerated\",values:[!1,\"reset\",\"autosize\",\"reset+autosize\"],dflt:\"reset+autosize\"},doubleClickDelay:{valType:\"number\",dflt:300,min:0},showAxisDragHandles:{valType:\"boolean\",dflt:!0},showAxisRangeEntryBoxes:{valType:\"boolean\",dflt:!0},showTips:{valType:\"boolean\",dflt:!0},showLink:{valType:\"boolean\",dflt:!1},linkText:{valType:\"string\",dflt:\"Edit chart\",noBlank:!0},sendData:{valType:\"boolean\",dflt:!0},showSources:{valType:\"any\",dflt:!1},displayModeBar:{valType:\"enumerated\",values:[\"hover\",!0,!1],dflt:\"hover\"},showSendToCloud:{valType:\"boolean\",dflt:!1},showEditInChartStudio:{valType:\"boolean\",dflt:!1},modeBarButtonsToRemove:{valType:\"any\",dflt:[]},modeBarButtonsToAdd:{valType:\"any\",dflt:[]},modeBarButtons:{valType:\"any\",dflt:!1},toImageButtonOptions:{valType:\"any\",dflt:{}},displaylogo:{valType:\"boolean\",dflt:!0},watermark:{valType:\"boolean\",dflt:!1},plotGlPixelRatio:{valType:\"number\",dflt:2,min:1,max:4},setBackground:{valType:\"any\",dflt:\"transparent\"},topojsonURL:{valType:\"string\",noBlank:!0,dflt:\"https://cdn.plot.ly/\"},mapboxAccessToken:{valType:\"string\",dflt:null},logging:{valType:\"boolean\",dflt:1},queueLength:{valType:\"integer\",min:0,dflt:0},globalTransforms:{valType:\"any\",dflt:[]},locale:{valType:\"string\",dflt:\"en-US\"},locales:{valType:\"any\",dflt:{}}},i={};!function t(e,r){for(var n in e){var i=e[n];i.valType?r[n]=i.dflt:(r[n]||(r[n]={}),t(i,r[n]))}}(n,i),e.exports={configAttributes:n,dfltConfig:i}},{}],756:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=t(\"../plots/attributes\"),o=t(\"../plots/layout_attributes\"),s=t(\"../plots/frame_attributes\"),l=t(\"../plots/animation_attributes\"),c=t(\"./plot_config\").configAttributes,u=t(\"../plots/polar/legacy/area_attributes\"),h=t(\"../plots/polar/legacy/axis_attributes\"),f=t(\"./edit_types\"),p=i.extendFlat,d=i.extendDeepAll,g=i.isPlainObject,v=i.isArrayOrTypedArray,m=i.nestedProperty,y=i.valObjectMeta,x=\"_isSubplotObj\",b=\"_isLinkedToArray\",_=[x,b,\"_arrayAttrRegexps\",\"_deprecated\"];function w(t,e,r){if(!t)return!1;if(t._isLinkedToArray)if(k(e[r]))r++;else if(r<e.length)return!1;for(;r<e.length;r++){var n=t[e[r]];if(!g(n))break;if(t=n,r===e.length-1)break;if(t._isLinkedToArray){if(!k(e[++r]))return!1}else if(\"info_array\"===t.valType){var i=e[++r];if(!k(i))return!1;var a=t.items;if(Array.isArray(a)){if(i>=a.length)return!1;if(2===t.dimensions){if(r++,e.length===r)return t;var o=e[r];if(!k(o))return!1;t=a[i][o]}else t=a[i]}else t=a}}return t}function k(t){return t===Math.round(t)&&t>=0}function T(t){return function(t){r.crawl(t,function(t,e,n){r.isValObject(t)?\"data_array\"===t.valType?(t.role=\"data\",n[e+\"src\"]={valType:\"string\",editType:\"none\"}):!0===t.arrayOk&&(n[e+\"src\"]={valType:\"string\",editType:\"none\"}):g(t)&&(t.role=\"object\")})}(t),function(t){r.crawl(t,function(t,e,r){if(!t)return;var n=t[b];if(!n)return;delete t[b],r[e]={items:{}},r[e].items[n]=t,r[e].role=\"object\"})}(t),function(t){!function t(e){for(var r in e)if(g(e[r]))t(e[r]);else if(Array.isArray(e[r]))for(var n=0;n<e[r].length;n++)t(e[r][n]);else e[r]instanceof RegExp&&(e[r]=e[r].toString())}(t)}(t),t}function A(t,e,r){var n=m(t,r),i=d({},e.layoutAttributes);i[x]=!0,n.set(i)}function M(t,e,r){var n=m(t,r);n.set(d(n.get()||{},e))}r.IS_SUBPLOT_OBJ=x,r.IS_LINKED_TO_ARRAY=b,r.DEPRECATED=\"_deprecated\",r.UNDERSCORE_ATTRS=_,r.get=function(){var t={};n.allTypes.concat(\"area\").forEach(function(e){t[e]=function(t){var e,i;\"area\"===t?(e={attributes:u},i={}):(e=n.modules[t]._module,i=e.basePlotModule);var o={type:null},s=d({},a),l=d({},e.attributes);r.crawl(l,function(t,e,r,n,i){m(s,i).set(void 0),void 0===t&&m(l,i).set(void 0)}),d(o,s),n.traceIs(t,\"noOpacity\")&&delete o.opacity;n.traceIs(t,\"showLegend\")||(delete o.showlegend,delete o.legendgroup);n.traceIs(t,\"noHover\")&&(delete o.hoverinfo,delete o.hoverlabel);e.selectPoints||delete o.selectedpoints;d(o,l),i.attributes&&d(o,i.attributes);o.type=t;var c={meta:e.meta||{},categories:e.categories||{},animatable:Boolean(e.animatable),type:t,attributes:T(o)};if(e.layoutAttributes){var h={};d(h,e.layoutAttributes),c.layoutAttributes=T(h)}e.animatable||r.crawl(c,function(t){r.isValObject(t)&&\"anim\"in t&&delete t.anim});return c}(e)});var e,i={};return Object.keys(n.transformsRegistry).forEach(function(t){i[t]=function(t){var e=n.transformsRegistry[t],r=d({},e.attributes);return Object.keys(n.componentsRegistry).forEach(function(e){var i=n.componentsRegistry[e];i.schema&&i.schema.transforms&&i.schema.transforms[t]&&Object.keys(i.schema.transforms[t]).forEach(function(e){M(r,i.schema.transforms[t][e],e)})}),{attributes:T(r)}}(t)}),{defs:{valObjects:y,metaKeys:_.concat([\"description\",\"role\",\"editType\",\"impliedEdits\"]),editType:{traces:f.traces,layout:f.layout},impliedEdits:{}},traces:t,layout:function(){var t,e,r={};for(t in d(r,o),n.subplotsRegistry)if((e=n.subplotsRegistry[t]).layoutAttributes)if(Array.isArray(e.attr))for(var i=0;i<e.attr.length;i++)A(r,e,e.attr[i]);else{var a=\"subplot\"===e.attr?e.name:e.attr;A(r,e,a)}for(t in r=function(t){return p(t,{radialaxis:h.radialaxis,angularaxis:h.angularaxis}),p(t,h.layout),t}(r),n.componentsRegistry){var s=(e=n.componentsRegistry[t]).schema;if(s&&(s.subplots||s.layout)){var l=s.subplots;if(l&&l.xaxis&&!l.yaxis)for(var c in l.xaxis)delete r.yaxis[c]}else\"colorscale\"===e.name?d(r,e.layoutAttributes):e.layoutAttributes&&M(r,e.layoutAttributes,e.name)}return{layoutAttributes:T(r)}}(),transforms:i,frames:(e={frames:d({},s)},T(e),e.frames),animation:T(l),config:T(c)}},r.crawl=function(t,e,n,i){var a=n||0;i=i||\"\",Object.keys(t).forEach(function(n){var o=t[n];if(-1===_.indexOf(n)){var s=(i?i+\".\":\"\")+n;e(o,n,t,a,s),r.isValObject(o)||g(o)&&\"impliedEdits\"!==n&&r.crawl(o,e,a+1,s)}})},r.isValObject=function(t){return t&&void 0!==t.valType},r.findArrayAttributes=function(t){var e,n,i=[],o=[],s=[];function l(t,r,a,l){o=o.slice(0,l).concat([r]),s=s.slice(0,l).concat([t&&t._isLinkedToArray]),t&&(\"data_array\"===t.valType||!0===t.arrayOk)&&!(\"colorbar\"===o[l-1]&&(\"ticktext\"===r||\"tickvals\"===r))&&function t(e,r,a){var l=e[o[r]];var c=a+o[r];if(r===o.length-1)v(l)&&i.push(n+c);else if(s[r]){if(Array.isArray(l))for(var u=0;u<l.length;u++)g(l[u])&&t(l[u],r+1,c+\"[\"+u+\"].\")}else g(l)&&t(l,r+1,c+\".\")}(e,0,\"\")}e=t,n=\"\",r.crawl(a,l),t._module&&t._module.attributes&&r.crawl(t._module.attributes,l);var c=t.transforms;if(c)for(var u=0;u<c.length;u++){var h=c[u],f=h._module;f&&(n=\"transforms[\"+u+\"].\",e=h,r.crawl(f.attributes,l))}return i},r.getTraceValObject=function(t,e){var r,i,o=e[0],s=1;if(\"transforms\"===o){if(1===e.length)return a.transforms;var l=t.transforms;if(!Array.isArray(l)||!l.length)return!1;var c=e[1];if(!k(c)||c>=l.length)return!1;i=(r=(n.transformsRegistry[l[c].type]||{}).attributes)&&r[e[2]],s=3}else if(\"area\"===t.type)i=u[o];else{var h=t._module;if(h||(h=(n.modules[t.type||a.type.dflt]||{})._module),!h)return!1;if(!(i=(r=h.attributes)&&r[o])){var f=h.basePlotModule;f&&f.attributes&&(i=f.attributes[o])}i||(i=a[o])}return w(i,e,s)},r.getLayoutValObject=function(t,e){return w(function(t,e){var r,i,a,s,l=t._basePlotModules;if(l){var c;for(r=0;r<l.length;r++){if((a=l[r]).attrRegex&&a.attrRegex.test(e)){if(a.layoutAttrOverrides)return a.layoutAttrOverrides;!c&&a.layoutAttributes&&(c=a.layoutAttributes)}var u=a.baseLayoutAttrOverrides;if(u&&e in u)return u[e]}if(c)return c}var f=t._modules;if(f)for(r=0;r<f.length;r++)if((s=f[r].layoutAttributes)&&e in s)return s[e];for(i in n.componentsRegistry){if(\"colorscale\"===(a=n.componentsRegistry[i]).name&&0===e.indexOf(\"coloraxis\"))return a.layoutAttributes[e];if(!a.schema&&e===a.name)return a.layoutAttributes}if(e in o)return o[e];if(\"radialaxis\"===e||\"angularaxis\"===e)return h[e];return h.layout[e]||!1}(t,e[0]),e,1)}},{\"../lib\":719,\"../plots/animation_attributes\":762,\"../plots/attributes\":764,\"../plots/frame_attributes\":794,\"../plots/layout_attributes\":819,\"../plots/polar/legacy/area_attributes\":834,\"../plots/polar/legacy/axis_attributes\":835,\"../registry\":847,\"./edit_types\":750,\"./plot_config\":755}],757:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/attributes\"),a=\"templateitemname\",o={name:{valType:\"string\",editType:\"none\"}};function s(t){return t&&\"string\"==typeof t}function l(t){var e=t.length-1;return\"s\"!==t.charAt(e)&&n.warn(\"bad argument to arrayDefaultKey: \"+t),t.substr(0,t.length-1)+\"defaults\"}o[a]={valType:\"string\",editType:\"calc\"},r.templatedArray=function(t,e){return e._isLinkedToArray=t,e.name=o.name,e[a]=o[a],e},r.traceTemplater=function(t){var e,r,a={};for(e in t)r=t[e],Array.isArray(r)&&r.length&&(a[e]=0);return{newTrace:function(o){var s={type:e=n.coerce(o,{},i,\"type\"),_template:null};if(e in a){r=t[e];var l=a[e]%r.length;a[e]++,s._template=r[l]}return s}}},r.newContainer=function(t,e,r){var i=t._template,a=i&&(i[e]||r&&i[r]);return n.isPlainObject(a)||(a=null),t[e]={_template:a}},r.arrayTemplater=function(t,e,r){var n=t._template,i=n&&n[l(e)],o=n&&n[e];Array.isArray(o)&&o.length||(o=[]);var c={};return{newItem:function(t){var e={name:t.name,_input:t},n=e[a]=t[a];if(!s(n))return e._template=i,e;for(var l=0;l<o.length;l++){var u=o[l];if(u.name===n)return c[n]=1,e._template=u,e}return e[r]=t[r]||!1,e._template=!1,e},defaultItems:function(){for(var t=[],e=0;e<o.length;e++){var r=o[e],n=r.name;if(s(n)&&!c[n]){var i={_template:r,name:n,_input:{_templateitemname:n}};i[a]=r[a],t.push(i),c[n]=1}}return t}}},r.arrayDefaultKey=l,r.arrayEditor=function(t,e,r){var i=(n.nestedProperty(t,e).get()||[]).length,o=r._index,s=o>=i&&(r._input||{})._templateitemname;s&&(o=i);var l,c=e+\"[\"+o+\"]\";function u(){l={},s&&(l[c]={},l[c][a]=s)}function h(t,e){s?n.nestedProperty(l[c],t).set(e):l[c+\".\"+t]=e}function f(){var t=l;return u(),t}return u(),{modifyBase:function(t,e){l[t]=e},modifyItem:h,getUpdateObj:f,applyUpdate:function(e,r){e&&h(e,r);var i=f();for(var a in i)n.nestedProperty(t,a).set(i[a])}}}},{\"../lib\":719,\"../plots/attributes\":764}],758:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../registry\"),a=t(\"../plots/plots\"),o=t(\"../lib\"),s=t(\"../lib/clear_gl_canvases\"),l=t(\"../components/color\"),c=t(\"../components/drawing\"),u=t(\"../components/titles\"),h=t(\"../components/modebar\"),f=t(\"../plots/cartesian/axes\"),p=t(\"../constants/alignment\"),d=t(\"../plots/cartesian/constraints\"),g=d.enforce,v=d.clean,m=t(\"../plots/cartesian/autorange\").doAutoRange,y=\"start\",x=\"middle\",b=\"end\";function _(t,e,r){for(var n=0;n<r.length;n++){var i=r[n][0],a=r[n][1];if(!(i[0]>=t[1]||i[1]<=t[0])&&(a[0]<e[1]&&a[1]>e[0]))return!0}return!1}function w(t){var e,i,a,s,u,d,g=t._fullLayout,v=g._size,m=v.p,y=f.list(t,\"\",!0);if(g._paperdiv.style({width:t._context.responsive&&g.autosize&&!t._context._hasZeroWidth&&!t.layout.width?\"100%\":g.width+\"px\",height:t._context.responsive&&g.autosize&&!t._context._hasZeroHeight&&!t.layout.height?\"100%\":g.height+\"px\"}).selectAll(\".main-svg\").call(c.setSize,g.width,g.height),t._context.setBackground(t,g.paper_bgcolor),r.drawMainTitle(t),h.manage(t),!g._has(\"cartesian\"))return t._promises.length&&Promise.all(t._promises);function x(t,e,r){var n=t._lw/2;return\"x\"===t._id.charAt(0)?e?\"top\"===r?e._offset-m-n:e._offset+e._length+m+n:v.t+v.h*(1-(t.position||0))+n%1:e?\"right\"===r?e._offset+e._length+m+n:e._offset-m-n:v.l+v.w*(t.position||0)+n%1}for(e=0;e<y.length;e++){var b=(s=y[e])._anchorAxis;s._linepositions={},s._lw=c.crispRound(t,s.linewidth,1),s._mainLinePosition=x(s,b,s.side),s._mainMirrorPosition=s.mirror&&b?x(s,b,p.OPPOSITE_SIDE[s.side]):null}var w=[],T=[],M=[],S=1===l.opacity(g.paper_bgcolor)&&1===l.opacity(g.plot_bgcolor)&&g.paper_bgcolor===g.plot_bgcolor;for(i in g._plots)if((a=g._plots[i]).mainplot)a.bg&&a.bg.remove(),a.bg=void 0;else{var E=a.xaxis.domain,C=a.yaxis.domain,L=a.plotgroup;if(_(E,C,M)){var P=L.node(),O=a.bg=o.ensureSingle(L,\"rect\",\"bg\");P.insertBefore(O.node(),P.childNodes[0]),T.push(i)}else L.select(\"rect.bg\").remove(),M.push([E,C]),S||(w.push(i),T.push(i))}var z,I,D,R,F,B,N,j,U,V,q,H,G,Y=g._bgLayer.selectAll(\".bg\").data(w);for(Y.enter().append(\"rect\").classed(\"bg\",!0),Y.exit().remove(),Y.each(function(t){g._plots[t].bg=n.select(this)}),e=0;e<T.length;e++)a=g._plots[T[e]],u=a.xaxis,d=a.yaxis,a.bg&&a.bg.call(c.setRect,u._offset-m,d._offset-m,u._length+2*m,d._length+2*m).call(l.fill,g.plot_bgcolor).style(\"stroke-width\",0);if(!g._hasOnlyLargeSploms)for(i in g._plots){a=g._plots[i],u=a.xaxis,d=a.yaxis;var W,X,Z=a.clipId=\"clip\"+g._uid+i+\"plot\",J=o.ensureSingleById(g._clips,\"clipPath\",Z,function(t){t.classed(\"plotclip\",!0).append(\"rect\")});a.clipRect=J.select(\"rect\").attr({width:u._length,height:d._length}),c.setTranslate(a.plot,u._offset,d._offset),a._hasClipOnAxisFalse?(W=null,X=Z):(W=Z,X=null),c.setClipUrl(a.plot,W,t),a.layerClipId=X}function K(t){return\"M\"+z+\",\"+t+\"H\"+I}function $(t){return\"M\"+u._offset+\",\"+t+\"h\"+u._length}function Q(t){return\"M\"+t+\",\"+j+\"V\"+N}function tt(t){return\"M\"+t+\",\"+d._offset+\"v\"+d._length}function et(t,e,r){if(!t.showline||i!==t._mainSubplot)return\"\";if(!t._anchorAxis)return r(t._mainLinePosition);var n=e(t._mainLinePosition);return t.mirror&&(n+=e(t._mainMirrorPosition)),n}for(i in g._plots){a=g._plots[i],u=a.xaxis,d=a.yaxis;var rt=\"M0,0\";k(u,i)&&(F=A(u,\"left\",d,y),z=u._offset-(F?m+F:0),B=A(u,\"right\",d,y),I=u._offset+u._length+(B?m+B:0),D=x(u,d,\"bottom\"),R=x(u,d,\"top\"),!(G=!u._anchorAxis||i!==u._mainSubplot)||\"allticks\"!==u.mirror&&\"all\"!==u.mirror||(u._linepositions[i]=[D,R]),rt=et(u,K,$),G&&u.showline&&(\"all\"===u.mirror||\"allticks\"===u.mirror)&&(rt+=K(D)+K(R)),a.xlines.style(\"stroke-width\",u._lw+\"px\").call(l.stroke,u.showline?u.linecolor:\"rgba(0,0,0,0)\")),a.xlines.attr(\"d\",rt);var nt=\"M0,0\";k(d,i)&&(q=A(d,\"bottom\",u,y),N=d._offset+d._length+(q?m:0),H=A(d,\"top\",u,y),j=d._offset-(H?m:0),U=x(d,u,\"left\"),V=x(d,u,\"right\"),!(G=!d._anchorAxis||i!==d._mainSubplot)||\"allticks\"!==d.mirror&&\"all\"!==d.mirror||(d._linepositions[i]=[U,V]),nt=et(d,Q,tt),G&&d.showline&&(\"all\"===d.mirror||\"allticks\"===d.mirror)&&(nt+=Q(U)+Q(V)),a.ylines.style(\"stroke-width\",d._lw+\"px\").call(l.stroke,d.showline?d.linecolor:\"rgba(0,0,0,0)\")),a.ylines.attr(\"d\",nt)}return f.makeClipPaths(t),t._promises.length&&Promise.all(t._promises)}function k(t,e){return(t.ticks||t.showline)&&(e===t._mainSubplot||\"all\"===t.mirror||\"allticks\"===t.mirror)}function T(t,e,r){if(!r.showline||!r._lw)return!1;if(\"all\"===r.mirror||\"allticks\"===r.mirror)return!0;var n=r._anchorAxis;if(!n)return!1;var i=p.FROM_BL[e];return r.side===e?n.domain[i]===t.domain[i]:r.mirror&&n.domain[1-i]===t.domain[1-i]}function A(t,e,r,n){if(T(t,e,r))return r._lw;for(var i=0;i<n.length;i++){var a=n[i];if(a._mainAxis===r._mainAxis&&T(t,e,a))return a._lw}return 0}r.layoutStyles=function(t){return o.syncOrAsync([a.doAutoMargin,w],t)},r.drawMainTitle=function(t){var e=t._fullLayout,r=function(t){var e=t.title,r=x;o.isRightAnchor(e)?r=b:o.isLeftAnchor(e)&&(r=y);return r}(e),n=function(t){var e=t.title,r=\"0em\";o.isTopAnchor(e)?r=p.CAP_SHIFT+\"em\":o.isMiddleAnchor(e)&&(r=p.MID_SHIFT+\"em\");return r}(e);u.draw(t,\"gtitle\",{propContainer:e,propName:\"title.text\",placeholder:e._dfltTitle.plot,attributes:{x:function(t,e){var r=t.title,n=t._size,i=0;e===y?i=r.pad.l:e===b&&(i=-r.pad.r);switch(r.xref){case\"paper\":return n.l+n.w*r.x+i;case\"container\":default:return t.width*r.x+i}}(e,r),y:function(t,e){var r=t.title,n=t._size,i=0;\"0em\"!==e&&e?e===p.CAP_SHIFT+\"em\"&&(i=r.pad.t):i=-r.pad.b;if(\"auto\"===r.y)return n.t/2;switch(r.yref){case\"paper\":return n.t+n.h-n.h*r.y+i;case\"container\":default:return t.height-t.height*r.y+i}}(e,n),\"text-anchor\":r,dy:n}})},r.doTraceStyle=function(t){var e,n=t.calcdata,o=[];for(e=0;e<n.length;e++){var l=n[e],c=l[0]||{},u=c.trace||{},h=u._module||{},f=h.arraysToCalcdata;f&&f(l,u);var p=h.editStyle;p&&o.push({fn:p,cd0:c})}if(o.length){for(e=0;e<o.length;e++){var d=o[e];d.fn(t,d.cd0)}s(t),r.redrawReglTraces(t)}return a.style(t),i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doColorBars=function(t){return i.getComponentMethod(\"colorbar\",\"draw\")(t),a.previousPromises(t)},r.layoutReplot=function(t){var e=t.layout;return t.layout=void 0,i.call(\"plot\",t,\"\",e)},r.doLegend=function(t){return i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doTicksRelayout=function(t){return f.draw(t,\"redraw\"),t._fullLayout._hasOnlyLargeSploms&&(i.subplotsRegistry.splom.updateGrid(t),s(t),r.redrawReglTraces(t)),r.drawMainTitle(t),a.previousPromises(t)},r.doModeBar=function(t){var e=t._fullLayout;h.manage(t);for(var r=0;r<e._basePlotModules.length;r++){var n=e._basePlotModules[r].updateFx;n&&n(t)}return a.previousPromises(t)},r.doCamera=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){var i=e[r[n]],a=i._scene,o=i.camera;a.setCamera(o)}},r.drawData=function(t){var e=t._fullLayout;s(t);for(var n=e._basePlotModules,o=0;o<n.length;o++)n[o].plot(t);return r.redrawReglTraces(t),a.style(t),i.getComponentMethod(\"shapes\",\"draw\")(t),i.getComponentMethod(\"annotations\",\"draw\")(t),e._replotting=!1,a.previousPromises(t)},r.redrawReglTraces=function(t){var e=t._fullLayout;if(e._has(\"regl\")){var r,n,i=t._fullData,a=[],s=[];for(e._hasOnlyLargeSploms&&e._splomGrid.draw(),r=0;r<i.length;r++){var l=i[r];!0===l.visible&&0!==l._length&&(\"splom\"===l.type?e._splomScenes[l.uid].draw():\"scattergl\"===l.type?o.pushUnique(a,l.xaxis+l.yaxis):\"scatterpolargl\"===l.type&&o.pushUnique(s,l.subplot))}for(r=0;r<a.length;r++)(n=e._plots[a[r]])._scene&&n._scene.draw();for(r=0;r<s.length;r++)(n=e[s[r]]._subplot)._scene&&n._scene.draw()}},r.doAutoRangeAndConstraints=function(t){for(var e,r,n=t._fullLayout,i=f.list(t,\"\",!0),a=n._axisMatchGroups||[],s=0;s<i.length;s++)e=i[s],v(t,e),m(t,e);g(t);t:for(var l=0;l<a.length;l++){var c,u=a[l],h=null;for(c in u){if(!1===(e=f.getFromId(t,c)).autorange)continue t;r=o.simpleMap(e.range,e.r2l),h?h[0]<h[1]?(h[0]=Math.min(h[0],r[0]),h[1]=Math.max(h[1],r[1])):(h[0]=Math.max(h[0],r[0]),h[1]=Math.min(h[1],r[1])):h=r}for(c in u)(e=f.getFromId(t,c)).range=o.simpleMap(h,e.l2r),e._input.range=e.range.slice(),e.setScale()}},r.finalDraw=function(t){i.getComponentMethod(\"shapes\",\"draw\")(t),i.getComponentMethod(\"images\",\"draw\")(t),i.getComponentMethod(\"annotations\",\"draw\")(t),i.getComponentMethod(\"rangeslider\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t)},r.drawMarginPushers=function(t){i.getComponentMethod(\"legend\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t),i.getComponentMethod(\"sliders\",\"draw\")(t),i.getComponentMethod(\"updatemenus\",\"draw\")(t),i.getComponentMethod(\"colorbar\",\"draw\")(t)}},{\"../components/color\":593,\"../components/drawing\":614,\"../components/modebar\":652,\"../components/titles\":681,\"../constants/alignment\":688,\"../lib\":719,\"../lib/clear_gl_canvases\":704,\"../plots/cartesian/autorange\":766,\"../plots/cartesian/axes\":767,\"../plots/cartesian/constraints\":774,\"../plots/plots\":828,\"../registry\":847,d3:163}],759:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.isPlainObject,a=t(\"./plot_schema\"),o=t(\"../plots/plots\"),s=t(\"../plots/attributes\"),l=t(\"./plot_template\"),c=t(\"./plot_config\").dfltConfig;function u(t,e){t=n.extendDeep({},t);var r,a,o=Object.keys(t).sort();function s(e,r,n){if(i(r)&&i(e))u(e,r);else if(Array.isArray(r)&&Array.isArray(e)){var o=l.arrayTemplater({_template:t},n);for(a=0;a<r.length;a++){var s=r[a],c=o.newItem(s)._template;c&&u(c,s)}var h=o.defaultItems();for(a=0;a<h.length;a++)r.push(h[a]._template);for(a=0;a<r.length;a++)delete r[a].templateitemname}}for(r=0;r<o.length;r++){var c=o[r],f=t[c];if(c in e?s(f,e[c],c):e[c]=f,h(c)===c)for(var p in e){var d=h(p);p===d||d!==c||p in t||s(f,e[p],c)}}}function h(t){return t.replace(/[0-9]+$/,\"\")}function f(t,e,r,a,o){var s=o&&r(o);for(var c in t){var u=t[c],d=p(t,c,a),g=p(t,c,o),v=r(g);if(!v){var m=h(c);m!==c&&(v=r(g=p(t,m,o)))}if((!s||s!==v)&&!(!v||v._noTemplating||\"data_array\"===v.valType||v.arrayOk&&Array.isArray(u)))if(!v.valType&&i(u))f(u,e,r,d,g);else if(v._isLinkedToArray&&Array.isArray(u))for(var y=!1,x=0,b={},_=0;_<u.length;_++){var w=u[_];if(i(w)){var k=w.name;if(k)b[k]||(f(w,e,r,p(u,x,d),p(u,x,g)),x++,b[k]=1);else if(!y){var T=p(t,l.arrayDefaultKey(c),a),A=p(u,x,d);f(w,e,r,A,p(u,x,g));var M=n.nestedProperty(e,A);n.nestedProperty(e,T).set(M.get()),M.set(null),y=!0}}}else{n.nestedProperty(e,d).set(u)}}}function p(t,e,r){return r?Array.isArray(t)?r+\"[\"+e+\"]\":r+\".\"+e:e}function d(t){for(var e=0;e<t.length;e++)if(i(t[e]))return!0}function g(t){var e;switch(t.code){case\"data\":e=\"The template has no key data.\";break;case\"layout\":e=\"The template has no key layout.\";break;case\"missing\":e=t.path?\"There are no templates for item \"+t.path+\" with name \"+t.templateitemname:\"There are no templates for trace \"+t.index+\", of type \"+t.traceType+\".\";break;case\"unused\":e=t.path?\"The template item at \"+t.path+\" was not used in constructing the plot.\":t.dataCount?\"Some of the templates of type \"+t.traceType+\" were not used. The template has \"+t.templateCount+\" traces, the data only has \"+t.dataCount+\" of this type.\":\"The template has \"+t.templateCount+\" traces of type \"+t.traceType+\" but there are none in the data.\";break;case\"reused\":e=\"Some of the templates of type \"+t.traceType+\" were used more than once. The template has \"+t.templateCount+\" traces, the data has \"+t.dataCount+\" of this type.\"}return t.msg=e,t}r.makeTemplate=function(t){t=n.isPlainObject(t)?t:n.getGraphDiv(t),t=n.extendDeep({_context:c},{data:t.data,layout:t.layout}),o.supplyDefaults(t);var e=t.data||[],r=t.layout||{};r._basePlotModules=t._fullLayout._basePlotModules,r._modules=t._fullLayout._modules;var l={data:{},layout:{}};e.forEach(function(t){var e={};f(t,e,function(t,e){return a.getTraceValObject(t,n.nestedProperty({},e).parts)}.bind(null,t));var r=n.coerce(t,{},s,\"type\"),i=l.data[r];i||(i=l.data[r]=[]),i.push(e)}),f(r,l.layout,function(t,e){return a.getLayoutValObject(t,n.nestedProperty({},e).parts)}.bind(null,r)),delete l.layout.template;var h=r.template;if(i(h)){var p,d,g,v,m,y,x=h.layout;i(x)&&u(x,l.layout);var b=h.data;if(i(b)){for(d in l.data)if(g=b[d],Array.isArray(g)){for(y=(m=l.data[d]).length,v=g.length,p=0;p<y;p++)u(g[p%v],m[p]);for(p=y;p<v;p++)m.push(n.extendDeep({},g[p]))}for(d in b)d in l.data||(l.data[d]=n.extendDeep([],b[d]))}}return l},r.validateTemplate=function(t,e){var r=n.extendDeep({},{_context:c,data:t.data,layout:t.layout}),a=r.layout||{};i(e)||(e=a.template||{});var s=e.layout,l=e.data,u=[];r.layout=a,r.layout.template=e,o.supplyDefaults(r);var f=r._fullLayout,v=r._fullData,m={};if(i(s)?(!function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)&&i(e[n])){var a,o=h(n),s=[];for(a=0;a<r.length;a++)s.push(p(e,n,r[a])),o!==n&&s.push(p(e,o,r[a]));for(a=0;a<s.length;a++)m[s[a]]=1;t(e[n],s)}}(f,[\"layout\"]),function t(e,r){for(var n in e)if(-1===n.indexOf(\"defaults\")&&i(e[n])){var a=p(e,n,r);m[a]?t(e[n],a):u.push({code:\"unused\",path:a})}}(s,\"layout\")):u.push({code:\"layout\"}),i(l)){for(var y,x={},b=0;b<v.length;b++){var _=v[b];x[y=_.type]=(x[y]||0)+1,_._fullInput._template||u.push({code:\"missing\",index:_._fullInput.index,traceType:y})}for(y in l){var w=l[y].length,k=x[y]||0;w>k?u.push({code:\"unused\",traceType:y,templateCount:w,dataCount:k}):k>w&&u.push({code:\"reused\",traceType:y,templateCount:w,dataCount:k})}}else u.push({code:\"data\"});if(function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)){var a=e[n],o=p(e,n,r);i(a)?(Array.isArray(e)&&!1===a._template&&a.templateitemname&&u.push({code:\"missing\",path:o,templateitemname:a.templateitemname}),t(a,o)):Array.isArray(a)&&d(a)&&t(a,o)}}({data:v,layout:f},\"\"),u.length)return u.map(g)}},{\"../lib\":719,\"../plots/attributes\":764,\"../plots/plots\":828,\"./plot_config\":755,\"./plot_schema\":756,\"./plot_template\":757}],760:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./plot_api\"),a=t(\"../lib\"),o=t(\"../snapshot/helpers\"),s=t(\"../snapshot/tosvg\"),l=t(\"../snapshot/svgtoimg\"),c={format:{valType:\"enumerated\",values:[\"png\",\"jpeg\",\"webp\",\"svg\"],dflt:\"png\"},width:{valType:\"number\",min:1},height:{valType:\"number\",min:1},scale:{valType:\"number\",min:0,dflt:1},setBackground:{valType:\"any\",dflt:!1},imageDataOnly:{valType:\"boolean\",dflt:!1}};e.exports=function(t,e){var r,u,h,f;function p(t){return!(t in e)||a.validate(e[t],c[t])}if(e=e||{},a.isPlainObject(t)?(r=t.data||[],u=t.layout||{},h=t.config||{},f={}):(t=a.getGraphDiv(t),r=a.extendDeep([],t.data),u=a.extendDeep({},t.layout),h=t._context,f=t._fullLayout||{}),!p(\"width\")&&null!==e.width||!p(\"height\")&&null!==e.height)throw new Error(\"Height and width should be pixel values.\");if(!p(\"format\"))throw new Error(\"Image format is not jpeg, png, svg or webp.\");var d={};function g(t,r){return a.coerce(e,d,c,t,r)}var v=g(\"format\"),m=g(\"width\"),y=g(\"height\"),x=g(\"scale\"),b=g(\"setBackground\"),_=g(\"imageDataOnly\"),w=document.createElement(\"div\");w.style.position=\"absolute\",w.style.left=\"-5000px\",document.body.appendChild(w);var k=a.extendFlat({},u);m?k.width=m:null===e.width&&n(f.width)&&(k.width=f.width),y?k.height=y:null===e.height&&n(f.height)&&(k.height=f.height);var T=a.extendFlat({},h,{_exportedPlot:!0,staticPlot:!0,setBackground:b}),A=o.getRedrawFunc(w);function M(){return new Promise(function(t){setTimeout(t,o.getDelay(w._fullLayout))})}function S(){return new Promise(function(t,e){var r=s(w,v,x),n=w._fullLayout.width,c=w._fullLayout.height;if(i.purge(w),document.body.removeChild(w),\"svg\"===v)return t(_?r:o.encodeSVG(r));var u=document.createElement(\"canvas\");u.id=a.randstr(),l({format:v,width:n,height:c,scale:x,canvas:u,svg:r,promise:!0}).then(t).catch(e)})}return new Promise(function(t,e){i.plot(w,r,k,T).then(A).then(M).then(S).then(function(e){t(function(t){return _?t.replace(o.IMAGE_URL_PREFIX,\"\"):t}(e))}).catch(function(t){e(t)})})}},{\"../lib\":719,\"../snapshot/helpers\":851,\"../snapshot/svgtoimg\":853,\"../snapshot/tosvg\":855,\"./plot_api\":754,\"fast-isnumeric\":225}],761:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/plots\"),a=t(\"./plot_schema\"),o=t(\"./plot_config\").dfltConfig,s=n.isPlainObject,l=Array.isArray,c=n.isArrayOrTypedArray;function u(t,e,r,i,a,o){o=o||[];for(var h=Object.keys(t),f=0;f<h.length;f++){var v=h[f];if(\"transforms\"!==v){var m=o.slice();m.push(v);var y=t[v],x=e[v],b=g(r,v),_=\"info_array\"===(b||{}).valType,w=\"colorscale\"===(b||{}).valType,k=(b||{}).items;if(d(r,v))if(s(y)&&s(x))u(y,x,b,i,a,m);else if(_&&l(y)){y.length>x.length&&i.push(p(\"unused\",a,m.concat(x.length)));var T,A,M,S,E,C=x.length,L=Array.isArray(k);if(L&&(C=Math.min(C,k.length)),2===b.dimensions)for(A=0;A<C;A++)if(l(y[A])){y[A].length>x[A].length&&i.push(p(\"unused\",a,m.concat(A,x[A].length)));var P=x[A].length;for(T=0;T<(L?Math.min(P,k[A].length):P);T++)M=L?k[A][T]:k,S=y[A][T],E=x[A][T],n.validate(S,M)?E!==S&&E!==+S&&i.push(p(\"dynamic\",a,m.concat(A,T),S,E)):i.push(p(\"value\",a,m.concat(A,T),S))}else i.push(p(\"array\",a,m.concat(A),y[A]));else for(A=0;A<C;A++)M=L?k[A]:k,S=y[A],E=x[A],n.validate(S,M)?E!==S&&E!==+S&&i.push(p(\"dynamic\",a,m.concat(A),S,E)):i.push(p(\"value\",a,m.concat(A),S))}else if(b.items&&!_&&l(y)){var O,z,I=k[Object.keys(k)[0]],D=[];for(O=0;O<x.length;O++){var R=x[O]._index||O;if((z=m.slice()).push(R),s(y[R])&&s(x[O])){D.push(R);var F=y[R],B=x[O];s(F)&&!1!==F.visible&&!1===B.visible?i.push(p(\"invisible\",a,z)):u(F,B,I,i,a,z)}}for(O=0;O<y.length;O++)(z=m.slice()).push(O),s(y[O])?-1===D.indexOf(O)&&i.push(p(\"unused\",a,z)):i.push(p(\"object\",a,z,y[O]))}else!s(y)&&s(x)?i.push(p(\"object\",a,m,y)):c(y)||!c(x)||_||w?v in e?n.validate(y,b)?\"enumerated\"===b.valType&&(b.coerceNumber&&y!==+x||y!==x)&&i.push(p(\"dynamic\",a,m,y,x)):i.push(p(\"value\",a,m,y)):i.push(p(\"unused\",a,m,y)):i.push(p(\"array\",a,m,y));else i.push(p(\"schema\",a,m))}}return i}e.exports=function(t,e){var r,c,h=a.get(),f=[],d={_context:n.extendFlat({},o)};l(t)?(d.data=n.extendDeep([],t),r=t):(d.data=[],r=[],f.push(p(\"array\",\"data\"))),s(e)?(d.layout=n.extendDeep({},e),c=e):(d.layout={},c={},arguments.length>1&&f.push(p(\"object\",\"layout\"))),i.supplyDefaults(d);for(var g=d._fullData,v=r.length,m=0;m<v;m++){var y=r[m],x=[\"data\",m];if(s(y)){var b=g[m],_=b.type,w=h.traces[_].attributes;w.type={valType:\"enumerated\",values:[_]},!1===b.visible&&!1!==y.visible&&f.push(p(\"invisible\",x)),u(y,b,w,f,x);var k=y.transforms,T=b.transforms;if(k){l(k)||f.push(p(\"array\",x,[\"transforms\"])),x.push(\"transforms\");for(var A=0;A<k.length;A++){var M=[\"transforms\",A],S=k[A].type;if(s(k[A])){var E=h.transforms[S]?h.transforms[S].attributes:{};E.type={valType:\"enumerated\",values:Object.keys(h.transforms)},u(k[A],T[A],E,f,x,M)}else f.push(p(\"object\",x,M))}}}else f.push(p(\"object\",x))}return u(c,d._fullLayout,function(t,e){for(var r=t.layout.layoutAttributes,i=0;i<e.length;i++){var a=e[i],o=t.traces[a.type],s=o.layoutAttributes;s&&(a.subplot?n.extendFlat(r[o.attributes.subplot.dflt],s):n.extendFlat(r,s))}return r}(h,g),f,\"layout\"),0===f.length?void 0:f};var h={object:function(t,e){return(\"layout\"===t&&\"\"===e?\"The layout argument\":\"data\"===t[0]&&\"\"===e?\"Trace \"+t[1]+\" in the data argument\":f(t)+\"key \"+e)+\" must be linked to an object container\"},array:function(t,e){return(\"data\"===t?\"The data argument\":f(t)+\"key \"+e)+\" must be linked to an array container\"},schema:function(t,e){return f(t)+\"key \"+e+\" is not part of the schema\"},unused:function(t,e,r){var n=s(r)?\"container\":\"key\";return f(t)+n+\" \"+e+\" did not get coerced\"},dynamic:function(t,e,r,n){return[f(t)+\"key\",e,\"(set to '\"+r+\"')\",\"got reset to\",\"'\"+n+\"'\",\"during defaults.\"].join(\" \")},invisible:function(t,e){return(e?f(t)+\"item \"+e:\"Trace \"+t[1])+\" got defaulted to be not visible\"},value:function(t,e,r){return[f(t)+\"key \"+e,\"is set to an invalid value (\"+r+\")\"].join(\" \")}};function f(t){return l(t)?\"In data trace \"+t[1]+\", \":\"In \"+t+\", \"}function p(t,e,r,i,a){var o,s;r=r||\"\",l(e)?(o=e[0],s=e[1]):(o=e,s=null);var c=function(t){if(!l(t))return String(t);for(var e=\"\",r=0;r<t.length;r++){var n=t[r];\"number\"==typeof n?e=e.substr(0,e.length-1)+\"[\"+n+\"]\":e+=n,r<t.length-1&&(e+=\".\")}return e}(r),u=h[t](e,c,i,a);return n.log(u),{code:t,container:o,trace:s,path:r,astr:c,msg:u}}function d(t,e){var r=m(e),n=r.keyMinusId,i=r.id;return!!(n in t&&t[n]._isSubplotObj&&i)||e in t}function g(t,e){return e in t?t[e]:t[m(e).keyMinusId]}var v=n.counterRegex(\"([a-z]+)\");function m(t){var e=t.match(v);return{keyMinusId:e&&e[1],id:e&&e[2]}}},{\"../lib\":719,\"../plots/plots\":828,\"./plot_config\":755,\"./plot_schema\":756}],762:[function(t,e,r){\"use strict\";e.exports={mode:{valType:\"enumerated\",dflt:\"afterall\",values:[\"immediate\",\"next\",\"afterall\"]},direction:{valType:\"enumerated\",values:[\"forward\",\"reverse\"],dflt:\"forward\"},fromcurrent:{valType:\"boolean\",dflt:!1},frame:{duration:{valType:\"number\",min:0,dflt:500},redraw:{valType:\"boolean\",dflt:!0}},transition:{duration:{valType:\"number\",min:0,dflt:500,editType:\"none\"},easing:{valType:\"enumerated\",dflt:\"cubic-in-out\",values:[\"linear\",\"quad\",\"cubic\",\"sin\",\"exp\",\"circle\",\"elastic\",\"back\",\"bounce\",\"linear-in\",\"quad-in\",\"cubic-in\",\"sin-in\",\"exp-in\",\"circle-in\",\"elastic-in\",\"back-in\",\"bounce-in\",\"linear-out\",\"quad-out\",\"cubic-out\",\"sin-out\",\"exp-out\",\"circle-out\",\"elastic-out\",\"back-out\",\"bounce-out\",\"linear-in-out\",\"quad-in-out\",\"cubic-in-out\",\"sin-in-out\",\"exp-in-out\",\"circle-in-out\",\"elastic-in-out\",\"back-in-out\",\"bounce-in-out\"],editType:\"none\"},ordering:{valType:\"enumerated\",values:[\"layout first\",\"traces first\"],dflt:\"layout first\",editType:\"none\"}}}},{}],763:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\");e.exports=function(t,e,r){var a,o,s=r.name,l=r.inclusionAttr||\"visible\",c=e[s],u=n.isArrayOrTypedArray(t[s])?t[s]:[],h=e[s]=[],f=i.arrayTemplater(e,s,l);for(a=0;a<u.length;a++){var p=u[a];n.isPlainObject(p)?o=f.newItem(p):(o=f.newItem({}))[l]=!1,o._index=a,!1!==o[l]&&r.handleItemDefaults(p,o,e,r),h.push(o)}var d=f.defaultItems();for(a=0;a<d.length;a++)(o=d[a])._index=h.length,r.handleItemDefaults({},o,e,r,{}),h.push(o);if(n.isArrayOrTypedArray(c)){var g=Math.min(c.length,h.length);for(a=0;a<g;a++)n.relinkPrivateKeys(h[a],c[a])}return h}},{\"../lib\":719,\"../plot_api/plot_template\":757}],764:[function(t,e,r){\"use strict\";var n=t(\"../components/fx/attributes\");e.exports={type:{valType:\"enumerated\",values:[],dflt:\"scatter\",editType:\"calc+clearAxisTypes\",_noTemplating:!0},visible:{valType:\"enumerated\",values:[!0,!1,\"legendonly\"],dflt:!0,editType:\"calc\"},showlegend:{valType:\"boolean\",dflt:!0,editType:\"style\"},legendgroup:{valType:\"string\",dflt:\"\",editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"style\"},name:{valType:\"string\",editType:\"style\"},uid:{valType:\"string\",editType:\"plot\",anim:!0},ids:{valType:\"data_array\",editType:\"calc\",anim:!0},customdata:{valType:\"data_array\",editType:\"calc\"},meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},selectedpoints:{valType:\"any\",editType:\"calc\"},hoverinfo:{valType:\"flaglist\",flags:[\"x\",\"y\",\"z\",\"text\",\"name\"],extras:[\"all\",\"none\",\"skip\"],arrayOk:!0,dflt:\"all\",editType:\"none\"},hoverlabel:n.hoverlabel,stream:{token:{valType:\"string\",noBlank:!0,strict:!0,editType:\"calc\"},maxpoints:{valType:\"number\",min:0,max:1e4,dflt:500,editType:\"calc\"},editType:\"calc\"},transforms:{_isLinkedToArray:\"transform\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"}}},{\"../components/fx/attributes\":623}],765:[function(t,e,r){\"use strict\";e.exports={xaxis:{valType:\"subplotid\",dflt:\"x\",editType:\"calc+clearAxisTypes\"},yaxis:{valType:\"subplotid\",dflt:\"y\",editType:\"calc+clearAxisTypes\"}}},{}],766:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").FP_SAFE,o=t(\"../../registry\");function s(t,e){var r,n,a=[],o=l(e),s=c(t,e),u=s.min,h=s.max;if(0===u.length||0===h.length)return i.simpleMap(e.range,e.r2l);var f=u[0].val,p=h[0].val;for(r=1;r<u.length&&f===p;r++)f=Math.min(f,u[r].val);for(r=1;r<h.length&&f===p;r++)p=Math.max(p,h[r].val);var d=!1;if(e.range){var g=i.simpleMap(e.range,e.r2l);d=g[1]<g[0]}\"reversed\"===e.autorange&&(d=!0,e.autorange=!0);var v,m,y,x,b,_,w=e.rangemode,k=\"tozero\"===w,T=\"nonnegative\"===w,A=e._length,M=A/10,S=0;for(r=0;r<u.length;r++)for(v=u[r],n=0;n<h.length;n++)(_=(m=h[n]).val-v.val)>0&&((b=A-o(v)-o(m))>M?_/b>S&&(y=v,x=m,S=_/b):_/A>S&&(y={val:v.val,pad:0},x={val:m.val,pad:0},S=_/A));if(f===p){var E=f-1,C=f+1;if(k)if(0===f)a=[0,1];else{var L=(f>0?h:u).reduce(function(t,e){return Math.max(t,o(e))},0),P=f/(1-Math.min(.5,L/A));a=f>0?[0,P]:[P,0]}else a=T?[Math.max(0,E),Math.max(1,C)]:[E,C]}else k?(y.val>=0&&(y={val:0,pad:0}),x.val<=0&&(x={val:0,pad:0})):T&&(y.val-S*o(y)<0&&(y={val:0,pad:0}),x.val<=0&&(x={val:1,pad:0})),S=(x.val-y.val)/(A-o(y)-o(x)),a=[y.val-S*o(y),x.val+S*o(x)];return d&&a.reverse(),i.simpleMap(a,e.l2r||Number)}function l(t){var e=t._length/20;return\"domain\"===t.constrain&&t._inputDomain&&(e*=(t._inputDomain[1]-t._inputDomain[0])/(t.domain[1]-t.domain[0])),function(t){return t.pad+(t.extrapad?e:0)}}function c(t,e){var r,n,i,a=e._id,o=t._fullData,s=t._fullLayout,l=[],c=[];function f(t,e){for(r=0;r<e.length;r++){var o=t[e[r]],s=(o._extremes||{})[a];if(!0===o.visible&&s){for(n=0;n<s.min.length;n++)i=s.min[n],u(l,i.val,i.pad,{extrapad:i.extrapad});for(n=0;n<s.max.length;n++)i=s.max[n],h(c,i.val,i.pad,{extrapad:i.extrapad})}}}return f(o,e._traceIndices),f(s.annotations||[],e._annIndices||[]),f(s.shapes||[],e._shapeIndices||[]),{min:l,max:c}}function u(t,e,r,n){f(t,e,r,n,d)}function h(t,e,r,n){f(t,e,r,n,g)}function f(t,e,r,n,i){for(var a=n.tozero,o=n.extrapad,s=!0,l=0;l<t.length&&s;l++){var c=t[l];if(i(c.val,e)&&c.pad>=r&&(c.extrapad||!o)){s=!1;break}i(e,c.val)&&c.pad<=r&&(o||!c.extrapad)&&(t.splice(l,1),l--)}if(s){var u=a&&0===e;t.push({val:e,pad:u?0:r,extrapad:!u&&o})}}function p(t){return n(t)&&Math.abs(t)<a}function d(t,e){return t<=e}function g(t,e){return t>=e}e.exports={getAutoRange:s,makePadFn:l,doAutoRange:function(t,e){if(e.setScale(),e.autorange){e.range=s(t,e),e._r=e.range.slice(),e._rl=i.simpleMap(e._r,e.r2l);var r=e._input,n={};n[e._attr+\".range\"]=e.range,n[e._attr+\".autorange\"]=e.autorange,o.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,n),r.range=e.range.slice(),r.autorange=e.autorange}var a=e._anchorAxis;if(a&&a.rangeslider){var l=a.rangeslider[e._name];l&&\"auto\"===l.rangemode&&(l.range=s(t,e)),a._input.rangeslider[e._name]=i.extendFlat({},l)}},findExtremes:function(t,e,r){r||(r={});t._m||t.setScale();var i,o,s,l,c,f,d,g,v,m=[],y=[],x=e.length,b=r.padded||!1,_=r.tozero&&(\"linear\"===t.type||\"-\"===t.type),w=\"log\"===t.type,k=!1;function T(t){if(Array.isArray(t))return k=!0,function(e){return Math.max(Number(t[e]||0),0)};var e=Math.max(Number(t||0),0);return function(){return e}}var A=T((t._m>0?r.ppadplus:r.ppadminus)||r.ppad||0),M=T((t._m>0?r.ppadminus:r.ppadplus)||r.ppad||0),S=T(r.vpadplus||r.vpad),E=T(r.vpadminus||r.vpad);if(!k){if(g=1/0,v=-1/0,w)for(i=0;i<x;i++)(o=e[i])<g&&o>0&&(g=o),o>v&&o<a&&(v=o);else for(i=0;i<x;i++)(o=e[i])<g&&o>-a&&(g=o),o>v&&o<a&&(v=o);e=[g,v],x=2}var C={tozero:_,extrapad:b};function L(r){s=e[r],n(s)&&(f=A(r),d=M(r),g=s-E(r),v=s+S(r),w&&g<v/10&&(g=v/10),l=t.c2l(g),c=t.c2l(v),_&&(l=Math.min(0,l),c=Math.max(0,c)),p(l)&&u(m,l,d,C),p(c)&&h(y,c,f,C))}var P=Math.min(6,x);for(i=0;i<P;i++)L(i);for(i=x-1;i>=P;i--)L(i);return{min:m,max:y,opts:r}},concatExtremes:c}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../registry\":847,\"fast-isnumeric\":225}],767:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../components/titles\"),u=t(\"../../components/color\"),h=t(\"../../components/drawing\"),f=t(\"./layout_attributes\"),p=t(\"./clean_ticks\"),d=t(\"../../constants/numerical\"),g=d.ONEAVGYEAR,v=d.ONEAVGMONTH,m=d.ONEDAY,y=d.ONEHOUR,x=d.ONEMIN,b=d.ONESEC,_=d.MINUS_SIGN,w=d.BADNUM,k=t(\"../../constants/alignment\").MID_SHIFT,T=t(\"../../constants/alignment\").LINE_SPACING,A=e.exports={};A.setConvert=t(\"./set_convert\");var M=t(\"./axis_autotype\"),S=t(\"./axis_ids\");A.id2name=S.id2name,A.name2id=S.name2id,A.cleanId=S.cleanId,A.list=S.list,A.listIds=S.listIds,A.getFromId=S.getFromId,A.getFromTrace=S.getFromTrace;var E=t(\"./autorange\");A.getAutoRange=E.getAutoRange,A.findExtremes=E.findExtremes,A.coerceRef=function(t,e,r,n,i,a){var o=n.charAt(n.length-1),l=r._fullLayout._subplots[o+\"axis\"],c=n+\"ref\",u={};return i||(i=l[0]||a),a||(a=i),u[c]={valType:\"enumerated\",values:l.concat(a?[a]:[]),dflt:i},s.coerce(t,e,u,c)},A.coercePosition=function(t,e,r,n,i,a){var o,l;if(\"paper\"===n||\"pixel\"===n)o=s.ensureNumber,l=r(i,a);else{var c=A.getFromId(e,n);l=r(i,a=c.fraction2r(a)),o=c.cleanPos}t[i]=o(l)},A.cleanPosition=function(t,e,r){return(\"paper\"===r||\"pixel\"===r?s.ensureNumber:A.getFromId(e,r).cleanPos)(t)},A.redrawComponents=function(t,e){e=e||A.listIds(t);var r=t._fullLayout;function n(n,i,a,s){for(var l=o.getComponentMethod(n,i),c={},u=0;u<e.length;u++)for(var h=r[A.id2name(e[u])][a],f=0;f<h.length;f++){var p=h[f];if(!c[p]&&(l(t,p),c[p]=1,s))return}}n(\"annotations\",\"drawOne\",\"_annIndices\"),n(\"shapes\",\"drawOne\",\"_shapeIndices\"),n(\"images\",\"draw\",\"_imgIndices\",!0)};var C=A.getDataConversions=function(t,e,r,n){var i,a=\"x\"===r||\"y\"===r||\"z\"===r?r:n;if(Array.isArray(a)){if(i={type:M(n),_categories:[]},A.setConvert(i),\"category\"===i.type)for(var o=0;o<n.length;o++)i.d2c(n[o])}else i=A.getFromTrace(t,e,a);return i?{d2c:i.d2c,c2d:i.c2d}:\"ids\"===a?{d2c:P,c2d:P}:{d2c:L,c2d:L}};function L(t){return+t}function P(t){return String(t)}A.getDataToCoordFunc=function(t,e,r,n){return C(t,e,r,n).d2c},A.counterLetter=function(t){var e=t.charAt(0);return\"x\"===e?\"y\":\"y\"===e?\"x\":void 0},A.minDtick=function(t,e,r,n){-1===[\"log\",\"category\",\"multicategory\"].indexOf(t.type)&&n?void 0===t._minDtick?(t._minDtick=e,t._forceTick0=r):t._minDtick&&((t._minDtick/e+1e-6)%1<2e-6&&((r-t._forceTick0)/e%1+1.000001)%1<2e-6?(t._minDtick=e,t._forceTick0=r):((e/t._minDtick+1e-6)%1>2e-6||((r-t._forceTick0)/t._minDtick%1+1.000001)%1>2e-6)&&(t._minDtick=0)):t._minDtick=0},A.saveRangeInitial=function(t,e){for(var r=A.list(t,\"\",!0),n=!1,i=0;i<r.length;i++){var a=r[i],o=void 0===a._rangeInitial,s=o||!(a.range[0]===a._rangeInitial[0]&&a.range[1]===a._rangeInitial[1]);(o&&!1===a.autorange||e&&s)&&(a._rangeInitial=a.range.slice(),n=!0)}return n},A.saveShowSpikeInitial=function(t,e){for(var r=A.list(t,\"\",!0),n=!1,i=\"on\",a=0;a<r.length;a++){var o=r[a],s=void 0===o._showSpikeInitial,l=s||!(o.showspikes===o._showspikes);(s||e&&l)&&(o._showSpikeInitial=o.showspikes,n=!0),\"on\"!==i||o.showspikes||(i=\"off\")}return t._fullLayout._cartesianSpikesEnabled=i,n},A.autoBin=function(t,e,r,n,a,o){var l,c=s.aggNums(Math.min,null,t),u=s.aggNums(Math.max,null,t);if(\"category\"===e.type||\"multicategory\"===e.type)return{start:c-.5,end:u+.5,size:Math.max(1,Math.round(o)||1),_dataSpan:u-c};if(a||(a=e.calendar),l=\"log\"===e.type?{type:\"linear\",range:[c,u]}:{type:e.type,range:s.simpleMap([c,u],e.c2r,0,a),calendar:a},A.setConvert(l),o=o&&p.dtick(o,l.type))l.dtick=o,l.tick0=p.tick0(void 0,l.type,a);else{var h;if(r)h=(u-c)/r;else{var f=s.distinctVals(t),d=Math.pow(10,Math.floor(Math.log(f.minDiff)/Math.LN10)),g=d*s.roundUp(f.minDiff/d,[.9,1.9,4.9,9.9],!0);h=Math.max(g,2*s.stdev(t)/Math.pow(t.length,n?.25:.4)),i(h)||(h=1)}A.autoTicks(l,h)}var v,y=l.dtick,x=A.tickIncrement(A.tickFirst(l),y,\"reverse\",a);if(\"number\"==typeof y)v=(x=function(t,e,r,n,a){var o=0,s=0,l=0,c=0;function u(e){return(1+100*(e-t)/r.dtick)%100<2}for(var h=0;h<e.length;h++)e[h]%1==0?l++:i(e[h])||c++,u(e[h])&&o++,u(e[h]+r.dtick/2)&&s++;var f=e.length-c;if(l===f&&\"date\"!==r.type)r.dtick<1?t=n-.5*r.dtick:(t-=.5)+r.dtick<n&&(t+=r.dtick);else if(s<.1*f&&(o>.3*f||u(n)||u(a))){var p=r.dtick/2;t+=t+p<n?p:-p}return t}(x,t,l,c,u))+(1+Math.floor((u-x)/y))*y;else for(\"M\"===l.dtick.charAt(0)&&(x=function(t,e,r,n,i){var a=s.findExactDates(e,i);if(a.exactDays>.8){var o=Number(r.substr(1));a.exactYears>.8&&o%12==0?t=A.tickIncrement(t,\"M6\",\"reverse\")+1.5*m:a.exactMonths>.8?t=A.tickIncrement(t,\"M1\",\"reverse\")+15.5*m:t-=m/2;var l=A.tickIncrement(t,r);if(l<=n)return l}return t}(x,t,y,c,a)),v=x,0;v<=u;)v=A.tickIncrement(v,y,!1,a),0;return{start:e.c2r(x,0,a),end:e.c2r(v,0,a),size:y,_dataSpan:u-c}},A.prepTicks=function(t){var e=s.simpleMap(t.range,t.r2l);if(\"auto\"===t.tickmode||!t.dtick){var r,n=t.nticks;n||(\"category\"===t.type||\"multicategory\"===t.type?(r=t.tickfont?1.2*(t.tickfont.size||12):15,n=t._length/r):(r=\"y\"===t._id.charAt(0)?40:80,n=s.constrain(t._length/r,4,9)+1),\"radialaxis\"===t._name&&(n*=2)),\"array\"===t.tickmode&&(n*=100),A.autoTicks(t,Math.abs(e[1]-e[0])/n),t._minDtick>0&&t.dtick<2*t._minDtick&&(t.dtick=t._minDtick,t.tick0=t.l2r(t._forceTick0))}t.tick0||(t.tick0=\"date\"===t.type?\"2000-01-01\":0),\"date\"===t.type&&t.dtick<.1&&(t.dtick=.1),j(t)},A.calcTicks=function(t){A.prepTicks(t);var e=s.simpleMap(t.range,t.r2l);if(\"array\"===t.tickmode)return function(t){var e=t.tickvals,r=t.ticktext,n=new Array(e.length),i=s.simpleMap(t.range,t.r2l),a=1.0001*i[0]-1e-4*i[1],o=1.0001*i[1]-1e-4*i[0],l=Math.min(a,o),c=Math.max(a,o),u=0;Array.isArray(r)||(r=[]);var h=\"category\"===t.type?t.d2l_noadd:t.d2l;\"log\"===t.type&&\"L\"!==String(t.dtick).charAt(0)&&(t.dtick=\"L\"+Math.pow(10,Math.floor(Math.min(t.range[0],t.range[1]))-1));for(var f=0;f<e.length;f++){var p=h(e[f]);p>l&&p<c&&(void 0===r[f]?n[u]=A.tickText(t,p):n[u]=U(t,p,String(r[f])),u++)}u<e.length&&n.splice(u,e.length-u);return n}(t);t._tmin=A.tickFirst(t);var r=1.0001*e[0]-1e-4*e[1],n=1.0001*e[1]-1e-4*e[0],a=e[1]<e[0];if(t._tmin<r!==a)return[];var o=[];\"category\"!==t.type&&\"multicategory\"!==t.type||(n=a?Math.max(-.5,n):Math.min(t._categories.length-.5,n));for(var l=\"log\"===t.type&&!(i(t.dtick)||\"L\"===t.dtick.charAt(0)),c=null,u=Math.max(1e3,t._length||0),h=t._tmin;(a?h>=n:h<=n)&&!(o.length>u||h===c);h=A.tickIncrement(h,t.dtick,a,t.calendar)){c=h;var f=!1;l&&h!==(0|h)&&(f=!0),o.push({minor:f,value:h})}rt(t)&&360===Math.abs(e[1]-e[0])&&o.pop(),t._tmax=(o[o.length-1]||{}).value,t._prevDateHead=\"\",t._inCalcTicks=!0;for(var p=new Array(o.length),d=0;d<o.length;d++)p[d]=A.tickText(t,o[d].value,!1,o[d].minor);return t._inCalcTicks=!1,p};var O=[2,5,10],z=[1,2,3,6,12],I=[1,2,5,10,15,30],D=[1,2,3,7,14],R=[-.046,0,.301,.477,.602,.699,.778,.845,.903,.954,1],F=[-.301,0,.301,.699,1],B=[15,30,45,90,180];function N(t,e,r){return e*s.roundUp(t/e,r)}function j(t){var e=t.dtick;if(t._tickexponent=0,i(e)||\"string\"==typeof e||(e=1),\"category\"!==t.type&&\"multicategory\"!==t.type||(t._tickround=null),\"date\"===t.type){var r=t.r2l(t.tick0),n=t.l2r(r).replace(/(^-|i)/g,\"\"),a=n.length;if(\"M\"===String(e).charAt(0))a>10||\"01-01\"!==n.substr(5)?t._tickround=\"d\":t._tickround=+e.substr(1)%12==0?\"y\":\"m\";else if(e>=m&&a<=10||e>=15*m)t._tickround=\"d\";else if(e>=x&&a<=16||e>=y)t._tickround=\"M\";else if(e>=b&&a<=19||e>=x)t._tickround=\"S\";else{var o=t.l2r(r+e).replace(/^-/,\"\").length;t._tickround=Math.max(a,o)-20,t._tickround<0&&(t._tickround=4)}}else if(i(e)||\"L\"===e.charAt(0)){var s=t.range.map(t.r2d||Number);i(e)||(e=Number(e.substr(1))),t._tickround=2-Math.floor(Math.log(e)/Math.LN10+.01);var l=Math.max(Math.abs(s[0]),Math.abs(s[1])),c=Math.floor(Math.log(l)/Math.LN10+.01);Math.abs(c)>3&&(q(t.exponentformat)&&!H(c)?t._tickexponent=3*Math.round((c-1)/3):t._tickexponent=c)}else t._tickround=null}function U(t,e,r){var n=t.tickfont||{};return{x:e,dx:0,dy:0,text:r||\"\",fontSize:n.size,font:n.family,fontColor:n.color}}A.autoTicks=function(t,e){var r;function n(t){return Math.pow(t,Math.floor(Math.log(e)/Math.LN10))}if(\"date\"===t.type){t.tick0=s.dateTick0(t.calendar);var a=2*e;a>g?(e/=g,r=n(10),t.dtick=\"M\"+12*N(e,r,O)):a>v?(e/=v,t.dtick=\"M\"+N(e,1,z)):a>m?(t.dtick=N(e,m,D),t.tick0=s.dateTick0(t.calendar,!0)):a>y?t.dtick=N(e,y,z):a>x?t.dtick=N(e,x,I):a>b?t.dtick=N(e,b,I):(r=n(10),t.dtick=N(e,r,O))}else if(\"log\"===t.type){t.tick0=0;var o=s.simpleMap(t.range,t.r2l);if(e>.7)t.dtick=Math.ceil(e);else if(Math.abs(o[1]-o[0])<1){var l=1.5*Math.abs((o[1]-o[0])/e);e=Math.abs(Math.pow(10,o[1])-Math.pow(10,o[0]))/l,r=n(10),t.dtick=\"L\"+N(e,r,O)}else t.dtick=e>.3?\"D2\":\"D1\"}else\"category\"===t.type||\"multicategory\"===t.type?(t.tick0=0,t.dtick=Math.ceil(Math.max(e,1))):rt(t)?(t.tick0=0,r=1,t.dtick=N(e,r,B)):(t.tick0=0,r=n(10),t.dtick=N(e,r,O));if(0===t.dtick&&(t.dtick=1),!i(t.dtick)&&\"string\"!=typeof t.dtick){var c=t.dtick;throw t.dtick=1,\"ax.dtick error: \"+String(c)}},A.tickIncrement=function(t,e,r,a){var o=r?-1:1;if(i(e))return t+o*e;var l=e.charAt(0),c=o*Number(e.substr(1));if(\"M\"===l)return s.incrementMonth(t,c,a);if(\"L\"===l)return Math.log(Math.pow(10,t)+c)/Math.LN10;if(\"D\"===l){var u=\"D2\"===e?F:R,h=t+.01*o,f=s.roundUp(s.mod(h,1),u,r);return Math.floor(h)+Math.log(n.round(Math.pow(10,f),1))/Math.LN10}throw\"unrecognized dtick \"+String(e)},A.tickFirst=function(t){var e=t.r2l||Number,r=s.simpleMap(t.range,e),a=r[1]<r[0],o=a?Math.floor:Math.ceil,l=1.0001*r[0]-1e-4*r[1],c=t.dtick,u=e(t.tick0);if(i(c)){var h=o((l-u)/c)*c+u;return\"category\"!==t.type&&\"multicategory\"!==t.type||(h=s.constrain(h,0,t._categories.length-1)),h}var f=c.charAt(0),p=Number(c.substr(1));if(\"M\"===f){for(var d,g,v,m=0,y=u;m<10;){if(((d=A.tickIncrement(y,c,a,t.calendar))-l)*(y-l)<=0)return a?Math.min(y,d):Math.max(y,d);g=(l-(y+d)/2)/(d-y),v=f+(Math.abs(Math.round(g))||1)*p,y=A.tickIncrement(y,v,g<0?!a:a,t.calendar),m++}return s.error(\"tickFirst did not converge\",t),y}if(\"L\"===f)return Math.log(o((Math.pow(10,l)-u)/p)*p+u)/Math.LN10;if(\"D\"===f){var x=\"D2\"===c?F:R,b=s.roundUp(s.mod(l,1),x,a);return Math.floor(l)+Math.log(n.round(Math.pow(10,b),1))/Math.LN10}throw\"unrecognized dtick \"+String(c)},A.tickText=function(t,e,r,n){var a,o=U(t,e),l=\"array\"===t.tickmode,c=r||l,u=t.type,h=\"category\"===u?t.d2l_noadd:t.d2l;if(l&&Array.isArray(t.ticktext)){var f=s.simpleMap(t.range,t.r2l),p=Math.abs(f[1]-f[0])/1e4;for(a=0;a<t.ticktext.length&&!(Math.abs(e-h(t.tickvals[a]))<p);a++);if(a<t.ticktext.length)return o.text=String(t.ticktext[a]),o}function d(n){if(void 0===n)return!0;if(r)return\"none\"===n;var i={first:t._tmin,last:t._tmax}[n];return\"all\"!==n&&e!==i}var g=r?\"never\":\"none\"!==t.exponentformat&&d(t.showexponent)?\"hide\":\"\";if(\"date\"===u?function(t,e,r,n){var a=t._tickround,o=r&&t.hoverformat||A.getTickFormat(t);n&&(a=i(a)?4:{y:\"m\",m:\"d\",d:\"M\",M:\"S\",S:4}[a]);var l,c=s.formatDate(e.x,o,a,t._dateFormat,t.calendar,t._extraFormat),u=c.indexOf(\"\\n\");-1!==u&&(l=c.substr(u+1),c=c.substr(0,u));n&&(\"00:00:00\"===c||\"00:00\"===c?(c=l,l=\"\"):8===c.length&&(c=c.replace(/:00$/,\"\")));l&&(r?\"d\"===a?c+=\", \"+l:c=l+(c?\", \"+c:\"\"):t._inCalcTicks&&l===t._prevDateHead||(c+=\"<br>\"+l,t._prevDateHead=l));e.text=c}(t,o,r,c):\"log\"===u?function(t,e,r,n,a){var o=t.dtick,l=e.x,c=t.tickformat,u=\"string\"==typeof o&&o.charAt(0);\"never\"===a&&(a=\"\");n&&\"L\"!==u&&(o=\"L3\",u=\"L\");if(c||\"L\"===u)e.text=G(Math.pow(10,l),t,a,n);else if(i(o)||\"D\"===u&&s.mod(l+.01,1)<.1){var h=Math.round(l),f=Math.abs(h),p=t.exponentformat;\"power\"===p||q(p)&&H(h)?(e.text=0===h?1:1===h?\"10\":\"10<sup>\"+(h>1?\"\":_)+f+\"</sup>\",e.fontSize*=1.25):(\"e\"===p||\"E\"===p)&&f>2?e.text=\"1\"+p+(h>0?\"+\":_)+f:(e.text=G(Math.pow(10,l),t,\"\",\"fakehover\"),\"D1\"===o&&\"y\"===t._id.charAt(0)&&(e.dy-=e.fontSize/6))}else{if(\"D\"!==u)throw\"unrecognized dtick \"+String(o);e.text=String(Math.round(Math.pow(10,s.mod(l,1)))),e.fontSize*=.75}if(\"D1\"===t.dtick){var d=String(e.text).charAt(0);\"0\"!==d&&\"1\"!==d||(\"y\"===t._id.charAt(0)?e.dx-=e.fontSize/4:(e.dy+=e.fontSize/2,e.dx+=(t.range[1]>t.range[0]?1:-1)*e.fontSize*(l<0?.5:.25)))}}(t,o,0,c,g):\"category\"===u?function(t,e){var r=t._categories[Math.round(e.x)];void 0===r&&(r=\"\");e.text=String(r)}(t,o):\"multicategory\"===u?function(t,e,r){var n=Math.round(e.x),i=t._categories[n]||[],a=void 0===i[1]?\"\":String(i[1]),o=void 0===i[0]?\"\":String(i[0]);r?e.text=o+\" - \"+a:(e.text=a,e.text2=o)}(t,o,r):rt(t)?function(t,e,r,n,i){if(\"radians\"!==t.thetaunit||r)e.text=G(e.x,t,i,n);else{var a=e.x/180;if(0===a)e.text=\"0\";else{var o=function(t){function e(t,e){return Math.abs(t-e)<=1e-6}var r=function(t){var r=1;for(;!e(Math.round(t*r)/r,t);)r*=10;return r}(t),n=t*r,i=Math.abs(function t(r,n){return e(n,0)?r:t(n,r%n)}(n,r));return[Math.round(n/i),Math.round(r/i)]}(a);if(o[1]>=100)e.text=G(s.deg2rad(e.x),t,i,n);else{var l=e.x<0;1===o[1]?1===o[0]?e.text=\"\\u03c0\":e.text=o[0]+\"\\u03c0\":e.text=[\"<sup>\",o[0],\"</sup>\",\"\\u2044\",\"<sub>\",o[1],\"</sub>\",\"\\u03c0\"].join(\"\"),l&&(e.text=_+e.text)}}}}(t,o,r,c,g):function(t,e,r,n,i){\"never\"===i?i=\"\":\"all\"===t.showexponent&&Math.abs(e.x/t.dtick)<1e-6&&(i=\"hide\");e.text=G(e.x,t,i,n)}(t,o,0,c,g),n||(t.tickprefix&&!d(t.showtickprefix)&&(o.text=t.tickprefix+o.text),t.ticksuffix&&!d(t.showticksuffix)&&(o.text+=t.ticksuffix)),\"boundaries\"===t.tickson||t.showdividers){var v=function(e){var r=t.l2p(e);return r>=0&&r<=t._length?e:null};o.xbnd=[v(o.x-.5),v(o.x+t.dtick-.5)]}return o},A.hoverLabelText=function(t,e,r){if(r!==w&&r!==e)return A.hoverLabelText(t,e)+\" - \"+A.hoverLabelText(t,r);var n=\"log\"===t.type&&e<=0,i=A.tickText(t,t.c2l(n?-e:e),\"hover\").text;return n?0===e?\"0\":_+i:i};var V=[\"f\",\"p\",\"n\",\"\\u03bc\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\"];function q(t){return\"SI\"===t||\"B\"===t}function H(t){return t>14||t<-15}function G(t,e,r,n){var a=t<0,o=e._tickround,l=r||e.exponentformat||\"B\",c=e._tickexponent,u=A.getTickFormat(e),h=e.separatethousands;if(n){var f={exponentformat:l,dtick:\"none\"===e.showexponent?e.dtick:i(t)&&Math.abs(t)||1,range:\"none\"===e.showexponent?e.range.map(e.r2d):[0,t||1]};j(f),o=(Number(f._tickround)||0)+4,c=f._tickexponent,e.hoverformat&&(u=e.hoverformat)}if(u)return e._numFormat(u)(t).replace(/-/g,_);var p,d=Math.pow(10,-o)/2;if(\"none\"===l&&(c=0),(t=Math.abs(t))<d)t=\"0\",a=!1;else{if(t+=d,c&&(t*=Math.pow(10,-c),o+=c),0===o)t=String(Math.floor(t));else if(o<0){t=(t=String(Math.round(t))).substr(0,t.length+o);for(var g=o;g<0;g++)t+=\"0\"}else{var v=(t=String(t)).indexOf(\".\")+1;v&&(t=t.substr(0,v+o).replace(/\\.?0+$/,\"\"))}t=s.numSeparate(t,e._separators,h)}c&&\"hide\"!==l&&(q(l)&&H(c)&&(l=\"power\"),p=c<0?_+-c:\"power\"!==l?\"+\"+c:String(c),\"e\"===l||\"E\"===l?t+=l+p:\"power\"===l?t+=\"\\xd710<sup>\"+p+\"</sup>\":\"B\"===l&&9===c?t+=\"B\":q(l)&&(t+=V[c/3+5]));return a?_+t:t}function Y(t,e){var r=t._id.charAt(0),n=t._tickAngles[e]||0,i=s.deg2rad(n),a=Math.sin(i),o=Math.cos(i),l=0,c=0;return t._selections[e].each(function(){var t=J(this),e=h.bBox(t.node()),r=e.width,n=e.height;l=Math.max(l,o*r,a*n),c=Math.max(c,a*r,o*n)}),{x:c,y:l}[r]}function W(t){return[t.text,t.x,t.axInfo,t.font,t.fontSize,t.fontColor].join(\"_\")}function X(t,e){var r,n=t._fullLayout._size,i=e._id.charAt(0),a=e.side;return\"free\"!==e.anchor?r=S.getFromId(t,e.anchor):\"x\"===i?r={_offset:n.t+(1-(e.position||0))*n.h,_length:0}:\"y\"===i&&(r={_offset:n.l+(e.position||0)*n.w,_length:0}),\"top\"===a||\"left\"===a?r._offset:\"bottom\"===a||\"right\"===a?r._offset+r._length:void 0}function Z(t,e){var r=t.l2p(e);return r>1&&r<t._length-1}function J(t){var e=n.select(t),r=e.select(\".text-math-group\");return r.empty()?e.select(\"text\"):r}function K(t){return t._id+\".automargin\"}function $(t){return t._id+\".rangeslider\"}function Q(t,e){for(var r=0;r<e.length;r++)-1===t.indexOf(e[r])&&t.push(e[r])}function tt(t,e,r){var n,i,a=[],o=[],l=t.layout;for(n=0;n<e.length;n++)a.push(A.getFromId(t,e[n]));for(n=0;n<r.length;n++)o.push(A.getFromId(t,r[n]));var c=Object.keys(f),u=[\"anchor\",\"domain\",\"overlaying\",\"position\",\"side\",\"tickangle\",\"editType\"],h=[\"linear\",\"log\"];for(n=0;n<c.length;n++){var p=c[n],d=a[0][p],g=o[0][p],v=!0,m=!1,y=!1;if(\"_\"!==p.charAt(0)&&\"function\"!=typeof d&&-1===u.indexOf(p)){for(i=1;i<a.length&&v;i++){var x=a[i][p];\"type\"===p&&-1!==h.indexOf(d)&&-1!==h.indexOf(x)&&d!==x?m=!0:x!==d&&(v=!1)}for(i=1;i<o.length&&v;i++){var b=o[i][p];\"type\"===p&&-1!==h.indexOf(g)&&-1!==h.indexOf(b)&&g!==b?y=!0:o[i][p]!==g&&(v=!1)}v&&(m&&(l[a[0]._name].type=\"linear\"),y&&(l[o[0]._name].type=\"linear\"),et(l,p,a,o,t._fullLayout._dfltTitle))}}for(n=0;n<t._fullLayout.annotations.length;n++){var _=t._fullLayout.annotations[n];-1!==e.indexOf(_.xref)&&-1!==r.indexOf(_.yref)&&s.swapAttrs(l.annotations[n],[\"?\"])}}function et(t,e,r,n,i){var a,o=s.nestedProperty,l=o(t[r[0]._name],e).get(),c=o(t[n[0]._name],e).get();for(\"title\"===e&&(l&&l.text===i.x&&(l.text=i.y),c&&c.text===i.y&&(c.text=i.x)),a=0;a<r.length;a++)o(t,r[a]._name+\".\"+e).set(c);for(a=0;a<n.length;a++)o(t,n[a]._name+\".\"+e).set(l)}function rt(t){return\"angularaxis\"===t._id}A.getTickFormat=function(t){var e,r,n,i,a,o,s,l;function c(t){return\"string\"!=typeof t?t:Number(t.replace(\"M\",\"\"))*v}function u(t,e){var r=[\"L\",\"D\"];if(typeof t==typeof e){if(\"number\"==typeof t)return t-e;var n=r.indexOf(t.charAt(0)),i=r.indexOf(e.charAt(0));return n===i?Number(t.replace(/(L|D)/g,\"\"))-Number(e.replace(/(L|D)/g,\"\")):n-i}return\"number\"==typeof t?1:-1}function h(t,e){var r=null===e[0],n=null===e[1],i=u(t,e[0])>=0,a=u(t,e[1])<=0;return(r||i)&&(n||a)}if(t.tickformatstops&&t.tickformatstops.length>0)switch(t.type){case\"date\":case\"linear\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&(i=t.dtick,a=n.dtickrange,o=void 0,void 0,void 0,o=c||function(t){return t},s=a[0],l=a[1],(!s&&\"number\"!=typeof s||o(s)<=o(i))&&(!l&&\"number\"!=typeof l||o(l)>=o(i)))){r=n;break}break;case\"log\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&h(t.dtick,n.dtickrange)){r=n;break}}return r?r.value:t.tickformat},A.getSubplots=function(t,e){var r=t._fullLayout._subplots,n=r.cartesian.concat(r.gl2d||[]),i=e?A.findSubplotsWithAxis(n,e):n;return i.sort(function(t,e){var r=t.substr(1).split(\"y\"),n=e.substr(1).split(\"y\");return r[0]===n[0]?+r[1]-+n[1]:+r[0]-+n[0]}),i},A.findSubplotsWithAxis=function(t,e){for(var r=new RegExp(\"x\"===e._id.charAt(0)?\"^\"+e._id+\"y\":e._id+\"$\"),n=[],i=0;i<t.length;i++){var a=t[i];r.test(a)&&n.push(a)}return n},A.makeClipPaths=function(t){var e=t._fullLayout;if(!e._hasOnlyLargeSploms){var r,i,a={_offset:0,_length:e.width,_id:\"\"},o={_offset:0,_length:e.height,_id:\"\"},s=A.list(t,\"x\",!0),l=A.list(t,\"y\",!0),c=[];for(r=0;r<s.length;r++)for(c.push({x:s[r],y:o}),i=0;i<l.length;i++)0===r&&c.push({x:a,y:l[i]}),c.push({x:s[r],y:l[i]});var u=e._clips.selectAll(\".axesclip\").data(c,function(t){return t.x._id+t.y._id});u.enter().append(\"clipPath\").classed(\"axesclip\",!0).attr(\"id\",function(t){return\"clip\"+e._uid+t.x._id+t.y._id}).append(\"rect\"),u.exit().remove(),u.each(function(t){n.select(this).select(\"rect\").attr({x:t.x._offset||0,y:t.y._offset||0,width:t.x._length||1,height:t.y._length||1})})}},A.draw=function(t,e,r){var n=t._fullLayout;\"redraw\"===e&&n._paper.selectAll(\"g.subplot\").each(function(t){var e=t[0],r=n._plots[e],i=r.xaxis,a=r.yaxis;r.xaxislayer.selectAll(\".\"+i._id+\"tick\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"tick2\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick2\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"divider\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"divider\").remove(),r.gridlayer&&r.gridlayer.selectAll(\"path\").remove(),r.zerolinelayer&&r.zerolinelayer.selectAll(\"path\").remove(),n._infolayer.select(\".g-\"+i._id+\"title\").remove(),n._infolayer.select(\".g-\"+a._id+\"title\").remove()});var i=e&&\"redraw\"!==e?e:A.listIds(t);return s.syncOrAsync(i.map(function(e){return function(){if(e){var n=A.getFromId(t,e),i=A.drawOne(t,n,r);return n._r=n.range.slice(),n._rl=s.simpleMap(n._r,n.r2l),i}}}))},A.drawOne=function(t,e,r){var n,i,l;r=r||{},e.setScale();var f=t._fullLayout,p=e._id,d=p.charAt(0),g=A.counterLetter(p),v=e._mainSubplot,m=e._mainLinePosition,y=e._mainMirrorPosition,x=f._plots[v][d+\"axislayer\"],b=e._subplotsWith,_=e._vals=A.calcTicks(e),w=[e.mirror,m,y].join(\"_\");for(n=0;n<_.length;n++)_[n].axInfo=w;if(e.visible){e._selections={},e._tickAngles={};var k,M,S=A.makeTransFn(e);if(\"boundaries\"===e.tickson){var E=function(t,e){var r,n=[],i=function(t,e){var r=t.xbnd[e];null!==r&&n.push(s.extendFlat({},t,{x:r}))};if(e.length){for(r=0;r<e.length;r++)i(e[r],0);i(e[r-1],1)}return n}(0,_);M=A.clipEnds(e,E),k=\"inside\"===e.ticks?M:E}else M=A.clipEnds(e,_),k=\"inside\"===e.ticks?M:_;var C=e._gridVals=M,L=function(t,e){var r,n,i=[],a=function(t,e){var r=t.xbnd[e];null!==r&&i.push(s.extendFlat({},t,{x:r}))};if(t.showdividers&&e.length){for(r=0;r<e.length;r++){var o=e[r];o.text2!==n&&a(o,0),n=o.text2}a(e[r-1],1)}return i}(e,_);if(!f._hasOnlyLargeSploms){var P={};for(n=0;n<b.length;n++){i=b[n];var O=(l=f._plots[i])[g+\"axis\"],z=O._mainAxis._id;if(!P[z]){P[z]=1;var I=\"x\"===d?\"M0,\"+O._offset+\"v\"+O._length:\"M\"+O._offset+\",0h\"+O._length;A.drawGrid(t,e,{vals:C,counterAxis:O,layer:l.gridlayer.select(\".\"+p),path:I,transFn:S}),A.drawZeroLine(t,e,{counterAxis:O,layer:l.zerolinelayer,path:I,transFn:S})}}}var D=A.getTickSigns(e),R=[];if(e.ticks){var F,B,N,j=A.makeTickPath(e,m,D[2]);if(e._anchorAxis&&e.mirror&&!0!==e.mirror?(F=A.makeTickPath(e,y,D[3]),B=j+F):(F=\"\",B=j),e.showdividers&&\"outside\"===e.ticks&&\"boundaries\"===e.tickson){var V={};for(n=0;n<L.length;n++)V[L[n].x]=1;N=function(t){return V[t.x]?F:B}}else N=B;A.drawTicks(t,e,{vals:k,layer:x,path:N,transFn:S}),R=Object.keys(e._linepositions||{})}for(n=0;n<R.length;n++){i=R[n],l=f._plots[i];var q=e._linepositions[i]||[],H=A.makeTickPath(e,q[0],D[0])+A.makeTickPath(e,q[1],D[1]);A.drawTicks(t,e,{vals:k,layer:l[d+\"axislayer\"],path:H,transFn:S})}var G=[];if(G.push(function(){return A.drawLabels(t,e,{vals:_,layer:x,transFn:S,labelFns:A.makeLabelFns(e,m)})}),\"multicategory\"===e.type){var Z=0,J={x:2,y:10}[d],Q=D[2]*(\"inside\"===e.ticks?-1:1);G.push(function(){return Z+=Y(e,p+\"tick\")+J,Z+=e._tickAngles[p+\"tick\"]?e.tickfont.size*T:0,A.drawLabels(t,e,{vals:function(t,e){for(var r=[],n={},i=0;i<e.length;i++){var a=e[i];n[a.text2]?n[a.text2].push(a.x):n[a.text2]=[a.x]}for(var o in n)r.push(U(t,s.interp(n[o],.5),o));return r}(e,_),layer:x,cls:p+\"tick2\",repositionOnUpdate:!0,secondary:!0,transFn:S,labelFns:A.makeLabelFns(e,m+Z*Q)})}),G.push(function(){return Z+=Y(e,p+\"tick2\"),e._labelLength=Z,function(t,e,r){var n=e._id+\"divider\",i=r.vals,a=r.layer.selectAll(\"path.\"+n).data(i,W);a.exit().remove(),a.enter().insert(\"path\",\":first-child\").classed(n,1).classed(\"crisp\",1).call(u.stroke,e.dividercolor).style(\"stroke-width\",h.crispRound(t,e.dividerwidth,1)+\"px\"),a.attr(\"transform\",r.transFn).attr(\"d\",r.path)}(t,e,{vals:L,layer:x,path:A.makeTickPath(e,m,Q,Z),transFn:S})})}var tt=o.getComponentMethod(\"rangeslider\",\"isVisible\")(e);return G.push(function(){if(e.showticklabels){var r=t.getBoundingClientRect(),n=x.node().getBoundingClientRect();e._boundingBox={width:n.width,height:n.height,left:n.left-r.left,right:n.right-r.left,top:n.top-r.top,bottom:n.bottom-r.top}}else{var i,a=f._size;\"x\"===d?(i=\"free\"===e.anchor?a.t+a.h*(1-e.position):a.t+a.h*(1-e._anchorAxis.domain[{bottom:0,top:1}[e.side]]),e._boundingBox={top:i,bottom:i,left:e._offset,right:e._offset+e._length,width:e._length,height:0}):(i=\"free\"===e.anchor?a.l+a.w*e.position:a.l+a.w*e._anchorAxis.domain[{left:0,right:1}[e.side]],e._boundingBox={left:i,right:i,bottom:e._offset+e._length,top:e._offset,height:e._length,width:0})}if(b){for(var o=e._counterSpan=[1/0,-1/0],s=0;s<b.length;s++){var l=f._plots[b[s]][\"x\"===d?\"yaxis\":\"xaxis\"];et(o,[l._offset,l._offset+l._length])}\"free\"===e.anchor&&et(o,\"x\"===d?[e._boundingBox.bottom,e._boundingBox.top]:[e._boundingBox.right,e._boundingBox.left])}},function(){var r,n,i=e.side.charAt(0);if(tt&&(n=o.getComponentMethod(\"rangeslider\",\"autoMarginOpts\")(t,e)),a.autoMargin(t,$(e),n),e.automargin&&(!tt||\"b\"!==i)){r={x:0,y:0,r:0,l:0,t:0,b:0};var s,l,c=e._boundingBox,u=X(t,e);switch(d+i){case\"xb\":s=0,l=c.top-u,r[i]=c.height;break;case\"xt\":s=1,l=u-c.bottom,r[i]=c.height;break;case\"yl\":s=0,l=u-c.right,r[i]=c.width;break;case\"yr\":s=1,l=c.left-u,r[i]=c.width}if(r[g]=\"free\"===e.anchor?e.position:e._anchorAxis.domain[s],r[i]>0&&(r[i]+=l),e.title.text!==f._dfltTitle[d]&&(r[i]+=e.title.font.size),\"x\"===d&&c.width>0){var h=c.right-(e._offset+e._length);h>0&&(r.x=1,r.r=h);var p=e._offset-c.left;p>0&&(r.x=0,r.l=p)}else if(\"y\"===d&&c.height>0){var v=c.bottom-(e._offset+e._length);v>0&&(r.y=0,r.b=v);var m=e._offset-c.top;m>0&&(r.y=1,r.t=m)}}a.autoMargin(t,K(e),r)}),r.skipTitle||tt&&e._boundingBox&&\"bottom\"===e.side||G.push(function(){return function(t,e){var r,n=t._fullLayout,i=e._id,a=i.charAt(0),o=e.title.font.size;if(\"multicategory\"===e.type)r=e._labelLength;else{r=10+1.5*o+(e.linewidth?e.linewidth-1:0)}var s,l,u,f,p=X(t,e);\"x\"===a?(l=e._offset+e._length/2,u=\"top\"===e.side?-r-o*(e.showticklabels?1:0):r+o*(e.showticklabels?1.5:.5),u+=p):(u=e._offset+e._length/2,l=\"right\"===e.side?r+o*(e.showticklabels?1:.5):-r-o*(e.showticklabels?.5:0),l+=p,s={rotate:\"-90\",offset:0});if(\"multicategory\"!==e.type){var d=e._selections[e._id+\"tick\"];if(f={selection:d,side:e.side},d&&d.node()&&d.node().parentNode){var g=h.getTranslate(d.node().parentNode);f.offsetLeft=g.x,f.offsetTop=g.y}}return c.draw(t,i+\"title\",{propContainer:e,propName:e._name+\".title.text\",placeholder:n._dfltTitle[a],avoid:f,transform:s,attributes:{x:l,y:u,\"text-anchor\":\"middle\"}})}(t,e)}),s.syncOrAsync(G)}function et(t,e){t[0]=Math.min(t[0],e[0]),t[1]=Math.max(t[1],e[1])}},A.getTickSigns=function(t){var e=t._id.charAt(0),r={x:\"top\",y:\"right\"}[e],n=t.side===r?1:-1,i=[-1,1,n,-n];return\"inside\"!==t.ticks==(\"x\"===e)&&(i=i.map(function(t){return-t})),i},A.makeTransFn=function(t){var e=t._id.charAt(0),r=t._offset;return\"x\"===e?function(e){return\"translate(\"+(r+t.l2p(e.x))+\",0)\"}:function(e){return\"translate(0,\"+(r+t.l2p(e.x))+\")\"}},A.makeTickPath=function(t,e,r,n){n=void 0!==n?n:t.ticklen;var i=t._id.charAt(0),a=(t.linewidth||1)/2;return\"x\"===i?\"M0,\"+(e+a*r)+\"v\"+n*r:\"M\"+(e+a*r)+\",0h\"+n*r},A.makeLabelFns=function(t,e,r){var n=t._id.charAt(0),a=\"boundaries\"!==t.tickson&&\"outside\"===t.ticks,o=0,l=0;if(a&&(o+=t.ticklen),r&&\"outside\"===t.ticks){var c=s.deg2rad(r);o=t.ticklen*Math.cos(c)+1,l=t.ticklen*Math.sin(c)}t.showticklabels&&(a||t.showline)&&(o+=.2*t.tickfont.size);var u,h,f,p,d={labelStandoff:o+=(t.linewidth||1)/2,labelShift:l};return\"x\"===n?(p=\"bottom\"===t.side?1:-1,u=l*p,h=e+o*p,f=\"bottom\"===t.side?1:-.2,d.xFn=function(t){return t.dx+u},d.yFn=function(t){return t.dy+h+t.fontSize*f},d.anchorFn=function(t,e){return i(e)&&0!==e&&180!==e?e*p<0?\"end\":\"start\":\"middle\"},d.heightFn=function(e,r,n){return r<-60||r>60?-.5*n:\"top\"===t.side?-n:0}):\"y\"===n&&(p=\"right\"===t.side?1:-1,u=o,h=-l*p,f=90===Math.abs(t.tickangle)?.5:0,d.xFn=function(t){return t.dx+e+(u+t.fontSize*f)*p},d.yFn=function(t){return t.dy+h+t.fontSize*k},d.anchorFn=function(e,r){return i(r)&&90===Math.abs(r)?\"middle\":\"right\"===t.side?\"start\":\"end\"},d.heightFn=function(e,r,n){return(r*=\"left\"===t.side?1:-1)<-30?-n:r<30?-.5*n:0}),d},A.drawTicks=function(t,e,r){r=r||{};var n=e._id+\"tick\",i=r.layer.selectAll(\"path.\"+n).data(e.ticks?r.vals:[],W);i.exit().remove(),i.enter().append(\"path\").classed(n,1).classed(\"ticks\",1).classed(\"crisp\",!1!==r.crisp).call(u.stroke,e.tickcolor).style(\"stroke-width\",h.crispRound(t,e.tickwidth,1)+\"px\").attr(\"d\",r.path),i.attr(\"transform\",r.transFn)},A.drawGrid=function(t,e,r){r=r||{};var n=e._id+\"grid\",i=r.vals,a=r.counterAxis;if(!1===e.showgrid)i=[];else if(a&&A.shouldShowZeroLine(t,e,a))for(var o=\"array\"===e.tickmode,s=0;s<i.length;s++){var l=i[s].x;if(o?!l:Math.abs(l)<e.dtick/100){if(i=i.slice(0,s).concat(i.slice(s+1)),!o)break;s--}}var c=r.layer.selectAll(\"path.\"+n).data(i,W);c.exit().remove(),c.enter().append(\"path\").classed(n,1).classed(\"crisp\",!1!==r.crisp),e._gw=h.crispRound(t,e.gridwidth,1),c.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(u.stroke,e.gridcolor||\"#ddd\").style(\"stroke-width\",e._gw+\"px\"),\"function\"==typeof r.path&&c.attr(\"d\",r.path)},A.drawZeroLine=function(t,e,r){r=r||r;var n=e._id+\"zl\",i=A.shouldShowZeroLine(t,e,r.counterAxis),a=r.layer.selectAll(\"path.\"+n).data(i?[{x:0,id:e._id}]:[]);a.exit().remove(),a.enter().append(\"path\").classed(n,1).classed(\"zl\",1).classed(\"crisp\",!1!==r.crisp).each(function(){r.layer.selectAll(\"path\").sort(function(t,e){return S.idSort(t.id,e.id)})}),a.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(u.stroke,e.zerolinecolor||u.defaultLine).style(\"stroke-width\",h.crispRound(t,e.zerolinewidth,e._gw||1)+\"px\")},A.drawLabels=function(t,e,r){r=r||{};var a=e._id,o=a.charAt(0),c=r.cls||a+\"tick\",u=r.vals,f=r.labelFns,p=r.secondary?0:e.tickangle,d=(e._tickAngles||{})[c],g=r.layer.selectAll(\"g.\"+c).data(e.showticklabels?u:[],W),v=[];function m(t,e){t.each(function(t){var a=n.select(this),o=a.select(\".text-math-group\"),s=f.anchorFn(t,e),c=r.transFn.call(a.node(),t)+(i(e)&&0!=+e?\" rotate(\"+e+\",\"+f.xFn(t)+\",\"+(f.yFn(t)-t.fontSize/2)+\")\":\"\"),u=l.lineCount(a),p=T*t.fontSize,d=f.heightFn(t,i(e)?+e:0,(u-1)*p);if(d&&(c+=\" translate(0, \"+d+\")\"),o.empty())a.select(\"text\").attr({transform:c,\"text-anchor\":s});else{var g=h.bBox(o.node()).width*{end:-.5,start:.5}[s];o.attr(\"transform\",c+(g?\"translate(\"+g+\",0)\":\"\"))}})}g.enter().append(\"g\").classed(c,1).append(\"text\").attr(\"text-anchor\",\"middle\").each(function(e){var r=n.select(this),i=t._promises.length;r.call(l.positionText,f.xFn(e),f.yFn(e)).call(h.font,e.font,e.fontSize,e.fontColor).text(e.text).call(l.convertToTspans,t),t._promises[i]?v.push(t._promises.pop().then(function(){m(r,p)})):m(r,p)}),g.exit().remove(),r.repositionOnUpdate&&g.each(function(t){n.select(this).select(\"text\").call(l.positionText,f.xFn(t),f.yFn(t))}),m(g,d||p),e._selections&&(e._selections[c]=g);var y=s.syncOrAsync([function(){return v.length&&Promise.all(v)},function(){m(g,p);var t=null;if(u.length&&\"x\"===o&&!i(p)&&(\"log\"!==e.type||\"D\"!==String(e.dtick).charAt(0))){t=0;var n,a=0,l=[];if(g.each(function(t){a=Math.max(a,t.fontSize);var r=e.l2p(t.x),n=J(this),i=h.bBox(n.node());l.push({top:0,bottom:10,height:10,left:r-i.width/2,right:r+i.width/2+2,width:i.width+2})}),\"boundaries\"!==e.tickson&&!e.showdividers||r.secondary){var f=u.length,d=Math.abs((u[f-1].x-u[0].x)*e._m)/(f-1)<2.5*a||\"multicategory\"===e.type;for(n=0;n<l.length-1;n++)if(s.bBoxIntersect(l[n],l[n+1])){t=d?90:30;break}}else{var v=2;for(e.ticks&&(v+=e.tickwidth/2),n=0;n<l.length;n++){var y=u[n].xbnd,x=l[n];if(null!==y[0]&&x.left-e.l2p(y[0])<v||null!==y[1]&&e.l2p(y[1])-x.right<v){t=90;break}}}t&&m(g,t)}e._tickAngles&&(e._tickAngles[c]=null===t?i(p)?p:0:t)}]);return y&&y.then&&t._promises.push(y),y},A.shouldShowZeroLine=function(t,e,r){var n=s.simpleMap(e.range,e.r2l);return n[0]*n[1]<=0&&e.zeroline&&(\"linear\"===e.type||\"-\"===e.type)&&e._gridVals.length&&(Z(e,0)||!function(t,e,r,n){var i=r._mainAxis;if(!i)return;var a=t._fullLayout,o=e._id.charAt(0),s=A.counterLetter(e._id),l=e._offset+(Math.abs(n[0])<Math.abs(n[1])==(\"x\"===o)?0:e._length);function c(t){if(!t.showline||!t.linewidth)return!1;var r=Math.max((t.linewidth+e.zerolinewidth)/2,1);function n(t){return\"number\"==typeof t&&Math.abs(t-l)<r}if(n(t._mainLinePosition)||n(t._mainMirrorPosition))return!0;var i=t._linepositions||{};for(var a in i)if(n(i[a][0])||n(i[a][1]))return!0}var u=a._plots[r._mainSubplot];if(!(u.mainplotinfo||u).overlays.length)return c(r);for(var h=A.list(t,s),f=0;f<h.length;f++){var p=h[f];if(p._mainAxis===i&&c(p))return!0}}(t,e,r,n)||function(t,e){for(var r=t._fullData,n=e._mainSubplot,i=e._id.charAt(0),a=0;a<r.length;a++){var s=r[a];if(!0===s.visible&&s.xaxis+s.yaxis===n){if(o.traceIs(s,\"bar-like\")&&s.orientation==={x:\"h\",y:\"v\"}[i])return!0;if(s.fill&&s.fill.charAt(s.fill.length-1)===i)return!0}}return!1}(t,e))},A.clipEnds=function(t,e){return e.filter(function(e){return Z(t,e.x)})},A.allowAutoMargin=function(t){for(var e=A.list(t,\"\",!0),r=0;r<e.length;r++){var n=e[r];n.automargin&&a.allowAutoMargin(t,K(n)),o.getComponentMethod(\"rangeslider\",\"isVisible\")(n)&&a.allowAutoMargin(t,$(n))}},A.swap=function(t,e){for(var r=function(t,e){var r,n,i=[];for(r=0;r<e.length;r++){var a=[],o=t._fullData[e[r]].xaxis,s=t._fullData[e[r]].yaxis;if(o&&s){for(n=0;n<i.length;n++)-1===i[n].x.indexOf(o)&&-1===i[n].y.indexOf(s)||a.push(n);if(a.length){var l,c=i[a[0]];if(a.length>1)for(n=1;n<a.length;n++)l=i[a[n]],Q(c.x,l.x),Q(c.y,l.y);Q(c.x,[o]),Q(c.y,[s])}else i.push({x:[o],y:[s]})}}return i}(t,e),n=0;n<r.length;n++)tt(t,r[n].x,r[n].y)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../components/titles\":681,\"../../constants/alignment\":688,\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/plots\":828,\"../../registry\":847,\"./autorange\":766,\"./axis_autotype\":768,\"./axis_ids\":770,\"./clean_ticks\":772,\"./layout_attributes\":779,\"./set_convert\":785,d3:163,\"fast-isnumeric\":225}],768:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){return!(r=r||{}).noMultiCategory&&(o=t,i.isArrayOrTypedArray(o[0])&&i.isArrayOrTypedArray(o[1]))?\"multicategory\":function(t,e){for(var r=Math.max(1,(t.length-1)/1e3),a=0,o=0,s={},l=0;l<t.length;l+=r){var c=t[Math.round(l)],u=String(c);s[u]||(s[u]=1,i.isDateTime(c,e)&&(a+=1),n(c)&&(o+=1))}return a>2*o}(t,e)?\"date\":function(t){for(var e=Math.max(1,(t.length-1)/1e3),r=0,n=0,o={},s=0;s<t.length;s+=e){var l=t[Math.round(s)],c=String(l);o[c]||(o[c]=1,\"boolean\"==typeof l?n++:i.cleanNumber(l)!==a?r++:\"string\"==typeof l&&n++)}return n>2*r}(t)?\"category\":function(t){if(!t)return!1;for(var e=0;e<t.length;e++)if(n(t[e]))return!0;return!1}(t)?\"linear\":\"-\";var o}},{\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],769:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./layout_attributes\"),o=t(\"./tick_value_defaults\"),s=t(\"./tick_mark_defaults\"),l=t(\"./tick_label_defaults\"),c=t(\"./category_order_defaults\"),u=t(\"./line_grid_defaults\"),h=t(\"./set_convert\");e.exports=function(t,e,r,f,p){var d=f.letter,g=f.font||{},v=f.splomStash||{},m=r(\"visible\",!f.visibleDflt),y=e.type;\"date\"===y&&n.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",f.calendar);h(e,p);var x=!e.isValidRange(t.range);x&&f.reverseDflt&&(x=\"reversed\"),!r(\"autorange\",x)||\"linear\"!==y&&\"-\"!==y||r(\"rangemode\"),r(\"range\"),e.cleanRange(),c(t,e,r,f),\"category\"===y||f.noHover||r(\"hoverformat\");var b=r(\"color\"),_=b!==a.color.dflt?b:g.color,w=v.label||p._dfltTitle[d];if(l(t,e,r,y,f,{pass:1}),!m)return e;r(\"title.text\",w),i.coerceFont(r,\"title.font\",{family:g.family,size:Math.round(1.2*g.size),color:_}),o(t,e,r,y),l(t,e,r,y,f,{pass:2}),s(t,e,r,f),u(t,e,r,{dfltColor:b,bgColor:f.bgColor,showGrid:f.showGrid,attributes:a}),(e.showline||e.ticks)&&r(\"mirror\"),f.automargin&&r(\"automargin\");var k,T=\"multicategory\"===e.type;f.noTickson||\"category\"!==e.type&&!T||!e.ticks&&!e.showgrid||(T&&(k=\"boundaries\"),r(\"tickson\",k));T&&(r(\"showdividers\")&&(r(\"dividercolor\"),r(\"dividerwidth\")));return e}},{\"../../lib\":719,\"../../registry\":847,\"./category_order_defaults\":771,\"./layout_attributes\":779,\"./line_grid_defaults\":781,\"./set_convert\":785,\"./tick_label_defaults\":786,\"./tick_mark_defaults\":787,\"./tick_value_defaults\":788}],770:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./constants\");r.id2name=function(t){if(\"string\"==typeof t&&t.match(i.AX_ID_PATTERN)){var e=t.substr(1);return\"1\"===e&&(e=\"\"),t.charAt(0)+\"axis\"+e}},r.name2id=function(t){if(t.match(i.AX_NAME_PATTERN)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),t.charAt(0)+e}},r.cleanId=function(t,e){if(t.match(i.AX_ID_PATTERN)&&(!e||t.charAt(0)===e)){var r=t.substr(1).replace(/^0+/,\"\");return\"1\"===r&&(r=\"\"),t.charAt(0)+r}},r.list=function(t,e,n){var i=t._fullLayout;if(!i)return[];var a,o=r.listIds(t,e),s=new Array(o.length);for(a=0;a<o.length;a++){var l=o[a];s[a]=i[l.charAt(0)+\"axis\"+l.substr(1)]}if(!n){var c=i._subplots.gl3d||[];for(a=0;a<c.length;a++){var u=i[c[a]];e?s.push(u[e+\"axis\"]):s.push(u.xaxis,u.yaxis,u.zaxis)}}return s},r.listIds=function(t,e){var r=t._fullLayout;if(!r)return[];var n=r._subplots;return e?n[e+\"axis\"]:n.xaxis.concat(n.yaxis)},r.getFromId=function(t,e,n){var i=t._fullLayout;return\"x\"===n?e=e.replace(/y[0-9]*/,\"\"):\"y\"===n&&(e=e.replace(/x[0-9]*/,\"\")),i[r.id2name(e)]},r.getFromTrace=function(t,e,i){var a=t._fullLayout,o=null;if(n.traceIs(e,\"gl3d\")){var s=e.scene;\"scene\"===s.substr(0,5)&&(o=a[s][i+\"axis\"])}else o=r.getFromId(t,e[i+\"axis\"]||i);return o},r.idSort=function(t,e){var r=t.charAt(0),n=e.charAt(0);return r!==n?r>n?1:-1:+(t.substr(1)||1)-+(e.substr(1)||1)},r.getAxisGroup=function(t,e){for(var r=t._axisMatchGroups,n=0;n<r.length;n++){if(r[n][e])return\"g\"+n}return e}},{\"../../registry\":847,\"./constants\":773}],771:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){if(\"category\"===e.type){var i,a=t.categoryarray,o=Array.isArray(a)&&a.length>0;o&&(i=\"array\");var s,l=r(\"categoryorder\",i);\"array\"===l&&(s=r(\"categoryarray\")),o||\"array\"!==l||(l=e.categoryorder=\"trace\"),\"trace\"===l?e._initialCategories=[]:\"array\"===l?e._initialCategories=s.slice():(s=function(t,e){var r,n,i,a=e.dataAttr||t._id.charAt(0),o={};if(e.axData)r=e.axData;else for(r=[],n=0;n<e.data.length;n++){var s=e.data[n];s[a+\"axis\"]===t._id&&r.push(s)}for(n=0;n<r.length;n++){var l=r[n][a];for(i=0;i<l.length;i++){var c=l[i];null!=c&&(o[c]=1)}}return Object.keys(o)}(e,n).sort(),\"category ascending\"===l?e._initialCategories=s:\"category descending\"===l&&(e._initialCategories=s.reverse()))}}},{}],772:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").ONEDAY;r.dtick=function(t,e){var r=\"log\"===e,i=\"date\"===e,o=\"category\"===e,s=i?a:1;if(!t)return s;if(n(t))return(t=Number(t))<=0?s:o?Math.max(1,Math.round(t)):i?Math.max(.1,t):t;if(\"string\"!=typeof t||!i&&!r)return s;var l=t.charAt(0),c=t.substr(1);return(c=n(c)?Number(c):0)<=0||!(i&&\"M\"===l&&c===Math.round(c)||r&&\"L\"===l||r&&\"D\"===l&&(1===c||2===c))?s:t},r.tick0=function(t,e,r,a){return\"date\"===e?i.cleanDate(t,i.dateTick0(r)):\"D1\"!==a&&\"D2\"!==a?n(t)?Number(t):0:void 0}},{\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],773:[function(t,e,r){\"use strict\";var n=t(\"../../lib/regex\").counter;e.exports={idRegex:{x:n(\"x\"),y:n(\"y\")},attrRegex:n(\"[xy]axis\"),xAxisMatch:n(\"xaxis\"),yAxisMatch:n(\"yaxis\"),AX_ID_PATTERN:/^[xyz][0-9]*$/,AX_NAME_PATTERN:/^[xyz]axis[0-9]*$/,SUBPLOT_PATTERN:/^x([0-9]*)y([0-9]*)$/,MINDRAG:8,MINSELECT:12,MINZOOM:20,DRAGGERSIZE:20,BENDPX:1.5,REDRAWDELAY:50,SELECTDELAY:100,SELECTID:\"-select\",DFLTRANGEX:[-1,6],DFLTRANGEY:[-1,4],traceLayerClasses:[\"heatmaplayer\",\"contourcarpetlayer\",\"contourlayer\",\"funnellayer\",\"waterfalllayer\",\"barlayer\",\"carpetlayer\",\"violinlayer\",\"boxlayer\",\"ohlclayer\",\"scattercarpetlayer\",\"scatterlayer\"],clipOnAxisFalseQuery:[\".scatterlayer\",\".barlayer\",\".funnellayer\",\".waterfalllayer\"],layerValue2layerClass:{\"above traces\":\"above\",\"below traces\":\"below\"}}},{\"../../lib/regex\":735}],774:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./axis_ids\").id2name,a=t(\"./scale_zoom\"),o=t(\"./autorange\").makePadFn,s=t(\"./autorange\").concatExtremes,l=t(\"../../constants/numerical\").ALMOST_EQUAL,c=t(\"../../constants/alignment\").FROM_BL;function u(t,e,r,n,a){var o,s,l,c,u=\"range\"!==a,h=n[i(e)].type,f=[];for(s=0;s<r.length;s++)if((l=r[s])!==e&&(c=n[i(l)]).type===h)if(c.fixedrange){if(u&&c.anchor){n[i(c.anchor)].fixedrange&&f.push(l)}}else f.push(l);for(o=0;o<t.length;o++)if(t[o][e]){var p=t[o],d=[];for(s=0;s<f.length;s++)p[l=f[s]]||d.push(l);return{linkableAxes:d,thisGroup:p}}return{linkableAxes:f,thisGroup:null}}function h(t,e,r,n,i){var a,o,s,l,c;null===e?((e={})[r]=1,c=t.length,t.push(e)):c=t.indexOf(e);var u=Object.keys(e);for(a=0;a<t.length;a++)if(s=t[a],a!==c&&s[n]){var h=s[n];for(o=0;o<u.length;o++)s[l=u[o]]=h*i*e[l];return void t.splice(c,1)}if(1!==i)for(o=0;o<u.length;o++)e[u[o]]*=i;e[n]=1}function f(t,e){var r=t._inputDomain,n=c[t.constraintoward],i=r[0]+(r[1]-r[0])*n;t.domain=t._input.domain=[i+(r[0]-i)/e,i+(r[1]-i)/e],t.setScale()}r.handleConstraintDefaults=function(t,e,r,i,a){var o,s,l,c,f=a._axisConstraintGroups,p=a._axisMatchGroups,d=e._id,g=d.charAt(0),v=((a._splomAxes||{})[g]||{})[d]||{},m=e._id,y=m.charAt(0),x=r(\"constrain\");if(n.coerce(t,e,{constraintoward:{valType:\"enumerated\",values:\"x\"===y?[\"left\",\"center\",\"right\"]:[\"bottom\",\"middle\",\"top\"],dflt:\"x\"===y?\"center\":\"middle\"}},\"constraintoward\"),!t.matches&&!v.matches||e.fixedrange||(s=u(p,m,i,a),o=n.coerce(t,e,{matches:{valType:\"enumerated\",values:s.linkableAxes||[],dflt:v.matches}},\"matches\")),o||!t.scaleanchor||e.fixedrange&&\"domain\"!==x||(c=u(f,m,i,a,x),l=n.coerce(t,e,{scaleanchor:{valType:\"enumerated\",values:c.linkableAxes||[]}},\"scaleanchor\")),o?(delete e.constrain,h(p,s.thisGroup,m,o,1)):-1!==i.indexOf(t.matches)&&n.warn(\"ignored \"+e._name+'.matches: \"'+t.matches+'\" to avoid either an infinite loop or because the target axis has fixed range.'),l){var b=r(\"scaleratio\");b||(b=e.scaleratio=1),h(f,c.thisGroup,m,l,b)}else-1!==i.indexOf(t.scaleanchor)&&n.warn(\"ignored \"+e._name+'.scaleanchor: \"'+t.scaleanchor+'\" to avoid either an infinite loop and possibly inconsistent scaleratios, or because the target axis has fixed range or this axis declares a *matches* constraint.')},r.enforce=function(t){var e,r,n,c,u,h,p,d=t._fullLayout,g=d._axisConstraintGroups||[];for(e=0;e<g.length;e++){var v=g[e],m=Object.keys(v),y=1/0,x=0,b=1/0,_={},w={},k=!1;for(r=0;r<m.length;r++)w[n=m[r]]=c=d[i(n)],c._inputDomain?c.domain=c._inputDomain.slice():c._inputDomain=c.domain.slice(),c._inputRange||(c._inputRange=c.range.slice()),c.setScale(),_[n]=u=Math.abs(c._m)/v[n],y=Math.min(y,u),\"domain\"!==c.constrain&&c._constraintShrinkable||(b=Math.min(b,u)),delete c._constraintShrinkable,x=Math.max(x,u),\"domain\"===c.constrain&&(k=!0);if(!(y>l*x)||k)for(r=0;r<m.length;r++)if(u=_[n=m[r]],h=(c=w[n]).constrain,u!==b||\"domain\"===h)if(p=u/b,\"range\"===h)a(c,p);else{var T=c._inputDomain,A=(c.domain[1]-c.domain[0])/(T[1]-T[0]),M=(c.r2l(c.range[1])-c.r2l(c.range[0]))/(c.r2l(c._inputRange[1])-c.r2l(c._inputRange[0]));if((p/=A)*M<1){c.domain=c._input.domain=T.slice(),a(c,p);continue}if(M<1&&(c.range=c._input.range=c._inputRange.slice(),p*=M),c.autorange){var S=c.r2l(c.range[0]),E=c.r2l(c.range[1]),C=(S+E)/2,L=C,P=C,O=Math.abs(E-C),z=C-O*p*1.0001,I=C+O*p*1.0001,D=o(c);f(c,p);var R,F,B=Math.abs(c._m),N=s(t,c),j=N.min,U=N.max;for(F=0;F<j.length;F++)(R=j[F].val-D(j[F])/B)>z&&R<L&&(L=R);for(F=0;F<U.length;F++)(R=U[F].val+D(U[F])/B)<I&&R>P&&(P=R);p/=(P-L)/(2*O),L=c.l2r(L),P=c.l2r(P),c.range=c._input.range=S<E?[L,P]:[P,L]}f(c,p)}}},r.clean=function(t,e){if(e._inputDomain){for(var r=!1,n=e._id,i=t._fullLayout._axisConstraintGroups,a=0;a<i.length;a++)if(i[a][n]){r=!0;break}r&&\"domain\"===e.constrain||(e._input.domain=e.domain=e._inputDomain,delete e._inputDomain)}}},{\"../../constants/alignment\":688,\"../../constants/numerical\":695,\"../../lib\":719,\"./autorange\":766,\"./axis_ids\":770,\"./scale_zoom\":783}],775:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"has-passive-events\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../components/color\"),u=t(\"../../components/drawing\"),h=t(\"../../components/fx\"),f=t(\"./axes\"),p=t(\"../../lib/setcursor\"),d=t(\"../../components/dragelement\"),g=t(\"../../constants/alignment\").FROM_TL,v=t(\"../../lib/clear_gl_canvases\"),m=t(\"../../plot_api/subroutines\").redrawReglTraces,y=t(\"../plots\"),x=t(\"./axis_ids\").getFromId,b=t(\"./select\").prepSelect,_=t(\"./select\").clearSelect,w=t(\"./select\").selectOnClick,k=t(\"./scale_zoom\"),T=t(\"./constants\"),A=T.MINDRAG,M=T.MINZOOM,S=!0;function E(t,e,r,n){var i=s.ensureSingle(t.draglayer,e,r,function(e){e.classed(\"drag\",!0).style({fill:\"transparent\",\"stroke-width\":0}).attr(\"data-subplot\",t.id)});return i.call(p,n),i.node()}function C(t,e,r,i,a,o,s){var l=E(t,\"rect\",e,r);return n.select(l).call(u.setRect,i,a,o,s),l}function L(t,e){for(var r=0;r<t.length;r++)if(!t[r].fixedrange)return e;return\"\"}function P(t,e,r,n,i){for(var a=0;a<t.length;a++){var o=t[a];if(!o.fixedrange){var s=o._rl[0],l=o._rl[1]-s;n[o._name+\".range[0]\"]=o.l2r(s+l*e),n[o._name+\".range[1]\"]=o.l2r(s+l*r)}}if(i&&i.length){var c=(e+(1-r))/2;P(i,c,1-c,n,[])}}function O(t,e){for(var r=0;r<t.length;r++){var n=t[r];n.fixedrange||(n.range=[n.l2r(n._rl[0]-e/n._m),n.l2r(n._rl[1]-e/n._m)])}}function z(t){return 1-(t>=0?Math.min(t,.9):1/(1/Math.max(t,-.3)+3.222))}function I(t,e,r,n,i){return t.append(\"path\").attr(\"class\",\"zoombox\").style({fill:e>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"transform\",\"translate(\"+r+\", \"+n+\")\").attr(\"d\",i+\"Z\")}function D(t,e,r){return t.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:c.background,stroke:c.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"transform\",\"translate(\"+e+\", \"+r+\")\").attr(\"d\",\"M0,0Z\")}function R(t,e,r,n,i,a){t.attr(\"d\",n+\"M\"+r.l+\",\"+r.t+\"v\"+r.h+\"h\"+r.w+\"v-\"+r.h+\"h-\"+r.w+\"Z\"),F(t,e,i,a)}function F(t,e,r,n){r||(t.transition().style(\"fill\",n>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),e.transition().style(\"opacity\",1).duration(200))}function B(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}function N(t){S&&t.data&&t._context.showTips&&(s.notifier(s._(t,\"Double-click to zoom back out\"),\"long\"),S=!1)}function j(t){return\"lasso\"===t||\"select\"===t}function U(t){var e=Math.floor(Math.min(t.b-t.t,t.r-t.l,M)/2);return\"M\"+(t.l-3.5)+\",\"+(t.t-.5+e)+\"h3v\"+-e+\"h\"+e+\"v-3h-\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.t-.5+e)+\"h-3v\"+-e+\"h\"+-e+\"v-3h\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.b+.5-e)+\"h-3v\"+e+\"h\"+-e+\"v3h\"+(e+3)+\"ZM\"+(t.l-3.5)+\",\"+(t.b+.5-e)+\"h3v\"+e+\"h\"+e+\"v3h-\"+(e+3)+\"Z\"}function V(t,e,r,n){for(var i,a,o,l,c=!1,u={},h={},f=0;f<e.length;f++){var p=e[f];for(i in r)if(p[i]){for(o in p)(\"x\"===o.charAt(0)?r:n)[o]||(u[o]=i);for(a in n)p[a]&&(c=!0)}for(a in n)if(p[a])for(l in p)(\"x\"===l.charAt(0)?r:n)[l]||(h[l]=a)}c&&(s.extendFlat(u,h),h={});var d={},g=[];for(o in u){var v=x(t,o);g.push(v),d[v._id]=v}var m={},y=[];for(l in h){var b=x(t,l);y.push(b),m[b._id]=b}return{xaHash:d,yaHash:m,xaxes:g,yaxes:y,xLinks:u,yLinks:h,isSubplotConstrained:c}}function q(t,e){if(a){var r=void 0!==t.onwheel?\"wheel\":\"mousewheel\";t._onwheel&&t.removeEventListener(r,t._onwheel),t._onwheel=e,t.addEventListener(r,e,{passive:!1})}else void 0!==t.onwheel?t.onwheel=e:void 0!==t.onmousewheel&&(t.onmousewheel=e)}function H(t){var e=[];for(var r in t)e.push(t[r]);return e}e.exports={makeDragBox:function(t,e,r,a,c,p,S,E){var F,G,Y,W,X,Z,J,K,$,Q,tt,et,rt,nt,it,at,ot,st,lt,ct,ut,ht=t._fullLayout._zoomlayer,ft=S+E===\"nsew\",pt=1===(S+E).length;function dt(){if(F=e.xaxis,G=e.yaxis,$=F._length,Q=G._length,J=F._offset,K=G._offset,(Y={})[F._id]=F,(W={})[G._id]=G,S&&E)for(var r=e.overlays,n=0;n<r.length;n++){var i=r[n].xaxis;Y[i._id]=i;var a=r[n].yaxis;W[a._id]=a}X=H(Y),Z=H(W),rt=L(X,E),nt=L(Z,S),it=!nt&&!rt,tt=V(t,t._fullLayout._axisConstraintGroups,Y,W),et=V(t,t._fullLayout._axisMatchGroups,Y,W),at=E||tt.isSubplotConstrained||et.isSubplotConstrained,ot=S||tt.isSubplotConstrained||et.isSubplotConstrained;var o=t._fullLayout;st=o._has(\"scattergl\"),lt=o._has(\"splom\"),ct=o._has(\"svg\")}dt();var gt=function(t,e,r){return t?\"nsew\"===t?r?\"\":\"pan\"===e?\"move\":\"crosshair\":t.toLowerCase()+\"-resize\":\"pointer\"}(nt+rt,t._fullLayout.dragmode,ft),vt=C(e,S+E+\"drag\",gt,r,a,c,p);if(it&&!ft)return vt.onmousedown=null,vt.style.pointerEvents=\"none\",vt;var mt,yt,xt,bt,_t,wt,kt,Tt,At,Mt,St={element:vt,gd:t,plotinfo:e};function Et(){St.plotinfo.selection=!1,_(t)}function Ct(r,i){var a=t._fullLayout.clickmode;if(B(t),2!==r||pt||function(){if(!t._transitioningWithDuration){var e=t._context.doubleClick,r=[];rt&&(r=r.concat(X)),nt&&(r=r.concat(Z)),et.xaxes&&(r=r.concat(et.xaxes)),et.yaxes&&(r=r.concat(et.yaxes));var n,i,a,s={};if(\"reset+autosize\"===e)for(e=\"autosize\",i=0;i<r.length;i++)if((n=r[i])._rangeInitial&&(n.range[0]!==n._rangeInitial[0]||n.range[1]!==n._rangeInitial[1])||!n._rangeInitial&&!n.autorange){e=\"reset\";break}if(\"autosize\"===e)for(i=0;i<r.length;i++)(n=r[i]).fixedrange||(s[n._name+\".autorange\"]=!0);else if(\"reset\"===e)for((rt||tt.isSubplotConstrained)&&(r=r.concat(tt.xaxes)),nt&&!tt.isSubplotConstrained&&(r=r.concat(tt.yaxes)),tt.isSubplotConstrained&&(rt?nt||(r=r.concat(Z)):r=r.concat(X)),i=0;i<r.length;i++)(n=r[i]).fixedrange||(n._rangeInitial?(a=n._rangeInitial,s[n._name+\".range[0]\"]=a[0],s[n._name+\".range[1]\"]=a[1]):s[n._name+\".autorange\"]=!0);t.emit(\"plotly_doubleclick\",null),o.call(\"_guiRelayout\",t,s)}}(),ft)a.indexOf(\"select\")>-1&&w(i,t,X,Z,e.id,St),a.indexOf(\"event\")>-1&&h.click(t,i,e.id);else if(1===r&&pt){var s=S?G:F,c=\"s\"===S||\"w\"===E?0:1,u=s._name+\".range[\"+c+\"]\",f=function(t,e){var r,i=t.range[e],a=Math.abs(i-t.range[1-e]);return\"date\"===t.type?i:\"log\"===t.type?(r=Math.ceil(Math.max(0,-Math.log(a)/Math.LN10))+3,n.format(\".\"+r+\"g\")(Math.pow(10,i))):(r=Math.floor(Math.log(Math.abs(i))/Math.LN10)-Math.floor(Math.log(a)/Math.LN10)+4,n.format(\".\"+String(r)+\"g\")(i))}(s,c),p=\"left\",d=\"middle\";if(s.fixedrange)return;S?(d=\"n\"===S?\"top\":\"bottom\",\"right\"===s.side&&(p=\"right\")):\"e\"===E&&(p=\"right\"),t._context.showAxisRangeEntryBoxes&&n.select(vt).call(l.makeEditable,{gd:t,immediate:!0,background:t._fullLayout.paper_bgcolor,text:String(f),fill:s.tickfont?s.tickfont.color:\"#444\",horizontalAlign:p,verticalAlign:d}).on(\"edit\",function(e){var r=s.d2r(e);void 0!==r&&o.call(\"_guiRelayout\",t,u,r)})}}function Lt(e,r){if(t._transitioningWithDuration)return!1;var n=Math.max(0,Math.min($,e+mt)),i=Math.max(0,Math.min(Q,r+yt)),a=Math.abs(n-mt),o=Math.abs(i-yt);function s(){kt=\"\",xt.r=xt.l,xt.t=xt.b,At.attr(\"d\",\"M0,0Z\")}if(xt.l=Math.min(mt,n),xt.r=Math.max(mt,n),xt.t=Math.min(yt,i),xt.b=Math.max(yt,i),tt.isSubplotConstrained)a>M||o>M?(kt=\"xy\",a/$>o/Q?(o=a*Q/$,yt>i?xt.t=yt-o:xt.b=yt+o):(a=o*$/Q,mt>n?xt.l=mt-a:xt.r=mt+a),At.attr(\"d\",U(xt))):s();else if(et.isSubplotConstrained)if(a>M||o>M){kt=\"xy\";var l=Math.min(xt.l/$,(Q-xt.b)/Q),c=Math.max(xt.r/$,(Q-xt.t)/Q);xt.l=l*$,xt.r=c*$,xt.b=(1-l)*Q,xt.t=(1-c)*Q,At.attr(\"d\",U(xt))}else s();else!nt||o<Math.min(Math.max(.6*a,A),M)?a<A||!rt?s():(xt.t=0,xt.b=Q,kt=\"x\",At.attr(\"d\",function(t,e){return\"M\"+(t.l-.5)+\",\"+(e-M-.5)+\"h-3v\"+(2*M+1)+\"h3ZM\"+(t.r+.5)+\",\"+(e-M-.5)+\"h3v\"+(2*M+1)+\"h-3Z\"}(xt,yt))):!rt||a<Math.min(.6*o,M)?(xt.l=0,xt.r=$,kt=\"y\",At.attr(\"d\",function(t,e){return\"M\"+(e-M-.5)+\",\"+(t.t-.5)+\"v-3h\"+(2*M+1)+\"v3ZM\"+(e-M-.5)+\",\"+(t.b+.5)+\"v3h\"+(2*M+1)+\"v-3Z\"}(xt,mt))):(kt=\"xy\",At.attr(\"d\",U(xt)));xt.w=xt.r-xt.l,xt.h=xt.b-xt.t,kt&&(Mt=!0),t._dragged=Mt,R(Tt,At,xt,_t,wt,bt),Pt(),t.emit(\"plotly_relayouting\",ut),wt=!0}function Pt(){ut={},\"xy\"!==kt&&\"x\"!==kt||(P(X,xt.l/$,xt.r/$,ut,tt.xaxes),Bt(\"x\",ut)),\"xy\"!==kt&&\"y\"!==kt||(P(Z,(Q-xt.b)/Q,(Q-xt.t)/Q,ut,tt.yaxes),Bt(\"y\",ut))}function Ot(){if(Math.min(xt.h,xt.w)<2*A)return B(t);Pt(),B(t),jt(),N(t)}St.prepFn=function(e,r,n){var a=St.dragmode,o=t._fullLayout.dragmode;o!==a&&(St.dragmode=o),dt(),it||(ft?e.shiftKey?\"pan\"===o?o=\"zoom\":j(o)||(o=\"pan\"):e.ctrlKey&&(o=\"pan\"):o=\"pan\"),St.minDrag=\"lasso\"===o?1:void 0,j(o)?(St.xaxes=X,St.yaxes=Z,b(e,r,n,St,o)):(St.clickFn=Ct,j(a)&&Et(),it||(\"zoom\"===o?(St.moveFn=Lt,St.doneFn=Ot,St.minDrag=1,function(e,r,n){var a=vt.getBoundingClientRect();mt=r-a.left,yt=n-a.top,xt={l:mt,r:mt,w:0,t:yt,b:yt,h:0},bt=t._hmpixcount?t._hmlumcount/t._hmpixcount:i(t._fullLayout.plot_bgcolor).getLuminance(),wt=!1,kt=\"xy\",Mt=!1,Tt=I(ht,bt,J,K,_t=\"M0,0H\"+$+\"V\"+Q+\"H0V0\"),At=D(ht,J,K)}(0,r,n)):\"pan\"===o&&(St.moveFn=Ft,St.doneFn=jt))),t._fullLayout._redrag=function(){var e=t._dragdata;e&&e.element===vt&&(j(t._fullLayout.dragmode)||(dt(),Ut([0,0,$,Q]),St.moveFn(e.dx,e.dy)))}},d.init(St);var zt=[0,0,$,Q],It=null,Dt=T.REDRAWDELAY,Rt=e.mainplot?t._fullLayout._plots[e.mainplot]:e;function Ft(e,r){if(!t._transitioningWithDuration){if(t._fullLayout._replotting=!0,\"ew\"===rt||\"ns\"===nt)return rt&&(O(X,e),Bt(\"x\")),nt&&(O(Z,r),Bt(\"y\")),Ut([rt?-e:0,nt?-r:0,$,Q]),Nt(),void t.emit(\"plotly_relayouting\",ut);if(tt.isSubplotConstrained&&rt&&nt){var n=\"w\"===rt==(\"n\"===nt)?1:-1,i=(e/$+n*r/Q)/2;e=i*$,r=n*i*Q}\"w\"===rt?e=l(X,0,e):\"e\"===rt?e=l(X,1,-e):rt||(e=0),\"n\"===nt?r=l(Z,1,r):\"s\"===nt?r=l(Z,0,-r):nt||(r=0);var a=\"w\"===rt?e:0,o=\"n\"===nt?r:0;if(tt.isSubplotConstrained){var s;if(!rt&&1===nt.length){for(s=0;s<X.length;s++)X[s].range=X[s]._r.slice(),k(X[s],1-r/Q);a=(e=r*$/Q)/2}if(!nt&&1===rt.length){for(s=0;s<Z.length;s++)Z[s].range=Z[s]._r.slice(),k(Z[s],1-e/$);o=(r=e*Q/$)/2}}Bt(\"x\"),Bt(\"y\"),Ut([a,o,$-e,Q-r]),Nt(),t.emit(\"plotly_relayouting\",ut)}function l(t,e,r){for(var n,i,a=1-e,o=0;o<t.length;o++){var s=t[o];if(!s.fixedrange){n=s,i=s._rl[a]+(s._rl[e]-s._rl[a])/z(r/s._length);var l=s.l2r(i);!1!==l&&void 0!==l&&(s.range[e]=l)}}return n._length*(n._rl[e]-i)/(n._rl[e]-n._rl[a])}}function Bt(t,e){for(var r=et.isSubplotConstrained?{x:Z,y:X}[t]:et[t+\"axes\"],n=et.isSubplotConstrained?{x:X,y:Z}[t]:[],i=0;i<r.length;i++){var a=r[i],o=a._id,s=et.xLinks[o]||et.yLinks[o],l=n[0]||Y[s]||W[s];l&&(e?(e[a._name+\".range[0]\"]=e[l._name+\".range[0]\"],e[a._name+\".range[1]\"]=e[l._name+\".range[1]\"]):a.range=l.range.slice())}}function Nt(){var e,r=[];function n(t){for(e=0;e<t.length;e++)t[e].fixedrange||r.push(t[e]._id)}for(at&&(n(X),n(tt.xaxes),n(et.xaxes)),ot&&(n(Z),n(tt.yaxes),n(et.yaxes)),ut={},e=0;e<r.length;e++){var i=r[e],a=x(t,i);f.drawOne(t,a,{skipTitle:!0}),ut[a._name+\".range[0]\"]=a.range[0],ut[a._name+\".range[1]\"]=a.range[1]}f.redrawComponents(t,r)}function jt(){Ut([0,0,$,Q]),s.syncOrAsync([y.previousPromises,function(){t._fullLayout._replotting=!1,o.call(\"_guiRelayout\",t,ut)}],t)}function Ut(e){var r,n,i,a,l=t._fullLayout,c=l._plots,h=l._subplots.cartesian;if(lt&&o.subplotsRegistry.splom.drag(t),st)for(r=0;r<h.length;r++)if(i=(n=c[h[r]]).xaxis,a=n.yaxis,n._scene){var f=s.simpleMap(i.range,i.r2l),p=s.simpleMap(a.range,a.r2l);n._scene.update({range:[f[0],p[0],f[1],p[1]]})}if((lt||st)&&(v(t),m(t)),ct){var d=e[2]/F._length,g=e[3]/G._length;for(r=0;r<h.length;r++){i=(n=c[h[r]]).xaxis,a=n.yaxis;var y,x,b,_,w=at&&!i.fixedrange&&Y[i._id],k=ot&&!a.fixedrange&&W[a._id];if(w?(y=d,b=E?e[0]:Ht(i,y)):et.xaHash[i._id]?(y=d,b=e[0]*i._length/F._length):et.yaHash[i._id]?(y=g,b=\"ns\"===nt?-e[1]*i._length/G._length:Ht(i,y,{n:\"top\",s:\"bottom\"}[nt])):b=qt(i,y=Vt(i,d,g)),k?(x=g,_=S?e[1]:Ht(a,x)):et.yaHash[a._id]?(x=g,_=e[1]*a._length/G._length):et.xaHash[a._id]?(x=d,_=\"ew\"===rt?-e[0]*a._length/F._length:Ht(a,x,{e:\"right\",w:\"left\"}[rt])):_=qt(a,x=Vt(a,d,g)),y||x){y||(y=1),x||(x=1);var T=i._offset-b/y,A=a._offset-_/x;n.clipRect.call(u.setTranslate,b,_).call(u.setScale,y,x),n.plot.call(u.setTranslate,T,A).call(u.setScale,1/y,1/x),y===n.xScaleFactor&&x===n.yScaleFactor||(u.setPointGroupScale(n.zoomScalePts,y,x),u.setTextPointsScale(n.zoomScaleTxt,y,x)),u.hideOutsideRangePoints(n.clipOnAxisFalseTraces,n),n.xScaleFactor=y,n.yScaleFactor=x}}}}function Vt(t,e,r){return t.fixedrange?0:at&&tt.xaHash[t._id]?e:ot&&(tt.isSubplotConstrained?tt.xaHash:tt.yaHash)[t._id]?r:0}function qt(t,e){return e?(t.range=t._r.slice(),k(t,e),Ht(t,e)):0}function Ht(t,e,r){return t._length*(1-e)*g[r||t.constraintoward||\"middle\"]}return S.length*E.length!=1&&q(vt,function(e){if(t._context._scrollZoom.cartesian||t._fullLayout._enablescrollzoom){if(Et(),t._transitioningWithDuration)return e.preventDefault(),void e.stopPropagation();dt(),clearTimeout(It);var r=-e.deltaY;if(isFinite(r)||(r=e.wheelDelta/10),isFinite(r)){var n,i=Math.exp(-Math.min(Math.max(r,-20),20)/200),a=Rt.draglayer.select(\".nsewdrag\").node().getBoundingClientRect(),o=(e.clientX-a.left)/a.width,l=(a.bottom-e.clientY)/a.height;if(at){for(E||(o=.5),n=0;n<X.length;n++)c(X[n],o,i);Bt(\"x\"),zt[2]*=i,zt[0]+=zt[2]*o*(1/i-1)}if(ot){for(S||(l=.5),n=0;n<Z.length;n++)c(Z[n],l,i);Bt(\"y\"),zt[3]*=i,zt[1]+=zt[3]*(1-l)*(1/i-1)}Ut(zt),Nt(),t.emit(\"plotly_relayouting\",ut),It=setTimeout(function(){zt=[0,0,$,Q],jt()},Dt),e.preventDefault()}else s.log(\"Did not find wheel motion attributes: \",e)}function c(t,e,r){if(!t.fixedrange){var n=s.simpleMap(t.range,t.r2l),i=n[0]+(n[1]-n[0])*e;t.range=n.map(function(e){return t.l2r(i+(e-i)*r)})}}}),vt},makeDragger:E,makeRectDragger:C,makeZoombox:I,makeCorners:D,updateZoombox:R,xyCorners:U,transitionZoombox:F,removeZoombox:B,showDoubleClickNotifier:N,attachWheelEventHandler:q}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/clear_gl_canvases\":704,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../plot_api/subroutines\":758,\"../../registry\":847,\"../plots\":828,\"./axes\":767,\"./axis_ids\":770,\"./constants\":773,\"./scale_zoom\":783,\"./select\":784,d3:163,\"has-passive-events\":411,tinycolor2:537}],776:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/fx\"),a=t(\"../../components/dragelement\"),o=t(\"../../lib/setcursor\"),s=t(\"./dragbox\").makeDragBox,l=t(\"./constants\").DRAGGERSIZE;r.initInteractions=function(t){var e=t._fullLayout;if(t._context.staticPlot)n.select(t).selectAll(\".drag\").remove();else if(e._has(\"cartesian\")||e._has(\"splom\")){Object.keys(e._plots||{}).sort(function(t,r){if((e._plots[t].mainplot&&!0)===(e._plots[r].mainplot&&!0)){var n=t.split(\"y\"),i=r.split(\"y\");return n[0]===i[0]?Number(n[1]||1)-Number(i[1]||1):Number(n[0]||1)-Number(i[0]||1)}return e._plots[t].mainplot?1:-1}).forEach(function(r){var n=e._plots[r],o=n.xaxis,c=n.yaxis;if(!n.mainplot){var u=s(t,n,o._offset,c._offset,o._length,c._length,\"ns\",\"ew\");u.onmousemove=function(e){t._fullLayout._rehover=function(){t._fullLayout._hoversubplot===r&&i.hover(t,e,r)},i.hover(t,e,r),t._fullLayout._lasthover=u,t._fullLayout._hoversubplot=r},u.onmouseout=function(e){t._dragging||(t._fullLayout._hoversubplot=null,a.unhover(t,e))},t._context.showAxisDragHandles&&(s(t,n,o._offset-l,c._offset-l,l,l,\"n\",\"w\"),s(t,n,o._offset+o._length,c._offset-l,l,l,\"n\",\"e\"),s(t,n,o._offset-l,c._offset+c._length,l,l,\"s\",\"w\"),s(t,n,o._offset+o._length,c._offset+c._length,l,l,\"s\",\"e\"))}if(t._context.showAxisDragHandles){if(r===o._mainSubplot){var h=o._mainLinePosition;\"top\"===o.side&&(h-=l),s(t,n,o._offset+.1*o._length,h,.8*o._length,l,\"\",\"ew\"),s(t,n,o._offset,h,.1*o._length,l,\"\",\"w\"),s(t,n,o._offset+.9*o._length,h,.1*o._length,l,\"\",\"e\")}if(r===c._mainSubplot){var f=c._mainLinePosition;\"right\"!==c.side&&(f-=l),s(t,n,f,c._offset+.1*c._length,l,.8*c._length,\"ns\",\"\"),s(t,n,f,c._offset+.9*c._length,l,.1*c._length,\"s\",\"\"),s(t,n,f,c._offset,l,.1*c._length,\"n\",\"\")}}});var o=e._hoverlayer.node();o.onmousemove=function(r){r.target=t._fullLayout._lasthover,i.hover(t,r,e._hoversubplot)},o.onclick=function(e){e.target=t._fullLayout._lasthover,i.click(t,e)},o.onmousedown=function(e){t._fullLayout._lasthover.onmousedown(e)},r.updateFx(t)}},r.updateFx=function(t){var e=t._fullLayout,r=\"pan\"===e.dragmode?\"move\":\"crosshair\";o(e._draggers,r)}},{\"../../components/dragelement\":611,\"../../components/fx\":632,\"../../lib/setcursor\":739,\"./constants\":773,\"./dragbox\":775,d3:163}],777:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t){return function(e,r){var a=e[t];if(Array.isArray(a))for(var o=n.subplotsRegistry.cartesian,s=o.idRegex,l=r._subplots,c=l.xaxis,u=l.yaxis,h=l.cartesian,f=r._has(\"cartesian\")||r._has(\"gl2d\"),p=0;p<a.length;p++){var d=a[p];if(i.isPlainObject(d)){var g=d.xref,v=d.yref,m=s.x.test(g),y=s.y.test(v);if(m||y){f||i.pushUnique(r._basePlotModules,o);var x=!1;m&&-1===c.indexOf(g)&&(c.push(g),x=!0),y&&-1===u.indexOf(v)&&(u.push(v),x=!0),x&&m&&y&&h.push(g+v)}}}}}},{\"../../lib\":719,\"../../registry\":847}],778:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../plots\"),s=t(\"../../components/drawing\"),l=t(\"../get_data\").getModuleCalcData,c=t(\"./axis_ids\"),u=t(\"./constants\"),h=t(\"../../constants/xmlns_namespaces\"),f=a.ensureSingle;function p(t,e,r){return a.ensureSingle(t,e,r,function(t){t.datum(r)})}function d(t,e,r,a,o){for(var c,h,f,p=u.traceLayerClasses,d=t._fullLayout,g=d._modules,v=[],m=[],y=0;y<g.length;y++){var x=(c=g[y]).name,b=i.modules[x].categories;if(b.svg){var _=c.layerName||x+\"layer\",w=c.plot;f=(h=l(r,w))[0],r=h[1],f.length&&v.push({i:p.indexOf(_),className:_,plotMethod:w,cdModule:f}),b.zoomScale&&m.push(\".\"+_)}}v.sort(function(t,e){return t.i-e.i});var k=e.plot.selectAll(\"g.mlayer\").data(v,function(t){return t.className});if(k.enter().append(\"g\").attr(\"class\",function(t){return t.className}).classed(\"mlayer\",!0).classed(\"rangeplot\",e.isRangePlot),k.exit().remove(),k.order(),k.each(function(r){var i=n.select(this),l=r.className;r.plotMethod(t,e,r.cdModule,i,a,o),-1===u.clipOnAxisFalseQuery.indexOf(\".\"+l)&&s.setClipUrl(i,e.layerClipId,t)}),d._has(\"scattergl\")&&(c=i.getModule(\"scattergl\"),f=l(r,c)[0],c.plot(t,e,f)),!t._context.staticPlot&&(e._hasClipOnAxisFalse&&(e.clipOnAxisFalseTraces=e.plot.selectAll(u.clipOnAxisFalseQuery.join(\",\")).selectAll(\".trace\")),m.length)){var T=e.plot.selectAll(m.join(\",\")).selectAll(\".trace\");e.zoomScalePts=T.selectAll(\"path.point\"),e.zoomScaleTxt=T.selectAll(\".textpoint\")}}function g(t,e){var r=e.plotgroup,n=e.id,i=u.layerValue2layerClass[e.xaxis.layer],a=u.layerValue2layerClass[e.yaxis.layer],o=t._fullLayout._hasOnlyLargeSploms;if(e.mainplot){var s=e.mainplotinfo,l=s.plotgroup,h=n+\"-x\",d=n+\"-y\";e.gridlayer=s.gridlayer,e.zerolinelayer=s.zerolinelayer,f(s.overlinesBelow,\"path\",h),f(s.overlinesBelow,\"path\",d),f(s.overaxesBelow,\"g\",h),f(s.overaxesBelow,\"g\",d),e.plot=f(s.overplot,\"g\",n),f(s.overlinesAbove,\"path\",h),f(s.overlinesAbove,\"path\",d),f(s.overaxesAbove,\"g\",h),f(s.overaxesAbove,\"g\",d),e.xlines=l.select(\".overlines-\"+i).select(\".\"+h),e.ylines=l.select(\".overlines-\"+a).select(\".\"+d),e.xaxislayer=l.select(\".overaxes-\"+i).select(\".\"+h),e.yaxislayer=l.select(\".overaxes-\"+a).select(\".\"+d)}else if(o)e.xlines=f(r,\"path\",\"xlines-above\"),e.ylines=f(r,\"path\",\"ylines-above\"),e.xaxislayer=f(r,\"g\",\"xaxislayer-above\"),e.yaxislayer=f(r,\"g\",\"yaxislayer-above\");else{var g=f(r,\"g\",\"layer-subplot\");e.shapelayer=f(g,\"g\",\"shapelayer\"),e.imagelayer=f(g,\"g\",\"imagelayer\"),e.gridlayer=f(r,\"g\",\"gridlayer\"),e.zerolinelayer=f(r,\"g\",\"zerolinelayer\"),f(r,\"path\",\"xlines-below\"),f(r,\"path\",\"ylines-below\"),e.overlinesBelow=f(r,\"g\",\"overlines-below\"),f(r,\"g\",\"xaxislayer-below\"),f(r,\"g\",\"yaxislayer-below\"),e.overaxesBelow=f(r,\"g\",\"overaxes-below\"),e.plot=f(r,\"g\",\"plot\"),e.overplot=f(r,\"g\",\"overplot\"),e.xlines=f(r,\"path\",\"xlines-above\"),e.ylines=f(r,\"path\",\"ylines-above\"),e.overlinesAbove=f(r,\"g\",\"overlines-above\"),f(r,\"g\",\"xaxislayer-above\"),f(r,\"g\",\"yaxislayer-above\"),e.overaxesAbove=f(r,\"g\",\"overaxes-above\"),e.xlines=r.select(\".xlines-\"+i),e.ylines=r.select(\".ylines-\"+a),e.xaxislayer=r.select(\".xaxislayer-\"+i),e.yaxislayer=r.select(\".yaxislayer-\"+a)}o||(p(e.gridlayer,\"g\",e.xaxis._id),p(e.gridlayer,\"g\",e.yaxis._id),e.gridlayer.selectAll(\"g\").map(function(t){return t[0]}).sort(c.idSort)),e.xlines.style(\"fill\",\"none\").classed(\"crisp\",!0),e.ylines.style(\"fill\",\"none\").classed(\"crisp\",!0)}function v(t,e){if(t){var r={};for(var i in t.each(function(t){var i=t[0];n.select(this).remove(),m(i,e),r[i]=!0}),e._plots)for(var a=e._plots[i].overlays||[],o=0;o<a.length;o++){var s=a[o];r[s.id]&&s.plot.selectAll(\".trace\").remove()}}}function m(t,e){e._draggers.selectAll(\"g.\"+t).remove(),e._defs.select(\"#clip\"+e._uid+t+\"plot\").remove()}r.name=\"cartesian\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=u.idRegex,r.attrRegex=u.attrRegex,r.attributes=t(\"./attributes\"),r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.transitionAxes=t(\"./transition_axes\"),r.finalizeSubplots=function(t,e){var r,n,i,o=e._subplots,s=o.xaxis,l=o.yaxis,h=o.cartesian,f=h.concat(o.gl2d||[]),p={},d={};for(r=0;r<f.length;r++){var g=f[r].split(\"y\");p[g[0]]=1,d[\"y\"+g[1]]=1}for(r=0;r<s.length;r++)p[n=s[r]]||(i=(t[c.id2name(n)]||{}).anchor,u.idRegex.y.test(i)||(i=\"y\"),h.push(n+i),f.push(n+i),d[i]||(d[i]=1,a.pushUnique(l,i)));for(r=0;r<l.length;r++)d[i=l[r]]||(n=(t[c.id2name(i)]||{}).anchor,u.idRegex.x.test(n)||(n=\"x\"),h.push(n+i),f.push(n+i),p[n]||(p[n]=1,a.pushUnique(s,n)));if(!f.length){for(var v in n=\"\",i=\"\",t){if(u.attrRegex.test(v))\"x\"===v.charAt(0)?(!n||+v.substr(5)<+n.substr(5))&&(n=v):(!i||+v.substr(5)<+i.substr(5))&&(i=v)}n=n?c.name2id(n):\"x\",i=i?c.name2id(i):\"y\",s.push(n),l.push(i),h.push(n+i)}},r.plot=function(t,e,r,n){var i,a=t._fullLayout,o=a._subplots.cartesian,s=t.calcdata;if(!Array.isArray(e))for(e=[],i=0;i<s.length;i++)e.push(i);for(i=0;i<o.length;i++){for(var l,c=o[i],u=a._plots[c],h=[],f=0;f<s.length;f++){var p=s[f],g=p[0].trace;g.xaxis+g.yaxis===c&&((-1!==e.indexOf(g.index)||g.carpet)&&(l&&l[0].trace.xaxis+l[0].trace.yaxis===c&&-1!==[\"tonextx\",\"tonexty\",\"tonext\"].indexOf(g.fill)&&-1===h.indexOf(l)&&h.push(l),h.push(p)),l=p)}d(t,u,h,r,n)}},r.clean=function(t,e,r,n){var i,a,o,s=n._plots||{},l=e._plots||{},u=n._subplots||{};if(n._hasOnlyLargeSploms&&!e._hasOnlyLargeSploms)for(o in s)(i=s[o]).plotgroup&&i.plotgroup.remove();var h=n._has&&n._has(\"gl\"),f=e._has&&e._has(\"gl\");if(h&&!f)for(o in s)(i=s[o])._scene&&i._scene.destroy();if(u.xaxis&&u.yaxis){var p=c.listIds({_fullLayout:n});for(a=0;a<p.length;a++){var d=p[a];e[c.id2name(d)]||n._infolayer.selectAll(\".g-\"+d+\"title\").remove()}}var g=n._has&&n._has(\"cartesian\"),y=e._has&&e._has(\"cartesian\");if(g&&!y)v(n._cartesianlayer.selectAll(\".subplot\"),n),n._defs.selectAll(\".axesclip\").remove(),delete n._axisConstraintGroups;else if(u.cartesian)for(a=0;a<u.cartesian.length;a++){var x=u.cartesian[a];if(!l[x]){var b=\".\"+x+\",.\"+x+\"-x,.\"+x+\"-y\";n._cartesianlayer.selectAll(b).remove(),m(x,n)}}},r.drawFramework=function(t){var e=t._fullLayout,r=function(t){var e,r,n,i,a,o,s=t._fullLayout,l=s._subplots.cartesian,c=l.length,u=[],h=[];for(e=0;e<c;e++){n=l[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var f=a._mainAxis,p=o._mainAxis,d=f._id+p._id,g=s._plots[d];i.overlays=[],d!==n&&g?(i.mainplot=d,i.mainplotinfo=g,h.push(n)):(i.mainplot=void 0,i.mainPlotinfo=void 0,u.push(n))}for(e=0;e<h.length;e++)n=h[e],(i=s._plots[n]).mainplotinfo.overlays.push(i);var v=u.concat(h),m=new Array(c);for(e=0;e<c;e++){n=v[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var y=[n,a.layer,o.layer,a.overlaying||\"\",o.overlaying||\"\"];for(r=0;r<i.overlays.length;r++)y.push(i.overlays[r].id);m[e]=y}return m}(t),i=e._cartesianlayer.selectAll(\".subplot\").data(r,String);i.enter().append(\"g\").attr(\"class\",function(t){return\"subplot \"+t[0]}),i.order(),i.exit().call(v,e),i.each(function(r){var i=r[0],a=e._plots[i];a.plotgroup=n.select(this),g(t,a),a.draglayer=f(e._draggers,\"g\",i)})},r.rangePlot=function(t,e,r){g(t,e),d(t,e,r),o.style(t)},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter(function(t,e){return e===r.size()-1}).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each(function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:h.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})})},r.updateFx=t(\"./graph_interact\").updateFx},{\"../../components/drawing\":614,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../registry\":847,\"../get_data\":802,\"../plots\":828,\"./attributes\":765,\"./axis_ids\":770,\"./constants\":773,\"./graph_interact\":776,\"./layout_attributes\":779,\"./layout_defaults\":780,\"./transition_axes\":789,d3:163}],779:[function(t,e,r){\"use strict\";var n=t(\"../font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray,l=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").DATE_FORMAT_LINK,t(\"./constants\"));e.exports={visible:{valType:\"boolean\",editType:\"plot\"},color:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},title:{text:{valType:\"string\",editType:\"ticks\"},font:n({editType:\"ticks\"}),editType:\"ticks\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"log\",\"date\",\"category\",\"multicategory\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"axrange\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0},{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0}],editType:\"axrange\",impliedEdits:{autorange:!1},anim:!0},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},scaleanchor:{valType:\"enumerated\",values:[l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},scaleratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},constrain:{valType:\"enumerated\",values:[\"range\",\"domain\"],dflt:\"range\",editType:\"plot\"},constraintoward:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\",\"top\",\"middle\",\"bottom\"],editType:\"plot\"},matches:{valType:\"enumerated\",values:[l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"calc\"},tickmode:{valType:\"enumerated\",values:[\"auto\",\"linear\",\"array\"],editType:\"ticks\",impliedEdits:{tick0:void 0,dtick:void 0}},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"ticks\"},tick0:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},dtick:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},tickvals:{valType:\"data_array\",editType:\"ticks\"},ticktext:{valType:\"data_array\",editType:\"ticks\"},ticks:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"\"],editType:\"ticks\"},tickson:{valType:\"enumerated\",values:[\"labels\",\"boundaries\"],dflt:\"labels\",editType:\"ticks\"},mirror:{valType:\"enumerated\",values:[!0,\"ticks\",!1,\"all\",\"allticks\"],dflt:!1,editType:\"ticks+layoutstyle\"},ticklen:{valType:\"number\",min:0,dflt:5,editType:\"ticks\"},tickwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},tickcolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},showticklabels:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},automargin:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},showspikes:{valType:\"boolean\",dflt:!1,editType:\"modebar\"},spikecolor:{valType:\"color\",dflt:null,editType:\"none\"},spikethickness:{valType:\"number\",dflt:3,editType:\"none\"},spikedash:o({},a,{dflt:\"dash\",editType:\"none\"}),spikemode:{valType:\"flaglist\",flags:[\"toaxis\",\"across\",\"marker\"],dflt:\"toaxis\",editType:\"none\"},spikesnap:{valType:\"enumerated\",values:[\"data\",\"cursor\"],dflt:\"data\",editType:\"none\"},tickfont:n({editType:\"ticks\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"ticks\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"ticks\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"ticks\"},tickformatstops:s(\"tickformatstop\",{enabled:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dtickrange:{valType:\"info_array\",items:[{valType:\"any\",editType:\"ticks\"},{valType:\"any\",editType:\"ticks\"}],editType:\"ticks\"},value:{valType:\"string\",dflt:\"\",editType:\"ticks\"},editType:\"ticks\"}),hoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},showline:{valType:\"boolean\",dflt:!1,editType:\"ticks+layoutstyle\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"layoutstyle\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks+layoutstyle\"},showgrid:{valType:\"boolean\",editType:\"ticks\"},gridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"ticks\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},zeroline:{valType:\"boolean\",editType:\"ticks\"},zerolinecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},zerolinewidth:{valType:\"number\",dflt:1,editType:\"ticks\"},showdividers:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dividercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},dividerwidth:{valType:\"number\",dflt:1,editType:\"ticks\"},anchor:{valType:\"enumerated\",values:[\"free\",l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},side:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],editType:\"plot\"},overlaying:{valType:\"enumerated\",values:[\"free\",l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},layer:{valType:\"enumerated\",values:[\"above traces\",\"below traces\"],dflt:\"above traces\",editType:\"plot\"},domain:{valType:\"info_array\",items:[{valType:\"number\",min:0,max:1,editType:\"plot\"},{valType:\"number\",min:0,max:1,editType:\"plot\"}],dflt:[0,1],editType:\"plot\"},position:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\",\"total ascending\",\"total descending\",\"min ascending\",\"min descending\",\"max ascending\",\"max descending\",\"sum ascending\",\"sum descending\",\"mean ascending\",\"mean descending\",\"median ascending\",\"median descending\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{autotick:{valType:\"boolean\",editType:\"ticks\"},title:{valType:\"string\",editType:\"ticks\"},titlefont:n({editType:\"ticks\"})}}},{\"../../components/color/attributes\":592,\"../../components/drawing/attributes\":613,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../font_attributes\":793,\"./constants\":773}],780:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../layout_attributes\"),s=t(\"./layout_attributes\"),l=t(\"./type_defaults\"),c=t(\"./axis_defaults\"),u=t(\"./constraints\").handleConstraintDefaults,h=t(\"./position_defaults\"),f=t(\"./axis_ids\"),p=f.id2name,d=f.name2id,g=t(\"../../registry\"),v=g.traceIs,m=g.getComponentMethod;function y(t,e,r){Array.isArray(t[e])?t[e].push(r):t[e]=[r]}e.exports=function(t,e,r){var f,g,x={},b={},_={},w={},k={},T={},A={},M={},S={};for(f=0;f<r.length;f++){var E=r[f];if(v(E,\"cartesian\")||v(E,\"gl2d\")){var C,L;if(E.xaxis)y(x,C=p(E.xaxis),E);else if(E.xaxes)for(g=0;g<E.xaxes.length;g++)y(x,p(E.xaxes[g]),E);if(E.yaxis)y(x,L=p(E.yaxis),E);else if(E.yaxes)for(g=0;g<E.yaxes.length;g++)y(x,p(E.yaxes[g]),E);if(\"funnel\"===E.type?\"h\"===E.orientation?(C&&(b[C]=!0),L&&(A[L]=!0)):L&&(_[L]=!0):(L&&(k[L]=!0,T[L]=!0),v(E,\"carpet\")&&(\"carpet\"!==E.type||E._cheater)||C&&(w[C]=!0)),\"carpet\"===E.type&&E._cheater&&C&&(b[C]=!0),v(E,\"2dMap\")&&(M[C]=!0,M[L]=!0),v(E,\"oriented\"))S[\"h\"===E.orientation?L:C]=!0}}var P=e._subplots,O=P.xaxis,z=P.yaxis,I=n.simpleMap(O,p),D=n.simpleMap(z,p),R=I.concat(D),F=i.background;O.length&&z.length&&(F=n.coerce(t,e,o,\"plot_bgcolor\"));var B,N,j,U,V=i.combine(F,e.paper_bgcolor);function q(t,e){return n.coerce(j,U,s,t,e)}function H(t,e){return n.coerce2(j,U,s,t,e)}function G(t){return\"x\"===t?z:O}var Y={x:G(\"x\"),y:G(\"y\")},W=Y.x.concat(Y.y);function X(e,r){for(var n=\"x\"===e?I:D,i=[],a=0;a<n.length;a++){var o=n[a];o===r||(t[o]||{}).overlaying||i.push(d(o))}return i}for(f=0;f<R.length;f++){N=(B=R[f]).charAt(0),n.isPlainObject(t[B])||(t[B]={}),j=t[B],U=a.newContainer(e,B,N+\"axis\");var Z=x[B]||[];U._traceIndices=Z.map(function(t){return t._expandedIndex}),U._annIndices=[],U._shapeIndices=[],U._imgIndices=[],U._subplotsWith=[],U._counterAxes=[],U._name=U._attr=B;var J=U._id=d(B),K=X(N,B),$=\"x\"===N&&!w[B]&&b[B]||\"y\"===N&&!k[B]&&_[B],Q=\"y\"===N&&!T[B]&&A[B],tt={letter:N,font:e.font,outerTicks:M[B],showGrid:!S[B],data:Z,bgColor:V,calendar:e.calendar,automargin:!0,visibleDflt:$,reverseDflt:Q,splomStash:((e._splomAxes||{})[N]||{})[J]};q(\"uirevision\",e.uirevision),l(j,U,q,tt),c(j,U,q,tt,e);var et=H(\"spikecolor\"),rt=H(\"spikethickness\"),nt=H(\"spikedash\"),it=H(\"spikemode\"),at=H(\"spikesnap\");q(\"showspikes\",!!(et||rt||nt||it||at))||(delete U.spikecolor,delete U.spikethickness,delete U.spikedash,delete U.spikemode,delete U.spikesnap),h(j,U,q,{letter:N,counterAxes:Y[N],overlayableAxes:K,grid:e.grid}),U._input=j}var ot=m(\"rangeslider\",\"handleDefaults\"),st=m(\"rangeselector\",\"handleDefaults\");for(f=0;f<I.length;f++)B=I[f],j=t[B],U=e[B],ot(t,e,B),\"date\"===U.type&&st(j,U,e,D,U.calendar),q(\"fixedrange\");for(f=0;f<D.length;f++){B=D[f],j=t[B],U=e[B];var lt=e[p(U.anchor)];q(\"fixedrange\",m(\"rangeslider\",\"isVisible\")(lt))}var ct=e._axisConstraintGroups=[],ut=e._axisMatchGroups=[];for(f=0;f<R.length;f++)N=(B=R[f]).charAt(0),j=t[B],U=e[B],u(j,U,q,W,e);for(f=0;f<ut.length;f++){var ht,ft=ut[f],pt=null,dt=null;for(ht in ft)(U=e[p(ht)]).matches||(pt=U.range,dt=U.autorange);if(null===pt||null===dt)for(ht in ft){pt=(U=e[p(ht)]).range,dt=U.autorange;break}for(ht in ft)(U=e[p(ht)]).matches&&(U.range=pt.slice(),U.autorange=dt),U._matchGroup=ft;if(ct.length)for(ht in ft)for(g=0;g<ct.length;g++){var gt=ct[g];for(var vt in gt)ht===vt&&(n.warn(\"Axis \"+vt+\" is set with both a *scaleanchor* and *matches* constraint; ignoring the scale constraint.\"),delete gt[vt],Object.keys(gt).length<2&&ct.splice(g,1))}}}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../registry\":847,\"../layout_attributes\":819,\"./axis_defaults\":769,\"./axis_ids\":770,\"./constraints\":774,\"./layout_attributes\":779,\"./position_defaults\":782,\"./type_defaults\":790}],781:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../components/color/attributes\").lightFraction,a=t(\"../../lib\");e.exports=function(t,e,r,o){var s=(o=o||{}).dfltColor;function l(r,n){return a.coerce2(t,e,o.attributes,r,n)}var c=l(\"linecolor\",s),u=l(\"linewidth\");r(\"showline\",o.showLine||!!c||!!u)||(delete e.linecolor,delete e.linewidth);var h=l(\"gridcolor\",n(s,o.bgColor,o.blend||i).toRgbString()),f=l(\"gridwidth\");if(r(\"showgrid\",o.showGrid||!!h||!!f)||(delete e.gridcolor,delete e.gridwidth),!o.noZeroLine){var p=l(\"zerolinecolor\",s),d=l(\"zerolinewidth\");r(\"zeroline\",o.showGrid||!!p||!!d)||(delete e.zerolinecolor,delete e.zerolinewidth)}}},{\"../../components/color/attributes\":592,\"../../lib\":719,tinycolor2:537}],782:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o,s,l,c,u=a.counterAxes||[],h=a.overlayableAxes||[],f=a.letter,p=a.grid;p&&(s=p._domains[f][p._axisMap[e._id]],o=p._anchors[e._id],s&&(l=p[f+\"side\"].split(\" \")[0],c=p.domain[f][\"right\"===l||\"top\"===l?1:0])),s=s||[0,1],o=o||(n(t.position)?\"free\":u[0]||\"free\"),l=l||(\"x\"===f?\"bottom\":\"left\"),c=c||0,\"free\"===i.coerce(t,e,{anchor:{valType:\"enumerated\",values:[\"free\"].concat(u),dflt:o}},\"anchor\")&&r(\"position\",c),i.coerce(t,e,{side:{valType:\"enumerated\",values:\"x\"===f?[\"bottom\",\"top\"]:[\"left\",\"right\"],dflt:l}},\"side\");var d=!1;if(h.length&&(d=i.coerce(t,e,{overlaying:{valType:\"enumerated\",values:[!1].concat(h),dflt:!1}},\"overlaying\")),!d){var g=r(\"domain\",s);g[0]>g[1]-1/4096&&(e.domain=s),i.noneOrAll(t.domain,e.domain,s)}return r(\"layer\"),e}},{\"../../lib\":719,\"fast-isnumeric\":225}],783:[function(t,e,r){\"use strict\";var n=t(\"../../constants/alignment\").FROM_BL;e.exports=function(t,e,r){void 0===r&&(r=n[t.constraintoward||\"center\"]);var i=[t.r2l(t.range[0]),t.r2l(t.range[1])],a=i[0]+(i[1]-i[0])*r;t.range=t._input.range=[t.l2r(a+(i[0]-a)*e),t.l2r(a+(i[1]-a)*e)]}},{\"../../constants/alignment\":688}],784:[function(t,e,r){\"use strict\";var n=t(\"polybooljs\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../../components/fx\"),s=t(\"../../lib\"),l=t(\"../../lib/polygon\"),c=t(\"../../lib/throttle\"),u=t(\"../../components/fx/helpers\").makeEventData,h=t(\"./axis_ids\").getFromId,f=t(\"../../lib/clear_gl_canvases\"),p=t(\"../../plot_api/subroutines\").redrawReglTraces,d=t(\"./constants\"),g=d.MINSELECT,v=l.filter,m=l.tester;function y(t){return t._id}function x(t,e,r,n,i,a,o){var s,l,c,u,h,f,p,d,g,v=e._hoverdata,m=e._fullLayout.clickmode.indexOf(\"event\")>-1,y=[];if(function(t){return t&&Array.isArray(t)&&!0!==t[0].hoverOnBox}(v)){k(t,e,a);var x=function(t,e){var r,n,i=t[0],a=-1,o=[];for(n=0;n<e.length;n++)if(r=e[n],i.fullData._expandedIndex===r.cd[0].trace._expandedIndex){if(!0===i.hoverOnBox)break;void 0!==i.pointNumber?a=i.pointNumber:void 0!==i.binNumber&&(a=i.binNumber,o=i.pointNumbers);break}return{pointNumber:a,pointNumbers:o,searchInfo:r}}(v,s=A(e,r,n,i));if(x.pointNumbers.length>0?function(t,e){var r,n,i,a=[];for(i=0;i<t.length;i++)(r=t[i]).cd[0].trace.selectedpoints&&r.cd[0].trace.selectedpoints.length>0&&a.push(r);if(1===a.length&&a[0]===e.searchInfo&&(n=e.searchInfo.cd[0].trace).selectedpoints.length===e.pointNumbers.length){for(i=0;i<e.pointNumbers.length;i++)if(n.selectedpoints.indexOf(e.pointNumbers[i])<0)return!1;return!0}return!1}(s,x):function(t){var e,r,n,i=0;for(n=0;n<t.length;n++)if(e=t[n],(r=e.cd[0].trace).selectedpoints){if(r.selectedpoints.length>1)return!1;if((i+=r.selectedpoints.length)>1)return!1}return 1===i}(s)&&(f=S(x))){for(o&&o.remove(),g=0;g<s.length;g++)(l=s[g])._module.selectPoints(l,!1);E(e,s),T(a),m&&e.emit(\"plotly_deselect\",null)}else{for(p=t.shiftKey&&(void 0!==f?f:S(x)),c=function(t,e,r){return{pointNumber:t,searchInfo:e,subtract:r}}(x.pointNumber,x.searchInfo,p),u=w(a.selectionDefs.concat([c])),g=0;g<s.length;g++)if(h=C(s[g]._module.selectPoints(s[g],u),s[g]),y.length)for(var b=0;b<h.length;b++)y.push(h[b]);else y=h;E(e,s,d={points:y}),c&&a&&a.selectionDefs.push(c),o&&M(a.mergedPolygons,o),m&&e.emit(\"plotly_selected\",d)}}}function b(t){return\"pointNumber\"in t&&\"searchInfo\"in t}function _(t){return{xmin:0,xmax:0,ymin:0,ymax:0,pts:[],contains:function(e,r,n,i){var a=t.searchInfo.cd[0].trace._expandedIndex;return i.cd[0].trace._expandedIndex===a&&n===t.pointNumber},isRect:!1,degenerate:!1,subtract:t.subtract}}function w(t){for(var e=[],r=b(t[0])?0:t[0][0][0],n=r,i=b(t[0])?0:t[0][0][1],a=i,o=0;o<t.length;o++)if(b(t[o]))e.push(_(t[o]));else{var s=l.tester(t[o]);s.subtract=t[o].subtract,e.push(s),r=Math.min(r,s.xmin),n=Math.max(n,s.xmax),i=Math.min(i,s.ymin),a=Math.max(a,s.ymax)}return{xmin:r,xmax:n,ymin:i,ymax:a,pts:[],contains:function(t,r,n,i){for(var a=!1,o=0;o<e.length;o++)e[o].contains(t,r,n,i)&&(a=!1===e[o].subtract);return a},isRect:!1,degenerate:!1}}function k(t,e,r){var n=e._fullLayout,i=r.plotinfo,a=n._lastSelectedSubplot&&n._lastSelectedSubplot===i.id,o=t.shiftKey||t.altKey;a&&o&&i.selection&&i.selection.selectionDefs&&!r.selectionDefs?(r.selectionDefs=i.selection.selectionDefs,r.mergedPolygons=i.selection.mergedPolygons):o&&i.selection||T(r),a||(L(e),n._lastSelectedSubplot=i.id)}function T(t){var e=t.plotinfo;e.selection={},e.selection.selectionDefs=t.selectionDefs=[],e.selection.mergedPolygons=t.mergedPolygons=[]}function A(t,e,r,n){var i,a,o,s=[],l=e.map(y),c=r.map(y);for(o=0;o<t.calcdata.length;o++)if(!0===(a=(i=t.calcdata[o])[0].trace).visible&&a._module&&a._module.selectPoints)if(!n||a.subplot!==n&&a.geo!==n)if(\"splom\"===a.type&&a._xaxes[l[0]]&&a._yaxes[c[0]]){var u=p(a._module,i,e[0],r[0]);u.scene=t._fullLayout._splomScenes[a.uid],s.push(u)}else if(\"sankey\"===a.type){var f=p(a._module,i,e[0],r[0]);s.push(f)}else{if(-1===l.indexOf(a.xaxis))continue;if(-1===c.indexOf(a.yaxis))continue;s.push(p(a._module,i,h(t,a.xaxis),h(t,a.yaxis)))}else s.push(p(a._module,i,e[0],r[0]));return s;function p(t,e,r,n){return{_module:t,cd:e,xaxis:r,yaxis:n}}}function M(t,e){var r,n,i=[];for(r=0;r<t.length;r++){var a=t[r];i.push(a.join(\"L\")+\"L\"+a[0])}n=t.length>0?\"M\"+i.join(\"M\")+\"Z\":\"M0,0Z\",e.attr(\"d\",n)}function S(t){var e=t.searchInfo.cd[0].trace,r=t.pointNumber,n=t.pointNumbers,i=n.length>0?n[0]:r;return!!e.selectedpoints&&e.selectedpoints.indexOf(i)>-1}function E(t,e,r){var n,a,o,s;for(n=0;n<e.length;n++){var l=e[n].cd[0].trace._fullInput,c=t._fullLayout._tracePreGUI[l.uid]||{};void 0===c.selectedpoints&&(c.selectedpoints=l._input.selectedpoints||null)}if(r){var u=r.points||[];for(n=0;n<e.length;n++)(s=e[n].cd[0].trace)._input.selectedpoints=s._fullInput.selectedpoints=[],s._fullInput!==s&&(s.selectedpoints=[]);for(n=0;n<u.length;n++){var h=u[n],d=h.data,g=h.fullData;h.pointIndices?([].push.apply(d.selectedpoints,h.pointIndices),s._fullInput!==s&&[].push.apply(g.selectedpoints,h.pointIndices)):(d.selectedpoints.push(h.pointIndex),s._fullInput!==s&&g.selectedpoints.push(h.pointIndex))}}else for(n=0;n<e.length;n++)delete(s=e[n].cd[0].trace).selectedpoints,delete s._input.selectedpoints,s._fullInput!==s&&delete s._fullInput.selectedpoints;var v=!1;for(n=0;n<e.length;n++){s=(o=(a=e[n]).cd)[0].trace,i.traceIs(s,\"regl\")&&(v=!0);var m=a._module,y=m.styleOnSelect||m.style;y&&(y(t,o,o[0].node3),o[0].nodeRangePlot3&&y(t,o,o[0].nodeRangePlot3))}v&&(f(t),p(t))}function C(t,e){if(Array.isArray(t))for(var r=e.cd,n=e.cd[0].trace,i=0;i<t.length;i++)t[i]=u(t[i],n,r);return t}function L(t){var e=(t._fullLayout||{})._zoomlayer;e&&e.selectAll(\".select-outline\").remove()}e.exports={prepSelect:function(t,e,r,i,l){var u,h,f,p,y,b,_,S=i.gd,L=S._fullLayout,P=L._zoomlayer,O=i.element.getBoundingClientRect(),z=i.plotinfo,I=z.xaxis._offset,D=z.yaxis._offset,R=e-O.left,F=r-O.top,B=R,N=F,j=\"M\"+R+\",\"+F,U=i.xaxes[0]._length,V=i.yaxes[0]._length,q=i.xaxes.concat(i.yaxes),H=t.altKey;k(t,S,i),\"lasso\"===l&&(u=v([[R,F]],d.BENDPX));var G=P.selectAll(\"path.select-outline-\"+z.id).data([1,2]);G.enter().append(\"path\").attr(\"class\",function(t){return\"select-outline select-outline-\"+t+\" select-outline-\"+z.id}).attr(\"transform\",\"translate(\"+I+\", \"+D+\")\").attr(\"d\",j+\"Z\");var Y,W=P.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:a.background,stroke:a.defaultLine,\"stroke-width\":1}).attr(\"transform\",\"translate(\"+I+\", \"+D+\")\").attr(\"d\",\"M0,0Z\"),X=L._uid+d.SELECTID,Z=[],J=A(S,i.xaxes,i.yaxes,i.subplot);function K(t,e){return\"log\"===t.type?t.p2d(e):t.p2r(e)}function $(t){var e=\"y\"===t._id.charAt(0)?1:0;return function(r){return K(t,r[e])}}function Q(t,e){return t-e}Y=z.fillRangeItems?z.fillRangeItems:\"select\"===l?function(t,e){var r=t.range={};for(y=0;y<q.length;y++){var n=q[y],i=n._id.charAt(0);r[n._id]=[K(n,e[i+\"min\"]),K(n,e[i+\"max\"])].sort(Q)}}:function(t,e,r){var n=t.lassoPoints={};for(y=0;y<q.length;y++){var i=q[y];n[i._id]=r.filtered.map($(i))}},i.moveFn=function(t,e){B=Math.max(0,Math.min(U,t+R)),N=Math.max(0,Math.min(V,e+F));var r=Math.abs(B-R),a=Math.abs(N-F);if(\"select\"===l){var o=L.selectdirection;\"h\"===(o=\"any\"===L.selectdirection?a<Math.min(.6*r,g)?\"h\":r<Math.min(.6*a,g)?\"v\":\"d\":L.selectdirection)?((p=[[R,0],[R,V],[B,V],[B,0]]).xmin=Math.min(R,B),p.xmax=Math.max(R,B),p.ymin=Math.min(0,V),p.ymax=Math.max(0,V),W.attr(\"d\",\"M\"+p.xmin+\",\"+(F-g)+\"h-4v\"+2*g+\"h4ZM\"+(p.xmax-1)+\",\"+(F-g)+\"h4v\"+2*g+\"h-4Z\")):\"v\"===o?((p=[[0,F],[0,N],[U,N],[U,F]]).xmin=Math.min(0,U),p.xmax=Math.max(0,U),p.ymin=Math.min(F,N),p.ymax=Math.max(F,N),W.attr(\"d\",\"M\"+(R-g)+\",\"+p.ymin+\"v-4h\"+2*g+\"v4ZM\"+(R-g)+\",\"+(p.ymax-1)+\"v4h\"+2*g+\"v-4Z\")):\"d\"===o&&((p=[[R,F],[R,N],[B,N],[B,F]]).xmin=Math.min(R,B),p.xmax=Math.max(R,B),p.ymin=Math.min(F,N),p.ymax=Math.max(F,N),W.attr(\"d\",\"M0,0Z\"))}else\"lasso\"===l&&(u.addPt([B,N]),p=u.filtered);i.selectionDefs&&i.selectionDefs.length?(f=function(t,e,r){return r?n.difference({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions:n.union({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions}(i.mergedPolygons,p,H),p.subtract=H,h=w(i.selectionDefs.concat([p]))):(f=[p],h=m(p)),M(f,G),c.throttle(X,d.SELECTDELAY,function(){var t;Z=[];var e,r=[];for(y=0;y<J.length;y++)if(e=(b=J[y])._module.selectPoints(b,h),r.push(e),t=C(e,b),Z.length)for(var n=0;n<t.length;n++)Z.push(t[n]);else Z=t;E(S,J,_={points:Z}),Y(_,p,u),i.gd.emit(\"plotly_selecting\",_)})},i.clickFn=function(t,e){var r=L.clickmode;W.remove(),c.done(X).then(function(){if(c.clear(X),2===t){for(G.remove(),y=0;y<J.length;y++)(b=J[y])._module.selectPoints(b,!1);E(S,J),T(i),S.emit(\"plotly_deselect\",null)}else r.indexOf(\"select\")>-1&&x(e,S,i.xaxes,i.yaxes,i.subplot,i,G),\"event\"===r&&S.emit(\"plotly_selected\",void 0);o.click(S,e)}).catch(s.error)},i.doneFn=function(){W.remove(),c.done(X).then(function(){c.clear(X),i.gd.emit(\"plotly_selected\",_),p&&i.selectionDefs&&(p.subtract=H,i.selectionDefs.push(p),i.mergedPolygons.length=0,[].push.apply(i.mergedPolygons,f)),i.doneFnCompleted&&i.doneFnCompleted(Z)}).catch(s.error)}},clearSelect:L,selectOnClick:x}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../components/fx/helpers\":628,\"../../lib\":719,\"../../lib/clear_gl_canvases\":704,\"../../lib/polygon\":731,\"../../lib/throttle\":744,\"../../plot_api/subroutines\":758,\"../../registry\":847,\"./axis_ids\":770,\"./constants\":773,polybooljs:473}],785:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=a.cleanNumber,s=a.ms2DateTime,l=a.dateTime2ms,c=a.ensureNumber,u=a.isArrayOrTypedArray,h=t(\"../../constants/numerical\"),f=h.FP_SAFE,p=h.BADNUM,d=h.LOG_CLIP,g=t(\"./constants\"),v=t(\"./axis_ids\");function m(t){return Math.pow(10,t)}function y(t){return null!=t}e.exports=function(t,e){e=e||{};var r=t._id||\"x\",h=r.charAt(0);function x(e,r){if(e>0)return Math.log(e)/Math.LN10;if(e<=0&&r&&t.range&&2===t.range.length){var n=t.range[0],i=t.range[1];return.5*(n+i-2*d*Math.abs(n-i))}return p}function b(e,r,n){var o=l(e,n||t.calendar);if(o===p){if(!i(e))return p;e=+e;var s=Math.floor(10*a.mod(e+.05,1)),c=Math.round(e-s/10);o=l(new Date(c))+s/10}return o}function _(e,r,n){return s(e,r,n||t.calendar)}function w(e){return t._categories[Math.round(e)]}function k(e){if(y(e)){if(void 0===t._categoriesMap&&(t._categoriesMap={}),void 0!==t._categoriesMap[e])return t._categoriesMap[e];t._categories.push(\"number\"==typeof e?String(e):e);var r=t._categories.length-1;return t._categoriesMap[e]=r,r}return p}function T(e){if(t._categoriesMap)return t._categoriesMap[e]}function A(t){var e=T(t);return void 0!==e?e:i(t)?+t:void 0}function M(e){return i(e)?n.round(t._b+t._m*e,2):p}function S(e){return(e-t._b)/t._m}t.c2l=\"log\"===t.type?x:c,t.l2c=\"log\"===t.type?m:c,t.l2p=M,t.p2l=S,t.c2p=\"log\"===t.type?function(t,e){return M(x(t,e))}:M,t.p2c=\"log\"===t.type?function(t){return m(S(t))}:S,-1!==[\"linear\",\"-\"].indexOf(t.type)?(t.d2r=t.r2d=t.d2c=t.r2c=t.d2l=t.r2l=o,t.c2d=t.c2r=t.l2d=t.l2r=c,t.d2p=t.r2p=function(e){return t.l2p(o(e))},t.p2d=t.p2r=S,t.cleanPos=c):\"log\"===t.type?(t.d2r=t.d2l=function(t,e){return x(o(t),e)},t.r2d=t.r2c=function(t){return m(o(t))},t.d2c=t.r2l=o,t.c2d=t.l2r=c,t.c2r=x,t.l2d=m,t.d2p=function(e,r){return t.l2p(t.d2r(e,r))},t.p2d=function(t){return m(S(t))},t.r2p=function(e){return t.l2p(o(e))},t.p2r=S,t.cleanPos=c):\"date\"===t.type?(t.d2r=t.r2d=a.identity,t.d2c=t.r2c=t.d2l=t.r2l=b,t.c2d=t.c2r=t.l2d=t.l2r=_,t.d2p=t.r2p=function(e,r,n){return t.l2p(b(e,0,n))},t.p2d=t.p2r=function(t,e,r){return _(S(t),e,r)},t.cleanPos=function(e){return a.cleanDate(e,p,t.calendar)}):\"category\"===t.type?(t.d2c=t.d2l=k,t.r2d=t.c2d=t.l2d=w,t.d2r=t.d2l_noadd=A,t.r2c=function(e){var r=A(e);return void 0!==r?r:t.fraction2r(.5)},t.l2r=t.c2r=c,t.r2l=A,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return w(S(t))},t.r2p=t.d2p,t.p2r=S,t.cleanPos=function(t){return\"string\"==typeof t&&\"\"!==t?t:c(t)}):\"multicategory\"===t.type&&(t.r2d=t.c2d=t.l2d=w,t.d2r=t.d2l_noadd=A,t.r2c=function(e){var r=A(e);return void 0!==r?r:t.fraction2r(.5)},t.r2c_just_indices=T,t.l2r=t.c2r=c,t.r2l=A,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return w(S(t))},t.r2p=t.d2p,t.p2r=S,t.cleanPos=function(t){return Array.isArray(t)||\"string\"==typeof t&&\"\"!==t?t:c(t)},t.setupMultiCategory=function(n){var i,o,s=t._traceIndices,l=e._axisMatchGroups;if(l&&l.length&&0===t._categories.length)for(i=0;i<l.length;i++){var c=l[i];if(c[r])for(var f in c)if(f!==r){var p=e[v.id2name(f)];s=s.concat(p._traceIndices)}}var d=[[0,{}],[0,{}]],g=[];for(i=0;i<s.length;i++){var m=n[s[i]];if(h in m){var x=m[h],b=m._length||a.minRowLength(x);if(u(x[0])&&u(x[1]))for(o=0;o<b;o++){var _=x[0][o],w=x[1][o];y(_)&&y(w)&&(g.push([_,w]),_ in d[0][1]||(d[0][1][_]=d[0][0]++),w in d[1][1]||(d[1][1][w]=d[1][0]++))}}}for(g.sort(function(t,e){var r=d[0][1],n=r[t[0]]-r[e[0]];if(n)return n;var i=d[1][1];return i[t[1]]-i[e[1]]}),i=0;i<g.length;i++)k(g[i])}),t.fraction2r=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return t.l2r(r+e*(n-r))},t.r2fraction=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return(t.r2l(e)-r)/(n-r)},t.cleanRange=function(e,r){r||(r={}),e||(e=\"range\");var n,o,s=a.nestedProperty(t,e).get();if(o=(o=\"date\"===t.type?a.dfltRange(t.calendar):\"y\"===h?g.DFLTRANGEY:r.dfltRange||g.DFLTRANGEX).slice(),s&&2===s.length)for(\"date\"!==t.type||t.autorange||(s[0]=a.cleanDate(s[0],p,t.calendar),s[1]=a.cleanDate(s[1],p,t.calendar)),n=0;n<2;n++)if(\"date\"===t.type){if(!a.isDateTime(s[n],t.calendar)){t[e]=o;break}if(t.r2l(s[0])===t.r2l(s[1])){var l=a.constrain(t.r2l(s[0]),a.MIN_MS+1e3,a.MAX_MS-1e3);s[0]=t.l2r(l-1e3),s[1]=t.l2r(l+1e3);break}}else{if(!i(s[n])){if(!i(s[1-n])){t[e]=o;break}s[n]=s[1-n]*(n?10:.1)}if(s[n]<-f?s[n]=-f:s[n]>f&&(s[n]=f),s[0]===s[1]){var c=Math.max(1,Math.abs(1e-6*s[0]));s[0]-=c,s[1]+=c}}else a.nestedProperty(t,e).set(o)},t.setScale=function(r){var n=e._size;if(t.overlaying){var i=v.getFromId({_fullLayout:e},t.overlaying);t.domain=i.domain}var a=r&&t._r?\"_r\":\"range\",o=t.calendar;t.cleanRange(a);var s=t.r2l(t[a][0],o),l=t.r2l(t[a][1],o);if(\"y\"===h?(t._offset=n.t+(1-t.domain[1])*n.h,t._length=n.h*(t.domain[1]-t.domain[0]),t._m=t._length/(s-l),t._b=-t._m*l):(t._offset=n.l+t.domain[0]*n.w,t._length=n.w*(t.domain[1]-t.domain[0]),t._m=t._length/(l-s),t._b=-t._m*s),!isFinite(t._m)||!isFinite(t._b)||t._length<0)throw e._replotting=!1,new Error(\"Something went wrong with axis scaling\")},t.makeCalcdata=function(e,r){var n,i,o,s,l=t.type,c=\"date\"===l&&e[r+\"calendar\"];if(r in e){if(n=e[r],s=e._length||a.minRowLength(n),a.isTypedArray(n)&&(\"linear\"===l||\"log\"===l)){if(s===n.length)return n;if(n.subarray)return n.subarray(0,s)}if(\"multicategory\"===l)return function(t,e){for(var r=new Array(e),n=0;n<e;n++){var i=(t[0]||[])[n],a=(t[1]||[])[n];r[n]=T([i,a])}return r}(n,s);for(i=new Array(s),o=0;o<s;o++)i[o]=t.d2c(n[o],0,c)}else{var u=r+\"0\"in e?t.d2c(e[r+\"0\"],0,c):0,h=e[\"d\"+r]?Number(e[\"d\"+r]):1;for(n=e[{x:\"y\",y:\"x\"}[r]],s=e._length||n.length,i=new Array(s),o=0;o<s;o++)i[o]=u+o*h}return i},t.isValidRange=function(e){return Array.isArray(e)&&2===e.length&&i(t.r2l(e[0]))&&i(t.r2l(e[1]))},t.isPtWithinRange=function(e,r){var n=t.c2l(e[h],null,r),i=t.r2l(t.range[0]),a=t.r2l(t.range[1]);return i<a?i<=n&&n<=a:a<=n&&n<=i},t.clearCalc=function(){var n=function(){t._categories=[],t._categoriesMap={}},i=e._axisMatchGroups;if(i&&i.length){for(var a=!1,o=0;o<i.length;o++){var s=i[o];if(s[r]){a=!0;var l=null,c=null;for(var u in s){var h=e[v.id2name(u)];if(h._categories){l=h._categories,c=h._categoriesMap;break}}l&&c?(t._categories=l,t._categoriesMap=c):n();break}}a||n()}else n();if(t._initialCategories)for(var f=0;f<t._initialCategories.length;f++)k(t._initialCategories[f])},t.sortByInitialCategories=function(){var n=[];if(t._categories=[],t._categoriesMap={},t._initialCategories)for(var i=0;i<t._initialCategories.length;i++)k(t._initialCategories[i]);n=n.concat(t._traceIndices);var a=t._matchGroup;for(var o in a)if(r!==o){var s=e[v.id2name(o)];s._categories=t._categories,s._categoriesMap=t._categoriesMap,n=n.concat(s._traceIndices)}return n};var E=e._d3locale;\"date\"===t.type&&(t._dateFormat=E?E.timeFormat.utc:n.time.format.utc,t._extraFormat=e._extraFormat),t._separators=e.separators,t._numFormat=E?E.numberFormat:n.format,delete t._minDtick,delete t._forceTick0}},{\"../../constants/numerical\":695,\"../../lib\":719,\"./axis_ids\":770,\"./constants\":773,d3:163,\"fast-isnumeric\":225}],786:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"../array_container_defaults\");function o(t){var e=[\"showexponent\",\"showtickprefix\",\"showticksuffix\"].filter(function(e){return void 0!==t[e]});if(e.every(function(r){return t[r]===t[e[0]]})||1===e.length)return t[e[0]]}function s(t,e){function r(r,a){return n.coerce(t,e,i.tickformatstops,r,a)}r(\"enabled\")&&(r(\"dtickrange\"),r(\"value\"))}e.exports=function(t,e,r,l,c,u){u&&1!==u.pass||function(t,e,r,n,i){var a=o(t);r(\"tickprefix\")&&r(\"showtickprefix\",a);r(\"ticksuffix\",i.tickSuffixDflt)&&r(\"showticksuffix\",a)}(t,0,r,0,c),u&&2!==u.pass||function(t,e,r,l,c){var u=o(t);r(\"tickprefix\")&&r(\"showtickprefix\",u);r(\"ticksuffix\",c.tickSuffixDflt)&&r(\"showticksuffix\",u);if(r(\"showticklabels\")){var h=c.font||{},f=e.color,p=f&&f!==i.color.dflt?f:h.color;if(n.coerceFont(r,\"tickfont\",{family:h.family,size:h.size,color:p}),r(\"tickangle\"),\"category\"!==l){var d=r(\"tickformat\"),g=t.tickformatstops;Array.isArray(g)&&g.length&&a(t,e,{name:\"tickformatstops\",inclusionAttr:\"enabled\",handleItemDefaults:s}),d||\"date\"===l||(r(\"showexponent\",u),r(\"exponentformat\"),r(\"separatethousands\"))}}}(t,e,r,l,c)}},{\"../../lib\":719,\"../array_container_defaults\":763,\"./layout_attributes\":779}],787:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r,a){var o=n.coerce2(t,e,i,\"ticklen\"),s=n.coerce2(t,e,i,\"tickwidth\"),l=n.coerce2(t,e,i,\"tickcolor\",e.color);r(\"ticks\",a.outerTicks||o||s||l?\"outside\":\"\")||(delete e.ticklen,delete e.tickwidth,delete e.tickcolor)}},{\"../../lib\":719,\"./layout_attributes\":779}],788:[function(t,e,r){\"use strict\";var n=t(\"./clean_ticks\");e.exports=function(t,e,r,i){var a;\"array\"!==t.tickmode||\"log\"!==i&&\"date\"!==i?a=r(\"tickmode\",Array.isArray(t.tickvals)?\"array\":t.dtick?\"linear\":\"auto\"):a=e.tickmode=\"auto\";if(\"auto\"===a)r(\"nticks\");else if(\"linear\"===a){var o=e.dtick=n.dtick(t.dtick,i);e.tick0=n.tick0(t.tick0,i,e.calendar,o)}else if(\"multicategory\"!==i){void 0===r(\"tickvals\")?e.tickmode=\"auto\":r(\"ticktext\")}}},{\"./clean_ticks\":772}],789:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../components/drawing\"),o=t(\"./axes\");e.exports=function(t,e,r,s){var l=t._fullLayout;if(0!==e.length){var c,u,h,f;s&&(c=s());var p=n.ease(r.easing);return t._transitionData._interruptCallbacks.push(function(){return window.cancelAnimationFrame(f),f=null,function(){for(var r={},n=0;n<e.length;n++){var a=e[n];a.xr0&&(r[a.plotinfo.xaxis._name+\".range\"]=a.xr0.slice()),a.yr0&&(r[a.plotinfo.yaxis._name+\".range\"]=a.yr0.slice())}return i.call(\"relayout\",t,r).then(function(){for(var t=0;t<e.length;t++)d(e[t].plotinfo)})}()}),u=Date.now(),f=window.requestAnimationFrame(function n(){h=Date.now();for(var a=Math.min(1,(h-u)/r.duration),o=p(a),s=0;s<e.length;s++)g(e[s],o);h-u>r.duration?(function(){for(var r={},n=0;n<e.length;n++){var a=e[n];a.xr1&&(r[a.plotinfo.xaxis._name+\".range\"]=a.xr1.slice()),a.yr1&&(r[a.plotinfo.yaxis._name+\".range\"]=a.yr1.slice())}c&&c(),i.call(\"relayout\",t,r).then(function(){for(var t=0;t<e.length;t++)d(e[t].plotinfo)})}(),f=window.cancelAnimationFrame(n)):f=window.requestAnimationFrame(n)}),Promise.resolve()}function d(t){var e=t.xaxis,r=t.yaxis;l._defs.select(\"#\"+t.clipId+\"> rect\").call(a.setTranslate,0,0).call(a.setScale,1,1),t.plot.call(a.setTranslate,e._offset,r._offset).call(a.setScale,1,1);var n=t.plot.selectAll(\".scatterlayer .trace\");n.selectAll(\".point\").call(a.setPointGroupScale,1,1),n.selectAll(\".textpoint\").call(a.setTextPointsScale,1,1),n.call(a.hideOutsideRangePoints,t)}function g(e,r){var n=e.plotinfo,i=n.xaxis,s=n.yaxis,l=e.xr0,c=e.xr1,u=i._length,h=e.yr0,f=e.yr1,p=s._length,d=!!c,g=!!f,v=[];if(d){var m=l[1]-l[0],y=c[1]-c[0];v[0]=(l[0]*(1-r)+r*c[0]-l[0])/(l[1]-l[0])*u,v[2]=u*(1-r+r*y/m),i.range[0]=l[0]*(1-r)+r*c[0],i.range[1]=l[1]*(1-r)+r*c[1]}else v[0]=0,v[2]=u;if(g){var x=h[1]-h[0],b=f[1]-f[0];v[1]=(h[1]*(1-r)+r*f[1]-h[1])/(h[0]-h[1])*p,v[3]=p*(1-r+r*b/x),s.range[0]=h[0]*(1-r)+r*f[0],s.range[1]=h[1]*(1-r)+r*f[1]}else v[1]=0,v[3]=p;o.drawOne(t,i,{skipTitle:!0}),o.drawOne(t,s,{skipTitle:!0}),o.redrawComponents(t,[i._id,s._id]);var _=d?u/v[2]:1,w=g?p/v[3]:1,k=d?v[0]:0,T=g?v[1]:0,A=d?v[0]/v[2]*u:0,M=g?v[1]/v[3]*p:0,S=i._offset-A,E=s._offset-M;n.clipRect.call(a.setTranslate,k,T).call(a.setScale,1/_,1/w),n.plot.call(a.setTranslate,S,E).call(a.setScale,_,w),a.setPointGroupScale(n.zoomScalePts,1/_,1/w),a.setTextPointsScale(n.zoomScaleTxt,1/_,1/w)}o.redrawComponents(t)}},{\"../../components/drawing\":614,\"../../registry\":847,\"./axes\":767,d3:163}],790:[function(t,e,r){\"use strict\";var n=t(\"../../registry\").traceIs,i=t(\"./axis_autotype\");function a(t){return{v:\"x\",h:\"y\"}[t.orientation||\"v\"]}function o(t,e){var r=a(t),i=n(t,\"box-violin\"),o=n(t._fullInput||{},\"candlestick\");return i&&!o&&e===r&&void 0===t[r]&&void 0===t[r+\"0\"]}e.exports=function(t,e,r,s){\"-\"===r(\"type\",(s.splomStash||{}).type)&&(!function(t,e){if(\"-\"!==t.type)return;var r=t._id,s=r.charAt(0);-1!==r.indexOf(\"scene\")&&(r=s);var l=function(t,e,r){for(var n=0;n<t.length;n++){var i=t[n];if(\"splom\"===i.type&&i._length>0&&(i[\"_\"+r+\"axes\"]||{})[e])return i;if((i[r+\"axis\"]||r)===e){if(o(i,r))return i;if((i[r]||[]).length||i[r+\"0\"])return i}}}(e,r,s);if(!l)return;if(\"histogram\"===l.type&&s==={v:\"y\",h:\"x\"}[l.orientation||\"v\"])return void(t.type=\"linear\");var c,u=s+\"calendar\",h=l[u],f={noMultiCategory:!n(l,\"cartesian\")||n(l,\"noMultiCategory\")};if(o(l,s)){var p=a(l),d=[];for(c=0;c<e.length;c++){var g=e[c];n(g,\"box-violin\")&&(g[s+\"axis\"]||s)===r&&(void 0!==g[p]?d.push(g[p][0]):void 0!==g.name?d.push(g.name):d.push(\"text\"),g[u]!==h&&(h=void 0))}t.type=i(d,h,f)}else if(\"splom\"===l.type){var v=l.dimensions,m=v[l._axesDim[r]];m.visible&&(t.type=i(m.values,h,f))}else t.type=i(l[s]||[l[s+\"0\"]],h,f)}(e,s.data),\"-\"===e.type?e.type=\"linear\":t.type=e.type)}},{\"../../registry\":847,\"./axis_autotype\":768}],791:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\");function a(t,e,r){var n,a,o,s=!1;if(\"data\"===e.type)n=t._fullData[null!==e.traces?e.traces[0]:0];else{if(\"layout\"!==e.type)return!1;n=t._fullLayout}return a=i.nestedProperty(n,e.prop).get(),(o=r[e.type]=r[e.type]||{}).hasOwnProperty(e.prop)&&o[e.prop]!==a&&(s=!0),o[e.prop]=a,{changed:s,value:a}}function o(t,e){var r=[],n=e[0],a={};if(\"string\"==typeof n)a[n]=e[1];else{if(!i.isPlainObject(n))return r;a=n}return l(a,function(t,e,n){r.push({type:\"layout\",prop:t,value:n})},\"\",0),r}function s(t,e){var r,n,a,o,s=[];if(n=e[0],a=e[1],r=e[2],o={},\"string\"==typeof n)o[n]=a;else{if(!i.isPlainObject(n))return s;o=n,void 0===r&&(r=a)}return void 0===r&&(r=null),l(o,function(e,n,i){var a,o;if(Array.isArray(i)){o=i.slice();var l=Math.min(o.length,t.data.length);r&&(l=Math.min(l,r.length)),a=[];for(var c=0;c<l;c++)a[c]=r?r[c]:c}else o=i,a=r?r.slice():null;if(null===a)Array.isArray(o)&&(o=o[0]);else if(Array.isArray(a)){if(!Array.isArray(o)){var u=o;o=[];for(var h=0;h<a.length;h++)o[h]=u}o.length=Math.min(a.length,o.length)}s.push({type:\"data\",prop:e,traces:a,value:o})},\"\",0),s}function l(t,e,r,n){Object.keys(t).forEach(function(a){var o=t[a];if(\"_\"!==a[0]){var s=r+(n>0?\".\":\"\")+a;i.isPlainObject(o)?l(o,e,s,n+1):e(s,a,o)}})}r.manageCommandObserver=function(t,e,n,o){var s={},l=!0;e&&e._commandObserver&&(s=e._commandObserver),s.cache||(s.cache={}),s.lookupTable={};var c=r.hasSimpleAPICommandBindings(t,n,s.lookupTable);if(e&&e._commandObserver){if(c)return s;if(e._commandObserver.remove)return e._commandObserver.remove(),e._commandObserver=null,s}if(c){a(t,c,s.cache),s.check=function(){if(l){var e=a(t,c,s.cache);return e.changed&&o&&void 0!==s.lookupTable[e.value]&&(s.disable(),Promise.resolve(o({value:e.value,type:c.type,prop:c.prop,traces:c.traces,index:s.lookupTable[e.value]})).then(s.enable,s.enable)),e.changed}};for(var u=[\"plotly_relayout\",\"plotly_redraw\",\"plotly_restyle\",\"plotly_update\",\"plotly_animatingframe\",\"plotly_afterplot\"],h=0;h<u.length;h++)t._internalOn(u[h],s.check);s.remove=function(){for(var e=0;e<u.length;e++)t._removeInternalListener(u[e],s.check)}}else i.log(\"Unable to automatically bind plot updates to API command\"),s.lookupTable={},s.remove=function(){};return s.disable=function(){l=!1},s.enable=function(){l=!0},e&&(e._commandObserver=s),s},r.hasSimpleAPICommandBindings=function(t,e,n){var i,a,o=e.length;for(i=0;i<o;i++){var s,l=e[i],c=l.method,u=l.args;if(Array.isArray(u)||(u=[]),!c)return!1;var h=r.computeAPICommandBindings(t,c,u);if(1!==h.length)return!1;if(a){if((s=h[0]).type!==a.type)return!1;if(s.prop!==a.prop)return!1;if(Array.isArray(a.traces)){if(!Array.isArray(s.traces))return!1;s.traces.sort();for(var f=0;f<a.traces.length;f++)if(a.traces[f]!==s.traces[f])return!1}else if(s.prop!==a.prop)return!1}else a=h[0],Array.isArray(a.traces)&&a.traces.sort();var p=(s=h[0]).value;if(Array.isArray(p)){if(1!==p.length)return!1;p=p[0]}n&&(n[p]=i)}return a},r.executeAPICommand=function(t,e,r){if(\"skip\"===e)return Promise.resolve();var a=n.apiMethodRegistry[e],o=[t];Array.isArray(r)||(r=[]);for(var s=0;s<r.length;s++)o.push(r[s]);return a.apply(null,o).catch(function(t){return i.warn(\"API call to Plotly.\"+e+\" rejected.\",t),Promise.reject(t)})},r.computeAPICommandBindings=function(t,e,r){var n;switch(Array.isArray(r)||(r=[]),e){case\"restyle\":n=s(t,r);break;case\"relayout\":n=o(t,r);break;case\"update\":n=s(t,[r[0],r[2]]).concat(o(t,[r[1]]));break;case\"animate\":n=function(t,e){return Array.isArray(e[0])&&1===e[0].length&&-1!==[\"string\",\"number\"].indexOf(typeof e[0][0])?[{type:\"layout\",prop:\"_currentFrame\",value:e[0][0].toString()}]:[]}(0,r);break;default:n=[]}return n}},{\"../lib\":719,\"../registry\":847}],792:[function(t,e,r){\"use strict\";var n=t(\"../lib/extend\").extendFlat;r.attributes=function(t,e){e=e||{};var r={valType:\"info_array\",editType:(t=t||{}).editType,items:[{valType:\"number\",min:0,max:1,editType:t.editType},{valType:\"number\",min:0,max:1,editType:t.editType}],dflt:[0,1]},i=(t.name&&t.name,t.trace,e.description&&e.description,{x:n({},r,{}),y:n({},r,{}),editType:t.editType});return t.noGridCell||(i.row={valType:\"integer\",min:0,dflt:0,editType:t.editType},i.column={valType:\"integer\",min:0,dflt:0,editType:t.editType}),i},r.defaults=function(t,e,r,n){var i=n&&n.x||[0,1],a=n&&n.y||[0,1],o=e.grid;if(o){var s=r(\"domain.column\");void 0!==s&&(s<o.columns?i=o._domains.x[s]:delete t.domain.column);var l=r(\"domain.row\");void 0!==l&&(l<o.rows?a=o._domains.y[l]:delete t.domain.row)}r(\"domain.x\",i),r(\"domain.y\",a)}},{\"../lib/extend\":710}],793:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType,r=t.colorEditType;void 0===r&&(r=e);var n={family:{valType:\"string\",noBlank:!0,strict:!0,editType:e},size:{valType:\"number\",min:1,editType:e},color:{valType:\"color\",editType:r},editType:e};return t.arrayOk&&(n.family.arrayOk=!0,n.size.arrayOk=!0,n.color.arrayOk=!0),n}},{}],794:[function(t,e,r){\"use strict\";e.exports={_isLinkedToArray:\"frames_entry\",group:{valType:\"string\"},name:{valType:\"string\"},traces:{valType:\"any\"},baseframe:{valType:\"string\"},data:{valType:\"any\"},layout:{valType:\"any\"}}},{}],795:[function(t,e,r){\"use strict\";r.projNames={equirectangular:\"equirectangular\",mercator:\"mercator\",orthographic:\"orthographic\",\"natural earth\":\"naturalEarth\",kavrayskiy7:\"kavrayskiy7\",miller:\"miller\",robinson:\"robinson\",eckert4:\"eckert4\",\"azimuthal equal area\":\"azimuthalEqualArea\",\"azimuthal equidistant\":\"azimuthalEquidistant\",\"conic equal area\":\"conicEqualArea\",\"conic conformal\":\"conicConformal\",\"conic equidistant\":\"conicEquidistant\",gnomonic:\"gnomonic\",stereographic:\"stereographic\",mollweide:\"mollweide\",hammer:\"hammer\",\"transverse mercator\":\"transverseMercator\",\"albers usa\":\"albersUsa\",\"winkel tripel\":\"winkel3\",aitoff:\"aitoff\",sinusoidal:\"sinusoidal\"},r.axesNames=[\"lonaxis\",\"lataxis\"],r.lonaxisSpan={orthographic:180,\"azimuthal equal area\":360,\"azimuthal equidistant\":360,\"conic conformal\":180,gnomonic:160,stereographic:180,\"transverse mercator\":180,\"*\":360},r.lataxisSpan={\"conic conformal\":150,stereographic:179.5,\"*\":180},r.scopeDefaults={world:{lonaxisRange:[-180,180],lataxisRange:[-90,90],projType:\"equirectangular\",projRotate:[0,0,0]},usa:{lonaxisRange:[-180,-50],lataxisRange:[15,80],projType:\"albers usa\"},europe:{lonaxisRange:[-30,60],lataxisRange:[30,85],projType:\"conic conformal\",projRotate:[15,0,0],projParallels:[0,60]},asia:{lonaxisRange:[22,160],lataxisRange:[-15,55],projType:\"mercator\",projRotate:[0,0,0]},africa:{lonaxisRange:[-30,60],lataxisRange:[-40,40],projType:\"mercator\",projRotate:[0,0,0]},\"north america\":{lonaxisRange:[-180,-45],lataxisRange:[5,85],projType:\"conic conformal\",projRotate:[-100,0,0],projParallels:[29.5,45.5]},\"south america\":{lonaxisRange:[-100,-30],lataxisRange:[-60,15],projType:\"mercator\",projRotate:[0,0,0]}},r.clipPad=.001,r.precision=.1,r.landColor=\"#F0DC82\",r.waterColor=\"#3399FF\",r.locationmodeToLayer={\"ISO-3\":\"countries\",\"USA-states\":\"subunits\",\"country names\":\"countries\"},r.sphereSVG={type:\"Sphere\"},r.fillLayers={ocean:1,land:1,lakes:1},r.lineLayers={subunits:1,countries:1,coastlines:1,rivers:1,frame:1},r.layers=[\"bg\",\"ocean\",\"land\",\"lakes\",\"subunits\",\"countries\",\"coastlines\",\"rivers\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"frontplot\"],r.layersForChoropleth=[\"bg\",\"ocean\",\"land\",\"subunits\",\"countries\",\"coastlines\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"rivers\",\"lakes\",\"frontplot\"],r.layerNameToAdjective={ocean:\"ocean\",land:\"land\",lakes:\"lake\",subunits:\"subunit\",countries:\"country\",coastlines:\"coastline\",rivers:\"river\",frame:\"frame\"}},{}],796:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"../../components/fx\"),c=t(\"../plots\"),u=t(\"../cartesian/axes\"),h=t(\"../../components/dragelement\"),f=t(\"../cartesian/select\").prepSelect,p=t(\"../cartesian/select\").selectOnClick,d=t(\"./zoom\"),g=t(\"./constants\"),v=t(\"../../lib/topojson_utils\"),m=t(\"topojson-client\").feature;function y(t){this.id=t.id,this.graphDiv=t.graphDiv,this.container=t.container,this.topojsonURL=t.topojsonURL,this.isStatic=t.staticPlot,this.topojsonName=null,this.topojson=null,this.projection=null,this.scope=null,this.viewInitial=null,this.fitScale=null,this.bounds=null,this.midPt=null,this.hasChoropleth=!1,this.traceHash={},this.layers={},this.basePaths={},this.dataPaths={},this.dataPoints={},this.clipDef=null,this.clipRect=null,this.bgRect=null,this.makeFramework()}t(\"./projections\")(n);var x=y.prototype;e.exports=function(t){return new y(t)},x.plot=function(t,e,r){var n=this,i=e[this.id],a=!1;for(var o in g.layerNameToAdjective)if(\"frame\"!==o&&i[\"show\"+o]){a=!0;break}for(var s=0;s<t.length;s++)if(t[0][0].trace.locationmode){a=!0;break}if(!a)return n.update(t,e);var l=v.getTopojsonName(i);null===n.topojson||l!==n.topojsonName?(n.topojsonName=l,void 0===PlotlyGeoAssets.topojson[n.topojsonName]?r.push(n.fetchTopojson().then(function(r){PlotlyGeoAssets.topojson[n.topojsonName]=r,n.topojson=r,n.update(t,e)})):(n.topojson=PlotlyGeoAssets.topojson[n.topojsonName],n.update(t,e))):n.update(t,e)},x.fetchTopojson=function(){var t=v.getTopojsonPath(this.topojsonURL,this.topojsonName);return new Promise(function(e,r){n.json(t,function(n,i){if(n)return 404===n.status?r(new Error([\"plotly.js could not find topojson file at\",t,\".\",\"Make sure the *topojsonURL* plot config option\",\"is set properly.\"].join(\" \"))):r(new Error([\"unexpected error while fetching topojson file at\",t].join(\" \")));e(i)})})},x.update=function(t,e){var r=e[this.id];if(!this.updateProjection(e,r)){this.hasChoropleth=!1;for(var n=0;n<t.length;n++)if(\"choropleth\"===t[n][0].trace.type){this.hasChoropleth=!0;break}this.viewInitial&&this.scope===r.scope||this.saveViewInitial(r),this.scope=r.scope,this.updateBaseLayers(e,r),this.updateDims(e,r),this.updateFx(e,r),c.generalUpdatePerTraceModule(this.graphDiv,this,t,r);var i=this.layers.frontplot.select(\".scatterlayer\");this.dataPoints.point=i.selectAll(\".point\"),this.dataPoints.text=i.selectAll(\"text\"),this.dataPaths.line=i.selectAll(\".js-line\");var a=this.layers.backplot.select(\".choroplethlayer\");this.dataPaths.choropleth=a.selectAll(\"path\"),this.render()}},x.updateProjection=function(t,e){var r=t._size,o=e.domain,s=e.projection,l=s.rotation||{},c=e.center||{},u=this.projection=function(t){for(var e=t.projection.type,r=n.geo[g.projNames[e]](),i=t._isClipped?g.lonaxisSpan[e]/2:null,a=[\"center\",\"rotate\",\"parallels\",\"clipExtent\"],o=function(t){return t?r:[]},s=0;s<a.length;s++){var l=a[s];\"function\"!=typeof r[l]&&(r[l]=o)}r.isLonLatOverEdges=function(t){if(null===r(t))return!0;if(i){var e=r.rotate();return n.geo.distance(t,[-e[0],-e[1]])>i*Math.PI/180}return!1},r.getPath=function(){return n.geo.path().projection(r)},r.getBounds=function(t){return r.getPath().bounds(t)},r.fitExtent=function(t,e){var n=t[1][0]-t[0][0],i=t[1][1]-t[0][1],a=r.clipExtent&&r.clipExtent();r.scale(150).translate([0,0]),a&&r.clipExtent(null);var o=r.getBounds(e),s=Math.min(n/(o[1][0]-o[0][0]),i/(o[1][1]-o[0][1])),l=+t[0][0]+(n-s*(o[1][0]+o[0][0]))/2,c=+t[0][1]+(i-s*(o[1][1]+o[0][1]))/2;return a&&r.clipExtent(a),r.scale(150*s).translate([l,c])},r.precision(g.precision),i&&r.clipAngle(i-g.clipPad);return r}(e);u.center([c.lon-l.lon,c.lat-l.lat]).rotate([-l.lon,-l.lat,l.roll]).parallels(s.parallels);var h=[[r.l+r.w*o.x[0],r.t+r.h*(1-o.y[1])],[r.l+r.w*o.x[1],r.t+r.h*(1-o.y[0])]],f=e.lonaxis,p=e.lataxis,d=function(t,e){var r=g.clipPad,n=t[0]+r,i=t[1]-r,a=e[0]+r,o=e[1]-r;n>0&&i<0&&(i+=360);var s=(i-n)/4;return{type:\"Polygon\",coordinates:[[[n,a],[n,o],[n+s,o],[n+2*s,o],[n+3*s,o],[i,o],[i,a],[i-s,a],[i-2*s,a],[i-3*s,a],[n,a]]]}}(f.range,p.range);u.fitExtent(h,d);var v=this.bounds=u.getBounds(d),m=this.fitScale=u.scale(),y=u.translate();if(!isFinite(v[0][0])||!isFinite(v[0][1])||!isFinite(v[1][0])||!isFinite(v[1][1])||isNaN(y[0])||isNaN(y[0])){for(var x=this.graphDiv,b=[\"projection.rotation\",\"center\",\"lonaxis.range\",\"lataxis.range\"],_=\"Invalid geo settings, relayout'ing to default view.\",w={},k=0;k<b.length;k++)w[this.id+\".\"+b[k]]=null;return this.viewInitial=null,a.warn(_),x._promises.push(i.call(\"relayout\",x,w)),_}var T=this.midPt=[(v[0][0]+v[1][0])/2,(v[0][1]+v[1][1])/2];if(u.scale(s.scale*m).translate([y[0]+(T[0]-y[0]),y[1]+(T[1]-y[1])]).clipExtent(v),e._isAlbersUsa){var A=u([c.lon,c.lat]),M=u.translate();u.translate([M[0]-(A[0]-M[0]),M[1]-(A[1]-M[1])])}},x.updateBaseLayers=function(t,e){var r=this,i=r.topojson,a=r.layers,l=r.basePaths;function c(t){return\"lonaxis\"===t||\"lataxis\"===t}function h(t){return Boolean(g.lineLayers[t])}function f(t){return Boolean(g.fillLayers[t])}var p=(this.hasChoropleth?g.layersForChoropleth:g.layers).filter(function(t){return h(t)||f(t)?e[\"show\"+t]:!c(t)||e[t].showgrid}),d=r.framework.selectAll(\".layer\").data(p,String);d.exit().each(function(t){delete a[t],delete l[t],n.select(this).remove()}),d.enter().append(\"g\").attr(\"class\",function(t){return\"layer \"+t}).each(function(t){var e=a[t]=n.select(this);\"bg\"===t?r.bgRect=e.append(\"rect\").style(\"pointer-events\",\"all\"):c(t)?l[t]=e.append(\"path\").style(\"fill\",\"none\"):\"backplot\"===t?e.append(\"g\").classed(\"choroplethlayer\",!0):\"frontplot\"===t?e.append(\"g\").classed(\"scatterlayer\",!0):h(t)?l[t]=e.append(\"path\").style(\"fill\",\"none\").style(\"stroke-miterlimit\",2):f(t)&&(l[t]=e.append(\"path\").style(\"stroke\",\"none\"))}),d.order(),d.each(function(r){var n=l[r],a=g.layerNameToAdjective[r];\"frame\"===r?n.datum(g.sphereSVG):h(r)||f(r)?n.datum(m(i,i.objects[r])):c(r)&&n.datum(function(t,e,r){var n,i,a,o=e[t],s=g.scopeDefaults[e.scope];\"lonaxis\"===t?(n=s.lonaxisRange,i=s.lataxisRange,a=function(t,e){return[t,e]}):\"lataxis\"===t&&(n=s.lataxisRange,i=s.lonaxisRange,a=function(t,e){return[e,t]});var l={type:\"linear\",range:[n[0],n[1]-1e-6],tick0:o.tick0,dtick:o.dtick};u.setConvert(l,r);var c=u.calcTicks(l);e.isScoped||\"lonaxis\"!==t||c.pop();for(var h=c.length,f=new Array(h),p=0;p<h;p++)for(var d=c[p].x,v=f[p]=[],m=i[0];m<i[1]+2.5;m+=2.5)v.push(a(d,m));return{type:\"MultiLineString\",coordinates:f}}(r,e,t)).call(o.stroke,e[r].gridcolor).call(s.dashLine,\"\",e[r].gridwidth),h(r)?n.call(o.stroke,e[a+\"color\"]).call(s.dashLine,\"\",e[a+\"width\"]):f(r)&&n.call(o.fill,e[a+\"color\"])})},x.updateDims=function(t,e){var r=this.bounds,n=(e.framewidth||0)/2,i=r[0][0]-n,a=r[0][1]-n,l=r[1][0]-i+n,c=r[1][1]-a+n;s.setRect(this.clipRect,i,a,l,c),this.bgRect.call(s.setRect,i,a,l,c).call(o.fill,e.bgcolor),this.xaxis._offset=i,this.xaxis._length=l,this.yaxis._offset=a,this.yaxis._length=c},x.updateFx=function(t,e){var r=this,a=r.graphDiv,o=r.bgRect,s=t.dragmode,c=t.clickmode;if(!r.isStatic){var u;\"select\"===s?u=function(t,e){(t.range={})[r.id]=[v([e.xmin,e.ymin]),v([e.xmax,e.ymax])]}:\"lasso\"===s&&(u=function(t,e,n){(t.lassoPoints={})[r.id]=n.filtered.map(v)});var g={element:r.bgRect.node(),gd:a,plotinfo:{id:r.id,xaxis:r.xaxis,yaxis:r.yaxis,fillRangeItems:u},xaxes:[r.xaxis],yaxes:[r.yaxis],subplot:r.id,clickFn:function(e){2===e&&t._zoomlayer.selectAll(\".select-outline\").remove()}};\"pan\"===s?(o.node().onmousedown=null,o.call(d(r,e)),o.on(\"dblclick.zoom\",function(){var t=r.viewInitial,e={};for(var n in t)e[r.id+\".\"+n]=t[n];i.call(\"_guiRelayout\",a,e),a.emit(\"plotly_doubleclick\",null)}),a._context._scrollZoom.geo||o.on(\"wheel.zoom\",null)):\"select\"!==s&&\"lasso\"!==s||(o.on(\".zoom\",null),g.prepFn=function(t,e,r){f(t,e,r,g,s)},h.init(g)),o.on(\"mousemove\",function(){var t=r.projection.invert(n.mouse(this));if(!t||isNaN(t[0])||isNaN(t[1]))return h.unhover(a,n.event);r.xaxis.p2c=function(){return t[0]},r.yaxis.p2c=function(){return t[1]},l.hover(a,n.event,r.id)}),o.on(\"mouseout\",function(){a._dragging||h.unhover(a,n.event)}),o.on(\"click\",function(){\"select\"!==s&&\"lasso\"!==s&&(c.indexOf(\"select\")>-1&&p(n.event,a,[r.xaxis],[r.yaxis],r.id,g),c.indexOf(\"event\")>-1&&l.click(a,n.event))})}function v(t){return r.projection.invert([t[0]+r.xaxis._offset,t[1]+r.yaxis._offset])}},x.makeFramework=function(){var t=this,e=t.graphDiv,r=e._fullLayout,i=\"clip\"+r._uid+t.id;t.clipDef=r._clips.append(\"clipPath\").attr(\"id\",i),t.clipRect=t.clipDef.append(\"rect\"),t.framework=n.select(t.container).append(\"g\").attr(\"class\",\"geo \"+t.id).call(s.setClipUrl,i,e),t.project=function(e){var r=t.projection(e);return r?[r[0]-t.xaxis._offset,r[1]-t.yaxis._offset]:[null,null]},t.xaxis={_id:\"x\",c2p:function(e){return t.project(e)[0]}},t.yaxis={_id:\"y\",c2p:function(e){return t.project(e)[1]}},t.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},u.setConvert(t.mockAxis,r)},x.saveViewInitial=function(t){var e=t.center||{},r=t.projection,n=r.rotation||{};t._isScoped?this.viewInitial={\"center.lon\":e.lon,\"center.lat\":e.lat,\"projection.scale\":r.scale}:t._isClipped?this.viewInitial={\"projection.scale\":r.scale,\"projection.rotation.lon\":n.lon,\"projection.rotation.lat\":n.lat}:this.viewInitial={\"center.lon\":e.lon,\"center.lat\":e.lat,\"projection.scale\":r.scale,\"projection.rotation.lon\":n.lon}},x.render=function(){var t,e=this.projection,r=e.getPath();function n(t){var r=e(t.lonlat);return r?\"translate(\"+r[0]+\",\"+r[1]+\")\":null}function i(t){return e.isLonLatOverEdges(t.lonlat)?\"none\":null}for(t in this.basePaths)this.basePaths[t].attr(\"d\",r);for(t in this.dataPaths)this.dataPaths[t].attr(\"d\",function(t){return r(t.geojson)});for(t in this.dataPoints)this.dataPoints[t].attr(\"display\",i).attr(\"transform\",n)}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../lib\":719,\"../../lib/topojson_utils\":746,\"../../registry\":847,\"../cartesian/axes\":767,\"../cartesian/select\":784,\"../plots\":828,\"./constants\":795,\"./projections\":800,\"./zoom\":801,d3:163,\"topojson-client\":540}],797:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./geo\"),o=\"geo\",s=i(o),l={};l[o]={valType:\"subplotid\",dflt:o,editType:\"calc\"},e.exports={attr:o,name:o,idRoot:o,idRegex:s,attrRegex:s,attributes:l,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[o],s=0;s<i.length;s++){var l=i[s],c=n(r,o,l),u=e[l]._subplot;u||(u=a({id:l,graphDiv:t,container:e._geolayer.node(),topojsonURL:t._context.topojsonURL,staticPlot:t._context.staticPlot}),e[l]._subplot=u),u.plot(c,e,t._promises)}},updateFx:function(t){for(var e=t._fullLayout,r=e._subplots[o],n=0;n<r.length;n++){var i=e[r[n]];i._subplot.updateFx(e,i)}},clean:function(t,e,r,n){for(var i=n._subplots[o]||[],a=0;a<i.length;a++){var s=i[a],l=n[s]._subplot;!e[s]&&l&&(l.framework.remove(),l.clipDef.remove())}}}},{\"../../lib\":719,\"../../plots/get_data\":802,\"./geo\":796,\"./layout_attributes\":798,\"./layout_defaults\":799}],798:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"./constants\"),o=t(\"../../plot_api/edit_types\").overrideAll,s={range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},showgrid:{valType:\"boolean\",dflt:!1},tick0:{valType:\"number\",dflt:0},dtick:{valType:\"number\"},gridcolor:{valType:\"color\",dflt:n.lightLine},gridwidth:{valType:\"number\",min:0,dflt:1}};(e.exports=o({domain:i({name:\"geo\"},{}),resolution:{valType:\"enumerated\",values:[110,50],dflt:110,coerceNumber:!0},scope:{valType:\"enumerated\",values:Object.keys(a.scopeDefaults),dflt:\"world\"},projection:{type:{valType:\"enumerated\",values:Object.keys(a.projNames)},rotation:{lon:{valType:\"number\"},lat:{valType:\"number\"},roll:{valType:\"number\"}},parallels:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},scale:{valType:\"number\",min:0,dflt:1}},center:{lon:{valType:\"number\"},lat:{valType:\"number\"}},showcoastlines:{valType:\"boolean\"},coastlinecolor:{valType:\"color\",dflt:n.defaultLine},coastlinewidth:{valType:\"number\",min:0,dflt:1},showland:{valType:\"boolean\",dflt:!1},landcolor:{valType:\"color\",dflt:a.landColor},showocean:{valType:\"boolean\",dflt:!1},oceancolor:{valType:\"color\",dflt:a.waterColor},showlakes:{valType:\"boolean\",dflt:!1},lakecolor:{valType:\"color\",dflt:a.waterColor},showrivers:{valType:\"boolean\",dflt:!1},rivercolor:{valType:\"color\",dflt:a.waterColor},riverwidth:{valType:\"number\",min:0,dflt:1},showcountries:{valType:\"boolean\"},countrycolor:{valType:\"color\",dflt:n.defaultLine},countrywidth:{valType:\"number\",min:0,dflt:1},showsubunits:{valType:\"boolean\"},subunitcolor:{valType:\"color\",dflt:n.defaultLine},subunitwidth:{valType:\"number\",min:0,dflt:1},showframe:{valType:\"boolean\"},framecolor:{valType:\"color\",dflt:n.defaultLine},framewidth:{valType:\"number\",min:0,dflt:1},bgcolor:{valType:\"color\",dflt:n.background},lonaxis:s,lataxis:s},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":592,\"../../plot_api/edit_types\":750,\"../domain\":792,\"./constants\":795}],799:[function(t,e,r){\"use strict\";var n=t(\"../subplot_defaults\"),i=t(\"./constants\"),a=t(\"./layout_attributes\"),o=i.axesNames;function s(t,e,r){var n=r(\"resolution\"),a=r(\"scope\"),s=i.scopeDefaults[a],l=r(\"projection.type\",s.projType),c=e._isAlbersUsa=\"albers usa\"===l;c&&(a=e.scope=\"usa\");var u=e._isScoped=\"world\"!==a,h=e._isConic=-1!==l.indexOf(\"conic\");e._isClipped=!!i.lonaxisSpan[l];for(var f=0;f<o.length;f++){var p,d=o[f],g=[30,10][f];if(u)p=s[d+\"Range\"];else{var v=i[d+\"Span\"],m=(v[l]||v[\"*\"])/2,y=r(\"projection.rotation.\"+d.substr(0,3),s.projRotate[f]);p=[y-m,y+m]}r(d+\".range\",p),r(d+\".tick0\"),r(d+\".dtick\",g),r(d+\".showgrid\")&&(r(d+\".gridcolor\"),r(d+\".gridwidth\"))}var x=e.lonaxis.range,b=e.lataxis.range,_=x[0],w=x[1];_>0&&w<0&&(w+=360);var k,T,A,M=(_+w)/2;if(!c){var S=u?s.projRotate:[M,0,0];k=r(\"projection.rotation.lon\",S[0]),r(\"projection.rotation.lat\",S[1]),r(\"projection.rotation.roll\",S[2]),r(\"showcoastlines\",!u)&&(r(\"coastlinecolor\"),r(\"coastlinewidth\")),r(\"showocean\")&&r(\"oceancolor\")}(c?(T=-96.6,A=38.7):(T=u?M:k,A=(b[0]+b[1])/2),r(\"center.lon\",T),r(\"center.lat\",A),h)&&r(\"projection.parallels\",s.projParallels||[0,60]);r(\"projection.scale\"),r(\"showland\")&&r(\"landcolor\"),r(\"showlakes\")&&r(\"lakecolor\"),r(\"showrivers\")&&(r(\"rivercolor\"),r(\"riverwidth\")),r(\"showcountries\",u&&\"usa\"!==a)&&(r(\"countrycolor\"),r(\"countrywidth\")),(\"usa\"===a||\"north america\"===a&&50===n)&&(r(\"showsubunits\",!0),r(\"subunitcolor\"),r(\"subunitwidth\")),u||r(\"showframe\",!0)&&(r(\"framecolor\"),r(\"framewidth\")),r(\"bgcolor\")}e.exports=function(t,e,r){n(t,e,r,{type:\"geo\",attributes:a,handleDefaults:s,partition:\"y\"})}},{\"../subplot_defaults\":842,\"./constants\":795,\"./layout_attributes\":798}],800:[function(t,e,r){\"use strict\";e.exports=function(t){function e(t,e){return{type:\"Feature\",id:t.id,properties:t.properties,geometry:r(t.geometry,e)}}function r(e,n){if(!e)return null;if(\"GeometryCollection\"===e.type)return{type:\"GeometryCollection\",geometries:object.geometries.map(function(t){return r(t,n)})};if(!c.hasOwnProperty(e.type))return null;var i=c[e.type];return t.geo.stream(e,n(i)),i.result()}t.geo.project=function(t,e){var i=e.stream;if(!i)throw new Error(\"not yet supported\");return(t&&n.hasOwnProperty(t.type)?n[t.type]:r)(t,i)};var n={Feature:e,FeatureCollection:function(t,r){return{type:\"FeatureCollection\",features:t.features.map(function(t){return e(t,r)})}}},i=[],a=[],o={point:function(t,e){i.push([t,e])},result:function(){var t=i.length?i.length<2?{type:\"Point\",coordinates:i[0]}:{type:\"MultiPoint\",coordinates:i}:null;return i=[],t}},s={lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){i.length&&(a.push(i),i=[])},result:function(){var t=a.length?a.length<2?{type:\"LineString\",coordinates:a[0]}:{type:\"MultiLineString\",coordinates:a}:null;return a=[],t}},l={polygonStart:u,lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){var t=i.length;if(t){do{i.push(i[0].slice())}while(++t<4);a.push(i),i=[]}},polygonEnd:u,result:function(){if(!a.length)return null;var t=[],e=[];return a.forEach(function(r){!function(t){if((e=t.length)<4)return!1;for(var e,r=0,n=t[e-1][1]*t[0][0]-t[e-1][0]*t[0][1];++r<e;)n+=t[r-1][1]*t[r][0]-t[r-1][0]*t[r][1];return n<=0}(r)?e.push(r):t.push([r])}),e.forEach(function(e){var r=e[0];t.some(function(t){if(function(t,e){for(var r=e[0],n=e[1],i=!1,a=0,o=t.length,s=o-1;a<o;s=a++){var l=t[a],c=l[0],u=l[1],h=t[s],f=h[0],p=h[1];u>n^p>n&&r<(f-c)*(n-u)/(p-u)+c&&(i=!i)}return i}(t[0],r))return t.push(e),!0})||t.push([e])}),a=[],t.length?t.length>1?{type:\"MultiPolygon\",coordinates:t}:{type:\"Polygon\",coordinates:t[0]}:null}},c={Point:o,MultiPoint:o,LineString:s,MultiLineString:s,Polygon:l,MultiPolygon:l,Sphere:l};function u(){}var h=1e-6,f=h*h,p=Math.PI,d=p/2,g=(Math.sqrt(p),p/180),v=180/p;function m(t){return t>1?d:t<-1?-d:Math.asin(t)}function y(t){return t>1?0:t<-1?p:Math.acos(t)}var x=t.geo.projection,b=t.geo.projectionMutator;function _(t,e){var r=(2+d)*Math.sin(e);e/=2;for(var n=0,i=1/0;n<10&&Math.abs(i)>h;n++){var a=Math.cos(e);e-=i=(e+Math.sin(e)*(a+2)-r)/(2*a*(1+a))}return[2/Math.sqrt(p*(4+p))*t*(1+Math.cos(e)),2*Math.sqrt(p/(4+p))*Math.sin(e)]}t.geo.interrupt=function(e){var r,n=[[[[-p,0],[0,d],[p,0]]],[[[-p,0],[0,-d],[p,0]]]];function i(t,r){for(var i=r<0?-1:1,a=n[+(r<0)],o=0,s=a.length-1;o<s&&t>a[o][2][0];++o);var l=e(t-a[o][1][0],r);return l[0]+=e(a[o][1][0],i*r>i*a[o][0][1]?a[o][0][1]:r)[0],l}e.invert&&(i.invert=function(t,a){for(var o=r[+(a<0)],s=n[+(a<0)],c=0,u=o.length;c<u;++c){var h=o[c];if(h[0][0]<=t&&t<h[1][0]&&h[0][1]<=a&&a<h[1][1]){var f=e.invert(t-e(s[c][1][0],0)[0],a);return f[0]+=s[c][1][0],l(i(f[0],f[1]),[t,a])?f:null}}});var a=t.geo.projection(i),o=a.stream;function s(t,e){for(var r,n,i,a=-1,o=t.length,s=t[0],l=[];++a<o;){n=((r=t[a])[0]-s[0])/e,i=(r[1]-s[1])/e;for(var c=0;c<e;++c)l.push([s[0]+c*n,s[1]+c*i]);s=r}return l.push(r),l}function l(t,e){return Math.abs(t[0]-e[0])<h&&Math.abs(t[1]-e[1])<h}return a.stream=function(e){var r=a.rotate(),i=o(e),l=(a.rotate([0,0]),o(e));return a.rotate(r),i.sphere=function(){t.geo.stream(function(){for(var e=1e-6,r=[],i=0,a=n[0].length;i<a;++i){var o=n[0][i],l=180*o[0][0]/p,c=180*o[0][1]/p,u=180*o[1][1]/p,h=180*o[2][0]/p,f=180*o[2][1]/p;r.push(s([[l+e,c+e],[l+e,u-e],[h-e,u-e],[h-e,f+e]],30))}for(var i=n[1].length-1;i>=0;--i){var o=n[1][i],l=180*o[0][0]/p,c=180*o[0][1]/p,u=180*o[1][1]/p,h=180*o[2][0]/p,f=180*o[2][1]/p;r.push(s([[h-e,f-e],[h-e,u+e],[l+e,u+e],[l+e,c-e]],30))}return{type:\"Polygon\",coordinates:[t.merge(r)]}}(),l)},i},a.lobes=function(t){return arguments.length?(n=t.map(function(t){return t.map(function(t){return[[t[0][0]*p/180,t[0][1]*p/180],[t[1][0]*p/180,t[1][1]*p/180],[t[2][0]*p/180,t[2][1]*p/180]]})}),r=n.map(function(t){return t.map(function(t){var r,n=e(t[0][0],t[0][1])[0],i=e(t[2][0],t[2][1])[0],a=e(t[1][0],t[0][1])[1],o=e(t[1][0],t[1][1])[1];return a>o&&(r=a,a=o,o=r),[[n,a],[i,o]]})}),a):n.map(function(t){return t.map(function(t){return[[180*t[0][0]/p,180*t[0][1]/p],[180*t[1][0]/p,180*t[1][1]/p],[180*t[2][0]/p,180*t[2][1]/p]]})})},a},_.invert=function(t,e){var r=.5*e*Math.sqrt((4+p)/p),n=m(r),i=Math.cos(n);return[t/(2/Math.sqrt(p*(4+p))*(1+i)),m((n+r*(i+2))/(2+d))]},(t.geo.eckert4=function(){return x(_)}).raw=_;var w=t.geo.azimuthalEqualArea.raw;function k(t,e){if(arguments.length<2&&(e=t),1===e)return w;if(e===1/0)return T;function r(r,n){var i=w(r/e,n);return i[0]*=t,i}return r.invert=function(r,n){var i=w.invert(r/t,n);return i[0]*=e,i},r}function T(t,e){return[t*Math.cos(e)/Math.cos(e/=2),2*Math.sin(e)]}function A(t,e){return[3*t/(2*p)*Math.sqrt(p*p/3-e*e),e]}function M(t,e){return[t,1.25*Math.log(Math.tan(p/4+.4*e))]}function S(t){return function(e){var r,n=t*Math.sin(e),i=30;do{e-=r=(e+Math.sin(e)-n)/(1+Math.cos(e))}while(Math.abs(r)>h&&--i>0);return e/2}}T.invert=function(t,e){var r=2*m(e/2);return[t*Math.cos(r/2)/Math.cos(r),r]},(t.geo.hammer=function(){var t=2,e=b(k),r=e(t);return r.coefficient=function(r){return arguments.length?e(t=+r):t},r}).raw=k,A.invert=function(t,e){return[2/3*p*t/Math.sqrt(p*p/3-e*e),e]},(t.geo.kavrayskiy7=function(){return x(A)}).raw=A,M.invert=function(t,e){return[t,2.5*Math.atan(Math.exp(.8*e))-.625*p]},(t.geo.miller=function(){return x(M)}).raw=M,S(p);var E=function(t,e,r){var n=S(r);function i(r,i){return[t*r*Math.cos(i=n(i)),e*Math.sin(i)]}return i.invert=function(n,i){var a=m(i/e);return[n/(t*Math.cos(a)),m((2*a+Math.sin(2*a))/r)]},i}(Math.SQRT2/d,Math.SQRT2,p);function C(t,e){var r=e*e,n=r*r;return[t*(.8707-.131979*r+n*(n*(.003971*r-.001529*n)-.013791)),e*(1.007226+r*(.015085+n*(.028874*r-.044475-.005916*n)))]}(t.geo.mollweide=function(){return x(E)}).raw=E,C.invert=function(t,e){var r,n=e,i=25;do{var a=n*n,o=a*a;n-=r=(n*(1.007226+a*(.015085+o*(.028874*a-.044475-.005916*o)))-e)/(1.007226+a*(.045255+o*(.259866*a-.311325-.005916*11*o)))}while(Math.abs(r)>h&&--i>0);return[t/(.8707+(a=n*n)*(a*(a*a*a*(.003971-.001529*a)-.013791)-.131979)),n]},(t.geo.naturalEarth=function(){return x(C)}).raw=C;var L=[[.9986,-.062],[1,0],[.9986,.062],[.9954,.124],[.99,.186],[.9822,.248],[.973,.31],[.96,.372],[.9427,.434],[.9216,.4958],[.8962,.5571],[.8679,.6176],[.835,.6769],[.7986,.7346],[.7597,.7903],[.7186,.8435],[.6732,.8936],[.6213,.9394],[.5722,.9761],[.5322,1]];function P(t,e){var r,n=Math.min(18,36*Math.abs(e)/p),i=Math.floor(n),a=n-i,o=(r=L[i])[0],s=r[1],l=(r=L[++i])[0],c=r[1],u=(r=L[Math.min(19,++i)])[0],h=r[1];return[t*(l+a*(u-o)/2+a*a*(u-2*l+o)/2),(e>0?d:-d)*(c+a*(h-s)/2+a*a*(h-2*c+s)/2)]}function O(t,e){return[t*Math.cos(e),e]}function z(t,e){var r,n=Math.cos(e),i=(r=y(n*Math.cos(t/=2)))?r/Math.sin(r):1;return[2*n*Math.sin(t)*i,Math.sin(e)*i]}function I(t,e){var r=z(t,e);return[(r[0]+t/d)/2,(r[1]+e)/2]}L.forEach(function(t){t[1]*=1.0144}),P.invert=function(t,e){var r=e/d,n=90*r,i=Math.min(18,Math.abs(n/5)),a=Math.max(0,Math.floor(i));do{var o=L[a][1],s=L[a+1][1],l=L[Math.min(19,a+2)][1],c=l-o,u=l-2*s+o,h=2*(Math.abs(r)-s)/c,p=u/c,m=h*(1-p*h*(1-2*p*h));if(m>=0||1===a){n=(e>=0?5:-5)*(m+i);var y,x=50;do{m=(i=Math.min(18,Math.abs(n)/5))-(a=Math.floor(i)),o=L[a][1],s=L[a+1][1],l=L[Math.min(19,a+2)][1],n-=(y=(e>=0?d:-d)*(s+m*(l-o)/2+m*m*(l-2*s+o)/2)-e)*v}while(Math.abs(y)>f&&--x>0);break}}while(--a>=0);var b=L[a][0],_=L[a+1][0],w=L[Math.min(19,a+2)][0];return[t/(_+m*(w-b)/2+m*m*(w-2*_+b)/2),n*g]},(t.geo.robinson=function(){return x(P)}).raw=P,O.invert=function(t,e){return[t/Math.cos(e),e]},(t.geo.sinusoidal=function(){return x(O)}).raw=O,z.invert=function(t,e){if(!(t*t+4*e*e>p*p+h)){var r=t,n=e,i=25;do{var a,o=Math.sin(r),s=Math.sin(r/2),l=Math.cos(r/2),c=Math.sin(n),u=Math.cos(n),f=Math.sin(2*n),d=c*c,g=u*u,v=s*s,m=1-g*l*l,x=m?y(u*l)*Math.sqrt(a=1/m):a=0,b=2*x*u*s-t,_=x*c-e,w=a*(g*v+x*u*l*d),k=a*(.5*o*f-2*x*c*s),T=.25*a*(f*s-x*c*g*o),A=a*(d*l+x*v*u),M=k*T-A*w;if(!M)break;var S=(_*k-b*A)/M,E=(b*T-_*w)/M;r-=S,n-=E}while((Math.abs(S)>h||Math.abs(E)>h)&&--i>0);return[r,n]}},(t.geo.aitoff=function(){return x(z)}).raw=z,I.invert=function(t,e){var r=t,n=e,i=25;do{var a,o=Math.cos(n),s=Math.sin(n),l=Math.sin(2*n),c=s*s,u=o*o,f=Math.sin(r),p=Math.cos(r/2),g=Math.sin(r/2),v=g*g,m=1-u*p*p,x=m?y(o*p)*Math.sqrt(a=1/m):a=0,b=.5*(2*x*o*g+r/d)-t,_=.5*(x*s+n)-e,w=.5*a*(u*v+x*o*p*c)+.5/d,k=a*(f*l/4-x*s*g),T=.125*a*(l*g-x*s*u*f),A=.5*a*(c*p+x*v*o)+.5,M=k*T-A*w,S=(_*k-b*A)/M,E=(b*T-_*w)/M;r-=S,n-=E}while((Math.abs(S)>h||Math.abs(E)>h)&&--i>0);return[r,n]},(t.geo.winkel3=function(){return x(I)}).raw=I}},{}],801:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=Math.PI/180,s=180/Math.PI,l={cursor:\"pointer\"},c={cursor:\"auto\"};function u(t,e){return n.behavior.zoom().translate(e.translate()).scale(e.scale())}function h(t,e,r){var n=t.id,o=t.graphDiv,s=o.layout,l=s[n],c=o._fullLayout,u=c[n],h={},f={};function p(t,e){h[n+\".\"+t]=i.nestedProperty(l,t).get(),a.call(\"_storeDirectGUIEdit\",s,c._preGUI,h);var r=i.nestedProperty(u,t);r.get()!==e&&(r.set(e),i.nestedProperty(l,t).set(e),f[n+\".\"+t]=e)}r(p),p(\"projection.scale\",e.scale()/t.fitScale),o.emit(\"plotly_relayout\",f)}function f(t,e){var r=u(0,e);function i(r){var n=e.invert(t.midPt);r(\"center.lon\",n[0]),r(\"center.lat\",n[1])}return r.on(\"zoomstart\",function(){n.select(this).style(l)}).on(\"zoom\",function(){e.scale(n.event.scale).translate(n.event.translate),t.render();var r=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":r[0],\"geo.center.lat\":r[1]})}).on(\"zoomend\",function(){n.select(this).style(c),h(t,e,i)}),r}function p(t,e){var r,i,a,o,s,f,p,d,g,v=u(0,e),m=2;function y(t){return e.invert(t)}function x(r){var n=e.rotate(),i=e.invert(t.midPt);r(\"projection.rotation.lon\",-n[0]),r(\"center.lon\",i[0]),r(\"center.lat\",i[1])}return v.on(\"zoomstart\",function(){n.select(this).style(l),r=n.mouse(this),i=e.rotate(),a=e.translate(),o=i,s=y(r)}).on(\"zoom\",function(){if(f=n.mouse(this),function(t){var r=y(t);if(!r)return!0;var n=e(r);return Math.abs(n[0]-t[0])>m||Math.abs(n[1]-t[1])>m}(r))return v.scale(e.scale()),void v.translate(e.translate());e.scale(n.event.scale),e.translate([a[0],n.event.translate[1]]),s?y(f)&&(d=y(f),p=[o[0]+(d[0]-s[0]),i[1],i[2]],e.rotate(p),o=p):s=y(r=f),g=!0,t.render();var l=e.rotate(),c=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":c[0],\"geo.center.lat\":c[1],\"geo.projection.rotation.lon\":-l[0]})}).on(\"zoomend\",function(){n.select(this).style(c),g&&h(t,e,x)}),v}function d(t,e){var r,i={r:e.rotate(),k:e.scale()},a=u(0,e),f=function(t){var e=0,r=arguments.length,i=[];for(;++e<r;)i.push(arguments[e]);var a=n.dispatch.apply(null,i);return a.of=function(e,r){return function(i){var o;try{o=i.sourceEvent=n.event,i.target=t,n.event=i,a[i.type].apply(e,r)}finally{n.event=o}}},a}(a,\"zoomstart\",\"zoom\",\"zoomend\"),p=0,d=a.on;function m(t){var r=e.rotate();t(\"projection.rotation.lon\",-r[0]),t(\"projection.rotation.lat\",-r[1])}return a.on(\"zoomstart\",function(){n.select(this).style(l);var t,c,u,h,m,b,_,w,k,T,A,M=n.mouse(this),S=e.rotate(),E=S,C=e.translate(),L=(c=.5*(t=S)[0]*o,u=.5*t[1]*o,h=.5*t[2]*o,m=Math.sin(c),b=Math.cos(c),_=Math.sin(u),w=Math.cos(u),k=Math.sin(h),T=Math.cos(h),[b*w*T+m*_*k,m*w*T-b*_*k,b*_*T+m*w*k,b*w*k-m*_*T]);r=g(e,M),d.call(a,\"zoom\",function(){var t,a,o,l,c,u,h,p,d,m,b=n.mouse(this);if(e.scale(i.k=n.event.scale),r){if(g(e,b)){e.rotate(S).translate(C);var _=g(e,b),w=function(t,e){if(!t||!e)return;var r=function(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}(t,e),n=Math.sqrt(x(r,r)),i=.5*Math.acos(Math.max(-1,Math.min(1,x(t,e)))),a=Math.sin(i)/n;return n&&[Math.cos(i),r[2]*a,-r[1]*a,r[0]*a]}(r,_),k=function(t){return[Math.atan2(2*(t[0]*t[1]+t[2]*t[3]),1-2*(t[1]*t[1]+t[2]*t[2]))*s,Math.asin(Math.max(-1,Math.min(1,2*(t[0]*t[2]-t[3]*t[1]))))*s,Math.atan2(2*(t[0]*t[3]+t[1]*t[2]),1-2*(t[2]*t[2]+t[3]*t[3]))*s]}((a=w,o=(t=L)[0],l=t[1],c=t[2],u=t[3],h=a[0],p=a[1],d=a[2],m=a[3],[o*h-l*p-c*d-u*m,o*p+l*h+c*m-u*d,o*d-l*m+c*h+u*p,o*m+l*d-c*p+u*h])),T=i.r=function(t,e,r){var n=y(e,2,t[0]);n=y(n,1,t[1]),n=y(n,0,t[2]-r[2]);var i,a,o=e[0],l=e[1],c=e[2],u=n[0],h=n[1],f=n[2],p=Math.atan2(l,o)*s,d=Math.sqrt(o*o+l*l);Math.abs(h)>d?(a=(h>0?90:-90)-p,i=0):(a=Math.asin(h/d)*s-p,i=Math.sqrt(d*d-h*h));var g=180-a-2*p,m=(Math.atan2(f,u)-Math.atan2(c,i))*s,x=(Math.atan2(f,u)-Math.atan2(c,-i))*s,b=v(r[0],r[1],a,m),_=v(r[0],r[1],g,x);return b<=_?[a,m,r[2]]:[g,x,r[2]]}(k,r,E);isFinite(T[0])&&isFinite(T[1])&&isFinite(T[2])||(T=E),e.rotate(T),E=T}}else r=g(e,M=b);f.of(this,arguments)({type:\"zoom\"})}),A=f.of(this,arguments),p++||A({type:\"zoomstart\"})}).on(\"zoomend\",function(){var r;n.select(this).style(c),d.call(a,\"zoom\",null),r=f.of(this,arguments),--p||r({type:\"zoomend\"}),h(t,e,m)}).on(\"zoom.redraw\",function(){t.render();var r=e.rotate();t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.projection.rotation.lon\":-r[0],\"geo.projection.rotation.lat\":-r[1]})}),n.rebind(a,f,\"on\")}function g(t,e){var r=t.invert(e);return r&&isFinite(r[0])&&isFinite(r[1])&&function(t){var e=t[0]*o,r=t[1]*o,n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}(r)}function v(t,e,r,n){var i=m(r-t),a=m(n-e);return Math.sqrt(i*i+a*a)}function m(t){return(t%360+540)%360-180}function y(t,e,r){var n=r*o,i=t.slice(),a=0===e?1:0,s=2===e?1:2,l=Math.cos(n),c=Math.sin(n);return i[a]=t[a]*l-t[s]*c,i[s]=t[s]*l+t[a]*c,i}function x(t,e){for(var r=0,n=0,i=t.length;n<i;++n)r+=t[n]*e[n];return r}e.exports=function(t,e){var r=t.projection;return(e._isScoped?f:e._isClipped?d:p)(t,r)}},{\"../../lib\":719,\"../../registry\":847,d3:163}],802:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"./cartesian/constants\").SUBPLOT_PATTERN;r.getSubplotCalcData=function(t,e,r){var i=n.subplotsRegistry[e];if(!i)return[];for(var a=i.attr,o=[],s=0;s<t.length;s++){var l=t[s];l[0].trace[a]===r&&o.push(l)}return o},r.getModuleCalcData=function(t,e){var r,i=[],a=[];if(!(r=\"string\"==typeof e?n.getModule(e).plot:\"function\"==typeof e?e:e.plot))return[i,t];for(var o=0;o<t.length;o++){var s=t[o],l=s[0].trace;!0===l.visible&&0!==l._length&&(l._module.plot===r?i.push(s):a.push(s))}return[i,a]},r.getSubplotData=function(t,e,r){if(!n.subplotsRegistry[e])return[];var a,o,s,l=n.subplotsRegistry[e].attr,c=[];if(\"gl2d\"===e){var u=r.match(i);o=\"x\"+u[1],s=\"y\"+u[2]}for(var h=0;h<t.length;h++)a=t[h],\"gl2d\"===e&&n.traceIs(a,\"gl2d\")?a[l[0]]===o&&a[l[1]]===s&&c.push(a):a[l]===r&&c.push(a);return c}},{\"../registry\":847,\"./cartesian/constants\":773}],803:[function(t,e,r){\"use strict\";var n=t(\"mouse-change\"),i=t(\"mouse-wheel\"),a=t(\"mouse-event-offset\"),o=t(\"../cartesian/constants\"),s=t(\"has-passive-events\");function l(t,e){this.element=t,this.plot=e,this.mouseListener=null,this.wheelListener=null,this.lastInputTime=Date.now(),this.lastPos=[0,0],this.boxEnabled=!1,this.boxInited=!1,this.boxStart=[0,0],this.boxEnd=[0,0],this.dragStart=[0,0]}e.exports=function(t){var e=t.mouseContainer,r=t.glplot,c=new l(e,r);function u(){t.xaxis.autorange=!1,t.yaxis.autorange=!1}function h(e,n,i){var a,s,l=t.calcDataBox(),h=r.viewBox,f=c.lastPos[0],p=c.lastPos[1],d=o.MINDRAG*r.pixelRatio,g=o.MINZOOM*r.pixelRatio;function v(e,r,n){var i=Math.min(r,n),a=Math.max(r,n);i!==a?(l[e]=i,l[e+2]=a,c.dataBox=l,t.setRanges(l)):(t.selectBox.selectBox=[0,0,1,1],t.glplot.setDirty())}switch(n*=r.pixelRatio,i*=r.pixelRatio,i=h[3]-h[1]-i,t.fullLayout.dragmode){case\"zoom\":if(e){var m=n/(h[2]-h[0])*(l[2]-l[0])+l[0],y=i/(h[3]-h[1])*(l[3]-l[1])+l[1];c.boxInited||(c.boxStart[0]=m,c.boxStart[1]=y,c.dragStart[0]=n,c.dragStart[1]=i),c.boxEnd[0]=m,c.boxEnd[1]=y,c.boxInited=!0,c.boxEnabled||c.boxStart[0]===c.boxEnd[0]&&c.boxStart[1]===c.boxEnd[1]||(c.boxEnabled=!0);var x=Math.abs(c.dragStart[0]-n)<g,b=Math.abs(c.dragStart[1]-i)<g;if(!function(){for(var e=t.graphDiv._fullLayout._axisConstraintGroups,r=t.xaxis._id,n=t.yaxis._id,i=0;i<e.length;i++)if(-1!==e[i][r]){if(-1!==e[i][n])return!0;break}return!1}()||x&&b)x&&(c.boxEnd[0]=c.boxStart[0]),b&&(c.boxEnd[1]=c.boxStart[1]);else{a=c.boxEnd[0]-c.boxStart[0],s=c.boxEnd[1]-c.boxStart[1];var _=(l[3]-l[1])/(l[2]-l[0]);Math.abs(a*_)>Math.abs(s)?(c.boxEnd[1]=c.boxStart[1]+Math.abs(a)*_*(s>=0?1:-1),c.boxEnd[1]<l[1]?(c.boxEnd[1]=l[1],c.boxEnd[0]=c.boxStart[0]+(l[1]-c.boxStart[1])/Math.abs(_)):c.boxEnd[1]>l[3]&&(c.boxEnd[1]=l[3],c.boxEnd[0]=c.boxStart[0]+(l[3]-c.boxStart[1])/Math.abs(_))):(c.boxEnd[0]=c.boxStart[0]+Math.abs(s)/_*(a>=0?1:-1),c.boxEnd[0]<l[0]?(c.boxEnd[0]=l[0],c.boxEnd[1]=c.boxStart[1]+(l[0]-c.boxStart[0])*Math.abs(_)):c.boxEnd[0]>l[2]&&(c.boxEnd[0]=l[2],c.boxEnd[1]=c.boxStart[1]+(l[2]-c.boxStart[0])*Math.abs(_)))}}else c.boxEnabled?(a=c.boxStart[0]!==c.boxEnd[0],s=c.boxStart[1]!==c.boxEnd[1],a||s?(a&&(v(0,c.boxStart[0],c.boxEnd[0]),t.xaxis.autorange=!1),s&&(v(1,c.boxStart[1],c.boxEnd[1]),t.yaxis.autorange=!1),t.relayoutCallback()):t.glplot.setDirty(),c.boxEnabled=!1,c.boxInited=!1):c.boxInited&&(c.boxInited=!1);break;case\"pan\":c.boxEnabled=!1,c.boxInited=!1,e?(c.panning||(c.dragStart[0]=n,c.dragStart[1]=i),Math.abs(c.dragStart[0]-n)<d&&(n=c.dragStart[0]),Math.abs(c.dragStart[1]-i)<d&&(i=c.dragStart[1]),a=(f-n)*(l[2]-l[0])/(r.viewBox[2]-r.viewBox[0]),s=(p-i)*(l[3]-l[1])/(r.viewBox[3]-r.viewBox[1]),l[0]+=a,l[2]+=a,l[1]+=s,l[3]+=s,t.setRanges(l),c.panning=!0,c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations()):c.panning&&(c.panning=!1,t.relayoutCallback())}c.lastPos[0]=n,c.lastPos[1]=i}return c.mouseListener=n(e,h),e.addEventListener(\"touchstart\",function(t){var r=a(t.changedTouches[0],e);h(0,r[0],r[1]),h(1,r[0],r[1]),t.preventDefault()},!!s&&{passive:!1}),e.addEventListener(\"touchmove\",function(t){t.preventDefault();var r=a(t.changedTouches[0],e);h(1,r[0],r[1]),t.preventDefault()},!!s&&{passive:!1}),e.addEventListener(\"touchend\",function(t){h(0,c.lastPos[0],c.lastPos[1]),t.preventDefault()},!!s&&{passive:!1}),c.wheelListener=i(e,function(e,n){if(!t.scrollZoom)return!1;var i=t.calcDataBox(),a=r.viewBox,o=c.lastPos[0],s=c.lastPos[1],l=Math.exp(5*n/(a[3]-a[1])),h=o/(a[2]-a[0])*(i[2]-i[0])+i[0],f=s/(a[3]-a[1])*(i[3]-i[1])+i[1];return i[0]=(i[0]-h)*l+h,i[2]=(i[2]-h)*l+h,i[1]=(i[1]-f)*l+f,i[3]=(i[3]-f)*l+f,t.setRanges(i),c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations(),t.relayoutCallback(),!0},!0),c}},{\"../cartesian/constants\":773,\"has-passive-events\":411,\"mouse-change\":435,\"mouse-event-offset\":436,\"mouse-wheel\":438}],804:[function(t,e,r){\"use strict\";var n=t(\"../cartesian/axes\"),i=t(\"../../lib/str2rgbarray\");function a(t){this.scene=t,this.gl=t.gl,this.pixelRatio=t.pixelRatio,this.screenBox=[0,0,1,1],this.viewBox=[0,0,1,1],this.dataBox=[-1,-1,1,1],this.borderLineEnable=[!1,!1,!1,!1],this.borderLineWidth=[1,1,1,1],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.ticks=[[],[]],this.tickEnable=[!0,!0,!1,!1],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labels=[\"x\",\"y\"],this.labelEnable=[!0,!0,!1,!1],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelPad=[15,15,15,15],this.labelSize=[12,12],this.labelFont=[\"sans-serif\",\"sans-serif\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.title=\"\",this.titleEnable=!0,this.titleCenter=[0,0,0,0],this.titleAngle=0,this.titleColor=[0,0,0,1],this.titleFont=\"sans-serif\",this.titleSize=18,this.gridLineEnable=[!0,!0],this.gridLineColor=[[0,0,0,.5],[0,0,0,.5]],this.gridLineWidth=[1,1],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[1,1],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.static=this.scene.staticPlot}var o=a.prototype,s=[\"xaxis\",\"yaxis\"];o.merge=function(t){var e,r,n,a,o,l,c,u,h,f,p;for(this.titleEnable=!1,this.backgroundColor=i(t.plot_bgcolor),f=0;f<2;++f){var d=(e=s[f]).charAt(0);for(n=(r=t[this.scene[e]._name]).title.text===this.scene.fullLayout._dfltTitle[d]?\"\":r.title.text,p=0;p<=2;p+=2)this.labelEnable[f+p]=!1,this.labels[f+p]=n,this.labelColor[f+p]=i(r.title.font.color),this.labelFont[f+p]=r.title.font.family,this.labelSize[f+p]=r.title.font.size,this.labelPad[f+p]=this.getLabelPad(e,r),this.tickEnable[f+p]=!1,this.tickColor[f+p]=i((r.tickfont||{}).color),this.tickAngle[f+p]=\"auto\"===r.tickangle?0:Math.PI*-r.tickangle/180,this.tickPad[f+p]=this.getTickPad(r),this.tickMarkLength[f+p]=0,this.tickMarkWidth[f+p]=r.tickwidth||0,this.tickMarkColor[f+p]=i(r.tickcolor),this.borderLineEnable[f+p]=!1,this.borderLineColor[f+p]=i(r.linecolor),this.borderLineWidth[f+p]=r.linewidth||0;c=this.hasSharedAxis(r),o=this.hasAxisInDfltPos(e,r)&&!c,l=this.hasAxisInAltrPos(e,r)&&!c,a=r.mirror||!1,u=c?-1!==String(a).indexOf(\"all\"):!!a,h=c?\"allticks\"===a:-1!==String(a).indexOf(\"ticks\"),o?this.labelEnable[f]=!0:l&&(this.labelEnable[f+2]=!0),o?this.tickEnable[f]=r.showticklabels:l&&(this.tickEnable[f+2]=r.showticklabels),(o||u)&&(this.borderLineEnable[f]=r.showline),(l||u)&&(this.borderLineEnable[f+2]=r.showline),(o||h)&&(this.tickMarkLength[f]=this.getTickMarkLength(r)),(l||h)&&(this.tickMarkLength[f+2]=this.getTickMarkLength(r)),this.gridLineEnable[f]=r.showgrid,this.gridLineColor[f]=i(r.gridcolor),this.gridLineWidth[f]=r.gridwidth,this.zeroLineEnable[f]=r.zeroline,this.zeroLineColor[f]=i(r.zerolinecolor),this.zeroLineWidth[f]=r.zerolinewidth}},o.hasSharedAxis=function(t){var e=this.scene,r=e.fullLayout._subplots.gl2d;return 0!==n.findSubplotsWithAxis(r,t).indexOf(e.id)},o.hasAxisInDfltPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"bottom\"===r:\"yaxis\"===t?\"left\"===r:void 0},o.hasAxisInAltrPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"top\"===r:\"yaxis\"===t?\"right\"===r:void 0},o.getLabelPad=function(t,e){var r=e.title.font.size,n=e.showticklabels;return\"xaxis\"===t?\"top\"===e.side?r*(1.5+(n?1:0))-10:r*(1.5+(n?.5:0))-10:\"yaxis\"===t?\"right\"===e.side?10+r*(1.5+(n?1:.5)):10+r*(1.5+(n?.5:0)):void 0},o.getTickPad=function(t){return\"outside\"===t.ticks?10+t.ticklen:15},o.getTickMarkLength=function(t){if(!t.ticks)return 0;var e=t.ticklen;return\"inside\"===t.ticks?-e:e},e.exports=function(t){return new a(t)}},{\"../../lib/str2rgbarray\":742,\"../cartesian/axes\":767}],805:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"./scene2d\"),a=t(\"../layout_attributes\"),o=t(\"../../constants/xmlns_namespaces\"),s=t(\"../cartesian/constants\"),l=t(\"../cartesian\"),c=t(\"../../components/fx/layout_attributes\"),u=t(\"../get_data\").getSubplotData;r.name=\"gl2d\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=s.idRegex,r.attrRegex=s.attrRegex,r.attributes=t(\"../cartesian/attributes\"),r.supplyLayoutDefaults=function(t,e,r){e._has(\"cartesian\")||l.supplyLayoutDefaults(t,e,r)},r.layoutAttrOverrides=n(l.layoutAttributes,\"plot\",\"from-root\"),r.baseLayoutAttrOverrides=n({plot_bgcolor:a.plot_bgcolor,hoverlabel:c.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl2d,a=0;a<n.length;a++){var o=n[a],s=e._plots[o],l=u(r,\"gl2d\",o),c=s._scene2d;void 0===c&&(c=new i({id:o,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio},e),s._scene2d=c),c.plot(l,t.calcdata,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl2d||[],a=0;a<i.length;a++){var o=i[a],s=n._plots[o];if(s._scene2d)0===u(t,\"gl2d\",o).length&&(s._scene2d.destroy(),delete n._plots[o])}l.clean.apply(this,arguments)},r.drawFramework=function(t){t._context.staticPlot||l.drawFramework(t)},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){var i=e._plots[r[n]]._scene2d,a=i.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":a,x:0,y:0,width:\"100%\",height:\"100%\",preserveAspectRatio:\"none\"}),i.destroy()}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){e._plots[r[n]]._scene2d.updateFx(e.dragmode)}}},{\"../../components/fx/layout_attributes\":633,\"../../constants/xmlns_namespaces\":696,\"../../plot_api/edit_types\":750,\"../cartesian\":778,\"../cartesian/attributes\":765,\"../cartesian/constants\":773,\"../get_data\":802,\"../layout_attributes\":819,\"./scene2d\":806}],806:[function(t,e,r){\"use strict\";var n,i,a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../../components/fx\"),l=t(\"gl-plot2d\"),c=t(\"gl-spikes2d\"),u=t(\"gl-select-box\"),h=t(\"webgl-context\"),f=t(\"./convert\"),p=t(\"./camera\"),d=t(\"../../lib/show_no_webgl_msg\"),g=t(\"../cartesian/constraints\"),v=g.enforce,m=g.clean,y=t(\"../cartesian/autorange\").doAutoRange,x=[\"xaxis\",\"yaxis\"],b=t(\"../cartesian/constants\").SUBPLOT_PATTERN;function _(t,e){this.container=t.container,this.graphDiv=t.graphDiv,this.pixelRatio=t.plotGlPixelRatio||window.devicePixelRatio,this.id=t.id,this.staticPlot=!!t.staticPlot,this.scrollZoom=this.graphDiv._context._scrollZoom.cartesian,this.fullData=null,this.updateRefs(e),this.makeFramework(),this.stopped||(this.glplotOptions=f(this),this.glplotOptions.merge(e),this.glplot=l(this.glplotOptions),this.camera=p(this),this.traces={},this.spikes=c(this.glplot),this.selectBox=u(this.glplot,{innerFill:!1,outerFill:!0}),this.lastButtonState=0,this.pickResult=null,this.isMouseOver=!0,this.stopped=!1,this.redraw=this.draw.bind(this),this.redraw())}e.exports=_;var w=_.prototype;w.makeFramework=function(){if(this.staticPlot){if(!(i||(n=document.createElement(\"canvas\"),i=h({canvas:n,preserveDrawingBuffer:!1,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"Error creating static canvas/context for image server\");this.canvas=n,this.gl=i}else{var t=this.container.querySelector(\".gl-canvas-focus\"),e=h({canvas:t,preserveDrawingBuffer:!0,premultipliedAlpha:!0});if(!e)return d(this),void(this.stopped=!0);this.canvas=t,this.gl=e}var r=this.canvas;r.style.width=\"100%\",r.style.height=\"100%\",r.style.position=\"absolute\",r.style.top=\"0px\",r.style.left=\"0px\",r.style[\"pointer-events\"]=\"none\",this.updateSize(r),r.className+=\" user-select-none\";var a=this.svgContainer=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");a.style.position=\"absolute\",a.style.top=a.style.left=\"0px\",a.style.width=a.style.height=\"100%\",a.style[\"z-index\"]=20,a.style[\"pointer-events\"]=\"none\";var o=this.mouseContainer=document.createElement(\"div\");o.style.position=\"absolute\",o.style[\"pointer-events\"]=\"auto\",this.pickCanvas=this.container.querySelector(\".gl-canvas-pick\");var s=this.container;s.appendChild(a),s.appendChild(o);var l=this;o.addEventListener(\"mouseout\",function(){l.isMouseOver=!1,l.unhover()}),o.addEventListener(\"mouseover\",function(){l.isMouseOver=!0})},w.toImage=function(t){t||(t=\"png\"),this.stopped=!0,this.staticPlot&&this.container.appendChild(n),this.updateSize(this.canvas);var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.clearColor(1,1,1,0),e.clear(e.COLOR_BUFFER_BIT|e.DEPTH_BUFFER_BIT),this.glplot.setDirty(),this.glplot.draw(),e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a);for(var o=0,s=i-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=a[4*(r*o+l)+c];a[4*(r*o+l)+c]=a[4*(r*s+l)+c],a[4*(r*s+l)+c]=u}var h=document.createElement(\"canvas\");h.width=r,h.height=i;var f,p=h.getContext(\"2d\"),d=p.createImageData(r,i);switch(d.data.set(a),p.putImageData(d,0,0),t){case\"jpeg\":f=h.toDataURL(\"image/jpeg\");break;case\"webp\":f=h.toDataURL(\"image/webp\");break;default:f=h.toDataURL(\"image/png\")}return this.staticPlot&&this.container.removeChild(n),f},w.updateSize=function(t){t||(t=this.canvas);var e=this.pixelRatio,r=this.fullLayout,n=r.width,i=r.height,a=0|Math.ceil(e*n),o=0|Math.ceil(e*i);return t.width===a&&t.height===o||(t.width=a,t.height=o),t},w.computeTickMarks=function(){this.xaxis.setScale(),this.yaxis.setScale();for(var t=[o.calcTicks(this.xaxis),o.calcTicks(this.yaxis)],e=0;e<2;++e)for(var r=0;r<t[e].length;++r)t[e][r].text=t[e][r].text+\"\";return t},w.updateRefs=function(t){this.fullLayout=t;var e=this.id.match(b),r=\"xaxis\"+e[1],n=\"yaxis\"+e[2];this.xaxis=this.fullLayout[r],this.yaxis=this.fullLayout[n]},w.relayoutCallback=function(){var t=this.graphDiv,e=this.xaxis,r=this.yaxis,n=t.layout,i={},o=i[e._name+\".range\"]=e.range.slice(),s=i[r._name+\".range\"]=r.range.slice();i[e._name+\".autorange\"]=e.autorange,i[r._name+\".autorange\"]=r.autorange,a.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,i);var l=n[e._name];l.range=o,l.autorange=e.autorange;var c=n[r._name];c.range=s,c.autorange=r.autorange,i.lastInputTime=this.camera.lastInputTime,t.emit(\"plotly_relayout\",i)},w.cameraChanged=function(){var t=this.camera;this.glplot.setDataBox(this.calcDataBox());var e=this.computeTickMarks();(function(t,e){for(var r=0;r<2;++r){var n=t[r],i=e[r];if(n.length!==i.length)return!0;for(var a=0;a<n.length;++a)if(n[a].x!==i[a].x)return!0}return!1})(e,this.glplotOptions.ticks)&&(this.glplotOptions.ticks=e,this.glplotOptions.dataBox=t.dataBox,this.glplot.update(this.glplotOptions),this.handleAnnotations())},w.handleAnnotations=function(){for(var t=this.graphDiv,e=this.fullLayout.annotations,r=0;r<e.length;r++){var n=e[r];n.xref===this.xaxis._id&&n.yref===this.yaxis._id&&a.getComponentMethod(\"annotations\",\"drawOne\")(t,r)}},w.destroy=function(){if(this.glplot){var t=this.traces;t&&Object.keys(t).map(function(e){t[e].dispose(),delete t[e]}),this.glplot.dispose(),this.container.removeChild(this.svgContainer),this.container.removeChild(this.mouseContainer),this.fullData=null,this.glplot=null,this.stopped=!0,this.camera.mouseListener.enabled=!1,this.mouseContainer.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=null}},w.plot=function(t,e,r){var n=this.glplot;this.updateRefs(r),this.xaxis.clearCalc(),this.yaxis.clearCalc(),this.updateTraces(t,e),this.updateFx(r.dragmode);var i=r.width,a=r.height;this.updateSize(this.canvas);var o=this.glplotOptions;o.merge(r),o.screenBox=[0,0,i,a];var s={_fullLayout:{_axisConstraintGroups:this.graphDiv._fullLayout._axisConstraintGroups,xaxis:this.xaxis,yaxis:this.yaxis}};m(s,this.xaxis),m(s,this.yaxis);var l,c,u=r._size,h=this.xaxis.domain,f=this.yaxis.domain;for(o.viewBox=[u.l+h[0]*u.w,u.b+f[0]*u.h,i-u.r-(1-h[1])*u.w,a-u.t-(1-f[1])*u.h],this.mouseContainer.style.width=u.w*(h[1]-h[0])+\"px\",this.mouseContainer.style.height=u.h*(f[1]-f[0])+\"px\",this.mouseContainer.height=u.h*(f[1]-f[0]),this.mouseContainer.style.left=u.l+h[0]*u.w+\"px\",this.mouseContainer.style.top=u.t+(1-f[1])*u.h+\"px\",c=0;c<2;++c)(l=this[x[c]])._length=o.viewBox[c+2]-o.viewBox[c],y(this.graphDiv,l),l.setScale();v(s),o.ticks=this.computeTickMarks(),o.dataBox=this.calcDataBox(),o.merge(r),n.update(o),this.glplot.draw()},w.calcDataBox=function(){var t=this.xaxis,e=this.yaxis,r=t.range,n=e.range,i=t.r2l,a=e.r2l;return[i(r[0]),a(n[0]),i(r[1]),a(n[1])]},w.setRanges=function(t){var e=this.xaxis,r=this.yaxis,n=e.l2r,i=r.l2r;e.range=[n(t[0]),n(t[2])],r.range=[i(t[1]),i(t[3])]},w.updateTraces=function(t,e){var r,n,i,a=Object.keys(this.traces);this.fullData=t;t:for(r=0;r<a.length;r++){var o=a[r],s=this.traces[o];for(n=0;n<t.length;n++)if((i=t[n]).uid===o&&i.type===s.type)continue t;s.dispose(),delete this.traces[o]}for(r=0;r<t.length;r++){i=t[r];var l=e[r],c=this.traces[i.uid];c?c.update(i,l):(c=i._module.plot(this,i,l),this.traces[i.uid]=c)}this.glplot.objects.sort(function(t,e){return t._trace.index-e._trace.index})},w.updateFx=function(t){\"lasso\"===t||\"select\"===t?(this.pickCanvas.style[\"pointer-events\"]=\"none\",this.mouseContainer.style[\"pointer-events\"]=\"none\"):(this.pickCanvas.style[\"pointer-events\"]=\"auto\",this.mouseContainer.style[\"pointer-events\"]=\"auto\"),this.mouseContainer.style.cursor=\"pan\"===t?\"move\":\"zoom\"===t?\"crosshair\":null},w.emitPointAction=function(t,e){for(var r,n=t.trace.uid,i=t.pointIndex,a=0;a<this.fullData.length;a++)this.fullData[a].uid===n&&(r=this.fullData[a]);var o={x:t.traceCoord[0],y:t.traceCoord[1],curveNumber:r.index,pointNumber:i,data:r._input,fullData:this.fullData,xaxis:this.xaxis,yaxis:this.yaxis};s.appendArrayPointValue(o,r,i),this.graphDiv.emit(e,{points:[o]})},w.draw=function(){if(!this.stopped){requestAnimationFrame(this.redraw);var t=this.glplot,e=this.camera,r=e.mouseListener,n=1===this.lastButtonState&&0===r.buttons,i=this.fullLayout;this.lastButtonState=r.buttons,this.cameraChanged();var a,o=r.x*t.pixelRatio,l=this.canvas.height-t.pixelRatio*r.y;if(e.boxEnabled&&\"zoom\"===i.dragmode){this.selectBox.enabled=!0;for(var c=this.selectBox.selectBox=[Math.min(e.boxStart[0],e.boxEnd[0]),Math.min(e.boxStart[1],e.boxEnd[1]),Math.max(e.boxStart[0],e.boxEnd[0]),Math.max(e.boxStart[1],e.boxEnd[1])],u=0;u<2;u++)e.boxStart[u]===e.boxEnd[u]&&(c[u]=t.dataBox[u],c[u+2]=t.dataBox[u+2]);t.setDirty()}else if(!e.panning&&this.isMouseOver){this.selectBox.enabled=!1;var h=i._size,f=this.xaxis.domain,p=this.yaxis.domain,d=(a=t.pick(o/t.pixelRatio+h.l+f[0]*h.w,l/t.pixelRatio-(h.t+(1-p[1])*h.h)))&&a.object._trace.handlePick(a);if(d&&n&&this.emitPointAction(d,\"plotly_click\"),a&&\"skip\"!==a.object._trace.hoverinfo&&i.hovermode&&d&&(!this.lastPickResult||this.lastPickResult.traceUid!==d.trace.uid||this.lastPickResult.dataCoord[0]!==d.dataCoord[0]||this.lastPickResult.dataCoord[1]!==d.dataCoord[1])){var g=d;this.lastPickResult={traceUid:d.trace?d.trace.uid:null,dataCoord:d.dataCoord.slice()},this.spikes.update({center:a.dataCoord}),g.screenCoord=[((t.viewBox[2]-t.viewBox[0])*(a.dataCoord[0]-t.dataBox[0])/(t.dataBox[2]-t.dataBox[0])+t.viewBox[0])/t.pixelRatio,(this.canvas.height-(t.viewBox[3]-t.viewBox[1])*(a.dataCoord[1]-t.dataBox[1])/(t.dataBox[3]-t.dataBox[1])-t.viewBox[1])/t.pixelRatio],this.emitPointAction(d,\"plotly_hover\");var v=this.fullData[g.trace.index]||{},m=g.pointIndex,y=s.castHoverinfo(v,i,m);if(y&&\"all\"!==y){var x=y.split(\"+\");-1===x.indexOf(\"x\")&&(g.traceCoord[0]=void 0),-1===x.indexOf(\"y\")&&(g.traceCoord[1]=void 0),-1===x.indexOf(\"z\")&&(g.traceCoord[2]=void 0),-1===x.indexOf(\"text\")&&(g.textLabel=void 0),-1===x.indexOf(\"name\")&&(g.name=void 0)}s.loneHover({x:g.screenCoord[0],y:g.screenCoord[1],xLabel:this.hoverFormatter(\"xaxis\",g.traceCoord[0]),yLabel:this.hoverFormatter(\"yaxis\",g.traceCoord[1]),zLabel:g.traceCoord[2],text:g.textLabel,name:g.name,color:s.castHoverOption(v,m,\"bgcolor\")||g.color,borderColor:s.castHoverOption(v,m,\"bordercolor\"),fontFamily:s.castHoverOption(v,m,\"font.family\"),fontSize:s.castHoverOption(v,m,\"font.size\"),fontColor:s.castHoverOption(v,m,\"font.color\"),nameLength:s.castHoverOption(v,m,\"namelength\"),textAlign:s.castHoverOption(v,m,\"align\")},{container:this.svgContainer,gd:this.graphDiv})}}a||this.unhover(),t.draw()}},w.unhover=function(){this.lastPickResult&&(this.spikes.update({}),this.lastPickResult=null,this.graphDiv.emit(\"plotly_unhover\"),s.loneUnhover(this.svgContainer))},w.hoverFormatter=function(t,e){if(void 0!==e){var r=this[t];return o.tickText(r,r.c2l(e),\"hover\").text}}},{\"../../components/fx\":632,\"../../lib/show_no_webgl_msg\":740,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../cartesian/autorange\":766,\"../cartesian/constants\":773,\"../cartesian/constraints\":774,\"./camera\":803,\"./convert\":804,\"gl-plot2d\":287,\"gl-select-box\":299,\"gl-spikes2d\":308,\"webgl-context\":556}],807:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../components/fx/layout_attributes\"),a=t(\"./scene\"),o=t(\"../get_data\").getSubplotData,s=t(\"../../lib\"),l=t(\"../../constants/xmlns_namespaces\");r.name=\"gl3d\",r.attr=\"scene\",r.idRoot=\"scene\",r.idRegex=r.attrRegex=s.counterRegex(\"scene\"),r.attributes=t(\"./layout/attributes\"),r.layoutAttributes=t(\"./layout/layout_attributes\"),r.baseLayoutAttrOverrides=n({hoverlabel:i.hoverlabel},\"plot\",\"nested\"),r.supplyLayoutDefaults=t(\"./layout/defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl3d,i=0;i<n.length;i++){var s=n[i],l=o(r,\"gl3d\",s),c=e[s],u=c.camera,h=c._scene;h||(h=new a({id:s,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio,camera:u},e),c._scene=h),h.viewInitial||(h.viewInitial={up:{x:u.up.x,y:u.up.y,z:u.up.z},eye:{x:u.eye.x,y:u.eye.y,z:u.eye.z},center:{x:u.center.x,y:u.center.y,z:u.center.z}}),h.plot(l,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl3d||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._scene&&(n[o]._scene.destroy(),n._infolayer&&n._infolayer.selectAll(\".annotation-\"+o).remove())}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=e._size,i=0;i<r.length;i++){var a=e[r[i]],o=a.domain,s=a._scene,c=s.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:l.svg,\"xlink:href\":c,x:n.l+n.w*o.x[0],y:n.t+n.h*(1-o.y[1]),width:n.w*(o.x[1]-o.x[0]),height:n.h*(o.y[1]-o.y[0]),preserveAspectRatio:\"none\"}),s.destroy()}},r.cleanId=function(t){if(t.match(/^scene[0-9]*$/)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),\"scene\"+e}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){e[r[n]]._scene.updateFx(e.dragmode,e.hovermode)}}},{\"../../components/fx/layout_attributes\":633,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../plot_api/edit_types\":750,\"../get_data\":802,\"./layout/attributes\":808,\"./layout/defaults\":812,\"./layout/layout_attributes\":813,\"./scene\":817}],808:[function(t,e,r){\"use strict\";e.exports={scene:{valType:\"subplotid\",dflt:\"scene\",editType:\"calc+clearAxisTypes\"}}},{}],809:[function(t,e,r){\"use strict\";var n=t(\"../../../components/color\"),i=t(\"../../cartesian/layout_attributes\"),a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../plot_api/edit_types\").overrideAll;e.exports=o({visible:i.visible,showspikes:{valType:\"boolean\",dflt:!0},spikesides:{valType:\"boolean\",dflt:!0},spikethickness:{valType:\"number\",min:0,dflt:2},spikecolor:{valType:\"color\",dflt:n.defaultLine},showbackground:{valType:\"boolean\",dflt:!1},backgroundcolor:{valType:\"color\",dflt:\"rgba(204, 204, 204, 0.5)\"},showaxeslabels:{valType:\"boolean\",dflt:!0},color:i.color,categoryorder:i.categoryorder,categoryarray:i.categoryarray,title:i.title,type:a({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autorange:i.autorange,rangemode:i.rangemode,range:a({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],anim:!1}),tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,mirror:i.mirror,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,tickfont:i.tickfont,tickangle:i.tickangle,tickprefix:i.tickprefix,showtickprefix:i.showtickprefix,ticksuffix:i.ticksuffix,showticksuffix:i.showticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,separatethousands:i.separatethousands,tickformat:i.tickformat,tickformatstops:i.tickformatstops,hoverformat:i.hoverformat,showline:i.showline,linecolor:i.linecolor,linewidth:i.linewidth,showgrid:i.showgrid,gridcolor:a({},i.gridcolor,{dflt:\"rgb(204, 204, 204)\"}),gridwidth:i.gridwidth,zeroline:i.zeroline,zerolinecolor:i.zerolinecolor,zerolinewidth:i.zerolinewidth,_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}},\"plot\",\"from-root\")},{\"../../../components/color\":593,\"../../../lib/extend\":710,\"../../../plot_api/edit_types\":750,\"../../cartesian/layout_attributes\":779}],810:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../../lib\"),a=t(\"../../../plot_api/plot_template\"),o=t(\"./axis_attributes\"),s=t(\"../../cartesian/type_defaults\"),l=t(\"../../cartesian/axis_defaults\"),c=[\"xaxis\",\"yaxis\",\"zaxis\"];e.exports=function(t,e,r){var u,h;function f(t,e){return i.coerce(u,h,o,t,e)}for(var p=0;p<c.length;p++){var d=c[p];u=t[d]||{},(h=a.newContainer(e,d))._id=d[0]+r.scene,h._name=d,s(u,h,f,r),l(u,h,f,{font:r.font,letter:d[0],data:r.data,showGrid:!0,noTickson:!0,bgColor:r.bgColor,calendar:r.calendar},r.fullLayout),f(\"gridcolor\",n(h.color,r.bgColor,13600/187).toRgbString()),f(\"title.text\",d[0]),h.setScale=i.noop,f(\"showspikes\")&&(f(\"spikesides\"),f(\"spikethickness\"),f(\"spikecolor\",h.color)),f(\"showaxeslabels\"),f(\"showbackground\")&&f(\"backgroundcolor\")}}},{\"../../../lib\":719,\"../../../plot_api/plot_template\":757,\"../../cartesian/axis_defaults\":769,\"../../cartesian/type_defaults\":790,\"./axis_attributes\":809,tinycolor2:537}],811:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"];function o(){this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[18,18,18],this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=[\"Open Sans\",\"Open Sans\",\"Open Sans\"],this.labelSize=[20,20,20],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[30,30,30],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[10,10,10],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!0,!0,!0],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._defaultTickPad=this.tickPad.slice(),this._defaultLabelPad=this.labelPad.slice(),this._defaultLineTickLength=this.lineTickLength.slice()}o.prototype.merge=function(t,e){for(var r=0;r<3;++r){var o=e[a[r]];o.visible?(this.labels[r]=t._meta?i.templateString(o.title.text,t._meta):o.title.text,\"font\"in o.title&&(o.title.font.color&&(this.labelColor[r]=n(o.title.font.color)),o.title.font.family&&(this.labelFont[r]=o.title.font.family),o.title.font.size&&(this.labelSize[r]=o.title.font.size)),\"showline\"in o&&(this.lineEnable[r]=o.showline),\"linecolor\"in o&&(this.lineColor[r]=n(o.linecolor)),\"linewidth\"in o&&(this.lineWidth[r]=o.linewidth),\"showgrid\"in o&&(this.gridEnable[r]=o.showgrid),\"gridcolor\"in o&&(this.gridColor[r]=n(o.gridcolor)),\"gridwidth\"in o&&(this.gridWidth[r]=o.gridwidth),\"log\"===o.type?this.zeroEnable[r]=!1:\"zeroline\"in o&&(this.zeroEnable[r]=o.zeroline),\"zerolinecolor\"in o&&(this.zeroLineColor[r]=n(o.zerolinecolor)),\"zerolinewidth\"in o&&(this.zeroLineWidth[r]=o.zerolinewidth),\"ticks\"in o&&o.ticks?this.lineTickEnable[r]=!0:this.lineTickEnable[r]=!1,\"ticklen\"in o&&(this.lineTickLength[r]=this._defaultLineTickLength[r]=o.ticklen),\"tickcolor\"in o&&(this.lineTickColor[r]=n(o.tickcolor)),\"tickwidth\"in o&&(this.lineTickWidth[r]=o.tickwidth),\"tickangle\"in o&&(this.tickAngle[r]=\"auto\"===o.tickangle?-3600:Math.PI*-o.tickangle/180),\"showticklabels\"in o&&(this.tickEnable[r]=o.showticklabels),\"tickfont\"in o&&(o.tickfont.color&&(this.tickColor[r]=n(o.tickfont.color)),o.tickfont.family&&(this.tickFont[r]=o.tickfont.family),o.tickfont.size&&(this.tickSize[r]=o.tickfont.size)),\"mirror\"in o?-1!==[\"ticks\",\"all\",\"allticks\"].indexOf(o.mirror)?(this.lineTickMirror[r]=!0,this.lineMirror[r]=!0):!0===o.mirror?(this.lineTickMirror[r]=!1,this.lineMirror[r]=!0):(this.lineTickMirror[r]=!1,this.lineMirror[r]=!1):this.lineMirror[r]=!1,\"showbackground\"in o&&!1!==o.showbackground?(this.backgroundEnable[r]=!0,this.backgroundColor[r]=n(o.backgroundcolor)):this.backgroundEnable[r]=!1):(this.tickEnable[r]=!1,this.labelEnable[r]=!1,this.lineEnable[r]=!1,this.lineTickEnable[r]=!1,this.gridEnable[r]=!1,this.zeroEnable[r]=!1,this.backgroundEnable[r]=!1)}},e.exports=function(t,e){var r=new o;return r.merge(t,e),r}},{\"../../../lib\":719,\"../../../lib/str2rgbarray\":742}],812:[function(t,e,r){\"use strict\";var n=t(\"../../../lib\"),i=t(\"../../../components/color\"),a=t(\"../../../registry\"),o=t(\"../../subplot_defaults\"),s=t(\"./axis_defaults\"),l=t(\"./layout_attributes\"),c=t(\"../../get_data\").getSubplotData,u=\"gl3d\";function h(t,e,r,n){for(var o=r(\"bgcolor\"),l=i.combine(o,n.paper_bgcolor),h=[\"up\",\"center\",\"eye\"],f=0;f<h.length;f++)r(\"camera.\"+h[f]+\".x\"),r(\"camera.\"+h[f]+\".y\"),r(\"camera.\"+h[f]+\".z\");r(\"camera.projection.type\");var p=!!r(\"aspectratio.x\")&&!!r(\"aspectratio.y\")&&!!r(\"aspectratio.z\"),d=r(\"aspectmode\",p?\"manual\":\"auto\");p||(t.aspectratio=e.aspectratio={x:1,y:1,z:1},\"manual\"===d&&(e.aspectmode=\"auto\"),t.aspectmode=e.aspectmode);var g=c(n.fullData,u,n.id);s(t,e,{font:n.font,scene:n.id,data:g,bgColor:l,calendar:n.calendar,fullLayout:n.fullLayout}),a.getComponentMethod(\"annotations3d\",\"handleDefaults\")(t,e,n);var v=n.getDfltFromLayout(\"dragmode\");if(!1!==v&&!v)if(v=\"orbit\",t.camera&&t.camera.up){var m=t.camera.up.x,y=t.camera.up.y,x=t.camera.up.z;0!==x&&(m&&y&&x?x/Math.sqrt(m*m+y*y+x*x)>.999&&(v=\"turntable\"):v=\"turntable\")}else v=\"turntable\";r(\"dragmode\",v),r(\"hovermode\",n.getDfltFromLayout(\"hovermode\"))}e.exports=function(t,e,r){var i=e._basePlotModules.length>1;o(t,e,r,{type:u,attributes:l,handleDefaults:h,fullLayout:e,font:e.font,fullData:r,getDfltFromLayout:function(e){if(!i)return n.validate(t[e],l[e])?t[e]:void 0},paper_bgcolor:e.paper_bgcolor,calendar:e.calendar})}},{\"../../../components/color\":593,\"../../../lib\":719,\"../../../registry\":847,\"../../get_data\":802,\"../../subplot_defaults\":842,\"./axis_defaults\":810,\"./layout_attributes\":813}],813:[function(t,e,r){\"use strict\";var n=t(\"./axis_attributes\"),i=t(\"../../domain\").attributes,a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../lib\").counterRegex;function s(t,e,r){return{x:{valType:\"number\",dflt:t,editType:\"camera\"},y:{valType:\"number\",dflt:e,editType:\"camera\"},z:{valType:\"number\",dflt:r,editType:\"camera\"},editType:\"camera\"}}e.exports={_arrayAttrRegexps:[o(\"scene\",\".annotations\",!0)],bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"plot\"},camera:{up:a(s(0,0,1),{}),center:a(s(0,0,0),{}),eye:a(s(1.25,1.25,1.25),{}),projection:{type:{valType:\"enumerated\",values:[\"perspective\",\"orthographic\"],dflt:\"perspective\",editType:\"calc\"},editType:\"calc\"},editType:\"camera\"},domain:i({name:\"scene\",editType:\"plot\"}),aspectmode:{valType:\"enumerated\",values:[\"auto\",\"cube\",\"data\",\"manual\"],dflt:\"auto\",editType:\"plot\",impliedEdits:{\"aspectratio.x\":void 0,\"aspectratio.y\":void 0,\"aspectratio.z\":void 0}},aspectratio:{x:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},y:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},z:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},editType:\"plot\",impliedEdits:{aspectmode:\"manual\"}},xaxis:n,yaxis:n,zaxis:n,dragmode:{valType:\"enumerated\",values:[\"orbit\",\"turntable\",\"zoom\",\"pan\",!1],editType:\"plot\"},hovermode:{valType:\"enumerated\",values:[\"closest\",!1],dflt:\"closest\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"plot\",_deprecated:{cameraposition:{valType:\"info_array\",editType:\"camera\"}}}},{\"../../../lib\":719,\"../../../lib/extend\":710,\"../../domain\":792,\"./axis_attributes\":809}],814:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=[\"xaxis\",\"yaxis\",\"zaxis\"];function a(){this.enabled=[!0,!0,!0],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.drawSides=[!0,!0,!0],this.lineWidth=[1,1,1]}a.prototype.merge=function(t){for(var e=0;e<3;++e){var r=t[i[e]];r.visible?(this.enabled[e]=r.showspikes,this.colors[e]=n(r.spikecolor),this.drawSides[e]=r.spikesides,this.lineWidth[e]=r.spikethickness):(this.enabled[e]=!1,this.drawSides[e]=!1)}},e.exports=function(t){var e=new a;return e.merge(t),e}},{\"../../../lib/str2rgbarray\":742}],815:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.axesOptions,r=t.glplot.axesPixels,s=t.fullSceneLayout,l=[[],[],[]],c=0;c<3;++c){var u=s[a[c]];if(u._length=(r[c].hi-r[c].lo)*r[c].pixelsPerDataUnit/t.dataScale[c],Math.abs(u._length)===1/0||isNaN(u._length))l[c]=[];else{u._input_range=u.range.slice(),u.range[0]=r[c].lo/t.dataScale[c],u.range[1]=r[c].hi/t.dataScale[c],u._m=1/(t.dataScale[c]*r[c].pixelsPerDataUnit),u.range[0]===u.range[1]&&(u.range[0]-=1,u.range[1]+=1);var h=u.tickmode;if(\"auto\"===u.tickmode){u.tickmode=\"linear\";var f=u.nticks||i.constrain(u._length/40,4,9);n.autoTicks(u,Math.abs(u.range[1]-u.range[0])/f)}for(var p=n.calcTicks(u),d=0;d<p.length;++d)p[d].x=p[d].x*t.dataScale[c],\"date\"===u.type&&(p[d].text=p[d].text.replace(/\\<br\\>/g,\" \"));l[c]=p,u.tickmode=h}}e.ticks=l;for(var c=0;c<3;++c){o[c]=.5*(t.glplot.bounds[0][c]+t.glplot.bounds[1][c]);for(var d=0;d<2;++d)e.bounds[d][c]=t.glplot.bounds[d][c]}t.contourLevels=function(t){for(var e=new Array(3),r=0;r<3;++r){for(var n=t[r],i=new Array(n.length),a=0;a<n.length;++a)i[a]=n[a].x;e[r]=i}return e}(l)};var n=t(\"../../cartesian/axes\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"],o=[0,0,0]},{\"../../../lib\":719,\"../../cartesian/axes\":767}],816:[function(t,e,r){\"use strict\";function n(t,e){var r,n,i=[0,0,0,0];for(r=0;r<4;++r)for(n=0;n<4;++n)i[n]+=t[4*r+n]*e[r];return i}e.exports=function(t,e){return n(t.projection,n(t.view,n(t.model,[e[0],e[1],e[2],1])))}},{}],817:[function(t,e,r){\"use strict\";var n,i,a=t(\"gl-plot3d\").createCamera,o=t(\"gl-plot3d\").createScene,s=t(\"webgl-context\"),l=t(\"has-passive-events\"),c=t(\"../../registry\"),u=t(\"../../lib\"),h=t(\"../../plots/cartesian/axes\"),f=t(\"../../components/fx\"),p=t(\"../../lib/str2rgbarray\"),d=t(\"../../lib/show_no_webgl_msg\"),g=t(\"./project\"),v=t(\"./layout/convert\"),m=t(\"./layout/spikes\"),y=t(\"./layout/tick_marks\");function x(t,e,r,a){if(t.initializeGLCamera(),!function(t,e,r,a,l){var c={canvas:a,gl:l,container:t.container,axes:t.axesOptions,spikes:t.spikeOptions,pickRadius:10,snapToData:!0,autoScale:!0,autoBounds:!1,cameraObject:e,pixelRatio:r};if(t.staticMode){if(!(i||(n=document.createElement(\"canvas\"),i=s({canvas:n,preserveDrawingBuffer:!0,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"error creating static canvas/context for image server\");c.pixelRatio=t.pixelRatio,c.gl=i,c.canvas=n}try{t.glplot=o(c)}catch(t){return!1}return!0}(t,t.camera,e,r,a))return d(t);var c=t.graphDiv,p=function(t){if(!1!==t.fullSceneLayout.dragmode){var e={};e[t.id+\".camera\"]=T(t.camera),t.saveCamera(c.layout),t.graphDiv.emit(\"plotly_relayout\",e)}};return t.glplot.canvas.addEventListener(\"mouseup\",function(){p(t)}),t.glplot.canvas.addEventListener(\"wheel\",function(){c._context._scrollZoom.gl3d&&p(t)},!!l&&{passive:!1}),t.glplot.canvas.addEventListener(\"mousemove\",function(){if(!1!==t.fullSceneLayout.dragmode&&0!==t.camera.mouseListener.buttons){var e={};e[t.id+\".camera\"]=T(t.camera),t.graphDiv.emit(\"plotly_relayouting\",e)}}),t.staticMode||t.glplot.canvas.addEventListener(\"webglcontextlost\",function(e){c&&c.emit&&c.emit(\"plotly_webglcontextlost\",{event:e,layer:t.id})},!1),t.glplot.camera=t.camera,t.glplot.oncontextloss=function(){t.recoverContext()},t.glplot.onrender=function(t){var e,r=t.graphDiv,n=t.svgContainer,i=t.container.getBoundingClientRect(),a=i.width,o=i.height;n.setAttributeNS(null,\"viewBox\",\"0 0 \"+a+\" \"+o),n.setAttributeNS(null,\"width\",a),n.setAttributeNS(null,\"height\",o),y(t),t.glplot.axes.update(t.axesOptions);for(var s,l=Object.keys(t.traces),c=null,p=t.glplot.selection,d=0;d<l.length;++d)\"skip\"!==(e=t.traces[l[d]]).data.hoverinfo&&e.handlePick(p)&&(c=e),e.setContourLevels&&e.setContourLevels();function v(e,r){var n=t.fullSceneLayout[e];return h.tickText(n,n.d2l(r),\"hover\").text}if(null!==c){var m=g(t.glplot.cameraParams,p.dataCoordinate);e=c.data;var x,b=r._fullData[e.index],_=p.index,w={xLabel:v(\"xaxis\",p.traceCoordinate[0]),yLabel:v(\"yaxis\",p.traceCoordinate[1]),zLabel:v(\"zaxis\",p.traceCoordinate[2])},k=f.castHoverinfo(b,t.fullLayout,_),T=(k||\"\").split(\"+\"),A=k&&\"all\"===k;b.hovertemplate||A||(-1===T.indexOf(\"x\")&&(w.xLabel=void 0),-1===T.indexOf(\"y\")&&(w.yLabel=void 0),-1===T.indexOf(\"z\")&&(w.zLabel=void 0),-1===T.indexOf(\"text\")&&(p.textLabel=void 0),-1===T.indexOf(\"name\")&&(c.name=void 0));var M=[];\"cone\"===e.type||\"streamtube\"===e.type?(w.uLabel=v(\"xaxis\",p.traceCoordinate[3]),(A||-1!==T.indexOf(\"u\"))&&M.push(\"u: \"+w.uLabel),w.vLabel=v(\"yaxis\",p.traceCoordinate[4]),(A||-1!==T.indexOf(\"v\"))&&M.push(\"v: \"+w.vLabel),w.wLabel=v(\"zaxis\",p.traceCoordinate[5]),(A||-1!==T.indexOf(\"w\"))&&M.push(\"w: \"+w.wLabel),w.normLabel=p.traceCoordinate[6].toPrecision(3),(A||-1!==T.indexOf(\"norm\"))&&M.push(\"norm: \"+w.normLabel),\"streamtube\"===e.type&&(w.divergenceLabel=p.traceCoordinate[7].toPrecision(3),(A||-1!==T.indexOf(\"divergence\"))&&M.push(\"divergence: \"+w.divergenceLabel)),p.textLabel&&M.push(p.textLabel),x=M.join(\"<br>\")):\"isosurface\"===e.type||\"volume\"===e.type?(w.valueLabel=h.tickText(t.mockAxis,t.mockAxis.d2l(p.traceCoordinate[3]),\"hover\").text,M.push(\"value: \"+w.valueLabel),p.textLabel&&M.push(p.textLabel),x=M.join(\"<br>\")):x=p.textLabel;var S={x:p.traceCoordinate[0],y:p.traceCoordinate[1],z:p.traceCoordinate[2],data:b._input,fullData:b,curveNumber:b.index,pointNumber:_};f.appendArrayPointValue(S,b,_),e._module.eventData&&(S=b._module.eventData(S,p,b,{},_));var E={points:[S]};t.fullSceneLayout.hovermode&&f.loneHover({trace:b,x:(.5+.5*m[0]/m[3])*a,y:(.5-.5*m[1]/m[3])*o,xLabel:w.xLabel,yLabel:w.yLabel,zLabel:w.zLabel,text:x,name:c.name,color:f.castHoverOption(b,_,\"bgcolor\")||c.color,borderColor:f.castHoverOption(b,_,\"bordercolor\"),fontFamily:f.castHoverOption(b,_,\"font.family\"),fontSize:f.castHoverOption(b,_,\"font.size\"),fontColor:f.castHoverOption(b,_,\"font.color\"),nameLength:f.castHoverOption(b,_,\"namelength\"),textAlign:f.castHoverOption(b,_,\"align\"),hovertemplate:u.castOption(b,_,\"hovertemplate\"),hovertemplateLabels:u.extendFlat({},S,w),eventData:[S]},{container:n,gd:r}),p.buttons&&p.distance<5?r.emit(\"plotly_click\",E):r.emit(\"plotly_hover\",E),s=E}else f.loneUnhover(n),r.emit(\"plotly_unhover\",s);t.drawAnnotations(t)}.bind(null,t),t.traces={},t.make4thDimension(),!0}function b(t,e){var r=document.createElement(\"div\"),n=t.container;this.graphDiv=t.graphDiv;var i=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");i.style.position=\"absolute\",i.style.top=i.style.left=\"0px\",i.style.width=i.style.height=\"100%\",i.style[\"z-index\"]=20,i.style[\"pointer-events\"]=\"none\",r.appendChild(i),this.svgContainer=i,r.id=t.id,r.style.position=\"absolute\",r.style.top=r.style.left=\"0px\",r.style.width=r.style.height=\"100%\",n.appendChild(r),this.fullLayout=e,this.id=t.id||\"scene\",this.fullSceneLayout=e[this.id],this.plotArgs=[[],{},{}],this.axesOptions=v(e,e[this.id]),this.spikeOptions=m(e[this.id]),this.container=r,this.staticMode=!!t.staticPlot,this.pixelRatio=this.pixelRatio||t.plotGlPixelRatio||2,this.dataScale=[1,1,1],this.contourLevels=[[],[],[]],this.convertAnnotations=c.getComponentMethod(\"annotations3d\",\"convert\"),this.drawAnnotations=c.getComponentMethod(\"annotations3d\",\"draw\"),x(this,this.pixelRatio)}var _=b.prototype;_.initializeGLCamera=function(){var t=this.fullSceneLayout.camera,e=\"orthographic\"===t.projection.type;this.camera=a(this.container,{center:[t.center.x,t.center.y,t.center.z],eye:[t.eye.x,t.eye.y,t.eye.z],up:[t.up.x,t.up.y,t.up.z],_ortho:e,zoomMin:.01,zoomMax:100,mode:\"orbit\"})},_.recoverContext=function(){var t=this,e=this.glplot.gl,r=this.glplot.canvas,n=this.glplot.camera,i=this.glplot.pixelRatio;this.glplot.dispose(),requestAnimationFrame(function a(){e.isContextLost()?requestAnimationFrame(a):x(t,n,i,r)?t.plot.apply(t,t.plotArgs):u.error(\"Catastrophic and unrecoverable WebGL error. Context lost.\")})};var w=[\"xaxis\",\"yaxis\",\"zaxis\"];function k(t,e,r){for(var n=t.fullSceneLayout,i=0;i<3;i++){var a=w[i],o=a.charAt(0),s=n[a],l=e[o],c=e[o+\"calendar\"],h=e[\"_\"+o+\"length\"];if(u.isArrayOrTypedArray(l))for(var f,p=0;p<(h||l.length);p++)if(u.isArrayOrTypedArray(l[p]))for(var d=0;d<l[p].length;++d)f=s.d2l(l[p][d],0,c),!isNaN(f)&&isFinite(f)&&(r[0][i]=Math.min(r[0][i],f),r[1][i]=Math.max(r[1][i],f));else f=s.d2l(l[p],0,c),!isNaN(f)&&isFinite(f)&&(r[0][i]=Math.min(r[0][i],f),r[1][i]=Math.max(r[1][i],f));else r[0][i]=Math.min(r[0][i],0),r[1][i]=Math.max(r[1][i],h-1)}}function T(t){return{up:{x:t.up[0],y:t.up[1],z:t.up[2]},center:{x:t.center[0],y:t.center[1],z:t.center[2]},eye:{x:t.eye[0],y:t.eye[1],z:t.eye[2]},projection:{type:!0===t._ortho?\"orthographic\":\"perspective\"}}}_.plot=function(t,e,r){if(this.plotArgs=[t,e,r],!this.glplot.contextLost){var n,i,a,o,s,l,c=e[this.id],u=r[this.id];c.bgcolor?this.glplot.clearColor=p(c.bgcolor):this.glplot.clearColor=[0,0,0,0],this.glplot.snapToData=!0,this.fullLayout=e,this.fullSceneLayout=c,this.glplotLayout=c,this.axesOptions.merge(e,c),this.spikeOptions.merge(c),this.setCamera(c.camera),this.updateFx(c.dragmode,c.hovermode),this.camera.enableWheel=this.graphDiv._context._scrollZoom.gl3d,this.glplot.update({}),this.setConvert(s),t?Array.isArray(t)||(t=[t]):t=[];var h=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&k(this,n,h);!function(t,e){for(var r=t.fullSceneLayout,n=r.annotations||[],i=0;i<3;i++)for(var a=w[i],o=a.charAt(0),s=r[a],l=0;l<n.length;l++){var c=n[l];if(c.visible){var u=s.r2l(c[o]);!isNaN(u)&&isFinite(u)&&(e[0][i]=Math.min(e[0][i],u),e[1][i]=Math.max(e[1][i],u))}}}(this,h);var f=[1,1,1];for(o=0;o<3;++o)h[1][o]===h[0][o]?f[o]=1:f[o]=1/(h[1][o]-h[0][o]);for(this.dataScale=f,this.convertAnnotations(this),a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&((i=this.traces[n.uid])?i.data.type===n.type?i.update(n):(i.dispose(),i=n._module.plot(this,n),this.traces[n.uid]=i):(i=n._module.plot(this,n),this.traces[n.uid]=i),i.name=n.name);var d=Object.keys(this.traces);t:for(a=0;a<d.length;++a){for(o=0;o<t.length;++o)if(t[o].uid===d[a]&&!0===t[o].visible&&0!==t[o]._length)continue t;(i=this.traces[d[a]]).dispose(),delete this.traces[d[a]]}this.glplot.objects.sort(function(t,e){return t._trace.data.index-e._trace.data.index});var g=[[0,0,0],[0,0,0]],v=[],m={};for(a=0;a<3;++a){if((l=(s=c[w[a]]).type)in m?(m[l].acc*=f[a],m[l].count+=1):m[l]={acc:f[a],count:1},s.autorange){g[0][a]=1/0,g[1][a]=-1/0;var y=this.glplot.objects,x=this.fullSceneLayout.annotations||[],b=s._name.charAt(0);for(o=0;o<y.length;o++){var _=y[o],T=_.bounds,A=_._trace.data._pad||0;\"ErrorBars\"===_.constructor.name&&s._lowerLogErrorBound?g[0][a]=Math.min(g[0][a],s._lowerLogErrorBound):g[0][a]=Math.min(g[0][a],T[0][a]/f[a]-A),g[1][a]=Math.max(g[1][a],T[1][a]/f[a]+A)}for(o=0;o<x.length;o++){var M=x[o];if(M.visible){var S=s.r2l(M[b]);g[0][a]=Math.min(g[0][a],S),g[1][a]=Math.max(g[1][a],S)}}if(\"rangemode\"in s&&\"tozero\"===s.rangemode&&(g[0][a]=Math.min(g[0][a],0),g[1][a]=Math.max(g[1][a],0)),g[0][a]>g[1][a])g[0][a]=-1,g[1][a]=1;else{var E=g[1][a]-g[0][a];g[0][a]-=E/32,g[1][a]+=E/32}if(\"reversed\"===s.autorange){var C=g[0][a];g[0][a]=g[1][a],g[1][a]=C}}else{var L=s.range;g[0][a]=s.r2l(L[0]),g[1][a]=s.r2l(L[1])}g[0][a]===g[1][a]&&(g[0][a]-=1,g[1][a]+=1),v[a]=g[1][a]-g[0][a],this.glplot.bounds[0][a]=g[0][a]*f[a],this.glplot.bounds[1][a]=g[1][a]*f[a]}var P=[1,1,1];for(a=0;a<3;++a){var O=m[l=(s=c[w[a]]).type];P[a]=Math.pow(O.acc,1/O.count)/f[a]}var z;if(\"auto\"===c.aspectmode)z=Math.max.apply(null,P)/Math.min.apply(null,P)<=4?P:[1,1,1];else if(\"cube\"===c.aspectmode)z=[1,1,1];else if(\"data\"===c.aspectmode)z=P;else{if(\"manual\"!==c.aspectmode)throw new Error(\"scene.js aspectRatio was not one of the enumerated types\");var I=c.aspectratio;z=[I.x,I.y,I.z]}c.aspectratio.x=u.aspectratio.x=z[0],c.aspectratio.y=u.aspectratio.y=z[1],c.aspectratio.z=u.aspectratio.z=z[2],this.glplot.aspect=z;var D=c.domain||null,R=e._size||null;if(D&&R){var F=this.container.style;F.position=\"absolute\",F.left=R.l+D.x[0]*R.w+\"px\",F.top=R.t+(1-D.y[1])*R.h+\"px\",F.width=R.w*(D.x[1]-D.x[0])+\"px\",F.height=R.h*(D.y[1]-D.y[0])+\"px\"}this.glplot.redraw()}},_.destroy=function(){this.glplot&&(this.camera.mouseListener.enabled=!1,this.container.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=this.glplot.camera=null,this.glplot.dispose(),this.container.parentNode.removeChild(this.container),this.glplot=null)},_.getCamera=function(){return this.glplot.camera.view.recalcMatrix(this.camera.view.lastT()),T(this.glplot.camera)},_.setCamera=function(t){var e;this.glplot.camera.lookAt.apply(this,[[(e=t).eye.x,e.eye.y,e.eye.z],[e.center.x,e.center.y,e.center.z],[e.up.x,e.up.y,e.up.z]]);var r=\"orthographic\"===t.projection.type;if(r!==this.glplot.camera._ortho){this.glplot.redraw();var n=this.glplot.pixelRatio,i=this.glplot.clearColor;this.glplot.gl.clearColor(i[0],i[1],i[2],i[3]),this.glplot.gl.clear(this.glplot.gl.DEPTH_BUFFER_BIT|this.glplot.gl.COLOR_BUFFER_BIT),this.glplot.dispose(),x(this,n),this.glplot.camera._ortho=r}},_.saveCamera=function(t){var e=this.fullLayout,r=this.getCamera(),n=u.nestedProperty(t,this.id+\".camera\"),i=n.get(),a=!1;function o(t,e,r,n){var i=[\"up\",\"center\",\"eye\"],a=[\"x\",\"y\",\"z\"];return e[i[r]]&&t[i[r]][a[n]]===e[i[r]][a[n]]}if(void 0===i)a=!0;else{for(var s=0;s<3;s++)for(var l=0;l<3;l++)if(!o(r,i,s,l)){a=!0;break}(!i.projection||r.projection&&r.projection.type!==i.projection.type)&&(a=!0)}if(a){var h={};h[this.id+\".camera\"]=i,c.call(\"_storeDirectGUIEdit\",t,e._preGUI,h),n.set(r),u.nestedProperty(e,this.id+\".camera\").set(r)}return a},_.updateFx=function(t,e){var r=this.camera;if(r)if(\"orbit\"===t)r.mode=\"orbit\",r.keyBindingMode=\"rotate\";else if(\"turntable\"===t){r.up=[0,0,1],r.mode=\"turntable\",r.keyBindingMode=\"rotate\";var n=this.graphDiv,i=n._fullLayout,a=this.fullSceneLayout.camera,o=a.up.x,s=a.up.y,l=a.up.z;if(l/Math.sqrt(o*o+s*s+l*l)<.999){var h=this.id+\".camera.up\",f={x:0,y:0,z:1},p={};p[h]=f;var d=n.layout;c.call(\"_storeDirectGUIEdit\",d,i._preGUI,p),a.up=f,u.nestedProperty(d,h).set(f)}}else r.keyBindingMode=t;this.fullSceneLayout.hovermode=e},_.toImage=function(t){t||(t=\"png\"),this.staticMode&&this.container.appendChild(n),this.glplot.redraw();var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a);for(var o=0,s=i-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=a[4*(r*o+l)+c];a[4*(r*o+l)+c]=a[4*(r*s+l)+c],a[4*(r*s+l)+c]=u}var h=document.createElement(\"canvas\");h.width=r,h.height=i;var f,p=h.getContext(\"2d\"),d=p.createImageData(r,i);switch(d.data.set(a),p.putImageData(d,0,0),t){case\"jpeg\":f=h.toDataURL(\"image/jpeg\");break;case\"webp\":f=h.toDataURL(\"image/webp\");break;default:f=h.toDataURL(\"image/png\")}return this.staticMode&&this.container.removeChild(n),f},_.setConvert=function(){for(var t=0;t<3;t++){var e=this.fullSceneLayout[w[t]];h.setConvert(e,this.fullLayout),e.setScale=u.noop}},_.make4thDimension=function(){var t=this.graphDiv._fullLayout;this.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},h.setConvert(this.mockAxis,t)},e.exports=b},{\"../../components/fx\":632,\"../../lib\":719,\"../../lib/show_no_webgl_msg\":740,\"../../lib/str2rgbarray\":742,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./layout/convert\":811,\"./layout/spikes\":814,\"./layout/tick_marks\":815,\"./project\":816,\"gl-plot3d\":290,\"has-passive-events\":411,\"webgl-context\":556}],818:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){n=n||t.length;for(var i=new Array(n),a=0;a<n;a++)i[a]=[t[a],e[a],r[a]];return i}},{}],819:[function(t,e,r){\"use strict\";var n=t(\"./font_attributes\"),i=t(\"./animation_attributes\"),a=t(\"../components/color/attributes\"),o=t(\"./pad_attributes\"),s=t(\"../lib/extend\").extendFlat,l=n({editType:\"calc\"});l.family.dflt='\"Open Sans\", verdana, arial, sans-serif',l.size.dflt=12,l.color.dflt=a.defaultLine,e.exports={font:l,title:{text:{valType:\"string\",editType:\"layoutstyle\"},font:n({editType:\"layoutstyle\"}),xref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},yref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},x:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"layoutstyle\"},y:{valType:\"number\",min:0,max:1,dflt:\"auto\",editType:\"layoutstyle\"},xanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"left\",\"center\",\"right\"],editType:\"layoutstyle\"},yanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],editType:\"layoutstyle\"},pad:s(o({editType:\"layoutstyle\"}),{}),editType:\"layoutstyle\"},autosize:{valType:\"boolean\",dflt:!1,editType:\"none\"},width:{valType:\"number\",min:10,dflt:700,editType:\"plot\"},height:{valType:\"number\",min:10,dflt:450,editType:\"plot\"},margin:{l:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},r:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},t:{valType:\"number\",min:0,dflt:100,editType:\"plot\"},b:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},pad:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},autoexpand:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},paper_bgcolor:{valType:\"color\",dflt:a.background,editType:\"plot\"},plot_bgcolor:{valType:\"color\",dflt:a.background,editType:\"layoutstyle\"},separators:{valType:\"string\",editType:\"plot\"},hidesources:{valType:\"boolean\",dflt:!1,editType:\"plot\"},showlegend:{valType:\"boolean\",editType:\"legend\"},colorway:{valType:\"colorlist\",dflt:a.defaults,editType:\"calc\"},datarevision:{valType:\"any\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editrevision:{valType:\"any\",editType:\"none\"},selectionrevision:{valType:\"any\",editType:\"none\"},template:{valType:\"any\",editType:\"calc\"},modebar:{orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\",editType:\"modebar\"},bgcolor:{valType:\"color\",editType:\"modebar\"},color:{valType:\"color\",editType:\"modebar\"},activecolor:{valType:\"color\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"modebar\"},meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},transition:s({},i.transition,{editType:\"none\"}),_deprecated:{title:{valType:\"string\",editType:\"layoutstyle\"},titlefont:n({editType:\"layoutstyle\"})}}},{\"../components/color/attributes\":592,\"../lib/extend\":710,\"./animation_attributes\":762,\"./font_attributes\":793,\"./pad_attributes\":827}],820:[function(t,e,r){\"use strict\";var n={\"open-street-map\":{id:\"osm\",version:8,sources:{\"plotly-osm-tiles\":{type:\"raster\",attribution:'<a href=\"http://www.openstreetmap.org/about/\" target=\"_blank\">\\xa9 OpenStreetMap</a>',tiles:[\"https://a.tile.openstreetmap.org/{z}/{x}/{y}.png\",\"https://b.tile.openstreetmap.org/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-osm-tiles\",type:\"raster\",source:\"plotly-osm-tiles\",minzoom:0,maxzoom:22}]},\"white-bg\":{id:\"white-bg\",version:8,sources:{},layers:[{id:\"white-bg\",type:\"background\",paint:{\"background-color\":\"#FFFFFF\"},minzoom:0,maxzoom:22}]},\"carto-positron\":{id:\"carto-positron\",version:8,sources:{\"plotly-carto-positron\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/light_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-positron\",type:\"raster\",source:\"plotly-carto-positron\",minzoom:0,maxzoom:22}]},\"carto-darkmatter\":{id:\"carto-darkmatter\",version:8,sources:{\"plotly-carto-darkmatter\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/dark_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-darkmatter\",type:\"raster\",source:\"plotly-carto-darkmatter\",minzoom:0,maxzoom:22}]},\"stamen-terrain\":{id:\"stamen-terrain\",version:8,sources:{\"plotly-stamen-terrain\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/terrain/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-terrain\",type:\"raster\",source:\"plotly-stamen-terrain\",minzoom:0,maxzoom:22}]},\"stamen-toner\":{id:\"stamen-toner\",version:8,sources:{\"plotly-stamen-toner\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/toner/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-toner\",type:\"raster\",source:\"plotly-stamen-toner\",minzoom:0,maxzoom:22}]},\"stamen-watercolor\":{id:\"stamen-watercolor\",version:8,sources:{\"plotly-stamen-watercolor\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://creativecommons.org/licenses/by-sa/3.0\">CC BY SA</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/watercolor/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-watercolor\",type:\"raster\",source:\"plotly-stamen-watercolor\",minzoom:0,maxzoom:22}]}},i=Object.keys(n);e.exports={requiredVersion:\"1.1.1\",styleUrlPrefix:\"mapbox://styles/mapbox/\",styleUrlSuffix:\"v9\",styleValuesMapbox:[\"basic\",\"streets\",\"outdoors\",\"light\",\"dark\",\"satellite\",\"satellite-streets\"],styleValueDflt:\"basic\",stylesNonMapbox:n,styleValuesNonMapbox:i,traceLayerPrefix:\"plotly-trace-layer-\",layoutLayerPrefix:\"plotly-layout-layer-\",wrongVersionErrorMsg:[\"Your custom plotly.js bundle is not using the correct mapbox-gl version\",\"Please install mapbox-gl@1.1.1.\"].join(\"\\n\"),noAccessTokenErrorMsg:[\"Missing Mapbox access token.\",\"Mapbox trace type require a Mapbox access token to be registered.\",\"For example:\",\"  Plotly.plot(gd, data, layout, { mapboxAccessToken: 'my-access-token' });\",\"More info here: https://www.mapbox.com/help/define-access-token/\"].join(\"\\n\"),missingStyleErrorMsg:[\"No valid mapbox style found, please set `mapbox.style` to one of:\",i.join(\", \"),\"or register a Mapbox access token to use a Mapbox-served style.\"].join(\"\\n\"),multipleTokensErrorMsg:[\"Set multiple mapbox access token across different mapbox subplot,\",\"using first token found as mapbox-gl does not allow multipleaccess tokens on the same page.\"].join(\"\\n\"),mapOnErrorMsg:\"Mapbox error.\",mapboxLogo:{path0:\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\",path1:\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\",path2:\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\",polygon:\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34\"},styleRules:{map:\"overflow:hidden;position:relative;\",\"missing-css\":\"display:none;\",canary:\"background-color:salmon;\",\"ctrl-bottom-left\":\"position: absolute; pointer-events: none; z-index: 2; bottom: 0; left: 0;\",\"ctrl-bottom-right\":\"position: absolute; pointer-events: none; z-index: 2; right: 0; bottom: 0;\",ctrl:\"clear: both; pointer-events: auto; transform: translate(0, 0);\",\"ctrl-attrib.mapboxgl-compact .mapboxgl-ctrl-attrib-inner\":\"display: none;\",\"ctrl-attrib.mapboxgl-compact:hover .mapboxgl-ctrl-attrib-inner\":\"display: block; margin-top:2px\",\"ctrl-attrib.mapboxgl-compact:hover\":\"padding: 2px 24px 2px 4px; visibility: visible; margin-top: 6px;\",\"ctrl-attrib.mapboxgl-compact::after\":'content: \"\"; cursor: pointer; position: absolute; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3Csvg viewBox=\"0 0 20 20\" xmlns=\"http://www.w3.org/2000/svg\"%3E %3Cpath fill=\"%23333333\" fill-rule=\"evenodd\" d=\"M4,10a6,6 0 1,0 12,0a6,6 0 1,0 -12,0 M9,7a1,1 0 1,0 2,0a1,1 0 1,0 -2,0 M9,10a1,1 0 1,1 2,0l0,3a1,1 0 1,1 -2,0\"/%3E %3C/svg%3E\\'); background-color: rgba(255, 255, 255, 0.5); width: 24px; height: 24px; box-sizing: border-box; border-radius: 12px;',\"ctrl-attrib.mapboxgl-compact\":\"min-height: 20px; padding: 0; margin: 10px; position: relative; background-color: #fff; border-radius: 3px 12px 12px 3px;\",\"ctrl-bottom-right > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; right: 0\",\"ctrl-bottom-left > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; left: 0\",\"ctrl-bottom-left .mapboxgl-ctrl\":\"margin: 0 0 10px 10px; float: left;\",\"ctrl-bottom-right .mapboxgl-ctrl\":\"margin: 0 10px 10px 0; float: right;\",\"ctrl-attrib\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a:hover\":\"color: inherit; text-decoration: underline;\",\"ctrl-attrib .mapbox-improve-map\":\"font-weight: bold; margin-left: 2px;\",\"attrib-empty\":\"display: none;\",\"ctrl-logo\":'display:block; width: 21px; height: 21px; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3C?xml version=\"1.0\" encoding=\"utf-8\"?%3E %3Csvg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\" viewBox=\"0 0 21 21\" style=\"enable-background:new 0 0 21 21;\" xml:space=\"preserve\"%3E%3Cg transform=\"translate(0,0.01)\"%3E%3Cpath d=\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3Cpath d=\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpath d=\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpolygon points=\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34 \" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3C/g%3E%3C/svg%3E\\')'}}},{}],821:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t.split(\" \"),i=r[0],a=r[1],o=n.isArrayOrTypedArray(e)?n.mean(e):e,s=.5+o/100,l=1.5+o/100,c=[\"\",\"\"],u=[0,0];switch(i){case\"top\":c[0]=\"top\",u[1]=-l;break;case\"bottom\":c[0]=\"bottom\",u[1]=l}switch(a){case\"left\":c[1]=\"right\",u[0]=-s;break;case\"right\":c[1]=\"left\",u[0]=s}return{anchor:c[0]&&c[1]?c.join(\"-\"):c[0]?c[0]:c[1]?c[1]:\"center\",offset:u}}},{\"../../lib\":719}],822:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"../../lib\"),a=t(\"../../plots/get_data\").getSubplotCalcData,o=t(\"../../constants/xmlns_namespaces\"),s=t(\"d3\"),l=t(\"../../components/drawing\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"./mapbox\"),h=r.constants=t(\"./constants\");function f(t){return\"string\"==typeof t&&-1!==h.styleValuesMapbox.indexOf(t)}r.name=\"mapbox\",r.attr=\"subplot\",r.idRoot=\"mapbox\",r.idRegex=r.attrRegex=i.counterRegex(\"mapbox\"),r.attributes={subplot:{valType:\"subplotid\",dflt:\"mapbox\",editType:\"calc\"}},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){var e=t._fullLayout,r=t.calcdata,o=e._subplots.mapbox;if(n.version!==h.requiredVersion)throw new Error(h.wrongVersionErrorMsg);var s=function(t,e){var r=t._fullLayout;if(\"\"===t._context.mapboxAccessToken)return\"\";for(var n=[],a=[],o=!1,s=!1,l=0;l<e.length;l++){var c=r[e[l]],u=c.accesstoken;f(c.style)&&(u?i.pushUnique(n,u):(f(c._input.style)&&(i.error(\"Uses Mapbox map style, but did not set an access token.\"),o=!0),s=!0)),u&&i.pushUnique(a,u)}if(s){var p=o?h.noAccessTokenErrorMsg:h.missingStyleErrorMsg;throw new Error(p)}return n.length?(n.length>1&&i.warn(h.multipleTokensErrorMsg),n[0]):(a.length&&i.log([\"Listed mapbox access token(s)\",a.join(\",\"),\"but did not use a Mapbox map style, ignoring token(s).\"].join(\" \")),\"\")}(t,o);n.accessToken=s;for(var l=0;l<o.length;l++){var c=o[l],p=a(r,\"mapbox\",c),d=e[c],g=d._subplot;g||(g=new u(t,c),e[c]._subplot=g),g.viewInitial||(g.viewInitial={center:i.extendFlat({},d.center),zoom:d.zoom,bearing:d.bearing,pitch:d.pitch}),g.plot(p,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.mapbox||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._subplot&&n[o]._subplot.destroy()}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=e._size,i=0;i<r.length;i++){var a=e[r[i]],u=a.domain,f=a._subplot.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":f,x:n.l+n.w*u.x[0],y:n.t+n.h*(1-u.y[1]),width:n.w*(u.x[1]-u.x[0]),height:n.h*(u.y[1]-u.y[0]),preserveAspectRatio:\"none\"});var p=s.select(a._subplot.div);if(!(null===p.select(\".mapboxgl-ctrl-logo\").node().offsetParent)){var d=e._glimages.append(\"g\");d.attr(\"transform\",\"translate(\"+(n.l+n.w*u.x[0]+10)+\", \"+(n.t+n.h*(1-u.y[0])-31)+\")\"),d.append(\"path\").attr(\"d\",h.mapboxLogo.path0).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"}),d.append(\"path\").attr(\"d\",h.mapboxLogo.path1).style(\"opacity\",.35).style(\"enable-background\",\"new\"),d.append(\"path\").attr(\"d\",h.mapboxLogo.path2).style(\"opacity\",.35).style(\"enable-background\",\"new\"),d.append(\"polygon\").attr(\"points\",h.mapboxLogo.polygon).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"})}var g=p.select(\".mapboxgl-ctrl-attrib\").text().replace(\"Improve this map\",\"\"),v=e._glimages.append(\"g\"),m=v.append(\"text\");m.text(g).classed(\"static-attribution\",!0).attr({\"font-size\":12,\"font-family\":\"Arial\",color:\"rgba(0, 0, 0, 0.75)\",\"text-anchor\":\"end\",\"data-unformatted\":g});var y=l.bBox(m.node()),x=n.w*(u.x[1]-u.x[0]);if(y.width>x/2){var b=g.split(\"|\").join(\"<br>\");m.text(b).attr(\"data-unformatted\",b).call(c.convertToTspans,t),y=l.bBox(m.node())}m.attr(\"transform\",\"translate(-3, \"+(8-y.height)+\")\"),v.insert(\"rect\",\".static-attribution\").attr({x:-y.width-6,y:-y.height-3,width:y.width+6,height:y.height+3,fill:\"rgba(255, 255, 255, 0.75)\"});var _=1;y.width+6>x&&(_=x/(y.width+6));var w=[n.l+n.w*u.x[1],n.t+n.h*(1-u.y[0])];v.attr(\"transform\",\"translate(\"+w[0]+\",\"+w[1]+\") scale(\"+_+\")\")}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=0;n<r.length;n++){e[r[n]]._subplot.updateFx(e)}}},{\"../../components/drawing\":614,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/get_data\":802,\"./constants\":820,\"./layout_attributes\":824,\"./layout_defaults\":825,\"./mapbox\":826,d3:163,\"mapbox-gl\":426}],823:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./convert_text_opts\"),a=t(\"./constants\");function o(t,e){this.subplot=t,this.uid=t.uid+\"-\"+e,this.index=e,this.idSource=\"source-\"+this.uid,this.idLayer=a.layoutLayerPrefix+this.uid,this.sourceType=null,this.source=null,this.layerType=null,this.below=null,this.visible=!1}var s=o.prototype;function l(t){var e=t.source;return t.visible&&(n.isPlainObject(e)||(\"string\"==typeof e||Array.isArray(e))&&e.length>0)}function c(t){var e={},r={};switch(t.type){case\"circle\":n.extendFlat(r,{\"circle-radius\":t.circle.radius,\"circle-color\":t.color,\"circle-opacity\":t.opacity});break;case\"line\":n.extendFlat(r,{\"line-width\":t.line.width,\"line-color\":t.color,\"line-opacity\":t.opacity,\"line-dasharray\":t.line.dash});break;case\"fill\":n.extendFlat(r,{\"fill-color\":t.color,\"fill-outline-color\":t.fill.outlinecolor,\"fill-opacity\":t.opacity});break;case\"symbol\":var a=t.symbol,o=i(a.textposition,a.iconsize);n.extendFlat(e,{\"icon-image\":a.icon+\"-15\",\"icon-size\":a.iconsize/10,\"text-field\":a.text,\"text-size\":a.textfont.size,\"text-anchor\":o.anchor,\"text-offset\":o.offset,\"symbol-placement\":a.placement}),n.extendFlat(r,{\"icon-color\":t.color,\"text-color\":a.textfont.color,\"text-opacity\":t.opacity})}return{layout:e,paint:r}}s.update=function(t){this.visible?this.needsNewSource(t)?(this.removeLayer(),this.updateSource(t),this.updateLayer(t)):this.needsNewLayer(t)?this.updateLayer(t):this.updateStyle(t):(this.updateSource(t),this.updateLayer(t)),this.visible=l(t)},s.needsNewSource=function(t){return this.sourceType!==t.sourcetype||this.source!==t.source||this.layerType!==t.type},s.needsNewLayer=function(t){return this.layerType!==t.type||this.below!==this.subplot.belowLookup[\"layout-\"+this.index]},s.updateSource=function(t){var e=this.subplot.map;if(e.getSource(this.idSource)&&e.removeSource(this.idSource),this.sourceType=t.sourcetype,this.source=t.source,l(t)){var r=function(t){var e,r=t.sourcetype,n=t.source,i={type:r};\"geojson\"===r?e=\"data\":\"vector\"===r?e=\"string\"==typeof n?\"url\":\"tiles\":\"raster\"===r?(e=\"tiles\",i.tileSize=256):\"image\"===r&&(e=\"url\",i.coordinates=t.coordinates);i[e]=n,t.sourceattribution&&(i.attribution=t.sourceattribution);return i}(t);e.addSource(this.idSource,r)}},s.updateLayer=function(t){var e,r=this.subplot,n=c(t),i=this.subplot.belowLookup[\"layout-\"+this.index];if(\"traces\"===i)for(var o=r.getMapLayers(),s=0;s<o.length;s++){var u=o[s].id;if(\"string\"==typeof u&&0===u.indexOf(a.traceLayerPrefix)){e=u;break}}else e=i;this.removeLayer(),l(t)&&r.addLayer({id:this.idLayer,source:this.idSource,\"source-layer\":t.sourcelayer||\"\",type:t.type,minzoom:t.minzoom,maxzoom:t.maxzoom,layout:n.layout,paint:n.paint},e),this.layerType=t.type,this.below=i},s.updateStyle=function(t){if(l(t)){var e=c(t);this.subplot.setOptions(this.idLayer,\"setLayoutProperty\",e.layout),this.subplot.setOptions(this.idLayer,\"setPaintProperty\",e.paint)}},s.removeLayer=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer)},s.dispose=function(){var t=this.subplot.map;t.removeLayer(this.idLayer),t.removeSource(this.idSource)},e.exports=function(t,e,r){var n=new o(t,e);return n.update(r),n}},{\"../../lib\":719,\"./constants\":820,\"./convert_text_opts\":821}],824:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\").defaultLine,a=t(\"../domain\").attributes,o=t(\"../font_attributes\"),s=t(\"../../traces/scatter/attributes\").textposition,l=t(\"../../plot_api/edit_types\").overrideAll,c=t(\"../../plot_api/plot_template\").templatedArray,u=t(\"./constants\"),h=o({});h.family.dflt=\"Open Sans Regular, Arial Unicode MS Regular\",(e.exports=l({_arrayAttrRegexps:[n.counterRegex(\"mapbox\",\".layers\",!0)],domain:a({name:\"mapbox\"}),accesstoken:{valType:\"string\",noBlank:!0,strict:!0},style:{valType:\"any\",values:u.styleValuesMapbox.concat(u.styleValuesNonMapbox),dflt:u.styleValueDflt},center:{lon:{valType:\"number\",dflt:0},lat:{valType:\"number\",dflt:0}},zoom:{valType:\"number\",dflt:1},bearing:{valType:\"number\",dflt:0},pitch:{valType:\"number\",dflt:0},layers:c(\"layer\",{visible:{valType:\"boolean\",dflt:!0},sourcetype:{valType:\"enumerated\",values:[\"geojson\",\"vector\",\"raster\",\"image\"],dflt:\"geojson\"},source:{valType:\"any\"},sourcelayer:{valType:\"string\",dflt:\"\"},sourceattribution:{valType:\"string\"},type:{valType:\"enumerated\",values:[\"circle\",\"line\",\"fill\",\"symbol\",\"raster\"],dflt:\"circle\"},coordinates:{valType:\"any\"},below:{valType:\"string\"},color:{valType:\"color\",dflt:i},opacity:{valType:\"number\",min:0,max:1,dflt:1},minzoom:{valType:\"number\",min:0,max:24,dflt:0},maxzoom:{valType:\"number\",min:0,max:24,dflt:24},circle:{radius:{valType:\"number\",dflt:15}},line:{width:{valType:\"number\",dflt:2},dash:{valType:\"data_array\"}},fill:{outlinecolor:{valType:\"color\",dflt:i}},symbol:{icon:{valType:\"string\",dflt:\"marker\"},iconsize:{valType:\"number\",dflt:10},text:{valType:\"string\",dflt:\"\"},placement:{valType:\"enumerated\",values:[\"point\",\"line\",\"line-center\"],dflt:\"point\"},textfont:h,textposition:n.extendFlat({},s,{arrayOk:!1})}})},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../traces/scatter/attributes\":1112,\"../domain\":792,\"../font_attributes\":793,\"./constants\":820}],825:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../subplot_defaults\"),a=t(\"../array_container_defaults\"),o=t(\"./layout_attributes\");function s(t,e,r,n){r(\"accesstoken\",n.accessToken),r(\"style\"),r(\"center.lon\"),r(\"center.lat\"),r(\"zoom\"),r(\"bearing\"),r(\"pitch\"),a(t,e,{name:\"layers\",handleItemDefaults:l}),e._input=t}function l(t,e){function r(r,i){return n.coerce(t,e,o.layers,r,i)}if(r(\"visible\")){var i,a=r(\"sourcetype\"),s=\"raster\"===a||\"image\"===a;r(\"source\"),r(\"sourceattribution\"),\"vector\"===a&&r(\"sourcelayer\"),\"image\"===a&&r(\"coordinates\"),s&&(i=\"raster\");var l=r(\"type\",i);s&&\"raster\"!==l&&(l=e.type=\"raster\",n.log(\"Source types *raster* and *image* must drawn *raster* layer type.\")),r(\"below\"),r(\"color\"),r(\"opacity\"),r(\"minzoom\"),r(\"maxzoom\"),\"circle\"===l&&r(\"circle.radius\"),\"line\"===l&&(r(\"line.width\"),r(\"line.dash\")),\"fill\"===l&&r(\"fill.outlinecolor\"),\"symbol\"===l&&(r(\"symbol.icon\"),r(\"symbol.iconsize\"),r(\"symbol.text\"),n.coerceFont(r,\"symbol.textfont\"),r(\"symbol.textposition\"),r(\"symbol.placement\"))}}e.exports=function(t,e,r){i(t,e,r,{type:\"mapbox\",attributes:o,handleDefaults:s,partition:\"y\",accessToken:e._mapboxAccessToken})}},{\"../../lib\":719,\"../array_container_defaults\":763,\"../subplot_defaults\":842,\"./layout_attributes\":824}],826:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"d3\"),a=t(\"../../components/fx\"),o=t(\"../../lib\"),s=t(\"../../registry\"),l=t(\"../cartesian/axes\"),c=t(\"../../components/dragelement\"),u=t(\"../cartesian/select\").prepSelect,h=t(\"../cartesian/select\").selectOnClick,f=t(\"./constants\"),p=t(\"./layers\");function d(t,e){this.id=e,this.gd=t;var r=t._fullLayout,n=t._context;this.container=r._glcontainer.node(),this.isStatic=n.staticPlot,this.uid=r._uid+\"-\"+this.id,this.div=null,this.xaxis=null,this.yaxis=null,this.createFramework(r),this.map=null,this.accessToken=null,this.styleObj=null,this.traceHash={},this.layerList=[],this.belowLookup={}}var g=d.prototype;g.plot=function(t,e,r){var n,i=this,a=e[i.id];i.map&&a.accesstoken!==i.accessToken&&(i.map.remove(),i.map=null,i.styleObj=null,i.traceHash=[],i.layerList={}),n=i.map?new Promise(function(r,n){i.updateMap(t,e,r,n)}):new Promise(function(r,n){i.createMap(t,e,r,n)}),r.push(n)},g.createMap=function(t,e,r,i){var a=this,o=e[a.id],s=a.styleObj=m(o.style);a.accessToken=o.accesstoken;var l=a.map=new n.Map({container:a.div,style:s.style,center:x(o.center),zoom:o.zoom,bearing:o.bearing,pitch:o.pitch,interactive:!a.isStatic,preserveDrawingBuffer:a.isStatic,doubleClickZoom:!1,boxZoom:!1,attributionControl:!1}).addControl(new n.AttributionControl({compact:!0}));l._canvas.style.left=\"0px\",l._canvas.style.top=\"0px\",a.rejectOnError(i),a.isStatic||a.initFx(t,e);var c=[];c.push(new Promise(function(t){l.once(\"load\",t)})),c=c.concat(a.fetchMapData(t,e)),Promise.all(c).then(function(){a.fillBelowLookup(t,e),a.updateData(t),a.updateLayout(e),a.resolveOnRender(r)}).catch(i)},g.fetchMapData=function(t){var e=[];function r(t){return new Promise(function(e,r){i.json(t,function(n,i){if(n){delete PlotlyGeoAssets[t];var a=404===n.status?'GeoJSON at URL \"'+t+'\" does not exist.':\"Unexpected error while fetching from \"+t;return r(new Error(a))}PlotlyGeoAssets[t]=i,e(i)})})}for(var n=0;n<t.length;n++){var a=t[n][0].trace.geojson;\"string\"!=typeof a||PlotlyGeoAssets[a]||(PlotlyGeoAssets[a]=\"pending\",e.push(r(a)))}return e},g.updateMap=function(t,e,r,n){var i=this,a=i.map,o=e[this.id];i.rejectOnError(n);var s=[],l=m(o.style);i.styleObj.id!==l.id&&(i.styleObj=l,a.setStyle(l.style),i.traceHash={},s.push(new Promise(function(t){a.once(\"styledata\",t)}))),s=s.concat(i.fetchMapData(t,e)),Promise.all(s).then(function(){i.fillBelowLookup(t,e),i.updateData(t),i.updateLayout(e),i.resolveOnRender(r)}).catch(n)},g.fillBelowLookup=function(t,e){var r,n,i=e[this.id].layers,a=this.belowLookup={},o=!1;for(r=0;r<t.length;r++){var s=t[r][0].trace,l=s._module;\"string\"==typeof s.below?n=s.below:l.getBelow&&(n=l.getBelow(s,this)),\"\"===n&&(o=!0),a[\"trace-\"+s.uid]=n||\"\"}for(r=0;r<i.length;r++){var c=i[r];n=\"string\"==typeof c.below?c.below:o?\"traces\":\"\",a[\"layout-\"+r]=n}var u,h,f={};for(u in a)f[n=a[u]]?f[n].push(u):f[n]=[u];for(n in f){var p=f[n];if(p.length>1)for(r=0;r<p.length;r++)0===(u=p[r]).indexOf(\"trace-\")?(h=u.split(\"trace-\")[1],this.traceHash[h]&&(this.traceHash[h].below=null)):0===u.indexOf(\"layout-\")&&(h=u.split(\"layout-\")[1],this.layerList[h]&&(this.layerList[h].below=null))}};var v={choroplethmapbox:0,densitymapbox:1,scattermapbox:2};function m(t){var e={};return o.isPlainObject(t)?(e.id=t.id,e.style=t):\"string\"==typeof t?(e.id=t,-1!==f.styleValuesMapbox.indexOf(t)?e.style=y(t):f.stylesNonMapbox[t]?e.style=f.stylesNonMapbox[t]:e.style=t):(e.id=f.styleValueDflt,e.style=y(f.styleValueDflt)),e.transition={duration:0,delay:0},e}function y(t){return f.styleUrlPrefix+t+\"-\"+f.styleUrlSuffix}function x(t){return[t.lon,t.lat]}g.updateData=function(t){var e,r,n,i,a=this.traceHash,o=t.slice().sort(function(t,e){return v[t[0].trace.type]-v[e[0].trace.type]});for(n=0;n<o.length;n++){var s=o[n];(e=a[(r=s[0].trace).uid])?e.update(s):r._module&&(a[r.uid]=r._module.plot(this,s))}var l=Object.keys(a);t:for(n=0;n<l.length;n++){var c=l[n];for(i=0;i<t.length;i++)if(c===(r=t[i][0].trace).uid)continue t;(e=a[c]).dispose(),delete a[c]}},g.updateLayout=function(t){var e=this.map,r=t[this.id];e.setCenter(x(r.center)),e.setZoom(r.zoom),e.setBearing(r.bearing),e.setPitch(r.pitch),this.updateLayers(t),this.updateFramework(t),this.updateFx(t),this.map.resize(),this.gd._context._scrollZoom.mapbox?e.scrollZoom.enable():e.scrollZoom.disable()},g.resolveOnRender=function(t){var e=this.map;e.on(\"render\",function r(){e.loaded()&&(e.off(\"render\",r),setTimeout(t,0))})},g.rejectOnError=function(t){var e=this.map;function r(){t(new Error(f.mapOnErrorMsg))}e.once(\"error\",r),e.once(\"style.error\",r),e.once(\"source.error\",r),e.once(\"tile.error\",r),e.once(\"layer.error\",r)},g.createFramework=function(t){var e=this,r=e.div=document.createElement(\"div\");r.id=e.uid,r.style.position=\"absolute\",e.container.appendChild(r),e.xaxis={_id:\"x\",c2p:function(t){return e.project(t).x}},e.yaxis={_id:\"y\",c2p:function(t){return e.project(t).y}},e.updateFramework(t),e.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},l.setConvert(e.mockAxis,t)},g.initFx=function(t,e){var r=this,n=r.gd,i=r.map,o=!1;function l(){a.loneUnhover(e._hoverlayer)}function c(){var t=r.getView();n.emit(\"plotly_relayouting\",r.getViewEdits(t))}i.on(\"moveend\",function(t){if(r.map){var e=n._fullLayout;if(t.originalEvent||o){var i=e[r.id];s.call(\"_storeDirectGUIEdit\",n.layout,e._preGUI,r.getViewEdits(i));var a=r.getView();i._input.center=i.center=a.center,i._input.zoom=i.zoom=a.zoom,i._input.bearing=i.bearing=a.bearing,i._input.pitch=i.pitch=a.pitch,n.emit(\"plotly_relayout\",r.getViewEdits(a))}o=!1,e._rehover&&e._rehover()}}),i.on(\"wheel\",function(){o=!0}),i.on(\"mousemove\",function(t){var e=r.div.getBoundingClientRect();t.clientX=t.point.x+e.left,t.clientY=t.point.y+e.top,t.target.getBoundingClientRect=function(){return e},r.xaxis.p2c=function(){return t.lngLat.lng},r.yaxis.p2c=function(){return t.lngLat.lat},n._fullLayout._rehover=function(){n._fullLayout._hoversubplot===r.id&&a.hover(n,t,r.id)},a.hover(n,t,r.id),n._fullLayout._hoversubplot=r.id}),i.on(\"dragstart\",l),i.on(\"zoomstart\",l),i.on(\"mouseout\",function(){n._fullLayout._hoversubplot=null}),i.on(\"drag\",c),i.on(\"zoom\",c),i.on(\"dblclick\",function(){var t=n._fullLayout[r.id];s.call(\"_storeDirectGUIEdit\",n.layout,n._fullLayout._preGUI,r.getViewEdits(t));var e=r.viewInitial;i.setCenter(x(e.center)),i.setZoom(e.zoom),i.setBearing(e.bearing),i.setPitch(e.pitch);var a=r.getView();t._input.center=t.center=a.center,t._input.zoom=t.zoom=a.zoom,t._input.bearing=t.bearing=a.bearing,t._input.pitch=t.pitch=a.pitch,n.emit(\"plotly_doubleclick\",null),n.emit(\"plotly_relayout\",r.getViewEdits(a))}),r.clearSelect=function(){n._fullLayout._zoomlayer.selectAll(\".select-outline\").remove()},r.onClickInPanFn=function(t){return function(e){var i=n._fullLayout.clickmode;i.indexOf(\"select\")>-1&&h(e.originalEvent,n,[r.xaxis],[r.yaxis],r.id,t),i.indexOf(\"event\")>-1&&a.click(n,e.originalEvent)}}},g.updateFx=function(t){var e=this,r=e.map,n=e.gd;if(!e.isStatic){var i,a=t.dragmode;i=\"select\"===a?function(t,r){(t.range={})[e.id]=[l([r.xmin,r.ymin]),l([r.xmax,r.ymax])]}:function(t,r,n){(t.lassoPoints={})[e.id]=n.filtered.map(l)};var s=e.dragOptions;e.dragOptions=o.extendDeep(s||{},{element:e.div,gd:n,plotinfo:{id:e.id,xaxis:e.xaxis,yaxis:e.yaxis,fillRangeItems:i},xaxes:[e.xaxis],yaxes:[e.yaxis],subplot:e.id}),r.off(\"click\",e.onClickInPanHandler),\"select\"===a||\"lasso\"===a?(r.dragPan.disable(),r.on(\"zoomstart\",e.clearSelect),e.dragOptions.prepFn=function(t,r,n){u(t,r,n,e.dragOptions,a)},c.init(e.dragOptions)):(r.dragPan.enable(),r.off(\"zoomstart\",e.clearSelect),e.div.onmousedown=null,e.onClickInPanHandler=e.onClickInPanFn(e.dragOptions),r.on(\"click\",e.onClickInPanHandler))}function l(t){var r=e.map.unproject(t);return[r.lng,r.lat]}},g.updateFramework=function(t){var e=t[this.id].domain,r=t._size,n=this.div.style;n.width=r.w*(e.x[1]-e.x[0])+\"px\",n.height=r.h*(e.y[1]-e.y[0])+\"px\",n.left=r.l+e.x[0]*r.w+\"px\",n.top=r.t+(1-e.y[1])*r.h+\"px\",this.xaxis._offset=r.l+e.x[0]*r.w,this.xaxis._length=r.w*(e.x[1]-e.x[0]),this.yaxis._offset=r.t+(1-e.y[1])*r.h,this.yaxis._length=r.h*(e.y[1]-e.y[0])},g.updateLayers=function(t){var e,r=t[this.id].layers,n=this.layerList;if(r.length!==n.length){for(e=0;e<n.length;e++)n[e].dispose();for(n=this.layerList=[],e=0;e<r.length;e++)n.push(p(this,e,r[e]))}else for(e=0;e<r.length;e++)n[e].update(r[e])},g.destroy=function(){this.map&&(this.map.remove(),this.map=null,this.container.removeChild(this.div))},g.toImage=function(){return this.map.stop(),this.map.getCanvas().toDataURL()},g.setOptions=function(t,e,r){for(var n in r)this.map[e](t,n,r[n])},g.getMapLayers=function(){return this.map.getStyle().layers},g.addLayer=function(t,e){var r=this.map;if(\"string\"==typeof e){if(\"\"===e)return void r.addLayer(t,e);for(var n=this.getMapLayers(),i=0;i<n.length;i++)if(e===n[i].id)return void r.addLayer(t,e);o.warn([\"Trying to add layer with *below* value\",e,\"referencing a layer that does not exist\",\"or that does not yet exist.\"].join(\" \"))}r.addLayer(t)},g.project=function(t){return this.map.project(new n.LngLat(t[0],t[1]))},g.getView=function(){var t=this.map,e=t.getCenter();return{center:{lon:e.lng,lat:e.lat},zoom:t.getZoom(),bearing:t.getBearing(),pitch:t.getPitch()}},g.getViewEdits=function(t){for(var e=this.id,r=[\"center\",\"zoom\",\"bearing\",\"pitch\"],n={},i=0;i<r.length;i++){var a=r[i];n[e+\".\"+a]=t[a]}return n},e.exports=d},{\"../../components/dragelement\":611,\"../../components/fx\":632,\"../../lib\":719,\"../../registry\":847,\"../cartesian/axes\":767,\"../cartesian/select\":784,\"./constants\":820,\"./layers\":823,d3:163,\"mapbox-gl\":426}],827:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType;return{t:{valType:\"number\",dflt:0,editType:e},r:{valType:\"number\",dflt:0,editType:e},b:{valType:\"number\",dflt:0,editType:e},l:{valType:\"number\",dflt:0,editType:e},editType:e}}},{}],828:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../registry\"),o=t(\"../plot_api/plot_schema\"),s=t(\"../plot_api/plot_template\"),l=t(\"../lib\"),c=t(\"../components/color\"),u=t(\"../constants/numerical\").BADNUM,h=t(\"./cartesian/axis_ids\"),f=t(\"./animation_attributes\"),p=t(\"./frame_attributes\"),d=l.relinkPrivateKeys,g=l._,v=e.exports={};l.extendFlat(v,a),v.attributes=t(\"./attributes\"),v.attributes.type.values=v.allTypes,v.fontAttrs=t(\"./font_attributes\"),v.layoutAttributes=t(\"./layout_attributes\"),v.fontWeight=\"normal\";var m=v.transformsRegistry,y=t(\"./command\");v.executeAPICommand=y.executeAPICommand,v.computeAPICommandBindings=y.computeAPICommandBindings,v.manageCommandObserver=y.manageCommandObserver,v.hasSimpleAPICommandBindings=y.hasSimpleAPICommandBindings,v.redrawText=function(t){var e=(t=l.getGraphDiv(t))._fullLayout||{};if(!(!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r))return new Promise(function(e){setTimeout(function(){a.getComponentMethod(\"annotations\",\"draw\")(t),a.getComponentMethod(\"legend\",\"draw\")(t),a.getComponentMethod(\"colorbar\",\"draw\")(t),e(v.previousPromises(t))},300)})},v.resize=function(t){return t=l.getGraphDiv(t),new Promise(function(e,r){t&&!l.isHidden(t)||r(new Error(\"Resize must be passed a displayed plot div element.\")),t._redrawTimer&&clearTimeout(t._redrawTimer),t._redrawTimer=setTimeout(function(){if(!t.layout||t.layout.width&&t.layout.height||l.isHidden(t))e(t);else{delete t.layout.width,delete t.layout.height;var r=t.changed;t.autoplay=!0,a.call(\"relayout\",t,{autosize:!0}).then(function(){t.changed=r,e(t)})}},100)})},v.previousPromises=function(t){if((t._promises||[]).length)return Promise.all(t._promises).then(function(){t._promises=[]})},v.addLinks=function(t){if(t._context.showLink||t._context.showSources){var e=t._fullLayout,r=l.ensureSingle(e._paper,\"text\",\"js-plot-link-container\",function(t){t.style({\"font-family\":'\"Open Sans\", Arial, sans-serif',\"font-size\":\"12px\",fill:c.defaultLine,\"pointer-events\":\"all\"}).each(function(){var t=n.select(this);t.append(\"tspan\").classed(\"js-link-to-tool\",!0),t.append(\"tspan\").classed(\"js-link-spacer\",!0),t.append(\"tspan\").classed(\"js-sourcelinks\",!0)})}),i=r.node(),a={y:e._paper.attr(\"height\")-9};document.body.contains(i)&&i.getComputedTextLength()>=e.width-20?(a[\"text-anchor\"]=\"start\",a.x=5):(a[\"text-anchor\"]=\"end\",a.x=e._paper.attr(\"width\")-7),r.attr(a);var o=r.select(\".js-link-to-tool\"),s=r.select(\".js-link-spacer\"),u=r.select(\".js-sourcelinks\");t._context.showSources&&t._context.showSources(t),t._context.showLink&&function(t,e){e.text(\"\");var r=e.append(\"a\").attr({\"xlink:xlink:href\":\"#\",class:\"link--impt link--embedview\",\"font-weight\":\"bold\"}).text(t._context.linkText+\" \"+String.fromCharCode(187));if(t._context.sendData)r.on(\"click\",function(){v.sendDataToCloud(t)});else{var n=window.location.pathname.split(\"/\"),i=window.location.search;r.attr({\"xlink:xlink:show\":\"new\",\"xlink:xlink:href\":\"/\"+n[2].split(\".\")[0]+\"/\"+n[1]+i})}}(t,o),s.text(o.text()&&u.text()?\" - \":\"\")}},v.sendDataToCloud=function(t){t.emit(\"plotly_beforeexport\");var e=(window.PLOTLYENV||{}).BASE_URL||t._context.plotlyServerURL,r=n.select(t).append(\"div\").attr(\"id\",\"hiddenform\").style(\"display\",\"none\"),i=r.append(\"form\").attr({action:e+\"/external\",method:\"post\",target:\"_blank\"});return i.append(\"input\").attr({type:\"text\",name:\"data\"}).node().value=v.graphJson(t,!1,\"keepdata\"),i.node().submit(),r.remove(),t.emit(\"plotly_afterexport\"),!1};var x=[\"days\",\"shortDays\",\"months\",\"shortMonths\",\"periods\",\"dateTime\",\"date\",\"time\",\"decimal\",\"thousands\",\"grouping\",\"currency\"],b=[\"year\",\"month\",\"dayMonth\",\"dayMonthYear\"];function _(t,e){var r=t._context.locale,n=!1,i={};function o(t){for(var r=!0,a=0;a<e.length;a++){var o=e[a];i[o]||(t[o]?i[o]=t[o]:r=!1)}r&&(n=!0)}for(var s=0;s<2;s++){for(var l=t._context.locales,c=0;c<2;c++){var u=(l[r]||{}).format;if(u&&(o(u),n))break;l=a.localeRegistry}var h=r.split(\"-\")[0];if(n||h===r)break;r=h}return n||o(a.localeRegistry.en.format),i}function w(t,e){var r={_fullLayout:e},n=\"x\"===t._id.charAt(0),i=t._mainAxis._anchorAxis,a=\"\",o=\"\",s=\"\";if(i&&(s=i._mainAxis._id,a=n?t._id+s:s+t._id),!a||!e._plots[a]){a=\"\";for(var l=t._counterAxes,c=0;c<l.length;c++){var u=l[c],f=n?t._id+u:u+t._id;o||(o=f);var p=h.getFromId(r,u);if(s&&p.overlaying===s){a=f;break}}}return a||o}function k(t){var e=t.transforms;if(Array.isArray(e)&&e.length)for(var r=0;r<e.length;r++){var n=e[r],i=n._module||m[n.type];if(i&&i.makesData)return!0}return!1}function T(t,e,r,n){for(var i=t.transforms,a=[t],o=0;o<i.length;o++){var s=i[o],l=m[s.type];l&&l.transform&&(a=l.transform(a,{transform:s,fullTrace:t,fullData:e,layout:r,fullLayout:n,transformIndex:o}))}return a}function A(t){var e=t.margin;if(!t._size){var r=t._size={l:Math.round(e.l),r:Math.round(e.r),t:Math.round(e.t),b:Math.round(e.b),p:Math.round(e.pad)};r.w=Math.round(t.width)-r.l-r.r,r.h=Math.round(t.height)-r.t-r.b}t._pushmargin||(t._pushmargin={}),t._pushmarginIds||(t._pushmarginIds={})}v.supplyDefaults=function(t,e){var r=e&&e.skipUpdateCalc,i=t._fullLayout||{};if(i._skipDefaults)delete i._skipDefaults;else{var o,s=t._fullLayout={},c=t.layout||{},u=t._fullData||[],h=t._fullData=[],f=t.data||[],p=t.calcdata||[],m=t._context||{};t._transitionData||v.createTransitionData(t),s._dfltTitle={plot:g(t,\"Click to enter Plot title\"),x:g(t,\"Click to enter X axis title\"),y:g(t,\"Click to enter Y axis title\"),colorbar:g(t,\"Click to enter Colorscale title\"),annotation:g(t,\"new text\")},s._traceWord=g(t,\"trace\");var y=_(t,x);if(s._mapboxAccessToken=m.mapboxAccessToken,i._initialAutoSizeIsDone){var w=i.width,k=i.height;v.supplyLayoutGlobalDefaults(c,s,y),c.width||(s.width=w),c.height||(s.height=k),v.sanitizeMargins(s)}else{v.supplyLayoutGlobalDefaults(c,s,y);var T=!c.width||!c.height,M=s.autosize,S=m.autosizable;T&&(M||S)?v.plotAutoSize(t,c,s):T&&v.sanitizeMargins(s),!M&&T&&(c.width=s.width,c.height=s.height)}s._d3locale=function(t,e){return t.decimal=e.charAt(0),t.thousands=e.charAt(1),n.locale(t)}(y,s.separators),s._extraFormat=_(t,b),s._initialAutoSizeIsDone=!0,s._dataLength=f.length,s._modules=[],s._visibleModules=[],s._basePlotModules=[];var E=s._subplots=function(){var t,e,r=a.collectableSubplotTypes,n={};if(!r){r=[];var i=a.subplotsRegistry;for(var o in i){var s=i[o],c=s.attr;if(c&&(r.push(o),Array.isArray(c)))for(e=0;e<c.length;e++)l.pushUnique(r,c[e])}}for(t=0;t<r.length;t++)n[r[t]]=[];return n}(),C=s._splomAxes={x:{},y:{}},L=s._splomSubplots={};s._splomGridDflt={},s._scatterStackOpts={},s._firstScatter={},s._alignmentOpts={},s._colorAxes={},s._requestRangeslider={},s._traceUids=function(t,e){var r,n,i=e.length,a=[];for(r=0;r<t.length;r++){var o=t[r]._fullInput;o!==n&&a.push(o),n=o}var s=a.length,c=new Array(i),u={};function h(t,e){c[e]=t,u[t]=1}function f(t,e){if(t&&\"string\"==typeof t&&!u[t])return h(t,e),!0}for(r=0;r<i;r++){var p=e[r].uid;\"number\"==typeof p&&(p=String(p)),f(p,r)||(r<s&&f(a[r].uid,r)||h(l.randstr(u),r))}return c}(u,f),s._globalTransforms=(t._context||{}).globalTransforms,v.supplyDataDefaults(f,h,c,s);var P=Object.keys(C.x),O=Object.keys(C.y);if(P.length>1&&O.length>1){for(a.getComponentMethod(\"grid\",\"sizeDefaults\")(c,s),o=0;o<P.length;o++)l.pushUnique(E.xaxis,P[o]);for(o=0;o<O.length;o++)l.pushUnique(E.yaxis,O[o]);for(var z in L)l.pushUnique(E.cartesian,z)}if(s._has=v._hasPlotType.bind(s),u.length===h.length)for(o=0;o<h.length;o++)d(h[o],u[o]);v.supplyLayoutModuleDefaults(c,s,h,t._transitionData);var I=s._visibleModules,D=[];for(o=0;o<I.length;o++){var R=I[o].crossTraceDefaults;R&&l.pushUnique(D,R)}for(o=0;o<D.length;o++)D[o](h,s);s._hasOnlyLargeSploms=1===s._basePlotModules.length&&\"splom\"===s._basePlotModules[0].name&&P.length>15&&O.length>15&&0===s.shapes.length&&0===s.images.length,s._hasCartesian=s._has(\"cartesian\"),s._hasGeo=s._has(\"geo\"),s._hasGL3D=s._has(\"gl3d\"),s._hasGL2D=s._has(\"gl2d\"),s._hasTernary=s._has(\"ternary\"),s._hasPie=s._has(\"pie\"),v.linkSubplots(h,s,u,i),v.cleanPlot(h,s,u,i),i._zoomlayer&&!t._dragging&&i._zoomlayer.selectAll(\".select-outline\").remove(),function(t,e){var r,n=[];e.meta&&(r=e._meta={meta:e.meta,layout:{meta:e.meta}});for(var i=0;i<t.length;i++){var a=t[i];a.meta?n[a.index]=a._meta={meta:a.meta}:e.meta&&(a._meta={meta:e.meta}),e.meta&&(a._meta.layout={meta:e.meta})}n.length&&(r||(r=e._meta={}),r.data=n)}(h,s),d(s,i),a.getComponentMethod(\"colorscale\",\"crossTraceDefaults\")(h,s),s._preGUI||(s._preGUI={}),s._tracePreGUI||(s._tracePreGUI={});var F,B=s._tracePreGUI,N={};for(F in B)N[F]=\"old\";for(o=0;o<h.length;o++)N[F=h[o]._fullInput.uid]||(B[F]={}),N[F]=\"new\";for(F in N)\"old\"===N[F]&&delete B[F];A(s),a.getComponentMethod(\"rangeslider\",\"makeData\")(s),r||p.length!==h.length||v.supplyDefaultsUpdateCalc(p,h)}},v.supplyDefaultsUpdateCalc=function(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=(t[r]||[])[0];if(i&&i.trace){var a=i.trace;if(a._hasCalcTransform){var o,s,c,u=a._arrayAttrs;for(o=0;o<u.length;o++)s=u[o],c=l.nestedProperty(a,s).get().slice(),l.nestedProperty(n,s).set(c)}i.trace=n}}},v.createTransitionData=function(t){t._transitionData||(t._transitionData={}),t._transitionData._frames||(t._transitionData._frames=[]),t._transitionData._frameHash||(t._transitionData._frameHash={}),t._transitionData._counter||(t._transitionData._counter=0),t._transitionData._interruptCallbacks||(t._transitionData._interruptCallbacks=[])},v._hasPlotType=function(t){var e,r=this._basePlotModules||[];for(e=0;e<r.length;e++)if(r[e].name===t)return!0;var n=this._modules||[];for(e=0;e<n.length;e++){var i=n[e].name;if(i===t)return!0;var o=a.modules[i];if(o&&o.categories[t])return!0}return!1},v.cleanPlot=function(t,e,r,n){var i,a,o=n._basePlotModules||[];for(i=0;i<o.length;i++){var s=o[i];s.clean&&s.clean(t,e,r,n)}var l=n._has&&n._has(\"gl\"),c=e._has&&e._has(\"gl\");l&&!c&&void 0!==n._glcontainer&&(n._glcontainer.selectAll(\".gl-canvas\").remove(),n._glcontainer.selectAll(\".no-webgl\").remove(),n._glcanvas=null);var u=!!n._infolayer;t:for(i=0;i<r.length;i++){var h=r[i].uid;for(a=0;a<t.length;a++){if(h===t[a].uid)continue t}u&&n._infolayer.select(\".cb\"+h).remove()}},v.linkSubplots=function(t,e,r,n){var i,a,o=n._plots||{},s=e._plots={},c=e._subplots,u={_fullData:t,_fullLayout:e},f=c.cartesian.concat(c.gl2d||[]);for(i=0;i<f.length;i++){var p,d=f[i],g=o[d],v=h.getFromId(u,d,\"x\"),m=h.getFromId(u,d,\"y\");for(g?p=s[d]=g:(p=s[d]={}).id=d,v._counterAxes.push(m._id),m._counterAxes.push(v._id),v._subplotsWith.push(d),m._subplotsWith.push(d),p.xaxis=v,p.yaxis=m,p._hasClipOnAxisFalse=!1,a=0;a<t.length;a++){var y=t[a];if(y.xaxis===p.xaxis._id&&y.yaxis===p.yaxis._id&&!1===y.cliponaxis){p._hasClipOnAxisFalse=!0;break}}}var x,b=h.list(u,null,!0);for(i=0;i<b.length;i++){var _=null;(x=b[i]).overlaying&&(_=h.getFromId(u,x.overlaying))&&_.overlaying&&(x.overlaying=!1,_=null),x._mainAxis=_||x,_&&(x.domain=_.domain.slice()),x._anchorAxis=\"free\"===x.anchor?null:h.getFromId(u,x.anchor)}for(i=0;i<b.length;i++)(x=b[i])._counterAxes.sort(h.idSort),x._subplotsWith.sort(l.subplotSort),x._mainSubplot=w(x,e)},v.clearExpandedTraceDefaultColors=function(t){var e,r,n;for(r=[],(e=t._module._colorAttrs)||(t._module._colorAttrs=e=[],o.crawl(t._module.attributes,function(t,n,i,a){r[a]=n,r.length=a+1,\"color\"===t.valType&&void 0===t.dflt&&e.push(r.join(\".\"))})),n=0;n<e.length;n++){l.nestedProperty(t,\"_input.\"+e[n]).get()||l.nestedProperty(t,e[n]).set(null)}},v.supplyDataDefaults=function(t,e,r,n){var i,o,c,u=n._modules,h=n._visibleModules,f=n._basePlotModules,p=0,g=0;function m(t){e.push(t);var r=t._module;r&&(l.pushUnique(u,r),!0===t.visible&&l.pushUnique(h,r),l.pushUnique(f,t._module.basePlotModule),p++,!1!==t._input.visible&&g++)}n._transformModules=[];var y={},x=[],b=(r.template||{}).data||{},_=s.traceTemplater(b);for(i=0;i<t.length;i++){if(c=t[i],(o=_.newTrace(c)).uid=n._traceUids[i],v.supplyTraceDefaults(c,o,g,n,i),o.index=i,o._input=c,o._expandedIndex=p,o.transforms&&o.transforms.length)for(var w=!1!==c.visible&&!1===o.visible,k=T(o,e,r,n),A=0;A<k.length;A++){var M=k[A],S={_template:o._template,type:o.type,uid:o.uid+A};w&&!1===M.visible&&delete M.visible,v.supplyTraceDefaults(M,S,p,n,i),d(S,M),S.index=i,S._input=c,S._fullInput=o,S._expandedIndex=p,S._expandedInput=M,m(S)}else o._fullInput=o,o._expandedInput=o,m(o);a.traceIs(o,\"carpetAxis\")&&(y[o.carpet]=o),a.traceIs(o,\"carpetDependent\")&&x.push(i)}for(i=0;i<x.length;i++)if((o=e[x[i]]).visible){var E=y[o.carpet];o._carpet=E,E&&E.visible?(o.xaxis=E.xaxis,o.yaxis=E.yaxis):o.visible=!1}},v.supplyAnimationDefaults=function(t){var e;t=t||{};var r={};function n(e,n){return l.coerce(t||{},r,f,e,n)}if(n(\"mode\"),n(\"direction\"),n(\"fromcurrent\"),Array.isArray(t.frame))for(r.frame=[],e=0;e<t.frame.length;e++)r.frame[e]=v.supplyAnimationFrameDefaults(t.frame[e]||{});else r.frame=v.supplyAnimationFrameDefaults(t.frame||{});if(Array.isArray(t.transition))for(r.transition=[],e=0;e<t.transition.length;e++)r.transition[e]=v.supplyAnimationTransitionDefaults(t.transition[e]||{});else r.transition=v.supplyAnimationTransitionDefaults(t.transition||{});return r},v.supplyAnimationFrameDefaults=function(t){var e={};function r(r,n){return l.coerce(t||{},e,f.frame,r,n)}return r(\"duration\"),r(\"redraw\"),e},v.supplyAnimationTransitionDefaults=function(t){var e={};function r(r,n){return l.coerce(t||{},e,f.transition,r,n)}return r(\"duration\"),r(\"easing\"),e},v.supplyFrameDefaults=function(t){var e={};function r(r,n){return l.coerce(t,e,p,r,n)}return r(\"group\"),r(\"name\"),r(\"traces\"),r(\"baseframe\"),r(\"data\"),r(\"layout\"),e},v.supplyTraceDefaults=function(t,e,r,n,i){var o,s=n.colorway||c.defaults,u=s[r%s.length];function h(r,n){return l.coerce(t,e,v.attributes,r,n)}var f=h(\"visible\");h(\"type\"),h(\"name\",n._traceWord+\" \"+i),h(\"uirevision\",n.uirevision);var p=v.getModule(e);if(e._module=p,p){var d=p.basePlotModule,g=d.attr,m=d.attributes;if(g&&m){var y=n._subplots,x=\"\";if(\"gl2d\"!==d.name||f){if(Array.isArray(g))for(o=0;o<g.length;o++){var b=g[o],_=l.coerce(t,e,m,b);y[b]&&l.pushUnique(y[b],_),x+=_}else x=l.coerce(t,e,m,g);y[d.name]&&l.pushUnique(y[d.name],x)}}}return f&&(h(\"customdata\"),h(\"ids\"),h(\"meta\"),a.traceIs(e,\"showLegend\")?(e._dfltShowLegend=!0,h(\"showlegend\"),h(\"legendgroup\")):e._dfltShowLegend=!1,p&&p.supplyDefaults(t,e,u,n),a.traceIs(e,\"noOpacity\")||h(\"opacity\"),a.traceIs(e,\"notLegendIsolatable\")&&(e.visible=!!e.visible),a.traceIs(e,\"noHover\")||(e.hovertemplate||l.coerceHoverinfo(t,e,n),\"parcats\"!==e.type&&a.getComponentMethod(\"fx\",\"supplyDefaults\")(t,e,u,n)),p&&p.selectPoints&&h(\"selectedpoints\"),v.supplyTransformDefaults(t,e,n)),e},v.hasMakesDataTransform=k,v.supplyTransformDefaults=function(t,e,r){if(e._length||k(t)){var n=r._globalTransforms||[],i=r._transformModules||[];if(Array.isArray(t.transforms)||0!==n.length)for(var a=t.transforms||[],o=n.concat(a),s=e.transforms=[],c=0;c<o.length;c++){var u,h=o[c],f=h.type,p=m[f],d=!(h._module&&h._module===p),g=p&&\"function\"==typeof p.transform;p||l.warn(\"Unrecognized transform type \"+f+\".\"),p&&p.supplyDefaults&&(d||g)?((u=p.supplyDefaults(h,e,r,t)).type=f,u._module=p,l.pushUnique(i,p)):u=l.extendFlat({},h),s.push(u)}}},v.supplyLayoutGlobalDefaults=function(t,e,r){function n(r,n){return l.coerce(t,e,v.layoutAttributes,r,n)}var i=t.template;l.isPlainObject(i)&&(e.template=i,e._template=i.layout,e._dataTemplate=i.data);var o=l.coerceFont(n,\"font\");n(\"title.text\",e._dfltTitle.plot),l.coerceFont(n,\"title.font\",{family:o.family,size:Math.round(1.4*o.size),color:o.color}),n(\"title.xref\"),n(\"title.yref\"),n(\"title.x\"),n(\"title.y\"),n(\"title.xanchor\"),n(\"title.yanchor\"),n(\"title.pad.t\"),n(\"title.pad.r\"),n(\"title.pad.b\"),n(\"title.pad.l\"),n(\"autosize\",!(t.width&&t.height)),n(\"width\"),n(\"height\"),n(\"margin.l\"),n(\"margin.r\"),n(\"margin.t\"),n(\"margin.b\"),n(\"margin.pad\"),n(\"margin.autoexpand\"),t.width&&t.height&&v.sanitizeMargins(e),a.getComponentMethod(\"grid\",\"sizeDefaults\")(t,e),n(\"paper_bgcolor\"),n(\"separators\",r.decimal+r.thousands),n(\"hidesources\"),n(\"colorway\"),n(\"datarevision\");var s=n(\"uirevision\");n(\"editrevision\",s),n(\"selectionrevision\",s),n(\"modebar.orientation\"),n(\"modebar.bgcolor\",c.addOpacity(e.paper_bgcolor,.5));var u=c.contrast(c.rgb(e.modebar.bgcolor));n(\"modebar.color\",c.addOpacity(u,.3)),n(\"modebar.activecolor\",c.addOpacity(u,.7)),n(\"modebar.uirevision\",s),n(\"meta\"),l.isPlainObject(t.transition)&&(n(\"transition.duration\"),n(\"transition.easing\"),n(\"transition.ordering\")),a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\"),a.getComponentMethod(\"fx\",\"supplyLayoutGlobalDefaults\")(t,e,n)},v.plotAutoSize=function(t,e,r){var n,a,o=t._context||{},s=o.frameMargins,c=l.isPlotDiv(t);if(c&&t.emit(\"plotly_autosize\"),o.fillFrame)n=window.innerWidth,a=window.innerHeight,document.body.style.overflow=\"hidden\";else{var u=c?window.getComputedStyle(t):{};if(n=parseFloat(u.width)||parseFloat(u.maxWidth)||r.width,a=parseFloat(u.height)||parseFloat(u.maxHeight)||r.height,i(s)&&s>0){var h=1-2*s;n=Math.round(h*n),a=Math.round(h*a)}}var f=v.layoutAttributes.width.min,p=v.layoutAttributes.height.min;n<f&&(n=f),a<p&&(a=p);var d=!e.width&&Math.abs(r.width-n)>1,g=!e.height&&Math.abs(r.height-a)>1;(g||d)&&(d&&(r.width=n),g&&(r.height=a)),t._initialAutoSize||(t._initialAutoSize={width:n,height:a}),v.sanitizeMargins(r)},v.supplyLayoutModuleDefaults=function(t,e,r,n){var i,o,s,c=a.componentsRegistry,u=e._basePlotModules,h=a.subplotsRegistry.cartesian;for(i in c)(s=c[i]).includeBasePlot&&s.includeBasePlot(t,e);for(var f in u.length||u.push(h),e._has(\"cartesian\")&&(a.getComponentMethod(\"grid\",\"contentDefaults\")(t,e),h.finalizeSubplots(t,e)),e._subplots)e._subplots[f].sort(l.subplotSort);for(o=0;o<u.length;o++)(s=u[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var p=e._modules;for(o=0;o<p.length;o++)(s=p[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var d=e._transformModules;for(o=0;o<d.length;o++)(s=d[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r,n);for(i in c)(s=c[i]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r)},v.purge=function(t){var e=t._fullLayout||{};void 0!==e._glcontainer&&(e._glcontainer.selectAll(\".gl-canvas\").remove(),e._glcontainer.remove(),e._glcanvas=null),void 0!==e._geocontainer&&e._geocontainer.remove(),e._modeBar&&e._modeBar.destroy(),t._transitionData&&(t._transitionData._interruptCallbacks&&(t._transitionData._interruptCallbacks.length=0),t._transitionData._animationRaf&&window.cancelAnimationFrame(t._transitionData._animationRaf)),l.clearThrottle(),l.clearResponsive(t),delete t.data,delete t.layout,delete t._fullData,delete t._fullLayout,delete t.calcdata,delete t.framework,delete t.empty,delete t.fid,delete t.undoqueue,delete t.undonum,delete t.autoplay,delete t.changed,delete t._promises,delete t._redrawTimer,delete t._hmlumcount,delete t._hmpixcount,delete t._transitionData,delete t._transitioning,delete t._initialAutoSize,delete t._transitioningWithDuration,delete t._dragging,delete t._dragged,delete t._dragdata,delete t._hoverdata,delete t._snapshotInProgress,delete t._editing,delete t._mouseDownTime,delete t._legendMouseDownTime,t.removeAllListeners&&t.removeAllListeners()},v.style=function(t){var e,r=t._fullLayout._visibleModules,n=[];for(e=0;e<r.length;e++){var i=r[e];i.style&&l.pushUnique(n,i.style)}for(e=0;e<n.length;e++)n[e](t)},v.sanitizeMargins=function(t){if(t&&t.margin){var e,r=t.width,n=t.height,i=t.margin,a=r-(i.l+i.r),o=n-(i.t+i.b);a<0&&(e=(r-1)/(i.l+i.r),i.l=Math.floor(e*i.l),i.r=Math.floor(e*i.r)),o<0&&(e=(n-1)/(i.t+i.b),i.t=Math.floor(e*i.t),i.b=Math.floor(e*i.b))}},v.clearAutoMarginIds=function(t){t._fullLayout._pushmarginIds={}},v.allowAutoMargin=function(t,e){t._fullLayout._pushmarginIds[e]=1},v.autoMargin=function(t,e,r){var n=t._fullLayout,i=n._pushmargin,a=n._pushmarginIds;if(!1!==n.margin.autoexpand){if(r){var o=r.pad;if(void 0===o){var s=n.margin;o=Math.min(12,s.l,s.r,s.t,s.b)}r.l+r.r>.5*n.width&&(r.l=r.r=0),r.b+r.t>.5*n.height&&(r.b=r.t=0);var l=void 0!==r.xl?r.xl:r.x,c=void 0!==r.xr?r.xr:r.x,u=void 0!==r.yt?r.yt:r.y,h=void 0!==r.yb?r.yb:r.y;i[e]={l:{val:l,size:r.l+o},r:{val:c,size:r.r+o},b:{val:h,size:r.b+o},t:{val:u,size:r.t+o}},a[e]=1}else delete i[e],delete a[e];n._replotting||v.doAutoMargin(t)}},v.doAutoMargin=function(t){var e=t._fullLayout;e._size||(e._size={}),A(e);var r=e._size,n=e.margin,o=l.extendFlat({},r),s=n.l,c=n.r,u=n.t,h=n.b,f=e.width,p=e.height,d=e._pushmargin,g=e._pushmarginIds;if(!1!==e.margin.autoexpand){for(var m in d)g[m]||delete d[m];for(var y in d.base={l:{val:0,size:s},r:{val:1,size:c},t:{val:1,size:u},b:{val:0,size:h}},d){var x=d[y].l||{},b=d[y].b||{},_=x.val,w=x.size,k=b.val,T=b.size;for(var M in d){if(i(w)&&d[M].r){var S=d[M].r.val,E=d[M].r.size;if(S>_){var C=(w*S+(E-f)*_)/(S-_),L=(E*(1-_)+(w-f)*(1-S))/(S-_);C>=0&&L>=0&&f-(C+L)>0&&C+L>s+c&&(s=C,c=L)}}if(i(T)&&d[M].t){var P=d[M].t.val,O=d[M].t.size;if(P>k){var z=(T*P+(O-p)*k)/(P-k),I=(O*(1-k)+(T-p)*(1-P))/(P-k);z>=0&&I>=0&&p-(I+z)>0&&z+I>h+u&&(h=z,u=I)}}}}}if(r.l=Math.round(s),r.r=Math.round(c),r.t=Math.round(u),r.b=Math.round(h),r.p=Math.round(n.pad),r.w=Math.round(f)-r.l-r.r,r.h=Math.round(p)-r.t-r.b,!e._replotting&&v.didMarginChange(o,r))return\"_redrawFromAutoMarginCount\"in e?e._redrawFromAutoMarginCount++:e._redrawFromAutoMarginCount=1,a.call(\"plot\",t)};var M=[\"l\",\"r\",\"t\",\"b\",\"p\",\"w\",\"h\"];function S(t,e,r){var n=!1;var i=[v.previousPromises,function(){if(t._transitionData)return t._transitioning=!1,function(t){var e=Promise.resolve();if(!t)return e;for(;t.length;)e=e.then(t.shift());return e}(t._transitionData._interruptCallbacks)},r.prepareFn,v.rehover,function(){return t.emit(\"plotly_transitioning\",[]),new Promise(function(i){t._transitioning=!0,e.duration>0&&(t._transitioningWithDuration=!0),t._transitionData._interruptCallbacks.push(function(){n=!0}),r.redraw&&t._transitionData._interruptCallbacks.push(function(){return a.call(\"redraw\",t)}),t._transitionData._interruptCallbacks.push(function(){t.emit(\"plotly_transitioninterrupted\",[])});var o=0,s=0;function l(){return o++,function(){var e;s++,n||s!==o||(e=i,t._transitionData&&(function(t){if(t)for(;t.length;)t.shift()}(t._transitionData._interruptCallbacks),Promise.resolve().then(function(){if(r.redraw)return a.call(\"redraw\",t)}).then(function(){t._transitioning=!1,t._transitioningWithDuration=!1,t.emit(\"plotly_transitioned\",[])}).then(e)))}}r.runFn(l),setTimeout(l())})}],o=l.syncOrAsync(i,t);return o&&o.then||(o=Promise.resolve()),o.then(function(){return t})}v.didMarginChange=function(t,e){for(var r=0;r<M.length;r++){var n=M[r],a=t[n],o=e[n];if(!i(a)||Math.abs(o-a)>1)return!0}return!1},v.graphJson=function(t,e,r,n,i){(i&&e&&!t._fullData||i&&!e&&!t._fullLayout)&&v.supplyDefaults(t);var a=i?t._fullData:t.data,o=i?t._fullLayout:t.layout,s=(t._transitionData||{})._frames;function c(t){if(\"function\"==typeof t)return null;if(l.isPlainObject(t)){var e,n,i={};for(e in t)if(\"function\"!=typeof t[e]&&-1===[\"_\",\"[\"].indexOf(e.charAt(0))){if(\"keepdata\"===r){if(\"src\"===e.substr(e.length-3))continue}else if(\"keepstream\"===r){if(\"string\"==typeof(n=t[e+\"src\"])&&n.indexOf(\":\")>0&&!l.isPlainObject(t.stream))continue}else if(\"keepall\"!==r&&\"string\"==typeof(n=t[e+\"src\"])&&n.indexOf(\":\")>0)continue;i[e]=c(t[e])}return i}return Array.isArray(t)?t.map(c):l.isTypedArray(t)?l.simpleMap(t,l.identity):l.isJSDate(t)?l.ms2DateTimeLocal(+t):t}var u={data:(a||[]).map(function(t){var r=c(t);return e&&delete r.fit,r})};return e||(u.layout=c(o)),t.framework&&t.framework.isPolar&&(u=t.framework.getConfig()),s&&(u.frames=c(s)),\"object\"===n?u:JSON.stringify(u)},v.modifyFrames=function(t,e){var r,n,i,a=t._transitionData._frames,o=t._transitionData._frameHash;for(r=0;r<e.length;r++)switch((n=e[r]).type){case\"replace\":i=n.value;var s=(a[n.index]||{}).name,l=i.name;a[n.index]=o[l]=i,l!==s&&(delete o[s],o[l]=i);break;case\"insert\":o[(i=n.value).name]=i,a.splice(n.index,0,i);break;case\"delete\":delete o[(i=a[n.index]).name],a.splice(n.index,1)}return Promise.resolve()},v.computeFrame=function(t,e){var r,n,i,a,o=t._transitionData._frameHash;if(!e)throw new Error(\"computeFrame must be given a string frame name\");var s=o[e.toString()];if(!s)return!1;for(var l=[s],c=[s.name];s.baseframe&&(s=o[s.baseframe.toString()])&&-1===c.indexOf(s.name);)l.push(s),c.push(s.name);for(var u={};s=l.pop();)if(s.layout&&(u.layout=v.extendLayout(u.layout,s.layout)),s.data){if(u.data||(u.data=[]),!(n=s.traces))for(n=[],r=0;r<s.data.length;r++)n[r]=r;for(u.traces||(u.traces=[]),r=0;r<s.data.length;r++)null!=(i=n[r])&&(-1===(a=u.traces.indexOf(i))&&(a=u.data.length,u.traces[a]=i),u.data[a]=v.extendTrace(u.data[a],s.data[r]))}return u},v.recomputeFrameHash=function(t){for(var e=t._transitionData._frameHash={},r=t._transitionData._frames,n=0;n<r.length;n++){var i=r[n];i&&i.name&&(e[i.name]=i)}},v.extendObjectWithContainers=function(t,e,r){var n,i,a,o,s,c,u,h=l.extendDeepNoArrays({},e||{}),f=l.expandObjectPaths(h),p={};if(r&&r.length)for(a=0;a<r.length;a++)void 0===(i=(n=l.nestedProperty(f,r[a])).get())?l.nestedProperty(p,r[a]).set(null):(n.set(null),l.nestedProperty(p,r[a]).set(i));if(t=l.extendDeepNoArrays(t||{},f),r&&r.length)for(a=0;a<r.length;a++)if(c=l.nestedProperty(p,r[a]).get()){for(u=(s=l.nestedProperty(t,r[a])).get(),Array.isArray(u)||(u=[],s.set(u)),o=0;o<c.length;o++){var d=c[o];u[o]=null===d?null:v.extendObjectWithContainers(u[o],d)}s.set(u)}return t},v.dataArrayContainers=[\"transforms\",\"dimensions\"],v.layoutArrayContainers=a.layoutArrayContainers,v.extendTrace=function(t,e){return v.extendObjectWithContainers(t,e,v.dataArrayContainers)},v.extendLayout=function(t,e){return v.extendObjectWithContainers(t,e,v.layoutArrayContainers)},v.transition=function(t,e,r,n,i,a){var o={redraw:i.redraw},s={},c=[];return o.prepareFn=function(){for(var i=Array.isArray(e)?e.length:0,a=n.slice(0,i),o=0;o<a.length;o++){var u=a[o],h=t._fullData[u]._module;if(h){if(h.animatable){var f=h.basePlotModule.name;s[f]||(s[f]=[]),s[f].push(u)}t.data[a[o]]=v.extendTrace(t.data[a[o]],e[o])}}var p=l.expandObjectPaths(l.extendDeepNoArrays({},r)),d=/^[xy]axis[0-9]*$/;for(var g in p)d.test(g)&&delete p[g].range;v.extendLayout(t.layout,p),delete t.calcdata,v.supplyDefaults(t),v.doCalcdata(t);var m=l.expandObjectPaths(r);if(m){var y=t._fullLayout._plots;for(var x in y){var b,_,w,k,T=y[x],A=T.xaxis,M=T.yaxis,S=A.range.slice(),E=M.range.slice();Array.isArray(m[A._name+\".range\"])?b=m[A._name+\".range\"].slice():Array.isArray((m[A._name]||{}).range)&&(b=m[A._name].range.slice()),Array.isArray(m[M._name+\".range\"])?_=m[M._name+\".range\"].slice():Array.isArray((m[M._name]||{}).range)&&(_=m[M._name].range.slice()),S&&b&&(S[0]!==b[0]||S[1]!==b[1])&&(w={xr0:S,xr1:b}),E&&_&&(E[0]!==_[0]||E[1]!==_[1])&&(k={yr0:E,yr1:_}),(w||k)&&c.push(l.extendFlat({plotinfo:T},w,k))}}return Promise.resolve()},o.runFn=function(e){var n,i,o=t._fullLayout._basePlotModules,u=c.length;if(r)for(i=0;i<o.length;i++)o[i].transitionAxes&&o[i].transitionAxes(t,c,a,e);for(var h in u?((n=l.extendFlat({},a)).duration=0,delete s.cartesian):n=a,s){var f=s[h];t._fullData[f[0]]._module.basePlotModule.plot(t,f,n,e)}},S(t,a,o)},v.transitionFromReact=function(t,e,r,n){var i=t._fullLayout,a=i.transition,o={},s=[];return o.prepareFn=function(){var t=i._plots;for(var a in o.redraw=!1,\"some\"===e.anim&&(o.redraw=!0),\"some\"===r.anim&&(o.redraw=!0),t){var c,u,h=t[a],f=h.xaxis,p=h.yaxis,d=n[f._name].range.slice(),g=n[p._name].range.slice(),v=f.range.slice(),m=p.range.slice();f.setScale(),p.setScale(),d[0]===v[0]&&d[1]===v[1]||(c={xr0:d,xr1:v}),g[0]===m[0]&&g[1]===m[1]||(u={yr0:g,yr1:m}),(c||u)&&s.push(l.extendFlat({plotinfo:h},c,u))}return Promise.resolve()},o.runFn=function(r){for(var n,i,o,c=t._fullData,u=t._fullLayout._basePlotModules,h=[],f=0;f<c.length;f++)h.push(f);function p(){for(var e=0;e<u.length;e++)u[e].transitionAxes&&u[e].transitionAxes(t,s,n,r)}function d(){for(var e=0;e<u.length;e++)u[e].plot(t,o,i,r)}s.length&&e.anim?\"traces first\"===a.ordering?(n=l.extendFlat({},a,{duration:0}),o=h,i=a,d(),setTimeout(p,a.duration)):(n=a,o=null,i=l.extendFlat({},a,{duration:0}),p(),d()):s.length?(n=a,p()):e.anim&&(o=h,i=a,d())},S(t,a,o)},v.doCalcdata=function(t,e){var r,n,i,s,c=h.list(t),f=t._fullData,p=t._fullLayout,d=new Array(f.length),g=(t.calcdata||[]).slice();for(t.calcdata=d,p._numBoxes=0,p._numViolins=0,p._violinScaleGroupStats={},t._hmpixcount=0,t._hmlumcount=0,p._piecolormap={},p._sunburstcolormap={},p._funnelareacolormap={},i=0;i<f.length;i++)Array.isArray(e)&&-1===e.indexOf(i)&&(d[i]=g[i]);for(i=0;i<f.length;i++)(r=f[i])._arrayAttrs=o.findArrayAttributes(r),r._extremes={};var v=p._subplots.polar||[];for(i=0;i<v.length;i++)c.push(p[v[i]].radialaxis,p[v[i]].angularaxis);var y=!1;function x(e){if(r=f[e],n=r._module,!0===r.visible&&r.transforms){if(n&&n.calc){var i=n.calc(t,r);i[0]&&i[0].t&&i[0].t._scene&&delete i[0].t._scene.dirty}for(s=0;s<r.transforms.length;s++){var a=r.transforms[s];(n=m[a.type])&&n.calcTransform&&(r._hasCalcTransform=!0,y=!0,n.calcTransform(t,r,a))}}}function b(e,i){if(r=f[e],!!(n=r._module).isContainer===i){var a=[];if(!0===r.visible&&0!==r._length){delete r._indexToPoints;var o=r.transforms||[];for(s=o.length-1;s>=0;s--)if(o[s].enabled){r._indexToPoints=o[s]._indexToPoints;break}n&&n.calc&&(a=n.calc(t,r))}Array.isArray(a)&&a[0]||(a=[{x:u,y:u}]),a[0].t||(a[0].t={}),a[0].trace=r,d[e]=a}}for(C(c,f),i=0;i<f.length;i++)b(i,!0);for(i=0;i<f.length;i++)x(i);for(y&&C(c,f),i=0;i<f.length;i++)b(i,!0);for(i=0;i<f.length;i++)b(i,!1);L(t);var _=function(t,e){var r,n,i,o,s,c=[];function u(t,r,n){var i=r._id.charAt(0);if(\"histogram2dcontour\"===t){var a=r._counterAxes[0],o=h.getFromId(e,a),s=\"x\"===i||\"x\"===a&&\"category\"===o.type,l=\"y\"===i||\"y\"===a&&\"category\"===o.type;return function(t,e){return 0===t||0===e?-1:s&&t===n[e].length-1?-1:l&&e===n.length-1?-1:(\"y\"===i?e:t)-1}}return function(t,e){return\"y\"===i?e:t}}var f={min:function(t){return l.aggNums(Math.min,null,t)},max:function(t){return l.aggNums(Math.max,null,t)},sum:function(t){return l.aggNums(function(t,e){return t+e},null,t)},total:function(t){return l.aggNums(function(t,e){return t+e},null,t)},mean:function(t){return l.mean(t)},median:function(t){return l.median(t)}};for(r=0;r<t.length;r++){var p=t[r];if(\"category\"===p.type){var d=p.categoryorder.match(E);if(d){var g=d[1],v=d[2],m=[];for(n=0;n<p._categories.length;n++)m.push([p._categories[n],[]]);for(n=0;n<p._traceIndices.length;n++){var y=p._traceIndices[n],x=e._fullData[y],b=p._id.charAt(0);if(!0===x.visible){var _=x.type;a.traceIs(x,\"histogram\")&&(delete x._xautoBinFinished,delete x._yautoBinFinished);var w=e.calcdata[y];for(i=0;i<w.length;i++){var k,T,A,M=w[i];if(\"splom\"===_){var S=x._axesDim[p._id];if(\"y\"===b){var C=x._diag[S][0];C&&(p=e._fullLayout[h.id2name(C)])}var L=M.trace.dimensions[S].values;for(o=0;o<L.length;o++)for(k=L[o],T=p._categoriesMap[k],s=0;s<M.trace.dimensions.length;s++)if(s!==S){var P=M.trace.dimensions[s];m[T][1].push(P.values[o])}}else if(\"scattergl\"===_){for(o=0;o<M.t.x.length;o++)\"x\"===b&&(k=M.t.x[o],T=k,A=M.t.y[o]),\"y\"===b&&(k=M.t.y[o],T=k,A=M.t.x[o]),m[T][1].push(A);M.t&&M.t._scene&&delete M.t._scene.dirty}else if(M.hasOwnProperty(\"z\")){A=M.z;var O=u(x.type,p,A);for(o=0;o<A.length;o++)for(s=0;s<A[o].length;s++)(T=O(s,o))+1&&m[T][1].push(A[o][s])}else for(\"x\"===b?(k=M.p+1?M.p:M.x,A=M.s||M.v||M.y):\"y\"===b&&(k=M.p+1?M.p:M.y,A=M.s||M.v||M.x),Array.isArray(A)||(A=[A]),o=0;o<A.length;o++)m[k][1].push(A[o])}}}p._categoriesValue=m;var z=[];for(n=0;n<m.length;n++)z.push([m[n][0],f[g](m[n][1])]);z.sort(function(t,e){return t[1]-e[1]}),p._categoriesAggregatedValue=z,p._initialCategories=z.map(function(t){return t[0]}),\"descending\"===v&&p._initialCategories.reverse(),c=c.concat(p.sortByInitialCategories())}}}return c}(c,t);if(_.length){for(p._numBoxes=0,p._numViolins=0,i=0;i<_.length;i++)b(_[i],!0);for(i=0;i<_.length;i++)b(_[i],!1);L(t)}a.getComponentMethod(\"fx\",\"calc\")(t),a.getComponentMethod(\"errorbars\",\"calc\")(t)};var E=/(total|sum|min|max|mean|median) (ascending|descending)/;function C(t,e){for(var r=0;r<t.length;r++){var n=t[r];n.clearCalc(),\"multicategory\"===n.type&&n.setupMultiCategory(e)}}function L(t){var e,r,n,i=t._fullLayout,a=i._visibleModules,o={};for(r=0;r<a.length;r++){var s=a[r],c=s.crossTraceCalc;if(c){var u=s.basePlotModule.name;o[u]?l.pushUnique(o[u],c):o[u]=[c]}}for(n in o){var h=o[n],f=i._subplots[n];if(Array.isArray(f))for(e=0;e<f.length;e++){var p=f[e],d=\"cartesian\"===n?i._plots[p]:i[p];for(r=0;r<h.length;r++)h[r](t,d,p)}else for(r=0;r<h.length;r++)h[r](t)}}v.rehover=function(t){t._fullLayout._rehover&&t._fullLayout._rehover()},v.redrag=function(t){t._fullLayout._redrag&&t._fullLayout._redrag()},v.generalUpdatePerTraceModule=function(t,e,r,n){var i,a=e.traceHash,o={};for(i=0;i<r.length;i++){var s=r[i],c=s[0].trace;c.visible&&(o[c.type]=o[c.type]||[],o[c.type].push(s))}for(var u in a)if(!o[u]){var h=a[u][0];h[0].trace.visible=!1,o[u]=[h]}for(var f in o){var p=o[f];p[0][0].trace._module.plot(t,e,l.filterVisible(p),n)}e.traceHash=o}},{\"../components/color\":593,\"../constants/numerical\":695,\"../lib\":719,\"../plot_api/plot_schema\":756,\"../plot_api/plot_template\":757,\"../registry\":847,\"./animation_attributes\":762,\"./attributes\":764,\"./cartesian/axis_ids\":770,\"./command\":791,\"./font_attributes\":793,\"./frame_attributes\":794,\"./layout_attributes\":819,d3:163,\"fast-isnumeric\":225}],829:[function(t,e,r){\"use strict\";e.exports={attr:\"subplot\",name:\"polar\",axisNames:[\"angularaxis\",\"radialaxis\"],axisName2dataArray:{angularaxis:\"theta\",radialaxis:\"r\"},layerNames:[\"draglayer\",\"plotbg\",\"backplot\",\"angular-grid\",\"radial-grid\",\"frontplot\",\"angular-line\",\"radial-line\",\"angular-axis\",\"radial-axis\"],radialDragBoxSize:50,angularDragBoxSize:30,cornerLen:25,cornerHalfWidth:2,MINDRAG:8,MINZOOM:20,OFFEDGE:20}},{}],830:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/polygon\").tester,a=n.findIndexOfMin,o=n.isAngleInsideSector,s=n.angleDelta,l=n.angleDist;function c(t,e,r,n){var i,a,o=n[0],s=n[1],l=h(Math.sin(e)-Math.sin(t)),c=h(Math.cos(e)-Math.cos(t)),u=Math.tan(r),f=h(1/u),p=l/c,d=s-p*o;return f?l&&c?a=u*(i=d/(u-p)):c?(i=s*f,a=s):(i=o,a=o*u):l&&c?(i=0,a=d):c?(i=0,a=s):i=a=NaN,[i,a]}function u(t,e,r,i){return n.isFullCircle([e,r])?function(t,e){var r,n=e.length,i=new Array(n+1);for(r=0;r<n;r++){var a=e[r];i[r]=[t*Math.cos(a),t*Math.sin(a)]}return i[r]=i[0].slice(),i}(t,i):function(t,e,r,i){var s,u,h=i.length,f=[];function p(e){return[t*Math.cos(e),t*Math.sin(e)]}function d(t,e,r){return c(t,e,r,p(t))}function g(t){return n.mod(t,h)}function v(t){return o(t,[e,r])}var m=a(i,function(t){return v(t)?l(t,e):1/0}),y=d(i[m],i[g(m-1)],e);for(f.push(y),s=m,u=0;u<h;s++,u++){var x=i[g(s)];if(!v(x))break;f.push(p(x))}var b=a(i,function(t){return v(t)?l(t,r):1/0}),_=d(i[b],i[g(b+1)],r);return f.push(_),f.push([0,0]),f.push(f[0].slice()),f}(t,e,r,i)}function h(t){return Math.abs(t)>1e-10?t:0}function f(t,e,r){e=e||0,r=r||0;for(var n=t.length,i=new Array(n),a=0;a<n;a++){var o=t[a];i[a]=[e+o[0],r-o[1]]}return i}e.exports={isPtInsidePolygon:function(t,e,r,n,a){if(!o(e,n))return!1;var s,l;r[0]<r[1]?(s=r[0],l=r[1]):(s=r[1],l=r[0]);var c=i(u(s,n[0],n[1],a)),h=i(u(l,n[0],n[1],a)),f=[t*Math.cos(e),t*Math.sin(e)];return h.contains(f)&&!c.contains(f)},findPolygonOffset:function(t,e,r,n){for(var i=1/0,a=1/0,o=u(t,e,r,n),s=0;s<o.length;s++){var l=o[s];i=Math.min(i,l[0]),a=Math.min(a,-l[1])}return[i,a]},findEnclosingVertexAngles:function(t,e){var r=a(e,function(e){var r=s(e,t);return r>0?r:1/0}),i=n.mod(r+1,e.length);return[e[r],e[i]]},findIntersectionXY:c,findXYatLength:function(t,e,r,n){var i=-e*r,a=e*e+1,o=2*(e*i-r),s=i*i+r*r-t*t,l=Math.sqrt(o*o-4*a*s),c=(-o+l)/(2*a),u=(-o-l)/(2*a);return[[c,e*c+i+n],[u,e*u+i+n]]},clampTiny:h,pathPolygon:function(t,e,r,n,i,a){return\"M\"+f(u(t,e,r,n),i,a).join(\"L\")},pathPolygonAnnulus:function(t,e,r,n,i,a,o){var s,l;t<e?(s=t,l=e):(s=e,l=t);var c=f(u(s,r,n,i),a,o);return\"M\"+f(u(l,r,n,i),a,o).reverse().join(\"L\")+\"M\"+c.join(\"L\")}}},{\"../../lib\":719,\"../../lib/polygon\":731}],831:[function(t,e,r){\"use strict\";var n=t(\"../get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./polar\"),o=t(\"./constants\"),s=o.attr,l=o.name,c=i(l),u={};u[s]={valType:\"subplotid\",dflt:l,editType:\"calc\"},e.exports={attr:s,name:l,idRoot:l,idRegex:c,attrRegex:c,attributes:u,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[l],o=0;o<i.length;o++){var s=i[o],c=n(r,l,s),u=e[s]._subplot;u||(u=a(t,s),e[s]._subplot=u),u.plot(c,e,t._promises)}},clean:function(t,e,r,n){for(var i=n._subplots[l]||[],a=n._has&&n._has(\"gl\"),o=e._has&&e._has(\"gl\"),s=a&&!o,c=0;c<i.length;c++){var u=i[c],h=n[u]._subplot;if(!e[u]&&h)for(var f in h.framework.remove(),h.layers[\"radial-axis-title\"].remove(),h.clipPaths)h.clipPaths[f].remove();s&&h._scene&&(h._scene.destroy(),h._scene=null)}},toSVG:t(\"../cartesian\").toSVG}},{\"../../lib\":719,\"../cartesian\":778,\"../get_data\":802,\"./constants\":829,\"./layout_attributes\":832,\"./layout_defaults\":833,\"./polar\":840}],832:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../cartesian/layout_attributes\"),a=t(\"../domain\").attributes,o=t(\"../../lib\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=s({color:i.color,showline:o({},i.showline,{dflt:!0}),linecolor:i.linecolor,linewidth:i.linewidth,showgrid:o({},i.showgrid,{dflt:!0}),gridcolor:i.gridcolor,gridwidth:i.gridwidth},\"plot\",\"from-root\"),c=s({tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,showtickprefix:i.showtickprefix,tickprefix:i.tickprefix,showticksuffix:i.showticksuffix,ticksuffix:i.ticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,separatethousands:i.separatethousands,tickfont:i.tickfont,tickangle:i.tickangle,tickformat:i.tickformat,tickformatstops:i.tickformatstops,layer:i.layer},\"plot\",\"from-root\"),u={visible:o({},i.visible,{dflt:!0}),type:o({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autorange:o({},i.autorange,{editType:\"plot\"}),rangemode:{valType:\"enumerated\",values:[\"tozero\",\"nonnegative\",\"normal\"],dflt:\"tozero\",editType:\"calc\"},range:o({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],editType:\"plot\"}),categoryorder:i.categoryorder,categoryarray:i.categoryarray,angle:{valType:\"angle\",editType:\"plot\"},side:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"clockwise\",editType:\"plot\"},title:s(i.title,\"plot\",\"from-root\"),hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}};u.title.text.dflt=\"\",o(u,l,c);var h={visible:o({},i.visible,{dflt:!0}),type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"category\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},categoryorder:i.categoryorder,categoryarray:i.categoryarray,thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\"],dflt:\"degrees\",editType:\"calc\"},period:{valType:\"number\",editType:\"calc\",min:0},direction:{valType:\"enumerated\",values:[\"counterclockwise\",\"clockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"angle\",editType:\"calc\"},hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"};o(h,l,c),e.exports={domain:a({name:\"polar\",editType:\"plot\"}),sector:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],dflt:[0,360],editType:\"plot\"},hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},bgcolor:{valType:\"color\",editType:\"plot\",dflt:n.background},radialaxis:u,angularaxis:h,gridshape:{valType:\"enumerated\",values:[\"circular\",\"linear\"],dflt:\"circular\",editType:\"plot\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"}},{\"../../components/color/attributes\":592,\"../../lib\":719,\"../../plot_api/edit_types\":750,\"../cartesian/layout_attributes\":779,\"../domain\":792}],833:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../subplot_defaults\"),s=t(\"../get_data\").getSubplotData,l=t(\"../cartesian/tick_value_defaults\"),c=t(\"../cartesian/tick_mark_defaults\"),u=t(\"../cartesian/tick_label_defaults\"),h=t(\"../cartesian/category_order_defaults\"),f=t(\"../cartesian/line_grid_defaults\"),p=t(\"../cartesian/axis_autotype\"),d=t(\"./layout_attributes\"),g=t(\"./set_convert\"),v=t(\"./constants\"),m=v.axisNames;function y(t,e,r,o){var p=r(\"bgcolor\");o.bgColor=i.combine(p,o.paper_bgcolor);var y=r(\"sector\");r(\"hole\");var b,_=s(o.fullData,v.name,o.id),w=o.layoutOut;function k(t,e){return r(b+\".\"+t,e)}for(var T=0;T<m.length;T++){b=m[T],n.isPlainObject(t[b])||(t[b]={});var A=t[b],M=a.newContainer(e,b);M._id=M._name=b,M._attr=o.id+\".\"+b,M._traceIndices=_.map(function(t){return t._expandedIndex});var S=v.axisName2dataArray[b],E=x(A,M,k,_,S);h(A,M,k,{axData:_,dataAttr:S});var C,L,P=k(\"visible\");switch(g(M,e,w),k(\"uirevision\",e.uirevision),P&&(L=(C=k(\"color\"))===A.color?C:o.font.color),M._m=1,b){case\"radialaxis\":var O=k(\"autorange\",!M.isValidRange(A.range));A.autorange=O,!O||\"linear\"!==E&&\"-\"!==E||k(\"rangemode\"),\"reversed\"===O&&(M._m=-1),k(\"range\"),M.cleanRange(\"range\",{dfltRange:[0,1]}),P&&(k(\"side\"),k(\"angle\",y[0]),k(\"title.text\"),n.coerceFont(k,\"title.font\",{family:o.font.family,size:Math.round(1.2*o.font.size),color:L}));break;case\"angularaxis\":if(\"date\"===E){n.log(\"Polar plots do not support date angular axes yet.\");for(var z=0;z<_.length;z++)_[z].visible=!1;E=A.type=M.type=\"linear\"}k(\"linear\"===E?\"thetaunit\":\"period\");var I=k(\"direction\");k(\"rotation\",{counterclockwise:0,clockwise:90}[I])}if(P)l(A,M,k,M.type),u(A,M,k,M.type,{tickSuffixDflt:\"degrees\"===M.thetaunit?\"\\xb0\":void 0}),c(A,M,k,{outerTicks:!0}),k(\"showticklabels\")&&(n.coerceFont(k,\"tickfont\",{family:o.font.family,size:o.font.size,color:L}),k(\"tickangle\"),k(\"tickformat\")),f(A,M,k,{dfltColor:C,bgColor:o.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:d[b]}),k(\"layer\");\"category\"!==E&&k(\"hoverformat\"),M._input=A}\"category\"===e.angularaxis.type&&r(\"gridshape\")}function x(t,e,r,n,i){if(\"-\"===r(\"type\")){for(var a,o=0;o<n.length;o++)if(n[o].visible){a=n[o];break}a&&a[i]&&(e.type=p(a[i],\"gregorian\")),\"-\"===e.type?e.type=\"linear\":t.type=e.type}return e.type}e.exports=function(t,e,r){o(t,e,r,{type:v.name,attributes:d,handleDefaults:y,font:e.font,paper_bgcolor:e.paper_bgcolor,fullData:r,layoutOut:e})}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../cartesian/axis_autotype\":768,\"../cartesian/category_order_defaults\":771,\"../cartesian/line_grid_defaults\":781,\"../cartesian/tick_label_defaults\":786,\"../cartesian/tick_mark_defaults\":787,\"../cartesian/tick_value_defaults\":788,\"../get_data\":802,\"../subplot_defaults\":842,\"./constants\":829,\"./layout_attributes\":832,\"./set_convert\":841}],834:[function(t,e,r){\"use strict\";var n=t(\"../../../traces/scatter/attributes\"),i=n.marker,a=t(\"../../../lib/extend\").extendFlat;[\"Area traces are deprecated!\",\"Please switch to the *barpolar* trace type.\"].join(\" \");e.exports={r:a({},n.r,{}),t:a({},n.t,{}),marker:{color:a({},i.color,{}),size:a({},i.size,{}),symbol:a({},i.symbol,{}),opacity:a({},i.opacity,{}),editType:\"calc\"}}},{\"../../../lib/extend\":710,\"../../../traces/scatter/attributes\":1112}],835:[function(t,e,r){\"use strict\";var n=t(\"../../cartesian/layout_attributes\"),i=t(\"../../../lib/extend\").extendFlat,a=t(\"../../../plot_api/edit_types\").overrideAll,o=[\"Legacy polar charts are deprecated!\",\"Please switch to *polar* subplots.\"].join(\" \"),s=i({},n.domain,{});function l(t,e){return i({},e,{showline:{valType:\"boolean\"},showticklabels:{valType:\"boolean\"},tickorientation:{valType:\"enumerated\",values:[\"horizontal\",\"vertical\"]},ticklen:{valType:\"number\",min:0},tickcolor:{valType:\"color\"},ticksuffix:{valType:\"string\"},endpadding:{valType:\"number\",description:o},visible:{valType:\"boolean\"}})}e.exports=a({radialaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},domain:s,orientation:{valType:\"number\"}}),angularaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\",dflt:0},{valType:\"number\",dflt:360}]},domain:s}),layout:{direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"]},orientation:{valType:\"angle\"}}},\"plot\",\"nested\")},{\"../../../lib/extend\":710,\"../../../plot_api/edit_types\":750,\"../../cartesian/layout_attributes\":779}],836:[function(t,e,r){\"use strict\";(e.exports=t(\"./micropolar\")).manager=t(\"./micropolar_manager\")},{\"./micropolar\":837,\"./micropolar_manager\":838}],837:[function(t,e,r){var n=t(\"d3\"),i=t(\"../../../lib\").extendDeepAll,a=t(\"../../../constants/alignment\").MID_SHIFT,o=e.exports={version:\"0.2.2\"};o.Axis=function(){var t,e,r,s,l={data:[],layout:{}},c={},u={},h=n.dispatch(\"hover\"),f={};return f.render=function(c){return function(c){e=c||e;var h=l.data,f=l.layout;(\"string\"==typeof e||e.nodeName)&&(e=n.select(e)),e.datum(h).each(function(e,l){var c=e.slice();u={data:o.util.cloneJson(c),layout:o.util.cloneJson(f)};var h=0;c.forEach(function(t,e){t.color||(t.color=f.defaultColorRange[h],h=(h+1)%f.defaultColorRange.length),t.strokeColor||(t.strokeColor=\"LinePlot\"===t.geometry?t.color:n.rgb(t.color).darker().toString()),u.data[e].color=t.color,u.data[e].strokeColor=t.strokeColor,u.data[e].strokeDash=t.strokeDash,u.data[e].strokeSize=t.strokeSize});var p=c.filter(function(t,e){var r=t.visible;return\"undefined\"==typeof r||!0===r}),d=!1,g=p.map(function(t,e){return d=d||\"undefined\"!=typeof t.groupId,t});if(d){var v=n.nest().key(function(t,e){return\"undefined\"!=typeof t.groupId?t.groupId:\"unstacked\"}).entries(g),m=[],y=v.map(function(t,e){if(\"unstacked\"===t.key)return t.values;var r=t.values[0].r.map(function(t,e){return 0});return t.values.forEach(function(t,e,n){t.yStack=[r],m.push(r),r=o.util.sumArrays(t.r,r)}),t.values});p=n.merge(y)}p.forEach(function(t,e){t.t=Array.isArray(t.t[0])?t.t:[t.t],t.r=Array.isArray(t.r[0])?t.r:[t.r]});var x=Math.min(f.width-f.margin.left-f.margin.right,f.height-f.margin.top-f.margin.bottom)/2;x=Math.max(10,x);var b,_=[f.margin.left+x,f.margin.top+x];b=d?[0,n.max(o.util.sumArrays(o.util.arrayLast(p).r[0],o.util.arrayLast(m)))]:n.extent(o.util.flattenArray(p.map(function(t,e){return t.r}))),f.radialAxis.domain!=o.DATAEXTENT&&(b[0]=0),r=n.scale.linear().domain(f.radialAxis.domain!=o.DATAEXTENT&&f.radialAxis.domain?f.radialAxis.domain:b).range([0,x]),u.layout.radialAxis.domain=r.domain();var w,k=o.util.flattenArray(p.map(function(t,e){return t.t})),T=\"string\"==typeof k[0];T&&(k=o.util.deduplicate(k),w=k.slice(),k=n.range(k.length),p=p.map(function(t,e){var r=t;return t.t=[k],d&&(r.yStack=t.yStack),r}));var A=p.filter(function(t,e){return\"LinePlot\"===t.geometry||\"DotPlot\"===t.geometry}).length===p.length,M=null===f.needsEndSpacing?T||!A:f.needsEndSpacing,S=f.angularAxis.domain&&f.angularAxis.domain!=o.DATAEXTENT&&!T&&f.angularAxis.domain[0]>=0?f.angularAxis.domain:n.extent(k),E=Math.abs(k[1]-k[0]);A&&!T&&(E=0);var C=S.slice();M&&T&&(C[1]+=E);var L=f.angularAxis.ticksCount||4;L>8&&(L=L/(L/8)+L%8),f.angularAxis.ticksStep&&(L=(C[1]-C[0])/L);var P=f.angularAxis.ticksStep||(C[1]-C[0])/(L*(f.minorTicks+1));w&&(P=Math.max(Math.round(P),1)),C[2]||(C[2]=P);var O=n.range.apply(this,C);if(O=O.map(function(t,e){return parseFloat(t.toPrecision(12))}),s=n.scale.linear().domain(C.slice(0,2)).range(\"clockwise\"===f.direction?[0,360]:[360,0]),u.layout.angularAxis.domain=s.domain(),u.layout.angularAxis.endPadding=M?E:0,\"undefined\"==typeof(t=n.select(this).select(\"svg.chart-root\"))||t.empty()){var z=(new DOMParser).parseFromString(\"<svg xmlns='http://www.w3.org/2000/svg' class='chart-root'>' + '<g class='outer-group'>' + '<g class='chart-group'>' + '<circle class='background-circle'></circle>' + '<g class='geometry-group'></g>' + '<g class='radial axis-group'>' + '<circle class='outside-circle'></circle>' + '</g>' + '<g class='angular axis-group'></g>' + '<g class='guides-group'><line></line><circle r='0'></circle></g>' + '</g>' + '<g class='legend-group'></g>' + '<g class='tooltips-group'></g>' + '<g class='title-group'><text></text></g>' + '</g>' + '</svg>\",\"application/xml\"),I=this.appendChild(this.ownerDocument.importNode(z.documentElement,!0));t=n.select(I)}t.select(\".guides-group\").style({\"pointer-events\":\"none\"}),t.select(\".angular.axis-group\").style({\"pointer-events\":\"none\"}),t.select(\".radial.axis-group\").style({\"pointer-events\":\"none\"});var D,R=t.select(\".chart-group\"),F={fill:\"none\",stroke:f.tickColor},B={\"font-size\":f.font.size,\"font-family\":f.font.family,fill:f.font.color,\"text-shadow\":[\"-1px 0px\",\"1px -1px\",\"-1px 1px\",\"1px 1px\"].map(function(t,e){return\" \"+t+\" 0 \"+f.font.outlineColor}).join(\",\")};if(f.showLegend){D=t.select(\".legend-group\").attr({transform:\"translate(\"+[x,f.margin.top]+\")\"}).style({display:\"block\"});var N=p.map(function(t,e){var r=o.util.cloneJson(t);return r.symbol=\"DotPlot\"===t.geometry?t.dotType||\"circle\":\"LinePlot\"!=t.geometry?\"square\":\"line\",r.visibleInLegend=\"undefined\"==typeof t.visibleInLegend||t.visibleInLegend,r.color=\"LinePlot\"===t.geometry?t.strokeColor:t.color,r});o.Legend().config({data:p.map(function(t,e){return t.name||\"Element\"+e}),legendConfig:i({},o.Legend.defaultConfig().legendConfig,{container:D,elements:N,reverseOrder:f.legend.reverseOrder})})();var j=D.node().getBBox();x=Math.min(f.width-j.width-f.margin.left-f.margin.right,f.height-f.margin.top-f.margin.bottom)/2,x=Math.max(10,x),_=[f.margin.left+x,f.margin.top+x],r.range([0,x]),u.layout.radialAxis.domain=r.domain(),D.attr(\"transform\",\"translate(\"+[_[0]+x,_[1]-x]+\")\")}else D=t.select(\".legend-group\").style({display:\"none\"});t.attr({width:f.width,height:f.height}).style({opacity:f.opacity}),R.attr(\"transform\",\"translate(\"+_+\")\").style({cursor:\"crosshair\"});var U=[(f.width-(f.margin.left+f.margin.right+2*x+(j?j.width:0)))/2,(f.height-(f.margin.top+f.margin.bottom+2*x))/2];if(U[0]=Math.max(0,U[0]),U[1]=Math.max(0,U[1]),t.select(\".outer-group\").attr(\"transform\",\"translate(\"+U+\")\"),f.title&&f.title.text){var V=t.select(\"g.title-group text\").style(B).text(f.title.text),q=V.node().getBBox();V.attr({x:_[0]-q.width/2,y:_[1]-x-20})}var H=t.select(\".radial.axis-group\");if(f.radialAxis.gridLinesVisible){var G=H.selectAll(\"circle.grid-circle\").data(r.ticks(5));G.enter().append(\"circle\").attr({class:\"grid-circle\"}).style(F),G.attr(\"r\",r),G.exit().remove()}H.select(\"circle.outside-circle\").attr({r:x}).style(F);var Y=t.select(\"circle.background-circle\").attr({r:x}).style({fill:f.backgroundColor,stroke:f.stroke});function W(t,e){return s(t)%360+f.orientation}if(f.radialAxis.visible){var X=n.svg.axis().scale(r).ticks(5).tickSize(5);H.call(X).attr({transform:\"rotate(\"+f.radialAxis.orientation+\")\"}),H.selectAll(\".domain\").style(F),H.selectAll(\"g>text\").text(function(t,e){return this.textContent+f.radialAxis.ticksSuffix}).style(B).style({\"text-anchor\":\"start\"}).attr({x:0,y:0,dx:0,dy:0,transform:function(t,e){return\"horizontal\"===f.radialAxis.tickOrientation?\"rotate(\"+-f.radialAxis.orientation+\") translate(\"+[0,B[\"font-size\"]]+\")\":\"translate(\"+[0,B[\"font-size\"]]+\")\"}}),H.selectAll(\"g>line\").style({stroke:\"black\"})}var Z=t.select(\".angular.axis-group\").selectAll(\"g.angular-tick\").data(O),J=Z.enter().append(\"g\").classed(\"angular-tick\",!0);Z.attr({transform:function(t,e){return\"rotate(\"+W(t)+\")\"}}).style({display:f.angularAxis.visible?\"block\":\"none\"}),Z.exit().remove(),J.append(\"line\").classed(\"grid-line\",!0).classed(\"major\",function(t,e){return e%(f.minorTicks+1)==0}).classed(\"minor\",function(t,e){return!(e%(f.minorTicks+1)==0)}).style(F),J.selectAll(\".minor\").style({stroke:f.minorTickColor}),Z.select(\"line.grid-line\").attr({x1:f.tickLength?x-f.tickLength:0,x2:x}).style({display:f.angularAxis.gridLinesVisible?\"block\":\"none\"}),J.append(\"text\").classed(\"axis-text\",!0).style(B);var K=Z.select(\"text.axis-text\").attr({x:x+f.labelOffset,dy:a+\"em\",transform:function(t,e){var r=W(t),n=x+f.labelOffset,i=f.angularAxis.tickOrientation;return\"horizontal\"==i?\"rotate(\"+-r+\" \"+n+\" 0)\":\"radial\"==i?r<270&&r>90?\"rotate(180 \"+n+\" 0)\":null:\"rotate(\"+(r<=180&&r>0?-90:90)+\" \"+n+\" 0)\"}}).style({\"text-anchor\":\"middle\",display:f.angularAxis.labelsVisible?\"block\":\"none\"}).text(function(t,e){return e%(f.minorTicks+1)!=0?\"\":w?w[t]+f.angularAxis.ticksSuffix:t+f.angularAxis.ticksSuffix}).style(B);f.angularAxis.rewriteTicks&&K.text(function(t,e){return e%(f.minorTicks+1)!=0?\"\":f.angularAxis.rewriteTicks(this.textContent,e)});var $=n.max(R.selectAll(\".angular-tick text\")[0].map(function(t,e){return t.getCTM().e+t.getBBox().width}));D.attr({transform:\"translate(\"+[x+$,f.margin.top]+\")\"});var Q=t.select(\"g.geometry-group\").selectAll(\"g\").size()>0,tt=t.select(\"g.geometry-group\").selectAll(\"g.geometry\").data(p);if(tt.enter().append(\"g\").attr({class:function(t,e){return\"geometry geometry\"+e}}),tt.exit().remove(),p[0]||Q){var et=[];p.forEach(function(t,e){var n={};n.radialScale=r,n.angularScale=s,n.container=tt.filter(function(t,r){return r==e}),n.geometry=t.geometry,n.orientation=f.orientation,n.direction=f.direction,n.index=e,et.push({data:t,geometryConfig:n})});var rt=n.nest().key(function(t,e){return\"undefined\"!=typeof t.data.groupId||\"unstacked\"}).entries(et),nt=[];rt.forEach(function(t,e){\"unstacked\"===t.key?nt=nt.concat(t.values.map(function(t,e){return[t]})):nt.push(t.values)}),nt.forEach(function(t,e){var r;r=Array.isArray(t)?t[0].geometryConfig.geometry:t.geometryConfig.geometry;var n=t.map(function(t,e){return i(o[r].defaultConfig(),t)});o[r]().config(n)()})}var it,at,ot=t.select(\".guides-group\"),st=t.select(\".tooltips-group\"),lt=o.tooltipPanel().config({container:st,fontSize:8})(),ct=o.tooltipPanel().config({container:st,fontSize:8})(),ut=o.tooltipPanel().config({container:st,hasTick:!0})();if(!T){var ht=ot.select(\"line\").attr({x1:0,y1:0,y2:0}).style({stroke:\"grey\",\"pointer-events\":\"none\"});R.on(\"mousemove.angular-guide\",function(t,e){var r=o.util.getMousePos(Y).angle;ht.attr({x2:-x,transform:\"rotate(\"+r+\")\"}).style({opacity:.5});var n=(r+180+360-f.orientation)%360;it=s.invert(n);var i=o.util.convertToCartesian(x+12,r+180);lt.text(o.util.round(it)).move([i[0]+_[0],i[1]+_[1]])}).on(\"mouseout.angular-guide\",function(t,e){ot.select(\"line\").style({opacity:0})})}var ft=ot.select(\"circle\").style({stroke:\"grey\",fill:\"none\"});R.on(\"mousemove.radial-guide\",function(t,e){var n=o.util.getMousePos(Y).radius;ft.attr({r:n}).style({opacity:.5}),at=r.invert(o.util.getMousePos(Y).radius);var i=o.util.convertToCartesian(n,f.radialAxis.orientation);ct.text(o.util.round(at)).move([i[0]+_[0],i[1]+_[1]])}).on(\"mouseout.radial-guide\",function(t,e){ft.style({opacity:0}),ut.hide(),lt.hide(),ct.hide()}),t.selectAll(\".geometry-group .mark\").on(\"mouseover.tooltip\",function(e,r){var i=n.select(this),a=this.style.fill,s=\"black\",l=this.style.opacity||1;if(i.attr({\"data-opacity\":l}),a&&\"none\"!==a){i.attr({\"data-fill\":a}),s=n.hsl(a).darker().toString(),i.style({fill:s,opacity:1});var c={t:o.util.round(e[0]),r:o.util.round(e[1])};T&&(c.t=w[e[0]]);var u=\"t: \"+c.t+\", r: \"+c.r,h=this.getBoundingClientRect(),f=t.node().getBoundingClientRect(),p=[h.left+h.width/2-U[0]-f.left,h.top+h.height/2-U[1]-f.top];ut.config({color:s}).text(u),ut.move(p)}else a=this.style.stroke||\"black\",i.attr({\"data-stroke\":a}),s=n.hsl(a).darker().toString(),i.style({stroke:s,opacity:1})}).on(\"mousemove.tooltip\",function(t,e){if(0!=n.event.which)return!1;n.select(this).attr(\"data-fill\")&&ut.show()}).on(\"mouseout.tooltip\",function(t,e){ut.hide();var r=n.select(this),i=r.attr(\"data-fill\");i?r.style({fill:i,opacity:r.attr(\"data-opacity\")}):r.style({stroke:r.attr(\"data-stroke\"),opacity:r.attr(\"data-opacity\")})})})}(c),this},f.config=function(t){if(!arguments.length)return l;var e=o.util.cloneJson(t);return e.data.forEach(function(t,e){l.data[e]||(l.data[e]={}),i(l.data[e],o.Axis.defaultConfig().data[0]),i(l.data[e],t)}),i(l.layout,o.Axis.defaultConfig().layout),i(l.layout,e.layout),this},f.getLiveConfig=function(){return u},f.getinputConfig=function(){return c},f.radialScale=function(t){return r},f.angularScale=function(t){return s},f.svg=function(){return t},n.rebind(f,h,\"on\"),f},o.Axis.defaultConfig=function(t,e){return{data:[{t:[1,2,3,4],r:[10,11,12,13],name:\"Line1\",geometry:\"LinePlot\",color:null,strokeDash:\"solid\",strokeColor:null,strokeSize:\"1\",visibleInLegend:!0,opacity:1}],layout:{defaultColorRange:n.scale.category10().range(),title:null,height:450,width:500,margin:{top:40,right:40,bottom:40,left:40},font:{size:12,color:\"gray\",outlineColor:\"white\",family:\"Tahoma, sans-serif\"},direction:\"clockwise\",orientation:0,labelOffset:10,radialAxis:{domain:null,orientation:-45,ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null},angularAxis:{domain:[0,360],ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,labelsVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null,ticksCount:null,ticksStep:null},minorTicks:0,tickLength:null,tickColor:\"silver\",minorTickColor:\"#eee\",backgroundColor:\"none\",needsEndSpacing:null,showLegend:!0,legend:{reverseOrder:!1},opacity:1}}},o.util={},o.DATAEXTENT=\"dataExtent\",o.AREA=\"AreaChart\",o.LINE=\"LinePlot\",o.DOT=\"DotPlot\",o.BAR=\"BarChart\",o.util._override=function(t,e){for(var r in t)r in e&&(e[r]=t[r])},o.util._extend=function(t,e){for(var r in t)e[r]=t[r]},o.util._rndSnd=function(){return 2*Math.random()-1+(2*Math.random()-1)+(2*Math.random()-1)},o.util.dataFromEquation2=function(t,e){var r=e||6;return n.range(0,360+r,r).map(function(e,r){var n=e*Math.PI/180;return[e,t(n)]})},o.util.dataFromEquation=function(t,e,r){var i=e||6,a=[],o=[];n.range(0,360+i,i).forEach(function(e,r){var n=e*Math.PI/180,i=t(n);a.push(e),o.push(i)});var s={t:a,r:o};return r&&(s.name=r),s},o.util.ensureArray=function(t,e){if(\"undefined\"==typeof t)return null;var r=[].concat(t);return n.range(e).map(function(t,e){return r[e]||r[0]})},o.util.fillArrays=function(t,e,r){return e.forEach(function(e,n){t[e]=o.util.ensureArray(t[e],r)}),t},o.util.cloneJson=function(t){return JSON.parse(JSON.stringify(t))},o.util.validateKeys=function(t,e){\"string\"==typeof e&&(e=e.split(\".\"));var r=e.shift();return t[r]&&(!e.length||objHasKeys(t[r],e))},o.util.sumArrays=function(t,e){return n.zip(t,e).map(function(t,e){return n.sum(t)})},o.util.arrayLast=function(t){return t[t.length-1]},o.util.arrayEqual=function(t,e){for(var r=Math.max(t.length,e.length,1);r-- >=0&&t[r]===e[r];);return-2===r},o.util.flattenArray=function(t){for(var e=[];!o.util.arrayEqual(e,t);)e=t,t=[].concat.apply([],t);return t},o.util.deduplicate=function(t){return t.filter(function(t,e,r){return r.indexOf(t)==e})},o.util.convertToCartesian=function(t,e){var r=e*Math.PI/180;return[t*Math.cos(r),t*Math.sin(r)]},o.util.round=function(t,e){var r=e||2,n=Math.pow(10,r);return Math.round(t*n)/n},o.util.getMousePos=function(t){var e=n.mouse(t.node()),r=e[0],i=e[1],a={};return a.x=r,a.y=i,a.pos=e,a.angle=180*(Math.atan2(i,r)+Math.PI)/Math.PI,a.radius=Math.sqrt(r*r+i*i),a},o.util.duplicatesCount=function(t){for(var e,r={},n={},i=0,a=t.length;i<a;i++)(e=t[i])in r?(r[e]++,n[e]=r[e]):r[e]=1;return n},o.util.duplicates=function(t){return Object.keys(o.util.duplicatesCount(t))},o.util.translator=function(t,e,r,n){if(n){var i=r.slice();r=e,e=i}var a=e.reduce(function(t,e){if(\"undefined\"!=typeof t)return t[e]},t);\"undefined\"!=typeof a&&(e.reduce(function(t,r,n){if(\"undefined\"!=typeof t)return n===e.length-1&&delete t[r],t[r]},t),r.reduce(function(t,e,n){return\"undefined\"==typeof t[e]&&(t[e]={}),n===r.length-1&&(t[e]=a),t[e]},t))},o.PolyChart=function(){var t=[o.PolyChart.defaultConfig()],e=n.dispatch(\"hover\"),r={solid:\"none\",dash:[5,2],dot:[2,5]};function a(){var e=t[0].geometryConfig,i=e.container;\"string\"==typeof i&&(i=n.select(i)),i.datum(t).each(function(t,i){var a=!!t[0].data.yStack,o=t.map(function(t,e){return a?n.zip(t.data.t[0],t.data.r[0],t.data.yStack[0]):n.zip(t.data.t[0],t.data.r[0])}),s=e.angularScale,l=e.radialScale.domain()[0],c={bar:function(r,i,a){var o=t[a].data,l=e.radialScale(r[1])-e.radialScale(0),c=e.radialScale(r[2]||0),u=o.barWidth;n.select(this).attr({class:\"mark bar\",d:\"M\"+[[l+c,-u/2],[l+c,u/2],[c,u/2],[c,-u/2]].join(\"L\")+\"Z\",transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0]))+\")\"}})}};c.dot=function(r,i,a){var o=r[2]?[r[0],r[1]+r[2]]:r,s=n.svg.symbol().size(t[a].data.dotSize).type(t[a].data.dotType)(r,i);n.select(this).attr({class:\"mark dot\",d:s,transform:function(t,r){var n,i,a,s=(n=function(t,r){var n=e.radialScale(t[1]),i=(e.angularScale(t[0])+e.orientation)*Math.PI/180;return{r:n,t:i}}(o),i=n.r*Math.cos(n.t),a=n.r*Math.sin(n.t),{x:i,y:a});return\"translate(\"+[s.x,s.y]+\")\"}})};var u=n.svg.line.radial().interpolate(t[0].data.lineInterpolation).radius(function(t){return e.radialScale(t[1])}).angle(function(t){return e.angularScale(t[0])*Math.PI/180});c.line=function(r,i,a){var s=r[2]?o[a].map(function(t,e){return[t[0],t[1]+t[2]]}):o[a];if(n.select(this).each(c.dot).style({opacity:function(e,r){return+t[a].data.dotVisible},fill:d.stroke(r,i,a)}).attr({class:\"mark dot\"}),!(i>0)){var l=n.select(this.parentNode).selectAll(\"path.line\").data([0]);l.enter().insert(\"path\"),l.attr({class:\"line\",d:u(s),transform:function(t,r){return\"rotate(\"+(e.orientation+90)+\")\"},\"pointer-events\":\"none\"}).style({fill:function(t,e){return d.fill(r,i,a)},\"fill-opacity\":0,stroke:function(t,e){return d.stroke(r,i,a)},\"stroke-width\":function(t,e){return d[\"stroke-width\"](r,i,a)},\"stroke-dasharray\":function(t,e){return d[\"stroke-dasharray\"](r,i,a)},opacity:function(t,e){return d.opacity(r,i,a)},display:function(t,e){return d.display(r,i,a)}})}};var h=e.angularScale.range(),f=Math.abs(h[1]-h[0])/o[0].length*Math.PI/180,p=n.svg.arc().startAngle(function(t){return-f/2}).endAngle(function(t){return f/2}).innerRadius(function(t){return e.radialScale(l+(t[2]||0))}).outerRadius(function(t){return e.radialScale(l+(t[2]||0))+e.radialScale(t[1])});c.arc=function(t,r,i){n.select(this).attr({class:\"mark arc\",d:p,transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0])+90)+\")\"}})};var d={fill:function(e,r,n){return t[n].data.color},stroke:function(e,r,n){return t[n].data.strokeColor},\"stroke-width\":function(e,r,n){return t[n].data.strokeSize+\"px\"},\"stroke-dasharray\":function(e,n,i){return r[t[i].data.strokeDash]},opacity:function(e,r,n){return t[n].data.opacity},display:function(e,r,n){return\"undefined\"==typeof t[n].data.visible||t[n].data.visible?\"block\":\"none\"}},g=n.select(this).selectAll(\"g.layer\").data(o);g.enter().append(\"g\").attr({class:\"layer\"});var v=g.selectAll(\"path.mark\").data(function(t,e){return t});v.enter().append(\"path\").attr({class:\"mark\"}),v.style(d).each(c[e.geometryType]),v.exit().remove(),g.exit().remove()})}return a.config=function(e){return arguments.length?(e.forEach(function(e,r){t[r]||(t[r]={}),i(t[r],o.PolyChart.defaultConfig()),i(t[r],e)}),this):t},a.getColorScale=function(){},n.rebind(a,e,\"on\"),a},o.PolyChart.defaultConfig=function(){return{data:{name:\"geom1\",t:[[1,2,3,4]],r:[[1,2,3,4]],dotType:\"circle\",dotSize:64,dotVisible:!1,barWidth:20,color:\"#ffa500\",strokeSize:1,strokeColor:\"silver\",strokeDash:\"solid\",opacity:1,index:0,visible:!0,visibleInLegend:!0},geometryConfig:{geometry:\"LinePlot\",geometryType:\"arc\",direction:\"clockwise\",orientation:0,container:\"body\",radialScale:null,angularScale:null,colorScale:n.scale.category20()}}},o.BarChart=function(){return o.PolyChart()},o.BarChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"bar\"}}},o.AreaChart=function(){return o.PolyChart()},o.AreaChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"arc\"}}},o.DotPlot=function(){return o.PolyChart()},o.DotPlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"dot\",dotType:\"circle\"}}},o.LinePlot=function(){return o.PolyChart()},o.LinePlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"line\"}}},o.Legend=function(){var t=o.Legend.defaultConfig(),e=n.dispatch(\"hover\");function r(){var e=t.legendConfig,a=t.data.map(function(t,r){return[].concat(t).map(function(t,n){var a=i({},e.elements[r]);return a.name=t,a.color=[].concat(e.elements[r].color)[n],a})}),o=n.merge(a);o=o.filter(function(t,r){return e.elements[r]&&(e.elements[r].visibleInLegend||\"undefined\"==typeof e.elements[r].visibleInLegend)}),e.reverseOrder&&(o=o.reverse());var s=e.container;(\"string\"==typeof s||s.nodeName)&&(s=n.select(s));var l=o.map(function(t,e){return t.color}),c=e.fontSize,u=null==e.isContinuous?\"number\"==typeof o[0]:e.isContinuous,h=u?e.height:c*o.length,f=s.classed(\"legend-group\",!0).selectAll(\"svg\").data([0]),p=f.enter().append(\"svg\").attr({width:300,height:h+c,xmlns:\"http://www.w3.org/2000/svg\",\"xmlns:xlink\":\"http://www.w3.org/1999/xlink\",version:\"1.1\"});p.append(\"g\").classed(\"legend-axis\",!0),p.append(\"g\").classed(\"legend-marks\",!0);var d=n.range(o.length),g=n.scale[u?\"linear\":\"ordinal\"]().domain(d).range(l),v=n.scale[u?\"linear\":\"ordinal\"]().domain(d)[u?\"range\":\"rangePoints\"]([0,h]);if(u){var m=f.select(\".legend-marks\").append(\"defs\").append(\"linearGradient\").attr({id:\"grad1\",x1:\"0%\",y1:\"0%\",x2:\"0%\",y2:\"100%\"}).selectAll(\"stop\").data(l);m.enter().append(\"stop\"),m.attr({offset:function(t,e){return e/(l.length-1)*100+\"%\"}}).style({\"stop-color\":function(t,e){return t}}),f.append(\"rect\").classed(\"legend-mark\",!0).attr({height:e.height,width:e.colorBandWidth,fill:\"url(#grad1)\"})}else{var y=f.select(\".legend-marks\").selectAll(\"path.legend-mark\").data(o);y.enter().append(\"path\").classed(\"legend-mark\",!0),y.attr({transform:function(t,e){return\"translate(\"+[c/2,v(e)+c/2]+\")\"},d:function(t,e){var r,i,a,o=t.symbol;return a=3*(i=c),\"line\"===(r=o)?\"M\"+[[-i/2,-i/12],[i/2,-i/12],[i/2,i/12],[-i/2,i/12]]+\"Z\":-1!=n.svg.symbolTypes.indexOf(r)?n.svg.symbol().type(r).size(a)():n.svg.symbol().type(\"square\").size(a)()},fill:function(t,e){return g(e)}}),y.exit().remove()}var x=n.svg.axis().scale(v).orient(\"right\"),b=f.select(\"g.legend-axis\").attr({transform:\"translate(\"+[u?e.colorBandWidth:c,c/2]+\")\"}).call(x);return b.selectAll(\".domain\").style({fill:\"none\",stroke:\"none\"}),b.selectAll(\"line\").style({fill:\"none\",stroke:u?e.textColor:\"none\"}),b.selectAll(\"text\").style({fill:e.textColor,\"font-size\":e.fontSize}).text(function(t,e){return o[e].name}),r}return r.config=function(e){return arguments.length?(i(t,e),this):t},n.rebind(r,e,\"on\"),r},o.Legend.defaultConfig=function(t,e){return{data:[\"a\",\"b\",\"c\"],legendConfig:{elements:[{symbol:\"line\",color:\"red\"},{symbol:\"square\",color:\"yellow\"},{symbol:\"diamond\",color:\"limegreen\"}],height:150,colorBandWidth:30,fontSize:12,container:\"body\",isContinuous:null,textColor:\"grey\",reverseOrder:!1}}},o.tooltipPanel=function(){var t,e,r,a={container:null,hasTick:!1,fontSize:12,color:\"white\",padding:5},s=\"tooltip-\"+o.tooltipPanel.uid++,l=10,c=function(){var n=(t=a.container.selectAll(\"g.\"+s).data([0])).enter().append(\"g\").classed(s,!0).style({\"pointer-events\":\"none\",display:\"none\"});return r=n.append(\"path\").style({fill:\"white\",\"fill-opacity\":.9}).attr({d:\"M0 0\"}),e=n.append(\"text\").attr({dx:a.padding+l,dy:.3*+a.fontSize}),c};return c.text=function(i){var o=n.hsl(a.color).l,s=o>=.5?\"#aaa\":\"white\",u=o>=.5?\"black\":\"white\",h=i||\"\";e.style({fill:u,\"font-size\":a.fontSize+\"px\"}).text(h);var f=a.padding,p=e.node().getBBox(),d={fill:a.color,stroke:s,\"stroke-width\":\"2px\"},g=p.width+2*f+l,v=p.height+2*f;return r.attr({d:\"M\"+[[l,-v/2],[l,-v/4],[a.hasTick?0:l,0],[l,v/4],[l,v/2],[g,v/2],[g,-v/2]].join(\"L\")+\"Z\"}).style(d),t.attr({transform:\"translate(\"+[l,-v/2+2*f]+\")\"}),t.style({display:\"block\"}),c},c.move=function(e){if(t)return t.attr({transform:\"translate(\"+[e[0],e[1]]+\")\"}).style({display:\"block\"}),c},c.hide=function(){if(t)return t.style({display:\"none\"}),c},c.show=function(){if(t)return t.style({display:\"block\"}),c},c.config=function(t){return i(a,t),c},c},o.tooltipPanel.uid=1,o.adapter={},o.adapter.plotly=function(){var t={convert:function(t,e){var r={};if(t.data&&(r.data=t.data.map(function(t,r){var n=i({},t);return[[n,[\"marker\",\"color\"],[\"color\"]],[n,[\"marker\",\"opacity\"],[\"opacity\"]],[n,[\"marker\",\"line\",\"color\"],[\"strokeColor\"]],[n,[\"marker\",\"line\",\"dash\"],[\"strokeDash\"]],[n,[\"marker\",\"line\",\"width\"],[\"strokeSize\"]],[n,[\"marker\",\"symbol\"],[\"dotType\"]],[n,[\"marker\",\"size\"],[\"dotSize\"]],[n,[\"marker\",\"barWidth\"],[\"barWidth\"]],[n,[\"line\",\"interpolation\"],[\"lineInterpolation\"]],[n,[\"showlegend\"],[\"visibleInLegend\"]]].forEach(function(t,r){o.util.translator.apply(null,t.concat(e))}),e||delete n.marker,e&&delete n.groupId,e?(\"LinePlot\"===n.geometry?(n.type=\"scatter\",!0===n.dotVisible?(delete n.dotVisible,n.mode=\"lines+markers\"):n.mode=\"lines\"):\"DotPlot\"===n.geometry?(n.type=\"scatter\",n.mode=\"markers\"):\"AreaChart\"===n.geometry?n.type=\"area\":\"BarChart\"===n.geometry&&(n.type=\"bar\"),delete n.geometry):(\"scatter\"===n.type?\"lines\"===n.mode?n.geometry=\"LinePlot\":\"markers\"===n.mode?n.geometry=\"DotPlot\":\"lines+markers\"===n.mode&&(n.geometry=\"LinePlot\",n.dotVisible=!0):\"area\"===n.type?n.geometry=\"AreaChart\":\"bar\"===n.type&&(n.geometry=\"BarChart\"),delete n.mode,delete n.type),n}),!e&&t.layout&&\"stack\"===t.layout.barmode)){var a=o.util.duplicates(r.data.map(function(t,e){return t.geometry}));r.data.forEach(function(t,e){var n=a.indexOf(t.geometry);-1!=n&&(r.data[e].groupId=n)})}if(t.layout){var s=i({},t.layout);if([[s,[\"plot_bgcolor\"],[\"backgroundColor\"]],[s,[\"showlegend\"],[\"showLegend\"]],[s,[\"radialaxis\"],[\"radialAxis\"]],[s,[\"angularaxis\"],[\"angularAxis\"]],[s.angularaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularaxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularaxis,[\"nticks\"],[\"ticksCount\"]],[s.angularaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularaxis,[\"range\"],[\"domain\"]],[s.angularaxis,[\"endpadding\"],[\"endPadding\"]],[s.radialaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialaxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularAxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularAxis,[\"nticks\"],[\"ticksCount\"]],[s.angularAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularAxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"endpadding\"],[\"endPadding\"]],[s.radialAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialAxis,[\"range\"],[\"domain\"]],[s.font,[\"outlinecolor\"],[\"outlineColor\"]],[s.legend,[\"traceorder\"],[\"reverseOrder\"]],[s,[\"labeloffset\"],[\"labelOffset\"]],[s,[\"defaultcolorrange\"],[\"defaultColorRange\"]]].forEach(function(t,r){o.util.translator.apply(null,t.concat(e))}),e?(\"undefined\"!=typeof s.tickLength&&(s.angularaxis.ticklen=s.tickLength,delete s.tickLength),s.tickColor&&(s.angularaxis.tickcolor=s.tickColor,delete s.tickColor)):(s.angularAxis&&\"undefined\"!=typeof s.angularAxis.ticklen&&(s.tickLength=s.angularAxis.ticklen),s.angularAxis&&\"undefined\"!=typeof s.angularAxis.tickcolor&&(s.tickColor=s.angularAxis.tickcolor)),s.legend&&\"boolean\"!=typeof s.legend.reverseOrder&&(s.legend.reverseOrder=\"normal\"!=s.legend.reverseOrder),s.legend&&\"boolean\"==typeof s.legend.traceorder&&(s.legend.traceorder=s.legend.traceorder?\"reversed\":\"normal\",delete s.legend.reverseOrder),s.margin&&\"undefined\"!=typeof s.margin.t){var l=[\"t\",\"r\",\"b\",\"l\",\"pad\"],c=[\"top\",\"right\",\"bottom\",\"left\",\"pad\"],u={};n.entries(s.margin).forEach(function(t,e){u[c[l.indexOf(t.key)]]=t.value}),s.margin=u}e&&(delete s.needsEndSpacing,delete s.minorTickColor,delete s.minorTicks,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksStep,delete s.angularaxis.rewriteTicks,delete s.angularaxis.nticks,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksStep,delete s.radialaxis.rewriteTicks,delete s.radialaxis.nticks),r.layout=s}return r}};return t}},{\"../../../constants/alignment\":688,\"../../../lib\":719,d3:163}],838:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../../lib\"),a=t(\"../../../components/color\"),o=t(\"./micropolar\"),s=t(\"./undo_manager\"),l=i.extendDeepAll,c=e.exports={};c.framework=function(t){var e,r,i,a,u,h=new s;function f(r,s){return s&&(u=s),n.select(n.select(u).node().parentNode).selectAll(\".svg-container>*:not(.chart-root)\").remove(),e=e?l(e,r):r,i||(i=o.Axis()),a=o.adapter.plotly().convert(e),i.config(a).render(u),t.data=e.data,t.layout=e.layout,c.fillLayout(t),e}return f.isPolar=!0,f.svg=function(){return i.svg()},f.getConfig=function(){return e},f.getLiveConfig=function(){return o.adapter.plotly().convert(i.getLiveConfig(),!0)},f.getLiveScales=function(){return{t:i.angularScale(),r:i.radialScale()}},f.setUndoPoint=function(){var t,n,i=this,a=o.util.cloneJson(e);t=a,n=r,h.add({undo:function(){n&&i(n)},redo:function(){i(t)}}),r=o.util.cloneJson(a)},f.undo=function(){h.undo()},f.redo=function(){h.redo()},f},c.fillLayout=function(t){var e=n.select(t).selectAll(\".plot-container\"),r=e.selectAll(\".svg-container\"),i=t.framework&&t.framework.svg&&t.framework.svg(),o={width:800,height:600,paper_bgcolor:a.background,_container:e,_paperdiv:r,_paper:i};t._fullLayout=l(o,t.layout)}},{\"../../../components/color\":593,\"../../../lib\":719,\"./micropolar\":837,\"./undo_manager\":839,d3:163}],839:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=[],r=-1,n=!1;function i(t,e){return t?(n=!0,t[e](),n=!1,this):this}return{add:function(t){return n?this:(e.splice(r+1,e.length-r),e.push(t),r=e.length-1,this)},setCallback:function(e){t=e},undo:function(){var n=e[r];return n?(i(n,\"undo\"),r-=1,t&&t(n.undo),this):this},redo:function(){var n=e[r+1];return n?(i(n,\"redo\"),r+=1,t&&t(n.redo),this):this},clear:function(){e=[],r=-1},hasUndo:function(){return-1!==r},hasRedo:function(){return r<e.length-1},getCommands:function(){return e},getPreviousCommand:function(){return e[r-1]},getIndex:function(){return r}}}},{}],840:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../plots\"),u=t(\"../../plots/cartesian/axes\"),h=t(\"../cartesian/set_convert\"),f=t(\"./set_convert\"),p=t(\"../cartesian/autorange\").doAutoRange,d=t(\"../cartesian/dragbox\"),g=t(\"../../components/dragelement\"),v=t(\"../../components/fx\"),m=t(\"../../components/titles\"),y=t(\"../cartesian/select\").prepSelect,x=t(\"../cartesian/select\").selectOnClick,b=t(\"../cartesian/select\").clearSelect,_=t(\"../../lib/setcursor\"),w=t(\"../../lib/clear_gl_canvases\"),k=t(\"../../plot_api/subroutines\").redrawReglTraces,T=t(\"../../constants/alignment\").MID_SHIFT,A=t(\"./constants\"),M=t(\"./helpers\"),S=o._,E=o.mod,C=o.deg2rad,L=o.rad2deg;function P(t,e){this.id=e,this.gd=t,this._hasClipOnAxisFalse=null,this.vangles=null,this.radialAxisAngle=null,this.traceHash={},this.layers={},this.clipPaths={},this.clipIds={},this.viewInitial={};var r=t._fullLayout,n=\"clip\"+r._uid+e;this.clipIds.forTraces=n+\"-for-traces\",this.clipPaths.forTraces=r._clips.append(\"clipPath\").attr(\"id\",this.clipIds.forTraces),this.clipPaths.forTraces.append(\"path\"),this.framework=r._polarlayer.append(\"g\").attr(\"class\",e),this.radialTickLayout=null,this.angularTickLayout=null}var O=P.prototype;function z(t){var e=t.ticks+String(t.ticklen)+String(t.showticklabels);return\"side\"in t&&(e+=t.side),e}function I(t,e){return e[o.findIndexOfMin(e,function(e){return o.angleDist(t,e)})]}function D(t,e,r){return e?(t.attr(\"display\",null),t.attr(r)):t&&t.attr(\"display\",\"none\"),t}function R(t,e){return\"translate(\"+t+\",\"+e+\")\"}function F(t){return\"rotate(\"+t+\")\"}e.exports=function(t,e){return new P(t,e)},O.plot=function(t,e){var r=e[this.id];this._hasClipOnAxisFalse=!1;for(var n=0;n<t.length;n++){if(!1===t[n][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(e,r),this.updateLayout(e,r),c.generalUpdatePerTraceModule(this.gd,this,t,r),this.updateFx(e,r)},O.updateLayers=function(t,e){var r=this.layers,i=e.radialaxis,a=e.angularaxis,o=A.layerNames,s=o.indexOf(\"frontplot\"),l=o.slice(0,s),c=\"below traces\"===a.layer,u=\"below traces\"===i.layer;c&&l.push(\"angular-line\"),u&&l.push(\"radial-line\"),c&&l.push(\"angular-axis\"),u&&l.push(\"radial-axis\"),l.push(\"frontplot\"),c||l.push(\"angular-line\"),u||l.push(\"radial-line\"),c||l.push(\"angular-axis\"),u||l.push(\"radial-axis\");var h=this.framework.selectAll(\".polarsublayer\").data(l,String);h.enter().append(\"g\").attr(\"class\",function(t){return\"polarsublayer \"+t}).each(function(t){var e=r[t]=n.select(this);switch(t){case\"frontplot\":e.append(\"g\").classed(\"barlayer\",!0),e.append(\"g\").classed(\"scatterlayer\",!0);break;case\"backplot\":e.append(\"g\").classed(\"maplayer\",!0);break;case\"plotbg\":r.bg=e.append(\"path\");break;case\"radial-grid\":case\"angular-grid\":e.style(\"fill\",\"none\");break;case\"radial-line\":e.append(\"line\").style(\"fill\",\"none\");break;case\"angular-line\":e.append(\"path\").style(\"fill\",\"none\")}}),h.order()},O.updateLayout=function(t,e){var r=this.layers,n=t._size,i=e.radialaxis,a=e.angularaxis,o=e.domain.x,c=e.domain.y;this.xOffset=n.l+n.w*o[0],this.yOffset=n.t+n.h*(1-c[1]);var u=this.xLength=n.w*(o[1]-o[0]),h=this.yLength=n.h*(c[1]-c[0]),f=e.sector;this.sectorInRad=f.map(C);var p,d,g,v,m,y=this.sectorBBox=function(t){var e,r,n,i,a=t[0],o=t[1]-a,s=E(a,360),l=s+o,c=Math.cos(C(s)),u=Math.sin(C(s)),h=Math.cos(C(l)),f=Math.sin(C(l));i=s<=90&&l>=90||s>90&&l>=450?1:u<=0&&f<=0?0:Math.max(u,f);e=s<=180&&l>=180||s>180&&l>=540?-1:c>=0&&h>=0?0:Math.min(c,h);r=s<=270&&l>=270||s>270&&l>=630?-1:u>=0&&f>=0?0:Math.min(u,f);n=l>=360?1:c<=0&&h<=0?0:Math.max(c,h);return[e,r,n,i]}(f),x=y[2]-y[0],b=y[3]-y[1],_=h/u,w=Math.abs(b/x);_>w?(p=u,m=(h-(d=u*w))/n.h/2,g=[o[0],o[1]],v=[c[0]+m,c[1]-m]):(d=h,m=(u-(p=h/w))/n.w/2,g=[o[0]+m,o[1]-m],v=[c[0],c[1]]),this.xLength2=p,this.yLength2=d,this.xDomain2=g,this.yDomain2=v;var k=this.xOffset2=n.l+n.w*g[0],T=this.yOffset2=n.t+n.h*(1-v[1]),A=this.radius=p/x,M=this.innerRadius=e.hole*A,S=this.cx=k-A*y[0],L=this.cy=T+A*y[3],P=this.cxx=S-k,O=this.cyy=L-T;this.radialAxis=this.mockAxis(t,e,i,{_id:\"x\",side:{counterclockwise:\"top\",clockwise:\"bottom\"}[i.side],domain:[M/n.w,A/n.w]}),this.angularAxis=this.mockAxis(t,e,a,{side:\"right\",domain:[0,Math.PI],autorange:!1}),this.doAutoRange(t,e),this.updateAngularAxis(t,e),this.updateRadialAxis(t,e),this.updateRadialAxisTitle(t,e),this.xaxis=this.mockCartesianAxis(t,e,{_id:\"x\",domain:g}),this.yaxis=this.mockCartesianAxis(t,e,{_id:\"y\",domain:v});var z=this.pathSubplot();this.clipPaths.forTraces.select(\"path\").attr(\"d\",z).attr(\"transform\",R(P,O)),r.frontplot.attr(\"transform\",R(k,T)).call(l.setClipUrl,this._hasClipOnAxisFalse?null:this.clipIds.forTraces,this.gd),r.bg.attr(\"d\",z).attr(\"transform\",R(S,L)).call(s.fill,e.bgcolor)},O.mockAxis=function(t,e,r,n){var i=o.extendFlat({anchor:\"free\",position:0},r,n);return f(i,e,t),i},O.mockCartesianAxis=function(t,e,r){var n=this,i=r._id,a=o.extendFlat({type:\"linear\"},r);h(a,t);var s={x:[0,2],y:[1,3]};return a.setRange=function(){var t=n.sectorBBox,r=s[i],o=n.radialAxis._rl,l=(o[1]-o[0])/(1-e.hole);a.range=[t[r[0]]*l,t[r[1]]*l]},a.isPtWithinRange=\"x\"===i?function(t){return n.isPtInside(t)}:function(){return!0},a.setRange(),a.setScale(),a},O.doAutoRange=function(t,e){var r=this.gd,n=this.radialAxis,i=e.radialaxis;n.setScale(),p(r,n);var a=n.range;i.range=a.slice(),i._input.range=a.slice(),n._rl=[n.r2l(a[0],null,\"gregorian\"),n.r2l(a[1],null,\"gregorian\")]},O.updateRadialAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,l=r.innerRadius,c=r.cx,h=r.cy,f=e.radialaxis,p=E(e.sector[0],360),d=r.radialAxis,g=l<a;r.fillViewInitialKey(\"radialaxis.angle\",f.angle),r.fillViewInitialKey(\"radialaxis.range\",d.range.slice()),d.setGeometry(),\"auto\"===d.tickangle&&p>90&&p<=270&&(d.tickangle=180);var v=function(t){return\"translate(\"+(d.l2p(t.x)+l)+\",0)\"},m=z(f);if(r.radialTickLayout!==m&&(i[\"radial-axis\"].selectAll(\".xtick\").remove(),r.radialTickLayout=m),g){d.setScale();var y=u.calcTicks(d),x=u.clipEnds(d,y),b=u.getTickSigns(d)[2];u.drawTicks(n,d,{vals:y,layer:i[\"radial-axis\"],path:u.makeTickPath(d,0,b),transFn:v,crisp:!1}),u.drawGrid(n,d,{vals:x,layer:i[\"radial-grid\"],path:function(t){return r.pathArc(d.r2p(t.x)+l)},transFn:o.noop,crisp:!1}),u.drawLabels(n,d,{vals:y,layer:i[\"radial-axis\"],transFn:v,labelFns:u.makeLabelFns(d,0)})}var _=r.radialAxisAngle=r.vangles?L(I(C(f.angle),r.vangles)):f.angle,w=R(c,h),k=w+F(-_);D(i[\"radial-axis\"],g&&(f.showticklabels||f.ticks),{transform:k}),D(i[\"radial-grid\"],g&&f.showgrid,{transform:w}),D(i[\"radial-line\"].select(\"line\"),g&&f.showline,{x1:l,y1:0,x2:a,y2:0,transform:k}).attr(\"stroke-width\",f.linewidth).call(s.stroke,f.linecolor)},O.updateRadialAxisTitle=function(t,e,r){var n=this.gd,i=this.radius,a=this.cx,o=this.cy,s=e.radialaxis,c=this.id+\"title\",u=void 0!==r?r:this.radialAxisAngle,h=C(u),f=Math.cos(h),p=Math.sin(h),d=0;if(s.title){var g=l.bBox(this.layers[\"radial-axis\"].node()).height,v=s.title.font.size;d=\"counterclockwise\"===s.side?-g-.4*v:g+.8*v}this.layers[\"radial-axis-title\"]=m.draw(n,c,{propContainer:s,propName:this.id+\".radialaxis.title\",placeholder:S(n,\"Click to enter radial axis title\"),attributes:{x:a+i/2*f+d*p,y:o-i/2*p+d*f,\"text-anchor\":\"middle\"},transform:{rotate:-u}})},O.updateAngularAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,l=r.innerRadius,c=r.cx,h=r.cy,f=e.angularaxis,p=r.angularAxis;r.fillViewInitialKey(\"angularaxis.rotation\",f.rotation),p.setGeometry(),p.setScale();var d=function(t){return p.t2g(t.x)};\"linear\"===p.type&&\"radians\"===p.thetaunit&&(p.tick0=L(p.tick0),p.dtick=L(p.dtick));var g=function(t){return R(c+a*Math.cos(t),h-a*Math.sin(t))},v=u.makeLabelFns(p,0).labelStandoff,m={xFn:function(t){var e=d(t);return Math.cos(e)*v},yFn:function(t){var e=d(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(v+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*T)},anchorFn:function(t){var e=d(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},heightFn:function(t,e,r){var n=d(t);return-.5*(1+Math.sin(n))*r}},y=z(f);r.angularTickLayout!==y&&(i[\"angular-axis\"].selectAll(\".\"+p._id+\"tick\").remove(),r.angularTickLayout=y);var x,b=u.calcTicks(p);if(\"linear\"===e.gridshape?(x=b.map(d),o.angleDelta(x[0],x[1])<0&&(x=x.slice().reverse())):x=null,r.vangles=x,\"category\"===p.type&&(b=b.filter(function(t){return o.isAngleInsideSector(d(t),r.sectorInRad)})),p.visible){var _=\"inside\"===p.ticks?-1:1,w=(p.linewidth||1)/2;u.drawTicks(n,p,{vals:b,layer:i[\"angular-axis\"],path:\"M\"+_*w+\",0h\"+_*p.ticklen,transFn:function(t){var e=d(t);return g(e)+F(-L(e))},crisp:!1}),u.drawGrid(n,p,{vals:b,layer:i[\"angular-grid\"],path:function(t){var e=d(t),r=Math.cos(e),n=Math.sin(e);return\"M\"+[c+l*r,h-l*n]+\"L\"+[c+a*r,h-a*n]},transFn:o.noop,crisp:!1}),u.drawLabels(n,p,{vals:b,layer:i[\"angular-axis\"],repositionOnUpdate:!0,transFn:function(t){return g(d(t))},labelFns:m})}D(i[\"angular-line\"].select(\"path\"),f.showline,{d:r.pathSubplot(),transform:R(c,h)}).attr(\"stroke-width\",f.linewidth).call(s.stroke,f.linecolor)},O.updateFx=function(t,e){this.gd._context.staticPlot||(this.updateAngularDrag(t),this.updateRadialDrag(t,e,0),this.updateRadialDrag(t,e,1),this.updateMainDrag(t))},O.updateMainDrag=function(t){var e=this,r=e.gd,o=e.layers,s=t._zoomlayer,l=A.MINZOOM,c=A.OFFEDGE,u=e.radius,h=e.innerRadius,f=e.cx,p=e.cy,m=e.cxx,_=e.cyy,w=e.sectorInRad,k=e.vangles,T=e.radialAxis,S=M.clampTiny,E=M.findXYatLength,C=M.findEnclosingVertexAngles,L=A.cornerHalfWidth,P=A.cornerLen/2,O=d.makeDragger(o,\"path\",\"maindrag\",\"crosshair\");n.select(O).attr(\"d\",e.pathSubplot()).attr(\"transform\",R(f,p));var z,I,D,F,B,N,j,U,V,q={element:O,gd:r,subplot:e.id,plotinfo:{id:e.id,xaxis:e.xaxis,yaxis:e.yaxis},xaxes:[e.xaxis],yaxes:[e.yaxis]};function H(t,e){return Math.sqrt(t*t+e*e)}function G(t,e){return H(t-m,e-_)}function Y(t,e){return Math.atan2(_-e,t-m)}function W(t,e){return[t*Math.cos(e),t*Math.sin(-e)]}function X(t,r){if(0===t)return e.pathSector(2*L);var n=P/t,i=r-n,a=r+n,o=Math.max(0,Math.min(t,u)),s=o-L,l=o+L;return\"M\"+W(s,i)+\"A\"+[s,s]+\" 0,0,0 \"+W(s,a)+\"L\"+W(l,a)+\"A\"+[l,l]+\" 0,0,1 \"+W(l,i)+\"Z\"}function Z(t,r,n){if(0===t)return e.pathSector(2*L);var i,a,o=W(t,r),s=W(t,n),l=S((o[0]+s[0])/2),c=S((o[1]+s[1])/2);if(l&&c){var u=c/l,h=-1/u,f=E(L,u,l,c);i=E(P,h,f[0][0],f[0][1]),a=E(P,h,f[1][0],f[1][1])}else{var p,d;c?(p=P,d=L):(p=L,d=P),i=[[l-p,c-d],[l+p,c-d]],a=[[l-p,c+d],[l+p,c+d]]}return\"M\"+i.join(\"L\")+\"L\"+a.reverse().join(\"L\")+\"Z\"}function J(t,e){return e=Math.max(Math.min(e,u),h),t<c?t=0:u-t<c?t=u:e<c?e=0:u-e<c&&(e=u),Math.abs(e-t)>l?(t<e?(D=t,F=e):(D=e,F=t),!0):(D=null,F=null,!1)}function K(t,e){t=t||B,e=e||\"M0,0Z\",U.attr(\"d\",t),V.attr(\"d\",e),d.transitionZoombox(U,V,N,j),N=!0;var n={};rt(n),r.emit(\"plotly_relayouting\",n)}function $(t,r){var n,i,a=z+t,o=I+r,s=G(z,I),l=Math.min(G(a,o),u),c=Y(z,I);J(s,l)&&(n=B+e.pathSector(F),D&&(n+=e.pathSector(D)),i=X(D,c)+X(F,c)),K(n,i)}function Q(t,e,r,n){var i=M.findIntersectionXY(r,n,r,[t-m,_-e]);return H(i[0],i[1])}function tt(t,r){var n,i,a=z+t,o=I+r,s=Y(z,I),l=Y(a,o),c=C(s,k),h=C(l,k);J(Q(z,I,c[0],c[1]),Math.min(Q(a,o,h[0],h[1]),u))&&(n=B+e.pathSector(F),D&&(n+=e.pathSector(D)),i=[Z(D,c[0],c[1]),Z(F,c[0],c[1])].join(\" \")),K(n,i)}function et(){if(d.removeZoombox(r),null!==D&&null!==F){var t={};rt(t),d.showDoubleClickNotifier(r),a.call(\"_guiRelayout\",r,t)}}function rt(t){var r=T._rl,n=(r[1]-r[0])/(1-h/u)/u,i=[r[0]+(D-h)*n,r[0]+(F-h)*n];t[e.id+\".radialaxis.range\"]=i}function nt(t,n){var i=r._fullLayout.clickmode;if(d.removeZoombox(r),2===t){var o={};for(var s in e.viewInitial)o[e.id+\".\"+s]=e.viewInitial[s];r.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",r,o)}i.indexOf(\"select\")>-1&&1===t&&x(n,r,[e.xaxis],[e.yaxis],e.id,q),i.indexOf(\"event\")>-1&&v.click(r,n,e.id)}q.prepFn=function(t,n,a){var o=r._fullLayout.dragmode,l=O.getBoundingClientRect();if(z=n-l.left,I=a-l.top,k){var c=M.findPolygonOffset(u,w[0],w[1],k);z+=m+c[0],I+=_+c[1]}switch(o){case\"zoom\":q.moveFn=k?tt:$,q.clickFn=nt,q.doneFn=et,function(){D=null,F=null,B=e.pathSubplot(),N=!1;var t=r._fullLayout[e.id];j=i(t.bgcolor).getLuminance(),(U=d.makeZoombox(s,j,f,p,B)).attr(\"fill-rule\",\"evenodd\"),V=d.makeCorners(s,f,p),b(r)}();break;case\"select\":case\"lasso\":y(t,n,a,q,o)}},O.onmousemove=function(t){v.hover(r,t,e.id),r._fullLayout._lasthover=O,r._fullLayout._hoversubplot=e.id},O.onmouseout=function(t){r._dragging||g.unhover(r,t)},g.init(q)},O.updateRadialDrag=function(t,e,r){var i=this,s=i.gd,l=i.layers,c=i.radius,u=i.innerRadius,h=i.cx,f=i.cy,p=i.radialAxis,v=A.radialDragBoxSize,m=v/2;if(p.visible){var y,x,_,T=C(i.radialAxisAngle),M=p._rl,S=M[0],E=M[1],P=M[r],O=.75*(M[1]-M[0])/(1-e.hole)/c;r?(y=h+(c+m)*Math.cos(T),x=f-(c+m)*Math.sin(T),_=\"radialdrag\"):(y=h+(u-m)*Math.cos(T),x=f-(u-m)*Math.sin(T),_=\"radialdrag-inner\");var z,B,N,j=d.makeRectDragger(l,_,\"crosshair\",-m,-m,v,v),U={element:j,gd:s};D(n.select(j),p.visible&&u<c,{transform:R(y,x)}),U.prepFn=function(){z=null,B=null,N=null,U.moveFn=V,U.doneFn=q,b(s)},U.clampFn=function(t,e){return Math.sqrt(t*t+e*e)<A.MINDRAG&&(t=0,e=0),[t,e]},g.init(U)}function V(t,e){if(z)z(t,e);else{var n=[t,-e],a=[Math.cos(T),Math.sin(T)],l=Math.abs(o.dot(n,a)/Math.sqrt(o.dot(n,n)));isNaN(l)||(z=l<.5?H:G)}var c={};!function(t){null!==B?t[i.id+\".radialaxis.angle\"]=B:null!==N&&(t[i.id+\".radialaxis.range[\"+r+\"]\"]=N)}(c),s.emit(\"plotly_relayouting\",c)}function q(){null!==B?a.call(\"_guiRelayout\",s,i.id+\".radialaxis.angle\",B):null!==N&&a.call(\"_guiRelayout\",s,i.id+\".radialaxis.range[\"+r+\"]\",N)}function H(t,e){if(0!==r){var n=y+t,a=x+e;B=Math.atan2(f-a,n-h),i.vangles&&(B=I(B,i.vangles)),B=L(B);var o=R(h,f)+F(-B);l[\"radial-axis\"].attr(\"transform\",o),l[\"radial-line\"].select(\"line\").attr(\"transform\",o);var s=i.gd._fullLayout,c=s[i.id];i.updateRadialAxisTitle(s,c,B)}}function G(t,e){var n=o.dot([t,-e],[Math.cos(T),Math.sin(T)]);if(N=P-O*n,O>0==(r?N>S:N<E)){var l=s._fullLayout,c=l[i.id];p.range[r]=N,p._rl[r]=N,i.updateRadialAxis(l,c),i.xaxis.setRange(),i.xaxis.setScale(),i.yaxis.setRange(),i.yaxis.setScale();var u=!1;for(var h in i.traceHash){var f=i.traceHash[h],d=o.filterVisible(f);f[0][0].trace._module.plot(s,i,d,c),a.traceIs(h,\"gl\")&&d.length&&(u=!0)}u&&(w(s),k(s))}else N=null}},O.updateAngularDrag=function(t){var e=this,r=e.gd,i=e.layers,s=e.radius,c=e.angularAxis,u=e.cx,h=e.cy,f=e.cxx,p=e.cyy,v=A.angularDragBoxSize,m=d.makeDragger(i,\"path\",\"angulardrag\",\"move\"),y={element:m,gd:r};function x(t,e){return Math.atan2(p+v-e,t-f-v)}n.select(m).attr(\"d\",e.pathAnnulus(s,s+v)).attr(\"transform\",R(u,h)).call(_,\"move\");var T,M,S,E,C,P,O=i.frontplot.select(\".scatterlayer\").selectAll(\".trace\"),z=O.selectAll(\".point\"),I=O.selectAll(\".textpoint\");function D(t,s){var d=e.gd._fullLayout,g=d[e.id],v=x(T+t,M+s),m=L(v-P);if(E=S+m,i.frontplot.attr(\"transform\",R(e.xOffset2,e.yOffset2)+F([-m,f,p])),e.vangles){C=e.radialAxisAngle+m;var y=R(u,h)+F(-m),b=R(u,h)+F(-C);i.bg.attr(\"transform\",y),i[\"radial-grid\"].attr(\"transform\",y),i[\"radial-axis\"].attr(\"transform\",b),i[\"radial-line\"].select(\"line\").attr(\"transform\",b),e.updateRadialAxisTitle(d,g,C)}else e.clipPaths.forTraces.select(\"path\").attr(\"transform\",R(f,p)+F(m));z.each(function(){var t=n.select(this),e=l.getTranslate(t);t.attr(\"transform\",R(e.x,e.y)+F([m]))}),I.each(function(){var t=n.select(this),e=t.select(\"text\"),r=l.getTranslate(t);t.attr(\"transform\",F([m,e.attr(\"x\"),e.attr(\"y\")])+R(r.x,r.y))}),c.rotation=o.modHalf(E,360),e.updateAngularAxis(d,g),e._hasClipOnAxisFalse&&!o.isFullCircle(e.sectorInRad)&&O.call(l.hideOutsideRangePoints,e);var _=!1;for(var A in e.traceHash)if(a.traceIs(A,\"gl\")){var D=e.traceHash[A],N=o.filterVisible(D);D[0][0].trace._module.plot(r,e,N,g),N.length&&(_=!0)}_&&(w(r),k(r));var j={};B(j),r.emit(\"plotly_relayouting\",j)}function B(t){t[e.id+\".angularaxis.rotation\"]=E,e.vangles&&(t[e.id+\".radialaxis.angle\"]=C)}function N(){I.select(\"text\").attr(\"transform\",null);var t={};B(t),a.call(\"_guiRelayout\",r,t)}y.prepFn=function(n,i,a){var o=t[e.id];S=o.angularaxis.rotation;var s=m.getBoundingClientRect();T=i-s.left,M=a-s.top,P=x(T,M),y.moveFn=D,y.doneFn=N,b(r)},e.vangles&&!o.isFullCircle(e.sectorInRad)&&(y.prepFn=o.noop,_(n.select(m),null)),g.init(y)},O.isPtInside=function(t){var e=this.sectorInRad,r=this.vangles,n=this.angularAxis.c2g(t.theta),i=this.radialAxis,a=i.c2l(t.r),s=i._rl;return(r?M.isPtInsidePolygon:o.isPtInsideSector)(a,n,s,e,r)},O.pathArc=function(t){var e=this.sectorInRad,r=this.vangles;return(r?M.pathPolygon:o.pathArc)(t,e[0],e[1],r)},O.pathSector=function(t){var e=this.sectorInRad,r=this.vangles;return(r?M.pathPolygon:o.pathSector)(t,e[0],e[1],r)},O.pathAnnulus=function(t,e){var r=this.sectorInRad,n=this.vangles;return(n?M.pathPolygonAnnulus:o.pathAnnulus)(t,e,r[0],r[1],n)},O.pathSubplot=function(){var t=this.innerRadius,e=this.radius;return t?this.pathAnnulus(t,e):this.pathSector(e)},O.fillViewInitialKey=function(t,e){t in this.viewInitial||(this.viewInitial[t]=e)}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../components/titles\":681,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/clear_gl_canvases\":704,\"../../lib/setcursor\":739,\"../../plot_api/subroutines\":758,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../cartesian/autorange\":766,\"../cartesian/dragbox\":775,\"../cartesian/select\":784,\"../cartesian/set_convert\":785,\"../plots\":828,\"./constants\":829,\"./helpers\":830,\"./set_convert\":841,d3:163,tinycolor2:537}],841:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../cartesian/set_convert\"),a=n.deg2rad,o=n.rad2deg;e.exports=function(t,e,r){switch(i(t,r),t._id){case\"x\":case\"radialaxis\":!function(t,e){var r=e._subplot;t.setGeometry=function(){var e=t._rl[0],n=t._rl[1],i=r.innerRadius,a=(r.radius-i)/(n-e),o=i/a,s=e>n?function(t){return t<=0}:function(t){return t>=0};t.c2g=function(r){var n=t.c2l(r)-e;return(s(n)?n:0)+o},t.g2c=function(r){return t.l2c(r+e-o)},t.g2p=function(t){return t*a},t.c2p=function(e){return t.g2p(t.c2g(e))}}}(t,e);break;case\"angularaxis\":!function(t,e){var r=t.type;if(\"linear\"===r){var i=t.d2c,s=t.c2d;t.d2c=function(t,e){return function(t,e){return\"degrees\"===e?a(t):t}(i(t),e)},t.c2d=function(t,e){return s(function(t,e){return\"degrees\"===e?o(t):t}(t,e))}}t.makeCalcdata=function(e,i){var a,o,s=e[i],l=e._length,c=function(r){return t.d2c(r,e.thetaunit)};if(s){if(n.isTypedArray(s)&&\"linear\"===r){if(l===s.length)return s;if(s.subarray)return s.subarray(0,l)}for(a=new Array(l),o=0;o<l;o++)a[o]=c(s[o])}else{var u=i+\"0\",h=\"d\"+i,f=u in e?c(e[u]):0,p=e[h]?c(e[h]):(t.period||2*Math.PI)/l;for(a=new Array(l),o=0;o<l;o++)a[o]=f+o*p}return a},t.setGeometry=function(){var i,s,l,c,u=e.sector,h=u.map(a),f={clockwise:-1,counterclockwise:1}[t.direction],p=a(t.rotation),d=function(t){return f*t+p},g=function(t){return(t-p)/f};switch(r){case\"linear\":s=i=n.identity,c=a,l=o,t.range=n.isFullCircle(h)?[u[0],u[0]+360]:h.map(g).map(o);break;case\"category\":var v=t._categories.length,m=t.period?Math.max(t.period,v):v;0===m&&(m=1),s=c=function(t){return 2*t*Math.PI/m},i=l=function(t){return t*m/Math.PI/2},t.range=[0,m]}t.c2g=function(t){return d(s(t))},t.g2c=function(t){return i(g(t))},t.t2g=function(t){return d(c(t))},t.g2t=function(t){return l(g(t))}}}(t,e)}}},{\"../../lib\":719,\"../cartesian/set_convert\":785}],842:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\"),a=t(\"./domain\").defaults;e.exports=function(t,e,r,o){var s,l,c=o.type,u=o.attributes,h=o.handleDefaults,f=o.partition||\"x\",p=e._subplots[c],d=p.length,g=d&&p[0].replace(/\\d+$/,\"\");function v(t,e){return n.coerce(s,l,u,t,e)}for(var m=0;m<d;m++){var y=p[m];s=t[y]?t[y]:t[y]={},l=i.newContainer(e,y,g),v(\"uirevision\",e.uirevision);var x={};x[f]=[m/d,(m+1)/d],a(l,e,v,x),o.id=y,h(s,l,v,o)}}},{\"../lib\":719,\"../plot_api/plot_template\":757,\"./domain\":792}],843:[function(t,e,r){\"use strict\";var n=t(\"./ternary\"),i=t(\"../../plots/get_data\").getSubplotCalcData,a=t(\"../../lib\").counterRegex;r.name=\"ternary\";var o=r.attr=\"subplot\";r.idRoot=\"ternary\",r.idRegex=r.attrRegex=a(\"ternary\"),(r.attributes={})[o]={valType:\"subplotid\",dflt:\"ternary\",editType:\"calc\"},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t.calcdata,a=e._subplots.ternary,o=0;o<a.length;o++){var s=a[o],l=i(r,\"ternary\",s),c=e[s]._subplot;c||(c=new n({id:s,graphDiv:t,container:e._ternarylayer.node()},e),e[s]._subplot=c),c.plot(l,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.ternary||[],a=0;a<i.length;a++){var o=i[a],s=n[o]._subplot;!e[o]&&s&&(s.plotContainer.remove(),s.clipDef.remove(),s.clipDefRelative.remove(),s.layers[\"a-title\"].remove(),s.layers[\"b-title\"].remove(),s.layers[\"c-title\"].remove())}}},{\"../../lib\":719,\"../../plots/get_data\":802,\"./layout_attributes\":844,\"./layout_defaults\":845,\"./ternary\":846}],844:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"../cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../lib/extend\").extendFlat,l={title:a.title,color:a.color,tickmode:a.tickmode,nticks:s({},a.nticks,{dflt:6,min:1}),tick0:a.tick0,dtick:a.dtick,tickvals:a.tickvals,ticktext:a.ticktext,ticks:a.ticks,ticklen:a.ticklen,tickwidth:a.tickwidth,tickcolor:a.tickcolor,showticklabels:a.showticklabels,showtickprefix:a.showtickprefix,tickprefix:a.tickprefix,showticksuffix:a.showticksuffix,ticksuffix:a.ticksuffix,showexponent:a.showexponent,exponentformat:a.exponentformat,separatethousands:a.separatethousands,tickfont:a.tickfont,tickangle:a.tickangle,tickformat:a.tickformat,tickformatstops:a.tickformatstops,hoverformat:a.hoverformat,showline:s({},a.showline,{dflt:!0}),linecolor:a.linecolor,linewidth:a.linewidth,showgrid:s({},a.showgrid,{dflt:!0}),gridcolor:a.gridcolor,gridwidth:a.gridwidth,layer:a.layer,min:{valType:\"number\",dflt:0,min:0},_deprecated:{title:a._deprecated.title,titlefont:a._deprecated.titlefont}},c=e.exports=o({domain:i({name:\"ternary\"}),bgcolor:{valType:\"color\",dflt:n.background},sum:{valType:\"number\",dflt:1,min:0},aaxis:l,baxis:l,caxis:l},\"plot\",\"from-root\");c.uirevision={valType:\"any\",editType:\"none\"},c.aaxis.uirevision=c.baxis.uirevision=c.caxis.uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":592,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../cartesian/layout_attributes\":779,\"../domain\":792}],845:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../lib\"),o=t(\"../subplot_defaults\"),s=t(\"../cartesian/tick_label_defaults\"),l=t(\"../cartesian/tick_mark_defaults\"),c=t(\"../cartesian/tick_value_defaults\"),u=t(\"../cartesian/line_grid_defaults\"),h=t(\"./layout_attributes\"),f=[\"aaxis\",\"baxis\",\"caxis\"];function p(t,e,r,a){var o,s,l,c=r(\"bgcolor\"),u=r(\"sum\");a.bgColor=n.combine(c,a.paper_bgcolor);for(var h=0;h<f.length;h++)s=t[o=f[h]]||{},(l=i.newContainer(e,o))._name=o,d(s,l,a,e);var p=e.aaxis,g=e.baxis,v=e.caxis;p.min+g.min+v.min>=u&&(p.min=0,g.min=0,v.min=0,t.aaxis&&delete t.aaxis.min,t.baxis&&delete t.baxis.min,t.caxis&&delete t.caxis.min)}function d(t,e,r,n){var i=h[e._name];function o(r,n){return a.coerce(t,e,i,r,n)}o(\"uirevision\",n.uirevision),e.type=\"linear\";var f=o(\"color\"),p=f!==i.color.dflt?f:r.font.color,d=e._name.charAt(0).toUpperCase(),g=\"Component \"+d,v=o(\"title.text\",g);e._hovertitle=v===g?v:d,a.coerceFont(o,\"title.font\",{family:r.font.family,size:Math.round(1.2*r.font.size),color:p}),o(\"min\"),c(t,e,o,\"linear\"),s(t,e,o,\"linear\",{}),l(t,e,o,{outerTicks:!0}),o(\"showticklabels\")&&(a.coerceFont(o,\"tickfont\",{family:r.font.family,size:r.font.size,color:p}),o(\"tickangle\"),o(\"tickformat\")),u(t,e,o,{dfltColor:f,bgColor:r.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:i}),o(\"hoverformat\"),o(\"layer\")}e.exports=function(t,e,r){o(t,e,r,{type:\"ternary\",attributes:h,handleDefaults:p,font:e.font,paper_bgcolor:e.paper_bgcolor})}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../cartesian/line_grid_defaults\":781,\"../cartesian/tick_label_defaults\":786,\"../cartesian/tick_mark_defaults\":787,\"../cartesian/tick_value_defaults\":788,\"../subplot_defaults\":842,\"./layout_attributes\":844}],846:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=o._,l=t(\"../../components/color\"),c=t(\"../../components/drawing\"),u=t(\"../cartesian/set_convert\"),h=t(\"../../lib/extend\").extendFlat,f=t(\"../plots\"),p=t(\"../cartesian/axes\"),d=t(\"../../components/dragelement\"),g=t(\"../../components/fx\"),v=t(\"../../components/titles\"),m=t(\"../cartesian/select\").prepSelect,y=t(\"../cartesian/select\").selectOnClick,x=t(\"../cartesian/select\").clearSelect,b=t(\"../cartesian/constants\");function _(t,e){this.id=t.id,this.graphDiv=t.graphDiv,this.init(e),this.makeFramework(e),this.aTickLayout=null,this.bTickLayout=null,this.cTickLayout=null}e.exports=_;var w=_.prototype;w.init=function(t){this.container=t._ternarylayer,this.defs=t._defs,this.layoutId=t._uid,this.traceHash={},this.layers={}},w.plot=function(t,e){var r=e[this.id],n=e._size;this._hasClipOnAxisFalse=!1;for(var i=0;i<t.length;i++){if(!1===t[i][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(r),this.adjustLayout(r,n),f.generalUpdatePerTraceModule(this.graphDiv,this,t,r),this.layers.plotbg.select(\"path\").call(l.fill,r.bgcolor)},w.makeFramework=function(t){var e=this.graphDiv,r=t[this.id],n=this.clipId=\"clip\"+this.layoutId+this.id,i=this.clipIdRelative=\"clip-relative\"+this.layoutId+this.id;this.clipDef=o.ensureSingleById(t._clips,\"clipPath\",n,function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")}),this.clipDefRelative=o.ensureSingleById(t._clips,\"clipPath\",i,function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")}),this.plotContainer=o.ensureSingle(this.container,\"g\",this.id),this.updateLayers(r),c.setClipUrl(this.layers.backplot,n,e),c.setClipUrl(this.layers.grids,n,e)},w.updateLayers=function(t){var e=this.layers,r=[\"draglayer\",\"plotbg\",\"backplot\",\"grids\"];\"below traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"below traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"below traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\"),r.push(\"frontplot\"),\"above traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"above traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"above traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\");var i=this.plotContainer.selectAll(\"g.toplevel\").data(r,String),a=[\"agrid\",\"bgrid\",\"cgrid\"];i.enter().append(\"g\").attr(\"class\",function(t){return\"toplevel \"+t}).each(function(t){var r=n.select(this);e[t]=r,\"frontplot\"===t?r.append(\"g\").classed(\"scatterlayer\",!0):\"backplot\"===t?r.append(\"g\").classed(\"maplayer\",!0):\"plotbg\"===t?r.append(\"path\").attr(\"d\",\"M0,0Z\"):\"aline\"===t||\"bline\"===t||\"cline\"===t?r.append(\"path\"):\"grids\"===t&&a.forEach(function(t){e[t]=r.append(\"g\").classed(\"grid \"+t,!0)})}),i.order()};var k=Math.sqrt(4/3);w.adjustLayout=function(t,e){var r,n,i,a,o,s,f=this,p=t.domain,d=(p.x[0]+p.x[1])/2,g=(p.y[0]+p.y[1])/2,v=p.x[1]-p.x[0],m=p.y[1]-p.y[0],y=v*e.w,x=m*e.h,b=t.sum,_=t.aaxis.min,w=t.baxis.min,T=t.caxis.min;y>k*x?i=(a=x)*k:a=(i=y)/k,o=v*i/y,s=m*a/x,r=e.l+e.w*d-i/2,n=e.t+e.h*(1-g)-a/2,f.x0=r,f.y0=n,f.w=i,f.h=a,f.sum=b,f.xaxis={type:\"linear\",range:[_+2*T-b,b-_-2*w],domain:[d-o/2,d+o/2],_id:\"x\"},u(f.xaxis,f.graphDiv._fullLayout),f.xaxis.setScale(),f.xaxis.isPtWithinRange=function(t){return t.a>=f.aaxis.range[0]&&t.a<=f.aaxis.range[1]&&t.b>=f.baxis.range[1]&&t.b<=f.baxis.range[0]&&t.c>=f.caxis.range[1]&&t.c<=f.caxis.range[0]},f.yaxis={type:\"linear\",range:[_,b-w-T],domain:[g-s/2,g+s/2],_id:\"y\"},u(f.yaxis,f.graphDiv._fullLayout),f.yaxis.setScale(),f.yaxis.isPtWithinRange=function(){return!0};var A=f.yaxis.domain[0],M=f.aaxis=h({},t.aaxis,{range:[_,b-w-T],side:\"left\",tickangle:(+t.aaxis.tickangle||0)-30,domain:[A,A+s*k],anchor:\"free\",position:0,_id:\"y\",_length:i});u(M,f.graphDiv._fullLayout),M.setScale();var S=f.baxis=h({},t.baxis,{range:[b-_-T,w],side:\"bottom\",domain:f.xaxis.domain,anchor:\"free\",position:0,_id:\"x\",_length:i});u(S,f.graphDiv._fullLayout),S.setScale();var E=f.caxis=h({},t.caxis,{range:[b-_-w,T],side:\"right\",tickangle:(+t.caxis.tickangle||0)+30,domain:[A,A+s*k],anchor:\"free\",position:0,_id:\"y\",_length:i});u(E,f.graphDiv._fullLayout),E.setScale();var C=\"M\"+r+\",\"+(n+a)+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";f.clipDef.select(\"path\").attr(\"d\",C),f.layers.plotbg.select(\"path\").attr(\"d\",C);var L=\"M0,\"+a+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";f.clipDefRelative.select(\"path\").attr(\"d\",L);var P=\"translate(\"+r+\",\"+n+\")\";f.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",P),f.clipDefRelative.select(\"path\").attr(\"transform\",null);var O=\"translate(\"+(r-S._offset)+\",\"+(n+a)+\")\";f.layers.baxis.attr(\"transform\",O),f.layers.bgrid.attr(\"transform\",O);var z=\"translate(\"+(r+i/2)+\",\"+n+\")rotate(30)translate(0,\"+-M._offset+\")\";f.layers.aaxis.attr(\"transform\",z),f.layers.agrid.attr(\"transform\",z);var I=\"translate(\"+(r+i/2)+\",\"+n+\")rotate(-30)translate(0,\"+-E._offset+\")\";f.layers.caxis.attr(\"transform\",I),f.layers.cgrid.attr(\"transform\",I),f.drawAxes(!0),f.layers.aline.select(\"path\").attr(\"d\",M.showline?\"M\"+r+\",\"+(n+a)+\"l\"+i/2+\",-\"+a:\"M0,0\").call(l.stroke,M.linecolor||\"#000\").style(\"stroke-width\",(M.linewidth||0)+\"px\"),f.layers.bline.select(\"path\").attr(\"d\",S.showline?\"M\"+r+\",\"+(n+a)+\"h\"+i:\"M0,0\").call(l.stroke,S.linecolor||\"#000\").style(\"stroke-width\",(S.linewidth||0)+\"px\"),f.layers.cline.select(\"path\").attr(\"d\",E.showline?\"M\"+(r+i/2)+\",\"+n+\"l\"+i/2+\",\"+a:\"M0,0\").call(l.stroke,E.linecolor||\"#000\").style(\"stroke-width\",(E.linewidth||0)+\"px\"),f.graphDiv._context.staticPlot||f.initInteractions(),c.setClipUrl(f.layers.frontplot,f._hasClipOnAxisFalse?null:f.clipId,f.graphDiv)},w.drawAxes=function(t){var e=this.graphDiv,r=this.id.substr(7)+\"title\",n=this.layers,i=this.aaxis,a=this.baxis,o=this.caxis;if(this.drawAx(i),this.drawAx(a),this.drawAx(o),t){var l=Math.max(i.showticklabels?i.tickfont.size/2:0,(o.showticklabels?.75*o.tickfont.size:0)+(\"outside\"===o.ticks?.87*o.ticklen:0)),c=(a.showticklabels?a.tickfont.size:0)+(\"outside\"===a.ticks?a.ticklen:0)+3;n[\"a-title\"]=v.draw(e,\"a\"+r,{propContainer:i,propName:this.id+\".aaxis.title\",placeholder:s(e,\"Click to enter Component A title\"),attributes:{x:this.x0+this.w/2,y:this.y0-i.title.font.size/3-l,\"text-anchor\":\"middle\"}}),n[\"b-title\"]=v.draw(e,\"b\"+r,{propContainer:a,propName:this.id+\".baxis.title\",placeholder:s(e,\"Click to enter Component B title\"),attributes:{x:this.x0-c,y:this.y0+this.h+.83*a.title.font.size+c,\"text-anchor\":\"middle\"}}),n[\"c-title\"]=v.draw(e,\"c\"+r,{propContainer:o,propName:this.id+\".caxis.title\",placeholder:s(e,\"Click to enter Component C title\"),attributes:{x:this.x0+this.w+c,y:this.y0+this.h+.83*o.title.font.size+c,\"text-anchor\":\"middle\"}})}},w.drawAx=function(t){var e,r=this.graphDiv,n=t._name,i=n.charAt(0),a=t._id,s=this.layers[n],l=i+\"tickLayout\",c=(e=t).ticks+String(e.ticklen)+String(e.showticklabels);this[l]!==c&&(s.selectAll(\".\"+a+\"tick\").remove(),this[l]=c),t.setScale();var u=p.calcTicks(t),h=p.clipEnds(t,u),f=p.makeTransFn(t),d=p.getTickSigns(t)[2],g=o.deg2rad(30),v=d*(t.linewidth||1)/2,m=d*t.ticklen,y=this.w,x=this.h,b=\"b\"===i?\"M0,\"+v+\"l\"+Math.sin(g)*m+\",\"+Math.cos(g)*m:\"M\"+v+\",0l\"+Math.cos(g)*m+\",\"+-Math.sin(g)*m,_={a:\"M0,0l\"+x+\",-\"+y/2,b:\"M0,0l-\"+y/2+\",-\"+x,c:\"M0,0l-\"+x+\",\"+y/2}[i];p.drawTicks(r,t,{vals:\"inside\"===t.ticks?h:u,layer:s,path:b,transFn:f,crisp:!1}),p.drawGrid(r,t,{vals:h,layer:this.layers[i+\"grid\"],path:_,transFn:f,crisp:!1}),p.drawLabels(r,t,{vals:u,layer:s,transFn:f,labelFns:p.makeLabelFns(t,0,30)})};var T=b.MINZOOM/2+.87,A=\"m-0.87,.5h\"+T+\"v3h-\"+(T+5.2)+\"l\"+(T/2+2.6)+\",-\"+(.87*T+4.5)+\"l2.6,1.5l-\"+T/2+\",\"+.87*T+\"Z\",M=\"m0.87,.5h-\"+T+\"v3h\"+(T+5.2)+\"l-\"+(T/2+2.6)+\",-\"+(.87*T+4.5)+\"l-2.6,1.5l\"+T/2+\",\"+.87*T+\"Z\",S=\"m0,1l\"+T/2+\",\"+.87*T+\"l2.6,-1.5l-\"+(T/2+2.6)+\",-\"+(.87*T+4.5)+\"l-\"+(T/2+2.6)+\",\"+(.87*T+4.5)+\"l2.6,1.5l\"+T/2+\",-\"+.87*T+\"Z\",E=\"m0.5,0.5h5v-2h-5v-5h-2v5h-5v2h5v5h2Z\",C=!0;function L(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}w.initInteractions=function(){var t,e,r,n,u,h,f,p,v,_,w=this,T=w.layers.plotbg.select(\"path\").node(),P=w.graphDiv,O=P._fullLayout._zoomlayer,z={element:T,gd:P,plotinfo:{id:w.id,xaxis:w.xaxis,yaxis:w.yaxis},subplot:w.id,prepFn:function(a,o,s){z.xaxes=[w.xaxis],z.yaxes=[w.yaxis];var c=P._fullLayout.dragmode;z.minDrag=\"lasso\"===c?1:void 0,\"zoom\"===c?(z.moveFn=N,z.clickFn=D,z.doneFn=j,function(a,o,s){var c=T.getBoundingClientRect();t=o-c.left,e=s-c.top,r={a:w.aaxis.range[0],b:w.baxis.range[1],c:w.caxis.range[1]},u=r,n=w.aaxis.range[1]-r.a,h=i(w.graphDiv._fullLayout[w.id].bgcolor).getLuminance(),f=\"M0,\"+w.h+\"L\"+w.w/2+\", 0L\"+w.w+\",\"+w.h+\"Z\",p=!1,v=O.append(\"path\").attr(\"class\",\"zoombox\").attr(\"transform\",\"translate(\"+w.x0+\", \"+w.y0+\")\").style({fill:h>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"d\",f),_=O.append(\"path\").attr(\"class\",\"zoombox-corners\").attr(\"transform\",\"translate(\"+w.x0+\", \"+w.y0+\")\").style({fill:l.background,stroke:l.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"d\",\"M0,0Z\"),x(P)}(0,o,s)):\"pan\"===c?(z.moveFn=U,z.clickFn=D,z.doneFn=V,r={a:w.aaxis.range[0],b:w.baxis.range[1],c:w.caxis.range[1]},u=r,x(P)):\"select\"!==c&&\"lasso\"!==c||m(a,o,s,z,c)}};function I(t){var e={};return e[w.id+\".aaxis.min\"]=t.a,e[w.id+\".baxis.min\"]=t.b,e[w.id+\".caxis.min\"]=t.c,e}function D(t,e){var r=P._fullLayout.clickmode;L(P),2===t&&(P.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",P,I({a:0,b:0,c:0}))),r.indexOf(\"select\")>-1&&1===t&&y(e,P,[w.xaxis],[w.yaxis],w.id,z),r.indexOf(\"event\")>-1&&g.click(P,e,w.id)}function R(t,e){return 1-e/w.h}function F(t,e){return 1-(t+(w.h-e)/Math.sqrt(3))/w.w}function B(t,e){return(t-(w.h-e)/Math.sqrt(3))/w.w}function N(i,a){var o=t+i,s=e+a,l=Math.max(0,Math.min(1,R(0,e),R(0,s))),c=Math.max(0,Math.min(1,F(t,e),F(o,s))),d=Math.max(0,Math.min(1,B(t,e),B(o,s))),g=(l/2+d)*w.w,m=(1-l/2-c)*w.w,y=(g+m)/2,x=m-g,T=(1-l)*w.h,C=T-x/k;x<b.MINZOOM?(u=r,v.attr(\"d\",f),_.attr(\"d\",\"M0,0Z\")):(u={a:r.a+l*n,b:r.b+c*n,c:r.c+d*n},v.attr(\"d\",f+\"M\"+g+\",\"+T+\"H\"+m+\"L\"+y+\",\"+C+\"L\"+g+\",\"+T+\"Z\"),_.attr(\"d\",\"M\"+t+\",\"+e+E+\"M\"+g+\",\"+T+A+\"M\"+m+\",\"+T+M+\"M\"+y+\",\"+C+S)),p||(v.transition().style(\"fill\",h>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),_.transition().style(\"opacity\",1).duration(200),p=!0),P.emit(\"plotly_relayouting\",I(u))}function j(){L(P),u!==r&&(a.call(\"_guiRelayout\",P,I(u)),C&&P.data&&P._context.showTips&&(o.notifier(s(P,\"Double-click to zoom back out\"),\"long\"),C=!1))}function U(t,e){var n=t/w.xaxis._m,i=e/w.yaxis._m,a=[(u={a:r.a-i,b:r.b+(n+i)/2,c:r.c-(n-i)/2}).a,u.b,u.c].sort(),o=a.indexOf(u.a),s=a.indexOf(u.b),l=a.indexOf(u.c);a[0]<0&&(a[1]+a[0]/2<0?(a[2]+=a[0]+a[1],a[0]=a[1]=0):(a[2]+=a[0]/2,a[1]+=a[0]/2,a[0]=0),u={a:a[o],b:a[s],c:a[l]},e=(r.a-u.a)*w.yaxis._m,t=(r.c-u.c-r.b+u.b)*w.xaxis._m);var h=\"translate(\"+(w.x0+t)+\",\"+(w.y0+e)+\")\";w.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",h);var f=\"translate(\"+-t+\",\"+-e+\")\";w.clipDefRelative.select(\"path\").attr(\"transform\",f),w.aaxis.range=[u.a,w.sum-u.b-u.c],w.baxis.range=[w.sum-u.a-u.c,u.b],w.caxis.range=[w.sum-u.a-u.b,u.c],w.drawAxes(!1),w._hasClipOnAxisFalse&&w.plotContainer.select(\".scatterlayer\").selectAll(\".trace\").call(c.hideOutsideRangePoints,w),P.emit(\"plotly_relayouting\",I(u))}function V(){a.call(\"_guiRelayout\",P,I(u))}T.onmousemove=function(t){g.hover(P,t,w.id),P._fullLayout._lasthover=T,P._fullLayout._hoversubplot=w.id},T.onmouseout=function(t){P._dragging||d.unhover(P,t)},d.init(z)}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../components/titles\":681,\"../../lib\":719,\"../../lib/extend\":710,\"../../registry\":847,\"../cartesian/axes\":767,\"../cartesian/constants\":773,\"../cartesian/select\":784,\"../cartesian/set_convert\":785,\"../plots\":828,d3:163,tinycolor2:537}],847:[function(t,e,r){\"use strict\";var n=t(\"./lib/loggers\"),i=t(\"./lib/noop\"),a=t(\"./lib/push_unique\"),o=t(\"./lib/is_plain_object\"),s=t(\"./lib/dom\").addStyleRule,l=t(\"./lib/extend\"),c=t(\"./plots/attributes\"),u=t(\"./plots/layout_attributes\"),h=l.extendFlat,f=l.extendDeepAll;function p(t){var e=t.name,i=t.categories,a=t.meta;if(r.modules[e])n.log(\"Type \"+e+\" already registered\");else{r.subplotsRegistry[t.basePlotModule.name]||function(t){var e=t.name;if(r.subplotsRegistry[e])return void n.log(\"Plot type \"+e+\" already registered.\");for(var i in m(t),r.subplotsRegistry[e]=t,r.componentsRegistry)b(i,t.name)}(t.basePlotModule);for(var o={},l=0;l<i.length;l++)o[i[l]]=!0,r.allCategories[i[l]]=!0;for(var c in r.modules[e]={_module:t,categories:o},a&&Object.keys(a).length&&(r.modules[e].meta=a),r.allTypes.push(e),r.componentsRegistry)y(c,e);t.layoutAttributes&&h(r.traceLayoutAttributes,t.layoutAttributes);var u=t.basePlotModule,f=u.name;if(\"mapbox\"===f){var p=u.constants.styleRules;for(var d in p)s(\".js-plotly-plot .plotly .mapboxgl-\"+d,p[d])}\"geo\"!==f&&\"mapbox\"!==f||void 0===typeof window||void 0!==window.PlotlyGeoAssets||(window.PlotlyGeoAssets={topojson:{}})}}function d(t){if(\"string\"!=typeof t.name)throw new Error(\"Component module *name* must be a string.\");var e=t.name;for(var n in r.componentsRegistry[e]=t,t.layoutAttributes&&(t.layoutAttributes._isLinkedToArray&&a(r.layoutArrayContainers,e),m(t)),r.modules)y(e,n);for(var i in r.subplotsRegistry)b(e,i);for(var o in r.transformsRegistry)x(e,o);t.schema&&t.schema.layout&&f(u,t.schema.layout)}function g(t){if(\"string\"!=typeof t.name)throw new Error(\"Transform module *name* must be a string.\");var e=\"Transform module \"+t.name,i=\"function\"==typeof t.transform,a=\"function\"==typeof t.calcTransform;if(!i&&!a)throw new Error(e+\" is missing a *transform* or *calcTransform* method.\");for(var s in i&&a&&n.log([e+\" has both a *transform* and *calcTransform* methods.\",\"Please note that all *transform* methods are executed\",\"before all *calcTransform* methods.\"].join(\" \")),o(t.attributes)||n.log(e+\" registered without an *attributes* object.\"),\"function\"!=typeof t.supplyDefaults&&n.log(e+\" registered without a *supplyDefaults* method.\"),r.transformsRegistry[t.name]=t,r.componentsRegistry)x(s,t.name)}function v(t){var e=t.name,n=e.split(\"-\")[0],i=t.dictionary,a=t.format,o=i&&Object.keys(i).length,s=a&&Object.keys(a).length,l=r.localeRegistry,c=l[e];if(c||(l[e]=c={}),n!==e){var u=l[n];u||(l[n]=u={}),o&&u.dictionary===c.dictionary&&(u.dictionary=i),s&&u.format===c.format&&(u.format=a)}o&&(c.dictionary=i),s&&(c.format=a)}function m(t){if(t.layoutAttributes){var e=t.layoutAttributes._arrayAttrRegexps;if(e)for(var n=0;n<e.length;n++)a(r.layoutArrayRegexes,e[n])}}function y(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.traces){var i=n.traces[e];i&&f(r.modules[e]._module.attributes,i)}}function x(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.transforms){var i=n.transforms[e];i&&f(r.transformsRegistry[e].attributes,i)}}function b(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.subplots){var i=r.subplotsRegistry[e],a=i.layoutAttributes,o=\"subplot\"===i.attr?i.name:i.attr;Array.isArray(o)&&(o=o[0]);var s=n.subplots[o];a&&s&&f(a,s)}}function _(t){return\"object\"==typeof t&&(t=t.type),t}r.modules={},r.allCategories={},r.allTypes=[],r.subplotsRegistry={},r.transformsRegistry={},r.componentsRegistry={},r.layoutArrayContainers=[],r.layoutArrayRegexes=[],r.traceLayoutAttributes={},r.localeRegistry={},r.apiMethodRegistry={},r.collectableSubplotTypes=null,r.register=function(t){if(r.collectableSubplotTypes=null,!t)throw new Error(\"No argument passed to Plotly.register.\");t&&!Array.isArray(t)&&(t=[t]);for(var e=0;e<t.length;e++){var n=t[e];if(!n)throw new Error(\"Invalid module was attempted to be registered!\");switch(n.moduleType){case\"trace\":p(n);break;case\"transform\":g(n);break;case\"component\":d(n);break;case\"locale\":v(n);break;case\"apiMethod\":var i=n.name;r.apiMethodRegistry[i]=n.fn;break;default:throw new Error(\"Invalid module was attempted to be registered!\")}}},r.getModule=function(t){var e=r.modules[_(t)];return!!e&&e._module},r.traceIs=function(t,e){if(\"various\"===(t=_(t)))return!1;var i=r.modules[t];return i||(t&&\"area\"!==t&&n.log(\"Unrecognized trace type \"+t+\".\"),i=r.modules[c.type.dflt]),!!i.categories[e]},r.getTransformIndices=function(t,e){for(var r=[],n=t.transforms||[],i=0;i<n.length;i++)n[i].type===e&&r.push(i);return r},r.hasTransform=function(t,e){for(var r=t.transforms||[],n=0;n<r.length;n++)if(r[n].type===e)return!0;return!1},r.getComponentMethod=function(t,e){var n=r.componentsRegistry[t];return n&&n[e]||i},r.call=function(){var t=arguments[0],e=[].slice.call(arguments,1);return r.apiMethodRegistry[t].apply(null,e)}},{\"./lib/dom\":708,\"./lib/extend\":710,\"./lib/is_plain_object\":720,\"./lib/loggers\":723,\"./lib/noop\":728,\"./lib/push_unique\":733,\"./plots/attributes\":764,\"./plots/layout_attributes\":819}],848:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=i.extendFlat,o=i.extendDeep;function s(t){var e;switch(t){case\"themes__thumb\":e={autosize:!0,width:150,height:150,title:{text:\"\"},showlegend:!1,margin:{l:5,r:5,t:5,b:5,pad:0},annotations:[]};break;case\"thumbnail\":e={title:{text:\"\"},hidesources:!0,showlegend:!1,borderwidth:0,bordercolor:\"\",margin:{l:1,r:1,t:1,b:1,pad:0},annotations:[]};break;default:e={}}return e}e.exports=function(t,e){var r;t.framework&&t.framework.isPolar&&(t=t.framework.getConfig());var i,l=t.data,c=t.layout,u=o([],l),h=o({},c,s(e.tileClass)),f=t._context||{};if(e.width&&(h.width=e.width),e.height&&(h.height=e.height),\"thumbnail\"===e.tileClass||\"themes__thumb\"===e.tileClass){h.annotations=[];var p=Object.keys(h);for(r=0;r<p.length;r++)i=p[r],[\"xaxis\",\"yaxis\",\"zaxis\"].indexOf(i.slice(0,5))>-1&&(h[p[r]].title={text:\"\"});for(r=0;r<u.length;r++){var d=u[r];d.showscale=!1,d.marker&&(d.marker.showscale=!1),n.traceIs(d,\"pie-like\")&&(d.textposition=\"none\")}}if(Array.isArray(e.annotations))for(r=0;r<e.annotations.length;r++)h.annotations.push(e.annotations[r]);var g=Object.keys(h).filter(function(t){return t.match(/^scene\\d*$/)});if(g.length){var v={};for(\"thumbnail\"===e.tileClass&&(v={title:{text:\"\"},showaxeslabels:!1,showticklabels:!1,linetickenable:!1}),r=0;r<g.length;r++){var m=h[g[r]];m.xaxis||(m.xaxis={}),m.yaxis||(m.yaxis={}),m.zaxis||(m.zaxis={}),a(m.xaxis,v),a(m.yaxis,v),a(m.zaxis,v),m._scene=null}}var y=document.createElement(\"div\");e.tileClass&&(y.className=e.tileClass);var x={gd:y,td:y,layout:h,data:u,config:{staticPlot:void 0===e.staticPlot||e.staticPlot,plotGlPixelRatio:void 0===e.plotGlPixelRatio?2:e.plotGlPixelRatio,displaylogo:e.displaylogo||!1,showLink:e.showLink||!1,showTips:e.showTips||!1,mapboxAccessToken:f.mapboxAccessToken}};return\"transparent\"!==e.setBackground&&(x.config.setBackground=e.setBackground||\"opaque\"),x.gd.defaultLayout=s(e.tileClass),x}},{\"../lib\":719,\"../registry\":847}],849:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/to_image\"),a=t(\"./filesaver\"),o=t(\"./helpers\");e.exports=function(t,e){var r;return n.isPlainObject(t)||(r=n.getGraphDiv(t)),(e=e||{}).format=e.format||\"png\",e.imageDataOnly=!0,new Promise(function(s,l){r&&r._snapshotInProgress&&l(new Error(\"Snapshotting already in progress.\")),n.isIE()&&\"svg\"!==e.format&&l(new Error(o.MSG_IE_BAD_FORMAT)),r&&(r._snapshotInProgress=!0);var c=i(t,e),u=e.filename||t.fn||\"newplot\";u+=\".\"+e.format,c.then(function(t){return r&&(r._snapshotInProgress=!1),a(t,u,e.format)}).then(function(t){s(t)}).catch(function(t){r&&(r._snapshotInProgress=!1),l(t)})})}},{\"../lib\":719,\"../plot_api/to_image\":760,\"./filesaver\":850,\"./helpers\":851}],850:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"./helpers\");e.exports=function(t,e,r){var a=document.createElement(\"a\"),o=\"download\"in a;return new Promise(function(s,l){var c,u;if(n.isIE9orBelow()&&l(new Error(\"IE < 10 unsupported\")),n.isSafari()){var h=\"svg\"===r?\",\":\";base64,\";return i.octetStream(h+encodeURIComponent(t)),s(e)}return n.isIE()?(c=i.createBlob(t,\"svg\"),window.navigator.msSaveBlob(c,e),c=null,s(e)):o?(c=i.createBlob(t,r),u=i.createObjectURL(c),a.href=u,a.download=e,document.body.appendChild(a),a.click(),document.body.removeChild(a),i.revokeObjectURL(u),c=null,s(e)):void l(new Error(\"download error\"))})}},{\"../lib\":719,\"./helpers\":851}],851:[function(t,e,r){\"use strict\";var n=t(\"../registry\");r.getDelay=function(t){return t._has&&(t._has(\"gl3d\")||t._has(\"gl2d\")||t._has(\"mapbox\"))?500:0},r.getRedrawFunc=function(t){return function(){var e=t._fullLayout||{};!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r||n.getComponentMethod(\"colorbar\",\"draw\")(t)}},r.encodeSVG=function(t){return\"data:image/svg+xml,\"+encodeURIComponent(t)};var i=window.URL||window.webkitURL;r.createObjectURL=function(t){return i.createObjectURL(t)},r.revokeObjectURL=function(t){return i.revokeObjectURL(t)},r.createBlob=function(t,e){if(\"svg\"===e)return new window.Blob([t],{type:\"image/svg+xml;charset=utf-8\"});var r=function(t){for(var e=t.length,r=new ArrayBuffer(e),n=new Uint8Array(r),i=0;i<e;i++)n[i]=t.charCodeAt(i);return r}(window.atob(t));return new window.Blob([r],{type:\"image/\"+e})},r.octetStream=function(t){document.location.href=\"data:application/octet-stream\"+t},r.IMAGE_URL_PREFIX=/^data:image\\/\\w+;base64,/,r.MSG_IE_BAD_FORMAT=\"Sorry IE does not support downloading from canvas. Try {format:'svg'} instead.\"},{\"../registry\":847}],852:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i={getDelay:n.getDelay,getRedrawFunc:n.getRedrawFunc,clone:t(\"./cloneplot\"),toSVG:t(\"./tosvg\"),svgToImg:t(\"./svgtoimg\"),toImage:t(\"./toimage\"),downloadImage:t(\"./download\")};e.exports=i},{\"./cloneplot\":848,\"./download\":849,\"./helpers\":851,\"./svgtoimg\":853,\"./toimage\":854,\"./tosvg\":855}],853:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"events\").EventEmitter,a=t(\"./helpers\");e.exports=function(t){var e=t.emitter||new i,r=new Promise(function(i,o){var s=window.Image,l=t.svg,c=t.format||\"png\";if(n.isIE()&&\"svg\"!==c){var u=new Error(a.MSG_IE_BAD_FORMAT);return o(u),t.promise?r:e.emit(\"error\",u)}var h,f,p=t.canvas,d=t.scale||1,g=t.width||300,v=t.height||150,m=d*g,y=d*v,x=p.getContext(\"2d\"),b=new s;\"svg\"===c||n.isIE9orBelow()||n.isSafari()?f=a.encodeSVG(l):(h=a.createBlob(l,\"svg\"),f=a.createObjectURL(h)),p.width=m,p.height=y,b.onload=function(){var r;switch(h=null,a.revokeObjectURL(f),\"svg\"!==c&&x.drawImage(b,0,0,m,y),c){case\"jpeg\":r=p.toDataURL(\"image/jpeg\");break;case\"png\":r=p.toDataURL(\"image/png\");break;case\"webp\":r=p.toDataURL(\"image/webp\");break;case\"svg\":r=f;break;default:var n=\"Image format is not jpeg, png, svg or webp.\";if(o(new Error(n)),!t.promise)return e.emit(\"error\",n)}i(r),t.promise||e.emit(\"success\",r)},b.onerror=function(r){if(h=null,a.revokeObjectURL(f),o(r),!t.promise)return e.emit(\"error\",r)},b.src=f});return t.promise?r:e}},{\"../lib\":719,\"./helpers\":851,events:104}],854:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i=t(\"../registry\"),a=t(\"../lib\"),o=t(\"./helpers\"),s=t(\"./cloneplot\"),l=t(\"./tosvg\"),c=t(\"./svgtoimg\");e.exports=function(t,e){var r=new n,u=s(t,{format:\"png\"}),h=u.gd;h.style.position=\"absolute\",h.style.left=\"-5000px\",document.body.appendChild(h);var f=o.getRedrawFunc(h);return i.call(\"plot\",h,u.data,u.layout,u.config).then(f).then(function(){var t=o.getDelay(h._fullLayout);setTimeout(function(){var t=l(h),n=document.createElement(\"canvas\");n.id=a.randstr(),(r=c({format:e.format,width:h._fullLayout.width,height:h._fullLayout.height,canvas:n,emitter:r,svg:t})).clean=function(){h&&document.body.removeChild(h)}},t)}).catch(function(t){r.emit(\"error\",t)}),r}},{\"../lib\":719,\"../registry\":847,\"./cloneplot\":848,\"./helpers\":851,\"./svgtoimg\":853,\"./tosvg\":855,events:104}],855:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=t(\"../components/drawing\"),o=t(\"../components/color\"),s=t(\"../constants/xmlns_namespaces\"),l=/\"/g,c=new RegExp('(\"TOBESTRIPPED)|(TOBESTRIPPED\")',\"g\");e.exports=function(t,e,r){var u,h=t._fullLayout,f=h._paper,p=h._toppaper,d=h.width,g=h.height;f.insert(\"rect\",\":first-child\").call(a.setRect,0,0,d,g).call(o.fill,h.paper_bgcolor);var v=h._basePlotModules||[];for(u=0;u<v.length;u++){var m=v[u];m.toSVG&&m.toSVG(t)}if(p){var y=p.node().childNodes,x=Array.prototype.slice.call(y);for(u=0;u<x.length;u++){var b=x[u];b.childNodes.length&&f.node().appendChild(b)}}h._draggers&&h._draggers.remove(),f.node().style.background=\"\",f.selectAll(\"text\").attr({\"data-unformatted\":null,\"data-math\":null}).each(function(){var t=n.select(this);if(\"hidden\"!==this.style.visibility&&\"none\"!==this.style.display){t.style({visibility:null,display:null});var e=this.style.fontFamily;e&&-1!==e.indexOf('\"')&&t.style(\"font-family\",e.replace(l,\"TOBESTRIPPED\"))}else t.remove()}),f.selectAll(\".point, .scatterpts, .legendfill>path, .legendlines>path, .cbfill\").each(function(){var t=n.select(this),e=this.style.fill;e&&-1!==e.indexOf(\"url(\")&&t.style(\"fill\",e.replace(l,\"TOBESTRIPPED\"));var r=this.style.stroke;r&&-1!==r.indexOf(\"url(\")&&t.style(\"stroke\",r.replace(l,\"TOBESTRIPPED\"))}),\"pdf\"!==e&&\"eps\"!==e||f.selectAll(\"#MathJax_SVG_glyphs path\").attr(\"stroke-width\",0),f.node().setAttributeNS(s.xmlns,\"xmlns\",s.svg),f.node().setAttributeNS(s.xmlns,\"xmlns:xlink\",s.xlink),\"svg\"===e&&r&&(f.attr(\"width\",r*d),f.attr(\"height\",r*g),f.attr(\"viewBox\",\"0 0 \"+d+\" \"+g));var _=(new window.XMLSerializer).serializeToString(f.node());return _=function(t){var e=n.select(\"body\").append(\"div\").style({display:\"none\"}).html(\"\"),r=t.replace(/(&[^;]*;)/gi,function(t){return\"&lt;\"===t?\"&#60;\":\"&rt;\"===t?\"&#62;\":-1!==t.indexOf(\"<\")||-1!==t.indexOf(\">\")?\"\":e.html(t).text()});return e.remove(),r}(_),_=(_=_.replace(/&(?!\\w+;|\\#[0-9]+;| \\#x[0-9A-F]+;)/g,\"&amp;\")).replace(c,\"'\"),i.isIE()&&(_=(_=(_=_.replace(/\"/gi,\"'\")).replace(/(\\('#)([^']*)('\\))/gi,'(\"#$2\")')).replace(/(\\\\')/gi,'\"')),_}},{\"../components/color\":593,\"../components/drawing\":614,\"../constants/xmlns_namespaces\":696,\"../lib\":719,d3:163}],856:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\",!0),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":719}],857:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/font_attributes\"),s=t(\"./constants.js\"),l=t(\"../../lib/extend\").extendFlat,c=o({editType:\"calc\",arrayOk:!0,colorEditType:\"style\"}),u=l({},n.marker.line.width,{dflt:0}),h=l({width:u,editType:\"calc\"},a(\"marker.line\")),f=l({line:h,editType:\"calc\"},a(\"marker\"),{opacity:{valType:\"number\",arrayOk:!0,dflt:1,min:0,max:1,editType:\"style\"}});e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,text:n.text,hovertext:n.hovertext,hovertemplate:i({},{keys:s.eventDataKeys}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"none\",arrayOk:!0,editType:\"calc\"},insidetextanchor:{valType:\"enumerated\",values:[\"end\",\"middle\",\"start\"],dflt:\"end\",editType:\"plot\"},textangle:{valType:\"angle\",dflt:\"auto\",editType:\"plot\"},textfont:l({},c,{}),insidetextfont:l({},c,{}),outsidetextfont:l({},c,{}),constraintext:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"both\",\"none\"],dflt:\"both\",editType:\"calc\"},cliponaxis:l({},n.cliponaxis,{}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},base:{valType:\"any\",dflt:null,arrayOk:!0,editType:\"calc\"},offset:{valType:\"number\",dflt:null,arrayOk:!0,editType:\"calc\"},width:{valType:\"number\",dflt:null,min:0,arrayOk:!0,editType:\"calc\"},marker:f,offsetgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},alignmentgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},selected:{marker:{opacity:n.selected.marker.opacity,color:n.selected.marker.color,editType:\"style\"},textfont:n.selected.textfont,editType:\"style\"},unselected:{marker:{opacity:n.unselected.marker.opacity,color:n.unselected.marker.color,editType:\"style\"},textfont:n.unselected.textfont,editType:\"style\"},r:n.r,t:n.t,_deprecated:{bardir:{valType:\"enumerated\",editType:\"calc\",values:[\"v\",\"h\"]}}}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"../scatter/attributes\":1112,\"./constants.js\":859}],858:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),o=t(\"./arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\");e.exports=function(t,e){var r,l,c=n.getFromId(t,e.xaxis||\"x\"),u=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=c.makeCalcdata(e,\"x\"),l=u.makeCalcdata(e,\"y\")):(r=u.makeCalcdata(e,\"y\"),l=c.makeCalcdata(e,\"x\"));for(var h=Math.min(l.length,r.length),f=new Array(h),p=0;p<h;p++)f[p]={p:l[p],s:r[p]},e.ids&&(f[p].id=String(e.ids[p]));return i(e,\"marker\")&&a(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),i(e,\"marker.line\")&&a(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),o(f,e),s(f,e),f}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"../../plots/cartesian/axes\":767,\"../scatter/calc_selection\":1114,\"./arrays_to_calcdata\":856}],859:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[]}},{}],860:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,c=t(\"./sieve.js\");function u(t,e,r,o,u){if(o.length){var b,_,w,k;switch(function(t,e){var r,a;for(r=0;r<e.length;r++){var o,s=e[r],l=s[0].trace,c=\"funnel\"===l.type?l._base:l.base,u=\"h\"===l.orientation?l.xcalendar:l.ycalendar,h=\"category\"===t.type||\"multicategory\"===t.type?function(){return null}:t.d2c;if(i(c)){for(a=0;a<Math.min(c.length,s.length);a++)o=h(c[a],0,u),n(o)?(s[a].b=+o,s[a].hasB=1):s[a].b=0;for(;a<s.length;a++)s[a].b=0}else{o=h(c,0,u);var f=n(o);for(o=f?o:0,a=0;a<s.length;a++)s[a].b=o,f&&(s[a].hasB=1)}}}(r,o),u.mode){case\"overlay\":h(e,r,o,u);break;case\"group\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(k=o[w])[0].trace.offset?_.push(k):b.push(k);_.length&&function(t,e,r,n,i){var o=new c(n,{sepNegVal:!1,overlapNoMerge:!i.norm});(function(t,e,r,n){for(var i=t._fullLayout,a=r.positions,o=r.distinctPositions,s=r.minDiff,c=r.traces,u=c.length,h=a.length!==o.length,f=s*(1-n.gap),v=l(i,e._id)+c[0][0].trace.orientation,m=i._alignmentOpts[v]||{},y=0;y<u;y++){var x,b,_=c[y],w=_[0].trace,k=m[w.alignmentgroup]||{},T=Object.keys(k.offsetGroups||{}).length,A=(x=T?f/T:h?f/u:f)*(1-(n.groupgap||0));b=T?((2*w._offsetIndex+1-T)*x-A)/2:h?((2*y+1-u)*x-A)/2:-A/2;var M=_[0].t;M.barwidth=A,M.poffset=b,M.bargroupwidth=f,M.bardelta=s}r.binWidth=c[0][0].t.barwidth/100,p(r),d(e,r),g(e,r,h)})(t,e,o,i),function(t){for(var e=t.traces,r=0;r<e.length;r++){var n=e[r],i=n[0].trace;if(void 0===i.base)for(var o=new c([n],{sepNegVal:!0,overlapNoMerge:!0}),s=0;s<n.length;s++){var l=n[s];if(l.p!==a){var u=o.put(l.p,l.b+l.s);u&&(l.b=u)}}}}(o),i.norm?(m(o),y(r,o,i)):v(r,o)}(t,e,r,_,u),b.length&&h(e,r,b,u);break;case\"stack\":case\"relative\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(k=o[w])[0].trace.base?_.push(k):b.push(k);_.length&&function(t,e,r,n,i){var o=new c(n,{sepNegVal:\"relative\"===i.mode,overlapNoMerge:!(i.norm||\"stack\"===i.mode||\"relative\"===i.mode)});f(e,o,i),function(t,e,r){var n,i,o,l,c,u,h=x(t),f=e.traces;for(l=0;l<f.length;l++)if(n=f[l],\"funnel\"===(i=n[0].trace).type)for(c=0;c<n.length;c++)(u=n[c]).s!==a&&e.put(u.p,-.5*u.s);for(l=0;l<f.length;l++){n=f[l],i=n[0].trace,o=\"funnel\"===i.type;var p=[];for(c=0;c<n.length;c++)if((u=n[c]).s!==a){var d;d=o?u.s:u.s+u.b;var g=e.put(u.p,d),v=g+d;u.b=g,u[h]=v,r.norm||(p.push(v),u.hasB&&p.push(g))}r.norm||(i._extremes[t._id]=s.findExtremes(t,p,{tozero:!0,padded:!0}))}}(r,o,i);for(var l=0;l<n.length;l++)for(var u=n[l],h=0;h<u.length;h++){var p=u[h];if(p.s!==a){var d=p.b+p.s===o.get(p.p,p.s);d&&(p._outmost=!0)}}i.norm&&y(r,o,i)}(0,e,r,_,u),b.length&&h(e,r,b,u)}!function(t,e){var r,i,a,o=x(e),s={},l=1/0,c=-1/0;for(r=0;r<t.length;r++)for(a=t[r],i=0;i<a.length;i++){var u=a[i].p;n(u)&&(l=Math.min(l,u),c=Math.max(c,u))}var h=1e4/(c-l),f=s.round=function(t){return String(Math.round(h*(t-l)))};for(r=0;r<t.length;r++){(a=t[r])[0].t.extents=s;var p=a[0].t.poffset,d=Array.isArray(p);for(i=0;i<a.length;i++){var g=a[i],v=g[o]-g.w/2;if(n(v)){var m=g[o]+g.w/2,y=f(g.p);s[y]?s[y]=[Math.min(v,s[y][0]),Math.max(m,s[y][1])]:s[y]=[v,m]}g.p0=g.p+(d?p[i]:p),g.p1=g.p0+g.w,g.s0=g.b,g.s1=g.s0+g.s}}}(o,e)}}function h(t,e,r,n){for(var i=0;i<r.length;i++){var a=r[i],o=new c([a],{sepNegVal:!1,overlapNoMerge:!n.norm});f(t,o,n),n.norm?(m(o),y(e,o,n)):v(e,o)}}function f(t,e,r){for(var n=e.minDiff,i=e.traces,a=n*(1-r.gap),o=a*(1-(r.groupgap||0)),s=-o/2,l=0;l<i.length;l++){var c=i[l][0].t;c.barwidth=o,c.poffset=s,c.bargroupwidth=a,c.bardelta=n}e.binWidth=i[0][0].t.barwidth/100,p(e),d(t,e),g(t,e)}function p(t){var e,r,a=t.traces;for(e=0;e<a.length;e++){var o,s=a[e],l=s[0],c=l.trace,u=l.t,h=c._offset||c.offset,f=u.poffset;if(i(h)){for(o=Array.prototype.slice.call(h,0,s.length),r=0;r<o.length;r++)n(o[r])||(o[r]=f);for(r=o.length;r<s.length;r++)o.push(f);u.poffset=o}else void 0!==h&&(u.poffset=h);var p=c._width||c.width,d=u.barwidth;if(i(p)){var g=Array.prototype.slice.call(p,0,s.length);for(r=0;r<g.length;r++)n(g[r])||(g[r]=d);for(r=g.length;r<s.length;r++)g.push(d);if(u.barwidth=g,void 0===h){for(o=[],r=0;r<s.length;r++)o.push(f+(d-g[r])/2);u.poffset=o}}else void 0!==p&&(u.barwidth=p,void 0===h&&(u.poffset=f+(d-p)/2))}}function d(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++)for(var a=r[i],o=a[0].t,s=o.poffset,l=Array.isArray(s),c=o.barwidth,u=Array.isArray(c),h=0;h<a.length;h++){var f=a[h],p=f.w=u?c[h]:c;f[n]=f.p+(l?s[h]:s)+p/2}}function g(t,e,r){var n=e.traces,i=e.minDiff/2;s.minDtick(t,e.minDiff,e.distinctPositions[0],r);for(var a=0;a<n.length;a++){var o,l,c,u,h=n[a],f=h[0],p=f.trace,d=[];for(u=0;u<h.length;u++)l=(o=h[u]).p-i,c=o.p+i,d.push(l,c);if(p.width||p.offset){var g=f.t,v=g.poffset,m=g.barwidth,y=Array.isArray(v),x=Array.isArray(m);for(u=0;u<h.length;u++){o=h[u];var b=y?v[u]:v,_=x?m[u]:m;c=(l=o.p+b)+_,d.push(l,c)}}p._extremes[t._id]=s.findExtremes(t,d,{padded:!1})}}function v(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++){for(var a=r[i],o=a[0].trace,l=[],c=!0,u=0;u<a.length;u++){var h=a[u],f=h.b,p=f+h.s;h[n]=p,l.push(p),h.hasB&&l.push(f),h.hasB&&h.b>0&&h.s>0||(c=!1)}o._extremes[t._id]=s.findExtremes(t,l,{tozero:!c,padded:!0})}}function m(t){for(var e=t.traces,r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++){var o=n[i];o.s!==a&&t.put(o.p,o.b+o.s)}}function y(t,e,r){var i=e.traces,o=x(t),l=\"fraction\"===r.norm?1:100,c=l/1e9,u=t.l2c(t.c2l(0)),h=\"stack\"===r.mode?l:u;function f(e){return n(t.c2l(e))&&(e<u-c||e>h+c||!n(u))}for(var p=0;p<i.length;p++){for(var d=i[p],g=d[0].trace,v=[],m=!0,y=!1,b=0;b<d.length;b++){var _=d[b];if(_.s!==a){var w=Math.abs(l/e.get(_.p,_.s));_.b*=w,_.s*=w;var k=_.b,T=k+_.s;_[o]=T,v.push(T),y=y||f(T),_.hasB&&(v.push(k),y=y||f(k)),_.hasB&&_.b>0&&_.s>0||(m=!1)}}g._extremes[t._id]=s.findExtremes(t,v,{tozero:!m,padded:y})}}function x(t){return t._id.charAt(0)}e.exports={crossTraceCalc:function(t,e){for(var r=e.xaxis,n=e.yaxis,i=t._fullLayout,a=t._fullData,s=t.calcdata,l=[],c=[],h=0;h<a.length;h++){var f=a[h];!0===f.visible&&o.traceIs(f,\"bar\")&&f.xaxis===r._id&&f.yaxis===n._id&&(\"h\"===f.orientation?l.push(s[h]):c.push(s[h]))}var p={mode:i.barmode,norm:i.barnorm,gap:i.bargap,groupgap:i.bargroupgap};u(t,r,n,c,p),u(t,n,r,l,p)},setGroupPositions:u}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"./sieve.js\":869,\"fast-isnumeric\":225}],861:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../registry\"),o=t(\"../scatter/xy_defaults\"),s=t(\"./style_defaults\"),l=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,c=t(\"./attributes\"),u=n.coerceFont;function h(t,e,r,n){var i=e.orientation,a=e[{v:\"x\",h:\"y\"}[i]+\"axis\"],o=l(r,a)+i,s=r._alignmentOpts||{},c=n(\"alignmentgroup\"),u=s[o];u||(u=s[o]={});var h=u[c];h?h.traces.push(e):h=u[c]={traces:[e],alignmentIndex:Object.keys(u).length,offsetGroups:{}};var f=n(\"offsetgroup\"),p=h.offsetGroups,d=p[f];f&&(d||(d=p[f]={offsetIndex:Object.keys(p).length}),e._offsetIndex=d.offsetIndex)}function f(t,e,r,i,a,o){var s=!(!1===(o=o||{}).moduleHasSelected),l=!(!1===o.moduleHasUnselected),c=!(!1===o.moduleHasConstrain),h=!(!1===o.moduleHasCliponaxis),f=!(!1===o.moduleHasTextangle),p=!(!1===o.moduleHasInsideanchor),d=Array.isArray(a)||\"auto\"===a,g=d||\"inside\"===a,v=d||\"outside\"===a;if(g||v){var m=u(i,\"textfont\",r.font),y=n.extendFlat({},m);!(t.textfont&&t.textfont.color)&&delete y.color,u(i,\"insidetextfont\",y),v&&u(i,\"outsidetextfont\",m),s&&i(\"selected.textfont.color\"),l&&i(\"unselected.textfont.color\"),c&&i(\"constraintext\"),h&&i(\"cliponaxis\"),f&&i(\"textangle\")}g&&p&&i(\"insidetextanchor\")}e.exports={supplyDefaults:function(t,e,r,l){function u(r,i){return n.coerce(t,e,c,r,i)}if(o(t,e,l,u)){u(\"orientation\",e.x&&!e.y?\"h\":\"v\"),u(\"base\"),u(\"offset\"),u(\"width\"),u(\"text\"),u(\"hovertext\"),u(\"hovertemplate\");var h=u(\"textposition\");f(t,0,l,u,h,{moduleHasSelected:!0,moduleHasUnselected:!0,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),s(t,e,u,r,l);var p=(e.marker.line||{}).color,d=a.getComponentMethod(\"errorbars\",\"supplyDefaults\");d(t,e,p||i.defaultLine,{axis:\"y\"}),d(t,e,p||i.defaultLine,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,u)}else e.visible=!1},crossTraceDefaults:function(t,e){var r;function i(t){return n.coerce(r._input,r,c,t)}if(\"group\"===e.barmode)for(var a=0;a<t.length;a++)\"bar\"===(r=t[a]).type&&(r._input,h(0,r,e,i))},handleGroupingDefaults:h,handleText:f}},{\"../../components/color\":593,\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../scatter/xy_defaults\":1137,\"./attributes\":857,\"./style_defaults\":871}],862:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../../lib\").isArrayOrTypedArray;r.coerceString=function(t,e,r){if(\"string\"==typeof e){if(e||!t.noBlank)return e}else if((\"number\"==typeof e||!0===e)&&!t.strict)return String(e);return void 0!==r?r:t.dflt},r.coerceNumber=function(t,e,r){if(n(e)){e=+e;var i=t.min,a=t.max;if(!(void 0!==i&&e<i||void 0!==a&&e>a))return e}return void 0!==r?r:t.dflt},r.coerceColor=function(t,e,r){return i(e).isValid()?e:void 0!==r?r:t.dflt},r.coerceEnumerated=function(t,e,r){return t.coerceNumber&&(e=+e),-1!==t.values.indexOf(e)?e:void 0!==r?r:t.dflt},r.getValue=function(t,e){var r;return Array.isArray(t)?e<t.length&&(r=t[e]):r=t,r},r.getLineWidth=function(t,e){return 0<e.mlw?e.mlw:a(t.marker.line.width)?0:t.marker.line.width}},{\"../../lib\":719,\"fast-isnumeric\":225,tinycolor2:537}],863:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../../lib\").fillText,s=t(\"./helpers\").getLineWidth;function l(t,e,r,i){var a,s,l,c,u,h,f,p=t.cd,d=p[0].trace,g=p[0].t,v=\"closest\"===i,m=\"waterfall\"===d.type,y=t.maxHoverDistance,x=t.maxSpikeDistance;function b(t){return t[l]-t.w/2}function _(t){return t[l]+t.w/2}var w=v?b:function(t){return Math.min(b(t),t.p-g.bardelta/2)},k=v?_:function(t){return Math.max(_(t),t.p+g.bardelta/2)};function T(t,e){return n.inbox(t-a,e-a,y+Math.min(1,Math.abs(e-t)/f)-1)}function A(t){return T(w(t),k(t))}function M(t){var e=s,r=t.b,i=t[c];return m&&(i+=Math.abs(t.rawS||0)),n.inbox(r-e,i-e,y+(i-e)/(i-r)-1)}\"h\"===d.orientation?(a=r,s=e,l=\"y\",c=\"x\",u=M,h=A):(a=e,s=r,l=\"x\",c=\"y\",h=M,u=A);var S=t[l+\"a\"],E=t[c+\"a\"];f=Math.abs(S.r2c(S.range[1])-S.r2c(S.range[0]));var C=n.getDistanceFunction(i,u,h,function(t){return(u(t)+h(t))/2});if(n.getClosest(p,C,t),!1!==t.index){v||(w=function(t){return Math.min(b(t),t.p-g.bargroupwidth/2)},k=function(t){return Math.max(_(t),t.p+g.bargroupwidth/2)});var L=p[t.index],P=d.base?L.b+L.s:L.s;t[c+\"0\"]=t[c+\"1\"]=E.c2p(L[c],!0),t[c+\"LabelVal\"]=P;var O=g.extents[g.extents.round(L.p)];return t[l+\"0\"]=S.c2p(v?w(L):O[0],!0),t[l+\"1\"]=S.c2p(v?k(L):O[1],!0),t[l+\"LabelVal\"]=L.p,t.spikeDistance=(M(L)+function(t){return T(b(t),_(t))}(L))/2+x-y,t[l+\"Spike\"]=S.c2p(L.p,!0),o(L,d,t),t.hovertemplate=d.hovertemplate,t}}function c(t,e){var r=e.mcc||t.marker.color,n=e.mlcc||t.marker.line.color,i=s(t,e);return a.opacity(r)?r:a.opacity(n)&&i?n:void 0}e.exports={hoverPoints:function(t,e,r,n){var a=l(t,e,r,n);if(a){var o=a.cd,s=o[0].trace,u=o[a.index];return a.color=c(s,u),i.getComponentMethod(\"errorbars\",\"hoverInfo\")(u,s,a),[a]}},hoverOnBars:l,getTraceColor:c}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"../../registry\":847,\"./helpers\":862}],864:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,colorbar:t(\"../scatter/marker_colorbar\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"bar\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"oriented\",\"errorBarsOK\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../scatter/marker_colorbar\":1129,\"./arrays_to_calcdata\":856,\"./attributes\":857,\"./calc\":858,\"./cross_trace_calc\":860,\"./defaults\":861,\"./hover\":863,\"./layout_attributes\":865,\"./layout_defaults\":866,\"./plot\":867,\"./select\":868,\"./style\":870}],865:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\",\"relative\"],dflt:\"group\",editType:\"calc\"},barnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},bargap:{valType:\"number\",min:0,max:1,editType:\"calc\"},bargroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],866:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\"),o=t(\"./layout_attributes\");e.exports=function(t,e,r){function s(r,n){return a.coerce(t,e,o,r,n)}for(var l=!1,c=!1,u=!1,h={},f=s(\"barmode\"),p=0;p<r.length;p++){var d=r[p];if(n.traceIs(d,\"bar\")&&d.visible){if(l=!0,\"group\"===f){var g=d.xaxis+d.yaxis;h[g]&&(u=!0),h[g]=!0}if(d.visible&&\"histogram\"===d.type)\"category\"!==i.getFromId({_fullLayout:e},d[\"v\"===d.orientation?\"xaxis\":\"yaxis\"]).type&&(c=!0)}}l?(\"overlay\"!==f&&s(\"barnorm\"),s(\"bargap\",c&&!u?0:.2),s(\"bargroupgap\")):delete e.barmode}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./layout_attributes\":865}],867:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../registry\"),u=t(\"../../plots/cartesian/axes\").tickText,h=t(\"./style\"),f=t(\"./helpers\"),p=t(\"./attributes\"),d=p.text,g=p.textposition,v=3;function m(t,e){return t<e?1:-1}function y(t){return\"auto\"===t?0:t}function x(t,e,r,n,i,a){var o=!!a.isHorizontal,s=!!a.constrained,l=a.angle||0,c=a.anchor||0,u=i.width,h=i.height,f=Math.abs(e-t),p=Math.abs(n-r),d=f>2*v&&p>2*v?v:0;f-=2*d,p-=2*d;var g=!1;if(!(\"auto\"===l)||u<=f&&h<=p||!(u>f||h>p)||(u>p||h>f)&&u<h==f<p||(g=!0),g){var x=p;p=f,f=x}var b=y(l),_=Math.abs(Math.sin(Math.PI/180*b)),w=Math.abs(Math.cos(Math.PI/180*b)),k=Math.max(f*w,p*_),T=Math.max(f*_,p*w),A=s?Math.min(k/u,T/h):Math.max(w,_);A=Math.min(1,A);var M=(t+e)/2,S=(r+n)/2;\"middle\"!==c&&(d+=.5*(A*(o!==g?h:u)*_+A*(o!==g?u:h)*w),o?(d*=m(t,e),M=\"start\"===c?t+d:e-d):(d*=m(r,n),S=\"start\"===c?r+d:n-d));return g&&(b+=90),{textX:(i.left+i.right)/2,textY:(i.top+i.bottom)/2,targetX:M,targetY:S,scale:A,rotate:b}}function b(t,e,r,n,i,a){var o,s=!!a.isHorizontal,l=!!a.constrained,c=a.angle||0,u=i.width,h=i.height,f=Math.abs(e-t),p=Math.abs(n-r);o=s?p>2*v?v:0:f>2*v?v:0;var d=1;l&&(d=s?Math.min(1,p/h):Math.min(1,f/u));var g=y(c);o+=.5*(d*(s?h:u)*Math.abs(Math.sin(Math.PI/180*g))+d*(s?u:h)*Math.abs(Math.cos(Math.PI/180*g)));var x=(t+e)/2,b=(r+n)/2;return s?x=e-o*m(e,t):b=n+o*m(r,n),{textX:(i.left+i.right)/2,textY:(i.top+i.bottom)/2,targetX:x,targetY:b,scale:d,rotate:g}}function _(t){var e,r=t.textX,n=t.textY,i=t.targetX,a=t.targetY,o=t.scale,s=t.rotate;return o<1?e=\"scale(\"+o+\") \":(o=1,e=\"\"),\"translate(\"+(i-o*r)+\" \"+(a-o*n)+\")\"+e+(s?\"rotate(\"+s+\" \"+r+\" \"+n+\") \":\"\")}e.exports={plot:function(t,e,r,p,y){var w=e.xaxis,k=e.yaxis,T=t._fullLayout;y||(y={mode:T.barmode,norm:T.barmode,gap:T.bargap,groupgap:T.bargroupgap});var A=a.makeTraceGroups(p,r,\"trace bars\").each(function(r){var c=n.select(this),p=r[0].trace,T=\"waterfall\"===p.type,A=\"funnel\"===p.type,M=\"bar\"===p.type||A,S=0;T&&p.connector.visible&&\"between\"===p.connector.mode&&(S=p.connector.line.width/2);var E=\"h\"===p.orientation,C=a.ensureSingle(c,\"g\",\"points\").selectAll(\"g.point\").data(a.identity);C.enter().append(\"g\").classed(\"point\",!0),C.exit().remove(),C.each(function(c,T){var A,C,L=n.select(this),P=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),n?[i,a]:[a,i]}(c,w,k,E),O=P[0][0],z=P[0][1],I=P[1][0],D=P[1][1],R=!(O!==z&&I!==D&&i(O)&&i(z)&&i(I)&&i(D));if(R&&M&&f.getLineWidth(p,c)&&(E?z-O==0:D-I==0)&&(R=!1),c.isBlank=R,S&&(E?(O-=m(O,z)*S,z+=m(O,z)*S):(I-=m(I,D)*S,D+=m(I,D)*S)),\"waterfall\"===p.type){if(!R){var F=p[c.dir].marker;A=F.line.width,C=F.color}}else A=f.getLineWidth(p,c),C=c.mc||p.marker.color;var B=n.round(A/2%1,2);function N(t){return 0===y.gap&&0===y.groupgap?n.round(Math.round(t)-B,2):t}if(!t._context.staticPlot){var j=s.opacity(C)<1||A>.01?N:function(t,e){return Math.abs(t-e)>=2?N(t):t>e?Math.ceil(t):Math.floor(t)};O=j(O,z),z=j(z,O),I=j(I,D),D=j(D,I)}a.ensureSingle(L,\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"d\",R?\"M0,0Z\":\"M\"+O+\",\"+I+\"V\"+D+\"H\"+z+\"V\"+I+\"Z\").call(l.setClipUrl,e.layerClipId,t),function(t,e,r,n,i,s,c,p,m,y){var w,k=e.xaxis,T=e.yaxis,A=t._fullLayout;function M(e,r,n){var i=a.ensureSingle(e,\"text\").text(r).attr({class:\"bartext bartext-\"+w,transform:\"\",\"text-anchor\":\"middle\",\"data-notex\":1}).call(l.font,n).call(o.convertToTspans,t);return i}var S=n[0].trace,E=\"h\"===S.orientation,C=function(t,e,r,n){var i,o=t[0].trace;return i=o.textinfo?function(t,e,r,n){var i=t[0].trace,o=\"h\"===i.orientation,s=\"waterfall\"===i.type,l=\"funnel\"===i.type;function c(t){var e=o?r:n;return u(e,+t,!0).text}var h,f,p=i.textinfo,d=t[e],g=p.split(\"+\"),v=[],m=function(t){return-1!==g.indexOf(t)};if(m(\"label\")&&v.push((f=t[e].p,u(o?n:r,f,!0).text)),m(\"text\")&&(0===(h=a.castOption(i,d.i,\"text\"))||h)&&v.push(h),s){var y=+d.rawS||d.s,x=d.v,b=x-y;m(\"initial\")&&v.push(c(b)),m(\"delta\")&&v.push(c(y)),m(\"final\")&&v.push(c(x))}if(l){m(\"value\")&&v.push(c(d.s));var _=0;m(\"percent initial\")&&_++,m(\"percent previous\")&&_++,m(\"percent total\")&&_++;var w=_>1;m(\"percent initial\")&&(h=a.formatPercent(d.begR),w&&(h+=\" of initial\"),v.push(h)),m(\"percent previous\")&&(h=a.formatPercent(d.difR),w&&(h+=\" of previous\"),v.push(h)),m(\"percent total\")&&(h=a.formatPercent(d.sumR),w&&(h+=\" of total\"),v.push(h))}return v.join(\"<br>\")}(t,e,r,n):f.getValue(o.text,e),f.coerceString(d,i)}(n,i,k,T);w=function(t,e){var r=f.getValue(t.textposition,e);return f.coerceEnumerated(g,r)}(S,i);var L=\"stack\"===y.mode||\"relative\"===y.mode,P=n[i],O=!L||P._outmost;if(C&&\"none\"!==w&&(!P.isBlank&&s!==c&&p!==m||\"auto\"!==w&&\"inside\"!==w)){var z=A.font,I=h.getBarColor(n[i],S),D=h.getInsideTextFont(S,i,z,I),R=h.getOutsideTextFont(S,i,z),F=r.datum();E?\"log\"===k.type&&F.s0<=0&&(s=k.range[0]<k.range[1]?0:k._length):\"log\"===T.type&&F.s0<=0&&(p=T.range[0]<T.range[1]?T._length:0);var B,N,j,U,V,q,H=Math.abs(c-s)-2*v,G=Math.abs(m-p)-2*v;if(\"outside\"===w&&(O||P.hasB||(w=\"inside\")),\"auto\"===w)if(O){w=\"inside\",B=M(r,C,D),N=l.bBox(B.node()),j=N.width,U=N.height;var Y=j>0&&U>0,W=j<=H&&U<=G,X=j<=G&&U<=H,Z=E?H>=j*(G/U):G>=U*(H/j);Y&&(W||X||Z)?w=\"inside\":(w=\"outside\",B.remove(),B=null)}else w=\"inside\";!B&&(B=M(r,C,\"outside\"===w?R:D),N=l.bBox(B.node()),j=N.width,U=N.height,j<=0||U<=0)?B.remove():(\"outside\"===w?(q=\"both\"===S.constraintext||\"outside\"===S.constraintext,V=_(b(s,c,p,m,N,{isHorizontal:E,constrained:q,angle:S.textangle}))):(q=\"both\"===S.constraintext||\"inside\"===S.constraintext,V=_(x(s,c,p,m,N,{isHorizontal:E,constrained:q,angle:S.textangle,anchor:S.insidetextanchor}))),B.attr(\"transform\",V))}else r.select(\"text\").remove()}(t,e,L,r,T,O,z,I,D,y),e.layerClipId&&l.hideOutsideRangePoint(c,L.select(\"text\"),w,k,p.xcalendar,p.ycalendar)});var L=!1===p.cliponaxis;l.setClipUrl(c,L?null:e.layerClipId,t)});c.getComponentMethod(\"errorbars\",\"plot\")(t,A,e)},getTransform:_,toMoveInsideBar:x,toMoveOutsideBar:b}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./attributes\":857,\"./helpers\":862,\"./style\":870,d3:163,\"fast-isnumeric\":225}],868:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=e.c2p(n?t.s0:t.p0,!0),o=e.c2p(n?t.s1:t.p1,!0),s=r.c2p(n?t.p0:t.s0,!0),l=r.c2p(n?t.p1:t.s1,!0);return i?[(a+o)/2,(s+l)/2]:n?[o,(s+l)/2]:[(a+o)/2,l]}e.exports=function(t,e){var r,i=t.cd,a=t.xaxis,o=t.yaxis,s=i[0].trace,l=\"funnel\"===s.type,c=\"h\"===s.orientation,u=[];if(!1===e)for(r=0;r<i.length;r++)i[r].selected=0;else for(r=0;r<i.length;r++){var h=i[r],f=\"ct\"in h?h.ct:n(h,a,o,c,l);e.contains(f,!1,r,t)?(u.push({pointNumber:r,x:a.c2d(h.x),y:o.c2d(h.y)}),h.selected=1):h.selected=0}return u}},{}],869:[function(t,e,r){\"use strict\";e.exports=a;var n=t(\"../../lib\").distinctVals,i=t(\"../../constants/numerical\").BADNUM;function a(t,e){this.traces=t,this.sepNegVal=e.sepNegVal,this.overlapNoMerge=e.overlapNoMerge;for(var r=1/0,a=[],o=0;o<t.length;o++){for(var s=t[o],l=0;l<s.length;l++){var c=s[l];c.p!==i&&a.push(c.p)}s[0]&&s[0].width1&&(r=Math.min(s[0].width1,r))}this.positions=a;var u=n(a);this.distinctPositions=u.vals,1===u.vals.length&&r!==1/0?this.minDiff=r:this.minDiff=Math.min(u.minDiff,r),this.binWidth=this.minDiff,this.bins={}}a.prototype.put=function(t,e){var r=this.getLabel(t,e),n=this.bins[r]||0;return this.bins[r]=n+e,n},a.prototype.get=function(t,e){var r=this.getLabel(t,e);return this.bins[r]||0},a.prototype.getLabel=function(t,e){return(e<0&&this.sepNegVal?\"v\":\"^\")+(this.overlapNoMerge?t:Math.round(t/this.binWidth))}},{\"../../constants/numerical\":695,\"../../lib\":719}],870:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../lib\"),s=t(\"../../registry\"),l=t(\"./attributes\"),c=l.textfont,u=l.insidetextfont,h=l.outsidetextfont,f=t(\"./helpers\");function p(t,e,r){a.pointStyle(t.selectAll(\"path\"),e,r),d(t,e,r)}function d(t,e,r){t.selectAll(\"text\").each(function(t){var i=n.select(this),o=g(i,t,e,r);a.font(i,o)})}function g(t,e,r,n){var i=n._fullLayout.font,a=r.textfont;if(t.classed(\"bartext-inside\")){var o=b(e,r);a=m(r,e.i,i,o)}else t.classed(\"bartext-outside\")&&(a=y(r,e.i,i));return a}function v(t,e,r){return x(c,t.textfont,e,r)}function m(t,e,r,n){var a=v(t,e,r);return(void 0===t._input.textfont||void 0===t._input.textfont.color||Array.isArray(t.textfont.color)&&void 0===t.textfont.color[e])&&(a={color:i.contrast(n),family:a.family,size:a.size}),x(u,t.insidetextfont,e,a)}function y(t,e,r){var n=v(t,e,r);return x(h,t.outsidetextfont,e,n)}function x(t,e,r,n){e=e||{};var i=f.getValue(e.family,r),a=f.getValue(e.size,r),o=f.getValue(e.color,r);return{family:f.coerceString(t.family,i,n.family),size:f.coerceNumber(t.size,a,n.size),color:f.coerceColor(t.color,o,n.color)}}function b(t,e){return\"waterfall\"===e.type?e[t.dir].marker.color:t.mc||e.marker.color}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.barlayer\").selectAll(\"g.trace\"),r=e.size(),i=t._fullLayout;e.style(\"opacity\",function(t){return t[0].trace.opacity}).each(function(t){(\"stack\"===i.barmode&&r>1||0===i.bargap&&0===i.bargroupgap&&!t[0].trace.marker.line.width)&&n.select(this).attr(\"shape-rendering\",\"crispEdges\")}),e.selectAll(\"g.points\").each(function(e){p(n.select(this),e[0].trace,t)}),s.getComponentMethod(\"errorbars\",\"style\")(e)},styleTextPoints:d,styleOnSelect:function(t,e,r){var i=e[0].trace;i.selectedpoints?function(t,e,r){a.selectedPointStyle(t.selectAll(\"path\"),e),function(t,e,r){t.each(function(t){var i,s=n.select(this);if(t.selected){i=o.extendFlat({},g(s,t,e,r));var l=e.selected.textfont&&e.selected.textfont.color;l&&(i.color=l),a.font(s,i)}else a.selectedTextStyle(s,e)})}(t.selectAll(\"text\"),e,r)}(r,i,t):(p(r,i,t),s.getComponentMethod(\"errorbars\",\"style\")(r))},getInsideTextFont:m,getOutsideTextFont:y,getBarColor:b}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../registry\":847,\"./attributes\":857,\"./helpers\":862,d3:163}],871:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s){r(\"marker.color\",o),i(t,\"marker\")&&a(t,e,s,r,{prefix:\"marker.\",cLetter:\"c\"}),r(\"marker.line.color\",n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,r,{prefix:\"marker.line.\",cLetter:\"c\"}),r(\"marker.line.width\"),r(\"marker.opacity\"),r(\"selected.marker.color\"),r(\"unselected.marker.color\")}},{\"../../components/color\":593,\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604}],872:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../scatterpolar/attributes\"),o=t(\"../bar/attributes\");e.exports={r:a.r,theta:a.theta,r0:a.r0,dr:a.dr,theta0:a.theta0,dtheta:a.dtheta,thetaunit:a.thetaunit,base:i({},o.base,{}),offset:i({},o.offset,{}),width:i({},o.width,{}),text:i({},o.text,{}),hovertext:i({},o.hovertext,{}),marker:o.marker,hoverinfo:a.hoverinfo,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../bar/attributes\":857,\"../scatterpolar/attributes\":1179}],873:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"../bar/arrays_to_calcdata\"),o=t(\"../bar/cross_trace_calc\").setGroupPositions,s=t(\"../scatter/calc_selection\"),l=t(\"../../registry\").traceIs,c=t(\"../../lib\").extendFlat;e.exports={calc:function(t,e){for(var r=t._fullLayout,o=e.subplot,l=r[o].radialaxis,c=r[o].angularaxis,u=l.makeCalcdata(e,\"r\"),h=c.makeCalcdata(e,\"theta\"),f=e._length,p=new Array(f),d=u,g=h,v=0;v<f;v++)p[v]={p:g[v],s:d[v]};function m(t){var r=e[t];void 0!==r&&(e[\"_\"+t]=Array.isArray(r)?c.makeCalcdata(e,t):c.d2c(r,e.thetaunit))}return\"linear\"===c.type&&(m(\"width\"),m(\"offset\")),n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),a(p,e),s(p,e),p},crossTraceCalc:function(t,e,r){for(var n=t.calcdata,i=[],a=0;a<n.length;a++){var s=n[a],u=s[0].trace;!0===u.visible&&l(u,\"bar\")&&u.subplot===r&&i.push(s)}var h=c({},e.radialaxis,{_id:\"x\"}),f=e.angularaxis;o(t,f,h,i,{mode:e.barmode,norm:e.barnorm,gap:e.bargap,groupgap:e.bargroupgap})}}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"../../lib\":719,\"../../registry\":847,\"../bar/arrays_to_calcdata\":856,\"../bar/cross_trace_calc\":860,\"../scatter/calc_selection\":1114}],874:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatterpolar/defaults\").handleRThetaDefaults,a=t(\"../bar/style_defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}i(t,e,s,l)?(l(\"thetaunit\"),l(\"base\"),l(\"offset\"),l(\"width\"),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),a(t,e,l,r,s),n.coerceSelectionMarkerOpacity(e,l)):e.visible=!1}},{\"../../lib\":719,\"../bar/style_defaults\":871,\"../scatterpolar/defaults\":1181,\"./attributes\":872}],875:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../bar/hover\").getTraceColor,o=i.fillText,s=t(\"../scatterpolar/hover\").makeHoverPointText,l=t(\"../../plots/polar/helpers\").isPtInsidePolygon;e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,h=t.subplot,f=h.radialAxis,p=h.angularAxis,d=h.vangles,g=d?l:i.isPtInsideSector,v=t.maxHoverDistance,m=p._period||2*Math.PI,y=Math.abs(f.g2p(Math.sqrt(e*e+r*r))),x=Math.atan2(r,e);f.range[0]>f.range[1]&&(x+=Math.PI);if(n.getClosest(c,function(t){return g(y,x,[t.rp0,t.rp1],[t.thetag0,t.thetag1],d)?v+Math.min(1,Math.abs(t.thetag1-t.thetag0)/m)-1+(t.rp1-y)/(t.rp1-t.rp0)-1:1/0},t),!1!==t.index){var b=c[t.index];t.x0=t.x1=b.ct[0],t.y0=t.y1=b.ct[1];var _=i.extendFlat({},b,{r:b.s,theta:b.p});return o(b,u,t),s(_,u,h,t),t.hovertemplate=u.hovertemplate,t.color=a(u,b),t.xLabelVal=t.yLabelVal=void 0,b.s<0&&(t.idealAlign=\"left\"),[t]}}},{\"../../components/fx\":632,\"../../lib\":719,\"../../plots/polar/helpers\":830,\"../bar/hover\":863,\"../scatterpolar/hover\":1182}],876:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"barpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"bar\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),colorbar:t(\"../scatter/marker_colorbar\"),style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),meta:{}}},{\"../../plots/polar\":831,\"../bar/select\":868,\"../bar/style\":870,\"../scatter/marker_colorbar\":1129,\"./attributes\":872,\"./calc\":873,\"./defaults\":874,\"./hover\":875,\"./layout_attributes\":877,\"./layout_defaults\":878,\"./plot\":879}],877:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},bargap:{valType:\"number\",dflt:.1,min:0,max:1,editType:\"calc\"}}},{}],878:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a,o={};function s(r,o){return n.coerce(t[a]||{},e[a],i,r,o)}for(var l=0;l<r.length;l++){var c=r[l];\"barpolar\"===c.type&&!0===c.visible&&(o[a=c.subplot]||(s(\"barmode\"),s(\"bargap\"),o[a]=1))}}},{\"../../lib\":719,\"./layout_attributes\":877}],879:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../components/drawing\"),s=t(\"../../plots/polar/helpers\");e.exports=function(t,e,r){var l=e.xaxis,c=e.yaxis,u=e.radialAxis,h=e.angularAxis,f=function(t){var e=t.cxx,r=t.cyy;if(t.vangles)return function(n,i,o,l){var c,u;a.angleDelta(o,l)>0?(c=o,u=l):(c=l,u=o);var h=s.findEnclosingVertexAngles(c,t.vangles)[0],f=s.findEnclosingVertexAngles(u,t.vangles)[1],p=[h,(c+u)/2,f];return s.pathPolygonAnnulus(n,i,c,u,p,e,r)};return function(t,n,i,o){return a.pathAnnulus(t,n,i,o,e,r)}}(e),p=e.layers.frontplot.select(\"g.barlayer\");a.makeTraceGroups(p,r,\"trace bars\").each(function(){var r=n.select(this),s=a.ensureSingle(r,\"g\",\"points\").selectAll(\"g.point\").data(a.identity);s.enter().append(\"g\").style(\"vector-effect\",\"non-scaling-stroke\").style(\"stroke-miterlimit\",2).classed(\"point\",!0),s.exit().remove(),s.each(function(t){var e,r=n.select(this),o=t.rp0=u.c2p(t.s0),s=t.rp1=u.c2p(t.s1),p=t.thetag0=h.c2g(t.p0),d=t.thetag1=h.c2g(t.p1);if(i(o)&&i(s)&&i(p)&&i(d)&&o!==s&&p!==d){var g=u.c2g(t.s1),v=(p+d)/2;t.ct=[l.c2p(g*Math.cos(v)),c.c2p(g*Math.sin(v))],e=f(o,s,p,d)}else e=\"M0,0Z\";a.ensureSingle(r,\"path\").attr(\"d\",e)}),o.setClipUrl(r,e._hasClipOnAxisFalse?e.clipIds.forTraces:null,t)})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../plots/polar/helpers\":830,d3:163,\"fast-isnumeric\":225}],880:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../bar/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../lib/extend\").extendFlat,l=n.marker,c=l.line;e.exports={y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},y0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},name:{valType:\"string\",editType:\"calc+clearAxisTypes\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),hovertemplate:o({}),whiskerwidth:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"calc\"},notched:{valType:\"boolean\",editType:\"calc\"},notchwidth:{valType:\"number\",min:0,max:.5,dflt:.25,editType:\"calc\"},boxpoints:{valType:\"enumerated\",values:[\"all\",\"outliers\",\"suspectedoutliers\",!1],dflt:\"outliers\",editType:\"calc\"},boxmean:{valType:\"enumerated\",values:[!0,\"sd\",!1],dflt:!1,editType:\"calc\"},jitter:{valType:\"number\",min:0,max:1,editType:\"calc\"},pointpos:{valType:\"number\",min:-2,max:2,editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},width:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},marker:{outliercolor:{valType:\"color\",dflt:\"rgba(0, 0, 0, 0)\",editType:\"style\"},symbol:s({},l.symbol,{arrayOk:!1,editType:\"plot\"}),opacity:s({},l.opacity,{arrayOk:!1,dflt:1,editType:\"style\"}),size:s({},l.size,{arrayOk:!1,editType:\"calc\"}),color:s({},l.color,{arrayOk:!1,editType:\"style\"}),line:{color:s({},c.color,{arrayOk:!1,dflt:a.defaultLine,editType:\"style\"}),width:s({},c.width,{arrayOk:!1,dflt:0,editType:\"style\"}),outliercolor:{valType:\"color\",editType:\"style\"},outlierwidth:{valType:\"number\",min:0,dflt:1,editType:\"style\"},editType:\"style\"},editType:\"plot\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,offsetgroup:i.offsetgroup,alignmentgroup:i.alignmentgroup,selected:{marker:n.selected.marker,editType:\"style\"},unselected:{marker:n.unselected.marker,editType:\"style\"},hoveron:{valType:\"flaglist\",flags:[\"boxes\",\"points\"],dflt:\"boxes+points\",editType:\"style\"}}},{\"../../components/color/attributes\":592,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../bar/attributes\":857,\"../scatter/attributes\":1112}],881:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=i._,o=t(\"../../plots/cartesian/axes\");function s(t,e,r){var n={text:\"tx\",hovertext:\"htx\"};for(var i in n)Array.isArray(e[i])&&(t[n[i]]=e[i][r])}function l(t,e){return t.v-e.v}function c(t){return t.v}e.exports=function(t,e){var r,u,h,f,p,d=t._fullLayout,g=o.getFromId(t,e.xaxis||\"x\"),v=o.getFromId(t,e.yaxis||\"y\"),m=[],y=\"violin\"===e.type?\"_numViolins\":\"_numBoxes\";\"h\"===e.orientation?(u=g,h=\"x\",f=v,p=\"y\"):(u=v,h=\"y\",f=g,p=\"x\");var x,b=u.makeCalcdata(e,h),_=function(t,e,r,a,o){if(e in t)return r.makeCalcdata(t,e);var s;s=e+\"0\"in t?t[e+\"0\"]:\"name\"in t&&(\"category\"===r.type||n(t.name)&&-1!==[\"linear\",\"log\"].indexOf(r.type)||i.isDateTime(t.name)&&\"date\"===r.type)?t.name:o;var l=\"multicategory\"===r.type?r.r2c_just_indices(s):r.d2c(s,0,t[e+\"calendar\"]);return a.map(function(){return l})}(e,p,f,b,d[y]),w=i.distinctVals(_),k=w.vals,T=w.minDiff/2,A=function(t,e){for(var r=t.length,n=new Array(r+1),i=0;i<r;i++)n[i]=t[i]-e;return n[r]=t[r-1]+e,n}(k,T),M=k.length,S=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=[];return e}(M);for(r=0;r<e._length;r++){var E=b[r];if(n(E)){var C=i.findBin(_[r],A);if(C>=0&&C<M){var L={v:E,i:r};s(L,e,r),S[C].push(L)}}}var P=\"all\"===(e.boxpoints||e.points)?i.identity:function(t){return t.v<x.lf||t.v>x.uf};for(r=0;r<M;r++)if(S[r].length>0){var O=S[r].sort(l),z=O.map(c),I=z.length;(x={}).pos=k[r],x.pts=O,x[p]=x.pos,x[h]=x.pts.map(function(t){return t.v}),x.min=z[0],x.max=z[I-1],x.mean=i.mean(z,I),x.sd=i.stdev(z,I,x.mean),x.q1=i.interp(z,.25),x.med=i.interp(z,.5),x.q3=i.interp(z,.75),x.lf=Math.min(x.q1,z[Math.min(i.findBin(2.5*x.q1-1.5*x.q3,z,!0)+1,I-1)]),x.uf=Math.max(x.q3,z[Math.max(i.findBin(2.5*x.q3-1.5*x.q1,z),0)]),x.lo=4*x.q1-3*x.q3,x.uo=4*x.q3-3*x.q1;var D=1.57*(x.q3-x.q1)/Math.sqrt(I);x.ln=x.med-D,x.un=x.med+D,x.pts2=O.filter(P),m.push(x)}!function(t,e){if(i.isArrayOrTypedArray(e.selectedpoints))for(var r=0;r<t.length;r++){for(var n=t[r].pts||[],a={},o=0;o<n.length;o++)a[n[o].i]=o;i.tagSelected(n,e,a)}}(m,e);var R=o.findExtremes(u,b,{padded:!0});return e._extremes[u._id]=R,m.length>0?(m[0].t={num:d[y],dPos:T,posLetter:p,valLetter:h,labels:{med:a(t,\"median:\"),min:a(t,\"min:\"),q1:a(t,\"q1:\"),q3:a(t,\"q3:\"),max:a(t,\"max:\"),mean:\"sd\"===e.boxmean?a(t,\"mean \\xb1 \\u03c3:\"):a(t,\"mean:\"),lf:a(t,\"lower fence:\"),uf:a(t,\"upper fence:\")}},d[y]++,m):[{t:{empty:!0}}]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"fast-isnumeric\":225}],882:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,o=[\"v\",\"h\"];function s(t,e,r,o){var s,l,c,u=e.calcdata,h=e._fullLayout,f=o._id,p=f.charAt(0),d=[],g=0;for(s=0;s<r.length;s++)for(c=u[r[s]],l=0;l<c.length;l++)d.push(c[l].pos),g+=(c[l].pts2||[]).length;if(d.length){var v=i.distinctVals(d),m=v.minDiff/2;n.minDtick(o,v.minDiff,v.vals[0],!0);var y=h[\"violin\"===t?\"_numViolins\":\"_numBoxes\"],x=\"group\"===h[t+\"mode\"]&&y>1,b=1-h[t+\"gap\"],_=1-h[t+\"groupgap\"];for(s=0;s<r.length;s++){var w,k,T,A,M,S,E=(c=u[r[s]])[0].trace,C=c[0].t,L=E.width,P=E.side;if(L)w=k=A=L/2,T=0;else if(w=m,x){var O=a(h,o._id)+E.orientation,z=(h._alignmentOpts[O]||{})[E.alignmentgroup]||{},I=Object.keys(z.offsetGroups||{}).length,D=I||y;k=w*b*_/D,T=2*w*(((I?E._offsetIndex:C.num)+.5)/D-.5)*b,A=w*b/D}else k=w*b*_,T=0,A=w;C.dPos=w,C.bPos=T,C.bdPos=k,C.wHover=A;var R,F,B,N,j,U,V=T+k,q=Boolean(L);if(\"positive\"===P?(M=w*(L?1:.5),R=V,S=R=T):\"negative\"===P?(M=R=T,S=w*(L?1:.5),F=V):(M=S=w,R=F=V),(E.boxpoints||E.points)&&g>0){var H=E.pointpos,G=E.jitter,Y=E.marker.size/2,W=0;H+G>=0&&((W=V*(H+G))>M?(q=!0,j=Y,B=W):W>R&&(j=Y,B=M)),W<=M&&(B=M);var X=0;H-G<=0&&((X=-V*(H-G))>S?(q=!0,U=Y,N=X):X>F&&(U=Y,N=S)),X<=S&&(N=S)}else B=M,N=S;var Z=new Array(c.length);for(l=0;l<c.length;l++)Z[l]=c[l].pos;E._extremes[f]=n.findExtremes(o,Z,{padded:q,vpadminus:N,vpadplus:B,ppadminus:{x:U,y:j}[p],ppadplus:{x:j,y:U}[p]})}}}e.exports={crossTraceCalc:function(t,e){for(var r=t.calcdata,n=e.xaxis,i=e.yaxis,a=0;a<o.length;a++){for(var l=o[a],c=\"h\"===l?i:n,u=[],h=0;h<r.length;h++){var f=r[h],p=f[0].t,d=f[0].trace;!0!==d.visible||\"box\"!==d.type&&\"candlestick\"!==d.type||p.empty||(d.orientation||\"v\")!==l||d.xaxis!==n._id||d.yaxis!==i._id||u.push(h)}s(\"box\",t,u,c)}},setPositionOffset:s}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_ids\":770}],883:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../bar/defaults\").handleGroupingDefaults,s=t(\"./attributes\");function l(t,e,r,a){var o,s,l=r(\"y\"),c=r(\"x\"),u=c&&c.length;if(l&&l.length)o=\"v\",u?s=Math.min(n.minRowLength(c),n.minRowLength(l)):(r(\"x0\"),s=n.minRowLength(l));else{if(!u)return void(e.visible=!1);o=\"h\",r(\"y0\"),s=n.minRowLength(c)}e._length=s,i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a),r(\"orientation\",o)}function c(t,e,r,i){var a=i.prefix,o=n.coerce2(t,e,s,\"marker.outliercolor\"),l=r(\"marker.line.outliercolor\"),c=r(a+\"points\",o||l?\"suspectedoutliers\":void 0);c?(r(\"jitter\",\"all\"===c?.3:0),r(\"pointpos\",\"all\"===c?-1.5:0),r(\"marker.symbol\"),r(\"marker.opacity\"),r(\"marker.size\"),r(\"marker.color\",e.line.color),r(\"marker.line.color\"),r(\"marker.line.width\"),\"suspectedoutliers\"===c&&(r(\"marker.line.outliercolor\",e.marker.color),r(\"marker.line.outlierwidth\")),r(\"selected.marker.color\"),r(\"unselected.marker.color\"),r(\"selected.marker.size\"),r(\"unselected.marker.size\"),r(\"text\"),r(\"hovertext\")):delete e.marker;var u=r(\"hoveron\");\"all\"!==u&&-1===u.indexOf(\"points\")||r(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,r)}e.exports={supplyDefaults:function(t,e,r,i){function o(r,i){return n.coerce(t,e,s,r,i)}l(t,e,o,i),!1!==e.visible&&(o(\"line.color\",(t.marker||{}).color||r),o(\"line.width\"),o(\"fillcolor\",a.addOpacity(e.line.color,.5)),o(\"whiskerwidth\"),o(\"boxmean\"),o(\"width\"),o(\"notched\",void 0!==t.notchwidth)&&o(\"notchwidth\"),c(t,e,o,{prefix:\"box\"}))},crossTraceDefaults:function(t,e){var r,i;function a(t){return n.coerce(i._input,i,s,t)}for(var l=0;l<t.length;l++){var c=(i=t[l]).type;\"box\"!==c&&\"violin\"!==c||(r=i._input,\"group\"===e[c+\"mode\"]&&o(r,i,e,a))}},handleSampleDefaults:l,handlePointsDefaults:c}},{\"../../components/color\":593,\"../../lib\":719,\"../../registry\":847,\"../bar/defaults\":861,\"./attributes\":880}],884:[function(t,e,r){\"use strict\";e.exports=function(t,e){return e.hoverOnBox&&(t.hoverOnBox=e.hoverOnBox),\"xVal\"in e&&(t.x=e.xVal),\"yVal\"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],885:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=i.fillText;function l(t,e,r,s){var l,c,u,h,f,p,d,g,v,m,y,x,b,_,w=t.cd,k=t.xa,T=t.ya,A=w[0].trace,M=w[0].t,S=\"violin\"===A.type,E=[],C=M.bdPos,L=M.wHover,P=function(t){return t.pos+M.bPos-p};S&&\"both\"!==A.side?(\"positive\"===A.side&&(v=function(t){var e=P(t);return a.inbox(e,e+L,m)},x=C,b=0),\"negative\"===A.side&&(v=function(t){var e=P(t);return a.inbox(e-L,e,m)},x=0,b=C)):(v=function(t){var e=P(t);return a.inbox(e-L,e+L,m)},x=b=C),_=S?function(t){return a.inbox(t.span[0]-f,t.span[1]-f,m)}:function(t){return a.inbox(t.min-f,t.max-f,m)},\"h\"===A.orientation?(f=e,p=r,d=_,g=v,l=\"y\",u=T,c=\"x\",h=k):(f=r,p=e,d=v,g=_,l=\"x\",u=k,c=\"y\",h=T);var O=Math.min(1,C/Math.abs(u.r2c(u.range[1])-u.r2c(u.range[0])));function z(t){return(d(t)+g(t))/2}m=t.maxHoverDistance-O,y=t.maxSpikeDistance-O;var I=a.getDistanceFunction(s,d,g,z);if(a.getClosest(w,I,t),!1===t.index)return[];var D=w[t.index],R=A.line.color,F=(A.marker||{}).color;o.opacity(R)&&A.line.width?t.color=R:o.opacity(F)&&A.boxpoints?t.color=F:t.color=A.fillcolor,t[l+\"0\"]=u.c2p(D.pos+M.bPos-b,!0),t[l+\"1\"]=u.c2p(D.pos+M.bPos+x,!0),t[l+\"LabelVal\"]=D.pos;var B=l+\"Spike\";t.spikeDistance=z(D)*y/m,t[B]=u.c2p(D.pos,!0);var N={},j=[\"med\",\"q1\",\"q3\",\"min\",\"max\"];(A.boxmean||(A.meanline||{}).visible)&&j.push(\"mean\"),(A.boxpoints||A.points)&&j.push(\"lf\",\"uf\");for(var U=0;U<j.length;U++){var V=j[U];if(V in D&&!(D[V]in N)){N[D[V]]=!0;var q=D[V],H=h.c2p(q,!0),G=i.extendFlat({},t);G.attr=V,G[c+\"0\"]=G[c+\"1\"]=H,G[c+\"LabelVal\"]=q,G[c+\"Label\"]=(M.labels?M.labels[V]+\" \":\"\")+n.hoverLabelText(h,q),G.hoverOnBox=!0,\"mean\"===V&&\"sd\"in D&&\"sd\"===A.boxmean&&(G[c+\"err\"]=D.sd),t.name=\"\",t.spikeDistance=void 0,t[B]=void 0,G.hovertemplate=!1,E.push(G)}}return E}function c(t,e,r){for(var n,o,l,c=t.cd,u=t.xa,h=t.ya,f=c[0].trace,p=u.c2p(e),d=h.c2p(r),g=a.quadrature(function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(u.c2p(t.x)-p)-e,1-3/e)},function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(h.c2p(t.y)-d)-e,1-3/e)}),v=!1,m=0;m<c.length;m++){o=c[m];for(var y=0;y<(o.pts||[]).length;y++){var x=g(l=o.pts[y]);x<=t.distance&&(t.distance=x,v=[m,y])}}if(!v)return!1;l=(o=c[v[0]]).pts[v[1]];var b,_=u.c2p(l.x,!0),w=h.c2p(l.y,!0),k=l.mrc||1;return n=i.extendFlat({},t,{index:l.i,color:(f.marker||{}).color,name:f.name,x0:_-k,x1:_+k,y0:w-k,y1:w+k,spikeDistance:t.distance,hovertemplate:f.hovertemplate}),\"h\"===f.orientation?(b=h,n.xLabelVal=l.x,n.yLabelVal=o.pos):(b=u,n.xLabelVal=o.pos,n.yLabelVal=l.y),n[b._id.charAt(0)+\"Spike\"]=b.c2p(o.pos,!0),s(l,f,n),n}e.exports={hoverPoints:function(t,e,r,n){var i,a=t.cd[0].trace.hoveron,o=[];return-1!==a.indexOf(\"boxes\")&&(o=o.concat(l(t,e,r,n))),-1!==a.indexOf(\"points\")&&(i=c(t,e,r)),\"closest\"===n?i?[i]:o:i?(o.push(i),o):o},hoverOnBoxes:l,hoverOnPoints:c}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],886:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\").supplyLayoutDefaults,calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"box\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"boxLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":880,\"./calc\":881,\"./cross_trace_calc\":882,\"./defaults\":883,\"./event_data\":884,\"./hover\":885,\"./layout_attributes\":887,\"./layout_defaults\":888,\"./plot\":889,\"./select\":890,\"./style\":891}],887:[function(t,e,r){\"use strict\";e.exports={boxmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"overlay\",editType:\"calc\"},boxgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"},boxgroupgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"}}},{}],888:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./layout_attributes\");function o(t,e,r,i,a){for(var o=a+\"Layout\",s=!1,l=0;l<r.length;l++){var c=r[l];if(n.traceIs(c,o)){s=!0;break}}s&&(i(a+\"mode\"),i(a+\"gap\"),i(a+\"groupgap\"))}e.exports={supplyLayoutDefaults:function(t,e,r){o(0,0,r,function(r,n){return i.coerce(t,e,a,r,n)},\"box\")},_supply:o}},{\"../../lib\":719,\"../../registry\":847,\"./layout_attributes\":887}],889:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=5,s=.01;function l(t,e,r,a){var o,s,l=e.pos,c=e.val,u=a.bPos,h=a.wdPos||0,f=a.bPosPxOffset||0,p=r.whiskerwidth||0,d=r.notched||!1,g=d?1-2*r.notchwidth:1;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var v=t.selectAll(\"path.box\").data(\"violin\"!==r.type||r.box.visible?i.identity:[]);v.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"box\"),v.exit().remove(),v.each(function(t){if(t.empty)return\"M0,0Z\";var e=t.pos,a=l.c2p(e+u,!0)+f,v=l.c2p(e+u-o,!0)+f,m=l.c2p(e+u+s,!0)+f,y=l.c2p(e+u-h,!0)+f,x=l.c2p(e+u+h,!0)+f,b=l.c2p(e+u-o*g,!0)+f,_=l.c2p(e+u+s*g,!0)+f,w=c.c2p(t.q1,!0),k=c.c2p(t.q3,!0),T=i.constrain(c.c2p(t.med,!0),Math.min(w,k)+1,Math.max(w,k)-1),A=void 0===t.lf||!1===r.boxpoints,M=c.c2p(A?t.min:t.lf,!0),S=c.c2p(A?t.max:t.uf,!0),E=c.c2p(t.ln,!0),C=c.c2p(t.un,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+T+\",\"+b+\"V\"+_+\"M\"+w+\",\"+v+\"V\"+m+(d?\"H\"+E+\"L\"+T+\",\"+_+\"L\"+C+\",\"+m:\"\")+\"H\"+k+\"V\"+v+(d?\"H\"+C+\"L\"+T+\",\"+b+\"L\"+E+\",\"+v:\"\")+\"ZM\"+w+\",\"+a+\"H\"+M+\"M\"+k+\",\"+a+\"H\"+S+(0===p?\"\":\"M\"+M+\",\"+y+\"V\"+x+\"M\"+S+\",\"+y+\"V\"+x)):n.select(this).attr(\"d\",\"M\"+b+\",\"+T+\"H\"+_+\"M\"+v+\",\"+w+\"H\"+m+(d?\"V\"+E+\"L\"+_+\",\"+T+\"L\"+m+\",\"+C:\"\")+\"V\"+k+\"H\"+v+(d?\"V\"+C+\"L\"+b+\",\"+T+\"L\"+v+\",\"+E:\"\")+\"ZM\"+a+\",\"+w+\"V\"+M+\"M\"+a+\",\"+k+\"V\"+S+(0===p?\"\":\"M\"+y+\",\"+M+\"H\"+x+\"M\"+y+\",\"+S+\"H\"+x))})}function c(t,e,r,n){var l=e.x,c=e.y,u=n.bdPos,h=n.bPos,f=r.boxpoints||r.points;i.seedPseudoRandom();var p=t.selectAll(\"g.points\").data(f?function(t){return t.forEach(function(t){t.t=n,t.trace=r}),t}:[]);p.enter().append(\"g\").attr(\"class\",\"points\"),p.exit().remove();var d=p.selectAll(\"path\").data(function(t){var e,n,a=t.pts2,l=Math.max((t.max-t.min)/10,t.q3-t.q1),c=1e-9*l,p=l*s,d=[],g=0;if(r.jitter){if(0===l)for(g=1,d=new Array(a.length),e=0;e<a.length;e++)d[e]=1;else for(e=0;e<a.length;e++){var v=Math.max(0,e-o),m=a[v].v,y=Math.min(a.length-1,e+o),x=a[y].v;\"all\"!==f&&(a[e].v<t.lf?x=Math.min(x,t.lf):m=Math.max(m,t.uf));var b=Math.sqrt(p*(y-v)/(x-m+c))||0;b=i.constrain(Math.abs(b),0,1),d.push(b),g=Math.max(b,g)}n=2*r.jitter/(g||1)}for(e=0;e<a.length;e++){var _=a[e],w=_.v,k=r.jitter?n*d[e]*(i.pseudoRandom()-.5):0,T=t.pos+h+u*(r.pointpos+k);\"h\"===r.orientation?(_.y=T,_.x=w):(_.x=T,_.y=w),\"suspectedoutliers\"===f&&w<t.uo&&w>t.lo&&(_.so=!0)}return a});d.enter().append(\"path\").classed(\"point\",!0),d.exit().remove(),d.call(a.translatePoints,l,c)}function u(t,e,r,a){var o,s,l=e.pos,c=e.val,u=a.bPos,h=a.bPosPxOffset||0,f=r.boxmean||(r.meanline||{}).visible;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var p=t.selectAll(\"path.mean\").data(\"box\"===r.type&&r.boxmean||\"violin\"===r.type&&r.box.visible&&r.meanline.visible?i.identity:[]);p.enter().append(\"path\").attr(\"class\",\"mean\").style({fill:\"none\",\"vector-effect\":\"non-scaling-stroke\"}),p.exit().remove(),p.each(function(t){var e=l.c2p(t.pos+u,!0)+h,i=l.c2p(t.pos+u-o,!0)+h,a=l.c2p(t.pos+u+s,!0)+h,p=c.c2p(t.mean,!0),d=c.c2p(t.mean-t.sd,!0),g=c.c2p(t.mean+t.sd,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+p+\",\"+i+\"V\"+a+(\"sd\"===f?\"m0,0L\"+d+\",\"+e+\"L\"+p+\",\"+i+\"L\"+g+\",\"+e+\"Z\":\"\")):n.select(this).attr(\"d\",\"M\"+i+\",\"+p+\"H\"+a+(\"sd\"===f?\"m0,0L\"+e+\",\"+d+\"L\"+i+\",\"+p+\"L\"+e+\",\"+g+\"Z\":\"\"))})}e.exports={plot:function(t,e,r,a){var o=e.xaxis,s=e.yaxis;i.makeTraceGroups(a,r,\"trace boxes\").each(function(t){var e,r,i=n.select(this),a=t[0],h=a.t,f=a.trace;h.wdPos=h.bdPos*f.whiskerwidth,!0!==f.visible||h.empty?i.remove():(\"h\"===f.orientation?(e=s,r=o):(e=o,r=s),l(i,{pos:e,val:r},f,h),c(i,{x:o,y:s},f,h),u(i,{pos:e,val:r},f,h))})},plotBoxAndWhiskers:l,plotPoints:c,plotBoxMean:u}},{\"../../components/drawing\":614,\"../../lib\":719,d3:163}],890:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i=t.cd,a=t.xaxis,o=t.yaxis,s=[];if(!1===e)for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++)i[r].pts[n].selected=0;else for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++){var l=i[r].pts[n],c=a.c2p(l.x),u=o.c2p(l.y);e.contains([c,u],null,l.i,t)?(s.push({pointNumber:l.i,x:a.c2d(l.x),y:o.c2d(l.y)}),l.selected=1):l.selected=0}return s}},{}],891:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\");e.exports={style:function(t,e,r){var o=r||n.select(t).selectAll(\"g.trace.boxes\");o.style(\"opacity\",function(t){return t[0].trace.opacity}),o.each(function(e){var r=n.select(this),o=e[0].trace,s=o.line.width;function l(t,e,r,n){t.style(\"stroke-width\",e+\"px\").call(i.stroke,r).call(i.fill,n)}var c=r.selectAll(\"path.box\");if(\"candlestick\"===o.type)c.each(function(t){if(!t.empty){var e=n.select(this),r=o[t.dir];l(e,r.line.width,r.line.color,r.fillcolor),e.style(\"opacity\",o.selectedpoints&&!t.selected?.3:1)}});else{l(c,s,o.line.color,o.fillcolor),r.selectAll(\"path.mean\").style({\"stroke-width\":s,\"stroke-dasharray\":2*s+\"px,\"+s+\"px\"}).call(i.stroke,o.line.color);var u=r.selectAll(\"path.point\");a.pointStyle(u,o,t)}})},styleOnSelect:function(t,e,r){var n=e[0].trace,i=r.selectAll(\"path.point\");n.selectedpoints?a.selectedPointStyle(i,n):a.pointStyle(i,n,t)}}},{\"../../components/color\":593,\"../../components/drawing\":614,d3:163}],892:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../ohlc/attributes\"),a=t(\"../box/attributes\");function o(t){return{line:{color:n({},a.line.color,{dflt:t}),width:a.line.width,editType:\"style\"},fillcolor:a.fillcolor,editType:\"style\"}}e.exports={x:i.x,open:i.open,high:i.high,low:i.low,close:i.close,line:{width:n({},a.line.width,{}),editType:\"style\"},increasing:o(i.increasing.line.color.dflt),decreasing:o(i.decreasing.line.color.dflt),text:i.text,hovertext:i.hovertext,whiskerwidth:n({},a.whiskerwidth,{dflt:0}),hoverlabel:i.hoverlabel}},{\"../../lib\":719,\"../box/attributes\":880,\"../ohlc/attributes\":1058}],893:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../ohlc/calc\").calcCommon;function o(t,e,r,n){return{min:r,q1:Math.min(t,n),med:n,q3:Math.max(t,n),max:e}}e.exports=function(t,e){var r=t._fullLayout,s=i.getFromId(t,e.xaxis),l=i.getFromId(t,e.yaxis),c=s.makeCalcdata(e,\"x\"),u=a(t,e,c,l,o);return u.length?(n.extendFlat(u[0].t,{num:r._numBoxes,dPos:n.distinctVals(c).minDiff/2,posLetter:\"x\",valLetter:\"y\"}),r._numBoxes++,u):[{t:{empty:!0}}]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../ohlc/calc\":1059}],894:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../ohlc/ohlc_defaults\"),o=t(\"./attributes\");function s(t,e,r,n){var a=r(n+\".line.color\");r(n+\".line.width\",e.line.width),r(n+\".fillcolor\",i.addOpacity(a,.5))}e.exports=function(t,e,r,i){function l(r,i){return n.coerce(t,e,o,r,i)}a(t,e,l,i)?(l(\"line.width\"),s(t,e,l,\"increasing\"),s(t,e,l,\"decreasing\"),l(\"text\"),l(\"hovertext\"),l(\"whiskerwidth\"),i._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../components/color\":593,\"../../lib\":719,\"../ohlc/ohlc_defaults\":1063,\"./attributes\":892}],895:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"candlestick\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\",\"candlestick\",\"boxLayout\"],meta:{},attributes:t(\"./attributes\"),layoutAttributes:t(\"../box/layout_attributes\"),supplyLayoutDefaults:t(\"../box/layout_defaults\").supplyLayoutDefaults,crossTraceCalc:t(\"../box/cross_trace_calc\").crossTraceCalc,supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"../box/plot\").plot,layerName:\"boxlayer\",style:t(\"../box/style\").style,hoverPoints:t(\"../ohlc/hover\").hoverPoints,selectPoints:t(\"../ohlc/select\")}},{\"../../plots/cartesian\":778,\"../box/cross_trace_calc\":882,\"../box/layout_attributes\":887,\"../box/layout_defaults\":888,\"../box/plot\":889,\"../box/style\":891,\"../ohlc/hover\":1061,\"../ohlc/select\":1065,\"./attributes\":892,\"./calc\":893,\"./defaults\":894}],896:[function(t,e,r){\"use strict\";var n=t(\"./axis_defaults\"),i=t(\"../../plot_api/plot_template\");e.exports=function(t,e,r,a,o){a(\"a\")||(a(\"da\"),a(\"a0\")),a(\"b\")||(a(\"db\"),a(\"b0\")),function(t,e,r,a){[\"aaxis\",\"baxis\"].forEach(function(o){var s=o.charAt(0),l=t[o]||{},c=i.newContainer(e,o),u={tickfont:\"x\",id:s+\"axis\",letter:s,font:e.font,name:o,data:t[s],calendar:e.calendar,dfltColor:a,bgColor:r.paper_bgcolor,fullLayout:r};n(l,c,u),c._categories=c._categories||[],t[o]||\"-\"===l.type||(t[o]={type:l.type})})}(t,e,r,o)}},{\"../../plot_api/plot_template\":757,\"./axis_defaults\":901}],897:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t){return function t(e,r){if(!n(e)||r>=10)return null;var i=1/0;var a=-1/0;var o=e.length;for(var s=0;s<o;s++){var l=e[s];if(n(l)){var c=t(l,r+1);c&&(i=Math.min(c[0],i),a=Math.max(c[1],a))}else i=Math.min(l,i),a=Math.max(l,a)}return[i,a]}(t,0)}},{\"../../lib\":719}],898:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./axis_attributes\"),a=t(\"../../components/color/attributes\"),o=n({editType:\"calc\"});o.family.dflt='\"Open Sans\", verdana, arial, sans-serif',o.size.dflt=12,o.color.dflt=a.defaultLine,e.exports={carpet:{valType:\"string\",editType:\"calc\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},a:{valType:\"data_array\",editType:\"calc\"},a0:{valType:\"number\",dflt:0,editType:\"calc\"},da:{valType:\"number\",dflt:1,editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},b0:{valType:\"number\",dflt:0,editType:\"calc\"},db:{valType:\"number\",dflt:1,editType:\"calc\"},cheaterslope:{valType:\"number\",dflt:1,editType:\"calc\"},aaxis:i,baxis:i,font:o,color:{valType:\"color\",dflt:a.defaultLine,editType:\"plot\"},transforms:void 0}},{\"../../components/color/attributes\":592,\"../../plots/font_attributes\":793,\"./axis_attributes\":900}],899:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,i){var a,o,s,l,c,u,h,f,p,d,g,v,m,y=n(r)?\"a\":\"b\",x=(\"a\"===y?t.aaxis:t.baxis).smoothing,b=\"a\"===y?t.a2i:t.b2j,_=\"a\"===y?r:i,w=\"a\"===y?i:r,k=\"a\"===y?e.a.length:e.b.length,T=\"a\"===y?e.b.length:e.a.length,A=Math.floor(\"a\"===y?t.b2j(w):t.a2i(w)),M=\"a\"===y?function(e){return t.evalxy([],e,A)}:function(e){return t.evalxy([],A,e)};x&&(s=Math.max(0,Math.min(T-2,A)),l=A-s,o=\"a\"===y?function(e,r){return t.dxydi([],e,s,r,l)}:function(e,r){return t.dxydj([],s,e,l,r)});var S=b(_[0]),E=b(_[1]),C=S<E?1:-1,L=1e-8*(E-S),P=C>0?Math.floor:Math.ceil,O=C>0?Math.ceil:Math.floor,z=C>0?Math.min:Math.max,I=C>0?Math.max:Math.min,D=P(S+L),R=O(E-L),F=[[h=M(S)]];for(a=D;a*C<R*C;a+=C)c=[],g=I(S,a),m=(v=z(E,a+C))-g,u=Math.max(0,Math.min(k-2,Math.floor(.5*(g+v)))),f=M(v),x&&(p=o(u,g-u),d=o(u,v-u),c.push([h[0]+p[0]/3*m,h[1]+p[1]/3*m]),c.push([f[0]-d[0]/3*m,f[1]-d[1]/3*m])),c.push(f),F.push(c),h=f;return F}},{\"../../lib\":719}],900:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../plots/cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").TIME_FORMAT_LINK;e.exports={color:{valType:\"color\",editType:\"calc\"},smoothing:{valType:\"number\",dflt:1,min:0,max:1.3,editType:\"calc\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"calc\"},font:n({editType:\"calc\"}),offset:{valType:\"number\",dflt:10,editType:\"calc\"},editType:\"calc\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"date\",\"category\"],dflt:\"-\",editType:\"calc\"},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"calc\"},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"calc\"},range:{valType:\"info_array\",editType:\"calc\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}]},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cheatertype:{valType:\"enumerated\",values:[\"index\",\"value\"],dflt:\"value\",editType:\"calc\"},tickmode:{valType:\"enumerated\",values:[\"linear\",\"array\"],dflt:\"array\",editType:\"calc\"},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},tickvals:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},showticklabels:{valType:\"enumerated\",values:[\"start\",\"end\",\"both\",\"none\"],dflt:\"start\",editType:\"calc\"},tickfont:n({editType:\"calc\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"calc\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"calc\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"calc\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"calc\"},tickformatstops:o(a.tickformatstops,\"calc\",\"from-root\"),categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},labelpadding:{valType:\"integer\",dflt:10,editType:\"calc\"},labelprefix:{valType:\"string\",editType:\"calc\"},labelsuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showline:{valType:\"boolean\",dflt:!1,editType:\"calc\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"calc\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},gridcolor:{valType:\"color\",editType:\"calc\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},showgrid:{valType:\"boolean\",dflt:!0,editType:\"calc\"},minorgridcount:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},minorgridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},minorgridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"calc\"},startline:{valType:\"boolean\",editType:\"calc\"},startlinecolor:{valType:\"color\",editType:\"calc\"},startlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endline:{valType:\"boolean\",editType:\"calc\"},endlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endlinecolor:{valType:\"color\",editType:\"calc\"},tick0:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},dtick:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},arraytick0:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},arraydtick:{valType:\"integer\",min:1,dflt:1,editType:\"calc\"},_deprecated:{title:{valType:\"string\",editType:\"calc\"},titlefont:n({editType:\"calc\"}),titleoffset:{valType:\"number\",dflt:10,editType:\"calc\"}},editType:\"calc\"}},{\"../../components/color/attributes\":592,\"../../constants/docs\":690,\"../../plot_api/edit_types\":750,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/font_attributes\":793}],901:[function(t,e,r){\"use strict\";var n=t(\"./attributes\"),i=t(\"../../components/color\").addOpacity,a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/tick_value_defaults\"),l=t(\"../../plots/cartesian/tick_label_defaults\"),c=t(\"../../plots/cartesian/category_order_defaults\"),u=t(\"../../plots/cartesian/set_convert\"),h=t(\"../../plots/cartesian/axis_autotype\");e.exports=function(t,e,r){var f=r.letter,p=r.font||{},d=n[f+\"axis\"];function g(r,n){return o.coerce(t,e,d,r,n)}function v(r,n){return o.coerce2(t,e,d,r,n)}r.name&&(e._name=r.name,e._id=r.name);var m=g(\"type\");(\"-\"===m&&(r.data&&function(t,e){if(\"-\"!==t.type)return;var r=t._id.charAt(0),n=t[r+\"calendar\"];t.type=h(e,n)}(e,r.data),\"-\"===e.type?e.type=\"linear\":m=t.type=e.type),g(\"smoothing\"),g(\"cheatertype\"),g(\"showticklabels\"),g(\"labelprefix\",f+\" = \"),g(\"labelsuffix\"),g(\"showtickprefix\"),g(\"showticksuffix\"),g(\"separatethousands\"),g(\"tickformat\"),g(\"exponentformat\"),g(\"showexponent\"),g(\"categoryorder\"),g(\"tickmode\"),g(\"tickvals\"),g(\"ticktext\"),g(\"tick0\"),g(\"dtick\"),\"array\"===e.tickmode&&(g(\"arraytick0\"),g(\"arraydtick\")),g(\"labelpadding\"),e._hovertitle=f,\"date\"===m)&&a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",r.calendar);u(e,r.fullLayout),e.c2p=o.identity;var y=g(\"color\",r.dfltColor),x=y===t.color?y:p.color;g(\"title.text\")&&(o.coerceFont(g,\"title.font\",{family:p.family,size:Math.round(1.2*p.size),color:x}),g(\"title.offset\")),g(\"tickangle\"),g(\"autorange\",!e.isValidRange(t.range))&&g(\"rangemode\"),g(\"range\"),e.cleanRange(),g(\"fixedrange\"),s(t,e,g,m),l(t,e,g,m,r),c(t,e,g,{data:r.data,dataAttr:f});var b=v(\"gridcolor\",i(y,.3)),_=v(\"gridwidth\"),w=g(\"showgrid\");w||(delete e.gridcolor,delete e.gridwidth);var k=v(\"startlinecolor\",y),T=v(\"startlinewidth\",_);g(\"startline\",e.showgrid||!!k||!!T)||(delete e.startlinecolor,delete e.startlinewidth);var A=v(\"endlinecolor\",y),M=v(\"endlinewidth\",_);return g(\"endline\",e.showgrid||!!A||!!M)||(delete e.endlinecolor,delete e.endlinewidth),w?(g(\"minorgridcount\"),g(\"minorgridwidth\",_),g(\"minorgridcolor\",i(b,.06)),e.minorgridcount||(delete e.minorgridwidth,delete e.minorgridcolor)):(delete e.gridcolor,delete e.gridWidth),\"none\"===e.showticklabels&&(delete e.tickfont,delete e.tickangle,delete e.showexponent,delete e.exponentformat,delete e.tickformat,delete e.showticksuffix,delete e.showtickprefix),e.showticksuffix||delete e.ticksuffix,e.showtickprefix||delete e.tickprefix,g(\"tickmode\"),e}},{\"../../components/color\":593,\"../../lib\":719,\"../../plots/cartesian/axis_autotype\":768,\"../../plots/cartesian/category_order_defaults\":771,\"../../plots/cartesian/set_convert\":785,\"../../plots/cartesian/tick_label_defaults\":786,\"../../plots/cartesian/tick_value_defaults\":788,\"../../registry\":847,\"./attributes\":898}],902:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\").isArray1D,a=t(\"./cheater_basis\"),o=t(\"./array_minmax\"),s=t(\"./calc_gridlines\"),l=t(\"./calc_labels\"),c=t(\"./calc_clippath\"),u=t(\"../heatmap/clean_2d_array\"),h=t(\"./smooth_fill_2d_array\"),f=t(\"../heatmap/convert_column_xyz\"),p=t(\"./set_convert\");e.exports=function(t,e){var r=n.getFromId(t,e.xaxis),d=n.getFromId(t,e.yaxis),g=e.aaxis,v=e.baxis,m=e.x,y=e.y,x=[];m&&i(m)&&x.push(\"x\"),y&&i(y)&&x.push(\"y\"),x.length&&f(e,g,v,\"a\",\"b\",x);var b=e._a=e._a||e.a,_=e._b=e._b||e.b;m=e._x||e.x,y=e._y||e.y;var w={};if(e._cheater){var k=\"index\"===g.cheatertype?b.length:b,T=\"index\"===v.cheatertype?_.length:_;m=a(k,T,e.cheaterslope)}e._x=m=u(m),e._y=y=u(y),h(m,b,_),h(y,b,_),p(e),e.setScale();var A=o(m),M=o(y),S=.5*(A[1]-A[0]),E=.5*(A[1]+A[0]),C=.5*(M[1]-M[0]),L=.5*(M[1]+M[0]);return A=[E-1.3*S,E+1.3*S],M=[L-1.3*C,L+1.3*C],e._extremes[r._id]=n.findExtremes(r,A,{padded:!0}),e._extremes[d._id]=n.findExtremes(d,M,{padded:!0}),s(e,\"a\",\"b\"),s(e,\"b\",\"a\"),l(e,g),l(e,v),w.clipsegments=c(e._xctrl,e._yctrl,g,v),w.x=m,w.y=y,w.a=b,w.b=_,[w]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../heatmap/clean_2d_array\":1003,\"../heatmap/convert_column_xyz\":1005,\"./array_minmax\":897,\"./calc_clippath\":903,\"./calc_gridlines\":904,\"./calc_labels\":905,\"./cheater_basis\":907,\"./set_convert\":920,\"./smooth_fill_2d_array\":921}],903:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a,o,s=[],l=!!r.smoothing,c=!!n.smoothing,u=t[0].length-1,h=t.length-1;for(i=0,a=[],o=[];i<=u;i++)a[i]=t[0][i],o[i]=e[0][i];for(s.push({x:a,y:o,bicubic:l}),i=0,a=[],o=[];i<=h;i++)a[i]=t[i][u],o[i]=e[i][u];for(s.push({x:a,y:o,bicubic:c}),i=u,a=[],o=[];i>=0;i--)a[u-i]=t[h][i],o[u-i]=e[h][i];for(s.push({x:a,y:o,bicubic:l}),i=h,a=[],o=[];i>=0;i--)a[h-i]=t[i][0],o[h-i]=e[i][0];return s.push({x:a,y:o,bicubic:c}),s}},{}],904:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e,r){var a,o,s,l,c,u,h,f,p,d,g,v,m,y,x=t[\"_\"+e],b=t[e+\"axis\"],_=b._gridlines=[],w=b._minorgridlines=[],k=b._boundarylines=[],T=t[\"_\"+r],A=t[r+\"axis\"];\"array\"===b.tickmode&&(b.tickvals=x.slice());var M=t._xctrl,S=t._yctrl,E=M[0].length,C=M.length,L=t._a.length,P=t._b.length;n.prepTicks(b),\"array\"===b.tickmode&&delete b.tickvals;var O=b.smoothing?3:1;function z(n){var i,a,o,s,l,c,u,h,p,d,g,v,m=[],y=[],x={};if(\"b\"===e)for(a=t.b2j(n),o=Math.floor(Math.max(0,Math.min(P-2,a))),s=a-o,x.length=P,x.crossLength=L,x.xy=function(e){return t.evalxy([],e,a)},x.dxy=function(e,r){return t.dxydi([],e,o,r,s)},i=0;i<L;i++)c=Math.min(L-2,i),u=i-c,h=t.evalxy([],i,a),A.smoothing&&i>0&&(p=t.dxydi([],i-1,o,0,s),m.push(l[0]+p[0]/3),y.push(l[1]+p[1]/3),d=t.dxydi([],i-1,o,1,s),m.push(h[0]-d[0]/3),y.push(h[1]-d[1]/3)),m.push(h[0]),y.push(h[1]),l=h;else for(i=t.a2i(n),c=Math.floor(Math.max(0,Math.min(L-2,i))),u=i-c,x.length=L,x.crossLength=P,x.xy=function(e){return t.evalxy([],i,e)},x.dxy=function(e,r){return t.dxydj([],c,e,u,r)},a=0;a<P;a++)o=Math.min(P-2,a),s=a-o,h=t.evalxy([],i,a),A.smoothing&&a>0&&(g=t.dxydj([],c,a-1,u,0),m.push(l[0]+g[0]/3),y.push(l[1]+g[1]/3),v=t.dxydj([],c,a-1,u,1),m.push(h[0]-v[0]/3),y.push(h[1]-v[1]/3)),m.push(h[0]),y.push(h[1]),l=h;return x.axisLetter=e,x.axis=b,x.crossAxis=A,x.value=n,x.constvar=r,x.index=f,x.x=m,x.y=y,x.smoothing=A.smoothing,x}function I(n){var i,a,o,s,l,c=[],u=[],h={};if(h.length=x.length,h.crossLength=T.length,\"b\"===e)for(o=Math.max(0,Math.min(P-2,n)),l=Math.min(1,Math.max(0,n-o)),h.xy=function(e){return t.evalxy([],e,n)},h.dxy=function(e,r){return t.dxydi([],e,o,r,l)},i=0;i<E;i++)c[i]=M[n*O][i],u[i]=S[n*O][i];else for(a=Math.max(0,Math.min(L-2,n)),s=Math.min(1,Math.max(0,n-a)),h.xy=function(e){return t.evalxy([],n,e)},h.dxy=function(e,r){return t.dxydj([],a,e,s,r)},i=0;i<C;i++)c[i]=M[i][n*O],u[i]=S[i][n*O];return h.axisLetter=e,h.axis=b,h.crossAxis=A,h.value=x[n],h.constvar=r,h.index=n,h.x=c,h.y=u,h.smoothing=A.smoothing,h}if(\"array\"===b.tickmode){for(l=5e-15,u=(c=[Math.floor((x.length-1-b.arraytick0)/b.arraydtick*(1+l)),Math.ceil(-b.arraytick0/b.arraydtick/(1+l))].sort(function(t,e){return t-e}))[0]-1,h=c[1]+1,f=u;f<h;f++)(o=b.arraytick0+b.arraydtick*f)<0||o>x.length-1||_.push(i(I(o),{color:b.gridcolor,width:b.gridwidth}));for(f=u;f<h;f++)if(s=b.arraytick0+b.arraydtick*f,g=Math.min(s+b.arraydtick,x.length-1),!(s<0||s>x.length-1||g<0||g>x.length-1))for(v=x[s],m=x[g],a=0;a<b.minorgridcount;a++)(y=g-s)<=0||(d=v+(m-v)*(a+1)/(b.minorgridcount+1)*(b.arraydtick/y))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&k.push(i(I(0),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&k.push(i(I(x.length-1),{color:b.endlinecolor,width:b.endlinewidth}))}else{for(l=5e-15,u=(c=[Math.floor((x[x.length-1]-b.tick0)/b.dtick*(1+l)),Math.ceil((x[0]-b.tick0)/b.dtick/(1+l))].sort(function(t,e){return t-e}))[0],h=c[1],f=u;f<=h;f++)p=b.tick0+b.dtick*f,_.push(i(z(p),{color:b.gridcolor,width:b.gridwidth}));for(f=u-1;f<h+1;f++)for(p=b.tick0+b.dtick*f,a=0;a<b.minorgridcount;a++)(d=p+b.dtick*(a+1)/(b.minorgridcount+1))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&k.push(i(z(x[0]),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&k.push(i(z(x[x.length-1]),{color:b.endlinecolor,width:b.endlinewidth}))}}},{\"../../lib/extend\":710,\"../../plots/cartesian/axes\":767}],905:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e){var r,a,o,s=e._labels=[],l=e._gridlines;for(r=0;r<l.length;r++)o=l[r],-1!==[\"start\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{prefix:void 0,suffix:void 0,endAnchor:!0,xy:o.xy(0),dxy:o.dxy(0,0),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a)),-1!==[\"end\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{endAnchor:!1,xy:o.xy(o.crossLength-1),dxy:o.dxy(o.crossLength-2,1),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a))}},{\"../../lib/extend\":710,\"../../plots/cartesian/axes\":767}],906:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=t[0]-e[0],a=t[1]-e[1],o=r[0]-e[0],s=r[1]-e[1],l=Math.pow(i*i+a*a,.25),c=Math.pow(o*o+s*s,.25),u=(c*c*i-l*l*o)*n,h=(c*c*a-l*l*s)*n,f=c*(l+c)*3,p=l*(l+c)*3;return[[e[0]+(f&&u/f),e[1]+(f&&h/f)],[e[0]-(p&&u/p),e[1]-(p&&h/p)]]}},{}],907:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i,a,o,s,l,c,u=[],h=n(t)?t.length:t,f=n(e)?e.length:e,p=n(t)?t:null,d=n(e)?e:null;p&&(o=(p.length-1)/(p[p.length-1]-p[0])/(h-1)),d&&(s=(d.length-1)/(d[d.length-1]-d[0])/(f-1));var g=1/0,v=-1/0;for(a=0;a<f;a++)for(u[a]=[],l=d?(d[a]-d[0])*s:a/(f-1),i=0;i<h;i++)c=(p?(p[i]-p[0])*o:i/(h-1))-l*r,g=Math.min(c,g),v=Math.max(c,v),u[a][i]=c;var m=1/(v-g),y=-g*m;for(a=0;a<f;a++)for(i=0;i<h;i++)u[a][i]=m*u[a][i]+y;return u}},{\"../../lib\":719}],908:[function(t,e,r){\"use strict\";var n=t(\"./catmull_rom\"),i=t(\"../../lib\").ensureArray;function a(t,e,r){var n=-.5*r[0]+1.5*e[0],i=-.5*r[1]+1.5*e[1];return[(2*n+t[0])/3,(2*i+t[1])/3]}e.exports=function(t,e,r,o,s,l){var c,u,h,f,p,d,g,v,m,y,x=r[0].length,b=r.length,_=s?3*x-2:x,w=l?3*b-2:b;for(t=i(t,w),e=i(e,w),h=0;h<w;h++)t[h]=i(t[h],_),e[h]=i(e[h],_);for(u=0,f=0;u<b;u++,f+=l?3:1)for(p=t[f],d=e[f],g=r[u],v=o[u],c=0,h=0;c<x;c++,h+=s?3:1)p[h]=g[c],d[h]=v[c];if(s)for(u=0,f=0;u<b;u++,f+=l?3:1){for(c=1,h=3;c<x-1;c++,h+=3)m=n([r[u][c-1],o[u][c-1]],[r[u][c],o[u][c]],[r[u][c+1],o[u][c+1]],s),t[f][h-1]=m[0][0],e[f][h-1]=m[0][1],t[f][h+1]=m[1][0],e[f][h+1]=m[1][1];y=a([t[f][0],e[f][0]],[t[f][2],e[f][2]],[t[f][3],e[f][3]]),t[f][1]=y[0],e[f][1]=y[1],y=a([t[f][_-1],e[f][_-1]],[t[f][_-3],e[f][_-3]],[t[f][_-4],e[f][_-4]]),t[f][_-2]=y[0],e[f][_-2]=y[1]}if(l)for(h=0;h<_;h++){for(f=3;f<w-3;f+=3)m=n([t[f-3][h],e[f-3][h]],[t[f][h],e[f][h]],[t[f+3][h],e[f+3][h]],l),t[f-1][h]=m[0][0],e[f-1][h]=m[0][1],t[f+1][h]=m[1][0],e[f+1][h]=m[1][1];y=a([t[0][h],e[0][h]],[t[2][h],e[2][h]],[t[3][h],e[3][h]]),t[1][h]=y[0],e[1][h]=y[1],y=a([t[w-1][h],e[w-1][h]],[t[w-3][h],e[w-3][h]],[t[w-4][h],e[w-4][h]]),t[w-2][h]=y[0],e[w-2][h]=y[1]}if(s&&l)for(f=1;f<w;f+=(f+1)%3==0?2:1){for(h=3;h<_-3;h+=3)m=n([t[f][h-3],e[f][h-3]],[t[f][h],e[f][h]],[t[f][h+3],e[f][h+3]],s),t[f][h-1]=.5*(t[f][h-1]+m[0][0]),e[f][h-1]=.5*(e[f][h-1]+m[0][1]),t[f][h+1]=.5*(t[f][h+1]+m[1][0]),e[f][h+1]=.5*(e[f][h+1]+m[1][1]);y=a([t[f][0],e[f][0]],[t[f][2],e[f][2]],[t[f][3],e[f][3]]),t[f][1]=.5*(t[f][1]+y[0]),e[f][1]=.5*(e[f][1]+y[1]),y=a([t[f][_-1],e[f][_-1]],[t[f][_-3],e[f][_-3]],[t[f][_-4],e[f][_-4]]),t[f][_-2]=.5*(t[f][_-2]+y[0]),e[f][_-2]=.5*(e[f][_-2]+y[1])}return[t,e]}},{\"../../lib\":719,\"./catmull_rom\":906}],909:[function(t,e,r){\"use strict\";e.exports={RELATIVE_CULL_TOLERANCE:1e-6}},{}],910:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3,n*=3;var f=i*i,p=1-i,d=p*p,g=p*i*2,v=-3*d,m=3*(d-g),y=3*(g-f),x=3*f,b=a*a,_=b*a,w=1-a,k=w*w,T=k*w;for(h=0;h<t.length;h++)o=v*(u=t[h])[n][r]+m*u[n][r+1]+y*u[n][r+2]+x*u[n][r+3],s=v*u[n+1][r]+m*u[n+1][r+1]+y*u[n+1][r+2]+x*u[n+1][r+3],l=v*u[n+2][r]+m*u[n+2][r+1]+y*u[n+2][r+2]+x*u[n+2][r+3],c=v*u[n+3][r]+m*u[n+3][r+1]+y*u[n+3][r+2]+x*u[n+3][r+3],e[h]=T*o+3*(k*a*s+w*b*l)+_*c;return e}:e?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),r*=3;var u=i*i,h=1-i,f=h*h,p=h*i*2,d=-3*f,g=3*(f-p),v=3*(p-u),m=3*u,y=1-a;for(l=0;l<t.length;l++)o=d*(c=t[l])[n][r]+g*c[n][r+1]+v*c[n][r+2]+m*c[n][r+3],s=d*c[n+1][r]+g*c[n+1][r+1]+v*c[n+1][r+2]+m*c[n+1][r+3],e[l]=y*o+a*s;return e}:r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),n*=3;var f=a*a,p=f*a,d=1-a,g=d*d,v=g*d;for(u=0;u<t.length;u++)o=(h=t[u])[n][r+1]-h[n][r],s=h[n+1][r+1]-h[n+1][r],l=h[n+2][r+1]-h[n+2][r],c=h[n+3][r+1]-h[n+3][r],e[u]=v*o+3*(g*a*s+d*f*l)+p*c;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-a;for(l=0;l<t.length;l++)o=(c=t[l])[n][r+1]-c[n][r],s=c[n+1][r+1]-c[n+1][r],e[l]=u*o+a*s;return e}}},{}],911:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3,n*=3;var f=i*i,p=f*i,d=1-i,g=d*d,v=g*d,m=a*a,y=1-a,x=y*y,b=y*a*2,_=-3*x,w=3*(x-b),k=3*(b-m),T=3*m;for(h=0;h<t.length;h++)o=_*(u=t[h])[n][r]+w*u[n+1][r]+k*u[n+2][r]+T*u[n+3][r],s=_*u[n][r+1]+w*u[n+1][r+1]+k*u[n+2][r+1]+T*u[n+3][r+1],l=_*u[n][r+2]+w*u[n+1][r+2]+k*u[n+2][r+2]+T*u[n+3][r+2],c=_*u[n][r+3]+w*u[n+1][r+3]+k*u[n+2][r+3]+T*u[n+3][r+3],e[h]=v*o+3*(g*i*s+d*f*l)+p*c;return e}:e?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3;var f=a*a,p=f*a,d=1-a,g=d*d,v=g*d;for(u=0;u<t.length;u++)o=(h=t[u])[n+1][r]-h[n][r],s=h[n+1][r+1]-h[n][r+1],l=h[n+1][r+2]-h[n][r+2],c=h[n+1][r+3]-h[n][r+3],e[u]=v*o+3*(g*a*s+d*f*l)+p*c;return e}:r?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),n*=3;var u=1-i,h=a*a,f=1-a,p=f*f,d=f*a*2,g=-3*p,v=3*(p-d),m=3*(d-h),y=3*h;for(l=0;l<t.length;l++)o=g*(c=t[l])[n][r]+v*c[n+1][r]+m*c[n+2][r]+y*c[n+3][r],s=g*c[n][r+1]+v*c[n+1][r+1]+m*c[n+2][r+1]+y*c[n+3][r+1],e[l]=u*o+i*s;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-i;for(l=0;l<t.length;l++)o=(c=t[l])[n+1][r]-c[n][r],s=c[n+1][r+1]-c[n][r+1],e[l]=u*o+i*s;return e}}},{}],912:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=e-2,o=r-2;return n&&i?function(e,r,n){var i,s,l,c,u,h;e||(e=[]);var f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));f*=3,p*=3;var v=d*d,m=v*d,y=1-d,x=y*y,b=x*y,_=g*g,w=_*g,k=1-g,T=k*k,A=T*k;for(h=0;h<t.length;h++)i=b*(u=t[h])[p][f]+3*(x*d*u[p][f+1]+y*v*u[p][f+2])+m*u[p][f+3],s=b*u[p+1][f]+3*(x*d*u[p+1][f+1]+y*v*u[p+1][f+2])+m*u[p+1][f+3],l=b*u[p+2][f]+3*(x*d*u[p+2][f+1]+y*v*u[p+2][f+2])+m*u[p+2][f+3],c=b*u[p+3][f]+3*(x*d*u[p+3][f+1]+y*v*u[p+3][f+2])+m*u[p+3][f+3],e[h]=A*i+3*(T*g*s+k*_*l)+w*c;return e}:n?function(e,r,n){e||(e=[]);var i,s,l,c,u,h,f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));f*=3;var v=d*d,m=v*d,y=1-d,x=y*y,b=x*y,_=1-g;for(u=0;u<t.length;u++)i=_*(h=t[u])[p][f]+g*h[p+1][f],s=_*h[p][f+1]+g*h[p+1][f+1],l=_*h[p][f+2]+g*h[p+1][f+1],c=_*h[p][f+3]+g*h[p+1][f+1],e[u]=b*i+3*(x*d*s+y*v*l)+m*c;return e}:i?function(e,r,n){e||(e=[]);var i,s,l,c,u,h,f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));p*=3;var v=g*g,m=v*g,y=1-g,x=y*y,b=x*y,_=1-d;for(u=0;u<t.length;u++)i=_*(h=t[u])[p][f]+d*h[p][f+1],s=_*h[p+1][f]+d*h[p+1][f+1],l=_*h[p+2][f]+d*h[p+2][f+1],c=_*h[p+3][f]+d*h[p+3][f+1],e[u]=b*i+3*(x*g*s+y*v*l)+m*c;return e}:function(e,r,n){e||(e=[]);var i,s,l,c,u=Math.max(0,Math.min(Math.floor(r),a)),h=Math.max(0,Math.min(Math.floor(n),o)),f=Math.max(0,Math.min(1,r-u)),p=Math.max(0,Math.min(1,n-h)),d=1-p,g=1-f;for(l=0;l<t.length;l++)i=g*(c=t[l])[h][u]+f*c[h][u+1],s=g*c[h+1][u]+f*c[h+1][u+1],e[l]=d*i+p*s;return e}}},{}],913:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xy_defaults\"),a=t(\"./ab_defaults\"),o=t(\"./attributes\"),s=t(\"../../components/color/attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,o,r,i)}e._clipPathId=\"clip\"+e.uid+\"carpet\";var u=c(\"color\",s.defaultLine);(n.coerceFont(c,\"font\"),c(\"carpet\"),a(t,e,l,c,u),e.a&&e.b)?(e.a.length<3&&(e.aaxis.smoothing=0),e.b.length<3&&(e.baxis.smoothing=0),i(t,e,c)||(e.visible=!1),e._cheater&&c(\"cheaterslope\")):e.visible=!1}},{\"../../components/color/attributes\":592,\"../../lib\":719,\"./ab_defaults\":896,\"./attributes\":898,\"./xy_defaults\":922}],914:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),plot:t(\"./plot\"),calc:t(\"./calc\"),animatable:!0,isContainer:!0,moduleType:\"trace\",name:\"carpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"carpetAxis\",\"notLegendIsolatable\",\"noMultiCategory\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":898,\"./calc\":902,\"./defaults\":913,\"./plot\":919}],915:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r,n=t._fullData.length,i=0;i<n;i++){var a=t._fullData[i];if(a.index!==e.index&&(\"carpet\"===a.type&&(r||(r=a),a.carpet===e.carpet)))return a}return r}},{}],916:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(0===t.length)return\"\";var n,i=[],a=r?3:1;for(n=0;n<t.length;n+=a)i.push(t[n]+\",\"+e[n]),r&&n<t.length-a&&(i.push(\"C\"),i.push([t[n+1]+\",\"+e[n+1],t[n+2]+\",\"+e[n+2]+\" \"].join(\" \")));return i.join(r?\"\":\"L\")}},{}],917:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i;for(n(t)?t.length>e.length&&(t=t.slice(0,e.length)):t=[],i=0;i<e.length;i++)t[i]=r(e[i]);return t}},{\"../../lib\":719}],918:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i[0]*t.dpdx(e),s=i[1]*t.dpdy(r),l=1,c=1;if(a){var u=Math.sqrt(i[0]*i[0]+i[1]*i[1]),h=Math.sqrt(a[0]*a[0]+a[1]*a[1]),f=(i[0]*a[0]+i[1]*a[1])/u/h;c=Math.max(0,f)}var p=180*Math.atan2(s,o)/Math.PI;return p<-90?(p+=180,l=-l):p>90&&(p-=180,l=-l),{angle:p,flip:l,p:t.c2p(n,e,r),offsetMultplier:c}}},{}],919:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"./map_1d_array\"),o=t(\"./makepath\"),s=t(\"./orient_text\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib\"),u=t(\"../../constants/alignment\");function h(t,e,r,i,s,l){var c=\"const-\"+s+\"-lines\",u=r.selectAll(\".\"+c).data(l);u.enter().append(\"path\").classed(c,!0).style(\"vector-effect\",\"non-scaling-stroke\"),u.each(function(r){var i=r,s=i.x,l=i.y,c=a([],s,t.c2p),u=a([],l,e.c2p),h=\"M\"+o(c,u,i.smoothing);n.select(this).attr(\"d\",h).style(\"stroke-width\",i.width).style(\"stroke\",i.color).style(\"fill\",\"none\")}),u.exit().remove()}function f(t,e,r,a,o,c,u,h){var f=c.selectAll(\"text.\"+h).data(u);f.enter().append(\"text\").classed(h,!0);var p=0,d={};return f.each(function(o,c){var u;if(\"auto\"===o.axis.tickangle)u=s(a,e,r,o.xy,o.dxy);else{var h=(o.axis.tickangle+180)*Math.PI/180;u=s(a,e,r,o.xy,[Math.cos(h),Math.sin(h)])}c||(d={angle:u.angle,flip:u.flip});var f=(o.endAnchor?-1:1)*u.flip,g=n.select(this).attr({\"text-anchor\":f>0?\"start\":\"end\",\"data-notex\":1}).call(i.font,o.font).text(o.text).call(l.convertToTspans,t),v=i.bBox(this);g.attr(\"transform\",\"translate(\"+u.p[0]+\",\"+u.p[1]+\") rotate(\"+u.angle+\")translate(\"+o.axis.labelpadding*f+\",\"+.3*v.height+\")\"),p=Math.max(p,v.width+o.axis.labelpadding)}),f.exit().remove(),d.maxExtent=p,d}e.exports=function(t,e,r,i){var l=e.xaxis,u=e.yaxis,p=t._fullLayout._clips;c.makeTraceGroups(i,r,\"trace\").each(function(e){var r=n.select(this),i=e[0],d=i.trace,v=d.aaxis,m=d.baxis,y=c.ensureSingle(r,\"g\",\"minorlayer\"),x=c.ensureSingle(r,\"g\",\"majorlayer\"),b=c.ensureSingle(r,\"g\",\"boundarylayer\"),_=c.ensureSingle(r,\"g\",\"labellayer\");r.style(\"opacity\",d.opacity),h(l,u,x,v,\"a\",v._gridlines),h(l,u,x,m,\"b\",m._gridlines),h(l,u,y,v,\"a\",v._minorgridlines),h(l,u,y,m,\"b\",m._minorgridlines),h(l,u,b,v,\"a-boundary\",v._boundarylines),h(l,u,b,m,\"b-boundary\",m._boundarylines);var w=f(t,l,u,d,i,_,v._labels,\"a-label\"),k=f(t,l,u,d,i,_,m._labels,\"b-label\");!function(t,e,r,n,i,a,o,l){var u,h,f,p,d=c.aggNums(Math.min,null,r.a),v=c.aggNums(Math.max,null,r.a),m=c.aggNums(Math.min,null,r.b),y=c.aggNums(Math.max,null,r.b);u=.5*(d+v),h=m,f=r.ab2xy(u,h,!0),p=r.dxyda_rough(u,h),void 0===o.angle&&c.extendFlat(o,s(r,i,a,f,r.dxydb_rough(u,h)));g(t,e,r,n,f,p,r.aaxis,i,a,o,\"a-title\"),u=d,h=.5*(m+y),f=r.ab2xy(u,h,!0),p=r.dxydb_rough(u,h),void 0===l.angle&&c.extendFlat(l,s(r,i,a,f,r.dxyda_rough(u,h)));g(t,e,r,n,f,p,r.baxis,i,a,l,\"b-title\")}(t,_,d,i,l,u,w,k),function(t,e,r,n,i){var s,l,u,h,f=r.select(\"#\"+t._clipPathId);f.size()||(f=r.append(\"clipPath\").classed(\"carpetclip\",!0));var p=c.ensureSingle(f,\"path\",\"carpetboundary\"),d=e.clipsegments,g=[];for(h=0;h<d.length;h++)s=d[h],l=a([],s.x,n.c2p),u=a([],s.y,i.c2p),g.push(o(l,u,s.bicubic));var v=\"M\"+g.join(\"L\")+\"Z\";f.attr(\"id\",t._clipPathId),p.attr(\"d\",v)}(d,i,p,l,u)})};var p=u.LINE_SPACING,d=(1-u.MID_SHIFT)/p+1;function g(t,e,r,a,o,c,u,h,f,g,v){var m=[];u.title.text&&m.push(u.title.text);var y=e.selectAll(\"text.\"+v).data(m),x=g.maxExtent;y.enter().append(\"text\").classed(v,!0),y.each(function(){var e=s(r,h,f,o,c);-1===[\"start\",\"both\"].indexOf(u.showticklabels)&&(x=0);var a=u.title.font.size;x+=a+u.title.offset;var v=(g.angle+(g.flip<0?180:0)-e.angle+450)%360,m=v>90&&v<270,y=n.select(this);y.text(u.title.text).call(l.convertToTspans,t),m&&(x=(-l.lineCount(y)+d)*p*a-x),y.attr(\"transform\",\"translate(\"+e.p[0]+\",\"+e.p[1]+\") rotate(\"+e.angle+\") translate(0,\"+x+\")\").classed(\"user-select-none\",!0).attr(\"text-anchor\",\"middle\").call(i.font,u.title.font)}),y.exit().remove()}},{\"../../components/drawing\":614,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"./makepath\":916,\"./map_1d_array\":917,\"./orient_text\":918,d3:163}],920:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/search\").findBin,a=t(\"./compute_control_points\"),o=t(\"./create_spline_evaluator\"),s=t(\"./create_i_derivative_evaluator\"),l=t(\"./create_j_derivative_evaluator\");e.exports=function(t){var e=t._a,r=t._b,c=e.length,u=r.length,h=t.aaxis,f=t.baxis,p=e[0],d=e[c-1],g=r[0],v=r[u-1],m=e[e.length-1]-e[0],y=r[r.length-1]-r[0],x=m*n.RELATIVE_CULL_TOLERANCE,b=y*n.RELATIVE_CULL_TOLERANCE;p-=x,d+=x,g-=b,v+=b,t.isVisible=function(t,e){return t>p&&t<d&&e>g&&e<v},t.isOccluded=function(t,e){return t<p||t>d||e<g||e>v},t.setScale=function(){var e=t._x,r=t._y,n=a(t._xctrl,t._yctrl,e,r,h.smoothing,f.smoothing);t._xctrl=n[0],t._yctrl=n[1],t.evalxy=o([t._xctrl,t._yctrl],c,u,h.smoothing,f.smoothing),t.dxydi=s([t._xctrl,t._yctrl],h.smoothing,f.smoothing),t.dxydj=l([t._xctrl,t._yctrl],h.smoothing,f.smoothing)},t.i2a=function(t){var r=Math.max(0,Math.floor(t[0]),c-2),n=t[0]-r;return(1-n)*e[r]+n*e[r+1]},t.j2b=function(t){var e=Math.max(0,Math.floor(t[1]),c-2),n=t[1]-e;return(1-n)*r[e]+n*r[e+1]},t.ij2ab=function(e){return[t.i2a(e[0]),t.j2b(e[1])]},t.a2i=function(t){var r=Math.max(0,Math.min(i(t,e),c-2)),n=e[r],a=e[r+1];return Math.max(0,Math.min(c-1,r+(t-n)/(a-n)))},t.b2j=function(t){var e=Math.max(0,Math.min(i(t,r),u-2)),n=r[e],a=r[e+1];return Math.max(0,Math.min(u-1,e+(t-n)/(a-n)))},t.ab2ij=function(e){return[t.a2i(e[0]),t.b2j(e[1])]},t.i2c=function(e,r){return t.evalxy([],e,r)},t.ab2xy=function(n,i,a){if(!a&&(n<e[0]||n>e[c-1]|i<r[0]||i>r[u-1]))return[!1,!1];var o=t.a2i(n),s=t.b2j(i),l=t.evalxy([],o,s);if(a){var h,f,p,d,g=0,v=0,m=[];n<e[0]?(h=0,f=0,g=(n-e[0])/(e[1]-e[0])):n>e[c-1]?(h=c-2,f=1,g=(n-e[c-1])/(e[c-1]-e[c-2])):f=o-(h=Math.max(0,Math.min(c-2,Math.floor(o)))),i<r[0]?(p=0,d=0,v=(i-r[0])/(r[1]-r[0])):i>r[u-1]?(p=u-2,d=1,v=(i-r[u-1])/(r[u-1]-r[u-2])):d=s-(p=Math.max(0,Math.min(u-2,Math.floor(s)))),g&&(t.dxydi(m,h,p,f,d),l[0]+=m[0]*g,l[1]+=m[1]*g),v&&(t.dxydj(m,h,p,f,d),l[0]+=m[0]*v,l[1]+=m[1]*v)}return l},t.c2p=function(t,e,r){return[e.c2p(t[0]),r.c2p(t[1])]},t.p2x=function(t,e,r){return[e.p2c(t[0]),r.p2c(t[1])]},t.dadi=function(t){var r=Math.max(0,Math.min(e.length-2,t));return e[r+1]-e[r]},t.dbdj=function(t){var e=Math.max(0,Math.min(r.length-2,t));return r[e+1]-r[e]},t.dxyda=function(e,r,n,i){var a=t.dxydi(null,e,r,n,i),o=t.dadi(e,n);return[a[0]/o,a[1]/o]},t.dxydb=function(e,r,n,i){var a=t.dxydj(null,e,r,n,i),o=t.dbdj(r,i);return[a[0]/o,a[1]/o]},t.dxyda_rough=function(e,r,n){var i=m*(n||.1),a=t.ab2xy(e+i,r,!0),o=t.ab2xy(e-i,r,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dxydb_rough=function(e,r,n){var i=y*(n||.1),a=t.ab2xy(e,r+i,!0),o=t.ab2xy(e,r-i,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dpdx=function(t){return t._m},t.dpdy=function(t){return t._m}}},{\"../../lib/search\":738,\"./compute_control_points\":908,\"./constants\":909,\"./create_i_derivative_evaluator\":910,\"./create_j_derivative_evaluator\":911,\"./create_spline_evaluator\":912}],921:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r){var i,a,o,s=[],l=[],c=t[0].length,u=t.length;function h(e,r){var n,i=0,a=0;return e>0&&void 0!==(n=t[r][e-1])&&(a++,i+=n),e<c-1&&void 0!==(n=t[r][e+1])&&(a++,i+=n),r>0&&void 0!==(n=t[r-1][e])&&(a++,i+=n),r<u-1&&void 0!==(n=t[r+1][e])&&(a++,i+=n),i/Math.max(1,a)}var f,p,d,g,v,m,y,x,b,_,w,k=0;for(i=0;i<c;i++)for(a=0;a<u;a++)void 0===t[a][i]&&(s.push(i),l.push(a),t[a][i]=h(i,a)),k=Math.max(k,Math.abs(t[a][i]));if(!s.length)return t;var T=0,A=0,M=s.length;do{for(T=0,o=0;o<M;o++){i=s[o],a=l[o];var S,E,C,L,P,O,z=0,I=0;0===i?(C=e[P=Math.min(c-1,2)],L=e[1],S=t[a][P],I+=(E=t[a][1])+(E-S)*(e[0]-L)/(L-C),z++):i===c-1&&(C=e[P=Math.max(0,c-3)],L=e[c-2],S=t[a][P],I+=(E=t[a][c-2])+(E-S)*(e[c-1]-L)/(L-C),z++),(0===i||i===c-1)&&a>0&&a<u-1&&(f=r[a+1]-r[a],I+=((p=r[a]-r[a-1])*t[a+1][i]+f*t[a-1][i])/(p+f),z++),0===a?(C=r[O=Math.min(u-1,2)],L=r[1],S=t[O][i],I+=(E=t[1][i])+(E-S)*(r[0]-L)/(L-C),z++):a===u-1&&(C=r[O=Math.max(0,u-3)],L=r[u-2],S=t[O][i],I+=(E=t[u-2][i])+(E-S)*(r[u-1]-L)/(L-C),z++),(0===a||a===u-1)&&i>0&&i<c-1&&(f=e[i+1]-e[i],I+=((p=e[i]-e[i-1])*t[a][i+1]+f*t[a][i-1])/(p+f),z++),z?I/=z:(d=e[i+1]-e[i],g=e[i]-e[i-1],x=(v=r[a+1]-r[a])*(m=r[a]-r[a-1])*(v+m),I=((y=d*g*(d+g))*(m*t[a+1][i]+v*t[a-1][i])+x*(g*t[a][i+1]+d*t[a][i-1]))/(x*(g+d)+y*(m+v))),T+=(_=(b=I-t[a][i])/k)*_,w=z?0:.85,t[a][i]+=b*(1+w)}T=Math.sqrt(T)}while(A++<100&&T>1e-5);return n.log(\"Smoother converged to\",T,\"after\",A,\"iterations\"),t}},{\"../../lib\":719}],922:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArray1D;e.exports=function(t,e,r){var i=r(\"x\"),a=i&&i.length,o=r(\"y\"),s=o&&o.length;if(!a&&!s)return!1;if(e._cheater=!i,a&&!n(i)||s&&!n(o))e._length=null;else{var l=a?i.length:1/0;s&&(l=Math.min(l,o.length)),e.a&&e.a.length&&(l=Math.min(l,e.a.length)),e.b&&e.b.length&&(l=Math.min(l,e.b.length)),e._length=l}return!0}},{\"../../lib\":719}],923:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scattergeo/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/color/attributes\").defaultLine,l=t(\"../../lib/extend\").extendFlat,c=i.marker.line;e.exports=l({locations:{valType:\"data_array\",editType:\"calc\"},locationmode:i.locationmode,z:{valType:\"data_array\",editType:\"calc\"},text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),marker:{line:{color:l({},c.color,{dflt:s}),width:l({},c.width,{dflt:1}),editType:\"calc\"},opacity:{valType:\"number\",arrayOk:!0,min:0,max:1,dflt:1,editType:\"style\"},editType:\"calc\"},selected:{marker:{opacity:i.selected.marker.opacity,editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:i.unselected.marker.opacity,editType:\"plot\"},editType:\"plot\"},hoverinfo:l({},o.hoverinfo,{editType:\"calc\",flags:[\"location\",\"z\",\"text\",\"name\"]}),hovertemplate:n()},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/color/attributes\":592,\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scattergeo/attributes\":1151}],924:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../components/colorscale/calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\");function l(t){return t&&\"string\"==typeof t}e.exports=function(t,e){var r,c=e._length,u=new Array(c);r=e.geojson?function(t){return l(t)||n(t)}:l;for(var h=0;h<c;h++){var f=u[h]={},p=e.locations[h],d=e.z[h];r(p)&&n(d)?(f.loc=p,f.z=d):(f.loc=null,f.z=i),f.index=h}return o(u,e),a(t,e,{vals:e.z,containerStr:\"\",cLetter:\"z\"}),s(u,e),u}},{\"../../components/colorscale/calc\":601,\"../../constants/numerical\":695,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc_selection\":1114,\"fast-isnumeric\":225}],925:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\");l&&l.length&&n.isArrayOrTypedArray(c)&&c.length?(e._length=Math.min(l.length,c.length),s(\"locationmode\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":923}],926:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){t.location=e.location,t.z=e.z;var a=n[i];return a.fIn&&(t.properties=a.fIn.properties),t}},{}],927:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"./attributes\"),a=t(\"../../lib\").fillText;e.exports=function(t,e,r){var o,s,l,c,u=t.cd,h=u[0].trace,f=t.subplot;for(s=0;s<u.length;s++)if(c=!1,(o=u[s])._polygons){for(l=0;l<o._polygons.length;l++)o._polygons[l].contains([e,r])&&(c=!c),o._polygons[l].contains([e+360,r])&&(c=!c);if(c)break}if(c&&o)return t.x0=t.x1=t.xa.c2p(o.ct),t.y0=t.y1=t.ya.c2p(o.ct),t.index=o.index,t.location=o.loc,t.z=o.z,t.zLabel=n.tickText(f.mockAxis,f.mockAxis.c2l(o.z),\"hover\").text,t.hovertemplate=o.hovertemplate,function(t,e,r){if(e.hovertemplate)return;var n=r.hi||e.hoverinfo,o=\"all\"===n?i.hoverinfo.flags:n.split(\"+\"),s=-1!==o.indexOf(\"name\"),l=-1!==o.indexOf(\"location\"),c=-1!==o.indexOf(\"z\"),u=-1!==o.indexOf(\"text\"),h=[];!s&&l?t.nameOverride=r.loc:(s&&(t.nameOverride=e.name),l&&h.push(r.loc));c&&h.push(t.zLabel);u&&a(r,e,h);t.extraText=h.join(\"<br>\")}(t,h,o,f.mockAxis),[t]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./attributes\":923}],928:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"choropleth\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"noOpacity\"],meta:{}}},{\"../../plots/geo\":797,\"../heatmap/colorbar\":1004,\"./attributes\":923,\"./calc\":924,\"./defaults\":925,\"./event_data\":926,\"./hover\":927,\"./plot\":929,\"./select\":930,\"./style\":931}],929:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../lib/polygon\"),o=t(\"../../lib/topojson_utils\").getTopojsonFeatures,s=t(\"../../lib/geo_location_utils\").locationToFeature,l=t(\"./style\").style;function c(t,e){for(var r=t[0].trace,n=t.length,i=o(r,e),a=0;a<n;a++){var l=t[a],c=s(r.locationmode,l.loc,i);c?(l.geojson=c,l.ct=c.properties.ct,l._polygons=u(c)):l.geojson=null}}function u(t){var e,r,n,i,o=t.geometry,s=o.coordinates,l=t.id,c=[];function u(t){for(var e=0;e<t.length-1;e++)if(t[e][0]>0&&t[e+1][0]<0)return e;return null}switch(e=\"RUS\"===l||\"FJI\"===l?function(t){var e;if(null===u(t))e=t;else for(e=new Array(t.length),i=0;i<t.length;i++)e[i]=[t[i][0]<0?t[i][0]+360:t[i][0],t[i][1]];c.push(a.tester(e))}:\"ATA\"===l?function(t){var e=u(t);if(null===e)return c.push(a.tester(t));var r=new Array(t.length+1),n=0;for(i=0;i<t.length;i++)i>e?r[n++]=[t[i][0]+360,t[i][1]]:i===e?(r[n++]=t[i],r[n++]=[t[i][0],-90]):r[n++]=t[i];var o=a.tester(r);o.pts.pop(),c.push(o)}:function(t){c.push(a.tester(t))},o.type){case\"MultiPolygon\":for(r=0;r<s.length;r++)for(n=0;n<s[r].length;n++)e(s[r][n]);break;case\"Polygon\":for(r=0;r<s.length;r++)e(s[r])}return c}e.exports={plot:function(t,e,r){for(var a=0;a<r.length;a++)c(r[a],e.topojson);var o=e.layers.backplot.select(\".choroplethlayer\");i.makeTraceGroups(o,r,\"trace choropleth\").each(function(e){var r=n.select(this).selectAll(\"path.choroplethlocation\").data(i.identity);r.enter().append(\"path\").classed(\"choroplethlocation\",!0),r.exit().remove(),l(t,e)})},feature2polygons:u}},{\"../../lib\":719,\"../../lib/geo_location_utils\":713,\"../../lib/polygon\":731,\"../../lib/topojson_utils\":746,\"./style\":931,d3:163}],930:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)(i=(n=s[r]).ct)&&(a=l.c2p(i),o=c.c2p(i),e.contains([a,o],null,r,t)?(u.push({pointNumber:r,lon:i[0],lat:i[1]}),n.selected=1):n.selected=0);return u}},{}],931:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../components/colorscale\");function s(t,e){var r=e[0].trace,s=e[0].node3.selectAll(\".choroplethlocation\"),l=r.marker||{},c=l.line||{},u=o.makeColorScaleFuncFromTrace(r);s.each(function(t){n.select(this).attr(\"fill\",u(t.z)).call(i.stroke,t.mlc||c.color).call(a.dashLine,\"\",t.mlw||c.width||0).style(\"opacity\",l.opacity)}),a.selectedPointStyle(s,r,t)}e.exports={style:function(t,e){e&&s(t,e)},styleOnSelect:function(t,e){var r=e[0].node3,n=e[0].trace;n.selectedpoints?a.selectedPointStyle(r.selectAll(\".choroplethlocation\"),n,t):s(t,e)}}},{\"../../components/color\":593,\"../../components/colorscale\":605,\"../../components/drawing\":614,d3:163}],932:[function(t,e,r){\"use strict\";var n=t(\"../choropleth/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../lib/extend\").extendFlat;e.exports=o({locations:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},geojson:{valType:\"any\",editType:\"calc\"},below:{valType:\"string\",editType:\"plot\"},text:n.text,hovertext:n.hovertext,marker:{line:{color:o({},n.marker.line.color,{editType:\"plot\"}),width:o({},n.marker.line.width,{editType:\"plot\"}),editType:\"calc\"},opacity:o({},n.marker.opacity,{editType:\"plot\"}),editType:\"calc\"},selected:{marker:{opacity:o({},n.selected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:o({},n.unselected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},hoverinfo:n.hoverinfo,hovertemplate:a({},{keys:[\"properties\"]})},i(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../choropleth/attributes\":923}],933:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"@turf/area\"),a=t(\"@turf/centroid\"),o=t(\"../../lib\"),s=t(\"../../components/colorscale\"),l=t(\"../../components/drawing\"),c=t(\"../../lib/geojson_utils\").makeBlank,u=t(\"../choropleth/plot\").feature2polygons;function h(t){var e,r=t[0].trace,n=r._opts;if(r.selectedpoints){for(var i=l.makeSelectedPointStyleFns(r),a=0;a<t.length;a++){var s=t[a];s.fOut&&(s.fOut.properties.mo2=i.selectedOpacityFn(s))}e={type:\"identity\",property:\"mo2\"}}else e=o.isArrayOrTypedArray(r.marker.opacity)?{type:\"identity\",property:\"mo\"}:r.marker.opacity;return o.extendFlat(n.fill.paint,{\"fill-opacity\":e}),o.extendFlat(n.line.paint,{\"line-opacity\":e}),n}e.exports={convert:function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,l={layout:{visibility:\"none\"},paint:{}},f={layout:{visibility:\"none\"},paint:{}},p=e._opts={fill:l,line:f,geojson:c()};if(!r)return p;var d=\"string\"==typeof e.geojson?(window.PlotlyGeoAssets||{})[e.geojson]:e.geojson;if(!o.isPlainObject(d))return o.error(\"Oops ... something when wrong when fetching \"+e.geojson),p;var g,v={},m=[];for(g=0;g<t.length;g++){var y=t[g];y.loc&&(v[y.loc]=y)}var x,b,_,w=s.makeColorScaleFuncFromTrace(e),k=e.marker,T=k.line||{};function A(t){var e=v[t.id];if(e){var r=t.geometry;if(\"Polygon\"===r.type||\"MultiPolygon\"===r.type){var n={fc:w(e.z)};x&&(n.mo=x(e)),b&&(n.mlc=b(e)),_&&(n.mlw=_(e));var s={type:\"Feature\",geometry:r,properties:n};e._polygons=u(s),e.ct=function(t){var e,r=t.geometry;if(\"MultiPolygon\"===r.type)for(var n=r.coordinates,o=0,s=0;s<n.length;s++){var l={type:\"Polygon\",coordinates:n[s]},c=i.default(l);c>o&&(o=c,e=l)}else e=r;return a.default(e).geometry.coordinates}(s),e.fIn=t,e.fOut=s,m.push(s)}else o.log([\"Location with id\",e.loc,\"does not have a valid GeoJSON geometry,\",\"choroplethmapbox traces only support *Polygon* and *MultiPolygon* geometries.\"].join(\" \"))}delete v[t.id]}switch(o.isArrayOrTypedArray(k.opacity)&&(x=function(t){var e=t.mo;return n(e)?+o.constrain(e,0,1):0}),o.isArrayOrTypedArray(T.color)&&(b=function(t){return t.mlc}),o.isArrayOrTypedArray(T.width)&&(_=function(t){return t.mlw}),d.type){case\"FeatureCollection\":var M=d.features;for(g=0;g<M.length;g++)A(M[g]);break;case\"Feature\":A(d);break;default:return o.warn([\"Invalid GeoJSON type\",(d.type||\"none\")+\",\",\"choroplethmapbox traces only support *FeatureCollection* and *Feature* types.\"].join(\" \")),p}for(var S in v)o.log(\"Location with id \"+S+\" does not have a matching feature\");var E=x?{type:\"identity\",property:\"mo\"}:k.opacity;return o.extendFlat(l.paint,{\"fill-color\":{type:\"identity\",property:\"fc\"},\"fill-opacity\":E}),o.extendFlat(f.paint,{\"line-color\":b?{type:\"identity\",property:\"mlc\"}:T.color,\"line-width\":_?{type:\"identity\",property:\"mlw\"}:T.width,\"line-opacity\":E}),l.layout.visibility=\"visible\",f.layout.visibility=\"visible\",p.geojson={type:\"FeatureCollection\",features:m},h(t),p},convertOnSelect:h}},{\"../../components/colorscale\":605,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/geojson_utils\":714,\"../choropleth/plot\":929,\"@turf/area\":55,\"@turf/centroid\":56,\"fast-isnumeric\":225}],934:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\"),u=s(\"geojson\");n.isArrayOrTypedArray(l)&&l.length&&n.isArrayOrTypedArray(c)&&c.length&&(\"string\"==typeof u&&\"\"!==u||n.isPlainObject(u))?(e._length=Math.min(l.length,c.length),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":932}],935:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../choropleth/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"../choropleth/hover\"),eventData:t(\"../choropleth/event_data\"),selectPoints:t(\"../choropleth/select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.updateOnSelect(e)},getBelow:function(t,e){for(var r=e.getMapLayers(),n=r.length-2;n>=0;n--){var i=r[n].id;if(\"string\"==typeof i&&0===i.indexOf(\"water\"))for(var a=n+1;a<r.length;a++)if(\"string\"==typeof(i=r[a].id)&&-1===i.indexOf(\"plotly-\"))return i}},moduleType:\"trace\",name:\"choroplethmapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"noOpacity\"],meta:{hr_name:\"choropleth_mapbox\"}}},{\"../../plots/mapbox\":822,\"../choropleth/calc\":924,\"../choropleth/event_data\":926,\"../choropleth/hover\":927,\"../choropleth/select\":930,\"../heatmap/colorbar\":1004,\"./attributes\":932,\"./defaults\":934,\"./plot\":936}],936:[function(t,e,r){\"use strict\";var n=t(\"./convert\").convert,i=t(\"./convert\").convertOnSelect,a=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function o(t,e){this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"fill\",a+e+\"-fill\"],[\"line\",a+e+\"-line\"]],this.below=null}var s=o.prototype;s.update=function(t){this._update(n(t))},s.updateOnSelect=function(t){this._update(i(t))},s._update=function(t){var e=this.subplot,r=this.layerList,n=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(t.geojson),n!==this.below&&(this._removeLayers(),this._addLayers(t,n),this.below=n);for(var i=0;i<r.length;i++){var a=r[i],o=a[0],s=a[1],l=t[o];e.setOptions(s,\"setLayoutProperty\",l.layout),\"visible\"===l.layout.visibility&&e.setOptions(s,\"setPaintProperty\",l.paint)}},s._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},s._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},s.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new o(t,r.uid),a=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(a,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":820,\"./convert\":933}],937:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"scaled\",\"absolute\"],editType:\"calc\",dflt:\"scaled\"},sizeref:{valType:\"number\",editType:\"calc\",min:0},anchor:{valType:\"enumerated\",editType:\"calc\",values:[\"tip\",\"tail\",\"cm\",\"center\"],dflt:\"cm\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:i({editType:\"calc\"},{keys:[\"norm\"]})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach(function(t){l[t]=a[t]}),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../mesh3d/attributes\":1053}],938:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){for(var r=e.u,i=e.v,a=e.w,o=Math.min(e.x.length,e.y.length,e.z.length,r.length,i.length,a.length),s=-1/0,l=1/0,c=0;c<o;c++){var u=r[c],h=i[c],f=a[c],p=Math.sqrt(u*u+h*h+f*f);s=Math.max(s,p),l=Math.min(l,p)}e._len=o,e._normMax=s,n(t,e,{vals:[l,s],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],939:[function(t,e,r){\"use strict\";var n=t(\"gl-cone3d\"),i=t(\"gl-cone3d\").createConeMesh,a=t(\"../../lib\").simpleMap,o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\");function c(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var u=c.prototype;u.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index,r=this.data.x[e],n=this.data.y[e],i=this.data.z[e],a=this.data.u[e],o=this.data.v[e],s=this.data.w[e];t.traceCoordinate=[r,n,i,a,o,s,Math.sqrt(a*a+o*o+s*s)];var l=this.data.hovertext||this.data.text;return Array.isArray(l)&&void 0!==l[e]?t.textLabel=l[e]:l&&(t.textLabel=l),!0}};var h={xaxis:0,yaxis:1,zaxis:2},f={tip:1,tail:0,cm:.25,center:.5},p={tip:1,tail:1,cm:.75,center:.5};function d(t,e){var r=t.fullSceneLayout,i=t.dataScale,c={};function u(t,e){var n=r[e],o=i[h[e]];return a(t,function(t){return n.d2l(t)*o})}c.vectors=l(u(e.u,\"xaxis\"),u(e.v,\"yaxis\"),u(e.w,\"zaxis\"),e._len),c.positions=l(u(e.x,\"xaxis\"),u(e.y,\"yaxis\"),u(e.z,\"zaxis\"),e._len);var d=s(e);c.colormap=o(e),c.vertexIntensityBounds=[d.min/e._normMax,d.max/e._normMax],c.coneOffset=f[e.anchor],\"scaled\"===e.sizemode?c.coneSize=e.sizeref||.5:c.coneSize=e.sizeref&&e._normMax?e.sizeref/e._normMax:.5;var g=n(c),v=e.lightposition;return g.lightPosition=[v.x,v.y,v.z],g.ambient=e.lighting.ambient,g.diffuse=e.lighting.diffuse,g.specular=e.lighting.specular,g.roughness=e.lighting.roughness,g.fresnel=e.lighting.fresnel,g.opacity=e.opacity,e._pad=p[e.anchor]*g.vectorScale*g.coneScale*e._normMax,g}u.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),a=i(r,n),o=new c(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../plots/gl3d/zip3\":818,\"gl-cone3d\":242}],940:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),h=s(\"x\"),f=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length&&p&&p.length?(s(\"sizeref\"),s(\"sizemode\"),s(\"anchor\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":937}],941:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"cone\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),eventData:function(t,e){return t.norm=e.traceCoordinate[6],t},meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":937,\"./calc\":938,\"./convert\":939,\"./defaults\":940}],942:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../components/drawing/attributes\").dash,s=t(\"../../plots/font_attributes\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../constants/filter_ops\"),u=c.COMPARISON_OPS2,h=c.INTERVAL_OPS,f=(t(\"../../constants/docs\").FORMAT_LINK,i.line);e.exports=l({z:n.z,x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,xtype:n.xtype,ytype:n.ytype,zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate,connectgaps:n.connectgaps,fillcolor:{valType:\"color\",editType:\"calc\"},autocontour:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"contours.start\":void 0,\"contours.end\":void 0,\"contours.size\":void 0}},ncontours:{valType:\"integer\",dflt:15,min:1,editType:\"calc\"},contours:{type:{valType:\"enumerated\",values:[\"levels\",\"constraint\"],dflt:\"levels\",editType:\"calc\"},start:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},end:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},coloring:{valType:\"enumerated\",values:[\"fill\",\"heatmap\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:{valType:\"boolean\",dflt:!0,editType:\"plot\"},showlabels:{valType:\"boolean\",dflt:!1,editType:\"plot\"},labelfont:s({editType:\"plot\",colorEditType:\"style\"}),labelformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},operation:{valType:\"enumerated\",values:[].concat(u).concat(h),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:l({},f.color,{editType:\"style+colorbars\"}),width:l({},f.width,{editType:\"style+colorbars\"}),dash:o,smoothing:l({},f.smoothing,{}),editType:\"plot\"}},a(\"\",{cLetter:\"z\",autoColorDflt:!1,editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../components/drawing/attributes\":613,\"../../constants/docs\":690,\"../../constants/filter_ops\":691,\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"../heatmap/attributes\":1001,\"../scatter/attributes\":1112}],943:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\"),i=t(\"../heatmap/calc\"),a=t(\"./set_contours\"),o=t(\"./end_plus\");e.exports=function(t,e){var r=i(t,e),s=r[0].z;a(e,s);var l,c=e.contours,u=n.extractOpts(e);if(\"heatmap\"===c.coloring&&u.auto&&!1===e.autocontour){var h=c.start,f=o(c),p=c.size||1,d=Math.floor((f-h)/p)+1;isFinite(p)||(p=1,d=1);var g=h-p/2;l=[g,g+d*p]}else l=s;return n.calc(t,e,{vals:l,cLetter:\"z\"}),r}},{\"../../components/colorscale\":605,\"../heatmap/calc\":1002,\"./end_plus\":953,\"./set_contours\":961}],944:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a,o,s=t[0],l=s.x.length,c=s.y.length,u=s.z,h=n.contours,f=-1/0,p=1/0;for(i=0;i<c;i++)p=Math.min(p,u[i][0]),p=Math.min(p,u[i][l-1]),f=Math.max(f,u[i][0]),f=Math.max(f,u[i][l-1]);for(i=1;i<l-1;i++)p=Math.min(p,u[0][i]),p=Math.min(p,u[c-1][i]),f=Math.max(f,u[0][i]),f=Math.max(f,u[c-1][i]);switch(s.prefixBoundary=!1,e){case\">\":h.value>f&&(s.prefixBoundary=!0);break;case\"<\":h.value<p&&(s.prefixBoundary=!0);break;case\"[]\":a=Math.min.apply(null,h.value),((o=Math.max.apply(null,h.value))<p||a>f)&&(s.prefixBoundary=!0);break;case\"][\":a=Math.min.apply(null,h.value),o=Math.max.apply(null,h.value),a<p&&o>f&&(s.prefixBoundary=!0)}}},{}],945:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\").extractOpts,i=t(\"./make_color_map\"),a=t(\"./end_plus\");e.exports={min:\"zmin\",max:\"zmax\",calc:function(t,e,r){var o=e.contours,s=e.line,l=o.size||1,c=o.coloring,u=i(e,{isColorbar:!0});if(\"heatmap\"===c){var h=n(e);r._fillgradient=e.colorscale,r._zrange=[h.min,h.max]}else\"fill\"===c&&(r._fillcolor=u);r._line={color:\"lines\"===c?u:s.color,width:!1!==o.showlines?s.width:0,dash:s.dash},r._levels={start:o.start,end:a(o),size:l}}}},{\"../../components/colorscale\":605,\"./end_plus\":953,\"./make_color_map\":958}],946:[function(t,e,r){\"use strict\";e.exports={BOTTOMSTART:[1,9,13,104,713],TOPSTART:[4,6,7,104,713],LEFTSTART:[8,12,14,208,1114],RIGHTSTART:[2,3,11,208,1114],NEWDELTA:[null,[-1,0],[0,-1],[-1,0],[1,0],null,[0,-1],[-1,0],[0,1],[0,1],null,[0,1],[1,0],[1,0],[0,-1]],CHOOSESADDLE:{104:[4,1],208:[2,8],713:[7,13],1114:[11,14]},SADDLEREMAINDER:{1:4,2:8,4:1,7:13,8:2,11:14,13:7,14:11},LABELDISTANCE:2,LABELINCREASE:10,LABELMIN:3,LABELMAX:10,LABELOPTIMIZER:{EDGECOST:1,ANGLECOST:1,NEIGHBORCOST:5,SAMELEVELFACTOR:10,SAMELEVELDISTANCE:5,MAXCOST:100,INITIALSEARCHPOINTS:10,ITERATIONS:5}}},{}],947:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./label_defaults\"),a=t(\"../../components/color\"),o=a.addOpacity,s=a.opacity,l=t(\"../../constants/filter_ops\"),c=l.CONSTRAINT_REDUCTION,u=l.COMPARISON_OPS2;e.exports=function(t,e,r,a,l,h){var f,p,d,g=e.contours,v=r(\"contours.operation\");(g._operation=c[v],function(t,e){var r;-1===u.indexOf(e.operation)?(t(\"contours.value\",[0,1]),Array.isArray(e.value)?e.value.length>2?e.value=e.value.slice(2):0===e.length?e.value=[0,1]:e.length<2?(r=parseFloat(e.value[0]),e.value=[r,r+1]):e.value=[parseFloat(e.value[0]),parseFloat(e.value[1])]:n(e.value)&&(r=parseFloat(e.value),e.value=[r,r+1])):(t(\"contours.value\",0),n(e.value)||(Array.isArray(e.value)?e.value=parseFloat(e.value[0]):e.value=0))}(r,g),\"=\"===v?f=g.showlines=!0:(f=r(\"contours.showlines\"),d=r(\"fillcolor\",o((t.line||{}).color||l,.5))),f)&&(p=r(\"line.color\",d&&s(d)?o(e.fillcolor,1):l),r(\"line.width\",2),r(\"line.dash\"));r(\"line.smoothing\"),i(r,a,p,h)}},{\"../../components/color\":593,\"../../constants/filter_ops\":691,\"./label_defaults\":957,\"fast-isnumeric\":225}],948:[function(t,e,r){\"use strict\";var n=t(\"../../constants/filter_ops\"),i=t(\"fast-isnumeric\");function a(t,e){var r,a=Array.isArray(e);function o(t){return i(t)?+t:null}return-1!==n.COMPARISON_OPS2.indexOf(t)?r=o(a?e[0]:e):-1!==n.INTERVAL_OPS.indexOf(t)?r=a?[o(e[0]),o(e[1])]:[o(e),o(e)]:-1!==n.SET_OPS.indexOf(t)&&(r=a?e.map(o):[o(e)]),r}function o(t){return function(e){e=a(t,e);var r=Math.min(e[0],e[1]),n=Math.max(e[0],e[1]);return{start:r,end:n,size:n-r}}}function s(t){return function(e){return{start:e=a(t,e),end:1/0,size:1/0}}}e.exports={\"[]\":o(\"[]\"),\"][\":o(\"][\"),\">\":s(\">\"),\"<\":s(\"<\"),\"=\":s(\"=\")}},{\"../../constants/filter_ops\":691,\"fast-isnumeric\":225}],949:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=n(\"contours.start\"),a=n(\"contours.end\"),o=!1===i||!1===a,s=r(\"contours.size\");!(o?e.autocontour=!0:r(\"autocontour\",!1))&&s||r(\"ncontours\")}},{}],950:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");function i(t){return n.extendFlat({},t,{edgepaths:n.extendDeep([],t.edgepaths),paths:n.extendDeep([],t.paths)})}e.exports=function(t,e){var r,a,o,s=function(t){return t.reverse()},l=function(t){return t};switch(e){case\"=\":case\"<\":return t;case\">\":for(1!==t.length&&n.warn(\"Contour data invalid for the specified inequality operation.\"),a=t[0],r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);return t;case\"][\":var c=s;s=l,l=c;case\"[]\":for(2!==t.length&&n.warn(\"Contour data invalid for the specified inequality range operation.\"),a=i(t[0]),o=i(t[1]),r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);for(;o.edgepaths.length;)a.edgepaths.push(l(o.edgepaths.shift()));for(;o.paths.length;)a.paths.push(l(o.paths.shift()));return[a]}}},{\"../../lib\":719}],951:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"./constraint_defaults\"),o=t(\"./contours_defaults\"),s=t(\"./style_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,l,r,i)}if(i(t,e,u,c)){u(\"text\"),u(\"hovertext\"),u(\"hovertemplate\");var h=\"constraint\"===u(\"contours.type\");u(\"connectgaps\",n.isArray1D(e.z)),h?a(t,e,u,c,r):(o(t,e,u,function(r){return n.coerce2(t,e,l,r)}),s(t,e,u,c))}else e.visible=!1}},{\"../../lib\":719,\"../heatmap/xyz_defaults\":1015,\"./attributes\":942,\"./constraint_defaults\":947,\"./contours_defaults\":949,\"./style_defaults\":963}],952:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constraint_mapping\"),a=t(\"./end_plus\");e.exports=function(t,e,r){for(var o=\"constraint\"===t.type?i[t._operation](t.value):t,s=o.size,l=[],c=a(o),u=r.trace._carpetTrace,h=u?{xaxis:u.aaxis,yaxis:u.baxis,x:r.a,y:r.b}:{xaxis:e.xaxis,yaxis:e.yaxis,x:r.x,y:r.y},f=o.start;f<c;f+=s)if(l.push(n.extendFlat({level:f,crossings:{},starts:[],edgepaths:[],paths:[],z:r.z,smoothing:r.trace.line.smoothing},h)),l.length>1e3){n.warn(\"Too many contours, clipping at 1000\",t);break}return l}},{\"../../lib\":719,\"./constraint_mapping\":948,\"./end_plus\":953}],953:[function(t,e,r){\"use strict\";e.exports=function(t){return t.end+t.size/1e6}},{}],954:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constants\");function a(t,e,r,n){return Math.abs(t[0]-e[0])<r&&Math.abs(t[1]-e[1])<n}function o(t,e,r,o,l){var c,u=e.join(\",\"),h=u,f=t.crossings[h],p=function(t,e,r){var n=0,a=0;t>20&&e?208===t||1114===t?n=0===r[0]?1:-1:a=0===r[1]?1:-1:-1!==i.BOTTOMSTART.indexOf(t)?a=1:-1!==i.LEFTSTART.indexOf(t)?n=1:-1!==i.TOPSTART.indexOf(t)?a=-1:n=-1;return[n,a]}(f,r,e),d=[s(t,e,[-p[0],-p[1]])],g=p.join(\",\"),v=t.z.length,m=t.z[0].length;for(c=0;c<1e4;c++){if(f>20?(f=i.CHOOSESADDLE[f][(p[0]||p[1])<0?0:1],t.crossings[h]=i.SADDLEREMAINDER[f]):delete t.crossings[h],!(p=i.NEWDELTA[f])){n.log(\"Found bad marching index:\",f,e,t.level);break}d.push(s(t,e,p)),e[0]+=p[0],e[1]+=p[1],a(d[d.length-1],d[d.length-2],o,l)&&d.pop(),h=e.join(\",\");var y=p[0]&&(e[0]<0||e[0]>m-2)||p[1]&&(e[1]<0||e[1]>v-2);if(h===u&&p.join(\",\")===g||r&&y)break;f=t.crossings[h]}1e4===c&&n.log(\"Infinite loop in contour?\");var x,b,_,w,k,T,A,M,S,E,C,L,P,O,z,I=a(d[0],d[d.length-1],o,l),D=0,R=.2*t.smoothing,F=[],B=0;for(c=1;c<d.length;c++)L=d[c],P=d[c-1],void 0,void 0,O=L[2]-P[2],z=L[3]-P[3],D+=A=Math.sqrt(O*O+z*z),F.push(A);var N=D/F.length*R;function j(t){return d[t%d.length]}for(c=d.length-2;c>=B;c--)if((x=F[c])<N){for(_=0,b=c-1;b>=B&&x+F[b]<N;b--)x+=F[b];if(I&&c===d.length-2)for(_=0;_<b&&x+F[_]<N;_++)x+=F[_];k=c-b+_+1,T=Math.floor((c+b+_+2)/2),w=I||c!==d.length-2?I||-1!==b?k%2?j(T):[(j(T)[0]+j(T+1)[0])/2,(j(T)[1]+j(T+1)[1])/2]:d[0]:d[d.length-1],d.splice(b+1,c-b+1,w),c=b+1,_&&(B=_),I&&(c===d.length-2?d[_]=d[d.length-1]:0===c&&(d[d.length-1]=d[0]))}for(d.splice(0,B),c=0;c<d.length;c++)d[c].length=2;if(!(d.length<2))if(I)d.pop(),t.paths.push(d);else{r||n.log(\"Unclosed interior contour?\",t.level,u,d.join(\"L\"));var U=!1;for(M=0;M<t.edgepaths.length;M++)if(E=t.edgepaths[M],!U&&a(E[0],d[d.length-1],o,l)){d.pop(),U=!0;var V=!1;for(S=0;S<t.edgepaths.length;S++)if(a((C=t.edgepaths[S])[C.length-1],d[0],o,l)){V=!0,d.shift(),t.edgepaths.splice(M,1),S===M?t.paths.push(d.concat(C)):(S>M&&S--,t.edgepaths[S]=C.concat(d,E));break}V||(t.edgepaths[M]=d.concat(E))}for(M=0;M<t.edgepaths.length&&!U;M++)a((E=t.edgepaths[M])[E.length-1],d[0],o,l)&&(d.shift(),t.edgepaths[M]=E.concat(d),U=!0);U||t.edgepaths.push(d)}}function s(t,e,r){var n=e[0]+Math.max(r[0],0),i=e[1]+Math.max(r[1],0),a=t.z[i][n],o=t.xaxis,s=t.yaxis;if(r[1]){var l=(t.level-a)/(t.z[i][n+1]-a);return[o.c2p((1-l)*t.x[n]+l*t.x[n+1],!0),s.c2p(t.y[i],!0),n+l,i]}var c=(t.level-a)/(t.z[i+1][n]-a);return[o.c2p(t.x[n],!0),s.c2p((1-c)*t.y[i]+c*t.y[i+1],!0),n,i+c]}e.exports=function(t,e,r){var i,a,s,l;for(e=e||.01,r=r||.01,a=0;a<t.length;a++){for(s=t[a],l=0;l<s.starts.length;l++)o(s,s.starts[l],\"edge\",e,r);for(i=0;Object.keys(s.crossings).length&&i<1e4;)i++,o(s,Object.keys(s.crossings)[0].split(\",\").map(Number),void 0,e,r);1e4===i&&n.log(\"Infinite loop in contour?\")}}},{\"../../lib\":719,\"./constants\":946}],955:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../heatmap/hover\");e.exports=function(t,e,r,a,o){var s=i(t,e,r,a,o,!0);return s&&s.forEach(function(t){var e=t.trace;\"constraint\"===e.contours.type&&(e.fillcolor&&n.opacity(e.fillcolor)?t.color=n.addOpacity(e.fillcolor,1):e.contours.showlines&&n.opacity(e.line.color)&&(t.color=n.addOpacity(e.line.color,1)))}),s}},{\"../../components/color\":593,\"../heatmap/hover\":1008}],956:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\").plot,style:t(\"./style\"),colorbar:t(\"./colorbar\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"contour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":942,\"./calc\":943,\"./colorbar\":945,\"./defaults\":951,\"./hover\":955,\"./plot\":960,\"./style\":962}],957:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i){if(i||(i={}),t(\"contours.showlabels\")){var a=e.font;n.coerceFont(t,\"contours.labelfont\",{family:a.family,size:a.size,color:r}),t(\"contours.labelformat\")}!1!==i.hasHover&&t(\"zhoverformat\")}},{\"../../lib\":719}],958:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/colorscale\"),a=t(\"./end_plus\");e.exports=function(t){var e=t.contours,r=e.start,o=a(e),s=e.size||1,l=Math.floor((o-r)/s)+1,c=\"lines\"===e.coloring?0:1,u=i.extractOpts(t);isFinite(s)||(s=1,l=1);var h,f,p=u.reversescale?i.flipScale(u.colorscale):u.colorscale,d=p.length,g=new Array(d),v=new Array(d);if(\"heatmap\"===e.coloring){var m=u.min,y=u.max;for(f=0;f<d;f++)h=p[f],g[f]=h[0]*(y-m)+m,v[f]=h[1];var x=n.extent([m,y,e.start,e.start+s*(l-1)]),b=x[m<y?0:1],_=x[m<y?1:0];b!==m&&(g.splice(0,0,b),v.splice(0,0,v[0])),_!==y&&(g.push(_),v.push(v[v.length-1]))}else for(f=0;f<d;f++)h=p[f],g[f]=(h[0]*(l+c-1)-c/2)*s+r,v[f]=h[1];return i.makeColorScaleFunc({domain:g,range:v},{noNumericCheck:!0})}},{\"../../components/colorscale\":605,\"./end_plus\":953,d3:163}],959:[function(t,e,r){\"use strict\";var n=t(\"./constants\");function i(t,e){var r=(e[0][0]>t?0:1)+(e[0][1]>t?0:2)+(e[1][1]>t?0:4)+(e[1][0]>t?0:8);return 5===r||10===r?t>(e[0][0]+e[0][1]+e[1][0]+e[1][1])/4?5===r?713:1114:5===r?104:208:15===r?0:r}e.exports=function(t){var e,r,a,o,s,l,c,u,h,f=t[0].z,p=f.length,d=f[0].length,g=2===p||2===d;for(r=0;r<p-1;r++)for(o=[],0===r&&(o=o.concat(n.BOTTOMSTART)),r===p-2&&(o=o.concat(n.TOPSTART)),e=0;e<d-1;e++)for(a=o.slice(),0===e&&(a=a.concat(n.LEFTSTART)),e===d-2&&(a=a.concat(n.RIGHTSTART)),s=e+\",\"+r,l=[[f[r][e],f[r][e+1]],[f[r+1][e],f[r+1][e+1]]],h=0;h<t.length;h++)(c=i((u=t[h]).level,l))&&(u.crossings[s]=c,-1!==a.indexOf(c)&&(u.starts.push([e,r]),g&&-1!==a.indexOf(c,a.indexOf(c)+1)&&u.starts.push([e,r])))}},{\"./constants\":946}],960:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../../plots/cartesian/set_convert\"),c=t(\"../heatmap/plot\"),u=t(\"./make_crossings\"),h=t(\"./find_all_paths\"),f=t(\"./empty_pathinfo\"),p=t(\"./convert_to_constraints\"),d=t(\"./close_boundaries\"),g=t(\"./constants\"),v=g.LABELOPTIMIZER;function m(t,e){var r,n,o,s,l,c,u,h=function(t,e){var r=t.prefixBoundary;if(void 0===r){var n=Math.min(t.z[0][0],t.z[0][1]);r=!t.edgepaths.length&&n>t.level}return r?\"M\"+e.join(\"L\")+\"Z\":\"\"}(t,e),f=0,p=t.edgepaths.map(function(t,e){return e}),d=!0;function g(t){return Math.abs(t[1]-e[2][1])<.01}function v(t){return Math.abs(t[0]-e[0][0])<.01}function m(t){return Math.abs(t[0]-e[2][0])<.01}for(;p.length;){for(c=a.smoothopen(t.edgepaths[f],t.smoothing),h+=d?c:c.replace(/^M/,\"L\"),p.splice(p.indexOf(f),1),r=t.edgepaths[f][t.edgepaths[f].length-1],s=-1,o=0;o<4;o++){if(!r){i.log(\"Missing end?\",f,t);break}for(u=r,Math.abs(u[1]-e[0][1])<.01&&!m(r)?n=e[1]:v(r)?n=e[0]:g(r)?n=e[3]:m(r)&&(n=e[2]),l=0;l<t.edgepaths.length;l++){var y=t.edgepaths[l][0];Math.abs(r[0]-n[0])<.01?Math.abs(r[0]-y[0])<.01&&(y[1]-r[1])*(n[1]-y[1])>=0&&(n=y,s=l):Math.abs(r[1]-n[1])<.01?Math.abs(r[1]-y[1])<.01&&(y[0]-r[0])*(n[0]-y[0])>=0&&(n=y,s=l):i.log(\"endpt to newendpt is not vert. or horz.\",r,n,y)}if(r=n,s>=0)break;h+=\"L\"+n}if(s===t.edgepaths.length){i.log(\"unclosed perimeter path\");break}f=s,(d=-1===p.indexOf(f))&&(f=p[0],h+=\"Z\")}for(f=0;f<t.paths.length;f++)h+=a.smoothclosed(t.paths[f],t.smoothing);return h}function y(t,e,r,n){var a=e.width/2,o=e.height/2,s=t.x,l=t.y,c=t.theta,u=Math.cos(c)*a,h=Math.sin(c)*a,f=(s>n.center?n.right-s:s-n.left)/(u+Math.abs(Math.sin(c)*o)),p=(l>n.middle?n.bottom-l:l-n.top)/(Math.abs(h)+Math.cos(c)*o);if(f<1||p<1)return 1/0;var d=v.EDGECOST*(1/(f-1)+1/(p-1));d+=v.ANGLECOST*c*c;for(var g=s-u,m=l-h,y=s+u,x=l+h,b=0;b<r.length;b++){var _=r[b],w=Math.cos(_.theta)*_.width/2,k=Math.sin(_.theta)*_.width/2,T=2*i.segmentDistance(g,m,y,x,_.x-w,_.y-k,_.x+w,_.y+k)/(e.height+_.height),A=_.level===e.level,M=A?v.SAMELEVELDISTANCE:1;if(T<=M)return 1/0;d+=v.NEIGHBORCOST*(A?v.SAMELEVELFACTOR:1)/(T-M)}return d}r.plot=function(t,e,o,s){var l=e.xaxis,v=e.yaxis;i.makeTraceGroups(s,o,\"contour\").each(function(o){var s=n.select(this),y=o[0],x=y.trace,b=y.x,_=y.y,w=x.contours,k=f(w,e,y),T=i.ensureSingle(s,\"g\",\"heatmapcoloring\"),A=[];\"heatmap\"===w.coloring&&(A=[o]),c(t,e,A,T),u(k),h(k);var M=l.c2p(b[0],!0),S=l.c2p(b[b.length-1],!0),E=v.c2p(_[0],!0),C=v.c2p(_[_.length-1],!0),L=[[M,C],[S,C],[S,E],[M,E]],P=k;\"constraint\"===w.type&&(P=p(k,w._operation),d(P,w._operation,L,x)),function(t,e,r){var n=i.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"===r.coloring?[0]:[]);n.enter().append(\"path\"),n.exit().remove(),n.attr(\"d\",\"M\"+e.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(s,L,w),function(t,e,r,a){var o=i.ensureSingle(t,\"g\",\"contourfill\").selectAll(\"path\").data(\"fill\"===a.coloring||\"constraint\"===a.type&&\"=\"!==a._operation?e:[]);o.enter().append(\"path\"),o.exit().remove(),o.each(function(t){var e=m(t,r);e?n.select(this).attr(\"d\",e).style(\"stroke\",\"none\"):n.select(this).remove()})}(s,P,L,w),function(t,e,o,s,l){var c=i.ensureSingle(t,\"g\",\"contourlines\"),u=!1!==l.showlines,h=l.showlabels,f=u&&h,p=r.createLines(c,u||h,e),d=r.createLineClip(c,f,o,s.trace.uid),v=t.selectAll(\"g.contourlabels\").data(h?[0]:[]);if(v.exit().remove(),v.enter().append(\"g\").classed(\"contourlabels\",!0),h){var m=[],y=[];i.clearLocationCache();var x=r.labelFormatter(l,s.t.cb,o._fullLayout),b=a.tester.append(\"text\").attr(\"data-notex\",1).call(a.font,l.labelfont),_=e[0].xaxis,w=e[0].yaxis,k=_._length,T=w._length,A=_.range,M=w.range,S=i.aggNums(Math.min,null,s.x),E=i.aggNums(Math.max,null,s.x),C=i.aggNums(Math.min,null,s.y),L=i.aggNums(Math.max,null,s.y),P=Math.max(_.c2p(S,!0),0),O=Math.min(_.c2p(E,!0),k),z=Math.max(w.c2p(L,!0),0),I=Math.min(w.c2p(C,!0),T),D={};A[0]<A[1]?(D.left=P,D.right=O):(D.left=O,D.right=P),M[0]<M[1]?(D.top=z,D.bottom=I):(D.top=I,D.bottom=z),D.middle=(D.top+D.bottom)/2,D.center=(D.left+D.right)/2,m.push([[D.left,D.top],[D.right,D.top],[D.right,D.bottom],[D.left,D.bottom]]);var R=Math.sqrt(k*k+T*T),F=g.LABELDISTANCE*R/Math.max(1,e.length/g.LABELINCREASE);p.each(function(t){var e=r.calcTextOpts(t.level,x,b,o);n.select(this).selectAll(\"path\").each(function(){var t=i.getVisibleSegment(this,D,e.height/2);if(t&&!(t.len<(e.width+e.height)*g.LABELMIN))for(var n=Math.min(Math.ceil(t.len/F),g.LABELMAX),a=0;a<n;a++){var o=r.findBestTextLocation(this,t,e,y,D);if(!o)break;r.addLabelData(o,e,y,m)}})}),b.remove(),r.drawLabels(v,y,o,d,f?m:null)}h&&!u&&p.remove()}(s,k,t,y,w),function(t,e,r,n,o){var s=r._fullLayout._clips,l=\"clip\"+n.trace.uid,c=s.selectAll(\"#\"+l).data(n.trace.connectgaps?[]:[0]);if(c.enter().append(\"clipPath\").classed(\"contourclip\",!0).attr(\"id\",l),c.exit().remove(),!1===n.trace.connectgaps){var f={level:.9,crossings:{},starts:[],edgepaths:[],paths:[],xaxis:e.xaxis,yaxis:e.yaxis,x:n.x,y:n.y,z:function(t){var e,r,n=t.trace._emptypoints,i=[],a=t.z.length,o=t.z[0].length,s=[];for(e=0;e<o;e++)s.push(1);for(e=0;e<a;e++)i.push(s.slice());for(e=0;e<n.length;e++)r=n[e],i[r[0]][r[1]]=0;return t.zmask=i,i}(n),smoothing:0};u([f]),h([f]);var p=m(f,o),d=i.ensureSingle(c,\"path\",\"\");d.attr(\"d\",p)}else l=null;a.setClipUrl(t,l,r)}(s,e,t,y,L)})},r.createLines=function(t,e,r){var n=r[0].smoothing,i=t.selectAll(\"g.contourlevel\").data(e?r:[]);if(i.exit().remove(),i.enter().append(\"g\").classed(\"contourlevel\",!0),e){var o=i.selectAll(\"path.openline\").data(function(t){return t.pedgepaths||t.edgepaths});o.exit().remove(),o.enter().append(\"path\").classed(\"openline\",!0),o.attr(\"d\",function(t){return a.smoothopen(t,n)}).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\");var s=i.selectAll(\"path.closedline\").data(function(t){return t.ppaths||t.paths});s.exit().remove(),s.enter().append(\"path\").classed(\"closedline\",!0),s.attr(\"d\",function(t){return a.smoothclosed(t,n)}).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\")}return i},r.createLineClip=function(t,e,r,n){var i=e?\"clipline\"+n:null,o=r._fullLayout._clips.selectAll(\"#\"+i).data(e?[0]:[]);return o.exit().remove(),o.enter().append(\"clipPath\").classed(\"contourlineclip\",!0).attr(\"id\",i),a.setClipUrl(t,i,r),o},r.labelFormatter=function(t,e,r){if(t.labelformat)return r._d3locale.numberFormat(t.labelformat);var n;if(e)n=e.axis;else{if(n={type:\"linear\",_id:\"ycontour\",showexponent:\"all\",exponentformat:\"B\"},\"constraint\"===t.type){var i=t.value;Array.isArray(i)?n.range=[i[0],i[i.length-1]]:n.range=[i,i]}else n.range=[t.start,t.end],n.nticks=(t.end-t.start)/t.size;n.range[0]===n.range[1]&&(n.range[1]+=n.range[0]||1),n.nticks||(n.nticks=1e3),l(n,r),s.prepTicks(n),n._tmin=null,n._tmax=null}return function(t){return s.tickText(n,t).text}},r.calcTextOpts=function(t,e,r,n){var i=e(t);r.text(i).call(o.convertToTspans,n);var s=a.bBox(r.node(),!0);return{text:i,width:s.width,height:s.height,level:t,dy:(s.top+s.bottom)/2}},r.findBestTextLocation=function(t,e,r,n,a){var o,s,l,c,u,h=r.width;e.isClosed?(s=e.len/v.INITIALSEARCHPOINTS,o=e.min+s/2,l=e.max):(s=(e.len-h)/(v.INITIALSEARCHPOINTS+1),o=e.min+s+h/2,l=e.max-(s+h)/2);for(var f=1/0,p=0;p<v.ITERATIONS;p++){for(var d=o;d<l;d+=s){var g=i.getTextLocation(t,e.total,d,h),m=y(g,r,n,a);m<f&&(f=m,u=g,c=d)}if(f>2*v.MAXCOST)break;p&&(s/=2),l=(o=c-s/2)+1.5*s}if(f<=v.MAXCOST)return u},r.addLabelData=function(t,e,r,n){var i=e.width/2,a=e.height/2,o=t.x,s=t.y,l=t.theta,c=Math.sin(l),u=Math.cos(l),h=i*u,f=a*c,p=i*c,d=-a*u,g=[[o-h-f,s-p-d],[o+h-f,s+p-d],[o+h+f,s+p+d],[o-h+f,s-p+d]];r.push({text:e.text,x:o,y:s,dy:e.dy,theta:l,level:e.level,width:e.width,height:e.height}),n.push(g)},r.drawLabels=function(t,e,r,a,s){var l=t.selectAll(\"text\").data(e,function(t){return t.text+\",\"+t.x+\",\"+t.y+\",\"+t.theta});if(l.exit().remove(),l.enter().append(\"text\").attr({\"data-notex\":1,\"text-anchor\":\"middle\"}).each(function(t){var e=t.x+Math.sin(t.theta)*t.dy,i=t.y-Math.cos(t.theta)*t.dy;n.select(this).text(t.text).attr({x:e,y:i,transform:\"rotate(\"+180*t.theta/Math.PI+\" \"+e+\" \"+i+\")\"}).call(o.convertToTspans,r)}),s){for(var c=\"\",u=0;u<s.length;u++)c+=\"M\"+s[u].join(\"L\")+\"Z\";i.ensureSingle(a,\"path\",\"\").attr(\"d\",c)}}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/set_convert\":785,\"../heatmap/plot\":1012,\"./close_boundaries\":944,\"./constants\":946,\"./convert_to_constraints\":950,\"./empty_pathinfo\":952,\"./find_all_paths\":954,\"./make_crossings\":959,d3:163}],961:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\");function a(t,e,r){var i={type:\"linear\",range:[t,e]};return n.autoTicks(i,(e-t)/(r||15)),i}e.exports=function(t,e){var r=t.contours;if(t.autocontour){var o=t.zmin,s=t.zmax;(t.zauto||void 0===o)&&(o=i.aggNums(Math.min,null,e)),(t.zauto||void 0===s)&&(s=i.aggNums(Math.max,null,e));var l=a(o,s,t.ncontours);r.size=l.dtick,r.start=n.tickFirst(l),l.range.reverse(),r.end=n.tickFirst(l),r.start===o&&(r.start+=r.size),r.end===s&&(r.end-=r.size),r.start>r.end&&(r.start=r.end=(r.start+r.end)/2),t._input.contours||(t._input.contours={}),i.extendFlat(t._input.contours,{start:r.start,end:r.end,size:r.size}),t._input.autocontour=!0}else if(\"constraint\"!==r.type){var c,u=r.start,h=r.end,f=t._input.contours;if(u>h&&(r.start=f.start=h,h=r.end=f.end=u,u=r.start),!(r.size>0))c=u===h?1:a(u,h,t.ncontours).dtick,f.size=r.size=c}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767}],962:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../heatmap/style\"),o=t(\"./make_color_map\");e.exports=function(t){var e=n.select(t).selectAll(\"g.contour\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.each(function(t){var e=n.select(this),r=t[0].trace,a=r.contours,s=r.line,l=a.size||1,c=a.start,u=\"constraint\"===a.type,h=!u&&\"lines\"===a.coloring,f=!u&&\"fill\"===a.coloring,p=h||f?o(r):null;e.selectAll(\"g.contourlevel\").each(function(t){n.select(this).selectAll(\"path\").call(i.lineGroupStyle,s.width,h?p(t.level):s.color,s.dash)});var d=a.labelfont;if(e.selectAll(\"g.contourlabels text\").each(function(t){i.font(n.select(this),{family:d.family,size:d.size,color:d.color||(h?p(t.level):s.color)})}),u)e.selectAll(\"g.contourfill path\").style(\"fill\",r.fillcolor);else if(f){var g;e.selectAll(\"g.contourfill path\").style(\"fill\",function(t){return void 0===g&&(g=t.level),p(t.level+.5*l)}),void 0===g&&(g=c),e.selectAll(\"g.contourbg path\").style(\"fill\",p(g-.5*l))}}),a(t)}},{\"../../components/drawing\":614,\"../heatmap/style\":1013,\"./make_color_map\":958,d3:163}],963:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/defaults\"),i=t(\"./label_defaults\");e.exports=function(t,e,r,a,o){var s,l=r(\"contours.coloring\"),c=\"\";\"fill\"===l&&(s=r(\"contours.showlines\")),!1!==s&&(\"lines\"!==l&&(c=r(\"line.color\",\"#000\")),r(\"line.width\",.5),r(\"line.dash\")),\"none\"!==l&&(!0!==t.showlegend&&(e.showlegend=!1),e._dfltShowLegend=!1,n(t,e,a,r,{prefix:\"\",cLetter:\"z\"})),r(\"line.smoothing\"),i(r,a,c,o)}},{\"../../components/colorscale/defaults\":603,\"./label_defaults\":957}],964:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../contour/attributes\"),a=i.contours,o=t(\"../scatter/attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../lib/extend\").extendFlat,c=o.line;e.exports=l({carpet:{valType:\"string\",editType:\"calc\"},z:n.z,a:n.x,a0:n.x0,da:n.dx,b:n.y,b0:n.y0,db:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,atype:n.xtype,btype:n.ytype,fillcolor:i.fillcolor,autocontour:i.autocontour,ncontours:i.ncontours,contours:{type:a.type,start:a.start,end:a.end,size:a.size,coloring:{valType:\"enumerated\",values:[\"fill\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:a.showlines,showlabels:a.showlabels,labelfont:a.labelfont,labelformat:a.labelformat,operation:a.operation,value:a.value,editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:l({},c.color,{}),width:c.width,dash:c.dash,smoothing:l({},c.smoothing,{}),editType:\"plot\"},transforms:void 0},s(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../contour/attributes\":942,\"../heatmap/attributes\":1001,\"../scatter/attributes\":1112}],965:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\"),i=t(\"../../lib\"),a=t(\"../heatmap/convert_column_xyz\"),o=t(\"../heatmap/clean_2d_array\"),s=t(\"../heatmap/interp2d\"),l=t(\"../heatmap/find_empties\"),c=t(\"../heatmap/make_bound_array\"),u=t(\"./defaults\"),h=t(\"../carpet/lookup_carpetid\"),f=t(\"../contour/set_contours\");e.exports=function(t,e){var r=e._carpetTrace=h(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){if(!e.a||!e.b){var p=t.data[r.index],d=t.data[e.index];d.a||(d.a=p.a),d.b||(d.b=p.b),u(d,e,e._defaultColor,t._fullLayout)}var g=function(t,e){var r,u,h,f,p,d,g,v=e._carpetTrace,m=v.aaxis,y=v.baxis;m._minDtick=0,y._minDtick=0,i.isArray1D(e.z)&&a(e,m,y,\"a\",\"b\",[\"z\"]);r=e._a=e._a||e.a,f=e._b=e._b||e.b,r=r?m.makeCalcdata(e,\"_a\"):[],f=f?y.makeCalcdata(e,\"_b\"):[],u=e.a0||0,h=e.da||1,p=e.b0||0,d=e.db||1,g=e._z=o(e._z||e.z,e.transpose),e._emptypoints=l(g),s(g,e._emptypoints);var x=i.maxRowLength(g),b=\"scaled\"===e.xtype?\"\":r,_=c(e,b,u,h,x,m),w=\"scaled\"===e.ytype?\"\":f,k=c(e,w,p,d,g.length,y),T={a:_,b:k,z:g};\"levels\"===e.contours.type&&\"none\"!==e.contours.coloring&&n(t,e,{vals:g,containerStr:\"\",cLetter:\"z\"});return[T]}(t,e);return f(e,e._z),g}}},{\"../../components/colorscale/calc\":601,\"../../lib\":719,\"../carpet/lookup_carpetid\":915,\"../contour/set_contours\":961,\"../heatmap/clean_2d_array\":1003,\"../heatmap/convert_column_xyz\":1005,\"../heatmap/find_empties\":1007,\"../heatmap/interp2d\":1010,\"../heatmap/make_bound_array\":1011,\"./defaults\":966}],966:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"./attributes\"),o=t(\"../contour/constraint_defaults\"),s=t(\"../contour/contours_defaults\"),l=t(\"../contour/style_defaults\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,a,r,i)}if(u(\"carpet\"),t.a&&t.b){if(!i(t,e,u,c,\"a\",\"b\"))return void(e.visible=!1);u(\"text\"),\"constraint\"===u(\"contours.type\")?o(t,e,u,c,r,{hasHover:!1}):(s(t,e,u,function(r){return n.coerce2(t,e,a,r)}),l(t,e,u,c,{hasHover:!1}))}else e._defaultColor=r,e._length=null}},{\"../../lib\":719,\"../contour/constraint_defaults\":947,\"../contour/contours_defaults\":949,\"../contour/style_defaults\":963,\"../heatmap/xyz_defaults\":1015,\"./attributes\":964}],967:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../contour/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../contour/style\"),moduleType:\"trace\",name:\"contourcarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"contour\",\"symbols\",\"showLegend\",\"hasLines\",\"carpetDependent\"],meta:{}}},{\"../../plots/cartesian\":778,\"../contour/colorbar\":945,\"../contour/style\":962,\"./attributes\":964,\"./calc\":965,\"./defaults\":966,\"./plot\":970}],968:[function(t,e,r){\"use strict\";var n=t(\"../../components/drawing\"),i=t(\"../carpet/axis_aligned_line\"),a=t(\"../../lib\");e.exports=function(t,e,r,o,s,l,c,u){var h,f,p,d,g,v,m,y=\"\",x=e.edgepaths.map(function(t,e){return e}),b=!0,_=1e-4*Math.abs(r[0][0]-r[2][0]),w=1e-4*Math.abs(r[0][1]-r[2][1]);function k(t){return Math.abs(t[1]-r[0][1])<w}function T(t){return Math.abs(t[1]-r[2][1])<w}function A(t){return Math.abs(t[0]-r[0][0])<_}function M(t){return Math.abs(t[0]-r[2][0])<_}function S(t,e){var r,n,a,o,h=\"\";for(k(t)&&!M(t)||T(t)&&!A(t)?(o=s.aaxis,a=i(s,l,[t[0],e[0]],.5*(t[1]+e[1]))):(o=s.baxis,a=i(s,l,.5*(t[0]+e[0]),[t[1],e[1]])),r=1;r<a.length;r++)for(h+=o.smoothing?\"C\":\"L\",n=0;n<a[r].length;n++){var f=a[r][n];h+=[c.c2p(f[0]),u.c2p(f[1])]+\" \"}return h}for(h=0,f=null;x.length;){var E=e.edgepaths[h][0];for(f&&(y+=S(f,E)),m=n.smoothopen(e.edgepaths[h].map(o),e.smoothing),y+=b?m:m.replace(/^M/,\"L\"),x.splice(x.indexOf(h),1),f=e.edgepaths[h][e.edgepaths[h].length-1],g=-1,d=0;d<4;d++){if(!f){a.log(\"Missing end?\",h,e);break}for(k(f)&&!M(f)?p=r[1]:A(f)?p=r[0]:T(f)?p=r[3]:M(f)&&(p=r[2]),v=0;v<e.edgepaths.length;v++){var C=e.edgepaths[v][0];Math.abs(f[0]-p[0])<_?Math.abs(f[0]-C[0])<_&&(C[1]-f[1])*(p[1]-C[1])>=0&&(p=C,g=v):Math.abs(f[1]-p[1])<w?Math.abs(f[1]-C[1])<w&&(C[0]-f[0])*(p[0]-C[0])>=0&&(p=C,g=v):a.log(\"endpt to newendpt is not vert. or horz.\",f,p,C)}if(g>=0)break;y+=S(f,p),f=p}if(g===e.edgepaths.length){a.log(\"unclosed perimeter path\");break}h=g,(b=-1===x.indexOf(h))&&(h=x[0],y+=S(f,p)+\"Z\",f=null)}for(h=0;h<e.paths.length;h++)y+=n.smoothclosed(e.paths[h].map(o),e.smoothing);return y}},{\"../../components/drawing\":614,\"../../lib\":719,\"../carpet/axis_aligned_line\":899}],969:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i,a,o,s,l,c,u;for(r=0;r<t.length;r++){for(o=(a=t[r]).pedgepaths=[],s=a.ppaths=[],n=0;n<a.edgepaths.length;n++){for(u=a.edgepaths[n],l=[],i=0;i<u.length;i++)l[i]=e(u[i]);o.push(l)}for(n=0;n<a.paths.length;n++){for(u=a.paths[n],c=[],i=0;i<u.length;i++)c[i]=e(u[i]);s.push(c)}}}},{}],970:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../carpet/map_1d_array\"),a=t(\"../carpet/makepath\"),o=t(\"../../components/drawing\"),s=t(\"../../lib\"),l=t(\"../contour/make_crossings\"),c=t(\"../contour/find_all_paths\"),u=t(\"../contour/plot\"),h=t(\"../contour/constants\"),f=t(\"../contour/convert_to_constraints\"),p=t(\"./join_all_paths\"),d=t(\"../contour/empty_pathinfo\"),g=t(\"./map_pathinfo\"),v=t(\"../carpet/lookup_carpetid\"),m=t(\"../contour/close_boundaries\");function y(t,e,r){var n=t.getPointAtLength(e),i=t.getPointAtLength(r),a=i.x-n.x,o=i.y-n.y,s=Math.sqrt(a*a+o*o);return[a/s,o/s]}function x(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]);return[t[0]/e,t[1]/e]}function b(t,e){var r=Math.abs(t[0]*e[0]+t[1]*e[1]);return Math.sqrt(1-r*r)/r}e.exports=function(t,e,r,_){var w=e.xaxis,k=e.yaxis;s.makeTraceGroups(_,r,\"contour\").each(function(r){var _=n.select(this),T=r[0],A=T.trace,M=A._carpetTrace=v(t,A),S=t.calcdata[M.index][0];if(M.visible&&\"legendonly\"!==M.visible){var E=T.a,C=T.b,L=A.contours,P=d(L,e,T),O=\"constraint\"===L.type,z=L._operation,I=O?\"=\"===z?\"lines\":\"fill\":L.coloring,D=[[E[0],C[C.length-1]],[E[E.length-1],C[C.length-1]],[E[E.length-1],C[0]],[E[0],C[0]]];l(P);var R=1e-8*(E[E.length-1]-E[0]),F=1e-8*(C[C.length-1]-C[0]);c(P,R,F);var B,N,j,U,V=P;\"constraint\"===L.type&&(V=f(P,z),m(V,z,D,A)),g(P,G);var q=[];for(U=S.clipsegments.length-1;U>=0;U--)B=S.clipsegments[U],N=i([],B.x,w.c2p),j=i([],B.y,k.c2p),N.reverse(),j.reverse(),q.push(a(N,j,B.bicubic));var H=\"M\"+q.join(\"L\")+\"Z\";!function(t,e,r,n,o,l){var c,u,h,f,p=s.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"!==l||o?[]:[0]);p.enter().append(\"path\"),p.exit().remove();var d=[];for(f=0;f<e.length;f++)c=e[f],u=i([],c.x,r.c2p),h=i([],c.y,n.c2p),d.push(a(u,h,c.bicubic));p.attr(\"d\",\"M\"+d.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(_,S.clipsegments,w,k,O,I),function(t,e,r,i,a,o,l,c,u,h,f){var d=s.ensureSingle(e,\"g\",\"contourfill\").selectAll(\"path\").data(\"fill\"===h?a:[]);d.enter().append(\"path\"),d.exit().remove(),d.each(function(e){var a=p(t,e,o,l,c,u,r,i);e.prefixBoundary&&(a=f+a),a?n.select(this).attr(\"d\",a).style(\"stroke\",\"none\"):n.select(this).remove()})}(A,_,w,k,V,D,G,M,S,I,H),function(t,e,r,i,a,l,c){var f=s.ensureSingle(t,\"g\",\"contourlines\"),p=!1!==a.showlines,d=a.showlabels,g=p&&d,v=u.createLines(f,p||d,e),m=u.createLineClip(f,g,r,i.trace.uid),_=t.selectAll(\"g.contourlabels\").data(d?[0]:[]);if(_.exit().remove(),_.enter().append(\"g\").classed(\"contourlabels\",!0),d){var w=l.xaxis,k=l.yaxis,T=w._length,A=k._length,M=[[[0,0],[T,0],[T,A],[0,A]]],S=[];s.clearLocationCache();var E=u.labelFormatter(a,i.t.cb,r._fullLayout),C=o.tester.append(\"text\").attr(\"data-notex\",1).call(o.font,a.labelfont),L={left:0,right:T,center:T/2,top:0,bottom:A,middle:A/2},P=Math.sqrt(T*T+A*A),O=h.LABELDISTANCE*P/Math.max(1,e.length/h.LABELINCREASE);v.each(function(t){var e=u.calcTextOpts(t.level,E,C,r);n.select(this).selectAll(\"path\").each(function(r){var n=s.getVisibleSegment(this,L,e.height/2);if(n&&(function(t,e,r,n,i,a){for(var o,s=0;s<r.pedgepaths.length;s++)e===r.pedgepaths[s]&&(o=r.edgepaths[s]);if(!o)return;var l=i.a[0],c=i.a[i.a.length-1],u=i.b[0],h=i.b[i.b.length-1];function f(t,e){var r,n=0;return(Math.abs(t[0]-l)<.1||Math.abs(t[0]-c)<.1)&&(r=x(i.dxydb_rough(t[0],t[1],.1)),n=Math.max(n,a*b(e,r)/2)),(Math.abs(t[1]-u)<.1||Math.abs(t[1]-h)<.1)&&(r=x(i.dxyda_rough(t[0],t[1],.1)),n=Math.max(n,a*b(e,r)/2)),n}var p=y(t,0,1),d=y(t,n.total,n.total-1),g=f(o[0],p),v=n.total-f(o[o.length-1],d);n.min<g&&(n.min=g);n.max>v&&(n.max=v);n.len=n.max-n.min}(this,r,t,n,c,e.height),!(n.len<(e.width+e.height)*h.LABELMIN)))for(var i=Math.min(Math.ceil(n.len/O),h.LABELMAX),a=0;a<i;a++){var o=u.findBestTextLocation(this,n,e,S,L);if(!o)break;u.addLabelData(o,e,S,M)}})}),C.remove(),u.drawLabels(_,S,r,m,g?M:null)}d&&!p&&v.remove()}(_,P,t,T,L,e,M),o.setClipUrl(_,M._clipPathId,t)}function G(t){var e=M.ab2xy(t[0],t[1],!0);return[w.c2p(e[0]),k.c2p(e[1])]}})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../carpet/lookup_carpetid\":915,\"../carpet/makepath\":916,\"../carpet/map_1d_array\":917,\"../contour/close_boundaries\":944,\"../contour/constants\":946,\"../contour/convert_to_constraints\":950,\"../contour/empty_pathinfo\":952,\"../contour/find_all_paths\":954,\"../contour/make_crossings\":959,\"../contour/plot\":960,\"./join_all_paths\":968,\"./map_pathinfo\":969,d3:163}],971:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../scattermapbox/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({lon:o.lon,lat:o.lat,z:{valType:\"data_array\",editType:\"calc\"},radius:{valType:\"number\",editType:\"plot\",arrayOk:!0,min:1,dflt:30},below:{valType:\"string\",editType:\"plot\"},text:o.text,hovertext:o.hovertext,hoverinfo:s({},a.hoverinfo,{flags:[\"lon\",\"lat\",\"z\",\"text\",\"name\"]}),hovertemplate:i()},n(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scattermapbox/attributes\":1171}],972:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../components/colorscale/calc\"),s=t(\"../../lib\")._;e.exports=function(t,e){for(var r=e._length,l=new Array(r),c=e.z,u=i(c)&&c.length,h=0;h<r;h++){var f=l[h]={},p=e.lon[h],d=e.lat[h];if(f.lonlat=n(p)&&n(d)?[+p,+d]:[a,a],u){var g=c[h];f.z=n(g)?g:a}}return o(t,e,{vals:u?c:[0,1],containerStr:\"\",cLetter:\"z\"}),r&&(l[0].t={labels:{lat:s(t,\"lat:\")+\" \",lon:s(t,\"lon:\")+\" \"}}),l}},{\"../../components/colorscale/calc\":601,\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],973:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../../components/colorscale\"),s=t(\"../../constants/numerical\").BADNUM,l=t(\"../../lib/geojson_utils\").makeBlank;e.exports=function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,c=e._opts={heatmap:{layout:{visibility:\"none\"},paint:{}},geojson:l()};if(!r)return c;var u,h=[],f=e.z,p=e.radius,d=i.isArrayOrTypedArray(f)&&f.length,g=i.isArrayOrTypedArray(p);for(u=0;u<t.length;u++){var v=t[u],m=v.lonlat;if(m[0]!==s){var y={};if(d){var x=v.z;y.z=x!==s?x:0}g&&(y.r=n(p[u])&&p[u]>0?+p[u]:0),h.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:m},properties:y})}}var b=o.extractOpts(e),_=b.reversescale?o.flipScale(b.colorscale):b.colorscale,w=_[0][1],k=[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,a.opacity(w)<1?w:a.addOpacity(w,0)];for(u=1;u<_.length;u++)k.push(_[u][0],_[u][1]);var T=[\"interpolate\",[\"linear\"],[\"get\",\"z\"],b.min,0,b.max,1];return i.extendFlat(c.heatmap.paint,{\"heatmap-weight\":d?T:1/(b.max-b.min),\"heatmap-color\":k,\"heatmap-radius\":g?{type:\"identity\",property:\"r\"}:e.radius,\"heatmap-opacity\":e.opacity}),c.geojson={type:\"FeatureCollection\",features:h},c.heatmap.layout.visibility=\"visible\",c}},{\"../../components/color\":593,\"../../components/colorscale\":605,\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/geojson_utils\":714,\"fast-isnumeric\":225}],974:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"lon\")||[],c=s(\"lat\")||[],u=Math.min(l.length,c.length);u?(e._length=u,s(\"z\"),s(\"radius\"),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":971}],975:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.z=e.z,t}},{}],976:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../scattermapbox/hover\");e.exports=function(t,e,r){var o=a(t,e,r);if(o){var s=o[0],l=s.cd,c=l[0].trace,u=l[s.index];if(delete s.color,\"z\"in u){var h=s.subplot.mockAxis;s.z=u.z,s.zLabel=i.tickText(h,h.c2l(u.z),\"hover\").text}return s.extraText=function(t,e,r){if(t.hovertemplate)return;var i=(e.hi||t.hoverinfo).split(\"+\"),a=-1!==i.indexOf(\"all\"),o=-1!==i.indexOf(\"lon\"),s=-1!==i.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}a||o&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):o?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(a||-1!==i.indexOf(\"text\"))&&n.fillText(e,t,c);return c.join(\"<br>\")}(c,u,l[0].t.labels),[s]}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scattermapbox/hover\":1175}],977:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),getBelow:function(t,e){for(var r=e.getMapLayers(),n=0;n<r.length;n++){var i=r[n],a=i.id;if(\"symbol\"===i.type&&\"string\"==typeof a&&-1===a.indexOf(\"plotly-\"))return a}},moduleType:\"trace\",name:\"densitymapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\"],meta:{hr_name:\"density_mapbox\"}}},{\"../../plots/mapbox\":822,\"../heatmap/colorbar\":1004,\"./attributes\":971,\"./calc\":972,\"./defaults\":974,\"./event_data\":975,\"./hover\":976,\"./plot\":978}],978:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function a(t,e){this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"heatmap\",i+e+\"-heatmap\"]],this.below=null}var o=a.prototype;o.update=function(t){var e=this.subplot,r=this.layerList,i=n(t),a=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(i.geojson),a!==this.below&&(this._removeLayers(),this._addLayers(i,a),this.below=a);for(var o=0;o<r.length;o++){var s=r[o],l=s[0],c=s[1],u=i[l];e.setOptions(c,\"setLayoutProperty\",u.layout),\"visible\"===u.layout.visibility&&e.setOptions(c,\"setPaintProperty\",u.paint)}},o._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},o._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},o.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new a(t,r.uid),o=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(o,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),i}},{\"../../plots/mapbox/constants\":820,\"./convert\":973}],979:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":719}],980:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"./constants\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../components/color\");e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,hovertext:n.hovertext,hovertemplate:o({},{keys:s.eventDataKeys}),hoverinfo:l({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"percent initial\",\"percent previous\",\"percent total\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"percent initial\",\"percent previous\",\"percent total\",\"value\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},text:n.text,textposition:l({},n.textposition,{dflt:\"auto\"}),insidetextanchor:l({},n.insidetextanchor,{dflt:\"middle\"}),textangle:l({},n.textangle,{dflt:0}),textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:l({},n.orientation,{}),offset:l({},n.offset,{arrayOk:!1}),width:l({},n.width,{arrayOk:!1}),marker:n.marker,connector:{fillcolor:{valType:\"color\",editType:\"style\"},line:{color:l({},i.color,{dflt:c.defaultLine}),width:l({},i.width,{dflt:0,editType:\"plot\"}),dash:i.dash,editType:\"style\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":593,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../bar/attributes\":857,\"../scatter/attributes\":1112,\"./constants\":982}],981:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"./arrays_to_calcdata\"),a=t(\"../scatter/calc_selection\"),o=t(\"../../constants/numerical\").BADNUM;function s(t){return t===o?0:t}e.exports=function(t,e){var r,l,c,u,h=n.getFromId(t,e.xaxis||\"x\"),f=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=h.makeCalcdata(e,\"x\"),l=f.makeCalcdata(e,\"y\")):(r=f.makeCalcdata(e,\"y\"),l=h.makeCalcdata(e,\"x\"));var p,d=Math.min(l.length,r.length),g=new Array(d);for(e._base=[],c=0;c<d;c++){r[c]<0&&(r[c]=o);var v=!1;r[c]!==o&&c+1<d&&r[c+1]!==o&&(v=!0),u=g[c]={p:l[c],s:r[c],cNext:v},e._base[c]=-.5*u.s,e.ids&&(u.id=String(e.ids[c])),0===c&&(g[0].vTotal=0),g[0].vTotal+=s(u.s),u.begR=s(u.s)/s(g[0].s)}for(c=0;c<d;c++)(u=g[c]).s!==o&&(u.sumR=u.s/g[0].vTotal,u.difR=void 0!==p?u.s/p:1,p=u.s);return i(g,e),a(g,e),g}},{\"../../constants/numerical\":695,\"../../plots/cartesian/axes\":767,\"../scatter/calc_selection\":1114,\"./arrays_to_calcdata\":979}],982:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"percentInitial\",\"percentPrevious\",\"percentTotal\"]}},{}],983:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],h=[],f=[];for(i=0;i<o.length;i++){var p=o[i],d=\"h\"===p.orientation;!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"funnel\"===p.type&&(r=s[i],d?f.push(r):h.push(r),u.push(r))}var g={mode:a.funnelmode,norm:a.funnelnorm,gap:a.funnelgap,groupgap:a.funnelgroupgap};for(n(t,l,c,h,g),n(t,c,l,f,g),i=0;i<u.length;i++){r=u[i];for(var v=0;v<r.length;v++)v+1<r.length&&(r[v].nextP0=r[v+1].p0,r[v].nextS0=r[v+1].s0,r[v].nextP1=r[v+1].p1,r[v].nextS1=r[v+1].s1)}}},{\"../bar/cross_trace_calc\":860}],984:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"./attributes\"),l=t(\"../../components/color\");e.exports={supplyDefaults:function(t,e,r,i){function c(r,i){return n.coerce(t,e,s,r,i)}if(o(t,e,i,c)){c(\"orientation\",e.y&&!e.x?\"v\":\"h\"),c(\"offset\"),c(\"width\");var u=c(\"text\");c(\"hovertext\"),c(\"hovertemplate\");var h=c(\"textposition\");a(t,e,i,c,h,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"!==e.textposition&&c(\"textinfo\",Array.isArray(u)?\"text+value\":\"value\");var f=c(\"marker.color\",r);c(\"marker.line.color\",l.defaultLine),c(\"marker.line.width\"),c(\"connector.visible\")&&(c(\"connector.fillcolor\",function(t){var e=n.isArrayOrTypedArray(t)?\"#000\":t;return l.addOpacity(e,.5*l.opacity(e))}(f)),c(\"connector.line.width\")&&(c(\"connector.line.color\"),c(\"connector.line.dash\")))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,s,t)}if(\"group\"===e.funnelmode)for(var l=0;l<t.length;l++)r=(a=t[l])._input,i(r,a,e,o)}}},{\"../../components/color\":593,\"../../lib\":719,\"../bar/defaults\":861,\"../scatter/xy_defaults\":1137,\"./attributes\":980}],985:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"percentInitial\"in e&&(t.percentInitial=e.percentInitial),\"percentPrevious\"in e&&(t.percentPrevious=e.percentPrevious),\"percentTotal\"in e&&(t.percentTotal=e.percentTotal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],986:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\").opacity,i=t(\"../bar/hover\").hoverOnBars,a=t(\"../../lib\").formatPercent;e.exports=function(t,e,r,o){var s=i(t,e,r,o);if(s){var l=s.cd,c=l[0].trace,u=\"h\"===c.orientation,h=l[s.index];s[(u?\"x\":\"y\")+\"LabelVal\"]=h.s,s.percentInitial=h.begR,s.percentInitialLabel=a(h.begR,1),s.percentPrevious=h.difR,s.percentPreviousLabel=a(h.difR,1),s.percentTotal=h.sumR,s.percentTotalLabel=a(h.sumR,1);var f=h.hi||c.hoverinfo,p=[];if(f&&\"none\"!==f&&\"skip\"!==f){var d=\"all\"===f,g=f.split(\"+\"),v=function(t){return d||-1!==g.indexOf(t)};v(\"percent initial\")&&p.push(s.percentInitialLabel+\" of initial\"),v(\"percent previous\")&&p.push(s.percentPreviousLabel+\" of previous\"),v(\"percent total\")&&p.push(s.percentTotalLabel+\" of total\")}return s.extraText=p.join(\"<br>\"),s.color=function(t,e){var r=t.marker,i=e.mc||r.color,a=e.mlc||r.line.color,o=e.mlw||r.line.width;if(n(i))return i;if(n(a)&&o)return a}(c,h),[s]}}},{\"../../components/color\":593,\"../../lib\":719,\"../bar/hover\":863}],987:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"funnel\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../bar/select\":868,\"./attributes\":980,\"./calc\":981,\"./cross_trace_calc\":983,\"./defaults\":984,\"./event_data\":985,\"./hover\":986,\"./layout_attributes\":988,\"./layout_defaults\":989,\"./plot\":990,\"./style\":991}],988:[function(t,e,r){\"use strict\";e.exports={funnelmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},funnelgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},funnelgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],989:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"funnel\"===l.type){a=!0;break}}a&&(o(\"funnelmode\"),o(\"funnelgap\",.2),o(\"funnelgroupgap\"))}},{\"../../lib\":719,\"./layout_attributes\":988}],990:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../bar/plot\").plot;function s(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),i[3]=o.c2p(t.nextS1,!0),a[3]=s.c2p(t.nextP1,!0),n?[i,a]:[a,i]}e.exports=function(t,e,r,l){var c=t._fullLayout;!function(t,e,r,o){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each(function(r){var o=n.select(this),u=r[0].trace,h=i.ensureSingle(o,\"g\",\"regions\");if(u.connector&&u.connector.visible){var f=\"h\"===u.orientation,p=h.selectAll(\"g.region\").data(i.identity);p.enter().append(\"g\").classed(\"region\",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var u=s(r,l,c,f),h=u[0],p=u[1],g=\"\";void 0!==h[3]&&void 0!==p[3]&&(g+=f?\"M\"+h[0]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[2]+\"H\"+h[3]+\"L\"+h[1]+\",\"+p[1]+\"Z\":\"M\"+h[1]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[3]+\"V\"+p[2]+\"L\"+h[1]+\",\"+p[0]+\"Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}})}else h.remove()})}(t,e,r,l),function(t,e,r,o){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each(function(r){var o=n.select(this),u=r[0].trace,h=i.ensureSingle(o,\"g\",\"lines\");if(u.connector&&u.connector.visible&&u.connector.line.width){var f=\"h\"===u.orientation,p=h.selectAll(\"g.line\").data(i.identity);p.enter().append(\"g\").classed(\"line\",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var u=s(r,l,c,f),h=u[0],p=u[1],g=\"\";void 0!==h[3]&&void 0!==p[3]&&(f?(g+=\"M\"+h[0]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[2],g+=\"M\"+h[1]+\",\"+p[1]+\"L\"+h[3]+\",\"+p[2]):(g+=\"M\"+h[1]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[3],g+=\"M\"+h[1]+\",\"+p[0]+\"L\"+h[2]+\",\"+p[2])),\"\"===g&&(g=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}})}else h.remove()})}(t,e,r,l),o(t,e,r,l,{mode:c.funnelmode,norm:c.funnelmode,gap:c.funnelgap,groupgap:c.funnelgroupgap})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../bar/plot\":867,d3:163}],991:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\").styleTextPoints;e.exports={style:function(t,e,r){var l=r||n.select(t).selectAll(\"g.funnellayer\").selectAll(\"g.trace\");l.style(\"opacity\",function(t){return t[0].trace.opacity}),l.each(function(e){var r=n.select(this),l=e[0].trace;r.selectAll(\".point > path\").each(function(t){if(!t.isBlank){var e=l.marker;n.select(this).call(a.fill,t.mc||e.color).call(a.stroke,t.mlc||e.line.color).call(i.dashLine,e.line.dash,t.mlw||e.line.width).style(\"opacity\",l.selectedpoints&&!t.selected?o:1)}}),s(r,l,t),r.selectAll(\".regions\").each(function(){n.select(this).selectAll(\"path\").style(\"stroke-width\",0).call(a.fill,l.connector.fillcolor)}),r.selectAll(\".lines\").each(function(){var t=l.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)})})}}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../constants/interactions\":694,\"../bar/style\":870,d3:163}],992:[function(t,e,r){\"use strict\";var n=t(\"../pie/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../plots/domain\").attributes,o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports={labels:n.labels,label0:n.label0,dlabel:n.dlabel,values:n.values,marker:{colors:n.marker.colors,line:{color:s({},n.marker.line.color,{dflt:null}),width:s({},n.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},text:n.text,hovertext:n.hovertext,scalegroup:s({},n.scalegroup,{}),textinfo:s({},n.textinfo,{flags:[\"label\",\"text\",\"value\",\"percent\"]}),hoverinfo:s({},i.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:o({},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),textposition:s({},n.textposition,{values:[\"inside\",\"none\"],dflt:\"inside\"}),textfont:n.textfont,insidetextfont:n.insidetextfont,title:{text:n.title.text,font:n.title.font,position:s({},n.title.position,{values:[\"top left\",\"top center\",\"top right\"],dflt:\"top center\"}),editType:\"plot\"},domain:a({name:\"funnelarea\",trace:!0,editType:\"calc\"}),aspectratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},baseratio:{valType:\"number\",min:0,max:1,dflt:.333,editType:\"plot\"}}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../pie/attributes\":1086}],993:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData;r.name=\"funnelarea\",r.plot=function(t){var e=n.getModule(\"funnelarea\"),r=i(t.calcdata,e)[0];e.plot(t,r)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"funnelarea\"),a=e._has&&e._has(\"funnelarea\");i&&!a&&n._funnelarealayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],994:[function(t,e,r){\"use strict\";var n=t(\"../pie/calc\");e.exports={calc:function(t,e){return n.calc(t,e)},crossTraceCalc:function(t){n.crossTraceCalc(t,{type:\"funnelarea\"})}}},{\"../pie/calc\":1088}],995:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}var c,u=l(\"values\"),h=n.isArrayOrTypedArray(u),f=l(\"labels\");if(Array.isArray(f)?(c=f.length,h&&(c=Math.min(c,u.length))):h&&(c=u.length,l(\"label0\"),l(\"dlabel\")),c){e._length=c,l(\"marker.line.width\")&&l(\"marker.line.color\",s.paper_bgcolor),l(\"marker.colors\"),l(\"scalegroup\");var p=l(\"text\"),d=l(\"textinfo\",Array.isArray(p)?\"text+percent\":\"percent\");if(l(\"hovertext\"),l(\"hovertemplate\"),d&&\"none\"!==d){var g=l(\"textposition\");o(t,e,s,l,g,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}a(e,s,l),l(\"title.text\")&&(l(\"title.position\"),n.coerceFont(l,\"title.font\",s.font)),l(\"aspectratio\"),l(\"baseratio\")}else e.visible=!1}},{\"../../lib\":719,\"../../plots/domain\":792,\"../bar/defaults\":861,\"./attributes\":992}],996:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"funnelarea\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"funnelarea\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\"),styleOne:t(\"../pie/style_one\"),meta:{}}},{\"../pie/style_one\":1097,\"./attributes\":992,\"./base_plot\":993,\"./calc\":994,\"./defaults\":995,\"./layout_attributes\":997,\"./layout_defaults\":998,\"./plot\":999,\"./style\":1e3}],997:[function(t,e,r){\"use strict\";var n=t(\"../pie/layout_attributes\").hiddenlabels;e.exports={hiddenlabels:n,funnelareacolorway:{valType:\"colorlist\",editType:\"calc\"},extendfunnelareacolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{\"../pie/layout_attributes\":1093}],998:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"funnelareacolorway\",e.colorway),r(\"extendfunnelareacolors\")}},{\"../../lib\":719,\"./layout_attributes\":997}],999:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../lib\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../bar/plot\"),l=s.getTransform,c=s.toMoveInsideBar,u=t(\"../pie/helpers\"),h=t(\"../pie/plot\"),f=h.attachFxHandlers,p=h.determineInsideTextFont,d=h.layoutAreas,g=h.prerenderTitles,v=h.positionTitleOutside;function m(t,e){return\"l\"+(e[0]-t[0])+\",\"+(e[1]-t[1])}e.exports=function(t,e){var r=t._fullLayout;g(e,t),d(e,r._size),a.makeTraceGroups(r._funnelarealayer,e,\"trace\").each(function(e){var s=n.select(this),h=e[0],d=h.trace;!function(t){if(!t.length)return;var e=t[0],r=e.trace,n=r.aspectratio,i=r.baseratio;i>.999&&(i=.999);var a,o=Math.pow(i,2),s=e.vTotal,l=s,c=s*o/(1-o)/s;function u(){var t,e={x:t=Math.sqrt(c),y:-t};return[e.x,e.y]}var h,f,p=[];for(p.push(u()),h=t.length-1;h>-1;h--)if(!(f=t[h]).hidden){var d=f.v/l;c+=d,p.push(u())}var g=1/0,v=-1/0;for(h=0;h<p.length;h++)a=p[h],g=Math.min(g,a[1]),v=Math.max(v,a[1]);for(h=0;h<p.length;h++)p[h][1]-=(v+g)/2;var m=p[p.length-1][0],y=e.r,x=(v-g)/2,b=y/m,_=y/x*n;for(e.r=_*x,h=0;h<p.length;h++)p[h][0]*=b,p[h][1]*=_;var w=[-(a=p[0])[0],a[1]],k=[a[0],a[1]],T=0;for(h=t.length-1;h>-1;h--)if(!(f=t[h]).hidden){var A=p[T+=1][0],M=p[T][1];f.TL=[-A,M],f.TR=[A,M],f.BL=w,f.BR=k,f.pxmid=(S=f.TR,E=f.BR,[.5*(S[0]+E[0]),.5*(S[1]+E[1])]),w=f.TL,k=f.TR}var S,E}(e),s.each(function(){var s=n.select(this).selectAll(\"g.slice\").data(e);s.enter().append(\"g\").classed(\"slice\",!0),s.exit().remove(),s.each(function(r){if(r.hidden)n.select(this).selectAll(\"path,g\").remove();else{r.pointNumber=r.i,r.curveNumber=d.index;var s=h.cx,g=h.cy,v=n.select(this),y=v.selectAll(\"path.surface\").data([r]);y.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),v.call(f,t,e);var x=\"M\"+(s+r.TR[0])+\",\"+(g+r.TR[1])+m(r.TR,r.BR)+m(r.BR,r.BL)+m(r.BL,r.TL)+\"Z\";y.attr(\"d\",x);var b=u.castOption(d.textposition,r.pts),_=v.selectAll(\"g.slicetext\").data(r.text&&\"none\"!==b?[0]:[]);_.enter().append(\"g\").classed(\"slicetext\",!0),_.exit().remove(),_.each(function(){var e=a.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)});e.text(r.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,p(d,r,t._fullLayout.font)).call(o.convertToTspans,t);var u,h,f,v=i.bBox(e.node()),m=Math.min(r.BL[1],r.BR[1]),y=Math.max(r.TL[1],r.TR[1]);h=Math.max(r.TL[0],r.BL[0]),f=Math.min(r.TR[0],r.BR[0]),u=l(c(h,f,m,y,v,{isHorizontal:!0,constrained:!0,angle:0,anchor:\"middle\"})),e.attr(\"transform\",\"translate(\"+s+\",\"+g+\")\"+u)})}});var g=n.select(this).selectAll(\"g.titletext\").data(d.title.text?[0]:[]);g.enter().append(\"g\").classed(\"titletext\",!0),g.exit().remove(),g.each(function(){var e=a.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),s=d.title.text;d._meta&&(s=a.templateString(s,d._meta)),e.text(s).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,d.title.font).call(o.convertToTspans,t);var l=v(h,r._size);e.attr(\"transform\",\"translate(\"+l.x+\",\"+l.y+\")\"+(l.scale<1?\"scale(\"+l.scale+\")\":\"\")+\"translate(\"+l.tx+\",\"+l.ty+\")\")})})})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../bar/plot\":867,\"../pie/helpers\":1091,\"../pie/plot\":1095,d3:163}],1000:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../pie/style_one\");e.exports=function(t){t._fullLayout._funnelarealayer.selectAll(\".trace\").each(function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each(function(t){n.select(this).call(i,t,e)})})}},{\"../pie/style_one\":1097,d3:163}],1001:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../components/colorscale/attributes\"),o=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../lib/extend\").extendFlat);e.exports=o({z:{valType:\"data_array\",editType:\"calc\"},x:o({},n.x,{impliedEdits:{xtype:\"array\"}}),x0:o({},n.x0,{impliedEdits:{xtype:\"scaled\"}}),dx:o({},n.dx,{impliedEdits:{xtype:\"scaled\"}}),y:o({},n.y,{impliedEdits:{ytype:\"array\"}}),y0:o({},n.y0,{impliedEdits:{ytype:\"scaled\"}}),dy:o({},n.dy,{impliedEdits:{ytype:\"scaled\"}}),text:{valType:\"data_array\",editType:\"calc\"},hovertext:{valType:\"data_array\",editType:\"calc\"},transpose:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xtype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},ytype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},zsmooth:{valType:\"enumerated\",values:[\"fast\",\"best\",!1],dflt:!1,editType:\"calc\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xgap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},ygap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},zhoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},hovertemplate:i()},{transforms:void 0},a(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../scatter/attributes\":1112}],1002:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../histogram2d/calc\"),s=t(\"../../components/colorscale/calc\"),l=t(\"./convert_column_xyz\"),c=t(\"./clean_2d_array\"),u=t(\"./interp2d\"),h=t(\"./find_empties\"),f=t(\"./make_bound_array\");e.exports=function(t,e){var r,p,d,g,v,m,y,x,b,_=a.getFromId(t,e.xaxis||\"x\"),w=a.getFromId(t,e.yaxis||\"y\"),k=n.traceIs(e,\"contour\"),T=n.traceIs(e,\"histogram\"),A=n.traceIs(e,\"gl2d\"),M=k?\"best\":e.zsmooth;if(_._minDtick=0,w._minDtick=0,T)r=(b=o(t,e)).x,p=b.x0,d=b.dx,g=b.y,v=b.y0,m=b.dy,y=b.z;else{var S=e.z;i.isArray1D(S)?(l(e,_,w,\"x\",\"y\",[\"z\"]),r=e._x,g=e._y,S=e._z):(r=e._x=e.x?_.makeCalcdata(e,\"x\"):[],g=e._y=e.y?w.makeCalcdata(e,\"y\"):[]),p=e.x0,d=e.dx,v=e.y0,m=e.dy,y=c(S,e,_,w),(k||e.connectgaps)&&(e._emptypoints=h(y),u(y,e._emptypoints))}function E(t){M=e._input.zsmooth=e.zsmooth=!1,i.warn('cannot use zsmooth: \"fast\": '+t)}if(\"fast\"===M)if(\"log\"===_.type||\"log\"===w.type)E(\"log axis found\");else if(!T){if(r.length){var C=(r[r.length-1]-r[0])/(r.length-1),L=Math.abs(C/100);for(x=0;x<r.length-1;x++)if(Math.abs(r[x+1]-r[x]-C)>L){E(\"x scale is not linear\");break}}if(g.length&&\"fast\"===M){var P=(g[g.length-1]-g[0])/(g.length-1),O=Math.abs(P/100);for(x=0;x<g.length-1;x++)if(Math.abs(g[x+1]-g[x]-P)>O){E(\"y scale is not linear\");break}}}var z=i.maxRowLength(y),I=\"scaled\"===e.xtype?\"\":r,D=f(e,I,p,d,z,_),R=\"scaled\"===e.ytype?\"\":g,F=f(e,R,v,m,y.length,w);A||(e._extremes[_._id]=a.findExtremes(_,D),e._extremes[w._id]=a.findExtremes(w,F));var B={x:D,y:F,z:y,text:e._text||e.text,hovertext:e._hovertext||e.hovertext};if(I&&I.length===D.length-1&&(B.xCenter=I),R&&R.length===F.length-1&&(B.yCenter=R),T&&(B.xRanges=b.xRanges,B.yRanges=b.yRanges,B.pts=b.pts),k||s(t,e,{vals:y,cLetter:\"z\"}),k&&e.contours&&\"heatmap\"===e.contours.coloring){var N={type:\"contour\"===e.type?\"heatmap\":\"histogram2d\",xcalendar:e.xcalendar,ycalendar:e.ycalendar};B.xfill=f(N,I,p,d,z,_),B.yfill=f(N,R,v,m,y.length,w)}return[B]}},{\"../../components/colorscale/calc\":601,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../histogram2d/calc\":1033,\"./clean_2d_array\":1003,\"./convert_column_xyz\":1005,\"./find_empties\":1007,\"./interp2d\":1010,\"./make_bound_array\":1011}],1003:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r,o){var s,l,c,u,h,f;function p(t){if(n(t))return+t}if(e&&e.transpose){for(s=0,h=0;h<t.length;h++)s=Math.max(s,t[h].length);if(0===s)return!1;c=function(t){return t.length},u=function(t,e,r){return(t[r]||[])[e]}}else s=t.length,c=function(t,e){return t[e].length},u=function(t,e,r){return(t[e]||[])[r]};var d=function(t,e,r){return e===a||r===a?a:u(t,e,r)};function g(t){if(e&&\"carpet\"!==e.type&&\"contourcarpet\"!==e.type&&t&&\"category\"===t.type&&e[\"_\"+t._id.charAt(0)].length){var r=t._id.charAt(0),n={},o=e[\"_\"+r+\"CategoryMap\"]||e[r];for(h=0;h<o.length;h++)n[o[h]]=h;return function(e){var r=n[t._categories[e]];return r+1?r:a}}return i.identity}var v=g(r),m=g(o);o&&\"category\"===o.type&&(s=o._categories.length);var y=new Array(s);for(h=0;h<s;h++)for(l=r&&\"category\"===r.type?r._categories.length:c(t,h),y[h]=new Array(l),f=0;f<l;f++)y[h][f]=p(d(t,m(h),v(f)));return y}},{\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],1004:[function(t,e,r){\"use strict\";e.exports={min:\"zmin\",max:\"zmax\"}},{}],1005:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r,a,o,s){var l,c,u,h,f=t._length,p=e.makeCalcdata(t,a),d=r.makeCalcdata(t,o),g=t.text,v=void 0!==g&&n.isArray1D(g),m=t.hovertext,y=void 0!==m&&n.isArray1D(m),x=n.distinctVals(p),b=x.vals,_=n.distinctVals(d),w=_.vals,k=[];for(l=0;l<s.length;l++)k[l]=n.init2dArray(w.length,b.length);for(v&&(u=n.init2dArray(w.length,b.length)),y&&(h=n.init2dArray(w.length,b.length)),l=0;l<f;l++)if(p[l]!==i&&d[l]!==i){var T=n.findBin(p[l]+x.minDiff/2,b),A=n.findBin(d[l]+_.minDiff/2,w);for(c=0;c<s.length;c++){var M=t[s[c]];k[c][A][T]=M[l]}v&&(u[A][T]=g[l]),y&&(h[A][T]=m[l])}for(t[\"_\"+a]=b,t[\"_\"+o]=w,c=0;c<s.length;c++)t[\"_\"+s[c]]=k[c];v&&(t._text=u),y&&(t._hovertext=h),e&&\"category\"===e.type&&(t[\"_\"+a+\"CategoryMap\"]=b.map(function(t){return e._categories[t]})),r&&\"category\"===r.type&&(t[\"_\"+o+\"CategoryMap\"]=w.map(function(t){return r._categories[t]}))}},{\"../../constants/numerical\":695,\"../../lib\":719}],1006:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xyz_defaults\"),a=t(\"./style_defaults\"),o=t(\"../../components/colorscale/defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l)?(c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\"),a(t,e,c,l),c(\"connectgaps\",n.isArray1D(e.z)&&!1!==e.zsmooth),o(t,e,l,c,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":1001,\"./style_defaults\":1014,\"./xyz_defaults\":1015}],1007:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").maxRowLength;e.exports=function(t){var e,r,i,a,o,s,l,c,u=[],h={},f=[],p=t[0],d=[],g=[0,0,0],v=n(t);for(r=0;r<t.length;r++)for(e=d,d=p,p=t[r+1]||[],i=0;i<v;i++)void 0===d[i]&&((s=(void 0!==d[i-1]?1:0)+(void 0!==d[i+1]?1:0)+(void 0!==e[i]?1:0)+(void 0!==p[i]?1:0))?(0===r&&s++,0===i&&s++,r===t.length-1&&s++,i===d.length-1&&s++,s<4&&(h[[r,i]]=[r,i,s]),u.push([r,i,s])):f.push([r,i]));for(;f.length;){for(l={},c=!1,o=f.length-1;o>=0;o--)(s=((h[[(r=(a=f[o])[0])-1,i=a[1]]]||g)[2]+(h[[r+1,i]]||g)[2]+(h[[r,i-1]]||g)[2]+(h[[r,i+1]]||g)[2])/20)&&(l[a]=[r,i,s],f.splice(o,1),c=!0);if(!c)throw\"findEmpties iterated with no new neighbors\";for(a in l)h[a]=l[a],u.push(l[a])}return u.sort(function(t,e){return e[2]-t[2]})}},{\"../../lib\":719}],1008:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../components/colorscale\").extractOpts;e.exports=function(t,e,r,s,l,c){var u,h,f,p,d=t.cd[0],g=d.trace,v=t.xa,m=t.ya,y=d.x,x=d.y,b=d.z,_=d.xCenter,w=d.yCenter,k=d.zmask,T=g.zhoverformat,A=y,M=x;if(!1!==t.index){try{f=Math.round(t.index[1]),p=Math.round(t.index[0])}catch(e){return void i.error(\"Error hovering on heatmap, pointNumber must be [row,col], found:\",t.index)}if(f<0||f>=b[0].length||p<0||p>b.length)return}else{if(n.inbox(e-y[0],e-y[y.length-1],0)>0||n.inbox(r-x[0],r-x[x.length-1],0)>0)return;if(c){var S;for(A=[2*y[0]-y[1]],S=1;S<y.length;S++)A.push((y[S]+y[S-1])/2);for(A.push([2*y[y.length-1]-y[y.length-2]]),M=[2*x[0]-x[1]],S=1;S<x.length;S++)M.push((x[S]+x[S-1])/2);M.push([2*x[x.length-1]-x[x.length-2]])}f=Math.max(0,Math.min(A.length-2,i.findBin(e,A))),p=Math.max(0,Math.min(M.length-2,i.findBin(r,M)))}var E=v.c2p(y[f]),C=v.c2p(y[f+1]),L=m.c2p(x[p]),P=m.c2p(x[p+1]);c?(C=E,u=y[f],P=L,h=x[p]):(u=_?_[f]:(y[f]+y[f+1])/2,h=w?w[p]:(x[p]+x[p+1])/2,v&&\"category\"===v.type&&(u=y[f]),m&&\"category\"===m.type&&(h=x[p]),g.zsmooth&&(E=C=v.c2p(u),L=P=m.c2p(h)));var O,z=b[p][f];k&&!k[p][f]&&(z=void 0),Array.isArray(d.hovertext)&&Array.isArray(d.hovertext[p])?O=d.hovertext[p][f]:Array.isArray(d.text)&&Array.isArray(d.text[p])&&(O=d.text[p][f]);var I=o(g),D={type:\"linear\",range:[I.min,I.max],hoverformat:T,_separators:v._separators,_numFormat:v._numFormat},R=a.tickText(D,z,\"hover\").text;return[i.extendFlat(t,{index:[p,f],distance:t.maxHoverDistance,spikeDistance:t.maxSpikeDistance,x0:E,x1:C,y0:L,y1:P,xLabelVal:u,yLabelVal:h,zLabelVal:z,zLabel:R,text:O})]}},{\"../../components/colorscale\":605,\"../../components/fx\":632,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],1009:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:t(\"./colorbar\"),style:t(\"./style\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"heatmap\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":1001,\"./calc\":1002,\"./colorbar\":1004,\"./defaults\":1006,\"./hover\":1008,\"./plot\":1012,\"./style\":1013}],1010:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[-1,0],[1,0],[0,-1],[0,1]];function a(t){return.5-.25*Math.min(1,.5*t)}function o(t,e,r){var n,a,o,s,l,c,u,h,f,p,d,g,v,m=0;for(s=0;s<e.length;s++){for(a=(n=e[s])[0],o=n[1],d=t[a][o],p=0,f=0,l=0;l<4;l++)(u=t[a+(c=i[l])[0]])&&void 0!==(h=u[o+c[1]])&&(0===p?g=v=h:(g=Math.min(g,h),v=Math.max(v,h)),f++,p+=h);if(0===f)throw\"iterateInterp2d order is wrong: no defined neighbors\";t[a][o]=p/f,void 0===d?f<4&&(m=1):(t[a][o]=(1+r)*t[a][o]-r*d,v>g&&(m=Math.max(m,Math.abs(t[a][o]-d)/(v-g))))}return m}e.exports=function(t,e){var r,i=1;for(o(t,e),r=0;r<e.length&&!(e[r][2]<4);r++);for(e=e.slice(r),r=0;r<100&&i>.01;r++)i=o(t,e,a(i));return i>.01&&n.log(\"interp2d didn't converge quickly\",i),t}},{\"../../lib\":719}],1011:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a,o,s){var l,c,u,h=[],f=n.traceIs(t,\"contour\"),p=n.traceIs(t,\"histogram\"),d=n.traceIs(t,\"gl2d\");if(i(e)&&e.length>1&&!p&&\"category\"!==s.type){var g=e.length;if(!(g<=o))return f?e.slice(0,o):e.slice(0,o+1);if(f||d)h=e.slice(0,o);else if(1===o)h=[e[0]-.5,e[0]+.5];else{for(h=[1.5*e[0]-.5*e[1]],u=1;u<g;u++)h.push(.5*(e[u-1]+e[u]));h.push(1.5*e[g-1]-.5*e[g-2])}if(g<o){var v=h[h.length-1],m=v-h[h.length-2];for(u=g;u<o;u++)v+=m,h.push(v)}}else{var y=t[s._id.charAt(0)+\"calendar\"];if(p)l=s.r2c(r,0,y);else if(i(e)&&1===e.length)l=e[0];else if(void 0===r)l=0;else{l=(\"log\"===s.type?s.d2c:s.r2c)(r,0,y)}for(c=a||1,u=f||d?0:-.5;u<o;u++)h.push(l+c*u)}return h}},{\"../../lib\":719,\"../../registry\":847}],1012:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/colorscale\").makeColorScaleFuncFromTrace,l=t(\"../../constants/xmlns_namespaces\");function c(t,e){var r=e.length-2,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=e[n+1],s=o.constrain(n+(t-i)/(a-i)-.5,0,r),l=Math.round(s),c=Math.abs(s-l);return s&&s!==r&&c?{bin0:l,frac:c,bin1:Math.round(l+c/(s-l))}:{bin0:l,bin1:l,frac:0}}function u(t,e){var r=e.length-1,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=(t-i)/(e[n+1]-i)||0;return a<=0?{bin0:n,bin1:n,frac:0}:a<.5?{bin0:n,bin1:n+1,frac:a}:{bin0:n+1,bin1:n,frac:1-a}}function h(t,e,r){t[e]=r[0],t[e+1]=r[1],t[e+2]=r[2],t[e+3]=Math.round(255*r[3])}e.exports=function(t,e,r,f){var p=e.xaxis,d=e.yaxis;o.makeTraceGroups(f,r,\"hm\").each(function(e){var r,f,g,v,m,y,x=n.select(this),b=e[0],_=b.trace,w=b.z,k=b.x,T=b.y,A=b.xCenter,M=b.yCenter,S=a.traceIs(_,\"contour\"),E=S?\"best\":_.zsmooth,C=w.length,L=o.maxRowLength(w),P=!1,O=!1;for(y=0;void 0===r&&y<k.length-1;)r=p.c2p(k[y]),y++;for(y=k.length-1;void 0===f&&y>0;)f=p.c2p(k[y]),y--;for(f<r&&(g=f,f=r,r=g,P=!0),y=0;void 0===v&&y<T.length-1;)v=d.c2p(T[y]),y++;for(y=T.length-1;void 0===m&&y>0;)m=d.c2p(T[y]),y--;if(m<v&&(g=v,v=m,m=g,O=!0),S&&(A=k,M=T,k=b.xfill,T=b.yfill),\"fast\"!==E){var z=\"best\"===E?0:.5;r=Math.max(-z*p._length,r),f=Math.min((1+z)*p._length,f),v=Math.max(-z*d._length,v),m=Math.min((1+z)*d._length,m)}var I=Math.round(f-r),D=Math.round(m-v);if(I<=0||D<=0){x.selectAll(\"image\").data([]).exit().remove()}else{var R,F;\"fast\"===E?(R=L,F=C):(R=I,F=D);var B=document.createElement(\"canvas\");B.width=R,B.height=F;var N,j,U=B.getContext(\"2d\"),V=s(_,{noNumericCheck:!0,returnArray:!0});\"fast\"===E?(N=P?function(t){return L-1-t}:o.identity,j=O?function(t){return C-1-t}:o.identity):(N=function(t){return o.constrain(Math.round(p.c2p(k[t])-r),0,I)},j=function(t){return o.constrain(Math.round(d.c2p(T[t])-v),0,D)});var q,H,G,Y,W,X=j(0),Z=[X,X],J=P?0:1,K=O?0:1,$=0,Q=0,tt=0,et=0;if(E){var rt,nt=0;try{rt=new Uint8Array(I*D*4)}catch(t){rt=new Array(I*D*4)}if(\"best\"===E){var it,at,ot,st=A||k,lt=M||T,ct=new Array(st.length),ut=new Array(lt.length),ht=new Array(I),ft=A?u:c,pt=M?u:c;for(y=0;y<st.length;y++)ct[y]=Math.round(p.c2p(st[y])-r);for(y=0;y<lt.length;y++)ut[y]=Math.round(d.c2p(lt[y])-v);for(y=0;y<I;y++)ht[y]=ft(y,ct);for(H=0;H<D;H++)for(at=w[(it=pt(H,ut)).bin0],ot=w[it.bin1],y=0;y<I;y++,nt+=4)h(rt,nt,W=Tt(at,ot,ht[y],it))}else for(H=0;H<C;H++)for(Y=w[H],Z=j(H),y=0;y<I;y++)W=kt(Y[y],1),h(rt,nt=4*(Z*I+N(y)),W);var dt=U.createImageData(I,D);try{dt.data.set(rt)}catch(t){var gt=dt.data,vt=gt.length;for(H=0;H<vt;H++)gt[H]=rt[H]}U.putImageData(dt,0,0)}else{var mt=_.xgap,yt=_.ygap,xt=Math.floor(mt/2),bt=Math.floor(yt/2);for(H=0;H<C;H++)if(Y=w[H],Z.reverse(),Z[K]=j(H+1),Z[0]!==Z[1]&&void 0!==Z[0]&&void 0!==Z[1])for(q=[G=N(0),G],y=0;y<L;y++)q.reverse(),q[J]=N(y+1),q[0]!==q[1]&&void 0!==q[0]&&void 0!==q[1]&&(W=kt(Y[y],(q[1]-q[0])*(Z[1]-Z[0])),U.fillStyle=\"rgba(\"+W.join(\",\")+\")\",U.fillRect(q[0]+xt,Z[0]+bt,q[1]-q[0]-mt,Z[1]-Z[0]-yt))}Q=Math.round(Q/$),tt=Math.round(tt/$),et=Math.round(et/$);var _t=i(\"rgb(\"+Q+\",\"+tt+\",\"+et+\")\");t._hmpixcount=(t._hmpixcount||0)+$,t._hmlumcount=(t._hmlumcount||0)+$*_t.getLuminance();var wt=x.selectAll(\"image\").data(e);wt.enter().append(\"svg:image\").attr({xmlns:l.svg,preserveAspectRatio:\"none\"}),wt.attr({height:D,width:I,x:r,y:v,\"xlink:href\":B.toDataURL(\"image/png\")})}function kt(t,e){if(void 0!==t){var r=V(t);return r[0]=Math.round(r[0]),r[1]=Math.round(r[1]),r[2]=Math.round(r[2]),$+=e,Q+=r[0]*e,tt+=r[1]*e,et+=r[2]*e,r}return[0,0,0,0]}function Tt(t,e,r,n){var i=t[r.bin0];if(void 0===i)return kt(void 0,1);var a,o=t[r.bin1],s=e[r.bin0],l=e[r.bin1],c=o-i||0,u=s-i||0;return a=void 0===o?void 0===l?0:void 0===s?2*(l-i):2*(2*l-s-i)/3:void 0===l?void 0===s?0:2*(2*i-o-s)/3:void 0===s?2*(2*l-o-i)/3:l+i-o-s,kt(i+r.frac*c+n.frac*(u+r.frac*a))}})}},{\"../../components/colorscale\":605,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../registry\":847,d3:163,tinycolor2:537}],1013:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t){n.select(t).selectAll(\".hm image\").style(\"opacity\",function(t){return t.trace.opacity})}},{d3:163}],1014:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){!1===r(\"zsmooth\")&&(r(\"xgap\"),r(\"ygap\")),r(\"zhoverformat\")}},{}],1015:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\");function o(t,e){var r=e(t);return\"scaled\"===(r?e(t+\"type\",\"array\"):\"scaled\")&&(e(t+\"0\"),e(\"d\"+t)),r}e.exports=function(t,e,r,s,l,c){var u,h,f=r(\"z\");if(l=l||\"x\",c=c||\"y\",void 0===f||!f.length)return 0;if(i.isArray1D(t.z)){u=r(l),h=r(c);var p=i.minRowLength(u),d=i.minRowLength(h);if(0===p||0===d)return 0;e._length=Math.min(p,d,f.length)}else{if(u=o(l,r),h=o(c,r),!function(t){for(var e,r=!0,a=!1,o=!1,s=0;s<t.length;s++){if(e=t[s],!i.isArrayOrTypedArray(e)){r=!1;break}e.length>0&&(a=!0);for(var l=0;l<e.length;l++)if(n(e[l])){o=!0;break}}return r&&a&&o}(f))return 0;r(\"transpose\"),e._length=null}return a.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[l,c],s),!0}},{\"../../lib\":719,\"../../registry\":847,\"fast-isnumeric\":225}],1016:[function(t,e,r){\"use strict\";for(var n=t(\"../heatmap/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=[\"z\",\"x\",\"x0\",\"dx\",\"y\",\"y0\",\"dy\",\"text\",\"transpose\",\"xtype\",\"ytype\"],l={},c=0;c<s.length;c++){var u=s[c];l[u]=n[u]}a(l,i(\"\",{cLetter:\"z\",autoColorDflt:!1})),e.exports=o(l,\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../heatmap/attributes\":1001}],1017:[function(t,e,r){\"use strict\";var n=t(\"gl-heatmap2d\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib/str2rgbarray\");function o(t,e){this.scene=t,this.uid=e,this.type=\"heatmapgl\",this.name=\"\",this.hoverinfo=\"all\",this.xData=[],this.yData=[],this.zData=[],this.textLabels=[],this.idToIndex=[],this.bounds=[0,0,0,0],this.options={z:[],x:[],y:[],shape:[0,0],colorLevels:[0],colorValues:[0,0,0,1]},this.heatmap=n(t.glplot,this.options),this.heatmap._trace=this}var s=o.prototype;s.handlePick=function(t){var e=this.options,r=e.shape,n=t.pointId,i=n%r[0],a=Math.floor(n/r[0]),o=n;return{trace:this,dataCoord:t.dataCoord,traceCoord:[e.x[i],e.y[a],e.z[o]],textLabel:this.textLabels[n],name:this.name,pointIndex:[a,i],hoverinfo:this.hoverinfo}},s.update=function(t,e){var r=e[0];this.index=t.index,this.name=t.name,this.hoverinfo=t.hoverinfo;var n=r.z;this.options.z=[].concat.apply([],n);var o=n[0].length,s=n.length;this.options.shape=[o,s],this.options.x=r.x,this.options.y=r.y;var l=function(t){for(var e=t.colorscale,r=t.zmin,n=t.zmax,i=e.length,o=new Array(i),s=new Array(4*i),l=0;l<i;l++){var c=e[l],u=a(c[1]);o[l]=r+c[0]*(n-r);for(var h=0;h<4;h++)s[4*l+h]=u[h]}return{colorLevels:o,colorValues:s}}(t);this.options.colorLevels=l.colorLevels,this.options.colorValues=l.colorValues,this.textLabels=[].concat.apply([],t.text),this.heatmap.update(this.options);var c=this.scene.xaxis,u=this.scene.yaxis;t._extremes[c._id]=i.findExtremes(c,r.x),t._extremes[u._id]=i.findExtremes(u,r.y)},s.dispose=function(){this.heatmap.dispose()},e.exports=function(t,e,r){var n=new o(t,e.uid);return n.update(e,r),n}},{\"../../lib/str2rgbarray\":742,\"../../plots/cartesian/axes\":767,\"gl-heatmap2d\":251}],1018:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"../heatmap/defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../heatmap/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"heatmapgl\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"2dMap\"],meta:{}}},{\"../../plots/gl2d\":805,\"../heatmap/calc\":1002,\"../heatmap/colorbar\":1004,\"../heatmap/defaults\":1006,\"./attributes\":1016,\"./convert\":1017}],1019:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"./bin_attributes\"),o=t(\"./constants\"),s=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),orientation:n.orientation,histfunc:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"min\",\"max\"],dflt:\"count\",editType:\"calc\"},histnorm:{valType:\"enumerated\",values:[\"\",\"percent\",\"probability\",\"density\",\"probability density\"],dflt:\"\",editType:\"calc\"},cumulative:{enabled:{valType:\"boolean\",dflt:!1,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"increasing\",\"decreasing\"],dflt:\"increasing\",editType:\"calc\"},currentbin:{valType:\"enumerated\",values:[\"include\",\"exclude\",\"half\"],dflt:\"include\",editType:\"calc\"},editType:\"calc\"},nbinsx:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},xbins:a(\"x\",!0),nbinsy:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},ybins:a(\"y\",!0),autobinx:{valType:\"boolean\",dflt:null,editType:\"calc\"},autobiny:{valType:\"boolean\",dflt:null,editType:\"calc\"},bingroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:i({},{keys:o.eventDataKeys}),marker:n.marker,offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,_deprecated:{bardir:n._deprecated.bardir}}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../bar/attributes\":857,\"./bin_attributes\":1021,\"./constants\":1025}],1020:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=t.length,n=0,i=0;i<r;i++)e[i]?(t[i]/=e[i],n+=t[i]):t[i]=null;return n}},{}],1021:[function(t,e,r){\"use strict\";e.exports=function(t,e){return{start:{valType:\"any\",editType:\"calc\"},end:{valType:\"any\",editType:\"calc\"},size:{valType:\"any\",editType:\"calc\"},editType:\"calc\"}}},{}],1022:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports={count:function(t,e,r){return r[t]++,1},sum:function(t,e,r,i){var a=i[e];return n(a)?(a=Number(a),r[t]+=a,a):0},avg:function(t,e,r,i,a){var o=i[e];return n(o)&&(o=Number(o),r[t]+=o,a[t]++),0},min:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]>a){var o=a-r[t];return r[t]=a,o}}return 0},max:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]<a){var o=a-r[t];return r[t]=a,o}}return 0}}},{\"fast-isnumeric\":225}],1023:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.ONEAVGYEAR,a=n.ONEAVGMONTH,o=n.ONEDAY,s=n.ONEHOUR,l=n.ONEMIN,c=n.ONESEC,u=t(\"../../plots/cartesian/axes\").tickIncrement;function h(t,e,r,n){if(t*e<=0)return 1/0;for(var i=Math.abs(e-t),a=\"date\"===r.type,o=f(i,a),s=0;s<10;s++){var l=f(80*o,a);if(o===l)break;if(!p(l,t,e,a,r,n))break;o=l}return o}function f(t,e){return e&&t>c?t>o?t>1.1*i?i:t>1.1*a?a:o:t>s?s:t>l?l:c:Math.pow(10,Math.floor(Math.log(t)/Math.LN10))}function p(t,e,r,n,a,s){if(n&&t>o){var l=d(e,a,s),c=d(r,a,s),u=t===i?0:1;return l[u]!==c[u]}return Math.floor(r/t)-Math.floor(e/t)>.1}function d(t,e,r){var n=e.c2d(t,i,r).split(\"-\");return\"\"===n[0]&&(n.unshift(),n[0]=\"-\"+n[0]),n}e.exports=function(t,e,r,n,a){var s,l,c=-1.1*e,f=-.1*e,p=t-f,d=r[0],g=r[1],v=Math.min(h(d+f,d+p,n,a),h(g+f,g+p,n,a)),m=Math.min(h(d+c,d+f,n,a),h(g+c,g+f,n,a));if(v>m&&m<Math.abs(g-d)/4e3?(s=v,l=!1):(s=Math.min(v,m),l=!0),\"date\"===n.type&&s>o){var y=s===i?1:6,x=s===i?\"M12\":\"M1\";return function(e,r){var o=n.c2d(e,i,a),s=o.indexOf(\"-\",y);s>0&&(o=o.substr(0,s));var c=n.d2c(o,0,a);if(c<e){var h=u(c,x,!1,a);(c+h)/2<e+t&&(c=h)}return r&&l?u(c,x,!0,a):c}}return function(e,r){var n=s*Math.round(e/s);return n+s/10<e&&n+.9*s<e+t&&(n+=s),r&&l&&(n-=s),n}}},{\"../../constants/numerical\":695,\"../../plots/cartesian/axes\":767}],1024:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../bar/arrays_to_calcdata\"),l=t(\"./bin_functions\"),c=t(\"./norm_functions\"),u=t(\"./average\"),h=t(\"./bin_label_vals\");function f(t,e,r,s,l){var c,u,h,p,d,g,v,m=s+\"bins\",y=t._fullLayout,x=e[\"_\"+s+\"bingroup\"],b=y._histogramBinOpts[x],_=\"overlay\"===y.barmode,w=function(t){return r.r2c(t,0,p)},k=function(t){return r.c2r(t,0,p)},T=\"date\"===r.type?function(t){return t||0===t?i.cleanDate(t,null,p):null}:function(t){return n(t)?Number(t):null};function A(t,e,r){e[t+\"Found\"]?(e[t]=T(e[t]),null===e[t]&&(e[t]=r[t])):(g[t]=e[t]=r[t],i.nestedProperty(u[0],m+\".\"+t).set(r[t]))}if(e[\"_\"+s+\"autoBinFinished\"])delete e[\"_\"+s+\"autoBinFinished\"];else{u=b.traces;var M=[],S=!0,E=!1,C=!1;for(c=0;c<u.length;c++)if((h=u[c]).visible){var L=b.dirs[c];d=h[\"_\"+L+\"pos0\"]=r.makeCalcdata(h,L),M=i.concat(M,d),delete h[\"_\"+s+\"autoBinFinished\"],!0===e.visible&&(S?S=!1:(delete h._autoBin,h[\"_\"+s+\"autoBinFinished\"]=1),a.traceIs(h,\"2dMap\")&&(E=!0),\"histogram2dcontour\"===h.type&&(C=!0))}p=u[0][s+\"calendar\"];var P=o.autoBin(M,r,b.nbins,E,p,b.sizeFound&&b.size),O=u[0]._autoBin={};if(g=O[b.dirs[0]]={},C&&(b.size||(P.start=k(o.tickIncrement(w(P.start),P.size,!0,p))),void 0===b.end&&(P.end=k(o.tickIncrement(w(P.end),P.size,!1,p)))),_&&!a.traceIs(e,\"2dMap\")&&0===P._dataSpan&&\"category\"!==r.type&&\"multicategory\"!==r.type){if(l)return[P,d,!0];P=function(t,e,r,n,a){var o,s,l,c=t._fullLayout,u=function(t,e){for(var r=e.xaxis,n=e.yaxis,i=e.orientation,a=[],o=t._fullData,s=0;s<o.length;s++){var l=o[s];\"histogram\"===l.type&&!0===l.visible&&l.orientation===i&&l.xaxis===r&&l.yaxis===n&&a.push(l)}return a}(t,e),h=!1,p=1/0,d=[e];for(o=0;o<u.length;o++)if((s=u[o])===e)h=!0;else if(h){var g=f(t,s,r,n,!0),v=g[0],m=g[2];s[\"_\"+n+\"autoBinFinished\"]=1,s[\"_\"+n+\"pos0\"]=g[1],m?d.push(s):p=Math.min(p,v.size)}else l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]],p=Math.min(p,l.size||s[a].size);var y=new Array(d.length);for(o=0;o<d.length;o++)for(var x=d[o][\"_\"+n+\"pos0\"],b=0;b<x.length;b++)if(void 0!==x[b]){y[o]=x[b];break}isFinite(p)||(p=i.distinctVals(y).minDiff);for(o=0;o<d.length;o++){var _=(s=d[o])[n+\"calendar\"],w={start:r.c2r(y[o]-p/2,0,_),end:r.c2r(y[o]+p/2,0,_),size:p};s._input[a]=s[a]=w,(l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]])&&i.extendFlat(l,w)}return e[a]}(t,e,r,s,m)}(v=h.cumulative||{}).enabled&&\"include\"!==v.currentbin&&(\"decreasing\"===v.direction?P.start=k(o.tickIncrement(w(P.start),P.size,!0,p)):P.end=k(o.tickIncrement(w(P.end),P.size,!1,p))),b.size=P.size,b.sizeFound||(g.size=P.size,i.nestedProperty(u[0],m+\".size\").set(P.size)),A(\"start\",b,P),A(\"end\",b,P)}d=e[\"_\"+s+\"pos0\"],delete e[\"_\"+s+\"pos0\"];var z=e._input[m]||{},I=i.extendFlat({},b),D=b.start,R=r.r2l(z.start),F=void 0!==R;if((b.startFound||F)&&R!==r.r2l(D)){var B=F?R:i.aggNums(Math.min,null,d),N={type:\"category\"===r.type||\"multicategory\"===r.type?\"linear\":r.type,r2l:r.r2l,dtick:b.size,tick0:D,calendar:p,range:[B,o.tickIncrement(B,b.size,!1,p)].map(r.l2r)},j=o.tickFirst(N);j>r.r2l(B)&&(j=o.tickIncrement(j,b.size,!0,p)),I.start=r.l2r(j),F||i.nestedProperty(e,m+\".start\").set(I.start)}var U=b.end,V=r.r2l(z.end),q=void 0!==V;if((b.endFound||q)&&V!==r.r2l(U)){var H=q?V:i.aggNums(Math.max,null,d);I.end=r.l2r(H),q||i.nestedProperty(e,m+\".start\").set(I.end)}var G=\"autobin\"+s;return!1===e._input[G]&&(e._input[m]=i.extendFlat({},e[m]||{}),delete e._input[G],delete e[G]),[I,d]}e.exports={calc:function(t,e){var r,a,p,d,g=[],v=[],m=o.getFromId(t,\"h\"===e.orientation?e.yaxis:e.xaxis),y=\"h\"===e.orientation?\"y\":\"x\",x={x:\"y\",y:\"x\"}[y],b=e[y+\"calendar\"],_=e.cumulative,w=f(t,e,m,y),k=w[0],T=w[1],A=\"string\"==typeof k.size,M=[],S=A?M:k,E=[],C=[],L=[],P=0,O=e.histnorm,z=e.histfunc,I=-1!==O.indexOf(\"density\");_.enabled&&I&&(O=O.replace(/ ?density$/,\"\"),I=!1);var D,R=\"max\"===z||\"min\"===z?null:0,F=l.count,B=c[O],N=!1,j=function(t){return m.r2c(t,0,b)};for(i.isArrayOrTypedArray(e[x])&&\"count\"!==z&&(D=e[x],N=\"avg\"===z,F=l[z]),r=j(k.start),p=j(k.end)+(r-o.tickIncrement(r,k.size,!1,b))/1e6;r<p&&g.length<1e6&&(a=o.tickIncrement(r,k.size,!1,b),g.push((r+a)/2),v.push(R),L.push([]),M.push(r),I&&E.push(1/(a-r)),N&&C.push(0),!(a<=r));)r=a;M.push(r),A||\"date\"!==m.type||(S={start:j(S.start),end:j(S.end),size:S.size});var U,V=v.length,q=!0,H=1/0,G=1/0,Y={};for(r=0;r<T.length;r++){var W=T[r];(d=i.findBin(W,S))>=0&&d<V&&(P+=F(d,r,v,D,C),q&&L[d].length&&W!==T[L[d][0]]&&(q=!1),L[d].push(r),Y[r]=d,H=Math.min(H,W-M[d]),G=Math.min(G,M[d+1]-W))}q||(U=h(H,G,M,m,b)),N&&(P=u(v,C)),B&&B(v,P,E),_.enabled&&function(t,e,r){var n,i,a;function o(e){a=t[e],t[e]/=2}function s(e){i=t[e],t[e]=a+i/2,a+=i}if(\"half\"===r)if(\"increasing\"===e)for(o(0),n=1;n<t.length;n++)s(n);else for(o(t.length-1),n=t.length-2;n>=0;n--)s(n);else if(\"increasing\"===e){for(n=1;n<t.length;n++)t[n]+=t[n-1];\"exclude\"===r&&(t.unshift(0),t.pop())}else{for(n=t.length-2;n>=0;n--)t[n]+=t[n+1];\"exclude\"===r&&(t.push(0),t.shift())}}(v,_.direction,_.currentbin);var X=Math.min(g.length,v.length),Z=[],J=0,K=X-1;for(r=0;r<X;r++)if(v[r]){J=r;break}for(r=X-1;r>=J;r--)if(v[r]){K=r;break}for(r=J;r<=K;r++)if(n(g[r])&&n(v[r])){var $={p:g[r],s:v[r],b:0};_.enabled||($.pts=L[r],q?$.ph0=$.ph1=L[r].length?T[L[r][0]]:g[r]:($.ph0=U(M[r]),$.ph1=U(M[r+1],!0))),Z.push($)}return 1===Z.length&&(Z[0].width1=o.tickIncrement(Z[0].p,k.size,!1,b)-Z[0].p),s(Z,e),i.isArrayOrTypedArray(e.selectedpoints)&&i.tagSelected(Z,e,Y),Z},calcAllAutoBins:f}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../bar/arrays_to_calcdata\":856,\"./average\":1020,\"./bin_functions\":1022,\"./bin_label_vals\":1023,\"./norm_functions\":1031,\"fast-isnumeric\":225}],1025:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"binNumber\"]}},{}],1026:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../../registry\").traceIs,o=t(\"../bar/defaults\").handleGroupingDefaults,s=n.nestedProperty,l=i.getAxisGroup,c=[{aStr:{x:\"xbins.start\",y:\"ybins.start\"},name:\"start\"},{aStr:{x:\"xbins.end\",y:\"ybins.end\"},name:\"end\"},{aStr:{x:\"xbins.size\",y:\"ybins.size\"},name:\"size\"},{aStr:{x:\"nbinsx\",y:\"nbinsy\"},name:\"nbins\"}],u=[\"x\",\"y\"];e.exports=function(t,e){var r,h,f,p,d,g,v,m=e._histogramBinOpts={},y=[],x={},b=[];function _(t,e){return n.coerce(r._input,r,r._module.attributes,t,e)}function w(t){return\"v\"===t.orientation?\"x\":\"y\"}function k(t,r,a){var o=t.uid+\"__\"+a;r||(r=o);var s=function(t,r){return i.getFromTrace({_fullLayout:e},t,r).type}(t,a),l=t[a+\"calendar\"],c=m[r],u=!0;c&&(s===c.axType&&l===c.calendar?(u=!1,c.traces.push(t),c.dirs.push(a)):(r=o,s!==c.axType&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set on a\",\"type:\"+s,\"axis\",\"with bins on\",\"type:\"+c.axType,\"axis.\"].join(\" \")),l!==c.calendar&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set with a\",l,\"calendar\",\"with bins\",c.calendar?\"on a \"+c.calendar+\" calendar\":\"w/o a set calendar\"].join(\" \")))),u&&(m[r]={traces:[t],dirs:[a],axType:s,calendar:t[a+\"calendar\"]||\"\"}),t[\"_\"+a+\"bingroup\"]=r}for(d=0;d<t.length;d++)r=t[d],a(r,\"histogram\")&&(y.push(r),delete r._xautoBinFinished,delete r._yautoBinFinished,a(r,\"2dMap\")||o(r._input,r,e,_));var T=e._alignmentOpts||{};for(d=0;d<y.length;d++){if(r=y[d],f=\"\",!a(r,\"2dMap\")){if(p=w(r),\"group\"===e.barmode&&r.alignmentgroup){var A=r[p+\"axis\"],M=l(e,A)+r.orientation;(T[M]||{})[r.alignmentgroup]&&(f=M)}f||\"overlay\"===e.barmode||(f=l(e,r.xaxis)+l(e,r.yaxis)+w(r))}f?(x[f]||(x[f]=[]),x[f].push(r)):b.push(r)}for(f in x)if(1!==(h=x[f]).length){var S=!1;for(d=0;d<h.length;d++){r=h[d],S=_(\"bingroup\");break}for(f=S||f,d=0;d<h.length;d++){var E=(r=h[d])._input.bingroup;E&&E!==f&&n.warn([\"Trace\",r.index,\"must match\",\"within bingroup\",f+\".\",\"Ignoring its bingroup:\",E,\"setting.\"].join(\" \")),r.bingroup=f,k(r,f,w(r))}}else b.push(h[0]);for(d=0;d<b.length;d++){r=b[d];var C=_(\"bingroup\");if(a(r,\"2dMap\"))for(v=0;v<2;v++){var L=_((p=u[v])+\"bingroup\",C?C+\"__\"+p:null);k(r,L,p)}else k(r,C,w(r))}for(f in m){var P=m[f];for(h=P.traces,g=0;g<c.length;g++){var O,z,I=c[g],D=I.name;if(\"nbins\"!==D||!P.sizeFound){for(d=0;d<h.length;d++){if(r=h[d],p=P.dirs[d],O=I.aStr[p],void 0!==s(r._input,O).get()){P[D]=_(O),P[D+\"Found\"]=!0;break}(z=(r._autoBin||{})[p]||{})[D]&&s(r,O).set(z[D])}if(\"start\"===D||\"end\"===D)for(;d<h.length;d++)(r=h[d])[\"_\"+p+\"bingroup\"]&&_(O,(z=(r._autoBin||{})[p]||{})[D]);\"nbins\"!==D||P.sizeFound||P.nbinsFound||(r=h[0],P[D]=_(O))}}}}},{\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../bar/defaults\":861}],1027:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../bar/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,n){return i.coerce(t,e,s,r,n)}var u=c(\"x\"),h=c(\"y\");c(\"cumulative.enabled\")&&(c(\"cumulative.direction\"),c(\"cumulative.currentbin\")),c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\");var f=c(\"orientation\",h&&!u?\"h\":\"v\"),p=\"v\"===f?\"x\":\"y\",d=\"v\"===f?\"y\":\"x\",g=u&&h?Math.min(i.minRowLength(u)&&i.minRowLength(h)):i.minRowLength(e[p]||[]);if(g){e._length=g,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],l),e[d]&&c(\"histfunc\"),c(\"histnorm\"),c(\"autobin\"+p),o(t,e,c,r,l),i.coerceSelectionMarkerOpacity(e,c);var v=(e.marker.line||{}).color,m=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");m(t,e,v||a.defaultLine,{axis:\"y\"}),m(t,e,v||a.defaultLine,{axis:\"x\",inherit:\"y\"})}else e.visible=!1}},{\"../../components/color\":593,\"../../lib\":719,\"../../registry\":847,\"../bar/style_defaults\":871,\"./attributes\":1019}],1028:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"zLabelVal\"in e&&(t.z=e.zLabelVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),!(r.cumulative||{}).enabled){var a,o=Array.isArray(i)?n[0].pts[i[0]][i[1]]:n[i].pts;if(t.pointNumbers=o,t.binNumber=t.pointNumber,delete t.pointNumber,delete t.pointIndex,r._indexToPoints){a=[];for(var s=0;s<o.length;s++)a=a.concat(r._indexToPoints[o[s]])}else a=o;t.pointIndices=a}return t}},{}],1029:[function(t,e,r){\"use strict\";var n=t(\"../bar/hover\").hoverPoints,i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o){var s=(t=o[0]).cd[t.index],l=t.cd[0].trace;if(!l.cumulative.enabled){var c=\"h\"===l.orientation?\"y\":\"x\";t[c+\"Label\"]=i(t[c+\"a\"],s.ph0,s.ph1)}return l.hovermplate&&(t.hovertemplate=l.hovertemplate),o}}},{\"../../plots/cartesian/axes\":767,\"../bar/hover\":863}],1030:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"../bar/layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),supplyLayoutDefaults:t(\"../bar/layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"../bar/cross_trace_calc\").crossTraceCalc,plot:t(\"../bar/plot\").plot,layerName:\"barlayer\",style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,colorbar:t(\"../scatter/marker_colorbar\"),hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"histogram\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"histogram\",\"oriented\",\"errorBarsOK\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":778,\"../bar/cross_trace_calc\":860,\"../bar/layout_attributes\":865,\"../bar/layout_defaults\":866,\"../bar/plot\":867,\"../bar/select\":868,\"../bar/style\":870,\"../scatter/marker_colorbar\":1129,\"./attributes\":1019,\"./calc\":1024,\"./cross_trace_defaults\":1026,\"./defaults\":1027,\"./event_data\":1028,\"./hover\":1029}],1031:[function(t,e,r){\"use strict\";e.exports={percent:function(t,e){for(var r=t.length,n=100/e,i=0;i<r;i++)t[i]*=n},probability:function(t,e){for(var r=t.length,n=0;n<r;n++)t[n]/=e},density:function(t,e,r,n){var i=t.length;n=n||1;for(var a=0;a<i;a++)t[a]*=r[a]*n},\"probability density\":function(t,e,r,n){var i=t.length;n&&(e/=n);for(var a=0;a<i;a++)t[a]*=r[a]/e}}},{}],1032:[function(t,e,r){\"use strict\";var n=t(\"../histogram/attributes\"),i=t(\"../histogram/bin_attributes\"),a=t(\"../heatmap/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../lib/extend\").extendFlat;e.exports=l({x:n.x,y:n.y,z:{valType:\"data_array\",editType:\"calc\"},marker:{color:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:i(\"x\"),nbinsy:n.nbinsy,ybins:i(\"y\"),autobinx:n.autobinx,autobiny:n.autobiny,bingroup:l({},n.bingroup,{}),xbingroup:l({},n.bingroup,{}),ybingroup:l({},n.bingroup,{}),xgap:a.xgap,ygap:a.ygap,zsmooth:a.zsmooth,zhoverformat:a.zhoverformat,hovertemplate:o({},{keys:\"z\"})},s(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../heatmap/attributes\":1001,\"../histogram/attributes\":1019,\"../histogram/bin_attributes\":1021}],1033:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../histogram/bin_functions\"),o=t(\"../histogram/norm_functions\"),s=t(\"../histogram/average\"),l=t(\"../histogram/bin_label_vals\"),c=t(\"../histogram/calc\").calcAllAutoBins;function u(t,e,r,n){var i,a=new Array(t);if(n)for(i=0;i<t;i++)a[i]=1/(e[i+1]-e[i]);else{var o=1/r;for(i=0;i<t;i++)a[i]=o}return a}function h(t,e){return{start:t(e.start),end:t(e.end),size:e.size}}function f(t,e,r,n,i,a){var o,s=t.length-1,c=new Array(s),u=l(r,n,t,i,a);for(o=0;o<s;o++){var h=(e||[])[o];c[o]=void 0===h?[u(t[o]),u(t[o+1],!0)]:[h,h]}return c}e.exports=function(t,e){var r,l,p,d,g=i.getFromId(t,e.xaxis),v=i.getFromId(t,e.yaxis),m=e.xcalendar,y=e.ycalendar,x=function(t){return g.r2c(t,0,m)},b=function(t){return v.r2c(t,0,y)},_=c(t,e,g,\"x\"),w=_[0],k=_[1],T=c(t,e,v,\"y\"),A=T[0],M=T[1],S=e._length;k.length>S&&k.splice(S,k.length-S),M.length>S&&M.splice(S,M.length-S);var E=[],C=[],L=[],P=\"string\"==typeof w.size,O=\"string\"==typeof A.size,z=[],I=[],D=P?z:w,R=O?I:A,F=0,B=[],N=[],j=e.histnorm,U=e.histfunc,V=-1!==j.indexOf(\"density\"),q=\"max\"===U||\"min\"===U?null:0,H=a.count,G=o[j],Y=!1,W=[],X=[],Z=\"z\"in e?e.z:\"marker\"in e&&Array.isArray(e.marker.color)?e.marker.color:\"\";Z&&\"count\"!==U&&(Y=\"avg\"===U,H=a[U]);var J=w.size,K=x(w.start),$=x(w.end)+(K-i.tickIncrement(K,J,!1,m))/1e6;for(r=K;r<$;r=i.tickIncrement(r,J,!1,m))C.push(q),z.push(r),Y&&L.push(0);z.push(r);var Q,tt=C.length,et=(r-K)/tt,rt=(Q=K+et/2,g.c2r(Q,0,m)),nt=A.size,it=b(A.start),at=b(A.end)+(it-i.tickIncrement(it,nt,!1,y))/1e6;for(r=it;r<at;r=i.tickIncrement(r,nt,!1,y)){E.push(C.slice()),I.push(r);var ot=new Array(tt);for(l=0;l<tt;l++)ot[l]=[];N.push(ot),Y&&B.push(L.slice())}I.push(r);var st=E.length,lt=(r-it)/st,ct=function(t){return v.c2r(t,0,y)}(it+lt/2);V&&(W=u(C.length,D,et,P),X=u(E.length,R,lt,O)),P||\"date\"!==g.type||(D=h(x,D)),O||\"date\"!==v.type||(R=h(b,R));var ut=!0,ht=!0,ft=new Array(tt),pt=new Array(st),dt=1/0,gt=1/0,vt=1/0,mt=1/0;for(r=0;r<S;r++){var yt=k[r],xt=M[r];p=n.findBin(yt,D),d=n.findBin(xt,R),p>=0&&p<tt&&d>=0&&d<st&&(F+=H(p,r,E[d],Z,B[d]),N[d][p].push(r),ut&&(void 0===ft[p]?ft[p]=yt:ft[p]!==yt&&(ut=!1)),ht&&(void 0===pt[d]?pt[d]=xt:pt[d]!==xt&&(ht=!1)),dt=Math.min(dt,yt-z[p]),gt=Math.min(gt,z[p+1]-yt),vt=Math.min(vt,xt-I[d]),mt=Math.min(mt,I[d+1]-xt))}if(Y)for(d=0;d<st;d++)F+=s(E[d],B[d]);if(G)for(d=0;d<st;d++)G(E[d],F,W,X[d]);return{x:k,xRanges:f(z,ut&&ft,dt,gt,g,m),x0:rt,dx:et,y:M,yRanges:f(I,ht&&pt,vt,mt,v,y),y0:ct,dy:lt,z:E,pts:N}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../histogram/average\":1020,\"../histogram/bin_functions\":1022,\"../histogram/bin_label_vals\":1023,\"../histogram/calc\":1024,\"../histogram/norm_functions\":1031}],1034:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./sample_defaults\"),a=t(\"../heatmap/style_defaults\"),o=t(\"../../components/colorscale/defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,l),o(t,e,l,c,{prefix:\"\",cLetter:\"z\"}),c(\"hovertemplate\"))}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../heatmap/style_defaults\":1014,\"./attributes\":1032,\"./sample_defaults\":1037}],1035:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/hover\"),i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a,o,s){var l=n(t,e,r,a,o,s);if(l){var c=(t=l[0]).index,u=c[0],h=c[1],f=t.cd[0],p=f.xRanges[h],d=f.yRanges[u];return t.xLabel=i(t.xa,p[0],p[1]),t.yLabel=i(t.ya,d[0],d[1]),l}}},{\"../../plots/cartesian/axes\":767,\"../heatmap/hover\":1008}],1036:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../heatmap/calc\"),plot:t(\"../heatmap/plot\"),layerName:\"heatmaplayer\",colorbar:t(\"../heatmap/colorbar\"),style:t(\"../heatmap/style\"),hoverPoints:t(\"./hover\"),eventData:t(\"../histogram/event_data\"),moduleType:\"trace\",name:\"histogram2d\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"histogram\"],meta:{}}},{\"../../plots/cartesian\":778,\"../heatmap/calc\":1002,\"../heatmap/colorbar\":1004,\"../heatmap/plot\":1012,\"../heatmap/style\":1013,\"../histogram/cross_trace_defaults\":1026,\"../histogram/event_data\":1028,\"./attributes\":1032,\"./defaults\":1034,\"./hover\":1035}],1037:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"y\"),l=i.minRowLength(o),c=i.minRowLength(s);l&&c?(e._length=Math.min(l,c),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a),(r(\"z\")||r(\"marker.color\"))&&r(\"histfunc\"),r(\"histnorm\"),r(\"autobinx\"),r(\"autobiny\")):e.visible=!1}},{\"../../lib\":719,\"../../registry\":847}],1038:[function(t,e,r){\"use strict\";var n=t(\"../histogram2d/attributes\"),i=t(\"../contour/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat;e.exports=o({x:n.x,y:n.y,z:n.z,marker:n.marker,histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:n.xbins,nbinsy:n.nbinsy,ybins:n.ybins,autobinx:n.autobinx,autobiny:n.autobiny,bingroup:n.bingroup,xbingroup:n.xbingroup,ybingroup:n.ybingroup,autocontour:i.autocontour,ncontours:i.ncontours,contours:i.contours,line:i.line,zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../contour/attributes\":942,\"../histogram2d/attributes\":1032}],1039:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../histogram2d/sample_defaults\"),a=t(\"../contour/contours_defaults\"),o=t(\"../contour/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,function(r){return n.coerce2(t,e,s,r)}),o(t,e,c,l),c(\"hovertemplate\"))}},{\"../../lib\":719,\"../contour/contours_defaults\":949,\"../contour/style_defaults\":963,\"../histogram2d/sample_defaults\":1037,\"./attributes\":1038}],1040:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../contour/calc\"),plot:t(\"../contour/plot\").plot,layerName:\"contourlayer\",style:t(\"../contour/style\"),colorbar:t(\"../contour/colorbar\"),hoverPoints:t(\"../contour/hover\"),moduleType:\"trace\",name:\"histogram2dcontour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"histogram\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":778,\"../contour/calc\":943,\"../contour/colorbar\":945,\"../contour/hover\":955,\"../contour/plot\":960,\"../contour/style\":962,\"../histogram/cross_trace_defaults\":1026,\"./attributes\":1038,\"./defaults\":1039}],1041:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../lib/extend\").extendDeep,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../components/color/attributes\"),l=t(\"../../plots/domain\").attributes,c=t(\"../../plots/cartesian/layout_attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,h=t(\"../../constants/delta.js\"),f=(t(\"../../constants/docs\").FORMAT_LINK,o({editType:\"plot\",colorEditType:\"plot\"})),p={color:{valType:\"color\",editType:\"plot\"},line:{color:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},width:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"calc\"},thickness:{valType:\"number\",min:0,max:1,dflt:1,editType:\"plot\"},editType:\"calc\"},d={valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},g=u(\"steps\",i({},p,{range:d}));e.exports={mode:{valType:\"flaglist\",editType:\"calc\",flags:[\"number\",\"delta\",\"gauge\"],dflt:\"number\"},value:{valType:\"number\",editType:\"calc\",anim:!0},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},domain:l({name:\"indicator\",trace:!0,editType:\"calc\"}),title:{text:{valType:\"string\",editType:\"plot\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},font:n({},f,{}),editType:\"plot\"},number:{valueformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:n({},f,{}),prefix:{valType:\"string\",dflt:\"\",editType:\"plot\"},suffix:{valType:\"string\",dflt:\"\",editType:\"plot\"},editType:\"plot\"},delta:{reference:{valType:\"number\",editType:\"calc\"},position:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],dflt:\"bottom\",editType:\"plot\"},relative:{valType:\"boolean\",editType:\"plot\",dflt:!1},valueformat:{valType:\"string\",editType:\"plot\"},increasing:{symbol:{valType:\"string\",dflt:h.INCREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:h.INCREASING.COLOR,editType:\"plot\"},editType:\"plot\"},decreasing:{symbol:{valType:\"string\",dflt:h.DECREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:h.DECREASING.COLOR,editType:\"plot\"},editType:\"plot\"},font:n({},f,{}),editType:\"calc\"},gauge:{shape:{valType:\"enumerated\",editType:\"plot\",dflt:\"angular\",values:[\"angular\",\"bullet\"]},bar:i({},p,{color:{dflt:\"green\"}}),bgcolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},axis:a({range:d,visible:n({},c.visible,{dflt:!0}),tickmode:c.tickmode,nticks:c.nticks,tick0:c.tick0,dtick:c.dtick,tickvals:c.tickvals,ticktext:c.ticktext,ticks:n({},c.ticks,{dflt:\"outside\"}),ticklen:c.ticklen,tickwidth:c.tickwidth,tickcolor:c.tickcolor,showticklabels:c.showticklabels,tickfont:o({}),tickangle:c.tickangle,tickformat:c.tickformat,tickformatstops:c.tickformatstops,tickprefix:c.tickprefix,showtickprefix:c.showtickprefix,ticksuffix:c.ticksuffix,showticksuffix:c.showticksuffix,separatethousands:c.separatethousands,exponentformat:c.exponentformat,showexponent:c.showexponent,editType:\"plot\"},\"plot\"),steps:g,threshold:{line:{color:n({},p.line.color,{}),width:n({},p.line.width,{dflt:1}),editType:\"plot\"},thickness:n({},p.thickness,{dflt:.85}),value:{valType:\"number\",editType:\"calc\",dflt:!1},editType:\"plot\"},editType:\"plot\"}}},{\"../../components/color/attributes\":592,\"../../constants/delta.js\":689,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1042:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=r.name=\"indicator\";r.plot=function(t,e,r,o){var s=n.getModule(a),l=i(t.calcdata,s)[0];s.plot(t,l,r,o)},r.clean=function(t,e,r,n){var i=n._has&&n._has(a),o=e._has&&e._has(a);i&&!o&&n._indicatorlayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],1043:[function(t,e,r){\"use strict\";e.exports={calc:function(t,e){var r=[],n=e.value;\"number\"!=typeof e._lastValue&&(e._lastValue=e.value);var i=e._lastValue,a=i;return e._hasDelta&&\"number\"==typeof e.delta.reference&&(a=e.delta.reference),r[0]={y:n,lastY:i,delta:n-a,relativeDelta:(n-a)/a},r}}},{}],1044:[function(t,e,r){\"use strict\";e.exports={defaultNumberFontSize:80,bulletNumberDomainSize:.25,bulletPadding:.025,innerRadius:.75,valueThickness:.5,titlePadding:5,horizontalPadding:10}},{}],1045:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../../plot_api/plot_template\"),s=t(\"../../plots/array_container_defaults\"),l=t(\"./constants.js\"),c=t(\"../../plots/cartesian/tick_value_defaults\"),u=t(\"../../plots/cartesian/tick_mark_defaults\"),h=t(\"../../plots/cartesian/tick_label_defaults\");function f(t,e){function r(r,a){return n.coerce(t,e,i.gauge.steps,r,a)}r(\"color\"),r(\"line.color\"),r(\"line.width\"),r(\"range\"),r(\"thickness\")}e.exports={supplyDefaults:function(t,e,r,p){function d(r,a){return n.coerce(t,e,i,r,a)}a(e,p,d),d(\"mode\"),e._hasNumber=-1!==e.mode.indexOf(\"number\"),e._hasDelta=-1!==e.mode.indexOf(\"delta\"),e._hasGauge=-1!==e.mode.indexOf(\"gauge\");var g=d(\"value\");e._range=[0,\"number\"==typeof g?1.5*g:1];var v,m,y,x,b,_,w=new Array(2);function k(t,e){return n.coerce(y,x,i.gauge,t,e)}function T(t,e){return n.coerce(b,_,i.gauge.axis,t,e)}if(e._hasNumber&&(d(\"number.valueformat\"),d(\"number.font.color\",p.font.color),d(\"number.font.family\",p.font.family),d(\"number.font.size\"),void 0===e.number.font.size&&(e.number.font.size=l.defaultNumberFontSize,w[0]=!0),d(\"number.prefix\"),d(\"number.suffix\"),v=e.number.font.size),e._hasDelta&&(d(\"delta.font.color\",p.font.color),d(\"delta.font.family\",p.font.family),d(\"delta.font.size\"),void 0===e.delta.font.size&&(e.delta.font.size=(e._hasNumber?.5:1)*(v||l.defaultNumberFontSize),w[1]=!0),d(\"delta.reference\",e.value),d(\"delta.relative\"),d(\"delta.valueformat\",e.delta.relative?\"2%\":\"\"),d(\"delta.increasing.symbol\"),d(\"delta.increasing.color\"),d(\"delta.decreasing.symbol\"),d(\"delta.decreasing.color\"),d(\"delta.position\"),m=e.delta.font.size),e._scaleNumbers=(!e._hasNumber||w[0])&&(!e._hasDelta||w[1])||!1,d(\"title.font.color\",p.font.color),d(\"title.font.family\",p.font.family),d(\"title.font.size\",.25*(v||m||l.defaultNumberFontSize)),d(\"title.text\"),e._hasGauge){(y=t.gauge)||(y={}),x=o.newContainer(e,\"gauge\"),k(\"shape\"),(e._isBullet=\"bullet\"===e.gauge.shape)||d(\"title.align\",\"center\"),(e._isAngular=\"angular\"===e.gauge.shape)||d(\"align\",\"center\"),k(\"bgcolor\",p.paper_bgcolor),k(\"borderwidth\"),k(\"bordercolor\"),k(\"bar.color\"),k(\"bar.line.color\"),k(\"bar.line.width\"),k(\"bar.thickness\",l.valueThickness*(\"bullet\"===e.gauge.shape?.5:1)),s(y,x,{name:\"steps\",handleItemDefaults:f}),k(\"threshold.value\"),k(\"threshold.thickness\"),k(\"threshold.line.width\"),k(\"threshold.line.color\"),b={},y&&(b=y.axis||{}),_=o.newContainer(x,\"axis\"),T(\"visible\"),e._range=T(\"range\",e._range);var A={outerTicks:!0};c(b,_,T,\"linear\"),h(b,_,T,\"linear\",A),u(b,_,T,A)}else d(\"title.align\",\"center\"),d(\"align\",\"center\"),e._isAngular=e._isBullet=!1;e._length=null}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/tick_label_defaults\":786,\"../../plots/cartesian/tick_mark_defaults\":787,\"../../plots/cartesian/tick_value_defaults\":788,\"../../plots/domain\":792,\"./attributes\":1041,\"./constants.js\":1044}],1046:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"indicator\",basePlotModule:t(\"./base_plot\"),categories:[\"svg\",\"noOpacity\",\"noHover\"],animatable:!0,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\").calc,plot:t(\"./plot\"),meta:{}}},{\"./attributes\":1041,\"./base_plot\":1042,\"./calc\":1043,\"./defaults\":1045,\"./plot\":1047}],1047:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=i.rad2deg,o=t(\"../../constants/alignment\").MID_SHIFT,s=t(\"../../components/drawing\"),l=t(\"./constants\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"../../plots/cartesian/axes\"),h=t(\"../../plots/cartesian/axis_defaults\"),f=t(\"../../plots/cartesian/position_defaults\"),p=t(\"../../plots/cartesian/layout_attributes\"),d=t(\"../../components/color\"),g={left:\"start\",center:\"middle\",right:\"end\"},v={left:0,center:.5,right:1},m=/[yzafpn\\xb5mkMGTPEZY]/;function y(t){return t&&t.duration>0}function x(t){t.each(function(t){d.stroke(n.select(this),t.line.color)}).each(function(t){d.fill(n.select(this),t.color)}).style(\"stroke-width\",function(t){return t.line.width})}function b(t,e,r){var n=t._fullLayout,a=i.extendFlat({type:\"linear\",ticks:\"outside\",range:r,showline:!0},e),o={type:\"linear\",_id:\"x\"+e._id},s={letter:\"x\",font:n.font,noHover:!0,noTickson:!0};function l(t,e){return i.coerce(a,o,p,t,e)}return h(a,o,l,s,n),f(a,o,l,s),o}function _(t,e){return\"translate(\"+t+\",\"+e+\")\"}function w(t,e,r){return[Math.min(e/t.width,r/t.height),t,e+\"x\"+r]}function k(t,e,r,i){var a=document.createElementNS(\"http://www.w3.org/2000/svg\",\"text\"),o=n.select(a);return o.text(t).attr(\"x\",0).attr(\"y\",0).attr(\"text-anchor\",r).attr(\"data-unformatted\",t).call(c.convertToTspans,i).call(s.font,e),s.bBox(o.node())}function T(t,e,r,n,a,o){var s=\"_cache\"+e;t[s]&&t[s].key===a||(t[s]={key:a,value:r});var l=i.aggNums(o,null,[t[s].value,n],2);return t[s].value=l,l}e.exports=function(t,e,r,h){var f,p=t._fullLayout;y(r)&&h&&(f=h()),i.makeTraceGroups(p._indicatorlayer,e,\"trace\").each(function(e){var h,A,M,S,E,C=e[0].trace,L=n.select(this),P=C._hasGauge,O=C._isAngular,z=C._isBullet,I=C.domain,D={w:p._size.w*(I.x[1]-I.x[0]),h:p._size.h*(I.y[1]-I.y[0]),l:p._size.l+p._size.w*I.x[0],r:p._size.r+p._size.w*(1-I.x[1]),t:p._size.t+p._size.h*(1-I.y[1]),b:p._size.b+p._size.h*I.y[0]},R=D.l+D.w/2,F=D.t+D.h/2,B=Math.min(D.w/2,D.h),N=l.innerRadius*B,j=C.align||\"center\";if(A=F,P){if(O&&(h=R,A=F+B/2,M=function(t){return e=t,r=.9*N,n=Math.sqrt(e.width/2*(e.width/2)+e.height*e.height),[r/n,e,r];var e,r,n}),z){var U=l.bulletPadding,V=1-l.bulletNumberDomainSize+U;h=D.l+(V+(1-V)*v[j])*D.w,M=function(t){return w(t,(l.bulletNumberDomainSize-U)*D.w,D.h)}}}else h=D.l+v[j]*D.w,M=function(t){return w(t,D.w,D.h)};!function(t,e,r,a){var o,l,h,f=r[0].trace,p=a.numbersX,x=a.numbersY,w=f.align||\"center\",A=g[w],M=a.transitionOpts,S=a.onComplete,E=i.ensureSingle(e,\"g\",\"numbers\"),C=[];f._hasNumber&&C.push(\"number\");f._hasDelta&&(C.push(\"delta\"),\"left\"===f.delta.position&&C.reverse());var L=E.selectAll(\"text\").data(C);function P(e,r,n,i){if(!e.match(\"s\")||n>=0==i>=0||r(n).slice(-1).match(m)||r(i).slice(-1).match(m))return r;var a=e.slice().replace(\"s\",\"f\").replace(/\\d+/,function(t){return parseInt(t)-1}),o=b(t,{tickformat:a});return function(t){return Math.abs(t)<1?u.tickText(o,t).text:r(t)}}L.enter().append(\"text\"),L.attr(\"text-anchor\",function(){return A}).attr(\"class\",function(t){return t}).attr(\"x\",null).attr(\"y\",null).attr(\"dx\",null).attr(\"dy\",null),L.exit().remove();var O,z=f.mode+f.align;f._hasDelta&&(O=function(){var e=b(t,{tickformat:f.delta.valueformat},f._range);e.setScale(),u.calcTicks(e);var i=function(t){return u.tickText(e,t).text},a=function(t){var e=f.delta.relative?t.relativeDelta:t.delta;return e},o=function(t,e){return 0===t||\"number\"!=typeof t||isNaN(t)?\"-\":(t>0?f.delta.increasing.symbol:f.delta.decreasing.symbol)+e(t)},h=function(t){return t.delta>=0?f.delta.increasing.color:f.delta.decreasing.color};void 0===f._deltaLastValue&&(f._deltaLastValue=a(r[0]));var p=E.select(\"text.delta\");function g(){p.text(o(a(r[0]),i)).call(d.fill,h(r[0])).call(c.convertToTspans,t)}p.call(s.font,f.delta.font).call(d.fill,h({delta:f._deltaLastValue})),y(M)?p.transition().duration(M.duration).ease(M.easing).tween(\"text\",function(){var t=n.select(this),e=a(r[0]),s=f._deltaLastValue,l=P(f.delta.valueformat,i,s,e),c=n.interpolateNumber(s,e);return f._deltaLastValue=e,function(e){t.text(o(c(e),l)),t.call(d.fill,h({delta:c(e)}))}}).each(\"end\",function(){g(),S&&S()}).each(\"interrupt\",function(){g(),S&&S()}):g();return l=k(o(a(r[0]),i),f.delta.font,A,t),p}(),z+=f.delta.position+f.delta.font.size+f.delta.font.family+f.delta.valueformat,z+=f.delta.increasing.symbol+f.delta.decreasing.symbol,h=l);f._hasNumber&&(!function(){var e=b(t,{tickformat:f.number.valueformat},f._range);e.setScale(),u.calcTicks(e);var i=function(t){return u.tickText(e,t).text},a=f.number.suffix,l=f.number.prefix,h=E.select(\"text.number\");function p(){var e=\"number\"==typeof r[0].y?l+i(r[0].y)+a:\"-\";h.text(e).call(s.font,f.number.font).call(c.convertToTspans,t)}y(M)?h.transition().duration(M.duration).ease(M.easing).each(\"end\",function(){p(),S&&S()}).each(\"interrupt\",function(){p(),S&&S()}).attrTween(\"text\",function(){var t=n.select(this),e=n.interpolateNumber(r[0].lastY,r[0].y);f._lastValue=r[0].y;var o=P(f.number.valueformat,i,r[0].lastY,r[0].y);return function(r){t.text(l+o(e(r))+a)}}):p();o=k(l+i(r[0].y)+a,f.number.font,A,t)}(),z+=f.number.font.size+f.number.font.family+f.number.valueformat+f.number.suffix+f.number.prefix,h=o);if(f._hasDelta&&f._hasNumber){var I,D,R=[(o.left+o.right)/2,(o.top+o.bottom)/2],F=[(l.left+l.right)/2,(l.top+l.bottom)/2],B=.75*f.delta.font.size;\"left\"===f.delta.position&&(I=T(f,\"deltaPos\",0,-1*(o.width*v[f.align]+l.width*(1-v[f.align])+B),z,Math.min),D=R[1]-F[1],h={width:o.width+l.width+B,height:Math.max(o.height,l.height),left:l.left+I,right:o.right,top:Math.min(o.top,l.top+D),bottom:Math.max(o.bottom,l.bottom+D)}),\"right\"===f.delta.position&&(I=T(f,\"deltaPos\",0,o.width*(1-v[f.align])+l.width*v[f.align]+B,z,Math.max),D=R[1]-F[1],h={width:o.width+l.width+B,height:Math.max(o.height,l.height),left:o.left,right:l.right+I,top:Math.min(o.top,l.top+D),bottom:Math.max(o.bottom,l.bottom+D)}),\"bottom\"===f.delta.position&&(I=null,D=l.height,h={width:Math.max(o.width,l.width),height:o.height+l.height,left:Math.min(o.left,l.left),right:Math.max(o.right,l.right),top:o.bottom-o.height,bottom:o.bottom+l.height}),\"top\"===f.delta.position&&(I=null,D=o.top,h={width:Math.max(o.width,l.width),height:o.height+l.height,left:Math.min(o.left,l.left),right:Math.max(o.right,l.right),top:o.bottom-o.height-l.height,bottom:o.bottom}),O.attr({dx:I,dy:D})}(f._hasNumber||f._hasDelta)&&E.attr(\"transform\",function(){var t=a.numbersScaler(h);z+=t[2];var e,r=T(f,\"numbersScale\",1,t[0],z,Math.min);f._scaleNumbers||(r=1),e=f._isAngular?x-r*h.bottom:x-r*(h.top+h.bottom)/2,f._numbersTop=r*h.top+e;var n=h[w];\"center\"===w&&(n=(h.left+h.right)/2);var i=p-r*n;return _(i=T(f,\"numbersTranslate\",0,i,z,Math.max),e)+\" scale(\"+r+\")\"})}(t,L,e,{numbersX:h,numbersY:A,numbersScaler:M,transitionOpts:r,onComplete:f}),P&&(S={range:C.gauge.axis.range,color:C.gauge.bgcolor,line:{color:C.gauge.bordercolor,width:0},thickness:1},E={range:C.gauge.axis.range,color:\"rgba(0, 0, 0, 0)\",line:{color:C.gauge.bordercolor,width:C.gauge.borderwidth},thickness:1});var q=L.selectAll(\"g.angular\").data(O?e:[]);q.exit().remove();var H=L.selectAll(\"g.angularaxis\").data(O?e:[]);H.exit().remove(),O&&function(t,e,r,i){var s,l,c,h,f=r[0].trace,p=i.size,d=i.radius,g=i.innerRadius,v=i.gaugeBg,m=i.gaugeOutline,w=[p.l+p.w/2,p.t+p.h/2+d/2],k=i.gauge,T=i.layer,A=i.transitionOpts,M=i.onComplete,S=Math.PI/2;function E(t){var e=f.gauge.axis.range[0],r=f.gauge.axis.range[1],n=(t-e)/(r-e)*Math.PI-S;return n<-S?-S:n>S?S:n}function C(t){return n.svg.arc().innerRadius((g+d)/2-t/2*(d-g)).outerRadius((g+d)/2+t/2*(d-g)).startAngle(-S)}function L(t){t.attr(\"d\",function(t){return C(t.thickness).startAngle(E(t.range[0])).endAngle(E(t.range[1]))()})}k.enter().append(\"g\").classed(\"angular\",!0),k.attr(\"transform\",_(w[0],w[1])),T.enter().append(\"g\").classed(\"angularaxis\",!0).classed(\"crisp\",!0),T.selectAll(\"g.xangularaxistick,path,text\").remove(),(s=b(t,f.gauge.axis)).type=\"linear\",s.range=f.gauge.axis.range,s._id=\"xangularaxis\",s.setScale();var P=function(t){return(s.range[0]-t.x)/(s.range[1]-s.range[0])*Math.PI+Math.PI},O={},z=u.makeLabelFns(s,0).labelStandoff;O.xFn=function(t){var e=P(t);return Math.cos(e)*z},O.yFn=function(t){var e=P(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(z+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*o)},O.anchorFn=function(t){var e=P(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},O.heightFn=function(t,e,r){var n=P(t);return-.5*(1+Math.sin(n))*r};var I=function(t){return _(w[0]+d*Math.cos(t),w[1]-d*Math.sin(t))};c=function(t){return I(P(t))};if(l=u.calcTicks(s),h=u.getTickSigns(s)[2],s.visible){h=\"inside\"===s.ticks?-1:1;var D=(s.linewidth||1)/2;u.drawTicks(t,s,{vals:l,layer:T,path:\"M\"+h*D+\",0h\"+h*s.ticklen,transFn:function(t){var e=P(t);return I(e)+\"rotate(\"+-a(e)+\")\"}}),u.drawLabels(t,s,{vals:l,layer:T,transFn:c,labelFns:O})}var R=[v].concat(f.gauge.steps),F=k.selectAll(\"g.bg-arc\").data(R);F.enter().append(\"g\").classed(\"bg-arc\",!0).append(\"path\"),F.select(\"path\").call(L).call(x),F.exit().remove();var B=C(f.gauge.bar.thickness),N=k.selectAll(\"g.value-arc\").data([f.gauge.bar]);N.enter().append(\"g\").classed(\"value-arc\",!0).append(\"path\");var j=N.select(\"path\");y(A)?(j.transition().duration(A.duration).ease(A.easing).each(\"end\",function(){M&&M()}).each(\"interrupt\",function(){M&&M()}).attrTween(\"d\",(U=B,V=E(r[0].lastY),q=E(r[0].y),function(){var t=n.interpolate(V,q);return function(e){return U.endAngle(t(e))()}})),f._lastValue=r[0].y):j.attr(\"d\",\"number\"==typeof r[0].y?B.endAngle(E(r[0].y)):\"M0,0Z\");var U,V,q;j.call(x),N.exit().remove(),R=[];var H=f.gauge.threshold.value;H&&R.push({range:[H,H],color:f.gauge.threshold.color,line:{color:f.gauge.threshold.line.color,width:f.gauge.threshold.line.width},thickness:f.gauge.threshold.thickness});var G=k.selectAll(\"g.threshold-arc\").data(R);G.enter().append(\"g\").classed(\"threshold-arc\",!0).append(\"path\"),G.select(\"path\").call(L).call(x),G.exit().remove();var Y=k.selectAll(\"g.gauge-outline\").data([m]);Y.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"path\"),Y.select(\"path\").call(L).call(x),Y.exit().remove()}(t,0,e,{radius:B,innerRadius:N,gauge:q,layer:H,size:D,gaugeBg:S,gaugeOutline:E,transitionOpts:r,onComplete:f});var G=L.selectAll(\"g.bullet\").data(z?e:[]);G.exit().remove();var Y=L.selectAll(\"g.bulletaxis\").data(z?e:[]);Y.exit().remove(),z&&function(t,e,r,n){var i,a,o,s,c,h=r[0].trace,f=n.gauge,p=n.layer,g=n.gaugeBg,v=n.gaugeOutline,m=n.size,_=h.domain,w=n.transitionOpts,k=n.onComplete;f.enter().append(\"g\").classed(\"bullet\",!0),f.attr(\"transform\",\"translate(\"+m.l+\", \"+m.t+\")\"),p.enter().append(\"g\").classed(\"bulletaxis\",!0).classed(\"crisp\",!0),p.selectAll(\"g.xbulletaxistick,path,text\").remove();var T=m.h,A=h.gauge.bar.thickness*T,M=_.x[0],S=_.x[0]+(_.x[1]-_.x[0])*(h._hasNumber||h._hasDelta?1-l.bulletNumberDomainSize:1);(i=b(t,h.gauge.axis))._id=\"xbulletaxis\",i.domain=[M,S],i.setScale(),a=u.calcTicks(i),o=u.makeTransFn(i),s=u.getTickSigns(i)[2],c=m.t+m.h,i.visible&&(u.drawTicks(t,i,{vals:\"inside\"===i.ticks?u.clipEnds(i,a):a,layer:p,path:u.makeTickPath(i,c,s),transFn:o}),u.drawLabels(t,i,{vals:a,layer:p,transFn:o,labelFns:u.makeLabelFns(i,c)}));function E(t){t.attr(\"width\",function(t){return Math.max(0,i.c2p(t.range[1])-i.c2p(t.range[0]))}).attr(\"x\",function(t){return i.c2p(t.range[0])}).attr(\"y\",function(t){return.5*(1-t.thickness)*T}).attr(\"height\",function(t){return t.thickness*T})}var C=[g].concat(h.gauge.steps),L=f.selectAll(\"g.bg-bullet\").data(C);L.enter().append(\"g\").classed(\"bg-bullet\",!0).append(\"rect\"),L.select(\"rect\").call(E).call(x),L.exit().remove();var P=f.selectAll(\"g.value-bullet\").data([h.gauge.bar]);P.enter().append(\"g\").classed(\"value-bullet\",!0).append(\"rect\"),P.select(\"rect\").attr(\"height\",A).attr(\"y\",(T-A)/2).call(x),y(w)?P.select(\"rect\").transition().duration(w.duration).ease(w.easing).each(\"end\",function(){k&&k()}).each(\"interrupt\",function(){k&&k()}).attr(\"width\",Math.max(0,i.c2p(Math.min(h.gauge.axis.range[1],r[0].y)))):P.select(\"rect\").attr(\"width\",\"number\"==typeof r[0].y?Math.max(0,i.c2p(Math.min(h.gauge.axis.range[1],r[0].y))):0);P.exit().remove();var O=r.filter(function(){return h.gauge.threshold.value}),z=f.selectAll(\"g.threshold-bullet\").data(O);z.enter().append(\"g\").classed(\"threshold-bullet\",!0).append(\"line\"),z.select(\"line\").attr(\"x1\",i.c2p(h.gauge.threshold.value)).attr(\"x2\",i.c2p(h.gauge.threshold.value)).attr(\"y1\",(1-h.gauge.threshold.thickness)/2*T).attr(\"y2\",(1-(1-h.gauge.threshold.thickness)/2)*T).call(d.stroke,h.gauge.threshold.line.color).style(\"stroke-width\",h.gauge.threshold.line.width),z.exit().remove();var I=f.selectAll(\"g.gauge-outline\").data([v]);I.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"rect\"),I.select(\"rect\").call(E).call(x),I.exit().remove()}(t,0,e,{gauge:G,layer:Y,size:D,gaugeBg:S,gaugeOutline:E,transitionOpts:r,onComplete:f});var W=L.selectAll(\"text.title\").data(e);W.exit().remove(),W.enter().append(\"text\").classed(\"title\",!0),W.attr(\"text-anchor\",function(){return z?g.right:g[C.title.align]}).text(C.title.text).call(s.font,C.title.font).call(c.convertToTspans,t),W.attr(\"transform\",function(){var t,e=D.l+D.w*v[C.title.align],r=l.titlePadding,n=s.bBox(W.node());if(P){if(O)if(C.gauge.axis.visible)t=s.bBox(H.node()).top-r-n.bottom;else t=D.t+D.h/2-B/2-n.bottom-r;z&&(t=A-(n.top+n.bottom)/2,e=D.l-l.bulletPadding*D.w)}else t=C._numbersTop-r-n.bottom;return _(e,t)})})}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_defaults\":769,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/cartesian/position_defaults\":782,\"./constants\":1044,d3:163}],1048:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;var c=e.exports=l(s({x:{valType:\"data_array\"},y:{valType:\"data_array\"},z:{valType:\"data_array\"},value:{valType:\"data_array\"},isomin:{valType:\"number\"},isomax:{valType:\"number\"},surface:{show:{valType:\"boolean\",dflt:!0},count:{valType:\"integer\",dflt:2,min:1},fill:{valType:\"number\",min:0,max:1,dflt:1},pattern:{valType:\"flaglist\",flags:[\"A\",\"B\",\"C\",\"D\",\"E\"],extras:[\"all\",\"odd\",\"even\"],dflt:\"all\"}},spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:.15}},slices:{x:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}}},caps:{x:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}}},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:i()},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:a.opacity,lightposition:a.lightposition,lighting:a.lighting,flatshading:a.flatshading,contour:a.contour,hoverinfo:s({},o.hoverinfo)}),\"calc\",\"nested\");c.flatshading.dflt=!0,c.lighting.facenormalsepsilon.dflt=0,c.x.editType=c.y.editType=c.z.editType=c.value.editType=\"calc+clearAxisTypes\",c.transforms=void 0},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../mesh3d/attributes\":1053}],1049:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e._len=Math.min(e.x.length,e.y.length,e.z.length,e.value.length);for(var r=1/0,i=-1/0,a=e.value.length,o=0;o<a;o++){var s=e.value[o];r=Math.min(r,s),i=Math.max(i,s)}e._minValues=r,e._maxValues=i,e._vMin=void 0===e.isomin||null===e.isomin?r:e.isomin,e._vMax=void 0===e.isomax||null===e.isomin?i:e.isomax,n(t,e,{vals:[e._vMin,e._vMax],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],1050:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib\"),a=t(\"../../lib/gl_format_color\").parseColorScale,o=t(\"../../lib/str2rgbarray\"),s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\");function c(t){return i.distinctVals(t).vals}var u=function(t,e){for(var r=e.length-1;r>0;r--){var n=Math.min(e[r],e[r-1]),i=Math.max(e[r],e[r-1]);if(i>n&&n<t&&t<=i)return{id:r,distRatio:(i-t)/(i-n)}}return{id:0,distRatio:0}};function h(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var f=h.prototype;function p(t){t._i=[],t._j=[],t._k=[];var e,r,n=t.surface.show,i=t.spaceframe.show,a=t.surface.fill,o=t.spaceframe.fill,s=!1,l=!1,h=0,f=c(t.x.slice(0,t._len)),p=c(t.y.slice(0,t._len)),d=c(t.z.slice(0,t._len)),g=f.length,v=p.length,m=d.length;function y(t,e,r){return r+m*e+m*v*t}var x,b,_,w,k,T=t._minValues,A=t._maxValues,M=t._vMin,S=t._vMax;function E(t,e,n){for(var i=w.length,a=r;a<i;a++)if(t===x[a]&&e===b[a]&&n===_[a])return a;return-1}function C(){r=e}function L(){x=[],b=[],_=[],w=[],e=0,C()}function P(t,r,n,i){return x.push(t),b.push(r),_.push(n),w.push(i),++e-1}function O(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=t[i]*(1-r)+r*e[i];return n}function z(t){k=t}function I(t,e){return\"all\"===t||null===t||t.indexOf(e)>-1}function D(t,e){return null===t?e:t}function R(e,r,n){C();var i,a,o,s=[r],l=[n];if(k>=1)s=[r],l=[n];else if(k>0){var c=function(t,e){var r=t[0],n=t[1],i=t[2],a=function(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=(t[i]+e[i]+r[i])/3;return n}(r,n,i),o=Math.sqrt(1-k),s=O(a,r,o),l=O(a,n,o),c=O(a,i,o),u=e[0],h=e[1],f=e[2];return{xyzv:[[r,n,l],[l,s,r],[n,i,c],[c,l,n],[i,r,s],[s,c,i]],abc:[[u,h,-1],[-1,-1,u],[h,f,-1],[-1,-1,h],[f,u,-1],[-1,-1,f]]}}(r,n);s=c.xyzv,l=c.abc}for(var u=0;u<s.length;u++){r=s[u],n=l[u];for(var f=[],p=0;p<3;p++){var d=r[p][0],g=r[p][1],v=r[p][2],m=r[p][3],y=n[p]>-1?n[p]:E(d,g,v);f[p]=y>-1?y:P(d,g,v,D(e,m))}i=f[0],a=f[1],o=f[2],t._i.push(i),t._j.push(a),t._k.push(o),++h}}function F(t,e,r,n){var i=t[3];i<r&&(i=r),i>n&&(i=n);for(var a=(t[3]-i)/(t[3]-e[3]+1e-9),o=[],s=0;s<4;s++)o[s]=(1-a)*t[s]+a*e[s];return o}function B(t,e,r){return t>=e&&t<=r}function N(t){var e=.001*(S-M);return t>=M-e&&t<=S+e}function j(e){for(var r=[],n=0;n<4;n++){var i=e[n];r.push([t.x[i],t.y[i],t.z[i],t.value[i]])}return r}var U=3;function V(t,e,r,n,i,a){a||(a=1),r=[-1,-1,-1];var o=!1,s=[B(e[0][3],n,i),B(e[1][3],n,i),B(e[2][3],n,i)];if(!s[0]&&!s[1]&&!s[2])return!1;var l=function(t,e,r){return N(e[0][3])&&N(e[1][3])&&N(e[2][3])?(R(t,e,r),!0):a<U&&V(t,e,r,M,S,++a)};if(s[0]&&s[1]&&s[2])return l(t,e,r)||o;var c=!1;return[[0,1,2],[2,0,1],[1,2,0]].forEach(function(a){if(s[a[0]]&&s[a[1]]&&!s[a[2]]){var u=e[a[0]],h=e[a[1]],f=e[a[2]],p=F(f,u,n,i),d=F(f,h,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,o=l(t,[u,h,d],[r[a[0]],r[a[1]],-1])||o,c=!0}}),c?o:([[0,1,2],[1,2,0],[2,0,1]].forEach(function(a){if(s[a[0]]&&!s[a[1]]&&!s[a[2]]){var u=e[a[0]],h=e[a[1]],f=e[a[2]],p=F(h,u,n,i),d=F(f,u,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,c=!0}}),o)}function q(t,e,r,n){var i=!1,a=j(e),o=[B(a[0][3],r,n),B(a[1][3],r,n),B(a[2][3],r,n),B(a[3][3],r,n)];if(!(o[0]||o[1]||o[2]||o[3]))return i;if(o[0]&&o[1]&&o[2]&&o[3])return l&&(i=function(t,e,r){var n=function(n,i,a){R(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(3,0,1),n(2,3,0),n(1,2,3)}(t,a,e)||i),i;var s=!1;return[[0,1,2,3],[3,0,1,2],[2,3,0,1],[1,2,3,0]].forEach(function(c){if(o[c[0]]&&o[c[1]]&&o[c[2]]&&!o[c[3]]){var u=a[c[0]],h=a[c[1]],f=a[c[2]],p=a[c[3]];if(l)i=R(t,[u,h,f],[e[c[0]],e[c[1]],e[c[2]]])||i;else{var d=F(p,u,r,n),g=F(p,h,r,n),v=F(p,f,r,n);i=R(null,[d,g,v],[-1,-1,-1])||i}s=!0}}),s?i:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2],[0,2,3,1],[1,3,2,0]].forEach(function(c){if(o[c[0]]&&o[c[1]]&&!o[c[2]]&&!o[c[3]]){var u=a[c[0]],h=a[c[1]],f=a[c[2]],p=a[c[3]],d=F(f,u,r,n),g=F(f,h,r,n),v=F(p,h,r,n),m=F(p,u,r,n);l?(i=R(t,[u,m,d],[e[c[0]],-1,-1])||i,i=R(t,[h,g,v],[e[c[1]],-1,-1])||i):i=function(t,e,r){var n=function(n,i,a){R(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(2,3,0)}(null,[d,g,v,m],[-1,-1,-1,-1])||i,s=!0}}),s?i:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2]].forEach(function(c){if(o[c[0]]&&!o[c[1]]&&!o[c[2]]&&!o[c[3]]){var u=a[c[0]],h=a[c[1]],f=a[c[2]],p=a[c[3]],d=F(h,u,r,n),g=F(f,u,r,n),v=F(p,u,r,n);l?(i=R(t,[u,d,g],[e[c[0]],-1,-1])||i,i=R(t,[u,g,v],[e[c[0]],-1,-1])||i,i=R(t,[u,v,d],[e[c[0]],-1,-1])||i):i=R(null,[d,g,v],[-1,-1,-1])||i,s=!0}}),i))}function H(t,e,r,n,i,a,o,c,u,h,f){var p=!1;return s&&(I(t,\"A\")&&(p=q(null,[e,r,n,a],h,f)||p),I(t,\"B\")&&(p=q(null,[r,n,i,u],h,f)||p),I(t,\"C\")&&(p=q(null,[r,a,o,u],h,f)||p),I(t,\"D\")&&(p=q(null,[n,a,c,u],h,f)||p),I(t,\"E\")&&(p=q(null,[r,n,a,u],h,f)||p)),l&&(p=q(t,[r,n,a,u],h,f)||p),p}function G(t,e,r,n,i,a,o,s){return[!0===s[0]||V(t,j([e,r,n]),[e,r,n],a,o),!0===s[1]||V(t,j([n,i,e]),[n,i,e],a,o)]}function Y(t,e,r,n,i,a,o,s,l){return s?G(t,e,r,i,n,a,o,l):G(t,r,i,n,e,a,o,l)}function W(t,e,r,n,i,a,o){var s,l,c,u,h=!1,f=function(){h=V(t,[s,l,c],[-1,-1,-1],i,a)||h,h=V(t,[c,u,s],[-1,-1,-1],i,a)||h},p=o[0],d=o[1],g=o[2];return p&&(s=O(j([y(e,r-0,n-0)])[0],j([y(e-1,r-0,n-0)])[0],p),l=O(j([y(e,r-0,n-1)])[0],j([y(e-1,r-0,n-1)])[0],p),c=O(j([y(e,r-1,n-1)])[0],j([y(e-1,r-1,n-1)])[0],p),u=O(j([y(e,r-1,n-0)])[0],j([y(e-1,r-1,n-0)])[0],p),f()),d&&(s=O(j([y(e-0,r,n-0)])[0],j([y(e-0,r-1,n-0)])[0],d),l=O(j([y(e-0,r,n-1)])[0],j([y(e-0,r-1,n-1)])[0],d),c=O(j([y(e-1,r,n-1)])[0],j([y(e-1,r-1,n-1)])[0],d),u=O(j([y(e-1,r,n-0)])[0],j([y(e-1,r-1,n-0)])[0],d),f()),g&&(s=O(j([y(e-0,r-0,n)])[0],j([y(e-0,r-0,n-1)])[0],g),l=O(j([y(e-0,r-1,n)])[0],j([y(e-0,r-1,n-1)])[0],g),c=O(j([y(e-1,r-1,n)])[0],j([y(e-1,r-1,n-1)])[0],g),u=O(j([y(e-1,r-0,n)])[0],j([y(e-1,r-0,n-1)])[0],g),f()),h}function X(t,e,r,n,i,a,o,l,c,u,h,f){var p=t;return f?(s&&\"even\"===t&&(p=null),H(p,e,r,n,i,a,o,l,c,u,h)):(s&&\"odd\"===t&&(p=null),H(p,c,l,o,a,i,n,r,e,u,h))}function Z(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<m;c++)for(var u=1;u<v;u++)a.push(Y(t,y(l,u-1,c-1),y(l,u-1,c),y(l,u,c-1),y(l,u,c),r,n,(l+u+c)%2,i&&i[o]?i[o]:[])),o++;return a}function J(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<g;c++)for(var u=1;u<m;u++)a.push(Y(t,y(c-1,l,u-1),y(c,l,u-1),y(c-1,l,u),y(c,l,u),r,n,(c+l+u)%2,i&&i[o]?i[o]:[])),o++;return a}function K(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<v;c++)for(var u=1;u<g;u++)a.push(Y(t,y(u-1,c-1,l),y(u-1,c,l),y(u,c-1,l),y(u,c,l),r,n,(u+c+l)%2,i&&i[o]?i[o]:[])),o++;return a}function $(t,e,r){for(var n=1;n<m;n++)for(var i=1;i<v;i++)for(var a=1;a<g;a++)X(t,y(a-1,i-1,n-1),y(a-1,i-1,n),y(a-1,i,n-1),y(a-1,i,n),y(a,i-1,n-1),y(a,i-1,n),y(a,i,n-1),y(a,i,n),e,r,(a+i+n)%2)}function Q(t,e,r){s=!0,$(t,e,r),s=!1}function tt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<m;u++)for(var h=1;h<v;h++)o.push(W(t,c,h,u,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function et(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<g;u++)for(var h=1;h<m;h++)o.push(W(t,u,c,h,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function rt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<v;u++)for(var h=1;h<g;h++)o.push(W(t,h,u,c,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function nt(t,e){for(var r=[],n=t;n<e;n++)r.push(n);return r}return function(){if(L(),function(){for(var e=0;e<g;e++)for(var r=0;r<v;r++)for(var n=0;n<m;n++){var i=y(e,r,n);P(t.x[i],t.y[i],t.z[i],t.value[i])}}(),i&&o&&(z(o),l=!0,$(null,M,S),l=!1),n&&a){z(a);for(var e=t.surface.pattern,r=t.surface.count,s=0;s<r;s++){var c=1===r?.5:s/(r-1),k=(1-c)*M+c*S,E=Math.abs(k-T)>Math.abs(k-A)?[T,k]:[k,A];Q(e,E[0],E[1])}}var C=[[Math.min(M,A),Math.max(M,A)],[Math.min(T,S),Math.max(T,S)]];[\"x\",\"y\",\"z\"].forEach(function(e){for(var r=[],n=0;n<C.length;n++){var i=0,a=C[n][0],o=C[n][1],s=t.slices[e];if(s.show&&s.fill){z(s.fill);var l=[],c=[],h=[];if(s.locations.length)for(var y=0;y<s.locations.length;y++){var x=u(s.locations[y],\"x\"===e?f:\"y\"===e?p:d);0===x.distRatio?l.push(x.id):x.id>0&&(c.push(x.id),\"x\"===e?h.push([x.distRatio,0,0]):\"y\"===e?h.push([0,x.distRatio,0]):h.push([0,0,x.distRatio]))}else l=nt(1,\"x\"===e?g-1:\"y\"===e?v-1:m-1);c.length>0&&(r[i]=\"x\"===e?tt(null,c,a,o,h,r[i]):\"y\"===e?et(null,c,a,o,h,r[i]):rt(null,c,a,o,h,r[i]),i++),l.length>0&&(r[i]=\"x\"===e?Z(null,l,a,o,r[i]):\"y\"===e?J(null,l,a,o,r[i]):K(null,l,a,o,r[i]),i++)}var b=t.caps[e];b.show&&b.fill&&(z(b.fill),r[i]=\"x\"===e?Z(null,[0,g-1],a,o,r[i]):\"y\"===e?J(null,[0,v-1],a,o,r[i]):K(null,[0,m-1],a,o,r[i]),i++)}}),0===h&&L(),t._x=x,t._y=b,t._z=_,t._intensity=w,t._Xs=f,t._Ys=p,t._Zs=d}(),t}f.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._x[e],n=this.data._y[e],i=this.data._z[e],a=this.data._Ys.length,o=this.data._Zs.length,s=u(r,this.data._Xs).id,l=u(n,this.data._Ys).id,c=u(i,this.data._Zs).id,h=t.index=c+o*l+o*a*s;t.traceCoordinate=[this.data._x[h],this.data._y[h],this.data._z[h],this.data.value[h]];var f=this.data.hovertext||this.data.text;return Array.isArray(f)&&void 0!==f[h]?t.textLabel=f[h]:f&&(t.textLabel=f),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map(function(e){return t.d2l(e,0,n)*r})}this.data=p(t);var i={positions:l(n(r.xaxis,t._x,e.dataScale[0],t.xcalendar),n(r.yaxis,t._y,e.dataScale[1],t.ycalendar),n(r.zaxis,t._z,e.dataScale[2],t.zcalendar)),cells:l(t._i,t._j,t._k),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:o(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},c=s(t);i.vertexIntensity=t._intensity,i.vertexIntensityBounds=[c.min,c.max],i.colormap=a(t),this.mesh.update(i)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports={findNearestOnAxis:u,generateIsoMeshes:p,createIsosurfaceTrace:function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new h(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../../plots/gl3d/zip3\":818,\"gl-mesh3d\":280}],1051:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"../../components/colorscale/defaults\");function s(t,e,r,n,a){var s=a(\"isomin\"),l=a(\"isomax\");null!=l&&null!=s&&s>l&&(e.isomin=null,e.isomax=null);var c=a(\"x\"),u=a(\"y\"),h=a(\"z\"),f=a(\"value\");c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length?(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],n),[\"x\",\"y\",\"z\"].forEach(function(t){var e=\"caps.\"+t;a(e+\".show\")&&a(e+\".fill\");var r=\"slices.\"+t;a(r+\".show\")&&(a(r+\".fill\"),a(r+\".locations\"))}),a(\"spaceframe.show\")&&a(\"spaceframe.fill\"),a(\"surface.show\")&&(a(\"surface.count\"),a(\"surface.fill\"),a(\"surface.pattern\")),a(\"contour.show\")&&(a(\"contour.color\"),a(\"contour.width\")),[\"text\",\"hovertext\",\"hovertemplate\",\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"flatshading\",\"opacity\"].forEach(function(t){a(t)}),o(t,e,n,a,{prefix:\"\",cLetter:\"c\"}),e._length=null):e.visible=!1}e.exports={supplyDefaults:function(t,e,r,i){s(t,e,0,i,function(r,i){return n.coerce(t,e,a,r,i)})},supplyIsoDefaults:s}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../../registry\":847,\"./attributes\":1048}],1052:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\").createIsosurfaceTrace,moduleType:\"trace\",name:\"isosurface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1048,\"./calc\":1049,\"./convert\":1050,\"./defaults\":1051}],1053:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../surface/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},i:{valType:\"data_array\",editType:\"calc\"},j:{valType:\"data_array\",editType:\"calc\"},k:{valType:\"data_array\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:i({editType:\"calc\"}),delaunayaxis:{valType:\"enumerated\",values:[\"x\",\"y\",\"z\"],dflt:\"z\",editType:\"calc\"},alphahull:{valType:\"number\",dflt:-1,editType:\"calc\"},intensity:{valType:\"data_array\",editType:\"calc\"},color:{valType:\"color\",editType:\"calc\"},vertexcolor:{valType:\"data_array\",editType:\"calc\"},facecolor:{valType:\"data_array\",editType:\"calc\"},transforms:void 0},n(\"\",{colorAttr:\"`intensity`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:a.opacity,flatshading:{valType:\"boolean\",dflt:!1,editType:\"calc\"},contour:{show:s({},a.contours.x.show,{}),color:a.contours.x.color,width:a.contours.x.width,editType:\"calc\"},lightposition:{x:s({},a.lightposition.x,{dflt:1e5}),y:s({},a.lightposition.y,{dflt:1e5}),z:s({},a.lightposition.z,{dflt:0}),editType:\"calc\"},lighting:s({vertexnormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-12,editType:\"calc\"},facenormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-6,editType:\"calc\"},editType:\"calc\"},a.lighting),hoverinfo:s({},o.hoverinfo,{editType:\"calc\"})})},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../surface/attributes\":1224}],1054:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.intensity&&n(t,e,{vals:e.intensity,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],1055:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"delaunay-triangulate\"),a=t(\"alpha-shape\"),o=t(\"convex-hull\"),s=t(\"../../lib/gl_format_color\").parseColorScale,l=t(\"../../lib/str2rgbarray\"),c=t(\"../../components/colorscale\").extractOpts,u=t(\"../../plots/gl3d/zip3\");function h(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.color=\"#fff\",this.data=null,this.showContour=!1}var f=h.prototype;function p(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=l(t[n]);return e}function d(t,e,r,n){for(var i=[],a=e.length,o=0;o<a;o++)i[o]=t.d2l(e[o],0,n)*r;return i}function g(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=Math.round(t[n]);return e}function v(t,e){for(var r=t.length,n=0;n<r;n++)if(t[n]<=-.5||t[n]>=e-.5)return!1;return!0}f.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index;t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]];var r=this.data.hovertext||this.data.text;return Array.isArray(r)&&void 0!==r[e]?t.textLabel=r[e]:r&&(t.textLabel=r),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;this.data=t;var n,h=t.x.length,f=u(d(r.xaxis,t.x,e.dataScale[0],t.xcalendar),d(r.yaxis,t.y,e.dataScale[1],t.ycalendar),d(r.zaxis,t.z,e.dataScale[2],t.zcalendar));if(t.i&&t.j&&t.k){if(t.i.length!==t.j.length||t.j.length!==t.k.length||!v(t.i,h)||!v(t.j,h)||!v(t.k,h))return;n=u(g(t.i),g(t.j),g(t.k))}else n=0===t.alphahull?o(f):t.alphahull>0?a(t.alphahull,f):function(t,e){for(var r=[\"x\",\"y\",\"z\"].indexOf(t),n=[],a=e.length,o=0;o<a;o++)n[o]=[e[o][(r+1)%3],e[o][(r+2)%3]];return i(n)}(t.delaunayaxis,f);var m={positions:f,cells:n,lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:l(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading};if(t.intensity){var y=c(t);this.color=\"#fff\",m.vertexIntensity=t.intensity,m.vertexIntensityBounds=[y.min,y.max],m.colormap=s(t)}else t.vertexcolor?(this.color=t.vertexcolor[0],m.vertexColors=p(t.vertexcolor)):t.facecolor?(this.color=t.facecolor[0],m.cellColors=p(t.facecolor)):(this.color=t.color,m.meshColor=l(t.color));this.mesh.update(m)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new h(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":605,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../../plots/gl3d/zip3\":818,\"alpha-shape\":64,\"convex-hull\":130,\"delaunay-triangulate\":165,\"gl-mesh3d\":280}],1056:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,n){return i.coerce(t,e,o,r,n)}function c(t){var e=t.map(function(t){var e=l(t);return e&&i.isArrayOrTypedArray(e)?e:null});return e.every(function(t){return t&&t.length===e[0].length})&&e}c([\"x\",\"y\",\"z\"])?(c([\"i\",\"j\",\"k\"]),(!e.i||e.j&&e.k)&&(!e.j||e.k&&e.i)&&(!e.k||e.i&&e.j)?(n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],s),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"contour.show\",\"contour.color\",\"contour.width\",\"colorscale\",\"reversescale\",\"flatshading\",\"alphahull\",\"delaunayaxis\",\"opacity\"].forEach(function(t){l(t)}),\"intensity\"in t?(l(\"intensity\"),a(t,e,s,l,{prefix:\"\",cLetter:\"c\"})):(e.showscale=!1,\"facecolor\"in t?l(\"facecolor\"):\"vertexcolor\"in t?l(\"vertexcolor\"):l(\"color\",r)),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),e._length=null):e.visible=!1):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../../registry\":847,\"./attributes\":1053}],1057:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"mesh3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1053,\"./calc\":1054,\"./convert\":1055,\"./defaults\":1056}],1058:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../scatter/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../components/fx/attributes\"),s=t(\"../../constants/delta.js\"),l=s.INCREASING.COLOR,c=s.DECREASING.COLOR,u=i.line;function h(t){return{line:{color:n({},u.color,{dflt:t}),width:u.width,dash:a,editType:\"style\"},editType:\"style\"}}e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},open:{valType:\"data_array\",editType:\"calc\"},high:{valType:\"data_array\",editType:\"calc\"},low:{valType:\"data_array\",editType:\"calc\"},close:{valType:\"data_array\",editType:\"calc\"},line:{width:n({},u.width,{}),dash:n({},a,{}),editType:\"style\"},increasing:h(l),decreasing:h(c),text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},tickwidth:{valType:\"number\",min:0,max:.5,dflt:.3,editType:\"calc\"},hoverlabel:n({},o.hoverlabel,{split:{valType:\"boolean\",dflt:!1,editType:\"style\"}})}},{\"../../components/drawing/attributes\":613,\"../../components/fx/attributes\":623,\"../../constants/delta.js\":689,\"../../lib\":719,\"../scatter/attributes\":1112}],1059:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=n._,a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/numerical\").BADNUM;function s(t,e,r,n){return{o:t,h:e,l:r,c:n}}function l(t,e,r,s,l){for(var c=s.makeCalcdata(e,\"open\"),u=s.makeCalcdata(e,\"high\"),h=s.makeCalcdata(e,\"low\"),f=s.makeCalcdata(e,\"close\"),p=Array.isArray(e.text),d=Array.isArray(e.hovertext),g=!0,v=null,m=[],y=0;y<r.length;y++){var x=r[y],b=c[y],_=u[y],w=h[y],k=f[y];if(x!==o&&b!==o&&_!==o&&w!==o&&k!==o){k===b?null!==v&&k!==v&&(g=k>v):g=k>b,v=k;var T=l(b,_,w,k);T.pos=x,T.yc=(b+k)/2,T.i=y,T.dir=g?\"increasing\":\"decreasing\",T.x=T.pos,T.y=[w,_],p&&(T.tx=e.text[y]),d&&(T.htx=e.hovertext[y]),m.push(T)}else m.push({pos:x,empty:!0})}return e._extremes[s._id]=a.findExtremes(s,n.concat(h,u),{padded:!0}),m.length&&(m[0].t={labels:{open:i(t,\"open:\")+\" \",high:i(t,\"high:\")+\" \",low:i(t,\"low:\")+\" \",close:i(t,\"close:\")+\" \"}}),m}e.exports={calc:function(t,e){var r=a.getFromId(t,e.xaxis),i=a.getFromId(t,e.yaxis),o=function(t,e,r){var i=r._minDiff;if(!i){var a,o=t._fullData,s=[];for(i=1/0,a=0;a<o.length;a++){var l=o[a];if(\"ohlc\"===l.type&&!0===l.visible&&l.xaxis===e._id){s.push(l);var c=e.makeCalcdata(l,\"x\");l._xcalc=c;var u=n.distinctVals(c).minDiff;u&&isFinite(u)&&(i=Math.min(i,u))}}for(i===1/0&&(i=1),a=0;a<s.length;a++)s[a]._minDiff=i}return i*r.tickwidth}(t,r,e),c=e._minDiff;e._minDiff=null;var u=e._xcalc;e._xcalc=null;var h=l(t,e,u,i,s);return e._extremes[r._id]=a.findExtremes(r,u,{vpad:c/2}),h.length?(n.extendFlat(h[0].t,{wHover:c/2,tickLen:o}),h):[{t:{empty:!0}}]},calcCommon:l}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],1060:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./ohlc_defaults\"),a=t(\"./attributes\");function o(t,e,r,n){r(n+\".line.color\"),r(n+\".line.width\",e.line.width),r(n+\".line.dash\",e.line.dash)}e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,a,r,i)}i(t,e,l,s)?(l(\"line.width\"),l(\"line.dash\"),o(t,e,l,\"increasing\"),o(t,e,l,\"decreasing\"),l(\"text\"),l(\"hovertext\"),l(\"tickwidth\"),s._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../lib\":719,\"./attributes\":1058,\"./ohlc_defaults\":1063}],1061:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\").fillText,l=t(\"../../constants/delta.js\"),c={increasing:l.INCREASING.SYMBOL,decreasing:l.DECREASING.SYMBOL};function u(t,e,r,n){var i,s,l=t.cd,c=t.xa,u=l[0].trace,h=l[0].t,f=u.type,p=\"ohlc\"===f?\"l\":\"min\",d=\"ohlc\"===f?\"h\":\"max\",g=h.bPos||0,v=function(t){return t.pos+g-e},m=h.bdPos||h.tickLen,y=h.wHover,x=Math.min(1,m/Math.abs(c.r2c(c.range[1])-c.r2c(c.range[0])));function b(t){var e=v(t);return a.inbox(e-y,e+y,i)}function _(t){var e=t[p],n=t[d];return e===n||a.inbox(e-r,n-r,i)}function w(t){return(b(t)+_(t))/2}i=t.maxHoverDistance-x,s=t.maxSpikeDistance-x;var k=a.getDistanceFunction(n,b,_,w);if(a.getClosest(l,k,t),!1===t.index)return null;var T=l[t.index];if(T.empty)return null;var A=u[T.dir],M=A.line.color;return o.opacity(M)&&A.line.width?t.color=M:t.color=A.fillcolor,t.x0=c.c2p(T.pos+g-m,!0),t.x1=c.c2p(T.pos+g+m,!0),t.xLabelVal=T.pos,t.spikeDistance=w(T)*s/i,t.xSpike=c.c2p(T.pos,!0),t}function h(t,e,r,a){var o=t.cd,s=t.ya,l=o[0].trace,c=o[0].t,h=[],f=u(t,e,r,a);if(!f)return[];var p=o[f.index].hi||l.hoverinfo,d=p.split(\"+\");if(!(\"all\"===p||-1!==d.indexOf(\"y\")))return[];for(var g=[\"high\",\"open\",\"close\",\"low\"],v={},m=0;m<g.length;m++){var y,x=g[m],b=l[x][f.index],_=s.c2p(b,!0);b in v?(y=v[b]).yLabel+=\"<br>\"+c.labels[x]+n.hoverLabelText(s,b):((y=i.extendFlat({},f)).y0=y.y1=_,y.yLabelVal=b,y.yLabel=c.labels[x]+n.hoverLabelText(s,b),y.name=\"\",h.push(y),v[b]=y)}return h}function f(t,e,r,i){var a=t.cd,o=t.ya,l=a[0].trace,h=a[0].t,f=u(t,e,r,i);if(!f)return[];var p=a[f.index],d=f.index=p.i,g=p.dir;function v(t){return h.labels[t]+n.hoverLabelText(o,l[t][d])}var m=p.hi||l.hoverinfo,y=m.split(\"+\"),x=\"all\"===m,b=x||-1!==y.indexOf(\"y\"),_=x||-1!==y.indexOf(\"text\"),w=b?[v(\"open\"),v(\"high\"),v(\"low\"),v(\"close\")+\"  \"+c[g]]:[];return _&&s(p,l,w),f.extraText=w.join(\"<br>\"),f.y0=f.y1=o.c2p(p.yc,!0),[f]}e.exports={hoverPoints:function(t,e,r,n){return t.cd[0].trace.hoverlabel.split?h(t,e,r,n):f(t,e,r,n)},hoverSplit:h,hoverOnPoints:f}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../constants/delta.js\":689,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],1062:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"ohlc\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\"],meta:{},attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\").calc,plot:t(\"./plot\"),style:t(\"./style\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\")}},{\"../../plots/cartesian\":778,\"./attributes\":1058,\"./calc\":1059,\"./defaults\":1060,\"./hover\":1061,\"./plot\":1064,\"./select\":1065,\"./style\":1066}],1063:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"open\"),l=r(\"high\"),c=r(\"low\"),u=r(\"close\");if(r(\"hoverlabel.split\"),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\"],a),s&&l&&c&&u){var h=Math.min(s.length,l.length,c.length,u.length);return o&&(h=Math.min(h,i.minRowLength(o))),e._length=h,h}}},{\"../../lib\":719,\"../../registry\":847}],1064:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=e.xaxis,s=e.yaxis;i.makeTraceGroups(a,r,\"trace ohlc\").each(function(t){var e=n.select(this),r=t[0],a=r.t;if(!0!==r.trace.visible||a.empty)e.remove();else{var l=a.tickLen,c=e.selectAll(\"path\").data(i.identity);c.enter().append(\"path\"),c.exit().remove(),c.attr(\"d\",function(t){if(t.empty)return\"M0,0Z\";var e=o.c2p(t.pos,!0),r=o.c2p(t.pos-l,!0),n=o.c2p(t.pos+l,!0);return\"M\"+r+\",\"+s.c2p(t.o,!0)+\"H\"+e+\"M\"+e+\",\"+s.c2p(t.h,!0)+\"V\"+s.c2p(t.l,!0)+\"M\"+n+\",\"+s.c2p(t.c,!0)+\"H\"+e})}})}},{\"../../lib\":719,d3:163}],1065:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n=t.cd,i=t.xaxis,a=t.yaxis,o=[],s=n[0].t.bPos||0;if(!1===e)for(r=0;r<n.length;r++)n[r].selected=0;else for(r=0;r<n.length;r++){var l=n[r];e.contains([i.c2p(l.pos+s),a.c2p(l.yc)],null,l.i,t)?(o.push({pointNumber:l.i,x:i.c2d(l.pos),y:a.c2d(l.yc)}),l.selected=1):l.selected=0}return o}},{}],1066:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\");e.exports=function(t,e,r){var o=r||n.select(t).selectAll(\"g.ohlclayer\").selectAll(\"g.trace\");o.style(\"opacity\",function(t){return t[0].trace.opacity}),o.each(function(t){var e=t[0].trace;n.select(this).selectAll(\"path\").each(function(t){if(!t.empty){var r=e[t.dir].line;n.select(this).style(\"fill\",\"none\").call(a.stroke,r.color).call(i.dashLine,r.dash,r.width).style(\"opacity\",e.selectedpoints&&!t.selected?.3:1)}})})}},{\"../../components/color\":593,\"../../components/drawing\":614,d3:163}],1067:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../plots/attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/fx/hovertemplate_attributes\"),l=t(\"../../plots/domain\").attributes,c=n({editType:\"calc\"},o(\"line\",{editTypeOverride:\"calc\"}),{shape:{valType:\"enumerated\",values:[\"linear\",\"hspline\"],dflt:\"linear\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\"]})});e.exports={domain:l({name:\"parcats\",trace:!0,editType:\"calc\"}),hoverinfo:n({},i.hoverinfo,{flags:[\"count\",\"probability\"],editType:\"plot\",arrayOk:!1}),hoveron:{valType:\"enumerated\",values:[\"category\",\"color\",\"dimension\"],dflt:\"category\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\",\"category\",\"categorycount\",\"colorcount\",\"bandcolorcount\"]}),arrangement:{valType:\"enumerated\",values:[\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"perpendicular\",editType:\"plot\"},bundlecolors:{valType:\"boolean\",dflt:!0,editType:\"plot\"},sortpaths:{valType:\"enumerated\",values:[\"forward\",\"backward\"],dflt:\"forward\",editType:\"plot\"},labelfont:a({editType:\"calc\"}),tickfont:a({editType:\"calc\"}),dimensions:{_isLinkedToArray:\"dimension\",label:{valType:\"string\",editType:\"calc\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",dflt:[],editType:\"calc\"},displayindex:{valType:\"integer\",editType:\"calc\"},editType:\"calc\",visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"}},line:c,counts:{valType:\"number\",min:0,dflt:1,arrayOk:!0,editType:\"calc\"},customdata:void 0,hoverlabel:void 0,ids:void 0,legendgroup:void 0,opacity:void 0,selectedpoints:void 0,showlegend:void 0}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1068:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"parcats\",r.plot=function(t,e,r,a){var o=n(t.calcdata,\"parcats\");if(o.length){var s=o[0];i(t,s,r,a)}},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcats\"),a=e._has&&e._has(\"parcats\");i&&!a&&n._paperdiv.selectAll(\".parcats\").remove()}},{\"../../plots/get_data\":802,\"./plot\":1073}],1069:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),o=t(\"../../lib/filter_unique.js\"),s=t(\"../../components/drawing\"),l=t(\"../../lib\");function c(t,e,r){t.valueInds.push(e),t.count+=r}function u(t,e,r){t.valueInds.push(e),t.count+=r}e.exports=function(t,e){var r=l.filterVisible(e.dimensions);if(0===r.length)return[];var h,f,p,d=r.map(function(t){var e;return\"trace\"===t.categoryorder?e=null:\"array\"===t.categoryorder?e=t.categoryarray:(e=o(t.values).sort(),\"category descending\"===t.categoryorder&&(e=e.reverse())),function(t,e){e=null==e?[]:e.map(function(t){return t});var r={},n={},i=[];e.forEach(function(t,e){r[t]=0,n[t]=e});for(var a=0;a<t.length;a++){var o,s=t[a];void 0===r[s]?(r[s]=1,o=e.push(s)-1,n[s]=o):(r[s]++,o=n[s]),i.push(o)}var l=e.map(function(t){return r[t]});return{uniqueValues:e,uniqueCounts:l,inds:i}}(t.values,e)});h=l.isArrayOrTypedArray(e.counts)?e.counts:[e.counts],function(t){var e;if(function(t){for(var e=new Array(t.length),r=0;r<t.length;r++){if(t[r]<0||t[r]>=t.length)return!1;if(void 0!==e[t[r]])return!1;e[t[r]]=!0}return!0}(t.map(function(t){return t.displayindex})))for(e=0;e<t.length;e++)t[e]._displayindex=t[e].displayindex;else for(e=0;e<t.length;e++)t[e]._displayindex=e}(r),r.forEach(function(t,e){!function(t,e){t._categoryarray=e.uniqueValues,null===t.ticktext||void 0===t.ticktext?t._ticktext=[]:t._ticktext=t.ticktext.slice();for(var r=t._ticktext.length;r<e.uniqueValues.length;r++)t._ticktext.push(e.uniqueValues[r])}(t,d[e])});var g,v=e.line;v?(i(e,\"line\")&&a(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),g=s.tryColorscale(v)):g=l.identity;var m,y,x,b,_=r[0].values.length,w={},k=d.map(function(t){return t.inds});for(p=0,m=0;m<_;m++){var T=[];for(y=0;y<k.length;y++)T.push(k[y][m]);f=h[m%h.length],p+=f;var A=(x=m,b=void 0,b=l.isArrayOrTypedArray(v.color)?v.color[x%v.color.length]:v.color,{color:g(b),rawColor:b}),M=T+\"-\"+A.rawColor;void 0===w[M]&&(w[M]={categoryInds:T,color:A.color,rawColor:A.rawColor,valueInds:[],count:0}),u(w[M],m,f)}var S,E=r.map(function(t,e){return r=e,n=t._index,i=t._displayindex,a=t.label,{dimensionInd:r,containerInd:n,displayInd:i,dimensionLabel:a,count:p,categories:[],dragX:null};var r,n,i,a});for(m=0;m<_;m++)for(f=h[m%h.length],y=0;y<E.length;y++){var C=E[y].containerInd,L=d[y].inds[m],P=E[y].categories;if(void 0===P[L]){var O=e.dimensions[C]._categoryarray[L],z=e.dimensions[C]._ticktext[L];P[L]={dimensionInd:y,categoryInd:S=L,categoryValue:O,displayInd:S,categoryLabel:z,valueInds:[],count:0,dragY:null}}c(P[L],m,f)}return n(function(t,e,r){var n=t.map(function(t){return t.categories.length}).reduce(function(t,e){return Math.max(t,e)});return{dimensions:t,paths:e,trace:void 0,maxCats:n,count:r}}(E,w,p))}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/filter_unique.js\":711,\"../../lib/gup\":717}],1070:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"./attributes\"),c=t(\"../parcoords/merge_length\");function u(t,e){function r(r,i){return n.coerce(t,e,l.dimensions,r,i)}var i=r(\"values\"),a=r(\"visible\");if(i&&i.length||(a=e.visible=!1),a){r(\"label\"),r(\"displayindex\",e._index);var o,s=t.categoryarray,c=Array.isArray(s)&&s.length>0;c&&(o=\"array\");var u=r(\"categoryorder\",o);\"array\"===u?(r(\"categoryarray\"),r(\"ticktext\")):(delete t.categoryarray,delete t.ticktext),c||\"array\"!==u||(e.categoryorder=\"trace\")}}e.exports=function(t,e,r,h){function f(r,i){return n.coerce(t,e,l,r,i)}var p=s(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=function(t,e,r,o,s){s(\"line.shape\"),s(\"line.hovertemplate\");var l=s(\"line.color\",o.colorway[0]);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,h,f);o(e,h,f),Array.isArray(p)&&p.length||(e.visible=!1),c(e,p,\"values\",d),f(\"hoveron\"),f(\"hovertemplate\"),f(\"arrangement\"),f(\"bundlecolors\"),f(\"sortpaths\"),f(\"counts\");var g={family:h.font.family,size:Math.round(h.font.size),color:h.font.color};n.coerceFont(f,\"labelfont\",g);var v={family:h.font.family,size:Math.round(h.font.size/1.2),color:h.font.color};n.coerceFont(f,\"tickfont\",v)}},{\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/domain\":792,\"../parcoords/merge_length\":1083,\"./attributes\":1067}],1071:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcats\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1067,\"./base_plot\":1068,\"./calc\":1069,\"./defaults\":1070,\"./plot\":1073}],1072:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plot_api/plot_api\"),a=t(\"../../components/fx\"),o=t(\"../../lib\"),s=t(\"../../components/drawing\"),l=t(\"tinycolor2\"),c=t(\"../../lib/svg_text_utils\");function u(t,e,r,i){var a=t.map(function(t,e,r){var n,i=r[0],a=e.margin||{l:80,r:80,t:100,b:80},o=i.trace,s=o.domain,l=e.width,c=e.height,u=Math.floor(l*(s.x[1]-s.x[0])),h=Math.floor(c*(s.y[1]-s.y[0])),f=s.x[0]*l+a.l,p=e.height-s.y[1]*e.height+a.t,d=o.line.shape;n=\"all\"===o.hoverinfo?[\"count\",\"probability\"]:(o.hoverinfo||\"\").split(\"+\");var g={trace:o,key:o.uid,model:i,x:f,y:p,width:u,height:h,hoveron:o.hoveron,hoverinfoItems:n,arrangement:o.arrangement,bundlecolors:o.bundlecolors,sortpaths:o.sortpaths,labelfont:o.labelfont,categorylabelfont:o.tickfont,pathShape:d,dragDimension:null,margin:a,paths:[],dimensions:[],graphDiv:t,traceSelection:null,pathSelection:null,dimensionSelection:null};i.dimensions&&(R(g),D(g));return g}.bind(0,e,r)),l=i.selectAll(\"g.parcatslayer\").data([null]);l.enter().append(\"g\").attr(\"class\",\"parcatslayer\").style(\"pointer-events\",\"all\");var u=l.selectAll(\"g.trace.parcats\").data(a,h),v=u.enter().append(\"g\").attr(\"class\",\"trace parcats\");u.attr(\"transform\",function(t){return\"translate(\"+t.x+\", \"+t.y+\")\"}),v.append(\"g\").attr(\"class\",\"paths\");var x=u.select(\"g.paths\").selectAll(\"path.path\").data(function(t){return t.paths},h);x.attr(\"fill\",function(t){return t.model.color});var w=x.enter().append(\"path\").attr(\"class\",\"path\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.model.color}).attr(\"fill-opacity\",0);y(w),x.attr(\"d\",function(t){return t.svgD}),w.empty()||x.sort(p),x.exit().remove(),x.on(\"mouseover\",d).on(\"mouseout\",g).on(\"click\",m),v.append(\"g\").attr(\"class\",\"dimensions\");var k=u.select(\"g.dimensions\").selectAll(\"g.dimension\").data(function(t){return t.dimensions},h);k.enter().append(\"g\").attr(\"class\",\"dimension\"),k.attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),k.exit().remove();var T=k.selectAll(\"g.category\").data(function(t){return t.categories},h),A=T.enter().append(\"g\").attr(\"class\",\"category\");T.attr(\"transform\",function(t){return\"translate(0, \"+t.y+\")\"}),A.append(\"rect\").attr(\"class\",\"catrect\").attr(\"pointer-events\",\"none\"),T.select(\"rect.catrect\").attr(\"fill\",\"none\").attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}),b(A);var P=T.selectAll(\"rect.bandrect\").data(function(t){return t.bands},h);P.each(function(){o.raiseToTop(this)}),P.attr(\"fill\",function(t){return t.color});var O=P.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.color}).attr(\"fill-opacity\",0);P.attr(\"fill\",function(t){return t.color}).attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}).attr(\"y\",function(t){return t.y}).attr(\"cursor\",function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"perpendicular\"===t.parcatsViewModel.arrangement?\"ns-resize\":\"move\"}),_(O),P.exit().remove(),A.append(\"text\").attr(\"class\",\"catlabel\").attr(\"pointer-events\",\"none\");var z=e._fullLayout.paper_bgcolor;T.select(\"text.catlabel\").attr(\"text-anchor\",function(t){return f(t)?\"start\":\"end\"}).attr(\"alignment-baseline\",\"middle\").style(\"text-shadow\",z+\" -1px  1px 2px, \"+z+\" 1px  1px 2px, \"+z+\"  1px -1px 2px, \"+z+\" -1px -1px 2px\").style(\"fill\",\"rgb(0, 0, 0)\").attr(\"x\",function(t){return f(t)?t.width+5:-5}).attr(\"y\",function(t){return t.height/2}).text(function(t){return t.model.categoryLabel}).each(function(t){s.font(n.select(this),t.parcatsViewModel.categorylabelfont),c.convertToTspans(n.select(this),e)}),A.append(\"text\").attr(\"class\",\"dimlabel\"),T.select(\"text.dimlabel\").attr(\"text-anchor\",\"middle\").attr(\"alignment-baseline\",\"baseline\").attr(\"cursor\",function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"ew-resize\"}).attr(\"x\",function(t){return t.width/2}).attr(\"y\",-5).text(function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null}).each(function(t){s.font(n.select(this),t.parcatsViewModel.labelfont)}),T.selectAll(\"rect.bandrect\").on(\"mouseover\",M).on(\"mouseout\",S),T.exit().remove(),k.call(n.behavior.drag().origin(function(t){return{x:t.x,y:0}}).on(\"dragstart\",E).on(\"drag\",C).on(\"dragend\",L)),u.each(function(t){t.traceSelection=n.select(this),t.pathSelection=n.select(this).selectAll(\"g.paths\").selectAll(\"path.path\"),t.dimensionSelection=n.select(this).selectAll(\"g.dimensions\").selectAll(\"g.dimension\")}),u.exit().remove()}function h(t){return t.key}function f(t){var e=t.parcatsViewModel.dimensions.length,r=t.parcatsViewModel.dimensions[e-1].model.dimensionInd;return t.model.dimensionInd===r}function p(t,e){return t.model.rawColor>e.model.rawColor?1:t.model.rawColor<e.model.rawColor?-1:0}function d(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){o.raiseToTop(this),x(n.select(this));var e=v(t);if(t.parcatsViewModel.graphDiv.emit(\"plotly_hover\",{points:e,event:n.event}),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\")){var r,i,s,c=n.mouse(this)[0],u=t.parcatsViewModel.graphDiv,h=t.parcatsViewModel.trace,f=u._fullLayout,p=f._paperdiv.node().getBoundingClientRect(),d=t.parcatsViewModel.graphDiv.getBoundingClientRect();for(s=0;s<t.leftXs.length-1;s++)if(t.leftXs[s]+t.dimWidths[s]-2<=c&&c<=t.leftXs[s+1]+2){var g=t.parcatsViewModel.dimensions[s],m=t.parcatsViewModel.dimensions[s+1];r=(g.x+g.width+m.x)/2,i=(t.topYs[s]+t.topYs[s+1]+t.height)/2;break}var y=t.parcatsViewModel.x+r,b=t.parcatsViewModel.y+i,_=l.mostReadable(t.model.color,[\"black\",\"white\"]),w=t.model.count,k=w/t.parcatsViewModel.model.count,T={countLabel:w,probabilityLabel:k.toFixed(3)},A=[];-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&A.push([\"Count:\",T.countLabel].join(\" \")),-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&A.push([\"P:\",T.probabilityLabel].join(\" \"));var M=A.join(\"<br>\"),S=n.mouse(u)[0];a.loneHover({trace:h,x:y-p.left+d.left,y:b-p.top+d.top,text:M,color:t.model.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:10,fontColor:_,idealAlign:S<y?\"right\":\"left\",hovertemplate:(h.line||{}).hovertemplate,hovertemplateLabels:T,eventData:[{data:h._input,fullData:h,count:w,probability:k}]},{container:f._hoverlayer.node(),outerContainer:f._paper.node(),gd:u})}}}function g(t){if(!t.parcatsViewModel.dragDimension&&(y(n.select(this)),a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()),t.parcatsViewModel.pathSelection.sort(p),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\"))){var e=v(t);t.parcatsViewModel.graphDiv.emit(\"plotly_unhover\",{points:e,event:n.event})}}function v(t){for(var e=[],r=P(t.parcatsViewModel),n=0;n<t.model.valueInds.length;n++){var i=t.model.valueInds[n];e.push({curveNumber:r,pointNumber:i})}return e}function m(t){if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){var e=v(t);t.parcatsViewModel.graphDiv.emit(\"plotly_click\",{points:e,event:n.event})}}function y(t){t.attr(\"fill\",function(t){return t.model.color}).attr(\"fill-opacity\",.6).attr(\"stroke\",\"lightgray\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1)}function x(t){t.attr(\"fill-opacity\",.8).attr(\"stroke\",function(t){return l.mostReadable(t.model.color,[\"black\",\"white\"])}).attr(\"stroke-width\",.3)}function b(t){t.select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",1).attr(\"stroke-opacity\",1)}function _(t){t.attr(\"stroke\",\"black\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1).attr(\"fill-opacity\",1)}function w(t){var e=t.parcatsViewModel.pathSelection,r=t.categoryViewModel.model.dimensionInd,n=t.categoryViewModel.model.categoryInd;return e.filter(function(e){return e.model.categoryInds[r]===n&&e.model.color===t.color})}function k(t,e,r){var i=n.select(t).datum().parcatsViewModel.graphDiv,a=n.select(t.parentNode).selectAll(\"rect.bandrect\"),o=[];a.each(function(t){w(t).each(function(t){Array.prototype.push.apply(o,v(t))})}),i.emit(e,{points:o,event:r})}function T(t,e,r){var i=n.select(t).datum(),a=i.parcatsViewModel.graphDiv,o=w(i),s=[];o.each(function(t){Array.prototype.push.apply(s,v(t))}),a.emit(e,{points:s,event:r})}function A(t,e){var r,i,a=n.select(e.parentNode).select(\"rect.catrect\"),o=a.node().getBoundingClientRect(),s=a.datum(),l=s.parcatsViewModel,c=l.model.dimensions[s.model.dimensionInd],u=l.trace,h=o.top+o.height/2;l.dimensions.length>1&&c.displayInd===l.dimensions.length-1?(r=o.left,i=\"left\"):(r=o.left+o.width,i=\"right\");var f=s.model.count,p=s.model.categoryLabel,d=f/s.parcatsViewModel.model.count,g={countLabel:f,categoryLabel:p,probabilityLabel:d.toFixed(3)},v=[];-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&v.push([\"Count:\",g.countLabel].join(\" \")),-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&v.push([\"P(\"+g.categoryLabel+\"):\",g.probabilityLabel].join(\" \"));var m=v.join(\"<br>\");return{trace:u,x:r-t.left,y:h-t.top,text:m,color:\"lightgray\",borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:12,fontColor:\"black\",idealAlign:i,hovertemplate:u.hovertemplate,hovertemplateLabels:g,eventData:[{data:u._input,fullData:u,count:f,category:p,probability:d}]}}function M(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){if(n.mouse(this)[1]<-1)return;var e,r=t.parcatsViewModel.graphDiv,i=r._fullLayout,s=i._paperdiv.node().getBoundingClientRect(),c=t.parcatsViewModel.hoveron;if(\"color\"===c?(!function(t){var e=n.select(t).datum(),r=w(e);x(r),r.each(function(){o.raiseToTop(this)}),n.select(t.parentNode).selectAll(\"rect.bandrect\").filter(function(t){return t.color===e.color}).each(function(){o.raiseToTop(this),n.select(this).attr(\"stroke\",\"black\").attr(\"stroke-width\",1.5)})}(this),T(this,\"plotly_hover\",n.event)):(!function(t){n.select(t.parentNode).selectAll(\"rect.bandrect\").each(function(t){var e=w(t);x(e),e.each(function(){o.raiseToTop(this)})}),n.select(t.parentNode).select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",2.5)}(this),k(this,\"plotly_hover\",n.event)),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\"))\"category\"===c?e=A(s,this):\"color\"===c?e=function(t,e){var r,i,a=e.getBoundingClientRect(),o=n.select(e).datum(),s=o.categoryViewModel,c=s.parcatsViewModel,u=c.model.dimensions[s.model.dimensionInd],h=c.trace,f=a.y+a.height/2;c.dimensions.length>1&&u.displayInd===c.dimensions.length-1?(r=a.left,i=\"left\"):(r=a.left+a.width,i=\"right\");var p=s.model.categoryLabel,d=o.parcatsViewModel.model.count,g=0;o.categoryViewModel.bands.forEach(function(t){t.color===o.color&&(g+=t.count)});var v=s.model.count,m=0;c.pathSelection.each(function(t){t.model.color===o.color&&(m+=t.model.count)});var y=g/d,x=g/m,b=g/v,_={countLabel:d,categoryLabel:p,probabilityLabel:y.toFixed(3)},w=[];-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&w.push([\"Count:\",_.countLabel].join(\" \")),-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&(w.push(\"P(color \\u2229 \"+p+\"): \"+_.probabilityLabel),w.push(\"P(\"+p+\" | color): \"+x.toFixed(3)),w.push(\"P(color | \"+p+\"): \"+b.toFixed(3)));var k=w.join(\"<br>\"),T=l.mostReadable(o.color,[\"black\",\"white\"]);return{trace:h,x:r-t.left,y:f-t.top,text:k,color:o.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontColor:T,fontSize:10,idealAlign:i,hovertemplate:h.hovertemplate,hovertemplateLabels:_,eventData:[{data:h._input,fullData:h,category:p,count:d,probability:y,categorycount:v,colorcount:m,bandcolorcount:g}]}}(s,this):\"dimension\"===c&&(e=function(t,e){var r=[];return n.select(e.parentNode.parentNode).selectAll(\"g.category\").select(\"rect.catrect\").each(function(){r.push(A(t,this))}),r}(s,this)),e&&a.loneHover(e,{container:i._hoverlayer.node(),outerContainer:i._paper.node(),gd:r})}}function S(t){var e=t.parcatsViewModel;if(!e.dragDimension&&(y(e.pathSelection),b(e.dimensionSelection.selectAll(\"g.category\")),_(e.dimensionSelection.selectAll(\"g.category\").selectAll(\"rect.bandrect\")),a.loneUnhover(e.graphDiv._fullLayout._hoverlayer.node()),e.pathSelection.sort(p),-1===e.hoverinfoItems.indexOf(\"skip\"))){\"color\"===t.parcatsViewModel.hoveron?T(this,\"plotly_unhover\",n.event):k(this,\"plotly_unhover\",n.event)}}function E(t){\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragDimensionDisplayInd=t.model.displayInd,t.initialDragDimensionDisplayInds=t.parcatsViewModel.model.dimensions.map(function(t){return t.displayInd}),t.dragHasMoved=!1,t.dragCategoryDisplayInd=null,n.select(this).selectAll(\"g.category\").select(\"rect.catrect\").each(function(e){var r=n.mouse(this)[0],i=n.mouse(this)[1];-2<=r&&r<=e.width+2&&-2<=i&&i<=e.height+2&&(t.dragCategoryDisplayInd=e.model.displayInd,t.initialDragCategoryDisplayInds=t.model.categories.map(function(t){return t.displayInd}),e.model.dragY=e.y,o.raiseToTop(this.parentNode),n.select(this.parentNode).selectAll(\"rect.bandrect\").each(function(e){e.y<i&&i<=e.y+e.height&&(t.potentialClickBand=this)}))}),t.parcatsViewModel.dragDimension=t,a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()))}function C(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragHasMoved=!0,null!==t.dragDimensionDisplayInd)){var e=t.dragDimensionDisplayInd,r=e-1,i=e+1,a=t.parcatsViewModel.dimensions[e];if(null!==t.dragCategoryDisplayInd){var o=a.categories[t.dragCategoryDisplayInd];o.model.dragY+=n.event.dy;var s=o.model.dragY,l=o.model.displayInd,c=a.categories,u=c[l-1],h=c[l+1];void 0!==u&&s<u.y+u.height/2&&(o.model.displayInd=u.model.displayInd,u.model.displayInd=l),void 0!==h&&s+o.height>h.y+h.height/2&&(o.model.displayInd=h.model.displayInd,h.model.displayInd=l),t.dragCategoryDisplayInd=o.model.displayInd}if(null===t.dragCategoryDisplayInd||\"freeform\"===t.parcatsViewModel.arrangement){a.model.dragX=n.event.x;var f=t.parcatsViewModel.dimensions[r],p=t.parcatsViewModel.dimensions[i];void 0!==f&&a.model.dragX<f.x+f.width&&(a.model.displayInd=f.model.displayInd,f.model.displayInd=e),void 0!==p&&a.model.dragX+a.width>p.x&&(a.model.displayInd=p.model.displayInd,p.model.displayInd=t.dragDimensionDisplayInd),t.dragDimensionDisplayInd=a.model.displayInd}R(t.parcatsViewModel),D(t.parcatsViewModel),z(t.parcatsViewModel),O(t.parcatsViewModel)}}function L(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&null!==t.dragDimensionDisplayInd){n.select(this).selectAll(\"text\").attr(\"font-weight\",\"normal\");var e={},r=P(t.parcatsViewModel),a=t.parcatsViewModel.model.dimensions.map(function(t){return t.displayInd}),o=t.initialDragDimensionDisplayInds.some(function(t,e){return t!==a[e]});o&&a.forEach(function(r,n){var i=t.parcatsViewModel.model.dimensions[n].containerInd;e[\"dimensions[\"+i+\"].displayindex\"]=r});var s=!1;if(null!==t.dragCategoryDisplayInd){var l=t.model.categories.map(function(t){return t.displayInd});if(s=t.initialDragCategoryDisplayInds.some(function(t,e){return t!==l[e]})){var c=t.model.categories.slice().sort(function(t,e){return t.displayInd-e.displayInd}),u=c.map(function(t){return t.categoryValue}),h=c.map(function(t){return t.categoryLabel});e[\"dimensions[\"+t.model.containerInd+\"].categoryarray\"]=[u],e[\"dimensions[\"+t.model.containerInd+\"].ticktext\"]=[h],e[\"dimensions[\"+t.model.containerInd+\"].categoryorder\"]=\"array\"}}if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")&&!t.dragHasMoved&&t.potentialClickBand&&(\"color\"===t.parcatsViewModel.hoveron?T(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent):k(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent)),t.model.dragX=null,null!==t.dragCategoryDisplayInd)t.parcatsViewModel.dimensions[t.dragDimensionDisplayInd].categories[t.dragCategoryDisplayInd].model.dragY=null,t.dragCategoryDisplayInd=null;t.dragDimensionDisplayInd=null,t.parcatsViewModel.dragDimension=null,t.dragHasMoved=null,t.potentialClickBand=null,R(t.parcatsViewModel),D(t.parcatsViewModel),n.transition().duration(300).ease(\"cubic-in-out\").each(function(){z(t.parcatsViewModel,!0),O(t.parcatsViewModel,!0)}).each(\"end\",function(){(o||s)&&i.restyle(t.parcatsViewModel.graphDiv,e,[r])})}}function P(t){for(var e,r=t.graphDiv._fullData,n=0;n<r.length;n++)if(t.key===r[n].uid){e=n;break}return e}function O(t,e){var r;void 0===e&&(e=!1),t.pathSelection.data(function(t){return t.paths},h),(r=t.pathSelection,e?r.transition():r).attr(\"d\",function(t){return t.svgD})}function z(t,e){function r(t){return e?t.transition():t}void 0===e&&(e=!1),t.dimensionSelection.data(function(t){return t.dimensions},h);var i=t.dimensionSelection.selectAll(\"g.category\").data(function(t){return t.categories},h);r(t.dimensionSelection).attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),r(i).attr(\"transform\",function(t){return\"translate(0, \"+t.y+\")\"}),i.select(\".dimlabel\").text(function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null}),i.select(\".catlabel\").attr(\"text-anchor\",function(t){return f(t)?\"start\":\"end\"}).attr(\"x\",function(t){return f(t)?t.width+5:-5}).each(function(t){var e,r;f(t)?(e=t.width+5,r=\"start\"):(e=-5,r=\"end\"),n.select(this).selectAll(\"tspan\").attr(\"x\",e).attr(\"text-anchor\",r)});var a=i.selectAll(\"rect.bandrect\").data(function(t){return t.bands},h),s=a.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"cursor\",\"move\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.color}).attr(\"fill-opacity\",0);a.attr(\"fill\",function(t){return t.color}).attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}).attr(\"y\",function(t){return t.y}),_(s),a.each(function(){o.raiseToTop(this)}),a.exit().remove()}function I(t,e,r,i,a){var o,s,l=[],c=[];for(s=0;s<r.length-1;s++)o=n.interpolateNumber(r[s]+t[s],t[s+1]),l.push(o(a)),c.push(o(1-a));var u=\"M \"+t[0]+\",\"+e[0];for(u+=\"l\"+r[0]+\",0 \",s=1;s<r.length;s++)u+=\"C\"+l[s-1]+\",\"+e[s-1]+\" \"+c[s-1]+\",\"+e[s]+\" \"+t[s]+\",\"+e[s],u+=\"l\"+r[s]+\",0 \";for(u+=\"l0,\"+i+\" \",u+=\"l -\"+r[r.length-1]+\",0 \",s=r.length-2;s>=0;s--)u+=\"C\"+c[s]+\",\"+(e[s+1]+i)+\" \"+l[s]+\",\"+(e[s]+i)+\" \"+(t[s]+r[s])+\",\"+(e[s]+i),u+=\"l-\"+r[s]+\",0 \";return u+=\"Z\"}function D(t){var e=t.dimensions,r=t.model,n=e.map(function(t){return t.categories.map(function(t){return t.y})}),i=t.model.dimensions.map(function(t){return t.categories.map(function(t){return t.displayInd})}),a=t.model.dimensions.map(function(t){return t.displayInd}),o=t.dimensions.map(function(t){return t.model.dimensionInd}),s=e.map(function(t){return t.x}),l=e.map(function(t){return t.width}),c=[];for(var u in r.paths)r.paths.hasOwnProperty(u)&&c.push(r.paths[u]);function h(t){var e=t.categoryInds.map(function(t,e){return i[e][t]});return o.map(function(t){return e[t]})}c.sort(function(e,r){var n=h(e),i=h(r);return\"backward\"===t.sortpaths&&(n.reverse(),i.reverse()),n.push(e.valueInds[0]),i.push(r.valueInds[0]),t.bundlecolors&&(n.unshift(e.rawColor),i.unshift(r.rawColor)),n<i?-1:n>i?1:0});for(var f=new Array(c.length),p=e[0].model.count,d=e[0].categories.map(function(t){return t.height}).reduce(function(t,e){return t+e}),g=0;g<c.length;g++){var v,m=c[g];v=p>0?d*(m.count/p):0;for(var y,x=new Array(n.length),b=0;b<m.categoryInds.length;b++){var _=m.categoryInds[b],w=i[b][_],k=a[b];x[k]=n[k][w],n[k][w]+=v;var T=t.dimensions[k].categories[w],A=T.bands.length,M=T.bands[A-1];if(void 0===M||m.rawColor!==M.rawColor){var S=void 0===M?0:M.y+M.height;T.bands.push({key:S,color:m.color,rawColor:m.rawColor,height:v,width:T.width,count:m.count,y:S,categoryViewModel:T,parcatsViewModel:t})}else{var E=T.bands[A-1];E.height+=v,E.count+=m.count}}y=\"hspline\"===t.pathShape?I(s,x,l,v,.5):I(s,x,l,v,0),f[g]={key:m.valueInds[0],model:m,height:v,leftXs:s,topYs:x,dimWidths:l,svgD:y,parcatsViewModel:t}}t.paths=f}function R(t){var e=t.model.dimensions.map(function(t){return{displayInd:t.displayInd,dimensionInd:t.dimensionInd}});e.sort(function(t,e){return t.displayInd-e.displayInd});var r=[];for(var n in e){var i=e[n].dimensionInd,a=t.model.dimensions[i];r.push(F(t,a))}t.dimensions=r}function F(t,e){var r,n=t.model.dimensions.length,i=e.displayInd;r=40+(n>1?(t.width-80-16)/(n-1):0)*i;var a,o,s,l,c,u=[],h=t.model.maxCats,f=e.categories.length,p=e.count,d=t.height-8*(h-1),g=8*(h-f)/2,v=e.categories.map(function(t){return{displayInd:t.displayInd,categoryInd:t.categoryInd}});for(v.sort(function(t,e){return t.displayInd-e.displayInd}),c=0;c<f;c++)l=v[c].categoryInd,o=e.categories[l],a=p>0?o.count/p*d:0,s={key:o.valueInds[0],model:o,width:16,height:a,y:null!==o.dragY?o.dragY:g,bands:[],parcatsViewModel:t},g=g+a+8,u.push(s);return{key:e.dimensionInd,x:null!==e.dragX?e.dragX:r,y:0,width:16,model:e,categories:u,parcatsViewModel:t,dragCategoryDisplayInd:null,dragDimensionDisplayInd:null,initialDragDimensionDisplayInds:null,initialDragCategoryDisplayInds:null,dragHasMoved:null,potentialClickBand:null}}e.exports=function(t,e,r,n){u(r,t,n,e)}},{\"../../components/drawing\":614,\"../../components/fx\":632,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_api\":754,d3:163,tinycolor2:537}],1073:[function(t,e,r){\"use strict\";var n=t(\"./parcats\");e.exports=function(t,e,r,i){var a=t._fullLayout,o=a._paper,s=a._size;n(t,o,e,{width:s.w,height:s.h,margin:{t:s.t,r:s.r,b:s.b,l:s.l}},r,i)}},{\"./parcats\":1072}],1074:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/cartesian/layout_attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../plots/domain\").attributes,s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/plot_template\").templatedArray;e.exports={domain:o({name:\"parcoords\",trace:!0,editType:\"plot\"}),labelangle:{valType:\"angle\",dflt:0,editType:\"plot\"},labelside:{valType:\"enumerated\",values:[\"top\",\"bottom\"],dflt:\"top\",editType:\"plot\"},labelfont:a({editType:\"plot\"}),tickfont:a({editType:\"plot\"}),rangefont:a({editType:\"plot\"}),dimensions:l(\"dimension\",{label:{valType:\"string\",editType:\"plot\"},tickvals:s({},i.tickvals,{editType:\"plot\"}),ticktext:s({},i.ticktext,{editType:\"plot\"}),tickformat:s({},i.tickformat,{editType:\"plot\"}),visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},constraintrange:{valType:\"info_array\",freeLength:!0,dimensions:\"1-2\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},multiselect:{valType:\"boolean\",dflt:!0,editType:\"plot\"},values:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"}),line:s({editType:\"calc\"},n(\"line\",{colorscaleDflt:\"Viridis\",autoColorDflt:!1,editTypeOverride:\"calc\"}))}},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1075:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\").keyFun,o=t(\"../../lib/gup\").repeat,s=t(\"../../lib\").sorterAsc,l=n.bar.snapRatio;function c(t,e){return t*(1-l)+e*l}var u=n.bar.snapClose;function h(t,e){return t*(1-u)+e*u}function f(t,e,r,n){if(function(t,e){for(var r=0;r<e.length;r++)if(t>=e[r][0]&&t<=e[r][1])return!0;return!1}(r,n))return r;var i=t?-1:1,a=0,o=e.length-1;if(i<0){var s=a;a=o,o=s}for(var l=e[a],u=l,f=a;i*f<i*o;f+=i){var p=f+i,d=e[p];if(i*r<i*h(l,d))return c(l,u);if(i*r<i*d||p===o)return c(d,l);u=l,l=d}}function p(t){t.attr(\"x\",-n.bar.captureWidth/2).attr(\"width\",n.bar.captureWidth)}function d(t){t.attr(\"visibility\",\"visible\").style(\"visibility\",\"visible\").attr(\"fill\",\"yellow\").attr(\"opacity\",0)}function g(t){if(!t.brush.filterSpecified)return\"0,\"+t.height;for(var e,r,n,i=v(t.brush.filter.getConsolidated(),t.height),a=[0],o=i.length?i[0][0]:null,s=0;s<i.length;s++)r=(e=i[s])[1]-e[0],a.push(o),a.push(r),(n=s+1)<i.length&&(o=i[n][0]-e[1]);return a.push(t.height),a}function v(t,e){return t.map(function(t){return t.map(function(t){return Math.max(0,t*e)}).sort(s)})}function m(){i.select(document.body).style(\"cursor\",null)}function y(t){t.attr(\"stroke-dasharray\",g)}function x(t,e){var r=i.select(t).selectAll(\".highlight, .highlight-shadow\");y(e?r.transition().duration(n.bar.snapDuration).each(\"end\",e):r)}function b(t,e){var r,i=t.brush,a=NaN,o={};if(i.filterSpecified){var s=t.height,l=i.filter.getConsolidated(),c=v(l,s),u=NaN,h=NaN,f=NaN;for(r=0;r<=c.length;r++){var p=c[r];if(p&&p[0]<=e&&e<=p[1]){u=r;break}if(h=r?r-1:NaN,p&&p[0]>e){f=r;break}}if(a=u,isNaN(a)&&(a=isNaN(h)||isNaN(f)?isNaN(h)?f:h:e-c[h][1]<c[f][0]-e?h:f),!isNaN(a)){var d=c[a],g=function(t,e){var r=n.bar.handleHeight;if(!(e>t[1]+r||e<t[0]-r))return e>=.9*t[1]+.1*t[0]?\"n\":e<=.9*t[0]+.1*t[1]?\"s\":\"ns\"}(d,e);g&&(o.interval=l[a],o.intervalPix=d,o.region=g)}}if(t.ordinal&&!o.region){var m=t.unitTickvals,y=t.unitToPaddedPx.invert(e);for(r=0;r<m.length;r++){var x=[.25*m[Math.max(r-1,0)]+.75*m[r],.25*m[Math.min(r+1,m.length-1)]+.75*m[r]];if(y>=x[0]&&y<=x[1]){o.clickableOrdinalRange=x;break}}}return o}function _(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.brush.svgBrush;a.wasDragged=!0,a._dragging=!0,a.grabbingBar?a.newExtent=[r-a.grabPoint,r+a.barLength-a.grabPoint].map(e.unitToPaddedPx.invert):a.newExtent=[a.startExtent,e.unitToPaddedPx.invert(r)].sort(s),e.brush.filterSpecified=!0,a.extent=a.stayingIntervals.concat([a.newExtent]),a.brushCallback(e),x(t.parentNode)}function w(t,e){var r=b(e,e.height-i.mouse(t)[1]-2*n.verticalPadding),a=\"crosshair\";r.clickableOrdinalRange?a=\"pointer\":r.region&&(a=r.region+\"-resize\"),i.select(document.body).style(\"cursor\",a)}function k(t){t.on(\"mousemove\",function(t){i.event.preventDefault(),t.parent.inBrushDrag||w(this,t)}).on(\"mouseleave\",function(t){t.parent.inBrushDrag||m()}).call(i.behavior.drag().on(\"dragstart\",function(t){!function(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.unitToPaddedPx.invert(r),o=e.brush,s=b(e,r),l=s.interval,c=o.svgBrush;if(c.wasDragged=!1,c.grabbingBar=\"ns\"===s.region,c.grabbingBar){var u=l.map(e.unitToPaddedPx);c.grabPoint=r-u[0]-n.verticalPadding,c.barLength=u[1]-u[0]}c.clickableOrdinalRange=s.clickableOrdinalRange,c.stayingIntervals=e.multiselect&&o.filterSpecified?o.filter.getConsolidated():[],l&&(c.stayingIntervals=c.stayingIntervals.filter(function(t){return t[0]!==l[0]&&t[1]!==l[1]})),c.startExtent=s.region?l[\"s\"===s.region?1:0]:a,e.parent.inBrushDrag=!0,c.brushStartCallback()}(this,t)}).on(\"drag\",function(t){_(this,t)}).on(\"dragend\",function(t){!function(t,e){var r=e.brush,n=r.filter,a=r.svgBrush;a._dragging||(w(t,e),_(t,e),e.brush.svgBrush.wasDragged=!1),a._dragging=!1,i.event.sourceEvent.stopPropagation();var o=a.grabbingBar;if(a.grabbingBar=!1,a.grabLocation=void 0,e.parent.inBrushDrag=!1,m(),!a.wasDragged)return a.wasDragged=void 0,a.clickableOrdinalRange?r.filterSpecified&&e.multiselect?a.extent.push(a.clickableOrdinalRange):(a.extent=[a.clickableOrdinalRange],r.filterSpecified=!0):o?(a.extent=a.stayingIntervals,0===a.extent.length&&A(r)):A(r),a.brushCallback(e),x(t.parentNode),void a.brushEndCallback(r.filterSpecified?n.getConsolidated():[]);var s=function(){n.set(n.getConsolidated())};if(e.ordinal){var l=e.unitTickvals;l[l.length-1]<l[0]&&l.reverse(),a.newExtent=[f(0,l,a.newExtent[0],a.stayingIntervals),f(1,l,a.newExtent[1],a.stayingIntervals)];var c=a.newExtent[1]>a.newExtent[0];a.extent=a.stayingIntervals.concat(c?[a.newExtent]:[]),a.extent.length||A(r),a.brushCallback(e),c?x(t.parentNode,s):(s(),x(t.parentNode))}else s();a.brushEndCallback(r.filterSpecified?n.getConsolidated():[])}(this,t)}))}function T(t,e){return t[0]-e[0]}function A(t){t.filterSpecified=!1,t.svgBrush.extent=[[-1/0,1/0]]}function M(t){for(var e,r=t.slice(),n=[],i=r.shift();i;){for(e=i.slice();(i=r.shift())&&i[0]<=e[1];)e[1]=Math.max(e[1],i[1]);n.push(e)}return n}e.exports={makeBrush:function(t,e,r,n,i,a){var o,l=function(){var t,e,r=[];return{set:function(n){1===(r=n.map(function(t){return t.slice().sort(s)}).sort(T)).length&&r[0][0]===-1/0&&r[0][1]===1/0&&(r=[[0,-1]]),t=M(r),e=r.reduce(function(t,e){return[Math.min(t[0],e[0]),Math.max(t[1],e[1])]},[1/0,-1/0])},get:function(){return r.slice()},getConsolidated:function(){return t},getBounds:function(){return e}}}();return l.set(r),{filter:l,filterSpecified:e,svgBrush:{extent:[],brushStartCallback:n,brushCallback:(o=i,function(t){var e=t.brush,r=function(t){return t.svgBrush.extent.map(function(t){return t.slice()})}(e).slice();e.filter.set(r),o()}),brushEndCallback:a}}},ensureAxisBrush:function(t){var e=t.selectAll(\".\"+n.cn.axisBrush).data(o,a);e.enter().append(\"g\").classed(n.cn.axisBrush,!0),function(t){var e=t.selectAll(\".background\").data(o);e.enter().append(\"rect\").classed(\"background\",!0).call(p).call(d).style(\"pointer-events\",\"auto\").attr(\"transform\",\"translate(0 \"+n.verticalPadding+\")\"),e.call(k).attr(\"height\",function(t){return t.height-n.verticalPadding});var r=t.selectAll(\".highlight-shadow\").data(o);r.enter().append(\"line\").classed(\"highlight-shadow\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width+n.bar.strokeWidth).attr(\"stroke\",n.bar.strokeColor).attr(\"opacity\",n.bar.strokeOpacity).attr(\"stroke-linecap\",\"butt\"),r.attr(\"y1\",function(t){return t.height}).call(y);var i=t.selectAll(\".highlight\").data(o);i.enter().append(\"line\").classed(\"highlight\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width-n.bar.strokeWidth).attr(\"stroke\",n.bar.fillColor).attr(\"opacity\",n.bar.fillOpacity).attr(\"stroke-linecap\",\"butt\"),i.attr(\"y1\",function(t){return t.height}).call(y)}(e)},cleanRanges:function(t,e){if(Array.isArray(t[0])?(t=t.map(function(t){return t.sort(s)}),t=e.multiselect?M(t.sort(T)):[t[0]]):t=[t.sort(s)],e.tickvals){var r=e.tickvals.slice().sort(s);if(!(t=t.map(function(t){var e=[f(0,r,t[0],[]),f(1,r,t[1],[])];if(e[1]>e[0])return e}).filter(function(t){return t})).length)return}return t.length>1?t:t[0]}}},{\"../../lib\":719,\"../../lib/gup\":717,\"./constants\":1078,d3:163}],1076:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../constants/xmlns_namespaces\");r.name=\"parcoords\",r.plot=function(t){var e=i(t.calcdata,\"parcoords\")[0];e.length&&a(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcoords\"),a=e._has&&e._has(\"parcoords\");i&&!a&&(n._paperdiv.selectAll(\".parcoords\").remove(),n._glimages.selectAll(\"*\").remove())},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter(function(t,e){return e===r.size()-1}).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each(function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})}),window.setTimeout(function(){n.selectAll(\"#filterBarPattern\").attr(\"id\",\"filterBarPattern\")},60)}},{\"../../constants/xmlns_namespaces\":696,\"../../plots/get_data\":802,\"./plot\":1085,d3:163}],1077:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale\"),a=t(\"../../lib/gup\").wrap;e.exports=function(t,e){var r,o;return i.hasColorscale(e,\"line\")&&n(e.line.color)?(r=e.line.color,o=i.extractOpts(e.line).colorscale,i.calc(t,e,{vals:r,containerStr:\"line\",cLetter:\"c\"})):(r=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=.5;return e}(e._length),o=[[0,e.line.color],[1,e.line.color]]),a({lineColor:r,cscale:o})}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gup\":717}],1078:[function(t,e,r){\"use strict\";e.exports={maxDimensionCount:60,overdrag:45,verticalPadding:2,tickDistance:50,canvasPixelRatio:1,blockLineCount:5e3,layers:[\"contextLineLayer\",\"focusLineLayer\",\"pickLineLayer\"],axisTitleOffset:28,axisExtentOffset:10,deselectedLineColor:\"#777\",bar:{width:4,captureWidth:10,fillColor:\"magenta\",fillOpacity:1,snapDuration:150,snapRatio:.25,snapClose:.01,strokeColor:\"white\",strokeOpacity:1,strokeWidth:1,handleHeight:8,handleOpacity:1,handleOverlap:0},cn:{axisExtentText:\"axis-extent-text\",parcoordsLineLayers:\"parcoords-line-layers\",parcoordsLineLayer:\"parcoords-lines\",parcoords:\"parcoords\",parcoordsControlView:\"parcoords-control-view\",yAxis:\"y-axis\",axisOverlays:\"axis-overlays\",axis:\"axis\",axisHeading:\"axis-heading\",axisTitle:\"axis-title\",axisExtent:\"axis-extent\",axisExtentTop:\"axis-extent-top\",axisExtentTopText:\"axis-extent-top-text\",axisExtentBottom:\"axis-extent-bottom\",axisExtentBottomText:\"axis-extent-bottom-text\",axisBrush:\"axis-brush\"},id:{filterBarPattern:\"filter-bar-pattern\"}}},{}],1079:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"../../plots/cartesian/axes\"),c=t(\"./attributes\"),u=t(\"./axisbrush\"),h=t(\"./constants\").maxDimensionCount,f=t(\"./merge_length\");function p(t,e,r,i){function a(r,i){return n.coerce(t,e,c.dimensions,r,i)}var o=a(\"values\"),s=a(\"visible\");if(o&&o.length||(s=e.visible=!1),s){a(\"label\"),a(\"tickvals\"),a(\"ticktext\"),a(\"tickformat\");var h=a(\"range\");e._ax={_id:\"y\",type:\"linear\",showexponent:\"all\",exponentformat:\"B\",range:h},l.setConvert(e._ax,i.layout),a(\"multiselect\");var f=a(\"constraintrange\");f&&(e.constraintrange=u.cleanRanges(f,e))}}e.exports=function(t,e,r,l){function u(r,i){return n.coerce(t,e,c,r,i)}var d=t.dimensions;Array.isArray(d)&&d.length>h&&(n.log(\"parcoords traces support up to \"+h+\" dimensions at the moment\"),d.splice(h));var g=s(t,e,{name:\"dimensions\",layout:l,handleItemDefaults:p}),v=function(t,e,r,o,s){var l=s(\"line.color\",r);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,l,u);o(e,l,u),Array.isArray(g)&&g.length||(e.visible=!1),f(e,g,\"values\",v);var m={family:l.font.family,size:Math.round(l.font.size/1.2),color:l.font.color};n.coerceFont(u,\"labelfont\",m),n.coerceFont(u,\"tickfont\",m),n.coerceFont(u,\"rangefont\",m),u(\"labelangle\"),u(\"labelside\")}},{\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"../../plots/domain\":792,\"./attributes\":1074,\"./axisbrush\":1075,\"./constants\":1078,\"./merge_length\":1083}],1080:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isTypedArray;r.convertTypedArray=function(t){return n(t)?Array.prototype.slice.call(t):t},r.isOrdinal=function(t){return!!t.tickvals},r.isVisible=function(t){return t.visible||!(\"visible\"in t)}},{\"../../lib\":719}],1081:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcoords\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"noOpacity\",\"noHover\"],meta:{}}},{\"./attributes\":1074,\"./base_plot\":1076,\"./calc\":1077,\"./defaults\":1079,\"./plot\":1085}],1082:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nattribute vec4 p01_04, p05_08, p09_12, p13_16,\\n               p17_20, p21_24, p25_28, p29_32,\\n               p33_36, p37_40, p41_44, p45_48,\\n               p49_52, p53_56, p57_60, colors;\\n\\nuniform mat4 dim0A, dim1A, dim0B, dim1B, dim0C, dim1C, dim0D, dim1D,\\n             loA, hiA, loB, hiB, loC, hiC, loD, hiD;\\n\\nuniform vec2 resolution, viewBoxPos, viewBoxSize;\\nuniform sampler2D mask, palette;\\nuniform float maskHeight;\\nuniform float drwLayer; // 0: context, 1: focus, 2: pick\\nuniform vec4 contextColor;\\n\\nbool isPick    = (drwLayer > 1.5);\\nbool isContext = (drwLayer < 0.5);\\n\\nconst vec4 ZEROS = vec4(0.0, 0.0, 0.0, 0.0);\\nconst vec4 UNITS = vec4(1.0, 1.0, 1.0, 1.0);\\n\\nfloat val(mat4 p, mat4 v) {\\n    return dot(matrixCompMult(p, v) * UNITS, UNITS);\\n}\\n\\nfloat axisY(float ratio, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float y1 = val(A, dim0A) + val(B, dim0B) + val(C, dim0C) + val(D, dim0D);\\n    float y2 = val(A, dim1A) + val(B, dim1B) + val(C, dim1C) + val(D, dim1D);\\n    return y1 * (1.0 - ratio) + y2 * ratio;\\n}\\n\\nint iMod(int a, int b) {\\n    return a - b * (a / b);\\n}\\n\\nbool fOutside(float p, float lo, float hi) {\\n    return (lo < hi) && (lo > p || p > hi);\\n}\\n\\nbool vOutside(vec4 p, vec4 lo, vec4 hi) {\\n    return (\\n        fOutside(p[0], lo[0], hi[0]) ||\\n        fOutside(p[1], lo[1], hi[1]) ||\\n        fOutside(p[2], lo[2], hi[2]) ||\\n        fOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool mOutside(mat4 p, mat4 lo, mat4 hi) {\\n    return (\\n        vOutside(p[0], lo[0], hi[0]) ||\\n        vOutside(p[1], lo[1], hi[1]) ||\\n        vOutside(p[2], lo[2], hi[2]) ||\\n        vOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool outsideBoundingBox(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    return mOutside(A, loA, hiA) ||\\n           mOutside(B, loB, hiB) ||\\n           mOutside(C, loC, hiC) ||\\n           mOutside(D, loD, hiD);\\n}\\n\\nbool outsideRasterMask(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    mat4 pnts[4];\\n    pnts[0] = A;\\n    pnts[1] = B;\\n    pnts[2] = C;\\n    pnts[3] = D;\\n\\n    for(int i = 0; i < 4; ++i) {\\n        for(int j = 0; j < 4; ++j) {\\n            for(int k = 0; k < 4; ++k) {\\n                if(0 == iMod(\\n                    int(255.0 * texture2D(mask,\\n                        vec2(\\n                            (float(i * 2 + j / 2) + 0.5) / 8.0,\\n                            (pnts[i][j][k] * (maskHeight - 1.0) + 1.0) / maskHeight\\n                        ))[3]\\n                    ) / int(pow(2.0, float(iMod(j * 4 + k, 8)))),\\n                    2\\n                )) return true;\\n            }\\n        }\\n    }\\n    return false;\\n}\\n\\nvec4 position(bool isContext, float v, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float x = 0.5 * sign(v) + 0.5;\\n    float y = axisY(x, A, B, C, D);\\n    float z = 1.0 - abs(v);\\n\\n    z += isContext ? 0.0 : 2.0 * float(\\n        outsideBoundingBox(A, B, C, D) ||\\n        outsideRasterMask(A, B, C, D)\\n    );\\n\\n    return vec4(\\n        2.0 * (vec2(x, y) * viewBoxSize + viewBoxPos) / resolution - 1.0,\\n        z,\\n        1.0\\n    );\\n}\\n\\nvoid main() {\\n    mat4 A = mat4(p01_04, p05_08, p09_12, p13_16);\\n    mat4 B = mat4(p17_20, p21_24, p25_28, p29_32);\\n    mat4 C = mat4(p33_36, p37_40, p41_44, p45_48);\\n    mat4 D = mat4(p49_52, p53_56, p57_60, ZEROS);\\n\\n    float v = colors[3];\\n\\n    gl_Position = position(isContext, v, A, B, C, D);\\n\\n    fragColor =\\n        isContext ? vec4(contextColor) :\\n        isPick ? vec4(colors.rgb, 1.0) : texture2D(palette, vec2(abs(v), 0.5));\\n}\\n\"]),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n    gl_FragColor = fragColor;\\n}\\n\"]),o=t(\"./constants\").maxDimensionCount,s=t(\"../../lib\"),l=1e-6,c=2048,u=new Uint8Array(4),h=new Uint8Array(4),f={shape:[256,1],format:\"rgba\",type:\"uint8\",mag:\"nearest\",min:\"nearest\"};function p(t,e,r,n,i){var a=t._gl;a.enable(a.SCISSOR_TEST),a.scissor(e,r,n,i),t.clear({color:[0,0,0,0],depth:1})}function d(t,e,r,n,i,a){var o=a.key;r.drawCompleted||(!function(t){t.read({x:0,y:0,width:1,height:1,data:u})}(t),r.drawCompleted=!0),function s(l){var c=Math.min(n,i-l*n);0===l&&(window.cancelAnimationFrame(r.currentRafs[o]),delete r.currentRafs[o],p(t,a.scissorX,a.scissorY,a.scissorWidth,a.viewBoxSize[1])),r.clearOnly||(a.count=2*c,a.offset=2*l*n,e(a),l*n+c<i&&(r.currentRafs[o]=window.requestAnimationFrame(function(){s(l+1)})),r.drawCompleted=!1)}(0)}function g(t,e){return(t>>>8*e)%256/255}function v(t,e,r){for(var n=new Array(8*e),i=0,a=0;a<e;a++)for(var o=0;o<2;o++)for(var s=0;s<4;s++){var l=4*t+s,c=r[64*a+l];63===l&&0===o&&(c*=-1),n[i++]=c}return n}function m(t){var e=\"0\"+t;return e.substr(e.length-2)}function y(t){return t<o?\"p\"+m(t+1)+\"_\"+m(t+4):\"colors\"}function x(t,e,r,n,i,a,o,l,c,u,h,f,p){for(var d=[[],[]],g=0;g<64;g++)d[0][g]=g===i?1:0,d[1][g]=g===a?1:0;var v=t.lines.canvasOverdrag,m=t.domain,y=t.canvasWidth,x=t.canvasHeight,b=t.deselectedLines.color;return s.extendFlat({key:h,resolution:[y,x],viewBoxPos:[o+v,l],viewBoxSize:[c,u],i0:i,i1:a,dim0A:d[0].slice(0,16),dim0B:d[0].slice(16,32),dim0C:d[0].slice(32,48),dim0D:d[0].slice(48,64),dim1A:d[1].slice(0,16),dim1B:d[1].slice(16,32),dim1C:d[1].slice(32,48),dim1D:d[1].slice(48,64),drwLayer:f,contextColor:[b[0]/255,b[1]/255,b[2]/255,b[3]<1?b[3]:Math.max(1/255,Math.pow(1/t.lines.color.length,1/3))],scissorX:(n===e?0:o+v)+(t.pad.l-v)+t.layoutWidth*m.x[0],scissorWidth:(n===r?y-o+v:c+.5)+(n===e?o+v:0),scissorY:l+t.pad.b+t.layoutHeight*m.y[0],scissorHeight:u,viewportX:t.pad.l-v+t.layoutWidth*m.x[0],viewportY:t.pad.b+t.layoutHeight*m.y[0],viewportWidth:y,viewportHeight:x},p)}function b(t){var e=c-1,r=Math.max(0,Math.floor(t[0]*e),0),n=Math.min(e,Math.ceil(t[1]*e),e);return[Math.min(r,n),Math.max(r,n)]}e.exports=function(t,e){var r,n,u,m,_,w=e.context,k=e.pick,T=e.regl,A={currentRafs:{},drawCompleted:!0,clearOnly:!1},M=function(t){for(var e={},r=0;r<=o;r+=4)e[y(r)]=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)});return e}(T),S=T.texture(f),E=[];L(e);var C=T({profile:!1,blend:{enable:w,func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:1,dstAlpha:1},equation:{rgb:\"add\",alpha:\"add\"},color:[0,0,0,0]},depth:{enable:!w,mask:!0,func:\"less\",range:[0,1]},cull:{enable:!0,face:\"back\"},scissor:{enable:!0,box:{x:T.prop(\"scissorX\"),y:T.prop(\"scissorY\"),width:T.prop(\"scissorWidth\"),height:T.prop(\"scissorHeight\")}},viewport:{x:T.prop(\"viewportX\"),y:T.prop(\"viewportY\"),width:T.prop(\"viewportWidth\"),height:T.prop(\"viewportHeight\")},dither:!1,vert:i,frag:a,primitive:\"lines\",lineWidth:1,attributes:M,uniforms:{resolution:T.prop(\"resolution\"),viewBoxPos:T.prop(\"viewBoxPos\"),viewBoxSize:T.prop(\"viewBoxSize\"),dim0A:T.prop(\"dim0A\"),dim1A:T.prop(\"dim1A\"),dim0B:T.prop(\"dim0B\"),dim1B:T.prop(\"dim1B\"),dim0C:T.prop(\"dim0C\"),dim1C:T.prop(\"dim1C\"),dim0D:T.prop(\"dim0D\"),dim1D:T.prop(\"dim1D\"),loA:T.prop(\"loA\"),hiA:T.prop(\"hiA\"),loB:T.prop(\"loB\"),hiB:T.prop(\"hiB\"),loC:T.prop(\"loC\"),hiC:T.prop(\"hiC\"),loD:T.prop(\"loD\"),hiD:T.prop(\"hiD\"),palette:S,contextColor:T.prop(\"contextColor\"),mask:T.prop(\"maskTexture\"),drwLayer:T.prop(\"drwLayer\"),maskHeight:T.prop(\"maskHeight\")},offset:T.prop(\"offset\"),count:T.prop(\"count\")});function L(t){r=t.model,n=t.viewModel,u=n.dimensions.slice(),m=u[0]?u[0].values.length:0;var e=r.lines,i=k?e.color.map(function(t,r){return r/e.color.length}):e.color,a=function(t,e,r){for(var n,i=new Array(t*(o+4)),a=0,s=0;s<t;s++){for(var c=0;c<o;c++)i[a++]=c<e.length?e[c].paddedUnitValues[s]:.5;i[a++]=g(s,2),i[a++]=g(s,1),i[a++]=g(s,0),i[a++]=(n=r[s],Math.max(l,Math.min(1-l,n)))}return i}(m,u,i);!function(t,e,r){for(var n=0;n<=o;n+=4)t[y(n)](v(n/4,e,r))}(M,m,a),w||k||(S=T.texture(s.extendFlat({data:function(t,e){for(var r=new Array(256),n=0;n<256;n++)r[n]=t(n/255).concat(e);return r}(r.unitToColor,255)},f)))}return{render:function(t,e,n){var i,a,o,s=t.length,l=1/0,h=-1/0;for(i=0;i<s;i++)t[i].dim0.canvasX<l&&(l=t[i].dim0.canvasX,a=i),t[i].dim1.canvasX>h&&(h=t[i].dim1.canvasX,o=i);0===s&&p(T,0,0,r.canvasWidth,r.canvasHeight);var f=function(t){var e,r,n,i=[[],[]];for(n=0;n<64;n++){var a=!t&&n<u.length?u[n].brush.filter.getBounds():[-1/0,1/0];i[0][n]=a[0],i[1][n]=a[1]}var o=8*c,s=new Array(o);for(e=0;e<o;e++)s[e]=255;if(!t)for(e=0;e<u.length;e++){var l=e%8,h=(e-l)/8,f=Math.pow(2,l),p=u[e].brush.filter.get();if(!(p.length<2)){var d=b(p[0])[1];for(r=1;r<p.length;r++){var g=b(p[r]);for(n=d+1;n<g[0];n++)s[8*n+h]&=~f;d=Math.max(d,g[1])}}}var v={shape:[8,c],format:\"alpha\",type:\"uint8\",mag:\"nearest\",min:\"nearest\",data:s};return _?_(v):_=T.texture(v),{maskTexture:_,maskHeight:c,loA:i[0].slice(0,16),loB:i[0].slice(16,32),loC:i[0].slice(32,48),loD:i[0].slice(48,64),hiA:i[1].slice(0,16),hiB:i[1].slice(16,32),hiC:i[1].slice(32,48),hiD:i[1].slice(48,64)}}(w);for(i=0;i<s;i++){var g=t[i],v=g.dim0.crossfilterDimensionIndex,y=g.dim1.crossfilterDimensionIndex,M=g.canvasX,S=g.canvasY,L=M+g.panelSizeX;if(e||!E[v]||E[v][0]!==M||E[v][1]!==L){E[v]=[M,L];var P=x(r,a,o,i,v,y,M,S,g.panelSizeX,g.panelSizeY,g.dim0.crossfilterDimensionIndex,w?0:k?2:1,f);A.clearOnly=n;var O=e?r.lines.blockLineCount:m;d(T,C,A,O,m,P)}}},readPixel:function(t,e){return T.read({x:t,y:e,width:1,height:1,data:h}),h},readPixels:function(t,e,r,n){var i=new Uint8Array(4*r*n);return T.read({x:t,y:e,width:r,height:n,data:i}),i},destroy:function(){for(var e in t.style[\"pointer-events\"]=\"none\",S.destroy(),_&&_.destroy(),M)M[e].destroy()},update:L}}},{\"../../lib\":719,\"./constants\":1078,glslify:409}],1083:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a;for(n||(n=1/0),i=0;i<e.length;i++)(a=e[i]).visible&&(n=Math.min(n,a[r].length));for(n===1/0&&(n=0),t._length=n,i=0;i<e.length;i++)(a=e[i]).visible&&(a._length=n);return n}},{}],1084:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"color-rgba\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../components/drawing\"),c=t(\"../../components/colorscale\"),u=t(\"../../lib/gup\"),h=u.keyFun,f=u.repeat,p=u.unwrap,d=t(\"./helpers\"),g=t(\"./constants\"),v=t(\"./axisbrush\"),m=t(\"./lines\");function y(t,e,r){return o.aggNums(t,null,e,r)}function x(t,e){return _(y(Math.min,t,e),y(Math.max,t,e))}function b(t){var e=t.range;return e?_(e[0],e[1]):x(t.values,t._length)}function _(t,e){return!isNaN(t)&&isFinite(t)||(t=0),!isNaN(e)&&isFinite(e)||(e=0),t===e&&(0===t?(t-=1,e+=1):(t*=.9,e*=1.1)),[t,e]}function w(t){return t.dimensions.some(function(t){return t.brush.filterSpecified})}function k(t,e,r){var a=p(e),s=a.trace,l=d.convertTypedArray(a.lineColor),u=s.line,h={color:i(g.deselectedLineColor)},f=c.extractOpts(u),v=f.reversescale?c.flipScale(a.cscale):a.cscale,m=s.domain,y=s.dimensions,x=t.width,_=s.labelangle,w=s.labelside,k=s.labelfont,T=s.tickfont,A=s.rangefont,M=o.extendDeepNoArrays({},u,{color:l.map(n.scale.linear().domain(b({values:l,range:[f.min,f.max],_length:s._length}))),blockLineCount:g.blockLineCount,canvasOverdrag:g.overdrag*g.canvasPixelRatio}),S=Math.floor(x*(m.x[1]-m.x[0])),E=Math.floor(t.height*(m.y[1]-m.y[0])),C=t.margin||{l:80,r:80,t:100,b:80},L=S,P=E;return{key:r,colCount:y.filter(d.isVisible).length,dimensions:y,tickDistance:g.tickDistance,unitToColor:function(t){var e=t.map(function(t){return t[0]}),r=t.map(function(t){var e=i(t[1]);return n.rgb(\"rgb(\"+e[0]+\",\"+e[1]+\",\"+e[2]+\")\")}),a=\"rgb\".split(\"\").map(function(t){return n.scale.linear().clamp(!0).domain(e).range(r.map((i=t,function(t){return t[i]})));var i});return function(t){return a.map(function(e){return e(t)})}}(v),lines:M,deselectedLines:h,labelAngle:_,labelSide:w,labelFont:k,tickFont:T,rangeFont:A,layoutWidth:x,layoutHeight:t.height,domain:m,translateX:m.x[0]*x,translateY:t.height-m.y[1]*t.height,pad:C,canvasWidth:L*g.canvasPixelRatio+2*M.canvasOverdrag,canvasHeight:P*g.canvasPixelRatio,width:L,height:P,canvasPixelRatio:g.canvasPixelRatio}}function T(t,e,r){var i=r.width,a=r.height,s=r.dimensions,l=r.canvasPixelRatio,c=function(t){return i*t/Math.max(1,r.colCount-1)},u=g.verticalPadding/a,h=function(t,e){return n.scale.linear().range([e,t-e])}(a,g.verticalPadding),f={key:r.key,xScale:c,model:r,inBrushDrag:!1},p={};return f.dimensions=s.filter(d.isVisible).map(function(i,s){var m=function(t,e){return n.scale.linear().domain(b(t)).range([e,1-e])}(i,u),y=p[i.label];p[i.label]=(y||0)+1;var x=i.label+(y?\"__\"+y:\"\"),_=i.constraintrange,k=_&&_.length;k&&!Array.isArray(_[0])&&(_=[_]);var T=k?_.map(function(t){return t.map(m)}):[[-1/0,1/0]],A=i.values;A.length>i._length&&(A=A.slice(0,i._length));var M,S=i.tickvals;function E(t,e){return{val:t,text:M[e]}}function C(t,e){return t.val-e.val}if(Array.isArray(S)&&S.length){M=i.ticktext,Array.isArray(M)&&M.length?M.length>S.length?M=M.slice(0,S.length):S.length>M.length&&(S=S.slice(0,M.length)):M=S.map(n.format(i.tickformat));for(var L=1;L<S.length;L++)if(S[L]<S[L-1]){for(var P=S.map(E).sort(C),O=0;O<S.length;O++)S[O]=P[O].val,M[O]=P[O].text;break}}else S=void 0;return A=d.convertTypedArray(A),A=d.convertTypedArray(A),{key:x,label:i.label,tickFormat:i.tickformat,tickvals:S,ticktext:M,ordinal:d.isOrdinal(i),multiselect:i.multiselect,xIndex:s,crossfilterDimensionIndex:s,visibleIndex:i._index,height:a,values:A,paddedUnitValues:A.map(m),unitTickvals:S&&S.map(m),xScale:c,x:c(s),canvasX:c(s)*l,unitToPaddedPx:h,domainScale:function(t,e,r,i,a){var o,s,l=b(r);return i?n.scale.ordinal().domain(i.map((o=n.format(r.tickformat),s=a,s?function(t,e){var r=s[e];return null==r?o(t):r}:o))).range(i.map(function(r){var n=(r-l[0])/(l[1]-l[0]);return t-e+n*(2*e-t)})):n.scale.linear().domain(l).range([t-e,e])}(a,g.verticalPadding,i,S,M),ordinalScale:function(t){if(t.tickvals){var e=b(t);return n.scale.ordinal().domain(t.tickvals).range(t.tickvals.map(function(t){return(t-e[0])/(e[1]-e[0])}))}}(i),parent:f,model:r,brush:v.makeBrush(t,k,T,function(){t.linePickActive(!1)},function(){var e=f;e.focusLayer&&e.focusLayer.render(e.panels,!0);var r=w(e);!t.contextShown()&&r?(e.contextLayer&&e.contextLayer.render(e.panels,!0),t.contextShown(!0)):t.contextShown()&&!r&&(e.contextLayer&&e.contextLayer.render(e.panels,!0,!0),t.contextShown(!1))},function(r){if(f.focusLayer.render(f.panels,!0),f.pickLayer&&f.pickLayer.render(f.panels,!0),t.linePickActive(!0),e&&e.filterChanged){var n=m.invert,a=r.map(function(t){return t.map(n).sort(o.sorterAsc)}).sort(function(t,e){return t[0]-e[0]});e.filterChanged(f.key,i._index,a)}})}}),f}function A(t){t.classed(g.cn.axisExtentText,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"default\").style(\"user-select\",\"none\")}function M(t,e){var r=\"top\"===e?1:-1,n=t*Math.PI/180;return{dir:r,dx:Math.sin(n),dy:Math.cos(n),degrees:t}}function S(t,e){for(var r=e.panels||(e.panels=[]),n=t.data(),i=0;i<n.length-1;i++){var a=r[i]||(r[i]={}),o=n[i],s=n[i+1];a.dim0=o,a.dim1=s,a.canvasX=o.canvasX,a.panelSizeX=s.canvasX-o.canvasX,a.panelSizeY=e.model.canvasHeight,a.y=0,a.canvasY=0}}function E(t,e){return a.tickText(t._ax,e,!1).text}function C(t,e){if(t.ordinal)return\"\";var r=t.domainScale.domain(),n=r[e?r.length-1:0];return E(t.model.dimensions[t.visibleIndex],n)}e.exports=function(t,e,r,i){var c=t._fullLayout,u=c._toppaper,y=c._glcontainer;!function(t){for(var e=0;e<t.length;e++)for(var r=0;r<t[e].length;r++)for(var n=t[e][r].trace,i=n.dimensions,o=0;o<i.length;o++){var s=i[o].values,l=i[o]._ax;l&&(l.range?l.range=_(l.range[0],l.range[1]):l.range=x(s,n._length),l.dtick||(l.dtick=.01*(Math.abs(l.range[1]-l.range[0])||1)),l.tickformat=i[o].tickformat,a.calcTicks(l),l.cleanRange())}}(e);var b,L,P=(b=!0,L=!1,{linePickActive:function(t){return arguments.length?b=!!t:b},contextShown:function(t){return arguments.length?L=!!t:L}}),O=e.filter(function(t){return p(t).trace.visible}).map(k.bind(0,r)).map(T.bind(0,P,i));y.each(function(t,e){return o.extendFlat(t,O[e])});var z=y.selectAll(\".gl-canvas\").each(function(t){t.viewModel=O[0],t.model=t.viewModel?t.viewModel.model:null}),I=null;z.filter(function(t){return t.pick}).style(\"pointer-events\",\"auto\").on(\"mousemove\",function(t){if(P.linePickActive()&&t.lineLayer&&i&&i.hover){var e=n.event,r=this.width,a=this.height,o=n.mouse(this),s=o[0],l=o[1];if(s<0||l<0||s>=r||l>=a)return;var c=t.lineLayer.readPixel(s,a-1-l),u=0!==c[3],h=u?c[2]+256*(c[1]+256*c[0]):null,f={x:s,y:l,clientX:e.clientX,clientY:e.clientY,dataIndex:t.model.key,curveNumber:h};h!==I&&(u?i.hover(f):i.unhover&&i.unhover(f),I=h)}}),z.style(\"opacity\",function(t){return t.pick?0:1}),u.style(\"background\",\"rgba(255, 255, 255, 0)\");var D=u.selectAll(\".\"+g.cn.parcoords).data(O,h);D.exit().remove(),D.enter().append(\"g\").classed(g.cn.parcoords,!0).style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"none\"),D.attr(\"transform\",function(t){return\"translate(\"+t.model.translateX+\",\"+t.model.translateY+\")\"});var R=D.selectAll(\".\"+g.cn.parcoordsControlView).data(f,h);R.enter().append(\"g\").classed(g.cn.parcoordsControlView,!0),R.attr(\"transform\",function(t){return\"translate(\"+t.model.pad.l+\",\"+t.model.pad.t+\")\"});var F=R.selectAll(\".\"+g.cn.yAxis).data(function(t){return t.dimensions},h);F.enter().append(\"g\").classed(g.cn.yAxis,!0),R.each(function(t){S(F,t)}),z.each(function(t){if(t.viewModel){!t.lineLayer||i?t.lineLayer=m(this,t):t.lineLayer.update(t),(t.key||0===t.key)&&(t.viewModel[t.key]=t.lineLayer);var e=!t.context||i;t.lineLayer.render(t.viewModel.panels,e)}}),F.attr(\"transform\",function(t){return\"translate(\"+t.xScale(t.xIndex)+\", 0)\"}),F.call(n.behavior.drag().origin(function(t){return t}).on(\"drag\",function(t){var e=t.parent;P.linePickActive(!1),t.x=Math.max(-g.overdrag,Math.min(t.model.width+g.overdrag,n.event.x)),t.canvasX=t.x*t.model.canvasPixelRatio,F.sort(function(t,e){return t.x-e.x}).each(function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e.xIndex),e.canvasX=e.x*e.model.canvasPixelRatio}),S(F,e),F.filter(function(e){return 0!==Math.abs(t.xIndex-e.xIndex)}).attr(\"transform\",function(t){return\"translate(\"+t.xScale(t.xIndex)+\", 0)\"}),n.select(this).attr(\"transform\",\"translate(\"+t.x+\", 0)\"),F.each(function(r,n,i){i===t.parent.key&&(e.dimensions[n]=r)}),e.contextLayer&&e.contextLayer.render(e.panels,!1,!w(e)),e.focusLayer.render&&e.focusLayer.render(e.panels)}).on(\"dragend\",function(t){var e=t.parent;t.x=t.xScale(t.xIndex),t.canvasX=t.x*t.model.canvasPixelRatio,S(F,e),n.select(this).attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),e.contextLayer&&e.contextLayer.render(e.panels,!1,!w(e)),e.focusLayer&&e.focusLayer.render(e.panels),e.pickLayer&&e.pickLayer.render(e.panels,!0),P.linePickActive(!0),i&&i.axesMoved&&i.axesMoved(e.key,e.dimensions.map(function(t){return t.crossfilterDimensionIndex}))})),F.exit().remove();var B=F.selectAll(\".\"+g.cn.axisOverlays).data(f,h);B.enter().append(\"g\").classed(g.cn.axisOverlays,!0),B.selectAll(\".\"+g.cn.axis).remove();var N=B.selectAll(\".\"+g.cn.axis).data(f,h);N.enter().append(\"g\").classed(g.cn.axis,!0),N.each(function(t){var e=t.model.height/t.model.tickDistance,r=t.domainScale,i=r.domain();n.select(this).call(n.svg.axis().orient(\"left\").tickSize(4).outerTickSize(2).ticks(e,t.tickFormat).tickValues(t.ordinal?i:null).tickFormat(function(e){return d.isOrdinal(t)?e:E(t.model.dimensions[t.visibleIndex],e)}).scale(r)),l.font(N.selectAll(\"text\"),t.model.tickFont)}),N.selectAll(\".domain, .tick>line\").attr(\"fill\",\"none\").attr(\"stroke\",\"black\").attr(\"stroke-opacity\",.25).attr(\"stroke-width\",\"1px\"),N.selectAll(\"text\").style(\"text-shadow\",\"1px 1px 1px #fff, -1px -1px 1px #fff, 1px -1px 1px #fff, -1px 1px 1px #fff\").style(\"cursor\",\"default\").style(\"user-select\",\"none\");var j=B.selectAll(\".\"+g.cn.axisHeading).data(f,h);j.enter().append(\"g\").classed(g.cn.axisHeading,!0);var U=j.selectAll(\".\"+g.cn.axisTitle).data(f,h);U.enter().append(\"text\").classed(g.cn.axisTitle,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"ew-resize\").style(\"user-select\",\"none\").style(\"pointer-events\",\"auto\"),U.text(function(t){return t.label}).each(function(e){var r=n.select(this);l.font(r,e.model.labelFont),s.convertToTspans(r,t)}).attr(\"transform\",function(t){var e=M(t.model.labelAngle,t.model.labelSide),r=g.axisTitleOffset;return(e.dir>0?\"\":\"translate(0,\"+(2*r+t.model.height)+\")\")+\"rotate(\"+e.degrees+\")translate(\"+-r*e.dx+\",\"+-r*e.dy+\")\"}).attr(\"text-anchor\",function(t){var e=M(t.model.labelAngle,t.model.labelSide);return 2*Math.abs(e.dx)>Math.abs(e.dy)?e.dir*e.dx<0?\"start\":\"end\":\"middle\"});var V=B.selectAll(\".\"+g.cn.axisExtent).data(f,h);V.enter().append(\"g\").classed(g.cn.axisExtent,!0);var q=V.selectAll(\".\"+g.cn.axisExtentTop).data(f,h);q.enter().append(\"g\").classed(g.cn.axisExtentTop,!0),q.attr(\"transform\",\"translate(0,\"+-g.axisExtentOffset+\")\");var H=q.selectAll(\".\"+g.cn.axisExtentTopText).data(f,h);H.enter().append(\"text\").classed(g.cn.axisExtentTopText,!0).call(A),H.text(function(t){return C(t,!0)}).each(function(t){l.font(n.select(this),t.model.rangeFont)});var G=V.selectAll(\".\"+g.cn.axisExtentBottom).data(f,h);G.enter().append(\"g\").classed(g.cn.axisExtentBottom,!0),G.attr(\"transform\",function(t){return\"translate(0,\"+(t.model.height+g.axisExtentOffset)+\")\"});var Y=G.selectAll(\".\"+g.cn.axisExtentBottomText).data(f,h);Y.enter().append(\"text\").classed(g.cn.axisExtentBottomText,!0).attr(\"dy\",\"0.75em\").call(A),Y.text(function(t){return C(t,!1)}).each(function(t){l.font(n.select(this),t.model.rangeFont)}),v.ensureAxisBrush(B)}},{\"../../components/colorscale\":605,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/gup\":717,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"./axisbrush\":1075,\"./constants\":1078,\"./helpers\":1080,\"./lines\":1082,\"color-rgba\":122,d3:163}],1085:[function(t,e,r){\"use strict\";var n=t(\"./parcoords\"),i=t(\"../../lib/prepare_regl\"),a=t(\"./helpers\").isVisible;function o(t,e,r){var n=e.indexOf(r),i=t.indexOf(n);return-1===i&&(i+=e.length),i}e.exports=function(t,e){var r=t._fullLayout;if(i(t)){var s={},l={},c={},u={},h=r._size;e.forEach(function(e,r){var n=e[0].trace;c[r]=n.index;var i=u[r]=n._fullInput.index;s[r]=t.data[i].dimensions,l[r]=t.data[i].dimensions.slice()});n(t,e,{width:h.w,height:h.h,margin:{t:h.t,r:h.r,b:h.b,l:h.l}},{filterChanged:function(e,n,i){var a=l[e][n],o=i.map(function(t){return t.slice()}),s=\"dimensions[\"+n+\"].constraintrange\",h=r._tracePreGUI[t._fullData[c[e]]._fullInput.uid];if(void 0===h[s]){var f=a.constraintrange;h[s]=f||null}var p=t._fullData[c[e]].dimensions[n];o.length?(1===o.length&&(o=o[0]),a.constraintrange=o,p.constraintrange=o.slice(),o=[o]):(delete a.constraintrange,delete p.constraintrange,o=null);var d={};d[s]=o,t.emit(\"plotly_restyle\",[d,[u[e]]])},hover:function(e){t.emit(\"plotly_hover\",e)},unhover:function(e){t.emit(\"plotly_unhover\",e)},axesMoved:function(e,r){var n=function(t,e){return function(r,n){return o(t,e,r)-o(t,e,n)}}(r,l[e].filter(a));s[e].sort(n),l[e].filter(function(t){return!a(t)}).sort(function(t){return l[e].indexOf(t)}).forEach(function(t){s[e].splice(s[e].indexOf(t),1),s[e].splice(l[e].indexOf(t),0,t)}),t.emit(\"plotly_restyle\",[{dimensions:[s[e]]},[u[e]]])}})}}},{\"../../lib/prepare_regl\":732,\"./helpers\":1080,\"./parcoords\":1084}],1086:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../plots/domain\").attributes,a=t(\"../../plots/font_attributes\"),o=t(\"../../components/color/attributes\"),s=t(\"../../components/fx/hovertemplate_attributes\"),l=t(\"../../lib/extend\").extendFlat,c=a({editType:\"plot\",arrayOk:!0,colorEditType:\"plot\"});e.exports={labels:{valType:\"data_array\",editType:\"calc\"},label0:{valType:\"number\",dflt:0,editType:\"calc\"},dlabel:{valType:\"number\",dflt:1,editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},marker:{colors:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:o.defaultLine,arrayOk:!0,editType:\"style\"},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0,editType:\"style\"},editType:\"calc\"},editType:\"calc\"},text:{valType:\"data_array\",editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"value\",\"percent\"],extras:[\"none\"],editType:\"calc\"},hoverinfo:l({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:s({},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"auto\",arrayOk:!0,editType:\"plot\"},textfont:l({},c,{}),insidetextfont:l({},c,{}),outsidetextfont:l({},c,{}),title:{text:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:l({},c,{}),position:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"plot\"},editType:\"plot\"},domain:i({name:\"pie\",trace:!0,editType:\"calc\"}),hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},sort:{valType:\"boolean\",dflt:!0,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"number\",min:-360,max:360,dflt:0,editType:\"calc\"},pull:{valType:\"number\",min:0,max:1,dflt:0,arrayOk:!0,editType:\"calc\"},_deprecated:{title:{valType:\"string\",dflt:\"\",editType:\"calc\"},titlefont:l({},c,{}),titleposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"calc\"}}}},{\"../../components/color/attributes\":592,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1087:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData;r.name=\"pie\",r.plot=function(t){var e=n.getModule(\"pie\"),r=i(t.calcdata,e)[0];e.plot(t,r)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"pie\"),a=e._has&&e._has(\"pie\");i&&!a&&n._pielayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],1088:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"tinycolor2\"),o=t(\"../../components/color\"),s=t(\"./helpers\"),l=t(\"../../lib\").isValidTextValue,c={};function u(t){return function(e,r){return!!e&&(!!(e=a(e)).isValid()&&(e=o.addOpacity(e,e.getAlpha()),t[r]||(t[r]=e),e))}}function h(t,e){var r,n=JSON.stringify(t),i=e[n];if(!i){for(i=t.slice(),r=0;r<t.length;r++)i.push(a(t[r]).lighten(20).toHexString());for(r=0;r<t.length;r++)i.push(a(t[r]).darken(20).toHexString());e[n]=i}return i}e.exports={calc:function(t,e){var r,a,o=[],c=t._fullLayout,h=c.hiddenlabels||[],f=e.labels,p=e.marker.colors||[],d=e.values,g=i(d)&&d.length;if(e.dlabel)for(f=new Array(d.length),r=0;r<d.length;r++)f[r]=String(e.label0+r*e.dlabel);var v={},m=u(c[\"_\"+e.type+\"colormap\"]),y=(g?d:f).length,x=0,b=!1;for(r=0;r<y;r++){var _,w,k;if(g){if(_=d[r],!n(_))continue;if((_=+_)<0)continue}else _=1;void 0!==(w=f[r])&&\"\"!==w||(w=r);var T=v[w=String(w)];void 0===T?(v[w]=o.length,(k=-1!==h.indexOf(w))||(x+=_),o.push({v:_,label:w,color:m(p[r],w),i:r,pts:[r],hidden:k})):(b=!0,(a=o[T]).v+=_,a.pts.push(r),a.hidden||(x+=_),!1===a.color&&p[r]&&(a.color=m(p[r],w)))}(\"funnelarea\"===e.type?b:e.sort)&&o.sort(function(t,e){return e.v-t.v}),o[0]&&(o[0].vTotal=x);var A=e.textinfo;if(A&&\"none\"!==A){var M,S=A.split(\"+\"),E=function(t){return-1!==S.indexOf(t)},C=E(\"label\"),L=E(\"text\"),P=E(\"value\"),O=E(\"percent\"),z=c.separators;for(r=0;r<o.length;r++){if(a=o[r],M=C?[a.label]:[],L){var I=s.getFirstFilled(e.text,a.pts);l(I)&&M.push(I)}P&&M.push(s.formatPieValue(a.v,z)),O&&M.push(s.formatPiePercent(a.v/x,z)),a.text=M.join(\"<br>\")}}return o},crossTraceCalc:function(t,e){var r=(e||{}).type;r||(r=\"pie\");var n=t._fullLayout,i=t.calcdata,a=n[r+\"colorway\"],o=n[\"_\"+r+\"colormap\"];n[\"extend\"+r+\"colors\"]&&(a=h(a,c));for(var s=0,l=0;l<i.length;l++){var u=i[l];if(u[0].trace.type===r)for(var f=0;f<u.length;f++){var p=u[f];!1===p.color&&(o[p.label]?p.color=o[p.label]:(o[p.label]=p.color=a[s%a.length],s++))}}},makePullColorFn:u,generateExtendedColors:h}},{\"../../components/color\":593,\"../../lib\":719,\"./helpers\":1091,\"fast-isnumeric\":225,tinycolor2:537}],1089:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}var c,u=l(\"values\"),h=n.isArrayOrTypedArray(u),f=l(\"labels\");if(Array.isArray(f)?(c=f.length,h&&(c=Math.min(c,u.length))):h&&(c=u.length,l(\"label0\"),l(\"dlabel\")),c){e._length=c,l(\"marker.line.width\")&&l(\"marker.line.color\"),l(\"marker.colors\"),l(\"scalegroup\");var p=l(\"text\"),d=l(\"textinfo\",Array.isArray(p)?\"text+percent\":\"percent\");if(l(\"hovertext\"),l(\"hovertemplate\"),d&&\"none\"!==d){var g=l(\"textposition\");o(t,e,s,l,g,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}a(e,s,l);var v=l(\"hole\");if(l(\"title.text\")){var m=l(\"title.position\",v?\"middle center\":\"top center\");v||\"middle center\"!==m||(e.title.position=\"top center\"),n.coerceFont(l,\"title.font\",s.font)}l(\"sort\"),l(\"direction\"),l(\"rotation\"),l(\"pull\")}else e.visible=!1}},{\"../../lib\":719,\"../../plots/domain\":792,\"../bar/defaults\":861,\"./attributes\":1086}],1090:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/helpers\").appendArrayMultiPointValues;e.exports=function(t,e){var r={curveNumber:e.index,pointNumbers:t.pts,data:e._input,fullData:e,label:t.label,color:t.color,value:t.v,percent:t.percent,text:t.text,v:t.v};return 1===t.pts.length&&(r.pointNumber=r.i=t.pts[0]),n(r,e,t.pts),\"funnelarea\"===e.type&&(delete r.v,delete r.i),r}},{\"../../components/fx/helpers\":628}],1091:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");r.formatPiePercent=function(t,e){var r=(100*t).toPrecision(3);return-1!==r.lastIndexOf(\".\")&&(r=r.replace(/[.]?0+$/,\"\")),n.numSeparate(r,e)+\"%\"},r.formatPieValue=function(t,e){var r=t.toPrecision(10);return-1!==r.lastIndexOf(\".\")&&(r=r.replace(/[.]?0+$/,\"\")),n.numSeparate(r,e)},r.getFirstFilled=function(t,e){if(Array.isArray(t))for(var r=0;r<e.length;r++){var n=t[e[r]];if(n||0===n)return n}},r.castOption=function(t,e){return Array.isArray(t)?r.getFirstFilled(t,e):t||void 0}},{\"../../lib\":719}],1092:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),layoutAttributes:t(\"./layout_attributes\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\"),styleOne:t(\"./style_one\"),moduleType:\"trace\",name:\"pie\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"pie\",\"showLegend\"],meta:{}}},{\"./attributes\":1086,\"./base_plot\":1087,\"./calc\":1088,\"./defaults\":1089,\"./layout_attributes\":1093,\"./layout_defaults\":1094,\"./plot\":1095,\"./style\":1096,\"./style_one\":1097}],1093:[function(t,e,r){\"use strict\";e.exports={hiddenlabels:{valType:\"data_array\",editType:\"calc\"},piecolorway:{valType:\"colorlist\",editType:\"calc\"},extendpiecolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1094:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"piecolorway\",e.colorway),r(\"extendpiecolors\")}},{\"../../lib\":719,\"./layout_attributes\":1093}],1095:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/fx\"),a=t(\"../../components/color\"),o=t(\"../../components/drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"./helpers\"),u=t(\"./event_data\");function h(t,e,r){var a=r[0],o=a.trace,l=a.cx,h=a.cy;\"_hasHoverLabel\"in o||(o._hasHoverLabel=!1),\"_hasHoverEvent\"in o||(o._hasHoverEvent=!1),t.on(\"mouseover\",function(t){var r=e._fullLayout,f=e._fullData[o.index];if(!e._dragging&&!1!==r.hovermode){var p=f.hoverinfo;if(Array.isArray(p)&&(p=i.castHoverinfo({hoverinfo:[c.castOption(p,t.pts)],_module:o._module},r,0)),\"all\"===p&&(p=\"label+text+value+percent+name\"),f.hovertemplate||\"none\"!==p&&\"skip\"!==p&&p){var d=t.rInscribed||0,g=l+t.pxmid[0]*(1-d),v=h+t.pxmid[1]*(1-d),m=r.separators,y=[];if(p&&-1!==p.indexOf(\"label\")&&y.push(t.label),t.text=c.castOption(f.hovertext||f.text,t.pts),p&&-1!==p.indexOf(\"text\")){var x=t.text;s.isValidTextValue(x)&&y.push(x)}t.value=t.v,t.valueLabel=c.formatPieValue(t.v,m),p&&-1!==p.indexOf(\"value\")&&y.push(t.valueLabel),t.percent=t.v/a.vTotal,t.percentLabel=c.formatPiePercent(t.percent,m),p&&-1!==p.indexOf(\"percent\")&&y.push(t.percentLabel);var b=f.hoverlabel,_=b.font;i.loneHover({trace:o,x0:g-d*a.r,x1:g+d*a.r,y:v,text:y.join(\"<br>\"),name:f.hovertemplate||-1!==p.indexOf(\"name\")?f.name:void 0,idealAlign:t.pxmid[0]<0?\"left\":\"right\",color:c.castOption(b.bgcolor,t.pts)||t.color,borderColor:c.castOption(b.bordercolor,t.pts),fontFamily:c.castOption(_.family,t.pts),fontSize:c.castOption(_.size,t.pts),fontColor:c.castOption(_.color,t.pts),nameLength:c.castOption(b.namelength,t.pts),textAlign:c.castOption(b.align,t.pts),hovertemplate:c.castOption(f.hovertemplate,t.pts),hovertemplateLabels:t,eventData:[u(t,f)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e}),o._hasHoverLabel=!0}o._hasHoverEvent=!0,e.emit(\"plotly_hover\",{points:[u(t,f)],event:n.event})}}),t.on(\"mouseout\",function(t){var r=e._fullLayout,a=e._fullData[o.index],s=n.select(this).datum();o._hasHoverEvent&&(t.originalEvent=n.event,e.emit(\"plotly_unhover\",{points:[u(s,a)],event:n.event}),o._hasHoverEvent=!1),o._hasHoverLabel&&(i.loneUnhover(r._hoverlayer.node()),o._hasHoverLabel=!1)}),t.on(\"click\",function(t){var r=e._fullLayout,a=e._fullData[o.index];e._dragging||!1===r.hovermode||(e._hoverdata=[u(t,a)],i.click(e,n.event))})}function f(t,e,r){var n=c.castOption(t.insidetextfont.color,e.pts);!n&&t._input.textfont&&(n=c.castOption(t._input.textfont.color,e.pts));var i=c.castOption(t.insidetextfont.family,e.pts)||c.castOption(t.textfont.family,e.pts)||r.family,o=c.castOption(t.insidetextfont.size,e.pts)||c.castOption(t.textfont.size,e.pts)||r.size;return{color:n||a.contrast(e.color),family:i,size:o}}function p(t,e){for(var r,n,i=0;i<t.length;i++)if((n=(r=t[i][0]).trace).title.text){var a=n.title.text;n._meta&&(a=s.templateString(a,n._meta));var c=o.tester.append(\"text\").attr(\"data-notex\",1).text(a).call(o.font,n.title.font).call(l.convertToTspans,e),u=o.bBox(c.node(),!0);r.titleBox={width:u.width,height:u.height},c.remove()}}function d(t,e,r){var n=Math.sqrt(t.width*t.width+t.height*t.height),i=t.width/t.height,a=e.halfangle,o=e.ring,s=e.rInscribed,l=r.r||e.rpx1,c={scale:s*l*2/n,rCenter:1-s,rotate:0};if(c.scale>=1)return c;var u=i+1/(2*Math.tan(a)),h=l*Math.min(1/(Math.sqrt(u*u+.5)+u),o/(Math.sqrt(i*i+o/2)+i)),f={scale:2*h/t.height,rCenter:Math.cos(h/l)-h*i/l,rotate:(180/Math.PI*e.midangle+720)%180-90},p=1/i,d=p+1/(2*Math.tan(a)),g=l*Math.min(1/(Math.sqrt(d*d+.5)+d),o/(Math.sqrt(p*p+o/2)+p)),v={scale:2*g/t.width,rCenter:Math.cos(g/l)-g/i/l,rotate:(180/Math.PI*e.midangle+810)%180-90},m=v.scale>f.scale?v:f;return c.scale<1&&m.scale>c.scale?m:c}function g(t,e){return t.v!==e.vTotal||e.trace.hole?Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2):1}function v(t,e){var r=e.pxmid[0],n=e.pxmid[1],i=t.width/2,a=t.height/2;return r<0&&(i*=-1),n<0&&(a*=-1),{scale:1,rCenter:1,rotate:0,x:i+Math.abs(a)*(i>0?1:-1)/2,y:a/(1+r*r/(n*n)),outside:!0}}function m(t,e){var r,n,i,a=t.trace,o={x:t.cx,y:t.cy},s={tx:0,ty:0};s.ty+=a.title.font.size,i=x(a),-1!==a.title.position.indexOf(\"top\")?(o.y-=(1+i)*t.r,s.ty-=t.titleBox.height):-1!==a.title.position.indexOf(\"bottom\")&&(o.y+=(1+i)*t.r);var l,c,u=(l=t.r,c=t.trace.aspectratio,l/(void 0===c?1:c)),h=e.w*(a.domain.x[1]-a.domain.x[0])/2;return-1!==a.title.position.indexOf(\"left\")?(h+=u,o.x-=(1+i)*u,s.tx+=t.titleBox.width/2):-1!==a.title.position.indexOf(\"center\")?h*=2:-1!==a.title.position.indexOf(\"right\")&&(h+=u,o.x+=(1+i)*u,s.tx-=t.titleBox.width/2),r=h/t.titleBox.width,n=y(t,e)/t.titleBox.height,{x:o.x,y:o.y,scale:Math.min(r,n),tx:s.tx,ty:s.ty}}function y(t,e){var r=t.trace,n=e.h*(r.domain.y[1]-r.domain.y[0]);return Math.min(t.titleBox.height,n/2)}function x(t){var e,r=t.pull;if(!r)return 0;if(Array.isArray(r))for(r=0,e=0;e<t.pull.length;e++)t.pull[e]>r&&(r=t.pull[e]);return r}function b(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n][0],a=i.trace,o=a.domain,s=e.w*(o.x[1]-o.x[0]),l=e.h*(o.y[1]-o.y[0]);a.title.text&&\"middle center\"!==a.title.position&&(l-=y(i,e));var c=s/2,u=l/2;\"funnelarea\"!==a.type||a.scalegroup||(u/=a.aspectratio),i.r=Math.min(c,u)/(1+x(a)),i.cx=e.l+e.w*(a.domain.x[1]+a.domain.x[0])/2,i.cy=e.t+e.h*(1-a.domain.y[0])-l/2,a.title.text&&-1!==a.title.position.indexOf(\"bottom\")&&(i.cy-=y(i,e)),a.scalegroup&&-1===r.indexOf(a.scalegroup)&&r.push(a.scalegroup)}!function(t,e){for(var r,n,i,a=0;a<e.length;a++){var o=1/0,s=e[a];for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var l;if(\"pie\"===i.type)l=r.r*r.r;else if(\"funnelarea\"===i.type){var c,u;i.aspectratio>1?(c=r.r,u=c/i.aspectratio):(u=r.r,c=u*i.aspectratio),c*=(1+i.baseratio)/2,l=c*u}o=Math.min(o,l/r.vTotal)}for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var h=o*r.vTotal;\"funnelarea\"===i.type&&(h/=(1+i.baseratio)/2,h/=i.aspectratio),r.r=Math.sqrt(h)}}}(t,r)}e.exports={plot:function(t,e){var r=t._fullLayout;p(e,t),b(e,r._size);var i=s.makeTraceGroups(r._pielayer,e,\"trace\").each(function(e){var i=n.select(this),u=e[0],p=u.trace;!function(t){var e,r,n,i=t[0],a=i.trace,o=a.rotation*Math.PI/180,s=2*Math.PI/i.vTotal,l=\"px0\",c=\"px1\";if(\"counterclockwise\"===a.direction){for(e=0;e<t.length&&t[e].hidden;e++);if(e===t.length)return;o+=s*t[e].v,s*=-1,l=\"px1\",c=\"px0\"}function u(t){return[i.r*Math.sin(t),-i.r*Math.cos(t)]}for(n=u(o),e=0;e<t.length;e++)(r=t[e]).hidden||(r[l]=n,o+=s*r.v/2,r.pxmid=u(o),r.midangle=o,o+=s*r.v/2,n=u(o),r[c]=n,r.largeArc=r.v>i.vTotal/2?1:0,r.halfangle=Math.PI*Math.min(r.v/i.vTotal,.5),r.ring=1-a.hole,r.rInscribed=g(r,i))}(e),i.attr(\"stroke-linejoin\",\"round\"),i.each(function(){var i=n.select(this).selectAll(\"g.slice\").data(e);i.enter().append(\"g\").classed(\"slice\",!0),i.exit().remove();var g=[[[],[]],[[],[]]],y=!1;i.each(function(r){if(r.hidden)n.select(this).selectAll(\"path,g\").remove();else{r.pointNumber=r.i,r.curveNumber=p.index,g[r.pxmid[1]<0?0:1][r.pxmid[0]<0?0:1].push(r);var i=u.cx,a=u.cy,m=n.select(this),x=m.selectAll(\"path.surface\").data([r]);if(x.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),m.call(h,t,e),p.pull){var b=+c.castOption(p.pull,r.pts)||0;b>0&&(i+=b*r.pxmid[0],a+=b*r.pxmid[1])}r.cxFinal=i,r.cyFinal=a;var _=p.hole;if(r.v===u.vTotal){var w=\"M\"+(i+r.px0[0])+\",\"+(a+r.px0[1])+S(r.px0,r.pxmid,!0,1)+S(r.pxmid,r.px0,!0,1)+\"Z\";_?x.attr(\"d\",\"M\"+(i+_*r.px0[0])+\",\"+(a+_*r.px0[1])+S(r.px0,r.pxmid,!1,_)+S(r.pxmid,r.px0,!1,_)+\"Z\"+w):x.attr(\"d\",w)}else{var k=S(r.px0,r.px1,!0,1);if(_){var T=1-_;x.attr(\"d\",\"M\"+(i+_*r.px1[0])+\",\"+(a+_*r.px1[1])+S(r.px1,r.px0,!1,_)+\"l\"+T*r.px0[0]+\",\"+T*r.px0[1]+k+\"Z\")}else x.attr(\"d\",\"M\"+i+\",\"+a+\"l\"+r.px0[0]+\",\"+r.px0[1]+k+\"Z\")}var A=c.castOption(p.textposition,r.pts),M=m.selectAll(\"g.slicetext\").data(r.text&&\"none\"!==A?[0]:[]);M.enter().append(\"g\").classed(\"slicetext\",!0),M.exit().remove(),M.each(function(){var e=s.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)});e.text(r.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(o.font,\"outside\"===A?function(t,e,r){var n=c.castOption(t.outsidetextfont.color,e.pts)||c.castOption(t.textfont.color,e.pts)||r.color,i=c.castOption(t.outsidetextfont.family,e.pts)||c.castOption(t.textfont.family,e.pts)||r.family,a=c.castOption(t.outsidetextfont.size,e.pts)||c.castOption(t.textfont.size,e.pts)||r.size;return{color:n,family:i,size:a}}(p,r,t._fullLayout.font):f(p,r,t._fullLayout.font)).call(l.convertToTspans,t);var h,g=o.bBox(e.node());\"outside\"===A?h=v(g,r):(h=d(g,r,u),\"auto\"===A&&h.scale<1&&(e.call(o.font,p.outsidetextfont),p.outsidetextfont.family===p.insidetextfont.family&&p.outsidetextfont.size===p.insidetextfont.size||(g=o.bBox(e.node())),h=v(g,r)));var m=i+r.pxmid[0]*h.rCenter+(h.x||0),x=a+r.pxmid[1]*h.rCenter+(h.y||0);h.outside&&(r.yLabelMin=x-g.height/2,r.yLabelMid=x,r.yLabelMax=x+g.height/2,r.labelExtraX=0,r.labelExtraY=0,y=!0),e.attr(\"transform\",\"translate(\"+m+\",\"+x+\")\"+(h.scale<1?\"scale(\"+h.scale+\")\":\"\")+(h.rotate?\"rotate(\"+h.rotate+\")\":\"\")+\"translate(\"+-(g.left+g.right)/2+\",\"+-(g.top+g.bottom)/2+\")\")})}function S(t,e,n,i){var a=i*(e[0]-t[0]),o=i*(e[1]-t[1]);return\"a\"+i*u.r+\",\"+i*u.r+\" 0 \"+r.largeArc+(n?\" 1 \":\" 0 \")+a+\",\"+o}});var x=n.select(this).selectAll(\"g.titletext\").data(p.title.text?[0]:[]);x.enter().append(\"g\").classed(\"titletext\",!0),x.exit().remove(),x.each(function(){var e,i=s.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),a=p.title.text;p._meta&&(a=s.templateString(a,p._meta)),i.text(a).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(o.font,p.title.font).call(l.convertToTspans,t),e=\"middle center\"===p.title.position?function(t){var e=Math.sqrt(t.titleBox.width*t.titleBox.width+t.titleBox.height*t.titleBox.height);return{x:t.cx,y:t.cy,scale:t.trace.hole*t.r*2/e,tx:0,ty:-t.titleBox.height/2+t.trace.title.font.size}}(u):m(u,r._size),i.attr(\"transform\",\"translate(\"+e.x+\",\"+e.y+\")\"+(e.scale<1?\"scale(\"+e.scale+\")\":\"\")+\"translate(\"+e.tx+\",\"+e.ty+\")\")}),y&&function(t,e){var r,n,i,a,o,s,l,u,h,f,p,d,g;function v(t,e){return t.pxmid[1]-e.pxmid[1]}function m(t,e){return e.pxmid[1]-t.pxmid[1]}function y(t,r){r||(r={});var i,u,h,p,d,g,v=r.labelExtraY+(n?r.yLabelMax:r.yLabelMin),m=n?t.yLabelMin:t.yLabelMax,y=n?t.yLabelMax:t.yLabelMin,x=t.cyFinal+o(t.px0[1],t.px1[1]),b=v-m;if(b*l>0&&(t.labelExtraY=b),Array.isArray(e.pull))for(u=0;u<f.length;u++)(h=f[u])===t||(c.castOption(e.pull,t.pts)||0)>=(c.castOption(e.pull,h.pts)||0)||((t.pxmid[1]-h.pxmid[1])*l>0?(p=h.cyFinal+o(h.px0[1],h.px1[1]),(b=p-m-t.labelExtraY)*l>0&&(t.labelExtraY+=b)):(y+t.labelExtraY-x)*l>0&&(i=3*s*Math.abs(u-f.indexOf(t)),d=h.cxFinal+a(h.px0[0],h.px1[0]),(g=d+i-(t.cxFinal+t.pxmid[0])-t.labelExtraX)*s>0&&(t.labelExtraX+=g)))}for(n=0;n<2;n++)for(i=n?v:m,o=n?Math.max:Math.min,l=n?1:-1,r=0;r<2;r++){for(a=r?Math.max:Math.min,s=r?1:-1,(u=t[n][r]).sort(i),h=t[1-n][r],f=h.concat(u),d=[],p=0;p<u.length;p++)void 0!==u[p].yLabelMid&&d.push(u[p]);for(g=!1,p=0;n&&p<h.length;p++)if(void 0!==h[p].yLabelMid){g=h[p];break}for(p=0;p<d.length;p++){var x=p&&d[p-1];g&&!p&&(x=g),y(d[p],x)}}}(g,p),function(t,e){t.each(function(t){var r=n.select(this);if(t.labelExtraX||t.labelExtraY){var i=r.select(\"g.slicetext text\");i.attr(\"transform\",\"translate(\"+t.labelExtraX+\",\"+t.labelExtraY+\")\"+i.attr(\"transform\"));var o=t.cxFinal+t.pxmid[0],l=t.cyFinal+t.pxmid[1],c=\"M\"+o+\",\"+l,u=(t.yLabelMax-t.yLabelMin)*(t.pxmid[0]<0?-1:1)/4;if(t.labelExtraX){var h=t.labelExtraX*t.pxmid[1]/t.pxmid[0],f=t.yLabelMid+t.labelExtraY-(t.cyFinal+t.pxmid[1]);Math.abs(h)>Math.abs(f)?c+=\"l\"+f*t.pxmid[0]/t.pxmid[1]+\",\"+f+\"H\"+(o+t.labelExtraX+u):c+=\"l\"+t.labelExtraX+\",\"+h+\"v\"+(f-h)+\"h\"+u}else c+=\"V\"+(t.yLabelMid+t.labelExtraY)+\"h\"+u;s.ensureSingle(r,\"path\",\"textline\").call(a.stroke,e.outsidetextfont.color).attr({\"stroke-width\":Math.min(2,e.outsidetextfont.size/8),d:c,fill:\"none\"})}else r.select(\"path.textline\").remove()})}(i,p)})});setTimeout(function(){i.selectAll(\"tspan\").each(function(){var t=n.select(this);t.attr(\"dy\")&&t.attr(\"dy\",t.attr(\"dy\"))})},0)},transformInsideText:d,determineInsideTextFont:f,positionTitleOutside:m,prerenderTitles:p,layoutAreas:b,attachFxHandlers:h}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"./event_data\":1090,\"./helpers\":1091,d3:163}],1096:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./style_one\");e.exports=function(t){t._fullLayout._pielayer.selectAll(\".trace\").each(function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each(function(t){n.select(this).call(i,t,e)})})}},{\"./style_one\":1097,d3:163}],1097:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./helpers\").castOption;e.exports=function(t,e,r){var a=r.marker.line,o=i(a.color,e.pts)||n.defaultLine,s=i(a.width,e.pts)||0;t.style(\"stroke-width\",s).call(n.fill,e.color).call(n.stroke,o)}},{\"../../components/color\":593,\"./helpers\":1091}],1098:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\");e.exports={x:n.x,y:n.y,xy:{valType:\"data_array\",editType:\"calc\"},indices:{valType:\"data_array\",editType:\"calc\"},xbounds:{valType:\"data_array\",editType:\"calc\"},ybounds:{valType:\"data_array\",editType:\"calc\"},text:n.text,marker:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,arrayOk:!1,editType:\"calc\"},blend:{valType:\"boolean\",dflt:null,editType:\"calc\"},sizemin:{valType:\"number\",min:.1,max:2,dflt:.5,editType:\"calc\"},sizemax:{valType:\"number\",min:.1,dflt:20,editType:\"calc\"},border:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},arearatio:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},transforms:void 0}},{\"../scatter/attributes\":1112}],1099:[function(t,e,r){\"use strict\";var n=t(\"gl-pointcloud2d\"),i=t(\"../../lib/str2rgbarray\"),a=t(\"../../plots/cartesian/autorange\").findExtremes,o=t(\"../scatter/get_trace_color\");function s(t,e){this.scene=t,this.uid=e,this.type=\"pointcloud\",this.pickXData=[],this.pickYData=[],this.xData=[],this.yData=[],this.textLabels=[],this.color=\"rgb(0, 0, 0)\",this.name=\"\",this.hoverinfo=\"all\",this.idToIndex=new Int32Array(0),this.bounds=[0,0,0,0],this.pointcloudOptions={positions:new Float32Array(0),idToIndex:this.idToIndex,sizemin:.5,sizemax:12,color:[0,0,0,1],areaRatio:1,borderColor:[0,0,0,1]},this.pointcloud=n(t.glplot,this.pointcloudOptions),this.pointcloud._trace=this}var l=s.prototype;l.handlePick=function(t){var e=this.idToIndex[t.pointId];return{trace:this,dataCoord:t.dataCoord,traceCoord:this.pickXYData?[this.pickXYData[2*e],this.pickXYData[2*e+1]]:[this.pickXData[e],this.pickYData[e]],textLabel:Array.isArray(this.textLabels)?this.textLabels[e]:this.textLabels,color:this.color,name:this.name,pointIndex:e,hoverinfo:this.hoverinfo}},l.update=function(t){this.index=t.index,this.textLabels=t.text,this.name=t.name,this.hoverinfo=t.hoverinfo,this.bounds=[1/0,1/0,-1/0,-1/0],this.updateFast(t),this.color=o(t,{})},l.updateFast=function(t){var e,r,n,o,s,l,c=this.xData=this.pickXData=t.x,u=this.yData=this.pickYData=t.y,h=this.pickXYData=t.xy,f=t.xbounds&&t.ybounds,p=t.indices,d=this.bounds;if(h){if(n=h,e=h.length>>>1,f)d[0]=t.xbounds[0],d[2]=t.xbounds[1],d[1]=t.ybounds[0],d[3]=t.ybounds[1];else for(l=0;l<e;l++)o=n[2*l],s=n[2*l+1],o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);if(p)r=p;else for(r=new Int32Array(e),l=0;l<e;l++)r[l]=l}else for(e=c.length,n=new Float32Array(2*e),r=new Int32Array(e),l=0;l<e;l++)o=c[l],s=u[l],r[l]=l,n[2*l]=o,n[2*l+1]=s,o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);this.idToIndex=r,this.pointcloudOptions.idToIndex=r,this.pointcloudOptions.positions=n;var g=i(t.marker.color),v=i(t.marker.border.color),m=t.opacity*t.marker.opacity;g[3]*=m,this.pointcloudOptions.color=g;var y=t.marker.blend;if(null===y){y=c.length<100||u.length<100}this.pointcloudOptions.blend=y,v[3]*=m,this.pointcloudOptions.borderColor=v;var x=t.marker.sizemin,b=Math.max(t.marker.sizemax,t.marker.sizemin);this.pointcloudOptions.sizeMin=x,this.pointcloudOptions.sizeMax=b,this.pointcloudOptions.areaRatio=t.marker.border.arearatio,this.pointcloud.update(this.pointcloudOptions);var _=this.scene.xaxis,w=this.scene.yaxis,k=b/2||.5;t._extremes[_._id]=a(_,[d[0],d[2]],{ppad:k}),t._extremes[w._id]=a(w,[d[1],d[3]],{ppad:k})},l.dispose=function(){this.pointcloud.dispose()},e.exports=function(t,e){var r=new s(t,e.uid);return r.update(e),r}},{\"../../lib/str2rgbarray\":742,\"../../plots/cartesian/autorange\":766,\"../scatter/get_trace_color\":1121,\"gl-pointcloud2d\":292}],1100:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\");e.exports=function(t,e,r){function a(r,a){return n.coerce(t,e,i,r,a)}a(\"x\"),a(\"y\"),a(\"xbounds\"),a(\"ybounds\"),t.xy&&t.xy instanceof Float32Array&&(e.xy=t.xy),t.indices&&t.indices instanceof Int32Array&&(e.indices=t.indices),a(\"text\"),a(\"marker.color\",r),a(\"marker.opacity\"),a(\"marker.blend\"),a(\"marker.sizemin\"),a(\"marker.sizemax\"),a(\"marker.border.color\",r),a(\"marker.border.arearatio\"),e._length=null}},{\"../../lib\":719,\"./attributes\":1098}],1101:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../scatter3d/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"pointcloud\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"showLegend\"],meta:{}}},{\"../../plots/gl2d\":805,\"../scatter3d/calc\":1139,\"./attributes\":1098,\"./convert\":1099,\"./defaults\":1100}],1102:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../components/fx/attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../../components/fx/hovertemplate_attributes\"),c=t(\"../../components/colorscale/attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,h=t(\"../../lib/extend\").extendFlat,f=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=f({hoverinfo:h({},i.hoverinfo,{flags:[],arrayOk:!1}),hoverlabel:o.hoverlabel,domain:s({name:\"sankey\",trace:!0}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\"},valueformat:{valType:\"string\",dflt:\".3s\"},valuesuffix:{valType:\"string\",dflt:\"\"},arrangement:{valType:\"enumerated\",values:[\"snap\",\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"snap\"},textfont:n({}),node:{label:{valType:\"data_array\",dflt:[]},groups:{valType:\"info_array\",impliedEdits:{x:[],y:[]},dimensions:2,freeLength:!0,dflt:[],items:{valType:\"number\",editType:\"calc\"}},x:{valType:\"data_array\",dflt:[]},y:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:.5,arrayOk:!0}},pad:{valType:\"number\",arrayOk:!1,min:0,dflt:20},thickness:{valType:\"number\",arrayOk:!1,min:1,dflt:20},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]})},link:{label:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0}},source:{valType:\"data_array\",dflt:[]},target:{valType:\"data_array\",dflt:[]},value:{valType:\"data_array\",dflt:[]},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]}),colorscales:u(\"concentrationscales\",{editType:\"calc\",label:{valType:\"string\",editType:\"calc\",dflt:\"\"},cmax:{valType:\"number\",editType:\"calc\",dflt:1},cmin:{valType:\"number\",editType:\"calc\",dflt:0},colorscale:h(c().colorscale,{dflt:[[0,\"white\"],[1,\"black\"]]})})}},\"calc\",\"nested\")).transforms=void 0},{\"../../components/color/attributes\":592,\"../../components/colorscale/attributes\":600,\"../../components/fx/attributes\":623,\"../../components/fx/hovertemplate_attributes\":631,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1103:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../components/fx/layout_attributes\"),s=t(\"../../lib/setcursor\"),l=t(\"../../components/dragelement\"),c=t(\"../../plots/cartesian/select\").prepSelect,u=t(\"../../lib\"),h=t(\"../../registry\");function f(t,e){var r=t._fullData[e],n=t._fullLayout,i=n.dragmode,a=\"pan\"===n.dragmode?\"move\":\"crosshair\",o=r._bgRect;if(\"pan\"!==i&&\"zoom\"!==i){s(o,a);var f={_id:\"x\",c2p:u.identity,_offset:r._sankey.translateX,_length:r._sankey.width},p={_id:\"y\",c2p:u.identity,_offset:r._sankey.translateY,_length:r._sankey.height},d={gd:t,element:o.node(),plotinfo:{id:e,xaxis:f,yaxis:p,fillRangeItems:u.noop},subplot:e,xaxes:[f],yaxes:[p],doneFnCompleted:function(r){var n,i=t._fullData[e],a=i.node.groups.slice(),o=[];function s(t){for(var e=i._sankey.graph.nodes,r=0;r<e.length;r++)if(e[r].pointNumber===t)return e[r]}for(var l=0;l<r.length;l++){var c=s(r[l].pointNumber);if(c)if(c.group){for(var u=0;u<c.childrenNodes.length;u++)o.push(c.childrenNodes[u].pointNumber);a[c.pointNumber-i.node._count]=!1}else o.push(c.pointNumber)}n=a.filter(Boolean).concat([o]),h.call(\"_guiRestyle\",t,{\"node.groups\":[n]},e)},prepFn:function(t,e,r){c(t,e,r,d,i)}};l.init(d)}}r.name=\"sankey\",r.baseLayoutAttrOverrides=n({hoverlabel:o.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){var e=i(t.calcdata,\"sankey\")[0];a(t,e),r.updateFx(t)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"sankey\"),a=e._has&&e._has(\"sankey\");i&&!a&&(n._paperdiv.selectAll(\".sankey\").remove(),n._paperdiv.selectAll(\".bgsankey\").remove())},r.updateFx=function(t){for(var e=0;e<t._fullData.length;e++)f(t,e)}},{\"../../components/dragelement\":611,\"../../components/fx/layout_attributes\":633,\"../../lib\":719,\"../../lib/setcursor\":739,\"../../plot_api/edit_types\":750,\"../../plots/cartesian/select\":784,\"../../plots/get_data\":802,\"../../registry\":847,\"./plot\":1108}],1104:[function(t,e,r){\"use strict\";var n=t(\"strongly-connected-components\"),i=t(\"../../lib\"),a=t(\"../../lib/gup\").wrap,o=i.isArrayOrTypedArray,s=i.isIndex,l=t(\"../../components/colorscale\");function c(t){var e,r=t.node,a=t.link,c=[],u=o(a.color),h={},f={},p=a.colorscales.length;for(e=0;e<p;e++){var d=a.colorscales[e],g=l.extractScale(d,{cLetter:\"c\"}),v=l.makeColorScaleFunc(g);f[d.label]=v}var m=0;for(e=0;e<a.value.length;e++)a.source[e]>m&&(m=a.source[e]),a.target[e]>m&&(m=a.target[e]);var y,x=m+1;t.node._count=x;var b=t.node.groups,_={};for(e=0;e<b.length;e++){var w=b[e];for(y=0;y<w.length;y++){var k=w[y],T=x+e;_.hasOwnProperty(k)?i.warn(\"Node \"+k+\" is already part of a group.\"):_[k]=T}}var A={source:[],target:[]};for(e=0;e<a.value.length;e++){var M=a.value[e],S=a.source[e],E=a.target[e];if(M>0&&s(S,x)&&s(E,x)&&(!_.hasOwnProperty(S)||!_.hasOwnProperty(E)||_[S]!==_[E])){_.hasOwnProperty(E)&&(E=_[E]),_.hasOwnProperty(S)&&(S=_[S]),E=+E,h[S=+S]=h[E]=!0;var C=\"\";a.label&&a.label[e]&&(C=a.label[e]);var L=null;C&&f.hasOwnProperty(C)&&(L=f[C]),c.push({pointNumber:e,label:C,color:u?a.color[e]:a.color,concentrationscale:L,source:S,target:E,value:+M}),A.source.push(S),A.target.push(E)}}var P=x+b.length,O=o(r.color),z=[];for(e=0;e<P;e++)if(h[e]){var I=r.label[e];z.push({group:e>x-1,childrenNodes:[],pointNumber:e,label:I,color:O?r.color[e]:r.color})}var D=!1;return function(t,e,r){for(var a=i.init2dArray(t,0),o=0;o<Math.min(e.length,r.length);o++)if(i.isIndex(e[o],t)&&i.isIndex(r[o],t)){if(e[o]===r[o])return!0;a[e[o]].push(r[o])}return n(a).components.some(function(t){return t.length>1})}(P,A.source,A.target)&&(D=!0),{circular:D,links:c,nodes:z,groups:b,groupLookup:_}}e.exports=function(t,e){var r=c(e);return a({circular:r.circular,_nodes:r.nodes,_links:r.links,_groups:r.groups,_groupLookup:r.groupLookup})}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gup\":717,\"strongly-connected-components\":530}],1105:[function(t,e,r){\"use strict\";e.exports={nodeTextOffsetHorizontal:4,nodeTextOffsetVertical:3,nodePadAcross:10,sankeyIterations:50,forceIterations:5,forceTicksPerFrame:10,duration:500,ease:\"linear\",cn:{sankey:\"sankey\",sankeyLinks:\"sankey-links\",sankeyLink:\"sankey-link\",sankeyNodeSet:\"sankey-node-set\",sankeyNode:\"sankey-node\",nodeRect:\"node-rect\",nodeCapture:\"node-capture\",nodeCentered:\"node-entered\",nodeLabelGuide:\"node-label-guide\",nodeLabel:\"node-label\",nodeLabelTextPath:\"node-label-text-path\"}}},{}],1106:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../components/color\"),o=t(\"tinycolor2\"),s=t(\"../../plots/domain\").defaults,l=t(\"../../components/fx/hoverlabel_defaults\"),c=t(\"../../plot_api/plot_template\"),u=t(\"../../plots/array_container_defaults\");function h(t,e){function r(r,a){return n.coerce(t,e,i.link.colorscales,r,a)}r(\"label\"),r(\"cmin\"),r(\"cmax\"),r(\"colorscale\")}e.exports=function(t,e,r,f){function p(r,a){return n.coerce(t,e,i,r,a)}var d=n.extendDeep(f.hoverlabel,t.hoverlabel),g=t.node,v=c.newContainer(e,\"node\");function m(t,e){return n.coerce(g,v,i.node,t,e)}m(\"label\"),m(\"groups\"),m(\"x\"),m(\"y\"),m(\"pad\"),m(\"thickness\"),m(\"line.color\"),m(\"line.width\"),m(\"hoverinfo\",t.hoverinfo),l(g,v,m,d),m(\"hovertemplate\");var y=f.colorway;m(\"color\",v.label.map(function(t,e){return a.addOpacity(function(t){return y[t%y.length]}(e),.8)}));var x=t.link||{},b=c.newContainer(e,\"link\");function _(t,e){return n.coerce(x,b,i.link,t,e)}_(\"label\"),_(\"source\"),_(\"target\"),_(\"value\"),_(\"line.color\"),_(\"line.width\"),_(\"hoverinfo\",t.hoverinfo),l(x,b,_,d),_(\"hovertemplate\");var w,k=o(f.paper_bgcolor).getLuminance()<.333?\"rgba(255, 255, 255, 0.6)\":\"rgba(0, 0, 0, 0.2)\";_(\"color\",n.repeat(k,b.value.length)),u(x,b,{name:\"colorscales\",handleItemDefaults:h}),s(e,f,p),p(\"orientation\"),p(\"valueformat\"),p(\"valuesuffix\"),v.x.length&&v.y.length&&(w=\"freeform\"),p(\"arrangement\",w),n.coerceFont(p,\"textfont\",n.extendFlat({},f.font)),e._length=null}},{\"../../components/color\":593,\"../../components/fx/hoverlabel_defaults\":630,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/array_container_defaults\":763,\"../../plots/domain\":792,\"./attributes\":1102,tinycolor2:537}],1107:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"sankey\",basePlotModule:t(\"./base_plot\"),selectPoints:t(\"./select.js\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1102,\"./base_plot\":1103,\"./calc\":1104,\"./defaults\":1106,\"./plot\":1108,\"./select.js\":1110}],1108:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./render\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\"),l=t(\"./constants\").cn,c=s._;function u(t){return\"\"!==t}function h(t,e){return t.filter(function(t){return t.key===e.traceId})}function f(t,e){n.select(t).select(\"path\").style(\"fill-opacity\",e),n.select(t).select(\"rect\").style(\"fill-opacity\",e)}function p(t){n.select(t).select(\"text.name\").style(\"fill\",\"black\")}function d(t){return function(e){return-1!==t.node.sourceLinks.indexOf(e.link)||-1!==t.node.targetLinks.indexOf(e.link)}}function g(t){return function(e){return-1!==e.node.sourceLinks.indexOf(t.link)||-1!==e.node.targetLinks.indexOf(t.link)}}function v(t,e,r){e&&r&&h(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(y.bind(0,e,r,!1))}function m(t,e,r){e&&r&&h(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(x.bind(0,e,r,!1))}function y(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",function(t){if(!t.link.concentrationscale)return.4}),i&&h(e,t).selectAll(\".\"+l.sankeyLink).filter(function(t){return t.link.label===i}).style(\"fill-opacity\",function(t){if(!t.link.concentrationscale)return.4}),r&&h(e,t).selectAll(\".\"+l.sankeyNode).filter(g(t)).call(v)}function x(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),i&&h(e,t).selectAll(\".\"+l.sankeyLink).filter(function(t){return t.link.label===i}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),r&&h(e,t).selectAll(l.sankeyNode).filter(g(t)).call(m)}function b(t,e){var r=t.hoverlabel||{},n=s.nestedProperty(r,e).get();return!Array.isArray(n)&&n}e.exports=function(t,e){for(var r=t._fullLayout,s=r._paper,h=r._size,d=0;d<t._fullData.length;d++)if(t._fullData[d].type===l.sankey&&!t._fullData[d]._viewInitial){var g=t._fullData[d].node;t._fullData[d]._viewInitial={node:{groups:g.groups.slice(),x:g.x.slice(),y:g.y.slice()}}}var _=c(t,\"source:\")+\" \",w=c(t,\"target:\")+\" \",k=c(t,\"concentration:\")+\" \",T=c(t,\"incoming flow count:\")+\" \",A=c(t,\"outgoing flow count:\")+\" \";i(t,s,e,{width:h.w,height:h.h,margin:{t:h.t,r:h.r,b:h.b,l:h.l}},{linkEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(y.bind(0,r,i,!0)),\"skip\"!==r.link.trace.link.hoverinfo&&(r.link.fullData=r.link.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.link]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var s=i.link.trace.link;if(\"none\"!==s.hoverinfo&&\"skip\"!==s.hoverinfo){for(var l=[],c=0,h=0;h<i.flow.links.length;h++){var d=i.flow.links[h];if(\"closest\"!==t._fullLayout.hovermode||i.link.pointNumber===d.pointNumber){i.link.pointNumber===d.pointNumber&&(c=h),d.fullData=d.trace,s=i.link.trace.link;var g=m(d),v={valueLabel:n.format(i.valueFormat)(d.value)+i.valueSuffix};l.push({x:g[0],y:g[1],name:v.valueLabel,text:[d.label||\"\",_+d.source.label,w+d.target.label,d.concentrationscale?k+n.format(\"%0.2f\")(d.flow.labelConcentration):\"\"].filter(u).join(\"<br>\"),color:b(s,\"bgcolor\")||o.addOpacity(d.color,1),borderColor:b(s,\"bordercolor\"),fontFamily:b(s,\"font.family\"),fontSize:b(s,\"font.size\"),fontColor:b(s,\"font.color\"),nameLength:b(s,\"namelength\"),textAlign:b(s,\"align\"),idealAlign:n.event.x<g[0]?\"right\":\"left\",hovertemplate:s.hovertemplate,hovertemplateLabels:v,eventData:[d]})}}a.loneHover(l,{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t,anchorIndex:c}).each(function(){i.link.concentrationscale||f(this,.65),p(this)})}}function m(t){var e,r;return t.circular?(e=(t.circularPathData.leftInnerExtent+t.circularPathData.rightInnerExtent)/2+i.parent.translateX,r=t.circularPathData.verticalFullExtent+i.parent.translateY):(e=(t.source.x1+t.target.x0)/2+i.parent.translateX,r=(t.y0+t.y1)/2+i.parent.translateY),[e,r]}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(x.bind(0,i,o,!0)),\"skip\"!==i.link.trace.link.hoverinfo&&(i.link.fullData=i.link.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.link]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r){var i=r.link;i.originalEvent=n.event,t._hoverdata=[i],a.click(t,{target:!0})}},nodeEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(v,r,i),\"skip\"!==r.node.trace.node.hoverinfo&&(r.node.fullData=r.node.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.node]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var o=i.node.trace.node;if(\"none\"!==o.hoverinfo&&\"skip\"!==o.hoverinfo){var s=n.select(e).select(\".\"+l.nodeRect),c=t._fullLayout._paperdiv.node().getBoundingClientRect(),h=s.node().getBoundingClientRect(),d=h.left-2-c.left,g=h.right+2-c.left,v=h.top+h.height/4-c.top,m={valueLabel:n.format(i.valueFormat)(i.node.value)+i.valueSuffix};i.node.fullData=i.node.trace;var y=a.loneHover({x0:d,x1:g,y:v,name:n.format(i.valueFormat)(i.node.value)+i.valueSuffix,text:[i.node.label,T+i.node.targetLinks.length,A+i.node.sourceLinks.length].filter(u).join(\"<br>\"),color:b(o,\"bgcolor\")||i.tinyColorHue,borderColor:b(o,\"bordercolor\"),fontFamily:b(o,\"font.family\"),fontSize:b(o,\"font.size\"),fontColor:b(o,\"font.color\"),nameLength:b(o,\"namelength\"),textAlign:b(o,\"align\"),idealAlign:\"left\",hovertemplate:o.hovertemplate,hovertemplateLabels:m,eventData:[i.node]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t});f(y,.85),p(y)}}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(m,i,o),\"skip\"!==i.node.trace.node.hoverinfo&&(i.node.fullData=i.node.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.node]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r,i){var o=r.node;o.originalEvent=n.event,t._hoverdata=[o],n.select(e).call(m,r,i),a.click(t,{target:!0})}}})}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"./constants\":1105,\"./render\":1109,d3:163}],1109:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"tinycolor2\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"@plotly/d3-sankey\"),c=t(\"@plotly/d3-sankey-circular\"),u=t(\"d3-force\"),h=t(\"../../lib\"),f=t(\"../../lib/gup\"),p=f.keyFun,d=f.repeat,g=f.unwrap,v=t(\"d3-interpolate\").interpolateNumber,m=t(\"../../registry\");function y(){var t=.5;return function(e){if(e.link.circular)return r=e.link,n=r.width/2,i=r.circularPathData,\"top\"===r.circularLinkType?\"M \"+i.targetX+\" \"+(i.targetY+n)+\" L\"+i.rightInnerExtent+\" \"+(i.targetY+n)+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightSmallArcRadius+n)+\" 0 0 1 \"+(i.rightFullExtent-n)+\" \"+(i.targetY-i.rightSmallArcRadius)+\"L\"+(i.rightFullExtent-n)+\" \"+i.verticalRightInnerExtent+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightLargeArcRadius+n)+\" 0 0 1 \"+i.rightInnerExtent+\" \"+(i.verticalFullExtent-n)+\"L\"+i.leftInnerExtent+\" \"+(i.verticalFullExtent-n)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftLargeArcRadius+n)+\" 0 0 1 \"+(i.leftFullExtent+n)+\" \"+i.verticalLeftInnerExtent+\"L\"+(i.leftFullExtent+n)+\" \"+(i.sourceY-i.leftSmallArcRadius)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftSmallArcRadius+n)+\" 0 0 1 \"+i.leftInnerExtent+\" \"+(i.sourceY+n)+\"L\"+i.sourceX+\" \"+(i.sourceY+n)+\"L\"+i.sourceX+\" \"+(i.sourceY-n)+\"L\"+i.leftInnerExtent+\" \"+(i.sourceY-n)+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftSmallArcRadius-n)+\" 0 0 0 \"+(i.leftFullExtent-n)+\" \"+(i.sourceY-i.leftSmallArcRadius)+\"L\"+(i.leftFullExtent-n)+\" \"+i.verticalLeftInnerExtent+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftLargeArcRadius-n)+\" 0 0 0 \"+i.leftInnerExtent+\" \"+(i.verticalFullExtent+n)+\"L\"+i.rightInnerExtent+\" \"+(i.verticalFullExtent+n)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightLargeArcRadius-n)+\" 0 0 0 \"+(i.rightFullExtent+n)+\" \"+i.verticalRightInnerExtent+\"L\"+(i.rightFullExtent+n)+\" \"+(i.targetY-i.rightSmallArcRadius)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightSmallArcRadius-n)+\" 0 0 0 \"+i.rightInnerExtent+\" \"+(i.targetY-n)+\"L\"+i.targetX+\" \"+(i.targetY-n)+\"Z\":\"M \"+i.targetX+\" \"+(i.targetY-n)+\" L\"+i.rightInnerExtent+\" \"+(i.targetY-n)+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightSmallArcRadius+n)+\" 0 0 0 \"+(i.rightFullExtent-n)+\" \"+(i.targetY+i.rightSmallArcRadius)+\"L\"+(i.rightFullExtent-n)+\" \"+i.verticalRightInnerExtent+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightLargeArcRadius+n)+\" 0 0 0 \"+i.rightInnerExtent+\" \"+(i.verticalFullExtent+n)+\"L\"+i.leftInnerExtent+\" \"+(i.verticalFullExtent+n)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftLargeArcRadius+n)+\" 0 0 0 \"+(i.leftFullExtent+n)+\" \"+i.verticalLeftInnerExtent+\"L\"+(i.leftFullExtent+n)+\" \"+(i.sourceY+i.leftSmallArcRadius)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftSmallArcRadius+n)+\" 0 0 0 \"+i.leftInnerExtent+\" \"+(i.sourceY-n)+\"L\"+i.sourceX+\" \"+(i.sourceY-n)+\"L\"+i.sourceX+\" \"+(i.sourceY+n)+\"L\"+i.leftInnerExtent+\" \"+(i.sourceY+n)+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftSmallArcRadius-n)+\" 0 0 1 \"+(i.leftFullExtent-n)+\" \"+(i.sourceY+i.leftSmallArcRadius)+\"L\"+(i.leftFullExtent-n)+\" \"+i.verticalLeftInnerExtent+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftLargeArcRadius-n)+\" 0 0 1 \"+i.leftInnerExtent+\" \"+(i.verticalFullExtent-n)+\"L\"+i.rightInnerExtent+\" \"+(i.verticalFullExtent-n)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightLargeArcRadius-n)+\" 0 0 1 \"+(i.rightFullExtent+n)+\" \"+i.verticalRightInnerExtent+\"L\"+(i.rightFullExtent+n)+\" \"+(i.targetY+i.rightSmallArcRadius)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightSmallArcRadius-n)+\" 0 0 1 \"+i.rightInnerExtent+\" \"+(i.targetY+n)+\"L\"+i.targetX+\" \"+(i.targetY+n)+\"Z\";var r,n,i,a=e.link.source.x1,o=e.link.target.x0,s=v(a,o),l=s(t),c=s(1-t),u=e.link.y0-e.link.width/2,h=e.link.y0+e.link.width/2,f=e.link.y1-e.link.width/2,p=e.link.y1+e.link.width/2;return\"M\"+a+\",\"+u+\"C\"+l+\",\"+u+\" \"+c+\",\"+f+\" \"+o+\",\"+f+\"L\"+o+\",\"+p+\"C\"+c+\",\"+p+\" \"+l+\",\"+h+\" \"+a+\",\"+h+\"Z\"}}function x(t){t.attr(\"transform\",function(t){return\"translate(\"+t.node.x0.toFixed(3)+\", \"+t.node.y0.toFixed(3)+\")\"})}function b(t){t.call(x)}function _(t,e){t.call(b),e.attr(\"d\",y())}function w(t){t.attr(\"width\",function(t){return t.node.x1-t.node.x0}).attr(\"height\",function(t){return t.visibleHeight})}function k(t){return t.link.width>1||t.linkLineWidth>0}function T(t){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"+(t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\")}function A(t){return\"translate(\"+(t.horizontal?0:t.labelY)+\" \"+(t.horizontal?t.labelY:0)+\")\"}function M(t){return i.svg.line()([[t.horizontal?t.left?-t.sizeAcross:t.visibleWidth+n.nodeTextOffsetHorizontal:n.nodeTextOffsetHorizontal,0],[t.horizontal?t.left?-n.nodeTextOffsetHorizontal:t.sizeAcross:t.visibleHeight-n.nodeTextOffsetHorizontal,0]])}function S(t){return t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\"}function E(t){return t.horizontal?\"scale(1 1)\":\"scale(-1 1)\"}function C(t){return t.darkBackground&&!t.horizontal?\"rgb(255,255,255)\":\"rgb(0,0,0)\"}function L(t){return t.horizontal&&t.left?\"100%\":\"0%\"}function P(t,e,r){t.on(\".basic\",null).on(\"mouseover.basic\",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.hover(this,t,e),t.interactionState.hovered=[this,t])}).on(\"mousemove.basic\",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.follow(this,t),t.interactionState.hovered=[this,t])}).on(\"mouseout.basic\",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.unhover(this,t,e),t.interactionState.hovered=!1)}).on(\"click.basic\",function(t){t.interactionState.hovered&&(r.unhover(this,t,e),t.interactionState.hovered=!1),t.interactionState.dragInProgress||t.partOfGroup||r.select(this,t,e)})}function O(t,e,r,a){var o=i.behavior.drag().origin(function(t){return{x:t.node.x0+t.visibleWidth/2,y:t.node.y0+t.visibleHeight/2}}).on(\"dragstart\",function(i){if(\"fixed\"!==i.arrangement&&(h.ensureSingle(a._fullLayout._infolayer,\"g\",\"dragcover\",function(t){a._fullLayout._dragCover=t}),h.raiseToTop(this),i.interactionState.dragInProgress=i.node,I(i.node),i.interactionState.hovered&&(r.nodeEvents.unhover.apply(0,i.interactionState.hovered),i.interactionState.hovered=!1),\"snap\"===i.arrangement)){var o=i.traceId+\"|\"+i.key;i.forceLayouts[o]?i.forceLayouts[o].alpha(1):function(t,e,r,i){!function(t){for(var e=0;e<t.length;e++)t[e].y=(t[e].y0+t[e].y1)/2,t[e].x=(t[e].x0+t[e].x1)/2}(r.graph.nodes);var a=r.graph.nodes.filter(function(t){return t.originalX===r.node.originalX}).filter(function(t){return!t.partOfGroup});r.forceLayouts[e]=u.forceSimulation(a).alphaDecay(0).force(\"collide\",u.forceCollide().radius(function(t){return t.dy/2+r.nodePad/2}).strength(1).iterations(n.forceIterations)).force(\"constrain\",function(t,e,r,i){return function(){for(var t=0,a=0;a<r.length;a++){var o=r[a];o===i.interactionState.dragInProgress?(o.x=o.lastDraggedX,o.y=o.lastDraggedY):(o.vx=(o.originalX-o.x)/n.forceTicksPerFrame,o.y=Math.min(i.size-o.dy/2,Math.max(o.dy/2,o.y))),t=Math.max(t,Math.abs(o.vx),Math.abs(o.vy))}!i.interactionState.dragInProgress&&t<.1&&i.forceLayouts[e].alpha()>0&&i.forceLayouts[e].alpha(0)}}(0,e,a,r)).stop()}(0,o,i),function(t,e,r,i,a){window.requestAnimationFrame(function o(){var s;for(s=0;s<n.forceTicksPerFrame;s++)r.forceLayouts[i].tick();var l=r.graph.nodes;if(function(t){for(var e=0;e<t.length;e++)t[e].y0=t[e].y-t[e].dy/2,t[e].y1=t[e].y0+t[e].dy,t[e].x0=t[e].x-t[e].dx/2,t[e].x1=t[e].x0+t[e].dx}(l),r.sankey.update(r.graph),_(t.filter(D(r)),e),r.forceLayouts[i].alpha()>0)window.requestAnimationFrame(o);else{var c=r.node.originalX;r.node.x0=c-r.visibleWidth/2,r.node.x1=c+r.visibleWidth/2,z(r,a)}})}(t,e,i,o,a)}}).on(\"drag\",function(r){if(\"fixed\"!==r.arrangement){var n=i.event.x,a=i.event.y;\"snap\"===r.arrangement?(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2,r.node.y0=a-r.visibleHeight/2,r.node.y1=a+r.visibleHeight/2):(\"freeform\"===r.arrangement&&(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2),a=Math.max(0,Math.min(r.size-r.visibleHeight/2,a)),r.node.y0=a-r.visibleHeight/2,r.node.y1=a+r.visibleHeight/2),I(r.node),\"snap\"!==r.arrangement&&(r.sankey.update(r.graph),_(t.filter(D(r)),e))}}).on(\"dragend\",function(t){if(\"fixed\"!==t.arrangement){t.interactionState.dragInProgress=!1;for(var e=0;e<t.node.childrenNodes.length;e++)t.node.childrenNodes[e].x=t.node.x,t.node.childrenNodes[e].y=t.node.y;\"snap\"!==t.arrangement&&z(t,a)}});t.on(\".drag\",null).call(o)}function z(t,e){for(var r=[],n=[],i=0;i<t.graph.nodes.length;i++){var a=(t.graph.nodes[i].x0+t.graph.nodes[i].x1)/2,o=(t.graph.nodes[i].y0+t.graph.nodes[i].y1)/2;r.push(a/t.figure.width),n.push(o/t.figure.height)}m.call(\"_guiRestyle\",e,{\"node.x\":[r],\"node.y\":[n]},t.trace.index).then(function(){e._fullLayout._dragCover&&e._fullLayout._dragCover.remove()})}function I(t){t.lastDraggedX=t.x0+t.dx/2,t.lastDraggedY=t.y0+t.dy/2}function D(t){return function(e){return e.node.originalX===t.node.originalX}}e.exports=function(t,e,r,u,f){var v=!1;h.ensureSingle(t._fullLayout._infolayer,\"g\",\"first-render\",function(){v=!0});var m=t._fullLayout._dragCover,b=r.filter(function(t){return g(t).trace.visible}).map(function(t,e,r){var i,o=g(e),s=o.trace,u=s.domain,f=\"h\"===s.orientation,p=s.node.pad,d=s.node.thickness,v=t.width*(u.x[1]-u.x[0]),m=t.height*(u.y[1]-u.y[0]),y=o._nodes,x=o._links,b=o.circular;(i=b?c.sankeyCircular().circularLinkGap(0):l.sankey()).iterations(n.sankeyIterations).size(f?[v,m]:[m,v]).nodeWidth(d).nodePadding(p).nodeId(function(t){return t.pointNumber}).nodes(y).links(x);var _,w,k,T=i();for(var A in i.nodePadding()<p&&h.warn(\"node.pad was reduced to \",i.nodePadding(),\" to fit within the figure.\"),o._groupLookup){var M,S=parseInt(o._groupLookup[A]);for(_=0;_<T.nodes.length;_++)if(T.nodes[_].pointNumber===S){M=T.nodes[_];break}if(M){var E={pointNumber:parseInt(A),x0:M.x0,x1:M.x1,y0:M.y0,y1:M.y1,partOfGroup:!0,sourceLinks:[],targetLinks:[]};T.nodes.unshift(E),M.childrenNodes.unshift(E)}}if(function(){for(_=0;_<T.nodes.length;_++){var t,e,r=T.nodes[_],n={};for(w=0;w<r.targetLinks.length;w++)t=(e=r.targetLinks[w]).source.pointNumber+\":\"+e.target.pointNumber,n.hasOwnProperty(t)||(n[t]=[]),n[t].push(e);var i=Object.keys(n);for(w=0;w<i.length;w++){var o=n[t=i[w]],s=0,l={};for(k=0;k<o.length;k++)l[(e=o[k]).label]||(l[e.label]=0),l[e.label]+=e.value,s+=e.value;for(k=0;k<o.length;k++)(e=o[k]).flow={value:s,labelConcentration:l[e.label]/s,concentration:e.value/s,links:o},e.concentrationscale&&(e.color=a(e.concentrationscale(e.flow.labelConcentration)))}var c=0;for(w=0;w<r.sourceLinks.length;w++)c+=r.sourceLinks[w].value;for(w=0;w<r.sourceLinks.length;w++)(e=r.sourceLinks[w]).concentrationOut=e.value/c;var u=0;for(w=0;w<r.targetLinks.length;w++)u+=r.targetLinks[w].value;for(w=0;w<r.targetLinks.length;w++)(e=r.targetLinks[w]).concenrationIn=e.value/u}}(),s.node.x.length&&s.node.y.length){for(_=0;_<Math.min(s.node.x.length,s.node.y.length,T.nodes.length);_++)if(s.node.x[_]&&s.node.y[_]){var C=[s.node.x[_]*v,s.node.y[_]*m];T.nodes[_].x0=C[0]-d/2,T.nodes[_].x1=C[0]+d/2;var L=T.nodes[_].y1-T.nodes[_].y0;T.nodes[_].y0=C[1]-L/2,T.nodes[_].y1=C[1]+L/2}\"snap\"===s.arrangement&&function(t){t.forEach(function(t){var e,r,n,i=0,a=t.length;for(t.sort(function(t,e){return t.y0-e.y0}),n=0;n<a;++n)(e=t[n]).y0>=i||(r=i-e.y0)>1e-6&&(e.y0+=r,e.y1+=r),i=e.y1+p})}(function(t){var e,r,n=t.map(function(t,e){return{x0:t.x0,index:e}}).sort(function(t,e){return t.x0-e.x0}),i=[],a=-1,o=-1/0;for(_=0;_<n.length;_++){var s=t[n[_].index];s.x0>o+d&&(a+=1,e=s.x0),o=s.x0,i[a]||(i[a]=[]),i[a].push(s),r=e-s.x0,s.x0+=r,s.x1+=r}return i}(y=T.nodes)),i.update(T)}return{circular:b,key:r,trace:s,guid:h.randstr(),horizontal:f,width:v,height:m,nodePad:s.node.pad,nodeLineColor:s.node.line.color,nodeLineWidth:s.node.line.width,linkLineColor:s.link.line.color,linkLineWidth:s.link.line.width,valueFormat:s.valueformat,valueSuffix:s.valuesuffix,textFont:s.textfont,translateX:u.x[0]*t.width+t.margin.l,translateY:t.height-u.y[1]*t.height+t.margin.t,dragParallel:f?m:v,dragPerpendicular:f?v:m,arrangement:s.arrangement,sankey:i,graph:T,forceLayouts:{},interactionState:{dragInProgress:!1,hovered:!1}}}.bind(null,u)),_=e.selectAll(\".\"+n.cn.sankey).data(b,p);_.exit().remove(),_.enter().append(\"g\").classed(n.cn.sankey,!0).style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"shape-rendering\",\"geometricPrecision\").style(\"pointer-events\",\"auto\").attr(\"transform\",T),_.each(function(e,r){t._fullData[r]._sankey=e;var n=\"bgsankey-\"+e.trace.uid+\"-\"+r;h.ensureSingle(t._fullLayout._draggers,\"rect\",n),t._fullData[r]._bgRect=i.select(\".\"+n),t._fullData[r]._bgRect.style(\"pointer-events\",\"all\").attr(\"width\",e.width).attr(\"height\",e.height).attr(\"x\",e.translateX).attr(\"y\",e.translateY).classed(\"bgsankey\",!0).style({fill:\"transparent\",\"stroke-width\":0})}),_.transition().ease(n.ease).duration(n.duration).attr(\"transform\",T);var z=_.selectAll(\".\"+n.cn.sankeyLinks).data(d,p);z.enter().append(\"g\").classed(n.cn.sankeyLinks,!0).style(\"fill\",\"none\");var I=z.selectAll(\".\"+n.cn.sankeyLink).data(function(t){return t.graph.links.filter(function(t){return t.value}).map(function(t,e,r){var n=a(e.color),i=e.source.label+\"|\"+e.target.label+\"__\"+r;return e.trace=t.trace,e.curveNumber=t.trace.index,{circular:t.circular,key:i,traceId:t.key,pointNumber:e.pointNumber,link:e,tinyColorHue:o.tinyRGB(n),tinyColorAlpha:n.getAlpha(),linkPath:y,linkLineColor:t.linkLineColor,linkLineWidth:t.linkLineWidth,valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,parent:t,interactionState:t.interactionState,flow:e.flow}}.bind(null,t))},p);I.enter().append(\"path\").classed(n.cn.sankeyLink,!0).call(P,_,f.linkEvents),I.style(\"stroke\",function(t){return k(t)?o.tinyRGB(a(t.linkLineColor)):t.tinyColorHue}).style(\"stroke-opacity\",function(t){return k(t)?o.opacity(t.linkLineColor):t.tinyColorAlpha}).style(\"fill\",function(t){return t.tinyColorHue}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}).style(\"stroke-width\",function(t){return k(t)?t.linkLineWidth:1}).attr(\"d\",y()),I.style(\"opacity\",function(){return t._context.staticPlot||v||m?1:0}).transition().ease(n.ease).duration(n.duration).style(\"opacity\",1),I.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var D=_.selectAll(\".\"+n.cn.sankeyNodeSet).data(d,p);D.enter().append(\"g\").classed(n.cn.sankeyNodeSet,!0),D.style(\"cursor\",function(t){switch(t.arrangement){case\"fixed\":return\"default\";case\"perpendicular\":return\"ns-resize\";default:return\"move\"}});var R=D.selectAll(\".\"+n.cn.sankeyNode).data(function(t){var e=t.graph.nodes;return function(t){var e,r=[];for(e=0;e<t.length;e++)t[e].originalX=(t[e].x0+t[e].x1)/2,t[e].originalY=(t[e].y0+t[e].y1)/2,-1===r.indexOf(t[e].originalX)&&r.push(t[e].originalX);for(r.sort(function(t,e){return t-e}),e=0;e<t.length;e++)t[e].originalLayerIndex=r.indexOf(t[e].originalX),t[e].originalLayer=t[e].originalLayerIndex/(r.length-1)}(e),e.map(function(t,e){var r=a(e.color),i=n.nodePadAcross,s=t.nodePad/2;e.dx=e.x1-e.x0,e.dy=e.y1-e.y0;var l=e.dx,c=Math.max(.5,e.dy),u=\"node_\"+e.pointNumber;return e.group&&(u=h.randstr()),e.trace=t.trace,e.curveNumber=t.trace.index,{index:e.pointNumber,key:u,partOfGroup:e.partOfGroup||!1,group:e.group,traceId:t.key,trace:t.trace,node:e,nodePad:t.nodePad,nodeLineColor:t.nodeLineColor,nodeLineWidth:t.nodeLineWidth,textFont:t.textFont,size:t.horizontal?t.height:t.width,visibleWidth:Math.ceil(l),visibleHeight:c,zoneX:-i,zoneY:-s,zoneWidth:l+2*i,zoneHeight:c+2*s,labelY:t.horizontal?e.dy/2+1:e.dx/2+1,left:1===e.originalLayer,sizeAcross:t.width,forceLayouts:t.forceLayouts,horizontal:t.horizontal,darkBackground:r.getBrightness()<=128,tinyColorHue:o.tinyRGB(r),tinyColorAlpha:r.getAlpha(),valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,graph:t.graph,arrangement:t.arrangement,uniqueNodeLabelPathId:[t.guid,t.key,u].join(\"_\"),interactionState:t.interactionState,figure:t}}.bind(null,t))},p);R.enter().append(\"g\").classed(n.cn.sankeyNode,!0).call(x).style(\"opacity\",function(e){return!t._context.staticPlot&&!v||e.partOfGroup?0:1}),R.call(P,_,f.nodeEvents).call(O,I,f,t),R.transition().ease(n.ease).duration(n.duration).call(x).style(\"opacity\",function(t){return t.partOfGroup?0:1}),R.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var F=R.selectAll(\".\"+n.cn.nodeRect).data(d);F.enter().append(\"rect\").classed(n.cn.nodeRect,!0).call(w),F.style(\"stroke-width\",function(t){return t.nodeLineWidth}).style(\"stroke\",function(t){return o.tinyRGB(a(t.nodeLineColor))}).style(\"stroke-opacity\",function(t){return o.opacity(t.nodeLineColor)}).style(\"fill\",function(t){return t.tinyColorHue}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),F.transition().ease(n.ease).duration(n.duration).call(w);var B=R.selectAll(\".\"+n.cn.nodeCapture).data(d);B.enter().append(\"rect\").classed(n.cn.nodeCapture,!0).style(\"fill-opacity\",0),B.attr(\"x\",function(t){return t.zoneX}).attr(\"y\",function(t){return t.zoneY}).attr(\"width\",function(t){return t.zoneWidth}).attr(\"height\",function(t){return t.zoneHeight});var N=R.selectAll(\".\"+n.cn.nodeCentered).data(d);N.enter().append(\"g\").classed(n.cn.nodeCentered,!0).attr(\"transform\",A),N.transition().ease(n.ease).duration(n.duration).attr(\"transform\",A);var j=N.selectAll(\".\"+n.cn.nodeLabelGuide).data(d);j.enter().append(\"path\").classed(n.cn.nodeLabelGuide,!0).attr(\"id\",function(t){return t.uniqueNodeLabelPathId}).attr(\"d\",M).attr(\"transform\",S),j.transition().ease(n.ease).duration(n.duration).attr(\"d\",M).attr(\"transform\",S);var U=N.selectAll(\".\"+n.cn.nodeLabel).data(d);U.enter().append(\"text\").classed(n.cn.nodeLabel,!0).attr(\"transform\",E).style(\"user-select\",\"none\").style(\"cursor\",\"default\").style(\"fill\",\"black\"),U.style(\"text-shadow\",function(t){return t.horizontal?\"-1px 1px 1px #fff, 1px 1px 1px #fff, 1px -1px 1px #fff, -1px -1px 1px #fff\":\"none\"}).each(function(t){s.font(U,t.textFont)}),U.transition().ease(n.ease).duration(n.duration).attr(\"transform\",E);var V=U.selectAll(\".\"+n.cn.nodeLabelTextPath).data(d);V.enter().append(\"textPath\").classed(n.cn.nodeLabelTextPath,!0).attr(\"alignment-baseline\",\"middle\").attr(\"xlink:href\",function(t){return\"#\"+t.uniqueNodeLabelPathId}).attr(\"startOffset\",L).style(\"fill\",C),V.text(function(t){return t.horizontal||t.node.dy>5?t.node.label:\"\"}).attr(\"text-anchor\",function(t){return t.horizontal&&t.left?\"end\":\"start\"}),V.transition().ease(n.ease).duration(n.duration).attr(\"startOffset\",L).style(\"fill\",C)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/gup\":717,\"../../registry\":847,\"./constants\":1105,\"@plotly/d3-sankey\":54,\"@plotly/d3-sankey-circular\":53,d3:163,\"d3-force\":156,\"d3-interpolate\":158,tinycolor2:537}],1110:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=[],n=t.cd[0].trace,i=n._sankey.graph.nodes,a=0;a<i.length;a++){var o=i[a];if(!o.partOfGroup){var s=[(o.x0+o.x1)/2,(o.y0+o.y1)/2];\"v\"===n.orientation&&s.reverse(),e&&e.contains(s,!1,a,t)&&r.push({pointNumber:o.pointNumber})}}return r}},{}],1111:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\"),n.mergeArray(e.customdata,t,\"data\"),n.mergeArray(e.textposition,t,\"tp\"),e.textfont&&(n.mergeArrayCastPositive(e.textfont.size,t,\"ts\"),n.mergeArray(e.textfont.color,t,\"tc\"),n.mergeArray(e.textfont.family,t,\"tf\"));var i=e.marker;if(i){n.mergeArrayCastPositive(i.size,t,\"ms\"),n.mergeArrayCastPositive(i.opacity,t,\"mo\"),n.mergeArray(i.symbol,t,\"mx\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;i.line&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"));var o=i.gradient;o&&\"none\"!==o.type&&(n.mergeArray(o.type,t,\"mgt\"),n.mergeArray(o.color,t,\"mgc\"))}}},{\"../../lib\":719}],1112:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../components/drawing/attributes\").dash,s=t(\"../../components/drawing\"),l=t(\"./constants\"),c=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},x0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dx:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},y0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dy:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},stackgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc\"},groupnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},stackgaps:{valType:\"enumerated\",values:[\"infer zero\",\"interpolate\"],dflt:\"infer zero\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"],editType:\"calc\"},hoveron:{valType:\"flaglist\",flags:[\"points\",\"fills\"],editType:\"style\"},hovertemplate:n({},{keys:l.eventDataKeys}),line:{color:{valType:\"color\",editType:\"style\",anim:!0},width:{valType:\"number\",min:0,dflt:2,editType:\"style\",anim:!0},shape:{valType:\"enumerated\",values:[\"linear\",\"spline\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},smoothing:{valType:\"number\",min:0,max:1.3,dflt:1,editType:\"plot\"},dash:c({},o,{editType:\"style\"}),simplify:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cliponaxis:{valType:\"boolean\",dflt:!0,editType:\"plot\"},fill:{valType:\"enumerated\",values:[\"none\",\"tozeroy\",\"tozerox\",\"tonexty\",\"tonextx\",\"toself\",\"tonext\"],editType:\"calc\"},fillcolor:{valType:\"color\",editType:\"style\",anim:!0},marker:c({symbol:{valType:\"enumerated\",values:s.symbolList,dflt:\"circle\",arrayOk:!0,editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,arrayOk:!0,editType:\"style\",anim:!0},size:{valType:\"number\",min:0,dflt:6,arrayOk:!0,editType:\"calc\",anim:!0},maxdisplayed:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},sizeref:{valType:\"number\",dflt:1,editType:\"calc\"},sizemin:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"diameter\",\"area\"],dflt:\"diameter\",editType:\"calc\"},line:c({width:{valType:\"number\",min:0,arrayOk:!0,editType:\"style\",anim:!0},editType:\"calc\"},i(\"marker.line\",{anim:!0})),gradient:{type:{valType:\"enumerated\",values:[\"radial\",\"horizontal\",\"vertical\",\"none\"],arrayOk:!0,dflt:\"none\",editType:\"calc\"},color:{valType:\"color\",arrayOk:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},i(\"marker\",{anim:!0})),selected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},unselected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\"],dflt:\"middle center\",arrayOk:!0,editType:\"calc\"},textfont:a({editType:\"calc\",colorEditType:\"style\",arrayOk:!0}),r:{valType:\"data_array\",editType:\"calc\"},t:{valType:\"data_array\",editType:\"calc\"}}},{\"../../components/colorscale/attributes\":600,\"../../components/drawing\":614,\"../../components/drawing/attributes\":613,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"./constants\":1116}],1113:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/numerical\").BADNUM,s=t(\"./subtypes\"),l=t(\"./colorscale_calc\"),c=t(\"./arrays_to_calcdata\"),u=t(\"./calc_selection\");function h(t,e,r,n,i,o,l){var c=e._length,u=t._fullLayout,h=r._id,f=n._id,p=u._firstScatter[d(e)]===e.uid,v=(g(e,u,r,n)||{}).orientation,m=e.fill;r._minDtick=0,n._minDtick=0;var y={padded:!0},x={padded:!0};l&&(y.ppad=x.ppad=l);var b=c<2||i[0]!==i[c-1]||o[0]!==o[c-1];b&&(\"tozerox\"===m||\"tonextx\"===m&&(p||\"h\"===v))?y.tozero=!0:(e.error_y||{}).visible||\"tonexty\"!==m&&\"tozeroy\"!==m&&(s.hasMarkers(e)||s.hasText(e))||(y.padded=!1,y.ppad=0),b&&(\"tozeroy\"===m||\"tonexty\"===m&&(p||\"v\"===v))?x.tozero=!0:\"tonextx\"!==m&&\"tozerox\"!==m||(x.padded=!1),h&&(e._extremes[h]=a.findExtremes(r,i,y)),f&&(e._extremes[f]=a.findExtremes(n,o,x))}function f(t,e){if(s.hasMarkers(t)){var r,n=t.marker,o=1.6*(t.marker.sizeref||1);if(r=\"area\"===t.marker.sizemode?function(t){return Math.max(Math.sqrt((t||0)/o),3)}:function(t){return Math.max((t||0)/o,3)},i.isArrayOrTypedArray(n.size)){var l={type:\"linear\"};a.setConvert(l);for(var c=l.makeCalcdata(t.marker,\"size\"),u=new Array(e),h=0;h<e;h++)u[h]=r(c[h]);return u}return r(n.size)}}function p(t,e){var r=d(e),n=t._firstScatter;n[r]||(n[r]=e.uid)}function d(t){var e=t.stackgroup;return t.xaxis+t.yaxis+t.type+(e?\"-\"+e:\"\")}function g(t,e,r,n){var i=t.stackgroup;if(i){var a=e._scatterStackOpts[r._id+n._id][i],o=\"v\"===a.orientation?n:r;return\"linear\"===o.type||\"log\"===o.type?a:void 0}}e.exports={calc:function(t,e){var r,s,d,v,m,y,x=t._fullLayout,b=a.getFromId(t,e.xaxis||\"x\"),_=a.getFromId(t,e.yaxis||\"y\"),w=b.makeCalcdata(e,\"x\"),k=_.makeCalcdata(e,\"y\"),T=e._length,A=new Array(T),M=e.ids,S=g(e,x,b,_),E=!1;p(x,e);var C,L=\"x\",P=\"y\";for(S?(i.pushUnique(S.traceIndices,e._expandedIndex),(r=\"v\"===S.orientation)?(P=\"s\",C=\"x\"):(L=\"s\",C=\"y\"),m=\"interpolate\"===S.stackgaps):h(t,e,b,_,w,k,f(e,T)),s=0;s<T;s++){var O=A[s]={},z=n(w[s]),I=n(k[s]);z&&I?(O[L]=w[s],O[P]=k[s]):S&&(r?z:I)?(O[C]=r?w[s]:k[s],O.gap=!0,m?(O.s=o,E=!0):O.s=0):O[L]=O[P]=o,M&&(O.id=String(M[s]))}if(c(A,e),l(t,e),u(A,e),S){for(s=0;s<A.length;)A[s][C]===o?A.splice(s,1):s++;if(i.sort(A,function(t,e){return t[C]-e[C]||t.i-e.i}),E){for(s=0;s<A.length-1&&A[s].gap;)s++;for((y=A[s].s)||(y=A[s].s=0),d=0;d<s;d++)A[d].s=y;for(v=A.length-1;v>s&&A[v].gap;)v--;for(y=A[v].s,d=A.length-1;d>v;d--)A[d].s=y;for(;s<v;)if(A[++s].gap){for(d=s+1;A[d].gap;)d++;for(var D=A[s-1][C],R=A[s-1].s,F=(A[d].s-R)/(A[d][C]-D);s<d;)A[s].s=R+(A[s][C]-D)*F,s++}}}return A},calcMarkerSize:f,calcAxisExpansion:h,setFirstScatter:p,getStackOpts:g}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./arrays_to_calcdata\":1111,\"./calc_selection\":1114,\"./colorscale_calc\":1115,\"./subtypes\":1135,\"fast-isnumeric\":225}],1114:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){n.isArrayOrTypedArray(e.selectedpoints)&&n.tagSelected(t,e)}},{\"../../lib\":719}],1115:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"./subtypes\");e.exports=function(t,e){a.hasLines(e)&&n(e,\"line\")&&i(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),a.hasMarkers(e)&&(n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}))}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"./subtypes\":1135}],1116:[function(t,e,r){\"use strict\";e.exports={PTS_LINESONLY:20,minTolerance:.2,toleranceGrowth:10,maxScreensAway:20,eventDataKeys:[]}},{}],1117:[function(t,e,r){\"use strict\";var n=t(\"./calc\");function i(t,e,r,n,i,a,o){i[n]=!0;var s={i:null,gap:!0,s:0};if(s[o]=r,t.splice(e,0,s),e&&r===t[e-1][o]){var l=t[e-1];s.s=l.s,s.i=l.i,s.gap=l.gap}else a&&(s.s=function(t,e,r,n){var i=t[e-1],a=t[e+1];return a?i?i.s+(a.s-i.s)*(r-i[n])/(a[n]-i[n]):a.s:i.s}(t,e,r,o));e||(t[0].t=t[1].t,t[0].trace=t[1].trace,delete t[1].t,delete t[1].trace)}e.exports=function(t,e){var r=e.xaxis,a=e.yaxis,o=r._id+a._id,s=t._fullLayout._scatterStackOpts[o];if(s){var l,c,u,h,f,p,d,g,v,m,y,x,b,_,w,k=t.calcdata;for(var T in s){var A=(m=s[T]).traceIndices;if(A.length){for(y=\"interpolate\"===m.stackgaps,x=m.groupnorm,\"v\"===m.orientation?(b=\"x\",_=\"y\"):(b=\"y\",_=\"x\"),w=new Array(A.length),l=0;l<w.length;l++)w[l]=!1;p=k[A[0]];var M=new Array(p.length);for(l=0;l<p.length;l++)M[l]=p[l][b];for(l=1;l<A.length;l++){for(f=k[A[l]],c=u=0;c<f.length;c++){for(d=f[c][b];d>M[u]&&u<M.length;u++)i(f,c,M[u],l,w,y,b),c++;if(d!==M[u]){for(h=0;h<l;h++)i(k[A[h]],u,d,h,w,y,b);M.splice(u,0,d)}u++}for(;u<M.length;u++)i(f,c,M[u],l,w,y,b),c++}var S=M.length;for(c=0;c<p.length;c++){for(g=p[c][_]=p[c].s,l=1;l<A.length;l++)(f=k[A[l]])[0].trace._rawLength=f[0].trace._length,f[0].trace._length=S,g+=f[c].s,f[c][_]=g;if(x)for(v=(\"fraction\"===x?g:g/100)||1,l=0;l<A.length;l++){var E=k[A[l]][c];E[_]/=v,E.sNorm=E.s/v}}for(l=0;l<A.length;l++){var C=(f=k[A[l]])[0].trace,L=n.calcMarkerSize(C,C._rawLength),P=Array.isArray(L);if(L&&w[l]||P){var O=L;for(L=new Array(S),c=0;c<S;c++)L[c]=f[c].gap?0:P?O[f[c].i]:O}var z=new Array(S),I=new Array(S);for(c=0;c<S;c++)z[c]=f[c].x,I[c]=f[c].y;n.calcAxisExpansion(t,C,r,a,z,I,L),f[0].t.orientation=m.orientation}}}}}},{\"./calc\":1113}],1118:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0;e<t.length;e++){var r=t[e];if(\"scatter\"===r.type){var n=r.fill;if(\"none\"!==n&&\"toself\"!==n&&(r.opacity=void 0,\"tonexty\"===n||\"tonextx\"===n))for(var i=e-1;i>=0;i--){var a=t[i];if(\"scatter\"===a.type&&a.xaxis===r.xaxis&&a.yaxis===r.yaxis){a.opacity=void 0;break}}}}}},{}],1119:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"./constants\"),s=t(\"./subtypes\"),l=t(\"./xy_defaults\"),c=t(\"./stack_defaults\"),u=t(\"./marker_defaults\"),h=t(\"./line_defaults\"),f=t(\"./line_shape_defaults\"),p=t(\"./text_defaults\"),d=t(\"./fillcolor_defaults\");e.exports=function(t,e,r,g){function v(r,i){return n.coerce(t,e,a,r,i)}var m=l(t,e,g,v);if(m||(e.visible=!1),e.visible){var y=c(t,e,g,v),x=!y&&m<o.PTS_LINESONLY?\"lines+markers\":\"lines\";v(\"text\"),v(\"hovertext\"),v(\"mode\",x),s.hasLines(e)&&(h(t,e,r,g,v),f(t,e,v),v(\"connectgaps\"),v(\"line.simplify\")),s.hasMarkers(e)&&u(t,e,r,g,v,{gradient:!0}),s.hasText(e)&&p(t,e,g,v);var b=[];(s.hasMarkers(e)||s.hasText(e))&&(v(\"cliponaxis\"),v(\"marker.maxdisplayed\"),b.push(\"points\")),v(\"fill\",y?y.fillDflt:\"none\"),\"none\"!==e.fill&&(d(t,e,r,v),s.hasLines(e)||f(t,e,v));var _=(e.line||{}).color,w=(e.marker||{}).color;\"tonext\"!==e.fill&&\"toself\"!==e.fill||b.push(\"fills\"),v(\"hoveron\",b.join(\"+\")||\"points\"),\"fills\"!==e.hoveron&&v(\"hovertemplate\");var k=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");k(t,e,_||w||r,{axis:\"y\"}),k(t,e,_||w||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,v)}}},{\"../../lib\":719,\"../../registry\":847,\"./attributes\":1112,\"./constants\":1116,\"./fillcolor_defaults\":1120,\"./line_defaults\":1124,\"./line_shape_defaults\":1126,\"./marker_defaults\":1130,\"./stack_defaults\":1133,\"./subtypes\":1135,\"./text_defaults\":1136,\"./xy_defaults\":1137}],1120:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a){var o=!1;if(e.marker){var s=e.marker.color,l=(e.marker.line||{}).color;s&&!i(s)?o=s:l&&!i(l)&&(o=l)}a(\"fillcolor\",n.addOpacity((e.line||{}).color||o||r,.5))}},{\"../../components/color\":593,\"../../lib\":719}],1121:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./subtypes\");e.exports=function(t,e){var r,a;if(\"lines\"===t.mode)return(r=t.line.color)&&n.opacity(r)?r:t.fillcolor;if(\"none\"===t.mode)return t.fill?t.fillcolor:\"\";var o=e.mcc||(t.marker||{}).color,s=e.mlcc||((t.marker||{}).line||{}).color;return(a=o&&n.opacity(o)?o:s&&n.opacity(s)&&(e.mlw||((t.marker||{}).line||{}).width)?s:\"\")?n.opacity(a)<.3?n.addOpacity(a,.3):a:(r=(t.line||{}).color)&&n.opacity(r)&&i.hasLines(t)&&t.line.width?r:t.fillcolor}},{\"../../components/color\":593,\"./subtypes\":1135}],1122:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/fx\"),a=t(\"../../registry\"),o=t(\"./get_trace_color\"),s=t(\"../../components/color\"),l=n.fillText;e.exports=function(t,e,r,c){var u=t.cd,h=u[0].trace,f=t.xa,p=t.ya,d=f.c2p(e),g=p.c2p(r),v=[d,g],m=h.hoveron||\"\",y=-1!==h.mode.indexOf(\"markers\")?3:.5;if(-1!==m.indexOf(\"points\")){var x=function(t){var e=Math.max(y,t.mrc||0),r=f.c2p(t.x)-d,n=p.c2p(t.y)-g;return Math.max(Math.sqrt(r*r+n*n)-e,1-y/e)},b=i.getDistanceFunction(c,function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(f.c2p(t.x)-d);return n<e?r*n/e:n-e+r},function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(p.c2p(t.y)-g);return n<e?r*n/e:n-e+r},x);if(i.getClosest(u,b,t),!1!==t.index){var _=u[t.index],w=f.c2p(_.x,!0),k=p.c2p(_.y,!0),T=_.mrc||1;t.index=_.i;var A=u[0].t.orientation,M=A&&(_.sNorm||_.s),S=\"h\"===A?M:_.x,E=\"v\"===A?M:_.y;return n.extendFlat(t,{color:o(h,_),x0:w-T,x1:w+T,xLabelVal:S,y0:k-T,y1:k+T,yLabelVal:E,spikeDistance:x(_),hovertemplate:h.hovertemplate}),l(_,h,t),a.getComponentMethod(\"errorbars\",\"hoverInfo\")(_,h,t),[t]}}if(-1!==m.indexOf(\"fills\")&&h._polygons){var C,L,P,O,z,I,D,R,F,B=h._polygons,N=[],j=!1,U=1/0,V=-1/0,q=1/0,H=-1/0;for(C=0;C<B.length;C++)(P=B[C]).contains(v)&&(j=!j,N.push(P),q=Math.min(q,P.ymin),H=Math.max(H,P.ymax));if(j){var G=((q=Math.max(q,0))+(H=Math.min(H,p._length)))/2;for(C=0;C<N.length;C++)for(O=N[C].pts,L=1;L<O.length;L++)(R=O[L-1][1])>G!=(F=O[L][1])>=G&&(I=O[L-1][0],D=O[L][0],F-R&&(z=I+(D-I)*(G-R)/(F-R),U=Math.min(U,z),V=Math.max(V,z)));U=Math.max(U,0),V=Math.min(V,f._length);var Y=s.defaultLine;return s.opacity(h.fillcolor)?Y=h.fillcolor:s.opacity((h.line||{}).color)&&(Y=h.line.color),n.extendFlat(t,{distance:t.maxHoverDistance,x0:U,x1:V,y0:G,y1:G,color:Y,hovertemplate:!1}),delete t.index,h.text&&!Array.isArray(h.text)?t.text=String(h.text):t.text=h.name,[t]}}}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"../../registry\":847,\"./get_trace_color\":1121}],1123:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports={hasLines:n.hasLines,hasMarkers:n.hasMarkers,hasText:n.hasText,isBubble:n.isBubble,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./cross_trace_calc\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\"),colorbar:t(\"./marker_colorbar\"),style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"./select\"),animatable:!0,moduleType:\"trace\",name:\"scatter\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"./arrays_to_calcdata\":1111,\"./attributes\":1112,\"./calc\":1113,\"./cross_trace_calc\":1117,\"./cross_trace_defaults\":1118,\"./defaults\":1119,\"./hover\":1122,\"./marker_colorbar\":1129,\"./plot\":1131,\"./select\":1132,\"./style\":1134,\"./subtypes\":1135}],1124:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s,l){var c=(t.marker||{}).color;(s(\"line.color\",r),i(t,\"line\"))?a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}):s(\"line.color\",!n(c)&&c||r);s(\"line.width\"),(l||{}).noDash||s(\"line.dash\")}},{\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"../../lib\":719}],1125:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.BADNUM,a=n.LOG_CLIP,o=a+.5,s=a-.5,l=t(\"../../lib\"),c=l.segmentsIntersect,u=l.constrain,h=t(\"./constants\");e.exports=function(t,e){var r,n,a,f,p,d,g,v,m,y,x,b,_,w,k,T,A,M,S=e.xaxis,E=e.yaxis,C=\"log\"===S.type,L=\"log\"===E.type,P=S._length,O=E._length,z=e.connectGaps,I=e.baseTolerance,D=e.shape,R=\"linear\"===D,F=e.fill&&\"none\"!==e.fill,B=[],N=h.minTolerance,j=t.length,U=new Array(j),V=0;function q(e){var r=t[e];if(!r)return!1;var n=S.c2p(r.x),a=E.c2p(r.y);if(n===i){if(C&&(n=S.c2p(r.x,!0)),n===i)return!1;L&&a===i&&(n*=Math.abs(S._m*O*(S._m>0?o:s)/(E._m*P*(E._m>0?o:s)))),n*=1e3}if(a===i){if(L&&(a=E.c2p(r.y,!0)),a===i)return!1;a*=1e3}return[n,a]}function H(t,e,r,n){var i=r-t,a=n-e,o=.5-t,s=.5-e,l=i*i+a*a,c=i*o+a*s;if(c>0&&c<l){var u=o*a-s*i;if(u*u<l)return!0}}function G(t,e){var r=t[0]/P,n=t[1]/O,i=Math.max(0,-r,r-1,-n,n-1);return i&&void 0!==A&&H(r,n,A,M)&&(i=0),i&&e&&H(r,n,e[0]/P,e[1]/O)&&(i=0),(1+h.toleranceGrowth*i)*I}function Y(t,e){var r=t[0]-e[0],n=t[1]-e[1];return Math.sqrt(r*r+n*n)}var W,X,Z,J,K,$,Q,tt=h.maxScreensAway,et=-P*tt,rt=P*(1+tt),nt=-O*tt,it=O*(1+tt),at=[[et,nt,rt,nt],[rt,nt,rt,it],[rt,it,et,it],[et,it,et,nt]];function ot(t){if(t[0]<et||t[0]>rt||t[1]<nt||t[1]>it)return[u(t[0],et,rt),u(t[1],nt,it)]}function st(t,e){return t[0]===e[0]&&(t[0]===et||t[0]===rt)||(t[1]===e[1]&&(t[1]===nt||t[1]===it)||void 0)}function lt(t,e,r){return function(n,i){var a=ot(n),o=ot(i),s=[];if(a&&o&&st(a,o))return s;a&&s.push(a),o&&s.push(o);var c=2*l.constrain((n[t]+i[t])/2,e,r)-((a||n)[t]+(o||i)[t]);c&&((a&&o?c>0==a[t]>o[t]?a:o:a||o)[t]+=c);return s}}function ct(t){var e=t[0],r=t[1],n=e===U[V-1][0],i=r===U[V-1][1];if(!n||!i)if(V>1){var a=e===U[V-2][0],o=r===U[V-2][1];n&&(e===et||e===rt)&&a?o?V--:U[V-1]=t:i&&(r===nt||r===it)&&o?a?V--:U[V-1]=t:U[V++]=t}else U[V++]=t}function ut(t){U[V-1][0]!==t[0]&&U[V-1][1]!==t[1]&&ct([Z,J]),ct(t),K=null,Z=J=0}function ht(t){if(A=t[0]/P,M=t[1]/O,W=t[0]<et?et:t[0]>rt?rt:0,X=t[1]<nt?nt:t[1]>it?it:0,W||X){if(V)if(K){var e=Q(K,t);e.length>1&&(ut(e[0]),U[V++]=e[1])}else $=Q(U[V-1],t)[0],U[V++]=$;else U[V++]=[W||t[0],X||t[1]];var r=U[V-1];W&&X&&(r[0]!==W||r[1]!==X)?(K&&(Z!==W&&J!==X?ct(Z&&J?(n=K,a=(i=t)[0]-n[0],o=(i[1]-n[1])/a,(n[1]*i[0]-i[1]*n[0])/a>0?[o>0?et:rt,it]:[o>0?rt:et,nt]):[Z||W,J||X]):Z&&J&&ct([Z,J])),ct([W,X])):Z-W&&J-X&&ct([W||Z,X||J]),K=t,Z=W,J=X}else K&&ut(Q(K,t)[0]),U[V++]=t;var n,i,a,o}for(\"linear\"===D||\"spline\"===D?Q=function(t,e){for(var r=[],n=0,i=0;i<4;i++){var a=at[i],o=c(t[0],t[1],e[0],e[1],a[0],a[1],a[2],a[3]);o&&(!n||Math.abs(o.x-r[0][0])>1||Math.abs(o.y-r[0][1])>1)&&(o=[o.x,o.y],n&&Y(o,t)<Y(r[0],t)?r.unshift(o):r.push(o),n++)}return r}:\"hv\"===D||\"vh\"===D?Q=function(t,e){var r=[],n=ot(t),i=ot(e);return n&&i&&st(n,i)?r:(n&&r.push(n),i&&r.push(i),r)}:\"hvh\"===D?Q=lt(0,et,rt):\"vhv\"===D&&(Q=lt(1,nt,it)),r=0;r<j;r++)if(n=q(r)){for(V=0,K=null,ht(n),r++;r<j;r++){if(!(f=q(r))){if(z)continue;break}if(R&&e.simplify){var ft=q(r+1);if(y=Y(f,n),F&&(0===V||V===j-1)||!(y<G(f,ft)*N)){for(v=[(f[0]-n[0])/y,(f[1]-n[1])/y],p=n,x=y,b=w=k=0,g=!1,a=f,r++;r<t.length;r++){if(d=ft,ft=q(r+1),!d){if(z)continue;break}if(T=(m=[d[0]-n[0],d[1]-n[1]])[0]*v[1]-m[1]*v[0],w=Math.min(w,T),(k=Math.max(k,T))-w>G(d,ft))break;a=d,(_=m[0]*v[0]+m[1]*v[1])>x?(x=_,f=d,g=!1):_<b&&(b=_,p=d,g=!0)}if(g?(ht(f),a!==p&&ht(p)):(p!==n&&ht(p),a!==f&&ht(f)),ht(a),r>=t.length||!d)break;ht(d),n=d}}else ht(f)}K&&ct([Z||K[0],J||K[1]]),B.push(U.slice(0,V))}return B}},{\"../../constants/numerical\":695,\"../../lib\":719,\"./constants\":1116}],1126:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){\"spline\"===r(\"line.shape\")&&r(\"line.smoothing\")}},{}],1127:[function(t,e,r){\"use strict\";var n={tonextx:1,tonexty:1,tonext:1};e.exports=function(t,e,r){var i,a,o,s,l,c={},u=!1,h=-1,f=0,p=-1;for(a=0;a<r.length;a++)(o=(i=r[a][0].trace).stackgroup||\"\")?o in c?l=c[o]:(l=c[o]=f,f++):i.fill in n&&p>=0?l=p:(l=p=f,f++),l<h&&(u=!0),i._groupIndex=h=l;var d=r.slice();u&&d.sort(function(t,e){var r=t[0].trace,n=e[0].trace;return r._groupIndex-n._groupIndex||r.index-n.index});var g={};for(a=0;a<d.length;a++)o=(i=d[a][0].trace).stackgroup||\"\",!0===i.visible?(i._nexttrace=null,i.fill in n&&(s=g[o],i._prevtrace=s||null,s&&(s._nexttrace=i)),i._ownfill=i.fill&&(\"tozero\"===i.fill.substr(0,6)||\"toself\"===i.fill||\"to\"===i.fill.substr(0,2)&&!i._prevtrace),g[o]=i):i._prevtrace=i._nexttrace=i._ownfill=null;return d}},{}],1128:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t){var e=t.marker,r=e.sizeref||1,i=e.sizemin||0,a=\"area\"===e.sizemode?function(t){return Math.sqrt(t/r)}:function(t){return t/r};return function(t){var e=a(t/2);return n(e)&&e>0?Math.max(e,i):0}}},{\"fast-isnumeric\":225}],1129:[function(t,e,r){\"use strict\";e.exports={container:\"marker\",min:\"cmin\",max:\"cmax\"}},{}],1130:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"./subtypes\");e.exports=function(t,e,r,s,l,c){var u=o.isBubble(t),h=(t.line||{}).color;(c=c||{},h&&(r=h),l(\"marker.symbol\"),l(\"marker.opacity\",u?.7:1),l(\"marker.size\"),l(\"marker.color\",r),i(t,\"marker\")&&a(t,e,s,l,{prefix:\"marker.\",cLetter:\"c\"}),c.noSelect||(l(\"selected.marker.color\"),l(\"unselected.marker.color\"),l(\"selected.marker.size\"),l(\"unselected.marker.size\")),c.noLine||(l(\"marker.line.color\",h&&!Array.isArray(h)&&e.marker.color!==h?h:u?n.background:n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,l,{prefix:\"marker.line.\",cLetter:\"c\"}),l(\"marker.line.width\",u?1:0)),u&&(l(\"marker.sizeref\"),l(\"marker.sizemin\"),l(\"marker.sizemode\")),c.gradient)&&(\"none\"!==l(\"marker.gradient.type\")&&l(\"marker.gradient.color\"))}},{\"../../components/color\":593,\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"./subtypes\":1135}],1131:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=a.ensureSingle,s=a.identity,l=t(\"../../components/drawing\"),c=t(\"./subtypes\"),u=t(\"./line_points\"),h=t(\"./link_traces\"),f=t(\"../../lib/polygon\").tester;function p(t,e,r,h,p,d,g){var v;!function(t,e,r,i,o){var s=r.xaxis,l=r.yaxis,u=n.extent(a.simpleMap(s.range,s.r2c)),h=n.extent(a.simpleMap(l.range,l.r2c)),f=i[0].trace;if(!c.hasMarkers(f))return;var p=f.marker.maxdisplayed;if(0===p)return;var d=i.filter(function(t){return t.x>=u[0]&&t.x<=u[1]&&t.y>=h[0]&&t.y<=h[1]}),g=Math.ceil(d.length/p),v=0;o.forEach(function(t,r){var n=t[0].trace;c.hasMarkers(n)&&n.marker.maxdisplayed>0&&r<e&&v++});var m=Math.round(v*g/3+Math.floor(v/3)*g/7.1);i.forEach(function(t){delete t.vis}),d.forEach(function(t,e){0===Math.round((e+m)%g)&&(t.vis=!0)})}(0,e,r,h,p);var m=!!g&&g.duration>0;function y(t){return m?t.transition():t}var x=r.xaxis,b=r.yaxis,_=h[0].trace,w=_.line,k=n.select(d),T=o(k,\"g\",\"errorbars\"),A=o(k,\"g\",\"lines\"),M=o(k,\"g\",\"points\"),S=o(k,\"g\",\"text\");if(i.getComponentMethod(\"errorbars\",\"plot\")(t,T,r,g),!0===_.visible){var E,C;y(k).style(\"opacity\",_.opacity);var L=_.fill.charAt(_.fill.length-1);\"x\"!==L&&\"y\"!==L&&(L=\"\"),h[0][r.isRangePlot?\"nodeRangePlot3\":\"node3\"]=k;var P,O,z=\"\",I=[],D=_._prevtrace;D&&(z=D._prevRevpath||\"\",C=D._nextFill,I=D._polygons);var R,F,B,N,j,U,V,q=\"\",H=\"\",G=[],Y=a.noop;if(E=_._ownFill,c.hasLines(_)||\"none\"!==_.fill){for(C&&C.datum(h),-1!==[\"hv\",\"vh\",\"hvh\",\"vhv\"].indexOf(w.shape)?(R=l.steps(w.shape),F=l.steps(w.shape.split(\"\").reverse().join(\"\"))):R=F=\"spline\"===w.shape?function(t){var e=t[t.length-1];return t.length>1&&t[0][0]===e[0]&&t[0][1]===e[1]?l.smoothclosed(t.slice(1),w.smoothing):l.smoothopen(t,w.smoothing)}:function(t){return\"M\"+t.join(\"L\")},B=function(t){return F(t.reverse())},G=u(h,{xaxis:x,yaxis:b,connectGaps:_.connectgaps,baseTolerance:Math.max(w.width||1,3)/4,shape:w.shape,simplify:w.simplify,fill:_.fill}),V=_._polygons=new Array(G.length),v=0;v<G.length;v++)_._polygons[v]=f(G[v]);G.length&&(N=G[0][0],U=(j=G[G.length-1])[j.length-1]),Y=function(t){return function(e){if(P=R(e),O=B(e),q?L?(q+=\"L\"+P.substr(1),H=O+\"L\"+H.substr(1)):(q+=\"Z\"+P,H=O+\"Z\"+H):(q=P,H=O),c.hasLines(_)&&e.length>1){var r=n.select(this);if(r.datum(h),t)y(r.style(\"opacity\",0).attr(\"d\",P).call(l.lineGroupStyle)).style(\"opacity\",1);else{var i=y(r);i.attr(\"d\",P),l.singleLineStyle(h,i)}}}}}var W=A.selectAll(\".js-line\").data(G);y(W.exit()).style(\"opacity\",0).remove(),W.each(Y(!1)),W.enter().append(\"path\").classed(\"js-line\",!0).style(\"vector-effect\",\"non-scaling-stroke\").call(l.lineGroupStyle).each(Y(!0)),l.setClipUrl(W,r.layerClipId,t),G.length?(E?(E.datum(h),N&&U&&(L?(\"y\"===L?N[1]=U[1]=b.c2p(0,!0):\"x\"===L&&(N[0]=U[0]=x.c2p(0,!0)),y(E).attr(\"d\",\"M\"+U+\"L\"+N+\"L\"+q.substr(1)).call(l.singleFillStyle)):y(E).attr(\"d\",q+\"Z\").call(l.singleFillStyle))):C&&(\"tonext\"===_.fill.substr(0,6)&&q&&z?(\"tonext\"===_.fill?y(C).attr(\"d\",q+\"Z\"+z+\"Z\").call(l.singleFillStyle):y(C).attr(\"d\",q+\"L\"+z.substr(1)+\"Z\").call(l.singleFillStyle),_._polygons=_._polygons.concat(I)):(Z(C),_._polygons=null)),_._prevRevpath=H,_._prevPolygons=V):(E?Z(E):C&&Z(C),_._polygons=_._prevRevpath=_._prevPolygons=null),M.datum(h),S.datum(h),function(e,i,a){var o,u=a[0].trace,h=c.hasMarkers(u),f=c.hasText(u),p=tt(u),d=et,g=et;if(h||f){var v=s,_=u.stackgroup,w=_&&\"infer zero\"===t._fullLayout._scatterStackOpts[x._id+b._id][_].stackgaps;u.marker.maxdisplayed||u._needsCull?v=w?K:J:_&&!w&&(v=$),h&&(d=v),f&&(g=v)}var k,T=(o=e.selectAll(\"path.point\").data(d,p)).enter().append(\"path\").classed(\"point\",!0);m&&T.call(l.pointStyle,u,t).call(l.translatePoints,x,b).style(\"opacity\",0).transition().style(\"opacity\",1),o.order(),h&&(k=l.makePointStyleFns(u)),o.each(function(e){var i=n.select(this),a=y(i);l.translatePoint(e,a,x,b)?(l.singlePointStyle(e,a,u,k,t),r.layerClipId&&l.hideOutsideRangePoint(e,a,x,b,u.xcalendar,u.ycalendar),u.customdata&&i.classed(\"plotly-customdata\",null!==e.data&&void 0!==e.data)):a.remove()}),m?o.exit().transition().style(\"opacity\",0).remove():o.exit().remove(),(o=i.selectAll(\"g\").data(g,p)).enter().append(\"g\").classed(\"textpoint\",!0).append(\"text\"),o.order(),o.each(function(t){var e=n.select(this),i=y(e.select(\"text\"));l.translatePoint(t,i,x,b)?r.layerClipId&&l.hideOutsideRangePoint(t,e,x,b,u.xcalendar,u.ycalendar):e.remove()}),o.selectAll(\"text\").call(l.textPointStyle,u,t).each(function(t){var e=x.c2p(t.x),r=b.c2p(t.y);n.select(this).selectAll(\"tspan.line\").each(function(){y(n.select(this)).attr({x:e,y:r})})}),o.exit().remove()}(M,S,h);var X=!1===_.cliponaxis?null:r.layerClipId;l.setClipUrl(M,X,t),l.setClipUrl(S,X,t)}function Z(t){y(t).attr(\"d\",\"M0,0Z\")}function J(t){return t.filter(function(t){return!t.gap&&t.vis})}function K(t){return t.filter(function(t){return t.vis})}function $(t){return t.filter(function(t){return!t.gap})}function Q(t){return t.id}function tt(t){if(t.ids)return Q}function et(){return!1}}e.exports=function(t,e,r,i,a,c){var u,f,d=!a,g=!!a&&a.duration>0,v=h(t,e,r);((u=i.selectAll(\"g.trace\").data(v,function(t){return t[0].trace.uid})).enter().append(\"g\").attr(\"class\",function(t){return\"trace scatter trace\"+t[0].trace.uid}).style(\"stroke-miterlimit\",2),u.order(),function(t,e,r){e.each(function(e){var i=o(n.select(this),\"g\",\"fills\");l.setClipUrl(i,r.layerClipId,t);var a=e[0].trace,c=[];a._ownfill&&c.push(\"_ownFill\"),a._nexttrace&&c.push(\"_nextFill\");var u=i.selectAll(\"g\").data(c,s);u.enter().append(\"g\"),u.exit().each(function(t){a[t]=null}).remove(),u.order().each(function(t){a[t]=o(n.select(this),\"path\",\"js-fill\")})})}(t,u,e),g)?(c&&(f=c()),n.transition().duration(a.duration).ease(a.easing).each(\"end\",function(){f&&f()}).each(\"interrupt\",function(){f&&f()}).each(function(){i.selectAll(\"g.trace\").each(function(r,n){p(t,n,e,r,v,this,a)})})):u.each(function(r,n){p(t,n,e,r,v,this,a)});d&&u.exit().remove(),i.selectAll(\"path:not([d])\").remove()}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/polygon\":731,\"../../registry\":847,\"./line_points\":1125,\"./link_traces\":1127,\"./subtypes\":1135,d3:163}],1132:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports=function(t,e){var r,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[],h=s[0].trace;if(!n.hasMarkers(h)&&!n.hasText(h))return[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)i=s[r],a=l.c2p(i.x),o=c.c2p(i.y),null!==i.i&&e.contains([a,o],!1,r,t)?(u.push({pointNumber:i.i,x:l.c2d(i.x),y:c.c2d(i.y)}),i.selected=1):i.selected=0;return u}},{\"./subtypes\":1135}],1133:[function(t,e,r){\"use strict\";var n=[\"orientation\",\"groupnorm\",\"stackgaps\"];e.exports=function(t,e,r,i){var a=r._scatterStackOpts,o=i(\"stackgroup\");if(o){var s=e.xaxis+e.yaxis,l=a[s];l||(l=a[s]={});var c=l[o],u=!1;c?c.traces.push(e):(c=l[o]={traceIndices:[],traces:[e]},u=!0);for(var h={orientation:e.x&&!e.y?\"h\":\"v\"},f=0;f<n.length;f++){var p=n[f],d=p+\"Found\";if(!c[d]){var g=void 0!==t[p],v=\"orientation\"===p;if((g||u)&&(c[p]=i(p,h[p]),v&&(c.fillDflt=\"h\"===c[p]?\"tonextx\":\"tonexty\"),g&&(c[d]=!0,!u&&(delete c.traces[0][p],v))))for(var m=0;m<c.traces.length-1;m++){var y=c.traces[m];y._input.fill!==y.fill&&(y.fill=c.fillDflt)}}}return c}}},{}],1134:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../registry\");function o(t,e,r){i.pointStyle(t.selectAll(\"path.point\"),e,r)}function s(t,e,r){i.textPointStyle(t.selectAll(\"text\"),e,r)}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.trace.scatter\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.selectAll(\"g.points\").each(function(e){o(n.select(this),e.trace||e[0].trace,t)}),e.selectAll(\"g.text\").each(function(e){s(n.select(this),e.trace||e[0].trace,t)}),e.selectAll(\"g.trace path.js-line\").call(i.lineGroupStyle),e.selectAll(\"g.trace path.js-fill\").call(i.fillGroupStyle),a.getComponentMethod(\"errorbars\",\"style\")(e)},stylePoints:o,styleText:s,styleOnSelect:function(t,e,r){var n=e[0].trace;n.selectedpoints?(i.selectedPointStyle(r.selectAll(\"path.point\"),n),i.selectedTextStyle(r.selectAll(\"text\"),n)):(o(r,n,t),s(r,n,t))}}},{\"../../components/drawing\":614,\"../../registry\":847,d3:163}],1135:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports={hasLines:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"lines\")},hasMarkers:function(t){return t.visible&&(t.mode&&-1!==t.mode.indexOf(\"markers\")||\"splom\"===t.type)},hasText:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"text\")},isBubble:function(t){return n.isPlainObject(t.marker)&&n.isArrayOrTypedArray(t.marker.size)}}},{\"../../lib\":719}],1136:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i,a){a=a||{},i(\"textposition\"),n.coerceFont(i,\"textfont\",r.font),a.noSelect||(i(\"selected.textfont.color\"),i(\"unselected.textfont.color\"))}},{\"../../lib\":719}],1137:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");e.exports=function(t,e,r,a){var o,s=a(\"x\"),l=a(\"y\");if(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],r),s){var c=n.minRowLength(s);l?o=Math.min(c,n.minRowLength(l)):(o=c,a(\"y0\"),a(\"dy\"))}else{if(!l)return 0;o=n.minRowLength(l),a(\"x0\"),a(\"dx\")}return e._length=o,o}},{\"../../lib\":719,\"../../registry\":847}],1138:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../constants/gl3d_dashes\"),l=t(\"../../constants/gl3d_markers\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../plot_api/edit_types\").overrideAll,h=n.line,f=n.marker,p=f.line,d=c({width:h.width,dash:{valType:\"enumerated\",values:Object.keys(s),dflt:\"solid\"}},i(\"line\"));var g=e.exports=u({x:n.x,y:n.y,z:{valType:\"data_array\"},text:c({},n.text,{}),hovertext:c({},n.hovertext,{}),hovertemplate:a(),mode:c({},n.mode,{dflt:\"lines+markers\"}),surfaceaxis:{valType:\"enumerated\",values:[-1,0,1,2],dflt:-1},surfacecolor:{valType:\"color\"},projection:{x:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},y:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},z:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}}},connectgaps:n.connectgaps,line:d,marker:c({symbol:{valType:\"enumerated\",values:Object.keys(l),dflt:\"circle\",arrayOk:!0},size:c({},f.size,{dflt:8}),sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode,opacity:c({},f.opacity,{arrayOk:!1}),colorbar:f.colorbar,line:c({width:c({},p.width,{arrayOk:!1})},i(\"marker.line\"))},i(\"marker\")),textposition:c({},n.textposition,{dflt:\"top center\"}),textfont:{color:n.textfont.color,size:n.textfont.size,family:c({},n.textfont.family,{arrayOk:!1})},hoverinfo:c({},o.hoverinfo)},\"calc\",\"nested\");g.x.editType=g.y.editType=g.z.editType=\"calc+clearAxisTypes\"},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../constants/gl3d_dashes\":692,\"../../constants/gl3d_markers\":693,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1139:[function(t,e,r){\"use strict\";var n=t(\"../scatter/arrays_to_calcdata\"),i=t(\"../scatter/colorscale_calc\");e.exports=function(t,e){var r=[{x:!1,y:!1,trace:e,t:{}}];return n(r,e),i(t,e),r}},{\"../scatter/arrays_to_calcdata\":1111,\"../scatter/colorscale_calc\":1115}],1140:[function(t,e,r){\"use strict\";var n=t(\"../../registry\");function i(t,e,r,i){if(!e||!e.visible)return null;for(var a=n.getComponentMethod(\"errorbars\",\"makeComputeError\")(e),o=new Array(t.length),s=0;s<t.length;s++){var l=a(+t[s],s);if(\"log\"===i.type){var c=i.c2l(t[s]),u=t[s]-l[0],h=t[s]+l[1];if(o[s]=[(i.c2l(u,!0)-c)*r,(i.c2l(h,!0)-c)*r],u>0){var f=i.c2l(u);i._lowerLogErrorBound||(i._lowerLogErrorBound=f),i._lowerErrorBound=Math.min(i._lowerLogErrorBound,f)}}else o[s]=[-l[0]*r,l[1]*r]}return o}e.exports=function(t,e,r){var n=[i(t.x,t.error_x,e[0],r.xaxis),i(t.y,t.error_y,e[1],r.yaxis),i(t.z,t.error_z,e[2],r.zaxis)],a=function(t){for(var e=0;e<t.length;e++)if(t[e])return t[e].length;return 0}(n);if(0===a)return null;for(var o=new Array(a),s=0;s<a;s++){for(var l=[[0,0,0],[0,0,0]],c=0;c<3;c++)if(n[c])for(var u=0;u<2;u++)l[u][c]=n[c][s][u];o[s]=l}return o}},{\"../../registry\":847}],1141:[function(t,e,r){\"use strict\";var n=t(\"gl-line3d\"),i=t(\"gl-scatter3d\"),a=t(\"gl-error3d\"),o=t(\"gl-mesh3d\"),s=t(\"delaunay-triangulate\"),l=t(\"../../lib\"),c=t(\"../../lib/str2rgbarray\"),u=t(\"../../lib/gl_format_color\").formatColor,h=t(\"../scatter/make_bubble_size_func\"),f=t(\"../../constants/gl3d_dashes\"),p=t(\"../../constants/gl3d_markers\"),d=t(\"./calc_errors\");function g(t,e){this.scene=t,this.uid=e,this.linePlot=null,this.scatterPlot=null,this.errorBars=null,this.textMarkers=null,this.delaunayMesh=null,this.color=null,this.mode=\"\",this.dataPoints=[],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.textLabels=null,this.data=null}var v=g.prototype;function m(t){return null==t?0:t.indexOf(\"left\")>-1?-1:t.indexOf(\"right\")>-1?1:0}function y(t){return null==t?0:t.indexOf(\"top\")>-1?-1:t.indexOf(\"bottom\")>-1?1:0}function x(t,e){return e(4*t)}function b(t){return p[t]}function _(t,e,r,n,i){var a=null;if(l.isArrayOrTypedArray(t)){a=[];for(var o=0;o<e;o++)void 0===t[o]?a[o]=n:a[o]=r(t[o],i)}else a=r(t,l.identity);return a}function w(t,e){var r,n,i,a,o,s,f=[],p=t.fullSceneLayout,g=t.dataScale,v=p.xaxis,w=p.yaxis,k=p.zaxis,T=e.marker,A=e.line,M=e.x||[],S=e.y||[],E=e.z||[],C=M.length,L=e.xcalendar,P=e.ycalendar,O=e.zcalendar;for(o=0;o<C;o++)r=v.d2l(M[o],0,L)*g[0],n=w.d2l(S[o],0,P)*g[1],i=k.d2l(E[o],0,O)*g[2],f[o]=[r,n,i];if(Array.isArray(e.text))s=e.text;else if(void 0!==e.text)for(s=new Array(C),o=0;o<C;o++)s[o]=e.text;if(a={position:f,mode:e.mode,text:s},\"line\"in e&&(a.lineColor=u(A,1,C),a.lineWidth=A.width,a.lineDashes=A.dash),\"marker\"in e){var z=h(e);a.scatterColor=u(T,1,C),a.scatterSize=_(T.size,C,x,20,z),a.scatterMarker=_(T.symbol,C,b,\"\\u25cf\"),a.scatterLineWidth=T.line.width,a.scatterLineColor=u(T.line,1,C),a.scatterAngle=0}\"textposition\"in e&&(a.textOffset=function(t){var e=[0,0];if(Array.isArray(t))for(var r=0;r<t.length;r++)e[r]=[0,0],t[r]&&(e[r][0]=m(t[r]),e[r][1]=y(t[r]));else e[0]=m(t),e[1]=y(t);return e}(e.textposition),a.textColor=u(e.textfont,1,C),a.textSize=_(e.textfont.size,C,l.identity,12),a.textFont=e.textfont.family,a.textAngle=0);var I=[\"x\",\"y\",\"z\"];for(a.project=[!1,!1,!1],a.projectScale=[1,1,1],a.projectOpacity=[1,1,1],o=0;o<3;++o){var D=e.projection[I[o]];(a.project[o]=D.show)&&(a.projectOpacity[o]=D.opacity,a.projectScale[o]=D.scale)}a.errorBounds=d(e,g,p);var R=function(t){for(var e=[0,0,0],r=[[0,0,0],[0,0,0],[0,0,0]],n=[1,1,1],i=0;i<3;i++){var a=t[i];a&&!1!==a.copy_zstyle&&!1!==t[2].visible&&(a=t[2]),a&&a.visible&&(e[i]=a.width/2,r[i]=c(a.color),n[i]=a.thickness)}return{capSize:e,color:r,lineWidth:n}}([e.error_x,e.error_y,e.error_z]);return a.errorColor=R.color,a.errorLineWidth=R.lineWidth,a.errorCapSize=R.capSize,a.delaunayAxis=e.surfaceaxis,a.delaunayColor=c(e.surfacecolor),a}function k(t){if(Array.isArray(t)){var e=t[0];return Array.isArray(e)&&(t=e),\"rgb(\"+t.slice(0,3).map(function(t){return Math.round(255*t)})+\")\"}return null}v.handlePick=function(t){if(t.object&&(t.object===this.linePlot||t.object===this.delaunayMesh||t.object===this.textMarkers||t.object===this.scatterPlot)){var e=t.index=t.data.index;return t.object.highlight&&t.object.highlight(null),this.scatterPlot&&(t.object=this.scatterPlot,this.scatterPlot.highlight(t.data)),t.textLabel=\"\",this.textLabels&&(Array.isArray(this.textLabels)?(this.textLabels[e]||0===this.textLabels[e])&&(t.textLabel=this.textLabels[e]):t.textLabel=this.textLabels),t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]],!0}},v.update=function(t){var e,r,l,c,u=this.scene.glplot.gl,h=f.solid;this.data=t;var p=w(this.scene,t);\"mode\"in p&&(this.mode=p.mode),\"lineDashes\"in p&&p.lineDashes in f&&(h=f[p.lineDashes]),this.color=k(p.scatterColor)||k(p.lineColor),this.dataPoints=p.position,e={gl:this.scene.glplot.gl,position:p.position,color:p.lineColor,lineWidth:p.lineWidth||1,dashes:h[0],dashScale:h[1],opacity:t.opacity,connectGaps:t.connectgaps},-1!==this.mode.indexOf(\"lines\")?this.linePlot?this.linePlot.update(e):(this.linePlot=n(e),this.linePlot._trace=this,this.scene.glplot.add(this.linePlot)):this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose(),this.linePlot=null);var d=t.opacity;if(t.marker&&t.marker.opacity&&(d*=t.marker.opacity),r={gl:this.scene.glplot.gl,position:p.position,color:p.scatterColor,size:p.scatterSize,glyph:p.scatterMarker,opacity:d,orthographic:!0,lineWidth:p.scatterLineWidth,lineColor:p.scatterLineColor,project:p.project,projectScale:p.projectScale,projectOpacity:p.projectOpacity},-1!==this.mode.indexOf(\"markers\")?this.scatterPlot?this.scatterPlot.update(r):(this.scatterPlot=i(r),this.scatterPlot._trace=this,this.scatterPlot.highlightScale=1,this.scene.glplot.add(this.scatterPlot)):this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose(),this.scatterPlot=null),c={gl:this.scene.glplot.gl,position:p.position,glyph:p.text,color:p.textColor,size:p.textSize,angle:p.textAngle,alignment:p.textOffset,font:p.textFont,orthographic:!0,lineWidth:0,project:!1,opacity:t.opacity},this.textLabels=t.hovertext||t.text,-1!==this.mode.indexOf(\"text\")?this.textMarkers?this.textMarkers.update(c):(this.textMarkers=i(c),this.textMarkers._trace=this,this.textMarkers.highlightScale=1,this.scene.glplot.add(this.textMarkers)):this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose(),this.textMarkers=null),l={gl:this.scene.glplot.gl,position:p.position,color:p.errorColor,error:p.errorBounds,lineWidth:p.errorLineWidth,capSize:p.errorCapSize,opacity:t.opacity},this.errorBars?p.errorBounds?this.errorBars.update(l):(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose(),this.errorBars=null):p.errorBounds&&(this.errorBars=a(l),this.errorBars._trace=this,this.scene.glplot.add(this.errorBars)),p.delaunayAxis>=0){var g=function(t,e,r){var n,i=(r+1)%3,a=(r+2)%3,o=[],l=[];for(n=0;n<t.length;++n){var c=t[n];!isNaN(c[i])&&isFinite(c[i])&&!isNaN(c[a])&&isFinite(c[a])&&(o.push([c[i],c[a]]),l.push(n))}var u=s(o);for(n=0;n<u.length;++n)for(var h=u[n],f=0;f<h.length;++f)h[f]=l[h[f]];return{positions:t,cells:u,meshColor:e}}(p.position,p.delaunayColor,p.delaunayAxis);g.opacity=t.opacity,this.delaunayMesh?this.delaunayMesh.update(g):(g.gl=u,this.delaunayMesh=o(g),this.delaunayMesh._trace=this,this.scene.glplot.add(this.delaunayMesh))}else this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose(),this.delaunayMesh=null)},v.dispose=function(){this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose()),this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose()),this.errorBars&&(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose()),this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose()),this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose())},e.exports=function(t,e){var r=new g(t,e.uid);return r.update(e),r}},{\"../../constants/gl3d_dashes\":692,\"../../constants/gl3d_markers\":693,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../scatter/make_bubble_size_func\":1128,\"./calc_errors\":1140,\"delaunay-triangulate\":165,\"gl-error3d\":247,\"gl-line3d\":255,\"gl-mesh3d\":280,\"gl-scatter3d\":297}],1142:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,n){return i.coerce(t,e,c,r,n)}if(function(t,e,r,i){var a=0,o=r(\"x\"),s=r(\"y\"),l=r(\"z\");n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],i),o&&s&&l&&(a=Math.min(o.length,s.length,l.length),e._length=e._xlength=e._ylength=e._zlength=a);return a}(t,e,h,u)){h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),a.hasLines(e)&&(h(\"connectgaps\"),s(t,e,r,u,h)),a.hasMarkers(e)&&o(t,e,r,u,h,{noSelect:!0}),a.hasText(e)&&l(t,e,u,h,{noSelect:!0});var f=(e.line||{}).color,p=(e.marker||{}).color;h(\"surfaceaxis\")>=0&&h(\"surfacecolor\",f||p);for(var d=[\"x\",\"y\",\"z\"],g=0;g<3;++g){var v=\"projection.\"+d[g];h(v+\".show\")&&(h(v+\".opacity\"),h(v+\".scale\"))}var m=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");m(t,e,f||p||r,{axis:\"z\"}),m(t,e,f||p||r,{axis:\"y\",inherit:\"z\"}),m(t,e,f||p||r,{axis:\"x\",inherit:\"z\"})}else e.visible=!1}},{\"../../lib\":719,\"../../registry\":847,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1138}],1143:[function(t,e,r){\"use strict\";e.exports={plot:t(\"./convert\"),attributes:t(\"./attributes\"),markerSymbols:t(\"../../constants/gl3d_markers\"),supplyDefaults:t(\"./defaults\"),colorbar:[{container:\"marker\",min:\"cmin\",max:\"cmax\"},{container:\"line\",min:\"cmin\",max:\"cmax\"}],calc:t(\"./calc\"),moduleType:\"trace\",name:\"scatter3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"symbols\",\"showLegend\"],meta:{}}},{\"../../constants/gl3d_markers\":693,\"../../plots/gl3d\":807,\"./attributes\":1138,\"./calc\":1139,\"./convert\":1141,\"./defaults\":1142}],1144:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=n.marker,c=n.line,u=l.line;e.exports={carpet:{valType:\"string\",editType:\"calc\"},a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},mode:s({},n.mode,{dflt:\"markers\"}),text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),line:{color:c.color,width:c.width,dash:c.dash,shape:s({},c.shape,{values:[\"linear\",\"spline\"]}),smoothing:c.smoothing,editType:\"calc\"},connectgaps:n.connectgaps,fill:s({},n.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:n.fillcolor,marker:s({symbol:l.symbol,opacity:l.opacity,maxdisplayed:l.maxdisplayed,size:l.size,sizeref:l.sizeref,sizemin:l.sizemin,sizemode:l.sizemode,line:s({width:u.width,editType:\"calc\"},o(\"marker.line\")),gradient:l.gradient,editType:\"calc\"},o(\"marker\")),textfont:n.textfont,textposition:n.textposition,selected:n.selected,unselected:n.unselected,hoverinfo:s({},i.hoverinfo,{flags:[\"a\",\"b\",\"text\",\"name\"]}),hoveron:n.hoveron,hovertemplate:a()}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1145:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=t(\"../carpet/lookup_carpetid\");e.exports=function(t,e){var r=e._carpetTrace=l(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){var c;e.xaxis=r.xaxis,e.yaxis=r.yaxis;var u,h,f=e._length,p=new Array(f),d=!1;for(c=0;c<f;c++)if(u=e.a[c],h=e.b[c],n(u)&&n(h)){var g=r.ab2xy(+u,+h,!0),v=r.isVisible(+u,+h);v||(d=!0),p[c]={x:g[0],y:g[1],a:u,b:h,vis:v}}else p[c]={x:!1,y:!1};return e._needsCull=d,p[0].carpet=r,p[0].trace=e,s(e,f),i(t,e),a(p,e),o(p,e),p}}},{\"../carpet/lookup_carpetid\":915,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc\":1113,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1146:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}p(\"carpet\"),e.xaxis=\"x\",e.yaxis=\"y\";var d=p(\"a\"),g=p(\"b\"),v=Math.min(d.length,g.length);if(v){e._length=v,p(\"text\"),p(\"hovertext\"),p(\"mode\",v<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,f,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,f,p,{gradient:!0}),a.hasText(e)&&c(t,e,f,p);var m=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"marker.maxdisplayed\"),m.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||m.push(\"fills\"),\"fills\"!==p(\"hoveron\",m.join(\"+\")||\"points\")&&p(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/line_shape_defaults\":1126,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1144}],1147:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=n[i];return t.a=a.a,t.b=a.b,t.y=a.y,t}},{}],1148:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../lib\").fillText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,h=c-u;return s.x0=Math.max(Math.min(s.x0,h),u),s.x1=Math.max(Math.min(s.x1,h),u),o}var f=s.cd[s.index];s.a=f.a,s.b=f.b,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.trace,d=p._carpet,g=d.ab2ij([f.a,f.b]),v=Math.floor(g[0]),m=g[0]-v,y=Math.floor(g[1]),x=g[1]-y,b=d.evalxy([],v,y,m,x);s.yLabel=b[1].toFixed(3),delete s.text;var _=[];if(!p.hovertemplate){var w=(f.hi||p.hoverinfo).split(\"+\");-1!==w.indexOf(\"all\")&&(w=[\"a\",\"b\",\"text\"]),-1!==w.indexOf(\"a\")&&k(d.aaxis,f.a),-1!==w.indexOf(\"b\")&&k(d.baxis,f.b),_.push(\"y: \"+s.yLabel),-1!==w.indexOf(\"text\")&&i(f,p,_),s.extraText=_.join(\"<br>\")}return o}function k(t,e){var r;r=t.labelprefix&&t.labelprefix.length>0?t.labelprefix.replace(/ = $/,\"\"):t._hovertitle,_.push(r+\": \"+e.toFixed(3)+t.labelsuffix)}}},{\"../../lib\":719,\"../scatter/hover\":1122}],1149:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scattercarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"svg\",\"carpet\",\"symbols\",\"showLegend\",\"carpetDependent\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../scatter/marker_colorbar\":1129,\"../scatter/select\":1132,\"../scatter/style\":1134,\"./attributes\":1144,\"./calc\":1145,\"./defaults\":1146,\"./event_data\":1147,\"./hover\":1148,\"./plot\":1150}],1150:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../components/drawing\");e.exports=function(t,e,r,o){var s,l,c,u=r[0][0].carpet,h={xaxis:i.getFromId(t,u.xaxis||\"x\"),yaxis:i.getFromId(t,u.yaxis||\"y\"),plot:e.plot};for(n(t,h,r,o),s=0;s<r.length;s++)l=r[s][0].trace,c=o.selectAll(\"g.trace\"+l.uid+\" .js-line\"),a.setClipUrl(c,r[s][0].carpet._clipPathId,t)}},{\"../../components/drawing\":614,\"../../plots/cartesian/axes\":767,\"../scatter/plot\":1131}],1151:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/drawing/attributes\").dash,l=t(\"../../lib/extend\").extendFlat,c=t(\"../../plot_api/edit_types\").overrideAll,u=i.marker,h=i.line,f=u.line;e.exports=c({lon:{valType:\"data_array\"},lat:{valType:\"data_array\"},locations:{valType:\"data_array\"},locationmode:{valType:\"enumerated\",values:[\"ISO-3\",\"USA-states\",\"country names\"],dflt:\"ISO-3\"},mode:l({},i.mode,{dflt:\"markers\"}),text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),textfont:i.textfont,textposition:i.textposition,line:{color:h.color,width:h.width,dash:s},connectgaps:i.connectgaps,marker:l({symbol:u.symbol,opacity:u.opacity,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,colorbar:u.colorbar,line:l({width:f.width},o(\"marker.line\")),gradient:u.gradient},o(\"marker\")),fill:{valType:\"enumerated\",values:[\"none\",\"toself\"],dflt:\"none\"},fillcolor:i.fillcolor,selected:i.selected,unselected:i.unselected,hoverinfo:l({},a.hoverinfo,{flags:[\"lon\",\"lat\",\"location\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":600,\"../../components/drawing/attributes\":613,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1152:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../scatter/colorscale_calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\"),l=t(\"../../lib\")._;e.exports=function(t,e){for(var r=Array.isArray(e.locations),c=r?e.locations.length:e._length,u=new Array(c),h=0;h<c;h++){var f=u[h]={};if(r){var p=e.locations[h];f.loc=\"string\"==typeof p?p:null}else{var d=e.lon[h],g=e.lat[h];n(d)&&n(g)?f.lonlat=[+d,+g]:f.lonlat=[i,i]}}return o(u,e),a(t,e),s(u,e),c&&(u[0].t={labels:{lat:l(t,\"lat:\")+\" \",lon:l(t,\"lon:\")+\" \"}}),u}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1153:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,i){return n.coerce(t,e,c,r,i)}!function(t,e,r){var n,i,a=0,o=r(\"locations\");if(o)return r(\"locationmode\"),a=o.length;return n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length),e._length=a,a}(0,e,h)?e.visible=!1:(h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),i.hasLines(e)&&(o(t,e,r,u,h),h(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,u,h,{gradient:!0}),i.hasText(e)&&s(t,e,u,h),h(\"fill\"),\"none\"!==e.fill&&l(t,e,r,h),n.coerceSelectionMarkerOpacity(e,h))}},{\"../../lib\":719,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1151}],1154:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.location=e.loc?e.loc:null,t}},{}],1155:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../scatter/get_trace_color\"),s=t(\"../../lib\").fillText,l=t(\"./attributes\");e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,h=t.xa,f=t.ya,p=t.subplot,d=p.projection.isLonLatOverEdges,g=p.project;if(n.getClosest(c,function(t){var n=t.lonlat;if(n[0]===a)return 1/0;if(d(n))return 1/0;var i=g(n),o=g([e,r]),s=Math.abs(i[0]-o[0]),l=Math.abs(i[1]-o[1]),c=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(s*s+l*l)-c,1-3/c)},t),!1!==t.index){var v=c[t.index],m=v.lonlat,y=[h.c2p(m),f.c2p(m)],x=v.mrc||1;t.x0=y[0]-x,t.x1=y[0]+x,t.y0=y[1]-x,t.y1=y[1]+x,t.loc=v.loc,t.lon=m[0],t.lat=m[1];var b=p.mockAxis;return t.lonLabel=i.tickText(b,b.c2l(t.lon),\"hover\").text,t.latLabel=i.tickText(b,b.c2l(t.lat),\"hover\").text,t.color=o(u,v),t.extraText=function(t,e,r,n){if(t.hovertemplate)return;var i=e.hi||t.hoverinfo,a=\"all\"===i?l.hoverinfo.flags:i.split(\"+\"),o=-1!==a.indexOf(\"location\")&&Array.isArray(t.locations),c=-1!==a.indexOf(\"lon\"),u=-1!==a.indexOf(\"lat\"),h=-1!==a.indexOf(\"text\"),f=[];function p(t){return t+\"\\xb0\"}o?f.push(e.loc):c&&u?f.push(\"(\"+p(r.lonLabel)+\", \"+p(r.latLabel)+\")\"):c?f.push(n.lon+p(r.lonLabel)):u&&f.push(n.lat+p(r.latLabel));h&&s(e,t,f);return f.join(\"<br>\")}(u,v,t,c[0].t.labels),t.hovertemplate=u.hovertemplate,[t]}}},{\"../../components/fx\":632,\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scatter/get_trace_color\":1121,\"./attributes\":1151}],1156:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"scattergeo\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/geo\":797,\"../scatter/marker_colorbar\":1129,\"../scatter/style\":1134,\"./attributes\":1151,\"./calc\":1152,\"./defaults\":1153,\"./event_data\":1154,\"./hover\":1155,\"./plot\":1157,\"./select\":1158,\"./style\":1159}],1157:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../lib/topojson_utils\").getTopojsonFeatures,s=t(\"../../lib/geo_location_utils\").locationToFeature,l=t(\"../../lib/geojson_utils\"),c=t(\"../scatter/subtypes\"),u=t(\"./style\");function h(t,e){var r=t[0].trace;if(Array.isArray(r.locations))for(var n=o(r,e),i=r.locationmode,l=0;l<t.length;l++){var c=t[l],u=s(i,c.loc,n);c.lonlat=u?u.properties.ct:[a,a]}}e.exports=function(t,e,r){for(var o=0;o<r.length;o++)h(r[o],e.topojson);function s(t,e){t.lonlat[0]===a&&n.select(e).remove()}var f=e.layers.frontplot.select(\".scatterlayer\"),p=i.makeTraceGroups(f,r,\"trace scattergeo\");p.selectAll(\"*\").remove(),p.each(function(e){var r=n.select(this),a=e[0].trace;if(c.hasLines(a)||\"none\"!==a.fill){var o=l.calcTraceToLineCoords(e),h=\"none\"!==a.fill?l.makePolygon(o):l.makeLine(o);r.selectAll(\"path.js-line\").data([{geojson:h,trace:a}]).enter().append(\"path\").classed(\"js-line\",!0).style(\"stroke-miterlimit\",2)}c.hasMarkers(a)&&r.selectAll(\"path.point\").data(i.identity).enter().append(\"path\").classed(\"point\",!0).each(function(t){s(t,this)}),c.hasText(a)&&r.selectAll(\"g\").data(i.identity).enter().append(\"g\").append(\"text\").each(function(t){s(t,this)}),u(t,e)})}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/geo_location_utils\":713,\"../../lib/geojson_utils\":714,\"../../lib/topojson_utils\":746,\"../scatter/subtypes\":1135,\"./style\":1159,d3:163}],1158:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,a,o,s,l,c=t.cd,u=t.xaxis,h=t.yaxis,f=[],p=c[0].trace;if(!n.hasMarkers(p)&&!n.hasText(p))return[];if(!1===e)for(l=0;l<c.length;l++)c[l].selected=0;else for(l=0;l<c.length;l++)(a=(r=c[l]).lonlat)[0]!==i&&(o=u.c2p(a),s=h.c2p(a),e.contains([o,s],null,l,t)?(f.push({pointNumber:l,lon:a[0],lat:a[1]}),r.selected=1):r.selected=0);return f}},{\"../../constants/numerical\":695,\"../scatter/subtypes\":1135}],1159:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../scatter/style\"),s=o.stylePoints,l=o.styleText;e.exports=function(t,e){e&&function(t,e){var r=e[0].trace,o=e[0].node3;o.style(\"opacity\",e[0].trace.opacity),s(o,r,t),l(o,r,t),o.selectAll(\"path.js-line\").style(\"fill\",\"none\").each(function(t){var e=n.select(this),r=t.trace,o=r.line||{};e.call(a.stroke,o.color).call(i.dashLine,o.dash||\"\",o.width||0),\"none\"!==r.fill&&e.call(a.fill,r.fillcolor)})}(t,e)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../scatter/style\":1134,d3:163}],1160:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=t(\"./constants\").DASHES,c=i.line,u=i.marker,h=u.line,f=e.exports=s({x:i.x,x0:i.x0,dx:i.dx,y:i.y,y0:i.y0,dy:i.dy,text:i.text,hovertext:i.hovertext,textposition:i.textposition,textfont:i.textfont,mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"]},line:{color:c.color,width:c.width,shape:{valType:\"enumerated\",values:[\"linear\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},dash:{valType:\"enumerated\",values:Object.keys(l),dflt:\"solid\"}},marker:o({},a(\"marker\"),{symbol:u.symbol,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:o({},a(\"marker.line\"),{width:h.width})}),connectgaps:i.connectgaps,fill:o({},i.fill,{dflt:\"none\"}),fillcolor:i.fillcolor,selected:{marker:i.selected.marker,textfont:i.selected.textfont},unselected:{marker:i.unselected.marker,textfont:i.unselected.textfont},opacity:n.opacity},\"calc\",\"nested\");f.x.editType=f.y.editType=f.x0.editType=f.y0.editType=\"calc+clearAxisTypes\",f.hovertemplate=i.hovertemplate},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../scatter/attributes\":1112,\"./constants\":1162}],1161:[function(t,e,r){\"use strict\";var n=t(\"point-cluster\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../plots/cartesian/autorange\").findExtremes,s=t(\"../scatter/calc\"),l=s.calcMarkerSize,c=s.calcAxisExpansion,u=s.setFirstScatter,h=t(\"../scatter/colorscale_calc\"),f=t(\"./convert\"),p=t(\"./scene_update\"),d=t(\"../../constants/numerical\").BADNUM,g=t(\"./constants\").TOO_MANY_POINTS;function v(t,e,r){var n=t._extremes[e._id],i=o(e,r._bnds,{padded:!0});n.min=n.min.concat(i.min),n.max=n.max.concat(i.max)}e.exports=function(t,e){var r,o,s,m=t._fullLayout,y=a.getFromId(t,e.xaxis),x=a.getFromId(t,e.yaxis),b=m._plots[e.xaxis+e.yaxis],_=e._length,w=_>=g,k=2*_,T={},A=y.makeCalcdata(e,\"x\"),M=x.makeCalcdata(e,\"y\"),S=new Array(k);for(r=0;r<_;r++)o=A[r],s=M[r],S[2*r]=o===d?NaN:o,S[2*r+1]=s===d?NaN:s;if(\"log\"===y.type)for(r=0;r<k;r+=2)S[r]=y.c2l(S[r]);if(\"log\"===x.type)for(r=1;r<k;r+=2)S[r]=x.c2l(S[r]);if(w&&\"log\"!==y.type&&\"log\"!==x.type)T.tree=n(S);else{var E=T.ids=new Array(_);for(r=0;r<_;r++)E[r]=r}h(t,e);var C,L=function(t,e,r,n,a,o){var s=f.style(t,r);s.marker&&(s.marker.positions=n);s.line&&n.length>1&&i.extendFlat(s.line,f.linePositions(t,r,n));if(s.errorX||s.errorY){var l=f.errorBarPositions(t,r,n,a,o);s.errorX&&i.extendFlat(s.errorX,l.x),s.errorY&&i.extendFlat(s.errorY,l.y)}s.text&&(i.extendFlat(s.text,{positions:n},f.textPosition(t,r,s.text,s.marker)),i.extendFlat(s.textSel,{positions:n},f.textPosition(t,r,s.text,s.markerSel)),i.extendFlat(s.textUnsel,{positions:n},f.textPosition(t,r,s.text,s.markerUnsel)));return s}(t,0,e,S,A,M),P=p(t,b);return u(m,e),w?L.marker&&(C=2*(L.marker.sizeAvg||Math.max(L.marker.size,3))):C=l(e,_),c(t,e,y,x,A,M,C),L.errorX&&v(e,y,L.errorX),L.errorY&&v(e,x,L.errorY),L.fill&&!P.fill2d&&(P.fill2d=!0),L.marker&&!P.scatter2d&&(P.scatter2d=!0),L.line&&!P.line2d&&(P.line2d=!0),!L.errorX&&!L.errorY||P.error2d||(P.error2d=!0),L.text&&!P.glText&&(P.glText=!0),L.marker&&(L.marker.snap=T.tree||g),P.lineOptions.push(L.line),P.errorXOptions.push(L.errorX),P.errorYOptions.push(L.errorY),P.fillOptions.push(L.fill),P.markerOptions.push(L.marker),P.markerSelectedOptions.push(L.markerSel),P.markerUnselectedOptions.push(L.markerUnsel),P.textOptions.push(L.text),P.textSelectedOptions.push(L.textSel),P.textUnselectedOptions.push(L.textUnsel),P.selectBatch.push([]),P.unselectBatch.push([]),T._scene=P,T.index=P.count,T.x=A,T.y=M,T.positions=S,P.count++,[{x:!1,y:!1,t:T,trace:e}]}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/autorange\":766,\"../../plots/cartesian/axis_ids\":770,\"../scatter/calc\":1113,\"../scatter/colorscale_calc\":1115,\"./constants\":1162,\"./convert\":1163,\"./scene_update\":1169,\"point-cluster\":469}],1162:[function(t,e,r){\"use strict\";e.exports={TOO_MANY_POINTS:1e5,SYMBOL_SDF_SIZE:200,SYMBOL_SIZE:20,SYMBOL_STROKE:1,DOT_RE:/-dot/,OPEN_RE:/-open/,DASHES:{solid:[1],dot:[1,1],dash:[4,1],longdash:[8,1],dashdot:[4,1,1,1],longdashdot:[8,1,1,1]}}},{}],1163:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"svg-path-sdf\"),a=t(\"color-normalize\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../components/drawing\"),c=t(\"../../plots/cartesian/axis_ids\"),u=t(\"../../lib/gl_format_color\").formatColor,h=t(\"../scatter/subtypes\"),f=t(\"../scatter/make_bubble_size_func\"),p=t(\"./constants\"),d=t(\"../../constants/interactions\").DESELECTDIM,g={start:1,left:1,end:-1,right:-1,middle:0,center:0,bottom:1,top:-1};function v(t){var e,r=t._length,i=t.textfont,a=t.textposition,o=Array.isArray(a)?a:[a],s=i.color,l=i.size,c=i.family,u={};for(u.text=t.text,u.opacity=t.opacity,u.font={},u.align=[],u.baseline=[],e=0;e<o.length;e++){var h=o[e].split(/\\s+/);switch(h[1]){case\"left\":u.align.push(\"right\");break;case\"right\":u.align.push(\"left\");break;default:u.align.push(h[1])}switch(h[0]){case\"top\":u.baseline.push(\"bottom\");break;case\"bottom\":u.baseline.push(\"top\");break;default:u.baseline.push(h[0])}}if(Array.isArray(s))for(u.color=new Array(r),e=0;e<r;e++)u.color[e]=s[e];else u.color=s;if(Array.isArray(l)||Array.isArray(c))for(u.font=new Array(r),e=0;e<r;e++){var f=u.font[e]={};f.size=Array.isArray(l)?n(l[e])?l[e]:0:l,f.family=Array.isArray(c)?c[e]:c}else u.font={size:l,family:c};return u}function m(t){var e,r,n=t._length,i=t.marker,o={},l=Array.isArray(i.symbol),c=s.isArrayOrTypedArray(i.color),h=s.isArrayOrTypedArray(i.line.color),d=s.isArrayOrTypedArray(i.opacity),g=s.isArrayOrTypedArray(i.size),v=s.isArrayOrTypedArray(i.line.width);if(l||(r=p.OPEN_RE.test(i.symbol)),l||c||h||d){o.colors=new Array(n),o.borderColors=new Array(n);var m=u(i,i.opacity,n),y=u(i.line,i.opacity,n);if(!Array.isArray(y[0])){var x=y;for(y=Array(n),e=0;e<n;e++)y[e]=x}if(!Array.isArray(m[0])){var b=m;for(m=Array(n),e=0;e<n;e++)m[e]=b}for(o.colors=m,o.borderColors=y,e=0;e<n;e++){if(l){var _=i.symbol[e];r=p.OPEN_RE.test(_)}r&&(y[e]=m[e].slice(),m[e]=m[e].slice(),m[e][3]=0)}o.opacity=t.opacity}else r?(o.color=a(i.color,\"uint8\"),o.color[3]=0,o.borderColor=a(i.color,\"uint8\")):(o.color=a(i.color,\"uint8\"),o.borderColor=a(i.line.color,\"uint8\")),o.opacity=t.opacity*i.opacity;if(l)for(o.markers=new Array(n),e=0;e<n;e++)o.markers[e]=M(i.symbol[e]);else o.marker=M(i.symbol);var w,k=f(t);if(g||v){var T,A=o.sizes=new Array(n),S=o.borderSizes=new Array(n),E=0;if(g){for(e=0;e<n;e++)A[e]=k(i.size[e]),E+=A[e];T=E/n}else for(w=k(i.size),e=0;e<n;e++)A[e]=w;if(v)for(e=0;e<n;e++)S[e]=i.line.width[e]/2;else for(w=i.line.width/2,e=0;e<n;e++)S[e]=w;o.sizeAvg=T}else o.size=k(i&&i.size||10),o.borderSizes=k(i.line.width);return o}function y(t,e){var r=t.marker,n={};return e?(e.marker&&e.marker.symbol?n=m(s.extendFlat({},r,e.marker)):e.marker&&(e.marker.size&&(n.size=e.marker.size/2),e.marker.color&&(n.colors=e.marker.color),void 0!==e.marker.opacity&&(n.opacity=e.marker.opacity)),n):n}function x(t,e){var r={};if(!e)return r;if(e.textfont){var n={opacity:1,text:t.text,textposition:t.textposition,textfont:s.extendFlat({},t.textfont)};e.textfont&&s.extendFlat(n.textfont,e.textfont),r=v(n)}return r}function b(t,e){var r={capSize:2*e.width,lineWidth:e.thickness,color:e.color};return e.copy_ystyle&&(r=t.error_y),r}var _=p.SYMBOL_SDF_SIZE,w=p.SYMBOL_SIZE,k=p.SYMBOL_STROKE,T={},A=l.symbolFuncs[0](.05*w);function M(t){if(\"circle\"===t)return null;var e,r,n=l.symbolNumber(t),a=l.symbolFuncs[n%100],o=!!l.symbolNoDot[n%100],s=!!l.symbolNoFill[n%100],c=p.DOT_RE.test(t);return T[t]?T[t]:(e=c&&!o?a(1.1*w)+A:a(w),r=i(e,{w:_,h:_,viewBox:[-w,-w,w,w],stroke:s?k:-k}),T[t]=r,r||null)}e.exports={style:function(t,e){var r,n={marker:void 0,markerSel:void 0,markerUnsel:void 0,line:void 0,fill:void 0,errorX:void 0,errorY:void 0,text:void 0,textSel:void 0,textUnsel:void 0};if(!0!==e.visible)return n;if(h.hasText(e)&&(n.text=v(e),n.textSel=x(e,e.selected),n.textUnsel=x(e,e.unselected)),h.hasMarkers(e)&&(n.marker=m(e),n.markerSel=y(e,e.selected),n.markerUnsel=y(e,e.unselected),!e.unselected&&Array.isArray(e.marker.opacity))){var i=e.marker.opacity;for(n.markerUnsel.opacity=new Array(i.length),r=0;r<i.length;r++)n.markerUnsel.opacity[r]=d*i[r]}if(h.hasLines(e)){n.line={overlay:!0,thickness:e.line.width,color:e.line.color,opacity:e.opacity};var a=(p.DASHES[e.line.dash]||[1]).slice();for(r=0;r<a.length;++r)a[r]*=e.line.width;n.line.dashes=a}return e.error_x&&e.error_x.visible&&(n.errorX=b(e,e.error_x)),e.error_y&&e.error_y.visible&&(n.errorY=b(e,e.error_y)),e.fill&&\"none\"!==e.fill&&(n.fill={closed:!0,fill:e.fillcolor,thickness:0}),n},markerStyle:m,markerSelection:y,linePositions:function(t,e,r){var n,i,a=r.length,o=a/2;if(h.hasLines(e)&&o)if(\"hv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i+2],r[2*i+1]));n.push(r[a-2],r[a-1])}else if(\"hvh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var s=(r[2*i]+r[2*i+2])/2;n.push(r[2*i],r[2*i+1],s,r[2*i+1],s,r[2*i+3])}n.push(r[a-2],r[a-1])}else if(\"vhv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var l=(r[2*i+1]+r[2*i+3])/2;n.push(r[2*i],r[2*i+1],r[2*i],l,r[2*i+2],l)}n.push(r[a-2],r[a-1])}else if(\"vh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+3]));n.push(r[a-2],r[a-1])}else n=r;var c=!1;for(i=0;i<n.length;i++)if(isNaN(n[i])){c=!0;break}var u=c||n.length>p.TOO_MANY_POINTS?\"rect\":h.hasMarkers(e)?\"rect\":\"round\";if(c&&e.connectgaps){var f=n[0],d=n[1];for(i=0;i<n.length;i+=2)isNaN(n[i])||isNaN(n[i+1])?(n[i]=f,n[i+1]=d):(f=n[i],d=n[i+1])}return{join:u,positions:n}},errorBarPositions:function(t,e,r,i,a){var s=o.getComponentMethod(\"errorbars\",\"makeComputeError\"),l=c.getFromId(t,e.xaxis),u=c.getFromId(t,e.yaxis),h=r.length/2,f={};function p(t,i){var a=i._id.charAt(0),o=e[\"error_\"+a];if(o&&o.visible&&(\"linear\"===i.type||\"log\"===i.type)){for(var l=s(o),c={x:0,y:1}[a],u={x:[0,1,2,3],y:[2,3,0,1]}[a],p=new Float64Array(4*h),d=1/0,g=-1/0,v=0,m=0;v<h;v++,m+=4){var y=t[v];if(n(y)){var x=r[2*v+c],b=l(y,v),_=b[0],w=b[1];if(n(_)&&n(w)){var k=y-_,T=y+w;p[m+u[0]]=x-i.c2l(k),p[m+u[1]]=i.c2l(T)-x,p[m+u[2]]=0,p[m+u[3]]=0,d=Math.min(d,y-_),g=Math.max(g,y+w)}}}f[a]={positions:r,errors:p,_bnds:[d,g]}}}return p(i,l),p(a,u),f},textPosition:function(t,e,r,n){var i,a=e._length,o={};if(h.hasMarkers(e)){var s=r.font,l=r.align,c=r.baseline;for(o.offset=new Array(a),i=0;i<a;i++){var u=n.sizes?n.sizes[i]:n.size,f=Array.isArray(s)?s[i].size:s.size,p=Array.isArray(l)?l.length>1?l[i]:l[0]:l,d=Array.isArray(c)?c.length>1?c[i]:c[0]:c,v=g[p],m=g[d],y=u?u/.8+1:0,x=-m*y-.5*m;o.offset[i]=[v*y/f,x/f]}}return o}}},{\"../../components/drawing\":614,\"../../constants/interactions\":694,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../scatter/make_bubble_size_func\":1128,\"../scatter/subtypes\":1135,\"./constants\":1162,\"color-normalize\":120,\"fast-isnumeric\":225,\"svg-path-sdf\":535}],1164:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"../scatter/constants\"),s=t(\"../scatter/subtypes\"),l=t(\"../scatter/xy_defaults\"),c=t(\"../scatter/marker_defaults\"),u=t(\"../scatter/line_defaults\"),h=t(\"../scatter/fillcolor_defaults\"),f=t(\"../scatter/text_defaults\");e.exports=function(t,e,r,p){function d(r,i){return n.coerce(t,e,a,r,i)}var g=!!t.marker&&/-open/.test(t.marker.symbol),v=s.isBubble(t),m=l(t,e,p,d);if(m){var y=m<o.PTS_LINESONLY?\"lines+markers\":\"lines\";d(\"text\"),d(\"hovertext\"),d(\"hovertemplate\"),d(\"mode\",y),s.hasLines(e)&&(d(\"connectgaps\"),u(t,e,r,p,d),d(\"line.shape\")),s.hasMarkers(e)&&(c(t,e,r,p,d),d(\"marker.line.width\",g||v?1:0)),s.hasText(e)&&f(t,e,p,d);var x=(e.line||{}).color,b=(e.marker||{}).color;d(\"fill\"),\"none\"!==e.fill&&h(t,e,r,d);var _=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");_(t,e,x||b||r,{axis:\"y\"}),_(t,e,x||b||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}},{\"../../lib\":719,\"../../registry\":847,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"../scatter/xy_defaults\":1137,\"./attributes\":1160}],1165:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../constants/interactions\").DESELECTDIM;e.exports={styleTextSelection:function(t){var e,r,o=t[0],s=o.trace,l=o.t,c=l._scene,u=l.index,h=c.selectBatch[u],f=c.unselectBatch[u],p=c.textOptions[u],d=c.textSelectedOptions[u]||{},g=c.textUnselectedOptions[u]||{},v=n.extendFlat({},p);if(h.length||f.length){var m=d.color,y=g.color,x=p.color,b=Array.isArray(x);for(v.color=new Array(s._length),e=0;e<h.length;e++)r=h[e],v.color[r]=m||(b?x[r]:x);for(e=0;e<f.length;e++){r=f[e];var _=b?x[r]:x;v.color[r]=y||(m?_:i.addOpacity(_,a))}}c.glText[u].update(v)}}},{\"../../components/color\":593,\"../../constants/interactions\":694,\"../../lib\":719}],1166:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\");function o(t,e,r,o){var s=t.xa,l=t.ya,c=t.distance,u=t.dxy,h=t.index,f={pointNumber:h,x:e[h],y:r[h]};f.tx=Array.isArray(o.text)?o.text[h]:o.text,f.htx=Array.isArray(o.hovertext)?o.hovertext[h]:o.hovertext,f.data=Array.isArray(o.customdata)?o.customdata[h]:o.customdata,f.tp=Array.isArray(o.textposition)?o.textposition[h]:o.textposition;var p=o.textfont;p&&(f.ts=Array.isArray(p.size)?p.size[h]:p.size,f.tc=Array.isArray(p.color)?p.color[h]:p.color,f.tf=Array.isArray(p.family)?p.family[h]:p.family);var d=o.marker;d&&(f.ms=i.isArrayOrTypedArray(d.size)?d.size[h]:d.size,f.mo=i.isArrayOrTypedArray(d.opacity)?d.opacity[h]:d.opacity,f.mx=Array.isArray(d.symbol)?d.symbol[h]:d.symbol,f.mc=i.isArrayOrTypedArray(d.color)?d.color[h]:d.color);var g=d&&d.line;g&&(f.mlc=Array.isArray(g.color)?g.color[h]:g.color,f.mlw=i.isArrayOrTypedArray(g.width)?g.width[h]:g.width);var v=d&&d.gradient;v&&\"none\"!==v.type&&(f.mgt=Array.isArray(v.type)?v.type[h]:v.type,f.mgc=Array.isArray(v.color)?v.color[h]:v.color);var m=s.c2p(f.x,!0),y=l.c2p(f.y,!0),x=f.mrc||1,b=o.hoverlabel;b&&(f.hbg=Array.isArray(b.bgcolor)?b.bgcolor[h]:b.bgcolor,f.hbc=Array.isArray(b.bordercolor)?b.bordercolor[h]:b.bordercolor,f.hts=Array.isArray(b.font.size)?b.font.size[h]:b.font.size,f.htc=Array.isArray(b.font.color)?b.font.color[h]:b.font.color,f.htf=Array.isArray(b.font.family)?b.font.family[h]:b.font.family,f.hnl=Array.isArray(b.namelength)?b.namelength[h]:b.namelength);var _=o.hoverinfo;_&&(f.hi=Array.isArray(_)?_[h]:_);var w=o.hovertemplate;w&&(f.ht=Array.isArray(w)?w[h]:w);var k={};return k[t.index]=f,i.extendFlat(t,{color:a(o,f),x0:m-x,x1:m+x,xLabelVal:f.x,y0:y-x,y1:y+x,yLabelVal:f.y,cd:k,distance:c,spikeDistance:u,hovertemplate:f.ht}),f.htx?t.text=f.htx:f.tx?t.text=f.tx:o.text&&(t.text=o.text),i.fillText(f,o,t),n.getComponentMethod(\"errorbars\",\"hoverInfo\")(f,o,t),t}e.exports={hoverPoints:function(t,e,r,n){var i,a,s,l,c,u,h,f,p,d=t.cd,g=d[0].t,v=d[0].trace,m=t.xa,y=t.ya,x=g.x,b=g.y,_=m.c2p(e),w=y.c2p(r),k=t.distance;if(g.tree){var T=m.p2c(_-k),A=m.p2c(_+k),M=y.p2c(w-k),S=y.p2c(w+k);i=\"x\"===n?g.tree.range(Math.min(T,A),Math.min(y._rl[0],y._rl[1]),Math.max(T,A),Math.max(y._rl[0],y._rl[1])):g.tree.range(Math.min(T,A),Math.min(M,S),Math.max(T,A),Math.max(M,S))}else{if(!g.ids)return[t];i=g.ids}var E=k;if(\"x\"===n)for(c=0;c<i.length;c++)s=x[i[c]],(u=Math.abs(m.c2p(s)-_))<E&&(E=u,h=y.c2p(b[i[c]])-w,p=Math.sqrt(u*u+h*h),a=i[c]);else for(c=i.length-1;c>-1;c--)s=x[i[c]],l=b[i[c]],u=m.c2p(s)-_,h=y.c2p(l)-w,(f=Math.sqrt(u*u+h*h))<E&&(E=p=f,a=i[c]);return t.index=a,t.distance=E,t.dxy=p,void 0===a?[t]:(o(t,x,b,v),[t])},calcHover:o}},{\"../../lib\":719,\"../../registry\":847,\"../scatter/get_trace_color\":1121}],1167:[function(t,e,r){\"use strict\";var n=t(\"./hover\");e.exports={moduleType:\"trace\",name:\"scattergl\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../scatter/cross_trace_defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:n.hoverPoints,selectPoints:t(\"./select\"),meta:{}}},{\"../../plots/cartesian\":778,\"../scatter/cross_trace_defaults\":1118,\"../scatter/marker_colorbar\":1129,\"./attributes\":1160,\"./calc\":1161,\"./defaults\":1164,\"./hover\":1166,\"./plot\":1168,\"./select\":1170}],1168:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"regl-line2d\"),a=t(\"regl-error2d\"),o=t(\"gl-text\"),s=t(\"../../lib\"),l=t(\"../../lib/prepare_regl\"),c=t(\"../scatter/subtypes\"),u=t(\"../scatter/link_traces\"),h=t(\"./edit_style\").styleTextSelection;e.exports=function(t,e,r){if(r.length){var f,p,d=t._fullLayout,g=e._scene,v=e.xaxis,m=e.yaxis;if(g)if(l(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])){var y=g.count,x=d._glcanvas.data()[0].regl;if(u(t,e,r),g.dirty){if(!0===g.error2d&&(g.error2d=a(x)),!0===g.line2d&&(g.line2d=i(x)),!0===g.scatter2d&&(g.scatter2d=n(x)),!0===g.fill2d&&(g.fill2d=i(x)),!0===g.glText)for(g.glText=new Array(y),f=0;f<y;f++)g.glText[f]=new o(x);if(g.glText){if(y>g.glText.length){var b=y-g.glText.length;for(f=0;f<b;f++)g.glText.push(new o(x))}else if(y<g.glText.length){var _=g.glText.length-y;g.glText.splice(y,_).forEach(function(t){t.destroy()})}for(f=0;f<y;f++)g.glText[f].update(g.textOptions[f])}if(g.line2d&&(g.line2d.update(g.lineOptions),g.lineOptions=g.lineOptions.map(function(t){if(t&&t.positions){for(var e=t.positions,r=0;r<e.length&&(isNaN(e[r])||isNaN(e[r+1]));)r+=2;for(var n=e.length-2;n>r&&(isNaN(e[n])||isNaN(e[n+1]));)n-=2;t.positions=e.slice(r,n+2)}return t}),g.line2d.update(g.lineOptions)),g.error2d){var w=(g.errorXOptions||[]).concat(g.errorYOptions||[]);g.error2d.update(w)}g.scatter2d&&g.scatter2d.update(g.markerOptions),g.fillOrder=s.repeat(null,y),g.fill2d&&(g.fillOptions=g.fillOptions.map(function(t,e){var n=r[e];if(t&&n&&n[0]&&n[0].trace){var i,a,o=n[0],s=o.trace,l=o.t,c=g.lineOptions[e],u=[];s._ownfill&&u.push(e),s._nexttrace&&u.push(e+1),u.length&&(g.fillOrder[e]=u);var h,f,p=[],d=c&&c.positions||l.positions;if(\"tozeroy\"===s.fill){for(h=0;h<d.length&&isNaN(d[h+1]);)h+=2;for(f=d.length-2;f>h&&isNaN(d[f+1]);)f-=2;0!==d[h+1]&&(p=[d[h],0]),p=p.concat(d.slice(h,f+2)),0!==d[f+1]&&(p=p.concat([d[f],0]))}else if(\"tozerox\"===s.fill){for(h=0;h<d.length&&isNaN(d[h]);)h+=2;for(f=d.length-2;f>h&&isNaN(d[f]);)f-=2;0!==d[h]&&(p=[0,d[h+1]]),p=p.concat(d.slice(h,f+2)),0!==d[f]&&(p=p.concat([0,d[f+1]]))}else if(\"toself\"===s.fill||\"tonext\"===s.fill){for(p=[],i=0,a=0;a<d.length;a+=2)(isNaN(d[a])||isNaN(d[a+1]))&&((p=p.concat(d.slice(i,a))).push(d[i],d[i+1]),i=a+2);p=p.concat(d.slice(i)),i&&p.push(d[i],d[i+1])}else{var v=s._nexttrace;if(v){var m=g.lineOptions[e+1];if(m){var y=m.positions;if(\"tonexty\"===s.fill){for(p=d.slice(),e=Math.floor(y.length/2);e--;){var x=y[2*e],b=y[2*e+1];isNaN(x)||isNaN(b)||p.push(x,b)}t.fill=v.fillcolor}}}}if(s._prevtrace&&\"tonext\"===s._prevtrace.fill){var _=g.lineOptions[e-1].positions,w=p.length/2,k=[i=w];for(a=0;a<_.length;a+=2)(isNaN(_[a])||isNaN(_[a+1]))&&(k.push(a/2+w+1),i=a+2);p=p.concat(_),t.hole=k}return t.fillmode=s.fill,t.opacity=s.opacity,t.positions=p,t}}),g.fill2d.update(g.fillOptions))}var k=d.dragmode,T=\"lasso\"===k||\"select\"===k,A=d.clickmode.indexOf(\"select\")>-1;for(f=0;f<y;f++){var M=r[f][0],S=M.trace,E=M.t,C=E.index,L=S._length,P=E.x,O=E.y;if(S.selectedpoints||T||A){if(T||(T=!0),S.selectedpoints){var z=g.selectBatch[C]=s.selIndices2selPoints(S),I={};for(p=0;p<z.length;p++)I[z[p]]=1;var D=[];for(p=0;p<L;p++)I[p]||D.push(p);g.unselectBatch[C]=D}var R=E.xpx=new Array(L),F=E.ypx=new Array(L);for(p=0;p<L;p++)R[p]=v.c2p(P[p]),F[p]=m.c2p(O[p])}else E.xpx=E.ypx=null}if(T){if(g.select2d||(g.select2d=n(d._glcanvas.data()[1].regl)),g.scatter2d){var B=new Array(y);for(f=0;f<y;f++)B[f]=g.selectBatch[f].length||g.unselectBatch[f].length?g.markerUnselectedOptions[f]:{};g.scatter2d.update(B)}g.select2d&&(g.select2d.update(g.markerOptions),g.select2d.update(g.markerSelectedOptions)),g.glText&&r.forEach(function(t){var e=((t||[])[0]||{}).trace||{};c.hasText(e)&&h(t)})}else g.scatter2d&&g.scatter2d.update(g.markerOptions);var N={viewport:function(t,e,r){var n=t._size,i=t.width,a=t.height;return[n.l+e.domain[0]*n.w,n.b+r.domain[0]*n.h,i-n.r-(1-e.domain[1])*n.w,a-n.t-(1-r.domain[1])*n.h]}(d,v,m),range:[(v._rl||v.range)[0],(m._rl||m.range)[0],(v._rl||v.range)[1],(m._rl||m.range)[1]]},j=s.repeat(N,g.count);g.fill2d&&g.fill2d.update(j),g.line2d&&g.line2d.update(j),g.error2d&&g.error2d.update(j.concat(j)),g.scatter2d&&g.scatter2d.update(j),g.select2d&&g.select2d.update(j),g.glText&&g.glText.forEach(function(t){t.update(N)})}else g.init()}}},{\"../../lib\":719,\"../../lib/prepare_regl\":732,\"../scatter/link_traces\":1127,\"../scatter/subtypes\":1135,\"./edit_style\":1165,\"gl-text\":317,\"regl-error2d\":490,\"regl-line2d\":491,\"regl-scatter2d\":497}],1169:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=e._scene,i={count:0,dirty:!0,lineOptions:[],fillOptions:[],markerOptions:[],markerSelectedOptions:[],markerUnselectedOptions:[],errorXOptions:[],errorYOptions:[],textOptions:[],textSelectedOptions:[],textUnselectedOptions:[],selectBatch:[],unselectBatch:[]},a={fill2d:!1,scatter2d:!1,error2d:!1,line2d:!1,glText:!1,select2d:!1};return e._scene||((r=e._scene={}).init=function(){n.extendFlat(r,a,i)},r.init(),r.update=function(t){var e=n.repeat(t,r.count);if(r.fill2d&&r.fill2d.update(e),r.scatter2d&&r.scatter2d.update(e),r.line2d&&r.line2d.update(e),r.error2d&&r.error2d.update(e.concat(e)),r.select2d&&r.select2d.update(e),r.glText)for(var i=0;i<r.count;i++)r.glText[i].update(t)},r.draw=function(){for(var t=r.count,e=r.fill2d,i=r.error2d,a=r.line2d,o=r.scatter2d,s=r.glText,l=r.select2d,c=r.selectBatch,u=r.unselectBatch,h=0;h<t;h++){if(e&&r.fillOrder[h]&&e.draw(r.fillOrder[h]),a&&r.lineOptions[h]&&a.draw(h),i&&(r.errorXOptions[h]&&i.draw(h),r.errorYOptions[h]&&i.draw(h+t)),o&&r.markerOptions[h])if(u[h].length){var f=n.repeat([],r.count);f[h]=u[h],o.draw(f)}else c[h].length||o.draw(h);s[h]&&r.textOptions[h]&&s[h].render()}l&&l.draw(c),r.dirty=!1},r.destroy=function(){r.fill2d&&r.fill2d.destroy&&r.fill2d.destroy(),r.scatter2d&&r.scatter2d.destroy&&r.scatter2d.destroy(),r.error2d&&r.error2d.destroy&&r.error2d.destroy(),r.line2d&&r.line2d.destroy&&r.line2d.destroy(),r.select2d&&r.select2d.destroy&&r.select2d.destroy(),r.glText&&r.glText.forEach(function(t){t.destroy&&t.destroy()}),r.lineOptions=null,r.fillOptions=null,r.markerOptions=null,r.markerSelectedOptions=null,r.markerUnselectedOptions=null,r.errorXOptions=null,r.errorYOptions=null,r.textOptions=null,r.textSelectedOptions=null,r.textUnselectedOptions=null,r.selectBatch=null,r.unselectBatch=null,e._scene=null}),r.dirty||n.extendFlat(r,i),r}},{\"../../lib\":719}],1170:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"./edit_style\").styleTextSelection;e.exports=function(t,e){var r=t.cd,a=[],o=r[0].trace,s=r[0].t,l=o._length,c=s.x,u=s.y,h=s._scene,f=s.index;if(!h)return a;var p=n.hasText(o),d=n.hasMarkers(o),g=!d&&!p;if(!0!==o.visible||g)return a;var v=[],m=[];if(!1!==e&&!e.degenerate)for(var y=0;y<l;y++)e.contains([s.xpx[y],s.ypx[y]],!1,y,t)?(v.push(y),a.push({pointNumber:y,x:c[y],y:u[y]})):m.push(y);if(d){var x=h.scatter2d;if(v.length||m.length){if(!h.selectBatch[f].length&&!h.unselectBatch[f].length){var b=new Array(h.count);b[f]=h.markerUnselectedOptions[f],x.update.apply(x,b)}}else{var _=new Array(h.count);_[f]=h.markerOptions[f],x.update.apply(x,_)}}return h.selectBatch[f]=v,h.unselectBatch[f]=m,p&&i(r),a}},{\"../scatter/subtypes\":1135,\"./edit_style\":1165}],1171:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scattergeo/attributes\"),a=t(\"../scatter/attributes\"),o=t(\"../../plots/mapbox/layout_attributes\"),s=t(\"../../plots/attributes\"),l=t(\"../../components/colorscale/attributes\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../plot_api/edit_types\").overrideAll,h=i.line,f=i.marker;e.exports=u({lon:i.lon,lat:i.lat,mode:c({},a.mode,{dflt:\"markers\"}),text:c({},a.text,{}),hovertext:c({},a.hovertext,{}),line:{color:h.color,width:h.width},connectgaps:a.connectgaps,marker:c({symbol:{valType:\"string\",dflt:\"circle\",arrayOk:!0},opacity:f.opacity,size:f.size,sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode},l(\"marker\")),fill:i.fill,fillcolor:a.fillcolor,textfont:o.layers.symbol.textfont,textposition:o.layers.symbol.textposition,below:{valType:\"string\"},selected:{marker:a.selected.marker},unselected:{marker:a.unselected.marker},hoverinfo:c({},s.hoverinfo,{flags:[\"lon\",\"lat\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../../plots/mapbox/layout_attributes\":824,\"../scatter/attributes\":1112,\"../scattergeo/attributes\":1151}],1172:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../lib/geojson_utils\"),s=t(\"../../components/colorscale\"),l=t(\"../../components/drawing\"),c=t(\"../scatter/make_bubble_size_func\"),u=t(\"../scatter/subtypes\"),h=t(\"../../plots/mapbox/convert_text_opts\");function f(){return{geojson:o.makeBlank(),layout:{visibility:\"none\"},paint:{}}}function p(t){return i.isArrayOrTypedArray(t)?function(t){return t}:t?function(){return t}:d}function d(){return\"\"}function g(t){return t[0]===a}e.exports=function(t){var e,r=t[0].trace,a=!0===r.visible&&0!==r._length,v=\"none\"!==r.fill,m=u.hasLines(r),y=u.hasMarkers(r),x=u.hasText(r),b=y&&\"circle\"===r.marker.symbol,_=y&&\"circle\"!==r.marker.symbol,w=f(),k=f(),T=f(),A=f(),M={fill:w,line:k,circle:T,symbol:A};if(!a)return M;if((v||m)&&(e=o.calcTraceToLineCoords(t)),v&&(w.geojson=o.makePolygon(e),w.layout.visibility=\"visible\",i.extendFlat(w.paint,{\"fill-color\":r.fillcolor})),m&&(k.geojson=o.makeLine(e),k.layout.visibility=\"visible\",i.extendFlat(k.paint,{\"line-width\":r.line.width,\"line-color\":r.line.color,\"line-opacity\":r.opacity})),b){var S=function(t){var e,r,a,o,u=t[0].trace,h=u.marker,f=u.selectedpoints,p=i.isArrayOrTypedArray(h.color),d=i.isArrayOrTypedArray(h.size),v=i.isArrayOrTypedArray(h.opacity);function m(t){return u.opacity*t}p&&(r=s.hasColorscale(u,\"marker\")?s.makeColorScaleFuncFromTrace(h):i.identity);d&&(a=c(u));v&&(o=function(t){var e=n(t)?+i.constrain(t,0,1):0;return m(e)});var y,x=[];for(e=0;e<t.length;e++){var b=t[e],_=b.lonlat;if(!g(_)){var w={};r&&(w.mcc=b.mcc=r(b.mc)),a&&(w.mrc=b.mrc=a(b.ms)),o&&(w.mo=o(b.mo)),f&&(w.selected=b.selected||0),x.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:_},properties:w})}}if(f)for(y=l.makeSelectedPointStyleFns(u),e=0;e<x.length;e++){var k=x[e].properties;y.selectedOpacityFn&&(k.mo=m(y.selectedOpacityFn(k))),y.selectedColorFn&&(k.mcc=y.selectedColorFn(k)),y.selectedSizeFn&&(k.mrc=y.selectedSizeFn(k))}return{geojson:{type:\"FeatureCollection\",features:x},mcc:p||y&&y.selectedColorFn?{type:\"identity\",property:\"mcc\"}:h.color,mrc:d||y&&y.selectedSizeFn?{type:\"identity\",property:\"mrc\"}:(T=h.size,T/2),mo:v||y&&y.selectedOpacityFn?{type:\"identity\",property:\"mo\"}:m(h.opacity)};var T}(t);T.geojson=S.geojson,T.layout.visibility=\"visible\",i.extendFlat(T.paint,{\"circle-color\":S.mcc,\"circle-radius\":S.mrc,\"circle-opacity\":S.mo})}if((_||x)&&(A.geojson=function(t){for(var e=t[0].trace,r=(e.marker||{}).symbol,n=e.text,i=\"circle\"!==r?p(r):d,a=u.hasText(e)?p(n):d,o=[],s=0;s<t.length;s++){var l=t[s];g(l.lonlat)||o.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:l.lonlat},properties:{symbol:i(l.mx),text:a(l.tx)}})}return{type:\"FeatureCollection\",features:o}}(t),i.extendFlat(A.layout,{visibility:\"visible\",\"icon-image\":\"{symbol}-15\",\"text-field\":\"{text}\"}),_&&(i.extendFlat(A.layout,{\"icon-size\":r.marker.size/10}),i.extendFlat(A.paint,{\"icon-opacity\":r.opacity*r.marker.opacity,\"icon-color\":r.marker.color})),x)){var E=(r.marker||{}).size,C=h(r.textposition,E);i.extendFlat(A.layout,{\"text-size\":r.textfont.size,\"text-anchor\":C.anchor,\"text-offset\":C.offset}),i.extendFlat(A.paint,{\"text-color\":r.textfont.color,\"text-opacity\":r.opacity})}return M}},{\"../../components/colorscale\":605,\"../../components/drawing\":614,\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/geojson_utils\":714,\"../../plots/mapbox/convert_text_opts\":821,\"../scatter/make_bubble_size_func\":1128,\"../scatter/subtypes\":1135,\"fast-isnumeric\":225}],1173:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,i){return n.coerce(t,e,c,r,i)}if(function(t,e,r){var n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length);return e._length=a,a}(0,e,h)){if(h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),h(\"below\"),i.hasLines(e)&&(o(t,e,r,u,h,{noDash:!0}),h(\"connectgaps\")),i.hasMarkers(e)){a(t,e,r,u,h,{noLine:!0});var f=e.marker;\"circle\"!==f.symbol&&(n.isArrayOrTypedArray(f.size)&&(f.size=f.size[0]),n.isArrayOrTypedArray(f.color)&&(f.color=f.color[0]))}i.hasText(e)&&s(t,e,u,h,{noSelect:!0}),h(\"fill\"),\"none\"!==e.fill&&l(t,e,r,h),n.coerceSelectionMarkerOpacity(e,h)}else e.visible=!1}},{\"../../lib\":719,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1171}],1174:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t}},{}],1175:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\"),o=i.fillText,s=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,h=t.ya,f=t.subplot,p=360*(e>=0?Math.floor((e+180)/360):Math.ceil((e-180)/360)),d=e-p;if(n.getClosest(l,function(t){var e=t.lonlat;if(e[0]===s)return 1/0;var n=i.modHalf(e[0],360),a=e[1],o=f.project([n,a]),l=o.x-u.c2p([d,a]),c=o.y-h.c2p([n,r]),p=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(l*l+c*c)-p,1-3/p)},t),!1!==t.index){var g=l[t.index],v=g.lonlat,m=[i.modHalf(v[0],360)+p,v[1]],y=u.c2p(m),x=h.c2p(m),b=g.mrc||1;return t.x0=y-b,t.x1=y+b,t.y0=x-b,t.y1=x+b,t.color=a(c,g),t.extraText=function(t,e,r){if(t.hovertemplate)return;var n=(e.hi||t.hoverinfo).split(\"+\"),i=-1!==n.indexOf(\"all\"),a=-1!==n.indexOf(\"lon\"),s=-1!==n.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}i||a&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):a?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(i||-1!==n.indexOf(\"text\"))&&o(e,t,c);return c.join(\"<br>\")}(c,g,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},{\"../../components/fx\":632,\"../../constants/numerical\":695,\"../../lib\":719,\"../scatter/get_trace_color\":1121}],1176:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"../scattergeo/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.update(e)},moduleType:\"trace\",name:\"scattermapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"symbols\",\"showLegend\",\"scatterlike\"],meta:{}}},{\"../../plots/mapbox\":822,\"../scatter/marker_colorbar\":1129,\"../scattergeo/calc\":1152,\"./attributes\":1171,\"./defaults\":1173,\"./event_data\":1174,\"./hover\":1175,\"./plot\":1177,\"./select\":1178}],1177:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix,a=[\"fill\",\"line\",\"circle\",\"symbol\"];function o(t,e){this.subplot=t,this.uid=e,this.sourceIds={fill:\"source-\"+e+\"-fill\",line:\"source-\"+e+\"-line\",circle:\"source-\"+e+\"-circle\",symbol:\"source-\"+e+\"-symbol\"},this.layerIds={fill:i+e+\"-fill\",line:i+e+\"-line\",circle:i+e+\"-circle\",symbol:i+e+\"-symbol\"},this.below=null}var s=o.prototype;s.addSource=function(t,e){this.subplot.map.addSource(this.sourceIds[t],{type:\"geojson\",data:e.geojson})},s.setSourceData=function(t,e){this.subplot.map.getSource(this.sourceIds[t]).setData(e.geojson)},s.addLayer=function(t,e,r){this.subplot.addLayer({type:t,id:this.layerIds[t],source:this.sourceIds[t],layout:e.layout,paint:e.paint},r)},s.update=function(t){var e,r,i,o=this.subplot,s=o.map,l=n(t),c=o.belowLookup[\"trace-\"+this.uid];if(c!==this.below){for(e=a.length-1;e>=0;e--)r=a[e],s.removeLayer(this.layerIds[r]);for(e=0;e<a.length;e++)i=l[r=a[e]],this.addLayer(r,i,c);this.below=c}for(e=0;e<a.length;e++)i=l[r=a[e]],o.setOptions(this.layerIds[r],\"setLayoutProperty\",i.layout),\"visible\"===i.layout.visibility&&(this.setSourceData(r,i),o.setOptions(this.layerIds[r],\"setPaintProperty\",i.paint));t[0].trace._glTrace=this},s.dispose=function(){for(var t=this.subplot.map,e=a.length-1;e>=0;e--){var r=a[e];t.removeLayer(this.layerIds[r]),t.removeSource(this.sourceIds[r])}},e.exports=function(t,e){for(var r=e[0].trace,i=new o(t,r.uid),s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid],c=0;c<a.length;c++){var u=a[c],h=s[u];i.addSource(u,h),i.addLayer(u,h,l)}return e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":820,\"./convert\":1172}],1178:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,o=t.cd,s=t.xaxis,l=t.yaxis,c=[],u=o[0].trace;if(!i.hasMarkers(u))return[];if(!1===e)for(r=0;r<o.length;r++)o[r].selected=0;else for(r=0;r<o.length;r++){var h=o[r],f=h.lonlat;if(f[0]!==a){var p=[n.modHalf(f[0],360),f[1]],d=[s.c2p(p),l.c2p(p)];e.contains(d,null,r,t)?(c.push({pointNumber:r,lon:f[0],lat:f[1]}),h.selected=1):h.selected=0}}return c}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../scatter/subtypes\":1135}],1179:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../scatter/attributes\"),o=t(\"../../plots/attributes\"),s=a.line;e.exports={mode:a.mode,r:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},theta:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},r0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dr:{valType:\"number\",dflt:1,editType:\"calc\"},theta0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dtheta:{valType:\"number\",editType:\"calc\"},thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\",\"gradians\"],dflt:\"degrees\",editType:\"calc+clearAxisTypes\"},text:a.text,hovertext:a.hovertext,line:{color:s.color,width:s.width,dash:s.dash,shape:i({},s.shape,{values:[\"linear\",\"spline\"]}),smoothing:s.smoothing,editType:\"calc\"},connectgaps:a.connectgaps,marker:a.marker,cliponaxis:i({},a.cliponaxis,{dflt:!1}),textposition:a.textposition,textfont:a.textfont,fill:i({},a.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:a.fillcolor,hoverinfo:i({},o.hoverinfo,{flags:[\"r\",\"theta\",\"text\",\"name\"]}),hoveron:a.hoveron,hovertemplate:n(),selected:a.selected,unselected:a.unselected}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1180:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../plots/cartesian/axes\"),o=t(\"../scatter/colorscale_calc\"),s=t(\"../scatter/arrays_to_calcdata\"),l=t(\"../scatter/calc_selection\"),c=t(\"../scatter/calc\").calcMarkerSize;e.exports=function(t,e){for(var r=t._fullLayout,u=e.subplot,h=r[u].radialaxis,f=r[u].angularaxis,p=h.makeCalcdata(e,\"r\"),d=f.makeCalcdata(e,\"theta\"),g=e._length,v=new Array(g),m=0;m<g;m++){var y=p[m],x=d[m],b=v[m]={};n(y)&&n(x)?(b.r=y,b.theta=x):b.r=i}var _=c(e,g);return e._extremes.x=a.findExtremes(h,p,{ppad:_}),o(t,e),s(v,e),l(v,e),v}},{\"../../constants/numerical\":695,\"../../plots/cartesian/axes\":767,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc\":1113,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1181:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/line_shape_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,h=t(\"./attributes\");function f(t,e,r,n){var i,a=n(\"r\"),o=n(\"theta\");if(a)o?i=Math.min(a.length,o.length):(i=a.length,n(\"theta0\"),n(\"dtheta\"));else{if(!o)return 0;i=e.theta.length,n(\"r0\"),n(\"dr\")}return e._length=i,i}e.exports={handleRThetaDefaults:f,supplyDefaults:function(t,e,r,p){function d(r,i){return n.coerce(t,e,h,r,i)}var g=f(0,e,0,d);if(g){d(\"thetaunit\"),d(\"mode\",g<u?\"lines+markers\":\"lines\"),d(\"text\"),d(\"hovertext\"),\"fills\"!==e.hoveron&&d(\"hovertemplate\"),i.hasLines(e)&&(o(t,e,r,p,d),s(t,e,d),d(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,p,d,{gradient:!0}),i.hasText(e)&&l(t,e,p,d);var v=[];(i.hasMarkers(e)||i.hasText(e))&&(d(\"cliponaxis\"),d(\"marker.maxdisplayed\"),v.push(\"points\")),d(\"fill\"),\"none\"!==e.fill&&(c(t,e,r,d),i.hasLines(e)||s(t,e,d)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||v.push(\"fills\"),d(\"hoveron\",v.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/line_shape_defaults\":1126,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1179}],1182:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\");function o(t,e,r,n){var o=r.radialAxis,s=r.angularAxis;o._hovertitle=\"r\",s._hovertitle=\"\\u03b8\";var l=o.c2l(t.r);n.rLabel=i.tickText(o,l,\"hover\").text;var c=\"degrees\"===s.thetaunit?a.rad2deg(t.theta):t.theta;n.thetaLabel=i.tickText(s,c,\"hover\").text;var u=t.hi||e.hoverinfo,h=[];function f(t,e){h.push(t._hovertitle+\": \"+e)}if(!e.hovertemplate){var p=u.split(\"+\");-1!==p.indexOf(\"all\")&&(p=[\"r\",\"theta\",\"text\"]),-1!==p.indexOf(\"r\")&&f(o,n.rLabel),-1!==p.indexOf(\"theta\")&&f(s,n.thetaLabel),-1!==p.indexOf(\"text\")&&n.text&&(h.push(n.text),delete n.text),n.extraText=h.join(\"<br>\")}}e.exports={hoverPoints:function(t,e,r,i){var a=n(t,e,r,i);if(a&&!1!==a[0].index){var s=a[0];if(void 0===s.index)return a;var l=t.subplot,c=s.cd[s.index],u=s.trace;if(l.isPtInside(c))return s.xLabelVal=void 0,s.yLabelVal=void 0,o(c,u,l,s),s.hovertemplate=u.hovertemplate,a}},makeHoverPointText:o}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scatter/hover\":1122}],1183:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scatter/select\"),meta:{}}},{\"../../plots/polar\":831,\"../scatter/marker_colorbar\":1129,\"../scatter/select\":1132,\"../scatter/style\":1134,\"./attributes\":1179,\"./calc\":1180,\"./defaults\":1181,\"./hover\":1182,\"./plot\":1184}],1184:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){for(var a=e.layers.frontplot.select(\"g.scatterlayer\"),o={xaxis:e.xaxis,yaxis:e.yaxis,plot:e.framework,layerClipId:e._hasClipOnAxisFalse?e.clipIds.forTraces:null},s=e.radialAxis,l=e.angularAxis,c=0;c<r.length;c++)for(var u=r[c],h=0;h<u.length;h++){var f=u[h],p=f.r;if(p===i)f.x=f.y=i;else{var d=s.c2g(p),g=l.c2g(f.theta);f.x=d*Math.cos(g),f.y=d*Math.sin(g)}}n(t,o,r,a)}},{\"../../constants/numerical\":695,\"../scatter/plot\":1131}],1185:[function(t,e,r){\"use strict\";var n=t(\"../scatterpolar/attributes\"),i=t(\"../scattergl/attributes\");e.exports={mode:n.mode,r:n.r,theta:n.theta,r0:n.r0,dr:n.dr,theta0:n.theta0,dtheta:n.dtheta,thetaunit:n.thetaunit,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,line:i.line,connectgaps:i.connectgaps,marker:i.marker,fill:i.fill,fillcolor:i.fillcolor,textposition:i.textposition,textfont:i.textfont,hoverinfo:n.hoverinfo,selected:n.selected,unselected:n.unselected}},{\"../scattergl/attributes\":1160,\"../scatterpolar/attributes\":1179}],1186:[function(t,e,r){\"use strict\";var n=t(\"../scatter/colorscale_calc\"),i=t(\"../scatter/calc\").calcMarkerSize,a=t(\"../scattergl/convert\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r=t._fullLayout,l=e.subplot,c=r[l].radialaxis,u=r[l].angularaxis,h=c.makeCalcdata(e,\"r\"),f=u.makeCalcdata(e,\"theta\"),p=e._length,d={};p<h.length&&(h=h.slice(0,p)),p<f.length&&(f=f.slice(0,p)),d.r=h,d.theta=f,n(t,e);var g,v=d.opts=a.style(t,e);return p<s?g=i(e,p):v.marker&&(g=2*(v.marker.sizeAvg||Math.max(v.marker.size,3))),e._extremes.x=o.findExtremes(c,h,{ppad:g}),[{x:!1,y:!1,t:d,trace:e}]}},{\"../../plots/cartesian/axes\":767,\"../scatter/calc\":1113,\"../scatter/colorscale_calc\":1115,\"../scattergl/constants\":1162,\"../scattergl/convert\":1163}],1187:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatterpolar/defaults\").handleRThetaDefaults,o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}var d=a(t,e,f,p);d?(p(\"thetaunit\"),p(\"mode\",d<u?\"lines+markers\":\"lines\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),i.hasLines(e)&&(s(t,e,r,f,p),p(\"connectgaps\")),i.hasMarkers(e)&&o(t,e,r,f,p),i.hasText(e)&&l(t,e,f,p),p(\"fill\"),\"none\"!==e.fill&&c(t,e,r,p),n.coerceSelectionMarkerOpacity(e,p)):e.visible=!1}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"../scatterpolar/defaults\":1181,\"./attributes\":1185}],1188:[function(t,e,r){\"use strict\";var n=t(\"../scattergl/hover\"),i=t(\"../scatterpolar/hover\").makeHoverPointText;e.exports={hoverPoints:function(t,e,r,a){var o=t.cd[0].t,s=o.r,l=o.theta,c=n.hoverPoints(t,e,r,a);if(c&&!1!==c[0].index){var u=c[0];if(void 0===u.index)return c;var h=t.subplot,f=u.cd[u.index],p=u.trace;if(f.r=s[u.index],f.theta=l[u.index],h.isPtInside(f))return u.xLabelVal=void 0,u.yLabelVal=void 0,i(f,p,h,u),c}}}},{\"../scattergl/hover\":1166,\"../scatterpolar/hover\":1182}],1189:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolargl\",basePlotModule:t(\"../../plots/polar\"),categories:[\"gl\",\"regl\",\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scattergl/select\"),meta:{}}},{\"../../plots/polar\":831,\"../scatter/marker_colorbar\":1129,\"../scattergl/select\":1170,\"./attributes\":1185,\"./calc\":1186,\"./defaults\":1187,\"./hover\":1188,\"./plot\":1190}],1190:[function(t,e,r){\"use strict\";var n=t(\"point-cluster\"),i=t(\"fast-isnumeric\"),a=t(\"../scattergl/plot\"),o=t(\"../scattergl/scene_update\"),s=t(\"../scattergl/convert\"),l=t(\"../../lib\"),c=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e,r){if(r.length){var u=e.radialAxis,h=e.angularAxis,f=o(t,e);return r.forEach(function(r){if(r&&r[0]&&r[0].trace){var a,o=r[0],p=o.trace,d=o.t,g=p._length,v=d.r,m=d.theta,y=d.opts,x=v.slice(),b=m.slice();for(a=0;a<v.length;a++)e.isPtInside({r:v[a],theta:m[a]})||(x[a]=NaN,b[a]=NaN);var _=new Array(2*g),w=Array(g),k=Array(g);for(a=0;a<g;a++){var T,A,M=x[a];if(i(M)){var S=u.c2g(M),E=h.c2g(b[a],p.thetaunit);T=S*Math.cos(E),A=S*Math.sin(E)}else T=A=NaN;w[a]=_[2*a]=T,k[a]=_[2*a+1]=A}d.tree=n(_),y.marker&&g>=c&&(y.marker.cluster=d.tree),y.marker&&(y.markerSel.positions=y.markerUnsel.positions=y.marker.positions=_),y.line&&_.length>1&&l.extendFlat(y.line,s.linePositions(t,p,_)),y.text&&(l.extendFlat(y.text,{positions:_},s.textPosition(t,p,y.text,y.marker)),l.extendFlat(y.textSel,{positions:_},s.textPosition(t,p,y.text,y.markerSel)),l.extendFlat(y.textUnsel,{positions:_},s.textPosition(t,p,y.text,y.markerUnsel))),y.fill&&!f.fill2d&&(f.fill2d=!0),y.marker&&!f.scatter2d&&(f.scatter2d=!0),y.line&&!f.line2d&&(f.line2d=!0),y.text&&!f.glText&&(f.glText=!0),f.lineOptions.push(y.line),f.fillOptions.push(y.fill),f.markerOptions.push(y.marker),f.markerSelectedOptions.push(y.markerSel),f.markerUnselectedOptions.push(y.markerUnsel),f.textOptions.push(y.text),f.textSelectedOptions.push(y.textSel),f.textUnselectedOptions.push(y.textUnsel),f.selectBatch.push([]),f.unselectBatch.push([]),d.x=w,d.y=k,d.rawx=w,d.rawy=k,d.r=v,d.theta=m,d.positions=_,d._scene=f,d.index=f.count,f.count++}}),a(t,e,r)}}},{\"../../lib\":719,\"../scattergl/constants\":1162,\"../scattergl/convert\":1163,\"../scattergl/plot\":1168,\"../scattergl/scene_update\":1169,\"fast-isnumeric\":225,\"point-cluster\":469}],1191:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/drawing/attributes\").dash,l=t(\"../../lib/extend\").extendFlat,c=i.marker,u=i.line,h=c.line;e.exports={a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},c:{valType:\"data_array\",editType:\"calc\"},sum:{valType:\"number\",dflt:0,min:0,editType:\"calc\"},mode:l({},i.mode,{dflt:\"markers\"}),text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),line:{color:u.color,width:u.width,dash:s,shape:l({},u.shape,{values:[\"linear\",\"spline\"]}),smoothing:u.smoothing,editType:\"calc\"},connectgaps:i.connectgaps,cliponaxis:i.cliponaxis,fill:l({},i.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:i.fillcolor,marker:l({symbol:c.symbol,opacity:c.opacity,maxdisplayed:c.maxdisplayed,size:c.size,sizeref:c.sizeref,sizemin:c.sizemin,sizemode:c.sizemode,line:l({width:h.width,editType:\"calc\"},o(\"marker.line\")),gradient:c.gradient,editType:\"calc\"},o(\"marker\")),textfont:i.textfont,textposition:i.textposition,selected:i.selected,unselected:i.unselected,hoverinfo:l({},a.hoverinfo,{flags:[\"a\",\"b\",\"c\",\"text\",\"name\"]}),hoveron:i.hoveron,hovertemplate:n()}},{\"../../components/colorscale/attributes\":600,\"../../components/drawing/attributes\":613,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1192:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=[\"a\",\"b\",\"c\"],c={a:[\"b\",\"c\"],b:[\"a\",\"c\"],c:[\"a\",\"b\"]};e.exports=function(t,e){var r,u,h,f,p,d,g=t._fullLayout[e.subplot].sum,v=e.sum||g,m={a:e.a,b:e.b,c:e.c};for(r=0;r<l.length;r++)if(!m[h=l[r]]){for(p=m[c[h][0]],d=m[c[h][1]],f=new Array(p.length),u=0;u<p.length;u++)f[u]=v-p[u]-d[u];m[h]=f}var y,x,b,_,w,k,T=e._length,A=new Array(T);for(r=0;r<T;r++)y=m.a[r],x=m.b[r],b=m.c[r],n(y)&&n(x)&&n(b)?(1!==(_=g/((y=+y)+(x=+x)+(b=+b)))&&(y*=_,x*=_,b*=_),k=y,w=b-x,A[r]={x:w,y:k,a:y,b:x,c:b}):A[r]={x:!1,y:!1};return s(e,T),i(t,e),a(A,e),o(A,e),A}},{\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc\":1113,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1193:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}var d,g=p(\"a\"),v=p(\"b\"),m=p(\"c\");if(g?(d=g.length,v?(d=Math.min(d,v.length),m&&(d=Math.min(d,m.length))):d=m?Math.min(d,m.length):0):v&&m&&(d=Math.min(v.length,m.length)),d){e._length=d,p(\"sum\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),p(\"mode\",d<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,f,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,f,p,{gradient:!0}),a.hasText(e)&&c(t,e,f,p);var y=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"cliponaxis\"),p(\"marker.maxdisplayed\"),y.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||y.push(\"fills\"),p(\"hoveron\",y.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/line_shape_defaults\":1126,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1191}],1194:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),n[i]){var a=n[i];t.a=a.a,t.b=a.b,t.c=a.c}else t.a=e.a,t.b=e.b,t.c=e.c;return t}},{}],1195:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,h=c-u;return s.x0=Math.max(Math.min(s.x0,h),u),s.x1=Math.max(Math.min(s.x1,h),u),o}var f=s.cd[s.index];s.a=f.a,s.b=f.b,s.c=f.c,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.subplot;s.aLabel=i.tickText(p.aaxis,f.a,\"hover\").text,s.bLabel=i.tickText(p.baxis,f.b,\"hover\").text,s.cLabel=i.tickText(p.caxis,f.c,\"hover\").text;var d=s.trace,g=f.hi||d.hoverinfo,v=[];if(!d.hovertemplate){var m=g.split(\"+\");-1!==m.indexOf(\"all\")&&(m=[\"a\",\"b\",\"c\"]),-1!==m.indexOf(\"a\")&&y(p.aaxis,s.aLabel),-1!==m.indexOf(\"b\")&&y(p.baxis,s.bLabel),-1!==m.indexOf(\"c\")&&y(p.caxis,s.cLabel)}return s.extraText=v.join(\"<br>\"),s.hovertemplate=d.hovertemplate,o}function y(t,e){v.push(t._hovertitle+\": \"+e)}}},{\"../../plots/cartesian/axes\":767,\"../scatter/hover\":1122}],1196:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scatterternary\",basePlotModule:t(\"../../plots/ternary\"),categories:[\"ternary\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/ternary\":843,\"../scatter/marker_colorbar\":1129,\"../scatter/select\":1132,\"../scatter/style\":1134,\"./attributes\":1191,\"./calc\":1192,\"./defaults\":1193,\"./event_data\":1194,\"./hover\":1195,\"./plot\":1197}],1197:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\");e.exports=function(t,e,r){var i=e.plotContainer;i.select(\".scatterlayer\").selectAll(\"*\").remove();var a={xaxis:e.xaxis,yaxis:e.yaxis,plot:i,layerClipId:e._hasClipOnAxisFalse?e.clipIdRelative:null},o=e.layers.frontplot.select(\"g.scatterlayer\");n(t,a,r,o)}},{\"../scatter/plot\":1131}],1198:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../scattergl/attributes\"),s=t(\"../../plots/cartesian/constants\").idRegex,l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"../../lib/extend\").extendFlat,u=n.marker,h=u.line,f=c(i(\"marker.line\",{editTypeOverride:\"calc\"}),{width:c({},h.width,{editType:\"calc\"}),editType:\"calc\"}),p=c(i(\"marker\"),{symbol:u.symbol,size:c({},u.size,{editType:\"markerSize\"}),sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:f,editType:\"calc\"});function d(t){return{valType:\"info_array\",freeLength:!0,editType:\"calc\",items:{valType:\"subplotid\",regex:s[t],editType:\"plot\"}}}p.color.editType=p.cmin.editType=p.cmax.editType=\"style\",e.exports={dimensions:l(\"dimension\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},label:{valType:\"string\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},axis:{type:{valType:\"enumerated\",values:[\"linear\",\"log\",\"date\",\"category\"],editType:\"calc+clearAxisTypes\"},matches:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc+clearAxisTypes\"},editType:\"calc+clearAxisTypes\"}),text:c({},o.text,{}),hovertext:c({},o.hovertext,{}),hovertemplate:a(),marker:p,xaxes:d(\"x\"),yaxes:d(\"y\"),diagonal:{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},showupperhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},showlowerhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},selected:{marker:o.selected.marker,editType:\"calc\"},unselected:{marker:o.unselected.marker,editType:\"calc\"},opacity:o.opacity}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773,\"../scatter/attributes\":1112,\"../scattergl/attributes\":1160}],1199:[function(t,e,r){\"use strict\";var n=t(\"regl-line2d\"),i=t(\"../../registry\"),a=t(\"../../lib/prepare_regl\"),o=t(\"../../plots/get_data\").getModuleCalcData,s=t(\"../../plots/cartesian\"),l=t(\"../../plots/cartesian/axis_ids\").getFromId,c=t(\"../../plots/cartesian/axes\").shouldShowZeroLine,u=\"splom\";function h(t,e,r){for(var n=r.matrixOptions.data.length,i=e._visibleDims,a=r.viewOpts.ranges=new Array(n),o=0;o<i.length;o++){var s=i[o],c=a[o]=new Array(4),u=l(t,e._diag[s][0]);u&&(c[0]=u.r2l(u.range[0]),c[2]=u.r2l(u.range[1]));var h=l(t,e._diag[s][1]);h&&(c[1]=h.r2l(h.range[0]),c[3]=h.r2l(h.range[1]))}r.selectBatch.length||r.unselectBatch.length?r.matrix.update({ranges:a},{ranges:a}):r.matrix.update({ranges:a})}function f(t){var e=t._fullLayout,r=e._glcanvas.data()[0].regl,i=e._splomGrid;i||(i=e._splomGrid=n(r)),i.update(function(t){var e,r=t._fullLayout,n=r._size,i=[0,0,r.width,r.height],a={};function o(t,e,r,n,o,s){var l=e[t+\"color\"],c=e[t+\"width\"],u=String(l+c);u in a?a[u].data.push(NaN,NaN,r,n,o,s):a[u]={data:[r,n,o,s],join:\"rect\",thickness:c,color:l,viewport:i,range:i,overlay:!1}}for(e in r._splomSubplots){var s,l,u=r._plots[e],h=u.xaxis,f=u.yaxis,p=h._vals,d=f._vals,g=n.b+f.domain[0]*n.h,v=-f._m,m=-v*f.r2l(f.range[0],f.calendar);if(h.showgrid)for(e=0;e<p.length;e++)s=h._offset+h.l2p(p[e].x),o(\"grid\",h,s,g,s,g+f._length);if(f.showgrid)for(e=0;e<d.length;e++)l=g+m+v*d[e].x,o(\"grid\",f,h._offset,l,h._offset+h._length,l);c(t,h,f)&&(s=h._offset+h.l2p(0),o(\"zeroline\",h,s,g,s,g+f._length)),c(t,f,h)&&(l=g+m+0,o(\"zeroline\",f,h._offset,l,h._offset+h._length,l))}var y=[];for(e in a)y.push(a[e]);return y}(t))}e.exports={name:u,attr:s.attr,attrRegex:s.attrRegex,layoutAttributes:s.layoutAttributes,supplyLayoutDefaults:s.supplyLayoutDefaults,drawFramework:s.drawFramework,plot:function(t){var e=t._fullLayout,r=i.getModule(u),n=o(t.calcdata,r)[0];a(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])&&(e._hasOnlyLargeSploms&&f(t),r.plot(t,{},n))},drag:function(t){var e=t.calcdata,r=t._fullLayout;r._hasOnlyLargeSploms&&f(t);for(var n=0;n<e.length;n++){var i=e[n][0].trace,a=r._splomScenes[i.uid];\"splom\"===i.type&&a&&a.matrix&&h(t,i,a)}},updateGrid:f,clean:function(t,e,r,n){var i,a={};if(n._splomScenes){for(i=0;i<t.length;i++){var o=t[i];\"splom\"===o.type&&(a[o.uid]=1)}for(i=0;i<r.length;i++){var l=r[i];if(!a[l.uid]){var c=n._splomScenes[l.uid];c&&c.destroy&&c.destroy(),n._splomScenes[l.uid]=null,delete n._splomScenes[l.uid]}}}0===Object.keys(n._splomScenes||{}).length&&delete n._splomScenes,n._splomGrid&&!e._hasOnlyLargeSploms&&n._hasOnlyLargeSploms&&(n._splomGrid.destroy(),n._splomGrid=null,delete n._splomGrid),s.clean(t,e,r,n)},updateFx:s.updateFx,toSVG:s.toSVG}},{\"../../lib/prepare_regl\":732,\"../../plots/cartesian\":778,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_ids\":770,\"../../plots/get_data\":802,\"../../registry\":847,\"regl-line2d\":491}],1200:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../scatter/calc\").calcMarkerSize,o=t(\"../scatter/calc\").calcAxisExpansion,s=t(\"../scatter/colorscale_calc\"),l=t(\"../scattergl/convert\").markerSelection,c=t(\"../scattergl/convert\").markerStyle,u=t(\"./scene_update\"),h=t(\"../../constants/numerical\").BADNUM,f=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r,p,d,g,v,m,y=e.dimensions,x=e._length,b={},_=b.cdata=[],w=b.data=[],k=e._visibleDims=[];function T(t,r){for(var i=t.makeCalcdata({v:r.values,vcalendar:e.calendar},\"v\"),a=0;a<i.length;a++)i[a]=i[a]===h?NaN:i[a];_.push(i),w.push(\"log\"===t.type?n.simpleMap(i,t.c2l):i)}for(r=0;r<y.length;r++)if((d=y[r]).visible){if(g=i.getFromId(t,e._diag[r][0]),v=i.getFromId(t,e._diag[r][1]),g&&v&&g.type!==v.type){n.log(\"Skipping splom dimension \"+r+\" with conflicting axis types\");continue}g?(T(g,d),v&&\"category\"===v.type&&(v._categories=g._categories.slice())):T(v,d),k.push(r)}for(s(t,e),n.extendFlat(b,c(e)),m=_.length*x>f?2*(b.sizeAvg||Math.max(b.size,3)):a(e,x),p=0;p<k.length;p++)d=y[r=k[p]],g=i.getFromId(t,e._diag[r][0])||{},v=i.getFromId(t,e._diag[r][1])||{},o(t,e,g,v,_[p],_[p],m);var A=u(t,e);return A.matrix||(A.matrix=!0),A.matrixOptions=b,A.selectedOptions=l(e,e.selected),A.unselectedOptions=l(e,e.unselected),[{x:!1,y:!1,t:{},trace:e}]}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../scatter/calc\":1113,\"../scatter/colorscale_calc\":1115,\"../scattergl/constants\":1162,\"../scattergl/convert\":1163,\"./scene_update\":1207}],1201:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"../scatter/subtypes\"),s=t(\"../scatter/marker_defaults\"),l=t(\"../parcoords/merge_length\"),c=/-open/;function u(t,e){function r(r,i){return n.coerce(t,e,a.dimensions,r,i)}r(\"label\");var i=r(\"values\");i&&i.length?r(\"visible\"):e.visible=!1,r(\"axis.type\"),r(\"axis.matches\")}e.exports=function(t,e,r,h){function f(r,i){return n.coerce(t,e,a,r,i)}var p=i(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=f(\"diagonal.visible\"),g=f(\"showupperhalf\"),v=f(\"showlowerhalf\");if(l(e,p,\"values\")&&(d||g||v)){f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),s(t,e,r,h,f);var m=c.test(e.marker.symbol),y=o.isBubble(e);f(\"marker.line.width\",m||y?1:0),function(t,e,r,n){var i,a,o=e.dimensions,s=o.length,l=e.showupperhalf,c=e.showlowerhalf,u=e.diagonal.visible,h=new Array(s),f=new Array(s);for(i=0;i<s;i++){var p=i?i+1:\"\";h[i]=\"x\"+p,f[i]=\"y\"+p}var d=n(\"xaxes\",h),g=n(\"yaxes\",f),v=e._diag=new Array(s);e._xaxes={},e._yaxes={};var m=[],y=[];function x(t,n,i,a){if(t){var o=t.charAt(0),s=r._splomAxes[o];if(e[\"_\"+o+\"axes\"][t]=1,a.push(t),!(t in s)){var l=s[t]={};i&&(l.label=i.label||\"\",i.visible&&i.axis&&(i.axis.type&&(l.type=i.axis.type),i.axis.matches&&(l.matches=n)))}}}var b=!u&&!c,_=!u&&!l;for(e._axesDim={},i=0;i<s;i++){var w=o[i],k=0===i,T=i===s-1,A=k&&b||T&&_?void 0:d[i],M=k&&_||T&&b?void 0:g[i];x(A,M,w,m),x(M,A,w,y),v[i]=[A,M],e._axesDim[A]=i,e._axesDim[M]=i}for(i=0;i<m.length;i++)for(a=0;a<y.length;a++){var S=m[i]+y[a];i>a&&l?r._splomSubplots[S]=1:i<a&&c?r._splomSubplots[S]=1:i!==a||!u&&c&&l||(r._splomSubplots[S]=1)}(!c||!u&&l&&c)&&(r._splomGridDflt.xside=\"bottom\",r._splomGridDflt.yside=\"left\")}(0,e,h,f),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../parcoords/merge_length\":1083,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"./attributes\":1198}],1202:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scattergl/convert\").markerStyle;e.exports=function(t,e){var r=e.trace,o=t._fullLayout._splomScenes[r.uid];if(o){i(t,r),n.extendFlat(o.matrixOptions,a(r));var s=n.extendFlat({},o.matrixOptions,o.viewOpts);o.matrix.update(s,null)}}},{\"../../lib\":719,\"../scatter/colorscale_calc\":1115,\"../scattergl/convert\":1163}],1203:[function(t,e,r){\"use strict\";r.getDimIndex=function(t,e){for(var r=e._id,n={x:0,y:1}[r.charAt(0)],i=t._visibleDims,a=0;a<i.length;a++){var o=i[a];if(t._diag[o][n]===r)return a}return!1}},{}],1204:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i=t(\"../scattergl/hover\").calcHover;e.exports={hoverPoints:function(t,e,r){var a=t.cd[0].trace,o=t.scene.matrixOptions.cdata,s=t.xa,l=t.ya,c=s.c2p(e),u=l.c2p(r),h=t.distance,f=n.getDimIndex(a,s),p=n.getDimIndex(a,l);if(!1===f||!1===p)return[t];for(var d,g,v=o[f],m=o[p],y=h,x=0;x<v.length;x++){var b=v[x],_=m[x],w=s.c2p(b)-c,k=l.c2p(_)-u,T=Math.sqrt(w*w+k*k);T<y&&(y=g=T,d=x)}return t.index=d,t.distance=y,t.dxy=g,void 0===d?[t]:(i(t,v,m,a),[t])}}},{\"../scattergl/hover\":1166,\"./helpers\":1203}],1205:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../components/grid\");e.exports={moduleType:\"trace\",name:\"splom\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\"),editStyle:t(\"./edit_style\"),meta:{}},n.register(i)},{\"../../components/grid\":636,\"../../registry\":847,\"../scatter/marker_colorbar\":1129,\"./attributes\":1198,\"./base_plot\":1199,\"./calc\":1200,\"./defaults\":1201,\"./edit_style\":1202,\"./hover\":1204,\"./plot\":1206,\"./select\":1208}],1206:[function(t,e,r){\"use strict\";var n=t(\"regl-splom\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\");function o(t,e){var r,o,s,l,c,u=t._fullLayout,h=u._size,f=e.trace,p=e.t,d=u._splomScenes[f.uid],g=d.matrixOptions,v=g.cdata,m=u._glcanvas.data()[0].regl,y=u.dragmode;if(0!==v.length){g.lower=f.showupperhalf,g.upper=f.showlowerhalf,g.diagonal=f.diagonal.visible;var x=f._visibleDims,b=v.length,_=d.viewOpts={};for(_.ranges=new Array(b),_.domains=new Array(b),c=0;c<x.length;c++){s=x[c];var w=_.ranges[c]=new Array(4),k=_.domains[c]=new Array(4);(r=a.getFromId(t,f._diag[s][0]))&&(w[0]=r._rl[0],w[2]=r._rl[1],k[0]=r.domain[0],k[2]=r.domain[1]),(o=a.getFromId(t,f._diag[s][1]))&&(w[1]=o._rl[0],w[3]=o._rl[1],k[1]=o.domain[0],k[3]=o.domain[1])}_.viewport=[h.l,h.b,h.w+h.l,h.h+h.b],!0===d.matrix&&(d.matrix=n(m));var T=u.clickmode.indexOf(\"select\")>-1,A=!0;if(\"lasso\"===y||\"select\"===y||!!f.selectedpoints||T){var M=f._length;if(f.selectedpoints){d.selectBatch=f.selectedpoints;var S=f.selectedpoints,E={};for(s=0;s<S.length;s++)E[S[s]]=!0;var C=[];for(s=0;s<M;s++)E[s]||C.push(s);d.unselectBatch=C}var L=p.xpx=new Array(b),P=p.ypx=new Array(b);for(c=0;c<x.length;c++){if(s=x[c],r=a.getFromId(t,f._diag[s][0]))for(L[c]=new Array(M),l=0;l<M;l++)L[c][l]=r.c2p(v[c][l]);if(o=a.getFromId(t,f._diag[s][1]))for(P[c]=new Array(M),l=0;l<M;l++)P[c][l]=o.c2p(v[c][l])}if(d.selectBatch.length||d.unselectBatch.length){var O=i.extendFlat({},g,d.unselectedOptions,_),z=i.extendFlat({},g,d.selectedOptions,_);d.matrix.update(O,z),A=!1}}else p.xpx=p.ypx=null;if(A){var I=i.extendFlat({},g,_);d.matrix.update(I,null)}}}e.exports=function(t,e,r){if(r.length)for(var n=0;n<r.length;n++)o(t,r[n][0])}},{\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"regl-splom\":501}],1207:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t._fullLayout,i=e.uid,a=r._splomScenes;a||(a=r._splomScenes={});var o={dirty:!0},s=a[e.uid];return s||((s=a[i]=n.extendFlat({},o,{matrix:!1,selectBatch:[],unselectBatch:[]})).draw=function(){s.matrix&&s.matrix.draw&&(s.selectBatch.length||s.unselectBatch.length?s.matrix.draw(s.unselectBatch,s.selectBatch):s.matrix.draw()),s.dirty=!1},s.destroy=function(){s.matrix&&s.matrix.destroy&&s.matrix.destroy(),s.matrixOptions=null,s.selectBatch=null,s.unselectBatch=null,s=null}),s.dirty||n.extendFlat(s,o),s}},{\"../../lib\":719}],1208:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"./helpers\");e.exports=function(t,e){var r=t.cd,o=r[0].trace,s=r[0].t,l=t.scene,c=l.matrixOptions.cdata,u=t.xaxis,h=t.yaxis,f=[];if(!l)return f;var p=!i.hasMarkers(o)&&!i.hasText(o);if(!0!==o.visible||p)return f;var d=a.getDimIndex(o,u),g=a.getDimIndex(o,h);if(!1===d||!1===g)return f;var v=s.xpx[d],m=s.ypx[g],y=c[d],x=c[g],b=[],_=[];if(!1!==e&&!e.degenerate)for(var w=0;w<y.length;w++)e.contains([v[w],m[w]],null,w,t)?(b.push(w),f.push({pointNumber:w,x:y[w],y:x[w]})):_.push(w);var k=l.matrixOptions;return b.length||_.length?l.selectBatch.length||l.unselectBatch.length||l.matrix.update(l.unselectedOptions,n.extendFlat({},k,l.selectedOptions,l.viewOpts)):l.matrix.update(k,null),l.selectBatch=b,l.unselectBatch=_,f}},{\"../../lib\":719,\"../scatter/subtypes\":1135,\"./helpers\":1203}],1209:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},starts:{x:{valType:\"data_array\",editType:\"calc\"},y:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},maxdisplayed:{valType:\"integer\",min:0,dflt:1e3,editType:\"calc\"},sizeref:{valType:\"number\",editType:\"calc\",min:0,dflt:1},text:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:i({editType:\"calc\"},{keys:[\"tubex\",\"tubey\",\"tubez\",\"tubeu\",\"tubev\",\"tubew\",\"norm\",\"divergence\"]})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach(function(t){l[t]=a[t]}),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"divergence\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../mesh3d/attributes\":1053}],1210:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){var r,i,a,o,s=e.u,l=e.v,c=e.w,u=e.x,h=e.y,f=e.z,p=Math.min(u.length,h.length,f.length,s.length,l.length,c.length),d=0;e.starts&&(i=e.starts.x||[],a=e.starts.y||[],o=e.starts.z||[],d=Math.min(i.length,a.length,o.length));var g=0,v=1/0;for(r=0;r<p;r++){var m=s[r],y=l[r],x=c[r],b=Math.sqrt(m*m+y*y+x*x);g=Math.max(g,b),v=Math.min(v,b)}n(t,e,{vals:[v,g],containerStr:\"\",cLetter:\"c\"});var _=-1/0,w=1/0,k=-1/0,T=1/0,A=-1/0,M=1/0;for(r=0;r<p;r++){var S=u[r];_=Math.max(_,S),w=Math.min(w,S);var E=h[r];k=Math.max(k,E),T=Math.min(T,E);var C=f[r];A=Math.max(A,C),M=Math.min(M,C)}for(r=0;r<d;r++){var L=i[r];_=Math.max(_,L),w=Math.min(w,L);var P=a[r];k=Math.max(k,P),T=Math.min(T,P);var O=o[r];A=Math.max(A,O),M=Math.min(M,O)}e._len=p,e._slen=d,e._normMax=g,e._xbnds=[w,_],e._ybnds=[T,k],e._zbnds=[M,A]}},{\"../../components/colorscale/calc\":601}],1211:[function(t,e,r){\"use strict\";var n=t(\"gl-streamtube3d\"),i=n.createTubeMesh,a=t(\"../../lib\"),o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\"),c={xaxis:0,yaxis:1,zaxis:2};function u(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var h=u.prototype;function f(t){return a.distinctVals(t).vals}function p(t){var e=t.length;return e>2?t.slice(1,e-1):2===e?[(t[0]+t[1])/2]:t}function d(t){var e=t.length;return 1===e?[.5,.5]:[t[1]-t[0],t[e-1]-t[e-2]]}function g(t,e){var r=t.fullSceneLayout,i=t.dataScale,u=e._len,h={};function g(t,e){var n=r[e],o=i[c[e]];return a.simpleMap(t,function(t){return n.d2l(t)*o})}h.vectors=l(g(e.u,\"xaxis\"),g(e.v,\"yaxis\"),g(e.w,\"zaxis\"),u);var v=f(e.x.slice(0,u)),m=f(e.y.slice(0,u)),y=f(e.z.slice(0,u));if(v.length*m.length*y.length>u)return{positions:[],cells:[]};var x=g(v,\"xaxis\"),b=g(m,\"yaxis\"),_=g(y,\"zaxis\");if(h.meshgrid=[x,b,_],e.starts){var w=e._slen;h.startingPositions=l(g(e.starts.x.slice(0,w),\"xaxis\"),g(e.starts.y.slice(0,w),\"yaxis\"),g(e.starts.z.slice(0,w),\"zaxis\"))}else{for(var k=b[0],T=p(x),A=p(_),M=new Array(T.length*A.length),S=0,E=0;E<T.length;E++)for(var C=0;C<A.length;C++)M[S++]=[T[E],k,A[C]];h.startingPositions=M}h.colormap=o(e),h.tubeSize=e.sizeref,h.maxLength=e.maxdisplayed;var L=g(e._xbnds,\"xaxis\"),P=g(e._ybnds,\"yaxis\"),O=g(e._zbnds,\"zaxis\"),z=d(x),I=d(b),D=d(_),R=[[L[0]-z[0],P[0]-I[0],O[0]-D[0]],[L[1]+z[1],P[1]+I[1],O[1]+D[1]]],F=n(h,R),B=s(e);F.vertexIntensityBounds=[B.min/e._normMax,B.max/e._normMax];var N=e.lightposition;return F.lightPosition=[N.x,N.y,N.z],F.ambient=e.lighting.ambient,F.diffuse=e.lighting.diffuse,F.specular=e.lighting.specular,F.roughness=e.lighting.roughness,F.fresnel=e.lighting.fresnel,F.opacity=e.opacity,e._pad=F.tubeScale*e.sizeref*2,F}h.handlePick=function(t){var e=this.scene.fullSceneLayout,r=this.scene.dataScale;function n(t,n){var i=e[n],a=r[c[n]];return i.l2c(t)/a}if(t.object===this.mesh){var i=t.data.position,a=t.data.velocity;return t.traceCoordinate=[n(i[0],\"xaxis\"),n(i[1],\"yaxis\"),n(i[2],\"zaxis\"),n(a[0],\"xaxis\"),n(a[1],\"yaxis\"),n(a[2],\"zaxis\"),t.data.intensity*this.data._normMax,t.data.divergence],t.textLabel=this.data.hovertext||this.data.text,!0}},h.update=function(t){this.data=t;var e=g(this.scene,t);this.mesh.update(e)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=g(t,e),a=i(r,n),o=new u(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../plots/gl3d/zip3\":818,\"gl-streamtube3d\":313}],1212:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),h=s(\"x\"),f=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length&&p&&p.length?(s(\"starts.x\"),s(\"starts.y\"),s(\"starts.z\"),s(\"maxdisplayed\"),s(\"sizeref\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":1209}],1213:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"streamtube\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),eventData:function(t,e){return t.tubex=t.x,t.tubey=t.y,t.tubez=t.z,t.tubeu=e.traceCoordinate[3],t.tubev=e.traceCoordinate[4],t.tubew=e.traceCoordinate[5],t.norm=e.traceCoordinate[6],t.divergence=e.traceCoordinate[7],delete t.x,delete t.y,delete t.z,t},meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1209,\"./calc\":1210,\"./convert\":1211,\"./defaults\":1212}],1214:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../plots/domain\").attributes,o=t(\"../pie/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports={labels:{valType:\"data_array\",editType:\"calc\"},parents:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},branchvalues:{valType:\"enumerated\",values:[\"remainder\",\"total\"],dflt:\"remainder\",editType:\"calc\"},level:{valType:\"any\",editType:\"plot\",anim:!0},maxdepth:{valType:\"integer\",editType:\"plot\",dflt:-1},marker:{colors:{valType:\"data_array\",editType:\"calc\"},line:{color:s({},o.marker.line.color,{dflt:null}),width:s({},o.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},leaf:{opacity:{valType:\"number\",editType:\"style\",min:0,max:1,dflt:.7},editType:\"plot\"},text:o.text,textinfo:s({},o.textinfo,{editType:\"plot\",flags:[\"label\",\"text\",\"value\"]}),textfont:o.textfont,hovertext:o.hovertext,hoverinfo:s({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"name\"]}),hovertemplate:i(),insidetextfont:o.insidetextfont,outsidetextfont:o.outsidetextfont,domain:a({name:\"sunburst\",trace:!0,editType:\"calc\"})}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../pie/attributes\":1086}],1215:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=r.name=\"sunburst\";r.plot=function(t,e,r,o){var s=n.getModule(a),l=i(t.calcdata,s)[0];s.plot(t,l,r,o)},r.clean=function(t,e,r,n){var i=n._has&&n._has(a),o=e._has&&e._has(a);i&&!o&&n._sunburstlayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],1216:[function(t,e,r){\"use strict\";var n=t(\"d3-hierarchy\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../pie/calc\").makePullColorFn,s=t(\"../pie/calc\").generateExtendedColors,l=a.isArrayOrTypedArray,c={};r.calc=function(t,e){var r,s,c,u,h,f,p=t._fullLayout,d=e.ids,g=l(d),v=e.labels,m=e.parents,y=e.values,x=l(y),b=[],_={},w={},k=function(t){return t||\"number\"==typeof t},T=function(t){return!x||i(y[t])&&y[t]>=0};g?(r=Math.min(d.length,m.length),s=function(t){return k(d[t])&&T(t)},c=function(t){return String(d[t])}):(r=Math.min(v.length,m.length),s=function(t){return k(v[t])&&T(t)},c=function(t){return String(v[t])}),x&&(r=Math.min(r,y.length));for(var A=0;A<r;A++)if(s(A)){var M=c(A),S=k(m[A])?String(m[A]):\"\",E={i:A,id:M,pid:S,label:k(v[A])?String(v[A]):\"\"};x&&(E.v=+y[A]),b.push(E),h=M,_[u=S]?_[u].push(h):_[u]=[h],w[h]=1}if(_[\"\"]){if(_[\"\"].length>1){for(var C=a.randstr(),L=0;L<b.length;L++)\"\"===b[L].pid&&(b[L].pid=C);b.unshift({hasMultipleRoots:!0,id:C,pid:\"\"})}}else{var P,O=[];for(P in _)w[P]||O.push(P);if(1!==O.length)return a.warn(\"Multiple implied roots, cannot build sunburst hierarchy.\");P=O[0],b.unshift({id:P,pid:\"\",label:P})}try{f=n.stratify().id(function(t){return t.id}).parentId(function(t){return t.pid})(b)}catch(t){return a.warn(\"Failed to build sunburst hierarchy. Error: \"+t.message)}var z=n.hierarchy(f),I=!1;if(x)switch(e.branchvalues){case\"remainder\":z.sum(function(t){return t.data.v});break;case\"total\":z.each(function(t){var e=t.data.data.v;if(t.children&&e<t.children.reduce(function(t,e){return t+e.data.data.v},0))return I=!0,a.warn([\"Total value for node\",t.data.data.id,\"is smaller than the sum of its children.\"].join(\" \"));t.value=e})}else z.count();if(!I){z.sort(function(t,e){return e.value-t.value});var D=e.marker.colors||[],R=o(p._sunburstcolormap);return z.each(function(t){var e=t.data.data,r=e.id;e.color=R(D[e.i],r)}),b[0].hierarchy=z,b}},r.crossTraceCalc=function(t){var e=t._fullLayout,r=t.calcdata,n=e.sunburstcolorway,i=e._sunburstcolormap;e.extendsunburstcolors&&(n=s(n,c));var a=0;function o(t){var e=t.data.data,r=e.id;!1===e.color&&(i[r]?e.color=i[r]:t.parent?t.parent.parent?e.color=t.parent.data.data.color:(i[r]=e.color=n[a%n.length],a++):e.color=\"rgba(0,0,0,0)\")}for(var l=0;l<r.length;l++){var u=r[l][0];\"sunburst\"===u.trace.type&&u.hierarchy&&u.hierarchy.each(o)}}},{\"../../lib\":719,\"../pie/calc\":1088,\"d3-hierarchy\":157,\"fast-isnumeric\":225}],1217:[function(t,e,r){\"use strict\";e.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:\"linear\"}},{}],1218:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}var c=l(\"labels\"),u=l(\"parents\");if(c&&c.length&&u&&u.length){var h=l(\"values\");h&&h.length&&l(\"branchvalues\"),l(\"level\"),l(\"maxdepth\"),l(\"marker.line.width\")&&l(\"marker.line.color\",s.paper_bgcolor),l(\"marker.colors\"),l(\"leaf.opacity\");var f=l(\"text\");l(\"textinfo\",Array.isArray(f)?\"text+label\":\"label\"),l(\"hovertext\"),l(\"hovertemplate\");o(t,e,s,l,\"auto\",{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),a(e,s,l),e._length=null}else e.visible=!1}},{\"../../lib\":719,\"../../plots/domain\":792,\"../bar/defaults\":861,\"./attributes\":1214}],1219:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"sunburst\",basePlotModule:t(\"./base_plot\"),categories:[],animatable:!0,attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\").style,meta:{}}},{\"./attributes\":1214,\"./base_plot\":1215,\"./calc\":1216,\"./defaults\":1218,\"./layout_attributes\":1220,\"./layout_defaults\":1221,\"./plot\":1222,\"./style\":1223}],1220:[function(t,e,r){\"use strict\";e.exports={sunburstcolorway:{valType:\"colorlist\",editType:\"calc\"},extendsunburstcolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1221:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"sunburstcolorway\",e.colorway),r(\"extendsunburstcolors\")}},{\"../../lib\":719,\"./layout_attributes\":1220}],1222:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"d3-hierarchy\"),a=t(\"../../registry\"),o=t(\"../../components/fx\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../lib\"),u=t(\"../../lib/events\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"../../lib/setcursor\"),p=t(\"../../components/fx/helpers\").appendArrayPointValue,d=t(\"../pie/plot\").transformInsideText,g=t(\"../pie/helpers\").formatPieValue,v=t(\"./style\").styleOne,m=t(\"./constants\");function y(t,e,r,a){var o=t._fullLayout,u=a&&a.duration>0,f=n.select(r).selectAll(\"g.slice\"),p=e[0],m=p.trace,y=x(p.hierarchy,m.level),w=m.maxdepth>=0?m.maxdepth:1/0,M=o._size,S=m.domain,E=M.w*(S.x[1]-S.x[0]),C=M.h*(S.y[1]-S.y[0]),L=.5*Math.min(E,C),P=p.cx=M.l+M.w*(S.x[1]+S.x[0])/2,O=p.cy=M.t+M.h*(1-S.y[0])-C/2;if(!y)return f.remove();var z=null,I={};u&&f.each(function(t){I[k(t)]={rpx0:t.rpx0,rpx1:t.rpx1,x0:t.x0,x1:t.x1,transform:t.transform},!z&&_(t)&&(z=t)});var D=function(t){return i.partition().size([2*Math.PI,t.height+1])(t)}(y).descendants(),R=y.height+1,F=0,B=w;p.hasMultipleRoots&&b(y)&&(D=D.slice(1),R-=1,F=1,B+=1),D=D.filter(function(t){return t.y1<=B});var N=Math.min(R,w),j=function(t){return(t-F)/N*L},U=function(t,e){return[t*Math.cos(e),-t*Math.sin(e)]},V=function(t){return c.pathAnnulus(t.rpx0,t.rpx1,t.x0,t.x1,P,O)},q=function(t){return P+t.pxmid[0]*t.transform.rCenter+(t.transform.x||0)},H=function(t){return O+t.pxmid[1]*t.transform.rCenter+(t.transform.y||0)};(f=f.data(D,function(t){return k(t)})).enter().append(\"g\").classed(\"slice\",!0),u?f.exit().transition().each(function(){var t=n.select(this);t.select(\"path.surface\").transition().attrTween(\"d\",function(t){var e=function(t){var e,r=k(t),i=I[r],a=I[k(y)];if(a){var o=t.x1>a.x1?2*Math.PI:0;e=t.rpx1<a.rpx1?{rpx0:0,rpx1:0}:{x0:o,x1:o}}else{var s,l=k(t.parent);f.each(function(t){if(k(t)===l)return s=t});var c,u=s.children;u.forEach(function(t,e){if(k(t)===r)return c=e});var h=u.length,p=n.interpolate(s.x0,s.x1);e={rpx0:L,rpx1:L,x0:p(c/h),x1:p((c+1)/h)}}return n.interpolate(i,e)}(t);return function(t){return V(e(t))}}),t.select(\"g.slicetext\").attr(\"opacity\",0)}).remove():f.exit().remove(),f.order();var G=null;if(u&&z){var Y=k(z);f.each(function(t){null===G&&k(t)===Y&&(G=t.x1)})}var W=f;function X(t){var e=t.parent,r=I[k(e)],i={};if(r){var a=e.children,o=a.indexOf(t),s=a.length,l=n.interpolate(r.x0,r.x1);i.x0=l(o/s),i.x1=l(o/s)}else i.x0=i.x1=0;return i}u&&(W=W.transition().each(\"end\",function(){T(n.select(this),t,{isTransitioning:!1})})),W.each(function(r){var i=n.select(this),a=c.ensureSingle(i,\"path\",\"surface\",function(t){t.style(\"pointer-events\",\"all\")});r.rpx0=j(r.y0),r.rpx1=j(r.y1),r.xmid=(r.x0+r.x1)/2,r.pxmid=U(r.rpx1,r.xmid),r.midangle=-(r.xmid-Math.PI/2),r.halfangle=.5*Math.min(c.angleDelta(r.x0,r.x1)||Math.PI,Math.PI),r.ring=1-r.rpx0/r.rpx1,r.rInscribed=function(t){return 0===t.rpx0&&c.isFullCircle([t.x0,t.x1])?1:Math.max(0,Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2))}(r),u?a.transition().attrTween(\"d\",function(t){var e=function(t){var e,r=I[k(t)],i={x0:t.x0,x1:t.x1,rpx0:t.rpx0,rpx1:t.rpx1};if(r)e=r;else if(z)if(t.parent)if(G){var a=t.x1>G?2*Math.PI:0;e={x0:a,x1:a}}else e={rpx0:L,rpx1:L},c.extendFlat(e,X(t));else e={rpx0:0,rpx1:0};else e={x0:0,x1:0};return n.interpolate(e,i)}(t);return function(t){return V(e(t))}}):a.attr(\"d\",V),i.call(A,t,e).call(T,t,{isTransitioning:t._transitioning}),a.call(v,r,m);var f=c.ensureSingle(i,\"g\",\"slicetext\"),y=c.ensureSingle(f,\"text\",\"\",function(t){t.attr(\"data-notex\",1)});y.text(function(t,e,r){var n=e.textinfo;if(!n||\"none\"===n)return\"\";var i=t.data.data,a=r.separators,o=n.split(\"+\"),s=function(t){return-1!==o.indexOf(t)},l=[];s(\"label\")&&i.label&&l.push(i.label);i.hasOwnProperty(\"v\")&&s(\"value\")&&l.push(g(i.v,a));if(s(\"text\")){var u=c.castOption(e,i.i,\"text\");c.isValidTextValue(u)&&l.push(u)}return l.join(\"<br>\")}(r,m,o)).classed(\"slicetext\",!0).attr(\"text-anchor\",\"middle\").call(l.font,b(r)?function(t,e,r){var n=e.data.data.i,i=c.castOption(t,n,\"outsidetextfont.color\")||c.castOption(t,n,\"textfont.color\")||r.color,a=c.castOption(t,n,\"outsidetextfont.family\")||c.castOption(t,n,\"textfont.family\")||r.family,o=c.castOption(t,n,\"outsidetextfont.size\")||c.castOption(t,n,\"textfont.size\")||r.size;return{color:i,family:a,size:o}}(m,r,o.font):function(t,e,r){var n=e.data.data,i=n.i,a=c.castOption(t,i,\"insidetextfont.color\");!a&&t._input.textfont&&(a=c.castOption(t._input,i,\"textfont.color\"));var o=c.castOption(t,i,\"insidetextfont.family\")||c.castOption(t,i,\"textfont.family\")||r.family,l=c.castOption(t,i,\"insidetextfont.size\")||c.castOption(t,i,\"textfont.size\")||r.size;return{color:a||s.contrast(n.color),family:o,size:l}}(m,r,o.font)).call(h.convertToTspans,t);var x=l.bBox(y.node());r.transform=d(x,r,p),r.translateX=q(r),r.translateY=H(r);var _=function(t,e){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"+(t.transform.scale<1?\"scale(\"+t.transform.scale+\")\":\"\")+(t.transform.rotate?\"rotate(\"+t.transform.rotate+\")\":\"\")+\"translate(\"+-(e.left+e.right)/2+\",\"+-(e.top+e.bottom)/2+\")\"};u?y.transition().attrTween(\"transform\",function(t){var e=function(t){var e,r=I[k(t)],i=t.transform;if(r)e=r;else if(e={rpx1:t.rpx1,transform:{scale:0,rotate:i.rotate,rCenter:i.rCenter,x:i.x,y:i.y}},z)if(t.parent)if(G){var a=t.x1>G?2*Math.PI:0;e.x0=e.x1=a}else c.extendFlat(e,X(t));else e.x0=e.x1=0;else e.x0=e.x1=0;var o=n.interpolate(e.rpx1,t.rpx1),s=n.interpolate(e.x0,t.x0),l=n.interpolate(e.x1,t.x1),u=n.interpolate(e.transform.scale,i.scale),h=n.interpolate(e.transform.rotate,i.rotate),f=0===i.rCenter?3:0===e.transform.rCenter?1/3:1,p=n.interpolate(e.transform.rCenter,i.rCenter);return function(t){var e=o(t),r=s(t),n=l(t),a=function(t){return p(Math.pow(t,f))}(t),c={pxmid:U(e,(r+n)/2),transform:{rCenter:a,x:i.x,y:i.y}},d={rpx1:o(t),translateX:q(c),translateY:H(c),transform:{scale:u(t),rotate:h(t),rCenter:a}};return d}}(t);return function(t){return _(e(t),x)}}):y.attr(\"transform\",_(r,x))})}function x(t,e){var r;return e&&t.eachAfter(function(t){if(k(t)===e)return r=t.copy()}),r||t}function b(t){return\"\"===t.data.data.pid}function _(t){return!t.parent}function w(t){return!t.children}function k(t){return t.data.data.id}function T(t,e,r){var n=t.datum(),i=(r||{}).isTransitioning;f(t,i||w(n)||b(n)?null:\"pointer\")}function A(t,e,r){var i=r[0],s=i.trace;\"_hasHoverLabel\"in s||(s._hasHoverLabel=!1),\"_hasHoverEvent\"in s||(s._hasHoverEvent=!1),t.on(\"mouseover\",function(t){var r=e._fullLayout;if(!e._dragging&&!1!==r.hovermode){var a=e._fullData[s.index],l=t.data.data,u=l.i,h=function(t){return c.castOption(a,u,t)},f=h(\"hovertemplate\"),p=o.castHoverinfo(a,r,u),d=r.separators;if(f||p&&\"none\"!==p&&\"skip\"!==p){var v=t.rInscribed,m=i.cx+t.pxmid[0]*(1-v),y=i.cy+t.pxmid[1]*(1-v),x={},b=[],_=[],w=function(t){return-1!==b.indexOf(t)};if(p&&(b=\"all\"===p?a._module.attributes.hoverinfo.flags:p.split(\"+\")),x.label=l.label,w(\"label\")&&x.label&&_.push(x.label),l.hasOwnProperty(\"v\")&&(x.value=l.v,x.valueLabel=g(x.value,d),w(\"value\")&&_.push(x.valueLabel)),x.text=h(\"hovertext\")||h(\"text\"),w(\"text\")){var k=x.text;c.isValidTextValue(k)&&_.push(k)}o.loneHover({trace:a,x0:m-v*t.rpx1,x1:m+v*t.rpx1,y:y,idealAlign:t.pxmid[0]<0?\"left\":\"right\",text:_.join(\"<br>\"),name:f||w(\"name\")?a.name:void 0,color:h(\"hoverlabel.bgcolor\")||l.color,borderColor:h(\"hoverlabel.bordercolor\"),fontFamily:h(\"hoverlabel.font.family\"),fontSize:h(\"hoverlabel.font.size\"),fontColor:h(\"hoverlabel.font.color\"),nameLength:h(\"hoverlabel.namelength\"),textAlign:h(\"hoverlabel.align\"),hovertemplate:f,hovertemplateLabels:x,eventData:[M(t,a)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e}),s._hasHoverLabel=!0}s._hasHoverEvent=!0,e.emit(\"plotly_hover\",{points:[M(t,a)],event:n.event})}}),t.on(\"mouseout\",function(t){var r=e._fullLayout,i=e._fullData[s.index],a=n.select(this).datum();s._hasHoverEvent&&(t.originalEvent=n.event,e.emit(\"plotly_unhover\",{points:[M(a,i)],event:n.event}),s._hasHoverEvent=!1),s._hasHoverLabel&&(o.loneUnhover(r._hoverlayer.node()),s._hasHoverLabel=!1)}),t.on(\"click\",function(t){var r=e._fullLayout,l=e._fullData[s.index];if(!1===u.triggerHandler(e,\"plotly_sunburstclick\",{points:[M(t,l)],event:n.event})||w(t)||b(t))r.hovermode&&(e._hoverdata=[M(t,l)],o.click(e,n.event));else if(!e._dragging&&!e._transitioning){a.call(\"_storeDirectGUIEdit\",l,r._tracePreGUI[l.uid],{level:l.level});var c=i.hierarchy,h=k(t),f=_(t)?function(t,e){var r;return t.eachAfter(function(t){for(var n=t.children||[],i=0;i<n.length;i++)if(k(n[i])===e)return r=t.copy()}),r||t}(c,h):x(c,h),p={data:[{level:k(f)}],traces:[s.index]},d={frame:{redraw:!1,duration:m.CLICK_TRANSITION_TIME},transition:{duration:m.CLICK_TRANSITION_TIME,easing:m.CLICK_TRANSITION_EASING},mode:\"immediate\",fromcurrent:!0};o.loneUnhover(r._hoverlayer.node()),a.call(\"animate\",e,p,d)}})}function M(t,e){var r=t.data.data,n={curveNumber:e.index,pointNumber:r.i,data:e._input,fullData:e};return p(n,e,r.i),n}e.exports=function(t,e,r,i){var a,o,s=t._fullLayout._sunburstlayer,l=!r,c=r&&r.duration>0;((a=s.selectAll(\"g.trace.sunburst\").data(e,function(t){return t[0].trace.uid})).enter().append(\"g\").classed(\"trace\",!0).classed(\"sunburst\",!0).attr(\"stroke-linejoin\",\"round\"),a.order(),c)?(i&&(o=i()),n.transition().duration(r.duration).ease(r.easing).each(\"end\",function(){o&&o()}).each(\"interrupt\",function(){o&&o()}).each(function(){s.selectAll(\"g.trace\").each(function(e){y(t,e,this,r)})})):a.each(function(e){y(t,e,this,r)});l&&a.exit().remove()}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../components/fx/helpers\":628,\"../../lib\":719,\"../../lib/events\":709,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../registry\":847,\"../pie/helpers\":1091,\"../pie/plot\":1095,\"./constants\":1217,\"./style\":1223,d3:163,\"d3-hierarchy\":157}],1223:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../lib\");function o(t,e,r){var n=e.data.data,o=!e.children,s=n.i,l=a.castOption(r,s,\"marker.line.color\")||i.defaultLine,c=a.castOption(r,s,\"marker.line.width\")||0;t.style(\"stroke-width\",c).call(i.fill,n.color).call(i.stroke,l).style(\"opacity\",o?r.leaf.opacity:null)}e.exports={style:function(t){t._fullLayout._sunburstlayer.selectAll(\".trace\").each(function(t){var e=n.select(this),r=t[0].trace;e.style(\"opacity\",r.opacity),e.selectAll(\"path.surface\").each(function(t){n.select(this).call(o,t,r)})})},styleOne:o}},{\"../../components/color\":593,\"../../lib\":719,d3:163}],1224:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;function c(t){return{show:{valType:\"boolean\",dflt:!1},start:{valType:\"number\",dflt:null,editType:\"plot\"},end:{valType:\"number\",dflt:null,editType:\"plot\"},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\"},project:{x:{valType:\"boolean\",dflt:!1},y:{valType:\"boolean\",dflt:!1},z:{valType:\"boolean\",dflt:!1}},color:{valType:\"color\",dflt:n.defaultLine},usecolormap:{valType:\"boolean\",dflt:!1},width:{valType:\"number\",min:1,max:16,dflt:2},highlight:{valType:\"boolean\",dflt:!0},highlightcolor:{valType:\"color\",dflt:n.defaultLine},highlightwidth:{valType:\"number\",min:1,max:16,dflt:2}}}var u=e.exports=l(s({z:{valType:\"data_array\"},x:{valType:\"data_array\"},y:{valType:\"data_array\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:a(),connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},surfacecolor:{valType:\"data_array\"}},i(\"\",{colorAttr:\"z or surfacecolor\",showScaleDflt:!0,autoColorDflt:!1,editTypeOverride:\"calc\"}),{contours:{x:c(),y:c(),z:c()},hidesurface:{valType:\"boolean\",dflt:!1},lightposition:{x:{valType:\"number\",min:-1e5,max:1e5,dflt:10},y:{valType:\"number\",min:-1e5,max:1e5,dflt:1e4},z:{valType:\"number\",min:-1e5,max:1e5,dflt:0}},lighting:{ambient:{valType:\"number\",min:0,max:1,dflt:.8},diffuse:{valType:\"number\",min:0,max:1,dflt:.8},specular:{valType:\"number\",min:0,max:2,dflt:.05},roughness:{valType:\"number\",min:0,max:1,dflt:.5},fresnel:{valType:\"number\",min:0,max:5,dflt:.2}},opacity:{valType:\"number\",min:0,max:1,dflt:1},_deprecated:{zauto:s({},i.zauto,{}),zmin:s({},i.zmin,{}),zmax:s({},i.zmax,{})},hoverinfo:s({},o.hoverinfo)}),\"calc\",\"nested\");u.x.editType=u.y.editType=u.z.editType=\"calc+clearAxisTypes\",u.transforms=void 0},{\"../../components/color\":593,\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764}],1225:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.surfacecolor?n(t,e,{vals:e.surfacecolor,containerStr:\"\",cLetter:\"c\"}):n(t,e,{vals:e.z,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],1226:[function(t,e,r){\"use strict\";var n=t(\"gl-surface3d\"),i=t(\"ndarray\"),a=t(\"ndarray-homography\"),o=t(\"ndarray-fill\"),s=t(\"../../lib\").isArrayOrTypedArray,l=t(\"../../lib/gl_format_color\").parseColorScale,c=t(\"../../lib/str2rgbarray\"),u=t(\"../../components/colorscale\").extractOpts,h=t(\"../heatmap/interp2d\"),f=t(\"../heatmap/find_empties\");function p(t,e,r){this.scene=t,this.uid=r,this.surface=e,this.data=null,this.showContour=[!1,!1,!1],this.contourStart=[null,null,null],this.contourEnd=[null,null,null],this.contourSize=[0,0,0],this.minValues=[1/0,1/0,1/0],this.maxValues=[-1/0,-1/0,-1/0],this.dataScaleX=1,this.dataScaleY=1,this.refineData=!0,this.objectOffset=[0,0,0]}var d=p.prototype;d.getXat=function(t,e,r,n){var i=s(this.data.x)?s(this.data.x[0])?this.data.x[e][t]:this.data.x[t]:t;return void 0===r?i:n.d2l(i,0,r)},d.getYat=function(t,e,r,n){var i=s(this.data.y)?s(this.data.y[0])?this.data.y[e][t]:this.data.y[e]:e;return void 0===r?i:n.d2l(i,0,r)},d.getZat=function(t,e,r,n){var i=this.data.z[e][t];return null===i&&this.data.connectgaps&&this.data._interpolatedZ&&(i=this.data._interpolatedZ[e][t]),void 0===r?i:n.d2l(i,0,r)},d.handlePick=function(t){if(t.object===this.surface){var e=(t.data.index[0]-1)/this.dataScaleX-1,r=(t.data.index[1]-1)/this.dataScaleY-1,n=Math.max(Math.min(Math.round(e),this.data.z[0].length-1),0),i=Math.max(Math.min(Math.round(r),this.data._ylength-1),0);t.index=[n,i],t.traceCoordinate=[this.getXat(n,i),this.getYat(n,i),this.getZat(n,i)],t.dataCoordinate=[this.getXat(n,i,this.data.xcalendar,this.scene.fullSceneLayout.xaxis),this.getYat(n,i,this.data.ycalendar,this.scene.fullSceneLayout.yaxis),this.getZat(n,i,this.data.zcalendar,this.scene.fullSceneLayout.zaxis)];for(var a=0;a<3;a++){var o=t.dataCoordinate[a];null!=o&&(t.dataCoordinate[a]*=this.scene.dataScale[a])}var s=this.data.hovertext||this.data.text;return Array.isArray(s)&&s[i]&&void 0!==s[i][n]?t.textLabel=s[i][n]:t.textLabel=s||\"\",t.data.dataCoordinate=t.dataCoordinate.slice(),this.surface.highlight(t.data),this.scene.glplot.spikes.position=t.dataCoordinate,!0}};var g=[2,3,5,7,11,13,17,19,23,29,31,37,41,43,47,53,59,61,67,71,73,79,83,89,97,101,103,107,109,113,127,131,137,139,149,151,157,163,167,173,179,181,191,193,197,199,211,223,227,229,233,239,241,251,257,263,269,271,277,281,283,293,307,311,313,317,331,337,347,349,353,359,367,373,379,383,389,397,401,409,419,421,431,433,439,443,449,457,461,463,467,479,487,491,499,503,509,521,523,541,547,557,563,569,571,577,587,593,599,601,607,613,617,619,631,641,643,647,653,659,661,673,677,683,691,701,709,719,727,733,739,743,751,757,761,769,773,787,797,809,811,821,823,827,829,839,853,857,859,863,877,881,883,887,907,911,919,929,937,941,947,953,967,971,977,983,991,997,1009,1013,1019,1021,1031,1033,1039,1049,1051,1061,1063,1069,1087,1091,1093,1097,1103,1109,1117,1123,1129,1151,1153,1163,1171,1181,1187,1193,1201,1213,1217,1223,1229,1231,1237,1249,1259,1277,1279,1283,1289,1291,1297,1301,1303,1307,1319,1321,1327,1361,1367,1373,1381,1399,1409,1423,1427,1429,1433,1439,1447,1451,1453,1459,1471,1481,1483,1487,1489,1493,1499,1511,1523,1531,1543,1549,1553,1559,1567,1571,1579,1583,1597,1601,1607,1609,1613,1619,1621,1627,1637,1657,1663,1667,1669,1693,1697,1699,1709,1721,1723,1733,1741,1747,1753,1759,1777,1783,1787,1789,1801,1811,1823,1831,1847,1861,1867,1871,1873,1877,1879,1889,1901,1907,1913,1931,1933,1949,1951,1973,1979,1987,1993,1997,1999,2003,2011,2017,2027,2029,2039,2053,2063,2069,2081,2083,2087,2089,2099,2111,2113,2129,2131,2137,2141,2143,2153,2161,2179,2203,2207,2213,2221,2237,2239,2243,2251,2267,2269,2273,2281,2287,2293,2297,2309,2311,2333,2339,2341,2347,2351,2357,2371,2377,2381,2383,2389,2393,2399,2411,2417,2423,2437,2441,2447,2459,2467,2473,2477,2503,2521,2531,2539,2543,2549,2551,2557,2579,2591,2593,2609,2617,2621,2633,2647,2657,2659,2663,2671,2677,2683,2687,2689,2693,2699,2707,2711,2713,2719,2729,2731,2741,2749,2753,2767,2777,2789,2791,2797,2801,2803,2819,2833,2837,2843,2851,2857,2861,2879,2887,2897,2903,2909,2917,2927,2939,2953,2957,2963,2969,2971,2999];function v(t,e){if(t<e)return 0;for(var r=0;0===Math.floor(t%e);)t/=e,r++;return r}function m(t){for(var e=[],r=0;r<g.length;r++){var n=g[r];e.push(v(t,n))}return e}function y(t){for(var e=m(t),r=t,n=0;n<g.length;n++)if(e[n]>0){r=g[n];break}return r}function x(t,e){if(!(t<1||e<1)){for(var r=m(t),n=m(e),i=1,a=0;a<g.length;a++)i*=Math.pow(g[a],Math.max(r[a],n[a]));return i}}d.calcXnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getXat(e-1,0),i=this.getXat(e,0);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r},d.calcYnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getYat(0,e-1),i=this.getYat(0,e);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r};var b=[1,2,4,6,12,24,36,48,60,120,180,240,360,720,840,1260],_=b[9],w=b[13];function k(t,e){for(var r=!1,n=0;n<t.length;n++)if(e===t[n]){r=!0;break}!1===r&&t.push(e)}d.estimateScale=function(t,e){for(var r=1+function(t){if(0!==t.length){for(var e=1,r=0;r<t.length;r++)e=x(e,t[r]);return e}}(0===e?this.calcXnums(t):this.calcYnums(t));r<_;)r*=2;for(;r>w;)r--,r/=y(r),++r<_&&(r=w);var n=Math.round(r/t);return n>1?n:1},d.refineCoords=function(t){for(var e=this.dataScaleX,r=this.dataScaleY,n=t[0].shape[0],o=t[0].shape[1],s=0|Math.floor(t[0].shape[0]*e+1),l=0|Math.floor(t[0].shape[1]*r+1),c=1+n+1,u=1+o+1,h=i(new Float32Array(c*u),[c,u]),f=0;f<t.length;++f){this.surface.padField(h,t[f]);var p=i(new Float32Array(s*l),[s,l]);a(p,h,[e,0,0,0,r,0,0,0,1]),t[f]=p}},d.setContourLevels=function(){var t,e,r,n=[[],[],[]],i=[!1,!1,!1],a=!1;for(t=0;t<3;++t)if(this.showContour[t]&&(a=!0,this.contourSize[t]>0&&null!==this.contourStart[t]&&null!==this.contourEnd[t]&&this.contourEnd[t]>this.contourStart[t]))for(i[t]=!0,e=this.contourStart[t];e<this.contourEnd[t];e+=this.contourSize[t])r=e*this.scene.dataScale[t],k(n[t],r);if(a){var o=[[],[],[]];for(t=0;t<3;++t)this.showContour[t]&&(o[t]=i[t]?n[t]:this.scene.contourLevels[t]);this.surface.update({levels:o})}},d.update=function(t){var e,r,n,a,s=this.scene,p=s.fullSceneLayout,d=this.surface,g=t.opacity,v=l(t,g),m=s.dataScale,y=t.z[0].length,x=t._ylength,b=s.contourLevels;this.data=t;var _=[];for(e=0;e<3;e++)for(_[e]=[],r=0;r<y;r++)_[e][r]=[];for(r=0;r<y;r++)for(n=0;n<x;n++)_[0][r][n]=this.getXat(r,n,t.xcalendar,p.xaxis),_[1][r][n]=this.getYat(r,n,t.ycalendar,p.yaxis),_[2][r][n]=this.getZat(r,n,t.zcalendar,p.zaxis);if(t.connectgaps)for(t._emptypoints=f(_[2]),h(_[2],t._emptypoints),t._interpolatedZ=[],r=0;r<y;r++)for(t._interpolatedZ[r]=[],n=0;n<x;n++)t._interpolatedZ[r][n]=_[2][r][n];for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null==(a=_[e][r][n])?_[e][r][n]=NaN:a=_[e][r][n]*=m[e];for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null!=(a=_[e][r][n])&&(this.minValues[e]>a&&(this.minValues[e]=a),this.maxValues[e]<a&&(this.maxValues[e]=a));for(e=0;e<3;e++)this.objectOffset[e]=.5*(this.minValues[e]+this.maxValues[e]);for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null!=(a=_[e][r][n])&&(_[e][r][n]-=this.objectOffset[e]);var k=[i(new Float32Array(y*x),[y,x]),i(new Float32Array(y*x),[y,x]),i(new Float32Array(y*x),[y,x])];o(k[0],function(t,e){return _[0][t][e]}),o(k[1],function(t,e){return _[1][t][e]}),o(k[2],function(t,e){return _[2][t][e]}),_=[];var T={colormap:v,levels:[[],[],[]],showContour:[!0,!0,!0],showSurface:!t.hidesurface,contourProject:[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],contourWidth:[1,1,1],contourColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],contourTint:[1,1,1],dynamicColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],dynamicWidth:[1,1,1],dynamicTint:[1,1,1],opacity:t.opacity},A=u(t);if(T.intensityBounds=[A.min,A.max],t.surfacecolor){var M=i(new Float32Array(y*x),[y,x]);o(M,function(e,r){return t.surfacecolor[r][e]}),k.push(M)}else T.intensityBounds[0]*=m[2],T.intensityBounds[1]*=m[2];(w<k[0].shape[0]||w<k[0].shape[1])&&(this.refineData=!1),!0===this.refineData&&(this.dataScaleX=this.estimateScale(k[0].shape[0],0),this.dataScaleY=this.estimateScale(k[0].shape[1],1),1===this.dataScaleX&&1===this.dataScaleY||this.refineCoords(k)),t.surfacecolor&&(T.intensity=k.pop());var S=[!0,!0,!0],E=[\"x\",\"y\",\"z\"];for(e=0;e<3;++e){var C=t.contours[E[e]];S[e]=C.highlight,T.showContour[e]=C.show||C.highlight,T.showContour[e]&&(T.contourProject[e]=[C.project.x,C.project.y,C.project.z],C.show?(this.showContour[e]=!0,T.levels[e]=b[e],d.highlightColor[e]=T.contourColor[e]=c(C.color),C.usecolormap?d.highlightTint[e]=T.contourTint[e]=0:d.highlightTint[e]=T.contourTint[e]=1,T.contourWidth[e]=C.width,this.contourStart[e]=C.start,this.contourEnd[e]=C.end,this.contourSize[e]=C.size):(this.showContour[e]=!1,this.contourStart[e]=null,this.contourEnd[e]=null,this.contourSize[e]=0),C.highlight&&(T.dynamicColor[e]=c(C.highlightcolor),T.dynamicWidth[e]=C.highlightwidth))}(function(t){var e=t[0].rgb,r=t[t.length-1].rgb;return e[0]===r[0]&&e[1]===r[1]&&e[2]===r[2]&&e[3]===r[3]})(v)&&(T.vertexColor=!0),T.objectOffset=this.objectOffset,T.coords=k,d.update(T),d.visible=t.visible,d.enableDynamic=S,d.enableHighlight=S,d.snapToData=!0,\"lighting\"in t&&(d.ambientLight=t.lighting.ambient,d.diffuseLight=t.lighting.diffuse,d.specularLight=t.lighting.specular,d.roughness=t.lighting.roughness,d.fresnel=t.lighting.fresnel),\"lightposition\"in t&&(d.lightPosition=[t.lightposition.x,t.lightposition.y,t.lightposition.z]),g&&g<1&&(d.supportsTransparency=!0)},d.dispose=function(){this.scene.glplot.remove(this.surface),this.surface.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new p(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../heatmap/find_empties\":1007,\"../heatmap/interp2d\":1010,\"gl-surface3d\":316,ndarray:450,\"ndarray-fill\":440,\"ndarray-homography\":442}],1227:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");function s(t,e,r){e in t&&!(r in t)&&(t[r]=t[e])}e.exports=function(t,e,r,l){var c,u;function h(r,n){return i.coerce(t,e,o,r,n)}var f=h(\"x\"),p=h(\"y\"),d=h(\"z\");if(!d||!d.length||f&&f.length<1||p&&p.length<1)e.visible=!1;else{e._xlength=Array.isArray(f)&&i.isArrayOrTypedArray(f[0])?d.length:d[0].length,e._ylength=d.length,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],l),h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"hidesurface\",\"connectgaps\",\"opacity\"].forEach(function(t){h(t)});var g=h(\"surfacecolor\"),v=[\"x\",\"y\",\"z\"];for(c=0;c<3;++c){var m=\"contours.\"+v[c],y=h(m+\".show\"),x=h(m+\".highlight\");if(y||x)for(u=0;u<3;++u)h(m+\".project.\"+v[u]);y&&(h(m+\".color\"),h(m+\".width\"),h(m+\".usecolormap\")),x&&(h(m+\".highlightcolor\"),h(m+\".highlightwidth\")),h(m+\".start\"),h(m+\".end\"),h(m+\".size\")}g||(s(t,\"zmin\",\"cmin\"),s(t,\"zmax\",\"cmax\"),s(t,\"zauto\",\"cauto\")),a(t,e,l,h,{prefix:\"\",cLetter:\"c\"}),e._length=null}}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../../registry\":847,\"./attributes\":1224}],1228:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"surface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"2dMap\",\"noOpacity\"],meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1224,\"./calc\":1225,\"./convert\":1226,\"./defaults\":1227}],1229:[function(t,e,r){\"use strict\";var n=t(\"../../components/annotations/attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../plots/domain\").attributes;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=a({domain:s({name:\"table\",trace:!0}),columnwidth:{valType:\"number\",arrayOk:!0,dflt:null},columnorder:{valType:\"data_array\"},header:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:28},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))},cells:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:20},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))}},\"calc\",\"from-root\")).transforms=void 0},{\"../../components/annotations/attributes\":576,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1230:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"table\",r.plot=function(t){var e=n(t.calcdata,\"table\")[0];e.length&&i(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"table\"),a=e._has&&e._has(\"table\");i&&!a&&n._paperdiv.selectAll(\".table\").remove()}},{\"../../plots/get_data\":802,\"./plot\":1237}],1231:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap;e.exports=function(){return n({})}},{\"../../lib/gup\":717}],1232:[function(t,e,r){\"use strict\";e.exports={cellPad:8,columnExtentOffset:10,columnTitleOffset:28,emptyHeaderHeight:16,latexCheck:/^\\$.*\\$$/,goldenRatio:1.618,lineBreaker:\"<br>\",maxDimensionCount:60,overdrag:45,releaseTransitionDuration:120,releaseTransitionEase:\"cubic-out\",scrollbarCaptureWidth:18,scrollbarHideDelay:1e3,scrollbarHideDuration:1e3,scrollbarOffset:5,scrollbarWidth:8,transitionDuration:100,transitionEase:\"cubic-out\",uplift:5,wrapSpacer:\" \",wrapSplitCharacter:\" \",cn:{table:\"table\",tableControlView:\"table-control-view\",scrollBackground:\"scroll-background\",yColumn:\"y-column\",columnBlock:\"column-block\",scrollAreaClip:\"scroll-area-clip\",scrollAreaClipRect:\"scroll-area-clip-rect\",columnBoundary:\"column-boundary\",columnBoundaryClippath:\"column-boundary-clippath\",columnBoundaryRect:\"column-boundary-rect\",columnCells:\"column-cells\",columnCell:\"column-cell\",cellRect:\"cell-rect\",cellText:\"cell-text\",cellTextHolder:\"cell-text-holder\",scrollbarKit:\"scrollbar-kit\",scrollbar:\"scrollbar\",scrollbarSlider:\"scrollbar-slider\",scrollbarGlyph:\"scrollbar-glyph\",scrollbarCaptureZone:\"scrollbar-capture-zone\"}}},{}],1233:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"fast-isnumeric\");function o(t){if(Array.isArray(t)){for(var e=0,r=0;r<t.length;r++)e=Math.max(e,o(t[r]));return e}return t}function s(t,e){return t+e}function l(t){var e,r=t.slice(),n=1/0,i=0;for(e=0;e<r.length;e++)Array.isArray(r[e])||(r[e]=[r[e]]),n=Math.min(n,r[e].length),i=Math.max(i,r[e].length);if(n!==i)for(e=0;e<r.length;e++){var a=i-r[e].length;a&&(r[e]=r[e].concat(c(a)))}return r}function c(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=\"\";return e}function u(t){return t.calcdata.columns.reduce(function(e,r){return r.xIndex<t.xIndex?e+r.columnWidth:e},0)}function h(t,e){return Object.keys(t).map(function(r){return i({},t[r],{auxiliaryBlocks:e})})}function f(t,e){for(var r,n={},i=0,a=0,o={firstRowIndex:null,lastRowIndex:null,rows:[]},s=0,l=0,c=0;c<t.length;c++)r=t[c],o.rows.push({rowIndex:c,rowHeight:r}),((a+=r)>=e||c===t.length-1)&&(n[i]=o,o.key=l++,o.firstRowIndex=s,o.lastRowIndex=c,o={firstRowIndex:null,lastRowIndex:null,rows:[]},i+=a,s=c+1,a=0);return n}e.exports=function(t,e){var r=l(e.cells.values),p=function(t){return t.slice(e.header.values.length,t.length)},d=l(e.header.values);d.length&&!d[0].length&&(d[0]=[\"\"],d=l(d));var g=d.concat(p(r).map(function(){return c((d[0]||[\"\"]).length)})),v=e.domain,m=Math.floor(t._fullLayout._size.w*(v.x[1]-v.x[0])),y=Math.floor(t._fullLayout._size.h*(v.y[1]-v.y[0])),x=e.header.values.length?g[0].map(function(){return e.header.height}):[n.emptyHeaderHeight],b=r.length?r[0].map(function(){return e.cells.height}):[],_=x.reduce(s,0),w=f(b,y-_+n.uplift),k=h(f(x,_),[]),T=h(w,k),A={},M=e._fullInput.columnorder.concat(p(r.map(function(t,e){return e}))),S=g.map(function(t,r){var n=Array.isArray(e.columnwidth)?e.columnwidth[Math.min(r,e.columnwidth.length-1)]:e.columnwidth;return a(n)?Number(n):1}),E=S.reduce(s,0);S=S.map(function(t){return t/E*m});var C=Math.max(o(e.header.line.width),o(e.cells.line.width)),L={key:e.uid+t._context.staticPlot,translateX:v.x[0]*t._fullLayout._size.w,translateY:t._fullLayout._size.h*(1-v.y[1]),size:t._fullLayout._size,width:m,maxLineWidth:C,height:y,columnOrder:M,groupHeight:y,rowBlocks:T,headerRowBlocks:k,scrollY:0,cells:i({},e.cells,{values:r}),headerCells:i({},e.header,{values:g}),gdColumns:g.map(function(t){return t[0]}),gdColumnsOriginalOrder:g.map(function(t){return t[0]}),prevPages:[0,0],scrollbarState:{scrollbarScrollInProgress:!1},columns:g.map(function(t,e){var r=A[t];return A[t]=(r||0)+1,{key:t+\"__\"+A[t],label:t,specIndex:e,xIndex:M[e],xScale:u,x:void 0,calcdata:void 0,columnWidth:S[e]}})};return L.columns.forEach(function(t){t.calcdata=L,t.x=u(t)}),L}},{\"../../lib/extend\":710,\"./constants\":1232,\"fast-isnumeric\":225}],1234:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat;r.splitToPanels=function(t){var e=[0,0],r=n({},t,{key:\"header\",type:\"header\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!0,values:t.calcdata.headerCells.values[t.specIndex],rowBlocks:t.calcdata.headerRowBlocks,calcdata:n({},t.calcdata,{cells:t.calcdata.headerCells})});return[n({},t,{key:\"cells1\",type:\"cells\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),n({},t,{key:\"cells2\",type:\"cells\",page:1,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),r]},r.splitToCells=function(t){var e=function(t){var e=t.rowBlocks[t.page],r=e?e.rows[0].rowIndex:0,n=e?r+e.rows.length:0;return[r,n]}(t);return(t.values||[]).slice(e[0],e[1]).map(function(r,n){return{keyWithinBlock:n+(\"string\"==typeof r&&r.match(/[<$&> ]/)?\"_keybuster_\"+Math.random():\"\"),key:e[0]+n,column:t,calcdata:t.calcdata,page:t.page,rowBlocks:t.rowBlocks,value:r}})}},{\"../../lib/extend\":710}],1235:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults;e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}a(e,o,s),s(\"columnwidth\"),s(\"header.values\"),s(\"header.format\"),s(\"header.align\"),s(\"header.prefix\"),s(\"header.suffix\"),s(\"header.height\"),s(\"header.line.width\"),s(\"header.line.color\"),s(\"header.fill.color\"),n.coerceFont(s,\"header.font\",n.extendFlat({},o.font)),function(t,e){for(var r=t.columnorder||[],n=t.header.values.length,i=r.slice(0,n),a=i.slice().sort(function(t,e){return t-e}),o=i.map(function(t){return a.indexOf(t)}),s=o.length;s<n;s++)o.push(s);e(\"columnorder\",o)}(e,s),s(\"cells.values\"),s(\"cells.format\"),s(\"cells.align\"),s(\"cells.prefix\"),s(\"cells.suffix\"),s(\"cells.height\"),s(\"cells.line.width\"),s(\"cells.line.color\"),s(\"cells.fill.color\"),n.coerceFont(s,\"cells.font\",n.extendFlat({},o.font)),e._length=null}},{\"../../lib\":719,\"../../plots/domain\":792,\"./attributes\":1229}],1236:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"table\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1229,\"./base_plot\":1230,\"./calc\":1231,\"./defaults\":1235,\"./plot\":1237}],1237:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\"),o=t(\"../../components/drawing\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../lib\").raiseToTop,c=t(\"../../lib\").cancelTransition,u=t(\"./data_preparation_helper\"),h=t(\"./data_split_helpers\"),f=t(\"../../components/color\");function p(t){return Math.ceil(t.calcdata.maxLineWidth/2)}function d(t,e){return\"clip\"+t._fullLayout._uid+\"_scrollAreaBottomClip_\"+e.key}function g(t,e){return\"clip\"+t._fullLayout._uid+\"_columnBoundaryClippath_\"+e.calcdata.key+\"_\"+e.specIndex}function v(t){return[].concat.apply([],t.map(function(t){return t})).map(function(t){return t.__data__})}function m(t,e,r){var o=t.selectAll(\".\"+n.cn.scrollbarKit).data(a.repeat,a.keyFun);o.enter().append(\"g\").classed(n.cn.scrollbarKit,!0).style(\"shape-rendering\",\"geometricPrecision\"),o.each(function(t){var e=t.scrollbarState;e.totalHeight=function(t){var e=t.rowBlocks;return z(e,e.length-1)+(e.length?I(e[e.length-1],1/0):1)}(t),e.scrollableAreaHeight=t.groupHeight-A(t),e.currentlyVisibleHeight=Math.min(e.totalHeight,e.scrollableAreaHeight),e.ratio=e.currentlyVisibleHeight/e.totalHeight,e.barLength=Math.max(e.ratio*e.currentlyVisibleHeight,n.goldenRatio*n.scrollbarWidth),e.barWiggleRoom=e.currentlyVisibleHeight-e.barLength,e.wiggleRoom=Math.max(0,e.totalHeight-e.scrollableAreaHeight),e.topY=0===e.barWiggleRoom?0:t.scrollY/e.wiggleRoom*e.barWiggleRoom,e.bottomY=e.topY+e.barLength,e.dragMultiplier=e.wiggleRoom/e.barWiggleRoom}).attr(\"transform\",function(t){return\"translate(\"+(t.width+n.scrollbarWidth/2+n.scrollbarOffset)+\" \"+A(t)+\")\"});var s=o.selectAll(\".\"+n.cn.scrollbar).data(a.repeat,a.keyFun);s.enter().append(\"g\").classed(n.cn.scrollbar,!0);var l=s.selectAll(\".\"+n.cn.scrollbarSlider).data(a.repeat,a.keyFun);l.enter().append(\"g\").classed(n.cn.scrollbarSlider,!0),l.attr(\"transform\",function(t){return\"translate(0 \"+(t.scrollbarState.topY||0)+\")\"});var c=l.selectAll(\".\"+n.cn.scrollbarGlyph).data(a.repeat,a.keyFun);c.enter().append(\"line\").classed(n.cn.scrollbarGlyph,!0).attr(\"stroke\",\"black\").attr(\"stroke-width\",n.scrollbarWidth).attr(\"stroke-linecap\",\"round\").attr(\"y1\",n.scrollbarWidth/2),c.attr(\"y2\",function(t){return t.scrollbarState.barLength-n.scrollbarWidth/2}).attr(\"stroke-opacity\",function(t){return t.columnDragInProgress||!t.scrollbarState.barWiggleRoom||r?0:.4}),c.transition().delay(0).duration(0),c.transition().delay(n.scrollbarHideDelay).duration(n.scrollbarHideDuration).attr(\"stroke-opacity\",0);var u=s.selectAll(\".\"+n.cn.scrollbarCaptureZone).data(a.repeat,a.keyFun);u.enter().append(\"line\").classed(n.cn.scrollbarCaptureZone,!0).attr(\"stroke\",\"white\").attr(\"stroke-opacity\",.01).attr(\"stroke-width\",n.scrollbarCaptureWidth).attr(\"stroke-linecap\",\"butt\").attr(\"y1\",0).on(\"mousedown\",function(r){var n=i.event.y,a=this.getBoundingClientRect(),o=r.scrollbarState,s=n-a.top,l=i.scale.linear().domain([0,o.scrollableAreaHeight]).range([0,o.totalHeight]).clamp(!0);o.topY<=s&&s<=o.bottomY||S(e,t,null,l(s-o.barLength/2))(r)}).call(i.behavior.drag().origin(function(t){return i.event.stopPropagation(),t.scrollbarState.scrollbarScrollInProgress=!0,t}).on(\"drag\",S(e,t)).on(\"dragend\",function(){})),u.attr(\"y2\",function(t){return t.scrollbarState.scrollableAreaHeight}),e._context.staticPlot&&(c.remove(),u.remove())}function y(t,e,r,s){var l=function(t){var e=t.selectAll(\".\"+n.cn.columnCell).data(h.splitToCells,function(t){return t.keyWithinBlock});return e.enter().append(\"g\").classed(n.cn.columnCell,!0),e.exit().remove(),e}(function(t){var e=t.selectAll(\".\"+n.cn.columnCells).data(a.repeat,a.keyFun);return e.enter().append(\"g\").classed(n.cn.columnCells,!0),e.exit().remove(),e}(r));!function(t){t.each(function(t,e){var r=t.calcdata.cells.font,n=t.column.specIndex,i={size:_(r.size,n,e),color:_(r.color,n,e),family:_(r.family,n,e)};t.rowNumber=t.key,t.align=_(t.calcdata.cells.align,n,e),t.cellBorderWidth=_(t.calcdata.cells.line.width,n,e),t.font=i})}(l),function(t){t.attr(\"width\",function(t){return t.column.columnWidth}).attr(\"stroke-width\",function(t){return t.cellBorderWidth}).each(function(t){var e=i.select(this);f.stroke(e,_(t.calcdata.cells.line.color,t.column.specIndex,t.rowNumber)),f.fill(e,_(t.calcdata.cells.fill.color,t.column.specIndex,t.rowNumber))})}(function(t){var e=t.selectAll(\".\"+n.cn.cellRect).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"rect\").classed(n.cn.cellRect,!0),e}(l));var c=function(t){var e=t.selectAll(\".\"+n.cn.cellText).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"text\").classed(n.cn.cellText,!0).style(\"cursor\",function(){return\"auto\"}).on(\"mousedown\",function(){i.event.stopPropagation()}),e}(function(t){var e=t.selectAll(\".\"+n.cn.cellTextHolder).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"g\").classed(n.cn.cellTextHolder,!0).style(\"shape-rendering\",\"geometricPrecision\"),e}(l));!function(t){t.each(function(t){o.font(i.select(this),t.font)})}(c),x(c,e,s,t),O(l)}function x(t,e,r,a){t.text(function(t){var e=t.column.specIndex,r=t.rowNumber,a=t.value,o=\"string\"==typeof a,s=o&&a.match(/<br>/i),l=!o||s;t.mayHaveMarkup=o&&a.match(/[<&>]/);var c,u=\"string\"==typeof(c=a)&&c.match(n.latexCheck);t.latex=u;var h,f,p=u?\"\":_(t.calcdata.cells.prefix,e,r)||\"\",d=u?\"\":_(t.calcdata.cells.suffix,e,r)||\"\",g=u?null:_(t.calcdata.cells.format,e,r)||null,v=p+(g?i.format(g)(t.value):t.value)+d;if(t.wrappingNeeded=!t.wrapped&&!l&&!u&&(h=b(v)),t.cellHeightMayIncrease=s||u||t.mayHaveMarkup||(void 0===h?b(v):h),t.needsConvertToTspans=t.mayHaveMarkup||t.wrappingNeeded||t.latex,t.wrappingNeeded){var m=(\" \"===n.wrapSplitCharacter?v.replace(/<a href=/gi,\"<a_href=\"):v).split(n.wrapSplitCharacter),y=\" \"===n.wrapSplitCharacter?m.map(function(t){return t.replace(/<a_href=/gi,\"<a href=\")}):m;t.fragments=y.map(function(t){return{text:t,width:null}}),t.fragments.push({fragment:n.wrapSpacer,width:null}),f=y.join(n.lineBreaker)+n.lineBreaker+n.wrapSpacer}else delete t.fragments,f=v;return f}).attr(\"dy\",function(t){return t.needsConvertToTspans?0:\"0.75em\"}).each(function(t){var o=i.select(this),l=t.wrappingNeeded?C:L;t.needsConvertToTspans?s.convertToTspans(o,a,l(r,this,e,a,t)):i.select(this.parentNode).attr(\"transform\",function(t){return\"translate(\"+P(t)+\" \"+n.cellPad+\")\"}).attr(\"text-anchor\",function(t){return{left:\"start\",center:\"middle\",right:\"end\"}[t.align]})})}function b(t){return-1!==t.indexOf(n.wrapSplitCharacter)}function _(t,e,r){if(Array.isArray(t)){var n=t[Math.min(e,t.length-1)];return Array.isArray(n)?n[Math.min(r,n.length-1)]:n}return t}function w(t,e,r){t.transition().ease(n.releaseTransitionEase).duration(n.releaseTransitionDuration).attr(\"transform\",\"translate(\"+e.x+\" \"+r+\")\")}function k(t){return\"cells\"===t.type}function T(t){return\"header\"===t.type}function A(t){return(t.rowBlocks.length?t.rowBlocks[0].auxiliaryBlocks:[]).reduce(function(t,e){return t+I(e,1/0)},0)}function M(t,e,r){var n=v(e)[0];if(void 0!==n){var i=n.rowBlocks,a=n.calcdata,o=z(i,i.length),s=n.calcdata.groupHeight-A(n),l=a.scrollY=Math.max(0,Math.min(o-s,a.scrollY)),c=function(t,e,r){for(var n=[],i=0,a=0;a<t.length;a++){for(var o=t[a],s=o.rows,l=0,c=0;c<s.length;c++)l+=s[c].rowHeight;o.allRowsHeight=l,e<i+l&&e+r>i&&n.push(a),i+=l}return n}(i,l,s);1===c.length&&(c[0]===i.length-1?c.unshift(c[0]-1):c.push(c[0]+1)),c[0]%2&&c.reverse(),e.each(function(t,e){t.page=c[e],t.scrollY=l}),e.attr(\"transform\",function(t){return\"translate(0 \"+(z(t.rowBlocks,t.page)-t.scrollY)+\")\"}),t&&(E(t,r,e,c,n.prevPages,n,0),E(t,r,e,c,n.prevPages,n,1),m(r,t))}}function S(t,e,r,a){return function(o){var s=o.calcdata?o.calcdata:o,l=e.filter(function(t){return s.key===t.key}),c=r||s.scrollbarState.dragMultiplier,u=s.scrollY;s.scrollY=void 0===a?s.scrollY+c*i.event.dy:a;var h=l.selectAll(\".\"+n.cn.yColumn).selectAll(\".\"+n.cn.columnBlock).filter(k);return M(t,h,l),s.scrollY===u}}function E(t,e,r,n,i,a,o){n[o]!==i[o]&&(clearTimeout(a.currentRepaint[o]),a.currentRepaint[o]=setTimeout(function(){var a=r.filter(function(t,e){return e===o&&n[e]!==i[e]});y(t,e,a,r),i[o]=n[o]}))}function C(t,e,r,a){return function(){var o=i.select(e.parentNode);o.each(function(t){var e=t.fragments;o.selectAll(\"tspan.line\").each(function(t,r){e[r].width=this.getComputedTextLength()});var r,i,a=e[e.length-1].width,s=e.slice(0,-1),l=[],c=0,u=t.column.columnWidth-2*n.cellPad;for(t.value=\"\";s.length;)c+(i=(r=s.shift()).width+a)>u&&(t.value+=l.join(n.wrapSpacer)+n.lineBreaker,l=[],c=0),l.push(r.text),c+=i;c&&(t.value+=l.join(n.wrapSpacer)),t.wrapped=!0}),o.selectAll(\"tspan.line\").remove(),x(o.select(\".\"+n.cn.cellText),r,t,a),i.select(e.parentNode.parentNode).call(O)}}function L(t,e,r,a,o){return function(){if(!o.settledY){var s=i.select(e.parentNode),l=R(o),c=o.key-l.firstRowIndex,u=l.rows[c].rowHeight,h=o.cellHeightMayIncrease?e.parentNode.getBoundingClientRect().height+2*n.cellPad:u,f=Math.max(h,u);f-l.rows[c].rowHeight&&(l.rows[c].rowHeight=f,t.selectAll(\".\"+n.cn.columnCell).call(O),M(null,t.filter(k),0),m(r,a,!0)),s.attr(\"transform\",function(){var t=this.parentNode.getBoundingClientRect(),e=i.select(this.parentNode).select(\".\"+n.cn.cellRect).node().getBoundingClientRect(),r=this.transform.baseVal.consolidate(),a=e.top-t.top+(r?r.matrix.f:n.cellPad);return\"translate(\"+P(o,i.select(this.parentNode).select(\".\"+n.cn.cellTextHolder).node().getBoundingClientRect().width)+\" \"+a+\")\"}),o.settledY=!0}}}function P(t,e){switch(t.align){case\"left\":return n.cellPad;case\"right\":return t.column.columnWidth-(e||0)-n.cellPad;case\"center\":return(t.column.columnWidth-(e||0))/2;default:return n.cellPad}}function O(t){t.attr(\"transform\",function(t){var e=t.rowBlocks[0].auxiliaryBlocks.reduce(function(t,e){return t+I(e,1/0)},0);return\"translate(0 \"+(I(R(t),t.key)+e)+\")\"}).selectAll(\".\"+n.cn.cellRect).attr(\"height\",function(t){return(e=R(t),r=t.key,e.rows[r-e.firstRowIndex]).rowHeight;var e,r})}function z(t,e){for(var r=0,n=e-1;n>=0;n--)r+=D(t[n]);return r}function I(t,e){for(var r=0,n=0;n<t.rows.length&&t.rows[n].rowIndex<e;n++)r+=t.rows[n].rowHeight;return r}function D(t){var e=t.allRowsHeight;if(void 0!==e)return e;for(var r=0,n=0;n<t.rows.length;n++)r+=t.rows[n].rowHeight;return t.allRowsHeight=r,r}function R(t){return t.rowBlocks[t.page]}e.exports=function(t,e){var r=!t._context.staticPlot,s=t._fullLayout._paper.selectAll(\".\"+n.cn.table).data(e.map(function(e){var r=a.unwrap(e).trace;return u(t,r)}),a.keyFun);s.exit().remove(),s.enter().append(\"g\").classed(n.cn.table,!0).attr(\"overflow\",\"visible\").style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"overflow\",\"visible\").style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"all\"),s.attr(\"width\",function(t){return t.width+t.size.l+t.size.r}).attr(\"height\",function(t){return t.height+t.size.t+t.size.b}).attr(\"transform\",function(t){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"});var f=s.selectAll(\".\"+n.cn.tableControlView).data(a.repeat,a.keyFun),x=f.enter().append(\"g\").classed(n.cn.tableControlView,!0).style(\"box-sizing\",\"content-box\");r&&x.on(\"mousemove\",function(e){f.filter(function(t){return e===t}).call(m,t)}).on(\"mousewheel\",function(e){if(!e.scrollbarState.wheeling){e.scrollbarState.wheeling=!0;var r=e.scrollY+i.event.deltaY;S(t,f,null,r)(e)||(i.event.stopPropagation(),i.event.preventDefault()),e.scrollbarState.wheeling=!1}}).call(m,t,!0),f.attr(\"transform\",function(t){return\"translate(\"+t.size.l+\" \"+t.size.t+\")\"});var b=f.selectAll(\".\"+n.cn.scrollBackground).data(a.repeat,a.keyFun);b.enter().append(\"rect\").classed(n.cn.scrollBackground,!0).attr(\"fill\",\"none\"),b.attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}),f.each(function(e){o.setClipUrl(i.select(this),d(t,e),t)});var _=f.selectAll(\".\"+n.cn.yColumn).data(function(t){return t.columns},a.keyFun);_.enter().append(\"g\").classed(n.cn.yColumn,!0),_.exit().remove(),_.attr(\"transform\",function(t){return\"translate(\"+t.x+\" 0)\"}),r&&_.call(i.behavior.drag().origin(function(e){return w(i.select(this),e,-n.uplift),l(this),e.calcdata.columnDragInProgress=!0,m(f.filter(function(t){return e.calcdata.key===t.key}),t),e}).on(\"drag\",function(t){var e=i.select(this),r=function(e){return(t===e?i.event.x:e.x)+e.columnWidth/2};t.x=Math.max(-n.overdrag,Math.min(t.calcdata.width+n.overdrag-t.columnWidth,i.event.x)),v(_).filter(function(e){return e.calcdata.key===t.calcdata.key}).sort(function(t,e){return r(t)-r(e)}).forEach(function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e)}),_.filter(function(e){return t!==e}).transition().ease(n.transitionEase).duration(n.transitionDuration).attr(\"transform\",function(t){return\"translate(\"+t.x+\" 0)\"}),e.call(c).attr(\"transform\",\"translate(\"+t.x+\" -\"+n.uplift+\" )\")}).on(\"dragend\",function(e){var r=i.select(this),n=e.calcdata;e.x=e.xScale(e),e.calcdata.columnDragInProgress=!1,w(r,e,0),function(t,e,r){var n=e.gdColumnsOriginalOrder;e.gdColumns.sort(function(t,e){return r[n.indexOf(t)]-r[n.indexOf(e)]}),e.columnorder=r,t.emit(\"plotly_restyle\")}(t,n,n.columns.map(function(t){return t.xIndex}))})),_.each(function(e){o.setClipUrl(i.select(this),g(t,e),t)});var A=_.selectAll(\".\"+n.cn.columnBlock).data(h.splitToPanels,a.keyFun);A.enter().append(\"g\").classed(n.cn.columnBlock,!0).attr(\"id\",function(t){return t.key}),A.style(\"cursor\",function(t){return t.dragHandle?\"ew-resize\":t.calcdata.scrollbarState.barWiggleRoom?\"ns-resize\":\"default\"});var E=A.filter(T),C=A.filter(k);r&&C.call(i.behavior.drag().origin(function(t){return i.event.stopPropagation(),t}).on(\"drag\",S(t,f,-1)).on(\"dragend\",function(){})),y(t,f,E,A),y(t,f,C,A);var L=f.selectAll(\".\"+n.cn.scrollAreaClip).data(a.repeat,a.keyFun);L.enter().append(\"clipPath\").classed(n.cn.scrollAreaClip,!0).attr(\"id\",function(e){return d(t,e)});var P=L.selectAll(\".\"+n.cn.scrollAreaClipRect).data(a.repeat,a.keyFun);P.enter().append(\"rect\").classed(n.cn.scrollAreaClipRect,!0).attr(\"x\",-n.overdrag).attr(\"y\",-n.uplift).attr(\"fill\",\"none\"),P.attr(\"width\",function(t){return t.width+2*n.overdrag}).attr(\"height\",function(t){return t.height+n.uplift}),_.selectAll(\".\"+n.cn.columnBoundary).data(a.repeat,a.keyFun).enter().append(\"g\").classed(n.cn.columnBoundary,!0);var O=_.selectAll(\".\"+n.cn.columnBoundaryClippath).data(a.repeat,a.keyFun);O.enter().append(\"clipPath\").classed(n.cn.columnBoundaryClippath,!0),O.attr(\"id\",function(e){return g(t,e)});var z=O.selectAll(\".\"+n.cn.columnBoundaryRect).data(a.repeat,a.keyFun);z.enter().append(\"rect\").classed(n.cn.columnBoundaryRect,!0).attr(\"fill\",\"none\"),z.attr(\"width\",function(t){return t.columnWidth+2*p(t)}).attr(\"height\",function(t){return t.calcdata.height+2*p(t)+n.uplift}).attr(\"x\",function(t){return-p(t)}).attr(\"y\",function(t){return-p(t)}),M(null,C,f)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/gup\":717,\"../../lib/svg_text_utils\":743,\"./constants\":1232,\"./data_preparation_helper\":1233,\"./data_split_helpers\":1234,d3:163}],1238:[function(t,e,r){\"use strict\";var n=t(\"../box/attributes\"),i=t(\"../../lib/extend\").extendFlat;e.exports={y:n.y,x:n.x,x0:n.x0,y0:n.y0,name:i({},n.name,{}),orientation:i({},n.orientation,{}),bandwidth:{valType:\"number\",min:0,editType:\"calc\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},scalemode:{valType:\"enumerated\",values:[\"width\",\"count\"],dflt:\"width\",editType:\"calc\"},spanmode:{valType:\"enumerated\",values:[\"soft\",\"hard\",\"manual\"],dflt:\"soft\",editType:\"calc\"},span:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}],editType:\"calc\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,points:i({},n.boxpoints,{}),jitter:i({},n.jitter,{}),pointpos:i({},n.pointpos,{}),width:i({},n.width,{}),marker:n.marker,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,box:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},width:{valType:\"number\",min:0,max:1,dflt:.25,editType:\"plot\"},fillcolor:{valType:\"color\",editType:\"style\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},editType:\"plot\"},meanline:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"plot\"},side:{valType:\"enumerated\",values:[\"both\",\"positive\",\"negative\"],dflt:\"both\",editType:\"calc\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,hoveron:{valType:\"flaglist\",flags:[\"violins\",\"points\",\"kde\"],dflt:\"violins+points+kde\",extras:[\"all\"],editType:\"style\"}}},{\"../../lib/extend\":710,\"../box/attributes\":880}],1239:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/calc\"),o=t(\"./helpers\"),s=t(\"../../constants/numerical\").BADNUM;function l(t,e,r){var i=e.max-e.min;if(!i)return t.bandwidth?t.bandwidth:0;if(t.bandwidth)return Math.max(t.bandwidth,i/1e4);var a=r.length,o=n.stdev(r,a-1,e.mean);return Math.max(function(t,e,r){return 1.059*Math.min(e,r/1.349)*Math.pow(t,-.2)}(a,o,e.q3-e.q1),i/100)}function c(t,e,r,n){var a,o=t.spanmode,l=t.span||[],c=[e.min,e.max],u=[e.min-2*n,e.max+2*n];function h(n){var i=l[n],a=\"multicategory\"===r.type?r.r2c(i):r.d2c(i,0,t[e.valLetter+\"calendar\"]);return a===s?u[n]:a}var f={type:\"linear\",range:a=\"soft\"===o?u:\"hard\"===o?c:[h(0),h(1)]};return i.setConvert(f),f.cleanRange(),a}e.exports=function(t,e){var r=a(t,e);if(r[0].t.empty)return r;for(var s=t._fullLayout,u=i.getFromId(t,e[\"h\"===e.orientation?\"xaxis\":\"yaxis\"]),h=1/0,f=-1/0,p=0,d=0,g=0;g<r.length;g++){var v=r[g],m=v.pts.map(o.extractVal),y=v.bandwidth=l(e,v,m),x=v.span=c(e,v,u,y);if(v.min===v.max&&0===y)x=v.span=[v.min,v.max],v.density=[{v:1,t:x[0]}],v.bandwidth=y,p=Math.max(p,1);else{var b=x[1]-x[0],_=Math.ceil(b/(y/3)),w=b/_;if(!isFinite(w)||!isFinite(_))return n.error(\"Something went wrong with computing the violin span\"),r[0].t.empty=!0,r;var k=o.makeKDE(v,e,m);v.density=new Array(_);for(var T=0,A=x[0];A<x[1]+w/2;T++,A+=w){var M=k(A);v.density[T]={v:M,t:A},p=Math.max(p,M)}}d=Math.max(d,m.length),h=Math.min(h,x[0]),f=Math.max(f,x[1])}var S=i.findExtremes(u,[h,f],{padded:!0});if(e._extremes[u._id]=S,e.width)r[0].t.maxKDE=p;else{var E=s._violinScaleGroupStats,C=e.scalegroup,L=E[C];L?(L.maxKDE=Math.max(L.maxKDE,p),L.maxCount=Math.max(L.maxCount,d)):E[C]={maxKDE:p,maxCount:d}}return r[0].t.labels.kde=n._(t,\"kde:\"),r}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../box/calc\":881,\"./helpers\":1242}],1240:[function(t,e,r){\"use strict\";var n=t(\"../box/cross_trace_calc\").setPositionOffset,i=[\"v\",\"h\"];e.exports=function(t,e){for(var r=t.calcdata,a=e.xaxis,o=e.yaxis,s=0;s<i.length;s++){for(var l=i[s],c=\"h\"===l?o:a,u=[],h=0;h<r.length;h++){var f=r[h],p=f[0].t,d=f[0].trace;!0!==d.visible||\"violin\"!==d.type||p.empty||d.orientation!==l||d.xaxis!==a._id||d.yaxis!==o._id||u.push(h)}n(\"violin\",t,u,c)}}},{\"../box/cross_trace_calc\":882}],1241:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../box/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}function c(r,i){return n.coerce2(t,e,o,r,i)}if(a.handleSampleDefaults(t,e,l,s),!1!==e.visible){l(\"bandwidth\"),l(\"side\"),l(\"width\")||(l(\"scalegroup\",e.name),l(\"scalemode\"));var u,h=l(\"span\");Array.isArray(h)&&(u=\"manual\"),l(\"spanmode\",u);var f=l(\"line.color\",(t.marker||{}).color||r),p=l(\"line.width\"),d=l(\"fillcolor\",i.addOpacity(e.line.color,.5));a.handlePointsDefaults(t,e,l,{prefix:\"\"});var g=c(\"box.width\"),v=c(\"box.fillcolor\",d),m=c(\"box.line.color\",f),y=c(\"box.line.width\",p);l(\"box.visible\",Boolean(g||v||m||y))||(e.box={visible:!1});var x=c(\"meanline.color\",f),b=c(\"meanline.width\",p);l(\"meanline.visible\",Boolean(x||b))||(e.meanline={visible:!1})}}},{\"../../components/color\":593,\"../../lib\":719,\"../box/defaults\":883,\"./attributes\":1238}],1242:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=function(t){return 1/Math.sqrt(2*Math.PI)*Math.exp(-.5*t*t)};r.makeKDE=function(t,e,r){var n=r.length,a=i,o=t.bandwidth,s=1/(n*o);return function(t){for(var e=0,i=0;i<n;i++)e+=a((t-r[i])/o);return s*e}},r.getPositionOnKdePath=function(t,e,r){var i,a;\"h\"===e.orientation?(i=\"y\",a=\"x\"):(i=\"x\",a=\"y\");var o=n.findPointOnPath(t.path,r,a,{pathLength:t.pathLength}),s=t.posCenterPx,l=o[i];return[l,\"both\"===e.side?2*s-l:s]},r.getKdeValue=function(t,e,n){var i=t.pts.map(r.extractVal);return r.makeKDE(t,e,i)(n)/t.posDensityScale},r.extractVal=function(t){return t.v}},{\"../../lib\":719}],1243:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/hover\"),o=t(\"./helpers\");e.exports=function(t,e,r,s,l){var c,u,h=t.cd,f=h[0].trace,p=f.hoveron,d=-1!==p.indexOf(\"violins\"),g=-1!==p.indexOf(\"kde\"),v=[];if(d||g){var m=a.hoverOnBoxes(t,e,r,s);if(g&&m.length>0){var y,x,b,_,w,k=t.xa,T=t.ya;\"h\"===f.orientation?(w=e,y=\"y\",b=T,x=\"x\",_=k):(w=r,y=\"x\",b=k,x=\"y\",_=T);var A=h[t.index];if(w>=A.span[0]&&w<=A.span[1]){var M=n.extendFlat({},t),S=_.c2p(w,!0),E=o.getKdeValue(A,f,w),C=o.getPositionOnKdePath(A,f,S),L=b._offset,P=b._length;M[y+\"0\"]=C[0],M[y+\"1\"]=C[1],M[x+\"0\"]=M[x+\"1\"]=S,M[x+\"Label\"]=x+\": \"+i.hoverLabelText(_,w)+\", \"+h[0].t.labels.kde+\" \"+E.toFixed(3),M.spikeDistance=m[0].spikeDistance;var O=y+\"Spike\";M[O]=m[0][O],m[0].spikeDistance=void 0,m[0][O]=void 0,M.hovertemplate=!1,v.push(M),(u={stroke:t.color})[y+\"1\"]=n.constrain(L+C[0],L,L+P),u[y+\"2\"]=n.constrain(L+C[1],L,L+P),u[x+\"1\"]=u[x+\"2\"]=_._offset+S}}d&&(v=v.concat(m))}-1!==p.indexOf(\"points\")&&(c=a.hoverOnPoints(t,e,r));var z=l.selectAll(\".violinline-\"+f.uid).data(u?[0]:[]);return z.enter().append(\"line\").classed(\"violinline-\"+f.uid,!0).attr(\"stroke-width\",1.5),z.exit().remove(),z.attr(u),\"closest\"===s?c?[c]:v:c?(v.push(c),v):v}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../box/hover\":885,\"./helpers\":1242}],1244:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../box/defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../box/select\"),moduleType:\"trace\",name:\"violin\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"violinLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../box/defaults\":883,\"../box/select\":890,\"../scatter/style\":1134,\"./attributes\":1238,\"./calc\":1239,\"./cross_trace_calc\":1240,\"./defaults\":1241,\"./hover\":1243,\"./layout_attributes\":1245,\"./layout_defaults\":1246,\"./plot\":1247,\"./style\":1248}],1245:[function(t,e,r){\"use strict\";var n=t(\"../box/layout_attributes\"),i=t(\"../../lib\").extendFlat;e.exports={violinmode:i({},n.boxmode,{}),violingap:i({},n.boxgap,{}),violingroupgap:i({},n.boxgroupgap,{})}},{\"../../lib\":719,\"../box/layout_attributes\":887}],1246:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"../box/layout_defaults\");e.exports=function(t,e,r){a._supply(t,e,r,function(r,a){return n.coerce(t,e,i,r,a)},\"violin\")}},{\"../../lib\":719,\"../box/layout_defaults\":888,\"./layout_attributes\":1245}],1247:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../box/plot\"),s=t(\"../scatter/line_points\"),l=t(\"./helpers\");e.exports=function(t,e,r,c){var u=t._fullLayout,h=e.xaxis,f=e.yaxis;function p(t){var e=s(t,{xaxis:h,yaxis:f,connectGaps:!0,baseTolerance:.75,shape:\"spline\",simplify:!0});return a.smoothopen(e[0],1)}i.makeTraceGroups(c,r,\"trace violins\").each(function(t){var r=n.select(this),a=t[0],s=a.t,c=a.trace;if(!0!==c.visible||s.empty)r.remove();else{var d=s.bPos,g=s.bdPos,v=e[s.valLetter+\"axis\"],m=e[s.posLetter+\"axis\"],y=\"both\"===c.side,x=y||\"positive\"===c.side,b=y||\"negative\"===c.side,_=r.selectAll(\"path.violin\").data(i.identity);_.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"violin\"),_.exit().remove(),_.each(function(t){var e,r,i,a,o,l,h,f,_=n.select(this),w=t.density,k=w.length,T=t.pos+d,A=m.c2p(T);if(c.width)e=s.maxKDE/g;else{var M=u._violinScaleGroupStats[c.scalegroup];e=\"count\"===c.scalemode?M.maxKDE/g*(M.maxCount/t.pts.length):M.maxKDE/g}if(x){for(h=new Array(k),o=0;o<k;o++)(f=h[o]={})[s.posLetter]=T+w[o].v/e,f[s.valLetter]=w[o].t;r=p(h)}if(b){for(h=new Array(k),l=0,o=k-1;l<k;l++,o--)(f=h[l]={})[s.posLetter]=T-w[o].v/e,f[s.valLetter]=w[o].t;i=p(h)}if(y)a=r+\"L\"+i.substr(1)+\"Z\";else{var S=[A,v.c2p(w[0].t)],E=[A,v.c2p(w[k-1].t)];\"h\"===c.orientation&&(S.reverse(),E.reverse()),a=x?\"M\"+S+\"L\"+r.substr(1)+\"L\"+E:\"M\"+E+\"L\"+i.substr(1)+\"L\"+S}_.attr(\"d\",a),t.posCenterPx=A,t.posDensityScale=e*g,t.path=_.node(),t.pathLength=t.path.getTotalLength()/(y?2:1)});var w,k,T,A=c.box,M=A.width,S=(A.line||{}).width;y?(w=g*M,k=0):x?(w=[0,g*M/2],k=-S):(w=[g*M/2,0],k=S),o.plotBoxAndWhiskers(r,{pos:m,val:v},c,{bPos:d,bdPos:w,bPosPxOffset:k}),o.plotBoxMean(r,{pos:m,val:v},c,{bPos:d,bdPos:w,bPosPxOffset:k}),!c.box.visible&&c.meanline.visible&&(T=i.identity);var E=r.selectAll(\"path.meanline\").data(T||[]);E.enter().append(\"path\").attr(\"class\",\"meanline\").style(\"fill\",\"none\").style(\"vector-effect\",\"non-scaling-stroke\"),E.exit().remove(),E.each(function(t){var e=v.c2p(t.mean,!0),r=l.getPositionOnKdePath(t,c,e);n.select(this).attr(\"d\",\"h\"===c.orientation?\"M\"+e+\",\"+r[0]+\"V\"+r[1]:\"M\"+r[0]+\",\"+e+\"H\"+r[1])}),o.plotPoints(r,{x:h,y:f},c,s)}})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../box/plot\":889,\"../scatter/line_points\":1125,\"./helpers\":1242,d3:163}],1248:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../scatter/style\").stylePoints;e.exports=function(t){var e=n.select(t).selectAll(\"g.trace.violins\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.each(function(e){var r=e[0].trace,o=n.select(this),s=r.box||{},l=s.line||{},c=r.meanline||{},u=c.width;o.selectAll(\"path.violin\").style(\"stroke-width\",r.line.width+\"px\").call(i.stroke,r.line.color).call(i.fill,r.fillcolor),o.selectAll(\"path.box\").style(\"stroke-width\",l.width+\"px\").call(i.stroke,l.color).call(i.fill,s.fillcolor);var h={\"stroke-width\":u+\"px\",\"stroke-dasharray\":2*u+\"px,\"+u+\"px\"};o.selectAll(\"path.mean\").style(h).call(i.stroke,c.color),o.selectAll(\"path.meanline\").style(h).call(i.stroke,c.color),a(o,r,t)})}},{\"../../components/color\":593,\"../scatter/style\":1134,d3:163}],1249:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../isosurface/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=e.exports=s(o({x:i.x,y:i.y,z:i.z,value:i.value,isomin:i.isomin,isomax:i.isomax,surface:i.surface,spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:1}},slices:i.slices,caps:i.caps,text:i.text,hovertext:i.hovertext,hovertemplate:i.hovertemplate},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{colorbar:i.colorbar,opacity:i.opacity,opacityscale:{valType:\"any\",editType:\"calc\"},lightposition:i.lightposition,lighting:i.lighting,flatshading:i.flatshading,contour:i.contour,hoverinfo:o({},a.hoverinfo)}),\"calc\",\"nested\");l.x.editType=l.y.editType=l.z.editType=l.value.editType=\"calc+clearAxisTypes\",l.transforms=void 0},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../isosurface/attributes\":1048}],1250:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib/gl_format_color\").parseColorScale,a=t(\"../../lib/str2rgbarray\"),o=t(\"../../components/colorscale\").extractOpts,s=t(\"../../plots/gl3d/zip3\"),l=t(\"../isosurface/convert\").findNearestOnAxis,c=t(\"../isosurface/convert\").generateIsoMeshes;function u(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var h=u.prototype;h.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._x[e],n=this.data._y[e],i=this.data._z[e],a=this.data._Ys.length,o=this.data._Zs.length,s=l(r,this.data._Xs).id,c=l(n,this.data._Ys).id,u=l(i,this.data._Zs).id,h=t.index=u+o*c+o*a*s;t.traceCoordinate=[this.data._x[h],this.data._y[h],this.data._z[h],this.data.value[h]];var f=this.data.hovertext||this.data.text;return Array.isArray(f)&&void 0!==f[h]?t.textLabel=f[h]:f&&(t.textLabel=f),!0}},h.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map(function(e){return t.d2l(e,0,n)*r})}this.data=c(t);var l={positions:s(n(r.xaxis,t._x,e.dataScale[0],t.xcalendar),n(r.yaxis,t._y,e.dataScale[1],t.ycalendar),n(r.zaxis,t._z,e.dataScale[2],t.zcalendar)),cells:s(t._i,t._j,t._k),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,opacityscale:t.opacityscale,contourEnable:t.contour.show,contourColor:a(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},u=o(t);l.vertexIntensity=t._intensity,l.vertexIntensityBounds=[u.min,u.max],l.colormap=i(t),this.mesh.update(l)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new u(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":605,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../../plots/gl3d/zip3\":818,\"../isosurface/convert\":1050,\"gl-mesh3d\":280}],1251:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../isosurface/defaults\").supplyIsoDefaults;e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}a(t,e,r,o,s);var l=s(\"opacityscale\");\"max\"===l?e.opacityscale=[[0,.1],[1,1]]:\"min\"===l?e.opacityscale=[[0,1],[1,.1]]:\"extremes\"===l?e.opacityscale=function(t,e){for(var r=[],n=0;n<32;n++){var i=n/31,a=e+(1-e)*(1-Math.pow(Math.sin(t*i*Math.PI),2));r.push([i,Math.max(1,Math.min(0,a))])}return r}(1,.1):function(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var n=t[r];if(2!==n.length||+n[0]<e)return!1;e=+n[0]}return!0}(l)||(e.opacityscale=void 0)}},{\"../../lib\":719,\"../isosurface/defaults\":1051,\"./attributes\":1249}],1252:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../isosurface/calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"volume\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],meta:{}}},{\"../../plots/gl3d\":807,\"../isosurface/calc\":1049,\"./attributes\":1249,\"./convert\":1250,\"./defaults\":1251}],1253:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"./constants\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../components/color\");function u(t){return{marker:{color:l({},n.marker.color,{arrayOk:!1,editType:\"style\"}),line:{color:l({},n.marker.line.color,{arrayOk:!1,editType:\"style\"}),width:l({},n.marker.line.width,{arrayOk:!1,editType:\"style\"}),editType:\"style\"},editType:\"style\"},editType:\"style\"}}e.exports={measure:{valType:\"data_array\",dflt:[],editType:\"calc\"},base:{valType:\"number\",dflt:null,arrayOk:!1,editType:\"calc\"},x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,hovertext:n.hovertext,hovertemplate:o({},{keys:s.eventDataKeys}),hoverinfo:l({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"initial\",\"delta\",\"final\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"initial\",\"delta\",\"final\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},text:n.text,textposition:n.textposition,insidetextanchor:n.insidetextanchor,textangle:n.textangle,textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:n.orientation,offset:n.offset,width:n.width,increasing:u(),decreasing:u(),totals:u(),connector:{line:{color:l({},i.color,{dflt:c.defaultLine}),width:l({},i.width,{editType:\"plot\"}),dash:i.dash,editType:\"plot\"},mode:{valType:\"enumerated\",values:[\"spanning\",\"between\"],dflt:\"between\",editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":593,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../bar/attributes\":857,\"../scatter/attributes\":1112,\"./constants\":1255}],1254:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\").mergeArray,a=t(\"../scatter/calc_selection\"),o=t(\"../../constants/numerical\").BADNUM;function s(t){return\"a\"===t||\"absolute\"===t}function l(t){return\"t\"===t||\"total\"===t}e.exports=function(t,e){var r,c,u=n.getFromId(t,e.xaxis||\"x\"),h=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=u.makeCalcdata(e,\"x\"),c=h.makeCalcdata(e,\"y\")):(r=h.makeCalcdata(e,\"y\"),c=u.makeCalcdata(e,\"x\"));for(var f,p=Math.min(c.length,r.length),d=new Array(p),g=0,v=!1,m=0;m<p;m++){var y=r[m]||0,x=!1;(r[m]!==o||l(e.measure[m])||s(e.measure[m]))&&m+1<p&&(r[m+1]!==o||l(e.measure[m+1])||s(e.measure[m+1]))&&(x=!0);var b=d[m]={i:m,p:c[m],s:y,rawS:y,cNext:x};s(e.measure[m])?(g=b.s,b.isSum=!0,b.dir=\"totals\",b.s=g):l(e.measure[m])?(b.isSum=!0,b.dir=\"totals\",b.s=g):(b.isSum=!1,b.dir=b.rawS<0?\"decreasing\":\"increasing\",f=b.s,b.s=g+f,g+=f),\"totals\"===b.dir&&(v=!0),e.ids&&(b.id=String(e.ids[m])),b.v=(e.base||0)+g}return d.length&&(d[0].hasTotals=v),i(e.text,d,\"tx\"),i(e.hovertext,d,\"htx\"),a(d,e),d}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scatter/calc_selection\":1114}],1255:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"initial\",\"delta\",\"final\"]}},{}],1256:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],h=[],f=[];for(i=0;i<o.length;i++){var p=o[i];!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"waterfall\"===p.type&&(r=s[i],\"h\"===p.orientation?f.push(r):h.push(r),u.push(r))}var d={mode:a.waterfallmode,norm:a.waterfallnorm,gap:a.waterfallgap,groupgap:a.waterfallgroupgap};for(n(t,l,c,h,d),n(t,c,l,f,d),i=0;i<u.length;i++){r=u[i];for(var g=0;g<r.length;g++){var v=r[g];!1===v.isSum&&(v.s0+=0===g?0:r[g-1].s),g+1<r.length&&(r[g].nextP0=r[g+1].p0,r[g].nextS0=r[g+1].s0)}}}},{\"../bar/cross_trace_calc\":860}],1257:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"./attributes\"),l=t(\"../../components/color\"),c=t(\"../../constants/delta.js\"),u=c.INCREASING.COLOR,h=c.DECREASING.COLOR,f=\"#4499FF\";function p(t,e,r){t(e+\".marker.color\",r),t(e+\".marker.line.color\",l.defaultLine),t(e+\".marker.line.width\")}e.exports={supplyDefaults:function(t,e,r,i){function l(r,i){return n.coerce(t,e,s,r,i)}if(o(t,e,i,l)){l(\"measure\"),l(\"orientation\",e.x&&!e.y?\"h\":\"v\"),l(\"base\"),l(\"offset\"),l(\"width\"),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\");var c=l(\"textposition\");a(t,e,i,l,c,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"!==e.textposition&&l(\"textinfo\"),p(l,\"increasing\",u),p(l,\"decreasing\",h),p(l,\"totals\",f),l(\"connector.visible\")&&(l(\"connector.mode\"),l(\"connector.line.width\")&&(l(\"connector.line.color\"),l(\"connector.line.dash\")))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,s,t)}if(\"group\"===e.waterfallmode)for(var l=0;l<t.length;l++)r=(a=t[l])._input,i(r,a,e,o)}}},{\"../../components/color\":593,\"../../constants/delta.js\":689,\"../../lib\":719,\"../bar/defaults\":861,\"../scatter/xy_defaults\":1137,\"./attributes\":1253}],1258:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"initial\"in e&&(t.initial=e.initial),\"delta\"in e&&(t.delta=e.delta),\"final\"in e&&(t.final=e.final),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],1259:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\").hoverLabelText,i=t(\"../../components/color\").opacity,a=t(\"../bar/hover\").hoverOnBars,o=t(\"../../constants/delta.js\"),s=o.INCREASING.SYMBOL,l=o.DECREASING.SYMBOL;e.exports=function(t,e,r,o){var c=a(t,e,r,o);if(c){var u=c.cd,h=u[0].trace,f=\"h\"===h.orientation,p=f?t.xa:t.ya,d=u[c.index],g=d.isSum?d.b+d.s:d.rawS;if(!d.isSum){c.initial=d.b+d.s-g,c.delta=g,c.final=c.initial+c.delta;var v=w(Math.abs(c.delta));c.deltaLabel=g<0?\"(\"+v+\")\":v,c.finalLabel=w(c.final),c.initialLabel=w(c.initial)}var m=d.hi||h.hoverinfo,y=[];if(m&&\"none\"!==m&&\"skip\"!==m){var x=\"all\"===m,b=m.split(\"+\"),_=function(t){return x||-1!==b.indexOf(t)};d.isSum||(!_(\"final\")||_(f?\"x\":\"y\")||y.push(c.finalLabel),_(\"delta\")&&(g<0?y.push(c.deltaLabel+\" \"+l):y.push(c.deltaLabel+\" \"+s)),_(\"initial\")&&y.push(\"Initial: \"+c.initialLabel))}return y.length&&(c.extraText=y.join(\"<br>\")),c.color=function(t,e){var r=t[e.dir].marker,n=r.color,a=r.line.color,o=r.line.width;if(i(n))return n;if(i(a)&&o)return a}(h,d),[c]}function w(t){return n(p,t)}}},{\"../../components/color\":593,\"../../constants/delta.js\":689,\"../../plots/cartesian/axes\":767,\"../bar/hover\":863}],1260:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"waterfall\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../bar/select\":868,\"./attributes\":1253,\"./calc\":1254,\"./cross_trace_calc\":1256,\"./defaults\":1257,\"./event_data\":1258,\"./hover\":1259,\"./layout_attributes\":1261,\"./layout_defaults\":1262,\"./plot\":1263,\"./style\":1264}],1261:[function(t,e,r){\"use strict\";e.exports={waterfallmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"group\",editType:\"calc\"},waterfallgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},waterfallgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],1262:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"waterfall\"===l.type){a=!0;break}}a&&(o(\"waterfallmode\"),o(\"waterfallgap\",.2),o(\"waterfallgroupgap\"))}},{\"../../lib\":719,\"./layout_attributes\":1261}],1263:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../bar/plot\").plot;e.exports=function(t,e,r,s){var l=t._fullLayout;o(t,e,r,s,{mode:l.waterfallmode,norm:l.waterfallmode,gap:l.waterfallgap,groupgap:l.waterfallgroupgap}),function(t,e,r,o){var s=e.xaxis,l=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each(function(r){var o=n.select(this),c=r[0].trace,u=i.ensureSingle(o,\"g\",\"lines\");if(c.connector&&c.connector.visible){var h=\"h\"===c.orientation,f=c.connector.mode,p=u.selectAll(\"g.line\").data(i.identity);p.enter().append(\"g\").classed(\"line\",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var c=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),n?[i,a]:[a,i]}(r,s,l,h),u=c[0],p=c[1],g=\"\";\"spanning\"===f&&!r.isSum&&o>0&&(g+=h?\"M\"+u[0]+\",\"+p[1]+\"V\"+p[0]:\"M\"+u[1]+\",\"+p[0]+\"H\"+u[0]),\"between\"!==f&&(r.isSum||o<d-1)&&(g+=h?\"M\"+u[1]+\",\"+p[0]+\"V\"+p[1]:\"M\"+u[0]+\",\"+p[1]+\"H\"+u[1]),void 0!==u[2]&&void 0!==p[2]&&(g+=h?\"M\"+u[1]+\",\"+p[1]+\"V\"+p[2]:\"M\"+u[1]+\",\"+p[1]+\"H\"+u[2]),\"\"===g&&(g=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}})}else u.remove()})}(t,e,r,s)}},{\"../../components/drawing\":614,\"../../lib\":719,\"../bar/plot\":867,d3:163}],1264:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\").styleTextPoints;e.exports={style:function(t,e,r){var l=r||n.select(t).selectAll(\"g.waterfalllayer\").selectAll(\"g.trace\");l.style(\"opacity\",function(t){return t[0].trace.opacity}),l.each(function(e){var r=n.select(this),l=e[0].trace;r.selectAll(\".point > path\").each(function(t){if(!t.isBlank){var e=l[t.dir].marker;n.select(this).call(a.fill,e.color).call(a.stroke,e.line.color).call(i.dashLine,e.line.dash,e.line.width).style(\"opacity\",l.selectedpoints&&!t.selected?o:1)}}),s(r,l,t),r.selectAll(\".lines\").each(function(){var t=l.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)})})}}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../constants/interactions\":694,\"../bar/style\":870,d3:163}],1265:[function(t,e,r){\"use strict\";var n=t(\"../plots/cartesian/axes\"),i=t(\"../lib\"),a=t(\"../plot_api/plot_schema\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/numerical\").BADNUM;r.moduleType=\"transform\",r.name=\"aggregate\";var l=r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},aggregations:{_isLinkedToArray:\"aggregation\",target:{valType:\"string\",editType:\"calc\"},func:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"median\",\"mode\",\"rms\",\"stddev\",\"min\",\"max\",\"first\",\"last\",\"change\",\"range\"],dflt:\"first\",editType:\"calc\"},funcmode:{valType:\"enumerated\",values:[\"sample\",\"population\"],dflt:\"sample\",editType:\"calc\"},enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},c=l.aggregations;function u(t,e,r,a){if(a.enabled){for(var o=a.target,l=i.nestedProperty(e,o),c=l.get(),u=function(t,e){var r=t.func,n=e.d2c,i=e.c2d;switch(r){case\"count\":return h;case\"first\":return f;case\"last\":return p;case\"sum\":return function(t,e){for(var r=0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r+=o)}return i(r)};case\"avg\":return function(t,e){for(var r=0,a=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l,a++)}return a?i(r/a):s};case\"min\":return function(t,e){for(var r=1/0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r=Math.min(r,o))}return r===1/0?s:i(r)};case\"max\":return function(t,e){for(var r=-1/0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r=Math.max(r,o))}return r===-1/0?s:i(r)};case\"range\":return function(t,e){for(var r=1/0,a=-1/0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r=Math.min(r,l),a=Math.max(a,l))}return a===-1/0||r===1/0?s:i(a-r)};case\"change\":return function(t,e){var r=n(t[e[0]]),a=n(t[e[e.length-1]]);return r===s||a===s?s:i(a-r)};case\"median\":return function(t,e){for(var r=[],a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&r.push(o)}if(!r.length)return s;r.sort();var l=(r.length-1)/2;return i((r[Math.floor(l)]+r[Math.ceil(l)])/2)};case\"mode\":return function(t,e){for(var r={},a=0,o=s,l=0;l<e.length;l++){var c=n(t[e[l]]);if(c!==s){var u=r[c]=(r[c]||0)+1;u>a&&(a=u,o=c)}}return a?i(o):s};case\"rms\":return function(t,e){for(var r=0,a=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l*l,a++)}return a?i(Math.sqrt(r/a)):s};case\"stddev\":return function(e,r){var i,a=0,o=0,l=1,c=s;for(i=0;i<r.length&&c===s;i++)c=n(e[r[i]]);if(c===s)return s;for(;i<r.length;i++){var u=n(e[r[i]]);if(u!==s){var h=u-c;a+=h,o+=h*h,l++}}var f=\"sample\"===t.funcmode?l-1:l;return f?Math.sqrt((o-a*a/l)/f):0}}}(a,n.getDataConversions(t,e,o,c)),d=new Array(r.length),g=0;g<r.length;g++)d[g]=u(c,r[g]);l.set(d),\"count\"===a.func&&i.pushUnique(e._arrayAttrs,o)}}function h(t,e){return e.length}function f(t,e){return t[e[0]]}function p(t,e){return t[e[e.length-1]]}r.supplyDefaults=function(t,e){var r,n={};function o(e,r){return i.coerce(t,n,l,e,r)}if(!o(\"enabled\"))return n;var s=a.findArrayAttributes(e),u={};for(r=0;r<s.length;r++)u[s[r]]=1;var h=o(\"groups\");if(!Array.isArray(h)){if(!u[h])return n.enabled=!1,n;u[h]=0}var f,p=t.aggregations||[],d=n.aggregations=new Array(p.length);function g(t,e){return i.coerce(p[r],f,c,t,e)}for(r=0;r<p.length;r++){f={_index:r};var v=g(\"target\"),m=g(\"func\");g(\"enabled\")&&v&&(u[v]||\"count\"===m&&void 0===u[v])?(\"stddev\"===m&&g(\"funcmode\"),u[v]=0,d[r]=f):d[r]={enabled:!1,_index:r}}for(r=0;r<s.length;r++)u[s[r]]&&d.push({target:s[r],func:c.func.dflt,enabled:!0,_index:-1});return n},r.calcTransform=function(t,e,r){if(r.enabled){var n=r.groups,a=i.getTargetArray(e,{target:n});if(a){var s,l,c,h,f={},p={},d=[],g=o(e.transforms,r),v=a.length;for(e._length&&(v=Math.min(v,e._length)),s=0;s<v;s++)void 0===(c=f[l=a[s]])?(f[l]=d.length,h=[s],d.push(h),p[f[l]]=g(s)):(d[c].push(s),p[f[l]]=(p[f[l]]||[]).concat(g(s)));r._indexToPoints=p;var m=r.aggregations;for(s=0;s<m.length;s++)u(t,e,d,m[s]);\"string\"==typeof n&&u(t,e,d,{target:n,func:\"first\",enabled:!0}),e._length=d.length}}}},{\"../constants/numerical\":695,\"../lib\":719,\"../plot_api/plot_schema\":756,\"../plots/cartesian/axes\":767,\"./helpers\":1268}],1266:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../registry\"),a=t(\"../plots/cartesian/axes\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/filter_ops\"),l=s.COMPARISON_OPS,c=s.INTERVAL_OPS,u=s.SET_OPS;r.moduleType=\"transform\",r.name=\"filter\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},operation:{valType:\"enumerated\",values:[].concat(l).concat(c).concat(u),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},preservegaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function a(i,a){return n.coerce(t,e,r.attributes,i,a)}if(a(\"enabled\")){var o=a(\"target\");if(n.isArrayOrTypedArray(o)&&0===o.length)return e.enabled=!1,e;a(\"preservegaps\"),a(\"operation\"),a(\"value\");var s=i.getComponentMethod(\"calendars\",\"handleDefaults\");s(t,e,\"valuecalendar\",null),s(t,e,\"targetcalendar\",null)}return e},r.calcTransform=function(t,e,r){if(r.enabled){var i=n.getTargetArray(e,r);if(i){var s=r.target,h=i.length;e._length&&(h=Math.min(h,e._length));var f=r.targetcalendar,p=e._arrayAttrs,d=r.preservegaps;if(\"string\"==typeof s){var g=n.nestedProperty(e,s+\"calendar\").get();g&&(f=g)}var v,m,y=function(t,e,r){var n=t.operation,i=t.value,a=Array.isArray(i);function o(t){return-1!==t.indexOf(n)}var s,h=function(r){return e(r,0,t.valuecalendar)},f=function(t){return e(t,0,r)};o(l)?s=h(a?i[0]:i):o(c)?s=a?[h(i[0]),h(i[1])]:[h(i),h(i)]:o(u)&&(s=a?i.map(h):[h(i)]);switch(n){case\"=\":return function(t){return f(t)===s};case\"!=\":return function(t){return f(t)!==s};case\"<\":return function(t){return f(t)<s};case\"<=\":return function(t){return f(t)<=s};case\">\":return function(t){return f(t)>s};case\">=\":return function(t){return f(t)>=s};case\"[]\":return function(t){var e=f(t);return e>=s[0]&&e<=s[1]};case\"()\":return function(t){var e=f(t);return e>s[0]&&e<s[1]};case\"[)\":return function(t){var e=f(t);return e>=s[0]&&e<s[1]};case\"(]\":return function(t){var e=f(t);return e>s[0]&&e<=s[1]};case\"][\":return function(t){var e=f(t);return e<=s[0]||e>=s[1]};case\")(\":return function(t){var e=f(t);return e<s[0]||e>s[1]};case\"](\":return function(t){var e=f(t);return e<=s[0]||e>s[1]};case\")[\":return function(t){var e=f(t);return e<s[0]||e>=s[1]};case\"{}\":return function(t){return-1!==s.indexOf(f(t))};case\"}{\":return function(t){return-1===s.indexOf(f(t))}}}(r,a.getDataToCoordFunc(t,e,s,i),f),x={},b={},_=0;d?(v=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set(new Array(h))},m=function(t,e){var r=x[t.astr][e];t.get()[e]=r}):(v=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set([])},m=function(t,e){var r=x[t.astr][e];t.get().push(r)}),T(v);for(var w=o(e.transforms,r),k=0;k<h;k++){y(i[k])?(T(m,k),b[_++]=w(k)):d&&_++}r._indexToPoints=b,e._length=_}}function T(t,r){for(var i=0;i<p.length;i++){t(n.nestedProperty(e,p[i]),r)}}}},{\"../constants/filter_ops\":691,\"../lib\":719,\"../plots/cartesian/axes\":767,\"../registry\":847,\"./helpers\":1268}],1267:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_schema\"),a=t(\"../plots/plots\"),o=t(\"./helpers\").pointsAccessorFunction;function s(t,e){var r,s,l,c,u,h,f,p,d,g,v=e.transform,m=e.transformIndex,y=t.transforms[m].groups,x=o(t.transforms,v);if(!Array.isArray(y)||0===y.length)return[t];var b=n.filterUnique(y),_=new Array(b.length),w=y.length,k=i.findArrayAttributes(t),T=v.styles||[],A={};for(r=0;r<T.length;r++)A[T[r].target]=T[r].value;v.styles&&(g=n.keyedContainer(v,\"styles\",\"target\",\"value.name\"));var M={},S={};for(r=0;r<b.length;r++){M[h=b[r]]=r,S[h]=0,(f=_[r]=n.extendDeepNoArrays({},t))._group=h,f.transforms[m]._indexToPoints={};var E=null;for(g&&(E=g.get(h)),f.name=E||\"\"===E?E:n.templateString(v.nameformat,{trace:t.name,group:h}),p=f.transforms,f.transforms=[],s=0;s<p.length;s++)f.transforms[s]=n.extendDeepNoArrays({},p[s]);for(s=0;s<k.length;s++)n.nestedProperty(f,k[s]).set([])}for(l=0;l<k.length;l++){for(c=k[l],s=0,d=[];s<b.length;s++)d[s]=n.nestedProperty(_[s],c).get();for(u=n.nestedProperty(t,c).get(),s=0;s<w;s++)d[M[y[s]]].push(u[s])}for(s=0;s<w;s++){(f=_[M[y[s]]]).transforms[m]._indexToPoints[S[y[s]]]=x(s),S[y[s]]++}for(r=0;r<b.length;r++)h=b[r],f=_[r],a.clearExpandedTraceDefaultColors(f),f=n.extendDeepNoArrays(f,A[h]||{});return _}r.moduleType=\"transform\",r.name=\"groupby\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"data_array\",dflt:[],editType:\"calc\"},nameformat:{valType:\"string\",editType:\"calc\"},styles:{_isLinkedToArray:\"style\",target:{valType:\"string\",editType:\"calc\"},value:{valType:\"any\",dflt:{},editType:\"calc\",_compareAsJSON:!0},editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t,e,i){var a,o={};function s(e,i){return n.coerce(t,o,r.attributes,e,i)}if(!s(\"enabled\"))return o;s(\"groups\"),s(\"nameformat\",i._dataLength>1?\"%{group} (%{trace})\":\"%{group}\");var l=t.styles,c=o.styles=[];if(l)for(a=0;a<l.length;a++){var u=c[a]={};n.coerce(l[a],c[a],r.attributes.styles,\"target\");var h=n.coerce(l[a],c[a],r.attributes.styles,\"value\");n.isPlainObject(h)?u.value=n.extendDeep({},h):h&&delete u.value}return o},r.transform=function(t,e){var r,n,i,a=[];for(n=0;n<t.length;n++)for(r=s(t[n],e),i=0;i<r.length;i++)a.push(r[i]);return a}},{\"../lib\":719,\"../plot_api/plot_schema\":756,\"../plots/plots\":828,\"./helpers\":1268}],1268:[function(t,e,r){\"use strict\";r.pointsAccessorFunction=function(t,e){for(var r,n,i=0;i<t.length&&(r=t[i])!==e;i++)r._indexToPoints&&!1!==r.enabled&&(n=r._indexToPoints);return n?function(t){return n[t]}:function(t){return[t]}}},{}],1269:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/cartesian/axes\"),a=t(\"./helpers\").pointsAccessorFunction;r.moduleType=\"transform\",r.name=\"sort\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},order:{valType:\"enumerated\",values:[\"ascending\",\"descending\"],dflt:\"ascending\",editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function i(i,a){return n.coerce(t,e,r.attributes,i,a)}return i(\"enabled\")&&(i(\"target\"),i(\"order\")),e},r.calcTransform=function(t,e,r){if(r.enabled){var o=n.getTargetArray(e,r);if(o){var s=r.target,l=o.length;e._length&&(l=Math.min(l,e._length));var c,u,h=e._arrayAttrs,f=function(t,e,r,n){var i,a=new Array(n),o=new Array(n);for(i=0;i<n;i++)a[i]={v:e[i],i:i};for(a.sort(function(t,e){switch(t.order){case\"ascending\":return function(t,r){return e(t.v)-e(r.v)};case\"descending\":return function(t,r){return e(r.v)-e(t.v)}}}(t,r)),i=0;i<n;i++)o[i]=a[i].i;return o}(r,o,i.getDataToCoordFunc(t,e,s,o),l),p=a(e.transforms,r),d={};for(c=0;c<h.length;c++){var g=n.nestedProperty(e,h[c]),v=g.get(),m=new Array(l);for(u=0;u<l;u++)m[u]=v[f[u]];g.set(m)}for(u=0;u<l;u++)d[u]=p(f[u]);r._indexToPoints=d,e._length=l}}}},{\"../lib\":719,\"../plots/cartesian/axes\":767,\"./helpers\":1268}]},{},[25])(25)});</script>    \n",
       "            <div id=\"7b5531dc-592b-47e9-98d6-571111d84464\" class=\"plotly-graph-div\" style=\"height:500px; width:500px;\"></div>\n",
       "            <script type=\"text/javascript\">\n",
       "                \n",
       "                    window.PLOTLYENV=window.PLOTLYENV || {};\n",
       "                    \n",
       "                if (document.getElementById(\"7b5531dc-592b-47e9-98d6-571111d84464\")) {\n",
       "                    Plotly.newPlot(\n",
       "                        '7b5531dc-592b-47e9-98d6-571111d84464',\n",
       "                        [{\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 2\", \"showscale\": false, \"type\": \"surface\", \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.010000000000000002, 0.020000000000000004, 0.030000000000000006, 0.04000000000000001, 0.05, 0.06000000000000001, 0.07, 0.08000000000000002, 0.09000000000000001, 0.1, 0.11000000000000001, 0.12000000000000002, 0.13, 0.14, 0.15000000000000002, 0.16000000000000003, 0.17000000000000004, 0.18000000000000002, 0.19000000000000003, 0.2, 0.21000000000000002, 0.22000000000000003, 0.23000000000000004, 0.24000000000000005, 0.25, 0.26, 0.27, 0.28, 0.29000000000000004, 0.30000000000000004, 0.31000000000000005, 0.32000000000000006, 0.33000000000000007, 0.3400000000000001, 0.35000000000000003, 0.36000000000000004, 0.37000000000000005, 0.38000000000000006, 0.39000000000000007, 0.4, 0.4100000000000001, 0.42000000000000004, 0.43, 0.44000000000000006, 0.45, 0.4600000000000001, 0.47000000000000003, 0.4800000000000001, 0.49000000000000005, 0.5, 0.5100000000000001, 0.52, 0.5300000000000001, 0.54, 0.55, 0.56, 0.5700000000000001, 0.5800000000000001, 0.5900000000000001, 0.6000000000000001, 0.6100000000000001, 0.6200000000000001, 0.6300000000000001, 0.6400000000000001, 0.65, 0.6600000000000001, 0.67, 0.6800000000000002, 0.6900000000000001, 0.7000000000000001, 0.7100000000000001, 0.7200000000000001, 0.7300000000000001, 0.7400000000000001, 0.75, 0.7600000000000001, 0.77, 0.7800000000000001, 0.79, 0.8, 0.81, 0.8200000000000002, 0.8300000000000001, 0.8400000000000001, 0.8500000000000001, 0.86, 0.8700000000000001, 0.8800000000000001, 0.8900000000000001, 0.9, 0.91, 0.9200000000000002, 0.9300000000000002, 0.9400000000000001, 0.9500000000000001, 0.9600000000000002, 0.9700000000000002, 0.9800000000000001, 0.9900000000000001, 1.0, 1.0100000000000002], [0.0, 0.020000000000000004, 0.04000000000000001, 0.06000000000000001, 0.08000000000000002, 0.1, 0.12000000000000002, 0.14, 0.16000000000000003, 0.18000000000000002, 0.2, 0.22000000000000003, 0.24000000000000005, 0.26, 0.28, 0.30000000000000004, 0.32000000000000006, 0.3400000000000001, 0.36000000000000004, 0.38000000000000006, 0.4, 0.42000000000000004, 0.44000000000000006, 0.4600000000000001, 0.4800000000000001, 0.5, 0.52, 0.54, 0.56, 0.5800000000000001, 0.6000000000000001, 0.6200000000000001, 0.6400000000000001, 0.6600000000000001, 0.6800000000000002, 0.7000000000000001, 0.7200000000000001, 0.7400000000000001, 0.7600000000000001, 0.7800000000000001, 0.8, 0.8200000000000002, 0.8400000000000001, 0.86, 0.8800000000000001, 0.9, 0.9200000000000002, 0.9400000000000001, 0.9600000000000002, 0.9800000000000001, 1.0, 1.0200000000000002, 1.04, 1.0600000000000003, 1.08, 1.1, 1.12, 1.1400000000000001, 1.1600000000000001, 1.1800000000000002, 1.2000000000000002, 1.2200000000000002, 1.2400000000000002, 1.2600000000000002, 1.2800000000000002, 1.3, 1.3200000000000003, 1.34, 1.3600000000000003, 1.3800000000000001, 1.4000000000000001, 1.4200000000000002, 1.4400000000000002, 1.4600000000000002, 1.4800000000000002, 1.5, 1.5200000000000002, 1.54, 1.5600000000000003, 1.58, 1.6, 1.62, 1.6400000000000003, 1.6600000000000001, 1.6800000000000002, 1.7000000000000002, 1.72, 1.7400000000000002, 1.7600000000000002, 1.7800000000000002, 1.8, 1.82, 1.8400000000000003, 1.8600000000000003, 1.8800000000000001, 1.9000000000000001, 1.9200000000000004, 1.9400000000000004, 1.9600000000000002, 1.9800000000000002, 2.0, 2.0200000000000005], [0.0, 0.030000000000000006, 0.06000000000000001, 0.09000000000000002, 0.12000000000000002, 0.15000000000000002, 0.18000000000000005, 0.21000000000000005, 0.24000000000000005, 0.2700000000000001, 0.30000000000000004, 0.33000000000000007, 0.3600000000000001, 0.39000000000000007, 0.4200000000000001, 0.45000000000000007, 0.4800000000000001, 0.5100000000000001, 0.5400000000000001, 0.5700000000000002, 0.6000000000000001, 0.6300000000000001, 0.6600000000000001, 0.6900000000000002, 0.7200000000000002, 0.7500000000000001, 0.7800000000000001, 0.8100000000000002, 0.8400000000000002, 0.8700000000000002, 0.9000000000000001, 0.9300000000000002, 0.9600000000000002, 0.9900000000000002, 1.0200000000000002, 1.0500000000000003, 1.0800000000000003, 1.1100000000000003, 1.1400000000000003, 1.1700000000000004, 1.2000000000000002, 1.2300000000000004, 1.2600000000000002, 1.29, 1.3200000000000003, 1.35, 1.3800000000000003, 1.4100000000000004, 1.4400000000000004, 1.4700000000000004, 1.5000000000000002, 1.5300000000000005, 1.5600000000000003, 1.5900000000000005, 1.6200000000000003, 1.6500000000000004, 1.6800000000000004, 1.7100000000000004, 1.7400000000000004, 1.7700000000000005, 1.8000000000000003, 1.8300000000000005, 1.8600000000000003, 1.8900000000000006, 1.9200000000000004, 1.9500000000000002, 1.9800000000000004, 2.0100000000000002, 2.0400000000000005, 2.0700000000000003, 2.1000000000000005, 2.1300000000000003, 2.1600000000000006, 2.1900000000000004, 2.2200000000000006, 2.2500000000000004, 2.2800000000000007, 2.3100000000000005, 2.3400000000000007, 2.3700000000000006, 2.4000000000000004, 2.43, 2.460000000000001, 2.4900000000000007, 2.5200000000000005, 2.5500000000000003, 2.58, 2.6100000000000008, 2.6400000000000006, 2.6700000000000004, 2.7, 2.7300000000000004, 2.7600000000000007, 2.7900000000000005, 2.8200000000000007, 2.8500000000000005, 2.880000000000001, 2.9100000000000006, 2.940000000000001, 2.9700000000000006, 3.0000000000000004, 3.0300000000000007], [0.0, 0.04000000000000001, 0.08000000000000002, 0.12000000000000002, 0.16000000000000003, 0.2, 0.24000000000000005, 0.28, 0.32000000000000006, 0.36000000000000004, 0.4, 0.44000000000000006, 0.4800000000000001, 0.52, 0.56, 0.6000000000000001, 0.6400000000000001, 0.6800000000000002, 0.7200000000000001, 0.7600000000000001, 0.8, 0.8400000000000001, 0.8800000000000001, 0.9200000000000002, 0.9600000000000002, 1.0, 1.04, 1.08, 1.12, 1.1600000000000001, 1.2000000000000002, 1.2400000000000002, 1.2800000000000002, 1.3200000000000003, 1.3600000000000003, 1.4000000000000001, 1.4400000000000002, 1.4800000000000002, 1.5200000000000002, 1.5600000000000003, 1.6, 1.6400000000000003, 1.6800000000000002, 1.72, 1.7600000000000002, 1.8, 1.8400000000000003, 1.8800000000000001, 1.9200000000000004, 1.9600000000000002, 2.0, 2.0400000000000005, 2.08, 2.1200000000000006, 2.16, 2.2, 2.24, 2.2800000000000002, 2.3200000000000003, 2.3600000000000003, 2.4000000000000004, 2.4400000000000004, 2.4800000000000004, 2.5200000000000005, 2.5600000000000005, 2.6, 2.6400000000000006, 2.68, 2.7200000000000006, 2.7600000000000002, 2.8000000000000003, 2.8400000000000003, 2.8800000000000003, 2.9200000000000004, 2.9600000000000004, 3.0, 3.0400000000000005, 3.08, 3.1200000000000006, 3.16, 3.2, 3.24, 3.2800000000000007, 3.3200000000000003, 3.3600000000000003, 3.4000000000000004, 3.44, 3.4800000000000004, 3.5200000000000005, 3.5600000000000005, 3.6, 3.64, 3.6800000000000006, 3.7200000000000006, 3.7600000000000002, 3.8000000000000003, 3.8400000000000007, 3.880000000000001, 3.9200000000000004, 3.9600000000000004, 4.0, 4.040000000000001], [0.0, 0.05, 0.1, 0.15000000000000002, 0.2, 0.25, 0.30000000000000004, 0.35000000000000003, 0.4, 0.45, 0.5, 0.55, 0.6000000000000001, 0.65, 0.7000000000000001, 0.75, 0.8, 0.8500000000000001, 0.9, 0.9500000000000001, 1.0, 1.05, 1.1, 1.1500000000000001, 1.2000000000000002, 1.25, 1.3, 1.35, 1.4000000000000001, 1.4500000000000002, 1.5, 1.55, 1.6, 1.6500000000000001, 1.7000000000000002, 1.75, 1.8, 1.85, 1.9000000000000001, 1.9500000000000002, 2.0, 2.0500000000000003, 2.1, 2.15, 2.2, 2.25, 2.3000000000000003, 2.35, 2.4000000000000004, 2.45, 2.5, 2.5500000000000003, 2.6, 2.6500000000000004, 2.7, 2.75, 2.8000000000000003, 2.85, 2.9000000000000004, 2.95, 3.0, 3.0500000000000003, 3.1, 3.1500000000000004, 3.2, 3.25, 3.3000000000000003, 3.35, 3.4000000000000004, 3.45, 3.5, 3.5500000000000003, 3.6, 3.6500000000000004, 3.7, 3.75, 3.8000000000000003, 3.85, 3.9000000000000004, 3.95, 4.0, 4.05, 4.1000000000000005, 4.15, 4.2, 4.25, 4.3, 4.3500000000000005, 4.4, 4.45, 4.5, 4.55, 4.6000000000000005, 4.65, 4.7, 4.75, 4.800000000000001, 4.8500000000000005, 4.9, 4.95, 5.0, 5.050000000000001], [0.0, 0.06000000000000001, 0.12000000000000002, 0.18000000000000005, 0.24000000000000005, 0.30000000000000004, 0.3600000000000001, 0.4200000000000001, 0.4800000000000001, 0.5400000000000001, 0.6000000000000001, 0.6600000000000001, 0.7200000000000002, 0.7800000000000001, 0.8400000000000002, 0.9000000000000001, 0.9600000000000002, 1.0200000000000002, 1.0800000000000003, 1.1400000000000003, 1.2000000000000002, 1.2600000000000002, 1.3200000000000003, 1.3800000000000003, 1.4400000000000004, 1.5000000000000002, 1.5600000000000003, 1.6200000000000003, 1.6800000000000004, 1.7400000000000004, 1.8000000000000003, 1.8600000000000003, 1.9200000000000004, 1.9800000000000004, 2.0400000000000005, 2.1000000000000005, 2.1600000000000006, 2.2200000000000006, 2.2800000000000007, 2.3400000000000007, 2.4000000000000004, 2.460000000000001, 2.5200000000000005, 2.58, 2.6400000000000006, 2.7, 2.7600000000000007, 2.8200000000000007, 2.880000000000001, 2.940000000000001, 3.0000000000000004, 3.060000000000001, 3.1200000000000006, 3.180000000000001, 3.2400000000000007, 3.3000000000000007, 3.3600000000000008, 3.420000000000001, 3.480000000000001, 3.540000000000001, 3.6000000000000005, 3.660000000000001, 3.7200000000000006, 3.780000000000001, 3.8400000000000007, 3.9000000000000004, 3.960000000000001, 4.0200000000000005, 4.080000000000001, 4.140000000000001, 4.200000000000001, 4.260000000000001, 4.320000000000001, 4.380000000000001, 4.440000000000001, 4.500000000000001, 4.560000000000001, 4.620000000000001, 4.6800000000000015, 4.740000000000001, 4.800000000000001, 4.86, 4.920000000000002, 4.980000000000001, 5.040000000000001, 5.1000000000000005, 5.16, 5.2200000000000015, 5.280000000000001, 5.340000000000001, 5.4, 5.460000000000001, 5.520000000000001, 5.580000000000001, 5.6400000000000015, 5.700000000000001, 5.760000000000002, 5.820000000000001, 5.880000000000002, 5.940000000000001, 6.000000000000001, 6.060000000000001], [0.0, 0.07, 0.14, 0.21000000000000005, 0.28, 0.35000000000000003, 0.4200000000000001, 0.4900000000000001, 0.56, 0.6300000000000001, 0.7000000000000001, 0.7700000000000001, 0.8400000000000002, 0.9100000000000001, 0.9800000000000002, 1.05, 1.12, 1.1900000000000002, 1.2600000000000002, 1.3300000000000003, 1.4000000000000001, 1.4700000000000002, 1.5400000000000003, 1.6100000000000003, 1.6800000000000004, 1.7500000000000002, 1.8200000000000003, 1.8900000000000003, 1.9600000000000004, 2.0300000000000002, 2.1, 2.1700000000000004, 2.24, 2.3100000000000005, 2.3800000000000003, 2.45, 2.5200000000000005, 2.5900000000000003, 2.6600000000000006, 2.7300000000000004, 2.8000000000000003, 2.8700000000000006, 2.9400000000000004, 3.0100000000000002, 3.0800000000000005, 3.1500000000000004, 3.2200000000000006, 3.2900000000000005, 3.3600000000000008, 3.4300000000000006, 3.5000000000000004, 3.5700000000000007, 3.6400000000000006, 3.710000000000001, 3.7800000000000007, 3.8500000000000005, 3.920000000000001, 3.9900000000000007, 4.0600000000000005, 4.130000000000001, 4.2, 4.2700000000000005, 4.340000000000001, 4.410000000000001, 4.48, 4.550000000000001, 4.620000000000001, 4.69, 4.760000000000001, 4.830000000000001, 4.9, 4.970000000000001, 5.040000000000001, 5.110000000000001, 5.180000000000001, 5.250000000000001, 5.320000000000001, 5.390000000000001, 5.460000000000001, 5.530000000000001, 5.6000000000000005, 5.67, 5.740000000000001, 5.810000000000001, 5.880000000000001, 5.95, 6.0200000000000005, 6.090000000000002, 6.160000000000001, 6.23, 6.300000000000001, 6.37, 6.440000000000001, 6.510000000000001, 6.580000000000001, 6.65, 6.7200000000000015, 6.790000000000002, 6.860000000000001, 6.930000000000001, 7.000000000000001, 7.070000000000002], [0.0, 0.08000000000000002, 0.16000000000000003, 0.24000000000000005, 0.32000000000000006, 0.4, 0.4800000000000001, 0.56, 0.6400000000000001, 0.7200000000000001, 0.8, 0.8800000000000001, 0.9600000000000002, 1.04, 1.12, 1.2000000000000002, 1.2800000000000002, 1.3600000000000003, 1.4400000000000002, 1.5200000000000002, 1.6, 1.6800000000000002, 1.7600000000000002, 1.8400000000000003, 1.9200000000000004, 2.0, 2.08, 2.16, 2.24, 2.3200000000000003, 2.4000000000000004, 2.4800000000000004, 2.5600000000000005, 2.6400000000000006, 2.7200000000000006, 2.8000000000000003, 2.8800000000000003, 2.9600000000000004, 3.0400000000000005, 3.1200000000000006, 3.2, 3.2800000000000007, 3.3600000000000003, 3.44, 3.5200000000000005, 3.6, 3.6800000000000006, 3.7600000000000002, 3.8400000000000007, 3.9200000000000004, 4.0, 4.080000000000001, 4.16, 4.240000000000001, 4.32, 4.4, 4.48, 4.5600000000000005, 4.640000000000001, 4.720000000000001, 4.800000000000001, 4.880000000000001, 4.960000000000001, 5.040000000000001, 5.120000000000001, 5.2, 5.280000000000001, 5.36, 5.440000000000001, 5.5200000000000005, 5.6000000000000005, 5.680000000000001, 5.760000000000001, 5.840000000000001, 5.920000000000001, 6.0, 6.080000000000001, 6.16, 6.240000000000001, 6.32, 6.4, 6.48, 6.560000000000001, 6.640000000000001, 6.720000000000001, 6.800000000000001, 6.88, 6.960000000000001, 7.040000000000001, 7.120000000000001, 7.2, 7.28, 7.360000000000001, 7.440000000000001, 7.5200000000000005, 7.6000000000000005, 7.6800000000000015, 7.760000000000002, 7.840000000000001, 7.920000000000001, 8.0, 8.080000000000002], [0.0, 0.09000000000000001, 0.18000000000000002, 0.2700000000000001, 0.36000000000000004, 0.45, 0.5400000000000001, 0.6300000000000001, 0.7200000000000001, 0.81, 0.9, 0.9900000000000001, 1.0800000000000003, 1.1700000000000002, 1.2600000000000002, 1.35, 1.4400000000000002, 1.5300000000000002, 1.62, 1.7100000000000002, 1.8, 1.8900000000000001, 1.9800000000000002, 2.0700000000000003, 2.1600000000000006, 2.25, 2.3400000000000003, 2.43, 2.5200000000000005, 2.6100000000000003, 2.7, 2.79, 2.8800000000000003, 2.97, 3.0600000000000005, 3.15, 3.24, 3.33, 3.4200000000000004, 3.5100000000000002, 3.6, 3.6900000000000004, 3.7800000000000002, 3.87, 3.9600000000000004, 4.05, 4.140000000000001, 4.23, 4.320000000000001, 4.41, 4.5, 4.590000000000001, 4.680000000000001, 4.7700000000000005, 4.86, 4.95, 5.040000000000001, 5.13, 5.220000000000001, 5.3100000000000005, 5.4, 5.49, 5.58, 5.670000000000001, 5.760000000000001, 5.8500000000000005, 5.94, 6.03, 6.120000000000001, 6.210000000000001, 6.3, 6.390000000000001, 6.48, 6.570000000000001, 6.66, 6.75, 6.840000000000001, 6.930000000000001, 7.0200000000000005, 7.11, 7.2, 7.29, 7.380000000000001, 7.470000000000001, 7.5600000000000005, 7.65, 7.74, 7.830000000000001, 7.920000000000001, 8.01, 8.1, 8.19, 8.280000000000001, 8.370000000000001, 8.46, 8.55, 8.640000000000002, 8.73, 8.82, 8.91, 9.0, 9.090000000000002], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.11000000000000001, 0.22000000000000003, 0.33000000000000007, 0.44000000000000006, 0.55, 0.6600000000000001, 0.7700000000000001, 0.8800000000000001, 0.9900000000000001, 1.1, 1.2100000000000002, 1.3200000000000003, 1.4300000000000002, 1.5400000000000003, 1.6500000000000001, 1.7600000000000002, 1.8700000000000003, 1.9800000000000002, 2.0900000000000003, 2.2, 2.3100000000000005, 2.4200000000000004, 2.5300000000000007, 2.6400000000000006, 2.75, 2.8600000000000003, 2.9700000000000006, 3.0800000000000005, 3.190000000000001, 3.3000000000000003, 3.4100000000000006, 3.5200000000000005, 3.630000000000001, 3.7400000000000007, 3.8500000000000005, 3.9600000000000004, 4.07, 4.180000000000001, 4.290000000000001, 4.4, 4.510000000000001, 4.620000000000001, 4.73, 4.840000000000001, 4.95, 5.060000000000001, 5.170000000000001, 5.280000000000001, 5.390000000000001, 5.5, 5.610000000000001, 5.720000000000001, 5.830000000000001, 5.940000000000001, 6.050000000000001, 6.160000000000001, 6.2700000000000005, 6.380000000000002, 6.490000000000001, 6.6000000000000005, 6.710000000000001, 6.820000000000001, 6.9300000000000015, 7.040000000000001, 7.15, 7.260000000000002, 7.370000000000001, 7.480000000000001, 7.590000000000001, 7.700000000000001, 7.810000000000001, 7.920000000000001, 8.030000000000001, 8.14, 8.25, 8.360000000000001, 8.47, 8.580000000000002, 8.690000000000001, 8.8, 8.91, 9.020000000000001, 9.13, 9.240000000000002, 9.350000000000001, 9.46, 9.570000000000002, 9.680000000000001, 9.790000000000001, 9.9, 10.01, 10.120000000000003, 10.230000000000002, 10.340000000000002, 10.450000000000001, 10.560000000000002, 10.670000000000002, 10.780000000000001, 10.89, 11.0, 11.110000000000003], [0.0, 0.12000000000000002, 0.24000000000000005, 0.3600000000000001, 0.4800000000000001, 0.6000000000000001, 0.7200000000000002, 0.8400000000000002, 0.9600000000000002, 1.0800000000000003, 1.2000000000000002, 1.3200000000000003, 1.4400000000000004, 1.5600000000000003, 1.6800000000000004, 1.8000000000000003, 1.9200000000000004, 2.0400000000000005, 2.1600000000000006, 2.2800000000000007, 2.4000000000000004, 2.5200000000000005, 2.6400000000000006, 2.7600000000000007, 2.880000000000001, 3.0000000000000004, 3.1200000000000006, 3.2400000000000007, 3.3600000000000008, 3.480000000000001, 3.6000000000000005, 3.7200000000000006, 3.8400000000000007, 3.960000000000001, 4.080000000000001, 4.200000000000001, 4.320000000000001, 4.440000000000001, 4.560000000000001, 4.6800000000000015, 4.800000000000001, 4.920000000000002, 5.040000000000001, 5.16, 5.280000000000001, 5.4, 5.520000000000001, 5.6400000000000015, 5.760000000000002, 5.880000000000002, 6.000000000000001, 6.120000000000002, 6.240000000000001, 6.360000000000002, 6.480000000000001, 6.600000000000001, 6.7200000000000015, 6.840000000000002, 6.960000000000002, 7.080000000000002, 7.200000000000001, 7.320000000000002, 7.440000000000001, 7.560000000000002, 7.6800000000000015, 7.800000000000001, 7.920000000000002, 8.040000000000001, 8.160000000000002, 8.280000000000001, 8.400000000000002, 8.520000000000001, 8.640000000000002, 8.760000000000002, 8.880000000000003, 9.000000000000002, 9.120000000000003, 9.240000000000002, 9.360000000000003, 9.480000000000002, 9.600000000000001, 9.72, 9.840000000000003, 9.960000000000003, 10.080000000000002, 10.200000000000001, 10.32, 10.440000000000003, 10.560000000000002, 10.680000000000001, 10.8, 10.920000000000002, 11.040000000000003, 11.160000000000002, 11.280000000000003, 11.400000000000002, 11.520000000000003, 11.640000000000002, 11.760000000000003, 11.880000000000003, 12.000000000000002, 12.120000000000003], [0.0, 0.13, 0.26, 0.39000000000000007, 0.52, 0.65, 0.7800000000000001, 0.9100000000000001, 1.04, 1.1700000000000002, 1.3, 1.4300000000000002, 1.5600000000000003, 1.6900000000000002, 1.8200000000000003, 1.9500000000000002, 2.08, 2.2100000000000004, 2.3400000000000003, 2.47, 2.6, 2.7300000000000004, 2.8600000000000003, 2.9900000000000007, 3.1200000000000006, 3.25, 3.3800000000000003, 3.5100000000000002, 3.6400000000000006, 3.7700000000000005, 3.9000000000000004, 4.03, 4.16, 4.290000000000001, 4.420000000000001, 4.55, 4.680000000000001, 4.8100000000000005, 4.94, 5.07, 5.2, 5.330000000000001, 5.460000000000001, 5.59, 5.720000000000001, 5.8500000000000005, 5.980000000000001, 6.11, 6.240000000000001, 6.370000000000001, 6.5, 6.630000000000001, 6.760000000000001, 6.8900000000000015, 7.0200000000000005, 7.15, 7.280000000000001, 7.41, 7.540000000000001, 7.670000000000001, 7.800000000000001, 7.930000000000001, 8.06, 8.190000000000001, 8.32, 8.450000000000001, 8.580000000000002, 8.71, 8.840000000000002, 8.97, 9.1, 9.23, 9.360000000000001, 9.490000000000002, 9.620000000000001, 9.75, 9.88, 10.01, 10.14, 10.270000000000001, 10.4, 10.53, 10.660000000000002, 10.790000000000001, 10.920000000000002, 11.05, 11.18, 11.310000000000002, 11.440000000000001, 11.57, 11.700000000000001, 11.83, 11.960000000000003, 12.090000000000002, 12.22, 12.35, 12.480000000000002, 12.610000000000001, 12.740000000000002, 12.870000000000001, 13.0, 13.130000000000003], [0.0, 0.14, 0.28, 0.4200000000000001, 0.56, 0.7000000000000001, 0.8400000000000002, 0.9800000000000002, 1.12, 1.2600000000000002, 1.4000000000000001, 1.5400000000000003, 1.6800000000000004, 1.8200000000000003, 1.9600000000000004, 2.1, 2.24, 2.3800000000000003, 2.5200000000000005, 2.6600000000000006, 2.8000000000000003, 2.9400000000000004, 3.0800000000000005, 3.2200000000000006, 3.3600000000000008, 3.5000000000000004, 3.6400000000000006, 3.7800000000000007, 3.920000000000001, 4.0600000000000005, 4.2, 4.340000000000001, 4.48, 4.620000000000001, 4.760000000000001, 4.9, 5.040000000000001, 5.180000000000001, 5.320000000000001, 5.460000000000001, 5.6000000000000005, 5.740000000000001, 5.880000000000001, 6.0200000000000005, 6.160000000000001, 6.300000000000001, 6.440000000000001, 6.580000000000001, 6.7200000000000015, 6.860000000000001, 7.000000000000001, 7.1400000000000015, 7.280000000000001, 7.420000000000002, 7.560000000000001, 7.700000000000001, 7.840000000000002, 7.980000000000001, 8.120000000000001, 8.260000000000002, 8.4, 8.540000000000001, 8.680000000000001, 8.820000000000002, 8.96, 9.100000000000001, 9.240000000000002, 9.38, 9.520000000000001, 9.660000000000002, 9.8, 9.940000000000001, 10.080000000000002, 10.220000000000002, 10.360000000000001, 10.500000000000002, 10.640000000000002, 10.780000000000001, 10.920000000000002, 11.060000000000002, 11.200000000000001, 11.34, 11.480000000000002, 11.620000000000003, 11.760000000000002, 11.9, 12.040000000000001, 12.180000000000003, 12.320000000000002, 12.46, 12.600000000000001, 12.74, 12.880000000000003, 13.020000000000001, 13.160000000000002, 13.3, 13.440000000000003, 13.580000000000004, 13.720000000000002, 13.860000000000001, 14.000000000000002, 14.140000000000004], [0.0, 0.15000000000000002, 0.30000000000000004, 0.45000000000000007, 0.6000000000000001, 0.75, 0.9000000000000001, 1.05, 1.2000000000000002, 1.35, 1.5, 1.6500000000000001, 1.8000000000000003, 1.9500000000000002, 2.1, 2.25, 2.4000000000000004, 2.5500000000000003, 2.7, 2.85, 3.0, 3.1500000000000004, 3.3000000000000003, 3.45, 3.6000000000000005, 3.75, 3.9000000000000004, 4.050000000000001, 4.2, 4.3500000000000005, 4.5, 4.65, 4.800000000000001, 4.95, 5.1000000000000005, 5.25, 5.4, 5.550000000000001, 5.7, 5.8500000000000005, 6.0, 6.15, 6.300000000000001, 6.449999999999999, 6.6000000000000005, 6.75, 6.9, 7.050000000000001, 7.200000000000001, 7.3500000000000005, 7.5, 7.65, 7.800000000000001, 7.950000000000001, 8.100000000000001, 8.25, 8.4, 8.55, 8.700000000000001, 8.850000000000001, 9.0, 9.15, 9.3, 9.450000000000001, 9.600000000000001, 9.75, 9.9, 10.05, 10.200000000000001, 10.350000000000001, 10.5, 10.65, 10.8, 10.950000000000001, 11.100000000000001, 11.25, 11.4, 11.55, 11.700000000000001, 11.850000000000001, 12.0, 12.149999999999999, 12.3, 12.450000000000001, 12.600000000000001, 12.75, 12.899999999999999, 13.05, 13.200000000000001, 13.350000000000001, 13.5, 13.649999999999999, 13.8, 13.950000000000001, 14.100000000000001, 14.25, 14.400000000000002, 14.55, 14.700000000000001, 14.850000000000001, 15.0, 15.150000000000002], [0.0, 0.16000000000000003, 0.32000000000000006, 0.4800000000000001, 0.6400000000000001, 0.8, 0.9600000000000002, 1.12, 1.2800000000000002, 1.4400000000000002, 1.6, 1.7600000000000002, 1.9200000000000004, 2.08, 2.24, 2.4000000000000004, 2.5600000000000005, 2.7200000000000006, 2.8800000000000003, 3.0400000000000005, 3.2, 3.3600000000000003, 3.5200000000000005, 3.6800000000000006, 3.8400000000000007, 4.0, 4.16, 4.32, 4.48, 4.640000000000001, 4.800000000000001, 4.960000000000001, 5.120000000000001, 5.280000000000001, 5.440000000000001, 5.6000000000000005, 5.760000000000001, 5.920000000000001, 6.080000000000001, 6.240000000000001, 6.4, 6.560000000000001, 6.720000000000001, 6.88, 7.040000000000001, 7.2, 7.360000000000001, 7.5200000000000005, 7.6800000000000015, 7.840000000000001, 8.0, 8.160000000000002, 8.32, 8.480000000000002, 8.64, 8.8, 8.96, 9.120000000000001, 9.280000000000001, 9.440000000000001, 9.600000000000001, 9.760000000000002, 9.920000000000002, 10.080000000000002, 10.240000000000002, 10.4, 10.560000000000002, 10.72, 10.880000000000003, 11.040000000000001, 11.200000000000001, 11.360000000000001, 11.520000000000001, 11.680000000000001, 11.840000000000002, 12.0, 12.160000000000002, 12.32, 12.480000000000002, 12.64, 12.8, 12.96, 13.120000000000003, 13.280000000000001, 13.440000000000001, 13.600000000000001, 13.76, 13.920000000000002, 14.080000000000002, 14.240000000000002, 14.4, 14.56, 14.720000000000002, 14.880000000000003, 15.040000000000001, 15.200000000000001, 15.360000000000003, 15.520000000000003, 15.680000000000001, 15.840000000000002, 16.0, 16.160000000000004], [0.0, 0.17000000000000004, 0.3400000000000001, 0.5100000000000001, 0.6800000000000002, 0.8500000000000001, 1.0200000000000002, 1.1900000000000002, 1.3600000000000003, 1.5300000000000002, 1.7000000000000002, 1.8700000000000003, 2.0400000000000005, 2.2100000000000004, 2.3800000000000003, 2.5500000000000003, 2.7200000000000006, 2.8900000000000006, 3.0600000000000005, 3.2300000000000004, 3.4000000000000004, 3.5700000000000007, 3.7400000000000007, 3.910000000000001, 4.080000000000001, 4.25, 4.420000000000001, 4.590000000000001, 4.760000000000001, 4.9300000000000015, 5.1000000000000005, 5.2700000000000005, 5.440000000000001, 5.610000000000001, 5.780000000000001, 5.950000000000001, 6.120000000000001, 6.290000000000001, 6.460000000000001, 6.630000000000002, 6.800000000000001, 6.9700000000000015, 7.1400000000000015, 7.3100000000000005, 7.480000000000001, 7.65, 7.820000000000002, 7.990000000000001, 8.160000000000002, 8.330000000000002, 8.5, 8.670000000000002, 8.840000000000002, 9.010000000000002, 9.180000000000001, 9.350000000000001, 9.520000000000001, 9.690000000000001, 9.860000000000003, 10.030000000000001, 10.200000000000001, 10.370000000000003, 10.540000000000001, 10.710000000000003, 10.880000000000003, 11.05, 11.220000000000002, 11.390000000000002, 11.560000000000002, 11.730000000000002, 11.900000000000002, 12.070000000000002, 12.240000000000002, 12.410000000000002, 12.580000000000002, 12.750000000000002, 12.920000000000002, 13.090000000000002, 13.260000000000003, 13.430000000000001, 13.600000000000001, 13.770000000000001, 13.940000000000003, 14.110000000000003, 14.280000000000003, 14.450000000000001, 14.620000000000001, 14.790000000000003, 14.960000000000003, 15.130000000000003, 15.3, 15.47, 15.640000000000004, 15.810000000000002, 15.980000000000002, 16.150000000000002, 16.320000000000004, 16.490000000000002, 16.660000000000004, 16.830000000000002, 17.0, 17.170000000000005], [0.0, 0.18000000000000002, 0.36000000000000004, 0.5400000000000001, 0.7200000000000001, 0.9, 1.0800000000000003, 1.2600000000000002, 1.4400000000000002, 1.62, 1.8, 1.9800000000000002, 2.1600000000000006, 2.3400000000000003, 2.5200000000000005, 2.7, 2.8800000000000003, 3.0600000000000005, 3.24, 3.4200000000000004, 3.6, 3.7800000000000002, 3.9600000000000004, 4.140000000000001, 4.320000000000001, 4.5, 4.680000000000001, 4.86, 5.040000000000001, 5.220000000000001, 5.4, 5.58, 5.760000000000001, 5.94, 6.120000000000001, 6.3, 6.48, 6.66, 6.840000000000001, 7.0200000000000005, 7.2, 7.380000000000001, 7.5600000000000005, 7.74, 7.920000000000001, 8.1, 8.280000000000001, 8.46, 8.640000000000002, 8.82, 9.0, 9.180000000000001, 9.360000000000001, 9.540000000000001, 9.72, 9.9, 10.080000000000002, 10.26, 10.440000000000001, 10.620000000000001, 10.8, 10.98, 11.16, 11.340000000000002, 11.520000000000001, 11.700000000000001, 11.88, 12.06, 12.240000000000002, 12.420000000000002, 12.6, 12.780000000000001, 12.96, 13.140000000000002, 13.32, 13.5, 13.680000000000001, 13.860000000000001, 14.040000000000001, 14.22, 14.4, 14.58, 14.760000000000002, 14.940000000000001, 15.120000000000001, 15.3, 15.48, 15.660000000000002, 15.840000000000002, 16.02, 16.2, 16.38, 16.560000000000002, 16.740000000000002, 16.92, 17.1, 17.280000000000005, 17.46, 17.64, 17.82, 18.0, 18.180000000000003], [0.0, 0.19000000000000003, 0.38000000000000006, 0.5700000000000002, 0.7600000000000001, 0.9500000000000001, 1.1400000000000003, 1.3300000000000003, 1.5200000000000002, 1.7100000000000002, 1.9000000000000001, 2.0900000000000003, 2.2800000000000007, 2.47, 2.6600000000000006, 2.85, 3.0400000000000005, 3.2300000000000004, 3.4200000000000004, 3.6100000000000003, 3.8000000000000003, 3.9900000000000007, 4.180000000000001, 4.370000000000001, 4.560000000000001, 4.75, 4.94, 5.130000000000001, 5.320000000000001, 5.510000000000001, 5.7, 5.890000000000001, 6.080000000000001, 6.270000000000001, 6.460000000000001, 6.65, 6.840000000000001, 7.030000000000001, 7.220000000000001, 7.410000000000001, 7.6000000000000005, 7.790000000000002, 7.980000000000001, 8.17, 8.360000000000001, 8.55, 8.740000000000002, 8.930000000000001, 9.120000000000003, 9.31, 9.5, 9.690000000000001, 9.88, 10.070000000000002, 10.260000000000002, 10.450000000000001, 10.640000000000002, 10.830000000000002, 11.020000000000001, 11.21, 11.4, 11.590000000000002, 11.780000000000001, 11.970000000000002, 12.160000000000002, 12.350000000000001, 12.540000000000003, 12.73, 12.920000000000002, 13.110000000000001, 13.3, 13.490000000000002, 13.680000000000001, 13.870000000000003, 14.060000000000002, 14.250000000000002, 14.440000000000001, 14.63, 14.820000000000002, 15.010000000000002, 15.200000000000001, 15.39, 15.580000000000004, 15.770000000000003, 15.960000000000003, 16.150000000000002, 16.34, 16.530000000000005, 16.720000000000002, 16.91, 17.1, 17.29, 17.480000000000004, 17.67, 17.860000000000003, 18.05, 18.240000000000006, 18.430000000000003, 18.62, 18.810000000000002, 19.0, 19.190000000000005], [0.0, 0.2, 0.4, 0.6000000000000001, 0.8, 1.0, 1.2000000000000002, 1.4000000000000001, 1.6, 1.8, 2.0, 2.2, 2.4000000000000004, 2.6, 2.8000000000000003, 3.0, 3.2, 3.4000000000000004, 3.6, 3.8000000000000003, 4.0, 4.2, 4.4, 4.6000000000000005, 4.800000000000001, 5.0, 5.2, 5.4, 5.6000000000000005, 5.800000000000001, 6.0, 6.2, 6.4, 6.6000000000000005, 6.800000000000001, 7.0, 7.2, 7.4, 7.6000000000000005, 7.800000000000001, 8.0, 8.200000000000001, 8.4, 8.6, 8.8, 9.0, 9.200000000000001, 9.4, 9.600000000000001, 9.8, 10.0, 10.200000000000001, 10.4, 10.600000000000001, 10.8, 11.0, 11.200000000000001, 11.4, 11.600000000000001, 11.8, 12.0, 12.200000000000001, 12.4, 12.600000000000001, 12.8, 13.0, 13.200000000000001, 13.4, 13.600000000000001, 13.8, 14.0, 14.200000000000001, 14.4, 14.600000000000001, 14.8, 15.0, 15.200000000000001, 15.4, 15.600000000000001, 15.8, 16.0, 16.2, 16.400000000000002, 16.6, 16.8, 17.0, 17.2, 17.400000000000002, 17.6, 17.8, 18.0, 18.2, 18.400000000000002, 18.6, 18.8, 19.0, 19.200000000000003, 19.400000000000002, 19.6, 19.8, 20.0, 20.200000000000003], [0.0, 0.21000000000000002, 0.42000000000000004, 0.6300000000000001, 0.8400000000000001, 1.05, 1.2600000000000002, 1.4700000000000002, 1.6800000000000002, 1.8900000000000001, 2.1, 2.3100000000000005, 2.5200000000000005, 2.7300000000000004, 2.9400000000000004, 3.1500000000000004, 3.3600000000000003, 3.5700000000000007, 3.7800000000000002, 3.9900000000000007, 4.2, 4.41, 4.620000000000001, 4.830000000000001, 5.040000000000001, 5.25, 5.460000000000001, 5.670000000000001, 5.880000000000001, 6.090000000000001, 6.300000000000001, 6.510000000000001, 6.720000000000001, 6.930000000000001, 7.1400000000000015, 7.3500000000000005, 7.5600000000000005, 7.7700000000000005, 7.980000000000001, 8.190000000000001, 8.4, 8.610000000000001, 8.82, 9.03, 9.240000000000002, 9.450000000000001, 9.660000000000002, 9.870000000000001, 10.080000000000002, 10.290000000000001, 10.5, 10.71, 10.920000000000002, 11.130000000000003, 11.340000000000002, 11.55, 11.760000000000002, 11.97, 12.180000000000001, 12.39, 12.600000000000001, 12.810000000000002, 13.020000000000001, 13.230000000000002, 13.440000000000001, 13.65, 13.860000000000001, 14.07, 14.280000000000003, 14.490000000000002, 14.700000000000001, 14.910000000000002, 15.120000000000001, 15.330000000000002, 15.540000000000001, 15.75, 15.960000000000003, 16.17, 16.380000000000003, 16.59, 16.8, 17.01, 17.220000000000002, 17.430000000000003, 17.64, 17.85, 18.06, 18.270000000000003, 18.480000000000004, 18.69, 18.900000000000002, 19.11, 19.320000000000004, 19.53, 19.740000000000002, 19.95, 20.160000000000004, 20.370000000000005, 20.580000000000002, 20.790000000000003, 21.0, 21.210000000000004], [0.0, 0.22000000000000003, 0.44000000000000006, 0.6600000000000001, 0.8800000000000001, 1.1, 1.3200000000000003, 1.5400000000000003, 1.7600000000000002, 1.9800000000000002, 2.2, 2.4200000000000004, 2.6400000000000006, 2.8600000000000003, 3.0800000000000005, 3.3000000000000003, 3.5200000000000005, 3.7400000000000007, 3.9600000000000004, 4.180000000000001, 4.4, 4.620000000000001, 4.840000000000001, 5.060000000000001, 5.280000000000001, 5.5, 5.720000000000001, 5.940000000000001, 6.160000000000001, 6.380000000000002, 6.6000000000000005, 6.820000000000001, 7.040000000000001, 7.260000000000002, 7.480000000000001, 7.700000000000001, 7.920000000000001, 8.14, 8.360000000000001, 8.580000000000002, 8.8, 9.020000000000001, 9.240000000000002, 9.46, 9.680000000000001, 9.9, 10.120000000000003, 10.340000000000002, 10.560000000000002, 10.780000000000001, 11.0, 11.220000000000002, 11.440000000000001, 11.660000000000002, 11.880000000000003, 12.100000000000001, 12.320000000000002, 12.540000000000001, 12.760000000000003, 12.980000000000002, 13.200000000000001, 13.420000000000002, 13.640000000000002, 13.860000000000003, 14.080000000000002, 14.3, 14.520000000000003, 14.740000000000002, 14.960000000000003, 15.180000000000001, 15.400000000000002, 15.620000000000003, 15.840000000000002, 16.060000000000002, 16.28, 16.5, 16.720000000000002, 16.94, 17.160000000000004, 17.380000000000003, 17.6, 17.82, 18.040000000000003, 18.26, 18.480000000000004, 18.700000000000003, 18.92, 19.140000000000004, 19.360000000000003, 19.580000000000002, 19.8, 20.02, 20.240000000000006, 20.460000000000004, 20.680000000000003, 20.900000000000002, 21.120000000000005, 21.340000000000003, 21.560000000000002, 21.78, 22.0, 22.220000000000006], [0.0, 0.23000000000000004, 0.4600000000000001, 0.6900000000000002, 0.9200000000000002, 1.1500000000000001, 1.3800000000000003, 1.6100000000000003, 1.8400000000000003, 2.0700000000000003, 2.3000000000000003, 2.5300000000000007, 2.7600000000000007, 2.9900000000000007, 3.2200000000000006, 3.45, 3.6800000000000006, 3.910000000000001, 4.140000000000001, 4.370000000000001, 4.6000000000000005, 4.830000000000001, 5.060000000000001, 5.290000000000001, 5.520000000000001, 5.750000000000001, 5.980000000000001, 6.210000000000001, 6.440000000000001, 6.670000000000002, 6.9, 7.130000000000001, 7.360000000000001, 7.590000000000002, 7.820000000000002, 8.05, 8.280000000000001, 8.510000000000002, 8.740000000000002, 8.970000000000002, 9.200000000000001, 9.430000000000001, 9.660000000000002, 9.89, 10.120000000000003, 10.350000000000001, 10.580000000000002, 10.810000000000002, 11.040000000000003, 11.270000000000001, 11.500000000000002, 11.730000000000002, 11.960000000000003, 12.190000000000003, 12.420000000000002, 12.650000000000002, 12.880000000000003, 13.110000000000001, 13.340000000000003, 13.570000000000002, 13.8, 14.030000000000003, 14.260000000000002, 14.490000000000004, 14.720000000000002, 14.950000000000001, 15.180000000000003, 15.410000000000002, 15.640000000000004, 15.870000000000003, 16.1, 16.330000000000002, 16.560000000000002, 16.790000000000003, 17.020000000000003, 17.250000000000004, 17.480000000000004, 17.71, 17.940000000000005, 18.17, 18.400000000000002, 18.630000000000003, 18.860000000000003, 19.090000000000003, 19.320000000000004, 19.55, 19.78, 20.010000000000005, 20.240000000000006, 20.470000000000002, 20.700000000000003, 20.930000000000003, 21.160000000000004, 21.390000000000004, 21.620000000000005, 21.85, 22.080000000000005, 22.310000000000006, 22.540000000000003, 22.770000000000003, 23.000000000000004, 23.230000000000008], [0.0, 0.24000000000000005, 0.4800000000000001, 0.7200000000000002, 0.9600000000000002, 1.2000000000000002, 1.4400000000000004, 1.6800000000000004, 1.9200000000000004, 2.1600000000000006, 2.4000000000000004, 2.6400000000000006, 2.880000000000001, 3.1200000000000006, 3.3600000000000008, 3.6000000000000005, 3.8400000000000007, 4.080000000000001, 4.320000000000001, 4.560000000000001, 4.800000000000001, 5.040000000000001, 5.280000000000001, 5.520000000000001, 5.760000000000002, 6.000000000000001, 6.240000000000001, 6.480000000000001, 6.7200000000000015, 6.960000000000002, 7.200000000000001, 7.440000000000001, 7.6800000000000015, 7.920000000000002, 8.160000000000002, 8.400000000000002, 8.640000000000002, 8.880000000000003, 9.120000000000003, 9.360000000000003, 9.600000000000001, 9.840000000000003, 10.080000000000002, 10.32, 10.560000000000002, 10.8, 11.040000000000003, 11.280000000000003, 11.520000000000003, 11.760000000000003, 12.000000000000002, 12.240000000000004, 12.480000000000002, 12.720000000000004, 12.960000000000003, 13.200000000000003, 13.440000000000003, 13.680000000000003, 13.920000000000003, 14.160000000000004, 14.400000000000002, 14.640000000000004, 14.880000000000003, 15.120000000000005, 15.360000000000003, 15.600000000000001, 15.840000000000003, 16.080000000000002, 16.320000000000004, 16.560000000000002, 16.800000000000004, 17.040000000000003, 17.280000000000005, 17.520000000000003, 17.760000000000005, 18.000000000000004, 18.240000000000006, 18.480000000000004, 18.720000000000006, 18.960000000000004, 19.200000000000003, 19.44, 19.680000000000007, 19.920000000000005, 20.160000000000004, 20.400000000000002, 20.64, 20.880000000000006, 21.120000000000005, 21.360000000000003, 21.6, 21.840000000000003, 22.080000000000005, 22.320000000000004, 22.560000000000006, 22.800000000000004, 23.040000000000006, 23.280000000000005, 23.520000000000007, 23.760000000000005, 24.000000000000004, 24.240000000000006], [0.0, 0.25, 0.5, 0.7500000000000001, 1.0, 1.25, 1.5000000000000002, 1.7500000000000002, 2.0, 2.25, 2.5, 2.75, 3.0000000000000004, 3.25, 3.5000000000000004, 3.75, 4.0, 4.25, 4.5, 4.75, 5.0, 5.25, 5.5, 5.750000000000001, 6.000000000000001, 6.25, 6.5, 6.75, 7.000000000000001, 7.250000000000001, 7.5, 7.75, 8.0, 8.25, 8.5, 8.75, 9.0, 9.25, 9.5, 9.75, 10.0, 10.250000000000002, 10.5, 10.75, 11.0, 11.25, 11.500000000000002, 11.75, 12.000000000000002, 12.25, 12.5, 12.750000000000002, 13.0, 13.250000000000002, 13.5, 13.75, 14.000000000000002, 14.25, 14.500000000000002, 14.75, 15.0, 15.250000000000002, 15.5, 15.750000000000002, 16.0, 16.25, 16.5, 16.75, 17.0, 17.25, 17.5, 17.75, 18.0, 18.25, 18.5, 18.75, 19.0, 19.25, 19.5, 19.75, 20.0, 20.25, 20.500000000000004, 20.75, 21.0, 21.25, 21.5, 21.750000000000004, 22.0, 22.25, 22.5, 22.75, 23.000000000000004, 23.25, 23.5, 23.75, 24.000000000000004, 24.250000000000004, 24.5, 24.75, 25.0, 25.250000000000004], [0.0, 0.26, 0.52, 0.7800000000000001, 1.04, 1.3, 1.5600000000000003, 1.8200000000000003, 2.08, 2.3400000000000003, 2.6, 2.8600000000000003, 3.1200000000000006, 3.3800000000000003, 3.6400000000000006, 3.9000000000000004, 4.16, 4.420000000000001, 4.680000000000001, 4.94, 5.2, 5.460000000000001, 5.720000000000001, 5.980000000000001, 6.240000000000001, 6.5, 6.760000000000001, 7.0200000000000005, 7.280000000000001, 7.540000000000001, 7.800000000000001, 8.06, 8.32, 8.580000000000002, 8.840000000000002, 9.1, 9.360000000000001, 9.620000000000001, 9.88, 10.14, 10.4, 10.660000000000002, 10.920000000000002, 11.18, 11.440000000000001, 11.700000000000001, 11.960000000000003, 12.22, 12.480000000000002, 12.740000000000002, 13.0, 13.260000000000002, 13.520000000000001, 13.780000000000003, 14.040000000000001, 14.3, 14.560000000000002, 14.82, 15.080000000000002, 15.340000000000002, 15.600000000000001, 15.860000000000001, 16.12, 16.380000000000003, 16.64, 16.900000000000002, 17.160000000000004, 17.42, 17.680000000000003, 17.94, 18.2, 18.46, 18.720000000000002, 18.980000000000004, 19.240000000000002, 19.5, 19.76, 20.02, 20.28, 20.540000000000003, 20.8, 21.06, 21.320000000000004, 21.580000000000002, 21.840000000000003, 22.1, 22.36, 22.620000000000005, 22.880000000000003, 23.14, 23.400000000000002, 23.66, 23.920000000000005, 24.180000000000003, 24.44, 24.7, 24.960000000000004, 25.220000000000002, 25.480000000000004, 25.740000000000002, 26.0, 26.260000000000005], [0.0, 0.27, 0.54, 0.8100000000000002, 1.08, 1.35, 1.6200000000000003, 1.8900000000000003, 2.16, 2.43, 2.7, 2.9700000000000006, 3.2400000000000007, 3.5100000000000002, 3.7800000000000007, 4.050000000000001, 4.32, 4.590000000000001, 4.86, 5.130000000000001, 5.4, 5.670000000000001, 5.940000000000001, 6.210000000000001, 6.480000000000001, 6.75, 7.0200000000000005, 7.290000000000001, 7.560000000000001, 7.830000000000002, 8.100000000000001, 8.370000000000001, 8.64, 8.910000000000002, 9.180000000000001, 9.450000000000001, 9.72, 9.990000000000002, 10.260000000000002, 10.530000000000001, 10.8, 11.070000000000002, 11.340000000000002, 11.61, 11.880000000000003, 12.15, 12.420000000000002, 12.690000000000001, 12.960000000000003, 13.230000000000002, 13.5, 13.770000000000003, 14.040000000000001, 14.310000000000002, 14.580000000000002, 14.850000000000001, 15.120000000000003, 15.390000000000002, 15.660000000000004, 15.930000000000001, 16.200000000000003, 16.470000000000002, 16.740000000000002, 17.01, 17.28, 17.55, 17.820000000000004, 18.090000000000003, 18.360000000000003, 18.630000000000003, 18.900000000000002, 19.17, 19.44, 19.710000000000004, 19.980000000000004, 20.25, 20.520000000000003, 20.790000000000003, 21.060000000000002, 21.330000000000002, 21.6, 21.87, 22.140000000000004, 22.410000000000004, 22.680000000000003, 22.950000000000003, 23.22, 23.490000000000006, 23.760000000000005, 24.03, 24.3, 24.57, 24.840000000000003, 25.110000000000003, 25.380000000000003, 25.650000000000002, 25.920000000000005, 26.190000000000005, 26.460000000000004, 26.730000000000004, 27.0, 27.270000000000007], [0.0, 0.28, 0.56, 0.8400000000000002, 1.12, 1.4000000000000001, 1.6800000000000004, 1.9600000000000004, 2.24, 2.5200000000000005, 2.8000000000000003, 3.0800000000000005, 3.3600000000000008, 3.6400000000000006, 3.920000000000001, 4.2, 4.48, 4.760000000000001, 5.040000000000001, 5.320000000000001, 5.6000000000000005, 5.880000000000001, 6.160000000000001, 6.440000000000001, 6.7200000000000015, 7.000000000000001, 7.280000000000001, 7.560000000000001, 7.840000000000002, 8.120000000000001, 8.4, 8.680000000000001, 8.96, 9.240000000000002, 9.520000000000001, 9.8, 10.080000000000002, 10.360000000000001, 10.640000000000002, 10.920000000000002, 11.200000000000001, 11.480000000000002, 11.760000000000002, 12.040000000000001, 12.320000000000002, 12.600000000000001, 12.880000000000003, 13.160000000000002, 13.440000000000003, 13.720000000000002, 14.000000000000002, 14.280000000000003, 14.560000000000002, 14.840000000000003, 15.120000000000003, 15.400000000000002, 15.680000000000003, 15.960000000000003, 16.240000000000002, 16.520000000000003, 16.8, 17.080000000000002, 17.360000000000003, 17.640000000000004, 17.92, 18.200000000000003, 18.480000000000004, 18.76, 19.040000000000003, 19.320000000000004, 19.6, 19.880000000000003, 20.160000000000004, 20.440000000000005, 20.720000000000002, 21.000000000000004, 21.280000000000005, 21.560000000000002, 21.840000000000003, 22.120000000000005, 22.400000000000002, 22.68, 22.960000000000004, 23.240000000000006, 23.520000000000003, 23.8, 24.080000000000002, 24.360000000000007, 24.640000000000004, 24.92, 25.200000000000003, 25.48, 25.760000000000005, 26.040000000000003, 26.320000000000004, 26.6, 26.880000000000006, 27.160000000000007, 27.440000000000005, 27.720000000000002, 28.000000000000004, 28.28000000000001], [0.0, 0.29000000000000004, 0.5800000000000001, 0.8700000000000002, 1.1600000000000001, 1.4500000000000002, 1.7400000000000004, 2.0300000000000002, 2.3200000000000003, 2.6100000000000003, 2.9000000000000004, 3.190000000000001, 3.480000000000001, 3.7700000000000005, 4.0600000000000005, 4.3500000000000005, 4.640000000000001, 4.9300000000000015, 5.220000000000001, 5.510000000000001, 5.800000000000001, 6.090000000000001, 6.380000000000002, 6.670000000000002, 6.960000000000002, 7.250000000000001, 7.540000000000001, 7.830000000000002, 8.120000000000001, 8.410000000000002, 8.700000000000001, 8.990000000000002, 9.280000000000001, 9.570000000000002, 9.860000000000003, 10.150000000000002, 10.440000000000001, 10.730000000000002, 11.020000000000001, 11.310000000000002, 11.600000000000001, 11.890000000000002, 12.180000000000001, 12.47, 12.760000000000003, 13.05, 13.340000000000003, 13.630000000000003, 13.920000000000003, 14.210000000000003, 14.500000000000002, 14.790000000000003, 15.080000000000002, 15.370000000000005, 15.660000000000004, 15.950000000000003, 16.240000000000002, 16.53, 16.820000000000004, 17.110000000000003, 17.400000000000002, 17.690000000000005, 17.980000000000004, 18.270000000000003, 18.560000000000002, 18.85, 19.140000000000004, 19.430000000000003, 19.720000000000006, 20.010000000000005, 20.300000000000004, 20.590000000000003, 20.880000000000003, 21.170000000000005, 21.460000000000004, 21.750000000000004, 22.040000000000003, 22.330000000000002, 22.620000000000005, 22.910000000000004, 23.200000000000003, 23.490000000000002, 23.780000000000005, 24.070000000000004, 24.360000000000003, 24.650000000000002, 24.94, 25.230000000000008, 25.520000000000007, 25.810000000000006, 26.1, 26.39, 26.680000000000007, 26.970000000000006, 27.260000000000005, 27.550000000000004, 27.840000000000007, 28.130000000000006, 28.420000000000005, 28.710000000000004, 29.000000000000004, 29.290000000000006], [0.0, 0.30000000000000004, 0.6000000000000001, 0.9000000000000001, 1.2000000000000002, 1.5, 1.8000000000000003, 2.1, 2.4000000000000004, 2.7, 3.0, 3.3000000000000003, 3.6000000000000005, 3.9000000000000004, 4.2, 4.5, 4.800000000000001, 5.1000000000000005, 5.4, 5.7, 6.0, 6.300000000000001, 6.6000000000000005, 6.9, 7.200000000000001, 7.5, 7.800000000000001, 8.100000000000001, 8.4, 8.700000000000001, 9.0, 9.3, 9.600000000000001, 9.9, 10.200000000000001, 10.5, 10.8, 11.100000000000001, 11.4, 11.700000000000001, 12.0, 12.3, 12.600000000000001, 12.899999999999999, 13.200000000000001, 13.5, 13.8, 14.100000000000001, 14.400000000000002, 14.700000000000001, 15.0, 15.3, 15.600000000000001, 15.900000000000002, 16.200000000000003, 16.5, 16.8, 17.1, 17.400000000000002, 17.700000000000003, 18.0, 18.3, 18.6, 18.900000000000002, 19.200000000000003, 19.5, 19.8, 20.1, 20.400000000000002, 20.700000000000003, 21.0, 21.3, 21.6, 21.900000000000002, 22.200000000000003, 22.5, 22.8, 23.1, 23.400000000000002, 23.700000000000003, 24.0, 24.299999999999997, 24.6, 24.900000000000002, 25.200000000000003, 25.5, 25.799999999999997, 26.1, 26.400000000000002, 26.700000000000003, 27.0, 27.299999999999997, 27.6, 27.900000000000002, 28.200000000000003, 28.5, 28.800000000000004, 29.1, 29.400000000000002, 29.700000000000003, 30.0, 30.300000000000004], [0.0, 0.31000000000000005, 0.6200000000000001, 0.9300000000000002, 1.2400000000000002, 1.55, 1.8600000000000003, 2.1700000000000004, 2.4800000000000004, 2.79, 3.1, 3.4100000000000006, 3.7200000000000006, 4.03, 4.340000000000001, 4.65, 4.960000000000001, 5.2700000000000005, 5.58, 5.890000000000001, 6.2, 6.510000000000001, 6.820000000000001, 7.130000000000001, 7.440000000000001, 7.75, 8.06, 8.370000000000001, 8.680000000000001, 8.990000000000002, 9.3, 9.610000000000001, 9.920000000000002, 10.23, 10.540000000000001, 10.85, 11.16, 11.47, 11.780000000000001, 12.090000000000002, 12.4, 12.710000000000003, 13.020000000000001, 13.33, 13.640000000000002, 13.950000000000001, 14.260000000000002, 14.57, 14.880000000000003, 15.190000000000001, 15.5, 15.810000000000002, 16.12, 16.430000000000003, 16.740000000000002, 17.05, 17.360000000000003, 17.67, 17.980000000000004, 18.290000000000003, 18.6, 18.910000000000004, 19.220000000000002, 19.53, 19.840000000000003, 20.150000000000002, 20.46, 20.77, 21.080000000000002, 21.39, 21.7, 22.01, 22.32, 22.630000000000003, 22.94, 23.25, 23.560000000000002, 23.87, 24.180000000000003, 24.490000000000002, 24.8, 25.11, 25.420000000000005, 25.730000000000004, 26.040000000000003, 26.35, 26.66, 26.970000000000002, 27.280000000000005, 27.590000000000003, 27.900000000000002, 28.21, 28.520000000000003, 28.830000000000002, 29.14, 29.45, 29.760000000000005, 30.070000000000004, 30.380000000000003, 30.69, 31.0, 31.310000000000006], [0.0, 0.32000000000000006, 0.6400000000000001, 0.9600000000000002, 1.2800000000000002, 1.6, 1.9200000000000004, 2.24, 2.5600000000000005, 2.8800000000000003, 3.2, 3.5200000000000005, 3.8400000000000007, 4.16, 4.48, 4.800000000000001, 5.120000000000001, 5.440000000000001, 5.760000000000001, 6.080000000000001, 6.4, 6.720000000000001, 7.040000000000001, 7.360000000000001, 7.6800000000000015, 8.0, 8.32, 8.64, 8.96, 9.280000000000001, 9.600000000000001, 9.920000000000002, 10.240000000000002, 10.560000000000002, 10.880000000000003, 11.200000000000001, 11.520000000000001, 11.840000000000002, 12.160000000000002, 12.480000000000002, 12.8, 13.120000000000003, 13.440000000000001, 13.76, 14.080000000000002, 14.4, 14.720000000000002, 15.040000000000001, 15.360000000000003, 15.680000000000001, 16.0, 16.320000000000004, 16.64, 16.960000000000004, 17.28, 17.6, 17.92, 18.240000000000002, 18.560000000000002, 18.880000000000003, 19.200000000000003, 19.520000000000003, 19.840000000000003, 20.160000000000004, 20.480000000000004, 20.8, 21.120000000000005, 21.44, 21.760000000000005, 22.080000000000002, 22.400000000000002, 22.720000000000002, 23.040000000000003, 23.360000000000003, 23.680000000000003, 24.0, 24.320000000000004, 24.64, 24.960000000000004, 25.28, 25.6, 25.92, 26.240000000000006, 26.560000000000002, 26.880000000000003, 27.200000000000003, 27.52, 27.840000000000003, 28.160000000000004, 28.480000000000004, 28.8, 29.12, 29.440000000000005, 29.760000000000005, 30.080000000000002, 30.400000000000002, 30.720000000000006, 31.040000000000006, 31.360000000000003, 31.680000000000003, 32.0, 32.32000000000001], [0.0, 0.33000000000000007, 0.6600000000000001, 0.9900000000000002, 1.3200000000000003, 1.6500000000000001, 1.9800000000000004, 2.3100000000000005, 2.6400000000000006, 2.97, 3.3000000000000003, 3.630000000000001, 3.960000000000001, 4.290000000000001, 4.620000000000001, 4.95, 5.280000000000001, 5.610000000000001, 5.94, 6.270000000000001, 6.6000000000000005, 6.930000000000001, 7.260000000000002, 7.590000000000002, 7.920000000000002, 8.25, 8.580000000000002, 8.910000000000002, 9.240000000000002, 9.570000000000002, 9.9, 10.23, 10.560000000000002, 10.890000000000002, 11.220000000000002, 11.55, 11.88, 12.21, 12.540000000000003, 12.870000000000003, 13.200000000000001, 13.530000000000003, 13.860000000000001, 14.190000000000001, 14.520000000000003, 14.850000000000001, 15.180000000000003, 15.510000000000002, 15.840000000000003, 16.17, 16.5, 16.830000000000002, 17.160000000000004, 17.490000000000002, 17.820000000000004, 18.150000000000002, 18.480000000000004, 18.810000000000002, 19.140000000000004, 19.470000000000002, 19.8, 20.130000000000003, 20.46, 20.790000000000003, 21.120000000000005, 21.450000000000003, 21.780000000000005, 22.110000000000003, 22.440000000000005, 22.770000000000003, 23.1, 23.430000000000003, 23.76, 24.090000000000003, 24.42, 24.750000000000004, 25.080000000000005, 25.410000000000004, 25.740000000000006, 26.070000000000004, 26.400000000000002, 26.73, 27.060000000000006, 27.390000000000004, 27.720000000000002, 28.05, 28.380000000000003, 28.710000000000004, 29.040000000000006, 29.370000000000005, 29.700000000000003, 30.03, 30.360000000000007, 30.690000000000005, 31.020000000000003, 31.35, 31.680000000000007, 32.010000000000005, 32.34, 32.67, 33.0, 33.330000000000005], [0.0, 0.3400000000000001, 0.6800000000000002, 1.0200000000000002, 1.3600000000000003, 1.7000000000000002, 2.0400000000000005, 2.3800000000000003, 2.7200000000000006, 3.0600000000000005, 3.4000000000000004, 3.7400000000000007, 4.080000000000001, 4.420000000000001, 4.760000000000001, 5.1000000000000005, 5.440000000000001, 5.780000000000001, 6.120000000000001, 6.460000000000001, 6.800000000000001, 7.1400000000000015, 7.480000000000001, 7.820000000000002, 8.160000000000002, 8.5, 8.840000000000002, 9.180000000000001, 9.520000000000001, 9.860000000000003, 10.200000000000001, 10.540000000000001, 10.880000000000003, 11.220000000000002, 11.560000000000002, 11.900000000000002, 12.240000000000002, 12.580000000000002, 12.920000000000002, 13.260000000000003, 13.600000000000001, 13.940000000000003, 14.280000000000003, 14.620000000000001, 14.960000000000003, 15.3, 15.640000000000004, 15.980000000000002, 16.320000000000004, 16.660000000000004, 17.0, 17.340000000000003, 17.680000000000003, 18.020000000000003, 18.360000000000003, 18.700000000000003, 19.040000000000003, 19.380000000000003, 19.720000000000006, 20.060000000000002, 20.400000000000002, 20.740000000000006, 21.080000000000002, 21.420000000000005, 21.760000000000005, 22.1, 22.440000000000005, 22.780000000000005, 23.120000000000005, 23.460000000000004, 23.800000000000004, 24.140000000000004, 24.480000000000004, 24.820000000000004, 25.160000000000004, 25.500000000000004, 25.840000000000003, 26.180000000000003, 26.520000000000007, 26.860000000000003, 27.200000000000003, 27.540000000000003, 27.880000000000006, 28.220000000000006, 28.560000000000006, 28.900000000000002, 29.240000000000002, 29.580000000000005, 29.920000000000005, 30.260000000000005, 30.6, 30.94, 31.28000000000001, 31.620000000000005, 31.960000000000004, 32.300000000000004, 32.64000000000001, 32.980000000000004, 33.32000000000001, 33.660000000000004, 34.0, 34.34000000000001], [0.0, 0.35000000000000003, 0.7000000000000001, 1.0500000000000003, 1.4000000000000001, 1.75, 2.1000000000000005, 2.45, 2.8000000000000003, 3.15, 3.5, 3.8500000000000005, 4.200000000000001, 4.55, 4.9, 5.25, 5.6000000000000005, 5.950000000000001, 6.3, 6.65, 7.0, 7.3500000000000005, 7.700000000000001, 8.05, 8.400000000000002, 8.75, 9.1, 9.450000000000001, 9.8, 10.150000000000002, 10.5, 10.85, 11.200000000000001, 11.55, 11.900000000000002, 12.25, 12.6, 12.950000000000001, 13.3, 13.650000000000002, 14.0, 14.350000000000001, 14.700000000000001, 15.049999999999999, 15.400000000000002, 15.75, 16.1, 16.45, 16.800000000000004, 17.150000000000002, 17.5, 17.85, 18.2, 18.550000000000004, 18.900000000000002, 19.25, 19.6, 19.95, 20.300000000000004, 20.650000000000002, 21.0, 21.35, 21.7, 22.050000000000004, 22.400000000000002, 22.75, 23.1, 23.45, 23.800000000000004, 24.150000000000002, 24.5, 24.85, 25.2, 25.550000000000004, 25.900000000000002, 26.25, 26.6, 26.95, 27.300000000000004, 27.650000000000002, 28.0, 28.349999999999998, 28.700000000000003, 29.050000000000004, 29.400000000000002, 29.75, 30.099999999999998, 30.450000000000003, 30.800000000000004, 31.150000000000002, 31.5, 31.849999999999998, 32.2, 32.550000000000004, 32.9, 33.25, 33.60000000000001, 33.95, 34.300000000000004, 34.65, 35.0, 35.35000000000001], [0.0, 0.36000000000000004, 0.7200000000000001, 1.0800000000000003, 1.4400000000000002, 1.8, 2.1600000000000006, 2.5200000000000005, 2.8800000000000003, 3.24, 3.6, 3.9600000000000004, 4.320000000000001, 4.680000000000001, 5.040000000000001, 5.4, 5.760000000000001, 6.120000000000001, 6.48, 6.840000000000001, 7.2, 7.5600000000000005, 7.920000000000001, 8.280000000000001, 8.640000000000002, 9.0, 9.360000000000001, 9.72, 10.080000000000002, 10.440000000000001, 10.8, 11.16, 11.520000000000001, 11.88, 12.240000000000002, 12.6, 12.96, 13.32, 13.680000000000001, 14.040000000000001, 14.4, 14.760000000000002, 15.120000000000001, 15.48, 15.840000000000002, 16.2, 16.560000000000002, 16.92, 17.280000000000005, 17.64, 18.0, 18.360000000000003, 18.720000000000002, 19.080000000000002, 19.44, 19.8, 20.160000000000004, 20.52, 20.880000000000003, 21.240000000000002, 21.6, 21.96, 22.32, 22.680000000000003, 23.040000000000003, 23.400000000000002, 23.76, 24.12, 24.480000000000004, 24.840000000000003, 25.2, 25.560000000000002, 25.92, 26.280000000000005, 26.64, 27.0, 27.360000000000003, 27.720000000000002, 28.080000000000002, 28.44, 28.8, 29.16, 29.520000000000003, 29.880000000000003, 30.240000000000002, 30.6, 30.96, 31.320000000000004, 31.680000000000003, 32.04, 32.4, 32.76, 33.120000000000005, 33.480000000000004, 33.84, 34.2, 34.56000000000001, 34.92, 35.28, 35.64, 36.0, 36.36000000000001], [0.0, 0.37000000000000005, 0.7400000000000001, 1.1100000000000003, 1.4800000000000002, 1.85, 2.2200000000000006, 2.5900000000000003, 2.9600000000000004, 3.33, 3.7, 4.07, 4.440000000000001, 4.8100000000000005, 5.180000000000001, 5.550000000000001, 5.920000000000001, 6.290000000000001, 6.66, 7.030000000000001, 7.4, 7.7700000000000005, 8.14, 8.510000000000002, 8.880000000000003, 9.25, 9.620000000000001, 9.990000000000002, 10.360000000000001, 10.730000000000002, 11.100000000000001, 11.47, 11.840000000000002, 12.21, 12.580000000000002, 12.950000000000001, 13.32, 13.690000000000001, 14.060000000000002, 14.430000000000001, 14.8, 15.170000000000003, 15.540000000000001, 15.91, 16.28, 16.650000000000002, 17.020000000000003, 17.39, 17.760000000000005, 18.130000000000003, 18.5, 18.870000000000005, 19.240000000000002, 19.610000000000003, 19.980000000000004, 20.35, 20.720000000000002, 21.090000000000003, 21.460000000000004, 21.830000000000002, 22.200000000000003, 22.570000000000004, 22.94, 23.310000000000002, 23.680000000000003, 24.05, 24.42, 24.790000000000003, 25.160000000000004, 25.53, 25.900000000000002, 26.270000000000003, 26.64, 27.010000000000005, 27.380000000000003, 27.75, 28.120000000000005, 28.490000000000002, 28.860000000000003, 29.230000000000004, 29.6, 29.97, 30.340000000000007, 30.710000000000004, 31.080000000000002, 31.450000000000003, 31.82, 32.190000000000005, 32.56, 32.93, 33.300000000000004, 33.67, 34.040000000000006, 34.410000000000004, 34.78, 35.15, 35.52000000000001, 35.89000000000001, 36.260000000000005, 36.63, 37.0, 37.370000000000005], [0.0, 0.38000000000000006, 0.7600000000000001, 1.1400000000000003, 1.5200000000000002, 1.9000000000000001, 2.2800000000000007, 2.6600000000000006, 3.0400000000000005, 3.4200000000000004, 3.8000000000000003, 4.180000000000001, 4.560000000000001, 4.94, 5.320000000000001, 5.7, 6.080000000000001, 6.460000000000001, 6.840000000000001, 7.220000000000001, 7.6000000000000005, 7.980000000000001, 8.360000000000001, 8.740000000000002, 9.120000000000003, 9.5, 9.88, 10.260000000000002, 10.640000000000002, 11.020000000000001, 11.4, 11.780000000000001, 12.160000000000002, 12.540000000000003, 12.920000000000002, 13.3, 13.680000000000001, 14.060000000000002, 14.440000000000001, 14.820000000000002, 15.200000000000001, 15.580000000000004, 15.960000000000003, 16.34, 16.720000000000002, 17.1, 17.480000000000004, 17.860000000000003, 18.240000000000006, 18.62, 19.0, 19.380000000000003, 19.76, 20.140000000000004, 20.520000000000003, 20.900000000000002, 21.280000000000005, 21.660000000000004, 22.040000000000003, 22.42, 22.8, 23.180000000000003, 23.560000000000002, 23.940000000000005, 24.320000000000004, 24.700000000000003, 25.080000000000005, 25.46, 25.840000000000003, 26.220000000000002, 26.6, 26.980000000000004, 27.360000000000003, 27.740000000000006, 28.120000000000005, 28.500000000000004, 28.880000000000003, 29.26, 29.640000000000004, 30.020000000000003, 30.400000000000002, 30.78, 31.160000000000007, 31.540000000000006, 31.920000000000005, 32.300000000000004, 32.68, 33.06000000000001, 33.440000000000005, 33.82, 34.2, 34.58, 34.96000000000001, 35.34, 35.720000000000006, 36.1, 36.48000000000001, 36.86000000000001, 37.24, 37.620000000000005, 38.0, 38.38000000000001], [0.0, 0.39000000000000007, 0.7800000000000001, 1.1700000000000004, 1.5600000000000003, 1.9500000000000002, 2.3400000000000007, 2.7300000000000004, 3.1200000000000006, 3.5100000000000002, 3.9000000000000004, 4.290000000000001, 4.6800000000000015, 5.07, 5.460000000000001, 5.8500000000000005, 6.240000000000001, 6.630000000000002, 7.0200000000000005, 7.410000000000001, 7.800000000000001, 8.190000000000001, 8.580000000000002, 8.970000000000002, 9.360000000000003, 9.75, 10.14, 10.530000000000001, 10.920000000000002, 11.310000000000002, 11.700000000000001, 12.090000000000002, 12.480000000000002, 12.870000000000003, 13.260000000000003, 13.650000000000002, 14.040000000000001, 14.430000000000001, 14.820000000000002, 15.210000000000003, 15.600000000000001, 15.990000000000004, 16.380000000000003, 16.77, 17.160000000000004, 17.55, 17.940000000000005, 18.330000000000002, 18.720000000000006, 19.110000000000003, 19.5, 19.890000000000004, 20.28, 20.670000000000005, 21.060000000000002, 21.450000000000003, 21.840000000000003, 22.230000000000004, 22.620000000000005, 23.010000000000005, 23.400000000000002, 23.790000000000003, 24.180000000000003, 24.570000000000004, 24.960000000000004, 25.35, 25.740000000000006, 26.130000000000003, 26.520000000000007, 26.910000000000004, 27.300000000000004, 27.690000000000005, 28.080000000000002, 28.470000000000006, 28.860000000000003, 29.250000000000004, 29.640000000000004, 30.030000000000005, 30.420000000000005, 30.810000000000006, 31.200000000000003, 31.59, 31.980000000000008, 32.370000000000005, 32.760000000000005, 33.150000000000006, 33.54, 33.93000000000001, 34.32000000000001, 34.71000000000001, 35.1, 35.49, 35.88000000000001, 36.27, 36.660000000000004, 37.050000000000004, 37.44000000000001, 37.830000000000005, 38.220000000000006, 38.61000000000001, 39.0, 39.39000000000001], [0.0, 0.4, 0.8, 1.2000000000000002, 1.6, 2.0, 2.4000000000000004, 2.8000000000000003, 3.2, 3.6, 4.0, 4.4, 4.800000000000001, 5.2, 5.6000000000000005, 6.0, 6.4, 6.800000000000001, 7.2, 7.6000000000000005, 8.0, 8.4, 8.8, 9.200000000000001, 9.600000000000001, 10.0, 10.4, 10.8, 11.200000000000001, 11.600000000000001, 12.0, 12.4, 12.8, 13.200000000000001, 13.600000000000001, 14.0, 14.4, 14.8, 15.200000000000001, 15.600000000000001, 16.0, 16.400000000000002, 16.8, 17.2, 17.6, 18.0, 18.400000000000002, 18.8, 19.200000000000003, 19.6, 20.0, 20.400000000000002, 20.8, 21.200000000000003, 21.6, 22.0, 22.400000000000002, 22.8, 23.200000000000003, 23.6, 24.0, 24.400000000000002, 24.8, 25.200000000000003, 25.6, 26.0, 26.400000000000002, 26.8, 27.200000000000003, 27.6, 28.0, 28.400000000000002, 28.8, 29.200000000000003, 29.6, 30.0, 30.400000000000002, 30.8, 31.200000000000003, 31.6, 32.0, 32.4, 32.800000000000004, 33.2, 33.6, 34.0, 34.4, 34.800000000000004, 35.2, 35.6, 36.0, 36.4, 36.800000000000004, 37.2, 37.6, 38.0, 38.400000000000006, 38.800000000000004, 39.2, 39.6, 40.0, 40.400000000000006], [0.0, 0.4100000000000001, 0.8200000000000002, 1.2300000000000004, 1.6400000000000003, 2.0500000000000003, 2.460000000000001, 2.8700000000000006, 3.2800000000000007, 3.6900000000000004, 4.1000000000000005, 4.510000000000001, 4.920000000000002, 5.330000000000001, 5.740000000000001, 6.15, 6.560000000000001, 6.9700000000000015, 7.380000000000001, 7.790000000000002, 8.200000000000001, 8.610000000000001, 9.020000000000001, 9.430000000000001, 9.840000000000003, 10.250000000000002, 10.660000000000002, 11.070000000000002, 11.480000000000002, 11.890000000000002, 12.3, 12.710000000000003, 13.120000000000003, 13.530000000000003, 13.940000000000003, 14.350000000000001, 14.760000000000002, 15.170000000000003, 15.580000000000004, 15.990000000000004, 16.400000000000002, 16.810000000000006, 17.220000000000002, 17.630000000000003, 18.040000000000003, 18.450000000000003, 18.860000000000003, 19.270000000000003, 19.680000000000007, 20.090000000000003, 20.500000000000004, 20.910000000000004, 21.320000000000004, 21.730000000000004, 22.140000000000004, 22.550000000000004, 22.960000000000004, 23.370000000000005, 23.780000000000005, 24.190000000000005, 24.6, 25.010000000000005, 25.420000000000005, 25.830000000000005, 26.240000000000006, 26.650000000000002, 27.060000000000006, 27.470000000000006, 27.880000000000006, 28.290000000000006, 28.700000000000003, 29.110000000000007, 29.520000000000003, 29.930000000000007, 30.340000000000007, 30.750000000000004, 31.160000000000007, 31.570000000000004, 31.980000000000008, 32.39000000000001, 32.800000000000004, 33.21, 33.62000000000001, 34.03000000000001, 34.440000000000005, 34.85, 35.260000000000005, 35.67000000000001, 36.080000000000005, 36.49000000000001, 36.900000000000006, 37.31, 37.720000000000006, 38.13000000000001, 38.540000000000006, 38.95, 39.360000000000014, 39.77000000000001, 40.18000000000001, 40.59, 41.00000000000001, 41.41000000000001], [0.0, 0.42000000000000004, 0.8400000000000001, 1.2600000000000002, 1.6800000000000002, 2.1, 2.5200000000000005, 2.9400000000000004, 3.3600000000000003, 3.7800000000000002, 4.2, 4.620000000000001, 5.040000000000001, 5.460000000000001, 5.880000000000001, 6.300000000000001, 6.720000000000001, 7.1400000000000015, 7.5600000000000005, 7.980000000000001, 8.4, 8.82, 9.240000000000002, 9.660000000000002, 10.080000000000002, 10.5, 10.920000000000002, 11.340000000000002, 11.760000000000002, 12.180000000000001, 12.600000000000001, 13.020000000000001, 13.440000000000001, 13.860000000000001, 14.280000000000003, 14.700000000000001, 15.120000000000001, 15.540000000000001, 15.960000000000003, 16.380000000000003, 16.8, 17.220000000000002, 17.64, 18.06, 18.480000000000004, 18.900000000000002, 19.320000000000004, 19.740000000000002, 20.160000000000004, 20.580000000000002, 21.0, 21.42, 21.840000000000003, 22.260000000000005, 22.680000000000003, 23.1, 23.520000000000003, 23.94, 24.360000000000003, 24.78, 25.200000000000003, 25.620000000000005, 26.040000000000003, 26.460000000000004, 26.880000000000003, 27.3, 27.720000000000002, 28.14, 28.560000000000006, 28.980000000000004, 29.400000000000002, 29.820000000000004, 30.240000000000002, 30.660000000000004, 31.080000000000002, 31.5, 31.920000000000005, 32.34, 32.760000000000005, 33.18, 33.6, 34.02, 34.440000000000005, 34.86000000000001, 35.28, 35.7, 36.12, 36.540000000000006, 36.96000000000001, 37.38, 37.800000000000004, 38.22, 38.64000000000001, 39.06, 39.480000000000004, 39.9, 40.32000000000001, 40.74000000000001, 41.160000000000004, 41.580000000000005, 42.0, 42.42000000000001], [0.0, 0.43, 0.86, 1.29, 1.72, 2.15, 2.58, 3.0100000000000002, 3.44, 3.87, 4.3, 4.73, 5.16, 5.59, 6.0200000000000005, 6.449999999999999, 6.88, 7.3100000000000005, 7.74, 8.17, 8.6, 9.03, 9.46, 9.89, 10.32, 10.75, 11.18, 11.61, 12.040000000000001, 12.47, 12.899999999999999, 13.33, 13.76, 14.190000000000001, 14.620000000000001, 15.049999999999999, 15.48, 15.91, 16.34, 16.77, 17.2, 17.630000000000003, 18.06, 18.49, 18.92, 19.349999999999998, 19.78, 20.21, 20.64, 21.07, 21.5, 21.93, 22.36, 22.790000000000003, 23.22, 23.65, 24.080000000000002, 24.509999999999998, 24.94, 25.37, 25.799999999999997, 26.23, 26.66, 27.090000000000003, 27.52, 27.95, 28.380000000000003, 28.81, 29.240000000000002, 29.67, 30.099999999999998, 30.53, 30.96, 31.39, 31.82, 32.25, 32.68, 33.11, 33.54, 33.97, 34.4, 34.83, 35.260000000000005, 35.690000000000005, 36.12, 36.55, 36.98, 37.410000000000004, 37.84, 38.27, 38.699999999999996, 39.129999999999995, 39.56, 39.99, 40.42, 40.85, 41.28, 41.71, 42.14, 42.57, 43.0, 43.43000000000001], [0.0, 0.44000000000000006, 0.8800000000000001, 1.3200000000000003, 1.7600000000000002, 2.2, 2.6400000000000006, 3.0800000000000005, 3.5200000000000005, 3.9600000000000004, 4.4, 4.840000000000001, 5.280000000000001, 5.720000000000001, 6.160000000000001, 6.6000000000000005, 7.040000000000001, 7.480000000000001, 7.920000000000001, 8.360000000000001, 8.8, 9.240000000000002, 9.680000000000001, 10.120000000000003, 10.560000000000002, 11.0, 11.440000000000001, 11.880000000000003, 12.320000000000002, 12.760000000000003, 13.200000000000001, 13.640000000000002, 14.080000000000002, 14.520000000000003, 14.960000000000003, 15.400000000000002, 15.840000000000002, 16.28, 16.720000000000002, 17.160000000000004, 17.6, 18.040000000000003, 18.480000000000004, 18.92, 19.360000000000003, 19.8, 20.240000000000006, 20.680000000000003, 21.120000000000005, 21.560000000000002, 22.0, 22.440000000000005, 22.880000000000003, 23.320000000000004, 23.760000000000005, 24.200000000000003, 24.640000000000004, 25.080000000000002, 25.520000000000007, 25.960000000000004, 26.400000000000002, 26.840000000000003, 27.280000000000005, 27.720000000000006, 28.160000000000004, 28.6, 29.040000000000006, 29.480000000000004, 29.920000000000005, 30.360000000000003, 30.800000000000004, 31.240000000000006, 31.680000000000003, 32.120000000000005, 32.56, 33.0, 33.440000000000005, 33.88, 34.32000000000001, 34.760000000000005, 35.2, 35.64, 36.080000000000005, 36.52, 36.96000000000001, 37.400000000000006, 37.84, 38.28000000000001, 38.720000000000006, 39.160000000000004, 39.6, 40.04, 40.48000000000001, 40.92000000000001, 41.36000000000001, 41.800000000000004, 42.24000000000001, 42.68000000000001, 43.120000000000005, 43.56, 44.0, 44.44000000000001], [0.0, 0.45, 0.9, 1.35, 1.8, 2.25, 2.7, 3.1500000000000004, 3.6, 4.05, 4.5, 4.95, 5.4, 5.8500000000000005, 6.300000000000001, 6.75, 7.2, 7.65, 8.1, 8.55, 9.0, 9.450000000000001, 9.9, 10.350000000000001, 10.8, 11.25, 11.700000000000001, 12.15, 12.600000000000001, 13.05, 13.5, 13.950000000000001, 14.4, 14.850000000000001, 15.3, 15.75, 16.2, 16.650000000000002, 17.1, 17.55, 18.0, 18.450000000000003, 18.900000000000002, 19.349999999999998, 19.8, 20.25, 20.700000000000003, 21.150000000000002, 21.6, 22.05, 22.5, 22.950000000000003, 23.400000000000002, 23.85, 24.3, 24.75, 25.200000000000003, 25.650000000000002, 26.1, 26.55, 27.0, 27.450000000000003, 27.900000000000002, 28.35, 28.8, 29.25, 29.700000000000003, 30.150000000000002, 30.6, 31.05, 31.5, 31.950000000000003, 32.4, 32.85, 33.300000000000004, 33.75, 34.2, 34.65, 35.1, 35.550000000000004, 36.0, 36.449999999999996, 36.900000000000006, 37.35, 37.800000000000004, 38.25, 38.699999999999996, 39.150000000000006, 39.6, 40.050000000000004, 40.5, 40.949999999999996, 41.400000000000006, 41.85, 42.300000000000004, 42.75, 43.2, 43.650000000000006, 44.1, 44.550000000000004, 45.0, 45.45], [0.0, 0.4600000000000001, 0.9200000000000002, 1.3800000000000003, 1.8400000000000003, 2.3000000000000003, 2.7600000000000007, 3.2200000000000006, 3.6800000000000006, 4.140000000000001, 4.6000000000000005, 5.060000000000001, 5.520000000000001, 5.980000000000001, 6.440000000000001, 6.9, 7.360000000000001, 7.820000000000002, 8.280000000000001, 8.740000000000002, 9.200000000000001, 9.660000000000002, 10.120000000000003, 10.580000000000002, 11.040000000000003, 11.500000000000002, 11.960000000000003, 12.420000000000002, 12.880000000000003, 13.340000000000003, 13.8, 14.260000000000002, 14.720000000000002, 15.180000000000003, 15.640000000000004, 16.1, 16.560000000000002, 17.020000000000003, 17.480000000000004, 17.940000000000005, 18.400000000000002, 18.860000000000003, 19.320000000000004, 19.78, 20.240000000000006, 20.700000000000003, 21.160000000000004, 21.620000000000005, 22.080000000000005, 22.540000000000003, 23.000000000000004, 23.460000000000004, 23.920000000000005, 24.380000000000006, 24.840000000000003, 25.300000000000004, 25.760000000000005, 26.220000000000002, 26.680000000000007, 27.140000000000004, 27.6, 28.060000000000006, 28.520000000000003, 28.980000000000008, 29.440000000000005, 29.900000000000002, 30.360000000000007, 30.820000000000004, 31.28000000000001, 31.740000000000006, 32.2, 32.660000000000004, 33.120000000000005, 33.580000000000005, 34.040000000000006, 34.50000000000001, 34.96000000000001, 35.42, 35.88000000000001, 36.34, 36.800000000000004, 37.260000000000005, 37.720000000000006, 38.18000000000001, 38.64000000000001, 39.1, 39.56, 40.02000000000001, 40.48000000000001, 40.940000000000005, 41.400000000000006, 41.86000000000001, 42.32000000000001, 42.78000000000001, 43.24000000000001, 43.7, 44.16000000000001, 44.62000000000001, 45.080000000000005, 45.540000000000006, 46.00000000000001, 46.460000000000015], [0.0, 0.47000000000000003, 0.9400000000000001, 1.4100000000000004, 1.8800000000000001, 2.35, 2.8200000000000007, 3.2900000000000005, 3.7600000000000002, 4.23, 4.7, 5.170000000000001, 5.6400000000000015, 6.11, 6.580000000000001, 7.050000000000001, 7.5200000000000005, 7.990000000000001, 8.46, 8.930000000000001, 9.4, 9.870000000000001, 10.340000000000002, 10.810000000000002, 11.280000000000003, 11.75, 12.22, 12.690000000000001, 13.160000000000002, 13.630000000000003, 14.100000000000001, 14.57, 15.040000000000001, 15.510000000000002, 15.980000000000002, 16.45, 16.92, 17.39, 17.860000000000003, 18.330000000000002, 18.8, 19.270000000000003, 19.740000000000002, 20.21, 20.680000000000003, 21.150000000000002, 21.620000000000005, 22.090000000000003, 22.560000000000006, 23.03, 23.5, 23.970000000000002, 24.44, 24.910000000000004, 25.380000000000003, 25.85, 26.320000000000004, 26.790000000000003, 27.260000000000005, 27.730000000000004, 28.200000000000003, 28.670000000000005, 29.14, 29.610000000000003, 30.080000000000002, 30.55, 31.020000000000003, 31.490000000000002, 31.960000000000004, 32.43, 32.9, 33.370000000000005, 33.84, 34.31, 34.78, 35.25, 35.720000000000006, 36.190000000000005, 36.660000000000004, 37.13, 37.6, 38.07, 38.540000000000006, 39.010000000000005, 39.480000000000004, 39.95, 40.42, 40.89000000000001, 41.36000000000001, 41.830000000000005, 42.300000000000004, 42.77, 43.24000000000001, 43.71000000000001, 44.18000000000001, 44.65, 45.12000000000001, 45.59, 46.06, 46.53, 47.0, 47.470000000000006], [0.0, 0.4800000000000001, 0.9600000000000002, 1.4400000000000004, 1.9200000000000004, 2.4000000000000004, 2.880000000000001, 3.3600000000000008, 3.8400000000000007, 4.320000000000001, 4.800000000000001, 5.280000000000001, 5.760000000000002, 6.240000000000001, 6.7200000000000015, 7.200000000000001, 7.6800000000000015, 8.160000000000002, 8.640000000000002, 9.120000000000003, 9.600000000000001, 10.080000000000002, 10.560000000000002, 11.040000000000003, 11.520000000000003, 12.000000000000002, 12.480000000000002, 12.960000000000003, 13.440000000000003, 13.920000000000003, 14.400000000000002, 14.880000000000003, 15.360000000000003, 15.840000000000003, 16.320000000000004, 16.800000000000004, 17.280000000000005, 17.760000000000005, 18.240000000000006, 18.720000000000006, 19.200000000000003, 19.680000000000007, 20.160000000000004, 20.64, 21.120000000000005, 21.6, 22.080000000000005, 22.560000000000006, 23.040000000000006, 23.520000000000007, 24.000000000000004, 24.480000000000008, 24.960000000000004, 25.44000000000001, 25.920000000000005, 26.400000000000006, 26.880000000000006, 27.360000000000007, 27.840000000000007, 28.320000000000007, 28.800000000000004, 29.28000000000001, 29.760000000000005, 30.24000000000001, 30.720000000000006, 31.200000000000003, 31.680000000000007, 32.160000000000004, 32.64000000000001, 33.120000000000005, 33.60000000000001, 34.080000000000005, 34.56000000000001, 35.040000000000006, 35.52000000000001, 36.00000000000001, 36.48000000000001, 36.96000000000001, 37.44000000000001, 37.92000000000001, 38.400000000000006, 38.88, 39.360000000000014, 39.84000000000001, 40.32000000000001, 40.800000000000004, 41.28, 41.76000000000001, 42.24000000000001, 42.720000000000006, 43.2, 43.68000000000001, 44.16000000000001, 44.64000000000001, 45.12000000000001, 45.60000000000001, 46.08000000000001, 46.56000000000001, 47.04000000000001, 47.52000000000001, 48.00000000000001, 48.48000000000001], [0.0, 0.49000000000000005, 0.9800000000000001, 1.4700000000000004, 1.9600000000000002, 2.45, 2.940000000000001, 3.4300000000000006, 3.9200000000000004, 4.41, 4.9, 5.390000000000001, 5.880000000000002, 6.370000000000001, 6.860000000000001, 7.3500000000000005, 7.840000000000001, 8.330000000000002, 8.82, 9.31, 9.8, 10.290000000000001, 10.780000000000001, 11.270000000000001, 11.760000000000003, 12.25, 12.740000000000002, 13.230000000000002, 13.720000000000002, 14.210000000000003, 14.700000000000001, 15.190000000000001, 15.680000000000001, 16.17, 16.660000000000004, 17.150000000000002, 17.64, 18.130000000000003, 18.62, 19.110000000000003, 19.6, 20.090000000000003, 20.580000000000002, 21.07, 21.560000000000002, 22.05, 22.540000000000003, 23.03, 23.520000000000007, 24.010000000000005, 24.5, 24.990000000000006, 25.480000000000004, 25.970000000000006, 26.460000000000004, 26.950000000000003, 27.440000000000005, 27.930000000000003, 28.420000000000005, 28.910000000000004, 29.400000000000002, 29.890000000000004, 30.380000000000003, 30.870000000000005, 31.360000000000003, 31.85, 32.34, 32.830000000000005, 33.32000000000001, 33.81, 34.300000000000004, 34.790000000000006, 35.28, 35.77, 36.260000000000005, 36.75, 37.24, 37.730000000000004, 38.220000000000006, 38.71000000000001, 39.2, 39.69, 40.18000000000001, 40.67000000000001, 41.160000000000004, 41.650000000000006, 42.14, 42.63000000000001, 43.120000000000005, 43.61000000000001, 44.1, 44.59, 45.080000000000005, 45.57000000000001, 46.06, 46.550000000000004, 47.04000000000001, 47.53000000000001, 48.02000000000001, 48.510000000000005, 49.0, 49.49000000000001], [0.0, 0.5, 1.0, 1.5000000000000002, 2.0, 2.5, 3.0000000000000004, 3.5000000000000004, 4.0, 4.5, 5.0, 5.5, 6.000000000000001, 6.5, 7.000000000000001, 7.5, 8.0, 8.5, 9.0, 9.5, 10.0, 10.5, 11.0, 11.500000000000002, 12.000000000000002, 12.5, 13.0, 13.5, 14.000000000000002, 14.500000000000002, 15.0, 15.5, 16.0, 16.5, 17.0, 17.5, 18.0, 18.5, 19.0, 19.5, 20.0, 20.500000000000004, 21.0, 21.5, 22.0, 22.5, 23.000000000000004, 23.5, 24.000000000000004, 24.5, 25.0, 25.500000000000004, 26.0, 26.500000000000004, 27.0, 27.5, 28.000000000000004, 28.5, 29.000000000000004, 29.5, 30.0, 30.500000000000004, 31.0, 31.500000000000004, 32.0, 32.5, 33.0, 33.5, 34.0, 34.5, 35.0, 35.5, 36.0, 36.5, 37.0, 37.5, 38.0, 38.5, 39.0, 39.5, 40.0, 40.5, 41.00000000000001, 41.5, 42.0, 42.5, 43.0, 43.50000000000001, 44.0, 44.5, 45.0, 45.5, 46.00000000000001, 46.5, 47.0, 47.5, 48.00000000000001, 48.50000000000001, 49.0, 49.5, 50.0, 50.50000000000001], [0.0, 0.5100000000000001, 1.0200000000000002, 1.5300000000000005, 2.0400000000000005, 2.5500000000000003, 3.060000000000001, 3.5700000000000007, 4.080000000000001, 4.590000000000001, 5.1000000000000005, 5.610000000000001, 6.120000000000002, 6.630000000000001, 7.1400000000000015, 7.65, 8.160000000000002, 8.670000000000002, 9.180000000000001, 9.690000000000001, 10.200000000000001, 10.71, 11.220000000000002, 11.730000000000002, 12.240000000000004, 12.750000000000002, 13.260000000000002, 13.770000000000003, 14.280000000000003, 14.790000000000003, 15.3, 15.810000000000002, 16.320000000000004, 16.830000000000002, 17.340000000000003, 17.85, 18.360000000000003, 18.870000000000005, 19.380000000000003, 19.890000000000004, 20.400000000000002, 20.910000000000004, 21.42, 21.93, 22.440000000000005, 22.950000000000003, 23.460000000000004, 23.970000000000002, 24.480000000000008, 24.990000000000006, 25.500000000000004, 26.010000000000005, 26.520000000000003, 27.030000000000005, 27.540000000000006, 28.050000000000004, 28.560000000000006, 29.070000000000004, 29.580000000000005, 30.090000000000003, 30.6, 31.110000000000007, 31.620000000000005, 32.13000000000001, 32.64000000000001, 33.150000000000006, 33.660000000000004, 34.17, 34.68000000000001, 35.190000000000005, 35.7, 36.21000000000001, 36.720000000000006, 37.230000000000004, 37.74000000000001, 38.25000000000001, 38.760000000000005, 39.27, 39.78000000000001, 40.290000000000006, 40.800000000000004, 41.31, 41.82000000000001, 42.330000000000005, 42.84, 43.35, 43.86, 44.37000000000001, 44.88000000000001, 45.39000000000001, 45.900000000000006, 46.410000000000004, 46.92000000000001, 47.43000000000001, 47.940000000000005, 48.45, 48.960000000000015, 49.47000000000001, 49.98000000000001, 50.49000000000001, 51.00000000000001, 51.51000000000001], [0.0, 0.52, 1.04, 1.5600000000000003, 2.08, 2.6, 3.1200000000000006, 3.6400000000000006, 4.16, 4.680000000000001, 5.2, 5.720000000000001, 6.240000000000001, 6.760000000000001, 7.280000000000001, 7.800000000000001, 8.32, 8.840000000000002, 9.360000000000001, 9.88, 10.4, 10.920000000000002, 11.440000000000001, 11.960000000000003, 12.480000000000002, 13.0, 13.520000000000001, 14.040000000000001, 14.560000000000002, 15.080000000000002, 15.600000000000001, 16.12, 16.64, 17.160000000000004, 17.680000000000003, 18.2, 18.720000000000002, 19.240000000000002, 19.76, 20.28, 20.8, 21.320000000000004, 21.840000000000003, 22.36, 22.880000000000003, 23.400000000000002, 23.920000000000005, 24.44, 24.960000000000004, 25.480000000000004, 26.0, 26.520000000000003, 27.040000000000003, 27.560000000000006, 28.080000000000002, 28.6, 29.120000000000005, 29.64, 30.160000000000004, 30.680000000000003, 31.200000000000003, 31.720000000000002, 32.24, 32.760000000000005, 33.28, 33.800000000000004, 34.32000000000001, 34.84, 35.36000000000001, 35.88, 36.4, 36.92, 37.440000000000005, 37.96000000000001, 38.480000000000004, 39.0, 39.52, 40.04, 40.56, 41.080000000000005, 41.6, 42.12, 42.64000000000001, 43.160000000000004, 43.68000000000001, 44.2, 44.72, 45.24000000000001, 45.760000000000005, 46.28, 46.800000000000004, 47.32, 47.84000000000001, 48.36000000000001, 48.88, 49.4, 49.92000000000001, 50.440000000000005, 50.96000000000001, 51.480000000000004, 52.0, 52.52000000000001], [0.0, 0.5300000000000001, 1.0600000000000003, 1.5900000000000005, 2.1200000000000006, 2.6500000000000004, 3.180000000000001, 3.710000000000001, 4.240000000000001, 4.7700000000000005, 5.300000000000001, 5.830000000000001, 6.360000000000002, 6.8900000000000015, 7.420000000000002, 7.950000000000001, 8.480000000000002, 9.010000000000002, 9.540000000000001, 10.070000000000002, 10.600000000000001, 11.130000000000003, 11.660000000000002, 12.190000000000003, 12.720000000000004, 13.250000000000002, 13.780000000000003, 14.310000000000002, 14.840000000000003, 15.370000000000005, 15.900000000000002, 16.430000000000003, 16.960000000000004, 17.490000000000002, 18.020000000000003, 18.550000000000004, 19.080000000000002, 19.610000000000003, 20.140000000000004, 20.670000000000005, 21.200000000000003, 21.730000000000004, 22.260000000000005, 22.790000000000003, 23.320000000000004, 23.85, 24.380000000000006, 24.910000000000004, 25.44000000000001, 25.970000000000006, 26.500000000000004, 27.030000000000005, 27.560000000000006, 28.090000000000007, 28.620000000000005, 29.150000000000006, 29.680000000000007, 30.210000000000004, 30.74000000000001, 31.270000000000007, 31.800000000000004, 32.330000000000005, 32.86000000000001, 33.39000000000001, 33.92000000000001, 34.45, 34.980000000000004, 35.510000000000005, 36.040000000000006, 36.57000000000001, 37.10000000000001, 37.63000000000001, 38.160000000000004, 38.69000000000001, 39.220000000000006, 39.75000000000001, 40.28000000000001, 40.81000000000001, 41.34000000000001, 41.870000000000005, 42.400000000000006, 42.93000000000001, 43.46000000000001, 43.99000000000001, 44.52000000000001, 45.050000000000004, 45.580000000000005, 46.110000000000014, 46.64000000000001, 47.17000000000001, 47.7, 48.230000000000004, 48.76000000000001, 49.29000000000001, 49.82000000000001, 50.35000000000001, 50.88000000000002, 51.41000000000001, 51.94000000000001, 52.470000000000006, 53.00000000000001, 53.530000000000015], [0.0, 0.54, 1.08, 1.6200000000000003, 2.16, 2.7, 3.2400000000000007, 3.7800000000000007, 4.32, 4.86, 5.4, 5.940000000000001, 6.480000000000001, 7.0200000000000005, 7.560000000000001, 8.100000000000001, 8.64, 9.180000000000001, 9.72, 10.260000000000002, 10.8, 11.340000000000002, 11.880000000000003, 12.420000000000002, 12.960000000000003, 13.5, 14.040000000000001, 14.580000000000002, 15.120000000000003, 15.660000000000004, 16.200000000000003, 16.740000000000002, 17.28, 17.820000000000004, 18.360000000000003, 18.900000000000002, 19.44, 19.980000000000004, 20.520000000000003, 21.060000000000002, 21.6, 22.140000000000004, 22.680000000000003, 23.22, 23.760000000000005, 24.3, 24.840000000000003, 25.380000000000003, 25.920000000000005, 26.460000000000004, 27.0, 27.540000000000006, 28.080000000000002, 28.620000000000005, 29.160000000000004, 29.700000000000003, 30.240000000000006, 30.780000000000005, 31.320000000000007, 31.860000000000003, 32.400000000000006, 32.940000000000005, 33.480000000000004, 34.02, 34.56, 35.1, 35.64000000000001, 36.18000000000001, 36.720000000000006, 37.260000000000005, 37.800000000000004, 38.34, 38.88, 39.42000000000001, 39.96000000000001, 40.5, 41.040000000000006, 41.580000000000005, 42.120000000000005, 42.660000000000004, 43.2, 43.74, 44.28000000000001, 44.82000000000001, 45.36000000000001, 45.900000000000006, 46.44, 46.98000000000001, 47.52000000000001, 48.06, 48.6, 49.14, 49.68000000000001, 50.220000000000006, 50.760000000000005, 51.300000000000004, 51.84000000000001, 52.38000000000001, 52.92000000000001, 53.46000000000001, 54.0, 54.54000000000001], [0.0, 0.55, 1.1, 1.6500000000000004, 2.2, 2.75, 3.3000000000000007, 3.8500000000000005, 4.4, 4.95, 5.5, 6.050000000000001, 6.600000000000001, 7.15, 7.700000000000001, 8.25, 8.8, 9.350000000000001, 9.9, 10.450000000000001, 11.0, 11.55, 12.100000000000001, 12.650000000000002, 13.200000000000003, 13.75, 14.3, 14.850000000000001, 15.400000000000002, 15.950000000000003, 16.5, 17.05, 17.6, 18.150000000000002, 18.700000000000003, 19.25, 19.8, 20.35, 20.900000000000002, 21.450000000000003, 22.0, 22.550000000000004, 23.1, 23.65, 24.200000000000003, 24.75, 25.300000000000004, 25.85, 26.400000000000006, 26.950000000000003, 27.5, 28.050000000000004, 28.6, 29.150000000000006, 29.700000000000003, 30.25, 30.800000000000004, 31.35, 31.900000000000006, 32.45, 33.0, 33.550000000000004, 34.1, 34.650000000000006, 35.2, 35.75, 36.300000000000004, 36.85, 37.400000000000006, 37.95, 38.5, 39.050000000000004, 39.6, 40.150000000000006, 40.7, 41.25, 41.800000000000004, 42.35, 42.900000000000006, 43.45, 44.0, 44.55, 45.10000000000001, 45.650000000000006, 46.2, 46.75, 47.3, 47.85000000000001, 48.400000000000006, 48.95, 49.5, 50.05, 50.60000000000001, 51.150000000000006, 51.7, 52.25, 52.80000000000001, 53.35000000000001, 53.900000000000006, 54.45, 55.0, 55.55000000000001], [0.0, 0.56, 1.12, 1.6800000000000004, 2.24, 2.8000000000000003, 3.3600000000000008, 3.920000000000001, 4.48, 5.040000000000001, 5.6000000000000005, 6.160000000000001, 6.7200000000000015, 7.280000000000001, 7.840000000000002, 8.4, 8.96, 9.520000000000001, 10.080000000000002, 10.640000000000002, 11.200000000000001, 11.760000000000002, 12.320000000000002, 12.880000000000003, 13.440000000000003, 14.000000000000002, 14.560000000000002, 15.120000000000003, 15.680000000000003, 16.240000000000002, 16.8, 17.360000000000003, 17.92, 18.480000000000004, 19.040000000000003, 19.6, 20.160000000000004, 20.720000000000002, 21.280000000000005, 21.840000000000003, 22.400000000000002, 22.960000000000004, 23.520000000000003, 24.080000000000002, 24.640000000000004, 25.200000000000003, 25.760000000000005, 26.320000000000004, 26.880000000000006, 27.440000000000005, 28.000000000000004, 28.560000000000006, 29.120000000000005, 29.680000000000007, 30.240000000000006, 30.800000000000004, 31.360000000000007, 31.920000000000005, 32.480000000000004, 33.040000000000006, 33.6, 34.160000000000004, 34.720000000000006, 35.28000000000001, 35.84, 36.400000000000006, 36.96000000000001, 37.52, 38.080000000000005, 38.64000000000001, 39.2, 39.760000000000005, 40.32000000000001, 40.88000000000001, 41.440000000000005, 42.00000000000001, 42.56000000000001, 43.120000000000005, 43.68000000000001, 44.24000000000001, 44.800000000000004, 45.36, 45.92000000000001, 46.48000000000001, 47.040000000000006, 47.6, 48.160000000000004, 48.72000000000001, 49.28000000000001, 49.84, 50.400000000000006, 50.96, 51.52000000000001, 52.080000000000005, 52.64000000000001, 53.2, 53.76000000000001, 54.320000000000014, 54.88000000000001, 55.440000000000005, 56.00000000000001, 56.56000000000002], [0.0, 0.5700000000000001, 1.1400000000000001, 1.7100000000000004, 2.2800000000000002, 2.85, 3.420000000000001, 3.9900000000000007, 4.5600000000000005, 5.13, 5.7, 6.2700000000000005, 6.840000000000002, 7.41, 7.980000000000001, 8.55, 9.120000000000001, 9.690000000000001, 10.26, 10.830000000000002, 11.4, 11.97, 12.540000000000001, 13.110000000000001, 13.680000000000003, 14.25, 14.82, 15.390000000000002, 15.960000000000003, 16.53, 17.1, 17.67, 18.240000000000002, 18.810000000000002, 19.380000000000003, 19.95, 20.52, 21.090000000000003, 21.660000000000004, 22.230000000000004, 22.8, 23.370000000000005, 23.94, 24.509999999999998, 25.080000000000002, 25.650000000000002, 26.220000000000002, 26.790000000000003, 27.360000000000007, 27.930000000000003, 28.5, 29.070000000000004, 29.64, 30.210000000000004, 30.780000000000005, 31.35, 31.920000000000005, 32.49, 33.06, 33.63, 34.2, 34.77, 35.34, 35.910000000000004, 36.480000000000004, 37.050000000000004, 37.620000000000005, 38.190000000000005, 38.760000000000005, 39.330000000000005, 39.9, 40.470000000000006, 41.04, 41.61000000000001, 42.18000000000001, 42.75, 43.32000000000001, 43.89, 44.46000000000001, 45.03, 45.6, 46.17, 46.74000000000001, 47.31, 47.88, 48.45, 49.019999999999996, 49.59000000000001, 50.160000000000004, 50.730000000000004, 51.300000000000004, 51.87, 52.440000000000005, 53.010000000000005, 53.580000000000005, 54.15, 54.72000000000001, 55.290000000000006, 55.86000000000001, 56.43000000000001, 57.0, 57.57000000000001], [0.0, 0.5800000000000001, 1.1600000000000001, 1.7400000000000004, 2.3200000000000003, 2.9000000000000004, 3.480000000000001, 4.0600000000000005, 4.640000000000001, 5.220000000000001, 5.800000000000001, 6.380000000000002, 6.960000000000002, 7.540000000000001, 8.120000000000001, 8.700000000000001, 9.280000000000001, 9.860000000000003, 10.440000000000001, 11.020000000000001, 11.600000000000001, 12.180000000000001, 12.760000000000003, 13.340000000000003, 13.920000000000003, 14.500000000000002, 15.080000000000002, 15.660000000000004, 16.240000000000002, 16.820000000000004, 17.400000000000002, 17.980000000000004, 18.560000000000002, 19.140000000000004, 19.720000000000006, 20.300000000000004, 20.880000000000003, 21.460000000000004, 22.040000000000003, 22.620000000000005, 23.200000000000003, 23.780000000000005, 24.360000000000003, 24.94, 25.520000000000007, 26.1, 26.680000000000007, 27.260000000000005, 27.840000000000007, 28.420000000000005, 29.000000000000004, 29.580000000000005, 30.160000000000004, 30.74000000000001, 31.320000000000007, 31.900000000000006, 32.480000000000004, 33.06, 33.64000000000001, 34.220000000000006, 34.800000000000004, 35.38000000000001, 35.96000000000001, 36.540000000000006, 37.120000000000005, 37.7, 38.28000000000001, 38.86000000000001, 39.44000000000001, 40.02000000000001, 40.60000000000001, 41.18000000000001, 41.760000000000005, 42.34000000000001, 42.92000000000001, 43.50000000000001, 44.080000000000005, 44.660000000000004, 45.24000000000001, 45.82000000000001, 46.400000000000006, 46.980000000000004, 47.56000000000001, 48.14000000000001, 48.720000000000006, 49.300000000000004, 49.88, 50.460000000000015, 51.04000000000001, 51.62000000000001, 52.2, 52.78, 53.360000000000014, 53.94000000000001, 54.52000000000001, 55.10000000000001, 55.680000000000014, 56.26000000000001, 56.84000000000001, 57.42000000000001, 58.00000000000001, 58.58000000000001], [0.0, 0.5900000000000001, 1.1800000000000002, 1.7700000000000005, 2.3600000000000003, 2.95, 3.540000000000001, 4.130000000000001, 4.720000000000001, 5.3100000000000005, 5.9, 6.490000000000001, 7.080000000000002, 7.670000000000001, 8.260000000000002, 8.850000000000001, 9.440000000000001, 10.030000000000001, 10.620000000000001, 11.21, 11.8, 12.39, 12.980000000000002, 13.570000000000002, 14.160000000000004, 14.75, 15.340000000000002, 15.930000000000001, 16.520000000000003, 17.110000000000003, 17.700000000000003, 18.290000000000003, 18.880000000000003, 19.470000000000002, 20.060000000000002, 20.650000000000002, 21.240000000000002, 21.830000000000002, 22.42, 23.010000000000005, 23.6, 24.190000000000005, 24.78, 25.37, 25.960000000000004, 26.55, 27.140000000000004, 27.730000000000004, 28.320000000000007, 28.910000000000004, 29.5, 30.090000000000003, 30.680000000000003, 31.270000000000007, 31.860000000000003, 32.45, 33.040000000000006, 33.63, 34.220000000000006, 34.81, 35.400000000000006, 35.99, 36.580000000000005, 37.17000000000001, 37.760000000000005, 38.35, 38.940000000000005, 39.53, 40.120000000000005, 40.71000000000001, 41.300000000000004, 41.89000000000001, 42.480000000000004, 43.07000000000001, 43.660000000000004, 44.25, 44.84, 45.43000000000001, 46.02000000000001, 46.61000000000001, 47.2, 47.79, 48.38000000000001, 48.970000000000006, 49.56, 50.150000000000006, 50.74, 51.33000000000001, 51.92000000000001, 52.510000000000005, 53.1, 53.69, 54.28000000000001, 54.870000000000005, 55.46000000000001, 56.050000000000004, 56.640000000000015, 57.23000000000001, 57.82000000000001, 58.410000000000004, 59.0, 59.59000000000001], [0.0, 0.6000000000000001, 1.2000000000000002, 1.8000000000000003, 2.4000000000000004, 3.0, 3.6000000000000005, 4.2, 4.800000000000001, 5.4, 6.0, 6.6000000000000005, 7.200000000000001, 7.800000000000001, 8.4, 9.0, 9.600000000000001, 10.200000000000001, 10.8, 11.4, 12.0, 12.600000000000001, 13.200000000000001, 13.8, 14.400000000000002, 15.0, 15.600000000000001, 16.200000000000003, 16.8, 17.400000000000002, 18.0, 18.6, 19.200000000000003, 19.8, 20.400000000000002, 21.0, 21.6, 22.200000000000003, 22.8, 23.400000000000002, 24.0, 24.6, 25.200000000000003, 25.799999999999997, 26.400000000000002, 27.0, 27.6, 28.200000000000003, 28.800000000000004, 29.400000000000002, 30.0, 30.6, 31.200000000000003, 31.800000000000004, 32.400000000000006, 33.0, 33.6, 34.2, 34.800000000000004, 35.400000000000006, 36.0, 36.6, 37.2, 37.800000000000004, 38.400000000000006, 39.0, 39.6, 40.2, 40.800000000000004, 41.400000000000006, 42.0, 42.6, 43.2, 43.800000000000004, 44.400000000000006, 45.0, 45.6, 46.2, 46.800000000000004, 47.400000000000006, 48.0, 48.599999999999994, 49.2, 49.800000000000004, 50.400000000000006, 51.0, 51.599999999999994, 52.2, 52.800000000000004, 53.400000000000006, 54.0, 54.599999999999994, 55.2, 55.800000000000004, 56.400000000000006, 57.0, 57.60000000000001, 58.2, 58.800000000000004, 59.400000000000006, 60.0, 60.60000000000001], [0.0, 0.6100000000000001, 1.2200000000000002, 1.8300000000000005, 2.4400000000000004, 3.0500000000000003, 3.660000000000001, 4.2700000000000005, 4.880000000000001, 5.49, 6.1000000000000005, 6.710000000000001, 7.320000000000002, 7.930000000000001, 8.540000000000001, 9.15, 9.760000000000002, 10.370000000000003, 10.98, 11.590000000000002, 12.200000000000001, 12.810000000000002, 13.420000000000002, 14.030000000000003, 14.640000000000004, 15.250000000000002, 15.860000000000001, 16.470000000000002, 17.080000000000002, 17.690000000000005, 18.3, 18.910000000000004, 19.520000000000003, 20.130000000000003, 20.740000000000006, 21.35, 21.96, 22.570000000000004, 23.180000000000003, 23.790000000000003, 24.400000000000002, 25.010000000000005, 25.620000000000005, 26.23, 26.840000000000003, 27.450000000000003, 28.060000000000006, 28.670000000000005, 29.28000000000001, 29.890000000000004, 30.500000000000004, 31.110000000000007, 31.720000000000002, 32.330000000000005, 32.940000000000005, 33.550000000000004, 34.160000000000004, 34.77, 35.38000000000001, 35.99, 36.6, 37.21000000000001, 37.82000000000001, 38.43000000000001, 39.040000000000006, 39.650000000000006, 40.260000000000005, 40.870000000000005, 41.48000000000001, 42.09, 42.7, 43.31000000000001, 43.92, 44.53000000000001, 45.14000000000001, 45.75000000000001, 46.36000000000001, 46.970000000000006, 47.580000000000005, 48.190000000000005, 48.800000000000004, 49.410000000000004, 50.02000000000001, 50.63000000000001, 51.24000000000001, 51.85, 52.46, 53.070000000000014, 53.68000000000001, 54.290000000000006, 54.900000000000006, 55.510000000000005, 56.12000000000001, 56.73000000000001, 57.34000000000001, 57.95, 58.56000000000002, 59.17000000000001, 59.78000000000001, 60.39000000000001, 61.00000000000001, 61.610000000000014], [0.0, 0.6200000000000001, 1.2400000000000002, 1.8600000000000003, 2.4800000000000004, 3.1, 3.7200000000000006, 4.340000000000001, 4.960000000000001, 5.58, 6.2, 6.820000000000001, 7.440000000000001, 8.06, 8.680000000000001, 9.3, 9.920000000000002, 10.540000000000001, 11.16, 11.780000000000001, 12.4, 13.020000000000001, 13.640000000000002, 14.260000000000002, 14.880000000000003, 15.5, 16.12, 16.740000000000002, 17.360000000000003, 17.980000000000004, 18.6, 19.220000000000002, 19.840000000000003, 20.46, 21.080000000000002, 21.7, 22.32, 22.94, 23.560000000000002, 24.180000000000003, 24.8, 25.420000000000005, 26.040000000000003, 26.66, 27.280000000000005, 27.900000000000002, 28.520000000000003, 29.14, 29.760000000000005, 30.380000000000003, 31.0, 31.620000000000005, 32.24, 32.86000000000001, 33.480000000000004, 34.1, 34.720000000000006, 35.34, 35.96000000000001, 36.580000000000005, 37.2, 37.82000000000001, 38.440000000000005, 39.06, 39.68000000000001, 40.300000000000004, 40.92, 41.54, 42.160000000000004, 42.78, 43.4, 44.02, 44.64, 45.260000000000005, 45.88, 46.5, 47.120000000000005, 47.74, 48.36000000000001, 48.980000000000004, 49.6, 50.22, 50.84000000000001, 51.46000000000001, 52.080000000000005, 52.7, 53.32, 53.940000000000005, 54.56000000000001, 55.18000000000001, 55.800000000000004, 56.42, 57.040000000000006, 57.660000000000004, 58.28, 58.9, 59.52000000000001, 60.14000000000001, 60.760000000000005, 61.38, 62.0, 62.62000000000001], [0.0, 0.6300000000000001, 1.2600000000000002, 1.8900000000000006, 2.5200000000000005, 3.1500000000000004, 3.780000000000001, 4.410000000000001, 5.040000000000001, 5.670000000000001, 6.300000000000001, 6.9300000000000015, 7.560000000000002, 8.190000000000001, 8.820000000000002, 9.450000000000001, 10.080000000000002, 10.710000000000003, 11.340000000000002, 11.970000000000002, 12.600000000000001, 13.230000000000002, 13.860000000000003, 14.490000000000004, 15.120000000000005, 15.750000000000002, 16.380000000000003, 17.01, 17.640000000000004, 18.270000000000003, 18.900000000000002, 19.53, 20.160000000000004, 20.790000000000003, 21.420000000000005, 22.050000000000004, 22.680000000000003, 23.310000000000002, 23.940000000000005, 24.570000000000004, 25.200000000000003, 25.830000000000005, 26.460000000000004, 27.090000000000003, 27.720000000000006, 28.35, 28.980000000000008, 29.610000000000003, 30.24000000000001, 30.870000000000005, 31.500000000000004, 32.13000000000001, 32.760000000000005, 33.39000000000001, 34.02, 34.650000000000006, 35.28000000000001, 35.910000000000004, 36.540000000000006, 37.17000000000001, 37.800000000000004, 38.43000000000001, 39.06, 39.69000000000001, 40.32000000000001, 40.95, 41.580000000000005, 42.21000000000001, 42.84000000000001, 43.470000000000006, 44.10000000000001, 44.73000000000001, 45.36000000000001, 45.99000000000001, 46.620000000000005, 47.25000000000001, 47.88000000000001, 48.510000000000005, 49.14000000000001, 49.77000000000001, 50.400000000000006, 51.03, 51.66000000000001, 52.29000000000001, 52.92000000000001, 53.550000000000004, 54.18000000000001, 54.81000000000001, 55.44000000000001, 56.07000000000001, 56.7, 57.330000000000005, 57.960000000000015, 58.59000000000001, 59.220000000000006, 59.85000000000001, 60.48000000000002, 61.110000000000014, 61.74000000000001, 62.37000000000001, 63.00000000000001, 63.63000000000002], [0.0, 0.6400000000000001, 1.2800000000000002, 1.9200000000000004, 2.5600000000000005, 3.2, 3.8400000000000007, 4.48, 5.120000000000001, 5.760000000000001, 6.4, 7.040000000000001, 7.6800000000000015, 8.32, 8.96, 9.600000000000001, 10.240000000000002, 10.880000000000003, 11.520000000000001, 12.160000000000002, 12.8, 13.440000000000001, 14.080000000000002, 14.720000000000002, 15.360000000000003, 16.0, 16.64, 17.28, 17.92, 18.560000000000002, 19.200000000000003, 19.840000000000003, 20.480000000000004, 21.120000000000005, 21.760000000000005, 22.400000000000002, 23.040000000000003, 23.680000000000003, 24.320000000000004, 24.960000000000004, 25.6, 26.240000000000006, 26.880000000000003, 27.52, 28.160000000000004, 28.8, 29.440000000000005, 30.080000000000002, 30.720000000000006, 31.360000000000003, 32.0, 32.64000000000001, 33.28, 33.92000000000001, 34.56, 35.2, 35.84, 36.480000000000004, 37.120000000000005, 37.760000000000005, 38.400000000000006, 39.040000000000006, 39.68000000000001, 40.32000000000001, 40.96000000000001, 41.6, 42.24000000000001, 42.88, 43.52000000000001, 44.160000000000004, 44.800000000000004, 45.440000000000005, 46.080000000000005, 46.720000000000006, 47.36000000000001, 48.0, 48.64000000000001, 49.28, 49.92000000000001, 50.56, 51.2, 51.84, 52.48000000000001, 53.120000000000005, 53.760000000000005, 54.400000000000006, 55.04, 55.68000000000001, 56.32000000000001, 56.96000000000001, 57.6, 58.24, 58.88000000000001, 59.52000000000001, 60.160000000000004, 60.800000000000004, 61.44000000000001, 62.08000000000001, 62.720000000000006, 63.36000000000001, 64.0, 64.64000000000001], [0.0, 0.65, 1.3, 1.9500000000000002, 2.6, 3.25, 3.9000000000000004, 4.550000000000001, 5.2, 5.8500000000000005, 6.5, 7.15, 7.800000000000001, 8.450000000000001, 9.100000000000001, 9.75, 10.4, 11.05, 11.700000000000001, 12.350000000000001, 13.0, 13.65, 14.3, 14.950000000000001, 15.600000000000001, 16.25, 16.900000000000002, 17.55, 18.200000000000003, 18.85, 19.5, 20.150000000000002, 20.8, 21.450000000000003, 22.1, 22.75, 23.400000000000002, 24.05, 24.700000000000003, 25.35, 26.0, 26.650000000000002, 27.3, 27.95, 28.6, 29.25, 29.900000000000002, 30.55, 31.200000000000003, 31.85, 32.5, 33.150000000000006, 33.800000000000004, 34.45, 35.1, 35.75, 36.400000000000006, 37.050000000000004, 37.7, 38.35, 39.0, 39.650000000000006, 40.300000000000004, 40.95, 41.6, 42.25, 42.900000000000006, 43.550000000000004, 44.2, 44.85, 45.5, 46.150000000000006, 46.800000000000004, 47.45, 48.1, 48.75, 49.400000000000006, 50.050000000000004, 50.7, 51.35, 52.0, 52.65, 53.300000000000004, 53.95, 54.6, 55.25, 55.9, 56.550000000000004, 57.2, 57.85, 58.5, 59.15, 59.800000000000004, 60.45, 61.1, 61.75, 62.400000000000006, 63.050000000000004, 63.7, 64.35000000000001, 65.0, 65.65], [0.0, 0.6600000000000001, 1.3200000000000003, 1.9800000000000004, 2.6400000000000006, 3.3000000000000003, 3.960000000000001, 4.620000000000001, 5.280000000000001, 5.94, 6.6000000000000005, 7.260000000000002, 7.920000000000002, 8.580000000000002, 9.240000000000002, 9.9, 10.560000000000002, 11.220000000000002, 11.88, 12.540000000000003, 13.200000000000001, 13.860000000000001, 14.520000000000003, 15.180000000000003, 15.840000000000003, 16.5, 17.160000000000004, 17.820000000000004, 18.480000000000004, 19.140000000000004, 19.8, 20.46, 21.120000000000005, 21.780000000000005, 22.440000000000005, 23.1, 23.76, 24.42, 25.080000000000005, 25.740000000000006, 26.400000000000002, 27.060000000000006, 27.720000000000002, 28.380000000000003, 29.040000000000006, 29.700000000000003, 30.360000000000007, 31.020000000000003, 31.680000000000007, 32.34, 33.0, 33.660000000000004, 34.32000000000001, 34.980000000000004, 35.64000000000001, 36.300000000000004, 36.96000000000001, 37.620000000000005, 38.28000000000001, 38.940000000000005, 39.6, 40.260000000000005, 40.92, 41.580000000000005, 42.24000000000001, 42.900000000000006, 43.56000000000001, 44.220000000000006, 44.88000000000001, 45.540000000000006, 46.2, 46.86000000000001, 47.52, 48.18000000000001, 48.84, 49.50000000000001, 50.16000000000001, 50.82000000000001, 51.48000000000001, 52.14000000000001, 52.800000000000004, 53.46, 54.12000000000001, 54.78000000000001, 55.440000000000005, 56.1, 56.760000000000005, 57.42000000000001, 58.08000000000001, 58.74000000000001, 59.400000000000006, 60.06, 60.72000000000001, 61.38000000000001, 62.040000000000006, 62.7, 63.360000000000014, 64.02000000000001, 64.68, 65.34, 66.0, 66.66000000000001], [0.0, 0.67, 1.34, 2.0100000000000002, 2.68, 3.35, 4.0200000000000005, 4.69, 5.36, 6.03, 6.7, 7.370000000000001, 8.040000000000001, 8.71, 9.38, 10.05, 10.72, 11.390000000000002, 12.06, 12.73, 13.4, 14.07, 14.740000000000002, 15.410000000000002, 16.080000000000002, 16.75, 17.42, 18.090000000000003, 18.76, 19.430000000000003, 20.1, 20.77, 21.44, 22.110000000000003, 22.780000000000005, 23.45, 24.12, 24.790000000000003, 25.46, 26.130000000000003, 26.8, 27.470000000000006, 28.14, 28.81, 29.480000000000004, 30.150000000000002, 30.820000000000004, 31.490000000000002, 32.160000000000004, 32.830000000000005, 33.5, 34.17, 34.84, 35.510000000000005, 36.18000000000001, 36.85, 37.52, 38.190000000000005, 38.86000000000001, 39.53, 40.2, 40.870000000000005, 41.54, 42.21000000000001, 42.88, 43.550000000000004, 44.220000000000006, 44.89, 45.56000000000001, 46.230000000000004, 46.9, 47.57000000000001, 48.24, 48.910000000000004, 49.580000000000005, 50.25, 50.92, 51.59, 52.260000000000005, 52.93000000000001, 53.6, 54.269999999999996, 54.94000000000001, 55.61000000000001, 56.28, 56.95, 57.62, 58.290000000000006, 58.96000000000001, 59.63, 60.300000000000004, 60.97, 61.64000000000001, 62.31000000000001, 62.980000000000004, 63.65, 64.32000000000001, 64.99000000000001, 65.66000000000001, 66.33, 67.0, 67.67000000000002], [0.0, 0.6800000000000002, 1.3600000000000003, 2.0400000000000005, 2.7200000000000006, 3.4000000000000004, 4.080000000000001, 4.760000000000001, 5.440000000000001, 6.120000000000001, 6.800000000000001, 7.480000000000001, 8.160000000000002, 8.840000000000002, 9.520000000000001, 10.200000000000001, 10.880000000000003, 11.560000000000002, 12.240000000000002, 12.920000000000002, 13.600000000000001, 14.280000000000003, 14.960000000000003, 15.640000000000004, 16.320000000000004, 17.0, 17.680000000000003, 18.360000000000003, 19.040000000000003, 19.720000000000006, 20.400000000000002, 21.080000000000002, 21.760000000000005, 22.440000000000005, 23.120000000000005, 23.800000000000004, 24.480000000000004, 25.160000000000004, 25.840000000000003, 26.520000000000007, 27.200000000000003, 27.880000000000006, 28.560000000000006, 29.240000000000002, 29.920000000000005, 30.6, 31.28000000000001, 31.960000000000004, 32.64000000000001, 33.32000000000001, 34.0, 34.68000000000001, 35.36000000000001, 36.040000000000006, 36.720000000000006, 37.400000000000006, 38.080000000000005, 38.760000000000005, 39.44000000000001, 40.120000000000005, 40.800000000000004, 41.48000000000001, 42.160000000000004, 42.84000000000001, 43.52000000000001, 44.2, 44.88000000000001, 45.56000000000001, 46.24000000000001, 46.92000000000001, 47.60000000000001, 48.28000000000001, 48.96000000000001, 49.64000000000001, 50.32000000000001, 51.00000000000001, 51.68000000000001, 52.36000000000001, 53.04000000000001, 53.720000000000006, 54.400000000000006, 55.080000000000005, 55.76000000000001, 56.44000000000001, 57.12000000000001, 57.800000000000004, 58.480000000000004, 59.16000000000001, 59.84000000000001, 60.52000000000001, 61.2, 61.88, 62.56000000000002, 63.24000000000001, 63.92000000000001, 64.60000000000001, 65.28000000000002, 65.96000000000001, 66.64000000000001, 67.32000000000001, 68.0, 68.68000000000002], [0.0, 0.6900000000000001, 1.3800000000000001, 2.0700000000000003, 2.7600000000000002, 3.45, 4.140000000000001, 4.830000000000001, 5.5200000000000005, 6.210000000000001, 6.9, 7.590000000000001, 8.280000000000001, 8.97, 9.660000000000002, 10.350000000000001, 11.040000000000001, 11.730000000000002, 12.420000000000002, 13.110000000000001, 13.8, 14.490000000000002, 15.180000000000001, 15.870000000000003, 16.560000000000002, 17.25, 17.94, 18.630000000000003, 19.320000000000004, 20.010000000000005, 20.700000000000003, 21.39, 22.080000000000002, 22.770000000000003, 23.460000000000004, 24.150000000000002, 24.840000000000003, 25.53, 26.220000000000002, 26.910000000000004, 27.6, 28.290000000000006, 28.980000000000004, 29.67, 30.360000000000003, 31.05, 31.740000000000006, 32.43, 33.120000000000005, 33.81, 34.5, 35.190000000000005, 35.88, 36.57000000000001, 37.260000000000005, 37.95, 38.64000000000001, 39.330000000000005, 40.02000000000001, 40.71000000000001, 41.400000000000006, 42.09, 42.78, 43.470000000000006, 44.160000000000004, 44.85, 45.540000000000006, 46.230000000000004, 46.92000000000001, 47.61000000000001, 48.300000000000004, 48.99000000000001, 49.68000000000001, 50.370000000000005, 51.06, 51.75, 52.440000000000005, 53.13, 53.82000000000001, 54.510000000000005, 55.2, 55.89, 56.58000000000001, 57.27000000000001, 57.96000000000001, 58.650000000000006, 59.34, 60.03000000000001, 60.720000000000006, 61.410000000000004, 62.1, 62.79, 63.48000000000001, 64.17, 64.86, 65.55, 66.24000000000001, 66.93, 67.62, 68.31, 69.0, 69.69000000000001], [0.0, 0.7000000000000001, 1.4000000000000001, 2.1000000000000005, 2.8000000000000003, 3.5, 4.200000000000001, 4.9, 5.6000000000000005, 6.3, 7.0, 7.700000000000001, 8.400000000000002, 9.1, 9.8, 10.5, 11.200000000000001, 11.900000000000002, 12.6, 13.3, 14.0, 14.700000000000001, 15.400000000000002, 16.1, 16.800000000000004, 17.5, 18.2, 18.900000000000002, 19.6, 20.300000000000004, 21.0, 21.7, 22.400000000000002, 23.1, 23.800000000000004, 24.5, 25.2, 25.900000000000002, 26.6, 27.300000000000004, 28.0, 28.700000000000003, 29.400000000000002, 30.099999999999998, 30.800000000000004, 31.5, 32.2, 32.9, 33.60000000000001, 34.300000000000004, 35.0, 35.7, 36.4, 37.10000000000001, 37.800000000000004, 38.5, 39.2, 39.9, 40.60000000000001, 41.300000000000004, 42.0, 42.7, 43.4, 44.10000000000001, 44.800000000000004, 45.5, 46.2, 46.9, 47.60000000000001, 48.300000000000004, 49.0, 49.7, 50.4, 51.10000000000001, 51.800000000000004, 52.5, 53.2, 53.9, 54.60000000000001, 55.300000000000004, 56.0, 56.699999999999996, 57.400000000000006, 58.10000000000001, 58.800000000000004, 59.5, 60.199999999999996, 60.900000000000006, 61.60000000000001, 62.300000000000004, 63.0, 63.699999999999996, 64.4, 65.10000000000001, 65.8, 66.5, 67.20000000000002, 67.9, 68.60000000000001, 69.3, 70.0, 70.70000000000002], [0.0, 0.7100000000000001, 1.4200000000000002, 2.1300000000000003, 2.8400000000000003, 3.5500000000000003, 4.260000000000001, 4.970000000000001, 5.680000000000001, 6.390000000000001, 7.1000000000000005, 7.810000000000001, 8.520000000000001, 9.23, 9.940000000000001, 10.65, 11.360000000000001, 12.070000000000002, 12.780000000000001, 13.490000000000002, 14.200000000000001, 14.910000000000002, 15.620000000000003, 16.330000000000002, 17.040000000000003, 17.75, 18.46, 19.17, 19.880000000000003, 20.590000000000003, 21.3, 22.01, 22.720000000000002, 23.430000000000003, 24.140000000000004, 24.85, 25.560000000000002, 26.270000000000003, 26.980000000000004, 27.690000000000005, 28.400000000000002, 29.110000000000007, 29.820000000000004, 30.53, 31.240000000000006, 31.950000000000003, 32.660000000000004, 33.370000000000005, 34.080000000000005, 34.790000000000006, 35.5, 36.21000000000001, 36.92, 37.63000000000001, 38.34, 39.050000000000004, 39.760000000000005, 40.470000000000006, 41.18000000000001, 41.89000000000001, 42.6, 43.31000000000001, 44.02, 44.73000000000001, 45.440000000000005, 46.150000000000006, 46.86000000000001, 47.57000000000001, 48.28000000000001, 48.99000000000001, 49.7, 50.41000000000001, 51.120000000000005, 51.830000000000005, 52.540000000000006, 53.25000000000001, 53.96000000000001, 54.67000000000001, 55.38000000000001, 56.09, 56.800000000000004, 57.510000000000005, 58.22000000000001, 58.93000000000001, 59.64000000000001, 60.35, 61.06, 61.77000000000001, 62.48000000000001, 63.190000000000005, 63.900000000000006, 64.61, 65.32000000000001, 66.03000000000002, 66.74000000000001, 67.45, 68.16000000000001, 68.87000000000002, 69.58000000000001, 70.29, 71.0, 71.71000000000002], [0.0, 0.7200000000000001, 1.4400000000000002, 2.1600000000000006, 2.8800000000000003, 3.6, 4.320000000000001, 5.040000000000001, 5.760000000000001, 6.48, 7.2, 7.920000000000001, 8.640000000000002, 9.360000000000001, 10.080000000000002, 10.8, 11.520000000000001, 12.240000000000002, 12.96, 13.680000000000001, 14.4, 15.120000000000001, 15.840000000000002, 16.560000000000002, 17.280000000000005, 18.0, 18.720000000000002, 19.44, 20.160000000000004, 20.880000000000003, 21.6, 22.32, 23.040000000000003, 23.76, 24.480000000000004, 25.2, 25.92, 26.64, 27.360000000000003, 28.080000000000002, 28.8, 29.520000000000003, 30.240000000000002, 30.96, 31.680000000000003, 32.4, 33.120000000000005, 33.84, 34.56000000000001, 35.28, 36.0, 36.720000000000006, 37.440000000000005, 38.160000000000004, 38.88, 39.6, 40.32000000000001, 41.04, 41.760000000000005, 42.480000000000004, 43.2, 43.92, 44.64, 45.36000000000001, 46.080000000000005, 46.800000000000004, 47.52, 48.24, 48.96000000000001, 49.68000000000001, 50.4, 51.120000000000005, 51.84, 52.56000000000001, 53.28, 54.0, 54.720000000000006, 55.440000000000005, 56.160000000000004, 56.88, 57.6, 58.32, 59.040000000000006, 59.760000000000005, 60.480000000000004, 61.2, 61.92, 62.64000000000001, 63.36000000000001, 64.08, 64.8, 65.52, 66.24000000000001, 66.96000000000001, 67.68, 68.4, 69.12000000000002, 69.84, 70.56, 71.28, 72.0, 72.72000000000001], [0.0, 0.7300000000000001, 1.4600000000000002, 2.1900000000000004, 2.9200000000000004, 3.6500000000000004, 4.380000000000001, 5.110000000000001, 5.840000000000001, 6.570000000000001, 7.300000000000001, 8.030000000000001, 8.760000000000002, 9.490000000000002, 10.220000000000002, 10.950000000000001, 11.680000000000001, 12.410000000000002, 13.140000000000002, 13.870000000000003, 14.600000000000001, 15.330000000000002, 16.060000000000002, 16.790000000000003, 17.520000000000003, 18.25, 18.980000000000004, 19.710000000000004, 20.440000000000005, 21.170000000000005, 21.900000000000002, 22.630000000000003, 23.360000000000003, 24.090000000000003, 24.820000000000004, 25.550000000000004, 26.280000000000005, 27.010000000000005, 27.740000000000006, 28.470000000000006, 29.200000000000003, 29.930000000000007, 30.660000000000004, 31.39, 32.120000000000005, 32.85, 33.580000000000005, 34.31, 35.040000000000006, 35.77, 36.5, 37.230000000000004, 37.96000000000001, 38.69000000000001, 39.42000000000001, 40.150000000000006, 40.88000000000001, 41.61000000000001, 42.34000000000001, 43.07000000000001, 43.800000000000004, 44.53000000000001, 45.260000000000005, 45.99000000000001, 46.720000000000006, 47.45, 48.18000000000001, 48.910000000000004, 49.64000000000001, 50.370000000000005, 51.10000000000001, 51.830000000000005, 52.56000000000001, 53.29000000000001, 54.02000000000001, 54.75000000000001, 55.48000000000001, 56.21000000000001, 56.94000000000001, 57.67000000000001, 58.400000000000006, 59.13, 59.860000000000014, 60.59000000000001, 61.32000000000001, 62.050000000000004, 62.78, 63.51000000000001, 64.24000000000001, 64.97000000000001, 65.7, 66.43, 67.16000000000001, 67.89000000000001, 68.62, 69.35000000000001, 70.08000000000001, 70.81000000000002, 71.54, 72.27000000000001, 73.0, 73.73000000000002], [0.0, 0.7400000000000001, 1.4800000000000002, 2.2200000000000006, 2.9600000000000004, 3.7, 4.440000000000001, 5.180000000000001, 5.920000000000001, 6.66, 7.4, 8.14, 8.880000000000003, 9.620000000000001, 10.360000000000001, 11.100000000000001, 11.840000000000002, 12.580000000000002, 13.32, 14.060000000000002, 14.8, 15.540000000000001, 16.28, 17.020000000000003, 17.760000000000005, 18.5, 19.240000000000002, 19.980000000000004, 20.720000000000002, 21.460000000000004, 22.200000000000003, 22.94, 23.680000000000003, 24.42, 25.160000000000004, 25.900000000000002, 26.64, 27.380000000000003, 28.120000000000005, 28.860000000000003, 29.6, 30.340000000000007, 31.080000000000002, 31.82, 32.56, 33.300000000000004, 34.040000000000006, 34.78, 35.52000000000001, 36.260000000000005, 37.0, 37.74000000000001, 38.480000000000004, 39.220000000000006, 39.96000000000001, 40.7, 41.440000000000005, 42.18000000000001, 42.92000000000001, 43.660000000000004, 44.400000000000006, 45.14000000000001, 45.88, 46.620000000000005, 47.36000000000001, 48.1, 48.84, 49.580000000000005, 50.32000000000001, 51.06, 51.800000000000004, 52.540000000000006, 53.28, 54.02000000000001, 54.760000000000005, 55.5, 56.24000000000001, 56.980000000000004, 57.720000000000006, 58.46000000000001, 59.2, 59.94, 60.680000000000014, 61.42000000000001, 62.160000000000004, 62.900000000000006, 63.64, 64.38000000000001, 65.12, 65.86, 66.60000000000001, 67.34, 68.08000000000001, 68.82000000000001, 69.56, 70.3, 71.04000000000002, 71.78000000000002, 72.52000000000001, 73.26, 74.0, 74.74000000000001], [0.0, 0.75, 1.5, 2.2500000000000004, 3.0, 3.75, 4.500000000000001, 5.250000000000001, 6.0, 6.75, 7.5, 8.25, 9.000000000000002, 9.75, 10.500000000000002, 11.25, 12.0, 12.750000000000002, 13.5, 14.250000000000002, 15.0, 15.75, 16.5, 17.250000000000004, 18.000000000000004, 18.75, 19.5, 20.25, 21.000000000000004, 21.750000000000004, 22.5, 23.25, 24.0, 24.750000000000004, 25.500000000000004, 26.25, 27.0, 27.75, 28.500000000000004, 29.250000000000004, 30.0, 30.750000000000004, 31.5, 32.25, 33.0, 33.75, 34.50000000000001, 35.25, 36.00000000000001, 36.75, 37.5, 38.25000000000001, 39.0, 39.75000000000001, 40.5, 41.25, 42.00000000000001, 42.75, 43.50000000000001, 44.25, 45.0, 45.75000000000001, 46.5, 47.25000000000001, 48.0, 48.75, 49.50000000000001, 50.25, 51.00000000000001, 51.75, 52.5, 53.25000000000001, 54.0, 54.75000000000001, 55.5, 56.25, 57.00000000000001, 57.75, 58.50000000000001, 59.25, 60.0, 60.75, 61.50000000000001, 62.25000000000001, 63.0, 63.75, 64.5, 65.25000000000001, 66.0, 66.75, 67.5, 68.25, 69.00000000000001, 69.75, 70.5, 71.25, 72.00000000000001, 72.75000000000001, 73.5, 74.25, 75.0, 75.75000000000001], [0.0, 0.7600000000000001, 1.5200000000000002, 2.2800000000000007, 3.0400000000000005, 3.8000000000000003, 4.560000000000001, 5.320000000000001, 6.080000000000001, 6.840000000000001, 7.6000000000000005, 8.360000000000001, 9.120000000000003, 9.88, 10.640000000000002, 11.4, 12.160000000000002, 12.920000000000002, 13.680000000000001, 14.440000000000001, 15.200000000000001, 15.960000000000003, 16.720000000000002, 17.480000000000004, 18.240000000000006, 19.0, 19.76, 20.520000000000003, 21.280000000000005, 22.040000000000003, 22.8, 23.560000000000002, 24.320000000000004, 25.080000000000005, 25.840000000000003, 26.6, 27.360000000000003, 28.120000000000005, 28.880000000000003, 29.640000000000004, 30.400000000000002, 31.160000000000007, 31.920000000000005, 32.68, 33.440000000000005, 34.2, 34.96000000000001, 35.720000000000006, 36.48000000000001, 37.24, 38.0, 38.760000000000005, 39.52, 40.28000000000001, 41.040000000000006, 41.800000000000004, 42.56000000000001, 43.32000000000001, 44.080000000000005, 44.84, 45.6, 46.36000000000001, 47.120000000000005, 47.88000000000001, 48.64000000000001, 49.400000000000006, 50.16000000000001, 50.92, 51.68000000000001, 52.440000000000005, 53.2, 53.96000000000001, 54.720000000000006, 55.48000000000001, 56.24000000000001, 57.00000000000001, 57.760000000000005, 58.52, 59.28000000000001, 60.040000000000006, 60.800000000000004, 61.56, 62.320000000000014, 63.08000000000001, 63.84000000000001, 64.60000000000001, 65.36, 66.12000000000002, 66.88000000000001, 67.64, 68.4, 69.16, 69.92000000000002, 70.68, 71.44000000000001, 72.2, 72.96000000000002, 73.72000000000001, 74.48, 75.24000000000001, 76.0, 76.76000000000002], [0.0, 0.77, 1.54, 2.3100000000000005, 3.08, 3.85, 4.620000000000001, 5.390000000000001, 6.16, 6.930000000000001, 7.7, 8.47, 9.240000000000002, 10.01, 10.780000000000001, 11.55, 12.32, 13.090000000000002, 13.860000000000001, 14.63, 15.4, 16.17, 16.94, 17.71, 18.480000000000004, 19.25, 20.02, 20.790000000000003, 21.560000000000002, 22.330000000000002, 23.1, 23.87, 24.64, 25.410000000000004, 26.180000000000003, 26.95, 27.720000000000002, 28.490000000000002, 29.26, 30.030000000000005, 30.8, 31.570000000000004, 32.34, 33.11, 33.88, 34.65, 35.42, 36.190000000000005, 36.96000000000001, 37.730000000000004, 38.5, 39.27, 40.04, 40.81000000000001, 41.580000000000005, 42.35, 43.120000000000005, 43.89, 44.660000000000004, 45.43000000000001, 46.2, 46.970000000000006, 47.74, 48.510000000000005, 49.28, 50.050000000000004, 50.82000000000001, 51.59, 52.36000000000001, 53.13, 53.9, 54.67000000000001, 55.440000000000005, 56.21000000000001, 56.980000000000004, 57.75, 58.52, 59.290000000000006, 60.06000000000001, 60.830000000000005, 61.6, 62.37, 63.14000000000001, 63.910000000000004, 64.68, 65.45, 66.22, 66.99000000000001, 67.76, 68.53, 69.3, 70.07, 70.84, 71.61000000000001, 72.38000000000001, 73.15, 73.92000000000002, 74.69000000000001, 75.46000000000001, 76.23, 77.0, 77.77000000000001], [0.0, 0.7800000000000001, 1.5600000000000003, 2.3400000000000007, 3.1200000000000006, 3.9000000000000004, 4.6800000000000015, 5.460000000000001, 6.240000000000001, 7.0200000000000005, 7.800000000000001, 8.580000000000002, 9.360000000000003, 10.14, 10.920000000000002, 11.700000000000001, 12.480000000000002, 13.260000000000003, 14.040000000000001, 14.820000000000002, 15.600000000000001, 16.380000000000003, 17.160000000000004, 17.940000000000005, 18.720000000000006, 19.5, 20.28, 21.060000000000002, 21.840000000000003, 22.620000000000005, 23.400000000000002, 24.180000000000003, 24.960000000000004, 25.740000000000006, 26.520000000000007, 27.300000000000004, 28.080000000000002, 28.860000000000003, 29.640000000000004, 30.420000000000005, 31.200000000000003, 31.980000000000008, 32.760000000000005, 33.54, 34.32000000000001, 35.1, 35.88000000000001, 36.660000000000004, 37.44000000000001, 38.220000000000006, 39.0, 39.78000000000001, 40.56, 41.34000000000001, 42.120000000000005, 42.900000000000006, 43.68000000000001, 44.46000000000001, 45.24000000000001, 46.02000000000001, 46.800000000000004, 47.580000000000005, 48.36000000000001, 49.14000000000001, 49.92000000000001, 50.7, 51.48000000000001, 52.260000000000005, 53.04000000000001, 53.82000000000001, 54.60000000000001, 55.38000000000001, 56.160000000000004, 56.94000000000001, 57.720000000000006, 58.50000000000001, 59.28000000000001, 60.06000000000001, 60.84000000000001, 61.62000000000001, 62.400000000000006, 63.18, 63.960000000000015, 64.74000000000001, 65.52000000000001, 66.30000000000001, 67.08, 67.86000000000001, 68.64000000000001, 69.42000000000002, 70.2, 70.98, 71.76000000000002, 72.54, 73.32000000000001, 74.10000000000001, 74.88000000000002, 75.66000000000001, 76.44000000000001, 77.22000000000001, 78.0, 78.78000000000002], [0.0, 0.79, 1.58, 2.3700000000000006, 3.16, 3.95, 4.740000000000001, 5.530000000000001, 6.32, 7.11, 7.9, 8.690000000000001, 9.480000000000002, 10.270000000000001, 11.060000000000002, 11.850000000000001, 12.64, 13.430000000000001, 14.22, 15.010000000000002, 15.8, 16.59, 17.380000000000003, 18.17, 18.960000000000004, 19.75, 20.540000000000003, 21.330000000000002, 22.120000000000005, 22.910000000000004, 23.700000000000003, 24.490000000000002, 25.28, 26.070000000000004, 26.860000000000003, 27.650000000000002, 28.44, 29.230000000000004, 30.020000000000003, 30.810000000000006, 31.6, 32.39000000000001, 33.18, 33.97, 34.760000000000005, 35.550000000000004, 36.34, 37.13, 37.92000000000001, 38.71000000000001, 39.5, 40.290000000000006, 41.080000000000005, 41.870000000000005, 42.660000000000004, 43.45, 44.24000000000001, 45.03, 45.82000000000001, 46.61000000000001, 47.400000000000006, 48.190000000000005, 48.980000000000004, 49.77000000000001, 50.56, 51.35, 52.14000000000001, 52.93000000000001, 53.720000000000006, 54.510000000000005, 55.300000000000004, 56.09, 56.88, 57.67000000000001, 58.46000000000001, 59.25, 60.040000000000006, 60.830000000000005, 61.62000000000001, 62.410000000000004, 63.2, 63.99, 64.78000000000002, 65.57000000000001, 66.36, 67.15, 67.94, 68.73000000000002, 69.52000000000001, 70.31, 71.10000000000001, 71.89, 72.68, 73.47000000000001, 74.26, 75.05, 75.84000000000002, 76.63000000000001, 77.42000000000002, 78.21000000000001, 79.0, 79.79000000000002], [0.0, 0.8, 1.6, 2.4000000000000004, 3.2, 4.0, 4.800000000000001, 5.6000000000000005, 6.4, 7.2, 8.0, 8.8, 9.600000000000001, 10.4, 11.200000000000001, 12.0, 12.8, 13.600000000000001, 14.4, 15.200000000000001, 16.0, 16.8, 17.6, 18.400000000000002, 19.200000000000003, 20.0, 20.8, 21.6, 22.400000000000002, 23.200000000000003, 24.0, 24.8, 25.6, 26.400000000000002, 27.200000000000003, 28.0, 28.8, 29.6, 30.400000000000002, 31.200000000000003, 32.0, 32.800000000000004, 33.6, 34.4, 35.2, 36.0, 36.800000000000004, 37.6, 38.400000000000006, 39.2, 40.0, 40.800000000000004, 41.6, 42.400000000000006, 43.2, 44.0, 44.800000000000004, 45.6, 46.400000000000006, 47.2, 48.0, 48.800000000000004, 49.6, 50.400000000000006, 51.2, 52.0, 52.800000000000004, 53.6, 54.400000000000006, 55.2, 56.0, 56.800000000000004, 57.6, 58.400000000000006, 59.2, 60.0, 60.800000000000004, 61.6, 62.400000000000006, 63.2, 64.0, 64.8, 65.60000000000001, 66.4, 67.2, 68.0, 68.8, 69.60000000000001, 70.4, 71.2, 72.0, 72.8, 73.60000000000001, 74.4, 75.2, 76.0, 76.80000000000001, 77.60000000000001, 78.4, 79.2, 80.0, 80.80000000000001], [0.0, 0.81, 1.62, 2.43, 3.24, 4.05, 4.86, 5.67, 6.48, 7.29, 8.1, 8.91, 9.72, 10.53, 11.34, 12.149999999999999, 12.96, 13.770000000000001, 14.58, 15.39, 16.2, 17.01, 17.82, 18.630000000000003, 19.44, 20.25, 21.06, 21.87, 22.68, 23.490000000000002, 24.299999999999997, 25.11, 25.92, 26.73, 27.540000000000003, 28.349999999999998, 29.16, 29.97, 30.78, 31.59, 32.4, 33.21, 34.02, 34.83, 35.64, 36.449999999999996, 37.260000000000005, 38.07, 38.88, 39.69, 40.5, 41.31, 42.12, 42.93000000000001, 43.74, 44.55, 45.36, 46.17, 46.980000000000004, 47.79, 48.599999999999994, 49.410000000000004, 50.22, 51.03, 51.84, 52.65, 53.46, 54.269999999999996, 55.080000000000005, 55.89, 56.699999999999996, 57.510000000000005, 58.32, 59.13, 59.94, 60.75, 61.56, 62.37, 63.18, 63.99, 64.8, 65.61, 66.42, 67.23, 68.04, 68.85, 69.66, 70.47, 71.28, 72.09, 72.89999999999999, 73.71, 74.52000000000001, 75.33, 76.14, 76.95, 77.76, 78.57000000000001, 79.38, 80.19, 81.0, 81.81], [0.0, 0.8200000000000002, 1.6400000000000003, 2.460000000000001, 3.2800000000000007, 4.1000000000000005, 4.920000000000002, 5.740000000000001, 6.560000000000001, 7.380000000000001, 8.200000000000001, 9.020000000000001, 9.840000000000003, 10.660000000000002, 11.480000000000002, 12.3, 13.120000000000003, 13.940000000000003, 14.760000000000002, 15.580000000000004, 16.400000000000002, 17.220000000000002, 18.040000000000003, 18.860000000000003, 19.680000000000007, 20.500000000000004, 21.320000000000004, 22.140000000000004, 22.960000000000004, 23.780000000000005, 24.6, 25.420000000000005, 26.240000000000006, 27.060000000000006, 27.880000000000006, 28.700000000000003, 29.520000000000003, 30.340000000000007, 31.160000000000007, 31.980000000000008, 32.800000000000004, 33.62000000000001, 34.440000000000005, 35.260000000000005, 36.080000000000005, 36.900000000000006, 37.720000000000006, 38.540000000000006, 39.360000000000014, 40.18000000000001, 41.00000000000001, 41.82000000000001, 42.64000000000001, 43.46000000000001, 44.28000000000001, 45.10000000000001, 45.92000000000001, 46.74000000000001, 47.56000000000001, 48.38000000000001, 49.2, 50.02000000000001, 50.84000000000001, 51.66000000000001, 52.48000000000001, 53.300000000000004, 54.12000000000001, 54.94000000000001, 55.76000000000001, 56.58000000000001, 57.400000000000006, 58.22000000000001, 59.040000000000006, 59.860000000000014, 60.680000000000014, 61.50000000000001, 62.320000000000014, 63.14000000000001, 63.960000000000015, 64.78000000000002, 65.60000000000001, 66.42, 67.24000000000002, 68.06000000000002, 68.88000000000001, 69.7, 70.52000000000001, 71.34000000000002, 72.16000000000001, 72.98000000000002, 73.80000000000001, 74.62, 75.44000000000001, 76.26000000000002, 77.08000000000001, 77.9, 78.72000000000003, 79.54000000000002, 80.36000000000001, 81.18, 82.00000000000001, 82.82000000000002], [0.0, 0.8300000000000001, 1.6600000000000001, 2.4900000000000007, 3.3200000000000003, 4.15, 4.980000000000001, 5.810000000000001, 6.640000000000001, 7.470000000000001, 8.3, 9.13, 9.960000000000003, 10.790000000000001, 11.620000000000003, 12.450000000000001, 13.280000000000001, 14.110000000000003, 14.940000000000001, 15.770000000000003, 16.6, 17.430000000000003, 18.26, 19.090000000000003, 19.920000000000005, 20.75, 21.580000000000002, 22.410000000000004, 23.240000000000006, 24.070000000000004, 24.900000000000002, 25.730000000000004, 26.560000000000002, 27.390000000000004, 28.220000000000006, 29.050000000000004, 29.880000000000003, 30.710000000000004, 31.540000000000006, 32.370000000000005, 33.2, 34.03000000000001, 34.86000000000001, 35.690000000000005, 36.52, 37.35, 38.18000000000001, 39.010000000000005, 39.84000000000001, 40.67000000000001, 41.5, 42.330000000000005, 43.160000000000004, 43.99000000000001, 44.82000000000001, 45.650000000000006, 46.48000000000001, 47.31, 48.14000000000001, 48.970000000000006, 49.800000000000004, 50.63000000000001, 51.46000000000001, 52.29000000000001, 53.120000000000005, 53.95, 54.78000000000001, 55.61000000000001, 56.44000000000001, 57.27000000000001, 58.10000000000001, 58.93000000000001, 59.760000000000005, 60.59000000000001, 61.42000000000001, 62.25000000000001, 63.08000000000001, 63.910000000000004, 64.74000000000001, 65.57000000000001, 66.4, 67.23, 68.06000000000002, 68.89000000000001, 69.72000000000001, 70.55000000000001, 71.38000000000001, 72.21000000000001, 73.04, 73.87, 74.7, 75.53, 76.36000000000001, 77.19000000000001, 78.02000000000001, 78.85000000000001, 79.68000000000002, 80.51000000000002, 81.34000000000002, 82.17000000000002, 83.0, 83.83000000000001], [0.0, 0.8400000000000001, 1.6800000000000002, 2.5200000000000005, 3.3600000000000003, 4.2, 5.040000000000001, 5.880000000000001, 6.720000000000001, 7.5600000000000005, 8.4, 9.240000000000002, 10.080000000000002, 10.920000000000002, 11.760000000000002, 12.600000000000001, 13.440000000000001, 14.280000000000003, 15.120000000000001, 15.960000000000003, 16.8, 17.64, 18.480000000000004, 19.320000000000004, 20.160000000000004, 21.0, 21.840000000000003, 22.680000000000003, 23.520000000000003, 24.360000000000003, 25.200000000000003, 26.040000000000003, 26.880000000000003, 27.720000000000002, 28.560000000000006, 29.400000000000002, 30.240000000000002, 31.080000000000002, 31.920000000000005, 32.760000000000005, 33.6, 34.440000000000005, 35.28, 36.12, 36.96000000000001, 37.800000000000004, 38.64000000000001, 39.480000000000004, 40.32000000000001, 41.160000000000004, 42.0, 42.84, 43.68000000000001, 44.52000000000001, 45.36000000000001, 46.2, 47.040000000000006, 47.88, 48.720000000000006, 49.56, 50.400000000000006, 51.24000000000001, 52.080000000000005, 52.92000000000001, 53.760000000000005, 54.6, 55.440000000000005, 56.28, 57.12000000000001, 57.96000000000001, 58.800000000000004, 59.64000000000001, 60.480000000000004, 61.32000000000001, 62.160000000000004, 63.0, 63.84000000000001, 64.68, 65.52000000000001, 66.36, 67.2, 68.04, 68.88000000000001, 69.72000000000001, 70.56, 71.4, 72.24, 73.08000000000001, 73.92000000000002, 74.76, 75.60000000000001, 76.44, 77.28000000000002, 78.12, 78.96000000000001, 79.8, 80.64000000000001, 81.48000000000002, 82.32000000000001, 83.16000000000001, 84.0, 84.84000000000002], [0.0, 0.8500000000000001, 1.7000000000000002, 2.5500000000000003, 3.4000000000000004, 4.25, 5.1000000000000005, 5.95, 6.800000000000001, 7.65, 8.5, 9.350000000000001, 10.200000000000001, 11.05, 11.9, 12.75, 13.600000000000001, 14.450000000000001, 15.3, 16.150000000000002, 17.0, 17.85, 18.700000000000003, 19.55, 20.400000000000002, 21.25, 22.1, 22.950000000000003, 23.8, 24.650000000000002, 25.5, 26.35, 27.200000000000003, 28.05, 28.900000000000002, 29.75, 30.6, 31.450000000000003, 32.300000000000004, 33.150000000000006, 34.0, 34.85, 35.7, 36.55, 37.400000000000006, 38.25, 39.1, 39.95, 40.800000000000004, 41.650000000000006, 42.5, 43.35, 44.2, 45.050000000000004, 45.900000000000006, 46.75, 47.6, 48.45, 49.300000000000004, 50.150000000000006, 51.0, 51.85, 52.7, 53.550000000000004, 54.400000000000006, 55.25, 56.1, 56.95, 57.800000000000004, 58.650000000000006, 59.5, 60.35, 61.2, 62.050000000000004, 62.900000000000006, 63.75, 64.60000000000001, 65.45, 66.30000000000001, 67.15, 68.0, 68.85, 69.7, 70.55000000000001, 71.4, 72.25, 73.1, 73.95, 74.80000000000001, 75.65, 76.5, 77.35, 78.2, 79.05000000000001, 79.9, 80.75, 81.60000000000001, 82.45, 83.30000000000001, 84.15, 85.0, 85.85000000000001], [0.0, 0.86, 1.72, 2.58, 3.44, 4.3, 5.16, 6.0200000000000005, 6.88, 7.74, 8.6, 9.46, 10.32, 11.18, 12.040000000000001, 12.899999999999999, 13.76, 14.620000000000001, 15.48, 16.34, 17.2, 18.06, 18.92, 19.78, 20.64, 21.5, 22.36, 23.22, 24.080000000000002, 24.94, 25.799999999999997, 26.66, 27.52, 28.380000000000003, 29.240000000000002, 30.099999999999998, 30.96, 31.82, 32.68, 33.54, 34.4, 35.260000000000005, 36.12, 36.98, 37.84, 38.699999999999996, 39.56, 40.42, 41.28, 42.14, 43.0, 43.86, 44.72, 45.580000000000005, 46.44, 47.3, 48.160000000000004, 49.019999999999996, 49.88, 50.74, 51.599999999999994, 52.46, 53.32, 54.18000000000001, 55.04, 55.9, 56.760000000000005, 57.62, 58.480000000000004, 59.34, 60.199999999999996, 61.06, 61.92, 62.78, 63.64, 64.5, 65.36, 66.22, 67.08, 67.94, 68.8, 69.66, 70.52000000000001, 71.38000000000001, 72.24, 73.1, 73.96, 74.82000000000001, 75.68, 76.54, 77.39999999999999, 78.25999999999999, 79.12, 79.98, 80.84, 81.7, 82.56, 83.42, 84.28, 85.14, 86.0, 86.86000000000001], [0.0, 0.8700000000000001, 1.7400000000000002, 2.6100000000000008, 3.4800000000000004, 4.3500000000000005, 5.2200000000000015, 6.090000000000002, 6.960000000000001, 7.830000000000001, 8.700000000000001, 9.570000000000002, 10.440000000000003, 11.310000000000002, 12.180000000000003, 13.05, 13.920000000000002, 14.790000000000003, 15.660000000000002, 16.530000000000005, 17.400000000000002, 18.270000000000003, 19.140000000000004, 20.010000000000005, 20.880000000000006, 21.750000000000004, 22.620000000000005, 23.490000000000006, 24.360000000000007, 25.230000000000008, 26.1, 26.970000000000002, 27.840000000000003, 28.710000000000004, 29.580000000000005, 30.450000000000003, 31.320000000000004, 32.190000000000005, 33.06000000000001, 33.93000000000001, 34.800000000000004, 35.67000000000001, 36.540000000000006, 37.410000000000004, 38.28000000000001, 39.150000000000006, 40.02000000000001, 40.89000000000001, 41.76000000000001, 42.63000000000001, 43.50000000000001, 44.37000000000001, 45.24000000000001, 46.110000000000014, 46.98000000000001, 47.85000000000001, 48.72000000000001, 49.59000000000001, 50.460000000000015, 51.33000000000001, 52.2, 53.070000000000014, 53.940000000000005, 54.81000000000001, 55.68000000000001, 56.550000000000004, 57.42000000000001, 58.290000000000006, 59.16000000000001, 60.03000000000001, 60.900000000000006, 61.77000000000001, 62.64000000000001, 63.51000000000001, 64.38000000000001, 65.25000000000001, 66.12000000000002, 66.99000000000001, 67.86000000000001, 68.73000000000002, 69.60000000000001, 70.47, 71.34000000000002, 72.21000000000001, 73.08000000000001, 73.95, 74.82000000000001, 75.69000000000001, 76.56000000000002, 77.43, 78.30000000000001, 79.17, 80.04000000000002, 80.91000000000001, 81.78000000000002, 82.65, 83.52000000000002, 84.39000000000001, 85.26000000000002, 86.13000000000001, 87.00000000000001, 87.87000000000002], [0.0, 0.8800000000000001, 1.7600000000000002, 2.6400000000000006, 3.5200000000000005, 4.4, 5.280000000000001, 6.160000000000001, 7.040000000000001, 7.920000000000001, 8.8, 9.680000000000001, 10.560000000000002, 11.440000000000001, 12.320000000000002, 13.200000000000001, 14.080000000000002, 14.960000000000003, 15.840000000000002, 16.720000000000002, 17.6, 18.480000000000004, 19.360000000000003, 20.240000000000006, 21.120000000000005, 22.0, 22.880000000000003, 23.760000000000005, 24.640000000000004, 25.520000000000007, 26.400000000000002, 27.280000000000005, 28.160000000000004, 29.040000000000006, 29.920000000000005, 30.800000000000004, 31.680000000000003, 32.56, 33.440000000000005, 34.32000000000001, 35.2, 36.080000000000005, 36.96000000000001, 37.84, 38.720000000000006, 39.6, 40.48000000000001, 41.36000000000001, 42.24000000000001, 43.120000000000005, 44.0, 44.88000000000001, 45.760000000000005, 46.64000000000001, 47.52000000000001, 48.400000000000006, 49.28000000000001, 50.160000000000004, 51.04000000000001, 51.92000000000001, 52.800000000000004, 53.68000000000001, 54.56000000000001, 55.44000000000001, 56.32000000000001, 57.2, 58.08000000000001, 58.96000000000001, 59.84000000000001, 60.720000000000006, 61.60000000000001, 62.48000000000001, 63.36000000000001, 64.24000000000001, 65.12, 66.0, 66.88000000000001, 67.76, 68.64000000000001, 69.52000000000001, 70.4, 71.28, 72.16000000000001, 73.04, 73.92000000000002, 74.80000000000001, 75.68, 76.56000000000002, 77.44000000000001, 78.32000000000001, 79.2, 80.08, 80.96000000000002, 81.84000000000002, 82.72000000000001, 83.60000000000001, 84.48000000000002, 85.36000000000001, 86.24000000000001, 87.12, 88.0, 88.88000000000002], [0.0, 0.8900000000000001, 1.7800000000000002, 2.6700000000000004, 3.5600000000000005, 4.45, 5.340000000000001, 6.23, 7.120000000000001, 8.01, 8.9, 9.790000000000001, 10.680000000000001, 11.57, 12.46, 13.350000000000001, 14.240000000000002, 15.130000000000003, 16.02, 16.91, 17.8, 18.69, 19.580000000000002, 20.470000000000002, 21.360000000000003, 22.25, 23.14, 24.03, 24.92, 25.810000000000006, 26.700000000000003, 27.590000000000003, 28.480000000000004, 29.370000000000005, 30.260000000000005, 31.150000000000002, 32.04, 32.93, 33.82, 34.71000000000001, 35.6, 36.49000000000001, 37.38, 38.27, 39.160000000000004, 40.050000000000004, 40.940000000000005, 41.830000000000005, 42.720000000000006, 43.61000000000001, 44.5, 45.39000000000001, 46.28, 47.17000000000001, 48.06, 48.95, 49.84, 50.730000000000004, 51.62000000000001, 52.510000000000005, 53.400000000000006, 54.290000000000006, 55.18000000000001, 56.07000000000001, 56.96000000000001, 57.85, 58.74000000000001, 59.63, 60.52000000000001, 61.410000000000004, 62.300000000000004, 63.190000000000005, 64.08, 64.97000000000001, 65.86, 66.75, 67.64, 68.53, 69.42000000000002, 70.31, 71.2, 72.09, 72.98000000000002, 73.87, 74.76, 75.65, 76.54, 77.43, 78.32000000000001, 79.21000000000001, 80.10000000000001, 80.99, 81.88000000000001, 82.77000000000001, 83.66000000000001, 84.55, 85.44000000000001, 86.33000000000001, 87.22000000000001, 88.11000000000001, 89.0, 89.89000000000001], [0.0, 0.9, 1.8, 2.7, 3.6, 4.5, 5.4, 6.300000000000001, 7.2, 8.1, 9.0, 9.9, 10.8, 11.700000000000001, 12.600000000000001, 13.5, 14.4, 15.3, 16.2, 17.1, 18.0, 18.900000000000002, 19.8, 20.700000000000003, 21.6, 22.5, 23.400000000000002, 24.3, 25.200000000000003, 26.1, 27.0, 27.900000000000002, 28.8, 29.700000000000003, 30.6, 31.5, 32.4, 33.300000000000004, 34.2, 35.1, 36.0, 36.900000000000006, 37.800000000000004, 38.699999999999996, 39.6, 40.5, 41.400000000000006, 42.300000000000004, 43.2, 44.1, 45.0, 45.900000000000006, 46.800000000000004, 47.7, 48.6, 49.5, 50.400000000000006, 51.300000000000004, 52.2, 53.1, 54.0, 54.900000000000006, 55.800000000000004, 56.7, 57.6, 58.5, 59.400000000000006, 60.300000000000004, 61.2, 62.1, 63.0, 63.900000000000006, 64.8, 65.7, 66.60000000000001, 67.5, 68.4, 69.3, 70.2, 71.10000000000001, 72.0, 72.89999999999999, 73.80000000000001, 74.7, 75.60000000000001, 76.5, 77.39999999999999, 78.30000000000001, 79.2, 80.10000000000001, 81.0, 81.89999999999999, 82.80000000000001, 83.7, 84.60000000000001, 85.5, 86.4, 87.30000000000001, 88.2, 89.10000000000001, 90.0, 90.9], [0.0, 0.91, 1.82, 2.7300000000000004, 3.64, 4.55, 5.460000000000001, 6.37, 7.28, 8.19, 9.1, 10.01, 10.920000000000002, 11.83, 12.74, 13.649999999999999, 14.56, 15.47, 16.38, 17.29, 18.2, 19.11, 20.02, 20.930000000000003, 21.840000000000003, 22.75, 23.66, 24.57, 25.48, 26.39, 27.299999999999997, 28.21, 29.12, 30.03, 30.94, 31.849999999999998, 32.76, 33.67, 34.58, 35.49, 36.4, 37.31, 38.22, 39.129999999999995, 40.04, 40.949999999999996, 41.86000000000001, 42.77, 43.68000000000001, 44.59, 45.5, 46.410000000000004, 47.32, 48.230000000000004, 49.14, 50.05, 50.96, 51.87, 52.78, 53.69, 54.599999999999994, 55.510000000000005, 56.42, 57.330000000000005, 58.24, 59.15, 60.06, 60.97, 61.88, 62.79, 63.699999999999996, 64.61, 65.52, 66.43, 67.34, 68.25, 69.16, 70.07, 70.98, 71.89, 72.8, 73.71, 74.62, 75.53, 76.44, 77.35, 78.25999999999999, 79.17, 80.08, 80.99, 81.89999999999999, 82.80999999999999, 83.72000000000001, 84.63000000000001, 85.54, 86.45, 87.36000000000001, 88.27000000000001, 89.18, 90.09, 91.0, 91.91000000000001], [0.0, 0.9200000000000002, 1.8400000000000003, 2.7600000000000007, 3.6800000000000006, 4.6000000000000005, 5.520000000000001, 6.440000000000001, 7.360000000000001, 8.280000000000001, 9.200000000000001, 10.120000000000003, 11.040000000000003, 11.960000000000003, 12.880000000000003, 13.8, 14.720000000000002, 15.640000000000004, 16.560000000000002, 17.480000000000004, 18.400000000000002, 19.320000000000004, 20.240000000000006, 21.160000000000004, 22.080000000000005, 23.000000000000004, 23.920000000000005, 24.840000000000003, 25.760000000000005, 26.680000000000007, 27.6, 28.520000000000003, 29.440000000000005, 30.360000000000007, 31.28000000000001, 32.2, 33.120000000000005, 34.040000000000006, 34.96000000000001, 35.88000000000001, 36.800000000000004, 37.720000000000006, 38.64000000000001, 39.56, 40.48000000000001, 41.400000000000006, 42.32000000000001, 43.24000000000001, 44.16000000000001, 45.080000000000005, 46.00000000000001, 46.92000000000001, 47.84000000000001, 48.76000000000001, 49.68000000000001, 50.60000000000001, 51.52000000000001, 52.440000000000005, 53.360000000000014, 54.28000000000001, 55.2, 56.12000000000001, 57.040000000000006, 57.960000000000015, 58.88000000000001, 59.800000000000004, 60.72000000000001, 61.64000000000001, 62.56000000000002, 63.48000000000001, 64.4, 65.32000000000001, 66.24000000000001, 67.16000000000001, 68.08000000000001, 69.00000000000001, 69.92000000000002, 70.84, 71.76000000000002, 72.68, 73.60000000000001, 74.52000000000001, 75.44000000000001, 76.36000000000001, 77.28000000000002, 78.2, 79.12, 80.04000000000002, 80.96000000000002, 81.88000000000001, 82.80000000000001, 83.72000000000001, 84.64000000000001, 85.56000000000002, 86.48000000000002, 87.4, 88.32000000000002, 89.24000000000002, 90.16000000000001, 91.08000000000001, 92.00000000000001, 92.92000000000003], [0.0, 0.9300000000000002, 1.8600000000000003, 2.7900000000000005, 3.7200000000000006, 4.65, 5.580000000000001, 6.510000000000001, 7.440000000000001, 8.370000000000001, 9.3, 10.230000000000002, 11.160000000000002, 12.090000000000002, 13.020000000000001, 13.950000000000001, 14.880000000000003, 15.810000000000002, 16.740000000000002, 17.67, 18.6, 19.53, 20.460000000000004, 21.390000000000004, 22.320000000000004, 23.25, 24.180000000000003, 25.110000000000003, 26.040000000000003, 26.970000000000006, 27.900000000000002, 28.830000000000002, 29.760000000000005, 30.690000000000005, 31.620000000000005, 32.550000000000004, 33.480000000000004, 34.410000000000004, 35.34, 36.27, 37.2, 38.13000000000001, 39.06, 39.99, 40.92000000000001, 41.85, 42.78000000000001, 43.71000000000001, 44.64000000000001, 45.57000000000001, 46.5, 47.43000000000001, 48.36000000000001, 49.29000000000001, 50.220000000000006, 51.150000000000006, 52.080000000000005, 53.010000000000005, 53.94000000000001, 54.870000000000005, 55.800000000000004, 56.73000000000001, 57.660000000000004, 58.59000000000001, 59.52000000000001, 60.45, 61.38000000000001, 62.31000000000001, 63.24000000000001, 64.17, 65.10000000000001, 66.03000000000002, 66.96000000000001, 67.89000000000001, 68.82000000000001, 69.75, 70.68, 71.61000000000001, 72.54, 73.47000000000001, 74.4, 75.33, 76.26000000000002, 77.19000000000001, 78.12, 79.05000000000001, 79.98, 80.91000000000001, 81.84000000000002, 82.77000000000001, 83.7, 84.63000000000001, 85.56000000000002, 86.49000000000001, 87.42000000000002, 88.35000000000001, 89.28000000000002, 90.21000000000002, 91.14000000000001, 92.07000000000001, 93.0, 93.93000000000002], [0.0, 0.9400000000000001, 1.8800000000000001, 2.8200000000000007, 3.7600000000000002, 4.7, 5.6400000000000015, 6.580000000000001, 7.5200000000000005, 8.46, 9.4, 10.340000000000002, 11.280000000000003, 12.22, 13.160000000000002, 14.100000000000001, 15.040000000000001, 15.980000000000002, 16.92, 17.860000000000003, 18.8, 19.740000000000002, 20.680000000000003, 21.620000000000005, 22.560000000000006, 23.5, 24.44, 25.380000000000003, 26.320000000000004, 27.260000000000005, 28.200000000000003, 29.14, 30.080000000000002, 31.020000000000003, 31.960000000000004, 32.9, 33.84, 34.78, 35.720000000000006, 36.660000000000004, 37.6, 38.540000000000006, 39.480000000000004, 40.42, 41.36000000000001, 42.300000000000004, 43.24000000000001, 44.18000000000001, 45.12000000000001, 46.06, 47.0, 47.940000000000005, 48.88, 49.82000000000001, 50.760000000000005, 51.7, 52.64000000000001, 53.580000000000005, 54.52000000000001, 55.46000000000001, 56.400000000000006, 57.34000000000001, 58.28, 59.220000000000006, 60.160000000000004, 61.1, 62.040000000000006, 62.980000000000004, 63.92000000000001, 64.86, 65.8, 66.74000000000001, 67.68, 68.62, 69.56, 70.5, 71.44000000000001, 72.38000000000001, 73.32000000000001, 74.26, 75.2, 76.14, 77.08000000000001, 78.02000000000001, 78.96000000000001, 79.9, 80.84, 81.78000000000002, 82.72000000000001, 83.66000000000001, 84.60000000000001, 85.54, 86.48000000000002, 87.42000000000002, 88.36000000000001, 89.3, 90.24000000000002, 91.18, 92.12, 93.06, 94.0, 94.94000000000001], [0.0, 0.9500000000000001, 1.9000000000000001, 2.8500000000000005, 3.8000000000000003, 4.75, 5.700000000000001, 6.65, 7.6000000000000005, 8.55, 9.5, 10.450000000000001, 11.400000000000002, 12.35, 13.3, 14.25, 15.200000000000001, 16.150000000000002, 17.1, 18.05, 19.0, 19.95, 20.900000000000002, 21.85, 22.800000000000004, 23.75, 24.7, 25.650000000000002, 26.6, 27.550000000000004, 28.5, 29.45, 30.400000000000002, 31.35, 32.300000000000004, 33.25, 34.2, 35.15, 36.1, 37.050000000000004, 38.0, 38.95, 39.9, 40.85, 41.800000000000004, 42.75, 43.7, 44.65, 45.60000000000001, 46.550000000000004, 47.5, 48.45, 49.4, 50.35000000000001, 51.300000000000004, 52.25, 53.2, 54.15, 55.10000000000001, 56.050000000000004, 57.0, 57.95, 58.9, 59.85000000000001, 60.800000000000004, 61.75, 62.7, 63.65, 64.60000000000001, 65.55, 66.5, 67.45, 68.4, 69.35000000000001, 70.3, 71.25, 72.2, 73.15, 74.10000000000001, 75.05, 76.0, 76.95, 77.9, 78.85000000000001, 79.8, 80.75, 81.7, 82.65, 83.60000000000001, 84.55, 85.5, 86.45, 87.4, 88.35000000000001, 89.3, 90.25, 91.20000000000002, 92.15, 93.10000000000001, 94.05, 95.0, 95.95000000000002], [0.0, 0.9600000000000002, 1.9200000000000004, 2.880000000000001, 3.8400000000000007, 4.800000000000001, 5.760000000000002, 6.7200000000000015, 7.6800000000000015, 8.640000000000002, 9.600000000000001, 10.560000000000002, 11.520000000000003, 12.480000000000002, 13.440000000000003, 14.400000000000002, 15.360000000000003, 16.320000000000004, 17.280000000000005, 18.240000000000006, 19.200000000000003, 20.160000000000004, 21.120000000000005, 22.080000000000005, 23.040000000000006, 24.000000000000004, 24.960000000000004, 25.920000000000005, 26.880000000000006, 27.840000000000007, 28.800000000000004, 29.760000000000005, 30.720000000000006, 31.680000000000007, 32.64000000000001, 33.60000000000001, 34.56000000000001, 35.52000000000001, 36.48000000000001, 37.44000000000001, 38.400000000000006, 39.360000000000014, 40.32000000000001, 41.28, 42.24000000000001, 43.2, 44.16000000000001, 45.12000000000001, 46.08000000000001, 47.04000000000001, 48.00000000000001, 48.960000000000015, 49.92000000000001, 50.88000000000002, 51.84000000000001, 52.80000000000001, 53.76000000000001, 54.72000000000001, 55.680000000000014, 56.640000000000015, 57.60000000000001, 58.56000000000002, 59.52000000000001, 60.48000000000002, 61.44000000000001, 62.400000000000006, 63.360000000000014, 64.32000000000001, 65.28000000000002, 66.24000000000001, 67.20000000000002, 68.16000000000001, 69.12000000000002, 70.08000000000001, 71.04000000000002, 72.00000000000001, 72.96000000000002, 73.92000000000002, 74.88000000000002, 75.84000000000002, 76.80000000000001, 77.76, 78.72000000000003, 79.68000000000002, 80.64000000000001, 81.60000000000001, 82.56, 83.52000000000002, 84.48000000000002, 85.44000000000001, 86.4, 87.36000000000001, 88.32000000000002, 89.28000000000002, 90.24000000000002, 91.20000000000002, 92.16000000000003, 93.12000000000002, 94.08000000000003, 95.04000000000002, 96.00000000000001, 96.96000000000002], [0.0, 0.9700000000000002, 1.9400000000000004, 2.9100000000000006, 3.880000000000001, 4.8500000000000005, 5.820000000000001, 6.790000000000002, 7.760000000000002, 8.73, 9.700000000000001, 10.670000000000002, 11.640000000000002, 12.610000000000001, 13.580000000000004, 14.55, 15.520000000000003, 16.490000000000002, 17.46, 18.430000000000003, 19.400000000000002, 20.370000000000005, 21.340000000000003, 22.310000000000006, 23.280000000000005, 24.250000000000004, 25.220000000000002, 26.190000000000005, 27.160000000000007, 28.130000000000006, 29.1, 30.070000000000004, 31.040000000000006, 32.010000000000005, 32.980000000000004, 33.95, 34.92, 35.89000000000001, 36.86000000000001, 37.830000000000005, 38.800000000000004, 39.77000000000001, 40.74000000000001, 41.71, 42.68000000000001, 43.650000000000006, 44.62000000000001, 45.59, 46.56000000000001, 47.53000000000001, 48.50000000000001, 49.47000000000001, 50.440000000000005, 51.41000000000001, 52.38000000000001, 53.35000000000001, 54.320000000000014, 55.290000000000006, 56.26000000000001, 57.23000000000001, 58.2, 59.17000000000001, 60.14000000000001, 61.110000000000014, 62.08000000000001, 63.050000000000004, 64.02000000000001, 64.99000000000001, 65.96000000000001, 66.93, 67.9, 68.87000000000002, 69.84, 70.81000000000002, 71.78000000000002, 72.75000000000001, 73.72000000000001, 74.69000000000001, 75.66000000000001, 76.63000000000001, 77.60000000000001, 78.57000000000001, 79.54000000000002, 80.51000000000002, 81.48000000000002, 82.45, 83.42, 84.39000000000001, 85.36000000000001, 86.33000000000001, 87.30000000000001, 88.27000000000001, 89.24000000000002, 90.21000000000002, 91.18, 92.15, 93.12000000000002, 94.09000000000002, 95.06000000000002, 96.03000000000002, 97.00000000000001, 97.97000000000003], [0.0, 0.9800000000000001, 1.9600000000000002, 2.940000000000001, 3.9200000000000004, 4.9, 5.880000000000002, 6.860000000000001, 7.840000000000001, 8.82, 9.8, 10.780000000000001, 11.760000000000003, 12.740000000000002, 13.720000000000002, 14.700000000000001, 15.680000000000001, 16.660000000000004, 17.64, 18.62, 19.6, 20.580000000000002, 21.560000000000002, 22.540000000000003, 23.520000000000007, 24.5, 25.480000000000004, 26.460000000000004, 27.440000000000005, 28.420000000000005, 29.400000000000002, 30.380000000000003, 31.360000000000003, 32.34, 33.32000000000001, 34.300000000000004, 35.28, 36.260000000000005, 37.24, 38.220000000000006, 39.2, 40.18000000000001, 41.160000000000004, 42.14, 43.120000000000005, 44.1, 45.080000000000005, 46.06, 47.04000000000001, 48.02000000000001, 49.0, 49.98000000000001, 50.96000000000001, 51.94000000000001, 52.92000000000001, 53.900000000000006, 54.88000000000001, 55.86000000000001, 56.84000000000001, 57.82000000000001, 58.800000000000004, 59.78000000000001, 60.760000000000005, 61.74000000000001, 62.720000000000006, 63.7, 64.68, 65.66000000000001, 66.64000000000001, 67.62, 68.60000000000001, 69.58000000000001, 70.56, 71.54, 72.52000000000001, 73.5, 74.48, 75.46000000000001, 76.44000000000001, 77.42000000000002, 78.4, 79.38, 80.36000000000001, 81.34000000000002, 82.32000000000001, 83.30000000000001, 84.28, 85.26000000000002, 86.24000000000001, 87.22000000000001, 88.2, 89.18, 90.16000000000001, 91.14000000000001, 92.12, 93.10000000000001, 94.08000000000003, 95.06000000000002, 96.04000000000002, 97.02000000000001, 98.0, 98.98000000000002], [0.0, 0.9900000000000001, 1.9800000000000002, 2.9700000000000006, 3.9600000000000004, 4.95, 5.940000000000001, 6.930000000000001, 7.920000000000001, 8.91, 9.9, 10.89, 11.880000000000003, 12.870000000000001, 13.860000000000001, 14.850000000000001, 15.840000000000002, 16.830000000000002, 17.82, 18.810000000000002, 19.8, 20.790000000000003, 21.78, 22.770000000000003, 23.760000000000005, 24.75, 25.740000000000002, 26.730000000000004, 27.720000000000002, 28.710000000000004, 29.700000000000003, 30.69, 31.680000000000003, 32.67, 33.660000000000004, 34.65, 35.64, 36.63, 37.620000000000005, 38.61000000000001, 39.6, 40.59, 41.580000000000005, 42.57, 43.56, 44.550000000000004, 45.540000000000006, 46.53, 47.52000000000001, 48.510000000000005, 49.5, 50.49000000000001, 51.480000000000004, 52.470000000000006, 53.46000000000001, 54.45, 55.440000000000005, 56.43000000000001, 57.42000000000001, 58.410000000000004, 59.400000000000006, 60.39000000000001, 61.38, 62.37000000000001, 63.36000000000001, 64.35000000000001, 65.34, 66.33, 67.32000000000001, 68.31, 69.3, 70.29, 71.28, 72.27000000000001, 73.26, 74.25, 75.24000000000001, 76.23, 77.22000000000001, 78.21000000000001, 79.2, 80.19, 81.18, 82.17000000000002, 83.16000000000001, 84.15, 85.14, 86.13000000000001, 87.12, 88.11000000000001, 89.10000000000001, 90.09, 91.08000000000001, 92.07000000000001, 93.06, 94.05, 95.04000000000002, 96.03000000000002, 97.02000000000001, 98.01, 99.0, 99.99000000000002], [0.0, 1.0, 2.0, 3.0000000000000004, 4.0, 5.0, 6.000000000000001, 7.000000000000001, 8.0, 9.0, 10.0, 11.0, 12.000000000000002, 13.0, 14.000000000000002, 15.0, 16.0, 17.0, 18.0, 19.0, 20.0, 21.0, 22.0, 23.000000000000004, 24.000000000000004, 25.0, 26.0, 27.0, 28.000000000000004, 29.000000000000004, 30.0, 31.0, 32.0, 33.0, 34.0, 35.0, 36.0, 37.0, 38.0, 39.0, 40.0, 41.00000000000001, 42.0, 43.0, 44.0, 45.0, 46.00000000000001, 47.0, 48.00000000000001, 49.0, 50.0, 51.00000000000001, 52.0, 53.00000000000001, 54.0, 55.0, 56.00000000000001, 57.0, 58.00000000000001, 59.0, 60.0, 61.00000000000001, 62.0, 63.00000000000001, 64.0, 65.0, 66.0, 67.0, 68.0, 69.0, 70.0, 71.0, 72.0, 73.0, 74.0, 75.0, 76.0, 77.0, 78.0, 79.0, 80.0, 81.0, 82.00000000000001, 83.0, 84.0, 85.0, 86.0, 87.00000000000001, 88.0, 89.0, 90.0, 91.0, 92.00000000000001, 93.0, 94.0, 95.0, 96.00000000000001, 97.00000000000001, 98.0, 99.0, 100.0, 101.00000000000001], [0.0, 1.0100000000000002, 2.0200000000000005, 3.0300000000000007, 4.040000000000001, 5.050000000000001, 6.060000000000001, 7.070000000000002, 8.080000000000002, 9.090000000000002, 10.100000000000001, 11.110000000000003, 12.120000000000003, 13.130000000000003, 14.140000000000004, 15.150000000000002, 16.160000000000004, 17.170000000000005, 18.180000000000003, 19.190000000000005, 20.200000000000003, 21.210000000000004, 22.220000000000006, 23.230000000000008, 24.240000000000006, 25.250000000000004, 26.260000000000005, 27.270000000000007, 28.28000000000001, 29.290000000000006, 30.300000000000004, 31.310000000000006, 32.32000000000001, 33.330000000000005, 34.34000000000001, 35.35000000000001, 36.36000000000001, 37.370000000000005, 38.38000000000001, 39.39000000000001, 40.400000000000006, 41.41000000000001, 42.42000000000001, 43.43000000000001, 44.44000000000001, 45.45, 46.460000000000015, 47.470000000000006, 48.48000000000001, 49.49000000000001, 50.50000000000001, 51.51000000000001, 52.52000000000001, 53.530000000000015, 54.54000000000001, 55.55000000000001, 56.56000000000002, 57.57000000000001, 58.58000000000001, 59.59000000000001, 60.60000000000001, 61.610000000000014, 62.62000000000001, 63.63000000000002, 64.64000000000001, 65.65, 66.66000000000001, 67.67000000000002, 68.68000000000002, 69.69000000000001, 70.70000000000002, 71.71000000000002, 72.72000000000001, 73.73000000000002, 74.74000000000001, 75.75000000000001, 76.76000000000002, 77.77000000000001, 78.78000000000002, 79.79000000000002, 80.80000000000001, 81.81, 82.82000000000002, 83.83000000000001, 84.84000000000002, 85.85000000000001, 86.86000000000001, 87.87000000000002, 88.88000000000002, 89.89000000000001, 90.9, 91.91000000000001, 92.92000000000003, 93.93000000000002, 94.94000000000001, 95.95000000000002, 96.96000000000002, 97.97000000000003, 98.98000000000002, 99.99000000000002, 101.00000000000001, 102.01000000000003]]}, {\"colorscale\": [[0.0, \"#440154\"], [0.1111111111111111, \"#482878\"], [0.2222222222222222, \"#3e4989\"], [0.3333333333333333, \"#31688e\"], [0.4444444444444444, \"#26828e\"], [0.5555555555555556, \"#1f9e89\"], [0.6666666666666666, \"#35b779\"], [0.7777777777777778, \"#6ece58\"], [0.8888888888888888, \"#b5de2b\"], [1.0, \"#fde725\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 1\", \"showscale\": false, \"type\": \"surface\", \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.1, 0.1414213562373095, 0.17320508075688776, 0.2, 0.223606797749979, 0.24494897427831783, 0.2645751311064591, 0.282842712474619, 0.3, 0.31622776601683794, 0.33166247903554, 0.3464101615137755, 0.36055512754639896, 0.37416573867739417, 0.38729833462074165, 0.4, 0.41231056256176607, 0.4242640687119285, 0.43588989435406744, 0.447213595499958, 0.45825756949558405, 0.469041575982343, 0.479583152331272, 0.48989794855663565, 0.5, 0.5099019513592785, 0.5196152422706632, 0.5291502622129182, 0.5385164807134505, 0.5477225575051661, 0.5567764362830022, 0.565685424949238, 0.574456264653803, 0.5830951894845301, 0.5916079783099616, 0.6, 0.608276253029822, 0.6164414002968976, 0.6244997998398399, 0.6324555320336759, 0.6403124237432849, 0.6480740698407861, 0.6557438524302001, 0.66332495807108, 0.6708203932499369, 0.6782329983125268, 0.6855654600401044, 0.692820323027551, 0.7000000000000001, 0.7071067811865476, 0.7141428428542851, 0.7211102550927979, 0.7280109889280519, 0.7348469228349535, 0.7416198487095663, 0.7483314773547883, 0.754983443527075, 0.7615773105863909, 0.7681145747868608, 0.7745966692414833, 0.7810249675906654, 0.787400787401181, 0.7937253933193772, 0.8, 0.8062257748298549, 0.812403840463596, 0.8185352771872451, 0.8246211251235321, 0.8306623862918076, 0.8366600265340756, 0.8426149773176359, 0.848528137423857, 0.8544003745317531, 0.8602325267042626, 0.8660254037844387, 0.8717797887081349, 0.8774964387392122, 0.8831760866327848, 0.8888194417315589, 0.894427190999916, 0.9, 0.9055385138137417, 0.9110433579144299, 0.9165151389911681, 0.9219544457292888, 0.9273618495495705, 0.9327379053088816, 0.938083151964686, 0.9433981132056604, 0.9486832980505138, 0.9539392014169457, 0.959166304662544, 0.9643650760992956, 0.9695359714832659, 0.9746794344808963, 0.9797958971132713, 0.9848857801796106, 0.9899494936611666, 0.9949874371066201, 1.0, 1.0049875621120892], [0.0, 0.1414213562373095, 0.19999999999999998, 0.24494897427831783, 0.282842712474619, 0.31622776601683794, 0.34641016151377546, 0.3741657386773941, 0.39999999999999997, 0.4242640687119285, 0.4472135954999579, 0.469041575982343, 0.48989794855663565, 0.5099019513592785, 0.529150262212918, 0.5477225575051661, 0.565685424949238, 0.58309518948453, 0.6, 0.6164414002968976, 0.6324555320336759, 0.6480740698407861, 0.6633249580710799, 0.6782329983125268, 0.6928203230275509, 0.7071067811865476, 0.7211102550927979, 0.7348469228349535, 0.7483314773547882, 0.7615773105863909, 0.7745966692414833, 0.7874007874011811, 0.7999999999999999, 0.812403840463596, 0.8246211251235321, 0.8366600265340756, 0.848528137423857, 0.8602325267042626, 0.8717797887081348, 0.8831760866327847, 0.8944271909999159, 0.9055385138137417, 0.9165151389911681, 0.9273618495495702, 0.938083151964686, 0.9486832980505137, 0.9591663046625439, 0.9695359714832658, 0.9797958971132713, 0.9899494936611665, 1.0, 1.0099504938362078, 1.019803902718557, 1.0295630140987002, 1.0392304845413265, 1.0488088481701516, 1.058300524425836, 1.0677078252031311, 1.0770329614269007, 1.0862780491200215, 1.0954451150103321, 1.104536101718726, 1.1135528725660042, 1.1224972160321824, 1.131370849898476, 1.1401754250991378, 1.1489125293076057, 1.1575836902790224, 1.16619037896906, 1.174734012447073, 1.1832159566199232, 1.1916375287812984, 1.2, 1.2083045973594573, 1.2165525060596438, 1.224744871391589, 1.2328828005937953, 1.2409673645990857, 1.2489995996796797, 1.2569805089976536, 1.2649110640673518, 1.2727922061357855, 1.2806248474865698, 1.2884098726725124, 1.2961481396815722, 1.3038404810405297, 1.3114877048604001, 1.3190905958272918, 1.3266499161421599, 1.3341664064126333, 1.3416407864998738, 1.349073756323204, 1.3564659966250536, 1.3638181696985856, 1.3711309200802089, 1.378404875209022, 1.3856406460551018, 1.392838827718412, 1.4, 1.407124727947029, 1.4142135623730951, 1.4212670403551897], [0.0, 0.17320508075688776, 0.24494897427831783, 0.3000000000000001, 0.3464101615137755, 0.38729833462074176, 0.42426406871192857, 0.45825756949558405, 0.48989794855663565, 0.5196152422706632, 0.5477225575051662, 0.574456264653803, 0.6000000000000002, 0.6244997998398399, 0.6480740698407861, 0.6708203932499369, 0.692820323027551, 0.7141428428542851, 0.7348469228349536, 0.7549834435270751, 0.7745966692414835, 0.7937253933193773, 0.8124038404635961, 0.8306623862918077, 0.8485281374238571, 0.8660254037844388, 0.8831760866327849, 0.9000000000000001, 0.9165151389911681, 0.9327379053088817, 0.9486832980505139, 0.9643650760992957, 0.9797958971132713, 0.9949874371066202, 1.009950493836208, 1.02469507659596, 1.0392304845413265, 1.053565375285274, 1.0677078252031313, 1.081665382639197, 1.0954451150103324, 1.1090536506409419, 1.1224972160321827, 1.1357816691600549, 1.148912529307606, 1.161895003862225, 1.1747340124470733, 1.187434208703792, 1.2000000000000004, 1.2124355652982142, 1.2247448713915892, 1.2369316876852985, 1.2489995996796799, 1.2609520212918495, 1.2727922061357857, 1.2845232578665131, 1.2961481396815722, 1.3076696830622023, 1.3190905958272923, 1.3304134695650072, 1.3416407864998738, 1.3527749258468684, 1.3638181696985856, 1.3747727084867523, 1.385640646055102, 1.3964240043768943, 1.4071247279470291, 1.4177446878757827, 1.4282856857085702, 1.4387494569938162, 1.4491376746189442, 1.4594519519326425, 1.4696938456699071, 1.4798648586948744, 1.489966442575134, 1.5000000000000002, 1.5099668870541503, 1.5198684153570665, 1.5297058540778359, 1.5394804318340656, 1.549193338482967, 1.5588457268119897, 1.5684387141358125, 1.5779733838059502, 1.5874507866387546, 1.5968719422671316, 1.6062378404209012, 1.6155494421403516, 1.6248076809271923, 1.6340134638368193, 1.6431676725154984, 1.6522711641858308, 1.6613247725836153, 1.670329308849007, 1.6792855623746668, 1.6881943016134133, 1.6970562748477143, 1.7058722109231985, 1.7146428199482249, 1.7233687939614089, 1.7320508075688776, 1.7406895185529214], [0.0, 0.2, 0.282842712474619, 0.3464101615137755, 0.4, 0.447213595499958, 0.48989794855663565, 0.5291502622129182, 0.565685424949238, 0.6, 0.6324555320336759, 0.66332495807108, 0.692820323027551, 0.7211102550927979, 0.7483314773547883, 0.7745966692414833, 0.8, 0.8246211251235321, 0.848528137423857, 0.8717797887081349, 0.894427190999916, 0.9165151389911681, 0.938083151964686, 0.959166304662544, 0.9797958971132713, 1.0, 1.019803902718557, 1.0392304845413265, 1.0583005244258363, 1.077032961426901, 1.0954451150103321, 1.1135528725660044, 1.131370849898476, 1.148912529307606, 1.1661903789690602, 1.1832159566199232, 1.2, 1.216552506059644, 1.2328828005937953, 1.2489995996796799, 1.2649110640673518, 1.2806248474865698, 1.2961481396815722, 1.3114877048604001, 1.32664991614216, 1.3416407864998738, 1.3564659966250536, 1.3711309200802089, 1.385640646055102, 1.4000000000000001, 1.4142135623730951, 1.4282856857085702, 1.4422205101855958, 1.4560219778561039, 1.469693845669907, 1.4832396974191326, 1.4966629547095767, 1.50996688705415, 1.5231546211727818, 1.5362291495737217, 1.5491933384829666, 1.5620499351813308, 1.574801574802362, 1.5874507866387544, 1.6, 1.6124515496597098, 1.624807680927192, 1.6370705543744901, 1.6492422502470643, 1.661324772583615, 1.6733200530681511, 1.6852299546352718, 1.697056274847714, 1.7088007490635062, 1.7204650534085253, 1.7320508075688774, 1.7435595774162698, 1.7549928774784245, 1.7663521732655696, 1.7776388834631178, 1.788854381999832, 1.8, 1.8110770276274835, 1.8220867158288598, 1.8330302779823362, 1.8439088914585775, 1.854723699099141, 1.8654758106177631, 1.876166303929372, 1.8867962264113207, 1.8973665961010275, 1.9078784028338913, 1.918332609325088, 1.9287301521985911, 1.9390719429665317, 1.9493588689617927, 1.9595917942265426, 1.9697715603592212, 1.9798989873223332, 1.9899748742132402, 2.0, 2.0099751242241783], [0.0, 0.223606797749979, 0.31622776601683794, 0.38729833462074176, 0.447213595499958, 0.5000000000000001, 0.5477225575051662, 0.5916079783099617, 0.6324555320336759, 0.6708203932499369, 0.7071067811865476, 0.7416198487095664, 0.7745966692414835, 0.806225774829855, 0.8366600265340756, 0.8660254037844386, 0.894427190999916, 0.9219544457292888, 0.9486832980505139, 0.9746794344808966, 1.0000000000000002, 1.02469507659596, 1.0488088481701516, 1.072380529476361, 1.0954451150103324, 1.118033988749895, 1.140175425099138, 1.1618950038622253, 1.1832159566199234, 1.2041594578792296, 1.2247448713915892, 1.2449899597988734, 1.2649110640673518, 1.2845232578665131, 1.30384048104053, 1.3228756555322954, 1.3416407864998738, 1.3601470508735445, 1.3784048752090223, 1.3964240043768943, 1.4142135623730951, 1.4317821063276355, 1.4491376746189442, 1.466287829861518, 1.4832396974191329, 1.5, 1.5165750888103102, 1.5329709716755893, 1.549193338482967, 1.565247584249853, 1.5811388300841898, 1.5968719422671316, 1.61245154965971, 1.627882059609971, 1.6431676725154984, 1.6583123951777001, 1.6733200530681511, 1.6881943016134133, 1.7029386365926404, 1.7175564037317668, 1.7320508075688772, 1.746424919657298, 1.760681686165901, 1.7748239349298849, 1.788854381999832, 1.8027756377319946, 1.8165902124584952, 1.8303005217723127, 1.8439088914585775, 1.8574175621006712, 1.8708286933869709, 1.8841443681416774, 1.8973665961010278, 1.91049731745428, 1.9235384061671346, 1.9364916731037085, 1.9493588689617931, 1.9621416870348585, 1.9748417658131503, 1.9874606914351793, 2.0000000000000004, 2.012461179749811, 2.024845673131659, 2.0371548787463363, 2.04939015319192, 2.0615528128088303, 2.0736441353327724, 2.0856653614614213, 2.0976176963403033, 2.1095023109728985, 2.121320343559643, 2.1330729007701543, 2.144761058952722, 2.1563858652847827, 2.1679483388678804, 2.179449471770337, 2.1908902300206647, 2.2022715545545246, 2.2135943621178655, 2.224859546128699, 2.23606797749979, 2.2472205054244236], [0.0, 0.24494897427831783, 0.34641016151377546, 0.42426406871192857, 0.48989794855663565, 0.5477225575051662, 0.6000000000000001, 0.6480740698407861, 0.6928203230275509, 0.7348469228349535, 0.7745966692414834, 0.8124038404635961, 0.8485281374238571, 0.8831760866327848, 0.916515138991168, 0.9486832980505138, 0.9797958971132713, 1.0099504938362078, 1.0392304845413265, 1.0677078252031313, 1.0954451150103324, 1.1224972160321824, 1.148912529307606, 1.174734012447073, 1.2000000000000002, 1.2247448713915892, 1.2489995996796799, 1.2727922061357857, 1.2961481396815722, 1.319090595827292, 1.3416407864998738, 1.3638181696985856, 1.3856406460551018, 1.4071247279470291, 1.4282856857085702, 1.449137674618944, 1.469693845669907, 1.489966442575134, 1.50996688705415, 1.5297058540778357, 1.5491933384829668, 1.5684387141358125, 1.5874507866387546, 1.606237840420901, 1.6248076809271923, 1.6431676725154982, 1.661324772583615, 1.6792855623746665, 1.6970562748477143, 1.7146428199482247, 1.7320508075688774, 1.7492855684535904, 1.7663521732655696, 1.7832554500127011, 1.8, 1.8165902124584952, 1.833030277982336, 1.849324200890693, 1.8654758106177631, 1.8814887722226779, 1.8973665961010275, 1.9131126469708992, 1.928730152198591, 1.9442222095223582, 1.9595917942265426, 1.9748417658131499, 1.98997487421324, 2.004993765576342, 2.0199009876724157, 2.0346989949375804, 2.04939015319192, 2.0639767440550294, 2.078460969082653, 2.092844953645635, 2.1071307505705477, 2.121320343559643, 2.1354156504062627, 2.149418526020468, 2.1633307652783937, 2.177154105707724, 2.1908902300206647, 2.2045407685048604, 2.2181073012818837, 2.2315913604421396, 2.244994432064365, 2.2583179581272432, 2.2715633383201097, 2.2847319317591728, 2.297825058615212, 2.3108440016582685, 2.32379000772445, 2.3366642891095846, 2.349468024894146, 2.3622023622035435, 2.374868417407584, 2.3874672772626644, 2.4000000000000004, 2.412467616362964, 2.4248711305964283, 2.4372115213907883, 2.4494897427831783, 2.4617067250182347], [0.0, 0.2645751311064591, 0.3741657386773941, 0.45825756949558405, 0.5291502622129182, 0.5916079783099617, 0.6480740698407861, 0.7000000000000001, 0.7483314773547882, 0.7937253933193772, 0.8366600265340756, 0.8774964387392122, 0.9165151389911681, 0.9539392014169458, 0.9899494936611666, 1.0246950765959597, 1.0583005244258363, 1.0908712114635715, 1.1224972160321824, 1.1532562594670797, 1.1832159566199234, 1.2124355652982142, 1.2409673645990857, 1.2688577540449522, 1.2961481396815722, 1.3228756555322954, 1.3490737563232043, 1.374772708486752, 1.4000000000000001, 1.4247806848775009, 1.4491376746189437, 1.4730919862656235, 1.4966629547095764, 1.5198684153570665, 1.5427248620541514, 1.5652475842498528, 1.5874507866387544, 1.6093476939431082, 1.6309506430300091, 1.6522711641858308, 1.6733200530681511, 1.6941074346097418, 1.7146428199482249, 1.7349351572897471, 1.7549928774784245, 1.7748239349298847, 1.7944358444926363, 1.8138357147217055, 1.8330302779823362, 1.8520259177452134, 1.8708286933869709, 1.8894443627691186, 1.9078784028338915, 1.9261360284258224, 1.9442222095223582, 1.9621416870348585, 1.9798989873223332, 1.997498435543818, 2.0149441679609885, 2.0322401432901573, 2.0493901531919194, 2.0663978319771825, 2.083266665599966, 2.1, 2.1166010488516727, 2.133072900770154, 2.149418526020468, 2.1656407827707715, 2.181742422927143, 2.1977260975835913, 2.2135943621178655, 2.2293496809607953, 2.244994432064365, 2.260530911091463, 2.2759613353482084, 2.29128784747792, 2.3065125189341593, 2.32163735324878, 2.336664289109585, 2.3515952032609695, 2.366431913239847, 2.3811761799581315, 2.395829710142188, 2.41039415863879, 2.4248711305964283, 2.4392621835300936, 2.4535688292770597, 2.4677925358506134, 2.4819347291981715, 2.495996794869737, 2.5099800796022267, 2.5238858928247927, 2.5377155080899043, 2.551470164434615, 2.5651510676761324, 2.578759391645525, 2.5922962793631443, 2.6057628441590768, 2.619160170741759, 2.632489316217637, 2.6457513110645907, 2.6589471600616665], [0.0, 0.282842712474619, 0.39999999999999997, 0.48989794855663565, 0.565685424949238, 0.6324555320336759, 0.6928203230275509, 0.7483314773547882, 0.7999999999999999, 0.848528137423857, 0.8944271909999159, 0.938083151964686, 0.9797958971132713, 1.019803902718557, 1.058300524425836, 1.0954451150103321, 1.131370849898476, 1.16619037896906, 1.2, 1.2328828005937953, 1.2649110640673518, 1.2961481396815722, 1.3266499161421599, 1.3564659966250536, 1.3856406460551018, 1.4142135623730951, 1.4422205101855958, 1.469693845669907, 1.4966629547095764, 1.5231546211727818, 1.5491933384829666, 1.5748015748023623, 1.5999999999999999, 1.624807680927192, 1.6492422502470643, 1.6733200530681511, 1.697056274847714, 1.7204650534085253, 1.7435595774162695, 1.7663521732655694, 1.7888543819998317, 1.8110770276274835, 1.8330302779823362, 1.8547236990991405, 1.876166303929372, 1.8973665961010273, 1.9183326093250879, 1.9390719429665315, 1.9595917942265426, 1.979898987322333, 2.0, 2.0199009876724157, 2.039607805437114, 2.0591260281974004, 2.078460969082653, 2.0976176963403033, 2.116601048851672, 2.1354156504062622, 2.1540659228538015, 2.172556098240043, 2.1908902300206643, 2.209072203437452, 2.2271057451320084, 2.244994432064365, 2.262741699796952, 2.2803508501982757, 2.2978250586152114, 2.315167380558045, 2.33238075793812, 2.349468024894146, 2.3664319132398464, 2.3832750575625967, 2.4, 2.4166091947189146, 2.4331050121192876, 2.449489742783178, 2.4657656011875906, 2.4819347291981715, 2.4979991993593593, 2.513961017995307, 2.5298221281347035, 2.545584412271571, 2.5612496949731396, 2.576819745345025, 2.5922962793631443, 2.6076809620810595, 2.6229754097208002, 2.6381811916545836, 2.6532998322843198, 2.6683328128252666, 2.6832815729997477, 2.698147512646408, 2.7129319932501073, 2.727636339397171, 2.7422618401604177, 2.756809750418044, 2.7712812921102037, 2.785677655436824, 2.8, 2.814249455894058, 2.8284271247461903, 2.8425340807103794], [0.0, 0.3, 0.4242640687119285, 0.5196152422706632, 0.6, 0.6708203932499369, 0.7348469228349535, 0.7937253933193772, 0.848528137423857, 0.8999999999999999, 0.9486832980505138, 0.99498743710662, 1.0392304845413265, 1.0816653826391969, 1.1224972160321824, 1.1618950038622249, 1.2, 1.236931687685298, 1.2727922061357855, 1.307669683062202, 1.3416407864998738, 1.374772708486752, 1.407124727947029, 1.438749456993816, 1.469693845669907, 1.5, 1.5297058540778354, 1.5588457268119895, 1.5874507866387544, 1.6155494421403513, 1.6431676725154982, 1.6703293088490065, 1.697056274847714, 1.7233687939614086, 1.7492855684535902, 1.7748239349298847, 1.7999999999999998, 1.8248287590894658, 1.849324200890693, 1.8734993995195195, 1.8973665961010275, 1.9209372712298547, 1.9442222095223582, 1.9672315572906, 1.98997487421324, 2.0124611797498106, 2.0346989949375804, 2.056696380120313, 2.078460969082653, 2.1, 2.1213203435596424, 2.142428528562855, 2.1633307652783937, 2.1840329667841556, 2.2045407685048604, 2.224859546128699, 2.244994432064365, 2.264950330581225, 2.2847319317591723, 2.3043437243605824, 2.3237900077244498, 2.3430749027719964, 2.362202362203543, 2.3811761799581315, 2.4, 2.4186773244895647, 2.437211521390788, 2.455605831561735, 2.473863375370596, 2.4919871588754225, 2.5099800796022267, 2.5278449319529073, 2.545584412271571, 2.563201123595259, 2.580697580112788, 2.598076211353316, 2.615339366124404, 2.6324893162176366, 2.6495282598983545, 2.6664583251946765, 2.6832815729997477, 2.7, 2.716615541441225, 2.7331300737432893, 2.749545416973504, 2.765863337187866, 2.7820855486487113, 2.7982137159266447, 2.814249455894058, 2.830194339616981, 2.846049894151541, 2.8618176042508368, 2.877498913987632, 2.8930952282978866, 2.9086079144497976, 2.9240383034426887, 2.939387691339814, 2.9546573405388314, 2.9698484809834995, 2.98496231131986, 3.0, 3.0149626863362675], [0.0, 0.31622776601683794, 0.4472135954999579, 0.5477225575051662, 0.6324555320336759, 0.7071067811865476, 0.7745966692414834, 0.8366600265340756, 0.8944271909999159, 0.9486832980505138, 1.0, 1.0488088481701516, 1.0954451150103324, 1.140175425099138, 1.1832159566199232, 1.224744871391589, 1.2649110640673518, 1.3038404810405297, 1.3416407864998738, 1.3784048752090223, 1.4142135623730951, 1.449137674618944, 1.4832396974191326, 1.5165750888103102, 1.5491933384829668, 1.5811388300841898, 1.61245154965971, 1.6431676725154984, 1.6733200530681511, 1.7029386365926402, 1.7320508075688772, 1.760681686165901, 1.7888543819998317, 1.8165902124584952, 1.8439088914585775, 1.8708286933869707, 1.8973665961010275, 1.9235384061671346, 1.949358868961793, 1.97484176581315, 2.0, 2.024845673131659, 2.04939015319192, 2.073644135332772, 2.0976176963403033, 2.1213203435596424, 2.1447610589527217, 2.16794833886788, 2.1908902300206647, 2.2135943621178655, 2.23606797749979, 2.2583179581272432, 2.280350850198276, 2.302172886644268, 2.32379000772445, 2.345207879911715, 2.3664319132398464, 2.3874672772626644, 2.4083189157584592, 2.4289915602982237, 2.449489742783178, 2.4698178070456938, 2.4899799195977463, 2.5099800796022267, 2.5298221281347035, 2.5495097567963922, 2.569046515733026, 2.588435821108957, 2.6076809620810595, 2.6267851073127395, 2.6457513110645907, 2.6645825188948455, 2.6832815729997477, 2.701851217221259, 2.7202941017470885, 2.7386127875258306, 2.7568097504180447, 2.7748873851023217, 2.7928480087537886, 2.8106938645110393, 2.8284271247461903, 2.8460498941515415, 2.863564212655271, 2.8809720581775866, 2.898275349237888, 2.9154759474226504, 2.932575659723036, 2.9495762407505253, 2.9664793948382653, 2.9832867780352594, 3.0, 3.0166206257996713, 3.0331501776206204, 3.0495901363953815, 3.0659419433511785, 3.082207001484488, 3.0983866769659336, 3.1144823004794877, 3.1304951684997055, 3.146426544510455, 3.1622776601683795, 3.178049716414141], [0.0, 0.33166247903554, 0.469041575982343, 0.574456264653803, 0.66332495807108, 0.7416198487095664, 0.8124038404635961, 0.8774964387392122, 0.938083151964686, 0.99498743710662, 1.0488088481701516, 1.1, 1.148912529307606, 1.1958260743101399, 1.2409673645990857, 1.284523257866513, 1.32664991614216, 1.3674794331177345, 1.407124727947029, 1.4456832294800963, 1.4832396974191329, 1.5198684153570665, 1.5556349186104048, 1.5905973720586868, 1.6248076809271923, 1.6583123951777001, 1.6911534525287766, 1.7233687939614089, 1.7549928774784245, 1.7860571099491753, 1.816590212458495, 1.846618531261939, 1.876166303929372, 1.9052558883257653, 1.9339079605813718, 1.9621416870348585, 1.98997487421324, 2.017424100183202, 2.0445048300260877, 2.0712315177207983, 2.0976176963403033, 2.1236760581595306, 2.149418526020468, 2.1748563170931545, 2.2, 2.224859546128699, 2.249444375840399, 2.273763400180415, 2.297825058615212, 2.32163735324878, 2.345207879911715, 2.368543856465403, 2.3916521486202797, 2.4145392935299275, 2.4372115213907883, 2.459674775249769, 2.4819347291981715, 2.503996805109783, 2.525866188063018, 2.5475478405713994, 2.569046515733026, 2.5903667693977237, 2.6115129714401193, 2.632489316217637, 2.65329983228432, 2.6739483914241875, 2.6944387170614963, 2.714774392099646, 2.734958866235469, 2.7549954627911823, 2.774887385102322, 2.7946377224964243, 2.814249455894058, 2.833725463060951, 2.8530685235374214, 2.8722813232690148, 2.8913664589601926, 2.91032644217105, 2.9291637031753623, 2.9478805945967355, 2.9664793948382657, 2.9849623113198605, 3.003331483536242, 3.0215889859476257, 3.039736830714133, 3.0577769702841313, 3.07571129984594, 3.093541659651604, 3.1112698372208096, 3.1288975694324033, 3.146426544510455, 3.1638584039112754, 3.1811947441173736, 3.1984371183438958, 3.2155870381627056, 3.2326459750489227, 3.2496153618543846, 3.2664965942122155, 3.283291031876401, 3.3000000000000007, 3.3166247903554003, 3.333166662499792], [0.0, 0.3464101615137755, 0.48989794855663565, 0.6000000000000002, 0.692820323027551, 0.7745966692414835, 0.8485281374238571, 0.9165151389911681, 0.9797958971132713, 1.0392304845413265, 1.0954451150103324, 1.148912529307606, 1.2000000000000004, 1.2489995996796799, 1.2961481396815722, 1.3416407864998738, 1.385640646055102, 1.4282856857085702, 1.4696938456699071, 1.5099668870541503, 1.549193338482967, 1.5874507866387546, 1.6248076809271923, 1.6613247725836153, 1.6970562748477143, 1.7320508075688776, 1.7663521732655698, 1.8000000000000003, 1.8330302779823362, 1.8654758106177634, 1.8973665961010278, 1.9287301521985913, 1.9595917942265426, 1.9899748742132404, 2.019900987672416, 2.04939015319192, 2.078460969082653, 2.107130750570548, 2.1354156504062627, 2.163330765278394, 2.1908902300206647, 2.2181073012818837, 2.2449944320643653, 2.2715633383201097, 2.297825058615212, 2.32379000772445, 2.3494680248941466, 2.374868417407584, 2.400000000000001, 2.4248711305964283, 2.4494897427831783, 2.473863375370597, 2.4979991993593598, 2.521904042583699, 2.5455844122715714, 2.5690465157330262, 2.5922962793631443, 2.6153393661244047, 2.6381811916545845, 2.6608269391300143, 2.6832815729997477, 2.705549851693737, 2.727636339397171, 2.7495454169735045, 2.771281292110204, 2.7928480087537886, 2.8142494558940583, 2.8354893757515653, 2.8565713714171403, 2.8774989139876324, 2.8982753492378883, 2.918903903865285, 2.9393876913398143, 2.9597297173897488, 2.979932885150268, 3.0000000000000004, 3.0199337741083006, 3.039736830714133, 3.0594117081556718, 3.078960863668131, 3.098386676965934, 3.1176914536239795, 3.136877428271625, 3.1559467676119004, 3.174901573277509, 3.193743884534263, 3.2124756808418025, 3.231098884280703, 3.2496153618543846, 3.2680269276736387, 3.286335345030997, 3.3045423283716615, 3.3226495451672307, 3.340658617698014, 3.3585711247493335, 3.3763886032268267, 3.3941125496954285, 3.411744421846397, 3.4292856398964497, 3.4467375879228177, 3.4641016151377553, 3.481379037105843], [0.0, 0.36055512754639896, 0.5099019513592785, 0.6244997998398399, 0.7211102550927979, 0.806225774829855, 0.8831760866327848, 0.9539392014169458, 1.019803902718557, 1.0816653826391969, 1.140175425099138, 1.1958260743101399, 1.2489995996796799, 1.3000000000000003, 1.3490737563232043, 1.396424004376894, 1.4422205101855958, 1.4866068747318506, 1.5297058540778357, 1.5716233645501714, 1.61245154965971, 1.6522711641858308, 1.6911534525287764, 1.7291616465790585, 1.7663521732655696, 1.8027756377319948, 1.8384776310850237, 1.8734993995195197, 1.9078784028338915, 1.94164878389476, 1.9748417658131499, 2.0074859899884734, 2.039607805437114, 2.0712315177207983, 2.102379604162864, 2.1330729007701543, 2.1633307652783937, 2.193171219946131, 2.222611077089287, 2.2516660498395407, 2.280350850198276, 2.3086792761230397, 2.336664289109585, 2.364318083507378, 2.3916521486202797, 2.4186773244895647, 2.445403852127497, 2.471841418861655, 2.4979991993593598, 2.5238858928247927, 2.5495097567963927, 2.574878637916747, 2.6000000000000005, 2.624880949681338, 2.6495282598983545, 2.673948391424188, 2.6981475126464085, 2.72213151776324, 2.7459060435491964, 2.7694764848252458, 2.792848008753788, 2.816025568065745, 2.839013913315678, 2.861817604250837, 2.8844410203711917, 2.9068883707497264, 2.9291637031753623, 2.951270912674741, 2.973213749463701, 2.994995826374388, 3.0166206257996717, 3.0380915061926625, 3.0594117081556713, 3.0805843601498726, 3.1016124838541645, 3.122498999199199, 3.1432467291003428, 3.1638584039112754, 3.1843366656181322, 3.204684071792413, 3.22490309931942, 3.2449961479175906, 3.264965543462902, 3.2848135411313684, 3.3045423283716615, 3.3241540277189325, 3.343650699460098, 3.363034344160048, 3.3823069050575527, 3.4014702703389896, 3.420526275297414, 3.439476704383968, 3.458323293158117, 3.4770677301427426, 3.4957116585897072, 3.5142566781611158, 3.532704346531139, 3.5510561809129415, 3.5693136595149495, 3.58747822293042, 3.6055512754639896, 3.6235341863986883], [0.0, 0.37416573867739417, 0.529150262212918, 0.6480740698407861, 0.7483314773547883, 0.8366600265340756, 0.916515138991168, 0.9899494936611666, 1.058300524425836, 1.1224972160321824, 1.1832159566199232, 1.2409673645990857, 1.2961481396815722, 1.3490737563232043, 1.4, 1.4491376746189437, 1.4966629547095767, 1.5427248620541512, 1.5874507866387544, 1.6309506430300091, 1.6733200530681511, 1.7146428199482247, 1.7549928774784245, 1.7944358444926363, 1.833030277982336, 1.8708286933869707, 1.9078784028338913, 1.9442222095223582, 1.9798989873223332, 2.0149441679609885, 2.0493901531919194, 2.083266665599966, 2.116601048851672, 2.149418526020468, 2.181742422927143, 2.2135943621178655, 2.244994432064365, 2.2759613353482084, 2.3065125189341593, 2.3366642891095846, 2.3664319132398464, 2.395829710142188, 2.4248711305964283, 2.453568829277059, 2.4819347291981715, 2.5099800796022262, 2.5377155080899043, 2.565151067676132, 2.5922962793631443, 2.619160170741759, 2.6457513110645907, 2.672077843177478, 2.6981475126464085, 2.7239676943752476, 2.749545416973504, 2.7748873851023217, 2.8, 2.824889378365107, 2.8495613697550017, 2.8740215726399825, 2.8982753492378874, 2.9223278392404914, 2.9461839725312466, 2.9698484809834995, 2.9933259094191533, 3.016620625799671, 3.0397368307141326, 3.062678566222711, 3.0854497241083023, 3.1080540535840107, 3.1304951684997055, 3.152776554086889, 3.1749015732775088, 3.196873472629156, 3.218695387886216, 3.24037034920393, 3.2619012860600183, 3.283291031876401, 3.3045423283716615, 3.3256578296631782, 3.3466401061363023, 3.3674916480965473, 3.3882148692194836, 3.408812109811862, 3.4292856398964493, 3.449637662132068, 3.4698703145794947, 3.4899856733230297, 3.509985754956849, 3.529872518944558, 3.5496478698597693, 3.5693136595149495, 3.5888716889852725, 3.6083237105337433, 3.627671429443411, 3.6469165057620936, 3.666060555964672, 3.685105154537656, 3.704051835490427, 3.722902093797257, 3.7416573867739413, 3.7603191353926335], [0.0, 0.38729833462074165, 0.5477225575051661, 0.6708203932499369, 0.7745966692414833, 0.8660254037844386, 0.9486832980505138, 1.0246950765959597, 1.0954451150103321, 1.1618950038622249, 1.224744871391589, 1.284523257866513, 1.3416407864998738, 1.396424004376894, 1.4491376746189437, 1.4999999999999998, 1.5491933384829666, 1.5968719422671311, 1.6431676725154982, 1.6881943016134133, 1.7320508075688772, 1.7748239349298847, 1.816590212458495, 1.857417562100671, 1.8973665961010275, 1.9364916731037083, 1.9748417658131499, 2.0124611797498106, 2.0493901531919194, 2.085665361461421, 2.1213203435596424, 2.1563858652847823, 2.1908902300206643, 2.224859546128699, 2.258317958127243, 2.29128784747792, 2.3237900077244498, 2.355843797877949, 2.3874672772626644, 2.4186773244895647, 2.449489742783178, 2.479919353527449, 2.5099800796022267, 2.5396850198400585, 2.569046515733026, 2.5980762113533156, 2.626785107312739, 2.6551836094703507, 2.6832815729997477, 2.7110883423451915, 2.7386127875258306, 2.765863337187866, 2.792848008753788, 2.819574435974337, 2.846049894151541, 2.8722813232690143, 2.8982753492378874, 2.924038303442689, 2.9495762407505253, 2.974894956128703, 2.9999999999999996, 3.0248966924508345, 3.049590136395381, 3.074085229787879, 3.098386676965933, 3.1224989991991987, 3.1464265445104544, 3.1701734968294715, 3.1937438845342623, 3.217141588429082, 3.24037034920393, 3.2634337744161437, 3.2863353450309964, 3.309078421554859, 3.3316662497915357, 3.3541019662496843, 3.3763886032268267, 3.3985290935932855, 3.420526275297414, 3.442382895611701, 3.4641016151377544, 3.485685011586675, 3.5071355833500366, 3.5284557528754696, 3.5496478698597693, 3.5707142142714248, 3.591656999213594, 3.6124783736376886, 3.63318042491699, 3.6537651812890215, 3.674234614174767, 3.694590640382233, 3.714835124201342, 3.7349698793966195, 3.7549966711037173, 3.7749172176353745, 3.794733192202055, 3.8144462245521304, 3.8340579025361623, 3.853569773599539, 3.8729833462074166, 3.892300091205713], [0.0, 0.4, 0.565685424949238, 0.692820323027551, 0.8, 0.894427190999916, 0.9797958971132713, 1.0583005244258363, 1.131370849898476, 1.2, 1.2649110640673518, 1.32664991614216, 1.385640646055102, 1.4422205101855958, 1.4966629547095767, 1.5491933384829666, 1.6, 1.6492422502470643, 1.697056274847714, 1.7435595774162698, 1.788854381999832, 1.8330302779823362, 1.876166303929372, 1.918332609325088, 1.9595917942265426, 2.0, 2.039607805437114, 2.078460969082653, 2.1166010488516727, 2.154065922853802, 2.1908902300206643, 2.227105745132009, 2.262741699796952, 2.297825058615212, 2.3323807579381204, 2.3664319132398464, 2.4, 2.433105012119288, 2.4657656011875906, 2.4979991993593598, 2.5298221281347035, 2.5612496949731396, 2.5922962793631443, 2.6229754097208002, 2.65329983228432, 2.6832815729997477, 2.7129319932501073, 2.7422618401604177, 2.771281292110204, 2.8000000000000003, 2.8284271247461903, 2.8565713714171403, 2.8844410203711917, 2.9120439557122078, 2.939387691339814, 2.9664793948382653, 2.9933259094191533, 3.0199337741083, 3.0463092423455636, 3.0724582991474434, 3.098386676965933, 3.1240998703626617, 3.149603149604724, 3.1749015732775088, 3.2, 3.2249030993194197, 3.249615361854384, 3.2741411087489802, 3.2984845004941286, 3.32264954516723, 3.3466401061363023, 3.3704599092705436, 3.394112549695428, 3.4176014981270124, 3.4409301068170506, 3.464101615137755, 3.4871191548325395, 3.509985754956849, 3.532704346531139, 3.5552777669262356, 3.577708763999664, 3.6, 3.622154055254967, 3.6441734316577197, 3.6660605559646724, 3.687817782917155, 3.709447398198282, 3.7309516212355263, 3.752332607858744, 3.7735924528226414, 3.794733192202055, 3.8157568056677826, 3.836665218650176, 3.8574603043971822, 3.8781438859330635, 3.8987177379235853, 3.9191835884530852, 3.9395431207184424, 3.9597979746446663, 3.9799497484264803, 4.0, 4.019950248448357], [0.0, 0.41231056256176607, 0.58309518948453, 0.7141428428542851, 0.8246211251235321, 0.9219544457292888, 1.0099504938362078, 1.0908712114635715, 1.16619037896906, 1.236931687685298, 1.3038404810405297, 1.3674794331177345, 1.4282856857085702, 1.4866068747318506, 1.5427248620541512, 1.5968719422671311, 1.6492422502470643, 1.7, 1.7492855684535902, 1.797220075561143, 1.8439088914585775, 1.8894443627691184, 1.9339079605813716, 1.977371993328519, 2.0199009876724157, 2.0615528128088303, 2.102379604162864, 2.142428528562855, 2.181742422927143, 2.220360331117452, 2.258317958127243, 2.2956480566497994, 2.33238075793812, 2.3685438564654024, 2.4041630560342617, 2.4392621835300936, 2.473863375370596, 2.5079872407968904, 2.541653005427767, 2.574878637916747, 2.6076809620810595, 2.6400757564888173, 2.672077843177478, 2.7037011669191546, 2.734958866235469, 2.765863337187866, 2.7964262908219126, 2.826658805020514, 2.8565713714171403, 2.8861739379323623, 2.9154759474226504, 2.944486372867092, 2.973213749463701, 3.001666203960727, 3.0298514815086235, 3.0577769702841313, 3.0854497241083023, 3.1128764832546763, 3.1400636936215167, 3.167017524422623, 3.1937438845342623, 3.2202484376209237, 3.246536616149585, 3.2726136343907144, 3.2984845004941286, 3.324154027718932, 3.3496268448888453, 3.374907406137241, 3.4, 3.424908757908742, 3.4496376621320683, 3.4741905532080417, 3.4985711369071804, 3.522782990761707, 3.5468295701936396, 3.570714214271425, 3.594440151122286, 3.6180105030251086, 3.6414282912066254, 3.664696440361739, 3.687817782917155, 3.710795063055895, 3.733630940518894, 3.7563279941985894, 3.778888725538237, 3.8013155617496426, 3.8236108588610325, 3.845776904605882, 3.867815921162743, 3.8897300677553446, 3.9115214431215892, 3.9331920878594273, 3.954743986657038, 3.976179070414209, 3.9974992182613374, 4.018706259482023, 4.039801975344831, 4.060788100849391, 4.08166632639171, 4.102438299353203, 4.123105625617661, 4.1436698710201325], [0.0, 0.4242640687119285, 0.6, 0.7348469228349536, 0.848528137423857, 0.9486832980505139, 1.0392304845413265, 1.1224972160321824, 1.2, 1.2727922061357855, 1.3416407864998738, 1.407124727947029, 1.4696938456699071, 1.5297058540778357, 1.5874507866387544, 1.6431676725154982, 1.697056274847714, 1.7492855684535902, 1.8, 1.8493242008906932, 1.8973665961010278, 1.9442222095223582, 1.98997487421324, 2.0346989949375804, 2.078460969082653, 2.121320343559643, 2.1633307652783937, 2.2045407685048604, 2.244994432064365, 2.2847319317591728, 2.32379000772445, 2.3622023622035435, 2.4, 2.4372115213907883, 2.4738633753705965, 2.5099800796022267, 2.545584412271571, 2.5806975801127883, 2.615339366124404, 2.6495282598983545, 2.6832815729997477, 2.716615541441225, 2.749545416973504, 2.782085548648711, 2.814249455894058, 2.846049894151541, 2.877498913987632, 2.9086079144497976, 2.9393876913398143, 2.9698484809834995, 3.0, 3.029851481508624, 3.0594117081556713, 3.0886890422961004, 3.1176914536239795, 3.146426544510455, 3.1749015732775088, 3.2031234756093934, 3.2310988842807027, 3.2588341473600644, 3.2863353450309964, 3.3136083051561784, 3.340658617698013, 3.3674916480965473, 3.394112549695428, 3.420526275297414, 3.4467375879228173, 3.4727510708370675, 3.4985711369071804, 3.5242020373412193, 3.5496478698597698, 3.5749125863438955, 3.6, 3.6249137920783716, 3.6496575181789317, 3.6742346141747673, 3.6986484017813863, 3.722902093797257, 3.7469987990390394, 3.7709415269929605, 3.7947331922020555, 3.8183766184073566, 3.84187454245971, 3.8652296180175374, 3.8884444190447165, 3.9115214431215897, 3.9344631145812006, 3.957271787481876, 3.97994974842648, 4.0024992192379, 4.024922359499621, 4.047221268969612, 4.069397989875161, 4.091454509095757, 4.113392760240627, 4.135214625627066, 4.156921938165306, 4.178516483155236, 4.2, 4.221374183841087, 4.242640687119286, 4.263801121065569], [0.0, 0.43588989435406744, 0.6164414002968976, 0.7549834435270751, 0.8717797887081349, 0.9746794344808966, 1.0677078252031313, 1.1532562594670797, 1.2328828005937953, 1.307669683062202, 1.3784048752090223, 1.4456832294800963, 1.5099668870541503, 1.5716233645501714, 1.6309506430300091, 1.6881943016134133, 1.7435595774162698, 1.797220075561143, 1.8493242008906932, 1.9000000000000004, 1.9493588689617931, 1.9974984355438181, 2.0445048300260877, 2.0904544960366875, 2.1354156504062627, 2.179449471770337, 2.2226110770892875, 2.2649503305812253, 2.3065125189341593, 2.3473389188611007, 2.3874672772626644, 2.4269322199023198, 2.4657656011875906, 2.503996805109783, 2.5416530054277673, 2.5787593916455256, 2.615339366124404, 2.651414716712571, 2.687005768508881, 2.7221315177632404, 2.7568097504180447, 2.791057147390573, 2.8248893783651075, 2.8583211855912904, 2.8913664589601926, 2.924038303442689, 2.956349099818897, 2.9883105594967874, 3.0199337741083006, 3.051229260478472, 3.082207001484489, 3.1128764832546767, 3.1432467291003428, 3.1733263305244868, 3.203123475609394, 3.232645975048923, 3.2619012860600183, 3.290896534380867, 3.319638534539567, 3.3481338085566414, 3.3763886032268267, 3.4044089061098406, 3.432200460346103, 3.4597687784012394, 3.4871191548325395, 3.5142566781611158, 3.541186241925155, 3.567912554982255, 3.594440151122286, 3.6207733980463352, 3.6469165057620945, 3.672873534441392, 3.6986484017813863, 3.7242448899072147, 3.749666651850535, 3.7749172176353754, 3.8000000000000007, 3.824918299781056, 3.8496753109840323, 3.874274125562104, 3.8987177379235862, 3.9230090491866068, 3.947150871198111, 3.9711459303329564, 3.9949968710876362, 4.018706259482024, 4.042276586281548, 4.065710270051225, 4.0890096600521755, 4.112177038990418, 4.135214625627067, 4.158124577258358, 4.180908992073375, 4.203569911396741, 4.226109321823088, 4.2485291572496005, 4.270831300812525, 4.293017586733137, 4.315089802078284, 4.337049688440289, 4.358898943540674, 4.380639222761903], [0.0, 0.447213595499958, 0.6324555320336759, 0.7745966692414835, 0.894427190999916, 1.0000000000000002, 1.0954451150103324, 1.1832159566199234, 1.2649110640673518, 1.3416407864998738, 1.4142135623730951, 1.4832396974191329, 1.549193338482967, 1.61245154965971, 1.6733200530681511, 1.7320508075688772, 1.788854381999832, 1.8439088914585775, 1.8973665961010278, 1.9493588689617931, 2.0000000000000004, 2.04939015319192, 2.0976176963403033, 2.144761058952722, 2.1908902300206647, 2.23606797749979, 2.280350850198276, 2.3237900077244507, 2.366431913239847, 2.4083189157584592, 2.4494897427831783, 2.489979919597747, 2.5298221281347035, 2.5690465157330262, 2.60768096208106, 2.6457513110645907, 2.6832815729997477, 2.720294101747089, 2.7568097504180447, 2.7928480087537886, 2.8284271247461903, 2.863564212655271, 2.8982753492378883, 2.932575659723036, 2.9664793948382657, 3.0, 3.0331501776206204, 3.0659419433511785, 3.098386676965934, 3.130495168499706, 3.1622776601683795, 3.193743884534263, 3.22490309931942, 3.255764119219942, 3.286335345030997, 3.3166247903554003, 3.3466401061363023, 3.3763886032268267, 3.405877273185281, 3.4351128074635335, 3.4641016151377544, 3.492849839314596, 3.521363372331802, 3.5496478698597698, 3.577708763999664, 3.605551275463989, 3.6331804249169903, 3.6606010435446255, 3.687817782917155, 3.7148351242013424, 3.7416573867739418, 3.768288736283355, 3.7947331922020555, 3.82099463490856, 3.847076812334269, 3.872983346207417, 3.8987177379235862, 3.924283374069717, 3.9496835316263006, 3.9749213828703587, 4.000000000000001, 4.024922359499622, 4.049691346263318, 4.0743097574926725, 4.09878030638384, 4.123105625617661, 4.147288270665545, 4.171330722922843, 4.1952353926806065, 4.219004621945797, 4.242640687119286, 4.266145801540309, 4.289522117905444, 4.312771730569565, 4.335896677735761, 4.358898943540674, 4.3817804600413295, 4.404543109109049, 4.427188724235731, 4.449719092257398, 4.47213595499958, 4.494441010848847], [0.0, 0.45825756949558405, 0.6480740698407861, 0.7937253933193773, 0.9165151389911681, 1.02469507659596, 1.1224972160321824, 1.2124355652982142, 1.2961481396815722, 1.374772708486752, 1.449137674618944, 1.5198684153570665, 1.5874507866387546, 1.6522711641858308, 1.7146428199482247, 1.7748239349298847, 1.8330302779823362, 1.8894443627691184, 1.9442222095223582, 1.9974984355438181, 2.04939015319192, 2.1, 2.149418526020468, 2.1977260975835913, 2.244994432064365, 2.2912878474779204, 2.336664289109585, 2.381176179958132, 2.4248711305964283, 2.4677925358506134, 2.5099800796022267, 2.551470164434615, 2.5922962793631443, 2.632489316217637, 2.672077843177478, 2.711088342345192, 2.749545416973504, 2.787471972953271, 2.824889378365107, 2.861817604250837, 2.898275349237888, 2.934280150224242, 2.9698484809835, 3.004995840263344, 3.039736830714133, 3.0740852297878796, 3.108054053584011, 3.1416556144810017, 3.174901573277509, 3.2078029864690882, 3.2403703492039306, 3.272613634390715, 3.3045423283716615, 3.336165463522456, 3.3674916480965478, 3.398529093593286, 3.4292856398964493, 3.459768778401239, 3.48998567332303, 3.5199431813596083, 3.5496478698597693, 3.5791060336346563, 3.608323710533743, 3.6373066958946425, 3.6660605559646724, 3.6945906403822333, 3.722902093797257, 3.7509998667022106, 3.778888725538237, 3.8065732621348563, 3.834057902536163, 3.861346915261565, 3.8884444190447165, 3.915354390090379, 3.9420806688854046, 3.968626966596886, 3.9949968710876362, 4.02119385257662, 4.047221268969613, 4.07308237088326, 4.09878030638384, 4.124318125460256, 4.149698784249287, 4.174925149029621, 4.2, 4.224926034855522, 4.249705872175156, 4.274342054632503, 4.298837052040936, 4.323193264243457, 4.347413023856832, 4.371498598878879, 4.3954521951671826, 4.419275958796871, 4.442971978304612, 4.466542286825459, 4.48998886412873, 4.513313638558704, 4.536518488885503, 4.559605246071199, 4.582575694955841, 4.605431575867782], [0.0, 0.469041575982343, 0.6633249580710799, 0.8124038404635961, 0.938083151964686, 1.0488088481701516, 1.148912529307606, 1.2409673645990857, 1.3266499161421599, 1.407124727947029, 1.4832396974191326, 1.5556349186104048, 1.6248076809271923, 1.6911534525287764, 1.7549928774784245, 1.816590212458495, 1.876166303929372, 1.9339079605813716, 1.98997487421324, 2.0445048300260877, 2.0976176963403033, 2.149418526020468, 2.2, 2.249444375840399, 2.297825058615212, 2.345207879911715, 2.3916521486202797, 2.4372115213907883, 2.4819347291981715, 2.5258661880630178, 2.569046515733026, 2.6115129714401193, 2.6532998322843198, 2.6944387170614963, 2.734958866235469, 2.7748873851023217, 2.814249455894058, 2.8530685235374214, 2.891366458960192, 2.9291637031753623, 2.9664793948382653, 3.0033314835362415, 3.039736830714133, 3.0757112998459397, 3.1112698372208096, 3.1464265445104544, 3.1811947441173736, 3.2155870381627056, 3.2496153618543846, 3.283291031876401, 3.3166247903554003, 3.3496268448888458, 3.3823069050575527, 3.414674215792775, 3.4467375879228173, 3.4785054261852175, 3.509985754956849, 3.5411862419251547, 3.5721142198983507, 3.602776706930364, 3.63318042491699, 3.6633318168028404, 3.6932370625238775, 3.722902093797257, 3.752332607858744, 3.7815340802378072, 3.81051177665153, 3.8392707640904935, 3.867815921162743, 3.8961519477556315, 3.924283374069717, 3.952214569073901, 3.97994974842648, 4.007492981902776, 4.034848200366403, 4.06201920231798, 4.0890096600521755, 4.115823125451336, 4.1424630354415966, 4.168932717135166, 4.1952353926806065, 4.221374183841087, 4.247352116319061, 4.273172123844299, 4.298837052040936, 4.324349662087931, 4.349712634186309, 4.374928570845472, 4.4, 4.424929377967517, 4.449719092257398, 4.474371464239419, 4.498888751680798, 4.523273151159457, 4.54752680036083, 4.571651780264984, 4.595650117230424, 4.61952378498044, 4.64327470649756, 4.666904755831214, 4.69041575982343, 4.713809499757071], [0.0, 0.479583152331272, 0.6782329983125268, 0.8306623862918077, 0.959166304662544, 1.072380529476361, 1.174734012447073, 1.2688577540449522, 1.3564659966250536, 1.438749456993816, 1.5165750888103102, 1.5905973720586868, 1.6613247725836153, 1.7291616465790585, 1.7944358444926363, 1.857417562100671, 1.918332609325088, 1.977371993328519, 2.0346989949375804, 2.0904544960366875, 2.144761058952722, 2.1977260975835913, 2.249444375840399, 2.3000000000000003, 2.349468024894146, 2.39791576165636, 2.4454038521274972, 2.491987158875423, 2.5377155080899043, 2.582634314028992, 2.6267851073127395, 2.670205984563738, 2.7129319932501073, 2.754995462791183, 2.7964262908219126, 2.8372521918222215, 2.877498913987632, 2.917190429162965, 2.956349099818897, 2.994995826374388, 3.0331501776206204, 3.0708305065568178, 3.108054053584011, 3.1448370387032774, 3.1811947441173736, 3.2171415884290826, 3.252691193458119, 3.2878564445547194, 3.3226495451672307, 3.357082066318904, 3.3911649915626345, 3.4249087579087423, 3.458323293158117, 3.491418050019219, 3.5242020373412197, 3.5566838487557484, 3.5888716889852725, 3.620773398046335, 3.6523964735499352, 3.6837480912787726, 3.714835124201342, 3.745664160065609, 3.7762415176998414, 3.8065732621348563, 3.836665218650176, 3.866522985836241, 3.8961519477556315, 3.9255572852781047, 3.954743986657038, 3.9837168574084183, 4.012480529547776, 4.041039470235351, 4.069397989875161, 4.097560249709576, 4.125530268947254, 4.153311931459037, 4.180908992073375, 4.2083250825001635, 4.235563716909475, 4.262628297189424, 4.289522117905444, 4.316248370981448, 4.342810150121694, 4.369210454990696, 4.3954521951671826, 4.421538193886829, 4.447471191587417, 4.473253849269009, 4.498888751680798, 4.524378410345448, 4.549725266430931, 4.57493169347915, 4.6000000000000005, 4.624932431938872, 4.649731175025068, 4.674398357008098, 4.698936049788292, 4.723346271447818, 4.747630988187688, 4.77179211617606, 4.79583152331272, 4.819751030914357], [0.0, 0.48989794855663565, 0.6928203230275509, 0.8485281374238571, 0.9797958971132713, 1.0954451150103324, 1.2000000000000002, 1.2961481396815722, 1.3856406460551018, 1.469693845669907, 1.5491933384829668, 1.6248076809271923, 1.6970562748477143, 1.7663521732655696, 1.833030277982336, 1.8973665961010275, 1.9595917942265426, 2.0199009876724157, 2.078460969082653, 2.1354156504062627, 2.1908902300206647, 2.244994432064365, 2.297825058615212, 2.349468024894146, 2.4000000000000004, 2.4494897427831783, 2.4979991993593598, 2.5455844122715714, 2.5922962793631443, 2.638181191654584, 2.6832815729997477, 2.727636339397171, 2.7712812921102037, 2.8142494558940583, 2.8565713714171403, 2.898275349237888, 2.939387691339814, 2.979932885150268, 3.0199337741083, 3.0594117081556713, 3.0983866769659336, 3.136877428271625, 3.174901573277509, 3.212475680841802, 3.2496153618543846, 3.2863353450309964, 3.32264954516723, 3.358571124749333, 3.3941125496954285, 3.4292856398964493, 3.464101615137755, 3.498571136907181, 3.532704346531139, 3.5665109000254023, 3.6, 3.6331804249169903, 3.666060555964672, 3.698648401781386, 3.7309516212355263, 3.7629775444453557, 3.794733192202055, 3.8262252939417984, 3.857460304397182, 3.8884444190447165, 3.9191835884530852, 3.9496835316262997, 3.97994974842648, 4.009987531152684, 4.039801975344831, 4.069397989875161, 4.09878030638384, 4.127953488110059, 4.156921938165306, 4.18568990729127, 4.214261501141095, 4.242640687119286, 4.270831300812525, 4.298837052040936, 4.3266615305567875, 4.354308211415448, 4.3817804600413295, 4.409081537009721, 4.436214602563767, 4.463182720884279, 4.48998886412873, 4.5166359162544865, 4.543126676640219, 4.5694638635183455, 4.595650117230424, 4.621688003316537, 4.6475800154489, 4.673328578219169, 4.698936049788292, 4.724404724407087, 4.749736834815168, 4.774934554525329, 4.800000000000001, 4.824935232725928, 4.849742261192857, 4.874423042781577, 4.898979485566357, 4.9234134500364695], [0.0, 0.5, 0.7071067811865476, 0.8660254037844388, 1.0, 1.118033988749895, 1.2247448713915892, 1.3228756555322954, 1.4142135623730951, 1.5, 1.5811388300841898, 1.6583123951777001, 1.7320508075688776, 1.8027756377319948, 1.8708286933869707, 1.9364916731037083, 2.0, 2.0615528128088303, 2.121320343559643, 2.179449471770337, 2.23606797749979, 2.2912878474779204, 2.345207879911715, 2.39791576165636, 2.4494897427831783, 2.5000000000000004, 2.5495097567963927, 2.5980762113533165, 2.6457513110645907, 2.6925824035672523, 2.7386127875258306, 2.783882181415011, 2.8284271247461903, 2.8722813232690148, 2.9154759474226504, 2.958039891549808, 3.0, 3.04138126514911, 3.0822070014844885, 3.1224989991991996, 3.1622776601683795, 3.2015621187164247, 3.2403703492039306, 3.278719262151, 3.3166247903554003, 3.3541019662496843, 3.3911649915626345, 3.4278273002005224, 3.4641016151377553, 3.5, 3.535533905932738, 3.5707142142714257, 3.6055512754639896, 3.64005494464026, 3.6742346141747677, 3.708099243547832, 3.7416573867739413, 3.774917217635375, 3.8078865529319548, 3.840572873934304, 3.8729833462074166, 3.9051248379533274, 3.9370039370059056, 3.968626966596886, 4.0, 4.031128874149275, 4.06201920231798, 4.092676385936225, 4.123105625617661, 4.153311931459037, 4.183300132670378, 4.2130748865881795, 4.242640687119286, 4.272001872658766, 4.301162633521313, 4.330127018922194, 4.358898943540674, 4.387482193696061, 4.415880433163924, 4.444097208657795, 4.47213595499958, 4.500000000000001, 4.527692569068709, 4.55521678957215, 4.582575694955841, 4.609772228646444, 4.636809247747852, 4.663689526544408, 4.69041575982343, 4.716990566028302, 4.743416490252569, 4.769696007084729, 4.79583152331272, 4.821825380496478, 4.847679857416329, 4.873397172404482, 4.898979485566357, 4.924428900898053, 4.949747468305833, 4.974937185533101, 5.000000000000001, 5.024937810560446], [0.0, 0.5099019513592785, 0.7211102550927979, 0.8831760866327849, 1.019803902718557, 1.140175425099138, 1.2489995996796799, 1.3490737563232043, 1.4422205101855958, 1.5297058540778354, 1.61245154965971, 1.6911534525287766, 1.7663521732655698, 1.8384776310850237, 1.9078784028338913, 1.9748417658131499, 2.039607805437114, 2.102379604162864, 2.1633307652783937, 2.2226110770892875, 2.280350850198276, 2.336664289109585, 2.3916521486202797, 2.4454038521274972, 2.4979991993593598, 2.5495097567963927, 2.6000000000000005, 2.6495282598983545, 2.6981475126464085, 2.7459060435491964, 2.792848008753788, 2.839013913315678, 2.8844410203711917, 2.9291637031753623, 2.973213749463701, 3.0166206257996713, 3.059411708155671, 3.101612483854165, 3.1432467291003428, 3.1843366656181322, 3.22490309931942, 3.264965543462902, 3.304542328371662, 3.3436506994600976, 3.382306905057553, 3.420526275297414, 3.458323293158117, 3.4957116585897072, 3.5327043465311396, 3.5693136595149495, 3.6055512754639896, 3.6414282912066254, 3.6769552621700474, 3.712142238654118, 3.7469987990390394, 3.7815340802378077, 3.8157568056677826, 3.849675310984032, 3.8832975677895205, 3.916631205513228, 3.9496835316262997, 3.9824615503479754, 4.014971979976946, 4.047221268969613, 4.079215610874228, 4.110960958218893, 4.142463035441596, 4.173727350941841, 4.204759208325728, 4.235563716909475, 4.266145801540309, 4.296510211788167, 4.3266615305567875, 4.356604182158393, 4.386342439892262, 4.415880433163924, 4.445222154178575, 4.474371464239419, 4.503332099679082, 4.532107677449864, 4.560701700396552, 4.589117562233507, 4.617358552246079, 4.645427859734774, 4.67332857821917, 4.701063709417264, 4.7286361670147565, 4.756048780237647, 4.7833042972405595, 4.810405388322278, 4.83735464897913, 4.864154602806124, 4.8908077042549944, 4.917316341257699, 4.943682837723311, 4.969909455915671, 4.9959983987187195, 5.021951811795889, 5.047771785649585, 5.073460357586329, 5.099019513592785, 5.1244511901275835], [0.0, 0.5196152422706632, 0.7348469228349535, 0.9000000000000001, 1.0392304845413265, 1.1618950038622253, 1.2727922061357857, 1.374772708486752, 1.469693845669907, 1.5588457268119895, 1.6431676725154984, 1.7233687939614089, 1.8000000000000003, 1.8734993995195197, 1.9442222095223582, 2.0124611797498106, 2.078460969082653, 2.142428528562855, 2.2045407685048604, 2.2649503305812253, 2.3237900077244507, 2.381176179958132, 2.4372115213907883, 2.491987158875423, 2.5455844122715714, 2.5980762113533165, 2.6495282598983545, 2.7, 2.749545416973504, 2.7982137159266447, 2.8460498941515415, 2.8930952282978866, 2.939387691339814, 2.9849623113198605, 3.0298514815086235, 3.0740852297878796, 3.117691453623979, 3.160696125855822, 3.203123475609394, 3.244996147917591, 3.286335345030997, 3.3271609519228256, 3.3674916480965478, 3.407345007480164, 3.4467375879228177, 3.4856850115866753, 3.5242020373412197, 3.5623026261113755, 3.6000000000000005, 3.6373066958946425, 3.6742346141747677, 3.7107950630558952, 3.7469987990390394, 3.782856063875548, 3.818376618407357, 3.853569773599539, 3.8884444190447165, 3.9230090491866063, 3.957271787481876, 3.9912404086950213, 4.024922359499621, 4.058324777540605, 4.091454509095756, 4.124318125460256, 4.156921938165306, 4.189272013130682, 4.221374183841087, 4.253234063627348, 4.28485705712571, 4.316248370981448, 4.3474130238568325, 4.378355855797928, 4.409081537009721, 4.439594576084623, 4.469899327725402, 4.5, 4.529900661162451, 4.559605246071199, 4.589117562233508, 4.618441295502196, 4.647580015448901, 4.676537180435969, 4.705316142407438, 4.73392015141785, 4.762352359916264, 4.790615826801394, 4.818713521262704, 4.846648326421054, 4.874423042781577, 4.902040391510457, 4.929503017546495, 4.956813492557492, 4.983974317750846, 5.0109879265470205, 5.037856687124, 5.06458290484024, 5.091168824543143, 5.117616632769595, 5.143928459844674, 5.170106381884226, 5.196152422706633, 5.222068555658764], [0.0, 0.5291502622129182, 0.7483314773547882, 0.9165151389911681, 1.0583005244258363, 1.1832159566199234, 1.2961481396815722, 1.4000000000000001, 1.4966629547095764, 1.5874507866387544, 1.6733200530681511, 1.7549928774784245, 1.8330302779823362, 1.9078784028338915, 1.9798989873223332, 2.0493901531919194, 2.1166010488516727, 2.181742422927143, 2.244994432064365, 2.3065125189341593, 2.366431913239847, 2.4248711305964283, 2.4819347291981715, 2.5377155080899043, 2.5922962793631443, 2.6457513110645907, 2.6981475126464085, 2.749545416973504, 2.8000000000000003, 2.8495613697550017, 2.8982753492378874, 2.946183972531247, 2.993325909419153, 3.039736830714133, 3.0854497241083028, 3.1304951684997055, 3.1749015732775088, 3.2186953878862163, 3.2619012860600183, 3.3045423283716615, 3.3466401061363023, 3.3882148692194836, 3.4292856398964497, 3.4698703145794942, 3.509985754956849, 3.5496478698597693, 3.5888716889852725, 3.627671429443411, 3.6660605559646724, 3.704051835490427, 3.7416573867739418, 3.7788887255382373, 3.815756805667783, 3.852272056851645, 3.8884444190447165, 3.924283374069717, 3.9597979746446663, 3.994996871087636, 4.029888335921977, 4.064480286580315, 4.098780306383839, 4.132795663954365, 4.166533331199932, 4.2, 4.233202097703345, 4.266145801540308, 4.298837052040936, 4.331281565541543, 4.363484845854286, 4.3954521951671826, 4.427188724235731, 4.458699361921591, 4.48998886412873, 4.521061822182926, 4.551922670696417, 4.58257569495584, 4.613025037868319, 4.64327470649756, 4.67332857821917, 4.703190406521939, 4.732863826479694, 4.762352359916263, 4.791659420284376, 4.82078831727758, 4.849742261192857, 4.878524367060187, 4.907137658554119, 4.935585071701227, 4.963869458396343, 4.991993589739474, 5.019960159204453, 5.047771785649585, 5.075431016179809, 5.10294032886923, 5.130302135352265, 5.15751878329105, 5.184592558726289, 5.2115256883181535, 5.238320341483518, 5.264978632435274, 5.291502622129181, 5.317894320123333], [0.0, 0.5385164807134505, 0.7615773105863909, 0.9327379053088817, 1.077032961426901, 1.2041594578792296, 1.319090595827292, 1.4247806848775009, 1.5231546211727818, 1.6155494421403513, 1.7029386365926402, 1.7860571099491753, 1.8654758106177634, 1.94164878389476, 2.0149441679609885, 2.085665361461421, 2.154065922853802, 2.220360331117452, 2.2847319317591728, 2.3473389188611007, 2.4083189157584592, 2.4677925358506134, 2.5258661880630178, 2.582634314028992, 2.638181191654584, 2.6925824035672523, 2.7459060435491964, 2.7982137159266447, 2.8495613697550017, 2.9000000000000004, 2.9495762407505253, 2.99833287011299, 3.0463092423455636, 3.0935416596516045, 3.1400636936215167, 3.1859064644147983, 3.2310988842807027, 3.2756678708318403, 3.3196385345395667, 3.363034344160048, 3.4058772731852804, 3.448187929913334, 3.48998567332303, 3.531288716601915, 3.5721142198983507, 3.6124783736376886, 3.6523964735499352, 3.691882988394947, 3.7309516212355267, 3.769615364994153, 3.8078865529319548, 3.845776904605883, 3.88329756778952, 3.9204591567825324, 3.957271787481876, 3.993745109543172, 4.029888335921977, 4.065710270051224, 4.101219330881976, 4.136423575989287, 4.171330722922842, 4.205948168962618, 4.240283009422838, 4.274342054632503, 4.308131845707604, 4.341658669218482, 4.374928570845472, 4.407947368106838, 4.440720662234904, 4.473253849269009, 4.505552130427525, 4.537620521815371, 4.5694638635183455, 4.601086828130937, 4.632493928760188, 4.663689526544408, 4.694677837722201, 4.725462940284264, 4.756048780237647, 4.786439177509728, 4.8166378315169185, 4.846648326421054, 4.876474136094644, 4.906118628814432, 4.935585071701227, 4.964876634922565, 4.993996395673509, 5.022947341949744, 5.0517323761260355, 5.0803543183522155, 5.10881590977792, 5.137119815616529, 5.165268628057984, 5.193264869039514, 5.221110992882646, 5.2488093888042835, 5.276362383309168, 5.3037722424704485, 5.331041174104736, 5.358171329847527, 5.385164807134505, 5.412023651093924], [0.0, 0.5477225575051661, 0.7745966692414833, 0.9486832980505139, 1.0954451150103321, 1.2247448713915892, 1.3416407864998738, 1.4491376746189437, 1.5491933384829666, 1.6431676725154982, 1.7320508075688772, 1.816590212458495, 1.8973665961010278, 1.9748417658131499, 2.0493901531919194, 2.1213203435596424, 2.1908902300206643, 2.258317958127243, 2.32379000772445, 2.3874672772626644, 2.4494897427831783, 2.5099800796022267, 2.569046515733026, 2.6267851073127395, 2.6832815729997477, 2.7386127875258306, 2.792848008753788, 2.8460498941515415, 2.8982753492378874, 2.9495762407505253, 2.9999999999999996, 3.049590136395381, 3.098386676965933, 3.146426544510455, 3.1937438845342623, 3.2403703492039297, 3.2863353450309964, 3.331666249791536, 3.376388603226826, 3.420526275297414, 3.4641016151377544, 3.5071355833500366, 3.5496478698597698, 3.5916569992135936, 3.63318042491699, 3.674234614174767, 3.714835124201342, 3.7549966711037173, 3.7947331922020555, 3.8340579025361627, 3.872983346207417, 3.9115214431215892, 3.9496835316262997, 3.9874804074753776, 4.024922359499621, 4.06201920231798, 4.098780306383839, 4.135214625627066, 4.171330722922842, 4.207136793592525, 4.242640687119285, 4.277849927241487, 4.3127717305695645, 4.347413023856832, 4.381780460041329, 4.415880433163923, 4.449719092257397, 4.483302354291978, 4.516635916254486, 4.54972526643093, 4.58257569495584, 4.61519230368573, 4.6475800154489, 4.679743582719036, 4.711687595755898, 4.743416490252569, 4.774934554525329, 4.806245936279166, 4.83735464897913, 4.868264577855234, 4.898979485566357, 4.929503017546495, 4.959838707054898, 4.9899899799498595, 5.019960159204453, 5.049752469181039, 5.079370039680118, 5.10881590977792, 5.138093031466052, 5.167204273105525, 5.196152422706632, 5.224940191045253, 5.253570214625479, 5.282045058497703, 5.310367218940701, 5.338539126015655, 5.366563145999495, 5.394441583704471, 5.422176684690383, 5.449770637375485, 5.477225575051661, 5.504543577809154], [0.0, 0.5567764362830022, 0.7874007874011811, 0.9643650760992957, 1.1135528725660044, 1.2449899597988734, 1.3638181696985856, 1.4730919862656235, 1.5748015748023623, 1.6703293088490065, 1.760681686165901, 1.846618531261939, 1.9287301521985913, 2.0074859899884734, 2.083266665599966, 2.1563858652847823, 2.227105745132009, 2.2956480566497994, 2.3622023622035435, 2.4269322199023198, 2.489979919597747, 2.551470164434615, 2.6115129714401193, 2.670205984563738, 2.727636339397171, 2.783882181415011, 2.839013913315678, 2.8930952282978866, 2.946183972531247, 2.99833287011299, 3.049590136395381, 3.1, 3.1496031496047245, 3.1984371183438953, 3.2465366161495854, 3.2939338184001206, 3.340658617698013, 3.38673884437522, 3.432200460346103, 3.477067730142742, 3.521363372331802, 3.5651086939951777, 3.6083237105337433, 3.6510272527057364, 3.693237062523878, 3.7349698793966195, 3.7762415176998414, 3.817066936798463, 3.8574603043971827, 3.8974350539810154, 3.9370039370059056, 3.9761790704142093, 4.014971979976947, 4.053393639902249, 4.091454509095757, 4.129164564412516, 4.166533331199932, 4.20356991139674, 4.240283009422838, 4.276680956068619, 4.3127717305695645, 4.34856298103178, 4.384062043356595, 4.419275958796871, 4.454211490264018, 4.488875137492688, 4.523273151159456, 4.557411546042337, 4.591296113299599, 4.624932431938872, 4.658325879540847, 4.69148164229596, 4.724404724407087, 4.757099956906519, 4.789572005931219, 4.8218253804964775, 4.8538644398046396, 4.8856934001224435, 4.917316341257699, 4.948737212663449, 4.979959839195494, 5.01098792654702, 5.041825066382213, 5.072474741188959, 5.10294032886923, 5.13322510708424, 5.163332257370235, 5.193264869039514, 5.223025942880239, 5.252618394667558, 5.282045058497703, 5.3113086899558, 5.340411969127476, 5.36935750346352, 5.398147830506312, 5.426785420486054, 5.455272678794342, 5.483611948342078, 5.511805511808268, 5.539855593785817, 5.567764362830022, 5.595533933415113], [0.0, 0.565685424949238, 0.7999999999999999, 0.9797958971132713, 1.131370849898476, 1.2649110640673518, 1.3856406460551018, 1.4966629547095764, 1.5999999999999999, 1.697056274847714, 1.7888543819998317, 1.876166303929372, 1.9595917942265426, 2.039607805437114, 2.116601048851672, 2.1908902300206643, 2.262741699796952, 2.33238075793812, 2.4, 2.4657656011875906, 2.5298221281347035, 2.5922962793631443, 2.6532998322843198, 2.7129319932501073, 2.7712812921102037, 2.8284271247461903, 2.8844410203711917, 2.939387691339814, 2.993325909419153, 3.0463092423455636, 3.098386676965933, 3.1496031496047245, 3.1999999999999997, 3.249615361854384, 3.2984845004941286, 3.3466401061363023, 3.394112549695428, 3.4409301068170506, 3.487119154832539, 3.5327043465311387, 3.5777087639996634, 3.622154055254967, 3.6660605559646724, 3.709447398198281, 3.752332607858744, 3.7947331922020546, 3.8366652186501757, 3.878143885933063, 3.9191835884530852, 3.959797974644666, 4.0, 4.039801975344831, 4.079215610874228, 4.118252056394801, 4.156921938165306, 4.1952353926806065, 4.233202097703344, 4.2708313008125245, 4.308131845707603, 4.345112196480086, 4.381780460041329, 4.418144406874904, 4.454211490264017, 4.48998886412873, 4.525483399593904, 4.560701700396551, 4.595650117230423, 4.63033476111609, 4.66476151587624, 4.698936049788292, 4.732863826479693, 4.766550115125193, 4.8, 4.833218389437829, 4.866210024238575, 4.898979485566356, 4.931531202375181, 4.963869458396343, 4.995998398718719, 5.027922035990614, 5.059644256269407, 5.091168824543142, 5.122499389946279, 5.15363949069005, 5.184592558726289, 5.215361924162119, 5.2459508194416005, 5.276362383309167, 5.3065996645686395, 5.336665625650533, 5.366563145999495, 5.396295025292816, 5.4258639865002145, 5.455272678794342, 5.4845236803208355, 5.513619500836088, 5.542562584220407, 5.571355310873648, 5.6, 5.628498911788116, 5.656854249492381, 5.685068161420759], [0.0, 0.574456264653803, 0.812403840463596, 0.9949874371066202, 1.148912529307606, 1.2845232578665131, 1.4071247279470291, 1.5198684153570665, 1.624807680927192, 1.7233687939614086, 1.8165902124584952, 1.9052558883257653, 1.9899748742132404, 2.0712315177207983, 2.149418526020468, 2.224859546128699, 2.297825058615212, 2.3685438564654024, 2.4372115213907883, 2.503996805109783, 2.5690465157330262, 2.632489316217637, 2.6944387170614963, 2.754995462791183, 2.8142494558940583, 2.8722813232690148, 2.9291637031753623, 2.9849623113198605, 3.039736830714133, 3.0935416596516045, 3.146426544510455, 3.1984371183438953, 3.249615361854384, 3.3000000000000007, 3.3496268448888458, 3.398529093593286, 3.4467375879228173, 3.49428104193123, 3.541186241925155, 3.58747822293042, 3.6331804249169903, 3.678314831549905, 3.7229020937972575, 3.7669616403674726, 3.8105117766515306, 3.853569773599539, 3.896151947755632, 3.9382737335030438, 3.9799497484264807, 4.02119385257662, 4.06201920231798, 4.102438299353204, 4.1424630354415966, 4.182104733265298, 4.221374183841087, 4.260281680828159, 4.298837052040936, 4.337049688440288, 4.374928570845472, 4.412482294582042, 4.449719092257398, 4.486646854834912, 4.523273151159457, 4.559605246071199, 4.595650117230424, 4.631414470763764, 4.666904755831214, 4.702127178203499, 4.737087712930805, 4.77179211617606, 4.806245936279167, 4.8404545241123795, 4.874423042781577, 4.908156476723211, 4.941659640242335, 4.974937185533101, 5.007993610219566, 5.040833264451424, 5.07346035758633, 5.105878964487898, 5.1380930314660525, 5.170106381884226, 5.201922721455982, 5.23354564325181, 5.264978632435274, 5.296225070746145, 5.327288240746882, 5.358171329847526, 5.388877434122993, 5.419409561935692, 5.449770637375486, 5.479963503528103, 5.509990925582366, 5.539855593785817, 5.569560126257729, 5.599107071667768, 5.628498911788117, 5.657738063926256, 5.686826883245173, 5.715767664977296, 5.7445626465380295, 5.773214009544425], [0.0, 0.5830951894845301, 0.8246211251235321, 1.009950493836208, 1.1661903789690602, 1.30384048104053, 1.4282856857085702, 1.5427248620541514, 1.6492422502470643, 1.7492855684535902, 1.8439088914585775, 1.9339079605813718, 2.019900987672416, 2.102379604162864, 2.181742422927143, 2.258317958127243, 2.3323807579381204, 2.4041630560342617, 2.4738633753705965, 2.5416530054277673, 2.60768096208106, 2.672077843177478, 2.734958866235469, 2.7964262908219126, 2.8565713714171403, 2.9154759474226504, 2.973213749463701, 3.0298514815086235, 3.0854497241083028, 3.1400636936215167, 3.1937438845342623, 3.2465366161495854, 3.2984845004941286, 3.3496268448888458, 3.4000000000000004, 3.449637662132068, 3.4985711369071804, 3.54682957019364, 3.594440151122286, 3.6414282912066254, 3.687817782917155, 3.733630940518894, 3.7788887255382373, 3.823610858861032, 3.8678159211627436, 3.911521443121589, 3.954743986657038, 3.997499218261337, 4.039801975344832, 4.08166632639171, 4.123105625617661, 4.164132562731403, 4.204759208325728, 4.244997055358225, 4.28485705712571, 4.324349662087931, 4.363484845854286, 4.402272140611028, 4.440720662234904, 4.4788391353117385, 4.516635916254486, 4.5541190146942805, 4.591296113299598, 4.628174586162454, 4.664761515876241, 4.701063709417263, 4.737087712930805, 4.77283982551269, 4.8083261120685235, 4.843552415324934, 4.878524367060187, 4.913247398615299, 4.947726750741193, 4.98196748283246, 5.015974481593781, 5.049752469181039, 5.083306010855535, 5.1166395221864125, 5.149757275833494, 5.182663407939976, 5.21536192416212, 5.247856705360771, 5.280151512977635, 5.31224999411737, 5.344155686354956, 5.375872022286245, 5.40740233383831, 5.4387498563548595, 5.469917732470938, 5.500909015790026, 5.531726674375733, 5.562373594069352, 5.592852581643825, 5.62316636780382, 5.653317610041029, 5.683308895353129, 5.713142742834281, 5.742821606144492, 5.772347875864725, 5.801723881744115, 5.830951894845301, 5.860034129593445], [0.0, 0.5916079783099616, 0.8366600265340756, 1.02469507659596, 1.1832159566199232, 1.3228756555322954, 1.449137674618944, 1.5652475842498528, 1.6733200530681511, 1.7748239349298847, 1.8708286933869707, 1.9621416870348585, 2.04939015319192, 2.1330729007701543, 2.2135943621178655, 2.29128784747792, 2.3664319132398464, 2.4392621835300936, 2.5099800796022267, 2.5787593916455256, 2.6457513110645907, 2.711088342345192, 2.7748873851023217, 2.8372521918222215, 2.898275349237888, 2.958039891549808, 3.0166206257996713, 3.0740852297878796, 3.1304951684997055, 3.1859064644147983, 3.2403703492039297, 3.2939338184001206, 3.3466401061363023, 3.398529093593286, 3.449637662132068, 3.5, 3.5496478698597693, 3.5986108430893164, 3.646916505762094, 3.6945906403822333, 3.7416573867739413, 3.7881393849751626, 3.834057902536163, 3.879432948254164, 3.924283374069717, 3.9686269665968856, 4.012480529547776, 4.05585995813465, 4.09878030638384, 4.141255848169731, 4.183300132670378, 4.224926034855522, 4.266145801540309, 4.306971093471606, 4.347413023856832, 4.387482193696061, 4.427188724235731, 4.466542286825459, 4.505552130427525, 4.544227107000705, 4.58257569495584, 4.620606020859168, 4.658325879540846, 4.695742752749559, 4.732863826479693, 4.769696007084728, 4.806245936279166, 4.8425200051213, 4.878524367060187, 4.914264950122246, 4.949747468305833, 4.984977432245807, 5.019960159204453, 5.054700782440045, 5.089204259999788, 5.123475382979799, 5.157518783291051, 5.191338940966964, 5.2249401910452535, 5.2583267300539625, 5.291502622129181, 5.324471804789654, 5.35723809439155, 5.389805191284746, 5.422176684690384, 5.454356057317858, 5.486346689738081, 5.518151864528558, 5.549774770204643, 5.58121850495033, 5.612486080160912, 5.643580423808984, 5.674504383644443, 5.705260730238365, 5.735852159879995, 5.766281297335397, 5.796550698475776, 5.826662852782887, 5.856620185738529, 5.886425061104576, 5.916079783099616, 5.9455865984779], [0.0, 0.6, 0.848528137423857, 1.0392304845413265, 1.2, 1.3416407864998738, 1.469693845669907, 1.5874507866387544, 1.697056274847714, 1.7999999999999998, 1.8973665961010275, 1.98997487421324, 2.078460969082653, 2.1633307652783937, 2.244994432064365, 2.3237900077244498, 2.4, 2.473863375370596, 2.545584412271571, 2.615339366124404, 2.6832815729997477, 2.749545416973504, 2.814249455894058, 2.877498913987632, 2.939387691339814, 3.0, 3.059411708155671, 3.117691453623979, 3.1749015732775088, 3.2310988842807027, 3.2863353450309964, 3.340658617698013, 3.394112549695428, 3.4467375879228173, 3.4985711369071804, 3.5496478698597693, 3.5999999999999996, 3.6496575181789317, 3.698648401781386, 3.746998799039039, 3.794733192202055, 3.8418745424597094, 3.8884444190447165, 3.9344631145812, 3.97994974842648, 4.024922359499621, 4.069397989875161, 4.113392760240626, 4.156921938165306, 4.2, 4.242640687119285, 4.28485705712571, 4.3266615305567875, 4.368065933568311, 4.409081537009721, 4.449719092257398, 4.48998886412873, 4.52990066116245, 4.569463863518345, 4.608687448721165, 4.6475800154488995, 4.686149805543993, 4.724404724407086, 4.762352359916263, 4.8, 4.8373546489791295, 4.874423042781576, 4.91121166312347, 4.947726750741192, 4.983974317750845, 5.019960159204453, 5.0556898639058145, 5.091168824543142, 5.126402247190518, 5.161395160225576, 5.196152422706632, 5.230678732248808, 5.264978632435273, 5.299056519796709, 5.332916650389353, 5.366563145999495, 5.4, 5.43323108288245, 5.466260147486579, 5.499090833947008, 5.531726674375732, 5.5641710972974225, 5.596427431853289, 5.628498911788116, 5.660388679233962, 5.692099788303082, 5.7236352085016735, 5.754997827975264, 5.786190456595773, 5.817215828899595, 5.848076606885377, 5.878775382679628, 5.909314681077663, 5.939696961966999, 5.96992462263972, 6.0, 6.029925372672535], [0.0, 0.608276253029822, 0.8602325267042626, 1.053565375285274, 1.216552506059644, 1.3601470508735445, 1.489966442575134, 1.6093476939431082, 1.7204650534085253, 1.8248287590894658, 1.9235384061671346, 2.017424100183202, 2.107130750570548, 2.193171219946131, 2.2759613353482084, 2.355843797877949, 2.433105012119288, 2.5079872407968904, 2.5806975801127883, 2.651414716712571, 2.720294101747089, 2.787471972953271, 2.8530685235374214, 2.917190429162965, 2.979932885150268, 3.04138126514911, 3.101612483854165, 3.160696125855822, 3.2186953878862163, 3.2756678708318403, 3.331666249791536, 3.38673884437522, 3.4409301068170506, 3.49428104193123, 3.54682957019364, 3.5986108430893164, 3.6496575181789317, 3.7, 3.7496666518505353, 3.7986839826445165, 3.847076812334269, 3.89486841883009, 3.942080668885405, 3.988734135035826, 4.034848200366404, 4.080441152620633, 4.125530268947254, 4.170131892398609, 4.214261501141096, 4.257933771208754, 4.301162633521314, 4.343961325794695, 4.386342439892262, 4.428317965096906, 4.469899327725402, 4.511097427455985, 4.551922670696417, 4.592385001282014, 4.632493928760188, 4.672258554489466, 4.711687595755898, 4.750789408087881, 4.789572005931219, 4.828043081829325, 4.866210024238576, 4.904079934095691, 4.941659640242335, 4.978955713801841, 5.015974481593781, 5.052722038663912, 5.089204259999789, 5.1254268114957995, 5.1613951602255765, 5.197114584074513, 5.232590180780452, 5.26782687642637, 5.302829433425142, 5.3376024580330075, 5.372150407425318, 5.406477596365309, 5.440588203494178, 5.474486277268398, 5.508175741568166, 5.541660400998964, 5.574943945906542, 5.608029957123981, 5.640921910468182, 5.673623181001714, 5.706137047074843, 5.7384666941614295, 5.770615218501404, 5.8025856305616035, 5.83438085832593, 5.866003750424986, 5.897457079114693, 5.928743543112655, 5.959865770300536, 5.990826320300065, 6.021627686929839, 6.052272300549605, 6.08276253029822, 6.113100686231171], [0.0, 0.6164414002968976, 0.8717797887081348, 1.0677078252031313, 1.2328828005937953, 1.3784048752090223, 1.50996688705415, 1.6309506430300091, 1.7435595774162695, 1.849324200890693, 1.949358868961793, 2.0445048300260877, 2.1354156504062627, 2.222611077089287, 2.3065125189341593, 2.3874672772626644, 2.4657656011875906, 2.541653005427767, 2.615339366124404, 2.687005768508881, 2.7568097504180447, 2.824889378365107, 2.891366458960192, 2.956349099818897, 3.0199337741083, 3.0822070014844885, 3.1432467291003428, 3.203123475609394, 3.2619012860600183, 3.3196385345395667, 3.376388603226826, 3.432200460346103, 3.487119154832539, 3.541186241925155, 3.594440151122286, 3.646916505762094, 3.698648401781386, 3.7496666518505353, 3.8000000000000003, 3.8496753109840323, 3.898717737923586, 3.9471508711981107, 3.9949968710876362, 4.042276586281547, 4.0890096600521755, 4.135214625627066, 4.180908992073375, 4.226109321823088, 4.270831300812525, 4.315089802078284, 4.358898943540674, 4.402272140611029, 4.445222154178574, 4.487761134463376, 4.529900661162451, 4.571651780264984, 4.613025037868319, 4.654030511288038, 4.694677837722201, 4.734976240700686, 4.774934554525329, 4.814561246884289, 4.853864439804639, 4.892851929090027, 4.931531202375181, 4.969909455915671, 5.007993610219566, 5.045790324617146, 5.083306010855534, 5.120546845796843, 5.157518783291051, 5.194227565288221, 5.230678732248808, 5.266877632905477, 5.302829433425141, 5.338539126015656, 5.374011537017762, 5.409251334519409, 5.444263035526481, 5.47905101272109, 5.513619500836089, 5.547972602672079, 5.582114294781146, 5.616048432839589, 5.649778756730214, 5.68330889535313, 5.716642371182581, 5.749782604586021, 5.782732917920384, 5.815496539419485, 5.848076606885378, 5.880476171195663, 5.912698199637794, 5.944745579080741, 5.976621118993575, 6.008327554319921, 6.0398675482166, 6.071243694664217, 6.102458520956943, 6.133514490078262, 6.164414002968977, 6.1951594006934165], [0.0, 0.6244997998398399, 0.8831760866327847, 1.081665382639197, 1.2489995996796799, 1.3964240043768943, 1.5297058540778357, 1.6522711641858308, 1.7663521732655694, 1.8734993995195195, 1.97484176581315, 2.0712315177207983, 2.163330765278394, 2.2516660498395407, 2.3366642891095846, 2.4186773244895647, 2.4979991993593598, 2.574878637916747, 2.6495282598983545, 2.7221315177632404, 2.7928480087537886, 2.861817604250837, 2.9291637031753623, 2.994995826374388, 3.0594117081556713, 3.1224989991991996, 3.1843366656181322, 3.244996147917591, 3.3045423283716615, 3.363034344160048, 3.420526275297414, 3.477067730142742, 3.5327043465311387, 3.58747822293042, 3.6414282912066254, 3.6945906403822333, 3.746998799039039, 3.7986839826445165, 3.8496753109840323, 3.900000000000001, 3.9496835316263, 3.9987498046264416, 4.047221268969613, 4.095119045888654, 4.1424630354415966, 4.189272013130682, 4.235563716909475, 4.281354925721529, 4.326661530556788, 4.371498598878879, 4.415880433163924, 4.459820624195553, 4.503332099679081, 4.546427168667723, 4.589117562233507, 4.631414470763765, 4.673328578219169, 4.7148700936505135, 4.756048780237647, 4.796873982084583, 4.8373546489791295, 4.87749935930288, 4.917316341257699, 4.956813492557492, 4.9959983987187195, 5.034878350069642, 5.073460357586329, 5.111751167652823, 5.149757275833494, 5.187484939737176, 5.2249401910452535, 5.262128846769148, 5.299056519796709, 5.335728628781641, 5.372150407425317, 5.408326913195984, 5.444263035526481, 5.479963503528103, 5.515432893255072, 5.550675634551168, 5.585696017507577, 5.620498198558559, 5.655086206239478, 5.68946394662977, 5.723635208501674, 5.757603668193913, 5.791372894228104, 5.8249463516842805, 5.858327406350725, 5.8915193286621745, 5.92452529743945, 5.957348403442593, 5.989991652748776, 6.02245796996542, 6.054750201288242, 6.08687111741328, 6.118823416311343, 6.150609725872713, 6.182232606429493, 6.213694553162394, 6.244997998398399, 6.276145313805283], [0.0, 0.6324555320336759, 0.8944271909999159, 1.0954451150103324, 1.2649110640673518, 1.4142135623730951, 1.5491933384829668, 1.6733200530681511, 1.7888543819998317, 1.8973665961010275, 2.0, 2.0976176963403033, 2.1908902300206647, 2.280350850198276, 2.3664319132398464, 2.449489742783178, 2.5298221281347035, 2.6076809620810595, 2.6832815729997477, 2.7568097504180447, 2.8284271247461903, 2.898275349237888, 2.9664793948382653, 3.0331501776206204, 3.0983866769659336, 3.1622776601683795, 3.22490309931942, 3.286335345030997, 3.3466401061363023, 3.4058772731852804, 3.4641016151377544, 3.521363372331802, 3.5777087639996634, 3.6331804249169903, 3.687817782917155, 3.7416573867739413, 3.794733192202055, 3.847076812334269, 3.898717737923586, 3.9496835316263, 4.0, 4.049691346263318, 4.09878030638384, 4.147288270665544, 4.1952353926806065, 4.242640687119285, 4.2895221179054435, 4.33589667773576, 4.3817804600413295, 4.427188724235731, 4.47213595499958, 4.5166359162544865, 4.560701700396552, 4.604345773288536, 4.6475800154489, 4.69041575982343, 4.732863826479693, 4.774934554525329, 4.8166378315169185, 4.857983120596447, 4.898979485566356, 4.9396356140913875, 4.979959839195493, 5.019960159204453, 5.059644256269407, 5.0990195135927845, 5.138093031466052, 5.176871642217914, 5.215361924162119, 5.253570214625479, 5.291502622129181, 5.329165037789691, 5.366563145999495, 5.403702434442518, 5.440588203494177, 5.477225575051661, 5.513619500836089, 5.549774770204643, 5.585696017507577, 5.621387729022079, 5.656854249492381, 5.692099788303083, 5.727128425310542, 5.761944116355173, 5.796550698475776, 5.830951894845301, 5.865151319446072, 5.8991524815010505, 5.932958789676531, 5.966573556070519, 6.0, 6.0332412515993425, 6.066300355241241, 6.099180272790763, 6.131883886702357, 6.164414002968976, 6.196773353931867, 6.228964600958975, 6.260990336999411, 6.29285308902091, 6.324555320336759, 6.356099432828282], [0.0, 0.6403124237432849, 0.9055385138137417, 1.1090536506409419, 1.2806248474865698, 1.4317821063276355, 1.5684387141358125, 1.6941074346097418, 1.8110770276274835, 1.9209372712298547, 2.024845673131659, 2.1236760581595306, 2.2181073012818837, 2.3086792761230397, 2.395829710142188, 2.479919353527449, 2.5612496949731396, 2.6400757564888173, 2.716615541441225, 2.791057147390573, 2.863564212655271, 2.934280150224242, 3.0033314835362415, 3.0708305065568178, 3.136877428271625, 3.2015621187164247, 3.264965543462902, 3.3271609519228256, 3.3882148692194836, 3.448187929913334, 3.5071355833500366, 3.5651086939951777, 3.622154055254967, 3.678314831549905, 3.733630940518894, 3.7881393849751626, 3.8418745424597094, 3.89486841883009, 3.9471508711981107, 3.9987498046264416, 4.049691346263318, 4.1000000000000005, 4.149698784249287, 4.198809355043403, 4.247352116319061, 4.295346318982906, 4.342810150121693, 4.389760813529594, 4.436214602563767, 4.4821869662029945, 4.527692569068709, 4.572745346069471, 4.617358552246079, 4.661544808322667, 4.705316142407437, 4.748684028233507, 4.791659420284376, 4.8342527861087286, 4.876474136094644, 4.9183330509431755, 4.959838707054898, 5.000999900019996, 5.041825066382213, 5.082322303829225, 5.122499389946279, 5.162363799656123, 5.201922721455982, 5.241183072551464, 5.280151512977635, 5.3188344587888805, 5.35723809439155, 5.395368384086485, 5.43323108288245, 5.470831746635972, 5.508175741568165, 5.545268253204709, 5.582114294781146, 5.61871871515206, 5.655086206239478, 5.691221310052879, 5.727128425310542, 5.762811813689565, 5.798275605729691, 5.833523806414096, 5.868560300448484, 5.903388857258177, 5.93801313572141, 5.9724366886556455, 6.006662967072483, 6.040695324215583, 6.074537019394977, 6.1081912216301815, 6.1416610131136355, 6.174949392505174, 6.208059278067504, 6.24099351065197, 6.27375485654325, 6.306346010171025, 6.338769596696192, 6.3710281744785915, 6.403124237432849, 6.435060217278469], [0.0, 0.6480740698407861, 0.9165151389911681, 1.1224972160321827, 1.2961481396815722, 1.4491376746189442, 1.5874507866387546, 1.7146428199482249, 1.8330302779823362, 1.9442222095223582, 2.04939015319192, 2.149418526020468, 2.2449944320643653, 2.336664289109585, 2.4248711305964283, 2.5099800796022267, 2.5922962793631443, 2.672077843177478, 2.749545416973504, 2.8248893783651075, 2.8982753492378883, 2.9698484809835, 3.039736830714133, 3.108054053584011, 3.174901573277509, 3.2403703492039306, 3.304542328371662, 3.3674916480965478, 3.4292856398964497, 3.48998567332303, 3.5496478698597698, 3.6083237105337433, 3.6660605559646724, 3.7229020937972575, 3.7788887255382373, 3.834057902536163, 3.8884444190447165, 3.942080668885405, 3.9949968710876362, 4.047221268969613, 4.09878030638384, 4.149698784249287, 4.200000000000001, 4.249705872175156, 4.298837052040936, 4.347413023856832, 4.3954521951671826, 4.442971978304612, 4.489988864128731, 4.536518488885503, 4.582575694955841, 4.628174586162455, 4.67332857821917, 4.718050444834181, 4.762352359916264, 4.806245936279167, 4.849742261192857, 4.892851929090027, 4.935585071701227, 4.9779513858614575, 5.019960159204453, 5.061620293937506, 5.10294032886923, 5.143928459844674, 5.184592558726289, 5.224940191045253, 5.264978632435274, 5.304714883949938, 5.344155686354956, 5.383307533477909, 5.422176684690385, 5.46076917659042, 5.499090833947008, 5.537147279962851, 5.574943945906542, 5.612486080160912, 5.649778756730215, 5.686826883245173, 5.723635208501675, 5.760208329565868, 5.796550698475777, 5.832666628567075, 5.868560300448485, 5.904235767650205, 5.939696961967, 5.974947698515863, 6.009991680526689, 6.044832503882966, 6.079473661428266, 6.113918547053109, 6.148170459575759, 6.182232606429493, 6.216108107168022, 6.249799996799899, 6.283311228962004, 6.316644678941503, 6.349803146555018, 6.38278935889318, 6.4156059729381765, 6.448255578061405, 6.480740698407861, 6.5130637951735135], [0.0, 0.6557438524302001, 0.9273618495495702, 1.1357816691600549, 1.3114877048604001, 1.466287829861518, 1.606237840420901, 1.7349351572897471, 1.8547236990991405, 1.9672315572906, 2.073644135332772, 2.1748563170931545, 2.2715633383201097, 2.364318083507378, 2.453568829277059, 2.5396850198400585, 2.6229754097208002, 2.7037011669191546, 2.782085548648711, 2.8583211855912904, 2.932575659723036, 3.004995840263344, 3.0757112998459397, 3.1448370387032774, 3.212475680841802, 3.278719262151, 3.3436506994600976, 3.407345007480164, 3.4698703145794942, 3.531288716601915, 3.5916569992135936, 3.6510272527057364, 3.709447398198281, 3.7669616403674726, 3.823610858861032, 3.879432948254164, 3.9344631145812, 3.988734135035826, 4.042276586281547, 4.095119045888654, 4.147288270665544, 4.198809355043403, 4.249705872175156, 4.299999999999999, 4.349712634186309, 4.398863489584553, 4.447471191587417, 4.495553358597804, 4.543126676640219, 4.5902069670114, 4.636809247747852, 4.682947789587239, 4.728636167014756, 4.773887304912004, 4.818713521262703, 4.863126566315131, 4.907137658554118, 4.950757517794625, 4.993996395673509, 5.03686410378521, 5.079370039680117, 5.121523210920751, 5.163332257370234, 5.204805471869242, 5.2459508194416005, 5.28677595515452, 5.3272882407468805, 5.367494760127856, 5.407402333838309, 5.447017532558529, 5.486346689738081, 5.525395913416522, 5.564171097297422, 5.602677931132575, 5.6409219104681805, 5.678908345800274, 5.716642371182581, 5.754128952326321, 5.791372894228104, 5.8283788483591215, 5.865151319446072, 5.9016946718718, 5.938013135721409, 5.974110812497538, 6.009991680526688, 6.0456596000767355, 6.081118318204308, 6.1163714733492105, 6.151422599691879, 6.186275131288617, 6.220932405998315, 6.255397669213365, 6.289674077406555, 6.323764701504951, 6.357672530100933, 6.3914004725099165, 6.424951361683604, 6.458327956987009, 6.491532946846992, 6.524568951279464, 6.557438524302, 6.590144156238162], [0.0, 0.66332495807108, 0.938083151964686, 1.148912529307606, 1.32664991614216, 1.4832396974191329, 1.6248076809271923, 1.7549928774784245, 1.876166303929372, 1.98997487421324, 2.0976176963403033, 2.2, 2.297825058615212, 2.3916521486202797, 2.4819347291981715, 2.569046515733026, 2.65329983228432, 2.734958866235469, 2.814249455894058, 2.8913664589601926, 2.9664793948382657, 3.039736830714133, 3.1112698372208096, 3.1811947441173736, 3.2496153618543846, 3.3166247903554003, 3.382306905057553, 3.4467375879228177, 3.509985754956849, 3.5721142198983507, 3.63318042491699, 3.693237062523878, 3.752332607858744, 3.8105117766515306, 3.8678159211627436, 3.924283374069717, 3.97994974842648, 4.034848200366404, 4.0890096600521755, 4.1424630354415966, 4.1952353926806065, 4.247352116319061, 4.298837052040936, 4.349712634186309, 4.4, 4.449719092257398, 4.498888751680798, 4.54752680036083, 4.595650117230424, 4.64327470649756, 4.69041575982343, 4.737087712930806, 4.7833042972405595, 4.829078587059855, 4.874423042781577, 4.919349550499538, 4.963869458396343, 5.007993610219566, 5.051732376126036, 5.095095681142799, 5.138093031466052, 5.180733538795447, 5.223025942880239, 5.264978632435274, 5.30659966456864, 5.347896782848375, 5.388877434122993, 5.429548784199292, 5.469917732470938, 5.509990925582365, 5.549774770204644, 5.589275444992849, 5.628498911788116, 5.667450926121902, 5.706137047074843, 5.7445626465380295, 5.782732917920385, 5.8206528843421, 5.858327406350725, 5.895761189193471, 5.9329587896765315, 5.969924622639721, 6.006662967072484, 6.043177971895251, 6.079473661428266, 6.115553940568263, 6.15142259969188, 6.187083319303208, 6.222539674441619, 6.2577951388648065, 6.29285308902091, 6.327716807822551, 6.362389488234747, 6.3968742366877915, 6.431174076325411, 6.465291950097845, 6.499230723708769, 6.532993188424431, 6.566582063752802, 6.600000000000001, 6.6332495807108005, 6.666333324999584], [0.0, 0.6708203932499369, 0.9486832980505137, 1.161895003862225, 1.3416407864998738, 1.5, 1.6431676725154982, 1.7748239349298847, 1.8973665961010273, 2.0124611797498106, 2.1213203435596424, 2.224859546128699, 2.32379000772445, 2.4186773244895647, 2.5099800796022262, 2.5980762113533156, 2.6832815729997477, 2.765863337187866, 2.846049894151541, 2.924038303442689, 3.0, 3.0740852297878796, 3.1464265445104544, 3.2171415884290826, 3.2863353450309964, 3.3541019662496843, 3.420526275297414, 3.4856850115866753, 3.5496478698597693, 3.6124783736376886, 3.674234614174767, 3.7349698793966195, 3.7947331922020546, 3.853569773599539, 3.911521443121589, 3.9686269665968856, 4.024922359499621, 4.080441152620633, 4.135214625627066, 4.189272013130682, 4.242640687119285, 4.295346318982906, 4.347413023856832, 4.398863489584553, 4.449719092257398, 4.499999999999999, 4.54972526643093, 4.598912915026768, 4.6475800154489, 4.695742752749558, 4.743416490252569, 4.790615826801393, 4.8373546489791295, 4.883646178829912, 4.9295030175464944, 4.9749371855331, 5.0199601592044525, 5.064582904840239, 5.10881590977792, 5.1526692111953, 5.196152422706631, 5.239274758971893, 5.282045058497702, 5.324471804789654, 5.366563145999495, 5.4083269131959835, 5.449770637375485, 5.490901565316937, 5.531726674375732, 5.572252686302012, 5.612486080160912, 5.652433104425031, 5.692099788303082, 5.731491952362839, 5.770615218501403, 5.809475019311125, 5.848076606885378, 5.886425061104575, 5.92452529743945, 5.962382074305537, 6.0, 6.037383539249432, 6.074537019394977, 6.111464636239008, 6.148170459575759, 6.18465843842649, 6.220932405998316, 6.256996084384263, 6.292853089020909, 6.328506932918695, 6.363961030678928, 6.399218702310462, 6.434283176858165, 6.469157595854347, 6.5038450166036395, 6.53834841531101, 6.572670690061993, 6.606814663663572, 6.640783086353596, 6.674578638386096, 6.7082039324993685, 6.74166151627327], [0.0, 0.6782329983125268, 0.9591663046625439, 1.1747340124470733, 1.3564659966250536, 1.5165750888103102, 1.661324772583615, 1.7944358444926363, 1.9183326093250879, 2.0346989949375804, 2.1447610589527217, 2.249444375840399, 2.3494680248941466, 2.445403852127497, 2.5377155080899043, 2.626785107312739, 2.7129319932501073, 2.7964262908219126, 2.877498913987632, 2.956349099818897, 3.0331501776206204, 3.108054053584011, 3.1811947441173736, 3.252691193458119, 3.32264954516723, 3.3911649915626345, 3.458323293158117, 3.5242020373412197, 3.5888716889852725, 3.6523964735499352, 3.714835124201342, 3.7762415176998414, 3.8366652186501757, 3.896151947755632, 3.954743986657038, 4.012480529547776, 4.069397989875161, 4.125530268947254, 4.180908992073375, 4.235563716909475, 4.2895221179054435, 4.342810150121693, 4.3954521951671826, 4.447471191587417, 4.498888751680798, 4.54972526643093, 4.6000000000000005, 4.649731175025068, 4.698936049788293, 4.747630988187688, 4.79583152331272, 4.843552415324934, 4.890807704254994, 4.937610758251404, 4.983974317750845, 5.029910535983717, 5.075431016179809, 5.120546845796843, 5.165268628057984, 5.209606511052442, 5.253570214625478, 5.297169055259611, 5.340411969127476, 5.383307533477908, 5.4258639865002145, 5.468089245796926, 5.509990925582365, 5.551576352712804, 5.592852581643825, 5.63382640840131, 5.674504383644443, 5.71489282489182, 5.754997827975264, 5.794825277780168, 5.834380858325929, 5.873670062235366, 5.912698199637794, 5.951470406546605, 5.989991652748776, 6.028266749240615, 6.066300355241241, 6.104096984812742, 6.1416610131136355, 6.178996682310163, 6.216108107168022, 6.252999280345393, 6.289674077406556, 6.326136261573884, 6.362389488234747, 6.398437309218556, 6.434283176858165, 6.469930447848725, 6.505382386916238, 6.540642170307134, 6.57571288910944, 6.6105975524153635, 6.64529909033446, 6.679820356865895, 6.714164132637808, 6.748333127521196, 6.782329983125269, 6.81615727518079], [0.0, 0.6855654600401044, 0.9695359714832658, 1.187434208703792, 1.3711309200802089, 1.5329709716755893, 1.6792855623746665, 1.8138357147217055, 1.9390719429665315, 2.056696380120313, 2.16794833886788, 2.273763400180415, 2.374868417407584, 2.471841418861655, 2.565151067676132, 2.6551836094703507, 2.7422618401604177, 2.826658805020514, 2.9086079144497976, 2.9883105594967874, 3.0659419433511785, 3.1416556144810017, 3.2155870381627056, 3.2878564445547194, 3.358571124749333, 3.4278273002005224, 3.4957116585897072, 3.5623026261113755, 3.627671429443411, 3.691882988394947, 3.7549966711037173, 3.817066936798463, 3.878143885933063, 3.9382737335030438, 3.997499218261337, 4.05585995813465, 4.113392760240626, 4.170131892398609, 4.226109321823088, 4.281354925721529, 4.33589667773576, 4.389760813529594, 4.442971978304612, 4.495553358597804, 4.54752680036083, 4.598912915026768, 4.649731175025068, 4.7, 4.749736834815168, 4.798958220280731, 4.847679857416329, 4.89591666595746, 4.94368283772331, 4.990991885387113, 5.037856687124, 5.084289527554465, 5.130302135352264, 5.175905717843014, 5.221110992882646, 5.265928218272634, 5.310367218940701, 5.354437412091022, 5.3981478305063115, 5.441507144165117, 5.4845236803208355, 5.527205442174191, 5.569560126257728, 5.61159513863928, 5.653317610041028, 5.69473440996154, 5.735852159879995, 5.776677245614472, 5.817215828899595, 5.857473858242988, 5.897457079114692, 5.937171043518958, 5.976621118993575, 6.015812497078014, 6.054750201288242, 6.09343909463285, 6.131883886702357, 6.17008914036094, 6.208059278067503, 6.245798587850876, 6.2833112289620034, 6.320601237224193, 6.357672530100934, 6.394528911499267, 6.431174076325411, 6.4676116148080505, 6.5038450166036395, 6.539877674696982, 6.575712889109439, 6.611353870426239, 6.646803743153547, 6.682065548915245, 6.717142249498666, 6.7520367297579185, 6.786751800382861, 6.821290200541244, 6.855654600401045, 6.889847603539574], [0.0, 0.692820323027551, 0.9797958971132713, 1.2000000000000004, 1.385640646055102, 1.549193338482967, 1.6970562748477143, 1.8330302779823362, 1.9595917942265426, 2.078460969082653, 2.1908902300206647, 2.297825058615212, 2.400000000000001, 2.4979991993593598, 2.5922962793631443, 2.6832815729997477, 2.771281292110204, 2.8565713714171403, 2.9393876913398143, 3.0199337741083006, 3.098386676965934, 3.174901573277509, 3.2496153618543846, 3.3226495451672307, 3.3941125496954285, 3.4641016151377553, 3.5327043465311396, 3.6000000000000005, 3.6660605559646724, 3.7309516212355267, 3.7947331922020555, 3.8574603043971827, 3.9191835884530852, 3.9799497484264807, 4.039801975344832, 4.09878030638384, 4.156921938165306, 4.214261501141096, 4.270831300812525, 4.326661530556788, 4.3817804600413295, 4.436214602563767, 4.489988864128731, 4.543126676640219, 4.595650117230424, 4.6475800154489, 4.698936049788293, 4.749736834815168, 4.800000000000002, 4.849742261192857, 4.898979485566357, 4.947726750741194, 4.9959983987187195, 5.043808085167398, 5.091168824543143, 5.1380930314660525, 5.184592558726289, 5.230678732248809, 5.276362383309169, 5.321653878260029, 5.366563145999495, 5.411099703387474, 5.455272678794342, 5.499090833947009, 5.542562584220408, 5.585696017507577, 5.628498911788117, 5.670978751503131, 5.713142742834281, 5.754997827975265, 5.796550698475777, 5.83780780773057, 5.8787753826796285, 5.9194594347794975, 5.959865770300536, 6.000000000000001, 6.039867548216601, 6.079473661428266, 6.1188234163113435, 6.157921727336262, 6.196773353931868, 6.235382907247959, 6.27375485654325, 6.311893535223801, 6.349803146555018, 6.387487769068526, 6.424951361683605, 6.462197768561406, 6.499230723708769, 6.536053855347277, 6.572670690061994, 6.609084656743323, 6.645299090334461, 6.681317235396028, 6.717142249498667, 6.752777206453653, 6.788225099390857, 6.823488843692794, 6.8585712797928995, 6.893475175845635, 6.9282032302755105, 6.962758074211686], [0.0, 0.7000000000000001, 0.9899494936611665, 1.2124355652982142, 1.4000000000000001, 1.565247584249853, 1.7146428199482247, 1.8520259177452134, 1.979898987322333, 2.1, 2.2135943621178655, 2.32163735324878, 2.4248711305964283, 2.5238858928247927, 2.619160170741759, 2.7110883423451915, 2.8000000000000003, 2.8861739379323623, 2.9698484809834995, 3.051229260478472, 3.130495168499706, 3.2078029864690882, 3.283291031876401, 3.357082066318904, 3.4292856398964493, 3.5, 3.5693136595149495, 3.6373066958946425, 3.704051835490427, 3.769615364994153, 3.8340579025361627, 3.8974350539810154, 3.959797974644666, 4.02119385257662, 4.08166632639171, 4.141255848169731, 4.2, 4.257933771208754, 4.315089802078284, 4.371498598878879, 4.427188724235731, 4.4821869662029945, 4.536518488885503, 4.5902069670114, 4.64327470649756, 4.695742752749558, 4.747630988187688, 4.798958220280731, 4.849742261192857, 4.9, 4.949747468305833, 4.998999899979996, 5.047771785649585, 5.096076922496363, 5.143928459844674, 5.191338940966964, 5.238320341483518, 5.2848841046895245, 5.331041174104736, 5.376802023508025, 5.422176684690383, 5.467174773134658, 5.511805511808268, 5.55607775323564, 5.6000000000000005, 5.643580423808984, 5.686826883245172, 5.729746940310715, 5.772347875864725, 5.814636704042653, 5.856620185738529, 5.898304841223451, 5.939696961966999, 5.980802621722272, 6.021627686929839, 6.06217782649107, 6.102458520956944, 6.142475071174486, 6.182232606429493, 6.221736092120913, 6.260990336999412, 6.300000000000001, 6.338769596696192, 6.377303505401009, 6.4156059729381765, 6.4536811201050215, 6.491532946846993, 6.529165337162171, 6.566582063752802, 6.603786792439623, 6.640783086353597, 6.67757440991862, 6.714164132637808, 6.750555532695069, 6.786751800382861, 6.822756041366274, 6.858571279792899, 6.894200461257274, 6.929646455628165, 6.96491205974634, 7.0, 7.034912934784624], [0.0, 0.7071067811865476, 1.0, 1.2247448713915892, 1.4142135623730951, 1.5811388300841898, 1.7320508075688774, 1.8708286933869709, 2.0, 2.1213203435596424, 2.23606797749979, 2.345207879911715, 2.4494897427831783, 2.5495097567963927, 2.6457513110645907, 2.7386127875258306, 2.8284271247461903, 2.9154759474226504, 3.0, 3.082207001484489, 3.1622776601683795, 3.2403703492039306, 3.3166247903554003, 3.3911649915626345, 3.464101615137755, 3.535533905932738, 3.6055512754639896, 3.6742346141747677, 3.7416573867739418, 3.8078865529319548, 3.872983346207417, 3.9370039370059056, 4.0, 4.06201920231798, 4.123105625617661, 4.183300132670378, 4.242640687119285, 4.301162633521314, 4.358898943540674, 4.415880433163924, 4.47213595499958, 4.527692569068709, 4.582575694955841, 4.636809247747852, 4.69041575982343, 4.743416490252569, 4.79583152331272, 4.847679857416329, 4.898979485566357, 4.949747468305833, 5.000000000000001, 5.04975246918104, 5.099019513592785, 5.147815070493501, 5.196152422706632, 5.244044240850759, 5.291502622129181, 5.338539126015656, 5.385164807134505, 5.431390245600108, 5.477225575051661, 5.522680508593631, 5.5677643628300215, 5.612486080160912, 5.656854249492381, 5.70087712549569, 5.744562646538029, 5.787918451395113, 5.830951894845301, 5.873670062235366, 5.916079783099617, 5.958187643906493, 6.0, 6.041522986797286, 6.082762530298219, 6.123724356957946, 6.164414002968978, 6.2048368229954285, 6.244997998398399, 6.284902544988268, 6.324555320336759, 6.3639610306789285, 6.403124237432849, 6.442049363362563, 6.480740698407861, 6.519202405202649, 6.557438524302001, 6.59545297913646, 6.6332495807108005, 6.670832032063167, 6.708203932499369, 6.745368781616021, 6.782329983125269, 6.8190908484929285, 6.855654600401045, 6.892024376045111, 6.92820323027551, 6.9641941385920605, 7.0, 7.035623639735145, 7.071067811865476, 7.1063352017759485], [0.0, 0.7141428428542851, 1.0099504938362078, 1.2369316876852985, 1.4282856857085702, 1.5968719422671316, 1.7492855684535904, 1.8894443627691186, 2.0199009876724157, 2.142428528562855, 2.2583179581272432, 2.368543856465403, 2.473863375370597, 2.574878637916747, 2.672077843177478, 2.765863337187866, 2.8565713714171403, 2.944486372867092, 3.029851481508624, 3.1128764832546767, 3.193743884534263, 3.272613634390715, 3.3496268448888458, 3.4249087579087423, 3.498571136907181, 3.5707142142714257, 3.6414282912066254, 3.7107950630558952, 3.7788887255382373, 3.845776904605883, 3.9115214431215892, 3.9761790704142093, 4.039801975344831, 4.102438299353204, 4.164132562731403, 4.224926034855522, 4.28485705712571, 4.343961325794695, 4.402272140611029, 4.459820624195553, 4.5166359162544865, 4.572745346069471, 4.628174586162455, 4.682947789587239, 4.737087712930806, 4.790615826801393, 4.843552415324934, 4.89591666595746, 4.947726750741194, 4.998999899979996, 5.04975246918104, 5.100000000000001, 5.149757275833494, 5.199038372622384, 5.247856705360771, 5.296225070746145, 5.344155686354956, 5.391660226683429, 5.43874985635486, 5.485435260760991, 5.531726674375732, 5.577633906953737, 5.62316636780382, 5.668333088307356, 5.713142742834281, 5.757603668193913, 5.801723881744115, 5.845511098270194, 5.888972745734184, 5.932115979985557, 5.974947698515863, 6.017474553332154, 6.059702963017248, 6.101639124038721, 6.143289021363068, 6.184658438426491, 6.225752966509353, 6.266578013557321, 6.307138812488593, 6.347440429023341, 6.387487769068526, 6.427285585688566, 6.466838485689898, 6.506150935845249, 6.54522726878143, 6.584071688552609, 6.62268827591938, 6.661080993352356, 6.6992536897776915, 6.73721010508059, 6.77495387438173, 6.81248853210044, 6.8498175158174845, 6.886944169949399, 6.923871749245506, 6.960603422117942, 6.997142273814362, 7.033491309442276, 7.069653456853455, 7.105631569396208, 7.141428428542851, 7.177046746399247], [0.0, 0.7211102550927979, 1.019803902718557, 1.2489995996796799, 1.4422205101855958, 1.61245154965971, 1.7663521732655696, 1.9078784028338915, 2.039607805437114, 2.1633307652783937, 2.280350850198276, 2.3916521486202797, 2.4979991993593598, 2.6000000000000005, 2.6981475126464085, 2.792848008753788, 2.8844410203711917, 2.973213749463701, 3.0594117081556713, 3.1432467291003428, 3.22490309931942, 3.3045423283716615, 3.3823069050575527, 3.458323293158117, 3.532704346531139, 3.6055512754639896, 3.6769552621700474, 3.7469987990390394, 3.815756805667783, 3.88329756778952, 3.9496835316262997, 4.014971979976947, 4.079215610874228, 4.1424630354415966, 4.204759208325728, 4.266145801540309, 4.3266615305567875, 4.386342439892262, 4.445222154178574, 4.503332099679081, 4.560701700396552, 4.617358552246079, 4.67332857821917, 4.728636167014756, 4.7833042972405595, 4.8373546489791295, 4.890807704254994, 4.94368283772331, 4.9959983987187195, 5.047771785649585, 5.099019513592785, 5.149757275833494, 5.200000000000001, 5.249761899362676, 5.299056519796709, 5.347896782848376, 5.396295025292817, 5.44426303552648, 5.491812087098393, 5.5389529696504916, 5.585696017507576, 5.63205113613149, 5.678027826631356, 5.723635208501674, 5.768882040742383, 5.813776741499453, 5.858327406350725, 5.902541825349482, 5.946427498927402, 5.989991652748776, 6.033241251599343, 6.076183012385325, 6.118823416311343, 6.161168720299745, 6.203224967708329, 6.244997998398398, 6.2864934582006855, 6.327716807822551, 6.3686733312362644, 6.409368143584826, 6.44980619863884, 6.489992295835181, 6.529931086925804, 6.569627082262737, 6.609084656743323, 6.648308055437865, 6.687301398920196, 6.726068688320096, 6.764613810115105, 6.802940540677979, 6.841052550594828, 6.878953408767936, 6.916646586316234, 6.954135460285485, 6.9914233171794145, 7.0285133563222315, 7.065408693062278, 7.102112361825883, 7.138627319029899, 7.17495644586084, 7.211102550927979, 7.247068372797377], [0.0, 0.7280109889280519, 1.0295630140987002, 1.2609520212918495, 1.4560219778561039, 1.627882059609971, 1.7832554500127011, 1.9261360284258224, 2.0591260281974004, 2.1840329667841556, 2.302172886644268, 2.4145392935299275, 2.521904042583699, 2.624880949681338, 2.7239676943752476, 2.819574435974337, 2.9120439557122078, 3.001666203960727, 3.0886890422961004, 3.1733263305244868, 3.255764119219942, 3.336165463522456, 3.414674215792775, 3.491418050019219, 3.5665109000254023, 3.64005494464026, 3.712142238654118, 3.782856063875548, 3.852272056851645, 3.9204591567825324, 3.9874804074753776, 4.053393639902249, 4.118252056394801, 4.182104733265298, 4.244997055358225, 4.306971093471606, 4.368065933568311, 4.428317965096906, 4.487761134463376, 4.546427168667723, 4.604345773288536, 4.661544808322667, 4.718050444834181, 4.773887304912004, 4.829078587059855, 4.883646178829912, 4.937610758251404, 4.990991885387113, 5.043808085167398, 5.096076922496363, 5.147815070493501, 5.199038372622384, 5.249761899362676, 5.300000000000001, 5.349766350038103, 5.399073994677236, 5.447935388750495, 5.496362433464519, 5.5443665102516455, 5.591958512006326, 5.639148871948674, 5.6859475903318, 5.732364259186606, 5.7784080852774675, 5.8240879114244155, 5.869412236331676, 5.914389233048499, 5.959026766175833, 6.003332407921454, 6.047313453096343, 6.090976933136425, 6.134329629226001, 6.177378084592201, 6.220128616033596, 6.262587324740471, 6.304760106459247, 6.3466526610489735, 6.388270501473776, 6.429618962271405, 6.470703207534712, 6.511528238439884, 6.552098900352467, 6.592419889539805, 6.632495759516172, 6.672330927044912, 6.711929677819935, 6.751296171847301, 6.790434448545985, 6.82934843158555, 6.868041933477111, 6.906518659932804, 6.944782214007867, 6.982836100038438, 7.020683727387242, 7.058328414008519, 7.095773389842717, 7.1330218000508046, 7.170076708097342, 7.206941098690901, 7.243617880589783, 7.28010988928052, 7.31641988953614], [0.0, 0.7348469228349535, 1.0392304845413265, 1.2727922061357857, 1.469693845669907, 1.6431676725154984, 1.8, 1.9442222095223582, 2.078460969082653, 2.2045407685048604, 2.32379000772445, 2.4372115213907883, 2.5455844122715714, 2.6495282598983545, 2.749545416973504, 2.846049894151541, 2.939387691339814, 3.0298514815086235, 3.1176914536239795, 3.203123475609394, 3.286335345030997, 3.3674916480965478, 3.4467375879228173, 3.5242020373412197, 3.6, 3.6742346141747677, 3.7469987990390394, 3.818376618407357, 3.8884444190447165, 3.957271787481876, 4.024922359499621, 4.091454509095757, 4.156921938165306, 4.221374183841087, 4.28485705712571, 4.347413023856832, 4.409081537009721, 4.469899327725402, 4.529900661162451, 4.589117562233507, 4.6475800154489, 4.705316142407437, 4.762352359916264, 4.818713521262703, 4.874423042781577, 4.9295030175464944, 4.983974317750845, 5.037856687124, 5.091168824543143, 5.143928459844674, 5.196152422706632, 5.247856705360771, 5.299056519796709, 5.349766350038103, 5.4, 5.449770637375486, 5.499090833947008, 5.547972602672079, 5.596427431853289, 5.644466316668034, 5.692099788303082, 5.739337940912697, 5.786190456595773, 5.8326666285670745, 5.878775382679628, 5.924525297439449, 5.96992462263972, 6.014981296729027, 6.059702963017247, 6.104096984812742, 6.148170459575759, 6.191930232165088, 6.235382907247959, 6.278534860936905, 6.321392251711643, 6.363961030678928, 6.406246951218788, 6.448255578061404, 6.489992295835182, 6.5314623171231725, 6.572670690061994, 6.613622305514581, 6.654321903845651, 6.694774081326419, 6.7349832961930955, 6.77495387438173, 6.814690014960329, 6.854195795277518, 6.8934751758456345, 6.932532004974806, 6.971370023173351, 7.009992867328754, 7.0484040746824395, 7.0866070866106305, 7.124605252222751, 7.162401831787993, 7.2, 7.237402849088892, 7.274613391789285, 7.3116345641723655, 7.348469228349535, 7.385120175054704], [0.0, 0.7416198487095663, 1.0488088481701516, 1.2845232578665131, 1.4832396974191326, 1.6583123951777001, 1.8165902124584952, 1.9621416870348585, 2.0976176963403033, 2.224859546128699, 2.345207879911715, 2.459674775249769, 2.5690465157330262, 2.673948391424188, 2.7748873851023217, 2.8722813232690143, 2.9664793948382653, 3.0577769702841313, 3.146426544510455, 3.232645975048923, 3.3166247903554003, 3.398529093593286, 3.4785054261852175, 3.5566838487557484, 3.6331804249169903, 3.708099243547832, 3.7815340802378077, 3.853569773599539, 3.924283374069717, 3.993745109543172, 4.06201920231798, 4.129164564412516, 4.1952353926806065, 4.260281680828159, 4.324349662087931, 4.387482193696061, 4.449719092257398, 4.511097427455985, 4.571651780264984, 4.631414470763765, 4.69041575982343, 4.748684028233507, 4.806245936279167, 4.863126566315131, 4.919349550499538, 4.9749371855331, 5.029910535983717, 5.084289527554465, 5.1380930314660525, 5.191338940966964, 5.244044240850759, 5.296225070746145, 5.347896782848376, 5.399073994677236, 5.449770637375486, 5.5, 5.549774770204643, 5.599107071667768, 5.648008498577176, 5.6964901474504455, 5.744562646538029, 5.792236183029832, 5.839520528262573, 5.886425061104576, 5.932958789676531, 5.979130371550699, 6.024948132556827, 6.070420084310475, 6.115553940568263, 6.1603571325045765, 6.2048368229954285, 6.248999919987198, 6.29285308902091, 6.336402764976356, 6.3796551630946325, 6.422616289332565, 6.465291950097846, 6.507687761409578, 6.549809157525127, 6.591661399070799, 6.6332495807108005, 6.674578638386097, 6.715653356152327, 6.756478372643548, 6.797058187186572, 6.837397165588672, 6.87749954561976, 6.917369442208505, 6.957010852370435, 6.996427659884722, 7.035623639735144, 7.074602462329597, 7.113367697511497, 7.15192281837549, 7.1902712048990205, 7.2284161474004796, 7.266360849833981, 7.30410843293006, 7.341661937191061, 7.379024325749307, 7.416198487095664, 7.4531872376856345], [0.0, 0.7483314773547883, 1.058300524425836, 1.2961481396815722, 1.4966629547095767, 1.6733200530681511, 1.833030277982336, 1.9798989873223332, 2.116601048851672, 2.244994432064365, 2.3664319132398464, 2.4819347291981715, 2.5922962793631443, 2.6981475126464085, 2.8, 2.8982753492378874, 2.9933259094191533, 3.0854497241083023, 3.1749015732775088, 3.2619012860600183, 3.3466401061363023, 3.4292856398964493, 3.509985754956849, 3.5888716889852725, 3.666060555964672, 3.7416573867739413, 3.8157568056677826, 3.8884444190447165, 3.9597979746446663, 4.029888335921977, 4.098780306383839, 4.166533331199932, 4.233202097703344, 4.298837052040936, 4.363484845854286, 4.427188724235731, 4.48998886412873, 4.551922670696417, 4.613025037868319, 4.673328578219169, 4.732863826479693, 4.791659420284376, 4.849742261192857, 4.907137658554118, 4.963869458396343, 5.0199601592044525, 5.075431016179809, 5.130302135352264, 5.184592558726289, 5.238320341483518, 5.291502622129181, 5.344155686354956, 5.396295025292817, 5.447935388750495, 5.499090833947008, 5.549774770204643, 5.6, 5.649778756730214, 5.6991227395100035, 5.748043145279965, 5.796550698475775, 5.844655678480983, 5.892367945062493, 5.939696961966999, 5.986651818838307, 6.033241251599342, 6.079473661428265, 6.125357132445422, 6.170899448216605, 6.216108107168021, 6.260990336999411, 6.305553108173778, 6.3498031465550175, 6.393746945258312, 6.437390775772432, 6.48074069840786, 6.523802572120037, 6.566582063752802, 6.609084656743323, 6.6513156593263565, 6.6932802122726045, 6.734983296193095, 6.776429738438967, 6.817624219623724, 6.858571279792899, 6.899275324264136, 6.939740629158989, 6.979971346646059, 7.019971509913698, 7.059745037889116, 7.099295739719539, 7.138627319029899, 7.177743377970545, 7.216647421067487, 7.255342858886822, 7.293833011524187, 7.332121111929344, 7.370210309075312, 7.408103670980854, 7.445804187594514, 7.483314773547883, 7.520638270785267], [0.0, 0.754983443527075, 1.0677078252031311, 1.3076696830622023, 1.50996688705415, 1.6881943016134133, 1.849324200890693, 1.997498435543818, 2.1354156504062622, 2.264950330581225, 2.3874672772626644, 2.503996805109783, 2.6153393661244047, 2.72213151776324, 2.824889378365107, 2.924038303442689, 3.0199337741083, 3.1128764832546763, 3.2031234756093934, 3.290896534380867, 3.3763886032268267, 3.459768778401239, 3.5411862419251547, 3.620773398046335, 3.698648401781386, 3.774917217635375, 3.849675310984032, 3.9230090491866063, 3.994996871087636, 4.065710270051224, 4.135214625627066, 4.20356991139674, 4.2708313008125245, 4.337049688440288, 4.402272140611028, 4.466542286825459, 4.52990066116245, 4.592385001282014, 4.654030511288038, 4.7148700936505135, 4.774934554525329, 4.8342527861087286, 4.892851929090027, 4.950757517794625, 5.007993610219566, 5.064582904840239, 5.120546845796843, 5.175905717843014, 5.230678732248809, 5.2848841046895245, 5.338539126015656, 5.391660226683429, 5.44426303552648, 5.496362433464519, 5.547972602672079, 5.599107071667768, 5.649778756730214, 5.7, 5.749782604586021, 5.799137866959191, 5.848076606885378, 5.8966091951222275, 5.944745579080739, 5.9924953066314535, 6.0398675482166, 6.08687111741328, 6.133514490078261, 6.17980582219215, 6.2257529665093525, 6.271363488110062, 6.316644678941503, 6.361603571427569, 6.406246951218787, 6.450581369148055, 6.494613152451807, 6.5383484153110105, 6.581793068761734, 6.624952830020755, 6.667833231267862, 6.710439627923047, 6.752777206453653, 6.794850991743675, 6.836665854054885, 6.878226515607057, 6.919537556802478, 6.960603422117942, 7.001428425685718, 7.042016756583302, 7.0823724838503095, 7.122499561249548, 7.162401831787993, 7.202083032012336, 7.24154679609267, 7.280796659706959, 7.31983606373804, 7.358668357794092, 7.397296803562772, 7.4357245780085215, 7.473954776421918, 7.5119904153293495, 7.54983443527075, 7.587489703452652], [0.0, 0.7615773105863909, 1.0770329614269007, 1.3190905958272923, 1.5231546211727818, 1.7029386365926404, 1.8654758106177631, 2.0149441679609885, 2.1540659228538015, 2.2847319317591723, 2.4083189157584592, 2.525866188063018, 2.6381811916545845, 2.7459060435491964, 2.8495613697550017, 2.9495762407505253, 3.0463092423455636, 3.1400636936215167, 3.2310988842807027, 3.319638534539567, 3.405877273185281, 3.48998567332303, 3.5721142198983507, 3.6523964735499352, 3.7309516212355263, 3.8078865529319548, 3.8832975677895205, 3.957271787481876, 4.029888335921977, 4.101219330881976, 4.171330722922842, 4.240283009422838, 4.308131845707603, 4.374928570845472, 4.440720662234904, 4.505552130427525, 4.569463863518345, 4.632493928760188, 4.694677837722201, 4.756048780237647, 4.8166378315169185, 4.876474136094644, 4.935585071701227, 4.993996395673509, 5.051732376126036, 5.10881590977792, 5.165268628057984, 5.221110992882646, 5.276362383309169, 5.331041174104736, 5.385164807134505, 5.43874985635486, 5.491812087098393, 5.5443665102516455, 5.596427431853289, 5.648008498577176, 5.6991227395100035, 5.749782604586021, 5.800000000000001, 5.849786320883866, 5.8991524815010505, 5.948108943185221, 5.99666574022598, 6.044832503882966, 6.092618484691127, 6.1400325732035, 6.187083319303208, 6.23377895020348, 6.280127387243033, 6.326136261573885, 6.3718129288295975, 6.417164482853779, 6.462197768561405, 6.5069193939989765, 6.55133574166368, 6.59545297913646, 6.639277069079134, 6.682813778641449, 6.726068688320096, 6.76904720030818, 6.811754546370562, 6.854195795277518, 6.8963758598266685, 6.938299503480662, 6.97997134664606, 7.021395872616784, 7.062577433203831, 7.103520254071217, 7.144228439796701, 7.184705978674423, 7.224956747275378, 7.264984514780469, 7.3047929470998705, 7.3443856107914165, 7.383765976789894, 7.4229374239582535, 7.4619032424710525, 7.5006666370396715, 7.539230729988306, 7.577598564189055, 7.6157731058639095, 7.653757247260983], [0.0, 0.7681145747868608, 1.0862780491200215, 1.3304134695650072, 1.5362291495737217, 1.7175564037317668, 1.8814887722226779, 2.0322401432901573, 2.172556098240043, 2.3043437243605824, 2.4289915602982237, 2.5475478405713994, 2.6608269391300143, 2.7694764848252458, 2.8740215726399825, 2.974894956128703, 3.0724582991474434, 3.167017524422623, 3.2588341473600644, 3.3481338085566414, 3.4351128074635335, 3.5199431813596083, 3.602776706930364, 3.6837480912787726, 3.7629775444453557, 3.840572873934304, 3.916631205513228, 3.9912404086950213, 4.064480286580315, 4.136423575989287, 4.207136793592525, 4.276680956068619, 4.345112196480086, 4.412482294582042, 4.4788391353117385, 4.544227107000705, 4.608687448721165, 4.672258554489466, 4.734976240700686, 4.796873982084583, 4.857983120596447, 4.9183330509431755, 4.9779513858614575, 5.03686410378521, 5.095095681142799, 5.1526692111953, 5.209606511052442, 5.265928218272634, 5.321653878260029, 5.376802023508025, 5.431390245600108, 5.485435260760991, 5.5389529696504916, 5.591958512006326, 5.644466316668034, 5.6964901474504455, 5.748043145279965, 5.799137866959191, 5.849786320883866, 5.8999999999999995, 5.949789912257406, 5.999166608788257, 6.048140210014975, 6.096720429870472, 6.144916598294887, 6.192737682156413, 6.240192304729077, 6.287288763847259, 6.334035048845246, 6.380438856379708, 6.4265076052238514, 6.472248450113762, 6.517668294720129, 6.562773803811921, 6.607571414672716, 6.652067347825035, 6.696267617113283, 6.740178039191546, 6.783804242458652, 6.827151675479314, 6.870225614927067, 6.913031173081747, 6.955573304911681, 6.997856814768361, 7.0398863627192165, 7.0816664705420855, 7.123201527403251, 7.164495795239188, 7.205553413860728, 7.246378405796926, 7.286974680894671, 7.327346040688948, 7.367496182557545, 7.407428703673091, 7.447147104764348, 7.486654793697916, 7.525955088890711, 7.565051222562872, 7.603946343840151, 7.642643521714199, 7.681145747868608, 7.719455939378112], [0.0, 0.7745966692414833, 1.0954451150103321, 1.3416407864998738, 1.5491933384829666, 1.7320508075688772, 1.8973665961010275, 2.0493901531919194, 2.1908902300206643, 2.3237900077244498, 2.449489742783178, 2.569046515733026, 2.6832815729997477, 2.792848008753788, 2.8982753492378874, 2.9999999999999996, 3.098386676965933, 3.1937438845342623, 3.2863353450309964, 3.3763886032268267, 3.4641016151377544, 3.5496478698597693, 3.63318042491699, 3.714835124201342, 3.794733192202055, 3.8729833462074166, 3.9496835316262997, 4.024922359499621, 4.098780306383839, 4.171330722922842, 4.242640687119285, 4.3127717305695645, 4.381780460041329, 4.449719092257398, 4.516635916254486, 4.58257569495584, 4.6475800154488995, 4.711687595755898, 4.774934554525329, 4.8373546489791295, 4.898979485566356, 4.959838707054898, 5.019960159204453, 5.079370039680117, 5.138093031466052, 5.196152422706631, 5.253570214625478, 5.310367218940701, 5.366563145999495, 5.422176684690383, 5.477225575051661, 5.531726674375732, 5.585696017507576, 5.639148871948674, 5.692099788303082, 5.744562646538029, 5.796550698475775, 5.848076606885378, 5.8991524815010505, 5.949789912257406, 5.999999999999999, 6.049793384901669, 6.099180272790762, 6.148170459575758, 6.196773353931866, 6.244997998398397, 6.292853089020909, 6.340346993658943, 6.387487769068525, 6.434283176858164, 6.48074069840786, 6.526867548832287, 6.572670690061993, 6.618156843109718, 6.663332499583071, 6.7082039324993685, 6.752777206453653, 6.797058187186571, 6.841052550594828, 6.884765791223402, 6.928203230275509, 6.97137002317335, 7.014271166700073, 7.056911505750939, 7.099295739719539, 7.1414284285428495, 7.183313998427188, 7.224956747275377, 7.26636084983398, 7.307530362578043, 7.348469228349534, 7.389181280764466, 7.429670248402684, 7.469939758793239, 7.5099933422074345, 7.549834435270749, 7.58946638440411, 7.628892449104261, 7.668115805072325, 7.707139547199078, 7.745966692414833, 7.784600182411426], [0.0, 0.7810249675906654, 1.104536101718726, 1.3527749258468684, 1.5620499351813308, 1.746424919657298, 1.9131126469708992, 2.0663978319771825, 2.209072203437452, 2.3430749027719964, 2.4698178070456938, 2.5903667693977237, 2.705549851693737, 2.816025568065745, 2.9223278392404914, 3.0248966924508345, 3.1240998703626617, 3.2202484376209237, 3.3136083051561784, 3.4044089061098406, 3.492849839314596, 3.5791060336346563, 3.6633318168028404, 3.745664160065609, 3.8262252939417984, 3.9051248379533274, 3.9824615503479754, 4.058324777540605, 4.132795663954365, 4.205948168962618, 4.277849927241487, 4.34856298103178, 4.418144406874904, 4.486646854834912, 4.5541190146942805, 4.620606020859168, 4.686149805543993, 4.750789408087881, 4.814561246884289, 4.87749935930288, 4.9396356140913875, 5.000999900019996, 5.061620293937506, 5.121523210920751, 5.180733538795447, 5.239274758971893, 5.297169055259611, 5.354437412091022, 5.411099703387474, 5.467174773134658, 5.522680508593631, 5.577633906953737, 5.63205113613149, 5.6859475903318, 5.739337940912697, 5.792236183029832, 5.844655678480983, 5.8966091951222275, 5.948108943185221, 5.999166608788257, 6.049793384901669, 6.1, 6.149796744608719, 6.199193495931548, 6.248199740725323, 6.296824596572465, 6.345076831686122, 6.392964883369843, 6.440496875241847, 6.487680633323437, 6.534523701081817, 6.5810333535091585, 6.627216610312357, 6.673080248281149, 6.71863081289633, 6.7638746292343415, 6.808817812219681, 6.853466276272176, 6.897825744392215, 6.941901756723442, 6.985699678629192, 7.029224708315989, 7.07248188403477, 7.115476090888086, 7.158212067269313, 7.200694410957877, 7.242927584892728, 7.284915922644544, 7.326663633605681, 7.368174807915458, 7.409453421137082, 7.450503338701353, 7.491328320131218, 7.531932023060219, 7.572318007057021, 7.6124897372673015, 7.652450587883597, 7.692203845452876, 7.731752712031082, 7.771100308193172, 7.810249675906655, 7.849203781276163], [0.0, 0.787400787401181, 1.1135528725660042, 1.3638181696985856, 1.574801574802362, 1.760681686165901, 1.928730152198591, 2.083266665599966, 2.2271057451320084, 2.362202362203543, 2.4899799195977463, 2.6115129714401193, 2.727636339397171, 2.839013913315678, 2.9461839725312466, 3.049590136395381, 3.149603149604724, 3.246536616149585, 3.340658617698013, 3.432200460346103, 3.521363372331802, 3.608323710533743, 3.6932370625238775, 3.7762415176998414, 3.857460304397182, 3.9370039370059056, 4.014971979976946, 4.091454509095756, 4.166533331199932, 4.240283009422838, 4.3127717305695645, 4.384062043356595, 4.454211490264017, 4.523273151159457, 4.591296113299598, 4.658325879540846, 4.724404724407086, 4.789572005931219, 4.853864439804639, 4.917316341257699, 4.979959839195493, 5.041825066382213, 5.10294032886923, 5.163332257370234, 5.223025942880239, 5.282045058497702, 5.340411969127476, 5.3981478305063115, 5.455272678794342, 5.511805511808268, 5.5677643628300215, 5.62316636780382, 5.678027826631356, 5.732364259186606, 5.786190456595773, 5.839520528262573, 5.892367945062493, 5.944745579080739, 5.99666574022598, 6.048140210014975, 6.099180272790762, 6.149796744608719, 6.199999999999999, 6.249799996799897, 6.299206299209448, 6.348228099241551, 6.39687423668779, 6.445153217728807, 6.49307323229917, 6.540642170307133, 6.587867636800241, 6.6347569661593475, 6.681317235396026, 6.727555276621664, 6.773477688750439, 6.819090848492928, 6.864400920692206, 6.90941386804988, 6.954135460285484, 6.998571282769077, 7.042726744663604, 7.08660708661063, 7.130217387990355, 7.173562573784381, 7.216647421067486, 7.259476565152615, 7.302054505411474, 7.344385610791416, 7.386474125047755, 7.428324171709255, 7.469939758793239, 7.511324783285569, 7.552483035399683, 7.593418202627852, 7.634133873596926, 7.674633541739956, 7.714920608794364, 7.754998388136519, 7.79487010796203, 7.834538914320357, 7.874007874011811, 7.913279977354524], [0.0, 0.7937253933193772, 1.1224972160321824, 1.3747727084867523, 1.5874507866387544, 1.7748239349298849, 1.9442222095223582, 2.1, 2.244994432064365, 2.3811761799581315, 2.5099800796022267, 2.632489316217637, 2.7495454169735045, 2.861817604250837, 2.9698484809834995, 3.074085229787879, 3.1749015732775088, 3.2726136343907144, 3.3674916480965473, 3.4597687784012394, 3.5496478698597698, 3.6373066958946425, 3.722902093797257, 3.8065732621348563, 3.8884444190447165, 3.968626966596886, 4.047221268969613, 4.124318125460256, 4.2, 4.274342054632503, 4.347413023856832, 4.419275958796871, 4.48998886412873, 4.559605246071199, 4.628174586162454, 4.695742752749559, 4.762352359916263, 4.828043081829325, 4.892851929090027, 4.956813492557492, 5.019960159204453, 5.082322303829225, 5.143928459844674, 5.204805471869242, 5.264978632435274, 5.324471804789654, 5.383307533477908, 5.441507144165117, 5.499090833947009, 5.55607775323564, 5.612486080160912, 5.668333088307356, 5.723635208501674, 5.7784080852774675, 5.8326666285670745, 5.886425061104576, 5.939696961966999, 5.9924953066314535, 6.044832503882966, 6.096720429870472, 6.148170459575758, 6.199193495931548, 6.249799996799897, 6.3, 6.3498031465550175, 6.3992187023104625, 6.448255578061403, 6.496922348312315, 6.545227268781429, 6.593178292750774, 6.640783086353597, 6.688049042882386, 6.734983296193095, 6.7815927332743895, 6.827884006044625, 6.87386354243376, 6.919537556802479, 6.96491205974634, 7.009992867328754, 7.0547856097829085, 7.0992957397195395, 7.143528539874395, 7.187489130426565, 7.23118247591637, 7.274613391789285, 7.317786550590281, 7.3607064878311785, 7.40337760755184, 7.445804187594514, 7.487990384609211, 7.52994023880668, 7.571657678474378, 7.6131465242697125, 7.654410493303845, 7.695453203028396, 7.736278174936576, 7.776888838089433, 7.817288532477231, 7.857480512225277, 7.897467948652911, 7.937253933193772, 7.976841480185], [0.0, 0.8, 1.131370849898476, 1.385640646055102, 1.6, 1.788854381999832, 1.9595917942265426, 2.1166010488516727, 2.262741699796952, 2.4, 2.5298221281347035, 2.65329983228432, 2.771281292110204, 2.8844410203711917, 2.9933259094191533, 3.098386676965933, 3.2, 3.2984845004941286, 3.394112549695428, 3.4871191548325395, 3.577708763999664, 3.6660605559646724, 3.752332607858744, 3.836665218650176, 3.9191835884530852, 4.0, 4.079215610874228, 4.156921938165306, 4.233202097703345, 4.308131845707604, 4.381780460041329, 4.454211490264018, 4.525483399593904, 4.595650117230424, 4.664761515876241, 4.732863826479693, 4.8, 4.866210024238576, 4.931531202375181, 4.9959983987187195, 5.059644256269407, 5.122499389946279, 5.184592558726289, 5.2459508194416005, 5.30659966456864, 5.366563145999495, 5.4258639865002145, 5.4845236803208355, 5.542562584220408, 5.6000000000000005, 5.656854249492381, 5.713142742834281, 5.768882040742383, 5.8240879114244155, 5.878775382679628, 5.932958789676531, 5.986651818838307, 6.0398675482166, 6.092618484691127, 6.144916598294887, 6.196773353931866, 6.248199740725323, 6.299206299209448, 6.3498031465550175, 6.4, 6.449806198638839, 6.499230723708768, 6.5482822174979605, 6.596969000988257, 6.64529909033446, 6.6932802122726045, 6.740919818541087, 6.788225099390856, 6.835202996254025, 6.881860213634101, 6.92820323027551, 6.974238309665079, 7.019971509913698, 7.065408693062278, 7.110555533852471, 7.155417527999328, 7.2, 7.244308110509934, 7.288346863315439, 7.332121111929345, 7.37563556583431, 7.418894796396564, 7.4619032424710525, 7.504665215717488, 7.547184905645283, 7.58946638440411, 7.631513611335565, 7.673330437300352, 7.7149206087943645, 7.756287771866127, 7.797435475847171, 7.8383671769061705, 7.879086241436885, 7.919595949289333, 7.959899496852961, 8.0, 8.039900496896713], [0.0, 0.8062257748298549, 1.1401754250991378, 1.3964240043768943, 1.6124515496597098, 1.8027756377319946, 1.9748417658131499, 2.133072900770154, 2.2803508501982757, 2.4186773244895647, 2.5495097567963922, 2.6739483914241875, 2.7928480087537886, 2.9068883707497264, 3.016620625799671, 3.1224989991991987, 3.2249030993194197, 3.324154027718932, 3.420526275297414, 3.5142566781611158, 3.605551275463989, 3.6945906403822333, 3.7815340802378072, 3.866522985836241, 3.9496835316262997, 4.031128874149275, 4.110960958218893, 4.189272013130682, 4.266145801540308, 4.341658669218482, 4.415880433163923, 4.488875137492688, 4.560701700396551, 4.631414470763764, 4.701063709417263, 4.769696007084728, 4.8373546489791295, 4.904079934095691, 4.969909455915671, 5.034878350069642, 5.0990195135927845, 5.162363799656123, 5.224940191045253, 5.28677595515452, 5.347896782848375, 5.4083269131959835, 5.468089245796926, 5.527205442174191, 5.585696017507577, 5.643580423808984, 5.70087712549569, 5.757603668193913, 5.813776741499453, 5.869412236331676, 5.924525297439449, 5.979130371550699, 6.033241251599342, 6.08687111741328, 6.1400325732035, 6.192737682156413, 6.244997998398397, 6.296824596572465, 6.348228099241551, 6.3992187023104625, 6.449806198638839, 6.499999999999999, 6.549809157525125, 6.599242380758566, 6.648308055437864, 6.697014260101287, 6.745368781616021, 6.793379129711516, 6.841052550594828, 6.888396039717809, 6.93541635375988, 6.98212002188447, 7.0285133563222315, 7.074602462329597, 7.12039324756716, 7.165891430938652, 7.211102550927978, 7.256031973468694, 7.300684899377592, 7.345066371381541, 7.389181280764467, 7.433034373659253, 7.476630257007497, 7.519973404208288, 7.5630681604756145, 7.6059187479225665, 7.648529270389177, 7.6909037180295, 7.733045971672482, 7.774959806970066, 7.816648898345122, 7.858116822750854, 7.899367063252599, 7.940403012442127, 7.981227975693965, 8.021845174272563, 8.06225774829855, 8.10246875958186], [0.0, 0.812403840463596, 1.1489125293076057, 1.4071247279470291, 1.624807680927192, 1.8165902124584952, 1.98997487421324, 2.149418526020468, 2.2978250586152114, 2.437211521390788, 2.569046515733026, 2.6944387170614963, 2.8142494558940583, 2.9291637031753623, 3.0397368307141326, 3.1464265445104544, 3.249615361854384, 3.3496268448888453, 3.4467375879228173, 3.541186241925155, 3.6331804249169903, 3.722902093797257, 3.81051177665153, 3.8961519477556315, 3.97994974842648, 4.06201920231798, 4.142463035441596, 4.221374183841087, 4.298837052040936, 4.374928570845472, 4.449719092257397, 4.523273151159456, 4.595650117230423, 4.666904755831214, 4.737087712930805, 4.806245936279166, 4.874423042781576, 4.941659640242335, 5.007993610219566, 5.073460357586329, 5.138093031466052, 5.201922721455982, 5.264978632435274, 5.3272882407468805, 5.388877434122993, 5.449770637375485, 5.509990925582365, 5.569560126257728, 5.628498911788117, 5.686826883245172, 5.744562646538029, 5.801723881744115, 5.858327406350725, 5.914389233048499, 5.96992462263972, 6.024948132556827, 6.079473661428265, 6.133514490078261, 6.187083319303208, 6.240192304729077, 6.292853089020909, 6.345076831686122, 6.39687423668779, 6.448255578061403, 6.499230723708768, 6.549809157525125, 6.6, 6.649812027418519, 6.699253689777691, 6.748333127521196, 6.797058187186572, 6.8454364360499325, 6.8934751758456345, 6.941181455631311, 6.988562083862459, 7.035623639735144, 7.08237248385031, 7.128814768248646, 7.17495644586084, 7.2208032794142785, 7.266360849833981, 7.311634564172365, 7.356629663099809, 7.401351227985333, 7.445804187594514, 7.489993324429602, 7.533923280734945, 7.577598564189054, 7.62102355330306, 7.664202502543888, 7.707139547199077, 7.749838707999025, 7.792303895511263, 7.834538914320357, 7.8765474670060875, 7.918333157931661, 7.95989949685296, 8.001249902359007, 8.04238770515324, 8.083316151184489, 8.12403840463596, 8.16455755078008], [0.0, 0.8185352771872451, 1.1575836902790224, 1.4177446878757827, 1.6370705543744901, 1.8303005217723127, 2.004993765576342, 2.1656407827707715, 2.315167380558045, 2.455605831561735, 2.588435821108957, 2.714774392099646, 2.8354893757515653, 2.951270912674741, 3.062678566222711, 3.1701734968294715, 3.2741411087489802, 3.374907406137241, 3.4727510708370675, 3.567912554982255, 3.6606010435446255, 3.7509998667022106, 3.8392707640904935, 3.9255572852781047, 4.009987531152684, 4.092676385936225, 4.173727350941841, 4.253234063627348, 4.331281565541543, 4.407947368106838, 4.483302354291978, 4.557411546042337, 4.63033476111609, 4.702127178203499, 4.77283982551269, 4.8425200051213, 4.91121166312347, 4.978955713801841, 5.045790324617146, 5.111751167652823, 5.176871642217914, 5.241183072551464, 5.304714883949938, 5.367494760127856, 5.429548784199292, 5.490901565316937, 5.551576352712804, 5.61159513863928, 5.670978751503131, 5.729746940310715, 5.787918451395113, 5.845511098270194, 5.902541825349482, 5.959026766175833, 6.014981296729027, 6.070420084310475, 6.125357132445422, 6.17980582219215, 6.23377895020348, 6.287288763847259, 6.340346993658943, 6.392964883369843, 6.445153217728807, 6.496922348312315, 6.5482822174979605, 6.599242380758566, 6.649812027418519, 6.7, 6.749814812274482, 6.79926466612383, 6.848357467305573, 6.897100840208152, 6.945502141674135, 6.993568473962345, 7.041306696913577, 7.088723439378913, 7.13582510996451, 7.182617907142214, 7.229107828771128, 7.275300681071539, 7.321202087089251, 7.366817494685205, 7.4121521840825695, 7.457211275000863, 7.501999733404421, 7.546522377890362, 7.590783885739338, 7.634788798650556, 7.678541528180987, 7.722046360907191, 7.76530746332687, 7.808328886515987, 7.851114570556209, 7.893668348746355, 7.935993951610599, 7.978095010715276, 8.019975062305368, 8.061637550770936, 8.103085831953157, 8.144323176298936, 8.18535277187245, 8.226177727231525], [0.0, 0.8246211251235321, 1.16619037896906, 1.4282856857085702, 1.6492422502470643, 1.8439088914585775, 2.0199009876724157, 2.181742422927143, 2.33238075793812, 2.473863375370596, 2.6076809620810595, 2.734958866235469, 2.8565713714171403, 2.973213749463701, 3.0854497241083023, 3.1937438845342623, 3.2984845004941286, 3.4, 3.4985711369071804, 3.594440151122286, 3.687817782917155, 3.778888725538237, 3.867815921162743, 3.954743986657038, 4.039801975344831, 4.123105625617661, 4.204759208325728, 4.28485705712571, 4.363484845854286, 4.440720662234904, 4.516635916254486, 4.591296113299599, 4.66476151587624, 4.737087712930805, 4.8083261120685235, 4.878524367060187, 4.947726750741192, 5.015974481593781, 5.083306010855534, 5.149757275833494, 5.215361924162119, 5.280151512977635, 5.344155686354956, 5.407402333838309, 5.469917732470938, 5.531726674375732, 5.592852581643825, 5.653317610041028, 5.713142742834281, 5.772347875864725, 5.830951894845301, 5.888972745734184, 5.946427498927402, 6.003332407921454, 6.059702963017247, 6.115553940568263, 6.170899448216605, 6.2257529665093525, 6.280127387243033, 6.334035048845246, 6.387487769068525, 6.440496875241847, 6.49307323229917, 6.545227268781429, 6.596969000988257, 6.648308055437864, 6.699253689777691, 6.749814812274482, 6.8, 6.849817515817484, 6.899275324264137, 6.948381106416083, 6.997142273814361, 7.045565981523414, 7.093659140387279, 7.14142842854285, 7.188880302244572, 7.236021006050217, 7.282856582413251, 7.329392880723478, 7.37563556583431, 7.42159012611179, 7.467261881037788, 7.512655988397179, 7.557777451076474, 7.602631123499285, 7.647221717722065, 7.691553809211764, 7.735631842325486, 7.779460135510689, 7.8230428862431785, 7.866384175718855, 7.909487973314076, 7.952358140828418, 7.994998436522675, 8.037412518964047, 8.079603950689663, 8.121576201698781, 8.16333265278342, 8.204876598706406, 8.246211251235321, 8.287339742040265], [0.0, 0.8306623862918076, 1.174734012447073, 1.4387494569938162, 1.661324772583615, 1.8574175621006712, 2.0346989949375804, 2.1977260975835913, 2.349468024894146, 2.4919871588754225, 2.6267851073127395, 2.7549954627911823, 2.8774989139876324, 2.994995826374388, 3.1080540535840107, 3.217141588429082, 3.32264954516723, 3.424908757908742, 3.5242020373412193, 3.6207733980463352, 3.7148351242013424, 3.8065732621348563, 3.8961519477556315, 3.9837168574084183, 4.069397989875161, 4.153311931459037, 4.235563716909475, 4.316248370981448, 4.3954521951671826, 4.473253849269009, 4.54972526643093, 4.624932431938872, 4.698936049788292, 4.77179211617606, 4.843552415324934, 4.914264950122246, 4.983974317750845, 5.052722038663912, 5.120546845796843, 5.187484939737176, 5.253570214625479, 5.3188344587888805, 5.383307533477909, 5.447017532558529, 5.509990925582365, 5.572252686302012, 5.63382640840131, 5.69473440996154, 5.754997827975265, 5.814636704042653, 5.873670062235366, 5.932115979985557, 5.989991652748776, 6.047313453096343, 6.104096984812742, 6.1603571325045765, 6.216108107168021, 6.271363488110062, 6.326136261573885, 6.380438856379708, 6.434283176858164, 6.487680633323437, 6.540642170307133, 6.593178292750774, 6.64529909033446, 6.697014260101287, 6.748333127521196, 6.79926466612383, 6.849817515817484, 6.9, 6.949820141557622, 6.999285677838847, 7.048404074682439, 7.097182539571601, 7.145628033979938, 7.19374728496908, 7.2415467960926705, 7.289032857656769, 7.336211556382492, 7.383088784512889, 7.429670248402685, 7.475961476626268, 7.521967827636597, 7.567694497005016, 7.6131465242697125, 7.658328799418317, 7.703246069028303, 7.747902942086975, 7.792303895511263, 7.836453279386026, 7.880355321938218, 7.924014134263013, 7.967433714816837, 8.010617953691215, 8.053570636680355, 8.096295449154509, 8.138795979750322, 8.18107572388864, 8.223138087129511, 8.264986388373547, 8.306623862918075, 8.34805366537614], [0.0, 0.8366600265340756, 1.1832159566199232, 1.4491376746189442, 1.6733200530681511, 1.8708286933869709, 2.04939015319192, 2.2135943621178655, 2.3664319132398464, 2.5099800796022267, 2.6457513110645907, 2.774887385102322, 2.8982753492378883, 3.0166206257996717, 3.1304951684997055, 3.24037034920393, 3.3466401061363023, 3.4496376621320683, 3.5496478698597698, 3.6469165057620945, 3.7416573867739418, 3.834057902536163, 3.924283374069717, 4.012480529547776, 4.09878030638384, 4.183300132670378, 4.266145801540309, 4.3474130238568325, 4.427188724235731, 4.505552130427525, 4.58257569495584, 4.658325879540847, 4.732863826479693, 4.806245936279167, 4.878524367060187, 4.949747468305833, 5.019960159204453, 5.089204259999789, 5.157518783291051, 5.2249401910452535, 5.291502622129181, 5.35723809439155, 5.422176684690385, 5.486346689738081, 5.549774770204644, 5.612486080160912, 5.674504383644443, 5.735852159879995, 5.796550698475777, 5.856620185738529, 5.916079783099617, 5.974947698515863, 6.033241251599343, 6.090976933136425, 6.148170459575759, 6.2048368229954285, 6.260990336999411, 6.316644678941503, 6.3718129288295975, 6.4265076052238514, 6.48074069840786, 6.534523701081817, 6.587867636800241, 6.640783086353597, 6.6932802122726045, 6.745368781616021, 6.797058187186572, 6.848357467305573, 6.899275324264137, 6.949820141557622, 7.000000000000001, 7.049822692805827, 7.0992957397195395, 7.148426400264607, 7.197221686178633, 7.24568837309472, 7.293833011524189, 7.341661937191062, 7.3891812807644675, 7.436396977031284, 7.4833147735478835, 7.529940238806681, 7.576278769950325, 7.622335600063802, 7.668115805072326, 7.713624310270757, 7.75886589650833, 7.803845206050669, 7.848566748139434, 7.893034904268446, 7.937253933193772, 7.981227975693966, 8.024961059095553, 8.068457101577724, 8.1117199162693, 8.154753215150045, 8.19756061276768, 8.240145629781066, 8.282511696339462, 8.324662155306966, 8.366600265340756, 8.408329203831164], [0.0, 0.8426149773176359, 1.1916375287812984, 1.4594519519326425, 1.6852299546352718, 1.8841443681416774, 2.0639767440550294, 2.2293496809607953, 2.3832750575625967, 2.5278449319529073, 2.6645825188948455, 2.7946377224964243, 2.918903903865285, 3.0380915061926625, 3.152776554086889, 3.2634337744161437, 3.3704599092705436, 3.4741905532080417, 3.5749125863438955, 3.672873534441392, 3.768288736283355, 3.861346915261565, 3.952214569073901, 4.041039470235351, 4.127953488110059, 4.2130748865881795, 4.296510211788167, 4.378355855797928, 4.458699361921591, 4.537620521815371, 4.61519230368573, 4.69148164229596, 4.766550115125193, 4.8404545241123795, 4.913247398615299, 4.984977432245807, 5.0556898639058145, 5.1254268114957995, 5.194227565288221, 5.262128846769148, 5.329165037789691, 5.395368384086485, 5.46076917659042, 5.525395913416522, 5.589275444992849, 5.652433104425031, 5.71489282489182, 5.776677245614472, 5.83780780773057, 5.898304841223451, 5.958187643906493, 6.017474553332154, 6.076183012385325, 6.134329629226001, 6.191930232165088, 6.248999919987198, 6.305553108173778, 6.361603571427569, 6.417164482853779, 6.472248450113762, 6.526867548832287, 6.5810333535091585, 6.6347569661593475, 6.688049042882386, 6.740919818541087, 6.793379129711516, 6.8454364360499325, 6.897100840208152, 6.948381106416083, 6.999285677838847, 7.049822692805827, 7.1, 7.149825172687791, 7.199305522062527, 7.248448109768049, 7.297259759663212, 7.345747068882784, 7.3939164182454755, 7.441773982055624, 7.489325737341113, 7.53657747256671, 7.583534795858723, 7.630203142774117, 7.676587783644501, 7.72269383052313, 7.768526243760782, 7.814089838234521, 7.859389289251424, 7.904429138147802, 7.949213797602879, 7.993747556684537, 8.038034585643434, 8.082078940470701, 8.125884567233282, 8.16945530620004, 8.212794895770866, 8.255906976220118, 8.298795093265047, 8.341462701469089, 8.383913167489272, 8.426149773176359, 8.468175718535841], [0.0, 0.848528137423857, 1.2, 1.4696938456699071, 1.697056274847714, 1.8973665961010278, 2.078460969082653, 2.244994432064365, 2.4, 2.545584412271571, 2.6832815729997477, 2.814249455894058, 2.9393876913398143, 3.0594117081556713, 3.1749015732775088, 3.2863353450309964, 3.394112549695428, 3.4985711369071804, 3.6, 3.6986484017813863, 3.7947331922020555, 3.8884444190447165, 3.97994974842648, 4.069397989875161, 4.156921938165306, 4.242640687119286, 4.3266615305567875, 4.409081537009721, 4.48998886412873, 4.5694638635183455, 4.6475800154489, 4.724404724407087, 4.8, 4.874423042781577, 4.947726750741193, 5.019960159204453, 5.091168824543142, 5.1613951602255765, 5.230678732248808, 5.299056519796709, 5.366563145999495, 5.43323108288245, 5.499090833947008, 5.564171097297422, 5.628498911788116, 5.692099788303082, 5.754997827975264, 5.817215828899595, 5.8787753826796285, 5.939696961966999, 6.0, 6.059702963017248, 6.118823416311343, 6.177378084592201, 6.235382907247959, 6.29285308902091, 6.3498031465550175, 6.406246951218787, 6.462197768561405, 6.517668294720129, 6.572670690061993, 6.627216610312357, 6.681317235396026, 6.734983296193095, 6.788225099390856, 6.841052550594828, 6.8934751758456345, 6.945502141674135, 6.997142273814361, 7.048404074682439, 7.0992957397195395, 7.149825172687791, 7.2, 7.249827584156743, 7.299315036357863, 7.3484692283495345, 7.397296803562773, 7.445804187594514, 7.493997598078079, 7.541883053985921, 7.589466384404111, 7.636753236814713, 7.68374908491942, 7.730459236035075, 7.776888838089433, 7.823042886243179, 7.868926229162401, 7.914543574963752, 7.95989949685296, 8.0049984384758, 8.049844718999243, 8.094442537939225, 8.138795979750322, 8.182909018191515, 8.226785520481254, 8.270429251254132, 8.313843876330612, 8.357032966310472, 8.4, 8.442748367682174, 8.485281374238571, 8.527602242131138], [0.0, 0.8544003745317531, 1.2083045973594573, 1.4798648586948744, 1.7088007490635062, 1.91049731745428, 2.092844953645635, 2.260530911091463, 2.4166091947189146, 2.563201123595259, 2.701851217221259, 2.833725463060951, 2.9597297173897488, 3.0805843601498726, 3.196873472629156, 3.309078421554859, 3.4176014981270124, 3.522782990761707, 3.6249137920783716, 3.7242448899072147, 3.82099463490856, 3.915354390090379, 4.007492981902776, 4.097560249709576, 4.18568990729127, 4.272001872658766, 4.356604182158393, 4.439594576084623, 4.521061822182926, 4.601086828130937, 4.679743582719036, 4.757099956906519, 4.833218389437829, 4.908156476723211, 4.98196748283246, 5.054700782440045, 5.126402247190518, 5.197114584074513, 5.266877632905477, 5.335728628781641, 5.403702434442518, 5.470831746635972, 5.537147279962851, 5.602677931132575, 5.667450926121902, 5.731491952362839, 5.794825277780168, 5.857473858242988, 5.9194594347794975, 5.980802621722272, 6.041522986797286, 6.101639124038721, 6.161168720299745, 6.220128616033596, 6.278534860936905, 6.336402764976356, 6.393746945258312, 6.450581369148055, 6.5069193939989765, 6.562773803811921, 6.618156843109718, 6.673080248281149, 6.727555276621664, 6.7815927332743895, 6.835202996254025, 6.888396039717809, 6.941181455631311, 6.993568473962345, 7.045565981523414, 7.097182539571601, 7.148426400264607, 7.199305522062527, 7.249827584156743, 7.3, 7.349829930005183, 7.399324293474371, 7.448489779814429, 7.4973328590906245, 7.545859791965394, 7.594076639065476, 7.64198926981712, 7.689603370785778, 7.736924453553881, 7.783957862167549, 7.830708780180758, 7.877182237323192, 7.923383115816122, 7.969316156358713, 8.014985963805552, 8.060397012554654, 8.105553651663778, 8.150460109711599, 8.195120499419152, 8.239538822045807, 8.283718971573094, 8.327664738688751, 8.37137981458254, 8.414867794564572, 8.4581321815162, 8.501176389182852, 8.544003745317532, 8.586617494683225], [0.0, 0.8602325267042626, 1.2165525060596438, 1.489966442575134, 1.7204650534085253, 1.9235384061671346, 2.1071307505705477, 2.2759613353482084, 2.4331050121192876, 2.580697580112788, 2.7202941017470885, 2.8530685235374214, 2.979932885150268, 3.1016124838541645, 3.218695387886216, 3.3316662497915357, 3.4409301068170506, 3.5468295701936396, 3.6496575181789317, 3.749666651850535, 3.847076812334269, 3.9420806688854046, 4.034848200366403, 4.125530268947254, 4.214261501141095, 4.301162633521313, 4.386342439892262, 4.469899327725402, 4.551922670696417, 4.632493928760188, 4.711687595755898, 4.789572005931219, 4.866210024238575, 4.941659640242335, 5.015974481593781, 5.089204259999788, 5.161395160225576, 5.232590180780452, 5.302829433425141, 5.372150407425317, 5.440588203494177, 5.508175741568165, 5.574943945906542, 5.6409219104681805, 5.706137047074843, 5.770615218501403, 5.834380858325929, 5.897457079114692, 5.959865770300536, 6.021627686929839, 6.082762530298219, 6.143289021363068, 6.203224967708329, 6.262587324740471, 6.321392251711643, 6.3796551630946325, 6.437390775772432, 6.494613152451807, 6.55133574166368, 6.607571414672716, 6.663332499583071, 6.71863081289633, 6.773477688750439, 6.827884006044625, 6.881860213634101, 6.93541635375988, 6.988562083862459, 7.041306696913577, 7.093659140387279, 7.145628033979938, 7.197221686178633, 7.248448109768049, 7.299315036357863, 7.349829930005183, 7.3999999999999995, 7.44983221287567, 7.49933330370107, 7.548509786706248, 7.597367965289032, 7.645913941446111, 7.694153624668538, 7.742092740338364, 7.789736837660179, 7.837091297158659, 7.884161337770809, 7.930952023559341, 7.977468270071652, 8.023714850367003, 8.069696400732806, 8.115417426109392, 8.160882305241266, 8.206095295571457, 8.251060537894508, 8.295782060782456, 8.340263784797218, 8.384509526501832, 8.42852300228219, 8.472307831990054, 8.515867542417507, 8.559205570612264, 8.602325267042627, 8.645229898620395], [0.0, 0.8660254037844387, 1.224744871391589, 1.5000000000000002, 1.7320508075688774, 1.9364916731037085, 2.121320343559643, 2.29128784747792, 2.449489742783178, 2.598076211353316, 2.7386127875258306, 2.8722813232690148, 3.0000000000000004, 3.122498999199199, 3.24037034920393, 3.3541019662496843, 3.464101615137755, 3.570714214271425, 3.6742346141747673, 3.7749172176353754, 3.872983346207417, 3.968626966596886, 4.06201920231798, 4.153311931459037, 4.242640687119286, 4.330127018922194, 4.415880433163924, 4.5, 4.58257569495584, 4.663689526544408, 4.743416490252569, 4.8218253804964775, 4.898979485566356, 4.974937185533101, 5.049752469181039, 5.123475382979799, 5.196152422706632, 5.26782687642637, 5.338539126015656, 5.408326913195984, 5.477225575051661, 5.545268253204709, 5.612486080160912, 5.678908345800274, 5.7445626465380295, 5.809475019311125, 5.873670062235366, 5.937171043518958, 6.000000000000001, 6.06217782649107, 6.123724356957946, 6.184658438426491, 6.244997998398398, 6.304760106459247, 6.363961030678928, 6.422616289332565, 6.48074069840786, 6.5383484153110105, 6.59545297913646, 6.652067347825035, 6.7082039324993685, 6.7638746292343415, 6.819090848492928, 6.87386354243376, 6.92820323027551, 6.98212002188447, 7.035623639735144, 7.088723439378913, 7.14142842854285, 7.19374728496908, 7.24568837309472, 7.297259759663212, 7.3484692283495345, 7.399324293474371, 7.44983221287567, 7.5, 7.549834435270751, 7.599342076785332, 7.6485292703891785, 7.697402159170327, 7.745966692414834, 7.794228634059948, 7.842193570679062, 7.88986691902975, 7.937253933193772, 7.984359711335657, 8.031189202104505, 8.077747210701757, 8.12403840463596, 8.170067319184096, 8.215838362577491, 8.261355820929154, 8.306623862918075, 8.351646544245034, 8.396427811873334, 8.440971508067065, 8.485281374238571, 8.529361054615991, 8.573214099741124, 8.616843969807043, 8.660254037844387, 8.703447592764606], [0.0, 0.8717797887081349, 1.2328828005937953, 1.5099668870541503, 1.7435595774162698, 1.9493588689617931, 2.1354156504062627, 2.3065125189341593, 2.4657656011875906, 2.615339366124404, 2.7568097504180447, 2.8913664589601926, 3.0199337741083006, 3.1432467291003428, 3.2619012860600183, 3.3763886032268267, 3.4871191548325395, 3.594440151122286, 3.6986484017813863, 3.8000000000000007, 3.8987177379235862, 3.9949968710876362, 4.0890096600521755, 4.180908992073375, 4.270831300812525, 4.358898943540674, 4.445222154178575, 4.529900661162451, 4.613025037868319, 4.694677837722201, 4.774934554525329, 4.8538644398046396, 4.931531202375181, 5.007993610219566, 5.083306010855535, 5.157518783291051, 5.230678732248808, 5.302829433425142, 5.374011537017762, 5.444263035526481, 5.513619500836089, 5.582114294781146, 5.649778756730215, 5.716642371182581, 5.782732917920385, 5.848076606885378, 5.912698199637794, 5.976621118993575, 6.039867548216601, 6.102458520956944, 6.164414002968978, 6.225752966509353, 6.2864934582006855, 6.3466526610489735, 6.406246951218788, 6.465291950097846, 6.523802572120037, 6.581793068761734, 6.639277069079134, 6.696267617113283, 6.752777206453653, 6.808817812219681, 6.864400920692206, 6.919537556802479, 6.974238309665079, 7.0285133563222315, 7.08237248385031, 7.13582510996451, 7.188880302244572, 7.2415467960926705, 7.293833011524189, 7.345747068882784, 7.397296803562773, 7.448489779814429, 7.49933330370107, 7.549834435270751, 7.600000000000001, 7.649836599562112, 7.6993506219680645, 7.748548251124208, 7.7974354758471724, 7.8460180983732135, 7.894301742396222, 7.942291860665913, 7.9899937421752725, 8.037412518964048, 8.084553172563096, 8.13142054010245, 8.178019320104351, 8.224354077980836, 8.270429251254134, 8.316249154516717, 8.36181798414675, 8.407139822793482, 8.452218643646177, 8.497058314499201, 8.54166260162505, 8.586035173466273, 8.630179604156568, 8.674099376880578, 8.717797887081348, 8.761278445523805], [0.0, 0.8774964387392122, 1.2409673645990857, 1.5198684153570665, 1.7549928774784245, 1.9621416870348585, 2.149418526020468, 2.32163735324878, 2.4819347291981715, 2.6324893162176366, 2.7748873851023217, 2.91032644217105, 3.039736830714133, 3.1638584039112754, 3.283291031876401, 3.3985290935932855, 3.509985754956849, 3.6180105030251086, 3.722902093797257, 3.824918299781056, 3.924283374069717, 4.02119385257662, 4.115823125451336, 4.2083250825001635, 4.298837052040936, 4.387482193696061, 4.474371464239419, 4.559605246071199, 4.64327470649756, 4.725462940284264, 4.806245936279166, 4.8856934001224435, 4.963869458396343, 5.040833264451424, 5.1166395221864125, 5.191338940966964, 5.264978632435273, 5.3376024580330075, 5.409251334519409, 5.479963503528103, 5.549774770204643, 5.61871871515206, 5.686826883245173, 5.754128952326321, 5.8206528843421, 5.886425061104575, 5.951470406546605, 6.015812497078014, 6.079473661428266, 6.142475071174486, 6.2048368229954285, 6.266578013557321, 6.327716807822551, 6.388270501473776, 6.448255578061404, 6.507687761409578, 6.566582063752802, 6.624952830020755, 6.682813778641449, 6.740178039191546, 6.797058187186571, 6.853466276272176, 6.90941386804988, 6.96491205974634, 7.019971509913698, 7.074602462329597, 7.128814768248646, 7.182617907142214, 7.236021006050217, 7.289032857656769, 7.341661937191062, 7.3939164182454755, 7.445804187594514, 7.4973328590906245, 7.548509786706248, 7.599342076785332, 7.649836599562112, 7.7, 7.749838707999026, 7.799358948016177, 7.848566748139434, 7.897467948652911, 7.9460682101275735, 7.994373021069257, 8.04238770515324, 8.090117428072352, 8.137567204023572, 8.184741901856162, 8.231646250902672, 8.278284846512591, 8.324662155306966, 8.370782520170978, 8.416650165000327, 8.462269199216012, 8.507643622061282, 8.55277732669336, 8.597674104081872, 8.64233764672499, 8.6867715521936, 8.73097932651315, 8.774964387392123, 8.81873006730561], [0.0, 0.8831760866327848, 1.2489995996796797, 1.5297058540778359, 1.7663521732655696, 1.9748417658131503, 2.1633307652783937, 2.336664289109585, 2.4979991993593593, 2.6495282598983545, 2.7928480087537886, 2.9291637031753623, 3.0594117081556718, 3.1843366656181322, 3.3045423283716615, 3.420526275297414, 3.532704346531139, 3.6414282912066254, 3.7469987990390394, 3.8496753109840323, 3.9496835316263006, 4.047221268969613, 4.1424630354415966, 4.235563716909475, 4.3266615305567875, 4.415880433163924, 4.503332099679082, 4.589117562233508, 4.67332857821917, 4.756048780237647, 4.83735464897913, 4.917316341257699, 4.995998398718719, 5.07346035758633, 5.149757275833494, 5.2249401910452535, 5.299056519796709, 5.372150407425318, 5.444263035526481, 5.515432893255072, 5.585696017507577, 5.655086206239478, 5.723635208501675, 5.791372894228104, 5.858327406350725, 5.92452529743945, 5.989991652748776, 6.054750201288242, 6.1188234163113435, 6.182232606429493, 6.244997998398399, 6.307138812488593, 6.3686733312362644, 6.429618962271405, 6.489992295835182, 6.549809157525127, 6.609084656743323, 6.667833231267862, 6.726068688320096, 6.783804242458652, 6.841052550594828, 6.897825744392215, 6.954135460285484, 7.009992867328754, 7.065408693062278, 7.12039324756716, 7.17495644586084, 7.229107828771128, 7.282856582413251, 7.336211556382492, 7.3891812807644675, 7.441773982055624, 7.493997598078079, 7.545859791965394, 7.597367965289032, 7.6485292703891785, 7.6993506219680645, 7.749838707999026, 7.800000000000002, 7.849840762716147, 7.899367063252601, 7.9485847796950635, 7.997499609252884, 8.046117075956577, 8.094442537939226, 8.142481194328914, 8.19023809177731, 8.23771813064759, 8.284926070883193, 8.33186653757728, 8.378544026261366, 8.424962907930219, 8.47112743381895, 8.517041739947036, 8.56270985144306, 8.608135686662937, 8.653323061113575, 8.698275691193055, 8.742997197757758, 8.787491109526087, 8.831760866327848, 8.875809822207776], [0.0, 0.8888194417315589, 1.2569805089976536, 1.5394804318340656, 1.7776388834631178, 1.9874606914351793, 2.177154105707724, 2.3515952032609695, 2.513961017995307, 2.6664583251946765, 2.8106938645110393, 2.9478805945967355, 3.078960863668131, 3.204684071792413, 3.3256578296631782, 3.442382895611701, 3.5552777669262356, 3.664696440361739, 3.7709415269929605, 3.874274125562104, 3.9749213828703587, 4.07308237088326, 4.168932717135166, 4.262628297189424, 4.354308211415448, 4.444097208657795, 4.532107677449864, 4.618441295502196, 4.703190406521939, 4.786439177509728, 4.868264577855234, 4.948737212663449, 5.027922035990614, 5.105878964487898, 5.182663407939976, 5.2583267300539625, 5.332916650389353, 5.406477596365309, 5.47905101272109, 5.550675634551168, 5.621387729022079, 5.691221310052879, 5.760208329565868, 5.8283788483591215, 5.895761189193471, 5.962382074305537, 6.028266749240615, 6.09343909463285, 6.157921727336262, 6.221736092120913, 6.284902544988268, 6.347440429023341, 6.409368143584826, 6.470703207534712, 6.5314623171231725, 6.591661399070799, 6.6513156593263565, 6.710439627923047, 6.76904720030818, 6.827151675479314, 6.884765791223402, 6.941901756723442, 6.998571282769077, 7.0547856097829085, 7.110555533852471, 7.165891430938652, 7.2208032794142785, 7.275300681071539, 7.329392880723478, 7.383088784512889, 7.436396977031284, 7.489325737341113, 7.541883053985921, 7.594076639065476, 7.645913941446111, 7.697402159170327, 7.748548251124208, 7.799358948016177, 7.849840762716147, 7.9, 7.949842765740717, 7.999374975584031, 8.048602363143555, 8.097530487747484, 8.14616474176652, 8.194510357550353, 8.242572413997951, 8.290355842785038, 8.337865434270332, 8.385105843100611, 8.432081593533118, 8.478797084492587, 8.525256594378847, 8.571464285639882, 8.61742420912421, 8.663140308225419, 8.708616422830897, 8.753856293085923, 8.798863562983575, 8.843641783790206, 8.88819441731559, 8.932524839036274], [0.0, 0.894427190999916, 1.2649110640673518, 1.549193338482967, 1.788854381999832, 2.0000000000000004, 2.1908902300206647, 2.366431913239847, 2.5298221281347035, 2.6832815729997477, 2.8284271247461903, 2.9664793948382657, 3.098386676965934, 3.22490309931942, 3.3466401061363023, 3.4641016151377544, 3.577708763999664, 3.687817782917155, 3.7947331922020555, 3.8987177379235862, 4.000000000000001, 4.09878030638384, 4.1952353926806065, 4.289522117905444, 4.3817804600413295, 4.47213595499958, 4.560701700396552, 4.647580015448901, 4.732863826479694, 4.8166378315169185, 4.898979485566357, 4.979959839195494, 5.059644256269407, 5.1380930314660525, 5.21536192416212, 5.291502622129181, 5.366563145999495, 5.440588203494178, 5.513619500836089, 5.585696017507577, 5.656854249492381, 5.727128425310542, 5.796550698475777, 5.865151319446072, 5.9329587896765315, 6.0, 6.066300355241241, 6.131883886702357, 6.196773353931868, 6.260990336999412, 6.324555320336759, 6.387487769068526, 6.44980619863884, 6.511528238439884, 6.572670690061994, 6.6332495807108005, 6.6932802122726045, 6.752777206453653, 6.811754546370562, 6.870225614927067, 6.928203230275509, 6.985699678629192, 7.042726744663604, 7.0992957397195395, 7.155417527999328, 7.211102550927978, 7.266360849833981, 7.321202087089251, 7.37563556583431, 7.429670248402685, 7.4833147735478835, 7.53657747256671, 7.589466384404111, 7.64198926981712, 7.694153624668538, 7.745966692414834, 7.7974354758471724, 7.848566748139434, 7.899367063252601, 7.949842765740717, 8.000000000000002, 8.049844718999244, 8.099382692526635, 8.148619514985345, 8.19756061276768, 8.246211251235321, 8.29457654133109, 8.342661445845685, 8.390470785361213, 8.438009243891594, 8.485281374238571, 8.532291603080617, 8.579044235810889, 8.62554346113913, 8.671793355471522, 8.717797887081348, 8.763560920082659, 8.809086218218098, 8.854377448471462, 8.899438184514796, 8.94427190999916, 8.988882021697695], [0.0, 0.9, 1.2727922061357855, 1.5588457268119897, 1.8, 2.012461179749811, 2.2045407685048604, 2.3811761799581315, 2.545584412271571, 2.7, 2.8460498941515415, 2.9849623113198605, 3.1176914536239795, 3.2449961479175906, 3.3674916480965473, 3.485685011586675, 3.6, 3.710795063055895, 3.8183766184073566, 3.9230090491866068, 4.024922359499622, 4.124318125460256, 4.221374183841087, 4.316248370981448, 4.409081537009721, 4.500000000000001, 4.589117562233507, 4.676537180435969, 4.762352359916263, 4.846648326421054, 4.929503017546495, 5.01098792654702, 5.091168824543142, 5.170106381884226, 5.247856705360771, 5.324471804789654, 5.4, 5.474486277268398, 5.547972602672079, 5.620498198558559, 5.692099788303083, 5.762811813689565, 5.832666628567075, 5.9016946718718, 5.969924622639721, 6.037383539249432, 6.104096984812742, 6.17008914036094, 6.235382907247959, 6.300000000000001, 6.3639610306789285, 6.427285585688566, 6.489992295835181, 6.552098900352467, 6.613622305514581, 6.674578638386097, 6.734983296193095, 6.794850991743675, 6.854195795277518, 6.913031173081747, 6.97137002317335, 7.029224708315989, 7.08660708661063, 7.143528539874395, 7.2, 7.256031973468694, 7.311634564172365, 7.366817494685205, 7.42159012611179, 7.475961476626268, 7.529940238806681, 7.583534795858723, 7.636753236814713, 7.689603370785778, 7.742092740338364, 7.794228634059948, 7.8460180983732135, 7.897467948652911, 7.9485847796950635, 7.999374975584031, 8.049844718999244, 8.100000000000001, 8.149846624323676, 8.19939022122987, 8.248636250920512, 8.2975900115636, 8.346256645946134, 8.394641147779934, 8.442748367682174, 8.490583018850943, 8.538149682454625, 8.58545281275251, 8.632496741962896, 8.67928568489366, 8.725823743349393, 8.772114910328067, 8.818163074019441, 8.863972021616496, 8.909545442950499, 8.95488693395958, 9.000000000000002, 9.044888059008803], [0.0, 0.9055385138137417, 1.2806248474865698, 1.5684387141358125, 1.8110770276274835, 2.024845673131659, 2.2181073012818837, 2.395829710142188, 2.5612496949731396, 2.716615541441225, 2.863564212655271, 3.003331483536242, 3.136877428271625, 3.264965543462902, 3.3882148692194836, 3.5071355833500366, 3.622154055254967, 3.733630940518894, 3.84187454245971, 3.947150871198111, 4.049691346263318, 4.149698784249287, 4.247352116319061, 4.342810150121694, 4.436214602563767, 4.527692569068709, 4.617358552246079, 4.705316142407438, 4.791659420284376, 4.876474136094644, 4.959838707054898, 5.041825066382213, 5.122499389946279, 5.201922721455982, 5.280151512977635, 5.35723809439155, 5.43323108288245, 5.508175741568166, 5.582114294781146, 5.655086206239478, 5.727128425310542, 5.798275605729691, 5.868560300448485, 5.938013135721409, 6.006662967072484, 6.074537019394977, 6.1416610131136355, 6.208059278067503, 6.27375485654325, 6.338769596696192, 6.403124237432849, 6.466838485689898, 6.529931086925804, 6.592419889539805, 6.654321903845651, 6.715653356152327, 6.776429738438967, 6.836665854054885, 6.8963758598266685, 6.955573304911681, 7.014271166700073, 7.07248188403477, 7.130217387990355, 7.187489130426565, 7.244308110509934, 7.300684899377592, 7.356629663099809, 7.4121521840825695, 7.467261881037788, 7.521967827636597, 7.576278769950325, 7.630203142774117, 7.68374908491942, 7.736924453553881, 7.789736837660179, 7.842193570679062, 7.894301742396222, 7.9460682101275735, 7.997499609252884, 8.048602363143555, 8.099382692526635, 8.149846624323676, 8.200000000000001, 8.249848483457136, 8.299397568498573, 8.348652585896723, 8.397618710086808, 8.446300965511472, 8.494704232638123, 8.542833253669418, 8.590692637965812, 8.638286867197687, 8.685620300243388, 8.732697177848321, 8.77952162705919, 8.826097665446492, 8.872429205127535, 8.918520056601322, 8.964373932405989, 9.009994450608726, 9.055385138137417, 9.100549433962767], [0.0, 0.9110433579144299, 1.2884098726725124, 1.5779733838059502, 1.8220867158288598, 2.0371548787463363, 2.2315913604421396, 2.41039415863879, 2.576819745345025, 2.7331300737432893, 2.8809720581775866, 3.0215889859476257, 3.1559467676119004, 3.2848135411313684, 3.408812109811862, 3.5284557528754696, 3.6441734316577197, 3.7563279941985894, 3.8652296180175374, 3.9711459303329564, 4.0743097574926725, 4.174925149029621, 4.273172123844299, 4.369210454990696, 4.463182720884279, 4.55521678957215, 4.645427859734774, 4.73392015141785, 4.82078831727758, 4.906118628814432, 4.9899899799498595, 5.072474741188959, 5.15363949069005, 5.23354564325181, 5.31224999411737, 5.389805191284746, 5.466260147486579, 5.541660400998964, 5.616048432839589, 5.68946394662977, 5.761944116355173, 5.833523806414096, 5.904235767650205, 5.974110812497538, 6.043177971895251, 6.111464636239008, 6.178996682310163, 6.245798587850876, 6.311893535223801, 6.377303505401009, 6.442049363362563, 6.506150935845249, 6.569627082262737, 6.632495759516172, 6.694774081326419, 6.756478372643548, 6.817624219623724, 6.878226515607057, 6.938299503480662, 6.997856814768361, 7.056911505750939, 7.115476090888086, 7.173562573784381, 7.23118247591637, 7.288346863315439, 7.345066371381541, 7.401351227985333, 7.457211275000863, 7.512655988397179, 7.567694497005016, 7.622335600063802, 7.676587783644501, 7.730459236035075, 7.783957862167549, 7.837091297158659, 7.88986691902975, 7.942291860665913, 7.994373021069257, 8.046117075956577, 8.097530487747484, 8.148619514985345, 8.19939022122987, 8.249848483457136, 8.299999999999999, 8.349850298059241, 8.399404740813482, 8.44866853415377, 8.49764673306675, 8.546344247688598, 8.594765849050223, 8.64291617453276, 8.690799733051039, 8.738420909981391, 8.78578397184907, 8.832893070789435, 8.879752248796134, 8.926365441768558, 8.972736483370054, 9.018869108707587, 9.064766957842878, 9.1104335791443, 9.155872432488342], [0.0, 0.9165151389911681, 1.2961481396815722, 1.5874507866387546, 1.8330302779823362, 2.04939015319192, 2.244994432064365, 2.4248711305964283, 2.5922962793631443, 2.749545416973504, 2.898275349237888, 3.039736830714133, 3.174901573277509, 3.3045423283716615, 3.4292856398964493, 3.5496478698597693, 3.6660605559646724, 3.778888725538237, 3.8884444190447165, 3.9949968710876362, 4.09878030638384, 4.2, 4.298837052040936, 4.3954521951671826, 4.48998886412873, 4.582575694955841, 4.67332857821917, 4.762352359916264, 4.849742261192857, 4.935585071701227, 5.019960159204453, 5.10294032886923, 5.184592558726289, 5.264978632435274, 5.344155686354956, 5.422176684690384, 5.499090833947008, 5.574943945906542, 5.649778756730214, 5.723635208501674, 5.796550698475776, 5.868560300448484, 5.939696961967, 6.009991680526688, 6.079473661428266, 6.148170459575759, 6.216108107168022, 6.2833112289620034, 6.349803146555018, 6.4156059729381765, 6.480740698407861, 6.54522726878143, 6.609084656743323, 6.672330927044912, 6.7349832961930955, 6.797058187186572, 6.858571279792899, 6.919537556802478, 6.97997134664606, 7.0398863627192165, 7.099295739719539, 7.158212067269313, 7.216647421067486, 7.274613391789285, 7.332121111929345, 7.389181280764467, 7.445804187594514, 7.501999733404421, 7.557777451076474, 7.6131465242697125, 7.668115805072326, 7.72269383052313, 7.776888838089433, 7.830708780180758, 7.884161337770809, 7.937253933193772, 7.9899937421752725, 8.04238770515324, 8.094442537939226, 8.14616474176652, 8.19756061276768, 8.248636250920512, 8.299397568498573, 8.349850298059241, 8.4, 8.449852069711044, 8.499411744350311, 8.548684109265006, 8.597674104081872, 8.646386528486914, 8.694826047713663, 8.742997197757758, 8.790904390334365, 8.838551917593742, 8.885943956609225, 8.933084573650918, 8.97997772825746, 9.026627277117408, 9.073036977771006, 9.119210492142399, 9.165151389911681, 9.210863151735564], [0.0, 0.9219544457292888, 1.3038404810405297, 1.5968719422671316, 1.8439088914585775, 2.0615528128088303, 2.2583179581272432, 2.4392621835300936, 2.6076809620810595, 2.765863337187866, 2.9154759474226504, 3.0577769702841313, 3.193743884534263, 3.3241540277189325, 3.449637662132068, 3.5707142142714248, 3.687817782917155, 3.8013155617496426, 3.9115214431215897, 4.018706259482024, 4.123105625617661, 4.224926034855522, 4.324349662087931, 4.421538193886829, 4.5166359162544865, 4.609772228646444, 4.701063709417264, 4.790615826801394, 4.878524367060187, 4.964876634922565, 5.049752469181039, 5.13322510708424, 5.215361924162119, 5.296225070746145, 5.375872022286245, 5.454356057317858, 5.531726674375732, 5.608029957123981, 5.68330889535313, 5.757603668193913, 5.830951894845301, 5.903388857258177, 5.974947698515863, 6.0456596000767355, 6.115553940568263, 6.18465843842649, 6.252999280345393, 6.320601237224193, 6.387487769068526, 6.4536811201050215, 6.519202405202649, 6.584071688552609, 6.648308055437865, 6.711929677819935, 6.77495387438173, 6.837397165588672, 6.899275324264136, 6.960603422117942, 7.021395872616784, 7.0816664705420855, 7.1414284285428495, 7.200694410957877, 7.259476565152615, 7.317786550590281, 7.37563556583431, 7.433034373659253, 7.489993324429602, 7.546522377890362, 7.602631123499285, 7.658328799418317, 7.713624310270757, 7.768526243760782, 7.823042886243179, 7.877182237323192, 7.930952023559341, 7.984359711335657, 8.037412518964048, 8.090117428072352, 8.142481194328914, 8.194510357550353, 8.246211251235321, 8.2975900115636, 8.348652585896723, 8.399404740813482, 8.449852069711044, 8.5, 8.549853799919623, 8.599418584997478, 8.648699324175862, 8.697700845625814, 8.746427842267952, 8.794884877018005, 8.843076387773658, 8.891006692158093, 8.938679992034618, 8.986100377805714, 9.033271832508973, 9.080198235721511, 9.126883367283709, 9.173330910852394, 9.219544457292889, 9.265527507918803], [0.0, 0.9273618495495705, 1.3114877048604001, 1.6062378404209012, 1.854723699099141, 2.0736441353327724, 2.2715633383201097, 2.4535688292770597, 2.6229754097208002, 2.7820855486487113, 2.932575659723036, 3.07571129984594, 3.2124756808418025, 3.343650699460098, 3.4698703145794947, 3.591656999213594, 3.709447398198282, 3.8236108588610325, 3.9344631145812006, 4.042276586281548, 4.147288270665545, 4.249705872175156, 4.349712634186309, 4.447471191587417, 4.543126676640219, 4.636809247747852, 4.7286361670147565, 4.818713521262704, 4.907137658554119, 4.993996395673509, 5.079370039680118, 5.163332257370235, 5.2459508194416005, 5.327288240746882, 5.40740233383831, 5.486346689738081, 5.5641710972974225, 5.640921910468182, 5.716642371182581, 5.791372894228104, 5.865151319446072, 5.93801313572141, 6.009991680526689, 6.081118318204308, 6.15142259969188, 6.220932405998316, 6.289674077406556, 6.357672530100934, 6.424951361683605, 6.491532946846993, 6.557438524302001, 6.62268827591938, 6.687301398920196, 6.751296171847301, 6.814690014960329, 6.87749954561976, 6.939740629158989, 7.001428425685718, 7.062577433203831, 7.123201527403251, 7.183313998427188, 7.242927584892728, 7.302054505411474, 7.3607064878311785, 7.418894796396564, 7.476630257007497, 7.533923280734945, 7.590783885739338, 7.647221717722065, 7.703246069028303, 7.75886589650833, 7.814089838234521, 7.868926229162401, 7.923383115816122, 7.977468270071652, 8.031189202104505, 8.084553172563096, 8.137567204023572, 8.19023809177731, 8.242572413997951, 8.29457654133109, 8.346256645946134, 8.397618710086808, 8.44866853415377, 8.499411744350311, 8.549853799919623, 8.600000000000001, 8.649855490122365, 8.699425268372618, 8.748714191239761, 8.79772697916911, 8.84646822183859, 8.894942383174834, 8.943153806124549, 8.99110671719561, 9.038805230781334, 9.086253353280439, 9.133454987024352, 9.180413934022802, 9.22713389953782, 9.273618495495704, 9.319871243745807], [0.0, 0.9327379053088816, 1.3190905958272918, 1.6155494421403516, 1.8654758106177631, 2.0856653614614213, 2.2847319317591728, 2.4677925358506134, 2.6381811916545836, 2.7982137159266447, 2.9495762407505253, 3.093541659651604, 3.231098884280703, 3.363034344160048, 3.4899856733230297, 3.6124783736376886, 3.7309516212355263, 3.845776904605882, 3.957271787481876, 4.065710270051225, 4.171330722922843, 4.274342054632503, 4.374928570845472, 4.473253849269009, 4.5694638635183455, 4.663689526544408, 4.756048780237647, 4.846648326421054, 4.935585071701227, 5.022947341949744, 5.10881590977792, 5.193264869039514, 5.276362383309167, 5.358171329847526, 5.4387498563548595, 5.518151864528558, 5.596427431853289, 5.673623181001714, 5.749782604586021, 5.8249463516842805, 5.8991524815010505, 5.9724366886556455, 6.044832503882966, 6.1163714733492105, 6.187083319303208, 6.256996084384263, 6.326136261573884, 6.394528911499267, 6.462197768561406, 6.529165337162171, 6.59545297913646, 6.661080993352356, 6.726068688320096, 6.790434448545985, 6.854195795277518, 6.917369442208505, 6.979971346646059, 7.042016756583302, 7.103520254071217, 7.164495795239188, 7.224956747275377, 7.284915922644544, 7.344385610791416, 7.40337760755184, 7.4619032424710525, 7.519973404208288, 7.577598564189054, 7.634788798650556, 7.691553809211764, 7.747902942086975, 7.803845206050669, 7.859389289251424, 7.914543574963752, 7.969316156358713, 8.023714850367003, 8.077747210701757, 8.13142054010245, 8.184741901856162, 8.23771813064759, 8.290355842785038, 8.342661445845685, 8.394641147779934, 8.446300965511472, 8.49764673306675, 8.548684109265006, 8.599418584997478, 8.649855490122365, 8.700000000000001, 8.749857141690944, 8.799431799837988, 8.848728722251575, 8.897752525216692, 8.946507698538017, 8.994998610338971, 9.043229511629129, 9.091204540653564, 9.138927727036691, 9.186402995732335, 9.233634170791044, 9.280624978954814, 9.327379053088816, 9.373899935459095], [0.0, 0.938083151964686, 1.3266499161421599, 1.6248076809271923, 1.876166303929372, 2.0976176963403033, 2.297825058615212, 2.4819347291981715, 2.6532998322843198, 2.814249455894058, 2.9664793948382653, 3.1112698372208096, 3.2496153618543846, 3.3823069050575527, 3.509985754956849, 3.63318042491699, 3.752332607858744, 3.867815921162743, 3.97994974842648, 4.0890096600521755, 4.1952353926806065, 4.298837052040936, 4.4, 4.498888751680798, 4.595650117230424, 4.69041575982343, 4.7833042972405595, 4.874423042781577, 4.963869458396343, 5.0517323761260355, 5.138093031466052, 5.223025942880239, 5.3065996645686395, 5.388877434122993, 5.469917732470938, 5.549774770204643, 5.628498911788116, 5.706137047074843, 5.782732917920384, 5.858327406350725, 5.932958789676531, 6.006662967072483, 6.079473661428266, 6.151422599691879, 6.222539674441619, 6.292853089020909, 6.362389488234747, 6.431174076325411, 6.499230723708769, 6.566582063752802, 6.6332495807108005, 6.6992536897776915, 6.764613810115105, 6.82934843158555, 6.8934751758456345, 6.957010852370435, 7.019971509913698, 7.0823724838503095, 7.144228439796701, 7.205553413860728, 7.26636084983398, 7.326663633605681, 7.386474125047755, 7.445804187594514, 7.504665215717488, 7.5630681604756145, 7.62102355330306, 7.678541528180987, 7.735631842325486, 7.792303895511263, 7.848566748139434, 7.904429138147802, 7.95989949685296, 8.014985963805552, 8.069696400732806, 8.12403840463596, 8.178019320104351, 8.231646250902672, 8.284926070883193, 8.337865434270332, 8.390470785361213, 8.442748367682174, 8.494704232638123, 8.546344247688598, 8.597674104081872, 8.648699324175862, 8.699425268372618, 8.749857141690944, 8.8, 8.849858755935035, 8.899438184514796, 8.948742928478838, 8.997777503361595, 9.046546302318914, 9.09505360072166, 9.143303560529969, 9.191300234460847, 9.23904756996088, 9.28654941299512, 9.333809511662428, 9.38083151964686, 9.427618999514142], [0.0, 0.9433981132056604, 1.3341664064126333, 1.6340134638368193, 1.8867962264113207, 2.1095023109728985, 2.3108440016582685, 2.495996794869737, 2.6683328128252666, 2.830194339616981, 2.9832867780352594, 3.1288975694324033, 3.2680269276736387, 3.4014702703389896, 3.529872518944558, 3.6537651812890215, 3.7735924528226414, 3.8897300677553446, 4.0024992192379, 4.112177038990418, 4.219004621945797, 4.323193264243457, 4.424929377967517, 4.524378410345448, 4.621688003316537, 4.716990566028302, 4.810405388322278, 4.902040391510457, 4.991993589739474, 5.0803543183522155, 5.167204273105525, 5.252618394667558, 5.336665625650533, 5.419409561935692, 5.500909015790026, 5.58121850495033, 5.660388679233962, 5.7384666941614295, 5.815496539419485, 5.8915193286621745, 5.966573556070519, 6.040695324215583, 6.113918547053109, 6.186275131288617, 6.2577951388648065, 6.328506932918695, 6.398437309218556, 6.4676116148080505, 6.536053855347277, 6.603786792439623, 6.670832032063167, 6.73721010508059, 6.802940540677979, 6.868041933477111, 6.932532004974806, 6.996427659884722, 7.059745037889116, 7.122499561249548, 7.184705978674423, 7.246378405796926, 7.307530362578043, 7.368174807915458, 7.428324171709255, 7.487990384609211, 7.547184905645283, 7.6059187479225665, 7.664202502543888, 7.722046360907191, 7.779460135510689, 7.836453279386026, 7.893034904268446, 7.949213797602879, 8.0049984384758, 8.060397012554654, 8.115417426109392, 8.170067319184096, 8.224354077980836, 8.278284846512591, 8.33186653757728, 8.385105843100611, 8.438009243891594, 8.490583018850943, 8.542833253669418, 8.594765849050223, 8.646386528486914, 8.697700845625814, 8.748714191239761, 8.799431799837988, 8.849858755935035, 8.899999999999999, 8.949860334105779, 8.99944442729661, 9.048756820690896, 9.097801932335084, 9.1465840618233, 9.195107394696377, 9.243376006633074, 9.291393867445294, 9.339164844888433, 9.38669270829721, 9.433981132056603, 9.481033698917013], [0.0, 0.9486832980505138, 1.3416407864998738, 1.6431676725154984, 1.8973665961010275, 2.121320343559643, 2.32379000772445, 2.5099800796022267, 2.6832815729997477, 2.846049894151541, 3.0, 3.146426544510455, 3.286335345030997, 3.420526275297414, 3.5496478698597693, 3.674234614174767, 3.794733192202055, 3.9115214431215892, 4.024922359499621, 4.135214625627067, 4.242640687119286, 4.347413023856832, 4.449719092257398, 4.549725266430931, 4.6475800154489, 4.743416490252569, 4.83735464897913, 4.929503017546495, 5.019960159204453, 5.10881590977792, 5.196152422706632, 5.282045058497703, 5.366563145999495, 5.449770637375486, 5.531726674375733, 5.612486080160912, 5.692099788303082, 5.770615218501404, 5.848076606885378, 5.92452529743945, 6.0, 6.074537019394977, 6.148170459575759, 6.220932405998315, 6.29285308902091, 6.363961030678928, 6.434283176858165, 6.5038450166036395, 6.572670690061994, 6.640783086353597, 6.708203932499369, 6.77495387438173, 6.841052550594828, 6.906518659932804, 6.971370023173351, 7.035623639735144, 7.099295739719539, 7.162401831787993, 7.224956747275378, 7.286974680894671, 7.348469228349534, 7.409453421137082, 7.469939758793239, 7.52994023880668, 7.58946638440411, 7.648529270389177, 7.707139547199077, 7.76530746332687, 7.8230428862431785, 7.880355321938218, 7.937253933193772, 7.993747556684537, 8.049844718999243, 8.105553651663778, 8.160882305241266, 8.215838362577491, 8.270429251254134, 8.324662155306966, 8.378544026261366, 8.432081593533118, 8.485281374238571, 8.538149682454625, 8.590692637965812, 8.64291617453276, 8.694826047713663, 8.746427842267952, 8.79772697916911, 8.848728722251575, 8.899438184514796, 8.949860334105779, 9.0, 9.049861877399014, 9.099450532861862, 9.148770409186145, 9.197825830053535, 9.246621004453464, 9.2951600308978, 9.343446901438464, 9.391485505499116, 9.439279633531365, 9.486832980505138, 9.534149149242424], [0.0, 0.9539392014169457, 1.349073756323204, 1.6522711641858308, 1.9078784028338913, 2.1330729007701543, 2.3366642891095846, 2.5238858928247927, 2.698147512646408, 2.8618176042508368, 3.0166206257996713, 3.1638584039112754, 3.3045423283716615, 3.439476704383968, 3.5693136595149495, 3.694590640382233, 3.8157568056677826, 3.9331920878594273, 4.047221268969612, 4.158124577258358, 4.266145801540309, 4.371498598878879, 4.474371464239419, 4.57493169347915, 4.673328578219169, 4.769696007084729, 4.864154602806124, 4.956813492557492, 5.047771785649585, 5.137119815616529, 5.224940191045253, 5.3113086899558, 5.396295025292816, 5.479963503528103, 5.562373594069352, 5.643580423808984, 5.7236352085016735, 5.8025856305616035, 5.880476171195663, 5.957348403442593, 6.0332412515993425, 6.1081912216301815, 6.182232606429493, 6.255397669213365, 6.327716807822551, 6.399218702310462, 6.469930447848725, 6.539877674696982, 6.609084656743323, 6.67757440991862, 6.745368781616021, 6.81248853210044, 6.878953408767936, 6.944782214007867, 7.009992867328754, 7.074602462329597, 7.138627319029899, 7.202083032012336, 7.264984514780469, 7.327346040688948, 7.389181280764466, 7.450503338701353, 7.511324783285569, 7.571657678474378, 7.631513611335565, 7.6909037180295, 7.749838707999025, 7.808328886515987, 7.866384175718855, 7.924014134263013, 7.981227975693966, 8.038034585643434, 8.094442537939225, 8.150460109711599, 8.206095295571457, 8.261355820929154, 8.316249154516717, 8.370782520170978, 8.424962907930219, 8.478797084492587, 8.532291603080617, 8.58545281275251, 8.638286867197687, 8.690799733051039, 8.742997197757758, 8.794884877018005, 8.84646822183859, 8.897752525216692, 8.948742928478838, 8.99944442729661, 9.049861877399014, 9.1, 9.1498633869583, 9.199456505685541, 9.248783703817493, 9.297849213662264, 9.346657156438338, 9.395211546314432, 9.443516294262428, 9.491575211733826, 9.539392014169458, 9.586970324351693], [0.0, 0.959166304662544, 1.3564659966250536, 1.6613247725836153, 1.918332609325088, 2.144761058952722, 2.349468024894146, 2.5377155080899043, 2.7129319932501073, 2.877498913987632, 3.0331501776206204, 3.1811947441173736, 3.3226495451672307, 3.458323293158117, 3.5888716889852725, 3.714835124201342, 3.836665218650176, 3.954743986657038, 4.069397989875161, 4.180908992073375, 4.289522117905444, 4.3954521951671826, 4.498888751680798, 4.6000000000000005, 4.698936049788292, 4.79583152331272, 4.8908077042549944, 4.983974317750846, 5.075431016179809, 5.165268628057984, 5.253570214625479, 5.340411969127476, 5.4258639865002145, 5.509990925582366, 5.592852581643825, 5.674504383644443, 5.754997827975264, 5.83438085832593, 5.912698199637794, 5.989991652748776, 6.066300355241241, 6.1416610131136355, 6.216108107168022, 6.289674077406555, 6.362389488234747, 6.434283176858165, 6.505382386916238, 6.575712889109439, 6.645299090334461, 6.714164132637808, 6.782329983125269, 6.8498175158174845, 6.916646586316234, 6.982836100038438, 7.0484040746824395, 7.113367697511497, 7.177743377970545, 7.24154679609267, 7.3047929470998705, 7.367496182557545, 7.429670248402684, 7.491328320131218, 7.552483035399683, 7.6131465242697125, 7.673330437300352, 7.733045971672482, 7.792303895511263, 7.851114570556209, 7.909487973314076, 7.967433714816837, 8.024961059095553, 8.082078940470701, 8.138795979750322, 8.195120499419152, 8.251060537894508, 8.306623862918075, 8.36181798414675, 8.416650165000327, 8.47112743381895, 8.525256594378847, 8.579044235810889, 8.632496741962896, 8.685620300243388, 8.738420909981391, 8.790904390334365, 8.843076387773658, 8.894942383174834, 8.946507698538017, 8.997777503361595, 9.048756820690896, 9.099450532861862, 9.1498633869583, 9.200000000000001, 9.249864863877743, 9.299462350050137, 9.348796714016196, 9.397872099576585, 9.446692542895637, 9.495261976375376, 9.54358423235212, 9.59166304662544, 9.639502061828715], [0.0, 0.9643650760992956, 1.3638181696985856, 1.670329308849007, 1.9287301521985911, 2.1563858652847827, 2.3622023622035435, 2.551470164434615, 2.727636339397171, 2.8930952282978866, 3.0495901363953815, 3.1984371183438958, 3.340658617698014, 3.4770677301427426, 3.6083237105337433, 3.7349698793966195, 3.8574603043971822, 3.976179070414209, 4.091454509095757, 4.203569911396741, 4.312771730569565, 4.419275958796871, 4.523273151159457, 4.624932431938872, 4.724404724407087, 4.821825380496478, 4.917316341257699, 5.0109879265470205, 5.10294032886923, 5.193264869039514, 5.282045058497703, 5.36935750346352, 5.455272678794342, 5.539855593785817, 5.62316636780382, 5.705260730238365, 5.786190456595773, 5.866003750424986, 5.944745579080741, 6.02245796996542, 6.099180272790763, 6.174949392505174, 6.249799996799899, 6.323764701504951, 6.3968742366877915, 6.469157595854347, 6.540642170307134, 6.611353870426239, 6.681317235396028, 6.750555532695069, 6.8190908484929285, 6.886944169949399, 6.954135460285485, 7.020683727387242, 7.0866070866106305, 7.15192281837549, 7.216647421067487, 7.280796659706959, 7.3443856107914165, 7.407428703673091, 7.469939758793239, 7.531932023060219, 7.593418202627852, 7.654410493303845, 7.7149206087943645, 7.774959806970066, 7.834538914320357, 7.893668348746355, 7.952358140828418, 8.010617953691215, 8.068457101577724, 8.125884567233282, 8.182909018191515, 8.239538822045807, 8.295782060782456, 8.351646544245034, 8.407139822793482, 8.462269199216012, 8.517041739947036, 8.571464285639882, 8.62554346113913, 8.67928568489366, 8.732697177848321, 8.78578397184907, 8.838551917593742, 8.891006692158093, 8.943153806124549, 8.994998610338971, 9.046546302318914, 9.097801932335084, 9.148770409186145, 9.199456505685541, 9.249864863877743, 9.3, 9.349866309204641, 9.39946807005588, 9.448809448814174, 9.497894503520243, 9.5467271878901, 9.595311355031686, 9.643650760992957, 9.691749068150704], [0.0, 0.9695359714832659, 1.3711309200802089, 1.6792855623746668, 1.9390719429665317, 2.1679483388678804, 2.374868417407584, 2.5651510676761324, 2.7422618401604177, 2.9086079144497976, 3.0659419433511785, 3.2155870381627056, 3.3585711247493335, 3.4957116585897072, 3.627671429443411, 3.7549966711037173, 3.8781438859330635, 3.9974992182613374, 4.113392760240627, 4.226109321823088, 4.335896677735761, 4.442971978304612, 4.54752680036083, 4.649731175025068, 4.749736834815168, 4.847679857416329, 4.943682837723311, 5.037856687124, 5.130302135352265, 5.221110992882646, 5.310367218940701, 5.398147830506312, 5.4845236803208355, 5.569560126257729, 5.653317610041029, 5.735852159879995, 5.817215828899595, 5.897457079114693, 5.976621118993575, 6.054750201288242, 6.131883886702357, 6.208059278067504, 6.283311228962004, 6.357672530100933, 6.431174076325411, 6.5038450166036395, 6.57571288910944, 6.646803743153547, 6.717142249498667, 6.786751800382861, 6.855654600401045, 6.923871749245506, 6.9914233171794145, 7.058328414008519, 7.124605252222751, 7.1902712048990205, 7.255342858886822, 7.31983606373804, 7.383765976789894, 7.447147104764348, 7.5099933422074345, 7.572318007057021, 7.634133873596926, 7.695453203028396, 7.756287771866127, 7.816648898345122, 7.8765474670060875, 7.935993951610599, 7.994998436522675, 8.053570636680355, 8.1117199162693, 8.16945530620004, 8.226785520481254, 8.283718971573094, 8.340263784797218, 8.396427811873334, 8.452218643646177, 8.507643622061282, 8.56270985144306, 8.61742420912421, 8.671793355471522, 8.725823743349393, 8.77952162705919, 8.832893070789435, 8.885943956609225, 8.938679992034618, 8.99110671719561, 9.043229511629129, 9.09505360072166, 9.1465840618233, 9.197825830053535, 9.248783703817493, 9.299462350050137, 9.349866309204641, 9.4, 9.44986772394196, 9.499473669630335, 9.548821916864929, 9.597916440561463, 9.646761114488118, 9.695359714832659, 9.743715923609434], [0.0, 0.9746794344808963, 1.378404875209022, 1.6881943016134133, 1.9493588689617927, 2.179449471770337, 2.3874672772626644, 2.578759391645525, 2.756809750418044, 2.9240383034426887, 3.082207001484488, 3.2326459750489227, 3.3763886032268267, 3.5142566781611158, 3.6469165057620936, 3.7749172176353745, 3.8987177379235853, 4.018706259482023, 4.135214625627066, 4.2485291572496005, 4.358898943540674, 4.466542286825459, 4.571651780264984, 4.674398357008098, 4.774934554525329, 4.873397172404482, 4.969909455915671, 5.06458290484024, 5.15751878329105, 5.2488093888042835, 5.338539126015655, 5.426785420486054, 5.513619500836088, 5.599107071667768, 5.683308895353129, 5.766281297335397, 5.848076606885377, 5.928743543112655, 6.008327554319921, 6.08687111741328, 6.164414002968976, 6.24099351065197, 6.316644678941503, 6.3914004725099165, 6.465291950097845, 6.53834841531101, 6.6105975524153635, 6.682065548915245, 6.752777206453653, 6.822756041366274, 6.892024376045111, 6.960603422117942, 7.0285133563222315, 7.095773389842717, 7.162401831787993, 7.2284161474004796, 7.293833011524187, 7.358668357794092, 7.4229374239582535, 7.486654793697916, 7.549834435270749, 7.6124897372673015, 7.674633541739956, 7.736278174936576, 7.797435475847171, 7.858116822750854, 7.918333157931661, 7.978095010715276, 8.037412518964047, 8.096295449154509, 8.154753215150045, 8.212794895770866, 8.270429251254132, 8.327664738688751, 8.384509526501832, 8.440971508067065, 8.497058314499201, 8.55277732669336, 8.608135686662937, 8.663140308225419, 8.717797887081348, 8.772114910328067, 8.826097665446492, 8.879752248796134, 8.933084573650918, 8.986100377805714, 9.038805230781334, 9.091204540653564, 9.143303560529969, 9.195107394696377, 9.246621004453464, 9.297849213662264, 9.348796714016196, 9.39946807005588, 9.44986772394196, 9.499999999999998, 9.549869109050658, 9.599479152537391, 9.648834126463154, 9.697937925146768, 9.746794344808963, 9.795407086997457], [0.0, 0.9797958971132713, 1.3856406460551018, 1.6970562748477143, 1.9595917942265426, 2.1908902300206647, 2.4000000000000004, 2.5922962793631443, 2.7712812921102037, 2.939387691339814, 3.0983866769659336, 3.2496153618543846, 3.3941125496954285, 3.532704346531139, 3.666060555964672, 3.794733192202055, 3.9191835884530852, 4.039801975344831, 4.156921938165306, 4.270831300812525, 4.3817804600413295, 4.48998886412873, 4.595650117230424, 4.698936049788292, 4.800000000000001, 4.898979485566357, 4.9959983987187195, 5.091168824543143, 5.184592558726289, 5.276362383309168, 5.366563145999495, 5.455272678794342, 5.542562584220407, 5.628498911788117, 5.713142742834281, 5.796550698475776, 5.878775382679628, 5.959865770300536, 6.0398675482166, 6.118823416311343, 6.196773353931867, 6.27375485654325, 6.349803146555018, 6.424951361683604, 6.499230723708769, 6.572670690061993, 6.64529909033446, 6.717142249498666, 6.788225099390857, 6.858571279792899, 6.92820323027551, 6.997142273814362, 7.065408693062278, 7.1330218000508046, 7.2, 7.266360849833981, 7.332121111929344, 7.397296803562772, 7.4619032424710525, 7.525955088890711, 7.58946638440411, 7.652450587883597, 7.714920608794364, 7.776888838089433, 7.8383671769061705, 7.899367063252599, 7.95989949685296, 8.019975062305368, 8.079603950689663, 8.138795979750322, 8.19756061276768, 8.255906976220118, 8.313843876330612, 8.37137981458254, 8.42852300228219, 8.485281374238571, 8.54166260162505, 8.597674104081872, 8.653323061113575, 8.708616422830897, 8.763560920082659, 8.818163074019441, 8.872429205127535, 8.926365441768558, 8.97997772825746, 9.033271832508973, 9.086253353280439, 9.138927727036691, 9.191300234460847, 9.243376006633074, 9.2951600308978, 9.346657156438338, 9.397872099576585, 9.448809448814174, 9.499473669630335, 9.549869109050658, 9.600000000000001, 9.649870465451857, 9.699484522385713, 9.748846085563153, 9.797958971132713, 9.846826900072939], [0.0, 0.9848857801796106, 1.392838827718412, 1.7058722109231985, 1.9697715603592212, 2.2022715545545246, 2.412467616362964, 2.6057628441590768, 2.785677655436824, 2.9546573405388314, 3.1144823004794877, 3.2664965942122155, 3.411744421846397, 3.5510561809129415, 3.685105154537656, 3.8144462245521304, 3.9395431207184424, 4.060788100849391, 4.178516483155236, 4.293017586733137, 4.404543109109049, 4.513313638558704, 4.61952378498044, 4.723346271447818, 4.824935232725928, 4.924428900898053, 5.021951811795889, 5.117616632769595, 5.2115256883181535, 5.3037722424704485, 5.394441583704471, 5.483611948342078, 5.571355310873648, 5.657738063926256, 5.742821606144492, 5.826662852782887, 5.909314681077663, 5.990826320300065, 6.071243694664217, 6.150609725872713, 6.228964600958975, 6.306346010171025, 6.38278935889318, 6.458327956987009, 6.532993188424431, 6.606814663663572, 6.679820356865895, 6.7520367297579185, 6.823488843692794, 6.894200461257274, 6.9641941385920605, 7.033491309442276, 7.102112361825883, 7.170076708097342, 7.237402849088892, 7.30410843293006, 7.370210309075312, 7.4357245780085215, 7.5006666370396715, 7.565051222562872, 7.628892449104261, 7.692203845452876, 7.754998388136519, 7.817288532477231, 7.879086241436885, 7.940403012442127, 8.001249902359007, 8.061637550770936, 8.121576201698781, 8.18107572388864, 8.240145629781066, 8.298795093265047, 8.357032966310472, 8.414867794564572, 8.472307831990054, 8.529361054615991, 8.586035173466273, 8.64233764672499, 8.698275691193055, 8.753856293085923, 8.809086218218098, 8.863972021616496, 8.918520056601322, 8.972736483370054, 9.026627277117408, 9.080198235721511, 9.133454987024352, 9.186402995732335, 9.23904756996088, 9.291393867445294, 9.343446901438464, 9.395211546314432, 9.446692542895637, 9.497894503520243, 9.548821916864929, 9.599479152537391, 9.649870465451857, 9.700000000000003, 9.749871794028884, 9.799489782636646, 9.848857801796106, 9.897979591815698], [0.0, 0.9899494936611666, 1.4, 1.7146428199482249, 1.9798989873223332, 2.2135943621178655, 2.4248711305964283, 2.619160170741759, 2.8, 2.9698484809834995, 3.1304951684997055, 3.283291031876401, 3.4292856398964497, 3.5693136595149495, 3.704051835490427, 3.8340579025361623, 3.9597979746446663, 4.08166632639171, 4.2, 4.315089802078284, 4.427188724235731, 4.536518488885503, 4.64327470649756, 4.747630988187688, 4.849742261192857, 4.949747468305833, 5.047771785649585, 5.143928459844674, 5.238320341483518, 5.331041174104736, 5.422176684690383, 5.511805511808268, 5.6, 5.686826883245173, 5.772347875864725, 5.856620185738529, 5.939696961966999, 6.021627686929839, 6.102458520956943, 6.182232606429493, 6.260990336999411, 6.338769596696192, 6.4156059729381765, 6.491532946846992, 6.566582063752802, 6.640783086353596, 6.714164132637808, 6.786751800382861, 6.8585712797928995, 6.929646455628165, 7.0, 7.069653456853455, 7.138627319029899, 7.206941098690901, 7.274613391789285, 7.341661937191061, 7.408103670980854, 7.473954776421918, 7.539230729988306, 7.603946343840151, 7.668115805072325, 7.731752712031082, 7.79487010796203, 7.857480512225277, 7.919595949289333, 7.981227975693965, 8.04238770515324, 8.103085831953157, 8.16333265278342, 8.223138087129511, 8.282511696339462, 8.341462701469089, 8.4, 8.4581321815162, 8.515867542417507, 8.573214099741124, 8.630179604156568, 8.6867715521936, 8.742997197757758, 8.798863562983575, 8.854377448471462, 8.909545442950499, 8.964373932405989, 9.018869108707587, 9.073036977771006, 9.126883367283709, 9.180413934022802, 9.233634170791044, 9.28654941299512, 9.339164844888433, 9.391485505499116, 9.443516294262428, 9.495261976375376, 9.5467271878901, 9.597916440561463, 9.648834126463154, 9.699484522385713, 9.749871794028884, 9.8, 9.849873095629203, 9.899494936611665, 9.948869282486328], [0.0, 0.9949874371066201, 1.407124727947029, 1.7233687939614089, 1.9899748742132402, 2.224859546128699, 2.4372115213907883, 2.632489316217637, 2.814249455894058, 2.98496231131986, 3.146426544510455, 3.3000000000000007, 3.4467375879228177, 3.58747822293042, 3.722902093797257, 3.853569773599539, 3.9799497484264803, 4.102438299353203, 4.221374183841087, 4.337049688440289, 4.449719092257398, 4.559605246071199, 4.666904755831214, 4.77179211617606, 4.874423042781577, 4.974937185533101, 5.073460357586329, 5.170106381884226, 5.264978632435274, 5.358171329847527, 5.449770637375485, 5.539855593785817, 5.628498911788116, 5.715767664977296, 5.801723881744115, 5.886425061104576, 5.96992462263972, 6.052272300549605, 6.133514490078262, 6.213694553162394, 6.29285308902091, 6.3710281744785915, 6.448255578061405, 6.524568951279464, 6.600000000000001, 6.674578638386096, 6.748333127521196, 6.821290200541244, 6.893475175845635, 6.96491205974634, 7.035623639735145, 7.105631569396208, 7.17495644586084, 7.243617880589783, 7.3116345641723655, 7.379024325749307, 7.445804187594514, 7.5119904153293495, 7.577598564189055, 7.642643521714199, 7.707139547199078, 7.771100308193172, 7.834538914320357, 7.897467948652911, 7.959899496852961, 8.021845174272563, 8.083316151184489, 8.144323176298936, 8.204876598706406, 8.264986388373547, 8.324662155306966, 8.383913167489272, 8.442748367682174, 8.501176389182852, 8.559205570612264, 8.616843969807043, 8.674099376880578, 8.73097932651315, 8.787491109526087, 8.843641783790206, 8.899438184514796, 8.95488693395958, 9.009994450608726, 9.064766957842878, 9.119210492142399, 9.173330910852394, 9.22713389953782, 9.280624978954814, 9.333809511662428, 9.38669270829721, 9.439279633531365, 9.491575211733826, 9.54358423235212, 9.595311355031686, 9.646761114488118, 9.697937925146768, 9.748846085563153, 9.799489782636646, 9.849873095629203, 9.900000000000002, 9.949874371066201, 9.999499987499377], [0.0, 1.0, 1.4142135623730951, 1.7320508075688776, 2.0, 2.23606797749979, 2.4494897427831783, 2.6457513110645907, 2.8284271247461903, 3.0, 3.1622776601683795, 3.3166247903554003, 3.4641016151377553, 3.6055512754639896, 3.7416573867739413, 3.8729833462074166, 4.0, 4.123105625617661, 4.242640687119286, 4.358898943540674, 4.47213595499958, 4.582575694955841, 4.69041575982343, 4.79583152331272, 4.898979485566357, 5.000000000000001, 5.099019513592785, 5.196152422706633, 5.291502622129181, 5.385164807134505, 5.477225575051661, 5.567764362830022, 5.656854249492381, 5.7445626465380295, 5.830951894845301, 5.916079783099616, 6.0, 6.08276253029822, 6.164414002968977, 6.244997998398399, 6.324555320336759, 6.403124237432849, 6.480740698407861, 6.557438524302, 6.6332495807108005, 6.7082039324993685, 6.782329983125269, 6.855654600401045, 6.9282032302755105, 7.0, 7.071067811865476, 7.141428428542851, 7.211102550927979, 7.28010988928052, 7.348469228349535, 7.416198487095664, 7.483314773547883, 7.54983443527075, 7.6157731058639095, 7.681145747868608, 7.745966692414833, 7.810249675906655, 7.874007874011811, 7.937253933193772, 8.0, 8.06225774829855, 8.12403840463596, 8.18535277187245, 8.246211251235321, 8.306623862918075, 8.366600265340756, 8.426149773176359, 8.485281374238571, 8.544003745317532, 8.602325267042627, 8.660254037844387, 8.717797887081348, 8.774964387392123, 8.831760866327848, 8.88819441731559, 8.94427190999916, 9.000000000000002, 9.055385138137417, 9.1104335791443, 9.165151389911681, 9.219544457292889, 9.273618495495704, 9.327379053088816, 9.38083151964686, 9.433981132056603, 9.486832980505138, 9.539392014169458, 9.59166304662544, 9.643650760992957, 9.695359714832659, 9.746794344808963, 9.797958971132713, 9.848857801796106, 9.899494936611665, 9.949874371066201, 10.000000000000002, 10.049875621120892], [0.0, 1.0049875621120892, 1.4212670403551897, 1.7406895185529214, 2.0099751242241783, 2.2472205054244236, 2.4617067250182347, 2.6589471600616665, 2.8425340807103794, 3.0149626863362675, 3.178049716414141, 3.333166662499792, 3.481379037105843, 3.6235341863986883, 3.7603191353926335, 3.892300091205713, 4.019950248448357, 4.1436698710201325, 4.263801121065569, 4.380639222761903, 4.494441010848847, 4.605431575867782, 4.713809499757071, 4.819751030914357, 4.9234134500364695, 5.024937810560446, 5.1244511901275835, 5.222068555658764, 5.317894320123333, 5.412023651093924, 5.504543577809154, 5.595533933415113, 5.685068161420759, 5.773214009544425, 5.860034129593445, 5.9455865984779, 6.029925372672535, 6.113100686231171, 6.1951594006934165, 6.276145313805283, 6.356099432828282, 6.435060217278469, 6.5130637951735135, 6.590144156238162, 6.666333324999584, 6.74166151627327, 6.81615727518079, 6.889847603539574, 6.962758074211686, 7.034912934784624, 7.1063352017759485, 7.177046746399247, 7.247068372797377, 7.31641988953614, 7.385120175054704, 7.4531872376856345, 7.520638270785267, 7.587489703452652, 7.653757247260983, 7.719455939378112, 7.784600182411426, 7.849203781276163, 7.913279977354524, 7.976841480185, 8.039900496896713, 8.10246875958186, 8.16455755078008, 8.226177727231525, 8.287339742040265, 8.34805366537614, 8.408329203831164, 8.468175718535841, 8.527602242131138, 8.586617494683225, 8.645229898620395, 8.703447592764606, 8.761278445523805, 8.81873006730561, 8.875809822207776, 8.932524839036274, 8.988882021697695, 9.044888059008803, 9.100549433962767, 9.155872432488342, 9.210863151735564, 9.265527507918803, 9.319871243745807, 9.373899935459095, 9.427618999514142, 9.481033698917013, 9.534149149242424, 9.586970324351693, 9.639502061828715, 9.691749068150704, 9.743715923609434, 9.795407086997457, 9.846826900072939, 9.897979591815698, 9.948869282486328, 9.999499987499377, 10.049875621120892, 10.100000000000001]]}],\n",
       "                        {\"autosize\": false, \"height\": 500, \"margin\": {\"b\": 65, \"l\": 65, \"r\": 50, \"t\": 90}, \"scene\": {\"xaxis\": {\"title\": {\"text\": \"K\"}}, \"yaxis\": {\"title\": {\"text\": \"L\"}}, \"zaxis\": {\"title\": {\"text\": \"Y\"}}}, \"template\": {\"data\": {\"bar\": [{\"error_x\": {\"color\": \"#2a3f5f\"}, \"error_y\": {\"color\": \"#2a3f5f\"}, \"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"bar\"}], \"barpolar\": [{\"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"barpolar\"}], \"carpet\": [{\"aaxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"baxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"type\": \"carpet\"}], \"choropleth\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"choropleth\"}], \"contour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"contour\"}], \"contourcarpet\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"contourcarpet\"}], \"heatmap\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmap\"}], \"heatmapgl\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmapgl\"}], \"histogram\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"histogram\"}], \"histogram2d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2d\"}], \"histogram2dcontour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2dcontour\"}], \"mesh3d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"mesh3d\"}], \"parcoords\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"parcoords\"}], \"scatter\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter\"}], \"scatter3d\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter3d\"}], \"scattercarpet\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattercarpet\"}], \"scattergeo\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergeo\"}], \"scattergl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergl\"}], \"scattermapbox\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattermapbox\"}], \"scatterpolar\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolar\"}], \"scatterpolargl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolargl\"}], \"scatterternary\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterternary\"}], \"surface\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"surface\"}], \"table\": [{\"cells\": {\"fill\": {\"color\": \"#EBF0F8\"}, \"line\": {\"color\": \"white\"}}, \"header\": {\"fill\": {\"color\": \"#C8D4E3\"}, \"line\": {\"color\": \"white\"}}, \"type\": \"table\"}]}, \"layout\": {\"annotationdefaults\": {\"arrowcolor\": \"#2a3f5f\", \"arrowhead\": 0, \"arrowwidth\": 1}, \"colorscale\": {\"diverging\": [[0, \"#8e0152\"], [0.1, \"#c51b7d\"], [0.2, \"#de77ae\"], [0.3, \"#f1b6da\"], [0.4, \"#fde0ef\"], [0.5, \"#f7f7f7\"], [0.6, \"#e6f5d0\"], [0.7, \"#b8e186\"], [0.8, \"#7fbc41\"], [0.9, \"#4d9221\"], [1, \"#276419\"]], \"sequential\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"sequentialminus\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]]}, \"colorway\": [\"#636efa\", \"#EF553B\", \"#00cc96\", \"#ab63fa\", \"#FFA15A\", \"#19d3f3\", \"#FF6692\", \"#B6E880\", \"#FF97FF\", \"#FECB52\"], \"font\": {\"color\": \"#2a3f5f\"}, \"geo\": {\"bgcolor\": \"white\", \"lakecolor\": \"white\", \"landcolor\": \"#E5ECF6\", \"showlakes\": true, \"showland\": true, \"subunitcolor\": \"white\"}, \"hoverlabel\": {\"align\": \"left\"}, \"hovermode\": \"closest\", \"mapbox\": {\"style\": \"light\"}, \"paper_bgcolor\": \"white\", \"plot_bgcolor\": \"#E5ECF6\", \"polar\": {\"angularaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"radialaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"scene\": {\"xaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"yaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"zaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}}, \"shapedefaults\": {\"line\": {\"color\": \"#2a3f5f\"}}, \"ternary\": {\"aaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"baxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"caxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"title\": {\"x\": 0.05}, \"xaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}, \"yaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}}}, \"title\": {\"text\": \"Cobb-Douglas Production Function\"}, \"width\": 500},\n",
       "                        {\"responsive\": true}\n",
       "                    )\n",
       "                };\n",
       "                \n",
       "            </script>\n",
       "        </div>\n",
       "</body>\n",
       "</html>"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "change_alpha_beta(2, filename=\"fig4.html\")\n",
    "display(HTML(\"fig4.html\"))"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "The above graph shows increasing returns to scale with $\\alpha + \\beta = 2$ (the purble-yellow surface) with constant returns to scale for comparison (the blue-yellow surface). Notice how the orange function no longer increases at a decreasing rate, but seems to mimic exponential growth. This is once again because of the definition of increasing returns to scale. As companies continue to increase their inputs by a factor of $c$, they see their output increase by more than that factor. Thus, as inputs $(K, L)$ increase, output will increase at an even faster rate than that - in this case by the square."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "metadata": {
    "tags": [
     "remove_input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<html>\n",
       "<head><meta charset=\"utf-8\" /></head>\n",
       "<body>\n",
       "    <div>\n",
       "            <script src=\"https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.5/MathJax.js?config=TeX-AMS-MML_SVG\"></script><script type=\"text/javascript\">if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}</script>\n",
       "                <script type=\"text/javascript\">window.PlotlyConfig = {MathJaxConfig: 'local'};</script>\n",
       "        <script type=\"text/javascript\">/**\n",
       "* plotly.js v1.49.1\n",
       "* Copyright 2012-2019, Plotly, Inc.\n",
       "* All rights reserved.\n",
       "* Licensed under the MIT license\n",
       "*/\n",
       "!function(t){if(\"object\"==typeof exports&&\"undefined\"!=typeof module)module.exports=t();else if(\"function\"==typeof define&&define.amd)define([],t);else{(\"undefined\"!=typeof window?window:\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:this).Plotly=t()}}(function(){return function(){return function t(e,r,n){function i(o,s){if(!r[o]){if(!e[o]){var l=\"function\"==typeof require&&require;if(!s&&l)return l(o,!0);if(a)return a(o,!0);var c=new Error(\"Cannot find module '\"+o+\"'\");throw c.code=\"MODULE_NOT_FOUND\",c}var u=r[o]={exports:{}};e[o][0].call(u.exports,function(t){return i(e[o][1][t]||t)},u,u.exports,t,e,r,n)}return r[o].exports}for(var a=\"function\"==typeof require&&require,o=0;o<n.length;o++)i(n[o]);return i}}()({1:[function(t,e,r){\"use strict\";var n=t(\"../src/lib\"),i={\"X,X div\":\"direction:ltr;font-family:'Open Sans', verdana, arial, sans-serif;margin:0;padding:0;\",\"X input,X button\":\"font-family:'Open Sans', verdana, arial, sans-serif;\",\"X input:focus,X button:focus\":\"outline:none;\",\"X a\":\"text-decoration:none;\",\"X a:hover\":\"text-decoration:none;\",\"X .crisp\":\"shape-rendering:crispEdges;\",\"X .user-select-none\":\"-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;\",\"X svg\":\"overflow:hidden;\",\"X svg a\":\"fill:#447adb;\",\"X svg a:hover\":\"fill:#3c6dc5;\",\"X .main-svg\":\"position:absolute;top:0;left:0;pointer-events:none;\",\"X .main-svg .draglayer\":\"pointer-events:all;\",\"X .cursor-default\":\"cursor:default;\",\"X .cursor-pointer\":\"cursor:pointer;\",\"X .cursor-crosshair\":\"cursor:crosshair;\",\"X .cursor-move\":\"cursor:move;\",\"X .cursor-col-resize\":\"cursor:col-resize;\",\"X .cursor-row-resize\":\"cursor:row-resize;\",\"X .cursor-ns-resize\":\"cursor:ns-resize;\",\"X .cursor-ew-resize\":\"cursor:ew-resize;\",\"X .cursor-sw-resize\":\"cursor:sw-resize;\",\"X .cursor-s-resize\":\"cursor:s-resize;\",\"X .cursor-se-resize\":\"cursor:se-resize;\",\"X .cursor-w-resize\":\"cursor:w-resize;\",\"X .cursor-e-resize\":\"cursor:e-resize;\",\"X .cursor-nw-resize\":\"cursor:nw-resize;\",\"X .cursor-n-resize\":\"cursor:n-resize;\",\"X .cursor-ne-resize\":\"cursor:ne-resize;\",\"X .cursor-grab\":\"cursor:-webkit-grab;cursor:grab;\",\"X .modebar\":\"position:absolute;top:2px;right:2px;\",\"X .ease-bg\":\"-webkit-transition:background-color 0.3s ease 0s;-moz-transition:background-color 0.3s ease 0s;-ms-transition:background-color 0.3s ease 0s;-o-transition:background-color 0.3s ease 0s;transition:background-color 0.3s ease 0s;\",\"X .modebar--hover>:not(.watermark)\":\"opacity:0;-webkit-transition:opacity 0.3s ease 0s;-moz-transition:opacity 0.3s ease 0s;-ms-transition:opacity 0.3s ease 0s;-o-transition:opacity 0.3s ease 0s;transition:opacity 0.3s ease 0s;\",\"X:hover .modebar--hover .modebar-group\":\"opacity:1;\",\"X .modebar-group\":\"float:left;display:inline-block;box-sizing:border-box;padding-left:8px;position:relative;vertical-align:middle;white-space:nowrap;\",\"X .modebar-btn\":\"position:relative;font-size:16px;padding:3px 4px;height:22px;cursor:pointer;line-height:normal;box-sizing:border-box;\",\"X .modebar-btn svg\":\"position:relative;top:2px;\",\"X .modebar.vertical\":\"display:flex;flex-direction:column;flex-wrap:wrap;align-content:flex-end;max-height:100%;\",\"X .modebar.vertical svg\":\"top:-1px;\",\"X .modebar.vertical .modebar-group\":\"display:block;float:none;padding-left:0px;padding-bottom:8px;\",\"X .modebar.vertical .modebar-group .modebar-btn\":\"display:block;text-align:center;\",\"X [data-title]:before,X [data-title]:after\":\"position:absolute;-webkit-transform:translate3d(0, 0, 0);-moz-transform:translate3d(0, 0, 0);-ms-transform:translate3d(0, 0, 0);-o-transform:translate3d(0, 0, 0);transform:translate3d(0, 0, 0);display:none;opacity:0;z-index:1001;pointer-events:none;top:110%;right:50%;\",\"X [data-title]:hover:before,X [data-title]:hover:after\":\"display:block;opacity:1;\",\"X [data-title]:before\":\"content:'';position:absolute;background:transparent;border:6px solid transparent;z-index:1002;margin-top:-12px;border-bottom-color:#69738a;margin-right:-6px;\",\"X [data-title]:after\":\"content:attr(data-title);background:#69738a;color:white;padding:8px 10px;font-size:12px;line-height:12px;white-space:nowrap;margin-right:-18px;border-radius:2px;\",\"X .vertical [data-title]:before,X .vertical [data-title]:after\":\"top:0%;right:200%;\",\"X .vertical [data-title]:before\":\"border:6px solid transparent;border-left-color:#69738a;margin-top:8px;margin-right:-30px;\",\"X .select-outline\":\"fill:none;stroke-width:1;shape-rendering:crispEdges;\",\"X .select-outline-1\":\"stroke:white;\",\"X .select-outline-2\":\"stroke:black;stroke-dasharray:2px 2px;\",Y:\"font-family:'Open Sans';position:fixed;top:50px;right:20px;z-index:10000;font-size:10pt;max-width:180px;\",\"Y p\":\"margin:0;\",\"Y .notifier-note\":\"min-width:180px;max-width:250px;border:1px solid #fff;z-index:3000;margin:0;background-color:#8c97af;background-color:rgba(140,151,175,0.9);color:#fff;padding:10px;overflow-wrap:break-word;word-wrap:break-word;-ms-hyphens:auto;-webkit-hyphens:auto;hyphens:auto;\",\"Y .notifier-close\":\"color:#fff;opacity:0.8;float:right;padding:0 5px;background:none;border:none;font-size:20px;font-weight:bold;line-height:20px;\",\"Y .notifier-close:hover\":\"color:#444;text-decoration:none;cursor:pointer;\"};for(var a in i){var o=a.replace(/^,/,\" ,\").replace(/X/g,\".js-plotly-plot .plotly\").replace(/Y/g,\".plotly-notifier\");n.addStyleRule(o,i[a])}},{\"../src/lib\":719}],2:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/aggregate\")},{\"../src/transforms/aggregate\":1265}],3:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/bar\")},{\"../src/traces/bar\":864}],4:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/barpolar\")},{\"../src/traces/barpolar\":876}],5:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/box\")},{\"../src/traces/box\":886}],6:[function(t,e,r){\"use strict\";e.exports=t(\"../src/components/calendars\")},{\"../src/components/calendars\":591}],7:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/candlestick\")},{\"../src/traces/candlestick\":895}],8:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/carpet\")},{\"../src/traces/carpet\":914}],9:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choropleth\")},{\"../src/traces/choropleth\":928}],10:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choroplethmapbox\")},{\"../src/traces/choroplethmapbox\":935}],11:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/cone\")},{\"../src/traces/cone\":941}],12:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contour\")},{\"../src/traces/contour\":956}],13:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contourcarpet\")},{\"../src/traces/contourcarpet\":967}],14:[function(t,e,r){\"use strict\";e.exports=t(\"../src/core\")},{\"../src/core\":697}],15:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/densitymapbox\")},{\"../src/traces/densitymapbox\":977}],16:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/filter\")},{\"../src/transforms/filter\":1266}],17:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnel\")},{\"../src/traces/funnel\":987}],18:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnelarea\")},{\"../src/traces/funnelarea\":996}],19:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/groupby\")},{\"../src/transforms/groupby\":1267}],20:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmap\")},{\"../src/traces/heatmap\":1009}],21:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmapgl\")},{\"../src/traces/heatmapgl\":1018}],22:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram\")},{\"../src/traces/histogram\":1030}],23:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2d\")},{\"../src/traces/histogram2d\":1036}],24:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2dcontour\")},{\"../src/traces/histogram2dcontour\":1040}],25:[function(t,e,r){\"use strict\";var n=t(\"./core\");n.register([t(\"./bar\"),t(\"./box\"),t(\"./heatmap\"),t(\"./histogram\"),t(\"./histogram2d\"),t(\"./histogram2dcontour\"),t(\"./contour\"),t(\"./scatterternary\"),t(\"./violin\"),t(\"./funnel\"),t(\"./waterfall\"),t(\"./pie\"),t(\"./sunburst\"),t(\"./funnelarea\"),t(\"./scatter3d\"),t(\"./surface\"),t(\"./isosurface\"),t(\"./volume\"),t(\"./mesh3d\"),t(\"./cone\"),t(\"./streamtube\"),t(\"./scattergeo\"),t(\"./choropleth\"),t(\"./scattergl\"),t(\"./splom\"),t(\"./pointcloud\"),t(\"./heatmapgl\"),t(\"./parcoords\"),t(\"./parcats\"),t(\"./scattermapbox\"),t(\"./choroplethmapbox\"),t(\"./densitymapbox\"),t(\"./sankey\"),t(\"./indicator\"),t(\"./table\"),t(\"./carpet\"),t(\"./scattercarpet\"),t(\"./contourcarpet\"),t(\"./ohlc\"),t(\"./candlestick\"),t(\"./scatterpolar\"),t(\"./scatterpolargl\"),t(\"./barpolar\")]),n.register([t(\"./aggregate\"),t(\"./filter\"),t(\"./groupby\"),t(\"./sort\")]),n.register([t(\"./calendars\")]),e.exports=n},{\"./aggregate\":2,\"./bar\":3,\"./barpolar\":4,\"./box\":5,\"./calendars\":6,\"./candlestick\":7,\"./carpet\":8,\"./choropleth\":9,\"./choroplethmapbox\":10,\"./cone\":11,\"./contour\":12,\"./contourcarpet\":13,\"./core\":14,\"./densitymapbox\":15,\"./filter\":16,\"./funnel\":17,\"./funnelarea\":18,\"./groupby\":19,\"./heatmap\":20,\"./heatmapgl\":21,\"./histogram\":22,\"./histogram2d\":23,\"./histogram2dcontour\":24,\"./indicator\":26,\"./isosurface\":27,\"./mesh3d\":28,\"./ohlc\":29,\"./parcats\":30,\"./parcoords\":31,\"./pie\":32,\"./pointcloud\":33,\"./sankey\":34,\"./scatter3d\":35,\"./scattercarpet\":36,\"./scattergeo\":37,\"./scattergl\":38,\"./scattermapbox\":39,\"./scatterpolar\":40,\"./scatterpolargl\":41,\"./scatterternary\":42,\"./sort\":43,\"./splom\":44,\"./streamtube\":45,\"./sunburst\":46,\"./surface\":47,\"./table\":48,\"./violin\":49,\"./volume\":50,\"./waterfall\":51}],26:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/indicator\")},{\"../src/traces/indicator\":1046}],27:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/isosurface\")},{\"../src/traces/isosurface\":1052}],28:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/mesh3d\")},{\"../src/traces/mesh3d\":1057}],29:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/ohlc\")},{\"../src/traces/ohlc\":1062}],30:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcats\")},{\"../src/traces/parcats\":1071}],31:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcoords\")},{\"../src/traces/parcoords\":1081}],32:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pie\")},{\"../src/traces/pie\":1092}],33:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pointcloud\")},{\"../src/traces/pointcloud\":1101}],34:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sankey\")},{\"../src/traces/sankey\":1107}],35:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatter3d\")},{\"../src/traces/scatter3d\":1143}],36:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattercarpet\")},{\"../src/traces/scattercarpet\":1149}],37:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergeo\")},{\"../src/traces/scattergeo\":1156}],38:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergl\")},{\"../src/traces/scattergl\":1167}],39:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattermapbox\")},{\"../src/traces/scattermapbox\":1176}],40:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolar\")},{\"../src/traces/scatterpolar\":1183}],41:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolargl\")},{\"../src/traces/scatterpolargl\":1189}],42:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterternary\")},{\"../src/traces/scatterternary\":1196}],43:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/sort\")},{\"../src/transforms/sort\":1269}],44:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/splom\")},{\"../src/traces/splom\":1205}],45:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/streamtube\")},{\"../src/traces/streamtube\":1213}],46:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sunburst\")},{\"../src/traces/sunburst\":1219}],47:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/surface\")},{\"../src/traces/surface\":1228}],48:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/table\")},{\"../src/traces/table\":1236}],49:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/violin\")},{\"../src/traces/violin\":1244}],50:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/volume\")},{\"../src/traces/volume\":1252}],51:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/waterfall\")},{\"../src/traces/waterfall\":1260}],52:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).eye||[0,0,1],r=t.center||[0,0,0],s=t.up||[0,1,0],l=t.distanceLimits||[0,1/0],c=t.mode||\"turntable\",u=n(),h=i(),f=a();return u.setDistanceLimits(l[0],l[1]),u.lookAt(0,e,r,s),h.setDistanceLimits(l[0],l[1]),h.lookAt(0,e,r,s),f.setDistanceLimits(l[0],l[1]),f.lookAt(0,e,r,s),new o({turntable:u,orbit:h,matrix:f},c)};var n=t(\"turntable-camera-controller\"),i=t(\"orbit-camera-controller\"),a=t(\"matrix-camera-controller\");function o(t,e){this._controllerNames=Object.keys(t),this._controllerList=this._controllerNames.map(function(e){return t[e]}),this._mode=e,this._active=t[e],this._active||(this._mode=\"turntable\",this._active=t.turntable),this.modes=this._controllerNames,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}var s=o.prototype;[[\"flush\",1],[\"idle\",1],[\"lookAt\",4],[\"rotate\",4],[\"pan\",4],[\"translate\",4],[\"setMatrix\",2],[\"setDistanceLimits\",2],[\"setDistance\",2]].forEach(function(t){for(var e=t[0],r=[],n=0;n<t[1];++n)r.push(\"a\"+n);var i=\"var cc=this._controllerList;for(var i=0;i<cc.length;++i){cc[i].\"+t[0]+\"(\"+r.join()+\")}\";s[e]=Function.apply(null,r.concat(i))}),s.recalcMatrix=function(t){this._active.recalcMatrix(t)},s.getDistance=function(t){return this._active.getDistance(t)},s.getDistanceLimits=function(t){return this._active.getDistanceLimits(t)},s.lastT=function(){return this._active.lastT()},s.setMode=function(t){if(t!==this._mode){var e=this._controllerNames.indexOf(t);if(!(e<0)){var r=this._active,n=this._controllerList[e],i=Math.max(r.lastT(),n.lastT());r.recalcMatrix(i),n.setMatrix(i,r.computedMatrix),this._active=n,this._mode=t,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}}},s.getMode=function(){return this._mode}},{\"matrix-camera-controller\":433,\"orbit-camera-controller\":456,\"turntable-camera-controller\":542}],53:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n,i){\"use strict\";function a(t){return t.target.depth}function o(t,e){return t.sourceLinks.length?t.depth:e-1}function s(t){return function(){return t}}i=i&&i.hasOwnProperty(\"default\")?i.default:i;var l=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&\"function\"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?\"symbol\":typeof t};function c(t,e){return h(t.source,e.source)||t.index-e.index}function u(t,e){return h(t.target,e.target)||t.index-e.index}function h(t,e){return t.partOfCycle===e.partOfCycle?t.y0-e.y0:\"top\"===t.circularLinkType||\"bottom\"===e.circularLinkType?-1:1}function f(t){return t.value}function p(t){return(t.y0+t.y1)/2}function d(t){return p(t.source)}function g(t){return p(t.target)}function v(t){return t.index}function m(t){return t.nodes}function y(t){return t.links}function x(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function b(t,e){return e(t)}var _=25,w=10,k=.3;function T(t,e){var r=0,n=0;t.links.forEach(function(i){i.circular&&(i.source.circularLinkType||i.target.circularLinkType?i.circularLinkType=i.source.circularLinkType?i.source.circularLinkType:i.target.circularLinkType:i.circularLinkType=r<n?\"top\":\"bottom\",\"top\"==i.circularLinkType?r+=1:n+=1,t.nodes.forEach(function(t){b(t,e)!=b(i.source,e)&&b(t,e)!=b(i.target,e)||(t.circularLinkType=i.circularLinkType)}))}),t.links.forEach(function(t){t.circular&&(t.source.circularLinkType==t.target.circularLinkType&&(t.circularLinkType=t.source.circularLinkType),Y(t,e)&&(t.circularLinkType=t.source.circularLinkType))})}function A(t){var e=Math.abs(t.y1-t.y0),r=Math.abs(t.target.x0-t.source.x1);return Math.atan(r/e)}function M(t,e){var r=0;t.sourceLinks.forEach(function(t){r=t.circular&&!Y(t,e)?r+1:r});var n=0;return t.targetLinks.forEach(function(t){n=t.circular&&!Y(t,e)?n+1:n}),r+n}function S(t){var e=t.source.sourceLinks,r=0;e.forEach(function(t){r=t.circular?r+1:r});var n=t.target.targetLinks,i=0;return n.forEach(function(t){i=t.circular?i+1:i}),!(r>1||i>1)}function E(t,e,r){return t.sort(L),t.forEach(function(n,i){var a,o,s=0;if(Y(n,r)&&S(n))n.circularPathData.verticalBuffer=s+n.width/2;else{for(var l=0;l<i;l++)if(a=t[i],o=t[l],!(a.source.column<o.target.column||a.target.column>o.source.column)){var c=t[l].circularPathData.verticalBuffer+t[l].width/2+e;s=c>s?c:s}n.circularPathData.verticalBuffer=s+n.width/2}}),t}function C(t,r,i,a){var o=e.min(t.links,function(t){return t.source.y0});t.links.forEach(function(t){t.circular&&(t.circularPathData={})}),E(t.links.filter(function(t){return\"top\"==t.circularLinkType}),r,a),E(t.links.filter(function(t){return\"bottom\"==t.circularLinkType}),r,a),t.links.forEach(function(e){if(e.circular){if(e.circularPathData.arcRadius=e.width+w,e.circularPathData.leftNodeBuffer=5,e.circularPathData.rightNodeBuffer=5,e.circularPathData.sourceWidth=e.source.x1-e.source.x0,e.circularPathData.sourceX=e.source.x0+e.circularPathData.sourceWidth,e.circularPathData.targetX=e.target.x0,e.circularPathData.sourceY=e.y0,e.circularPathData.targetY=e.y1,Y(e,a)&&S(e))e.circularPathData.leftSmallArcRadius=w+e.width/2,e.circularPathData.leftLargeArcRadius=w+e.width/2,e.circularPathData.rightSmallArcRadius=w+e.width/2,e.circularPathData.rightLargeArcRadius=w+e.width/2,\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=e.source.y1+_+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=e.source.y0-_-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius);else{var s=e.source.column,l=e.circularLinkType,c=t.links.filter(function(t){return t.source.column==s&&t.circularLinkType==l});\"bottom\"==e.circularLinkType?c.sort(O):c.sort(P);var u=0;c.forEach(function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.leftSmallArcRadius=w+e.width/2+u,e.circularPathData.leftLargeArcRadius=w+e.width/2+n*r+u),u+=t.width}),s=e.target.column,c=t.links.filter(function(t){return t.target.column==s&&t.circularLinkType==l}),\"bottom\"==e.circularLinkType?c.sort(I):c.sort(z),u=0,c.forEach(function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.rightSmallArcRadius=w+e.width/2+u,e.circularPathData.rightLargeArcRadius=w+e.width/2+n*r+u),u+=t.width}),\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=Math.max(i,e.source.y1,e.target.y1)+_+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=o-_-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius)}e.circularPathData.leftInnerExtent=e.circularPathData.sourceX+e.circularPathData.leftNodeBuffer,e.circularPathData.rightInnerExtent=e.circularPathData.targetX-e.circularPathData.rightNodeBuffer,e.circularPathData.leftFullExtent=e.circularPathData.sourceX+e.circularPathData.leftLargeArcRadius+e.circularPathData.leftNodeBuffer,e.circularPathData.rightFullExtent=e.circularPathData.targetX-e.circularPathData.rightLargeArcRadius-e.circularPathData.rightNodeBuffer}if(e.circular)e.path=function(t){var e=\"\";e=\"top\"==t.circularLinkType?\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 0 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY-t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 0 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 0 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY-t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 0 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY:\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 1 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY+t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 1 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 1 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY+t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 1 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY;return e}(e);else{var h=n.linkHorizontal().source(function(t){return[t.source.x0+(t.source.x1-t.source.x0),t.y0]}).target(function(t){return[t.target.x0,t.y1]});e.path=h(e)}})}function L(t,e){return D(t)==D(e)?\"bottom\"==t.circularLinkType?O(t,e):P(t,e):D(e)-D(t)}function P(t,e){return t.y0-e.y0}function O(t,e){return e.y0-t.y0}function z(t,e){return t.y1-e.y1}function I(t,e){return e.y1-t.y1}function D(t){return t.target.column-t.source.column}function R(t){return t.target.x0-t.source.x1}function F(t,e){var r=A(t),n=R(e)/Math.tan(r);return\"up\"==G(t)?t.y1+n:t.y1-n}function B(t,e){var r=A(t),n=R(e)/Math.tan(r);return\"up\"==G(t)?t.y1-n:t.y1+n}function N(t,e,r,n){t.links.forEach(function(i){if(!i.circular&&i.target.column-i.source.column>1){var a=i.source.column+1,o=i.target.column-1,s=1,l=o-a+1;for(s=1;a<=o;a++,s++)t.nodes.forEach(function(o){if(o.column==a){var c,u=s/(l+1),h=Math.pow(1-u,3),f=3*u*Math.pow(1-u,2),p=3*Math.pow(u,2)*(1-u),d=Math.pow(u,3),g=h*i.y0+f*i.y0+p*i.y1+d*i.y1,v=g-i.width/2,m=g+i.width/2;v>o.y0&&v<o.y1?(c=o.y1-v+10,c=\"bottom\"==o.circularLinkType?c:-c,o=U(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&j(o,t)&&U(t,c,e,r)})):m>o.y0&&m<o.y1?(c=m-o.y0+10,o=U(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&U(t,c,e,r)})):v<o.y0&&m>o.y1&&(c=m-o.y0+10,o=U(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&U(t,c,e,r)}))}})}})}function j(t,e){return t.y0>e.y0&&t.y0<e.y1||(t.y1>e.y0&&t.y1<e.y1||t.y0<e.y0&&t.y1>e.y1)}function U(t,e,r,n){return t.y0+e>=r&&t.y1+e<=n&&(t.y0=t.y0+e,t.y1=t.y1+e,t.targetLinks.forEach(function(t){t.y1=t.y1+e}),t.sourceLinks.forEach(function(t){t.y0=t.y0+e})),t}function V(t,e,r,n){t.nodes.forEach(function(i){n&&i.y+(i.y1-i.y0)>e&&(i.y=i.y-(i.y+(i.y1-i.y0)-e));var a=t.links.filter(function(t){return b(t.source,r)==b(i,r)}),o=a.length;o>1&&a.sort(function(t,e){if(!t.circular&&!e.circular){if(t.target.column==e.target.column)return t.y1-e.y1;if(!H(t,e))return t.y1-e.y1;if(t.target.column>e.target.column){var r=B(e,t);return t.y1-r}if(e.target.column>t.target.column)return B(t,e)-e.y1}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.target.column===e.target.column?t.target.y1-e.target.y1:e.target.column-t.target.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.target.column===e.target.column?e.target.y1-t.target.y1:t.target.column-e.target.column:\"top\"==t.circularLinkType?-1:1:void 0});var s=i.y0;a.forEach(function(t){t.y0=s+t.width/2,s+=t.width}),a.forEach(function(t,e){if(\"bottom\"==t.circularLinkType){for(var r=e+1,n=0;r<o;r++)n+=a[r].width;t.y0=i.y1-n-t.width/2}})})}function q(t,e,r){t.nodes.forEach(function(e){var n=t.links.filter(function(t){return b(t.target,r)==b(e,r)}),i=n.length;i>1&&n.sort(function(t,e){if(!t.circular&&!e.circular){if(t.source.column==e.source.column)return t.y0-e.y0;if(!H(t,e))return t.y0-e.y0;if(e.source.column<t.source.column){var r=F(e,t);return t.y0-r}if(t.source.column<e.source.column)return F(t,e)-e.y0}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:t.source.column-e.source.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:e.source.column-t.source.column:\"top\"==t.circularLinkType?-1:1:void 0});var a=e.y0;n.forEach(function(t){t.y1=a+t.width/2,a+=t.width}),n.forEach(function(t,r){if(\"bottom\"==t.circularLinkType){for(var a=r+1,o=0;a<i;a++)o+=n[a].width;t.y1=e.y1-o-t.width/2}})})}function H(t,e){return G(t)==G(e)}function G(t){return t.y0-t.y1>0?\"up\":\"down\"}function Y(t,e){return b(t.source,e)==b(t.target,e)}t.sankeyCircular=function(){var t,n,a=0,b=0,A=1,S=1,E=24,L=v,P=o,O=m,z=y,I=32,D=2,R=null;function F(){var o={nodes:O.apply(null,arguments),links:z.apply(null,arguments)};!function(t){t.nodes.forEach(function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]});var e=r.map(t.nodes,L);t.links.forEach(function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!==(\"undefined\"==typeof n?\"undefined\":l(n))&&(n=t.source=x(e,n)),\"object\"!==(\"undefined\"==typeof i?\"undefined\":l(i))&&(i=t.target=x(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)})}(o),function(t,e,r){var n=0;if(null===r){for(var a=[],o=0;o<t.links.length;o++){var s=t.links[o],l=s.source.index,c=s.target.index;a[l]||(a[l]=[]),a[c]||(a[c]=[]),-1===a[l].indexOf(c)&&a[l].push(c)}var u=i(a);u.sort(function(t,e){return t.length-e.length});var h={};for(o=0;o<u.length;o++){var f=u[o],p=f.slice(-2);h[p[0]]||(h[p[0]]={}),h[p[0]][p[1]]=!0}t.links.forEach(function(t){var e=t.target.index,r=t.source.index;e===r||h[r]&&h[r][e]?(t.circular=!0,t.circularLinkID=n,n+=1):t.circular=!1})}else t.links.forEach(function(t){t.source[r]<t.target[r]?t.circular=!1:(t.circular=!0,t.circularLinkID=n,n+=1)})}(o,0,R),function(t){t.nodes.forEach(function(t){t.partOfCycle=!1,t.value=Math.max(e.sum(t.sourceLinks,f),e.sum(t.targetLinks,f)),t.sourceLinks.forEach(function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)}),t.targetLinks.forEach(function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)})})}(o),function(t){var e,r,n;for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach(function(t){t.depth=n,t.sourceLinks.forEach(function(t){r.indexOf(t.target)<0&&!t.circular&&r.push(t.target)})});for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach(function(t){t.height=n,t.targetLinks.forEach(function(t){r.indexOf(t.source)<0&&!t.circular&&r.push(t.source)})});t.nodes.forEach(function(t){t.column=Math.floor(P.call(null,t,n))})}(o),T(o,L),function(i,o,s){var l=r.nest().key(function(t){return t.column}).sortKeys(e.ascending).entries(i.nodes).map(function(t){return t.values});(function(r){if(n){var o=1/0;l.forEach(function(t){var e=S*n/(t.length+1);o=e<o?e:o}),t=o}var s=e.min(l,function(r){return(S-b-(r.length-1)*t)/e.sum(r,f)});s*=k,i.links.forEach(function(t){t.width=t.value*s});var c=function(t){var r=0,n=0,i=0,a=0,o=e.max(t.nodes,function(t){return t.column});return t.links.forEach(function(t){t.circular&&(\"top\"==t.circularLinkType?r+=t.width:n+=t.width,0==t.target.column&&(a+=t.width),t.source.column==o&&(i+=t.width))}),{top:r=r>0?r+_+w:r,bottom:n=n>0?n+_+w:n,left:a=a>0?a+_+w:a,right:i=i>0?i+_+w:i}}(i),u=function(t,r){var n=e.max(t.nodes,function(t){return t.column}),i=A-a,o=S-b,s=i+r.right+r.left,l=o+r.top+r.bottom,c=i/s,u=o/l;return a=a*c+r.left,A=0==r.right?A:A*c,b=b*u+r.top,S*=u,t.nodes.forEach(function(t){t.x0=a+t.column*((A-a-E)/n),t.x1=t.x0+E}),u}(i,c);s*=u,i.links.forEach(function(t){t.width=t.value*s}),l.forEach(function(t){var e=t.length;t.forEach(function(t,n){t.depth==l.length-1&&1==e?(t.y0=S/2-t.value*s,t.y1=t.y0+t.value*s):0==t.depth&&1==e?(t.y0=S/2-t.value*s,t.y1=t.y0+t.value*s):t.partOfCycle?0==M(t,r)?(t.y0=S/2+n,t.y1=t.y0+t.value*s):\"top\"==t.circularLinkType?(t.y0=b+n,t.y1=t.y0+t.value*s):(t.y0=S-t.value*s-n,t.y1=t.y0+t.value*s):0==c.top||0==c.bottom?(t.y0=(S-b)/e*n,t.y1=t.y0+t.value*s):(t.y0=(S-b)/2-e/2+n,t.y1=t.y0+t.value*s)})})})(s),m();for(var c=1,u=o;u>0;--u)v(c*=.99,s),m();function v(t,r){var n=l.length;l.forEach(function(i){var a=i.length,o=i[0].depth;i.forEach(function(i){var s;if(i.sourceLinks.length||i.targetLinks.length)if(i.partOfCycle&&M(i,r)>0);else if(0==o&&1==a)s=i.y1-i.y0,i.y0=S/2-s/2,i.y1=S/2+s/2;else if(o==n-1&&1==a)s=i.y1-i.y0,i.y0=S/2-s/2,i.y1=S/2+s/2;else{var l=e.mean(i.sourceLinks,g),c=e.mean(i.targetLinks,d),u=((l&&c?(l+c)/2:l||c)-p(i))*t;i.y0+=u,i.y1+=u}})})}function m(){l.forEach(function(e){var r,n,i,a=b,o=e.length;for(e.sort(h),i=0;i<o;++i)r=e[i],(n=a-r.y0)>0&&(r.y0+=n,r.y1+=n),a=r.y1+t;if((n=a-t-S)>0)for(a=r.y0-=n,r.y1-=n,i=o-2;i>=0;--i)r=e[i],(n=r.y1+t-a)>0&&(r.y0-=n,r.y1-=n),a=r.y0})}}(o,I,L),B(o);for(var s=0;s<4;s++)V(o,S,L),q(o,0,L),N(o,b,S,L),V(o,S,L),q(o,0,L);return function(t,r,n){var i=t.nodes,a=t.links,o=!1,s=!1;if(a.forEach(function(t){\"top\"==t.circularLinkType?o=!0:\"bottom\"==t.circularLinkType&&(s=!0)}),0==o||0==s){var l=e.min(i,function(t){return t.y0}),c=e.max(i,function(t){return t.y1}),u=c-l,h=n-r,f=h/u;i.forEach(function(t){var e=(t.y1-t.y0)*f;t.y0=(t.y0-l)*f,t.y1=t.y0+e}),a.forEach(function(t){t.y0=(t.y0-l)*f,t.y1=(t.y1-l)*f,t.width=t.width*f})}}(o,b,S),C(o,D,S,L),o}function B(t){t.nodes.forEach(function(t){t.sourceLinks.sort(u),t.targetLinks.sort(c)}),t.nodes.forEach(function(t){var e=t.y0,r=e,n=t.y1,i=n;t.sourceLinks.forEach(function(t){t.circular?(t.y0=n-t.width/2,n-=t.width):(t.y0=e+t.width/2,e+=t.width)}),t.targetLinks.forEach(function(t){t.circular?(t.y1=i-t.width/2,i-=t.width):(t.y1=r+t.width/2,r+=t.width)})})}return F.nodeId=function(t){return arguments.length?(L=\"function\"==typeof t?t:s(t),F):L},F.nodeAlign=function(t){return arguments.length?(P=\"function\"==typeof t?t:s(t),F):P},F.nodeWidth=function(t){return arguments.length?(E=+t,F):E},F.nodePadding=function(e){return arguments.length?(t=+e,F):t},F.nodes=function(t){return arguments.length?(O=\"function\"==typeof t?t:s(t),F):O},F.links=function(t){return arguments.length?(z=\"function\"==typeof t?t:s(t),F):z},F.size=function(t){return arguments.length?(a=b=0,A=+t[0],S=+t[1],F):[A-a,S-b]},F.extent=function(t){return arguments.length?(a=+t[0][0],A=+t[1][0],b=+t[0][1],S=+t[1][1],F):[[a,b],[A,S]]},F.iterations=function(t){return arguments.length?(I=+t,F):I},F.circularLinkGap=function(t){return arguments.length?(D=+t,F):D},F.nodePaddingRatio=function(t){return arguments.length?(n=+t,F):n},F.sortNodes=function(t){return arguments.length?(R=t,F):R},F.update=function(t){return T(t,L),B(t),t.links.forEach(function(t){t.circular&&(t.circularLinkType=t.y0+t.y1<S?\"top\":\"bottom\",t.source.circularLinkType=t.circularLinkType,t.target.circularLinkType=t.circularLinkType)}),V(t,S,L,!1),q(t,0,L),C(t,D,S,L),t},F},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,a)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=o,Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\"),t(\"elementary-circuits-directed-graph\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,null)},{\"d3-array\":152,\"d3-collection\":153,\"d3-shape\":161,\"elementary-circuits-directed-graph\":172}],54:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n){\"use strict\";function i(t){return t.target.depth}function a(t,e){return t.sourceLinks.length?t.depth:e-1}function o(t){return function(){return t}}function s(t,e){return c(t.source,e.source)||t.index-e.index}function l(t,e){return c(t.target,e.target)||t.index-e.index}function c(t,e){return t.y0-e.y0}function u(t){return t.value}function h(t){return(t.y0+t.y1)/2}function f(t){return h(t.source)*t.value}function p(t){return h(t.target)*t.value}function d(t){return t.index}function g(t){return t.nodes}function v(t){return t.links}function m(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function y(t){return[t.source.x1,t.y0]}function x(t){return[t.target.x0,t.y1]}t.sankey=function(){var t=0,n=0,i=1,y=1,x=24,b=8,_=d,w=a,k=g,T=v,A=32,M=2/3;function S(){var a={nodes:k.apply(null,arguments),links:T.apply(null,arguments)};return function(t){t.nodes.forEach(function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]});var e=r.map(t.nodes,_);t.links.forEach(function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!=typeof n&&(n=t.source=m(e,n)),\"object\"!=typeof i&&(i=t.target=m(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)})}(a),function(t){t.nodes.forEach(function(t){t.value=Math.max(e.sum(t.sourceLinks,u),e.sum(t.targetLinks,u))})}(a),function(e){var r,n,a;for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach(function(t){t.depth=a,t.sourceLinks.forEach(function(t){n.indexOf(t.target)<0&&n.push(t.target)})});for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach(function(t){t.height=a,t.targetLinks.forEach(function(t){n.indexOf(t.source)<0&&n.push(t.source)})});var o=(i-t-x)/(a-1);e.nodes.forEach(function(e){e.x1=(e.x0=t+Math.max(0,Math.min(a-1,Math.floor(w.call(null,e,a))))*o)+x})}(a),function(t){var i=r.nest().key(function(t){return t.x0}).sortKeys(e.ascending).entries(t.nodes).map(function(t){return t.values});(function(){var r=e.max(i,function(t){return t.length}),a=M*(y-n)/(r-1);b>a&&(b=a);var o=e.min(i,function(t){return(y-n-(t.length-1)*b)/e.sum(t,u)});i.forEach(function(t){t.forEach(function(t,e){t.y1=(t.y0=e)+t.value*o})}),t.links.forEach(function(t){t.width=t.value*o})})(),d();for(var a=1,o=A;o>0;--o)l(a*=.99),d(),s(a),d();function s(t){i.forEach(function(r){r.forEach(function(r){if(r.targetLinks.length){var n=(e.sum(r.targetLinks,f)/e.sum(r.targetLinks,u)-h(r))*t;r.y0+=n,r.y1+=n}})})}function l(t){i.slice().reverse().forEach(function(r){r.forEach(function(r){if(r.sourceLinks.length){var n=(e.sum(r.sourceLinks,p)/e.sum(r.sourceLinks,u)-h(r))*t;r.y0+=n,r.y1+=n}})})}function d(){i.forEach(function(t){var e,r,i,a=n,o=t.length;for(t.sort(c),i=0;i<o;++i)e=t[i],(r=a-e.y0)>0&&(e.y0+=r,e.y1+=r),a=e.y1+b;if((r=a-b-y)>0)for(a=e.y0-=r,e.y1-=r,i=o-2;i>=0;--i)e=t[i],(r=e.y1+b-a)>0&&(e.y0-=r,e.y1-=r),a=e.y0})}}(a),E(a),a}function E(t){t.nodes.forEach(function(t){t.sourceLinks.sort(l),t.targetLinks.sort(s)}),t.nodes.forEach(function(t){var e=t.y0,r=e;t.sourceLinks.forEach(function(t){t.y0=e+t.width/2,e+=t.width}),t.targetLinks.forEach(function(t){t.y1=r+t.width/2,r+=t.width})})}return S.update=function(t){return E(t),t},S.nodeId=function(t){return arguments.length?(_=\"function\"==typeof t?t:o(t),S):_},S.nodeAlign=function(t){return arguments.length?(w=\"function\"==typeof t?t:o(t),S):w},S.nodeWidth=function(t){return arguments.length?(x=+t,S):x},S.nodePadding=function(t){return arguments.length?(b=+t,S):b},S.nodes=function(t){return arguments.length?(k=\"function\"==typeof t?t:o(t),S):k},S.links=function(t){return arguments.length?(T=\"function\"==typeof t?t:o(t),S):T},S.size=function(e){return arguments.length?(t=n=0,i=+e[0],y=+e[1],S):[i-t,y-n]},S.extent=function(e){return arguments.length?(t=+e[0][0],i=+e[1][0],n=+e[0][1],y=+e[1][1],S):[[t,n],[i,y]]},S.iterations=function(t){return arguments.length?(A=+t,S):A},S},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,i)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=a,t.sankeyLinkHorizontal=function(){return n.linkHorizontal().source(y).target(x)},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3)},{\"d3-array\":152,\"d3-collection\":153,\"d3-shape\":161}],55:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\"),i=6378137;function a(t){var e=0;if(t&&t.length>0){e+=Math.abs(o(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(o(t[r]))}return e}function o(t){var e,r,n,a,o,l,c=0,u=t.length;if(u>2){for(l=0;l<u;l++)l===u-2?(n=u-2,a=u-1,o=0):l===u-1?(n=u-1,a=0,o=1):(n=l,a=l+1,o=l+2),e=t[n],r=t[a],c+=(s(t[o][0])-s(e[0]))*Math.sin(s(r[1]));c=c*i*i/2}return c}function s(t){return t*Math.PI/180}r.default=function(t){return n.geomReduce(t,function(t,e){return t+function(t){var e,r=0;switch(t.type){case\"Polygon\":return a(t.coordinates);case\"MultiPolygon\":for(e=0;e<t.coordinates.length;e++)r+=a(t.coordinates[e]);return r;case\"Point\":case\"MultiPoint\":case\"LineString\":case\"MultiLineString\":return 0}return 0}(e)},0)}},{\"@turf/meta\":58}],56:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\"),i=t(\"@turf/helpers\");r.default=function(t,e){void 0===e&&(e={});var r=0,a=0,o=0;return n.coordEach(t,function(t){r+=t[0],a+=t[1],o++}),i.point([r/o,a/o],e.properties)}},{\"@turf/helpers\":57,\"@turf/meta\":58}],57:[function(t,e,r){\"use strict\";function n(t,e,r){void 0===r&&(r={});var n={type:\"Feature\"};return(0===r.id||r.id)&&(n.id=r.id),r.bbox&&(n.bbox=r.bbox),n.properties=e||{},n.geometry=t,n}function i(t,e,r){return void 0===r&&(r={}),n({type:\"Point\",coordinates:t},e,r)}function a(t,e,r){void 0===r&&(r={});for(var i=0,a=t;i<a.length;i++){var o=a[i];if(o.length<4)throw new Error(\"Each LinearRing of a Polygon must have 4 or more Positions.\");for(var s=0;s<o[o.length-1].length;s++)if(o[o.length-1][s]!==o[0][s])throw new Error(\"First and last Position are not equivalent.\")}return n({type:\"Polygon\",coordinates:t},e,r)}function o(t,e,r){if(void 0===r&&(r={}),t.length<2)throw new Error(\"coordinates must be an array of two or more positions\");return n({type:\"LineString\",coordinates:t},e,r)}function s(t,e){void 0===e&&(e={});var r={type:\"FeatureCollection\"};return e.id&&(r.id=e.id),e.bbox&&(r.bbox=e.bbox),r.features=t,r}function l(t,e,r){return void 0===r&&(r={}),n({type:\"MultiLineString\",coordinates:t},e,r)}function c(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPoint\",coordinates:t},e,r)}function u(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPolygon\",coordinates:t},e,r)}function h(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t*n}function f(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t/n}function p(t){return 180*(t%(2*Math.PI))/Math.PI}function d(t){return!isNaN(t)&&null!==t&&!Array.isArray(t)&&!/^\\s*$/.test(t)}Object.defineProperty(r,\"__esModule\",{value:!0}),r.earthRadius=6371008.8,r.factors={centimeters:100*r.earthRadius,centimetres:100*r.earthRadius,degrees:r.earthRadius/111325,feet:3.28084*r.earthRadius,inches:39.37*r.earthRadius,kilometers:r.earthRadius/1e3,kilometres:r.earthRadius/1e3,meters:r.earthRadius,metres:r.earthRadius,miles:r.earthRadius/1609.344,millimeters:1e3*r.earthRadius,millimetres:1e3*r.earthRadius,nauticalmiles:r.earthRadius/1852,radians:1,yards:r.earthRadius/1.0936},r.unitsFactors={centimeters:100,centimetres:100,degrees:1/111325,feet:3.28084,inches:39.37,kilometers:.001,kilometres:.001,meters:1,metres:1,miles:1/1609.344,millimeters:1e3,millimetres:1e3,nauticalmiles:1/1852,radians:1/r.earthRadius,yards:1/1.0936},r.areaFactors={acres:247105e-9,centimeters:1e4,centimetres:1e4,feet:10.763910417,inches:1550.003100006,kilometers:1e-6,kilometres:1e-6,meters:1,metres:1,miles:3.86e-7,millimeters:1e6,millimetres:1e6,yards:1.195990046},r.feature=n,r.geometry=function(t,e,r){switch(void 0===r&&(r={}),t){case\"Point\":return i(e).geometry;case\"LineString\":return o(e).geometry;case\"Polygon\":return a(e).geometry;case\"MultiPoint\":return c(e).geometry;case\"MultiLineString\":return l(e).geometry;case\"MultiPolygon\":return u(e).geometry;default:throw new Error(t+\" is invalid\")}},r.point=i,r.points=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return i(t,e)}),r)},r.polygon=a,r.polygons=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return a(t,e)}),r)},r.lineString=o,r.lineStrings=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return o(t,e)}),r)},r.featureCollection=s,r.multiLineString=l,r.multiPoint=c,r.multiPolygon=u,r.geometryCollection=function(t,e,r){return void 0===r&&(r={}),n({type:\"GeometryCollection\",geometries:t},e,r)},r.round=function(t,e){if(void 0===e&&(e=0),e&&!(e>=0))throw new Error(\"precision must be a positive number\");var r=Math.pow(10,e||0);return Math.round(t*r)/r},r.radiansToLength=h,r.lengthToRadians=f,r.lengthToDegrees=function(t,e){return p(f(t,e))},r.bearingToAzimuth=function(t){var e=t%360;return e<0&&(e+=360),e},r.radiansToDegrees=p,r.degreesToRadians=function(t){return t%360*Math.PI/180},r.convertLength=function(t,e,r){if(void 0===e&&(e=\"kilometers\"),void 0===r&&(r=\"kilometers\"),!(t>=0))throw new Error(\"length must be a positive number\");return h(f(t,e),r)},r.convertArea=function(t,e,n){if(void 0===e&&(e=\"meters\"),void 0===n&&(n=\"kilometers\"),!(t>=0))throw new Error(\"area must be a positive number\");var i=r.areaFactors[e];if(!i)throw new Error(\"invalid original units\");var a=r.areaFactors[n];if(!a)throw new Error(\"invalid final units\");return t/i*a},r.isNumber=d,r.isObject=function(t){return!!t&&t.constructor===Object},r.validateBBox=function(t){if(!t)throw new Error(\"bbox is required\");if(!Array.isArray(t))throw new Error(\"bbox must be an Array\");if(4!==t.length&&6!==t.length)throw new Error(\"bbox must be an Array of 4 or 6 numbers\");t.forEach(function(t){if(!d(t))throw new Error(\"bbox must only contain numbers\")})},r.validateId=function(t){if(!t)throw new Error(\"id is required\");if(-1===[\"string\",\"number\"].indexOf(typeof t))throw new Error(\"id must be a number or a string\")},r.radians2degrees=function(){throw new Error(\"method has been renamed to `radiansToDegrees`\")},r.degrees2radians=function(){throw new Error(\"method has been renamed to `degreesToRadians`\")},r.distanceToDegrees=function(){throw new Error(\"method has been renamed to `lengthToDegrees`\")},r.distanceToRadians=function(){throw new Error(\"method has been renamed to `lengthToRadians`\")},r.radiansToDistance=function(){throw new Error(\"method has been renamed to `radiansToLength`\")},r.bearingToAngle=function(){throw new Error(\"method has been renamed to `bearingToAzimuth`\")},r.convertDistance=function(){throw new Error(\"method has been renamed to `convertLength`\")}},{}],58:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/helpers\");function i(t,e,r){if(null!==t)for(var n,a,o,s,l,c,u,h,f=0,p=0,d=t.type,g=\"FeatureCollection\"===d,v=\"Feature\"===d,m=g?t.features.length:1,y=0;y<m;y++){l=(h=!!(u=g?t.features[y].geometry:v?t.geometry:t)&&\"GeometryCollection\"===u.type)?u.geometries.length:1;for(var x=0;x<l;x++){var b=0,_=0;if(null!==(s=h?u.geometries[x]:u)){c=s.coordinates;var w=s.type;switch(f=!r||\"Polygon\"!==w&&\"MultiPolygon\"!==w?0:1,w){case null:break;case\"Point\":if(!1===e(c,p,y,b,_))return!1;p++,b++;break;case\"LineString\":case\"MultiPoint\":for(n=0;n<c.length;n++){if(!1===e(c[n],p,y,b,_))return!1;p++,\"MultiPoint\"===w&&b++}\"LineString\"===w&&b++;break;case\"Polygon\":case\"MultiLineString\":for(n=0;n<c.length;n++){for(a=0;a<c[n].length-f;a++){if(!1===e(c[n][a],p,y,b,_))return!1;p++}\"MultiLineString\"===w&&b++,\"Polygon\"===w&&_++}\"Polygon\"===w&&b++;break;case\"MultiPolygon\":for(n=0;n<c.length;n++){for(_=0,a=0;a<c[n].length;a++){for(o=0;o<c[n][a].length-f;o++){if(!1===e(c[n][a][o],p,y,b,_))return!1;p++}_++}b++}break;case\"GeometryCollection\":for(n=0;n<s.geometries.length;n++)if(!1===i(s.geometries[n],e,r))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}}}}}function a(t,e){var r;switch(t.type){case\"FeatureCollection\":for(r=0;r<t.features.length&&!1!==e(t.features[r].properties,r);r++);break;case\"Feature\":e(t.properties,0)}}function o(t,e){if(\"Feature\"===t.type)e(t,0);else if(\"FeatureCollection\"===t.type)for(var r=0;r<t.features.length&&!1!==e(t.features[r],r);r++);}function s(t,e){var r,n,i,a,o,s,l,c,u,h,f=0,p=\"FeatureCollection\"===t.type,d=\"Feature\"===t.type,g=p?t.features.length:1;for(r=0;r<g;r++){for(s=p?t.features[r].geometry:d?t.geometry:t,c=p?t.features[r].properties:d?t.properties:{},u=p?t.features[r].bbox:d?t.bbox:void 0,h=p?t.features[r].id:d?t.id:void 0,o=(l=!!s&&\"GeometryCollection\"===s.type)?s.geometries.length:1,i=0;i<o;i++)if(null!==(a=l?s.geometries[i]:s))switch(a.type){case\"Point\":case\"LineString\":case\"MultiPoint\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":if(!1===e(a,f,c,u,h))return!1;break;case\"GeometryCollection\":for(n=0;n<a.geometries.length;n++)if(!1===e(a.geometries[n],f,c,u,h))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}else if(!1===e(null,f,c,u,h))return!1;f++}}function l(t,e){s(t,function(t,r,i,a,o){var s,l=null===t?null:t.type;switch(l){case null:case\"Point\":case\"LineString\":case\"Polygon\":return!1!==e(n.feature(t,i,{bbox:a,id:o}),r,0)&&void 0}switch(l){case\"MultiPoint\":s=\"Point\";break;case\"MultiLineString\":s=\"LineString\";break;case\"MultiPolygon\":s=\"Polygon\"}for(var c=0;c<t.coordinates.length;c++){var u={type:s,coordinates:t.coordinates[c]};if(!1===e(n.feature(u,i),r,c))return!1}})}function c(t,e){l(t,function(t,r,a){var o=0;if(t.geometry){var s=t.geometry.type;if(\"Point\"!==s&&\"MultiPoint\"!==s){var l,c=0,u=0,h=0;return!1!==i(t,function(i,s,f,p,d){if(void 0===l||r>c||p>u||d>h)return l=i,c=r,u=p,h=d,void(o=0);var g=n.lineString([l,i],t.properties);if(!1===e(g,r,a,d,o))return!1;o++,l=i})&&void 0}}})}function u(t,e){if(!t)throw new Error(\"geojson is required\");l(t,function(t,r,i){if(null!==t.geometry){var a=t.geometry.type,o=t.geometry.coordinates;switch(a){case\"LineString\":if(!1===e(t,r,i,0,0))return!1;break;case\"Polygon\":for(var s=0;s<o.length;s++)if(!1===e(n.lineString(o[s],t.properties),r,i,s))return!1}}})}r.coordEach=i,r.coordReduce=function(t,e,r,n){var a=r;return i(t,function(t,n,i,o,s){a=0===n&&void 0===r?t:e(a,t,n,i,o,s)},n),a},r.propEach=a,r.propReduce=function(t,e,r){var n=r;return a(t,function(t,i){n=0===i&&void 0===r?t:e(n,t,i)}),n},r.featureEach=o,r.featureReduce=function(t,e,r){var n=r;return o(t,function(t,i){n=0===i&&void 0===r?t:e(n,t,i)}),n},r.coordAll=function(t){var e=[];return i(t,function(t){e.push(t)}),e},r.geomEach=s,r.geomReduce=function(t,e,r){var n=r;return s(t,function(t,i,a,o,s){n=0===i&&void 0===r?t:e(n,t,i,a,o,s)}),n},r.flattenEach=l,r.flattenReduce=function(t,e,r){var n=r;return l(t,function(t,i,a){n=0===i&&0===a&&void 0===r?t:e(n,t,i,a)}),n},r.segmentEach=c,r.segmentReduce=function(t,e,r){var n=r,i=!1;return c(t,function(t,a,o,s,l){n=!1===i&&void 0===r?t:e(n,t,a,o,s,l),i=!0}),n},r.lineEach=u,r.lineReduce=function(t,e,r){var n=r;return u(t,function(t,i,a,o){n=0===i&&void 0===r?t:e(n,t,i,a,o)}),n},r.findSegment=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.segmentIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":case\"MultiPoint\":return null;case\"LineString\":return s<0&&(s=c.length+s-1),n.lineString([c[s],c[s+1]],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s-1),n.lineString([c[o][s],c[o][s+1]],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s-1),n.lineString([c[a][s],c[a][s+1]],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s-1),n.lineString([c[a][o][s],c[a][o][s+1]],l,e)}throw new Error(\"geojson is invalid\")},r.findPoint=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.coordIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":return n.point(c,l,e);case\"MultiPoint\":return a<0&&(a=c.length+a),n.point(c[a],l,e);case\"LineString\":return s<0&&(s=c.length+s),n.point(c[s],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s),n.point(c[o][s],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s),n.point(c[a][s],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s),n.point(c[a][o][s],l,e)}throw new Error(\"geojson is invalid\")}},{\"@turf/helpers\":57}],59:[function(t,e,r){\"use strict\";var n=\"undefined\"==typeof WeakMap?t(\"weak-map\"):WeakMap,i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=new n;e.exports=function(t){var e=o.get(t),r=e&&(e._triangleBuffer.handle||e._triangleBuffer.buffer);if(!r||!t.isBuffer(r)){var n=i(t,new Float32Array([-1,-1,-1,4,4,-1]));(e=a(t,[{buffer:n,type:t.FLOAT,size:2}]))._triangleBuffer=n,o.set(t,e)}e.bind(),t.drawArrays(t.TRIANGLES,0,3),e.unbind()}},{\"gl-buffer\":241,\"gl-vao\":327,\"weak-map\":552}],60:[function(t,e,r){e.exports=function(t){var e=0,r=0,n=0,i=0;return t.map(function(t){var a=(t=t.slice())[0],o=a.toUpperCase();if(a!=o)switch(t[0]=o,a){case\"a\":t[6]+=n,t[7]+=i;break;case\"v\":t[1]+=i;break;case\"h\":t[1]+=n;break;default:for(var s=1;s<t.length;)t[s++]+=n,t[s++]+=i}switch(o){case\"Z\":n=e,i=r;break;case\"H\":n=t[1];break;case\"V\":i=t[1];break;case\"M\":n=e=t[1],i=r=t[2];break;default:n=t[t.length-2],i=t[t.length-1]}return t})}},{}],61:[function(t,e,r){var n=t(\"pad-left\");e.exports=function(t,e,r){e=\"number\"==typeof e?e:1,r=r||\": \";var i=t.split(/\\r?\\n/),a=String(i.length+e-1).length;return i.map(function(t,i){var o=i+e,s=String(o).length,l=n(o,a-s);return l+r+t}).join(\"\\n\")}},{\"pad-left\":457}],62:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[0];for(var r=t[0].length,n=[t[0]],a=[0],o=1;o<e;++o)if(n.push(t[o]),i(n,r)){if(a.push(o),a.length===r+1)return a}else n.pop();return a};var n=t(\"robust-orientation\");function i(t,e){for(var r=new Array(e+1),i=0;i<t.length;++i)r[i]=t[i];for(i=0;i<=t.length;++i){for(var a=t.length;a<=e;++a){for(var o=new Array(e),s=0;s<e;++s)o[s]=Math.pow(a+1-i,s);r[a]=o}if(n.apply(void 0,r))return!0}return!1}},{\"robust-orientation\":510}],63:[function(t,e,r){\"use strict\";e.exports=function(t,e){return n(e).filter(function(r){for(var n=new Array(r.length),a=0;a<r.length;++a)n[a]=e[r[a]];return i(n)*t<1})};var n=t(\"delaunay-triangulate\"),i=t(\"circumradius\")},{circumradius:114,\"delaunay-triangulate\":165}],64:[function(t,e,r){e.exports=function(t,e){return i(n(t,e))};var n=t(\"alpha-complex\"),i=t(\"simplicial-complex-boundary\")},{\"alpha-complex\":63,\"simplicial-complex-boundary\":517}],65:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(!t||null==t.length)throw Error(\"Argument should be an array\");e=null==e?1:Math.floor(e);for(var r=Array(2*e),n=0;n<e;n++){for(var i=-1/0,a=1/0,o=n,s=t.length;o<s;o+=e)t[o]>i&&(i=t[o]),t[o]<a&&(a=t[o]);r[n]=a,r[e+n]=i}return r}},{}],66:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\");e.exports=function(t,e,r){if(!t||null==t.length)throw Error(\"Argument should be an array\");null==e&&(e=1);null==r&&(r=n(t,e));for(var i=0;i<e;i++){var a=r[e+i],o=r[i],s=i,l=t.length;if(a===1/0&&o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:t[s]===o?0:.5;else if(a===1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:0;else if(o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===o?0:1;else{var c=a-o;for(s=i;s<l;s+=e)t[s]=0===c?.5:(t[s]-o)/c}}return t}},{\"array-bounds\":65}],67:[function(t,e,r){e.exports=function(t,e){var r=\"number\"==typeof t,n=\"number\"==typeof e;r&&!n?(e=t,t=0):r||n||(t=0,e=0);var i=(e|=0)-(t|=0);if(i<0)throw new Error(\"array length must be positive\");for(var a=new Array(i),o=0,s=t;o<i;o++,s++)a[o]=s;return a}},{}],68:[function(t,e,r){(function(r){\"use strict\";var n=t(\"object-assign\");function i(t,e){if(t===e)return 0;for(var r=t.length,n=e.length,i=0,a=Math.min(r,n);i<a;++i)if(t[i]!==e[i]){r=t[i],n=e[i];break}return r<n?-1:n<r?1:0}function a(t){return r.Buffer&&\"function\"==typeof r.Buffer.isBuffer?r.Buffer.isBuffer(t):!(null==t||!t._isBuffer)}var o=t(\"util/\"),s=Object.prototype.hasOwnProperty,l=Array.prototype.slice,c=\"foo\"===function(){}.name;function u(t){return Object.prototype.toString.call(t)}function h(t){return!a(t)&&(\"function\"==typeof r.ArrayBuffer&&(\"function\"==typeof ArrayBuffer.isView?ArrayBuffer.isView(t):!!t&&(t instanceof DataView||!!(t.buffer&&t.buffer instanceof ArrayBuffer))))}var f=e.exports=y,p=/\\s*function\\s+([^\\(\\s]*)\\s*/;function d(t){if(o.isFunction(t)){if(c)return t.name;var e=t.toString().match(p);return e&&e[1]}}function g(t,e){return\"string\"==typeof t?t.length<e?t:t.slice(0,e):t}function v(t){if(c||!o.isFunction(t))return o.inspect(t);var e=d(t);return\"[Function\"+(e?\": \"+e:\"\")+\"]\"}function m(t,e,r,n,i){throw new f.AssertionError({message:r,actual:t,expected:e,operator:n,stackStartFunction:i})}function y(t,e){t||m(t,!0,e,\"==\",f.ok)}function x(t,e,r,n){if(t===e)return!0;if(a(t)&&a(e))return 0===i(t,e);if(o.isDate(t)&&o.isDate(e))return t.getTime()===e.getTime();if(o.isRegExp(t)&&o.isRegExp(e))return t.source===e.source&&t.global===e.global&&t.multiline===e.multiline&&t.lastIndex===e.lastIndex&&t.ignoreCase===e.ignoreCase;if(null!==t&&\"object\"==typeof t||null!==e&&\"object\"==typeof e){if(h(t)&&h(e)&&u(t)===u(e)&&!(t instanceof Float32Array||t instanceof Float64Array))return 0===i(new Uint8Array(t.buffer),new Uint8Array(e.buffer));if(a(t)!==a(e))return!1;var s=(n=n||{actual:[],expected:[]}).actual.indexOf(t);return-1!==s&&s===n.expected.indexOf(e)||(n.actual.push(t),n.expected.push(e),function(t,e,r,n){if(null==t||null==e)return!1;if(o.isPrimitive(t)||o.isPrimitive(e))return t===e;if(r&&Object.getPrototypeOf(t)!==Object.getPrototypeOf(e))return!1;var i=b(t),a=b(e);if(i&&!a||!i&&a)return!1;if(i)return t=l.call(t),e=l.call(e),x(t,e,r);var s,c,u=k(t),h=k(e);if(u.length!==h.length)return!1;for(u.sort(),h.sort(),c=u.length-1;c>=0;c--)if(u[c]!==h[c])return!1;for(c=u.length-1;c>=0;c--)if(s=u[c],!x(t[s],e[s],r,n))return!1;return!0}(t,e,r,n))}return r?t===e:t==e}function b(t){return\"[object Arguments]\"==Object.prototype.toString.call(t)}function _(t,e){if(!t||!e)return!1;if(\"[object RegExp]\"==Object.prototype.toString.call(e))return e.test(t);try{if(t instanceof e)return!0}catch(t){}return!Error.isPrototypeOf(e)&&!0===e.call({},t)}function w(t,e,r,n){var i;if(\"function\"!=typeof e)throw new TypeError('\"block\" argument must be a function');\"string\"==typeof r&&(n=r,r=null),i=function(t){var e;try{t()}catch(t){e=t}return e}(e),n=(r&&r.name?\" (\"+r.name+\").\":\".\")+(n?\" \"+n:\".\"),t&&!i&&m(i,r,\"Missing expected exception\"+n);var a=\"string\"==typeof n,s=!t&&i&&!r;if((!t&&o.isError(i)&&a&&_(i,r)||s)&&m(i,r,\"Got unwanted exception\"+n),t&&i&&r&&!_(i,r)||!t&&i)throw i}f.AssertionError=function(t){var e;this.name=\"AssertionError\",this.actual=t.actual,this.expected=t.expected,this.operator=t.operator,t.message?(this.message=t.message,this.generatedMessage=!1):(this.message=g(v((e=this).actual),128)+\" \"+e.operator+\" \"+g(v(e.expected),128),this.generatedMessage=!0);var r=t.stackStartFunction||m;if(Error.captureStackTrace)Error.captureStackTrace(this,r);else{var n=new Error;if(n.stack){var i=n.stack,a=d(r),o=i.indexOf(\"\\n\"+a);if(o>=0){var s=i.indexOf(\"\\n\",o+1);i=i.substring(s+1)}this.stack=i}}},o.inherits(f.AssertionError,Error),f.fail=m,f.ok=y,f.equal=function(t,e,r){t!=e&&m(t,e,r,\"==\",f.equal)},f.notEqual=function(t,e,r){t==e&&m(t,e,r,\"!=\",f.notEqual)},f.deepEqual=function(t,e,r){x(t,e,!1)||m(t,e,r,\"deepEqual\",f.deepEqual)},f.deepStrictEqual=function(t,e,r){x(t,e,!0)||m(t,e,r,\"deepStrictEqual\",f.deepStrictEqual)},f.notDeepEqual=function(t,e,r){x(t,e,!1)&&m(t,e,r,\"notDeepEqual\",f.notDeepEqual)},f.notDeepStrictEqual=function t(e,r,n){x(e,r,!0)&&m(e,r,n,\"notDeepStrictEqual\",t)},f.strictEqual=function(t,e,r){t!==e&&m(t,e,r,\"===\",f.strictEqual)},f.notStrictEqual=function(t,e,r){t===e&&m(t,e,r,\"!==\",f.notStrictEqual)},f.throws=function(t,e,r){w(!0,t,e,r)},f.doesNotThrow=function(t,e,r){w(!1,t,e,r)},f.ifError=function(t){if(t)throw t},f.strict=n(function t(e,r){e||m(e,!0,r,\"==\",t)},f,{equal:f.strictEqual,deepEqual:f.deepStrictEqual,notEqual:f.notStrictEqual,notDeepEqual:f.notDeepStrictEqual}),f.strict.strict=f.strict;var k=Object.keys||function(t){var e=[];for(var r in t)s.call(t,r)&&e.push(r);return e}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"object-assign\":454,\"util/\":71}],69:[function(t,e,r){\"function\"==typeof Object.create?e.exports=function(t,e){t.super_=e,t.prototype=Object.create(e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}})}:e.exports=function(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}},{}],70:[function(t,e,r){e.exports=function(t){return t&&\"object\"==typeof t&&\"function\"==typeof t.copy&&\"function\"==typeof t.fill&&\"function\"==typeof t.readUInt8}},{}],71:[function(t,e,r){(function(e,n){var i=/%[sdj%]/g;r.format=function(t){if(!m(t)){for(var e=[],r=0;r<arguments.length;r++)e.push(s(arguments[r]));return e.join(\" \")}r=1;for(var n=arguments,a=n.length,o=String(t).replace(i,function(t){if(\"%%\"===t)return\"%\";if(r>=a)return t;switch(t){case\"%s\":return String(n[r++]);case\"%d\":return Number(n[r++]);case\"%j\":try{return JSON.stringify(n[r++])}catch(t){return\"[Circular]\"}default:return t}}),l=n[r];r<a;l=n[++r])g(l)||!b(l)?o+=\" \"+l:o+=\" \"+s(l);return o},r.deprecate=function(t,i){if(y(n.process))return function(){return r.deprecate(t,i).apply(this,arguments)};if(!0===e.noDeprecation)return t;var a=!1;return function(){if(!a){if(e.throwDeprecation)throw new Error(i);e.traceDeprecation?console.trace(i):console.error(i),a=!0}return t.apply(this,arguments)}};var a,o={};function s(t,e){var n={seen:[],stylize:c};return arguments.length>=3&&(n.depth=arguments[2]),arguments.length>=4&&(n.colors=arguments[3]),d(e)?n.showHidden=e:e&&r._extend(n,e),y(n.showHidden)&&(n.showHidden=!1),y(n.depth)&&(n.depth=2),y(n.colors)&&(n.colors=!1),y(n.customInspect)&&(n.customInspect=!0),n.colors&&(n.stylize=l),u(n,t,n.depth)}function l(t,e){var r=s.styles[e];return r?\"\\x1b[\"+s.colors[r][0]+\"m\"+t+\"\\x1b[\"+s.colors[r][1]+\"m\":t}function c(t,e){return t}function u(t,e,n){if(t.customInspect&&e&&k(e.inspect)&&e.inspect!==r.inspect&&(!e.constructor||e.constructor.prototype!==e)){var i=e.inspect(n,t);return m(i)||(i=u(t,i,n)),i}var a=function(t,e){if(y(e))return t.stylize(\"undefined\",\"undefined\");if(m(e)){var r=\"'\"+JSON.stringify(e).replace(/^\"|\"$/g,\"\").replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"')+\"'\";return t.stylize(r,\"string\")}if(v(e))return t.stylize(\"\"+e,\"number\");if(d(e))return t.stylize(\"\"+e,\"boolean\");if(g(e))return t.stylize(\"null\",\"null\")}(t,e);if(a)return a;var o=Object.keys(e),s=function(t){var e={};return t.forEach(function(t,r){e[t]=!0}),e}(o);if(t.showHidden&&(o=Object.getOwnPropertyNames(e)),w(e)&&(o.indexOf(\"message\")>=0||o.indexOf(\"description\")>=0))return h(e);if(0===o.length){if(k(e)){var l=e.name?\": \"+e.name:\"\";return t.stylize(\"[Function\"+l+\"]\",\"special\")}if(x(e))return t.stylize(RegExp.prototype.toString.call(e),\"regexp\");if(_(e))return t.stylize(Date.prototype.toString.call(e),\"date\");if(w(e))return h(e)}var c,b=\"\",T=!1,A=[\"{\",\"}\"];(p(e)&&(T=!0,A=[\"[\",\"]\"]),k(e))&&(b=\" [Function\"+(e.name?\": \"+e.name:\"\")+\"]\");return x(e)&&(b=\" \"+RegExp.prototype.toString.call(e)),_(e)&&(b=\" \"+Date.prototype.toUTCString.call(e)),w(e)&&(b=\" \"+h(e)),0!==o.length||T&&0!=e.length?n<0?x(e)?t.stylize(RegExp.prototype.toString.call(e),\"regexp\"):t.stylize(\"[Object]\",\"special\"):(t.seen.push(e),c=T?function(t,e,r,n,i){for(var a=[],o=0,s=e.length;o<s;++o)S(e,String(o))?a.push(f(t,e,r,n,String(o),!0)):a.push(\"\");return i.forEach(function(i){i.match(/^\\d+$/)||a.push(f(t,e,r,n,i,!0))}),a}(t,e,n,s,o):o.map(function(r){return f(t,e,n,s,r,T)}),t.seen.pop(),function(t,e,r){if(t.reduce(function(t,e){return 0,e.indexOf(\"\\n\")>=0&&0,t+e.replace(/\\u001b\\[\\d\\d?m/g,\"\").length+1},0)>60)return r[0]+(\"\"===e?\"\":e+\"\\n \")+\" \"+t.join(\",\\n  \")+\" \"+r[1];return r[0]+e+\" \"+t.join(\", \")+\" \"+r[1]}(c,b,A)):A[0]+b+A[1]}function h(t){return\"[\"+Error.prototype.toString.call(t)+\"]\"}function f(t,e,r,n,i,a){var o,s,l;if((l=Object.getOwnPropertyDescriptor(e,i)||{value:e[i]}).get?s=l.set?t.stylize(\"[Getter/Setter]\",\"special\"):t.stylize(\"[Getter]\",\"special\"):l.set&&(s=t.stylize(\"[Setter]\",\"special\")),S(n,i)||(o=\"[\"+i+\"]\"),s||(t.seen.indexOf(l.value)<0?(s=g(r)?u(t,l.value,null):u(t,l.value,r-1)).indexOf(\"\\n\")>-1&&(s=a?s.split(\"\\n\").map(function(t){return\"  \"+t}).join(\"\\n\").substr(2):\"\\n\"+s.split(\"\\n\").map(function(t){return\"   \"+t}).join(\"\\n\")):s=t.stylize(\"[Circular]\",\"special\")),y(o)){if(a&&i.match(/^\\d+$/))return s;(o=JSON.stringify(\"\"+i)).match(/^\"([a-zA-Z_][a-zA-Z_0-9]*)\"$/)?(o=o.substr(1,o.length-2),o=t.stylize(o,\"name\")):(o=o.replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"').replace(/(^\"|\"$)/g,\"'\"),o=t.stylize(o,\"string\"))}return o+\": \"+s}function p(t){return Array.isArray(t)}function d(t){return\"boolean\"==typeof t}function g(t){return null===t}function v(t){return\"number\"==typeof t}function m(t){return\"string\"==typeof t}function y(t){return void 0===t}function x(t){return b(t)&&\"[object RegExp]\"===T(t)}function b(t){return\"object\"==typeof t&&null!==t}function _(t){return b(t)&&\"[object Date]\"===T(t)}function w(t){return b(t)&&(\"[object Error]\"===T(t)||t instanceof Error)}function k(t){return\"function\"==typeof t}function T(t){return Object.prototype.toString.call(t)}function A(t){return t<10?\"0\"+t.toString(10):t.toString(10)}r.debuglog=function(t){if(y(a)&&(a=e.env.NODE_DEBUG||\"\"),t=t.toUpperCase(),!o[t])if(new RegExp(\"\\\\b\"+t+\"\\\\b\",\"i\").test(a)){var n=e.pid;o[t]=function(){var e=r.format.apply(r,arguments);console.error(\"%s %d: %s\",t,n,e)}}else o[t]=function(){};return o[t]},r.inspect=s,s.colors={bold:[1,22],italic:[3,23],underline:[4,24],inverse:[7,27],white:[37,39],grey:[90,39],black:[30,39],blue:[34,39],cyan:[36,39],green:[32,39],magenta:[35,39],red:[31,39],yellow:[33,39]},s.styles={special:\"cyan\",number:\"yellow\",boolean:\"yellow\",undefined:\"grey\",null:\"bold\",string:\"green\",date:\"magenta\",regexp:\"red\"},r.isArray=p,r.isBoolean=d,r.isNull=g,r.isNullOrUndefined=function(t){return null==t},r.isNumber=v,r.isString=m,r.isSymbol=function(t){return\"symbol\"==typeof t},r.isUndefined=y,r.isRegExp=x,r.isObject=b,r.isDate=_,r.isError=w,r.isFunction=k,r.isPrimitive=function(t){return null===t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||\"symbol\"==typeof t||\"undefined\"==typeof t},r.isBuffer=t(\"./support/isBuffer\");var M=[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"];function S(t,e){return Object.prototype.hasOwnProperty.call(t,e)}r.log=function(){var t,e;console.log(\"%s - %s\",(t=new Date,e=[A(t.getHours()),A(t.getMinutes()),A(t.getSeconds())].join(\":\"),[t.getDate(),M[t.getMonth()],e].join(\" \")),r.format.apply(r,arguments))},r.inherits=t(\"inherits\"),r._extend=function(t,e){if(!e||!b(e))return t;for(var r=Object.keys(e),n=r.length;n--;)t[r[n]]=e[r[n]];return t}}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./support/isBuffer\":70,_process:482,inherits:69}],72:[function(t,e,r){e.exports=function(t){return atob(t)}},{}],73:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=e.length,a=new Array(r+1),o=0;o<r;++o){for(var s=new Array(r+1),l=0;l<=r;++l)s[l]=t[l][o];a[o]=s}a[r]=new Array(r+1);for(var o=0;o<=r;++o)a[r][o]=1;for(var c=new Array(r+1),o=0;o<r;++o)c[o]=e[o];c[r]=1;var u=n(a,c),h=i(u[r+1]);0===h&&(h=1);for(var f=new Array(r+1),o=0;o<=r;++o)f[o]=i(u[o])/h;return f};var n=t(\"robust-linear-solve\");function i(t){for(var e=0,r=0;r<t.length;++r)e+=t[r];return e}},{\"robust-linear-solve\":509}],74:[function(t,e,r){\"use strict\";r.byteLength=function(t){var e=c(t),r=e[0],n=e[1];return 3*(r+n)/4-n},r.toByteArray=function(t){for(var e,r=c(t),n=r[0],o=r[1],s=new a(function(t,e,r){return 3*(e+r)/4-r}(0,n,o)),l=0,u=o>0?n-4:n,h=0;h<u;h+=4)e=i[t.charCodeAt(h)]<<18|i[t.charCodeAt(h+1)]<<12|i[t.charCodeAt(h+2)]<<6|i[t.charCodeAt(h+3)],s[l++]=e>>16&255,s[l++]=e>>8&255,s[l++]=255&e;2===o&&(e=i[t.charCodeAt(h)]<<2|i[t.charCodeAt(h+1)]>>4,s[l++]=255&e);1===o&&(e=i[t.charCodeAt(h)]<<10|i[t.charCodeAt(h+1)]<<4|i[t.charCodeAt(h+2)]>>2,s[l++]=e>>8&255,s[l++]=255&e);return s},r.fromByteArray=function(t){for(var e,r=t.length,i=r%3,a=[],o=0,s=r-i;o<s;o+=16383)a.push(u(t,o,o+16383>s?s:o+16383));1===i?(e=t[r-1],a.push(n[e>>2]+n[e<<4&63]+\"==\")):2===i&&(e=(t[r-2]<<8)+t[r-1],a.push(n[e>>10]+n[e>>4&63]+n[e<<2&63]+\"=\"));return a.join(\"\")};for(var n=[],i=[],a=\"undefined\"!=typeof Uint8Array?Uint8Array:Array,o=\"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/\",s=0,l=o.length;s<l;++s)n[s]=o[s],i[o.charCodeAt(s)]=s;function c(t){var e=t.length;if(e%4>0)throw new Error(\"Invalid string. Length must be a multiple of 4\");var r=t.indexOf(\"=\");return-1===r&&(r=e),[r,r===e?0:4-r%4]}function u(t,e,r){for(var i,a,o=[],s=e;s<r;s+=3)i=(t[s]<<16&16711680)+(t[s+1]<<8&65280)+(255&t[s+2]),o.push(n[(a=i)>>18&63]+n[a>>12&63]+n[a>>6&63]+n[63&a]);return o.join(\"\")}i[\"-\".charCodeAt(0)]=62,i[\"_\".charCodeAt(0)]=63},{}],75:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).add(e[0].mul(t[1])),t[1].mul(e[1]))}},{\"./lib/rationalize\":85}],76:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t[0].mul(e[1]).cmp(e[0].mul(t[1]))}},{}],77:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]),t[1].mul(e[0]))}},{\"./lib/rationalize\":85}],78:[function(t,e,r){\"use strict\";var n=t(\"./is-rat\"),i=t(\"./lib/is-bn\"),a=t(\"./lib/num-to-bn\"),o=t(\"./lib/str-to-bn\"),s=t(\"./lib/rationalize\"),l=t(\"./div\");e.exports=function t(e,r){if(n(e))return r?l(e,t(r)):[e[0].clone(),e[1].clone()];var c=0;var u,h;if(i(e))u=e.clone();else if(\"string\"==typeof e)u=o(e);else{if(0===e)return[a(0),a(1)];if(e===Math.floor(e))u=a(e);else{for(;e!==Math.floor(e);)e*=Math.pow(2,256),c-=256;u=a(e)}}if(n(r))u.mul(r[1]),h=r[0].clone();else if(i(r))h=r.clone();else if(\"string\"==typeof r)h=o(r);else if(r)if(r===Math.floor(r))h=a(r);else{for(;r!==Math.floor(r);)r*=Math.pow(2,256),c+=256;h=a(r)}else h=a(1);c>0?u=u.ushln(c):c<0&&(h=h.ushln(-c));return s(u,h)}},{\"./div\":77,\"./is-rat\":79,\"./lib/is-bn\":83,\"./lib/num-to-bn\":84,\"./lib/rationalize\":85,\"./lib/str-to-bn\":86}],79:[function(t,e,r){\"use strict\";var n=t(\"./lib/is-bn\");e.exports=function(t){return Array.isArray(t)&&2===t.length&&n(t[0])&&n(t[1])}},{\"./lib/is-bn\":83}],80:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return t.cmp(new n(0))}},{\"bn.js\":94}],81:[function(t,e,r){\"use strict\";var n=t(\"./bn-sign\");e.exports=function(t){var e=t.length,r=t.words,i=0;if(1===e)i=r[0];else if(2===e)i=r[0]+67108864*r[1];else for(var a=0;a<e;a++){var o=r[a];i+=o*Math.pow(67108864,a)}return n(t)*i}},{\"./bn-sign\":80}],82:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=t(\"bit-twiddle\").countTrailingZeros;e.exports=function(t){var e=i(n.lo(t));if(e<32)return e;var r=i(n.hi(t));if(r>20)return 52;return r+32}},{\"bit-twiddle\":92,\"double-bits\":167}],83:[function(t,e,r){\"use strict\";t(\"bn.js\");e.exports=function(t){return t&&\"object\"==typeof t&&Boolean(t.words)}},{\"bn.js\":94}],84:[function(t,e,r){\"use strict\";var n=t(\"bn.js\"),i=t(\"double-bits\");e.exports=function(t){var e=i.exponent(t);return e<52?new n(t):new n(t*Math.pow(2,52-e)).ushln(e-52)}},{\"bn.js\":94,\"double-bits\":167}],85:[function(t,e,r){\"use strict\";var n=t(\"./num-to-bn\"),i=t(\"./bn-sign\");e.exports=function(t,e){var r=i(t),a=i(e);if(0===r)return[n(0),n(1)];if(0===a)return[n(0),n(0)];a<0&&(t=t.neg(),e=e.neg());var o=t.gcd(e);if(o.cmpn(1))return[t.div(o),e.div(o)];return[t,e]}},{\"./bn-sign\":80,\"./num-to-bn\":84}],86:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return new n(t)}},{\"bn.js\":94}],87:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[0]),t[1].mul(e[1]))}},{\"./lib/rationalize\":85}],88:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-sign\");e.exports=function(t){return n(t[0])*n(t[1])}},{\"./lib/bn-sign\":80}],89:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).sub(t[1].mul(e[0])),t[1].mul(e[1]))}},{\"./lib/rationalize\":85}],90:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-to-num\"),i=t(\"./lib/ctz\");e.exports=function(t){var e=t[0],r=t[1];if(0===e.cmpn(0))return 0;var a=e.abs().divmod(r.abs()),o=a.div,s=n(o),l=a.mod,c=e.negative!==r.negative?-1:1;if(0===l.cmpn(0))return c*s;if(s){var u=i(s)+4,h=n(l.ushln(u).divRound(r));return c*(s+h*Math.pow(2,-u))}var f=r.bitLength()-l.bitLength()+53,h=n(l.ushln(f).divRound(r));return f<1023?c*h*Math.pow(2,-f):(h*=Math.pow(2,-1023),c*h*Math.pow(2,1023-f))}},{\"./lib/bn-to-num\":81,\"./lib/ctz\":82}],91:[function(t,e,r){\"use strict\";function n(t,e,r,n,i,a){var o=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",a?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a\",i?\".get(m)\":\"[m]\"];return a?e.indexOf(\"c\")<0?o.push(\";if(x===y){return m}else if(x<=y){\"):o.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):o.push(\";if(\",e,\"){i=m;\"),r?o.push(\"l=m+1}else{h=m-1}\"):o.push(\"h=m-1}else{l=m+1}\"),o.push(\"}\"),a?o.push(\"return -1};\"):o.push(\"return i};\"),o.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],!1,i),n(\"B\",\"x\"+t+\"y\",e,[\"y\"],!0,i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!1,i),n(\"Q\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!0,i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(a.shape){if(typeof(c)==='function'){return Q(a,(l===undefined)?0:l|0,(h===undefined)?a.shape[0]-1:h|0,y,c)}else{return B(a,(c===undefined)?0:c|0,(l===undefined)?a.shape[0]-1:l|0,y)}}else{if(typeof(c)==='function'){return P(a,(l===undefined)?0:l|0,(h===undefined)?a.length-1:h|0,y,c)}else{return A(a,(c===undefined)?0:c|0,(l===undefined)?a.length-1:l|0,y)}}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],92:[function(t,e,r){\"use strict\";function n(t){var e=32;return(t&=-t)&&e--,65535&t&&(e-=16),16711935&t&&(e-=8),252645135&t&&(e-=4),858993459&t&&(e-=2),1431655765&t&&(e-=1),e}r.INT_BITS=32,r.INT_MAX=2147483647,r.INT_MIN=-1<<31,r.sign=function(t){return(t>0)-(t<0)},r.abs=function(t){var e=t>>31;return(t^e)-e},r.min=function(t,e){return e^(t^e)&-(t<e)},r.max=function(t,e){return t^(t^e)&-(t<e)},r.isPow2=function(t){return!(t&t-1||!t)},r.log2=function(t){var e,r;return e=(t>65535)<<4,e|=r=((t>>>=e)>255)<<3,e|=r=((t>>>=r)>15)<<2,(e|=r=((t>>>=r)>3)<<1)|(t>>>=r)>>1},r.log10=function(t){return t>=1e9?9:t>=1e8?8:t>=1e7?7:t>=1e6?6:t>=1e5?5:t>=1e4?4:t>=1e3?3:t>=100?2:t>=10?1:0},r.popCount=function(t){return 16843009*((t=(858993459&(t-=t>>>1&1431655765))+(t>>>2&858993459))+(t>>>4)&252645135)>>>24},r.countTrailingZeros=n,r.nextPow2=function(t){return t+=0===t,--t,t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)+1},r.prevPow2=function(t){return t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)-(t>>>1)},r.parity=function(t){return t^=t>>>16,t^=t>>>8,t^=t>>>4,27030>>>(t&=15)&1};var i=new Array(256);!function(t){for(var e=0;e<256;++e){var r=e,n=e,i=7;for(r>>>=1;r;r>>>=1)n<<=1,n|=1&r,--i;t[e]=n<<i&255}}(i),r.reverse=function(t){return i[255&t]<<24|i[t>>>8&255]<<16|i[t>>>16&255]<<8|i[t>>>24&255]},r.interleave2=function(t,e){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t&=65535)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e&=65535)|e<<8))|e<<4))|e<<2))|e<<1))<<1},r.deinterleave2=function(t,e){return(t=65535&((t=16711935&((t=252645135&((t=858993459&((t=t>>>e&1431655765)|t>>>1))|t>>>2))|t>>>4))|t>>>16))<<16>>16},r.interleave3=function(t,e,r){return t=1227133513&((t=3272356035&((t=251719695&((t=4278190335&((t&=1023)|t<<16))|t<<8))|t<<4))|t<<2),(t|=(e=1227133513&((e=3272356035&((e=251719695&((e=4278190335&((e&=1023)|e<<16))|e<<8))|e<<4))|e<<2))<<1)|(r=1227133513&((r=3272356035&((r=251719695&((r=4278190335&((r&=1023)|r<<16))|r<<8))|r<<4))|r<<2))<<2},r.deinterleave3=function(t,e){return(t=1023&((t=4278190335&((t=251719695&((t=3272356035&((t=t>>>e&1227133513)|t>>>2))|t>>>4))|t>>>8))|t>>>16))<<22>>22},r.nextCombination=function(t){var e=t|t-1;return e+1|(~e&-~e)-1>>>n(t)+1}},{}],93:[function(t,e,r){\"use strict\";var n=t(\"clamp\");e.exports=function(t,e){e||(e={});var r,o,s,l,c,u,h,f,p,d,g,v=null==e.cutoff?.25:e.cutoff,m=null==e.radius?8:e.radius,y=e.channel||0;if(ArrayBuffer.isView(t)||Array.isArray(t)){if(!e.width||!e.height)throw Error(\"For raw data width and height should be provided by options\");r=e.width,o=e.height,l=t,u=e.stride?e.stride:Math.floor(t.length/r/o)}else window.HTMLCanvasElement&&t instanceof window.HTMLCanvasElement?(h=(f=t).getContext(\"2d\"),r=f.width,o=f.height,p=h.getImageData(0,0,r,o),l=p.data,u=4):window.CanvasRenderingContext2D&&t instanceof window.CanvasRenderingContext2D?(f=t.canvas,h=t,r=f.width,o=f.height,p=h.getImageData(0,0,r,o),l=p.data,u=4):window.ImageData&&t instanceof window.ImageData&&(p=t,r=t.width,o=t.height,l=p.data,u=4);if(s=Math.max(r,o),window.Uint8ClampedArray&&l instanceof window.Uint8ClampedArray||window.Uint8Array&&l instanceof window.Uint8Array)for(c=l,l=Array(r*o),d=0,g=c.length;d<g;d++)l[d]=c[d*u+y]/255;else if(1!==u)throw Error(\"Raw data can have only 1 value per pixel\");var x=Array(r*o),b=Array(r*o),_=Array(s),w=Array(s),k=Array(s+1),T=Array(s);for(d=0,g=r*o;d<g;d++){var A=l[d];x[d]=1===A?0:0===A?i:Math.pow(Math.max(0,.5-A),2),b[d]=1===A?i:0===A?0:Math.pow(Math.max(0,A-.5),2)}a(x,r,o,_,w,T,k),a(b,r,o,_,w,T,k);var M=window.Float32Array?new Float32Array(r*o):new Array(r*o);for(d=0,g=r*o;d<g;d++)M[d]=n(1-((x[d]-b[d])/m+v),0,1);return M};var i=1e20;function a(t,e,r,n,i,a,s){for(var l=0;l<e;l++){for(var c=0;c<r;c++)n[c]=t[c*e+l];for(o(n,i,a,s,r),c=0;c<r;c++)t[c*e+l]=i[c]}for(c=0;c<r;c++){for(l=0;l<e;l++)n[l]=t[c*e+l];for(o(n,i,a,s,e),l=0;l<e;l++)t[c*e+l]=Math.sqrt(i[l])}}function o(t,e,r,n,a){r[0]=0,n[0]=-i,n[1]=+i;for(var o=1,s=0;o<a;o++){for(var l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);l<=n[s];)s--,l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);r[++s]=o,n[s]=l,n[s+1]=+i}for(o=0,s=0;o<a;o++){for(;n[s+1]<o;)s++;e[o]=(o-r[s])*(o-r[s])+t[r[s]]}}},{clamp:115}],94:[function(t,e,r){!function(e,r){\"use strict\";function n(t,e){if(!t)throw new Error(e||\"Assertion failed\")}function i(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}function a(t,e,r){if(a.isBN(t))return t;this.negative=0,this.words=null,this.length=0,this.red=null,null!==t&&(\"le\"!==e&&\"be\"!==e||(r=e,e=10),this._init(t||0,e||10,r||\"be\"))}var o;\"object\"==typeof e?e.exports=a:r.BN=a,a.BN=a,a.wordSize=26;try{o=t(\"buffer\").Buffer}catch(t){}function s(t,e,r){for(var n=0,i=Math.min(t.length,r),a=e;a<i;a++){var o=t.charCodeAt(a)-48;n<<=4,n|=o>=49&&o<=54?o-49+10:o>=17&&o<=22?o-17+10:15&o}return n}function l(t,e,r,n){for(var i=0,a=Math.min(t.length,r),o=e;o<a;o++){var s=t.charCodeAt(o)-48;i*=n,i+=s>=49?s-49+10:s>=17?s-17+10:s}return i}a.isBN=function(t){return t instanceof a||null!==t&&\"object\"==typeof t&&t.constructor.wordSize===a.wordSize&&Array.isArray(t.words)},a.max=function(t,e){return t.cmp(e)>0?t:e},a.min=function(t,e){return t.cmp(e)<0?t:e},a.prototype._init=function(t,e,r){if(\"number\"==typeof t)return this._initNumber(t,e,r);if(\"object\"==typeof t)return this._initArray(t,e,r);\"hex\"===e&&(e=16),n(e===(0|e)&&e>=2&&e<=36);var i=0;\"-\"===(t=t.toString().replace(/\\s+/g,\"\"))[0]&&i++,16===e?this._parseHex(t,i):this._parseBase(t,e,i),\"-\"===t[0]&&(this.negative=1),this.strip(),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initNumber=function(t,e,r){t<0&&(this.negative=1,t=-t),t<67108864?(this.words=[67108863&t],this.length=1):t<4503599627370496?(this.words=[67108863&t,t/67108864&67108863],this.length=2):(n(t<9007199254740992),this.words=[67108863&t,t/67108864&67108863,1],this.length=3),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initArray=function(t,e,r){if(n(\"number\"==typeof t.length),t.length<=0)return this.words=[0],this.length=1,this;this.length=Math.ceil(t.length/3),this.words=new Array(this.length);for(var i=0;i<this.length;i++)this.words[i]=0;var a,o,s=0;if(\"be\"===r)for(i=t.length-1,a=0;i>=0;i-=3)o=t[i]|t[i-1]<<8|t[i-2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);else if(\"le\"===r)for(i=0,a=0;i<t.length;i+=3)o=t[i]|t[i+1]<<8|t[i+2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);return this.strip()},a.prototype._parseHex=function(t,e){this.length=Math.ceil((t.length-e)/6),this.words=new Array(this.length);for(var r=0;r<this.length;r++)this.words[r]=0;var n,i,a=0;for(r=t.length-6,n=0;r>=e;r-=6)i=s(t,r,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303,(a+=24)>=26&&(a-=26,n++);r+6!==e&&(i=s(t,e,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303),this.strip()},a.prototype._parseBase=function(t,e,r){this.words=[0],this.length=1;for(var n=0,i=1;i<=67108863;i*=e)n++;n--,i=i/e|0;for(var a=t.length-r,o=a%n,s=Math.min(a,a-o)+r,c=0,u=r;u<s;u+=n)c=l(t,u,u+n,e),this.imuln(i),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c);if(0!==o){var h=1;for(c=l(t,u,t.length,e),u=0;u<o;u++)h*=e;this.imuln(h),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c)}},a.prototype.copy=function(t){t.words=new Array(this.length);for(var e=0;e<this.length;e++)t.words[e]=this.words[e];t.length=this.length,t.negative=this.negative,t.red=this.red},a.prototype.clone=function(){var t=new a(null);return this.copy(t),t},a.prototype._expand=function(t){for(;this.length<t;)this.words[this.length++]=0;return this},a.prototype.strip=function(){for(;this.length>1&&0===this.words[this.length-1];)this.length--;return this._normSign()},a.prototype._normSign=function(){return 1===this.length&&0===this.words[0]&&(this.negative=0),this},a.prototype.inspect=function(){return(this.red?\"<BN-R: \":\"<BN: \")+this.toString(16)+\">\"};var c=[\"\",\"0\",\"00\",\"000\",\"0000\",\"00000\",\"000000\",\"0000000\",\"00000000\",\"000000000\",\"0000000000\",\"00000000000\",\"000000000000\",\"0000000000000\",\"00000000000000\",\"000000000000000\",\"0000000000000000\",\"00000000000000000\",\"000000000000000000\",\"0000000000000000000\",\"00000000000000000000\",\"000000000000000000000\",\"0000000000000000000000\",\"00000000000000000000000\",\"000000000000000000000000\",\"0000000000000000000000000\"],u=[0,0,25,16,12,11,10,9,8,8,7,7,7,7,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5],h=[0,0,33554432,43046721,16777216,48828125,60466176,40353607,16777216,43046721,1e7,19487171,35831808,62748517,7529536,11390625,16777216,24137569,34012224,47045881,64e6,4084101,5153632,6436343,7962624,9765625,11881376,14348907,17210368,20511149,243e5,28629151,33554432,39135393,45435424,52521875,60466176];function f(t,e,r){r.negative=e.negative^t.negative;var n=t.length+e.length|0;r.length=n,n=n-1|0;var i=0|t.words[0],a=0|e.words[0],o=i*a,s=67108863&o,l=o/67108864|0;r.words[0]=s;for(var c=1;c<n;c++){for(var u=l>>>26,h=67108863&l,f=Math.min(c,e.length-1),p=Math.max(0,c-t.length+1);p<=f;p++){var d=c-p|0;u+=(o=(i=0|t.words[d])*(a=0|e.words[p])+h)/67108864|0,h=67108863&o}r.words[c]=0|h,l=0|u}return 0!==l?r.words[c]=0|l:r.length--,r.strip()}a.prototype.toString=function(t,e){var r;if(e=0|e||1,16===(t=t||10)||\"hex\"===t){r=\"\";for(var i=0,a=0,o=0;o<this.length;o++){var s=this.words[o],l=(16777215&(s<<i|a)).toString(16);r=0!==(a=s>>>24-i&16777215)||o!==this.length-1?c[6-l.length]+l+r:l+r,(i+=2)>=26&&(i-=26,o--)}for(0!==a&&(r=a.toString(16)+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}if(t===(0|t)&&t>=2&&t<=36){var f=u[t],p=h[t];r=\"\";var d=this.clone();for(d.negative=0;!d.isZero();){var g=d.modn(p).toString(t);r=(d=d.idivn(p)).isZero()?g+r:c[f-g.length]+g+r}for(this.isZero()&&(r=\"0\"+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}n(!1,\"Base should be between 2 and 36\")},a.prototype.toNumber=function(){var t=this.words[0];return 2===this.length?t+=67108864*this.words[1]:3===this.length&&1===this.words[2]?t+=4503599627370496+67108864*this.words[1]:this.length>2&&n(!1,\"Number can only safely store up to 53 bits\"),0!==this.negative?-t:t},a.prototype.toJSON=function(){return this.toString(16)},a.prototype.toBuffer=function(t,e){return n(\"undefined\"!=typeof o),this.toArrayLike(o,t,e)},a.prototype.toArray=function(t,e){return this.toArrayLike(Array,t,e)},a.prototype.toArrayLike=function(t,e,r){var i=this.byteLength(),a=r||Math.max(1,i);n(i<=a,\"byte array longer than desired length\"),n(a>0,\"Requested array length <= 0\"),this.strip();var o,s,l=\"le\"===e,c=new t(a),u=this.clone();if(l){for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[s]=o;for(;s<a;s++)c[s]=0}else{for(s=0;s<a-i;s++)c[s]=0;for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[a-s-1]=o}return c},Math.clz32?a.prototype._countBits=function(t){return 32-Math.clz32(t)}:a.prototype._countBits=function(t){var e=t,r=0;return e>=4096&&(r+=13,e>>>=13),e>=64&&(r+=7,e>>>=7),e>=8&&(r+=4,e>>>=4),e>=2&&(r+=2,e>>>=2),r+e},a.prototype._zeroBits=function(t){if(0===t)return 26;var e=t,r=0;return 0==(8191&e)&&(r+=13,e>>>=13),0==(127&e)&&(r+=7,e>>>=7),0==(15&e)&&(r+=4,e>>>=4),0==(3&e)&&(r+=2,e>>>=2),0==(1&e)&&r++,r},a.prototype.bitLength=function(){var t=this.words[this.length-1],e=this._countBits(t);return 26*(this.length-1)+e},a.prototype.zeroBits=function(){if(this.isZero())return 0;for(var t=0,e=0;e<this.length;e++){var r=this._zeroBits(this.words[e]);if(t+=r,26!==r)break}return t},a.prototype.byteLength=function(){return Math.ceil(this.bitLength()/8)},a.prototype.toTwos=function(t){return 0!==this.negative?this.abs().inotn(t).iaddn(1):this.clone()},a.prototype.fromTwos=function(t){return this.testn(t-1)?this.notn(t).iaddn(1).ineg():this.clone()},a.prototype.isNeg=function(){return 0!==this.negative},a.prototype.neg=function(){return this.clone().ineg()},a.prototype.ineg=function(){return this.isZero()||(this.negative^=1),this},a.prototype.iuor=function(t){for(;this.length<t.length;)this.words[this.length++]=0;for(var e=0;e<t.length;e++)this.words[e]=this.words[e]|t.words[e];return this.strip()},a.prototype.ior=function(t){return n(0==(this.negative|t.negative)),this.iuor(t)},a.prototype.or=function(t){return this.length>t.length?this.clone().ior(t):t.clone().ior(this)},a.prototype.uor=function(t){return this.length>t.length?this.clone().iuor(t):t.clone().iuor(this)},a.prototype.iuand=function(t){var e;e=this.length>t.length?t:this;for(var r=0;r<e.length;r++)this.words[r]=this.words[r]&t.words[r];return this.length=e.length,this.strip()},a.prototype.iand=function(t){return n(0==(this.negative|t.negative)),this.iuand(t)},a.prototype.and=function(t){return this.length>t.length?this.clone().iand(t):t.clone().iand(this)},a.prototype.uand=function(t){return this.length>t.length?this.clone().iuand(t):t.clone().iuand(this)},a.prototype.iuxor=function(t){var e,r;this.length>t.length?(e=this,r=t):(e=t,r=this);for(var n=0;n<r.length;n++)this.words[n]=e.words[n]^r.words[n];if(this!==e)for(;n<e.length;n++)this.words[n]=e.words[n];return this.length=e.length,this.strip()},a.prototype.ixor=function(t){return n(0==(this.negative|t.negative)),this.iuxor(t)},a.prototype.xor=function(t){return this.length>t.length?this.clone().ixor(t):t.clone().ixor(this)},a.prototype.uxor=function(t){return this.length>t.length?this.clone().iuxor(t):t.clone().iuxor(this)},a.prototype.inotn=function(t){n(\"number\"==typeof t&&t>=0);var e=0|Math.ceil(t/26),r=t%26;this._expand(e),r>0&&e--;for(var i=0;i<e;i++)this.words[i]=67108863&~this.words[i];return r>0&&(this.words[i]=~this.words[i]&67108863>>26-r),this.strip()},a.prototype.notn=function(t){return this.clone().inotn(t)},a.prototype.setn=function(t,e){n(\"number\"==typeof t&&t>=0);var r=t/26|0,i=t%26;return this._expand(r+1),this.words[r]=e?this.words[r]|1<<i:this.words[r]&~(1<<i),this.strip()},a.prototype.iadd=function(t){var e,r,n;if(0!==this.negative&&0===t.negative)return this.negative=0,e=this.isub(t),this.negative^=1,this._normSign();if(0===this.negative&&0!==t.negative)return t.negative=0,e=this.isub(t),t.negative=1,e._normSign();this.length>t.length?(r=this,n=t):(r=t,n=this);for(var i=0,a=0;a<n.length;a++)e=(0|r.words[a])+(0|n.words[a])+i,this.words[a]=67108863&e,i=e>>>26;for(;0!==i&&a<r.length;a++)e=(0|r.words[a])+i,this.words[a]=67108863&e,i=e>>>26;if(this.length=r.length,0!==i)this.words[this.length]=i,this.length++;else if(r!==this)for(;a<r.length;a++)this.words[a]=r.words[a];return this},a.prototype.add=function(t){var e;return 0!==t.negative&&0===this.negative?(t.negative=0,e=this.sub(t),t.negative^=1,e):0===t.negative&&0!==this.negative?(this.negative=0,e=t.sub(this),this.negative=1,e):this.length>t.length?this.clone().iadd(t):t.clone().iadd(this)},a.prototype.isub=function(t){if(0!==t.negative){t.negative=0;var e=this.iadd(t);return t.negative=1,e._normSign()}if(0!==this.negative)return this.negative=0,this.iadd(t),this.negative=1,this._normSign();var r,n,i=this.cmp(t);if(0===i)return this.negative=0,this.length=1,this.words[0]=0,this;i>0?(r=this,n=t):(r=t,n=this);for(var a=0,o=0;o<n.length;o++)a=(e=(0|r.words[o])-(0|n.words[o])+a)>>26,this.words[o]=67108863&e;for(;0!==a&&o<r.length;o++)a=(e=(0|r.words[o])+a)>>26,this.words[o]=67108863&e;if(0===a&&o<r.length&&r!==this)for(;o<r.length;o++)this.words[o]=r.words[o];return this.length=Math.max(this.length,o),r!==this&&(this.negative=1),this.strip()},a.prototype.sub=function(t){return this.clone().isub(t)};var p=function(t,e,r){var n,i,a,o=t.words,s=e.words,l=r.words,c=0,u=0|o[0],h=8191&u,f=u>>>13,p=0|o[1],d=8191&p,g=p>>>13,v=0|o[2],m=8191&v,y=v>>>13,x=0|o[3],b=8191&x,_=x>>>13,w=0|o[4],k=8191&w,T=w>>>13,A=0|o[5],M=8191&A,S=A>>>13,E=0|o[6],C=8191&E,L=E>>>13,P=0|o[7],O=8191&P,z=P>>>13,I=0|o[8],D=8191&I,R=I>>>13,F=0|o[9],B=8191&F,N=F>>>13,j=0|s[0],U=8191&j,V=j>>>13,q=0|s[1],H=8191&q,G=q>>>13,Y=0|s[2],W=8191&Y,X=Y>>>13,Z=0|s[3],J=8191&Z,K=Z>>>13,$=0|s[4],Q=8191&$,tt=$>>>13,et=0|s[5],rt=8191&et,nt=et>>>13,it=0|s[6],at=8191&it,ot=it>>>13,st=0|s[7],lt=8191&st,ct=st>>>13,ut=0|s[8],ht=8191&ut,ft=ut>>>13,pt=0|s[9],dt=8191&pt,gt=pt>>>13;r.negative=t.negative^e.negative,r.length=19;var vt=(c+(n=Math.imul(h,U))|0)+((8191&(i=(i=Math.imul(h,V))+Math.imul(f,U)|0))<<13)|0;c=((a=Math.imul(f,V))+(i>>>13)|0)+(vt>>>26)|0,vt&=67108863,n=Math.imul(d,U),i=(i=Math.imul(d,V))+Math.imul(g,U)|0,a=Math.imul(g,V);var mt=(c+(n=n+Math.imul(h,H)|0)|0)+((8191&(i=(i=i+Math.imul(h,G)|0)+Math.imul(f,H)|0))<<13)|0;c=((a=a+Math.imul(f,G)|0)+(i>>>13)|0)+(mt>>>26)|0,mt&=67108863,n=Math.imul(m,U),i=(i=Math.imul(m,V))+Math.imul(y,U)|0,a=Math.imul(y,V),n=n+Math.imul(d,H)|0,i=(i=i+Math.imul(d,G)|0)+Math.imul(g,H)|0,a=a+Math.imul(g,G)|0;var yt=(c+(n=n+Math.imul(h,W)|0)|0)+((8191&(i=(i=i+Math.imul(h,X)|0)+Math.imul(f,W)|0))<<13)|0;c=((a=a+Math.imul(f,X)|0)+(i>>>13)|0)+(yt>>>26)|0,yt&=67108863,n=Math.imul(b,U),i=(i=Math.imul(b,V))+Math.imul(_,U)|0,a=Math.imul(_,V),n=n+Math.imul(m,H)|0,i=(i=i+Math.imul(m,G)|0)+Math.imul(y,H)|0,a=a+Math.imul(y,G)|0,n=n+Math.imul(d,W)|0,i=(i=i+Math.imul(d,X)|0)+Math.imul(g,W)|0,a=a+Math.imul(g,X)|0;var xt=(c+(n=n+Math.imul(h,J)|0)|0)+((8191&(i=(i=i+Math.imul(h,K)|0)+Math.imul(f,J)|0))<<13)|0;c=((a=a+Math.imul(f,K)|0)+(i>>>13)|0)+(xt>>>26)|0,xt&=67108863,n=Math.imul(k,U),i=(i=Math.imul(k,V))+Math.imul(T,U)|0,a=Math.imul(T,V),n=n+Math.imul(b,H)|0,i=(i=i+Math.imul(b,G)|0)+Math.imul(_,H)|0,a=a+Math.imul(_,G)|0,n=n+Math.imul(m,W)|0,i=(i=i+Math.imul(m,X)|0)+Math.imul(y,W)|0,a=a+Math.imul(y,X)|0,n=n+Math.imul(d,J)|0,i=(i=i+Math.imul(d,K)|0)+Math.imul(g,J)|0,a=a+Math.imul(g,K)|0;var bt=(c+(n=n+Math.imul(h,Q)|0)|0)+((8191&(i=(i=i+Math.imul(h,tt)|0)+Math.imul(f,Q)|0))<<13)|0;c=((a=a+Math.imul(f,tt)|0)+(i>>>13)|0)+(bt>>>26)|0,bt&=67108863,n=Math.imul(M,U),i=(i=Math.imul(M,V))+Math.imul(S,U)|0,a=Math.imul(S,V),n=n+Math.imul(k,H)|0,i=(i=i+Math.imul(k,G)|0)+Math.imul(T,H)|0,a=a+Math.imul(T,G)|0,n=n+Math.imul(b,W)|0,i=(i=i+Math.imul(b,X)|0)+Math.imul(_,W)|0,a=a+Math.imul(_,X)|0,n=n+Math.imul(m,J)|0,i=(i=i+Math.imul(m,K)|0)+Math.imul(y,J)|0,a=a+Math.imul(y,K)|0,n=n+Math.imul(d,Q)|0,i=(i=i+Math.imul(d,tt)|0)+Math.imul(g,Q)|0,a=a+Math.imul(g,tt)|0;var _t=(c+(n=n+Math.imul(h,rt)|0)|0)+((8191&(i=(i=i+Math.imul(h,nt)|0)+Math.imul(f,rt)|0))<<13)|0;c=((a=a+Math.imul(f,nt)|0)+(i>>>13)|0)+(_t>>>26)|0,_t&=67108863,n=Math.imul(C,U),i=(i=Math.imul(C,V))+Math.imul(L,U)|0,a=Math.imul(L,V),n=n+Math.imul(M,H)|0,i=(i=i+Math.imul(M,G)|0)+Math.imul(S,H)|0,a=a+Math.imul(S,G)|0,n=n+Math.imul(k,W)|0,i=(i=i+Math.imul(k,X)|0)+Math.imul(T,W)|0,a=a+Math.imul(T,X)|0,n=n+Math.imul(b,J)|0,i=(i=i+Math.imul(b,K)|0)+Math.imul(_,J)|0,a=a+Math.imul(_,K)|0,n=n+Math.imul(m,Q)|0,i=(i=i+Math.imul(m,tt)|0)+Math.imul(y,Q)|0,a=a+Math.imul(y,tt)|0,n=n+Math.imul(d,rt)|0,i=(i=i+Math.imul(d,nt)|0)+Math.imul(g,rt)|0,a=a+Math.imul(g,nt)|0;var wt=(c+(n=n+Math.imul(h,at)|0)|0)+((8191&(i=(i=i+Math.imul(h,ot)|0)+Math.imul(f,at)|0))<<13)|0;c=((a=a+Math.imul(f,ot)|0)+(i>>>13)|0)+(wt>>>26)|0,wt&=67108863,n=Math.imul(O,U),i=(i=Math.imul(O,V))+Math.imul(z,U)|0,a=Math.imul(z,V),n=n+Math.imul(C,H)|0,i=(i=i+Math.imul(C,G)|0)+Math.imul(L,H)|0,a=a+Math.imul(L,G)|0,n=n+Math.imul(M,W)|0,i=(i=i+Math.imul(M,X)|0)+Math.imul(S,W)|0,a=a+Math.imul(S,X)|0,n=n+Math.imul(k,J)|0,i=(i=i+Math.imul(k,K)|0)+Math.imul(T,J)|0,a=a+Math.imul(T,K)|0,n=n+Math.imul(b,Q)|0,i=(i=i+Math.imul(b,tt)|0)+Math.imul(_,Q)|0,a=a+Math.imul(_,tt)|0,n=n+Math.imul(m,rt)|0,i=(i=i+Math.imul(m,nt)|0)+Math.imul(y,rt)|0,a=a+Math.imul(y,nt)|0,n=n+Math.imul(d,at)|0,i=(i=i+Math.imul(d,ot)|0)+Math.imul(g,at)|0,a=a+Math.imul(g,ot)|0;var kt=(c+(n=n+Math.imul(h,lt)|0)|0)+((8191&(i=(i=i+Math.imul(h,ct)|0)+Math.imul(f,lt)|0))<<13)|0;c=((a=a+Math.imul(f,ct)|0)+(i>>>13)|0)+(kt>>>26)|0,kt&=67108863,n=Math.imul(D,U),i=(i=Math.imul(D,V))+Math.imul(R,U)|0,a=Math.imul(R,V),n=n+Math.imul(O,H)|0,i=(i=i+Math.imul(O,G)|0)+Math.imul(z,H)|0,a=a+Math.imul(z,G)|0,n=n+Math.imul(C,W)|0,i=(i=i+Math.imul(C,X)|0)+Math.imul(L,W)|0,a=a+Math.imul(L,X)|0,n=n+Math.imul(M,J)|0,i=(i=i+Math.imul(M,K)|0)+Math.imul(S,J)|0,a=a+Math.imul(S,K)|0,n=n+Math.imul(k,Q)|0,i=(i=i+Math.imul(k,tt)|0)+Math.imul(T,Q)|0,a=a+Math.imul(T,tt)|0,n=n+Math.imul(b,rt)|0,i=(i=i+Math.imul(b,nt)|0)+Math.imul(_,rt)|0,a=a+Math.imul(_,nt)|0,n=n+Math.imul(m,at)|0,i=(i=i+Math.imul(m,ot)|0)+Math.imul(y,at)|0,a=a+Math.imul(y,ot)|0,n=n+Math.imul(d,lt)|0,i=(i=i+Math.imul(d,ct)|0)+Math.imul(g,lt)|0,a=a+Math.imul(g,ct)|0;var Tt=(c+(n=n+Math.imul(h,ht)|0)|0)+((8191&(i=(i=i+Math.imul(h,ft)|0)+Math.imul(f,ht)|0))<<13)|0;c=((a=a+Math.imul(f,ft)|0)+(i>>>13)|0)+(Tt>>>26)|0,Tt&=67108863,n=Math.imul(B,U),i=(i=Math.imul(B,V))+Math.imul(N,U)|0,a=Math.imul(N,V),n=n+Math.imul(D,H)|0,i=(i=i+Math.imul(D,G)|0)+Math.imul(R,H)|0,a=a+Math.imul(R,G)|0,n=n+Math.imul(O,W)|0,i=(i=i+Math.imul(O,X)|0)+Math.imul(z,W)|0,a=a+Math.imul(z,X)|0,n=n+Math.imul(C,J)|0,i=(i=i+Math.imul(C,K)|0)+Math.imul(L,J)|0,a=a+Math.imul(L,K)|0,n=n+Math.imul(M,Q)|0,i=(i=i+Math.imul(M,tt)|0)+Math.imul(S,Q)|0,a=a+Math.imul(S,tt)|0,n=n+Math.imul(k,rt)|0,i=(i=i+Math.imul(k,nt)|0)+Math.imul(T,rt)|0,a=a+Math.imul(T,nt)|0,n=n+Math.imul(b,at)|0,i=(i=i+Math.imul(b,ot)|0)+Math.imul(_,at)|0,a=a+Math.imul(_,ot)|0,n=n+Math.imul(m,lt)|0,i=(i=i+Math.imul(m,ct)|0)+Math.imul(y,lt)|0,a=a+Math.imul(y,ct)|0,n=n+Math.imul(d,ht)|0,i=(i=i+Math.imul(d,ft)|0)+Math.imul(g,ht)|0,a=a+Math.imul(g,ft)|0;var At=(c+(n=n+Math.imul(h,dt)|0)|0)+((8191&(i=(i=i+Math.imul(h,gt)|0)+Math.imul(f,dt)|0))<<13)|0;c=((a=a+Math.imul(f,gt)|0)+(i>>>13)|0)+(At>>>26)|0,At&=67108863,n=Math.imul(B,H),i=(i=Math.imul(B,G))+Math.imul(N,H)|0,a=Math.imul(N,G),n=n+Math.imul(D,W)|0,i=(i=i+Math.imul(D,X)|0)+Math.imul(R,W)|0,a=a+Math.imul(R,X)|0,n=n+Math.imul(O,J)|0,i=(i=i+Math.imul(O,K)|0)+Math.imul(z,J)|0,a=a+Math.imul(z,K)|0,n=n+Math.imul(C,Q)|0,i=(i=i+Math.imul(C,tt)|0)+Math.imul(L,Q)|0,a=a+Math.imul(L,tt)|0,n=n+Math.imul(M,rt)|0,i=(i=i+Math.imul(M,nt)|0)+Math.imul(S,rt)|0,a=a+Math.imul(S,nt)|0,n=n+Math.imul(k,at)|0,i=(i=i+Math.imul(k,ot)|0)+Math.imul(T,at)|0,a=a+Math.imul(T,ot)|0,n=n+Math.imul(b,lt)|0,i=(i=i+Math.imul(b,ct)|0)+Math.imul(_,lt)|0,a=a+Math.imul(_,ct)|0,n=n+Math.imul(m,ht)|0,i=(i=i+Math.imul(m,ft)|0)+Math.imul(y,ht)|0,a=a+Math.imul(y,ft)|0;var Mt=(c+(n=n+Math.imul(d,dt)|0)|0)+((8191&(i=(i=i+Math.imul(d,gt)|0)+Math.imul(g,dt)|0))<<13)|0;c=((a=a+Math.imul(g,gt)|0)+(i>>>13)|0)+(Mt>>>26)|0,Mt&=67108863,n=Math.imul(B,W),i=(i=Math.imul(B,X))+Math.imul(N,W)|0,a=Math.imul(N,X),n=n+Math.imul(D,J)|0,i=(i=i+Math.imul(D,K)|0)+Math.imul(R,J)|0,a=a+Math.imul(R,K)|0,n=n+Math.imul(O,Q)|0,i=(i=i+Math.imul(O,tt)|0)+Math.imul(z,Q)|0,a=a+Math.imul(z,tt)|0,n=n+Math.imul(C,rt)|0,i=(i=i+Math.imul(C,nt)|0)+Math.imul(L,rt)|0,a=a+Math.imul(L,nt)|0,n=n+Math.imul(M,at)|0,i=(i=i+Math.imul(M,ot)|0)+Math.imul(S,at)|0,a=a+Math.imul(S,ot)|0,n=n+Math.imul(k,lt)|0,i=(i=i+Math.imul(k,ct)|0)+Math.imul(T,lt)|0,a=a+Math.imul(T,ct)|0,n=n+Math.imul(b,ht)|0,i=(i=i+Math.imul(b,ft)|0)+Math.imul(_,ht)|0,a=a+Math.imul(_,ft)|0;var St=(c+(n=n+Math.imul(m,dt)|0)|0)+((8191&(i=(i=i+Math.imul(m,gt)|0)+Math.imul(y,dt)|0))<<13)|0;c=((a=a+Math.imul(y,gt)|0)+(i>>>13)|0)+(St>>>26)|0,St&=67108863,n=Math.imul(B,J),i=(i=Math.imul(B,K))+Math.imul(N,J)|0,a=Math.imul(N,K),n=n+Math.imul(D,Q)|0,i=(i=i+Math.imul(D,tt)|0)+Math.imul(R,Q)|0,a=a+Math.imul(R,tt)|0,n=n+Math.imul(O,rt)|0,i=(i=i+Math.imul(O,nt)|0)+Math.imul(z,rt)|0,a=a+Math.imul(z,nt)|0,n=n+Math.imul(C,at)|0,i=(i=i+Math.imul(C,ot)|0)+Math.imul(L,at)|0,a=a+Math.imul(L,ot)|0,n=n+Math.imul(M,lt)|0,i=(i=i+Math.imul(M,ct)|0)+Math.imul(S,lt)|0,a=a+Math.imul(S,ct)|0,n=n+Math.imul(k,ht)|0,i=(i=i+Math.imul(k,ft)|0)+Math.imul(T,ht)|0,a=a+Math.imul(T,ft)|0;var Et=(c+(n=n+Math.imul(b,dt)|0)|0)+((8191&(i=(i=i+Math.imul(b,gt)|0)+Math.imul(_,dt)|0))<<13)|0;c=((a=a+Math.imul(_,gt)|0)+(i>>>13)|0)+(Et>>>26)|0,Et&=67108863,n=Math.imul(B,Q),i=(i=Math.imul(B,tt))+Math.imul(N,Q)|0,a=Math.imul(N,tt),n=n+Math.imul(D,rt)|0,i=(i=i+Math.imul(D,nt)|0)+Math.imul(R,rt)|0,a=a+Math.imul(R,nt)|0,n=n+Math.imul(O,at)|0,i=(i=i+Math.imul(O,ot)|0)+Math.imul(z,at)|0,a=a+Math.imul(z,ot)|0,n=n+Math.imul(C,lt)|0,i=(i=i+Math.imul(C,ct)|0)+Math.imul(L,lt)|0,a=a+Math.imul(L,ct)|0,n=n+Math.imul(M,ht)|0,i=(i=i+Math.imul(M,ft)|0)+Math.imul(S,ht)|0,a=a+Math.imul(S,ft)|0;var Ct=(c+(n=n+Math.imul(k,dt)|0)|0)+((8191&(i=(i=i+Math.imul(k,gt)|0)+Math.imul(T,dt)|0))<<13)|0;c=((a=a+Math.imul(T,gt)|0)+(i>>>13)|0)+(Ct>>>26)|0,Ct&=67108863,n=Math.imul(B,rt),i=(i=Math.imul(B,nt))+Math.imul(N,rt)|0,a=Math.imul(N,nt),n=n+Math.imul(D,at)|0,i=(i=i+Math.imul(D,ot)|0)+Math.imul(R,at)|0,a=a+Math.imul(R,ot)|0,n=n+Math.imul(O,lt)|0,i=(i=i+Math.imul(O,ct)|0)+Math.imul(z,lt)|0,a=a+Math.imul(z,ct)|0,n=n+Math.imul(C,ht)|0,i=(i=i+Math.imul(C,ft)|0)+Math.imul(L,ht)|0,a=a+Math.imul(L,ft)|0;var Lt=(c+(n=n+Math.imul(M,dt)|0)|0)+((8191&(i=(i=i+Math.imul(M,gt)|0)+Math.imul(S,dt)|0))<<13)|0;c=((a=a+Math.imul(S,gt)|0)+(i>>>13)|0)+(Lt>>>26)|0,Lt&=67108863,n=Math.imul(B,at),i=(i=Math.imul(B,ot))+Math.imul(N,at)|0,a=Math.imul(N,ot),n=n+Math.imul(D,lt)|0,i=(i=i+Math.imul(D,ct)|0)+Math.imul(R,lt)|0,a=a+Math.imul(R,ct)|0,n=n+Math.imul(O,ht)|0,i=(i=i+Math.imul(O,ft)|0)+Math.imul(z,ht)|0,a=a+Math.imul(z,ft)|0;var Pt=(c+(n=n+Math.imul(C,dt)|0)|0)+((8191&(i=(i=i+Math.imul(C,gt)|0)+Math.imul(L,dt)|0))<<13)|0;c=((a=a+Math.imul(L,gt)|0)+(i>>>13)|0)+(Pt>>>26)|0,Pt&=67108863,n=Math.imul(B,lt),i=(i=Math.imul(B,ct))+Math.imul(N,lt)|0,a=Math.imul(N,ct),n=n+Math.imul(D,ht)|0,i=(i=i+Math.imul(D,ft)|0)+Math.imul(R,ht)|0,a=a+Math.imul(R,ft)|0;var Ot=(c+(n=n+Math.imul(O,dt)|0)|0)+((8191&(i=(i=i+Math.imul(O,gt)|0)+Math.imul(z,dt)|0))<<13)|0;c=((a=a+Math.imul(z,gt)|0)+(i>>>13)|0)+(Ot>>>26)|0,Ot&=67108863,n=Math.imul(B,ht),i=(i=Math.imul(B,ft))+Math.imul(N,ht)|0,a=Math.imul(N,ft);var zt=(c+(n=n+Math.imul(D,dt)|0)|0)+((8191&(i=(i=i+Math.imul(D,gt)|0)+Math.imul(R,dt)|0))<<13)|0;c=((a=a+Math.imul(R,gt)|0)+(i>>>13)|0)+(zt>>>26)|0,zt&=67108863;var It=(c+(n=Math.imul(B,dt))|0)+((8191&(i=(i=Math.imul(B,gt))+Math.imul(N,dt)|0))<<13)|0;return c=((a=Math.imul(N,gt))+(i>>>13)|0)+(It>>>26)|0,It&=67108863,l[0]=vt,l[1]=mt,l[2]=yt,l[3]=xt,l[4]=bt,l[5]=_t,l[6]=wt,l[7]=kt,l[8]=Tt,l[9]=At,l[10]=Mt,l[11]=St,l[12]=Et,l[13]=Ct,l[14]=Lt,l[15]=Pt,l[16]=Ot,l[17]=zt,l[18]=It,0!==c&&(l[19]=c,r.length++),r};function d(t,e,r){return(new g).mulp(t,e,r)}function g(t,e){this.x=t,this.y=e}Math.imul||(p=f),a.prototype.mulTo=function(t,e){var r=this.length+t.length;return 10===this.length&&10===t.length?p(this,t,e):r<63?f(this,t,e):r<1024?function(t,e,r){r.negative=e.negative^t.negative,r.length=t.length+e.length;for(var n=0,i=0,a=0;a<r.length-1;a++){var o=i;i=0;for(var s=67108863&n,l=Math.min(a,e.length-1),c=Math.max(0,a-t.length+1);c<=l;c++){var u=a-c,h=(0|t.words[u])*(0|e.words[c]),f=67108863&h;s=67108863&(f=f+s|0),i+=(o=(o=o+(h/67108864|0)|0)+(f>>>26)|0)>>>26,o&=67108863}r.words[a]=s,n=o,o=i}return 0!==n?r.words[a]=n:r.length--,r.strip()}(this,t,e):d(this,t,e)},g.prototype.makeRBT=function(t){for(var e=new Array(t),r=a.prototype._countBits(t)-1,n=0;n<t;n++)e[n]=this.revBin(n,r,t);return e},g.prototype.revBin=function(t,e,r){if(0===t||t===r-1)return t;for(var n=0,i=0;i<e;i++)n|=(1&t)<<e-i-1,t>>=1;return n},g.prototype.permute=function(t,e,r,n,i,a){for(var o=0;o<a;o++)n[o]=e[t[o]],i[o]=r[t[o]]},g.prototype.transform=function(t,e,r,n,i,a){this.permute(a,t,e,r,n,i);for(var o=1;o<i;o<<=1)for(var s=o<<1,l=Math.cos(2*Math.PI/s),c=Math.sin(2*Math.PI/s),u=0;u<i;u+=s)for(var h=l,f=c,p=0;p<o;p++){var d=r[u+p],g=n[u+p],v=r[u+p+o],m=n[u+p+o],y=h*v-f*m;m=h*m+f*v,v=y,r[u+p]=d+v,n[u+p]=g+m,r[u+p+o]=d-v,n[u+p+o]=g-m,p!==s&&(y=l*h-c*f,f=l*f+c*h,h=y)}},g.prototype.guessLen13b=function(t,e){var r=1|Math.max(e,t),n=1&r,i=0;for(r=r/2|0;r;r>>>=1)i++;return 1<<i+1+n},g.prototype.conjugate=function(t,e,r){if(!(r<=1))for(var n=0;n<r/2;n++){var i=t[n];t[n]=t[r-n-1],t[r-n-1]=i,i=e[n],e[n]=-e[r-n-1],e[r-n-1]=-i}},g.prototype.normalize13b=function(t,e){for(var r=0,n=0;n<e/2;n++){var i=8192*Math.round(t[2*n+1]/e)+Math.round(t[2*n]/e)+r;t[n]=67108863&i,r=i<67108864?0:i/67108864|0}return t},g.prototype.convert13b=function(t,e,r,i){for(var a=0,o=0;o<e;o++)a+=0|t[o],r[2*o]=8191&a,a>>>=13,r[2*o+1]=8191&a,a>>>=13;for(o=2*e;o<i;++o)r[o]=0;n(0===a),n(0==(-8192&a))},g.prototype.stub=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=0;return e},g.prototype.mulp=function(t,e,r){var n=2*this.guessLen13b(t.length,e.length),i=this.makeRBT(n),a=this.stub(n),o=new Array(n),s=new Array(n),l=new Array(n),c=new Array(n),u=new Array(n),h=new Array(n),f=r.words;f.length=n,this.convert13b(t.words,t.length,o,n),this.convert13b(e.words,e.length,c,n),this.transform(o,a,s,l,n,i),this.transform(c,a,u,h,n,i);for(var p=0;p<n;p++){var d=s[p]*u[p]-l[p]*h[p];l[p]=s[p]*h[p]+l[p]*u[p],s[p]=d}return this.conjugate(s,l,n),this.transform(s,l,f,a,n,i),this.conjugate(f,a,n),this.normalize13b(f,n),r.negative=t.negative^e.negative,r.length=t.length+e.length,r.strip()},a.prototype.mul=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),this.mulTo(t,e)},a.prototype.mulf=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),d(this,t,e)},a.prototype.imul=function(t){return this.clone().mulTo(t,this)},a.prototype.imuln=function(t){n(\"number\"==typeof t),n(t<67108864);for(var e=0,r=0;r<this.length;r++){var i=(0|this.words[r])*t,a=(67108863&i)+(67108863&e);e>>=26,e+=i/67108864|0,e+=a>>>26,this.words[r]=67108863&a}return 0!==e&&(this.words[r]=e,this.length++),this},a.prototype.muln=function(t){return this.clone().imuln(t)},a.prototype.sqr=function(){return this.mul(this)},a.prototype.isqr=function(){return this.imul(this.clone())},a.prototype.pow=function(t){var e=function(t){for(var e=new Array(t.bitLength()),r=0;r<e.length;r++){var n=r/26|0,i=r%26;e[r]=(t.words[n]&1<<i)>>>i}return e}(t);if(0===e.length)return new a(1);for(var r=this,n=0;n<e.length&&0===e[n];n++,r=r.sqr());if(++n<e.length)for(var i=r.sqr();n<e.length;n++,i=i.sqr())0!==e[n]&&(r=r.mul(i));return r},a.prototype.iushln=function(t){n(\"number\"==typeof t&&t>=0);var e,r=t%26,i=(t-r)/26,a=67108863>>>26-r<<26-r;if(0!==r){var o=0;for(e=0;e<this.length;e++){var s=this.words[e]&a,l=(0|this.words[e])-s<<r;this.words[e]=l|o,o=s>>>26-r}o&&(this.words[e]=o,this.length++)}if(0!==i){for(e=this.length-1;e>=0;e--)this.words[e+i]=this.words[e];for(e=0;e<i;e++)this.words[e]=0;this.length+=i}return this.strip()},a.prototype.ishln=function(t){return n(0===this.negative),this.iushln(t)},a.prototype.iushrn=function(t,e,r){var i;n(\"number\"==typeof t&&t>=0),i=e?(e-e%26)/26:0;var a=t%26,o=Math.min((t-a)/26,this.length),s=67108863^67108863>>>a<<a,l=r;if(i-=o,i=Math.max(0,i),l){for(var c=0;c<o;c++)l.words[c]=this.words[c];l.length=o}if(0===o);else if(this.length>o)for(this.length-=o,c=0;c<this.length;c++)this.words[c]=this.words[c+o];else this.words[0]=0,this.length=1;var u=0;for(c=this.length-1;c>=0&&(0!==u||c>=i);c--){var h=0|this.words[c];this.words[c]=u<<26-a|h>>>a,u=h&s}return l&&0!==u&&(l.words[l.length++]=u),0===this.length&&(this.words[0]=0,this.length=1),this.strip()},a.prototype.ishrn=function(t,e,r){return n(0===this.negative),this.iushrn(t,e,r)},a.prototype.shln=function(t){return this.clone().ishln(t)},a.prototype.ushln=function(t){return this.clone().iushln(t)},a.prototype.shrn=function(t){return this.clone().ishrn(t)},a.prototype.ushrn=function(t){return this.clone().iushrn(t)},a.prototype.testn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26,i=1<<e;return!(this.length<=r)&&!!(this.words[r]&i)},a.prototype.imaskn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26;if(n(0===this.negative,\"imaskn works only with positive numbers\"),this.length<=r)return this;if(0!==e&&r++,this.length=Math.min(r,this.length),0!==e){var i=67108863^67108863>>>e<<e;this.words[this.length-1]&=i}return this.strip()},a.prototype.maskn=function(t){return this.clone().imaskn(t)},a.prototype.iaddn=function(t){return n(\"number\"==typeof t),n(t<67108864),t<0?this.isubn(-t):0!==this.negative?1===this.length&&(0|this.words[0])<t?(this.words[0]=t-(0|this.words[0]),this.negative=0,this):(this.negative=0,this.isubn(t),this.negative=1,this):this._iaddn(t)},a.prototype._iaddn=function(t){this.words[0]+=t;for(var e=0;e<this.length&&this.words[e]>=67108864;e++)this.words[e]-=67108864,e===this.length-1?this.words[e+1]=1:this.words[e+1]++;return this.length=Math.max(this.length,e+1),this},a.prototype.isubn=function(t){if(n(\"number\"==typeof t),n(t<67108864),t<0)return this.iaddn(-t);if(0!==this.negative)return this.negative=0,this.iaddn(t),this.negative=1,this;if(this.words[0]-=t,1===this.length&&this.words[0]<0)this.words[0]=-this.words[0],this.negative=1;else for(var e=0;e<this.length&&this.words[e]<0;e++)this.words[e]+=67108864,this.words[e+1]-=1;return this.strip()},a.prototype.addn=function(t){return this.clone().iaddn(t)},a.prototype.subn=function(t){return this.clone().isubn(t)},a.prototype.iabs=function(){return this.negative=0,this},a.prototype.abs=function(){return this.clone().iabs()},a.prototype._ishlnsubmul=function(t,e,r){var i,a,o=t.length+r;this._expand(o);var s=0;for(i=0;i<t.length;i++){a=(0|this.words[i+r])+s;var l=(0|t.words[i])*e;s=((a-=67108863&l)>>26)-(l/67108864|0),this.words[i+r]=67108863&a}for(;i<this.length-r;i++)s=(a=(0|this.words[i+r])+s)>>26,this.words[i+r]=67108863&a;if(0===s)return this.strip();for(n(-1===s),s=0,i=0;i<this.length;i++)s=(a=-(0|this.words[i])+s)>>26,this.words[i]=67108863&a;return this.negative=1,this.strip()},a.prototype._wordDiv=function(t,e){var r=(this.length,t.length),n=this.clone(),i=t,o=0|i.words[i.length-1];0!==(r=26-this._countBits(o))&&(i=i.ushln(r),n.iushln(r),o=0|i.words[i.length-1]);var s,l=n.length-i.length;if(\"mod\"!==e){(s=new a(null)).length=l+1,s.words=new Array(s.length);for(var c=0;c<s.length;c++)s.words[c]=0}var u=n.clone()._ishlnsubmul(i,1,l);0===u.negative&&(n=u,s&&(s.words[l]=1));for(var h=l-1;h>=0;h--){var f=67108864*(0|n.words[i.length+h])+(0|n.words[i.length+h-1]);for(f=Math.min(f/o|0,67108863),n._ishlnsubmul(i,f,h);0!==n.negative;)f--,n.negative=0,n._ishlnsubmul(i,1,h),n.isZero()||(n.negative^=1);s&&(s.words[h]=f)}return s&&s.strip(),n.strip(),\"div\"!==e&&0!==r&&n.iushrn(r),{div:s||null,mod:n}},a.prototype.divmod=function(t,e,r){return n(!t.isZero()),this.isZero()?{div:new a(0),mod:new a(0)}:0!==this.negative&&0===t.negative?(s=this.neg().divmod(t,e),\"mod\"!==e&&(i=s.div.neg()),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.iadd(t)),{div:i,mod:o}):0===this.negative&&0!==t.negative?(s=this.divmod(t.neg(),e),\"mod\"!==e&&(i=s.div.neg()),{div:i,mod:s.mod}):0!=(this.negative&t.negative)?(s=this.neg().divmod(t.neg(),e),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.isub(t)),{div:s.div,mod:o}):t.length>this.length||this.cmp(t)<0?{div:new a(0),mod:this}:1===t.length?\"div\"===e?{div:this.divn(t.words[0]),mod:null}:\"mod\"===e?{div:null,mod:new a(this.modn(t.words[0]))}:{div:this.divn(t.words[0]),mod:new a(this.modn(t.words[0]))}:this._wordDiv(t,e);var i,o,s},a.prototype.div=function(t){return this.divmod(t,\"div\",!1).div},a.prototype.mod=function(t){return this.divmod(t,\"mod\",!1).mod},a.prototype.umod=function(t){return this.divmod(t,\"mod\",!0).mod},a.prototype.divRound=function(t){var e=this.divmod(t);if(e.mod.isZero())return e.div;var r=0!==e.div.negative?e.mod.isub(t):e.mod,n=t.ushrn(1),i=t.andln(1),a=r.cmp(n);return a<0||1===i&&0===a?e.div:0!==e.div.negative?e.div.isubn(1):e.div.iaddn(1)},a.prototype.modn=function(t){n(t<=67108863);for(var e=(1<<26)%t,r=0,i=this.length-1;i>=0;i--)r=(e*r+(0|this.words[i]))%t;return r},a.prototype.idivn=function(t){n(t<=67108863);for(var e=0,r=this.length-1;r>=0;r--){var i=(0|this.words[r])+67108864*e;this.words[r]=i/t|0,e=i%t}return this.strip()},a.prototype.divn=function(t){return this.clone().idivn(t)},a.prototype.egcd=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i=new a(1),o=new a(0),s=new a(0),l=new a(1),c=0;e.isEven()&&r.isEven();)e.iushrn(1),r.iushrn(1),++c;for(var u=r.clone(),h=e.clone();!e.isZero();){for(var f=0,p=1;0==(e.words[0]&p)&&f<26;++f,p<<=1);if(f>0)for(e.iushrn(f);f-- >0;)(i.isOdd()||o.isOdd())&&(i.iadd(u),o.isub(h)),i.iushrn(1),o.iushrn(1);for(var d=0,g=1;0==(r.words[0]&g)&&d<26;++d,g<<=1);if(d>0)for(r.iushrn(d);d-- >0;)(s.isOdd()||l.isOdd())&&(s.iadd(u),l.isub(h)),s.iushrn(1),l.iushrn(1);e.cmp(r)>=0?(e.isub(r),i.isub(s),o.isub(l)):(r.isub(e),s.isub(i),l.isub(o))}return{a:s,b:l,gcd:r.iushln(c)}},a.prototype._invmp=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i,o=new a(1),s=new a(0),l=r.clone();e.cmpn(1)>0&&r.cmpn(1)>0;){for(var c=0,u=1;0==(e.words[0]&u)&&c<26;++c,u<<=1);if(c>0)for(e.iushrn(c);c-- >0;)o.isOdd()&&o.iadd(l),o.iushrn(1);for(var h=0,f=1;0==(r.words[0]&f)&&h<26;++h,f<<=1);if(h>0)for(r.iushrn(h);h-- >0;)s.isOdd()&&s.iadd(l),s.iushrn(1);e.cmp(r)>=0?(e.isub(r),o.isub(s)):(r.isub(e),s.isub(o))}return(i=0===e.cmpn(1)?o:s).cmpn(0)<0&&i.iadd(t),i},a.prototype.gcd=function(t){if(this.isZero())return t.abs();if(t.isZero())return this.abs();var e=this.clone(),r=t.clone();e.negative=0,r.negative=0;for(var n=0;e.isEven()&&r.isEven();n++)e.iushrn(1),r.iushrn(1);for(;;){for(;e.isEven();)e.iushrn(1);for(;r.isEven();)r.iushrn(1);var i=e.cmp(r);if(i<0){var a=e;e=r,r=a}else if(0===i||0===r.cmpn(1))break;e.isub(r)}return r.iushln(n)},a.prototype.invm=function(t){return this.egcd(t).a.umod(t)},a.prototype.isEven=function(){return 0==(1&this.words[0])},a.prototype.isOdd=function(){return 1==(1&this.words[0])},a.prototype.andln=function(t){return this.words[0]&t},a.prototype.bincn=function(t){n(\"number\"==typeof t);var e=t%26,r=(t-e)/26,i=1<<e;if(this.length<=r)return this._expand(r+1),this.words[r]|=i,this;for(var a=i,o=r;0!==a&&o<this.length;o++){var s=0|this.words[o];a=(s+=a)>>>26,s&=67108863,this.words[o]=s}return 0!==a&&(this.words[o]=a,this.length++),this},a.prototype.isZero=function(){return 1===this.length&&0===this.words[0]},a.prototype.cmpn=function(t){var e,r=t<0;if(0!==this.negative&&!r)return-1;if(0===this.negative&&r)return 1;if(this.strip(),this.length>1)e=1;else{r&&(t=-t),n(t<=67108863,\"Number is too big\");var i=0|this.words[0];e=i===t?0:i<t?-1:1}return 0!==this.negative?0|-e:e},a.prototype.cmp=function(t){if(0!==this.negative&&0===t.negative)return-1;if(0===this.negative&&0!==t.negative)return 1;var e=this.ucmp(t);return 0!==this.negative?0|-e:e},a.prototype.ucmp=function(t){if(this.length>t.length)return 1;if(this.length<t.length)return-1;for(var e=0,r=this.length-1;r>=0;r--){var n=0|this.words[r],i=0|t.words[r];if(n!==i){n<i?e=-1:n>i&&(e=1);break}}return e},a.prototype.gtn=function(t){return 1===this.cmpn(t)},a.prototype.gt=function(t){return 1===this.cmp(t)},a.prototype.gten=function(t){return this.cmpn(t)>=0},a.prototype.gte=function(t){return this.cmp(t)>=0},a.prototype.ltn=function(t){return-1===this.cmpn(t)},a.prototype.lt=function(t){return-1===this.cmp(t)},a.prototype.lten=function(t){return this.cmpn(t)<=0},a.prototype.lte=function(t){return this.cmp(t)<=0},a.prototype.eqn=function(t){return 0===this.cmpn(t)},a.prototype.eq=function(t){return 0===this.cmp(t)},a.red=function(t){return new w(t)},a.prototype.toRed=function(t){return n(!this.red,\"Already a number in reduction context\"),n(0===this.negative,\"red works only with positives\"),t.convertTo(this)._forceRed(t)},a.prototype.fromRed=function(){return n(this.red,\"fromRed works only with numbers in reduction context\"),this.red.convertFrom(this)},a.prototype._forceRed=function(t){return this.red=t,this},a.prototype.forceRed=function(t){return n(!this.red,\"Already a number in reduction context\"),this._forceRed(t)},a.prototype.redAdd=function(t){return n(this.red,\"redAdd works only with red numbers\"),this.red.add(this,t)},a.prototype.redIAdd=function(t){return n(this.red,\"redIAdd works only with red numbers\"),this.red.iadd(this,t)},a.prototype.redSub=function(t){return n(this.red,\"redSub works only with red numbers\"),this.red.sub(this,t)},a.prototype.redISub=function(t){return n(this.red,\"redISub works only with red numbers\"),this.red.isub(this,t)},a.prototype.redShl=function(t){return n(this.red,\"redShl works only with red numbers\"),this.red.shl(this,t)},a.prototype.redMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.mul(this,t)},a.prototype.redIMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.imul(this,t)},a.prototype.redSqr=function(){return n(this.red,\"redSqr works only with red numbers\"),this.red._verify1(this),this.red.sqr(this)},a.prototype.redISqr=function(){return n(this.red,\"redISqr works only with red numbers\"),this.red._verify1(this),this.red.isqr(this)},a.prototype.redSqrt=function(){return n(this.red,\"redSqrt works only with red numbers\"),this.red._verify1(this),this.red.sqrt(this)},a.prototype.redInvm=function(){return n(this.red,\"redInvm works only with red numbers\"),this.red._verify1(this),this.red.invm(this)},a.prototype.redNeg=function(){return n(this.red,\"redNeg works only with red numbers\"),this.red._verify1(this),this.red.neg(this)},a.prototype.redPow=function(t){return n(this.red&&!t.red,\"redPow(normalNum)\"),this.red._verify1(this),this.red.pow(this,t)};var v={k256:null,p224:null,p192:null,p25519:null};function m(t,e){this.name=t,this.p=new a(e,16),this.n=this.p.bitLength(),this.k=new a(1).iushln(this.n).isub(this.p),this.tmp=this._tmp()}function y(){m.call(this,\"k256\",\"ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffe fffffc2f\")}function x(){m.call(this,\"p224\",\"ffffffff ffffffff ffffffff ffffffff 00000000 00000000 00000001\")}function b(){m.call(this,\"p192\",\"ffffffff ffffffff ffffffff fffffffe ffffffff ffffffff\")}function _(){m.call(this,\"25519\",\"7fffffffffffffff ffffffffffffffff ffffffffffffffff ffffffffffffffed\")}function w(t){if(\"string\"==typeof t){var e=a._prime(t);this.m=e.p,this.prime=e}else n(t.gtn(1),\"modulus must be greater than 1\"),this.m=t,this.prime=null}function k(t){w.call(this,t),this.shift=this.m.bitLength(),this.shift%26!=0&&(this.shift+=26-this.shift%26),this.r=new a(1).iushln(this.shift),this.r2=this.imod(this.r.sqr()),this.rinv=this.r._invmp(this.m),this.minv=this.rinv.mul(this.r).isubn(1).div(this.m),this.minv=this.minv.umod(this.r),this.minv=this.r.sub(this.minv)}m.prototype._tmp=function(){var t=new a(null);return t.words=new Array(Math.ceil(this.n/13)),t},m.prototype.ireduce=function(t){var e,r=t;do{this.split(r,this.tmp),e=(r=(r=this.imulK(r)).iadd(this.tmp)).bitLength()}while(e>this.n);var n=e<this.n?-1:r.ucmp(this.p);return 0===n?(r.words[0]=0,r.length=1):n>0?r.isub(this.p):r.strip(),r},m.prototype.split=function(t,e){t.iushrn(this.n,0,e)},m.prototype.imulK=function(t){return t.imul(this.k)},i(y,m),y.prototype.split=function(t,e){for(var r=Math.min(t.length,9),n=0;n<r;n++)e.words[n]=t.words[n];if(e.length=r,t.length<=9)return t.words[0]=0,void(t.length=1);var i=t.words[9];for(e.words[e.length++]=4194303&i,n=10;n<t.length;n++){var a=0|t.words[n];t.words[n-10]=(4194303&a)<<4|i>>>22,i=a}i>>>=22,t.words[n-10]=i,0===i&&t.length>10?t.length-=10:t.length-=9},y.prototype.imulK=function(t){t.words[t.length]=0,t.words[t.length+1]=0,t.length+=2;for(var e=0,r=0;r<t.length;r++){var n=0|t.words[r];e+=977*n,t.words[r]=67108863&e,e=64*n+(e/67108864|0)}return 0===t.words[t.length-1]&&(t.length--,0===t.words[t.length-1]&&t.length--),t},i(x,m),i(b,m),i(_,m),_.prototype.imulK=function(t){for(var e=0,r=0;r<t.length;r++){var n=19*(0|t.words[r])+e,i=67108863&n;n>>>=26,t.words[r]=i,e=n}return 0!==e&&(t.words[t.length++]=e),t},a._prime=function(t){if(v[t])return v[t];var e;if(\"k256\"===t)e=new y;else if(\"p224\"===t)e=new x;else if(\"p192\"===t)e=new b;else{if(\"p25519\"!==t)throw new Error(\"Unknown prime \"+t);e=new _}return v[t]=e,e},w.prototype._verify1=function(t){n(0===t.negative,\"red works only with positives\"),n(t.red,\"red works only with red numbers\")},w.prototype._verify2=function(t,e){n(0==(t.negative|e.negative),\"red works only with positives\"),n(t.red&&t.red===e.red,\"red works only with red numbers\")},w.prototype.imod=function(t){return this.prime?this.prime.ireduce(t)._forceRed(this):t.umod(this.m)._forceRed(this)},w.prototype.neg=function(t){return t.isZero()?t.clone():this.m.sub(t)._forceRed(this)},w.prototype.add=function(t,e){this._verify2(t,e);var r=t.add(e);return r.cmp(this.m)>=0&&r.isub(this.m),r._forceRed(this)},w.prototype.iadd=function(t,e){this._verify2(t,e);var r=t.iadd(e);return r.cmp(this.m)>=0&&r.isub(this.m),r},w.prototype.sub=function(t,e){this._verify2(t,e);var r=t.sub(e);return r.cmpn(0)<0&&r.iadd(this.m),r._forceRed(this)},w.prototype.isub=function(t,e){this._verify2(t,e);var r=t.isub(e);return r.cmpn(0)<0&&r.iadd(this.m),r},w.prototype.shl=function(t,e){return this._verify1(t),this.imod(t.ushln(e))},w.prototype.imul=function(t,e){return this._verify2(t,e),this.imod(t.imul(e))},w.prototype.mul=function(t,e){return this._verify2(t,e),this.imod(t.mul(e))},w.prototype.isqr=function(t){return this.imul(t,t.clone())},w.prototype.sqr=function(t){return this.mul(t,t)},w.prototype.sqrt=function(t){if(t.isZero())return t.clone();var e=this.m.andln(3);if(n(e%2==1),3===e){var r=this.m.add(new a(1)).iushrn(2);return this.pow(t,r)}for(var i=this.m.subn(1),o=0;!i.isZero()&&0===i.andln(1);)o++,i.iushrn(1);n(!i.isZero());var s=new a(1).toRed(this),l=s.redNeg(),c=this.m.subn(1).iushrn(1),u=this.m.bitLength();for(u=new a(2*u*u).toRed(this);0!==this.pow(u,c).cmp(l);)u.redIAdd(l);for(var h=this.pow(u,i),f=this.pow(t,i.addn(1).iushrn(1)),p=this.pow(t,i),d=o;0!==p.cmp(s);){for(var g=p,v=0;0!==g.cmp(s);v++)g=g.redSqr();n(v<d);var m=this.pow(h,new a(1).iushln(d-v-1));f=f.redMul(m),h=m.redSqr(),p=p.redMul(h),d=v}return f},w.prototype.invm=function(t){var e=t._invmp(this.m);return 0!==e.negative?(e.negative=0,this.imod(e).redNeg()):this.imod(e)},w.prototype.pow=function(t,e){if(e.isZero())return new a(1).toRed(this);if(0===e.cmpn(1))return t.clone();var r=new Array(16);r[0]=new a(1).toRed(this),r[1]=t;for(var n=2;n<r.length;n++)r[n]=this.mul(r[n-1],t);var i=r[0],o=0,s=0,l=e.bitLength()%26;for(0===l&&(l=26),n=e.length-1;n>=0;n--){for(var c=e.words[n],u=l-1;u>=0;u--){var h=c>>u&1;i!==r[0]&&(i=this.sqr(i)),0!==h||0!==o?(o<<=1,o|=h,(4===++s||0===n&&0===u)&&(i=this.mul(i,r[o]),s=0,o=0)):s=0}l=26}return i},w.prototype.convertTo=function(t){var e=t.umod(this.m);return e===t?e.clone():e},w.prototype.convertFrom=function(t){var e=t.clone();return e.red=null,e},a.mont=function(t){return new k(t)},i(k,w),k.prototype.convertTo=function(t){return this.imod(t.ushln(this.shift))},k.prototype.convertFrom=function(t){var e=this.imod(t.mul(this.rinv));return e.red=null,e},k.prototype.imul=function(t,e){if(t.isZero()||e.isZero())return t.words[0]=0,t.length=1,t;var r=t.imul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),a=i;return i.cmp(this.m)>=0?a=i.isub(this.m):i.cmpn(0)<0&&(a=i.iadd(this.m)),a._forceRed(this)},k.prototype.mul=function(t,e){if(t.isZero()||e.isZero())return new a(0)._forceRed(this);var r=t.mul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),o=i;return i.cmp(this.m)>=0?o=i.isub(this.m):i.cmpn(0)<0&&(o=i.iadd(this.m)),o._forceRed(this)},k.prototype.invm=function(t){return this.imod(t._invmp(this.m).mul(this.r2))._forceRed(this)}}(\"undefined\"==typeof e||e,this)},{buffer:103}],95:[function(t,e,r){\"use strict\";e.exports=function(t){var e,r,n,i=t.length,a=0;for(e=0;e<i;++e)a+=t[e].length;var o=new Array(a),s=0;for(e=0;e<i;++e){var l=t[e],c=l.length;for(r=0;r<c;++r){var u=o[s++]=new Array(c-1),h=0;for(n=0;n<c;++n)n!==r&&(u[h++]=l[n]);if(1&r){var f=u[1];u[1]=u[0],u[0]=f}}}return o}},{}],96:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 1:return n=[],c(i=t,i,u,!0),n;case 2:return\"function\"==typeof e?c(t,t,e,!0):function(t,e){return n=[],c(t,e,u,!1),n}(t,e);case 3:return c(t,e,r,!1);default:throw new Error(\"box-intersect: Invalid arguments\")}var i};var n,i=t(\"typedarray-pool\"),a=t(\"./lib/sweep\"),o=t(\"./lib/intersect\");function s(t,e){for(var r=0;r<t;++r)if(!(e[r]<=e[r+t]))return!0;return!1}function l(t,e,r,n){for(var i=0,a=0,o=0,l=t.length;o<l;++o){var c=t[o];if(!s(e,c)){for(var u=0;u<2*e;++u)r[i++]=c[u];n[a++]=o}}return a}function c(t,e,r,n){var s=t.length,c=e.length;if(!(s<=0||c<=0)){var u=t[0].length>>>1;if(!(u<=0)){var h,f=i.mallocDouble(2*u*s),p=i.mallocInt32(s);if((s=l(t,u,f,p))>0){if(1===u&&n)a.init(s),h=a.sweepComplete(u,r,0,s,f,p,0,s,f,p);else{var d=i.mallocDouble(2*u*c),g=i.mallocInt32(c);(c=l(e,u,d,g))>0&&(a.init(s+c),h=1===u?a.sweepBipartite(u,r,0,s,f,p,0,c,d,g):o(u,r,n,s,f,p,c,d,g),i.free(d),i.free(g))}i.free(f),i.free(p)}return h}}}function u(t,e){n.push([t,e])}},{\"./lib/intersect\":98,\"./lib/sweep\":102,\"typedarray-pool\":545}],97:[function(t,e,r){\"use strict\";var n=\"d\",i=\"ax\",a=\"vv\",o=\"fp\",s=\"es\",l=\"rs\",c=\"re\",u=\"rb\",h=\"ri\",f=\"rp\",p=\"bs\",d=\"be\",g=\"bb\",v=\"bi\",m=\"bp\",y=\"rv\",x=\"Q\",b=[n,i,a,l,c,u,h,p,d,g,v];function _(t){var e=\"bruteForce\"+(t?\"Full\":\"Partial\"),r=[],_=b.slice();t||_.splice(3,0,o);var w=[\"function \"+e+\"(\"+_.join()+\"){\"];function k(e,o){var _=function(t,e,r){var o=\"bruteForce\"+(t?\"Red\":\"Blue\")+(e?\"Flip\":\"\")+(r?\"Full\":\"\"),_=[\"function \",o,\"(\",b.join(),\"){\",\"var \",s,\"=2*\",n,\";\"],w=\"for(var i=\"+l+\",\"+f+\"=\"+s+\"*\"+l+\";i<\"+c+\";++i,\"+f+\"+=\"+s+\"){var x0=\"+u+\"[\"+i+\"+\"+f+\"],x1=\"+u+\"[\"+i+\"+\"+f+\"+\"+n+\"],xi=\"+h+\"[i];\",k=\"for(var j=\"+p+\",\"+m+\"=\"+s+\"*\"+p+\";j<\"+d+\";++j,\"+m+\"+=\"+s+\"){var y0=\"+g+\"[\"+i+\"+\"+m+\"],\"+(r?\"y1=\"+g+\"[\"+i+\"+\"+m+\"+\"+n+\"],\":\"\")+\"yi=\"+v+\"[j];\";return t?_.push(w,x,\":\",k):_.push(k,x,\":\",w),r?_.push(\"if(y1<x0||x1<y0)continue;\"):e?_.push(\"if(y0<=x0||x1<y0)continue;\"):_.push(\"if(y0<x0||x1<y0)continue;\"),_.push(\"for(var k=\"+i+\"+1;k<\"+n+\";++k){var r0=\"+u+\"[k+\"+f+\"],r1=\"+u+\"[k+\"+n+\"+\"+f+\"],b0=\"+g+\"[k+\"+m+\"],b1=\"+g+\"[k+\"+n+\"+\"+m+\"];if(r1<b0||b1<r0)continue \"+x+\";}var \"+y+\"=\"+a+\"(\"),e?_.push(\"yi,xi\"):_.push(\"xi,yi\"),_.push(\");if(\"+y+\"!==void 0)return \"+y+\";}}}\"),{name:o,code:_.join(\"\")}}(e,o,t);r.push(_.code),w.push(\"return \"+_.name+\"(\"+b.join()+\");\")}w.push(\"if(\"+c+\"-\"+l+\">\"+d+\"-\"+p+\"){\"),t?(k(!0,!1),w.push(\"}else{\"),k(!1,!1)):(w.push(\"if(\"+o+\"){\"),k(!0,!0),w.push(\"}else{\"),k(!0,!1),w.push(\"}}else{if(\"+o+\"){\"),k(!1,!0),w.push(\"}else{\"),k(!1,!1),w.push(\"}\")),w.push(\"}}return \"+e);var T=r.join(\"\")+w.join(\"\");return new Function(T)()}r.partial=_(!1),r.full=_(!0)},{}],98:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,u,S,E,C,L){!function(t,e){var r=8*i.log2(e+1)*(t+1)|0,a=i.nextPow2(b*r);w.length<a&&(n.free(w),w=n.mallocInt32(a));var o=i.nextPow2(_*r);k<o&&(n.free(k),k=n.mallocDouble(o))}(t,a+E);var P,O=0,z=2*t;T(O++,0,0,a,0,E,r?16:0,-1/0,1/0),r||T(O++,0,0,E,0,a,1,-1/0,1/0);for(;O>0;){var I=(O-=1)*b,D=w[I],R=w[I+1],F=w[I+2],B=w[I+3],N=w[I+4],j=w[I+5],U=O*_,V=k[U],q=k[U+1],H=1&j,G=!!(16&j),Y=u,W=S,X=C,Z=L;if(H&&(Y=C,W=L,X=u,Z=S),!(2&j&&(F=v(t,D,R,F,Y,W,q),R>=F)||4&j&&(R=m(t,D,R,F,Y,W,V))>=F)){var J=F-R,K=N-B;if(G){if(t*J*(J+K)<p){if(void 0!==(P=l.scanComplete(t,D,e,R,F,Y,W,B,N,X,Z)))return P;continue}}else{if(t*Math.min(J,K)<h){if(void 0!==(P=o(t,D,e,H,R,F,Y,W,B,N,X,Z)))return P;continue}if(t*J*K<f){if(void 0!==(P=l.scanBipartite(t,D,e,H,R,F,Y,W,B,N,X,Z)))return P;continue}}var $=d(t,D,R,F,Y,W,V,q);if(R<$)if(t*($-R)<h){if(void 0!==(P=s(t,D+1,e,R,$,Y,W,B,N,X,Z)))return P}else if(D===t-2){if(void 0!==(P=H?l.sweepBipartite(t,e,B,N,X,Z,R,$,Y,W):l.sweepBipartite(t,e,R,$,Y,W,B,N,X,Z)))return P}else T(O++,D+1,R,$,B,N,H,-1/0,1/0),T(O++,D+1,B,N,R,$,1^H,-1/0,1/0);if($<F){var Q=c(t,D,B,N,X,Z),tt=X[z*Q+D],et=g(t,D,Q,N,X,Z,tt);if(et<N&&T(O++,D,$,F,et,N,(4|H)+(G?16:0),tt,q),B<Q&&T(O++,D,$,F,B,Q,(2|H)+(G?16:0),V,tt),Q+1===et){if(void 0!==(P=G?M(t,D,e,$,F,Y,W,Q,X,Z[Q]):A(t,D,e,H,$,F,Y,W,Q,X,Z[Q])))return P}else if(Q<et){var rt;if(G){if(rt=y(t,D,$,F,Y,W,tt),$<rt){var nt=g(t,D,$,rt,Y,W,tt);if(D===t-2){if($<nt&&void 0!==(P=l.sweepComplete(t,e,$,nt,Y,W,Q,et,X,Z)))return P;if(nt<rt&&void 0!==(P=l.sweepBipartite(t,e,nt,rt,Y,W,Q,et,X,Z)))return P}else $<nt&&T(O++,D+1,$,nt,Q,et,16,-1/0,1/0),nt<rt&&(T(O++,D+1,nt,rt,Q,et,0,-1/0,1/0),T(O++,D+1,Q,et,nt,rt,1,-1/0,1/0))}}else rt=H?x(t,D,$,F,Y,W,tt):y(t,D,$,F,Y,W,tt),$<rt&&(D===t-2?P=H?l.sweepBipartite(t,e,Q,et,X,Z,$,rt,Y,W):l.sweepBipartite(t,e,$,rt,Y,W,Q,et,X,Z):(T(O++,D+1,$,rt,Q,et,H,-1/0,1/0),T(O++,D+1,Q,et,$,rt,1^H,-1/0,1/0)))}}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./brute\"),o=a.partial,s=a.full,l=t(\"./sweep\"),c=t(\"./median\"),u=t(\"./partition\"),h=128,f=1<<22,p=1<<22,d=u(\"!(lo>=p0)&&!(p1>=hi)\",[\"p0\",\"p1\"]),g=u(\"lo===p0\",[\"p0\"]),v=u(\"lo<p0\",[\"p0\"]),m=u(\"hi<=p0\",[\"p0\"]),y=u(\"lo<=p0&&p0<=hi\",[\"p0\"]),x=u(\"lo<p0&&p0<=hi\",[\"p0\"]),b=6,_=2,w=n.mallocInt32(1024),k=n.mallocDouble(1024);function T(t,e,r,n,i,a,o,s,l){var c=b*t;w[c]=e,w[c+1]=r,w[c+2]=n,w[c+3]=i,w[c+4]=a,w[c+5]=o;var u=_*t;k[u]=s,k[u+1]=l}function A(t,e,r,n,i,a,o,s,l,c,u){var h=2*t,f=l*h,p=c[f+e];t:for(var d=i,g=i*h;d<a;++d,g+=h){var v=o[g+e],m=o[g+e+t];if(!(p<v||m<p)&&(!n||p!==v)){for(var y,x=s[d],b=e+1;b<t;++b){v=o[g+b],m=o[g+b+t];var _=c[f+b],w=c[f+b+t];if(m<_||w<v)continue t}if(void 0!==(y=n?r(u,x):r(x,u)))return y}}}function M(t,e,r,n,i,a,o,s,l,c){var u=2*t,h=s*u,f=l[h+e];t:for(var p=n,d=n*u;p<i;++p,d+=u){var g=o[p];if(g!==c){var v=a[d+e],m=a[d+e+t];if(!(f<v||m<f)){for(var y=e+1;y<t;++y){v=a[d+y],m=a[d+y+t];var x=l[h+y],b=l[h+y+t];if(m<x||b<v)continue t}var _=r(g,c);if(void 0!==_)return _}}}}},{\"./brute\":97,\"./median\":99,\"./partition\":100,\"./sweep\":102,\"bit-twiddle\":92,\"typedarray-pool\":545}],99:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,o,s,l){if(o<=r+1)return r;var c=r,u=o,h=o+r>>>1,f=2*t,p=h,d=s[f*h+e];for(;c<u;){if(u-c<i){a(t,e,c,u,s,l),d=s[f*h+e];break}var g=u-c,v=Math.random()*g+c|0,m=s[f*v+e],y=Math.random()*g+c|0,x=s[f*y+e],b=Math.random()*g+c|0,_=s[f*b+e];m<=x?_>=x?(p=y,d=x):m>=_?(p=v,d=m):(p=b,d=_):x>=_?(p=y,d=x):_>=m?(p=v,d=m):(p=b,d=_);for(var w=f*(u-1),k=f*p,T=0;T<f;++T,++w,++k){var A=s[w];s[w]=s[k],s[k]=A}var M=l[u-1];l[u-1]=l[p],l[p]=M,p=n(t,e,c,u-1,s,l,d);for(var w=f*(u-1),k=f*p,T=0;T<f;++T,++w,++k){var A=s[w];s[w]=s[k],s[k]=A}var M=l[u-1];if(l[u-1]=l[p],l[p]=M,h<p){for(u=p-1;c<u&&s[f*(u-1)+e]===d;)u-=1;u+=1}else{if(!(p<h))break;for(c=p+1;c<u&&s[f*c+e]===d;)c+=1}}return n(t,e,r,h,s,l,s[f*h+e])};var n=t(\"./partition\")(\"lo<p0\",[\"p0\"]),i=8;function a(t,e,r,n,i,a){for(var o=2*t,s=o*(r+1)+e,l=r+1;l<n;++l,s+=o)for(var c=i[s],u=l,h=o*(l-1);u>r&&i[h+e]>c;--u,h-=o){for(var f=h,p=h+o,d=0;d<o;++d,++f,++p){var g=i[f];i[f]=i[p],i[p]=g}var v=a[u];a[u]=a[u-1],a[u-1]=v}}},{\"./partition\":100}],100:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=\"abcdef\".split(\"\").concat(e),i=[];t.indexOf(\"lo\")>=0&&i.push(\"lo=e[k+n]\");t.indexOf(\"hi\")>=0&&i.push(\"hi=e[k+o]\");return r.push(n.replace(\"_\",i.join()).replace(\"$\",t)),Function.apply(void 0,r)};var n=\"for(var j=2*a,k=j*c,l=k,m=c,n=b,o=a+b,p=c;d>p;++p,k+=j){var _;if($)if(m===p)m+=1,l+=j;else{for(var s=0;j>s;++s){var t=e[k+s];e[k+s]=e[l],e[l++]=t}var u=f[p];f[p]=f[m],f[m++]=u}}return m\"},{}],101:[function(t,e,r){\"use strict\";e.exports=function(t,e){e<=4*n?i(0,e-1,t):function t(e,r,h){var f=(r-e+1)/6|0,p=e+f,d=r-f,g=e+r>>1,v=g-f,m=g+f,y=p,x=v,b=g,_=m,w=d,k=e+1,T=r-1,A=0;c(y,x,h)&&(A=y,y=x,x=A);c(_,w,h)&&(A=_,_=w,w=A);c(y,b,h)&&(A=y,y=b,b=A);c(x,b,h)&&(A=x,x=b,b=A);c(y,_,h)&&(A=y,y=_,_=A);c(b,_,h)&&(A=b,b=_,_=A);c(x,w,h)&&(A=x,x=w,w=A);c(x,b,h)&&(A=x,x=b,b=A);c(_,w,h)&&(A=_,_=w,w=A);var M=h[2*x];var S=h[2*x+1];var E=h[2*_];var C=h[2*_+1];var L=2*y;var P=2*b;var O=2*w;var z=2*p;var I=2*g;var D=2*d;for(var R=0;R<2;++R){var F=h[L+R],B=h[P+R],N=h[O+R];h[z+R]=F,h[I+R]=B,h[D+R]=N}o(v,e,h);o(m,r,h);for(var j=k;j<=T;++j)if(u(j,M,S,h))j!==k&&a(j,k,h),++k;else if(!u(j,E,C,h))for(;;){if(u(T,E,C,h)){u(T,M,S,h)?(s(j,k,T,h),++k,--T):(a(j,T,h),--T);break}if(--T<j)break}l(e,k-1,M,S,h);l(r,T+1,E,C,h);k-2-e<=n?i(e,k-2,h):t(e,k-2,h);r-(T+2)<=n?i(T+2,r,h):t(T+2,r,h);T-k<=n?i(k,T,h):t(k,T,h)}(0,e-1,t)};var n=32;function i(t,e,r){for(var n=2*(t+1),i=t+1;i<=e;++i){for(var a=r[n++],o=r[n++],s=i,l=n-2;s-- >t;){var c=r[l-2],u=r[l-1];if(c<a)break;if(c===a&&u<o)break;r[l]=c,r[l+1]=u,l-=2}r[l]=a,r[l+1]=o}}function a(t,e,r){e*=2;var n=r[t*=2],i=r[t+1];r[t]=r[e],r[t+1]=r[e+1],r[e]=n,r[e+1]=i}function o(t,e,r){e*=2,r[t*=2]=r[e],r[t+1]=r[e+1]}function s(t,e,r,n){e*=2,r*=2;var i=n[t*=2],a=n[t+1];n[t]=n[e],n[t+1]=n[e+1],n[e]=n[r],n[e+1]=n[r+1],n[r]=i,n[r+1]=a}function l(t,e,r,n,i){e*=2,i[t*=2]=i[e],i[e]=r,i[t+1]=i[e+1],i[e+1]=n}function c(t,e,r){e*=2;var n=r[t*=2],i=r[e];return!(n<i)&&(n!==i||r[t+1]>r[e+1])}function u(t,e,r,n){var i=n[t*=2];return i<e||i===e&&n[t+1]<r}},{}],102:[function(t,e,r){\"use strict\";e.exports={init:function(t){var e=i.nextPow2(t);s.length<e&&(n.free(s),s=n.mallocInt32(e));l.length<e&&(n.free(l),l=n.mallocInt32(e));c.length<e&&(n.free(c),c=n.mallocInt32(e));u.length<e&&(n.free(u),u=n.mallocInt32(e));h.length<e&&(n.free(h),h=n.mallocInt32(e));f.length<e&&(n.free(f),f=n.mallocInt32(e));var r=8*e;p.length<r&&(n.free(p),p=n.mallocDouble(r))},sweepBipartite:function(t,e,r,n,i,h,f,v,m,y){for(var x=0,b=2*t,_=t-1,w=b-1,k=r;k<n;++k){var T=h[k],A=b*k;p[x++]=i[A+_],p[x++]=-(T+1),p[x++]=i[A+w],p[x++]=T}for(var k=f;k<v;++k){var T=y[k]+o,M=b*k;p[x++]=m[M+_],p[x++]=-T,p[x++]=m[M+w],p[x++]=T}var S=x>>>1;a(p,S);for(var E=0,C=0,k=0;k<S;++k){var L=0|p[2*k+1];if(L>=o)d(c,u,C--,L=L-o|0);else if(L>=0)d(s,l,E--,L);else if(L<=-o){L=-L-o|0;for(var P=0;P<E;++P){var O=e(s[P],L);if(void 0!==O)return O}g(c,u,C++,L)}else{L=-L-1|0;for(var P=0;P<C;++P){var O=e(L,c[P]);if(void 0!==O)return O}g(s,l,E++,L)}}},sweepComplete:function(t,e,r,n,i,o,v,m,y,x){for(var b=0,_=2*t,w=t-1,k=_-1,T=r;T<n;++T){var A=o[T]+1<<1,M=_*T;p[b++]=i[M+w],p[b++]=-A,p[b++]=i[M+k],p[b++]=A}for(var T=v;T<m;++T){var A=x[T]+1<<1,S=_*T;p[b++]=y[S+w],p[b++]=1|-A,p[b++]=y[S+k],p[b++]=1|A}var E=b>>>1;a(p,E);for(var C=0,L=0,P=0,T=0;T<E;++T){var O=0|p[2*T+1],z=1&O;if(T<E-1&&O>>1==p[2*T+3]>>1&&(z=2,T+=1),O<0){for(var I=-(O>>1)-1,D=0;D<P;++D){var R=e(h[D],I);if(void 0!==R)return R}if(0!==z)for(var D=0;D<C;++D){var R=e(s[D],I);if(void 0!==R)return R}if(1!==z)for(var D=0;D<L;++D){var R=e(c[D],I);if(void 0!==R)return R}0===z?g(s,l,C++,I):1===z?g(c,u,L++,I):2===z&&g(h,f,P++,I)}else{var I=(O>>1)-1;0===z?d(s,l,C--,I):1===z?d(c,u,L--,I):2===z&&d(h,f,P--,I)}}},scanBipartite:function(t,e,r,n,i,c,u,h,f,v,m,y){var x=0,b=2*t,_=e,w=e+t,k=1,T=1;n?T=o:k=o;for(var A=i;A<c;++A){var M=A+k,S=b*A;p[x++]=u[S+_],p[x++]=-M,p[x++]=u[S+w],p[x++]=M}for(var A=f;A<v;++A){var M=A+T,E=b*A;p[x++]=m[E+_],p[x++]=-M}var C=x>>>1;a(p,C);for(var L=0,A=0;A<C;++A){var P=0|p[2*A+1];if(P<0){var M=-P,O=!1;if(M>=o?(O=!n,M-=o):(O=!!n,M-=1),O)g(s,l,L++,M);else{var z=y[M],I=b*M,D=m[I+e+1],R=m[I+e+1+t];t:for(var F=0;F<L;++F){var B=s[F],N=b*B;if(!(R<u[N+e+1]||u[N+e+1+t]<D)){for(var j=e+2;j<t;++j)if(m[I+j+t]<u[N+j]||u[N+j+t]<m[I+j])continue t;var U,V=h[B];if(void 0!==(U=n?r(z,V):r(V,z)))return U}}}}else d(s,l,L--,P-k)}},scanComplete:function(t,e,r,n,i,l,c,u,h,f,d){for(var g=0,v=2*t,m=e,y=e+t,x=n;x<i;++x){var b=x+o,_=v*x;p[g++]=l[_+m],p[g++]=-b,p[g++]=l[_+y],p[g++]=b}for(var x=u;x<h;++x){var b=x+1,w=v*x;p[g++]=f[w+m],p[g++]=-b}var k=g>>>1;a(p,k);for(var T=0,x=0;x<k;++x){var A=0|p[2*x+1];if(A<0){var b=-A;if(b>=o)s[T++]=b-o;else{var M=d[b-=1],S=v*b,E=f[S+e+1],C=f[S+e+1+t];t:for(var L=0;L<T;++L){var P=s[L],O=c[P];if(O===M)break;var z=v*P;if(!(C<l[z+e+1]||l[z+e+1+t]<E)){for(var I=e+2;I<t;++I)if(f[S+I+t]<l[z+I]||l[z+I+t]<f[S+I])continue t;var D=r(O,M);if(void 0!==D)return D}}}}else{for(var b=A-o,L=T-1;L>=0;--L)if(s[L]===b){for(var I=L+1;I<T;++I)s[I-1]=s[I];break}--T}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./sort\"),o=1<<28,s=n.mallocInt32(1024),l=n.mallocInt32(1024),c=n.mallocInt32(1024),u=n.mallocInt32(1024),h=n.mallocInt32(1024),f=n.mallocInt32(1024),p=n.mallocDouble(8192);function d(t,e,r,n){var i=e[n],a=t[r-1];t[i]=a,e[a]=i}function g(t,e,r,n){t[r]=n,e[n]=r}},{\"./sort\":101,\"bit-twiddle\":92,\"typedarray-pool\":545}],103:[function(t,e,r){},{}],104:[function(t,e,r){var n=Object.create||function(t){var e=function(){};return e.prototype=t,new e},i=Object.keys||function(t){var e=[];for(var r in t)Object.prototype.hasOwnProperty.call(t,r)&&e.push(r);return r},a=Function.prototype.bind||function(t){var e=this;return function(){return e.apply(t,arguments)}};function o(){this._events&&Object.prototype.hasOwnProperty.call(this,\"_events\")||(this._events=n(null),this._eventsCount=0),this._maxListeners=this._maxListeners||void 0}e.exports=o,o.EventEmitter=o,o.prototype._events=void 0,o.prototype._maxListeners=void 0;var s,l=10;try{var c={};Object.defineProperty&&Object.defineProperty(c,\"x\",{value:0}),s=0===c.x}catch(t){s=!1}function u(t){return void 0===t._maxListeners?o.defaultMaxListeners:t._maxListeners}function h(t,e,r,i){var a,o,s;if(\"function\"!=typeof r)throw new TypeError('\"listener\" argument must be a function');if((o=t._events)?(o.newListener&&(t.emit(\"newListener\",e,r.listener?r.listener:r),o=t._events),s=o[e]):(o=t._events=n(null),t._eventsCount=0),s){if(\"function\"==typeof s?s=o[e]=i?[r,s]:[s,r]:i?s.unshift(r):s.push(r),!s.warned&&(a=u(t))&&a>0&&s.length>a){s.warned=!0;var l=new Error(\"Possible EventEmitter memory leak detected. \"+s.length+' \"'+String(e)+'\" listeners added. Use emitter.setMaxListeners() to increase limit.');l.name=\"MaxListenersExceededWarning\",l.emitter=t,l.type=e,l.count=s.length,\"object\"==typeof console&&console.warn&&console.warn(\"%s: %s\",l.name,l.message)}}else s=o[e]=r,++t._eventsCount;return t}function f(){if(!this.fired)switch(this.target.removeListener(this.type,this.wrapFn),this.fired=!0,arguments.length){case 0:return this.listener.call(this.target);case 1:return this.listener.call(this.target,arguments[0]);case 2:return this.listener.call(this.target,arguments[0],arguments[1]);case 3:return this.listener.call(this.target,arguments[0],arguments[1],arguments[2]);default:for(var t=new Array(arguments.length),e=0;e<t.length;++e)t[e]=arguments[e];this.listener.apply(this.target,t)}}function p(t,e,r){var n={fired:!1,wrapFn:void 0,target:t,type:e,listener:r},i=a.call(f,n);return i.listener=r,n.wrapFn=i,i}function d(t,e,r){var n=t._events;if(!n)return[];var i=n[e];return i?\"function\"==typeof i?r?[i.listener||i]:[i]:r?function(t){for(var e=new Array(t.length),r=0;r<e.length;++r)e[r]=t[r].listener||t[r];return e}(i):v(i,i.length):[]}function g(t){var e=this._events;if(e){var r=e[t];if(\"function\"==typeof r)return 1;if(r)return r.length}return 0}function v(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t[n];return r}s?Object.defineProperty(o,\"defaultMaxListeners\",{enumerable:!0,get:function(){return l},set:function(t){if(\"number\"!=typeof t||t<0||t!=t)throw new TypeError('\"defaultMaxListeners\" must be a positive number');l=t}}):o.defaultMaxListeners=l,o.prototype.setMaxListeners=function(t){if(\"number\"!=typeof t||t<0||isNaN(t))throw new TypeError('\"n\" argument must be a positive number');return this._maxListeners=t,this},o.prototype.getMaxListeners=function(){return u(this)},o.prototype.emit=function(t){var e,r,n,i,a,o,s=\"error\"===t;if(o=this._events)s=s&&null==o.error;else if(!s)return!1;if(s){if(arguments.length>1&&(e=arguments[1]),e instanceof Error)throw e;var l=new Error('Unhandled \"error\" event. ('+e+\")\");throw l.context=e,l}if(!(r=o[t]))return!1;var c=\"function\"==typeof r;switch(n=arguments.length){case 1:!function(t,e,r){if(e)t.call(r);else for(var n=t.length,i=v(t,n),a=0;a<n;++a)i[a].call(r)}(r,c,this);break;case 2:!function(t,e,r,n){if(e)t.call(r,n);else for(var i=t.length,a=v(t,i),o=0;o<i;++o)a[o].call(r,n)}(r,c,this,arguments[1]);break;case 3:!function(t,e,r,n,i){if(e)t.call(r,n,i);else for(var a=t.length,o=v(t,a),s=0;s<a;++s)o[s].call(r,n,i)}(r,c,this,arguments[1],arguments[2]);break;case 4:!function(t,e,r,n,i,a){if(e)t.call(r,n,i,a);else for(var o=t.length,s=v(t,o),l=0;l<o;++l)s[l].call(r,n,i,a)}(r,c,this,arguments[1],arguments[2],arguments[3]);break;default:for(i=new Array(n-1),a=1;a<n;a++)i[a-1]=arguments[a];!function(t,e,r,n){if(e)t.apply(r,n);else for(var i=t.length,a=v(t,i),o=0;o<i;++o)a[o].apply(r,n)}(r,c,this,i)}return!0},o.prototype.addListener=function(t,e){return h(this,t,e,!1)},o.prototype.on=o.prototype.addListener,o.prototype.prependListener=function(t,e){return h(this,t,e,!0)},o.prototype.once=function(t,e){if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');return this.on(t,p(this,t,e)),this},o.prototype.prependOnceListener=function(t,e){if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');return this.prependListener(t,p(this,t,e)),this},o.prototype.removeListener=function(t,e){var r,i,a,o,s;if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');if(!(i=this._events))return this;if(!(r=i[t]))return this;if(r===e||r.listener===e)0==--this._eventsCount?this._events=n(null):(delete i[t],i.removeListener&&this.emit(\"removeListener\",t,r.listener||e));else if(\"function\"!=typeof r){for(a=-1,o=r.length-1;o>=0;o--)if(r[o]===e||r[o].listener===e){s=r[o].listener,a=o;break}if(a<0)return this;0===a?r.shift():function(t,e){for(var r=e,n=r+1,i=t.length;n<i;r+=1,n+=1)t[r]=t[n];t.pop()}(r,a),1===r.length&&(i[t]=r[0]),i.removeListener&&this.emit(\"removeListener\",t,s||e)}return this},o.prototype.removeAllListeners=function(t){var e,r,a;if(!(r=this._events))return this;if(!r.removeListener)return 0===arguments.length?(this._events=n(null),this._eventsCount=0):r[t]&&(0==--this._eventsCount?this._events=n(null):delete r[t]),this;if(0===arguments.length){var o,s=i(r);for(a=0;a<s.length;++a)\"removeListener\"!==(o=s[a])&&this.removeAllListeners(o);return this.removeAllListeners(\"removeListener\"),this._events=n(null),this._eventsCount=0,this}if(\"function\"==typeof(e=r[t]))this.removeListener(t,e);else if(e)for(a=e.length-1;a>=0;a--)this.removeListener(t,e[a]);return this},o.prototype.listeners=function(t){return d(this,t,!0)},o.prototype.rawListeners=function(t){return d(this,t,!1)},o.listenerCount=function(t,e){return\"function\"==typeof t.listenerCount?t.listenerCount(e):g.call(t,e)},o.prototype.listenerCount=g,o.prototype.eventNames=function(){return this._eventsCount>0?Reflect.ownKeys(this._events):[]}},{}],105:[function(t,e,r){(function(e){\"use strict\";var n=t(\"base64-js\"),i=t(\"ieee754\");r.Buffer=e,r.SlowBuffer=function(t){+t!=t&&(t=0);return e.alloc(+t)},r.INSPECT_MAX_BYTES=50;var a=2147483647;function o(t){if(t>a)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"');var r=new Uint8Array(t);return r.__proto__=e.prototype,r}function e(t,e,r){if(\"number\"==typeof t){if(\"string\"==typeof e)throw new TypeError('The \"string\" argument must be of type string. Received type number');return c(t)}return s(t,e,r)}function s(t,r,n){if(\"string\"==typeof t)return function(t,r){\"string\"==typeof r&&\"\"!==r||(r=\"utf8\");if(!e.isEncoding(r))throw new TypeError(\"Unknown encoding: \"+r);var n=0|f(t,r),i=o(n),a=i.write(t,r);a!==n&&(i=i.slice(0,a));return i}(t,r);if(ArrayBuffer.isView(t))return u(t);if(null==t)throw TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t);if(N(t,ArrayBuffer)||t&&N(t.buffer,ArrayBuffer))return function(t,r,n){if(r<0||t.byteLength<r)throw new RangeError('\"offset\" is outside of buffer bounds');if(t.byteLength<r+(n||0))throw new RangeError('\"length\" is outside of buffer bounds');var i;i=void 0===r&&void 0===n?new Uint8Array(t):void 0===n?new Uint8Array(t,r):new Uint8Array(t,r,n);return i.__proto__=e.prototype,i}(t,r,n);if(\"number\"==typeof t)throw new TypeError('The \"value\" argument must not be of type number. Received type number');var i=t.valueOf&&t.valueOf();if(null!=i&&i!==t)return e.from(i,r,n);var a=function(t){if(e.isBuffer(t)){var r=0|h(t.length),n=o(r);return 0===n.length?n:(t.copy(n,0,0,r),n)}if(void 0!==t.length)return\"number\"!=typeof t.length||j(t.length)?o(0):u(t);if(\"Buffer\"===t.type&&Array.isArray(t.data))return u(t.data)}(t);if(a)return a;if(\"undefined\"!=typeof Symbol&&null!=Symbol.toPrimitive&&\"function\"==typeof t[Symbol.toPrimitive])return e.from(t[Symbol.toPrimitive](\"string\"),r,n);throw new TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t)}function l(t){if(\"number\"!=typeof t)throw new TypeError('\"size\" argument must be of type number');if(t<0)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"')}function c(t){return l(t),o(t<0?0:0|h(t))}function u(t){for(var e=t.length<0?0:0|h(t.length),r=o(e),n=0;n<e;n+=1)r[n]=255&t[n];return r}function h(t){if(t>=a)throw new RangeError(\"Attempt to allocate Buffer larger than maximum size: 0x\"+a.toString(16)+\" bytes\");return 0|t}function f(t,r){if(e.isBuffer(t))return t.length;if(ArrayBuffer.isView(t)||N(t,ArrayBuffer))return t.byteLength;if(\"string\"!=typeof t)throw new TypeError('The \"string\" argument must be one of type string, Buffer, or ArrayBuffer. Received type '+typeof t);var n=t.length,i=arguments.length>2&&!0===arguments[2];if(!i&&0===n)return 0;for(var a=!1;;)switch(r){case\"ascii\":case\"latin1\":case\"binary\":return n;case\"utf8\":case\"utf-8\":return R(t).length;case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return 2*n;case\"hex\":return n>>>1;case\"base64\":return F(t).length;default:if(a)return i?-1:R(t).length;r=(\"\"+r).toLowerCase(),a=!0}}function p(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function d(t,r,n,i,a){if(0===t.length)return-1;if(\"string\"==typeof n?(i=n,n=0):n>2147483647?n=2147483647:n<-2147483648&&(n=-2147483648),j(n=+n)&&(n=a?0:t.length-1),n<0&&(n=t.length+n),n>=t.length){if(a)return-1;n=t.length-1}else if(n<0){if(!a)return-1;n=0}if(\"string\"==typeof r&&(r=e.from(r,i)),e.isBuffer(r))return 0===r.length?-1:g(t,r,n,i,a);if(\"number\"==typeof r)return r&=255,\"function\"==typeof Uint8Array.prototype.indexOf?a?Uint8Array.prototype.indexOf.call(t,r,n):Uint8Array.prototype.lastIndexOf.call(t,r,n):g(t,[r],n,i,a);throw new TypeError(\"val must be string, number or Buffer\")}function g(t,e,r,n,i){var a,o=1,s=t.length,l=e.length;if(void 0!==n&&(\"ucs2\"===(n=String(n).toLowerCase())||\"ucs-2\"===n||\"utf16le\"===n||\"utf-16le\"===n)){if(t.length<2||e.length<2)return-1;o=2,s/=2,l/=2,r/=2}function c(t,e){return 1===o?t[e]:t.readUInt16BE(e*o)}if(i){var u=-1;for(a=r;a<s;a++)if(c(t,a)===c(e,-1===u?0:a-u)){if(-1===u&&(u=a),a-u+1===l)return u*o}else-1!==u&&(a-=a-u),u=-1}else for(r+l>s&&(r=s-l),a=r;a>=0;a--){for(var h=!0,f=0;f<l;f++)if(c(t,a+f)!==c(e,f)){h=!1;break}if(h)return a}return-1}function v(t,e,r,n){r=Number(r)||0;var i=t.length-r;n?(n=Number(n))>i&&(n=i):n=i;var a=e.length;n>a/2&&(n=a/2);for(var o=0;o<n;++o){var s=parseInt(e.substr(2*o,2),16);if(j(s))return o;t[r+o]=s}return o}function m(t,e,r,n){return B(R(e,t.length-r),t,r,n)}function y(t,e,r,n){return B(function(t){for(var e=[],r=0;r<t.length;++r)e.push(255&t.charCodeAt(r));return e}(e),t,r,n)}function x(t,e,r,n){return y(t,e,r,n)}function b(t,e,r,n){return B(F(e),t,r,n)}function _(t,e,r,n){return B(function(t,e){for(var r,n,i,a=[],o=0;o<t.length&&!((e-=2)<0);++o)r=t.charCodeAt(o),n=r>>8,i=r%256,a.push(i),a.push(n);return a}(e,t.length-r),t,r,n)}function w(t,e,r){return 0===e&&r===t.length?n.fromByteArray(t):n.fromByteArray(t.slice(e,r))}function k(t,e,r){r=Math.min(t.length,r);for(var n=[],i=e;i<r;){var a,o,s,l,c=t[i],u=null,h=c>239?4:c>223?3:c>191?2:1;if(i+h<=r)switch(h){case 1:c<128&&(u=c);break;case 2:128==(192&(a=t[i+1]))&&(l=(31&c)<<6|63&a)>127&&(u=l);break;case 3:a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&(l=(15&c)<<12|(63&a)<<6|63&o)>2047&&(l<55296||l>57343)&&(u=l);break;case 4:a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&(l=(15&c)<<18|(63&a)<<12|(63&o)<<6|63&s)>65535&&l<1114112&&(u=l)}null===u?(u=65533,h=1):u>65535&&(u-=65536,n.push(u>>>10&1023|55296),u=56320|1023&u),n.push(u),i+=h}return function(t){var e=t.length;if(e<=T)return String.fromCharCode.apply(String,t);var r=\"\",n=0;for(;n<e;)r+=String.fromCharCode.apply(String,t.slice(n,n+=T));return r}(n)}r.kMaxLength=a,e.TYPED_ARRAY_SUPPORT=function(){try{var t=new Uint8Array(1);return t.__proto__={__proto__:Uint8Array.prototype,foo:function(){return 42}},42===t.foo()}catch(t){return!1}}(),e.TYPED_ARRAY_SUPPORT||\"undefined\"==typeof console||\"function\"!=typeof console.error||console.error(\"This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support.\"),Object.defineProperty(e.prototype,\"parent\",{enumerable:!0,get:function(){if(e.isBuffer(this))return this.buffer}}),Object.defineProperty(e.prototype,\"offset\",{enumerable:!0,get:function(){if(e.isBuffer(this))return this.byteOffset}}),\"undefined\"!=typeof Symbol&&null!=Symbol.species&&e[Symbol.species]===e&&Object.defineProperty(e,Symbol.species,{value:null,configurable:!0,enumerable:!1,writable:!1}),e.poolSize=8192,e.from=function(t,e,r){return s(t,e,r)},e.prototype.__proto__=Uint8Array.prototype,e.__proto__=Uint8Array,e.alloc=function(t,e,r){return function(t,e,r){return l(t),t<=0?o(t):void 0!==e?\"string\"==typeof r?o(t).fill(e,r):o(t).fill(e):o(t)}(t,e,r)},e.allocUnsafe=function(t){return c(t)},e.allocUnsafeSlow=function(t){return c(t)},e.isBuffer=function(t){return null!=t&&!0===t._isBuffer&&t!==e.prototype},e.compare=function(t,r){if(N(t,Uint8Array)&&(t=e.from(t,t.offset,t.byteLength)),N(r,Uint8Array)&&(r=e.from(r,r.offset,r.byteLength)),!e.isBuffer(t)||!e.isBuffer(r))throw new TypeError('The \"buf1\", \"buf2\" arguments must be one of type Buffer or Uint8Array');if(t===r)return 0;for(var n=t.length,i=r.length,a=0,o=Math.min(n,i);a<o;++a)if(t[a]!==r[a]){n=t[a],i=r[a];break}return n<i?-1:i<n?1:0},e.isEncoding=function(t){switch(String(t).toLowerCase()){case\"hex\":case\"utf8\":case\"utf-8\":case\"ascii\":case\"latin1\":case\"binary\":case\"base64\":case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return!0;default:return!1}},e.concat=function(t,r){if(!Array.isArray(t))throw new TypeError('\"list\" argument must be an Array of Buffers');if(0===t.length)return e.alloc(0);var n;if(void 0===r)for(r=0,n=0;n<t.length;++n)r+=t[n].length;var i=e.allocUnsafe(r),a=0;for(n=0;n<t.length;++n){var o=t[n];if(N(o,Uint8Array)&&(o=e.from(o)),!e.isBuffer(o))throw new TypeError('\"list\" argument must be an Array of Buffers');o.copy(i,a),a+=o.length}return i},e.byteLength=f,e.prototype._isBuffer=!0,e.prototype.swap16=function(){var t=this.length;if(t%2!=0)throw new RangeError(\"Buffer size must be a multiple of 16-bits\");for(var e=0;e<t;e+=2)p(this,e,e+1);return this},e.prototype.swap32=function(){var t=this.length;if(t%4!=0)throw new RangeError(\"Buffer size must be a multiple of 32-bits\");for(var e=0;e<t;e+=4)p(this,e,e+3),p(this,e+1,e+2);return this},e.prototype.swap64=function(){var t=this.length;if(t%8!=0)throw new RangeError(\"Buffer size must be a multiple of 64-bits\");for(var e=0;e<t;e+=8)p(this,e,e+7),p(this,e+1,e+6),p(this,e+2,e+5),p(this,e+3,e+4);return this},e.prototype.toString=function(){var t=this.length;return 0===t?\"\":0===arguments.length?k(this,0,t):function(t,e,r){var n=!1;if((void 0===e||e<0)&&(e=0),e>this.length)return\"\";if((void 0===r||r>this.length)&&(r=this.length),r<=0)return\"\";if((r>>>=0)<=(e>>>=0))return\"\";for(t||(t=\"utf8\");;)switch(t){case\"hex\":return S(this,e,r);case\"utf8\":case\"utf-8\":return k(this,e,r);case\"ascii\":return A(this,e,r);case\"latin1\":case\"binary\":return M(this,e,r);case\"base64\":return w(this,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return E(this,e,r);default:if(n)throw new TypeError(\"Unknown encoding: \"+t);t=(t+\"\").toLowerCase(),n=!0}}.apply(this,arguments)},e.prototype.toLocaleString=e.prototype.toString,e.prototype.equals=function(t){if(!e.isBuffer(t))throw new TypeError(\"Argument must be a Buffer\");return this===t||0===e.compare(this,t)},e.prototype.inspect=function(){var t=\"\",e=r.INSPECT_MAX_BYTES;return t=this.toString(\"hex\",0,e).replace(/(.{2})/g,\"$1 \").trim(),this.length>e&&(t+=\" ... \"),\"<Buffer \"+t+\">\"},e.prototype.compare=function(t,r,n,i,a){if(N(t,Uint8Array)&&(t=e.from(t,t.offset,t.byteLength)),!e.isBuffer(t))throw new TypeError('The \"target\" argument must be one of type Buffer or Uint8Array. Received type '+typeof t);if(void 0===r&&(r=0),void 0===n&&(n=t?t.length:0),void 0===i&&(i=0),void 0===a&&(a=this.length),r<0||n>t.length||i<0||a>this.length)throw new RangeError(\"out of range index\");if(i>=a&&r>=n)return 0;if(i>=a)return-1;if(r>=n)return 1;if(this===t)return 0;for(var o=(a>>>=0)-(i>>>=0),s=(n>>>=0)-(r>>>=0),l=Math.min(o,s),c=this.slice(i,a),u=t.slice(r,n),h=0;h<l;++h)if(c[h]!==u[h]){o=c[h],s=u[h];break}return o<s?-1:s<o?1:0},e.prototype.includes=function(t,e,r){return-1!==this.indexOf(t,e,r)},e.prototype.indexOf=function(t,e,r){return d(this,t,e,r,!0)},e.prototype.lastIndexOf=function(t,e,r){return d(this,t,e,r,!1)},e.prototype.write=function(t,e,r,n){if(void 0===e)n=\"utf8\",r=this.length,e=0;else if(void 0===r&&\"string\"==typeof e)n=e,r=this.length,e=0;else{if(!isFinite(e))throw new Error(\"Buffer.write(string, encoding, offset[, length]) is no longer supported\");e>>>=0,isFinite(r)?(r>>>=0,void 0===n&&(n=\"utf8\")):(n=r,r=void 0)}var i=this.length-e;if((void 0===r||r>i)&&(r=i),t.length>0&&(r<0||e<0)||e>this.length)throw new RangeError(\"Attempt to write outside buffer bounds\");n||(n=\"utf8\");for(var a=!1;;)switch(n){case\"hex\":return v(this,t,e,r);case\"utf8\":case\"utf-8\":return m(this,t,e,r);case\"ascii\":return y(this,t,e,r);case\"latin1\":case\"binary\":return x(this,t,e,r);case\"base64\":return b(this,t,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return _(this,t,e,r);default:if(a)throw new TypeError(\"Unknown encoding: \"+n);n=(\"\"+n).toLowerCase(),a=!0}},e.prototype.toJSON=function(){return{type:\"Buffer\",data:Array.prototype.slice.call(this._arr||this,0)}};var T=4096;function A(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(127&t[i]);return n}function M(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(t[i]);return n}function S(t,e,r){var n=t.length;(!e||e<0)&&(e=0),(!r||r<0||r>n)&&(r=n);for(var i=\"\",a=e;a<r;++a)i+=D(t[a]);return i}function E(t,e,r){for(var n=t.slice(e,r),i=\"\",a=0;a<n.length;a+=2)i+=String.fromCharCode(n[a]+256*n[a+1]);return i}function C(t,e,r){if(t%1!=0||t<0)throw new RangeError(\"offset is not uint\");if(t+e>r)throw new RangeError(\"Trying to access beyond buffer length\")}function L(t,r,n,i,a,o){if(!e.isBuffer(t))throw new TypeError('\"buffer\" argument must be a Buffer instance');if(r>a||r<o)throw new RangeError('\"value\" argument is out of bounds');if(n+i>t.length)throw new RangeError(\"Index out of range\")}function P(t,e,r,n,i,a){if(r+n>t.length)throw new RangeError(\"Index out of range\");if(r<0)throw new RangeError(\"Index out of range\")}function O(t,e,r,n,a){return e=+e,r>>>=0,a||P(t,0,r,4),i.write(t,e,r,n,23,4),r+4}function z(t,e,r,n,a){return e=+e,r>>>=0,a||P(t,0,r,8),i.write(t,e,r,n,52,8),r+8}e.prototype.slice=function(t,r){var n=this.length;(t=~~t)<0?(t+=n)<0&&(t=0):t>n&&(t=n),(r=void 0===r?n:~~r)<0?(r+=n)<0&&(r=0):r>n&&(r=n),r<t&&(r=t);var i=this.subarray(t,r);return i.__proto__=e.prototype,i},e.prototype.readUIntLE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n},e.prototype.readUIntBE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t+--e],i=1;e>0&&(i*=256);)n+=this[t+--e]*i;return n},e.prototype.readUInt8=function(t,e){return t>>>=0,e||C(t,1,this.length),this[t]},e.prototype.readUInt16LE=function(t,e){return t>>>=0,e||C(t,2,this.length),this[t]|this[t+1]<<8},e.prototype.readUInt16BE=function(t,e){return t>>>=0,e||C(t,2,this.length),this[t]<<8|this[t+1]},e.prototype.readUInt32LE=function(t,e){return t>>>=0,e||C(t,4,this.length),(this[t]|this[t+1]<<8|this[t+2]<<16)+16777216*this[t+3]},e.prototype.readUInt32BE=function(t,e){return t>>>=0,e||C(t,4,this.length),16777216*this[t]+(this[t+1]<<16|this[t+2]<<8|this[t+3])},e.prototype.readIntLE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n>=(i*=128)&&(n-=Math.pow(2,8*e)),n},e.prototype.readIntBE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=e,i=1,a=this[t+--n];n>0&&(i*=256);)a+=this[t+--n]*i;return a>=(i*=128)&&(a-=Math.pow(2,8*e)),a},e.prototype.readInt8=function(t,e){return t>>>=0,e||C(t,1,this.length),128&this[t]?-1*(255-this[t]+1):this[t]},e.prototype.readInt16LE=function(t,e){t>>>=0,e||C(t,2,this.length);var r=this[t]|this[t+1]<<8;return 32768&r?4294901760|r:r},e.prototype.readInt16BE=function(t,e){t>>>=0,e||C(t,2,this.length);var r=this[t+1]|this[t]<<8;return 32768&r?4294901760|r:r},e.prototype.readInt32LE=function(t,e){return t>>>=0,e||C(t,4,this.length),this[t]|this[t+1]<<8|this[t+2]<<16|this[t+3]<<24},e.prototype.readInt32BE=function(t,e){return t>>>=0,e||C(t,4,this.length),this[t]<<24|this[t+1]<<16|this[t+2]<<8|this[t+3]},e.prototype.readFloatLE=function(t,e){return t>>>=0,e||C(t,4,this.length),i.read(this,t,!0,23,4)},e.prototype.readFloatBE=function(t,e){return t>>>=0,e||C(t,4,this.length),i.read(this,t,!1,23,4)},e.prototype.readDoubleLE=function(t,e){return t>>>=0,e||C(t,8,this.length),i.read(this,t,!0,52,8)},e.prototype.readDoubleBE=function(t,e){return t>>>=0,e||C(t,8,this.length),i.read(this,t,!1,52,8)},e.prototype.writeUIntLE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||L(this,t,e,r,Math.pow(2,8*r)-1,0);var i=1,a=0;for(this[e]=255&t;++a<r&&(i*=256);)this[e+a]=t/i&255;return e+r},e.prototype.writeUIntBE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||L(this,t,e,r,Math.pow(2,8*r)-1,0);var i=r-1,a=1;for(this[e+i]=255&t;--i>=0&&(a*=256);)this[e+i]=t/a&255;return e+r},e.prototype.writeUInt8=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,1,255,0),this[e]=255&t,e+1},e.prototype.writeUInt16LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,65535,0),this[e]=255&t,this[e+1]=t>>>8,e+2},e.prototype.writeUInt16BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,65535,0),this[e]=t>>>8,this[e+1]=255&t,e+2},e.prototype.writeUInt32LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,4294967295,0),this[e+3]=t>>>24,this[e+2]=t>>>16,this[e+1]=t>>>8,this[e]=255&t,e+4},e.prototype.writeUInt32BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,4294967295,0),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},e.prototype.writeIntLE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);L(this,t,e,r,i-1,-i)}var a=0,o=1,s=0;for(this[e]=255&t;++a<r&&(o*=256);)t<0&&0===s&&0!==this[e+a-1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},e.prototype.writeIntBE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);L(this,t,e,r,i-1,-i)}var a=r-1,o=1,s=0;for(this[e+a]=255&t;--a>=0&&(o*=256);)t<0&&0===s&&0!==this[e+a+1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},e.prototype.writeInt8=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,1,127,-128),t<0&&(t=255+t+1),this[e]=255&t,e+1},e.prototype.writeInt16LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,32767,-32768),this[e]=255&t,this[e+1]=t>>>8,e+2},e.prototype.writeInt16BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,32767,-32768),this[e]=t>>>8,this[e+1]=255&t,e+2},e.prototype.writeInt32LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,2147483647,-2147483648),this[e]=255&t,this[e+1]=t>>>8,this[e+2]=t>>>16,this[e+3]=t>>>24,e+4},e.prototype.writeInt32BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,2147483647,-2147483648),t<0&&(t=4294967295+t+1),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},e.prototype.writeFloatLE=function(t,e,r){return O(this,t,e,!0,r)},e.prototype.writeFloatBE=function(t,e,r){return O(this,t,e,!1,r)},e.prototype.writeDoubleLE=function(t,e,r){return z(this,t,e,!0,r)},e.prototype.writeDoubleBE=function(t,e,r){return z(this,t,e,!1,r)},e.prototype.copy=function(t,r,n,i){if(!e.isBuffer(t))throw new TypeError(\"argument should be a Buffer\");if(n||(n=0),i||0===i||(i=this.length),r>=t.length&&(r=t.length),r||(r=0),i>0&&i<n&&(i=n),i===n)return 0;if(0===t.length||0===this.length)return 0;if(r<0)throw new RangeError(\"targetStart out of bounds\");if(n<0||n>=this.length)throw new RangeError(\"Index out of range\");if(i<0)throw new RangeError(\"sourceEnd out of bounds\");i>this.length&&(i=this.length),t.length-r<i-n&&(i=t.length-r+n);var a=i-n;if(this===t&&\"function\"==typeof Uint8Array.prototype.copyWithin)this.copyWithin(r,n,i);else if(this===t&&n<r&&r<i)for(var o=a-1;o>=0;--o)t[o+r]=this[o+n];else Uint8Array.prototype.set.call(t,this.subarray(n,i),r);return a},e.prototype.fill=function(t,r,n,i){if(\"string\"==typeof t){if(\"string\"==typeof r?(i=r,r=0,n=this.length):\"string\"==typeof n&&(i=n,n=this.length),void 0!==i&&\"string\"!=typeof i)throw new TypeError(\"encoding must be a string\");if(\"string\"==typeof i&&!e.isEncoding(i))throw new TypeError(\"Unknown encoding: \"+i);if(1===t.length){var a=t.charCodeAt(0);(\"utf8\"===i&&a<128||\"latin1\"===i)&&(t=a)}}else\"number\"==typeof t&&(t&=255);if(r<0||this.length<r||this.length<n)throw new RangeError(\"Out of range index\");if(n<=r)return this;var o;if(r>>>=0,n=void 0===n?this.length:n>>>0,t||(t=0),\"number\"==typeof t)for(o=r;o<n;++o)this[o]=t;else{var s=e.isBuffer(t)?t:e.from(t,i),l=s.length;if(0===l)throw new TypeError('The value \"'+t+'\" is invalid for argument \"value\"');for(o=0;o<n-r;++o)this[o+r]=s[o%l]}return this};var I=/[^+\\/0-9A-Za-z-_]/g;function D(t){return t<16?\"0\"+t.toString(16):t.toString(16)}function R(t,e){var r;e=e||1/0;for(var n=t.length,i=null,a=[],o=0;o<n;++o){if((r=t.charCodeAt(o))>55295&&r<57344){if(!i){if(r>56319){(e-=3)>-1&&a.push(239,191,189);continue}if(o+1===n){(e-=3)>-1&&a.push(239,191,189);continue}i=r;continue}if(r<56320){(e-=3)>-1&&a.push(239,191,189),i=r;continue}r=65536+(i-55296<<10|r-56320)}else i&&(e-=3)>-1&&a.push(239,191,189);if(i=null,r<128){if((e-=1)<0)break;a.push(r)}else if(r<2048){if((e-=2)<0)break;a.push(r>>6|192,63&r|128)}else if(r<65536){if((e-=3)<0)break;a.push(r>>12|224,r>>6&63|128,63&r|128)}else{if(!(r<1114112))throw new Error(\"Invalid code point\");if((e-=4)<0)break;a.push(r>>18|240,r>>12&63|128,r>>6&63|128,63&r|128)}}return a}function F(t){return n.toByteArray(function(t){if((t=(t=t.split(\"=\")[0]).trim().replace(I,\"\")).length<2)return\"\";for(;t.length%4!=0;)t+=\"=\";return t}(t))}function B(t,e,r,n){for(var i=0;i<n&&!(i+r>=e.length||i>=t.length);++i)e[i+r]=t[i];return i}function N(t,e){return t instanceof e||null!=t&&null!=t.constructor&&null!=t.constructor.name&&t.constructor.name===e.name}function j(t){return t!=t}}).call(this,t(\"buffer\").Buffer)},{\"base64-js\":74,buffer:105,ieee754:412}],106:[function(t,e,r){\"use strict\";var n=t(\"./lib/monotone\"),i=t(\"./lib/triangulation\"),a=t(\"./lib/delaunay\"),o=t(\"./lib/filter\");function s(t){return[Math.min(t[0],t[1]),Math.max(t[0],t[1])]}function l(t,e){return t[0]-e[0]||t[1]-e[1]}function c(t,e,r){return e in t?t[e]:r}e.exports=function(t,e,r){Array.isArray(e)?(r=r||{},e=e||[]):(r=e||{},e=[]);var u=!!c(r,\"delaunay\",!0),h=!!c(r,\"interior\",!0),f=!!c(r,\"exterior\",!0),p=!!c(r,\"infinity\",!1);if(!h&&!f||0===t.length)return[];var d=n(t,e);if(u||h!==f||p){for(var g=i(t.length,function(t){return t.map(s).sort(l)}(e)),v=0;v<d.length;++v){var m=d[v];g.addTriangle(m[0],m[1],m[2])}return u&&a(t,g),f?h?p?o(g,0,p):g.cells():o(g,1,p):o(g,-1)}return d}},{\"./lib/delaunay\":107,\"./lib/filter\":108,\"./lib/monotone\":109,\"./lib/triangulation\":110}],107:[function(t,e,r){\"use strict\";var n=t(\"robust-in-sphere\")[4];t(\"binary-search-bounds\");function i(t,e,r,i,a,o){var s=e.opposite(i,a);if(!(s<0)){if(a<i){var l=i;i=a,a=l,l=o,o=s,s=l}e.isConstraint(i,a)||n(t[i],t[a],t[o],t[s])<0&&r.push(i,a)}}e.exports=function(t,e){for(var r=[],a=t.length,o=e.stars,s=0;s<a;++s)for(var l=o[s],c=1;c<l.length;c+=2){var u=l[c];if(!(u<s)&&!e.isConstraint(s,u)){for(var h=l[c-1],f=-1,p=1;p<l.length;p+=2)if(l[p-1]===u){f=l[p];break}f<0||n(t[s],t[u],t[h],t[f])<0&&r.push(s,u)}}for(;r.length>0;){for(var u=r.pop(),s=r.pop(),h=-1,f=-1,l=o[s],d=1;d<l.length;d+=2){var g=l[d-1],v=l[d];g===u?f=v:v===u&&(h=g)}h<0||f<0||(n(t[s],t[u],t[h],t[f])>=0||(e.flip(s,u),i(t,e,r,h,s,f),i(t,e,r,s,f,h),i(t,e,r,f,u,h),i(t,e,r,u,h,f)))}}},{\"binary-search-bounds\":111,\"robust-in-sphere\":508}],108:[function(t,e,r){\"use strict\";var n,i=t(\"binary-search-bounds\");function a(t,e,r,n,i,a,o){this.cells=t,this.neighbor=e,this.flags=n,this.constraint=r,this.active=i,this.next=a,this.boundary=o}function o(t,e){return t[0]-e[0]||t[1]-e[1]||t[2]-e[2]}e.exports=function(t,e,r){var n=function(t,e){for(var r=t.cells(),n=r.length,i=0;i<n;++i){var s=r[i],l=s[0],c=s[1],u=s[2];c<u?c<l&&(s[0]=c,s[1]=u,s[2]=l):u<l&&(s[0]=u,s[1]=l,s[2]=c)}r.sort(o);for(var h=new Array(n),i=0;i<h.length;++i)h[i]=0;var f=[],p=[],d=new Array(3*n),g=new Array(3*n),v=null;e&&(v=[]);for(var m=new a(r,d,g,h,f,p,v),i=0;i<n;++i)for(var s=r[i],y=0;y<3;++y){var l=s[y],c=s[(y+1)%3],x=d[3*i+y]=m.locate(c,l,t.opposite(c,l)),b=g[3*i+y]=t.isConstraint(l,c);x<0&&(b?p.push(i):(f.push(i),h[i]=1),e&&v.push([c,l,-1]))}return m}(t,r);if(0===e)return r?n.cells.concat(n.boundary):n.cells;var i=1,s=n.active,l=n.next,c=n.flags,u=n.cells,h=n.constraint,f=n.neighbor;for(;s.length>0||l.length>0;){for(;s.length>0;){var p=s.pop();if(c[p]!==-i){c[p]=i;u[p];for(var d=0;d<3;++d){var g=f[3*p+d];g>=0&&0===c[g]&&(h[3*p+d]?l.push(g):(s.push(g),c[g]=i))}}}var v=l;l=s,s=v,l.length=0,i=-i}var m=function(t,e,r){for(var n=0,i=0;i<t.length;++i)e[i]===r&&(t[n++]=t[i]);return t.length=n,t}(u,c,e);if(r)return m.concat(n.boundary);return m},a.prototype.locate=(n=[0,0,0],function(t,e,r){var a=t,s=e,l=r;return e<r?e<t&&(a=e,s=r,l=t):r<t&&(a=r,s=t,l=e),a<0?-1:(n[0]=a,n[1]=s,n[2]=l,i.eq(this.cells,n,o))})},{\"binary-search-bounds\":111}],109:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"robust-orientation\")[3],a=0,o=1,s=2;function l(t,e,r,n,i){this.a=t,this.b=e,this.idx=r,this.lowerIds=n,this.upperIds=i}function c(t,e,r,n){this.a=t,this.b=e,this.type=r,this.idx=n}function u(t,e){var r=t.a[0]-e.a[0]||t.a[1]-e.a[1]||t.type-e.type;return r||(t.type!==a&&(r=i(t.a,t.b,e.b))?r:t.idx-e.idx)}function h(t,e){return i(t.a,t.b,e)}function f(t,e,r,a,o){for(var s=n.lt(e,a,h),l=n.gt(e,a,h),c=s;c<l;++c){for(var u=e[c],f=u.lowerIds,p=f.length;p>1&&i(r[f[p-2]],r[f[p-1]],a)>0;)t.push([f[p-1],f[p-2],o]),p-=1;f.length=p,f.push(o);var d=u.upperIds;for(p=d.length;p>1&&i(r[d[p-2]],r[d[p-1]],a)<0;)t.push([d[p-2],d[p-1],o]),p-=1;d.length=p,d.push(o)}}function p(t,e){var r;return(r=t.a[0]<e.a[0]?i(t.a,t.b,e.a):i(e.b,e.a,t.a))?r:(r=e.b[0]<t.b[0]?i(t.a,t.b,e.b):i(e.b,e.a,t.b))||t.idx-e.idx}function d(t,e,r){var i=n.le(t,r,p),a=t[i],o=a.upperIds,s=o[o.length-1];a.upperIds=[s],t.splice(i+1,0,new l(r.a,r.b,r.idx,[s],o))}function g(t,e,r){var i=r.a;r.a=r.b,r.b=i;var a=n.eq(t,r,p),o=t[a];t[a-1].upperIds=o.upperIds,t.splice(a,1)}e.exports=function(t,e){for(var r=t.length,n=e.length,i=[],h=0;h<r;++h)i.push(new c(t[h],null,a,h));for(var h=0;h<n;++h){var p=e[h],v=t[p[0]],m=t[p[1]];v[0]<m[0]?i.push(new c(v,m,s,h),new c(m,v,o,h)):v[0]>m[0]&&i.push(new c(m,v,s,h),new c(v,m,o,h))}i.sort(u);for(var y=i[0].a[0]-(1+Math.abs(i[0].a[0]))*Math.pow(2,-52),x=[new l([y,1],[y,0],-1,[],[],[],[])],b=[],h=0,_=i.length;h<_;++h){var w=i[h],k=w.type;k===a?f(b,x,t,w.a,w.idx):k===s?d(x,t,w):g(x,t,w)}return b}},{\"binary-search-bounds\":111,\"robust-orientation\":510}],110:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\");function i(t,e){this.stars=t,this.edges=e}e.exports=function(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=[];return new i(r,e)};var a=i.prototype;function o(t,e,r){for(var n=1,i=t.length;n<i;n+=2)if(t[n-1]===e&&t[n]===r)return t[n-1]=t[i-2],t[n]=t[i-1],void(t.length=i-2)}a.isConstraint=function(){var t=[0,0];function e(t,e){return t[0]-e[0]||t[1]-e[1]}return function(r,i){return t[0]=Math.min(r,i),t[1]=Math.max(r,i),n.eq(this.edges,t,e)>=0}}(),a.removeTriangle=function(t,e,r){var n=this.stars;o(n[t],e,r),o(n[e],r,t),o(n[r],t,e)},a.addTriangle=function(t,e,r){var n=this.stars;n[t].push(e,r),n[e].push(r,t),n[r].push(t,e)},a.opposite=function(t,e){for(var r=this.stars[e],n=1,i=r.length;n<i;n+=2)if(r[n]===t)return r[n-1];return-1},a.flip=function(t,e){var r=this.opposite(t,e),n=this.opposite(e,t);this.removeTriangle(t,e,r),this.removeTriangle(e,t,n),this.addTriangle(t,n,r),this.addTriangle(e,r,n)},a.edges=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2)e.push([i[a],i[a+1]]);return e},a.cells=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2){var s=i[a],l=i[a+1];r<Math.min(s,l)&&e.push([r,s,l])}return e}},{\"binary-search-bounds\":111}],111:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",i?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a[m]\"];return i?e.indexOf(\"c\")<0?a.push(\";if(x===y){return m}else if(x<=y){\"):a.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):a.push(\";if(\",e,\"){i=m;\"),r?a.push(\"l=m+1}else{h=m-1}\"):a.push(\"h=m-1}else{l=m+1}\"),a.push(\"}\"),i?a.push(\"return -1};\"):a.push(\"return i};\"),a.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(typeof(c)==='function'){return P(a,(l===void 0)?0:l|0,(h===void 0)?a.length-1:h|0,y,c)}else{return A(a,(c===void 0)?0:c|0,(l===void 0)?a.length-1:l|0,y)}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],112:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1,r=1;r<t.length;++r)for(var n=0;n<r;++n)if(t[r]<t[n])e=-e;else if(t[n]===t[r])return 0;return e}},{}],113:[function(t,e,r){\"use strict\";var n=t(\"dup\"),i=t(\"robust-linear-solve\");function a(t,e){for(var r=0,n=t.length,i=0;i<n;++i)r+=t[i]*e[i];return r}function o(t){var e=t.length;if(0===e)return[];t[0].length;var r=n([t.length+1,t.length+1],1),o=n([t.length+1],1);r[e][e]=0;for(var s=0;s<e;++s){for(var l=0;l<=s;++l)r[l][s]=r[s][l]=2*a(t[s],t[l]);o[s]=a(t[s],t[s])}var c=i(r,o),u=0,h=c[e+1];for(s=0;s<h.length;++s)u+=h[s];var f=new Array(e);for(s=0;s<e;++s){h=c[s];var p=0;for(l=0;l<h.length;++l)p+=h[l];f[s]=p/u}return f}function s(t){if(0===t.length)return[];for(var e=t[0].length,r=n([e]),i=o(t),a=0;a<t.length;++a)for(var s=0;s<e;++s)r[s]+=t[a][s]*i[a];return r}s.barycenetric=o,e.exports=s},{dup:170,\"robust-linear-solve\":509}],114:[function(t,e,r){e.exports=function(t){for(var e=n(t),r=0,i=0;i<t.length;++i)for(var a=t[i],o=0;o<e.length;++o)r+=Math.pow(a[o]-e[o],2);return Math.sqrt(r/t.length)};var n=t(\"circumcenter\")},{circumcenter:113}],115:[function(t,e,r){e.exports=function(t,e,r){return e<r?t<e?e:t>r?r:t:t<r?r:t>e?e:t}},{}],116:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n;if(r){n=e;for(var i=new Array(e.length),a=0;a<e.length;++a){var o=e[a];i[a]=[o[0],o[1],r[a]]}e=i}var s=function(t,e,r){var n=d(t,[],p(t));return m(e,n,r),!!n}(t,e,!!r);for(;y(t,e,!!r);)s=!0;if(r&&s){n.length=0,r.length=0;for(var a=0;a<e.length;++a){var o=e[a];n.push([o[0],o[1]]),r.push(o[2])}}return s};var n=t(\"union-find\"),i=t(\"box-intersect\"),a=t(\"robust-segment-intersect\"),o=t(\"big-rat\"),s=t(\"big-rat/cmp\"),l=t(\"big-rat/to-float\"),c=t(\"rat-vec\"),u=t(\"nextafter\"),h=t(\"./lib/rat-seg-intersect\");function f(t){var e=l(t);return[u(e,-1/0),u(e,1/0)]}function p(t){for(var e=new Array(t.length),r=0;r<t.length;++r){var n=t[r];e[r]=[u(n[0],-1/0),u(n[1],-1/0),u(n[0],1/0),u(n[1],1/0)]}return e}function d(t,e,r){for(var a=e.length,o=new n(a),s=[],l=0;l<e.length;++l){var c=e[l],h=f(c[0]),p=f(c[1]);s.push([u(h[0],-1/0),u(p[0],-1/0),u(h[1],1/0),u(p[1],1/0)])}i(s,function(t,e){o.link(t,e)});var d=!0,g=new Array(a);for(l=0;l<a;++l){(m=o.find(l))!==l&&(d=!1,t[m]=[Math.min(t[l][0],t[m][0]),Math.min(t[l][1],t[m][1])])}if(d)return null;var v=0;for(l=0;l<a;++l){var m;(m=o.find(l))===l?(g[l]=v,t[v++]=t[l]):g[l]=-1}t.length=v;for(l=0;l<a;++l)g[l]<0&&(g[l]=g[o.find(l)]);return g}function g(t,e){return t[0]-e[0]||t[1]-e[1]}function v(t,e){var r=t[0]-e[0]||t[1]-e[1];return r||(t[2]<e[2]?-1:t[2]>e[2]?1:0)}function m(t,e,r){if(0!==t.length){if(e)for(var n=0;n<t.length;++n){var i=e[(o=t[n])[0]],a=e[o[1]];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}else for(n=0;n<t.length;++n){var o;i=(o=t[n])[0],a=o[1];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}r?t.sort(v):t.sort(g);var s=1;for(n=1;n<t.length;++n){var l=t[n-1],c=t[n];(c[0]!==l[0]||c[1]!==l[1]||r&&c[2]!==l[2])&&(t[s++]=c)}t.length=s}}function y(t,e,r){var n=function(t,e){for(var r=new Array(e.length),n=0;n<e.length;++n){var i=e[n],a=t[i[0]],o=t[i[1]];r[n]=[u(Math.min(a[0],o[0]),-1/0),u(Math.min(a[1],o[1]),-1/0),u(Math.max(a[0],o[0]),1/0),u(Math.max(a[1],o[1]),1/0)]}return r}(t,e),f=function(t,e,r){var n=[];return i(r,function(r,i){var o=e[r],s=e[i];if(o[0]!==s[0]&&o[0]!==s[1]&&o[1]!==s[0]&&o[1]!==s[1]){var l=t[o[0]],c=t[o[1]],u=t[s[0]],h=t[s[1]];a(l,c,u,h)&&n.push([r,i])}}),n}(t,e,n),g=p(t),v=function(t,e,r,n){var o=[];return i(r,n,function(r,n){var i=e[r];if(i[0]!==n&&i[1]!==n){var s=t[n],l=t[i[0]],c=t[i[1]];a(l,c,s,s)&&o.push([r,n])}}),o}(t,e,n,g),y=d(t,function(t,e,r,n,i){var a,u,f=t.map(function(t){return[o(t[0]),o(t[1])]});for(a=0;a<r.length;++a){var p=r[a];u=p[0];var d=p[1],g=e[u],v=e[d],m=h(c(t[g[0]]),c(t[g[1]]),c(t[v[0]]),c(t[v[1]]));if(m){var y=t.length;t.push([l(m[0]),l(m[1])]),f.push(m),n.push([u,y],[d,y])}}for(n.sort(function(t,e){if(t[0]!==e[0])return t[0]-e[0];var r=f[t[1]],n=f[e[1]];return s(r[0],n[0])||s(r[1],n[1])}),a=n.length-1;a>=0;--a){var x=e[u=(S=n[a])[0]],b=x[0],_=x[1],w=t[b],k=t[_];if((w[0]-k[0]||w[1]-k[1])<0){var T=b;b=_,_=T}x[0]=b;var A,M=x[1]=S[1];for(i&&(A=x[2]);a>0&&n[a-1][0]===u;){var S,E=(S=n[--a])[1];i?e.push([M,E,A]):e.push([M,E]),M=E}i?e.push([M,_,A]):e.push([M,_])}return f}(t,e,f,v,r));return m(e,y,r),!!y||(f.length>0||v.length>0)}},{\"./lib/rat-seg-intersect\":117,\"big-rat\":78,\"big-rat/cmp\":76,\"big-rat/to-float\":90,\"box-intersect\":96,nextafter:451,\"rat-vec\":486,\"robust-segment-intersect\":513,\"union-find\":546}],117:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var a=s(e,t),h=s(n,r),f=u(a,h);if(0===o(f))return null;var p=s(t,r),d=u(h,p),g=i(d,f),v=c(a,g);return l(t,v)};var n=t(\"big-rat/mul\"),i=t(\"big-rat/div\"),a=t(\"big-rat/sub\"),o=t(\"big-rat/sign\"),s=t(\"rat-vec/sub\"),l=t(\"rat-vec/add\"),c=t(\"rat-vec/muls\");function u(t,e){return a(n(t[0],e[1]),n(t[1],e[0]))}},{\"big-rat/div\":77,\"big-rat/mul\":87,\"big-rat/sign\":88,\"big-rat/sub\":89,\"rat-vec/add\":485,\"rat-vec/muls\":487,\"rat-vec/sub\":488}],118:[function(t,e,r){\"use strict\";var n=t(\"clamp\");function i(t,e){null==e&&(e=!0);var r=t[0],i=t[1],a=t[2],o=t[3];return null==o&&(o=e?1:255),e&&(r*=255,i*=255,a*=255,o*=255),16777216*(r=255&n(r,0,255))+((i=255&n(i,0,255))<<16)+((a=255&n(a,0,255))<<8)+(o=255&n(o,0,255))}e.exports=i,e.exports.to=i,e.exports.from=function(t,e){var r=(t=+t)>>>24,n=(16711680&t)>>>16,i=(65280&t)>>>8,a=255&t;return!1===e?[r,n,i,a]:[r/255,n/255,i/255,a/255]}},{clamp:115}],119:[function(t,e,r){\"use strict\";e.exports={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]}},{}],120:[function(t,e,r){\"use strict\";var n=t(\"color-rgba\"),i=t(\"clamp\"),a=t(\"dtype\");e.exports=function(t,e){\"float\"!==e&&e||(e=\"array\"),\"uint\"===e&&(e=\"uint8\"),\"uint_clamped\"===e&&(e=\"uint8_clamped\");var r=new(a(e))(4),o=\"uint8\"!==e&&\"uint8_clamped\"!==e;return t.length&&\"string\"!=typeof t||((t=n(t))[0]/=255,t[1]/=255,t[2]/=255),function(t){return t instanceof Uint8Array||t instanceof Uint8ClampedArray||!!(Array.isArray(t)&&(t[0]>1||0===t[0])&&(t[1]>1||0===t[1])&&(t[2]>1||0===t[2])&&(!t[3]||t[3]>1))}(t)?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:255,o&&(r[0]/=255,r[1]/=255,r[2]/=255,r[3]/=255),r):(o?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:1):(r[0]=i(Math.floor(255*t[0]),0,255),r[1]=i(Math.floor(255*t[1]),0,255),r[2]=i(Math.floor(255*t[2]),0,255),r[3]=null==t[3]?255:i(Math.floor(255*t[3]),0,255)),r)}},{clamp:115,\"color-rgba\":122,dtype:169}],121:[function(t,e,r){(function(r){\"use strict\";var n=t(\"color-name\"),i=t(\"is-plain-obj\"),a=t(\"defined\");e.exports=function(t){var e,s,l=[],c=1;if(\"string\"==typeof t)if(n[t])l=n[t].slice(),s=\"rgb\";else if(\"transparent\"===t)c=0,s=\"rgb\",l=[0,0,0];else if(/^#[A-Fa-f0-9]+$/.test(t)){var u=t.slice(1),h=u.length,f=h<=4;c=1,f?(l=[parseInt(u[0]+u[0],16),parseInt(u[1]+u[1],16),parseInt(u[2]+u[2],16)],4===h&&(c=parseInt(u[3]+u[3],16)/255)):(l=[parseInt(u[0]+u[1],16),parseInt(u[2]+u[3],16),parseInt(u[4]+u[5],16)],8===h&&(c=parseInt(u[6]+u[7],16)/255)),l[0]||(l[0]=0),l[1]||(l[1]=0),l[2]||(l[2]=0),s=\"rgb\"}else if(e=/^((?:rgb|hs[lvb]|hwb|cmyk?|xy[zy]|gray|lab|lchu?v?|[ly]uv|lms)a?)\\s*\\(([^\\)]*)\\)/.exec(t)){var p=e[1],d=\"rgb\"===p,u=p.replace(/a$/,\"\");s=u;var h=\"cmyk\"===u?4:\"gray\"===u?1:3;l=e[2].trim().split(/\\s*,\\s*/).map(function(t,e){if(/%$/.test(t))return e===h?parseFloat(t)/100:\"rgb\"===u?255*parseFloat(t)/100:parseFloat(t);if(\"h\"===u[e]){if(/deg$/.test(t))return parseFloat(t);if(void 0!==o[t])return o[t]}return parseFloat(t)}),p===u&&l.push(1),c=d?1:void 0===l[h]?1:l[h],l=l.slice(0,h)}else t.length>10&&/[0-9](?:\\s|\\/)/.test(t)&&(l=t.match(/([0-9]+)/g).map(function(t){return parseFloat(t)}),s=t.match(/([a-z])/gi).join(\"\").toLowerCase());else if(isNaN(t))if(i(t)){var g=a(t.r,t.red,t.R,null);null!==g?(s=\"rgb\",l=[g,a(t.g,t.green,t.G),a(t.b,t.blue,t.B)]):(s=\"hsl\",l=[a(t.h,t.hue,t.H),a(t.s,t.saturation,t.S),a(t.l,t.lightness,t.L,t.b,t.brightness)]),c=a(t.a,t.alpha,t.opacity,1),null!=t.opacity&&(c/=100)}else(Array.isArray(t)||r.ArrayBuffer&&ArrayBuffer.isView&&ArrayBuffer.isView(t))&&(l=[t[0],t[1],t[2]],s=\"rgb\",c=4===t.length?t[3]:1);else s=\"rgb\",l=[t>>>16,(65280&t)>>>8,255&t];return{space:s,values:l,alpha:c}};var o={red:0,orange:60,yellow:120,green:180,blue:240,purple:300}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"color-name\":119,defined:164,\"is-plain-obj\":422}],122:[function(t,e,r){\"use strict\";var n=t(\"color-parse\"),i=t(\"color-space/hsl\"),a=t(\"clamp\");e.exports=function(t){var e,r=n(t);return r.space?((e=Array(3))[0]=a(r.values[0],0,255),e[1]=a(r.values[1],0,255),e[2]=a(r.values[2],0,255),\"h\"===r.space[0]&&(e=i.rgb(e)),e.push(a(r.alpha,0,1)),e):[]}},{clamp:115,\"color-parse\":121,\"color-space/hsl\":123}],123:[function(t,e,r){\"use strict\";var n=t(\"./rgb\");e.exports={name:\"hsl\",min:[0,0,0],max:[360,100,100],channel:[\"hue\",\"saturation\",\"lightness\"],alias:[\"HSL\"],rgb:function(t){var e,r,n,i,a,o=t[0]/360,s=t[1]/100,l=t[2]/100;if(0===s)return[a=255*l,a,a];e=2*l-(r=l<.5?l*(1+s):l+s-l*s),i=[0,0,0];for(var c=0;c<3;c++)(n=o+1/3*-(c-1))<0?n++:n>1&&n--,a=6*n<1?e+6*(r-e)*n:2*n<1?r:3*n<2?e+(r-e)*(2/3-n)*6:e,i[c]=255*a;return i}},n.hsl=function(t){var e,r,n=t[0]/255,i=t[1]/255,a=t[2]/255,o=Math.min(n,i,a),s=Math.max(n,i,a),l=s-o;return s===o?e=0:n===s?e=(i-a)/l:i===s?e=2+(a-n)/l:a===s&&(e=4+(n-i)/l),(e=Math.min(60*e,360))<0&&(e+=360),r=(o+s)/2,[e,100*(s===o?0:r<=.5?l/(s+o):l/(2-s-o)),100*r]}},{\"./rgb\":124}],124:[function(t,e,r){\"use strict\";e.exports={name:\"rgb\",min:[0,0,0],max:[255,255,255],channel:[\"red\",\"green\",\"blue\"],alias:[\"RGB\"]}},{}],125:[function(t,e,r){e.exports={jet:[{index:0,rgb:[0,0,131]},{index:.125,rgb:[0,60,170]},{index:.375,rgb:[5,255,255]},{index:.625,rgb:[255,255,0]},{index:.875,rgb:[250,0,0]},{index:1,rgb:[128,0,0]}],hsv:[{index:0,rgb:[255,0,0]},{index:.169,rgb:[253,255,2]},{index:.173,rgb:[247,255,2]},{index:.337,rgb:[0,252,4]},{index:.341,rgb:[0,252,10]},{index:.506,rgb:[1,249,255]},{index:.671,rgb:[2,0,253]},{index:.675,rgb:[8,0,253]},{index:.839,rgb:[255,0,251]},{index:.843,rgb:[255,0,245]},{index:1,rgb:[255,0,6]}],hot:[{index:0,rgb:[0,0,0]},{index:.3,rgb:[230,0,0]},{index:.6,rgb:[255,210,0]},{index:1,rgb:[255,255,255]}],cool:[{index:0,rgb:[0,255,255]},{index:1,rgb:[255,0,255]}],spring:[{index:0,rgb:[255,0,255]},{index:1,rgb:[255,255,0]}],summer:[{index:0,rgb:[0,128,102]},{index:1,rgb:[255,255,102]}],autumn:[{index:0,rgb:[255,0,0]},{index:1,rgb:[255,255,0]}],winter:[{index:0,rgb:[0,0,255]},{index:1,rgb:[0,255,128]}],bone:[{index:0,rgb:[0,0,0]},{index:.376,rgb:[84,84,116]},{index:.753,rgb:[169,200,200]},{index:1,rgb:[255,255,255]}],copper:[{index:0,rgb:[0,0,0]},{index:.804,rgb:[255,160,102]},{index:1,rgb:[255,199,127]}],greys:[{index:0,rgb:[0,0,0]},{index:1,rgb:[255,255,255]}],yignbu:[{index:0,rgb:[8,29,88]},{index:.125,rgb:[37,52,148]},{index:.25,rgb:[34,94,168]},{index:.375,rgb:[29,145,192]},{index:.5,rgb:[65,182,196]},{index:.625,rgb:[127,205,187]},{index:.75,rgb:[199,233,180]},{index:.875,rgb:[237,248,217]},{index:1,rgb:[255,255,217]}],greens:[{index:0,rgb:[0,68,27]},{index:.125,rgb:[0,109,44]},{index:.25,rgb:[35,139,69]},{index:.375,rgb:[65,171,93]},{index:.5,rgb:[116,196,118]},{index:.625,rgb:[161,217,155]},{index:.75,rgb:[199,233,192]},{index:.875,rgb:[229,245,224]},{index:1,rgb:[247,252,245]}],yiorrd:[{index:0,rgb:[128,0,38]},{index:.125,rgb:[189,0,38]},{index:.25,rgb:[227,26,28]},{index:.375,rgb:[252,78,42]},{index:.5,rgb:[253,141,60]},{index:.625,rgb:[254,178,76]},{index:.75,rgb:[254,217,118]},{index:.875,rgb:[255,237,160]},{index:1,rgb:[255,255,204]}],bluered:[{index:0,rgb:[0,0,255]},{index:1,rgb:[255,0,0]}],rdbu:[{index:0,rgb:[5,10,172]},{index:.35,rgb:[106,137,247]},{index:.5,rgb:[190,190,190]},{index:.6,rgb:[220,170,132]},{index:.7,rgb:[230,145,90]},{index:1,rgb:[178,10,28]}],picnic:[{index:0,rgb:[0,0,255]},{index:.1,rgb:[51,153,255]},{index:.2,rgb:[102,204,255]},{index:.3,rgb:[153,204,255]},{index:.4,rgb:[204,204,255]},{index:.5,rgb:[255,255,255]},{index:.6,rgb:[255,204,255]},{index:.7,rgb:[255,153,255]},{index:.8,rgb:[255,102,204]},{index:.9,rgb:[255,102,102]},{index:1,rgb:[255,0,0]}],rainbow:[{index:0,rgb:[150,0,90]},{index:.125,rgb:[0,0,200]},{index:.25,rgb:[0,25,255]},{index:.375,rgb:[0,152,255]},{index:.5,rgb:[44,255,150]},{index:.625,rgb:[151,255,0]},{index:.75,rgb:[255,234,0]},{index:.875,rgb:[255,111,0]},{index:1,rgb:[255,0,0]}],portland:[{index:0,rgb:[12,51,131]},{index:.25,rgb:[10,136,186]},{index:.5,rgb:[242,211,56]},{index:.75,rgb:[242,143,56]},{index:1,rgb:[217,30,30]}],blackbody:[{index:0,rgb:[0,0,0]},{index:.2,rgb:[230,0,0]},{index:.4,rgb:[230,210,0]},{index:.7,rgb:[255,255,255]},{index:1,rgb:[160,200,255]}],earth:[{index:0,rgb:[0,0,130]},{index:.1,rgb:[0,180,180]},{index:.2,rgb:[40,210,40]},{index:.4,rgb:[230,230,50]},{index:.6,rgb:[120,70,20]},{index:1,rgb:[255,255,255]}],electric:[{index:0,rgb:[0,0,0]},{index:.15,rgb:[30,0,100]},{index:.4,rgb:[120,0,100]},{index:.6,rgb:[160,90,0]},{index:.8,rgb:[230,200,0]},{index:1,rgb:[255,250,220]}],alpha:[{index:0,rgb:[255,255,255,0]},{index:1,rgb:[255,255,255,1]}],viridis:[{index:0,rgb:[68,1,84]},{index:.13,rgb:[71,44,122]},{index:.25,rgb:[59,81,139]},{index:.38,rgb:[44,113,142]},{index:.5,rgb:[33,144,141]},{index:.63,rgb:[39,173,129]},{index:.75,rgb:[92,200,99]},{index:.88,rgb:[170,220,50]},{index:1,rgb:[253,231,37]}],inferno:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[31,12,72]},{index:.25,rgb:[85,15,109]},{index:.38,rgb:[136,34,106]},{index:.5,rgb:[186,54,85]},{index:.63,rgb:[227,89,51]},{index:.75,rgb:[249,140,10]},{index:.88,rgb:[249,201,50]},{index:1,rgb:[252,255,164]}],magma:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[28,16,68]},{index:.25,rgb:[79,18,123]},{index:.38,rgb:[129,37,129]},{index:.5,rgb:[181,54,122]},{index:.63,rgb:[229,80,100]},{index:.75,rgb:[251,135,97]},{index:.88,rgb:[254,194,135]},{index:1,rgb:[252,253,191]}],plasma:[{index:0,rgb:[13,8,135]},{index:.13,rgb:[75,3,161]},{index:.25,rgb:[125,3,168]},{index:.38,rgb:[168,34,150]},{index:.5,rgb:[203,70,121]},{index:.63,rgb:[229,107,93]},{index:.75,rgb:[248,148,65]},{index:.88,rgb:[253,195,40]},{index:1,rgb:[240,249,33]}],warm:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[172,0,187]},{index:.25,rgb:[219,0,170]},{index:.38,rgb:[255,0,130]},{index:.5,rgb:[255,63,74]},{index:.63,rgb:[255,123,0]},{index:.75,rgb:[234,176,0]},{index:.88,rgb:[190,228,0]},{index:1,rgb:[147,255,0]}],cool:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[116,0,218]},{index:.25,rgb:[98,74,237]},{index:.38,rgb:[68,146,231]},{index:.5,rgb:[0,204,197]},{index:.63,rgb:[0,247,146]},{index:.75,rgb:[0,255,88]},{index:.88,rgb:[40,255,8]},{index:1,rgb:[147,255,0]}],\"rainbow-soft\":[{index:0,rgb:[125,0,179]},{index:.1,rgb:[199,0,180]},{index:.2,rgb:[255,0,121]},{index:.3,rgb:[255,108,0]},{index:.4,rgb:[222,194,0]},{index:.5,rgb:[150,255,0]},{index:.6,rgb:[0,255,55]},{index:.7,rgb:[0,246,150]},{index:.8,rgb:[50,167,222]},{index:.9,rgb:[103,51,235]},{index:1,rgb:[124,0,186]}],bathymetry:[{index:0,rgb:[40,26,44]},{index:.13,rgb:[59,49,90]},{index:.25,rgb:[64,76,139]},{index:.38,rgb:[63,110,151]},{index:.5,rgb:[72,142,158]},{index:.63,rgb:[85,174,163]},{index:.75,rgb:[120,206,163]},{index:.88,rgb:[187,230,172]},{index:1,rgb:[253,254,204]}],cdom:[{index:0,rgb:[47,15,62]},{index:.13,rgb:[87,23,86]},{index:.25,rgb:[130,28,99]},{index:.38,rgb:[171,41,96]},{index:.5,rgb:[206,67,86]},{index:.63,rgb:[230,106,84]},{index:.75,rgb:[242,149,103]},{index:.88,rgb:[249,193,135]},{index:1,rgb:[254,237,176]}],chlorophyll:[{index:0,rgb:[18,36,20]},{index:.13,rgb:[25,63,41]},{index:.25,rgb:[24,91,59]},{index:.38,rgb:[13,119,72]},{index:.5,rgb:[18,148,80]},{index:.63,rgb:[80,173,89]},{index:.75,rgb:[132,196,122]},{index:.88,rgb:[175,221,162]},{index:1,rgb:[215,249,208]}],density:[{index:0,rgb:[54,14,36]},{index:.13,rgb:[89,23,80]},{index:.25,rgb:[110,45,132]},{index:.38,rgb:[120,77,178]},{index:.5,rgb:[120,113,213]},{index:.63,rgb:[115,151,228]},{index:.75,rgb:[134,185,227]},{index:.88,rgb:[177,214,227]},{index:1,rgb:[230,241,241]}],\"freesurface-blue\":[{index:0,rgb:[30,4,110]},{index:.13,rgb:[47,14,176]},{index:.25,rgb:[41,45,236]},{index:.38,rgb:[25,99,212]},{index:.5,rgb:[68,131,200]},{index:.63,rgb:[114,156,197]},{index:.75,rgb:[157,181,203]},{index:.88,rgb:[200,208,216]},{index:1,rgb:[241,237,236]}],\"freesurface-red\":[{index:0,rgb:[60,9,18]},{index:.13,rgb:[100,17,27]},{index:.25,rgb:[142,20,29]},{index:.38,rgb:[177,43,27]},{index:.5,rgb:[192,87,63]},{index:.63,rgb:[205,125,105]},{index:.75,rgb:[216,162,148]},{index:.88,rgb:[227,199,193]},{index:1,rgb:[241,237,236]}],oxygen:[{index:0,rgb:[64,5,5]},{index:.13,rgb:[106,6,15]},{index:.25,rgb:[144,26,7]},{index:.38,rgb:[168,64,3]},{index:.5,rgb:[188,100,4]},{index:.63,rgb:[206,136,11]},{index:.75,rgb:[220,174,25]},{index:.88,rgb:[231,215,44]},{index:1,rgb:[248,254,105]}],par:[{index:0,rgb:[51,20,24]},{index:.13,rgb:[90,32,35]},{index:.25,rgb:[129,44,34]},{index:.38,rgb:[159,68,25]},{index:.5,rgb:[182,99,19]},{index:.63,rgb:[199,134,22]},{index:.75,rgb:[212,171,35]},{index:.88,rgb:[221,210,54]},{index:1,rgb:[225,253,75]}],phase:[{index:0,rgb:[145,105,18]},{index:.13,rgb:[184,71,38]},{index:.25,rgb:[186,58,115]},{index:.38,rgb:[160,71,185]},{index:.5,rgb:[110,97,218]},{index:.63,rgb:[50,123,164]},{index:.75,rgb:[31,131,110]},{index:.88,rgb:[77,129,34]},{index:1,rgb:[145,105,18]}],salinity:[{index:0,rgb:[42,24,108]},{index:.13,rgb:[33,50,162]},{index:.25,rgb:[15,90,145]},{index:.38,rgb:[40,118,137]},{index:.5,rgb:[59,146,135]},{index:.63,rgb:[79,175,126]},{index:.75,rgb:[120,203,104]},{index:.88,rgb:[193,221,100]},{index:1,rgb:[253,239,154]}],temperature:[{index:0,rgb:[4,35,51]},{index:.13,rgb:[23,51,122]},{index:.25,rgb:[85,59,157]},{index:.38,rgb:[129,79,143]},{index:.5,rgb:[175,95,130]},{index:.63,rgb:[222,112,101]},{index:.75,rgb:[249,146,66]},{index:.88,rgb:[249,196,65]},{index:1,rgb:[232,250,91]}],turbidity:[{index:0,rgb:[34,31,27]},{index:.13,rgb:[65,50,41]},{index:.25,rgb:[98,69,52]},{index:.38,rgb:[131,89,57]},{index:.5,rgb:[161,112,59]},{index:.63,rgb:[185,140,66]},{index:.75,rgb:[202,174,88]},{index:.88,rgb:[216,209,126]},{index:1,rgb:[233,246,171]}],\"velocity-blue\":[{index:0,rgb:[17,32,64]},{index:.13,rgb:[35,52,116]},{index:.25,rgb:[29,81,156]},{index:.38,rgb:[31,113,162]},{index:.5,rgb:[50,144,169]},{index:.63,rgb:[87,173,176]},{index:.75,rgb:[149,196,189]},{index:.88,rgb:[203,221,211]},{index:1,rgb:[254,251,230]}],\"velocity-green\":[{index:0,rgb:[23,35,19]},{index:.13,rgb:[24,64,38]},{index:.25,rgb:[11,95,45]},{index:.38,rgb:[39,123,35]},{index:.5,rgb:[95,146,12]},{index:.63,rgb:[152,165,18]},{index:.75,rgb:[201,186,69]},{index:.88,rgb:[233,216,137]},{index:1,rgb:[255,253,205]}],cubehelix:[{index:0,rgb:[0,0,0]},{index:.07,rgb:[22,5,59]},{index:.13,rgb:[60,4,105]},{index:.2,rgb:[109,1,135]},{index:.27,rgb:[161,0,147]},{index:.33,rgb:[210,2,142]},{index:.4,rgb:[251,11,123]},{index:.47,rgb:[255,29,97]},{index:.53,rgb:[255,54,69]},{index:.6,rgb:[255,85,46]},{index:.67,rgb:[255,120,34]},{index:.73,rgb:[255,157,37]},{index:.8,rgb:[241,191,57]},{index:.87,rgb:[224,220,93]},{index:.93,rgb:[218,241,142]},{index:1,rgb:[227,253,198]}]}},{}],126:[function(t,e,r){\"use strict\";var n=t(\"./colorScale\"),i=t(\"lerp\");function a(t){return[t[0]/255,t[1]/255,t[2]/255,t[3]]}function o(t){for(var e,r=\"#\",n=0;n<3;++n)r+=(\"00\"+(e=(e=t[n]).toString(16))).substr(e.length);return r}function s(t){return\"rgba(\"+t.join(\",\")+\")\"}e.exports=function(t){var e,r,l,c,u,h,f,p,d,g;t||(t={});p=(t.nshades||72)-1,f=t.format||\"hex\",(h=t.colormap)||(h=\"jet\");if(\"string\"==typeof h){if(h=h.toLowerCase(),!n[h])throw Error(h+\" not a supported colorscale\");u=n[h]}else{if(!Array.isArray(h))throw Error(\"unsupported colormap option\",h);u=h.slice()}if(u.length>p+1)throw new Error(h+\" map requires nshades to be at least size \"+u.length);d=Array.isArray(t.alpha)?2!==t.alpha.length?[1,1]:t.alpha.slice():\"number\"==typeof t.alpha?[t.alpha,t.alpha]:[1,1];e=u.map(function(t){return Math.round(t.index*p)}),d[0]=Math.min(Math.max(d[0],0),1),d[1]=Math.min(Math.max(d[1],0),1);var v=u.map(function(t,e){var r=u[e].index,n=u[e].rgb.slice();return 4===n.length&&n[3]>=0&&n[3]<=1?n:(n[3]=d[0]+(d[1]-d[0])*r,n)}),m=[];for(g=0;g<e.length-1;++g){c=e[g+1]-e[g],r=v[g],l=v[g+1];for(var y=0;y<c;y++){var x=y/c;m.push([Math.round(i(r[0],l[0],x)),Math.round(i(r[1],l[1],x)),Math.round(i(r[2],l[2],x)),i(r[3],l[3],x)])}}m.push(u[u.length-1].rgb.concat(d[1])),\"hex\"===f?m=m.map(o):\"rgbaString\"===f?m=m.map(s):\"float\"===f&&(m=m.map(a));return m}},{\"./colorScale\":125,lerp:425}],127:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a){var o=n(e,r,a);if(0===o){var s=i(n(t,e,r)),c=i(n(t,e,a));if(s===c){if(0===s){var u=l(t,e,r),h=l(t,e,a);return u===h?0:u?1:-1}return 0}return 0===c?s>0?-1:l(t,e,a)?-1:1:0===s?c>0?1:l(t,e,r)?1:-1:i(c-s)}var f=n(t,e,r);if(f>0)return o>0&&n(t,e,a)>0?1:-1;if(f<0)return o>0||n(t,e,a)>0?1:-1;var p=n(t,e,a);return p>0?1:l(t,e,r)?1:-1};var n=t(\"robust-orientation\"),i=t(\"signum\"),a=t(\"two-sum\"),o=t(\"robust-product\"),s=t(\"robust-sum\");function l(t,e,r){var n=a(t[0],-e[0]),i=a(t[1],-e[1]),l=a(r[0],-e[0]),c=a(r[1],-e[1]),u=s(o(n,l),o(i,c));return u[u.length-1]>=0}},{\"robust-orientation\":510,\"robust-product\":511,\"robust-sum\":515,signum:516,\"two-sum\":544}],128:[function(t,e,r){e.exports=function(t,e){var r=t.length,a=t.length-e.length;if(a)return a;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return t[0]+t[1]-e[0]-e[1]||n(t[0],t[1])-n(e[0],e[1]);case 3:var o=t[0]+t[1],s=e[0]+e[1];if(a=o+t[2]-(s+e[2]))return a;var l=n(t[0],t[1]),c=n(e[0],e[1]);return n(l,t[2])-n(c,e[2])||n(l+t[2],o)-n(c+e[2],s);case 4:var u=t[0],h=t[1],f=t[2],p=t[3],d=e[0],g=e[1],v=e[2],m=e[3];return u+h+f+p-(d+g+v+m)||n(u,h,f,p)-n(d,g,v,m,d)||n(u+h,u+f,u+p,h+f,h+p,f+p)-n(d+g,d+v,d+m,g+v,g+m,v+m)||n(u+h+f,u+h+p,u+f+p,h+f+p)-n(d+g+v,d+g+m,d+v+m,g+v+m);default:for(var y=t.slice().sort(i),x=e.slice().sort(i),b=0;b<r;++b)if(a=y[b]-x[b])return a;return 0}};var n=Math.min;function i(t,e){return t-e}},{}],129:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"cell-orientation\");e.exports=function(t,e){return n(t,e)||i(t)-i(e)}},{\"cell-orientation\":112,\"compare-cell\":128}],130:[function(t,e,r){\"use strict\";var n=t(\"./lib/ch1d\"),i=t(\"./lib/ch2d\"),a=t(\"./lib/chnd\");e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[[0]];var r=t[0].length;if(0===r)return[];if(1===r)return n(t);if(2===r)return i(t);return a(t,r)}},{\"./lib/ch1d\":131,\"./lib/ch2d\":132,\"./lib/chnd\":133}],131:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0,r=0,n=1;n<t.length;++n)t[n][0]<t[e][0]&&(e=n),t[n][0]>t[r][0]&&(r=n);return e<r?[[e],[r]]:e>r?[[r],[e]]:[[e]]}},{}],132:[function(t,e,r){\"use strict\";e.exports=function(t){var e=n(t),r=e.length;if(r<=2)return[];for(var i=new Array(r),a=e[r-1],o=0;o<r;++o){var s=e[o];i[o]=[a,s],a=s}return i};var n=t(\"monotone-convex-hull-2d\")},{\"monotone-convex-hull-2d\":434}],133:[function(t,e,r){\"use strict\";e.exports=function(t,e){try{return n(t,!0)}catch(s){var r=i(t);if(r.length<=e)return[];var a=function(t,e){for(var r=t.length,n=new Array(r),i=0;i<e.length;++i)n[i]=t[e[i]];for(var a=e.length,i=0;i<r;++i)e.indexOf(i)<0&&(n[a++]=t[i]);return n}(t,r),o=n(a,!0);return function(t,e){for(var r=t.length,n=e.length,i=0;i<r;++i)for(var a=t[i],o=0;o<a.length;++o){var s=a[o];if(s<n)a[o]=e[s];else{s-=n;for(var l=0;l<n;++l)s>=e[l]&&(s+=1);a[o]=s}}return t}(o,r)}};var n=t(\"incremental-convex-hull\"),i=t(\"affine-hull\")},{\"affine-hull\":62,\"incremental-convex-hull\":413}],134:[function(t,e,r){e.exports={AFG:\"afghan\",ALA:\"\\\\b\\\\wland\",ALB:\"albania\",DZA:\"algeria\",ASM:\"^(?=.*americ).*samoa\",AND:\"andorra\",AGO:\"angola\",AIA:\"anguill?a\",ATA:\"antarctica\",ATG:\"antigua\",ARG:\"argentin\",ARM:\"armenia\",ABW:\"^(?!.*bonaire).*\\\\baruba\",AUS:\"australia\",AUT:\"^(?!.*hungary).*austria|\\\\baustri.*\\\\bemp\",AZE:\"azerbaijan\",BHS:\"bahamas\",BHR:\"bahrain\",BGD:\"bangladesh|^(?=.*east).*paki?stan\",BRB:\"barbados\",BLR:\"belarus|byelo\",BEL:\"^(?!.*luxem).*belgium\",BLZ:\"belize|^(?=.*british).*honduras\",BEN:\"benin|dahome\",BMU:\"bermuda\",BTN:\"bhutan\",BOL:\"bolivia\",BES:\"^(?=.*bonaire).*eustatius|^(?=.*carib).*netherlands|\\\\bbes.?islands\",BIH:\"herzegovina|bosnia\",BWA:\"botswana|bechuana\",BVT:\"bouvet\",BRA:\"brazil\",IOT:\"british.?indian.?ocean\",BRN:\"brunei\",BGR:\"bulgaria\",BFA:\"burkina|\\\\bfaso|upper.?volta\",BDI:\"burundi\",CPV:\"verde\",KHM:\"cambodia|kampuchea|khmer\",CMR:\"cameroon\",CAN:\"canada\",CYM:\"cayman\",CAF:\"\\\\bcentral.african.republic\",TCD:\"\\\\bchad\",CHL:\"\\\\bchile\",CHN:\"^(?!.*\\\\bmac)(?!.*\\\\bhong)(?!.*\\\\btai)(?!.*\\\\brep).*china|^(?=.*peo)(?=.*rep).*china\",CXR:\"christmas\",CCK:\"\\\\bcocos|keeling\",COL:\"colombia\",COM:\"comoro\",COG:\"^(?!.*\\\\bdem)(?!.*\\\\bd[\\\\.]?r)(?!.*kinshasa)(?!.*zaire)(?!.*belg)(?!.*l.opoldville)(?!.*free).*\\\\bcongo\",COK:\"\\\\bcook\",CRI:\"costa.?rica\",CIV:\"ivoire|ivory\",HRV:\"croatia\",CUB:\"\\\\bcuba\",CUW:\"^(?!.*bonaire).*\\\\bcura(c|\\xe7)ao\",CYP:\"cyprus\",CSK:\"czechoslovakia\",CZE:\"^(?=.*rep).*czech|czechia|bohemia\",COD:\"\\\\bdem.*congo|congo.*\\\\bdem|congo.*\\\\bd[\\\\.]?r|\\\\bd[\\\\.]?r.*congo|belgian.?congo|congo.?free.?state|kinshasa|zaire|l.opoldville|drc|droc|rdc\",DNK:\"denmark\",DJI:\"djibouti\",DMA:\"dominica(?!n)\",DOM:\"dominican.rep\",ECU:\"ecuador\",EGY:\"egypt\",SLV:\"el.?salvador\",GNQ:\"guine.*eq|eq.*guine|^(?=.*span).*guinea\",ERI:\"eritrea\",EST:\"estonia\",ETH:\"ethiopia|abyssinia\",FLK:\"falkland|malvinas\",FRO:\"faroe|faeroe\",FJI:\"fiji\",FIN:\"finland\",FRA:\"^(?!.*\\\\bdep)(?!.*martinique).*france|french.?republic|\\\\bgaul\",GUF:\"^(?=.*french).*guiana\",PYF:\"french.?polynesia|tahiti\",ATF:\"french.?southern\",GAB:\"gabon\",GMB:\"gambia\",GEO:\"^(?!.*south).*georgia\",DDR:\"german.?democratic.?republic|democratic.?republic.*germany|east.germany\",DEU:\"^(?!.*east).*germany|^(?=.*\\\\bfed.*\\\\brep).*german\",GHA:\"ghana|gold.?coast\",GIB:\"gibraltar\",GRC:\"greece|hellenic|hellas\",GRL:\"greenland\",GRD:\"grenada\",GLP:\"guadeloupe\",GUM:\"\\\\bguam\",GTM:\"guatemala\",GGY:\"guernsey\",GIN:\"^(?!.*eq)(?!.*span)(?!.*bissau)(?!.*portu)(?!.*new).*guinea\",GNB:\"bissau|^(?=.*portu).*guinea\",GUY:\"guyana|british.?guiana\",HTI:\"haiti\",HMD:\"heard.*mcdonald\",VAT:\"holy.?see|vatican|papal.?st\",HND:\"^(?!.*brit).*honduras\",HKG:\"hong.?kong\",HUN:\"^(?!.*austr).*hungary\",ISL:\"iceland\",IND:\"india(?!.*ocea)\",IDN:\"indonesia\",IRN:\"\\\\biran|persia\",IRQ:\"\\\\biraq|mesopotamia\",IRL:\"(^ireland)|(^republic.*ireland)\",IMN:\"^(?=.*isle).*\\\\bman\",ISR:\"israel\",ITA:\"italy\",JAM:\"jamaica\",JPN:\"japan\",JEY:\"jersey\",JOR:\"jordan\",KAZ:\"kazak\",KEN:\"kenya|british.?east.?africa|east.?africa.?prot\",KIR:\"kiribati\",PRK:\"^(?=.*democrat|people|north|d.*p.*.r).*\\\\bkorea|dprk|korea.*(d.*p.*r)\",KWT:\"kuwait\",KGZ:\"kyrgyz|kirghiz\",LAO:\"\\\\blaos?\\\\b\",LVA:\"latvia\",LBN:\"lebanon\",LSO:\"lesotho|basuto\",LBR:\"liberia\",LBY:\"libya\",LIE:\"liechtenstein\",LTU:\"lithuania\",LUX:\"^(?!.*belg).*luxem\",MAC:\"maca(o|u)\",MDG:\"madagascar|malagasy\",MWI:\"malawi|nyasa\",MYS:\"malaysia\",MDV:\"maldive\",MLI:\"\\\\bmali\\\\b\",MLT:\"\\\\bmalta\",MHL:\"marshall\",MTQ:\"martinique\",MRT:\"mauritania\",MUS:\"mauritius\",MYT:\"\\\\bmayotte\",MEX:\"\\\\bmexic\",FSM:\"fed.*micronesia|micronesia.*fed\",MCO:\"monaco\",MNG:\"mongolia\",MNE:\"^(?!.*serbia).*montenegro\",MSR:\"montserrat\",MAR:\"morocco|\\\\bmaroc\",MOZ:\"mozambique\",MMR:\"myanmar|burma\",NAM:\"namibia\",NRU:\"nauru\",NPL:\"nepal\",NLD:\"^(?!.*\\\\bant)(?!.*\\\\bcarib).*netherlands\",ANT:\"^(?=.*\\\\bant).*(nether|dutch)\",NCL:\"new.?caledonia\",NZL:\"new.?zealand\",NIC:\"nicaragua\",NER:\"\\\\bniger(?!ia)\",NGA:\"nigeria\",NIU:\"niue\",NFK:\"norfolk\",MNP:\"mariana\",NOR:\"norway\",OMN:\"\\\\boman|trucial\",PAK:\"^(?!.*east).*paki?stan\",PLW:\"palau\",PSE:\"palestin|\\\\bgaza|west.?bank\",PAN:\"panama\",PNG:\"papua|new.?guinea\",PRY:\"paraguay\",PER:\"peru\",PHL:\"philippines\",PCN:\"pitcairn\",POL:\"poland\",PRT:\"portugal\",PRI:\"puerto.?rico\",QAT:\"qatar\",KOR:\"^(?!.*d.*p.*r)(?!.*democrat)(?!.*people)(?!.*north).*\\\\bkorea(?!.*d.*p.*r)\",MDA:\"moldov|b(a|e)ssarabia\",REU:\"r(e|\\xe9)union\",ROU:\"r(o|u|ou)mania\",RUS:\"\\\\brussia|soviet.?union|u\\\\.?s\\\\.?s\\\\.?r|socialist.?republics\",RWA:\"rwanda\",BLM:\"barth(e|\\xe9)lemy\",SHN:\"helena\",KNA:\"kitts|\\\\bnevis\",LCA:\"\\\\blucia\",MAF:\"^(?=.*collectivity).*martin|^(?=.*france).*martin(?!ique)|^(?=.*french).*martin(?!ique)\",SPM:\"miquelon\",VCT:\"vincent\",WSM:\"^(?!.*amer).*samoa\",SMR:\"san.?marino\",STP:\"\\\\bs(a|\\xe3)o.?tom(e|\\xe9)\",SAU:\"\\\\bsa\\\\w*.?arabia\",SEN:\"senegal\",SRB:\"^(?!.*monte).*serbia\",SYC:\"seychell\",SLE:\"sierra\",SGP:\"singapore\",SXM:\"^(?!.*martin)(?!.*saba).*maarten\",SVK:\"^(?!.*cze).*slovak\",SVN:\"slovenia\",SLB:\"solomon\",SOM:\"somali\",ZAF:\"south.africa|s\\\\\\\\..?africa\",SGS:\"south.?georgia|sandwich\",SSD:\"\\\\bs\\\\w*.?sudan\",ESP:\"spain\",LKA:\"sri.?lanka|ceylon\",SDN:\"^(?!.*\\\\bs(?!u)).*sudan\",SUR:\"surinam|dutch.?guiana\",SJM:\"svalbard\",SWZ:\"swaziland\",SWE:\"sweden\",CHE:\"switz|swiss\",SYR:\"syria\",TWN:\"taiwan|taipei|formosa|^(?!.*peo)(?=.*rep).*china\",TJK:\"tajik\",THA:\"thailand|\\\\bsiam\",MKD:\"macedonia|fyrom\",TLS:\"^(?=.*leste).*timor|^(?=.*east).*timor\",TGO:\"togo\",TKL:\"tokelau\",TON:\"tonga\",TTO:\"trinidad|tobago\",TUN:\"tunisia\",TUR:\"turkey\",TKM:\"turkmen\",TCA:\"turks\",TUV:\"tuvalu\",UGA:\"uganda\",UKR:\"ukrain\",ARE:\"emirates|^u\\\\.?a\\\\.?e\\\\.?$|united.?arab.?em\",GBR:\"united.?kingdom|britain|^u\\\\.?k\\\\.?$\",TZA:\"tanzania\",USA:\"united.?states\\\\b(?!.*islands)|\\\\bu\\\\.?s\\\\.?a\\\\.?\\\\b|^\\\\s*u\\\\.?s\\\\.?\\\\b(?!.*islands)\",UMI:\"minor.?outlying.?is\",URY:\"uruguay\",UZB:\"uzbek\",VUT:\"vanuatu|new.?hebrides\",VEN:\"venezuela\",VNM:\"^(?!.*republic).*viet.?nam|^(?=.*socialist).*viet.?nam\",VGB:\"^(?=.*\\\\bu\\\\.?\\\\s?k).*virgin|^(?=.*brit).*virgin|^(?=.*kingdom).*virgin\",VIR:\"^(?=.*\\\\bu\\\\.?\\\\s?s).*virgin|^(?=.*states).*virgin\",WLF:\"futuna|wallis\",ESH:\"western.sahara\",YEM:\"^(?!.*arab)(?!.*north)(?!.*sana)(?!.*peo)(?!.*dem)(?!.*south)(?!.*aden)(?!.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YMD:\"^(?=.*peo).*yemen|^(?!.*rep)(?=.*dem).*yemen|^(?=.*south).*yemen|^(?=.*aden).*yemen|^(?=.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YUG:\"yugoslavia\",ZMB:\"zambia|northern.?rhodesia\",EAZ:\"zanzibar\",ZWE:\"zimbabwe|^(?!.*northern).*rhodesia\"}},{}],135:[function(t,e,r){e.exports=[\"xx-small\",\"x-small\",\"small\",\"medium\",\"large\",\"x-large\",\"xx-large\",\"larger\",\"smaller\"]},{}],136:[function(t,e,r){e.exports=[\"normal\",\"condensed\",\"semi-condensed\",\"extra-condensed\",\"ultra-condensed\",\"expanded\",\"semi-expanded\",\"extra-expanded\",\"ultra-expanded\"]},{}],137:[function(t,e,r){e.exports=[\"normal\",\"italic\",\"oblique\"]},{}],138:[function(t,e,r){e.exports=[\"normal\",\"bold\",\"bolder\",\"lighter\",\"100\",\"200\",\"300\",\"400\",\"500\",\"600\",\"700\",\"800\",\"900\"]},{}],139:[function(t,e,r){\"use strict\";e.exports={parse:t(\"./parse\"),stringify:t(\"./stringify\")}},{\"./parse\":141,\"./stringify\":142}],140:[function(t,e,r){\"use strict\";var n=t(\"css-font-size-keywords\");e.exports={isSize:function(t){return/^[\\d\\.]/.test(t)||-1!==t.indexOf(\"/\")||-1!==n.indexOf(t)}}},{\"css-font-size-keywords\":135}],141:[function(t,e,r){\"use strict\";var n=t(\"unquote\"),i=t(\"css-global-keywords\"),a=t(\"css-system-font-keywords\"),o=t(\"css-font-weight-keywords\"),s=t(\"css-font-style-keywords\"),l=t(\"css-font-stretch-keywords\"),c=t(\"string-split-by\"),u=t(\"./lib/util\").isSize;e.exports=f;var h=f.cache={};function f(t){if(\"string\"!=typeof t)throw new Error(\"Font argument must be a string.\");if(h[t])return h[t];if(\"\"===t)throw new Error(\"Cannot parse an empty string.\");if(-1!==a.indexOf(t))return h[t]={system:t};for(var e,r={style:\"normal\",variant:\"normal\",weight:\"normal\",stretch:\"normal\",lineHeight:\"normal\",size:\"1rem\",family:[\"serif\"]},f=c(t,/\\s+/);e=f.shift();){if(-1!==i.indexOf(e))return[\"style\",\"variant\",\"weight\",\"stretch\"].forEach(function(t){r[t]=e}),h[t]=r;if(-1===s.indexOf(e))if(\"normal\"!==e&&\"small-caps\"!==e)if(-1===l.indexOf(e)){if(-1===o.indexOf(e)){if(u(e)){var d=c(e,\"/\");if(r.size=d[0],null!=d[1]?r.lineHeight=p(d[1]):\"/\"===f[0]&&(f.shift(),r.lineHeight=p(f.shift())),!f.length)throw new Error(\"Missing required font-family.\");return r.family=c(f.join(\" \"),/\\s*,\\s*/).map(n),h[t]=r}throw new Error(\"Unknown or unsupported font token: \"+e)}r.weight=e}else r.stretch=e;else r.variant=e;else r.style=e}throw new Error(\"Missing required font-size.\")}function p(t){var e=parseFloat(t);return e.toString()===t?e:t}},{\"./lib/util\":140,\"css-font-stretch-keywords\":136,\"css-font-style-keywords\":137,\"css-font-weight-keywords\":138,\"css-global-keywords\":143,\"css-system-font-keywords\":144,\"string-split-by\":529,unquote:548}],142:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\"),i=t(\"./lib/util\").isSize,a=g(t(\"css-global-keywords\")),o=g(t(\"css-system-font-keywords\")),s=g(t(\"css-font-weight-keywords\")),l=g(t(\"css-font-style-keywords\")),c=g(t(\"css-font-stretch-keywords\")),u={normal:1,\"small-caps\":1},h={serif:1,\"sans-serif\":1,monospace:1,cursive:1,fantasy:1,\"system-ui\":1},f=\"1rem\",p=\"serif\";function d(t,e){if(t&&!e[t]&&!a[t])throw Error(\"Unknown keyword `\"+t+\"`\");return t}function g(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=1;return e}e.exports=function(t){if((t=n(t,{style:\"style fontstyle fontStyle font-style slope distinction\",variant:\"variant font-variant fontVariant fontvariant var capitalization\",weight:\"weight w font-weight fontWeight fontweight\",stretch:\"stretch font-stretch fontStretch fontstretch width\",size:\"size s font-size fontSize fontsize height em emSize\",lineHeight:\"lh line-height lineHeight lineheight leading\",family:\"font family fontFamily font-family fontfamily type typeface face\",system:\"system reserved default global\"})).system)return t.system&&d(t.system,o),t.system;if(d(t.style,l),d(t.variant,u),d(t.weight,s),d(t.stretch,c),null==t.size&&(t.size=f),\"number\"==typeof t.size&&(t.size+=\"px\"),!i)throw Error(\"Bad size value `\"+t.size+\"`\");t.family||(t.family=p),Array.isArray(t.family)&&(t.family.length||(t.family=[p]),t.family=t.family.map(function(t){return h[t]?t:'\"'+t+'\"'}).join(\", \"));var e=[];return e.push(t.style),t.variant!==t.style&&e.push(t.variant),t.weight!==t.variant&&t.weight!==t.style&&e.push(t.weight),t.stretch!==t.weight&&t.stretch!==t.variant&&t.stretch!==t.style&&e.push(t.stretch),e.push(t.size+(null==t.lineHeight||\"normal\"===t.lineHeight||t.lineHeight+\"\"==\"1\"?\"\":\"/\"+t.lineHeight)),e.push(t.family),e.filter(Boolean).join(\" \")}},{\"./lib/util\":140,\"css-font-stretch-keywords\":136,\"css-font-style-keywords\":137,\"css-font-weight-keywords\":138,\"css-global-keywords\":143,\"css-system-font-keywords\":144,\"pick-by-alias\":465}],143:[function(t,e,r){e.exports=[\"inherit\",\"initial\",\"unset\"]},{}],144:[function(t,e,r){e.exports=[\"caption\",\"icon\",\"menu\",\"message-box\",\"small-caption\",\"status-bar\"]},{}],145:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i-1,s=i*i,l=o*o,c=(1+2*i)*l,u=i*l,h=s*(3-2*i),f=s*o;if(t.length){a||(a=new Array(t.length));for(var p=t.length-1;p>=0;--p)a[p]=c*t[p]+u*e[p]+h*r[p]+f*n[p];return a}return c*t+u*e+h*r+f*n},e.exports.derivative=function(t,e,r,n,i,a){var o=6*i*i-6*i,s=3*i*i-4*i+1,l=-6*i*i+6*i,c=3*i*i-2*i;if(t.length){a||(a=new Array(t.length));for(var u=t.length-1;u>=0;--u)a[u]=o*t[u]+s*e[u]+l*r[u]+c*n[u];return a}return o*t+s*e+l*r[u]+c*n}},{}],146:[function(t,e,r){\"use strict\";var n=t(\"./lib/thunk.js\");function i(){this.argTypes=[],this.shimArgs=[],this.arrayArgs=[],this.arrayBlockIndices=[],this.scalarArgs=[],this.offsetArgs=[],this.offsetArgIndex=[],this.indexArgs=[],this.shapeArgs=[],this.funcName=\"\",this.pre=null,this.body=null,this.post=null,this.debug=!1}e.exports=function(t){var e=new i;e.pre=t.pre,e.body=t.body,e.post=t.post;var r=t.args.slice(0);e.argTypes=r;for(var a=0;a<r.length;++a){var o=r[a];if(\"array\"===o||\"object\"==typeof o&&o.blockIndices){if(e.argTypes[a]=\"array\",e.arrayArgs.push(a),e.arrayBlockIndices.push(o.blockIndices?o.blockIndices:0),e.shimArgs.push(\"array\"+a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array args\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array args\")}else if(\"scalar\"===o)e.scalarArgs.push(a),e.shimArgs.push(\"scalar\"+a);else if(\"index\"===o){if(e.indexArgs.push(a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array index\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array index\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array index\")}else if(\"shape\"===o){if(e.shapeArgs.push(a),a<e.pre.args.length&&e.pre.args[a].lvalue)throw new Error(\"cwise: pre() block may not write to array shape\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array shape\");if(a<e.post.args.length&&e.post.args[a].lvalue)throw new Error(\"cwise: post() block may not write to array shape\")}else{if(\"object\"!=typeof o||!o.offset)throw new Error(\"cwise: Unknown argument type \"+r[a]);e.argTypes[a]=\"offset\",e.offsetArgs.push({array:o.array,offset:o.offset}),e.offsetArgIndex.push(a)}}if(e.arrayArgs.length<=0)throw new Error(\"cwise: No array arguments specified\");if(e.pre.args.length>r.length)throw new Error(\"cwise: Too many arguments in pre() block\");if(e.body.args.length>r.length)throw new Error(\"cwise: Too many arguments in body() block\");if(e.post.args.length>r.length)throw new Error(\"cwise: Too many arguments in post() block\");return e.debug=!!t.printCode||!!t.debug,e.funcName=t.funcName||\"cwise\",e.blockSize=t.blockSize||64,n(e)}},{\"./lib/thunk.js\":148}],147:[function(t,e,r){\"use strict\";var n=t(\"uniq\");function i(t,e,r){var n,i,a=t.length,o=e.arrayArgs.length,s=e.indexArgs.length>0,l=[],c=[],u=0,h=0;for(n=0;n<a;++n)c.push([\"i\",n,\"=0\"].join(\"\"));for(i=0;i<o;++i)for(n=0;n<a;++n)h=u,u=t[n],0===n?c.push([\"d\",i,\"s\",n,\"=t\",i,\"p\",u].join(\"\")):c.push([\"d\",i,\"s\",n,\"=(t\",i,\"p\",u,\"-s\",h,\"*t\",i,\"p\",h,\")\"].join(\"\"));for(c.length>0&&l.push(\"var \"+c.join(\",\")),n=a-1;n>=0;--n)u=t[n],l.push([\"for(i\",n,\"=0;i\",n,\"<s\",u,\";++i\",n,\"){\"].join(\"\"));for(l.push(r),n=0;n<a;++n){for(h=u,u=t[n],i=0;i<o;++i)l.push([\"p\",i,\"+=d\",i,\"s\",n].join(\"\"));s&&(n>0&&l.push([\"index[\",h,\"]-=s\",h].join(\"\")),l.push([\"++index[\",u,\"]\"].join(\"\"))),l.push(\"}\")}return l.join(\"\\n\")}function a(t,e,r){for(var n=t.body,i=[],a=[],o=0;o<t.args.length;++o){var s=t.args[o];if(!(s.count<=0)){var l=new RegExp(s.name,\"g\"),c=\"\",u=e.arrayArgs.indexOf(o);switch(e.argTypes[o]){case\"offset\":var h=e.offsetArgIndex.indexOf(o);u=e.offsetArgs[h].array,c=\"+q\"+h;case\"array\":c=\"p\"+u+c;var f=\"l\"+o,p=\"a\"+u;if(0===e.arrayBlockIndices[u])1===s.count?\"generic\"===r[u]?s.lvalue?(i.push([\"var \",f,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,f),a.push([p,\".set(\",c,\",\",f,\")\"].join(\"\"))):n=n.replace(l,[p,\".get(\",c,\")\"].join(\"\")):n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\")):\"generic\"===r[u]?(i.push([\"var \",f,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,f),s.lvalue&&a.push([p,\".set(\",c,\",\",f,\")\"].join(\"\"))):(i.push([\"var \",f,\"=\",p,\"[\",c,\"]\"].join(\"\")),n=n.replace(l,f),s.lvalue&&a.push([p,\"[\",c,\"]=\",f].join(\"\")));else{for(var d=[s.name],g=[c],v=0;v<Math.abs(e.arrayBlockIndices[u]);v++)d.push(\"\\\\s*\\\\[([^\\\\]]+)\\\\]\"),g.push(\"$\"+(v+1)+\"*t\"+u+\"b\"+v);if(l=new RegExp(d.join(\"\"),\"g\"),c=g.join(\"+\"),\"generic\"===r[u])throw new Error(\"cwise: Generic arrays not supported in combination with blocks!\");n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\"))}break;case\"scalar\":n=n.replace(l,\"Y\"+e.scalarArgs.indexOf(o));break;case\"index\":n=n.replace(l,\"index\");break;case\"shape\":n=n.replace(l,\"shape\")}}}return[i.join(\"\\n\"),n,a.join(\"\\n\")].join(\"\\n\").trim()}e.exports=function(t,e){for(var r=e[1].length-Math.abs(t.arrayBlockIndices[0])|0,o=new Array(t.arrayArgs.length),s=new Array(t.arrayArgs.length),l=0;l<t.arrayArgs.length;++l)s[l]=e[2*l],o[l]=e[2*l+1];var c=[],u=[],h=[],f=[],p=[];for(l=0;l<t.arrayArgs.length;++l){t.arrayBlockIndices[l]<0?(h.push(0),f.push(r),c.push(r),u.push(r+t.arrayBlockIndices[l])):(h.push(t.arrayBlockIndices[l]),f.push(t.arrayBlockIndices[l]+r),c.push(0),u.push(t.arrayBlockIndices[l]));for(var d=[],g=0;g<o[l].length;g++)h[l]<=o[l][g]&&o[l][g]<f[l]&&d.push(o[l][g]-h[l]);p.push(d)}var v=[\"SS\"],m=[\"'use strict'\"],y=[];for(g=0;g<r;++g)y.push([\"s\",g,\"=SS[\",g,\"]\"].join(\"\"));for(l=0;l<t.arrayArgs.length;++l){for(v.push(\"a\"+l),v.push(\"t\"+l),v.push(\"p\"+l),g=0;g<r;++g)y.push([\"t\",l,\"p\",g,\"=t\",l,\"[\",h[l]+g,\"]\"].join(\"\"));for(g=0;g<Math.abs(t.arrayBlockIndices[l]);++g)y.push([\"t\",l,\"b\",g,\"=t\",l,\"[\",c[l]+g,\"]\"].join(\"\"))}for(l=0;l<t.scalarArgs.length;++l)v.push(\"Y\"+l);if(t.shapeArgs.length>0&&y.push(\"shape=SS.slice(0)\"),t.indexArgs.length>0){var x=new Array(r);for(l=0;l<r;++l)x[l]=\"0\";y.push([\"index=[\",x.join(\",\"),\"]\"].join(\"\"))}for(l=0;l<t.offsetArgs.length;++l){var b=t.offsetArgs[l],_=[];for(g=0;g<b.offset.length;++g)0!==b.offset[g]&&(1===b.offset[g]?_.push([\"t\",b.array,\"p\",g].join(\"\")):_.push([b.offset[g],\"*t\",b.array,\"p\",g].join(\"\")));0===_.length?y.push(\"q\"+l+\"=0\"):y.push([\"q\",l,\"=\",_.join(\"+\")].join(\"\"))}var w=n([].concat(t.pre.thisVars).concat(t.body.thisVars).concat(t.post.thisVars));for((y=y.concat(w)).length>0&&m.push(\"var \"+y.join(\",\")),l=0;l<t.arrayArgs.length;++l)m.push(\"p\"+l+\"|=0\");t.pre.body.length>3&&m.push(a(t.pre,t,s));var k=a(t.body,t,s),T=function(t){for(var e=0,r=t[0].length;e<r;){for(var n=1;n<t.length;++n)if(t[n][e]!==t[0][e])return e;++e}return e}(p);T<r?m.push(function(t,e,r,n){for(var a=e.length,o=r.arrayArgs.length,s=r.blockSize,l=r.indexArgs.length>0,c=[],u=0;u<o;++u)c.push([\"var offset\",u,\"=p\",u].join(\"\"));for(u=t;u<a;++u)c.push([\"for(var j\"+u+\"=SS[\",e[u],\"]|0;j\",u,\">0;){\"].join(\"\")),c.push([\"if(j\",u,\"<\",s,\"){\"].join(\"\")),c.push([\"s\",e[u],\"=j\",u].join(\"\")),c.push([\"j\",u,\"=0\"].join(\"\")),c.push([\"}else{s\",e[u],\"=\",s].join(\"\")),c.push([\"j\",u,\"-=\",s,\"}\"].join(\"\")),l&&c.push([\"index[\",e[u],\"]=j\",u].join(\"\"));for(u=0;u<o;++u){for(var h=[\"offset\"+u],f=t;f<a;++f)h.push([\"j\",f,\"*t\",u,\"p\",e[f]].join(\"\"));c.push([\"p\",u,\"=(\",h.join(\"+\"),\")\"].join(\"\"))}for(c.push(i(e,r,n)),u=t;u<a;++u)c.push(\"}\");return c.join(\"\\n\")}(T,p[0],t,k)):m.push(i(p[0],t,k)),t.post.body.length>3&&m.push(a(t.post,t,s)),t.debug&&console.log(\"-----Generated cwise routine for \",e,\":\\n\"+m.join(\"\\n\")+\"\\n----------\");var A=[t.funcName||\"unnamed\",\"_cwise_loop_\",o[0].join(\"s\"),\"m\",T,function(t){for(var e=new Array(t.length),r=!0,n=0;n<t.length;++n){var i=t[n],a=i.match(/\\d+/);a=a?a[0]:\"\",0===i.charAt(0)?e[n]=\"u\"+i.charAt(1)+a:e[n]=i.charAt(0)+a,n>0&&(r=r&&e[n]===e[n-1])}return r?e[0]:e.join(\"\")}(s)].join(\"\");return new Function([\"function \",A,\"(\",v.join(\",\"),\"){\",m.join(\"\\n\"),\"} return \",A].join(\"\"))()}},{uniq:547}],148:[function(t,e,r){\"use strict\";var n=t(\"./compile.js\");e.exports=function(t){var e=[\"'use strict'\",\"var CACHED={}\"],r=[],i=t.funcName+\"_cwise_thunk\";e.push([\"return function \",i,\"(\",t.shimArgs.join(\",\"),\"){\"].join(\"\"));for(var a=[],o=[],s=[[\"array\",t.arrayArgs[0],\".shape.slice(\",Math.max(0,t.arrayBlockIndices[0]),t.arrayBlockIndices[0]<0?\",\"+t.arrayBlockIndices[0]+\")\":\")\"].join(\"\")],l=[],c=[],u=0;u<t.arrayArgs.length;++u){var h=t.arrayArgs[u];r.push([\"t\",h,\"=array\",h,\".dtype,\",\"r\",h,\"=array\",h,\".order\"].join(\"\")),a.push(\"t\"+h),a.push(\"r\"+h),o.push(\"t\"+h),o.push(\"r\"+h+\".join()\"),s.push(\"array\"+h+\".data\"),s.push(\"array\"+h+\".stride\"),s.push(\"array\"+h+\".offset|0\"),u>0&&(l.push(\"array\"+t.arrayArgs[0]+\".shape.length===array\"+h+\".shape.length+\"+(Math.abs(t.arrayBlockIndices[0])-Math.abs(t.arrayBlockIndices[u]))),c.push(\"array\"+t.arrayArgs[0]+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[0])+\"]===array\"+h+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[u])+\"]\"))}for(t.arrayArgs.length>1&&(e.push(\"if (!(\"+l.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same dimensionality!')\"),e.push(\"for(var shapeIndex=array\"+t.arrayArgs[0]+\".shape.length-\"+Math.abs(t.arrayBlockIndices[0])+\"; shapeIndex--\\x3e0;) {\"),e.push(\"if (!(\"+c.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same shape!')\"),e.push(\"}\")),u=0;u<t.scalarArgs.length;++u)s.push(\"scalar\"+t.scalarArgs[u]);return r.push([\"type=[\",o.join(\",\"),\"].join()\"].join(\"\")),r.push(\"proc=CACHED[type]\"),e.push(\"var \"+r.join(\",\")),e.push([\"if(!proc){\",\"CACHED[type]=proc=compile([\",a.join(\",\"),\"])}\",\"return proc(\",s.join(\",\"),\")}\"].join(\"\")),t.debug&&console.log(\"-----Generated thunk:\\n\"+e.join(\"\\n\")+\"\\n----------\"),new Function(\"compile\",e.join(\"\\n\"))(n.bind(void 0,t))}},{\"./compile.js\":147}],149:[function(t,e,r){e.exports=t(\"cwise-compiler\")},{\"cwise-compiler\":146}],150:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/copy\"),a=t(\"es5-ext/object/normalize-options\"),o=t(\"es5-ext/object/valid-callable\"),s=t(\"es5-ext/object/map\"),l=t(\"es5-ext/object/valid-callable\"),c=t(\"es5-ext/object/valid-value\"),u=Function.prototype.bind,h=Object.defineProperty,f=Object.prototype.hasOwnProperty;n=function(t,e,r){var n,a=c(e)&&l(e.value);return delete(n=i(e)).writable,delete n.value,n.get=function(){return!r.overwriteDefinition&&f.call(this,t)?a:(e.value=u.call(a,r.resolveContext?r.resolveContext(this):this),h(this,t,e),this[t])},n},e.exports=function(t){var e=a(arguments[1]);return null!=e.resolveContext&&o(e.resolveContext),s(t,function(t,r){return n(r,t,e)})}},{\"es5-ext/object/copy\":189,\"es5-ext/object/map\":198,\"es5-ext/object/normalize-options\":199,\"es5-ext/object/valid-callable\":203,\"es5-ext/object/valid-value\":205}],151:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/object/assign\"),i=t(\"es5-ext/object/normalize-options\"),a=t(\"es5-ext/object/is-callable\"),o=t(\"es5-ext/string/#/contains\");(e.exports=function(t,e){var r,a,s,l,c;return arguments.length<2||\"string\"!=typeof t?(l=e,e=t,t=null):l=arguments[2],null==t?(r=s=!0,a=!1):(r=o.call(t,\"c\"),a=o.call(t,\"e\"),s=o.call(t,\"w\")),c={value:e,configurable:r,enumerable:a,writable:s},l?n(i(l),c):c}).gs=function(t,e,r){var s,l,c,u;return\"string\"!=typeof t?(c=r,r=e,e=t,t=null):c=arguments[3],null==e?e=void 0:a(e)?null==r?r=void 0:a(r)||(c=r,r=void 0):(c=e,e=r=void 0),null==t?(s=!0,l=!1):(s=o.call(t,\"c\"),l=o.call(t,\"e\")),u={get:e,set:r,configurable:s,enumerable:l},c?n(i(c),u):u}},{\"es5-ext/object/assign\":186,\"es5-ext/object/is-callable\":192,\"es5-ext/object/normalize-options\":199,\"es5-ext/string/#/contains\":206}],152:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function r(t){var r;return 1===t.length&&(r=t,t=function(t,n){return e(r(t),n)}),{left:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}var n=r(e),i=n.right,a=n.left;function o(t,e){return[t,e]}function s(t){return null===t?NaN:+t}function l(t,e){var r,n,i=t.length,a=0,o=-1,l=0,c=0;if(null==e)for(;++o<i;)isNaN(r=s(t[o]))||(c+=(n=r-l)*(r-(l+=n/++a)));else for(;++o<i;)isNaN(r=s(e(t[o],o,t)))||(c+=(n=r-l)*(r-(l+=n/++a)));if(a>1)return c/(a-1)}function c(t,e){var r=l(t,e);return r?Math.sqrt(r):r}function u(t,e){var r,n,i,a=t.length,o=-1;if(null==e){for(;++o<a;)if(null!=(r=t[o])&&r>=r)for(n=i=r;++o<a;)null!=(r=t[o])&&(n>r&&(n=r),i<r&&(i=r))}else for(;++o<a;)if(null!=(r=e(t[o],o,t))&&r>=r)for(n=i=r;++o<a;)null!=(r=e(t[o],o,t))&&(n>r&&(n=r),i<r&&(i=r));return[n,i]}var h=Array.prototype,f=h.slice,p=h.map;function d(t){return function(){return t}}function g(t){return t}function v(t,e,r){t=+t,e=+e,r=(i=arguments.length)<2?(e=t,t=0,1):i<3?1:+r;for(var n=-1,i=0|Math.max(0,Math.ceil((e-t)/r)),a=new Array(i);++n<i;)a[n]=t+n*r;return a}var m=Math.sqrt(50),y=Math.sqrt(10),x=Math.sqrt(2);function b(t,e,r){var n=(e-t)/Math.max(0,r),i=Math.floor(Math.log(n)/Math.LN10),a=n/Math.pow(10,i);return i>=0?(a>=m?10:a>=y?5:a>=x?2:1)*Math.pow(10,i):-Math.pow(10,-i)/(a>=m?10:a>=y?5:a>=x?2:1)}function _(t,e,r){var n=Math.abs(e-t)/Math.max(0,r),i=Math.pow(10,Math.floor(Math.log(n)/Math.LN10)),a=n/i;return a>=m?i*=10:a>=y?i*=5:a>=x&&(i*=2),e<t?-i:i}function w(t){return Math.ceil(Math.log(t.length)/Math.LN2)+1}function k(t,e,r){if(null==r&&(r=s),n=t.length){if((e=+e)<=0||n<2)return+r(t[0],0,t);if(e>=1)return+r(t[n-1],n-1,t);var n,i=(n-1)*e,a=Math.floor(i),o=+r(t[a],a,t);return o+(+r(t[a+1],a+1,t)-o)*(i-a)}}function T(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&n>r&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&n>r&&(n=r);return n}function A(t){if(!(i=t.length))return[];for(var e=-1,r=T(t,M),n=new Array(r);++e<r;)for(var i,a=-1,o=n[e]=new Array(i);++a<i;)o[a]=t[a][e];return n}function M(t){return t.length}t.bisect=i,t.bisectRight=i,t.bisectLeft=a,t.ascending=e,t.bisector=r,t.cross=function(t,e,r){var n,i,a,s,l=t.length,c=e.length,u=new Array(l*c);for(null==r&&(r=o),n=a=0;n<l;++n)for(s=t[n],i=0;i<c;++i,++a)u[a]=r(s,e[i]);return u},t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.deviation=c,t.extent=u,t.histogram=function(){var t=g,e=u,r=w;function n(n){var a,o,s=n.length,l=new Array(s);for(a=0;a<s;++a)l[a]=t(n[a],a,n);var c=e(l),u=c[0],h=c[1],f=r(l,u,h);Array.isArray(f)||(f=_(u,h,f),f=v(Math.ceil(u/f)*f,h,f));for(var p=f.length;f[0]<=u;)f.shift(),--p;for(;f[p-1]>h;)f.pop(),--p;var d,g=new Array(p+1);for(a=0;a<=p;++a)(d=g[a]=[]).x0=a>0?f[a-1]:u,d.x1=a<p?f[a]:h;for(a=0;a<s;++a)u<=(o=l[a])&&o<=h&&g[i(f,o,0,p)].push(n[a]);return g}return n.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:d(e),n):t},n.domain=function(t){return arguments.length?(e=\"function\"==typeof t?t:d([t[0],t[1]]),n):e},n.thresholds=function(t){return arguments.length?(r=\"function\"==typeof t?t:Array.isArray(t)?d(f.call(t)):d(t),n):r},n},t.thresholdFreedmanDiaconis=function(t,r,n){return t=p.call(t,s).sort(e),Math.ceil((n-r)/(2*(k(t,.75)-k(t,.25))*Math.pow(t.length,-1/3)))},t.thresholdScott=function(t,e,r){return Math.ceil((r-e)/(3.5*c(t)*Math.pow(t.length,-1/3)))},t.thresholdSturges=w,t.max=function(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&r>n&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&r>n&&(n=r);return n},t.mean=function(t,e){var r,n=t.length,i=n,a=-1,o=0;if(null==e)for(;++a<n;)isNaN(r=s(t[a]))?--i:o+=r;else for(;++a<n;)isNaN(r=s(e(t[a],a,t)))?--i:o+=r;if(i)return o/i},t.median=function(t,r){var n,i=t.length,a=-1,o=[];if(null==r)for(;++a<i;)isNaN(n=s(t[a]))||o.push(n);else for(;++a<i;)isNaN(n=s(r(t[a],a,t)))||o.push(n);return k(o.sort(e),.5)},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r},t.min=T,t.pairs=function(t,e){null==e&&(e=o);for(var r=0,n=t.length-1,i=t[0],a=new Array(n<0?0:n);r<n;)a[r]=e(i,i=t[++r]);return a},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.quantile=k,t.range=v,t.scan=function(t,r){if(n=t.length){var n,i,a=0,o=0,s=t[o];for(null==r&&(r=e);++a<n;)(r(i=t[a],s)<0||0!==r(s,s))&&(s=i,o=a);return 0===r(s,s)?o:void 0}},t.shuffle=function(t,e,r){for(var n,i,a=(null==r?t.length:r)-(e=null==e?0:+e);a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.sum=function(t,e){var r,n=t.length,i=-1,a=0;if(null==e)for(;++i<n;)(r=+t[i])&&(a+=r);else for(;++i<n;)(r=+e(t[i],i,t))&&(a+=r);return a},t.ticks=function(t,e,r){var n,i,a,o,s=-1;if(r=+r,(t=+t)==(e=+e)&&r>0)return[t];if((n=e<t)&&(i=t,t=e,e=i),0===(o=b(t,e,r))||!isFinite(o))return[];if(o>0)for(t=Math.ceil(t/o),e=Math.floor(e/o),a=new Array(i=Math.ceil(e-t+1));++s<i;)a[s]=(t+s)*o;else for(t=Math.floor(t*o),e=Math.ceil(e*o),a=new Array(i=Math.ceil(t-e+1));++s<i;)a[s]=(t-s)/o;return n&&a.reverse(),a},t.tickIncrement=b,t.tickStep=_,t.transpose=A,t.variance=l,t.zip=function(){return A(arguments)},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],153:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(){}function r(t,r){var n=new e;if(t instanceof e)t.each(function(t,e){n.set(e,t)});else if(Array.isArray(t)){var i,a=-1,o=t.length;if(null==r)for(;++a<o;)n.set(a,t[a]);else for(;++a<o;)n.set(r(i=t[a],a,t),i)}else if(t)for(var s in t)n.set(s,t[s]);return n}e.prototype=r.prototype={constructor:e,has:function(t){return\"$\"+t in this},get:function(t){return this[\"$\"+t]},set:function(t,e){return this[\"$\"+t]=e,this},remove:function(t){var e=\"$\"+t;return e in this&&delete this[e]},clear:function(){for(var t in this)\"$\"===t[0]&&delete this[t]},keys:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(e.slice(1));return t},values:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(this[e]);return t},entries:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push({key:e.slice(1),value:this[e]});return t},size:function(){var t=0;for(var e in this)\"$\"===e[0]&&++t;return t},empty:function(){for(var t in this)if(\"$\"===t[0])return!1;return!0},each:function(t){for(var e in this)\"$\"===e[0]&&t(this[e],e.slice(1),this)}};function n(){return{}}function i(t,e,r){t[e]=r}function a(){return r()}function o(t,e,r){t.set(e,r)}function s(){}var l=r.prototype;function c(t,e){var r=new s;if(t instanceof s)t.each(function(t){r.add(t)});else if(t){var n=-1,i=t.length;if(null==e)for(;++n<i;)r.add(t[n]);else for(;++n<i;)r.add(e(t[n],n,t))}return r}s.prototype=c.prototype={constructor:s,has:l.has,add:function(t){return this[\"$\"+(t+=\"\")]=t,this},remove:l.remove,clear:l.clear,values:l.keys,size:l.size,empty:l.empty,each:l.each};t.nest=function(){var t,e,s,l=[],c=[];function u(n,i,a,o){if(i>=l.length)return null!=t&&n.sort(t),null!=e?e(n):n;for(var s,c,h,f=-1,p=n.length,d=l[i++],g=r(),v=a();++f<p;)(h=g.get(s=d(c=n[f])+\"\"))?h.push(c):g.set(s,[c]);return g.each(function(t,e){o(v,e,u(t,i,a,o))}),v}return s={object:function(t){return u(t,0,n,i)},map:function(t){return u(t,0,a,o)},entries:function(t){return function t(r,n){if(++n>l.length)return r;var i,a=c[n-1];return null!=e&&n>=l.length?i=r.entries():(i=[],r.each(function(e,r){i.push({key:r,values:t(e,n)})})),null!=a?i.sort(function(t,e){return a(t.key,e.key)}):i}(u(t,0,a,o),0)},key:function(t){return l.push(t),s},sortKeys:function(t){return c[l.length-1]=t,s},sortValues:function(e){return t=e,s},rollup:function(t){return e=t,s}}},t.set=c,t.map=r,t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],154:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e,r){t.prototype=e.prototype=r,r.constructor=t}function r(t,e){var r=Object.create(t.prototype);for(var n in e)r[n]=e[n];return r}function n(){}var i=\"\\\\s*([+-]?\\\\d+)\\\\s*\",a=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)\\\\s*\",o=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)%\\\\s*\",s=/^#([0-9a-f]{3})$/,l=/^#([0-9a-f]{6})$/,c=new RegExp(\"^rgb\\\\(\"+[i,i,i]+\"\\\\)$\"),u=new RegExp(\"^rgb\\\\(\"+[o,o,o]+\"\\\\)$\"),h=new RegExp(\"^rgba\\\\(\"+[i,i,i,a]+\"\\\\)$\"),f=new RegExp(\"^rgba\\\\(\"+[o,o,o,a]+\"\\\\)$\"),p=new RegExp(\"^hsl\\\\(\"+[a,o,o]+\"\\\\)$\"),d=new RegExp(\"^hsla\\\\(\"+[a,o,o,a]+\"\\\\)$\"),g={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};function v(t){var e;return t=(t+\"\").trim().toLowerCase(),(e=s.exec(t))?new _((e=parseInt(e[1],16))>>8&15|e>>4&240,e>>4&15|240&e,(15&e)<<4|15&e,1):(e=l.exec(t))?m(parseInt(e[1],16)):(e=c.exec(t))?new _(e[1],e[2],e[3],1):(e=u.exec(t))?new _(255*e[1]/100,255*e[2]/100,255*e[3]/100,1):(e=h.exec(t))?y(e[1],e[2],e[3],e[4]):(e=f.exec(t))?y(255*e[1]/100,255*e[2]/100,255*e[3]/100,e[4]):(e=p.exec(t))?k(e[1],e[2]/100,e[3]/100,1):(e=d.exec(t))?k(e[1],e[2]/100,e[3]/100,e[4]):g.hasOwnProperty(t)?m(g[t]):\"transparent\"===t?new _(NaN,NaN,NaN,0):null}function m(t){return new _(t>>16&255,t>>8&255,255&t,1)}function y(t,e,r,n){return n<=0&&(t=e=r=NaN),new _(t,e,r,n)}function x(t){return t instanceof n||(t=v(t)),t?new _((t=t.rgb()).r,t.g,t.b,t.opacity):new _}function b(t,e,r,n){return 1===arguments.length?x(t):new _(t,e,r,null==n?1:n)}function _(t,e,r,n){this.r=+t,this.g=+e,this.b=+r,this.opacity=+n}function w(t){return((t=Math.max(0,Math.min(255,Math.round(t)||0)))<16?\"0\":\"\")+t.toString(16)}function k(t,e,r,n){return n<=0?t=e=r=NaN:r<=0||r>=1?t=e=NaN:e<=0&&(t=NaN),new A(t,e,r,n)}function T(t,e,r,i){return 1===arguments.length?function(t){if(t instanceof A)return new A(t.h,t.s,t.l,t.opacity);if(t instanceof n||(t=v(t)),!t)return new A;if(t instanceof A)return t;var e=(t=t.rgb()).r/255,r=t.g/255,i=t.b/255,a=Math.min(e,r,i),o=Math.max(e,r,i),s=NaN,l=o-a,c=(o+a)/2;return l?(s=e===o?(r-i)/l+6*(r<i):r===o?(i-e)/l+2:(e-r)/l+4,l/=c<.5?o+a:2-o-a,s*=60):l=c>0&&c<1?0:s,new A(s,l,c,t.opacity)}(t):new A(t,e,r,null==i?1:i)}function A(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}function M(t,e,r){return 255*(t<60?e+(r-e)*t/60:t<180?r:t<240?e+(r-e)*(240-t)/60:e)}e(n,v,{displayable:function(){return this.rgb().displayable()},hex:function(){return this.rgb().hex()},toString:function(){return this.rgb()+\"\"}}),e(_,b,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new _(this.r*t,this.g*t,this.b*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new _(this.r*t,this.g*t,this.b*t,this.opacity)},rgb:function(){return this},displayable:function(){return 0<=this.r&&this.r<=255&&0<=this.g&&this.g<=255&&0<=this.b&&this.b<=255&&0<=this.opacity&&this.opacity<=1},hex:function(){return\"#\"+w(this.r)+w(this.g)+w(this.b)},toString:function(){var t=this.opacity;return(1===(t=isNaN(t)?1:Math.max(0,Math.min(1,t)))?\"rgb(\":\"rgba(\")+Math.max(0,Math.min(255,Math.round(this.r)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.g)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.b)||0))+(1===t?\")\":\", \"+t+\")\")}})),e(A,T,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new A(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new A(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=this.h%360+360*(this.h<0),e=isNaN(t)||isNaN(this.s)?0:this.s,r=this.l,n=r+(r<.5?r:1-r)*e,i=2*r-n;return new _(M(t>=240?t-240:t+120,i,n),M(t,i,n),M(t<120?t+240:t-120,i,n),this.opacity)},displayable:function(){return(0<=this.s&&this.s<=1||isNaN(this.s))&&0<=this.l&&this.l<=1&&0<=this.opacity&&this.opacity<=1}}));var S=Math.PI/180,E=180/Math.PI,C=.96422,L=1,P=.82521,O=4/29,z=6/29,I=3*z*z,D=z*z*z;function R(t){if(t instanceof B)return new B(t.l,t.a,t.b,t.opacity);if(t instanceof G){if(isNaN(t.h))return new B(t.l,0,0,t.opacity);var e=t.h*S;return new B(t.l,Math.cos(e)*t.c,Math.sin(e)*t.c,t.opacity)}t instanceof _||(t=x(t));var r,n,i=V(t.r),a=V(t.g),o=V(t.b),s=N((.2225045*i+.7168786*a+.0606169*o)/L);return i===a&&a===o?r=n=s:(r=N((.4360747*i+.3850649*a+.1430804*o)/C),n=N((.0139322*i+.0971045*a+.7141733*o)/P)),new B(116*s-16,500*(r-s),200*(s-n),t.opacity)}function F(t,e,r,n){return 1===arguments.length?R(t):new B(t,e,r,null==n?1:n)}function B(t,e,r,n){this.l=+t,this.a=+e,this.b=+r,this.opacity=+n}function N(t){return t>D?Math.pow(t,1/3):t/I+O}function j(t){return t>z?t*t*t:I*(t-O)}function U(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function V(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function q(t){if(t instanceof G)return new G(t.h,t.c,t.l,t.opacity);if(t instanceof B||(t=R(t)),0===t.a&&0===t.b)return new G(NaN,0,t.l,t.opacity);var e=Math.atan2(t.b,t.a)*E;return new G(e<0?e+360:e,Math.sqrt(t.a*t.a+t.b*t.b),t.l,t.opacity)}function H(t,e,r,n){return 1===arguments.length?q(t):new G(t,e,r,null==n?1:n)}function G(t,e,r,n){this.h=+t,this.c=+e,this.l=+r,this.opacity=+n}e(B,F,r(n,{brighter:function(t){return new B(this.l+18*(null==t?1:t),this.a,this.b,this.opacity)},darker:function(t){return new B(this.l-18*(null==t?1:t),this.a,this.b,this.opacity)},rgb:function(){var t=(this.l+16)/116,e=isNaN(this.a)?t:t+this.a/500,r=isNaN(this.b)?t:t-this.b/200;return new _(U(3.1338561*(e=C*j(e))-1.6168667*(t=L*j(t))-.4906146*(r=P*j(r))),U(-.9787684*e+1.9161415*t+.033454*r),U(.0719453*e-.2289914*t+1.4052427*r),this.opacity)}})),e(G,H,r(n,{brighter:function(t){return new G(this.h,this.c,this.l+18*(null==t?1:t),this.opacity)},darker:function(t){return new G(this.h,this.c,this.l-18*(null==t?1:t),this.opacity)},rgb:function(){return R(this).rgb()}}));var Y=-.14861,W=1.78277,X=-.29227,Z=-.90649,J=1.97294,K=J*Z,$=J*W,Q=W*X-Z*Y;function tt(t,e,r,n){return 1===arguments.length?function(t){if(t instanceof et)return new et(t.h,t.s,t.l,t.opacity);t instanceof _||(t=x(t));var e=t.r/255,r=t.g/255,n=t.b/255,i=(Q*n+K*e-$*r)/(Q+K-$),a=n-i,o=(J*(r-i)-X*a)/Z,s=Math.sqrt(o*o+a*a)/(J*i*(1-i)),l=s?Math.atan2(o,a)*E-120:NaN;return new et(l<0?l+360:l,s,i,t.opacity)}(t):new et(t,e,r,null==n?1:n)}function et(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}e(et,tt,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new et(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new et(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=isNaN(this.h)?0:(this.h+120)*S,e=+this.l,r=isNaN(this.s)?0:this.s*e*(1-e),n=Math.cos(t),i=Math.sin(t);return new _(255*(e+r*(Y*n+W*i)),255*(e+r*(X*n+Z*i)),255*(e+r*(J*n)),this.opacity)}})),t.color=v,t.rgb=b,t.hsl=T,t.lab=F,t.hcl=H,t.lch=function(t,e,r,n){return 1===arguments.length?q(t):new G(r,e,t,null==n?1:n)},t.gray=function(t,e){return new B(t,0,0,null==e?1:e)},t.cubehelix=tt,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],155:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e={value:function(){}};function r(){for(var t,e=0,r=arguments.length,i={};e<r;++e){if(!(t=arguments[e]+\"\")||t in i)throw new Error(\"illegal type: \"+t);i[t]=[]}return new n(i)}function n(t){this._=t}function i(t,e){for(var r,n=0,i=t.length;n<i;++n)if((r=t[n]).name===e)return r.value}function a(t,r,n){for(var i=0,a=t.length;i<a;++i)if(t[i].name===r){t[i]=e,t=t.slice(0,i).concat(t.slice(i+1));break}return null!=n&&t.push({name:r,value:n}),t}n.prototype=r.prototype={constructor:n,on:function(t,e){var r,n,o=this._,s=(n=o,(t+\"\").trim().split(/^|\\s+/).map(function(t){var e=\"\",r=t.indexOf(\".\");if(r>=0&&(e=t.slice(r+1),t=t.slice(0,r)),t&&!n.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);return{type:t,name:e}})),l=-1,c=s.length;if(!(arguments.length<2)){if(null!=e&&\"function\"!=typeof e)throw new Error(\"invalid callback: \"+e);for(;++l<c;)if(r=(t=s[l]).type)o[r]=a(o[r],t.name,e);else if(null==e)for(r in o)o[r]=a(o[r],t.name,null);return this}for(;++l<c;)if((r=(t=s[l]).type)&&(r=i(o[r],t.name)))return r},copy:function(){var t={},e=this._;for(var r in e)t[r]=e[r].slice();return new n(t)},call:function(t,e){if((r=arguments.length-2)>0)for(var r,n,i=new Array(r),a=0;a<r;++a)i[a]=arguments[a+2];if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(a=0,r=(n=this._[t]).length;a<r;++a)n[a].value.apply(e,i)},apply:function(t,e,r){if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(var n=this._[t],i=0,a=n.length;i<a;++i)n[i].value.apply(e,r)}},t.dispatch=r,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],156:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n,i){\"use strict\";var a=function(t){return function(){return t}},o=function(){return 1e-6*(Math.random()-.5)};function s(t){return t.x+t.vx}function l(t){return t.y+t.vy}function c(t){return t.index}function u(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function h(t){return t.x}function f(t){return t.y}var p=10,d=Math.PI*(3-Math.sqrt(5));t.forceCenter=function(t,e){var r;function n(){var n,i,a=r.length,o=0,s=0;for(n=0;n<a;++n)o+=(i=r[n]).x,s+=i.y;for(o=o/a-t,s=s/a-e,n=0;n<a;++n)(i=r[n]).x-=o,i.y-=s}return null==t&&(t=0),null==e&&(e=0),n.initialize=function(t){r=t},n.x=function(e){return arguments.length?(t=+e,n):t},n.y=function(t){return arguments.length?(e=+t,n):e},n},t.forceCollide=function(t){var r,n,i=1,c=1;function u(){for(var t,a,u,f,p,d,g,v=r.length,m=0;m<c;++m)for(a=e.quadtree(r,s,l).visitAfter(h),t=0;t<v;++t)u=r[t],d=n[u.index],g=d*d,f=u.x+u.vx,p=u.y+u.vy,a.visit(y);function y(t,e,r,n,a){var s=t.data,l=t.r,c=d+l;if(!s)return e>f+c||n<f-c||r>p+c||a<p-c;if(s.index>u.index){var h=f-s.x-s.vx,v=p-s.y-s.vy,m=h*h+v*v;m<c*c&&(0===h&&(m+=(h=o())*h),0===v&&(m+=(v=o())*v),m=(c-(m=Math.sqrt(m)))/m*i,u.vx+=(h*=m)*(c=(l*=l)/(g+l)),u.vy+=(v*=m)*c,s.vx-=h*(c=1-c),s.vy-=v*c)}}}function h(t){if(t.data)return t.r=n[t.data.index];for(var e=t.r=0;e<4;++e)t[e]&&t[e].r>t.r&&(t.r=t[e].r)}function f(){if(r){var e,i,a=r.length;for(n=new Array(a),e=0;e<a;++e)i=r[e],n[i.index]=+t(i,e,r)}}return\"function\"!=typeof t&&(t=a(null==t?1:+t)),u.initialize=function(t){r=t,f()},u.iterations=function(t){return arguments.length?(c=+t,u):c},u.strength=function(t){return arguments.length?(i=+t,u):i},u.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),f(),u):t},u},t.forceLink=function(t){var e,n,i,s,l,h=c,f=function(t){return 1/Math.min(s[t.source.index],s[t.target.index])},p=a(30),d=1;function g(r){for(var i=0,a=t.length;i<d;++i)for(var s,c,u,h,f,p,g,v=0;v<a;++v)c=(s=t[v]).source,h=(u=s.target).x+u.vx-c.x-c.vx||o(),f=u.y+u.vy-c.y-c.vy||o(),h*=p=((p=Math.sqrt(h*h+f*f))-n[v])/p*r*e[v],f*=p,u.vx-=h*(g=l[v]),u.vy-=f*g,c.vx+=h*(g=1-g),c.vy+=f*g}function v(){if(i){var a,o,c=i.length,f=t.length,p=r.map(i,h);for(a=0,s=new Array(c);a<f;++a)(o=t[a]).index=a,\"object\"!=typeof o.source&&(o.source=u(p,o.source)),\"object\"!=typeof o.target&&(o.target=u(p,o.target)),s[o.source.index]=(s[o.source.index]||0)+1,s[o.target.index]=(s[o.target.index]||0)+1;for(a=0,l=new Array(f);a<f;++a)o=t[a],l[a]=s[o.source.index]/(s[o.source.index]+s[o.target.index]);e=new Array(f),m(),n=new Array(f),y()}}function m(){if(i)for(var r=0,n=t.length;r<n;++r)e[r]=+f(t[r],r,t)}function y(){if(i)for(var e=0,r=t.length;e<r;++e)n[e]=+p(t[e],e,t)}return null==t&&(t=[]),g.initialize=function(t){i=t,v()},g.links=function(e){return arguments.length?(t=e,v(),g):t},g.id=function(t){return arguments.length?(h=t,g):h},g.iterations=function(t){return arguments.length?(d=+t,g):d},g.strength=function(t){return arguments.length?(f=\"function\"==typeof t?t:a(+t),m(),g):f},g.distance=function(t){return arguments.length?(p=\"function\"==typeof t?t:a(+t),y(),g):p},g},t.forceManyBody=function(){var t,r,n,i,s=a(-30),l=1,c=1/0,u=.81;function p(i){var a,o=t.length,s=e.quadtree(t,h,f).visitAfter(g);for(n=i,a=0;a<o;++a)r=t[a],s.visit(v)}function d(){if(t){var e,r,n=t.length;for(i=new Array(n),e=0;e<n;++e)r=t[e],i[r.index]=+s(r,e,t)}}function g(t){var e,r,n,a,o,s=0,l=0;if(t.length){for(n=a=o=0;o<4;++o)(e=t[o])&&(r=Math.abs(e.value))&&(s+=e.value,l+=r,n+=r*e.x,a+=r*e.y);t.x=n/l,t.y=a/l}else{(e=t).x=e.data.x,e.y=e.data.y;do{s+=i[e.data.index]}while(e=e.next)}t.value=s}function v(t,e,a,s){if(!t.value)return!0;var h=t.x-r.x,f=t.y-r.y,p=s-e,d=h*h+f*f;if(p*p/u<d)return d<c&&(0===h&&(d+=(h=o())*h),0===f&&(d+=(f=o())*f),d<l&&(d=Math.sqrt(l*d)),r.vx+=h*t.value*n/d,r.vy+=f*t.value*n/d),!0;if(!(t.length||d>=c)){(t.data!==r||t.next)&&(0===h&&(d+=(h=o())*h),0===f&&(d+=(f=o())*f),d<l&&(d=Math.sqrt(l*d)));do{t.data!==r&&(p=i[t.data.index]*n/d,r.vx+=h*p,r.vy+=f*p)}while(t=t.next)}}return p.initialize=function(e){t=e,d()},p.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),d(),p):s},p.distanceMin=function(t){return arguments.length?(l=t*t,p):Math.sqrt(l)},p.distanceMax=function(t){return arguments.length?(c=t*t,p):Math.sqrt(c)},p.theta=function(t){return arguments.length?(u=t*t,p):Math.sqrt(u)},p},t.forceRadial=function(t,e,r){var n,i,o,s=a(.1);function l(t){for(var a=0,s=n.length;a<s;++a){var l=n[a],c=l.x-e||1e-6,u=l.y-r||1e-6,h=Math.sqrt(c*c+u*u),f=(o[a]-h)*i[a]*t/h;l.vx+=c*f,l.vy+=u*f}}function c(){if(n){var e,r=n.length;for(i=new Array(r),o=new Array(r),e=0;e<r;++e)o[e]=+t(n[e],e,n),i[e]=isNaN(o[e])?0:+s(n[e],e,n)}}return\"function\"!=typeof t&&(t=a(+t)),null==e&&(e=0),null==r&&(r=0),l.initialize=function(t){n=t,c()},l.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),c(),l):s},l.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),c(),l):t},l.x=function(t){return arguments.length?(e=+t,l):e},l.y=function(t){return arguments.length?(r=+t,l):r},l},t.forceSimulation=function(t){var e,a=1,o=.001,s=1-Math.pow(o,1/300),l=0,c=.6,u=r.map(),h=i.timer(g),f=n.dispatch(\"tick\",\"end\");function g(){v(),f.call(\"tick\",e),a<o&&(h.stop(),f.call(\"end\",e))}function v(){var e,r,n=t.length;for(a+=(l-a)*s,u.each(function(t){t(a)}),e=0;e<n;++e)null==(r=t[e]).fx?r.x+=r.vx*=c:(r.x=r.fx,r.vx=0),null==r.fy?r.y+=r.vy*=c:(r.y=r.fy,r.vy=0)}function m(){for(var e,r=0,n=t.length;r<n;++r){if((e=t[r]).index=r,isNaN(e.x)||isNaN(e.y)){var i=p*Math.sqrt(r),a=r*d;e.x=i*Math.cos(a),e.y=i*Math.sin(a)}(isNaN(e.vx)||isNaN(e.vy))&&(e.vx=e.vy=0)}}function y(e){return e.initialize&&e.initialize(t),e}return null==t&&(t=[]),m(),e={tick:v,restart:function(){return h.restart(g),e},stop:function(){return h.stop(),e},nodes:function(r){return arguments.length?(t=r,m(),u.each(y),e):t},alpha:function(t){return arguments.length?(a=+t,e):a},alphaMin:function(t){return arguments.length?(o=+t,e):o},alphaDecay:function(t){return arguments.length?(s=+t,e):+s},alphaTarget:function(t){return arguments.length?(l=+t,e):l},velocityDecay:function(t){return arguments.length?(c=1-t,e):1-c},force:function(t,r){return arguments.length>1?(null==r?u.remove(t):u.set(t,y(r)),e):u.get(t)},find:function(e,r,n){var i,a,o,s,l,c=0,u=t.length;for(null==n?n=1/0:n*=n,c=0;c<u;++c)(o=(i=e-(s=t[c]).x)*i+(a=r-s.y)*a)<n&&(l=s,n=o);return l},on:function(t,r){return arguments.length>1?(f.on(t,r),e):f.on(t)}}},t.forceX=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vx+=(n[a]-i.x)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},t.forceY=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vy+=(n[a]-i.y)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.y=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-quadtree\"),t(\"d3-collection\"),t(\"d3-dispatch\"),t(\"d3-timer\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,n.d3)},{\"d3-collection\":153,\"d3-dispatch\":155,\"d3-quadtree\":160,\"d3-timer\":162}],157:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e){return t.parent===e.parent?1:2}function r(t,e){return t+e.x}function n(t,e){return Math.max(t,e.y)}function i(t){var e=0,r=t.children,n=r&&r.length;if(n)for(;--n>=0;)e+=r[n].value;else e=1;t.value=e}function a(t,e){var r,n,i,a,s,u=new c(t),h=+t.value&&(u.value=t.value),f=[u];for(null==e&&(e=o);r=f.pop();)if(h&&(r.value=+r.data.value),(i=e(r.data))&&(s=i.length))for(r.children=new Array(s),a=s-1;a>=0;--a)f.push(n=r.children[a]=new c(i[a])),n.parent=r,n.depth=r.depth+1;return u.eachBefore(l)}function o(t){return t.children}function s(t){t.data=t.data.data}function l(t){var e=0;do{t.height=e}while((t=t.parent)&&t.height<++e)}function c(t){this.data=t,this.depth=this.height=0,this.parent=null}c.prototype=a.prototype={constructor:c,count:function(){return this.eachAfter(i)},each:function(t){var e,r,n,i,a=this,o=[a];do{for(e=o.reverse(),o=[];a=e.pop();)if(t(a),r=a.children)for(n=0,i=r.length;n<i;++n)o.push(r[n])}while(o.length);return this},eachAfter:function(t){for(var e,r,n,i=this,a=[i],o=[];i=a.pop();)if(o.push(i),e=i.children)for(r=0,n=e.length;r<n;++r)a.push(e[r]);for(;i=o.pop();)t(i);return this},eachBefore:function(t){for(var e,r,n=this,i=[n];n=i.pop();)if(t(n),e=n.children)for(r=e.length-1;r>=0;--r)i.push(e[r]);return this},sum:function(t){return this.eachAfter(function(e){for(var r=+t(e.data)||0,n=e.children,i=n&&n.length;--i>=0;)r+=n[i].value;e.value=r})},sort:function(t){return this.eachBefore(function(e){e.children&&e.children.sort(t)})},path:function(t){for(var e=this,r=function(t,e){if(t===e)return t;var r=t.ancestors(),n=e.ancestors(),i=null;for(t=r.pop(),e=n.pop();t===e;)i=t,t=r.pop(),e=n.pop();return i}(e,t),n=[e];e!==r;)e=e.parent,n.push(e);for(var i=n.length;t!==r;)n.splice(i,0,t),t=t.parent;return n},ancestors:function(){for(var t=this,e=[t];t=t.parent;)e.push(t);return e},descendants:function(){var t=[];return this.each(function(e){t.push(e)}),t},leaves:function(){var t=[];return this.eachBefore(function(e){e.children||t.push(e)}),t},links:function(){var t=this,e=[];return t.each(function(r){r!==t&&e.push({source:r.parent,target:r})}),e},copy:function(){return a(this).eachBefore(s)}};var u=Array.prototype.slice;function h(t){for(var e,r,n=0,i=(t=function(t){for(var e,r,n=t.length;n;)r=Math.random()*n--|0,e=t[n],t[n]=t[r],t[r]=e;return t}(u.call(t))).length,a=[];n<i;)e=t[n],r&&d(r,e)?++n:(r=v(a=f(a,e)),n=0);return r}function f(t,e){var r,n;if(g(e,t))return[e];for(r=0;r<t.length;++r)if(p(e,t[r])&&g(m(t[r],e),t))return[t[r],e];for(r=0;r<t.length-1;++r)for(n=r+1;n<t.length;++n)if(p(m(t[r],t[n]),e)&&p(m(t[r],e),t[n])&&p(m(t[n],e),t[r])&&g(y(t[r],t[n],e),t))return[t[r],t[n],e];throw new Error}function p(t,e){var r=t.r-e.r,n=e.x-t.x,i=e.y-t.y;return r<0||r*r<n*n+i*i}function d(t,e){var r=t.r-e.r+1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function g(t,e){for(var r=0;r<e.length;++r)if(!d(t,e[r]))return!1;return!0}function v(t){switch(t.length){case 1:return{x:(e=t[0]).x,y:e.y,r:e.r};case 2:return m(t[0],t[1]);case 3:return y(t[0],t[1],t[2])}var e}function m(t,e){var r=t.x,n=t.y,i=t.r,a=e.x,o=e.y,s=e.r,l=a-r,c=o-n,u=s-i,h=Math.sqrt(l*l+c*c);return{x:(r+a+l/h*u)/2,y:(n+o+c/h*u)/2,r:(h+i+s)/2}}function y(t,e,r){var n=t.x,i=t.y,a=t.r,o=e.x,s=e.y,l=e.r,c=r.x,u=r.y,h=r.r,f=n-o,p=n-c,d=i-s,g=i-u,v=l-a,m=h-a,y=n*n+i*i-a*a,x=y-o*o-s*s+l*l,b=y-c*c-u*u+h*h,_=p*d-f*g,w=(d*b-g*x)/(2*_)-n,k=(g*v-d*m)/_,T=(p*x-f*b)/(2*_)-i,A=(f*m-p*v)/_,M=k*k+A*A-1,S=2*(a+w*k+T*A),E=w*w+T*T-a*a,C=-(M?(S+Math.sqrt(S*S-4*M*E))/(2*M):E/S);return{x:n+w+k*C,y:i+T+A*C,r:C}}function x(t,e,r){var n,i,a,o,s=t.x-e.x,l=t.y-e.y,c=s*s+l*l;c?(i=e.r+r.r,i*=i,o=t.r+r.r,i>(o*=o)?(n=(c+o-i)/(2*c),a=Math.sqrt(Math.max(0,o/c-n*n)),r.x=t.x-n*s-a*l,r.y=t.y-n*l+a*s):(n=(c+i-o)/(2*c),a=Math.sqrt(Math.max(0,i/c-n*n)),r.x=e.x+n*s-a*l,r.y=e.y+n*l+a*s)):(r.x=e.x+r.r,r.y=e.y)}function b(t,e){var r=t.r+e.r-1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function _(t){var e=t._,r=t.next._,n=e.r+r.r,i=(e.x*r.r+r.x*e.r)/n,a=(e.y*r.r+r.y*e.r)/n;return i*i+a*a}function w(t){this._=t,this.next=null,this.previous=null}function k(t){if(!(i=t.length))return 0;var e,r,n,i,a,o,s,l,c,u,f;if((e=t[0]).x=0,e.y=0,!(i>1))return e.r;if(r=t[1],e.x=-r.r,r.x=e.r,r.y=0,!(i>2))return e.r+r.r;x(r,e,n=t[2]),e=new w(e),r=new w(r),n=new w(n),e.next=n.previous=r,r.next=e.previous=n,n.next=r.previous=e;t:for(s=3;s<i;++s){x(e._,r._,n=t[s]),n=new w(n),l=r.next,c=e.previous,u=r._.r,f=e._.r;do{if(u<=f){if(b(l._,n._)){r=l,e.next=r,r.previous=e,--s;continue t}u+=l._.r,l=l.next}else{if(b(c._,n._)){(e=c).next=r,r.previous=e,--s;continue t}f+=c._.r,c=c.previous}}while(l!==c.next);for(n.previous=e,n.next=r,e.next=r.previous=r=n,a=_(e);(n=n.next)!==r;)(o=_(n))<a&&(e=n,a=o);r=e.next}for(e=[r._],n=r;(n=n.next)!==r;)e.push(n._);for(n=h(e),s=0;s<i;++s)(e=t[s]).x-=n.x,e.y-=n.y;return n.r}function T(t){if(\"function\"!=typeof t)throw new Error;return t}function A(){return 0}function M(t){return function(){return t}}function S(t){return Math.sqrt(t.value)}function E(t){return function(e){e.children||(e.r=Math.max(0,+t(e)||0))}}function C(t,e){return function(r){if(n=r.children){var n,i,a,o=n.length,s=t(r)*e||0;if(s)for(i=0;i<o;++i)n[i].r+=s;if(a=k(n),s)for(i=0;i<o;++i)n[i].r-=s;r.r=a+s}}}function L(t){return function(e){var r=e.parent;e.r*=t,r&&(e.x=r.x+t*e.x,e.y=r.y+t*e.y)}}function P(t){t.x0=Math.round(t.x0),t.y0=Math.round(t.y0),t.x1=Math.round(t.x1),t.y1=Math.round(t.y1)}function O(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(n-e)/t.value;++s<l;)(a=o[s]).y0=r,a.y1=i,a.x0=e,a.x1=e+=a.value*c}var z=\"$\",I={depth:-1},D={};function R(t){return t.id}function F(t){return t.parentId}function B(t,e){return t.parent===e.parent?1:2}function N(t){var e=t.children;return e?e[0]:t.t}function j(t){var e=t.children;return e?e[e.length-1]:t.t}function U(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function V(t,e,r){return t.a.parent===e.parent?t.a:r}function q(t,e){this._=t,this.parent=null,this.children=null,this.A=null,this.a=this,this.z=0,this.m=0,this.c=0,this.s=0,this.t=null,this.i=e}function H(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(i-r)/t.value;++s<l;)(a=o[s]).x0=e,a.x1=n,a.y0=r,a.y1=r+=a.value*c}q.prototype=Object.create(c.prototype);var G=(1+Math.sqrt(5))/2;function Y(t,e,r,n,i,a){for(var o,s,l,c,u,h,f,p,d,g,v,m=[],y=e.children,x=0,b=0,_=y.length,w=e.value;x<_;){l=i-r,c=a-n;do{u=y[b++].value}while(!u&&b<_);for(h=f=u,v=u*u*(g=Math.max(c/l,l/c)/(w*t)),d=Math.max(f/v,v/h);b<_;++b){if(u+=s=y[b].value,s<h&&(h=s),s>f&&(f=s),v=u*u*g,(p=Math.max(f/v,v/h))>d){u-=s;break}d=p}m.push(o={value:u,dice:l<c,children:y.slice(x,b)}),o.dice?O(o,r,n,i,w?n+=c*u/w:a):H(o,r,n,w?r+=l*u/w:i,a),w-=u,x=b}return m}var W=function t(e){function r(t,r,n,i,a){Y(e,t,r,n,i,a)}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);var X=function t(e){function r(t,r,n,i,a){if((o=t._squarify)&&o.ratio===e)for(var o,s,l,c,u,h=-1,f=o.length,p=t.value;++h<f;){for(l=(s=o[h]).children,c=s.value=0,u=l.length;c<u;++c)s.value+=l[c].value;s.dice?O(s,r,n,i,n+=(a-n)*s.value/p):H(s,r,n,r+=(i-r)*s.value/p,a),p-=s.value}else t._squarify=o=Y(e,t,r,n,i,a),o.ratio=e}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);t.cluster=function(){var t=e,i=1,a=1,o=!1;function s(e){var s,l=0;e.eachAfter(function(e){var i=e.children;i?(e.x=function(t){return t.reduce(r,0)/t.length}(i),e.y=function(t){return 1+t.reduce(n,0)}(i)):(e.x=s?l+=t(e,s):0,e.y=0,s=e)});var c=function(t){for(var e;e=t.children;)t=e[0];return t}(e),u=function(t){for(var e;e=t.children;)t=e[e.length-1];return t}(e),h=c.x-t(c,u)/2,f=u.x+t(u,c)/2;return e.eachAfter(o?function(t){t.x=(t.x-e.x)*i,t.y=(e.y-t.y)*a}:function(t){t.x=(t.x-h)/(f-h)*i,t.y=(1-(e.y?t.y/e.y:1))*a})}return s.separation=function(e){return arguments.length?(t=e,s):t},s.size=function(t){return arguments.length?(o=!1,i=+t[0],a=+t[1],s):o?null:[i,a]},s.nodeSize=function(t){return arguments.length?(o=!0,i=+t[0],a=+t[1],s):o?[i,a]:null},s},t.hierarchy=a,t.pack=function(){var t=null,e=1,r=1,n=A;function i(i){return i.x=e/2,i.y=r/2,t?i.eachBefore(E(t)).eachAfter(C(n,.5)).eachBefore(L(1)):i.eachBefore(E(S)).eachAfter(C(A,1)).eachAfter(C(n,i.r/Math.min(e,r))).eachBefore(L(Math.min(e,r)/(2*i.r))),i}return i.radius=function(e){return arguments.length?(t=null==(r=e)?null:T(r),i):t;var r},i.size=function(t){return arguments.length?(e=+t[0],r=+t[1],i):[e,r]},i.padding=function(t){return arguments.length?(n=\"function\"==typeof t?t:M(+t),i):n},i},t.packSiblings=function(t){return k(t),t},t.packEnclose=h,t.partition=function(){var t=1,e=1,r=0,n=!1;function i(i){var a=i.height+1;return i.x0=i.y0=r,i.x1=t,i.y1=e/a,i.eachBefore(function(t,e){return function(n){n.children&&O(n,n.x0,t*(n.depth+1)/e,n.x1,t*(n.depth+2)/e);var i=n.x0,a=n.y0,o=n.x1-r,s=n.y1-r;o<i&&(i=o=(i+o)/2),s<a&&(a=s=(a+s)/2),n.x0=i,n.y0=a,n.x1=o,n.y1=s}}(e,a)),n&&i.eachBefore(P),i}return i.round=function(t){return arguments.length?(n=!!t,i):n},i.size=function(r){return arguments.length?(t=+r[0],e=+r[1],i):[t,e]},i.padding=function(t){return arguments.length?(r=+t,i):r},i},t.stratify=function(){var t=R,e=F;function r(r){var n,i,a,o,s,u,h,f=r.length,p=new Array(f),d={};for(i=0;i<f;++i)n=r[i],s=p[i]=new c(n),null!=(u=t(n,i,r))&&(u+=\"\")&&(d[h=z+(s.id=u)]=h in d?D:s);for(i=0;i<f;++i)if(s=p[i],null!=(u=e(r[i],i,r))&&(u+=\"\")){if(!(o=d[z+u]))throw new Error(\"missing: \"+u);if(o===D)throw new Error(\"ambiguous: \"+u);o.children?o.children.push(s):o.children=[s],s.parent=o}else{if(a)throw new Error(\"multiple roots\");a=s}if(!a)throw new Error(\"no root\");if(a.parent=I,a.eachBefore(function(t){t.depth=t.parent.depth+1,--f}).eachBefore(l),a.parent=null,f>0)throw new Error(\"cycle\");return a}return r.id=function(e){return arguments.length?(t=T(e),r):t},r.parentId=function(t){return arguments.length?(e=T(t),r):e},r},t.tree=function(){var t=B,e=1,r=1,n=null;function i(i){var l=function(t){for(var e,r,n,i,a,o=new q(t,0),s=[o];e=s.pop();)if(n=e._.children)for(e.children=new Array(a=n.length),i=a-1;i>=0;--i)s.push(r=e.children[i]=new q(n[i],i)),r.parent=e;return(o.parent=new q(null,0)).children=[o],o}(i);if(l.eachAfter(a),l.parent.m=-l.z,l.eachBefore(o),n)i.eachBefore(s);else{var c=i,u=i,h=i;i.eachBefore(function(t){t.x<c.x&&(c=t),t.x>u.x&&(u=t),t.depth>h.depth&&(h=t)});var f=c===u?1:t(c,u)/2,p=f-c.x,d=e/(u.x+f+p),g=r/(h.depth||1);i.eachBefore(function(t){t.x=(t.x+p)*d,t.y=t.depth*g})}return i}function a(e){var r=e.children,n=e.parent.children,i=e.i?n[e.i-1]:null;if(r){!function(t){for(var e,r=0,n=0,i=t.children,a=i.length;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(e);var a=(r[0].z+r[r.length-1].z)/2;i?(e.z=i.z+t(e._,i._),e.m=e.z-a):e.z=a}else i&&(e.z=i.z+t(e._,i._));e.parent.A=function(e,r,n){if(r){for(var i,a=e,o=e,s=r,l=a.parent.children[0],c=a.m,u=o.m,h=s.m,f=l.m;s=j(s),a=N(a),s&&a;)l=N(l),(o=j(o)).a=e,(i=s.z+h-a.z-c+t(s._,a._))>0&&(U(V(s,e,n),e,i),c+=i,u+=i),h+=s.m,c+=a.m,f+=l.m,u+=o.m;s&&!j(o)&&(o.t=s,o.m+=h-u),a&&!N(l)&&(l.t=a,l.m+=c-f,n=e)}return n}(e,i,e.parent.A||n[0])}function o(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function s(t){t.x*=e,t.y=t.depth*r}return i.separation=function(e){return arguments.length?(t=e,i):t},i.size=function(t){return arguments.length?(n=!1,e=+t[0],r=+t[1],i):n?null:[e,r]},i.nodeSize=function(t){return arguments.length?(n=!0,e=+t[0],r=+t[1],i):n?[e,r]:null},i},t.treemap=function(){var t=W,e=!1,r=1,n=1,i=[0],a=A,o=A,s=A,l=A,c=A;function u(t){return t.x0=t.y0=0,t.x1=r,t.y1=n,t.eachBefore(h),i=[0],e&&t.eachBefore(P),t}function h(e){var r=i[e.depth],n=e.x0+r,u=e.y0+r,h=e.x1-r,f=e.y1-r;h<n&&(n=h=(n+h)/2),f<u&&(u=f=(u+f)/2),e.x0=n,e.y0=u,e.x1=h,e.y1=f,e.children&&(r=i[e.depth+1]=a(e)/2,n+=c(e)-r,u+=o(e)-r,(h-=s(e)-r)<n&&(n=h=(n+h)/2),(f-=l(e)-r)<u&&(u=f=(u+f)/2),t(e,n,u,h,f))}return u.round=function(t){return arguments.length?(e=!!t,u):e},u.size=function(t){return arguments.length?(r=+t[0],n=+t[1],u):[r,n]},u.tile=function(e){return arguments.length?(t=T(e),u):t},u.padding=function(t){return arguments.length?u.paddingInner(t).paddingOuter(t):u.paddingInner()},u.paddingInner=function(t){return arguments.length?(a=\"function\"==typeof t?t:M(+t),u):a},u.paddingOuter=function(t){return arguments.length?u.paddingTop(t).paddingRight(t).paddingBottom(t).paddingLeft(t):u.paddingTop()},u.paddingTop=function(t){return arguments.length?(o=\"function\"==typeof t?t:M(+t),u):o},u.paddingRight=function(t){return arguments.length?(s=\"function\"==typeof t?t:M(+t),u):s},u.paddingBottom=function(t){return arguments.length?(l=\"function\"==typeof t?t:M(+t),u):l},u.paddingLeft=function(t){return arguments.length?(c=\"function\"==typeof t?t:M(+t),u):c},u},t.treemapBinary=function(t,e,r,n,i){var a,o,s=t.children,l=s.length,c=new Array(l+1);for(c[0]=o=a=0;a<l;++a)c[a+1]=o+=s[a].value;!function t(e,r,n,i,a,o,l){if(e>=r-1){var u=s[e];return u.x0=i,u.y0=a,u.x1=o,void(u.y1=l)}for(var h=c[e],f=n/2+h,p=e+1,d=r-1;p<d;){var g=p+d>>>1;c[g]<f?p=g+1:d=g}f-c[p-1]<c[p]-f&&e+1<p&&--p;var v=c[p]-h,m=n-v;if(o-i>l-a){var y=(i*m+o*v)/n;t(e,p,v,i,a,y,l),t(p,r,m,y,a,o,l)}else{var x=(a*m+l*v)/n;t(e,p,v,i,a,o,x),t(p,r,m,i,x,o,l)}}(0,l,t.value,e,r,n,i)},t.treemapDice=O,t.treemapSlice=H,t.treemapSliceDice=function(t,e,r,n,i){(1&t.depth?H:O)(t,e,r,n,i)},t.treemapSquarify=W,t.treemapResquarify=X,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],158:[function(t,e,r){var n,i;n=this,i=function(t,e){\"use strict\";function r(t,e,r,n,i){var a=t*t,o=a*t;return((1-3*t+3*a-o)*e+(4-6*a+3*o)*r+(1+3*t+3*a-3*o)*n+o*i)/6}function n(t){var e=t.length-1;return function(n){var i=n<=0?n=0:n>=1?(n=1,e-1):Math.floor(n*e),a=t[i],o=t[i+1],s=i>0?t[i-1]:2*a-o,l=i<e-1?t[i+2]:2*o-a;return r((n-i/e)*e,s,a,o,l)}}function i(t){var e=t.length;return function(n){var i=Math.floor(((n%=1)<0?++n:n)*e),a=t[(i+e-1)%e],o=t[i%e],s=t[(i+1)%e],l=t[(i+2)%e];return r((n-i/e)*e,a,o,s,l)}}function a(t){return function(){return t}}function o(t,e){return function(r){return t+r*e}}function s(t,e){var r=e-t;return r?o(t,r>180||r<-180?r-360*Math.round(r/360):r):a(isNaN(t)?e:t)}function l(t){return 1==(t=+t)?c:function(e,r){return r-e?function(t,e,r){return t=Math.pow(t,r),e=Math.pow(e,r)-t,r=1/r,function(n){return Math.pow(t+n*e,r)}}(e,r,t):a(isNaN(e)?r:e)}}function c(t,e){var r=e-t;return r?o(t,r):a(isNaN(t)?e:t)}var u=function t(r){var n=l(r);function i(t,r){var i=n((t=e.rgb(t)).r,(r=e.rgb(r)).r),a=n(t.g,r.g),o=n(t.b,r.b),s=c(t.opacity,r.opacity);return function(e){return t.r=i(e),t.g=a(e),t.b=o(e),t.opacity=s(e),t+\"\"}}return i.gamma=t,i}(1);function h(t){return function(r){var n,i,a=r.length,o=new Array(a),s=new Array(a),l=new Array(a);for(n=0;n<a;++n)i=e.rgb(r[n]),o[n]=i.r||0,s[n]=i.g||0,l[n]=i.b||0;return o=t(o),s=t(s),l=t(l),i.opacity=1,function(t){return i.r=o(t),i.g=s(t),i.b=l(t),i+\"\"}}}var f=h(n),p=h(i);function d(t,e){var r,n=e?e.length:0,i=t?Math.min(n,t.length):0,a=new Array(i),o=new Array(n);for(r=0;r<i;++r)a[r]=_(t[r],e[r]);for(;r<n;++r)o[r]=e[r];return function(t){for(r=0;r<i;++r)o[r]=a[r](t);return o}}function g(t,e){var r=new Date;return e-=t=+t,function(n){return r.setTime(t+e*n),r}}function v(t,e){return e-=t=+t,function(r){return t+e*r}}function m(t,e){var r,n={},i={};for(r in null!==t&&\"object\"==typeof t||(t={}),null!==e&&\"object\"==typeof e||(e={}),e)r in t?n[r]=_(t[r],e[r]):i[r]=e[r];return function(t){for(r in n)i[r]=n[r](t);return i}}var y=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,x=new RegExp(y.source,\"g\");function b(t,e){var r,n,i,a=y.lastIndex=x.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=y.exec(t))&&(n=x.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:v(r,n)})),a=x.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?function(t){return function(e){return t(e)+\"\"}}(l[0].x):function(t){return function(){return t}}(e):(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}function _(t,r){var n,i=typeof r;return null==r||\"boolean\"===i?a(r):(\"number\"===i?v:\"string\"===i?(n=e.color(r))?(r=n,u):b:r instanceof e.color?u:r instanceof Date?g:Array.isArray(r)?d:\"function\"!=typeof r.valueOf&&\"function\"!=typeof r.toString||isNaN(r)?m:v)(t,r)}var w,k,T,A,M=180/Math.PI,S={translateX:0,translateY:0,rotate:0,skewX:0,scaleX:1,scaleY:1};function E(t,e,r,n,i,a){var o,s,l;return(o=Math.sqrt(t*t+e*e))&&(t/=o,e/=o),(l=t*r+e*n)&&(r-=t*l,n-=e*l),(s=Math.sqrt(r*r+n*n))&&(r/=s,n/=s,l/=s),t*n<e*r&&(t=-t,e=-e,l=-l,o=-o),{translateX:i,translateY:a,rotate:Math.atan2(e,t)*M,skewX:Math.atan(l)*M,scaleX:o,scaleY:s}}function C(t,e,r,n){function i(t){return t.length?t.pop()+\" \":\"\"}return function(a,o){var s=[],l=[];return a=t(a),o=t(o),function(t,n,i,a,o,s){if(t!==i||n!==a){var l=o.push(\"translate(\",null,e,null,r);s.push({i:l-4,x:v(t,i)},{i:l-2,x:v(n,a)})}else(i||a)&&o.push(\"translate(\"+i+e+a+r)}(a.translateX,a.translateY,o.translateX,o.translateY,s,l),function(t,e,r,a){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),a.push({i:r.push(i(r)+\"rotate(\",null,n)-2,x:v(t,e)})):e&&r.push(i(r)+\"rotate(\"+e+n)}(a.rotate,o.rotate,s,l),function(t,e,r,a){t!==e?a.push({i:r.push(i(r)+\"skewX(\",null,n)-2,x:v(t,e)}):e&&r.push(i(r)+\"skewX(\"+e+n)}(a.skewX,o.skewX,s,l),function(t,e,r,n,a,o){if(t!==r||e!==n){var s=a.push(i(a)+\"scale(\",null,\",\",null,\")\");o.push({i:s-4,x:v(t,r)},{i:s-2,x:v(e,n)})}else 1===r&&1===n||a.push(i(a)+\"scale(\"+r+\",\"+n+\")\")}(a.scaleX,a.scaleY,o.scaleX,o.scaleY,s,l),a=o=null,function(t){for(var e,r=-1,n=l.length;++r<n;)s[(e=l[r]).i]=e.x(t);return s.join(\"\")}}}var L=C(function(t){return\"none\"===t?S:(w||(w=document.createElement(\"DIV\"),k=document.documentElement,T=document.defaultView),w.style.transform=t,t=T.getComputedStyle(k.appendChild(w),null).getPropertyValue(\"transform\"),k.removeChild(w),E(+(t=t.slice(7,-1).split(\",\"))[0],+t[1],+t[2],+t[3],+t[4],+t[5]))},\"px, \",\"px)\",\"deg)\"),P=C(function(t){return null==t?S:(A||(A=document.createElementNS(\"http://www.w3.org/2000/svg\",\"g\")),A.setAttribute(\"transform\",t),(t=A.transform.baseVal.consolidate())?E((t=t.matrix).a,t.b,t.c,t.d,t.e,t.f):S)},\", \",\")\",\")\"),O=Math.SQRT2,z=2,I=4,D=1e-12;function R(t){return((t=Math.exp(t))+1/t)/2}function F(t){return function(r,n){var i=t((r=e.hsl(r)).h,(n=e.hsl(n)).h),a=c(r.s,n.s),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.s=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var B=F(s),N=F(c);function j(t){return function(r,n){var i=t((r=e.hcl(r)).h,(n=e.hcl(n)).h),a=c(r.c,n.c),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.c=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var U=j(s),V=j(c);function q(t){return function r(n){function i(r,i){var a=t((r=e.cubehelix(r)).h,(i=e.cubehelix(i)).h),o=c(r.s,i.s),s=c(r.l,i.l),l=c(r.opacity,i.opacity);return function(t){return r.h=a(t),r.s=o(t),r.l=s(Math.pow(t,n)),r.opacity=l(t),r+\"\"}}return n=+n,i.gamma=r,i}(1)}var H=q(s),G=q(c);t.interpolate=_,t.interpolateArray=d,t.interpolateBasis=n,t.interpolateBasisClosed=i,t.interpolateDate=g,t.interpolateDiscrete=function(t){var e=t.length;return function(r){return t[Math.max(0,Math.min(e-1,Math.floor(r*e)))]}},t.interpolateHue=function(t,e){var r=s(+t,+e);return function(t){var e=r(t);return e-360*Math.floor(e/360)}},t.interpolateNumber=v,t.interpolateObject=m,t.interpolateRound=function(t,e){return e-=t=+t,function(r){return Math.round(t+e*r)}},t.interpolateString=b,t.interpolateTransformCss=L,t.interpolateTransformSvg=P,t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,h=l-a,f=u*u+h*h;if(f<D)n=Math.log(c/o)/O,r=function(t){return[i+t*u,a+t*h,o*Math.exp(O*t*n)]};else{var p=Math.sqrt(f),d=(c*c-o*o+I*f)/(2*o*z*p),g=(c*c-o*o-I*f)/(2*c*z*p),v=Math.log(Math.sqrt(d*d+1)-d),m=Math.log(Math.sqrt(g*g+1)-g);n=(m-v)/O,r=function(t){var e,r=t*n,s=R(v),l=o/(z*p)*(s*(e=O*r+v,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(v));return[i+l*u,a+l*h,o*s/R(O*r+v)]}}return r.duration=1e3*n,r},t.interpolateRgb=u,t.interpolateRgbBasis=f,t.interpolateRgbBasisClosed=p,t.interpolateHsl=B,t.interpolateHslLong=N,t.interpolateLab=function(t,r){var n=c((t=e.lab(t)).l,(r=e.lab(r)).l),i=c(t.a,r.a),a=c(t.b,r.b),o=c(t.opacity,r.opacity);return function(e){return t.l=n(e),t.a=i(e),t.b=a(e),t.opacity=o(e),t+\"\"}},t.interpolateHcl=U,t.interpolateHclLong=V,t.interpolateCubehelix=H,t.interpolateCubehelixLong=G,t.piecewise=function(t,e){for(var r=0,n=e.length-1,i=e[0],a=new Array(n<0?0:n);r<n;)a[r]=t(i,i=e[++r]);return function(t){var e=Math.max(0,Math.min(n-1,Math.floor(t*=n)));return a[e](t-e)}},t.quantize=function(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t(n/(e-1));return r},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-color\")):i(n.d3=n.d3||{},n.d3)},{\"d3-color\":154}],159:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e=Math.PI,r=2*e,n=r-1e-6;function i(){this._x0=this._y0=this._x1=this._y1=null,this._=\"\"}function a(){return new i}i.prototype=a.prototype={constructor:i,moveTo:function(t,e){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)},closePath:function(){null!==this._x1&&(this._x1=this._x0,this._y1=this._y0,this._+=\"Z\")},lineTo:function(t,e){this._+=\"L\"+(this._x1=+t)+\",\"+(this._y1=+e)},quadraticCurveTo:function(t,e,r,n){this._+=\"Q\"+ +t+\",\"+ +e+\",\"+(this._x1=+r)+\",\"+(this._y1=+n)},bezierCurveTo:function(t,e,r,n,i,a){this._+=\"C\"+ +t+\",\"+ +e+\",\"+ +r+\",\"+ +n+\",\"+(this._x1=+i)+\",\"+(this._y1=+a)},arcTo:function(t,r,n,i,a){t=+t,r=+r,n=+n,i=+i,a=+a;var o=this._x1,s=this._y1,l=n-t,c=i-r,u=o-t,h=s-r,f=u*u+h*h;if(a<0)throw new Error(\"negative radius: \"+a);if(null===this._x1)this._+=\"M\"+(this._x1=t)+\",\"+(this._y1=r);else if(f>1e-6)if(Math.abs(h*l-c*u)>1e-6&&a){var p=n-o,d=i-s,g=l*l+c*c,v=p*p+d*d,m=Math.sqrt(g),y=Math.sqrt(f),x=a*Math.tan((e-Math.acos((g+f-v)/(2*m*y)))/2),b=x/y,_=x/m;Math.abs(b-1)>1e-6&&(this._+=\"L\"+(t+b*u)+\",\"+(r+b*h)),this._+=\"A\"+a+\",\"+a+\",0,0,\"+ +(h*p>u*d)+\",\"+(this._x1=t+_*l)+\",\"+(this._y1=r+_*c)}else this._+=\"L\"+(this._x1=t)+\",\"+(this._y1=r);else;},arc:function(t,i,a,o,s,l){t=+t,i=+i;var c=(a=+a)*Math.cos(o),u=a*Math.sin(o),h=t+c,f=i+u,p=1^l,d=l?o-s:s-o;if(a<0)throw new Error(\"negative radius: \"+a);null===this._x1?this._+=\"M\"+h+\",\"+f:(Math.abs(this._x1-h)>1e-6||Math.abs(this._y1-f)>1e-6)&&(this._+=\"L\"+h+\",\"+f),a&&(d<0&&(d=d%r+r),d>n?this._+=\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(t-c)+\",\"+(i-u)+\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(this._x1=h)+\",\"+(this._y1=f):d>1e-6&&(this._+=\"A\"+a+\",\"+a+\",0,\"+ +(d>=e)+\",\"+p+\",\"+(this._x1=t+a*Math.cos(s))+\",\"+(this._y1=i+a*Math.sin(s))))},rect:function(t,e,r,n){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)+\"h\"+ +r+\"v\"+ +n+\"h\"+-r+\"Z\"},toString:function(){return this._}},t.path=a,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],160:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e,r,n){if(isNaN(e)||isNaN(r))return t;var i,a,o,s,l,c,u,h,f,p=t._root,d={data:n},g=t._x0,v=t._y0,m=t._x1,y=t._y1;if(!p)return t._root=d,t;for(;p.length;)if((c=e>=(a=(g+m)/2))?g=a:m=a,(u=r>=(o=(v+y)/2))?v=o:y=o,i=p,!(p=p[h=u<<1|c]))return i[h]=d,t;if(s=+t._x.call(null,p.data),l=+t._y.call(null,p.data),e===s&&r===l)return d.next=p,i?i[h]=d:t._root=d,t;do{i=i?i[h]=new Array(4):t._root=new Array(4),(c=e>=(a=(g+m)/2))?g=a:m=a,(u=r>=(o=(v+y)/2))?v=o:y=o}while((h=u<<1|c)==(f=(l>=o)<<1|s>=a));return i[f]=p,i[h]=d,t}var r=function(t,e,r,n,i){this.node=t,this.x0=e,this.y0=r,this.x1=n,this.y1=i};function n(t){return t[0]}function i(t){return t[1]}function a(t,e,r){var a=new o(null==e?n:e,null==r?i:r,NaN,NaN,NaN,NaN);return null==t?a:a.addAll(t)}function o(t,e,r,n,i,a){this._x=t,this._y=e,this._x0=r,this._y0=n,this._x1=i,this._y1=a,this._root=void 0}function s(t){for(var e={data:t.data},r=e;t=t.next;)r=r.next={data:t.data};return e}var l=a.prototype=o.prototype;l.copy=function(){var t,e,r=new o(this._x,this._y,this._x0,this._y0,this._x1,this._y1),n=this._root;if(!n)return r;if(!n.length)return r._root=s(n),r;for(t=[{source:n,target:r._root=new Array(4)}];n=t.pop();)for(var i=0;i<4;++i)(e=n.source[i])&&(e.length?t.push({source:e,target:n.target[i]=new Array(4)}):n.target[i]=s(e));return r},l.add=function(t){var r=+this._x.call(null,t),n=+this._y.call(null,t);return e(this.cover(r,n),r,n,t)},l.addAll=function(t){var r,n,i,a,o=t.length,s=new Array(o),l=new Array(o),c=1/0,u=1/0,h=-1/0,f=-1/0;for(n=0;n<o;++n)isNaN(i=+this._x.call(null,r=t[n]))||isNaN(a=+this._y.call(null,r))||(s[n]=i,l[n]=a,i<c&&(c=i),i>h&&(h=i),a<u&&(u=a),a>f&&(f=a));for(h<c&&(c=this._x0,h=this._x1),f<u&&(u=this._y0,f=this._y1),this.cover(c,u).cover(h,f),n=0;n<o;++n)e(this,s[n],l[n],t[n]);return this},l.cover=function(t,e){if(isNaN(t=+t)||isNaN(e=+e))return this;var r=this._x0,n=this._y0,i=this._x1,a=this._y1;if(isNaN(r))i=(r=Math.floor(t))+1,a=(n=Math.floor(e))+1;else{if(!(r>t||t>i||n>e||e>a))return this;var o,s,l=i-r,c=this._root;switch(s=(e<(n+a)/2)<<1|t<(r+i)/2){case 0:do{(o=new Array(4))[s]=c,c=o}while(a=n+(l*=2),t>(i=r+l)||e>a);break;case 1:do{(o=new Array(4))[s]=c,c=o}while(a=n+(l*=2),(r=i-l)>t||e>a);break;case 2:do{(o=new Array(4))[s]=c,c=o}while(n=a-(l*=2),t>(i=r+l)||n>e);break;case 3:do{(o=new Array(4))[s]=c,c=o}while(n=a-(l*=2),(r=i-l)>t||n>e)}this._root&&this._root.length&&(this._root=c)}return this._x0=r,this._y0=n,this._x1=i,this._y1=a,this},l.data=function(){var t=[];return this.visit(function(e){if(!e.length)do{t.push(e.data)}while(e=e.next)}),t},l.extent=function(t){return arguments.length?this.cover(+t[0][0],+t[0][1]).cover(+t[1][0],+t[1][1]):isNaN(this._x0)?void 0:[[this._x0,this._y0],[this._x1,this._y1]]},l.find=function(t,e,n){var i,a,o,s,l,c,u,h=this._x0,f=this._y0,p=this._x1,d=this._y1,g=[],v=this._root;for(v&&g.push(new r(v,h,f,p,d)),null==n?n=1/0:(h=t-n,f=e-n,p=t+n,d=e+n,n*=n);c=g.pop();)if(!(!(v=c.node)||(a=c.x0)>p||(o=c.y0)>d||(s=c.x1)<h||(l=c.y1)<f))if(v.length){var m=(a+s)/2,y=(o+l)/2;g.push(new r(v[3],m,y,s,l),new r(v[2],a,y,m,l),new r(v[1],m,o,s,y),new r(v[0],a,o,m,y)),(u=(e>=y)<<1|t>=m)&&(c=g[g.length-1],g[g.length-1]=g[g.length-1-u],g[g.length-1-u]=c)}else{var x=t-+this._x.call(null,v.data),b=e-+this._y.call(null,v.data),_=x*x+b*b;if(_<n){var w=Math.sqrt(n=_);h=t-w,f=e-w,p=t+w,d=e+w,i=v.data}}return i},l.remove=function(t){if(isNaN(a=+this._x.call(null,t))||isNaN(o=+this._y.call(null,t)))return this;var e,r,n,i,a,o,s,l,c,u,h,f,p=this._root,d=this._x0,g=this._y0,v=this._x1,m=this._y1;if(!p)return this;if(p.length)for(;;){if((c=a>=(s=(d+v)/2))?d=s:v=s,(u=o>=(l=(g+m)/2))?g=l:m=l,e=p,!(p=p[h=u<<1|c]))return this;if(!p.length)break;(e[h+1&3]||e[h+2&3]||e[h+3&3])&&(r=e,f=h)}for(;p.data!==t;)if(n=p,!(p=p.next))return this;return(i=p.next)&&delete p.next,n?(i?n.next=i:delete n.next,this):e?(i?e[h]=i:delete e[h],(p=e[0]||e[1]||e[2]||e[3])&&p===(e[3]||e[2]||e[1]||e[0])&&!p.length&&(r?r[f]=p:this._root=p),this):(this._root=i,this)},l.removeAll=function(t){for(var e=0,r=t.length;e<r;++e)this.remove(t[e]);return this},l.root=function(){return this._root},l.size=function(){var t=0;return this.visit(function(e){if(!e.length)do{++t}while(e=e.next)}),t},l.visit=function(t){var e,n,i,a,o,s,l=[],c=this._root;for(c&&l.push(new r(c,this._x0,this._y0,this._x1,this._y1));e=l.pop();)if(!t(c=e.node,i=e.x0,a=e.y0,o=e.x1,s=e.y1)&&c.length){var u=(i+o)/2,h=(a+s)/2;(n=c[3])&&l.push(new r(n,u,h,o,s)),(n=c[2])&&l.push(new r(n,i,h,u,s)),(n=c[1])&&l.push(new r(n,u,a,o,h)),(n=c[0])&&l.push(new r(n,i,a,u,h))}return this},l.visitAfter=function(t){var e,n=[],i=[];for(this._root&&n.push(new r(this._root,this._x0,this._y0,this._x1,this._y1));e=n.pop();){var a=e.node;if(a.length){var o,s=e.x0,l=e.y0,c=e.x1,u=e.y1,h=(s+c)/2,f=(l+u)/2;(o=a[0])&&n.push(new r(o,s,l,h,f)),(o=a[1])&&n.push(new r(o,h,l,c,f)),(o=a[2])&&n.push(new r(o,s,f,h,u)),(o=a[3])&&n.push(new r(o,h,f,c,u))}i.push(e)}for(;e=i.pop();)t(e.node,e.x0,e.y0,e.x1,e.y1);return this},l.x=function(t){return arguments.length?(this._x=t,this):this._x},l.y=function(t){return arguments.length?(this._y=t,this):this._y},t.quadtree=a,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],161:[function(t,e,r){var n,i;n=this,i=function(t,e){\"use strict\";function r(t){return function(){return t}}var n=Math.abs,i=Math.atan2,a=Math.cos,o=Math.max,s=Math.min,l=Math.sin,c=Math.sqrt,u=1e-12,h=Math.PI,f=h/2,p=2*h;function d(t){return t>=1?f:t<=-1?-f:Math.asin(t)}function g(t){return t.innerRadius}function v(t){return t.outerRadius}function m(t){return t.startAngle}function y(t){return t.endAngle}function x(t){return t&&t.padAngle}function b(t,e,r,n,i,a,s){var l=t-r,u=e-n,h=(s?a:-a)/c(l*l+u*u),f=h*u,p=-h*l,d=t+f,g=e+p,v=r+f,m=n+p,y=(d+v)/2,x=(g+m)/2,b=v-d,_=m-g,w=b*b+_*_,k=i-a,T=d*m-v*g,A=(_<0?-1:1)*c(o(0,k*k*w-T*T)),M=(T*_-b*A)/w,S=(-T*b-_*A)/w,E=(T*_+b*A)/w,C=(-T*b+_*A)/w,L=M-y,P=S-x,O=E-y,z=C-x;return L*L+P*P>O*O+z*z&&(M=E,S=C),{cx:M,cy:S,x01:-f,y01:-p,x11:M*(i/k-1),y11:S*(i/k-1)}}function _(t){this._context=t}function w(t){return new _(t)}function k(t){return t[0]}function T(t){return t[1]}function A(){var t=k,n=T,i=r(!0),a=null,o=w,s=null;function l(r){var l,c,u,h=r.length,f=!1;for(null==a&&(s=o(u=e.path())),l=0;l<=h;++l)!(l<h&&i(c=r[l],l,r))===f&&((f=!f)?s.lineStart():s.lineEnd()),f&&s.point(+t(c,l,r),+n(c,l,r));if(u)return s=null,u+\"\"||null}return l.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),l):t},l.y=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),l):n},l.defined=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(!!t),l):i},l.curve=function(t){return arguments.length?(o=t,null!=a&&(s=o(a)),l):o},l.context=function(t){return arguments.length?(null==t?a=s=null:s=o(a=t),l):a},l}function M(){var t=k,n=null,i=r(0),a=T,o=r(!0),s=null,l=w,c=null;function u(r){var u,h,f,p,d,g=r.length,v=!1,m=new Array(g),y=new Array(g);for(null==s&&(c=l(d=e.path())),u=0;u<=g;++u){if(!(u<g&&o(p=r[u],u,r))===v)if(v=!v)h=u,c.areaStart(),c.lineStart();else{for(c.lineEnd(),c.lineStart(),f=u-1;f>=h;--f)c.point(m[f],y[f]);c.lineEnd(),c.areaEnd()}v&&(m[u]=+t(p,u,r),y[u]=+i(p,u,r),c.point(n?+n(p,u,r):m[u],a?+a(p,u,r):y[u]))}if(d)return c=null,d+\"\"||null}function h(){return A().defined(o).curve(l).context(s)}return u.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),n=null,u):t},u.x0=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),u):t},u.x1=function(t){return arguments.length?(n=null==t?null:\"function\"==typeof t?t:r(+t),u):n},u.y=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a=null,u):i},u.y0=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),u):i},u.y1=function(t){return arguments.length?(a=null==t?null:\"function\"==typeof t?t:r(+t),u):a},u.lineX0=u.lineY0=function(){return h().x(t).y(i)},u.lineY1=function(){return h().x(t).y(a)},u.lineX1=function(){return h().x(n).y(i)},u.defined=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(!!t),u):o},u.curve=function(t){return arguments.length?(l=t,null!=s&&(c=l(s)),u):l},u.context=function(t){return arguments.length?(null==t?s=c=null:c=l(s=t),u):s},u}function S(t,e){return e<t?-1:e>t?1:e>=t?0:NaN}function E(t){return t}_.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._point=0},lineEnd:function(){(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:this._context.lineTo(t,e)}}};var C=P(w);function L(t){this._curve=t}function P(t){function e(e){return new L(t(e))}return e._curve=t,e}function O(t){var e=t.curve;return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function z(){return O(A().curve(C))}function I(){var t=M().curve(C),e=t.curve,r=t.lineX0,n=t.lineX1,i=t.lineY0,a=t.lineY1;return t.angle=t.x,delete t.x,t.startAngle=t.x0,delete t.x0,t.endAngle=t.x1,delete t.x1,t.radius=t.y,delete t.y,t.innerRadius=t.y0,delete t.y0,t.outerRadius=t.y1,delete t.y1,t.lineStartAngle=function(){return O(r())},delete t.lineX0,t.lineEndAngle=function(){return O(n())},delete t.lineX1,t.lineInnerRadius=function(){return O(i())},delete t.lineY0,t.lineOuterRadius=function(){return O(a())},delete t.lineY1,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function D(t,e){return[(e=+e)*Math.cos(t-=Math.PI/2),e*Math.sin(t)]}L.prototype={areaStart:function(){this._curve.areaStart()},areaEnd:function(){this._curve.areaEnd()},lineStart:function(){this._curve.lineStart()},lineEnd:function(){this._curve.lineEnd()},point:function(t,e){this._curve.point(e*Math.sin(t),e*-Math.cos(t))}};var R=Array.prototype.slice;function F(t){return t.source}function B(t){return t.target}function N(t){var n=F,i=B,a=k,o=T,s=null;function l(){var r,l=R.call(arguments),c=n.apply(this,l),u=i.apply(this,l);if(s||(s=r=e.path()),t(s,+a.apply(this,(l[0]=c,l)),+o.apply(this,l),+a.apply(this,(l[0]=u,l)),+o.apply(this,l)),r)return s=null,r+\"\"||null}return l.source=function(t){return arguments.length?(n=t,l):n},l.target=function(t){return arguments.length?(i=t,l):i},l.x=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),l):a},l.y=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),l):o},l.context=function(t){return arguments.length?(s=null==t?null:t,l):s},l}function j(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e=(e+n)/2,r,e,i,n,i)}function U(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e,r=(r+i)/2,n,r,n,i)}function V(t,e,r,n,i){var a=D(e,r),o=D(e,r=(r+i)/2),s=D(n,r),l=D(n,i);t.moveTo(a[0],a[1]),t.bezierCurveTo(o[0],o[1],s[0],s[1],l[0],l[1])}var q={draw:function(t,e){var r=Math.sqrt(e/h);t.moveTo(r,0),t.arc(0,0,r,0,p)}},H={draw:function(t,e){var r=Math.sqrt(e/5)/2;t.moveTo(-3*r,-r),t.lineTo(-r,-r),t.lineTo(-r,-3*r),t.lineTo(r,-3*r),t.lineTo(r,-r),t.lineTo(3*r,-r),t.lineTo(3*r,r),t.lineTo(r,r),t.lineTo(r,3*r),t.lineTo(-r,3*r),t.lineTo(-r,r),t.lineTo(-3*r,r),t.closePath()}},G=Math.sqrt(1/3),Y=2*G,W={draw:function(t,e){var r=Math.sqrt(e/Y),n=r*G;t.moveTo(0,-r),t.lineTo(n,0),t.lineTo(0,r),t.lineTo(-n,0),t.closePath()}},X=Math.sin(h/10)/Math.sin(7*h/10),Z=Math.sin(p/10)*X,J=-Math.cos(p/10)*X,K={draw:function(t,e){var r=Math.sqrt(.8908130915292852*e),n=Z*r,i=J*r;t.moveTo(0,-r),t.lineTo(n,i);for(var a=1;a<5;++a){var o=p*a/5,s=Math.cos(o),l=Math.sin(o);t.lineTo(l*r,-s*r),t.lineTo(s*n-l*i,l*n+s*i)}t.closePath()}},$={draw:function(t,e){var r=Math.sqrt(e),n=-r/2;t.rect(n,n,r,r)}},Q=Math.sqrt(3),tt={draw:function(t,e){var r=-Math.sqrt(e/(3*Q));t.moveTo(0,2*r),t.lineTo(-Q*r,-r),t.lineTo(Q*r,-r),t.closePath()}},et=-.5,rt=Math.sqrt(3)/2,nt=1/Math.sqrt(12),it=3*(nt/2+1),at={draw:function(t,e){var r=Math.sqrt(e/it),n=r/2,i=r*nt,a=n,o=r*nt+r,s=-a,l=o;t.moveTo(n,i),t.lineTo(a,o),t.lineTo(s,l),t.lineTo(et*n-rt*i,rt*n+et*i),t.lineTo(et*a-rt*o,rt*a+et*o),t.lineTo(et*s-rt*l,rt*s+et*l),t.lineTo(et*n+rt*i,et*i-rt*n),t.lineTo(et*a+rt*o,et*o-rt*a),t.lineTo(et*s+rt*l,et*l-rt*s),t.closePath()}},ot=[q,H,W,$,K,tt,at];function st(){}function lt(t,e,r){t._context.bezierCurveTo((2*t._x0+t._x1)/3,(2*t._y0+t._y1)/3,(t._x0+2*t._x1)/3,(t._y0+2*t._y1)/3,(t._x0+4*t._x1+e)/6,(t._y0+4*t._y1+r)/6)}function ct(t){this._context=t}function ut(t){this._context=t}function ht(t){this._context=t}function ft(t,e){this._basis=new ct(t),this._beta=e}ct.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){switch(this._point){case 3:lt(this,this._x1,this._y1);case 2:this._context.lineTo(this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,this._context.lineTo((5*this._x0+this._x1)/6,(5*this._y0+this._y1)/6);default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ut.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._y0=this._y1=this._y2=this._y3=this._y4=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x2,this._y2),this._context.closePath();break;case 2:this._context.moveTo((this._x2+2*this._x3)/3,(this._y2+2*this._y3)/3),this._context.lineTo((this._x3+2*this._x2)/3,(this._y3+2*this._y2)/3),this._context.closePath();break;case 3:this.point(this._x2,this._y2),this.point(this._x3,this._y3),this.point(this._x4,this._y4)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x2=t,this._y2=e;break;case 1:this._point=2,this._x3=t,this._y3=e;break;case 2:this._point=3,this._x4=t,this._y4=e,this._context.moveTo((this._x0+4*this._x1+t)/6,(this._y0+4*this._y1+e)/6);break;default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ht.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3;var r=(this._x0+4*this._x1+t)/6,n=(this._y0+4*this._y1+e)/6;this._line?this._context.lineTo(r,n):this._context.moveTo(r,n);break;case 3:this._point=4;default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ft.prototype={lineStart:function(){this._x=[],this._y=[],this._basis.lineStart()},lineEnd:function(){var t=this._x,e=this._y,r=t.length-1;if(r>0)for(var n,i=t[0],a=e[0],o=t[r]-i,s=e[r]-a,l=-1;++l<=r;)n=l/r,this._basis.point(this._beta*t[l]+(1-this._beta)*(i+n*o),this._beta*e[l]+(1-this._beta)*(a+n*s));this._x=this._y=null,this._basis.lineEnd()},point:function(t,e){this._x.push(+t),this._y.push(+e)}};var pt=function t(e){function r(t){return 1===e?new ct(t):new ft(t,e)}return r.beta=function(e){return t(+e)},r}(.85);function dt(t,e,r){t._context.bezierCurveTo(t._x1+t._k*(t._x2-t._x0),t._y1+t._k*(t._y2-t._y0),t._x2+t._k*(t._x1-e),t._y2+t._k*(t._y1-r),t._x2,t._y2)}function gt(t,e){this._context=t,this._k=(1-e)/6}gt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:dt(this,this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2,this._x1=t,this._y1=e;break;case 2:this._point=3;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var vt=function t(e){function r(t){return new gt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function mt(t,e){this._context=t,this._k=(1-e)/6}mt.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var yt=function t(e){function r(t){return new mt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function xt(t,e){this._context=t,this._k=(1-e)/6}xt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var bt=function t(e){function r(t){return new xt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function _t(t,e,r){var n=t._x1,i=t._y1,a=t._x2,o=t._y2;if(t._l01_a>u){var s=2*t._l01_2a+3*t._l01_a*t._l12_a+t._l12_2a,l=3*t._l01_a*(t._l01_a+t._l12_a);n=(n*s-t._x0*t._l12_2a+t._x2*t._l01_2a)/l,i=(i*s-t._y0*t._l12_2a+t._y2*t._l01_2a)/l}if(t._l23_a>u){var c=2*t._l23_2a+3*t._l23_a*t._l12_a+t._l12_2a,h=3*t._l23_a*(t._l23_a+t._l12_a);a=(a*c+t._x1*t._l23_2a-e*t._l12_2a)/h,o=(o*c+t._y1*t._l23_2a-r*t._l12_2a)/h}t._context.bezierCurveTo(n,i,a,o,t._x2,t._y2)}function wt(t,e){this._context=t,this._alpha=e}wt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:this.point(this._x2,this._y2)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var kt=function t(e){function r(t){return e?new wt(t,e):new gt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Tt(t,e){this._context=t,this._alpha=e}Tt.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var At=function t(e){function r(t){return e?new Tt(t,e):new mt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Mt(t,e){this._context=t,this._alpha=e}Mt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var St=function t(e){function r(t){return e?new Mt(t,e):new xt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Et(t){this._context=t}function Ct(t){return t<0?-1:1}function Lt(t,e,r){var n=t._x1-t._x0,i=e-t._x1,a=(t._y1-t._y0)/(n||i<0&&-0),o=(r-t._y1)/(i||n<0&&-0),s=(a*i+o*n)/(n+i);return(Ct(a)+Ct(o))*Math.min(Math.abs(a),Math.abs(o),.5*Math.abs(s))||0}function Pt(t,e){var r=t._x1-t._x0;return r?(3*(t._y1-t._y0)/r-e)/2:e}function Ot(t,e,r){var n=t._x0,i=t._y0,a=t._x1,o=t._y1,s=(a-n)/3;t._context.bezierCurveTo(n+s,i+s*e,a-s,o-s*r,a,o)}function zt(t){this._context=t}function It(t){this._context=new Dt(t)}function Dt(t){this._context=t}function Rt(t){this._context=t}function Ft(t){var e,r,n=t.length-1,i=new Array(n),a=new Array(n),o=new Array(n);for(i[0]=0,a[0]=2,o[0]=t[0]+2*t[1],e=1;e<n-1;++e)i[e]=1,a[e]=4,o[e]=4*t[e]+2*t[e+1];for(i[n-1]=2,a[n-1]=7,o[n-1]=8*t[n-1]+t[n],e=1;e<n;++e)r=i[e]/a[e-1],a[e]-=r,o[e]-=r*o[e-1];for(i[n-1]=o[n-1]/a[n-1],e=n-2;e>=0;--e)i[e]=(o[e]-i[e+1])/a[e];for(a[n-1]=(t[n]+i[n-1])/2,e=0;e<n-1;++e)a[e]=2*t[e+1]-i[e+1];return[i,a]}function Bt(t,e){this._context=t,this._t=e}function Nt(t,e){if((i=t.length)>1)for(var r,n,i,a=1,o=t[e[0]],s=o.length;a<i;++a)for(n=o,o=t[e[a]],r=0;r<s;++r)o[r][1]+=o[r][0]=isNaN(n[r][1])?n[r][0]:n[r][1]}function jt(t){for(var e=t.length,r=new Array(e);--e>=0;)r[e]=e;return r}function Ut(t,e){return t[e]}function Vt(t){var e=t.map(qt);return jt(t).sort(function(t,r){return e[t]-e[r]})}function qt(t){for(var e,r=-1,n=0,i=t.length,a=-1/0;++r<i;)(e=+t[r][1])>a&&(a=e,n=r);return n}function Ht(t){var e=t.map(Gt);return jt(t).sort(function(t,r){return e[t]-e[r]})}function Gt(t){for(var e,r=0,n=-1,i=t.length;++n<i;)(e=+t[n][1])&&(r+=e);return r}Et.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._point=0},lineEnd:function(){this._point&&this._context.closePath()},point:function(t,e){t=+t,e=+e,this._point?this._context.lineTo(t,e):(this._point=1,this._context.moveTo(t,e))}},zt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=this._t0=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x1,this._y1);break;case 3:Ot(this,this._t0,Pt(this,this._t0))}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){var r=NaN;if(e=+e,(t=+t)!==this._x1||e!==this._y1){switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,Ot(this,Pt(this,r=Lt(this,t,e)),r);break;default:Ot(this,this._t0,r=Lt(this,t,e))}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e,this._t0=r}}},(It.prototype=Object.create(zt.prototype)).point=function(t,e){zt.prototype.point.call(this,e,t)},Dt.prototype={moveTo:function(t,e){this._context.moveTo(e,t)},closePath:function(){this._context.closePath()},lineTo:function(t,e){this._context.lineTo(e,t)},bezierCurveTo:function(t,e,r,n,i,a){this._context.bezierCurveTo(e,t,n,r,a,i)}},Rt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=[],this._y=[]},lineEnd:function(){var t=this._x,e=this._y,r=t.length;if(r)if(this._line?this._context.lineTo(t[0],e[0]):this._context.moveTo(t[0],e[0]),2===r)this._context.lineTo(t[1],e[1]);else for(var n=Ft(t),i=Ft(e),a=0,o=1;o<r;++a,++o)this._context.bezierCurveTo(n[0][a],i[0][a],n[1][a],i[1][a],t[o],e[o]);(this._line||0!==this._line&&1===r)&&this._context.closePath(),this._line=1-this._line,this._x=this._y=null},point:function(t,e){this._x.push(+t),this._y.push(+e)}},Bt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=this._y=NaN,this._point=0},lineEnd:function(){0<this._t&&this._t<1&&2===this._point&&this._context.lineTo(this._x,this._y),(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line>=0&&(this._t=1-this._t,this._line=1-this._line)},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:if(this._t<=0)this._context.lineTo(this._x,e),this._context.lineTo(t,e);else{var r=this._x*(1-this._t)+t*this._t;this._context.lineTo(r,this._y),this._context.lineTo(r,e)}}this._x=t,this._y=e}},t.arc=function(){var t=g,o=v,_=r(0),w=null,k=m,T=y,A=x,M=null;function S(){var r,g,v,m=+t.apply(this,arguments),y=+o.apply(this,arguments),x=k.apply(this,arguments)-f,S=T.apply(this,arguments)-f,E=n(S-x),C=S>x;if(M||(M=r=e.path()),y<m&&(g=y,y=m,m=g),y>u)if(E>p-u)M.moveTo(y*a(x),y*l(x)),M.arc(0,0,y,x,S,!C),m>u&&(M.moveTo(m*a(S),m*l(S)),M.arc(0,0,m,S,x,C));else{var L,P,O=x,z=S,I=x,D=S,R=E,F=E,B=A.apply(this,arguments)/2,N=B>u&&(w?+w.apply(this,arguments):c(m*m+y*y)),j=s(n(y-m)/2,+_.apply(this,arguments)),U=j,V=j;if(N>u){var q=d(N/m*l(B)),H=d(N/y*l(B));(R-=2*q)>u?(I+=q*=C?1:-1,D-=q):(R=0,I=D=(x+S)/2),(F-=2*H)>u?(O+=H*=C?1:-1,z-=H):(F=0,O=z=(x+S)/2)}var G=y*a(O),Y=y*l(O),W=m*a(D),X=m*l(D);if(j>u){var Z,J=y*a(z),K=y*l(z),$=m*a(I),Q=m*l(I);if(E<h&&(Z=function(t,e,r,n,i,a,o,s){var l=r-t,c=n-e,h=o-i,f=s-a,p=f*l-h*c;if(!(p*p<u))return[t+(p=(h*(e-a)-f*(t-i))/p)*l,e+p*c]}(G,Y,$,Q,J,K,W,X))){var tt=G-Z[0],et=Y-Z[1],rt=J-Z[0],nt=K-Z[1],it=1/l(((v=(tt*rt+et*nt)/(c(tt*tt+et*et)*c(rt*rt+nt*nt)))>1?0:v<-1?h:Math.acos(v))/2),at=c(Z[0]*Z[0]+Z[1]*Z[1]);U=s(j,(m-at)/(it-1)),V=s(j,(y-at)/(it+1))}}F>u?V>u?(L=b($,Q,G,Y,y,V,C),P=b(J,K,W,X,y,V,C),M.moveTo(L.cx+L.x01,L.cy+L.y01),V<j?M.arc(L.cx,L.cy,V,i(L.y01,L.x01),i(P.y01,P.x01),!C):(M.arc(L.cx,L.cy,V,i(L.y01,L.x01),i(L.y11,L.x11),!C),M.arc(0,0,y,i(L.cy+L.y11,L.cx+L.x11),i(P.cy+P.y11,P.cx+P.x11),!C),M.arc(P.cx,P.cy,V,i(P.y11,P.x11),i(P.y01,P.x01),!C))):(M.moveTo(G,Y),M.arc(0,0,y,O,z,!C)):M.moveTo(G,Y),m>u&&R>u?U>u?(L=b(W,X,J,K,m,-U,C),P=b(G,Y,$,Q,m,-U,C),M.lineTo(L.cx+L.x01,L.cy+L.y01),U<j?M.arc(L.cx,L.cy,U,i(L.y01,L.x01),i(P.y01,P.x01),!C):(M.arc(L.cx,L.cy,U,i(L.y01,L.x01),i(L.y11,L.x11),!C),M.arc(0,0,m,i(L.cy+L.y11,L.cx+L.x11),i(P.cy+P.y11,P.cx+P.x11),C),M.arc(P.cx,P.cy,U,i(P.y11,P.x11),i(P.y01,P.x01),!C))):M.arc(0,0,m,D,I,C):M.lineTo(W,X)}else M.moveTo(0,0);if(M.closePath(),r)return M=null,r+\"\"||null}return S.centroid=function(){var e=(+t.apply(this,arguments)+ +o.apply(this,arguments))/2,r=(+k.apply(this,arguments)+ +T.apply(this,arguments))/2-h/2;return[a(r)*e,l(r)*e]},S.innerRadius=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),S):t},S.outerRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),S):o},S.cornerRadius=function(t){return arguments.length?(_=\"function\"==typeof t?t:r(+t),S):_},S.padRadius=function(t){return arguments.length?(w=null==t?null:\"function\"==typeof t?t:r(+t),S):w},S.startAngle=function(t){return arguments.length?(k=\"function\"==typeof t?t:r(+t),S):k},S.endAngle=function(t){return arguments.length?(T=\"function\"==typeof t?t:r(+t),S):T},S.padAngle=function(t){return arguments.length?(A=\"function\"==typeof t?t:r(+t),S):A},S.context=function(t){return arguments.length?(M=null==t?null:t,S):M},S},t.area=M,t.line=A,t.pie=function(){var t=E,e=S,n=null,i=r(0),a=r(p),o=r(0);function s(r){var s,l,c,u,h,f=r.length,d=0,g=new Array(f),v=new Array(f),m=+i.apply(this,arguments),y=Math.min(p,Math.max(-p,a.apply(this,arguments)-m)),x=Math.min(Math.abs(y)/f,o.apply(this,arguments)),b=x*(y<0?-1:1);for(s=0;s<f;++s)(h=v[g[s]=s]=+t(r[s],s,r))>0&&(d+=h);for(null!=e?g.sort(function(t,r){return e(v[t],v[r])}):null!=n&&g.sort(function(t,e){return n(r[t],r[e])}),s=0,c=d?(y-f*b)/d:0;s<f;++s,m=u)l=g[s],u=m+((h=v[l])>0?h*c:0)+b,v[l]={data:r[l],index:s,value:h,startAngle:m,endAngle:u,padAngle:x};return v}return s.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),s):t},s.sortValues=function(t){return arguments.length?(e=t,n=null,s):e},s.sort=function(t){return arguments.length?(n=t,e=null,s):n},s.startAngle=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),s):i},s.endAngle=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),s):a},s.padAngle=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),s):o},s},t.areaRadial=I,t.radialArea=I,t.lineRadial=z,t.radialLine=z,t.pointRadial=D,t.linkHorizontal=function(){return N(j)},t.linkVertical=function(){return N(U)},t.linkRadial=function(){var t=N(V);return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t},t.symbol=function(){var t=r(q),n=r(64),i=null;function a(){var r;if(i||(i=r=e.path()),t.apply(this,arguments).draw(i,+n.apply(this,arguments)),r)return i=null,r+\"\"||null}return a.type=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(e),a):t},a.size=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),a):n},a.context=function(t){return arguments.length?(i=null==t?null:t,a):i},a},t.symbols=ot,t.symbolCircle=q,t.symbolCross=H,t.symbolDiamond=W,t.symbolSquare=$,t.symbolStar=K,t.symbolTriangle=tt,t.symbolWye=at,t.curveBasisClosed=function(t){return new ut(t)},t.curveBasisOpen=function(t){return new ht(t)},t.curveBasis=function(t){return new ct(t)},t.curveBundle=pt,t.curveCardinalClosed=yt,t.curveCardinalOpen=bt,t.curveCardinal=vt,t.curveCatmullRomClosed=At,t.curveCatmullRomOpen=St,t.curveCatmullRom=kt,t.curveLinearClosed=function(t){return new Et(t)},t.curveLinear=w,t.curveMonotoneX=function(t){return new zt(t)},t.curveMonotoneY=function(t){return new It(t)},t.curveNatural=function(t){return new Rt(t)},t.curveStep=function(t){return new Bt(t,.5)},t.curveStepAfter=function(t){return new Bt(t,1)},t.curveStepBefore=function(t){return new Bt(t,0)},t.stack=function(){var t=r([]),e=jt,n=Nt,i=Ut;function a(r){var a,o,s=t.apply(this,arguments),l=r.length,c=s.length,u=new Array(c);for(a=0;a<c;++a){for(var h,f=s[a],p=u[a]=new Array(l),d=0;d<l;++d)p[d]=h=[0,+i(r[d],f,d,r)],h.data=r[d];p.key=f}for(a=0,o=e(u);a<c;++a)u[o[a]].index=a;return n(u,o),u}return a.keys=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(R.call(e)),a):t},a.value=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a):i},a.order=function(t){return arguments.length?(e=null==t?jt:\"function\"==typeof t?t:r(R.call(t)),a):e},a.offset=function(t){return arguments.length?(n=null==t?Nt:t,a):n},a},t.stackOffsetExpand=function(t,e){if((n=t.length)>0){for(var r,n,i,a=0,o=t[0].length;a<o;++a){for(i=r=0;r<n;++r)i+=t[r][a][1]||0;if(i)for(r=0;r<n;++r)t[r][a][1]/=i}Nt(t,e)}},t.stackOffsetDiverging=function(t,e){if((s=t.length)>1)for(var r,n,i,a,o,s,l=0,c=t[e[0]].length;l<c;++l)for(a=o=0,r=0;r<s;++r)(i=(n=t[e[r]][l])[1]-n[0])>=0?(n[0]=a,n[1]=a+=i):i<0?(n[1]=o,n[0]=o+=i):n[0]=a},t.stackOffsetNone=Nt,t.stackOffsetSilhouette=function(t,e){if((r=t.length)>0){for(var r,n=0,i=t[e[0]],a=i.length;n<a;++n){for(var o=0,s=0;o<r;++o)s+=t[o][n][1]||0;i[n][1]+=i[n][0]=-s/2}Nt(t,e)}},t.stackOffsetWiggle=function(t,e){if((i=t.length)>0&&(n=(r=t[e[0]]).length)>0){for(var r,n,i,a=0,o=1;o<n;++o){for(var s=0,l=0,c=0;s<i;++s){for(var u=t[e[s]],h=u[o][1]||0,f=(h-(u[o-1][1]||0))/2,p=0;p<s;++p){var d=t[e[p]];f+=(d[o][1]||0)-(d[o-1][1]||0)}l+=h,c+=f*h}r[o-1][1]+=r[o-1][0]=a,l&&(a-=c/l)}r[o-1][1]+=r[o-1][0]=a,Nt(t,e)}},t.stackOrderAppearance=Vt,t.stackOrderAscending=Ht,t.stackOrderDescending=function(t){return Ht(t).reverse()},t.stackOrderInsideOut=function(t){var e,r,n=t.length,i=t.map(Gt),a=Vt(t),o=0,s=0,l=[],c=[];for(e=0;e<n;++e)r=a[e],o<s?(o+=i[r],l.push(r)):(s+=i[r],c.push(r));return c.reverse().concat(l)},t.stackOrderNone=jt,t.stackOrderReverse=function(t){return jt(t).reverse()},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-path\")):i(n.d3=n.d3||{},n.d3)},{\"d3-path\":159}],162:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e,r,n=0,i=0,a=0,o=1e3,s=0,l=0,c=0,u=\"object\"==typeof performance&&performance.now?performance:Date,h=\"object\"==typeof window&&window.requestAnimationFrame?window.requestAnimationFrame.bind(window):function(t){setTimeout(t,17)};function f(){return l||(h(p),l=u.now()+c)}function p(){l=0}function d(){this._call=this._time=this._next=null}function g(t,e,r){var n=new d;return n.restart(t,e,r),n}function v(){f(),++n;for(var t,r=e;r;)(t=l-r._time)>=0&&r._call.call(null,t),r=r._next;--n}function m(){l=(s=u.now())+c,n=i=0;try{v()}finally{n=0,function(){var t,n,i=e,a=1/0;for(;i;)i._call?(a>i._time&&(a=i._time),t=i,i=i._next):(n=i._next,i._next=null,i=t?t._next=n:e=n);r=t,x(a)}(),l=0}}function y(){var t=u.now(),e=t-s;e>o&&(c-=e,s=t)}function x(t){n||(i&&(i=clearTimeout(i)),t-l>24?(t<1/0&&(i=setTimeout(m,t-u.now()-c)),a&&(a=clearInterval(a))):(a||(s=u.now(),a=setInterval(y,o)),n=1,h(m)))}d.prototype=g.prototype={constructor:d,restart:function(t,n,i){if(\"function\"!=typeof t)throw new TypeError(\"callback is not a function\");i=(null==i?f():+i)+(null==n?0:+n),this._next||r===this||(r?r._next=this:e=this,r=this),this._call=t,this._time=i,x()},stop:function(){this._call&&(this._call=null,this._time=1/0,x())}};t.now=f,t.timer=g,t.timerFlush=v,t.timeout=function(t,e,r){var n=new d;return e=null==e?0:+e,n.restart(function(r){n.stop(),t(r+e)},e,r),n},t.interval=function(t,e,r){var n=new d,i=e;return null==e?(n.restart(t,e,r),n):(e=+e,r=null==r?f():+r,n.restart(function a(o){o+=i,n.restart(a,i+=e,r),t(o)},e,r),n)},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],163:[function(t,e,r){!function(){var t={version:\"3.5.17\"},r=[].slice,n=function(t){return r.call(t)},i=this.document;function a(t){return t&&(t.ownerDocument||t.document||t).documentElement}function o(t){return t&&(t.ownerDocument&&t.ownerDocument.defaultView||t.document&&t||t.defaultView)}if(i)try{n(i.documentElement.childNodes)[0].nodeType}catch(t){n=function(t){for(var e=t.length,r=new Array(e);e--;)r[e]=t[e];return r}}if(Date.now||(Date.now=function(){return+new Date}),i)try{i.createElement(\"DIV\").style.setProperty(\"opacity\",0,\"\")}catch(t){var s=this.Element.prototype,l=s.setAttribute,c=s.setAttributeNS,u=this.CSSStyleDeclaration.prototype,h=u.setProperty;s.setAttribute=function(t,e){l.call(this,t,e+\"\")},s.setAttributeNS=function(t,e,r){c.call(this,t,e,r+\"\")},u.setProperty=function(t,e,r){h.call(this,t,e+\"\",r)}}function f(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function p(t){return null===t?NaN:+t}function d(t){return!isNaN(t)}function g(t){return{left:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}t.ascending=f,t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.min=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&r>n&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&r>n&&(r=n)}return r},t.max=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&n>r&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&n>r&&(r=n)}return r},t.extent=function(t,e){var r,n,i,a=-1,o=t.length;if(1===arguments.length){for(;++a<o;)if(null!=(n=t[a])&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=t[a])&&(r>n&&(r=n),i<n&&(i=n))}else{for(;++a<o;)if(null!=(n=e.call(t,t[a],a))&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=e.call(t,t[a],a))&&(r>n&&(r=n),i<n&&(i=n))}return[r,i]},t.sum=function(t,e){var r,n=0,i=t.length,a=-1;if(1===arguments.length)for(;++a<i;)d(r=+t[a])&&(n+=r);else for(;++a<i;)d(r=+e.call(t,t[a],a))&&(n+=r);return n},t.mean=function(t,e){var r,n=0,i=t.length,a=-1,o=i;if(1===arguments.length)for(;++a<i;)d(r=p(t[a]))?n+=r:--o;else for(;++a<i;)d(r=p(e.call(t,t[a],a)))?n+=r:--o;if(o)return n/o},t.quantile=function(t,e){var r=(t.length-1)*e+1,n=Math.floor(r),i=+t[n-1],a=r-n;return a?i+a*(t[n]-i):i},t.median=function(e,r){var n,i=[],a=e.length,o=-1;if(1===arguments.length)for(;++o<a;)d(n=p(e[o]))&&i.push(n);else for(;++o<a;)d(n=p(r.call(e,e[o],o)))&&i.push(n);if(i.length)return t.quantile(i.sort(f),.5)},t.variance=function(t,e){var r,n,i=t.length,a=0,o=0,s=-1,l=0;if(1===arguments.length)for(;++s<i;)d(r=p(t[s]))&&(o+=(n=r-a)*(r-(a+=n/++l)));else for(;++s<i;)d(r=p(e.call(t,t[s],s)))&&(o+=(n=r-a)*(r-(a+=n/++l)));if(l>1)return o/(l-1)},t.deviation=function(){var e=t.variance.apply(this,arguments);return e?Math.sqrt(e):e};var v=g(f);function m(t){return t.length}t.bisectLeft=v.left,t.bisect=t.bisectRight=v.right,t.bisector=function(t){return g(1===t.length?function(e,r){return f(t(e),r)}:t)},t.shuffle=function(t,e,r){(a=arguments.length)<3&&(r=t.length,a<2&&(e=0));for(var n,i,a=r-e;a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.pairs=function(t){for(var e=0,r=t.length-1,n=t[0],i=new Array(r<0?0:r);e<r;)i[e]=[n,n=t[++e]];return i},t.transpose=function(e){if(!(a=e.length))return[];for(var r=-1,n=t.min(e,m),i=new Array(n);++r<n;)for(var a,o=-1,s=i[r]=new Array(a);++o<a;)s[o]=e[o][r];return i},t.zip=function(){return t.transpose(arguments)},t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r};var y=Math.abs;function x(t,e){for(var r in e)Object.defineProperty(t.prototype,r,{value:e[r],enumerable:!1})}function b(){this._=Object.create(null)}t.range=function(t,e,r){if(arguments.length<3&&(r=1,arguments.length<2&&(e=t,t=0)),(e-t)/r==1/0)throw new Error(\"infinite range\");var n,i=[],a=function(t){var e=1;for(;t*e%1;)e*=10;return e}(y(r)),o=-1;if(t*=a,e*=a,(r*=a)<0)for(;(n=t+r*++o)>e;)i.push(n/a);else for(;(n=t+r*++o)<e;)i.push(n/a);return i},t.map=function(t,e){var r=new b;if(t instanceof b)t.forEach(function(t,e){r.set(t,e)});else if(Array.isArray(t)){var n,i=-1,a=t.length;if(1===arguments.length)for(;++i<a;)r.set(i,t[i]);else for(;++i<a;)r.set(e.call(t,n=t[i],i),n)}else for(var o in t)r.set(o,t[o]);return r};var _=\"__proto__\",w=\"\\0\";function k(t){return(t+=\"\")===_||t[0]===w?w+t:t}function T(t){return(t+=\"\")[0]===w?t.slice(1):t}function A(t){return k(t)in this._}function M(t){return(t=k(t))in this._&&delete this._[t]}function S(){var t=[];for(var e in this._)t.push(T(e));return t}function E(){var t=0;for(var e in this._)++t;return t}function C(){for(var t in this._)return!1;return!0}function L(){this._=Object.create(null)}function P(t){return t}function O(t,e,r){return function(){var n=r.apply(e,arguments);return n===e?t:n}}function z(t,e){if(e in t)return e;e=e.charAt(0).toUpperCase()+e.slice(1);for(var r=0,n=I.length;r<n;++r){var i=I[r]+e;if(i in t)return i}}x(b,{has:A,get:function(t){return this._[k(t)]},set:function(t,e){return this._[k(t)]=e},remove:M,keys:S,values:function(){var t=[];for(var e in this._)t.push(this._[e]);return t},entries:function(){var t=[];for(var e in this._)t.push({key:T(e),value:this._[e]});return t},size:E,empty:C,forEach:function(t){for(var e in this._)t.call(this,T(e),this._[e])}}),t.nest=function(){var e,r,n={},i=[],a=[];function o(t,a,s){if(s>=i.length)return r?r.call(n,a):e?a.sort(e):a;for(var l,c,u,h,f=-1,p=a.length,d=i[s++],g=new b;++f<p;)(h=g.get(l=d(c=a[f])))?h.push(c):g.set(l,[c]);return t?(c=t(),u=function(e,r){c.set(e,o(t,r,s))}):(c={},u=function(e,r){c[e]=o(t,r,s)}),g.forEach(u),c}return n.map=function(t,e){return o(e,t,0)},n.entries=function(e){return function t(e,r){if(r>=i.length)return e;var n=[],o=a[r++];return e.forEach(function(e,i){n.push({key:e,values:t(i,r)})}),o?n.sort(function(t,e){return o(t.key,e.key)}):n}(o(t.map,e,0),0)},n.key=function(t){return i.push(t),n},n.sortKeys=function(t){return a[i.length-1]=t,n},n.sortValues=function(t){return e=t,n},n.rollup=function(t){return r=t,n},n},t.set=function(t){var e=new L;if(t)for(var r=0,n=t.length;r<n;++r)e.add(t[r]);return e},x(L,{has:A,add:function(t){return this._[k(t+=\"\")]=!0,t},remove:M,values:S,size:E,empty:C,forEach:function(t){for(var e in this._)t.call(this,T(e))}}),t.behavior={},t.rebind=function(t,e){for(var r,n=1,i=arguments.length;++n<i;)t[r=arguments[n]]=O(t,e,e[r]);return t};var I=[\"webkit\",\"ms\",\"moz\",\"Moz\",\"o\",\"O\"];function D(){}function R(){}function F(t){var e=[],r=new b;function n(){for(var r,n=e,i=-1,a=n.length;++i<a;)(r=n[i].on)&&r.apply(this,arguments);return t}return n.on=function(n,i){var a,o=r.get(n);return arguments.length<2?o&&o.on:(o&&(o.on=null,e=e.slice(0,a=e.indexOf(o)).concat(e.slice(a+1)),r.remove(n)),i&&e.push(r.set(n,{on:i})),t)},n}function B(){t.event.preventDefault()}function N(){for(var e,r=t.event;e=r.sourceEvent;)r=e;return r}function j(e){for(var r=new R,n=0,i=arguments.length;++n<i;)r[arguments[n]]=F(r);return r.of=function(n,i){return function(a){try{var o=a.sourceEvent=t.event;a.target=e,t.event=a,r[a.type].apply(n,i)}finally{t.event=o}}},r}t.dispatch=function(){for(var t=new R,e=-1,r=arguments.length;++e<r;)t[arguments[e]]=F(t);return t},R.prototype.on=function(t,e){var r=t.indexOf(\".\"),n=\"\";if(r>=0&&(n=t.slice(r+1),t=t.slice(0,r)),t)return arguments.length<2?this[t].on(n):this[t].on(n,e);if(2===arguments.length){if(null==e)for(t in this)this.hasOwnProperty(t)&&this[t].on(n,null);return this}},t.event=null,t.requote=function(t){return t.replace(U,\"\\\\$&\")};var U=/[\\\\\\^\\$\\*\\+\\?\\|\\[\\]\\(\\)\\.\\{\\}]/g,V={}.__proto__?function(t,e){t.__proto__=e}:function(t,e){for(var r in e)t[r]=e[r]};function q(t){return V(t,W),t}var H=function(t,e){return e.querySelector(t)},G=function(t,e){return e.querySelectorAll(t)},Y=function(t,e){var r=t.matches||t[z(t,\"matchesSelector\")];return(Y=function(t,e){return r.call(t,e)})(t,e)};\"function\"==typeof Sizzle&&(H=function(t,e){return Sizzle(t,e)[0]||null},G=Sizzle,Y=Sizzle.matchesSelector),t.selection=function(){return t.select(i.documentElement)};var W=t.selection.prototype=[];function X(t){return\"function\"==typeof t?t:function(){return H(t,this)}}function Z(t){return\"function\"==typeof t?t:function(){return G(t,this)}}W.select=function(t){var e,r,n,i,a=[];t=X(t);for(var o=-1,s=this.length;++o<s;){a.push(e=[]),e.parentNode=(n=this[o]).parentNode;for(var l=-1,c=n.length;++l<c;)(i=n[l])?(e.push(r=t.call(i,i.__data__,l,o)),r&&\"__data__\"in i&&(r.__data__=i.__data__)):e.push(null)}return q(a)},W.selectAll=function(t){var e,r,i=[];t=Z(t);for(var a=-1,o=this.length;++a<o;)for(var s=this[a],l=-1,c=s.length;++l<c;)(r=s[l])&&(i.push(e=n(t.call(r,r.__data__,l,a))),e.parentNode=r);return q(i)};var J=\"http://www.w3.org/1999/xhtml\",K={svg:\"http://www.w3.org/2000/svg\",xhtml:J,xlink:\"http://www.w3.org/1999/xlink\",xml:\"http://www.w3.org/XML/1998/namespace\",xmlns:\"http://www.w3.org/2000/xmlns/\"};function $(e,r){return e=t.ns.qualify(e),null==r?e.local?function(){this.removeAttributeNS(e.space,e.local)}:function(){this.removeAttribute(e)}:\"function\"==typeof r?e.local?function(){var t=r.apply(this,arguments);null==t?this.removeAttributeNS(e.space,e.local):this.setAttributeNS(e.space,e.local,t)}:function(){var t=r.apply(this,arguments);null==t?this.removeAttribute(e):this.setAttribute(e,t)}:e.local?function(){this.setAttributeNS(e.space,e.local,r)}:function(){this.setAttribute(e,r)}}function Q(t){return t.trim().replace(/\\s+/g,\" \")}function tt(e){return new RegExp(\"(?:^|\\\\s+)\"+t.requote(e)+\"(?:\\\\s+|$)\",\"g\")}function et(t){return(t+\"\").trim().split(/^|\\s+/)}function rt(t,e){var r=(t=et(t).map(nt)).length;return\"function\"==typeof e?function(){for(var n=-1,i=e.apply(this,arguments);++n<r;)t[n](this,i)}:function(){for(var n=-1;++n<r;)t[n](this,e)}}function nt(t){var e=tt(t);return function(r,n){if(i=r.classList)return n?i.add(t):i.remove(t);var i=r.getAttribute(\"class\")||\"\";n?(e.lastIndex=0,e.test(i)||r.setAttribute(\"class\",Q(i+\" \"+t))):r.setAttribute(\"class\",Q(i.replace(e,\" \")))}}function it(t,e,r){return null==e?function(){this.style.removeProperty(t)}:\"function\"==typeof e?function(){var n=e.apply(this,arguments);null==n?this.style.removeProperty(t):this.style.setProperty(t,n,r)}:function(){this.style.setProperty(t,e,r)}}function at(t,e){return null==e?function(){delete this[t]}:\"function\"==typeof e?function(){var r=e.apply(this,arguments);null==r?delete this[t]:this[t]=r}:function(){this[t]=e}}function ot(e){return\"function\"==typeof e?e:(e=t.ns.qualify(e)).local?function(){return this.ownerDocument.createElementNS(e.space,e.local)}:function(){var t=this.ownerDocument,r=this.namespaceURI;return r===J&&t.documentElement.namespaceURI===J?t.createElement(e):t.createElementNS(r,e)}}function st(){var t=this.parentNode;t&&t.removeChild(this)}function lt(t){return{__data__:t}}function ct(t){return function(){return Y(this,t)}}function ut(t,e){for(var r=0,n=t.length;r<n;r++)for(var i,a=t[r],o=0,s=a.length;o<s;o++)(i=a[o])&&e(i,o,r);return t}function ht(t){return V(t,ft),t}t.ns={prefix:K,qualify:function(t){var e=t.indexOf(\":\"),r=t;return e>=0&&\"xmlns\"!==(r=t.slice(0,e))&&(t=t.slice(e+1)),K.hasOwnProperty(r)?{space:K[r],local:t}:t}},W.attr=function(e,r){if(arguments.length<2){if(\"string\"==typeof e){var n=this.node();return(e=t.ns.qualify(e)).local?n.getAttributeNS(e.space,e.local):n.getAttribute(e)}for(r in e)this.each($(r,e[r]));return this}return this.each($(e,r))},W.classed=function(t,e){if(arguments.length<2){if(\"string\"==typeof t){var r=this.node(),n=(t=et(t)).length,i=-1;if(e=r.classList){for(;++i<n;)if(!e.contains(t[i]))return!1}else for(e=r.getAttribute(\"class\");++i<n;)if(!tt(t[i]).test(e))return!1;return!0}for(e in t)this.each(rt(e,t[e]));return this}return this.each(rt(t,e))},W.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.each(it(r,t[r],e));return this}if(n<2){var i=this.node();return o(i).getComputedStyle(i,null).getPropertyValue(t)}r=\"\"}return this.each(it(t,e,r))},W.property=function(t,e){if(arguments.length<2){if(\"string\"==typeof t)return this.node()[t];for(e in t)this.each(at(e,t[e]));return this}return this.each(at(t,e))},W.text=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.textContent=null==e?\"\":e}:null==t?function(){this.textContent=\"\"}:function(){this.textContent=t}):this.node().textContent},W.html=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.innerHTML=null==e?\"\":e}:null==t?function(){this.innerHTML=\"\"}:function(){this.innerHTML=t}):this.node().innerHTML},W.append=function(t){return t=ot(t),this.select(function(){return this.appendChild(t.apply(this,arguments))})},W.insert=function(t,e){return t=ot(t),e=X(e),this.select(function(){return this.insertBefore(t.apply(this,arguments),e.apply(this,arguments)||null)})},W.remove=function(){return this.each(st)},W.data=function(t,e){var r,n,i=-1,a=this.length;if(!arguments.length){for(t=new Array(a=(r=this[0]).length);++i<a;)(n=r[i])&&(t[i]=n.__data__);return t}function o(t,r){var n,i,a,o=t.length,u=r.length,h=Math.min(o,u),f=new Array(u),p=new Array(u),d=new Array(o);if(e){var g,v=new b,m=new Array(o);for(n=-1;++n<o;)(i=t[n])&&(v.has(g=e.call(i,i.__data__,n))?d[n]=i:v.set(g,i),m[n]=g);for(n=-1;++n<u;)(i=v.get(g=e.call(r,a=r[n],n)))?!0!==i&&(f[n]=i,i.__data__=a):p[n]=lt(a),v.set(g,!0);for(n=-1;++n<o;)n in m&&!0!==v.get(m[n])&&(d[n]=t[n])}else{for(n=-1;++n<h;)i=t[n],a=r[n],i?(i.__data__=a,f[n]=i):p[n]=lt(a);for(;n<u;++n)p[n]=lt(r[n]);for(;n<o;++n)d[n]=t[n]}p.update=f,p.parentNode=f.parentNode=d.parentNode=t.parentNode,s.push(p),l.push(f),c.push(d)}var s=ht([]),l=q([]),c=q([]);if(\"function\"==typeof t)for(;++i<a;)o(r=this[i],t.call(r,r.parentNode.__data__,i));else for(;++i<a;)o(r=this[i],t);return l.enter=function(){return s},l.exit=function(){return c},l},W.datum=function(t){return arguments.length?this.property(\"__data__\",t):this.property(\"__data__\")},W.filter=function(t){var e,r,n,i=[];\"function\"!=typeof t&&(t=ct(t));for(var a=0,o=this.length;a<o;a++){i.push(e=[]),e.parentNode=(r=this[a]).parentNode;for(var s=0,l=r.length;s<l;s++)(n=r[s])&&t.call(n,n.__data__,s,a)&&e.push(n)}return q(i)},W.order=function(){for(var t=-1,e=this.length;++t<e;)for(var r,n=this[t],i=n.length-1,a=n[i];--i>=0;)(r=n[i])&&(a&&a!==r.nextSibling&&a.parentNode.insertBefore(r,a),a=r);return this},W.sort=function(t){t=function(t){arguments.length||(t=f);return function(e,r){return e&&r?t(e.__data__,r.__data__):!e-!r}}.apply(this,arguments);for(var e=-1,r=this.length;++e<r;)this[e].sort(t);return this.order()},W.each=function(t){return ut(this,function(e,r,n){t.call(e,e.__data__,r,n)})},W.call=function(t){var e=n(arguments);return t.apply(e[0]=this,e),this},W.empty=function(){return!this.node()},W.node=function(){for(var t=0,e=this.length;t<e;t++)for(var r=this[t],n=0,i=r.length;n<i;n++){var a=r[n];if(a)return a}return null},W.size=function(){var t=0;return ut(this,function(){++t}),t};var ft=[];function pt(e,r,i){var a=\"__on\"+e,o=e.indexOf(\".\"),s=gt;o>0&&(e=e.slice(0,o));var l=dt.get(e);function c(){var t=this[a];t&&(this.removeEventListener(e,t,t.$),delete this[a])}return l&&(e=l,s=vt),o?r?function(){var t=s(r,n(arguments));c.call(this),this.addEventListener(e,this[a]=t,t.$=i),t._=r}:c:r?D:function(){var r,n=new RegExp(\"^__on([^.]+)\"+t.requote(e)+\"$\");for(var i in this)if(r=i.match(n)){var a=this[i];this.removeEventListener(r[1],a,a.$),delete this[i]}}}t.selection.enter=ht,t.selection.enter.prototype=ft,ft.append=W.append,ft.empty=W.empty,ft.node=W.node,ft.call=W.call,ft.size=W.size,ft.select=function(t){for(var e,r,n,i,a,o=[],s=-1,l=this.length;++s<l;){n=(i=this[s]).update,o.push(e=[]),e.parentNode=i.parentNode;for(var c=-1,u=i.length;++c<u;)(a=i[c])?(e.push(n[c]=r=t.call(i.parentNode,a.__data__,c,s)),r.__data__=a.__data__):e.push(null)}return q(o)},ft.insert=function(t,e){var r,n,i;return arguments.length<2&&(r=this,e=function(t,e,a){var o,s=r[a].update,l=s.length;for(a!=i&&(i=a,n=0),e>=n&&(n=e+1);!(o=s[n])&&++n<l;);return o}),W.insert.call(this,t,e)},t.select=function(t){var e;return\"string\"==typeof t?(e=[H(t,i)]).parentNode=i.documentElement:(e=[t]).parentNode=a(t),q([e])},t.selectAll=function(t){var e;return\"string\"==typeof t?(e=n(G(t,i))).parentNode=i.documentElement:(e=n(t)).parentNode=null,q([e])},W.on=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=!1),t)this.each(pt(r,t[r],e));return this}if(n<2)return(n=this.node()[\"__on\"+t])&&n._;r=!1}return this.each(pt(t,e,r))};var dt=t.map({mouseenter:\"mouseover\",mouseleave:\"mouseout\"});function gt(e,r){return function(n){var i=t.event;t.event=n,r[0]=this.__data__;try{e.apply(this,r)}finally{t.event=i}}}function vt(t,e){var r=gt(t,e);return function(t){var e=t.relatedTarget;e&&(e===this||8&e.compareDocumentPosition(this))||r.call(this,t)}}i&&dt.forEach(function(t){\"on\"+t in i&&dt.remove(t)});var mt,yt=0;function xt(e){var r=\".dragsuppress-\"+ ++yt,n=\"click\"+r,i=t.select(o(e)).on(\"touchmove\"+r,B).on(\"dragstart\"+r,B).on(\"selectstart\"+r,B);if(null==mt&&(mt=!(\"onselectstart\"in e)&&z(e.style,\"userSelect\")),mt){var s=a(e).style,l=s[mt];s[mt]=\"none\"}return function(t){if(i.on(r,null),mt&&(s[mt]=l),t){var e=function(){i.on(n,null)};i.on(n,function(){B(),e()},!0),setTimeout(e,0)}}}t.mouse=function(t){return _t(t,N())};var bt=this.navigator&&/WebKit/.test(this.navigator.userAgent)?-1:0;function _t(e,r){r.changedTouches&&(r=r.changedTouches[0]);var n=e.ownerSVGElement||e;if(n.createSVGPoint){var i=n.createSVGPoint();if(bt<0){var a=o(e);if(a.scrollX||a.scrollY){var s=(n=t.select(\"body\").append(\"svg\").style({position:\"absolute\",top:0,left:0,margin:0,padding:0,border:\"none\"},\"important\"))[0][0].getScreenCTM();bt=!(s.f||s.e),n.remove()}}return bt?(i.x=r.pageX,i.y=r.pageY):(i.x=r.clientX,i.y=r.clientY),[(i=i.matrixTransform(e.getScreenCTM().inverse())).x,i.y]}var l=e.getBoundingClientRect();return[r.clientX-l.left-e.clientLeft,r.clientY-l.top-e.clientTop]}function wt(){return t.event.changedTouches[0].identifier}t.touch=function(t,e,r){if(arguments.length<3&&(r=e,e=N().changedTouches),e)for(var n,i=0,a=e.length;i<a;++i)if((n=e[i]).identifier===r)return _t(t,n)},t.behavior.drag=function(){var e=j(a,\"drag\",\"dragstart\",\"dragend\"),r=null,n=s(D,t.mouse,o,\"mousemove\",\"mouseup\"),i=s(wt,t.touch,P,\"touchmove\",\"touchend\");function a(){this.on(\"mousedown.drag\",n).on(\"touchstart.drag\",i)}function s(n,i,a,o,s){return function(){var l,c=t.event.target.correspondingElement||t.event.target,u=this.parentNode,h=e.of(this,arguments),f=0,p=n(),d=\".drag\"+(null==p?\"\":\"-\"+p),g=t.select(a(c)).on(o+d,function(){var t,e,r=i(u,p);if(!r)return;t=r[0]-m[0],e=r[1]-m[1],f|=t|e,m=r,h({type:\"drag\",x:r[0]+l[0],y:r[1]+l[1],dx:t,dy:e})}).on(s+d,function(){if(!i(u,p))return;g.on(o+d,null).on(s+d,null),v(f),h({type:\"dragend\"})}),v=xt(c),m=i(u,p);l=r?[(l=r.apply(this,arguments)).x-m[0],l.y-m[1]]:[0,0],h({type:\"dragstart\"})}}return a.origin=function(t){return arguments.length?(r=t,a):r},t.rebind(a,e,\"on\")},t.touches=function(t,e){return arguments.length<2&&(e=N().touches),e?n(e).map(function(e){var r=_t(t,e);return r.identifier=e.identifier,r}):[]};var kt=1e-6,Tt=kt*kt,At=Math.PI,Mt=2*At,St=Mt-kt,Et=At/2,Ct=At/180,Lt=180/At;function Pt(t){return t>0?1:t<0?-1:0}function Ot(t,e,r){return(e[0]-t[0])*(r[1]-t[1])-(e[1]-t[1])*(r[0]-t[0])}function zt(t){return t>1?0:t<-1?At:Math.acos(t)}function It(t){return t>1?Et:t<-1?-Et:Math.asin(t)}function Dt(t){return((t=Math.exp(t))+1/t)/2}function Rt(t){return(t=Math.sin(t/2))*t}var Ft=Math.SQRT2;t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,h=l-a,f=u*u+h*h;if(f<Tt)n=Math.log(c/o)/Ft,r=function(t){return[i+t*u,a+t*h,o*Math.exp(Ft*t*n)]};else{var p=Math.sqrt(f),d=(c*c-o*o+4*f)/(2*o*2*p),g=(c*c-o*o-4*f)/(2*c*2*p),v=Math.log(Math.sqrt(d*d+1)-d),m=Math.log(Math.sqrt(g*g+1)-g);n=(m-v)/Ft,r=function(t){var e,r=t*n,s=Dt(v),l=o/(2*p)*(s*(e=Ft*r+v,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(v));return[i+l*u,a+l*h,o*s/Dt(Ft*r+v)]}}return r.duration=1e3*n,r},t.behavior.zoom=function(){var e,r,n,a,s,l,c,u,h,f={x:0,y:0,k:1},p=[960,500],d=jt,g=250,v=0,m=\"mousedown.zoom\",y=\"mousemove.zoom\",x=\"mouseup.zoom\",b=\"touchstart.zoom\",_=j(w,\"zoomstart\",\"zoom\",\"zoomend\");function w(t){t.on(m,P).on(Nt+\".zoom\",z).on(\"dblclick.zoom\",I).on(b,O)}function k(t){return[(t[0]-f.x)/f.k,(t[1]-f.y)/f.k]}function T(t){f.k=Math.max(d[0],Math.min(d[1],t))}function A(t,e){e=function(t){return[t[0]*f.k+f.x,t[1]*f.k+f.y]}(e),f.x+=t[0]-e[0],f.y+=t[1]-e[1]}function M(e,n,i,a){e.__chart__={x:f.x,y:f.y,k:f.k},T(Math.pow(2,a)),A(r=n,i),e=t.select(e),g>0&&(e=e.transition().duration(g)),e.call(w.event)}function S(){c&&c.domain(l.range().map(function(t){return(t-f.x)/f.k}).map(l.invert)),h&&h.domain(u.range().map(function(t){return(t-f.y)/f.k}).map(u.invert))}function E(t){v++||t({type:\"zoomstart\"})}function C(t){S(),t({type:\"zoom\",scale:f.k,translate:[f.x,f.y]})}function L(t){--v||(t({type:\"zoomend\"}),r=null)}function P(){var e=this,r=_.of(e,arguments),n=0,i=t.select(o(e)).on(y,function(){n=1,A(t.mouse(e),a),C(r)}).on(x,function(){i.on(y,null).on(x,null),s(n),L(r)}),a=k(t.mouse(e)),s=xt(e);hs.call(e),E(r)}function O(){var e,r=this,n=_.of(r,arguments),i={},a=0,o=\".zoom-\"+t.event.changedTouches[0].identifier,l=\"touchmove\"+o,c=\"touchend\"+o,u=[],h=t.select(r),p=xt(r);function d(){var n=t.touches(r);return e=f.k,n.forEach(function(t){t.identifier in i&&(i[t.identifier]=k(t))}),n}function g(){var e=t.event.target;t.select(e).on(l,v).on(c,y),u.push(e);for(var n=t.event.changedTouches,o=0,h=n.length;o<h;++o)i[n[o].identifier]=null;var p=d(),g=Date.now();if(1===p.length){if(g-s<500){var m=p[0];M(r,m,i[m.identifier],Math.floor(Math.log(f.k)/Math.LN2)+1),B()}s=g}else if(p.length>1){m=p[0];var x=p[1],b=m[0]-x[0],_=m[1]-x[1];a=b*b+_*_}}function v(){var o,l,c,u,h=t.touches(r);hs.call(r);for(var f=0,p=h.length;f<p;++f,u=null)if(c=h[f],u=i[c.identifier]){if(l)break;o=c,l=u}if(u){var d=(d=c[0]-o[0])*d+(d=c[1]-o[1])*d,g=a&&Math.sqrt(d/a);o=[(o[0]+c[0])/2,(o[1]+c[1])/2],l=[(l[0]+u[0])/2,(l[1]+u[1])/2],T(g*e)}s=null,A(o,l),C(n)}function y(){if(t.event.touches.length){for(var e=t.event.changedTouches,r=0,a=e.length;r<a;++r)delete i[e[r].identifier];for(var s in i)return void d()}t.selectAll(u).on(o,null),h.on(m,P).on(b,O),p(),L(n)}g(),E(n),h.on(m,null).on(b,g)}function z(){var i=_.of(this,arguments);a?clearTimeout(a):(hs.call(this),e=k(r=n||t.mouse(this)),E(i)),a=setTimeout(function(){a=null,L(i)},50),B(),T(Math.pow(2,.002*Bt())*f.k),A(r,e),C(i)}function I(){var e=t.mouse(this),r=Math.log(f.k)/Math.LN2;M(this,e,k(e),t.event.shiftKey?Math.ceil(r)-1:Math.floor(r)+1)}return Nt||(Nt=\"onwheel\"in i?(Bt=function(){return-t.event.deltaY*(t.event.deltaMode?120:1)},\"wheel\"):\"onmousewheel\"in i?(Bt=function(){return t.event.wheelDelta},\"mousewheel\"):(Bt=function(){return-t.event.detail},\"MozMousePixelScroll\")),w.event=function(e){e.each(function(){var e=_.of(this,arguments),n=f;ds?t.select(this).transition().each(\"start.zoom\",function(){f=this.__chart__||{x:0,y:0,k:1},E(e)}).tween(\"zoom:zoom\",function(){var i=p[0],a=p[1],o=r?r[0]:i/2,s=r?r[1]:a/2,l=t.interpolateZoom([(o-f.x)/f.k,(s-f.y)/f.k,i/f.k],[(o-n.x)/n.k,(s-n.y)/n.k,i/n.k]);return function(t){var r=l(t),n=i/r[2];this.__chart__=f={x:o-r[0]*n,y:s-r[1]*n,k:n},C(e)}}).each(\"interrupt.zoom\",function(){L(e)}).each(\"end.zoom\",function(){L(e)}):(this.__chart__=f,E(e),C(e),L(e))})},w.translate=function(t){return arguments.length?(f={x:+t[0],y:+t[1],k:f.k},S(),w):[f.x,f.y]},w.scale=function(t){return arguments.length?(f={x:f.x,y:f.y,k:null},T(+t),S(),w):f.k},w.scaleExtent=function(t){return arguments.length?(d=null==t?jt:[+t[0],+t[1]],w):d},w.center=function(t){return arguments.length?(n=t&&[+t[0],+t[1]],w):n},w.size=function(t){return arguments.length?(p=t&&[+t[0],+t[1]],w):p},w.duration=function(t){return arguments.length?(g=+t,w):g},w.x=function(t){return arguments.length?(c=t,l=t.copy(),f={x:0,y:0,k:1},w):c},w.y=function(t){return arguments.length?(h=t,u=t.copy(),f={x:0,y:0,k:1},w):h},t.rebind(w,_,\"on\")};var Bt,Nt,jt=[0,1/0];function Ut(){}function Vt(t,e,r){return this instanceof Vt?(this.h=+t,this.s=+e,void(this.l=+r)):arguments.length<2?t instanceof Vt?new Vt(t.h,t.s,t.l):ue(\"\"+t,he,Vt):new Vt(t,e,r)}t.color=Ut,Ut.prototype.toString=function(){return this.rgb()+\"\"},t.hsl=Vt;var qt=Vt.prototype=new Ut;function Ht(t,e,r){var n,i;function a(t){return Math.round(255*function(t){return t>360?t-=360:t<0&&(t+=360),t<60?n+(i-n)*t/60:t<180?i:t<240?n+(i-n)*(240-t)/60:n}(t))}return t=isNaN(t)?0:(t%=360)<0?t+360:t,e=isNaN(e)?0:e<0?0:e>1?1:e,n=2*(r=r<0?0:r>1?1:r)-(i=r<=.5?r*(1+e):r+e-r*e),new ae(a(t+120),a(t),a(t-120))}function Gt(e,r,n){return this instanceof Gt?(this.h=+e,this.c=+r,void(this.l=+n)):arguments.length<2?e instanceof Gt?new Gt(e.h,e.c,e.l):ee(e instanceof Xt?e.l:(e=fe((e=t.rgb(e)).r,e.g,e.b)).l,e.a,e.b):new Gt(e,r,n)}qt.brighter=function(t){return t=Math.pow(.7,arguments.length?t:1),new Vt(this.h,this.s,this.l/t)},qt.darker=function(t){return t=Math.pow(.7,arguments.length?t:1),new Vt(this.h,this.s,t*this.l)},qt.rgb=function(){return Ht(this.h,this.s,this.l)},t.hcl=Gt;var Yt=Gt.prototype=new Ut;function Wt(t,e,r){return isNaN(t)&&(t=0),isNaN(e)&&(e=0),new Xt(r,Math.cos(t*=Ct)*e,Math.sin(t)*e)}function Xt(t,e,r){return this instanceof Xt?(this.l=+t,this.a=+e,void(this.b=+r)):arguments.length<2?t instanceof Xt?new Xt(t.l,t.a,t.b):t instanceof Gt?Wt(t.h,t.c,t.l):fe((t=ae(t)).r,t.g,t.b):new Xt(t,e,r)}Yt.brighter=function(t){return new Gt(this.h,this.c,Math.min(100,this.l+Zt*(arguments.length?t:1)))},Yt.darker=function(t){return new Gt(this.h,this.c,Math.max(0,this.l-Zt*(arguments.length?t:1)))},Yt.rgb=function(){return Wt(this.h,this.c,this.l).rgb()},t.lab=Xt;var Zt=18,Jt=.95047,Kt=1,$t=1.08883,Qt=Xt.prototype=new Ut;function te(t,e,r){var n=(t+16)/116,i=n+e/500,a=n-r/200;return new ae(ie(3.2404542*(i=re(i)*Jt)-1.5371385*(n=re(n)*Kt)-.4985314*(a=re(a)*$t)),ie(-.969266*i+1.8760108*n+.041556*a),ie(.0556434*i-.2040259*n+1.0572252*a))}function ee(t,e,r){return t>0?new Gt(Math.atan2(r,e)*Lt,Math.sqrt(e*e+r*r),t):new Gt(NaN,NaN,t)}function re(t){return t>.206893034?t*t*t:(t-4/29)/7.787037}function ne(t){return t>.008856?Math.pow(t,1/3):7.787037*t+4/29}function ie(t){return Math.round(255*(t<=.00304?12.92*t:1.055*Math.pow(t,1/2.4)-.055))}function ae(t,e,r){return this instanceof ae?(this.r=~~t,this.g=~~e,void(this.b=~~r)):arguments.length<2?t instanceof ae?new ae(t.r,t.g,t.b):ue(\"\"+t,ae,Ht):new ae(t,e,r)}function oe(t){return new ae(t>>16,t>>8&255,255&t)}function se(t){return oe(t)+\"\"}Qt.brighter=function(t){return new Xt(Math.min(100,this.l+Zt*(arguments.length?t:1)),this.a,this.b)},Qt.darker=function(t){return new Xt(Math.max(0,this.l-Zt*(arguments.length?t:1)),this.a,this.b)},Qt.rgb=function(){return te(this.l,this.a,this.b)},t.rgb=ae;var le=ae.prototype=new Ut;function ce(t){return t<16?\"0\"+Math.max(0,t).toString(16):Math.min(255,t).toString(16)}function ue(t,e,r){var n,i,a,o=0,s=0,l=0;if(n=/([a-z]+)\\((.*)\\)/.exec(t=t.toLowerCase()))switch(i=n[2].split(\",\"),n[1]){case\"hsl\":return r(parseFloat(i[0]),parseFloat(i[1])/100,parseFloat(i[2])/100);case\"rgb\":return e(de(i[0]),de(i[1]),de(i[2]))}return(a=ge.get(t))?e(a.r,a.g,a.b):(null==t||\"#\"!==t.charAt(0)||isNaN(a=parseInt(t.slice(1),16))||(4===t.length?(o=(3840&a)>>4,o|=o>>4,s=240&a,s|=s>>4,l=15&a,l|=l<<4):7===t.length&&(o=(16711680&a)>>16,s=(65280&a)>>8,l=255&a)),e(o,s,l))}function he(t,e,r){var n,i,a=Math.min(t/=255,e/=255,r/=255),o=Math.max(t,e,r),s=o-a,l=(o+a)/2;return s?(i=l<.5?s/(o+a):s/(2-o-a),n=t==o?(e-r)/s+(e<r?6:0):e==o?(r-t)/s+2:(t-e)/s+4,n*=60):(n=NaN,i=l>0&&l<1?0:n),new Vt(n,i,l)}function fe(t,e,r){var n=ne((.4124564*(t=pe(t))+.3575761*(e=pe(e))+.1804375*(r=pe(r)))/Jt),i=ne((.2126729*t+.7151522*e+.072175*r)/Kt);return Xt(116*i-16,500*(n-i),200*(i-ne((.0193339*t+.119192*e+.9503041*r)/$t)))}function pe(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function de(t){var e=parseFloat(t);return\"%\"===t.charAt(t.length-1)?Math.round(2.55*e):e}le.brighter=function(t){t=Math.pow(.7,arguments.length?t:1);var e=this.r,r=this.g,n=this.b,i=30;return e||r||n?(e&&e<i&&(e=i),r&&r<i&&(r=i),n&&n<i&&(n=i),new ae(Math.min(255,e/t),Math.min(255,r/t),Math.min(255,n/t))):new ae(i,i,i)},le.darker=function(t){return new ae((t=Math.pow(.7,arguments.length?t:1))*this.r,t*this.g,t*this.b)},le.hsl=function(){return he(this.r,this.g,this.b)},le.toString=function(){return\"#\"+ce(this.r)+ce(this.g)+ce(this.b)};var ge=t.map({aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074});function ve(t){return\"function\"==typeof t?t:function(){return t}}function me(t){return function(e,r,n){return 2===arguments.length&&\"function\"==typeof r&&(n=r,r=null),ye(e,r,t,n)}}function ye(e,r,i,a){var o={},s=t.dispatch(\"beforesend\",\"progress\",\"load\",\"error\"),l={},c=new XMLHttpRequest,u=null;function h(){var t,e=c.status;if(!e&&function(t){var e=t.responseType;return e&&\"text\"!==e?t.response:t.responseText}(c)||e>=200&&e<300||304===e){try{t=i.call(o,c)}catch(t){return void s.error.call(o,t)}s.load.call(o,t)}else s.error.call(o,c)}return!this.XDomainRequest||\"withCredentials\"in c||!/^(http(s)?:)?\\/\\//.test(e)||(c=new XDomainRequest),\"onload\"in c?c.onload=c.onerror=h:c.onreadystatechange=function(){c.readyState>3&&h()},c.onprogress=function(e){var r=t.event;t.event=e;try{s.progress.call(o,c)}finally{t.event=r}},o.header=function(t,e){return t=(t+\"\").toLowerCase(),arguments.length<2?l[t]:(null==e?delete l[t]:l[t]=e+\"\",o)},o.mimeType=function(t){return arguments.length?(r=null==t?null:t+\"\",o):r},o.responseType=function(t){return arguments.length?(u=t,o):u},o.response=function(t){return i=t,o},[\"get\",\"post\"].forEach(function(t){o[t]=function(){return o.send.apply(o,[t].concat(n(arguments)))}}),o.send=function(t,n,i){if(2===arguments.length&&\"function\"==typeof n&&(i=n,n=null),c.open(t,e,!0),null==r||\"accept\"in l||(l.accept=r+\",*/*\"),c.setRequestHeader)for(var a in l)c.setRequestHeader(a,l[a]);return null!=r&&c.overrideMimeType&&c.overrideMimeType(r),null!=u&&(c.responseType=u),null!=i&&o.on(\"error\",i).on(\"load\",function(t){i(null,t)}),s.beforesend.call(o,c),c.send(null==n?null:n),o},o.abort=function(){return c.abort(),o},t.rebind(o,s,\"on\"),null==a?o:o.get(function(t){return 1===t.length?function(e,r){t(null==e?r:null)}:t}(a))}ge.forEach(function(t,e){ge.set(t,oe(e))}),t.functor=ve,t.xhr=me(P),t.dsv=function(t,e){var r=new RegExp('[\"'+t+\"\\n]\"),n=t.charCodeAt(0);function i(t,r,n){arguments.length<3&&(n=r,r=null);var i=ye(t,e,null==r?a:o(r),n);return i.row=function(t){return arguments.length?i.response(null==(r=t)?a:o(t)):r},i}function a(t){return i.parse(t.responseText)}function o(t){return function(e){return i.parse(e.responseText,t)}}function s(e){return e.map(l).join(t)}function l(t){return r.test(t)?'\"'+t.replace(/\\\"/g,'\"\"')+'\"':t}return i.parse=function(t,e){var r;return i.parseRows(t,function(t,n){if(r)return r(t,n-1);var i=new Function(\"d\",\"return {\"+t.map(function(t,e){return JSON.stringify(t)+\": d[\"+e+\"]\"}).join(\",\")+\"}\");r=e?function(t,r){return e(i(t),r)}:i})},i.parseRows=function(t,e){var r,i,a={},o={},s=[],l=t.length,c=0,u=0;function h(){if(c>=l)return o;if(i)return i=!1,a;var e=c;if(34===t.charCodeAt(e)){for(var r=e;r++<l;)if(34===t.charCodeAt(r)){if(34!==t.charCodeAt(r+1))break;++r}return c=r+2,13===(s=t.charCodeAt(r+1))?(i=!0,10===t.charCodeAt(r+2)&&++c):10===s&&(i=!0),t.slice(e+1,r).replace(/\"\"/g,'\"')}for(;c<l;){var s,u=1;if(10===(s=t.charCodeAt(c++)))i=!0;else if(13===s)i=!0,10===t.charCodeAt(c)&&(++c,++u);else if(s!==n)continue;return t.slice(e,c-u)}return t.slice(e)}for(;(r=h())!==o;){for(var f=[];r!==a&&r!==o;)f.push(r),r=h();e&&null==(f=e(f,u++))||s.push(f)}return s},i.format=function(e){if(Array.isArray(e[0]))return i.formatRows(e);var r=new L,n=[];return e.forEach(function(t){for(var e in t)r.has(e)||n.push(r.add(e))}),[n.map(l).join(t)].concat(e.map(function(e){return n.map(function(t){return l(e[t])}).join(t)})).join(\"\\n\")},i.formatRows=function(t){return t.map(s).join(\"\\n\")},i},t.csv=t.dsv(\",\",\"text/csv\"),t.tsv=t.dsv(\"\\t\",\"text/tab-separated-values\");var xe,be,_e,we,ke=this[z(this,\"requestAnimationFrame\")]||function(t){setTimeout(t,17)};function Te(t,e,r){var n=arguments.length;n<2&&(e=0),n<3&&(r=Date.now());var i={c:t,t:r+e,n:null};return be?be.n=i:xe=i,be=i,_e||(we=clearTimeout(we),_e=1,ke(Ae)),i}function Ae(){var t=Me(),e=Se()-t;e>24?(isFinite(e)&&(clearTimeout(we),we=setTimeout(Ae,e)),_e=0):(_e=1,ke(Ae))}function Me(){for(var t=Date.now(),e=xe;e;)t>=e.t&&e.c(t-e.t)&&(e.c=null),e=e.n;return t}function Se(){for(var t,e=xe,r=1/0;e;)e.c?(e.t<r&&(r=e.t),e=(t=e).n):e=t?t.n=e.n:xe=e.n;return be=t,r}function Ee(t,e){return e-(t?Math.ceil(Math.log(t)/Math.LN10):1)}t.timer=function(){Te.apply(this,arguments)},t.timer.flush=function(){Me(),Se()},t.round=function(t,e){return e?Math.round(t*(e=Math.pow(10,e)))/e:Math.round(t)};var Ce=[\"y\",\"z\",\"a\",\"f\",\"p\",\"n\",\"\\xb5\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\",\"P\",\"E\",\"Z\",\"Y\"].map(function(t,e){var r=Math.pow(10,3*y(8-e));return{scale:e>8?function(t){return t/r}:function(t){return t*r},symbol:t}});t.formatPrefix=function(e,r){var n=0;return(e=+e)&&(e<0&&(e*=-1),r&&(e=t.round(e,Ee(e,r))),n=1+Math.floor(1e-12+Math.log(e)/Math.LN10),n=Math.max(-24,Math.min(24,3*Math.floor((n-1)/3)))),Ce[8+n/3]};var Le=/(?:([^{])?([<>=^]))?([+\\- ])?([$#])?(0)?(\\d+)?(,)?(\\.-?\\d+)?([a-z%])?/i,Pe=t.map({b:function(t){return t.toString(2)},c:function(t){return String.fromCharCode(t)},o:function(t){return t.toString(8)},x:function(t){return t.toString(16)},X:function(t){return t.toString(16).toUpperCase()},g:function(t,e){return t.toPrecision(e)},e:function(t,e){return t.toExponential(e)},f:function(t,e){return t.toFixed(e)},r:function(e,r){return(e=t.round(e,Ee(e,r))).toFixed(Math.max(0,Math.min(20,Ee(e*(1+1e-15),r))))}});function Oe(t){return t+\"\"}var ze=t.time={},Ie=Date;function De(){this._=new Date(arguments.length>1?Date.UTC.apply(this,arguments):arguments[0])}De.prototype={getDate:function(){return this._.getUTCDate()},getDay:function(){return this._.getUTCDay()},getFullYear:function(){return this._.getUTCFullYear()},getHours:function(){return this._.getUTCHours()},getMilliseconds:function(){return this._.getUTCMilliseconds()},getMinutes:function(){return this._.getUTCMinutes()},getMonth:function(){return this._.getUTCMonth()},getSeconds:function(){return this._.getUTCSeconds()},getTime:function(){return this._.getTime()},getTimezoneOffset:function(){return 0},valueOf:function(){return this._.valueOf()},setDate:function(){Re.setUTCDate.apply(this._,arguments)},setDay:function(){Re.setUTCDay.apply(this._,arguments)},setFullYear:function(){Re.setUTCFullYear.apply(this._,arguments)},setHours:function(){Re.setUTCHours.apply(this._,arguments)},setMilliseconds:function(){Re.setUTCMilliseconds.apply(this._,arguments)},setMinutes:function(){Re.setUTCMinutes.apply(this._,arguments)},setMonth:function(){Re.setUTCMonth.apply(this._,arguments)},setSeconds:function(){Re.setUTCSeconds.apply(this._,arguments)},setTime:function(){Re.setTime.apply(this._,arguments)}};var Re=Date.prototype;function Fe(t,e,r){function n(e){var r=t(e),n=a(r,1);return e-r<n-e?r:n}function i(r){return e(r=t(new Ie(r-1)),1),r}function a(t,r){return e(t=new Ie(+t),r),t}function o(t,n,a){var o=i(t),s=[];if(a>1)for(;o<n;)r(o)%a||s.push(new Date(+o)),e(o,1);else for(;o<n;)s.push(new Date(+o)),e(o,1);return s}t.floor=t,t.round=n,t.ceil=i,t.offset=a,t.range=o;var s=t.utc=Be(t);return s.floor=s,s.round=Be(n),s.ceil=Be(i),s.offset=Be(a),s.range=function(t,e,r){try{Ie=De;var n=new De;return n._=t,o(n,e,r)}finally{Ie=Date}},t}function Be(t){return function(e,r){try{Ie=De;var n=new De;return n._=e,t(n,r)._}finally{Ie=Date}}}ze.year=Fe(function(t){return(t=ze.day(t)).setMonth(0,1),t},function(t,e){t.setFullYear(t.getFullYear()+e)},function(t){return t.getFullYear()}),ze.years=ze.year.range,ze.years.utc=ze.year.utc.range,ze.day=Fe(function(t){var e=new Ie(2e3,0);return e.setFullYear(t.getFullYear(),t.getMonth(),t.getDate()),e},function(t,e){t.setDate(t.getDate()+e)},function(t){return t.getDate()-1}),ze.days=ze.day.range,ze.days.utc=ze.day.utc.range,ze.dayOfYear=function(t){var e=ze.year(t);return Math.floor((t-e-6e4*(t.getTimezoneOffset()-e.getTimezoneOffset()))/864e5)},[\"sunday\",\"monday\",\"tuesday\",\"wednesday\",\"thursday\",\"friday\",\"saturday\"].forEach(function(t,e){e=7-e;var r=ze[t]=Fe(function(t){return(t=ze.day(t)).setDate(t.getDate()-(t.getDay()+e)%7),t},function(t,e){t.setDate(t.getDate()+7*Math.floor(e))},function(t){var r=ze.year(t).getDay();return Math.floor((ze.dayOfYear(t)+(r+e)%7)/7)-(r!==e)});ze[t+\"s\"]=r.range,ze[t+\"s\"].utc=r.utc.range,ze[t+\"OfYear\"]=function(t){var r=ze.year(t).getDay();return Math.floor((ze.dayOfYear(t)+(r+e)%7)/7)}}),ze.week=ze.sunday,ze.weeks=ze.sunday.range,ze.weeks.utc=ze.sunday.utc.range,ze.weekOfYear=ze.sundayOfYear;var Ne={\"-\":\"\",_:\" \",0:\"0\"},je=/^\\s*\\d+/,Ue=/^%/;function Ve(t,e,r){var n=t<0?\"-\":\"\",i=(n?-t:t)+\"\",a=i.length;return n+(a<r?new Array(r-a+1).join(e)+i:i)}function qe(e){return new RegExp(\"^(?:\"+e.map(t.requote).join(\"|\")+\")\",\"i\")}function He(t){for(var e=new b,r=-1,n=t.length;++r<n;)e.set(t[r].toLowerCase(),r);return e}function Ge(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+1));return n?(t.w=+n[0],r+n[0].length):-1}function Ye(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.U=+n[0],r+n[0].length):-1}function We(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.W=+n[0],r+n[0].length):-1}function Xe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+4));return n?(t.y=+n[0],r+n[0].length):-1}function Ze(t,e,r){je.lastIndex=0;var n,i=je.exec(e.slice(r,r+2));return i?(t.y=(n=+i[0])+(n>68?1900:2e3),r+i[0].length):-1}function Je(t,e,r){return/^[+-]\\d{4}$/.test(e=e.slice(r,r+5))?(t.Z=-e,r+5):-1}function Ke(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.m=n[0]-1,r+n[0].length):-1}function $e(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.d=+n[0],r+n[0].length):-1}function Qe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.j=+n[0],r+n[0].length):-1}function tr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.H=+n[0],r+n[0].length):-1}function er(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.M=+n[0],r+n[0].length):-1}function rr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.S=+n[0],r+n[0].length):-1}function nr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.L=+n[0],r+n[0].length):-1}function ir(t){var e=t.getTimezoneOffset(),r=e>0?\"-\":\"+\",n=y(e)/60|0,i=y(e)%60;return r+Ve(n,\"0\",2)+Ve(i,\"0\",2)}function ar(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r,r+1));return n?r+n[0].length:-1}function or(t){for(var e=t.length,r=-1;++r<e;)t[r][0]=this(t[r][0]);return function(e){for(var r=0,n=t[r];!n[1](e);)n=t[++r];return n[0](e)}}t.locale=function(e){return{numberFormat:function(e){var r=e.decimal,n=e.thousands,i=e.grouping,a=e.currency,o=i&&n?function(t,e){for(var r=t.length,a=[],o=0,s=i[0],l=0;r>0&&s>0&&(l+s+1>e&&(s=Math.max(1,e-l)),a.push(t.substring(r-=s,r+s)),!((l+=s+1)>e));)s=i[o=(o+1)%i.length];return a.reverse().join(n)}:P;return function(e){var n=Le.exec(e),i=n[1]||\" \",s=n[2]||\">\",l=n[3]||\"-\",c=n[4]||\"\",u=n[5],h=+n[6],f=n[7],p=n[8],d=n[9],g=1,v=\"\",m=\"\",y=!1,x=!0;switch(p&&(p=+p.substring(1)),(u||\"0\"===i&&\"=\"===s)&&(u=i=\"0\",s=\"=\"),d){case\"n\":f=!0,d=\"g\";break;case\"%\":g=100,m=\"%\",d=\"f\";break;case\"p\":g=100,m=\"%\",d=\"r\";break;case\"b\":case\"o\":case\"x\":case\"X\":\"#\"===c&&(v=\"0\"+d.toLowerCase());case\"c\":x=!1;case\"d\":y=!0,p=0;break;case\"s\":g=-1,d=\"r\"}\"$\"===c&&(v=a[0],m=a[1]),\"r\"!=d||p||(d=\"g\"),null!=p&&(\"g\"==d?p=Math.max(1,Math.min(21,p)):\"e\"!=d&&\"f\"!=d||(p=Math.max(0,Math.min(20,p)))),d=Pe.get(d)||Oe;var b=u&&f;return function(e){var n=m;if(y&&e%1)return\"\";var a=e<0||0===e&&1/e<0?(e=-e,\"-\"):\"-\"===l?\"\":l;if(g<0){var c=t.formatPrefix(e,p);e=c.scale(e),n=c.symbol+m}else e*=g;var _,w,k=(e=d(e,p)).lastIndexOf(\".\");if(k<0){var T=x?e.lastIndexOf(\"e\"):-1;T<0?(_=e,w=\"\"):(_=e.substring(0,T),w=e.substring(T))}else _=e.substring(0,k),w=r+e.substring(k+1);!u&&f&&(_=o(_,1/0));var A=v.length+_.length+w.length+(b?0:a.length),M=A<h?new Array(A=h-A+1).join(i):\"\";return b&&(_=o(M+_,M.length?h-w.length:1/0)),a+=v,e=_+w,(\"<\"===s?a+e+M:\">\"===s?M+a+e:\"^\"===s?M.substring(0,A>>=1)+a+e+M.substring(A):a+(b?e:M+e))+n}}}(e),timeFormat:function(e){var r=e.dateTime,n=e.date,i=e.time,a=e.periods,o=e.days,s=e.shortDays,l=e.months,c=e.shortMonths;function u(t){var e=t.length;function r(r){for(var n,i,a,o=[],s=-1,l=0;++s<e;)37===t.charCodeAt(s)&&(o.push(t.slice(l,s)),null!=(i=Ne[n=t.charAt(++s)])&&(n=t.charAt(++s)),(a=_[n])&&(n=a(r,null==i?\"e\"===n?\" \":\"0\":i)),o.push(n),l=s+1);return o.push(t.slice(l,s)),o.join(\"\")}return r.parse=function(e){var r={y:1900,m:0,d:1,H:0,M:0,S:0,L:0,Z:null};if(h(r,t,e,0)!=e.length)return null;\"p\"in r&&(r.H=r.H%12+12*r.p);var n=null!=r.Z&&Ie!==De,i=new(n?De:Ie);return\"j\"in r?i.setFullYear(r.y,0,r.j):\"W\"in r||\"U\"in r?(\"w\"in r||(r.w=\"W\"in r?1:0),i.setFullYear(r.y,0,1),i.setFullYear(r.y,0,\"W\"in r?(r.w+6)%7+7*r.W-(i.getDay()+5)%7:r.w+7*r.U-(i.getDay()+6)%7)):i.setFullYear(r.y,r.m,r.d),i.setHours(r.H+(r.Z/100|0),r.M+r.Z%100,r.S,r.L),n?i._:i},r.toString=function(){return t},r}function h(t,e,r,n){for(var i,a,o,s=0,l=e.length,c=r.length;s<l;){if(n>=c)return-1;if(37===(i=e.charCodeAt(s++))){if(o=e.charAt(s++),!(a=w[o in Ne?e.charAt(s++):o])||(n=a(t,r,n))<0)return-1}else if(i!=r.charCodeAt(n++))return-1}return n}u.utc=function(t){var e=u(t);function r(t){try{var r=new(Ie=De);return r._=t,e(r)}finally{Ie=Date}}return r.parse=function(t){try{Ie=De;var r=e.parse(t);return r&&r._}finally{Ie=Date}},r.toString=e.toString,r},u.multi=u.utc.multi=or;var f=t.map(),p=qe(o),d=He(o),g=qe(s),v=He(s),m=qe(l),y=He(l),x=qe(c),b=He(c);a.forEach(function(t,e){f.set(t.toLowerCase(),e)});var _={a:function(t){return s[t.getDay()]},A:function(t){return o[t.getDay()]},b:function(t){return c[t.getMonth()]},B:function(t){return l[t.getMonth()]},c:u(r),d:function(t,e){return Ve(t.getDate(),e,2)},e:function(t,e){return Ve(t.getDate(),e,2)},H:function(t,e){return Ve(t.getHours(),e,2)},I:function(t,e){return Ve(t.getHours()%12||12,e,2)},j:function(t,e){return Ve(1+ze.dayOfYear(t),e,3)},L:function(t,e){return Ve(t.getMilliseconds(),e,3)},m:function(t,e){return Ve(t.getMonth()+1,e,2)},M:function(t,e){return Ve(t.getMinutes(),e,2)},p:function(t){return a[+(t.getHours()>=12)]},S:function(t,e){return Ve(t.getSeconds(),e,2)},U:function(t,e){return Ve(ze.sundayOfYear(t),e,2)},w:function(t){return t.getDay()},W:function(t,e){return Ve(ze.mondayOfYear(t),e,2)},x:u(n),X:u(i),y:function(t,e){return Ve(t.getFullYear()%100,e,2)},Y:function(t,e){return Ve(t.getFullYear()%1e4,e,4)},Z:ir,\"%\":function(){return\"%\"}},w={a:function(t,e,r){g.lastIndex=0;var n=g.exec(e.slice(r));return n?(t.w=v.get(n[0].toLowerCase()),r+n[0].length):-1},A:function(t,e,r){p.lastIndex=0;var n=p.exec(e.slice(r));return n?(t.w=d.get(n[0].toLowerCase()),r+n[0].length):-1},b:function(t,e,r){x.lastIndex=0;var n=x.exec(e.slice(r));return n?(t.m=b.get(n[0].toLowerCase()),r+n[0].length):-1},B:function(t,e,r){m.lastIndex=0;var n=m.exec(e.slice(r));return n?(t.m=y.get(n[0].toLowerCase()),r+n[0].length):-1},c:function(t,e,r){return h(t,_.c.toString(),e,r)},d:$e,e:$e,H:tr,I:tr,j:Qe,L:nr,m:Ke,M:er,p:function(t,e,r){var n=f.get(e.slice(r,r+=2).toLowerCase());return null==n?-1:(t.p=n,r)},S:rr,U:Ye,w:Ge,W:We,x:function(t,e,r){return h(t,_.x.toString(),e,r)},X:function(t,e,r){return h(t,_.X.toString(),e,r)},y:Ze,Y:Xe,Z:Je,\"%\":ar};return u}(e)}};var sr=t.locale({decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],dateTime:\"%a %b %e %X %Y\",date:\"%m/%d/%Y\",time:\"%H:%M:%S\",periods:[\"AM\",\"PM\"],days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"]});function lr(){}t.format=sr.numberFormat,t.geo={},lr.prototype={s:0,t:0,add:function(t){ur(t,this.t,cr),ur(cr.s,this.s,this),this.s?this.t+=cr.t:this.s=cr.t},reset:function(){this.s=this.t=0},valueOf:function(){return this.s}};var cr=new lr;function ur(t,e,r){var n=r.s=t+e,i=n-t,a=n-i;r.t=t-a+(e-i)}function hr(t,e){t&&pr.hasOwnProperty(t.type)&&pr[t.type](t,e)}t.geo.stream=function(t,e){t&&fr.hasOwnProperty(t.type)?fr[t.type](t,e):hr(t,e)};var fr={Feature:function(t,e){hr(t.geometry,e)},FeatureCollection:function(t,e){for(var r=t.features,n=-1,i=r.length;++n<i;)hr(r[n].geometry,e)}},pr={Sphere:function(t,e){e.sphere()},Point:function(t,e){t=t.coordinates,e.point(t[0],t[1],t[2])},MultiPoint:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)t=r[n],e.point(t[0],t[1],t[2])},LineString:function(t,e){dr(t.coordinates,e,0)},MultiLineString:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)dr(r[n],e,0)},Polygon:function(t,e){gr(t.coordinates,e)},MultiPolygon:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)gr(r[n],e)},GeometryCollection:function(t,e){for(var r=t.geometries,n=-1,i=r.length;++n<i;)hr(r[n],e)}};function dr(t,e,r){var n,i=-1,a=t.length-r;for(e.lineStart();++i<a;)n=t[i],e.point(n[0],n[1],n[2]);e.lineEnd()}function gr(t,e){var r=-1,n=t.length;for(e.polygonStart();++r<n;)dr(t[r],e,1);e.polygonEnd()}t.geo.area=function(e){return vr=0,t.geo.stream(e,Cr),vr};var vr,mr,yr,xr,br,_r,wr,kr,Tr,Ar,Mr,Sr,Er=new lr,Cr={sphere:function(){vr+=4*At},point:D,lineStart:D,lineEnd:D,polygonStart:function(){Er.reset(),Cr.lineStart=Lr},polygonEnd:function(){var t=2*Er;vr+=t<0?4*At+t:t,Cr.lineStart=Cr.lineEnd=Cr.point=D}};function Lr(){var t,e,r,n,i;function a(t,e){e=e*Ct/2+At/4;var a=(t*=Ct)-r,o=a>=0?1:-1,s=o*a,l=Math.cos(e),c=Math.sin(e),u=i*c,h=n*l+u*Math.cos(s),f=u*o*Math.sin(s);Er.add(Math.atan2(f,h)),r=t,n=l,i=c}Cr.point=function(o,s){Cr.point=a,r=(t=o)*Ct,n=Math.cos(s=(e=s)*Ct/2+At/4),i=Math.sin(s)},Cr.lineEnd=function(){a(t,e)}}function Pr(t){var e=t[0],r=t[1],n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}function Or(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}function zr(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}function Ir(t,e){t[0]+=e[0],t[1]+=e[1],t[2]+=e[2]}function Dr(t,e){return[t[0]*e,t[1]*e,t[2]*e]}function Rr(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]+t[2]*t[2]);t[0]/=e,t[1]/=e,t[2]/=e}function Fr(t){return[Math.atan2(t[1],t[0]),It(t[2])]}function Br(t,e){return y(t[0]-e[0])<kt&&y(t[1]-e[1])<kt}t.geo.bounds=function(){var e,r,n,i,a,o,s,l,c,u,h,f={point:p,lineStart:g,lineEnd:v,polygonStart:function(){f.point=m,f.lineStart=x,f.lineEnd=b,c=0,Cr.polygonStart()},polygonEnd:function(){Cr.polygonEnd(),f.point=p,f.lineStart=g,f.lineEnd=v,Er<0?(e=-(n=180),r=-(i=90)):c>kt?i=90:c<-kt&&(r=-90),h[0]=e,h[1]=n}};function p(t,a){u.push(h=[e=t,n=t]),a<r&&(r=a),a>i&&(i=a)}function d(t,o){var s=Pr([t*Ct,o*Ct]);if(l){var c=zr(l,s),u=zr([c[1],-c[0],0],c);Rr(u),u=Fr(u);var h=t-a,f=h>0?1:-1,d=u[0]*Lt*f,g=y(h)>180;if(g^(f*a<d&&d<f*t))(v=u[1]*Lt)>i&&(i=v);else if(g^(f*a<(d=(d+360)%360-180)&&d<f*t)){var v;(v=-u[1]*Lt)<r&&(r=v)}else o<r&&(r=o),o>i&&(i=o);g?t<a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t):n>=e?(t<e&&(e=t),t>n&&(n=t)):t>a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t)}else p(t,o);l=s,a=t}function g(){f.point=d}function v(){h[0]=e,h[1]=n,f.point=p,l=null}function m(t,e){if(l){var r=t-a;c+=y(r)>180?r+(r>0?360:-360):r}else o=t,s=e;Cr.point(t,e),d(t,e)}function x(){Cr.lineStart()}function b(){m(o,s),Cr.lineEnd(),y(c)>kt&&(e=-(n=180)),h[0]=e,h[1]=n,l=null}function _(t,e){return(e-=t)<0?e+360:e}function w(t,e){return t[0]-e[0]}function k(t,e){return e[0]<=e[1]?e[0]<=t&&t<=e[1]:t<e[0]||e[1]<t}return function(a){if(i=n=-(e=r=1/0),u=[],t.geo.stream(a,f),c=u.length){u.sort(w);for(var o=1,s=[g=u[0]];o<c;++o)k((p=u[o])[0],g)||k(p[1],g)?(_(g[0],p[1])>_(g[0],g[1])&&(g[1]=p[1]),_(p[0],g[1])>_(g[0],g[1])&&(g[0]=p[0])):s.push(g=p);for(var l,c,p,d=-1/0,g=(o=0,s[c=s.length-1]);o<=c;g=p,++o)p=s[o],(l=_(g[1],p[0]))>d&&(d=l,e=p[0],n=g[1])}return u=h=null,e===1/0||r===1/0?[[NaN,NaN],[NaN,NaN]]:[[e,r],[n,i]]}}(),t.geo.centroid=function(e){mr=yr=xr=br=_r=wr=kr=Tr=Ar=Mr=Sr=0,t.geo.stream(e,Nr);var r=Ar,n=Mr,i=Sr,a=r*r+n*n+i*i;return a<Tt&&(r=wr,n=kr,i=Tr,yr<kt&&(r=xr,n=br,i=_r),(a=r*r+n*n+i*i)<Tt)?[NaN,NaN]:[Math.atan2(n,r)*Lt,It(i/Math.sqrt(a))*Lt]};var Nr={sphere:D,point:jr,lineStart:Vr,lineEnd:qr,polygonStart:function(){Nr.lineStart=Hr},polygonEnd:function(){Nr.lineStart=Vr}};function jr(t,e){t*=Ct;var r=Math.cos(e*=Ct);Ur(r*Math.cos(t),r*Math.sin(t),Math.sin(e))}function Ur(t,e,r){xr+=(t-xr)/++mr,br+=(e-br)/mr,_r+=(r-_r)/mr}function Vr(){var t,e,r;function n(n,i){n*=Ct;var a=Math.cos(i*=Ct),o=a*Math.cos(n),s=a*Math.sin(n),l=Math.sin(i),c=Math.atan2(Math.sqrt((c=e*l-r*s)*c+(c=r*o-t*l)*c+(c=t*s-e*o)*c),t*o+e*s+r*l);yr+=c,wr+=c*(t+(t=o)),kr+=c*(e+(e=s)),Tr+=c*(r+(r=l)),Ur(t,e,r)}Nr.point=function(i,a){i*=Ct;var o=Math.cos(a*=Ct);t=o*Math.cos(i),e=o*Math.sin(i),r=Math.sin(a),Nr.point=n,Ur(t,e,r)}}function qr(){Nr.point=jr}function Hr(){var t,e,r,n,i;function a(t,e){t*=Ct;var a=Math.cos(e*=Ct),o=a*Math.cos(t),s=a*Math.sin(t),l=Math.sin(e),c=n*l-i*s,u=i*o-r*l,h=r*s-n*o,f=Math.sqrt(c*c+u*u+h*h),p=r*o+n*s+i*l,d=f&&-zt(p)/f,g=Math.atan2(f,p);Ar+=d*c,Mr+=d*u,Sr+=d*h,yr+=g,wr+=g*(r+(r=o)),kr+=g*(n+(n=s)),Tr+=g*(i+(i=l)),Ur(r,n,i)}Nr.point=function(o,s){t=o,e=s,Nr.point=a,o*=Ct;var l=Math.cos(s*=Ct);r=l*Math.cos(o),n=l*Math.sin(o),i=Math.sin(s),Ur(r,n,i)},Nr.lineEnd=function(){a(t,e),Nr.lineEnd=qr,Nr.point=jr}}function Gr(t,e){function r(r,n){return r=t(r,n),e(r[0],r[1])}return t.invert&&e.invert&&(r.invert=function(r,n){return(r=e.invert(r,n))&&t.invert(r[0],r[1])}),r}function Yr(){return!0}function Wr(t,e,r,n,i){var a=[],o=[];if(t.forEach(function(t){if(!((e=t.length-1)<=0)){var e,r=t[0],n=t[e];if(Br(r,n)){i.lineStart();for(var s=0;s<e;++s)i.point((r=t[s])[0],r[1]);i.lineEnd()}else{var l=new Zr(r,t,null,!0),c=new Zr(r,null,l,!1);l.o=c,a.push(l),o.push(c),l=new Zr(n,t,null,!1),c=new Zr(n,null,l,!0),l.o=c,a.push(l),o.push(c)}}}),o.sort(e),Xr(a),Xr(o),a.length){for(var s=0,l=r,c=o.length;s<c;++s)o[s].e=l=!l;for(var u,h,f=a[0];;){for(var p=f,d=!0;p.v;)if((p=p.n)===f)return;u=p.z,i.lineStart();do{if(p.v=p.o.v=!0,p.e){if(d)for(s=0,c=u.length;s<c;++s)i.point((h=u[s])[0],h[1]);else n(p.x,p.n.x,1,i);p=p.n}else{if(d)for(s=(u=p.p.z).length-1;s>=0;--s)i.point((h=u[s])[0],h[1]);else n(p.x,p.p.x,-1,i);p=p.p}u=(p=p.o).z,d=!d}while(!p.v);i.lineEnd()}}}function Xr(t){if(e=t.length){for(var e,r,n=0,i=t[0];++n<e;)i.n=r=t[n],r.p=i,i=r;i.n=r=t[0],r.p=i}}function Zr(t,e,r,n){this.x=t,this.z=e,this.o=r,this.e=n,this.v=!1,this.n=this.p=null}function Jr(e,r,n,i){return function(a,o){var s,l=r(o),c=a.invert(i[0],i[1]),u={point:h,lineStart:p,lineEnd:d,polygonStart:function(){u.point=b,u.lineStart=_,u.lineEnd=w,s=[],g=[]},polygonEnd:function(){u.point=h,u.lineStart=p,u.lineEnd=d,s=t.merge(s);var e=function(t,e){var r=t[0],n=t[1],i=[Math.sin(r),-Math.cos(r),0],a=0,o=0;Er.reset();for(var s=0,l=e.length;s<l;++s){var c=e[s],u=c.length;if(u)for(var h=c[0],f=h[0],p=h[1]/2+At/4,d=Math.sin(p),g=Math.cos(p),v=1;;){v===u&&(v=0);var m=(t=c[v])[0],y=t[1]/2+At/4,x=Math.sin(y),b=Math.cos(y),_=m-f,w=_>=0?1:-1,k=w*_,T=k>At,A=d*x;if(Er.add(Math.atan2(A*w*Math.sin(k),g*b+A*Math.cos(k))),a+=T?_+w*Mt:_,T^f>=r^m>=r){var M=zr(Pr(h),Pr(t));Rr(M);var S=zr(i,M);Rr(S);var E=(T^_>=0?-1:1)*It(S[2]);(n>E||n===E&&(M[0]||M[1]))&&(o+=T^_>=0?1:-1)}if(!v++)break;f=m,d=x,g=b,h=t}}return(a<-kt||a<kt&&Er<-kt)^1&o}(c,g);s.length?(x||(o.polygonStart(),x=!0),Wr(s,Qr,e,n,o)):e&&(x||(o.polygonStart(),x=!0),o.lineStart(),n(null,null,1,o),o.lineEnd()),x&&(o.polygonEnd(),x=!1),s=g=null},sphere:function(){o.polygonStart(),o.lineStart(),n(null,null,1,o),o.lineEnd(),o.polygonEnd()}};function h(t,r){var n=a(t,r);e(t=n[0],r=n[1])&&o.point(t,r)}function f(t,e){var r=a(t,e);l.point(r[0],r[1])}function p(){u.point=f,l.lineStart()}function d(){u.point=h,l.lineEnd()}var g,v,m=$r(),y=r(m),x=!1;function b(t,e){v.push([t,e]);var r=a(t,e);y.point(r[0],r[1])}function _(){y.lineStart(),v=[]}function w(){b(v[0][0],v[0][1]),y.lineEnd();var t,e=y.clean(),r=m.buffer(),n=r.length;if(v.pop(),g.push(v),v=null,n)if(1&e){var i,a=-1;if((n=(t=r[0]).length-1)>0){for(x||(o.polygonStart(),x=!0),o.lineStart();++a<n;)o.point((i=t[a])[0],i[1]);o.lineEnd()}}else n>1&&2&e&&r.push(r.pop().concat(r.shift())),s.push(r.filter(Kr))}return u}}function Kr(t){return t.length>1}function $r(){var t,e=[];return{lineStart:function(){e.push(t=[])},point:function(e,r){t.push([e,r])},lineEnd:D,buffer:function(){var r=e;return e=[],t=null,r},rejoin:function(){e.length>1&&e.push(e.pop().concat(e.shift()))}}}function Qr(t,e){return((t=t.x)[0]<0?t[1]-Et-kt:Et-t[1])-((e=e.x)[0]<0?e[1]-Et-kt:Et-e[1])}var tn=Jr(Yr,function(t){var e,r=NaN,n=NaN,i=NaN;return{lineStart:function(){t.lineStart(),e=1},point:function(a,o){var s=a>0?At:-At,l=y(a-r);y(l-At)<kt?(t.point(r,n=(n+o)/2>0?Et:-Et),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),t.point(a,n),e=0):i!==s&&l>=At&&(y(r-i)<kt&&(r-=i*kt),y(a-s)<kt&&(a-=s*kt),n=function(t,e,r,n){var i,a,o=Math.sin(t-r);return y(o)>kt?Math.atan((Math.sin(e)*(a=Math.cos(n))*Math.sin(r)-Math.sin(n)*(i=Math.cos(e))*Math.sin(t))/(i*a*o)):(e+n)/2}(r,n,a,o),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),e=0),t.point(r=a,n=o),i=s},lineEnd:function(){t.lineEnd(),r=n=NaN},clean:function(){return 2-e}}},function(t,e,r,n){var i;if(null==t)i=r*Et,n.point(-At,i),n.point(0,i),n.point(At,i),n.point(At,0),n.point(At,-i),n.point(0,-i),n.point(-At,-i),n.point(-At,0),n.point(-At,i);else if(y(t[0]-e[0])>kt){var a=t[0]<e[0]?At:-At;i=r*a/2,n.point(-a,i),n.point(0,i),n.point(a,i)}else n.point(e[0],e[1])},[-At,-At/2]);function en(t,e,r,n){return function(i){var a,o=i.a,s=i.b,l=o.x,c=o.y,u=0,h=1,f=s.x-l,p=s.y-c;if(a=t-l,f||!(a>0)){if(a/=f,f<0){if(a<u)return;a<h&&(h=a)}else if(f>0){if(a>h)return;a>u&&(u=a)}if(a=r-l,f||!(a<0)){if(a/=f,f<0){if(a>h)return;a>u&&(u=a)}else if(f>0){if(a<u)return;a<h&&(h=a)}if(a=e-c,p||!(a>0)){if(a/=p,p<0){if(a<u)return;a<h&&(h=a)}else if(p>0){if(a>h)return;a>u&&(u=a)}if(a=n-c,p||!(a<0)){if(a/=p,p<0){if(a>h)return;a>u&&(u=a)}else if(p>0){if(a<u)return;a<h&&(h=a)}return u>0&&(i.a={x:l+u*f,y:c+u*p}),h<1&&(i.b={x:l+h*f,y:c+h*p}),i}}}}}}var rn=1e9;function nn(e,r,n,i){return function(l){var c,u,h,f,p,d,g,v,m,y,x,b=l,_=$r(),w=en(e,r,n,i),k={point:M,lineStart:function(){k.point=S,u&&u.push(h=[]);y=!0,m=!1,g=v=NaN},lineEnd:function(){c&&(S(f,p),d&&m&&_.rejoin(),c.push(_.buffer()));k.point=M,m&&l.lineEnd()},polygonStart:function(){l=_,c=[],u=[],x=!0},polygonEnd:function(){l=b,c=t.merge(c);var r=function(t){for(var e=0,r=u.length,n=t[1],i=0;i<r;++i)for(var a,o=1,s=u[i],l=s.length,c=s[0];o<l;++o)a=s[o],c[1]<=n?a[1]>n&&Ot(c,a,t)>0&&++e:a[1]<=n&&Ot(c,a,t)<0&&--e,c=a;return 0!==e}([e,i]),n=x&&r,a=c.length;(n||a)&&(l.polygonStart(),n&&(l.lineStart(),T(null,null,1,l),l.lineEnd()),a&&Wr(c,o,r,T,l),l.polygonEnd()),c=u=h=null}};function T(t,o,l,c){var u=0,h=0;if(null==t||(u=a(t,l))!==(h=a(o,l))||s(t,o)<0^l>0)do{c.point(0===u||3===u?e:n,u>1?i:r)}while((u=(u+l+4)%4)!==h);else c.point(o[0],o[1])}function A(t,a){return e<=t&&t<=n&&r<=a&&a<=i}function M(t,e){A(t,e)&&l.point(t,e)}function S(t,e){var r=A(t=Math.max(-rn,Math.min(rn,t)),e=Math.max(-rn,Math.min(rn,e)));if(u&&h.push([t,e]),y)f=t,p=e,d=r,y=!1,r&&(l.lineStart(),l.point(t,e));else if(r&&m)l.point(t,e);else{var n={a:{x:g,y:v},b:{x:t,y:e}};w(n)?(m||(l.lineStart(),l.point(n.a.x,n.a.y)),l.point(n.b.x,n.b.y),r||l.lineEnd(),x=!1):r&&(l.lineStart(),l.point(t,e),x=!1)}g=t,v=e,m=r}return k};function a(t,i){return y(t[0]-e)<kt?i>0?0:3:y(t[0]-n)<kt?i>0?2:1:y(t[1]-r)<kt?i>0?1:0:i>0?3:2}function o(t,e){return s(t.x,e.x)}function s(t,e){var r=a(t,1),n=a(e,1);return r!==n?r-n:0===r?e[1]-t[1]:1===r?t[0]-e[0]:2===r?t[1]-e[1]:e[0]-t[0]}}function an(t){var e=0,r=At/3,n=Cn(t),i=n(e,r);return i.parallels=function(t){return arguments.length?n(e=t[0]*At/180,r=t[1]*At/180):[e/At*180,r/At*180]},i}function on(t,e){var r=Math.sin(t),n=(r+Math.sin(e))/2,i=1+r*(2*n-r),a=Math.sqrt(i)/n;function o(t,e){var r=Math.sqrt(i-2*n*Math.sin(e))/n;return[r*Math.sin(t*=n),a-r*Math.cos(t)]}return o.invert=function(t,e){var r=a-e;return[Math.atan2(t,r)/n,It((i-(t*t+r*r)*n*n)/(2*n))]},o}t.geo.clipExtent=function(){var t,e,r,n,i,a,o={stream:function(t){return i&&(i.valid=!1),(i=a(t)).valid=!0,i},extent:function(s){return arguments.length?(a=nn(t=+s[0][0],e=+s[0][1],r=+s[1][0],n=+s[1][1]),i&&(i.valid=!1,i=null),o):[[t,e],[r,n]]}};return o.extent([[0,0],[960,500]])},(t.geo.conicEqualArea=function(){return an(on)}).raw=on,t.geo.albers=function(){return t.geo.conicEqualArea().rotate([96,0]).center([-.6,38.7]).parallels([29.5,45.5]).scale(1070)},t.geo.albersUsa=function(){var e,r,n,i,a=t.geo.albers(),o=t.geo.conicEqualArea().rotate([154,0]).center([-2,58.5]).parallels([55,65]),s=t.geo.conicEqualArea().rotate([157,0]).center([-3,19.9]).parallels([8,18]),l={point:function(t,r){e=[t,r]}};function c(t){var a=t[0],o=t[1];return e=null,r(a,o),e||(n(a,o),e)||i(a,o),e}return c.invert=function(t){var e=a.scale(),r=a.translate(),n=(t[0]-r[0])/e,i=(t[1]-r[1])/e;return(i>=.12&&i<.234&&n>=-.425&&n<-.214?o:i>=.166&&i<.234&&n>=-.214&&n<-.115?s:a).invert(t)},c.stream=function(t){var e=a.stream(t),r=o.stream(t),n=s.stream(t);return{point:function(t,i){e.point(t,i),r.point(t,i),n.point(t,i)},sphere:function(){e.sphere(),r.sphere(),n.sphere()},lineStart:function(){e.lineStart(),r.lineStart(),n.lineStart()},lineEnd:function(){e.lineEnd(),r.lineEnd(),n.lineEnd()},polygonStart:function(){e.polygonStart(),r.polygonStart(),n.polygonStart()},polygonEnd:function(){e.polygonEnd(),r.polygonEnd(),n.polygonEnd()}}},c.precision=function(t){return arguments.length?(a.precision(t),o.precision(t),s.precision(t),c):a.precision()},c.scale=function(t){return arguments.length?(a.scale(t),o.scale(.35*t),s.scale(t),c.translate(a.translate())):a.scale()},c.translate=function(t){if(!arguments.length)return a.translate();var e=a.scale(),u=+t[0],h=+t[1];return r=a.translate(t).clipExtent([[u-.455*e,h-.238*e],[u+.455*e,h+.238*e]]).stream(l).point,n=o.translate([u-.307*e,h+.201*e]).clipExtent([[u-.425*e+kt,h+.12*e+kt],[u-.214*e-kt,h+.234*e-kt]]).stream(l).point,i=s.translate([u-.205*e,h+.212*e]).clipExtent([[u-.214*e+kt,h+.166*e+kt],[u-.115*e-kt,h+.234*e-kt]]).stream(l).point,c},c.scale(1070)};var sn,ln,cn,un,hn,fn,pn={point:D,lineStart:D,lineEnd:D,polygonStart:function(){ln=0,pn.lineStart=dn},polygonEnd:function(){pn.lineStart=pn.lineEnd=pn.point=D,sn+=y(ln/2)}};function dn(){var t,e,r,n;function i(t,e){ln+=n*t-r*e,r=t,n=e}pn.point=function(a,o){pn.point=i,t=r=a,e=n=o},pn.lineEnd=function(){i(t,e)}}var gn={point:function(t,e){t<cn&&(cn=t);t>hn&&(hn=t);e<un&&(un=e);e>fn&&(fn=e)},lineStart:D,lineEnd:D,polygonStart:D,polygonEnd:D};function vn(){var t=mn(4.5),e=[],r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(e){return t=mn(e),r},result:function(){if(e.length){var t=e.join(\"\");return e=[],t}}};function n(r,n){e.push(\"M\",r,\",\",n,t)}function i(t,n){e.push(\"M\",t,\",\",n),r.point=a}function a(t,r){e.push(\"L\",t,\",\",r)}function o(){r.point=n}function s(){e.push(\"Z\")}return r}function mn(t){return\"m0,\"+t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+-2*t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+2*t+\"z\"}var yn,xn={point:bn,lineStart:_n,lineEnd:wn,polygonStart:function(){xn.lineStart=kn},polygonEnd:function(){xn.point=bn,xn.lineStart=_n,xn.lineEnd=wn}};function bn(t,e){xr+=t,br+=e,++_r}function _n(){var t,e;function r(r,n){var i=r-t,a=n-e,o=Math.sqrt(i*i+a*a);wr+=o*(t+r)/2,kr+=o*(e+n)/2,Tr+=o,bn(t=r,e=n)}xn.point=function(n,i){xn.point=r,bn(t=n,e=i)}}function wn(){xn.point=bn}function kn(){var t,e,r,n;function i(t,e){var i=t-r,a=e-n,o=Math.sqrt(i*i+a*a);wr+=o*(r+t)/2,kr+=o*(n+e)/2,Tr+=o,Ar+=(o=n*t-r*e)*(r+t),Mr+=o*(n+e),Sr+=3*o,bn(r=t,n=e)}xn.point=function(a,o){xn.point=i,bn(t=r=a,e=n=o)},xn.lineEnd=function(){i(t,e)}}function Tn(t){var e=4.5,r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(t){return e=t,r},result:D};function n(r,n){t.moveTo(r+e,n),t.arc(r,n,e,0,Mt)}function i(e,n){t.moveTo(e,n),r.point=a}function a(e,r){t.lineTo(e,r)}function o(){r.point=n}function s(){t.closePath()}return r}function An(t){var e=.5,r=Math.cos(30*Ct),n=16;function i(e){return(n?function(e){var r,i,o,s,l,c,u,h,f,p,d,g,v={point:m,lineStart:y,lineEnd:b,polygonStart:function(){e.polygonStart(),v.lineStart=_},polygonEnd:function(){e.polygonEnd(),v.lineStart=y}};function m(r,n){r=t(r,n),e.point(r[0],r[1])}function y(){h=NaN,v.point=x,e.lineStart()}function x(r,i){var o=Pr([r,i]),s=t(r,i);a(h,f,u,p,d,g,h=s[0],f=s[1],u=r,p=o[0],d=o[1],g=o[2],n,e),e.point(h,f)}function b(){v.point=m,e.lineEnd()}function _(){y(),v.point=w,v.lineEnd=k}function w(t,e){x(r=t,e),i=h,o=f,s=p,l=d,c=g,v.point=x}function k(){a(h,f,u,p,d,g,i,o,r,s,l,c,n,e),v.lineEnd=b,b()}return v}:function(e){return Sn(e,function(r,n){r=t(r,n),e.point(r[0],r[1])})})(e)}function a(n,i,o,s,l,c,u,h,f,p,d,g,v,m){var x=u-n,b=h-i,_=x*x+b*b;if(_>4*e&&v--){var w=s+p,k=l+d,T=c+g,A=Math.sqrt(w*w+k*k+T*T),M=Math.asin(T/=A),S=y(y(T)-1)<kt||y(o-f)<kt?(o+f)/2:Math.atan2(k,w),E=t(S,M),C=E[0],L=E[1],P=C-n,O=L-i,z=b*P-x*O;(z*z/_>e||y((x*P+b*O)/_-.5)>.3||s*p+l*d+c*g<r)&&(a(n,i,o,s,l,c,C,L,S,w/=A,k/=A,T,v,m),m.point(C,L),a(C,L,S,w,k,T,u,h,f,p,d,g,v,m))}}return i.precision=function(t){return arguments.length?(n=(e=t*t)>0&&16,i):Math.sqrt(e)},i}function Mn(t){this.stream=t}function Sn(t,e){return{point:e,sphere:function(){t.sphere()},lineStart:function(){t.lineStart()},lineEnd:function(){t.lineEnd()},polygonStart:function(){t.polygonStart()},polygonEnd:function(){t.polygonEnd()}}}function En(t){return Cn(function(){return t})()}function Cn(e){var r,n,i,a,o,s,l=An(function(t,e){return[(t=r(t,e))[0]*c+a,o-t[1]*c]}),c=150,u=480,h=250,f=0,p=0,d=0,g=0,v=0,m=tn,x=P,b=null,_=null;function w(t){return[(t=i(t[0]*Ct,t[1]*Ct))[0]*c+a,o-t[1]*c]}function k(t){return(t=i.invert((t[0]-a)/c,(o-t[1])/c))&&[t[0]*Lt,t[1]*Lt]}function T(){i=Gr(n=zn(d,g,v),r);var t=r(f,p);return a=u-t[0]*c,o=h+t[1]*c,A()}function A(){return s&&(s.valid=!1,s=null),w}return w.stream=function(t){return s&&(s.valid=!1),(s=Ln(m(n,l(x(t))))).valid=!0,s},w.clipAngle=function(t){return arguments.length?(m=null==t?(b=t,tn):function(t){var e=Math.cos(t),r=e>0,n=y(e)>kt;return Jr(i,function(t){var e,s,l,c,u;return{lineStart:function(){c=l=!1,u=1},point:function(h,f){var p,d=[h,f],g=i(h,f),v=r?g?0:o(h,f):g?o(h+(h<0?At:-At),f):0;if(!e&&(c=l=g)&&t.lineStart(),g!==l&&(p=a(e,d),(Br(e,p)||Br(d,p))&&(d[0]+=kt,d[1]+=kt,g=i(d[0],d[1]))),g!==l)u=0,g?(t.lineStart(),p=a(d,e),t.point(p[0],p[1])):(p=a(e,d),t.point(p[0],p[1]),t.lineEnd()),e=p;else if(n&&e&&r^g){var m;v&s||!(m=a(d,e,!0))||(u=0,r?(t.lineStart(),t.point(m[0][0],m[0][1]),t.point(m[1][0],m[1][1]),t.lineEnd()):(t.point(m[1][0],m[1][1]),t.lineEnd(),t.lineStart(),t.point(m[0][0],m[0][1])))}!g||e&&Br(e,d)||t.point(d[0],d[1]),e=d,l=g,s=v},lineEnd:function(){l&&t.lineEnd(),e=null},clean:function(){return u|(c&&l)<<1}}},Fn(t,6*Ct),r?[0,-t]:[-At,t-At]);function i(t,r){return Math.cos(t)*Math.cos(r)>e}function a(t,r,n){var i=[1,0,0],a=zr(Pr(t),Pr(r)),o=Or(a,a),s=a[0],l=o-s*s;if(!l)return!n&&t;var c=e*o/l,u=-e*s/l,h=zr(i,a),f=Dr(i,c);Ir(f,Dr(a,u));var p=h,d=Or(f,p),g=Or(p,p),v=d*d-g*(Or(f,f)-1);if(!(v<0)){var m=Math.sqrt(v),x=Dr(p,(-d-m)/g);if(Ir(x,f),x=Fr(x),!n)return x;var b,_=t[0],w=r[0],k=t[1],T=r[1];w<_&&(b=_,_=w,w=b);var A=w-_,M=y(A-At)<kt;if(!M&&T<k&&(b=k,k=T,T=b),M||A<kt?M?k+T>0^x[1]<(y(x[0]-_)<kt?k:T):k<=x[1]&&x[1]<=T:A>At^(_<=x[0]&&x[0]<=w)){var S=Dr(p,(-d+m)/g);return Ir(S,f),[x,Fr(S)]}}}function o(e,n){var i=r?t:At-t,a=0;return e<-i?a|=1:e>i&&(a|=2),n<-i?a|=4:n>i&&(a|=8),a}}((b=+t)*Ct),A()):b},w.clipExtent=function(t){return arguments.length?(_=t,x=t?nn(t[0][0],t[0][1],t[1][0],t[1][1]):P,A()):_},w.scale=function(t){return arguments.length?(c=+t,T()):c},w.translate=function(t){return arguments.length?(u=+t[0],h=+t[1],T()):[u,h]},w.center=function(t){return arguments.length?(f=t[0]%360*Ct,p=t[1]%360*Ct,T()):[f*Lt,p*Lt]},w.rotate=function(t){return arguments.length?(d=t[0]%360*Ct,g=t[1]%360*Ct,v=t.length>2?t[2]%360*Ct:0,T()):[d*Lt,g*Lt,v*Lt]},t.rebind(w,l,\"precision\"),function(){return r=e.apply(this,arguments),w.invert=r.invert&&k,T()}}function Ln(t){return Sn(t,function(e,r){t.point(e*Ct,r*Ct)})}function Pn(t,e){return[t,e]}function On(t,e){return[t>At?t-Mt:t<-At?t+Mt:t,e]}function zn(t,e,r){return t?e||r?Gr(Dn(t),Rn(e,r)):Dn(t):e||r?Rn(e,r):On}function In(t){return function(e,r){return[(e+=t)>At?e-Mt:e<-At?e+Mt:e,r]}}function Dn(t){var e=In(t);return e.invert=In(-t),e}function Rn(t,e){var r=Math.cos(t),n=Math.sin(t),i=Math.cos(e),a=Math.sin(e);function o(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*r+s*n;return[Math.atan2(l*i-u*a,s*r-c*n),It(u*i+l*a)]}return o.invert=function(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*i-l*a;return[Math.atan2(l*i+c*a,s*r+u*n),It(u*r-s*n)]},o}function Fn(t,e){var r=Math.cos(t),n=Math.sin(t);return function(i,a,o,s){var l=o*e;null!=i?(i=Bn(r,i),a=Bn(r,a),(o>0?i<a:i>a)&&(i+=o*Mt)):(i=t+o*Mt,a=t-.5*l);for(var c,u=i;o>0?u>a:u<a;u-=l)s.point((c=Fr([r,-n*Math.cos(u),-n*Math.sin(u)]))[0],c[1])}}function Bn(t,e){var r=Pr(e);r[0]-=t,Rr(r);var n=zt(-r[1]);return((-r[2]<0?-n:n)+2*Math.PI-kt)%(2*Math.PI)}function Nn(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map(function(e){return[t,e]})}}function jn(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map(function(e){return[e,t]})}}function Un(t){return t.source}function Vn(t){return t.target}t.geo.path=function(){var e,r,n,i,a,o=4.5;function s(e){return e&&(\"function\"==typeof o&&i.pointRadius(+o.apply(this,arguments)),a&&a.valid||(a=n(i)),t.geo.stream(e,a)),i.result()}function l(){return a=null,s}return s.area=function(e){return sn=0,t.geo.stream(e,n(pn)),sn},s.centroid=function(e){return xr=br=_r=wr=kr=Tr=Ar=Mr=Sr=0,t.geo.stream(e,n(xn)),Sr?[Ar/Sr,Mr/Sr]:Tr?[wr/Tr,kr/Tr]:_r?[xr/_r,br/_r]:[NaN,NaN]},s.bounds=function(e){return hn=fn=-(cn=un=1/0),t.geo.stream(e,n(gn)),[[cn,un],[hn,fn]]},s.projection=function(t){return arguments.length?(n=(e=t)?t.stream||(r=t,i=An(function(t,e){return r([t*Lt,e*Lt])}),function(t){return Ln(i(t))}):P,l()):e;var r,i},s.context=function(t){return arguments.length?(i=null==(r=t)?new vn:new Tn(t),\"function\"!=typeof o&&i.pointRadius(o),l()):r},s.pointRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:(i.pointRadius(+t),+t),s):o},s.projection(t.geo.albersUsa()).context(null)},t.geo.transform=function(t){return{stream:function(e){var r=new Mn(e);for(var n in t)r[n]=t[n];return r}}},Mn.prototype={point:function(t,e){this.stream.point(t,e)},sphere:function(){this.stream.sphere()},lineStart:function(){this.stream.lineStart()},lineEnd:function(){this.stream.lineEnd()},polygonStart:function(){this.stream.polygonStart()},polygonEnd:function(){this.stream.polygonEnd()}},t.geo.projection=En,t.geo.projectionMutator=Cn,(t.geo.equirectangular=function(){return En(Pn)}).raw=Pn.invert=Pn,t.geo.rotation=function(t){function e(e){return(e=t(e[0]*Ct,e[1]*Ct))[0]*=Lt,e[1]*=Lt,e}return t=zn(t[0]%360*Ct,t[1]*Ct,t.length>2?t[2]*Ct:0),e.invert=function(e){return(e=t.invert(e[0]*Ct,e[1]*Ct))[0]*=Lt,e[1]*=Lt,e},e},On.invert=Pn,t.geo.circle=function(){var t,e,r=[0,0],n=6;function i(){var t=\"function\"==typeof r?r.apply(this,arguments):r,n=zn(-t[0]*Ct,-t[1]*Ct,0).invert,i=[];return e(null,null,1,{point:function(t,e){i.push(t=n(t,e)),t[0]*=Lt,t[1]*=Lt}}),{type:\"Polygon\",coordinates:[i]}}return i.origin=function(t){return arguments.length?(r=t,i):r},i.angle=function(r){return arguments.length?(e=Fn((t=+r)*Ct,n*Ct),i):t},i.precision=function(r){return arguments.length?(e=Fn(t*Ct,(n=+r)*Ct),i):n},i.angle(90)},t.geo.distance=function(t,e){var r,n=(e[0]-t[0])*Ct,i=t[1]*Ct,a=e[1]*Ct,o=Math.sin(n),s=Math.cos(n),l=Math.sin(i),c=Math.cos(i),u=Math.sin(a),h=Math.cos(a);return Math.atan2(Math.sqrt((r=h*o)*r+(r=c*u-l*h*s)*r),l*u+c*h*s)},t.geo.graticule=function(){var e,r,n,i,a,o,s,l,c,u,h,f,p=10,d=p,g=90,v=360,m=2.5;function x(){return{type:\"MultiLineString\",coordinates:b()}}function b(){return t.range(Math.ceil(i/g)*g,n,g).map(h).concat(t.range(Math.ceil(l/v)*v,s,v).map(f)).concat(t.range(Math.ceil(r/p)*p,e,p).filter(function(t){return y(t%g)>kt}).map(c)).concat(t.range(Math.ceil(o/d)*d,a,d).filter(function(t){return y(t%v)>kt}).map(u))}return x.lines=function(){return b().map(function(t){return{type:\"LineString\",coordinates:t}})},x.outline=function(){return{type:\"Polygon\",coordinates:[h(i).concat(f(s).slice(1),h(n).reverse().slice(1),f(l).reverse().slice(1))]}},x.extent=function(t){return arguments.length?x.majorExtent(t).minorExtent(t):x.minorExtent()},x.majorExtent=function(t){return arguments.length?(i=+t[0][0],n=+t[1][0],l=+t[0][1],s=+t[1][1],i>n&&(t=i,i=n,n=t),l>s&&(t=l,l=s,s=t),x.precision(m)):[[i,l],[n,s]]},x.minorExtent=function(t){return arguments.length?(r=+t[0][0],e=+t[1][0],o=+t[0][1],a=+t[1][1],r>e&&(t=r,r=e,e=t),o>a&&(t=o,o=a,a=t),x.precision(m)):[[r,o],[e,a]]},x.step=function(t){return arguments.length?x.majorStep(t).minorStep(t):x.minorStep()},x.majorStep=function(t){return arguments.length?(g=+t[0],v=+t[1],x):[g,v]},x.minorStep=function(t){return arguments.length?(p=+t[0],d=+t[1],x):[p,d]},x.precision=function(t){return arguments.length?(m=+t,c=Nn(o,a,90),u=jn(r,e,m),h=Nn(l,s,90),f=jn(i,n,m),x):m},x.majorExtent([[-180,-90+kt],[180,90-kt]]).minorExtent([[-180,-80-kt],[180,80+kt]])},t.geo.greatArc=function(){var e,r,n=Un,i=Vn;function a(){return{type:\"LineString\",coordinates:[e||n.apply(this,arguments),r||i.apply(this,arguments)]}}return a.distance=function(){return t.geo.distance(e||n.apply(this,arguments),r||i.apply(this,arguments))},a.source=function(t){return arguments.length?(n=t,e=\"function\"==typeof t?null:t,a):n},a.target=function(t){return arguments.length?(i=t,r=\"function\"==typeof t?null:t,a):i},a.precision=function(){return arguments.length?a:0},a},t.geo.interpolate=function(t,e){return r=t[0]*Ct,n=t[1]*Ct,i=e[0]*Ct,a=e[1]*Ct,o=Math.cos(n),s=Math.sin(n),l=Math.cos(a),c=Math.sin(a),u=o*Math.cos(r),h=o*Math.sin(r),f=l*Math.cos(i),p=l*Math.sin(i),d=2*Math.asin(Math.sqrt(Rt(a-n)+o*l*Rt(i-r))),g=1/Math.sin(d),(v=d?function(t){var e=Math.sin(t*=d)*g,r=Math.sin(d-t)*g,n=r*u+e*f,i=r*h+e*p,a=r*s+e*c;return[Math.atan2(i,n)*Lt,Math.atan2(a,Math.sqrt(n*n+i*i))*Lt]}:function(){return[r*Lt,n*Lt]}).distance=d,v;var r,n,i,a,o,s,l,c,u,h,f,p,d,g,v},t.geo.length=function(e){return yn=0,t.geo.stream(e,qn),yn};var qn={sphere:D,point:D,lineStart:function(){var t,e,r;function n(n,i){var a=Math.sin(i*=Ct),o=Math.cos(i),s=y((n*=Ct)-t),l=Math.cos(s);yn+=Math.atan2(Math.sqrt((s=o*Math.sin(s))*s+(s=r*a-e*o*l)*s),e*a+r*o*l),t=n,e=a,r=o}qn.point=function(i,a){t=i*Ct,e=Math.sin(a*=Ct),r=Math.cos(a),qn.point=n},qn.lineEnd=function(){qn.point=qn.lineEnd=D}},lineEnd:D,polygonStart:D,polygonEnd:D};function Hn(t,e){function r(e,r){var n=Math.cos(e),i=Math.cos(r),a=t(n*i);return[a*i*Math.sin(e),a*Math.sin(r)]}return r.invert=function(t,r){var n=Math.sqrt(t*t+r*r),i=e(n),a=Math.sin(i),o=Math.cos(i);return[Math.atan2(t*a,n*o),Math.asin(n&&r*a/n)]},r}var Gn=Hn(function(t){return Math.sqrt(2/(1+t))},function(t){return 2*Math.asin(t/2)});(t.geo.azimuthalEqualArea=function(){return En(Gn)}).raw=Gn;var Yn=Hn(function(t){var e=Math.acos(t);return e&&e/Math.sin(e)},P);function Wn(t,e){var r=Math.cos(t),n=function(t){return Math.tan(At/4+t/2)},i=t===e?Math.sin(t):Math.log(r/Math.cos(e))/Math.log(n(e)/n(t)),a=r*Math.pow(n(t),i)/i;if(!i)return Jn;function o(t,e){a>0?e<-Et+kt&&(e=-Et+kt):e>Et-kt&&(e=Et-kt);var r=a/Math.pow(n(e),i);return[r*Math.sin(i*t),a-r*Math.cos(i*t)]}return o.invert=function(t,e){var r=a-e,n=Pt(i)*Math.sqrt(t*t+r*r);return[Math.atan2(t,r)/i,2*Math.atan(Math.pow(a/n,1/i))-Et]},o}function Xn(t,e){var r=Math.cos(t),n=t===e?Math.sin(t):(r-Math.cos(e))/(e-t),i=r/n+t;if(y(n)<kt)return Pn;function a(t,e){var r=i-e;return[r*Math.sin(n*t),i-r*Math.cos(n*t)]}return a.invert=function(t,e){var r=i-e;return[Math.atan2(t,r)/n,i-Pt(n)*Math.sqrt(t*t+r*r)]},a}(t.geo.azimuthalEquidistant=function(){return En(Yn)}).raw=Yn,(t.geo.conicConformal=function(){return an(Wn)}).raw=Wn,(t.geo.conicEquidistant=function(){return an(Xn)}).raw=Xn;var Zn=Hn(function(t){return 1/t},Math.atan);function Jn(t,e){return[t,Math.log(Math.tan(At/4+e/2))]}function Kn(t){var e,r=En(t),n=r.scale,i=r.translate,a=r.clipExtent;return r.scale=function(){var t=n.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.translate=function(){var t=i.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.clipExtent=function(t){var o=a.apply(r,arguments);if(o===r){if(e=null==t){var s=At*n(),l=i();a([[l[0]-s,l[1]-s],[l[0]+s,l[1]+s]])}}else e&&(o=null);return o},r.clipExtent(null)}(t.geo.gnomonic=function(){return En(Zn)}).raw=Zn,Jn.invert=function(t,e){return[t,2*Math.atan(Math.exp(e))-Et]},(t.geo.mercator=function(){return Kn(Jn)}).raw=Jn;var $n=Hn(function(){return 1},Math.asin);(t.geo.orthographic=function(){return En($n)}).raw=$n;var Qn=Hn(function(t){return 1/(1+t)},function(t){return 2*Math.atan(t)});function ti(t,e){return[Math.log(Math.tan(At/4+e/2)),-t]}function ei(t){return t[0]}function ri(t){return t[1]}function ni(t){for(var e=t.length,r=[0,1],n=2,i=2;i<e;i++){for(;n>1&&Ot(t[r[n-2]],t[r[n-1]],t[i])<=0;)--n;r[n++]=i}return r.slice(0,n)}function ii(t,e){return t[0]-e[0]||t[1]-e[1]}(t.geo.stereographic=function(){return En(Qn)}).raw=Qn,ti.invert=function(t,e){return[-e,2*Math.atan(Math.exp(t))-Et]},(t.geo.transverseMercator=function(){var t=Kn(ti),e=t.center,r=t.rotate;return t.center=function(t){return t?e([-t[1],t[0]]):[(t=e())[1],-t[0]]},t.rotate=function(t){return t?r([t[0],t[1],t.length>2?t[2]+90:90]):[(t=r())[0],t[1],t[2]-90]},r([0,0,90])}).raw=ti,t.geom={},t.geom.hull=function(t){var e=ei,r=ri;if(arguments.length)return n(t);function n(t){if(t.length<3)return[];var n,i=ve(e),a=ve(r),o=t.length,s=[],l=[];for(n=0;n<o;n++)s.push([+i.call(this,t[n],n),+a.call(this,t[n],n),n]);for(s.sort(ii),n=0;n<o;n++)l.push([s[n][0],-s[n][1]]);var c=ni(s),u=ni(l),h=u[0]===c[0],f=u[u.length-1]===c[c.length-1],p=[];for(n=c.length-1;n>=0;--n)p.push(t[s[c[n]][2]]);for(n=+h;n<u.length-f;++n)p.push(t[s[u[n]][2]]);return p}return n.x=function(t){return arguments.length?(e=t,n):e},n.y=function(t){return arguments.length?(r=t,n):r},n},t.geom.polygon=function(t){return V(t,ai),t};var ai=t.geom.polygon.prototype=[];function oi(t,e,r){return(r[0]-e[0])*(t[1]-e[1])<(r[1]-e[1])*(t[0]-e[0])}function si(t,e,r,n){var i=t[0],a=r[0],o=e[0]-i,s=n[0]-a,l=t[1],c=r[1],u=e[1]-l,h=n[1]-c,f=(s*(l-c)-h*(i-a))/(h*o-s*u);return[i+f*o,l+f*u]}function li(t){var e=t[0],r=t[t.length-1];return!(e[0]-r[0]||e[1]-r[1])}ai.area=function(){for(var t,e=-1,r=this.length,n=this[r-1],i=0;++e<r;)t=n,n=this[e],i+=t[1]*n[0]-t[0]*n[1];return.5*i},ai.centroid=function(t){var e,r,n=-1,i=this.length,a=0,o=0,s=this[i-1];for(arguments.length||(t=-1/(6*this.area()));++n<i;)e=s,s=this[n],r=e[0]*s[1]-s[0]*e[1],a+=(e[0]+s[0])*r,o+=(e[1]+s[1])*r;return[a*t,o*t]},ai.clip=function(t){for(var e,r,n,i,a,o,s=li(t),l=-1,c=this.length-li(this),u=this[c-1];++l<c;){for(e=t.slice(),t.length=0,i=this[l],a=e[(n=e.length-s)-1],r=-1;++r<n;)oi(o=e[r],u,i)?(oi(a,u,i)||t.push(si(a,o,u,i)),t.push(o)):oi(a,u,i)&&t.push(si(a,o,u,i)),a=o;s&&t.push(t[0]),u=i}return t};var ci,ui,hi,fi,pi,di=[],gi=[];function vi(){Ii(this),this.edge=this.site=this.circle=null}function mi(t){var e=di.pop()||new vi;return e.site=t,e}function yi(t){Si(t),hi.remove(t),di.push(t),Ii(t)}function xi(t){var e=t.circle,r=e.x,n=e.cy,i={x:r,y:n},a=t.P,o=t.N,s=[t];yi(t);for(var l=a;l.circle&&y(r-l.circle.x)<kt&&y(n-l.circle.cy)<kt;)a=l.P,s.unshift(l),yi(l),l=a;s.unshift(l),Si(l);for(var c=o;c.circle&&y(r-c.circle.x)<kt&&y(n-c.circle.cy)<kt;)o=c.N,s.push(c),yi(c),c=o;s.push(c),Si(c);var u,h=s.length;for(u=1;u<h;++u)c=s[u],l=s[u-1],Pi(c.edge,l.site,c.site,i);l=s[0],(c=s[h-1]).edge=Li(l.site,c.site,null,i),Mi(l),Mi(c)}function bi(t){for(var e,r,n,i,a=t.x,o=t.y,s=hi._;s;)if((n=_i(s,o)-a)>kt)s=s.L;else{if(!((i=a-wi(s,o))>kt)){n>-kt?(e=s.P,r=s):i>-kt?(e=s,r=s.N):e=r=s;break}if(!s.R){e=s;break}s=s.R}var l=mi(t);if(hi.insert(e,l),e||r){if(e===r)return Si(e),r=mi(e.site),hi.insert(l,r),l.edge=r.edge=Li(e.site,l.site),Mi(e),void Mi(r);if(r){Si(e),Si(r);var c=e.site,u=c.x,h=c.y,f=t.x-u,p=t.y-h,d=r.site,g=d.x-u,v=d.y-h,m=2*(f*v-p*g),y=f*f+p*p,x=g*g+v*v,b={x:(v*y-p*x)/m+u,y:(f*x-g*y)/m+h};Pi(r.edge,c,d,b),l.edge=Li(c,t,null,b),r.edge=Li(t,d,null,b),Mi(e),Mi(r)}else l.edge=Li(e.site,l.site)}}function _i(t,e){var r=t.site,n=r.x,i=r.y,a=i-e;if(!a)return n;var o=t.P;if(!o)return-1/0;var s=(r=o.site).x,l=r.y,c=l-e;if(!c)return s;var u=s-n,h=1/a-1/c,f=u/c;return h?(-f+Math.sqrt(f*f-2*h*(u*u/(-2*c)-l+c/2+i-a/2)))/h+n:(n+s)/2}function wi(t,e){var r=t.N;if(r)return _i(r,e);var n=t.site;return n.y===e?n.x:1/0}function ki(t){this.site=t,this.edges=[]}function Ti(t,e){return e.angle-t.angle}function Ai(){Ii(this),this.x=this.y=this.arc=this.site=this.cy=null}function Mi(t){var e=t.P,r=t.N;if(e&&r){var n=e.site,i=t.site,a=r.site;if(n!==a){var o=i.x,s=i.y,l=n.x-o,c=n.y-s,u=a.x-o,h=2*(l*(v=a.y-s)-c*u);if(!(h>=-Tt)){var f=l*l+c*c,p=u*u+v*v,d=(v*f-c*p)/h,g=(l*p-u*f)/h,v=g+s,m=gi.pop()||new Ai;m.arc=t,m.site=i,m.x=d+o,m.y=v+Math.sqrt(d*d+g*g),m.cy=v,t.circle=m;for(var y=null,x=pi._;x;)if(m.y<x.y||m.y===x.y&&m.x<=x.x){if(!x.L){y=x.P;break}x=x.L}else{if(!x.R){y=x;break}x=x.R}pi.insert(y,m),y||(fi=m)}}}}function Si(t){var e=t.circle;e&&(e.P||(fi=e.N),pi.remove(e),gi.push(e),Ii(e),t.circle=null)}function Ei(t,e){var r=t.b;if(r)return!0;var n,i,a=t.a,o=e[0][0],s=e[1][0],l=e[0][1],c=e[1][1],u=t.l,h=t.r,f=u.x,p=u.y,d=h.x,g=h.y,v=(f+d)/2,m=(p+g)/2;if(g===p){if(v<o||v>=s)return;if(f>d){if(a){if(a.y>=c)return}else a={x:v,y:l};r={x:v,y:c}}else{if(a){if(a.y<l)return}else a={x:v,y:c};r={x:v,y:l}}}else if(i=m-(n=(f-d)/(g-p))*v,n<-1||n>1)if(f>d){if(a){if(a.y>=c)return}else a={x:(l-i)/n,y:l};r={x:(c-i)/n,y:c}}else{if(a){if(a.y<l)return}else a={x:(c-i)/n,y:c};r={x:(l-i)/n,y:l}}else if(p<g){if(a){if(a.x>=s)return}else a={x:o,y:n*o+i};r={x:s,y:n*s+i}}else{if(a){if(a.x<o)return}else a={x:s,y:n*s+i};r={x:o,y:n*o+i}}return t.a=a,t.b=r,!0}function Ci(t,e){this.l=t,this.r=e,this.a=this.b=null}function Li(t,e,r,n){var i=new Ci(t,e);return ci.push(i),r&&Pi(i,t,e,r),n&&Pi(i,e,t,n),ui[t.i].edges.push(new Oi(i,t,e)),ui[e.i].edges.push(new Oi(i,e,t)),i}function Pi(t,e,r,n){t.a||t.b?t.l===r?t.b=n:t.a=n:(t.a=n,t.l=e,t.r=r)}function Oi(t,e,r){var n=t.a,i=t.b;this.edge=t,this.site=e,this.angle=r?Math.atan2(r.y-e.y,r.x-e.x):t.l===e?Math.atan2(i.x-n.x,n.y-i.y):Math.atan2(n.x-i.x,i.y-n.y)}function zi(){this._=null}function Ii(t){t.U=t.C=t.L=t.R=t.P=t.N=null}function Di(t,e){var r=e,n=e.R,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.R=n.L,r.R&&(r.R.U=r),n.L=r}function Ri(t,e){var r=e,n=e.L,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.L=n.R,r.L&&(r.L.U=r),n.R=r}function Fi(t){for(;t.L;)t=t.L;return t}function Bi(t,e){var r,n,i,a=t.sort(Ni).pop();for(ci=[],ui=new Array(t.length),hi=new zi,pi=new zi;;)if(i=fi,a&&(!i||a.y<i.y||a.y===i.y&&a.x<i.x))a.x===r&&a.y===n||(ui[a.i]=new ki(a),bi(a),r=a.x,n=a.y),a=t.pop();else{if(!i)break;xi(i.arc)}e&&(function(t){for(var e,r=ci,n=en(t[0][0],t[0][1],t[1][0],t[1][1]),i=r.length;i--;)(!Ei(e=r[i],t)||!n(e)||y(e.a.x-e.b.x)<kt&&y(e.a.y-e.b.y)<kt)&&(e.a=e.b=null,r.splice(i,1))}(e),function(t){for(var e,r,n,i,a,o,s,l,c,u,h=t[0][0],f=t[1][0],p=t[0][1],d=t[1][1],g=ui,v=g.length;v--;)if((a=g[v])&&a.prepare())for(l=(s=a.edges).length,o=0;o<l;)n=(u=s[o].end()).x,i=u.y,e=(c=s[++o%l].start()).x,r=c.y,(y(n-e)>kt||y(i-r)>kt)&&(s.splice(o,0,new Oi((m=a.site,x=u,b=y(n-h)<kt&&d-i>kt?{x:h,y:y(e-h)<kt?r:d}:y(i-d)<kt&&f-n>kt?{x:y(r-d)<kt?e:f,y:d}:y(n-f)<kt&&i-p>kt?{x:f,y:y(e-f)<kt?r:p}:y(i-p)<kt&&n-h>kt?{x:y(r-p)<kt?e:h,y:p}:null,_=void 0,_=new Ci(m,null),_.a=x,_.b=b,ci.push(_),_),a.site,null)),++l);var m,x,b,_}(e));var o={cells:ui,edges:ci};return hi=pi=ci=ui=null,o}function Ni(t,e){return e.y-t.y||e.x-t.x}ki.prototype.prepare=function(){for(var t,e=this.edges,r=e.length;r--;)(t=e[r].edge).b&&t.a||e.splice(r,1);return e.sort(Ti),e.length},Oi.prototype={start:function(){return this.edge.l===this.site?this.edge.a:this.edge.b},end:function(){return this.edge.l===this.site?this.edge.b:this.edge.a}},zi.prototype={insert:function(t,e){var r,n,i;if(t){if(e.P=t,e.N=t.N,t.N&&(t.N.P=e),t.N=e,t.R){for(t=t.R;t.L;)t=t.L;t.L=e}else t.R=e;r=t}else this._?(t=Fi(this._),e.P=null,e.N=t,t.P=t.L=e,r=t):(e.P=e.N=null,this._=e,r=null);for(e.L=e.R=null,e.U=r,e.C=!0,t=e;r&&r.C;)r===(n=r.U).L?(i=n.R)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.R&&(Di(this,r),r=(t=r).U),r.C=!1,n.C=!0,Ri(this,n)):(i=n.L)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.L&&(Ri(this,r),r=(t=r).U),r.C=!1,n.C=!0,Di(this,n)),r=t.U;this._.C=!1},remove:function(t){t.N&&(t.N.P=t.P),t.P&&(t.P.N=t.N),t.N=t.P=null;var e,r,n,i=t.U,a=t.L,o=t.R;if(r=a?o?Fi(o):a:o,i?i.L===t?i.L=r:i.R=r:this._=r,a&&o?(n=r.C,r.C=t.C,r.L=a,a.U=r,r!==o?(i=r.U,r.U=t.U,t=r.R,i.L=t,r.R=o,o.U=r):(r.U=i,i=r,t=r.R)):(n=t.C,t=r),t&&(t.U=i),!n)if(t&&t.C)t.C=!1;else{do{if(t===this._)break;if(t===i.L){if((e=i.R).C&&(e.C=!1,i.C=!0,Di(this,i),e=i.R),e.L&&e.L.C||e.R&&e.R.C){e.R&&e.R.C||(e.L.C=!1,e.C=!0,Ri(this,e),e=i.R),e.C=i.C,i.C=e.R.C=!1,Di(this,i),t=this._;break}}else if((e=i.L).C&&(e.C=!1,i.C=!0,Ri(this,i),e=i.L),e.L&&e.L.C||e.R&&e.R.C){e.L&&e.L.C||(e.R.C=!1,e.C=!0,Di(this,e),e=i.L),e.C=i.C,i.C=e.L.C=!1,Ri(this,i),t=this._;break}e.C=!0,t=i,i=i.U}while(!t.C);t&&(t.C=!1)}}},t.geom.voronoi=function(t){var e=ei,r=ri,n=e,i=r,a=ji;if(t)return o(t);function o(t){var e=new Array(t.length),r=a[0][0],n=a[0][1],i=a[1][0],o=a[1][1];return Bi(s(t),a).cells.forEach(function(a,s){var l=a.edges,c=a.site;(e[s]=l.length?l.map(function(t){var e=t.start();return[e.x,e.y]}):c.x>=r&&c.x<=i&&c.y>=n&&c.y<=o?[[r,o],[i,o],[i,n],[r,n]]:[]).point=t[s]}),e}function s(t){return t.map(function(t,e){return{x:Math.round(n(t,e)/kt)*kt,y:Math.round(i(t,e)/kt)*kt,i:e}})}return o.links=function(t){return Bi(s(t)).edges.filter(function(t){return t.l&&t.r}).map(function(e){return{source:t[e.l.i],target:t[e.r.i]}})},o.triangles=function(t){var e=[];return Bi(s(t)).cells.forEach(function(r,n){for(var i,a,o,s,l=r.site,c=r.edges.sort(Ti),u=-1,h=c.length,f=c[h-1].edge,p=f.l===l?f.r:f.l;++u<h;)f,i=p,p=(f=c[u].edge).l===l?f.r:f.l,n<i.i&&n<p.i&&(o=i,s=p,((a=l).x-s.x)*(o.y-a.y)-(a.x-o.x)*(s.y-a.y)<0)&&e.push([t[n],t[i.i],t[p.i]])}),e},o.x=function(t){return arguments.length?(n=ve(e=t),o):e},o.y=function(t){return arguments.length?(i=ve(r=t),o):r},o.clipExtent=function(t){return arguments.length?(a=null==t?ji:t,o):a===ji?null:a},o.size=function(t){return arguments.length?o.clipExtent(t&&[[0,0],t]):a===ji?null:a&&a[1]},o};var ji=[[-1e6,-1e6],[1e6,1e6]];function Ui(t){return t.x}function Vi(t){return t.y}function qi(e,r){e=t.rgb(e),r=t.rgb(r);var n=e.r,i=e.g,a=e.b,o=r.r-n,s=r.g-i,l=r.b-a;return function(t){return\"#\"+ce(Math.round(n+o*t))+ce(Math.round(i+s*t))+ce(Math.round(a+l*t))}}function Hi(t,e){var r,n={},i={};for(r in t)r in e?n[r]=Zi(t[r],e[r]):i[r]=t[r];for(r in e)r in t||(i[r]=e[r]);return function(t){for(r in n)i[r]=n[r](t);return i}}function Gi(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function Yi(t,e){var r,n,i,a=Wi.lastIndex=Xi.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=Wi.exec(t))&&(n=Xi.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:Gi(r,n)})),a=Xi.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?(e=l[0].x,function(t){return e(t)+\"\"}):function(){return e}:(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}t.geom.delaunay=function(e){return t.geom.voronoi().triangles(e)},t.geom.quadtree=function(t,e,r,n,i){var a,o=ei,s=ri;if(a=arguments.length)return o=Ui,s=Vi,3===a&&(i=r,n=e,r=e=0),l(t);function l(t){var l,c,u,h,f,p,d,g,v,m=ve(o),x=ve(s);if(null!=e)p=e,d=r,g=n,v=i;else if(g=v=-(p=d=1/0),c=[],u=[],f=t.length,a)for(h=0;h<f;++h)(l=t[h]).x<p&&(p=l.x),l.y<d&&(d=l.y),l.x>g&&(g=l.x),l.y>v&&(v=l.y),c.push(l.x),u.push(l.y);else for(h=0;h<f;++h){var b=+m(l=t[h],h),_=+x(l,h);b<p&&(p=b),_<d&&(d=_),b>g&&(g=b),_>v&&(v=_),c.push(b),u.push(_)}var w=g-p,k=v-d;function T(t,e,r,n,i,a,o,s){if(!isNaN(r)&&!isNaN(n))if(t.leaf){var l=t.x,c=t.y;if(null!=l)if(y(l-r)+y(c-n)<.01)A(t,e,r,n,i,a,o,s);else{var u=t.point;t.x=t.y=t.point=null,A(t,u,l,c,i,a,o,s),A(t,e,r,n,i,a,o,s)}else t.x=r,t.y=n,t.point=e}else A(t,e,r,n,i,a,o,s)}function A(t,e,r,n,i,a,o,s){var l=.5*(i+o),c=.5*(a+s),u=r>=l,h=n>=c,f=h<<1|u;t.leaf=!1,u?i=l:o=l,h?a=c:s=c,T(t=t.nodes[f]||(t.nodes[f]={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){T(M,t,+m(t,++h),+x(t,h),p,d,g,v)}}),e,r,n,i,a,o,s)}w>k?v=d+w:g=p+k;var M={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){T(M,t,+m(t,++h),+x(t,h),p,d,g,v)}};if(M.visit=function(t){!function t(e,r,n,i,a,o){if(!e(r,n,i,a,o)){var s=.5*(n+a),l=.5*(i+o),c=r.nodes;c[0]&&t(e,c[0],n,i,s,l),c[1]&&t(e,c[1],s,i,a,l),c[2]&&t(e,c[2],n,l,s,o),c[3]&&t(e,c[3],s,l,a,o)}}(t,M,p,d,g,v)},M.find=function(t){return function(t,e,r,n,i,a,o){var s,l=1/0;return function t(c,u,h,f,p){if(!(u>a||h>o||f<n||p<i)){if(d=c.point){var d,g=e-c.x,v=r-c.y,m=g*g+v*v;if(m<l){var y=Math.sqrt(l=m);n=e-y,i=r-y,a=e+y,o=r+y,s=d}}for(var x=c.nodes,b=.5*(u+f),_=.5*(h+p),w=(r>=_)<<1|e>=b,k=w+4;w<k;++w)if(c=x[3&w])switch(3&w){case 0:t(c,u,h,b,_);break;case 1:t(c,b,h,f,_);break;case 2:t(c,u,_,b,p);break;case 3:t(c,b,_,f,p)}}}(t,n,i,a,o),s}(M,t[0],t[1],p,d,g,v)},h=-1,null==e){for(;++h<f;)T(M,t[h],c[h],u[h],p,d,g,v);--h}else t.forEach(M.add);return c=u=t=l=null,M}return l.x=function(t){return arguments.length?(o=t,l):o},l.y=function(t){return arguments.length?(s=t,l):s},l.extent=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=+t[0][0],r=+t[0][1],n=+t[1][0],i=+t[1][1]),l):null==e?null:[[e,r],[n,i]]},l.size=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=r=0,n=+t[0],i=+t[1]),l):null==e?null:[n-e,i-r]},l},t.interpolateRgb=qi,t.interpolateObject=Hi,t.interpolateNumber=Gi,t.interpolateString=Yi;var Wi=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,Xi=new RegExp(Wi.source,\"g\");function Zi(e,r){for(var n,i=t.interpolators.length;--i>=0&&!(n=t.interpolators[i](e,r)););return n}function Ji(t,e){var r,n=[],i=[],a=t.length,o=e.length,s=Math.min(t.length,e.length);for(r=0;r<s;++r)n.push(Zi(t[r],e[r]));for(;r<a;++r)i[r]=t[r];for(;r<o;++r)i[r]=e[r];return function(t){for(r=0;r<s;++r)i[r]=n[r](t);return i}}t.interpolate=Zi,t.interpolators=[function(t,e){var r=typeof e;return(\"string\"===r?ge.has(e.toLowerCase())||/^(#|rgb\\(|hsl\\()/i.test(e)?qi:Yi:e instanceof Ut?qi:Array.isArray(e)?Ji:\"object\"===r&&isNaN(e)?Hi:Gi)(t,e)}],t.interpolateArray=Ji;var Ki=function(){return P},$i=t.map({linear:Ki,poly:function(t){return function(e){return Math.pow(e,t)}},quad:function(){return ra},cubic:function(){return na},sin:function(){return aa},exp:function(){return oa},circle:function(){return sa},elastic:function(t,e){var r;arguments.length<2&&(e=.45);arguments.length?r=e/Mt*Math.asin(1/t):(t=1,r=e/4);return function(n){return 1+t*Math.pow(2,-10*n)*Math.sin((n-r)*Mt/e)}},back:function(t){t||(t=1.70158);return function(e){return e*e*((t+1)*e-t)}},bounce:function(){return la}}),Qi=t.map({in:P,out:ta,\"in-out\":ea,\"out-in\":function(t){return ea(ta(t))}});function ta(t){return function(e){return 1-t(1-e)}}function ea(t){return function(e){return.5*(e<.5?t(2*e):2-t(2-2*e))}}function ra(t){return t*t}function na(t){return t*t*t}function ia(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}function aa(t){return 1-Math.cos(t*Et)}function oa(t){return Math.pow(2,10*(t-1))}function sa(t){return 1-Math.sqrt(1-t*t)}function la(t){return t<1/2.75?7.5625*t*t:t<2/2.75?7.5625*(t-=1.5/2.75)*t+.75:t<2.5/2.75?7.5625*(t-=2.25/2.75)*t+.9375:7.5625*(t-=2.625/2.75)*t+.984375}function ca(t,e){return e-=t,function(r){return Math.round(t+e*r)}}function ua(t){var e,r,n,i=[t.a,t.b],a=[t.c,t.d],o=fa(i),s=ha(i,a),l=fa(((e=a)[0]+=(n=-s)*(r=i)[0],e[1]+=n*r[1],e))||0;i[0]*a[1]<a[0]*i[1]&&(i[0]*=-1,i[1]*=-1,o*=-1,s*=-1),this.rotate=(o?Math.atan2(i[1],i[0]):Math.atan2(-a[0],a[1]))*Lt,this.translate=[t.e,t.f],this.scale=[o,l],this.skew=l?Math.atan2(s,l)*Lt:0}function ha(t,e){return t[0]*e[0]+t[1]*e[1]}function fa(t){var e=Math.sqrt(ha(t,t));return e&&(t[0]/=e,t[1]/=e),e}t.ease=function(t){var e,n=t.indexOf(\"-\"),i=n>=0?t.slice(0,n):t,a=n>=0?t.slice(n+1):\"in\";return i=$i.get(i)||Ki,a=Qi.get(a)||P,e=a(i.apply(null,r.call(arguments,1))),function(t){return t<=0?0:t>=1?1:e(t)}},t.interpolateHcl=function(e,r){e=t.hcl(e),r=t.hcl(r);var n=e.h,i=e.c,a=e.l,o=r.h-n,s=r.c-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.c:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Wt(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateHsl=function(e,r){e=t.hsl(e),r=t.hsl(r);var n=e.h,i=e.s,a=e.l,o=r.h-n,s=r.s-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.s:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Ht(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateLab=function(e,r){e=t.lab(e),r=t.lab(r);var n=e.l,i=e.a,a=e.b,o=r.l-n,s=r.a-i,l=r.b-a;return function(t){return te(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateRound=ca,t.transform=function(e){var r=i.createElementNS(t.ns.prefix.svg,\"g\");return(t.transform=function(t){if(null!=t){r.setAttribute(\"transform\",t);var e=r.transform.baseVal.consolidate()}return new ua(e?e.matrix:pa)})(e)},ua.prototype.toString=function(){return\"translate(\"+this.translate+\")rotate(\"+this.rotate+\")skewX(\"+this.skew+\")scale(\"+this.scale+\")\"};var pa={a:1,b:0,c:0,d:1,e:0,f:0};function da(t){return t.length?t.pop()+\",\":\"\"}function ga(e,r){var n=[],i=[];return e=t.transform(e),r=t.transform(r),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(\"translate(\",null,\",\",null,\")\");n.push({i:i-4,x:Gi(t[0],e[0])},{i:i-2,x:Gi(t[1],e[1])})}else(e[0]||e[1])&&r.push(\"translate(\"+e+\")\")}(e.translate,r.translate,n,i),function(t,e,r,n){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),n.push({i:r.push(da(r)+\"rotate(\",null,\")\")-2,x:Gi(t,e)})):e&&r.push(da(r)+\"rotate(\"+e+\")\")}(e.rotate,r.rotate,n,i),function(t,e,r,n){t!==e?n.push({i:r.push(da(r)+\"skewX(\",null,\")\")-2,x:Gi(t,e)}):e&&r.push(da(r)+\"skewX(\"+e+\")\")}(e.skew,r.skew,n,i),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(da(r)+\"scale(\",null,\",\",null,\")\");n.push({i:i-4,x:Gi(t[0],e[0])},{i:i-2,x:Gi(t[1],e[1])})}else 1===e[0]&&1===e[1]||r.push(da(r)+\"scale(\"+e+\")\")}(e.scale,r.scale,n,i),e=r=null,function(t){for(var e,r=-1,a=i.length;++r<a;)n[(e=i[r]).i]=e.x(t);return n.join(\"\")}}function va(t,e){return e=(e-=t=+t)||1/e,function(r){return(r-t)/e}}function ma(t,e){return e=(e-=t=+t)||1/e,function(r){return Math.max(0,Math.min(1,(r-t)/e))}}function ya(t){for(var e=t.source,r=t.target,n=function(t,e){if(t===e)return t;var r=xa(t),n=xa(e),i=r.pop(),a=n.pop(),o=null;for(;i===a;)o=i,i=r.pop(),a=n.pop();return o}(e,r),i=[e];e!==n;)e=e.parent,i.push(e);for(var a=i.length;r!==n;)i.splice(a,0,r),r=r.parent;return i}function xa(t){for(var e=[],r=t.parent;null!=r;)e.push(t),t=r,r=r.parent;return e.push(t),e}function ba(t){t.fixed|=2}function _a(t){t.fixed&=-7}function wa(t){t.fixed|=4,t.px=t.x,t.py=t.y}function ka(t){t.fixed&=-5}t.interpolateTransform=ga,t.layout={},t.layout.bundle=function(){return function(t){for(var e=[],r=-1,n=t.length;++r<n;)e.push(ya(t[r]));return e}},t.layout.chord=function(){var e,r,n,i,a,o,s,l={},c=0;function u(){var l,u,f,p,d,g={},v=[],m=t.range(i),y=[];for(e=[],r=[],l=0,p=-1;++p<i;){for(u=0,d=-1;++d<i;)u+=n[p][d];v.push(u),y.push(t.range(i)),l+=u}for(a&&m.sort(function(t,e){return a(v[t],v[e])}),o&&y.forEach(function(t,e){t.sort(function(t,r){return o(n[e][t],n[e][r])})}),l=(Mt-c*i)/l,u=0,p=-1;++p<i;){for(f=u,d=-1;++d<i;){var x=m[p],b=y[x][d],_=n[x][b],w=u,k=u+=_*l;g[x+\"-\"+b]={index:x,subindex:b,startAngle:w,endAngle:k,value:_}}r[x]={index:x,startAngle:f,endAngle:u,value:v[x]},u+=c}for(p=-1;++p<i;)for(d=p-1;++d<i;){var T=g[p+\"-\"+d],A=g[d+\"-\"+p];(T.value||A.value)&&e.push(T.value<A.value?{source:A,target:T}:{source:T,target:A})}s&&h()}function h(){e.sort(function(t,e){return s((t.source.value+t.target.value)/2,(e.source.value+e.target.value)/2)})}return l.matrix=function(t){return arguments.length?(i=(n=t)&&n.length,e=r=null,l):n},l.padding=function(t){return arguments.length?(c=t,e=r=null,l):c},l.sortGroups=function(t){return arguments.length?(a=t,e=r=null,l):a},l.sortSubgroups=function(t){return arguments.length?(o=t,e=null,l):o},l.sortChords=function(t){return arguments.length?(s=t,e&&h(),l):s},l.chords=function(){return e||u(),e},l.groups=function(){return r||u(),r},l},t.layout.force=function(){var e,r,n,i,a,o,s={},l=t.dispatch(\"start\",\"tick\",\"end\"),c=[1,1],u=.9,h=Ta,f=Aa,p=-30,d=Ma,g=.1,v=.64,m=[],y=[];function x(t){return function(e,r,n,i){if(e.point!==t){var a=e.cx-t.x,o=e.cy-t.y,s=i-r,l=a*a+o*o;if(s*s/v<l){if(l<d){var c=e.charge/l;t.px-=a*c,t.py-=o*c}return!0}if(e.point&&l&&l<d){c=e.pointCharge/l;t.px-=a*c,t.py-=o*c}}return!e.charge}}function b(e){e.px=t.event.x,e.py=t.event.y,s.resume()}return s.tick=function(){if((n*=.99)<.005)return e=null,l.end({type:\"end\",alpha:n=0}),!0;var r,s,h,f,d,v,b,_,w,k=m.length,T=y.length;for(s=0;s<T;++s)f=(h=y[s]).source,(v=(_=(d=h.target).x-f.x)*_+(w=d.y-f.y)*w)&&(_*=v=n*a[s]*((v=Math.sqrt(v))-i[s])/v,w*=v,d.x-=_*(b=f.weight+d.weight?f.weight/(f.weight+d.weight):.5),d.y-=w*b,f.x+=_*(b=1-b),f.y+=w*b);if((b=n*g)&&(_=c[0]/2,w=c[1]/2,s=-1,b))for(;++s<k;)(h=m[s]).x+=(_-h.x)*b,h.y+=(w-h.y)*b;if(p)for(!function t(e,r,n){var i=0,a=0;e.charge=0;if(!e.leaf)for(var o,s=e.nodes,l=s.length,c=-1;++c<l;)null!=(o=s[c])&&(t(o,r,n),e.charge+=o.charge,i+=o.charge*o.cx,a+=o.charge*o.cy);if(e.point){e.leaf||(e.point.x+=Math.random()-.5,e.point.y+=Math.random()-.5);var u=r*n[e.point.index];e.charge+=e.pointCharge=u,i+=u*e.point.x,a+=u*e.point.y}e.cx=i/e.charge;e.cy=a/e.charge}(r=t.geom.quadtree(m),n,o),s=-1;++s<k;)(h=m[s]).fixed||r.visit(x(h));for(s=-1;++s<k;)(h=m[s]).fixed?(h.x=h.px,h.y=h.py):(h.x-=(h.px-(h.px=h.x))*u,h.y-=(h.py-(h.py=h.y))*u);l.tick({type:\"tick\",alpha:n})},s.nodes=function(t){return arguments.length?(m=t,s):m},s.links=function(t){return arguments.length?(y=t,s):y},s.size=function(t){return arguments.length?(c=t,s):c},s.linkDistance=function(t){return arguments.length?(h=\"function\"==typeof t?t:+t,s):h},s.distance=s.linkDistance,s.linkStrength=function(t){return arguments.length?(f=\"function\"==typeof t?t:+t,s):f},s.friction=function(t){return arguments.length?(u=+t,s):u},s.charge=function(t){return arguments.length?(p=\"function\"==typeof t?t:+t,s):p},s.chargeDistance=function(t){return arguments.length?(d=t*t,s):Math.sqrt(d)},s.gravity=function(t){return arguments.length?(g=+t,s):g},s.theta=function(t){return arguments.length?(v=t*t,s):Math.sqrt(v)},s.alpha=function(t){return arguments.length?(t=+t,n?t>0?n=t:(e.c=null,e.t=NaN,e=null,l.end({type:\"end\",alpha:n=0})):t>0&&(l.start({type:\"start\",alpha:n=t}),e=Te(s.tick)),s):n},s.start=function(){var t,e,r,n=m.length,l=y.length,u=c[0],d=c[1];for(t=0;t<n;++t)(r=m[t]).index=t,r.weight=0;for(t=0;t<l;++t)\"number\"==typeof(r=y[t]).source&&(r.source=m[r.source]),\"number\"==typeof r.target&&(r.target=m[r.target]),++r.source.weight,++r.target.weight;for(t=0;t<n;++t)r=m[t],isNaN(r.x)&&(r.x=g(\"x\",u)),isNaN(r.y)&&(r.y=g(\"y\",d)),isNaN(r.px)&&(r.px=r.x),isNaN(r.py)&&(r.py=r.y);if(i=[],\"function\"==typeof h)for(t=0;t<l;++t)i[t]=+h.call(this,y[t],t);else for(t=0;t<l;++t)i[t]=h;if(a=[],\"function\"==typeof f)for(t=0;t<l;++t)a[t]=+f.call(this,y[t],t);else for(t=0;t<l;++t)a[t]=f;if(o=[],\"function\"==typeof p)for(t=0;t<n;++t)o[t]=+p.call(this,m[t],t);else for(t=0;t<n;++t)o[t]=p;function g(r,i){if(!e){for(e=new Array(n),c=0;c<n;++c)e[c]=[];for(c=0;c<l;++c){var a=y[c];e[a.source.index].push(a.target),e[a.target.index].push(a.source)}}for(var o,s=e[t],c=-1,u=s.length;++c<u;)if(!isNaN(o=s[c][r]))return o;return Math.random()*i}return s.resume()},s.resume=function(){return s.alpha(.1)},s.stop=function(){return s.alpha(0)},s.drag=function(){if(r||(r=t.behavior.drag().origin(P).on(\"dragstart.force\",ba).on(\"drag.force\",b).on(\"dragend.force\",_a)),!arguments.length)return r;this.on(\"mouseover.force\",wa).on(\"mouseout.force\",ka).call(r)},t.rebind(s,l,\"on\")};var Ta=20,Aa=1,Ma=1/0;function Sa(e,r){return t.rebind(e,r,\"sort\",\"children\",\"value\"),e.nodes=e,e.links=za,e}function Ea(t,e){for(var r=[t];null!=(t=r.pop());)if(e(t),(i=t.children)&&(n=i.length))for(var n,i;--n>=0;)r.push(i[n])}function Ca(t,e){for(var r=[t],n=[];null!=(t=r.pop());)if(n.push(t),(a=t.children)&&(i=a.length))for(var i,a,o=-1;++o<i;)r.push(a[o]);for(;null!=(t=n.pop());)e(t)}function La(t){return t.children}function Pa(t){return t.value}function Oa(t,e){return e.value-t.value}function za(e){return t.merge(e.map(function(t){return(t.children||[]).map(function(e){return{source:t,target:e}})}))}t.layout.hierarchy=function(){var t=Oa,e=La,r=Pa;function n(i){var a,o=[i],s=[];for(i.depth=0;null!=(a=o.pop());)if(s.push(a),(c=e.call(n,a,a.depth))&&(l=c.length)){for(var l,c,u;--l>=0;)o.push(u=c[l]),u.parent=a,u.depth=a.depth+1;r&&(a.value=0),a.children=c}else r&&(a.value=+r.call(n,a,a.depth)||0),delete a.children;return Ca(i,function(e){var n,i;t&&(n=e.children)&&n.sort(t),r&&(i=e.parent)&&(i.value+=e.value)}),s}return n.sort=function(e){return arguments.length?(t=e,n):t},n.children=function(t){return arguments.length?(e=t,n):e},n.value=function(t){return arguments.length?(r=t,n):r},n.revalue=function(t){return r&&(Ea(t,function(t){t.children&&(t.value=0)}),Ca(t,function(t){var e;t.children||(t.value=+r.call(n,t,t.depth)||0),(e=t.parent)&&(e.value+=t.value)})),t},n},t.layout.partition=function(){var e=t.layout.hierarchy(),r=[1,1];function n(t,n){var i=e.call(this,t,n);return function t(e,r,n,i){var a=e.children;if(e.x=r,e.y=e.depth*i,e.dx=n,e.dy=i,a&&(o=a.length)){var o,s,l,c=-1;for(n=e.value?n/e.value:0;++c<o;)t(s=a[c],r,l=s.value*n,i),r+=l}}(i[0],0,r[0],r[1]/function t(e){var r=e.children,n=0;if(r&&(i=r.length))for(var i,a=-1;++a<i;)n=Math.max(n,t(r[a]));return 1+n}(i[0])),i}return n.size=function(t){return arguments.length?(r=t,n):r},Sa(n,e)},t.layout.pie=function(){var e=Number,r=Ia,n=0,i=Mt,a=0;function o(s){var l,c=s.length,u=s.map(function(t,r){return+e.call(o,t,r)}),h=+(\"function\"==typeof n?n.apply(this,arguments):n),f=(\"function\"==typeof i?i.apply(this,arguments):i)-h,p=Math.min(Math.abs(f)/c,+(\"function\"==typeof a?a.apply(this,arguments):a)),d=p*(f<0?-1:1),g=t.sum(u),v=g?(f-c*d)/g:0,m=t.range(c),y=[];return null!=r&&m.sort(r===Ia?function(t,e){return u[e]-u[t]}:function(t,e){return r(s[t],s[e])}),m.forEach(function(t){y[t]={data:s[t],value:l=u[t],startAngle:h,endAngle:h+=l*v+d,padAngle:p}}),y}return o.value=function(t){return arguments.length?(e=t,o):e},o.sort=function(t){return arguments.length?(r=t,o):r},o.startAngle=function(t){return arguments.length?(n=t,o):n},o.endAngle=function(t){return arguments.length?(i=t,o):i},o.padAngle=function(t){return arguments.length?(a=t,o):a},o};var Ia={};function Da(t){return t.x}function Ra(t){return t.y}function Fa(t,e,r){t.y0=e,t.y=r}t.layout.stack=function(){var e=P,r=ja,n=Ua,i=Fa,a=Da,o=Ra;function s(l,c){if(!(p=l.length))return l;var u=l.map(function(t,r){return e.call(s,t,r)}),h=u.map(function(t){return t.map(function(t,e){return[a.call(s,t,e),o.call(s,t,e)]})}),f=r.call(s,h,c);u=t.permute(u,f),h=t.permute(h,f);var p,d,g,v,m=n.call(s,h,c),y=u[0].length;for(g=0;g<y;++g)for(i.call(s,u[0][g],v=m[g],h[0][g][1]),d=1;d<p;++d)i.call(s,u[d][g],v+=h[d-1][g][1],h[d][g][1]);return l}return s.values=function(t){return arguments.length?(e=t,s):e},s.order=function(t){return arguments.length?(r=\"function\"==typeof t?t:Ba.get(t)||ja,s):r},s.offset=function(t){return arguments.length?(n=\"function\"==typeof t?t:Na.get(t)||Ua,s):n},s.x=function(t){return arguments.length?(a=t,s):a},s.y=function(t){return arguments.length?(o=t,s):o},s.out=function(t){return arguments.length?(i=t,s):i},s};var Ba=t.map({\"inside-out\":function(e){var r,n,i=e.length,a=e.map(Va),o=e.map(qa),s=t.range(i).sort(function(t,e){return a[t]-a[e]}),l=0,c=0,u=[],h=[];for(r=0;r<i;++r)n=s[r],l<c?(l+=o[n],u.push(n)):(c+=o[n],h.push(n));return h.reverse().concat(u)},reverse:function(e){return t.range(e.length).reverse()},default:ja}),Na=t.map({silhouette:function(t){var e,r,n,i=t.length,a=t[0].length,o=[],s=0,l=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];n>s&&(s=n),o.push(n)}for(r=0;r<a;++r)l[r]=(s-o[r])/2;return l},wiggle:function(t){var e,r,n,i,a,o,s,l,c,u=t.length,h=t[0],f=h.length,p=[];for(p[0]=l=c=0,r=1;r<f;++r){for(e=0,i=0;e<u;++e)i+=t[e][r][1];for(e=0,a=0,s=h[r][0]-h[r-1][0];e<u;++e){for(n=0,o=(t[e][r][1]-t[e][r-1][1])/(2*s);n<e;++n)o+=(t[n][r][1]-t[n][r-1][1])/s;a+=o*t[e][r][1]}p[r]=l-=i?a/i*s:0,l<c&&(c=l)}for(r=0;r<f;++r)p[r]-=c;return p},expand:function(t){var e,r,n,i=t.length,a=t[0].length,o=1/i,s=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];if(n)for(e=0;e<i;e++)t[e][r][1]/=n;else for(e=0;e<i;e++)t[e][r][1]=o}for(r=0;r<a;++r)s[r]=0;return s},zero:Ua});function ja(e){return t.range(e.length)}function Ua(t){for(var e=-1,r=t[0].length,n=[];++e<r;)n[e]=0;return n}function Va(t){for(var e,r=1,n=0,i=t[0][1],a=t.length;r<a;++r)(e=t[r][1])>i&&(n=r,i=e);return n}function qa(t){return t.reduce(Ha,0)}function Ha(t,e){return t+e[1]}function Ga(t,e){return Ya(t,Math.ceil(Math.log(e.length)/Math.LN2+1))}function Ya(t,e){for(var r=-1,n=+t[0],i=(t[1]-n)/e,a=[];++r<=e;)a[r]=i*r+n;return a}function Wa(e){return[t.min(e),t.max(e)]}function Xa(t,e){return t.value-e.value}function Za(t,e){var r=t._pack_next;t._pack_next=e,e._pack_prev=t,e._pack_next=r,r._pack_prev=e}function Ja(t,e){t._pack_next=e,e._pack_prev=t}function Ka(t,e){var r=e.x-t.x,n=e.y-t.y,i=t.r+e.r;return.999*i*i>r*r+n*n}function $a(t){if((e=t.children)&&(l=e.length)){var e,r,n,i,a,o,s,l,c=1/0,u=-1/0,h=1/0,f=-1/0;if(e.forEach(Qa),(r=e[0]).x=-r.r,r.y=0,x(r),l>1&&((n=e[1]).x=n.r,n.y=0,x(n),l>2))for(eo(r,n,i=e[2]),x(i),Za(r,i),r._pack_prev=i,Za(i,n),n=r._pack_next,a=3;a<l;a++){eo(r,n,i=e[a]);var p=0,d=1,g=1;for(o=n._pack_next;o!==n;o=o._pack_next,d++)if(Ka(o,i)){p=1;break}if(1==p)for(s=r._pack_prev;s!==o._pack_prev&&!Ka(s,i);s=s._pack_prev,g++);p?(d<g||d==g&&n.r<r.r?Ja(r,n=o):Ja(r=s,n),a--):(Za(r,i),n=i,x(i))}var v=(c+u)/2,m=(h+f)/2,y=0;for(a=0;a<l;a++)(i=e[a]).x-=v,i.y-=m,y=Math.max(y,i.r+Math.sqrt(i.x*i.x+i.y*i.y));t.r=y,e.forEach(to)}function x(t){c=Math.min(t.x-t.r,c),u=Math.max(t.x+t.r,u),h=Math.min(t.y-t.r,h),f=Math.max(t.y+t.r,f)}}function Qa(t){t._pack_next=t._pack_prev=t}function to(t){delete t._pack_next,delete t._pack_prev}function eo(t,e,r){var n=t.r+r.r,i=e.x-t.x,a=e.y-t.y;if(n&&(i||a)){var o=e.r+r.r,s=i*i+a*a,l=.5+((n*=n)-(o*=o))/(2*s),c=Math.sqrt(Math.max(0,2*o*(n+s)-(n-=s)*n-o*o))/(2*s);r.x=t.x+l*i+c*a,r.y=t.y+l*a-c*i}else r.x=t.x+n,r.y=t.y}function ro(t,e){return t.parent==e.parent?1:2}function no(t){var e=t.children;return e.length?e[0]:t.t}function io(t){var e,r=t.children;return(e=r.length)?r[e-1]:t.t}function ao(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function oo(t,e,r){return t.a.parent===e.parent?t.a:r}function so(t){return{x:t.x,y:t.y,dx:t.dx,dy:t.dy}}function lo(t,e){var r=t.x+e[3],n=t.y+e[0],i=t.dx-e[1]-e[3],a=t.dy-e[0]-e[2];return i<0&&(r+=i/2,i=0),a<0&&(n+=a/2,a=0),{x:r,y:n,dx:i,dy:a}}function co(t){var e=t[0],r=t[t.length-1];return e<r?[e,r]:[r,e]}function uo(t){return t.rangeExtent?t.rangeExtent():co(t.range())}function ho(t,e,r,n){var i=r(t[0],t[1]),a=n(e[0],e[1]);return function(t){return a(i(t))}}function fo(t,e){var r,n=0,i=t.length-1,a=t[n],o=t[i];return o<a&&(r=n,n=i,i=r,r=a,a=o,o=r),t[n]=e.floor(a),t[i]=e.ceil(o),t}function po(t){return t?{floor:function(e){return Math.floor(e/t)*t},ceil:function(e){return Math.ceil(e/t)*t}}:go}t.layout.histogram=function(){var e=!0,r=Number,n=Wa,i=Ga;function a(a,o){for(var s,l,c=[],u=a.map(r,this),h=n.call(this,u,o),f=i.call(this,h,u,o),p=(o=-1,u.length),d=f.length-1,g=e?1:1/p;++o<d;)(s=c[o]=[]).dx=f[o+1]-(s.x=f[o]),s.y=0;if(d>0)for(o=-1;++o<p;)(l=u[o])>=h[0]&&l<=h[1]&&((s=c[t.bisect(f,l,1,d)-1]).y+=g,s.push(a[o]));return c}return a.value=function(t){return arguments.length?(r=t,a):r},a.range=function(t){return arguments.length?(n=ve(t),a):n},a.bins=function(t){return arguments.length?(i=\"number\"==typeof t?function(e){return Ya(e,t)}:ve(t),a):i},a.frequency=function(t){return arguments.length?(e=!!t,a):e},a},t.layout.pack=function(){var e,r=t.layout.hierarchy().sort(Xa),n=0,i=[1,1];function a(t,a){var o=r.call(this,t,a),s=o[0],l=i[0],c=i[1],u=null==e?Math.sqrt:\"function\"==typeof e?e:function(){return e};if(s.x=s.y=0,Ca(s,function(t){t.r=+u(t.value)}),Ca(s,$a),n){var h=n*(e?1:Math.max(2*s.r/l,2*s.r/c))/2;Ca(s,function(t){t.r+=h}),Ca(s,$a),Ca(s,function(t){t.r-=h})}return function t(e,r,n,i){var a=e.children;e.x=r+=i*e.x;e.y=n+=i*e.y;e.r*=i;if(a)for(var o=-1,s=a.length;++o<s;)t(a[o],r,n,i)}(s,l/2,c/2,e?1:1/Math.max(2*s.r/l,2*s.r/c)),o}return a.size=function(t){return arguments.length?(i=t,a):i},a.radius=function(t){return arguments.length?(e=null==t||\"function\"==typeof t?t:+t,a):e},a.padding=function(t){return arguments.length?(n=+t,a):n},Sa(a,r)},t.layout.tree=function(){var e=t.layout.hierarchy().sort(null).value(null),r=ro,n=[1,1],i=null;function a(t,a){var c=e.call(this,t,a),u=c[0],h=function(t){var e,r={A:null,children:[t]},n=[r];for(;null!=(e=n.pop());)for(var i,a=e.children,o=0,s=a.length;o<s;++o)n.push((a[o]=i={_:a[o],parent:e,children:(i=a[o].children)&&i.slice()||[],A:null,a:null,z:0,m:0,c:0,s:0,t:null,i:o}).a=i);return r.children[0]}(u);if(Ca(h,o),h.parent.m=-h.z,Ea(h,s),i)Ea(u,l);else{var f=u,p=u,d=u;Ea(u,function(t){t.x<f.x&&(f=t),t.x>p.x&&(p=t),t.depth>d.depth&&(d=t)});var g=r(f,p)/2-f.x,v=n[0]/(p.x+r(p,f)/2+g),m=n[1]/(d.depth||1);Ea(u,function(t){t.x=(t.x+g)*v,t.y=t.depth*m})}return c}function o(t){var e=t.children,n=t.parent.children,i=t.i?n[t.i-1]:null;if(e.length){!function(t){var e,r=0,n=0,i=t.children,a=i.length;for(;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(t);var a=(e[0].z+e[e.length-1].z)/2;i?(t.z=i.z+r(t._,i._),t.m=t.z-a):t.z=a}else i&&(t.z=i.z+r(t._,i._));t.parent.A=function(t,e,n){if(e){for(var i,a=t,o=t,s=e,l=a.parent.children[0],c=a.m,u=o.m,h=s.m,f=l.m;s=io(s),a=no(a),s&&a;)l=no(l),(o=io(o)).a=t,(i=s.z+h-a.z-c+r(s._,a._))>0&&(ao(oo(s,t,n),t,i),c+=i,u+=i),h+=s.m,c+=a.m,f+=l.m,u+=o.m;s&&!io(o)&&(o.t=s,o.m+=h-u),a&&!no(l)&&(l.t=a,l.m+=c-f,n=t)}return n}(t,i,t.parent.A||n[0])}function s(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function l(t){t.x*=n[0],t.y=t.depth*n[1]}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t)?l:null,a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null==(n=t)?null:l,a):i?n:null},Sa(a,e)},t.layout.cluster=function(){var e=t.layout.hierarchy().sort(null).value(null),r=ro,n=[1,1],i=!1;function a(a,o){var s,l=e.call(this,a,o),c=l[0],u=0;Ca(c,function(e){var n=e.children;n&&n.length?(e.x=function(t){return t.reduce(function(t,e){return t+e.x},0)/t.length}(n),e.y=function(e){return 1+t.max(e,function(t){return t.y})}(n)):(e.x=s?u+=r(e,s):0,e.y=0,s=e)});var h=function t(e){var r=e.children;return r&&r.length?t(r[0]):e}(c),f=function t(e){var r,n=e.children;return n&&(r=n.length)?t(n[r-1]):e}(c),p=h.x-r(h,f)/2,d=f.x+r(f,h)/2;return Ca(c,i?function(t){t.x=(t.x-c.x)*n[0],t.y=(c.y-t.y)*n[1]}:function(t){t.x=(t.x-p)/(d-p)*n[0],t.y=(1-(c.y?t.y/c.y:1))*n[1]}),l}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t),a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null!=(n=t),a):i?n:null},Sa(a,e)},t.layout.treemap=function(){var e,r=t.layout.hierarchy(),n=Math.round,i=[1,1],a=null,o=so,s=!1,l=\"squarify\",c=.5*(1+Math.sqrt(5));function u(t,e){for(var r,n,i=-1,a=t.length;++i<a;)n=(r=t[i]).value*(e<0?0:e),r.area=isNaN(n)||n<=0?0:n}function h(t){var e=t.children;if(e&&e.length){var r,n,i,a=o(t),s=[],c=e.slice(),f=1/0,g=\"slice\"===l?a.dx:\"dice\"===l?a.dy:\"slice-dice\"===l?1&t.depth?a.dy:a.dx:Math.min(a.dx,a.dy);for(u(c,a.dx*a.dy/t.value),s.area=0;(i=c.length)>0;)s.push(r=c[i-1]),s.area+=r.area,\"squarify\"!==l||(n=p(s,g))<=f?(c.pop(),f=n):(s.area-=s.pop().area,d(s,g,a,!1),g=Math.min(a.dx,a.dy),s.length=s.area=0,f=1/0);s.length&&(d(s,g,a,!0),s.length=s.area=0),e.forEach(h)}}function f(t){var e=t.children;if(e&&e.length){var r,n=o(t),i=e.slice(),a=[];for(u(i,n.dx*n.dy/t.value),a.area=0;r=i.pop();)a.push(r),a.area+=r.area,null!=r.z&&(d(a,r.z?n.dx:n.dy,n,!i.length),a.length=a.area=0);e.forEach(f)}}function p(t,e){for(var r,n=t.area,i=0,a=1/0,o=-1,s=t.length;++o<s;)(r=t[o].area)&&(r<a&&(a=r),r>i&&(i=r));return e*=e,(n*=n)?Math.max(e*i*c/n,n/(e*a*c)):1/0}function d(t,e,r,i){var a,o=-1,s=t.length,l=r.x,c=r.y,u=e?n(t.area/e):0;if(e==r.dx){for((i||u>r.dy)&&(u=r.dy);++o<s;)(a=t[o]).x=l,a.y=c,a.dy=u,l+=a.dx=Math.min(r.x+r.dx-l,u?n(a.area/u):0);a.z=!0,a.dx+=r.x+r.dx-l,r.y+=u,r.dy-=u}else{for((i||u>r.dx)&&(u=r.dx);++o<s;)(a=t[o]).x=l,a.y=c,a.dx=u,c+=a.dy=Math.min(r.y+r.dy-c,u?n(a.area/u):0);a.z=!1,a.dy+=r.y+r.dy-c,r.x+=u,r.dx-=u}}function g(t){var n=e||r(t),a=n[0];return a.x=a.y=0,a.value?(a.dx=i[0],a.dy=i[1]):a.dx=a.dy=0,e&&r.revalue(a),u([a],a.dx*a.dy/a.value),(e?f:h)(a),s&&(e=n),n}return g.size=function(t){return arguments.length?(i=t,g):i},g.padding=function(t){if(!arguments.length)return a;function e(e){return lo(e,t)}var r;return o=null==(a=t)?so:\"function\"==(r=typeof t)?function(e){var r=t.call(g,e,e.depth);return null==r?so(e):lo(e,\"number\"==typeof r?[r,r,r,r]:r)}:\"number\"===r?(t=[t,t,t,t],e):e,g},g.round=function(t){return arguments.length?(n=t?Math.round:Number,g):n!=Number},g.sticky=function(t){return arguments.length?(s=t,e=null,g):s},g.ratio=function(t){return arguments.length?(c=t,g):c},g.mode=function(t){return arguments.length?(l=t+\"\",g):l},Sa(g,r)},t.random={normal:function(t,e){var r=arguments.length;return r<2&&(e=1),r<1&&(t=0),function(){var r,n,i;do{i=(r=2*Math.random()-1)*r+(n=2*Math.random()-1)*n}while(!i||i>1);return t+e*r*Math.sqrt(-2*Math.log(i)/i)}},logNormal:function(){var e=t.random.normal.apply(t,arguments);return function(){return Math.exp(e())}},bates:function(e){var r=t.random.irwinHall(e);return function(){return r()/e}},irwinHall:function(t){return function(){for(var e=0,r=0;r<t;r++)e+=Math.random();return e}}},t.scale={};var go={floor:P,ceil:P};function vo(e,r,n,i){var a=[],o=[],s=0,l=Math.min(e.length,r.length)-1;for(e[l]<e[0]&&(e=e.slice().reverse(),r=r.slice().reverse());++s<=l;)a.push(n(e[s-1],e[s])),o.push(i(r[s-1],r[s]));return function(r){var n=t.bisect(e,r,1,l)-1;return o[n](a[n](r))}}function mo(e,r){return t.rebind(e,r,\"range\",\"rangeRound\",\"interpolate\",\"clamp\")}function yo(t,e){return fo(t,po(xo(t,e)[2])),fo(t,po(xo(t,e)[2])),t}function xo(t,e){null==e&&(e=10);var r=co(t),n=r[1]-r[0],i=Math.pow(10,Math.floor(Math.log(n/e)/Math.LN10)),a=e/n*i;return a<=.15?i*=10:a<=.35?i*=5:a<=.75&&(i*=2),r[0]=Math.ceil(r[0]/i)*i,r[1]=Math.floor(r[1]/i)*i+.5*i,r[2]=i,r}function bo(e,r){return t.range.apply(t,xo(e,r))}function _o(e,r,n){var i=xo(e,r);if(n){var a=Le.exec(n);if(a.shift(),\"s\"===a[8]){var o=t.formatPrefix(Math.max(y(i[0]),y(i[1])));return a[7]||(a[7]=\".\"+ko(o.scale(i[2]))),a[8]=\"f\",n=t.format(a.join(\"\")),function(t){return n(o.scale(t))+o.symbol}}a[7]||(a[7]=\".\"+function(t,e){var r=ko(e[2]);return t in wo?Math.abs(r-ko(Math.max(y(e[0]),y(e[1]))))+ +(\"e\"!==t):r-2*(\"%\"===t)}(a[8],i)),n=a.join(\"\")}else n=\",.\"+ko(i[2])+\"f\";return t.format(n)}t.scale.linear=function(){return function t(e,r,n,i){var a,o;function s(){var t=Math.min(e.length,r.length)>2?vo:ho,s=i?ma:va;return a=t(e,r,s,n),o=t(r,e,s,Zi),l}function l(t){return a(t)}l.invert=function(t){return o(t)};l.domain=function(t){return arguments.length?(e=t.map(Number),s()):e};l.range=function(t){return arguments.length?(r=t,s()):r};l.rangeRound=function(t){return l.range(t).interpolate(ca)};l.clamp=function(t){return arguments.length?(i=t,s()):i};l.interpolate=function(t){return arguments.length?(n=t,s()):n};l.ticks=function(t){return bo(e,t)};l.tickFormat=function(t,r){return _o(e,t,r)};l.nice=function(t){return yo(e,t),s()};l.copy=function(){return t(e,r,n,i)};return s()}([0,1],[0,1],Zi,!1)};var wo={s:1,g:1,p:1,r:1,e:1};function ko(t){return-Math.floor(Math.log(t)/Math.LN10+.01)}t.scale.log=function(){return function e(r,n,i,a){function o(t){return(i?Math.log(t<0?0:t):-Math.log(t>0?0:-t))/Math.log(n)}function s(t){return i?Math.pow(n,t):-Math.pow(n,-t)}function l(t){return r(o(t))}l.invert=function(t){return s(r.invert(t))};l.domain=function(t){return arguments.length?(i=t[0]>=0,r.domain((a=t.map(Number)).map(o)),l):a};l.base=function(t){return arguments.length?(n=+t,r.domain(a.map(o)),l):n};l.nice=function(){var t=fo(a.map(o),i?Math:Ao);return r.domain(t),a=t.map(s),l};l.ticks=function(){var t=co(a),e=[],r=t[0],l=t[1],c=Math.floor(o(r)),u=Math.ceil(o(l)),h=n%1?2:n;if(isFinite(u-c)){if(i){for(;c<u;c++)for(var f=1;f<h;f++)e.push(s(c)*f);e.push(s(c))}else for(e.push(s(c));c++<u;)for(var f=h-1;f>0;f--)e.push(s(c)*f);for(c=0;e[c]<r;c++);for(u=e.length;e[u-1]>l;u--);e=e.slice(c,u)}return e};l.tickFormat=function(e,r){if(!arguments.length)return To;arguments.length<2?r=To:\"function\"!=typeof r&&(r=t.format(r));var i=Math.max(1,n*e/l.ticks().length);return function(t){var e=t/s(Math.round(o(t)));return e*n<n-.5&&(e*=n),e<=i?r(t):\"\"}};l.copy=function(){return e(r.copy(),n,i,a)};return mo(l,r)}(t.scale.linear().domain([0,1]),10,!0,[1,10])};var To=t.format(\".0e\"),Ao={floor:function(t){return-Math.ceil(-t)},ceil:function(t){return-Math.floor(-t)}};function Mo(t){return function(e){return e<0?-Math.pow(-e,t):Math.pow(e,t)}}t.scale.pow=function(){return function t(e,r,n){var i=Mo(r),a=Mo(1/r);function o(t){return e(i(t))}o.invert=function(t){return a(e.invert(t))};o.domain=function(t){return arguments.length?(e.domain((n=t.map(Number)).map(i)),o):n};o.ticks=function(t){return bo(n,t)};o.tickFormat=function(t,e){return _o(n,t,e)};o.nice=function(t){return o.domain(yo(n,t))};o.exponent=function(t){return arguments.length?(i=Mo(r=t),a=Mo(1/r),e.domain(n.map(i)),o):r};o.copy=function(){return t(e.copy(),r,n)};return mo(o,e)}(t.scale.linear(),1,[0,1])},t.scale.sqrt=function(){return t.scale.pow().exponent(.5)},t.scale.ordinal=function(){return function e(r,n){var i,a,o;function s(t){return a[((i.get(t)||(\"range\"===n.t?i.set(t,r.push(t)):NaN))-1)%a.length]}function l(e,n){return t.range(r.length).map(function(t){return e+n*t})}s.domain=function(t){if(!arguments.length)return r;r=[],i=new b;for(var e,a=-1,o=t.length;++a<o;)i.has(e=t[a])||i.set(e,r.push(e));return s[n.t].apply(s,n.a)};s.range=function(t){return arguments.length?(a=t,o=0,n={t:\"range\",a:arguments},s):a};s.rangePoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=(i+c)/2,0):(c-i)/(r.length-1+e);return a=l(i+u*e/2,u),o=0,n={t:\"rangePoints\",a:arguments},s};s.rangeRoundPoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=c=Math.round((i+c)/2),0):(c-i)/(r.length-1+e)|0;return a=l(i+Math.round(u*e/2+(c-i-(r.length-1+e)*u)/2),u),o=0,n={t:\"rangeRoundPoints\",a:arguments},s};s.rangeBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],h=t[1-c],f=(h-u)/(r.length-e+2*i);return a=l(u+f*i,f),c&&a.reverse(),o=f*(1-e),n={t:\"rangeBands\",a:arguments},s};s.rangeRoundBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],h=t[1-c],f=Math.floor((h-u)/(r.length-e+2*i));return a=l(u+Math.round((h-u-(r.length-e)*f)/2),f),c&&a.reverse(),o=Math.round(f*(1-e)),n={t:\"rangeRoundBands\",a:arguments},s};s.rangeBand=function(){return o};s.rangeExtent=function(){return co(n.a[0])};s.copy=function(){return e(r,n)};return s.domain(r)}([],{t:\"range\",a:[[]]})},t.scale.category10=function(){return t.scale.ordinal().range(So)},t.scale.category20=function(){return t.scale.ordinal().range(Eo)},t.scale.category20b=function(){return t.scale.ordinal().range(Co)},t.scale.category20c=function(){return t.scale.ordinal().range(Lo)};var So=[2062260,16744206,2924588,14034728,9725885,9197131,14907330,8355711,12369186,1556175].map(se),Eo=[2062260,11454440,16744206,16759672,2924588,10018698,14034728,16750742,9725885,12955861,9197131,12885140,14907330,16234194,8355711,13092807,12369186,14408589,1556175,10410725].map(se),Co=[3750777,5395619,7040719,10264286,6519097,9216594,11915115,13556636,9202993,12426809,15186514,15190932,8666169,11356490,14049643,15177372,8077683,10834324,13528509,14589654].map(se),Lo=[3244733,7057110,10406625,13032431,15095053,16616764,16625259,16634018,3253076,7652470,10607003,13101504,7695281,10394312,12369372,14342891,6513507,9868950,12434877,14277081].map(se);function Po(){return 0}t.scale.quantile=function(){return function e(r,n){var i;function a(){var e=0,a=n.length;for(i=[];++e<a;)i[e-1]=t.quantile(r,e/a);return o}function o(e){if(!isNaN(e=+e))return n[t.bisect(i,e)]}o.domain=function(t){return arguments.length?(r=t.map(p).filter(d).sort(f),a()):r};o.range=function(t){return arguments.length?(n=t,a()):n};o.quantiles=function(){return i};o.invertExtent=function(t){return(t=n.indexOf(t))<0?[NaN,NaN]:[t>0?i[t-1]:r[0],t<i.length?i[t]:r[r.length-1]]};o.copy=function(){return e(r,n)};return a()}([],[])},t.scale.quantize=function(){return function t(e,r,n){var i,a;function o(t){return n[Math.max(0,Math.min(a,Math.floor(i*(t-e))))]}function s(){return i=n.length/(r-e),a=n.length-1,o}o.domain=function(t){return arguments.length?(e=+t[0],r=+t[t.length-1],s()):[e,r]};o.range=function(t){return arguments.length?(n=t,s()):n};o.invertExtent=function(t){return[t=(t=n.indexOf(t))<0?NaN:t/i+e,t+1/i]};o.copy=function(){return t(e,r,n)};return s()}(0,1,[0,1])},t.scale.threshold=function(){return function e(r,n){function i(e){if(e<=e)return n[t.bisect(r,e)]}i.domain=function(t){return arguments.length?(r=t,i):r};i.range=function(t){return arguments.length?(n=t,i):n};i.invertExtent=function(t){return t=n.indexOf(t),[r[t-1],r[t]]};i.copy=function(){return e(r,n)};return i}([.5],[0,1])},t.scale.identity=function(){return function t(e){function r(t){return+t}r.invert=r;r.domain=r.range=function(t){return arguments.length?(e=t.map(r),r):e};r.ticks=function(t){return bo(e,t)};r.tickFormat=function(t,r){return _o(e,t,r)};r.copy=function(){return t(e)};return r}([0,1])},t.svg={},t.svg.arc=function(){var t=zo,e=Io,r=Po,n=Oo,i=Do,a=Ro,o=Fo;function s(){var s=Math.max(0,+t.apply(this,arguments)),c=Math.max(0,+e.apply(this,arguments)),u=i.apply(this,arguments)-Et,h=a.apply(this,arguments)-Et,f=Math.abs(h-u),p=u>h?0:1;if(c<s&&(d=c,c=s,s=d),f>=St)return l(c,p)+(s?l(s,1-p):\"\")+\"Z\";var d,g,v,m,y,x,b,_,w,k,T,A,M=0,S=0,E=[];if((m=(+o.apply(this,arguments)||0)/2)&&(v=n===Oo?Math.sqrt(s*s+c*c):+n.apply(this,arguments),p||(S*=-1),c&&(S=It(v/c*Math.sin(m))),s&&(M=It(v/s*Math.sin(m)))),c){y=c*Math.cos(u+S),x=c*Math.sin(u+S),b=c*Math.cos(h-S),_=c*Math.sin(h-S);var C=Math.abs(h-u-2*S)<=At?0:1;if(S&&Bo(y,x,b,_)===p^C){var L=(u+h)/2;y=c*Math.cos(L),x=c*Math.sin(L),b=_=null}}else y=x=0;if(s){w=s*Math.cos(h-M),k=s*Math.sin(h-M),T=s*Math.cos(u+M),A=s*Math.sin(u+M);var P=Math.abs(u-h+2*M)<=At?0:1;if(M&&Bo(w,k,T,A)===1-p^P){var O=(u+h)/2;w=s*Math.cos(O),k=s*Math.sin(O),T=A=null}}else w=k=0;if(f>kt&&(d=Math.min(Math.abs(c-s)/2,+r.apply(this,arguments)))>.001){g=s<c^p?0:1;var z=d,I=d;if(f<At){var D=null==T?[w,k]:null==b?[y,x]:si([y,x],[T,A],[b,_],[w,k]),R=y-D[0],F=x-D[1],B=b-D[0],N=_-D[1],j=1/Math.sin(Math.acos((R*B+F*N)/(Math.sqrt(R*R+F*F)*Math.sqrt(B*B+N*N)))/2),U=Math.sqrt(D[0]*D[0]+D[1]*D[1]);I=Math.min(d,(s-U)/(j-1)),z=Math.min(d,(c-U)/(j+1))}if(null!=b){var V=No(null==T?[w,k]:[T,A],[y,x],c,z,p),q=No([b,_],[w,k],c,z,p);d===z?E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 0,\",g,\" \",V[1],\"A\",c,\",\",c,\" 0 \",1-p^Bo(V[1][0],V[1][1],q[1][0],q[1][1]),\",\",p,\" \",q[1],\"A\",z,\",\",z,\" 0 0,\",g,\" \",q[0]):E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 1,\",g,\" \",q[0])}else E.push(\"M\",y,\",\",x);if(null!=T){var H=No([y,x],[T,A],s,-I,p),G=No([w,k],null==b?[y,x]:[b,_],s,-I,p);d===I?E.push(\"L\",G[0],\"A\",I,\",\",I,\" 0 0,\",g,\" \",G[1],\"A\",s,\",\",s,\" 0 \",p^Bo(G[1][0],G[1][1],H[1][0],H[1][1]),\",\",1-p,\" \",H[1],\"A\",I,\",\",I,\" 0 0,\",g,\" \",H[0]):E.push(\"L\",G[0],\"A\",I,\",\",I,\" 0 0,\",g,\" \",H[0])}else E.push(\"L\",w,\",\",k)}else E.push(\"M\",y,\",\",x),null!=b&&E.push(\"A\",c,\",\",c,\" 0 \",C,\",\",p,\" \",b,\",\",_),E.push(\"L\",w,\",\",k),null!=T&&E.push(\"A\",s,\",\",s,\" 0 \",P,\",\",1-p,\" \",T,\",\",A);return E.push(\"Z\"),E.join(\"\")}function l(t,e){return\"M0,\"+t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+-t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+t}return s.innerRadius=function(e){return arguments.length?(t=ve(e),s):t},s.outerRadius=function(t){return arguments.length?(e=ve(t),s):e},s.cornerRadius=function(t){return arguments.length?(r=ve(t),s):r},s.padRadius=function(t){return arguments.length?(n=t==Oo?Oo:ve(t),s):n},s.startAngle=function(t){return arguments.length?(i=ve(t),s):i},s.endAngle=function(t){return arguments.length?(a=ve(t),s):a},s.padAngle=function(t){return arguments.length?(o=ve(t),s):o},s.centroid=function(){var r=(+t.apply(this,arguments)+ +e.apply(this,arguments))/2,n=(+i.apply(this,arguments)+ +a.apply(this,arguments))/2-Et;return[Math.cos(n)*r,Math.sin(n)*r]},s};var Oo=\"auto\";function zo(t){return t.innerRadius}function Io(t){return t.outerRadius}function Do(t){return t.startAngle}function Ro(t){return t.endAngle}function Fo(t){return t&&t.padAngle}function Bo(t,e,r,n){return(t-r)*e-(e-n)*t>0?0:1}function No(t,e,r,n,i){var a=t[0]-e[0],o=t[1]-e[1],s=(i?n:-n)/Math.sqrt(a*a+o*o),l=s*o,c=-s*a,u=t[0]+l,h=t[1]+c,f=e[0]+l,p=e[1]+c,d=(u+f)/2,g=(h+p)/2,v=f-u,m=p-h,y=v*v+m*m,x=r-n,b=u*p-f*h,_=(m<0?-1:1)*Math.sqrt(Math.max(0,x*x*y-b*b)),w=(b*m-v*_)/y,k=(-b*v-m*_)/y,T=(b*m+v*_)/y,A=(-b*v+m*_)/y,M=w-d,S=k-g,E=T-d,C=A-g;return M*M+S*S>E*E+C*C&&(w=T,k=A),[[w-l,k-c],[w*r/x,k*r/x]]}function jo(t){var e=ei,r=ri,n=Yr,i=Vo,a=i.key,o=.7;function s(a){var s,l=[],c=[],u=-1,h=a.length,f=ve(e),p=ve(r);function d(){l.push(\"M\",i(t(c),o))}for(;++u<h;)n.call(this,s=a[u],u)?c.push([+f.call(this,s,u),+p.call(this,s,u)]):c.length&&(d(),c=[]);return c.length&&d(),l.length?l.join(\"\"):null}return s.x=function(t){return arguments.length?(e=t,s):e},s.y=function(t){return arguments.length?(r=t,s):r},s.defined=function(t){return arguments.length?(n=t,s):n},s.interpolate=function(t){return arguments.length?(a=\"function\"==typeof t?i=t:(i=Uo.get(t)||Vo).key,s):a},s.tension=function(t){return arguments.length?(o=t,s):o},s}t.svg.line=function(){return jo(P)};var Uo=t.map({linear:Vo,\"linear-closed\":qo,step:function(t){var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];for(;++e<r;)i.push(\"H\",(n[0]+(n=t[e])[0])/2,\"V\",n[1]);r>1&&i.push(\"H\",n[0]);return i.join(\"\")},\"step-before\":Ho,\"step-after\":Go,basis:Xo,\"basis-open\":function(t){if(t.length<4)return Vo(t);var e,r=[],n=-1,i=t.length,a=[0],o=[0];for(;++n<3;)e=t[n],a.push(e[0]),o.push(e[1]);r.push(Zo($o,a)+\",\"+Zo($o,o)),--n;for(;++n<i;)e=t[n],a.shift(),a.push(e[0]),o.shift(),o.push(e[1]),Qo(r,a,o);return r.join(\"\")},\"basis-closed\":function(t){var e,r,n=-1,i=t.length,a=i+4,o=[],s=[];for(;++n<4;)r=t[n%i],o.push(r[0]),s.push(r[1]);e=[Zo($o,o),\",\",Zo($o,s)],--n;for(;++n<a;)r=t[n%i],o.shift(),o.push(r[0]),s.shift(),s.push(r[1]),Qo(e,o,s);return e.join(\"\")},bundle:function(t,e){var r=t.length-1;if(r)for(var n,i,a=t[0][0],o=t[0][1],s=t[r][0]-a,l=t[r][1]-o,c=-1;++c<=r;)n=t[c],i=c/r,n[0]=e*n[0]+(1-e)*(a+i*s),n[1]=e*n[1]+(1-e)*(o+i*l);return Xo(t)},cardinal:function(t,e){return t.length<3?Vo(t):t[0]+Yo(t,Wo(t,e))},\"cardinal-open\":function(t,e){return t.length<4?Vo(t):t[1]+Yo(t.slice(1,-1),Wo(t,e))},\"cardinal-closed\":function(t,e){return t.length<3?qo(t):t[0]+Yo((t.push(t[0]),t),Wo([t[t.length-2]].concat(t,[t[1]]),e))},monotone:function(t){return t.length<3?Vo(t):t[0]+Yo(t,function(t){var e,r,n,i,a=[],o=function(t){var e=0,r=t.length-1,n=[],i=t[0],a=t[1],o=n[0]=ts(i,a);for(;++e<r;)n[e]=(o+(o=ts(i=a,a=t[e+1])))/2;return n[e]=o,n}(t),s=-1,l=t.length-1;for(;++s<l;)e=ts(t[s],t[s+1]),y(e)<kt?o[s]=o[s+1]=0:(r=o[s]/e,n=o[s+1]/e,(i=r*r+n*n)>9&&(i=3*e/Math.sqrt(i),o[s]=i*r,o[s+1]=i*n));s=-1;for(;++s<=l;)i=(t[Math.min(l,s+1)][0]-t[Math.max(0,s-1)][0])/(6*(1+o[s]*o[s])),a.push([i||0,o[s]*i||0]);return a}(t))}});function Vo(t){return t.length>1?t.join(\"L\"):t+\"Z\"}function qo(t){return t.join(\"L\")+\"Z\"}function Ho(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"V\",(n=t[e])[1],\"H\",n[0]);return i.join(\"\")}function Go(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"H\",(n=t[e])[0],\"V\",n[1]);return i.join(\"\")}function Yo(t,e){if(e.length<1||t.length!=e.length&&t.length!=e.length+2)return Vo(t);var r=t.length!=e.length,n=\"\",i=t[0],a=t[1],o=e[0],s=o,l=1;if(r&&(n+=\"Q\"+(a[0]-2*o[0]/3)+\",\"+(a[1]-2*o[1]/3)+\",\"+a[0]+\",\"+a[1],i=t[1],l=2),e.length>1){s=e[1],a=t[l],l++,n+=\"C\"+(i[0]+o[0])+\",\"+(i[1]+o[1])+\",\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1];for(var c=2;c<e.length;c++,l++)a=t[l],s=e[c],n+=\"S\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1]}if(r){var u=t[l];n+=\"Q\"+(a[0]+2*s[0]/3)+\",\"+(a[1]+2*s[1]/3)+\",\"+u[0]+\",\"+u[1]}return n}function Wo(t,e){for(var r,n=[],i=(1-e)/2,a=t[0],o=t[1],s=1,l=t.length;++s<l;)r=a,a=o,o=t[s],n.push([i*(o[0]-r[0]),i*(o[1]-r[1])]);return n}function Xo(t){if(t.length<3)return Vo(t);var e=1,r=t.length,n=t[0],i=n[0],a=n[1],o=[i,i,i,(n=t[1])[0]],s=[a,a,a,n[1]],l=[i,\",\",a,\"L\",Zo($o,o),\",\",Zo($o,s)];for(t.push(t[r-1]);++e<=r;)n=t[e],o.shift(),o.push(n[0]),s.shift(),s.push(n[1]),Qo(l,o,s);return t.pop(),l.push(\"L\",n),l.join(\"\")}function Zo(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}Uo.forEach(function(t,e){e.key=t,e.closed=/-closed$/.test(t)});var Jo=[0,2/3,1/3,0],Ko=[0,1/3,2/3,0],$o=[0,1/6,2/3,1/6];function Qo(t,e,r){t.push(\"C\",Zo(Jo,e),\",\",Zo(Jo,r),\",\",Zo(Ko,e),\",\",Zo(Ko,r),\",\",Zo($o,e),\",\",Zo($o,r))}function ts(t,e){return(e[1]-t[1])/(e[0]-t[0])}function es(t){for(var e,r,n,i=-1,a=t.length;++i<a;)r=(e=t[i])[0],n=e[1]-Et,e[0]=r*Math.cos(n),e[1]=r*Math.sin(n);return t}function rs(t){var e=ei,r=ei,n=0,i=ri,a=Yr,o=Vo,s=o.key,l=o,c=\"L\",u=.7;function h(s){var h,f,p,d=[],g=[],v=[],m=-1,y=s.length,x=ve(e),b=ve(n),_=e===r?function(){return f}:ve(r),w=n===i?function(){return p}:ve(i);function k(){d.push(\"M\",o(t(v),u),c,l(t(g.reverse()),u),\"Z\")}for(;++m<y;)a.call(this,h=s[m],m)?(g.push([f=+x.call(this,h,m),p=+b.call(this,h,m)]),v.push([+_.call(this,h,m),+w.call(this,h,m)])):g.length&&(k(),g=[],v=[]);return g.length&&k(),d.length?d.join(\"\"):null}return h.x=function(t){return arguments.length?(e=r=t,h):r},h.x0=function(t){return arguments.length?(e=t,h):e},h.x1=function(t){return arguments.length?(r=t,h):r},h.y=function(t){return arguments.length?(n=i=t,h):i},h.y0=function(t){return arguments.length?(n=t,h):n},h.y1=function(t){return arguments.length?(i=t,h):i},h.defined=function(t){return arguments.length?(a=t,h):a},h.interpolate=function(t){return arguments.length?(s=\"function\"==typeof t?o=t:(o=Uo.get(t)||Vo).key,l=o.reverse||o,c=o.closed?\"M\":\"L\",h):s},h.tension=function(t){return arguments.length?(u=t,h):u},h}function ns(t){return t.radius}function is(t){return[t.x,t.y]}function as(){return 64}function os(){return\"circle\"}function ss(t){var e=Math.sqrt(t/At);return\"M0,\"+e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+-e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+e+\"Z\"}t.svg.line.radial=function(){var t=jo(es);return t.radius=t.x,delete t.x,t.angle=t.y,delete t.y,t},Ho.reverse=Go,Go.reverse=Ho,t.svg.area=function(){return rs(P)},t.svg.area.radial=function(){var t=rs(es);return t.radius=t.x,delete t.x,t.innerRadius=t.x0,delete t.x0,t.outerRadius=t.x1,delete t.x1,t.angle=t.y,delete t.y,t.startAngle=t.y0,delete t.y0,t.endAngle=t.y1,delete t.y1,t},t.svg.chord=function(){var t=Un,e=Vn,r=ns,n=Do,i=Ro;function a(r,n){var i,a,c=o(this,t,r,n),u=o(this,e,r,n);return\"M\"+c.p0+s(c.r,c.p1,c.a1-c.a0)+(a=u,(i=c).a0==a.a0&&i.a1==a.a1?l(c.r,c.p1,c.r,c.p0):l(c.r,c.p1,u.r,u.p0)+s(u.r,u.p1,u.a1-u.a0)+l(u.r,u.p1,c.r,c.p0))+\"Z\"}function o(t,e,a,o){var s=e.call(t,a,o),l=r.call(t,s,o),c=n.call(t,s,o)-Et,u=i.call(t,s,o)-Et;return{r:l,a0:c,a1:u,p0:[l*Math.cos(c),l*Math.sin(c)],p1:[l*Math.cos(u),l*Math.sin(u)]}}function s(t,e,r){return\"A\"+t+\",\"+t+\" 0 \"+ +(r>At)+\",1 \"+e}function l(t,e,r,n){return\"Q 0,0 \"+n}return a.radius=function(t){return arguments.length?(r=ve(t),a):r},a.source=function(e){return arguments.length?(t=ve(e),a):t},a.target=function(t){return arguments.length?(e=ve(t),a):e},a.startAngle=function(t){return arguments.length?(n=ve(t),a):n},a.endAngle=function(t){return arguments.length?(i=ve(t),a):i},a},t.svg.diagonal=function(){var t=Un,e=Vn,r=is;function n(n,i){var a=t.call(this,n,i),o=e.call(this,n,i),s=(a.y+o.y)/2,l=[a,{x:a.x,y:s},{x:o.x,y:s},o];return\"M\"+(l=l.map(r))[0]+\"C\"+l[1]+\" \"+l[2]+\" \"+l[3]}return n.source=function(e){return arguments.length?(t=ve(e),n):t},n.target=function(t){return arguments.length?(e=ve(t),n):e},n.projection=function(t){return arguments.length?(r=t,n):r},n},t.svg.diagonal.radial=function(){var e=t.svg.diagonal(),r=is,n=e.projection;return e.projection=function(t){return arguments.length?n(function(t){return function(){var e=t.apply(this,arguments),r=e[0],n=e[1]-Et;return[r*Math.cos(n),r*Math.sin(n)]}}(r=t)):r},e},t.svg.symbol=function(){var t=os,e=as;function r(r,n){return(ls.get(t.call(this,r,n))||ss)(e.call(this,r,n))}return r.type=function(e){return arguments.length?(t=ve(e),r):t},r.size=function(t){return arguments.length?(e=ve(t),r):e},r};var ls=t.map({circle:ss,cross:function(t){var e=Math.sqrt(t/5)/2;return\"M\"+-3*e+\",\"+-e+\"H\"+-e+\"V\"+-3*e+\"H\"+e+\"V\"+-e+\"H\"+3*e+\"V\"+e+\"H\"+e+\"V\"+3*e+\"H\"+-e+\"V\"+e+\"H\"+-3*e+\"Z\"},diamond:function(t){var e=Math.sqrt(t/(2*us)),r=e*us;return\"M0,\"+-e+\"L\"+r+\",0 0,\"+e+\" \"+-r+\",0Z\"},square:function(t){var e=Math.sqrt(t)/2;return\"M\"+-e+\",\"+-e+\"L\"+e+\",\"+-e+\" \"+e+\",\"+e+\" \"+-e+\",\"+e+\"Z\"},\"triangle-down\":function(t){var e=Math.sqrt(t/cs),r=e*cs/2;return\"M0,\"+r+\"L\"+e+\",\"+-r+\" \"+-e+\",\"+-r+\"Z\"},\"triangle-up\":function(t){var e=Math.sqrt(t/cs),r=e*cs/2;return\"M0,\"+-r+\"L\"+e+\",\"+r+\" \"+-e+\",\"+r+\"Z\"}});t.svg.symbolTypes=ls.keys();var cs=Math.sqrt(3),us=Math.tan(30*Ct);W.transition=function(t){for(var e,r,n=ds||++ms,i=bs(t),a=[],o=gs||{time:Date.now(),ease:ia,delay:0,duration:250},s=-1,l=this.length;++s<l;){a.push(e=[]);for(var c=this[s],u=-1,h=c.length;++u<h;)(r=c[u])&&_s(r,u,i,n,o),e.push(r)}return ps(a,i,n)},W.interrupt=function(t){return this.each(null==t?hs:fs(bs(t)))};var hs=fs(bs());function fs(t){return function(){var e,r,n;(e=this[t])&&(n=e[r=e.active])&&(n.timer.c=null,n.timer.t=NaN,--e.count?delete e[r]:delete this[t],e.active+=.5,n.event&&n.event.interrupt.call(this,this.__data__,n.index))}}function ps(t,e,r){return V(t,vs),t.namespace=e,t.id=r,t}var ds,gs,vs=[],ms=0;function ys(t,e,r,n){var i=t.id,a=t.namespace;return ut(t,\"function\"==typeof r?function(t,o,s){t[a][i].tween.set(e,n(r.call(t,t.__data__,o,s)))}:(r=n(r),function(t){t[a][i].tween.set(e,r)}))}function xs(t){return null==t&&(t=\"\"),function(){this.textContent=t}}function bs(t){return null==t?\"__transition__\":\"__transition_\"+t+\"__\"}function _s(t,e,r,n,i){var a,o,s,l,c,u=t[r]||(t[r]={active:0,count:0}),h=u[n];function f(r){var i=u.active,f=u[i];for(var d in f&&(f.timer.c=null,f.timer.t=NaN,--u.count,delete u[i],f.event&&f.event.interrupt.call(t,t.__data__,f.index)),u)if(+d<n){var g=u[d];g.timer.c=null,g.timer.t=NaN,--u.count,delete u[d]}o.c=p,Te(function(){return o.c&&p(r||1)&&(o.c=null,o.t=NaN),1},0,a),u.active=n,h.event&&h.event.start.call(t,t.__data__,e),c=[],h.tween.forEach(function(r,n){(n=n.call(t,t.__data__,e))&&c.push(n)}),l=h.ease,s=h.duration}function p(i){for(var a=i/s,o=l(a),f=c.length;f>0;)c[--f].call(t,o);if(a>=1)return h.event&&h.event.end.call(t,t.__data__,e),--u.count?delete u[n]:delete t[r],1}h||(a=i.time,o=Te(function(t){var e=h.delay;if(o.t=e+a,e<=t)return f(t-e);o.c=f},0,a),h=u[n]={tween:new b,time:a,timer:o,delay:i.delay,duration:i.duration,ease:i.ease,index:e},i=null,++u.count)}vs.call=W.call,vs.empty=W.empty,vs.node=W.node,vs.size=W.size,t.transition=function(e,r){return e&&e.transition?ds?e.transition(r):e:t.selection().transition(e)},t.transition.prototype=vs,vs.select=function(t){var e,r,n,i=this.id,a=this.namespace,o=[];t=X(t);for(var s=-1,l=this.length;++s<l;){o.push(e=[]);for(var c=this[s],u=-1,h=c.length;++u<h;)(n=c[u])&&(r=t.call(n,n.__data__,u,s))?(\"__data__\"in n&&(r.__data__=n.__data__),_s(r,u,a,i,n[a][i]),e.push(r)):e.push(null)}return ps(o,a,i)},vs.selectAll=function(t){var e,r,n,i,a,o=this.id,s=this.namespace,l=[];t=Z(t);for(var c=-1,u=this.length;++c<u;)for(var h=this[c],f=-1,p=h.length;++f<p;)if(n=h[f]){a=n[s][o],r=t.call(n,n.__data__,f,c),l.push(e=[]);for(var d=-1,g=r.length;++d<g;)(i=r[d])&&_s(i,d,s,o,a),e.push(i)}return ps(l,s,o)},vs.filter=function(t){var e,r,n=[];\"function\"!=typeof t&&(t=ct(t));for(var i=0,a=this.length;i<a;i++){n.push(e=[]);for(var o,s=0,l=(o=this[i]).length;s<l;s++)(r=o[s])&&t.call(r,r.__data__,s,i)&&e.push(r)}return ps(n,this.namespace,this.id)},vs.tween=function(t,e){var r=this.id,n=this.namespace;return arguments.length<2?this.node()[n][r].tween.get(t):ut(this,null==e?function(e){e[n][r].tween.remove(t)}:function(i){i[n][r].tween.set(t,e)})},vs.attr=function(e,r){if(arguments.length<2){for(r in e)this.attr(r,e[r]);return this}var n=\"transform\"==e?ga:Zi,i=t.ns.qualify(e);function a(){this.removeAttribute(i)}function o(){this.removeAttributeNS(i.space,i.local)}return ys(this,\"attr.\"+e,r,i.local?function(t){return null==t?o:(t+=\"\",function(){var e,r=this.getAttributeNS(i.space,i.local);return r!==t&&(e=n(r,t),function(t){this.setAttributeNS(i.space,i.local,e(t))})})}:function(t){return null==t?a:(t+=\"\",function(){var e,r=this.getAttribute(i);return r!==t&&(e=n(r,t),function(t){this.setAttribute(i,e(t))})})})},vs.attrTween=function(e,r){var n=t.ns.qualify(e);return this.tween(\"attr.\"+e,n.local?function(t,e){var i=r.call(this,t,e,this.getAttributeNS(n.space,n.local));return i&&function(t){this.setAttributeNS(n.space,n.local,i(t))}}:function(t,e){var i=r.call(this,t,e,this.getAttribute(n));return i&&function(t){this.setAttribute(n,i(t))}})},vs.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.style(r,t[r],e);return this}r=\"\"}function i(){this.style.removeProperty(t)}return ys(this,\"style.\"+t,e,function(e){return null==e?i:(e+=\"\",function(){var n,i=o(this).getComputedStyle(this,null).getPropertyValue(t);return i!==e&&(n=Zi(i,e),function(e){this.style.setProperty(t,n(e),r)})})})},vs.styleTween=function(t,e,r){return arguments.length<3&&(r=\"\"),this.tween(\"style.\"+t,function(n,i){var a=e.call(this,n,i,o(this).getComputedStyle(this,null).getPropertyValue(t));return a&&function(e){this.style.setProperty(t,a(e),r)}})},vs.text=function(t){return ys(this,\"text\",t,xs)},vs.remove=function(){var t=this.namespace;return this.each(\"end.transition\",function(){var e;this[t].count<2&&(e=this.parentNode)&&e.removeChild(this)})},vs.ease=function(e){var r=this.id,n=this.namespace;return arguments.length<1?this.node()[n][r].ease:(\"function\"!=typeof e&&(e=t.ease.apply(t,arguments)),ut(this,function(t){t[n][r].ease=e}))},vs.delay=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].delay:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].delay=+t.call(n,n.__data__,i,a)}:(t=+t,function(n){n[r][e].delay=t}))},vs.duration=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].duration:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].duration=Math.max(1,t.call(n,n.__data__,i,a))}:(t=Math.max(1,t),function(n){n[r][e].duration=t}))},vs.each=function(e,r){var n=this.id,i=this.namespace;if(arguments.length<2){var a=gs,o=ds;try{ds=n,ut(this,function(t,r,a){gs=t[i][n],e.call(t,t.__data__,r,a)})}finally{gs=a,ds=o}}else ut(this,function(a){var o=a[i][n];(o.event||(o.event=t.dispatch(\"start\",\"end\",\"interrupt\"))).on(e,r)});return this},vs.transition=function(){for(var t,e,r,n=this.id,i=++ms,a=this.namespace,o=[],s=0,l=this.length;s<l;s++){o.push(t=[]);for(var c,u=0,h=(c=this[s]).length;u<h;u++)(e=c[u])&&_s(e,u,a,i,{time:(r=e[a][n]).time,ease:r.ease,delay:r.delay+r.duration,duration:r.duration}),t.push(e)}return ps(o,a,i)},t.svg.axis=function(){var e,r=t.scale.linear(),i=ws,a=6,o=6,s=3,l=[10],c=null;function u(n){n.each(function(){var n,u=t.select(this),h=this.__chart__||r,f=this.__chart__=r.copy(),p=null==c?f.ticks?f.ticks.apply(f,l):f.domain():c,d=null==e?f.tickFormat?f.tickFormat.apply(f,l):P:e,g=u.selectAll(\".tick\").data(p,f),v=g.enter().insert(\"g\",\".domain\").attr(\"class\",\"tick\").style(\"opacity\",kt),m=t.transition(g.exit()).style(\"opacity\",kt).remove(),y=t.transition(g.order()).style(\"opacity\",1),x=Math.max(a,0)+s,b=uo(f),_=u.selectAll(\".domain\").data([0]),w=(_.enter().append(\"path\").attr(\"class\",\"domain\"),t.transition(_));v.append(\"line\"),v.append(\"text\");var k,T,A,M,S=v.select(\"line\"),E=y.select(\"line\"),C=g.select(\"text\").text(d),L=v.select(\"text\"),O=y.select(\"text\"),z=\"top\"===i||\"left\"===i?-1:1;if(\"bottom\"===i||\"top\"===i?(n=Ts,k=\"x\",A=\"y\",T=\"x2\",M=\"y2\",C.attr(\"dy\",z<0?\"0em\":\".71em\").style(\"text-anchor\",\"middle\"),w.attr(\"d\",\"M\"+b[0]+\",\"+z*o+\"V0H\"+b[1]+\"V\"+z*o)):(n=As,k=\"y\",A=\"x\",T=\"y2\",M=\"x2\",C.attr(\"dy\",\".32em\").style(\"text-anchor\",z<0?\"end\":\"start\"),w.attr(\"d\",\"M\"+z*o+\",\"+b[0]+\"H0V\"+b[1]+\"H\"+z*o)),S.attr(M,z*a),L.attr(A,z*x),E.attr(T,0).attr(M,z*a),O.attr(k,0).attr(A,z*x),f.rangeBand){var I=f,D=I.rangeBand()/2;h=f=function(t){return I(t)+D}}else h.rangeBand?h=f:m.call(n,f,h);v.call(n,h,f),y.call(n,f,f)})}return u.scale=function(t){return arguments.length?(r=t,u):r},u.orient=function(t){return arguments.length?(i=t in ks?t+\"\":ws,u):i},u.ticks=function(){return arguments.length?(l=n(arguments),u):l},u.tickValues=function(t){return arguments.length?(c=t,u):c},u.tickFormat=function(t){return arguments.length?(e=t,u):e},u.tickSize=function(t){var e=arguments.length;return e?(a=+t,o=+arguments[e-1],u):a},u.innerTickSize=function(t){return arguments.length?(a=+t,u):a},u.outerTickSize=function(t){return arguments.length?(o=+t,u):o},u.tickPadding=function(t){return arguments.length?(s=+t,u):s},u.tickSubdivide=function(){return arguments.length&&u},u};var ws=\"bottom\",ks={top:1,right:1,bottom:1,left:1};function Ts(t,e,r){t.attr(\"transform\",function(t){var n=e(t);return\"translate(\"+(isFinite(n)?n:r(t))+\",0)\"})}function As(t,e,r){t.attr(\"transform\",function(t){var n=e(t);return\"translate(0,\"+(isFinite(n)?n:r(t))+\")\"})}t.svg.brush=function(){var e,r,n=j(f,\"brushstart\",\"brush\",\"brushend\"),i=null,a=null,s=[0,0],l=[0,0],c=!0,u=!0,h=Ss[0];function f(e){e.each(function(){var e=t.select(this).style(\"pointer-events\",\"all\").style(\"-webkit-tap-highlight-color\",\"rgba(0,0,0,0)\").on(\"mousedown.brush\",v).on(\"touchstart.brush\",v),r=e.selectAll(\".background\").data([0]);r.enter().append(\"rect\").attr(\"class\",\"background\").style(\"visibility\",\"hidden\").style(\"cursor\",\"crosshair\"),e.selectAll(\".extent\").data([0]).enter().append(\"rect\").attr(\"class\",\"extent\").style(\"cursor\",\"move\");var n=e.selectAll(\".resize\").data(h,P);n.exit().remove(),n.enter().append(\"g\").attr(\"class\",function(t){return\"resize \"+t}).style(\"cursor\",function(t){return Ms[t]}).append(\"rect\").attr(\"x\",function(t){return/[ew]$/.test(t)?-3:null}).attr(\"y\",function(t){return/^[ns]/.test(t)?-3:null}).attr(\"width\",6).attr(\"height\",6).style(\"visibility\",\"hidden\"),n.style(\"display\",f.empty()?\"none\":null);var o,s=t.transition(e),l=t.transition(r);i&&(o=uo(i),l.attr(\"x\",o[0]).attr(\"width\",o[1]-o[0]),d(s)),a&&(o=uo(a),l.attr(\"y\",o[0]).attr(\"height\",o[1]-o[0]),g(s)),p(s)})}function p(t){t.selectAll(\".resize\").attr(\"transform\",function(t){return\"translate(\"+s[+/e$/.test(t)]+\",\"+l[+/^s/.test(t)]+\")\"})}function d(t){t.select(\".extent\").attr(\"x\",s[0]),t.selectAll(\".extent,.n>rect,.s>rect\").attr(\"width\",s[1]-s[0])}function g(t){t.select(\".extent\").attr(\"y\",l[0]),t.selectAll(\".extent,.e>rect,.w>rect\").attr(\"height\",l[1]-l[0])}function v(){var h,v,m=this,y=t.select(t.event.target),x=n.of(m,arguments),b=t.select(m),_=y.datum(),w=!/^(n|s)$/.test(_)&&i,k=!/^(e|w)$/.test(_)&&a,T=y.classed(\"extent\"),A=xt(m),M=t.mouse(m),S=t.select(o(m)).on(\"keydown.brush\",function(){32==t.event.keyCode&&(T||(h=null,M[0]-=s[1],M[1]-=l[1],T=2),B())}).on(\"keyup.brush\",function(){32==t.event.keyCode&&2==T&&(M[0]+=s[1],M[1]+=l[1],T=0,B())});if(t.event.changedTouches?S.on(\"touchmove.brush\",L).on(\"touchend.brush\",O):S.on(\"mousemove.brush\",L).on(\"mouseup.brush\",O),b.interrupt().selectAll(\"*\").interrupt(),T)M[0]=s[0]-M[0],M[1]=l[0]-M[1];else if(_){var E=+/w$/.test(_),C=+/^n/.test(_);v=[s[1-E]-M[0],l[1-C]-M[1]],M[0]=s[E],M[1]=l[C]}else t.event.altKey&&(h=M.slice());function L(){var e=t.mouse(m),r=!1;v&&(e[0]+=v[0],e[1]+=v[1]),T||(t.event.altKey?(h||(h=[(s[0]+s[1])/2,(l[0]+l[1])/2]),M[0]=s[+(e[0]<h[0])],M[1]=l[+(e[1]<h[1])]):h=null),w&&P(e,i,0)&&(d(b),r=!0),k&&P(e,a,1)&&(g(b),r=!0),r&&(p(b),x({type:\"brush\",mode:T?\"move\":\"resize\"}))}function P(t,n,i){var a,o,f=uo(n),p=f[0],d=f[1],g=M[i],v=i?l:s,m=v[1]-v[0];if(T&&(p-=g,d-=m+g),a=(i?u:c)?Math.max(p,Math.min(d,t[i])):t[i],T?o=(a+=g)+m:(h&&(g=Math.max(p,Math.min(d,2*h[i]-a))),g<a?(o=a,a=g):o=g),v[0]!=a||v[1]!=o)return i?r=null:e=null,v[0]=a,v[1]=o,!0}function O(){L(),b.style(\"pointer-events\",\"all\").selectAll(\".resize\").style(\"display\",f.empty()?\"none\":null),t.select(\"body\").style(\"cursor\",null),S.on(\"mousemove.brush\",null).on(\"mouseup.brush\",null).on(\"touchmove.brush\",null).on(\"touchend.brush\",null).on(\"keydown.brush\",null).on(\"keyup.brush\",null),A(),x({type:\"brushend\"})}b.style(\"pointer-events\",\"none\").selectAll(\".resize\").style(\"display\",null),t.select(\"body\").style(\"cursor\",y.style(\"cursor\")),x({type:\"brushstart\"}),L()}return f.event=function(i){i.each(function(){var i=n.of(this,arguments),a={x:s,y:l,i:e,j:r},o=this.__chart__||a;this.__chart__=a,ds?t.select(this).transition().each(\"start.brush\",function(){e=o.i,r=o.j,s=o.x,l=o.y,i({type:\"brushstart\"})}).tween(\"brush:brush\",function(){var t=Ji(s,a.x),n=Ji(l,a.y);return e=r=null,function(e){s=a.x=t(e),l=a.y=n(e),i({type:\"brush\",mode:\"resize\"})}}).each(\"end.brush\",function(){e=a.i,r=a.j,i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"})}):(i({type:\"brushstart\"}),i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"}))})},f.x=function(t){return arguments.length?(h=Ss[!(i=t)<<1|!a],f):i},f.y=function(t){return arguments.length?(h=Ss[!i<<1|!(a=t)],f):a},f.clamp=function(t){return arguments.length?(i&&a?(c=!!t[0],u=!!t[1]):i?c=!!t:a&&(u=!!t),f):i&&a?[c,u]:i?c:a?u:null},f.extent=function(t){var n,o,c,u,h;return arguments.length?(i&&(n=t[0],o=t[1],a&&(n=n[0],o=o[0]),e=[n,o],i.invert&&(n=i(n),o=i(o)),o<n&&(h=n,n=o,o=h),n==s[0]&&o==s[1]||(s=[n,o])),a&&(c=t[0],u=t[1],i&&(c=c[1],u=u[1]),r=[c,u],a.invert&&(c=a(c),u=a(u)),u<c&&(h=c,c=u,u=h),c==l[0]&&u==l[1]||(l=[c,u])),f):(i&&(e?(n=e[0],o=e[1]):(n=s[0],o=s[1],i.invert&&(n=i.invert(n),o=i.invert(o)),o<n&&(h=n,n=o,o=h))),a&&(r?(c=r[0],u=r[1]):(c=l[0],u=l[1],a.invert&&(c=a.invert(c),u=a.invert(u)),u<c&&(h=c,c=u,u=h))),i&&a?[[n,c],[o,u]]:i?[n,o]:a&&[c,u])},f.clear=function(){return f.empty()||(s=[0,0],l=[0,0],e=r=null),f},f.empty=function(){return!!i&&s[0]==s[1]||!!a&&l[0]==l[1]},t.rebind(f,n,\"on\")};var Ms={n:\"ns-resize\",e:\"ew-resize\",s:\"ns-resize\",w:\"ew-resize\",nw:\"nwse-resize\",ne:\"nesw-resize\",se:\"nwse-resize\",sw:\"nesw-resize\"},Ss=[[\"n\",\"e\",\"s\",\"w\",\"nw\",\"ne\",\"se\",\"sw\"],[\"e\",\"w\"],[\"n\",\"s\"],[]],Es=ze.format=sr.timeFormat,Cs=Es.utc,Ls=Cs(\"%Y-%m-%dT%H:%M:%S.%LZ\");function Ps(t){return t.toISOString()}function Os(e,r,n){function i(t){return e(t)}function a(e,n){var i=(e[1]-e[0])/n,a=t.bisect(Is,i);return a==Is.length?[r.year,xo(e.map(function(t){return t/31536e6}),n)[2]]:a?r[i/Is[a-1]<Is[a]/i?a-1:a]:[Fs,xo(e,n)[2]]}return i.invert=function(t){return zs(e.invert(t))},i.domain=function(t){return arguments.length?(e.domain(t),i):e.domain().map(zs)},i.nice=function(t,e){var r=i.domain(),n=co(r),o=null==t?a(n,10):\"number\"==typeof t&&a(n,t);function s(r){return!isNaN(r)&&!t.range(r,zs(+r+1),e).length}return o&&(t=o[0],e=o[1]),i.domain(fo(r,e>1?{floor:function(e){for(;s(e=t.floor(e));)e=zs(e-1);return e},ceil:function(e){for(;s(e=t.ceil(e));)e=zs(+e+1);return e}}:t))},i.ticks=function(t,e){var r=co(i.domain()),n=null==t?a(r,10):\"number\"==typeof t?a(r,t):!t.range&&[{range:t},e];return n&&(t=n[0],e=n[1]),t.range(r[0],zs(+r[1]+1),e<1?1:e)},i.tickFormat=function(){return n},i.copy=function(){return Os(e.copy(),r,n)},mo(i,e)}function zs(t){return new Date(t)}Es.iso=Date.prototype.toISOString&&+new Date(\"2000-01-01T00:00:00.000Z\")?Ps:Ls,Ps.parse=function(t){var e=new Date(t);return isNaN(e)?null:e},Ps.toString=Ls.toString,ze.second=Fe(function(t){return new Ie(1e3*Math.floor(t/1e3))},function(t,e){t.setTime(t.getTime()+1e3*Math.floor(e))},function(t){return t.getSeconds()}),ze.seconds=ze.second.range,ze.seconds.utc=ze.second.utc.range,ze.minute=Fe(function(t){return new Ie(6e4*Math.floor(t/6e4))},function(t,e){t.setTime(t.getTime()+6e4*Math.floor(e))},function(t){return t.getMinutes()}),ze.minutes=ze.minute.range,ze.minutes.utc=ze.minute.utc.range,ze.hour=Fe(function(t){var e=t.getTimezoneOffset()/60;return new Ie(36e5*(Math.floor(t/36e5-e)+e))},function(t,e){t.setTime(t.getTime()+36e5*Math.floor(e))},function(t){return t.getHours()}),ze.hours=ze.hour.range,ze.hours.utc=ze.hour.utc.range,ze.month=Fe(function(t){return(t=ze.day(t)).setDate(1),t},function(t,e){t.setMonth(t.getMonth()+e)},function(t){return t.getMonth()}),ze.months=ze.month.range,ze.months.utc=ze.month.utc.range;var Is=[1e3,5e3,15e3,3e4,6e4,3e5,9e5,18e5,36e5,108e5,216e5,432e5,864e5,1728e5,6048e5,2592e6,7776e6,31536e6],Ds=[[ze.second,1],[ze.second,5],[ze.second,15],[ze.second,30],[ze.minute,1],[ze.minute,5],[ze.minute,15],[ze.minute,30],[ze.hour,1],[ze.hour,3],[ze.hour,6],[ze.hour,12],[ze.day,1],[ze.day,2],[ze.week,1],[ze.month,1],[ze.month,3],[ze.year,1]],Rs=Es.multi([[\".%L\",function(t){return t.getMilliseconds()}],[\":%S\",function(t){return t.getSeconds()}],[\"%I:%M\",function(t){return t.getMinutes()}],[\"%I %p\",function(t){return t.getHours()}],[\"%a %d\",function(t){return t.getDay()&&1!=t.getDate()}],[\"%b %d\",function(t){return 1!=t.getDate()}],[\"%B\",function(t){return t.getMonth()}],[\"%Y\",Yr]]),Fs={range:function(e,r,n){return t.range(Math.ceil(e/n)*n,+r,n).map(zs)},floor:P,ceil:P};Ds.year=ze.year,ze.scale=function(){return Os(t.scale.linear(),Ds,Rs)};var Bs=Ds.map(function(t){return[t[0].utc,t[1]]}),Ns=Cs.multi([[\".%L\",function(t){return t.getUTCMilliseconds()}],[\":%S\",function(t){return t.getUTCSeconds()}],[\"%I:%M\",function(t){return t.getUTCMinutes()}],[\"%I %p\",function(t){return t.getUTCHours()}],[\"%a %d\",function(t){return t.getUTCDay()&&1!=t.getUTCDate()}],[\"%b %d\",function(t){return 1!=t.getUTCDate()}],[\"%B\",function(t){return t.getUTCMonth()}],[\"%Y\",Yr]]);function js(t){return JSON.parse(t.responseText)}function Us(t){var e=i.createRange();return e.selectNode(i.body),e.createContextualFragment(t.responseText)}Bs.year=ze.year.utc,ze.scale.utc=function(){return Os(t.scale.linear(),Bs,Ns)},t.text=me(function(t){return t.responseText}),t.json=function(t,e){return ye(t,\"application/json\",js,e)},t.html=function(t,e){return ye(t,\"text/html\",Us,e)},t.xml=me(function(t){return t.responseXML}),\"object\"==typeof e&&e.exports?e.exports=t:this.d3=t}()},{}],164:[function(t,e,r){e.exports=function(){for(var t=0;t<arguments.length;t++)if(void 0!==arguments[t])return arguments[t]}},{}],165:[function(t,e,r){\"use strict\";var n=t(\"incremental-convex-hull\"),i=t(\"uniq\");function a(t,e){this.point=t,this.index=e}function o(t,e){for(var r=t.point,n=e.point,i=r.length,a=0;a<i;++a){var o=n[a]-r[a];if(o)return o}return 0}e.exports=function(t,e){var r=t.length;if(0===r)return[];var s=t[0].length;if(s<1)return[];if(1===s)return function(t,e,r){if(1===t)return r?[[-1,0]]:[];var n=e.map(function(t,e){return[t[0],e]});n.sort(function(t,e){return t[0]-e[0]});for(var i=new Array(t-1),a=1;a<t;++a){var o=n[a-1],s=n[a];i[a-1]=[o[1],s[1]]}r&&i.push([-1,i[0][1]],[i[t-1][1],-1]);return i}(r,t,e);for(var l=new Array(r),c=1,u=0;u<r;++u){for(var h=t[u],f=new Array(s+1),p=0,d=0;d<s;++d){var g=h[d];f[d]=g,p+=g*g}f[s]=p,l[u]=new a(f,u),c=Math.max(p,c)}i(l,o),r=l.length;for(var v=new Array(r+s+1),m=new Array(r+s+1),y=(s+1)*(s+1)*c,x=new Array(s+1),u=0;u<=s;++u)x[u]=0;x[s]=y,v[0]=x.slice(),m[0]=-1;for(var u=0;u<=s;++u){var f=x.slice();f[u]=1,v[u+1]=f,m[u+1]=-1}for(var u=0;u<r;++u){var b=l[u];v[u+s+1]=b.point,m[u+s+1]=b.index}var _=n(v,!1);_=e?_.filter(function(t){for(var e=0,r=0;r<=s;++r){var n=m[t[r]];if(n<0&&++e>=2)return!1;t[r]=n}return!0}):_.filter(function(t){for(var e=0;e<=s;++e){var r=m[t[e]];if(r<0)return!1;t[e]=r}return!0});if(1&s)for(var u=0;u<_.length;++u){var b=_[u],f=b[0];b[0]=b[1],b[1]=f}return _}},{\"incremental-convex-hull\":413,uniq:547}],166:[function(t,e,r){\"use strict\";e.exports=a;var n=(a.canvas=document.createElement(\"canvas\")).getContext(\"2d\"),i=o([32,126]);function a(t,e){Array.isArray(t)&&(t=t.join(\", \"));var r,a={},s=16,l=.05;e&&(2===e.length&&\"number\"==typeof e[0]?r=o(e):Array.isArray(e)?r=e:(e.o?r=o(e.o):e.pairs&&(r=e.pairs),e.fontSize&&(s=e.fontSize),null!=e.threshold&&(l=e.threshold))),r||(r=i),n.font=s+\"px \"+t;for(var c=0;c<r.length;c++){var u=r[c],h=n.measureText(u[0]).width+n.measureText(u[1]).width,f=n.measureText(u).width;if(Math.abs(h-f)>s*l){var p=(f-h)/s;a[u]=1e3*p}}return a}function o(t){for(var e=[],r=t[0];r<=t[1];r++)for(var n=String.fromCharCode(r),i=t[0];i<t[1];i++){var a=n+String.fromCharCode(i);e.push(a)}return e}a.createPairs=o,a.ascii=i},{}],167:[function(t,e,r){(function(t){var r=!1;if(\"undefined\"!=typeof Float64Array){var n=new Float64Array(1),i=new Uint32Array(n.buffer);if(n[0]=1,r=!0,1072693248===i[1]){e.exports=function(t){return n[0]=t,[i[0],i[1]]},e.exports.pack=function(t,e){return i[0]=t,i[1]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[0]},e.exports.hi=function(t){return n[0]=t,i[1]}}else if(1072693248===i[0]){e.exports=function(t){return n[0]=t,[i[1],i[0]]},e.exports.pack=function(t,e){return i[1]=t,i[0]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[1]},e.exports.hi=function(t){return n[0]=t,i[0]}}else r=!1}if(!r){var a=new t(8);e.exports=function(t){return a.writeDoubleLE(t,0,!0),[a.readUInt32LE(0,!0),a.readUInt32LE(4,!0)]},e.exports.pack=function(t,e){return a.writeUInt32LE(t,0,!0),a.writeUInt32LE(e,4,!0),a.readDoubleLE(0,!0)},e.exports.lo=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(0,!0)},e.exports.hi=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(4,!0)}}e.exports.sign=function(t){return e.exports.hi(t)>>>31},e.exports.exponent=function(t){return(e.exports.hi(t)<<1>>>21)-1023},e.exports.fraction=function(t){var r=e.exports.lo(t),n=e.exports.hi(t),i=1048575&n;return 2146435072&n&&(i+=1<<20),[r,i]},e.exports.denormalized=function(t){return!(2146435072&e.exports.hi(t))}}).call(this,t(\"buffer\").Buffer)},{buffer:105}],168:[function(t,e,r){var n=t(\"abs-svg-path\"),i=t(\"normalize-svg-path\"),a={M:\"moveTo\",C:\"bezierCurveTo\"};e.exports=function(t,e){t.beginPath(),i(n(e)).forEach(function(e){var r=e[0],n=e.slice(1);t[a[r]].apply(t,n)}),t.closePath()}},{\"abs-svg-path\":60,\"normalize-svg-path\":452}],169:[function(t,e,r){e.exports=function(t){switch(t){case\"int8\":return Int8Array;case\"int16\":return Int16Array;case\"int32\":return Int32Array;case\"uint8\":return Uint8Array;case\"uint16\":return Uint16Array;case\"uint32\":return Uint32Array;case\"float32\":return Float32Array;case\"float64\":return Float64Array;case\"array\":return Array;case\"uint8_clamped\":return Uint8ClampedArray}}},{}],170:[function(t,e,r){\"use strict\";e.exports=function(t,e){switch(\"undefined\"==typeof e&&(e=0),typeof t){case\"number\":if(t>0)return function(t,e){var r,n;for(r=new Array(t),n=0;n<t;++n)r[n]=e;return r}(0|t,e);break;case\"object\":if(\"number\"==typeof t.length)return function t(e,r,n){var i=0|e[n];if(i<=0)return[];var a,o=new Array(i);if(n===e.length-1)for(a=0;a<i;++a)o[a]=r;else for(a=0;a<i;++a)o[a]=t(e,r,n+1);return o}(t,e,0)}return[]}},{}],171:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(\"number\"!=typeof e){e=0;for(var i=0;i<r;++i){var a=t[i];e=Math.max(e,a[0],a[1])}e=1+(0|e)}e|=0;for(var o=new Array(e),i=0;i<e;++i)o[i]=[];for(var i=0;i<r;++i){var a=t[i];o[a[0]].push(a[1]),o[a[1]].push(a[0])}for(var s=0;s<e;++s)n(o[s],function(t,e){return t-e});return o};var n=t(\"uniq\")},{uniq:547}],172:[function(t,e,r){var n=t(\"strongly-connected-components\");e.exports=function(t){var e,r=[],i=[],a=[],o={},s=[];function l(t){var r,n,u=!1;for(i.push(t),a[t]=!0,r=0;r<s[t].length;r++)(n=s[t][r])===e?(c(e,i),u=!0):a[n]||(u=l(n));if(u)!function t(e){a[e]=!1,o.hasOwnProperty(e)&&Object.keys(o[e]).forEach(function(r){delete o[e][r],a[r]&&t(r)})}(t);else for(r=0;r<s[t].length;r++){n=s[t][r];var h=o[n];h||(h={},o[n]=h),h[n]=!0}return i.pop(),u}function c(t,e){var n=[].concat(e).concat(t);r.push(n)}function u(e){!function(e){for(var r=0;r<t.length;r++)r<e&&(t[r]=[]),t[r]=t[r].filter(function(t){return t>=e})}(e);for(var r,i=n(t).components.filter(function(t){return t.length>1}),a=1/0,o=0;o<i.length;o++)for(var s=0;s<i[o].length;s++)i[o][s]<a&&(a=i[o][s],r=o);var l=i[r];return!!l&&{leastVertex:a,adjList:t.map(function(t,e){return-1===l.indexOf(e)?[]:t.filter(function(t){return-1!==l.indexOf(t)})})}}e=0;for(var h=t.length;e<h;){var f=u(e);if(e=f.leastVertex,s=f.adjList){for(var p=0;p<s.length;p++)for(var d=0;d<s[p].length;d++){var g=s[p][d];a[+g]=!1,o[g]={}}l(e),e+=1}else e=h}return r}},{\"strongly-connected-components\":530}],173:[function(t,e,r){\"use strict\";var n=t(\"../../object/valid-value\");e.exports=function(){return n(this).length=0,this}},{\"../../object/valid-value\":205}],174:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Array.from:t(\"./shim\")},{\"./is-implemented\":175,\"./shim\":176}],175:[function(t,e,r){\"use strict\";e.exports=function(){var t,e,r=Array.from;return\"function\"==typeof r&&(e=r(t=[\"raz\",\"dwa\"]),Boolean(e&&e!==t&&\"dwa\"===e[1]))}},{}],176:[function(t,e,r){\"use strict\";var n=t(\"es6-symbol\").iterator,i=t(\"../../function/is-arguments\"),a=t(\"../../function/is-function\"),o=t(\"../../number/to-pos-integer\"),s=t(\"../../object/valid-callable\"),l=t(\"../../object/valid-value\"),c=t(\"../../object/is-value\"),u=t(\"../../string/is-string\"),h=Array.isArray,f=Function.prototype.call,p={configurable:!0,enumerable:!0,writable:!0,value:null},d=Object.defineProperty;e.exports=function(t){var e,r,g,v,m,y,x,b,_,w,k=arguments[1],T=arguments[2];if(t=Object(l(t)),c(k)&&s(k),this&&this!==Array&&a(this))e=this;else{if(!k){if(i(t))return 1!==(m=t.length)?Array.apply(null,t):((v=new Array(1))[0]=t[0],v);if(h(t)){for(v=new Array(m=t.length),r=0;r<m;++r)v[r]=t[r];return v}}v=[]}if(!h(t))if(void 0!==(_=t[n])){for(x=s(_).call(t),e&&(v=new e),b=x.next(),r=0;!b.done;)w=k?f.call(k,T,b.value,r):b.value,e?(p.value=w,d(v,r,p)):v[r]=w,b=x.next(),++r;m=r}else if(u(t)){for(m=t.length,e&&(v=new e),r=0,g=0;r<m;++r)w=t[r],r+1<m&&(y=w.charCodeAt(0))>=55296&&y<=56319&&(w+=t[++r]),w=k?f.call(k,T,w,g):w,e?(p.value=w,d(v,g,p)):v[g]=w,++g;m=g}if(void 0===m)for(m=o(t.length),e&&(v=new e(m)),r=0;r<m;++r)w=k?f.call(k,T,t[r],r):t[r],e?(p.value=w,d(v,r,p)):v[r]=w;return e&&(p.value=null,v.length=m),v}},{\"../../function/is-arguments\":177,\"../../function/is-function\":178,\"../../number/to-pos-integer\":184,\"../../object/is-value\":194,\"../../object/valid-callable\":203,\"../../object/valid-value\":205,\"../../string/is-string\":209,\"es6-symbol\":219}],177:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(function(){return arguments}());e.exports=function(t){return n.call(t)===i}},{}],178:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(t(\"./noop\"));e.exports=function(t){return\"function\"==typeof t&&n.call(t)===i}},{\"./noop\":179}],179:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],180:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Math.sign:t(\"./shim\")},{\"./is-implemented\":181,\"./shim\":182}],181:[function(t,e,r){\"use strict\";e.exports=function(){var t=Math.sign;return\"function\"==typeof t&&(1===t(10)&&-1===t(-20))}},{}],182:[function(t,e,r){\"use strict\";e.exports=function(t){return t=Number(t),isNaN(t)||0===t?t:t>0?1:-1}},{}],183:[function(t,e,r){\"use strict\";var n=t(\"../math/sign\"),i=Math.abs,a=Math.floor;e.exports=function(t){return isNaN(t)?0:0!==(t=Number(t))&&isFinite(t)?n(t)*a(i(t)):t}},{\"../math/sign\":180}],184:[function(t,e,r){\"use strict\";var n=t(\"./to-integer\"),i=Math.max;e.exports=function(t){return i(0,n(t))}},{\"./to-integer\":183}],185:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./valid-value\"),a=Function.prototype.bind,o=Function.prototype.call,s=Object.keys,l=Object.prototype.propertyIsEnumerable;e.exports=function(t,e){return function(r,c){var u,h=arguments[2],f=arguments[3];return r=Object(i(r)),n(c),u=s(r),f&&u.sort(\"function\"==typeof f?a.call(f,r):void 0),\"function\"!=typeof t&&(t=u[t]),o.call(t,u,function(t,n){return l.call(r,t)?o.call(c,h,r[t],t,r,n):e})}}},{\"./valid-callable\":203,\"./valid-value\":205}],186:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.assign:t(\"./shim\")},{\"./is-implemented\":187,\"./shim\":188}],187:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=Object.assign;return\"function\"==typeof e&&(e(t={foo:\"raz\"},{bar:\"dwa\"},{trzy:\"trzy\"}),t.foo+t.bar+t.trzy===\"razdwatrzy\")}},{}],188:[function(t,e,r){\"use strict\";var n=t(\"../keys\"),i=t(\"../valid-value\"),a=Math.max;e.exports=function(t,e){var r,o,s,l=a(arguments.length,2);for(t=Object(i(t)),s=function(n){try{t[n]=e[n]}catch(t){r||(r=t)}},o=1;o<l;++o)e=arguments[o],n(e).forEach(s);if(void 0!==r)throw r;return t}},{\"../keys\":195,\"../valid-value\":205}],189:[function(t,e,r){\"use strict\";var n=t(\"../array/from\"),i=t(\"./assign\"),a=t(\"./valid-value\");e.exports=function(t){var e=Object(a(t)),r=arguments[1],o=Object(arguments[2]);if(e!==t&&!r)return e;var s={};return r?n(r,function(e){(o.ensure||e in t)&&(s[e]=t[e])}):i(s,t),s}},{\"../array/from\":174,\"./assign\":186,\"./valid-value\":205}],190:[function(t,e,r){\"use strict\";var n,i,a,o,s=Object.create;t(\"./set-prototype-of/is-implemented\")()||(n=t(\"./set-prototype-of/shim\")),e.exports=n?1!==n.level?s:(i={},a={},o={configurable:!1,enumerable:!1,writable:!0,value:void 0},Object.getOwnPropertyNames(Object.prototype).forEach(function(t){a[t]=\"__proto__\"!==t?o:{configurable:!0,enumerable:!1,writable:!0,value:void 0}}),Object.defineProperties(i,a),Object.defineProperty(n,\"nullPolyfill\",{configurable:!1,enumerable:!1,writable:!1,value:i}),function(t,e){return s(null===t?i:t,e)}):s},{\"./set-prototype-of/is-implemented\":201,\"./set-prototype-of/shim\":202}],191:[function(t,e,r){\"use strict\";e.exports=t(\"./_iterate\")(\"forEach\")},{\"./_iterate\":185}],192:[function(t,e,r){\"use strict\";e.exports=function(t){return\"function\"==typeof t}},{}],193:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i={function:!0,object:!0};e.exports=function(t){return n(t)&&i[typeof t]||!1}},{\"./is-value\":194}],194:[function(t,e,r){\"use strict\";var n=t(\"../function/noop\")();e.exports=function(t){return t!==n&&null!==t}},{\"../function/noop\":179}],195:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.keys:t(\"./shim\")},{\"./is-implemented\":196,\"./shim\":197}],196:[function(t,e,r){\"use strict\";e.exports=function(){try{return Object.keys(\"primitive\"),!0}catch(t){return!1}}},{}],197:[function(t,e,r){\"use strict\";var n=t(\"../is-value\"),i=Object.keys;e.exports=function(t){return i(n(t)?Object(t):t)}},{\"../is-value\":194}],198:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./for-each\"),a=Function.prototype.call;e.exports=function(t,e){var r={},o=arguments[2];return n(e),i(t,function(t,n,i,s){r[n]=a.call(e,o,t,n,i,s)}),r}},{\"./for-each\":191,\"./valid-callable\":203}],199:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i=Array.prototype.forEach,a=Object.create;e.exports=function(t){var e=a(null);return i.call(arguments,function(t){n(t)&&function(t,e){var r;for(r in t)e[r]=t[r]}(Object(t),e)}),e}},{\"./is-value\":194}],200:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.setPrototypeOf:t(\"./shim\")},{\"./is-implemented\":201,\"./shim\":202}],201:[function(t,e,r){\"use strict\";var n=Object.create,i=Object.getPrototypeOf,a={};e.exports=function(){var t=Object.setPrototypeOf,e=arguments[0]||n;return\"function\"==typeof t&&i(t(e(null),a))===a}},{}],202:[function(t,e,r){\"use strict\";var n,i,a,o,s=t(\"../is-object\"),l=t(\"../valid-value\"),c=Object.prototype.isPrototypeOf,u=Object.defineProperty,h={configurable:!0,enumerable:!1,writable:!0,value:void 0};n=function(t,e){if(l(t),null===e||s(e))return t;throw new TypeError(\"Prototype must be null or an object\")},e.exports=(i=function(){var t,e=Object.create(null),r={},n=Object.getOwnPropertyDescriptor(Object.prototype,\"__proto__\");if(n){try{(t=n.set).call(e,r)}catch(t){}if(Object.getPrototypeOf(e)===r)return{set:t,level:2}}return e.__proto__=r,Object.getPrototypeOf(e)===r?{level:2}:((e={}).__proto__=r,Object.getPrototypeOf(e)===r&&{level:1})}())?(2===i.level?i.set?(o=i.set,a=function(t,e){return o.call(n(t,e),e),t}):a=function(t,e){return n(t,e).__proto__=e,t}:a=function t(e,r){var i;return n(e,r),(i=c.call(t.nullPolyfill,e))&&delete t.nullPolyfill.__proto__,null===r&&(r=t.nullPolyfill),e.__proto__=r,i&&u(t.nullPolyfill,\"__proto__\",h),e},Object.defineProperty(a,\"level\",{configurable:!1,enumerable:!1,writable:!1,value:i.level})):null,t(\"../create\")},{\"../create\":190,\"../is-object\":193,\"../valid-value\":205}],203:[function(t,e,r){\"use strict\";e.exports=function(t){if(\"function\"!=typeof t)throw new TypeError(t+\" is not a function\");return t}},{}],204:[function(t,e,r){\"use strict\";var n=t(\"./is-object\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not an Object\");return t}},{\"./is-object\":193}],205:[function(t,e,r){\"use strict\";var n=t(\"./is-value\");e.exports=function(t){if(!n(t))throw new TypeError(\"Cannot use null or undefined\");return t}},{\"./is-value\":194}],206:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?String.prototype.contains:t(\"./shim\")},{\"./is-implemented\":207,\"./shim\":208}],207:[function(t,e,r){\"use strict\";var n=\"razdwatrzy\";e.exports=function(){return\"function\"==typeof n.contains&&(!0===n.contains(\"dwa\")&&!1===n.contains(\"foo\"))}},{}],208:[function(t,e,r){\"use strict\";var n=String.prototype.indexOf;e.exports=function(t){return n.call(this,t,arguments[1])>-1}},{}],209:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(\"\");e.exports=function(t){return\"string\"==typeof t||t&&\"object\"==typeof t&&(t instanceof String||n.call(t)===i)||!1}},{}],210:[function(t,e,r){\"use strict\";var n=Object.create(null),i=Math.random;e.exports=function(){var t;do{t=i().toString(36).slice(2)}while(n[t]);return t}},{}],211:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"es5-ext/string/#/contains\"),o=t(\"d\"),s=t(\"es6-symbol\"),l=t(\"./\"),c=Object.defineProperty;n=e.exports=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");l.call(this,t),e=e?a.call(e,\"key+value\")?\"key+value\":a.call(e,\"key\")?\"key\":\"value\":\"value\",c(this,\"__kind__\",o(\"\",e))},i&&i(n,l),delete n.prototype.constructor,n.prototype=Object.create(l.prototype,{_resolve:o(function(t){return\"value\"===this.__kind__?this.__list__[t]:\"key+value\"===this.__kind__?[t,this.__list__[t]]:t})}),c(n.prototype,s.toStringTag,o(\"c\",\"Array Iterator\"))},{\"./\":214,d:151,\"es5-ext/object/set-prototype-of\":200,\"es5-ext/string/#/contains\":206,\"es6-symbol\":219}],212:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/valid-callable\"),a=t(\"es5-ext/string/is-string\"),o=t(\"./get\"),s=Array.isArray,l=Function.prototype.call,c=Array.prototype.some;e.exports=function(t,e){var r,u,h,f,p,d,g,v,m=arguments[2];if(s(t)||n(t)?r=\"array\":a(t)?r=\"string\":t=o(t),i(e),h=function(){f=!0},\"array\"!==r)if(\"string\"!==r)for(u=t.next();!u.done;){if(l.call(e,m,u.value,h),f)return;u=t.next()}else for(d=t.length,p=0;p<d&&(g=t[p],p+1<d&&(v=g.charCodeAt(0))>=55296&&v<=56319&&(g+=t[++p]),l.call(e,m,g,h),!f);++p);else c.call(t,function(t){return l.call(e,m,t,h),f})}},{\"./get\":213,\"es5-ext/function/is-arguments\":177,\"es5-ext/object/valid-callable\":203,\"es5-ext/string/is-string\":209}],213:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/string/is-string\"),a=t(\"./array\"),o=t(\"./string\"),s=t(\"./valid-iterable\"),l=t(\"es6-symbol\").iterator;e.exports=function(t){return\"function\"==typeof s(t)[l]?t[l]():n(t)?new a(t):i(t)?new o(t):new a(t)}},{\"./array\":211,\"./string\":216,\"./valid-iterable\":217,\"es5-ext/function/is-arguments\":177,\"es5-ext/string/is-string\":209,\"es6-symbol\":219}],214:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/array/#/clear\"),a=t(\"es5-ext/object/assign\"),o=t(\"es5-ext/object/valid-callable\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"d\"),c=t(\"d/auto-bind\"),u=t(\"es6-symbol\"),h=Object.defineProperty,f=Object.defineProperties;e.exports=n=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");f(this,{__list__:l(\"w\",s(t)),__context__:l(\"w\",e),__nextIndex__:l(\"w\",0)}),e&&(o(e.on),e.on(\"_add\",this._onAdd),e.on(\"_delete\",this._onDelete),e.on(\"_clear\",this._onClear))},delete n.prototype.constructor,f(n.prototype,a({_next:l(function(){var t;if(this.__list__)return this.__redo__&&void 0!==(t=this.__redo__.shift())?t:this.__nextIndex__<this.__list__.length?this.__nextIndex__++:void this._unBind()}),next:l(function(){return this._createResult(this._next())}),_createResult:l(function(t){return void 0===t?{done:!0,value:void 0}:{done:!1,value:this._resolve(t)}}),_resolve:l(function(t){return this.__list__[t]}),_unBind:l(function(){this.__list__=null,delete this.__redo__,this.__context__&&(this.__context__.off(\"_add\",this._onAdd),this.__context__.off(\"_delete\",this._onDelete),this.__context__.off(\"_clear\",this._onClear),this.__context__=null)}),toString:l(function(){return\"[object \"+(this[u.toStringTag]||\"Object\")+\"]\"})},c({_onAdd:l(function(t){t>=this.__nextIndex__||(++this.__nextIndex__,this.__redo__?(this.__redo__.forEach(function(e,r){e>=t&&(this.__redo__[r]=++e)},this),this.__redo__.push(t)):h(this,\"__redo__\",l(\"c\",[t])))}),_onDelete:l(function(t){var e;t>=this.__nextIndex__||(--this.__nextIndex__,this.__redo__&&(-1!==(e=this.__redo__.indexOf(t))&&this.__redo__.splice(e,1),this.__redo__.forEach(function(e,r){e>t&&(this.__redo__[r]=--e)},this)))}),_onClear:l(function(){this.__redo__&&i.call(this.__redo__),this.__nextIndex__=0})}))),h(n.prototype,u.iterator,l(function(){return this}))},{d:151,\"d/auto-bind\":150,\"es5-ext/array/#/clear\":173,\"es5-ext/object/assign\":186,\"es5-ext/object/valid-callable\":203,\"es5-ext/object/valid-value\":205,\"es6-symbol\":219}],215:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/string/is-string\"),o=t(\"es6-symbol\").iterator,s=Array.isArray;e.exports=function(t){return!!i(t)&&(!!s(t)||(!!a(t)||(!!n(t)||\"function\"==typeof t[o])))}},{\"es5-ext/function/is-arguments\":177,\"es5-ext/object/is-value\":194,\"es5-ext/string/is-string\":209,\"es6-symbol\":219}],216:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"d\"),o=t(\"es6-symbol\"),s=t(\"./\"),l=Object.defineProperty;n=e.exports=function(t){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");t=String(t),s.call(this,t),l(this,\"__length__\",a(\"\",t.length))},i&&i(n,s),delete n.prototype.constructor,n.prototype=Object.create(s.prototype,{_next:a(function(){if(this.__list__)return this.__nextIndex__<this.__length__?this.__nextIndex__++:void this._unBind()}),_resolve:a(function(t){var e,r=this.__list__[t];return this.__nextIndex__===this.__length__?r:(e=r.charCodeAt(0))>=55296&&e<=56319?r+this.__list__[this.__nextIndex__++]:r})}),l(n.prototype,o.toStringTag,a(\"c\",\"String Iterator\"))},{\"./\":214,d:151,\"es5-ext/object/set-prototype-of\":200,\"es6-symbol\":219}],217:[function(t,e,r){\"use strict\";var n=t(\"./is-iterable\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not iterable\");return t}},{\"./is-iterable\":215}],218:[function(t,e,r){(function(n,i){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():t.ES6Promise=n()}(this,function(){\"use strict\";function e(t){return\"function\"==typeof t}var r=Array.isArray?Array.isArray:function(t){return\"[object Array]\"===Object.prototype.toString.call(t)},a=0,o=void 0,s=void 0,l=function(t,e){g[a]=t,g[a+1]=e,2===(a+=2)&&(s?s(v):_())};var c=\"undefined\"!=typeof window?window:void 0,u=c||{},h=u.MutationObserver||u.WebKitMutationObserver,f=\"undefined\"==typeof self&&\"undefined\"!=typeof n&&\"[object process]\"==={}.toString.call(n),p=\"undefined\"!=typeof Uint8ClampedArray&&\"undefined\"!=typeof importScripts&&\"undefined\"!=typeof MessageChannel;function d(){var t=setTimeout;return function(){return t(v,1)}}var g=new Array(1e3);function v(){for(var t=0;t<a;t+=2){(0,g[t])(g[t+1]),g[t]=void 0,g[t+1]=void 0}a=0}var m,y,x,b,_=void 0;function w(t,e){var r=arguments,n=this,i=new this.constructor(A);void 0===i[T]&&V(i);var a,o=n._state;return o?(a=r[o-1],l(function(){return j(o,i,a,n._result)})):R(n,i,t,e),i}function k(t){if(t&&\"object\"==typeof t&&t.constructor===this)return t;var e=new this(A);return O(e,t),e}f?_=function(){return n.nextTick(v)}:h?(y=0,x=new h(v),b=document.createTextNode(\"\"),x.observe(b,{characterData:!0}),_=function(){b.data=y=++y%2}):p?((m=new MessageChannel).port1.onmessage=v,_=function(){return m.port2.postMessage(0)}):_=void 0===c&&\"function\"==typeof t?function(){try{var e=t(\"vertx\");return o=e.runOnLoop||e.runOnContext,function(){o(v)}}catch(t){return d()}}():d();var T=Math.random().toString(36).substring(16);function A(){}var M=void 0,S=1,E=2,C=new B;function L(t){try{return t.then}catch(t){return C.error=t,C}}function P(t,r,n){r.constructor===t.constructor&&n===w&&r.constructor.resolve===k?function(t,e){e._state===S?I(t,e._result):e._state===E?D(t,e._result):R(e,void 0,function(e){return O(t,e)},function(e){return D(t,e)})}(t,r):n===C?D(t,C.error):void 0===n?I(t,r):e(n)?function(t,e,r){l(function(t){var n=!1,i=function(t,e,r,n){try{t.call(e,r,n)}catch(t){return t}}(r,e,function(r){n||(n=!0,e!==r?O(t,r):I(t,r))},function(e){n||(n=!0,D(t,e))},t._label);!n&&i&&(n=!0,D(t,i))},t)}(t,r,n):I(t,r)}function O(t,e){var r;t===e?D(t,new TypeError(\"You cannot resolve a promise with itself\")):\"function\"==typeof(r=e)||\"object\"==typeof r&&null!==r?P(t,e,L(e)):I(t,e)}function z(t){t._onerror&&t._onerror(t._result),F(t)}function I(t,e){t._state===M&&(t._result=e,t._state=S,0!==t._subscribers.length&&l(F,t))}function D(t,e){t._state===M&&(t._state=E,t._result=e,l(z,t))}function R(t,e,r,n){var i=t._subscribers,a=i.length;t._onerror=null,i[a]=e,i[a+S]=r,i[a+E]=n,0===a&&t._state&&l(F,t)}function F(t){var e=t._subscribers,r=t._state;if(0!==e.length){for(var n=void 0,i=void 0,a=t._result,o=0;o<e.length;o+=3)n=e[o],i=e[o+r],n?j(r,n,i,a):i(a);t._subscribers.length=0}}function B(){this.error=null}var N=new B;function j(t,r,n,i){var a=e(n),o=void 0,s=void 0,l=void 0,c=void 0;if(a){if((o=function(t,e){try{return t(e)}catch(t){return N.error=t,N}}(n,i))===N?(c=!0,s=o.error,o=null):l=!0,r===o)return void D(r,new TypeError(\"A promises callback cannot return that same promise.\"))}else o=i,l=!0;r._state!==M||(a&&l?O(r,o):c?D(r,s):t===S?I(r,o):t===E&&D(r,o))}var U=0;function V(t){t[T]=U++,t._state=void 0,t._result=void 0,t._subscribers=[]}function q(t,e){this._instanceConstructor=t,this.promise=new t(A),this.promise[T]||V(this.promise),r(e)?(this._input=e,this.length=e.length,this._remaining=e.length,this._result=new Array(this.length),0===this.length?I(this.promise,this._result):(this.length=this.length||0,this._enumerate(),0===this._remaining&&I(this.promise,this._result))):D(this.promise,new Error(\"Array Methods must be provided an Array\"))}function H(t){this[T]=U++,this._result=this._state=void 0,this._subscribers=[],A!==t&&(\"function\"!=typeof t&&function(){throw new TypeError(\"You must pass a resolver function as the first argument to the promise constructor\")}(),this instanceof H?function(t,e){try{e(function(e){O(t,e)},function(e){D(t,e)})}catch(e){D(t,e)}}(this,t):function(){throw new TypeError(\"Failed to construct 'Promise': Please use the 'new' operator, this object constructor cannot be called as a function.\")}())}function G(){var t=void 0;if(\"undefined\"!=typeof i)t=i;else if(\"undefined\"!=typeof self)t=self;else try{t=Function(\"return this\")()}catch(t){throw new Error(\"polyfill failed because global object is unavailable in this environment\")}var e=t.Promise;if(e){var r=null;try{r=Object.prototype.toString.call(e.resolve())}catch(t){}if(\"[object Promise]\"===r&&!e.cast)return}t.Promise=H}return q.prototype._enumerate=function(){for(var t=this.length,e=this._input,r=0;this._state===M&&r<t;r++)this._eachEntry(e[r],r)},q.prototype._eachEntry=function(t,e){var r=this._instanceConstructor,n=r.resolve;if(n===k){var i=L(t);if(i===w&&t._state!==M)this._settledAt(t._state,e,t._result);else if(\"function\"!=typeof i)this._remaining--,this._result[e]=t;else if(r===H){var a=new r(A);P(a,t,i),this._willSettleAt(a,e)}else this._willSettleAt(new r(function(e){return e(t)}),e)}else this._willSettleAt(n(t),e)},q.prototype._settledAt=function(t,e,r){var n=this.promise;n._state===M&&(this._remaining--,t===E?D(n,r):this._result[e]=r),0===this._remaining&&I(n,this._result)},q.prototype._willSettleAt=function(t,e){var r=this;R(t,void 0,function(t){return r._settledAt(S,e,t)},function(t){return r._settledAt(E,e,t)})},H.all=function(t){return new q(this,t).promise},H.race=function(t){var e=this;return r(t)?new e(function(r,n){for(var i=t.length,a=0;a<i;a++)e.resolve(t[a]).then(r,n)}):new e(function(t,e){return e(new TypeError(\"You must pass an array to race.\"))})},H.resolve=k,H.reject=function(t){var e=new this(A);return D(e,t),e},H._setScheduler=function(t){s=t},H._setAsap=function(t){l=t},H._asap=l,H.prototype={constructor:H,then:w,catch:function(t){return this.then(null,t)}},G(),H.polyfill=G,H.Promise=H,H})}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{_process:482}],219:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Symbol:t(\"./polyfill\")},{\"./is-implemented\":220,\"./polyfill\":222}],220:[function(t,e,r){\"use strict\";var n={object:!0,symbol:!0};e.exports=function(){var t;if(\"function\"!=typeof Symbol)return!1;t=Symbol(\"test symbol\");try{String(t)}catch(t){return!1}return!!n[typeof Symbol.iterator]&&(!!n[typeof Symbol.toPrimitive]&&!!n[typeof Symbol.toStringTag])}},{}],221:[function(t,e,r){\"use strict\";e.exports=function(t){return!!t&&(\"symbol\"==typeof t||!!t.constructor&&(\"Symbol\"===t.constructor.name&&\"Symbol\"===t[t.constructor.toStringTag]))}},{}],222:[function(t,e,r){\"use strict\";var n,i,a,o,s=t(\"d\"),l=t(\"./validate-symbol\"),c=Object.create,u=Object.defineProperties,h=Object.defineProperty,f=Object.prototype,p=c(null);if(\"function\"==typeof Symbol){n=Symbol;try{String(n()),o=!0}catch(t){}}var d,g=(d=c(null),function(t){for(var e,r,n=0;d[t+(n||\"\")];)++n;return d[t+=n||\"\"]=!0,h(f,e=\"@@\"+t,s.gs(null,function(t){r||(r=!0,h(this,e,s(t)),r=!1)})),e});a=function(t){if(this instanceof a)throw new TypeError(\"Symbol is not a constructor\");return i(t)},e.exports=i=function t(e){var r;if(this instanceof t)throw new TypeError(\"Symbol is not a constructor\");return o?n(e):(r=c(a.prototype),e=void 0===e?\"\":String(e),u(r,{__description__:s(\"\",e),__name__:s(\"\",g(e))}))},u(i,{for:s(function(t){return p[t]?p[t]:p[t]=i(String(t))}),keyFor:s(function(t){var e;for(e in l(t),p)if(p[e]===t)return e}),hasInstance:s(\"\",n&&n.hasInstance||i(\"hasInstance\")),isConcatSpreadable:s(\"\",n&&n.isConcatSpreadable||i(\"isConcatSpreadable\")),iterator:s(\"\",n&&n.iterator||i(\"iterator\")),match:s(\"\",n&&n.match||i(\"match\")),replace:s(\"\",n&&n.replace||i(\"replace\")),search:s(\"\",n&&n.search||i(\"search\")),species:s(\"\",n&&n.species||i(\"species\")),split:s(\"\",n&&n.split||i(\"split\")),toPrimitive:s(\"\",n&&n.toPrimitive||i(\"toPrimitive\")),toStringTag:s(\"\",n&&n.toStringTag||i(\"toStringTag\")),unscopables:s(\"\",n&&n.unscopables||i(\"unscopables\"))}),u(a.prototype,{constructor:s(i),toString:s(\"\",function(){return this.__name__})}),u(i.prototype,{toString:s(function(){return\"Symbol (\"+l(this).__description__+\")\"}),valueOf:s(function(){return l(this)})}),h(i.prototype,i.toPrimitive,s(\"\",function(){var t=l(this);return\"symbol\"==typeof t?t:t.toString()})),h(i.prototype,i.toStringTag,s(\"c\",\"Symbol\")),h(a.prototype,i.toStringTag,s(\"c\",i.prototype[i.toStringTag])),h(a.prototype,i.toPrimitive,s(\"c\",i.prototype[i.toPrimitive]))},{\"./validate-symbol\":223,d:151}],223:[function(t,e,r){\"use strict\";var n=t(\"./is-symbol\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not a symbol\");return t}},{\"./is-symbol\":221}],224:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=e||0,i=r||1;return[[t[12]+t[0],t[13]+t[1],t[14]+t[2],t[15]+t[3]],[t[12]-t[0],t[13]-t[1],t[14]-t[2],t[15]-t[3]],[t[12]+t[4],t[13]+t[5],t[14]+t[6],t[15]+t[7]],[t[12]-t[4],t[13]-t[5],t[14]-t[6],t[15]-t[7]],[n*t[12]+t[8],n*t[13]+t[9],n*t[14]+t[10],n*t[15]+t[11]],[i*t[12]-t[8],i*t[13]-t[9],i*t[14]-t[10],i*t[15]-t[11]]]}},{}],225:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\");e.exports=function(t){var e=typeof t;if(\"string\"===e){var r=t;if(0===(t=+t)&&n(r))return!1}else if(\"number\"!==e)return!1;return t-t<1}},{\"is-string-blank\":423}],226:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 0:return new o([0],[0],0);case 1:if(\"number\"==typeof t){var n=l(t);return new o(n,n,0)}return new o(t,l(t.length),0);case 2:if(\"number\"==typeof e){var n=l(t.length);return new o(t,n,+e)}r=0;case 3:if(t.length!==e.length)throw new Error(\"state and velocity lengths must match\");return new o(t,e,r)}};var n=t(\"cubic-hermite\"),i=t(\"binary-search-bounds\");function a(t,e,r){return Math.min(e,Math.max(t,r))}function o(t,e,r){this.dimension=t.length,this.bounds=[new Array(this.dimension),new Array(this.dimension)];for(var n=0;n<this.dimension;++n)this.bounds[0][n]=-1/0,this.bounds[1][n]=1/0;this._state=t.slice().reverse(),this._velocity=e.slice().reverse(),this._time=[r],this._scratch=[t.slice(),t.slice(),t.slice(),t.slice(),t.slice()]}var s=o.prototype;function l(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=0;return e}s.flush=function(t){var e=i.gt(this._time,t)-1;e<=0||(this._time.splice(0,e),this._state.splice(0,e*this.dimension),this._velocity.splice(0,e*this.dimension))},s.curve=function(t){var e=this._time,r=e.length,o=i.le(e,t),s=this._scratch[0],l=this._state,c=this._velocity,u=this.dimension,h=this.bounds;if(o<0)for(var f=u-1,p=0;p<u;++p,--f)s[p]=l[f];else if(o>=r-1){f=l.length-1;var d=t-e[r-1];for(p=0;p<u;++p,--f)s[p]=l[f]+d*c[f]}else{f=u*(o+1)-1;var g=e[o],v=e[o+1]-g||1,m=this._scratch[1],y=this._scratch[2],x=this._scratch[3],b=this._scratch[4],_=!0;for(p=0;p<u;++p,--f)m[p]=l[f],x[p]=c[f]*v,y[p]=l[f+u],b[p]=c[f+u]*v,_=_&&m[p]===y[p]&&x[p]===b[p]&&0===x[p];if(_)for(p=0;p<u;++p)s[p]=m[p];else n(m,x,y,b,(t-g)/v,s)}var w=h[0],k=h[1];for(p=0;p<u;++p)s[p]=a(w[p],k[p],s[p]);return s},s.dcurve=function(t){var e=this._time,r=e.length,a=i.le(e,t),o=this._scratch[0],s=this._state,l=this._velocity,c=this.dimension;if(a>=r-1)for(var u=s.length-1,h=(e[r-1],0);h<c;++h,--u)o[h]=l[u];else{u=c*(a+1)-1;var f=e[a],p=e[a+1]-f||1,d=this._scratch[1],g=this._scratch[2],v=this._scratch[3],m=this._scratch[4],y=!0;for(h=0;h<c;++h,--u)d[h]=s[u],v[h]=l[u]*p,g[h]=s[u+c],m[h]=l[u+c]*p,y=y&&d[h]===g[h]&&v[h]===m[h]&&0===v[h];if(y)for(h=0;h<c;++h)o[h]=0;else{n.derivative(d,v,g,m,(t-f)/p,o);for(h=0;h<c;++h)o[h]/=p}}return o},s.lastT=function(){var t=this._time;return t[t.length-1]},s.stable=function(){for(var t=this._velocity,e=t.length,r=this.dimension-1;r>=0;--r)if(t[--e])return!1;return!0},s.jump=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1];this._time.push(e,t);for(var u=0;u<2;++u)for(var h=0;h<r;++h)n.push(n[o++]),i.push(0);this._time.push(t);for(h=r;h>0;--h)n.push(a(l[h-1],c[h-1],arguments[h])),i.push(0)}},s.push=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=t-e,l=this.bounds,c=l[0],u=l[1],h=s>1e-6?1/s:0;this._time.push(t);for(var f=r;f>0;--f){var p=a(c[f-1],u[f-1],arguments[f]);n.push(p),i.push((p-n[o++])*h)}}},s.set=function(t){var e=this.dimension;if(!(t<this.lastT()||arguments.length!==e+1)){var r=this._state,n=this._velocity,i=this.bounds,o=i[0],s=i[1];this._time.push(t);for(var l=e;l>0;--l)r.push(a(o[l-1],s[l-1],arguments[l])),n.push(0)}},s.move=function(t){var e=this.lastT(),r=this.dimension;if(!(t<=e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1],u=t-e,h=u>1e-6?1/u:0;this._time.push(t);for(var f=r;f>0;--f){var p=arguments[f];n.push(a(l[f-1],c[f-1],n[o++]+p)),i.push(p*h)}}},s.idle=function(t){var e=this.lastT();if(!(t<e)){var r=this.dimension,n=this._state,i=this._velocity,o=n.length-r,s=this.bounds,l=s[0],c=s[1],u=t-e;this._time.push(t);for(var h=r-1;h>=0;--h)n.push(a(l[h],c[h],n[o]+u*i[o])),i.push(0),o+=1}}},{\"binary-search-bounds\":91,\"cubic-hermite\":145}],227:[function(t,e,r){var n=t(\"dtype\");e.exports=function(t,e,r){if(!t)throw new TypeError(\"must specify data as first parameter\");if(r=0|+(r||0),Array.isArray(t)&&t[0]&&\"number\"==typeof t[0][0]){var i,a,o,s,l=t[0].length,c=t.length*l;e&&\"string\"!=typeof e||(e=new(n(e||\"float32\"))(c+r));var u=e.length-r;if(c!==u)throw new Error(\"source length \"+c+\" (\"+l+\"x\"+t.length+\") does not match destination length \"+u);for(i=0,o=r;i<t.length;i++)for(a=0;a<l;a++)e[o++]=null===t[i][a]?NaN:t[i][a]}else if(e&&\"string\"!=typeof e)e.set(t,r);else{var h=n(e||\"float32\");if(Array.isArray(t)||\"array\"===e)for(e=new h(t.length+r),i=0,o=r,s=e.length;o<s;o++,i++)e[o]=null===t[i]?NaN:t[i];else 0===r?e=new h(t):(e=new h(t.length+r)).set(t,r)}return e}},{dtype:169}],228:[function(t,e,r){\"use strict\";var n=t(\"css-font/stringify\"),i=[32,126];e.exports=function(t){var e=(t=t||{}).shape?t.shape:t.canvas?[t.canvas.width,t.canvas.height]:[512,512],r=t.canvas||document.createElement(\"canvas\"),a=t.font,o=\"number\"==typeof t.step?[t.step,t.step]:t.step||[32,32],s=t.chars||i;a&&\"string\"!=typeof a&&(a=n(a));if(Array.isArray(s)){if(2===s.length&&\"number\"==typeof s[0]&&\"number\"==typeof s[1]){for(var l=[],c=s[0],u=0;c<=s[1];c++)l[u++]=String.fromCharCode(c);s=l}}else s=String(s).split(\"\");e=e.slice(),r.width=e[0],r.height=e[1];var h=r.getContext(\"2d\");h.fillStyle=\"#000\",h.fillRect(0,0,r.width,r.height),h.font=a,h.textAlign=\"center\",h.textBaseline=\"middle\",h.fillStyle=\"#fff\";for(var f=o[0]/2,p=o[1]/2,c=0;c<s.length;c++)h.fillText(s[c],f,p),(f+=o[0])>e[0]-o[0]/2&&(f=o[0]/2,p+=o[1]);return r}},{\"css-font/stringify\":142}],229:[function(t,e,r){\"use strict\";function n(t,e){e||(e={}),(\"string\"==typeof t||Array.isArray(t))&&(e.family=t);var r=Array.isArray(e.family)?e.family.join(\", \"):e.family;if(!r)throw Error(\"`family` must be defined\");var s=e.size||e.fontSize||e.em||48,l=e.weight||e.fontWeight||\"\",c=(t=[e.style||e.fontStyle||\"\",l,s].join(\" \")+\"px \"+r,e.origin||\"top\");if(n.cache[r]&&s<=n.cache[r].em)return i(n.cache[r],c);var u=e.canvas||n.canvas,h=u.getContext(\"2d\"),f={upper:void 0!==e.upper?e.upper:\"H\",lower:void 0!==e.lower?e.lower:\"x\",descent:void 0!==e.descent?e.descent:\"p\",ascent:void 0!==e.ascent?e.ascent:\"h\",tittle:void 0!==e.tittle?e.tittle:\"i\",overshoot:void 0!==e.overshoot?e.overshoot:\"O\"},p=Math.ceil(1.5*s);u.height=p,u.width=.5*p,h.font=t;var d={top:0};h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillStyle=\"black\",h.fillText(\"H\",0,0);var g=a(h.getImageData(0,0,p,p));h.clearRect(0,0,p,p),h.textBaseline=\"bottom\",h.fillText(\"H\",0,p);var v=a(h.getImageData(0,0,p,p));d.lineHeight=d.bottom=p-v+g,h.clearRect(0,0,p,p),h.textBaseline=\"alphabetic\",h.fillText(\"H\",0,p);var m=p-a(h.getImageData(0,0,p,p))-1+g;d.baseline=d.alphabetic=m,h.clearRect(0,0,p,p),h.textBaseline=\"middle\",h.fillText(\"H\",0,.5*p);var y=a(h.getImageData(0,0,p,p));d.median=d.middle=p-y-1+g-.5*p,h.clearRect(0,0,p,p),h.textBaseline=\"hanging\",h.fillText(\"H\",0,.5*p);var x=a(h.getImageData(0,0,p,p));d.hanging=p-x-1+g-.5*p,h.clearRect(0,0,p,p),h.textBaseline=\"ideographic\",h.fillText(\"H\",0,p);var b=a(h.getImageData(0,0,p,p));if(d.ideographic=p-b-1+g,f.upper&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.upper,0,0),d.upper=a(h.getImageData(0,0,p,p)),d.capHeight=d.baseline-d.upper),f.lower&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.lower,0,0),d.lower=a(h.getImageData(0,0,p,p)),d.xHeight=d.baseline-d.lower),f.tittle&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.tittle,0,0),d.tittle=a(h.getImageData(0,0,p,p))),f.ascent&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.ascent,0,0),d.ascent=a(h.getImageData(0,0,p,p))),f.descent&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.descent,0,0),d.descent=o(h.getImageData(0,0,p,p))),f.overshoot){h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.overshoot,0,0);var _=o(h.getImageData(0,0,p,p));d.overshoot=_-m}for(var w in d)d[w]/=s;return d.em=s,n.cache[r]=d,i(d,c)}function i(t,e){var r={};for(var n in\"string\"==typeof e&&(e=t[e]),t)\"em\"!==n&&(r[n]=t[n]-e);return r}function a(t){for(var e=t.height,r=t.data,n=3;n<r.length;n+=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}function o(t){for(var e=t.height,r=t.data,n=r.length-1;n>0;n-=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}e.exports=n,n.canvas=document.createElement(\"canvas\"),n.cache={}},{}],230:[function(t,e,r){\"use strict\";e.exports=function(t){return new c(t||d,null)};var n=0,i=1;function a(t,e,r,n,i,a){this._color=t,this.key=e,this.value=r,this.left=n,this.right=i,this._count=a}function o(t){return new a(t._color,t.key,t.value,t.left,t.right,t._count)}function s(t,e){return new a(t,e.key,e.value,e.left,e.right,e._count)}function l(t){t._count=1+(t.left?t.left._count:0)+(t.right?t.right._count:0)}function c(t,e){this._compare=t,this.root=e}var u=c.prototype;function h(t,e){this.tree=t,this._stack=e}Object.defineProperty(u,\"keys\",{get:function(){var t=[];return this.forEach(function(e,r){t.push(e)}),t}}),Object.defineProperty(u,\"values\",{get:function(){var t=[];return this.forEach(function(e,r){t.push(r)}),t}}),Object.defineProperty(u,\"length\",{get:function(){return this.root?this.root._count:0}}),u.insert=function(t,e){for(var r=this._compare,o=this.root,u=[],h=[];o;){var f=r(t,o.key);u.push(o),h.push(f),o=f<=0?o.left:o.right}u.push(new a(n,t,e,null,null,1));for(var p=u.length-2;p>=0;--p){o=u[p];h[p]<=0?u[p]=new a(o._color,o.key,o.value,u[p+1],o.right,o._count+1):u[p]=new a(o._color,o.key,o.value,o.left,u[p+1],o._count+1)}for(p=u.length-1;p>1;--p){var d=u[p-1];o=u[p];if(d._color===i||o._color===i)break;var g=u[p-2];if(g.left===d)if(d.left===o){if(!(v=g.right)||v._color!==n){if(g._color=n,g.left=d.right,d._color=i,d.right=g,u[p-2]=d,u[p-1]=o,l(g),l(d),p>=3)(m=u[p-3]).left===g?m.left=d:m.right=d;break}d._color=i,g.right=s(i,v),g._color=n,p-=1}else{if(!(v=g.right)||v._color!==n){if(d.right=o.left,g._color=n,g.left=o.right,o._color=i,o.left=d,o.right=g,u[p-2]=o,u[p-1]=d,l(g),l(d),l(o),p>=3)(m=u[p-3]).left===g?m.left=o:m.right=o;break}d._color=i,g.right=s(i,v),g._color=n,p-=1}else if(d.right===o){if(!(v=g.left)||v._color!==n){if(g._color=n,g.right=d.left,d._color=i,d.left=g,u[p-2]=d,u[p-1]=o,l(g),l(d),p>=3)(m=u[p-3]).right===g?m.right=d:m.left=d;break}d._color=i,g.left=s(i,v),g._color=n,p-=1}else{var v;if(!(v=g.left)||v._color!==n){var m;if(d.left=o.right,g._color=n,g.right=o.left,o._color=i,o.right=d,o.left=g,u[p-2]=o,u[p-1]=d,l(g),l(d),l(o),p>=3)(m=u[p-3]).right===g?m.right=o:m.left=o;break}d._color=i,g.left=s(i,v),g._color=n,p-=1}}return u[0]._color=i,new c(r,u[0])},u.forEach=function(t,e,r){if(this.root)switch(arguments.length){case 1:return function t(e,r){var n;if(r.left&&(n=t(e,r.left)))return n;return(n=e(r.key,r.value))||(r.right?t(e,r.right):void 0)}(t,this.root);case 2:return function t(e,r,n,i){if(r(e,i.key)<=0){var a;if(i.left&&(a=t(e,r,n,i.left)))return a;if(a=n(i.key,i.value))return a}if(i.right)return t(e,r,n,i.right)}(e,this._compare,t,this.root);case 3:if(this._compare(e,r)>=0)return;return function t(e,r,n,i,a){var o,s=n(e,a.key),l=n(r,a.key);if(s<=0){if(a.left&&(o=t(e,r,n,i,a.left)))return o;if(l>0&&(o=i(a.key,a.value)))return o}if(l>0&&a.right)return t(e,r,n,i,a.right)}(e,r,this._compare,t,this.root)}},Object.defineProperty(u,\"begin\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.left;return new h(this,t)}}),Object.defineProperty(u,\"end\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.right;return new h(this,t)}}),u.at=function(t){if(t<0)return new h(this,[]);for(var e=this.root,r=[];;){if(r.push(e),e.left){if(t<e.left._count){e=e.left;continue}t-=e.left._count}if(!t)return new h(this,r);if(t-=1,!e.right)break;if(t>=e.right._count)break;e=e.right}return new h(this,[])},u.ge=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<=0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},u.gt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},u.lt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},u.le=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>=0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},u.find=function(t){for(var e=this._compare,r=this.root,n=[];r;){var i=e(t,r.key);if(n.push(r),0===i)return new h(this,n);r=i<=0?r.left:r.right}return new h(this,[])},u.remove=function(t){var e=this.find(t);return e?e.remove():this},u.get=function(t){for(var e=this._compare,r=this.root;r;){var n=e(t,r.key);if(0===n)return r.value;r=n<=0?r.left:r.right}};var f=h.prototype;function p(t,e){t.key=e.key,t.value=e.value,t.left=e.left,t.right=e.right,t._color=e._color,t._count=e._count}function d(t,e){return t<e?-1:t>e?1:0}Object.defineProperty(f,\"valid\",{get:function(){return this._stack.length>0}}),Object.defineProperty(f,\"node\",{get:function(){return this._stack.length>0?this._stack[this._stack.length-1]:null},enumerable:!0}),f.clone=function(){return new h(this.tree,this._stack.slice())},f.remove=function(){var t=this._stack;if(0===t.length)return this.tree;var e=new Array(t.length),r=t[t.length-1];e[e.length-1]=new a(r._color,r.key,r.value,r.left,r.right,r._count);for(var u=t.length-2;u>=0;--u){(r=t[u]).left===t[u+1]?e[u]=new a(r._color,r.key,r.value,e[u+1],r.right,r._count):e[u]=new a(r._color,r.key,r.value,r.left,e[u+1],r._count)}if((r=e[e.length-1]).left&&r.right){var h=e.length;for(r=r.left;r.right;)e.push(r),r=r.right;var f=e[h-1];e.push(new a(r._color,f.key,f.value,r.left,r.right,r._count)),e[h-1].key=r.key,e[h-1].value=r.value;for(u=e.length-2;u>=h;--u)r=e[u],e[u]=new a(r._color,r.key,r.value,r.left,e[u+1],r._count);e[h-1].left=e[h]}if((r=e[e.length-1])._color===n){var d=e[e.length-2];d.left===r?d.left=null:d.right===r&&(d.right=null),e.pop();for(u=0;u<e.length;++u)e[u]._count--;return new c(this.tree._compare,e[0])}if(r.left||r.right){r.left?p(r,r.left):r.right&&p(r,r.right),r._color=i;for(u=0;u<e.length-1;++u)e[u]._count--;return new c(this.tree._compare,e[0])}if(1===e.length)return new c(this.tree._compare,null);for(u=0;u<e.length;++u)e[u]._count--;var g=e[e.length-2];return function(t){for(var e,r,a,c,u=t.length-1;u>=0;--u){if(e=t[u],0===u)return void(e._color=i);if((r=t[u-1]).left===e){if((a=r.right).right&&a.right._color===n)return c=(a=r.right=o(a)).right=o(a.right),r.right=a.left,a.left=r,a.right=c,a._color=r._color,e._color=i,r._color=i,c._color=i,l(r),l(a),u>1&&((h=t[u-2]).left===r?h.left=a:h.right=a),void(t[u-1]=a);if(a.left&&a.left._color===n)return c=(a=r.right=o(a)).left=o(a.left),r.right=c.left,a.left=c.right,c.left=r,c.right=a,c._color=r._color,r._color=i,a._color=i,e._color=i,l(r),l(a),l(c),u>1&&((h=t[u-2]).left===r?h.left=c:h.right=c),void(t[u-1]=c);if(a._color===i){if(r._color===n)return r._color=i,void(r.right=s(n,a));r.right=s(n,a);continue}a=o(a),r.right=a.left,a.left=r,a._color=r._color,r._color=n,l(r),l(a),u>1&&((h=t[u-2]).left===r?h.left=a:h.right=a),t[u-1]=a,t[u]=r,u+1<t.length?t[u+1]=e:t.push(e),u+=2}else{if((a=r.left).left&&a.left._color===n)return c=(a=r.left=o(a)).left=o(a.left),r.left=a.right,a.right=r,a.left=c,a._color=r._color,e._color=i,r._color=i,c._color=i,l(r),l(a),u>1&&((h=t[u-2]).right===r?h.right=a:h.left=a),void(t[u-1]=a);if(a.right&&a.right._color===n)return c=(a=r.left=o(a)).right=o(a.right),r.left=c.right,a.right=c.left,c.right=r,c.left=a,c._color=r._color,r._color=i,a._color=i,e._color=i,l(r),l(a),l(c),u>1&&((h=t[u-2]).right===r?h.right=c:h.left=c),void(t[u-1]=c);if(a._color===i){if(r._color===n)return r._color=i,void(r.left=s(n,a));r.left=s(n,a);continue}var h;a=o(a),r.left=a.right,a.right=r,a._color=r._color,r._color=n,l(r),l(a),u>1&&((h=t[u-2]).right===r?h.right=a:h.left=a),t[u-1]=a,t[u]=r,u+1<t.length?t[u+1]=e:t.push(e),u+=2}}}(e),g.left===r?g.left=null:g.right=null,new c(this.tree._compare,e[0])},Object.defineProperty(f,\"key\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].key},enumerable:!0}),Object.defineProperty(f,\"value\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].value},enumerable:!0}),Object.defineProperty(f,\"index\",{get:function(){var t=0,e=this._stack;if(0===e.length){var r=this.tree.root;return r?r._count:0}e[e.length-1].left&&(t=e[e.length-1].left._count);for(var n=e.length-2;n>=0;--n)e[n+1]===e[n].right&&(++t,e[n].left&&(t+=e[n].left._count));return t},enumerable:!0}),f.next=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.right)for(e=e.right;e;)t.push(e),e=e.left;else for(t.pop();t.length>0&&t[t.length-1].right===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(f,\"hasNext\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].right)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].left===t[e])return!0;return!1}}),f.update=function(t){var e=this._stack;if(0===e.length)throw new Error(\"Can't update empty node!\");var r=new Array(e.length),n=e[e.length-1];r[r.length-1]=new a(n._color,n.key,t,n.left,n.right,n._count);for(var i=e.length-2;i>=0;--i)(n=e[i]).left===e[i+1]?r[i]=new a(n._color,n.key,n.value,r[i+1],n.right,n._count):r[i]=new a(n._color,n.key,n.value,n.left,r[i+1],n._count);return new c(this.tree._compare,r[0])},f.prev=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.left)for(e=e.left;e;)t.push(e),e=e.right;else for(t.pop();t.length>0&&t[t.length-1].left===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(f,\"hasPrev\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].left)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].right===t[e])return!0;return!1}})},{}],231:[function(t,e,r){var n=[.9999999999998099,676.5203681218851,-1259.1392167224028,771.3234287776531,-176.6150291621406,12.507343278686905,-.13857109526572012,9984369578019572e-21,1.5056327351493116e-7],i=607/128,a=[.9999999999999971,57.15623566586292,-59.59796035547549,14.136097974741746,-.4919138160976202,3399464998481189e-20,4652362892704858e-20,-9837447530487956e-20,.0001580887032249125,-.00021026444172410488,.00021743961811521265,-.0001643181065367639,8441822398385275e-20,-26190838401581408e-21,36899182659531625e-22];function o(t){if(t<0)return Number(\"0/0\");for(var e=a[0],r=a.length-1;r>0;--r)e+=a[r]/(t+r);var n=t+i+.5;return.5*Math.log(2*Math.PI)+(t+.5)*Math.log(n)-n+Math.log(e)-Math.log(t)}e.exports=function t(e){if(e<.5)return Math.PI/(Math.sin(Math.PI*e)*t(1-e));if(e>100)return Math.exp(o(e));e-=1;for(var r=n[0],i=1;i<9;i++)r+=n[i]/(e+i);var a=e+7+.5;return Math.sqrt(2*Math.PI)*Math.pow(a,e+.5)*Math.exp(-a)*r},e.exports.log=o},{}],232:[function(t,e,r){e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"must specify type string\");if(e=e||{},\"undefined\"==typeof document&&!e.canvas)return null;var r=e.canvas||document.createElement(\"canvas\");\"number\"==typeof e.width&&(r.width=e.width);\"number\"==typeof e.height&&(r.height=e.height);var n,i=e;try{var a=[t];0===t.indexOf(\"webgl\")&&a.push(\"experimental-\"+t);for(var o=0;o<a.length;o++)if(n=r.getContext(a[o],i))return n}catch(t){n=null}return n||null}},{}],233:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=new u(t);return r.update(e),r};var n=t(\"./lib/text.js\"),i=t(\"./lib/lines.js\"),a=t(\"./lib/background.js\"),o=t(\"./lib/cube.js\"),s=t(\"./lib/ticks.js\"),l=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]);function c(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function u(t){this.gl=t,this.pixelRatio=1,this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.autoTicks=!0,this.tickSpacing=[1,1,1],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickAlign=[\"auto\",\"auto\",\"auto\"],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[10,10,10],this.lastCubeProps={cubeEdges:[0,0,0],axis:[0,0,0]},this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=\"sans-serif\",this.labelSize=[20,20,20],this.labelAngle=[0,0,0],this.labelAlign=[\"auto\",\"auto\",\"auto\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[10,10,10],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[0,0,0],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!1,!1,!1],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._firstInit=!0,this._text=null,this._lines=null,this._background=a(t)}var h=u.prototype;function f(){this.primalOffset=[0,0,0],this.primalMinor=[0,0,0],this.mirrorOffset=[0,0,0],this.mirrorMinor=[0,0,0]}h.update=function(t){function e(e,r,n){if(n in t){var i,a=t[n],o=this[n];(e?Array.isArray(a)&&Array.isArray(a[0]):Array.isArray(a))?this[n]=i=[r(a[0]),r(a[1]),r(a[2])]:this[n]=i=[r(a),r(a),r(a)];for(var s=0;s<3;++s)if(i[s]!==o[s])return!0}return!1}t=t||{};var r,a=e.bind(this,!1,Number),o=e.bind(this,!1,Boolean),l=e.bind(this,!1,String),c=e.bind(this,!0,function(t){if(Array.isArray(t)){if(3===t.length)return[+t[0],+t[1],+t[2],1];if(4===t.length)return[+t[0],+t[1],+t[2],+t[3]]}return[0,0,0,1]}),u=!1,h=!1;if(\"bounds\"in t)for(var f=t.bounds,p=0;p<2;++p)for(var d=0;d<3;++d)f[p][d]!==this.bounds[p][d]&&(h=!0),this.bounds[p][d]=f[p][d];if(\"ticks\"in t){r=t.ticks,u=!0,this.autoTicks=!1;for(p=0;p<3;++p)this.tickSpacing[p]=0}else a(\"tickSpacing\")&&(this.autoTicks=!0,h=!0);if(this._firstInit&&(\"ticks\"in t||\"tickSpacing\"in t||(this.autoTicks=!0),h=!0,u=!0,this._firstInit=!1),h&&this.autoTicks&&(r=s.create(this.bounds,this.tickSpacing),u=!0),u){for(p=0;p<3;++p)r[p].sort(function(t,e){return t.x-e.x});s.equal(r,this.ticks)?u=!1:this.ticks=r}o(\"tickEnable\"),l(\"tickFont\")&&(u=!0),a(\"tickSize\"),a(\"tickAngle\"),a(\"tickPad\"),c(\"tickColor\");var g=l(\"labels\");l(\"labelFont\")&&(g=!0),o(\"labelEnable\"),a(\"labelSize\"),a(\"labelPad\"),c(\"labelColor\"),o(\"lineEnable\"),o(\"lineMirror\"),a(\"lineWidth\"),c(\"lineColor\"),o(\"lineTickEnable\"),o(\"lineTickMirror\"),a(\"lineTickLength\"),a(\"lineTickWidth\"),c(\"lineTickColor\"),o(\"gridEnable\"),a(\"gridWidth\"),c(\"gridColor\"),o(\"zeroEnable\"),c(\"zeroLineColor\"),a(\"zeroLineWidth\"),o(\"backgroundEnable\"),c(\"backgroundColor\"),this._text?this._text&&(g||u)&&this._text.update(this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont):this._text=n(this.gl,this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont),this._lines&&u&&(this._lines.dispose(),this._lines=null),this._lines||(this._lines=i(this.gl,this.bounds,this.ticks))};var p=[new f,new f,new f];function d(t,e,r,n,i){for(var a=t.primalOffset,o=t.primalMinor,s=t.mirrorOffset,l=t.mirrorMinor,c=n[e],u=0;u<3;++u)if(e!==u){var h=a,f=s,p=o,d=l;c&1<<u&&(h=s,f=a,p=l,d=o),h[u]=r[0][u],f[u]=r[1][u],i[u]>0?(p[u]=-1,d[u]=0):(p[u]=0,d[u]=1)}}var g=[0,0,0],v={model:l,view:l,projection:l,_ortho:!1};h.isOpaque=function(){return!0},h.isTransparent=function(){return!1},h.drawTransparent=function(t){};var m=[0,0,0],y=[0,0,0],x=[0,0,0];h.draw=function(t){t=t||v;for(var e=this.gl,r=t.model||l,n=t.view||l,i=t.projection||l,a=this.bounds,s=t._ortho||!1,u=o(r,n,i,a,s),h=u.cubeEdges,f=u.axis,b=n[12],_=n[13],w=n[14],k=n[15],T=(s?2:1)*this.pixelRatio*(i[3]*b+i[7]*_+i[11]*w+i[15]*k)/e.drawingBufferHeight,A=0;A<3;++A)this.lastCubeProps.cubeEdges[A]=h[A],this.lastCubeProps.axis[A]=f[A];var M=p;for(A=0;A<3;++A)d(p[A],A,this.bounds,h,f);e=this.gl;var S,E=g;for(A=0;A<3;++A)this.backgroundEnable[A]?E[A]=f[A]:E[A]=0;this._background.draw(r,n,i,a,E,this.backgroundColor),this._lines.bind(r,n,i,this);for(A=0;A<3;++A){var C=[0,0,0];f[A]>0?C[A]=a[1][A]:C[A]=a[0][A];for(var L=0;L<2;++L){var P=(A+1+L)%3,O=(A+1+(1^L))%3;this.gridEnable[P]&&this._lines.drawGrid(P,O,this.bounds,C,this.gridColor[P],this.gridWidth[P]*this.pixelRatio)}for(L=0;L<2;++L){P=(A+1+L)%3,O=(A+1+(1^L))%3;this.zeroEnable[O]&&Math.min(a[0][O],a[1][O])<=0&&Math.max(a[0][O],a[1][O])>=0&&this._lines.drawZero(P,O,this.bounds,C,this.zeroLineColor[O],this.zeroLineWidth[O]*this.pixelRatio)}}for(A=0;A<3;++A){this.lineEnable[A]&&this._lines.drawAxisLine(A,this.bounds,M[A].primalOffset,this.lineColor[A],this.lineWidth[A]*this.pixelRatio),this.lineMirror[A]&&this._lines.drawAxisLine(A,this.bounds,M[A].mirrorOffset,this.lineColor[A],this.lineWidth[A]*this.pixelRatio);var z=c(m,M[A].primalMinor),I=c(y,M[A].mirrorMinor),D=this.lineTickLength;for(L=0;L<3;++L){var R=T/r[5*L];z[L]*=D[L]*R,I[L]*=D[L]*R}this.lineTickEnable[A]&&this._lines.drawAxisTicks(A,M[A].primalOffset,z,this.lineTickColor[A],this.lineTickWidth[A]*this.pixelRatio),this.lineTickMirror[A]&&this._lines.drawAxisTicks(A,M[A].mirrorOffset,I,this.lineTickColor[A],this.lineTickWidth[A]*this.pixelRatio)}this._lines.unbind(),this._text.bind(r,n,i,this.pixelRatio);var F,B;function N(t){(B=[0,0,0])[t]=1}function j(t,e,r){var n=(t+1)%3,i=(t+2)%3,a=e[n],o=e[i],s=r[n],l=r[i];a>0&&l>0?N(n):a>0&&l<0?N(n):a<0&&l>0?N(n):a<0&&l<0?N(n):o>0&&s>0?N(i):o>0&&s<0?N(i):o<0&&s>0?N(i):o<0&&s<0&&N(i)}for(A=0;A<3;++A){var U=M[A].primalMinor,V=M[A].mirrorMinor,q=c(x,M[A].primalOffset);for(L=0;L<3;++L)this.lineTickEnable[A]&&(q[L]+=T*U[L]*Math.max(this.lineTickLength[L],0)/r[5*L]);var H=[0,0,0];if(H[A]=1,this.tickEnable[A]){-3600===this.tickAngle[A]?(this.tickAngle[A]=0,this.tickAlign[A]=\"auto\"):this.tickAlign[A]=-1,F=1,\"auto\"===(S=[this.tickAlign[A],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]),B=[0,0,0],j(A,U,V);for(L=0;L<3;++L)q[L]+=T*U[L]*this.tickPad[L]/r[5*L];this._text.drawTicks(A,this.tickSize[A],this.tickAngle[A],q,this.tickColor[A],H,B,S)}if(this.labelEnable[A]){F=0,B=[0,0,0],this.labels[A].length>4&&(N(A),F=1),\"auto\"===(S=[this.labelAlign[A],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]);for(L=0;L<3;++L)q[L]+=T*U[L]*this.labelPad[L]/r[5*L];q[A]+=.5*(a[0][A]+a[1][A]),this._text.drawLabel(A,this.labelSize[A],this.labelAngle[A],q,this.labelColor[A],[0,0,0],B,S)}}this._text.unbind()},h.dispose=function(){this._text.dispose(),this._lines.dispose(),this._background.dispose(),this._lines=null,this._text=null,this._background=null,this.gl=null}},{\"./lib/background.js\":234,\"./lib/cube.js\":235,\"./lib/lines.js\":236,\"./lib/text.js\":238,\"./lib/ticks.js\":239}],234:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=[],r=[],s=0,l=0;l<3;++l)for(var c=(l+1)%3,u=(l+2)%3,h=[0,0,0],f=[0,0,0],p=-1;p<=1;p+=2){r.push(s,s+2,s+1,s+1,s+2,s+3),h[l]=p,f[l]=p;for(var d=-1;d<=1;d+=2){h[c]=d;for(var g=-1;g<=1;g+=2)h[u]=g,e.push(h[0],h[1],h[2],f[0],f[1],f[2]),s+=1}var v=c;c=u,u=v}var m=n(t,new Float32Array(e)),y=n(t,new Uint16Array(r),t.ELEMENT_ARRAY_BUFFER),x=i(t,[{buffer:m,type:t.FLOAT,size:3,offset:0,stride:24},{buffer:m,type:t.FLOAT,size:3,offset:12,stride:24}],y),b=a(t);return b.attributes.position.location=0,b.attributes.normal.location=1,new o(t,m,x,b)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").bg;function o(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n}var s=o.prototype;s.draw=function(t,e,r,n,i,a){for(var o=!1,s=0;s<3;++s)o=o||i[s];if(o){var l=this.gl;l.enable(l.POLYGON_OFFSET_FILL),l.polygonOffset(1,2),this.shader.bind(),this.shader.uniforms={model:t,view:e,projection:r,bounds:n,enable:i,colors:a},this.vao.bind(),this.vao.draw(this.gl.TRIANGLES,36),this.vao.unbind(),l.disable(l.POLYGON_OFFSET_FILL)}},s.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders\":237,\"gl-buffer\":241,\"gl-vao\":327}],235:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,p){i(s,e,t),i(s,r,s);for(var y=0,x=0;x<2;++x){u[2]=a[x][2];for(var b=0;b<2;++b){u[1]=a[b][1];for(var _=0;_<2;++_)u[0]=a[_][0],f(l[y],u,s),y+=1}}for(var w=-1,x=0;x<8;++x){for(var k=l[x][3],T=0;T<3;++T)c[x][T]=l[x][T]/k;p&&(c[x][2]*=-1),k<0&&(w<0?w=x:c[x][2]<c[w][2]&&(w=x))}if(w<0){w=0;for(var A=0;A<3;++A){for(var M=(A+2)%3,S=(A+1)%3,E=-1,C=-1,L=0;L<2;++L){var P=L<<A,O=P+(L<<M)+(1-L<<S),z=P+(1-L<<M)+(L<<S);o(c[P],c[O],c[z],h)<0||(L?E=1:C=1)}if(E<0||C<0)C>E&&(w|=1<<A);else{for(var L=0;L<2;++L){var P=L<<A,O=P+(L<<M)+(1-L<<S),z=P+(1-L<<M)+(L<<S),I=d([l[P],l[O],l[z],l[P+(1<<M)+(1<<S)]]);L?E=I:C=I}C>E&&(w|=1<<A)}}}for(var D=7^w,R=-1,x=0;x<8;++x)x!==w&&x!==D&&(R<0?R=x:c[R][1]>c[x][1]&&(R=x));for(var F=-1,x=0;x<3;++x){var B=R^1<<x;if(B!==w&&B!==D){F<0&&(F=B);var S=c[B];S[0]<c[F][0]&&(F=B)}}for(var N=-1,x=0;x<3;++x){var B=R^1<<x;if(B!==w&&B!==D&&B!==F){N<0&&(N=B);var S=c[B];S[0]>c[N][0]&&(N=B)}}var j=g;j[0]=j[1]=j[2]=0,j[n.log2(F^R)]=R&F,j[n.log2(R^N)]=R&N;var U=7^N;U===w||U===D?(U=7^F,j[n.log2(N^U)]=U&N):j[n.log2(F^U)]=U&F;for(var V=v,q=w,A=0;A<3;++A)V[A]=q&1<<A?-1:1;return m};var n=t(\"bit-twiddle\"),i=t(\"gl-mat4/multiply\"),a=t(\"split-polygon\"),o=t(\"robust-orientation\"),s=new Array(16),l=new Array(8),c=new Array(8),u=new Array(3),h=[0,0,0];function f(t,e,r){for(var n=0;n<4;++n){t[n]=r[12+n];for(var i=0;i<3;++i)t[n]+=e[i]*r[4*i+n]}}!function(){for(var t=0;t<8;++t)l[t]=[1,1,1,1],c[t]=[1,1,1]}();var p=[[0,0,1,0,0],[0,0,-1,1,0],[0,-1,0,1,0],[0,1,0,1,0],[-1,0,0,1,0],[1,0,0,1,0]];function d(t){for(var e=0;e<p.length;++e)if((t=a.positive(t,p[e])).length<3)return 0;var r=t[0],n=r[0]/r[3],i=r[1]/r[3],o=0;for(e=1;e+1<t.length;++e){var s=t[e],l=t[e+1],c=s[0]/s[3]-n,u=s[1]/s[3]-i,h=l[0]/l[3]-n,f=l[1]/l[3]-i;o+=Math.abs(c*f-u*h)}return o}var g=[1,1,1],v=[0,0,0],m={cubeEdges:g,axis:v}},{\"bit-twiddle\":92,\"gl-mat4/multiply\":267,\"robust-orientation\":510,\"split-polygon\":527}],236:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var o=[],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[0,0,0];o.push(0,0,1,0,1,1,0,0,-1,0,0,-1,0,1,1,0,1,-1);for(var h=0;h<3;++h){for(var f=o.length/3|0,d=0;d<r[h].length;++d){var g=+r[h][d].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var v=o.length/3|0;s[h]=f,l[h]=v-f;for(var f=o.length/3|0,m=0;m<r[h].length;++m){var g=+r[h][m].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var v=o.length/3|0;c[h]=f,u[h]=v-f}var y=n(t,new Float32Array(o)),x=i(t,[{buffer:y,type:t.FLOAT,size:3,stride:0,offset:0}]),b=a(t);return b.attributes.position.location=0,new p(t,y,x,b,l,s,u,c)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").line,o=[0,0,0],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[1,1];function h(t){return t[0]=t[1]=t[2]=0,t}function f(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function p(t,e,r,n,i,a,o,s){this.gl=t,this.vertBuffer=e,this.vao=r,this.shader=n,this.tickCount=i,this.tickOffset=a,this.gridCount=o,this.gridOffset=s}var d=p.prototype;d.bind=function(t,e,r){this.shader.bind(),this.shader.uniforms.model=t,this.shader.uniforms.view=e,this.shader.uniforms.projection=r,u[0]=this.gl.drawingBufferWidth,u[1]=this.gl.drawingBufferHeight,this.shader.uniforms.screenShape=u,this.vao.bind()},d.unbind=function(){this.vao.unbind()},d.drawAxisLine=function(t,e,r,n,i){var a=h(s);this.shader.uniforms.majorAxis=s,a[t]=e[1][t]-e[0][t],this.shader.uniforms.minorAxis=a;var o,u=f(c,r);u[t]+=e[0][t],this.shader.uniforms.offset=u,this.shader.uniforms.lineWidth=i,this.shader.uniforms.color=n,(o=h(l))[(t+2)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6),(o=h(l))[(t+1)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6)},d.drawAxisTicks=function(t,e,r,n,i){if(this.tickCount[t]){var a=h(o);a[t]=1,this.shader.uniforms.majorAxis=a,this.shader.uniforms.offset=e,this.shader.uniforms.minorAxis=r,this.shader.uniforms.color=n,this.shader.uniforms.lineWidth=i;var s=h(l);s[t]=1,this.shader.uniforms.screenAxis=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t])}},d.drawGrid=function(t,e,r,n,i,a){if(this.gridCount[t]){var u=h(s);u[e]=r[1][e]-r[0][e],this.shader.uniforms.minorAxis=u;var p=f(c,n);p[e]+=r[0][e],this.shader.uniforms.offset=p;var d=h(o);d[t]=1,this.shader.uniforms.majorAxis=d;var g=h(l);g[t]=1,this.shader.uniforms.screenAxis=g,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,this.gridCount[t],this.gridOffset[t])}},d.drawZero=function(t,e,r,n,i,a){var o=h(s);this.shader.uniforms.majorAxis=o,o[t]=r[1][t]-r[0][t],this.shader.uniforms.minorAxis=o;var u=f(c,n);u[t]+=r[0][t],this.shader.uniforms.offset=u;var p=h(l);p[e]=1,this.shader.uniforms.screenAxis=p,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,6)},d.dispose=function(){this.vao.dispose(),this.vertBuffer.dispose(),this.shader.dispose()}},{\"./shaders\":237,\"gl-buffer\":241,\"gl-vao\":327}],237:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, majorAxis, minorAxis, screenAxis;\\nuniform float lineWidth;\\nuniform vec2 screenShape;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nvoid main() {\\n  vec3 major = position.x * majorAxis;\\n  vec3 minor = position.y * minorAxis;\\n\\n  vec3 vPosition = major + minor + offset;\\n  vec3 pPosition = project(vPosition);\\n  vec3 offset = project(vPosition + screenAxis * position.z);\\n\\n  vec2 screen = normalize((offset - pPosition).xy * screenShape) / screenShape;\\n\\n  gl_Position = vec4(pPosition + vec3(0.5 * screen * lineWidth, 0), 1.0);\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.line=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"}])};var s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, axis, alignDir, alignOpt;\\nuniform float scale, angle, pixelScale;\\nuniform vec2 resolution;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nfloat computeViewAngle(vec3 a, vec3 b) {\\n  vec3 A = project(a);\\n  vec3 B = project(b);\\n\\n  return atan(\\n    (B.y - A.y) * resolution.y,\\n    (B.x - A.x) * resolution.x\\n  );\\n}\\n\\nconst float PI = 3.141592;\\nconst float TWO_PI = 2.0 * PI;\\nconst float HALF_PI = 0.5 * PI;\\nconst float ONE_AND_HALF_PI = 1.5 * PI;\\n\\nint option = int(floor(alignOpt.x + 0.001));\\nfloat hv_ratio =       alignOpt.y;\\nbool enableAlign =    (alignOpt.z != 0.0);\\n\\nfloat mod_angle(float a) {\\n  return mod(a, PI);\\n}\\n\\nfloat positive_angle(float a) {\\n  return mod_angle((a < 0.0) ?\\n    a + TWO_PI :\\n    a\\n  );\\n}\\n\\nfloat look_upwards(float a) {\\n  float b = positive_angle(a);\\n  return ((b > HALF_PI) && (b <= ONE_AND_HALF_PI)) ?\\n    b - PI :\\n    b;\\n}\\n\\nfloat look_horizontal_or_vertical(float a, float ratio) {\\n  // ratio controls the ratio between being horizontal to (vertical + horizontal)\\n  // if ratio is set to 0.5 then it is 50%, 50%.\\n  // when using a higher ratio e.g. 0.75 the result would\\n  // likely be more horizontal than vertical.\\n\\n  float b = positive_angle(a);\\n\\n  return\\n    (b < (      ratio) * HALF_PI) ? 0.0 :\\n    (b < (2.0 - ratio) * HALF_PI) ? -HALF_PI :\\n    (b < (2.0 + ratio) * HALF_PI) ? 0.0 :\\n    (b < (4.0 - ratio) * HALF_PI) ? HALF_PI :\\n                                    0.0;\\n}\\n\\nfloat roundTo(float a, float b) {\\n  return float(b * floor((a + 0.5 * b) / b));\\n}\\n\\nfloat look_round_n_directions(float a, int n) {\\n  float b = positive_angle(a);\\n  float div = TWO_PI / float(n);\\n  float c = roundTo(b, div);\\n  return look_upwards(c);\\n}\\n\\nfloat applyAlignOption(float rawAngle, float delta) {\\n  return\\n    (option >  2) ? look_round_n_directions(rawAngle + delta, option) :       // option 3-n: round to n directions\\n    (option == 2) ? look_horizontal_or_vertical(rawAngle + delta, hv_ratio) : // horizontal or vertical\\n    (option == 1) ? rawAngle + delta :       // use free angle, and flip to align with one direction of the axis\\n    (option == 0) ? look_upwards(rawAngle) : // use free angle, and stay upwards\\n    (option ==-1) ? 0.0 :                    // useful for backward compatibility, all texts remains horizontal\\n                    rawAngle;                // otherwise return back raw input angle\\n}\\n\\nbool isAxisTitle = (axis.x == 0.0) &&\\n                   (axis.y == 0.0) &&\\n                   (axis.z == 0.0);\\n\\nvoid main() {\\n  //Compute world offset\\n  float axisDistance = position.z;\\n  vec3 dataPosition = axisDistance * axis + offset;\\n\\n  float beta = angle; // i.e. user defined attributes for each tick\\n\\n  float axisAngle;\\n  float clipAngle;\\n  float flip;\\n\\n  if (enableAlign) {\\n    axisAngle = (isAxisTitle) ? HALF_PI :\\n                      computeViewAngle(dataPosition, dataPosition + axis);\\n    clipAngle = computeViewAngle(dataPosition, dataPosition + alignDir);\\n\\n    axisAngle += (sin(axisAngle) < 0.0) ? PI : 0.0;\\n    clipAngle += (sin(clipAngle) < 0.0) ? PI : 0.0;\\n\\n    flip = (dot(vec2(cos(axisAngle), sin(axisAngle)),\\n                vec2(sin(clipAngle),-cos(clipAngle))) > 0.0) ? 1.0 : 0.0;\\n\\n    beta += applyAlignOption(clipAngle, flip * PI);\\n  }\\n\\n  //Compute plane offset\\n  vec2 planeCoord = position.xy * pixelScale;\\n\\n  mat2 planeXform = scale * mat2(\\n     cos(beta), sin(beta),\\n    -sin(beta), cos(beta)\\n  );\\n\\n  vec2 viewOffset = 2.0 * planeXform * planeCoord / resolution;\\n\\n  //Compute clip position\\n  vec3 clipPosition = project(dataPosition);\\n\\n  //Apply text offset in clip coordinates\\n  clipPosition += vec3(viewOffset, 0.0);\\n\\n  //Done\\n  gl_Position = vec4(clipPosition, 1.0);\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.text=function(t){return i(t,s,l,null,[{name:\"position\",type:\"vec3\"}])};var c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec3 normal;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 enable;\\nuniform vec3 bounds[2];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n\\n  vec3 signAxis = sign(bounds[1] - bounds[0]);\\n\\n  vec3 realNormal = signAxis * normal;\\n\\n  if(dot(realNormal, enable) > 0.0) {\\n    vec3 minRange = min(bounds[0], bounds[1]);\\n    vec3 maxRange = max(bounds[0], bounds[1]);\\n    vec3 nPosition = mix(minRange, maxRange, 0.5 * (position + 1.0));\\n    gl_Position = projection * view * model * vec4(nPosition, 1.0);\\n  } else {\\n    gl_Position = vec4(0,0,0,0);\\n  }\\n\\n  colorChannel = abs(realNormal);\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 colors[3];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n  gl_FragColor = colorChannel.x * colors[0] +\\n                 colorChannel.y * colors[1] +\\n                 colorChannel.z * colors[2];\\n}\"]);r.bg=function(t){return i(t,c,u,null,[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}])}},{\"gl-shader\":301,glslify:409}],238:[function(t,e,r){(function(r){\"use strict\";e.exports=function(t,e,r,a,s,l){var u=n(t),h=i(t,[{buffer:u,size:3}]),f=o(t);f.attributes.position.location=0;var p=new c(t,f,u,h);return p.update(e,r,a,s,l),p};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"vectorize-text\"),o=t(\"./shaders\").text,s=window||r.global||{},l=s.__TEXT_CACHE||{};s.__TEXT_CACHE={};function c(t,e,r,n){this.gl=t,this.shader=e,this.buffer=r,this.vao=n,this.tickOffset=this.tickCount=this.labelOffset=this.labelCount=null}var u=c.prototype,h=[0,0];u.bind=function(t,e,r,n){this.vao.bind(),this.shader.bind();var i=this.shader.uniforms;i.model=t,i.view=e,i.projection=r,i.pixelScale=n,h[0]=this.gl.drawingBufferWidth,h[1]=this.gl.drawingBufferHeight,this.shader.uniforms.resolution=h},u.unbind=function(){this.vao.unbind()},u.update=function(t,e,r,n,i){var o=[];function s(t,e,r,n,i,s){var c=l[r];c||(c=l[r]={});var u=c[e];u||(u=c[e]=function(t,e){try{return a(t,e)}catch(e){return console.warn('error vectorizing text:\"'+t+'\" error:',e),{cells:[],positions:[]}}}(e,{triangles:!0,font:r,textAlign:\"center\",textBaseline:\"middle\",lineSpacing:i,styletags:s}));for(var h=(n||12)/12,f=u.positions,p=u.cells,d=0,g=p.length;d<g;++d)for(var v=p[d],m=2;m>=0;--m){var y=f[v[m]];o.push(h*y[0],-h*y[1],t)}}for(var c=[0,0,0],u=[0,0,0],h=[0,0,0],f=[0,0,0],p={breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},d=0;d<3;++d){h[d]=o.length/3|0,s(.5*(t[0][d]+t[1][d]),e[d],r[d],12,1.25,p),f[d]=(o.length/3|0)-h[d],c[d]=o.length/3|0;for(var g=0;g<n[d].length;++g)n[d][g].text&&s(n[d][g].x,n[d][g].text,n[d][g].font||i,n[d][g].fontSize||12,1.25,p);u[d]=(o.length/3|0)-c[d]}this.buffer.update(o),this.tickOffset=c,this.tickCount=u,this.labelOffset=h,this.labelCount=f},u.drawTicks=function(t,e,r,n,i,a,o,s){this.tickCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t]))},u.drawLabel=function(t,e,r,n,i,a,o,s){this.labelCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.labelCount[t],this.labelOffset[t]))},u.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()}}).call(this,t(\"_process\"))},{\"./shaders\":237,_process:482,\"gl-buffer\":241,\"gl-vao\":327,\"vectorize-text\":550}],239:[function(t,e,r){\"use strict\";function n(t,e){var r=t+\"\",n=r.indexOf(\".\"),i=0;n>=0&&(i=r.length-n-1);var a=Math.pow(10,i),o=Math.round(t*e*a),s=o+\"\";if(s.indexOf(\"e\")>=0)return s;var l=o/a,c=o%a;o<0?(l=0|-Math.ceil(l),c=0|-c):(l=0|Math.floor(l),c|=0);var u=\"\"+l;if(o<0&&(u=\"-\"+u),i){for(var h=\"\"+c;h.length<i;)h=\"0\"+h;return u+\".\"+h}return u}r.create=function(t,e){for(var r=[],i=0;i<3;++i){for(var a=[],o=(t[0][i],t[1][i],0);o*e[i]<=t[1][i];++o)a.push({x:o*e[i],text:n(e[i],o)});for(var o=-1;o*e[i]>=t[0][i];--o)a.push({x:o*e[i],text:n(e[i],o)});r.push(a)}return r},r.equal=function(t,e){for(var r=0;r<3;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;++n){var i=t[r][n],a=e[r][n];if(i.x!==a.x||i.text!==a.text||i.font!==a.font||i.fontColor!==a.fontColor||i.fontSize!==a.fontSize||i.dx!==a.dx||i.dy!==a.dy)return!1}}return!0}},{}],240:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,l,h){var f=e.model||c,p=e.view||c,m=e.projection||c,y=e._ortho||!1,x=t.bounds,b=(h=h||a(f,p,m,x,y)).axis;o(u,p,f),o(u,m,u);for(var _=g,w=0;w<3;++w)_[w].lo=1/0,_[w].hi=-1/0,_[w].pixelsPerDataUnit=1/0;var k=n(s(u,u));s(u,u);for(var T=0;T<3;++T){var A=(T+1)%3,M=(T+2)%3,S=v;t:for(var w=0;w<2;++w){var E=[];if(b[T]<0!=!!w){S[T]=x[w][T];for(var C=0;C<2;++C){S[A]=x[C^w][A];for(var L=0;L<2;++L)S[M]=x[L^C^w][M],E.push(S.slice())}for(var P=y?5:4,C=P;C===P;++C){if(0===E.length)continue t;E=i.positive(E,k[C])}for(var C=0;C<E.length;++C)for(var M=E[C],O=d(v,u,M,r,l),L=0;L<3;++L)_[L].lo=Math.min(_[L].lo,M[L]),_[L].hi=Math.max(_[L].hi,M[L]),L!==T&&(_[L].pixelsPerDataUnit=Math.min(_[L].pixelsPerDataUnit,Math.abs(O[L])))}}}return _};var n=t(\"extract-frustum-planes\"),i=t(\"split-polygon\"),a=t(\"./lib/cube.js\"),o=t(\"gl-mat4/multiply\"),s=t(\"gl-mat4/transpose\"),l=t(\"gl-vec4/transformMat4\"),c=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]),u=new Float32Array(16);function h(t,e,r){this.lo=t,this.hi=e,this.pixelsPerDataUnit=r}var f=[0,0,0,1],p=[0,0,0,1];function d(t,e,r,n,i){for(var a=0;a<3;++a){for(var o=f,s=p,c=0;c<3;++c)s[c]=o[c]=r[c];s[3]=o[3]=1,s[a]+=1,l(s,s,e),s[3]<0&&(t[a]=1/0),o[a]-=1,l(o,o,e),o[3]<0&&(t[a]=1/0);var u=(o[0]/o[3]-s[0]/s[3])*n,h=(o[1]/o[3]-s[1]/s[3])*i;t[a]=.25*Math.sqrt(u*u+h*h)}return t}var g=[new h(1/0,-1/0,1/0),new h(1/0,-1/0,1/0),new h(1/0,-1/0,1/0)],v=[0,0,0]},{\"./lib/cube.js\":235,\"extract-frustum-planes\":224,\"gl-mat4/multiply\":267,\"gl-mat4/transpose\":276,\"gl-vec4/transformMat4\":398,\"split-polygon\":527}],241:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"ndarray-ops\"),a=t(\"ndarray\"),o=[\"uint8\",\"uint8_clamped\",\"uint16\",\"uint32\",\"int8\",\"int16\",\"int32\",\"float32\"];function s(t,e,r,n,i){this.gl=t,this.type=e,this.handle=r,this.length=n,this.usage=i}var l=s.prototype;function c(t,e,r,n,i,a){var o=i.length*i.BYTES_PER_ELEMENT;if(a<0)return t.bufferData(e,i,n),o;if(o+a>r)throw new Error(\"gl-buffer: If resizing buffer, must not specify offset\");return t.bufferSubData(e,a,i),r}function u(t,e){for(var r=n.malloc(t.length,e),i=t.length,a=0;a<i;++a)r[a]=t[a];return r}l.bind=function(){this.gl.bindBuffer(this.type,this.handle)},l.unbind=function(){this.gl.bindBuffer(this.type,null)},l.dispose=function(){this.gl.deleteBuffer(this.handle)},l.update=function(t,e){if(\"number\"!=typeof e&&(e=-1),this.bind(),\"object\"==typeof t&&\"undefined\"!=typeof t.shape){var r=t.dtype;if(o.indexOf(r)<0&&(r=\"float32\"),this.type===this.gl.ELEMENT_ARRAY_BUFFER)r=gl.getExtension(\"OES_element_index_uint\")&&\"uint16\"!==r?\"uint32\":\"uint16\";if(r===t.dtype&&function(t,e){for(var r=1,n=e.length-1;n>=0;--n){if(e[n]!==r)return!1;r*=t[n]}return!0}(t.shape,t.stride))0===t.offset&&t.data.length===t.shape[0]?this.length=c(this.gl,this.type,this.length,this.usage,t.data,e):this.length=c(this.gl,this.type,this.length,this.usage,t.data.subarray(t.offset,t.shape[0]),e);else{var s=n.malloc(t.size,r),l=a(s,t.shape);i.assign(l,t),this.length=c(this.gl,this.type,this.length,this.usage,e<0?s:s.subarray(0,t.size),e),n.free(s)}}else if(Array.isArray(t)){var h;h=this.type===this.gl.ELEMENT_ARRAY_BUFFER?u(t,\"uint16\"):u(t,\"float32\"),this.length=c(this.gl,this.type,this.length,this.usage,e<0?h:h.subarray(0,t.length),e),n.free(h)}else if(\"object\"==typeof t&&\"number\"==typeof t.length)this.length=c(this.gl,this.type,this.length,this.usage,t,e);else{if(\"number\"!=typeof t&&void 0!==t)throw new Error(\"gl-buffer: Invalid data type\");if(e>=0)throw new Error(\"gl-buffer: Cannot specify offset when resizing buffer\");(t|=0)<=0&&(t=1),this.gl.bufferData(this.type,0|t,this.usage),this.length=t}},e.exports=function(t,e,r,n){if(r=r||t.ARRAY_BUFFER,n=n||t.DYNAMIC_DRAW,r!==t.ARRAY_BUFFER&&r!==t.ELEMENT_ARRAY_BUFFER)throw new Error(\"gl-buffer: Invalid type for webgl buffer, must be either gl.ARRAY_BUFFER or gl.ELEMENT_ARRAY_BUFFER\");if(n!==t.DYNAMIC_DRAW&&n!==t.STATIC_DRAW&&n!==t.STREAM_DRAW)throw new Error(\"gl-buffer: Invalid usage for buffer, must be either gl.DYNAMIC_DRAW, gl.STATIC_DRAW or gl.STREAM_DRAW\");var i=t.createBuffer(),a=new s(t,r,i,0,n);return a.update(e),a}},{ndarray:450,\"ndarray-ops\":444,\"typedarray-pool\":545}],242:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\"),i=function(t,e){for(var r=0;r<t.length;r++)if(t[r]>=e)return r-1;return r},a=n.create(),o=n.create(),s=function(t,e,r){return t<e?e:t>r?r:t},l=function(t,e,r,l){var c=t[0],u=t[1],h=t[2],f=r[0].length,p=r[1].length,d=r[2].length,g=i(r[0],c),v=i(r[1],u),m=i(r[2],h),y=g+1,x=v+1,b=m+1;if(l&&(g=s(g,0,f-1),y=s(y,0,f-1),v=s(v,0,p-1),x=s(x,0,p-1),m=s(m,0,d-1),b=s(b,0,d-1)),g<0||v<0||m<0||y>=f||x>=p||b>=d)return n.create();var _=(c-r[0][g])/(r[0][y]-r[0][g]),w=(u-r[1][v])/(r[1][x]-r[1][v]),k=(h-r[2][m])/(r[2][b]-r[2][m]);(_<0||_>1||isNaN(_))&&(_=0),(w<0||w>1||isNaN(w))&&(w=0),(k<0||k>1||isNaN(k))&&(k=0);var T=m*f*p,A=b*f*p,M=v*f,S=x*f,E=g,C=y,L=e[M+T+E],P=e[M+T+C],O=e[S+T+E],z=e[S+T+C],I=e[M+A+E],D=e[M+A+C],R=e[S+A+E],F=e[S+A+C],B=n.create();return n.lerp(B,L,P,_),n.lerp(a,O,z,_),n.lerp(B,B,a,w),n.lerp(a,I,D,_),n.lerp(o,R,F,_),n.lerp(a,a,o,w),n.lerp(B,B,a,k),B};e.exports=function(t,e){var r;r=t.positions?t.positions:function(t){for(var e=t[0],r=t[1],n=t[2],i=[],a=0;a<n.length;a++)for(var o=0;o<r.length;o++)for(var s=0;s<e.length;s++)i.push([n[a],r[o],e[s]]);return i}(t.meshgrid);var i=t.meshgrid,a=t.vectors,o={positions:[],vertexIntensity:[],vertexIntensityBounds:t.vertexIntensityBounds,vertexNormals:[],vectors:[],cells:[],coneOffset:t.coneOffset,colormap:t.colormap};if(0===t.positions.length)return e&&(e[0]=[0,0,0],e[1]=[0,0,0]),o;for(var s=0,c=1/0,u=-1/0,h=1/0,f=-1/0,p=1/0,d=-1/0,g=null,v=null,m=[],y=1/0,x=0;x<r.length;x++){var b,_=r[x];c=Math.min(_[0],c),u=Math.max(_[0],u),h=Math.min(_[1],h),f=Math.max(_[1],f),p=Math.min(_[2],p),d=Math.max(_[2],d),b=i?l(_,a,i,!0):a[x],n.length(b)>s&&(s=n.length(b)),x&&(y=Math.min(y,2*n.distance(g,_)/(n.length(v)+n.length(b)))),g=_,v=b,m.push(b)}var w=[c,h,p],k=[u,f,d];e&&(e[0]=w,e[1]=k),0===s&&(s=1);var T=1/s;isFinite(y)&&!isNaN(y)||(y=1),o.vectorScale=y;var A=function(t,e,r){var i=n.create();return void 0!==t&&n.set(i,t,e,r),i}(0,1,0),M=t.coneSize||.5;t.absoluteConeSize&&(M=t.absoluteConeSize*T),o.coneScale=M;x=0;for(var S=0;x<r.length;x++)for(var E=(_=r[x])[0],C=_[1],L=_[2],P=m[x],O=n.length(P)*T,z=0;z<8;z++){o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vertexIntensity.push(O,O,O),o.vertexIntensity.push(O,O,O),o.vertexNormals.push(A,A,A),o.vertexNormals.push(A,A,A);var I=o.positions.length;o.cells.push([I-6,I-5,I-4],[I-3,I-2,I-1])}return o},e.exports.createConeMesh=t(\"./lib/conemesh\")},{\"./lib/conemesh\":243,\"gl-vec3\":346}],243:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./shaders\"),g=d.meshShader,v=d.pickShader,m=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function y(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,y,x,b,_,w,k,T){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=i,this.triangleVectors=a,this.triangleColors=s,this.triangleNormals=c,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=u,this.triangleCount=0,this.lineWidth=1,this.edgePositions=h,this.edgeColors=p,this.edgeUVs=d,this.edgeIds=f,this.edgeVAO=g,this.edgeCount=0,this.pointPositions=v,this.pointColors=x,this.pointUVs=b,this.pointSizes=_,this.pointIds=y,this.pointVAO=w,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=k,this.contourVAO=T,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.coneScale=2,this.vectorScale=1,this.coneOffset=.25,this._model=m,this._view=m,this._projection=m,this._resolution=[1,1]}var x=y.prototype;function b(t){var e=n(t,v.vertex,v.fragment,null,v.attributes);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.vector.location=5,e}x.isOpaque=function(){return this.opacity>=1},x.isTransparent=function(){return this.opacity<1},x.pickSlots=1,x.setPickBase=function(t){this.pickId=t},x.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=i[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},x.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),void 0!==t.vectorScale&&(this.vectorScale=t.vectorScale),void 0!==t.coneScale&&(this.coneScale=t.coneScale),void 0!==t.coneOffset&&(this.coneOffset=t.coneOffset),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=h({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return u(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,i=t.vectors;if(n&&r&&i){var a=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[],w=[],k=[];this.cells=r,this.positions=n;var T=t.vertexNormals,A=t.cellNormals,M=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,S=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!A&&(A=s.faceNormals(r,n,S)),A||T||(T=s.vertexNormals(r,n,M));var E=t.vertexColors,C=t.cellColors,L=t.meshColor||[1,1,1,1],P=t.vertexUVs,O=t.vertexIntensity,z=t.cellUVs,I=t.cellIntensity,D=1/0,R=-1/0;if(!P&&!z)if(O)if(t.vertexIntensityBounds)D=+t.vertexIntensityBounds[0],R=+t.vertexIntensityBounds[1];else for(var F=0;F<O.length;++F){var B=O[F];D=Math.min(D,B),R=Math.max(R,B)}else if(I)for(F=0;F<I.length;++F){B=I[F];D=Math.min(D,B),R=Math.max(R,B)}else for(F=0;F<n.length;++F){B=n[F][2];D=Math.min(D,B),R=Math.max(R,B)}this.intensity=O||(I?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,I):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var N=t.pointSizes,j=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(F=0;F<n.length;++F)for(var U=n[F],V=0;V<3;++V)!isNaN(U[V])&&isFinite(U[V])&&(this.bounds[0][V]=Math.min(this.bounds[0][V],U[V]),this.bounds[1][V]=Math.max(this.bounds[1][V],U[V]));var q=0,H=0,G=0;t:for(F=0;F<r.length;++F){var Y=r[F];switch(Y.length){case 1:for(U=n[X=Y[0]],V=0;V<3;++V)if(isNaN(U[V])||!isFinite(U[V]))continue t;x.push(U[0],U[1],U[2],U[3]),3===(Z=E?E[X]:C?C[F]:L).length?b.push(Z[0],Z[1],Z[2],1):b.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],_.push(J[0],J[1]),N?w.push(N[X]):w.push(j),k.push(F),G+=1;break;case 2:for(V=0;V<2;++V){U=n[X=Y[V]];for(var W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t}for(V=0;V<2;++V){U=n[X=Y[V]];g.push(U[0],U[1],U[2]),3===(Z=E?E[X]:C?C[F]:L).length?v.push(Z[0],Z[1],Z[2],1):v.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],m.push(J[0],J[1]),y.push(F)}H+=1;break;case 3:for(V=0;V<3;++V)for(U=n[X=Y[V]],W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t;for(V=0;V<3;++V){var X;U=n[X=Y[2-V]];a.push(U[0],U[1],U[2],U[3]);var Z,J,K,$=i[X];l.push($[0],$[1],$[2]),3===(Z=E?E[X]:C?C[F]:L).length?c.push(Z[0],Z[1],Z[2],1):c.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],p.push(J[0],J[1]),K=T?T[X]:A[F],f.push(K[0],K[1],K[2]),d.push(F)}q+=1}}this.pointCount=G,this.edgeCount=H,this.triangleCount=q,this.pointPositions.update(x),this.pointColors.update(b),this.pointUVs.update(_),this.pointSizes.update(w),this.pointIds.update(new Uint32Array(k)),this.edgePositions.update(g),this.edgeColors.update(v),this.edgeUVs.update(m),this.edgeIds.update(new Uint32Array(y)),this.trianglePositions.update(a),this.triangleVectors.update(l),this.triangleColors.update(c),this.triangleUVs.update(p),this.triangleNormals.update(f),this.triangleIds.update(new Uint32Array(d))}},x.drawTransparent=x.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:m.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var f=u[12+o],p=0;p<3;++p)f+=u[4*p+o]*this.lightPosition[p];s.lightPosition[o]=f/h}if(this.triangleCount>0){var d=this.triShader;d.bind(),d.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},x.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:i,clipBounds:a,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind())},x.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3);return{index:Math.floor(r[1]/48),position:n,dataCoordinate:n}},x.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose()},e.exports=function(t,e){1===arguments.length&&(t=(e=t).gl);var r=e.triShader||function(t){var e=n(t,g.vertex,g.fragment,null,g.attributes);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.vector.location=5,e}(t),s=b(t),l=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));l.generateMipmap(),l.minFilter=t.LINEAR_MIPMAP_LINEAR,l.magFilter=t.LINEAR;var c=i(t),h=i(t),f=i(t),p=i(t),d=i(t),v=i(t),m=a(t,[{buffer:c,type:t.FLOAT,size:4},{buffer:v,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:f,type:t.FLOAT,size:4},{buffer:p,type:t.FLOAT,size:2},{buffer:d,type:t.FLOAT,size:3},{buffer:h,type:t.FLOAT,size:3}]),x=i(t),_=i(t),w=i(t),k=i(t),T=a(t,[{buffer:x,type:t.FLOAT,size:3},{buffer:k,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:_,type:t.FLOAT,size:4},{buffer:w,type:t.FLOAT,size:2}]),A=i(t),M=i(t),S=i(t),E=i(t),C=i(t),L=a(t,[{buffer:A,type:t.FLOAT,size:3},{buffer:C,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:M,type:t.FLOAT,size:4},{buffer:S,type:t.FLOAT,size:2},{buffer:E,type:t.FLOAT,size:1}]),P=i(t),O=new y(t,l,r,s,c,h,v,f,p,d,m,x,k,_,w,T,A,C,M,S,E,L,P,a(t,[{buffer:P,type:t.FLOAT,size:3}]));return O.update(e),O}},{\"./shaders\":244,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-shader\":301,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,normals:453,\"simplicial-complex-contour\":518,\"typedarray-pool\":545}],244:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\nuniform float vectorScale;\\nuniform float coneScale;\\n\\nuniform float coneOffset;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * conePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal,0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(conePosition, 1.0);\\n  vec4 t_position  = view * conePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = conePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular\\n            , opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nuniform float vectorScale;\\nuniform float coneScale;\\nuniform float coneOffset;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n  gl_Position = projection * view * conePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec3\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec3\"}]}},{glslify:409}],245:[function(t,e,r){e.exports={0:\"NONE\",1:\"ONE\",2:\"LINE_LOOP\",3:\"LINE_STRIP\",4:\"TRIANGLES\",5:\"TRIANGLE_STRIP\",6:\"TRIANGLE_FAN\",256:\"DEPTH_BUFFER_BIT\",512:\"NEVER\",513:\"LESS\",514:\"EQUAL\",515:\"LEQUAL\",516:\"GREATER\",517:\"NOTEQUAL\",518:\"GEQUAL\",519:\"ALWAYS\",768:\"SRC_COLOR\",769:\"ONE_MINUS_SRC_COLOR\",770:\"SRC_ALPHA\",771:\"ONE_MINUS_SRC_ALPHA\",772:\"DST_ALPHA\",773:\"ONE_MINUS_DST_ALPHA\",774:\"DST_COLOR\",775:\"ONE_MINUS_DST_COLOR\",776:\"SRC_ALPHA_SATURATE\",1024:\"STENCIL_BUFFER_BIT\",1028:\"FRONT\",1029:\"BACK\",1032:\"FRONT_AND_BACK\",1280:\"INVALID_ENUM\",1281:\"INVALID_VALUE\",1282:\"INVALID_OPERATION\",1285:\"OUT_OF_MEMORY\",1286:\"INVALID_FRAMEBUFFER_OPERATION\",2304:\"CW\",2305:\"CCW\",2849:\"LINE_WIDTH\",2884:\"CULL_FACE\",2885:\"CULL_FACE_MODE\",2886:\"FRONT_FACE\",2928:\"DEPTH_RANGE\",2929:\"DEPTH_TEST\",2930:\"DEPTH_WRITEMASK\",2931:\"DEPTH_CLEAR_VALUE\",2932:\"DEPTH_FUNC\",2960:\"STENCIL_TEST\",2961:\"STENCIL_CLEAR_VALUE\",2962:\"STENCIL_FUNC\",2963:\"STENCIL_VALUE_MASK\",2964:\"STENCIL_FAIL\",2965:\"STENCIL_PASS_DEPTH_FAIL\",2966:\"STENCIL_PASS_DEPTH_PASS\",2967:\"STENCIL_REF\",2968:\"STENCIL_WRITEMASK\",2978:\"VIEWPORT\",3024:\"DITHER\",3042:\"BLEND\",3088:\"SCISSOR_BOX\",3089:\"SCISSOR_TEST\",3106:\"COLOR_CLEAR_VALUE\",3107:\"COLOR_WRITEMASK\",3317:\"UNPACK_ALIGNMENT\",3333:\"PACK_ALIGNMENT\",3379:\"MAX_TEXTURE_SIZE\",3386:\"MAX_VIEWPORT_DIMS\",3408:\"SUBPIXEL_BITS\",3410:\"RED_BITS\",3411:\"GREEN_BITS\",3412:\"BLUE_BITS\",3413:\"ALPHA_BITS\",3414:\"DEPTH_BITS\",3415:\"STENCIL_BITS\",3553:\"TEXTURE_2D\",4352:\"DONT_CARE\",4353:\"FASTEST\",4354:\"NICEST\",5120:\"BYTE\",5121:\"UNSIGNED_BYTE\",5122:\"SHORT\",5123:\"UNSIGNED_SHORT\",5124:\"INT\",5125:\"UNSIGNED_INT\",5126:\"FLOAT\",5386:\"INVERT\",5890:\"TEXTURE\",6401:\"STENCIL_INDEX\",6402:\"DEPTH_COMPONENT\",6406:\"ALPHA\",6407:\"RGB\",6408:\"RGBA\",6409:\"LUMINANCE\",6410:\"LUMINANCE_ALPHA\",7680:\"KEEP\",7681:\"REPLACE\",7682:\"INCR\",7683:\"DECR\",7936:\"VENDOR\",7937:\"RENDERER\",7938:\"VERSION\",9728:\"NEAREST\",9729:\"LINEAR\",9984:\"NEAREST_MIPMAP_NEAREST\",9985:\"LINEAR_MIPMAP_NEAREST\",9986:\"NEAREST_MIPMAP_LINEAR\",9987:\"LINEAR_MIPMAP_LINEAR\",10240:\"TEXTURE_MAG_FILTER\",10241:\"TEXTURE_MIN_FILTER\",10242:\"TEXTURE_WRAP_S\",10243:\"TEXTURE_WRAP_T\",10497:\"REPEAT\",10752:\"POLYGON_OFFSET_UNITS\",16384:\"COLOR_BUFFER_BIT\",32769:\"CONSTANT_COLOR\",32770:\"ONE_MINUS_CONSTANT_COLOR\",32771:\"CONSTANT_ALPHA\",32772:\"ONE_MINUS_CONSTANT_ALPHA\",32773:\"BLEND_COLOR\",32774:\"FUNC_ADD\",32777:\"BLEND_EQUATION_RGB\",32778:\"FUNC_SUBTRACT\",32779:\"FUNC_REVERSE_SUBTRACT\",32819:\"UNSIGNED_SHORT_4_4_4_4\",32820:\"UNSIGNED_SHORT_5_5_5_1\",32823:\"POLYGON_OFFSET_FILL\",32824:\"POLYGON_OFFSET_FACTOR\",32854:\"RGBA4\",32855:\"RGB5_A1\",32873:\"TEXTURE_BINDING_2D\",32926:\"SAMPLE_ALPHA_TO_COVERAGE\",32928:\"SAMPLE_COVERAGE\",32936:\"SAMPLE_BUFFERS\",32937:\"SAMPLES\",32938:\"SAMPLE_COVERAGE_VALUE\",32939:\"SAMPLE_COVERAGE_INVERT\",32968:\"BLEND_DST_RGB\",32969:\"BLEND_SRC_RGB\",32970:\"BLEND_DST_ALPHA\",32971:\"BLEND_SRC_ALPHA\",33071:\"CLAMP_TO_EDGE\",33170:\"GENERATE_MIPMAP_HINT\",33189:\"DEPTH_COMPONENT16\",33306:\"DEPTH_STENCIL_ATTACHMENT\",33635:\"UNSIGNED_SHORT_5_6_5\",33648:\"MIRRORED_REPEAT\",33901:\"ALIASED_POINT_SIZE_RANGE\",33902:\"ALIASED_LINE_WIDTH_RANGE\",33984:\"TEXTURE0\",33985:\"TEXTURE1\",33986:\"TEXTURE2\",33987:\"TEXTURE3\",33988:\"TEXTURE4\",33989:\"TEXTURE5\",33990:\"TEXTURE6\",33991:\"TEXTURE7\",33992:\"TEXTURE8\",33993:\"TEXTURE9\",33994:\"TEXTURE10\",33995:\"TEXTURE11\",33996:\"TEXTURE12\",33997:\"TEXTURE13\",33998:\"TEXTURE14\",33999:\"TEXTURE15\",34000:\"TEXTURE16\",34001:\"TEXTURE17\",34002:\"TEXTURE18\",34003:\"TEXTURE19\",34004:\"TEXTURE20\",34005:\"TEXTURE21\",34006:\"TEXTURE22\",34007:\"TEXTURE23\",34008:\"TEXTURE24\",34009:\"TEXTURE25\",34010:\"TEXTURE26\",34011:\"TEXTURE27\",34012:\"TEXTURE28\",34013:\"TEXTURE29\",34014:\"TEXTURE30\",34015:\"TEXTURE31\",34016:\"ACTIVE_TEXTURE\",34024:\"MAX_RENDERBUFFER_SIZE\",34041:\"DEPTH_STENCIL\",34055:\"INCR_WRAP\",34056:\"DECR_WRAP\",34067:\"TEXTURE_CUBE_MAP\",34068:\"TEXTURE_BINDING_CUBE_MAP\",34069:\"TEXTURE_CUBE_MAP_POSITIVE_X\",34070:\"TEXTURE_CUBE_MAP_NEGATIVE_X\",34071:\"TEXTURE_CUBE_MAP_POSITIVE_Y\",34072:\"TEXTURE_CUBE_MAP_NEGATIVE_Y\",34073:\"TEXTURE_CUBE_MAP_POSITIVE_Z\",34074:\"TEXTURE_CUBE_MAP_NEGATIVE_Z\",34076:\"MAX_CUBE_MAP_TEXTURE_SIZE\",34338:\"VERTEX_ATTRIB_ARRAY_ENABLED\",34339:\"VERTEX_ATTRIB_ARRAY_SIZE\",34340:\"VERTEX_ATTRIB_ARRAY_STRIDE\",34341:\"VERTEX_ATTRIB_ARRAY_TYPE\",34342:\"CURRENT_VERTEX_ATTRIB\",34373:\"VERTEX_ATTRIB_ARRAY_POINTER\",34466:\"NUM_COMPRESSED_TEXTURE_FORMATS\",34467:\"COMPRESSED_TEXTURE_FORMATS\",34660:\"BUFFER_SIZE\",34661:\"BUFFER_USAGE\",34816:\"STENCIL_BACK_FUNC\",34817:\"STENCIL_BACK_FAIL\",34818:\"STENCIL_BACK_PASS_DEPTH_FAIL\",34819:\"STENCIL_BACK_PASS_DEPTH_PASS\",34877:\"BLEND_EQUATION_ALPHA\",34921:\"MAX_VERTEX_ATTRIBS\",34922:\"VERTEX_ATTRIB_ARRAY_NORMALIZED\",34930:\"MAX_TEXTURE_IMAGE_UNITS\",34962:\"ARRAY_BUFFER\",34963:\"ELEMENT_ARRAY_BUFFER\",34964:\"ARRAY_BUFFER_BINDING\",34965:\"ELEMENT_ARRAY_BUFFER_BINDING\",34975:\"VERTEX_ATTRIB_ARRAY_BUFFER_BINDING\",35040:\"STREAM_DRAW\",35044:\"STATIC_DRAW\",35048:\"DYNAMIC_DRAW\",35632:\"FRAGMENT_SHADER\",35633:\"VERTEX_SHADER\",35660:\"MAX_VERTEX_TEXTURE_IMAGE_UNITS\",35661:\"MAX_COMBINED_TEXTURE_IMAGE_UNITS\",35663:\"SHADER_TYPE\",35664:\"FLOAT_VEC2\",35665:\"FLOAT_VEC3\",35666:\"FLOAT_VEC4\",35667:\"INT_VEC2\",35668:\"INT_VEC3\",35669:\"INT_VEC4\",35670:\"BOOL\",35671:\"BOOL_VEC2\",35672:\"BOOL_VEC3\",35673:\"BOOL_VEC4\",35674:\"FLOAT_MAT2\",35675:\"FLOAT_MAT3\",35676:\"FLOAT_MAT4\",35678:\"SAMPLER_2D\",35680:\"SAMPLER_CUBE\",35712:\"DELETE_STATUS\",35713:\"COMPILE_STATUS\",35714:\"LINK_STATUS\",35715:\"VALIDATE_STATUS\",35716:\"INFO_LOG_LENGTH\",35717:\"ATTACHED_SHADERS\",35718:\"ACTIVE_UNIFORMS\",35719:\"ACTIVE_UNIFORM_MAX_LENGTH\",35720:\"SHADER_SOURCE_LENGTH\",35721:\"ACTIVE_ATTRIBUTES\",35722:\"ACTIVE_ATTRIBUTE_MAX_LENGTH\",35724:\"SHADING_LANGUAGE_VERSION\",35725:\"CURRENT_PROGRAM\",36003:\"STENCIL_BACK_REF\",36004:\"STENCIL_BACK_VALUE_MASK\",36005:\"STENCIL_BACK_WRITEMASK\",36006:\"FRAMEBUFFER_BINDING\",36007:\"RENDERBUFFER_BINDING\",36048:\"FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE\",36049:\"FRAMEBUFFER_ATTACHMENT_OBJECT_NAME\",36050:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL\",36051:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE\",36053:\"FRAMEBUFFER_COMPLETE\",36054:\"FRAMEBUFFER_INCOMPLETE_ATTACHMENT\",36055:\"FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT\",36057:\"FRAMEBUFFER_INCOMPLETE_DIMENSIONS\",36061:\"FRAMEBUFFER_UNSUPPORTED\",36064:\"COLOR_ATTACHMENT0\",36096:\"DEPTH_ATTACHMENT\",36128:\"STENCIL_ATTACHMENT\",36160:\"FRAMEBUFFER\",36161:\"RENDERBUFFER\",36162:\"RENDERBUFFER_WIDTH\",36163:\"RENDERBUFFER_HEIGHT\",36164:\"RENDERBUFFER_INTERNAL_FORMAT\",36168:\"STENCIL_INDEX8\",36176:\"RENDERBUFFER_RED_SIZE\",36177:\"RENDERBUFFER_GREEN_SIZE\",36178:\"RENDERBUFFER_BLUE_SIZE\",36179:\"RENDERBUFFER_ALPHA_SIZE\",36180:\"RENDERBUFFER_DEPTH_SIZE\",36181:\"RENDERBUFFER_STENCIL_SIZE\",36194:\"RGB565\",36336:\"LOW_FLOAT\",36337:\"MEDIUM_FLOAT\",36338:\"HIGH_FLOAT\",36339:\"LOW_INT\",36340:\"MEDIUM_INT\",36341:\"HIGH_INT\",36346:\"SHADER_COMPILER\",36347:\"MAX_VERTEX_UNIFORM_VECTORS\",36348:\"MAX_VARYING_VECTORS\",36349:\"MAX_FRAGMENT_UNIFORM_VECTORS\",37440:\"UNPACK_FLIP_Y_WEBGL\",37441:\"UNPACK_PREMULTIPLY_ALPHA_WEBGL\",37442:\"CONTEXT_LOST_WEBGL\",37443:\"UNPACK_COLORSPACE_CONVERSION_WEBGL\",37444:\"BROWSER_DEFAULT_WEBGL\"}},{}],246:[function(t,e,r){var n=t(\"./1.0/numbers\");e.exports=function(t){return n[t]}},{\"./1.0/numbers\":245}],247:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),o=i(e,[{buffer:r,type:e.FLOAT,size:3,offset:0,stride:40},{buffer:r,type:e.FLOAT,size:4,offset:12,stride:40},{buffer:r,type:e.FLOAT,size:3,offset:28,stride:40}]),l=a(e);l.attributes.position.location=0,l.attributes.color.location=1,l.attributes.offset.location=2;var c=new s(e,r,o,l);return c.update(t),c};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\"),o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.shader=n,this.buffer=e,this.vao=r,this.pixelRatio=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lineWidth=[1,1,1],this.capSize=[10,10,10],this.lineCount=[0,0,0],this.lineOffset=[0,0,0],this.opacity=1,this.hasAlpha=!1}var l=s.prototype;function c(t,e){for(var r=0;r<3;++r)t[0][r]=Math.min(t[0][r],e[r]),t[1][r]=Math.max(t[1][r],e[r])}l.isOpaque=function(){return!this.hasAlpha},l.isTransparent=function(){return this.hasAlpha},l.drawTransparent=l.draw=function(t){var e=this.gl,r=this.shader.uniforms;this.shader.bind();var n=r.view=t.view||o,i=r.projection=t.projection||o;r.model=t.model||o,r.clipBounds=this.clipBounds,r.opacity=this.opacity;var a=n[12],s=n[13],l=n[14],c=n[15],u=(t._ortho||!1?2:1)*this.pixelRatio*(i[3]*a+i[7]*s+i[11]*l+i[15]*c)/e.drawingBufferHeight;this.vao.bind();for(var h=0;h<3;++h)e.lineWidth(this.lineWidth[h]*this.pixelRatio),r.capSize=this.capSize[h]*u,this.lineCount[h]&&e.drawArrays(e.LINES,this.lineOffset[h],this.lineCount[h]);this.vao.unbind()};var u=function(){for(var t=new Array(3),e=0;e<3;++e){for(var r=[],n=1;n<=2;++n)for(var i=-1;i<=1;i+=2){var a=[0,0,0];a[(n+e)%3]=i,r.push(a)}t[e]=r}return t}();function h(t,e,r,n){for(var i=u[n],a=0;a<i.length;++a){var o=i[a];t.push(e[0],e[1],e[2],r[0],r[1],r[2],r[3],o[0],o[1],o[2])}return i.length}l.update=function(t){\"lineWidth\"in(t=t||{})&&(this.lineWidth=t.lineWidth,Array.isArray(this.lineWidth)||(this.lineWidth=[this.lineWidth,this.lineWidth,this.lineWidth])),\"capSize\"in t&&(this.capSize=t.capSize,Array.isArray(this.capSize)||(this.capSize=[this.capSize,this.capSize,this.capSize])),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var e=t.color||[[0,0,0],[0,0,0],[0,0,0]],r=t.position,n=t.error;if(Array.isArray(e[0])||(e=[e,e,e]),r&&n){var i=[],a=r.length,o=0;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.lineCount=[0,0,0];for(var s=0;s<3;++s){this.lineOffset[s]=o;t:for(var l=0;l<a;++l){for(var u=r[l],f=0;f<3;++f)if(isNaN(u[f])||!isFinite(u[f]))continue t;var p=n[l],d=e[s];if(Array.isArray(d[0])&&(d=e[l]),3===d.length?d=[d[0],d[1],d[2],1]:4===d.length&&(d=[d[0],d[1],d[2],d[3]],!this.hasAlpha&&d[3]<1&&(this.hasAlpha=!0)),!isNaN(p[0][s])&&!isNaN(p[1][s])){var g;if(p[0][s]<0)(g=u.slice())[s]+=p[0][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+h(i,g,d,s);if(p[1][s]>0)(g=u.slice())[s]+=p[1][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+h(i,g,d,s)}}this.lineCount[s]=o-this.lineOffset[s]}this.buffer.update(i)}},l.dispose=function(){this.shader.dispose(),this.buffer.dispose(),this.vao.dispose()}},{\"./shaders/index\":248,\"gl-buffer\":241,\"gl-vao\":327}],248:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, offset;\\nattribute vec4 color;\\nuniform mat4 model, view, projection;\\nuniform float capSize;\\nvarying vec4 fragColor;\\nvarying vec3 fragPosition;\\n\\nvoid main() {\\n  vec4 worldPosition  = model * vec4(position, 1.0);\\n  worldPosition       = (worldPosition / worldPosition.w) + vec4(capSize * offset, 0.0);\\n  gl_Position         = projection * view * worldPosition;\\n  fragColor           = color;\\n  fragPosition        = position;\\n}\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float opacity;\\nvarying vec3 fragPosition;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], fragPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  gl_FragColor = opacity * fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"offset\",type:\"vec3\"}])}},{\"gl-shader\":301,glslify:409}],249:[function(t,e,r){\"use strict\";var n=t(\"gl-texture2d\");e.exports=function(t,e,r,n){i||(i=t.FRAMEBUFFER_UNSUPPORTED,a=t.FRAMEBUFFER_INCOMPLETE_ATTACHMENT,o=t.FRAMEBUFFER_INCOMPLETE_DIMENSIONS,s=t.FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT);var c=t.getExtension(\"WEBGL_draw_buffers\");!l&&c&&function(t,e){var r=t.getParameter(e.MAX_COLOR_ATTACHMENTS_WEBGL);l=new Array(r+1);for(var n=0;n<=r;++n){for(var i=new Array(r),a=0;a<n;++a)i[a]=t.COLOR_ATTACHMENT0+a;for(var a=n;a<r;++a)i[a]=t.NONE;l[n]=i}}(t,c);Array.isArray(e)&&(n=r,r=0|e[1],e=0|e[0]);if(\"number\"!=typeof e)throw new Error(\"gl-fbo: Missing shape parameter\");var u=t.getParameter(t.MAX_RENDERBUFFER_SIZE);if(e<0||e>u||r<0||r>u)throw new Error(\"gl-fbo: Parameters are too large for FBO\");var h=1;if(\"color\"in(n=n||{})){if((h=Math.max(0|n.color,0))<0)throw new Error(\"gl-fbo: Must specify a nonnegative number of colors\");if(h>1){if(!c)throw new Error(\"gl-fbo: Multiple draw buffer extension not supported\");if(h>t.getParameter(c.MAX_COLOR_ATTACHMENTS_WEBGL))throw new Error(\"gl-fbo: Context does not support \"+h+\" draw buffers\")}}var f=t.UNSIGNED_BYTE,p=t.getExtension(\"OES_texture_float\");if(n.float&&h>0){if(!p)throw new Error(\"gl-fbo: Context does not support floating point textures\");f=t.FLOAT}else n.preferFloat&&h>0&&p&&(f=t.FLOAT);var g=!0;\"depth\"in n&&(g=!!n.depth);var v=!1;\"stencil\"in n&&(v=!!n.stencil);return new d(t,e,r,f,h,g,v,c)};var i,a,o,s,l=null;function c(t){return[t.getParameter(t.FRAMEBUFFER_BINDING),t.getParameter(t.RENDERBUFFER_BINDING),t.getParameter(t.TEXTURE_BINDING_2D)]}function u(t,e){t.bindFramebuffer(t.FRAMEBUFFER,e[0]),t.bindRenderbuffer(t.RENDERBUFFER,e[1]),t.bindTexture(t.TEXTURE_2D,e[2])}function h(t){switch(t){case i:throw new Error(\"gl-fbo: Framebuffer unsupported\");case a:throw new Error(\"gl-fbo: Framebuffer incomplete attachment\");case o:throw new Error(\"gl-fbo: Framebuffer incomplete dimensions\");case s:throw new Error(\"gl-fbo: Framebuffer incomplete missing attachment\");default:throw new Error(\"gl-fbo: Framebuffer failed for unspecified reason\")}}function f(t,e,r,i,a,o){if(!i)return null;var s=n(t,e,r,a,i);return s.magFilter=t.NEAREST,s.minFilter=t.NEAREST,s.mipSamples=1,s.bind(),t.framebufferTexture2D(t.FRAMEBUFFER,o,t.TEXTURE_2D,s.handle,0),s}function p(t,e,r,n,i){var a=t.createRenderbuffer();return t.bindRenderbuffer(t.RENDERBUFFER,a),t.renderbufferStorage(t.RENDERBUFFER,n,e,r),t.framebufferRenderbuffer(t.FRAMEBUFFER,i,t.RENDERBUFFER,a),a}function d(t,e,r,n,i,a,o,s){this.gl=t,this._shape=[0|e,0|r],this._destroyed=!1,this._ext=s,this.color=new Array(i);for(var d=0;d<i;++d)this.color[d]=null;this._color_rb=null,this.depth=null,this._depth_rb=null,this._colorType=n,this._useDepth=a,this._useStencil=o;var g=this,v=[0|e,0|r];Object.defineProperties(v,{0:{get:function(){return g._shape[0]},set:function(t){return g.width=t}},1:{get:function(){return g._shape[1]},set:function(t){return g.height=t}}}),this._shapeVector=v,function(t){var e=c(t.gl),r=t.gl,n=t.handle=r.createFramebuffer(),i=t._shape[0],a=t._shape[1],o=t.color.length,s=t._ext,d=t._useStencil,g=t._useDepth,v=t._colorType;r.bindFramebuffer(r.FRAMEBUFFER,n);for(var m=0;m<o;++m)t.color[m]=f(r,i,a,v,r.RGBA,r.COLOR_ATTACHMENT0+m);0===o?(t._color_rb=p(r,i,a,r.RGBA4,r.COLOR_ATTACHMENT0),s&&s.drawBuffersWEBGL(l[0])):o>1&&s.drawBuffersWEBGL(l[o]);var y=r.getExtension(\"WEBGL_depth_texture\");y?d?t.depth=f(r,i,a,y.UNSIGNED_INT_24_8_WEBGL,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g&&(t.depth=f(r,i,a,r.UNSIGNED_SHORT,r.DEPTH_COMPONENT,r.DEPTH_ATTACHMENT)):g&&d?t._depth_rb=p(r,i,a,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g?t._depth_rb=p(r,i,a,r.DEPTH_COMPONENT16,r.DEPTH_ATTACHMENT):d&&(t._depth_rb=p(r,i,a,r.STENCIL_INDEX,r.STENCIL_ATTACHMENT));var x=r.checkFramebufferStatus(r.FRAMEBUFFER);if(x!==r.FRAMEBUFFER_COMPLETE){for(t._destroyed=!0,r.bindFramebuffer(r.FRAMEBUFFER,null),r.deleteFramebuffer(t.handle),t.handle=null,t.depth&&(t.depth.dispose(),t.depth=null),t._depth_rb&&(r.deleteRenderbuffer(t._depth_rb),t._depth_rb=null),m=0;m<t.color.length;++m)t.color[m].dispose(),t.color[m]=null;t._color_rb&&(r.deleteRenderbuffer(t._color_rb),t._color_rb=null),u(r,e),h(x)}u(r,e)}(this)}var g=d.prototype;function v(t,e,r){if(t._destroyed)throw new Error(\"gl-fbo: Can't resize destroyed FBO\");if(t._shape[0]!==e||t._shape[1]!==r){var n=t.gl,i=n.getParameter(n.MAX_RENDERBUFFER_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-fbo: Can't resize FBO, invalid dimensions\");t._shape[0]=e,t._shape[1]=r;for(var a=c(n),o=0;o<t.color.length;++o)t.color[o].shape=t._shape;t._color_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._color_rb),n.renderbufferStorage(n.RENDERBUFFER,n.RGBA4,t._shape[0],t._shape[1])),t.depth&&(t.depth.shape=t._shape),t._depth_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._depth_rb),t._useDepth&&t._useStencil?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_STENCIL,t._shape[0],t._shape[1]):t._useDepth?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_COMPONENT16,t._shape[0],t._shape[1]):t._useStencil&&n.renderbufferStorage(n.RENDERBUFFER,n.STENCIL_INDEX,t._shape[0],t._shape[1])),n.bindFramebuffer(n.FRAMEBUFFER,t.handle);var s=n.checkFramebufferStatus(n.FRAMEBUFFER);s!==n.FRAMEBUFFER_COMPLETE&&(t.dispose(),u(n,a),h(s)),u(n,a)}}Object.defineProperties(g,{shape:{get:function(){return this._destroyed?[0,0]:this._shapeVector},set:function(t){if(Array.isArray(t)||(t=[0|t,0|t]),2!==t.length)throw new Error(\"gl-fbo: Shape vector must be length 2\");var e=0|t[0],r=0|t[1];return v(this,e,r),[e,r]},enumerable:!1},width:{get:function(){return this._destroyed?0:this._shape[0]},set:function(t){return v(this,t|=0,this._shape[1]),t},enumerable:!1},height:{get:function(){return this._destroyed?0:this._shape[1]},set:function(t){return t|=0,v(this,this._shape[0],t),t},enumerable:!1}}),g.bind=function(){if(!this._destroyed){var t=this.gl;t.bindFramebuffer(t.FRAMEBUFFER,this.handle),t.viewport(0,0,this._shape[0],this._shape[1])}},g.dispose=function(){if(!this._destroyed){this._destroyed=!0;var t=this.gl;t.deleteFramebuffer(this.handle),this.handle=null,this.depth&&(this.depth.dispose(),this.depth=null),this._depth_rb&&(t.deleteRenderbuffer(this._depth_rb),this._depth_rb=null);for(var e=0;e<this.color.length;++e)this.color[e].dispose(),this.color[e]=null;this._color_rb&&(t.deleteRenderbuffer(this._color_rb),this._color_rb=null)}}},{\"gl-texture2d\":322}],250:[function(t,e,r){var n=t(\"sprintf-js\").sprintf,i=t(\"gl-constants/lookup\"),a=t(\"glsl-shader-name\"),o=t(\"add-line-numbers\");e.exports=function(t,e,r){\"use strict\";var s=a(e)||\"of unknown name (see npm glsl-shader-name)\",l=\"unknown type\";void 0!==r&&(l=r===i.FRAGMENT_SHADER?\"fragment\":\"vertex\");for(var c=n(\"Error compiling %s shader %s:\\n\",l,s),u=n(\"%s%s\",c,t),h=t.split(\"\\n\"),f={},p=0;p<h.length;p++){var d=h[p];if(\"\"!==d&&\"\\0\"!==d){var g=parseInt(d.split(\":\")[2]);if(isNaN(g))throw new Error(n(\"Could not parse error: %s\",d));f[g]=d}}for(var v=o(e).split(\"\\n\"),p=0;p<v.length;p++)if(f[p+3]||f[p+2]||f[p+1]){var m=v[p];if(c+=m+\"\\n\",f[p+1]){var y=f[p+1];y=y.substr(y.split(\":\",3).join(\":\").length+1).trim(),c+=n(\"^^^ %s\\n\\n\",y)}}return{long:c.trim(),short:u.trim()}}},{\"add-line-numbers\":61,\"gl-constants/lookup\":246,\"glsl-shader-name\":401,\"sprintf-js\":528}],251:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.gl,n=o(r,l.vertex,l.fragment),i=o(r,l.pickVertex,l.pickFragment),a=s(r),u=s(r),h=s(r),f=s(r),p=new c(t,n,i,a,u,h,f);return p.update(e),t.addObject(p),p};var n=t(\"binary-search-bounds\"),i=t(\"iota-array\"),a=t(\"typedarray-pool\"),o=t(\"gl-shader\"),s=t(\"gl-buffer\"),l=t(\"./lib/shaders\");function c(t,e,r,n,i,a,o){this.plot=t,this.shader=e,this.pickShader=r,this.positionBuffer=n,this.weightBuffer=i,this.colorBuffer=a,this.idBuffer=o,this.xData=[],this.yData=[],this.shape=[0,0],this.bounds=[1/0,1/0,-1/0,-1/0],this.pickOffset=0}var u,h=c.prototype,f=[0,0,1,0,0,1,1,0,1,1,0,1];h.draw=(u=[1,0,0,0,1,0,0,0,1],function(){var t=this.plot,e=this.shader,r=this.bounds,n=this.numVertices;if(!(n<=0)){var i=t.gl,a=t.dataBox,o=r[2]-r[0],s=r[3]-r[1],l=a[2]-a[0],c=a[3]-a[1];u[0]=2*o/l,u[4]=2*s/c,u[6]=2*(r[0]-a[0])/l-1,u[7]=2*(r[1]-a[1])/c-1,e.bind();var h=e.uniforms;h.viewTransform=u,h.shape=this.shape;var f=e.attributes;this.positionBuffer.bind(),f.position.pointer(),this.weightBuffer.bind(),f.weight.pointer(i.UNSIGNED_BYTE,!1),this.colorBuffer.bind(),f.color.pointer(i.UNSIGNED_BYTE,!0),i.drawArrays(i.TRIANGLES,0,n)}}),h.drawPick=function(){var t=[1,0,0,0,1,0,0,0,1],e=[0,0,0,0];return function(r){var n=this.plot,i=this.pickShader,a=this.bounds,o=this.numVertices;if(!(o<=0)){var s=n.gl,l=n.dataBox,c=a[2]-a[0],u=a[3]-a[1],h=l[2]-l[0],f=l[3]-l[1];t[0]=2*c/h,t[4]=2*u/f,t[6]=2*(a[0]-l[0])/h-1,t[7]=2*(a[1]-l[1])/f-1;for(var p=0;p<4;++p)e[p]=r>>8*p&255;this.pickOffset=r,i.bind();var d=i.uniforms;d.viewTransform=t,d.pickOffset=e,d.shape=this.shape;var g=i.attributes;return this.positionBuffer.bind(),g.position.pointer(),this.weightBuffer.bind(),g.weight.pointer(s.UNSIGNED_BYTE,!1),this.idBuffer.bind(),g.pickId.pointer(s.UNSIGNED_BYTE,!1),s.drawArrays(s.TRIANGLES,0,o),r+this.shape[0]*this.shape[1]}}}(),h.pick=function(t,e,r){var n=this.pickOffset,i=this.shape[0]*this.shape[1];if(r<n||r>=n+i)return null;var a=r-n,o=this.xData,s=this.yData;return{object:this,pointId:a,dataCoord:[o[a%this.shape[0]],s[a/this.shape[0]|0]]}},h.update=function(t){var e=(t=t||{}).shape||[0,0],r=t.x||i(e[0]),o=t.y||i(e[1]),s=t.z||new Float32Array(e[0]*e[1]);this.xData=r,this.yData=o;var l=t.colorLevels||[0],c=t.colorValues||[0,0,0,1],u=l.length,h=this.bounds,p=h[0]=r[0],d=h[1]=o[0],g=1/((h[2]=r[r.length-1])-p),v=1/((h[3]=o[o.length-1])-d),m=e[0],y=e[1];this.shape=[m,y];var x=(m-1)*(y-1)*(f.length>>>1);this.numVertices=x;for(var b=a.mallocUint8(4*x),_=a.mallocFloat32(2*x),w=a.mallocUint8(2*x),k=a.mallocUint32(x),T=0,A=0;A<y-1;++A)for(var M=v*(o[A]-d),S=v*(o[A+1]-d),E=0;E<m-1;++E)for(var C=g*(r[E]-p),L=g*(r[E+1]-p),P=0;P<f.length;P+=2){var O,z,I,D,R=f[P],F=f[P+1],B=s[(A+F)*m+(E+R)],N=n.le(l,B);if(N<0)O=c[0],z=c[1],I=c[2],D=c[3];else if(N===u-1)O=c[4*u-4],z=c[4*u-3],I=c[4*u-2],D=c[4*u-1];else{var j=(B-l[N])/(l[N+1]-l[N]),U=1-j,V=4*N,q=4*(N+1);O=U*c[V]+j*c[q],z=U*c[V+1]+j*c[q+1],I=U*c[V+2]+j*c[q+2],D=U*c[V+3]+j*c[q+3]}b[4*T]=255*O,b[4*T+1]=255*z,b[4*T+2]=255*I,b[4*T+3]=255*D,_[2*T]=.5*C+.5*L,_[2*T+1]=.5*M+.5*S,w[2*T]=R,w[2*T+1]=F,k[T]=A*m+E,T+=1}this.positionBuffer.update(_),this.weightBuffer.update(w),this.colorBuffer.update(b),this.idBuffer.update(k),a.free(_),a.free(b),a.free(w),a.free(k)},h.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.positionBuffer.dispose(),this.weightBuffer.dispose(),this.colorBuffer.dispose(),this.idBuffer.dispose(),this.plot.removeObject(this)}},{\"./lib/shaders\":252,\"binary-search-bounds\":253,\"gl-buffer\":241,\"gl-shader\":301,\"iota-array\":416,\"typedarray-pool\":545}],252:[function(t,e,r){\"use strict\";var n=t(\"glslify\");e.exports={fragment:n([\"precision lowp float;\\n#define GLSLIFY 1\\nvarying vec4 fragColor;\\nvoid main() {\\n  gl_FragColor = vec4(fragColor.rgb * fragColor.a, fragColor.a);\\n}\\n\"]),vertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 color;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  fragColor = color;\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"]),pickFragment:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nuniform vec2 shape;\\nuniform vec4 pickOffset;\\n\\nvoid main() {\\n  vec2 d = step(.5, vWeight);\\n  vec4 id = fragId + pickOffset;\\n  id.x += d.x + d.y*shape.x;\\n\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  gl_FragColor = id/255.;\\n}\\n\"]),pickVertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nvoid main() {\\n  vWeight = weight;\\n\\n  fragId = pickId;\\n\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"])}},{glslify:409}],253:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],254:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, nextPosition;\\nattribute float arcLength, lineWidth;\\nattribute vec4 color;\\n\\nuniform vec2 screenShape;\\nuniform float pixelRatio;\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 fragColor;\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  vec4 startPoint = project(position);\\n  vec4 endPoint   = project(nextPosition);\\n\\n  vec2 A = startPoint.xy / startPoint.w;\\n  vec2 B =   endPoint.xy /   endPoint.w;\\n\\n  float clipAngle = atan(\\n    (B.y - A.y) * screenShape.y,\\n    (B.x - A.x) * screenShape.x\\n  );\\n\\n  vec2 offset = 0.5 * pixelRatio * lineWidth * vec2(\\n    sin(clipAngle),\\n    -cos(clipAngle)\\n  ) / screenShape;\\n\\n  gl_Position = vec4(startPoint.xy + startPoint.w * offset, startPoint.zw);\\n\\n  worldPosition = position;\\n  pixelArcLength = arcLength;\\n  fragColor = color;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3      clipBounds[2];\\nuniform sampler2D dashTexture;\\nuniform float     dashScale;\\nuniform float     opacity;\\n\\nvarying vec3    worldPosition;\\nvarying float   pixelArcLength;\\nvarying vec4    fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], worldPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  float dashWeight = texture2D(dashTexture, vec2(dashScale * pixelArcLength, 0)).r;\\n  if(dashWeight < 0.5) {\\n    discard;\\n  }\\n  gl_FragColor = fragColor * opacity;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\n#define FLOAT_MAX  1.70141184e38\\n#define FLOAT_MIN  1.17549435e-38\\n\\nlowp vec4 encode_float_1540259130(highp float v) {\\n  highp float av = abs(v);\\n\\n  //Handle special cases\\n  if(av < FLOAT_MIN) {\\n    return vec4(0.0, 0.0, 0.0, 0.0);\\n  } else if(v > FLOAT_MAX) {\\n    return vec4(127.0, 128.0, 0.0, 0.0) / 255.0;\\n  } else if(v < -FLOAT_MAX) {\\n    return vec4(255.0, 128.0, 0.0, 0.0) / 255.0;\\n  }\\n\\n  highp vec4 c = vec4(0,0,0,0);\\n\\n  //Compute exponent and mantissa\\n  highp float e = floor(log2(av));\\n  highp float m = av * pow(2.0, -e) - 1.0;\\n  \\n  //Unpack mantissa\\n  c[1] = floor(128.0 * m);\\n  m -= c[1] / 128.0;\\n  c[2] = floor(32768.0 * m);\\n  m -= c[2] / 32768.0;\\n  c[3] = floor(8388608.0 * m);\\n  \\n  //Unpack exponent\\n  highp float ebias = e + 127.0;\\n  c[0] = floor(ebias / 2.0);\\n  ebias -= c[0] * 2.0;\\n  c[1] += floor(ebias) * 128.0; \\n\\n  //Unpack sign bit\\n  c[0] += 128.0 * step(0.0, -v);\\n\\n  //Scale back to range\\n  return c / 255.0;\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform float pickId;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], worldPosition)) discard;\\n\\n  gl_FragColor = vec4(pickId/255.0, encode_float_1540259130(pixelArcLength).xyz);\\n}\"]),l=[{name:\"position\",type:\"vec3\"},{name:\"nextPosition\",type:\"vec3\"},{name:\"arcLength\",type:\"float\"},{name:\"lineWidth\",type:\"float\"},{name:\"color\",type:\"vec4\"}];r.createShader=function(t){return i(t,a,o,null,l)},r.createPickShader=function(t){return i(t,a,s,null,l)}},{\"gl-shader\":301,glslify:409}],255:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl||t.scene&&t.scene.gl,r=u(e);r.attributes.position.location=0,r.attributes.nextPosition.location=1,r.attributes.arcLength.location=2,r.attributes.lineWidth.location=3,r.attributes.color.location=4;var o=h(e);o.attributes.position.location=0,o.attributes.nextPosition.location=1,o.attributes.arcLength.location=2,o.attributes.lineWidth.location=3,o.attributes.color.location=4;for(var s=n(e),c=i(e,[{buffer:s,size:3,offset:0,stride:48},{buffer:s,size:3,offset:12,stride:48},{buffer:s,size:1,offset:24,stride:48},{buffer:s,size:1,offset:28,stride:48},{buffer:s,size:4,offset:32,stride:48}]),f=l(new Array(1024),[256,1,4]),p=0;p<1024;++p)f.data[p]=255;var d=a(e,f);d.wrap=e.REPEAT;var g=new v(e,r,o,s,c,d);return g.update(t),g};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"gl-texture2d\"),o=t(\"glsl-read-float\"),s=t(\"binary-search-bounds\"),l=t(\"ndarray\"),c=t(\"./lib/shaders\"),u=c.createShader,h=c.createPickShader,f=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function p(t,e){for(var r=0,n=0;n<3;++n){var i=t[n]-e[n];r+=i*i}return Math.sqrt(r)}function d(t){for(var e=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],r=0;r<3;++r)e[0][r]=Math.max(t[0][r],e[0][r]),e[1][r]=Math.min(t[1][r],e[1][r]);return e}function g(t,e,r,n){this.arcLength=t,this.position=e,this.index=r,this.dataCoordinate=n}function v(t,e,r,n,i,a){this.gl=t,this.shader=e,this.pickShader=r,this.buffer=n,this.vao=i,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.points=[],this.arcLength=[],this.vertexCount=0,this.bounds=[[0,0,0],[0,0,0]],this.pickId=0,this.lineWidth=1,this.texture=a,this.dashScale=1,this.opacity=1,this.hasAlpha=!1,this.dirty=!0,this.pixelRatio=1}var m=v.prototype;m.isTransparent=function(){return this.hasAlpha},m.isOpaque=function(){return!this.hasAlpha},m.pickSlots=1,m.setPickBase=function(t){this.pickId=t},m.drawTransparent=m.draw=function(t){if(this.vertexCount){var e=this.gl,r=this.shader,n=this.vao;r.bind(),r.uniforms={model:t.model||f,view:t.view||f,projection:t.projection||f,clipBounds:d(this.clipBounds),dashTexture:this.texture.bind(),dashScale:this.dashScale/this.arcLength[this.arcLength.length-1],opacity:this.opacity,screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},m.drawPick=function(t){if(this.vertexCount){var e=this.gl,r=this.pickShader,n=this.vao;r.bind(),r.uniforms={model:t.model||f,view:t.view||f,projection:t.projection||f,pickId:this.pickId,clipBounds:d(this.clipBounds),screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},m.update=function(t){var e,r;this.dirty=!0;var n=!!t.connectGaps;\"dashScale\"in t&&(this.dashScale=t.dashScale),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var i=[],a=[],o=[],c=0,u=0,h=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],f=t.position||t.positions;if(f){var d=t.color||t.colors||[0,0,0,1],g=t.lineWidth||1,v=!1;t:for(e=1;e<f.length;++e){var m,y,x,b=f[e-1],_=f[e];for(a.push(c),o.push(b.slice()),r=0;r<3;++r){if(isNaN(b[r])||isNaN(_[r])||!isFinite(b[r])||!isFinite(_[r])){if(!n&&i.length>0){for(var w=0;w<24;++w)i.push(i[i.length-12]);u+=2,v=!0}continue t}h[0][r]=Math.min(h[0][r],b[r],_[r]),h[1][r]=Math.max(h[1][r],b[r],_[r])}Array.isArray(d[0])?(m=d.length>e-1?d[e-1]:d.length>0?d[d.length-1]:[0,0,0,1],y=d.length>e?d[e]:d.length>0?d[d.length-1]:[0,0,0,1]):m=y=d,3===m.length&&(m=[m[0],m[1],m[2],1]),3===y.length&&(y=[y[0],y[1],y[2],1]),!this.hasAlpha&&m[3]<1&&(this.hasAlpha=!0),x=Array.isArray(g)?g.length>e-1?g[e-1]:g.length>0?g[g.length-1]:[0,0,0,1]:g;var k=c;if(c+=p(b,_),v){for(r=0;r<2;++r)i.push(b[0],b[1],b[2],_[0],_[1],_[2],k,x,m[0],m[1],m[2],m[3]);u+=2,v=!1}i.push(b[0],b[1],b[2],_[0],_[1],_[2],k,x,m[0],m[1],m[2],m[3],b[0],b[1],b[2],_[0],_[1],_[2],k,-x,m[0],m[1],m[2],m[3],_[0],_[1],_[2],b[0],b[1],b[2],c,-x,y[0],y[1],y[2],y[3],_[0],_[1],_[2],b[0],b[1],b[2],c,x,y[0],y[1],y[2],y[3]),u+=4}}if(this.buffer.update(i),a.push(c),o.push(f[f.length-1].slice()),this.bounds=h,this.vertexCount=u,this.points=o,this.arcLength=a,\"dashes\"in t){var T=t.dashes.slice();for(T.unshift(0),e=1;e<T.length;++e)T[e]=T[e-1]+T[e];var A=l(new Array(1024),[256,1,4]);for(e=0;e<256;++e){for(r=0;r<4;++r)A.set(e,0,r,0);1&s.le(T,T[T.length-1]*e/255)?A.set(e,0,0,0):A.set(e,0,0,255)}this.texture.setPixels(A)}},m.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()},m.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=o(t.value[0],t.value[1],t.value[2],0),r=s.le(this.arcLength,e);if(r<0)return null;if(r===this.arcLength.length-1)return new g(this.arcLength[this.arcLength.length-1],this.points[this.points.length-1].slice(),r);for(var n=this.points[r],i=this.points[Math.min(r+1,this.points.length-1)],a=(e-this.arcLength[r])/(this.arcLength[r+1]-this.arcLength[r]),l=1-a,c=[0,0,0],u=0;u<3;++u)c[u]=l*n[u]+a*i[u];var h=Math.min(a<.5?r:r+1,this.points.length-1);return new g(e,c,h,this.points[h])}},{\"./lib/shaders\":254,\"binary-search-bounds\":256,\"gl-buffer\":241,\"gl-texture2d\":322,\"gl-vao\":327,\"glsl-read-float\":400,ndarray:450}],256:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],257:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r*a-i*n;return o?(o=1/o,t[0]=a*o,t[1]=-n*o,t[2]=-i*o,t[3]=r*o,t):null}},{}],258:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=u*o-s*c,f=-u*a+s*l,p=c*a-o*l,d=r*h+n*f+i*p;return d?(d=1/d,t[0]=h*d,t[1]=(-u*n+i*c)*d,t[2]=(s*n-i*o)*d,t[3]=f*d,t[4]=(u*r-i*l)*d,t[5]=(-s*r+i*a)*d,t[6]=p*d,t[7]=(-c*r+n*l)*d,t[8]=(o*r-n*a)*d,t):null}},{}],259:[function(t,e,r){e.exports=function(t){var e=new Float32Array(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e}},{}],260:[function(t,e,r){e.exports=function(){var t=new Float32Array(16);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],261:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3],a=t[4],o=t[5],s=t[6],l=t[7],c=t[8],u=t[9],h=t[10],f=t[11],p=t[12],d=t[13],g=t[14],v=t[15];return(e*o-r*a)*(h*v-f*g)-(e*s-n*a)*(u*v-f*d)+(e*l-i*a)*(u*g-h*d)+(r*s-n*o)*(c*v-f*p)-(r*l-i*o)*(c*g-h*p)+(n*l-i*s)*(c*d-u*p)}},{}],262:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r+r,s=n+n,l=i+i,c=r*o,u=n*o,h=n*s,f=i*o,p=i*s,d=i*l,g=a*o,v=a*s,m=a*l;return t[0]=1-h-d,t[1]=u+m,t[2]=f-v,t[3]=0,t[4]=u-m,t[5]=1-c-d,t[6]=p+g,t[7]=0,t[8]=f+v,t[9]=p-g,t[10]=1-c-h,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],263:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=n+n,l=i+i,c=a+a,u=n*s,h=n*l,f=n*c,p=i*l,d=i*c,g=a*c,v=o*s,m=o*l,y=o*c;return t[0]=1-(p+g),t[1]=h+y,t[2]=f-m,t[3]=0,t[4]=h-y,t[5]=1-(u+g),t[6]=d+v,t[7]=0,t[8]=f+m,t[9]=d-v,t[10]=1-(u+p),t[11]=0,t[12]=r[0],t[13]=r[1],t[14]=r[2],t[15]=1,t}},{}],264:[function(t,e,r){e.exports=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],265:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],g=e[13],v=e[14],m=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,k=i*c-a*l,T=u*g-h*d,A=u*v-f*d,M=u*m-p*d,S=h*v-f*g,E=h*m-p*g,C=f*m-p*v,L=y*C-x*E+b*S+_*M-w*A+k*T;if(!L)return null;return L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(i*E-n*C-a*S)*L,t[2]=(g*k-v*w+m*_)*L,t[3]=(f*w-h*k-p*_)*L,t[4]=(l*M-o*C-c*A)*L,t[5]=(r*C-i*M+a*A)*L,t[6]=(v*b-d*k-m*x)*L,t[7]=(u*k-f*b+p*x)*L,t[8]=(o*E-s*M+c*T)*L,t[9]=(n*M-r*E-a*T)*L,t[10]=(d*w-g*b+m*y)*L,t[11]=(h*b-u*w-p*y)*L,t[12]=(s*A-o*S-l*T)*L,t[13]=(r*S-n*A+i*T)*L,t[14]=(g*x-d*_-v*y)*L,t[15]=(u*_-h*x+f*y)*L,t}},{}],266:[function(t,e,r){var n=t(\"./identity\");e.exports=function(t,e,r,i){var a,o,s,l,c,u,h,f,p,d,g=e[0],v=e[1],m=e[2],y=i[0],x=i[1],b=i[2],_=r[0],w=r[1],k=r[2];if(Math.abs(g-_)<1e-6&&Math.abs(v-w)<1e-6&&Math.abs(m-k)<1e-6)return n(t);h=g-_,f=v-w,p=m-k,d=1/Math.sqrt(h*h+f*f+p*p),a=x*(p*=d)-b*(f*=d),o=b*(h*=d)-y*p,s=y*f-x*h,(d=Math.sqrt(a*a+o*o+s*s))?(a*=d=1/d,o*=d,s*=d):(a=0,o=0,s=0);l=f*s-p*o,c=p*a-h*s,u=h*o-f*a,(d=Math.sqrt(l*l+c*c+u*u))?(l*=d=1/d,c*=d,u*=d):(l=0,c=0,u=0);return t[0]=a,t[1]=l,t[2]=h,t[3]=0,t[4]=o,t[5]=c,t[6]=f,t[7]=0,t[8]=s,t[9]=u,t[10]=p,t[11]=0,t[12]=-(a*g+o*v+s*m),t[13]=-(l*g+c*v+u*m),t[14]=-(h*g+f*v+p*m),t[15]=1,t}},{\"./identity\":264}],267:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],g=e[12],v=e[13],m=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*h+w*g,t[1]=x*i+b*l+_*f+w*v,t[2]=x*a+b*c+_*p+w*m,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*h+w*g,t[5]=x*i+b*l+_*f+w*v,t[6]=x*a+b*c+_*p+w*m,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*h+w*g,t[9]=x*i+b*l+_*f+w*v,t[10]=x*a+b*c+_*p+w*m,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*h+w*g,t[13]=x*i+b*l+_*f+w*v,t[14]=x*a+b*c+_*p+w*m,t[15]=x*o+b*u+_*d+w*y,t}},{}],268:[function(t,e,r){e.exports=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t}},{}],269:[function(t,e,r){e.exports=function(t,e,r,n,i){var a=1/Math.tan(e/2),o=1/(n-i);return t[0]=a/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=a,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=(i+n)*o,t[11]=-1,t[12]=0,t[13]=0,t[14]=2*i*n*o,t[15]=0,t}},{}],270:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_,w,k,T,A,M,S,E=n[0],C=n[1],L=n[2],P=Math.sqrt(E*E+C*C+L*L);if(Math.abs(P)<1e-6)return null;E*=P=1/P,C*=P,L*=P,i=Math.sin(r),a=Math.cos(r),o=1-a,s=e[0],l=e[1],c=e[2],u=e[3],h=e[4],f=e[5],p=e[6],d=e[7],g=e[8],v=e[9],m=e[10],y=e[11],x=E*E*o+a,b=C*E*o+L*i,_=L*E*o-C*i,w=E*C*o-L*i,k=C*C*o+a,T=L*C*o+E*i,A=E*L*o+C*i,M=C*L*o-E*i,S=L*L*o+a,t[0]=s*x+h*b+g*_,t[1]=l*x+f*b+v*_,t[2]=c*x+p*b+m*_,t[3]=u*x+d*b+y*_,t[4]=s*w+h*k+g*T,t[5]=l*w+f*k+v*T,t[6]=c*w+p*k+m*T,t[7]=u*w+d*k+y*T,t[8]=s*A+h*M+g*S,t[9]=l*A+f*M+v*S,t[10]=c*A+p*M+m*S,t[11]=u*A+d*M+y*S,e!==t&&(t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t}},{}],271:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+h*n,t[7]=l*i+f*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=h*i-s*n,t[11]=f*i-l*n,t}},{}],272:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[8],u=e[9],h=e[10],f=e[11];e!==t&&(t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i-c*n,t[1]=o*i-u*n,t[2]=s*i-h*n,t[3]=l*i-f*n,t[8]=a*n+c*i,t[9]=o*n+u*i,t[10]=s*n+h*i,t[11]=l*n+f*i,t}},{}],273:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+h*n,t[3]=l*i+f*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=h*i-s*n,t[7]=f*i-l*n,t}},{}],274:[function(t,e,r){e.exports=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},{}],275:[function(t,e,r){e.exports=function(t,e,r){var n,i,a,o,s,l,c,u,h,f,p,d,g=r[0],v=r[1],m=r[2];e===t?(t[12]=e[0]*g+e[4]*v+e[8]*m+e[12],t[13]=e[1]*g+e[5]*v+e[9]*m+e[13],t[14]=e[2]*g+e[6]*v+e[10]*m+e[14],t[15]=e[3]*g+e[7]*v+e[11]*m+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*g+s*v+h*m+e[12],t[13]=i*g+l*v+f*m+e[13],t[14]=a*g+c*v+p*m+e[14],t[15]=o*g+u*v+d*m+e[15]);return t}},{}],276:[function(t,e,r){e.exports=function(t,e){if(t===e){var r=e[1],n=e[2],i=e[3],a=e[6],o=e[7],s=e[11];t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=r,t[6]=e[9],t[7]=e[13],t[8]=n,t[9]=a,t[11]=e[14],t[12]=i,t[13]=o,t[14]=s}else t[0]=e[0],t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=e[1],t[5]=e[5],t[6]=e[9],t[7]=e[13],t[8]=e[2],t[9]=e[6],t[10]=e[10],t[11]=e[14],t[12]=e[3],t[13]=e[7],t[14]=e[11],t[15]=e[15];return t}},{}],277:[function(t,e,r){\"use strict\";e.exports=function(t,e){switch(e.length){case 0:break;case 1:t[0]=1/e[0];break;case 4:n(t,e);break;case 9:i(t,e);break;case 16:a(t,e);break;default:throw new Error(\"currently supports matrices up to 4x4\")}return t};var n=t(\"gl-mat2/invert\"),i=t(\"gl-mat3/invert\"),a=t(\"gl-mat4/invert\")},{\"gl-mat2/invert\":257,\"gl-mat3/invert\":258,\"gl-mat4/invert\":265}],278:[function(t,e,r){\"use strict\";var n=t(\"barycentric\"),i=t(\"polytope-closest-point/lib/closest_point_2d.js\");function a(t,e){for(var r=[0,0,0,0],n=0;n<4;++n)for(var i=0;i<4;++i)r[i]+=t[4*n+i]*e[n];return r}function o(t,e,r,n,i){for(var o=a(n,a(r,a(e,[t[0],t[1],t[2],1]))),s=0;s<3;++s)o[s]/=o[3];return[.5*i[0]*(1+o[0]),.5*i[1]*(1-o[1])]}e.exports=function(t,e,r,a,s,l){if(1===t.length)return[0,t[0].slice()];for(var c=new Array(t.length),u=0;u<t.length;++u)c[u]=o(t[u],r,a,s,l);for(var h=0,f=1/0,u=0;u<c.length;++u){for(var p=0,d=0;d<2;++d)p+=Math.pow(c[u][d]-e[d],2);p<f&&(f=p,h=u)}for(var g=function(t,e){if(2===t.length){for(var r=0,a=0,o=0;o<2;++o)r+=Math.pow(e[o]-t[0][o],2),a+=Math.pow(e[o]-t[1][o],2);return r=Math.sqrt(r),a=Math.sqrt(a),r+a<1e-6?[1,0]:[a/(r+a),r/(a+r)]}if(3===t.length){var s=[0,0];return i(t[0],t[1],t[2],e,s),n(t,s)}return[]}(c,e),v=0,u=0;u<3;++u){if(g[u]<-.001||g[u]>1.0001)return null;v+=g[u]}if(Math.abs(v-1)>.001)return null;return[h,function(t,e){for(var r=[0,0,0],n=0;n<t.length;++n)for(var i=t[n],a=e[n],o=0;o<3;++o)r[o]+=a*i[o];return r}(t,g),g]}},{barycentric:73,\"polytope-closest-point/lib/closest_point_2d.js\":481}],279:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, normal;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  gl_Position      = project(position);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * vec4(position , 1.0);\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal  = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  f_color          = color;\\n  f_data           = position;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\n//#pragma glslify: beckmann = require(glsl-specular-beckmann) // used in gl-surface3d\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (f_color.a == 0.0 ||\\n    outOfRange(clipBounds[0], clipBounds[1], f_data)\\n  ) discard;\\n\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  //float specular = max(0.0, beckmann(L, V, N, roughness)); // used in gl-surface3d\\n\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = vec4(f_color.rgb, 1.0) * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * f_color.a;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_color = color;\\n  f_data  = position;\\n  f_uv    = uv;\\n}\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_data)) discard;\\n\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\nattribute float pointSize;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0 ,0.0 ,0.0);\\n  } else {\\n    gl_Position = projection * view * model * vec4(position, 1.0);\\n  }\\n  gl_PointSize = pointSize;\\n  f_color = color;\\n  f_uv = uv;\\n}\"]),c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  vec2 pointR = gl_PointCoord.xy - vec2(0.5, 0.5);\\n  if(dot(pointR, pointR) > 0.25) {\\n    discard;\\n  }\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_id        = id;\\n  f_position  = position;\\n}\"]),h=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]),f=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3  position;\\nattribute float pointSize;\\nattribute vec4  id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0, 0.0, 0.0);\\n  } else {\\n    gl_Position  = projection * view * model * vec4(position, 1.0);\\n    gl_PointSize = pointSize;\\n  }\\n  f_id         = id;\\n  f_position   = position;\\n}\"]),p=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n}\"]),d=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec3 contourColor;\\n\\nvoid main() {\\n  gl_FragColor = vec4(contourColor, 1.0);\\n}\\n\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.wireShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.pointShader={vertex:l,fragment:c,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"pointSize\",type:\"float\"}]},r.pickShader={vertex:u,fragment:h,attributes:[{name:\"position\",type:\"vec3\"},{name:\"id\",type:\"vec4\"}]},r.pointPickShader={vertex:f,fragment:h,attributes:[{name:\"position\",type:\"vec3\"},{name:\"pointSize\",type:\"float\"},{name:\"id\",type:\"vec4\"}]},r.contourShader={vertex:p,fragment:d,attributes:[{name:\"position\",type:\"vec3\"}]}},{glslify:409}],280:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./lib/shaders\"),g=t(\"./lib/closest-point\"),v=d.meshShader,m=d.wireShader,y=d.pointShader,x=d.pickShader,b=d.pointPickShader,_=d.contourShader,w=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function k(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_,k,T,A,M,S){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.lineShader=n,this.pointShader=i,this.pickShader=a,this.pointPickShader=o,this.contourShader=s,this.trianglePositions=l,this.triangleColors=u,this.triangleNormals=f,this.triangleUVs=h,this.triangleIds=c,this.triangleVAO=p,this.triangleCount=0,this.lineWidth=1,this.edgePositions=d,this.edgeColors=v,this.edgeUVs=m,this.edgeIds=g,this.edgeVAO=y,this.edgeCount=0,this.pointPositions=x,this.pointColors=_,this.pointUVs=k,this.pointSizes=T,this.pointIds=b,this.pointVAO=A,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=M,this.contourVAO=S,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.hasAlpha=!1,this.opacityscale=!1,this._model=w,this._view=w,this._projection=w,this._resolution=[1,1]}var T=k.prototype;function A(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}function M(t){var e=n(t,y.vertex,y.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.pointSize.location=4,e}function S(t){var e=n(t,x.vertex,x.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e}function E(t){var e=n(t,b.vertex,b.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.pointSize.location=4,e}function C(t){var e=n(t,_.vertex,_.fragment);return e.attributes.position.location=0,e}T.isOpaque=function(){return!this.hasAlpha},T.isTransparent=function(){return this.hasAlpha},T.pickSlots=1,T.setPickBase=function(t){this.pickId=t},T.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=i[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},T.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=t.opacity,this.opacity<1&&(this.hasAlpha=!0)),\"opacityscale\"in t&&(this.opacityscale=t.opacityscale,this.hasAlpha=!0),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t,e){for(var r=h({colormap:t,nshades:256,format:\"rgba\"}),n=new Uint8Array(1024),i=0;i<256;++i){for(var a=r[i],o=0;o<3;++o)n[4*i+o]=a[o];n[4*i+3]=e?255*A(i/255,e):255*a[3]}return u(n,[256,256,4],[4,0,1])}(t.colormap,this.opacityscale)),this.texture.generateMipmap());var r=t.cells,n=t.positions;if(n&&r){var i=[],a=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[];this.cells=r,this.positions=n;var w=t.vertexNormals,k=t.cellNormals,T=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,M=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!k&&(k=s.faceNormals(r,n,M)),k||w||(w=s.vertexNormals(r,n,T));var S=t.vertexColors,E=t.cellColors,C=t.meshColor||[1,1,1,1],L=t.vertexUVs,P=t.vertexIntensity,O=t.cellUVs,z=t.cellIntensity,I=1/0,D=-1/0;if(!L&&!O)if(P)if(t.vertexIntensityBounds)I=+t.vertexIntensityBounds[0],D=+t.vertexIntensityBounds[1];else for(var R=0;R<P.length;++R){var F=P[R];I=Math.min(I,F),D=Math.max(D,F)}else if(z)for(R=0;R<z.length;++R){F=z[R];I=Math.min(I,F),D=Math.max(D,F)}else for(R=0;R<n.length;++R){F=n[R][2];I=Math.min(I,F),D=Math.max(D,F)}this.intensity=P||(z?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,z):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var B=t.pointSizes,N=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(R=0;R<n.length;++R)for(var j=n[R],U=0;U<3;++U)!isNaN(j[U])&&isFinite(j[U])&&(this.bounds[0][U]=Math.min(this.bounds[0][U],j[U]),this.bounds[1][U]=Math.max(this.bounds[1][U],j[U]));var V=0,q=0,H=0;t:for(R=0;R<r.length;++R){var G=r[R];switch(G.length){case 1:for(j=n[W=G[0]],U=0;U<3;++U)if(isNaN(j[U])||!isFinite(j[U]))continue t;m.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?y.push(X[0],X[1],X[2],this.opacity):(y.push(X[0],X[1],X[2],X[3]*this.opacity),!this.hasAlpha&&X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],x.push(Z[0],Z[1]),B?b.push(B[W]):b.push(N),_.push(R),H+=1;break;case 2:for(U=0;U<2;++U){j=n[W=G[U]];for(var Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t}for(U=0;U<2;++U){j=n[W=G[U]];p.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?d.push(X[0],X[1],X[2],this.opacity):(d.push(X[0],X[1],X[2],X[3]*this.opacity),!this.hasAlpha&&X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],g.push(Z[0],Z[1]),v.push(R)}q+=1;break;case 3:for(U=0;U<3;++U)for(j=n[W=G[U]],Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t;for(U=0;U<3;++U){var W,X,Z,J;j=n[W=G[2-U]];i.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?a.push(X[0],X[1],X[2],this.opacity):(a.push(X[0],X[1],X[2],X[3]*this.opacity),!this.hasAlpha&&X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],c.push(Z[0],Z[1]),J=w?w[W]:k[R],l.push(J[0],J[1],J[2]),f.push(R)}V+=1}}this.pointCount=H,this.edgeCount=q,this.triangleCount=V,this.pointPositions.update(m),this.pointColors.update(y),this.pointUVs.update(x),this.pointSizes.update(b),this.pointIds.update(new Uint32Array(_)),this.edgePositions.update(p),this.edgeColors.update(d),this.edgeUVs.update(g),this.edgeIds.update(new Uint32Array(v)),this.trianglePositions.update(i),this.triangleColors.update(a),this.triangleUVs.update(c),this.triangleNormals.update(l),this.triangleIds.update(new Uint32Array(f))}},T.drawTransparent=T.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:w.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h,f=u[15];for(o=0;o<3;++o)f+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];s.lightPosition[o]=p/f}this.triangleCount>0&&((h=this.triShader).bind(),h.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind());this.edgeCount>0&&this.lineWidth>0&&((h=this.lineShader).bind(),h.uniforms=s,this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind());this.pointCount>0&&((h=this.pointShader).bind(),h.uniforms=s,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind());this.contourEnable&&this.contourCount>0&&this.contourLineWidth>0&&((h=this.contourShader).bind(),h.uniforms=s,this.contourVAO.bind(),e.drawArrays(e.LINES,0,this.contourCount),this.contourVAO.unbind())},T.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s,l={model:r,view:n,projection:i,clipBounds:a,pickId:this.pickId/255};((s=this.pickShader).bind(),s.uniforms=l,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind()),this.pointCount>0)&&((s=this.pointPickShader).bind(),s.uniforms=l,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind())},T.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;for(var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions,i=new Array(r.length),a=0;a<r.length;++a)i[a]=n[r[a]];var o=g(i,[t.coord[0],this._resolution[1]-t.coord[1]],this._model,this._view,this._projection,this._resolution);if(!o)return null;var s=o[2],l=0;for(a=0;a<r.length;++a)l+=s[a]*this.intensity[r[a]];return{position:o[1],index:r[o[0]],cell:r,cellId:e,intensity:l,dataCoordinate:this.positions[r[o[0]]]}},T.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.lineShader.dispose(),this.pointShader.dispose(),this.pickShader.dispose(),this.pointPickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose(),this.contourShader.dispose()},e.exports=function(t,e){if(1===arguments.length&&(t=(e=t).gl),!(t.getExtension(\"OES_standard_derivatives\")||t.getExtension(\"MOZ_OES_standard_derivatives\")||t.getExtension(\"WEBKIT_OES_standard_derivatives\")))throw new Error(\"derivatives not supported\");var r=function(t){var e=n(t,v.vertex,v.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.normal.location=4,e}(t),s=function(t){var e=n(t,m.vertex,m.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e}(t),l=M(t),c=S(t),h=E(t),f=C(t),p=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));p.generateMipmap(),p.minFilter=t.LINEAR_MIPMAP_LINEAR,p.magFilter=t.LINEAR;var d=i(t),g=i(t),y=i(t),x=i(t),b=i(t),_=a(t,[{buffer:d,type:t.FLOAT,size:3},{buffer:b,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:g,type:t.FLOAT,size:4},{buffer:y,type:t.FLOAT,size:2},{buffer:x,type:t.FLOAT,size:3}]),w=i(t),T=i(t),A=i(t),L=i(t),P=a(t,[{buffer:w,type:t.FLOAT,size:3},{buffer:L,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:T,type:t.FLOAT,size:4},{buffer:A,type:t.FLOAT,size:2}]),O=i(t),z=i(t),I=i(t),D=i(t),R=i(t),F=a(t,[{buffer:O,type:t.FLOAT,size:3},{buffer:R,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:z,type:t.FLOAT,size:4},{buffer:I,type:t.FLOAT,size:2},{buffer:D,type:t.FLOAT,size:1}]),B=i(t),N=new k(t,p,r,s,l,c,h,f,d,b,g,y,x,_,w,L,T,A,P,O,R,z,I,D,F,B,a(t,[{buffer:B,type:t.FLOAT,size:3}]));return N.update(e),N}},{\"./lib/closest-point\":278,\"./lib/shaders\":279,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-shader\":301,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,normals:453,\"simplicial-complex-contour\":518,\"typedarray-pool\":545}],281:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[0,0,0,1,1,0,1,1]),s=i(e,a.boxVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawBox=(s=[0,0],l=[0,0],function(t,e,r,n,i){var a=this.plot,o=this.shader,c=a.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,o.uniforms.lo=s,o.uniforms.hi=l,o.uniforms.color=i,c.drawArrays(c.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":284,\"gl-buffer\":241,\"gl-shader\":301}],282:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,o.gridVert,o.gridFrag),l=i(e,o.tickVert,o.gridFrag);return new s(t,r,a,l)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"binary-search-bounds\"),o=t(\"./shaders\");function s(t,e,r,n){this.plot=t,this.vbo=e,this.shader=r,this.tickShader=n,this.ticks=[[],[]]}function l(t,e){return t-e}var c,u,h,f,p,d=s.prototype;d.draw=(c=[0,0],u=[0,0],h=[0,0],function(){for(var t=this.plot,e=this.vbo,r=this.shader,n=this.ticks,i=t.gl,a=t._tickBounds,o=t.dataBox,s=t.viewBox,l=t.gridLineWidth,f=t.gridLineColor,p=t.gridLineEnable,d=t.pixelRatio,g=0;g<2;++g){var v=a[g],m=a[g+2]-v,y=.5*(o[g+2]+o[g]),x=o[g+2]-o[g];u[g]=2*m/x,c[g]=2*(v-y)/x}r.bind(),e.bind(),r.attributes.dataCoord.pointer(),r.uniforms.dataShift=c,r.uniforms.dataScale=u;var b=0;for(g=0;g<2;++g){h[0]=h[1]=0,h[g]=1,r.uniforms.dataAxis=h,r.uniforms.lineWidth=l[g]/(s[g+2]-s[g])*d,r.uniforms.color=f[g];var _=6*n[g].length;p[g]&&_&&i.drawArrays(i.TRIANGLES,b,_),b+=_}}),d.drawTickMarks=function(){var t=[0,0],e=[0,0],r=[1,0],n=[0,1],i=[0,0],o=[0,0];return function(){for(var s=this.plot,c=this.vbo,u=this.tickShader,h=this.ticks,f=s.gl,p=s._tickBounds,d=s.dataBox,g=s.viewBox,v=s.pixelRatio,m=s.screenBox,y=m[2]-m[0],x=m[3]-m[1],b=g[2]-g[0],_=g[3]-g[1],w=0;w<2;++w){var k=p[w],T=p[w+2]-k,A=.5*(d[w+2]+d[w]),M=d[w+2]-d[w];e[w]=2*T/M,t[w]=2*(k-A)/M}e[0]*=b/y,t[0]*=b/y,e[1]*=_/x,t[1]*=_/x,u.bind(),c.bind(),u.attributes.dataCoord.pointer();var S=u.uniforms;S.dataShift=t,S.dataScale=e;var E=s.tickMarkLength,C=s.tickMarkWidth,L=s.tickMarkColor,P=6*h[0].length,O=Math.min(a.ge(h[0],(d[0]-p[0])/(p[2]-p[0]),l),h[0].length),z=Math.min(a.gt(h[0],(d[2]-p[0])/(p[2]-p[0]),l),h[0].length),I=0+6*O,D=6*Math.max(0,z-O),R=Math.min(a.ge(h[1],(d[1]-p[1])/(p[3]-p[1]),l),h[1].length),F=Math.min(a.gt(h[1],(d[3]-p[1])/(p[3]-p[1]),l),h[1].length),B=P+6*R,N=6*Math.max(0,F-R);i[0]=2*(g[0]-E[1])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=E[1]*v/y,o[1]=C[1]*v/x,N&&(S.color=L[1],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,f.drawArrays(f.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[1]-E[0])/x-1,o[0]=C[0]*v/y,o[1]=E[0]*v/x,D&&(S.color=L[0],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,f.drawArrays(f.TRIANGLES,I,D)),i[0]=2*(g[2]+E[3])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=E[3]*v/y,o[1]=C[3]*v/x,N&&(S.color=L[3],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,f.drawArrays(f.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[3]+E[2])/x-1,o[0]=C[2]*v/y,o[1]=E[2]*v/x,D&&(S.color=L[2],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,f.drawArrays(f.TRIANGLES,I,D))}}(),d.update=(f=[1,1,-1,-1,1,-1],p=[1,-1,1,1,-1,-1],function(t){for(var e=t.ticks,r=t.bounds,n=new Float32Array(18*(e[0].length+e[1].length)),i=(this.plot.zeroLineEnable,0),a=[[],[]],o=0;o<2;++o)for(var s=a[o],l=e[o],c=r[o],u=r[o+2],h=0;h<l.length;++h){var d=(l[h].x-c)/(u-c);s.push(d);for(var g=0;g<6;++g)n[i++]=d,n[i++]=f[g],n[i++]=p[g]}this.ticks=a,this.vbo.update(n)}),d.dispose=function(){this.vbo.dispose(),this.shader.dispose(),this.tickShader.dispose()}},{\"./shaders\":284,\"binary-search-bounds\":286,\"gl-buffer\":241,\"gl-shader\":301}],283:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[-1,-1,-1,1,1,-1,1,1]),s=i(e,a.lineVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawLine=(s=[0,0],l=[0,0],function(t,e,r,n,i,a){var o=this.plot,c=this.shader,u=o.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,c.uniforms.start=s,c.uniforms.end=l,c.uniforms.width=i*o.pixelRatio,c.uniforms.color=a,u.drawArrays(u.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":284,\"gl-buffer\":241,\"gl-shader\":301}],284:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision lowp float;\\n#define GLSLIFY 1\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = vec4(color.xyz * color.w, color.w);\\n}\\n\"]);e.exports={lineVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 start, end;\\nuniform float width;\\n\\nvec2 perp(vec2 v) {\\n  return vec2(v.y, -v.x);\\n}\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  vec2 delta = normalize(perp(start - end));\\n  vec2 offset = mix(start, end, 0.5 * (coord.y+1.0));\\n  gl_Position = vec4(screen(offset + 0.5 * width * delta * coord.x), 0, 1);\\n}\\n\"]),lineFrag:i,textVert:n([\"#define GLSLIFY 1\\nattribute vec3 textCoordinate;\\n\\nuniform vec2 dataScale, dataShift, dataAxis, screenOffset, textScale;\\nuniform float angle;\\n\\nvoid main() {\\n  float dataOffset  = textCoordinate.z;\\n  vec2 glyphOffset  = textCoordinate.xy;\\n  mat2 glyphMatrix = mat2(cos(angle), sin(angle), -sin(angle), cos(angle));\\n  vec2 screenCoordinate = dataAxis * (dataScale * dataOffset + dataShift) +\\n    glyphMatrix * glyphOffset * textScale + screenOffset;\\n  gl_Position = vec4(screenCoordinate, 0, 1);\\n}\\n\"]),textFrag:i,gridVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale;\\nuniform float lineWidth;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  pos += 10.0 * dataCoord.y * vec2(dataAxis.y, -dataAxis.x) + dataCoord.z * lineWidth;\\n  gl_Position = vec4(pos, 0, 1);\\n}\\n\"]),gridFrag:i,boxVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 lo, hi;\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  gl_Position = vec4(screen(mix(lo, hi, coord)), 0, 1);\\n}\\n\"]),tickVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale, screenOffset, tickScale;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  gl_Position = vec4(pos + tickScale*dataCoord.yz + screenOffset, 0, 1);\\n}\\n\"])}},{glslify:409}],285:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,s.textVert,s.textFrag);return new l(t,r,a)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"text-cache\"),o=t(\"binary-search-bounds\"),s=t(\"./shaders\");function l(t,e,r){this.plot=t,this.vbo=e,this.shader=r,this.tickOffset=[[],[]],this.tickX=[[],[]],this.labelOffset=[0,0],this.labelCount=[0,0]}var c,u,h,f,p,d,g=l.prototype;g.drawTicks=(c=[0,0],u=[0,0],h=[0,0],function(t){var e=this.plot,r=this.shader,n=this.tickX[t],i=this.tickOffset[t],a=e.gl,s=e.viewBox,l=e.dataBox,f=e.screenBox,p=e.pixelRatio,d=e.tickEnable,g=e.tickPad,v=e.tickColor,m=e.tickAngle,y=e.labelEnable,x=e.labelPad,b=e.labelColor,_=e.labelAngle,w=this.labelOffset[t],k=this.labelCount[t],T=o.lt(n,l[t]),A=o.le(n,l[t+2]);c[0]=c[1]=0,c[t]=1,u[t]=(s[2+t]+s[t])/(f[2+t]-f[t])-1;var M=2/f[2+(1^t)]-f[1^t];u[1^t]=M*s[1^t]-1,d[t]&&(u[1^t]-=M*p*g[t],T<A&&i[A]>i[T]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=v[t],r.uniforms.angle=m[t],a.drawArrays(a.TRIANGLES,i[T],i[A]-i[T]))),y[t]&&k&&(u[1^t]-=M*p*x[t],r.uniforms.dataAxis=h,r.uniforms.screenOffset=u,r.uniforms.color=b[t],r.uniforms.angle=_[t],a.drawArrays(a.TRIANGLES,w,k)),u[1^t]=M*s[2+(1^t)]-1,d[t+2]&&(u[1^t]+=M*p*g[t+2],T<A&&i[A]>i[T]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=v[t+2],r.uniforms.angle=m[t+2],a.drawArrays(a.TRIANGLES,i[T],i[A]-i[T]))),y[t+2]&&k&&(u[1^t]+=M*p*x[t+2],r.uniforms.dataAxis=h,r.uniforms.screenOffset=u,r.uniforms.color=b[t+2],r.uniforms.angle=_[t+2],a.drawArrays(a.TRIANGLES,w,k))}),g.drawTitle=function(){var t=[0,0],e=[0,0];return function(){var r=this.plot,n=this.shader,i=r.gl,a=r.screenBox,o=r.titleCenter,s=r.titleAngle,l=r.titleColor,c=r.pixelRatio;if(this.titleCount){for(var u=0;u<2;++u)e[u]=2*(o[u]*c-a[u])/(a[2+u]-a[u])-1;n.bind(),n.uniforms.dataAxis=t,n.uniforms.screenOffset=e,n.uniforms.angle=s,n.uniforms.color=l,i.drawArrays(i.TRIANGLES,this.titleOffset,this.titleCount)}}}(),g.bind=(f=[0,0],p=[0,0],d=[0,0],function(){var t=this.plot,e=this.shader,r=t._tickBounds,n=t.dataBox,i=t.screenBox,a=t.viewBox;e.bind();for(var o=0;o<2;++o){var s=r[o],l=r[o+2]-s,c=.5*(n[o+2]+n[o]),u=n[o+2]-n[o],h=a[o],g=a[o+2]-h,v=i[o],m=i[o+2]-v;p[o]=2*l/u*g/m,f[o]=2*(s-c)/u*g/m}d[1]=2*t.pixelRatio/(i[3]-i[1]),d[0]=d[1]*(i[3]-i[1])/(i[2]-i[0]),e.uniforms.dataScale=p,e.uniforms.dataShift=f,e.uniforms.textScale=d,this.vbo.bind(),e.attributes.textCoordinate.pointer()}),g.update=function(t){var e,r,n,i,o,s=[],l=t.ticks,c=t.bounds;for(o=0;o<2;++o){var u=[Math.floor(s.length/3)],h=[-1/0],f=l[o];for(e=0;e<f.length;++e){var p=f[e],d=p.x,g=p.text,v=p.font||\"sans-serif\";i=p.fontSize||12;for(var m=1/(c[o+2]-c[o]),y=c[o],x=g.split(\"\\n\"),b=0;b<x.length;b++)for(n=a(v,x[b]).data,r=0;r<n.length;r+=2)s.push(n[r]*i,-n[r+1]*i-b*i*1.2,(d-y)*m);u.push(Math.floor(s.length/3)),h.push(d)}this.tickOffset[o]=u,this.tickX[o]=h}for(o=0;o<2;++o){for(this.labelOffset[o]=Math.floor(s.length/3),n=a(t.labelFont[o],t.labels[o],{textAlign:\"center\"}).data,i=t.labelSize[o],e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.labelCount[o]=Math.floor(s.length/3)-this.labelOffset[o]}for(this.titleOffset=Math.floor(s.length/3),n=a(t.titleFont,t.title).data,i=t.titleSize,e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.titleCount=Math.floor(s.length/3)-this.titleOffset,this.vbo.update(s)},g.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":284,\"binary-search-bounds\":286,\"gl-buffer\":241,\"gl-shader\":301,\"text-cache\":536}],286:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],287:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[e.drawingBufferWidth,e.drawingBufferHeight]),c=new l(e,r);return c.grid=i(c),c.text=a(c),c.line=o(c),c.box=s(c),c.update(t),c};var n=t(\"gl-select-static\"),i=t(\"./lib/grid\"),a=t(\"./lib/text\"),o=t(\"./lib/line\"),s=t(\"./lib/box\");function l(t,e){this.gl=t,this.pickBuffer=e,this.screenBox=[0,0,t.drawingBufferWidth,t.drawingBufferHeight],this.viewBox=[0,0,0,0],this.dataBox=[-10,-10,10,10],this.gridLineEnable=[!0,!0],this.gridLineWidth=[1,1],this.gridLineColor=[[0,0,0,1],[0,0,0,1]],this.pixelRatio=1,this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickEnable=[!0,!0,!0,!0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[15,15,15,15],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelEnable=[!0,!0,!0,!0],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.titleCenter=[0,0],this.titleEnable=!0,this.titleAngle=0,this.titleColor=[0,0,0,1],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[4,4],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderLineEnable=[!0,!0,!0,!0],this.borderLineWidth=[2,2,2,2],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.grid=null,this.text=null,this.line=null,this.box=null,this.objects=[],this.overlays=[],this._tickBounds=[1/0,1/0,-1/0,-1/0],this.static=!1,this.dirty=!1,this.pickDirty=!1,this.pickDelay=120,this.pickRadius=10,this._pickTimeout=null,this._drawPick=this.drawPick.bind(this),this._depthCounter=0}var c=l.prototype;function u(t){for(var e=t.slice(),r=0;r<e.length;++r)e[r]=e[r].slice();return e}function h(t,e){return t.x-e.x}c.setDirty=function(){this.dirty=this.pickDirty=!0},c.setOverlayDirty=function(){this.dirty=!0},c.nextDepthValue=function(){return this._depthCounter++/65536},c.draw=function(){var t=this.gl,e=this.screenBox,r=this.viewBox,n=this.dataBox,i=this.pixelRatio,a=this.grid,o=this.line,s=this.text,l=this.objects;if(this._depthCounter=0,this.pickDirty&&(this._pickTimeout&&clearTimeout(this._pickTimeout),this.pickDirty=!1,this._pickTimeout=setTimeout(this._drawPick,this.pickDelay)),this.dirty){if(this.dirty=!1,t.bindFramebuffer(t.FRAMEBUFFER,null),t.enable(t.SCISSOR_TEST),t.disable(t.DEPTH_TEST),t.depthFunc(t.LESS),t.depthMask(!1),t.enable(t.BLEND),t.blendEquation(t.FUNC_ADD,t.FUNC_ADD),t.blendFunc(t.ONE,t.ONE_MINUS_SRC_ALPHA),this.borderColor){t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]);var c=this.borderColor;t.clearColor(c[0]*c[3],c[1]*c[3],c[2]*c[3],c[3]),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT)}t.scissor(r[0],r[1],r[2]-r[0],r[3]-r[1]),t.viewport(r[0],r[1],r[2]-r[0],r[3]-r[1]);var u=this.backgroundColor;t.clearColor(u[0]*u[3],u[1]*u[3],u[2]*u[3],u[3]),t.clear(t.COLOR_BUFFER_BIT),a.draw();var h=this.zeroLineEnable,f=this.zeroLineColor,p=this.zeroLineWidth;if(h[0]||h[1]){o.bind();for(var d=0;d<2;++d)if(h[d]&&n[d]<=0&&n[d+2]>=0){var g=e[d]-n[d]*(e[d+2]-e[d])/(n[d+2]-n[d]);0===d?o.drawLine(g,e[1],g,e[3],p[d],f[d]):o.drawLine(e[0],g,e[2],g,p[d],f[d])}}for(d=0;d<l.length;++d)l[d].draw();t.viewport(e[0],e[1],e[2]-e[0],e[3]-e[1]),t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]),this.grid.drawTickMarks(),o.bind();var v=this.borderLineEnable,m=this.borderLineWidth,y=this.borderLineColor;for(v[1]&&o.drawLine(r[0],r[1]-.5*m[1]*i,r[0],r[3]+.5*m[3]*i,m[1],y[1]),v[0]&&o.drawLine(r[0]-.5*m[0]*i,r[1],r[2]+.5*m[2]*i,r[1],m[0],y[0]),v[3]&&o.drawLine(r[2],r[1]-.5*m[1]*i,r[2],r[3]+.5*m[3]*i,m[3],y[3]),v[2]&&o.drawLine(r[0]-.5*m[0]*i,r[3],r[2]+.5*m[2]*i,r[3],m[2],y[2]),s.bind(),d=0;d<2;++d)s.drawTicks(d);this.titleEnable&&s.drawTitle();var x=this.overlays;for(d=0;d<x.length;++d)x[d].draw();t.disable(t.SCISSOR_TEST),t.disable(t.BLEND),t.depthMask(!0)}},c.drawPick=function(){if(!this.static){var t=this.pickBuffer;this.gl;this._pickTimeout=null,t.begin();for(var e=1,r=this.objects,n=0;n<r.length;++n)e=r[n].drawPick(e);t.end()}},c.pick=function(t,e){if(!this.static){var r=this.pixelRatio,n=this.pickPixelRatio,i=this.viewBox,a=0|Math.round((t-i[0]/r)*n),o=0|Math.round((e-i[1]/r)*n),s=this.pickBuffer.query(a,o,this.pickRadius);if(!s)return null;for(var l=s.id+(s.value[0]<<8)+(s.value[1]<<16)+(s.value[2]<<24),c=this.objects,u=0;u<c.length;++u){var h=c[u].pick(a,o,l);if(h)return h}return null}},c.setScreenBox=function(t){var e=this.screenBox,r=this.pixelRatio;e[0]=0|Math.round(t[0]*r),e[1]=0|Math.round(t[1]*r),e[2]=0|Math.round(t[2]*r),e[3]=0|Math.round(t[3]*r),this.setDirty()},c.setDataBox=function(t){var e=this.dataBox;(e[0]!==t[0]||e[1]!==t[1]||e[2]!==t[2]||e[3]!==t[3])&&(e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],this.setDirty())},c.setViewBox=function(t){var e=this.pixelRatio,r=this.viewBox;r[0]=0|Math.round(t[0]*e),r[1]=0|Math.round(t[1]*e),r[2]=0|Math.round(t[2]*e),r[3]=0|Math.round(t[3]*e);var n=this.pickPixelRatio;this.pickBuffer.shape=[0|Math.round((t[2]-t[0])*n),0|Math.round((t[3]-t[1])*n)],this.setDirty()},c.update=function(t){t=t||{};var e=this.gl;this.pixelRatio=t.pixelRatio||1;var r=this.pixelRatio;this.pickPixelRatio=Math.max(r,1),this.setScreenBox(t.screenBox||[0,0,e.drawingBufferWidth/r,e.drawingBufferHeight/r]);this.screenBox;this.setViewBox(t.viewBox||[.125*(this.screenBox[2]-this.screenBox[0])/r,.125*(this.screenBox[3]-this.screenBox[1])/r,.875*(this.screenBox[2]-this.screenBox[0])/r,.875*(this.screenBox[3]-this.screenBox[1])/r]);var n=this.viewBox,i=(n[2]-n[0])/(n[3]-n[1]);this.setDataBox(t.dataBox||[-10,-10/i,10,10/i]),this.borderColor=!1!==t.borderColor&&(t.borderColor||[0,0,0,0]).slice(),this.backgroundColor=(t.backgroundColor||[0,0,0,0]).slice(),this.gridLineEnable=(t.gridLineEnable||[!0,!0]).slice(),this.gridLineWidth=(t.gridLineWidth||[1,1]).slice(),this.gridLineColor=u(t.gridLineColor||[[.5,.5,.5,1],[.5,.5,.5,1]]),this.zeroLineEnable=(t.zeroLineEnable||[!0,!0]).slice(),this.zeroLineWidth=(t.zeroLineWidth||[4,4]).slice(),this.zeroLineColor=u(t.zeroLineColor||[[0,0,0,1],[0,0,0,1]]),this.tickMarkLength=(t.tickMarkLength||[0,0,0,0]).slice(),this.tickMarkWidth=(t.tickMarkWidth||[0,0,0,0]).slice(),this.tickMarkColor=u(t.tickMarkColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.titleCenter=(t.titleCenter||[.5*(n[0]+n[2])/r,(n[3]+120)/r]).slice(),this.titleEnable=!(\"titleEnable\"in t&&!t.titleEnable),this.titleAngle=t.titleAngle||0,this.titleColor=(t.titleColor||[0,0,0,1]).slice(),this.labelPad=(t.labelPad||[15,15,15,15]).slice(),this.labelAngle=(t.labelAngle||[0,Math.PI/2,0,3*Math.PI/2]).slice(),this.labelEnable=(t.labelEnable||[!0,!0,!0,!0]).slice(),this.labelColor=u(t.labelColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.tickPad=(t.tickPad||[15,15,15,15]).slice(),this.tickAngle=(t.tickAngle||[0,0,0,0]).slice(),this.tickEnable=(t.tickEnable||[!0,!0,!0,!0]).slice(),this.tickColor=u(t.tickColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.borderLineEnable=(t.borderLineEnable||[!0,!0,!0,!0]).slice(),this.borderLineWidth=(t.borderLineWidth||[2,2,2,2]).slice(),this.borderLineColor=u(t.borderLineColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]);var a=t.ticks||[[],[]],o=this._tickBounds;o[0]=o[1]=1/0,o[2]=o[3]=-1/0;for(var s=0;s<2;++s){var l=a[s].slice(0);0!==l.length&&(l.sort(h),o[s]=Math.min(o[s],l[0].x),o[s+2]=Math.max(o[s+2],l[l.length-1].x))}this.grid.update({bounds:o,ticks:a}),this.text.update({bounds:o,ticks:a,labels:t.labels||[\"x\",\"y\"],labelSize:t.labelSize||[12,12],labelFont:t.labelFont||[\"sans-serif\",\"sans-serif\"],title:t.title||\"\",titleSize:t.titleSize||18,titleFont:t.titleFont||\"sans-serif\"}),this.static=!!t.static,this.setDirty()},c.dispose=function(){this.box.dispose(),this.grid.dispose(),this.text.dispose(),this.line.dispose();for(var t=this.objects.length-1;t>=0;--t)this.objects[t].dispose();this.objects.length=0;for(t=this.overlays.length-1;t>=0;--t)this.overlays[t].dispose();this.overlays.length=0,this.gl=null},c.addObject=function(t){this.objects.indexOf(t)<0&&(this.objects.push(t),this.setDirty())},c.removeObject=function(t){for(var e=this.objects,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setDirty();break}},c.addOverlay=function(t){this.overlays.indexOf(t)<0&&(this.overlays.push(t),this.setOverlayDirty())},c.removeOverlay=function(t){for(var e=this.overlays,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setOverlayDirty();break}}},{\"./lib/box\":281,\"./lib/grid\":282,\"./lib/line\":283,\"./lib/text\":285,\"gl-select-static\":300}],288:[function(t,e,r){\"use strict\";e.exports=function(t,e){t=t||document.body,e=e||{};var r=[.01,1/0];\"distanceLimits\"in e&&(r[0]=e.distanceLimits[0],r[1]=e.distanceLimits[1]);\"zoomMin\"in e&&(r[0]=e.zoomMin);\"zoomMax\"in e&&(r[1]=e.zoomMax);var c=i({center:e.center||[0,0,0],up:e.up||[0,1,0],eye:e.eye||[0,0,10],mode:e.mode||\"orbit\",distanceLimits:r}),u=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],h=0,f=t.clientWidth,p=t.clientHeight,d={keyBindingMode:\"rotate\",enableWheel:!0,view:c,element:t,delay:e.delay||16,rotateSpeed:e.rotateSpeed||1,zoomSpeed:e.zoomSpeed||1,translateSpeed:e.translateSpeed||1,flipX:!!e.flipX,flipY:!!e.flipY,modes:c.modes,_ortho:e._ortho||e.projection&&\"orthographic\"===e.projection.type||!1,tick:function(){var e=n(),r=this.delay,i=e-2*r;c.idle(e-r),c.recalcMatrix(i),c.flush(e-(100+2*r));for(var a=!0,o=c.computedMatrix,s=0;s<16;++s)a=a&&u[s]===o[s],u[s]=o[s];var l=t.clientWidth===f&&t.clientHeight===p;return f=t.clientWidth,p=t.clientHeight,a?!l:(h=Math.exp(c.computedRadius[0]),!0)},lookAt:function(t,e,r){c.lookAt(c.lastT(),t,e,r)},rotate:function(t,e,r){c.rotate(c.lastT(),t,e,r)},pan:function(t,e,r){c.pan(c.lastT(),t,e,r)},translate:function(t,e,r){c.translate(c.lastT(),t,e,r)}};return Object.defineProperties(d,{matrix:{get:function(){return c.computedMatrix},set:function(t){return c.setMatrix(c.lastT(),t),c.computedMatrix},enumerable:!0},mode:{get:function(){return c.getMode()},set:function(t){var e=c.computedUp.slice(),r=c.computedEye.slice(),i=c.computedCenter.slice();if(c.setMode(t),\"turntable\"===t){var a=n();c._active.lookAt(a,r,i,e),c._active.lookAt(a+500,r,i,[0,0,1]),c._active.flush(a)}return c.getMode()},enumerable:!0},center:{get:function(){return c.computedCenter},set:function(t){return c.lookAt(c.lastT(),null,t),c.computedCenter},enumerable:!0},eye:{get:function(){return c.computedEye},set:function(t){return c.lookAt(c.lastT(),t),c.computedEye},enumerable:!0},up:{get:function(){return c.computedUp},set:function(t){return c.lookAt(c.lastT(),null,null,t),c.computedUp},enumerable:!0},distance:{get:function(){return h},set:function(t){return c.setDistance(c.lastT(),t),t},enumerable:!0},distanceLimits:{get:function(){return c.getDistanceLimits(r)},set:function(t){return c.setDistanceLimits(t),t},enumerable:!0}}),t.addEventListener(\"contextmenu\",function(t){return t.preventDefault(),!1}),d._lastX=-1,d._lastY=-1,d._lastMods={shift:!1,control:!1,alt:!1,meta:!1},d.enableMouseListeners=function(){function e(e,r,i,a){var o=d.keyBindingMode;if(!1!==o){var s=\"rotate\"===o,l=\"pan\"===o,u=\"zoom\"===o,f=!!a.control,p=!!a.alt,g=!!a.shift,v=!!(1&e),m=!!(2&e),y=!!(4&e),x=1/t.clientHeight,b=x*(r-d._lastX),_=x*(i-d._lastY),w=d.flipX?1:-1,k=d.flipY?1:-1,T=Math.PI*d.rotateSpeed,A=n();if(-1!==d._lastX&&-1!==d._lastY&&((s&&v&&!f&&!p&&!g||v&&!f&&!p&&g)&&c.rotate(A,w*T*b,-k*T*_,0),(l&&v&&!f&&!p&&!g||m||v&&f&&!p&&!g)&&c.pan(A,-d.translateSpeed*b*h,d.translateSpeed*_*h,0),u&&v&&!f&&!p&&!g||y||v&&!f&&p&&!g)){var M=-d.zoomSpeed*_/window.innerHeight*(A-c.lastT())*100;c.pan(A,0,0,h*(Math.exp(M)-1))}return d._lastX=r,d._lastY=i,d._lastMods=a,!0}}d.mouseListener=a(t,e),t.addEventListener(\"touchstart\",function(r){var n=s(r.changedTouches[0],t);e(0,n[0],n[1],d._lastMods),e(1,n[0],n[1],d._lastMods),r.preventDefault()},!!l&&{passive:!1}),t.addEventListener(\"touchmove\",function(r){var n=s(r.changedTouches[0],t);e(1,n[0],n[1],d._lastMods),r.preventDefault()},!!l&&{passive:!1}),t.addEventListener(\"touchend\",function(t){e(0,d._lastX,d._lastY,d._lastMods),t.preventDefault()},!!l&&{passive:!1}),d.wheelListener=o(t,function(t,e){if(!1!==d.keyBindingMode&&d.enableWheel){var r=d.flipX?1:-1,i=d.flipY?1:-1,a=n();if(Math.abs(t)>Math.abs(e))c.rotate(a,0,0,-t*r*Math.PI*d.rotateSpeed/window.innerWidth);else if(!d._ortho){var o=-d.zoomSpeed*i*e/window.innerHeight*(a-c.lastT())/20;c.pan(a,0,0,h*(Math.exp(o)-1))}}},!0)},d.enableMouseListeners(),d};var n=t(\"right-now\"),i=t(\"3d-view\"),a=t(\"mouse-change\"),o=t(\"mouse-wheel\"),s=t(\"mouse-event-offset\"),l=t(\"has-passive-events\")},{\"3d-view\":52,\"has-passive-events\":411,\"mouse-change\":435,\"mouse-event-offset\":436,\"mouse-wheel\":438,\"right-now\":504}],289:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\nattribute vec2 position;\\nvarying vec2 uv;\\nvoid main() {\\n  uv = position;\\n  gl_Position = vec4(position, 0, 1);\\n}\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D accumBuffer;\\nvarying vec2 uv;\\n\\nvoid main() {\\n  vec4 accum = texture2D(accumBuffer, 0.5 * (uv + 1.0));\\n  gl_FragColor = min(vec4(1,1,1,1), accum);\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec2\"}])}},{\"gl-shader\":301,glslify:409}],290:[function(t,e,r){\"use strict\";var n=t(\"./camera.js\"),i=t(\"gl-axes3d\"),a=t(\"gl-axes3d/properties\"),o=t(\"gl-spikes3d\"),s=t(\"gl-select-static\"),l=t(\"gl-fbo\"),c=t(\"a-big-triangle\"),u=t(\"mouse-change\"),h=t(\"mouse-wheel\"),f=t(\"gl-mat4/perspective\"),p=t(\"gl-mat4/ortho\"),d=t(\"./lib/shader\"),g=t(\"is-mobile\")({tablet:!0});function v(){this.mouse=[-1,-1],this.screen=null,this.distance=1/0,this.index=null,this.dataCoordinate=null,this.dataPosition=null,this.object=null,this.data=null}function m(t){var e=Math.round(Math.log(Math.abs(t))/Math.log(10));if(e<0){var r=Math.round(Math.pow(10,-e));return Math.ceil(t*r)/r}if(e>0){r=Math.round(Math.pow(10,e));return Math.ceil(t/r)*r}return Math.ceil(t)}function y(t){return\"boolean\"!=typeof t||t}e.exports={createScene:function(t){(t=t||{}).camera=t.camera||{};var e=t.canvas;if(!e)if(e=document.createElement(\"canvas\"),t.container){var r=t.container;r.appendChild(e)}else document.body.appendChild(e);var x=t.gl;x||(x=function(t,e){var r=null;try{(r=t.getContext(\"webgl\",e))||(r=t.getContext(\"experimental-webgl\",e))}catch(t){return null}return r}(e,t.glOptions||{premultipliedAlpha:!0,antialias:!0,preserveDrawingBuffer:g}));if(!x)throw new Error(\"webgl not supported\");var b=t.bounds||[[-10,-10,-10],[10,10,10]],_=new v,w=l(x,[x.drawingBufferWidth,x.drawingBufferHeight],{preferFloat:!g}),k=d(x),T=t.cameraObject&&!0===t.cameraObject._ortho||t.camera.projection&&\"orthographic\"===t.camera.projection.type||!1,A={eye:t.camera.eye||[2,0,0],center:t.camera.center||[0,0,0],up:t.camera.up||[0,1,0],zoomMin:t.camera.zoomMax||.1,zoomMax:t.camera.zoomMin||100,mode:t.camera.mode||\"turntable\",_ortho:T},M=t.axes||{},S=i(x,M);S.enable=!M.disable;var E=t.spikes||{},C=o(x,E),L=[],P=[],O=[],z=[],I=!0,D=!0,R=new Array(16),F=new Array(16),B={view:null,projection:R,model:F,_ortho:!1},D=!0,N=[x.drawingBufferWidth,x.drawingBufferHeight],j=t.cameraObject||n(e,A),U={gl:x,contextLost:!1,pixelRatio:t.pixelRatio||1,canvas:e,selection:_,camera:j,axes:S,axesPixels:null,spikes:C,bounds:b,objects:L,shape:N,aspect:t.aspectRatio||[1,1,1],pickRadius:t.pickRadius||10,zNear:t.zNear||.01,zFar:t.zFar||1e3,fovy:t.fovy||Math.PI/4,clearColor:t.clearColor||[0,0,0,0],autoResize:y(t.autoResize),autoBounds:y(t.autoBounds),autoScale:!!t.autoScale,autoCenter:y(t.autoCenter),clipToBounds:y(t.clipToBounds),snapToData:!!t.snapToData,onselect:t.onselect||null,onrender:t.onrender||null,onclick:t.onclick||null,cameraParams:B,oncontextloss:null,mouseListener:null,_stopped:!1},V=[x.drawingBufferWidth/U.pixelRatio|0,x.drawingBufferHeight/U.pixelRatio|0];function q(){if(!U._stopped&&U.autoResize){var t=e.parentNode,r=1,n=1;t&&t!==document.body?(r=t.clientWidth,n=t.clientHeight):(r=window.innerWidth,n=window.innerHeight);var i=0|Math.ceil(r*U.pixelRatio),a=0|Math.ceil(n*U.pixelRatio);if(i!==e.width||a!==e.height){e.width=i,e.height=a;var o=e.style;o.position=o.position||\"absolute\",o.left=\"0px\",o.top=\"0px\",o.width=r+\"px\",o.height=n+\"px\",I=!0}}}U.autoResize&&q();function H(){for(var t=L.length,e=z.length,r=0;r<e;++r)O[r]=0;t:for(var r=0;r<t;++r){var n=L[r],i=n.pickSlots;if(i){for(var a=0;a<e;++a)if(O[a]+i<255){P[r]=a,n.setPickBase(O[a]+1),O[a]+=i;continue t}var o=s(x,N);P[r]=e,z.push(o),O.push(i),n.setPickBase(1),e+=1}else P[r]=-1}for(;e>0&&0===O[e-1];)O.pop(),z.pop().dispose()}function G(){if(U.contextLost)return!0;x.isContextLost()&&(U.contextLost=!0,U.mouseListener.enabled=!1,U.selection.object=null,U.oncontextloss&&U.oncontextloss())}window.addEventListener(\"resize\",q),U.update=function(t){U._stopped||(t=t||{},I=!0,D=!0)},U.add=function(t){U._stopped||(t.axes=S,L.push(t),P.push(-1),I=!0,D=!0,H())},U.remove=function(t){if(!U._stopped){var e=L.indexOf(t);e<0||(L.splice(e,1),P.pop(),I=!0,D=!0,H())}},U.dispose=function(){if(!U._stopped&&(U._stopped=!0,window.removeEventListener(\"resize\",q),e.removeEventListener(\"webglcontextlost\",G),U.mouseListener.enabled=!1,!U.contextLost)){S.dispose(),C.dispose();for(var t=0;t<L.length;++t)L[t].dispose();w.dispose();for(var t=0;t<z.length;++t)z[t].dispose();k.dispose(),x=null,S=null,C=null,L=[]}},U.wheelListener=h(e,function(t,e){if(!1!==j.keyBindingMode&&j.enableWheel&&j._ortho){var r=t>e?1.1:1/1.1;U.aspect[0]*=r,U.aspect[1]*=r,U.aspect[2]*=r,U.redraw()}},!0),U._mouseRotating=!1,U._prevButtons=0,U.enableMouseListeners=function(){U.mouseListener=u(e,function(t,e,r){if(!U._stopped){var n=z.length,i=L.length,a=_.object;_.distance=1/0,_.mouse[0]=e,_.mouse[1]=r,_.object=null,_.screen=null,_.dataCoordinate=_.dataPosition=null;var o=!1;if(t&&U._prevButtons)U._mouseRotating=!0;else{U._mouseRotating&&(D=!0),U._mouseRotating=!1;for(var s=0;s<n;++s){var l=z[s].query(e,V[1]-r-1,U.pickRadius);if(l){if(l.distance>_.distance)continue;for(var c=0;c<i;++c){var u=L[c];if(P[c]===s){var h=u.pick(l);h&&(_.buttons=t,_.screen=l.coord,_.distance=l.distance,_.object=u,_.index=h.distance,_.dataPosition=h.position,_.dataCoordinate=h.dataCoordinate,_.data=h,o=!0)}}}}}a&&a!==_.object&&(a.highlight&&a.highlight(null),I=!0),_.object&&(_.object.highlight&&_.object.highlight(_.data),I=!0),(o=o||_.object!==a)&&U.onselect&&U.onselect(_),1&t&&!(1&U._prevButtons)&&U.onclick&&U.onclick(_),U._prevButtons=t}})},e.addEventListener(\"webglcontextlost\",G);var Y=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],W=[Y[0].slice(),Y[1].slice()];function X(){if(!G()){q();var t=U.camera.tick();B.view=U.camera.matrix,I=I||t,D=D||t,S.pixelRatio=U.pixelRatio,C.pixelRatio=U.pixelRatio;var e=L.length,r=Y[0],n=Y[1];r[0]=r[1]=r[2]=1/0,n[0]=n[1]=n[2]=-1/0;for(var i=0;i<e;++i){var o=L[i];o.pixelRatio=U.pixelRatio,o.axes=U.axes,I=I||!!o.dirty,D=D||!!o.dirty;var s=o.bounds;if(s)for(var l=s[0],u=s[1],h=0;h<3;++h)r[h]=Math.min(r[h],l[h]),n[h]=Math.max(n[h],u[h])}var d=U.bounds;if(U.autoBounds)for(var h=0;h<3;++h){if(n[h]<r[h])r[h]=-1,n[h]=1;else{r[h]===n[h]&&(r[h]-=1,n[h]+=1);var g=.05*(n[h]-r[h]);r[h]=r[h]-g,n[h]=n[h]+g}d[0][h]=r[h],d[1][h]=n[h]}for(var v=!1,h=0;h<3;++h)v=v||W[0][h]!==d[0][h]||W[1][h]!==d[1][h],W[0][h]=d[0][h],W[1][h]=d[1][h];if(D=D||v,I=I||v){if(v){for(var y=[0,0,0],i=0;i<3;++i)y[i]=m((d[1][i]-d[0][i])/10);S.autoTicks?S.update({bounds:d,tickSpacing:y}):S.update({bounds:d})}var b=x.drawingBufferWidth,A=x.drawingBufferHeight;N[0]=b,N[1]=A,V[0]=0|Math.max(b/U.pixelRatio,1),V[1]=0|Math.max(A/U.pixelRatio,1),T?(p(R,-b/A,b/A,-1,1,U.zNear,U.zFar),B._ortho=!0):(f(R,U.fovy,b/A,U.zNear,U.zFar),B._ortho=!1);for(var i=0;i<16;++i)F[i]=0;F[15]=1;for(var M=0,i=0;i<3;++i)M=Math.max(M,d[1][i]-d[0][i]);for(var i=0;i<3;++i)U.autoScale?F[5*i]=U.aspect[i]/(d[1][i]-d[0][i]):F[5*i]=1/M,U.autoCenter&&(F[12+i]=.5*-F[5*i]*(d[0][i]+d[1][i]));for(var i=0;i<e;++i){var o=L[i];o.axesBounds=d,U.clipToBounds&&(o.clipBounds=d)}_.object&&(U.snapToData?C.position=_.dataCoordinate:C.position=_.dataPosition,C.bounds=d),D&&(D=!1,function(){if(G())return;x.colorMask(!0,!0,!0,!0),x.depthMask(!0),x.disable(x.BLEND),x.enable(x.DEPTH_TEST);for(var t=L.length,e=z.length,r=0;r<e;++r){var n=z[r];n.shape=V,n.begin();for(var i=0;i<t;++i)if(P[i]===r){var a=L[i];a.drawPick&&(a.pixelRatio=1,a.drawPick(B))}n.end()}}()),U.axesPixels=a(U.axes,B,b,A),U.onrender&&U.onrender(),x.bindFramebuffer(x.FRAMEBUFFER,null),x.viewport(0,0,b,A);var E=U.clearColor;x.clearColor(E[0],E[1],E[2],E[3]),x.clear(x.COLOR_BUFFER_BIT|x.DEPTH_BUFFER_BIT),x.depthMask(!0),x.colorMask(!0,!0,!0,!0),x.enable(x.DEPTH_TEST),x.depthFunc(x.LEQUAL),x.disable(x.BLEND),x.disable(x.CULL_FACE);var O=!1;S.enable&&(O=O||S.isTransparent(),S.draw(B)),C.axes=S,_.object&&C.draw(B),x.disable(x.CULL_FACE);for(var i=0;i<e;++i){var o=L[i];o.axes=S,o.pixelRatio=U.pixelRatio,o.isOpaque&&o.isOpaque()&&o.draw(B),o.isTransparent&&o.isTransparent()&&(O=!0)}if(O){w.shape=N,w.bind(),x.clear(x.DEPTH_BUFFER_BIT),x.colorMask(!1,!1,!1,!1),x.depthMask(!0),x.depthFunc(x.LESS),S.enable&&S.isTransparent()&&S.drawTransparent(B);for(var i=0;i<e;++i){var o=L[i];o.isOpaque&&o.isOpaque()&&o.draw(B)}x.enable(x.BLEND),x.blendEquation(x.FUNC_ADD),x.blendFunc(x.ONE,x.ONE_MINUS_SRC_ALPHA),x.colorMask(!0,!0,!0,!0),x.depthMask(!1),x.clearColor(0,0,0,0),x.clear(x.COLOR_BUFFER_BIT),S.isTransparent()&&S.drawTransparent(B);for(var i=0;i<e;++i){var o=L[i];o.isTransparent&&o.isTransparent()&&o.drawTransparent(B)}x.bindFramebuffer(x.FRAMEBUFFER,null),x.blendFunc(x.ONE,x.ONE_MINUS_SRC_ALPHA),x.disable(x.DEPTH_TEST),k.bind(),w.color[0].bind(0),k.uniforms.accumBuffer=0,c(x),x.disable(x.BLEND)}I=!1;for(var i=0;i<e;++i)L[i].dirty=!1}}}return U.enableMouseListeners(),function t(){U._stopped||U.contextLost||(X(),requestAnimationFrame(t))}(),U.redraw=function(){U._stopped||(I=!0,X())},U},createCamera:n}},{\"./camera.js\":288,\"./lib/shader\":289,\"a-big-triangle\":59,\"gl-axes3d\":233,\"gl-axes3d/properties\":240,\"gl-fbo\":249,\"gl-mat4/ortho\":268,\"gl-mat4/perspective\":269,\"gl-select-static\":300,\"gl-spikes3d\":310,\"is-mobile\":420,\"mouse-change\":435,\"mouse-wheel\":438}],291:[function(t,e,r){var n=t(\"glslify\");r.pointVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform float pointCloud;\\n\\nhighp float rand(vec2 co) {\\n  highp float a = 12.9898;\\n  highp float b = 78.233;\\n  highp float c = 43758.5453;\\n  highp float d = dot(co.xy, vec2(a, b));\\n  highp float e = mod(d, 3.14);\\n  return fract(sin(e) * c);\\n}\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n    // if we don't jitter the point size a bit, overall point cloud\\n    // saturation 'jumps' on zooming, which is disturbing and confusing\\n  gl_PointSize = pointSize * ((19.5 + rand(position)) / 20.0);\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    // get the same square surface as circle would be\\n    gl_PointSize *= 0.886;\\n  }\\n}\"]),r.pointFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color, borderColor;\\nuniform float centerFraction;\\nuniform float pointCloud;\\n\\nvoid main() {\\n  float radius;\\n  vec4 baseColor;\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    if(centerFraction == 1.0) {\\n      gl_FragColor = color;\\n    } else {\\n      gl_FragColor = mix(borderColor, color, centerFraction);\\n    }\\n  } else {\\n    radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n    if(radius > 1.0) {\\n      discard;\\n    }\\n    baseColor = mix(borderColor, color, step(radius, centerFraction));\\n    gl_FragColor = vec4(baseColor.rgb * baseColor.a, baseColor.a);\\n  }\\n}\\n\"]),r.pickVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform vec4 pickOffset;\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n  gl_PointSize = pointSize;\\n\\n  vec4 id = pickId + pickOffset;\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  fragId = id;\\n}\\n\"]),r.pickFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  float radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n  if(radius > 1.0) {\\n    discard;\\n  }\\n  gl_FragColor = fragId / 255.0;\\n}\\n\"])},{glslify:409}],292:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"typedarray-pool\"),o=t(\"./lib/shader\");function s(t,e,r,n,i){this.plot=t,this.offsetBuffer=e,this.pickBuffer=r,this.shader=n,this.pickShader=i,this.sizeMin=.5,this.sizeMinCap=2,this.sizeMax=20,this.areaRatio=1,this.pointCount=0,this.color=[1,0,0,1],this.borderColor=[0,0,0,1],this.blend=!1,this.pickOffset=0,this.points=null}e.exports=function(t,e){var r=t.gl,a=i(r),l=i(r),c=n(r,o.pointVertex,o.pointFragment),u=n(r,o.pickVertex,o.pickFragment),h=new s(t,a,l,c,u);return h.update(e),t.addObject(h),h};var l,c,u=s.prototype;u.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.offsetBuffer.dispose(),this.pickBuffer.dispose(),this.plot.removeObject(this)},u.update=function(t){var e;function r(e,r){return e in t?t[e]:r}t=t||{},this.sizeMin=r(\"sizeMin\",.5),this.sizeMax=r(\"sizeMax\",20),this.color=r(\"color\",[1,0,0,1]).slice(),this.areaRatio=r(\"areaRatio\",1),this.borderColor=r(\"borderColor\",[0,0,0,1]).slice(),this.blend=r(\"blend\",!1);var n=t.positions.length>>>1,i=t.positions instanceof Float32Array,o=t.idToIndex instanceof Int32Array&&t.idToIndex.length>=n,s=t.positions,l=i?s:a.mallocFloat32(s.length),c=o?t.idToIndex:a.mallocInt32(n);if(i||l.set(s),!o)for(l.set(s),e=0;e<n;e++)c[e]=e;this.points=s,this.offsetBuffer.update(l),this.pickBuffer.update(c),i||a.free(l),o||a.free(c),this.pointCount=n,this.pickOffset=0},u.unifiedDraw=(l=[1,0,0,0,1,0,0,0,1],c=[0,0,0,0],function(t){var e=void 0!==t,r=e?this.pickShader:this.shader,n=this.plot.gl,i=this.plot.dataBox;if(0===this.pointCount)return t;var a=i[2]-i[0],o=i[3]-i[1],s=function(t,e){var r,n=0,i=t.length>>>1;for(r=0;r<i;r++){var a=t[2*r],o=t[2*r+1];a>=e[0]&&a<=e[2]&&o>=e[1]&&o<=e[3]&&n++}return n}(this.points,i),u=this.plot.pickPixelRatio*Math.max(Math.min(this.sizeMinCap,this.sizeMin),Math.min(this.sizeMax,this.sizeMax/Math.pow(s,.33333)));l[0]=2/a,l[4]=2/o,l[6]=-2*i[0]/a-1,l[7]=-2*i[1]/o-1,this.offsetBuffer.bind(),r.bind(),r.attributes.position.pointer(),r.uniforms.matrix=l,r.uniforms.color=this.color,r.uniforms.borderColor=this.borderColor,r.uniforms.pointCloud=u<5,r.uniforms.pointSize=u,r.uniforms.centerFraction=Math.min(1,Math.max(0,Math.sqrt(1-this.areaRatio))),e&&(c[0]=255&t,c[1]=t>>8&255,c[2]=t>>16&255,c[3]=t>>24&255,this.pickBuffer.bind(),r.attributes.pickId.pointer(n.UNSIGNED_BYTE),r.uniforms.pickOffset=c,this.pickOffset=t);var h=n.getParameter(n.BLEND),f=n.getParameter(n.DITHER);return h&&!this.blend&&n.disable(n.BLEND),f&&n.disable(n.DITHER),n.drawArrays(n.POINTS,0,this.pointCount),h&&!this.blend&&n.enable(n.BLEND),f&&n.enable(n.DITHER),t+this.pointCount}),u.draw=u.unifiedDraw,u.drawPick=u.unifiedDraw,u.pick=function(t,e,r){var n=this.pickOffset,i=this.pointCount;if(r<n||r>=n+i)return null;var a=r-n,o=this.points;return{object:this,pointId:a,dataCoord:[o[2*a],o[2*a+1]]}}},{\"./lib/shader\":291,\"gl-buffer\":241,\"gl-shader\":301,\"typedarray-pool\":545}],293:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c=e[0],u=e[1],h=e[2],f=e[3],p=r[0],d=r[1],g=r[2],v=r[3];(a=c*p+u*d+h*g+f*v)<0&&(a=-a,p=-p,d=-d,g=-g,v=-v);1-a>1e-6?(i=Math.acos(a),o=Math.sin(i),s=Math.sin((1-n)*i)/o,l=Math.sin(n*i)/o):(s=1-n,l=n);return t[0]=s*c+l*p,t[1]=s*u+l*d,t[2]=s*h+l*g,t[3]=s*f+l*v,t}},{}],294:[function(t,e,r){\"use strict\";e.exports=function(t){return t||0===t?t.toString():\"\"}},{}],295:[function(t,e,r){\"use strict\";var n=t(\"vectorize-text\");e.exports=function(t,e,r){var a=i[e];a||(a=i[e]={});if(t in a)return a[t];var o={textAlign:\"center\",textBaseline:\"middle\",lineHeight:1,font:e,lineSpacing:1.25,styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},triangles:!0},s=n(t,o);o.triangles=!1;var l,c,u=n(t,o);if(r&&1!==r){for(l=0;l<s.positions.length;++l)for(c=0;c<s.positions[l].length;++c)s.positions[l][c]/=r;for(l=0;l<u.positions.length;++l)for(c=0;c<u.positions[l].length;++c)u.positions[l][c]/=r}var h=[[1/0,1/0],[-1/0,-1/0]],f=u.positions.length;for(l=0;l<f;++l){var p=u.positions[l];for(c=0;c<2;++c)h[0][c]=Math.min(h[0][c],p[c]),h[1][c]=Math.max(h[1][c],p[c])}return a[t]=[s,u,h]};var i={}},{\"vectorize-text\":550}],296:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform vec4 highlightId;\\nuniform float highlightScale;\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = 1.0;\\n    if(distance(highlightId, id) < 0.0001) {\\n      scale = highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1);\\n    vec4 viewPosition = view * worldPosition;\\n    viewPosition = viewPosition / viewPosition.w;\\n    vec4 clipPosition = projection * (viewPosition + scale * vec4(glyph.x, -glyph.y, 0, 0));\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float highlightScale, pixelRatio;\\nuniform vec4 highlightId;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = pixelRatio;\\n    if(distance(highlightId.bgr, id.bgr) < 0.001) {\\n      scale *= highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1.0);\\n    vec4 viewPosition = view * worldPosition;\\n    vec4 clipPosition = projection * viewPosition;\\n    clipPosition /= clipPosition.w;\\n\\n    gl_Position = clipPosition + vec4(screenSize * scale * vec2(glyph.x, -glyph.y), 0.0, 0.0);\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform float highlightScale;\\nuniform vec4 highlightId;\\nuniform vec3 axes[2];\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float scale, pixelRatio;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float lscale = pixelRatio * scale;\\n    if(distance(highlightId, id) < 0.0001) {\\n      lscale *= highlightScale;\\n    }\\n\\n    vec4 clipCenter   = projection * view * model * vec4(position, 1);\\n    vec3 dataPosition = position + 0.5*lscale*(axes[0] * glyph.x + axes[1] * glyph.y) * clipCenter.w * screenSize.y;\\n    vec4 clipPosition = projection * view * model * vec4(dataPosition, 1);\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = dataPosition;\\n  }\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float opacity;\\n\\nvarying vec4 interpColor;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (\\n    outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate) ||\\n    interpColor.a * opacity == 0.\\n  ) discard;\\n  gl_FragColor = interpColor * opacity;\\n}\\n\"]),c=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float pickGroup;\\n\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate)) discard;\\n\\n  gl_FragColor = vec4(pickGroup, pickId.bgr);\\n}\"]),u=[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"glyph\",type:\"vec2\"},{name:\"id\",type:\"vec4\"}],h={vertex:a,fragment:l,attributes:u},f={vertex:o,fragment:l,attributes:u},p={vertex:s,fragment:l,attributes:u},d={vertex:a,fragment:c,attributes:u},g={vertex:o,fragment:c,attributes:u},v={vertex:s,fragment:c,attributes:u};function m(t,e){var r=n(t,e),i=r.attributes;return i.position.location=0,i.color.location=1,i.glyph.location=2,i.id.location=3,r}r.createPerspective=function(t){return m(t,h)},r.createOrtho=function(t){return m(t,f)},r.createProject=function(t){return m(t,p)},r.createPickPerspective=function(t){return m(t,d)},r.createPickOrtho=function(t){return m(t,g)},r.createPickProject=function(t){return m(t,v)}},{\"gl-shader\":301,glslify:409}],297:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"typedarray-pool\"),s=t(\"gl-mat4/multiply\"),l=t(\"./lib/shaders\"),c=t(\"./lib/glyphs\"),u=t(\"./lib/get-simple-string\"),h=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function f(t,e){var r=t[0],n=t[1],i=t[2],a=t[3];return t[0]=e[0]*r+e[4]*n+e[8]*i+e[12]*a,t[1]=e[1]*r+e[5]*n+e[9]*i+e[13]*a,t[2]=e[2]*r+e[6]*n+e[10]*i+e[14]*a,t[3]=e[3]*r+e[7]*n+e[11]*i+e[15]*a,t}function p(t,e,r,n){return f(n,n),f(n,n),f(n,n)}function d(t,e){this.index=t,this.dataCoordinate=this.position=e}function g(t){return!0===t?1:t>1?1:t}function v(t,e,r,n,i,a,o,s,l,c,u,h){this.gl=t,this.pixelRatio=1,this.shader=e,this.orthoShader=r,this.projectShader=n,this.pointBuffer=i,this.colorBuffer=a,this.glyphBuffer=o,this.idBuffer=s,this.vao=l,this.vertexCount=0,this.lineVertexCount=0,this.opacity=1,this.hasAlpha=!1,this.lineWidth=0,this.projectScale=[2/3,2/3,2/3],this.projectOpacity=[1,1,1],this.projectHasAlpha=!1,this.pickId=0,this.pickPerspectiveShader=c,this.pickOrthoShader=u,this.pickProjectShader=h,this.points=[],this._selectResult=new d(0,[0,0,0]),this.useOrtho=!0,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.axesProject=[!0,!0,!0],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.highlightId=[1,1,1,1],this.highlightScale=2,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.dirty=!0}e.exports=function(t){var e=t.gl,r=l.createPerspective(e),n=l.createOrtho(e),o=l.createProject(e),s=l.createPickPerspective(e),c=l.createPickOrtho(e),u=l.createPickProject(e),h=i(e),f=i(e),p=i(e),d=i(e),g=a(e,[{buffer:h,size:3,type:e.FLOAT},{buffer:f,size:4,type:e.FLOAT},{buffer:p,size:2,type:e.FLOAT},{buffer:d,size:4,type:e.UNSIGNED_BYTE,normalized:!0}]),m=new v(e,r,n,o,h,f,p,d,g,s,c,u);return m.update(t),m};var m=v.prototype;m.pickSlots=1,m.setPickBase=function(t){this.pickId=t},m.isTransparent=function(){if(this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&this.projectHasAlpha)return!0;return!1},m.isOpaque=function(){if(!this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&!this.projectHasAlpha)return!0;return!1};var y=[0,0],x=[0,0,0],b=[0,0,0],_=[0,0,0,1],w=[0,0,0,1],k=h.slice(),T=[0,0,0],A=[[0,0,0],[0,0,0]];function M(t){return t[0]=t[1]=t[2]=0,t}function S(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=1,t}function E(t,e,r,n){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[r]=n,t}function C(t,e,r,n){var i,a=e.axesProject,o=e.gl,l=t.uniforms,c=r.model||h,u=r.view||h,f=r.projection||h,d=e.axesBounds,g=function(t){for(var e=A,r=0;r<2;++r)for(var n=0;n<3;++n)e[r][n]=Math.max(Math.min(t[r][n],1e8),-1e8);return e}(e.clipBounds);i=e.axes&&e.axes.lastCubeProps?e.axes.lastCubeProps.axis:[1,1,1],y[0]=2/o.drawingBufferWidth,y[1]=2/o.drawingBufferHeight,t.bind(),l.view=u,l.projection=f,l.screenSize=y,l.highlightId=e.highlightId,l.highlightScale=e.highlightScale,l.clipBounds=g,l.pickGroup=e.pickId/255,l.pixelRatio=n;for(var v=0;v<3;++v)if(a[v]){l.scale=e.projectScale[v],l.opacity=e.projectOpacity[v];for(var m=k,C=0;C<16;++C)m[C]=0;for(C=0;C<4;++C)m[5*C]=1;m[5*v]=0,i[v]<0?m[12+v]=d[0][v]:m[12+v]=d[1][v],s(m,c,m),l.model=m;var L=(v+1)%3,P=(v+2)%3,O=M(x),z=M(b);O[L]=1,z[P]=1;var I=p(0,0,0,S(_,O)),D=p(0,0,0,S(w,z));if(Math.abs(I[1])>Math.abs(D[1])){var R=I;I=D,D=R,R=O,O=z,z=R;var F=L;L=P,P=F}I[0]<0&&(O[L]=-1),D[1]>0&&(z[P]=-1);var B=0,N=0;for(C=0;C<4;++C)B+=Math.pow(c[4*L+C],2),N+=Math.pow(c[4*P+C],2);O[L]/=Math.sqrt(B),z[P]/=Math.sqrt(N),l.axes[0]=O,l.axes[1]=z,l.fragClipBounds[0]=E(T,g[0],v,-1e8),l.fragClipBounds[1]=E(T,g[1],v,1e8),e.vao.bind(),e.vao.draw(o.TRIANGLES,e.vertexCount),e.lineWidth>0&&(o.lineWidth(e.lineWidth*n),e.vao.draw(o.LINES,e.lineVertexCount,e.vertexCount)),e.vao.unbind()}}var L=[[-1e8,-1e8,-1e8],[1e8,1e8,1e8]];function P(t,e,r,n,i,a,o){var s=r.gl;if((a===r.projectHasAlpha||o)&&C(e,r,n,i),a===r.hasAlpha||o){t.bind();var l=t.uniforms;l.model=n.model||h,l.view=n.view||h,l.projection=n.projection||h,y[0]=2/s.drawingBufferWidth,y[1]=2/s.drawingBufferHeight,l.screenSize=y,l.highlightId=r.highlightId,l.highlightScale=r.highlightScale,l.fragClipBounds=L,l.clipBounds=r.axes.bounds,l.opacity=r.opacity,l.pickGroup=r.pickId/255,l.pixelRatio=i,r.vao.bind(),r.vao.draw(s.TRIANGLES,r.vertexCount),r.lineWidth>0&&(s.lineWidth(r.lineWidth*i),r.vao.draw(s.LINES,r.lineVertexCount,r.vertexCount)),r.vao.unbind()}}function O(t,e,r,i){var a;a=Array.isArray(t)?e<t.length?t[e]:void 0:t,a=u(a);var o=!0;n(a)&&(a=\"\\u25bc\",o=!1);var s=c(a,r,i);return{mesh:s[0],lines:s[1],bounds:s[2],visible:o}}m.draw=function(t){P(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!1,!1)},m.drawTransparent=function(t){P(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!0,!1)},m.drawPick=function(t){P(this.useOrtho?this.pickOrthoShader:this.pickPerspectiveShader,this.pickProjectShader,this,t,1,!0,!0)},m.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[2]+(t.value[1]<<8)+(t.value[0]<<16);if(e>=this.pointCount||e<0)return null;var r=this.points[e],n=this._selectResult;n.index=e;for(var i=0;i<3;++i)n.position[i]=n.dataCoordinate[i]=r[i];return n},m.highlight=function(t){if(t){var e=t.index,r=255&e,n=e>>8&255,i=e>>16&255;this.highlightId=[r/255,n/255,i/255,0]}else this.highlightId=[1,1,1,1]},m.update=function(t){if(\"perspective\"in(t=t||{})&&(this.useOrtho=!t.perspective),\"orthographic\"in t&&(this.useOrtho=!!t.orthographic),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"project\"in t)if(Array.isArray(t.project))this.axesProject=t.project;else{var e=!!t.project;this.axesProject=[e,e,e]}if(\"projectScale\"in t)if(Array.isArray(t.projectScale))this.projectScale=t.projectScale.slice();else{var r=+t.projectScale;this.projectScale=[r,r,r]}if(this.projectHasAlpha=!1,\"projectOpacity\"in t){if(Array.isArray(t.projectOpacity))this.projectOpacity=t.projectOpacity.slice();else{r=+t.projectOpacity;this.projectOpacity=[r,r,r]}for(var n=0;n<3;++n)this.projectOpacity[n]=g(this.projectOpacity[n]),this.projectOpacity[n]<1&&(this.projectHasAlpha=!0)}this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=g(t.opacity),this.opacity<1&&(this.hasAlpha=!0)),this.dirty=!0;var i,a,s=t.position,l=t.font||\"normal\",c=t.alignment||[0,0];if(2===c.length)i=c[0],a=c[1];else{i=[],a=[];for(n=0;n<c.length;++n)i[n]=c[n][0],a[n]=c[n][1]}var u=[1/0,1/0,1/0],h=[-1/0,-1/0,-1/0],f=t.glyph,p=t.color,d=t.size,v=t.angle,m=t.lineColor,y=-1,x=0,b=0,_=0;if(s.length){_=s.length;t:for(n=0;n<_;++n){for(var w=s[n],k=0;k<3;++k)if(isNaN(w[k])||!isFinite(w[k]))continue t;var T=(N=O(f,n,l,this.pixelRatio)).mesh,A=N.lines,M=N.bounds;x+=3*T.cells.length,b+=2*A.edges.length}}var S=x+b,E=o.mallocFloat(3*S),C=o.mallocFloat(4*S),L=o.mallocFloat(2*S),P=o.mallocUint32(S);if(S>0){var z=0,I=x,D=[0,0,0,1],R=[0,0,0,1],F=Array.isArray(p)&&Array.isArray(p[0]),B=Array.isArray(m)&&Array.isArray(m[0]);t:for(n=0;n<_;++n){y+=1;for(w=s[n],k=0;k<3;++k){if(isNaN(w[k])||!isFinite(w[k]))continue t;h[k]=Math.max(h[k],w[k]),u[k]=Math.min(u[k],w[k])}T=(N=O(f,n,l,this.pixelRatio)).mesh,A=N.lines,M=N.bounds;var N,j=N.visible;if(j)if(Array.isArray(p)){if(3===(U=F?n<p.length?p[n]:[0,0,0,0]:p).length){for(k=0;k<3;++k)D[k]=U[k];D[3]=1}else if(4===U.length){for(k=0;k<4;++k)D[k]=U[k];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else D[0]=D[1]=D[2]=0,D[3]=1;else D=[1,1,1,0];if(j)if(Array.isArray(m)){var U;if(3===(U=B?n<m.length?m[n]:[0,0,0,0]:m).length){for(k=0;k<3;++k)R[k]=U[k];R[k]=1}else if(4===U.length){for(k=0;k<4;++k)R[k]=U[k];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else R[0]=R[1]=R[2]=0,R[3]=1;else R=[1,1,1,0];var V=.5;j?Array.isArray(d)?V=n<d.length?+d[n]:12:d?V=+d:this.useOrtho&&(V=12):V=0;var q=0;Array.isArray(v)?q=n<v.length?+v[n]:0:v&&(q=+v);var H=Math.cos(q),G=Math.sin(q);for(w=s[n],k=0;k<3;++k)h[k]=Math.max(h[k],w[k]),u[k]=Math.min(u[k],w[k]);var Y=i,W=a;Y=0;Array.isArray(i)?Y=n<i.length?i[n]:0:i&&(Y=i);W=0;Array.isArray(a)?W=n<a.length?a[n]:0:a&&(W=a);var X=[Y*=Y>0?1-M[0][0]:Y<0?1+M[1][0]:1,W*=W>0?1-M[0][1]:W<0?1+M[1][1]:1],Z=T.cells||[],J=T.positions||[];for(k=0;k<Z.length;++k)for(var K=Z[k],$=0;$<3;++$){for(var Q=0;Q<3;++Q)E[3*z+Q]=w[Q];for(Q=0;Q<4;++Q)C[4*z+Q]=D[Q];P[z]=y;var tt=J[K[$]];L[2*z]=V*(H*tt[0]-G*tt[1]+X[0]),L[2*z+1]=V*(G*tt[0]+H*tt[1]+X[1]),z+=1}for(Z=A.edges,J=A.positions,k=0;k<Z.length;++k)for(K=Z[k],$=0;$<2;++$){for(Q=0;Q<3;++Q)E[3*I+Q]=w[Q];for(Q=0;Q<4;++Q)C[4*I+Q]=R[Q];P[I]=y;tt=J[K[$]];L[2*I]=V*(H*tt[0]-G*tt[1]+X[0]),L[2*I+1]=V*(G*tt[0]+H*tt[1]+X[1]),I+=1}}}this.bounds=[u,h],this.points=s,this.pointCount=s.length,this.vertexCount=x,this.lineVertexCount=b,this.pointBuffer.update(E),this.colorBuffer.update(C),this.glyphBuffer.update(L),this.idBuffer.update(P),o.free(E),o.free(C),o.free(L),o.free(P)},m.dispose=function(){this.shader.dispose(),this.orthoShader.dispose(),this.pickPerspectiveShader.dispose(),this.pickOrthoShader.dispose(),this.vao.dispose(),this.pointBuffer.dispose(),this.colorBuffer.dispose(),this.glyphBuffer.dispose(),this.idBuffer.dispose()}},{\"./lib/get-simple-string\":294,\"./lib/glyphs\":295,\"./lib/shaders\":296,\"gl-buffer\":241,\"gl-mat4/multiply\":267,\"gl-vao\":327,\"is-string-blank\":423,\"typedarray-pool\":545}],298:[function(t,e,r){\"use strict\";var n=t(\"glslify\");r.boxVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 vertex;\\n\\nuniform vec2 cornerA, cornerB;\\n\\nvoid main() {\\n  gl_Position = vec4(mix(cornerA, cornerB, vertex), 0, 1);\\n}\\n\"]),r.boxFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\n\\nvoid main() {\\n  gl_FragColor = color;\\n}\\n\"])},{glslify:409}],299:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"./lib/shaders\");function o(t,e,r){this.plot=t,this.boxBuffer=e,this.boxShader=r,this.enabled=!0,this.selectBox=[1/0,1/0,-1/0,-1/0],this.borderColor=[0,0,0,1],this.innerFill=!1,this.innerColor=[0,0,0,.25],this.outerFill=!0,this.outerColor=[0,0,0,.5],this.borderWidth=10}e.exports=function(t,e){var r=t.gl,s=i(r,[0,0,0,1,1,0,1,1]),l=n(r,a.boxVertex,a.boxFragment),c=new o(t,s,l);return c.update(e),t.addOverlay(c),c};var s=o.prototype;s.draw=function(){if(this.enabled){var t=this.plot,e=this.selectBox,r=this.borderWidth,n=(this.innerFill,this.innerColor),i=(this.outerFill,this.outerColor),a=this.borderColor,o=t.box,s=t.screenBox,l=t.dataBox,c=t.viewBox,u=t.pixelRatio,h=(e[0]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],f=(e[1]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1],p=(e[2]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],d=(e[3]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1];if(h=Math.max(h,c[0]),f=Math.max(f,c[1]),p=Math.min(p,c[2]),d=Math.min(d,c[3]),!(p<h||d<f)){o.bind();var g=s[2]-s[0],v=s[3]-s[1];if(this.outerFill&&(o.drawBox(0,0,g,f,i),o.drawBox(0,f,h,d,i),o.drawBox(0,d,g,v,i),o.drawBox(p,f,g,d,i)),this.innerFill&&o.drawBox(h,f,p,d,n),r>0){var m=r*u;o.drawBox(h-m,f-m,p+m,f+m,a),o.drawBox(h-m,d-m,p+m,d+m,a),o.drawBox(h-m,f-m,h+m,d+m,a),o.drawBox(p-m,f-m,p+m,d+m,a)}}}},s.update=function(t){t=t||{},this.innerFill=!!t.innerFill,this.outerFill=!!t.outerFill,this.innerColor=(t.innerColor||[0,0,0,.5]).slice(),this.outerColor=(t.outerColor||[0,0,0,.5]).slice(),this.borderColor=(t.borderColor||[0,0,0,1]).slice(),this.borderWidth=t.borderWidth||0,this.selectBox=(t.selectBox||this.selectBox).slice()},s.dispose=function(){this.boxBuffer.dispose(),this.boxShader.dispose(),this.plot.removeOverlay(this)}},{\"./lib/shaders\":298,\"gl-buffer\":241,\"gl-shader\":301}],300:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=n(t,e),a=i.mallocUint8(e[0]*e[1]*4);return new c(t,r,a)};var n=t(\"gl-fbo\"),i=t(\"typedarray-pool\"),a=t(\"ndarray\"),o=t(\"bit-twiddle\").nextPow2,s=t(\"cwise/lib/wrapper\")({args:[\"array\",{offset:[0,0,1],array:0},{offset:[0,0,2],array:0},{offset:[0,0,3],array:0},\"scalar\",\"scalar\",\"index\"],pre:{body:\"{this_closestD2=1e8,this_closestX=-1,this_closestY=-1}\",args:[],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[]},body:{body:\"{if(_inline_16_arg0_<255||_inline_16_arg1_<255||_inline_16_arg2_<255||_inline_16_arg3_<255){var _inline_16_l=_inline_16_arg4_-_inline_16_arg6_[0],_inline_16_a=_inline_16_arg5_-_inline_16_arg6_[1],_inline_16_f=_inline_16_l*_inline_16_l+_inline_16_a*_inline_16_a;_inline_16_f<this_closestD2&&(this_closestD2=_inline_16_f,this_closestX=_inline_16_arg6_[0],this_closestY=_inline_16_arg6_[1])}}\",args:[{name:\"_inline_16_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg4_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg5_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg6_\",lvalue:!1,rvalue:!0,count:4}],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[\"_inline_16_a\",\"_inline_16_f\",\"_inline_16_l\"]},post:{body:\"{return[this_closestX,this_closestY,this_closestD2]}\",args:[],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[]},debug:!1,funcName:\"cwise\",blockSize:64});function l(t,e,r,n,i){this.coord=[t,e],this.id=r,this.value=n,this.distance=i}function c(t,e,r){this.gl=t,this.fbo=e,this.buffer=r,this._readTimeout=null;var n=this;this._readCallback=function(){n.gl&&(e.bind(),t.readPixels(0,0,e.shape[0],e.shape[1],t.RGBA,t.UNSIGNED_BYTE,n.buffer),n._readTimeout=null)}}var u=c.prototype;Object.defineProperty(u,\"shape\",{get:function(){return this.gl?this.fbo.shape.slice():[0,0]},set:function(t){if(this.gl){this.fbo.shape=t;var e=this.fbo.shape[0],r=this.fbo.shape[1];if(r*e*4>this.buffer.length){i.free(this.buffer);for(var n=this.buffer=i.mallocUint8(o(r*e*4)),a=0;a<r*e*4;++a)n[a]=255}return t}}}),u.begin=function(){var t=this.gl;this.shape;t&&(this.fbo.bind(),t.clearColor(1,1,1,1),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT))},u.end=function(){var t=this.gl;t&&(t.bindFramebuffer(t.FRAMEBUFFER,null),this._readTimeout||clearTimeout(this._readTimeout),this._readTimeout=setTimeout(this._readCallback,1))},u.query=function(t,e,r){if(!this.gl)return null;var n=this.fbo.shape.slice();t|=0,e|=0,\"number\"!=typeof r&&(r=1);var i=0|Math.min(Math.max(t-r,0),n[0]),o=0|Math.min(Math.max(t+r,0),n[0]),c=0|Math.min(Math.max(e-r,0),n[1]),u=0|Math.min(Math.max(e+r,0),n[1]);if(o<=i||u<=c)return null;var h=[o-i,u-c],f=a(this.buffer,[h[0],h[1],4],[4,4*n[0],1],4*(i+n[0]*c)),p=s(f.hi(h[0],h[1],1),r,r),d=p[0],g=p[1];return d<0||Math.pow(this.radius,2)<p[2]?null:new l(d+i|0,g+c|0,f.get(d,g,0),[f.get(d,g,1),f.get(d,g,2),f.get(d,g,3)],Math.sqrt(p[2]))},u.dispose=function(){this.gl&&(this.fbo.dispose(),i.free(this.buffer),this.gl=null,this._readTimeout&&clearTimeout(this._readTimeout))}},{\"bit-twiddle\":92,\"cwise/lib/wrapper\":149,\"gl-fbo\":249,ndarray:450,\"typedarray-pool\":545}],301:[function(t,e,r){\"use strict\";var n=t(\"./lib/create-uniforms\"),i=t(\"./lib/create-attributes\"),a=t(\"./lib/reflect\"),o=t(\"./lib/shader-cache\"),s=t(\"./lib/runtime-reflect\"),l=t(\"./lib/GLError\");function c(t){this.gl=t,this.gl.lastAttribCount=0,this._vref=this._fref=this._relink=this.vertShader=this.fragShader=this.program=this.attributes=this.uniforms=this.types=null}var u=c.prototype;function h(t,e){return t.name<e.name?-1:1}u.bind=function(){var t;this.program||this._relink();var e=this.gl.getProgramParameter(this.program,this.gl.ACTIVE_ATTRIBUTES),r=this.gl.lastAttribCount;if(e>r)for(t=r;t<e;t++)this.gl.enableVertexAttribArray(t);else if(r>e)for(t=e;t<r;t++)this.gl.disableVertexAttribArray(t);this.gl.lastAttribCount=e,this.gl.useProgram(this.program)},u.dispose=function(){for(var t=this.gl.lastAttribCount,e=0;e<t;e++)this.gl.disableVertexAttribArray(e);this.gl.lastAttribCount=0,this._fref&&this._fref.dispose(),this._vref&&this._vref.dispose(),this.attributes=this.types=this.vertShader=this.fragShader=this.program=this._relink=this._fref=this._vref=null},u.update=function(t,e,r,c){if(!e||1===arguments.length){var u=t;t=u.vertex,e=u.fragment,r=u.uniforms,c=u.attributes}var f=this,p=f.gl,d=f._vref;f._vref=o.shader(p,p.VERTEX_SHADER,t),d&&d.dispose(),f.vertShader=f._vref.shader;var g=this._fref;if(f._fref=o.shader(p,p.FRAGMENT_SHADER,e),g&&g.dispose(),f.fragShader=f._fref.shader,!r||!c){var v=p.createProgram();if(p.attachShader(v,f.fragShader),p.attachShader(v,f.vertShader),p.linkProgram(v),!p.getProgramParameter(v,p.LINK_STATUS)){var m=p.getProgramInfoLog(v);throw new l(m,\"Error linking program:\"+m)}r=r||s.uniforms(p,v),c=c||s.attributes(p,v),p.deleteProgram(v)}(c=c.slice()).sort(h);var y,x=[],b=[],_=[];for(y=0;y<c.length;++y){var w=c[y];if(w.type.indexOf(\"mat\")>=0){for(var k=0|w.type.charAt(w.type.length-1),T=new Array(k),A=0;A<k;++A)T[A]=_.length,b.push(w.name+\"[\"+A+\"]\"),\"number\"==typeof w.location?_.push(w.location+A):Array.isArray(w.location)&&w.location.length===k&&\"number\"==typeof w.location[A]?_.push(0|w.location[A]):_.push(-1);x.push({name:w.name,type:w.type,locations:T})}else x.push({name:w.name,type:w.type,locations:[_.length]}),b.push(w.name),\"number\"==typeof w.location?_.push(0|w.location):_.push(-1)}var M=0;for(y=0;y<_.length;++y)if(_[y]<0){for(;_.indexOf(M)>=0;)M+=1;_[y]=M}var S=new Array(r.length);function E(){f.program=o.program(p,f._vref,f._fref,b,_);for(var t=0;t<r.length;++t)S[t]=p.getUniformLocation(f.program,r[t].name)}E(),f._relink=E,f.types={uniforms:a(r),attributes:a(c)},f.attributes=i(p,f,x,_),Object.defineProperty(f,\"uniforms\",n(p,f,r,S))},e.exports=function(t,e,r,n,i){var a=new c(t);return a.update(e,r,n,i),a}},{\"./lib/GLError\":302,\"./lib/create-attributes\":303,\"./lib/create-uniforms\":304,\"./lib/reflect\":305,\"./lib/runtime-reflect\":306,\"./lib/shader-cache\":307}],302:[function(t,e,r){function n(t,e,r){this.shortMessage=e||\"\",this.longMessage=r||\"\",this.rawError=t||\"\",this.message=\"gl-shader: \"+(e||t||\"\")+(r?\"\\n\"+r:\"\"),this.stack=(new Error).stack}n.prototype=new Error,n.prototype.name=\"GLError\",n.prototype.constructor=n,e.exports=n},{}],303:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){for(var a={},l=0,c=r.length;l<c;++l){var u=r[l],h=u.name,f=u.type,p=u.locations;switch(f){case\"bool\":case\"int\":case\"float\":o(t,e,p[0],i,1,a,h);break;default:if(f.indexOf(\"vec\")>=0){var d=f.charCodeAt(f.length-1)-48;if(d<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+h+\": \"+f);o(t,e,p[0],i,d,a,h)}else{if(!(f.indexOf(\"mat\")>=0))throw new n(\"\",\"Unknown data type for attribute \"+h+\": \"+f);var d=f.charCodeAt(f.length-1)-48;if(d<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+h+\": \"+f);s(t,e,p,i,d,a,h)}}}return a};var n=t(\"./GLError\");function i(t,e,r,n,i,a){this._gl=t,this._wrapper=e,this._index=r,this._locations=n,this._dimension=i,this._constFunc=a}var a=i.prototype;function o(t,e,r,n,a,o,s){for(var l=[\"gl\",\"v\"],c=[],u=0;u<a;++u)l.push(\"x\"+u),c.push(\"x\"+u);l.push(\"if(x0.length===void 0){return gl.vertexAttrib\"+a+\"f(v,\"+c.join()+\")}else{return gl.vertexAttrib\"+a+\"fv(v,x0)}\");var h=Function.apply(null,l),f=new i(t,e,r,n,a,h);Object.defineProperty(o,s,{set:function(e){return t.disableVertexAttribArray(n[r]),h(t,n[r],e),e},get:function(){return f},enumerable:!0})}function s(t,e,r,n,i,a,s){for(var l=new Array(i),c=new Array(i),u=0;u<i;++u)o(t,e,r[u],n,i,l,u),c[u]=l[u];Object.defineProperty(l,\"location\",{set:function(t){if(Array.isArray(t))for(var e=0;e<i;++e)c[e].location=t[e];else for(e=0;e<i;++e)c[e].location=t+e;return t},get:function(){for(var t=new Array(i),e=0;e<i;++e)t[e]=n[r[e]];return t},enumerable:!0}),l.pointer=function(e,a,o,s){e=e||t.FLOAT,a=!!a,o=o||i*i,s=s||0;for(var l=0;l<i;++l){var c=n[r[l]];t.vertexAttribPointer(c,i,e,a,o,s+l*i),t.enableVertexAttribArray(c)}};var h=new Array(i),f=t[\"vertexAttrib\"+i+\"fv\"];Object.defineProperty(a,s,{set:function(e){for(var a=0;a<i;++a){var o=n[r[a]];if(t.disableVertexAttribArray(o),Array.isArray(e[0]))f.call(t,o,e[a]);else{for(var s=0;s<i;++s)h[s]=e[i*a+s];f.call(t,o,h)}}return e},get:function(){return l},enumerable:!0})}a.pointer=function(t,e,r,n){var i=this._gl,a=this._locations[this._index];i.vertexAttribPointer(a,this._dimension,t||i.FLOAT,!!e,r||0,n||0),i.enableVertexAttribArray(a)},a.set=function(t,e,r,n){return this._constFunc(this._locations[this._index],t,e,r,n)},Object.defineProperty(a,\"location\",{get:function(){return this._locations[this._index]},set:function(t){return t!==this._locations[this._index]&&(this._locations[this._index]=0|t,this._wrapper.program=null),0|t}})},{\"./GLError\":302}],304:[function(t,e,r){\"use strict\";var n=t(\"./reflect\"),i=t(\"./GLError\");function a(t){return new Function(\"y\",\"return function(){return y}\")(t)}function o(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}e.exports=function(t,e,r,s){function l(t,e,r){switch(r){case\"bool\":case\"int\":case\"sampler2D\":case\"samplerCube\":return\"gl.uniform1i(locations[\"+e+\"],obj\"+t+\")\";case\"float\":return\"gl.uniform1f(locations[\"+e+\"],obj\"+t+\")\";default:var n=r.indexOf(\"vec\");if(!(0<=n&&n<=1&&r.length===4+n)){if(0===r.indexOf(\"mat\")&&4===r.length){var a=r.charCodeAt(r.length-1)-48;if(a<2||a>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+r);return\"gl.uniformMatrix\"+a+\"fv(locations[\"+e+\"],false,obj\"+t+\")\"}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+r)}var a=r.charCodeAt(r.length-1)-48;if(a<2||a>4)throw new i(\"\",\"Invalid data type\");switch(r.charAt(0)){case\"b\":case\"i\":return\"gl.uniform\"+a+\"iv(locations[\"+e+\"],obj\"+t+\")\";case\"v\":return\"gl.uniform\"+a+\"fv(locations[\"+e+\"],obj\"+t+\")\";default:throw new i(\"\",\"Unrecognized data type for vector \"+name+\": \"+r)}}}function c(e){for(var n=[\"return function updateProperty(obj){\"],i=function t(e,r){if(\"object\"!=typeof r)return[[e,r]];var n=[];for(var i in r){var a=r[i],o=e;parseInt(i)+\"\"===i?o+=\"[\"+i+\"]\":o+=\".\"+i,\"object\"==typeof a?n.push.apply(n,t(o,a)):n.push([o,a])}return n}(\"\",e),a=0;a<i.length;++a){var o=i[a],c=o[0],u=o[1];s[u]&&n.push(l(c,u,r[u].type))}n.push(\"return obj}\");var h=new Function(\"gl\",\"locations\",n.join(\"\\n\"));return h(t,s)}function u(n,l,u){if(\"object\"==typeof u){var f=h(u);Object.defineProperty(n,l,{get:a(f),set:c(u),enumerable:!0,configurable:!1})}else s[u]?Object.defineProperty(n,l,{get:(p=u,new Function(\"gl\",\"wrapper\",\"locations\",\"return function(){return gl.getUniform(wrapper.program,locations[\"+p+\"])}\")(t,e,s)),set:c(u),enumerable:!0,configurable:!1}):n[l]=function(t){switch(t){case\"bool\":return!1;case\"int\":case\"sampler2D\":case\"samplerCube\":case\"float\":return 0;default:var e=t.indexOf(\"vec\");if(0<=e&&e<=1&&t.length===4+e){var r=t.charCodeAt(t.length-1)-48;if(r<2||r>4)throw new i(\"\",\"Invalid data type\");return\"b\"===t.charAt(0)?o(r,!1):o(r,0)}if(0===t.indexOf(\"mat\")&&4===t.length){var r=t.charCodeAt(t.length-1)-48;if(r<2||r>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+t);return o(r*r,0)}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+t)}}(r[u].type);var p}function h(t){var e;if(Array.isArray(t)){e=new Array(t.length);for(var r=0;r<t.length;++r)u(e,r,t[r])}else for(var n in e={},t)u(e,n,t[n]);return e}var f=n(r,!0);return{get:a(h(f)),set:c(f),enumerable:!0,configurable:!0}}},{\"./GLError\":302,\"./reflect\":305}],305:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r={},n=0;n<t.length;++n)for(var i=t[n].name,a=i.split(\".\"),o=r,s=0;s<a.length;++s){var l=a[s].split(\"[\");if(l.length>1){l[0]in o||(o[l[0]]=[]),o=o[l[0]];for(var c=1;c<l.length;++c){var u=parseInt(l[c]);c<l.length-1||s<a.length-1?(u in o||(c<l.length-1?o[u]=[]:o[u]={}),o=o[u]):o[u]=e?n:t[n].type}}else s<a.length-1?(l[0]in o||(o[l[0]]={}),o=o[l[0]]):o[l[0]]=e?n:t[n].type}return r}},{}],306:[function(t,e,r){\"use strict\";r.uniforms=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_UNIFORMS),n=[],i=0;i<r;++i){var o=t.getActiveUniform(e,i);if(o){var s=a(t,o.type);if(o.size>1)for(var l=0;l<o.size;++l)n.push({name:o.name.replace(\"[0]\",\"[\"+l+\"]\"),type:s});else n.push({name:o.name,type:s})}}return n},r.attributes=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_ATTRIBUTES),n=[],i=0;i<r;++i){var o=t.getActiveAttrib(e,i);o&&n.push({name:o.name,type:a(t,o.type)})}return n};var n={FLOAT:\"float\",FLOAT_VEC2:\"vec2\",FLOAT_VEC3:\"vec3\",FLOAT_VEC4:\"vec4\",INT:\"int\",INT_VEC2:\"ivec2\",INT_VEC3:\"ivec3\",INT_VEC4:\"ivec4\",BOOL:\"bool\",BOOL_VEC2:\"bvec2\",BOOL_VEC3:\"bvec3\",BOOL_VEC4:\"bvec4\",FLOAT_MAT2:\"mat2\",FLOAT_MAT3:\"mat3\",FLOAT_MAT4:\"mat4\",SAMPLER_2D:\"sampler2D\",SAMPLER_CUBE:\"samplerCube\"},i=null;function a(t,e){if(!i){var r=Object.keys(n);i={};for(var a=0;a<r.length;++a){var o=r[a];i[t[o]]=n[o]}}return i[e]}},{}],307:[function(t,e,r){\"use strict\";r.shader=function(t,e,r){return u(t).getShaderReference(e,r)},r.program=function(t,e,r,n,i){return u(t).getProgram(e,r,n,i)};var n=t(\"./GLError\"),i=t(\"gl-format-compiler-error\"),a=new(\"undefined\"==typeof WeakMap?t(\"weakmap-shim\"):WeakMap),o=0;function s(t,e,r,n,i,a,o){this.id=t,this.src=e,this.type=r,this.shader=n,this.count=a,this.programs=[],this.cache=o}function l(t){this.gl=t,this.shaders=[{},{}],this.programs={}}s.prototype.dispose=function(){if(0==--this.count){for(var t=this.cache,e=t.gl,r=this.programs,n=0,i=r.length;n<i;++n){var a=t.programs[r[n]];a&&(delete t.programs[n],e.deleteProgram(a))}e.deleteShader(this.shader),delete t.shaders[this.type===e.FRAGMENT_SHADER|0][this.src]}};var c=l.prototype;function u(t){var e=a.get(t);return e||(e=new l(t),a.set(t,e)),e}c.getShaderReference=function(t,e){var r=this.gl,a=this.shaders[t===r.FRAGMENT_SHADER|0],l=a[e];if(l&&r.isShader(l.shader))l.count+=1;else{var c=function(t,e,r){var a=t.createShader(e);if(t.shaderSource(a,r),t.compileShader(a),!t.getShaderParameter(a,t.COMPILE_STATUS)){var o=t.getShaderInfoLog(a);try{var s=i(o,r,e)}catch(t){throw console.warn(\"Failed to format compiler error: \"+t),new n(o,\"Error compiling shader:\\n\"+o)}throw new n(o,s.short,s.long)}return a}(r,t,e);l=a[e]=new s(o++,e,t,c,[],1,this)}return l},c.getProgram=function(t,e,r,i){var a=[t.id,e.id,r.join(\":\"),i.join(\":\")].join(\"@\"),o=this.programs[a];return o&&this.gl.isProgram(o)||(this.programs[a]=o=function(t,e,r,i,a){var o=t.createProgram();t.attachShader(o,e),t.attachShader(o,r);for(var s=0;s<i.length;++s)t.bindAttribLocation(o,a[s],i[s]);if(t.linkProgram(o),!t.getProgramParameter(o,t.LINK_STATUS)){var l=t.getProgramInfoLog(o);throw new n(l,\"Error linking program: \"+l)}return o}(this.gl,t.shader,e.shader,r,i),t.programs.push(a),e.programs.push(a)),o}},{\"./GLError\":302,\"gl-format-compiler-error\":250,\"weakmap-shim\":555}],308:[function(t,e,r){\"use strict\";function n(t){this.plot=t,this.enable=[!0,!0,!1,!1],this.width=[1,1,1,1],this.color=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.center=[1/0,1/0]}e.exports=function(t,e){var r=new n(t);return r.update(e),t.addOverlay(r),r};var i=n.prototype;i.update=function(t){t=t||{},this.enable=(t.enable||[!0,!0,!1,!1]).slice(),this.width=(t.width||[1,1,1,1]).slice(),this.color=(t.color||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]).map(function(t){return t.slice()}),this.center=(t.center||[1/0,1/0]).slice(),this.plot.setOverlayDirty()},i.draw=function(){var t=this.enable,e=this.width,r=this.color,n=this.center,i=this.plot,a=i.line,o=i.dataBox,s=i.viewBox;if(a.bind(),o[0]<=n[0]&&n[0]<=o[2]&&o[1]<=n[1]&&n[1]<=o[3]){var l=s[0]+(n[0]-o[0])/(o[2]-o[0])*(s[2]-s[0]),c=s[1]+(n[1]-o[1])/(o[3]-o[1])*(s[3]-s[1]);t[0]&&a.drawLine(l,c,s[0],c,e[0],r[0]),t[1]&&a.drawLine(l,c,l,s[1],e[1],r[1]),t[2]&&a.drawLine(l,c,s[2],c,e[2],r[2]),t[3]&&a.drawLine(l,c,l,s[3],e[3],r[3])}},i.dispose=function(){this.plot.removeOverlay(this)}},{}],309:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, color;\\nattribute float weight;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 coordinates[3];\\nuniform vec4 colors[3];\\nuniform vec2 screenShape;\\nuniform float lineWidth;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vertexPosition = mix(coordinates[0],\\n    mix(coordinates[2], coordinates[1], 0.5 * (position + 1.0)), abs(position));\\n\\n  vec4 clipPos = projection * view * model * vec4(vertexPosition, 1.0);\\n  vec2 clipOffset = (projection * view * model * vec4(color, 0.0)).xy;\\n  vec2 delta = weight * clipOffset * screenShape;\\n  vec2 lineOffset = normalize(vec2(delta.y, -delta.x)) / screenShape;\\n\\n  gl_Position   = vec4(clipPos.xy + clipPos.w * 0.5 * lineWidth * lineOffset, clipPos.z, clipPos.w);\\n  fragColor     = color.x * colors[0] + color.y * colors[1] + color.z * colors[2];\\n}\\n\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  gl_FragColor = fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec3\"},{name:\"weight\",type:\"float\"}])}},{\"gl-shader\":301,glslify:409}],310:[function(t,e,r){\"use strict\";var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\");e.exports=function(t,e){var r=[];function o(t,e,n,i,a,o){var s=[t,e,n,0,0,0,1];s[i+3]=1,s[i]=a,r.push.apply(r,s),s[6]=-1,r.push.apply(r,s),s[i]=o,r.push.apply(r,s),r.push.apply(r,s),s[6]=1,r.push.apply(r,s),s[i]=a,r.push.apply(r,s)}o(0,0,0,0,0,1),o(0,0,0,1,0,1),o(0,0,0,2,0,1),o(1,0,0,1,-1,1),o(1,0,0,2,-1,1),o(0,1,0,0,-1,1),o(0,1,0,2,-1,1),o(0,0,1,0,-1,1),o(0,0,1,1,-1,1);var l=n(t,r),c=i(t,[{type:t.FLOAT,buffer:l,size:3,offset:0,stride:28},{type:t.FLOAT,buffer:l,size:3,offset:12,stride:28},{type:t.FLOAT,buffer:l,size:1,offset:24,stride:28}]),u=a(t);u.attributes.position.location=0,u.attributes.color.location=1,u.attributes.weight.location=2;var h=new s(t,l,c,u);return h.update(e),h};var o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n,this.pixelRatio=1,this.bounds=[[-1e3,-1e3,-1e3],[1e3,1e3,1e3]],this.position=[0,0,0],this.lineWidth=[2,2,2],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.enabled=[!0,!0,!0],this.drawSides=[!0,!0,!0],this.axes=null}var l=s.prototype,c=[0,0,0],u=[0,0,0],h=[0,0];l.isTransparent=function(){return!1},l.drawTransparent=function(t){},l.draw=function(t){var e=this.gl,r=this.vao,n=this.shader;r.bind(),n.bind();var i,a=t.model||o,s=t.view||o,l=t.projection||o;this.axes&&(i=this.axes.lastCubeProps.axis);for(var f=c,p=u,d=0;d<3;++d)i&&i[d]<0?(f[d]=this.bounds[0][d],p[d]=this.bounds[1][d]):(f[d]=this.bounds[1][d],p[d]=this.bounds[0][d]);h[0]=e.drawingBufferWidth,h[1]=e.drawingBufferHeight,n.uniforms.model=a,n.uniforms.view=s,n.uniforms.projection=l,n.uniforms.coordinates=[this.position,f,p],n.uniforms.colors=this.colors,n.uniforms.screenShape=h;for(d=0;d<3;++d)n.uniforms.lineWidth=this.lineWidth[d]*this.pixelRatio,this.enabled[d]&&(r.draw(e.TRIANGLES,6,6*d),this.drawSides[d]&&r.draw(e.TRIANGLES,12,18+12*d));r.unbind()},l.update=function(t){t&&(\"bounds\"in t&&(this.bounds=t.bounds),\"position\"in t&&(this.position=t.position),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"colors\"in t&&(this.colors=t.colors),\"enabled\"in t&&(this.enabled=t.enabled),\"drawSides\"in t&&(this.drawSides=t.drawSides))},l.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders/index\":309,\"gl-buffer\":241,\"gl-vao\":327}],311:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\nuniform float vectorScale;\\nuniform float tubeScale;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * tubePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal,0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(tubePosition, 1.0);\\n  vec4 t_position  = view * tubePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = tubePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular\\n            , opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform float tubeScale;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  gl_Position = projection * view * tubePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec4\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec4\"}]}},{glslify:409}],312:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./shaders\"),g=d.meshShader,v=d.pickShader,m=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function y(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,y,x,b,_,w,k,T){this.gl=t,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=i,this.triangleVectors=a,this.triangleColors=s,this.triangleNormals=c,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=u,this.triangleCount=0,this.lineWidth=1,this.edgePositions=h,this.edgeColors=p,this.edgeUVs=d,this.edgeIds=f,this.edgeVAO=g,this.edgeCount=0,this.pointPositions=v,this.pointColors=x,this.pointUVs=b,this.pointSizes=_,this.pointIds=y,this.pointVAO=w,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=k,this.contourVAO=T,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!1,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.tubeScale=1,this._model=m,this._view=m,this._projection=m,this._resolution=[1,1],this.pixelRatio=1}var x=y.prototype;function b(t){var e=n(t,v.vertex,v.fragment,null,v.attributes);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.vector.location=5,e}x.isOpaque=function(){return this.opacity>=1},x.isTransparent=function(){return this.opacity<1},x.pickSlots=1,x.setPickBase=function(t){this.pickId=t},x.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=i[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},x.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=h({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return u(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,i=t.vectors;if(n&&r&&i){void 0!==t.tubeScale&&(this.tubeScale=t.tubeScale);var a=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[],w=[],k=[];this.cells=r,this.positions=n,this.vectors=i;var T=t.vertexNormals,A=t.cellNormals,M=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,S=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!A&&(A=s.faceNormals(r,n,S)),A||T||(T=s.vertexNormals(r,n,M));var E=t.vertexColors,C=t.cellColors,L=t.meshColor||[1,1,1,1],P=t.vertexUVs,O=t.vertexIntensity,z=t.cellUVs,I=t.cellIntensity,D=1/0,R=-1/0;if(!P&&!z)if(O)if(t.vertexIntensityBounds)D=+t.vertexIntensityBounds[0],R=+t.vertexIntensityBounds[1];else for(var F=0;F<O.length;++F){var B=O[F];D=Math.min(D,B),R=Math.max(R,B)}else if(I)for(F=0;F<I.length;++F){B=I[F];D=Math.min(D,B),R=Math.max(R,B)}else for(F=0;F<n.length;++F){B=n[F][2];D=Math.min(D,B),R=Math.max(R,B)}this.intensity=O||(I?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,I):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var N=t.pointSizes,j=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(F=0;F<n.length;++F)for(var U=n[F],V=0;V<3;++V)!isNaN(U[V])&&isFinite(U[V])&&(this.bounds[0][V]=Math.min(this.bounds[0][V],U[V]),this.bounds[1][V]=Math.max(this.bounds[1][V],U[V]));var q=0,H=0,G=0;t:for(F=0;F<r.length;++F){var Y=r[F];switch(Y.length){case 1:for(U=n[X=Y[0]],V=0;V<3;++V)if(isNaN(U[V])||!isFinite(U[V]))continue t;x.push(U[0],U[1],U[2],U[3]),3===(Z=E?E[X]:C?C[F]:L).length?b.push(Z[0],Z[1],Z[2],1):b.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],_.push(J[0],J[1]),N?w.push(N[X]):w.push(j),k.push(F),G+=1;break;case 2:for(V=0;V<2;++V){U=n[X=Y[V]];for(var W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t}for(V=0;V<2;++V){U=n[X=Y[V]];g.push(U[0],U[1],U[2]),3===(Z=E?E[X]:C?C[F]:L).length?v.push(Z[0],Z[1],Z[2],1):v.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],m.push(J[0],J[1]),y.push(F)}H+=1;break;case 3:for(V=0;V<3;++V)for(U=n[X=Y[V]],W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t;for(V=0;V<3;++V){var X;U=n[X=Y[2-V]];a.push(U[0],U[1],U[2],U[3]);var Z,J,K,$=i[X];l.push($[0],$[1],$[2],$[3]),3===(Z=E?E[X]:C?C[F]:L).length?c.push(Z[0],Z[1],Z[2],1):c.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],p.push(J[0],J[1]),K=T?T[X]:A[F],f.push(K[0],K[1],K[2]),d.push(F)}q+=1}}this.pointCount=G,this.edgeCount=H,this.triangleCount=q,this.pointPositions.update(x),this.pointColors.update(b),this.pointUVs.update(_),this.pointSizes.update(w),this.pointIds.update(new Uint32Array(k)),this.edgePositions.update(g),this.edgeColors.update(v),this.edgeUVs.update(m),this.edgeIds.update(new Uint32Array(y)),this.trianglePositions.update(a),this.triangleVectors.update(l),this.triangleColors.update(c),this.triangleUVs.update(p),this.triangleNormals.update(f),this.triangleIds.update(new Uint32Array(d))}},x.drawTransparent=x.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:m.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,tubeScale:this.tubeScale,contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var f=u[12+o],p=0;p<3;++p)f+=u[4*p+o]*this.lightPosition[p];s.lightPosition[o]=f/h}if(this.triangleCount>0){var d=this.triShader;d.bind(),d.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},x.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:i,clipBounds:a,tubeScale:this.tubeScale,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind())},x.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3);return{index:e,position:n,intensity:this.intensity[r[1]],velocity:this.vectors[r[1]].slice(0,3),divergence:this.vectors[r[1]][3],dataCoordinate:n}},x.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose()},e.exports=function(t,e){1===arguments.length&&(t=(e=t).gl);var r=e.triShader||function(t){var e=n(t,g.vertex,g.fragment,null,g.attributes);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.vector.location=5,e}(t),s=b(t),l=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));l.generateMipmap(),l.minFilter=t.LINEAR_MIPMAP_LINEAR,l.magFilter=t.LINEAR;var c=i(t),h=i(t),f=i(t),p=i(t),d=i(t),v=i(t),m=a(t,[{buffer:c,type:t.FLOAT,size:4},{buffer:v,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:f,type:t.FLOAT,size:4},{buffer:p,type:t.FLOAT,size:2},{buffer:d,type:t.FLOAT,size:3},{buffer:h,type:t.FLOAT,size:4}]),x=i(t),_=i(t),w=i(t),k=i(t),T=a(t,[{buffer:x,type:t.FLOAT,size:3},{buffer:k,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:_,type:t.FLOAT,size:4},{buffer:w,type:t.FLOAT,size:2}]),A=i(t),M=i(t),S=i(t),E=i(t),C=i(t),L=a(t,[{buffer:A,type:t.FLOAT,size:3},{buffer:C,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:M,type:t.FLOAT,size:4},{buffer:S,type:t.FLOAT,size:2},{buffer:E,type:t.FLOAT,size:1}]),P=i(t),O=new y(t,l,r,s,c,h,v,f,p,d,m,x,k,_,w,T,A,C,M,S,E,L,P,a(t,[{buffer:P,type:t.FLOAT,size:3}]));return O.update(e),O}},{\"./shaders\":311,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-shader\":301,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,normals:453,\"simplicial-complex-contour\":518,\"typedarray-pool\":545}],313:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\"),i=t(\"gl-vec4\"),a=function(t,e,r,a){for(var o=0,s=0;s<t.length;s++)for(var l=t[s].velocities,c=0;c<l.length;c++){var u=n.length(l[c]);u>o&&(o=u)}var h=t.map(function(t){return function(t,e,r,a){var o,s,l,c=t.points,u=t.velocities,h=t.divergences;n.set(n.create(),0,1,0),n.create(),n.create();n.create();for(var f=[],p=[],d=[],g=[],v=[],m=[],y=0,x=0,b=i.create(),_=i.create(),w=0;w<c.length;w++){o=c[w],s=u[w],l=h[w],0===e&&(l=.05*r),x=n.length(s)/a,b=i.create(),n.copy(b,s),b[3]=l;for(var k=0;k<8;k++)v[k]=[o[0],o[1],o[2],k];if(g.length>0)for(k=0;k<8;k++){var T=(k+1)%8;f.push(g[k],v[k],v[T],v[T],g[T],g[k]),d.push(_,b,b,b,_,_),m.push(y,x,x,x,y,y),p.push([f.length-6,f.length-5,f.length-4],[f.length-3,f.length-2,f.length-1])}var A=g;g=v,v=A,A=_,_=b,b=A,A=y,y=x,x=A}return{positions:f,cells:p,vectors:d,vertexIntensity:m}}(t,r,a,o)}),f=[],p=[],d=[],g=[];for(s=0;s<h.length;s++){var v=h[s],m=f.length;f=f.concat(v.positions),d=d.concat(v.vectors),g=g.concat(v.vertexIntensity);for(c=0;c<v.cells.length;c++){var y=v.cells[c],x=[];p.push(x);for(var b=0;b<y.length;b++)x.push(y[b]+m)}}return{positions:f,cells:p,vectors:d,vertexIntensity:g,colormap:e}},o=function(t,e){var r=n.create(),i=1e-4;n.add(r,t,[i,0,0]);var a=this.getVelocity(r);n.subtract(a,a,e),n.scale(a,a,1e4),n.add(r,t,[0,i,0]);var o=this.getVelocity(r);n.subtract(o,o,e),n.scale(o,o,1e4),n.add(r,t,[0,0,i]);var s=this.getVelocity(r);return n.subtract(s,s,e),n.scale(s,s,1e4),n.add(r,a,o),n.add(r,r,s),r},s=function(t){return f(t,this.vectors,this.meshgrid,this.clampBorders)},l=function(t,e){for(var r=0;r<t.length;r++){var n=t[r];if(n===e)return r;if(n>e)return r-1}return r},c=n.create(),u=n.create(),h=function(t,e,r){return t<e?e:t>r?r:t},f=function(t,e,r,i){var a=t[0],o=t[1],s=t[2],f=r[0].length,p=r[1].length,d=r[2].length,g=l(r[0],a),v=l(r[1],o),m=l(r[2],s),y=g+1,x=v+1,b=m+1;if(r[0][g]===a&&(y=g),r[1][v]===o&&(x=v),r[2][m]===s&&(b=m),i&&(g=h(g,0,f-1),y=h(y,0,f-1),v=h(v,0,p-1),x=h(x,0,p-1),m=h(m,0,d-1),b=h(b,0,d-1)),g<0||v<0||m<0||y>=f||x>=p||b>=d)return n.create();var _=(a-r[0][g])/(r[0][y]-r[0][g]),w=(o-r[1][v])/(r[1][x]-r[1][v]),k=(s-r[2][m])/(r[2][b]-r[2][m]);(_<0||_>1||isNaN(_))&&(_=0),(w<0||w>1||isNaN(w))&&(w=0),(k<0||k>1||isNaN(k))&&(k=0);var T=m*f*p,A=b*f*p,M=v*f,S=x*f,E=g,C=y,L=e[M+T+E],P=e[M+T+C],O=e[S+T+E],z=e[S+T+C],I=e[M+A+E],D=e[M+A+C],R=e[S+A+E],F=e[S+A+C],B=n.create();return n.lerp(B,L,P,_),n.lerp(c,O,z,_),n.lerp(B,B,c,w),n.lerp(c,I,D,_),n.lerp(u,R,F,_),n.lerp(c,c,u,w),n.lerp(B,B,c,k),B},p=function(t){var e=1/0;t.sort(function(t,e){return t-e});for(var r=1;r<t.length;r++){var n=Math.abs(t[r]-t[r-1]);n<e&&(e=n)}return e};e.exports=function(t,e){var r=t.startingPositions,i=t.maxLength||1e3,l=t.tubeSize||1,c=t.absoluteTubeSize;t.getDivergence||(t.getDivergence=o),t.getVelocity||(t.getVelocity=s),void 0===t.clampBorders&&(t.clampBorders=!0);var u=[],h=e[0][0],f=e[0][1],d=e[0][2],g=e[1][0],v=e[1][1],m=e[1][2],y=function(t,e){var r=e[0],n=e[1],i=e[2];return r>=h&&r<=g&&n>=f&&n<=v&&i>=d&&i<=m},x=10*n.distance(e[0],e[1])/i,b=x*x,_=1,w=0;n.create();r.length>=2&&(_=function(t){for(var e=[],r=[],n=[],i={},a={},o={},s=0;s<t.length;s++){var l=t[s],c=l[0],u=l[1],h=l[2];i[c]||(e.push(c),i[c]=!0),a[u]||(r.push(u),a[u]=!0),o[h]||(n.push(h),o[h]=!0)}var f=p(e),d=p(r),g=p(n),v=Math.min(f,d,g);return isFinite(v)?v:1}(r));for(var k=0;k<r.length;k++){var T=n.create();n.copy(T,r[k]);var A=[T],M=[],S=t.getVelocity(T),E=T;M.push(S);var C=[],L=t.getDivergence(T,S);(I=n.length(L))>w&&!isNaN(I)&&isFinite(I)&&(w=I),C.push(I),u.push({points:A,velocities:M,divergences:C});for(var P=0;P<100*i&&A.length<i&&y(0,T);){P++;var O=n.clone(S),z=n.squaredLength(O);if(0===z)break;if(z>b&&n.scale(O,O,x/Math.sqrt(z)),n.add(O,O,T),S=t.getVelocity(O),n.squaredDistance(E,O)-b>-1e-4*b){A.push(O),E=O,M.push(S);L=t.getDivergence(O,S);(I=n.length(L))>w&&!isNaN(I)&&isFinite(I)&&(w=I),C.push(I)}T=O}}for(k=0;k<C.length;k++){var I=C[k];!isNaN(I)&&isFinite(I)||(C[k]=w)}var D=a(u,t.colormap,w,_);return c?D.tubeScale=c:(0===w&&(w=1),D.tubeScale=.5*l*_/w),D},e.exports.createTubeMesh=t(\"./lib/tubemesh\")},{\"./lib/tubemesh\":312,\"gl-vec3\":346,\"gl-vec4\":382}],314:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute vec3 f;\\nattribute vec3 normal;\\n\\nuniform vec3 objectOffset;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 lightPosition, eyePosition;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 localCoordinate = vec3(uv.zw, f.x);\\n  worldCoordinate = objectOffset + localCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n  vec4 clipPosition = projection * view * worldPosition;\\n  gl_Position = clipPosition;\\n  kill = f.y;\\n  value = f.z;\\n  planeCoordinate = uv.xy;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * worldPosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  lightDirection = lightPosition - cameraCoordinate.xyz;\\n  eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  surfaceNormal  = normalize((vec4(normal,0) * inverseModel).xyz);\\n}\\n\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat beckmannSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness) {\\n  return beckmannDistribution(dot(surfaceNormal, normalize(lightDirection + viewDirection)), roughness);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 lowerBound, upperBound;\\nuniform float contourTint;\\nuniform vec4 contourColor;\\nuniform sampler2D colormap;\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform float vertexColor;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec3 N = normalize(surfaceNormal);\\n  vec3 V = normalize(eyeDirection);\\n  vec3 L = normalize(lightDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = max(beckmannSpecular(L, V, N, roughness), 0.);\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  //decide how to interpolate color \\u2014 in vertex or in fragment\\n  vec4 surfaceColor =\\n    step(vertexColor, .5) * texture2D(colormap, vec2(value, value)) +\\n    step(.5, vertexColor) * vColor;\\n\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = mix(litColor, contourColor, contourTint) * opacity;\\n}\\n\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute float f;\\n\\nuniform vec3 objectOffset;\\nuniform mat3 permutation;\\nuniform mat4 model, view, projection;\\nuniform float height, zOffset;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 dataCoordinate = permutation * vec3(uv.xy, height);\\n  worldCoordinate = objectOffset + dataCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n\\n  vec4 clipPosition = projection * view * worldPosition;\\n  clipPosition.z += zOffset;\\n\\n  gl_Position = clipPosition;\\n  value = f + objectOffset.z;\\n  kill = -1.0;\\n  planeCoordinate = uv.zw;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Don't do lighting for contours\\n  surfaceNormal   = vec3(1,0,0);\\n  eyeDirection    = vec3(0,1,0);\\n  lightDirection  = vec3(0,0,1);\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec2 shape;\\nuniform vec3 clipBounds[2];\\nuniform float pickId;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 surfaceNormal;\\n\\nvec2 splitFloat(float v) {\\n  float vh = 255.0 * v;\\n  float upper = floor(vh);\\n  float lower = fract(vh);\\n  return vec2(upper / 255.0, floor(lower * 16.0) / 16.0);\\n}\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec2 ux = splitFloat(planeCoordinate.x / shape.x);\\n  vec2 uy = splitFloat(planeCoordinate.y / shape.y);\\n  gl_FragColor = vec4(pickId, ux.x, uy.x, ux.y + (uy.y/16.0));\\n}\\n\"]);r.createShader=function(t){var e=n(t,a,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createPickShader=function(t){var e=n(t,a,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createContourShader=function(t){var e=n(t,s,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e},r.createPickContourShader=function(t){var e=n(t,s,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e}},{\"gl-shader\":301,glslify:409}],315:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],316:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=y(e),n=b(e),s=x(e),l=_(e),c=i(e),u=a(e,[{buffer:c,size:4,stride:w,offset:0},{buffer:c,size:3,stride:w,offset:16},{buffer:c,size:3,stride:w,offset:28}]),h=i(e),f=a(e,[{buffer:h,size:4,stride:20,offset:0},{buffer:h,size:1,stride:20,offset:16}]),p=i(e),d=a(e,[{buffer:p,size:2,type:e.FLOAT}]),g=o(e,1,S,e.RGBA,e.UNSIGNED_BYTE);g.minFilter=e.LINEAR,g.magFilter=e.LINEAR;var v=new E(e,[0,0],[[0,0,0],[0,0,0]],r,n,c,u,g,s,l,h,f,p,d,[0,0,0]),m={levels:[[],[],[]]};for(var k in t)m[k]=t[k];return m.colormap=m.colormap||\"jet\",v.update(m),v};var n=t(\"bit-twiddle\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"typedarray-pool\"),l=t(\"colormap\"),c=t(\"ndarray-ops\"),u=t(\"ndarray-pack\"),h=t(\"ndarray\"),f=t(\"surface-nets\"),p=t(\"gl-mat4/multiply\"),d=t(\"gl-mat4/invert\"),g=t(\"binary-search-bounds\"),v=t(\"ndarray-gradient\"),m=t(\"./lib/shaders\"),y=m.createShader,x=m.createContourShader,b=m.createPickShader,_=m.createPickContourShader,w=40,k=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1],T=[[0,0],[0,1],[1,0],[1,1],[1,0],[0,1]],A=[[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0]];function M(t,e,r,n,i){this.position=t,this.index=e,this.uv=r,this.level=n,this.dataCoordinate=i}!function(){for(var t=0;t<3;++t){var e=A[t],r=(t+2)%3;e[(t+1)%3+0]=1,e[r+3]=1,e[t+6]=1}}();var S=256;function E(t,e,r,n,i,a,o,l,c,u,f,p,d,g,v){this.gl=t,this.shape=e,this.bounds=r,this.objectOffset=v,this.intensityBounds=[],this._shader=n,this._pickShader=i,this._coordinateBuffer=a,this._vao=o,this._colorMap=l,this._contourShader=c,this._contourPickShader=u,this._contourBuffer=f,this._contourVAO=p,this._contourOffsets=[[],[],[]],this._contourCounts=[[],[],[]],this._vertexCount=0,this._pickResult=new M([0,0,0],[0,0],[0,0],[0,0,0],[0,0,0]),this._dynamicBuffer=d,this._dynamicVAO=g,this._dynamicOffsets=[0,0,0],this._dynamicCounts=[0,0,0],this.contourWidth=[1,1,1],this.contourLevels=[[1],[1],[1]],this.contourTint=[0,0,0],this.contourColor=[[.5,.5,.5,1],[.5,.5,.5,1],[.5,.5,.5,1]],this.showContour=!0,this.showSurface=!0,this.enableHighlight=[!0,!0,!0],this.highlightColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.highlightTint=[1,1,1],this.highlightLevel=[-1,-1,-1],this.enableDynamic=[!0,!0,!0],this.dynamicLevel=[NaN,NaN,NaN],this.dynamicColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.dynamicTint=[1,1,1],this.dynamicWidth=[1,1,1],this.axesBounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.surfaceProject=[!1,!1,!1],this.contourProject=[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],this.colorBounds=[!1,!1],this._field=[h(s.mallocFloat(1024),[0,0]),h(s.mallocFloat(1024),[0,0]),h(s.mallocFloat(1024),[0,0])],this.pickId=1,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.snapToData=!1,this.pixelRatio=1,this.opacity=1,this.lightPosition=[10,1e4,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.vertexColor=0,this.dirty=!0}var C=E.prototype;C.isTransparent=function(){return this.opacity<1},C.isOpaque=function(){if(this.opacity>=1)return!0;for(var t=0;t<3;++t)if(this._contourCounts[t].length>0||this._dynamicCounts[t]>0)return!0;return!1},C.pickSlots=1,C.setPickBase=function(t){this.pickId=t};var L=[0,0,0],P={showSurface:!1,showContour:!1,projections:[k.slice(),k.slice(),k.slice()],clipBounds:[[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]]]};function O(t,e){var r,n,i,a=e.axes&&e.axes.lastCubeProps.axis||L,o=e.showSurface,s=e.showContour;for(r=0;r<3;++r)for(o=o||e.surfaceProject[r],n=0;n<3;++n)s=s||e.contourProject[r][n];for(r=0;r<3;++r){var l=P.projections[r];for(n=0;n<16;++n)l[n]=0;for(n=0;n<4;++n)l[5*n]=1;l[5*r]=0,l[12+r]=e.axesBounds[+(a[r]>0)][r],p(l,t.model,l);var c=P.clipBounds[r];for(i=0;i<2;++i)for(n=0;n<3;++n)c[i][n]=t.clipBounds[i][n];c[0][r]=-1e8,c[1][r]=1e8}return P.showSurface=o,P.showContour=s,P}var z={model:k,view:k,projection:k,inverseModel:k.slice(),lowerBound:[0,0,0],upperBound:[0,0,0],colorMap:0,clipBounds:[[0,0,0],[0,0,0]],height:0,contourTint:0,contourColor:[0,0,0,1],permutation:[1,0,0,0,1,0,0,0,1],zOffset:-1e-4,objectOffset:[0,0,0],kambient:1,kdiffuse:1,kspecular:1,lightPosition:[1e3,1e3,1e3],eyePosition:[0,0,0],roughness:1,fresnel:1,opacity:1,vertexColor:0},I=k.slice(),D=[1,0,0,0,1,0,0,0,1];function R(t,e){t=t||{};var r=this.gl;r.disable(r.CULL_FACE),this._colorMap.bind(0);var n=z;n.model=t.model||k,n.view=t.view||k,n.projection=t.projection||k,n.lowerBound=[this.bounds[0][0],this.bounds[0][1],this.colorBounds[0]||this.bounds[0][2]],n.upperBound=[this.bounds[1][0],this.bounds[1][1],this.colorBounds[1]||this.bounds[1][2]],n.objectOffset=this.objectOffset,n.contourColor=this.contourColor[0],n.inverseModel=d(n.inverseModel,n.model);for(var i=0;i<2;++i)for(var a=n.clipBounds[i],o=0;o<3;++o)a[o]=Math.min(Math.max(this.clipBounds[i][o],-1e8),1e8);n.kambient=this.ambientLight,n.kdiffuse=this.diffuseLight,n.kspecular=this.specularLight,n.roughness=this.roughness,n.fresnel=this.fresnel,n.opacity=this.opacity,n.height=0,n.permutation=D,n.vertexColor=this.vertexColor;var s=I;for(p(s,n.view,n.model),p(s,n.projection,s),d(s,s),i=0;i<3;++i)n.eyePosition[i]=s[12+i]/s[15];var l=s[15];for(i=0;i<3;++i)l+=this.lightPosition[i]*s[4*i+3];for(i=0;i<3;++i){var c=s[12+i];for(o=0;o<3;++o)c+=s[4*o+i]*this.lightPosition[o];n.lightPosition[i]=c/l}var u=O(n,this);if(u.showSurface&&e===this.opacity<1){for(this._shader.bind(),this._shader.uniforms=n,this._vao.bind(),this.showSurface&&this._vertexCount&&this._vao.draw(r.TRIANGLES,this._vertexCount),i=0;i<3;++i)this.surfaceProject[i]&&this.vertexCount&&(this._shader.uniforms.model=u.projections[i],this._shader.uniforms.clipBounds=u.clipBounds[i],this._vao.draw(r.TRIANGLES,this._vertexCount));this._vao.unbind()}if(u.showContour&&!e){var h=this._contourShader;n.kambient=1,n.kdiffuse=0,n.kspecular=0,n.opacity=1,h.bind(),h.uniforms=n;var f=this._contourVAO;for(f.bind(),i=0;i<3;++i)for(h.uniforms.permutation=A[i],r.lineWidth(this.contourWidth[i]*this.pixelRatio),o=0;o<this.contourLevels[i].length;++o)o===this.highlightLevel[i]?(h.uniforms.contourColor=this.highlightColor[i],h.uniforms.contourTint=this.highlightTint[i]):0!==o&&o-1!==this.highlightLevel[i]||(h.uniforms.contourColor=this.contourColor[i],h.uniforms.contourTint=this.contourTint[i]),this._contourCounts[i][o]&&(h.uniforms.height=this.contourLevels[i][o],f.draw(r.LINES,this._contourCounts[i][o],this._contourOffsets[i][o]));for(i=0;i<3;++i)for(h.uniforms.model=u.projections[i],h.uniforms.clipBounds=u.clipBounds[i],o=0;o<3;++o)if(this.contourProject[i][o]){h.uniforms.permutation=A[o],r.lineWidth(this.contourWidth[o]*this.pixelRatio);for(var g=0;g<this.contourLevels[o].length;++g)g===this.highlightLevel[o]?(h.uniforms.contourColor=this.highlightColor[o],h.uniforms.contourTint=this.highlightTint[o]):0!==g&&g-1!==this.highlightLevel[o]||(h.uniforms.contourColor=this.contourColor[o],h.uniforms.contourTint=this.contourTint[o]),this._contourCounts[o][g]&&(h.uniforms.height=this.contourLevels[o][g],f.draw(r.LINES,this._contourCounts[o][g],this._contourOffsets[o][g]))}for(f.unbind(),(f=this._dynamicVAO).bind(),i=0;i<3;++i)if(0!==this._dynamicCounts[i])for(h.uniforms.model=n.model,h.uniforms.clipBounds=n.clipBounds,h.uniforms.permutation=A[i],r.lineWidth(this.dynamicWidth[i]*this.pixelRatio),h.uniforms.contourColor=this.dynamicColor[i],h.uniforms.contourTint=this.dynamicTint[i],h.uniforms.height=this.dynamicLevel[i],f.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]),o=0;o<3;++o)this.contourProject[o][i]&&(h.uniforms.model=u.projections[o],h.uniforms.clipBounds=u.clipBounds[o],f.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]));f.unbind()}}C.draw=function(t){return R.call(this,t,!1)},C.drawTransparent=function(t){return R.call(this,t,!0)};var F={model:k,view:k,projection:k,inverseModel:k,clipBounds:[[0,0,0],[0,0,0]],height:0,shape:[0,0],pickId:0,lowerBound:[0,0,0],upperBound:[0,0,0],zOffset:0,objectOffset:[0,0,0],permutation:[1,0,0,0,1,0,0,0,1],lightPosition:[0,0,0],eyePosition:[0,0,0]};function B(t,e){return Array.isArray(t)?[e(t[0]),e(t[1]),e(t[2])]:[e(t),e(t),e(t)]}function N(t){return Array.isArray(t)?3===t.length?[t[0],t[1],t[2],1]:[t[0],t[1],t[2],t[3]]:[0,0,0,1]}function j(t){if(Array.isArray(t)){if(Array.isArray(t))return[N(t[0]),N(t[1]),N(t[2])];var e=N(t);return[e.slice(),e.slice(),e.slice()]}}C.drawPick=function(t){t=t||{};var e=this.gl;e.disable(e.CULL_FACE);var r=F;r.model=t.model||k,r.view=t.view||k,r.projection=t.projection||k,r.shape=this._field[2].shape,r.pickId=this.pickId/255,r.lowerBound=this.bounds[0],r.upperBound=this.bounds[1],r.objectOffset=this.objectOffset,r.permutation=D;for(var n=0;n<2;++n)for(var i=r.clipBounds[n],a=0;a<3;++a)i[a]=Math.min(Math.max(this.clipBounds[n][a],-1e8),1e8);var o=O(r,this);if(o.showSurface){for(this._pickShader.bind(),this._pickShader.uniforms=r,this._vao.bind(),this._vao.draw(e.TRIANGLES,this._vertexCount),n=0;n<3;++n)this.surfaceProject[n]&&(this._pickShader.uniforms.model=o.projections[n],this._pickShader.uniforms.clipBounds=o.clipBounds[n],this._vao.draw(e.TRIANGLES,this._vertexCount));this._vao.unbind()}if(o.showContour){var s=this._contourPickShader;s.bind(),s.uniforms=r;var l=this._contourVAO;for(l.bind(),a=0;a<3;++a)for(e.lineWidth(this.contourWidth[a]*this.pixelRatio),s.uniforms.permutation=A[a],n=0;n<this.contourLevels[a].length;++n)this._contourCounts[a][n]&&(s.uniforms.height=this.contourLevels[a][n],l.draw(e.LINES,this._contourCounts[a][n],this._contourOffsets[a][n]));for(n=0;n<3;++n)for(s.uniforms.model=o.projections[n],s.uniforms.clipBounds=o.clipBounds[n],a=0;a<3;++a)if(this.contourProject[n][a]){s.uniforms.permutation=A[a],e.lineWidth(this.contourWidth[a]*this.pixelRatio);for(var c=0;c<this.contourLevels[a].length;++c)this._contourCounts[a][c]&&(s.uniforms.height=this.contourLevels[a][c],l.draw(e.LINES,this._contourCounts[a][c],this._contourOffsets[a][c]))}l.unbind()}},C.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=this._field[2].shape,r=this._pickResult,n=e[0]*(t.value[0]+(t.value[2]>>4)/16)/255,i=Math.floor(n),a=n-i,o=e[1]*(t.value[1]+(15&t.value[2])/16)/255,s=Math.floor(o),l=o-s;i+=1,s+=1;var c=r.position;c[0]=c[1]=c[2]=0;for(var u=0;u<2;++u)for(var h=u?a:1-a,f=0;f<2;++f)for(var p=i+u,d=s+f,v=h*(f?l:1-l),m=0;m<3;++m)c[m]+=this._field[m].get(p,d)*v;for(var y=this._pickResult.level,x=0;x<3;++x)if(y[x]=g.le(this.contourLevels[x],c[x]),y[x]<0)this.contourLevels[x].length>0&&(y[x]=0);else if(y[x]<this.contourLevels[x].length-1){var b=this.contourLevels[x][y[x]],_=this.contourLevels[x][y[x]+1];Math.abs(b-c[x])>Math.abs(_-c[x])&&(y[x]+=1)}for(r.index[0]=a<.5?i:i+1,r.index[1]=l<.5?s:s+1,r.uv[0]=n/e[0],r.uv[1]=o/e[1],m=0;m<3;++m)r.dataCoordinate[m]=this._field[m].get(r.index[0],r.index[1]);return r},C.padField=function(t,e){var r=e.shape.slice(),n=t.shape.slice();c.assign(t.lo(1,1).hi(r[0],r[1]),e),c.assign(t.lo(1).hi(r[0],1),e.hi(r[0],1)),c.assign(t.lo(1,n[1]-1).hi(r[0],1),e.lo(0,r[1]-1).hi(r[0],1)),c.assign(t.lo(0,1).hi(1,r[1]),e.hi(1)),c.assign(t.lo(n[0]-1,1).hi(1,r[1]),e.lo(r[0]-1)),t.set(0,0,e.get(0,0)),t.set(0,n[1]-1,e.get(0,r[1]-1)),t.set(n[0]-1,0,e.get(r[0]-1,0)),t.set(n[0]-1,n[1]-1,e.get(r[0]-1,r[1]-1))},C.update=function(t){t=t||{},this.objectOffset=t.objectOffset||this.objectOffset,this.dirty=!0,\"contourWidth\"in t&&(this.contourWidth=B(t.contourWidth,Number)),\"showContour\"in t&&(this.showContour=B(t.showContour,Boolean)),\"showSurface\"in t&&(this.showSurface=!!t.showSurface),\"contourTint\"in t&&(this.contourTint=B(t.contourTint,Boolean)),\"contourColor\"in t&&(this.contourColor=j(t.contourColor)),\"contourProject\"in t&&(this.contourProject=B(t.contourProject,function(t){return B(t,Boolean)})),\"surfaceProject\"in t&&(this.surfaceProject=t.surfaceProject),\"dynamicColor\"in t&&(this.dynamicColor=j(t.dynamicColor)),\"dynamicTint\"in t&&(this.dynamicTint=B(t.dynamicTint,Number)),\"dynamicWidth\"in t&&(this.dynamicWidth=B(t.dynamicWidth,Number)),\"opacity\"in t&&(this.opacity=t.opacity),\"colorBounds\"in t&&(this.colorBounds=t.colorBounds),\"vertexColor\"in t&&(this.vertexColor=t.vertexColor?1:0);var e=t.field||t.coords&&t.coords[2]||null,r=!1;if(e||(e=this._field[2].shape[0]||this._field[2].shape[2]?this._field[2].lo(1,1).hi(this._field[2].shape[0]-2,this._field[2].shape[1]-2):this._field[2].hi(0,0)),\"field\"in t||\"coords\"in t){var i=(e.shape[0]+2)*(e.shape[1]+2);i>this._field[2].data.length&&(s.freeFloat(this._field[2].data),this._field[2].data=s.mallocFloat(n.nextPow2(i))),this._field[2]=h(this._field[2].data,[e.shape[0]+2,e.shape[1]+2]),this.padField(this._field[2],e),this.shape=e.shape.slice();for(var a=this.shape,o=0;o<2;++o)this._field[2].size>this._field[o].data.length&&(s.freeFloat(this._field[o].data),this._field[o].data=s.mallocFloat(this._field[2].size)),this._field[o]=h(this._field[o].data,[a[0]+2,a[1]+2]);if(t.coords){var p=t.coords;if(!Array.isArray(p)||3!==p.length)throw new Error(\"gl-surface: invalid coordinates for x/y\");for(o=0;o<2;++o){var d=p[o];for(b=0;b<2;++b)if(d.shape[b]!==a[b])throw new Error(\"gl-surface: coords have incorrect shape\");this.padField(this._field[o],d)}}else if(t.ticks){var g=t.ticks;if(!Array.isArray(g)||2!==g.length)throw new Error(\"gl-surface: invalid ticks\");for(o=0;o<2;++o){var m=g[o];if((Array.isArray(m)||m.length)&&(m=h(m)),m.shape[0]!==a[o])throw new Error(\"gl-surface: invalid tick length\");var y=h(m.data,a);y.stride[o]=m.stride[0],y.stride[1^o]=0,this.padField(this._field[o],y)}}else{for(o=0;o<2;++o){var x=[0,0];x[o]=1,this._field[o]=h(this._field[o].data,[a[0]+2,a[1]+2],x,0)}this._field[0].set(0,0,0);for(var b=0;b<a[0];++b)this._field[0].set(b+1,0,b);for(this._field[0].set(a[0]+1,0,a[0]-1),this._field[1].set(0,0,0),b=0;b<a[1];++b)this._field[1].set(0,b+1,b);this._field[1].set(0,a[1]+1,a[1]-1)}var _=this._field,w=h(s.mallocFloat(3*_[2].size*2),[3,a[0]+2,a[1]+2,2]);for(o=0;o<3;++o)v(w.pick(o),_[o],\"mirror\");var k=h(s.mallocFloat(3*_[2].size),[a[0]+2,a[1]+2,3]);for(o=0;o<a[0]+2;++o)for(b=0;b<a[1]+2;++b){var A=w.get(0,o,b,0),M=w.get(0,o,b,1),E=w.get(1,o,b,0),C=w.get(1,o,b,1),L=w.get(2,o,b,0),P=w.get(2,o,b,1),O=E*P-C*L,z=L*M-P*A,I=A*C-M*E,D=Math.sqrt(O*O+z*z+I*I);D<1e-8?(D=Math.max(Math.abs(O),Math.abs(z),Math.abs(I)))<1e-8?(I=1,z=O=0,D=1):D=1/D:D=1/Math.sqrt(D),k.set(o,b,0,O*D),k.set(o,b,1,z*D),k.set(o,b,2,I*D)}s.free(w.data);var R=[1/0,1/0,1/0],F=[-1/0,-1/0,-1/0],N=1/0,U=-1/0,V=(a[0]-1)*(a[1]-1)*6,q=s.mallocFloat(n.nextPow2(10*V)),H=0,G=0;for(o=0;o<a[0]-1;++o)t:for(b=0;b<a[1]-1;++b){for(var Y=0;Y<2;++Y)for(var W=0;W<2;++W)for(var X=0;X<3;++X){var Z=this._field[X].get(1+o+Y,1+b+W);if(isNaN(Z)||!isFinite(Z))continue t}for(X=0;X<6;++X){var J=o+T[X][0],K=b+T[X][1],$=this._field[0].get(J+1,K+1),Q=this._field[1].get(J+1,K+1);Z=this._field[2].get(J+1,K+1),O=k.get(J+1,K+1,0),z=k.get(J+1,K+1,1),I=k.get(J+1,K+1,2),t.intensity&&(tt=t.intensity.get(J,K));var tt=t.intensity?t.intensity.get(J,K):Z+this.objectOffset[2];q[H++]=J,q[H++]=K,q[H++]=$,q[H++]=Q,q[H++]=Z,q[H++]=0,q[H++]=tt,q[H++]=O,q[H++]=z,q[H++]=I,R[0]=Math.min(R[0],$+this.objectOffset[0]),R[1]=Math.min(R[1],Q+this.objectOffset[1]),R[2]=Math.min(R[2],Z+this.objectOffset[2]),N=Math.min(N,tt),F[0]=Math.max(F[0],$+this.objectOffset[0]),F[1]=Math.max(F[1],Q+this.objectOffset[1]),F[2]=Math.max(F[2],Z+this.objectOffset[2]),U=Math.max(U,tt),G+=1}}for(t.intensityBounds&&(N=+t.intensityBounds[0],U=+t.intensityBounds[1]),o=6;o<H;o+=10)q[o]=(q[o]-N)/(U-N);this._vertexCount=G,this._coordinateBuffer.update(q.subarray(0,H)),s.freeFloat(q),s.free(k.data),this.bounds=[R,F],this.intensity=t.intensity||this._field[2],this.intensityBounds[0]===N&&this.intensityBounds[1]===U||(r=!0),this.intensityBounds=[N,U]}if(\"levels\"in t){var et=t.levels;for(et=Array.isArray(et[0])?et.slice():[[],[],et],o=0;o<3;++o)et[o]=et[o].slice(),et[o].sort(function(t,e){return t-e});for(o=0;o<3;++o)for(b=0;b<et[o].length;++b)et[o][b]-=this.objectOffset[o];t:for(o=0;o<3;++o){if(et[o].length!==this.contourLevels[o].length){r=!0;break}for(b=0;b<et[o].length;++b)if(et[o][b]!==this.contourLevels[o][b]){r=!0;break t}}this.contourLevels=et}if(r){_=this._field,a=this.shape;for(var rt=[],nt=0;nt<3;++nt){var it=this.contourLevels[nt],at=[],ot=[],st=[0,0,0];for(o=0;o<it.length;++o){var lt=f(this._field[nt],it[o]);at.push(rt.length/5|0),G=0;t:for(b=0;b<lt.cells.length;++b){var ct=lt.cells[b];for(X=0;X<2;++X){var ut=lt.positions[ct[X]],ht=ut[0],ft=0|Math.floor(ht),pt=ht-ft,dt=ut[1],gt=0|Math.floor(dt),vt=dt-gt,mt=!1;e:for(var yt=0;yt<3;++yt){st[yt]=0;var xt=(nt+yt+1)%3;for(Y=0;Y<2;++Y){var bt=Y?pt:1-pt;for(J=0|Math.min(Math.max(ft+Y,0),a[0]),W=0;W<2;++W){var _t=W?vt:1-vt;if(K=0|Math.min(Math.max(gt+W,0),a[1]),Z=yt<2?this._field[xt].get(J,K):(this.intensity.get(J,K)-this.intensityBounds[0])/(this.intensityBounds[1]-this.intensityBounds[0]),!isFinite(Z)||isNaN(Z)){mt=!0;break e}var wt=bt*_t;st[yt]+=wt*Z}}}if(mt){if(X>0){for(var kt=0;kt<5;++kt)rt.pop();G-=1}continue t}rt.push(st[0],st[1],ut[0],ut[1],st[2]),G+=1}}ot.push(G)}this._contourOffsets[nt]=at,this._contourCounts[nt]=ot}var Tt=s.mallocFloat(rt.length);for(o=0;o<rt.length;++o)Tt[o]=rt[o];this._contourBuffer.update(Tt),s.freeFloat(Tt)}t.colormap&&this._colorMap.setPixels(function(t){var e=u([l({colormap:t,nshades:S,format:\"rgba\"}).map(function(t){return[t[0],t[1],t[2],255*t[3]]})]);return c.divseq(e,255),e}(t.colormap))},C.dispose=function(){this._shader.dispose(),this._vao.dispose(),this._coordinateBuffer.dispose(),this._colorMap.dispose(),this._contourBuffer.dispose(),this._contourVAO.dispose(),this._contourShader.dispose(),this._contourPickShader.dispose(),this._dynamicBuffer.dispose(),this._dynamicVAO.dispose();for(var t=0;t<3;++t)s.freeFloat(this._field[t].data)},C.highlight=function(t){var e,r;if(!t)return this._dynamicCounts=[0,0,0],this.dyanamicLevel=[NaN,NaN,NaN],void(this.highlightLevel=[-1,-1,-1]);for(e=0;e<3;++e)this.enableHighlight[e]?this.highlightLevel[e]=t.level[e]:this.highlightLevel[e]=-1;for(r=this.snapToData?t.dataCoordinate:t.position,e=0;e<3;++e)r[e]-=this.objectOffset[e];if(this.enableDynamic[0]&&r[0]!==this.dynamicLevel[0]||this.enableDynamic[1]&&r[1]!==this.dynamicLevel[1]||this.enableDynamic[2]&&r[2]!==this.dynamicLevel[2]){for(var n=0,i=this.shape,a=s.mallocFloat(12*i[0]*i[1]),o=0;o<3;++o)if(this.enableDynamic[o]){this.dynamicLevel[o]=r[o];var l=(o+1)%3,c=(o+2)%3,u=this._field[o],h=this._field[l],p=this._field[c],d=f(u,r[o]),g=d.cells,v=d.positions;for(this._dynamicOffsets[o]=n,e=0;e<g.length;++e)for(var m=g[e],y=0;y<2;++y){var x=v[m[y]],b=+x[0],_=0|b,w=0|Math.min(_+1,i[0]),k=b-_,T=1-k,A=+x[1],M=0|A,S=0|Math.min(M+1,i[1]),E=A-M,C=1-E,L=T*C,P=T*E,O=k*C,z=k*E,I=L*h.get(_,M)+P*h.get(_,S)+O*h.get(w,M)+z*h.get(w,S),D=L*p.get(_,M)+P*p.get(_,S)+O*p.get(w,M)+z*p.get(w,S);if(isNaN(I)||isNaN(D)){y&&(n-=1);break}a[2*n+0]=I,a[2*n+1]=D,n+=1}this._dynamicCounts[o]=n-this._dynamicOffsets[o]}else this.dynamicLevel[o]=NaN,this._dynamicCounts[o]=0;this._dynamicBuffer.update(a.subarray(0,2*n)),s.freeFloat(a)}}},{\"./lib/shaders\":314,\"binary-search-bounds\":315,\"bit-twiddle\":92,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,\"ndarray-gradient\":441,\"ndarray-ops\":444,\"ndarray-pack\":445,\"surface-nets\":531,\"typedarray-pool\":545}],317:[function(t,e,r){\"use strict\";var n=t(\"css-font\"),i=t(\"pick-by-alias\"),a=t(\"regl\"),o=t(\"gl-util/context\"),s=t(\"es6-weak-map\"),l=t(\"color-normalize\"),c=t(\"font-atlas\"),u=t(\"typedarray-pool\"),h=t(\"parse-rect\"),f=t(\"is-plain-obj\"),p=t(\"parse-unit\"),d=t(\"to-px\"),g=t(\"detect-kerning\"),v=t(\"object-assign\"),m=t(\"font-measure\"),y=t(\"flatten-vertex-data\"),x=t(\"bit-twiddle\").nextPow2,b=new s,_=!1;if(document.body){var w=document.body.appendChild(document.createElement(\"div\"));w.style.font=\"italic small-caps bold condensed 16px/2 cursive\",getComputedStyle(w).fontStretch&&(_=!0),document.body.removeChild(w)}var k=function(t){!function(t){return\"function\"==typeof t&&t._gl&&t.prop&&t.texture&&t.buffer}(t)?this.gl=o(t):(t={regl:t},this.gl=t.regl._gl),this.shader=b.get(this.gl),this.shader?this.regl=this.shader.regl:this.regl=t.regl||a({gl:this.gl}),this.charBuffer=this.regl.buffer({type:\"uint8\",usage:\"stream\"}),this.sizeBuffer=this.regl.buffer({type:\"float\",usage:\"stream\"}),this.shader||(this.shader=this.createShader(),b.set(this.gl,this.shader)),this.batch=[],this.fontSize=[],this.font=[],this.fontAtlas=[],this.draw=this.shader.draw.bind(this),this.render=function(){this.regl._refresh(),this.draw(this.batch)},this.canvas=this.gl.canvas,this.update(f(t)?t:{})};k.prototype.createShader=function(){var t=this.regl,e=t({blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},stencil:{enable:!1},depth:{enable:!1},count:t.prop(\"count\"),offset:t.prop(\"offset\"),attributes:{charOffset:{offset:4,stride:8,buffer:t.this(\"sizeBuffer\")},width:{offset:0,stride:8,buffer:t.this(\"sizeBuffer\")},char:t.this(\"charBuffer\"),position:t.this(\"position\")},uniforms:{atlasSize:function(t,e){return[e.atlas.width,e.atlas.height]},atlasDim:function(t,e){return[e.atlas.cols,e.atlas.rows]},atlas:function(t,e){return e.atlas.texture},charStep:function(t,e){return e.atlas.step},em:function(t,e){return e.atlas.em},color:t.prop(\"color\"),opacity:t.prop(\"opacity\"),viewport:t.this(\"viewportArray\"),scale:t.this(\"scale\"),align:t.prop(\"align\"),baseline:t.prop(\"baseline\"),translate:t.this(\"translate\"),positionOffset:t.prop(\"positionOffset\")},primitive:\"points\",viewport:t.this(\"viewport\"),vert:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tattribute float width, charOffset, char;\\n\\t\\t\\tattribute vec2 position;\\n\\t\\t\\tuniform float fontSize, charStep, em, align, baseline;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tuniform vec4 color;\\n\\t\\t\\tuniform vec2 atlasSize, atlasDim, scale, translate, positionOffset;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\t\"+(k.normalViewport?\"\":\"vec2 positionOffset = vec2(positionOffset.x,- positionOffset.y);\")+\"\\n\\n\\t\\t\\t\\tvec2 offset = floor(em * (vec2(align + charOffset, baseline)\\n\\t\\t\\t\\t\\t+ positionOffset))\\n\\t\\t\\t\\t\\t/ (viewport.zw * scale.xy);\\n\\n\\t\\t\\t\\tvec2 position = (position + translate) * scale;\\n\\t\\t\\t\\tposition += offset * scale;\\n\\n\\t\\t\\t\\t\"+(k.normalViewport?\"position.y = 1. - position.y;\":\"\")+\"\\n\\n\\t\\t\\t\\tcharCoord = position * viewport.zw + viewport.xy;\\n\\n\\t\\t\\t\\tgl_Position = vec4(position * 2. - 1., 0, 1);\\n\\n\\t\\t\\t\\tgl_PointSize = charStep;\\n\\n\\t\\t\\t\\tcharId.x = mod(char, atlasDim.x);\\n\\t\\t\\t\\tcharId.y = floor(char / atlasDim.x);\\n\\n\\t\\t\\t\\tcharWidth = width * em;\\n\\n\\t\\t\\t\\tfontColor = color / 255.;\\n\\t\\t\\t}\",frag:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tuniform sampler2D atlas;\\n\\t\\t\\tuniform float fontSize, charStep, opacity;\\n\\t\\t\\tuniform vec2 atlasSize;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\n\\t\\t\\tfloat lightness(vec4 color) {\\n\\t\\t\\t\\treturn color.r * 0.299 + color.g * 0.587 + color.b * 0.114;\\n\\t\\t\\t}\\n\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\tvec2 uv = gl_FragCoord.xy - charCoord + charStep * .5;\\n\\t\\t\\t\\tfloat halfCharStep = floor(charStep * .5 + .5);\\n\\n\\t\\t\\t\\t// invert y and shift by 1px (FF expecially needs that)\\n\\t\\t\\t\\tuv.y = charStep - uv.y;\\n\\n\\t\\t\\t\\t// ignore points outside of character bounding box\\n\\t\\t\\t\\tfloat halfCharWidth = ceil(charWidth * .5);\\n\\t\\t\\t\\tif (floor(uv.x) > halfCharStep + halfCharWidth ||\\n\\t\\t\\t\\t\\tfloor(uv.x) < halfCharStep - halfCharWidth) return;\\n\\n\\t\\t\\t\\tuv += charId * charStep;\\n\\t\\t\\t\\tuv = uv / atlasSize;\\n\\n\\t\\t\\t\\tvec4 color = fontColor;\\n\\t\\t\\t\\tvec4 mask = texture2D(atlas, uv);\\n\\n\\t\\t\\t\\tfloat maskY = lightness(mask);\\n\\t\\t\\t\\t// float colorY = lightness(color);\\n\\t\\t\\t\\tcolor.a *= maskY;\\n\\t\\t\\t\\tcolor.a *= opacity;\\n\\n\\t\\t\\t\\t// color.a += .1;\\n\\n\\t\\t\\t\\t// antialiasing, see yiq color space y-channel formula\\n\\t\\t\\t\\t// color.rgb += (1. - color.rgb) * (1. - mask.rgb);\\n\\n\\t\\t\\t\\tgl_FragColor = color;\\n\\t\\t\\t}\"});return{regl:t,draw:e,atlas:{}}},k.prototype.update=function(t){var e=this;if(\"string\"==typeof t)t={text:t};else if(!t)return;null!=(t=i(t,{position:\"position positions coord coords coordinates\",font:\"font fontFace fontface typeface cssFont css-font family fontFamily\",fontSize:\"fontSize fontsize size font-size\",text:\"text texts chars characters value values symbols\",align:\"align alignment textAlign textbaseline\",baseline:\"baseline textBaseline textbaseline\",direction:\"dir direction textDirection\",color:\"color colour fill fill-color fillColor textColor textcolor\",kerning:\"kerning kern\",range:\"range dataBox\",viewport:\"vp viewport viewBox viewbox viewPort\",opacity:\"opacity alpha transparency visible visibility opaque\",offset:\"offset positionOffset padding shift indent indentation\"},!0)).opacity&&(Array.isArray(t.opacity)?this.opacity=t.opacity.map(function(t){return parseFloat(t)}):this.opacity=parseFloat(t.opacity)),null!=t.viewport&&(this.viewport=h(t.viewport),k.normalViewport&&(this.viewport.y=this.canvas.height-this.viewport.y-this.viewport.height),this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null==this.viewport&&(this.viewport={x:0,y:0,width:this.gl.drawingBufferWidth,height:this.gl.drawingBufferHeight},this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null!=t.kerning&&(this.kerning=t.kerning),null!=t.offset&&(\"number\"==typeof t.offset&&(t.offset=[t.offset,0]),this.positionOffset=y(t.offset)),t.direction&&(this.direction=t.direction),t.range&&(this.range=t.range,this.scale=[1/(t.range[2]-t.range[0]),1/(t.range[3]-t.range[1])],this.translate=[-t.range[0],-t.range[1]]),t.scale&&(this.scale=t.scale),t.translate&&(this.translate=t.translate),this.scale||(this.scale=[1/this.viewport.width,1/this.viewport.height]),this.translate||(this.translate=[0,0]),this.font.length||t.font||(t.font=k.baseFontSize+\"px sans-serif\");var r,a=!1,o=!1;if(t.font&&(Array.isArray(t.font)?t.font:[t.font]).forEach(function(t,r){if(\"string\"==typeof t)try{t=n.parse(t)}catch(e){t=n.parse(k.baseFontSize+\"px \"+t)}else t=n.parse(n.stringify(t));var i=n.stringify({size:k.baseFontSize,family:t.family,stretch:_?t.stretch:void 0,variant:t.variant,weight:t.weight,style:t.style}),s=p(t.size),l=Math.round(s[0]*d(s[1]));if(l!==e.fontSize[r]&&(o=!0,e.fontSize[r]=l),!(e.font[r]&&i==e.font[r].baseString||(a=!0,e.font[r]=k.fonts[i],e.font[r]))){var c=t.family.join(\", \"),u=[t.style];t.style!=t.variant&&u.push(t.variant),t.variant!=t.weight&&u.push(t.weight),_&&t.weight!=t.stretch&&u.push(t.stretch),e.font[r]={baseString:i,family:c,weight:t.weight,stretch:t.stretch,style:t.style,variant:t.variant,width:{},kerning:{},metrics:m(c,{origin:\"top\",fontSize:k.baseFontSize,fontStyle:u.join(\" \")})},k.fonts[i]=e.font[r]}}),(a||o)&&this.font.forEach(function(r,i){var a=n.stringify({size:e.fontSize[i],family:r.family,stretch:_?r.stretch:void 0,variant:r.variant,weight:r.weight,style:r.style});if(e.fontAtlas[i]=e.shader.atlas[a],!e.fontAtlas[i]){var o=r.metrics;e.shader.atlas[a]=e.fontAtlas[i]={fontString:a,step:2*Math.ceil(e.fontSize[i]*o.bottom*.5),em:e.fontSize[i],cols:0,rows:0,height:0,width:0,chars:[],ids:{},texture:e.regl.texture()}}null==t.text&&(t.text=e.text)}),\"string\"==typeof t.text&&t.position&&t.position.length>2){for(var s=Array(.5*t.position.length),f=0;f<s.length;f++)s[f]=t.text;t.text=s}if(null!=t.text||a){if(this.textOffsets=[0],Array.isArray(t.text)){this.count=t.text[0].length,this.counts=[this.count];for(var b=1;b<t.text.length;b++)this.textOffsets[b]=this.textOffsets[b-1]+t.text[b-1].length,this.count+=t.text[b].length,this.counts.push(t.text[b].length);this.text=t.text.join(\"\")}else this.text=t.text,this.count=this.text.length,this.counts=[this.count];r=[],this.font.forEach(function(t,n){k.atlasContext.font=t.baseString;for(var i=e.fontAtlas[n],a=0;a<e.text.length;a++){var o=e.text.charAt(a);if(null==i.ids[o]&&(i.ids[o]=i.chars.length,i.chars.push(o),r.push(o)),null==t.width[o]&&(t.width[o]=k.atlasContext.measureText(o).width/k.baseFontSize,e.kerning)){var s=[];for(var l in t.width)s.push(l+o,o+l);v(t.kerning,g(t.family,{pairs:s}))}}})}if(t.position)if(t.position.length>2){for(var w=!t.position[0].length,T=u.mallocFloat(2*this.count),A=0,M=0;A<this.counts.length;A++){var S=this.counts[A];if(w)for(var E=0;E<S;E++)T[M++]=t.position[2*A],T[M++]=t.position[2*A+1];else for(var C=0;C<S;C++)T[M++]=t.position[A][0],T[M++]=t.position[A][1]}this.position.call?this.position({type:\"float\",data:T}):this.position=this.regl.buffer({type:\"float\",data:T}),u.freeFloat(T)}else this.position.destroy&&this.position.destroy(),this.position={constant:t.position};if(t.text||a){var L=u.mallocUint8(this.count),P=u.mallocFloat(2*this.count);this.textWidth=[];for(var O=0,z=0;O<this.counts.length;O++){for(var I=this.counts[O],D=this.font[O]||this.font[0],R=this.fontAtlas[O]||this.fontAtlas[0],F=0;F<I;F++){var B=this.text.charAt(z),N=this.text.charAt(z-1);if(L[z]=R.ids[B],P[2*z]=D.width[B],F){var j=P[2*z-2],U=P[2*z],V=P[2*z-1]+.5*j+.5*U;if(this.kerning){var q=D.kerning[N+B];q&&(V+=.001*q)}P[2*z+1]=V}else P[2*z+1]=.5*P[2*z];z++}this.textWidth.push(P.length?.5*P[2*z-2]+P[2*z-1]:0)}t.align||(t.align=this.align),this.charBuffer({data:L,type:\"uint8\",usage:\"stream\"}),this.sizeBuffer({data:P,type:\"float\",usage:\"stream\"}),u.freeUint8(L),u.freeFloat(P),r.length&&this.font.forEach(function(t,r){var n=e.fontAtlas[r],i=n.step,a=Math.floor(k.maxAtlasSize/i),o=Math.min(a,n.chars.length),s=Math.ceil(n.chars.length/o),l=x(o*i),u=x(s*i);n.width=l,n.height=u,n.rows=s,n.cols=o,n.em&&n.texture({data:c({canvas:k.atlasCanvas,font:n.fontString,chars:n.chars,shape:[l,u],step:[i,i]})})})}if(t.align&&(this.align=t.align,this.alignOffset=this.textWidth.map(function(t,r){var n=Array.isArray(e.align)?e.align.length>1?e.align[r]:e.align[0]:e.align;if(\"number\"==typeof n)return n;switch(n){case\"right\":case\"end\":return-t;case\"center\":case\"centre\":case\"middle\":return.5*-t}return 0})),null==this.baseline&&null==t.baseline&&(t.baseline=0),null!=t.baseline&&(this.baseline=t.baseline,Array.isArray(this.baseline)||(this.baseline=[this.baseline]),this.baselineOffset=this.baseline.map(function(t,r){var n=(e.font[r]||e.font[0]).metrics,i=0;return i+=.5*n.bottom,i+=\"number\"==typeof t?t-n.baseline:-n[t],k.normalViewport||(i*=-1),i})),null!=t.color)if(t.color||(t.color=\"transparent\"),\"string\"!=typeof t.color&&isNaN(t.color)){var H;if(\"number\"==typeof t.color[0]&&t.color.length>this.counts.length){var G=t.color.length;H=u.mallocUint8(G);for(var Y=(t.color.subarray||t.color.slice).bind(t.color),W=0;W<G;W+=4)H.set(l(Y(W,W+4),\"uint8\"),W)}else{var X=t.color.length;H=u.mallocUint8(4*X);for(var Z=0;Z<X;Z++)H.set(l(t.color[Z]||0,\"uint8\"),4*Z)}this.color=H}else this.color=l(t.color,\"uint8\");if(t.position||t.text||t.color||t.baseline||t.align||t.font||t.offset||t.opacity)if(this.color.length>4||this.baselineOffset.length>1||this.align&&this.align.length>1||this.fontAtlas.length>1||this.positionOffset.length>2){var J=Math.max(.5*this.position.length||0,.25*this.color.length||0,this.baselineOffset.length||0,this.alignOffset.length||0,this.font.length||0,this.opacity.length||0,.5*this.positionOffset.length||0);this.batch=Array(J);for(var K=0;K<this.batch.length;K++)this.batch[K]={count:this.counts.length>1?this.counts[K]:this.counts[0],offset:this.textOffsets.length>1?this.textOffsets[K]:this.textOffsets[0],color:this.color?this.color.length<=4?this.color:this.color.subarray(4*K,4*K+4):[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[K]:this.opacity,baseline:null!=this.baselineOffset[K]?this.baselineOffset[K]:this.baselineOffset[0],align:this.align?null!=this.alignOffset[K]?this.alignOffset[K]:this.alignOffset[0]:0,atlas:this.fontAtlas[K]||this.fontAtlas[0],positionOffset:this.positionOffset.length>2?this.positionOffset.subarray(2*K,2*K+2):this.positionOffset}}else this.count?this.batch=[{count:this.count,offset:0,color:this.color||[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[0]:this.opacity,baseline:this.baselineOffset[0],align:this.alignOffset?this.alignOffset[0]:0,atlas:this.fontAtlas[0],positionOffset:this.positionOffset}]:this.batch=[]},k.prototype.destroy=function(){},k.prototype.kerning=!0,k.prototype.position={constant:new Float32Array(2)},k.prototype.translate=null,k.prototype.scale=null,k.prototype.font=null,k.prototype.text=\"\",k.prototype.positionOffset=[0,0],k.prototype.opacity=1,k.prototype.color=new Uint8Array([0,0,0,255]),k.prototype.alignOffset=[0,0],k.normalViewport=!1,k.maxAtlasSize=1024,k.atlasCanvas=document.createElement(\"canvas\"),k.atlasContext=k.atlasCanvas.getContext(\"2d\",{alpha:!1}),k.baseFontSize=64,k.fonts={},e.exports=k},{\"bit-twiddle\":92,\"color-normalize\":120,\"css-font\":139,\"detect-kerning\":166,\"es6-weak-map\":318,\"flatten-vertex-data\":227,\"font-atlas\":228,\"font-measure\":229,\"gl-util/context\":323,\"is-plain-obj\":422,\"object-assign\":454,\"parse-rect\":459,\"parse-unit\":461,\"pick-by-alias\":465,regl:502,\"to-px\":539,\"typedarray-pool\":545}],318:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?WeakMap:t(\"./polyfill\")},{\"./is-implemented\":319,\"./polyfill\":321}],319:[function(t,e,r){\"use strict\";e.exports=function(){var t,e;if(\"function\"!=typeof WeakMap)return!1;try{t=new WeakMap([[e={},\"one\"],[{},\"two\"],[{},\"three\"]])}catch(t){return!1}return\"[object WeakMap]\"===String(t)&&(\"function\"==typeof t.set&&(t.set({},1)===t&&(\"function\"==typeof t.delete&&(\"function\"==typeof t.has&&\"one\"===t.get(e)))))}},{}],320:[function(t,e,r){\"use strict\";e.exports=\"function\"==typeof WeakMap&&\"[object WeakMap]\"===Object.prototype.toString.call(new WeakMap)},{}],321:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/object/set-prototype-of\"),o=t(\"es5-ext/object/valid-object\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"es5-ext/string/random-uniq\"),c=t(\"d\"),u=t(\"es6-iterator/get\"),h=t(\"es6-iterator/for-of\"),f=t(\"es6-symbol\").toStringTag,p=t(\"./is-native-implemented\"),d=Array.isArray,g=Object.defineProperty,v=Object.prototype.hasOwnProperty,m=Object.getPrototypeOf;e.exports=n=function(){var t,e=arguments[0];if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");return t=p&&a&&WeakMap!==n?a(new WeakMap,m(this)):this,i(e)&&(d(e)||(e=u(e))),g(t,\"__weakMapData__\",c(\"c\",\"$weakMap$\"+l())),e?(h(e,function(e){s(e),t.set(e[0],e[1])}),t):t},p&&(a&&a(n,WeakMap),n.prototype=Object.create(WeakMap.prototype,{constructor:c(n)})),Object.defineProperties(n.prototype,{delete:c(function(t){return!!v.call(o(t),this.__weakMapData__)&&(delete t[this.__weakMapData__],!0)}),get:c(function(t){if(v.call(o(t),this.__weakMapData__))return t[this.__weakMapData__]}),has:c(function(t){return v.call(o(t),this.__weakMapData__)}),set:c(function(t,e){return g(o(t),this.__weakMapData__,c(\"c\",e)),this}),toString:c(function(){return\"[object WeakMap]\"})}),g(n.prototype,f,c(\"c\",\"WeakMap\"))},{\"./is-native-implemented\":320,d:151,\"es5-ext/object/is-value\":194,\"es5-ext/object/set-prototype-of\":200,\"es5-ext/object/valid-object\":204,\"es5-ext/object/valid-value\":205,\"es5-ext/string/random-uniq\":210,\"es6-iterator/for-of\":212,\"es6-iterator/get\":213,\"es6-symbol\":219}],322:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"ndarray-ops\"),a=t(\"typedarray-pool\");e.exports=function(t){if(arguments.length<=1)throw new Error(\"gl-texture2d: Missing arguments for texture2d constructor\");o||function(t){o=[t.LINEAR,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_NEAREST],s=[t.NEAREST,t.LINEAR,t.NEAREST_MIPMAP_NEAREST,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_LINEAR],l=[t.REPEAT,t.CLAMP_TO_EDGE,t.MIRRORED_REPEAT]}(t);if(\"number\"==typeof arguments[1])return v(t,arguments[1],arguments[2],arguments[3]||t.RGBA,arguments[4]||t.UNSIGNED_BYTE);if(Array.isArray(arguments[1]))return v(t,0|arguments[1][0],0|arguments[1][1],arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(\"object\"==typeof arguments[1]){var e=arguments[1],r=c(e)?e:e.raw;if(r)return function(t,e,r,n,i,a){var o=g(t);return t.texImage2D(t.TEXTURE_2D,0,i,i,a,e),new f(t,o,r,n,i,a)}(t,r,0|e.width,0|e.height,arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(e.shape&&e.data&&e.stride)return function(t,e){var r=e.dtype,o=e.shape.slice(),s=t.getParameter(t.MAX_TEXTURE_SIZE);if(o[0]<0||o[0]>s||o[1]<0||o[1]>s)throw new Error(\"gl-texture2d: Invalid texture size\");var l=d(o,e.stride.slice()),c=0;\"float32\"===r?c=t.FLOAT:\"float64\"===r?(c=t.FLOAT,l=!1,r=\"float32\"):\"uint8\"===r?c=t.UNSIGNED_BYTE:(c=t.UNSIGNED_BYTE,l=!1,r=\"uint8\");var h,p,v=0;if(2===o.length)v=t.LUMINANCE,o=[o[0],o[1],1],e=n(e.data,o,[e.stride[0],e.stride[1],1],e.offset);else{if(3!==o.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===o[2])v=t.ALPHA;else if(2===o[2])v=t.LUMINANCE_ALPHA;else if(3===o[2])v=t.RGB;else{if(4!==o[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");v=t.RGBA}}c!==t.FLOAT||t.getExtension(\"OES_texture_float\")||(c=t.UNSIGNED_BYTE,l=!1);var m=e.size;if(l)h=0===e.offset&&e.data.length===m?e.data:e.data.subarray(e.offset,e.offset+m);else{var y=[o[2],o[2]*o[0],1];p=a.malloc(m,r);var x=n(p,o,y,0);\"float32\"!==r&&\"float64\"!==r||c!==t.UNSIGNED_BYTE?i.assign(x,e):u(x,e),h=p.subarray(0,m)}var b=g(t);t.texImage2D(t.TEXTURE_2D,0,v,o[0],o[1],0,v,c,h),l||a.free(p);return new f(t,b,o[0],o[1],v,c)}(t,e)}throw new Error(\"gl-texture2d: Invalid arguments for texture2d constructor\")};var o=null,s=null,l=null;function c(t){return\"undefined\"!=typeof HTMLCanvasElement&&t instanceof HTMLCanvasElement||\"undefined\"!=typeof HTMLImageElement&&t instanceof HTMLImageElement||\"undefined\"!=typeof HTMLVideoElement&&t instanceof HTMLVideoElement||\"undefined\"!=typeof ImageData&&t instanceof ImageData}var u=function(t,e){i.muls(t,e,255)};function h(t,e,r){var n=t.gl,i=n.getParameter(n.MAX_TEXTURE_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-texture2d: Invalid texture size\");return t._shape=[e,r],t.bind(),n.texImage2D(n.TEXTURE_2D,0,t.format,e,r,0,t.format,t.type,null),t._mipLevels=[0],t}function f(t,e,r,n,i,a){this.gl=t,this.handle=e,this.format=i,this.type=a,this._shape=[r,n],this._mipLevels=[0],this._magFilter=t.NEAREST,this._minFilter=t.NEAREST,this._wrapS=t.CLAMP_TO_EDGE,this._wrapT=t.CLAMP_TO_EDGE,this._anisoSamples=1;var o=this,s=[this._wrapS,this._wrapT];Object.defineProperties(s,[{get:function(){return o._wrapS},set:function(t){return o.wrapS=t}},{get:function(){return o._wrapT},set:function(t){return o.wrapT=t}}]),this._wrapVector=s;var l=[this._shape[0],this._shape[1]];Object.defineProperties(l,[{get:function(){return o._shape[0]},set:function(t){return o.width=t}},{get:function(){return o._shape[1]},set:function(t){return o.height=t}}]),this._shapeVector=l}var p=f.prototype;function d(t,e){return 3===t.length?1===e[2]&&e[1]===t[0]*t[2]&&e[0]===t[2]:1===e[0]&&e[1]===t[0]}function g(t){var e=t.createTexture();return t.bindTexture(t.TEXTURE_2D,e),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MIN_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MAG_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_S,t.CLAMP_TO_EDGE),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_T,t.CLAMP_TO_EDGE),e}function v(t,e,r,n,i){var a=t.getParameter(t.MAX_TEXTURE_SIZE);if(e<0||e>a||r<0||r>a)throw new Error(\"gl-texture2d: Invalid texture shape\");if(i===t.FLOAT&&!t.getExtension(\"OES_texture_float\"))throw new Error(\"gl-texture2d: Floating point textures not supported on this platform\");var o=g(t);return t.texImage2D(t.TEXTURE_2D,0,n,e,r,0,n,i,null),new f(t,o,e,r,n,i)}Object.defineProperties(p,{minFilter:{get:function(){return this._minFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,t),this._minFilter=t}},magFilter:{get:function(){return this._magFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,t),this._magFilter=t}},mipSamples:{get:function(){return this._anisoSamples},set:function(t){var e=this._anisoSamples;if(this._anisoSamples=0|Math.max(t,1),e!==this._anisoSamples){var r=this.gl.getExtension(\"EXT_texture_filter_anisotropic\");r&&this.gl.texParameterf(this.gl.TEXTURE_2D,r.TEXTURE_MAX_ANISOTROPY_EXT,this._anisoSamples)}return this._anisoSamples}},wrapS:{get:function(){return this._wrapS},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_S,t),this._wrapS=t}},wrapT:{get:function(){return this._wrapT},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_T,t),this._wrapT=t}},wrap:{get:function(){return this._wrapVector},set:function(t){if(Array.isArray(t)||(t=[t,t]),2!==t.length)throw new Error(\"gl-texture2d: Must specify wrap mode for rows and columns\");for(var e=0;e<2;++e)if(l.indexOf(t[e])<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);this._wrapS=t[0],this._wrapT=t[1];var r=this.gl;return this.bind(),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_S,this._wrapS),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_T,this._wrapT),t}},shape:{get:function(){return this._shapeVector},set:function(t){if(Array.isArray(t)){if(2!==t.length)throw new Error(\"gl-texture2d: Invalid texture shape\")}else t=[0|t,0|t];return h(this,0|t[0],0|t[1]),[0|t[0],0|t[1]]}},width:{get:function(){return this._shape[0]},set:function(t){return h(this,t|=0,this._shape[1]),t}},height:{get:function(){return this._shape[1]},set:function(t){return t|=0,h(this,this._shape[0],t),t}}}),p.bind=function(t){var e=this.gl;return void 0!==t&&e.activeTexture(e.TEXTURE0+(0|t)),e.bindTexture(e.TEXTURE_2D,this.handle),void 0!==t?0|t:e.getParameter(e.ACTIVE_TEXTURE)-e.TEXTURE0},p.dispose=function(){this.gl.deleteTexture(this.handle)},p.generateMipmap=function(){this.bind(),this.gl.generateMipmap(this.gl.TEXTURE_2D);for(var t=Math.min(this._shape[0],this._shape[1]),e=0;t>0;++e,t>>>=1)this._mipLevels.indexOf(e)<0&&this._mipLevels.push(e)},p.setPixels=function(t,e,r,o){var s=this.gl;this.bind(),Array.isArray(e)?(o=r,r=0|e[1],e=0|e[0]):(e=e||0,r=r||0),o=o||0;var l=c(t)?t:t.raw;if(l){this._mipLevels.indexOf(o)<0?(s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,this.type,l),this._mipLevels.push(o)):s.texSubImage2D(s.TEXTURE_2D,o,e,r,this.format,this.type,l)}else{if(!(t.shape&&t.stride&&t.data))throw new Error(\"gl-texture2d: Unsupported data type\");if(t.shape.length<2||e+t.shape[1]>this._shape[1]>>>o||r+t.shape[0]>this._shape[0]>>>o||e<0||r<0)throw new Error(\"gl-texture2d: Texture dimensions are out of bounds\");!function(t,e,r,o,s,l,c,h){var f=h.dtype,p=h.shape.slice();if(p.length<2||p.length>3)throw new Error(\"gl-texture2d: Invalid ndarray, must be 2d or 3d\");var g=0,v=0,m=d(p,h.stride.slice());\"float32\"===f?g=t.FLOAT:\"float64\"===f?(g=t.FLOAT,m=!1,f=\"float32\"):\"uint8\"===f?g=t.UNSIGNED_BYTE:(g=t.UNSIGNED_BYTE,m=!1,f=\"uint8\");if(2===p.length)v=t.LUMINANCE,p=[p[0],p[1],1],h=n(h.data,p,[h.stride[0],h.stride[1],1],h.offset);else{if(3!==p.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===p[2])v=t.ALPHA;else if(2===p[2])v=t.LUMINANCE_ALPHA;else if(3===p[2])v=t.RGB;else{if(4!==p[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");v=t.RGBA}p[2]}v!==t.LUMINANCE&&v!==t.ALPHA||s!==t.LUMINANCE&&s!==t.ALPHA||(v=s);if(v!==s)throw new Error(\"gl-texture2d: Incompatible texture format for setPixels\");var y=h.size,x=c.indexOf(o)<0;x&&c.push(o);if(g===l&&m)0===h.offset&&h.data.length===y?x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,h.data):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,h.data):x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,h.data.subarray(h.offset,h.offset+y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,h.data.subarray(h.offset,h.offset+y));else{var b;b=l===t.FLOAT?a.mallocFloat32(y):a.mallocUint8(y);var _=n(b,p,[p[2],p[2]*p[0],1]);g===t.FLOAT&&l===t.UNSIGNED_BYTE?u(_,h):i.assign(_,h),x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,b.subarray(0,y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,b.subarray(0,y)),l===t.FLOAT?a.freeFloat32(b):a.freeUint8(b)}}(s,e,r,o,this.format,this.type,this._mipLevels,t)}}},{ndarray:450,\"ndarray-ops\":444,\"typedarray-pool\":545}],323:[function(t,e,r){(function(r){\"use strict\";var n=t(\"pick-by-alias\");function i(t){if(t.container)if(t.container==document.body)document.body.style.width||(t.canvas.width=t.width||t.pixelRatio*r.innerWidth),document.body.style.height||(t.canvas.height=t.height||t.pixelRatio*r.innerHeight);else{var e=t.container.getBoundingClientRect();t.canvas.width=t.width||e.right-e.left,t.canvas.height=t.height||e.bottom-e.top}}function a(t){return\"function\"==typeof t.getContext&&\"width\"in t&&\"height\"in t}function o(){var t=document.createElement(\"canvas\");return t.style.position=\"absolute\",t.style.top=0,t.style.left=0,t}e.exports=function(t){var e;if(t?\"string\"==typeof t&&(t={container:t}):t={},a(t)?t={container:t}:t=\"string\"==typeof(e=t).nodeName&&\"function\"==typeof e.appendChild&&\"function\"==typeof e.getBoundingClientRect?{container:t}:function(t){return\"function\"==typeof t.drawArrays||\"function\"==typeof t.drawElements}(t)?{gl:t}:n(t,{container:\"container target element el canvas holder parent parentNode wrapper use ref root node\",gl:\"gl context webgl glContext\",attrs:\"attributes attrs contextAttributes\",pixelRatio:\"pixelRatio pxRatio px ratio pxratio pixelratio\",width:\"w width\",height:\"h height\"},!0),t.pixelRatio||(t.pixelRatio=r.pixelRatio||1),t.gl)return t.gl;if(t.canvas&&(t.container=t.canvas.parentNode),t.container){if(\"string\"==typeof t.container){var s=document.querySelector(t.container);if(!s)throw Error(\"Element \"+t.container+\" is not found\");t.container=s}a(t.container)?(t.canvas=t.container,t.container=t.canvas.parentNode):t.canvas||(t.canvas=o(),t.container.appendChild(t.canvas),i(t))}else if(!t.canvas){if(\"undefined\"==typeof document)throw Error(\"Not DOM environment. Use headless-gl.\");t.container=document.body||document.documentElement,t.canvas=o(),t.container.appendChild(t.canvas),i(t)}if(!t.gl)try{t.gl=t.canvas.getContext(\"webgl\",t.attrs)}catch(e){try{t.gl=t.canvas.getContext(\"experimental-webgl\",t.attrs)}catch(e){t.gl=t.canvas.getContext(\"webgl-experimental\",t.attrs)}}return t.gl}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"pick-by-alias\":465}],324:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){e?e.bind():t.bindBuffer(t.ELEMENT_ARRAY_BUFFER,null);var n=0|t.getParameter(t.MAX_VERTEX_ATTRIBS);if(r){if(r.length>n)throw new Error(\"gl-vao: Too many vertex attributes\");for(var i=0;i<r.length;++i){var a=r[i];if(a.buffer){var o=a.buffer,s=a.size||4,l=a.type||t.FLOAT,c=!!a.normalized,u=a.stride||0,h=a.offset||0;o.bind(),t.enableVertexAttribArray(i),t.vertexAttribPointer(i,s,l,c,u,h)}else{if(\"number\"==typeof a)t.vertexAttrib1f(i,a);else if(1===a.length)t.vertexAttrib1f(i,a[0]);else if(2===a.length)t.vertexAttrib2f(i,a[0],a[1]);else if(3===a.length)t.vertexAttrib3f(i,a[0],a[1],a[2]);else{if(4!==a.length)throw new Error(\"gl-vao: Invalid vertex attribute\");t.vertexAttrib4f(i,a[0],a[1],a[2],a[3])}t.disableVertexAttribArray(i)}}for(;i<n;++i)t.disableVertexAttribArray(i)}else for(t.bindBuffer(t.ARRAY_BUFFER,null),i=0;i<n;++i)t.disableVertexAttribArray(i)}},{}],325:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t){this.gl=t,this._elements=null,this._attributes=null,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(){n(this.gl,this._elements,this._attributes)},i.prototype.update=function(t,e,r){this._elements=e,this._attributes=t,this._elementsType=r||this.gl.UNSIGNED_SHORT},i.prototype.dispose=function(){},i.prototype.unbind=function(){},i.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._elements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t){return new i(t)}},{\"./do-bind.js\":324}],326:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t,e,r,n,i,a){this.location=t,this.dimension=e,this.a=r,this.b=n,this.c=i,this.d=a}function a(t,e,r){this.gl=t,this._ext=e,this.handle=r,this._attribs=[],this._useElements=!1,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(t){switch(this.dimension){case 1:t.vertexAttrib1f(this.location,this.a);break;case 2:t.vertexAttrib2f(this.location,this.a,this.b);break;case 3:t.vertexAttrib3f(this.location,this.a,this.b,this.c);break;case 4:t.vertexAttrib4f(this.location,this.a,this.b,this.c,this.d)}},a.prototype.bind=function(){this._ext.bindVertexArrayOES(this.handle);for(var t=0;t<this._attribs.length;++t)this._attribs[t].bind(this.gl)},a.prototype.unbind=function(){this._ext.bindVertexArrayOES(null)},a.prototype.dispose=function(){this._ext.deleteVertexArrayOES(this.handle)},a.prototype.update=function(t,e,r){if(this.bind(),n(this.gl,e,t),this.unbind(),this._attribs.length=0,t)for(var a=0;a<t.length;++a){var o=t[a];\"number\"==typeof o?this._attribs.push(new i(a,1,o)):Array.isArray(o)&&this._attribs.push(new i(a,o.length,o[0],o[1],o[2],o[3]))}this._useElements=!!e,this._elementsType=r||this.gl.UNSIGNED_SHORT},a.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._useElements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t,e){return new a(t,e,e.createVertexArrayOES())}},{\"./do-bind.js\":324}],327:[function(t,e,r){\"use strict\";var n=t(\"./lib/vao-native.js\"),i=t(\"./lib/vao-emulated.js\");function a(t){this.bindVertexArrayOES=t.bindVertexArray.bind(t),this.createVertexArrayOES=t.createVertexArray.bind(t),this.deleteVertexArrayOES=t.deleteVertexArray.bind(t)}e.exports=function(t,e,r,o){var s,l=t.createVertexArray?new a(t):t.getExtension(\"OES_vertex_array_object\");return(s=l?n(t,l):i(t)).update(e,r,o),s}},{\"./lib/vao-emulated.js\":325,\"./lib/vao-native.js\":326}],328:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t}},{}],329:[function(t,e,r){e.exports=function(t,e){var r=n(t[0],t[1],t[2]),o=n(e[0],e[1],e[2]);i(r,r),i(o,o);var s=a(r,o);return s>1?0:Math.acos(s)};var n=t(\"./fromValues\"),i=t(\"./normalize\"),a=t(\"./dot\")},{\"./dot\":339,\"./fromValues\":345,\"./normalize\":356}],330:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.ceil(e[0]),t[1]=Math.ceil(e[1]),t[2]=Math.ceil(e[2]),t}},{}],331:[function(t,e,r){e.exports=function(t){var e=new Float32Array(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e}},{}],332:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}},{}],333:[function(t,e,r){e.exports=function(){var t=new Float32Array(3);return t[0]=0,t[1]=0,t[2]=0,t}},{}],334:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2];return t[0]=i*l-a*s,t[1]=a*o-n*l,t[2]=n*s-i*o,t}},{}],335:[function(t,e,r){e.exports=t(\"./distance\")},{\"./distance\":336}],336:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return Math.sqrt(r*r+n*n+i*i)}},{}],337:[function(t,e,r){e.exports=t(\"./divide\")},{\"./divide\":338}],338:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t}},{}],339:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}},{}],340:[function(t,e,r){e.exports=1e-6},{}],341:[function(t,e,r){e.exports=function(t,e){var r=t[0],i=t[1],a=t[2],o=e[0],s=e[1],l=e[2];return Math.abs(r-o)<=n*Math.max(1,Math.abs(r),Math.abs(o))&&Math.abs(i-s)<=n*Math.max(1,Math.abs(i),Math.abs(s))&&Math.abs(a-l)<=n*Math.max(1,Math.abs(a),Math.abs(l))};var n=t(\"./epsilon\")},{\"./epsilon\":340}],342:[function(t,e,r){e.exports=function(t,e){return t[0]===e[0]&&t[1]===e[1]&&t[2]===e[2]}},{}],343:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.floor(e[0]),t[1]=Math.floor(e[1]),t[2]=Math.floor(e[2]),t}},{}],344:[function(t,e,r){e.exports=function(t,e,r,i,a,o){var s,l;e||(e=3);r||(r=0);l=i?Math.min(i*e+r,t.length):t.length;for(s=r;s<l;s+=e)n[0]=t[s],n[1]=t[s+1],n[2]=t[s+2],a(n,n,o),t[s]=n[0],t[s+1]=n[1],t[s+2]=n[2];return t};var n=t(\"./create\")()},{\"./create\":333}],345:[function(t,e,r){e.exports=function(t,e,r){var n=new Float32Array(3);return n[0]=t,n[1]=e,n[2]=r,n}},{}],346:[function(t,e,r){e.exports={EPSILON:t(\"./epsilon\"),create:t(\"./create\"),clone:t(\"./clone\"),angle:t(\"./angle\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),equals:t(\"./equals\"),exactEquals:t(\"./exactEquals\"),add:t(\"./add\"),subtract:t(\"./subtract\"),sub:t(\"./sub\"),multiply:t(\"./multiply\"),mul:t(\"./mul\"),divide:t(\"./divide\"),div:t(\"./div\"),min:t(\"./min\"),max:t(\"./max\"),floor:t(\"./floor\"),ceil:t(\"./ceil\"),round:t(\"./round\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),dist:t(\"./dist\"),squaredDistance:t(\"./squaredDistance\"),sqrDist:t(\"./sqrDist\"),length:t(\"./length\"),len:t(\"./len\"),squaredLength:t(\"./squaredLength\"),sqrLen:t(\"./sqrLen\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),cross:t(\"./cross\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformMat3:t(\"./transformMat3\"),transformQuat:t(\"./transformQuat\"),rotateX:t(\"./rotateX\"),rotateY:t(\"./rotateY\"),rotateZ:t(\"./rotateZ\"),forEach:t(\"./forEach\")}},{\"./add\":328,\"./angle\":329,\"./ceil\":330,\"./clone\":331,\"./copy\":332,\"./create\":333,\"./cross\":334,\"./dist\":335,\"./distance\":336,\"./div\":337,\"./divide\":338,\"./dot\":339,\"./epsilon\":340,\"./equals\":341,\"./exactEquals\":342,\"./floor\":343,\"./forEach\":344,\"./fromValues\":345,\"./inverse\":347,\"./len\":348,\"./length\":349,\"./lerp\":350,\"./max\":351,\"./min\":352,\"./mul\":353,\"./multiply\":354,\"./negate\":355,\"./normalize\":356,\"./random\":357,\"./rotateX\":358,\"./rotateY\":359,\"./rotateZ\":360,\"./round\":361,\"./scale\":362,\"./scaleAndAdd\":363,\"./set\":364,\"./sqrDist\":365,\"./sqrLen\":366,\"./squaredDistance\":367,\"./squaredLength\":368,\"./sub\":369,\"./subtract\":370,\"./transformMat3\":371,\"./transformMat4\":372,\"./transformQuat\":373}],347:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t}},{}],348:[function(t,e,r){e.exports=t(\"./length\")},{\"./length\":349}],349:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return Math.sqrt(e*e+r*r+n*n)}},{}],350:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t}},{}],351:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t}},{}],352:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t}},{}],353:[function(t,e,r){e.exports=t(\"./multiply\")},{\"./multiply\":354}],354:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t}},{}],355:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t}},{}],356:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=r*r+n*n+i*i;a>0&&(a=1/Math.sqrt(a),t[0]=e[0]*a,t[1]=e[1]*a,t[2]=e[2]*a);return t}},{}],357:[function(t,e,r){e.exports=function(t,e){e=e||1;var r=2*Math.random()*Math.PI,n=2*Math.random()-1,i=Math.sqrt(1-n*n)*e;return t[0]=Math.cos(r)*i,t[1]=Math.sin(r)*i,t[2]=n*e,t}},{}],358:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[1],a=r[2],o=e[1]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=e[0],t[1]=i+o*c-s*l,t[2]=a+o*l+s*c,t}},{}],359:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[2],o=e[0]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+s*l+o*c,t[1]=e[1],t[2]=a+s*c-o*l,t}},{}],360:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[1],o=e[0]-i,s=e[1]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+o*c-s*l,t[1]=a+o*l+s*c,t[2]=e[2],t}},{}],361:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.round(e[0]),t[1]=Math.round(e[1]),t[2]=Math.round(e[2]),t}},{}],362:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t}},{}],363:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t}},{}],364:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e,t[1]=r,t[2]=n,t}},{}],365:[function(t,e,r){e.exports=t(\"./squaredDistance\")},{\"./squaredDistance\":367}],366:[function(t,e,r){e.exports=t(\"./squaredLength\")},{\"./squaredLength\":368}],367:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return r*r+n*n+i*i}},{}],368:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return e*e+r*r+n*n}},{}],369:[function(t,e,r){e.exports=t(\"./subtract\")},{\"./subtract\":370}],370:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t}},{}],371:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t}},{}],372:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[3]*n+r[7]*i+r[11]*a+r[15];return o=o||1,t[0]=(r[0]*n+r[4]*i+r[8]*a+r[12])/o,t[1]=(r[1]*n+r[5]*i+r[9]*a+r[13])/o,t[2]=(r[2]*n+r[6]*i+r[10]*a+r[14])/o,t}},{}],373:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,h=c*i+l*n-o*a,f=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+h*-l-f*-s,t[1]=h*c+p*-s+f*-o-u*-l,t[2]=f*c+p*-l+u*-s-h*-o,t}},{}],374:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t[3]=e[3]+r[3],t}},{}],375:[function(t,e,r){e.exports=function(t){var e=new Float32Array(4);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e}},{}],376:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t}},{}],377:[function(t,e,r){e.exports=function(){var t=new Float32Array(4);return t[0]=0,t[1]=0,t[2]=0,t[3]=0,t}},{}],378:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return Math.sqrt(r*r+n*n+i*i+a*a)}},{}],379:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t[3]=e[3]/r[3],t}},{}],380:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}},{}],381:[function(t,e,r){e.exports=function(t,e,r,n){var i=new Float32Array(4);return i[0]=t,i[1]=e,i[2]=r,i[3]=n,i}},{}],382:[function(t,e,r){e.exports={create:t(\"./create\"),clone:t(\"./clone\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),add:t(\"./add\"),subtract:t(\"./subtract\"),multiply:t(\"./multiply\"),divide:t(\"./divide\"),min:t(\"./min\"),max:t(\"./max\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),squaredDistance:t(\"./squaredDistance\"),length:t(\"./length\"),squaredLength:t(\"./squaredLength\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformQuat:t(\"./transformQuat\")}},{\"./add\":374,\"./clone\":375,\"./copy\":376,\"./create\":377,\"./distance\":378,\"./divide\":379,\"./dot\":380,\"./fromValues\":381,\"./inverse\":383,\"./length\":384,\"./lerp\":385,\"./max\":386,\"./min\":387,\"./multiply\":388,\"./negate\":389,\"./normalize\":390,\"./random\":391,\"./scale\":392,\"./scaleAndAdd\":393,\"./set\":394,\"./squaredDistance\":395,\"./squaredLength\":396,\"./subtract\":397,\"./transformMat4\":398,\"./transformQuat\":399}],383:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t[3]=1/e[3],t}},{}],384:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return Math.sqrt(e*e+r*r+n*n+i*i)}},{}],385:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2],s=e[3];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t[3]=s+n*(r[3]-s),t}},{}],386:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t[3]=Math.max(e[3],r[3]),t}},{}],387:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t[3]=Math.min(e[3],r[3]),t}},{}],388:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t[3]=e[3]*r[3],t}},{}],389:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t[3]=-e[3],t}},{}],390:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r*r+n*n+i*i+a*a;o>0&&(o=1/Math.sqrt(o),t[0]=r*o,t[1]=n*o,t[2]=i*o,t[3]=a*o);return t}},{}],391:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"./scale\");e.exports=function(t,e){return e=e||1,t[0]=Math.random(),t[1]=Math.random(),t[2]=Math.random(),t[3]=Math.random(),n(t,t),i(t,t,e),t}},{\"./normalize\":390,\"./scale\":392}],392:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t}},{}],393:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t[3]=e[3]+r[3]*n,t}},{}],394:[function(t,e,r){e.exports=function(t,e,r,n,i){return t[0]=e,t[1]=r,t[2]=n,t[3]=i,t}},{}],395:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return r*r+n*n+i*i+a*a}},{}],396:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return e*e+r*r+n*n+i*i}},{}],397:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t[3]=e[3]-r[3],t}},{}],398:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}},{}],399:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,h=c*i+l*n-o*a,f=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+h*-l-f*-s,t[1]=h*c+p*-s+f*-o-u*-l,t[2]=f*c+p*-l+u*-s-h*-o,t[3]=e[3],t}},{}],400:[function(t,e,r){e.exports=function(t,e,r,a){return n[0]=a,n[1]=r,n[2]=e,n[3]=t,i[0]};var n=new Uint8Array(4),i=new Float32Array(n.buffer)},{}],401:[function(t,e,r){var n=t(\"glsl-tokenizer\"),i=t(\"atob-lite\");e.exports=function(t){for(var e=Array.isArray(t)?t:n(t),r=0;r<e.length;r++){var a=e[r];if(\"preprocessor\"===a.type){var o=a.data.match(/\\#define\\s+SHADER_NAME(_B64)?\\s+(.+)$/);if(o&&o[2]){var s=o[1],l=o[2];return(s?i(l):l).trim()}}}}},{\"atob-lite\":72,\"glsl-tokenizer\":408}],402:[function(t,e,r){e.exports=function(t){var e,r,k,T=0,A=0,M=l,S=[],E=[],C=1,L=0,P=0,O=!1,z=!1,I=\"\",D=a,R=n;\"300 es\"===(t=t||{}).version&&(D=s,R=o);return function(t){return E=[],null!==t?function(t){var r;T=0,k=(I+=t).length;for(;e=I[T],T<k;){switch(r=T,M){case u:T=U();break;case h:case f:T=j();break;case p:T=V();break;case d:T=G();break;case _:T=H();break;case g:T=Y();break;case c:T=W();break;case x:T=N();break;case l:T=B()}if(r!==T)switch(I[r]){case\"\\n\":L=0,++C;break;default:++L}}return A+=T,I=I.slice(T),E}(t.replace?t.replace(/\\r\\n/g,\"\\n\"):t):function(t){S.length&&F(S.join(\"\"));return M=b,F(\"(eof)\"),E}()};function F(t){t.length&&E.push({type:w[M],data:t,position:P,line:C,column:L})}function B(){return S=S.length?[]:S,\"/\"===r&&\"*\"===e?(P=A+T-1,M=u,r=e,T+1):\"/\"===r&&\"/\"===e?(P=A+T-1,M=h,r=e,T+1):\"#\"===e?(M=f,P=A+T,T):/\\s/.test(e)?(M=x,P=A+T,T):(O=/\\d/.test(e),z=/[^\\w_]/.test(e),P=A+T,M=O?d:z?p:c,T)}function N(){return/[^\\s]/g.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function j(){return\"\\r\"!==e&&\"\\n\"!==e||\"\\\\\"===r?(S.push(e),r=e,T+1):(F(S.join(\"\")),M=l,T)}function U(){return\"/\"===e&&\"*\"===r?(S.push(e),F(S.join(\"\")),M=l,T+1):(S.push(e),r=e,T+1)}function V(){if(\".\"===r&&/\\d/.test(e))return M=g,T;if(\"/\"===r&&\"*\"===e)return M=u,T;if(\"/\"===r&&\"/\"===e)return M=h,T;if(\".\"===e&&S.length){for(;q(S););return M=g,T}if(\";\"===e||\")\"===e||\"(\"===e){if(S.length)for(;q(S););return F(e),M=l,T+1}var t=2===S.length&&\"=\"!==e;if(/[\\w_\\d\\s]/.test(e)||t){for(;q(S););return M=l,T}return S.push(e),r=e,T+1}function q(t){for(var e,r,n=0;;){if(e=i.indexOf(t.slice(0,t.length+n).join(\"\")),r=i[e],-1===e){if(n--+t.length>0)continue;r=t.slice(0,1).join(\"\")}return F(r),P+=r.length,(S=S.slice(r.length)).length}}function H(){return/[^a-fA-F0-9]/.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function G(){return\".\"===e?(S.push(e),M=g,r=e,T+1):/[eE]/.test(e)?(S.push(e),M=g,r=e,T+1):\"x\"===e&&1===S.length&&\"0\"===S[0]?(M=_,S.push(e),r=e,T+1):/[^\\d]/.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function Y(){return\"f\"===e&&(S.push(e),r=e,T+=1),/[eE]/.test(e)?(S.push(e),r=e,T+1):\"-\"===e&&/[eE]/.test(r)?(S.push(e),r=e,T+1):/[^\\d]/.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function W(){if(/[^\\d\\w_]/.test(e)){var t=S.join(\"\");return M=R.indexOf(t)>-1?y:D.indexOf(t)>-1?m:v,F(S.join(\"\")),M=l,T}return S.push(e),r=e,T+1}};var n=t(\"./lib/literals\"),i=t(\"./lib/operators\"),a=t(\"./lib/builtins\"),o=t(\"./lib/literals-300es\"),s=t(\"./lib/builtins-300es\"),l=999,c=9999,u=0,h=1,f=2,p=3,d=4,g=5,v=6,m=7,y=8,x=9,b=10,_=11,w=[\"block-comment\",\"line-comment\",\"preprocessor\",\"operator\",\"integer\",\"float\",\"ident\",\"builtin\",\"keyword\",\"whitespace\",\"eof\",\"integer\"]},{\"./lib/builtins\":404,\"./lib/builtins-300es\":403,\"./lib/literals\":406,\"./lib/literals-300es\":405,\"./lib/operators\":407}],403:[function(t,e,r){var n=t(\"./builtins\");n=n.slice().filter(function(t){return!/^(gl\\_|texture)/.test(t)}),e.exports=n.concat([\"gl_VertexID\",\"gl_InstanceID\",\"gl_Position\",\"gl_PointSize\",\"gl_FragCoord\",\"gl_FrontFacing\",\"gl_FragDepth\",\"gl_PointCoord\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexUniformVectors\",\"gl_MaxVertexOutputVectors\",\"gl_MaxFragmentInputVectors\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxTextureImageUnits\",\"gl_MaxFragmentUniformVectors\",\"gl_MaxDrawBuffers\",\"gl_MinProgramTexelOffset\",\"gl_MaxProgramTexelOffset\",\"gl_DepthRangeParameters\",\"gl_DepthRange\",\"trunc\",\"round\",\"roundEven\",\"isnan\",\"isinf\",\"floatBitsToInt\",\"floatBitsToUint\",\"intBitsToFloat\",\"uintBitsToFloat\",\"packSnorm2x16\",\"unpackSnorm2x16\",\"packUnorm2x16\",\"unpackUnorm2x16\",\"packHalf2x16\",\"unpackHalf2x16\",\"outerProduct\",\"transpose\",\"determinant\",\"inverse\",\"texture\",\"textureSize\",\"textureProj\",\"textureLod\",\"textureOffset\",\"texelFetch\",\"texelFetchOffset\",\"textureProjOffset\",\"textureLodOffset\",\"textureProjLod\",\"textureProjLodOffset\",\"textureGrad\",\"textureGradOffset\",\"textureProjGrad\",\"textureProjGradOffset\"])},{\"./builtins\":404}],404:[function(t,e,r){e.exports=[\"abs\",\"acos\",\"all\",\"any\",\"asin\",\"atan\",\"ceil\",\"clamp\",\"cos\",\"cross\",\"dFdx\",\"dFdy\",\"degrees\",\"distance\",\"dot\",\"equal\",\"exp\",\"exp2\",\"faceforward\",\"floor\",\"fract\",\"gl_BackColor\",\"gl_BackLightModelProduct\",\"gl_BackLightProduct\",\"gl_BackMaterial\",\"gl_BackSecondaryColor\",\"gl_ClipPlane\",\"gl_ClipVertex\",\"gl_Color\",\"gl_DepthRange\",\"gl_DepthRangeParameters\",\"gl_EyePlaneQ\",\"gl_EyePlaneR\",\"gl_EyePlaneS\",\"gl_EyePlaneT\",\"gl_Fog\",\"gl_FogCoord\",\"gl_FogFragCoord\",\"gl_FogParameters\",\"gl_FragColor\",\"gl_FragCoord\",\"gl_FragData\",\"gl_FragDepth\",\"gl_FragDepthEXT\",\"gl_FrontColor\",\"gl_FrontFacing\",\"gl_FrontLightModelProduct\",\"gl_FrontLightProduct\",\"gl_FrontMaterial\",\"gl_FrontSecondaryColor\",\"gl_LightModel\",\"gl_LightModelParameters\",\"gl_LightModelProducts\",\"gl_LightProducts\",\"gl_LightSource\",\"gl_LightSourceParameters\",\"gl_MaterialParameters\",\"gl_MaxClipPlanes\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxDrawBuffers\",\"gl_MaxFragmentUniformComponents\",\"gl_MaxLights\",\"gl_MaxTextureCoords\",\"gl_MaxTextureImageUnits\",\"gl_MaxTextureUnits\",\"gl_MaxVaryingFloats\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxVertexUniformComponents\",\"gl_ModelViewMatrix\",\"gl_ModelViewMatrixInverse\",\"gl_ModelViewMatrixInverseTranspose\",\"gl_ModelViewMatrixTranspose\",\"gl_ModelViewProjectionMatrix\",\"gl_ModelViewProjectionMatrixInverse\",\"gl_ModelViewProjectionMatrixInverseTranspose\",\"gl_ModelViewProjectionMatrixTranspose\",\"gl_MultiTexCoord0\",\"gl_MultiTexCoord1\",\"gl_MultiTexCoord2\",\"gl_MultiTexCoord3\",\"gl_MultiTexCoord4\",\"gl_MultiTexCoord5\",\"gl_MultiTexCoord6\",\"gl_MultiTexCoord7\",\"gl_Normal\",\"gl_NormalMatrix\",\"gl_NormalScale\",\"gl_ObjectPlaneQ\",\"gl_ObjectPlaneR\",\"gl_ObjectPlaneS\",\"gl_ObjectPlaneT\",\"gl_Point\",\"gl_PointCoord\",\"gl_PointParameters\",\"gl_PointSize\",\"gl_Position\",\"gl_ProjectionMatrix\",\"gl_ProjectionMatrixInverse\",\"gl_ProjectionMatrixInverseTranspose\",\"gl_ProjectionMatrixTranspose\",\"gl_SecondaryColor\",\"gl_TexCoord\",\"gl_TextureEnvColor\",\"gl_TextureMatrix\",\"gl_TextureMatrixInverse\",\"gl_TextureMatrixInverseTranspose\",\"gl_TextureMatrixTranspose\",\"gl_Vertex\",\"greaterThan\",\"greaterThanEqual\",\"inversesqrt\",\"length\",\"lessThan\",\"lessThanEqual\",\"log\",\"log2\",\"matrixCompMult\",\"max\",\"min\",\"mix\",\"mod\",\"normalize\",\"not\",\"notEqual\",\"pow\",\"radians\",\"reflect\",\"refract\",\"sign\",\"sin\",\"smoothstep\",\"sqrt\",\"step\",\"tan\",\"texture2D\",\"texture2DLod\",\"texture2DProj\",\"texture2DProjLod\",\"textureCube\",\"textureCubeLod\",\"texture2DLodEXT\",\"texture2DProjLodEXT\",\"textureCubeLodEXT\",\"texture2DGradEXT\",\"texture2DProjGradEXT\",\"textureCubeGradEXT\"]},{}],405:[function(t,e,r){var n=t(\"./literals\");e.exports=n.slice().concat([\"layout\",\"centroid\",\"smooth\",\"case\",\"mat2x2\",\"mat2x3\",\"mat2x4\",\"mat3x2\",\"mat3x3\",\"mat3x4\",\"mat4x2\",\"mat4x3\",\"mat4x4\",\"uint\",\"uvec2\",\"uvec3\",\"uvec4\",\"samplerCubeShadow\",\"sampler2DArray\",\"sampler2DArrayShadow\",\"isampler2D\",\"isampler3D\",\"isamplerCube\",\"isampler2DArray\",\"usampler2D\",\"usampler3D\",\"usamplerCube\",\"usampler2DArray\",\"coherent\",\"restrict\",\"readonly\",\"writeonly\",\"resource\",\"atomic_uint\",\"noperspective\",\"patch\",\"sample\",\"subroutine\",\"common\",\"partition\",\"active\",\"filter\",\"image1D\",\"image2D\",\"image3D\",\"imageCube\",\"iimage1D\",\"iimage2D\",\"iimage3D\",\"iimageCube\",\"uimage1D\",\"uimage2D\",\"uimage3D\",\"uimageCube\",\"image1DArray\",\"image2DArray\",\"iimage1DArray\",\"iimage2DArray\",\"uimage1DArray\",\"uimage2DArray\",\"image1DShadow\",\"image2DShadow\",\"image1DArrayShadow\",\"image2DArrayShadow\",\"imageBuffer\",\"iimageBuffer\",\"uimageBuffer\",\"sampler1DArray\",\"sampler1DArrayShadow\",\"isampler1D\",\"isampler1DArray\",\"usampler1D\",\"usampler1DArray\",\"isampler2DRect\",\"usampler2DRect\",\"samplerBuffer\",\"isamplerBuffer\",\"usamplerBuffer\",\"sampler2DMS\",\"isampler2DMS\",\"usampler2DMS\",\"sampler2DMSArray\",\"isampler2DMSArray\",\"usampler2DMSArray\"])},{\"./literals\":406}],406:[function(t,e,r){e.exports=[\"precision\",\"highp\",\"mediump\",\"lowp\",\"attribute\",\"const\",\"uniform\",\"varying\",\"break\",\"continue\",\"do\",\"for\",\"while\",\"if\",\"else\",\"in\",\"out\",\"inout\",\"float\",\"int\",\"void\",\"bool\",\"true\",\"false\",\"discard\",\"return\",\"mat2\",\"mat3\",\"mat4\",\"vec2\",\"vec3\",\"vec4\",\"ivec2\",\"ivec3\",\"ivec4\",\"bvec2\",\"bvec3\",\"bvec4\",\"sampler1D\",\"sampler2D\",\"sampler3D\",\"samplerCube\",\"sampler1DShadow\",\"sampler2DShadow\",\"struct\",\"asm\",\"class\",\"union\",\"enum\",\"typedef\",\"template\",\"this\",\"packed\",\"goto\",\"switch\",\"default\",\"inline\",\"noinline\",\"volatile\",\"public\",\"static\",\"extern\",\"external\",\"interface\",\"long\",\"short\",\"double\",\"half\",\"fixed\",\"unsigned\",\"input\",\"output\",\"hvec2\",\"hvec3\",\"hvec4\",\"dvec2\",\"dvec3\",\"dvec4\",\"fvec2\",\"fvec3\",\"fvec4\",\"sampler2DRect\",\"sampler3DRect\",\"sampler2DRectShadow\",\"sizeof\",\"cast\",\"namespace\",\"using\"]},{}],407:[function(t,e,r){e.exports=[\"<<=\",\">>=\",\"++\",\"--\",\"<<\",\">>\",\"<=\",\">=\",\"==\",\"!=\",\"&&\",\"||\",\"+=\",\"-=\",\"*=\",\"/=\",\"%=\",\"&=\",\"^^\",\"^=\",\"|=\",\"(\",\")\",\"[\",\"]\",\".\",\"!\",\"~\",\"*\",\"/\",\"%\",\"+\",\"-\",\"<\",\">\",\"&\",\"^\",\"|\",\"?\",\":\",\"=\",\",\",\";\",\"{\",\"}\"]},{}],408:[function(t,e,r){var n=t(\"./index\");e.exports=function(t,e){var r=n(e),i=[];return i=(i=i.concat(r(t))).concat(r(null))}},{\"./index\":402}],409:[function(t,e,r){e.exports=function(t){\"string\"==typeof t&&(t=[t]);for(var e=[].slice.call(arguments,1),r=[],n=0;n<t.length-1;n++)r.push(t[n],e[n]||\"\");return r.push(t[n]),r.join(\"\")}},{}],410:[function(t,e,r){(function(r){\"use strict\";var n,i=t(\"is-browser\");n=\"function\"==typeof r.matchMedia?!r.matchMedia(\"(hover: none)\").matches:i,e.exports=n}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"is-browser\":417}],411:[function(t,e,r){\"use strict\";var n=t(\"is-browser\");e.exports=n&&function(){var t=!1;try{var e=Object.defineProperty({},\"passive\",{get:function(){t=!0}});window.addEventListener(\"test\",null,e),window.removeEventListener(\"test\",null,e)}catch(e){t=!1}return t}()},{\"is-browser\":417}],412:[function(t,e,r){r.read=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?i-1:0,f=r?-1:1,p=t[e+h];for(h+=f,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+h],h+=f,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},r.write=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,h=u>>1,f=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,i),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g}},{}],413:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(0===r)throw new Error(\"Must have at least d+1 points\");var i=t[0].length;if(r<=i)throw new Error(\"Must input at least d+1 points\");var o=t.slice(0,i+1),s=n.apply(void 0,o);if(0===s)throw new Error(\"Input not in general position\");for(var l=new Array(i+1),u=0;u<=i;++u)l[u]=u;s<0&&(l[0]=1,l[1]=0);for(var h=new a(l,new Array(i+1),!1),f=h.adjacent,p=new Array(i+2),u=0;u<=i;++u){for(var d=l.slice(),g=0;g<=i;++g)g===u&&(d[g]=-1);var v=d[0];d[0]=d[1],d[1]=v;var m=new a(d,new Array(i+1),!0);f[u]=m,p[u]=m}p[i+1]=h;for(var u=0;u<=i;++u)for(var d=f[u].vertices,y=f[u].adjacent,g=0;g<=i;++g){var x=d[g];if(x<0)y[g]=h;else for(var b=0;b<=i;++b)f[b].vertices.indexOf(x)<0&&(y[g]=f[b])}for(var _=new c(i,o,p),w=!!e,u=i+1;u<r;++u)_.insert(t[u],w);return _.boundary()};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\").compareCells;function a(t,e,r){this.vertices=t,this.adjacent=e,this.boundary=r,this.lastVisited=-1}function o(t,e,r){this.vertices=t,this.cell=e,this.index=r}function s(t,e){return i(t.vertices,e.vertices)}a.prototype.flip=function(){var t=this.vertices[0];this.vertices[0]=this.vertices[1],this.vertices[1]=t;var e=this.adjacent[0];this.adjacent[0]=this.adjacent[1],this.adjacent[1]=e};var l=[];function c(t,e,r){this.dimension=t,this.vertices=e,this.simplices=r,this.interior=r.filter(function(t){return!t.boundary}),this.tuple=new Array(t+1);for(var i=0;i<=t;++i)this.tuple[i]=this.vertices[i];var a=l[t];a||(a=l[t]=function(t){for(var e=[\"function orient(){var tuple=this.tuple;return test(\"],r=0;r<=t;++r)r>0&&e.push(\",\"),e.push(\"tuple[\",r,\"]\");e.push(\")}return orient\");var i=new Function(\"test\",e.join(\"\")),a=n[t+1];return a||(a=n),i(a)}(t)),this.orient=a}var u=c.prototype;u.handleBoundaryDegeneracy=function(t,e){var r=this.dimension,n=this.vertices.length-1,i=this.tuple,a=this.vertices,o=[t];for(t.lastVisited=-n;o.length>0;){(t=o.pop()).vertices;for(var s=t.adjacent,l=0;l<=r;++l){var c=s[l];if(c.boundary&&!(c.lastVisited<=-n)){for(var u=c.vertices,h=0;h<=r;++h){var f=u[h];i[h]=f<0?e:a[f]}var p=this.orient();if(p>0)return c;c.lastVisited=-n,0===p&&o.push(c)}}}return null},u.walk=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,a=this.tuple,o=e?this.interior.length*Math.random()|0:this.interior.length-1,s=this.interior[o];t:for(;!s.boundary;){for(var l=s.vertices,c=s.adjacent,u=0;u<=n;++u)a[u]=i[l[u]];s.lastVisited=r;for(u=0;u<=n;++u){var h=c[u];if(!(h.lastVisited>=r)){var f=a[u];a[u]=t;var p=this.orient();if(a[u]=f,p<0){s=h;continue t}h.boundary?h.lastVisited=-r:h.lastVisited=r}}return}return s},u.addPeaks=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,l=this.tuple,c=this.interior,u=this.simplices,h=[e];e.lastVisited=r,e.vertices[e.vertices.indexOf(-1)]=r,e.boundary=!1,c.push(e);for(var f=[];h.length>0;){var p=(e=h.pop()).vertices,d=e.adjacent,g=p.indexOf(r);if(!(g<0))for(var v=0;v<=n;++v)if(v!==g){var m=d[v];if(m.boundary&&!(m.lastVisited>=r)){var y=m.vertices;if(m.lastVisited!==-r){for(var x=0,b=0;b<=n;++b)y[b]<0?(x=b,l[b]=t):l[b]=i[y[b]];if(this.orient()>0){y[x]=r,m.boundary=!1,c.push(m),h.push(m),m.lastVisited=r;continue}m.lastVisited=-r}var _=m.adjacent,w=p.slice(),k=d.slice(),T=new a(w,k,!0);u.push(T);var A=_.indexOf(e);if(!(A<0)){_[A]=T,k[g]=m,w[v]=-1,k[v]=e,d[v]=T,T.flip();for(b=0;b<=n;++b){var M=w[b];if(!(M<0||M===r)){for(var S=new Array(n-1),E=0,C=0;C<=n;++C){var L=w[C];L<0||C===b||(S[E++]=L)}f.push(new o(S,T,b))}}}}}}f.sort(s);for(v=0;v+1<f.length;v+=2){var P=f[v],O=f[v+1],z=P.index,I=O.index;z<0||I<0||(P.cell.adjacent[P.index]=O.cell,O.cell.adjacent[O.index]=P.cell)}},u.insert=function(t,e){var r=this.vertices;r.push(t);var n=this.walk(t,e);if(n){for(var i=this.dimension,a=this.tuple,o=0;o<=i;++o){var s=n.vertices[o];a[o]=s<0?t:r[s]}var l=this.orient(a);l<0||(0!==l||(n=this.handleBoundaryDegeneracy(n,t)))&&this.addPeaks(t,n)}},u.boundary=function(){for(var t=this.dimension,e=[],r=this.simplices,n=r.length,i=0;i<n;++i){var a=r[i];if(a.boundary){for(var o=new Array(t),s=a.vertices,l=0,c=0,u=0;u<=t;++u)s[u]>=0?o[l++]=s[u]:c=1&u;if(c===(1&t)){var h=o[0];o[0]=o[1],o[1]=h}e.push(o)}}return e}},{\"robust-orientation\":510,\"simplicial-complex\":520}],414:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=0,a=1;function o(t,e,r,n,i){this.mid=t,this.left=e,this.right=r,this.leftPoints=n,this.rightPoints=i,this.count=(e?e.count:0)+(r?r.count:0)+n.length}e.exports=function(t){if(!t||0===t.length)return new x(null);return new x(y(t))};var s=o.prototype;function l(t,e){t.mid=e.mid,t.left=e.left,t.right=e.right,t.leftPoints=e.leftPoints,t.rightPoints=e.rightPoints,t.count=e.count}function c(t,e){var r=y(e);t.mid=r.mid,t.left=r.left,t.right=r.right,t.leftPoints=r.leftPoints,t.rightPoints=r.rightPoints,t.count=r.count}function u(t,e){var r=t.intervals([]);r.push(e),c(t,r)}function h(t,e){var r=t.intervals([]),n=r.indexOf(e);return n<0?i:(r.splice(n,1),c(t,r),a)}function f(t,e,r){for(var n=0;n<t.length&&t[n][0]<=e;++n){var i=r(t[n]);if(i)return i}}function p(t,e,r){for(var n=t.length-1;n>=0&&t[n][1]>=e;--n){var i=r(t[n]);if(i)return i}}function d(t,e){for(var r=0;r<t.length;++r){var n=e(t[r]);if(n)return n}}function g(t,e){return t-e}function v(t,e){var r=t[0]-e[0];return r||t[1]-e[1]}function m(t,e){var r=t[1]-e[1];return r||t[0]-e[0]}function y(t){if(0===t.length)return null;for(var e=[],r=0;r<t.length;++r)e.push(t[r][0],t[r][1]);e.sort(g);var n=e[e.length>>1],i=[],a=[],s=[];for(r=0;r<t.length;++r){var l=t[r];l[1]<n?i.push(l):n<l[0]?a.push(l):s.push(l)}var c=s,u=s.slice();return c.sort(v),u.sort(m),new o(n,y(i),y(a),c,u)}function x(t){this.root=t}s.intervals=function(t){return t.push.apply(t,this.leftPoints),this.left&&this.left.intervals(t),this.right&&this.right.intervals(t),t},s.insert=function(t){var e=this.count-this.leftPoints.length;if(this.count+=1,t[1]<this.mid)this.left?4*(this.left.count+1)>3*(e+1)?u(this,t):this.left.insert(t):this.left=y([t]);else if(t[0]>this.mid)this.right?4*(this.right.count+1)>3*(e+1)?u(this,t):this.right.insert(t):this.right=y([t]);else{var r=n.ge(this.leftPoints,t,v),i=n.ge(this.rightPoints,t,m);this.leftPoints.splice(r,0,t),this.rightPoints.splice(i,0,t)}},s.remove=function(t){var e=this.count-this.leftPoints;if(t[1]<this.mid)return this.left?4*(this.right?this.right.count:0)>3*(e-1)?h(this,t):2===(c=this.left.remove(t))?(this.left=null,this.count-=1,a):(c===a&&(this.count-=1),c):i;if(t[0]>this.mid)return this.right?4*(this.left?this.left.count:0)>3*(e-1)?h(this,t):2===(c=this.right.remove(t))?(this.right=null,this.count-=1,a):(c===a&&(this.count-=1),c):i;if(1===this.count)return this.leftPoints[0]===t?2:i;if(1===this.leftPoints.length&&this.leftPoints[0]===t){if(this.left&&this.right){for(var r=this,o=this.left;o.right;)r=o,o=o.right;if(r===this)o.right=this.right;else{var s=this.left,c=this.right;r.count-=o.count,r.right=o.left,o.left=s,o.right=c}l(this,o),this.count=(this.left?this.left.count:0)+(this.right?this.right.count:0)+this.leftPoints.length}else this.left?l(this,this.left):l(this,this.right);return a}for(s=n.ge(this.leftPoints,t,v);s<this.leftPoints.length&&this.leftPoints[s][0]===t[0];++s)if(this.leftPoints[s]===t){this.count-=1,this.leftPoints.splice(s,1);for(c=n.ge(this.rightPoints,t,m);c<this.rightPoints.length&&this.rightPoints[c][1]===t[1];++c)if(this.rightPoints[c]===t)return this.rightPoints.splice(c,1),a}return i},s.queryPoint=function(t,e){if(t<this.mid){if(this.left)if(r=this.left.queryPoint(t,e))return r;return f(this.leftPoints,t,e)}if(t>this.mid){var r;if(this.right)if(r=this.right.queryPoint(t,e))return r;return p(this.rightPoints,t,e)}return d(this.leftPoints,e)},s.queryInterval=function(t,e,r){var n;if(t<this.mid&&this.left&&(n=this.left.queryInterval(t,e,r)))return n;if(e>this.mid&&this.right&&(n=this.right.queryInterval(t,e,r)))return n;return e<this.mid?f(this.leftPoints,e,r):t>this.mid?p(this.rightPoints,t,r):d(this.leftPoints,r)};var b=x.prototype;b.insert=function(t){this.root?this.root.insert(t):this.root=new o(t[0],null,null,[t],[t])},b.remove=function(t){if(this.root){var e=this.root.remove(t);return 2===e&&(this.root=null),e!==i}return!1},b.queryPoint=function(t,e){if(this.root)return this.root.queryPoint(t,e)},b.queryInterval=function(t,e,r){if(t<=e&&this.root)return this.root.queryInterval(t,e,r)},Object.defineProperty(b,\"count\",{get:function(){return this.root?this.root.count:0}}),Object.defineProperty(b,\"intervals\",{get:function(){return this.root?this.root.intervals([]):[]}})},{\"binary-search-bounds\":91}],415:[function(t,e,r){\"use strict\";e.exports=function(t,e){e=e||new Array(t.length);for(var r=0;r<t.length;++r)e[t[r]]=r;return e}},{}],416:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=r;return e}},{}],417:[function(t,e,r){e.exports=!0},{}],418:[function(t,e,r){function n(t){return!!t.constructor&&\"function\"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}e.exports=function(t){return null!=t&&(n(t)||function(t){return\"function\"==typeof t.readFloatLE&&\"function\"==typeof t.slice&&n(t.slice(0,0))}(t)||!!t._isBuffer)}},{}],419:[function(t,e,r){\"use strict\";e.exports=\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion))},{}],420:[function(t,e,r){\"use strict\";e.exports=a,e.exports.isMobile=a;var n=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i,i=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino|android|ipad|playbook|silk/i;function a(t){t||(t={});var e=t.ua;return e||\"undefined\"==typeof navigator||(e=navigator.userAgent),e&&e.headers&&\"string\"==typeof e.headers[\"user-agent\"]&&(e=e.headers[\"user-agent\"]),\"string\"==typeof e&&(t.tablet?i.test(e):n.test(e))}},{}],421:[function(t,e,r){\"use strict\";e.exports=function(t){var e=typeof t;return null!==t&&(\"object\"===e||\"function\"===e)}},{}],422:[function(t,e,r){\"use strict\";var n=Object.prototype.toString;e.exports=function(t){var e;return\"[object Object]\"===n.call(t)&&(null===(e=Object.getPrototypeOf(t))||e===Object.getPrototypeOf({}))}},{}],423:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=t.length,n=0;n<r;n++)if(((e=t.charCodeAt(n))<9||e>13)&&32!==e&&133!==e&&160!==e&&5760!==e&&6158!==e&&(e<8192||e>8205)&&8232!==e&&8233!==e&&8239!==e&&8287!==e&&8288!==e&&12288!==e&&65279!==e)return!1;return!0}},{}],424:[function(t,e,r){\"use strict\";e.exports=function(t){return\"string\"==typeof t&&(t=t.trim(),!!(/^[mzlhvcsqta]\\s*[-+.0-9][^mlhvzcsqta]+/i.test(t)&&/[\\dz]$/i.test(t)&&t.length>4))}},{}],425:[function(t,e,r){e.exports=function(t,e,r){return t*(1-r)+e*r}},{}],426:[function(t,e,r){var n,i;n=this,i=function(){\"use strict\";var t,e,r;function n(n,i){if(t)if(e){var a=\"var sharedChunk = {}; (\"+t+\")(sharedChunk); (\"+e+\")(sharedChunk);\",o={};t(o),(r=i(o)).workerUrl=window.URL.createObjectURL(new Blob([a],{type:\"text/javascript\"}))}else e=i;else t=i}return n(0,function(t){function e(t,e){return t(e={exports:{}},e.exports),e.exports}var r=n;function n(t,e,r,n){this.cx=3*t,this.bx=3*(r-t)-this.cx,this.ax=1-this.cx-this.bx,this.cy=3*e,this.by=3*(n-e)-this.cy,this.ay=1-this.cy-this.by,this.p1x=t,this.p1y=n,this.p2x=r,this.p2y=n}n.prototype.sampleCurveX=function(t){return((this.ax*t+this.bx)*t+this.cx)*t},n.prototype.sampleCurveY=function(t){return((this.ay*t+this.by)*t+this.cy)*t},n.prototype.sampleCurveDerivativeX=function(t){return(3*this.ax*t+2*this.bx)*t+this.cx},n.prototype.solveCurveX=function(t,e){var r,n,i,a,o;for(void 0===e&&(e=1e-6),i=t,o=0;o<8;o++){if(a=this.sampleCurveX(i)-t,Math.abs(a)<e)return i;var s=this.sampleCurveDerivativeX(i);if(Math.abs(s)<1e-6)break;i-=a/s}if((i=t)<(r=0))return r;if(i>(n=1))return n;for(;r<n;){if(a=this.sampleCurveX(i),Math.abs(a-t)<e)return i;t>a?r=i:n=i,i=.5*(n-r)+r}return i},n.prototype.solve=function(t,e){return this.sampleCurveY(this.solveCurveX(t,e))};var i=a;function a(t,e){this.x=t,this.y=e}function o(t,e){if(Array.isArray(t)){if(!Array.isArray(e)||t.length!==e.length)return!1;for(var r=0;r<t.length;r++)if(!o(t[r],e[r]))return!1;return!0}if(\"object\"==typeof t&&null!==t&&null!==e){if(\"object\"!=typeof e)return!1;if(Object.keys(t).length!==Object.keys(e).length)return!1;for(var n in t)if(!o(t[n],e[n]))return!1;return!0}return t===e}function s(t,e,n,i){var a=new r(t,e,n,i);return function(t){return a.solve(t)}}a.prototype={clone:function(){return new a(this.x,this.y)},add:function(t){return this.clone()._add(t)},sub:function(t){return this.clone()._sub(t)},multByPoint:function(t){return this.clone()._multByPoint(t)},divByPoint:function(t){return this.clone()._divByPoint(t)},mult:function(t){return this.clone()._mult(t)},div:function(t){return this.clone()._div(t)},rotate:function(t){return this.clone()._rotate(t)},rotateAround:function(t,e){return this.clone()._rotateAround(t,e)},matMult:function(t){return this.clone()._matMult(t)},unit:function(){return this.clone()._unit()},perp:function(){return this.clone()._perp()},round:function(){return this.clone()._round()},mag:function(){return Math.sqrt(this.x*this.x+this.y*this.y)},equals:function(t){return this.x===t.x&&this.y===t.y},dist:function(t){return Math.sqrt(this.distSqr(t))},distSqr:function(t){var e=t.x-this.x,r=t.y-this.y;return e*e+r*r},angle:function(){return Math.atan2(this.y,this.x)},angleTo:function(t){return Math.atan2(this.y-t.y,this.x-t.x)},angleWith:function(t){return this.angleWithSep(t.x,t.y)},angleWithSep:function(t,e){return Math.atan2(this.x*e-this.y*t,this.x*t+this.y*e)},_matMult:function(t){var e=t[0]*this.x+t[1]*this.y,r=t[2]*this.x+t[3]*this.y;return this.x=e,this.y=r,this},_add:function(t){return this.x+=t.x,this.y+=t.y,this},_sub:function(t){return this.x-=t.x,this.y-=t.y,this},_mult:function(t){return this.x*=t,this.y*=t,this},_div:function(t){return this.x/=t,this.y/=t,this},_multByPoint:function(t){return this.x*=t.x,this.y*=t.y,this},_divByPoint:function(t){return this.x/=t.x,this.y/=t.y,this},_unit:function(){return this._div(this.mag()),this},_perp:function(){var t=this.y;return this.y=this.x,this.x=-t,this},_rotate:function(t){var e=Math.cos(t),r=Math.sin(t),n=e*this.x-r*this.y,i=r*this.x+e*this.y;return this.x=n,this.y=i,this},_rotateAround:function(t,e){var r=Math.cos(t),n=Math.sin(t),i=e.x+r*(this.x-e.x)-n*(this.y-e.y),a=e.y+n*(this.x-e.x)+r*(this.y-e.y);return this.x=i,this.y=a,this},_round:function(){return this.x=Math.round(this.x),this.y=Math.round(this.y),this}},a.convert=function(t){return t instanceof a?t:Array.isArray(t)?new a(t[0],t[1]):t};var l=s(.25,.1,.25,1);function c(t,e,r){return Math.min(r,Math.max(e,t))}function u(t,e,r){var n=r-e,i=((t-e)%n+n)%n+e;return i===e?r:i}function h(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}var f=1;function p(){return f++}function d(){return function t(e){return e?(e^16*Math.random()>>e/4).toString(16):([1e7]+-[1e3]+-4e3+-8e3+-1e11).replace(/[018]/g,t)}()}function g(t){return!!t&&/^[0-9a-f]{8}-[0-9a-f]{4}-[4][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$/i.test(t)}function v(t,e){t.forEach(function(t){e[t]&&(e[t]=e[t].bind(e))})}function m(t,e){return-1!==t.indexOf(e,t.length-e.length)}function y(t,e,r){var n={};for(var i in t)n[i]=e.call(r||this,t[i],i,t);return n}function x(t,e,r){var n={};for(var i in t)e.call(r||this,t[i],i,t)&&(n[i]=t[i]);return n}function b(t){return Array.isArray(t)?t.map(b):\"object\"==typeof t&&t?y(t,b):t}var _={};function w(t){_[t]||(\"undefined\"!=typeof console&&console.warn(t),_[t]=!0)}function k(t,e,r){return(r.y-t.y)*(e.x-t.x)>(e.y-t.y)*(r.x-t.x)}function T(t){for(var e=0,r=0,n=t.length,i=n-1,a=void 0,o=void 0;r<n;i=r++)a=t[r],e+=((o=t[i]).x-a.x)*(a.y+o.y);return e}function A(t){var e={};if(t.replace(/(?:^|(?:\\s*\\,\\s*))([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)(?:\\=(?:([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)|(?:\\\"((?:[^\"\\\\]|\\\\.)*)\\\")))?/g,function(t,r,n,i){var a=n||i;return e[r]=!a||a.toLowerCase(),\"\"}),e[\"max-age\"]){var r=parseInt(e[\"max-age\"],10);isNaN(r)?delete e[\"max-age\"]:e[\"max-age\"]=r}return e}function M(t){try{var e=self[t];return e.setItem(\"_mapbox_test_\",1),e.removeItem(\"_mapbox_test_\"),!0}catch(t){return!1}}var S,E,C,L=self.performance&&self.performance.now?self.performance.now.bind(self.performance):Date.now.bind(Date),P=self.requestAnimationFrame||self.mozRequestAnimationFrame||self.webkitRequestAnimationFrame||self.msRequestAnimationFrame,O=self.cancelAnimationFrame||self.mozCancelAnimationFrame||self.webkitCancelAnimationFrame||self.msCancelAnimationFrame,z={now:L,frame:function(t){var e=P(t);return{cancel:function(){return O(e)}}},getImageData:function(t){var e=self.document.createElement(\"canvas\"),r=e.getContext(\"2d\");if(!r)throw new Error(\"failed to create canvas 2d context\");return e.width=t.width,e.height=t.height,r.drawImage(t,0,0,t.width,t.height),r.getImageData(0,0,t.width,t.height)},resolveURL:function(t){return S||(S=self.document.createElement(\"a\")),S.href=t,S.href},hardwareConcurrency:self.navigator.hardwareConcurrency||4,get devicePixelRatio(){return self.devicePixelRatio}},I={API_URL:\"https://api.mapbox.com\",get EVENTS_URL(){return this.API_URL?0===this.API_URL.indexOf(\"https://api.mapbox.cn\")?\"https://events.mapbox.cn/events/v2\":0===this.API_URL.indexOf(\"https://api.mapbox.com\")?\"https://events.mapbox.com/events/v2\":null:null},FEEDBACK_URL:\"https://apps.mapbox.com/feedback\",REQUIRE_ACCESS_TOKEN:!0,ACCESS_TOKEN:null,MAX_PARALLEL_IMAGE_REQUESTS:16},D={supported:!1,testSupport:function(t){!R&&C&&(F?B(t):E=t)}},R=!1,F=!1;function B(t){var e=t.createTexture();t.bindTexture(t.TEXTURE_2D,e);try{if(t.texImage2D(t.TEXTURE_2D,0,t.RGBA,t.RGBA,t.UNSIGNED_BYTE,C),t.isContextLost())return;D.supported=!0}catch(t){}t.deleteTexture(e),R=!0}self.document&&((C=self.document.createElement(\"img\")).onload=function(){E&&B(E),E=null,F=!0},C.onerror=function(){R=!0,E=null},C.src=\"data:image/webp;base64,UklGRh4AAABXRUJQVlA4TBEAAAAvAQAAAAfQ//73v/+BiOh/AAA=\");var N=\"01\",j=function(t){this._transformRequestFn=t,this._createSkuToken()};j.prototype._createSkuToken=function(){var t=function(){for(var t=\"\",e=0;e<10;e++)t+=\"0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ\"[Math.floor(62*Math.random())];return{token:[\"1\",N,t].join(\"\"),tokenExpiresAt:Date.now()+432e5}}();this._skuToken=t.token,this._skuTokenExpiresAt=t.tokenExpiresAt},j.prototype._isSkuTokenExpired=function(){return Date.now()>this._skuTokenExpiresAt},j.prototype.transformRequest=function(t,e){return this._transformRequestFn&&this._transformRequestFn(t,e)||{url:t}},j.prototype.normalizeStyleURL=function(t,e){return Y(t,e)},j.prototype.normalizeGlyphsURL=function(t,e){return W(t,e)},j.prototype.normalizeSourceURL=function(t,e){return X(t,e)},j.prototype.normalizeSpriteURL=function(t,e,r,n){return Z(t,e,r,n)},j.prototype.normalizeTileURL=function(t,e,r){return this._isSkuTokenExpired()&&this._createSkuToken(),K(t,e,r,this._skuToken)},j.prototype.canonicalizeTileURL=function(t){return Q(t)},j.prototype.canonicalizeTileset=function(t,e){return tt(t,e)};var U=\"See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\";function V(t,e){var r=rt(I.API_URL);if(t.protocol=r.protocol,t.authority=r.authority,\"/\"!==r.path&&(t.path=\"\"+r.path+t.path),!I.REQUIRE_ACCESS_TOKEN)return nt(t);if(!(e=e||I.ACCESS_TOKEN))throw new Error(\"An API access token is required to use Mapbox GL. \"+U);if(\"s\"===e[0])throw new Error(\"Use a public access token (pk.*) with Mapbox GL, not a secret access token (sk.*). \"+U);return t.params.push(\"access_token=\"+e),nt(t)}function q(t){return 0===t.indexOf(\"mapbox:\")}var H=/^((https?:)?\\/\\/)?([^\\/]+\\.)?mapbox\\.c(n|om)(\\/|\\?|$)/i;function G(t){return H.test(t)}var Y=function(t,e){if(!q(t))return t;var r=rt(t);return r.path=\"/styles/v1\"+r.path,V(r,e)},W=function(t,e){if(!q(t))return t;var r=rt(t);return r.path=\"/fonts/v1\"+r.path,V(r,e)},X=function(t,e){if(!q(t))return t;var r=rt(t);return r.path=\"/v4/\"+r.authority+\".json\",r.params.push(\"secure\"),V(r,e)},Z=function(t,e,r,n){var i=rt(t);return q(t)?(i.path=\"/styles/v1\"+i.path+\"/sprite\"+e+r,V(i,n)):(i.path+=\"\"+e+r,nt(i))},J=/(\\.(png|jpg)\\d*)(?=$)/,K=function(t,e,r,n){if(!e||!q(e))return t;var i=rt(t),a=z.devicePixelRatio>=2||512===r?\"@2x\":\"\",o=D.supported?\".webp\":\"$1\";return i.path=i.path.replace(J,\"\"+a+o),i.path=\"/v4\"+i.path,I.REQUIRE_ACCESS_TOKEN&&I.ACCESS_TOKEN&&n&&i.params.push(\"sku=\"+n),V(i)},$=/\\.[\\w]+$/,Q=function(t){var e=rt(t);if(!e.path.match(/(^\\/v4\\/)/)||!e.path.match($))return t;var r=\"mapbox://tiles/\";r+=e.path.replace(\"/v4/\",\"\");var n=e.params.filter(function(t){return!t.match(/^access_token=/)});return n.length&&(r+=\"?\"+n.join(\"&\")),r},tt=function(t,e){if(!q(e))return t.tiles||[];for(var r=[],n=0,i=t.tiles;n<i.length;n+=1){var a=i[n],o=Q(a);r.push(o)}return r},et=/^(\\w+):\\/\\/([^\\/?]*)(\\/[^?]+)?\\??(.+)?/;function rt(t){var e=t.match(et);if(!e)throw new Error(\"Unable to parse URL object\");return{protocol:e[1],authority:e[2],path:e[3]||\"/\",params:e[4]?e[4].split(\"&\"):[]}}function nt(t){var e=t.params.length?\"?\"+t.params.join(\"&\"):\"\";return t.protocol+\"://\"+t.authority+t.path+e}function it(t){if(!t)return null;var e,r=t.split(\".\");if(!r||3!==r.length)return null;try{return JSON.parse((e=r[1],decodeURIComponent(self.atob(e).split(\"\").map(function(t){return\"%\"+(\"00\"+t.charCodeAt(0).toString(16)).slice(-2)}).join(\"\"))))}catch(t){return null}}var at=function(t){this.type=t,this.anonId=null,this.eventData={},this.queue=[],this.pendingRequest=null};at.prototype.getStorageKey=function(t){var e,r=it(I.ACCESS_TOKEN),n=\"\";return r&&r.u?(e=r.u,n=self.btoa(encodeURIComponent(e).replace(/%([0-9A-F]{2})/g,function(t,e){return String.fromCharCode(Number(\"0x\"+e))}))):n=I.ACCESS_TOKEN||\"\",t?\"mapbox.eventData.\"+t+\":\"+n:\"mapbox.eventData:\"+n},at.prototype.fetchEventData=function(){var t=M(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{var n=self.localStorage.getItem(e);n&&(this.eventData=JSON.parse(n));var i=self.localStorage.getItem(r);i&&(this.anonId=i)}catch(t){w(\"Unable to read from LocalStorage\")}},at.prototype.saveEventData=function(){var t=M(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{self.localStorage.setItem(r,this.anonId),Object.keys(this.eventData).length>=1&&self.localStorage.setItem(e,JSON.stringify(this.eventData))}catch(t){w(\"Unable to write to LocalStorage\")}},at.prototype.processRequests=function(){},at.prototype.postEvent=function(t,e,r){var n=this;if(I.EVENTS_URL){var i=rt(I.EVENTS_URL);i.params.push(\"access_token=\"+(I.ACCESS_TOKEN||\"\"));var a={event:this.type,created:new Date(t).toISOString(),sdkIdentifier:\"mapbox-gl-js\",sdkVersion:\"1.1.1\",skuId:N,userId:this.anonId},o=e?h(a,e):a,s={url:nt(i),headers:{\"Content-Type\":\"text/plain\"},body:JSON.stringify([o])};this.pendingRequest=St(s,function(t){n.pendingRequest=null,r(t),n.saveEventData(),n.processRequests()})}},at.prototype.queueRequest=function(t){this.queue.push(t),this.processRequests()};var ot,st=function(t){function e(){t.call(this,\"map.load\"),this.success={},this.skuToken=\"\"}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.postMapLoadEvent=function(t,e,r){this.skuToken=r,I.EVENTS_URL&&I.ACCESS_TOKEN&&Array.isArray(t)&&t.some(function(t){return q(t)||G(t)})&&this.queueRequest({id:e,timestamp:Date.now()})},e.prototype.processRequests=function(){var t=this;if(!this.pendingRequest&&0!==this.queue.length){var e=this.queue.shift(),r=e.id,n=e.timestamp;r&&this.success[r]||(this.anonId||this.fetchEventData(),g(this.anonId)||(this.anonId=d()),this.postEvent(n,{skuToken:this.skuToken},function(e){e||r&&(t.success[r]=!0)}))}},e}(at),lt=new(function(t){function e(){t.call(this,\"appUserTurnstile\")}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.postTurnstileEvent=function(t){I.EVENTS_URL&&I.ACCESS_TOKEN&&Array.isArray(t)&&t.some(function(t){return q(t)||G(t)})&&this.queueRequest(Date.now())},e.prototype.processRequests=function(){var t=this;if(!this.pendingRequest&&0!==this.queue.length){this.anonId&&this.eventData.lastSuccess&&this.eventData.tokenU||this.fetchEventData();var e=it(I.ACCESS_TOKEN),r=e?e.u:I.ACCESS_TOKEN,n=r!==this.eventData.tokenU;g(this.anonId)||(this.anonId=d(),n=!0);var i=this.queue.shift();if(this.eventData.lastSuccess){var a=new Date(this.eventData.lastSuccess),o=new Date(i),s=(i-this.eventData.lastSuccess)/864e5;n=n||s>=1||s<-1||a.getDate()!==o.getDate()}else n=!0;if(!n)return this.processRequests();this.postEvent(i,{\"enabled.telemetry\":!1},function(e){e||(t.eventData.lastSuccess=i,t.eventData.tokenU=r)})}},e}(at)),ct=lt.postTurnstileEvent.bind(lt),ut=new st,ht=ut.postMapLoadEvent.bind(ut),ft=\"mapbox-tiles\",pt=500,dt=50,gt=42e4;function vt(t){var e=t.indexOf(\"?\");return e<0?t:t.slice(0,e)}var mt=1/0,yt={Unknown:\"Unknown\",Style:\"Style\",Source:\"Source\",Tile:\"Tile\",Glyphs:\"Glyphs\",SpriteImage:\"SpriteImage\",SpriteJSON:\"SpriteJSON\",Image:\"Image\"};\"function\"==typeof Object.freeze&&Object.freeze(yt);var xt=function(t){function e(e,r,n){401===r&&G(n)&&(e+=\": you may have provided an invalid Mapbox access token. See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\"),t.call(this,e),this.status=r,this.url=n,this.name=this.constructor.name,this.message=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.toString=function(){return this.name+\": \"+this.message+\" (\"+this.status+\"): \"+this.url},e}(Error);function bt(){return\"undefined\"!=typeof WorkerGlobalScope&&\"undefined\"!=typeof self&&self instanceof WorkerGlobalScope}var _t=bt()?function(){return self.worker&&self.worker.referrer}:function(){var t=self.location.origin;if(t&&\"null\"!==t&&\"file://\"!==t)return t+self.location.pathname};function wt(t,e){var r,n=new self.AbortController,i=new self.Request(t.url,{method:t.method||\"GET\",body:t.body,credentials:t.credentials,headers:t.headers,referrer:_t(),signal:n.signal}),a=!1,o=!1,s=(r=i.url).indexOf(\"sku=\")>0&&G(r);\"json\"===t.type&&i.headers.set(\"Accept\",\"application/json\");var l=function(r,n,a){if(!o){if(r&&\"SecurityError\"!==r.message&&w(r),n&&a)return c(n);var l=Date.now();self.fetch(i).then(function(r){if(r.ok){var n=s?r.clone():null;return c(r,n,l)}return e(new xt(r.statusText,r.status,t.url))}).catch(function(t){20!==t.code&&e(new Error(t.message))})}},c=function(r,n,s){(\"arrayBuffer\"===t.type?r.arrayBuffer():\"json\"===t.type?r.json():r.text()).then(function(t){o||(n&&s&&function(t,e,r){if(self.caches){var n={status:e.status,statusText:e.statusText,headers:new self.Headers};e.headers.forEach(function(t,e){return n.headers.set(e,t)});var i=A(e.headers.get(\"Cache-Control\")||\"\");i[\"no-store\"]||(i[\"max-age\"]&&n.headers.set(\"Expires\",new Date(r+1e3*i[\"max-age\"]).toUTCString()),new Date(n.headers.get(\"Expires\")).getTime()-r<gt||function(t,e){if(void 0===ot)try{new Response(new ReadableStream),ot=!0}catch(t){ot=!1}ot?e(t.body):t.blob().then(e)}(e,function(e){var r=new self.Response(e,n);self.caches.open(ft).then(function(e){return e.put(vt(t.url),r)})}))}}(i,n,s),a=!0,e(null,t,r.headers.get(\"Cache-Control\"),r.headers.get(\"Expires\")))}).catch(function(t){return e(new Error(t.message))})};return s?function(t,e){if(!self.caches)return e(null);var r=vt(t.url);self.caches.open(ft).catch(e).then(function(t){t.match(r).catch(e).then(function(n){var i=function(t){if(!t)return!1;var e=new Date(t.headers.get(\"Expires\")),r=A(t.headers.get(\"Cache-Control\")||\"\");return e>Date.now()&&!r[\"no-cache\"]}(n);t.delete(r),i&&t.put(r,n.clone()),e(null,n,i)})})}(i,l):l(null,null),{cancel:function(){o=!0,a||n.abort()}}}var kt,Tt,At=function(t,e){if(!/^file:/.test(t.url)){if(self.fetch&&self.Request&&self.AbortController&&self.Request.prototype.hasOwnProperty(\"signal\"))return wt(t,e);if(bt()&&self.worker&&self.worker.actor)return self.worker.actor.send(\"getResource\",t,e)}return function(t,e){var r=new self.XMLHttpRequest;for(var n in r.open(t.method||\"GET\",t.url,!0),\"arrayBuffer\"===t.type&&(r.responseType=\"arraybuffer\"),t.headers)r.setRequestHeader(n,t.headers[n]);return\"json\"===t.type&&r.setRequestHeader(\"Accept\",\"application/json\"),r.withCredentials=\"include\"===t.credentials,r.onerror=function(){e(new Error(r.statusText))},r.onload=function(){if((r.status>=200&&r.status<300||0===r.status)&&null!==r.response){var n=r.response;if(\"json\"===t.type)try{n=JSON.parse(r.response)}catch(t){return e(t)}e(null,n,r.getResponseHeader(\"Cache-Control\"),r.getResponseHeader(\"Expires\"))}else e(new xt(r.statusText,r.status,t.url))},r.send(t.body),{cancel:function(){return r.abort()}}}(t,e)},Mt=function(t,e){return At(h(t,{type:\"arrayBuffer\"}),e)},St=function(t,e){return At(h(t,{method:\"POST\"}),e)};kt=[],Tt=0;var Et=function(t,e){if(Tt>=I.MAX_PARALLEL_IMAGE_REQUESTS){var r={requestParameters:t,callback:e,cancelled:!1,cancel:function(){this.cancelled=!0}};return kt.push(r),r}Tt++;var n=!1,i=function(){if(!n)for(n=!0,Tt--;kt.length&&Tt<I.MAX_PARALLEL_IMAGE_REQUESTS;){var t=kt.shift(),e=t.requestParameters,r=t.callback;t.cancelled||(t.cancel=Et(e,r).cancel)}},a=Mt(t,function(t,r,n,a){if(i(),t)e(t);else if(r){var o=new self.Image,s=self.URL||self.webkitURL;o.onload=function(){e(null,o),s.revokeObjectURL(o.src)},o.onerror=function(){return e(new Error(\"Could not load image. Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.\"))};var l=new self.Blob([new Uint8Array(r)],{type:\"image/png\"});o.cacheControl=n,o.expires=a,o.src=r.byteLength?s.createObjectURL(l):\"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAC0lEQVQYV2NgAAIAAAUAAarVyFEAAAAASUVORK5CYII=\"}});return{cancel:function(){a.cancel(),i()}}};function Ct(t,e,r){r[t]&&-1!==r[t].indexOf(e)||(r[t]=r[t]||[],r[t].push(e))}function Lt(t,e,r){if(r&&r[t]){var n=r[t].indexOf(e);-1!==n&&r[t].splice(n,1)}}var Pt=function(t,e){void 0===e&&(e={}),h(this,e),this.type=t},Ot=function(t){function e(e,r){void 0===r&&(r={}),t.call(this,\"error\",h({error:e},r))}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Pt),zt=function(){};zt.prototype.on=function(t,e){return this._listeners=this._listeners||{},Ct(t,e,this._listeners),this},zt.prototype.off=function(t,e){return Lt(t,e,this._listeners),Lt(t,e,this._oneTimeListeners),this},zt.prototype.once=function(t,e){return this._oneTimeListeners=this._oneTimeListeners||{},Ct(t,e,this._oneTimeListeners),this},zt.prototype.fire=function(t,e){\"string\"==typeof t&&(t=new Pt(t,e||{}));var r=t.type;if(this.listens(r)){t.target=this;for(var n=0,i=this._listeners&&this._listeners[r]?this._listeners[r].slice():[];n<i.length;n+=1)i[n].call(this,t);for(var a=0,o=this._oneTimeListeners&&this._oneTimeListeners[r]?this._oneTimeListeners[r].slice():[];a<o.length;a+=1){var s=o[a];Lt(r,s,this._oneTimeListeners),s.call(this,t)}var l=this._eventedParent;l&&(h(t,\"function\"==typeof this._eventedParentData?this._eventedParentData():this._eventedParentData),l.fire(t))}else t instanceof Ot&&console.error(t.error);return this},zt.prototype.listens=function(t){return this._listeners&&this._listeners[t]&&this._listeners[t].length>0||this._oneTimeListeners&&this._oneTimeListeners[t]&&this._oneTimeListeners[t].length>0||this._eventedParent&&this._eventedParent.listens(t)},zt.prototype.setEventedParent=function(t,e){return this._eventedParent=t,this._eventedParentData=e,this};var It={$version:8,$root:{version:{required:!0,type:\"enum\",values:[8]},name:{type:\"string\"},metadata:{type:\"*\"},center:{type:\"array\",value:\"number\"},zoom:{type:\"number\"},bearing:{type:\"number\",default:0,period:360,units:\"degrees\"},pitch:{type:\"number\",default:0,units:\"degrees\"},light:{type:\"light\"},sources:{required:!0,type:\"sources\"},sprite:{type:\"string\"},glyphs:{type:\"string\"},transition:{type:\"transition\"},layers:{required:!0,type:\"array\",value:\"layer\"}},sources:{\"*\":{type:\"source\"}},source:[\"source_vector\",\"source_raster\",\"source_raster_dem\",\"source_geojson\",\"source_video\",\"source_image\"],source_vector:{type:{required:!0,type:\"enum\",values:{vector:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},attribution:{type:\"string\"},\"*\":{type:\"*\"}},source_raster:{type:{required:!0,type:\"enum\",values:{raster:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},attribution:{type:\"string\"},\"*\":{type:\"*\"}},source_raster_dem:{type:{required:!0,type:\"enum\",values:{\"raster-dem\":{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},attribution:{type:\"string\"},encoding:{type:\"enum\",values:{terrarium:{},mapbox:{}},default:\"mapbox\"},\"*\":{type:\"*\"}},source_geojson:{type:{required:!0,type:\"enum\",values:{geojson:{}}},data:{type:\"*\"},maxzoom:{type:\"number\",default:18},attribution:{type:\"string\"},buffer:{type:\"number\",default:128,maximum:512,minimum:0},tolerance:{type:\"number\",default:.375},cluster:{type:\"boolean\",default:!1},clusterRadius:{type:\"number\",default:50,minimum:0},clusterMaxZoom:{type:\"number\"},clusterProperties:{type:\"*\"},lineMetrics:{type:\"boolean\",default:!1},generateId:{type:\"boolean\",default:!1}},source_video:{type:{required:!0,type:\"enum\",values:{video:{}}},urls:{required:!0,type:\"array\",value:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},source_image:{type:{required:!0,type:\"enum\",values:{image:{}}},url:{required:!0,type:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},layer:{id:{type:\"string\",required:!0},type:{type:\"enum\",values:{fill:{},line:{},symbol:{},circle:{},heatmap:{},\"fill-extrusion\":{},raster:{},hillshade:{},background:{}},required:!0},metadata:{type:\"*\"},source:{type:\"string\"},\"source-layer\":{type:\"string\"},minzoom:{type:\"number\",minimum:0,maximum:24},maxzoom:{type:\"number\",minimum:0,maximum:24},filter:{type:\"filter\"},layout:{type:\"layout\"},paint:{type:\"paint\"}},layout:[\"layout_fill\",\"layout_line\",\"layout_circle\",\"layout_heatmap\",\"layout_fill-extrusion\",\"layout_symbol\",\"layout_raster\",\"layout_hillshade\",\"layout_background\"],layout_background:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_fill:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_circle:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_heatmap:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},\"layout_fill-extrusion\":{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_line:{\"line-cap\":{type:\"enum\",values:{butt:{},round:{},square:{}},default:\"butt\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-join\":{type:\"enum\",values:{bevel:{},round:{},miter:{}},default:\"miter\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"line-miter-limit\":{type:\"number\",default:2,requires:[{\"line-join\":\"miter\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-round-limit\":{type:\"number\",default:1.05,requires:[{\"line-join\":\"round\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_symbol:{\"symbol-placement\":{type:\"enum\",values:{point:{},line:{},\"line-center\":{}},default:\"point\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-spacing\":{type:\"number\",default:250,minimum:1,units:\"pixels\",requires:[{\"symbol-placement\":\"line\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-avoid-edges\":{type:\"boolean\",default:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"symbol-z-order\":{type:\"enum\",values:{auto:{},\"viewport-y\":{},source:{}},default:\"auto\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-optional\":{type:\"boolean\",default:!1,requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-size\":{type:\"number\",default:1,minimum:0,units:\"factor of the original icon size\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-text-fit\":{type:\"enum\",values:{none:{},width:{},height:{},both:{}},default:\"none\",requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-text-fit-padding\":{type:\"array\",value:\"number\",length:4,default:[0,0,0,0],units:\"pixels\",requires:[\"icon-image\",\"text-field\",{\"icon-text-fit\":[\"both\",\"width\",\"height\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-image\":{type:\"string\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-keep-upright\":{type:\"boolean\",default:!1,requires:[\"icon-image\",{\"icon-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-offset\":{type:\"array\",value:\"number\",length:2,default:[0,0],requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-anchor\":{type:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-field\":{type:\"formatted\",default:\"\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-font\":{type:\"array\",value:\"string\",default:[\"Open Sans Regular\",\"Arial Unicode MS Regular\"],requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-size\":{type:\"number\",default:16,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-width\":{type:\"number\",default:10,minimum:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-line-height\":{type:\"number\",default:1.2,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-letter-spacing\":{type:\"number\",default:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-justify\":{type:\"enum\",values:{auto:{},left:{},center:{},right:{}},default:\"center\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-radial-offset\":{type:\"number\",units:\"ems\",default:0,requires:[{\"!\":\"text-offset\"}],\"property-type\":\"data-driven\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]}},\"text-variable-anchor\":{type:\"array\",value:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},requires:[{\"!\":\"text-anchor\"},{\"!\":\"text-offset\"},{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-anchor\":{type:\"enum\",requires:[\"text-field\"],values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-angle\":{type:\"number\",default:45,units:\"degrees\",requires:[\"text-field\",{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-keep-upright\":{type:\"boolean\",default:!0,requires:[\"text-field\",{\"text-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-transform\":{type:\"enum\",values:{none:{},uppercase:{},lowercase:{}},default:\"none\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-offset\":{type:\"array\",value:\"number\",units:\"ems\",length:2,default:[0,0],requires:[\"text-field\",{\"!\":\"text-radial-offset\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-optional\":{type:\"boolean\",default:!1,requires:[\"text-field\",\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_raster:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_hillshade:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},filter:{type:\"array\",value:\"*\"},filter_operator:{type:\"enum\",values:{\"==\":{},\"!=\":{},\">\":{},\">=\":{},\"<\":{},\"<=\":{},in:{},\"!in\":{},all:{},any:{},none:{},has:{},\"!has\":{}}},geometry_type:{type:\"enum\",values:{Point:{},LineString:{},Polygon:{}}},function:{expression:{type:\"expression\"},stops:{type:\"array\",value:\"function_stop\"},base:{type:\"number\",default:1,minimum:0},property:{type:\"string\",default:\"$zoom\"},type:{type:\"enum\",values:{identity:{},exponential:{},interval:{},categorical:{}},default:\"exponential\"},colorSpace:{type:\"enum\",values:{rgb:{},lab:{},hcl:{}},default:\"rgb\"},default:{type:\"*\",required:!1}},function_stop:{type:\"array\",minimum:0,maximum:22,value:[\"number\",\"color\"],length:2},expression:{type:\"array\",value:\"*\",minimum:1},expression_name:{type:\"enum\",values:{let:{group:\"Variable binding\"},var:{group:\"Variable binding\"},literal:{group:\"Types\"},array:{group:\"Types\"},at:{group:\"Lookup\"},case:{group:\"Decision\"},match:{group:\"Decision\"},coalesce:{group:\"Decision\"},step:{group:\"Ramps, scales, curves\"},interpolate:{group:\"Ramps, scales, curves\"},\"interpolate-hcl\":{group:\"Ramps, scales, curves\"},\"interpolate-lab\":{group:\"Ramps, scales, curves\"},ln2:{group:\"Math\"},pi:{group:\"Math\"},e:{group:\"Math\"},typeof:{group:\"Types\"},string:{group:\"Types\"},number:{group:\"Types\"},boolean:{group:\"Types\"},object:{group:\"Types\"},collator:{group:\"Types\"},format:{group:\"Types\"},\"number-format\":{group:\"Types\"},\"to-string\":{group:\"Types\"},\"to-number\":{group:\"Types\"},\"to-boolean\":{group:\"Types\"},\"to-rgba\":{group:\"Color\"},\"to-color\":{group:\"Types\"},rgb:{group:\"Color\"},rgba:{group:\"Color\"},get:{group:\"Lookup\"},has:{group:\"Lookup\"},length:{group:\"Lookup\"},properties:{group:\"Feature data\"},\"feature-state\":{group:\"Feature data\"},\"geometry-type\":{group:\"Feature data\"},id:{group:\"Feature data\"},zoom:{group:\"Zoom\"},\"heatmap-density\":{group:\"Heatmap\"},\"line-progress\":{group:\"Feature data\"},accumulated:{group:\"Feature data\"},\"+\":{group:\"Math\"},\"*\":{group:\"Math\"},\"-\":{group:\"Math\"},\"/\":{group:\"Math\"},\"%\":{group:\"Math\"},\"^\":{group:\"Math\"},sqrt:{group:\"Math\"},log10:{group:\"Math\"},ln:{group:\"Math\"},log2:{group:\"Math\"},sin:{group:\"Math\"},cos:{group:\"Math\"},tan:{group:\"Math\"},asin:{group:\"Math\"},acos:{group:\"Math\"},atan:{group:\"Math\"},min:{group:\"Math\"},max:{group:\"Math\"},round:{group:\"Math\"},abs:{group:\"Math\"},ceil:{group:\"Math\"},floor:{group:\"Math\"},\"==\":{group:\"Decision\"},\"!=\":{group:\"Decision\"},\">\":{group:\"Decision\"},\"<\":{group:\"Decision\"},\">=\":{group:\"Decision\"},\"<=\":{group:\"Decision\"},all:{group:\"Decision\"},any:{group:\"Decision\"},\"!\":{group:\"Decision\"},\"is-supported-script\":{group:\"String\"},upcase:{group:\"String\"},downcase:{group:\"String\"},concat:{group:\"String\"},\"resolved-locale\":{group:\"String\"}}},light:{anchor:{type:\"enum\",default:\"viewport\",values:{map:{},viewport:{}},\"property-type\":\"data-constant\",transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]}},position:{type:\"array\",default:[1.15,210,30],length:3,value:\"number\",\"property-type\":\"data-constant\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]}},color:{type:\"color\",\"property-type\":\"data-constant\",default:\"#ffffff\",expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0},intensity:{type:\"number\",\"property-type\":\"data-constant\",default:.5,minimum:0,maximum:1,expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0}},paint:[\"paint_fill\",\"paint_line\",\"paint_circle\",\"paint_heatmap\",\"paint_fill-extrusion\",\"paint_symbol\",\"paint_raster\",\"paint_hillshade\",\"paint_background\"],paint_fill:{\"fill-antialias\":{type:\"boolean\",default:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-outline-color\":{type:\"color\",transition:!0,requires:[{\"!\":\"fill-pattern\"},{\"fill-antialias\":!0}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"}},\"paint_fill-extrusion\":{\"fill-extrusion-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-extrusion-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-extrusion-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"fill-extrusion-height\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-base\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,requires:[\"fill-extrusion-height\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-vertical-gradient\":{type:\"boolean\",default:!0,transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_line:{\"line-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"line-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-width\":{type:\"number\",default:1,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-gap-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-offset\":{type:\"number\",default:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-dasharray\":{type:\"array\",value:\"number\",minimum:0,transition:!0,units:\"line widths\",requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"line-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"line-gradient\":{type:\"color\",transition:!1,requires:[{\"!\":\"line-dasharray\"},{\"!\":\"line-pattern\"},{source:\"geojson\",has:{lineMetrics:!0}}],expression:{interpolated:!0,parameters:[\"line-progress\"]},\"property-type\":\"color-ramp\"}},paint_circle:{\"circle-radius\":{type:\"number\",default:5,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-blur\":{type:\"number\",default:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"circle-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-scale\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-stroke-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"}},paint_heatmap:{\"heatmap-radius\":{type:\"number\",default:30,minimum:1,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-weight\":{type:\"number\",default:1,minimum:0,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-intensity\":{type:\"number\",default:1,minimum:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"heatmap-color\":{type:\"color\",default:[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,\"rgba(0, 0, 255, 0)\",.1,\"royalblue\",.3,\"cyan\",.5,\"lime\",.7,\"yellow\",1,\"red\"],transition:!1,expression:{interpolated:!0,parameters:[\"heatmap-density\"]},\"property-type\":\"color-ramp\"},\"heatmap-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_symbol:{\"icon-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"icon-image\",\"icon-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"text-field\",\"text-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_raster:{\"raster-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-hue-rotate\":{type:\"number\",default:0,period:360,transition:!0,units:\"degrees\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-min\":{type:\"number\",default:0,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-max\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-saturation\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-contrast\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-resampling\":{type:\"enum\",values:{linear:{},nearest:{}},default:\"linear\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-fade-duration\":{type:\"number\",default:300,minimum:0,transition:!1,units:\"milliseconds\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_hillshade:{\"hillshade-illumination-direction\":{type:\"number\",default:335,minimum:0,maximum:359,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-illumination-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-exaggeration\":{type:\"number\",default:.5,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-shadow-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-highlight-color\":{type:\"color\",default:\"#FFFFFF\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-accent-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_background:{\"background-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"background-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"background-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"background-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},transition:{duration:{type:\"number\",default:300,minimum:0,units:\"milliseconds\"},delay:{type:\"number\",default:0,minimum:0,units:\"milliseconds\"}},\"property-type\":{\"data-driven\":{type:\"property-type\"},\"cross-faded\":{type:\"property-type\"},\"cross-faded-data-driven\":{type:\"property-type\"},\"color-ramp\":{type:\"property-type\"},\"data-constant\":{type:\"property-type\"},constant:{type:\"property-type\"}}},Dt=function(t,e,r,n){this.message=(t?t+\": \":\"\")+r,n&&(this.identifier=n),null!=e&&e.__line__&&(this.line=e.__line__)};function Rt(t){var e=t.key,r=t.value;return r?[new Dt(e,r,\"constants have been deprecated as of v8\")]:[]}function Ft(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}function Bt(t){return t instanceof Number||t instanceof String||t instanceof Boolean}function Nt(t){return Bt(t)?t.valueOf():t}function jt(t){if(Array.isArray(t))return t.map(jt);if(t instanceof Object&&!Bt(t)){var e={};for(var r in t)e[r]=jt(t[r]);return e}return Nt(t)}var Ut=function(t){function e(e,r){t.call(this,r),this.message=r,this.key=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Error),Vt=function(t,e){void 0===e&&(e=[]),this.parent=t,this.bindings={};for(var r=0,n=e;r<n.length;r+=1){var i=n[r],a=i[0],o=i[1];this.bindings[a]=o}};Vt.prototype.concat=function(t){return new Vt(this,t)},Vt.prototype.get=function(t){if(this.bindings[t])return this.bindings[t];if(this.parent)return this.parent.get(t);throw new Error(t+\" not found in scope.\")},Vt.prototype.has=function(t){return!!this.bindings[t]||!!this.parent&&this.parent.has(t)};var qt={kind:\"null\"},Ht={kind:\"number\"},Gt={kind:\"string\"},Yt={kind:\"boolean\"},Wt={kind:\"color\"},Xt={kind:\"object\"},Zt={kind:\"value\"},Jt={kind:\"collator\"},Kt={kind:\"formatted\"};function $t(t,e){return{kind:\"array\",itemType:t,N:e}}function Qt(t){if(\"array\"===t.kind){var e=Qt(t.itemType);return\"number\"==typeof t.N?\"array<\"+e+\", \"+t.N+\">\":\"value\"===t.itemType.kind?\"array\":\"array<\"+e+\">\"}return t.kind}var te=[qt,Ht,Gt,Yt,Wt,Kt,Xt,$t(Zt)];function ee(t,e){if(\"error\"===e.kind)return null;if(\"array\"===t.kind){if(\"array\"===e.kind&&(0===e.N&&\"value\"===e.itemType.kind||!ee(t.itemType,e.itemType))&&(\"number\"!=typeof t.N||t.N===e.N))return null}else{if(t.kind===e.kind)return null;if(\"value\"===t.kind)for(var r=0,n=te;r<n.length;r+=1)if(!ee(n[r],e))return null}return\"Expected \"+Qt(t)+\" but found \"+Qt(e)+\" instead.\"}var re=e(function(t,e){var r={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],rebeccapurple:[102,51,153,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function n(t){return(t=Math.round(t))<0?0:t>255?255:t}function i(t){return t<0?0:t>1?1:t}function a(t){return\"%\"===t[t.length-1]?n(parseFloat(t)/100*255):n(parseInt(t))}function o(t){return\"%\"===t[t.length-1]?i(parseFloat(t)/100):i(parseFloat(t))}function s(t,e,r){return r<0?r+=1:r>1&&(r-=1),6*r<1?t+(e-t)*r*6:2*r<1?e:3*r<2?t+(e-t)*(2/3-r)*6:t}try{e.parseCSSColor=function(t){var e,i=t.replace(/ /g,\"\").toLowerCase();if(i in r)return r[i].slice();if(\"#\"===i[0])return 4===i.length?(e=parseInt(i.substr(1),16))>=0&&e<=4095?[(3840&e)>>4|(3840&e)>>8,240&e|(240&e)>>4,15&e|(15&e)<<4,1]:null:7===i.length&&(e=parseInt(i.substr(1),16))>=0&&e<=16777215?[(16711680&e)>>16,(65280&e)>>8,255&e,1]:null;var l=i.indexOf(\"(\"),c=i.indexOf(\")\");if(-1!==l&&c+1===i.length){var u=i.substr(0,l),h=i.substr(l+1,c-(l+1)).split(\",\"),f=1;switch(u){case\"rgba\":if(4!==h.length)return null;f=o(h.pop());case\"rgb\":return 3!==h.length?null:[a(h[0]),a(h[1]),a(h[2]),f];case\"hsla\":if(4!==h.length)return null;f=o(h.pop());case\"hsl\":if(3!==h.length)return null;var p=(parseFloat(h[0])%360+360)%360/360,d=o(h[1]),g=o(h[2]),v=g<=.5?g*(d+1):g+d-g*d,m=2*g-v;return[n(255*s(m,v,p+1/3)),n(255*s(m,v,p)),n(255*s(m,v,p-1/3)),f];default:return null}}return null}}catch(t){}}).parseCSSColor,ne=function(t,e,r,n){void 0===n&&(n=1),this.r=t,this.g=e,this.b=r,this.a=n};ne.parse=function(t){if(t){if(t instanceof ne)return t;if(\"string\"==typeof t){var e=re(t);if(e)return new ne(e[0]/255*e[3],e[1]/255*e[3],e[2]/255*e[3],e[3])}}},ne.prototype.toString=function(){var t=this.toArray(),e=t[0],r=t[1],n=t[2],i=t[3];return\"rgba(\"+Math.round(e)+\",\"+Math.round(r)+\",\"+Math.round(n)+\",\"+i+\")\"},ne.prototype.toArray=function(){var t=this.r,e=this.g,r=this.b,n=this.a;return 0===n?[0,0,0,0]:[255*t/n,255*e/n,255*r/n,n]},ne.black=new ne(0,0,0,1),ne.white=new ne(1,1,1,1),ne.transparent=new ne(0,0,0,0),ne.red=new ne(1,0,0,1);var ie=function(t,e,r){this.sensitivity=t?e?\"variant\":\"case\":e?\"accent\":\"base\",this.locale=r,this.collator=new Intl.Collator(this.locale?this.locale:[],{sensitivity:this.sensitivity,usage:\"search\"})};ie.prototype.compare=function(t,e){return this.collator.compare(t,e)},ie.prototype.resolvedLocale=function(){return new Intl.Collator(this.locale?this.locale:[]).resolvedOptions().locale};var ae=function(t,e,r){this.text=t,this.scale=e,this.fontStack=r},oe=function(t){this.sections=t};function se(t,e,r,n){return\"number\"==typeof t&&t>=0&&t<=255&&\"number\"==typeof e&&e>=0&&e<=255&&\"number\"==typeof r&&r>=0&&r<=255?void 0===n||\"number\"==typeof n&&n>=0&&n<=1?null:\"Invalid rgba value [\"+[t,e,r,n].join(\", \")+\"]: 'a' must be between 0 and 1.\":\"Invalid rgba value [\"+(\"number\"==typeof n?[t,e,r,n]:[t,e,r]).join(\", \")+\"]: 'r', 'g', and 'b' must be between 0 and 255.\"}function le(t){if(null===t)return qt;if(\"string\"==typeof t)return Gt;if(\"boolean\"==typeof t)return Yt;if(\"number\"==typeof t)return Ht;if(t instanceof ne)return Wt;if(t instanceof ie)return Jt;if(t instanceof oe)return Kt;if(Array.isArray(t)){for(var e,r=t.length,n=0,i=t;n<i.length;n+=1){var a=le(i[n]);if(e){if(e===a)continue;e=Zt;break}e=a}return $t(e||Zt,r)}return Xt}function ce(t){var e=typeof t;return null===t?\"\":\"string\"===e||\"number\"===e||\"boolean\"===e?String(t):t instanceof ne||t instanceof oe?t.toString():JSON.stringify(t)}oe.fromString=function(t){return new oe([new ae(t,null,null)])},oe.prototype.toString=function(){return this.sections.map(function(t){return t.text}).join(\"\")},oe.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.text);var i={};n.fontStack&&(i[\"text-font\"]=[\"literal\",n.fontStack.split(\",\")]),n.scale&&(i[\"font-scale\"]=n.scale),t.push(i)}return t};var ue=function(t,e){this.type=t,this.value=e};ue.parse=function(t,e){if(2!==t.length)return e.error(\"'literal' expression requires exactly one argument, but found \"+(t.length-1)+\" instead.\");if(!function t(e){if(null===e)return!0;if(\"string\"==typeof e)return!0;if(\"boolean\"==typeof e)return!0;if(\"number\"==typeof e)return!0;if(e instanceof ne)return!0;if(e instanceof ie)return!0;if(e instanceof oe)return!0;if(Array.isArray(e)){for(var r=0,n=e;r<n.length;r+=1)if(!t(n[r]))return!1;return!0}if(\"object\"==typeof e){for(var i in e)if(!t(e[i]))return!1;return!0}return!1}(t[1]))return e.error(\"invalid value\");var r=t[1],n=le(r),i=e.expectedType;return\"array\"!==n.kind||0!==n.N||!i||\"array\"!==i.kind||\"number\"==typeof i.N&&0!==i.N||(n=i),new ue(n,r)},ue.prototype.evaluate=function(){return this.value},ue.prototype.eachChild=function(){},ue.prototype.possibleOutputs=function(){return[this.value]},ue.prototype.serialize=function(){return\"array\"===this.type.kind||\"object\"===this.type.kind?[\"literal\",this.value]:this.value instanceof ne?[\"rgba\"].concat(this.value.toArray()):this.value instanceof oe?this.value.serialize():this.value};var he=function(t){this.name=\"ExpressionEvaluationError\",this.message=t};he.prototype.toJSON=function(){return this.message};var fe={string:Gt,number:Ht,boolean:Yt,object:Xt},pe=function(t,e){this.type=t,this.args=e};pe.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r,n=1,i=t[0];if(\"array\"===i){var a,o;if(t.length>2){var s=t[1];if(\"string\"!=typeof s||!(s in fe)||\"object\"===s)return e.error('The item type argument of \"array\" must be one of string, number, boolean',1);a=fe[s],n++}else a=Zt;if(t.length>3){if(null!==t[2]&&(\"number\"!=typeof t[2]||t[2]<0||t[2]!==Math.floor(t[2])))return e.error('The length argument to \"array\" must be a positive integer literal',2);o=t[2],n++}r=$t(a,o)}else r=fe[i];for(var l=[];n<t.length;n++){var c=e.parse(t[n],n,Zt);if(!c)return null;l.push(c)}return new pe(r,l)},pe.prototype.evaluate=function(t){for(var e=0;e<this.args.length;e++){var r=this.args[e].evaluate(t);if(!ee(this.type,le(r)))return r;if(e===this.args.length-1)throw new he(\"Expected value to be of type \"+Qt(this.type)+\", but found \"+Qt(le(r))+\" instead.\")}return null},pe.prototype.eachChild=function(t){this.args.forEach(t)},pe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},pe.prototype.serialize=function(){var t=this.type,e=[t.kind];if(\"array\"===t.kind){var r=t.itemType;if(\"string\"===r.kind||\"number\"===r.kind||\"boolean\"===r.kind){e.push(r.kind);var n=t.N;(\"number\"==typeof n||this.args.length>1)&&e.push(n)}}return e.concat(this.args.map(function(t){return t.serialize()}))};var de=function(t){this.type=Kt,this.sections=t};de.parse=function(t,e){if(t.length<3)return e.error(\"Expected at least two arguments.\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");for(var r=[],n=1;n<t.length-1;n+=2){var i=e.parse(t[n],1,Zt);if(!i)return null;var a=i.type.kind;if(\"string\"!==a&&\"value\"!==a&&\"null\"!==a)return e.error(\"Formatted text type must be 'string', 'value', or 'null'.\");var o=t[n+1];if(\"object\"!=typeof o||Array.isArray(o))return e.error(\"Format options argument must be an object.\");var s=null;if(o[\"font-scale\"]&&!(s=e.parse(o[\"font-scale\"],1,Ht)))return null;var l=null;if(o[\"text-font\"]&&!(l=e.parse(o[\"text-font\"],1,$t(Gt))))return null;r.push({text:i,scale:s,font:l})}return new de(r)},de.prototype.evaluate=function(t){return new oe(this.sections.map(function(e){return new ae(ce(e.text.evaluate(t)),e.scale?e.scale.evaluate(t):null,e.font?e.font.evaluate(t).join(\",\"):null)}))},de.prototype.eachChild=function(t){for(var e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t(n.text),n.scale&&t(n.scale),n.font&&t(n.font)}},de.prototype.possibleOutputs=function(){return[void 0]},de.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.text.serialize());var i={};n.scale&&(i[\"font-scale\"]=n.scale.serialize()),n.font&&(i[\"text-font\"]=n.font.serialize()),t.push(i)}return t};var ge={\"to-boolean\":Yt,\"to-color\":Wt,\"to-number\":Ht,\"to-string\":Gt},ve=function(t,e){this.type=t,this.args=e};ve.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r=t[0];if((\"to-boolean\"===r||\"to-string\"===r)&&2!==t.length)return e.error(\"Expected one argument.\");for(var n=ge[r],i=[],a=1;a<t.length;a++){var o=e.parse(t[a],a,Zt);if(!o)return null;i.push(o)}return new ve(n,i)},ve.prototype.evaluate=function(t){if(\"boolean\"===this.type.kind)return Boolean(this.args[0].evaluate(t));if(\"color\"===this.type.kind){for(var e,r,n=0,i=this.args;n<i.length;n+=1){if(r=null,(e=i[n].evaluate(t))instanceof ne)return e;if(\"string\"==typeof e){var a=t.parseColor(e);if(a)return a}else if(Array.isArray(e)&&!(r=e.length<3||e.length>4?\"Invalid rbga value \"+JSON.stringify(e)+\": expected an array containing either three or four numeric values.\":se(e[0],e[1],e[2],e[3])))return new ne(e[0]/255,e[1]/255,e[2]/255,e[3])}throw new he(r||\"Could not parse color from value '\"+(\"string\"==typeof e?e:String(JSON.stringify(e)))+\"'\")}if(\"number\"===this.type.kind){for(var o=null,s=0,l=this.args;s<l.length;s+=1){if(null===(o=l[s].evaluate(t)))return 0;var c=Number(o);if(!isNaN(c))return c}throw new he(\"Could not convert \"+JSON.stringify(o)+\" to number.\")}return\"formatted\"===this.type.kind?oe.fromString(ce(this.args[0].evaluate(t))):ce(this.args[0].evaluate(t))},ve.prototype.eachChild=function(t){this.args.forEach(t)},ve.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},ve.prototype.serialize=function(){if(\"formatted\"===this.type.kind)return new de([{text:this.args[0],scale:null,font:null}]).serialize();var t=[\"to-\"+this.type.kind];return this.eachChild(function(e){t.push(e.serialize())}),t};var me=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],ye=function(){this.globals=null,this.feature=null,this.featureState=null,this._parseColorCache={}};ye.prototype.id=function(){return this.feature&&\"id\"in this.feature?this.feature.id:null},ye.prototype.geometryType=function(){return this.feature?\"number\"==typeof this.feature.type?me[this.feature.type]:this.feature.type:null},ye.prototype.properties=function(){return this.feature&&this.feature.properties||{}},ye.prototype.parseColor=function(t){var e=this._parseColorCache[t];return e||(e=this._parseColorCache[t]=ne.parse(t)),e};var xe=function(t,e,r,n){this.name=t,this.type=e,this._evaluate=r,this.args=n};xe.prototype.evaluate=function(t){return this._evaluate(t,this.args)},xe.prototype.eachChild=function(t){this.args.forEach(t)},xe.prototype.possibleOutputs=function(){return[void 0]},xe.prototype.serialize=function(){return[this.name].concat(this.args.map(function(t){return t.serialize()}))},xe.parse=function(t,e){var r,n=t[0],i=xe.definitions[n];if(!i)return e.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0);for(var a=Array.isArray(i)?i[0]:i.type,o=Array.isArray(i)?[[i[1],i[2]]]:i.overloads,s=o.filter(function(e){var r=e[0];return!Array.isArray(r)||r.length===t.length-1}),l=null,c=0,u=s;c<u.length;c+=1){var h=u[c],f=h[0],p=h[1];l=new Ae(e.registry,e.path,null,e.scope);for(var d=[],g=!1,v=1;v<t.length;v++){var m=t[v],y=Array.isArray(f)?f[v-1]:f.type,x=l.parse(m,1+d.length,y);if(!x){g=!0;break}d.push(x)}if(!g)if(Array.isArray(f)&&f.length!==d.length)l.error(\"Expected \"+f.length+\" arguments, but found \"+d.length+\" instead.\");else{for(var b=0;b<d.length;b++){var _=Array.isArray(f)?f[b]:f.type,w=d[b];l.concat(b+1).checkSubtype(_,w.type)}if(0===l.errors.length)return new xe(n,a,p,d)}}if(1===s.length)(r=e.errors).push.apply(r,l.errors);else{for(var k=(s.length?s:o).map(function(t){var e;return e=t[0],Array.isArray(e)?\"(\"+e.map(Qt).join(\", \")+\")\":\"(\"+Qt(e.type)+\"...)\"}).join(\" | \"),T=[],A=1;A<t.length;A++){var M=e.parse(t[A],1+T.length);if(!M)return null;T.push(Qt(M.type))}e.error(\"Expected arguments of type \"+k+\", but found (\"+T.join(\", \")+\") instead.\")}return null},xe.register=function(t,e){for(var r in xe.definitions=e,e)t[r]=xe};var be=function(t,e,r){this.type=Jt,this.locale=r,this.caseSensitive=t,this.diacriticSensitive=e};function _e(t){if(t instanceof xe){if(\"get\"===t.name&&1===t.args.length)return!1;if(\"feature-state\"===t.name)return!1;if(\"has\"===t.name&&1===t.args.length)return!1;if(\"properties\"===t.name||\"geometry-type\"===t.name||\"id\"===t.name)return!1;if(/^filter-/.test(t.name))return!1}var e=!0;return t.eachChild(function(t){e&&!_e(t)&&(e=!1)}),e}function we(t){if(t instanceof xe&&\"feature-state\"===t.name)return!1;var e=!0;return t.eachChild(function(t){e&&!we(t)&&(e=!1)}),e}function ke(t,e){if(t instanceof xe&&e.indexOf(t.name)>=0)return!1;var r=!0;return t.eachChild(function(t){r&&!ke(t,e)&&(r=!1)}),r}be.parse=function(t,e){if(2!==t.length)return e.error(\"Expected one argument.\");var r=t[1];if(\"object\"!=typeof r||Array.isArray(r))return e.error(\"Collator options argument must be an object.\");var n=e.parse(void 0!==r[\"case-sensitive\"]&&r[\"case-sensitive\"],1,Yt);if(!n)return null;var i=e.parse(void 0!==r[\"diacritic-sensitive\"]&&r[\"diacritic-sensitive\"],1,Yt);if(!i)return null;var a=null;return r.locale&&!(a=e.parse(r.locale,1,Gt))?null:new be(n,i,a)},be.prototype.evaluate=function(t){return new ie(this.caseSensitive.evaluate(t),this.diacriticSensitive.evaluate(t),this.locale?this.locale.evaluate(t):null)},be.prototype.eachChild=function(t){t(this.caseSensitive),t(this.diacriticSensitive),this.locale&&t(this.locale)},be.prototype.possibleOutputs=function(){return[void 0]},be.prototype.serialize=function(){var t={};return t[\"case-sensitive\"]=this.caseSensitive.serialize(),t[\"diacritic-sensitive\"]=this.diacriticSensitive.serialize(),this.locale&&(t.locale=this.locale.serialize()),[\"collator\",t]};var Te=function(t,e){this.type=e.type,this.name=t,this.boundExpression=e};Te.parse=function(t,e){if(2!==t.length||\"string\"!=typeof t[1])return e.error(\"'var' expression requires exactly one string literal argument.\");var r=t[1];return e.scope.has(r)?new Te(r,e.scope.get(r)):e.error('Unknown variable \"'+r+'\". Make sure \"'+r+'\" has been bound in an enclosing \"let\" expression before using it.',1)},Te.prototype.evaluate=function(t){return this.boundExpression.evaluate(t)},Te.prototype.eachChild=function(){},Te.prototype.possibleOutputs=function(){return[void 0]},Te.prototype.serialize=function(){return[\"var\",this.name]};var Ae=function(t,e,r,n,i){void 0===e&&(e=[]),void 0===n&&(n=new Vt),void 0===i&&(i=[]),this.registry=t,this.path=e,this.key=e.map(function(t){return\"[\"+t+\"]\"}).join(\"\"),this.scope=n,this.errors=i,this.expectedType=r};function Me(t,e){for(var r,n,i=t.length-1,a=0,o=i,s=0;a<=o;)if(r=t[s=Math.floor((a+o)/2)],n=t[s+1],r<=e){if(s===i||e<n)return s;a=s+1}else{if(!(r>e))throw new he(\"Input is not a number.\");o=s-1}return 0}Ae.prototype.parse=function(t,e,r,n,i){return void 0===i&&(i={}),e?this.concat(e,r,n)._parse(t,i):this._parse(t,i)},Ae.prototype._parse=function(t,e){function r(t,e,r){return\"assert\"===r?new pe(e,[t]):\"coerce\"===r?new ve(e,[t]):t}if(null!==t&&\"string\"!=typeof t&&\"boolean\"!=typeof t&&\"number\"!=typeof t||(t=[\"literal\",t]),Array.isArray(t)){if(0===t.length)return this.error('Expected an array with at least one element. If you wanted a literal array, use [\"literal\", []].');var n=t[0];if(\"string\"!=typeof n)return this.error(\"Expression name must be a string, but found \"+typeof n+' instead. If you wanted a literal array, use [\"literal\", [...]].',0),null;var i=this.registry[n];if(i){var a=i.parse(t,this);if(!a)return null;if(this.expectedType){var o=this.expectedType,s=a.type;if(\"string\"!==o.kind&&\"number\"!==o.kind&&\"boolean\"!==o.kind&&\"object\"!==o.kind&&\"array\"!==o.kind||\"value\"!==s.kind)if(\"color\"!==o.kind&&\"formatted\"!==o.kind||\"value\"!==s.kind&&\"string\"!==s.kind){if(this.checkSubtype(o,s))return null}else a=r(a,o,e.typeAnnotation||\"coerce\");else a=r(a,o,e.typeAnnotation||\"assert\")}if(!(a instanceof ue)&&function t(e){if(e instanceof Te)return t(e.boundExpression);if(e instanceof xe&&\"error\"===e.name)return!1;if(e instanceof be)return!1;var r=e instanceof ve||e instanceof pe,n=!0;return e.eachChild(function(e){n=r?n&&t(e):n&&e instanceof ue}),!!n&&(_e(e)&&ke(e,[\"zoom\",\"heatmap-density\",\"line-progress\",\"accumulated\",\"is-supported-script\"]))}(a)){var l=new ye;try{a=new ue(a.type,a.evaluate(l))}catch(t){return this.error(t.message),null}}return a}return this.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0)}return void 0===t?this.error(\"'undefined' value invalid. Use null instead.\"):\"object\"==typeof t?this.error('Bare objects invalid. Use [\"literal\", {...}] instead.'):this.error(\"Expected an array, but found \"+typeof t+\" instead.\")},Ae.prototype.concat=function(t,e,r){var n=\"number\"==typeof t?this.path.concat(t):this.path,i=r?this.scope.concat(r):this.scope;return new Ae(this.registry,n,e||null,i,this.errors)},Ae.prototype.error=function(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];var n=\"\"+this.key+e.map(function(t){return\"[\"+t+\"]\"}).join(\"\");this.errors.push(new Ut(n,t))},Ae.prototype.checkSubtype=function(t,e){var r=ee(t,e);return r&&this.error(r),r};var Se=function(t,e,r){this.type=t,this.input=e,this.labels=[],this.outputs=[];for(var n=0,i=r;n<i.length;n+=1){var a=i[n],o=a[0],s=a[1];this.labels.push(o),this.outputs.push(s)}};function Ee(t,e,r){return t*(1-r)+e*r}Se.parse=function(t,e){if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");var r=e.parse(t[1],1,Ht);if(!r)return null;var n=[],i=null;e.expectedType&&\"value\"!==e.expectedType.kind&&(i=e.expectedType);for(var a=1;a<t.length;a+=2){var o=1===a?-1/0:t[a],s=t[a+1],l=a,c=a+1;if(\"number\"!=typeof o)return e.error('Input/output pairs for \"step\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',l);if(n.length&&n[n.length-1][0]>=o)return e.error('Input/output pairs for \"step\" expressions must be arranged with input values in strictly ascending order.',l);var u=e.parse(s,c,i);if(!u)return null;i=i||u.type,n.push([o,u])}return new Se(i,r,n)},Se.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;return n>=e[i-1]?r[i-1].evaluate(t):r[Me(e,n)].evaluate(t)},Se.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},Se.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()}))},Se.prototype.serialize=function(){for(var t=[\"step\",this.input.serialize()],e=0;e<this.labels.length;e++)e>0&&t.push(this.labels[e]),t.push(this.outputs[e].serialize());return t};var Ce=Object.freeze({number:Ee,color:function(t,e,r){return new ne(Ee(t.r,e.r,r),Ee(t.g,e.g,r),Ee(t.b,e.b,r),Ee(t.a,e.a,r))},array:function(t,e,r){return t.map(function(t,n){return Ee(t,e[n],r)})}}),Le=.95047,Pe=1,Oe=1.08883,ze=4/29,Ie=6/29,De=3*Ie*Ie,Re=Ie*Ie*Ie,Fe=Math.PI/180,Be=180/Math.PI;function Ne(t){return t>Re?Math.pow(t,1/3):t/De+ze}function je(t){return t>Ie?t*t*t:De*(t-ze)}function Ue(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function Ve(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function qe(t){var e=Ve(t.r),r=Ve(t.g),n=Ve(t.b),i=Ne((.4124564*e+.3575761*r+.1804375*n)/Le),a=Ne((.2126729*e+.7151522*r+.072175*n)/Pe);return{l:116*a-16,a:500*(i-a),b:200*(a-Ne((.0193339*e+.119192*r+.9503041*n)/Oe)),alpha:t.a}}function He(t){var e=(t.l+16)/116,r=isNaN(t.a)?e:e+t.a/500,n=isNaN(t.b)?e:e-t.b/200;return e=Pe*je(e),r=Le*je(r),n=Oe*je(n),new ne(Ue(3.2404542*r-1.5371385*e-.4985314*n),Ue(-.969266*r+1.8760108*e+.041556*n),Ue(.0556434*r-.2040259*e+1.0572252*n),t.alpha)}var Ge={forward:qe,reverse:He,interpolate:function(t,e,r){return{l:Ee(t.l,e.l,r),a:Ee(t.a,e.a,r),b:Ee(t.b,e.b,r),alpha:Ee(t.alpha,e.alpha,r)}}},Ye={forward:function(t){var e=qe(t),r=e.l,n=e.a,i=e.b,a=Math.atan2(i,n)*Be;return{h:a<0?a+360:a,c:Math.sqrt(n*n+i*i),l:r,alpha:t.a}},reverse:function(t){var e=t.h*Fe,r=t.c;return He({l:t.l,a:Math.cos(e)*r,b:Math.sin(e)*r,alpha:t.alpha})},interpolate:function(t,e,r){return{h:function(t,e,r){var n=e-t;return t+r*(n>180||n<-180?n-360*Math.round(n/360):n)}(t.h,e.h,r),c:Ee(t.c,e.c,r),l:Ee(t.l,e.l,r),alpha:Ee(t.alpha,e.alpha,r)}}},We=Object.freeze({lab:Ge,hcl:Ye}),Xe=function(t,e,r,n,i){this.type=t,this.operator=e,this.interpolation=r,this.input=n,this.labels=[],this.outputs=[];for(var a=0,o=i;a<o.length;a+=1){var s=o[a],l=s[0],c=s[1];this.labels.push(l),this.outputs.push(c)}};function Ze(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}Xe.interpolationFactor=function(t,e,n,i){var a=0;if(\"exponential\"===t.name)a=Ze(e,t.base,n,i);else if(\"linear\"===t.name)a=Ze(e,1,n,i);else if(\"cubic-bezier\"===t.name){var o=t.controlPoints;a=new r(o[0],o[1],o[2],o[3]).solve(Ze(e,1,n,i))}return a},Xe.parse=function(t,e){var r=t[0],n=t[1],i=t[2],a=t.slice(3);if(!Array.isArray(n)||0===n.length)return e.error(\"Expected an interpolation type expression.\",1);if(\"linear\"===n[0])n={name:\"linear\"};else if(\"exponential\"===n[0]){var o=n[1];if(\"number\"!=typeof o)return e.error(\"Exponential interpolation requires a numeric base.\",1,1);n={name:\"exponential\",base:o}}else{if(\"cubic-bezier\"!==n[0])return e.error(\"Unknown interpolation type \"+String(n[0]),1,0);var s=n.slice(1);if(4!==s.length||s.some(function(t){return\"number\"!=typeof t||t<0||t>1}))return e.error(\"Cubic bezier interpolation requires four numeric arguments with values between 0 and 1.\",1);n={name:\"cubic-bezier\",controlPoints:s}}if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");if(!(i=e.parse(i,2,Ht)))return null;var l=[],c=null;\"interpolate-hcl\"===r||\"interpolate-lab\"===r?c=Wt:e.expectedType&&\"value\"!==e.expectedType.kind&&(c=e.expectedType);for(var u=0;u<a.length;u+=2){var h=a[u],f=a[u+1],p=u+3,d=u+4;if(\"number\"!=typeof h)return e.error('Input/output pairs for \"interpolate\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',p);if(l.length&&l[l.length-1][0]>=h)return e.error('Input/output pairs for \"interpolate\" expressions must be arranged with input values in strictly ascending order.',p);var g=e.parse(f,d,c);if(!g)return null;c=c||g.type,l.push([h,g])}return\"number\"===c.kind||\"color\"===c.kind||\"array\"===c.kind&&\"number\"===c.itemType.kind&&\"number\"==typeof c.N?new Xe(c,r,n,i,l):e.error(\"Type \"+Qt(c)+\" is not interpolatable.\")},Xe.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;if(n>=e[i-1])return r[i-1].evaluate(t);var a=Me(e,n),o=e[a],s=e[a+1],l=Xe.interpolationFactor(this.interpolation,n,o,s),c=r[a].evaluate(t),u=r[a+1].evaluate(t);return\"interpolate\"===this.operator?Ce[this.type.kind.toLowerCase()](c,u,l):\"interpolate-hcl\"===this.operator?Ye.reverse(Ye.interpolate(Ye.forward(c),Ye.forward(u),l)):Ge.reverse(Ge.interpolate(Ge.forward(c),Ge.forward(u),l))},Xe.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},Xe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()}))},Xe.prototype.serialize=function(){var t;t=\"linear\"===this.interpolation.name?[\"linear\"]:\"exponential\"===this.interpolation.name?1===this.interpolation.base?[\"linear\"]:[\"exponential\",this.interpolation.base]:[\"cubic-bezier\"].concat(this.interpolation.controlPoints);for(var e=[this.operator,t,this.input.serialize()],r=0;r<this.labels.length;r++)e.push(this.labels[r],this.outputs[r].serialize());return e};var Je=function(t,e){this.type=t,this.args=e};Je.parse=function(t,e){if(t.length<2)return e.error(\"Expectected at least one argument.\");var r=null,n=e.expectedType;n&&\"value\"!==n.kind&&(r=n);for(var i=[],a=0,o=t.slice(1);a<o.length;a+=1){var s=o[a],l=e.parse(s,1+i.length,r,void 0,{typeAnnotation:\"omit\"});if(!l)return null;r=r||l.type,i.push(l)}var c=n&&i.some(function(t){return ee(n,t.type)});return new Je(c?Zt:r,i)},Je.prototype.evaluate=function(t){for(var e=null,r=0,n=this.args;r<n.length&&null===(e=n[r].evaluate(t));r+=1);return e},Je.prototype.eachChild=function(t){this.args.forEach(t)},Je.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},Je.prototype.serialize=function(){var t=[\"coalesce\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var Ke=function(t,e){this.type=e.type,this.bindings=[].concat(t),this.result=e};Ke.prototype.evaluate=function(t){return this.result.evaluate(t)},Ke.prototype.eachChild=function(t){for(var e=0,r=this.bindings;e<r.length;e+=1)t(r[e][1]);t(this.result)},Ke.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found \"+(t.length-1)+\" instead.\");for(var r=[],n=1;n<t.length-1;n+=2){var i=t[n];if(\"string\"!=typeof i)return e.error(\"Expected string, but found \"+typeof i+\" instead.\",n);if(/[^a-zA-Z0-9_]/.test(i))return e.error(\"Variable names must contain only alphanumeric characters or '_'.\",n);var a=e.parse(t[n+1],n+1);if(!a)return null;r.push([i,a])}var o=e.parse(t[t.length-1],t.length-1,e.expectedType,r);return o?new Ke(r,o):null},Ke.prototype.possibleOutputs=function(){return this.result.possibleOutputs()},Ke.prototype.serialize=function(){for(var t=[\"let\"],e=0,r=this.bindings;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];t.push(i,a.serialize())}return t.push(this.result.serialize()),t};var $e=function(t,e,r){this.type=t,this.index=e,this.input=r};$e.parse=function(t,e){if(3!==t.length)return e.error(\"Expected 2 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,Ht),n=e.parse(t[2],2,$t(e.expectedType||Zt));if(!r||!n)return null;var i=n.type;return new $e(i.itemType,r,n)},$e.prototype.evaluate=function(t){var e=this.index.evaluate(t),r=this.input.evaluate(t);if(e<0)throw new he(\"Array index out of bounds: \"+e+\" < 0.\");if(e>=r.length)throw new he(\"Array index out of bounds: \"+e+\" > \"+(r.length-1)+\".\");if(e!==Math.floor(e))throw new he(\"Array index must be an integer, but found \"+e+\" instead.\");return r[e]},$e.prototype.eachChild=function(t){t(this.index),t(this.input)},$e.prototype.possibleOutputs=function(){return[void 0]},$e.prototype.serialize=function(){return[\"at\",this.index.serialize(),this.input.serialize()]};var Qe=function(t,e,r,n,i,a){this.inputType=t,this.type=e,this.input=r,this.cases=n,this.outputs=i,this.otherwise=a};Qe.parse=function(t,e){if(t.length<5)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=1)return e.error(\"Expected an even number of arguments.\");var r,n;e.expectedType&&\"value\"!==e.expectedType.kind&&(n=e.expectedType);for(var i={},a=[],o=2;o<t.length-1;o+=2){var s=t[o],l=t[o+1];Array.isArray(s)||(s=[s]);var c=e.concat(o);if(0===s.length)return c.error(\"Expected at least one branch label.\");for(var u=0,h=s;u<h.length;u+=1){var f=h[u];if(\"number\"!=typeof f&&\"string\"!=typeof f)return c.error(\"Branch labels must be numbers or strings.\");if(\"number\"==typeof f&&Math.abs(f)>Number.MAX_SAFE_INTEGER)return c.error(\"Branch labels must be integers no larger than \"+Number.MAX_SAFE_INTEGER+\".\");if(\"number\"==typeof f&&Math.floor(f)!==f)return c.error(\"Numeric branch labels must be integer values.\");if(r){if(c.checkSubtype(r,le(f)))return null}else r=le(f);if(void 0!==i[String(f)])return c.error(\"Branch labels must be unique.\");i[String(f)]=a.length}var p=e.parse(l,o,n);if(!p)return null;n=n||p.type,a.push(p)}var d=e.parse(t[1],1,Zt);if(!d)return null;var g=e.parse(t[t.length-1],t.length-1,n);return g?\"value\"!==d.type.kind&&e.concat(1).checkSubtype(r,d.type)?null:new Qe(r,n,d,i,a,g):null},Qe.prototype.evaluate=function(t){var e=this.input.evaluate(t);return(le(e)===this.inputType&&this.outputs[this.cases[e]]||this.otherwise).evaluate(t)},Qe.prototype.eachChild=function(t){t(this.input),this.outputs.forEach(t),t(this.otherwise)},Qe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()})).concat(this.otherwise.possibleOutputs())},Qe.prototype.serialize=function(){for(var t=this,e=[\"match\",this.input.serialize()],r=[],n={},i=0,a=Object.keys(this.cases).sort();i<a.length;i+=1){var o=a[i];void 0===(h=n[this.cases[o]])?(n[this.cases[o]]=r.length,r.push([this.cases[o],[o]])):r[h][1].push(o)}for(var s=function(e){return\"number\"===t.inputType.kind?Number(e):e},l=0,c=r;l<c.length;l+=1){var u=c[l],h=u[0],f=u[1];1===f.length?e.push(s(f[0])):e.push(f.map(s)),e.push(this.outputs[outputIndex$1].serialize())}return e.push(this.otherwise.serialize()),e};var tr=function(t,e,r){this.type=t,this.branches=e,this.otherwise=r};function er(t,e){return\"==\"===t||\"!=\"===t?\"boolean\"===e.kind||\"string\"===e.kind||\"number\"===e.kind||\"null\"===e.kind||\"value\"===e.kind:\"string\"===e.kind||\"number\"===e.kind||\"value\"===e.kind}function rr(t,e,r,n){return 0===n.compare(e,r)}function nr(t,e,r){var n=\"==\"!==t&&\"!=\"!==t;return function(){function i(t,e,r){this.type=Yt,this.lhs=t,this.rhs=e,this.collator=r,this.hasUntypedArgument=\"value\"===t.type.kind||\"value\"===e.type.kind}return i.parse=function(t,e){if(3!==t.length&&4!==t.length)return e.error(\"Expected two or three arguments.\");var r=t[0],a=e.parse(t[1],1,Zt);if(!a)return null;if(!er(r,a.type))return e.concat(1).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Qt(a.type)+\"'.\");var o=e.parse(t[2],2,Zt);if(!o)return null;if(!er(r,o.type))return e.concat(2).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Qt(o.type)+\"'.\");if(a.type.kind!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot compare types '\"+Qt(a.type)+\"' and '\"+Qt(o.type)+\"'.\");n&&(\"value\"===a.type.kind&&\"value\"!==o.type.kind?a=new pe(o.type,[a]):\"value\"!==a.type.kind&&\"value\"===o.type.kind&&(o=new pe(a.type,[o])));var s=null;if(4===t.length){if(\"string\"!==a.type.kind&&\"string\"!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot use collator to compare non-string types.\");if(!(s=e.parse(t[3],3,Jt)))return null}return new i(a,o,s)},i.prototype.evaluate=function(i){var a=this.lhs.evaluate(i),o=this.rhs.evaluate(i);if(n&&this.hasUntypedArgument){var s=le(a),l=le(o);if(s.kind!==l.kind||\"string\"!==s.kind&&\"number\"!==s.kind)throw new he('Expected arguments for \"'+t+'\" to be (string, string) or (number, number), but found ('+s.kind+\", \"+l.kind+\") instead.\")}if(this.collator&&!n&&this.hasUntypedArgument){var c=le(a),u=le(o);if(\"string\"!==c.kind||\"string\"!==u.kind)return e(i,a,o)}return this.collator?r(i,a,o,this.collator.evaluate(i)):e(i,a,o)},i.prototype.eachChild=function(t){t(this.lhs),t(this.rhs),this.collator&&t(this.collator)},i.prototype.possibleOutputs=function(){return[!0,!1]},i.prototype.serialize=function(){var e=[t];return this.eachChild(function(t){e.push(t.serialize())}),e},i}()}tr.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=0)return e.error(\"Expected an odd number of arguments.\");var r;e.expectedType&&\"value\"!==e.expectedType.kind&&(r=e.expectedType);for(var n=[],i=1;i<t.length-1;i+=2){var a=e.parse(t[i],i,Yt);if(!a)return null;var o=e.parse(t[i+1],i+1,r);if(!o)return null;n.push([a,o]),r=r||o.type}var s=e.parse(t[t.length-1],t.length-1,r);return s?new tr(r,n,s):null},tr.prototype.evaluate=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];if(i.evaluate(t))return a.evaluate(t)}return this.otherwise.evaluate(t)},tr.prototype.eachChild=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];t(i),t(a)}t(this.otherwise)},tr.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.branches.map(function(t){return t[0],t[1].possibleOutputs()})).concat(this.otherwise.possibleOutputs())},tr.prototype.serialize=function(){var t=[\"case\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var ir=nr(\"==\",function(t,e,r){return e===r},rr),ar=nr(\"!=\",function(t,e,r){return e!==r},function(t,e,r,n){return!rr(0,e,r,n)}),or=nr(\"<\",function(t,e,r){return e<r},function(t,e,r,n){return n.compare(e,r)<0}),sr=nr(\">\",function(t,e,r){return e>r},function(t,e,r,n){return n.compare(e,r)>0}),lr=nr(\"<=\",function(t,e,r){return e<=r},function(t,e,r,n){return n.compare(e,r)<=0}),cr=nr(\">=\",function(t,e,r){return e>=r},function(t,e,r,n){return n.compare(e,r)>=0}),ur=function(t,e,r,n,i){this.type=Gt,this.number=t,this.locale=e,this.currency=r,this.minFractionDigits=n,this.maxFractionDigits=i};ur.parse=function(t,e){if(3!==t.length)return e.error(\"Expected two arguments.\");var r=e.parse(t[1],1,Ht);if(!r)return null;var n=t[2];if(\"object\"!=typeof n||Array.isArray(n))return e.error(\"NumberFormat options argument must be an object.\");var i=null;if(n.locale&&!(i=e.parse(n.locale,1,Gt)))return null;var a=null;if(n.currency&&!(a=e.parse(n.currency,1,Gt)))return null;var o=null;if(n[\"min-fraction-digits\"]&&!(o=e.parse(n[\"min-fraction-digits\"],1,Ht)))return null;var s=null;return n[\"max-fraction-digits\"]&&!(s=e.parse(n[\"max-fraction-digits\"],1,Ht))?null:new ur(r,i,a,o,s)},ur.prototype.evaluate=function(t){return new Intl.NumberFormat(this.locale?this.locale.evaluate(t):[],{style:this.currency?\"currency\":\"decimal\",currency:this.currency?this.currency.evaluate(t):void 0,minimumFractionDigits:this.minFractionDigits?this.minFractionDigits.evaluate(t):void 0,maximumFractionDigits:this.maxFractionDigits?this.maxFractionDigits.evaluate(t):void 0}).format(this.number.evaluate(t))},ur.prototype.eachChild=function(t){t(this.number),this.locale&&t(this.locale),this.currency&&t(this.currency),this.minFractionDigits&&t(this.minFractionDigits),this.maxFractionDigits&&t(this.maxFractionDigits)},ur.prototype.possibleOutputs=function(){return[void 0]},ur.prototype.serialize=function(){var t={};return this.locale&&(t.locale=this.locale.serialize()),this.currency&&(t.currency=this.currency.serialize()),this.minFractionDigits&&(t[\"min-fraction-digits\"]=this.minFractionDigits.serialize()),this.maxFractionDigits&&(t[\"max-fraction-digits\"]=this.maxFractionDigits.serialize()),[\"number-format\",this.number.serialize(),t]};var hr=function(t){this.type=Ht,this.input=t};hr.parse=function(t,e){if(2!==t.length)return e.error(\"Expected 1 argument, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1);return r?\"array\"!==r.type.kind&&\"string\"!==r.type.kind&&\"value\"!==r.type.kind?e.error(\"Expected argument of type string or array, but found \"+Qt(r.type)+\" instead.\"):new hr(r):null},hr.prototype.evaluate=function(t){var e=this.input.evaluate(t);if(\"string\"==typeof e)return e.length;if(Array.isArray(e))return e.length;throw new he(\"Expected value to be of type string or array, but found \"+Qt(le(e))+\" instead.\")},hr.prototype.eachChild=function(t){t(this.input)},hr.prototype.possibleOutputs=function(){return[void 0]},hr.prototype.serialize=function(){var t=[\"length\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var fr={\"==\":ir,\"!=\":ar,\">\":sr,\"<\":or,\">=\":cr,\"<=\":lr,array:pe,at:$e,boolean:pe,case:tr,coalesce:Je,collator:be,format:de,interpolate:Xe,\"interpolate-hcl\":Xe,\"interpolate-lab\":Xe,length:hr,let:Ke,literal:ue,match:Qe,number:pe,\"number-format\":ur,object:pe,step:Se,string:pe,\"to-boolean\":ve,\"to-color\":ve,\"to-number\":ve,\"to-string\":ve,var:Te};function pr(t,e){var r=e[0],n=e[1],i=e[2],a=e[3];r=r.evaluate(t),n=n.evaluate(t),i=i.evaluate(t);var o=a?a.evaluate(t):1,s=se(r,n,i,o);if(s)throw new he(s);return new ne(r/255*o,n/255*o,i/255*o,o)}function dr(t,e){return t in e}function gr(t,e){var r=e[t];return void 0===r?null:r}function vr(t){return{type:t}}function mr(t){return{result:\"success\",value:t}}function yr(t){return{result:\"error\",value:t}}function xr(t){return\"data-driven\"===t[\"property-type\"]||\"cross-faded-data-driven\"===t[\"property-type\"]}function br(t){return!!t.expression&&t.expression.parameters.indexOf(\"zoom\")>-1}function _r(t){return!!t.expression&&t.expression.interpolated}function wr(t){return t instanceof Number?\"number\":t instanceof String?\"string\":t instanceof Boolean?\"boolean\":Array.isArray(t)?\"array\":null===t?\"null\":typeof t}function kr(t){return\"object\"==typeof t&&null!==t&&!Array.isArray(t)}function Tr(t){return t}function Ar(t,e,r){return void 0!==t?t:void 0!==e?e:void 0!==r?r:void 0}function Mr(t,e,r,n,i){return Ar(typeof r===i?n[r]:void 0,t.default,e.default)}function Sr(t,e,r){if(\"number\"!==wr(r))return Ar(t.default,e.default);var n=t.stops.length;if(1===n)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[n-1][0])return t.stops[n-1][1];var i=Me(t.stops.map(function(t){return t[0]}),r);return t.stops[i][1]}function Er(t,e,r){var n=void 0!==t.base?t.base:1;if(\"number\"!==wr(r))return Ar(t.default,e.default);var i=t.stops.length;if(1===i)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[i-1][0])return t.stops[i-1][1];var a=Me(t.stops.map(function(t){return t[0]}),r),o=function(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}(r,n,t.stops[a][0],t.stops[a+1][0]),s=t.stops[a][1],l=t.stops[a+1][1],c=Ce[e.type]||Tr;if(t.colorSpace&&\"rgb\"!==t.colorSpace){var u=We[t.colorSpace];c=function(t,e){return u.reverse(u.interpolate(u.forward(t),u.forward(e),o))}}return\"function\"==typeof s.evaluate?{evaluate:function(){for(var t=[],e=arguments.length;e--;)t[e]=arguments[e];var r=s.evaluate.apply(void 0,t),n=l.evaluate.apply(void 0,t);if(void 0!==r&&void 0!==n)return c(r,n,o)}}:c(s,l,o)}function Cr(t,e,r){return\"color\"===e.type?r=ne.parse(r):\"formatted\"===e.type?r=oe.fromString(r.toString()):wr(r)===e.type||\"enum\"===e.type&&e.values[r]||(r=void 0),Ar(r,t.default,e.default)}xe.register(fr,{error:[{kind:\"error\"},[Gt],function(t,e){var r=e[0];throw new he(r.evaluate(t))}],typeof:[Gt,[Zt],function(t,e){return Qt(le(e[0].evaluate(t)))}],\"to-rgba\":[$t(Ht,4),[Wt],function(t,e){return e[0].evaluate(t).toArray()}],rgb:[Wt,[Ht,Ht,Ht],pr],rgba:[Wt,[Ht,Ht,Ht,Ht],pr],has:{type:Yt,overloads:[[[Gt],function(t,e){return dr(e[0].evaluate(t),t.properties())}],[[Gt,Xt],function(t,e){var r=e[0],n=e[1];return dr(r.evaluate(t),n.evaluate(t))}]]},get:{type:Zt,overloads:[[[Gt],function(t,e){return gr(e[0].evaluate(t),t.properties())}],[[Gt,Xt],function(t,e){var r=e[0],n=e[1];return gr(r.evaluate(t),n.evaluate(t))}]]},\"feature-state\":[Zt,[Gt],function(t,e){return gr(e[0].evaluate(t),t.featureState||{})}],properties:[Xt,[],function(t){return t.properties()}],\"geometry-type\":[Gt,[],function(t){return t.geometryType()}],id:[Zt,[],function(t){return t.id()}],zoom:[Ht,[],function(t){return t.globals.zoom}],\"heatmap-density\":[Ht,[],function(t){return t.globals.heatmapDensity||0}],\"line-progress\":[Ht,[],function(t){return t.globals.lineProgress||0}],accumulated:[Zt,[],function(t){return void 0===t.globals.accumulated?null:t.globals.accumulated}],\"+\":[Ht,vr(Ht),function(t,e){for(var r=0,n=0,i=e;n<i.length;n+=1)r+=i[n].evaluate(t);return r}],\"*\":[Ht,vr(Ht),function(t,e){for(var r=1,n=0,i=e;n<i.length;n+=1)r*=i[n].evaluate(t);return r}],\"-\":{type:Ht,overloads:[[[Ht,Ht],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)-n.evaluate(t)}],[[Ht],function(t,e){return-e[0].evaluate(t)}]]},\"/\":[Ht,[Ht,Ht],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)/n.evaluate(t)}],\"%\":[Ht,[Ht,Ht],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)%n.evaluate(t)}],ln2:[Ht,[],function(){return Math.LN2}],pi:[Ht,[],function(){return Math.PI}],e:[Ht,[],function(){return Math.E}],\"^\":[Ht,[Ht,Ht],function(t,e){var r=e[0],n=e[1];return Math.pow(r.evaluate(t),n.evaluate(t))}],sqrt:[Ht,[Ht],function(t,e){var r=e[0];return Math.sqrt(r.evaluate(t))}],log10:[Ht,[Ht],function(t,e){var r=e[0];return Math.log(r.evaluate(t))/Math.LN10}],ln:[Ht,[Ht],function(t,e){var r=e[0];return Math.log(r.evaluate(t))}],log2:[Ht,[Ht],function(t,e){var r=e[0];return Math.log(r.evaluate(t))/Math.LN2}],sin:[Ht,[Ht],function(t,e){var r=e[0];return Math.sin(r.evaluate(t))}],cos:[Ht,[Ht],function(t,e){var r=e[0];return Math.cos(r.evaluate(t))}],tan:[Ht,[Ht],function(t,e){var r=e[0];return Math.tan(r.evaluate(t))}],asin:[Ht,[Ht],function(t,e){var r=e[0];return Math.asin(r.evaluate(t))}],acos:[Ht,[Ht],function(t,e){var r=e[0];return Math.acos(r.evaluate(t))}],atan:[Ht,[Ht],function(t,e){var r=e[0];return Math.atan(r.evaluate(t))}],min:[Ht,vr(Ht),function(t,e){return Math.min.apply(Math,e.map(function(e){return e.evaluate(t)}))}],max:[Ht,vr(Ht),function(t,e){return Math.max.apply(Math,e.map(function(e){return e.evaluate(t)}))}],abs:[Ht,[Ht],function(t,e){var r=e[0];return Math.abs(r.evaluate(t))}],round:[Ht,[Ht],function(t,e){var r=e[0].evaluate(t);return r<0?-Math.round(-r):Math.round(r)}],floor:[Ht,[Ht],function(t,e){var r=e[0];return Math.floor(r.evaluate(t))}],ceil:[Ht,[Ht],function(t,e){var r=e[0];return Math.ceil(r.evaluate(t))}],\"filter-==\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1];return t.properties()[r.value]===n.value}],\"filter-id-==\":[Yt,[Zt],function(t,e){var r=e[0];return t.id()===r.value}],\"filter-type-==\":[Yt,[Gt],function(t,e){var r=e[0];return t.geometryType()===r.value}],\"filter-<\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<a}],\"filter-id-<\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<i}],\"filter->\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>a}],\"filter-id->\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>i}],\"filter-<=\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<=a}],\"filter-id-<=\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<=i}],\"filter->=\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>=a}],\"filter-id->=\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>=i}],\"filter-has\":[Yt,[Zt],function(t,e){return e[0].value in t.properties()}],\"filter-has-id\":[Yt,[],function(t){return null!==t.id()}],\"filter-type-in\":[Yt,[$t(Gt)],function(t,e){return e[0].value.indexOf(t.geometryType())>=0}],\"filter-id-in\":[Yt,[$t(Zt)],function(t,e){return e[0].value.indexOf(t.id())>=0}],\"filter-in-small\":[Yt,[Gt,$t(Zt)],function(t,e){var r=e[0];return e[1].value.indexOf(t.properties()[r.value])>=0}],\"filter-in-large\":[Yt,[Gt,$t(Zt)],function(t,e){var r=e[0],n=e[1];return function(t,e,r,n){for(;r<=n;){var i=r+n>>1;if(e[i]===t)return!0;e[i]>t?n=i-1:r=i+1}return!1}(t.properties()[r.value],n.value,0,n.value.length-1)}],all:{type:Yt,overloads:[[[Yt,Yt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)&&n.evaluate(t)}],[vr(Yt),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(!n[r].evaluate(t))return!1;return!0}]]},any:{type:Yt,overloads:[[[Yt,Yt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)||n.evaluate(t)}],[vr(Yt),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(n[r].evaluate(t))return!0;return!1}]]},\"!\":[Yt,[Yt],function(t,e){return!e[0].evaluate(t)}],\"is-supported-script\":[Yt,[Gt],function(t,e){var r=e[0],n=t.globals&&t.globals.isSupportedScript;return!n||n(r.evaluate(t))}],upcase:[Gt,[Gt],function(t,e){return e[0].evaluate(t).toUpperCase()}],downcase:[Gt,[Gt],function(t,e){return e[0].evaluate(t).toLowerCase()}],concat:[Gt,vr(Zt),function(t,e){return e.map(function(e){return ce(e.evaluate(t))}).join(\"\")}],\"resolved-locale\":[Gt,[Jt],function(t,e){return e[0].evaluate(t).resolvedLocale()}]});var Lr=function(t,e){var r;this.expression=t,this._warningHistory={},this._evaluator=new ye,this._defaultValue=e?\"color\"===(r=e).type&&kr(r.default)?new ne(0,0,0,0):\"color\"===r.type?ne.parse(r.default)||null:void 0===r.default?null:r.default:null,this._enumValues=e&&\"enum\"===e.type?e.values:null};function Pr(t){return Array.isArray(t)&&t.length>0&&\"string\"==typeof t[0]&&t[0]in fr}function Or(t,e){var r=new Ae(fr,[],e?function(t){var e={color:Wt,string:Gt,number:Ht,enum:Gt,boolean:Yt,formatted:Kt};return\"array\"===t.type?$t(e[t.value]||Zt,t.length):e[t.type]}(e):void 0),n=r.parse(t,void 0,void 0,void 0,e&&\"string\"===e.type?{typeAnnotation:\"coerce\"}:void 0);return n?mr(new Lr(n,e)):yr(r.errors)}Lr.prototype.evaluateWithoutErrorHandling=function(t,e,r){return this._evaluator.globals=t,this._evaluator.feature=e,this._evaluator.featureState=r,this.expression.evaluate(this._evaluator)},Lr.prototype.evaluate=function(t,e,r){this._evaluator.globals=t,this._evaluator.feature=e||null,this._evaluator.featureState=r||null;try{var n=this.expression.evaluate(this._evaluator);if(null==n)return this._defaultValue;if(this._enumValues&&!(n in this._enumValues))throw new he(\"Expected value to be one of \"+Object.keys(this._enumValues).map(function(t){return JSON.stringify(t)}).join(\", \")+\", but found \"+JSON.stringify(n)+\" instead.\");return n}catch(t){return this._warningHistory[t.message]||(this._warningHistory[t.message]=!0,\"undefined\"!=typeof console&&console.warn(t.message)),this._defaultValue}};var zr=function(t,e){this.kind=t,this._styleExpression=e,this.isStateDependent=\"constant\"!==t&&!we(e.expression)};zr.prototype.evaluateWithoutErrorHandling=function(t,e,r){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r)},zr.prototype.evaluate=function(t,e,r){return this._styleExpression.evaluate(t,e,r)};var Ir=function(t,e,r){this.kind=t,this.zoomStops=r.labels,this._styleExpression=e,this.isStateDependent=\"camera\"!==t&&!we(e.expression),r instanceof Xe&&(this.interpolationType=r.interpolation)};function Dr(t,e){if(\"error\"===(t=Or(t,e)).result)return t;var r=t.value.expression,n=_e(r);if(!n&&!xr(e))return yr([new Ut(\"\",\"data expressions not supported\")]);var i=ke(r,[\"zoom\"]);if(!i&&!br(e))return yr([new Ut(\"\",\"zoom expressions not supported\")]);var a=function t(e){var r=null;if(e instanceof Ke)r=t(e.result);else if(e instanceof Je)for(var n=0,i=e.args;n<i.length;n+=1){var a=i[n];if(r=t(a))break}else(e instanceof Se||e instanceof Xe)&&e.input instanceof xe&&\"zoom\"===e.input.name&&(r=e);return r instanceof Ut?r:(e.eachChild(function(e){var n=t(e);n instanceof Ut?r=n:!r&&n?r=new Ut(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.'):r&&n&&r!==n&&(r=new Ut(\"\",'Only one zoom-based \"step\" or \"interpolate\" subexpression may be used in an expression.'))}),r)}(r);return a||i?a instanceof Ut?yr([a]):a instanceof Xe&&!_r(e)?yr([new Ut(\"\",'\"interpolate\" expressions cannot be used with this property')]):mr(a?new Ir(n?\"camera\":\"composite\",t.value,a):new zr(n?\"constant\":\"source\",t.value)):yr([new Ut(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.')])}Ir.prototype.evaluateWithoutErrorHandling=function(t,e,r){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r)},Ir.prototype.evaluate=function(t,e,r){return this._styleExpression.evaluate(t,e,r)},Ir.prototype.interpolationFactor=function(t,e,r){return this.interpolationType?Xe.interpolationFactor(this.interpolationType,t,e,r):0};var Rr=function(t,e){this._parameters=t,this._specification=e,Ft(this,function t(e,r){var n,i,a,o=\"color\"===r.type,s=e.stops&&\"object\"==typeof e.stops[0][0],l=s||void 0!==e.property,c=s||!l,u=e.type||(_r(r)?\"exponential\":\"interval\");if(o&&((e=Ft({},e)).stops&&(e.stops=e.stops.map(function(t){return[t[0],ne.parse(t[1])]})),e.default?e.default=ne.parse(e.default):e.default=ne.parse(r.default)),e.colorSpace&&\"rgb\"!==e.colorSpace&&!We[e.colorSpace])throw new Error(\"Unknown color space: \"+e.colorSpace);if(\"exponential\"===u)n=Er;else if(\"interval\"===u)n=Sr;else if(\"categorical\"===u){n=Mr,i=Object.create(null);for(var h=0,f=e.stops;h<f.length;h+=1){var p=f[h];i[p[0]]=p[1]}a=typeof e.stops[0][0]}else{if(\"identity\"!==u)throw new Error('Unknown function type \"'+u+'\"');n=Cr}if(s){for(var d={},g=[],v=0;v<e.stops.length;v++){var m=e.stops[v],y=m[0].zoom;void 0===d[y]&&(d[y]={zoom:y,type:e.type,property:e.property,default:e.default,stops:[]},g.push(y)),d[y].stops.push([m[0].value,m[1]])}for(var x=[],b=0,_=g;b<_.length;b+=1){var w=_[b];x.push([d[w].zoom,t(d[w],r)])}var k={name:\"linear\"};return{kind:\"composite\",interpolationType:k,interpolationFactor:Xe.interpolationFactor.bind(void 0,k),zoomStops:x.map(function(t){return t[0]}),evaluate:function(t,n){var i=t.zoom;return Er({stops:x,base:e.base},r,i).evaluate(i,n)}}}if(c){var T=\"exponential\"===u?{name:\"exponential\",base:void 0!==e.base?e.base:1}:null;return{kind:\"camera\",interpolationType:T,interpolationFactor:Xe.interpolationFactor.bind(void 0,T),zoomStops:e.stops.map(function(t){return t[0]}),evaluate:function(t){var o=t.zoom;return n(e,r,o,i,a)}}}return{kind:\"source\",evaluate:function(t,o){var s=o&&o.properties?o.properties[e.property]:void 0;return void 0===s?Ar(e.default,r.default):n(e,r,s,i,a)}}}(this._parameters,this._specification))};function Fr(t){var e=t.key,r=t.value,n=t.valueSpec||{},i=t.objectElementValidators||{},a=t.style,o=t.styleSpec,s=[],l=wr(r);if(\"object\"!==l)return[new Dt(e,r,\"object expected, \"+l+\" found\")];for(var c in r){var u=c.split(\".\")[0],h=n[u]||n[\"*\"],f=void 0;if(i[u])f=i[u];else if(n[u])f=ln;else if(i[\"*\"])f=i[\"*\"];else{if(!n[\"*\"]){s.push(new Dt(e,r[c],'unknown property \"'+c+'\"'));continue}f=ln}s=s.concat(f({key:(e?e+\".\":e)+c,value:r[c],valueSpec:h,style:a,styleSpec:o,object:r,objectKey:c},r))}for(var p in n)i[p]||n[p].required&&void 0===n[p].default&&void 0===r[p]&&s.push(new Dt(e,r,'missing required property \"'+p+'\"'));return s}function Br(t){var e=t.value,r=t.valueSpec,n=t.style,i=t.styleSpec,a=t.key,o=t.arrayElementValidator||ln;if(\"array\"!==wr(e))return[new Dt(a,e,\"array expected, \"+wr(e)+\" found\")];if(r.length&&e.length!==r.length)return[new Dt(a,e,\"array length \"+r.length+\" expected, length \"+e.length+\" found\")];if(r[\"min-length\"]&&e.length<r[\"min-length\"])return[new Dt(a,e,\"array length at least \"+r[\"min-length\"]+\" expected, length \"+e.length+\" found\")];var s={type:r.value,values:r.values};i.$version<7&&(s.function=r.function),\"object\"===wr(r.value)&&(s=r.value);for(var l=[],c=0;c<e.length;c++)l=l.concat(o({array:e,arrayIndex:c,value:e[c],valueSpec:s,style:n,styleSpec:i,key:a+\"[\"+c+\"]\"}));return l}function Nr(t){var e=t.key,r=t.value,n=t.valueSpec,i=wr(r);return\"number\"!==i?[new Dt(e,r,\"number expected, \"+i+\" found\")]:\"minimum\"in n&&r<n.minimum?[new Dt(e,r,r+\" is less than the minimum value \"+n.minimum)]:\"maximum\"in n&&r>n.maximum?[new Dt(e,r,r+\" is greater than the maximum value \"+n.maximum)]:[]}function jr(t){var e,r,n,i=t.valueSpec,a=Nt(t.value.type),o={},s=\"categorical\"!==a&&void 0===t.value.property,l=!s,c=\"array\"===wr(t.value.stops)&&\"array\"===wr(t.value.stops[0])&&\"object\"===wr(t.value.stops[0][0]),u=Fr({key:t.key,value:t.value,valueSpec:t.styleSpec.function,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{stops:function(t){if(\"identity\"===a)return[new Dt(t.key,t.value,'identity function may not have a \"stops\" property')];var e=[],r=t.value;return e=e.concat(Br({key:t.key,value:r,valueSpec:t.valueSpec,style:t.style,styleSpec:t.styleSpec,arrayElementValidator:h})),\"array\"===wr(r)&&0===r.length&&e.push(new Dt(t.key,r,\"array must have at least one stop\")),e},default:function(t){return ln({key:t.key,value:t.value,valueSpec:i,style:t.style,styleSpec:t.styleSpec})}}});return\"identity\"===a&&s&&u.push(new Dt(t.key,t.value,'missing required property \"property\"')),\"identity\"===a||t.value.stops||u.push(new Dt(t.key,t.value,'missing required property \"stops\"')),\"exponential\"===a&&t.valueSpec.expression&&!_r(t.valueSpec)&&u.push(new Dt(t.key,t.value,\"exponential functions not supported\")),t.styleSpec.$version>=8&&(l&&!xr(t.valueSpec)?u.push(new Dt(t.key,t.value,\"property functions not supported\")):s&&!br(t.valueSpec)&&u.push(new Dt(t.key,t.value,\"zoom functions not supported\"))),\"categorical\"!==a&&!c||void 0!==t.value.property||u.push(new Dt(t.key,t.value,'\"property\" property is required')),u;function h(t){var e=[],a=t.value,s=t.key;if(\"array\"!==wr(a))return[new Dt(s,a,\"array expected, \"+wr(a)+\" found\")];if(2!==a.length)return[new Dt(s,a,\"array length 2 expected, length \"+a.length+\" found\")];if(c){if(\"object\"!==wr(a[0]))return[new Dt(s,a,\"object expected, \"+wr(a[0])+\" found\")];if(void 0===a[0].zoom)return[new Dt(s,a,\"object stop key must have zoom\")];if(void 0===a[0].value)return[new Dt(s,a,\"object stop key must have value\")];if(n&&n>Nt(a[0].zoom))return[new Dt(s,a[0].zoom,\"stop zoom values must appear in ascending order\")];Nt(a[0].zoom)!==n&&(n=Nt(a[0].zoom),r=void 0,o={}),e=e.concat(Fr({key:s+\"[0]\",value:a[0],valueSpec:{zoom:{}},style:t.style,styleSpec:t.styleSpec,objectElementValidators:{zoom:Nr,value:f}}))}else e=e.concat(f({key:s+\"[0]\",value:a[0],valueSpec:{},style:t.style,styleSpec:t.styleSpec},a));return Pr(jt(a[1]))?e.concat([new Dt(s+\"[1]\",a[1],\"expressions are not allowed in function stops.\")]):e.concat(ln({key:s+\"[1]\",value:a[1],valueSpec:i,style:t.style,styleSpec:t.styleSpec}))}function f(t,n){var s=wr(t.value),l=Nt(t.value),c=null!==t.value?t.value:n;if(e){if(s!==e)return[new Dt(t.key,c,s+\" stop domain type must match previous stop domain type \"+e)]}else e=s;if(\"number\"!==s&&\"string\"!==s&&\"boolean\"!==s)return[new Dt(t.key,c,\"stop domain value must be a number, string, or boolean\")];if(\"number\"!==s&&\"categorical\"!==a){var u=\"number expected, \"+s+\" found\";return xr(i)&&void 0===a&&(u+='\\nIf you intended to use a categorical function, specify `\"type\": \"categorical\"`.'),[new Dt(t.key,c,u)]}return\"categorical\"!==a||\"number\"!==s||isFinite(l)&&Math.floor(l)===l?\"categorical\"!==a&&\"number\"===s&&void 0!==r&&l<r?[new Dt(t.key,c,\"stop domain values must appear in ascending order\")]:(r=l,\"categorical\"===a&&l in o?[new Dt(t.key,c,\"stop domain values must be unique\")]:(o[l]=!0,[])):[new Dt(t.key,c,\"integer expected, found \"+l)]}}function Ur(t){var e=(\"property\"===t.expressionContext?Dr:Or)(jt(t.value),t.valueSpec);if(\"error\"===e.result)return e.value.map(function(e){return new Dt(\"\"+t.key+e.key,t.value,e.message)});var r=e.value.expression||e.value._styleExpression.expression;if(\"property\"===t.expressionContext&&\"text-font\"===t.propertyKey&&-1!==r.possibleOutputs().indexOf(void 0))return[new Dt(t.key,t.value,'Invalid data expression for \"'+t.propertyKey+'\". Output values must be contained as literals within the expression.')];if(\"property\"===t.expressionContext&&\"layout\"===t.propertyType&&!we(r))return[new Dt(t.key,t.value,'\"feature-state\" data expressions are not supported with layout properties.')];if(\"filter\"===t.expressionContext&&!we(r))return[new Dt(t.key,t.value,'\"feature-state\" data expressions are not supported with filters.')];if(t.expressionContext&&0===t.expressionContext.indexOf(\"cluster\")){if(!ke(r,[\"zoom\",\"feature-state\"]))return[new Dt(t.key,t.value,'\"zoom\" and \"feature-state\" expressions are not supported with cluster properties.')];if(\"cluster-initial\"===t.expressionContext&&!_e(r))return[new Dt(t.key,t.value,\"Feature data expressions are not supported with initial expression part of cluster properties.\")]}return[]}function Vr(t){var e=t.key,r=t.value,n=t.valueSpec,i=[];return Array.isArray(n.values)?-1===n.values.indexOf(Nt(r))&&i.push(new Dt(e,r,\"expected one of [\"+n.values.join(\", \")+\"], \"+JSON.stringify(r)+\" found\")):-1===Object.keys(n.values).indexOf(Nt(r))&&i.push(new Dt(e,r,\"expected one of [\"+Object.keys(n.values).join(\", \")+\"], \"+JSON.stringify(r)+\" found\")),i}function qr(t){if(!0===t||!1===t)return!0;if(!Array.isArray(t)||0===t.length)return!1;switch(t[0]){case\"has\":return t.length>=2&&\"$id\"!==t[1]&&\"$type\"!==t[1];case\"in\":case\"!in\":case\"!has\":case\"none\":return!1;case\"==\":case\"!=\":case\">\":case\">=\":case\"<\":case\"<=\":return 3!==t.length||Array.isArray(t[1])||Array.isArray(t[2]);case\"any\":case\"all\":for(var e=0,r=t.slice(1);e<r.length;e+=1){var n=r[e];if(!qr(n)&&\"boolean\"!=typeof n)return!1}return!0;default:return!0}}Rr.deserialize=function(t){return new Rr(t._parameters,t._specification)},Rr.serialize=function(t){return{_parameters:t._parameters,_specification:t._specification}};var Hr={type:\"boolean\",default:!1,transition:!1,\"property-type\":\"data-driven\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]}};function Gr(t){if(null==t)return function(){return!0};qr(t)||(t=Wr(t));var e=Or(t,Hr);if(\"error\"===e.result)throw new Error(e.value.map(function(t){return t.key+\": \"+t.message}).join(\", \"));return function(t,r){return e.value.evaluate(t,r)}}function Yr(t,e){return t<e?-1:t>e?1:0}function Wr(t){if(!t)return!0;var e,r=t[0];return t.length<=1?\"any\"!==r:\"==\"===r?Xr(t[1],t[2],\"==\"):\"!=\"===r?Kr(Xr(t[1],t[2],\"==\")):\"<\"===r||\">\"===r||\"<=\"===r||\">=\"===r?Xr(t[1],t[2],r):\"any\"===r?(e=t.slice(1),[\"any\"].concat(e.map(Wr))):\"all\"===r?[\"all\"].concat(t.slice(1).map(Wr)):\"none\"===r?[\"all\"].concat(t.slice(1).map(Wr).map(Kr)):\"in\"===r?Zr(t[1],t.slice(2)):\"!in\"===r?Kr(Zr(t[1],t.slice(2))):\"has\"===r?Jr(t[1]):\"!has\"!==r||Kr(Jr(t[1]))}function Xr(t,e,r){switch(t){case\"$type\":return[\"filter-type-\"+r,e];case\"$id\":return[\"filter-id-\"+r,e];default:return[\"filter-\"+r,t,e]}}function Zr(t,e){if(0===e.length)return!1;switch(t){case\"$type\":return[\"filter-type-in\",[\"literal\",e]];case\"$id\":return[\"filter-id-in\",[\"literal\",e]];default:return e.length>200&&!e.some(function(t){return typeof t!=typeof e[0]})?[\"filter-in-large\",t,[\"literal\",e.sort(Yr)]]:[\"filter-in-small\",t,[\"literal\",e]]}}function Jr(t){switch(t){case\"$type\":return!0;case\"$id\":return[\"filter-has-id\"];default:return[\"filter-has\",t]}}function Kr(t){return[\"!\",t]}function $r(t){return qr(jt(t.value))?Ur(Ft({},t,{expressionContext:\"filter\",valueSpec:{value:\"boolean\"}})):function t(e){var r=e.value,n=e.key;if(\"array\"!==wr(r))return[new Dt(n,r,\"array expected, \"+wr(r)+\" found\")];var i,a=e.styleSpec,o=[];if(r.length<1)return[new Dt(n,r,\"filter array must have at least 1 element\")];switch(o=o.concat(Vr({key:n+\"[0]\",value:r[0],valueSpec:a.filter_operator,style:e.style,styleSpec:e.styleSpec})),Nt(r[0])){case\"<\":case\"<=\":case\">\":case\">=\":r.length>=2&&\"$type\"===Nt(r[1])&&o.push(new Dt(n,r,'\"$type\" cannot be use with operator \"'+r[0]+'\"'));case\"==\":case\"!=\":3!==r.length&&o.push(new Dt(n,r,'filter array for operator \"'+r[0]+'\" must have 3 elements'));case\"in\":case\"!in\":r.length>=2&&\"string\"!==(i=wr(r[1]))&&o.push(new Dt(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"));for(var s=2;s<r.length;s++)i=wr(r[s]),\"$type\"===Nt(r[1])?o=o.concat(Vr({key:n+\"[\"+s+\"]\",value:r[s],valueSpec:a.geometry_type,style:e.style,styleSpec:e.styleSpec})):\"string\"!==i&&\"number\"!==i&&\"boolean\"!==i&&o.push(new Dt(n+\"[\"+s+\"]\",r[s],\"string, number, or boolean expected, \"+i+\" found\"));break;case\"any\":case\"all\":case\"none\":for(var l=1;l<r.length;l++)o=o.concat(t({key:n+\"[\"+l+\"]\",value:r[l],style:e.style,styleSpec:e.styleSpec}));break;case\"has\":case\"!has\":i=wr(r[1]),2!==r.length?o.push(new Dt(n,r,'filter array for \"'+r[0]+'\" operator must have 2 elements')):\"string\"!==i&&o.push(new Dt(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"))}return o}(t)}function Qr(t,e){var r=t.key,n=t.style,i=t.styleSpec,a=t.value,o=t.objectKey,s=i[e+\"_\"+t.layerType];if(!s)return[];var l=o.match(/^(.*)-transition$/);if(\"paint\"===e&&l&&s[l[1]]&&s[l[1]].transition)return ln({key:r,value:a,valueSpec:i.transition,style:n,styleSpec:i});var c,u=t.valueSpec||s[o];if(!u)return[new Dt(r,a,'unknown property \"'+o+'\"')];if(\"string\"===wr(a)&&xr(u)&&!u.tokens&&(c=/^{([^}]+)}$/.exec(a)))return[new Dt(r,a,'\"'+o+'\" does not support interpolation syntax\\nUse an identity property function instead: `{ \"type\": \"identity\", \"property\": '+JSON.stringify(c[1])+\" }`.\")];var h=[];return\"symbol\"===t.layerType&&(\"text-field\"===o&&n&&!n.glyphs&&h.push(new Dt(r,a,'use of \"text-field\" requires a style \"glyphs\" property')),\"text-font\"===o&&kr(jt(a))&&\"identity\"===Nt(a.type)&&h.push(new Dt(r,a,'\"text-font\" does not support identity functions'))),h.concat(ln({key:t.key,value:a,valueSpec:u,style:n,styleSpec:i,expressionContext:\"property\",propertyType:e,propertyKey:o}))}function tn(t){return Qr(t,\"paint\")}function en(t){return Qr(t,\"layout\")}function rn(t){var e=[],r=t.value,n=t.key,i=t.style,a=t.styleSpec;r.type||r.ref||e.push(new Dt(n,r,'either \"type\" or \"ref\" is required'));var o,s=Nt(r.type),l=Nt(r.ref);if(r.id)for(var c=Nt(r.id),u=0;u<t.arrayIndex;u++){var h=i.layers[u];Nt(h.id)===c&&e.push(new Dt(n,r.id,'duplicate layer id \"'+r.id+'\", previously used at line '+h.id.__line__))}if(\"ref\"in r)[\"type\",\"source\",\"source-layer\",\"filter\",\"layout\"].forEach(function(t){t in r&&e.push(new Dt(n,r[t],'\"'+t+'\" is prohibited for ref layers'))}),i.layers.forEach(function(t){Nt(t.id)===l&&(o=t)}),o?o.ref?e.push(new Dt(n,r.ref,\"ref cannot reference another ref layer\")):s=Nt(o.type):e.push(new Dt(n,r.ref,'ref layer \"'+l+'\" not found'));else if(\"background\"!==s)if(r.source){var f=i.sources&&i.sources[r.source],p=f&&Nt(f.type);f?\"vector\"===p&&\"raster\"===s?e.push(new Dt(n,r.source,'layer \"'+r.id+'\" requires a raster source')):\"raster\"===p&&\"raster\"!==s?e.push(new Dt(n,r.source,'layer \"'+r.id+'\" requires a vector source')):\"vector\"!==p||r[\"source-layer\"]?\"raster-dem\"===p&&\"hillshade\"!==s?e.push(new Dt(n,r.source,\"raster-dem source can only be used with layer type 'hillshade'.\")):\"line\"!==s||!r.paint||!r.paint[\"line-gradient\"]||\"geojson\"===p&&f.lineMetrics||e.push(new Dt(n,r,'layer \"'+r.id+'\" specifies a line-gradient, which requires a GeoJSON source with `lineMetrics` enabled.')):e.push(new Dt(n,r,'layer \"'+r.id+'\" must specify a \"source-layer\"')):e.push(new Dt(n,r.source,'source \"'+r.source+'\" not found'))}else e.push(new Dt(n,r,'missing required property \"source\"'));return e=e.concat(Fr({key:n,value:r,valueSpec:a.layer,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(){return[]},type:function(){return ln({key:n+\".type\",value:r.type,valueSpec:a.layer.type,style:t.style,styleSpec:t.styleSpec,object:r,objectKey:\"type\"})},filter:$r,layout:function(t){return Fr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return en(Ft({layerType:s},t))}}})},paint:function(t){return Fr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return tn(Ft({layerType:s},t))}}})}}}))}function nn(t){var e=t.value,r=t.key,n=t.styleSpec,i=t.style;if(!e.type)return[new Dt(r,e,'\"type\" is required')];var a,o=Nt(e.type);switch(o){case\"vector\":case\"raster\":case\"raster-dem\":if(a=Fr({key:r,value:e,valueSpec:n[\"source_\"+o.replace(\"-\",\"_\")],style:t.style,styleSpec:n}),\"url\"in e)for(var s in e)[\"type\",\"url\",\"tileSize\"].indexOf(s)<0&&a.push(new Dt(r+\".\"+s,e[s],'a source with a \"url\" property may not include a \"'+s+'\" property'));return a;case\"geojson\":if(a=Fr({key:r,value:e,valueSpec:n.source_geojson,style:i,styleSpec:n}),e.cluster)for(var l in e.clusterProperties){var c=e.clusterProperties[l],u=c[0],h=c[1],f=\"string\"==typeof u?[u,[\"accumulated\"],[\"get\",l]]:u;a.push.apply(a,Ur({key:r+\".\"+l+\".map\",value:h,expressionContext:\"cluster-map\"})),a.push.apply(a,Ur({key:r+\".\"+l+\".reduce\",value:f,expressionContext:\"cluster-reduce\"}))}return a;case\"video\":return Fr({key:r,value:e,valueSpec:n.source_video,style:i,styleSpec:n});case\"image\":return Fr({key:r,value:e,valueSpec:n.source_image,style:i,styleSpec:n});case\"canvas\":return[new Dt(r,null,\"Please use runtime APIs to add canvas sources, rather than including them in stylesheets.\",\"source.canvas\")];default:return Vr({key:r+\".type\",value:e.type,valueSpec:{values:[\"vector\",\"raster\",\"raster-dem\",\"geojson\",\"video\",\"image\"]},style:i,styleSpec:n})}}function an(t){var e=t.value,r=t.styleSpec,n=r.light,i=t.style,a=[],o=wr(e);if(void 0===e)return a;if(\"object\"!==o)return a.concat([new Dt(\"light\",e,\"object expected, \"+o+\" found\")]);for(var s in e){var l=s.match(/^(.*)-transition$/);a=l&&n[l[1]]&&n[l[1]].transition?a.concat(ln({key:s,value:e[s],valueSpec:r.transition,style:i,styleSpec:r})):n[s]?a.concat(ln({key:s,value:e[s],valueSpec:n[s],style:i,styleSpec:r})):a.concat([new Dt(s,e[s],'unknown property \"'+s+'\"')])}return a}function on(t){var e=t.value,r=t.key,n=wr(e);return\"string\"!==n?[new Dt(r,e,\"string expected, \"+n+\" found\")]:[]}var sn={\"*\":function(){return[]},array:Br,boolean:function(t){var e=t.value,r=t.key,n=wr(e);return\"boolean\"!==n?[new Dt(r,e,\"boolean expected, \"+n+\" found\")]:[]},number:Nr,color:function(t){var e=t.key,r=t.value,n=wr(r);return\"string\"!==n?[new Dt(e,r,\"color expected, \"+n+\" found\")]:null===re(r)?[new Dt(e,r,'color expected, \"'+r+'\" found')]:[]},constants:Rt,enum:Vr,filter:$r,function:jr,layer:rn,object:Fr,source:nn,light:an,string:on,formatted:function(t){return 0===on(t).length?[]:Ur(t)}};function ln(t){var e=t.value,r=t.valueSpec,n=t.styleSpec;return r.expression&&kr(Nt(e))?jr(t):r.expression&&Pr(jt(e))?Ur(t):r.type&&sn[r.type]?sn[r.type](t):Fr(Ft({},t,{valueSpec:r.type?n[r.type]:r}))}function cn(t){var e=t.value,r=t.key,n=on(t);return n.length?n:(-1===e.indexOf(\"{fontstack}\")&&n.push(new Dt(r,e,'\"glyphs\" url must include a \"{fontstack}\" token')),-1===e.indexOf(\"{range}\")&&n.push(new Dt(r,e,'\"glyphs\" url must include a \"{range}\" token')),n)}function un(t,e){e=e||It;var r=[];return r=r.concat(ln({key:\"\",value:t,valueSpec:e.$root,styleSpec:e,style:t,objectElementValidators:{glyphs:cn,\"*\":function(){return[]}}})),t.constants&&(r=r.concat(Rt({key:\"constants\",value:t.constants,style:t,styleSpec:e}))),hn(r)}function hn(t){return[].concat(t).sort(function(t,e){return t.line-e.line})}function fn(t){return function(){for(var e=[],r=arguments.length;r--;)e[r]=arguments[r];return hn(t.apply(this,e))}}un.source=fn(nn),un.light=fn(an),un.layer=fn(rn),un.filter=fn($r),un.paintProperty=fn(tn),un.layoutProperty=fn(en);var pn=un,dn=pn.light,gn=pn.paintProperty,vn=pn.layoutProperty;function mn(t,e){var r=!1;if(e&&e.length)for(var n=0,i=e;n<i.length;n+=1){var a=i[n];t.fire(new Ot(new Error(a.message))),r=!0}return r}var yn=bn,xn=3;function bn(t,e,r){var n=this.cells=[];if(t instanceof ArrayBuffer){this.arrayBuffer=t;var i=new Int32Array(this.arrayBuffer);t=i[0],e=i[1],r=i[2],this.d=e+2*r;for(var a=0;a<this.d*this.d;a++){var o=i[xn+a],s=i[xn+a+1];n.push(o===s?null:i.subarray(o,s))}var l=i[xn+n.length],c=i[xn+n.length+1];this.keys=i.subarray(l,c),this.bboxes=i.subarray(c),this.insert=this._insertReadonly}else{this.d=e+2*r;for(var u=0;u<this.d*this.d;u++)n.push([]);this.keys=[],this.bboxes=[]}this.n=e,this.extent=t,this.padding=r,this.scale=e/t,this.uid=0;var h=r/e*t;this.min=-h,this.max=t+h}bn.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertCell,this.uid++),this.keys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},bn.prototype._insertReadonly=function(){throw\"Cannot insert into a GridIndex created from an ArrayBuffer.\"},bn.prototype._insertCell=function(t,e,r,n,i,a){this.cells[i].push(a)},bn.prototype.query=function(t,e,r,n,i){var a=this.min,o=this.max;if(t<=a&&e<=a&&o<=r&&o<=n&&!i)return Array.prototype.slice.call(this.keys);var s=[];return this._forEachCell(t,e,r,n,this._queryCell,s,{},i),s},bn.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=this.cells[i];if(null!==l)for(var c=this.keys,u=this.bboxes,h=0;h<l.length;h++){var f=l[h];if(void 0===o[f]){var p=4*f;(s?s(u[p+0],u[p+1],u[p+2],u[p+3]):t<=u[p+2]&&e<=u[p+3]&&r>=u[p+0]&&n>=u[p+1])?(o[f]=!0,a.push(c[f])):o[f]=!1}}},bn.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToCellCoord(t),c=this._convertToCellCoord(e),u=this._convertToCellCoord(r),h=this._convertToCellCoord(n),f=l;f<=u;f++)for(var p=c;p<=h;p++){var d=this.d*p+f;if((!s||s(this._convertFromCellCoord(f),this._convertFromCellCoord(p),this._convertFromCellCoord(f+1),this._convertFromCellCoord(p+1)))&&i.call(this,t,e,r,n,d,a,o,s))return}},bn.prototype._convertFromCellCoord=function(t){return(t-this.padding)/this.scale},bn.prototype._convertToCellCoord=function(t){return Math.max(0,Math.min(this.d-1,Math.floor(t*this.scale)+this.padding))},bn.prototype.toArrayBuffer=function(){if(this.arrayBuffer)return this.arrayBuffer;for(var t=this.cells,e=xn+this.cells.length+1+1,r=0,n=0;n<this.cells.length;n++)r+=this.cells[n].length;var i=new Int32Array(e+r+this.keys.length+this.bboxes.length);i[0]=this.extent,i[1]=this.n,i[2]=this.padding;for(var a=e,o=0;o<t.length;o++){var s=t[o];i[xn+o]=a,i.set(s,a),a+=s.length}return i[xn+t.length]=a,i.set(this.keys,a),a+=this.keys.length,i[xn+t.length+1]=a,i.set(this.bboxes,a),a+=this.bboxes.length,i.buffer};var _n=self.ImageData,wn={};function kn(t,e,r){void 0===r&&(r={}),Object.defineProperty(e,\"_classRegistryKey\",{value:t,writeable:!1}),wn[t]={klass:e,omit:r.omit||[],shallow:r.shallow||[]}}for(var Tn in kn(\"Object\",Object),yn.serialize=function(t,e){var r=t.toArrayBuffer();return e&&e.push(r),{buffer:r}},yn.deserialize=function(t){return new yn(t.buffer)},kn(\"Grid\",yn),kn(\"Color\",ne),kn(\"Error\",Error),kn(\"StylePropertyFunction\",Rr),kn(\"StyleExpression\",Lr,{omit:[\"_evaluator\"]}),kn(\"ZoomDependentExpression\",Ir),kn(\"ZoomConstantExpression\",zr),kn(\"CompoundExpression\",xe,{omit:[\"_evaluate\"]}),fr)fr[Tn]._classRegistryKey||kn(\"Expression_\"+Tn,fr[Tn]);function An(t,e){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp)return t;if(t instanceof ArrayBuffer)return e&&e.push(t),t;if(ArrayBuffer.isView(t)){var r=t;return e&&e.push(r.buffer),r}if(t instanceof _n)return e&&e.push(t.data.buffer),t;if(Array.isArray(t)){for(var n=[],i=0,a=t;i<a.length;i+=1){var o=a[i];n.push(An(o,e))}return n}if(\"object\"==typeof t){var s=t.constructor,l=s._classRegistryKey;if(!l)throw new Error(\"can't serialize object of unregistered class\");var c=s.serialize?s.serialize(t,e):{};if(!s.serialize){for(var u in t)if(t.hasOwnProperty(u)&&!(wn[l].omit.indexOf(u)>=0)){var h=t[u];c[u]=wn[l].shallow.indexOf(u)>=0?h:An(h,e)}t instanceof Error&&(c.message=t.message)}if(c.$name)throw new Error(\"$name property is reserved for worker serialization logic.\");return\"Object\"!==l&&(c.$name=l),c}throw new Error(\"can't serialize object of type \"+typeof t)}function Mn(t){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp||t instanceof ArrayBuffer||ArrayBuffer.isView(t)||t instanceof _n)return t;if(Array.isArray(t))return t.map(Mn);if(\"object\"==typeof t){var e=t.$name||\"Object\",r=wn[e].klass;if(!r)throw new Error(\"can't deserialize unregistered class \"+e);if(r.deserialize)return r.deserialize(t);for(var n=Object.create(r.prototype),i=0,a=Object.keys(t);i<a.length;i+=1){var o=a[i];if(\"$name\"!==o){var s=t[o];n[o]=wn[e].shallow.indexOf(o)>=0?s:Mn(s)}}return n}throw new Error(\"can't deserialize object of type \"+typeof t)}var Sn=function(){this.first=!0};Sn.prototype.update=function(t,e){var r=Math.floor(t);return this.first?(this.first=!1,this.lastIntegerZoom=r,this.lastIntegerZoomTime=0,this.lastZoom=t,this.lastFloorZoom=r,!0):(this.lastFloorZoom>r?(this.lastIntegerZoom=r+1,this.lastIntegerZoomTime=e):this.lastFloorZoom<r&&(this.lastIntegerZoom=r,this.lastIntegerZoomTime=e),t!==this.lastZoom&&(this.lastZoom=t,this.lastFloorZoom=r,!0))};var En={\"Latin-1 Supplement\":function(t){return t>=128&&t<=255},Arabic:function(t){return t>=1536&&t<=1791},\"Arabic Supplement\":function(t){return t>=1872&&t<=1919},\"Arabic Extended-A\":function(t){return t>=2208&&t<=2303},\"Hangul Jamo\":function(t){return t>=4352&&t<=4607},\"Unified Canadian Aboriginal Syllabics\":function(t){return t>=5120&&t<=5759},Khmer:function(t){return t>=6016&&t<=6143},\"Unified Canadian Aboriginal Syllabics Extended\":function(t){return t>=6320&&t<=6399},\"General Punctuation\":function(t){return t>=8192&&t<=8303},\"Letterlike Symbols\":function(t){return t>=8448&&t<=8527},\"Number Forms\":function(t){return t>=8528&&t<=8591},\"Miscellaneous Technical\":function(t){return t>=8960&&t<=9215},\"Control Pictures\":function(t){return t>=9216&&t<=9279},\"Optical Character Recognition\":function(t){return t>=9280&&t<=9311},\"Enclosed Alphanumerics\":function(t){return t>=9312&&t<=9471},\"Geometric Shapes\":function(t){return t>=9632&&t<=9727},\"Miscellaneous Symbols\":function(t){return t>=9728&&t<=9983},\"Miscellaneous Symbols and Arrows\":function(t){return t>=11008&&t<=11263},\"CJK Radicals Supplement\":function(t){return t>=11904&&t<=12031},\"Kangxi Radicals\":function(t){return t>=12032&&t<=12255},\"Ideographic Description Characters\":function(t){return t>=12272&&t<=12287},\"CJK Symbols and Punctuation\":function(t){return t>=12288&&t<=12351},Hiragana:function(t){return t>=12352&&t<=12447},Katakana:function(t){return t>=12448&&t<=12543},Bopomofo:function(t){return t>=12544&&t<=12591},\"Hangul Compatibility Jamo\":function(t){return t>=12592&&t<=12687},Kanbun:function(t){return t>=12688&&t<=12703},\"Bopomofo Extended\":function(t){return t>=12704&&t<=12735},\"CJK Strokes\":function(t){return t>=12736&&t<=12783},\"Katakana Phonetic Extensions\":function(t){return t>=12784&&t<=12799},\"Enclosed CJK Letters and Months\":function(t){return t>=12800&&t<=13055},\"CJK Compatibility\":function(t){return t>=13056&&t<=13311},\"CJK Unified Ideographs Extension A\":function(t){return t>=13312&&t<=19903},\"Yijing Hexagram Symbols\":function(t){return t>=19904&&t<=19967},\"CJK Unified Ideographs\":function(t){return t>=19968&&t<=40959},\"Yi Syllables\":function(t){return t>=40960&&t<=42127},\"Yi Radicals\":function(t){return t>=42128&&t<=42191},\"Hangul Jamo Extended-A\":function(t){return t>=43360&&t<=43391},\"Hangul Syllables\":function(t){return t>=44032&&t<=55215},\"Hangul Jamo Extended-B\":function(t){return t>=55216&&t<=55295},\"Private Use Area\":function(t){return t>=57344&&t<=63743},\"CJK Compatibility Ideographs\":function(t){return t>=63744&&t<=64255},\"Arabic Presentation Forms-A\":function(t){return t>=64336&&t<=65023},\"Vertical Forms\":function(t){return t>=65040&&t<=65055},\"CJK Compatibility Forms\":function(t){return t>=65072&&t<=65103},\"Small Form Variants\":function(t){return t>=65104&&t<=65135},\"Arabic Presentation Forms-B\":function(t){return t>=65136&&t<=65279},\"Halfwidth and Fullwidth Forms\":function(t){return t>=65280&&t<=65519}};function Cn(t){for(var e=0,r=t;e<r.length;e+=1)if(On(r[e].charCodeAt(0)))return!0;return!1}function Ln(t){for(var e=0,r=t;e<r.length;e+=1)if(!Pn(r[e].charCodeAt(0)))return!1;return!0}function Pn(t){return!(En.Arabic(t)||En[\"Arabic Supplement\"](t)||En[\"Arabic Extended-A\"](t)||En[\"Arabic Presentation Forms-A\"](t)||En[\"Arabic Presentation Forms-B\"](t))}function On(t){return!!(746===t||747===t||!(t<4352)&&(En[\"Bopomofo Extended\"](t)||En.Bopomofo(t)||En[\"CJK Compatibility Forms\"](t)&&!(t>=65097&&t<=65103)||En[\"CJK Compatibility Ideographs\"](t)||En[\"CJK Compatibility\"](t)||En[\"CJK Radicals Supplement\"](t)||En[\"CJK Strokes\"](t)||!(!En[\"CJK Symbols and Punctuation\"](t)||t>=12296&&t<=12305||t>=12308&&t<=12319||12336===t)||En[\"CJK Unified Ideographs Extension A\"](t)||En[\"CJK Unified Ideographs\"](t)||En[\"Enclosed CJK Letters and Months\"](t)||En[\"Hangul Compatibility Jamo\"](t)||En[\"Hangul Jamo Extended-A\"](t)||En[\"Hangul Jamo Extended-B\"](t)||En[\"Hangul Jamo\"](t)||En[\"Hangul Syllables\"](t)||En.Hiragana(t)||En[\"Ideographic Description Characters\"](t)||En.Kanbun(t)||En[\"Kangxi Radicals\"](t)||En[\"Katakana Phonetic Extensions\"](t)||En.Katakana(t)&&12540!==t||!(!En[\"Halfwidth and Fullwidth Forms\"](t)||65288===t||65289===t||65293===t||t>=65306&&t<=65310||65339===t||65341===t||65343===t||t>=65371&&t<=65503||65507===t||t>=65512&&t<=65519)||!(!En[\"Small Form Variants\"](t)||t>=65112&&t<=65118||t>=65123&&t<=65126)||En[\"Unified Canadian Aboriginal Syllabics\"](t)||En[\"Unified Canadian Aboriginal Syllabics Extended\"](t)||En[\"Vertical Forms\"](t)||En[\"Yijing Hexagram Symbols\"](t)||En[\"Yi Syllables\"](t)||En[\"Yi Radicals\"](t)))}function zn(t){return!(On(t)||function(t){return!!(En[\"Latin-1 Supplement\"](t)&&(167===t||169===t||174===t||177===t||188===t||189===t||190===t||215===t||247===t)||En[\"General Punctuation\"](t)&&(8214===t||8224===t||8225===t||8240===t||8241===t||8251===t||8252===t||8258===t||8263===t||8264===t||8265===t||8273===t)||En[\"Letterlike Symbols\"](t)||En[\"Number Forms\"](t)||En[\"Miscellaneous Technical\"](t)&&(t>=8960&&t<=8967||t>=8972&&t<=8991||t>=8996&&t<=9e3||9003===t||t>=9085&&t<=9114||t>=9150&&t<=9165||9167===t||t>=9169&&t<=9179||t>=9186&&t<=9215)||En[\"Control Pictures\"](t)&&9251!==t||En[\"Optical Character Recognition\"](t)||En[\"Enclosed Alphanumerics\"](t)||En[\"Geometric Shapes\"](t)||En[\"Miscellaneous Symbols\"](t)&&!(t>=9754&&t<=9759)||En[\"Miscellaneous Symbols and Arrows\"](t)&&(t>=11026&&t<=11055||t>=11088&&t<=11097||t>=11192&&t<=11243)||En[\"CJK Symbols and Punctuation\"](t)||En.Katakana(t)||En[\"Private Use Area\"](t)||En[\"CJK Compatibility Forms\"](t)||En[\"Small Form Variants\"](t)||En[\"Halfwidth and Fullwidth Forms\"](t)||8734===t||8756===t||8757===t||t>=9984&&t<=10087||t>=10102&&t<=10131||65532===t||65533===t)}(t))}function In(t,e){return!(!e&&(t>=1424&&t<=2303||En[\"Arabic Presentation Forms-A\"](t)||En[\"Arabic Presentation Forms-B\"](t))||t>=2304&&t<=3583||t>=3840&&t<=4255||En.Khmer(t))}var Dn,Rn=!1,Fn=null,Bn=!1,Nn=new zt,jn={applyArabicShaping:null,processBidirectionalText:null,processStyledBidirectionalText:null,isLoaded:function(){return Bn||null!=jn.applyArabicShaping}},Un=function(t,e){this.zoom=t,e?(this.now=e.now,this.fadeDuration=e.fadeDuration,this.zoomHistory=e.zoomHistory,this.transition=e.transition):(this.now=0,this.fadeDuration=0,this.zoomHistory=new Sn,this.transition={})};Un.prototype.isSupportedScript=function(t){return function(t,e){for(var r=0,n=t;r<n.length;r+=1)if(!In(n[r].charCodeAt(0),e))return!1;return!0}(t,jn.isLoaded())},Un.prototype.crossFadingFactor=function(){return 0===this.fadeDuration?1:Math.min((this.now-this.zoomHistory.lastIntegerZoomTime)/this.fadeDuration,1)},Un.prototype.getCrossfadeParameters=function(){var t=this.zoom,e=t-Math.floor(t),r=this.crossFadingFactor();return t>this.zoomHistory.lastIntegerZoom?{fromScale:2,toScale:1,t:e+(1-e)*r}:{fromScale:.5,toScale:1,t:1-(1-r)*e}};var Vn=function(t,e){this.property=t,this.value=e,this.expression=function(t,e){if(kr(t))return new Rr(t,e);if(Pr(t)){var r=Dr(t,e);if(\"error\"===r.result)throw new Error(r.value.map(function(t){return t.key+\": \"+t.message}).join(\", \"));return r.value}var n=t;return\"string\"==typeof t&&\"color\"===e.type&&(n=ne.parse(t)),{kind:\"constant\",evaluate:function(){return n}}}(void 0===e?t.specification.default:e,t.specification)};Vn.prototype.isDataDriven=function(){return\"source\"===this.expression.kind||\"composite\"===this.expression.kind},Vn.prototype.possiblyEvaluate=function(t){return this.property.possiblyEvaluate(this,t)};var qn=function(t){this.property=t,this.value=new Vn(t,void 0)};qn.prototype.transitioned=function(t,e){return new Gn(this.property,this.value,e,h({},t.transition,this.transition),t.now)},qn.prototype.untransitioned=function(){return new Gn(this.property,this.value,null,{},0)};var Hn=function(t){this._properties=t,this._values=Object.create(t.defaultTransitionablePropertyValues)};Hn.prototype.getValue=function(t){return b(this._values[t].value.value)},Hn.prototype.setValue=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new qn(this._values[t].property)),this._values[t].value=new Vn(this._values[t].property,null===e?void 0:b(e))},Hn.prototype.getTransition=function(t){return b(this._values[t].transition)},Hn.prototype.setTransition=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new qn(this._values[t].property)),this._values[t].transition=b(e)||void 0},Hn.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i);var a=this.getTransition(n);void 0!==a&&(t[n+\"-transition\"]=a)}return t},Hn.prototype.transitioned=function(t,e){for(var r=new Yn(this._properties),n=0,i=Object.keys(this._values);n<i.length;n+=1){var a=i[n];r._values[a]=this._values[a].transitioned(t,e._values[a])}return r},Hn.prototype.untransitioned=function(){for(var t=new Yn(this._properties),e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e];t._values[n]=this._values[n].untransitioned()}return t};var Gn=function(t,e,r,n,i){this.property=t,this.value=e,this.begin=i+n.delay||0,this.end=this.begin+n.duration||0,t.specification.transition&&(n.delay||n.duration)&&(this.prior=r)};Gn.prototype.possiblyEvaluate=function(t){var e=t.now||0,r=this.value.possiblyEvaluate(t),n=this.prior;if(n){if(e>this.end)return this.prior=null,r;if(this.value.isDataDriven())return this.prior=null,r;if(e<this.begin)return n.possiblyEvaluate(t);var i=(e-this.begin)/(this.end-this.begin);return this.property.interpolate(n.possiblyEvaluate(t),r,function(t){if(i<=0)return 0;if(i>=1)return 1;var e=i*i,r=e*i;return 4*(i<.5?r:3*(i-e)+r-.75)}())}return r};var Yn=function(t){this._properties=t,this._values=Object.create(t.defaultTransitioningPropertyValues)};Yn.prototype.possiblyEvaluate=function(t){for(var e=new Zn(this._properties),r=0,n=Object.keys(this._values);r<n.length;r+=1){var i=n[r];e._values[i]=this._values[i].possiblyEvaluate(t)}return e},Yn.prototype.hasTransition=function(){for(var t=0,e=Object.keys(this._values);t<e.length;t+=1){var r=e[t];if(this._values[r].prior)return!0}return!1};var Wn=function(t){this._properties=t,this._values=Object.create(t.defaultPropertyValues)};Wn.prototype.getValue=function(t){return b(this._values[t].value)},Wn.prototype.setValue=function(t,e){this._values[t]=new Vn(this._values[t].property,null===e?void 0:b(e))},Wn.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i)}return t},Wn.prototype.possiblyEvaluate=function(t){for(var e=new Zn(this._properties),r=0,n=Object.keys(this._values);r<n.length;r+=1){var i=n[r];e._values[i]=this._values[i].possiblyEvaluate(t)}return e};var Xn=function(t,e,r){this.property=t,this.value=e,this.parameters=r};Xn.prototype.isConstant=function(){return\"constant\"===this.value.kind},Xn.prototype.constantOr=function(t){return\"constant\"===this.value.kind?this.value.value:t},Xn.prototype.evaluate=function(t,e){return this.property.evaluate(this.value,this.parameters,t,e)};var Zn=function(t){this._properties=t,this._values=Object.create(t.defaultPossiblyEvaluatedValues)};Zn.prototype.get=function(t){return this._values[t]};var Jn=function(t){this.specification=t};Jn.prototype.possiblyEvaluate=function(t,e){return t.expression.evaluate(e)},Jn.prototype.interpolate=function(t,e,r){var n=Ce[this.specification.type];return n?n(t,e,r):t};var Kn=function(t){this.specification=t};Kn.prototype.possiblyEvaluate=function(t,e){return\"constant\"===t.expression.kind||\"camera\"===t.expression.kind?new Xn(this,{kind:\"constant\",value:t.expression.evaluate(e)},e):new Xn(this,t.expression,e)},Kn.prototype.interpolate=function(t,e,r){if(\"constant\"!==t.value.kind||\"constant\"!==e.value.kind)return t;if(void 0===t.value.value||void 0===e.value.value)return new Xn(this,{kind:\"constant\",value:void 0},t.parameters);var n=Ce[this.specification.type];return n?new Xn(this,{kind:\"constant\",value:n(t.value.value,e.value.value,r)},t.parameters):t},Kn.prototype.evaluate=function(t,e,r,n){return\"constant\"===t.kind?t.value:t.evaluate(e,r,n)};var $n=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(t,e){if(void 0===t.value)return new Xn(this,{kind:\"constant\",value:void 0},e);if(\"constant\"===t.expression.kind){var r=t.expression.evaluate(e),n=this._calculate(r,r,r,e);return new Xn(this,{kind:\"constant\",value:n},e)}if(\"camera\"===t.expression.kind){var i=this._calculate(t.expression.evaluate({zoom:e.zoom-1}),t.expression.evaluate({zoom:e.zoom}),t.expression.evaluate({zoom:e.zoom+1}),e);return new Xn(this,{kind:\"constant\",value:i},e)}return new Xn(this,t.expression,e)},e.prototype.evaluate=function(t,e,r,n){if(\"source\"===t.kind){var i=t.evaluate(e,r,n);return this._calculate(i,i,i,e)}return\"composite\"===t.kind?this._calculate(t.evaluate({zoom:Math.floor(e.zoom)-1},r,n),t.evaluate({zoom:Math.floor(e.zoom)},r,n),t.evaluate({zoom:Math.floor(e.zoom)+1},r,n),e):t.value},e.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},e.prototype.interpolate=function(t){return t},e}(Kn),Qn=function(t){this.specification=t};Qn.prototype.possiblyEvaluate=function(t,e){if(void 0!==t.value){if(\"constant\"===t.expression.kind){var r=t.expression.evaluate(e);return this._calculate(r,r,r,e)}return this._calculate(t.expression.evaluate(new Un(Math.floor(e.zoom-1),e)),t.expression.evaluate(new Un(Math.floor(e.zoom),e)),t.expression.evaluate(new Un(Math.floor(e.zoom+1),e)),e)}},Qn.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},Qn.prototype.interpolate=function(t){return t};var ti=function(t){this.specification=t};ti.prototype.possiblyEvaluate=function(t,e){return!!t.expression.evaluate(e)},ti.prototype.interpolate=function(){return!1};var ei=function(t){for(var e in this.properties=t,this.defaultPropertyValues={},this.defaultTransitionablePropertyValues={},this.defaultTransitioningPropertyValues={},this.defaultPossiblyEvaluatedValues={},t){var r=t[e],n=this.defaultPropertyValues[e]=new Vn(r,void 0),i=this.defaultTransitionablePropertyValues[e]=new qn(r);this.defaultTransitioningPropertyValues[e]=i.untransitioned(),this.defaultPossiblyEvaluatedValues[e]=n.possiblyEvaluate({})}};kn(\"DataDrivenProperty\",Kn),kn(\"DataConstantProperty\",Jn),kn(\"CrossFadedDataDrivenProperty\",$n),kn(\"CrossFadedProperty\",Qn),kn(\"ColorRampProperty\",ti);var ri=function(t){function e(e,r){if(t.call(this),this.id=e.id,this.type=e.type,this._featureFilter=function(){return!0},\"custom\"!==e.type&&(e=e,this.metadata=e.metadata,this.minzoom=e.minzoom,this.maxzoom=e.maxzoom,\"background\"!==e.type&&(this.source=e.source,this.sourceLayer=e[\"source-layer\"],this.filter=e.filter),r.layout&&(this._unevaluatedLayout=new Wn(r.layout)),r.paint)){for(var n in this._transitionablePaint=new Hn(r.paint),e.paint)this.setPaintProperty(n,e.paint[n],{validate:!1});for(var i in e.layout)this.setLayoutProperty(i,e.layout[i],{validate:!1});this._transitioningPaint=this._transitionablePaint.untransitioned()}}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getCrossfadeParameters=function(){return this._crossfadeParameters},e.prototype.getLayoutProperty=function(t){return\"visibility\"===t?this.visibility:this._unevaluatedLayout.getValue(t)},e.prototype.setLayoutProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e){var n=\"layers.\"+this.id+\".layout.\"+t;if(this._validate(vn,n,t,e,r))return}\"visibility\"!==t?this._unevaluatedLayout.setValue(t,e):this.visibility=e},e.prototype.getPaintProperty=function(t){return m(t,\"-transition\")?this._transitionablePaint.getTransition(t.slice(0,-\"-transition\".length)):this._transitionablePaint.getValue(t)},e.prototype.setPaintProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e){var n=\"layers.\"+this.id+\".paint.\"+t;if(this._validate(gn,n,t,e,r))return!1}if(m(t,\"-transition\"))return this._transitionablePaint.setTransition(t.slice(0,-\"-transition\".length),e||void 0),!1;var i=this._transitionablePaint._values[t],a=\"cross-faded-data-driven\"===i.property.specification[\"property-type\"],o=i.value.isDataDriven();return this._transitionablePaint.setValue(t,e),this._handleSpecialPaintPropertyUpdate(t),this._transitionablePaint._values[t].value.isDataDriven()||o||a},e.prototype._handleSpecialPaintPropertyUpdate=function(t){},e.prototype.isHidden=function(t){return!!(this.minzoom&&t<this.minzoom)||!!(this.maxzoom&&t>=this.maxzoom)||\"none\"===this.visibility},e.prototype.updateTransitions=function(t){this._transitioningPaint=this._transitionablePaint.transitioned(t,this._transitioningPaint)},e.prototype.hasTransition=function(){return this._transitioningPaint.hasTransition()},e.prototype.recalculate=function(t){t.getCrossfadeParameters&&(this._crossfadeParameters=t.getCrossfadeParameters()),this._unevaluatedLayout&&(this.layout=this._unevaluatedLayout.possiblyEvaluate(t)),this.paint=this._transitioningPaint.possiblyEvaluate(t)},e.prototype.serialize=function(){var t={id:this.id,type:this.type,source:this.source,\"source-layer\":this.sourceLayer,metadata:this.metadata,minzoom:this.minzoom,maxzoom:this.maxzoom,filter:this.filter,layout:this._unevaluatedLayout&&this._unevaluatedLayout.serialize(),paint:this._transitionablePaint&&this._transitionablePaint.serialize()};return this.visibility&&(t.layout=t.layout||{},t.layout.visibility=this.visibility),x(t,function(t,e){return!(void 0===t||\"layout\"===e&&!Object.keys(t).length||\"paint\"===e&&!Object.keys(t).length)})},e.prototype._validate=function(t,e,r,n,i){return void 0===i&&(i={}),(!i||!1!==i.validate)&&mn(this,t.call(pn,{key:e,layerType:this.type,objectKey:r,value:n,styleSpec:It,style:{glyphs:!0,sprite:!0}}))},e.prototype.is3D=function(){return!1},e.prototype.isTileClipped=function(){return!1},e.prototype.hasOffscreenPass=function(){return!1},e.prototype.resize=function(){},e.prototype.isStateDependent=function(){for(var t in this.paint._values){var e=this.paint.get(t);if(e instanceof Xn&&xr(e.property.specification)&&(\"source\"===e.value.kind||\"composite\"===e.value.kind)&&e.value.isStateDependent)return!0}return!1},e}(zt),ni={Int8:Int8Array,Uint8:Uint8Array,Int16:Int16Array,Uint16:Uint16Array,Int32:Int32Array,Uint32:Uint32Array,Float32:Float32Array},ii=function(t,e){this._structArray=t,this._pos1=e*this.size,this._pos2=this._pos1/2,this._pos4=this._pos1/4,this._pos8=this._pos1/8},ai=function(){this.isTransferred=!1,this.capacity=-1,this.resize(0)};function oi(t,e){void 0===e&&(e=1);var r=0,n=0;return{members:t.map(function(t){var i,a=(i=t.type,ni[i].BYTES_PER_ELEMENT),o=r=si(r,Math.max(e,a)),s=t.components||1;return n=Math.max(n,a),r+=a*s,{name:t.name,type:t.type,components:s,offset:o}}),size:si(r,Math.max(n,e)),alignment:e}}function si(t,e){return Math.ceil(t/e)*e}ai.serialize=function(t,e){return t._trim(),e&&(t.isTransferred=!0,e.push(t.arrayBuffer)),{length:t.length,arrayBuffer:t.arrayBuffer}},ai.deserialize=function(t){var e=Object.create(this.prototype);return e.arrayBuffer=t.arrayBuffer,e.length=t.length,e.capacity=t.arrayBuffer.byteLength/e.bytesPerElement,e._refreshViews(),e},ai.prototype._trim=function(){this.length!==this.capacity&&(this.capacity=this.length,this.arrayBuffer=this.arrayBuffer.slice(0,this.length*this.bytesPerElement),this._refreshViews())},ai.prototype.clear=function(){this.length=0},ai.prototype.resize=function(t){this.reserve(t),this.length=t},ai.prototype.reserve=function(t){if(t>this.capacity){this.capacity=Math.max(t,Math.floor(5*this.capacity),128),this.arrayBuffer=new ArrayBuffer(this.capacity*this.bytesPerElement);var e=this.uint8;this._refreshViews(),e&&this.uint8.set(e)}},ai.prototype._refreshViews=function(){throw new Error(\"_refreshViews() must be implemented by each concrete StructArray layout\")};var li=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.int16[n+0]=e,this.int16[n+1]=r,t},e}(ai);li.prototype.bytesPerElement=4,kn(\"StructArrayLayout2i4\",li);var ci=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.int16[a+0]=e,this.int16[a+1]=r,this.int16[a+2]=n,this.int16[a+3]=i,t},e}(ai);ci.prototype.bytesPerElement=8,kn(\"StructArrayLayout4i8\",ci);var ui=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(ai);ui.prototype.bytesPerElement=12,kn(\"StructArrayLayout2i4i12\",ui);var hi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=4*t,l=8*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.uint8[l+4]=n,this.uint8[l+5]=i,this.uint8[l+6]=a,this.uint8[l+7]=o,t},e}(ai);hi.prototype.bytesPerElement=8,kn(\"StructArrayLayout2i4ub8\",hi);var fi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s){var l=this.length;return this.resize(l+1),this.emplace(l,t,e,r,n,i,a,o,s)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l){var c=8*t;return this.uint16[c+0]=e,this.uint16[c+1]=r,this.uint16[c+2]=n,this.uint16[c+3]=i,this.uint16[c+4]=a,this.uint16[c+5]=o,this.uint16[c+6]=s,this.uint16[c+7]=l,t},e}(ai);fi.prototype.bytesPerElement=16,kn(\"StructArrayLayout8ui16\",fi);var pi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s){var l=this.length;return this.resize(l+1),this.emplace(l,t,e,r,n,i,a,o,s)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l){var c=8*t;return this.int16[c+0]=e,this.int16[c+1]=r,this.int16[c+2]=n,this.int16[c+3]=i,this.uint16[c+4]=a,this.uint16[c+5]=o,this.uint16[c+6]=s,this.uint16[c+7]=l,t},e}(ai);pi.prototype.bytesPerElement=16,kn(\"StructArrayLayout4i4ui16\",pi);var di=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.float32[i+0]=e,this.float32[i+1]=r,this.float32[i+2]=n,t},e}(ai);di.prototype.bytesPerElement=12,kn(\"StructArrayLayout3f12\",di);var gi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.uint32[r+0]=e,t},e}(ai);gi.prototype.bytesPerElement=4,kn(\"StructArrayLayout1ul4\",gi);var vi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u){var h=this.length;return this.resize(h+1),this.emplace(h,t,e,r,n,i,a,o,s,l,c,u)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h){var f=12*t,p=6*t;return this.int16[f+0]=e,this.int16[f+1]=r,this.int16[f+2]=n,this.int16[f+3]=i,this.int16[f+4]=a,this.int16[f+5]=o,this.uint32[p+3]=s,this.uint16[f+8]=l,this.uint16[f+9]=c,this.int16[f+10]=u,this.int16[f+11]=h,t},e}(ai);vi.prototype.bytesPerElement=24,kn(\"StructArrayLayout6i1ul2ui2i24\",vi);var mi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(ai);mi.prototype.bytesPerElement=12,kn(\"StructArrayLayout2i2i2i12\",mi);var yi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=12*t,o=3*t;return this.uint8[a+0]=e,this.uint8[a+1]=r,this.float32[o+1]=n,this.float32[o+2]=i,t},e}(ai);yi.prototype.bytesPerElement=12,kn(\"StructArrayLayout2ub2f12\",yi);var xi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d){var g=this.length;return this.resize(g+1),this.emplace(g,t,e,r,n,i,a,o,s,l,c,u,h,f,p,d)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g){var v=22*t,m=11*t,y=44*t;return this.int16[v+0]=e,this.int16[v+1]=r,this.uint16[v+2]=n,this.uint16[v+3]=i,this.uint32[m+2]=a,this.uint32[m+3]=o,this.uint32[m+4]=s,this.uint16[v+10]=l,this.uint16[v+11]=c,this.uint16[v+12]=u,this.float32[m+7]=h,this.float32[m+8]=f,this.uint8[y+36]=p,this.uint8[y+37]=d,this.uint32[m+10]=g,t},e}(ai);xi.prototype.bytesPerElement=44,kn(\"StructArrayLayout2i2ui3ul3ui2f2ub1ul44\",xi);var bi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m){var y=this.length;return this.resize(y+1),this.emplace(y,t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m,y){var x=22*t,b=11*t;return this.int16[x+0]=e,this.int16[x+1]=r,this.int16[x+2]=n,this.int16[x+3]=i,this.int16[x+4]=a,this.int16[x+5]=o,this.uint16[x+6]=s,this.uint16[x+7]=l,this.uint16[x+8]=c,this.uint16[x+9]=u,this.uint16[x+10]=h,this.uint16[x+11]=f,this.uint16[x+12]=p,this.uint16[x+13]=d,this.uint16[x+14]=g,this.uint32[b+8]=v,this.float32[b+9]=m,this.float32[b+10]=y,t},e}(ai);bi.prototype.bytesPerElement=44,kn(\"StructArrayLayout6i9ui1ul2f44\",bi);var _i=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.float32[r+0]=e,t},e}(ai);_i.prototype.bytesPerElement=4,kn(\"StructArrayLayout1f4\",_i);var wi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.int16[i+0]=e,this.int16[i+1]=r,this.int16[i+2]=n,t},e}(ai);wi.prototype.bytesPerElement=6,kn(\"StructArrayLayout3i6\",wi);var ki=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=2*t,a=4*t;return this.uint32[i+0]=e,this.uint16[a+2]=r,this.uint16[a+3]=n,t},e}(ai);ki.prototype.bytesPerElement=8,kn(\"StructArrayLayout1ul2ui8\",ki);var Ti=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.uint16[i+0]=e,this.uint16[i+1]=r,this.uint16[i+2]=n,t},e}(ai);Ti.prototype.bytesPerElement=6,kn(\"StructArrayLayout3ui6\",Ti);var Ai=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.uint16[n+0]=e,this.uint16[n+1]=r,t},e}(ai);Ai.prototype.bytesPerElement=4,kn(\"StructArrayLayout2ui4\",Ai);var Mi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.uint16[r+0]=e,t},e}(ai);Mi.prototype.bytesPerElement=2,kn(\"StructArrayLayout1ui2\",Mi);var Si=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.float32[n+0]=e,this.float32[n+1]=r,t},e}(ai);Si.prototype.bytesPerElement=8,kn(\"StructArrayLayout2f8\",Si);var Ei=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.float32[a+0]=e,this.float32[a+1]=r,this.float32[a+2]=n,this.float32[a+3]=i,t},e}(ai);Ei.prototype.bytesPerElement=16,kn(\"StructArrayLayout4f16\",Ei);var Ci=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorPointX:{configurable:!0},anchorPointY:{configurable:!0},x1:{configurable:!0},y1:{configurable:!0},x2:{configurable:!0},y2:{configurable:!0},featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0},radius:{configurable:!0},signedDistanceFromAnchor:{configurable:!0},anchorPoint:{configurable:!0}};return r.anchorPointX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorPointX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorPointY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorPointY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.x1.get=function(){return this._structArray.int16[this._pos2+2]},r.x1.set=function(t){this._structArray.int16[this._pos2+2]=t},r.y1.get=function(){return this._structArray.int16[this._pos2+3]},r.y1.set=function(t){this._structArray.int16[this._pos2+3]=t},r.x2.get=function(){return this._structArray.int16[this._pos2+4]},r.x2.set=function(t){this._structArray.int16[this._pos2+4]=t},r.y2.get=function(){return this._structArray.int16[this._pos2+5]},r.y2.set=function(t){this._structArray.int16[this._pos2+5]=t},r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.featureIndex.set=function(t){this._structArray.uint32[this._pos4+3]=t},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.sourceLayerIndex.set=function(t){this._structArray.uint16[this._pos2+8]=t},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.bucketIndex.set=function(t){this._structArray.uint16[this._pos2+9]=t},r.radius.get=function(){return this._structArray.int16[this._pos2+10]},r.radius.set=function(t){this._structArray.int16[this._pos2+10]=t},r.signedDistanceFromAnchor.get=function(){return this._structArray.int16[this._pos2+11]},r.signedDistanceFromAnchor.set=function(t){this._structArray.int16[this._pos2+11]=t},r.anchorPoint.get=function(){return new i(this.anchorPointX,this.anchorPointY)},Object.defineProperties(e.prototype,r),e}(ii);Ci.prototype.size=24;var Li=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Ci(this,t)},e}(vi);kn(\"CollisionBoxArray\",Li);var Pi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},glyphStartIndex:{configurable:!0},numGlyphs:{configurable:!0},vertexStartIndex:{configurable:!0},lineStartIndex:{configurable:!0},lineLength:{configurable:!0},segment:{configurable:!0},lowerSize:{configurable:!0},upperSize:{configurable:!0},lineOffsetX:{configurable:!0},lineOffsetY:{configurable:!0},writingMode:{configurable:!0},hidden:{configurable:!0},crossTileID:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.glyphStartIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.glyphStartIndex.set=function(t){this._structArray.uint16[this._pos2+2]=t},r.numGlyphs.get=function(){return this._structArray.uint16[this._pos2+3]},r.numGlyphs.set=function(t){this._structArray.uint16[this._pos2+3]=t},r.vertexStartIndex.get=function(){return this._structArray.uint32[this._pos4+2]},r.vertexStartIndex.set=function(t){this._structArray.uint32[this._pos4+2]=t},r.lineStartIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.lineStartIndex.set=function(t){this._structArray.uint32[this._pos4+3]=t},r.lineLength.get=function(){return this._structArray.uint32[this._pos4+4]},r.lineLength.set=function(t){this._structArray.uint32[this._pos4+4]=t},r.segment.get=function(){return this._structArray.uint16[this._pos2+10]},r.segment.set=function(t){this._structArray.uint16[this._pos2+10]=t},r.lowerSize.get=function(){return this._structArray.uint16[this._pos2+11]},r.lowerSize.set=function(t){this._structArray.uint16[this._pos2+11]=t},r.upperSize.get=function(){return this._structArray.uint16[this._pos2+12]},r.upperSize.set=function(t){this._structArray.uint16[this._pos2+12]=t},r.lineOffsetX.get=function(){return this._structArray.float32[this._pos4+7]},r.lineOffsetX.set=function(t){this._structArray.float32[this._pos4+7]=t},r.lineOffsetY.get=function(){return this._structArray.float32[this._pos4+8]},r.lineOffsetY.set=function(t){this._structArray.float32[this._pos4+8]=t},r.writingMode.get=function(){return this._structArray.uint8[this._pos1+36]},r.writingMode.set=function(t){this._structArray.uint8[this._pos1+36]=t},r.hidden.get=function(){return this._structArray.uint8[this._pos1+37]},r.hidden.set=function(t){this._structArray.uint8[this._pos1+37]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+10]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+10]=t},Object.defineProperties(e.prototype,r),e}(ii);Pi.prototype.size=44;var Oi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Pi(this,t)},e}(xi);kn(\"PlacedSymbolArray\",Oi);var zi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},rightJustifiedTextSymbolIndex:{configurable:!0},centerJustifiedTextSymbolIndex:{configurable:!0},leftJustifiedTextSymbolIndex:{configurable:!0},verticalPlacedTextSymbolIndex:{configurable:!0},key:{configurable:!0},textBoxStartIndex:{configurable:!0},textBoxEndIndex:{configurable:!0},iconBoxStartIndex:{configurable:!0},iconBoxEndIndex:{configurable:!0},featureIndex:{configurable:!0},numHorizontalGlyphVertices:{configurable:!0},numVerticalGlyphVertices:{configurable:!0},numIconVertices:{configurable:!0},crossTileID:{configurable:!0},textBoxScale:{configurable:!0},radialTextOffset:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.rightJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+2]},r.rightJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+2]=t},r.centerJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+3]},r.centerJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+3]=t},r.leftJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+4]},r.leftJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+4]=t},r.verticalPlacedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+5]},r.verticalPlacedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+5]=t},r.key.get=function(){return this._structArray.uint16[this._pos2+6]},r.key.set=function(t){this._structArray.uint16[this._pos2+6]=t},r.textBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+7]},r.textBoxStartIndex.set=function(t){this._structArray.uint16[this._pos2+7]=t},r.textBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.textBoxEndIndex.set=function(t){this._structArray.uint16[this._pos2+8]=t},r.iconBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.iconBoxStartIndex.set=function(t){this._structArray.uint16[this._pos2+9]=t},r.iconBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+10]},r.iconBoxEndIndex.set=function(t){this._structArray.uint16[this._pos2+10]=t},r.featureIndex.get=function(){return this._structArray.uint16[this._pos2+11]},r.featureIndex.set=function(t){this._structArray.uint16[this._pos2+11]=t},r.numHorizontalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+12]},r.numHorizontalGlyphVertices.set=function(t){this._structArray.uint16[this._pos2+12]=t},r.numVerticalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+13]},r.numVerticalGlyphVertices.set=function(t){this._structArray.uint16[this._pos2+13]=t},r.numIconVertices.get=function(){return this._structArray.uint16[this._pos2+14]},r.numIconVertices.set=function(t){this._structArray.uint16[this._pos2+14]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+8]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+8]=t},r.textBoxScale.get=function(){return this._structArray.float32[this._pos4+9]},r.textBoxScale.set=function(t){this._structArray.float32[this._pos4+9]=t},r.radialTextOffset.get=function(){return this._structArray.float32[this._pos4+10]},r.radialTextOffset.set=function(t){this._structArray.float32[this._pos4+10]=t},Object.defineProperties(e.prototype,r),e}(ii);zi.prototype.size=44;var Ii=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new zi(this,t)},e}(bi);kn(\"SymbolInstanceArray\",Ii);var Di=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={offsetX:{configurable:!0}};return r.offsetX.get=function(){return this._structArray.float32[this._pos4+0]},r.offsetX.set=function(t){this._structArray.float32[this._pos4+0]=t},Object.defineProperties(e.prototype,r),e}(ii);Di.prototype.size=4;var Ri=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getoffsetX=function(t){return this.float32[1*t+0]},e.prototype.get=function(t){return new Di(this,t)},e}(_i);kn(\"GlyphOffsetArray\",Ri);var Fi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={x:{configurable:!0},y:{configurable:!0},tileUnitDistanceFromAnchor:{configurable:!0}};return r.x.get=function(){return this._structArray.int16[this._pos2+0]},r.x.set=function(t){this._structArray.int16[this._pos2+0]=t},r.y.get=function(){return this._structArray.int16[this._pos2+1]},r.y.set=function(t){this._structArray.int16[this._pos2+1]=t},r.tileUnitDistanceFromAnchor.get=function(){return this._structArray.int16[this._pos2+2]},r.tileUnitDistanceFromAnchor.set=function(t){this._structArray.int16[this._pos2+2]=t},Object.defineProperties(e.prototype,r),e}(ii);Fi.prototype.size=6;var Bi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getx=function(t){return this.int16[3*t+0]},e.prototype.gety=function(t){return this.int16[3*t+1]},e.prototype.gettileUnitDistanceFromAnchor=function(t){return this.int16[3*t+2]},e.prototype.get=function(t){return new Fi(this,t)},e}(wi);kn(\"SymbolLineVertexArray\",Bi);var Ni=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0}};return r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+0]},r.featureIndex.set=function(t){this._structArray.uint32[this._pos4+0]=t},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.sourceLayerIndex.set=function(t){this._structArray.uint16[this._pos2+2]=t},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+3]},r.bucketIndex.set=function(t){this._structArray.uint16[this._pos2+3]=t},Object.defineProperties(e.prototype,r),e}(ii);Ni.prototype.size=8;var ji=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Ni(this,t)},e}(ki);kn(\"FeatureIndexArray\",ji);var Ui=oi([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,Vi=function(t){void 0===t&&(t=[]),this.segments=t};function qi(t,e){return 256*(t=c(Math.floor(t),0,255))+c(Math.floor(e),0,255)}Vi.prototype.prepareSegment=function(t,e,r,n){var i=this.segments[this.segments.length-1];return t>Vi.MAX_VERTEX_ARRAY_LENGTH&&w(\"Max vertices per segment is \"+Vi.MAX_VERTEX_ARRAY_LENGTH+\": bucket requested \"+t),(!i||i.vertexLength+t>Vi.MAX_VERTEX_ARRAY_LENGTH||i.sortKey!==n)&&(i={vertexOffset:e.length,primitiveOffset:r.length,vertexLength:0,primitiveLength:0},void 0!==n&&(i.sortKey=n),this.segments.push(i)),i},Vi.prototype.get=function(){return this.segments},Vi.prototype.destroy=function(){for(var t=0,e=this.segments;t<e.length;t+=1){var r=e[t];for(var n in r.vaos)r.vaos[n].destroy()}},Vi.simpleSegment=function(t,e,r,n){return new Vi([{vertexOffset:t,primitiveOffset:e,vertexLength:r,primitiveLength:n,vaos:{},sortKey:0}])},Vi.MAX_VERTEX_ARRAY_LENGTH=Math.pow(2,16)-1,kn(\"SegmentVector\",Vi);var Hi=function(){this.ids=[],this.positions=[],this.indexed=!1};function Gi(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}Hi.prototype.add=function(t,e,r,n){this.ids.push(t),this.positions.push(e,r,n)},Hi.prototype.getPositions=function(t){for(var e=0,r=this.ids.length-1;e<r;){var n=e+r>>1;this.ids[n]>=t?r=n:e=n+1}for(var i=[];this.ids[e]===t;){var a=this.positions[3*e],o=this.positions[3*e+1],s=this.positions[3*e+2];i.push({index:a,start:o,end:s}),e++}return i},Hi.serialize=function(t,e){var r=new Float64Array(t.ids),n=new Uint32Array(t.positions);return function t(e,r,n,i){if(!(n>=i)){for(var a=e[n+i>>1],o=n-1,s=i+1;;){do{o++}while(e[o]<a);do{s--}while(e[s]>a);if(o>=s)break;Gi(e,o,s),Gi(r,3*o,3*s),Gi(r,3*o+1,3*s+1),Gi(r,3*o+2,3*s+2)}t(e,r,n,s),t(e,r,s+1,i)}}(r,n,0,r.length-1),e.push(r.buffer,n.buffer),{ids:r,positions:n}},Hi.deserialize=function(t){var e=new Hi;return e.ids=t.ids,e.positions=t.positions,e.indexed=!0,e},kn(\"FeaturePositionMap\",Hi);var Yi=function(t,e){this.gl=t.gl,this.location=e},Wi=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1i(this.location,t))},e}(Yi),Xi=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1f(this.location,t))},e}(Yi),Zi=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]||(this.current=t,this.gl.uniform2f(this.location,t[0],t[1]))},e}(Yi),Ji=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]||(this.current=t,this.gl.uniform3f(this.location,t[0],t[1],t[2]))},e}(Yi),Ki=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]&&t[3]===this.current[3]||(this.current=t,this.gl.uniform4f(this.location,t[0],t[1],t[2],t[3]))},e}(Yi),$i=function(t){function e(e,r){t.call(this,e,r),this.current=ne.transparent}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t.r===this.current.r&&t.g===this.current.g&&t.b===this.current.b&&t.a===this.current.a||(this.current=t,this.gl.uniform4f(this.location,t.r,t.g,t.b,t.a))},e}(Yi),Qi=new Float32Array(16),ta=function(t){function e(e,r){t.call(this,e,r),this.current=Qi}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(t[12]!==this.current[12]||t[0]!==this.current[0])return this.current=t,void this.gl.uniformMatrix4fv(this.location,!1,t);for(var e=1;e<16;e++)if(t[e]!==this.current[e]){this.current=t,this.gl.uniformMatrix4fv(this.location,!1,t);break}},e}(Yi);function ea(t){return[qi(255*t.r,255*t.g),qi(255*t.b,255*t.a)]}var ra=function(t,e,r){this.value=t,this.names=e,this.uniformNames=this.names.map(function(t){return\"u_\"+t}),this.type=r,this.maxValue=-1/0};ra.prototype.defines=function(){return this.names.map(function(t){return\"#define HAS_UNIFORM_u_\"+t})},ra.prototype.setConstantPatternPositions=function(){},ra.prototype.populatePaintArray=function(){},ra.prototype.updatePaintArray=function(){},ra.prototype.upload=function(){},ra.prototype.destroy=function(){},ra.prototype.setUniforms=function(t,e,r,n){e.set(n.constantOr(this.value))},ra.prototype.getBinding=function(t,e){return\"color\"===this.type?new $i(t,e):new Xi(t,e)},ra.serialize=function(t){var e=t.value,r=t.names,n=t.type;return{value:An(e),names:r,type:n}},ra.deserialize=function(t){var e=t.value,r=t.names,n=t.type;return new ra(Mn(e),r,n)};var na=function(t,e,r){this.value=t,this.names=e,this.uniformNames=this.names.map(function(t){return\"u_\"+t}),this.type=r,this.maxValue=-1/0,this.patternPositions={patternTo:null,patternFrom:null}};na.prototype.defines=function(){return this.names.map(function(t){return\"#define HAS_UNIFORM_u_\"+t})},na.prototype.populatePaintArray=function(){},na.prototype.updatePaintArray=function(){},na.prototype.upload=function(){},na.prototype.destroy=function(){},na.prototype.setConstantPatternPositions=function(t,e){this.patternPositions.patternTo=t.tlbr,this.patternPositions.patternFrom=e.tlbr},na.prototype.setUniforms=function(t,e,r,n,i){var a=this.patternPositions;\"u_pattern_to\"===i&&a.patternTo&&e.set(a.patternTo),\"u_pattern_from\"===i&&a.patternFrom&&e.set(a.patternFrom)},na.prototype.getBinding=function(t,e){return new Ki(t,e)};var ia=function(t,e,r,n){this.expression=t,this.names=e,this.type=r,this.uniformNames=this.names.map(function(t){return\"a_\"+t}),this.maxValue=-1/0,this.paintVertexAttributes=e.map(function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?2:1,offset:0}}),this.paintVertexArray=new n};ia.prototype.defines=function(){return[]},ia.prototype.setConstantPatternPositions=function(){},ia.prototype.populatePaintArray=function(t,e){var r=this.paintVertexArray,n=r.length;r.reserve(t);var i=this.expression.evaluate(new Un(0),e,{});if(\"color\"===this.type)for(var a=ea(i),o=n;o<t;o++)r.emplaceBack(a[0],a[1]);else{for(var s=n;s<t;s++)r.emplaceBack(i);this.maxValue=Math.max(this.maxValue,i)}},ia.prototype.updatePaintArray=function(t,e,r,n){var i=this.paintVertexArray,a=this.expression.evaluate({zoom:0},r,n);if(\"color\"===this.type)for(var o=ea(a),s=t;s<e;s++)i.emplace(s,o[0],o[1]);else{for(var l=t;l<e;l++)i.emplace(l,a);this.maxValue=Math.max(this.maxValue,a)}},ia.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},ia.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},ia.prototype.setUniforms=function(t,e){e.set(0)},ia.prototype.getBinding=function(t,e){return new Xi(t,e)};var aa=function(t,e,r,n,i,a){this.expression=t,this.names=e,this.uniformNames=this.names.map(function(t){return\"u_\"+t+\"_t\"}),this.type=r,this.useIntegerZoom=n,this.zoom=i,this.maxValue=-1/0;var o=a;this.paintVertexAttributes=e.map(function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?4:2,offset:0}}),this.paintVertexArray=new o};aa.prototype.defines=function(){return[]},aa.prototype.setConstantPatternPositions=function(){},aa.prototype.populatePaintArray=function(t,e){var r=this.paintVertexArray,n=r.length;r.reserve(t);var i=this.expression.evaluate(new Un(this.zoom),e,{}),a=this.expression.evaluate(new Un(this.zoom+1),e,{});if(\"color\"===this.type)for(var o=ea(i),s=ea(a),l=n;l<t;l++)r.emplaceBack(o[0],o[1],s[0],s[1]);else{for(var c=n;c<t;c++)r.emplaceBack(i,a);this.maxValue=Math.max(this.maxValue,i,a)}},aa.prototype.updatePaintArray=function(t,e,r,n){var i=this.paintVertexArray,a=this.expression.evaluate({zoom:this.zoom},r,n),o=this.expression.evaluate({zoom:this.zoom+1},r,n);if(\"color\"===this.type)for(var s=ea(a),l=ea(o),c=t;c<e;c++)i.emplace(c,s[0],s[1],l[0],l[1]);else{for(var u=t;u<e;u++)i.emplace(u,a,o);this.maxValue=Math.max(this.maxValue,a,o)}},aa.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},aa.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},aa.prototype.interpolationFactor=function(t){return this.useIntegerZoom?this.expression.interpolationFactor(Math.floor(t),this.zoom,this.zoom+1):this.expression.interpolationFactor(t,this.zoom,this.zoom+1)},aa.prototype.setUniforms=function(t,e,r){e.set(this.interpolationFactor(r.zoom))},aa.prototype.getBinding=function(t,e){return new Xi(t,e)};var oa=function(t,e,r,n,i,a,o){this.expression=t,this.names=e,this.type=r,this.uniformNames=this.names.map(function(t){return\"u_\"+t+\"_t\"}),this.useIntegerZoom=n,this.zoom=i,this.maxValue=-1/0,this.layerId=o,this.paintVertexAttributes=e.map(function(t){return{name:\"a_\"+t,type:\"Uint16\",components:4,offset:0}}),this.zoomInPaintVertexArray=new a,this.zoomOutPaintVertexArray=new a};oa.prototype.defines=function(){return[]},oa.prototype.setConstantPatternPositions=function(){},oa.prototype.populatePaintArray=function(t,e,r){var n=this.zoomInPaintVertexArray,i=this.zoomOutPaintVertexArray,a=this.layerId,o=n.length;if(n.reserve(t),i.reserve(t),r&&e.patterns&&e.patterns[a]){var s=e.patterns[a],l=s.min,c=s.mid,u=s.max,h=r[l],f=r[c],p=r[u];if(!h||!f||!p)return;for(var d=o;d<t;d++)n.emplaceBack(f.tl[0],f.tl[1],f.br[0],f.br[1],h.tl[0],h.tl[1],h.br[0],h.br[1]),i.emplaceBack(f.tl[0],f.tl[1],f.br[0],f.br[1],p.tl[0],p.tl[1],p.br[0],p.br[1])}},oa.prototype.updatePaintArray=function(t,e,r,n,i){var a=this.zoomInPaintVertexArray,o=this.zoomOutPaintVertexArray,s=this.layerId;if(i&&r.patterns&&r.patterns[s]){var l=r.patterns[s],c=l.min,u=l.mid,h=l.max,f=i[c],p=i[u],d=i[h];if(!f||!p||!d)return;for(var g=t;g<e;g++)a.emplace(g,p.tl[0],p.tl[1],p.br[0],p.br[1],f.tl[0],f.tl[1],f.br[0],f.br[1]),o.emplace(g,p.tl[0],p.tl[1],p.br[0],p.br[1],d.tl[0],d.tl[1],d.br[0],d.br[1])}},oa.prototype.upload=function(t){this.zoomInPaintVertexArray&&this.zoomInPaintVertexArray.arrayBuffer&&this.zoomOutPaintVertexArray&&this.zoomOutPaintVertexArray.arrayBuffer&&(this.zoomInPaintVertexBuffer=t.createVertexBuffer(this.zoomInPaintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent),this.zoomOutPaintVertexBuffer=t.createVertexBuffer(this.zoomOutPaintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},oa.prototype.destroy=function(){this.zoomOutPaintVertexBuffer&&this.zoomOutPaintVertexBuffer.destroy(),this.zoomInPaintVertexBuffer&&this.zoomInPaintVertexBuffer.destroy()},oa.prototype.setUniforms=function(t,e){e.set(0)},oa.prototype.getBinding=function(t,e){return new Xi(t,e)};var sa=function(){this.binders={},this.cacheKey=\"\",this._buffers=[],this._featureMap=new Hi,this._bufferOffset=0};sa.createDynamic=function(t,e,r){var n=new sa,i=[];for(var a in t.paint._values)if(r(a)){var o=t.paint.get(a);if(o instanceof Xn&&xr(o.property.specification)){var s=ca(a,t.type),l=o.property.specification.type,c=o.property.useIntegerZoom;if(\"cross-faded\"===o.property.specification[\"property-type\"]||\"cross-faded-data-driven\"===o.property.specification[\"property-type\"])if(\"constant\"===o.value.kind)n.binders[a]=new na(o.value.value,s,l),i.push(\"/u_\"+a);else{var u=ua(a,l,\"source\");n.binders[a]=new oa(o.value,s,l,c,e,u,t.id),i.push(\"/a_\"+a)}else if(\"constant\"===o.value.kind)n.binders[a]=new ra(o.value.value,s,l),i.push(\"/u_\"+a);else if(\"source\"===o.value.kind){var h=ua(a,l,\"source\");n.binders[a]=new ia(o.value,s,l,h),i.push(\"/a_\"+a)}else{var f=ua(a,l,\"composite\");n.binders[a]=new aa(o.value,s,l,c,e,f),i.push(\"/z_\"+a)}}}return n.cacheKey=i.sort().join(\"\"),n},sa.prototype.populatePaintArrays=function(t,e,r,n){for(var i in this.binders)this.binders[i].populatePaintArray(t,e,n);void 0!==e.id&&this._featureMap.add(+e.id,r,this._bufferOffset,t),this._bufferOffset=t},sa.prototype.setConstantPatternPositions=function(t,e){for(var r in this.binders)this.binders[r].setConstantPatternPositions(t,e)},sa.prototype.updatePaintArrays=function(t,e,r,n){var i=!1;for(var a in t)for(var o=0,s=this._featureMap.getPositions(+a);o<s.length;o+=1){var l=s[o],c=e.feature(l.index);for(var u in this.binders){var h=this.binders[u];if(!(h instanceof ra||h instanceof na)&&!0===h.expression.isStateDependent){var f=r.paint.get(u);h.expression=f.value,h.updatePaintArray(l.start,l.end,c,t[a],n),i=!0}}}return i},sa.prototype.defines=function(){var t=[];for(var e in this.binders)t.push.apply(t,this.binders[e].defines());return t},sa.prototype.getPaintVertexBuffers=function(){return this._buffers},sa.prototype.getUniforms=function(t,e){var r=[];for(var n in this.binders)for(var i=this.binders[n],a=0,o=i.uniformNames;a<o.length;a+=1){var s=o[a];if(e[s]){var l=i.getBinding(t,e[s]);r.push({name:s,property:n,binding:l})}}return r},sa.prototype.setUniforms=function(t,e,r,n){for(var i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.name,l=o.property,c=o.binding;this.binders[l].setUniforms(t,c,n,r.get(l),s)}},sa.prototype.updatePatternPaintBuffers=function(t){var e=[];for(var r in this.binders){var n=this.binders[r];if(n instanceof oa){var i=2===t.fromScale?n.zoomInPaintVertexBuffer:n.zoomOutPaintVertexBuffer;i&&e.push(i)}else(n instanceof ia||n instanceof aa)&&n.paintVertexBuffer&&e.push(n.paintVertexBuffer)}this._buffers=e},sa.prototype.upload=function(t){for(var e in this.binders)this.binders[e].upload(t);var r=[];for(var n in this.binders){var i=this.binders[n];(i instanceof ia||i instanceof aa)&&i.paintVertexBuffer&&r.push(i.paintVertexBuffer)}this._buffers=r},sa.prototype.destroy=function(){for(var t in this.binders)this.binders[t].destroy()};var la=function(t,e,r,n){void 0===n&&(n=function(){return!0}),this.programConfigurations={};for(var i=0,a=e;i<a.length;i+=1){var o=a[i];this.programConfigurations[o.id]=sa.createDynamic(o,r,n),this.programConfigurations[o.id].layoutAttributes=t}this.needsUpload=!1};function ca(t,e){return{\"text-opacity\":[\"opacity\"],\"icon-opacity\":[\"opacity\"],\"text-color\":[\"fill_color\"],\"icon-color\":[\"fill_color\"],\"text-halo-color\":[\"halo_color\"],\"icon-halo-color\":[\"halo_color\"],\"text-halo-blur\":[\"halo_blur\"],\"icon-halo-blur\":[\"halo_blur\"],\"text-halo-width\":[\"halo_width\"],\"icon-halo-width\":[\"halo_width\"],\"line-gap-width\":[\"gapwidth\"],\"line-pattern\":[\"pattern_to\",\"pattern_from\"],\"fill-pattern\":[\"pattern_to\",\"pattern_from\"],\"fill-extrusion-pattern\":[\"pattern_to\",\"pattern_from\"]}[t]||[t.replace(e+\"-\",\"\").replace(/-/g,\"_\")]}function ua(t,e,r){var n={color:{source:Si,composite:Ei},number:{source:_i,composite:Si}},i=function(t){return{\"line-pattern\":{source:fi,composite:fi},\"fill-pattern\":{source:fi,composite:fi},\"fill-extrusion-pattern\":{source:fi,composite:fi}}[t]}(t);return i&&i[r]||n[e][r]}la.prototype.populatePaintArrays=function(t,e,r,n){for(var i in this.programConfigurations)this.programConfigurations[i].populatePaintArrays(t,e,r,n);this.needsUpload=!0},la.prototype.updatePaintArrays=function(t,e,r,n){for(var i=0,a=r;i<a.length;i+=1){var o=a[i];this.needsUpload=this.programConfigurations[o.id].updatePaintArrays(t,e,o,n)||this.needsUpload}},la.prototype.get=function(t){return this.programConfigurations[t]},la.prototype.upload=function(t){if(this.needsUpload){for(var e in this.programConfigurations)this.programConfigurations[e].upload(t);this.needsUpload=!1}},la.prototype.destroy=function(){for(var t in this.programConfigurations)this.programConfigurations[t].destroy()},kn(\"ConstantBinder\",ra),kn(\"CrossFadedConstantBinder\",na),kn(\"SourceExpressionBinder\",ia),kn(\"CrossFadedCompositeBinder\",oa),kn(\"CompositeExpressionBinder\",aa),kn(\"ProgramConfiguration\",sa,{omit:[\"_buffers\"]}),kn(\"ProgramConfigurationSet\",la);var ha=8192,fa=(16,{min:-1*Math.pow(2,15),max:Math.pow(2,15)-1});function pa(t){for(var e=ha/t.extent,r=t.loadGeometry(),n=0;n<r.length;n++)for(var i=r[n],a=0;a<i.length;a++){var o=i[a];o.x=Math.round(o.x*e),o.y=Math.round(o.y*e),(o.x<fa.min||o.x>fa.max||o.y<fa.min||o.y>fa.max)&&w(\"Geometry exceeds allowed extent, reduce your vector tile buffer size\")}return r}function da(t,e,r,n,i){t.emplaceBack(2*e+(n+1)/2,2*r+(i+1)/2)}var ga=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new li,this.indexArray=new Ti,this.segments=new Vi,this.programConfigurations=new la(Ui,t.layers,t.zoom),this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function va(t,e){for(var r=0;r<t.length;r++)if(Aa(e,t[r]))return!0;for(var n=0;n<e.length;n++)if(Aa(t,e[n]))return!0;return!!ba(t,e)}function ma(t,e,r){return!!Aa(t,e)||!!wa(e,t,r)}function ya(t,e){if(1===t.length)return Ta(e,t[0]);for(var r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++)if(Aa(t,n[i]))return!0;for(var a=0;a<t.length;a++)if(Ta(e,t[a]))return!0;for(var o=0;o<e.length;o++)if(ba(t,e[o]))return!0;return!1}function xa(t,e,r){if(t.length>1){if(ba(t,e))return!0;for(var n=0;n<e.length;n++)if(wa(e[n],t,r))return!0}for(var i=0;i<t.length;i++)if(wa(t[i],e,r))return!0;return!1}function ba(t,e){if(0===t.length||0===e.length)return!1;for(var r=0;r<t.length-1;r++)for(var n=t[r],i=t[r+1],a=0;a<e.length-1;a++)if(_a(n,i,e[a],e[a+1]))return!0;return!1}function _a(t,e,r,n){return k(t,r,n)!==k(e,r,n)&&k(t,e,r)!==k(t,e,n)}function wa(t,e,r){var n=r*r;if(1===e.length)return t.distSqr(e[0])<n;for(var i=1;i<e.length;i++)if(ka(t,e[i-1],e[i])<n)return!0;return!1}function ka(t,e,r){var n=e.distSqr(r);if(0===n)return t.distSqr(e);var i=((t.x-e.x)*(r.x-e.x)+(t.y-e.y)*(r.y-e.y))/n;return i<0?t.distSqr(e):i>1?t.distSqr(r):t.distSqr(r.sub(e)._mult(i)._add(e))}function Ta(t,e){for(var r,n,i,a=!1,o=0;o<t.length;o++)for(var s=0,l=(r=t[o]).length-1;s<r.length;l=s++)n=r[s],i=r[l],n.y>e.y!=i.y>e.y&&e.x<(i.x-n.x)*(e.y-n.y)/(i.y-n.y)+n.x&&(a=!a);return a}function Aa(t,e){for(var r=!1,n=0,i=t.length-1;n<t.length;i=n++){var a=t[n],o=t[i];a.y>e.y!=o.y>e.y&&e.x<(o.x-a.x)*(e.y-a.y)/(o.y-a.y)+a.x&&(r=!r)}return r}function Ma(t,e,r){var n=r[0],i=r[2];if(t.x<n.x&&e.x<n.x||t.x>i.x&&e.x>i.x||t.y<n.y&&e.y<n.y||t.y>i.y&&e.y>i.y)return!1;var a=k(t,e,r[0]);return a!==k(t,e,r[1])||a!==k(t,e,r[2])||a!==k(t,e,r[3])}function Sa(t,e,r){var n=e.paint.get(t).value;return\"constant\"===n.kind?n.value:r.programConfigurations.get(e.id).binders[t].maxValue}function Ea(t){return Math.sqrt(t[0]*t[0]+t[1]*t[1])}function Ca(t,e,r,n,a){if(!e[0]&&!e[1])return t;var o=i.convert(e)._mult(a);\"viewport\"===r&&o._rotate(-n);for(var s=[],l=0;l<t.length;l++){var c=t[l];s.push(c.sub(o))}return s}ga.prototype.populate=function(t,e){for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a);this.addFeature(a,l,o),e.featureIndex.insert(a,l,o,s,this.index)}}},ga.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},ga.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},ga.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},ga.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ui),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},ga.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},ga.prototype.addFeature=function(t,e,r){for(var n=0,i=e;n<i.length;n+=1)for(var a=0,o=i[n];a<o.length;a+=1){var s=o[a],l=s.x,c=s.y;if(!(l<0||l>=ha||c<0||c>=ha)){var u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),h=u.vertexLength;da(this.layoutVertexArray,l,c,-1,-1),da(this.layoutVertexArray,l,c,1,-1),da(this.layoutVertexArray,l,c,1,1),da(this.layoutVertexArray,l,c,-1,1),this.indexArray.emplaceBack(h,h+1,h+2),this.indexArray.emplaceBack(h,h+3,h+2),u.vertexLength+=4,u.primitiveLength+=2}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,{})},kn(\"CircleBucket\",ga,{omit:[\"layers\"]});var La={paint:new ei({\"circle-radius\":new Kn(It.paint_circle[\"circle-radius\"]),\"circle-color\":new Kn(It.paint_circle[\"circle-color\"]),\"circle-blur\":new Kn(It.paint_circle[\"circle-blur\"]),\"circle-opacity\":new Kn(It.paint_circle[\"circle-opacity\"]),\"circle-translate\":new Jn(It.paint_circle[\"circle-translate\"]),\"circle-translate-anchor\":new Jn(It.paint_circle[\"circle-translate-anchor\"]),\"circle-pitch-scale\":new Jn(It.paint_circle[\"circle-pitch-scale\"]),\"circle-pitch-alignment\":new Jn(It.paint_circle[\"circle-pitch-alignment\"]),\"circle-stroke-width\":new Kn(It.paint_circle[\"circle-stroke-width\"]),\"circle-stroke-color\":new Kn(It.paint_circle[\"circle-stroke-color\"]),\"circle-stroke-opacity\":new Kn(It.paint_circle[\"circle-stroke-opacity\"])})},Pa=\"undefined\"!=typeof Float32Array?Float32Array:Array;function Oa(){var t=new Pa(9);return Pa!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[5]=0,t[6]=0,t[7]=0),t[0]=1,t[4]=1,t[8]=1,t}function za(){var t=new Pa(3);return Pa!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0),t}function Ia(t,e,r){var n=new Pa(3);return n[0]=t,n[1]=e,n[2]=r,n}Math.PI;function Da(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}function Ra(){var t=new Pa(4);return Pa!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0),t[3]=1,t}za(),function(){var t;t=new Pa(4),Pa!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0,t[3]=0)}();za(),Ia(1,0,0),Ia(0,1,0),Ra(),Ra(),Oa(),function(){var t;t=new Pa(2),Pa!=Float32Array&&(t[0]=0,t[1]=0)}();var Fa=function(t){function e(e){t.call(this,e,La)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new ga(t)},e.prototype.queryRadius=function(t){var e=t;return Sa(\"circle-radius\",this,e)+Sa(\"circle-stroke-width\",this,e)+Ea(this.paint.get(\"circle-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o,s){for(var l=Ca(t,this.paint.get(\"circle-translate\"),this.paint.get(\"circle-translate-anchor\"),a.angle,o),c=this.paint.get(\"circle-radius\").evaluate(e,r)+this.paint.get(\"circle-stroke-width\").evaluate(e,r),u=\"map\"===this.paint.get(\"circle-pitch-alignment\"),h=u?l:function(t,e){return l.map(function(t){return Ba(t,e)})}(0,s),f=u?c*o:c,p=0,d=n;p<d.length;p+=1)for(var g=0,v=d[p];g<v.length;g+=1){var m=v[g],y=u?m:Ba(m,s),x=f,b=Da([],[m.x,m.y,0,1],s);if(\"viewport\"===this.paint.get(\"circle-pitch-scale\")&&\"map\"===this.paint.get(\"circle-pitch-alignment\")?x*=b[3]/a.cameraToCenterDistance:\"map\"===this.paint.get(\"circle-pitch-scale\")&&\"viewport\"===this.paint.get(\"circle-pitch-alignment\")&&(x*=a.cameraToCenterDistance/b[3]),ma(h,y,x))return!0}return!1},e}(ri);function Ba(t,e){var r=Da([],[t.x,t.y,0,1],e);return new i(r[0]/r[3],r[1]/r[3])}var Na=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ga);function ja(t,e,r,n){var i=e.width,a=e.height;if(n){if(n instanceof Uint8ClampedArray)n=new Uint8Array(n.buffer);else if(n.length!==i*a*r)throw new RangeError(\"mismatched image size\")}else n=new Uint8Array(i*a*r);return t.width=i,t.height=a,t.data=n,t}function Ua(t,e,r){var n=e.width,i=e.height;if(n!==t.width||i!==t.height){var a=ja({},{width:n,height:i},r);Va(t,a,{x:0,y:0},{x:0,y:0},{width:Math.min(t.width,n),height:Math.min(t.height,i)},r),t.width=n,t.height=i,t.data=a.data}}function Va(t,e,r,n,i,a){if(0===i.width||0===i.height)return e;if(i.width>t.width||i.height>t.height||r.x>t.width-i.width||r.y>t.height-i.height)throw new RangeError(\"out of range source coordinates for image copy\");if(i.width>e.width||i.height>e.height||n.x>e.width-i.width||n.y>e.height-i.height)throw new RangeError(\"out of range destination coordinates for image copy\");for(var o=t.data,s=e.data,l=0;l<i.height;l++)for(var c=((r.y+l)*t.width+r.x)*a,u=((n.y+l)*e.width+n.x)*a,h=0;h<i.width*a;h++)s[u+h]=o[c+h];return e}kn(\"HeatmapBucket\",Na,{omit:[\"layers\"]});var qa=function(t,e){ja(this,t,1,e)};qa.prototype.resize=function(t){Ua(this,t,1)},qa.prototype.clone=function(){return new qa({width:this.width,height:this.height},new Uint8Array(this.data))},qa.copy=function(t,e,r,n,i){Va(t,e,r,n,i,1)};var Ha=function(t,e){ja(this,t,4,e)};Ha.prototype.resize=function(t){Ua(this,t,4)},Ha.prototype.replace=function(t,e){e?this.data.set(t):t instanceof Uint8ClampedArray?this.data=new Uint8Array(t.buffer):this.data=t},Ha.prototype.clone=function(){return new Ha({width:this.width,height:this.height},new Uint8Array(this.data))},Ha.copy=function(t,e,r,n,i){Va(t,e,r,n,i,4)},kn(\"AlphaImage\",qa),kn(\"RGBAImage\",Ha);var Ga={paint:new ei({\"heatmap-radius\":new Kn(It.paint_heatmap[\"heatmap-radius\"]),\"heatmap-weight\":new Kn(It.paint_heatmap[\"heatmap-weight\"]),\"heatmap-intensity\":new Jn(It.paint_heatmap[\"heatmap-intensity\"]),\"heatmap-color\":new ti(It.paint_heatmap[\"heatmap-color\"]),\"heatmap-opacity\":new Jn(It.paint_heatmap[\"heatmap-opacity\"])})};function Ya(t,e){for(var r=new Uint8Array(1024),n={},i=0,a=0;i<256;i++,a+=4){n[e]=i/255;var o=t.evaluate(n);r[a+0]=Math.floor(255*o.r/o.a),r[a+1]=Math.floor(255*o.g/o.a),r[a+2]=Math.floor(255*o.b/o.a),r[a+3]=Math.floor(255*o.a)}return new Ha({width:256,height:1},r)}var Wa=function(t){function e(e){t.call(this,e,Ga),this._updateColorRamp()}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new Na(t)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"heatmap-color\"===t&&this._updateColorRamp()},e.prototype._updateColorRamp=function(){var t=this._transitionablePaint._values[\"heatmap-color\"].value.expression;this.colorRamp=Ya(t,\"heatmapDensity\"),this.colorRampTexture=null},e.prototype.resize=function(){this.heatmapFbo&&(this.heatmapFbo.destroy(),this.heatmapFbo=null)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"heatmap-opacity\")&&\"none\"!==this.visibility},e}(ri),Xa={paint:new ei({\"hillshade-illumination-direction\":new Jn(It.paint_hillshade[\"hillshade-illumination-direction\"]),\"hillshade-illumination-anchor\":new Jn(It.paint_hillshade[\"hillshade-illumination-anchor\"]),\"hillshade-exaggeration\":new Jn(It.paint_hillshade[\"hillshade-exaggeration\"]),\"hillshade-shadow-color\":new Jn(It.paint_hillshade[\"hillshade-shadow-color\"]),\"hillshade-highlight-color\":new Jn(It.paint_hillshade[\"hillshade-highlight-color\"]),\"hillshade-accent-color\":new Jn(It.paint_hillshade[\"hillshade-accent-color\"])})},Za=function(t){function e(e){t.call(this,e,Xa)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"hillshade-exaggeration\")&&\"none\"!==this.visibility},e}(ri),Ja=oi([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,Ka=Qa,$a=Qa;function Qa(t,e,r){r=r||2;var n,i,a,o,s,l,c,u=e&&e.length,h=u?e[0]*r:t.length,f=to(t,0,h,r,!0),p=[];if(!f||f.next===f.prev)return p;if(u&&(f=function(t,e,r,n){var i,a,o,s=[];for(i=0,a=e.length;i<a;i++)(o=to(t,e[i]*n,i<a-1?e[i+1]*n:t.length,n,!1))===o.next&&(o.steiner=!0),s.push(uo(o));for(s.sort(so),i=0;i<s.length;i++)lo(s[i],r),r=eo(r,r.next);return r}(t,e,f,r)),t.length>80*r){n=a=t[0],i=o=t[1];for(var d=r;d<h;d+=r)(s=t[d])<n&&(n=s),(l=t[d+1])<i&&(i=l),s>a&&(a=s),l>o&&(o=l);c=0!==(c=Math.max(a-n,o-i))?1/c:0}return ro(f,p,r,n,i,c),p}function to(t,e,r,n,i){var a,o;if(i===wo(t,e,r,n)>0)for(a=e;a<r;a+=n)o=xo(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=xo(a,t[a],t[a+1],o);return o&&go(o,o.next)&&(bo(o),o=o.next),o}function eo(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!go(n,n.next)&&0!==po(n.prev,n,n.next))n=n.next;else{if(bo(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function ro(t,e,r,n,i,a,o){if(t){!o&&a&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=co(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,a);for(var s,l,c=t;t.prev!==t.next;)if(s=t.prev,l=t.next,a?io(t,n,i,a):no(t))e.push(s.i/r),e.push(t.i/r),e.push(l.i/r),bo(t),t=l.next,c=l.next;else if((t=l)===c){o?1===o?ro(t=ao(t,e,r),e,r,n,i,a,2):2===o&&oo(t,e,r,n,i,a):ro(eo(t),e,r,n,i,a,1);break}}}function no(t){var e=t.prev,r=t,n=t.next;if(po(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(ho(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&po(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function io(t,e,r,n){var i=t.prev,a=t,o=t.next;if(po(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,h=co(s,l,e,r,n),f=co(c,u,e,r,n),p=t.prevZ,d=t.nextZ;p&&p.z>=h&&d&&d.z<=f;){if(p!==t.prev&&p!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&po(p.prev,p,p.next)>=0)return!1;if(p=p.prevZ,d!==t.prev&&d!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&po(d.prev,d,d.next)>=0)return!1;d=d.nextZ}for(;p&&p.z>=h;){if(p!==t.prev&&p!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&po(p.prev,p,p.next)>=0)return!1;p=p.prevZ}for(;d&&d.z<=f;){if(d!==t.prev&&d!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&po(d.prev,d,d.next)>=0)return!1;d=d.nextZ}return!0}function ao(t,e,r){var n=t;do{var i=n.prev,a=n.next.next;!go(i,a)&&vo(i,n,n.next,a)&&mo(i,a)&&mo(a,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(a.i/r),bo(n),bo(n.next),n=t=a),n=n.next}while(n!==t);return n}function oo(t,e,r,n,i,a){var o=t;do{for(var s=o.next.next;s!==o.prev;){if(o.i!==s.i&&fo(o,s)){var l=yo(o,s);return o=eo(o,o.next),l=eo(l,l.next),ro(o,e,r,n,i,a),void ro(l,e,r,n,i,a)}s=s.next}o=o.next}while(o!==t)}function so(t,e){return t.x-e.x}function lo(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r.prev;var l,c=r,u=r.x,h=r.y,f=1/0;for(n=r.next;n!==c;)i>=n.x&&n.x>=u&&i!==n.x&&ho(a<h?i:o,a,u,h,a<h?o:i,a,n.x,n.y)&&((l=Math.abs(a-n.y)/(i-n.x))<f||l===f&&n.x>r.x)&&mo(n,t)&&(r=n,f=l),n=n.next;return r}(t,e)){var r=yo(e,t);eo(r,r.next)}}function co(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function uo(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function ho(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function fo(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&vo(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&mo(t,e)&&mo(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)}function po(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function go(t,e){return t.x===e.x&&t.y===e.y}function vo(t,e,r,n){return!!(go(t,e)&&go(r,n)||go(t,n)&&go(r,e))||po(t,e,r)>0!=po(t,e,n)>0&&po(r,n,t)>0!=po(r,n,e)>0}function mo(t,e){return po(t.prev,t,t.next)<0?po(t,e,t.next)>=0&&po(t,t.prev,e)>=0:po(t,e,t.prev)<0||po(t,t.next,e)<0}function yo(t,e){var r=new _o(t.i,t.x,t.y),n=new _o(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function xo(t,e,r,n){var i=new _o(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function bo(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function _o(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function wo(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}function ko(t,e,r,n,i){!function t(e,r,n,i,a){for(;i>n;){if(i-n>600){var o=i-n+1,s=r-n+1,l=Math.log(o),c=.5*Math.exp(2*l/3),u=.5*Math.sqrt(l*c*(o-c)/o)*(s-o/2<0?-1:1);t(e,r,Math.max(n,Math.floor(r-s*c/o+u)),Math.min(i,Math.floor(r+(o-s)*c/o+u)),a)}var h=e[r],f=n,p=i;for(To(e,n,r),a(e[i],h)>0&&To(e,n,i);f<p;){for(To(e,f,p),f++,p--;a(e[f],h)<0;)f++;for(;a(e[p],h)>0;)p--}0===a(e[n],h)?To(e,n,p):To(e,++p,i),p<=r&&(n=p+1),r<=p&&(i=p-1)}}(t,e,r||0,n||t.length-1,i||Ao)}function To(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function Ao(t,e){return t<e?-1:t>e?1:0}function Mo(t,e){var r=t.length;if(r<=1)return[t];for(var n,i,a=[],o=0;o<r;o++){var s=T(t[o]);0!==s&&(t[o].area=Math.abs(s),void 0===i&&(i=s<0),i===s<0?(n&&a.push(n),n=[t[o]]):n.push(t[o]))}if(n&&a.push(n),e>1)for(var l=0;l<a.length;l++)a[l].length<=e||(ko(a[l],e,1,a[l].length-1,So),a[l]=a[l].slice(0,e));return a}function So(t,e){return e.area-t.area}function Eo(t,e,r){for(var n=r.patternDependencies,i=!1,a=0,o=e;a<o.length;a+=1){var s=o[a].paint.get(t+\"-pattern\");s.isConstant()||(i=!0);var l=s.constantOr(null);l&&(i=!0,n[l.to]=!0,n[l.from]=!0)}return i}function Co(t,e,r,n,i){for(var a=i.patternDependencies,o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.paint.get(t+\"-pattern\").value;if(\"constant\"!==c.kind){var u=c.evaluate({zoom:n-1},r,{}),h=c.evaluate({zoom:n},r,{}),f=c.evaluate({zoom:n+1},r,{});a[u]=!0,a[h]=!0,a[f]=!0,r.patterns[l.id]={min:u,mid:h,max:f}}}return r}Qa.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(wo(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(wo(t,c,u,r))}var h=0;for(s=0;s<n.length;s+=3){var f=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;h+=Math.abs((t[f]-t[d])*(t[p+1]-t[f+1])-(t[f]-t[p])*(t[d+1]-t[f+1]))}return 0===o&&0===h?0:Math.abs((h-o)/o)},Qa.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r},Ka.default=$a;var Lo=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new li,this.indexArray=new Ti,this.indexArray2=new Ai,this.programConfigurations=new la(Ja,t.layers,t.zoom),this.segments=new Vi,this.segments2=new Vi,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};Lo.prototype.populate=function(t,e){this.features=[],this.hasPattern=Eo(\"fill\",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a),c={sourceLayerIndex:s,index:o,geometry:l,properties:a.properties,type:a.type,patterns:{}};void 0!==a.id&&(c.id=a.id),this.hasPattern?this.features.push(Co(\"fill\",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(a,l,o,s,this.index)}}},Lo.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Lo.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var i=n[r],a=i.geometry;this.addFeature(i,a,i.index,e)}},Lo.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Lo.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Lo.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ja),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.indexBuffer2=t.createIndexBuffer(this.indexArray2)),this.programConfigurations.upload(t),this.uploaded=!0},Lo.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.indexBuffer2.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.segments2.destroy())},Lo.prototype.addFeature=function(t,e,r,n){for(var i=0,a=Mo(e,500);i<a.length;i+=1){for(var o=a[i],s=0,l=0,c=o;l<c.length;l+=1)s+=c[l].length;for(var u=this.segments.prepareSegment(s,this.layoutVertexArray,this.indexArray),h=u.vertexLength,f=[],p=[],d=0,g=o;d<g.length;d+=1){var v=g[d];if(0!==v.length){v!==o[0]&&p.push(f.length/2);var m=this.segments2.prepareSegment(v.length,this.layoutVertexArray,this.indexArray2),y=m.vertexLength;this.layoutVertexArray.emplaceBack(v[0].x,v[0].y),this.indexArray2.emplaceBack(y+v.length-1,y),f.push(v[0].x),f.push(v[0].y);for(var x=1;x<v.length;x++)this.layoutVertexArray.emplaceBack(v[x].x,v[x].y),this.indexArray2.emplaceBack(y+x-1,y+x),f.push(v[x].x),f.push(v[x].y);m.vertexLength+=v.length,m.primitiveLength+=v.length}}for(var b=Ka(f,p),_=0;_<b.length;_+=3)this.indexArray.emplaceBack(h+b[_],h+b[_+1],h+b[_+2]);u.vertexLength+=s,u.primitiveLength+=b.length/3}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,n)},kn(\"FillBucket\",Lo,{omit:[\"layers\",\"features\"]});var Po={paint:new ei({\"fill-antialias\":new Jn(It.paint_fill[\"fill-antialias\"]),\"fill-opacity\":new Kn(It.paint_fill[\"fill-opacity\"]),\"fill-color\":new Kn(It.paint_fill[\"fill-color\"]),\"fill-outline-color\":new Kn(It.paint_fill[\"fill-outline-color\"]),\"fill-translate\":new Jn(It.paint_fill[\"fill-translate\"]),\"fill-translate-anchor\":new Jn(It.paint_fill[\"fill-translate-anchor\"]),\"fill-pattern\":new $n(It.paint_fill[\"fill-pattern\"])})},Oo=function(t){function e(e){t.call(this,e,Po)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e);var r=this.paint._values[\"fill-outline-color\"];\"constant\"===r.value.kind&&void 0===r.value.value&&(this.paint._values[\"fill-outline-color\"]=this.paint._values[\"fill-color\"])},e.prototype.createBucket=function(t){return new Lo(t)},e.prototype.queryRadius=function(){return Ea(this.paint.get(\"fill-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o){return ya(Ca(t,this.paint.get(\"fill-translate\"),this.paint.get(\"fill-translate-anchor\"),a.angle,o),n)},e.prototype.isTileClipped=function(){return!0},e}(ri),zo=oi([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_normal_ed\",components:4,type:\"Int16\"}],4).members,Io=Do;function Do(t,e,r,n,i){this.properties={},this.extent=r,this.type=0,this._pbf=t,this._geometry=-1,this._keys=n,this._values=i,t.readFields(Ro,this,e)}function Ro(t,e,r){1==t?e.id=r.readVarint():2==t?function(t,e){for(var r=t.readVarint()+t.pos;t.pos<r;){var n=e._keys[t.readVarint()],i=e._values[t.readVarint()];e.properties[n]=i}}(r,e):3==t?e.type=r.readVarint():4==t&&(e._geometry=r.pos)}function Fo(t){for(var e,r,n=0,i=0,a=t.length,o=a-1;i<a;o=i++)e=t[i],n+=((r=t[o]).x-e.x)*(e.y+r.y);return n}Do.types=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],Do.prototype.loadGeometry=function(){var t=this._pbf;t.pos=this._geometry;for(var e,r=t.readVarint()+t.pos,n=1,a=0,o=0,s=0,l=[];t.pos<r;){if(a<=0){var c=t.readVarint();n=7&c,a=c>>3}if(a--,1===n||2===n)o+=t.readSVarint(),s+=t.readSVarint(),1===n&&(e&&l.push(e),e=[]),e.push(new i(o,s));else{if(7!==n)throw new Error(\"unknown command \"+n);e&&e.push(e[0].clone())}}return e&&l.push(e),l},Do.prototype.bbox=function(){var t=this._pbf;t.pos=this._geometry;for(var e=t.readVarint()+t.pos,r=1,n=0,i=0,a=0,o=1/0,s=-1/0,l=1/0,c=-1/0;t.pos<e;){if(n<=0){var u=t.readVarint();r=7&u,n=u>>3}if(n--,1===r||2===r)(i+=t.readSVarint())<o&&(o=i),i>s&&(s=i),(a+=t.readSVarint())<l&&(l=a),a>c&&(c=a);else if(7!==r)throw new Error(\"unknown command \"+r)}return[o,l,s,c]},Do.prototype.toGeoJSON=function(t,e,r){var n,i,a=this.extent*Math.pow(2,r),o=this.extent*t,s=this.extent*e,l=this.loadGeometry(),c=Do.types[this.type];function u(t){for(var e=0;e<t.length;e++){var r=t[e],n=180-360*(r.y+s)/a;t[e]=[360*(r.x+o)/a-180,360/Math.PI*Math.atan(Math.exp(n*Math.PI/180))-90]}}switch(this.type){case 1:var h=[];for(n=0;n<l.length;n++)h[n]=l[n][0];u(l=h);break;case 2:for(n=0;n<l.length;n++)u(l[n]);break;case 3:for(l=function(t){var e=t.length;if(e<=1)return[t];for(var r,n,i=[],a=0;a<e;a++){var o=Fo(t[a]);0!==o&&(void 0===n&&(n=o<0),n===o<0?(r&&i.push(r),r=[t[a]]):r.push(t[a]))}return r&&i.push(r),i}(l),n=0;n<l.length;n++)for(i=0;i<l[n].length;i++)u(l[n][i])}1===l.length?l=l[0]:c=\"Multi\"+c;var f={type:\"Feature\",geometry:{type:c,coordinates:l},properties:this.properties};return\"id\"in this&&(f.id=this.id),f};var Bo=No;function No(t,e){this.version=1,this.name=null,this.extent=4096,this.length=0,this._pbf=t,this._keys=[],this._values=[],this._features=[],t.readFields(jo,this,e),this.length=this._features.length}function jo(t,e,r){15===t?e.version=r.readVarint():1===t?e.name=r.readString():5===t?e.extent=r.readVarint():2===t?e._features.push(r.pos):3===t?e._keys.push(r.readString()):4===t&&e._values.push(function(t){for(var e=null,r=t.readVarint()+t.pos;t.pos<r;){var n=t.readVarint()>>3;e=1===n?t.readString():2===n?t.readFloat():3===n?t.readDouble():4===n?t.readVarint64():5===n?t.readVarint():6===n?t.readSVarint():7===n?t.readBoolean():null}return e}(r))}function Uo(t,e,r){if(3===t){var n=new Bo(r,r.readVarint()+r.pos);n.length&&(e[n.name]=n)}}No.prototype.feature=function(t){if(t<0||t>=this._features.length)throw new Error(\"feature index out of bounds\");this._pbf.pos=this._features[t];var e=this._pbf.readVarint()+this._pbf.pos;return new Io(this._pbf,e,this.extent,this._keys,this._values)};var Vo={VectorTile:function(t,e){this.layers=t.readFields(Uo,{},e)},VectorTileFeature:Io,VectorTileLayer:Bo},qo=Vo.VectorTileFeature.types,Ho=Math.pow(2,13);function Go(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,2*Math.floor(n*Ho)+o,i*Ho*2,a*Ho*2,Math.round(s))}var Yo=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new ui,this.indexArray=new Ti,this.programConfigurations=new la(zo,t.layers,t.zoom),this.segments=new Vi,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function Wo(t,e){return t.x===e.x&&(t.x<0||t.x>ha)||t.y===e.y&&(t.y<0||t.y>ha)}function Xo(t){return t.every(function(t){return t.x<0})||t.every(function(t){return t.x>ha})||t.every(function(t){return t.y<0})||t.every(function(t){return t.y>ha})}Yo.prototype.populate=function(t,e){this.features=[],this.hasPattern=Eo(\"fill-extrusion\",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a),c={sourceLayerIndex:s,index:o,geometry:l,properties:a.properties,type:a.type,patterns:{}};void 0!==a.id&&(c.id=a.id),this.hasPattern?this.features.push(Co(\"fill-extrusion\",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(a,l,o,s,this.index,!0)}}},Yo.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var i=n[r],a=i.geometry;this.addFeature(i,a,i.index,e)}},Yo.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Yo.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Yo.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Yo.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,zo),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Yo.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Yo.prototype.addFeature=function(t,e,r,n){for(var i=0,a=Mo(e,500);i<a.length;i+=1){for(var o=a[i],s=0,l=0,c=o;l<c.length;l+=1)s+=c[l].length;for(var u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),h=0,f=o;h<f.length;h+=1){var p=f[h];if(0!==p.length&&!Xo(p))for(var d=0,g=0;g<p.length;g++){var v=p[g];if(g>=1){var m=p[g-1];if(!Wo(v,m)){u.vertexLength+4>Vi.MAX_VERTEX_ARRAY_LENGTH&&(u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray));var y=v.sub(m)._perp()._unit(),x=m.dist(v);d+x>32768&&(d=0),Go(this.layoutVertexArray,v.x,v.y,y.x,y.y,0,0,d),Go(this.layoutVertexArray,v.x,v.y,y.x,y.y,0,1,d),d+=x,Go(this.layoutVertexArray,m.x,m.y,y.x,y.y,0,0,d),Go(this.layoutVertexArray,m.x,m.y,y.x,y.y,0,1,d);var b=u.vertexLength;this.indexArray.emplaceBack(b,b+2,b+1),this.indexArray.emplaceBack(b+1,b+2,b+3),u.vertexLength+=4,u.primitiveLength+=2}}}}if(u.vertexLength+s>Vi.MAX_VERTEX_ARRAY_LENGTH&&(u=this.segments.prepareSegment(s,this.layoutVertexArray,this.indexArray)),\"Polygon\"===qo[t.type]){for(var _=[],w=[],k=u.vertexLength,T=0,A=o;T<A.length;T+=1){var M=A[T];if(0!==M.length){M!==o[0]&&w.push(_.length/2);for(var S=0;S<M.length;S++){var E=M[S];Go(this.layoutVertexArray,E.x,E.y,0,0,1,1,0),_.push(E.x),_.push(E.y)}}}for(var C=Ka(_,w),L=0;L<C.length;L+=3)this.indexArray.emplaceBack(k+C[L],k+C[L+2],k+C[L+1]);u.primitiveLength+=C.length/3,u.vertexLength+=s}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,n)},kn(\"FillExtrusionBucket\",Yo,{omit:[\"layers\",\"features\"]});var Zo={paint:new ei({\"fill-extrusion-opacity\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-opacity\"]),\"fill-extrusion-color\":new Kn(It[\"paint_fill-extrusion\"][\"fill-extrusion-color\"]),\"fill-extrusion-translate\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-translate\"]),\"fill-extrusion-translate-anchor\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-translate-anchor\"]),\"fill-extrusion-pattern\":new $n(It[\"paint_fill-extrusion\"][\"fill-extrusion-pattern\"]),\"fill-extrusion-height\":new Kn(It[\"paint_fill-extrusion\"][\"fill-extrusion-height\"]),\"fill-extrusion-base\":new Kn(It[\"paint_fill-extrusion\"][\"fill-extrusion-base\"]),\"fill-extrusion-vertical-gradient\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-vertical-gradient\"])})},Jo=function(t){function e(e){t.call(this,e,Zo)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new Yo(t)},e.prototype.queryRadius=function(){return Ea(this.paint.get(\"fill-extrusion-translate\"))},e.prototype.is3D=function(){return!0},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s,l){var c=Ca(t,this.paint.get(\"fill-extrusion-translate\"),this.paint.get(\"fill-extrusion-translate-anchor\"),o.angle,s),u=this.paint.get(\"fill-extrusion-height\").evaluate(e,r),h=this.paint.get(\"fill-extrusion-base\").evaluate(e,r),f=function(t,e,r,n){for(var a=[],o=0,s=t;o<s.length;o+=1){var l=s[o],c=[l.x,l.y,0,1];Da(c,c,e),a.push(new i(c[0]/c[3],c[1]/c[3]))}return a}(c,l),p=function(t,e,r,n){for(var a=[],o=[],s=n[8]*e,l=n[9]*e,c=n[10]*e,u=n[11]*e,h=n[8]*r,f=n[9]*r,p=n[10]*r,d=n[11]*r,g=0,v=t;g<v.length;g+=1){for(var m=[],y=[],x=0,b=v[g];x<b.length;x+=1){var _=b[x],w=_.x,k=_.y,T=n[0]*w+n[4]*k+n[12],A=n[1]*w+n[5]*k+n[13],M=n[2]*w+n[6]*k+n[14],S=n[3]*w+n[7]*k+n[15],E=M+c,C=S+u,L=T+h,P=A+f,O=M+p,z=S+d,I=new i((T+s)/C,(A+l)/C);I.z=E/C,m.push(I);var D=new i(L/z,P/z);D.z=O/z,y.push(D)}a.push(m),o.push(y)}return[a,o]}(n,h,u,l);return function(t,e,r){var n=1/0;ya(r,e)&&(n=$o(r,e[0]));for(var i=0;i<e.length;i++)for(var a=e[i],o=t[i],s=0;s<a.length-1;s++){var l=a[s],c=a[s+1],u=o[s],h=[l,c,o[s+1],u,l];va(r,h)&&(n=Math.min(n,$o(r,h)))}return n!==1/0&&n}(p[0],p[1],f)},e}(ri);function Ko(t,e){return t.x*e.x+t.y*e.y}function $o(t,e){if(1===t.length){var r=e[0],n=e[1],i=e[3],a=t[0],o=n.sub(r),s=i.sub(r),l=a.sub(r),c=Ko(o,o),u=Ko(o,s),h=Ko(s,s),f=Ko(l,o),p=Ko(l,s),d=c*h-u*u,g=(h*f-u*p)/d,v=(c*p-u*f)/d,m=1-g-v;return r.z*m+n.z*g+i.z*v}for(var y=1/0,x=0,b=e;x<b.length;x+=1){var _=b[x];y=Math.min(y,_.z)}return y}var Qo=oi([{name:\"a_pos_normal\",components:2,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint8\"}],4).members,ts=Vo.VectorTileFeature.types,es=63,rs=Math.cos(Math.PI/180*37.5),ns=.5,is=Math.pow(2,14)/ns;function as(t,e,r,n,i,a,o){t.emplaceBack((e.x<<1)+(n?1:0),(e.y<<1)+(i?1:0),Math.round(es*r.x)+128,Math.round(es*r.y)+128,1+(0===a?0:a<0?-1:1)|(o*ns&63)<<2,o*ns>>6)}var os=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.features=[],this.hasPattern=!1,this.layoutVertexArray=new hi,this.indexArray=new Ti,this.programConfigurations=new la(Qo,t.layers,t.zoom),this.segments=new Vi,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function ss(t,e){return(t/e.tileTotal*(e.end-e.start)+e.start)*(is-1)}os.prototype.populate=function(t,e){this.features=[],this.hasPattern=Eo(\"line\",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a),c={sourceLayerIndex:s,index:o,geometry:l,properties:a.properties,type:a.type,patterns:{}};void 0!==a.id&&(c.id=a.id),this.hasPattern?this.features.push(Co(\"line\",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(a,l,o,s,this.index)}}},os.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},os.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var i=n[r],a=i.geometry;this.addFeature(i,a,i.index,e)}},os.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},os.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},os.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Qo),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},os.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},os.prototype.addFeature=function(t,e,r,n){for(var i=this.layers[0].layout,a=i.get(\"line-join\").evaluate(t,{}),o=i.get(\"line-cap\"),s=i.get(\"line-miter-limit\"),l=i.get(\"line-round-limit\"),c=0,u=e;c<u.length;c+=1){var h=u[c];this.addLine(h,t,a,o,s,l,r,n)}},os.prototype.addLine=function(t,e,r,n,i,a,o,s){var l=null;e.properties&&e.properties.hasOwnProperty(\"mapbox_clip_start\")&&e.properties.hasOwnProperty(\"mapbox_clip_end\")&&(l={start:e.properties.mapbox_clip_start,end:e.properties.mapbox_clip_end,tileTotal:void 0});for(var c=\"Polygon\"===ts[e.type],u=t.length;u>=2&&t[u-1].equals(t[u-2]);)u--;for(var h=0;h<u-1&&t[h].equals(t[h+1]);)h++;if(!(u<(c?3:2))){l&&(l.tileTotal=function(t,e,r){for(var n,i,a=0,o=h;o<r-1;o++)n=t[o],i=t[o+1],a+=n.dist(i);return a}(t,0,u)),\"bevel\"===r&&(i=1.05);var f=ha/(512*this.overscaling)*15,p=t[h],d=this.segments.prepareSegment(10*u,this.layoutVertexArray,this.indexArray);this.distance=0;var g,v,m,y=n,x=c?\"butt\":n,b=!0,_=void 0,w=void 0,k=void 0,T=void 0;this.e1=this.e2=this.e3=-1,c&&(g=t[u-2],T=p.sub(g)._unit()._perp());for(var A=h;A<u;A++)if(!(w=c&&A===u-1?t[h+1]:t[A+1])||!t[A].equals(w)){T&&(k=T),g&&(_=g),g=t[A],T=w?w.sub(g)._unit()._perp():k;var M=(k=k||T).add(T);0===M.x&&0===M.y||M._unit();var S=M.x*T.x+M.y*T.y,E=0!==S?1/S:1/0,C=S<rs&&_&&w;if(C&&A>h){var L=g.dist(_);if(L>2*f){var P=g.sub(g.sub(_)._mult(f/L)._round());this.distance+=P.dist(_),this.addCurrentVertex(P,this.distance,k.mult(1),0,0,!1,d,l),_=P}}var O=_&&w,z=O?r:w?y:x;if(O&&\"round\"===z&&(E<a?z=\"miter\":E<=2&&(z=\"fakeround\")),\"miter\"===z&&E>i&&(z=\"bevel\"),\"bevel\"===z&&(E>2&&(z=\"flipbevel\"),E<i&&(z=\"miter\")),_&&(this.distance+=g.dist(_)),\"miter\"===z)M._mult(E),this.addCurrentVertex(g,this.distance,M,0,0,!1,d,l);else if(\"flipbevel\"===z){if(E>100)M=T.clone().mult(-1);else{var I=k.x*T.y-k.y*T.x>0?-1:1,D=E*k.add(T).mag()/k.sub(T).mag();M._perp()._mult(D*I)}this.addCurrentVertex(g,this.distance,M,0,0,!1,d,l),this.addCurrentVertex(g,this.distance,M.mult(-1),0,0,!1,d,l)}else if(\"bevel\"===z||\"fakeround\"===z){var R=k.x*T.y-k.y*T.x>0,F=-Math.sqrt(E*E-1);if(R?(m=0,v=F):(v=0,m=F),b||this.addCurrentVertex(g,this.distance,k,v,m,!1,d,l),\"fakeround\"===z){for(var B=Math.floor(8*(.5-(S-.5))),N=void 0,j=0;j<B;j++)N=T.mult((j+1)/(B+1))._add(k)._unit(),this.addPieSliceVertex(g,this.distance,N,R,d,l);this.addPieSliceVertex(g,this.distance,M,R,d,l);for(var U=B-1;U>=0;U--)N=k.mult((U+1)/(B+1))._add(T)._unit(),this.addPieSliceVertex(g,this.distance,N,R,d,l)}w&&this.addCurrentVertex(g,this.distance,T,-v,-m,!1,d,l)}else\"butt\"===z?(b||this.addCurrentVertex(g,this.distance,k,0,0,!1,d,l),w&&this.addCurrentVertex(g,this.distance,T,0,0,!1,d,l)):\"square\"===z?(b||(this.addCurrentVertex(g,this.distance,k,1,1,!1,d,l),this.e1=this.e2=-1),w&&this.addCurrentVertex(g,this.distance,T,-1,-1,!1,d,l)):\"round\"===z&&(b||(this.addCurrentVertex(g,this.distance,k,0,0,!1,d,l),this.addCurrentVertex(g,this.distance,k,1,1,!0,d,l),this.e1=this.e2=-1),w&&(this.addCurrentVertex(g,this.distance,T,-1,-1,!0,d,l),this.addCurrentVertex(g,this.distance,T,0,0,!1,d,l)));if(C&&A<u-1){var V=g.dist(w);if(V>2*f){var q=g.add(w.sub(g)._mult(f/V)._round());this.distance+=q.dist(g),this.addCurrentVertex(q,this.distance,T.mult(1),0,0,!1,d,l),g=q}}b=!1}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,e,o,s)}},os.prototype.addCurrentVertex=function(t,e,r,n,i,a,o,s){var l,c=this.layoutVertexArray,u=this.indexArray;s&&(e=ss(e,s)),l=r.clone(),n&&l._sub(r.perp()._mult(n)),as(c,t,l,a,!1,n,e),this.e3=o.vertexLength++,this.e1>=0&&this.e2>=0&&(u.emplaceBack(this.e1,this.e2,this.e3),o.primitiveLength++),this.e1=this.e2,this.e2=this.e3,l=r.mult(-1),i&&l._sub(r.perp()._mult(i)),as(c,t,l,a,!0,-i,e),this.e3=o.vertexLength++,this.e1>=0&&this.e2>=0&&(u.emplaceBack(this.e1,this.e2,this.e3),o.primitiveLength++),this.e1=this.e2,this.e2=this.e3,e>is/2&&!s&&(this.distance=0,this.addCurrentVertex(t,this.distance,r,n,i,a,o))},os.prototype.addPieSliceVertex=function(t,e,r,n,i,a){r=r.mult(n?-1:1);var o=this.layoutVertexArray,s=this.indexArray;a&&(e=ss(e,a)),as(o,t,r,!1,n,0,e),this.e3=i.vertexLength++,this.e1>=0&&this.e2>=0&&(s.emplaceBack(this.e1,this.e2,this.e3),i.primitiveLength++),n?this.e2=this.e3:this.e1=this.e3},kn(\"LineBucket\",os,{omit:[\"layers\",\"features\"]});var ls=new ei({\"line-cap\":new Jn(It.layout_line[\"line-cap\"]),\"line-join\":new Kn(It.layout_line[\"line-join\"]),\"line-miter-limit\":new Jn(It.layout_line[\"line-miter-limit\"]),\"line-round-limit\":new Jn(It.layout_line[\"line-round-limit\"])}),cs={paint:new ei({\"line-opacity\":new Kn(It.paint_line[\"line-opacity\"]),\"line-color\":new Kn(It.paint_line[\"line-color\"]),\"line-translate\":new Jn(It.paint_line[\"line-translate\"]),\"line-translate-anchor\":new Jn(It.paint_line[\"line-translate-anchor\"]),\"line-width\":new Kn(It.paint_line[\"line-width\"]),\"line-gap-width\":new Kn(It.paint_line[\"line-gap-width\"]),\"line-offset\":new Kn(It.paint_line[\"line-offset\"]),\"line-blur\":new Kn(It.paint_line[\"line-blur\"]),\"line-dasharray\":new Qn(It.paint_line[\"line-dasharray\"]),\"line-pattern\":new $n(It.paint_line[\"line-pattern\"]),\"line-gradient\":new ti(It.paint_line[\"line-gradient\"])}),layout:ls},us=new(function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(e,r){return r=new Un(Math.floor(r.zoom),{now:r.now,fadeDuration:r.fadeDuration,zoomHistory:r.zoomHistory,transition:r.transition}),t.prototype.possiblyEvaluate.call(this,e,r)},e.prototype.evaluate=function(e,r,n,i){return r=h({},r,{zoom:Math.floor(r.zoom)}),t.prototype.evaluate.call(this,e,r,n,i)},e}(Kn))(cs.paint.properties[\"line-width\"].specification);us.useIntegerZoom=!0;var hs=function(t){function e(e){t.call(this,e,cs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"line-gradient\"===t&&this._updateGradient()},e.prototype._updateGradient=function(){var t=this._transitionablePaint._values[\"line-gradient\"].value.expression;this.gradient=Ya(t,\"lineProgress\"),this.gradientTexture=null},e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e),this.paint._values[\"line-floorwidth\"]=us.possiblyEvaluate(this._transitioningPaint._values[\"line-width\"].value,e)},e.prototype.createBucket=function(t){return new os(t)},e.prototype.queryRadius=function(t){var e=t,r=fs(Sa(\"line-width\",this,e),Sa(\"line-gap-width\",this,e)),n=Sa(\"line-offset\",this,e);return r/2+Math.abs(n)+Ea(this.paint.get(\"line-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s){var l=Ca(t,this.paint.get(\"line-translate\"),this.paint.get(\"line-translate-anchor\"),o.angle,s),c=s/2*fs(this.paint.get(\"line-width\").evaluate(e,r),this.paint.get(\"line-gap-width\").evaluate(e,r)),u=this.paint.get(\"line-offset\").evaluate(e,r);return u&&(n=function(t,e){for(var r=[],n=new i(0,0),a=0;a<t.length;a++){for(var o=t[a],s=[],l=0;l<o.length;l++){var c=o[l-1],u=o[l],h=o[l+1],f=0===l?n:u.sub(c)._unit()._perp(),p=l===o.length-1?n:h.sub(u)._unit()._perp(),d=f._add(p)._unit(),g=d.x*p.x+d.y*p.y;d._mult(1/g),s.push(d._mult(e)._add(u))}r.push(s)}return r}(n,u*s)),function(t,e,r){for(var n=0;n<e.length;n++){var i=e[n];if(t.length>=3)for(var a=0;a<i.length;a++)if(Aa(t,i[a]))return!0;if(xa(t,i,r))return!0}return!1}(l,n,c)},e.prototype.isTileClipped=function(){return!0},e}(ri);function fs(t,e){return e>0?e+2*t:t}var ps=oi([{name:\"a_pos_offset\",components:4,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint16\"}]),ds=oi([{name:\"a_projected_pos\",components:3,type:\"Float32\"}],4),gs=(oi([{name:\"a_fade_opacity\",components:1,type:\"Uint32\"}],4),oi([{name:\"a_placed\",components:2,type:\"Uint8\"},{name:\"a_shift\",components:2,type:\"Float32\"}])),vs=(oi([{type:\"Int16\",name:\"anchorPointX\"},{type:\"Int16\",name:\"anchorPointY\"},{type:\"Int16\",name:\"x1\"},{type:\"Int16\",name:\"y1\"},{type:\"Int16\",name:\"x2\"},{type:\"Int16\",name:\"y2\"},{type:\"Uint32\",name:\"featureIndex\"},{type:\"Uint16\",name:\"sourceLayerIndex\"},{type:\"Uint16\",name:\"bucketIndex\"},{type:\"Int16\",name:\"radius\"},{type:\"Int16\",name:\"signedDistanceFromAnchor\"}]),oi([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4)),ms=oi([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4);function ys(t,e,r){return t.sections.forEach(function(t){t.text=function(t,e,r){var n=e.layout.get(\"text-transform\").evaluate(r,{});return\"uppercase\"===n?t=t.toLocaleUpperCase():\"lowercase\"===n&&(t=t.toLocaleLowerCase()),jn.applyArabicShaping&&(t=jn.applyArabicShaping(t)),t}(t.text,e,r)}),t}oi([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Uint16\",name:\"glyphStartIndex\"},{type:\"Uint16\",name:\"numGlyphs\"},{type:\"Uint32\",name:\"vertexStartIndex\"},{type:\"Uint32\",name:\"lineStartIndex\"},{type:\"Uint32\",name:\"lineLength\"},{type:\"Uint16\",name:\"segment\"},{type:\"Uint16\",name:\"lowerSize\"},{type:\"Uint16\",name:\"upperSize\"},{type:\"Float32\",name:\"lineOffsetX\"},{type:\"Float32\",name:\"lineOffsetY\"},{type:\"Uint8\",name:\"writingMode\"},{type:\"Uint8\",name:\"hidden\"},{type:\"Uint32\",name:\"crossTileID\"}]),oi([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Int16\",name:\"rightJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"centerJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"leftJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"verticalPlacedTextSymbolIndex\"},{type:\"Uint16\",name:\"key\"},{type:\"Uint16\",name:\"textBoxStartIndex\"},{type:\"Uint16\",name:\"textBoxEndIndex\"},{type:\"Uint16\",name:\"iconBoxStartIndex\"},{type:\"Uint16\",name:\"iconBoxEndIndex\"},{type:\"Uint16\",name:\"featureIndex\"},{type:\"Uint16\",name:\"numHorizontalGlyphVertices\"},{type:\"Uint16\",name:\"numVerticalGlyphVertices\"},{type:\"Uint16\",name:\"numIconVertices\"},{type:\"Uint32\",name:\"crossTileID\"},{type:\"Float32\",name:\"textBoxScale\"},{type:\"Float32\",name:\"radialTextOffset\"}]),oi([{type:\"Float32\",name:\"offsetX\"}]),oi([{type:\"Int16\",name:\"x\"},{type:\"Int16\",name:\"y\"},{type:\"Int16\",name:\"tileUnitDistanceFromAnchor\"}]);var xs={\"!\":\"\\ufe15\",\"#\":\"\\uff03\",$:\"\\uff04\",\"%\":\"\\uff05\",\"&\":\"\\uff06\",\"(\":\"\\ufe35\",\")\":\"\\ufe36\",\"*\":\"\\uff0a\",\"+\":\"\\uff0b\",\",\":\"\\ufe10\",\"-\":\"\\ufe32\",\".\":\"\\u30fb\",\"/\":\"\\uff0f\",\":\":\"\\ufe13\",\";\":\"\\ufe14\",\"<\":\"\\ufe3f\",\"=\":\"\\uff1d\",\">\":\"\\ufe40\",\"?\":\"\\ufe16\",\"@\":\"\\uff20\",\"[\":\"\\ufe47\",\"\\\\\":\"\\uff3c\",\"]\":\"\\ufe48\",\"^\":\"\\uff3e\",_:\"\\ufe33\",\"`\":\"\\uff40\",\"{\":\"\\ufe37\",\"|\":\"\\u2015\",\"}\":\"\\ufe38\",\"~\":\"\\uff5e\",\"\\xa2\":\"\\uffe0\",\"\\xa3\":\"\\uffe1\",\"\\xa5\":\"\\uffe5\",\"\\xa6\":\"\\uffe4\",\"\\xac\":\"\\uffe2\",\"\\xaf\":\"\\uffe3\",\"\\u2013\":\"\\ufe32\",\"\\u2014\":\"\\ufe31\",\"\\u2018\":\"\\ufe43\",\"\\u2019\":\"\\ufe44\",\"\\u201c\":\"\\ufe41\",\"\\u201d\":\"\\ufe42\",\"\\u2026\":\"\\ufe19\",\"\\u2027\":\"\\u30fb\",\"\\u20a9\":\"\\uffe6\",\"\\u3001\":\"\\ufe11\",\"\\u3002\":\"\\ufe12\",\"\\u3008\":\"\\ufe3f\",\"\\u3009\":\"\\ufe40\",\"\\u300a\":\"\\ufe3d\",\"\\u300b\":\"\\ufe3e\",\"\\u300c\":\"\\ufe41\",\"\\u300d\":\"\\ufe42\",\"\\u300e\":\"\\ufe43\",\"\\u300f\":\"\\ufe44\",\"\\u3010\":\"\\ufe3b\",\"\\u3011\":\"\\ufe3c\",\"\\u3014\":\"\\ufe39\",\"\\u3015\":\"\\ufe3a\",\"\\u3016\":\"\\ufe17\",\"\\u3017\":\"\\ufe18\",\"\\uff01\":\"\\ufe15\",\"\\uff08\":\"\\ufe35\",\"\\uff09\":\"\\ufe36\",\"\\uff0c\":\"\\ufe10\",\"\\uff0d\":\"\\ufe32\",\"\\uff0e\":\"\\u30fb\",\"\\uff1a\":\"\\ufe13\",\"\\uff1b\":\"\\ufe14\",\"\\uff1c\":\"\\ufe3f\",\"\\uff1e\":\"\\ufe40\",\"\\uff1f\":\"\\ufe16\",\"\\uff3b\":\"\\ufe47\",\"\\uff3d\":\"\\ufe48\",\"\\uff3f\":\"\\ufe33\",\"\\uff5b\":\"\\ufe37\",\"\\uff5c\":\"\\u2015\",\"\\uff5d\":\"\\ufe38\",\"\\uff5f\":\"\\ufe35\",\"\\uff60\":\"\\ufe36\",\"\\uff61\":\"\\ufe12\",\"\\uff62\":\"\\ufe41\",\"\\uff63\":\"\\ufe42\"},bs=function(t){function e(e,r,n,i){t.call(this,e,r),this.angle=n,void 0!==i&&(this.segment=i)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.clone=function(){return new e(this.x,this.y,this.angle,this.segment)},e}(i);kn(\"Anchor\",bs);var _s=256;function ws(t,e){var r=e.expression;if(\"constant\"===r.kind)return{kind:\"constant\",layoutSize:r.evaluate(new Un(t+1))};if(\"source\"===r.kind)return{kind:\"source\"};for(var n=r.zoomStops,i=r.interpolationType,a=0;a<n.length&&n[a]<=t;)a++;for(var o=a=Math.max(0,a-1);o<n.length&&n[o]<t+1;)o++;o=Math.min(n.length-1,o);var s=n[a],l=n[o];return\"composite\"===r.kind?{kind:\"composite\",minZoom:s,maxZoom:l,interpolationType:i}:{kind:\"camera\",minZoom:s,maxZoom:l,minSize:r.evaluate(new Un(s)),maxSize:r.evaluate(new Un(l)),interpolationType:i}}function ks(t,e,r){var n=e.uSize,i=e.uSizeT,a=r.lowerSize,o=r.upperSize;return\"source\"===t.kind?a/_s:\"composite\"===t.kind?Ee(a/_s,o/_s,i):n}function Ts(t,e){var r=0,n=0;if(\"constant\"===t.kind)n=t.layoutSize;else if(\"source\"!==t.kind){var i=t.interpolationType,a=t.minZoom,o=t.maxZoom,s=i?c(Xe.interpolationFactor(i,e,a,o),0,1):0;\"camera\"===t.kind?n=Ee(t.minSize,t.maxSize,s):r=s}return{uSizeT:r,uSize:n}}var As=Object.freeze({getSizeData:ws,evaluateSizeForFeature:ks,evaluateSizeForZoom:Ts,SIZE_PACK_FACTOR:_s}),Ms=Vo.VectorTileFeature.types,Ss=[{name:\"a_fade_opacity\",components:1,type:\"Uint8\",offset:0}];function Es(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,Math.round(32*n),Math.round(32*i),a,o,s?s[0]:0,s?s[1]:0)}function Cs(t,e,r){t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r)}var Ls=function(t){this.layoutVertexArray=new pi,this.indexArray=new Ti,this.programConfigurations=t,this.segments=new Vi,this.dynamicLayoutVertexArray=new di,this.opacityVertexArray=new gi,this.placedSymbolArray=new Oi};Ls.prototype.upload=function(t,e,r,n){r&&(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,ps.members),this.indexBuffer=t.createIndexBuffer(this.indexArray,e),this.dynamicLayoutVertexBuffer=t.createVertexBuffer(this.dynamicLayoutVertexArray,ds.members,!0),this.opacityVertexBuffer=t.createVertexBuffer(this.opacityVertexArray,Ss,!0),this.opacityVertexBuffer.itemSize=1),(r||n)&&this.programConfigurations.upload(t)},Ls.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.dynamicLayoutVertexBuffer.destroy(),this.opacityVertexBuffer.destroy())},kn(\"SymbolBuffers\",Ls);var Ps=function(t,e,r){this.layoutVertexArray=new t,this.layoutAttributes=e,this.indexArray=new r,this.segments=new Vi,this.collisionVertexArray=new yi};Ps.prototype.upload=function(t){this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,this.layoutAttributes),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.collisionVertexBuffer=t.createVertexBuffer(this.collisionVertexArray,gs.members,!0)},Ps.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.segments.destroy(),this.collisionVertexBuffer.destroy())},kn(\"CollisionBuffers\",Ps);var Os=function(t){this.collisionBoxArray=t.collisionBoxArray,this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.pixelRatio=t.pixelRatio,this.sourceLayerIndex=t.sourceLayerIndex,this.hasPattern=!1;var e=this.layers[0]._unevaluatedLayout._values;this.textSizeData=ws(this.zoom,e[\"text-size\"]),this.iconSizeData=ws(this.zoom,e[\"icon-size\"]);var r=this.layers[0].layout,n=r.get(\"symbol-sort-key\"),i=r.get(\"symbol-z-order\");this.sortFeaturesByKey=\"viewport-y\"!==i&&void 0!==n.constantOr(1);var a=\"viewport-y\"===i||\"auto\"===i&&!this.sortFeaturesByKey;this.sortFeaturesByY=a&&(r.get(\"text-allow-overlap\")||r.get(\"icon-allow-overlap\")||r.get(\"text-ignore-placement\")||r.get(\"icon-ignore-placement\")),this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id}),this.sourceID=t.sourceID};Os.prototype.createArrays=function(){this.text=new Ls(new la(ps.members,this.layers,this.zoom,function(t){return/^text/.test(t)})),this.icon=new Ls(new la(ps.members,this.layers,this.zoom,function(t){return/^icon/.test(t)})),this.collisionBox=new Ps(mi,vs.members,Ai),this.collisionCircle=new Ps(mi,ms.members,Ti),this.glyphOffsetArray=new Ri,this.lineVertexArray=new Bi,this.symbolInstances=new Ii},Os.prototype.calculateGlyphDependencies=function(t,e,r,n){for(var i=0;i<t.length;i++)if(e[t.charCodeAt(i)]=!0,r&&n){var a=xs[t.charAt(i)];a&&(e[a.charCodeAt(0)]=!0)}},Os.prototype.populate=function(t,e){var r=this.layers[0],n=r.layout,i=n.get(\"text-font\"),a=n.get(\"text-field\"),o=n.get(\"icon-image\"),s=(\"constant\"!==a.value.kind||a.value.value.toString().length>0)&&(\"constant\"!==i.value.kind||i.value.value.length>0),l=\"constant\"!==o.value.kind||o.value.value&&o.value.value.length>0,c=n.get(\"symbol-sort-key\");if(this.features=[],s||l){for(var u=e.iconDependencies,h=e.glyphDependencies,f=new Un(this.zoom),p=0,d=t;p<d.length;p+=1){var g=d[p],v=g.feature,m=g.index,y=g.sourceLayerIndex;if(r._featureFilter(f,v)){var x=void 0;if(s){var b=r.getValueAndResolveTokens(\"text-field\",v);x=ys(b instanceof oe?b:oe.fromString(b),r,v)}var _=void 0;if(l&&(_=r.getValueAndResolveTokens(\"icon-image\",v)),x||_){var w=this.sortFeaturesByKey?c.evaluate(v,{}):void 0,k={text:x,icon:_,index:m,sourceLayerIndex:y,geometry:pa(v),properties:v.properties,type:Ms[v.type],sortKey:w};if(void 0!==v.id&&(k.id=v.id),this.features.push(k),_&&(u[_]=!0),x)for(var T=i.evaluate(v,{}).join(\",\"),A=\"map\"===n.get(\"text-rotation-alignment\")&&\"point\"!==n.get(\"symbol-placement\"),M=0,S=x.sections;M<S.length;M+=1){var E=S[M],C=Cn(x.toString()),L=E.fontStack||T,P=h[L]=h[L]||{};this.calculateGlyphDependencies(E.text,P,A,C)}}}}\"line\"===n.get(\"symbol-placement\")&&(this.features=function(t){var e={},r={},n=[],i=0;function a(e){n.push(t[e]),i++}function o(t,e,i){var a=r[t];return delete r[t],r[e]=a,n[a].geometry[0].pop(),n[a].geometry[0]=n[a].geometry[0].concat(i[0]),a}function s(t,r,i){var a=e[r];return delete e[r],e[t]=a,n[a].geometry[0].shift(),n[a].geometry[0]=i[0].concat(n[a].geometry[0]),a}function l(t,e,r){var n=r?e[0][e[0].length-1]:e[0][0];return t+\":\"+n.x+\":\"+n.y}for(var c=0;c<t.length;c++){var u=t[c],h=u.geometry,f=u.text?u.text.toString():null;if(f){var p=l(f,h),d=l(f,h,!0);if(p in r&&d in e&&r[p]!==e[d]){var g=s(p,d,h),v=o(p,d,n[g].geometry);delete e[p],delete r[d],r[l(f,n[v].geometry,!0)]=v,n[g].geometry=null}else p in r?o(p,d,h):d in e?s(p,d,h):(a(c),e[p]=i-1,r[d]=i-1)}else a(c)}return n.filter(function(t){return t.geometry})}(this.features)),this.sortFeaturesByKey&&this.features.sort(function(t,e){return t.sortKey-e.sortKey})}},Os.prototype.update=function(t,e,r){this.stateDependentLayers.length&&(this.text.programConfigurations.updatePaintArrays(t,e,this.layers,r),this.icon.programConfigurations.updatePaintArrays(t,e,this.layers,r))},Os.prototype.isEmpty=function(){return 0===this.symbolInstances.length},Os.prototype.uploadPending=function(){return!this.uploaded||this.text.programConfigurations.needsUpload||this.icon.programConfigurations.needsUpload},Os.prototype.upload=function(t){this.uploaded||(this.collisionBox.upload(t),this.collisionCircle.upload(t)),this.text.upload(t,this.sortFeaturesByY,!this.uploaded,this.text.programConfigurations.needsUpload),this.icon.upload(t,this.sortFeaturesByY,!this.uploaded,this.icon.programConfigurations.needsUpload),this.uploaded=!0},Os.prototype.destroy=function(){this.text.destroy(),this.icon.destroy(),this.collisionBox.destroy(),this.collisionCircle.destroy()},Os.prototype.addToLineVertexArray=function(t,e){var r=this.lineVertexArray.length;if(void 0!==t.segment){for(var n=t.dist(e[t.segment+1]),i=t.dist(e[t.segment]),a={},o=t.segment+1;o<e.length;o++)a[o]={x:e[o].x,y:e[o].y,tileUnitDistanceFromAnchor:n},o<e.length-1&&(n+=e[o+1].dist(e[o]));for(var s=t.segment||0;s>=0;s--)a[s]={x:e[s].x,y:e[s].y,tileUnitDistanceFromAnchor:i},s>0&&(i+=e[s-1].dist(e[s]));for(var l=0;l<e.length;l++){var c=a[l];this.lineVertexArray.emplaceBack(c.x,c.y,c.tileUnitDistanceFromAnchor)}}return{lineStartIndex:r,lineLength:this.lineVertexArray.length-r}},Os.prototype.addSymbols=function(t,e,r,n,i,a,o,s,l,c){for(var u=t.indexArray,h=t.layoutVertexArray,f=t.dynamicLayoutVertexArray,p=t.segments.prepareSegment(4*e.length,t.layoutVertexArray,t.indexArray,a.sortKey),d=this.glyphOffsetArray.length,g=p.vertexLength,v=0,m=e;v<m.length;v+=1){var y=m[v],x=y.tl,b=y.tr,_=y.bl,w=y.br,k=y.tex,T=p.vertexLength,A=y.glyphOffset[1];Es(h,s.x,s.y,x.x,A+x.y,k.x,k.y,r),Es(h,s.x,s.y,b.x,A+b.y,k.x+k.w,k.y,r),Es(h,s.x,s.y,_.x,A+_.y,k.x,k.y+k.h,r),Es(h,s.x,s.y,w.x,A+w.y,k.x+k.w,k.y+k.h,r),Cs(f,s,0),u.emplaceBack(T,T+1,T+2),u.emplaceBack(T+1,T+2,T+3),p.vertexLength+=4,p.primitiveLength+=2,this.glyphOffsetArray.emplaceBack(y.glyphOffset[0])}t.placedSymbolArray.emplaceBack(s.x,s.y,d,this.glyphOffsetArray.length-d,g,l,c,s.segment,r?r[0]:0,r?r[1]:0,n[0],n[1],o,!1,0),t.programConfigurations.populatePaintArrays(t.layoutVertexArray.length,a,a.index,{})},Os.prototype._addCollisionDebugVertex=function(t,e,r,n,i,a){return e.emplaceBack(0,0),t.emplaceBack(r.x,r.y,n,i,Math.round(a.x),Math.round(a.y))},Os.prototype.addCollisionDebugVertices=function(t,e,r,n,a,o,s,l){var c=a.segments.prepareSegment(4,a.layoutVertexArray,a.indexArray),u=c.vertexLength,h=a.layoutVertexArray,f=a.collisionVertexArray,p=s.anchorX,d=s.anchorY;if(this._addCollisionDebugVertex(h,f,o,p,d,new i(t,e)),this._addCollisionDebugVertex(h,f,o,p,d,new i(r,e)),this._addCollisionDebugVertex(h,f,o,p,d,new i(r,n)),this._addCollisionDebugVertex(h,f,o,p,d,new i(t,n)),c.vertexLength+=4,l){var g=a.indexArray;g.emplaceBack(u,u+1,u+2),g.emplaceBack(u,u+2,u+3),c.primitiveLength+=2}else{var v=a.indexArray;v.emplaceBack(u,u+1),v.emplaceBack(u+1,u+2),v.emplaceBack(u+2,u+3),v.emplaceBack(u+3,u),c.primitiveLength+=4}},Os.prototype.addDebugCollisionBoxes=function(t,e,r){for(var n=t;n<e;n++){var i=this.collisionBoxArray.get(n),a=i.x1,o=i.y1,s=i.x2,l=i.y2,c=i.radius>0;this.addCollisionDebugVertices(a,o,s,l,c?this.collisionCircle:this.collisionBox,i.anchorPoint,r,c)}},Os.prototype.generateCollisionDebugBuffers=function(){for(var t=0;t<this.symbolInstances.length;t++){var e=this.symbolInstances.get(t);this.addDebugCollisionBoxes(e.textBoxStartIndex,e.textBoxEndIndex,e),this.addDebugCollisionBoxes(e.iconBoxStartIndex,e.iconBoxEndIndex,e)}},Os.prototype._deserializeCollisionBoxesForSymbol=function(t,e,r,n,i){for(var a={},o=e;o<r;o++){var s=t.get(o);if(0===s.radius){a.textBox={x1:s.x1,y1:s.y1,x2:s.x2,y2:s.y2,anchorPointX:s.anchorPointX,anchorPointY:s.anchorPointY},a.textFeatureIndex=s.featureIndex;break}a.textCircles||(a.textCircles=[],a.textFeatureIndex=s.featureIndex),a.textCircles.push(s.anchorPointX,s.anchorPointY,s.radius,s.signedDistanceFromAnchor,1)}for(var l=n;l<i;l++){var c=t.get(l);if(0===c.radius){a.iconBox={x1:c.x1,y1:c.y1,x2:c.x2,y2:c.y2,anchorPointX:c.anchorPointX,anchorPointY:c.anchorPointY},a.iconFeatureIndex=c.featureIndex;break}}return a},Os.prototype.deserializeCollisionBoxes=function(t){this.collisionArrays=[];for(var e=0;e<this.symbolInstances.length;e++){var r=this.symbolInstances.get(e);this.collisionArrays.push(this._deserializeCollisionBoxesForSymbol(t,r.textBoxStartIndex,r.textBoxEndIndex,r.iconBoxStartIndex,r.iconBoxEndIndex))}},Os.prototype.hasTextData=function(){return this.text.segments.get().length>0},Os.prototype.hasIconData=function(){return this.icon.segments.get().length>0},Os.prototype.hasCollisionBoxData=function(){return this.collisionBox.segments.get().length>0},Os.prototype.hasCollisionCircleData=function(){return this.collisionCircle.segments.get().length>0},Os.prototype.addIndicesForPlacedTextSymbol=function(t){for(var e=this.text.placedSymbolArray.get(t),r=e.vertexStartIndex+4*e.numGlyphs,n=e.vertexStartIndex;n<r;n+=4)this.text.indexArray.emplaceBack(n,n+1,n+2),this.text.indexArray.emplaceBack(n+1,n+2,n+3)},Os.prototype.getSortedSymbolIndexes=function(t){if(this.sortedAngle===t&&void 0!==this.symbolInstanceIndexes)return this.symbolInstanceIndexes;for(var e=Math.sin(t),r=Math.cos(t),n=[],i=[],a=[],o=0;o<this.symbolInstances.length;++o){a.push(o);var s=this.symbolInstances.get(o);n.push(0|Math.round(e*s.anchorX+r*s.anchorY)),i.push(s.featureIndex)}return a.sort(function(t,e){return n[t]-n[e]||i[e]-i[t]}),a},Os.prototype.sortFeatures=function(t){var e=this;if(this.sortFeaturesByY&&this.sortedAngle!==t&&!(this.text.segments.get().length>1||this.icon.segments.get().length>1)){this.symbolInstanceIndexes=this.getSortedSymbolIndexes(t),this.sortedAngle=t,this.text.indexArray.clear(),this.icon.indexArray.clear(),this.featureSortOrder=[];for(var r=0,n=this.symbolInstanceIndexes;r<n.length;r+=1){var i=n[r],a=this.symbolInstances.get(i);this.featureSortOrder.push(a.featureIndex),[a.rightJustifiedTextSymbolIndex,a.centerJustifiedTextSymbolIndex,a.leftJustifiedTextSymbolIndex].forEach(function(t,r,n){t>=0&&n.indexOf(t)===r&&e.addIndicesForPlacedTextSymbol(t)}),a.verticalPlacedTextSymbolIndex>=0&&this.addIndicesForPlacedTextSymbol(a.verticalPlacedTextSymbolIndex);var o=this.icon.placedSymbolArray.get(i);if(o.numGlyphs){var s=o.vertexStartIndex;this.icon.indexArray.emplaceBack(s,s+1,s+2),this.icon.indexArray.emplaceBack(s+1,s+2,s+3)}}this.text.indexBuffer&&this.text.indexBuffer.updateData(this.text.indexArray),this.icon.indexBuffer&&this.icon.indexBuffer.updateData(this.icon.indexArray)}},kn(\"SymbolBucket\",Os,{omit:[\"layers\",\"collisionBoxArray\",\"features\",\"compareText\"]}),Os.MAX_GLYPHS=65535,Os.addDynamicAttributes=Cs;var zs=new ei({\"symbol-placement\":new Jn(It.layout_symbol[\"symbol-placement\"]),\"symbol-spacing\":new Jn(It.layout_symbol[\"symbol-spacing\"]),\"symbol-avoid-edges\":new Jn(It.layout_symbol[\"symbol-avoid-edges\"]),\"symbol-sort-key\":new Kn(It.layout_symbol[\"symbol-sort-key\"]),\"symbol-z-order\":new Jn(It.layout_symbol[\"symbol-z-order\"]),\"icon-allow-overlap\":new Jn(It.layout_symbol[\"icon-allow-overlap\"]),\"icon-ignore-placement\":new Jn(It.layout_symbol[\"icon-ignore-placement\"]),\"icon-optional\":new Jn(It.layout_symbol[\"icon-optional\"]),\"icon-rotation-alignment\":new Jn(It.layout_symbol[\"icon-rotation-alignment\"]),\"icon-size\":new Kn(It.layout_symbol[\"icon-size\"]),\"icon-text-fit\":new Jn(It.layout_symbol[\"icon-text-fit\"]),\"icon-text-fit-padding\":new Jn(It.layout_symbol[\"icon-text-fit-padding\"]),\"icon-image\":new Kn(It.layout_symbol[\"icon-image\"]),\"icon-rotate\":new Kn(It.layout_symbol[\"icon-rotate\"]),\"icon-padding\":new Jn(It.layout_symbol[\"icon-padding\"]),\"icon-keep-upright\":new Jn(It.layout_symbol[\"icon-keep-upright\"]),\"icon-offset\":new Kn(It.layout_symbol[\"icon-offset\"]),\"icon-anchor\":new Kn(It.layout_symbol[\"icon-anchor\"]),\"icon-pitch-alignment\":new Jn(It.layout_symbol[\"icon-pitch-alignment\"]),\"text-pitch-alignment\":new Jn(It.layout_symbol[\"text-pitch-alignment\"]),\"text-rotation-alignment\":new Jn(It.layout_symbol[\"text-rotation-alignment\"]),\"text-field\":new Kn(It.layout_symbol[\"text-field\"]),\"text-font\":new Kn(It.layout_symbol[\"text-font\"]),\"text-size\":new Kn(It.layout_symbol[\"text-size\"]),\"text-max-width\":new Kn(It.layout_symbol[\"text-max-width\"]),\"text-line-height\":new Jn(It.layout_symbol[\"text-line-height\"]),\"text-letter-spacing\":new Kn(It.layout_symbol[\"text-letter-spacing\"]),\"text-justify\":new Kn(It.layout_symbol[\"text-justify\"]),\"text-radial-offset\":new Kn(It.layout_symbol[\"text-radial-offset\"]),\"text-variable-anchor\":new Jn(It.layout_symbol[\"text-variable-anchor\"]),\"text-anchor\":new Kn(It.layout_symbol[\"text-anchor\"]),\"text-max-angle\":new Jn(It.layout_symbol[\"text-max-angle\"]),\"text-rotate\":new Kn(It.layout_symbol[\"text-rotate\"]),\"text-padding\":new Jn(It.layout_symbol[\"text-padding\"]),\"text-keep-upright\":new Jn(It.layout_symbol[\"text-keep-upright\"]),\"text-transform\":new Kn(It.layout_symbol[\"text-transform\"]),\"text-offset\":new Kn(It.layout_symbol[\"text-offset\"]),\"text-allow-overlap\":new Jn(It.layout_symbol[\"text-allow-overlap\"]),\"text-ignore-placement\":new Jn(It.layout_symbol[\"text-ignore-placement\"]),\"text-optional\":new Jn(It.layout_symbol[\"text-optional\"])}),Is={paint:new ei({\"icon-opacity\":new Kn(It.paint_symbol[\"icon-opacity\"]),\"icon-color\":new Kn(It.paint_symbol[\"icon-color\"]),\"icon-halo-color\":new Kn(It.paint_symbol[\"icon-halo-color\"]),\"icon-halo-width\":new Kn(It.paint_symbol[\"icon-halo-width\"]),\"icon-halo-blur\":new Kn(It.paint_symbol[\"icon-halo-blur\"]),\"icon-translate\":new Jn(It.paint_symbol[\"icon-translate\"]),\"icon-translate-anchor\":new Jn(It.paint_symbol[\"icon-translate-anchor\"]),\"text-opacity\":new Kn(It.paint_symbol[\"text-opacity\"]),\"text-color\":new Kn(It.paint_symbol[\"text-color\"]),\"text-halo-color\":new Kn(It.paint_symbol[\"text-halo-color\"]),\"text-halo-width\":new Kn(It.paint_symbol[\"text-halo-width\"]),\"text-halo-blur\":new Kn(It.paint_symbol[\"text-halo-blur\"]),\"text-translate\":new Jn(It.paint_symbol[\"text-translate\"]),\"text-translate-anchor\":new Jn(It.paint_symbol[\"text-translate-anchor\"])}),layout:zs},Ds=function(t){function e(e){t.call(this,e,Is)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e),\"auto\"===this.layout.get(\"icon-rotation-alignment\")&&(\"point\"!==this.layout.get(\"symbol-placement\")?this.layout._values[\"icon-rotation-alignment\"]=\"map\":this.layout._values[\"icon-rotation-alignment\"]=\"viewport\"),\"auto\"===this.layout.get(\"text-rotation-alignment\")&&(\"point\"!==this.layout.get(\"symbol-placement\")?this.layout._values[\"text-rotation-alignment\"]=\"map\":this.layout._values[\"text-rotation-alignment\"]=\"viewport\"),\"auto\"===this.layout.get(\"text-pitch-alignment\")&&(this.layout._values[\"text-pitch-alignment\"]=this.layout.get(\"text-rotation-alignment\")),\"auto\"===this.layout.get(\"icon-pitch-alignment\")&&(this.layout._values[\"icon-pitch-alignment\"]=this.layout.get(\"icon-rotation-alignment\"))},e.prototype.getValueAndResolveTokens=function(t,e){var r,n=this.layout.get(t).evaluate(e,{}),i=this._unevaluatedLayout._values[t];return i.isDataDriven()||Pr(i.value)?n:(r=e.properties,n.replace(/{([^{}]+)}/g,function(t,e){return e in r?String(r[e]):\"\"}))},e.prototype.createBucket=function(t){return new Os(t)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e}(ri),Rs={paint:new ei({\"background-color\":new Jn(It.paint_background[\"background-color\"]),\"background-pattern\":new Qn(It.paint_background[\"background-pattern\"]),\"background-opacity\":new Jn(It.paint_background[\"background-opacity\"])})},Fs=function(t){function e(e){t.call(this,e,Rs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ri),Bs={paint:new ei({\"raster-opacity\":new Jn(It.paint_raster[\"raster-opacity\"]),\"raster-hue-rotate\":new Jn(It.paint_raster[\"raster-hue-rotate\"]),\"raster-brightness-min\":new Jn(It.paint_raster[\"raster-brightness-min\"]),\"raster-brightness-max\":new Jn(It.paint_raster[\"raster-brightness-max\"]),\"raster-saturation\":new Jn(It.paint_raster[\"raster-saturation\"]),\"raster-contrast\":new Jn(It.paint_raster[\"raster-contrast\"]),\"raster-resampling\":new Jn(It.paint_raster[\"raster-resampling\"]),\"raster-fade-duration\":new Jn(It.paint_raster[\"raster-fade-duration\"])})},Ns=function(t){function e(e){t.call(this,e,Bs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ri),js=function(t){function e(e){t.call(this,e,{}),this.implementation=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.is3D=function(){return\"3d\"===this.implementation.renderingMode},e.prototype.hasOffscreenPass=function(){return void 0!==this.implementation.prerender},e.prototype.recalculate=function(){},e.prototype.updateTransitions=function(){},e.prototype.hasTransition=function(){},e.prototype.serialize=function(){},e.prototype.onAdd=function(t){this.implementation.onAdd&&this.implementation.onAdd(t,t.painter.context.gl)},e.prototype.onRemove=function(t){this.implementation.onRemove&&this.implementation.onRemove(t,t.painter.context.gl)},e}(ri),Us={circle:Fa,heatmap:Wa,hillshade:Za,fill:Oo,\"fill-extrusion\":Jo,line:hs,symbol:Ds,background:Fs,raster:Ns};function Vs(t){for(var e=0,r=0,n=0,i=t;n<i.length;n+=1){var a=i[n];e+=a.w*a.h,r=Math.max(r,a.w)}t.sort(function(t,e){return e.h-t.h});for(var o=[{x:0,y:0,w:Math.max(Math.ceil(Math.sqrt(e/.95)),r),h:1/0}],s=0,l=0,c=0,u=t;c<u.length;c+=1)for(var h=u[c],f=o.length-1;f>=0;f--){var p=o[f];if(!(h.w>p.w||h.h>p.h)){if(h.x=p.x,h.y=p.y,l=Math.max(l,h.y+h.h),s=Math.max(s,h.x+h.w),h.w===p.w&&h.h===p.h){var d=o.pop();f<o.length&&(o[f]=d)}else h.h===p.h?(p.x+=h.w,p.w-=h.w):h.w===p.w?(p.y+=h.h,p.h-=h.h):(o.push({x:p.x+h.w,y:p.y,w:p.w-h.w,h:h.h}),p.y+=h.h,p.h-=h.h);break}}return{w:s,h:l,fill:e/(s*l)||0}}var qs=function(t,e){var r=e.pixelRatio,n=e.version;this.paddedRect=t,this.pixelRatio=r,this.version=n},Hs={tl:{configurable:!0},br:{configurable:!0},tlbr:{configurable:!0},displaySize:{configurable:!0}};Hs.tl.get=function(){return[this.paddedRect.x+1,this.paddedRect.y+1]},Hs.br.get=function(){return[this.paddedRect.x+this.paddedRect.w-1,this.paddedRect.y+this.paddedRect.h-1]},Hs.tlbr.get=function(){return this.tl.concat(this.br)},Hs.displaySize.get=function(){return[(this.paddedRect.w-2)/this.pixelRatio,(this.paddedRect.h-2)/this.pixelRatio]},Object.defineProperties(qs.prototype,Hs);var Gs=function(t,e){var r={},n={};this.haveRenderCallbacks=[];var i=[];this.addImages(t,r,i),this.addImages(e,n,i);var a=Vs(i),o=a.w,s=a.h,l=new Ha({width:o||1,height:s||1});for(var c in t){var u=t[c],h=r[c].paddedRect;Ha.copy(u.data,l,{x:0,y:0},{x:h.x+1,y:h.y+1},u.data)}for(var f in e){var p=e[f],d=n[f].paddedRect,g=d.x+1,v=d.y+1,m=p.data.width,y=p.data.height;Ha.copy(p.data,l,{x:0,y:0},{x:g,y:v},p.data),Ha.copy(p.data,l,{x:0,y:y-1},{x:g,y:v-1},{width:m,height:1}),Ha.copy(p.data,l,{x:0,y:0},{x:g,y:v+y},{width:m,height:1}),Ha.copy(p.data,l,{x:m-1,y:0},{x:g-1,y:v},{width:1,height:y}),Ha.copy(p.data,l,{x:0,y:0},{x:g+m,y:v},{width:1,height:y})}this.image=l,this.iconPositions=r,this.patternPositions=n};Gs.prototype.addImages=function(t,e,r){for(var n in t){var i=t[n],a={x:0,y:0,w:i.data.width+2,h:i.data.height+2};r.push(a),e[n]=new qs(a,i),i.hasRenderCallback&&this.haveRenderCallbacks.push(n)}},Gs.prototype.patchUpdatedImages=function(t,e){for(var r in t.dispatchRenderCallbacks(this.haveRenderCallbacks),t.updatedImages)this.patchUpdatedImage(this.iconPositions[r],t.getImage(r),e),this.patchUpdatedImage(this.patternPositions[r],t.getImage(r),e)},Gs.prototype.patchUpdatedImage=function(t,e,r){if(t&&e&&t.version!==e.version){t.version=e.version;var n=t.tl,i=n[0],a=n[1];r.update(e.data,void 0,{x:i,y:a})}},kn(\"ImagePosition\",qs),kn(\"ImageAtlas\",Gs);var Ys=self.HTMLImageElement,Ws=self.HTMLCanvasElement,Xs=self.HTMLVideoElement,Zs=self.ImageData,Js=function(t,e,r,n){this.context=t,this.format=r,this.texture=t.gl.createTexture(),this.update(e,n)};Js.prototype.update=function(t,e,r){var n=t.width,i=t.height,a=!(this.size&&this.size[0]===n&&this.size[1]===i||r),o=this.context,s=o.gl;if(this.useMipmap=Boolean(e&&e.useMipmap),s.bindTexture(s.TEXTURE_2D,this.texture),o.pixelStoreUnpackFlipY.set(!1),o.pixelStoreUnpack.set(1),o.pixelStoreUnpackPremultiplyAlpha.set(this.format===s.RGBA&&(!e||!1!==e.premultiply)),a)this.size=[n,i],t instanceof Ys||t instanceof Ws||t instanceof Xs||t instanceof Zs?s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,s.UNSIGNED_BYTE,t):s.texImage2D(s.TEXTURE_2D,0,this.format,n,i,0,this.format,s.UNSIGNED_BYTE,t.data);else{var l=r||{x:0,y:0},c=l.x,u=l.y;t instanceof Ys||t instanceof Ws||t instanceof Xs||t instanceof Zs?s.texSubImage2D(s.TEXTURE_2D,0,c,u,s.RGBA,s.UNSIGNED_BYTE,t):s.texSubImage2D(s.TEXTURE_2D,0,c,u,n,i,s.RGBA,s.UNSIGNED_BYTE,t.data)}this.useMipmap&&this.isSizePowerOfTwo()&&s.generateMipmap(s.TEXTURE_2D)},Js.prototype.bind=function(t,e,r){var n=this.context.gl;n.bindTexture(n.TEXTURE_2D,this.texture),r!==n.LINEAR_MIPMAP_NEAREST||this.isSizePowerOfTwo()||(r=n.LINEAR),t!==this.filter&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,t),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,r||t),this.filter=t),e!==this.wrap&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,e),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,e),this.wrap=e)},Js.prototype.isSizePowerOfTwo=function(){return this.size[0]===this.size[1]&&Math.log(this.size[0])/Math.LN2%1==0},Js.prototype.destroy=function(){this.context.gl.deleteTexture(this.texture),this.texture=null};var Ks=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?i-1:0,f=r?-1:1,p=t[e+h];for(h+=f,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+h],h+=f,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},$s=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,h=u>>1,f=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,i),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g},Qs=tl;function tl(t){this.buf=ArrayBuffer.isView&&ArrayBuffer.isView(t)?t:new Uint8Array(t||0),this.pos=0,this.type=0,this.length=this.buf.length}function el(t){return t.type===tl.Bytes?t.readVarint()+t.pos:t.pos+1}function rl(t,e,r){return r?4294967296*e+(t>>>0):4294967296*(e>>>0)+(t>>>0)}function nl(t,e,r){var n=e<=16383?1:e<=2097151?2:e<=268435455?3:Math.floor(Math.log(e)/(7*Math.LN2));r.realloc(n);for(var i=r.pos-1;i>=t;i--)r.buf[i+n]=r.buf[i]}function il(t,e){for(var r=0;r<t.length;r++)e.writeVarint(t[r])}function al(t,e){for(var r=0;r<t.length;r++)e.writeSVarint(t[r])}function ol(t,e){for(var r=0;r<t.length;r++)e.writeFloat(t[r])}function sl(t,e){for(var r=0;r<t.length;r++)e.writeDouble(t[r])}function ll(t,e){for(var r=0;r<t.length;r++)e.writeBoolean(t[r])}function cl(t,e){for(var r=0;r<t.length;r++)e.writeFixed32(t[r])}function ul(t,e){for(var r=0;r<t.length;r++)e.writeSFixed32(t[r])}function hl(t,e){for(var r=0;r<t.length;r++)e.writeFixed64(t[r])}function fl(t,e){for(var r=0;r<t.length;r++)e.writeSFixed64(t[r])}function pl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+16777216*t[e+3]}function dl(t,e,r){t[r]=e,t[r+1]=e>>>8,t[r+2]=e>>>16,t[r+3]=e>>>24}function gl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+(t[e+3]<<24)}tl.Varint=0,tl.Fixed64=1,tl.Bytes=2,tl.Fixed32=5,tl.prototype={destroy:function(){this.buf=null},readFields:function(t,e,r){for(r=r||this.length;this.pos<r;){var n=this.readVarint(),i=n>>3,a=this.pos;this.type=7&n,t(i,e,this),this.pos===a&&this.skip(n)}return e},readMessage:function(t,e){return this.readFields(t,e,this.readVarint()+this.pos)},readFixed32:function(){var t=pl(this.buf,this.pos);return this.pos+=4,t},readSFixed32:function(){var t=gl(this.buf,this.pos);return this.pos+=4,t},readFixed64:function(){var t=pl(this.buf,this.pos)+4294967296*pl(this.buf,this.pos+4);return this.pos+=8,t},readSFixed64:function(){var t=pl(this.buf,this.pos)+4294967296*gl(this.buf,this.pos+4);return this.pos+=8,t},readFloat:function(){var t=Ks(this.buf,this.pos,!0,23,4);return this.pos+=4,t},readDouble:function(){var t=Ks(this.buf,this.pos,!0,52,8);return this.pos+=8,t},readVarint:function(t){var e,r,n=this.buf;return e=127&(r=n[this.pos++]),r<128?e:(e|=(127&(r=n[this.pos++]))<<7,r<128?e:(e|=(127&(r=n[this.pos++]))<<14,r<128?e:(e|=(127&(r=n[this.pos++]))<<21,r<128?e:function(t,e,r){var n,i,a=r.buf;if(n=(112&(i=a[r.pos++]))>>4,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<3,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<10,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<17,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<24,i<128)return rl(t,n,e);if(n|=(1&(i=a[r.pos++]))<<31,i<128)return rl(t,n,e);throw new Error(\"Expected varint not more than 10 bytes\")}(e|=(15&(r=n[this.pos]))<<28,t,this))))},readVarint64:function(){return this.readVarint(!0)},readSVarint:function(){var t=this.readVarint();return t%2==1?(t+1)/-2:t/2},readBoolean:function(){return Boolean(this.readVarint())},readString:function(){var t=this.readVarint()+this.pos,e=function(t,e,r){for(var n=\"\",i=e;i<r;){var a,o,s,l=t[i],c=null,u=l>239?4:l>223?3:l>191?2:1;if(i+u>r)break;1===u?l<128&&(c=l):2===u?128==(192&(a=t[i+1]))&&(c=(31&l)<<6|63&a)<=127&&(c=null):3===u?(a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&((c=(15&l)<<12|(63&a)<<6|63&o)<=2047||c>=55296&&c<=57343)&&(c=null)):4===u&&(a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&((c=(15&l)<<18|(63&a)<<12|(63&o)<<6|63&s)<=65535||c>=1114112)&&(c=null)),null===c?(c=65533,u=1):c>65535&&(c-=65536,n+=String.fromCharCode(c>>>10&1023|55296),c=56320|1023&c),n+=String.fromCharCode(c),i+=u}return n}(this.buf,this.pos,t);return this.pos=t,e},readBytes:function(){var t=this.readVarint()+this.pos,e=this.buf.subarray(this.pos,t);return this.pos=t,e},readPackedVarint:function(t,e){if(this.type!==tl.Bytes)return t.push(this.readVarint(e));var r=el(this);for(t=t||[];this.pos<r;)t.push(this.readVarint(e));return t},readPackedSVarint:function(t){if(this.type!==tl.Bytes)return t.push(this.readSVarint());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSVarint());return t},readPackedBoolean:function(t){if(this.type!==tl.Bytes)return t.push(this.readBoolean());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readBoolean());return t},readPackedFloat:function(t){if(this.type!==tl.Bytes)return t.push(this.readFloat());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFloat());return t},readPackedDouble:function(t){if(this.type!==tl.Bytes)return t.push(this.readDouble());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readDouble());return t},readPackedFixed32:function(t){if(this.type!==tl.Bytes)return t.push(this.readFixed32());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFixed32());return t},readPackedSFixed32:function(t){if(this.type!==tl.Bytes)return t.push(this.readSFixed32());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed32());return t},readPackedFixed64:function(t){if(this.type!==tl.Bytes)return t.push(this.readFixed64());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFixed64());return t},readPackedSFixed64:function(t){if(this.type!==tl.Bytes)return t.push(this.readSFixed64());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed64());return t},skip:function(t){var e=7&t;if(e===tl.Varint)for(;this.buf[this.pos++]>127;);else if(e===tl.Bytes)this.pos=this.readVarint()+this.pos;else if(e===tl.Fixed32)this.pos+=4;else{if(e!==tl.Fixed64)throw new Error(\"Unimplemented type: \"+e);this.pos+=8}},writeTag:function(t,e){this.writeVarint(t<<3|e)},realloc:function(t){for(var e=this.length||16;e<this.pos+t;)e*=2;if(e!==this.length){var r=new Uint8Array(e);r.set(this.buf),this.buf=r,this.length=e}},finish:function(){return this.length=this.pos,this.pos=0,this.buf.subarray(0,this.length)},writeFixed32:function(t){this.realloc(4),dl(this.buf,t,this.pos),this.pos+=4},writeSFixed32:function(t){this.realloc(4),dl(this.buf,t,this.pos),this.pos+=4},writeFixed64:function(t){this.realloc(8),dl(this.buf,-1&t,this.pos),dl(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeSFixed64:function(t){this.realloc(8),dl(this.buf,-1&t,this.pos),dl(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeVarint:function(t){(t=+t||0)>268435455||t<0?function(t,e){var r,n;if(t>=0?(r=t%4294967296|0,n=t/4294967296|0):(n=~(-t/4294967296),4294967295^(r=~(-t%4294967296))?r=r+1|0:(r=0,n=n+1|0)),t>=0x10000000000000000||t<-0x10000000000000000)throw new Error(\"Given varint doesn't fit into 10 bytes\");e.realloc(10),function(t,e,r){r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos]=127&t}(r,0,e),function(t,e){var r=(7&t)<<4;e.buf[e.pos++]|=r|((t>>>=3)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t)))))}(n,e)}(t,this):(this.realloc(4),this.buf[this.pos++]=127&t|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=t>>>7&127))))},writeSVarint:function(t){this.writeVarint(t<0?2*-t-1:2*t)},writeBoolean:function(t){this.writeVarint(Boolean(t))},writeString:function(t){t=String(t),this.realloc(4*t.length),this.pos++;var e=this.pos;this.pos=function(t,e,r){for(var n,i,a=0;a<e.length;a++){if((n=e.charCodeAt(a))>55295&&n<57344){if(!i){n>56319||a+1===e.length?(t[r++]=239,t[r++]=191,t[r++]=189):i=n;continue}if(n<56320){t[r++]=239,t[r++]=191,t[r++]=189,i=n;continue}n=i-55296<<10|n-56320|65536,i=null}else i&&(t[r++]=239,t[r++]=191,t[r++]=189,i=null);n<128?t[r++]=n:(n<2048?t[r++]=n>>6|192:(n<65536?t[r++]=n>>12|224:(t[r++]=n>>18|240,t[r++]=n>>12&63|128),t[r++]=n>>6&63|128),t[r++]=63&n|128)}return r}(this.buf,t,this.pos);var r=this.pos-e;r>=128&&nl(e,r,this),this.pos=e-1,this.writeVarint(r),this.pos+=r},writeFloat:function(t){this.realloc(4),$s(this.buf,t,this.pos,!0,23,4),this.pos+=4},writeDouble:function(t){this.realloc(8),$s(this.buf,t,this.pos,!0,52,8),this.pos+=8},writeBytes:function(t){var e=t.length;this.writeVarint(e),this.realloc(e);for(var r=0;r<e;r++)this.buf[this.pos++]=t[r]},writeRawMessage:function(t,e){this.pos++;var r=this.pos;t(e,this);var n=this.pos-r;n>=128&&nl(r,n,this),this.pos=r-1,this.writeVarint(n),this.pos+=n},writeMessage:function(t,e,r){this.writeTag(t,tl.Bytes),this.writeRawMessage(e,r)},writePackedVarint:function(t,e){e.length&&this.writeMessage(t,il,e)},writePackedSVarint:function(t,e){e.length&&this.writeMessage(t,al,e)},writePackedBoolean:function(t,e){e.length&&this.writeMessage(t,ll,e)},writePackedFloat:function(t,e){e.length&&this.writeMessage(t,ol,e)},writePackedDouble:function(t,e){e.length&&this.writeMessage(t,sl,e)},writePackedFixed32:function(t,e){e.length&&this.writeMessage(t,cl,e)},writePackedSFixed32:function(t,e){e.length&&this.writeMessage(t,ul,e)},writePackedFixed64:function(t,e){e.length&&this.writeMessage(t,hl,e)},writePackedSFixed64:function(t,e){e.length&&this.writeMessage(t,fl,e)},writeBytesField:function(t,e){this.writeTag(t,tl.Bytes),this.writeBytes(e)},writeFixed32Field:function(t,e){this.writeTag(t,tl.Fixed32),this.writeFixed32(e)},writeSFixed32Field:function(t,e){this.writeTag(t,tl.Fixed32),this.writeSFixed32(e)},writeFixed64Field:function(t,e){this.writeTag(t,tl.Fixed64),this.writeFixed64(e)},writeSFixed64Field:function(t,e){this.writeTag(t,tl.Fixed64),this.writeSFixed64(e)},writeVarintField:function(t,e){this.writeTag(t,tl.Varint),this.writeVarint(e)},writeSVarintField:function(t,e){this.writeTag(t,tl.Varint),this.writeSVarint(e)},writeStringField:function(t,e){this.writeTag(t,tl.Bytes),this.writeString(e)},writeFloatField:function(t,e){this.writeTag(t,tl.Fixed32),this.writeFloat(e)},writeDoubleField:function(t,e){this.writeTag(t,tl.Fixed64),this.writeDouble(e)},writeBooleanField:function(t,e){this.writeVarintField(t,Boolean(e))}};var vl=3;function ml(t,e,r){1===t&&r.readMessage(yl,e)}function yl(t,e,r){if(3===t){var n=r.readMessage(xl,{}),i=n.id,a=n.bitmap,o=n.width,s=n.height,l=n.left,c=n.top,u=n.advance;e.push({id:i,bitmap:new qa({width:o+2*vl,height:s+2*vl},a),metrics:{width:o,height:s,left:l,top:c,advance:u}})}}function xl(t,e,r){1===t?e.id=r.readVarint():2===t?e.bitmap=r.readBytes():3===t?e.width=r.readVarint():4===t?e.height=r.readVarint():5===t?e.left=r.readSVarint():6===t?e.top=r.readSVarint():7===t&&(e.advance=r.readVarint())}var bl=vl,_l=function(t,e,r){this.target=t,this.parent=e,this.mapId=r,this.callbacks={},this.callbackID=0,v([\"receive\"],this),this.target.addEventListener(\"message\",this.receive,!1)};function wl(t,e,r){var n=2*Math.PI*6378137/256/Math.pow(2,r);return[t*n-2*Math.PI*6378137/2,e*n-2*Math.PI*6378137/2]}_l.prototype.send=function(t,e,r,n){var i=this,a=r?this.mapId+\":\"+this.callbackID++:null;r&&(this.callbacks[a]=r);var o=[];if(this.target.postMessage({targetMapId:n,sourceMapId:this.mapId,type:t,id:String(a),data:An(e,o)},o),r)return{cancel:function(){i.callbacks[a]=null,i.target.postMessage({targetMapId:n,sourceMapId:i.mapId,type:\"<cancel>\",id:String(a)})}}},_l.prototype.receive=function(t){var e,r=this,n=t.data,i=n.id;if(!n.targetMapId||this.mapId===n.targetMapId){var a=function(t,e){delete r.callbacks[i];var n=[];r.target.postMessage({sourceMapId:r.mapId,type:\"<response>\",id:String(i),error:t?An(t):null,data:An(e,n)},n)};if(\"<response>\"===n.type||\"<cancel>\"===n.type)e=this.callbacks[n.id],delete this.callbacks[n.id],e&&n.error?e(Mn(n.error)):e&&e(null,Mn(n.data));else if(void 0!==n.id&&this.parent[n.type]){this.callbacks[n.id]=null;var o=this.parent[n.type](n.sourceMapId,Mn(n.data),a);o&&null===this.callbacks[n.id]&&(this.callbacks[n.id]=o.cancel)}else if(void 0!==n.id&&this.parent.getWorkerSource){var s=n.type.split(\".\"),l=Mn(n.data);this.parent.getWorkerSource(n.sourceMapId,s[0],l.source)[s[1]](l,a)}else this.parent[n.type](Mn(n.data))}},_l.prototype.remove=function(){this.target.removeEventListener(\"message\",this.receive,!1)};var kl=function(t,e){t&&(e?this.setSouthWest(t).setNorthEast(e):4===t.length?this.setSouthWest([t[0],t[1]]).setNorthEast([t[2],t[3]]):this.setSouthWest(t[0]).setNorthEast(t[1]))};kl.prototype.setNorthEast=function(t){return this._ne=t instanceof Tl?new Tl(t.lng,t.lat):Tl.convert(t),this},kl.prototype.setSouthWest=function(t){return this._sw=t instanceof Tl?new Tl(t.lng,t.lat):Tl.convert(t),this},kl.prototype.extend=function(t){var e,r,n=this._sw,i=this._ne;if(t instanceof Tl)e=t,r=t;else{if(!(t instanceof kl))return Array.isArray(t)?t.every(Array.isArray)?this.extend(kl.convert(t)):this.extend(Tl.convert(t)):this;if(e=t._sw,r=t._ne,!e||!r)return this}return n||i?(n.lng=Math.min(e.lng,n.lng),n.lat=Math.min(e.lat,n.lat),i.lng=Math.max(r.lng,i.lng),i.lat=Math.max(r.lat,i.lat)):(this._sw=new Tl(e.lng,e.lat),this._ne=new Tl(r.lng,r.lat)),this},kl.prototype.getCenter=function(){return new Tl((this._sw.lng+this._ne.lng)/2,(this._sw.lat+this._ne.lat)/2)},kl.prototype.getSouthWest=function(){return this._sw},kl.prototype.getNorthEast=function(){return this._ne},kl.prototype.getNorthWest=function(){return new Tl(this.getWest(),this.getNorth())},kl.prototype.getSouthEast=function(){return new Tl(this.getEast(),this.getSouth())},kl.prototype.getWest=function(){return this._sw.lng},kl.prototype.getSouth=function(){return this._sw.lat},kl.prototype.getEast=function(){return this._ne.lng},kl.prototype.getNorth=function(){return this._ne.lat},kl.prototype.toArray=function(){return[this._sw.toArray(),this._ne.toArray()]},kl.prototype.toString=function(){return\"LngLatBounds(\"+this._sw.toString()+\", \"+this._ne.toString()+\")\"},kl.prototype.isEmpty=function(){return!(this._sw&&this._ne)},kl.convert=function(t){return!t||t instanceof kl?t:new kl(t)};var Tl=function(t,e){if(isNaN(t)||isNaN(e))throw new Error(\"Invalid LngLat object: (\"+t+\", \"+e+\")\");if(this.lng=+t,this.lat=+e,this.lat>90||this.lat<-90)throw new Error(\"Invalid LngLat latitude value: must be between -90 and 90\")};function Al(t){return 2*Math.PI*6378137*Math.cos(t*Math.PI/180)}function Ml(t){return(180+t)/360}function Sl(t){return(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+t*Math.PI/360)))/360}function El(t,e){return t/Al(e)}function Cl(t){var e=180-360*t;return 360/Math.PI*Math.atan(Math.exp(e*Math.PI/180))-90}Tl.prototype.wrap=function(){return new Tl(u(this.lng,-180,180),this.lat)},Tl.prototype.toArray=function(){return[this.lng,this.lat]},Tl.prototype.toString=function(){return\"LngLat(\"+this.lng+\", \"+this.lat+\")\"},Tl.prototype.toBounds=function(t){void 0===t&&(t=0);var e=360*t/40075017,r=e/Math.cos(Math.PI/180*this.lat);return new kl(new Tl(this.lng-r,this.lat-e),new Tl(this.lng+r,this.lat+e))},Tl.convert=function(t){if(t instanceof Tl)return t;if(Array.isArray(t)&&(2===t.length||3===t.length))return new Tl(Number(t[0]),Number(t[1]));if(!Array.isArray(t)&&\"object\"==typeof t&&null!==t)return new Tl(Number(\"lng\"in t?t.lng:t.lon),Number(t.lat));throw new Error(\"`LngLatLike` argument must be specified as a LngLat instance, an object {lng: <lng>, lat: <lat>}, an object {lon: <lng>, lat: <lat>}, or an array of [<lng>, <lat>]\")};var Ll=function(t,e,r){void 0===r&&(r=0),this.x=+t,this.y=+e,this.z=+r};Ll.fromLngLat=function(t,e){void 0===e&&(e=0);var r=Tl.convert(t);return new Ll(Ml(r.lng),Sl(r.lat),El(e,r.lat))},Ll.prototype.toLngLat=function(){return new Tl(360*this.x-180,Cl(this.y))},Ll.prototype.toAltitude=function(){return this.z*Al(Cl(this.y))};var Pl=function(t,e,r){this.z=t,this.x=e,this.y=r,this.key=Il(0,t,e,r)};Pl.prototype.equals=function(t){return this.z===t.z&&this.x===t.x&&this.y===t.y},Pl.prototype.url=function(t,e){var r,n,i,a,o,s=(r=this.x,n=this.y,i=this.z,a=wl(256*r,256*(n=Math.pow(2,i)-n-1),i),o=wl(256*(r+1),256*(n+1),i),a[0]+\",\"+a[1]+\",\"+o[0]+\",\"+o[1]),l=function(t,e,r){for(var n,i=\"\",a=t;a>0;a--)i+=(e&(n=1<<a-1)?1:0)+(r&n?2:0);return i}(this.z,this.x,this.y);return t[(this.x+this.y)%t.length].replace(\"{prefix}\",(this.x%16).toString(16)+(this.y%16).toString(16)).replace(\"{z}\",String(this.z)).replace(\"{x}\",String(this.x)).replace(\"{y}\",String(\"tms\"===e?Math.pow(2,this.z)-this.y-1:this.y)).replace(\"{quadkey}\",l).replace(\"{bbox-epsg-3857}\",s)},Pl.prototype.getTilePoint=function(t){var e=Math.pow(2,this.z);return new i((t.x*e-this.x)*ha,(t.y*e-this.y)*ha)};var Ol=function(t,e){this.wrap=t,this.canonical=e,this.key=Il(t,e.z,e.x,e.y)},zl=function(t,e,r,n,i){this.overscaledZ=t,this.wrap=e,this.canonical=new Pl(r,+n,+i),this.key=Il(e,t,n,i)};function Il(t,e,r,n){(t*=2)<0&&(t=-1*t-1);var i=1<<e;return 32*(i*i*t+i*n+r)+e}zl.prototype.equals=function(t){return this.overscaledZ===t.overscaledZ&&this.wrap===t.wrap&&this.canonical.equals(t.canonical)},zl.prototype.scaledTo=function(t){var e=this.canonical.z-t;return t>this.canonical.z?new zl(t,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y):new zl(t,this.wrap,t,this.canonical.x>>e,this.canonical.y>>e)},zl.prototype.isChildOf=function(t){if(t.wrap!==this.wrap)return!1;var e=this.canonical.z-t.canonical.z;return 0===t.overscaledZ||t.overscaledZ<this.overscaledZ&&t.canonical.x===this.canonical.x>>e&&t.canonical.y===this.canonical.y>>e},zl.prototype.children=function(t){if(this.overscaledZ>=t)return[new zl(this.overscaledZ+1,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y)];var e=this.canonical.z+1,r=2*this.canonical.x,n=2*this.canonical.y;return[new zl(e,this.wrap,e,r,n),new zl(e,this.wrap,e,r+1,n),new zl(e,this.wrap,e,r,n+1),new zl(e,this.wrap,e,r+1,n+1)]},zl.prototype.isLessThan=function(t){return this.wrap<t.wrap||!(this.wrap>t.wrap)&&(this.overscaledZ<t.overscaledZ||!(this.overscaledZ>t.overscaledZ)&&(this.canonical.x<t.canonical.x||!(this.canonical.x>t.canonical.x)&&this.canonical.y<t.canonical.y))},zl.prototype.wrapped=function(){return new zl(this.overscaledZ,0,this.canonical.z,this.canonical.x,this.canonical.y)},zl.prototype.unwrapTo=function(t){return new zl(this.overscaledZ,t,this.canonical.z,this.canonical.x,this.canonical.y)},zl.prototype.overscaleFactor=function(){return Math.pow(2,this.overscaledZ-this.canonical.z)},zl.prototype.toUnwrapped=function(){return new Ol(this.wrap,this.canonical)},zl.prototype.toString=function(){return this.overscaledZ+\"/\"+this.canonical.x+\"/\"+this.canonical.y},zl.prototype.getTilePoint=function(t){return this.canonical.getTilePoint(new Ll(t.x-this.wrap,t.y))},kn(\"CanonicalTileID\",Pl),kn(\"OverscaledTileID\",zl,{omit:[\"posMatrix\"]});var Dl=function(t,e,r){if(this.uid=t,e.height!==e.width)throw new RangeError(\"DEM tiles must be square\");if(r&&\"mapbox\"!==r&&\"terrarium\"!==r)return w('\"'+r+'\" is not a valid encoding type. Valid types include \"mapbox\" and \"terrarium\".');var n=this.dim=e.height;this.stride=this.dim+2,this.data=new Int32Array(this.stride*this.stride);for(var i=e.data,a=\"terrarium\"===r?this._unpackTerrarium:this._unpackMapbox,o=0;o<n;o++)for(var s=0;s<n;s++){var l=4*(o*n+s);this.set(s,o,a(i[l],i[l+1],i[l+2]))}for(var c=0;c<n;c++)this.set(-1,c,this.get(0,c)),this.set(n,c,this.get(n-1,c)),this.set(c,-1,this.get(c,0)),this.set(c,n,this.get(c,n-1));this.set(-1,-1,this.get(0,0)),this.set(n,-1,this.get(n-1,0)),this.set(-1,n,this.get(0,n-1)),this.set(n,n,this.get(n-1,n-1))};Dl.prototype.set=function(t,e,r){this.data[this._idx(t,e)]=r+65536},Dl.prototype.get=function(t,e){return this.data[this._idx(t,e)]-65536},Dl.prototype._idx=function(t,e){if(t<-1||t>=this.dim+1||e<-1||e>=this.dim+1)throw new RangeError(\"out of range source coordinates for DEM data\");return(e+1)*this.stride+(t+1)},Dl.prototype._unpackMapbox=function(t,e,r){return(256*t*256+256*e+r)/10-1e4},Dl.prototype._unpackTerrarium=function(t,e,r){return 256*t+e+r/256-32768},Dl.prototype.getPixels=function(){return new Ha({width:this.stride,height:this.stride},new Uint8Array(this.data.buffer))},Dl.prototype.backfillBorder=function(t,e,r){if(this.dim!==t.dim)throw new Error(\"dem dimension mismatch\");var n=e*this.dim,i=e*this.dim+this.dim,a=r*this.dim,o=r*this.dim+this.dim;switch(e){case-1:n=i-1;break;case 1:i=n+1}switch(r){case-1:a=o-1;break;case 1:o=a+1}for(var s=-e*this.dim,l=-r*this.dim,c=a;c<o;c++)for(var u=n;u<i;u++)this.set(u,c,t.get(u+s,c+l))},kn(\"DEMData\",Dl);var Rl=oi([{name:\"a_pos\",type:\"Int16\",components:2},{name:\"a_texture_pos\",type:\"Int16\",components:2}]),Fl=function(t){this._stringToNumber={},this._numberToString=[];for(var e=0;e<t.length;e++){var r=t[e];this._stringToNumber[r]=e,this._numberToString[e]=r}};Fl.prototype.encode=function(t){return this._stringToNumber[t]},Fl.prototype.decode=function(t){return this._numberToString[t]};var Bl=function(t,e,r,n){this.type=\"Feature\",this._vectorTileFeature=t,t._z=e,t._x=r,t._y=n,this.properties=t.properties,null!=t.id&&(this.id=t.id)},Nl={geometry:{configurable:!0}};Nl.geometry.get=function(){return void 0===this._geometry&&(this._geometry=this._vectorTileFeature.toGeoJSON(this._vectorTileFeature._x,this._vectorTileFeature._y,this._vectorTileFeature._z).geometry),this._geometry},Nl.geometry.set=function(t){this._geometry=t},Bl.prototype.toJSON=function(){var t={geometry:this.geometry};for(var e in this)\"_geometry\"!==e&&\"_vectorTileFeature\"!==e&&(t[e]=this[e]);return t},Object.defineProperties(Bl.prototype,Nl);var jl=function(){this.state={},this.stateChanges={},this.deletedStates={}};jl.prototype.updateState=function(t,e,r){var n=String(e);if(this.stateChanges[t]=this.stateChanges[t]||{},this.stateChanges[t][n]=this.stateChanges[t][n]||{},h(this.stateChanges[t][n],r),null===this.deletedStates[t])for(var i in this.deletedStates[t]={},this.state[t])i!==n&&(this.deletedStates[t][i]=null);else if(this.deletedStates[t]&&null===this.deletedStates[t][n])for(var a in this.deletedStates[t][n]={},this.state[t][n])r[a]||(this.deletedStates[t][n][a]=null);else for(var o in r)this.deletedStates[t]&&this.deletedStates[t][n]&&null===this.deletedStates[t][n][o]&&delete this.deletedStates[t][n][o]},jl.prototype.removeFeatureState=function(t,e,r){if(null!==this.deletedStates[t]){var n=String(e);if(this.deletedStates[t]=this.deletedStates[t]||{},r&&void 0!==e&&e>=0)null!==this.deletedStates[t][n]&&(this.deletedStates[t][n]=this.deletedStates[t][n]||{},this.deletedStates[t][n][r]=null);else if(void 0!==e&&e>=0)if(this.stateChanges[t]&&this.stateChanges[t][n])for(r in this.deletedStates[t][n]={},this.stateChanges[t][n])this.deletedStates[t][n][r]=null;else this.deletedStates[t][n]=null;else this.deletedStates[t]=null}},jl.prototype.getState=function(t,e){var r=String(e),n=this.state[t]||{},i=this.stateChanges[t]||{},a=h({},n[r],i[r]);if(null===this.deletedStates[t])return{};if(this.deletedStates[t]){var o=this.deletedStates[t][e];if(null===o)return{};for(var s in o)delete a[s]}return a},jl.prototype.initializeTileState=function(t,e){t.setFeatureState(this.state,e)},jl.prototype.coalesceChanges=function(t,e){var r={};for(var n in this.stateChanges){this.state[n]=this.state[n]||{};var i={};for(var a in this.stateChanges[n])this.state[n][a]||(this.state[n][a]={}),h(this.state[n][a],this.stateChanges[n][a]),i[a]=this.state[n][a];r[n]=i}for(var o in this.deletedStates){this.state[o]=this.state[o]||{};var s={};if(null===this.deletedStates[o])for(var l in this.state[o])s[l]={},this.state[o][l]={};else for(var c in this.deletedStates[o]){if(null===this.deletedStates[o][c])this.state[o][c]={};else for(var u=0,f=Object.keys(this.deletedStates[o][c]);u<f.length;u+=1){var p=f[u];delete this.state[o][c][p]}s[c]=this.state[o][c]}r[o]=r[o]||{},h(r[o],s)}if(this.stateChanges={},this.deletedStates={},0!==Object.keys(r).length)for(var d in t)t[d].setFeatureState(r,e)};var Ul=function(t,e,r){this.tileID=t,this.x=t.canonical.x,this.y=t.canonical.y,this.z=t.canonical.z,this.grid=e||new yn(ha,16,0),this.grid3D=new yn(ha,16,0),this.featureIndexArray=r||new ji};function Vl(t){for(var e=1/0,r=1/0,n=-1/0,i=-1/0,a=0,o=t;a<o.length;a+=1){var s=o[a];e=Math.min(e,s.x),r=Math.min(r,s.y),n=Math.max(n,s.x),i=Math.max(i,s.y)}return{minX:e,minY:r,maxX:n,maxY:i}}function ql(t,e){return e-t}Ul.prototype.insert=function(t,e,r,n,i,a){var o=this.featureIndexArray.length;this.featureIndexArray.emplaceBack(r,n,i);for(var s=a?this.grid3D:this.grid,l=0;l<e.length;l++){for(var c=e[l],u=[1/0,1/0,-1/0,-1/0],h=0;h<c.length;h++){var f=c[h];u[0]=Math.min(u[0],f.x),u[1]=Math.min(u[1],f.y),u[2]=Math.max(u[2],f.x),u[3]=Math.max(u[3],f.y)}u[0]<ha&&u[1]<ha&&u[2]>=0&&u[3]>=0&&s.insert(o,u[0],u[1],u[2],u[3])}},Ul.prototype.loadVTLayers=function(){return this.vtLayers||(this.vtLayers=new Vo.VectorTile(new Qs(this.rawTileData)).layers,this.sourceLayerCoder=new Fl(this.vtLayers?Object.keys(this.vtLayers).sort():[\"_geojsonTileLayer\"])),this.vtLayers},Ul.prototype.query=function(t,e,r){var n=this;this.loadVTLayers();for(var a=t.params||{},o=ha/t.tileSize/t.scale,s=Gr(a.filter),l=t.queryGeometry,c=t.queryPadding*o,u=Vl(l),h=this.grid.query(u.minX-c,u.minY-c,u.maxX+c,u.maxY+c),f=Vl(t.cameraQueryGeometry),p=0,d=this.grid3D.query(f.minX-c,f.minY-c,f.maxX+c,f.maxY+c,function(e,r,n,a){return function(t,e,r,n,a){for(var o=0,s=t;o<s.length;o+=1){var l=s[o];if(e<=l.x&&r<=l.y&&n>=l.x&&a>=l.y)return!0}var c=[new i(e,r),new i(e,a),new i(n,a),new i(n,r)];if(t.length>2)for(var u=0,h=c;u<h.length;u+=1)if(Aa(t,h[u]))return!0;for(var f=0;f<t.length-1;f++)if(Ma(t[f],t[f+1],c))return!0;return!1}(t.cameraQueryGeometry,e-c,r-c,n+c,a+c)});p<d.length;p+=1){var g=d[p];h.push(g)}h.sort(ql);for(var v,m={},y=function(i){var c=h[i];if(c!==v){v=c;var u=n.featureIndexArray.get(c),f=null;n.loadMatchingFeature(m,u.bucketIndex,u.sourceLayerIndex,u.featureIndex,s,a.layers,e,function(e,i){f||(f=pa(e));var a={};return e.id&&(a=r.getState(i.sourceLayer||\"_geojsonTileLayer\",e.id)),i.queryIntersectsFeature(l,e,a,f,n.z,t.transform,o,t.pixelPosMatrix)})}},x=0;x<h.length;x++)y(x);return m},Ul.prototype.loadMatchingFeature=function(t,e,r,n,i,a,o,s){var l=this.bucketLayerIDs[e];if(!a||function(t,e){for(var r=0;r<t.length;r++)if(e.indexOf(t[r])>=0)return!0;return!1}(a,l)){var c=this.sourceLayerCoder.decode(r),u=this.vtLayers[c].feature(n);if(i(new Un(this.tileID.overscaledZ),u))for(var h=0;h<l.length;h++){var f=l[h];if(!(a&&a.indexOf(f)<0)){var p=o[f];if(p){var d=!s||s(u,p);if(d){var g=new Bl(u,this.z,this.x,this.y);g.layer=p.serialize();var v=t[f];void 0===v&&(v=t[f]=[]),v.push({featureIndex:n,feature:g,intersectionZ:d})}}}}}},Ul.prototype.lookupSymbolFeatures=function(t,e,r,n,i,a){var o={};this.loadVTLayers();for(var s=Gr(n),l=0,c=t;l<c.length;l+=1){var u=c[l];this.loadMatchingFeature(o,e,r,u,s,i,a)}return o},Ul.prototype.hasLayer=function(t){for(var e=0,r=this.bucketLayerIDs;e<r.length;e+=1)for(var n=0,i=r[e];n<i.length;n+=1)if(t===i[n])return!0;return!1},kn(\"FeatureIndex\",Ul,{omit:[\"rawTileData\",\"sourceLayerCoder\"]});var Hl=function(t,e){this.tileID=t,this.uid=p(),this.uses=0,this.tileSize=e,this.buckets={},this.expirationTime=null,this.queryPadding=0,this.hasSymbolBuckets=!1,this.expiredRequestCount=0,this.state=\"loading\"};Hl.prototype.registerFadeDuration=function(t){var e=t+this.timeAdded;e<z.now()||this.fadeEndTime&&e<this.fadeEndTime||(this.fadeEndTime=e)},Hl.prototype.wasRequested=function(){return\"errored\"===this.state||\"loaded\"===this.state||\"reloading\"===this.state},Hl.prototype.loadVectorData=function(t,e,r){if(this.hasData()&&this.unloadVectorData(),this.state=\"loaded\",t){for(var n in t.featureIndex&&(this.latestFeatureIndex=t.featureIndex,t.rawTileData?(this.latestRawTileData=t.rawTileData,this.latestFeatureIndex.rawTileData=t.rawTileData):this.latestRawTileData&&(this.latestFeatureIndex.rawTileData=this.latestRawTileData)),this.collisionBoxArray=t.collisionBoxArray,this.buckets=function(t,e){var r={};if(!e)return r;for(var n=function(){var t=a[i],n=t.layerIds.map(function(t){return e.getLayer(t)}).filter(Boolean);if(0!==n.length){t.layers=n,t.stateDependentLayerIds&&(t.stateDependentLayers=t.stateDependentLayerIds.map(function(t){return n.filter(function(e){return e.id===t})[0]}));for(var o=0,s=n;o<s.length;o+=1){var l=s[o];r[l.id]=t}}},i=0,a=t;i<a.length;i+=1)n();return r}(t.buckets,e.style),this.hasSymbolBuckets=!1,this.buckets){var i=this.buckets[n];if(i instanceof Os){if(this.hasSymbolBuckets=!0,!r)break;i.justReloaded=!0}}for(var a in this.queryPadding=0,this.buckets){var o=this.buckets[a];this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(a).queryRadius(o))}t.imageAtlas&&(this.imageAtlas=t.imageAtlas),t.glyphAtlasImage&&(this.glyphAtlasImage=t.glyphAtlasImage)}else this.collisionBoxArray=new Li},Hl.prototype.unloadVectorData=function(){for(var t in this.buckets)this.buckets[t].destroy();this.buckets={},this.imageAtlasTexture&&this.imageAtlasTexture.destroy(),this.imageAtlas&&(this.imageAtlas=null),this.glyphAtlasTexture&&this.glyphAtlasTexture.destroy(),this.latestFeatureIndex=null,this.state=\"unloaded\"},Hl.prototype.unloadDEMData=function(){this.dem=null,this.neighboringTiles=null,this.state=\"unloaded\"},Hl.prototype.getBucket=function(t){return this.buckets[t.id]},Hl.prototype.upload=function(t){for(var e in this.buckets){var r=this.buckets[e];r.uploadPending()&&r.upload(t)}var n=t.gl;this.imageAtlas&&!this.imageAtlas.uploaded&&(this.imageAtlasTexture=new Js(t,this.imageAtlas.image,n.RGBA),this.imageAtlas.uploaded=!0),this.glyphAtlasImage&&(this.glyphAtlasTexture=new Js(t,this.glyphAtlasImage,n.ALPHA),this.glyphAtlasImage=null)},Hl.prototype.prepare=function(t){this.imageAtlas&&this.imageAtlas.patchUpdatedImages(t,this.imageAtlasTexture)},Hl.prototype.queryRenderedFeatures=function(t,e,r,n,i,a,o,s,l){return this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData?this.latestFeatureIndex.query({queryGeometry:r,cameraQueryGeometry:n,scale:i,tileSize:this.tileSize,pixelPosMatrix:l,transform:o,params:a,queryPadding:this.queryPadding*s},t,e):{}},Hl.prototype.querySourceFeatures=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData){var r=this.latestFeatureIndex.loadVTLayers(),n=e?e.sourceLayer:\"\",i=r._geojsonTileLayer||r[n];if(i)for(var a=Gr(e&&e.filter),o=this.tileID.canonical,s=o.z,l=o.x,c=o.y,u={z:s,x:l,y:c},h=0;h<i.length;h++){var f=i.feature(h);if(a(new Un(this.tileID.overscaledZ),f)){var p=new Bl(f,s,l,c);p.tile=u,t.push(p)}}}},Hl.prototype.clearMask=function(){this.segments&&(this.segments.destroy(),delete this.segments),this.maskedBoundsBuffer&&(this.maskedBoundsBuffer.destroy(),delete this.maskedBoundsBuffer),this.maskedIndexBuffer&&(this.maskedIndexBuffer.destroy(),delete this.maskedIndexBuffer)},Hl.prototype.setMask=function(t,e){if(!o(this.mask,t)&&(this.mask=t,this.clearMask(),!o(t,{0:!0}))){var r=new ci,n=new Ti;this.segments=new Vi,this.segments.prepareSegment(0,r,n);for(var a=Object.keys(t),s=0;s<a.length;s++){var l=t[+a[s]],c=ha>>l.z,u=new i(l.x*c,l.y*c),h=new i(u.x+c,u.y+c),f=this.segments.prepareSegment(4,r,n);r.emplaceBack(u.x,u.y,u.x,u.y),r.emplaceBack(h.x,u.y,h.x,u.y),r.emplaceBack(u.x,h.y,u.x,h.y),r.emplaceBack(h.x,h.y,h.x,h.y);var p=f.vertexLength;n.emplaceBack(p,p+1,p+2),n.emplaceBack(p+1,p+2,p+3),f.vertexLength+=4,f.primitiveLength+=2}this.maskedBoundsBuffer=e.createVertexBuffer(r,Rl.members),this.maskedIndexBuffer=e.createIndexBuffer(n)}},Hl.prototype.hasData=function(){return\"loaded\"===this.state||\"reloading\"===this.state||\"expired\"===this.state},Hl.prototype.patternsLoaded=function(){return this.imageAtlas&&!!Object.keys(this.imageAtlas.patternPositions).length},Hl.prototype.setExpiryData=function(t){var e=this.expirationTime;if(t.cacheControl){var r=A(t.cacheControl);r[\"max-age\"]&&(this.expirationTime=Date.now()+1e3*r[\"max-age\"])}else t.expires&&(this.expirationTime=new Date(t.expires).getTime());if(this.expirationTime){var n=Date.now(),i=!1;if(this.expirationTime>n)i=!1;else if(e)if(this.expirationTime<e)i=!0;else{var a=this.expirationTime-e;a?this.expirationTime=n+Math.max(a,3e4):i=!0}else i=!0;i?(this.expiredRequestCount++,this.state=\"expired\"):this.expiredRequestCount=0}},Hl.prototype.getExpiryTimeout=function(){if(this.expirationTime)return this.expiredRequestCount?1e3*(1<<Math.min(this.expiredRequestCount-1,31)):Math.min(this.expirationTime-(new Date).getTime(),Math.pow(2,31)-1)},Hl.prototype.setFeatureState=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData&&0!==Object.keys(t).length){var r=this.latestFeatureIndex.loadVTLayers();for(var n in this.buckets){var i=this.buckets[n],a=i.layers[0].sourceLayer||\"_geojsonTileLayer\",o=r[a],s=t[a];o&&s&&0!==Object.keys(s).length&&(i.update(s,o,this.imageAtlas&&this.imageAtlas.patternPositions||{}),e&&e.style&&(this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(n).queryRadius(i))))}}},Hl.prototype.holdingForFade=function(){return void 0!==this.symbolFadeHoldUntil},Hl.prototype.symbolFadeFinished=function(){return!this.symbolFadeHoldUntil||this.symbolFadeHoldUntil<z.now()},Hl.prototype.clearFadeHold=function(){this.symbolFadeHoldUntil=void 0},Hl.prototype.setHoldDuration=function(t){this.symbolFadeHoldUntil=z.now()+t};var Gl=24,Yl={horizontal:1,vertical:2,horizontalOnly:3},Wl=function(){this.text=\"\",this.sectionIndex=[],this.sections=[]};function Xl(t,e,r,n,i,a,o,s,l,c){var u,h=Wl.fromFeature(t,r);c===Yl.vertical&&h.verticalizePunctuation();var f=jn.processBidirectionalText,p=jn.processStyledBidirectionalText;if(f&&1===h.sections.length){u=[];for(var d=0,g=f(h.toString(),tc(h,s,n,e));d<g.length;d+=1){var v=g[d],m=new Wl;m.text=v,m.sections=h.sections;for(var y=0;y<v.length;y++)m.sectionIndex.push(0);u.push(m)}}else if(p){u=[];for(var x=0,b=p(h.text,h.sectionIndex,tc(h,s,n,e));x<b.length;x+=1){var _=b[x],w=new Wl;w.text=_[0],w.sectionIndex=_[1],w.sections=h.sections,u.push(w)}}else u=function(t,e){for(var r=[],n=t.text,i=0,a=0,o=e;a<o.length;a+=1){var s=o[a];r.push(t.substring(i,s)),i=s}return i<n.length&&r.push(t.substring(i,n.length)),r}(h,tc(h,s,n,e));var k=[],T={positionedGlyphs:k,text:h.toString(),top:l[1],bottom:l[1],left:l[0],right:l[0],writingMode:c,lineCount:u.length};return function(t,e,r,n,i,a,o,s){for(var l=0,c=-17,u=0,h=t.positionedGlyphs,f=\"right\"===a?1:\"left\"===a?0:.5,p=0,d=r;p<d.length;p+=1){var g=d[p];g.trim();var v=g.getMaxScale();if(g.length()){for(var m=h.length,y=0;y<g.length();y++){var x=g.getSection(y),b=g.getCharCode(y),_=24*(v-x.scale),w=e[x.fontStack],k=w&&w[b];k&&(On(b)&&o!==Yl.horizontal?(h.push({glyph:b,x:l,y:_,vertical:!0,scale:x.scale,fontStack:x.fontStack}),l+=Gl*x.scale+s):(h.push({glyph:b,x:l,y:c+_,vertical:!1,scale:x.scale,fontStack:x.fontStack}),l+=k.metrics.advance*x.scale+s))}if(h.length!==m){var T=l-s;u=Math.max(T,u),rc(h,e,m,h.length-1,f)}l=0,c+=n*v}else c+=n}var A=ec(i),M=A.horizontalAlign,S=A.verticalAlign;!function(t,e,r,n,i,a,o){for(var s=(e-r)*i,l=(-n*o+.5)*a,c=0;c<t.length;c++)t[c].x+=s,t[c].y+=l}(h,f,M,S,u,n,r.length);var E=c- -17;t.top+=-S*E,t.bottom=t.top+E,t.left+=-M*u,t.right=t.left+u}(T,e,u,i,a,o,c,s),!!k.length&&T}Wl.fromFeature=function(t,e){for(var r=new Wl,n=0;n<t.sections.length;n++){var i=t.sections[n];r.sections.push({scale:i.scale||1,fontStack:i.fontStack||e}),r.text+=i.text;for(var a=0;a<i.text.length;a++)r.sectionIndex.push(n)}return r},Wl.prototype.length=function(){return this.text.length},Wl.prototype.getSection=function(t){return this.sections[this.sectionIndex[t]]},Wl.prototype.getCharCode=function(t){return this.text.charCodeAt(t)},Wl.prototype.verticalizePunctuation=function(){this.text=function(t){for(var e=\"\",r=0;r<t.length;r++){var n=t.charCodeAt(r+1)||null,i=t.charCodeAt(r-1)||null;n&&zn(n)&&!xs[t[r+1]]||i&&zn(i)&&!xs[t[r-1]]||!xs[t[r]]?e+=t[r]:e+=xs[t[r]]}return e}(this.text)},Wl.prototype.trim=function(){for(var t=0,e=0;e<this.text.length&&Zl[this.text.charCodeAt(e)];e++)t++;for(var r=this.text.length,n=this.text.length-1;n>=0&&n>=t&&Zl[this.text.charCodeAt(n)];n--)r--;this.text=this.text.substring(t,r),this.sectionIndex=this.sectionIndex.slice(t,r)},Wl.prototype.substring=function(t,e){var r=new Wl;return r.text=this.text.substring(t,e),r.sectionIndex=this.sectionIndex.slice(t,e),r.sections=this.sections,r},Wl.prototype.toString=function(){return this.text},Wl.prototype.getMaxScale=function(){var t=this;return this.sectionIndex.reduce(function(e,r){return Math.max(e,t.sections[r].scale)},0)};var Zl={9:!0,10:!0,11:!0,12:!0,13:!0,32:!0},Jl={};function Kl(t,e,r,n){var i=Math.pow(t-e,2);return n?t<e?i/2:2*i:i+Math.abs(r)*r}function $l(t,e,r){var n=0;return 10===t&&(n-=1e4),r&&(n+=150),40!==t&&65288!==t||(n+=50),41!==e&&65289!==e||(n+=50),n}function Ql(t,e,r,n,i,a){for(var o=null,s=Kl(e,r,i,a),l=0,c=n;l<c.length;l+=1){var u=c[l],h=Kl(e-u.x,r,i,a)+u.badness;h<=s&&(o=u,s=h)}return{index:t,x:e,priorBreak:o,badness:s}}function tc(t,e,r,n){if(!r)return[];if(!t)return[];for(var i,a=[],o=function(t,e,r,n){for(var i=0,a=0;a<t.length();a++){var o=t.getSection(a),s=n[o.fontStack],l=s&&s[t.getCharCode(a)];l&&(i+=l.metrics.advance*o.scale+e)}return i/Math.max(1,Math.ceil(i/r))}(t,e,r,n),s=t.text.indexOf(\"\\u200b\")>=0,l=0,c=0;c<t.length();c++){var u=t.getSection(c),h=t.getCharCode(c),f=n[u.fontStack],p=f&&f[h];if(p&&!Zl[h]&&(l+=p.metrics.advance*u.scale+e),c<t.length()-1){var d=!((i=h)<11904||!(En[\"Bopomofo Extended\"](i)||En.Bopomofo(i)||En[\"CJK Compatibility Forms\"](i)||En[\"CJK Compatibility Ideographs\"](i)||En[\"CJK Compatibility\"](i)||En[\"CJK Radicals Supplement\"](i)||En[\"CJK Strokes\"](i)||En[\"CJK Symbols and Punctuation\"](i)||En[\"CJK Unified Ideographs Extension A\"](i)||En[\"CJK Unified Ideographs\"](i)||En[\"Enclosed CJK Letters and Months\"](i)||En[\"Halfwidth and Fullwidth Forms\"](i)||En.Hiragana(i)||En[\"Ideographic Description Characters\"](i)||En[\"Kangxi Radicals\"](i)||En[\"Katakana Phonetic Extensions\"](i)||En.Katakana(i)||En[\"Vertical Forms\"](i)||En[\"Yi Radicals\"](i)||En[\"Yi Syllables\"](i)));(Jl[h]||d)&&a.push(Ql(c+1,l,o,a,$l(h,t.getCharCode(c+1),d&&s),!1))}}return function t(e){return e?t(e.priorBreak).concat(e.index):[]}(Ql(t.length(),l,o,a,0,!0))}function ec(t){var e=.5,r=.5;switch(t){case\"right\":case\"top-right\":case\"bottom-right\":e=1;break;case\"left\":case\"top-left\":case\"bottom-left\":e=0}switch(t){case\"bottom\":case\"bottom-right\":case\"bottom-left\":r=1;break;case\"top\":case\"top-right\":case\"top-left\":r=0}return{horizontalAlign:e,verticalAlign:r}}function rc(t,e,r,n,i){if(i){var a=t[n],o=e[a.fontStack],s=o&&o[a.glyph];if(s)for(var l=s.metrics.advance*a.scale,c=(t[n].x+l)*i,u=r;u<=n;u++)t[u].x-=c}}function nc(t,e,r){var n=ec(r),i=n.horizontalAlign,a=n.verticalAlign,o=e[0],s=e[1],l=o-t.displaySize[0]*i,c=l+t.displaySize[0],u=s-t.displaySize[1]*a;return{image:t,top:u,bottom:u+t.displaySize[1],left:l,right:c}}function ic(t,e,r,n,i){if(void 0===e.segment)return!0;for(var a=e,o=e.segment+1,s=0;s>-r/2;){if(--o<0)return!1;s-=t[o].dist(a),a=t[o]}s+=t[o].dist(t[o+1]),o++;for(var l=[],c=0;s<r/2;){var u=t[o-1],h=t[o],f=t[o+1];if(!f)return!1;var p=u.angleTo(h)-h.angleTo(f);for(p=Math.abs((p+3*Math.PI)%(2*Math.PI)-Math.PI),l.push({distance:s,angleDelta:p}),c+=p;s-l[0].distance>n;)c-=l.shift().angleDelta;if(c>i)return!1;o++,s+=h.dist(f)}return!0}function ac(t){for(var e=0,r=0;r<t.length-1;r++)e+=t[r].dist(t[r+1]);return e}function oc(t,e,r){return t?.6*e*r:0}function sc(t,e){return Math.max(t?t.right-t.left:0,e?e.right-e.left:0)}function lc(t,e,r,n,i,a){for(var o=oc(r,i,a),s=sc(r,n)*a,l=0,c=ac(t)/2,u=0;u<t.length-1;u++){var h=t[u],f=t[u+1],p=h.dist(f);if(l+p>c){var d=(c-l)/p,g=Ee(h.x,f.x,d),v=Ee(h.y,f.y,d),m=new bs(g,v,f.angleTo(h),u);return m._round(),!o||ic(t,m,s,o,e)?m:void 0}l+=p}}function cc(t,e,r,n,i,a,o,s,l){var c=oc(n,a,o),u=sc(n,i),h=u*o,f=0===t[0].x||t[0].x===l||0===t[0].y||t[0].y===l;return e-h<e/4&&(e=h+e/4),function t(e,r,n,i,a,o,s,l,c){for(var u=o/2,h=ac(e),f=0,p=r-n,d=[],g=0;g<e.length-1;g++){for(var v=e[g],m=e[g+1],y=v.dist(m),x=m.angleTo(v);p+n<f+y;){var b=((p+=n)-f)/y,_=Ee(v.x,m.x,b),w=Ee(v.y,m.y,b);if(_>=0&&_<c&&w>=0&&w<c&&p-u>=0&&p+u<=h){var k=new bs(_,w,x,g);k._round(),i&&!ic(e,k,o,i,a)||d.push(k)}}f+=y}return l||d.length||s||(d=t(e,f/2,n,i,a,o,s,!0,c)),d}(t,f?e/2*s%e:(u/2+2*a)*o*s%e,e,c,r,h,f,!1,l)}Jl[10]=!0,Jl[32]=!0,Jl[38]=!0,Jl[40]=!0,Jl[41]=!0,Jl[43]=!0,Jl[45]=!0,Jl[47]=!0,Jl[173]=!0,Jl[183]=!0,Jl[8203]=!0,Jl[8208]=!0,Jl[8211]=!0,Jl[8231]=!0;var uc=function(t,e,r,n,a,o,s,l,c,u,h,f){var p=s.top*l-c,d=s.bottom*l+c,g=s.left*l-c,v=s.right*l+c;if(this.boxStartIndex=t.length,u){var m=d-p,y=v-g;m>0&&(m=Math.max(10*l,m),this._addLineCollisionCircles(t,e,r,r.segment,y,m,n,a,o,h))}else{if(f){var x=new i(g,p),b=new i(v,p),_=new i(g,d),w=new i(v,d),k=f*Math.PI/180;x._rotate(k),b._rotate(k),_._rotate(k),w._rotate(k),g=Math.min(x.x,b.x,_.x,w.x),v=Math.max(x.x,b.x,_.x,w.x),p=Math.min(x.y,b.y,_.y,w.y),d=Math.max(x.y,b.y,_.y,w.y)}t.emplaceBack(r.x,r.y,g,p,v,d,n,a,o,0,0)}this.boxEndIndex=t.length};uc.prototype._addLineCollisionCircles=function(t,e,r,n,i,a,o,s,l,c){var u=a/2,h=Math.floor(i/u)||1,f=1+.4*Math.log(c)/Math.LN2,p=Math.floor(h*f/2),d=-a/2,g=r,v=n+1,m=d,y=-i/2,x=y-i/4;do{if(--v<0){if(m>y)return;v=0;break}m-=e[v].dist(g),g=e[v]}while(m>x);for(var b=e[v].dist(e[v+1]),_=-p;_<h+p;_++){var w=_*u,k=y+w;if(w<0&&(k+=w),w>i&&(k+=w-i),!(k<m)){for(;m+b<k;){if(m+=b,++v+1>=e.length)return;b=e[v].dist(e[v+1])}var T=k-m,A=e[v],M=e[v+1].sub(A)._unit()._mult(T)._add(A)._round(),S=Math.abs(k-d)<u?0:.8*(k-d);t.emplaceBack(M.x,M.y,-a/2,-a/2,a/2,a/2,o,s,l,a/2,S)}}};var hc=function(t,e){if(void 0===t&&(t=[]),void 0===e&&(e=fc),this.data=t,this.length=this.data.length,this.compare=e,this.length>0)for(var r=(this.length>>1)-1;r>=0;r--)this._down(r)};function fc(t,e){return t<e?-1:t>e?1:0}function pc(t,e,r){void 0===e&&(e=1),void 0===r&&(r=!1);for(var n=1/0,a=1/0,o=-1/0,s=-1/0,l=t[0],c=0;c<l.length;c++){var u=l[c];(!c||u.x<n)&&(n=u.x),(!c||u.y<a)&&(a=u.y),(!c||u.x>o)&&(o=u.x),(!c||u.y>s)&&(s=u.y)}var h=o-n,f=s-a,p=Math.min(h,f),d=p/2,g=new hc([],dc);if(0===p)return new i(n,a);for(var v=n;v<o;v+=p)for(var m=a;m<s;m+=p)g.push(new gc(v+d,m+d,d,t));for(var y=function(t){for(var e=0,r=0,n=0,i=t[0],a=0,o=i.length,s=o-1;a<o;s=a++){var l=i[a],c=i[s],u=l.x*c.y-c.x*l.y;r+=(l.x+c.x)*u,n+=(l.y+c.y)*u,e+=3*u}return new gc(r/e,n/e,0,t)}(t),x=g.length;g.length;){var b=g.pop();(b.d>y.d||!y.d)&&(y=b,r&&console.log(\"found best %d after %d probes\",Math.round(1e4*b.d)/1e4,x)),b.max-y.d<=e||(d=b.h/2,g.push(new gc(b.p.x-d,b.p.y-d,d,t)),g.push(new gc(b.p.x+d,b.p.y-d,d,t)),g.push(new gc(b.p.x-d,b.p.y+d,d,t)),g.push(new gc(b.p.x+d,b.p.y+d,d,t)),x+=4)}return r&&(console.log(\"num probes: \"+x),console.log(\"best distance: \"+y.d)),y.p}function dc(t,e){return e.max-t.max}function gc(t,e,r,n){this.p=new i(t,e),this.h=r,this.d=function(t,e){for(var r=!1,n=1/0,i=0;i<e.length;i++)for(var a=e[i],o=0,s=a.length,l=s-1;o<s;l=o++){var c=a[o],u=a[l];c.y>t.y!=u.y>t.y&&t.x<(u.x-c.x)*(t.y-c.y)/(u.y-c.y)+c.x&&(r=!r),n=Math.min(n,ka(t,c,u))}return(r?1:-1)*Math.sqrt(n)}(this.p,n),this.max=this.d+this.h*Math.SQRT2}hc.prototype.push=function(t){this.data.push(t),this.length++,this._up(this.length-1)},hc.prototype.pop=function(){if(0!==this.length){var t=this.data[0];return this.length--,this.length>0&&(this.data[0]=this.data[this.length],this._down(0)),this.data.pop(),t}},hc.prototype.peek=function(){return this.data[0]},hc.prototype._up=function(t){for(var e=this.data,r=this.compare,n=e[t];t>0;){var i=t-1>>1,a=e[i];if(r(n,a)>=0)break;e[t]=a,t=i}e[t]=n},hc.prototype._down=function(t){for(var e=this.data,r=this.compare,n=this.length>>1,i=e[t];t<n;){var a=1+(t<<1),o=e[a],s=a+1;if(s<this.length&&r(e[s],o)<0&&(a=s,o=e[s]),r(o,i)>=0)break;e[t]=o,t=a}e[t]=i};var vc=e(function(t){t.exports=function(t,e){var r,n,i,a,o,s,l,c;for(r=3&t.length,n=t.length-r,i=e,o=3432918353,s=461845907,c=0;c<n;)l=255&t.charCodeAt(c)|(255&t.charCodeAt(++c))<<8|(255&t.charCodeAt(++c))<<16|(255&t.charCodeAt(++c))<<24,++c,i=27492+(65535&(a=5*(65535&(i=(i^=l=(65535&(l=(l=(65535&l)*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295)<<13|i>>>19))+((5*(i>>>16)&65535)<<16)&4294967295))+((58964+(a>>>16)&65535)<<16);switch(l=0,r){case 3:l^=(255&t.charCodeAt(c+2))<<16;case 2:l^=(255&t.charCodeAt(c+1))<<8;case 1:i^=l=(65535&(l=(l=(65535&(l^=255&t.charCodeAt(c)))*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295}return i^=t.length,i=2246822507*(65535&(i^=i>>>16))+((2246822507*(i>>>16)&65535)<<16)&4294967295,i=3266489909*(65535&(i^=i>>>13))+((3266489909*(i>>>16)&65535)<<16)&4294967295,(i^=i>>>16)>>>0}}),mc=e(function(t){t.exports=function(t,e){for(var r,n=t.length,i=e^n,a=0;n>=4;)r=1540483477*(65535&(r=255&t.charCodeAt(a)|(255&t.charCodeAt(++a))<<8|(255&t.charCodeAt(++a))<<16|(255&t.charCodeAt(++a))<<24))+((1540483477*(r>>>16)&65535)<<16),i=1540483477*(65535&i)+((1540483477*(i>>>16)&65535)<<16)^(r=1540483477*(65535&(r^=r>>>24))+((1540483477*(r>>>16)&65535)<<16)),n-=4,++a;switch(n){case 3:i^=(255&t.charCodeAt(a+2))<<16;case 2:i^=(255&t.charCodeAt(a+1))<<8;case 1:i=1540483477*(65535&(i^=255&t.charCodeAt(a)))+((1540483477*(i>>>16)&65535)<<16)}return i=1540483477*(65535&(i^=i>>>13))+((1540483477*(i>>>16)&65535)<<16),(i^=i>>>15)>>>0}}),yc=vc,xc=vc,bc=mc;yc.murmur3=xc,yc.murmur2=bc;var _c=7;function wc(t,e){var r=0,n=0,i=e/Math.sqrt(2);switch(t){case\"top-right\":case\"top-left\":n=i-_c;break;case\"bottom-right\":case\"bottom-left\":n=-i+_c;break;case\"bottom\":n=-e+_c;break;case\"top\":n=e-_c}switch(t){case\"top-right\":case\"bottom-right\":r=-i;break;case\"top-left\":case\"bottom-left\":r=i;break;case\"left\":r=e;break;case\"right\":r=-e}return[r,n]}function kc(t){switch(t){case\"right\":case\"top-right\":case\"bottom-right\":return\"right\";case\"left\":case\"top-left\":case\"bottom-left\":return\"left\"}return\"center\"}function Tc(t,e,r,n,a,o,s){var l=o.layoutTextSize.evaluate(e,{}),c=o.layoutIconSize.evaluate(e,{}),u=o.textMaxSize.evaluate(e,{});void 0===u&&(u=l);var h=t.layers[0].layout,f=h.get(\"icon-offset\").evaluate(e,{}),p=Sc(r.horizontal),d=l/24,g=t.tilePixelRatio*d,v=t.tilePixelRatio*u/24,m=t.tilePixelRatio*c,y=t.tilePixelRatio*h.get(\"symbol-spacing\"),x=h.get(\"text-padding\")*t.tilePixelRatio,b=h.get(\"icon-padding\")*t.tilePixelRatio,_=h.get(\"text-max-angle\")/180*Math.PI,k=\"map\"===h.get(\"text-rotation-alignment\")&&\"point\"!==h.get(\"symbol-placement\"),T=\"map\"===h.get(\"icon-rotation-alignment\")&&\"point\"!==h.get(\"symbol-placement\"),A=h.get(\"symbol-placement\"),M=y/2,S=function(l,c){c.x<0||c.x>=ha||c.y<0||c.y>=ha||function(t,e,r,n,a,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_){var k,T,A=t.addToLineVertexArray(e,r),M=0,S=0,E=0,C={},L=yc(\"\"),P=(o.layout.get(\"text-radial-offset\").evaluate(x,{})||0)*Gl;for(var O in n.horizontal){var z=n.horizontal[O];if(!k){L=yc(z.text);var I=o.layout.get(\"text-rotate\").evaluate(x,{});k=new uc(s,r,e,l,c,u,z,h,f,p,t.overscaling,I)}var D=1===z.lineCount;if(S+=Mc(t,e,z,o,p,x,d,A,n.vertical?Yl.horizontal:Yl.horizontalOnly,D?Object.keys(n.horizontal):[O],C,b,_),D)break}n.vertical&&(E+=Mc(t,e,n.vertical,o,p,x,d,A,Yl.vertical,[\"vertical\"],C,b,_));var R=k?k.boxStartIndex:t.collisionBoxArray.length,F=k?k.boxEndIndex:t.collisionBoxArray.length;if(a){var B=function(t,e,r,n,a,o){var s,l,c,u,h=e.image,f=r.layout,p=e.top-1/h.pixelRatio,d=e.left-1/h.pixelRatio,g=e.bottom+1/h.pixelRatio,v=e.right+1/h.pixelRatio;if(\"none\"!==f.get(\"icon-text-fit\")&&a){var m=v-d,y=g-p,x=f.get(\"text-size\").evaluate(o,{})/24,b=a.left*x,_=a.right*x,w=a.top*x,k=_-b,T=a.bottom*x-w,A=f.get(\"icon-text-fit-padding\")[0],M=f.get(\"icon-text-fit-padding\")[1],S=f.get(\"icon-text-fit-padding\")[2],E=f.get(\"icon-text-fit-padding\")[3],C=\"width\"===f.get(\"icon-text-fit\")?.5*(T-y):0,L=\"height\"===f.get(\"icon-text-fit\")?.5*(k-m):0,P=\"width\"===f.get(\"icon-text-fit\")||\"both\"===f.get(\"icon-text-fit\")?k:m,O=\"height\"===f.get(\"icon-text-fit\")||\"both\"===f.get(\"icon-text-fit\")?T:y;s=new i(b+L-E,w+C-A),l=new i(b+L+M+P,w+C-A),c=new i(b+L+M+P,w+C+S+O),u=new i(b+L-E,w+C+S+O)}else s=new i(d,p),l=new i(v,p),c=new i(v,g),u=new i(d,g);var z=r.layout.get(\"icon-rotate\").evaluate(o,{})*Math.PI/180;if(z){var I=Math.sin(z),D=Math.cos(z),R=[D,-I,I,D];s._matMult(R),l._matMult(R),u._matMult(R),c._matMult(R)}return[{tl:s,tr:l,bl:u,br:c,tex:h.paddedRect,writingMode:void 0,glyphOffset:[0,0]}]}(0,a,o,0,Sc(n.horizontal),x),N=o.layout.get(\"icon-rotate\").evaluate(x,{});T=new uc(s,r,e,l,c,u,a,g,v,!1,t.overscaling,N),M=4*B.length;var j=t.iconSizeData,U=null;\"source\"===j.kind?(U=[_s*o.layout.get(\"icon-size\").evaluate(x,{})])[0]>Ac&&w(t.layerIds[0]+': Value for \"icon-size\" is >= 256. Reduce your \"icon-size\".'):\"composite\"===j.kind&&((U=[_s*_.compositeIconSizes[0].evaluate(x,{}),_s*_.compositeIconSizes[1].evaluate(x,{})])[0]>Ac||U[1]>Ac)&&w(t.layerIds[0]+': Value for \"icon-size\" is >= 256. Reduce your \"icon-size\".'),t.addSymbols(t.icon,B,U,y,m,x,!1,e,A.lineStartIndex,A.lineLength)}var V=T?T.boxStartIndex:t.collisionBoxArray.length,q=T?T.boxEndIndex:t.collisionBoxArray.length;t.glyphOffsetArray.length>=Os.MAX_GLYPHS&&w(\"Too many glyphs being rendered in a tile. See https://github.com/mapbox/mapbox-gl-js/issues/2907\"),t.symbolInstances.emplaceBack(e.x,e.y,C.right>=0?C.right:-1,C.center>=0?C.center:-1,C.left>=0?C.left:-1,C.vertical||-1,L,R,F,V,q,l,S,E,M,0,h,P)}(t,c,l,r,n,t.layers[0],t.collisionBoxArray,e.index,e.sourceLayerIndex,t.index,g,x,k,s,m,b,T,f,e,a,o)};if(\"line\"===A)for(var E=0,C=function(t,e,r,n,a){for(var o=[],s=0;s<t.length;s++)for(var l=t[s],c=void 0,u=0;u<l.length-1;u++){var h=l[u],f=l[u+1];h.x<0&&f.x<0||(h.x<0?h=new i(0,h.y+(f.y-h.y)*((0-h.x)/(f.x-h.x)))._round():f.x<0&&(f=new i(0,h.y+(f.y-h.y)*((0-h.x)/(f.x-h.x)))._round()),h.y<0&&f.y<0||(h.y<0?h=new i(h.x+(f.x-h.x)*((0-h.y)/(f.y-h.y)),0)._round():f.y<0&&(f=new i(h.x+(f.x-h.x)*((0-h.y)/(f.y-h.y)),0)._round()),h.x>=n&&f.x>=n||(h.x>=n?h=new i(n,h.y+(f.y-h.y)*((n-h.x)/(f.x-h.x)))._round():f.x>=n&&(f=new i(n,h.y+(f.y-h.y)*((n-h.x)/(f.x-h.x)))._round()),h.y>=a&&f.y>=a||(h.y>=a?h=new i(h.x+(f.x-h.x)*((a-h.y)/(f.y-h.y)),a)._round():f.y>=a&&(f=new i(h.x+(f.x-h.x)*((a-h.y)/(f.y-h.y)),a)._round()),c&&h.equals(c[c.length-1])||(c=[h],o.push(c)),c.push(f)))))}return o}(e.geometry,0,0,ha,ha);E<C.length;E+=1)for(var L=C[E],P=0,O=cc(L,y,_,r.vertical||p,n,24,v,t.overscaling,ha);P<O.length;P+=1){var z=O[P];p&&Ec(t,p.text,M,z)||S(L,z)}else if(\"line-center\"===A)for(var I=0,D=e.geometry;I<D.length;I+=1){var R=D[I];if(R.length>1){var F=lc(R,_,r.vertical||p,n,24,v);F&&S(R,F)}}else if(\"Polygon\"===e.type)for(var B=0,N=Mo(e.geometry,0);B<N.length;B+=1){var j=N[B],U=pc(j,16);S(j[0],new bs(U.x,U.y,0))}else if(\"LineString\"===e.type)for(var V=0,q=e.geometry;V<q.length;V+=1){var H=q[V];S(H,new bs(H[0].x,H[0].y,0))}else if(\"Point\"===e.type)for(var G=0,Y=e.geometry;G<Y.length;G+=1)for(var W=0,X=Y[G];W<X.length;W+=1){var Z=X[W];S([Z],new bs(Z.x,Z.y,0))}}var Ac=65535;function Mc(t,e,r,n,a,o,s,l,c,u,h,f,p){var d=function(t,e,r,n,a,o,s){for(var l=n.layout.get(\"text-rotate\").evaluate(o,{})*Math.PI/180,c=e.positionedGlyphs,u=[],h=0;h<c.length;h++){var f=c[h],p=s[f.fontStack],d=p&&p[f.glyph];if(d){var g=d.rect;if(g){var v=bl+1,m=d.metrics.advance*f.scale/2,y=a?[f.x+m,f.y]:[0,0],x=a?[0,0]:[f.x+m+r[0],f.y+r[1]],b=(d.metrics.left-v)*f.scale-m+x[0],_=(-d.metrics.top-v)*f.scale+x[1],w=b+g.w*f.scale,k=_+g.h*f.scale,T=new i(b,_),A=new i(w,_),M=new i(b,k),S=new i(w,k);if(a&&f.vertical){var E=new i(-m,m),C=-Math.PI/2,L=new i(5,0);T._rotateAround(C,E)._add(L),A._rotateAround(C,E)._add(L),M._rotateAround(C,E)._add(L),S._rotateAround(C,E)._add(L)}if(l){var P=Math.sin(l),O=Math.cos(l),z=[O,-P,P,O];T._matMult(z),A._matMult(z),M._matMult(z),S._matMult(z)}u.push({tl:T,tr:A,bl:M,br:S,tex:g,writingMode:e.writingMode,glyphOffset:y})}}}return u}(0,r,s,n,a,o,f),g=t.textSizeData,v=null;\"source\"===g.kind?(v=[_s*n.layout.get(\"text-size\").evaluate(o,{})])[0]>Ac&&w(t.layerIds[0]+': Value for \"text-size\" is >= 256. Reduce your \"text-size\".'):\"composite\"===g.kind&&((v=[_s*p.compositeTextSizes[0].evaluate(o,{}),_s*p.compositeTextSizes[1].evaluate(o,{})])[0]>Ac||v[1]>Ac)&&w(t.layerIds[0]+': Value for \"text-size\" is >= 256. Reduce your \"text-size\".'),t.addSymbols(t.text,d,v,s,a,o,c,e,l.lineStartIndex,l.lineLength);for(var m=0,y=u;m<y.length;m+=1)h[y[m]]=t.text.placedSymbolArray.length-1;return 4*d.length}function Sc(t){for(var e in t)return t[e];return null}function Ec(t,e,r,n){var i=t.compareText;if(e in i){for(var a=i[e],o=a.length-1;o>=0;o--)if(n.dist(a[o])<r)return!0}else i[e]=[];return i[e].push(n),!1}t.Actor=_l,t.AlphaImage=qa,t.CanonicalTileID=Pl,t.CollisionBoxArray=Li,t.Color=ne,t.DEMData=Dl,t.DataConstantProperty=Jn,t.DictionaryCoder=Fl,t.EXTENT=ha,t.ErrorEvent=Ot,t.EvaluationParameters=Un,t.Event=Pt,t.Evented=zt,t.FeatureIndex=Ul,t.FillBucket=Lo,t.FillExtrusionBucket=Yo,t.ImageAtlas=Gs,t.ImagePosition=qs,t.LineBucket=os,t.LngLat=Tl,t.LngLatBounds=kl,t.MercatorCoordinate=Ll,t.ONE_EM=Gl,t.OverscaledTileID=zl,t.Point=i,t.Point$1=i,t.ProgramConfiguration=sa,t.Properties=ei,t.Protobuf=Qs,t.RGBAImage=Ha,t.RequestManager=j,t.ResourceType=yt,t.SegmentVector=Vi,t.SourceFeatureState=jl,t.StructArrayLayout1ui2=Mi,t.StructArrayLayout2i4=li,t.StructArrayLayout2ui4=Ai,t.StructArrayLayout3ui6=Ti,t.StructArrayLayout4i8=ci,t.SymbolBucket=Os,t.Texture=Js,t.Tile=Hl,t.Transitionable=Hn,t.Uniform1f=Xi,t.Uniform1i=Wi,t.Uniform2f=Zi,t.Uniform3f=Ji,t.Uniform4f=Ki,t.UniformColor=$i,t.UniformMatrix4f=ta,t.UnwrappedTileID=Ol,t.ValidationError=Dt,t.WritingMode=Yl,t.ZoomHistory=Sn,t.addDynamicAttributes=Cs,t.asyncAll=function(t,e,r){if(!t.length)return r(null,[]);var n=t.length,i=new Array(t.length),a=null;t.forEach(function(t,o){e(t,function(t,e){t&&(a=t),i[o]=e,0==--n&&r(a,i)})})},t.bezier=s,t.bindAll=v,t.browser=z,t.cacheEntryPossiblyAdded=function(t){++mt>dt&&(t.send(\"enforceCacheSizeLimit\",pt),mt=0)},t.clamp=c,t.clearTileCache=function(t){var e=self.caches.delete(ft);t&&e.catch(t).then(function(){return t()})},t.clone=function(t){var e=new Pa(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e},t.clone$1=b,t.config=I,t.create=function(){var t=new Pa(16);return Pa!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=0,t[12]=0,t[13]=0,t[14]=0),t[0]=1,t[5]=1,t[10]=1,t[15]=1,t},t.create$1=Oa,t.create$2=function(){var t=new Pa(4);return Pa!=Float32Array&&(t[1]=0,t[2]=0),t[0]=1,t[3]=1,t},t.createCommonjsModule=e,t.createExpression=Or,t.createLayout=oi,t.createStyleLayer=function(t){return\"custom\"===t.type?new js(t):new Us[t.type](t)},t.deepEqual=o,t.ease=l,t.emitValidationErrors=mn,t.endsWith=m,t.enforceCacheSizeLimit=function(t){self.caches&&self.caches.open(ft).then(function(e){e.keys().then(function(r){for(var n=0;n<r.length-t;n++)e.delete(r[n])})})},t.evaluateRadialOffset=wc,t.evaluateSizeForFeature=ks,t.evaluateSizeForZoom=Ts,t.evented=Nn,t.extend=h,t.featureFilter=Gr,t.filterObject=x,t.fromRotation=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=r,t[2]=0,t[3]=-r,t[4]=n,t[5]=0,t[6]=0,t[7]=0,t[8]=1,t},t.getAnchorAlignment=ec,t.getAnchorJustification=kc,t.getArrayBuffer=Mt,t.getImage=Et,t.getJSON=function(t,e){return At(h(t,{type:\"json\"}),e)},t.getReferrer=_t,t.getVideo=function(t,e){var r,n,i=self.document.createElement(\"video\");i.muted=!0,i.onloadstart=function(){e(null,i)};for(var a=0;a<t.length;a++){var o=self.document.createElement(\"source\");r=t[a],n=void 0,(n=self.document.createElement(\"a\")).href=r,(n.protocol!==self.document.location.protocol||n.host!==self.document.location.host)&&(i.crossOrigin=\"Anonymous\"),o.src=t[a],i.appendChild(o)}return{cancel:function(){}}},t.identity=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t},t.invert=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],g=e[13],v=e[14],m=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,k=i*c-a*l,T=u*g-h*d,A=u*v-f*d,M=u*m-p*d,S=h*v-f*g,E=h*m-p*g,C=f*m-p*v,L=y*C-x*E+b*S+_*M-w*A+k*T;return L?(L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(i*E-n*C-a*S)*L,t[2]=(g*k-v*w+m*_)*L,t[3]=(f*w-h*k-p*_)*L,t[4]=(l*M-o*C-c*A)*L,t[5]=(r*C-i*M+a*A)*L,t[6]=(v*b-d*k-m*x)*L,t[7]=(u*k-f*b+p*x)*L,t[8]=(o*E-s*M+c*T)*L,t[9]=(n*M-r*E-a*T)*L,t[10]=(d*w-g*b+m*y)*L,t[11]=(h*b-u*w-p*y)*L,t[12]=(s*A-o*S-l*T)*L,t[13]=(r*S-n*A+i*T)*L,t[14]=(g*x-d*_-v*y)*L,t[15]=(u*_-h*x+f*y)*L,t):null},t.isChar=En,t.isMapboxURL=q,t.keysDifference=function(t,e){var r=[];for(var n in t)n in e||r.push(n);return r},t.makeRequest=At,t.mapObject=y,t.mercatorXfromLng=Ml,t.mercatorYfromLat=Sl,t.mercatorZfromAltitude=El,t.multiply=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],g=e[12],v=e[13],m=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*h+w*g,t[1]=x*i+b*l+_*f+w*v,t[2]=x*a+b*c+_*p+w*m,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*h+w*g,t[5]=x*i+b*l+_*f+w*v,t[6]=x*a+b*c+_*p+w*m,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*h+w*g,t[9]=x*i+b*l+_*f+w*v,t[10]=x*a+b*c+_*p+w*m,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*h+w*g,t[13]=x*i+b*l+_*f+w*v,t[14]=x*a+b*c+_*p+w*m,t[15]=x*o+b*u+_*d+w*y,t},t.mvt=Vo,t.number=Ee,t.ortho=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t},t.parseGlyphPBF=function(t){return new Qs(t).readFields(ml,[])},t.pbf=Qs,t.performSymbolLayout=function(t,e,r,n,i,a){t.createArrays();var o=512*t.overscaling;t.tilePixelRatio=ha/o,t.compareText={},t.iconsNeedLinear=!1;var s=t.layers[0].layout,l=t.layers[0]._unevaluatedLayout._values,c={};if(\"composite\"===t.textSizeData.kind){var u=t.textSizeData,h=u.minZoom,f=u.maxZoom;c.compositeTextSizes=[l[\"text-size\"].possiblyEvaluate(new Un(h)),l[\"text-size\"].possiblyEvaluate(new Un(f))]}if(\"composite\"===t.iconSizeData.kind){var p=t.iconSizeData,d=p.minZoom,g=p.maxZoom;c.compositeIconSizes=[l[\"icon-size\"].possiblyEvaluate(new Un(d)),l[\"icon-size\"].possiblyEvaluate(new Un(g))]}c.layoutTextSize=l[\"text-size\"].possiblyEvaluate(new Un(t.zoom+1)),c.layoutIconSize=l[\"icon-size\"].possiblyEvaluate(new Un(t.zoom+1)),c.textMaxSize=l[\"text-size\"].possiblyEvaluate(new Un(18));for(var v=s.get(\"text-line-height\")*Gl,m=\"map\"===s.get(\"text-rotation-alignment\")&&\"point\"!==s.get(\"symbol-placement\"),y=s.get(\"text-keep-upright\"),x=0,b=t.features;x<b.length;x+=1){var _=b[x],k=s.get(\"text-font\").evaluate(_,{}).join(\",\"),T=r,A={horizontal:{},vertical:void 0},M=_.text,S=[0,0];if(M){var E=M.toString(),C=s.get(\"text-letter-spacing\").evaluate(_,{})*Gl,L=Ln(E)?C:0,P=s.get(\"text-anchor\").evaluate(_,{}),O=s.get(\"text-variable-anchor\"),z=s.get(\"text-radial-offset\").evaluate(_,{});O||(S=z?wc(P,z*Gl):s.get(\"text-offset\").evaluate(_,{}).map(function(t){return t*Gl}));var I=m?\"center\":s.get(\"text-justify\").evaluate(_,{}),D=\"point\"===s.get(\"symbol-placement\")?s.get(\"text-max-width\").evaluate(_,{})*Gl:0;if(!m&&O)for(var R=\"auto\"===I?O.map(function(t){return kc(t)}):[I],F=!1,B=0;B<R.length;B++){var N=R[B];if(!A.horizontal[N])if(F)A.horizontal[N]=A.horizontal[0];else{var j=Xl(M,e,k,D,v,\"center\",N,L,S,Yl.horizontal);j&&(A.horizontal[N]=j,F=1===j.lineCount)}}else{\"auto\"===I&&(I=kc(P));var U=Xl(M,e,k,D,v,P,I,L,S,Yl.horizontal);U&&(A.horizontal[I]=U),Cn(E)&&m&&y&&(A.vertical=Xl(M,e,k,D,v,P,I,L,S,Yl.vertical))}}var V=void 0;if(_.icon){var q=n[_.icon];q&&(V=nc(i[_.icon],s.get(\"icon-offset\").evaluate(_,{}),s.get(\"icon-anchor\").evaluate(_,{})),void 0===t.sdfIcons?t.sdfIcons=q.sdf:t.sdfIcons!==q.sdf&&w(\"Style sheet warning: Cannot mix SDF and non-SDF icons in one buffer\"),q.pixelRatio!==t.pixelRatio?t.iconsNeedLinear=!0:0!==s.get(\"icon-rotate\").constantOr(1)&&(t.iconsNeedLinear=!0))}(Object.keys(A.horizontal).length||V)&&Tc(t,_,A,V,T,c,S)}a&&t.generateCollisionDebugBuffers()},t.perspective=function(t,e,r,n,i){var a,o=1/Math.tan(e/2);return t[0]=o/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=o,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=-1,t[12]=0,t[13]=0,t[15]=0,null!=i&&i!==1/0?(a=1/(n-i),t[10]=(i+n)*a,t[14]=2*i*n*a):(t[10]=-1,t[14]=-2*n),t},t.pick=function(t,e){for(var r={},n=0;n<e.length;n++){var i=e[n];i in t&&(r[i]=t[i])}return r},t.plugin=jn,t.polygonIntersectsPolygon=va,t.postMapLoadEvent=ht,t.postTurnstileEvent=ct,t.potpack=Vs,t.rasterBoundsAttributes=Rl,t.refProperties=[\"type\",\"source\",\"source-layer\",\"minzoom\",\"maxzoom\",\"filter\",\"layout\"],t.register=kn,t.registerForPluginAvailability=function(t){return Fn?t({pluginURL:Fn,completionCallback:Dn}):Nn.once(\"pluginAvailable\",t),t},t.rotate=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=Math.sin(r),l=Math.cos(r);return t[0]=n*l+a*s,t[1]=i*l+o*s,t[2]=n*-s+a*l,t[3]=i*-s+o*l,t},t.rotateX=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];return e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+h*n,t[7]=l*i+f*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=h*i-s*n,t[11]=f*i-l*n,t},t.rotateZ=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];return e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+h*n,t[3]=l*i+f*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=h*i-s*n,t[7]=f*i-l*n,t},t.scale=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t},t.setCacheLimits=function(t,e){pt=t,dt=e},t.setRTLTextPlugin=function(t,e){if(Rn)throw new Error(\"setRTLTextPlugin cannot be called multiple times.\");Rn=!0,Fn=z.resolveURL(t),Dn=function(t){t?(Rn=!1,Fn=null,e&&e(t)):Bn=!0},Nn.fire(new Pt(\"pluginAvailable\",{pluginURL:Fn,completionCallback:Dn}))},t.sphericalToCartesian=function(t){var e=t[0],r=t[1],n=t[2];return r+=90,r*=Math.PI/180,n*=Math.PI/180,{x:e*Math.cos(r)*Math.sin(n),y:e*Math.sin(r)*Math.sin(n),z:e*Math.cos(n)}},t.styleSpec=It,t.symbolSize=As,t.transformMat3=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t},t.transformMat4=Da,t.translate=function(t,e,r){var n,i,a,o,s,l,c,u,h,f,p,d,g=r[0],v=r[1],m=r[2];return e===t?(t[12]=e[0]*g+e[4]*v+e[8]*m+e[12],t[13]=e[1]*g+e[5]*v+e[9]*m+e[13],t[14]=e[2]*g+e[6]*v+e[10]*m+e[14],t[15]=e[3]*g+e[7]*v+e[11]*m+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*g+s*v+h*m+e[12],t[13]=i*g+l*v+f*m+e[13],t[14]=a*g+c*v+p*m+e[14],t[15]=o*g+u*v+d*m+e[15]),t},t.uniqueId=p,t.validateCustomStyleLayer=function(t){var e=[],r=t.id;return void 0===r&&e.push({message:\"layers.\"+r+': missing required property \"id\"'}),void 0===t.render&&e.push({message:\"layers.\"+r+': missing required method \"render\"'}),t.renderingMode&&\"2d\"!==t.renderingMode&&\"3d\"!==t.renderingMode&&e.push({message:\"layers.\"+r+': property \"renderingMode\" must be either \"2d\" or \"3d\"'}),e},t.validateLight=dn,t.validateStyle=pn,t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.vectorTile=Vo,t.version=\"1.1.1\",t.warnOnce=w,t.webpSupported=D,t.window=self,t.wrap=u}),n(0,function(t){function e(t){var r=typeof t;if(\"number\"===r||\"boolean\"===r||\"string\"===r||null==t)return JSON.stringify(t);if(Array.isArray(t)){for(var n=\"[\",i=0,a=t;i<a.length;i+=1)n+=e(a[i])+\",\";return n+\"]\"}for(var o=Object.keys(t).sort(),s=\"{\",l=0;l<o.length;l++)s+=JSON.stringify(o[l])+\":\"+e(t[o[l]])+\",\";return s+\"}\"}function r(r){for(var n=\"\",i=0,a=t.refProperties;i<a.length;i+=1)n+=\"/\"+e(r[a[i]]);return n}var n=function(t){this.keyCache={},t&&this.replace(t)};n.prototype.replace=function(t){this._layerConfigs={},this._layers={},this.update(t,[])},n.prototype.update=function(e,n){for(var i=this,a=0,o=e;a<o.length;a+=1){var s=o[a];this._layerConfigs[s.id]=s;var l=this._layers[s.id]=t.createStyleLayer(s);l._featureFilter=t.featureFilter(l.filter),this.keyCache[s.id]&&delete this.keyCache[s.id]}for(var c=0,u=n;c<u.length;c+=1){var h=u[c];delete this.keyCache[h],delete this._layerConfigs[h],delete this._layers[h]}this.familiesBySource={};for(var f=0,p=function(t,e){for(var n={},i=0;i<t.length;i++){var a=e&&e[t[i].id]||r(t[i]);e&&(e[t[i].id]=a);var o=n[a];o||(o=n[a]=[]),o.push(t[i])}var s=[];for(var l in n)s.push(n[l]);return s}(t.values(this._layerConfigs),this.keyCache);f<p.length;f+=1){var d=p[f].map(function(t){return i._layers[t.id]}),g=d[0];if(\"none\"!==g.visibility){var v=g.source||\"\",m=this.familiesBySource[v];m||(m=this.familiesBySource[v]={});var y=g.sourceLayer||\"_geojsonTileLayer\",x=m[y];x||(x=m[y]=[]),x.push(d)}}};var i=function(e){var r={},n=[];for(var i in e){var a=e[i],o=r[i]={};for(var s in a){var l=a[+s];if(l&&0!==l.bitmap.width&&0!==l.bitmap.height){var c={x:0,y:0,w:l.bitmap.width+2,h:l.bitmap.height+2};n.push(c),o[s]={rect:c,metrics:l.metrics}}}}var u=t.potpack(n),h=u.w,f=u.h,p=new t.AlphaImage({width:h||1,height:f||1});for(var d in e){var g=e[d];for(var v in g){var m=g[+v];if(m&&0!==m.bitmap.width&&0!==m.bitmap.height){var y=r[d][v].rect;t.AlphaImage.copy(m.bitmap,p,{x:0,y:0},{x:y.x+1,y:y.y+1},m.bitmap)}}}this.image=p,this.positions=r};t.register(\"GlyphAtlas\",i);var a=function(e){this.tileID=new t.OverscaledTileID(e.tileID.overscaledZ,e.tileID.wrap,e.tileID.canonical.z,e.tileID.canonical.x,e.tileID.canonical.y),this.uid=e.uid,this.zoom=e.zoom,this.pixelRatio=e.pixelRatio,this.tileSize=e.tileSize,this.source=e.source,this.overscaling=this.tileID.overscaleFactor(),this.showCollisionBoxes=e.showCollisionBoxes,this.collectResourceTiming=!!e.collectResourceTiming,this.returnDependencies=!!e.returnDependencies};function o(e,r){for(var n=new t.EvaluationParameters(r),i=0,a=e;i<a.length;i+=1)a[i].recalculate(n)}a.prototype.parse=function(e,r,n,a){var s=this;this.status=\"parsing\",this.data=e,this.collisionBoxArray=new t.CollisionBoxArray;var l=new t.DictionaryCoder(Object.keys(e.layers).sort()),c=new t.FeatureIndex(this.tileID);c.bucketLayerIDs=[];var u,h,f,p,d={},g={featureIndex:c,iconDependencies:{},patternDependencies:{},glyphDependencies:{}},v=r.familiesBySource[this.source];for(var m in v){var y=e.layers[m];if(y){1===y.version&&t.warnOnce('Vector tile source \"'+this.source+'\" layer \"'+m+'\" does not use vector tile spec v2 and therefore may have some rendering errors.');for(var x=l.encode(m),b=[],_=0;_<y.length;_++){var w=y.feature(_);b.push({feature:w,index:_,sourceLayerIndex:x})}for(var k=0,T=v[m];k<T.length;k+=1){var A=T[k],M=A[0];M.minzoom&&this.zoom<Math.floor(M.minzoom)||M.maxzoom&&this.zoom>=M.maxzoom||\"none\"!==M.visibility&&(o(A,this.zoom),(d[M.id]=M.createBucket({index:c.bucketLayerIDs.length,layers:A,zoom:this.zoom,pixelRatio:this.pixelRatio,overscaling:this.overscaling,collisionBoxArray:this.collisionBoxArray,sourceLayerIndex:x,sourceID:this.source})).populate(b,g),c.bucketLayerIDs.push(A.map(function(t){return t.id})))}}}var S=t.mapObject(g.glyphDependencies,function(t){return Object.keys(t).map(Number)});Object.keys(S).length?n.send(\"getGlyphs\",{uid:this.uid,stacks:S},function(t,e){u||(u=t,h=e,L.call(s))}):h={};var E=Object.keys(g.iconDependencies);E.length?n.send(\"getImages\",{icons:E},function(t,e){u||(u=t,f=e,L.call(s))}):f={};var C=Object.keys(g.patternDependencies);function L(){if(u)return a(u);if(h&&f&&p){var e=new i(h),r=new t.ImageAtlas(f,p);for(var n in d){var s=d[n];s instanceof t.SymbolBucket?(o(s.layers,this.zoom),t.performSymbolLayout(s,h,e.positions,f,r.iconPositions,this.showCollisionBoxes)):s.hasPattern&&(s instanceof t.LineBucket||s instanceof t.FillBucket||s instanceof t.FillExtrusionBucket)&&(o(s.layers,this.zoom),s.addFeatures(g,r.patternPositions))}this.status=\"done\",a(null,{buckets:t.values(d).filter(function(t){return!t.isEmpty()}),featureIndex:c,collisionBoxArray:this.collisionBoxArray,glyphAtlasImage:e.image,imageAtlas:r,glyphMap:this.returnDependencies?h:null,iconMap:this.returnDependencies?f:null,glyphPositions:this.returnDependencies?e.positions:null})}}C.length?n.send(\"getImages\",{icons:C},function(t,e){u||(u=t,p=e,L.call(s))}):p={},L.call(this)};var s=\"undefined\"!=typeof performance,l={getEntriesByName:function(t){return!!(s&&performance&&performance.getEntriesByName)&&performance.getEntriesByName(t)},mark:function(t){return!!(s&&performance&&performance.mark)&&performance.mark(t)},measure:function(t,e,r){return!!(s&&performance&&performance.measure)&&performance.measure(t,e,r)},clearMarks:function(t){return!!(s&&performance&&performance.clearMarks)&&performance.clearMarks(t)},clearMeasures:function(t){return!!(s&&performance&&performance.clearMeasures)&&performance.clearMeasures(t)}},c=function(t){this._marks={start:[t.url,\"start\"].join(\"#\"),end:[t.url,\"end\"].join(\"#\"),measure:t.url.toString()},l.mark(this._marks.start)};function u(e,r){var n=t.getArrayBuffer(e.request,function(e,n,i,a){e?r(e):n&&r(null,{vectorTile:new t.vectorTile.VectorTile(new t.pbf(n)),rawData:n,cacheControl:i,expires:a})});return function(){n.cancel(),r()}}c.prototype.finish=function(){l.mark(this._marks.end);var t=l.getEntriesByName(this._marks.measure);return 0===t.length&&(l.measure(this._marks.measure,this._marks.start,this._marks.end),t=l.getEntriesByName(this._marks.measure),l.clearMarks(this._marks.start),l.clearMarks(this._marks.end),l.clearMeasures(this._marks.measure)),t},l.Performance=c;var h=function(t,e,r){this.actor=t,this.layerIndex=e,this.loadVectorData=r||u,this.loading={},this.loaded={}};h.prototype.loadTile=function(e,r){var n=this,i=e.uid;this.loading||(this.loading={});var o=!!(e&&e.request&&e.request.collectResourceTiming)&&new l.Performance(e.request),s=this.loading[i]=new a(e);s.abort=this.loadVectorData(e,function(e,a){if(delete n.loading[i],e||!a)return s.status=\"done\",n.loaded[i]=s,r(e);var l=a.rawData,c={};a.expires&&(c.expires=a.expires),a.cacheControl&&(c.cacheControl=a.cacheControl);var u={};if(o){var h=o.finish();h&&(u.resourceTiming=JSON.parse(JSON.stringify(h)))}s.vectorTile=a.vectorTile,s.parse(a.vectorTile,n.layerIndex,n.actor,function(e,n){if(e||!n)return r(e);r(null,t.extend({rawTileData:l.slice(0)},n,c,u))}),n.loaded=n.loaded||{},n.loaded[i]=s})},h.prototype.reloadTile=function(t,e){var r=this.loaded,n=t.uid,i=this;if(r&&r[n]){var a=r[n];a.showCollisionBoxes=t.showCollisionBoxes;var o=function(t,r){var n=a.reloadCallback;n&&(delete a.reloadCallback,a.parse(a.vectorTile,i.layerIndex,i.actor,n)),e(t,r)};\"parsing\"===a.status?a.reloadCallback=o:\"done\"===a.status&&(a.vectorTile?a.parse(a.vectorTile,this.layerIndex,this.actor,o):o())}},h.prototype.abortTile=function(t,e){var r=this.loading,n=t.uid;r&&r[n]&&r[n].abort&&(r[n].abort(),delete r[n]),e()},h.prototype.removeTile=function(t,e){var r=this.loaded,n=t.uid;r&&r[n]&&delete r[n],e()};var f=function(){this.loaded={}};f.prototype.loadTile=function(e,r){var n=e.uid,i=e.encoding,a=e.rawImageData,o=new t.DEMData(n,a,i);this.loaded=this.loaded||{},this.loaded[n]=o,r(null,o)},f.prototype.removeTile=function(t){var e=this.loaded,r=t.uid;e&&e[r]&&delete e[r]};var p={RADIUS:6378137,FLATTENING:1/298.257223563,POLAR_RADIUS:6356752.3142};function d(t){var e=0;if(t&&t.length>0){e+=Math.abs(g(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(g(t[r]))}return e}function g(t){var e,r,n,i,a,o,s=0,l=t.length;if(l>2){for(o=0;o<l;o++)o===l-2?(n=l-2,i=l-1,a=0):o===l-1?(n=l-1,i=0,a=1):(n=o,i=o+1,a=o+2),e=t[n],r=t[i],s+=(v(t[a][0])-v(e[0]))*Math.sin(v(r[1]));s=s*p.RADIUS*p.RADIUS/2}return s}function v(t){return t*Math.PI/180}var m={geometry:function t(e){var r,n=0;switch(e.type){case\"Polygon\":return d(e.coordinates);case\"MultiPolygon\":for(r=0;r<e.coordinates.length;r++)n+=d(e.coordinates[r]);return n;case\"Point\":case\"MultiPoint\":case\"LineString\":case\"MultiLineString\":return 0;case\"GeometryCollection\":for(r=0;r<e.geometries.length;r++)n+=t(e.geometries[r]);return n}},ring:g};function y(t,e){return function(r){return t(r,e)}}function x(t,e){e=!!e,t[0]=b(t[0],e);for(var r=1;r<t.length;r++)t[r]=b(t[r],!e);return t}function b(t,e){return function(t){return m.ring(t)>=0}(t)===e?t:t.reverse()}var _=t.vectorTile.VectorTileFeature.prototype.toGeoJSON,w=function(e){this._feature=e,this.extent=t.EXTENT,this.type=e.type,this.properties=e.tags,\"id\"in e&&!isNaN(e.id)&&(this.id=parseInt(e.id,10))};w.prototype.loadGeometry=function(){if(1===this._feature.type){for(var e=[],r=0,n=this._feature.geometry;r<n.length;r+=1){var i=n[r];e.push([new t.Point$1(i[0],i[1])])}return e}for(var a=[],o=0,s=this._feature.geometry;o<s.length;o+=1){for(var l=[],c=0,u=s[o];c<u.length;c+=1){var h=u[c];l.push(new t.Point$1(h[0],h[1]))}a.push(l)}return a},w.prototype.toGeoJSON=function(t,e,r){return _.call(this,t,e,r)};var k=function(e){this.layers={_geojsonTileLayer:this},this.name=\"_geojsonTileLayer\",this.extent=t.EXTENT,this.length=e.length,this._features=e};k.prototype.feature=function(t){return new w(this._features[t])};var T=t.vectorTile.VectorTileFeature,A=M;function M(t,e){this.options=e||{},this.features=t,this.length=t.length}function S(t,e){this.id=\"number\"==typeof t.id?t.id:void 0,this.type=t.type,this.rawGeometry=1===t.type?[t.geometry]:t.geometry,this.properties=t.tags,this.extent=e||4096}M.prototype.feature=function(t){return new S(this.features[t],this.options.extent)},S.prototype.loadGeometry=function(){var e=this.rawGeometry;this.geometry=[];for(var r=0;r<e.length;r++){for(var n=e[r],i=[],a=0;a<n.length;a++)i.push(new t.Point$1(n[a][0],n[a][1]));this.geometry.push(i)}return this.geometry},S.prototype.bbox=function(){this.geometry||this.loadGeometry();for(var t=this.geometry,e=1/0,r=-1/0,n=1/0,i=-1/0,a=0;a<t.length;a++)for(var o=t[a],s=0;s<o.length;s++){var l=o[s];e=Math.min(e,l.x),r=Math.max(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.y)}return[e,n,r,i]},S.prototype.toGeoJSON=T.prototype.toGeoJSON;var E=P,C=P,L=A;function P(e){var r=new t.pbf;return function(t,e){for(var r in t.layers)e.writeMessage(3,O,t.layers[r])}(e,r),r.finish()}function O(t,e){var r;e.writeVarintField(15,t.version||1),e.writeStringField(1,t.name||\"\"),e.writeVarintField(5,t.extent||4096);var n={keys:[],values:[],keycache:{},valuecache:{}};for(r=0;r<t.length;r++)n.feature=t.feature(r),e.writeMessage(2,z,n);var i=n.keys;for(r=0;r<i.length;r++)e.writeStringField(3,i[r]);var a=n.values;for(r=0;r<a.length;r++)e.writeMessage(4,B,a[r])}function z(t,e){var r=t.feature;void 0!==r.id&&e.writeVarintField(1,r.id),e.writeMessage(2,I,t),e.writeVarintField(3,r.type),e.writeMessage(4,F,r)}function I(t,e){var r=t.feature,n=t.keys,i=t.values,a=t.keycache,o=t.valuecache;for(var s in r.properties){var l=a[s];void 0===l&&(n.push(s),l=n.length-1,a[s]=l),e.writeVarint(l);var c=r.properties[s],u=typeof c;\"string\"!==u&&\"boolean\"!==u&&\"number\"!==u&&(c=JSON.stringify(c));var h=u+\":\"+c,f=o[h];void 0===f&&(i.push(c),f=i.length-1,o[h]=f),e.writeVarint(f)}}function D(t,e){return(e<<3)+(7&t)}function R(t){return t<<1^t>>31}function F(t,e){for(var r=t.loadGeometry(),n=t.type,i=0,a=0,o=r.length,s=0;s<o;s++){var l=r[s],c=1;1===n&&(c=l.length),e.writeVarint(D(1,c));for(var u=3===n?l.length-1:l.length,h=0;h<u;h++){1===h&&1!==n&&e.writeVarint(D(2,u-1));var f=l[h].x-i,p=l[h].y-a;e.writeVarint(R(f)),e.writeVarint(R(p)),i+=f,a+=p}3===n&&e.writeVarint(D(7,1))}}function B(t,e){var r=typeof t;\"string\"===r?e.writeStringField(1,t):\"boolean\"===r?e.writeBooleanField(7,t):\"number\"===r&&(t%1!=0?e.writeDoubleField(3,t):t<0?e.writeSVarintField(6,t):e.writeVarintField(5,t))}function N(t,e,r,n){j(t,r,n),j(e,2*r,2*n),j(e,2*r+1,2*n+1)}function j(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function U(t,e,r,n){var i=t-r,a=e-n;return i*i+a*a}E.fromVectorTileJs=C,E.fromGeojsonVt=function(t,e){e=e||{};var r={};for(var n in t)r[n]=new A(t[n].features,e),r[n].name=n,r[n].version=e.version,r[n].extent=e.extent;return P({layers:r})},E.GeoJSONWrapper=L;var V=function(t){return t[0]},q=function(t){return t[1]},H=function(t,e,r,n,i){void 0===e&&(e=V),void 0===r&&(r=q),void 0===n&&(n=64),void 0===i&&(i=Float64Array),this.nodeSize=n,this.points=t;for(var a=t.length<65536?Uint16Array:Uint32Array,o=this.ids=new a(t.length),s=this.coords=new i(2*t.length),l=0;l<t.length;l++)o[l]=l,s[2*l]=e(t[l]),s[2*l+1]=r(t[l]);!function t(e,r,n,i,a,o){if(!(a-i<=n)){var s=i+a>>1;!function t(e,r,n,i,a,o){for(;a>i;){if(a-i>600){var s=a-i+1,l=n-i+1,c=Math.log(s),u=.5*Math.exp(2*c/3),h=.5*Math.sqrt(c*u*(s-u)/s)*(l-s/2<0?-1:1);t(e,r,n,Math.max(i,Math.floor(n-l*u/s+h)),Math.min(a,Math.floor(n+(s-l)*u/s+h)),o)}var f=r[2*n+o],p=i,d=a;for(N(e,r,i,n),r[2*a+o]>f&&N(e,r,i,a);p<d;){for(N(e,r,p,d),p++,d--;r[2*p+o]<f;)p++;for(;r[2*d+o]>f;)d--}r[2*i+o]===f?N(e,r,i,d):N(e,r,++d,a),d<=n&&(i=d+1),n<=d&&(a=d-1)}}(e,r,s,i,a,o%2),t(e,r,n,i,s-1,o+1),t(e,r,n,s+1,a,o+1)}}(o,s,n,0,o.length-1,0)};H.prototype.range=function(t,e,r,n){return function(t,e,r,n,i,a,o){for(var s,l,c=[0,t.length-1,0],u=[];c.length;){var h=c.pop(),f=c.pop(),p=c.pop();if(f-p<=o)for(var d=p;d<=f;d++)s=e[2*d],l=e[2*d+1],s>=r&&s<=i&&l>=n&&l<=a&&u.push(t[d]);else{var g=Math.floor((p+f)/2);s=e[2*g],l=e[2*g+1],s>=r&&s<=i&&l>=n&&l<=a&&u.push(t[g]);var v=(h+1)%2;(0===h?r<=s:n<=l)&&(c.push(p),c.push(g-1),c.push(v)),(0===h?i>=s:a>=l)&&(c.push(g+1),c.push(f),c.push(v))}}return u}(this.ids,this.coords,t,e,r,n,this.nodeSize)},H.prototype.within=function(t,e,r){return function(t,e,r,n,i,a){for(var o=[0,t.length-1,0],s=[],l=i*i;o.length;){var c=o.pop(),u=o.pop(),h=o.pop();if(u-h<=a)for(var f=h;f<=u;f++)U(e[2*f],e[2*f+1],r,n)<=l&&s.push(t[f]);else{var p=Math.floor((h+u)/2),d=e[2*p],g=e[2*p+1];U(d,g,r,n)<=l&&s.push(t[p]);var v=(c+1)%2;(0===c?r-i<=d:n-i<=g)&&(o.push(h),o.push(p-1),o.push(v)),(0===c?r+i>=d:n+i>=g)&&(o.push(p+1),o.push(u),o.push(v))}}return s}(this.ids,this.coords,t,e,r,this.nodeSize)};var G={minZoom:0,maxZoom:16,radius:40,extent:512,nodeSize:64,log:!1,reduce:null,map:function(t){return t}},Y=function(t){this.options=Q(Object.create(G),t),this.trees=new Array(this.options.maxZoom+1)};function W(t,e,r,n,i){return{x:t,y:e,zoom:1/0,id:r,parentId:-1,numPoints:n,properties:i}}function X(t,e){var r=t.geometry.coordinates,n=r[0],i=r[1];return{x:K(n),y:$(i),zoom:1/0,index:e,parentId:-1}}function Z(t){return{type:\"Feature\",id:t.id,properties:J(t),geometry:{type:\"Point\",coordinates:[(n=t.x,360*(n-.5)),(e=t.y,r=(180-360*e)*Math.PI/180,360*Math.atan(Math.exp(r))/Math.PI-90)]}};var e,r,n}function J(t){var e=t.numPoints,r=e>=1e4?Math.round(e/1e3)+\"k\":e>=1e3?Math.round(e/100)/10+\"k\":e;return Q(Q({},t.properties),{cluster:!0,cluster_id:t.id,point_count:e,point_count_abbreviated:r})}function K(t){return t/360+.5}function $(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function Q(t,e){for(var r in e)t[r]=e[r];return t}function tt(t){return t.x}function et(t){return t.y}function rt(t,e,r,n,i,a){var o=i-r,s=a-n;if(0!==o||0!==s){var l=((t-r)*o+(e-n)*s)/(o*o+s*s);l>1?(r=i,n=a):l>0&&(r+=o*l,n+=s*l)}return(o=t-r)*o+(s=e-n)*s}function nt(t,e,r,n){var i={id:void 0===t?null:t,type:e,geometry:r,tags:n,minX:1/0,minY:1/0,maxX:-1/0,maxY:-1/0};return function(t){var e=t.geometry,r=t.type;if(\"Point\"===r||\"MultiPoint\"===r||\"LineString\"===r)it(t,e);else if(\"Polygon\"===r||\"MultiLineString\"===r)for(var n=0;n<e.length;n++)it(t,e[n]);else if(\"MultiPolygon\"===r)for(n=0;n<e.length;n++)for(var i=0;i<e[n].length;i++)it(t,e[n][i])}(i),i}function it(t,e){for(var r=0;r<e.length;r+=3)t.minX=Math.min(t.minX,e[r]),t.minY=Math.min(t.minY,e[r+1]),t.maxX=Math.max(t.maxX,e[r]),t.maxY=Math.max(t.maxY,e[r+1])}function at(t,e,r,n){if(e.geometry){var i=e.geometry.coordinates,a=e.geometry.type,o=Math.pow(r.tolerance/((1<<r.maxZoom)*r.extent),2),s=[],l=e.id;if(r.promoteId?l=e.properties[r.promoteId]:r.generateId&&(l=n||0),\"Point\"===a)ot(i,s);else if(\"MultiPoint\"===a)for(var c=0;c<i.length;c++)ot(i[c],s);else if(\"LineString\"===a)st(i,s,o,!1);else if(\"MultiLineString\"===a){if(r.lineMetrics){for(c=0;c<i.length;c++)s=[],st(i[c],s,o,!1),t.push(nt(l,\"LineString\",s,e.properties));return}lt(i,s,o,!1)}else if(\"Polygon\"===a)lt(i,s,o,!0);else{if(\"MultiPolygon\"!==a){if(\"GeometryCollection\"===a){for(c=0;c<e.geometry.geometries.length;c++)at(t,{id:l,geometry:e.geometry.geometries[c],properties:e.properties},r,n);return}throw new Error(\"Input data is not a valid GeoJSON object.\")}for(c=0;c<i.length;c++){var u=[];lt(i[c],u,o,!0),s.push(u)}}t.push(nt(l,a,s,e.properties))}}function ot(t,e){e.push(ct(t[0])),e.push(ut(t[1])),e.push(0)}function st(t,e,r,n){for(var i,a,o=0,s=0;s<t.length;s++){var l=ct(t[s][0]),c=ut(t[s][1]);e.push(l),e.push(c),e.push(0),s>0&&(o+=n?(i*c-l*a)/2:Math.sqrt(Math.pow(l-i,2)+Math.pow(c-a,2))),i=l,a=c}var u=e.length-3;e[2]=1,function t(e,r,n,i){for(var a,o=i,s=n-r>>1,l=n-r,c=e[r],u=e[r+1],h=e[n],f=e[n+1],p=r+3;p<n;p+=3){var d=rt(e[p],e[p+1],c,u,h,f);if(d>o)a=p,o=d;else if(d===o){var g=Math.abs(p-s);g<l&&(a=p,l=g)}}o>i&&(a-r>3&&t(e,r,a,i),e[a+2]=o,n-a>3&&t(e,a,n,i))}(e,0,u,r),e[u+2]=1,e.size=Math.abs(o),e.start=0,e.end=e.size}function lt(t,e,r,n){for(var i=0;i<t.length;i++){var a=[];st(t[i],a,r,n),e.push(a)}}function ct(t){return t/360+.5}function ut(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function ht(t,e,r,n,i,a,o,s){if(n/=e,a>=(r/=e)&&o<n)return t;if(o<r||a>=n)return null;for(var l=[],c=0;c<t.length;c++){var u=t[c],h=u.geometry,f=u.type,p=0===i?u.minX:u.minY,d=0===i?u.maxX:u.maxY;if(p>=r&&d<n)l.push(u);else if(!(d<r||p>=n)){var g=[];if(\"Point\"===f||\"MultiPoint\"===f)ft(h,g,r,n,i);else if(\"LineString\"===f)pt(h,g,r,n,i,!1,s.lineMetrics);else if(\"MultiLineString\"===f)gt(h,g,r,n,i,!1);else if(\"Polygon\"===f)gt(h,g,r,n,i,!0);else if(\"MultiPolygon\"===f)for(var v=0;v<h.length;v++){var m=[];gt(h[v],m,r,n,i,!0),m.length&&g.push(m)}if(g.length){if(s.lineMetrics&&\"LineString\"===f){for(v=0;v<g.length;v++)l.push(nt(u.id,f,g[v],u.tags));continue}\"LineString\"!==f&&\"MultiLineString\"!==f||(1===g.length?(f=\"LineString\",g=g[0]):f=\"MultiLineString\"),\"Point\"!==f&&\"MultiPoint\"!==f||(f=3===g.length?\"Point\":\"MultiPoint\"),l.push(nt(u.id,f,g,u.tags))}}}return l.length?l:null}function ft(t,e,r,n,i){for(var a=0;a<t.length;a+=3){var o=t[a+i];o>=r&&o<=n&&(e.push(t[a]),e.push(t[a+1]),e.push(t[a+2]))}}function pt(t,e,r,n,i,a,o){for(var s,l,c=dt(t),u=0===i?mt:yt,h=t.start,f=0;f<t.length-3;f+=3){var p=t[f],d=t[f+1],g=t[f+2],v=t[f+3],m=t[f+4],y=0===i?p:d,x=0===i?v:m,b=!1;o&&(s=Math.sqrt(Math.pow(p-v,2)+Math.pow(d-m,2))),y<r?x>r&&(l=u(c,p,d,v,m,r),o&&(c.start=h+s*l)):y>n?x<n&&(l=u(c,p,d,v,m,n),o&&(c.start=h+s*l)):vt(c,p,d,g),x<r&&y>=r&&(l=u(c,p,d,v,m,r),b=!0),x>n&&y<=n&&(l=u(c,p,d,v,m,n),b=!0),!a&&b&&(o&&(c.end=h+s*l),e.push(c),c=dt(t)),o&&(h+=s)}var _=t.length-3;p=t[_],d=t[_+1],g=t[_+2],(y=0===i?p:d)>=r&&y<=n&&vt(c,p,d,g),_=c.length-3,a&&_>=3&&(c[_]!==c[0]||c[_+1]!==c[1])&&vt(c,c[0],c[1],c[2]),c.length&&e.push(c)}function dt(t){var e=[];return e.size=t.size,e.start=t.start,e.end=t.end,e}function gt(t,e,r,n,i,a){for(var o=0;o<t.length;o++)pt(t[o],e,r,n,i,a,!1)}function vt(t,e,r,n){t.push(e),t.push(r),t.push(n)}function mt(t,e,r,n,i,a){var o=(a-e)/(n-e);return t.push(a),t.push(r+(i-r)*o),t.push(1),o}function yt(t,e,r,n,i,a){var o=(a-r)/(i-r);return t.push(e+(n-e)*o),t.push(a),t.push(1),o}function xt(t,e){for(var r=[],n=0;n<t.length;n++){var i,a=t[n],o=a.type;if(\"Point\"===o||\"MultiPoint\"===o||\"LineString\"===o)i=bt(a.geometry,e);else if(\"MultiLineString\"===o||\"Polygon\"===o){i=[];for(var s=0;s<a.geometry.length;s++)i.push(bt(a.geometry[s],e))}else if(\"MultiPolygon\"===o)for(i=[],s=0;s<a.geometry.length;s++){for(var l=[],c=0;c<a.geometry[s].length;c++)l.push(bt(a.geometry[s][c],e));i.push(l)}r.push(nt(a.id,o,i,a.tags))}return r}function bt(t,e){var r=[];r.size=t.size,void 0!==t.start&&(r.start=t.start,r.end=t.end);for(var n=0;n<t.length;n+=3)r.push(t[n]+e,t[n+1],t[n+2]);return r}function _t(t,e){if(t.transformed)return t;var r,n,i,a=1<<t.z,o=t.x,s=t.y;for(r=0;r<t.features.length;r++){var l=t.features[r],c=l.geometry,u=l.type;if(l.geometry=[],1===u)for(n=0;n<c.length;n+=2)l.geometry.push(wt(c[n],c[n+1],e,a,o,s));else for(n=0;n<c.length;n++){var h=[];for(i=0;i<c[n].length;i+=2)h.push(wt(c[n][i],c[n][i+1],e,a,o,s));l.geometry.push(h)}}return t.transformed=!0,t}function wt(t,e,r,n,i,a){return[Math.round(r*(t*n-i)),Math.round(r*(e*n-a))]}function kt(t,e,r,n,i){for(var a=e===i.maxZoom?0:i.tolerance/((1<<e)*i.extent),o={features:[],numPoints:0,numSimplified:0,numFeatures:0,source:null,x:r,y:n,z:e,transformed:!1,minX:2,minY:1,maxX:-1,maxY:0},s=0;s<t.length;s++){o.numFeatures++,Tt(o,t[s],a,i);var l=t[s].minX,c=t[s].minY,u=t[s].maxX,h=t[s].maxY;l<o.minX&&(o.minX=l),c<o.minY&&(o.minY=c),u>o.maxX&&(o.maxX=u),h>o.maxY&&(o.maxY=h)}return o}function Tt(t,e,r,n){var i=e.geometry,a=e.type,o=[];if(\"Point\"===a||\"MultiPoint\"===a)for(var s=0;s<i.length;s+=3)o.push(i[s]),o.push(i[s+1]),t.numPoints++,t.numSimplified++;else if(\"LineString\"===a)At(o,i,t,r,!1,!1);else if(\"MultiLineString\"===a||\"Polygon\"===a)for(s=0;s<i.length;s++)At(o,i[s],t,r,\"Polygon\"===a,0===s);else if(\"MultiPolygon\"===a)for(var l=0;l<i.length;l++){var c=i[l];for(s=0;s<c.length;s++)At(o,c[s],t,r,!0,0===s)}if(o.length){var u=e.tags||null;if(\"LineString\"===a&&n.lineMetrics){for(var h in u={},e.tags)u[h]=e.tags[h];u.mapbox_clip_start=i.start/i.size,u.mapbox_clip_end=i.end/i.size}var f={geometry:o,type:\"Polygon\"===a||\"MultiPolygon\"===a?3:\"LineString\"===a||\"MultiLineString\"===a?2:1,tags:u};null!==e.id&&(f.id=e.id),t.features.push(f)}}function At(t,e,r,n,i,a){var o=n*n;if(n>0&&e.size<(i?o:n))r.numPoints+=e.length/3;else{for(var s=[],l=0;l<e.length;l+=3)(0===n||e[l+2]>o)&&(r.numSimplified++,s.push(e[l]),s.push(e[l+1])),r.numPoints++;i&&function(t,e){for(var r=0,n=0,i=t.length,a=i-2;n<i;a=n,n+=2)r+=(t[n]-t[a])*(t[n+1]+t[a+1]);if(r>0===e)for(n=0,i=t.length;n<i/2;n+=2){var o=t[n],s=t[n+1];t[n]=t[i-2-n],t[n+1]=t[i-1-n],t[i-2-n]=o,t[i-1-n]=s}}(s,a),t.push(s)}}function Mt(t,e){var r=(e=this.options=function(t,e){for(var r in e)t[r]=e[r];return t}(Object.create(this.options),e)).debug;if(r&&console.time(\"preprocess data\"),e.maxZoom<0||e.maxZoom>24)throw new Error(\"maxZoom should be in the 0-24 range\");if(e.promoteId&&e.generateId)throw new Error(\"promoteId and generateId cannot be used together.\");var n=function(t,e){var r=[];if(\"FeatureCollection\"===t.type)for(var n=0;n<t.features.length;n++)at(r,t.features[n],e,n);else\"Feature\"===t.type?at(r,t,e):at(r,{geometry:t},e);return r}(t,e);this.tiles={},this.tileCoords=[],r&&(console.timeEnd(\"preprocess data\"),console.log(\"index: maxZoom: %d, maxPoints: %d\",e.indexMaxZoom,e.indexMaxPoints),console.time(\"generate tiles\"),this.stats={},this.total=0),(n=function(t,e){var r=e.buffer/e.extent,n=t,i=ht(t,1,-1-r,r,0,-1,2,e),a=ht(t,1,1-r,2+r,0,-1,2,e);return(i||a)&&(n=ht(t,1,-r,1+r,0,-1,2,e)||[],i&&(n=xt(i,1).concat(n)),a&&(n=n.concat(xt(a,-1)))),n}(n,e)).length&&this.splitTile(n,0,0,0),r&&(n.length&&console.log(\"features: %d, points: %d\",this.tiles[0].numFeatures,this.tiles[0].numPoints),console.timeEnd(\"generate tiles\"),console.log(\"tiles generated:\",this.total,JSON.stringify(this.stats)))}function St(t,e,r){return 32*((1<<t)*r+e)+t}function Et(t,e){var r=t.tileID.canonical;if(!this._geoJSONIndex)return e(null,null);var n=this._geoJSONIndex.getTile(r.z,r.x,r.y);if(!n)return e(null,null);var i=new k(n.features),a=E(i);0===a.byteOffset&&a.byteLength===a.buffer.byteLength||(a=new Uint8Array(a)),e(null,{vectorTile:i,rawData:a.buffer})}Y.prototype.load=function(t){var e=this.options,r=e.log,n=e.minZoom,i=e.maxZoom,a=e.nodeSize;r&&console.time(\"total time\");var o=\"prepare \"+t.length+\" points\";r&&console.time(o),this.points=t;for(var s=[],l=0;l<t.length;l++)t[l].geometry&&s.push(X(t[l],l));this.trees[i+1]=new H(s,tt,et,a,Float32Array),r&&console.timeEnd(o);for(var c=i;c>=n;c--){var u=+Date.now();s=this._cluster(s,c),this.trees[c]=new H(s,tt,et,a,Float32Array),r&&console.log(\"z%d: %d clusters in %dms\",c,s.length,+Date.now()-u)}return r&&console.timeEnd(\"total time\"),this},Y.prototype.getClusters=function(t,e){var r=((t[0]+180)%360+360)%360-180,n=Math.max(-90,Math.min(90,t[1])),i=180===t[2]?180:((t[2]+180)%360+360)%360-180,a=Math.max(-90,Math.min(90,t[3]));if(t[2]-t[0]>=360)r=-180,i=180;else if(r>i){var o=this.getClusters([r,n,180,a],e),s=this.getClusters([-180,n,i,a],e);return o.concat(s)}for(var l=this.trees[this._limitZoom(e)],c=[],u=0,h=l.range(K(r),$(a),K(i),$(n));u<h.length;u+=1){var f=h[u],p=l.points[f];c.push(p.numPoints?Z(p):this.points[p.index])}return c},Y.prototype.getChildren=function(t){var e=t>>5,r=t%32,n=\"No cluster with the specified id.\",i=this.trees[r];if(!i)throw new Error(n);var a=i.points[e];if(!a)throw new Error(n);for(var o=this.options.radius/(this.options.extent*Math.pow(2,r-1)),s=[],l=0,c=i.within(a.x,a.y,o);l<c.length;l+=1){var u=c[l],h=i.points[u];h.parentId===t&&s.push(h.numPoints?Z(h):this.points[h.index])}if(0===s.length)throw new Error(n);return s},Y.prototype.getLeaves=function(t,e,r){e=e||10,r=r||0;var n=[];return this._appendLeaves(n,t,e,r,0),n},Y.prototype.getTile=function(t,e,r){var n=this.trees[this._limitZoom(t)],i=Math.pow(2,t),a=this.options,o=a.extent,s=a.radius/o,l=(r-s)/i,c=(r+1+s)/i,u={features:[]};return this._addTileFeatures(n.range((e-s)/i,l,(e+1+s)/i,c),n.points,e,r,i,u),0===e&&this._addTileFeatures(n.range(1-s/i,l,1,c),n.points,i,r,i,u),e===i-1&&this._addTileFeatures(n.range(0,l,s/i,c),n.points,-1,r,i,u),u.features.length?u:null},Y.prototype.getClusterExpansionZoom=function(t){for(var e=t%32-1;e<=this.options.maxZoom;){var r=this.getChildren(t);if(e++,1!==r.length)break;t=r[0].properties.cluster_id}return e},Y.prototype._appendLeaves=function(t,e,r,n,i){for(var a=0,o=this.getChildren(e);a<o.length;a+=1){var s=o[a],l=s.properties;if(l&&l.cluster?i+l.point_count<=n?i+=l.point_count:i=this._appendLeaves(t,l.cluster_id,r,n,i):i<n?i++:t.push(s),t.length===r)break}return i},Y.prototype._addTileFeatures=function(t,e,r,n,i,a){for(var o=0,s=t;o<s.length;o+=1){var l=e[s[o]],c={type:1,geometry:[[Math.round(this.options.extent*(l.x*i-r)),Math.round(this.options.extent*(l.y*i-n))]],tags:l.numPoints?J(l):this.points[l.index].properties},u=l.numPoints?l.id:this.points[l.index].id;void 0!==u&&(c.id=u),a.features.push(c)}},Y.prototype._limitZoom=function(t){return Math.max(this.options.minZoom,Math.min(t,this.options.maxZoom+1))},Y.prototype._cluster=function(t,e){for(var r=[],n=this.options,i=n.radius,a=n.extent,o=n.reduce,s=i/(a*Math.pow(2,e)),l=0;l<t.length;l++){var c=t[l];if(!(c.zoom<=e)){c.zoom=e;for(var u=this.trees[e+1],h=u.within(c.x,c.y,s),f=c.numPoints||1,p=c.x*f,d=c.y*f,g=o?this._map(c,!0):null,v=(l<<5)+(e+1),m=0,y=h;m<y.length;m+=1){var x=y[m],b=u.points[x];if(!(b.zoom<=e)){b.zoom=e;var _=b.numPoints||1;p+=b.x*_,d+=b.y*_,f+=_,b.parentId=v,o&&o(g,this._map(b))}}1===f?r.push(c):(c.parentId=v,r.push(W(p/f,d/f,v,f,g)))}}return r},Y.prototype._map=function(t,e){if(t.numPoints)return e?Q({},t.properties):t.properties;var r=this.points[t.index].properties,n=this.options.map(r);return e&&n===r?Q({},n):n},Mt.prototype.options={maxZoom:14,indexMaxZoom:5,indexMaxPoints:1e5,tolerance:3,extent:4096,buffer:64,lineMetrics:!1,promoteId:null,generateId:!1,debug:0},Mt.prototype.splitTile=function(t,e,r,n,i,a,o){for(var s=[t,e,r,n],l=this.options,c=l.debug;s.length;){n=s.pop(),r=s.pop(),e=s.pop(),t=s.pop();var u=1<<e,h=St(e,r,n),f=this.tiles[h];if(!f&&(c>1&&console.time(\"creation\"),f=this.tiles[h]=kt(t,e,r,n,l),this.tileCoords.push({z:e,x:r,y:n}),c)){c>1&&(console.log(\"tile z%d-%d-%d (features: %d, points: %d, simplified: %d)\",e,r,n,f.numFeatures,f.numPoints,f.numSimplified),console.timeEnd(\"creation\"));var p=\"z\"+e;this.stats[p]=(this.stats[p]||0)+1,this.total++}if(f.source=t,i){if(e===l.maxZoom||e===i)continue;var d=1<<i-e;if(r!==Math.floor(a/d)||n!==Math.floor(o/d))continue}else if(e===l.indexMaxZoom||f.numPoints<=l.indexMaxPoints)continue;if(f.source=null,0!==t.length){c>1&&console.time(\"clipping\");var g,v,m,y,x,b,_=.5*l.buffer/l.extent,w=.5-_,k=.5+_,T=1+_;g=v=m=y=null,x=ht(t,u,r-_,r+k,0,f.minX,f.maxX,l),b=ht(t,u,r+w,r+T,0,f.minX,f.maxX,l),t=null,x&&(g=ht(x,u,n-_,n+k,1,f.minY,f.maxY,l),v=ht(x,u,n+w,n+T,1,f.minY,f.maxY,l),x=null),b&&(m=ht(b,u,n-_,n+k,1,f.minY,f.maxY,l),y=ht(b,u,n+w,n+T,1,f.minY,f.maxY,l),b=null),c>1&&console.timeEnd(\"clipping\"),s.push(g||[],e+1,2*r,2*n),s.push(v||[],e+1,2*r,2*n+1),s.push(m||[],e+1,2*r+1,2*n),s.push(y||[],e+1,2*r+1,2*n+1)}}},Mt.prototype.getTile=function(t,e,r){var n=this.options,i=n.extent,a=n.debug;if(t<0||t>24)return null;var o=1<<t,s=St(t,e=(e%o+o)%o,r);if(this.tiles[s])return _t(this.tiles[s],i);a>1&&console.log(\"drilling down to z%d-%d-%d\",t,e,r);for(var l,c=t,u=e,h=r;!l&&c>0;)c--,u=Math.floor(u/2),h=Math.floor(h/2),l=this.tiles[St(c,u,h)];return l&&l.source?(a>1&&console.log(\"found parent tile z%d-%d-%d\",c,u,h),a>1&&console.time(\"drilling down\"),this.splitTile(l.source,c,u,h,t,e,r),a>1&&console.timeEnd(\"drilling down\"),this.tiles[s]?_t(this.tiles[s],i):null):null};var Ct=function(e){function r(t,r,n){e.call(this,t,r,Et),n&&(this.loadGeoJSON=n)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadData=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),this._pendingCallback=e,this._pendingLoadDataParams=t,this._state&&\"Idle\"!==this._state?this._state=\"NeedsLoadData\":(this._state=\"Coalescing\",this._loadData())},r.prototype._loadData=function(){var e=this;if(this._pendingCallback&&this._pendingLoadDataParams){var r=this._pendingCallback,n=this._pendingLoadDataParams;delete this._pendingCallback,delete this._pendingLoadDataParams;var i=!!(n&&n.request&&n.request.collectResourceTiming)&&new l.Performance(n.request);this.loadGeoJSON(n,function(a,o){if(a||!o)return r(a);if(\"object\"!=typeof o)return r(new Error(\"Input data given to '\"+n.source+\"' is not a valid GeoJSON object.\"));!function t(e,r){switch(e&&e.type||null){case\"FeatureCollection\":return e.features=e.features.map(y(t,r)),e;case\"GeometryCollection\":return e.geometries=e.geometries.map(y(t,r)),e;case\"Feature\":return e.geometry=t(e.geometry,r),e;case\"Polygon\":case\"MultiPolygon\":return function(t,e){return\"Polygon\"===t.type?t.coordinates=x(t.coordinates,e):\"MultiPolygon\"===t.type&&(t.coordinates=t.coordinates.map(y(x,e))),t}(e,r);default:return e}}(o,!0);try{e._geoJSONIndex=n.cluster?new Y(function(e){var r=e.superclusterOptions,n=e.clusterProperties;if(!n||!r)return r;for(var i={},a={},o={accumulated:null,zoom:0},s={properties:null},l=Object.keys(n),c=0,u=l;c<u.length;c+=1){var h=u[c],f=n[h],p=f[0],d=f[1],g=t.createExpression(d),v=t.createExpression(\"string\"==typeof p?[p,[\"accumulated\"],[\"get\",h]]:p);i[h]=g.value,a[h]=v.value}return r.map=function(t){s.properties=t;for(var e={},r=0,n=l;r<n.length;r+=1){var a=n[r];e[a]=i[a].evaluate(o,s)}return e},r.reduce=function(t,e){s.properties=e;for(var r=0,n=l;r<n.length;r+=1){var i=n[r];o.accumulated=t[i],t[i]=a[i].evaluate(o,s)}},r}(n)).load(o.features):new Mt(o,n.geojsonVtOptions)}catch(a){return r(a)}e.loaded={};var s={};if(i){var l=i.finish();l&&(s.resourceTiming={},s.resourceTiming[n.source]=JSON.parse(JSON.stringify(l)))}r(null,s)})}},r.prototype.coalesce=function(){\"Coalescing\"===this._state?this._state=\"Idle\":\"NeedsLoadData\"===this._state&&(this._state=\"Coalescing\",this._loadData())},r.prototype.reloadTile=function(t,r){var n=this.loaded,i=t.uid;return n&&n[i]?e.prototype.reloadTile.call(this,t,r):this.loadTile(t,r)},r.prototype.loadGeoJSON=function(e,r){if(e.request)t.getJSON(e.request,r);else{if(\"string\"!=typeof e.data)return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"));try{return r(null,JSON.parse(e.data))}catch(t){return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"))}}},r.prototype.removeSource=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),e()},r.prototype.getClusterExpansionZoom=function(t,e){e(null,this._geoJSONIndex.getClusterExpansionZoom(t.clusterId))},r.prototype.getClusterChildren=function(t,e){e(null,this._geoJSONIndex.getChildren(t.clusterId))},r.prototype.getClusterLeaves=function(t,e){e(null,this._geoJSONIndex.getLeaves(t.clusterId,t.limit,t.offset))},r}(h),Lt=function(e){var r=this;this.self=e,this.actor=new t.Actor(e,this),this.layerIndexes={},this.workerSourceTypes={vector:h,geojson:Ct},this.workerSources={},this.demWorkerSources={},this.self.registerWorkerSource=function(t,e){if(r.workerSourceTypes[t])throw new Error('Worker source with name \"'+t+'\" already registered.');r.workerSourceTypes[t]=e},this.self.registerRTLTextPlugin=function(e){if(t.plugin.isLoaded())throw new Error(\"RTL text plugin already registered.\");t.plugin.applyArabicShaping=e.applyArabicShaping,t.plugin.processBidirectionalText=e.processBidirectionalText,t.plugin.processStyledBidirectionalText=e.processStyledBidirectionalText}};return Lt.prototype.setReferrer=function(t,e){this.referrer=e},Lt.prototype.setLayers=function(t,e,r){this.getLayerIndex(t).replace(e),r()},Lt.prototype.updateLayers=function(t,e,r){this.getLayerIndex(t).update(e.layers,e.removedIds),r()},Lt.prototype.loadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).loadTile(e,r)},Lt.prototype.loadDEMTile=function(t,e,r){this.getDEMWorkerSource(t,e.source).loadTile(e,r)},Lt.prototype.reloadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).reloadTile(e,r)},Lt.prototype.abortTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).abortTile(e,r)},Lt.prototype.removeTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).removeTile(e,r)},Lt.prototype.removeDEMTile=function(t,e){this.getDEMWorkerSource(t,e.source).removeTile(e)},Lt.prototype.removeSource=function(t,e,r){if(this.workerSources[t]&&this.workerSources[t][e.type]&&this.workerSources[t][e.type][e.source]){var n=this.workerSources[t][e.type][e.source];delete this.workerSources[t][e.type][e.source],void 0!==n.removeSource?n.removeSource(e,r):r()}},Lt.prototype.loadWorkerSource=function(t,e,r){try{this.self.importScripts(e.url),r()}catch(t){r(t.toString())}},Lt.prototype.loadRTLTextPlugin=function(e,r,n){try{t.plugin.isLoaded()||(this.self.importScripts(r),n(t.plugin.isLoaded()?null:new Error(\"RTL Text Plugin failed to import scripts from \"+r)))}catch(t){n(t.toString())}},Lt.prototype.getLayerIndex=function(t){var e=this.layerIndexes[t];return e||(e=this.layerIndexes[t]=new n),e},Lt.prototype.getWorkerSource=function(t,e,r){var n=this;if(this.workerSources[t]||(this.workerSources[t]={}),this.workerSources[t][e]||(this.workerSources[t][e]={}),!this.workerSources[t][e][r]){var i={send:function(e,r,i){n.actor.send(e,r,i,t)}};this.workerSources[t][e][r]=new this.workerSourceTypes[e](i,this.getLayerIndex(t))}return this.workerSources[t][e][r]},Lt.prototype.getDEMWorkerSource=function(t,e){return this.demWorkerSources[t]||(this.demWorkerSources[t]={}),this.demWorkerSources[t][e]||(this.demWorkerSources[t][e]=new f),this.demWorkerSources[t][e]},Lt.prototype.enforceCacheSizeLimit=function(e,r){t.enforceCacheSizeLimit(r)},\"undefined\"!=typeof WorkerGlobalScope&&void 0!==t.window&&t.window instanceof WorkerGlobalScope&&(t.window.worker=new Lt(t.window)),Lt}),n(0,function(t){var e=t.createCommonjsModule(function(t){function e(t){return!!(\"undefined\"!=typeof window&&\"undefined\"!=typeof document&&Array.prototype&&Array.prototype.every&&Array.prototype.filter&&Array.prototype.forEach&&Array.prototype.indexOf&&Array.prototype.lastIndexOf&&Array.prototype.map&&Array.prototype.some&&Array.prototype.reduce&&Array.prototype.reduceRight&&Array.isArray&&Function.prototype&&Function.prototype.bind&&Object.keys&&Object.create&&Object.getPrototypeOf&&Object.getOwnPropertyNames&&Object.isSealed&&Object.isFrozen&&Object.isExtensible&&Object.getOwnPropertyDescriptor&&Object.defineProperty&&Object.defineProperties&&Object.seal&&Object.freeze&&Object.preventExtensions&&\"JSON\"in window&&\"parse\"in JSON&&\"stringify\"in JSON&&function(){if(!(\"Worker\"in window&&\"Blob\"in window&&\"URL\"in window))return!1;var t,e,r=new Blob([\"\"],{type:\"text/javascript\"}),n=URL.createObjectURL(r);try{e=new Worker(n),t=!0}catch(e){t=!1}return e&&e.terminate(),URL.revokeObjectURL(n),t}()&&\"Uint8ClampedArray\"in window&&ArrayBuffer.isView&&function(t){return void 0===r[t]&&(r[t]=function(t){var r=document.createElement(\"canvas\"),n=Object.create(e.webGLContextAttributes);return n.failIfMajorPerformanceCaveat=t,r.probablySupportsContext?r.probablySupportsContext(\"webgl\",n)||r.probablySupportsContext(\"experimental-webgl\",n):r.supportsContext?r.supportsContext(\"webgl\",n)||r.supportsContext(\"experimental-webgl\",n):r.getContext(\"webgl\",n)||r.getContext(\"experimental-webgl\",n)}(t)),r[t]}(t&&t.failIfMajorPerformanceCaveat))}t.exports?t.exports=e:window&&(window.mapboxgl=window.mapboxgl||{},window.mapboxgl.supported=e);var r={};e.webGLContextAttributes={antialias:!1,alpha:!0,stencil:!0,depth:!0}}),r={create:function(e,r,n){var i=t.window.document.createElement(e);return void 0!==r&&(i.className=r),n&&n.appendChild(i),i},createNS:function(e,r){return t.window.document.createElementNS(e,r)}},n=t.window.document.documentElement.style;function i(t){if(!n)return t[0];for(var e=0;e<t.length;e++)if(t[e]in n)return t[e];return t[0]}var a,o=i([\"userSelect\",\"MozUserSelect\",\"WebkitUserSelect\",\"msUserSelect\"]);r.disableDrag=function(){n&&o&&(a=n[o],n[o]=\"none\")},r.enableDrag=function(){n&&o&&(n[o]=a)};var s=i([\"transform\",\"WebkitTransform\"]);r.setTransform=function(t,e){t.style[s]=e};var l=!1;try{var c=Object.defineProperty({},\"passive\",{get:function(){l=!0}});t.window.addEventListener(\"test\",c,c),t.window.removeEventListener(\"test\",c,c)}catch(t){l=!1}r.addEventListener=function(t,e,r,n){void 0===n&&(n={}),\"passive\"in n&&l?t.addEventListener(e,r,n):t.addEventListener(e,r,n.capture)},r.removeEventListener=function(t,e,r,n){void 0===n&&(n={}),\"passive\"in n&&l?t.removeEventListener(e,r,n):t.removeEventListener(e,r,n.capture)};var u=function(e){e.preventDefault(),e.stopPropagation(),t.window.removeEventListener(\"click\",u,!0)};function h(t){var e=t.userImage;return!!(e&&e.render&&e.render())&&(t.data.replace(new Uint8Array(e.data.buffer)),!0)}r.suppressClick=function(){t.window.addEventListener(\"click\",u,!0),t.window.setTimeout(function(){t.window.removeEventListener(\"click\",u,!0)},0)},r.mousePos=function(e,r){var n=e.getBoundingClientRect(),i=t.window.TouchEvent&&r instanceof t.window.TouchEvent?r.touches[0]:r;return new t.Point(i.clientX-n.left-e.clientLeft,i.clientY-n.top-e.clientTop)},r.touchPos=function(e,r){for(var n=e.getBoundingClientRect(),i=[],a=\"touchend\"===r.type?r.changedTouches:r.touches,o=0;o<a.length;o++)i.push(new t.Point(a[o].clientX-n.left-e.clientLeft,a[o].clientY-n.top-e.clientTop));return i},r.mouseButton=function(e){return void 0!==t.window.InstallTrigger&&2===e.button&&e.ctrlKey&&t.window.navigator.platform.toUpperCase().indexOf(\"MAC\")>=0?0:e.button},r.remove=function(t){t.parentNode&&t.parentNode.removeChild(t)};var f=function(e){function r(){e.call(this),this.images={},this.updatedImages={},this.callbackDispatchedThisFrame={},this.loaded=!1,this.requestors=[],this.patterns={},this.atlasImage=new t.RGBAImage({width:1,height:1}),this.dirty=!0}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.isLoaded=function(){return this.loaded},r.prototype.setLoaded=function(t){if(this.loaded!==t&&(this.loaded=t,t)){for(var e=0,r=this.requestors;e<r.length;e+=1){var n=r[e],i=n.ids,a=n.callback;this._notify(i,a)}this.requestors=[]}},r.prototype.getImage=function(t){return this.images[t]},r.prototype.addImage=function(t,e){this.images[t]=e},r.prototype.updateImage=function(t,e){var r=this.images[t];e.version=r.version+1,this.images[t]=e,this.updatedImages[t]=!0},r.prototype.removeImage=function(t){var e=this.images[t];delete this.images[t],delete this.patterns[t],e.userImage&&e.userImage.onRemove&&e.userImage.onRemove()},r.prototype.listImages=function(){return Object.keys(this.images)},r.prototype.getImages=function(t,e){var r=!0;if(!this.isLoaded())for(var n=0,i=t;n<i.length;n+=1){var a=i[n];this.images[a]||(r=!1)}this.isLoaded()||r?this._notify(t,e):this.requestors.push({ids:t,callback:e})},r.prototype._notify=function(e,r){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i];this.images[o]||this.fire(new t.Event(\"styleimagemissing\",{id:o}));var s=this.images[o];s?n[o]={data:s.data.clone(),pixelRatio:s.pixelRatio,sdf:s.sdf,version:s.version,hasRenderCallback:Boolean(s.userImage&&s.userImage.render)}:t.warnOnce('Image \"'+o+'\" could not be loaded. Please make sure you have added the image with map.addImage() or a \"sprite\" property in your style. You can provide missing images by listening for the \"styleimagemissing\" map event.')}r(null,n)},r.prototype.getPixelSize=function(){var t=this.atlasImage;return{width:t.width,height:t.height}},r.prototype.getPattern=function(e){var r=this.patterns[e],n=this.getImage(e);if(!n)return null;if(r&&r.position.version===n.version)return r.position;if(r)r.position.version=n.version;else{var i={w:n.data.width+2,h:n.data.height+2,x:0,y:0},a=new t.ImagePosition(i,n);this.patterns[e]={bin:i,position:a}}return this._updatePatternAtlas(),this.patterns[e].position},r.prototype.bind=function(e){var r=e.gl;this.atlasTexture?this.dirty&&(this.atlasTexture.update(this.atlasImage),this.dirty=!1):this.atlasTexture=new t.Texture(e,this.atlasImage,r.RGBA),this.atlasTexture.bind(r.LINEAR,r.CLAMP_TO_EDGE)},r.prototype._updatePatternAtlas=function(){var e=[];for(var r in this.patterns)e.push(this.patterns[r].bin);var n=t.potpack(e),i=n.w,a=n.h,o=this.atlasImage;for(var s in o.resize({width:i||1,height:a||1}),this.patterns){var l=this.patterns[s].bin,c=l.x+1,u=l.y+1,h=this.images[s].data,f=h.width,p=h.height;t.RGBAImage.copy(h,o,{x:0,y:0},{x:c,y:u},{width:f,height:p}),t.RGBAImage.copy(h,o,{x:0,y:p-1},{x:c,y:u-1},{width:f,height:1}),t.RGBAImage.copy(h,o,{x:0,y:0},{x:c,y:u+p},{width:f,height:1}),t.RGBAImage.copy(h,o,{x:f-1,y:0},{x:c-1,y:u},{width:1,height:p}),t.RGBAImage.copy(h,o,{x:0,y:0},{x:c+f,y:u},{width:1,height:p})}this.dirty=!0},r.prototype.beginFrame=function(){this.callbackDispatchedThisFrame={}},r.prototype.dispatchRenderCallbacks=function(t){for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!this.callbackDispatchedThisFrame[n]){this.callbackDispatchedThisFrame[n]=!0;var i=this.images[n];h(i)&&this.updateImage(n,i)}}},r}(t.Evented),p=g,d=1e20;function g(t,e,r,n,i,a){this.fontSize=t||24,this.buffer=void 0===e?3:e,this.cutoff=n||.25,this.fontFamily=i||\"sans-serif\",this.fontWeight=a||\"normal\",this.radius=r||8;var o=this.size=this.fontSize+2*this.buffer;this.canvas=document.createElement(\"canvas\"),this.canvas.width=this.canvas.height=o,this.ctx=this.canvas.getContext(\"2d\"),this.ctx.font=this.fontWeight+\" \"+this.fontSize+\"px \"+this.fontFamily,this.ctx.textBaseline=\"middle\",this.ctx.fillStyle=\"black\",this.gridOuter=new Float64Array(o*o),this.gridInner=new Float64Array(o*o),this.f=new Float64Array(o),this.d=new Float64Array(o),this.z=new Float64Array(o+1),this.v=new Int16Array(o),this.middle=Math.round(o/2*(navigator.userAgent.indexOf(\"Gecko/\")>=0?1.2:1))}function v(t,e,r,n,i,a,o){for(var s=0;s<e;s++){for(var l=0;l<r;l++)n[l]=t[l*e+s];for(m(n,i,a,o,r),l=0;l<r;l++)t[l*e+s]=i[l]}for(l=0;l<r;l++){for(s=0;s<e;s++)n[s]=t[l*e+s];for(m(n,i,a,o,e),s=0;s<e;s++)t[l*e+s]=Math.sqrt(i[s])}}function m(t,e,r,n,i){r[0]=0,n[0]=-d,n[1]=+d;for(var a=1,o=0;a<i;a++){for(var s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);s<=n[o];)o--,s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);r[++o]=a,n[o]=s,n[o+1]=+d}for(a=0,o=0;a<i;a++){for(;n[o+1]<a;)o++;e[a]=(a-r[o])*(a-r[o])+t[r[o]]}}g.prototype.draw=function(t){this.ctx.clearRect(0,0,this.size,this.size),this.ctx.fillText(t,this.buffer,this.middle);for(var e=this.ctx.getImageData(0,0,this.size,this.size),r=new Uint8ClampedArray(this.size*this.size),n=0;n<this.size*this.size;n++){var i=e.data[4*n+3]/255;this.gridOuter[n]=1===i?0:0===i?d:Math.pow(Math.max(0,.5-i),2),this.gridInner[n]=1===i?d:0===i?0:Math.pow(Math.max(0,i-.5),2)}for(v(this.gridOuter,this.size,this.size,this.f,this.d,this.v,this.z),v(this.gridInner,this.size,this.size,this.f,this.d,this.v,this.z),n=0;n<this.size*this.size;n++){var a=this.gridOuter[n]-this.gridInner[n];r[n]=Math.max(0,Math.min(255,Math.round(255-255*(a/this.radius+this.cutoff))))}return r};var y=function(t,e){this.requestManager=t,this.localIdeographFontFamily=e,this.entries={}};y.prototype.setURL=function(t){this.url=t},y.prototype.getGlyphs=function(e,r){var n=this,i=[];for(var a in e)for(var o=0,s=e[a];o<s.length;o+=1){var l=s[o];i.push({stack:a,id:l})}t.asyncAll(i,function(t,e){var r=t.stack,i=t.id,a=n.entries[r];a||(a=n.entries[r]={glyphs:{},requests:{}});var o=a.glyphs[i];if(void 0===o)if(o=n._tinySDF(a,r,i))e(null,{stack:r,id:i,glyph:o});else{var s=Math.floor(i/256);if(256*s>65535)e(new Error(\"glyphs > 65535 not supported\"));else{var l=a.requests[s];l||(l=a.requests[s]=[],y.loadGlyphRange(r,s,n.url,n.requestManager,function(t,e){if(e)for(var r in e)a.glyphs[+r]=e[+r];for(var n=0,i=l;n<i.length;n+=1)(0,i[n])(t,e);delete a.requests[s]})),l.push(function(t,n){t?e(t):n&&e(null,{stack:r,id:i,glyph:n[i]||null})})}}else e(null,{stack:r,id:i,glyph:o})},function(t,e){if(t)r(t);else if(e){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.stack,l=o.id,c=o.glyph;(n[s]||(n[s]={}))[l]=c&&{id:c.id,bitmap:c.bitmap.clone(),metrics:c.metrics}}r(null,n)}})},y.prototype._tinySDF=function(e,r,n){var i=this.localIdeographFontFamily;if(i&&(t.isChar[\"CJK Unified Ideographs\"](n)||t.isChar[\"Hangul Syllables\"](n)||t.isChar.Hiragana(n)||t.isChar.Katakana(n))){var a=e.tinySDF;if(!a){var o=\"400\";/bold/i.test(r)?o=\"900\":/medium/i.test(r)?o=\"500\":/light/i.test(r)&&(o=\"200\"),a=e.tinySDF=new y.TinySDF(24,3,8,.25,i,o)}return{id:n,bitmap:new t.AlphaImage({width:30,height:30},a.draw(String.fromCharCode(n))),metrics:{width:24,height:24,left:0,top:-8,advance:24}}}},y.loadGlyphRange=function(e,r,n,i,a){var o=256*r,s=o+255,l=i.transformRequest(i.normalizeGlyphsURL(n).replace(\"{fontstack}\",e).replace(\"{range}\",o+\"-\"+s),t.ResourceType.Glyphs);t.getArrayBuffer(l,function(e,r){if(e)a(e);else if(r){for(var n={},i=0,o=t.parseGlyphPBF(r);i<o.length;i+=1){var s=o[i];n[s.id]=s}a(null,n)}})},y.TinySDF=p;var x=function(){this.specification=t.styleSpec.light.position};x.prototype.possiblyEvaluate=function(e,r){return t.sphericalToCartesian(e.expression.evaluate(r))},x.prototype.interpolate=function(e,r,n){return{x:t.number(e.x,r.x,n),y:t.number(e.y,r.y,n),z:t.number(e.z,r.z,n)}};var b=new t.Properties({anchor:new t.DataConstantProperty(t.styleSpec.light.anchor),position:new x,color:new t.DataConstantProperty(t.styleSpec.light.color),intensity:new t.DataConstantProperty(t.styleSpec.light.intensity)}),_=function(e){function r(r){e.call(this),this._transitionable=new t.Transitionable(b),this.setLight(r),this._transitioning=this._transitionable.untransitioned()}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getLight=function(){return this._transitionable.serialize()},r.prototype.setLight=function(e,r){if(void 0===r&&(r={}),!this._validate(t.validateLight,e,r))for(var n in e){var i=e[n];t.endsWith(n,\"-transition\")?this._transitionable.setTransition(n.slice(0,-\"-transition\".length),i):this._transitionable.setValue(n,i)}},r.prototype.updateTransitions=function(t){this._transitioning=this._transitionable.transitioned(t,this._transitioning)},r.prototype.hasTransition=function(){return this._transitioning.hasTransition()},r.prototype.recalculate=function(t){this.properties=this._transitioning.possiblyEvaluate(t)},r.prototype._validate=function(e,r,n){return(!n||!1!==n.validate)&&t.emitValidationErrors(this,e.call(t.validateStyle,t.extend({value:r,style:{glyphs:!0,sprite:!0},styleSpec:t.styleSpec})))},r}(t.Evented),w=function(t,e){this.width=t,this.height=e,this.nextRow=0,this.bytes=4,this.data=new Uint8Array(this.width*this.height*this.bytes),this.positions={}};w.prototype.getDash=function(t,e){var r=t.join(\",\")+String(e);return this.positions[r]||(this.positions[r]=this.addDash(t,e)),this.positions[r]},w.prototype.addDash=function(e,r){var n=r?7:0,i=2*n+1;if(this.nextRow+i>this.height)return t.warnOnce(\"LineAtlas out of space\"),null;for(var a=0,o=0;o<e.length;o++)a+=e[o];for(var s=this.width/a,l=s/2,c=e.length%2==1,u=-n;u<=n;u++)for(var h=this.nextRow+n+u,f=this.width*h,p=c?-e[e.length-1]:0,d=e[0],g=1,v=0;v<this.width;v++){for(;d<v/s;)p=d,d+=e[g],c&&g===e.length-1&&(d+=e[0]),g++;var m=Math.abs(v-p*s),y=Math.abs(v-d*s),x=Math.min(m,y),b=g%2==1,_=void 0;if(r){var w=n?u/n*(l+1):0;if(b){var k=l-Math.abs(w);_=Math.sqrt(x*x+k*k)}else _=l-Math.sqrt(x*x+w*w)}else _=(b?1:-1)*x;this.data[3+4*(f+v)]=Math.max(0,Math.min(255,_+128))}var T={y:(this.nextRow+n+.5)/this.height,height:2*n/this.height,width:a};return this.nextRow+=i,this.dirty=!0,T},w.prototype.bind=function(t){var e=t.gl;this.texture?(e.bindTexture(e.TEXTURE_2D,this.texture),this.dirty&&(this.dirty=!1,e.texSubImage2D(e.TEXTURE_2D,0,0,0,this.width,this.height,e.RGBA,e.UNSIGNED_BYTE,this.data))):(this.texture=e.createTexture(),e.bindTexture(e.TEXTURE_2D,this.texture),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_S,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_T,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,e.LINEAR),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,e.LINEAR),e.texImage2D(e.TEXTURE_2D,0,e.RGBA,this.width,this.height,0,e.RGBA,e.UNSIGNED_BYTE,this.data))};var k=function e(r,n){this.workerPool=r,this.actors=[],this.currentActor=0,this.id=t.uniqueId();for(var i=this.workerPool.acquire(this.id),a=0;a<i.length;a++){var o=i[a],s=new e.Actor(o,n,this.id);s.name=\"Worker \"+a,this.actors.push(s)}};function T(e,r,n){var i=function(i,a){if(i)return n(i);if(a){var o=t.pick(a,[\"tiles\",\"minzoom\",\"maxzoom\",\"attribution\",\"mapbox_logo\",\"bounds\"]);a.vector_layers&&(o.vectorLayers=a.vector_layers,o.vectorLayerIds=o.vectorLayers.map(function(t){return t.id})),e.url&&(o.tiles=r.canonicalizeTileset(o,e.url)),n(null,o)}};return e.url?t.getJSON(r.transformRequest(r.normalizeSourceURL(e.url),t.ResourceType.Source),i):t.browser.frame(function(){return i(null,e)})}k.prototype.broadcast=function(e,r,n){n=n||function(){},t.asyncAll(this.actors,function(t,n){t.send(e,r,n)},n)},k.prototype.send=function(t,e,r,n){return(\"number\"!=typeof n||isNaN(n))&&(n=this.currentActor=(this.currentActor+1)%this.actors.length),this.actors[n].send(t,e,r),n},k.prototype.remove=function(){this.actors.forEach(function(t){t.remove()}),this.actors=[],this.workerPool.release(this.id)},k.Actor=t.Actor;var A=function(e,r,n){this.bounds=t.LngLatBounds.convert(this.validateBounds(e)),this.minzoom=r||0,this.maxzoom=n||24};A.prototype.validateBounds=function(t){return Array.isArray(t)&&4===t.length?[Math.max(-180,t[0]),Math.max(-90,t[1]),Math.min(180,t[2]),Math.min(90,t[3])]:[-180,-90,180,90]},A.prototype.contains=function(e){var r=Math.pow(2,e.z),n=Math.floor(t.mercatorXfromLng(this.bounds.getWest())*r),i=Math.floor(t.mercatorYfromLat(this.bounds.getNorth())*r),a=Math.ceil(t.mercatorXfromLng(this.bounds.getEast())*r),o=Math.ceil(t.mercatorYfromLat(this.bounds.getSouth())*r);return e.x>=n&&e.x<a&&e.y>=i&&e.y<o};var M=function(e){function r(r,n,i,a){if(e.call(this),this.id=r,this.dispatcher=i,this.type=\"vector\",this.minzoom=0,this.maxzoom=22,this.scheme=\"xyz\",this.tileSize=512,this.reparseOverscaled=!0,this.isTileClipped=!0,t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"])),this._options=t.extend({type:\"vector\"},n),this._collectResourceTiming=n.collectResourceTiming,512!==this.tileSize)throw new Error(\"vector tile sources must have a tileSize of 512\");this.setEventedParent(a)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=T(this._options,this.map._requestManager,function(r,n){e._tileJSONRequest=null,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))})},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,null),i={request:this.map._requestManager.transformRequest(n,t.ResourceType.Tile),uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,tileSize:this.tileSize*e.tileID.overscaleFactor(),type:this.type,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes};function a(n,i){return e.aborted?r(null):n&&404!==n.status?r(n):(i&&i.resourceTiming&&(e.resourceTiming=i.resourceTiming),this.map._refreshExpiredTiles&&i&&e.setExpiryData(i),e.loadVectorData(i,this.map.painter),t.cacheEntryPossiblyAdded(this.dispatcher),r(null),void(e.reloadCallback&&(this.loadTile(e,e.reloadCallback),e.reloadCallback=null)))}i.request.collectResourceTiming=this._collectResourceTiming,void 0===e.workerID||\"expired\"===e.state?e.workerID=this.dispatcher.send(\"loadTile\",i,a.bind(this)):\"loading\"===e.state?e.reloadCallback=r:this.dispatcher.send(\"reloadTile\",i,a.bind(this),e.workerID)},r.prototype.abortTile=function(t){this.dispatcher.send(\"abortTile\",{uid:t.uid,type:this.type,source:this.id},void 0,t.workerID)},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.dispatcher.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},void 0,t.workerID)},r.prototype.hasTransition=function(){return!1},r}(t.Evented),S=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.dispatcher=i,this.setEventedParent(a),this.type=\"raster\",this.minzoom=0,this.maxzoom=22,this.roundZoom=!0,this.scheme=\"xyz\",this.tileSize=512,this._loaded=!1,this._options=t.extend({},n),t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"]))}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=T(this._options,this.map._requestManager,function(r,n){e._tileJSONRequest=null,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))})},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.loadTile=function(e,r){var n=this,i=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(i,t.ResourceType.Tile),function(i,a){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(i)e.state=\"errored\",r(i);else if(a){n.map._refreshExpiredTiles&&e.setExpiryData(a),delete a.cacheControl,delete a.expires;var o=n.map.painter.context,s=o.gl;e.texture=n.map.painter.getTileTexture(a.width),e.texture?e.texture.update(a,{useMipmap:!0}):(e.texture=new t.Texture(o,a,s.RGBA,{useMipmap:!0}),e.texture.bind(s.LINEAR,s.CLAMP_TO_EDGE,s.LINEAR_MIPMAP_NEAREST),o.extTextureFilterAnisotropic&&s.texParameterf(s.TEXTURE_2D,o.extTextureFilterAnisotropic.TEXTURE_MAX_ANISOTROPY_EXT,o.extTextureFilterAnisotropicMax)),e.state=\"loaded\",t.cacheEntryPossiblyAdded(n.dispatcher),r(null)}})},r.prototype.abortTile=function(t,e){t.request&&(t.request.cancel(),delete t.request),e()},r.prototype.unloadTile=function(t,e){t.texture&&this.map.painter.saveTileTexture(t.texture),e()},r.prototype.hasTransition=function(){return!1},r}(t.Evented),E=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),this.type=\"raster-dem\",this.maxzoom=22,this._options=t.extend({},n),this.encoding=n.encoding||\"mapbox\"}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.serialize=function(){return{type:\"raster-dem\",url:this.url,tileSize:this.tileSize,tiles:this.tiles,bounds:this.bounds,encoding:this.encoding}},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(n,t.ResourceType.Tile),function(n,i){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(n)e.state=\"errored\",r(n);else if(i){this.map._refreshExpiredTiles&&e.setExpiryData(i),delete i.cacheControl,delete i.expires;var a=t.browser.getImageData(i),o={uid:e.uid,coord:e.tileID,source:this.id,rawImageData:a,encoding:this.encoding};e.workerID&&\"expired\"!==e.state||(e.workerID=this.dispatcher.send(\"loadDEMTile\",o,function(t,n){t&&(e.state=\"errored\",r(t)),n&&(e.dem=n,e.needsHillshadePrepare=!0,e.state=\"loaded\",r(null))}.bind(this)))}}.bind(this)),e.neighboringTiles=this._getNeighboringTiles(e.tileID)},r.prototype._getNeighboringTiles=function(e){var r=e.canonical,n=Math.pow(2,r.z),i=(r.x-1+n)%n,a=0===r.x?e.wrap-1:e.wrap,o=(r.x+1+n)%n,s=r.x+1===n?e.wrap+1:e.wrap,l={};return l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y).key]={backfilled:!1},r.y>0&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y-1).key]={backfilled:!1}),r.y+1<n&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y+1).key]={backfilled:!1}),l},r.prototype.unloadTile=function(t){t.demTexture&&this.map.painter.saveTileTexture(t.demTexture),t.fbo&&(t.fbo.destroy(),delete t.fbo),t.dem&&delete t.dem,delete t.neighboringTiles,t.state=\"unloaded\",this.dispatcher.send(\"removeDEMTile\",{uid:t.uid,source:this.id},void 0,t.workerID)},r}(S),C=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.type=\"geojson\",this.minzoom=0,this.maxzoom=18,this.tileSize=512,this.isTileClipped=!0,this.reparseOverscaled=!0,this._removed=!1,this.dispatcher=i,this.setEventedParent(a),this._data=n.data,this._options=t.extend({},n),this._collectResourceTiming=n.collectResourceTiming,this._resourceTiming=[],void 0!==n.maxzoom&&(this.maxzoom=n.maxzoom),n.type&&(this.type=n.type),n.attribution&&(this.attribution=n.attribution);var o=t.EXTENT/this.tileSize;this.workerOptions=t.extend({source:this.id,cluster:n.cluster||!1,geojsonVtOptions:{buffer:(void 0!==n.buffer?n.buffer:128)*o,tolerance:(void 0!==n.tolerance?n.tolerance:.375)*o,extent:t.EXTENT,maxZoom:this.maxzoom,lineMetrics:n.lineMetrics||!1,generateId:n.generateId||!1},superclusterOptions:{maxZoom:void 0!==n.clusterMaxZoom?Math.min(n.clusterMaxZoom,this.maxzoom-1):this.maxzoom-1,extent:t.EXTENT,radius:(n.clusterRadius||50)*o,log:!1},clusterProperties:n.clusterProperties},n.workerOptions)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData(function(r){if(r)e.fire(new t.ErrorEvent(r));else{var n={dataType:\"source\",sourceDataType:\"metadata\"};e._collectResourceTiming&&e._resourceTiming&&e._resourceTiming.length>0&&(n.resourceTiming=e._resourceTiming,e._resourceTiming=[]),e.fire(new t.Event(\"data\",n))}})},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setData=function(e){var r=this;return this._data=e,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData(function(e){if(e)r.fire(new t.ErrorEvent(e));else{var n={dataType:\"source\",sourceDataType:\"content\"};r._collectResourceTiming&&r._resourceTiming&&r._resourceTiming.length>0&&(n.resourceTiming=r._resourceTiming,r._resourceTiming=[]),r.fire(new t.Event(\"data\",n))}}),this},r.prototype.getClusterExpansionZoom=function(t,e){return this.dispatcher.send(\"geojson.getClusterExpansionZoom\",{clusterId:t,source:this.id},e,this.workerID),this},r.prototype.getClusterChildren=function(t,e){return this.dispatcher.send(\"geojson.getClusterChildren\",{clusterId:t,source:this.id},e,this.workerID),this},r.prototype.getClusterLeaves=function(t,e,r,n){return this.dispatcher.send(\"geojson.getClusterLeaves\",{source:this.id,clusterId:t,limit:e,offset:r},n,this.workerID),this},r.prototype._updateWorkerData=function(e){var r=this,n=t.extend({},this.workerOptions),i=this._data;\"string\"==typeof i?(n.request=this.map._requestManager.transformRequest(t.browser.resolveURL(i),t.ResourceType.Source),n.request.collectResourceTiming=this._collectResourceTiming):n.data=JSON.stringify(i),this.workerID=this.dispatcher.send(this.type+\".loadData\",n,function(t,i){r._removed||i&&i.abandoned||(r._loaded=!0,i&&i.resourceTiming&&i.resourceTiming[r.id]&&(r._resourceTiming=i.resourceTiming[r.id].slice(0)),r.dispatcher.send(r.type+\".coalesce\",{source:n.source},null,r.workerID),e(t))},this.workerID)},r.prototype.loadTile=function(e,r){var n=this,i=void 0===e.workerID?\"loadTile\":\"reloadTile\",a={type:this.type,uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,maxZoom:this.maxzoom,tileSize:this.tileSize,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes};e.workerID=this.dispatcher.send(i,a,function(t,a){return e.unloadVectorData(),e.aborted?r(null):t?r(t):(e.loadVectorData(a,n.map.painter,\"reloadTile\"===i),r(null))},this.workerID)},r.prototype.abortTile=function(t){t.aborted=!0},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.dispatcher.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},null,t.workerID)},r.prototype.onRemove=function(){this._removed=!0,this.dispatcher.send(\"removeSource\",{type:this.type,source:this.id},null,this.workerID)},r.prototype.serialize=function(){return t.extend({},this._options,{type:this.type,data:this._data})},r.prototype.hasTransition=function(){return!1},r}(t.Evented),L=function(e){function r(t,r,n,i){e.call(this),this.id=t,this.dispatcher=n,this.coordinates=r.coordinates,this.type=\"image\",this.minzoom=0,this.maxzoom=22,this.tileSize=512,this.tiles={},this.setEventedParent(i),this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(e,r){var n=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this.url=this.options.url,t.getImage(this.map._requestManager.transformRequest(this.url,t.ResourceType.Image),function(i,a){i?n.fire(new t.ErrorEvent(i)):a&&(n.image=a,e&&(n.coordinates=e),r&&r(),n._finishLoading())})},r.prototype.updateImage=function(t){var e=this;return this.image&&t.url?(this.options.url=t.url,this.load(t.coordinates,function(){e.texture=null}),this):this},r.prototype._finishLoading=function(){this.map&&(this.setCoordinates(this.coordinates),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setCoordinates=function(e){var r=this;this.coordinates=e;var n=e.map(t.MercatorCoordinate.fromLngLat);this.tileID=function(e){for(var r=1/0,n=1/0,i=-1/0,a=-1/0,o=0,s=e;o<s.length;o+=1){var l=s[o];r=Math.min(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.x),a=Math.max(a,l.y)}var c=i-r,u=a-n,h=Math.max(c,u),f=Math.max(0,Math.floor(-Math.log(h)/Math.LN2)),p=Math.pow(2,f);return new t.CanonicalTileID(f,Math.floor((r+i)/2*p),Math.floor((n+a)/2*p))}(n),this.minzoom=this.maxzoom=this.tileID.z;var i=n.map(function(t){return r.tileID.getTilePoint(t)._round()});return this._boundsArray=new t.StructArrayLayout4i8,this._boundsArray.emplaceBack(i[0].x,i[0].y,0,0),this._boundsArray.emplaceBack(i[1].x,i[1].y,t.EXTENT,0),this._boundsArray.emplaceBack(i[3].x,i[3].y,0,t.EXTENT),this._boundsArray.emplaceBack(i[2].x,i[2].y,t.EXTENT,t.EXTENT),this.boundsBuffer&&(this.boundsBuffer.destroy(),delete this.boundsBuffer),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})),this},r.prototype.prepare=function(){if(0!==Object.keys(this.tiles).length&&this.image){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture||(this.texture=new t.Texture(e,this.image,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.loadTile=function(t,e){this.tileID&&this.tileID.equals(t.tileID.canonical)?(this.tiles[String(t.tileID.wrap)]=t,t.buckets={},e(null)):(t.state=\"errored\",e(null))},r.prototype.serialize=function(){return{type:\"image\",url:this.options.url,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return!1},r}(t.Evented),P=function(e){function r(t,r,n,i){e.call(this,t,r,n,i),this.roundZoom=!0,this.type=\"video\",this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this,r=this.options;this.urls=[];for(var n=0,i=r.urls;n<i.length;n+=1){var a=i[n];this.urls.push(this.map._requestManager.transformRequest(a,t.ResourceType.Source).url)}t.getVideo(this.urls,function(r,n){r?e.fire(new t.ErrorEvent(r)):n&&(e.video=n,e.video.loop=!0,e.video.addEventListener(\"playing\",function(){e.map.triggerRepaint()}),e.map&&e.video.play(),e._finishLoading())})},r.prototype.getVideo=function(){return this.video},r.prototype.onAdd=function(t){this.map||(this.map=t,this.load(),this.video&&(this.video.play(),this.setCoordinates(this.coordinates)))},r.prototype.prepare=function(){if(!(0===Object.keys(this.tiles).length||this.video.readyState<2)){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?this.video.paused||(this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE),r.texSubImage2D(r.TEXTURE_2D,0,0,0,r.RGBA,r.UNSIGNED_BYTE,this.video)):(this.texture=new t.Texture(e,this.video,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"video\",urls:this.urls,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this.video&&!this.video.paused},r}(L),O=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),n.coordinates?Array.isArray(n.coordinates)&&4===n.coordinates.length&&!n.coordinates.some(function(t){return!Array.isArray(t)||2!==t.length||t.some(function(t){return\"number\"!=typeof t})})||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"coordinates\" property must be an array of 4 longitude/latitude array pairs'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"coordinates\"'))),n.animate&&\"boolean\"!=typeof n.animate&&this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'optional \"animate\" property must be a boolean value'))),n.canvas?\"string\"==typeof n.canvas||n.canvas instanceof t.window.HTMLCanvasElement||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"canvas\" must be either a string representing the ID of the canvas element from which to read, or an HTMLCanvasElement instance'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"canvas\"'))),this.options=n,this.animate=void 0===n.animate||n.animate}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){this.canvas||(this.canvas=this.options.canvas instanceof t.window.HTMLCanvasElement?this.options.canvas:t.window.document.getElementById(this.options.canvas)),this.width=this.canvas.width,this.height=this.canvas.height,this._hasInvalidDimensions()?this.fire(new t.ErrorEvent(new Error(\"Canvas dimensions cannot be less than or equal to zero.\"))):(this.play=function(){this._playing=!0,this.map.triggerRepaint()},this.pause=function(){this._playing&&(this.prepare(),this._playing=!1)},this._finishLoading())},r.prototype.getCanvas=function(){return this.canvas},r.prototype.onAdd=function(t){this.map=t,this.load(),this.canvas&&this.animate&&this.play()},r.prototype.onRemove=function(){this.pause()},r.prototype.prepare=function(){var e=!1;if(this.canvas.width!==this.width&&(this.width=this.canvas.width,e=!0),this.canvas.height!==this.height&&(this.height=this.canvas.height,e=!0),!this._hasInvalidDimensions()&&0!==Object.keys(this.tiles).length){var r=this.map.painter.context,n=r.gl;for(var i in this.boundsBuffer||(this.boundsBuffer=r.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?(e||this._playing)&&this.texture.update(this.canvas,{premultiply:!0}):this.texture=new t.Texture(r,this.canvas,n.RGBA,{premultiply:!0}),this.tiles){var a=this.tiles[i];\"loaded\"!==a.state&&(a.state=\"loaded\",a.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"canvas\",coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this._playing},r.prototype._hasInvalidDimensions=function(){for(var t=0,e=[this.canvas.width,this.canvas.height];t<e.length;t+=1){var r=e[t];if(isNaN(r)||r<=0)return!0}return!1},r}(L),z={vector:M,raster:S,\"raster-dem\":E,geojson:C,video:P,image:L,canvas:O},I=function(e,r,n,i){var a=new z[r.type](e,r,n,i);if(a.id!==e)throw new Error(\"Expected Source id to be \"+e+\" instead of \"+a.id);return t.bindAll([\"load\",\"abort\",\"unload\",\"serialize\",\"prepare\"],a),a};function D(e,r){var n=t.identity([]);return t.translate(n,n,[1,1,0]),t.scale(n,n,[.5*e.width,.5*e.height,1]),t.multiply(n,n,e.calculatePosMatrix(r.toUnwrapped()))}function R(t,e,r,n,i){var a=function(t,e,r){if(t)for(var n=0,i=t;n<i.length;n+=1){var a=e[i[n]];if(a&&a.source===r&&\"fill-extrusion\"===a.type)return!0}else for(var o in e){var s=e[o];if(s.source===r&&\"fill-extrusion\"===s.type)return!0}return!1}(n&&n.layers,e,t.id),o=i.maxPitchScaleFactor(),s=t.tilesIn(r,o,a);s.sort(F);for(var l=[],c=0,u=s;c<u.length;c+=1){var h=u[c];l.push({wrappedTileID:h.tileID.wrapped().key,queryResults:h.tile.queryRenderedFeatures(e,t._state,h.queryGeometry,h.cameraQueryGeometry,h.scale,n,i,o,D(t.transform,h.tileID))})}var f=function(t){for(var e={},r={},n=0,i=t;n<i.length;n+=1){var a=i[n],o=a.queryResults,s=a.wrappedTileID,l=r[s]=r[s]||{};for(var c in o)for(var u=o[c],h=l[c]=l[c]||{},f=e[c]=e[c]||[],p=0,d=u;p<d.length;p+=1){var g=d[p];h[g.featureIndex]||(h[g.featureIndex]=!0,f.push(g))}}return e}(l);for(var p in f)f[p].forEach(function(e){var r=e.feature,n=t.getFeatureState(r.layer[\"source-layer\"],r.id);r.source=r.layer.source,r.layer[\"source-layer\"]&&(r.sourceLayer=r.layer[\"source-layer\"]),r.state=n});return f}function F(t,e){var r=t.tileID,n=e.tileID;return r.overscaledZ-n.overscaledZ||r.canonical.y-n.canonical.y||r.wrap-n.wrap||r.canonical.x-n.canonical.x}var B=function(t,e){this.max=t,this.onRemove=e,this.reset()};B.prototype.reset=function(){for(var t in this.data)for(var e=0,r=this.data[t];e<r.length;e+=1){var n=r[e];n.timeout&&clearTimeout(n.timeout),this.onRemove(n.value)}return this.data={},this.order=[],this},B.prototype.add=function(t,e,r){var n=this,i=t.wrapped().key;void 0===this.data[i]&&(this.data[i]=[]);var a={value:e,timeout:void 0};if(void 0!==r&&(a.timeout=setTimeout(function(){n.remove(t,a)},r)),this.data[i].push(a),this.order.push(i),this.order.length>this.max){var o=this._getAndRemoveByKey(this.order[0]);o&&this.onRemove(o)}return this},B.prototype.has=function(t){return t.wrapped().key in this.data},B.prototype.getAndRemove=function(t){return this.has(t)?this._getAndRemoveByKey(t.wrapped().key):null},B.prototype._getAndRemoveByKey=function(t){var e=this.data[t].shift();return e.timeout&&clearTimeout(e.timeout),0===this.data[t].length&&delete this.data[t],this.order.splice(this.order.indexOf(t),1),e.value},B.prototype.get=function(t){return this.has(t)?this.data[t.wrapped().key][0].value:null},B.prototype.remove=function(t,e){if(!this.has(t))return this;var r=t.wrapped().key,n=void 0===e?0:this.data[r].indexOf(e),i=this.data[r][n];return this.data[r].splice(n,1),i.timeout&&clearTimeout(i.timeout),0===this.data[r].length&&delete this.data[r],this.onRemove(i.value),this.order.splice(this.order.indexOf(r),1),this},B.prototype.setMaxSize=function(t){for(this.max=t;this.order.length>this.max;){var e=this._getAndRemoveByKey(this.order[0]);e&&this.onRemove(e)}return this};var N=function(t,e,r){this.context=t;var n=t.gl;this.buffer=n.createBuffer(),this.dynamicDraw=Boolean(r),this.context.unbindVAO(),t.bindElementBuffer.set(this.buffer),n.bufferData(n.ELEMENT_ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?n.DYNAMIC_DRAW:n.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};N.prototype.bind=function(){this.context.bindElementBuffer.set(this.buffer)},N.prototype.updateData=function(t){var e=this.context.gl;this.context.unbindVAO(),this.bind(),e.bufferSubData(e.ELEMENT_ARRAY_BUFFER,0,t.arrayBuffer)},N.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var j={Int8:\"BYTE\",Uint8:\"UNSIGNED_BYTE\",Int16:\"SHORT\",Uint16:\"UNSIGNED_SHORT\",Int32:\"INT\",Uint32:\"UNSIGNED_INT\",Float32:\"FLOAT\"},U=function(t,e,r,n){this.length=e.length,this.attributes=r,this.itemSize=e.bytesPerElement,this.dynamicDraw=n,this.context=t;var i=t.gl;this.buffer=i.createBuffer(),t.bindVertexBuffer.set(this.buffer),i.bufferData(i.ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?i.DYNAMIC_DRAW:i.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};U.prototype.bind=function(){this.context.bindVertexBuffer.set(this.buffer)},U.prototype.updateData=function(t){var e=this.context.gl;this.bind(),e.bufferSubData(e.ARRAY_BUFFER,0,t.arrayBuffer)},U.prototype.enableAttributes=function(t,e){for(var r=0;r<this.attributes.length;r++){var n=this.attributes[r],i=e.attributes[n.name];void 0!==i&&t.enableVertexAttribArray(i)}},U.prototype.setVertexAttribPointers=function(t,e,r){for(var n=0;n<this.attributes.length;n++){var i=this.attributes[n],a=e.attributes[i.name];void 0!==a&&t.vertexAttribPointer(a,i.components,t[j[i.type]],!1,this.itemSize,i.offset+this.itemSize*(r||0))}},U.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var V=function(t){this.gl=t.gl,this.default=this.getDefault(),this.current=this.default,this.dirty=!1};V.prototype.get=function(){return this.current},V.prototype.set=function(t){},V.prototype.getDefault=function(){return this.default},V.prototype.setDefault=function(){this.set(this.default)};var q=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.clearColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(V),H=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 1},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearDepth(t),this.current=t,this.dirty=!1)},e}(V),G=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearStencil(t),this.current=t,this.dirty=!1)},e}(V),Y=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return[!0,!0,!0,!0]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.colorMask(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(V),W=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthMask(t),this.current=t,this.dirty=!1)},e}(V),X=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 255},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.stencilMask(t),this.current=t,this.dirty=!1)},e}(V),Z=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return{func:this.gl.ALWAYS,ref:0,mask:255}},e.prototype.set=function(t){var e=this.current;(t.func!==e.func||t.ref!==e.ref||t.mask!==e.mask||this.dirty)&&(this.gl.stencilFunc(t.func,t.ref,t.mask),this.current=t,this.dirty=!1)},e}(V),J=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.KEEP,t.KEEP,t.KEEP]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||this.dirty)&&(this.gl.stencilOp(t[0],t[1],t[2]),this.current=t,this.dirty=!1)},e}(V),K=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.STENCIL_TEST):e.disable(e.STENCIL_TEST),this.current=t,this.dirty=!1}},e}(V),$=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return[0,1]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.depthRange(t[0],t[1]),this.current=t,this.dirty=!1)},e}(V),Q=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.DEPTH_TEST):e.disable(e.DEPTH_TEST),this.current=t,this.dirty=!1}},e}(V),tt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.LESS},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthFunc(t),this.current=t,this.dirty=!1)},e}(V),et=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.BLEND):e.disable(e.BLEND),this.current=t,this.dirty=!1}},e}(V),rt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.ONE,t.ZERO]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.blendFunc(t[0],t[1]),this.current=t,this.dirty=!1)},e}(V),nt=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.blendColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(V),it=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.FUNC_ADD},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.blendEquation(t),this.current=t,this.dirty=!1)},e}(V),at=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.CULL_FACE):e.disable(e.CULL_FACE),this.current=t,this.dirty=!1}},e}(V),ot=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.BACK},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.cullFace(t),this.current=t,this.dirty=!1)},e}(V),st=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.CCW},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.frontFace(t),this.current=t,this.dirty=!1)},e}(V),lt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.useProgram(t),this.current=t,this.dirty=!1)},e}(V),ct=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.TEXTURE0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.activeTexture(t),this.current=t,this.dirty=!1)},e}(V),ut=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[0,0,t.drawingBufferWidth,t.drawingBufferHeight]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.viewport(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(V),ht=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindFramebuffer(e.FRAMEBUFFER,t),this.current=t,this.dirty=!1}},e}(V),ft=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindRenderbuffer(e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(V),pt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindTexture(e.TEXTURE_2D,t),this.current=t,this.dirty=!1}},e}(V),dt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindBuffer(e.ARRAY_BUFFER,t),this.current=t,this.dirty=!1}},e}(V),gt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){var e=this.gl;e.bindBuffer(e.ELEMENT_ARRAY_BUFFER,t),this.current=t,this.dirty=!1},e}(V),vt=function(t){function e(e){t.call(this,e),this.vao=e.extVertexArrayObject}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){this.vao&&(t!==this.current||this.dirty)&&(this.vao.bindVertexArrayOES(t),this.current=t,this.dirty=!1)},e}(V),mt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 4},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_ALIGNMENT,t),this.current=t,this.dirty=!1}},e}(V),yt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_PREMULTIPLY_ALPHA_WEBGL,t),this.current=t,this.dirty=!1}},e}(V),xt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_FLIP_Y_WEBGL,t),this.current=t,this.dirty=!1}},e}(V),bt=function(t){function e(e,r){t.call(this,e),this.context=e,this.parent=r}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e}(V),_t=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.setDirty=function(){this.dirty=!0},e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferTexture2D(e.FRAMEBUFFER,e.COLOR_ATTACHMENT0,e.TEXTURE_2D,t,0),this.current=t,this.dirty=!1}},e}(bt),wt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferRenderbuffer(e.FRAMEBUFFER,e.DEPTH_ATTACHMENT,e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(bt),kt=function(t,e,r){this.context=t,this.width=e,this.height=r;var n=t.gl,i=this.framebuffer=n.createFramebuffer();this.colorAttachment=new _t(t,i),this.depthAttachment=new wt(t,i)};kt.prototype.destroy=function(){var t=this.context.gl,e=this.colorAttachment.get();e&&t.deleteTexture(e);var r=this.depthAttachment.get();r&&t.deleteRenderbuffer(r),t.deleteFramebuffer(this.framebuffer)};var Tt=function(t,e,r){this.func=t,this.mask=e,this.range=r};Tt.ReadOnly=!1,Tt.ReadWrite=!0,Tt.disabled=new Tt(519,Tt.ReadOnly,[0,1]);var At=function(t,e,r,n,i,a){this.test=t,this.ref=e,this.mask=r,this.fail=n,this.depthFail=i,this.pass=a};At.disabled=new At({func:519,mask:0},0,0,7680,7680,7680);var Mt=function(t,e,r){this.blendFunction=t,this.blendColor=e,this.mask=r};Mt.disabled=new Mt(Mt.Replace=[1,0],t.Color.transparent,[!1,!1,!1,!1]),Mt.unblended=new Mt(Mt.Replace,t.Color.transparent,[!0,!0,!0,!0]),Mt.alphaBlended=new Mt([1,771],t.Color.transparent,[!0,!0,!0,!0]);var St=function(t,e,r){this.enable=t,this.mode=e,this.frontFace=r};St.disabled=new St(!1,1029,2305),St.backCCW=new St(!0,1029,2305);var Et=function(t){this.gl=t,this.extVertexArrayObject=this.gl.getExtension(\"OES_vertex_array_object\"),this.clearColor=new q(this),this.clearDepth=new H(this),this.clearStencil=new G(this),this.colorMask=new Y(this),this.depthMask=new W(this),this.stencilMask=new X(this),this.stencilFunc=new Z(this),this.stencilOp=new J(this),this.stencilTest=new K(this),this.depthRange=new $(this),this.depthTest=new Q(this),this.depthFunc=new tt(this),this.blend=new et(this),this.blendFunc=new rt(this),this.blendColor=new nt(this),this.blendEquation=new it(this),this.cullFace=new at(this),this.cullFaceSide=new ot(this),this.frontFace=new st(this),this.program=new lt(this),this.activeTexture=new ct(this),this.viewport=new ut(this),this.bindFramebuffer=new ht(this),this.bindRenderbuffer=new ft(this),this.bindTexture=new pt(this),this.bindVertexBuffer=new dt(this),this.bindElementBuffer=new gt(this),this.bindVertexArrayOES=this.extVertexArrayObject&&new vt(this),this.pixelStoreUnpack=new mt(this),this.pixelStoreUnpackPremultiplyAlpha=new yt(this),this.pixelStoreUnpackFlipY=new xt(this),this.extTextureFilterAnisotropic=t.getExtension(\"EXT_texture_filter_anisotropic\")||t.getExtension(\"MOZ_EXT_texture_filter_anisotropic\")||t.getExtension(\"WEBKIT_EXT_texture_filter_anisotropic\"),this.extTextureFilterAnisotropic&&(this.extTextureFilterAnisotropicMax=t.getParameter(this.extTextureFilterAnisotropic.MAX_TEXTURE_MAX_ANISOTROPY_EXT)),this.extTextureHalfFloat=t.getExtension(\"OES_texture_half_float\"),this.extTextureHalfFloat&&t.getExtension(\"OES_texture_half_float_linear\")};Et.prototype.setDefault=function(){this.unbindVAO(),this.clearColor.setDefault(),this.clearDepth.setDefault(),this.clearStencil.setDefault(),this.colorMask.setDefault(),this.depthMask.setDefault(),this.stencilMask.setDefault(),this.stencilFunc.setDefault(),this.stencilOp.setDefault(),this.stencilTest.setDefault(),this.depthRange.setDefault(),this.depthTest.setDefault(),this.depthFunc.setDefault(),this.blend.setDefault(),this.blendFunc.setDefault(),this.blendColor.setDefault(),this.blendEquation.setDefault(),this.cullFace.setDefault(),this.cullFaceSide.setDefault(),this.frontFace.setDefault(),this.program.setDefault(),this.activeTexture.setDefault(),this.bindFramebuffer.setDefault(),this.pixelStoreUnpack.setDefault(),this.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.pixelStoreUnpackFlipY.setDefault()},Et.prototype.setDirty=function(){this.clearColor.dirty=!0,this.clearDepth.dirty=!0,this.clearStencil.dirty=!0,this.colorMask.dirty=!0,this.depthMask.dirty=!0,this.stencilMask.dirty=!0,this.stencilFunc.dirty=!0,this.stencilOp.dirty=!0,this.stencilTest.dirty=!0,this.depthRange.dirty=!0,this.depthTest.dirty=!0,this.depthFunc.dirty=!0,this.blend.dirty=!0,this.blendFunc.dirty=!0,this.blendColor.dirty=!0,this.blendEquation.dirty=!0,this.cullFace.dirty=!0,this.cullFaceSide.dirty=!0,this.frontFace.dirty=!0,this.program.dirty=!0,this.activeTexture.dirty=!0,this.viewport.dirty=!0,this.bindFramebuffer.dirty=!0,this.bindRenderbuffer.dirty=!0,this.bindTexture.dirty=!0,this.bindVertexBuffer.dirty=!0,this.bindElementBuffer.dirty=!0,this.extVertexArrayObject&&(this.bindVertexArrayOES.dirty=!0),this.pixelStoreUnpack.dirty=!0,this.pixelStoreUnpackPremultiplyAlpha.dirty=!0,this.pixelStoreUnpackFlipY.dirty=!0},Et.prototype.createIndexBuffer=function(t,e){return new N(this,t,e)},Et.prototype.createVertexBuffer=function(t,e,r){return new U(this,t,e,r)},Et.prototype.createRenderbuffer=function(t,e,r){var n=this.gl,i=n.createRenderbuffer();return this.bindRenderbuffer.set(i),n.renderbufferStorage(n.RENDERBUFFER,t,e,r),this.bindRenderbuffer.set(null),i},Et.prototype.createFramebuffer=function(t,e){return new kt(this,t,e)},Et.prototype.clear=function(t){var e=t.color,r=t.depth,n=this.gl,i=0;e&&(i|=n.COLOR_BUFFER_BIT,this.clearColor.set(e),this.colorMask.set([!0,!0,!0,!0])),void 0!==r&&(i|=n.DEPTH_BUFFER_BIT,this.depthRange.set([0,1]),this.clearDepth.set(r),this.depthMask.set(!0)),n.clear(i)},Et.prototype.setCullFace=function(t){!1===t.enable?this.cullFace.set(!1):(this.cullFace.set(!0),this.cullFaceSide.set(t.mode),this.frontFace.set(t.frontFace))},Et.prototype.setDepthMode=function(t){t.func!==this.gl.ALWAYS||t.mask?(this.depthTest.set(!0),this.depthFunc.set(t.func),this.depthMask.set(t.mask),this.depthRange.set(t.range)):this.depthTest.set(!1)},Et.prototype.setStencilMode=function(t){t.test.func!==this.gl.ALWAYS||t.mask?(this.stencilTest.set(!0),this.stencilMask.set(t.mask),this.stencilOp.set([t.fail,t.depthFail,t.pass]),this.stencilFunc.set({func:t.test.func,ref:t.ref,mask:t.test.mask})):this.stencilTest.set(!1)},Et.prototype.setColorMode=function(e){t.deepEqual(e.blendFunction,Mt.Replace)?this.blend.set(!1):(this.blend.set(!0),this.blendFunc.set(e.blendFunction),this.blendColor.set(e.blendColor)),this.colorMask.set(e.mask)},Et.prototype.unbindVAO=function(){this.extVertexArrayObject&&this.bindVertexArrayOES.set(null)};var Ct=function(e){function r(r,n,i){var a=this;e.call(this),this.id=r,this.dispatcher=i,this.on(\"data\",function(t){\"source\"===t.dataType&&\"metadata\"===t.sourceDataType&&(a._sourceLoaded=!0),a._sourceLoaded&&!a._paused&&\"source\"===t.dataType&&\"content\"===t.sourceDataType&&(a.reload(),a.transform&&a.update(a.transform))}),this.on(\"error\",function(){a._sourceErrored=!0}),this._source=I(r,n,i,this),this._tiles={},this._cache=new B(0,this._unloadTile.bind(this)),this._timers={},this._cacheTimers={},this._maxTileCacheSize=null,this._coveredTiles={},this._state=new t.SourceFeatureState}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.onAdd=function(t){this.map=t,this._maxTileCacheSize=t?t._maxTileCacheSize:null,this._source&&this._source.onAdd&&this._source.onAdd(t)},r.prototype.onRemove=function(t){this._source&&this._source.onRemove&&this._source.onRemove(t)},r.prototype.loaded=function(){if(this._sourceErrored)return!0;if(!this._sourceLoaded)return!1;for(var t in this._tiles){var e=this._tiles[t];if(\"loaded\"!==e.state&&\"errored\"!==e.state)return!1}return!0},r.prototype.getSource=function(){return this._source},r.prototype.pause=function(){this._paused=!0},r.prototype.resume=function(){if(this._paused){var t=this._shouldReloadOnResume;this._paused=!1,this._shouldReloadOnResume=!1,t&&this.reload(),this.transform&&this.update(this.transform)}},r.prototype._loadTile=function(t,e){return this._source.loadTile(t,e)},r.prototype._unloadTile=function(t){if(this._source.unloadTile)return this._source.unloadTile(t,function(){})},r.prototype._abortTile=function(t){if(this._source.abortTile)return this._source.abortTile(t,function(){})},r.prototype.serialize=function(){return this._source.serialize()},r.prototype.prepare=function(t){for(var e in this._source.prepare&&this._source.prepare(),this._state.coalesceChanges(this._tiles,this.map?this.map.painter:null),this._tiles){var r=this._tiles[e];r.upload(t),r.prepare(this.map.style.imageManager)}},r.prototype.getIds=function(){return Object.keys(this._tiles).map(Number).sort(Lt)},r.prototype.getRenderableIds=function(e){var r=this,n=[];for(var i in this._tiles)this._isIdRenderable(+i,e)&&n.push(+i);return e?n.sort(function(e,n){var i=r._tiles[e].tileID,a=r._tiles[n].tileID,o=new t.Point(i.canonical.x,i.canonical.y)._rotate(r.transform.angle),s=new t.Point(a.canonical.x,a.canonical.y)._rotate(r.transform.angle);return i.overscaledZ-a.overscaledZ||s.y-o.y||s.x-o.x}):n.sort(Lt)},r.prototype.hasRenderableParent=function(t){var e=this.findLoadedParent(t,0);return!!e&&this._isIdRenderable(e.tileID.key)},r.prototype._isIdRenderable=function(t,e){return this._tiles[t]&&this._tiles[t].hasData()&&!this._coveredTiles[t]&&(e||!this._tiles[t].holdingForFade())},r.prototype.reload=function(){if(this._paused)this._shouldReloadOnResume=!0;else for(var t in this._cache.reset(),this._tiles)\"errored\"!==this._tiles[t].state&&this._reloadTile(t,\"reloading\")},r.prototype._reloadTile=function(t,e){var r=this._tiles[t];r&&(\"loading\"!==r.state&&(r.state=e),this._loadTile(r,this._tileLoaded.bind(this,r,t,e)))},r.prototype._tileLoaded=function(e,r,n,i){if(i)return e.state=\"errored\",void(404!==i.status?this._source.fire(new t.ErrorEvent(i,{tile:e})):this.update(this.transform));e.timeAdded=t.browser.now(),\"expired\"===n&&(e.refreshedUponExpiration=!0),this._setTileReloadTimer(r,e),\"raster-dem\"===this.getSource().type&&e.dem&&this._backfillDEM(e),this._state.initializeTileState(e,this.map?this.map.painter:null),this._source.fire(new t.Event(\"data\",{dataType:\"source\",tile:e,coord:e.tileID}))},r.prototype._backfillDEM=function(t){for(var e=this.getRenderableIds(),r=0;r<e.length;r++){var n=e[r];if(t.neighboringTiles&&t.neighboringTiles[n]){var i=this.getTileByID(n);a(t,i),a(i,t)}}function a(t,e){t.needsHillshadePrepare=!0;var r=e.tileID.canonical.x-t.tileID.canonical.x,n=e.tileID.canonical.y-t.tileID.canonical.y,i=Math.pow(2,t.tileID.canonical.z),a=e.tileID.key;0===r&&0===n||Math.abs(n)>1||(Math.abs(r)>1&&(1===Math.abs(r+i)?r+=i:1===Math.abs(r-i)&&(r-=i)),e.dem&&t.dem&&(t.dem.backfillBorder(e.dem,r,n),t.neighboringTiles&&t.neighboringTiles[a]&&(t.neighboringTiles[a].backfilled=!0)))}},r.prototype.getTile=function(t){return this.getTileByID(t.key)},r.prototype.getTileByID=function(t){return this._tiles[t]},r.prototype.getZoom=function(t){return t.zoom+t.scaleZoom(t.tileSize/this._source.tileSize)},r.prototype._retainLoadedChildren=function(t,e,r,n){for(var i in this._tiles){var a=this._tiles[i];if(!(n[i]||!a.hasData()||a.tileID.overscaledZ<=e||a.tileID.overscaledZ>r)){for(var o=a.tileID;a&&a.tileID.overscaledZ>e+1;){var s=a.tileID.scaledTo(a.tileID.overscaledZ-1);(a=this._tiles[s.key])&&a.hasData()&&(o=s)}for(var l=o;l.overscaledZ>e;)if(t[(l=l.scaledTo(l.overscaledZ-1)).key]){n[o.key]=o;break}}}},r.prototype.findLoadedParent=function(t,e){for(var r=t.overscaledZ-1;r>=e;r--){var n=t.scaledTo(r);if(!n)return;var i=String(n.key),a=this._tiles[i];if(a&&a.hasData())return a;if(this._cache.has(n))return this._cache.get(n)}},r.prototype.updateCacheSize=function(t){var e=(Math.ceil(t.width/this._source.tileSize)+1)*(Math.ceil(t.height/this._source.tileSize)+1),r=Math.floor(5*e),n=\"number\"==typeof this._maxTileCacheSize?Math.min(this._maxTileCacheSize,r):r;this._cache.setMaxSize(n)},r.prototype.handleWrapJump=function(t){var e=(t-(void 0===this._prevLng?t:this._prevLng))/360,r=Math.round(e);if(this._prevLng=t,r){var n={};for(var i in this._tiles){var a=this._tiles[i];a.tileID=a.tileID.unwrapTo(a.tileID.wrap+r),n[a.tileID.key]=a}for(var o in this._tiles=n,this._timers)clearTimeout(this._timers[o]),delete this._timers[o];for(var s in this._tiles){var l=this._tiles[s];this._setTileReloadTimer(s,l)}}},r.prototype.update=function(e){var n=this;if(this.transform=e,this._sourceLoaded&&!this._paused){var i;this.updateCacheSize(e),this.handleWrapJump(this.transform.center.lng),this._coveredTiles={},this.used?this._source.tileID?i=e.getVisibleUnwrappedCoordinates(this._source.tileID).map(function(e){return new t.OverscaledTileID(e.canonical.z,e.wrap,e.canonical.z,e.canonical.x,e.canonical.y)}):(i=e.coveringTiles({tileSize:this._source.tileSize,minzoom:this._source.minzoom,maxzoom:this._source.maxzoom,roundZoom:this._source.roundZoom,reparseOverscaled:this._source.reparseOverscaled}),this._source.hasTile&&(i=i.filter(function(t){return n._source.hasTile(t)}))):i=[];var a=(this._source.roundZoom?Math.round:Math.floor)(this.getZoom(e)),o=Math.max(a-r.maxOverzooming,this._source.minzoom),s=Math.max(a+r.maxUnderzooming,this._source.minzoom),l=this._updateRetainedTiles(i,a);if(Pt(this._source.type)){for(var c={},u={},h=0,f=Object.keys(l);h<f.length;h+=1){var p=f[h],d=l[p],g=this._tiles[p];if(g&&!(g.fadeEndTime&&g.fadeEndTime<=t.browser.now())){var v=this.findLoadedParent(d,o);v&&(this._addTile(v.tileID),c[v.tileID.key]=v.tileID),u[p]=d}}for(var m in this._retainLoadedChildren(u,a,s,l),c)l[m]||(this._coveredTiles[m]=!0,l[m]=c[m])}for(var y in l)this._tiles[y].clearFadeHold();for(var x=0,b=t.keysDifference(this._tiles,l);x<b.length;x+=1){var _=b[x],w=this._tiles[_];w.hasSymbolBuckets&&!w.holdingForFade()?w.setHoldDuration(this.map._fadeDuration):w.hasSymbolBuckets&&!w.symbolFadeFinished()||this._removeTile(_)}}},r.prototype.releaseSymbolFadeTiles=function(){for(var t in this._tiles)this._tiles[t].holdingForFade()&&this._removeTile(t)},r.prototype._updateRetainedTiles=function(t,e){for(var n={},i={},a=Math.max(e-r.maxOverzooming,this._source.minzoom),o=Math.max(e+r.maxUnderzooming,this._source.minzoom),s={},l=0,c=t;l<c.length;l+=1){var u=c[l],h=this._addTile(u);n[u.key]=u,h.hasData()||e<this._source.maxzoom&&(s[u.key]=u)}this._retainLoadedChildren(s,e,o,n);for(var f=0,p=t;f<p.length;f+=1){var d=p[f],g=this._tiles[d.key];if(!g.hasData()){if(e+1>this._source.maxzoom){var v=d.children(this._source.maxzoom)[0],m=this.getTile(v);if(m&&m.hasData()){n[v.key]=v;continue}}else{var y=d.children(this._source.maxzoom);if(n[y[0].key]&&n[y[1].key]&&n[y[2].key]&&n[y[3].key])continue}for(var x=g.wasRequested(),b=d.overscaledZ-1;b>=a;--b){var _=d.scaledTo(b);if(i[_.key])break;if(i[_.key]=!0,!(g=this.getTile(_))&&x&&(g=this._addTile(_)),g&&(n[_.key]=_,x=g.wasRequested(),g.hasData()))break}}}return n},r.prototype._addTile=function(e){var r=this._tiles[e.key];if(r)return r;(r=this._cache.getAndRemove(e))&&(this._setTileReloadTimer(e.key,r),r.tileID=e,this._state.initializeTileState(r,this.map?this.map.painter:null),this._cacheTimers[e.key]&&(clearTimeout(this._cacheTimers[e.key]),delete this._cacheTimers[e.key],this._setTileReloadTimer(e.key,r)));var n=Boolean(r);return n||(r=new t.Tile(e,this._source.tileSize*e.overscaleFactor()),this._loadTile(r,this._tileLoaded.bind(this,r,e.key,r.state))),r?(r.uses++,this._tiles[e.key]=r,n||this._source.fire(new t.Event(\"dataloading\",{tile:r,coord:r.tileID,dataType:\"source\"})),r):null},r.prototype._setTileReloadTimer=function(t,e){var r=this;t in this._timers&&(clearTimeout(this._timers[t]),delete this._timers[t]);var n=e.getExpiryTimeout();n&&(this._timers[t]=setTimeout(function(){r._reloadTile(t,\"expired\"),delete r._timers[t]},n))},r.prototype._removeTile=function(t){var e=this._tiles[t];e&&(e.uses--,delete this._tiles[t],this._timers[t]&&(clearTimeout(this._timers[t]),delete this._timers[t]),e.uses>0||(e.hasData()?this._cache.add(e.tileID,e,e.getExpiryTimeout()):(e.aborted=!0,this._abortTile(e),this._unloadTile(e))))},r.prototype.clearTiles=function(){for(var t in this._shouldReloadOnResume=!1,this._paused=!1,this._tiles)this._removeTile(t);this._cache.reset()},r.prototype.tilesIn=function(e,r,n){var i=this,a=[],o=this.transform;if(!o)return a;for(var s=n?o.getCameraQueryGeometry(e):e,l=e.map(function(t){return o.pointCoordinate(t)}),c=s.map(function(t){return o.pointCoordinate(t)}),u=this.getIds(),h=1/0,f=1/0,p=-1/0,d=-1/0,g=0,v=c;g<v.length;g+=1){var m=v[g];h=Math.min(h,m.x),f=Math.min(f,m.y),p=Math.max(p,m.x),d=Math.max(d,m.y)}for(var y=function(e){var n=i._tiles[u[e]];if(!n.holdingForFade()){var s=n.tileID,g=Math.pow(2,o.zoom-n.tileID.overscaledZ),v=r*n.queryPadding*t.EXTENT/n.tileSize/g,m=[s.getTilePoint(new t.MercatorCoordinate(h,f)),s.getTilePoint(new t.MercatorCoordinate(p,d))];if(m[0].x-v<t.EXTENT&&m[0].y-v<t.EXTENT&&m[1].x+v>=0&&m[1].y+v>=0){var y=l.map(function(t){return s.getTilePoint(t)}),x=c.map(function(t){return s.getTilePoint(t)});a.push({tile:n,tileID:s,queryGeometry:y,cameraQueryGeometry:x,scale:g})}}},x=0;x<u.length;x++)y(x);return a},r.prototype.getVisibleCoordinates=function(t){for(var e=this,r=this.getRenderableIds(t).map(function(t){return e._tiles[t].tileID}),n=0,i=r;n<i.length;n+=1){var a=i[n];a.posMatrix=this.transform.calculatePosMatrix(a.toUnwrapped())}return r},r.prototype.hasTransition=function(){if(this._source.hasTransition())return!0;if(Pt(this._source.type))for(var e in this._tiles){var r=this._tiles[e];if(void 0!==r.fadeEndTime&&r.fadeEndTime>=t.browser.now())return!0}return!1},r.prototype.setFeatureState=function(t,e,r){t=t||\"_geojsonTileLayer\",this._state.updateState(t,e,r)},r.prototype.removeFeatureState=function(t,e,r){t=t||\"_geojsonTileLayer\",this._state.removeFeatureState(t,e,r)},r.prototype.getFeatureState=function(t,e){return t=t||\"_geojsonTileLayer\",this._state.getState(t,e)},r}(t.Evented);function Lt(t,e){return t%32-e%32||e-t}function Pt(t){return\"raster\"===t||\"image\"===t||\"video\"===t}function Ot(){return new t.window.Worker(Jn.workerUrl)}Ct.maxOverzooming=10,Ct.maxUnderzooming=3;var zt=function(){this.active={}};zt.prototype.acquire=function(t){if(!this.workers)for(this.workers=[];this.workers.length<zt.workerCount;)this.workers.push(new Ot);return this.active[t]=!0,this.workers.slice()},zt.prototype.release=function(t){delete this.active[t],0===Object.keys(this.active).length&&(this.workers.forEach(function(t){t.terminate()}),this.workers=null)};var It,Dt=Math.floor(t.browser.hardwareConcurrency/2);function Rt(e,r){var n={};for(var i in e)\"ref\"!==i&&(n[i]=e[i]);return t.refProperties.forEach(function(t){t in r&&(n[t]=r[t])}),n}function Ft(t){t=t.slice();for(var e=Object.create(null),r=0;r<t.length;r++)e[t[r].id]=t[r];for(var n=0;n<t.length;n++)\"ref\"in t[n]&&(t[n]=Rt(t[n],e[t[n].ref]));return t}zt.workerCount=Math.max(Math.min(Dt,6),1);var Bt={setStyle:\"setStyle\",addLayer:\"addLayer\",removeLayer:\"removeLayer\",setPaintProperty:\"setPaintProperty\",setLayoutProperty:\"setLayoutProperty\",setFilter:\"setFilter\",addSource:\"addSource\",removeSource:\"removeSource\",setGeoJSONSourceData:\"setGeoJSONSourceData\",setLayerZoomRange:\"setLayerZoomRange\",setLayerProperty:\"setLayerProperty\",setCenter:\"setCenter\",setZoom:\"setZoom\",setBearing:\"setBearing\",setPitch:\"setPitch\",setSprite:\"setSprite\",setGlyphs:\"setGlyphs\",setTransition:\"setTransition\",setLight:\"setLight\"};function Nt(t,e,r){r.push({command:Bt.addSource,args:[t,e[t]]})}function jt(t,e,r){e.push({command:Bt.removeSource,args:[t]}),r[t]=!0}function Ut(t,e,r,n){jt(t,r,n),Nt(t,e,r)}function Vt(e,r,n){var i;for(i in e[n])if(e[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;for(i in r[n])if(r[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;return!0}function qt(e,r,n,i,a,o){var s;for(s in r=r||{},e=e||{})e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}));for(s in r)r.hasOwnProperty(s)&&!e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}))}function Ht(t){return t.id}function Gt(t,e){return t[e.id]=e,t}var Yt=function(t,e,r){var n=this.boxCells=[],i=this.circleCells=[];this.xCellCount=Math.ceil(t/r),this.yCellCount=Math.ceil(e/r);for(var a=0;a<this.xCellCount*this.yCellCount;a++)n.push([]),i.push([]);this.circleKeys=[],this.boxKeys=[],this.bboxes=[],this.circles=[],this.width=t,this.height=e,this.xScale=this.xCellCount/t,this.yScale=this.yCellCount/e,this.boxUid=0,this.circleUid=0};function Wt(e,r,n,i,a){var o=t.create();return r?(t.scale(o,o,[1/a,1/a,1]),n||t.rotateZ(o,o,i.angle)):t.multiply(o,i.labelPlaneMatrix,e),o}function Xt(e,r,n,i,a){if(r){var o=t.clone(e);return t.scale(o,o,[a,a,1]),n||t.rotateZ(o,o,-i.angle),o}return i.glCoordMatrix}function Zt(e,r){var n=[e.x,e.y,0,1];ae(n,n,r);var i=n[3];return{point:new t.Point(n[0]/i,n[1]/i),signedDistanceFromCamera:i}}function Jt(t,e){var r=t[0]/t[3],n=t[1]/t[3];return r>=-e[0]&&r<=e[0]&&n>=-e[1]&&n<=e[1]}function Kt(e,r,n,i,a,o,s,l){var c=i?e.textSizeData:e.iconSizeData,u=t.evaluateSizeForZoom(c,n.transform.zoom),h=[256/n.width*2+1,256/n.height*2+1],f=i?e.text.dynamicLayoutVertexArray:e.icon.dynamicLayoutVertexArray;f.clear();for(var p=e.lineVertexArray,d=i?e.text.placedSymbolArray:e.icon.placedSymbolArray,g=n.transform.width/n.transform.height,v=!1,m=0;m<d.length;m++){var y=d.get(m);if(y.hidden||y.writingMode===t.WritingMode.vertical&&!v)ie(y.numGlyphs,f);else{v=!1;var x=[y.anchorX,y.anchorY,0,1];if(t.transformMat4(x,x,r),Jt(x,h)){var b=.5+x[3]/n.transform.cameraToCenterDistance*.5,_=t.evaluateSizeForFeature(c,u,y),w=s?_*b:_/b,k=new t.Point(y.anchorX,y.anchorY),T=Zt(k,a).point,A={},M=te(y,w,!1,l,r,a,o,e.glyphOffsetArray,p,f,T,k,A,g);v=M.useVertical,(M.notEnoughRoom||v||M.needsFlipping&&te(y,w,!0,l,r,a,o,e.glyphOffsetArray,p,f,T,k,A,g).notEnoughRoom)&&ie(y.numGlyphs,f)}else ie(y.numGlyphs,f)}}i?e.text.dynamicLayoutVertexBuffer.updateData(f):e.icon.dynamicLayoutVertexBuffer.updateData(f)}function $t(t,e,r,n,i,a,o,s,l,c,u,h){var f=s.glyphStartIndex+s.numGlyphs,p=s.lineStartIndex,d=s.lineStartIndex+s.lineLength,g=e.getoffsetX(s.glyphStartIndex),v=e.getoffsetX(f-1),m=re(t*g,r,n,i,a,o,s.segment,p,d,l,c,u,h);if(!m)return null;var y=re(t*v,r,n,i,a,o,s.segment,p,d,l,c,u,h);return y?{first:m,last:y}:null}function Qt(e,r,n,i){return e===t.WritingMode.horizontal&&Math.abs(n.y-r.y)>Math.abs(n.x-r.x)*i?{useVertical:!0}:(e===t.WritingMode.vertical?r.y<n.y:r.x>n.x)?{needsFlipping:!0}:null}function te(e,r,n,i,a,o,s,l,c,u,h,f,p,d){var g,v=r/24,m=e.lineOffsetX*v,y=e.lineOffsetY*v;if(e.numGlyphs>1){var x=e.glyphStartIndex+e.numGlyphs,b=e.lineStartIndex,_=e.lineStartIndex+e.lineLength,w=$t(v,l,m,y,n,h,f,e,c,o,p,!1);if(!w)return{notEnoughRoom:!0};var k=Zt(w.first.point,s).point,T=Zt(w.last.point,s).point;if(i&&!n){var A=Qt(e.writingMode,k,T,d);if(A)return A}g=[w.first];for(var M=e.glyphStartIndex+1;M<x-1;M++)g.push(re(v*l.getoffsetX(M),m,y,n,h,f,e.segment,b,_,c,o,p,!1));g.push(w.last)}else{if(i&&!n){var S=Zt(f,a).point,E=e.lineStartIndex+e.segment+1,C=new t.Point(c.getx(E),c.gety(E)),L=Zt(C,a),P=L.signedDistanceFromCamera>0?L.point:ee(f,C,S,1,a),O=Qt(e.writingMode,S,P,d);if(O)return O}var z=re(v*l.getoffsetX(e.glyphStartIndex),m,y,n,h,f,e.segment,e.lineStartIndex,e.lineStartIndex+e.lineLength,c,o,p,!1);if(!z)return{notEnoughRoom:!0};g=[z]}for(var I=0,D=g;I<D.length;I+=1){var R=D[I];t.addDynamicAttributes(u,R.point,R.angle)}return{}}function ee(t,e,r,n,i){var a=Zt(t.add(t.sub(e)._unit()),i).point,o=r.sub(a);return r.add(o._mult(n/o.mag()))}function re(e,r,n,i,a,o,s,l,c,u,h,f,p){var d=i?e-r:e+r,g=d>0?1:-1,v=0;i&&(g*=-1,v=Math.PI),g<0&&(v+=Math.PI);for(var m=g>0?l+s:l+s+1,y=m,x=a,b=a,_=0,w=0,k=Math.abs(d);_+w<=k;){if((m+=g)<l||m>=c)return null;if(b=x,void 0===(x=f[m])){var T=new t.Point(u.getx(m),u.gety(m)),A=Zt(T,h);if(A.signedDistanceFromCamera>0)x=f[m]=A.point;else{var M=m-g;x=ee(0===_?o:new t.Point(u.getx(M),u.gety(M)),T,b,k-_+1,h)}}_+=w,w=b.dist(x)}var S=(k-_)/w,E=x.sub(b),C=E.mult(S)._add(b);return C._add(E._unit()._perp()._mult(n*g)),{point:C,angle:v+Math.atan2(x.y-b.y,x.x-b.x),tileDistance:p?{prevTileDistance:m-g===y?0:u.gettileUnitDistanceFromAnchor(m-g),lastSegmentViewportDistance:k-_}:null}}Yt.prototype.keysLength=function(){return this.boxKeys.length+this.circleKeys.length},Yt.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertBoxCell,this.boxUid++),this.boxKeys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},Yt.prototype.insertCircle=function(t,e,r,n){this._forEachCell(e-n,r-n,e+n,r+n,this._insertCircleCell,this.circleUid++),this.circleKeys.push(t),this.circles.push(e),this.circles.push(r),this.circles.push(n)},Yt.prototype._insertBoxCell=function(t,e,r,n,i,a){this.boxCells[i].push(a)},Yt.prototype._insertCircleCell=function(t,e,r,n,i,a){this.circleCells[i].push(a)},Yt.prototype._query=function(t,e,r,n,i,a){if(r<0||t>this.width||n<0||e>this.height)return!i&&[];var o=[];if(t<=0&&e<=0&&this.width<=r&&this.height<=n){if(i)return!0;for(var s=0;s<this.boxKeys.length;s++)o.push({key:this.boxKeys[s],x1:this.bboxes[4*s],y1:this.bboxes[4*s+1],x2:this.bboxes[4*s+2],y2:this.bboxes[4*s+3]});for(var l=0;l<this.circleKeys.length;l++){var c=this.circles[3*l],u=this.circles[3*l+1],h=this.circles[3*l+2];o.push({key:this.circleKeys[l],x1:c-h,y1:u-h,x2:c+h,y2:u+h})}return a?o.filter(a):o}var f={hitTest:i,seenUids:{box:{},circle:{}}};return this._forEachCell(t,e,r,n,this._queryCell,o,f,a),i?o.length>0:o},Yt.prototype._queryCircle=function(t,e,r,n,i){var a=t-r,o=t+r,s=e-r,l=e+r;if(o<0||a>this.width||l<0||s>this.height)return!n&&[];var c=[],u={hitTest:n,circle:{x:t,y:e,radius:r},seenUids:{box:{},circle:{}}};return this._forEachCell(a,s,o,l,this._queryCellCircle,c,u,i),n?c.length>0:c},Yt.prototype.query=function(t,e,r,n,i){return this._query(t,e,r,n,!1,i)},Yt.prototype.hitTest=function(t,e,r,n,i){return this._query(t,e,r,n,!0,i)},Yt.prototype.hitTestCircle=function(t,e,r,n){return this._queryCircle(t,e,r,!0,n)},Yt.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=o.seenUids,c=this.boxCells[i];if(null!==c)for(var u=this.bboxes,h=0,f=c;h<f.length;h+=1){var p=f[h];if(!l.box[p]){l.box[p]=!0;var d=4*p;if(t<=u[d+2]&&e<=u[d+3]&&r>=u[d+0]&&n>=u[d+1]&&(!s||s(this.boxKeys[p]))){if(o.hitTest)return a.push(!0),!0;a.push({key:this.boxKeys[p],x1:u[d],y1:u[d+1],x2:u[d+2],y2:u[d+3]})}}}var g=this.circleCells[i];if(null!==g)for(var v=this.circles,m=0,y=g;m<y.length;m+=1){var x=y[m];if(!l.circle[x]){l.circle[x]=!0;var b=3*x;if(this._circleAndRectCollide(v[b],v[b+1],v[b+2],t,e,r,n)&&(!s||s(this.circleKeys[x]))){if(o.hitTest)return a.push(!0),!0;var _=v[b],w=v[b+1],k=v[b+2];a.push({key:this.circleKeys[x],x1:_-k,y1:w-k,x2:_+k,y2:w+k})}}}},Yt.prototype._queryCellCircle=function(t,e,r,n,i,a,o,s){var l=o.circle,c=o.seenUids,u=this.boxCells[i];if(null!==u)for(var h=this.bboxes,f=0,p=u;f<p.length;f+=1){var d=p[f];if(!c.box[d]){c.box[d]=!0;var g=4*d;if(this._circleAndRectCollide(l.x,l.y,l.radius,h[g+0],h[g+1],h[g+2],h[g+3])&&(!s||s(this.boxKeys[d])))return a.push(!0),!0}}var v=this.circleCells[i];if(null!==v)for(var m=this.circles,y=0,x=v;y<x.length;y+=1){var b=x[y];if(!c.circle[b]){c.circle[b]=!0;var _=3*b;if(this._circlesCollide(m[_],m[_+1],m[_+2],l.x,l.y,l.radius)&&(!s||s(this.circleKeys[b])))return a.push(!0),!0}}},Yt.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToXCellCoord(t),c=this._convertToYCellCoord(e),u=this._convertToXCellCoord(r),h=this._convertToYCellCoord(n),f=l;f<=u;f++)for(var p=c;p<=h;p++){var d=this.xCellCount*p+f;if(i.call(this,t,e,r,n,d,a,o,s))return}},Yt.prototype._convertToXCellCoord=function(t){return Math.max(0,Math.min(this.xCellCount-1,Math.floor(t*this.xScale)))},Yt.prototype._convertToYCellCoord=function(t){return Math.max(0,Math.min(this.yCellCount-1,Math.floor(t*this.yScale)))},Yt.prototype._circlesCollide=function(t,e,r,n,i,a){var o=n-t,s=i-e,l=r+a;return l*l>o*o+s*s},Yt.prototype._circleAndRectCollide=function(t,e,r,n,i,a,o){var s=(a-n)/2,l=Math.abs(t-(n+s));if(l>s+r)return!1;var c=(o-i)/2,u=Math.abs(e-(i+c));if(u>c+r)return!1;if(l<=s||u<=c)return!0;var h=l-s,f=u-c;return h*h+f*f<=r*r};var ne=new Float32Array([-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0]);function ie(t,e){for(var r=0;r<t;r++){var n=e.length;e.resize(n+4),e.float32.set(ne,3*n)}}function ae(t,e,r){var n=e[0],i=e[1];return t[0]=r[0]*n+r[4]*i+r[12],t[1]=r[1]*n+r[5]*i+r[13],t[3]=r[3]*n+r[7]*i+r[15],t}var oe=function(t,e,r){void 0===e&&(e=new Yt(t.width+200,t.height+200,25)),void 0===r&&(r=new Yt(t.width+200,t.height+200,25)),this.transform=t,this.grid=e,this.ignoredGrid=r,this.pitchfactor=Math.cos(t._pitch)*t.cameraToCenterDistance,this.screenRightBoundary=t.width+100,this.screenBottomBoundary=t.height+100,this.gridRightBoundary=t.width+200,this.gridBottomBoundary=t.height+200};function se(t,e,r){t[e+4]=r?1:0}function le(e,r,n){return r*(t.EXTENT/(e.tileSize*Math.pow(2,n-e.tileID.overscaledZ)))}oe.prototype.placeCollisionBox=function(t,e,r,n,i){var a=this.projectAndGetPerspectiveRatio(n,t.anchorPointX,t.anchorPointY),o=r*a.perspectiveRatio,s=t.x1*o+a.point.x,l=t.y1*o+a.point.y,c=t.x2*o+a.point.x,u=t.y2*o+a.point.y;return!this.isInsideGrid(s,l,c,u)||!e&&this.grid.hitTest(s,l,c,u,i)?{box:[],offscreen:!1}:{box:[s,l,c,u],offscreen:this.isOffscreen(s,l,c,u)}},oe.prototype.approximateTileDistance=function(t,e,r,n,i){var a=i?1:n/this.pitchfactor,o=t.lastSegmentViewportDistance*r;return t.prevTileDistance+o+(a-1)*o*Math.abs(Math.sin(e))},oe.prototype.placeCollisionCircles=function(e,r,n,i,a,o,s,l,c,u,h,f,p){var d=[],g=this.projectAnchor(c,a.anchorX,a.anchorY),v=l/24,m=a.lineOffsetX*l,y=a.lineOffsetY*l,x=new t.Point(a.anchorX,a.anchorY),b=$t(v,s,m,y,!1,Zt(x,u).point,x,a,o,u,{},!0),_=!1,w=!1,k=!0,T=g.perspectiveRatio*i,A=1/(i*n),M=0,S=0;b&&(M=this.approximateTileDistance(b.first.tileDistance,b.first.angle,A,g.cameraDistance,f),S=this.approximateTileDistance(b.last.tileDistance,b.last.angle,A,g.cameraDistance,f));for(var E=0;E<e.length;E+=5){var C=e[E],L=e[E+1],P=e[E+2],O=e[E+3];if(!b||O<-M||O>S)se(e,E,!1);else{var z=this.projectPoint(c,C,L),I=P*T;if(d.length>0){var D=z.x-d[d.length-4],R=z.y-d[d.length-3];if(I*I*2>D*D+R*R&&E+8<e.length){var F=e[E+8];if(F>-M&&F<S){se(e,E,!1);continue}}}var B=E/5;d.push(z.x,z.y,I,B),se(e,E,!0);var N=z.x-I,j=z.y-I,U=z.x+I,V=z.y+I;if(k=k&&this.isOffscreen(N,j,U,V),w=w||this.isInsideGrid(N,j,U,V),!r&&this.grid.hitTestCircle(z.x,z.y,I,p)){if(!h)return{circles:[],offscreen:!1};_=!0}}}return{circles:_||!w?[]:d,offscreen:k}},oe.prototype.queryRenderedSymbols=function(e){if(0===e.length||0===this.grid.keysLength()&&0===this.ignoredGrid.keysLength())return{};for(var r=[],n=1/0,i=1/0,a=-1/0,o=-1/0,s=0,l=e;s<l.length;s+=1){var c=l[s],u=new t.Point(c.x+100,c.y+100);n=Math.min(n,u.x),i=Math.min(i,u.y),a=Math.max(a,u.x),o=Math.max(o,u.y),r.push(u)}for(var h={},f={},p=0,d=this.grid.query(n,i,a,o).concat(this.ignoredGrid.query(n,i,a,o));p<d.length;p+=1){var g=d[p],v=g.key;if(void 0===h[v.bucketInstanceId]&&(h[v.bucketInstanceId]={}),!h[v.bucketInstanceId][v.featureIndex]){var m=[new t.Point(g.x1,g.y1),new t.Point(g.x2,g.y1),new t.Point(g.x2,g.y2),new t.Point(g.x1,g.y2)];t.polygonIntersectsPolygon(r,m)&&(h[v.bucketInstanceId][v.featureIndex]=!0,void 0===f[v.bucketInstanceId]&&(f[v.bucketInstanceId]=[]),f[v.bucketInstanceId].push(v.featureIndex))}}return f},oe.prototype.insertCollisionBox=function(t,e,r,n,i){var a={bucketInstanceId:r,featureIndex:n,collisionGroupID:i};(e?this.ignoredGrid:this.grid).insert(a,t[0],t[1],t[2],t[3])},oe.prototype.insertCollisionCircles=function(t,e,r,n,i){for(var a=e?this.ignoredGrid:this.grid,o={bucketInstanceId:r,featureIndex:n,collisionGroupID:i},s=0;s<t.length;s+=4)a.insertCircle(o,t[s],t[s+1],t[s+2])},oe.prototype.projectAnchor=function(t,e,r){var n=[e,r,0,1];return ae(n,n,t),{perspectiveRatio:.5+this.transform.cameraToCenterDistance/n[3]*.5,cameraDistance:n[3]}},oe.prototype.projectPoint=function(e,r,n){var i=[r,n,0,1];return ae(i,i,e),new t.Point((i[0]/i[3]+1)/2*this.transform.width+100,(-i[1]/i[3]+1)/2*this.transform.height+100)},oe.prototype.projectAndGetPerspectiveRatio=function(e,r,n){var i=[r,n,0,1];return ae(i,i,e),{point:new t.Point((i[0]/i[3]+1)/2*this.transform.width+100,(-i[1]/i[3]+1)/2*this.transform.height+100),perspectiveRatio:.5+this.transform.cameraToCenterDistance/i[3]*.5}},oe.prototype.isOffscreen=function(t,e,r,n){return r<100||t>=this.screenRightBoundary||n<100||e>this.screenBottomBoundary},oe.prototype.isInsideGrid=function(t,e,r,n){return r>=0&&t<this.gridRightBoundary&&n>=0&&e<this.gridBottomBoundary};var ce=function(t,e,r,n){this.opacity=t?Math.max(0,Math.min(1,t.opacity+(t.placed?e:-e))):n&&r?1:0,this.placed=r};ce.prototype.isHidden=function(){return 0===this.opacity&&!this.placed};var ue=function(t,e,r,n,i){this.text=new ce(t?t.text:null,e,r,i),this.icon=new ce(t?t.icon:null,e,n,i)};ue.prototype.isHidden=function(){return this.text.isHidden()&&this.icon.isHidden()};var he=function(t,e,r){this.text=t,this.icon=e,this.skipFade=r},fe=function(t,e,r,n,i){this.bucketInstanceId=t,this.featureIndex=e,this.sourceLayerIndex=r,this.bucketIndex=n,this.tileID=i},pe=function(t){this.crossSourceCollisions=t,this.maxGroupID=0,this.collisionGroups={}};function de(e,r,n,i,a){var o=t.getAnchorAlignment(e),s=-(o.horizontalAlign-.5)*r,l=-(o.verticalAlign-.5)*n,c=t.evaluateRadialOffset(e,i);return new t.Point(s+c[0]*a,l+c[1]*a)}pe.prototype.get=function(t){if(this.crossSourceCollisions)return{ID:0,predicate:null};if(!this.collisionGroups[t]){var e=++this.maxGroupID;this.collisionGroups[t]={ID:e,predicate:function(t){return t.collisionGroupID===e}}}return this.collisionGroups[t]};var ge=function(t,e,r,n){this.transform=t.clone(),this.collisionIndex=new oe(this.transform),this.placements={},this.opacities={},this.variableOffsets={},this.stale=!1,this.commitTime=0,this.fadeDuration=e,this.retainedQueryData={},this.collisionGroups=new pe(r),this.prevPlacement=n,n&&(n.prevPlacement=void 0)};function ve(t,e,r,n,i){t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0)}ge.prototype.placeLayerTile=function(e,r,n,i){var a=r.getBucket(e),o=r.latestFeatureIndex;if(a&&o&&e.id===a.layerIds[0]){var s=r.collisionBoxArray,l=a.layers[0].layout,c=Math.pow(2,this.transform.zoom-r.tileID.overscaledZ),u=r.tileSize/t.EXTENT,h=this.transform.calculatePosMatrix(r.tileID.toUnwrapped()),f=Wt(h,\"map\"===l.get(\"text-pitch-alignment\"),\"map\"===l.get(\"text-rotation-alignment\"),this.transform,le(r,1,this.transform.zoom)),p=Wt(h,\"map\"===l.get(\"icon-pitch-alignment\"),\"map\"===l.get(\"icon-rotation-alignment\"),this.transform,le(r,1,this.transform.zoom));this.retainedQueryData[a.bucketInstanceId]=new fe(a.bucketInstanceId,o,a.sourceLayerIndex,a.index,r.tileID),this.placeLayerBucket(a,h,f,p,c,u,n,r.holdingForFade(),i,s)}},ge.prototype.attemptAnchorPlacement=function(e,r,n,i,a,o,s,l,c,u,h,f,p,d){var g,v=de(e,n,i,a,o),m=this.collisionIndex.placeCollisionBox(function(e,r,n,i,a,o){var s=e.x1,l=e.x2,c=e.y1,u=e.y2,h=e.anchorPointX,f=e.anchorPointY,p=new t.Point(r,n);return i&&p._rotate(a?o:-o),{x1:s+p.x,y1:c+p.y,x2:l+p.x,y2:u+p.y,anchorPointX:h,anchorPointY:f}}(r,v.x,v.y,s,l,this.transform.angle),f,c,u,h.predicate);if(m.box.length>0)return this.prevPlacement&&this.prevPlacement.variableOffsets[p.crossTileID]&&this.prevPlacement.placements[p.crossTileID]&&this.prevPlacement.placements[p.crossTileID].text&&(g=this.prevPlacement.variableOffsets[p.crossTileID].anchor),this.variableOffsets[p.crossTileID]={radialOffset:a,width:n,height:i,anchor:e,textBoxScale:o,prevAnchor:g},this.markUsedJustification(d,e,p),m},ge.prototype.placeLayerBucket=function(e,r,n,i,a,o,s,l,c,u){var h=this,f=e.layers[0].layout,p=t.evaluateSizeForZoom(e.textSizeData,this.transform.zoom),d=f.get(\"text-optional\"),g=f.get(\"icon-optional\"),v=f.get(\"text-allow-overlap\"),m=f.get(\"icon-allow-overlap\"),y=v&&(m||!e.hasIconData()||g),x=m&&(v||!e.hasTextData()||d),b=this.collisionGroups.get(e.sourceID),_=\"map\"===f.get(\"text-rotation-alignment\"),w=\"map\"===f.get(\"text-pitch-alignment\"),k=\"viewport-y\"===f.get(\"symbol-z-order\");!e.collisionArrays&&u&&e.deserializeCollisionBoxes(u);var T=function(i,u){if(!c[i.crossTileID])if(l)h.placements[i.crossTileID]=new he(!1,!1,!1);else{var m=!1,k=!1,T=!0,A=null,M=null,S=null,E=0,C=0;u.textFeatureIndex&&(E=u.textFeatureIndex);var L=u.textBox;if(L)if(f.get(\"text-variable-anchor\")){var P=L.x2-L.x1,O=L.y2-L.y1,z=i.textBoxScale,I=f.get(\"text-variable-anchor\");if(h.prevPlacement&&h.prevPlacement.variableOffsets[i.crossTileID]){var D=h.prevPlacement.variableOffsets[i.crossTileID];I[0]!==D.anchor&&(I=I.filter(function(t){return t!==D.anchor})).unshift(D.anchor)}for(var R=0,F=I;R<F.length;R+=1){var B=F[R];if(A=h.attemptAnchorPlacement(B,L,P,O,i.radialTextOffset,z,_,w,o,r,b,v,i,e)){m=!0;break}}if(!h.variableOffsets[i.crossTileID]&&h.prevPlacement){var N=h.prevPlacement.variableOffsets[i.crossTileID];N&&(h.variableOffsets[i.crossTileID]=N,h.markUsedJustification(e,N.anchor,i))}}else m=(A=h.collisionIndex.placeCollisionBox(L,f.get(\"text-allow-overlap\"),o,r,b.predicate)).box.length>0;T=A&&A.offscreen;var j=u.textCircles;if(j){var U=e.text.placedSymbolArray.get(i.centerJustifiedTextSymbolIndex),V=t.evaluateSizeForFeature(e.textSizeData,p,U);M=h.collisionIndex.placeCollisionCircles(j,f.get(\"text-allow-overlap\"),a,o,U,e.lineVertexArray,e.glyphOffsetArray,V,r,n,s,w,b.predicate),m=f.get(\"text-allow-overlap\")||M.circles.length>0,T=T&&M.offscreen}u.iconFeatureIndex&&(C=u.iconFeatureIndex),u.iconBox&&(k=(S=h.collisionIndex.placeCollisionBox(u.iconBox,f.get(\"icon-allow-overlap\"),o,r,b.predicate)).box.length>0,T=T&&S.offscreen);var q=d||0===i.numHorizontalGlyphVertices&&0===i.numVerticalGlyphVertices,H=g||0===i.numIconVertices;q||H?H?q||(k=k&&m):m=k&&m:k=m=k&&m,m&&A&&h.collisionIndex.insertCollisionBox(A.box,f.get(\"text-ignore-placement\"),e.bucketInstanceId,E,b.ID),k&&S&&h.collisionIndex.insertCollisionBox(S.box,f.get(\"icon-ignore-placement\"),e.bucketInstanceId,C,b.ID),m&&M&&h.collisionIndex.insertCollisionCircles(M.circles,f.get(\"text-ignore-placement\"),e.bucketInstanceId,E,b.ID),h.placements[i.crossTileID]=new he(m||y,k||x,T||e.justReloaded),c[i.crossTileID]=!0}};if(k)for(var A=e.getSortedSymbolIndexes(this.transform.angle),M=A.length-1;M>=0;--M){var S=A[M];T(e.symbolInstances.get(S),e.collisionArrays[S])}else for(var E=0;E<e.symbolInstances.length;++E)T(e.symbolInstances.get(E),e.collisionArrays[E]);e.justReloaded=!1},ge.prototype.markUsedJustification=function(e,r,n){var i={left:n.leftJustifiedTextSymbolIndex,center:n.centerJustifiedTextSymbolIndex,right:n.rightJustifiedTextSymbolIndex},a=i[t.getAnchorJustification(r)];for(var o in i){var s=i[o];s>=0&&(e.text.placedSymbolArray.get(s).crossTileID=a>=0&&s!==a?0:n.crossTileID)}},ge.prototype.commit=function(t){this.commitTime=t;var e=this.prevPlacement,r=!1,n=e&&0!==this.fadeDuration?(this.commitTime-e.commitTime)/this.fadeDuration:1,i=e?e.opacities:{},a=e?e.variableOffsets:{};for(var o in this.placements){var s=this.placements[o],l=i[o];l?(this.opacities[o]=new ue(l,n,s.text,s.icon),r=r||s.text!==l.text.placed||s.icon!==l.icon.placed):(this.opacities[o]=new ue(null,n,s.text,s.icon,s.skipFade),r=r||s.text||s.icon)}for(var c in i){var u=i[c];if(!this.opacities[c]){var h=new ue(u,n,!1,!1);h.isHidden()||(this.opacities[c]=h,r=r||u.text.placed||u.icon.placed)}}for(var f in a)this.variableOffsets[f]||!this.opacities[f]||this.opacities[f].isHidden()||(this.variableOffsets[f]=a[f]);r?this.lastPlacementChangeTime=t:\"number\"!=typeof this.lastPlacementChangeTime&&(this.lastPlacementChangeTime=e?e.lastPlacementChangeTime:t)},ge.prototype.updateLayerOpacities=function(t,e){for(var r={},n=0,i=e;n<i.length;n+=1){var a=i[n],o=a.getBucket(t);o&&a.latestFeatureIndex&&t.id===o.layerIds[0]&&this.updateBucketOpacities(o,r,a.collisionBoxArray)}},ge.prototype.updateBucketOpacities=function(e,r,n){e.hasTextData()&&e.text.opacityVertexArray.clear(),e.hasIconData()&&e.icon.opacityVertexArray.clear(),e.hasCollisionBoxData()&&e.collisionBox.collisionVertexArray.clear(),e.hasCollisionCircleData()&&e.collisionCircle.collisionVertexArray.clear();var i=e.layers[0].layout,a=new ue(null,0,!1,!1,!0),o=i.get(\"text-allow-overlap\"),s=i.get(\"icon-allow-overlap\"),l=i.get(\"text-variable-anchor\"),c=\"map\"===i.get(\"text-rotation-alignment\"),u=\"map\"===i.get(\"text-pitch-alignment\"),h=new ue(null,0,o&&(s||!e.hasIconData()||i.get(\"icon-optional\")),s&&(o||!e.hasTextData()||i.get(\"text-optional\")),!0);!e.collisionArrays&&n&&(e.hasCollisionBoxData()||e.hasCollisionCircleData())&&e.deserializeCollisionBoxes(n);for(var f=0;f<e.symbolInstances.length;f++){var p=e.symbolInstances.get(f),d=p.numHorizontalGlyphVertices,g=p.numVerticalGlyphVertices,v=p.crossTileID,m=r[v],y=this.opacities[v];m?y=a:y||(y=h,this.opacities[v]=y),r[v]=!0;var x=d>0||g>0,b=p.numIconVertices>0;if(x){for(var _=Te(y.text),w=(d+g)/4,k=0;k<w;k++)e.text.opacityVertexArray.emplaceBack(_);var T=y.text.isHidden()?1:0;[p.rightJustifiedTextSymbolIndex,p.centerJustifiedTextSymbolIndex,p.leftJustifiedTextSymbolIndex,p.verticalPlacedTextSymbolIndex].forEach(function(t){t>=0&&(e.text.placedSymbolArray.get(t).hidden=T)});var A=this.variableOffsets[p.crossTileID];A&&this.markUsedJustification(e,A.anchor,p)}if(b){for(var M=Te(y.icon),S=0;S<p.numIconVertices/4;S++)e.icon.opacityVertexArray.emplaceBack(M);e.icon.placedSymbolArray.get(f).hidden=y.icon.isHidden()}if(e.hasCollisionBoxData()||e.hasCollisionCircleData()){var E=e.collisionArrays[f];if(E){if(E.textBox){var C=new t.Point(0,0),L=!0;if(l){var P=this.variableOffsets[v];P?(C=de(P.anchor,P.width,P.height,P.radialOffset,P.textBoxScale),c&&C._rotate(u?this.transform.angle:-this.transform.angle)):L=!1}ve(e.collisionBox.collisionVertexArray,y.text.placed,!L,C.x,C.y)}E.iconBox&&ve(e.collisionBox.collisionVertexArray,y.icon.placed,!1);var O=E.textCircles;if(O&&e.hasCollisionCircleData())for(var z=0;z<O.length;z+=5){var I=m||0===O[z+4];ve(e.collisionCircle.collisionVertexArray,y.text.placed,I)}}}}e.sortFeatures(this.transform.angle),this.retainedQueryData[e.bucketInstanceId]&&(this.retainedQueryData[e.bucketInstanceId].featureSortOrder=e.featureSortOrder),e.hasTextData()&&e.text.opacityVertexBuffer&&e.text.opacityVertexBuffer.updateData(e.text.opacityVertexArray),e.hasIconData()&&e.icon.opacityVertexBuffer&&e.icon.opacityVertexBuffer.updateData(e.icon.opacityVertexArray),e.hasCollisionBoxData()&&e.collisionBox.collisionVertexBuffer&&e.collisionBox.collisionVertexBuffer.updateData(e.collisionBox.collisionVertexArray),e.hasCollisionCircleData()&&e.collisionCircle.collisionVertexBuffer&&e.collisionCircle.collisionVertexBuffer.updateData(e.collisionCircle.collisionVertexArray)},ge.prototype.symbolFadeChange=function(t){return 0===this.fadeDuration?1:(t-this.commitTime)/this.fadeDuration},ge.prototype.hasTransitions=function(t){return this.stale||t-this.lastPlacementChangeTime<this.fadeDuration},ge.prototype.stillRecent=function(t){return this.commitTime+this.fadeDuration>t},ge.prototype.setStale=function(){this.stale=!0};var me=Math.pow(2,25),ye=Math.pow(2,24),xe=Math.pow(2,17),be=Math.pow(2,16),_e=Math.pow(2,9),we=Math.pow(2,8),ke=Math.pow(2,1);function Te(t){if(0===t.opacity&&!t.placed)return 0;if(1===t.opacity&&t.placed)return 4294967295;var e=t.placed?1:0,r=Math.floor(127*t.opacity);return r*me+e*ye+r*xe+e*be+r*_e+e*we+r*ke+e}var Ae=function(){this._currentTileIndex=0,this._seenCrossTileIDs={}};Ae.prototype.continuePlacement=function(t,e,r,n,i){for(;this._currentTileIndex<t.length;){var a=t[this._currentTileIndex];if(e.placeLayerTile(n,a,r,this._seenCrossTileIDs),this._currentTileIndex++,i())return!0}};var Me=function(t,e,r,n,i,a,o){this.placement=new ge(t,i,a,o),this._currentPlacementIndex=e.length-1,this._forceFullPlacement=r,this._showCollisionBoxes=n,this._done=!1};Me.prototype.isDone=function(){return this._done},Me.prototype.continuePlacement=function(e,r,n){for(var i=this,a=t.browser.now(),o=function(){var e=t.browser.now()-a;return!i._forceFullPlacement&&e>2};this._currentPlacementIndex>=0;){var s=r[e[this._currentPlacementIndex]],l=this.placement.collisionIndex.transform.zoom;if(\"symbol\"===s.type&&(!s.minzoom||s.minzoom<=l)&&(!s.maxzoom||s.maxzoom>l)){if(this._inProgressLayer||(this._inProgressLayer=new Ae),this._inProgressLayer.continuePlacement(n[s.source],this.placement,this._showCollisionBoxes,s,o))return;delete this._inProgressLayer}this._currentPlacementIndex--}this._done=!0},Me.prototype.commit=function(t){return this.placement.commit(t),this.placement};var Se=512/t.EXTENT/2,Ee=function(t,e,r){this.tileID=t,this.indexedSymbolInstances={},this.bucketInstanceId=r;for(var n=0;n<e.length;n++){var i=e.get(n),a=i.key;this.indexedSymbolInstances[a]||(this.indexedSymbolInstances[a]=[]),this.indexedSymbolInstances[a].push({crossTileID:i.crossTileID,coord:this.getScaledCoordinates(i,t)})}};Ee.prototype.getScaledCoordinates=function(e,r){var n=r.canonical.z-this.tileID.canonical.z,i=Se/Math.pow(2,n);return{x:Math.floor((r.canonical.x*t.EXTENT+e.anchorX)*i),y:Math.floor((r.canonical.y*t.EXTENT+e.anchorY)*i)}},Ee.prototype.findMatches=function(t,e,r){for(var n=this.tileID.canonical.z<e.canonical.z?1:Math.pow(2,this.tileID.canonical.z-e.canonical.z),i=0;i<t.length;i++){var a=t.get(i);if(!a.crossTileID){var o=this.indexedSymbolInstances[a.key];if(o)for(var s=this.getScaledCoordinates(a,e),l=0,c=o;l<c.length;l+=1){var u=c[l];if(Math.abs(u.coord.x-s.x)<=n&&Math.abs(u.coord.y-s.y)<=n&&!r[u.crossTileID]){r[u.crossTileID]=!0,a.crossTileID=u.crossTileID;break}}}}};var Ce=function(){this.maxCrossTileID=0};Ce.prototype.generate=function(){return++this.maxCrossTileID};var Le=function(){this.indexes={},this.usedCrossTileIDs={},this.lng=0};Le.prototype.handleWrapJump=function(t){var e=Math.round((t-this.lng)/360);if(0!==e)for(var r in this.indexes){var n=this.indexes[r],i={};for(var a in n){var o=n[a];o.tileID=o.tileID.unwrapTo(o.tileID.wrap+e),i[o.tileID.key]=o}this.indexes[r]=i}this.lng=t},Le.prototype.addBucket=function(t,e,r){if(this.indexes[t.overscaledZ]&&this.indexes[t.overscaledZ][t.key]){if(this.indexes[t.overscaledZ][t.key].bucketInstanceId===e.bucketInstanceId)return!1;this.removeBucketCrossTileIDs(t.overscaledZ,this.indexes[t.overscaledZ][t.key])}for(var n=0;n<e.symbolInstances.length;n++)e.symbolInstances.get(n).crossTileID=0;this.usedCrossTileIDs[t.overscaledZ]||(this.usedCrossTileIDs[t.overscaledZ]={});var i=this.usedCrossTileIDs[t.overscaledZ];for(var a in this.indexes){var o=this.indexes[a];if(Number(a)>t.overscaledZ)for(var s in o){var l=o[s];l.tileID.isChildOf(t)&&l.findMatches(e.symbolInstances,t,i)}else{var c=o[t.scaledTo(Number(a)).key];c&&c.findMatches(e.symbolInstances,t,i)}}for(var u=0;u<e.symbolInstances.length;u++){var h=e.symbolInstances.get(u);h.crossTileID||(h.crossTileID=r.generate(),i[h.crossTileID]=!0)}return void 0===this.indexes[t.overscaledZ]&&(this.indexes[t.overscaledZ]={}),this.indexes[t.overscaledZ][t.key]=new Ee(t,e.symbolInstances,e.bucketInstanceId),!0},Le.prototype.removeBucketCrossTileIDs=function(t,e){for(var r in e.indexedSymbolInstances)for(var n=0,i=e.indexedSymbolInstances[r];n<i.length;n+=1){var a=i[n];delete this.usedCrossTileIDs[t][a.crossTileID]}},Le.prototype.removeStaleBuckets=function(t){var e=!1;for(var r in this.indexes){var n=this.indexes[r];for(var i in n)t[n[i].bucketInstanceId]||(this.removeBucketCrossTileIDs(r,n[i]),delete n[i],e=!0)}return e};var Pe=function(){this.layerIndexes={},this.crossTileIDs=new Ce,this.maxBucketInstanceId=0,this.bucketsInCurrentPlacement={}};Pe.prototype.addLayer=function(t,e,r){var n=this.layerIndexes[t.id];void 0===n&&(n=this.layerIndexes[t.id]=new Le);var i=!1,a={};n.handleWrapJump(r);for(var o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.getBucket(t);c&&t.id===c.layerIds[0]&&(c.bucketInstanceId||(c.bucketInstanceId=++this.maxBucketInstanceId),n.addBucket(l.tileID,c,this.crossTileIDs)&&(i=!0),a[c.bucketInstanceId]=!0)}return n.removeStaleBuckets(a)&&(i=!0),i},Pe.prototype.pruneUnusedLayers=function(t){var e={};for(var r in t.forEach(function(t){e[t]=!0}),this.layerIndexes)e[r]||delete this.layerIndexes[r]};var Oe=function(e,r){return t.emitValidationErrors(e,r&&r.filter(function(t){return\"source.canvas\"!==t.identifier}))},ze=t.pick(Bt,[\"addLayer\",\"removeLayer\",\"setPaintProperty\",\"setLayoutProperty\",\"setFilter\",\"addSource\",\"removeSource\",\"setLayerZoomRange\",\"setLight\",\"setTransition\",\"setGeoJSONSourceData\"]),Ie=t.pick(Bt,[\"setCenter\",\"setZoom\",\"setBearing\",\"setPitch\"]),De=function(e){function r(n,i){var a=this;void 0===i&&(i={}),e.call(this),this.map=n,this.dispatcher=new k((It||(It=new zt),It),this),this.imageManager=new f,this.imageManager.setEventedParent(this),this.glyphManager=new y(n._requestManager,i.localIdeographFontFamily),this.lineAtlas=new w(256,512),this.crossTileSymbolIndex=new Pe,this._layers={},this._order=[],this.sourceCaches={},this.zoomHistory=new t.ZoomHistory,this._loaded=!1,this._resetUpdates(),this.dispatcher.broadcast(\"setReferrer\",t.getReferrer());var o=this;this._rtlTextPluginCallback=r.registerForPluginAvailability(function(t){for(var e in o.dispatcher.broadcast(\"loadRTLTextPlugin\",t.pluginURL,t.completionCallback),o.sourceCaches)o.sourceCaches[e].reload()}),this.on(\"data\",function(t){if(\"source\"===t.dataType&&\"metadata\"===t.sourceDataType){var e=a.sourceCaches[t.sourceId];if(e){var r=e.getSource();if(r&&r.vectorLayerIds)for(var n in a._layers){var i=a._layers[n];i.source===r.id&&a._validateLayer(i)}}}})}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadURL=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"}));var i=\"boolean\"==typeof r.validate?r.validate:!t.isMapboxURL(e);e=this.map._requestManager.normalizeStyleURL(e,r.accessToken);var a=this.map._requestManager.transformRequest(e,t.ResourceType.Style);this._request=t.getJSON(a,function(e,r){n._request=null,e?n.fire(new t.ErrorEvent(e)):r&&n._load(r,i)})},r.prototype.loadJSON=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"})),this._request=t.browser.frame(function(){n._request=null,n._load(e,!1!==r.validate)})},r.prototype._load=function(e,r){var n=this;if(!r||!Oe(this,t.validateStyle(e))){for(var i in this._loaded=!0,this.stylesheet=e,e.sources)this.addSource(i,e.sources[i],{validate:!1});e.sprite?this._spriteRequest=function(e,r,n){var i,a,o,s=t.browser.devicePixelRatio>1?\"@2x\":\"\",l=t.getJSON(r.transformRequest(r.normalizeSpriteURL(e,s,\".json\"),t.ResourceType.SpriteJSON),function(t,e){l=null,o||(o=t,i=e,u())}),c=t.getImage(r.transformRequest(r.normalizeSpriteURL(e,s,\".png\"),t.ResourceType.SpriteImage),function(t,e){c=null,o||(o=t,a=e,u())});function u(){if(o)n(o);else if(i&&a){var e=t.browser.getImageData(a),r={};for(var s in i){var l=i[s],c=l.width,u=l.height,h=l.x,f=l.y,p=l.sdf,d=l.pixelRatio,g=new t.RGBAImage({width:c,height:u});t.RGBAImage.copy(e,g,{x:h,y:f},{x:0,y:0},{width:c,height:u}),r[s]={data:g,pixelRatio:d,sdf:p}}n(null,r)}}return{cancel:function(){l&&(l.cancel(),l=null),c&&(c.cancel(),c=null)}}}(e.sprite,this.map._requestManager,function(e,r){if(n._spriteRequest=null,e)n.fire(new t.ErrorEvent(e));else if(r)for(var i in r)n.imageManager.addImage(i,r[i]);n.imageManager.setLoaded(!0),n.fire(new t.Event(\"data\",{dataType:\"style\"}))}):this.imageManager.setLoaded(!0),this.glyphManager.setURL(e.glyphs);var a=Ft(this.stylesheet.layers);this._order=a.map(function(t){return t.id}),this._layers={};for(var o=0,s=a;o<s.length;o+=1){var l=s[o];(l=t.createStyleLayer(l)).setEventedParent(this,{layer:{id:l.id}}),this._layers[l.id]=l}this.dispatcher.broadcast(\"setLayers\",this._serializeLayers(this._order)),this.light=new _(this.stylesheet.light),this.fire(new t.Event(\"data\",{dataType:\"style\"})),this.fire(new t.Event(\"style.load\"))}},r.prototype._validateLayer=function(e){var r=this.sourceCaches[e.source];if(r){var n=e.sourceLayer;if(n){var i=r.getSource();(\"geojson\"===i.type||i.vectorLayerIds&&-1===i.vectorLayerIds.indexOf(n))&&this.fire(new t.ErrorEvent(new Error('Source layer \"'+n+'\" does not exist on source \"'+i.id+'\" as specified by style layer \"'+e.id+'\"')))}}},r.prototype.loaded=function(){if(!this._loaded)return!1;if(Object.keys(this._updatedSources).length)return!1;for(var t in this.sourceCaches)if(!this.sourceCaches[t].loaded())return!1;return!!this.imageManager.isLoaded()},r.prototype._serializeLayers=function(t){for(var e=[],r=0,n=t;r<n.length;r+=1){var i=n[r],a=this._layers[i];\"custom\"!==a.type&&e.push(a.serialize())}return e},r.prototype.hasTransitions=function(){if(this.light&&this.light.hasTransition())return!0;for(var t in this.sourceCaches)if(this.sourceCaches[t].hasTransition())return!0;for(var e in this._layers)if(this._layers[e].hasTransition())return!0;return!1},r.prototype._checkLoaded=function(){if(!this._loaded)throw new Error(\"Style is not done loading\")},r.prototype.update=function(e){if(this._loaded){var r=this._changed;if(this._changed){var n=Object.keys(this._updatedLayers),i=Object.keys(this._removedLayers);for(var a in(n.length||i.length)&&this._updateWorkerLayers(n,i),this._updatedSources){var o=this._updatedSources[a];\"reload\"===o?this._reloadSource(a):\"clear\"===o&&this._clearSource(a)}for(var s in this._updatedPaintProps)this._layers[s].updateTransitions(e);this.light.updateTransitions(e),this._resetUpdates()}for(var l in this.sourceCaches)this.sourceCaches[l].used=!1;for(var c=0,u=this._order;c<u.length;c+=1){var h=u[c],f=this._layers[h];f.recalculate(e),!f.isHidden(e.zoom)&&f.source&&(this.sourceCaches[f.source].used=!0)}this.light.recalculate(e),this.z=e.zoom,r&&this.fire(new t.Event(\"data\",{dataType:\"style\"}))}},r.prototype._updateWorkerLayers=function(t,e){this.dispatcher.broadcast(\"updateLayers\",{layers:this._serializeLayers(t),removedIds:e})},r.prototype._resetUpdates=function(){this._changed=!1,this._updatedLayers={},this._removedLayers={},this._updatedSources={},this._updatedPaintProps={}},r.prototype.setState=function(e){var r=this;if(this._checkLoaded(),Oe(this,t.validateStyle(e)))return!1;(e=t.clone$1(e)).layers=Ft(e.layers);var n=function(e,r){if(!e)return[{command:Bt.setStyle,args:[r]}];var n=[];try{if(!t.deepEqual(e.version,r.version))return[{command:Bt.setStyle,args:[r]}];t.deepEqual(e.center,r.center)||n.push({command:Bt.setCenter,args:[r.center]}),t.deepEqual(e.zoom,r.zoom)||n.push({command:Bt.setZoom,args:[r.zoom]}),t.deepEqual(e.bearing,r.bearing)||n.push({command:Bt.setBearing,args:[r.bearing]}),t.deepEqual(e.pitch,r.pitch)||n.push({command:Bt.setPitch,args:[r.pitch]}),t.deepEqual(e.sprite,r.sprite)||n.push({command:Bt.setSprite,args:[r.sprite]}),t.deepEqual(e.glyphs,r.glyphs)||n.push({command:Bt.setGlyphs,args:[r.glyphs]}),t.deepEqual(e.transition,r.transition)||n.push({command:Bt.setTransition,args:[r.transition]}),t.deepEqual(e.light,r.light)||n.push({command:Bt.setLight,args:[r.light]});var i={},a=[];!function(e,r,n,i){var a;for(a in r=r||{},e=e||{})e.hasOwnProperty(a)&&(r.hasOwnProperty(a)||jt(a,n,i));for(a in r)r.hasOwnProperty(a)&&(e.hasOwnProperty(a)?t.deepEqual(e[a],r[a])||(\"geojson\"===e[a].type&&\"geojson\"===r[a].type&&Vt(e,r,a)?n.push({command:Bt.setGeoJSONSourceData,args:[a,r[a].data]}):Ut(a,r,n,i)):Nt(a,r,n))}(e.sources,r.sources,a,i);var o=[];e.layers&&e.layers.forEach(function(t){i[t.source]?n.push({command:Bt.removeLayer,args:[t.id]}):o.push(t)}),n=n.concat(a),function(e,r,n){r=r||[];var i,a,o,s,l,c,u,h=(e=e||[]).map(Ht),f=r.map(Ht),p=e.reduce(Gt,{}),d=r.reduce(Gt,{}),g=h.slice(),v=Object.create(null);for(i=0,a=0;i<h.length;i++)o=h[i],d.hasOwnProperty(o)?a++:(n.push({command:Bt.removeLayer,args:[o]}),g.splice(g.indexOf(o,a),1));for(i=0,a=0;i<f.length;i++)o=f[f.length-1-i],g[g.length-1-i]!==o&&(p.hasOwnProperty(o)?(n.push({command:Bt.removeLayer,args:[o]}),g.splice(g.lastIndexOf(o,g.length-a),1)):a++,c=g[g.length-i],n.push({command:Bt.addLayer,args:[d[o],c]}),g.splice(g.length-i,0,o),v[o]=!0);for(i=0;i<f.length;i++)if(s=p[o=f[i]],l=d[o],!v[o]&&!t.deepEqual(s,l))if(t.deepEqual(s.source,l.source)&&t.deepEqual(s[\"source-layer\"],l[\"source-layer\"])&&t.deepEqual(s.type,l.type)){for(u in qt(s.layout,l.layout,n,o,null,Bt.setLayoutProperty),qt(s.paint,l.paint,n,o,null,Bt.setPaintProperty),t.deepEqual(s.filter,l.filter)||n.push({command:Bt.setFilter,args:[o,l.filter]}),t.deepEqual(s.minzoom,l.minzoom)&&t.deepEqual(s.maxzoom,l.maxzoom)||n.push({command:Bt.setLayerZoomRange,args:[o,l.minzoom,l.maxzoom]}),s)s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?qt(s[u],l[u],n,o,u.slice(6),Bt.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Bt.setLayerProperty,args:[o,u,l[u]]}));for(u in l)l.hasOwnProperty(u)&&!s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?qt(s[u],l[u],n,o,u.slice(6),Bt.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Bt.setLayerProperty,args:[o,u,l[u]]}))}else n.push({command:Bt.removeLayer,args:[o]}),c=g[g.lastIndexOf(o)+1],n.push({command:Bt.addLayer,args:[l,c]})}(o,r.layers,n)}catch(t){console.warn(\"Unable to compute style diff:\",t),n=[{command:Bt.setStyle,args:[r]}]}return n}(this.serialize(),e).filter(function(t){return!(t.command in Ie)});if(0===n.length)return!1;var i=n.filter(function(t){return!(t.command in ze)});if(i.length>0)throw new Error(\"Unimplemented: \"+i.map(function(t){return t.command}).join(\", \")+\".\");return n.forEach(function(t){\"setTransition\"!==t.command&&r[t.command].apply(r,t.args)}),this.stylesheet=e,!0},r.prototype.addImage=function(e,r){if(this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"An image with this name already exists.\")));this.imageManager.addImage(e,r),this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.updateImage=function(t,e){this.imageManager.updateImage(t,e)},r.prototype.getImage=function(t){return this.imageManager.getImage(t)},r.prototype.removeImage=function(e){if(!this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"No image with this name exists.\")));this.imageManager.removeImage(e),this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.listImages=function(){return this._checkLoaded(),this.imageManager.listImages()},r.prototype.addSource=function(e,r,n){var i=this;if(void 0===n&&(n={}),this._checkLoaded(),void 0!==this.sourceCaches[e])throw new Error(\"There is already a source with this ID\");if(!r.type)throw new Error(\"The type property must be defined, but the only the following properties were given: \"+Object.keys(r).join(\", \")+\".\");if(!([\"vector\",\"raster\",\"geojson\",\"video\",\"image\"].indexOf(r.type)>=0&&this._validate(t.validateStyle.source,\"sources.\"+e,r,null,n))){this.map&&this.map._collectResourceTiming&&(r.collectResourceTiming=!0);var a=this.sourceCaches[e]=new Ct(e,r,this.dispatcher);a.style=this,a.setEventedParent(this,function(){return{isSourceLoaded:i.loaded(),source:a.serialize(),sourceId:e}}),a.onAdd(this.map),this._changed=!0}},r.prototype.removeSource=function(e){if(this._checkLoaded(),void 0===this.sourceCaches[e])throw new Error(\"There is no source with this ID\");for(var r in this._layers)if(this._layers[r].source===e)return this.fire(new t.ErrorEvent(new Error('Source \"'+e+'\" cannot be removed while layer \"'+r+'\" is using it.')));var n=this.sourceCaches[e];delete this.sourceCaches[e],delete this._updatedSources[e],n.fire(new t.Event(\"data\",{sourceDataType:\"metadata\",dataType:\"source\",sourceId:e})),n.setEventedParent(null),n.clearTiles(),n.onRemove&&n.onRemove(this.map),this._changed=!0},r.prototype.setGeoJSONSourceData=function(t,e){this._checkLoaded(),this.sourceCaches[t].getSource().setData(e),this._changed=!0},r.prototype.getSource=function(t){return this.sourceCaches[t]&&this.sourceCaches[t].getSource()},r.prototype.addLayer=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=e.id;if(this.getLayer(i))this.fire(new t.ErrorEvent(new Error('Layer with id \"'+i+'\" already exists on this map')));else{var a;if(\"custom\"===e.type){if(Oe(this,t.validateCustomStyleLayer(e)))return;a=t.createStyleLayer(e)}else{if(\"object\"==typeof e.source&&(this.addSource(i,e.source),e=t.clone$1(e),e=t.extend(e,{source:i})),this._validate(t.validateStyle.layer,\"layers.\"+i,e,{arrayIndex:-1},n))return;a=t.createStyleLayer(e),this._validateLayer(a),a.setEventedParent(this,{layer:{id:i}})}var o=r?this._order.indexOf(r):this._order.length;if(r&&-1===o)this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.')));else{if(this._order.splice(o,0,i),this._layerOrderChanged=!0,this._layers[i]=a,this._removedLayers[i]&&a.source&&\"custom\"!==a.type){var s=this._removedLayers[i];delete this._removedLayers[i],s.type!==a.type?this._updatedSources[a.source]=\"clear\":(this._updatedSources[a.source]=\"reload\",this.sourceCaches[a.source].pause())}this._updateLayer(a),a.onAdd&&a.onAdd(this.map)}}},r.prototype.moveLayer=function(e,r){if(this._checkLoaded(),this._changed=!0,this._layers[e]){if(e!==r){var n=this._order.indexOf(e);this._order.splice(n,1);var i=r?this._order.indexOf(r):this._order.length;r&&-1===i?this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.'))):(this._order.splice(i,0,e),this._layerOrderChanged=!0)}}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be moved.\")))},r.prototype.removeLayer=function(e){this._checkLoaded();var r=this._layers[e];if(r){r.setEventedParent(null);var n=this._order.indexOf(e);this._order.splice(n,1),this._layerOrderChanged=!0,this._changed=!0,this._removedLayers[e]=r,delete this._layers[e],delete this._updatedLayers[e],delete this._updatedPaintProps[e],r.onRemove&&r.onRemove(this.map)}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be removed.\")))},r.prototype.getLayer=function(t){return this._layers[t]},r.prototype.setLayerZoomRange=function(e,r,n){this._checkLoaded();var i=this.getLayer(e);i?i.minzoom===r&&i.maxzoom===n||(null!=r&&(i.minzoom=r),null!=n&&(i.maxzoom=n),this._updateLayer(i)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot have zoom extent.\")))},r.prototype.setFilter=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=this.getLayer(e);if(i){if(!t.deepEqual(i.filter,r))return null==r?(i.filter=void 0,void this._updateLayer(i)):void(this._validate(t.validateStyle.filter,\"layers.\"+i.id+\".filter\",r,null,n)||(i.filter=t.clone$1(r),this._updateLayer(i)))}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be filtered.\")))},r.prototype.getFilter=function(e){return t.clone$1(this.getLayer(e).filter)},r.prototype.setLayoutProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getLayoutProperty(r),n)||(a.setLayoutProperty(r,n,i),this._updateLayer(a)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getLayoutProperty=function(e,r){var n=this.getLayer(e);if(n)return n.getLayoutProperty(r);this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style.\")))},r.prototype.setPaintProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getPaintProperty(r),n)||(a.setPaintProperty(r,n,i)&&this._updateLayer(a),this._changed=!0,this._updatedPaintProps[e]=!0):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getPaintProperty=function(t,e){return this.getLayer(t).getPaintProperty(e)},r.prototype.setFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=e.sourceLayer,a=this.sourceCaches[n],o=parseInt(e.id,10);if(void 0!==a){var s=a.getSource().type;\"geojson\"===s&&i?this.fire(new t.ErrorEvent(new Error(\"GeoJSON sources cannot have a sourceLayer parameter.\"))):\"vector\"!==s||i?isNaN(o)||o<0?this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided and non-negative.\"))):a.setFeatureState(i,o,r):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.removeFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=this.sourceCaches[n];if(void 0!==i){var a=i.getSource().type,o=\"vector\"===a?e.sourceLayer:void 0,s=parseInt(e.id,10);\"vector\"!==a||o?void 0!==e.id&&isNaN(s)||s<0?this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be non-negative.\"))):r&&\"string\"!=typeof e.id&&\"number\"!=typeof e.id?this.fire(new t.ErrorEvent(new Error(\"A feature id is requred to remove its specific state property.\"))):i.removeFeatureState(o,s,r):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.getFeatureState=function(e){this._checkLoaded();var r=e.source,n=e.sourceLayer,i=this.sourceCaches[r],a=parseInt(e.id,10);if(void 0!==i)if(\"vector\"!==i.getSource().type||n){if(!(isNaN(a)||a<0))return i.getFeatureState(n,a);this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided and non-negative.\")))}else this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")));else this.fire(new t.ErrorEvent(new Error(\"The source '\"+r+\"' does not exist in the map's style.\")))},r.prototype.getTransition=function(){return t.extend({duration:300,delay:0},this.stylesheet&&this.stylesheet.transition)},r.prototype.serialize=function(){return t.filterObject({version:this.stylesheet.version,name:this.stylesheet.name,metadata:this.stylesheet.metadata,light:this.stylesheet.light,center:this.stylesheet.center,zoom:this.stylesheet.zoom,bearing:this.stylesheet.bearing,pitch:this.stylesheet.pitch,sprite:this.stylesheet.sprite,glyphs:this.stylesheet.glyphs,transition:this.stylesheet.transition,sources:t.mapObject(this.sourceCaches,function(t){return t.serialize()}),layers:this._serializeLayers(this._order)},function(t){return void 0!==t})},r.prototype._updateLayer=function(t){this._updatedLayers[t.id]=!0,t.source&&!this._updatedSources[t.source]&&(this._updatedSources[t.source]=\"reload\",this.sourceCaches[t.source].pause()),this._changed=!0},r.prototype._flattenAndSortRenderedFeatures=function(t){for(var e=this,r=function(t){return\"fill-extrusion\"===e._layers[t].type},n={},i=[],a=this._order.length-1;a>=0;a--){var o=this._order[a];if(r(o)){n[o]=a;for(var s=0,l=t;s<l.length;s+=1){var c=l[s][o];if(c)for(var u=0,h=c;u<h.length;u+=1){var f=h[u];i.push(f)}}}}i.sort(function(t,e){return e.intersectionZ-t.intersectionZ});for(var p=[],d=this._order.length-1;d>=0;d--){var g=this._order[d];if(r(g))for(var v=i.length-1;v>=0;v--){var m=i[v].feature;if(n[m.layer.id]<d)break;p.push(m),i.pop()}else for(var y=0,x=t;y<x.length;y+=1){var b=x[y][g];if(b)for(var _=0,w=b;_<w.length;_+=1){var k=w[_];p.push(k.feature)}}}return p},r.prototype.queryRenderedFeatures=function(e,r,n){r&&r.filter&&this._validate(t.validateStyle.filter,\"queryRenderedFeatures.filter\",r.filter,null,r);var i={};if(r&&r.layers){if(!Array.isArray(r.layers))return this.fire(new t.ErrorEvent(new Error(\"parameters.layers must be an Array.\"))),[];for(var a=0,o=r.layers;a<o.length;a+=1){var s=o[a],l=this._layers[s];if(!l)return this.fire(new t.ErrorEvent(new Error(\"The layer '\"+s+\"' does not exist in the map's style and cannot be queried for features.\"))),[];i[l.source]=!0}}var c=[];for(var u in this.sourceCaches)r.layers&&!i[u]||c.push(R(this.sourceCaches[u],this._layers,e,r,n));return this.placement&&c.push(function(t,e,r,n,i,a){for(var o={},s=i.queryRenderedSymbols(r),l=[],c=0,u=Object.keys(s).map(Number);c<u.length;c+=1){var h=u[c];l.push(a[h])}l.sort(F);for(var f=function(){var e=d[p],r=e.featureIndex.lookupSymbolFeatures(s[e.bucketInstanceId],e.bucketIndex,e.sourceLayerIndex,n.filter,n.layers,t);for(var i in r){var a=o[i]=o[i]||[],l=r[i];l.sort(function(t,r){var n=e.featureSortOrder;if(n){var i=n.indexOf(t.featureIndex);return n.indexOf(r.featureIndex)-i}return r.featureIndex-t.featureIndex});for(var c=0,u=l;c<u.length;c+=1){var h=u[c];a.push(h)}}},p=0,d=l;p<d.length;p+=1)f();var g=function(r){o[r].forEach(function(n){var i=n.feature,a=t[r],o=e[a.source].getFeatureState(i.layer[\"source-layer\"],i.id);i.source=i.layer.source,i.layer[\"source-layer\"]&&(i.sourceLayer=i.layer[\"source-layer\"]),i.state=o})};for(var v in o)g(v);return o}(this._layers,this.sourceCaches,e,r,this.placement.collisionIndex,this.placement.retainedQueryData)),this._flattenAndSortRenderedFeatures(c)},r.prototype.querySourceFeatures=function(e,r){r&&r.filter&&this._validate(t.validateStyle.filter,\"querySourceFeatures.filter\",r.filter,null,r);var n=this.sourceCaches[e];return n?function(t,e){for(var r=t.getRenderableIds().map(function(e){return t.getTileByID(e)}),n=[],i={},a=0;a<r.length;a++){var o=r[a],s=o.tileID.canonical.key;i[s]||(i[s]=!0,o.querySourceFeatures(n,e))}return n}(n,r):[]},r.prototype.addSourceType=function(t,e,n){return r.getSourceType(t)?n(new Error('A source type called \"'+t+'\" already exists.')):(r.setSourceType(t,e),e.workerSourceURL?void this.dispatcher.broadcast(\"loadWorkerSource\",{name:t,url:e.workerSourceURL},n):n(null,null))},r.prototype.getLight=function(){return this.light.getLight()},r.prototype.setLight=function(e,r){void 0===r&&(r={}),this._checkLoaded();var n=this.light.getLight(),i=!1;for(var a in e)if(!t.deepEqual(e[a],n[a])){i=!0;break}if(i){var o={now:t.browser.now(),transition:t.extend({duration:300,delay:0},this.stylesheet.transition)};this.light.setLight(e,r),this.light.updateTransitions(o)}},r.prototype._validate=function(e,r,n,i,a){return void 0===a&&(a={}),(!a||!1!==a.validate)&&Oe(this,e.call(t.validateStyle,t.extend({key:r,style:this.serialize(),value:n,styleSpec:t.styleSpec},i)))},r.prototype._remove=function(){for(var e in this._request&&(this._request.cancel(),this._request=null),this._spriteRequest&&(this._spriteRequest.cancel(),this._spriteRequest=null),t.evented.off(\"pluginAvailable\",this._rtlTextPluginCallback),this.sourceCaches)this.sourceCaches[e].clearTiles();this.dispatcher.remove()},r.prototype._clearSource=function(t){this.sourceCaches[t].clearTiles()},r.prototype._reloadSource=function(t){this.sourceCaches[t].resume(),this.sourceCaches[t].reload()},r.prototype._updateSources=function(t){for(var e in this.sourceCaches)this.sourceCaches[e].update(t)},r.prototype._generateCollisionBoxes=function(){for(var t in this.sourceCaches)this._reloadSource(t)},r.prototype._updatePlacement=function(e,r,n,i){for(var a=!1,o=!1,s={},l=0,c=this._order;l<c.length;l+=1){var u=c[l],h=this._layers[u];if(\"symbol\"===h.type){if(!s[h.source]){var f=this.sourceCaches[h.source];s[h.source]=f.getRenderableIds(!0).map(function(t){return f.getTileByID(t)}).sort(function(t,e){return e.tileID.overscaledZ-t.tileID.overscaledZ||(t.tileID.isLessThan(e.tileID)?-1:1)})}var p=this.crossTileSymbolIndex.addLayer(h,s[h.source],e.center.lng);a=a||p}}this.crossTileSymbolIndex.pruneUnusedLayers(this._order);var d=this._layerOrderChanged||0===n;if((d||!this.pauseablePlacement||this.pauseablePlacement.isDone()&&!this.placement.stillRecent(t.browser.now()))&&(this.pauseablePlacement=new Me(e,this._order,d,r,n,i,this.placement),this._layerOrderChanged=!1),this.pauseablePlacement.isDone()?this.placement.setStale():(this.pauseablePlacement.continuePlacement(this._order,this._layers,s),this.pauseablePlacement.isDone()&&(this.placement=this.pauseablePlacement.commit(t.browser.now()),o=!0),a&&this.pauseablePlacement.placement.setStale()),o||a)for(var g=0,v=this._order;g<v.length;g+=1){var m=v[g],y=this._layers[m];\"symbol\"===y.type&&this.placement.updateLayerOpacities(y,s[y.source])}return!this.pauseablePlacement.isDone()||this.placement.hasTransitions(t.browser.now())},r.prototype._releaseSymbolFadeTiles=function(){for(var t in this.sourceCaches)this.sourceCaches[t].releaseSymbolFadeTiles()},r.prototype.getImages=function(t,e,r){this.imageManager.getImages(e.icons,r)},r.prototype.getGlyphs=function(t,e,r){this.glyphManager.getGlyphs(e.stacks,r)},r.prototype.getResource=function(e,r,n){return t.makeRequest(r,n)},r}(t.Evented);De.getSourceType=function(t){return z[t]},De.setSourceType=function(t,e){z[t]=e},De.registerForPluginAvailability=t.registerForPluginAvailability;var Re=t.createLayout([{name:\"a_pos\",type:\"Int16\",components:2}]),Fe=lr(\"#ifdef GL_ES\\nprecision mediump float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\",\"#ifdef GL_ES\\nprecision highp float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\\nvec2 unpack_float(const float packedValue) {int packedIntValue=int(packedValue);int v0=packedIntValue/256;return vec2(v0,packedIntValue-v0*256);}vec2 unpack_opacity(const float packedOpacity) {int intOpacity=int(packedOpacity)/2;return vec2(float(intOpacity)/127.0,mod(packedOpacity,2.0));}vec4 decode_color(const vec2 encodedColor) {return vec4(unpack_float(encodedColor[0])/255.0,unpack_float(encodedColor[1])/255.0\\n);}float unpack_mix_vec2(const vec2 packedValue,const float t) {return mix(packedValue[0],packedValue[1],t);}vec4 unpack_mix_color(const vec4 packedColors,const float t) {vec4 minColor=decode_color(vec2(packedColors[0],packedColors[1]));vec4 maxColor=decode_color(vec2(packedColors[2],packedColors[3]));return mix(minColor,maxColor,t);}vec2 get_pattern_pos(const vec2 pixel_coord_upper,const vec2 pixel_coord_lower,const vec2 pattern_size,const float tile_units_to_pixels,const vec2 pos) {vec2 offset=mod(mod(mod(pixel_coord_upper,pattern_size)*256.0,pattern_size)*256.0+pixel_coord_lower,pattern_size);return (tile_units_to_pixels*pos+offset)/pattern_size;}\"),Be=lr(\"uniform vec4 u_color;uniform float u_opacity;void main() {gl_FragColor=u_color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),Ne=lr(\"uniform vec2 u_pattern_tl_a;uniform vec2 u_pattern_br_a;uniform vec2 u_pattern_tl_b;uniform vec2 u_pattern_br_b;uniform vec2 u_texsize;uniform float u_mix;uniform float u_opacity;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(u_pattern_tl_a/u_texsize,u_pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(u_pattern_tl_b/u_texsize,u_pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_mix)*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pattern_size_a;uniform vec2 u_pattern_size_b;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_scale_a;uniform float u_scale_b;uniform float u_tile_units_to_pixels;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_a*u_pattern_size_a,u_tile_units_to_pixels,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_b*u_pattern_size_b,u_tile_units_to_pixels,a_pos);}\"),je=lr(\"varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=v_data.xy;float extrude_length=length(extrude);lowp float antialiasblur=v_data.z;float antialiased_blur=-max(blur,antialiasblur);float opacity_t=smoothstep(0.0,antialiased_blur,extrude_length-1.0);float color_t=stroke_width < 0.01 ? 0.0 : smoothstep(antialiased_blur,0.0,extrude_length-radius/(radius+stroke_width));gl_FragColor=opacity_t*mix(color*opacity,stroke_color*stroke_opacity,color_t);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform bool u_scale_with_map;uniform bool u_pitch_with_map;uniform vec2 u_extrude_scale;uniform lowp float u_device_pixel_ratio;uniform highp float u_camera_to_center_distance;attribute vec2 a_pos;varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main(void) {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=vec2(mod(a_pos,2.0)*2.0-1.0);vec2 circle_center=floor(a_pos*0.5);if (u_pitch_with_map) {vec2 corner_position=circle_center;if (u_scale_with_map) {corner_position+=extrude*(radius+stroke_width)*u_extrude_scale;} else {vec4 projected_center=u_matrix*vec4(circle_center,0,1);corner_position+=extrude*(radius+stroke_width)*u_extrude_scale*(projected_center.w/u_camera_to_center_distance);}gl_Position=u_matrix*vec4(corner_position,0,1);} else {gl_Position=u_matrix*vec4(circle_center,0,1);if (u_scale_with_map) {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*u_camera_to_center_distance;} else {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*gl_Position.w;}}lowp float antialiasblur=1.0/u_device_pixel_ratio/(radius+stroke_width);v_data=vec3(extrude.x,extrude.y,antialiasblur);}\"),Ue=lr(\"void main() {gl_FragColor=vec4(1.0);}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),Ve=lr(\"uniform highp float u_intensity;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main() {\\n#pragma mapbox: initialize highp float weight\\nfloat d=-0.5*3.0*3.0*dot(v_extrude,v_extrude);float val=weight*u_intensity*GAUSS_COEF*exp(d);gl_FragColor=vec4(val,1.0,1.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform float u_extrude_scale;uniform float u_opacity;uniform float u_intensity;attribute vec2 a_pos;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#pragma mapbox: define mediump float radius\\nconst highp float ZERO=1.0/255.0/16.0;\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main(void) {\\n#pragma mapbox: initialize highp float weight\\n#pragma mapbox: initialize mediump float radius\\nvec2 unscaled_extrude=vec2(mod(a_pos,2.0)*2.0-1.0);float S=sqrt(-2.0*log(ZERO/weight/u_intensity/GAUSS_COEF))/3.0;v_extrude=S*unscaled_extrude;vec2 extrude=v_extrude*radius*u_extrude_scale;vec4 pos=vec4(floor(a_pos*0.5)+extrude,0,1);gl_Position=u_matrix*pos;}\"),qe=lr(\"uniform sampler2D u_image;uniform sampler2D u_color_ramp;uniform float u_opacity;varying vec2 v_pos;void main() {float t=texture2D(u_image,v_pos).r;vec4 color=texture2D(u_color_ramp,vec2(t,0.5));gl_FragColor=color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(0.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;attribute vec2 a_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos*u_world,0,1);v_pos.x=a_pos.x;v_pos.y=1.0-a_pos.y;}\"),He=lr(\"varying float v_placed;varying float v_notUsed;void main() {float alpha=0.5;gl_FragColor=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {gl_FragColor=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {gl_FragColor*=.1;}}\",\"attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;attribute vec2 a_shift;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);gl_Position.xy+=(a_extrude+a_shift)*u_extrude_scale*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;}\"),Ge=lr(\"uniform float u_overscale_factor;varying float v_placed;varying float v_notUsed;varying float v_radius;varying vec2 v_extrude;varying vec2 v_extrude_scale;void main() {float alpha=0.5;vec4 color=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {color=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {color*=.2;}float extrude_scale_length=length(v_extrude_scale);float extrude_length=length(v_extrude)*extrude_scale_length;float stroke_width=15.0*extrude_scale_length/u_overscale_factor;float radius=v_radius*extrude_scale_length;float distance_to_edge=abs(extrude_length-radius);float opacity_t=smoothstep(-stroke_width,0.0,-distance_to_edge);gl_FragColor=opacity_t*color;}\",\"attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;varying float v_radius;varying vec2 v_extrude;varying vec2 v_extrude_scale;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);highp float padding_factor=1.2;gl_Position.xy+=a_extrude*u_extrude_scale*padding_factor*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;v_radius=abs(a_extrude.y);v_extrude=a_extrude*padding_factor;v_extrude_scale=u_extrude_scale*u_camera_to_center_distance*collision_perspective_ratio;}\"),Ye=lr(\"uniform highp vec4 u_color;void main() {gl_FragColor=u_color;}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),We=lr(\"#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_FragColor=color*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);}\"),Xe=lr(\"varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=outline_color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;uniform vec2 u_world;varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),Ze=lr(\"uniform vec2 u_texsize;uniform sampler2D u_image;uniform float u_fade;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);float dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=mix(color1,color2,u_fade)*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec4 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;gl_Position=u_matrix*vec4(a_pos,0,1);vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,a_pos);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),Je=lr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_fade)*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec4 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileZoomRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileZoomRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileZoomRatio,a_pos);}\"),Ke=lr(\"varying vec4 v_color;void main() {gl_FragColor=v_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;uniform float u_vertical_gradient;uniform lowp float u_opacity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec4 v_color;\\n#pragma mapbox: define highp float base\\n#pragma mapbox: define highp float height\\n#pragma mapbox: define highp vec4 color\\nvoid main() {\\n#pragma mapbox: initialize highp float base\\n#pragma mapbox: initialize highp float height\\n#pragma mapbox: initialize highp vec4 color\\nvec3 normal=a_normal_ed.xyz;base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);gl_Position=u_matrix*vec4(a_pos,t > 0.0 ? height : base,1);float colorvalue=color.r*0.2126+color.g*0.7152+color.b*0.0722;v_color=vec4(0.0,0.0,0.0,1.0);vec4 ambientlight=vec4(0.03,0.03,0.03,1.0);color+=ambientlight;float directional=clamp(dot(normal/16384.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((1.0-colorvalue+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_color.r+=clamp(color.r*directional*u_lightcolor.r,mix(0.0,0.3,1.0-u_lightcolor.r),1.0);v_color.g+=clamp(color.g*directional*u_lightcolor.g,mix(0.0,0.3,1.0-u_lightcolor.g),1.0);v_color.b+=clamp(color.b*directional*u_lightcolor.b,mix(0.0,0.3,1.0-u_lightcolor.b),1.0);v_color*=u_opacity;}\"),$e=lr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);vec4 mixedColor=mix(color1,color2,u_fade);gl_FragColor=mixedColor*v_lighting;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_height_factor;uniform vec4 u_scale;uniform float u_vertical_gradient;uniform lowp float u_opacity;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec3 normal=a_normal_ed.xyz;float edgedistance=a_normal_ed.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);float z=t > 0.0 ? height : base;gl_Position=u_matrix*vec4(a_pos,z,1);vec2 pos=normal.x==1.0 && normal.y==0.0 && normal.z==16384.0\\n? a_pos\\n: vec2(edgedistance,z*u_height_factor);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,pos);v_lighting=vec4(0.0,0.0,0.0,1.0);float directional=clamp(dot(normal/16383.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((0.5+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_lighting.rgb+=clamp(directional*u_lightcolor,mix(vec3(0.0),vec3(0.3),1.0-u_lightcolor),vec3(1.0));v_lighting*=u_opacity;}\"),Qe=lr(\"#ifdef GL_ES\\nprecision highp float;\\n#endif\\nuniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_dimension;uniform float u_zoom;uniform float u_maxzoom;float getElevation(vec2 coord,float bias) {vec4 data=texture2D(u_image,coord)*255.0;return (data.r+data.g*256.0+data.b*256.0*256.0)/4.0;}void main() {vec2 epsilon=1.0/u_dimension;float a=getElevation(v_pos+vec2(-epsilon.x,-epsilon.y),0.0);float b=getElevation(v_pos+vec2(0,-epsilon.y),0.0);float c=getElevation(v_pos+vec2(epsilon.x,-epsilon.y),0.0);float d=getElevation(v_pos+vec2(-epsilon.x,0),0.0);float e=getElevation(v_pos,0.0);float f=getElevation(v_pos+vec2(epsilon.x,0),0.0);float g=getElevation(v_pos+vec2(-epsilon.x,epsilon.y),0.0);float h=getElevation(v_pos+vec2(0,epsilon.y),0.0);float i=getElevation(v_pos+vec2(epsilon.x,epsilon.y),0.0);float exaggeration=u_zoom < 2.0 ? 0.4 : u_zoom < 4.5 ? 0.35 : 0.3;vec2 deriv=vec2((c+f+f+i)-(a+d+d+g),(g+h+h+i)-(a+b+b+c))/ pow(2.0,(u_zoom-u_maxzoom)*exaggeration+19.2562-u_zoom);gl_FragColor=clamp(vec4(deriv.x/2.0+0.5,deriv.y/2.0+0.5,1.0,1.0),0.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_dimension;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);highp vec2 epsilon=1.0/u_dimension;float scale=(u_dimension.x-2.0)/u_dimension.x;v_pos=(a_texture_pos/8192.0)*scale+epsilon;}\"),tr=lr(\"uniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_latrange;uniform vec2 u_light;uniform vec4 u_shadow;uniform vec4 u_highlight;uniform vec4 u_accent;\\n#define PI 3.141592653589793\\nvoid main() {vec4 pixel=texture2D(u_image,v_pos);vec2 deriv=((pixel.rg*2.0)-1.0);float scaleFactor=cos(radians((u_latrange[0]-u_latrange[1])*(1.0-v_pos.y)+u_latrange[1]));float slope=atan(1.25*length(deriv)/scaleFactor);float aspect=deriv.x !=0.0 ? atan(deriv.y,-deriv.x) : PI/2.0*(deriv.y > 0.0 ? 1.0 :-1.0);float intensity=u_light.x;float azimuth=u_light.y+PI;float base=1.875-intensity*1.75;float maxValue=0.5*PI;float scaledSlope=intensity !=0.5 ? ((pow(base,slope)-1.0)/(pow(base,maxValue)-1.0))*maxValue : slope;float accent=cos(scaledSlope);vec4 accent_color=(1.0-accent)*u_accent*clamp(intensity*2.0,0.0,1.0);float shade=abs(mod((aspect+azimuth)/PI+0.5,2.0)-1.0);vec4 shade_color=mix(u_shadow,u_highlight,shade)*sin(scaledSlope)*clamp(intensity*2.0,0.0,1.0);gl_FragColor=accent_color*(1.0-shade_color.a)+shade_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos=a_texture_pos/8192.0;}\"),er=lr(\"uniform lowp float u_device_pixel_ratio;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform vec2 u_units_to_pixels;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_linesofar;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),rr=lr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);vec4 color=texture2D(u_image,vec2(v_lineprogress,0.5));gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define MAX_LINE_DISTANCE 32767.0\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_lineprogress=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0/MAX_LINE_DISTANCE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),nr=lr(\"uniform lowp float u_device_pixel_ratio;uniform vec2 u_texsize;uniform float u_fade;uniform mediump vec4 u_scale;uniform sampler2D u_image;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileZoomRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);vec2 pattern_size_a=vec2(display_size_a.x*fromScale/tileZoomRatio,display_size_a.y);vec2 pattern_size_b=vec2(display_size_b.x*toScale/tileZoomRatio,display_size_b.y);float dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float x_a=mod(v_linesofar/pattern_size_a.x,1.0);float x_b=mod(v_linesofar/pattern_size_b.x,1.0);float y_a=0.5+(v_normal.y*clamp(v_width2.s,0.0,(pattern_size_a.y+2.0)/2.0)/pattern_size_a.y);float y_b=0.5+(v_normal.y*clamp(v_width2.s,0.0,(pattern_size_b.y+2.0)/2.0)/pattern_size_b.y);vec2 pos_a=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,vec2(x_a,y_a));vec2 pos_b=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,vec2(x_b,y_b));vec4 color=mix(texture2D(u_image,pos_a),texture2D(u_image,pos_b),u_fade);gl_FragColor=color*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform vec2 u_units_to_pixels;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_linesofar=a_linesofar;v_width2=vec2(outset,inset);}\"),ir=lr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;uniform float u_sdfgamma;uniform float u_mix;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float sdfdist_a=texture2D(u_image,v_tex_a).a;float sdfdist_b=texture2D(u_image,v_tex_b).a;float sdfdist=mix(sdfdist_a,sdfdist_b,u_mix);alpha*=smoothstep(0.5-u_sdfgamma/floorwidth,0.5+u_sdfgamma/floorwidth,sdfdist);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_patternscale_a;uniform float u_tex_y_a;uniform vec2 u_patternscale_b;uniform float u_tex_y_b;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_tex_a=vec2(a_linesofar*u_patternscale_a.x/floorwidth,normal.y*u_patternscale_a.y+u_tex_y_a);v_tex_b=vec2(a_linesofar*u_patternscale_b.x/floorwidth,normal.y*u_patternscale_b.y+u_tex_y_b);v_width2=vec2(outset,inset);}\"),ar=lr(\"uniform float u_fade_t;uniform float u_opacity;uniform sampler2D u_image0;uniform sampler2D u_image1;varying vec2 v_pos0;varying vec2 v_pos1;uniform float u_brightness_low;uniform float u_brightness_high;uniform float u_saturation_factor;uniform float u_contrast_factor;uniform vec3 u_spin_weights;void main() {vec4 color0=texture2D(u_image0,v_pos0);vec4 color1=texture2D(u_image1,v_pos1);if (color0.a > 0.0) {color0.rgb=color0.rgb/color0.a;}if (color1.a > 0.0) {color1.rgb=color1.rgb/color1.a;}vec4 color=mix(color0,color1,u_fade_t);color.a*=u_opacity;vec3 rgb=color.rgb;rgb=vec3(dot(rgb,u_spin_weights.xyz),dot(rgb,u_spin_weights.zxy),dot(rgb,u_spin_weights.yzx));float average=(color.r+color.g+color.b)/3.0;rgb+=(average-rgb)*u_saturation_factor;rgb=(rgb-0.5)*u_contrast_factor+0.5;vec3 u_high_vec=vec3(u_brightness_low,u_brightness_low,u_brightness_low);vec3 u_low_vec=vec3(u_brightness_high,u_brightness_high,u_brightness_high);gl_FragColor=vec4(mix(u_high_vec,u_low_vec,rgb)*color.a,color.a);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_tl_parent;uniform float u_scale_parent;uniform float u_buffer_scale;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos0;varying vec2 v_pos1;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos0=(((a_texture_pos/8192.0)-0.5)/u_buffer_scale )+0.5;v_pos1=(v_pos0*u_scale_parent)+u_tl_parent;}\"),or=lr(\"uniform sampler2D u_texture;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nlowp float alpha=opacity*v_fade_opacity;gl_FragColor=texture2D(u_texture,v_tex)*alpha;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform highp float u_camera_to_center_distance;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform float u_fade_change;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform vec2 u_texsize;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size[0],a_size[1],u_size_t)/256.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size[0]/256.0;} else if (!u_is_size_zoom_constant && u_is_size_feature_constant) {size=u_size;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);v_tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;v_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));}\"),sr=lr(\"#define SDF_PX 8.0\\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;uniform bool u_is_text;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nfloat EDGE_GAMMA=0.105/u_device_pixel_ratio;vec2 tex=v_data0.xy;float gamma_scale=v_data1.x;float size=v_data1.y;float fade_opacity=v_data1[2];float fontScale=u_is_text ? size/24.0 : size;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size[0],a_size[1],u_size_t)/256.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size[0]/256.0;} else if (!u_is_size_zoom_constant && u_is_size_feature_constant) {size=u_size;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);float gamma_scale=gl_Position.w;vec2 tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));v_data0=vec2(tex.x,tex.y);v_data1=vec3(gamma_scale,size,interpolated_fade_opacity);}\");function lr(t,e){var r=/#pragma mapbox: ([\\w]+) ([\\w]+) ([\\w]+) ([\\w]+)/g,n={};return{fragmentSource:t=t.replace(r,function(t,e,r,i,a){return n[a]=!0,\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"\\n#ifdef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"}),vertexSource:e=e.replace(r,function(t,e,r,i,a){var o=\"float\"===i?\"vec2\":\"vec4\",s=a.match(/color/)?\"color\":o;return n[a]?\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"})}}var cr=Object.freeze({prelude:Fe,background:Be,backgroundPattern:Ne,circle:je,clippingMask:Ue,heatmap:Ve,heatmapTexture:qe,collisionBox:He,collisionCircle:Ge,debug:Ye,fill:We,fillOutline:Xe,fillOutlinePattern:Ze,fillPattern:Je,fillExtrusion:Ke,fillExtrusionPattern:$e,hillshadePrepare:Qe,hillshade:tr,line:er,lineGradient:rr,linePattern:nr,lineSDF:ir,raster:ar,symbolIcon:or,symbolSDF:sr}),ur=function(){this.boundProgram=null,this.boundLayoutVertexBuffer=null,this.boundPaintVertexBuffers=[],this.boundIndexBuffer=null,this.boundVertexOffset=null,this.boundDynamicVertexBuffer=null,this.vao=null};ur.prototype.bind=function(t,e,r,n,i,a,o,s){this.context=t;for(var l=this.boundPaintVertexBuffers.length!==n.length,c=0;!l&&c<n.length;c++)this.boundPaintVertexBuffers[c]!==n[c]&&(l=!0);var u=!this.vao||this.boundProgram!==e||this.boundLayoutVertexBuffer!==r||l||this.boundIndexBuffer!==i||this.boundVertexOffset!==a||this.boundDynamicVertexBuffer!==o||this.boundDynamicVertexBuffer2!==s;!t.extVertexArrayObject||u?this.freshBind(e,r,n,i,a,o,s):(t.bindVertexArrayOES.set(this.vao),o&&o.bind(),i&&i.dynamicDraw&&i.bind(),s&&s.bind())},ur.prototype.freshBind=function(t,e,r,n,i,a,o){var s,l=t.numAttributes,c=this.context,u=c.gl;if(c.extVertexArrayObject)this.vao&&this.destroy(),this.vao=c.extVertexArrayObject.createVertexArrayOES(),c.bindVertexArrayOES.set(this.vao),s=0,this.boundProgram=t,this.boundLayoutVertexBuffer=e,this.boundPaintVertexBuffers=r,this.boundIndexBuffer=n,this.boundVertexOffset=i,this.boundDynamicVertexBuffer=a,this.boundDynamicVertexBuffer2=o;else{s=c.currentNumAttributes||0;for(var h=l;h<s;h++)u.disableVertexAttribArray(h)}e.enableAttributes(u,t);for(var f=0,p=r;f<p.length;f+=1)p[f].enableAttributes(u,t);a&&a.enableAttributes(u,t),o&&o.enableAttributes(u,t),e.bind(),e.setVertexAttribPointers(u,t,i);for(var d=0,g=r;d<g.length;d+=1){var v=g[d];v.bind(),v.setVertexAttribPointers(u,t,i)}a&&(a.bind(),a.setVertexAttribPointers(u,t,i)),n&&n.bind(),o&&(o.bind(),o.setVertexAttribPointers(u,t,i)),c.currentNumAttributes=l},ur.prototype.destroy=function(){this.vao&&(this.context.extVertexArrayObject.deleteVertexArrayOES(this.vao),this.vao=null)};var hr=function(t,e,r,n,i){var a=t.gl;this.program=a.createProgram();var o=r.defines();i&&o.push(\"#define OVERDRAW_INSPECTOR;\");var s=o.concat(Fe.fragmentSource,e.fragmentSource).join(\"\\n\"),l=o.concat(Fe.vertexSource,e.vertexSource).join(\"\\n\"),c=a.createShader(a.FRAGMENT_SHADER);a.shaderSource(c,s),a.compileShader(c),a.attachShader(this.program,c);var u=a.createShader(a.VERTEX_SHADER);a.shaderSource(u,l),a.compileShader(u),a.attachShader(this.program,u);for(var h=r.layoutAttributes||[],f=0;f<h.length;f++)a.bindAttribLocation(this.program,f,h[f].name);a.linkProgram(this.program),this.numAttributes=a.getProgramParameter(this.program,a.ACTIVE_ATTRIBUTES),this.attributes={};for(var p={},d=0;d<this.numAttributes;d++){var g=a.getActiveAttrib(this.program,d);g&&(this.attributes[g.name]=a.getAttribLocation(this.program,g.name))}for(var v=a.getProgramParameter(this.program,a.ACTIVE_UNIFORMS),m=0;m<v;m++){var y=a.getActiveUniform(this.program,m);y&&(p[y.name]=a.getUniformLocation(this.program,y.name))}this.fixedUniforms=n(t,p),this.binderUniforms=r.getUniforms(t,p)};function fr(e,r,n){var i=1/le(n,1,r.transform.tileZoom),a=Math.pow(2,n.tileID.overscaledZ),o=n.tileSize*Math.pow(2,r.transform.tileZoom)/a,s=o*(n.tileID.canonical.x+n.tileID.wrap*a),l=o*n.tileID.canonical.y;return{u_image:0,u_texsize:n.imageAtlasTexture.size,u_scale:[t.browser.devicePixelRatio,i,e.fromScale,e.toScale],u_fade:e.t,u_pixel_coord_upper:[s>>16,l>>16],u_pixel_coord_lower:[65535&s,65535&l]}}hr.prototype.draw=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g){var v,m=t.gl;for(var y in t.program.set(this.program),t.setDepthMode(r),t.setStencilMode(n),t.setColorMode(i),t.setCullFace(a),this.fixedUniforms)this.fixedUniforms[y].set(o[y]);p&&p.setUniforms(t,this.binderUniforms,h,{zoom:f});for(var x=(v={},v[m.LINES]=2,v[m.TRIANGLES]=3,v[m.LINE_STRIP]=1,v)[e],b=0,_=u.get();b<_.length;b+=1){var w=_[b],k=w.vaos||(w.vaos={});(k[s]||(k[s]=new ur)).bind(t,this,l,p?p.getPaintVertexBuffers():[],c,w.vertexOffset,d,g),m.drawElements(e,w.primitiveLength*x,m.UNSIGNED_SHORT,w.primitiveOffset*x*2)}};var pr=function(e,r,n,i){var a=r.style.light,o=a.properties.get(\"position\"),s=[o.x,o.y,o.z],l=t.create$1();\"viewport\"===a.properties.get(\"anchor\")&&t.fromRotation(l,-r.transform.angle),t.transformMat3(s,s,l);var c=a.properties.get(\"color\");return{u_matrix:e,u_lightpos:s,u_lightintensity:a.properties.get(\"intensity\"),u_lightcolor:[c.r,c.g,c.b],u_vertical_gradient:+n,u_opacity:i}},dr=function(e,r,n,i,a,o,s){return t.extend(pr(e,r,n,i),fr(o,r,s),{u_height_factor:-Math.pow(2,a.overscaledZ)/s.tileSize/8})},gr=function(t){return{u_matrix:t}},vr=function(e,r,n,i){return t.extend(gr(e),fr(n,r,i))},mr=function(t,e){return{u_matrix:t,u_world:e}},yr=function(e,r,n,i,a){return t.extend(vr(e,r,n,i),{u_world:a})},xr=function(e,r,n,i){var a,o,s=e.transform;if(\"map\"===i.paint.get(\"circle-pitch-alignment\")){var l=le(n,1,s.zoom);a=!0,o=[l,l]}else a=!1,o=s.pixelsToGLUnits;return{u_camera_to_center_distance:s.cameraToCenterDistance,u_scale_with_map:+(\"map\"===i.paint.get(\"circle-pitch-scale\")),u_matrix:e.translatePosMatrix(r.posMatrix,n,i.paint.get(\"circle-translate\"),i.paint.get(\"circle-translate-anchor\")),u_pitch_with_map:+a,u_device_pixel_ratio:t.browser.devicePixelRatio,u_extrude_scale:o}},br=function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pixels_to_tile_units:new t.Uniform1f(e,r.u_pixels_to_tile_units),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_overscale_factor:new t.Uniform1f(e,r.u_overscale_factor)}},_r=function(t,e,r){var n=le(r,1,e.zoom),i=Math.pow(2,e.zoom-r.tileID.overscaledZ),a=r.tileID.overscaleFactor();return{u_matrix:t,u_camera_to_center_distance:e.cameraToCenterDistance,u_pixels_to_tile_units:n,u_extrude_scale:[e.pixelsToGLUnits[0]/(n*i),e.pixelsToGLUnits[1]/(n*i)],u_overscale_factor:a}},wr=function(t,e){return{u_matrix:t,u_color:e}},kr=function(t){return{u_matrix:t}},Tr=function(t,e,r,n){return{u_matrix:t,u_extrude_scale:le(e,1,r),u_intensity:n}},Ar=function(t,e,r){var n=r.paint.get(\"hillshade-shadow-color\"),i=r.paint.get(\"hillshade-highlight-color\"),a=r.paint.get(\"hillshade-accent-color\"),o=r.paint.get(\"hillshade-illumination-direction\")*(Math.PI/180);\"viewport\"===r.paint.get(\"hillshade-illumination-anchor\")&&(o-=t.transform.angle);var s=!t.options.moving;return{u_matrix:t.transform.calculatePosMatrix(e.tileID.toUnwrapped(),s),u_image:0,u_latrange:Sr(t,e.tileID),u_light:[r.paint.get(\"hillshade-exaggeration\"),o],u_shadow:n,u_highlight:i,u_accent:a}},Mr=function(e,r){var n=e.dem.stride,i=t.create();return t.ortho(i,0,t.EXTENT,-t.EXTENT,0,0,1),t.translate(i,i,[0,-t.EXTENT,0]),{u_matrix:i,u_image:1,u_dimension:[n,n],u_zoom:e.tileID.overscaledZ,u_maxzoom:r}};function Sr(e,r){var n=Math.pow(2,r.canonical.z),i=r.canonical.y;return[new t.MercatorCoordinate(0,i/n).toLngLat().lat,new t.MercatorCoordinate(0,(i+1)/n).toLngLat().lat]}var Er=function(e,r,n){var i=e.transform;return{u_matrix:zr(e,r,n),u_ratio:1/le(r,1,i.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_units_to_pixels:[1/i.pixelsToGLUnits[0],1/i.pixelsToGLUnits[1]]}},Cr=function(e,r,n){return t.extend(Er(e,r,n),{u_image:0})},Lr=function(e,r,n,i){var a=e.transform,o=Or(r,a);return{u_matrix:zr(e,r,n),u_texsize:r.imageAtlasTexture.size,u_ratio:1/le(r,1,a.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_image:0,u_scale:[t.browser.devicePixelRatio,o,i.fromScale,i.toScale],u_fade:i.t,u_units_to_pixels:[1/a.pixelsToGLUnits[0],1/a.pixelsToGLUnits[1]]}},Pr=function(e,r,n,i,a){var o=e.transform,s=e.lineAtlas,l=Or(r,o),c=\"round\"===n.layout.get(\"line-cap\"),u=s.getDash(i.from,c),h=s.getDash(i.to,c),f=u.width*a.fromScale,p=h.width*a.toScale;return t.extend(Er(e,r,n),{u_patternscale_a:[l/f,-u.height/2],u_patternscale_b:[l/p,-h.height/2],u_sdfgamma:s.width/(256*Math.min(f,p)*t.browser.devicePixelRatio)/2,u_image:0,u_tex_y_a:u.y,u_tex_y_b:h.y,u_mix:a.t})};function Or(t,e){return 1/le(t,1,e.tileZoom)}function zr(t,e,r){return t.translatePosMatrix(e.tileID.posMatrix,e,r.paint.get(\"line-translate\"),r.paint.get(\"line-translate-anchor\"))}var Ir=function(t,e,r,n,i){return{u_matrix:t,u_tl_parent:e,u_scale_parent:r,u_buffer_scale:1,u_fade_t:n.mix,u_opacity:n.opacity*i.paint.get(\"raster-opacity\"),u_image0:0,u_image1:1,u_brightness_low:i.paint.get(\"raster-brightness-min\"),u_brightness_high:i.paint.get(\"raster-brightness-max\"),u_saturation_factor:(o=i.paint.get(\"raster-saturation\"),o>0?1-1/(1.001-o):-o),u_contrast_factor:(a=i.paint.get(\"raster-contrast\"),a>0?1/(1-a):1+a),u_spin_weights:function(t){t*=Math.PI/180;var e=Math.sin(t),r=Math.cos(t);return[(2*r+1)/3,(-Math.sqrt(3)*e-r+1)/3,(Math.sqrt(3)*e-r+1)/3]}(i.paint.get(\"raster-hue-rotate\"))};var a,o};var Dr=function(t,e,r,n,i,a,o,s,l,c){var u=i.transform;return{u_is_size_zoom_constant:+(\"constant\"===t||\"source\"===t),u_is_size_feature_constant:+(\"constant\"===t||\"camera\"===t),u_size_t:e?e.uSizeT:0,u_size:e?e.uSize:0,u_camera_to_center_distance:u.cameraToCenterDistance,u_pitch:u.pitch/360*2*Math.PI,u_rotate_symbol:+r,u_aspect_ratio:u.width/u.height,u_fade_change:i.options.fadeDuration?i.symbolFadeChange:1,u_matrix:a,u_label_plane_matrix:o,u_coord_matrix:s,u_is_text:+l,u_pitch_with_map:+n,u_texsize:c,u_texture:0}},Rr=function(e,r,n,i,a,o,s,l,c,u,h){var f=a.transform;return t.extend(Dr(e,r,n,i,a,o,s,l,c,u),{u_gamma_scale:i?Math.cos(f._pitch)*f.cameraToCenterDistance:1,u_device_pixel_ratio:t.browser.devicePixelRatio,u_is_halo:+h})},Fr=function(t,e,r){return{u_matrix:t,u_opacity:e,u_color:r}},Br=function(e,r,n,i,a,o){return t.extend(function(t,e,r,n){var i=r.imageManager.getPattern(t.from),a=r.imageManager.getPattern(t.to),o=r.imageManager.getPixelSize(),s=o.width,l=o.height,c=Math.pow(2,n.tileID.overscaledZ),u=n.tileSize*Math.pow(2,r.transform.tileZoom)/c,h=u*(n.tileID.canonical.x+n.tileID.wrap*c),f=u*n.tileID.canonical.y;return{u_image:0,u_pattern_tl_a:i.tl,u_pattern_br_a:i.br,u_pattern_tl_b:a.tl,u_pattern_br_b:a.br,u_texsize:[s,l],u_mix:e.t,u_pattern_size_a:i.displaySize,u_pattern_size_b:a.displaySize,u_scale_a:e.fromScale,u_scale_b:e.toScale,u_tile_units_to_pixels:1/le(n,1,r.transform.tileZoom),u_pixel_coord_upper:[h>>16,f>>16],u_pixel_coord_lower:[65535&h,65535&f]}}(i,o,n,a),{u_matrix:e,u_opacity:r})},Nr={fillExtrusion:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fillExtrusionPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_height_factor:new t.Uniform1f(e,r.u_height_factor),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fill:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},fillPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},fillOutline:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world)}},fillOutlinePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},circle:function(e,r){return{u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_scale_with_map:new t.Uniform1i(e,r.u_scale_with_map),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},collisionBox:br,collisionCircle:br,debug:function(e,r){return{u_color:new t.UniformColor(e,r.u_color),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},clippingMask:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmap:function(e,r){return{u_extrude_scale:new t.Uniform1f(e,r.u_extrude_scale),u_intensity:new t.Uniform1f(e,r.u_intensity),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmapTexture:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_color_ramp:new t.Uniform1i(e,r.u_color_ramp),u_opacity:new t.Uniform1f(e,r.u_opacity)}},hillshade:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_latrange:new t.Uniform2f(e,r.u_latrange),u_light:new t.Uniform2f(e,r.u_light),u_shadow:new t.UniformColor(e,r.u_shadow),u_highlight:new t.UniformColor(e,r.u_highlight),u_accent:new t.UniformColor(e,r.u_accent)}},hillshadePrepare:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_dimension:new t.Uniform2f(e,r.u_dimension),u_zoom:new t.Uniform1f(e,r.u_zoom),u_maxzoom:new t.Uniform1f(e,r.u_maxzoom)}},line:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels)}},lineGradient:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_image:new t.Uniform1i(e,r.u_image)}},linePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_texsize:new t.Uniform2f(e,r.u_texsize),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_image:new t.Uniform1i(e,r.u_image),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},lineSDF:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_patternscale_a:new t.Uniform2f(e,r.u_patternscale_a),u_patternscale_b:new t.Uniform2f(e,r.u_patternscale_b),u_sdfgamma:new t.Uniform1f(e,r.u_sdfgamma),u_image:new t.Uniform1i(e,r.u_image),u_tex_y_a:new t.Uniform1f(e,r.u_tex_y_a),u_tex_y_b:new t.Uniform1f(e,r.u_tex_y_b),u_mix:new t.Uniform1f(e,r.u_mix)}},raster:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_tl_parent:new t.Uniform2f(e,r.u_tl_parent),u_scale_parent:new t.Uniform1f(e,r.u_scale_parent),u_buffer_scale:new t.Uniform1f(e,r.u_buffer_scale),u_fade_t:new t.Uniform1f(e,r.u_fade_t),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image0:new t.Uniform1i(e,r.u_image0),u_image1:new t.Uniform1i(e,r.u_image1),u_brightness_low:new t.Uniform1f(e,r.u_brightness_low),u_brightness_high:new t.Uniform1f(e,r.u_brightness_high),u_saturation_factor:new t.Uniform1f(e,r.u_saturation_factor),u_contrast_factor:new t.Uniform1f(e,r.u_contrast_factor),u_spin_weights:new t.Uniform3f(e,r.u_spin_weights)}},symbolIcon:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1f(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture)}},symbolSDF:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1f(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture),u_gamma_scale:new t.Uniform1f(e,r.u_gamma_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_is_halo:new t.Uniform1f(e,r.u_is_halo)}},background:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_color:new t.UniformColor(e,r.u_color)}},backgroundPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image:new t.Uniform1i(e,r.u_image),u_pattern_tl_a:new t.Uniform2f(e,r.u_pattern_tl_a),u_pattern_br_a:new t.Uniform2f(e,r.u_pattern_br_a),u_pattern_tl_b:new t.Uniform2f(e,r.u_pattern_tl_b),u_pattern_br_b:new t.Uniform2f(e,r.u_pattern_br_b),u_texsize:new t.Uniform2f(e,r.u_texsize),u_mix:new t.Uniform1f(e,r.u_mix),u_pattern_size_a:new t.Uniform2f(e,r.u_pattern_size_a),u_pattern_size_b:new t.Uniform2f(e,r.u_pattern_size_b),u_scale_a:new t.Uniform1f(e,r.u_scale_a),u_scale_b:new t.Uniform1f(e,r.u_scale_b),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_tile_units_to_pixels:new t.Uniform1f(e,r.u_tile_units_to_pixels)}}};function jr(e,r){for(var n=e.sort(function(t,e){return t.tileID.isLessThan(e.tileID)?-1:e.tileID.isLessThan(t.tileID)?1:0}),i=0;i<n.length;i++){var a={},o=n[i],s=n.slice(i+1);Ur(o.tileID.wrapped(),o.tileID,s,new t.OverscaledTileID(0,o.tileID.wrap+1,0,0,0),a),o.setMask(a,r)}}function Ur(e,r,n,i,a){for(var o=0;o<n.length;o++){var s=n[o];if(i.isLessThan(s.tileID))break;if(r.key===s.tileID.key)return;if(s.tileID.isChildOf(r)){for(var l=r.children(1/0),c=0;c<l.length;c++)Ur(e,l[c],n.slice(o),i,a);return}}var u=r.overscaledZ-e.overscaledZ,h=new t.CanonicalTileID(u,r.canonical.x-(e.canonical.x<<u),r.canonical.y-(e.canonical.y<<u));a[h.key]=a[h.key]||h}function Vr(t,e,r,n,i){for(var a=t.context,o=a.gl,s=i?t.useProgram(\"collisionCircle\"):t.useProgram(\"collisionBox\"),l=0;l<n.length;l++){var c=n[l],u=e.getTile(c),h=u.getBucket(r);if(h){var f=i?h.collisionCircle:h.collisionBox;f&&s.draw(a,i?o.TRIANGLES:o.LINES,Tt.disabled,At.disabled,t.colorModeForRenderPass(),St.disabled,_r(c.posMatrix,t.transform,u),r.id,f.layoutVertexBuffer,f.indexBuffer,f.segments,null,t.transform.zoom,null,null,f.collisionVertexBuffer)}}}var qr=t.identity(new Float32Array(16));function Hr(e,r,n,i,a,o){var s=t.getAnchorAlignment(e),l=-(s.horizontalAlign-.5)*r,c=-(s.verticalAlign-.5)*n,u=t.evaluateRadialOffset(e,i);return new t.Point((l/a+u[0])*o,(c/a+u[1])*o)}function Gr(e,r,n,i,a,o,s,l,c,u){var h=e.text.placedSymbolArray,f=e.text.dynamicLayoutVertexArray;f.clear();for(var p=0;p<h.length;p++){var d=h.get(p),g=!d.hidden&&d.crossTileID?i[d.crossTileID]:null;if(g){var v=new t.Point(d.anchorX,d.anchorY),m=Zt(v,n?l:s),y=.5+o.cameraToCenterDistance/m.signedDistanceFromCamera*.5,x=a.evaluateSizeForFeature(e.textSizeData,u,d)*y/t.ONE_EM;n&&(x*=e.tilePixelRatio/c);for(var b=g.width,_=g.height,w=g.radialOffset,k=g.textBoxScale,T=Hr(g.anchor,b,_,w,k,x),A=n?Zt(v.add(T),s).point:m.point.add(r?T.rotate(-o.angle):T),M=0;M<d.numGlyphs;M++)t.addDynamicAttributes(f,A,0)}else ie(d.numGlyphs,f)}e.text.dynamicLayoutVertexBuffer.updateData(f)}function Yr(e,r,n,i,a,o,s,l,c,u,h,f,p){for(var d,g,v=e.context,m=v.gl,y=e.transform,x=\"map\"===l,b=\"map\"===c,_=x&&\"point\"!==n.layout.get(\"symbol-placement\"),w=x&&!b&&!_,k=void 0!==n.layout.get(\"symbol-sort-key\").constantOr(1),T=e.depthModeForSublayer(0,Tt.ReadOnly),A=n.layout.get(\"text-variable-anchor\"),M=[],S=0,E=i;S<E.length;S+=1){var C=E[S],L=r.getTile(C),P=L.getBucket(n);if(P){var O=a?P.text:P.icon;if(O&&O.segments.get().length){var z=O.programConfigurations.get(n.id),I=a||P.sdfIcons,D=a?P.textSizeData:P.iconSizeData;d||(d=e.useProgram(I?\"symbolSDF\":\"symbolIcon\",z),g=t.evaluateSizeForZoom(D,y.zoom)),v.activeTexture.set(m.TEXTURE0);var R=void 0,F=void 0,B=void 0;if(a)F=L.glyphAtlasTexture,B=m.LINEAR,R=L.glyphAtlasTexture.size;else{var N=1!==n.layout.get(\"icon-size\").constantOr(0)||P.iconsNeedLinear,j=b||0!==y.pitch;F=L.imageAtlasTexture,B=I||e.options.rotating||e.options.zooming||N||j?m.LINEAR:m.NEAREST,R=L.imageAtlasTexture.size}var U=le(L,1,e.transform.zoom),V=Wt(C.posMatrix,b,x,e.transform,U),q=Xt(C.posMatrix,b,x,e.transform,U);if(_)Kt(P,C.posMatrix,e,a,V,q,b,u);else if(a&&g&&A){var H=Math.pow(2,y.zoom-L.tileID.overscaledZ);Gr(P,x,b,p,t.symbolSize,y,V,C.posMatrix,H,g)}var G=e.translatePosMatrix(C.posMatrix,L,o,s),Y=_||a&&A?qr:V,W=e.translatePosMatrix(q,L,o,s,!0),X=I&&0!==n.paint.get(a?\"text-halo-width\":\"icon-halo-width\").constantOr(1),Z={program:d,buffers:O,uniformValues:I?Rr(D.kind,g,w,b,e,G,Y,W,a,R,!0):Dr(D.kind,g,w,b,e,G,Y,W,a,R),atlasTexture:F,atlasInterpolation:B,isSDF:I,hasHalo:X};if(k)for(var J=0,K=O.segments.get();J<K.length;J+=1){var $=K[J];M.push({segments:new t.SegmentVector([$]),sortKey:$.sortKey,state:Z})}else M.push({segments:O.segments,sortKey:0,state:Z})}}}k&&M.sort(function(t,e){return t.sortKey-e.sortKey});for(var Q=0,tt=M;Q<tt.length;Q+=1){var et=tt[Q],rt=et.state;if(rt.atlasTexture.bind(rt.atlasInterpolation,m.CLAMP_TO_EDGE),rt.isSDF){var nt=rt.uniformValues;rt.hasHalo&&(nt.u_is_halo=1,Wr(rt.buffers,et.segments,n,e,rt.program,T,h,f,nt)),nt.u_is_halo=0}Wr(rt.buffers,et.segments,n,e,rt.program,T,h,f,rt.uniformValues)}}function Wr(t,e,r,n,i,a,o,s,l){var c=n.context,u=c.gl;i.draw(c,u.TRIANGLES,a,o,s,St.disabled,l,r.id,t.layoutVertexBuffer,t.indexBuffer,e,r.paint,n.transform.zoom,t.programConfigurations.get(r.id),t.dynamicLayoutVertexBuffer,t.opacityVertexBuffer)}function Xr(t,e,r,n,i,a,o){var s,l,c,u,h,f=t.context.gl,p=r.paint.get(\"fill-pattern\"),d=p&&p.constantOr(1),g=r.getCrossfadeParameters();o?(l=d&&!r.getPaintProperty(\"fill-outline-color\")?\"fillOutlinePattern\":\"fillOutline\",s=f.LINES):(l=d?\"fillPattern\":\"fill\",s=f.TRIANGLES);for(var v=0,m=n;v<m.length;v+=1){var y=m[v],x=e.getTile(y);if(!d||x.patternsLoaded()){var b=x.getBucket(r);if(b){var _=b.programConfigurations.get(r.id),w=t.useProgram(l,_);d&&(t.context.activeTexture.set(f.TEXTURE0),x.imageAtlasTexture.bind(f.LINEAR,f.CLAMP_TO_EDGE),_.updatePatternPaintBuffers(g));var k=p.constantOr(null);if(k&&x.imageAtlas){var T=x.imageAtlas.patternPositions[k.to],A=x.imageAtlas.patternPositions[k.from];T&&A&&_.setConstantPatternPositions(T,A)}var M=t.translatePosMatrix(y.posMatrix,x,r.paint.get(\"fill-translate\"),r.paint.get(\"fill-translate-anchor\"));if(o){u=b.indexBuffer2,h=b.segments2;var S=[f.drawingBufferWidth,f.drawingBufferHeight];c=\"fillOutlinePattern\"===l&&d?yr(M,t,g,x,S):mr(M,S)}else u=b.indexBuffer,h=b.segments,c=d?vr(M,t,g,x):gr(M);w.draw(t.context,s,i,t.stencilModeForClipping(y),a,St.disabled,c,r.id,b.layoutVertexBuffer,u,h,r.paint,t.transform.zoom,_)}}}}function Zr(t,e,r,n,i,a,o){for(var s=t.context,l=s.gl,c=r.paint.get(\"fill-extrusion-pattern\"),u=c.constantOr(1),h=r.getCrossfadeParameters(),f=r.paint.get(\"fill-extrusion-opacity\"),p=0,d=n;p<d.length;p+=1){var g=d[p],v=e.getTile(g),m=v.getBucket(r);if(m){var y=m.programConfigurations.get(r.id),x=t.useProgram(u?\"fillExtrusionPattern\":\"fillExtrusion\",y);u&&(t.context.activeTexture.set(l.TEXTURE0),v.imageAtlasTexture.bind(l.LINEAR,l.CLAMP_TO_EDGE),y.updatePatternPaintBuffers(h));var b=c.constantOr(null);if(b&&v.imageAtlas){var _=v.imageAtlas.patternPositions[b.to],w=v.imageAtlas.patternPositions[b.from];_&&w&&y.setConstantPatternPositions(_,w)}var k=t.translatePosMatrix(g.posMatrix,v,r.paint.get(\"fill-extrusion-translate\"),r.paint.get(\"fill-extrusion-translate-anchor\")),T=r.paint.get(\"fill-extrusion-vertical-gradient\"),A=u?dr(k,t,T,f,g,h,v):pr(k,t,T,f);x.draw(s,s.gl.TRIANGLES,i,a,o,St.backCCW,A,r.id,m.layoutVertexBuffer,m.indexBuffer,m.segments,r.paint,t.transform.zoom,y)}}}function Jr(t,e,r,n,i,a){var o=t.context,s=o.gl,l=e.fbo;if(l){var c=t.useProgram(\"hillshade\");o.activeTexture.set(s.TEXTURE0),s.bindTexture(s.TEXTURE_2D,l.colorAttachment.get());var u=Ar(t,e,r);e.maskedBoundsBuffer&&e.maskedIndexBuffer&&e.segments?c.draw(o,s.TRIANGLES,n,i,a,St.disabled,u,r.id,e.maskedBoundsBuffer,e.maskedIndexBuffer,e.segments):c.draw(o,s.TRIANGLES,n,i,a,St.disabled,u,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}}function Kr(e,r,n,i,a,o,s){var l=e.context,c=l.gl;if(r.dem&&r.dem.data){var u=r.dem.dim,h=r.dem.stride,f=r.dem.getPixels();if(l.activeTexture.set(c.TEXTURE1),l.pixelStoreUnpackPremultiplyAlpha.set(!1),r.demTexture=r.demTexture||e.getTileTexture(h),r.demTexture){var p=r.demTexture;p.update(f,{premultiply:!1}),p.bind(c.NEAREST,c.CLAMP_TO_EDGE)}else r.demTexture=new t.Texture(l,f,c.RGBA,{premultiply:!1}),r.demTexture.bind(c.NEAREST,c.CLAMP_TO_EDGE);l.activeTexture.set(c.TEXTURE0);var d=r.fbo;if(!d){var g=new t.Texture(l,{width:u,height:u,data:null},c.RGBA);g.bind(c.LINEAR,c.CLAMP_TO_EDGE),(d=r.fbo=l.createFramebuffer(u,u)).colorAttachment.set(g.texture)}l.bindFramebuffer.set(d.framebuffer),l.viewport.set([0,0,u,u]),e.useProgram(\"hillshadePrepare\").draw(l,c.TRIANGLES,a,o,s,St.disabled,Mr(r,i),n.id,e.rasterBoundsBuffer,e.quadTriangleIndexBuffer,e.rasterBoundsSegments),r.needsHillshadePrepare=!1}}function $r(e,r,n,i,a){var o=i.paint.get(\"raster-fade-duration\");if(o>0){var s=t.browser.now(),l=(s-e.timeAdded)/o,c=r?(s-r.timeAdded)/o:-1,u=n.getSource(),h=a.coveringZoomLevel({tileSize:u.tileSize,roundZoom:u.roundZoom}),f=!r||Math.abs(r.tileID.overscaledZ-h)>Math.abs(e.tileID.overscaledZ-h),p=f&&e.refreshedUponExpiration?1:t.clamp(f?l:1-c,0,1);return e.refreshedUponExpiration&&l>=1&&(e.refreshedUponExpiration=!1),r?{opacity:1,mix:1-p}:{opacity:p,mix:0}}return{opacity:1,mix:0}}function Qr(e,r,n){var i=e.context,a=i.gl,o=n.posMatrix,s=e.useProgram(\"debug\"),l=Tt.disabled,c=At.disabled,u=e.colorModeForRenderPass(),h=\"$debug\";s.draw(i,a.LINE_STRIP,l,c,u,St.disabled,wr(o,t.Color.red),h,e.debugBuffer,e.tileBorderIndexBuffer,e.debugSegments);for(var f=r.getTileByID(n.key).latestRawTileData,p=f&&f.byteLength||0,d=Math.floor(p/1024),g=function(t,e,r,n){n=n||1;var i,a,o,s,l,c,u,h,f=[];for(i=0,a=t.length;i<a;i++)if(l=tn[t[i]]){for(h=null,o=0,s=l[1].length;o<s;o+=2)-1===l[1][o]&&-1===l[1][o+1]?h=null:(c=e+l[1][o]*n,u=200-l[1][o+1]*n,h&&f.push(h.x,h.y,c,u),h={x:c,y:u});e+=l[0]*n}return f}(n.toString()+\" \"+d+\"kb\",50,0,5),v=new t.StructArrayLayout2i4,m=new t.StructArrayLayout2ui4,y=0;y<g.length;y+=2)v.emplaceBack(g[y],g[y+1]),m.emplaceBack(y,y+1);for(var x=i.createVertexBuffer(v,Re.members),b=i.createIndexBuffer(m),_=t.SegmentVector.simpleSegment(0,0,v.length/2,v.length/2),w=r.getTile(n).tileSize,k=t.EXTENT/(Math.pow(2,e.transform.zoom-n.overscaledZ)*w),T=[[-1,-1],[-1,1],[1,-1],[1,1]],A=0;A<T.length;A++){var M=T[A];s.draw(i,a.LINES,l,c,u,St.disabled,wr(t.translate([],o,[k*M[0],k*M[1],0]),t.Color.white),h,x,b,_)}s.draw(i,a.LINES,l,c,u,St.disabled,wr(o,t.Color.black),h,x,b,_)}var tn={\" \":[16,[]],\"!\":[10,[5,21,5,7,-1,-1,5,2,4,1,5,0,6,1,5,2]],'\"':[16,[4,21,4,14,-1,-1,12,21,12,14]],\"#\":[21,[11,25,4,-7,-1,-1,17,25,10,-7,-1,-1,4,12,18,12,-1,-1,3,6,17,6]],$:[20,[8,25,8,-4,-1,-1,12,25,12,-4,-1,-1,17,18,15,20,12,21,8,21,5,20,3,18,3,16,4,14,5,13,7,12,13,10,15,9,16,8,17,6,17,3,15,1,12,0,8,0,5,1,3,3]],\"%\":[24,[21,21,3,0,-1,-1,8,21,10,19,10,17,9,15,7,14,5,14,3,16,3,18,4,20,6,21,8,21,10,20,13,19,16,19,19,20,21,21,-1,-1,17,7,15,6,14,4,14,2,16,0,18,0,20,1,21,3,21,5,19,7,17,7]],\"&\":[26,[23,12,23,13,22,14,21,14,20,13,19,11,17,6,15,3,13,1,11,0,7,0,5,1,4,2,3,4,3,6,4,8,5,9,12,13,13,14,14,16,14,18,13,20,11,21,9,20,8,18,8,16,9,13,11,10,16,3,18,1,20,0,22,0,23,1,23,2]],\"'\":[10,[5,19,4,20,5,21,6,20,6,18,5,16,4,15]],\"(\":[14,[11,25,9,23,7,20,5,16,4,11,4,7,5,2,7,-2,9,-5,11,-7]],\")\":[14,[3,25,5,23,7,20,9,16,10,11,10,7,9,2,7,-2,5,-5,3,-7]],\"*\":[16,[8,21,8,9,-1,-1,3,18,13,12,-1,-1,13,18,3,12]],\"+\":[26,[13,18,13,0,-1,-1,4,9,22,9]],\",\":[10,[6,1,5,0,4,1,5,2,6,1,6,-1,5,-3,4,-4]],\"-\":[26,[4,9,22,9]],\".\":[10,[5,2,4,1,5,0,6,1,5,2]],\"/\":[22,[20,25,2,-7]],0:[20,[9,21,6,20,4,17,3,12,3,9,4,4,6,1,9,0,11,0,14,1,16,4,17,9,17,12,16,17,14,20,11,21,9,21]],1:[20,[6,17,8,18,11,21,11,0]],2:[20,[4,16,4,17,5,19,6,20,8,21,12,21,14,20,15,19,16,17,16,15,15,13,13,10,3,0,17,0]],3:[20,[5,21,16,21,10,13,13,13,15,12,16,11,17,8,17,6,16,3,14,1,11,0,8,0,5,1,4,2,3,4]],4:[20,[13,21,3,7,18,7,-1,-1,13,21,13,0]],5:[20,[15,21,5,21,4,12,5,13,8,14,11,14,14,13,16,11,17,8,17,6,16,3,14,1,11,0,8,0,5,1,4,2,3,4]],6:[20,[16,18,15,20,12,21,10,21,7,20,5,17,4,12,4,7,5,3,7,1,10,0,11,0,14,1,16,3,17,6,17,7,16,10,14,12,11,13,10,13,7,12,5,10,4,7]],7:[20,[17,21,7,0,-1,-1,3,21,17,21]],8:[20,[8,21,5,20,4,18,4,16,5,14,7,13,11,12,14,11,16,9,17,7,17,4,16,2,15,1,12,0,8,0,5,1,4,2,3,4,3,7,4,9,6,11,9,12,13,13,15,14,16,16,16,18,15,20,12,21,8,21]],9:[20,[16,14,15,11,13,9,10,8,9,8,6,9,4,11,3,14,3,15,4,18,6,20,9,21,10,21,13,20,15,18,16,14,16,9,15,4,13,1,10,0,8,0,5,1,4,3]],\":\":[10,[5,14,4,13,5,12,6,13,5,14,-1,-1,5,2,4,1,5,0,6,1,5,2]],\";\":[10,[5,14,4,13,5,12,6,13,5,14,-1,-1,6,1,5,0,4,1,5,2,6,1,6,-1,5,-3,4,-4]],\"<\":[24,[20,18,4,9,20,0]],\"=\":[26,[4,12,22,12,-1,-1,4,6,22,6]],\">\":[24,[4,18,20,9,4,0]],\"?\":[18,[3,16,3,17,4,19,5,20,7,21,11,21,13,20,14,19,15,17,15,15,14,13,13,12,9,10,9,7,-1,-1,9,2,8,1,9,0,10,1,9,2]],\"@\":[27,[18,13,17,15,15,16,12,16,10,15,9,14,8,11,8,8,9,6,11,5,14,5,16,6,17,8,-1,-1,12,16,10,14,9,11,9,8,10,6,11,5,-1,-1,18,16,17,8,17,6,19,5,21,5,23,7,24,10,24,12,23,15,22,17,20,19,18,20,15,21,12,21,9,20,7,19,5,17,4,15,3,12,3,9,4,6,5,4,7,2,9,1,12,0,15,0,18,1,20,2,21,3,-1,-1,19,16,18,8,18,6,19,5]],A:[18,[9,21,1,0,-1,-1,9,21,17,0,-1,-1,4,7,14,7]],B:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,15,17,13,16,12,13,11,-1,-1,4,11,13,11,16,10,17,9,18,7,18,4,17,2,16,1,13,0,4,0]],C:[21,[18,16,17,18,15,20,13,21,9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5]],D:[21,[4,21,4,0,-1,-1,4,21,11,21,14,20,16,18,17,16,18,13,18,8,17,5,16,3,14,1,11,0,4,0]],E:[19,[4,21,4,0,-1,-1,4,21,17,21,-1,-1,4,11,12,11,-1,-1,4,0,17,0]],F:[18,[4,21,4,0,-1,-1,4,21,17,21,-1,-1,4,11,12,11]],G:[21,[18,16,17,18,15,20,13,21,9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,18,8,-1,-1,13,8,18,8]],H:[22,[4,21,4,0,-1,-1,18,21,18,0,-1,-1,4,11,18,11]],I:[8,[4,21,4,0]],J:[16,[12,21,12,5,11,2,10,1,8,0,6,0,4,1,3,2,2,5,2,7]],K:[21,[4,21,4,0,-1,-1,18,21,4,7,-1,-1,9,12,18,0]],L:[17,[4,21,4,0,-1,-1,4,0,16,0]],M:[24,[4,21,4,0,-1,-1,4,21,12,0,-1,-1,20,21,12,0,-1,-1,20,21,20,0]],N:[22,[4,21,4,0,-1,-1,4,21,18,0,-1,-1,18,21,18,0]],O:[22,[9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,19,8,19,13,18,16,17,18,15,20,13,21,9,21]],P:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,14,17,12,16,11,13,10,4,10]],Q:[22,[9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,19,8,19,13,18,16,17,18,15,20,13,21,9,21,-1,-1,12,4,18,-2]],R:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,15,17,13,16,12,13,11,4,11,-1,-1,11,11,18,0]],S:[20,[17,18,15,20,12,21,8,21,5,20,3,18,3,16,4,14,5,13,7,12,13,10,15,9,16,8,17,6,17,3,15,1,12,0,8,0,5,1,3,3]],T:[16,[8,21,8,0,-1,-1,1,21,15,21]],U:[22,[4,21,4,6,5,3,7,1,10,0,12,0,15,1,17,3,18,6,18,21]],V:[18,[1,21,9,0,-1,-1,17,21,9,0]],W:[24,[2,21,7,0,-1,-1,12,21,7,0,-1,-1,12,21,17,0,-1,-1,22,21,17,0]],X:[20,[3,21,17,0,-1,-1,17,21,3,0]],Y:[18,[1,21,9,11,9,0,-1,-1,17,21,9,11]],Z:[20,[17,21,3,0,-1,-1,3,21,17,21,-1,-1,3,0,17,0]],\"[\":[14,[4,25,4,-7,-1,-1,5,25,5,-7,-1,-1,4,25,11,25,-1,-1,4,-7,11,-7]],\"\\\\\":[14,[0,21,14,-3]],\"]\":[14,[9,25,9,-7,-1,-1,10,25,10,-7,-1,-1,3,25,10,25,-1,-1,3,-7,10,-7]],\"^\":[16,[6,15,8,18,10,15,-1,-1,3,12,8,17,13,12,-1,-1,8,17,8,0]],_:[16,[0,-2,16,-2]],\"`\":[10,[6,21,5,20,4,18,4,16,5,15,6,16,5,17]],a:[19,[15,14,15,0,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],b:[19,[4,21,4,0,-1,-1,4,11,6,13,8,14,11,14,13,13,15,11,16,8,16,6,15,3,13,1,11,0,8,0,6,1,4,3]],c:[18,[15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],d:[19,[15,21,15,0,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],e:[18,[3,8,15,8,15,10,14,12,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],f:[12,[10,21,8,21,6,20,5,17,5,0,-1,-1,2,14,9,14]],g:[19,[15,14,15,-2,14,-5,13,-6,11,-7,8,-7,6,-6,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],h:[19,[4,21,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0]],i:[8,[3,21,4,20,5,21,4,22,3,21,-1,-1,4,14,4,0]],j:[10,[5,21,6,20,7,21,6,22,5,21,-1,-1,6,14,6,-3,5,-6,3,-7,1,-7]],k:[17,[4,21,4,0,-1,-1,14,14,4,4,-1,-1,8,8,15,0]],l:[8,[4,21,4,0]],m:[30,[4,14,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0,-1,-1,15,10,18,13,20,14,23,14,25,13,26,10,26,0]],n:[19,[4,14,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0]],o:[19,[8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3,16,6,16,8,15,11,13,13,11,14,8,14]],p:[19,[4,14,4,-7,-1,-1,4,11,6,13,8,14,11,14,13,13,15,11,16,8,16,6,15,3,13,1,11,0,8,0,6,1,4,3]],q:[19,[15,14,15,-7,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],r:[13,[4,14,4,0,-1,-1,4,8,5,11,7,13,9,14,12,14]],s:[17,[14,11,13,13,10,14,7,14,4,13,3,11,4,9,6,8,11,7,13,6,14,4,14,3,13,1,10,0,7,0,4,1,3,3]],t:[12,[5,21,5,4,6,1,8,0,10,0,-1,-1,2,14,9,14]],u:[19,[4,14,4,4,5,1,7,0,10,0,12,1,15,4,-1,-1,15,14,15,0]],v:[16,[2,14,8,0,-1,-1,14,14,8,0]],w:[22,[3,14,7,0,-1,-1,11,14,7,0,-1,-1,11,14,15,0,-1,-1,19,14,15,0]],x:[17,[3,14,14,0,-1,-1,14,14,3,0]],y:[16,[2,14,8,0,-1,-1,14,14,8,0,6,-4,4,-6,2,-7,1,-7]],z:[17,[14,14,3,0,-1,-1,3,14,14,14,-1,-1,3,0,14,0]],\"{\":[14,[9,25,7,24,6,23,5,21,5,19,6,17,7,16,8,14,8,12,6,10,-1,-1,7,24,6,22,6,20,7,18,8,17,9,15,9,13,8,11,4,9,8,7,9,5,9,3,8,1,7,0,6,-2,6,-4,7,-6,-1,-1,6,8,8,6,8,4,7,2,6,1,5,-1,5,-3,6,-5,7,-6,9,-7]],\"|\":[8,[4,25,4,-7]],\"}\":[14,[5,25,7,24,8,23,9,21,9,19,8,17,7,16,6,14,6,12,8,10,-1,-1,7,24,8,22,8,20,7,18,6,17,5,15,5,13,6,11,10,9,6,7,5,5,5,3,6,1,7,0,8,-2,8,-4,7,-6,-1,-1,8,8,6,6,6,4,7,2,8,1,9,-1,9,-3,8,-5,7,-6,5,-7]],\"~\":[24,[3,6,3,8,4,11,6,12,8,12,10,11,14,8,16,7,18,7,20,8,21,10,-1,-1,3,8,4,10,6,11,8,11,10,10,14,7,16,6,18,6,20,7,21,10,21,12]]},en={symbol:function(t,e,r,n,i){if(\"translucent\"===t.renderPass){var a=At.disabled,o=t.colorModeForRenderPass();0!==r.paint.get(\"icon-opacity\").constantOr(1)&&Yr(t,e,r,n,!1,r.paint.get(\"icon-translate\"),r.paint.get(\"icon-translate-anchor\"),r.layout.get(\"icon-rotation-alignment\"),r.layout.get(\"icon-pitch-alignment\"),r.layout.get(\"icon-keep-upright\"),a,o,i),0!==r.paint.get(\"text-opacity\").constantOr(1)&&Yr(t,e,r,n,!0,r.paint.get(\"text-translate\"),r.paint.get(\"text-translate-anchor\"),r.layout.get(\"text-rotation-alignment\"),r.layout.get(\"text-pitch-alignment\"),r.layout.get(\"text-keep-upright\"),a,o,i),e.map.showCollisionBoxes&&function(t,e,r,n){Vr(t,e,r,n,!1),Vr(t,e,r,n,!0)}(t,e,r,n)}},circle:function(t,e,r,n){if(\"translucent\"===t.renderPass){var i=r.paint.get(\"circle-opacity\"),a=r.paint.get(\"circle-stroke-width\"),o=r.paint.get(\"circle-stroke-opacity\");if(0!==i.constantOr(1)||0!==a.constantOr(1)&&0!==o.constantOr(1))for(var s=t.context,l=s.gl,c=t.depthModeForSublayer(0,Tt.ReadOnly),u=At.disabled,h=t.colorModeForRenderPass(),f=0;f<n.length;f++){var p=n[f],d=e.getTile(p),g=d.getBucket(r);if(g){var v=g.programConfigurations.get(r.id);t.useProgram(\"circle\",v).draw(s,l.TRIANGLES,c,u,h,St.disabled,xr(t,p,d,r),r.id,g.layoutVertexBuffer,g.indexBuffer,g.segments,r.paint,t.transform.zoom,v)}}}},heatmap:function(e,r,n,i){if(0!==n.paint.get(\"heatmap-opacity\"))if(\"offscreen\"===e.renderPass){var a=e.context,o=a.gl,s=e.depthModeForSublayer(0,Tt.ReadOnly),l=At.disabled,c=new Mt([o.ONE,o.ONE],t.Color.transparent,[!0,!0,!0,!0]);!function(t,e,r){var n=t.gl;t.activeTexture.set(n.TEXTURE1),t.viewport.set([0,0,e.width/4,e.height/4]);var i=r.heatmapFbo;if(i)n.bindTexture(n.TEXTURE_2D,i.colorAttachment.get()),t.bindFramebuffer.set(i.framebuffer);else{var a=n.createTexture();n.bindTexture(n.TEXTURE_2D,a),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,n.LINEAR),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,n.LINEAR),i=r.heatmapFbo=t.createFramebuffer(e.width/4,e.height/4),function t(e,r,n,i){var a=e.gl;a.texImage2D(a.TEXTURE_2D,0,a.RGBA,r.width/4,r.height/4,0,a.RGBA,e.extTextureHalfFloat?e.extTextureHalfFloat.HALF_FLOAT_OES:a.UNSIGNED_BYTE,null),i.colorAttachment.set(n),e.extTextureHalfFloat&&a.checkFramebufferStatus(a.FRAMEBUFFER)!==a.FRAMEBUFFER_COMPLETE&&(e.extTextureHalfFloat=null,i.colorAttachment.setDirty(),t(e,r,n,i))}(t,e,a,i)}}(a,e,n),a.clear({color:t.Color.transparent});for(var u=0;u<i.length;u++){var h=i[u];if(!r.hasRenderableParent(h)){var f=r.getTile(h),p=f.getBucket(n);if(p){var d=p.programConfigurations.get(n.id),g=e.useProgram(\"heatmap\",d),v=e.transform.zoom;g.draw(a,o.TRIANGLES,s,l,c,St.disabled,Tr(h.posMatrix,f,v,n.paint.get(\"heatmap-intensity\")),n.id,p.layoutVertexBuffer,p.indexBuffer,p.segments,n.paint,e.transform.zoom,d)}}}a.viewport.set([0,0,e.width,e.height])}else\"translucent\"===e.renderPass&&(e.context.setColorMode(e.colorModeForRenderPass()),function(e,r){var n=e.context,i=n.gl,a=r.heatmapFbo;if(a){n.activeTexture.set(i.TEXTURE0),i.bindTexture(i.TEXTURE_2D,a.colorAttachment.get()),n.activeTexture.set(i.TEXTURE1);var o=r.colorRampTexture;o||(o=r.colorRampTexture=new t.Texture(n,r.colorRamp,i.RGBA)),o.bind(i.LINEAR,i.CLAMP_TO_EDGE),e.useProgram(\"heatmapTexture\").draw(n,i.TRIANGLES,Tt.disabled,At.disabled,e.colorModeForRenderPass(),St.disabled,function(e,r,n,i){var a=t.create();t.ortho(a,0,e.width,e.height,0,0,1);var o=e.context.gl;return{u_matrix:a,u_world:[o.drawingBufferWidth,o.drawingBufferHeight],u_image:n,u_color_ramp:i,u_opacity:r.paint.get(\"heatmap-opacity\")}}(e,r,0,1),r.id,e.viewportBuffer,e.quadTriangleIndexBuffer,e.viewportSegments,r.paint,e.transform.zoom)}}(e,n))},line:function(e,r,n,i){if(\"translucent\"===e.renderPass){var a=n.paint.get(\"line-opacity\"),o=n.paint.get(\"line-width\");if(0!==a.constantOr(1)&&0!==o.constantOr(1)){var s=e.depthModeForSublayer(0,Tt.ReadOnly),l=e.colorModeForRenderPass(),c=n.paint.get(\"line-dasharray\"),u=n.paint.get(\"line-pattern\"),h=u.constantOr(1),f=n.paint.get(\"line-gradient\"),p=n.getCrossfadeParameters(),d=c?\"lineSDF\":h?\"linePattern\":f?\"lineGradient\":\"line\",g=e.context,v=g.gl,m=!0;if(f){g.activeTexture.set(v.TEXTURE0);var y=n.gradientTexture;if(!n.gradient)return;y||(y=n.gradientTexture=new t.Texture(g,n.gradient,v.RGBA)),y.bind(v.LINEAR,v.CLAMP_TO_EDGE)}for(var x=0,b=i;x<b.length;x+=1){var _=b[x],w=r.getTile(_);if(!h||w.patternsLoaded()){var k=w.getBucket(n);if(k){var T=k.programConfigurations.get(n.id),A=e.context.program.get(),M=e.useProgram(d,T),S=m||M.program!==A,E=u.constantOr(null);if(E&&w.imageAtlas){var C=w.imageAtlas.patternPositions[E.to],L=w.imageAtlas.patternPositions[E.from];C&&L&&T.setConstantPatternPositions(C,L)}var P=c?Pr(e,w,n,c,p):h?Lr(e,w,n,p):f?Cr(e,w,n):Er(e,w,n);c&&(S||e.lineAtlas.dirty)?(g.activeTexture.set(v.TEXTURE0),e.lineAtlas.bind(g)):h&&(g.activeTexture.set(v.TEXTURE0),w.imageAtlasTexture.bind(v.LINEAR,v.CLAMP_TO_EDGE),T.updatePatternPaintBuffers(p)),M.draw(g,v.TRIANGLES,s,e.stencilModeForClipping(_),l,St.disabled,P,n.id,k.layoutVertexBuffer,k.indexBuffer,k.segments,n.paint,e.transform.zoom,T),m=!1}}}}}},fill:function(e,r,n,i){var a=n.paint.get(\"fill-color\"),o=n.paint.get(\"fill-opacity\");if(0!==o.constantOr(1)){var s=e.colorModeForRenderPass(),l=n.paint.get(\"fill-pattern\"),c=e.opaquePassEnabledForLayer()&&!l.constantOr(1)&&1===a.constantOr(t.Color.transparent).a&&1===o.constantOr(0)?\"opaque\":\"translucent\";if(e.renderPass===c){var u=e.depthModeForSublayer(1,\"opaque\"===e.renderPass?Tt.ReadWrite:Tt.ReadOnly);Xr(e,r,n,i,u,s,!1)}if(\"translucent\"===e.renderPass&&n.paint.get(\"fill-antialias\")){var h=e.depthModeForSublayer(n.getPaintProperty(\"fill-outline-color\")?2:0,Tt.ReadOnly);Xr(e,r,n,i,h,s,!0)}}},\"fill-extrusion\":function(t,e,r,n){var i=r.paint.get(\"fill-extrusion-opacity\");if(0!==i&&\"translucent\"===t.renderPass){var a=new Tt(t.context.gl.LEQUAL,Tt.ReadWrite,t.depthRangeFor3D);if(1!==i||r.paint.get(\"fill-extrusion-pattern\").constantOr(1))Zr(t,e,r,n,a,At.disabled,Mt.disabled),Zr(t,e,r,n,a,t.stencilModeFor3D(),t.colorModeForRenderPass());else{var o=t.colorModeForRenderPass();Zr(t,e,r,n,a,At.disabled,o)}}},hillshade:function(t,e,r,n){if(\"offscreen\"===t.renderPass||\"translucent\"===t.renderPass){for(var i=t.context,a=e.getSource().maxzoom,o=t.depthModeForSublayer(0,Tt.ReadOnly),s=At.disabled,l=t.colorModeForRenderPass(),c=0,u=n;c<u.length;c+=1){var h=u[c],f=e.getTile(h);f.needsHillshadePrepare&&\"offscreen\"===t.renderPass?Kr(t,f,r,a,o,s,l):\"translucent\"===t.renderPass&&Jr(t,f,r,o,s,l)}i.viewport.set([0,0,t.width,t.height])}},raster:function(t,e,r,n){if(\"translucent\"===t.renderPass&&0!==r.paint.get(\"raster-opacity\"))for(var i=t.context,a=i.gl,o=e.getSource(),s=t.useProgram(\"raster\"),l=At.disabled,c=t.colorModeForRenderPass(),u=n.length&&n[0].overscaledZ,h=!t.options.moving,f=0,p=n;f<p.length;f+=1){var d=p[f],g=t.depthModeForSublayer(d.overscaledZ-u,1===r.paint.get(\"raster-opacity\")?Tt.ReadWrite:Tt.ReadOnly,a.LESS),v=e.getTile(d),m=t.transform.calculatePosMatrix(d.toUnwrapped(),h);v.registerFadeDuration(r.paint.get(\"raster-fade-duration\"));var y=e.findLoadedParent(d,0),x=$r(v,y,e,r,t.transform),b=void 0,_=void 0,w=\"nearest\"===r.paint.get(\"raster-resampling\")?a.NEAREST:a.LINEAR;i.activeTexture.set(a.TEXTURE0),v.texture.bind(w,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),i.activeTexture.set(a.TEXTURE1),y?(y.texture.bind(w,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),b=Math.pow(2,y.tileID.overscaledZ-v.tileID.overscaledZ),_=[v.tileID.canonical.x*b%1,v.tileID.canonical.y*b%1]):v.texture.bind(w,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST);var k=Ir(m,_||[0,0],b||1,x,r);o instanceof L?s.draw(i,a.TRIANGLES,g,l,c,St.disabled,k,r.id,o.boundsBuffer,t.quadTriangleIndexBuffer,o.boundsSegments):v.maskedBoundsBuffer&&v.maskedIndexBuffer&&v.segments?s.draw(i,a.TRIANGLES,g,l,c,St.disabled,k,r.id,v.maskedBoundsBuffer,v.maskedIndexBuffer,v.segments,r.paint,t.transform.zoom):s.draw(i,a.TRIANGLES,g,l,c,St.disabled,k,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}},background:function(t,e,r){var n=r.paint.get(\"background-color\"),i=r.paint.get(\"background-opacity\");if(0!==i){var a=t.context,o=a.gl,s=t.transform,l=s.tileSize,c=r.paint.get(\"background-pattern\");if(!t.isPatternMissing(c)){var u=c||1!==n.a||1!==i?\"translucent\":\"opaque\";if(t.renderPass===u){var h=At.disabled,f=t.depthModeForSublayer(0,\"opaque\"===u?Tt.ReadWrite:Tt.ReadOnly),p=t.colorModeForRenderPass(),d=t.useProgram(c?\"backgroundPattern\":\"background\"),g=s.coveringTiles({tileSize:l});c&&(a.activeTexture.set(o.TEXTURE0),t.imageManager.bind(t.context));for(var v=r.getCrossfadeParameters(),m=0,y=g;m<y.length;m+=1){var x=y[m],b=t.transform.calculatePosMatrix(x.toUnwrapped()),_=c?Br(b,i,t,c,{tileID:x,tileSize:l},v):Fr(b,i,n);d.draw(a,o.TRIANGLES,f,h,p,St.disabled,_,r.id,t.tileExtentBuffer,t.quadTriangleIndexBuffer,t.tileExtentSegments)}}}}},debug:function(t,e,r){for(var n=0;n<r.length;n++)Qr(t,e,r[n])},custom:function(t,e,r){var n=t.context,i=r.implementation;if(\"offscreen\"===t.renderPass){var a=i.prerender;a&&(t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),a.call(i,n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState())}else if(\"translucent\"===t.renderPass){t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),n.setStencilMode(At.disabled);var o=\"3d\"===i.renderingMode?new Tt(t.context.gl.LEQUAL,Tt.ReadWrite,t.depthRangeFor3D):t.depthModeForSublayer(0,Tt.ReadOnly);n.setDepthMode(o),i.render(n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState(),n.bindFramebuffer.set(null)}}},rn=function(e,r){this.context=new Et(e),this.transform=r,this._tileTextures={},this.setup(),this.numSublayers=Ct.maxUnderzooming+Ct.maxOverzooming+1,this.depthEpsilon=1/Math.pow(2,16),this.depthRboNeedsClear=!0,this.emptyProgramConfiguration=new t.ProgramConfiguration,this.crossTileSymbolIndex=new Pe};function nn(t,e){if(t.y>e.y){var r=t;t=e,e=r}return{x0:t.x,y0:t.y,x1:e.x,y1:e.y,dx:e.x-t.x,dy:e.y-t.y}}function an(t,e,r,n,i){var a=Math.max(r,Math.floor(e.y0)),o=Math.min(n,Math.ceil(e.y1));if(t.x0===e.x0&&t.y0===e.y0?t.x0+e.dy/t.dy*t.dx<e.x1:t.x1-e.dy/t.dy*t.dx<e.x0){var s=t;t=e,e=s}for(var l=t.dx/t.dy,c=e.dx/e.dy,u=t.dx>0,h=e.dx<0,f=a;f<o;f++){var p=l*Math.max(0,Math.min(t.dy,f+u-t.y0))+t.x0,d=c*Math.max(0,Math.min(e.dy,f+h-e.y0))+e.x0;i(Math.floor(d),Math.ceil(p),f)}}function on(t,e,r,n,i,a){var o,s=nn(t,e),l=nn(e,r),c=nn(r,t);s.dy>l.dy&&(o=s,s=l,l=o),s.dy>c.dy&&(o=s,s=c,c=o),l.dy>c.dy&&(o=l,l=c,c=o),s.dy&&an(c,s,n,i,a),l.dy&&an(c,l,n,i,a)}rn.prototype.resize=function(e,r){var n=this.context.gl;if(this.width=e*t.browser.devicePixelRatio,this.height=r*t.browser.devicePixelRatio,this.context.viewport.set([0,0,this.width,this.height]),this.style)for(var i=0,a=this.style._order;i<a.length;i+=1){var o=a[i];this.style._layers[o].resize()}this.depthRbo&&(n.deleteRenderbuffer(this.depthRbo),this.depthRbo=null)},rn.prototype.setup=function(){var e=this.context,r=new t.StructArrayLayout2i4;r.emplaceBack(0,0),r.emplaceBack(t.EXTENT,0),r.emplaceBack(0,t.EXTENT),r.emplaceBack(t.EXTENT,t.EXTENT),this.tileExtentBuffer=e.createVertexBuffer(r,Re.members),this.tileExtentSegments=t.SegmentVector.simpleSegment(0,0,4,2);var n=new t.StructArrayLayout2i4;n.emplaceBack(0,0),n.emplaceBack(t.EXTENT,0),n.emplaceBack(0,t.EXTENT),n.emplaceBack(t.EXTENT,t.EXTENT),this.debugBuffer=e.createVertexBuffer(n,Re.members),this.debugSegments=t.SegmentVector.simpleSegment(0,0,4,5);var i=new t.StructArrayLayout4i8;i.emplaceBack(0,0,0,0),i.emplaceBack(t.EXTENT,0,t.EXTENT,0),i.emplaceBack(0,t.EXTENT,0,t.EXTENT),i.emplaceBack(t.EXTENT,t.EXTENT,t.EXTENT,t.EXTENT),this.rasterBoundsBuffer=e.createVertexBuffer(i,t.rasterBoundsAttributes.members),this.rasterBoundsSegments=t.SegmentVector.simpleSegment(0,0,4,2);var a=new t.StructArrayLayout2i4;a.emplaceBack(0,0),a.emplaceBack(1,0),a.emplaceBack(0,1),a.emplaceBack(1,1),this.viewportBuffer=e.createVertexBuffer(a,Re.members),this.viewportSegments=t.SegmentVector.simpleSegment(0,0,4,2);var o=new t.StructArrayLayout1ui2;o.emplaceBack(0),o.emplaceBack(1),o.emplaceBack(3),o.emplaceBack(2),o.emplaceBack(0),this.tileBorderIndexBuffer=e.createIndexBuffer(o);var s=new t.StructArrayLayout3ui6;s.emplaceBack(0,1,2),s.emplaceBack(2,1,3),this.quadTriangleIndexBuffer=e.createIndexBuffer(s);var l=this.context.gl;this.stencilClearMode=new At({func:l.ALWAYS,mask:0},0,255,l.ZERO,l.ZERO,l.ZERO)},rn.prototype.clearStencil=function(){var e=this.context,r=e.gl;this.nextStencilID=1,this.currentStencilSource=void 0;var n=t.create();t.ortho(n,0,this.width,this.height,0,0,1),t.scale(n,n,[r.drawingBufferWidth,r.drawingBufferHeight,0]),this.useProgram(\"clippingMask\").draw(e,r.TRIANGLES,Tt.disabled,this.stencilClearMode,Mt.disabled,St.disabled,kr(n),\"$clipping\",this.viewportBuffer,this.quadTriangleIndexBuffer,this.viewportSegments)},rn.prototype._renderTileClippingMasks=function(t,e){if(this.currentStencilSource!==t.source&&t.isTileClipped()&&e&&e.length){this.currentStencilSource=t.source;var r=this.context,n=r.gl;this.nextStencilID+e.length>256&&this.clearStencil(),r.setColorMode(Mt.disabled),r.setDepthMode(Tt.disabled);var i=this.useProgram(\"clippingMask\");this._tileClippingMaskIDs={};for(var a=0,o=e;a<o.length;a+=1){var s=o[a],l=this._tileClippingMaskIDs[s.key]=this.nextStencilID++;i.draw(r,n.TRIANGLES,Tt.disabled,new At({func:n.ALWAYS,mask:0},l,255,n.KEEP,n.KEEP,n.REPLACE),Mt.disabled,St.disabled,kr(s.posMatrix),\"$clipping\",this.tileExtentBuffer,this.quadTriangleIndexBuffer,this.tileExtentSegments)}}},rn.prototype.stencilModeFor3D=function(){this.nextStencilID+1>256&&this.clearStencil();var t=this.nextStencilID++,e=this.context.gl;return new At({func:e.NOTEQUAL,mask:255},t,255,e.KEEP,e.KEEP,e.REPLACE)},rn.prototype.stencilModeForClipping=function(t){var e=this.context.gl;return new At({func:e.EQUAL,mask:255},this._tileClippingMaskIDs[t.key],0,e.KEEP,e.KEEP,e.REPLACE)},rn.prototype.colorModeForRenderPass=function(){var e=this.context.gl;return this._showOverdrawInspector?new Mt([e.CONSTANT_COLOR,e.ONE],new t.Color(1/8,1/8,1/8,0),[!0,!0,!0,!0]):\"opaque\"===this.renderPass?Mt.unblended:Mt.alphaBlended},rn.prototype.depthModeForSublayer=function(t,e,r){if(!this.opaquePassEnabledForLayer())return Tt.disabled;var n=1-((1+this.currentLayer)*this.numSublayers+t)*this.depthEpsilon;return new Tt(r||this.context.gl.LEQUAL,e,[n,n])},rn.prototype.opaquePassEnabledForLayer=function(){return this.currentLayer<this.opaquePassCutoff},rn.prototype.render=function(e,r){this.style=e,this.options=r,this.lineAtlas=e.lineAtlas,this.imageManager=e.imageManager,this.glyphManager=e.glyphManager,this.symbolFadeChange=e.placement.symbolFadeChange(t.browser.now()),this.imageManager.beginFrame();var n=this.style._order,i=this.style.sourceCaches;for(var a in i){var o=i[a];o.used&&o.prepare(this.context)}var s={},l={},c={};for(var u in i){var h=i[u];s[u]=h.getVisibleCoordinates(),l[u]=s[u].slice().reverse(),c[u]=h.getVisibleCoordinates(!0).reverse()}for(var f in i){var p=i[f],d=p.getSource();if(\"raster\"===d.type||\"raster-dem\"===d.type){for(var g=[],v=0,m=s[f];v<m.length;v+=1){var y=m[v];g.push(p.getTile(y))}jr(g,this.context)}}this.opaquePassCutoff=1/0;for(var x=0;x<n.length;x++){var b=n[x];if(this.style._layers[b].is3D()){this.opaquePassCutoff=x;break}}this.renderPass=\"offscreen\",this.depthRboNeedsClear=!0;for(var _=0,w=n;_<w.length;_+=1){var k=w[_],T=this.style._layers[k];if(T.hasOffscreenPass()&&!T.isHidden(this.transform.zoom)){var A=l[T.source];(\"custom\"===T.type||A.length)&&this.renderLayer(this,i[T.source],T,A)}}for(this.context.bindFramebuffer.set(null),this.context.clear({color:r.showOverdrawInspector?t.Color.black:t.Color.transparent,depth:1}),this.clearStencil(),this._showOverdrawInspector=r.showOverdrawInspector,this.depthRangeFor3D=[0,1-(e._order.length+2)*this.numSublayers*this.depthEpsilon],this.renderPass=\"opaque\",this.currentLayer=n.length-1;this.currentLayer>=0;this.currentLayer--){var M=this.style._layers[n[this.currentLayer]],S=i[M.source],E=s[M.source];this._renderTileClippingMasks(M,E),this.renderLayer(this,S,M,E)}for(this.renderPass=\"translucent\",this.currentLayer=0;this.currentLayer<n.length;this.currentLayer++){var C=this.style._layers[n[this.currentLayer]],L=i[C.source],P=(\"symbol\"===C.type?c:l)[C.source];this._renderTileClippingMasks(C,s[C.source]),this.renderLayer(this,L,C,P)}if(this.options.showTileBoundaries)for(var O in i){en.debug(this,i[O],s[O]);break}this.context.setDefault()},rn.prototype.setupOffscreenDepthRenderbuffer=function(){var t=this.context;this.depthRbo||(this.depthRbo=t.createRenderbuffer(t.gl.DEPTH_COMPONENT16,this.width,this.height))},rn.prototype.renderLayer=function(t,e,r,n){r.isHidden(this.transform.zoom)||(\"background\"===r.type||\"custom\"===r.type||n.length)&&(this.id=r.id,en[r.type](t,e,r,n,this.style.placement.variableOffsets))},rn.prototype.translatePosMatrix=function(e,r,n,i,a){if(!n[0]&&!n[1])return e;var o=a?\"map\"===i?this.transform.angle:0:\"viewport\"===i?-this.transform.angle:0;if(o){var s=Math.sin(o),l=Math.cos(o);n=[n[0]*l-n[1]*s,n[0]*s+n[1]*l]}var c=[a?n[0]:le(r,n[0],this.transform.zoom),a?n[1]:le(r,n[1],this.transform.zoom),0],u=new Float32Array(16);return t.translate(u,e,c),u},rn.prototype.saveTileTexture=function(t){var e=this._tileTextures[t.size[0]];e?e.push(t):this._tileTextures[t.size[0]]=[t]},rn.prototype.getTileTexture=function(t){var e=this._tileTextures[t];return e&&e.length>0?e.pop():null},rn.prototype.isPatternMissing=function(t){if(!t)return!1;var e=this.imageManager.getPattern(t.from),r=this.imageManager.getPattern(t.to);return!e||!r},rn.prototype.useProgram=function(t,e){void 0===e&&(e=this.emptyProgramConfiguration),this.cache=this.cache||{};var r=\"\"+t+(e.cacheKey||\"\")+(this._showOverdrawInspector?\"/overdraw\":\"\");return this.cache[r]||(this.cache[r]=new hr(this.context,cr[t],e,Nr[t],this._showOverdrawInspector)),this.cache[r]},rn.prototype.setCustomLayerDefaults=function(){this.context.unbindVAO(),this.context.cullFace.setDefault(),this.context.activeTexture.setDefault(),this.context.pixelStoreUnpack.setDefault(),this.context.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.context.pixelStoreUnpackFlipY.setDefault()},rn.prototype.setBaseState=function(){var t=this.context.gl;this.context.cullFace.set(!1),this.context.viewport.set([0,0,this.width,this.height]),this.context.blendEquation.set(t.FUNC_ADD)};var sn=function(e,r,n){this.tileSize=512,this.maxValidLatitude=85.051129,this._renderWorldCopies=void 0===n||n,this._minZoom=e||0,this._maxZoom=r||22,this.setMaxBounds(),this.width=0,this.height=0,this._center=new t.LngLat(0,0),this.zoom=0,this.angle=0,this._fov=.6435011087932844,this._pitch=0,this._unmodified=!0,this._posMatrixCache={},this._alignedPosMatrixCache={}},ln={minZoom:{configurable:!0},maxZoom:{configurable:!0},renderWorldCopies:{configurable:!0},worldSize:{configurable:!0},centerPoint:{configurable:!0},size:{configurable:!0},bearing:{configurable:!0},pitch:{configurable:!0},fov:{configurable:!0},zoom:{configurable:!0},center:{configurable:!0},unmodified:{configurable:!0},point:{configurable:!0}};sn.prototype.clone=function(){var t=new sn(this._minZoom,this._maxZoom,this._renderWorldCopies);return t.tileSize=this.tileSize,t.latRange=this.latRange,t.width=this.width,t.height=this.height,t._center=this._center,t.zoom=this.zoom,t.angle=this.angle,t._fov=this._fov,t._pitch=this._pitch,t._unmodified=this._unmodified,t._calcMatrices(),t},ln.minZoom.get=function(){return this._minZoom},ln.minZoom.set=function(t){this._minZoom!==t&&(this._minZoom=t,this.zoom=Math.max(this.zoom,t))},ln.maxZoom.get=function(){return this._maxZoom},ln.maxZoom.set=function(t){this._maxZoom!==t&&(this._maxZoom=t,this.zoom=Math.min(this.zoom,t))},ln.renderWorldCopies.get=function(){return this._renderWorldCopies},ln.renderWorldCopies.set=function(t){void 0===t?t=!0:null===t&&(t=!1),this._renderWorldCopies=t},ln.worldSize.get=function(){return this.tileSize*this.scale},ln.centerPoint.get=function(){return this.size._div(2)},ln.size.get=function(){return new t.Point(this.width,this.height)},ln.bearing.get=function(){return-this.angle/Math.PI*180},ln.bearing.set=function(e){var r=-t.wrap(e,-180,180)*Math.PI/180;this.angle!==r&&(this._unmodified=!1,this.angle=r,this._calcMatrices(),this.rotationMatrix=t.create$2(),t.rotate(this.rotationMatrix,this.rotationMatrix,this.angle))},ln.pitch.get=function(){return this._pitch/Math.PI*180},ln.pitch.set=function(e){var r=t.clamp(e,0,60)/180*Math.PI;this._pitch!==r&&(this._unmodified=!1,this._pitch=r,this._calcMatrices())},ln.fov.get=function(){return this._fov/Math.PI*180},ln.fov.set=function(t){t=Math.max(.01,Math.min(60,t)),this._fov!==t&&(this._unmodified=!1,this._fov=t/180*Math.PI,this._calcMatrices())},ln.zoom.get=function(){return this._zoom},ln.zoom.set=function(t){var e=Math.min(Math.max(t,this.minZoom),this.maxZoom);this._zoom!==e&&(this._unmodified=!1,this._zoom=e,this.scale=this.zoomScale(e),this.tileZoom=Math.floor(e),this.zoomFraction=e-this.tileZoom,this._constrain(),this._calcMatrices())},ln.center.get=function(){return this._center},ln.center.set=function(t){t.lat===this._center.lat&&t.lng===this._center.lng||(this._unmodified=!1,this._center=t,this._constrain(),this._calcMatrices())},sn.prototype.coveringZoomLevel=function(t){return(t.roundZoom?Math.round:Math.floor)(this.zoom+this.scaleZoom(this.tileSize/t.tileSize))},sn.prototype.getVisibleUnwrappedCoordinates=function(e){var r=[new t.UnwrappedTileID(0,e)];if(this._renderWorldCopies)for(var n=this.pointCoordinate(new t.Point(0,0)),i=this.pointCoordinate(new t.Point(this.width,0)),a=this.pointCoordinate(new t.Point(this.width,this.height)),o=this.pointCoordinate(new t.Point(0,this.height)),s=Math.floor(Math.min(n.x,i.x,a.x,o.x)),l=Math.floor(Math.max(n.x,i.x,a.x,o.x)),c=s-1;c<=l+1;c++)0!==c&&r.push(new t.UnwrappedTileID(c,e));return r},sn.prototype.coveringTiles=function(e){var r=this.coveringZoomLevel(e),n=r;if(void 0!==e.minzoom&&r<e.minzoom)return[];void 0!==e.maxzoom&&r>e.maxzoom&&(r=e.maxzoom);var i=t.MercatorCoordinate.fromLngLat(this.center),a=Math.pow(2,r),o=new t.Point(a*i.x-.5,a*i.y-.5);return function(e,r,n,i){void 0===i&&(i=!0);var a=1<<e,o={};function s(r,s,l){var c,u,h,f;if(l>=0&&l<=a)for(c=r;c<s;c++)u=Math.floor(c/a),h=(c%a+a)%a,0!==u&&!0!==i||(f=new t.OverscaledTileID(n,u,e,h,l),o[f.key]=f)}var l=r.map(function(e){return new t.Point(e.x,e.y)._mult(a)});return on(l[0],l[1],l[2],0,a,s),on(l[2],l[3],l[0],0,a,s),Object.keys(o).map(function(t){return o[t]})}(r,[this.pointCoordinate(new t.Point(0,0)),this.pointCoordinate(new t.Point(this.width,0)),this.pointCoordinate(new t.Point(this.width,this.height)),this.pointCoordinate(new t.Point(0,this.height))],e.reparseOverscaled?n:r,this._renderWorldCopies).sort(function(t,e){return o.dist(t.canonical)-o.dist(e.canonical)})},sn.prototype.resize=function(t,e){this.width=t,this.height=e,this.pixelsToGLUnits=[2/t,-2/e],this._constrain(),this._calcMatrices()},ln.unmodified.get=function(){return this._unmodified},sn.prototype.zoomScale=function(t){return Math.pow(2,t)},sn.prototype.scaleZoom=function(t){return Math.log(t)/Math.LN2},sn.prototype.project=function(e){var r=t.clamp(e.lat,-this.maxValidLatitude,this.maxValidLatitude);return new t.Point(t.mercatorXfromLng(e.lng)*this.worldSize,t.mercatorYfromLat(r)*this.worldSize)},sn.prototype.unproject=function(e){return new t.MercatorCoordinate(e.x/this.worldSize,e.y/this.worldSize).toLngLat()},ln.point.get=function(){return this.project(this.center)},sn.prototype.setLocationAtPoint=function(e,r){var n=this.pointCoordinate(r),i=this.pointCoordinate(this.centerPoint),a=this.locationCoordinate(e),o=new t.MercatorCoordinate(a.x-(n.x-i.x),a.y-(n.y-i.y));this.center=this.coordinateLocation(o),this._renderWorldCopies&&(this.center=this.center.wrap())},sn.prototype.locationPoint=function(t){return this.coordinatePoint(this.locationCoordinate(t))},sn.prototype.pointLocation=function(t){return this.coordinateLocation(this.pointCoordinate(t))},sn.prototype.locationCoordinate=function(e){return t.MercatorCoordinate.fromLngLat(e)},sn.prototype.coordinateLocation=function(t){return t.toLngLat()},sn.prototype.pointCoordinate=function(e){var r=[e.x,e.y,0,1],n=[e.x,e.y,1,1];t.transformMat4(r,r,this.pixelMatrixInverse),t.transformMat4(n,n,this.pixelMatrixInverse);var i=r[3],a=n[3],o=r[0]/i,s=n[0]/a,l=r[1]/i,c=n[1]/a,u=r[2]/i,h=n[2]/a,f=u===h?0:(0-u)/(h-u);return new t.MercatorCoordinate(t.number(o,s,f)/this.worldSize,t.number(l,c,f)/this.worldSize)},sn.prototype.coordinatePoint=function(e){var r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix),new t.Point(r[0]/r[3],r[1]/r[3])},sn.prototype.getBounds=function(){return(new t.LngLatBounds).extend(this.pointLocation(new t.Point(0,0))).extend(this.pointLocation(new t.Point(this.width,0))).extend(this.pointLocation(new t.Point(this.width,this.height))).extend(this.pointLocation(new t.Point(0,this.height)))},sn.prototype.getMaxBounds=function(){return this.latRange&&2===this.latRange.length&&this.lngRange&&2===this.lngRange.length?new t.LngLatBounds([this.lngRange[0],this.latRange[0]],[this.lngRange[1],this.latRange[1]]):null},sn.prototype.setMaxBounds=function(t){t?(this.lngRange=[t.getWest(),t.getEast()],this.latRange=[t.getSouth(),t.getNorth()],this._constrain()):(this.lngRange=null,this.latRange=[-this.maxValidLatitude,this.maxValidLatitude])},sn.prototype.calculatePosMatrix=function(e,r){void 0===r&&(r=!1);var n=e.key,i=r?this._alignedPosMatrixCache:this._posMatrixCache;if(i[n])return i[n];var a=e.canonical,o=this.worldSize/this.zoomScale(a.z),s=a.x+Math.pow(2,a.z)*e.wrap,l=t.identity(new Float64Array(16));return t.translate(l,l,[s*o,a.y*o,0]),t.scale(l,l,[o/t.EXTENT,o/t.EXTENT,1]),t.multiply(l,r?this.alignedProjMatrix:this.projMatrix,l),i[n]=new Float32Array(l),i[n]},sn.prototype.customLayerMatrix=function(){return this.mercatorMatrix.slice()},sn.prototype._constrain=function(){if(this.center&&this.width&&this.height&&!this._constraining){this._constraining=!0;var e,r,n,i,a=-90,o=90,s=-180,l=180,c=this.size,u=this._unmodified;if(this.latRange){var h=this.latRange;a=t.mercatorYfromLat(h[1])*this.worldSize,e=(o=t.mercatorYfromLat(h[0])*this.worldSize)-a<c.y?c.y/(o-a):0}if(this.lngRange){var f=this.lngRange;s=t.mercatorXfromLng(f[0])*this.worldSize,r=(l=t.mercatorXfromLng(f[1])*this.worldSize)-s<c.x?c.x/(l-s):0}var p=this.point,d=Math.max(r||0,e||0);if(d)return this.center=this.unproject(new t.Point(r?(l+s)/2:p.x,e?(o+a)/2:p.y)),this.zoom+=this.scaleZoom(d),this._unmodified=u,void(this._constraining=!1);if(this.latRange){var g=p.y,v=c.y/2;g-v<a&&(i=a+v),g+v>o&&(i=o-v)}if(this.lngRange){var m=p.x,y=c.x/2;m-y<s&&(n=s+y),m+y>l&&(n=l-y)}void 0===n&&void 0===i||(this.center=this.unproject(new t.Point(void 0!==n?n:p.x,void 0!==i?i:p.y))),this._unmodified=u,this._constraining=!1}},sn.prototype._calcMatrices=function(){if(this.height){this.cameraToCenterDistance=.5/Math.tan(this._fov/2)*this.height;var e=this._fov/2,r=Math.PI/2+this._pitch,n=Math.sin(e)*this.cameraToCenterDistance/Math.sin(Math.PI-r-e),i=this.point,a=i.x,o=i.y,s=1.01*(Math.cos(Math.PI/2-this._pitch)*n+this.cameraToCenterDistance),l=new Float64Array(16);t.perspective(l,this._fov,this.width/this.height,1,s),t.scale(l,l,[1,-1,1]),t.translate(l,l,[0,0,-this.cameraToCenterDistance]),t.rotateX(l,l,this._pitch),t.rotateZ(l,l,this.angle),t.translate(l,l,[-a,-o,0]),this.mercatorMatrix=t.scale([],l,[this.worldSize,this.worldSize,this.worldSize]),t.scale(l,l,[1,1,t.mercatorZfromAltitude(1,this.center.lat)*this.worldSize,1]),this.projMatrix=l;var c=this.width%2/2,u=this.height%2/2,h=Math.cos(this.angle),f=Math.sin(this.angle),p=a-Math.round(a)+h*c+f*u,d=o-Math.round(o)+h*u+f*c,g=new Float64Array(l);if(t.translate(g,g,[p>.5?p-1:p,d>.5?d-1:d,0]),this.alignedProjMatrix=g,l=t.create(),t.scale(l,l,[this.width/2,-this.height/2,1]),t.translate(l,l,[1,-1,0]),this.labelPlaneMatrix=l,l=t.create(),t.scale(l,l,[1,-1,1]),t.translate(l,l,[-1,-1,0]),t.scale(l,l,[2/this.width,2/this.height,1]),this.glCoordMatrix=l,this.pixelMatrix=t.multiply(new Float64Array(16),this.labelPlaneMatrix,this.projMatrix),!(l=t.invert(new Float64Array(16),this.pixelMatrix)))throw new Error(\"failed to invert matrix\");this.pixelMatrixInverse=l,this._posMatrixCache={},this._alignedPosMatrixCache={}}},sn.prototype.maxPitchScaleFactor=function(){if(!this.pixelMatrixInverse)return 1;var e=this.pointCoordinate(new t.Point(0,0)),r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix)[3]/this.cameraToCenterDistance},sn.prototype.getCameraPoint=function(){var e=this._pitch,r=Math.tan(e)*(this.cameraToCenterDistance||1);return this.centerPoint.add(new t.Point(0,r))},sn.prototype.getCameraQueryGeometry=function(e){var r=this.getCameraPoint();if(1===e.length)return[e[0],r];for(var n=r.x,i=r.y,a=r.x,o=r.y,s=0,l=e;s<l.length;s+=1){var c=l[s];n=Math.min(n,c.x),i=Math.min(i,c.y),a=Math.max(a,c.x),o=Math.max(o,c.y)}return[new t.Point(n,i),new t.Point(a,i),new t.Point(a,o),new t.Point(n,o),new t.Point(n,i)]},Object.defineProperties(sn.prototype,ln);var cn=function(){var e,r,n,i;t.bindAll([\"_onHashChange\",\"_updateHash\"],this),this._updateHash=(e=this._updateHashUnthrottled.bind(this),300,r=!1,n=null,i=function(){n=null,r&&(e(),n=setTimeout(i,300),r=!1)},function(){return r=!0,n||i(),n})};cn.prototype.addTo=function(e){return this._map=e,t.window.addEventListener(\"hashchange\",this._onHashChange,!1),this._map.on(\"moveend\",this._updateHash),this},cn.prototype.remove=function(){return t.window.removeEventListener(\"hashchange\",this._onHashChange,!1),this._map.off(\"moveend\",this._updateHash),clearTimeout(this._updateHash()),delete this._map,this},cn.prototype.getHashString=function(t){var e=this._map.getCenter(),r=Math.round(100*this._map.getZoom())/100,n=Math.ceil((r*Math.LN2+Math.log(512/360/.5))/Math.LN10),i=Math.pow(10,n),a=Math.round(e.lng*i)/i,o=Math.round(e.lat*i)/i,s=this._map.getBearing(),l=this._map.getPitch(),c=\"\";return c+=t?\"#/\"+a+\"/\"+o+\"/\"+r:\"#\"+r+\"/\"+o+\"/\"+a,(s||l)&&(c+=\"/\"+Math.round(10*s)/10),l&&(c+=\"/\"+Math.round(l)),c},cn.prototype._onHashChange=function(){var e=t.window.location.hash.replace(\"#\",\"\").split(\"/\");return e.length>=3&&(this._map.jumpTo({center:[+e[2],+e[1]],zoom:+e[0],bearing:+(e[3]||0),pitch:+(e[4]||0)}),!0)},cn.prototype._updateHashUnthrottled=function(){var e=this.getHashString();try{t.window.history.replaceState(t.window.history.state,\"\",e)}catch(t){}};var un=function(e){function n(n,i,a,o){void 0===o&&(o={});var s=r.mousePos(i.getCanvasContainer(),a),l=i.unproject(s);e.call(this,n,t.extend({point:s,lngLat:l,originalEvent:a},o)),this._defaultPrevented=!1,this.target=i}e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),hn=function(e){function n(n,i,a){var o=r.touchPos(i.getCanvasContainer(),a),s=o.map(function(t){return i.unproject(t)}),l=o.reduce(function(t,e,r,n){return t.add(e.div(n.length))},new t.Point(0,0)),c=i.unproject(l);e.call(this,n,{points:o,point:l,lngLats:s,lngLat:c,originalEvent:a}),this._defaultPrevented=!1}e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),fn=function(t){function e(e,r,n){t.call(this,e,{originalEvent:n}),this._defaultPrevented=!1}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={defaultPrevented:{configurable:!0}};return e.prototype.preventDefault=function(){this._defaultPrevented=!0},r.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(e.prototype,r),e}(t.Event),pn=function(e){this._map=e,this._el=e.getCanvasContainer(),this._delta=0,this._defaultZoomRate=.01,this._wheelZoomRate=1/450,t.bindAll([\"_onWheel\",\"_onTimeout\",\"_onScrollFrame\",\"_onScrollFinished\"],this)};pn.prototype.setZoomRate=function(t){this._defaultZoomRate=t},pn.prototype.setWheelZoomRate=function(t){this._wheelZoomRate=t},pn.prototype.isEnabled=function(){return!!this._enabled},pn.prototype.isActive=function(){return!!this._active},pn.prototype.isZooming=function(){return!!this._zooming},pn.prototype.enable=function(t){this.isEnabled()||(this._enabled=!0,this._aroundCenter=t&&\"center\"===t.around)},pn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},pn.prototype.onWheel=function(e){if(this.isEnabled()){var r=e.deltaMode===t.window.WheelEvent.DOM_DELTA_LINE?40*e.deltaY:e.deltaY,n=t.browser.now(),i=n-(this._lastWheelEventTime||0);this._lastWheelEventTime=n,0!==r&&r%4.000244140625==0?this._type=\"wheel\":0!==r&&Math.abs(r)<4?this._type=\"trackpad\":i>400?(this._type=null,this._lastValue=r,this._timeout=setTimeout(this._onTimeout,40,e)):this._type||(this._type=Math.abs(i*r)<200?\"trackpad\":\"wheel\",this._timeout&&(clearTimeout(this._timeout),this._timeout=null,r+=this._lastValue)),e.shiftKey&&r&&(r/=4),this._type&&(this._lastWheelEvent=e,this._delta-=r,this.isActive()||this._start(e)),e.preventDefault()}},pn.prototype._onTimeout=function(t){this._type=\"wheel\",this._delta-=this._lastValue,this.isActive()||this._start(t)},pn.prototype._start=function(e){if(this._delta){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),this._active=!0,this.isZooming()||(this._zooming=!0,this._map.fire(new t.Event(\"movestart\",{originalEvent:e})),this._map.fire(new t.Event(\"zoomstart\",{originalEvent:e}))),this._finishTimeout&&clearTimeout(this._finishTimeout);var n=r.mousePos(this._el,e);this._around=t.LngLat.convert(this._aroundCenter?this._map.getCenter():this._map.unproject(n)),this._aroundPoint=this._map.transform.locationPoint(this._around),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onScrollFrame))}},pn.prototype._onScrollFrame=function(){var e=this;if(this._frameId=null,this.isActive()){var r=this._map.transform;if(0!==this._delta){var n=\"wheel\"===this._type&&Math.abs(this._delta)>4.000244140625?this._wheelZoomRate:this._defaultZoomRate,i=2/(1+Math.exp(-Math.abs(this._delta*n)));this._delta<0&&0!==i&&(i=1/i);var a=\"number\"==typeof this._targetZoom?r.zoomScale(this._targetZoom):r.scale;this._targetZoom=Math.min(r.maxZoom,Math.max(r.minZoom,r.scaleZoom(a*i))),\"wheel\"===this._type&&(this._startZoom=r.zoom,this._easing=this._smoothOutEasing(200)),this._delta=0}var o=\"number\"==typeof this._targetZoom?this._targetZoom:r.zoom,s=this._startZoom,l=this._easing,c=!1;if(\"wheel\"===this._type&&s&&l){var u=Math.min((t.browser.now()-this._lastWheelEventTime)/200,1),h=l(u);r.zoom=t.number(s,o,h),u<1?this._frameId||(this._frameId=this._map._requestRenderFrame(this._onScrollFrame)):c=!0}else r.zoom=o,c=!0;r.setLocationAtPoint(this._around,this._aroundPoint),this._map.fire(new t.Event(\"move\",{originalEvent:this._lastWheelEvent})),this._map.fire(new t.Event(\"zoom\",{originalEvent:this._lastWheelEvent})),c&&(this._active=!1,this._finishTimeout=setTimeout(function(){e._zooming=!1,e._map.fire(new t.Event(\"zoomend\",{originalEvent:e._lastWheelEvent})),e._map.fire(new t.Event(\"moveend\",{originalEvent:e._lastWheelEvent})),delete e._targetZoom},200))}},pn.prototype._smoothOutEasing=function(e){var r=t.ease;if(this._prevEase){var n=this._prevEase,i=(t.browser.now()-n.start)/n.duration,a=n.easing(i+.01)-n.easing(i),o=.27/Math.sqrt(a*a+1e-4)*.01,s=Math.sqrt(.0729-o*o);r=t.bezier(o,s,.25,1)}return this._prevEase={start:t.browser.now(),duration:e,easing:r},r};var dn=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._container=e.getContainer(),this._clickTolerance=r.clickTolerance||1,t.bindAll([\"_onMouseMove\",\"_onMouseUp\",\"_onKeyDown\"],this)};dn.prototype.isEnabled=function(){return!!this._enabled},dn.prototype.isActive=function(){return!!this._active},dn.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},dn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},dn.prototype.onMouseDown=function(e){this.isEnabled()&&e.shiftKey&&0===e.button&&(t.window.document.addEventListener(\"mousemove\",this._onMouseMove,!1),t.window.document.addEventListener(\"keydown\",this._onKeyDown,!1),t.window.document.addEventListener(\"mouseup\",this._onMouseUp,!1),r.disableDrag(),this._startPos=this._lastPos=r.mousePos(this._el,e),this._active=!0)},dn.prototype._onMouseMove=function(t){var e=r.mousePos(this._el,t);if(!(this._lastPos.equals(e)||!this._box&&e.dist(this._startPos)<this._clickTolerance)){var n=this._startPos;this._lastPos=e,this._box||(this._box=r.create(\"div\",\"mapboxgl-boxzoom\",this._container),this._container.classList.add(\"mapboxgl-crosshair\"),this._fireEvent(\"boxzoomstart\",t));var i=Math.min(n.x,e.x),a=Math.max(n.x,e.x),o=Math.min(n.y,e.y),s=Math.max(n.y,e.y);r.setTransform(this._box,\"translate(\"+i+\"px,\"+o+\"px)\"),this._box.style.width=a-i+\"px\",this._box.style.height=s-o+\"px\"}},dn.prototype._onMouseUp=function(e){if(0===e.button){var n=this._startPos,i=r.mousePos(this._el,e);this._finish(),r.suppressClick(),n.x===i.x&&n.y===i.y?this._fireEvent(\"boxzoomcancel\",e):this._map.fitScreenCoordinates(n,i,this._map.getBearing(),{linear:!0}).fire(new t.Event(\"boxzoomend\",{originalEvent:e}))}},dn.prototype._onKeyDown=function(t){27===t.keyCode&&(this._finish(),this._fireEvent(\"boxzoomcancel\",t))},dn.prototype._finish=function(){this._active=!1,t.window.document.removeEventListener(\"mousemove\",this._onMouseMove,!1),t.window.document.removeEventListener(\"keydown\",this._onKeyDown,!1),t.window.document.removeEventListener(\"mouseup\",this._onMouseUp,!1),this._container.classList.remove(\"mapboxgl-crosshair\"),this._box&&(r.remove(this._box),this._box=null),r.enableDrag(),delete this._startPos,delete this._lastPos},dn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,{originalEvent:r}))};var gn=t.bezier(0,0,.25,1),vn=function(e,r){this._map=e,this._el=r.element||e.getCanvasContainer(),this._state=\"disabled\",this._button=r.button||\"right\",this._bearingSnap=r.bearingSnap||0,this._pitchWithRotate=!1!==r.pitchWithRotate,t.bindAll([\"onMouseDown\",\"_onMouseMove\",\"_onMouseUp\",\"_onBlur\",\"_onDragFrame\"],this)};vn.prototype.isEnabled=function(){return\"disabled\"!==this._state},vn.prototype.isActive=function(){return\"active\"===this._state},vn.prototype.enable=function(){this.isEnabled()||(this._state=\"enabled\")},vn.prototype.disable=function(){if(this.isEnabled())switch(this._state){case\"active\":this._state=\"disabled\",this._unbind(),this._deactivate(),this._fireEvent(\"rotateend\"),this._pitchWithRotate&&this._fireEvent(\"pitchend\"),this._fireEvent(\"moveend\");break;case\"pending\":this._state=\"disabled\",this._unbind();break;default:this._state=\"disabled\"}},vn.prototype.onMouseDown=function(e){if(\"enabled\"===this._state){if(\"right\"===this._button){if(this._eventButton=r.mouseButton(e),this._eventButton!==(e.ctrlKey?0:2))return}else{if(e.ctrlKey||0!==r.mouseButton(e))return;this._eventButton=0}r.disableDrag(),t.window.document.addEventListener(\"mousemove\",this._onMouseMove,{capture:!0}),t.window.document.addEventListener(\"mouseup\",this._onMouseUp),t.window.addEventListener(\"blur\",this._onBlur),this._state=\"pending\",this._inertia=[[t.browser.now(),this._map.getBearing()]],this._startPos=this._lastPos=r.mousePos(this._el,e),this._center=this._map.transform.centerPoint,e.preventDefault()}},vn.prototype._onMouseMove=function(t){var e=r.mousePos(this._el,t);this._lastPos.equals(e)||(this._lastMoveEvent=t,this._lastPos=e,\"pending\"===this._state&&(this._state=\"active\",this._fireEvent(\"rotatestart\",t),this._fireEvent(\"movestart\",t),this._pitchWithRotate&&this._fireEvent(\"pitchstart\",t)),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onDragFrame)))},vn.prototype._onDragFrame=function(){this._frameId=null;var e=this._lastMoveEvent;if(e){var r=this._map.transform,n=this._startPos,i=this._lastPos,a=.8*(n.x-i.x),o=-.5*(n.y-i.y),s=r.bearing-a,l=r.pitch-o,c=this._inertia,u=c[c.length-1];this._drainInertiaBuffer(),c.push([t.browser.now(),this._map._normalizeBearing(s,u[1])]),r.bearing=s,this._pitchWithRotate&&(this._fireEvent(\"pitch\",e),r.pitch=l),this._fireEvent(\"rotate\",e),this._fireEvent(\"move\",e),delete this._lastMoveEvent,this._startPos=this._lastPos}},vn.prototype._onMouseUp=function(t){if(r.mouseButton(t)===this._eventButton)switch(this._state){case\"active\":this._state=\"enabled\",r.suppressClick(),this._unbind(),this._deactivate(),this._inertialRotate(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},vn.prototype._onBlur=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._fireEvent(\"rotateend\",t),this._pitchWithRotate&&this._fireEvent(\"pitchend\",t),this._fireEvent(\"moveend\",t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},vn.prototype._unbind=function(){t.window.document.removeEventListener(\"mousemove\",this._onMouseMove,{capture:!0}),t.window.document.removeEventListener(\"mouseup\",this._onMouseUp),t.window.removeEventListener(\"blur\",this._onBlur),r.enableDrag()},vn.prototype._deactivate=function(){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._lastMoveEvent,delete this._startPos,delete this._lastPos},vn.prototype._inertialRotate=function(t){var e=this;this._fireEvent(\"rotateend\",t),this._drainInertiaBuffer();var r=this._map,n=r.getBearing(),i=this._inertia,a=function(){Math.abs(n)<e._bearingSnap?r.resetNorth({noMoveStart:!0},{originalEvent:t}):e._fireEvent(\"moveend\",t),e._pitchWithRotate&&e._fireEvent(\"pitchend\",t)};if(i.length<2)a();else{var o=i[0],s=i[i.length-1],l=i[i.length-2],c=r._normalizeBearing(n,l[1]),u=s[1]-o[1],h=u<0?-1:1,f=(s[0]-o[0])/1e3;if(0!==u&&0!==f){var p=Math.abs(u*(.25/f));p>180&&(p=180);var d=p/180;c+=h*p*(d/2),Math.abs(r._normalizeBearing(c,0))<this._bearingSnap&&(c=r._normalizeBearing(0,c)),r.rotateTo(c,{duration:1e3*d,easing:gn,noMoveStart:!0},{originalEvent:t})}else a()}},vn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},vn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>0&&r-e[0][0]>160;)e.shift()};var mn=t.bezier(0,0,.3,1),yn=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._state=\"disabled\",this._clickTolerance=r.clickTolerance||1,t.bindAll([\"_onMove\",\"_onMouseUp\",\"_onTouchEnd\",\"_onBlur\",\"_onDragFrame\"],this)};yn.prototype.isEnabled=function(){return\"disabled\"!==this._state},yn.prototype.isActive=function(){return\"active\"===this._state},yn.prototype.enable=function(){this.isEnabled()||(this._el.classList.add(\"mapboxgl-touch-drag-pan\"),this._state=\"enabled\")},yn.prototype.disable=function(){if(this.isEnabled())switch(this._el.classList.remove(\"mapboxgl-touch-drag-pan\"),this._state){case\"active\":this._state=\"disabled\",this._unbind(),this._deactivate(),this._fireEvent(\"dragend\"),this._fireEvent(\"moveend\");break;case\"pending\":this._state=\"disabled\",this._unbind();break;default:this._state=\"disabled\"}},yn.prototype.onMouseDown=function(e){\"enabled\"===this._state&&(e.ctrlKey||0!==r.mouseButton(e)||(r.addEventListener(t.window.document,\"mousemove\",this._onMove,{capture:!0}),r.addEventListener(t.window.document,\"mouseup\",this._onMouseUp),this._start(e)))},yn.prototype.onTouchStart=function(e){\"enabled\"===this._state&&(e.touches.length>1||(r.addEventListener(t.window.document,\"touchmove\",this._onMove,{capture:!0,passive:!1}),r.addEventListener(t.window.document,\"touchend\",this._onTouchEnd),this._start(e)))},yn.prototype._start=function(e){t.window.addEventListener(\"blur\",this._onBlur),this._state=\"pending\",this._startPos=this._mouseDownPos=this._lastPos=r.mousePos(this._el,e),this._inertia=[[t.browser.now(),this._startPos]]},yn.prototype._onMove=function(e){e.preventDefault();var n=r.mousePos(this._el,e);this._lastPos.equals(n)||\"pending\"===this._state&&n.dist(this._mouseDownPos)<this._clickTolerance||(this._lastMoveEvent=e,this._lastPos=n,this._drainInertiaBuffer(),this._inertia.push([t.browser.now(),this._lastPos]),\"pending\"===this._state&&(this._state=\"active\",this._fireEvent(\"dragstart\",e),this._fireEvent(\"movestart\",e)),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onDragFrame)))},yn.prototype._onDragFrame=function(){this._frameId=null;var t=this._lastMoveEvent;if(t){var e=this._map.transform;e.setLocationAtPoint(e.pointLocation(this._startPos),this._lastPos),this._fireEvent(\"drag\",t),this._fireEvent(\"move\",t),this._startPos=this._lastPos,delete this._lastMoveEvent}},yn.prototype._onMouseUp=function(t){if(0===r.mouseButton(t))switch(this._state){case\"active\":this._state=\"enabled\",r.suppressClick(),this._unbind(),this._deactivate(),this._inertialPan(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},yn.prototype._onTouchEnd=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._inertialPan(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},yn.prototype._onBlur=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._fireEvent(\"dragend\",t),this._fireEvent(\"moveend\",t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},yn.prototype._unbind=function(){r.removeEventListener(t.window.document,\"touchmove\",this._onMove,{capture:!0,passive:!1}),r.removeEventListener(t.window.document,\"touchend\",this._onTouchEnd),r.removeEventListener(t.window.document,\"mousemove\",this._onMove,{capture:!0}),r.removeEventListener(t.window.document,\"mouseup\",this._onMouseUp),r.removeEventListener(t.window,\"blur\",this._onBlur)},yn.prototype._deactivate=function(){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._lastMoveEvent,delete this._startPos,delete this._mouseDownPos,delete this._lastPos},yn.prototype._inertialPan=function(t){this._fireEvent(\"dragend\",t),this._drainInertiaBuffer();var e=this._inertia;if(e.length<2)this._fireEvent(\"moveend\",t);else{var r=e[e.length-1],n=e[0],i=r[1].sub(n[1]),a=(r[0]-n[0])/1e3;if(0===a||r[1].equals(n[1]))this._fireEvent(\"moveend\",t);else{var o=i.mult(.3/a),s=o.mag();s>1400&&(s=1400,o._unit()._mult(s));var l=s/750,c=o.mult(-l/2);this._map.panBy(c,{duration:1e3*l,easing:mn,noMoveStart:!0},{originalEvent:t})}}},yn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},yn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>0&&r-e[0][0]>160;)e.shift()};var xn=function(e){this._map=e,this._el=e.getCanvasContainer(),t.bindAll([\"_onKeyDown\"],this)};function bn(t){return t*(2-t)}xn.prototype.isEnabled=function(){return!!this._enabled},xn.prototype.enable=function(){this.isEnabled()||(this._el.addEventListener(\"keydown\",this._onKeyDown,!1),this._enabled=!0)},xn.prototype.disable=function(){this.isEnabled()&&(this._el.removeEventListener(\"keydown\",this._onKeyDown),this._enabled=!1)},xn.prototype._onKeyDown=function(t){if(!(t.altKey||t.ctrlKey||t.metaKey)){var e=0,r=0,n=0,i=0,a=0;switch(t.keyCode){case 61:case 107:case 171:case 187:e=1;break;case 189:case 109:case 173:e=-1;break;case 37:t.shiftKey?r=-1:(t.preventDefault(),i=-1);break;case 39:t.shiftKey?r=1:(t.preventDefault(),i=1);break;case 38:t.shiftKey?n=1:(t.preventDefault(),a=-1);break;case 40:t.shiftKey?n=-1:(a=1,t.preventDefault());break;default:return}var o=this._map,s=o.getZoom(),l={duration:300,delayEndEvents:500,easing:bn,zoom:e?Math.round(s)+e*(t.shiftKey?2:1):s,bearing:o.getBearing()+15*r,pitch:o.getPitch()+10*n,offset:[100*-i,100*-a],center:o.getCenter()};o.easeTo(l,{originalEvent:t})}};var _n=function(e){this._map=e,t.bindAll([\"_onDblClick\",\"_onZoomEnd\"],this)};_n.prototype.isEnabled=function(){return!!this._enabled},_n.prototype.isActive=function(){return!!this._active},_n.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},_n.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},_n.prototype.onTouchStart=function(t){var e=this;if(this.isEnabled()&&!(t.points.length>1))if(this._tapped){var r=t.points[0],n=this._tappedPoint;if(n&&n.dist(r)<=30){t.originalEvent.preventDefault();var i=function(){e._tapped&&e._zoom(t),e._map.off(\"touchcancel\",a),e._resetTapped()},a=function(){e._map.off(\"touchend\",i),e._resetTapped()};this._map.once(\"touchend\",i),this._map.once(\"touchcancel\",a)}else this._resetTapped()}else this._tappedPoint=t.points[0],this._tapped=setTimeout(function(){e._tapped=null,e._tappedPoint=null},300)},_n.prototype._resetTapped=function(){clearTimeout(this._tapped),this._tapped=null,this._tappedPoint=null},_n.prototype.onDblClick=function(t){this.isEnabled()&&(t.originalEvent.preventDefault(),this._zoom(t))},_n.prototype._zoom=function(t){this._active=!0,this._map.on(\"zoomend\",this._onZoomEnd),this._map.zoomTo(this._map.getZoom()+(t.originalEvent.shiftKey?-1:1),{around:t.lngLat},t)},_n.prototype._onZoomEnd=function(){this._active=!1,this._map.off(\"zoomend\",this._onZoomEnd)};var wn=t.bezier(0,0,.15,1),kn=function(e){this._map=e,this._el=e.getCanvasContainer(),t.bindAll([\"_onMove\",\"_onEnd\",\"_onTouchFrame\"],this)};kn.prototype.isEnabled=function(){return!!this._enabled},kn.prototype.enable=function(t){this.isEnabled()||(this._el.classList.add(\"mapboxgl-touch-zoom-rotate\"),this._enabled=!0,this._aroundCenter=!!t&&\"center\"===t.around)},kn.prototype.disable=function(){this.isEnabled()&&(this._el.classList.remove(\"mapboxgl-touch-zoom-rotate\"),this._enabled=!1)},kn.prototype.disableRotation=function(){this._rotationDisabled=!0},kn.prototype.enableRotation=function(){this._rotationDisabled=!1},kn.prototype.onStart=function(e){if(this.isEnabled()&&2===e.touches.length){var n=r.mousePos(this._el,e.touches[0]),i=r.mousePos(this._el,e.touches[1]),a=n.add(i).div(2);this._startVec=n.sub(i),this._startAround=this._map.transform.pointLocation(a),this._gestureIntent=void 0,this._inertia=[],r.addEventListener(t.window.document,\"touchmove\",this._onMove,{passive:!1}),r.addEventListener(t.window.document,\"touchend\",this._onEnd)}},kn.prototype._getTouchEventData=function(t){var e=r.mousePos(this._el,t.touches[0]),n=r.mousePos(this._el,t.touches[1]),i=e.sub(n);return{vec:i,center:e.add(n).div(2),scale:i.mag()/this._startVec.mag(),bearing:this._rotationDisabled?0:180*i.angleWith(this._startVec)/Math.PI}},kn.prototype._onMove=function(e){if(2===e.touches.length){var r=this._getTouchEventData(e),n=r.vec,i=r.scale,a=r.bearing;if(!this._gestureIntent){var o=this._rotationDisabled&&1!==i||Math.abs(1-i)>.15;Math.abs(a)>10?this._gestureIntent=\"rotate\":o&&(this._gestureIntent=\"zoom\"),this._gestureIntent&&(this._map.fire(new t.Event(this._gestureIntent+\"start\",{originalEvent:e})),this._map.fire(new t.Event(\"movestart\",{originalEvent:e})),this._startVec=n)}this._lastTouchEvent=e,this._frameId||(this._frameId=this._map._requestRenderFrame(this._onTouchFrame)),e.preventDefault()}},kn.prototype._onTouchFrame=function(){this._frameId=null;var e=this._gestureIntent;if(e){var r=this._map.transform;this._startScale||(this._startScale=r.scale,this._startBearing=r.bearing);var n=this._getTouchEventData(this._lastTouchEvent),i=n.center,a=n.bearing,o=n.scale,s=r.pointLocation(i),l=r.locationPoint(s);\"rotate\"===e&&(r.bearing=this._startBearing+a),r.zoom=r.scaleZoom(this._startScale*o),r.setLocationAtPoint(this._startAround,l),this._map.fire(new t.Event(e,{originalEvent:this._lastTouchEvent})),this._map.fire(new t.Event(\"move\",{originalEvent:this._lastTouchEvent})),this._drainInertiaBuffer(),this._inertia.push([t.browser.now(),o,i])}},kn.prototype._onEnd=function(e){r.removeEventListener(t.window.document,\"touchmove\",this._onMove,{passive:!1}),r.removeEventListener(t.window.document,\"touchend\",this._onEnd);var n=this._gestureIntent,i=this._startScale;if(this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._gestureIntent,delete this._startScale,delete this._startBearing,delete this._lastTouchEvent,n){this._map.fire(new t.Event(n+\"end\",{originalEvent:e})),this._drainInertiaBuffer();var a=this._inertia,o=this._map;if(a.length<2)o.snapToNorth({},{originalEvent:e});else{var s=a[a.length-1],l=a[0],c=o.transform.scaleZoom(i*s[1]),u=o.transform.scaleZoom(i*l[1]),h=c-u,f=(s[0]-l[0])/1e3,p=s[2];if(0!==f&&c!==u){var d=.15*h/f;Math.abs(d)>2.5&&(d=d>0?2.5:-2.5);var g=1e3*Math.abs(d/(12*.15)),v=c+d*g/2e3;v<0&&(v=0),o.easeTo({zoom:v,duration:g,easing:wn,around:this._aroundCenter?o.getCenter():o.unproject(p),noMoveStart:!0},{originalEvent:e})}else o.snapToNorth({},{originalEvent:e})}}},kn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>2&&r-e[0][0]>160;)e.shift()};var Tn={scrollZoom:pn,boxZoom:dn,dragRotate:vn,dragPan:yn,keyboard:xn,doubleClickZoom:_n,touchZoomRotate:kn},An=function(e){function r(r,n){e.call(this),this._moving=!1,this._zooming=!1,this.transform=r,this._bearingSnap=n.bearingSnap,t.bindAll([\"_renderFrameCallback\"],this)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getCenter=function(){return new t.LngLat(this.transform.center.lng,this.transform.center.lat)},r.prototype.setCenter=function(t,e){return this.jumpTo({center:t},e)},r.prototype.panBy=function(e,r,n){return e=t.Point.convert(e).mult(-1),this.panTo(this.transform.center,t.extend({offset:e},r),n)},r.prototype.panTo=function(e,r,n){return this.easeTo(t.extend({center:e},r),n)},r.prototype.getZoom=function(){return this.transform.zoom},r.prototype.setZoom=function(t,e){return this.jumpTo({zoom:t},e),this},r.prototype.zoomTo=function(e,r,n){return this.easeTo(t.extend({zoom:e},r),n)},r.prototype.zoomIn=function(t,e){return this.zoomTo(this.getZoom()+1,t,e),this},r.prototype.zoomOut=function(t,e){return this.zoomTo(this.getZoom()-1,t,e),this},r.prototype.getBearing=function(){return this.transform.bearing},r.prototype.setBearing=function(t,e){return this.jumpTo({bearing:t},e),this},r.prototype.rotateTo=function(e,r,n){return this.easeTo(t.extend({bearing:e},r),n)},r.prototype.resetNorth=function(e,r){return this.rotateTo(0,t.extend({duration:1e3},e),r),this},r.prototype.snapToNorth=function(t,e){return Math.abs(this.getBearing())<this._bearingSnap?this.resetNorth(t,e):this},r.prototype.getPitch=function(){return this.transform.pitch},r.prototype.setPitch=function(t,e){return this.jumpTo({pitch:t},e),this},r.prototype.cameraForBounds=function(e,r){return e=t.LngLatBounds.convert(e),this._cameraForBoxAndBearing(e.getNorthWest(),e.getSouthEast(),0,r)},r.prototype._cameraForBoxAndBearing=function(e,r,n,i){if(\"number\"==typeof(i=t.extend({padding:{top:0,bottom:0,right:0,left:0},offset:[0,0],maxZoom:this.transform.maxZoom},i)).padding){var a=i.padding;i.padding={top:a,bottom:a,right:a,left:a}}if(t.deepEqual(Object.keys(i.padding).sort(function(t,e){return t<e?-1:t>e?1:0}),[\"bottom\",\"left\",\"right\",\"top\"])){var o=this.transform,s=o.project(t.LngLat.convert(e)),l=o.project(t.LngLat.convert(r)),c=s.rotate(-n*Math.PI/180),u=l.rotate(-n*Math.PI/180),h=new t.Point(Math.max(c.x,u.x),Math.max(c.y,u.y)),f=new t.Point(Math.min(c.x,u.x),Math.min(c.y,u.y)),p=h.sub(f),d=(o.width-i.padding.left-i.padding.right)/p.x,g=(o.height-i.padding.top-i.padding.bottom)/p.y;if(!(g<0||d<0)){var v=Math.min(o.scaleZoom(o.scale*Math.min(d,g)),i.maxZoom),m=t.Point.convert(i.offset),y=(i.padding.left-i.padding.right)/2,x=(i.padding.top-i.padding.bottom)/2,b=new t.Point(m.x+y,m.y+x).mult(o.scale/o.zoomScale(v));return{center:o.unproject(s.add(l).div(2).sub(b)),zoom:v,bearing:n}}t.warnOnce(\"Map cannot fit within canvas with the given bounds, padding, and/or offset.\")}else t.warnOnce(\"options.padding must be a positive number, or an Object with keys 'bottom', 'left', 'right', 'top'\")},r.prototype.fitBounds=function(t,e,r){return this._fitInternal(this.cameraForBounds(t,e),e,r)},r.prototype.fitScreenCoordinates=function(e,r,n,i,a){return this._fitInternal(this._cameraForBoxAndBearing(this.transform.pointLocation(t.Point.convert(e)),this.transform.pointLocation(t.Point.convert(r)),n,i),i,a)},r.prototype._fitInternal=function(e,r,n){return e?(r=t.extend(e,r)).linear?this.easeTo(r,n):this.flyTo(r,n):this},r.prototype.jumpTo=function(e,r){this.stop();var n=this.transform,i=!1,a=!1,o=!1;return\"zoom\"in e&&n.zoom!==+e.zoom&&(i=!0,n.zoom=+e.zoom),void 0!==e.center&&(n.center=t.LngLat.convert(e.center)),\"bearing\"in e&&n.bearing!==+e.bearing&&(a=!0,n.bearing=+e.bearing),\"pitch\"in e&&n.pitch!==+e.pitch&&(o=!0,n.pitch=+e.pitch),this.fire(new t.Event(\"movestart\",r)).fire(new t.Event(\"move\",r)),i&&this.fire(new t.Event(\"zoomstart\",r)).fire(new t.Event(\"zoom\",r)).fire(new t.Event(\"zoomend\",r)),a&&this.fire(new t.Event(\"rotatestart\",r)).fire(new t.Event(\"rotate\",r)).fire(new t.Event(\"rotateend\",r)),o&&this.fire(new t.Event(\"pitchstart\",r)).fire(new t.Event(\"pitch\",r)).fire(new t.Event(\"pitchend\",r)),this.fire(new t.Event(\"moveend\",r))},r.prototype.easeTo=function(e,r){var n=this;this.stop(),!1===(e=t.extend({offset:[0,0],duration:500,easing:t.ease},e)).animate&&(e.duration=0);var i=this.transform,a=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=\"zoom\"in e?+e.zoom:a,c=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,u=\"pitch\"in e?+e.pitch:s,h=i.centerPoint.add(t.Point.convert(e.offset)),f=i.pointLocation(h),p=t.LngLat.convert(e.center||f);this._normalizeCenter(p);var d,g,v=i.project(f),m=i.project(p).sub(v),y=i.zoomScale(l-a);return e.around&&(d=t.LngLat.convert(e.around),g=i.locationPoint(d)),this._zooming=l!==a,this._rotating=o!==c,this._pitching=u!==s,this._prepareEase(r,e.noMoveStart),clearTimeout(this._easeEndTimeoutID),this._ease(function(e){if(n._zooming&&(i.zoom=t.number(a,l,e)),n._rotating&&(i.bearing=t.number(o,c,e)),n._pitching&&(i.pitch=t.number(s,u,e)),d)i.setLocationAtPoint(d,g);else{var f=i.zoomScale(i.zoom-a),p=l>a?Math.min(2,y):Math.max(.5,y),x=Math.pow(p,1-e),b=i.unproject(v.add(m.mult(e*x)).mult(f));i.setLocationAtPoint(i.renderWorldCopies?b.wrap():b,h)}n._fireMoveEvents(r)},function(){e.delayEndEvents?n._easeEndTimeoutID=setTimeout(function(){return n._afterEase(r)},e.delayEndEvents):n._afterEase(r)},e),this},r.prototype._prepareEase=function(e,r){this._moving=!0,r||this.fire(new t.Event(\"movestart\",e)),this._zooming&&this.fire(new t.Event(\"zoomstart\",e)),this._rotating&&this.fire(new t.Event(\"rotatestart\",e)),this._pitching&&this.fire(new t.Event(\"pitchstart\",e))},r.prototype._fireMoveEvents=function(e){this.fire(new t.Event(\"move\",e)),this._zooming&&this.fire(new t.Event(\"zoom\",e)),this._rotating&&this.fire(new t.Event(\"rotate\",e)),this._pitching&&this.fire(new t.Event(\"pitch\",e))},r.prototype._afterEase=function(e){var r=this._zooming,n=this._rotating,i=this._pitching;this._moving=!1,this._zooming=!1,this._rotating=!1,this._pitching=!1,r&&this.fire(new t.Event(\"zoomend\",e)),n&&this.fire(new t.Event(\"rotateend\",e)),i&&this.fire(new t.Event(\"pitchend\",e)),this.fire(new t.Event(\"moveend\",e))},r.prototype.flyTo=function(e,r){var n=this;this.stop(),e=t.extend({offset:[0,0],speed:1.2,curve:1.42,easing:t.ease},e);var i=this.transform,a=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=\"zoom\"in e?t.clamp(+e.zoom,i.minZoom,i.maxZoom):a,c=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,u=\"pitch\"in e?+e.pitch:s,h=i.zoomScale(l-a),f=i.centerPoint.add(t.Point.convert(e.offset)),p=i.pointLocation(f),d=t.LngLat.convert(e.center||p);this._normalizeCenter(d);var g=i.project(p),v=i.project(d).sub(g),m=e.curve,y=Math.max(i.width,i.height),x=y/h,b=v.mag();if(\"minZoom\"in e){var _=t.clamp(Math.min(e.minZoom,a,l),i.minZoom,i.maxZoom),w=y/i.zoomScale(_-a);m=Math.sqrt(w/b*2)}var k=m*m;function T(t){var e=(x*x-y*y+(t?-1:1)*k*k*b*b)/(2*(t?x:y)*k*b);return Math.log(Math.sqrt(e*e+1)-e)}function A(t){return(Math.exp(t)-Math.exp(-t))/2}function M(t){return(Math.exp(t)+Math.exp(-t))/2}var S=T(0),E=function(t){return M(S)/M(S+m*t)},C=function(t){return y*((M(S)*(A(e=S+m*t)/M(e))-A(S))/k)/b;var e},L=(T(1)-S)/m;if(Math.abs(b)<1e-6||!isFinite(L)){if(Math.abs(y-x)<1e-6)return this.easeTo(e,r);var P=x<y?-1:1;L=Math.abs(Math.log(x/y))/m,C=function(){return 0},E=function(t){return Math.exp(P*m*t)}}if(\"duration\"in e)e.duration=+e.duration;else{var O=\"screenSpeed\"in e?+e.screenSpeed/m:+e.speed;e.duration=1e3*L/O}return e.maxDuration&&e.duration>e.maxDuration&&(e.duration=0),this._zooming=!0,this._rotating=o!==c,this._pitching=u!==s,this._prepareEase(r,!1),this._ease(function(e){var h=e*L,p=1/E(h);i.zoom=1===e?l:a+i.scaleZoom(p),n._rotating&&(i.bearing=t.number(o,c,e)),n._pitching&&(i.pitch=t.number(s,u,e));var m=1===e?d:i.unproject(g.add(v.mult(C(h))).mult(p));i.setLocationAtPoint(i.renderWorldCopies?m.wrap():m,f),n._fireMoveEvents(r)},function(){return n._afterEase(r)},e),this},r.prototype.isEasing=function(){return!!this._easeFrameId},r.prototype.stop=function(){if(this._easeFrameId&&(this._cancelRenderFrame(this._easeFrameId),delete this._easeFrameId,delete this._onEaseFrame),this._onEaseEnd){var t=this._onEaseEnd;delete this._onEaseEnd,t.call(this)}return this},r.prototype._ease=function(e,r,n){!1===n.animate||0===n.duration?(e(1),r()):(this._easeStart=t.browser.now(),this._easeOptions=n,this._onEaseFrame=e,this._onEaseEnd=r,this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback))},r.prototype._renderFrameCallback=function(){var e=Math.min((t.browser.now()-this._easeStart)/this._easeOptions.duration,1);this._onEaseFrame(this._easeOptions.easing(e)),e<1?this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback):this.stop()},r.prototype._normalizeBearing=function(e,r){e=t.wrap(e,-180,180);var n=Math.abs(e-r);return Math.abs(e-360-r)<n&&(e-=360),Math.abs(e+360-r)<n&&(e+=360),e},r.prototype._normalizeCenter=function(t){var e=this.transform;if(e.renderWorldCopies&&!e.lngRange){var r=t.lng-e.center.lng;t.lng+=r>180?-360:r<-180?360:0}},r}(t.Evented),Mn=function(e){void 0===e&&(e={}),this.options=e,t.bindAll([\"_updateEditLink\",\"_updateData\",\"_updateCompact\"],this)};Mn.prototype.getDefaultPosition=function(){return\"bottom-right\"},Mn.prototype.onAdd=function(t){var e=this.options&&this.options.compact;return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-attrib\"),this._innerContainer=r.create(\"div\",\"mapboxgl-ctrl-attrib-inner\",this._container),e&&this._container.classList.add(\"mapboxgl-compact\"),this._updateAttributions(),this._updateEditLink(),this._map.on(\"styledata\",this._updateData),this._map.on(\"sourcedata\",this._updateData),this._map.on(\"moveend\",this._updateEditLink),void 0===e&&(this._map.on(\"resize\",this._updateCompact),this._updateCompact()),this._container},Mn.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"styledata\",this._updateData),this._map.off(\"sourcedata\",this._updateData),this._map.off(\"moveend\",this._updateEditLink),this._map.off(\"resize\",this._updateCompact),this._map=void 0},Mn.prototype._updateEditLink=function(){var e=this._editLink;e||(e=this._editLink=this._container.querySelector(\".mapbox-improve-map\"));var r=[{key:\"owner\",value:this.styleOwner},{key:\"id\",value:this.styleId},{key:\"access_token\",value:t.config.ACCESS_TOKEN}];if(e){var n=r.reduce(function(t,e,n){return e.value&&(t+=e.key+\"=\"+e.value+(n<r.length-1?\"&\":\"\")),t},\"?\");e.href=t.config.FEEDBACK_URL+\"/\"+n+(this._map._hash?this._map._hash.getHashString(!0):\"\"),e.rel=\"noopener nofollow\"}},Mn.prototype._updateData=function(t){!t||\"metadata\"!==t.sourceDataType&&\"style\"!==t.dataType||(this._updateAttributions(),this._updateEditLink())},Mn.prototype._updateAttributions=function(){if(this._map.style){var t=[];if(this.options.customAttribution&&(Array.isArray(this.options.customAttribution)?t=t.concat(this.options.customAttribution.map(function(t){return\"string\"!=typeof t?\"\":t})):\"string\"==typeof this.options.customAttribution&&t.push(this.options.customAttribution)),this._map.style.stylesheet){var e=this._map.style.stylesheet;this.styleOwner=e.owner,this.styleId=e.id}var r=this._map.style.sourceCaches;for(var n in r){var i=r[n];if(i.used){var a=i.getSource();a.attribution&&t.indexOf(a.attribution)<0&&t.push(a.attribution)}}t.sort(function(t,e){return t.length-e.length});var o=(t=t.filter(function(e,r){for(var n=r+1;n<t.length;n++)if(t[n].indexOf(e)>=0)return!1;return!0})).join(\" | \");o!==this._attribHTML&&(this._attribHTML=o,t.length?(this._innerContainer.innerHTML=o,this._container.classList.remove(\"mapboxgl-attrib-empty\")):this._container.classList.add(\"mapboxgl-attrib-empty\"),this._editLink=null)}},Mn.prototype._updateCompact=function(){this._map.getCanvasContainer().offsetWidth<=640?this._container.classList.add(\"mapboxgl-compact\"):this._container.classList.remove(\"mapboxgl-compact\")};var Sn=function(){t.bindAll([\"_updateLogo\"],this),t.bindAll([\"_updateCompact\"],this)};Sn.prototype.onAdd=function(t){this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl\");var e=r.create(\"a\",\"mapboxgl-ctrl-logo\");return e.target=\"_blank\",e.rel=\"noopener nofollow\",e.href=\"https://www.mapbox.com/\",e.setAttribute(\"aria-label\",\"Mapbox logo\"),e.setAttribute(\"rel\",\"noopener nofollow\"),this._container.appendChild(e),this._container.style.display=\"none\",this._map.on(\"sourcedata\",this._updateLogo),this._updateLogo(),this._map.on(\"resize\",this._updateCompact),this._updateCompact(),this._container},Sn.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"sourcedata\",this._updateLogo),this._map.off(\"resize\",this._updateCompact)},Sn.prototype.getDefaultPosition=function(){return\"bottom-left\"},Sn.prototype._updateLogo=function(t){t&&\"metadata\"!==t.sourceDataType||(this._container.style.display=this._logoRequired()?\"block\":\"none\")},Sn.prototype._logoRequired=function(){if(this._map.style){var t=this._map.style.sourceCaches;for(var e in t)if(t[e].getSource().mapbox_logo)return!0;return!1}},Sn.prototype._updateCompact=function(){var t=this._container.children;if(t.length){var e=t[0];this._map.getCanvasContainer().offsetWidth<250?e.classList.add(\"mapboxgl-compact\"):e.classList.remove(\"mapboxgl-compact\")}};var En=function(){this._queue=[],this._id=0,this._cleared=!1,this._currentlyRunning=!1};En.prototype.add=function(t){var e=++this._id;return this._queue.push({callback:t,id:e,cancelled:!1}),e},En.prototype.remove=function(t){for(var e=this._currentlyRunning,r=0,n=e?this._queue.concat(e):this._queue;r<n.length;r+=1){var i=n[r];if(i.id===t)return void(i.cancelled=!0)}},En.prototype.run=function(){var t=this._currentlyRunning=this._queue;this._queue=[];for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!n.cancelled&&(n.callback(),this._cleared))break}this._cleared=!1,this._currentlyRunning=!1},En.prototype.clear=function(){this._currentlyRunning&&(this._cleared=!0),this._queue=[]};var Cn=t.window.HTMLImageElement,Ln=t.window.HTMLElement,Pn={center:[0,0],zoom:0,bearing:0,pitch:0,minZoom:0,maxZoom:22,interactive:!0,scrollZoom:!0,boxZoom:!0,dragRotate:!0,dragPan:!0,keyboard:!0,doubleClickZoom:!0,touchZoomRotate:!0,bearingSnap:7,clickTolerance:3,hash:!1,attributionControl:!0,failIfMajorPerformanceCaveat:!1,preserveDrawingBuffer:!1,trackResize:!0,renderWorldCopies:!0,refreshExpiredTiles:!0,maxTileCacheSize:null,localIdeographFontFamily:\"sans-serif\",transformRequest:null,fadeDuration:300,crossSourceCollisions:!0},On=function(n){function i(e){var i=this;if(null!=(e=t.extend({},Pn,e)).minZoom&&null!=e.maxZoom&&e.minZoom>e.maxZoom)throw new Error(\"maxZoom must be greater than minZoom\");var a=new sn(e.minZoom,e.maxZoom,e.renderWorldCopies);if(n.call(this,a,e),this._interactive=e.interactive,this._maxTileCacheSize=e.maxTileCacheSize,this._failIfMajorPerformanceCaveat=e.failIfMajorPerformanceCaveat,this._preserveDrawingBuffer=e.preserveDrawingBuffer,this._antialias=e.antialias,this._trackResize=e.trackResize,this._bearingSnap=e.bearingSnap,this._refreshExpiredTiles=e.refreshExpiredTiles,this._fadeDuration=e.fadeDuration,this._crossSourceCollisions=e.crossSourceCollisions,this._crossFadingFactor=1,this._collectResourceTiming=e.collectResourceTiming,this._renderTaskQueue=new En,this._controls=[],this._mapId=t.uniqueId(),this._requestManager=new t.RequestManager(e.transformRequest),\"string\"==typeof e.container){if(this._container=t.window.document.getElementById(e.container),!this._container)throw new Error(\"Container '\"+e.container+\"' not found.\")}else{if(!(e.container instanceof Ln))throw new Error(\"Invalid type: 'container' must be a String or HTMLElement.\");this._container=e.container}if(e.maxBounds&&this.setMaxBounds(e.maxBounds),t.bindAll([\"_onWindowOnline\",\"_onWindowResize\",\"_contextLost\",\"_contextRestored\"],this),this._setupContainer(),this._setupPainter(),void 0===this.painter)throw new Error(\"Failed to initialize WebGL.\");this.on(\"move\",function(){return i._update(!1)}),this.on(\"moveend\",function(){return i._update(!1)}),this.on(\"zoom\",function(){return i._update(!0)}),void 0!==t.window&&(t.window.addEventListener(\"online\",this._onWindowOnline,!1),t.window.addEventListener(\"resize\",this._onWindowResize,!1)),function(t,e){var n=t.getCanvasContainer(),i=null,a=!1,o=null;for(var s in Tn)t[s]=new Tn[s](t,e),e.interactive&&e[s]&&t[s].enable(e[s]);r.addEventListener(n,\"mouseout\",function(e){t.fire(new un(\"mouseout\",t,e))}),r.addEventListener(n,\"mousedown\",function(i){a=!0,o=r.mousePos(n,i);var s=new un(\"mousedown\",t,i);t.fire(s),s.defaultPrevented||(e.interactive&&!t.doubleClickZoom.isActive()&&t.stop(),t.boxZoom.onMouseDown(i),t.boxZoom.isActive()||t.dragPan.isActive()||t.dragRotate.onMouseDown(i),t.boxZoom.isActive()||t.dragRotate.isActive()||t.dragPan.onMouseDown(i))}),r.addEventListener(n,\"mouseup\",function(e){var r=t.dragRotate.isActive();i&&!r&&t.fire(new un(\"contextmenu\",t,i)),i=null,a=!1,t.fire(new un(\"mouseup\",t,e))}),r.addEventListener(n,\"mousemove\",function(e){if(!t.dragPan.isActive()&&!t.dragRotate.isActive()){for(var r=e.target;r&&r!==n;)r=r.parentNode;r===n&&t.fire(new un(\"mousemove\",t,e))}}),r.addEventListener(n,\"mouseover\",function(e){for(var r=e.target;r&&r!==n;)r=r.parentNode;r===n&&t.fire(new un(\"mouseover\",t,e))}),r.addEventListener(n,\"touchstart\",function(r){var n=new hn(\"touchstart\",t,r);t.fire(n),n.defaultPrevented||(e.interactive&&t.stop(),t.boxZoom.isActive()||t.dragRotate.isActive()||t.dragPan.onTouchStart(r),t.touchZoomRotate.onStart(r),t.doubleClickZoom.onTouchStart(n))},{passive:!1}),r.addEventListener(n,\"touchmove\",function(e){t.fire(new hn(\"touchmove\",t,e))},{passive:!1}),r.addEventListener(n,\"touchend\",function(e){t.fire(new hn(\"touchend\",t,e))}),r.addEventListener(n,\"touchcancel\",function(e){t.fire(new hn(\"touchcancel\",t,e))}),r.addEventListener(n,\"click\",function(i){var a=r.mousePos(n,i);(a.equals(o)||a.dist(o)<e.clickTolerance)&&t.fire(new un(\"click\",t,i))}),r.addEventListener(n,\"dblclick\",function(e){var r=new un(\"dblclick\",t,e);t.fire(r),r.defaultPrevented||t.doubleClickZoom.onDblClick(r)}),r.addEventListener(n,\"contextmenu\",function(e){var r=t.dragRotate.isActive();a||r?a&&(i=e):t.fire(new un(\"contextmenu\",t,e)),(t.dragRotate.isEnabled()||t.listens(\"contextmenu\"))&&e.preventDefault()}),r.addEventListener(n,\"wheel\",function(r){e.interactive&&t.stop();var n=new fn(\"wheel\",t,r);t.fire(n),n.defaultPrevented||t.scrollZoom.onWheel(r)},{passive:!1})}(this,e),this._hash=e.hash&&(new cn).addTo(this),this._hash&&this._hash._onHashChange()||(this.jumpTo({center:e.center,zoom:e.zoom,bearing:e.bearing,pitch:e.pitch}),e.bounds&&(this.resize(),this.fitBounds(e.bounds,t.extend({},e.fitBoundsOptions,{duration:0})))),this.resize(),this._localIdeographFontFamily=e.localIdeographFontFamily,e.style&&this.setStyle(e.style,{localIdeographFontFamily:e.localIdeographFontFamily}),e.attributionControl&&this.addControl(new Mn({customAttribution:e.customAttribution})),this.addControl(new Sn,e.logoPosition),this.on(\"style.load\",function(){i.transform.unmodified&&i.jumpTo(i.style.stylesheet)}),this.on(\"data\",function(e){i._update(\"style\"===e.dataType),i.fire(new t.Event(e.dataType+\"data\",e))}),this.on(\"dataloading\",function(e){i.fire(new t.Event(e.dataType+\"dataloading\",e))})}n&&(i.__proto__=n),i.prototype=Object.create(n&&n.prototype),i.prototype.constructor=i;var a={showTileBoundaries:{configurable:!0},showCollisionBoxes:{configurable:!0},showOverdrawInspector:{configurable:!0},repaint:{configurable:!0},vertices:{configurable:!0}};return i.prototype._getMapId=function(){return this._mapId},i.prototype.addControl=function(e,r){if(void 0===r&&e.getDefaultPosition&&(r=e.getDefaultPosition()),void 0===r&&(r=\"top-right\"),!e||!e.onAdd)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.addControl(). Argument must be a control with onAdd and onRemove methods.\")));var n=e.onAdd(this);this._controls.push(e);var i=this._controlPositions[r];return-1!==r.indexOf(\"bottom\")?i.insertBefore(n,i.firstChild):i.appendChild(n),this},i.prototype.removeControl=function(e){if(!e||!e.onRemove)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.removeControl(). Argument must be a control with onAdd and onRemove methods.\")));var r=this._controls.indexOf(e);return r>-1&&this._controls.splice(r,1),e.onRemove(this),this},i.prototype.resize=function(e){var r=this._containerDimensions(),n=r[0],i=r[1];return this._resizeCanvas(n,i),this.transform.resize(n,i),this.painter.resize(n,i),this.fire(new t.Event(\"movestart\",e)).fire(new t.Event(\"move\",e)).fire(new t.Event(\"resize\",e)).fire(new t.Event(\"moveend\",e)),this},i.prototype.getBounds=function(){return this.transform.getBounds()},i.prototype.getMaxBounds=function(){return this.transform.getMaxBounds()},i.prototype.setMaxBounds=function(e){return this.transform.setMaxBounds(t.LngLatBounds.convert(e)),this._update()},i.prototype.setMinZoom=function(t){if((t=null==t?0:t)>=0&&t<=this.transform.maxZoom)return this.transform.minZoom=t,this._update(),this.getZoom()<t&&this.setZoom(t),this;throw new Error(\"minZoom must be between 0 and the current maxZoom, inclusive\")},i.prototype.getMinZoom=function(){return this.transform.minZoom},i.prototype.setMaxZoom=function(t){if((t=null==t?22:t)>=this.transform.minZoom)return this.transform.maxZoom=t,this._update(),this.getZoom()>t&&this.setZoom(t),this;throw new Error(\"maxZoom must be greater than the current minZoom\")},i.prototype.getRenderWorldCopies=function(){return this.transform.renderWorldCopies},i.prototype.setRenderWorldCopies=function(t){return this.transform.renderWorldCopies=t,this._update()},i.prototype.getMaxZoom=function(){return this.transform.maxZoom},i.prototype.project=function(e){return this.transform.locationPoint(t.LngLat.convert(e))},i.prototype.unproject=function(e){return this.transform.pointLocation(t.Point.convert(e))},i.prototype.isMoving=function(){return this._moving||this.dragPan.isActive()||this.dragRotate.isActive()||this.scrollZoom.isActive()},i.prototype.isZooming=function(){return this._zooming||this.scrollZoom.isZooming()},i.prototype.isRotating=function(){return this._rotating||this.dragRotate.isActive()},i.prototype.on=function(t,e,r){var i=this;if(void 0===r)return n.prototype.on.call(this,t,e);var a=function(){var n;if(\"mouseenter\"===t||\"mouseover\"===t){var a=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){var o=i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[];o.length?a||(a=!0,r.call(i,new un(t,i,n.originalEvent,{features:o}))):a=!1},mouseout:function(){a=!1}}}}if(\"mouseleave\"===t||\"mouseout\"===t){var o=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){(i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[]).length?o=!0:o&&(o=!1,r.call(i,new un(t,i,n.originalEvent)))},mouseout:function(e){o&&(o=!1,r.call(i,new un(t,i,e.originalEvent)))}}}}return{layer:e,listener:r,delegates:(n={},n[t]=function(t){var n=i.getLayer(e)?i.queryRenderedFeatures(t.point,{layers:[e]}):[];n.length&&(t.features=n,r.call(i,t),delete t.features)},n)}}();for(var o in this._delegatedListeners=this._delegatedListeners||{},this._delegatedListeners[t]=this._delegatedListeners[t]||[],this._delegatedListeners[t].push(a),a.delegates)this.on(o,a.delegates[o]);return this},i.prototype.off=function(t,e,r){if(void 0===r)return n.prototype.off.call(this,t,e);if(this._delegatedListeners&&this._delegatedListeners[t])for(var i=this._delegatedListeners[t],a=0;a<i.length;a++){var o=i[a];if(o.layer===e&&o.listener===r){for(var s in o.delegates)this.off(s,o.delegates[s]);return i.splice(a,1),this}}return this},i.prototype.queryRenderedFeatures=function(e,r){if(!this.style)return[];var n;if(void 0!==r||void 0===e||e instanceof t.Point||Array.isArray(e)||(r=e,e=void 0),r=r||{},(e=e||[[0,0],[this.transform.width,this.transform.height]])instanceof t.Point||\"number\"==typeof e[0])n=[t.Point.convert(e)];else{var i=t.Point.convert(e[0]),a=t.Point.convert(e[1]);n=[i,new t.Point(a.x,i.y),a,new t.Point(i.x,a.y),i]}return this.style.queryRenderedFeatures(n,r,this.transform)},i.prototype.querySourceFeatures=function(t,e){return this.style.querySourceFeatures(t,e)},i.prototype.setStyle=function(e,r){return!1!==(r=t.extend({},{localIdeographFontFamily:Pn.localIdeographFontFamily},r)).diff&&r.localIdeographFontFamily===this._localIdeographFontFamily&&this.style&&e?(this._diffStyle(e,r),this):(this._localIdeographFontFamily=r.localIdeographFontFamily,this._updateStyle(e,r))},i.prototype._updateStyle=function(t,e){return this.style&&(this.style.setEventedParent(null),this.style._remove()),t?(this.style=new De(this,e||{}),this.style.setEventedParent(this,{style:this.style}),\"string\"==typeof t?this.style.loadURL(t):this.style.loadJSON(t),this):(delete this.style,this)},i.prototype._diffStyle=function(e,r){var n=this;if(\"string\"==typeof e){var i=this._requestManager.normalizeStyleURL(e),a=this._requestManager.transformRequest(i,t.ResourceType.Style);t.getJSON(a,function(e,i){e?n.fire(new t.ErrorEvent(e)):i&&n._updateDiff(i,r)})}else\"object\"==typeof e&&this._updateDiff(e,r)},i.prototype._updateDiff=function(e,r){try{this.style.setState(e)&&this._update(!0)}catch(n){t.warnOnce(\"Unable to perform style diff: \"+(n.message||n.error||n)+\".  Rebuilding the style from scratch.\"),this._updateStyle(e,r)}},i.prototype.getStyle=function(){if(this.style)return this.style.serialize()},i.prototype.isStyleLoaded=function(){return this.style?this.style.loaded():t.warnOnce(\"There is no style added to the map.\")},i.prototype.addSource=function(t,e){return this.style.addSource(t,e),this._update(!0)},i.prototype.isSourceLoaded=function(e){var r=this.style&&this.style.sourceCaches[e];if(void 0!==r)return r.loaded();this.fire(new t.ErrorEvent(new Error(\"There is no source with ID '\"+e+\"'\")))},i.prototype.areTilesLoaded=function(){var t=this.style&&this.style.sourceCaches;for(var e in t){var r=t[e]._tiles;for(var n in r){var i=r[n];if(\"loaded\"!==i.state&&\"errored\"!==i.state)return!1}}return!0},i.prototype.addSourceType=function(t,e,r){return this.style.addSourceType(t,e,r)},i.prototype.removeSource=function(t){return this.style.removeSource(t),this._update(!0)},i.prototype.getSource=function(t){return this.style.getSource(t)},i.prototype.addImage=function(e,r,n){void 0===n&&(n={});var i=n.pixelRatio;void 0===i&&(i=1);var a=n.sdf;if(void 0===a&&(a=!1),r instanceof Cn){var o=t.browser.getImageData(r),s=o.width,l=o.height,c=o.data;this.style.addImage(e,{data:new t.RGBAImage({width:s,height:l},c),pixelRatio:i,sdf:a,version:0})}else{if(void 0===r.width||void 0===r.height)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.addImage(). The second argument must be an `HTMLImageElement`, `ImageData`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));var u=r.width,h=r.height,f=r.data,p=r;this.style.addImage(e,{data:new t.RGBAImage({width:u,height:h},new Uint8Array(f)),pixelRatio:i,sdf:a,version:0,userImage:p}),p.onAdd&&p.onAdd(this,e)}},i.prototype.updateImage=function(e,r){var n=this.style.getImage(e);if(!n)return this.fire(new t.ErrorEvent(new Error(\"The map has no image with that id. If you are adding a new image use `map.addImage(...)` instead.\")));var i=r instanceof Cn?t.browser.getImageData(r):r,a=i.width,o=i.height,s=i.data;if(void 0===a||void 0===o)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.updateImage(). The second argument must be an `HTMLImageElement`, `ImageData`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));if(a!==n.data.width||o!==n.data.height)return this.fire(new t.ErrorEvent(new Error(\"The width and height of the updated image must be that same as the previous version of the image\")));var l=!(r instanceof Cn);n.data.replace(s,l),this.style.updateImage(e,n)},i.prototype.hasImage=function(e){return e?!!this.style.getImage(e):(this.fire(new t.ErrorEvent(new Error(\"Missing required image id\"))),!1)},i.prototype.removeImage=function(t){this.style.removeImage(t)},i.prototype.loadImage=function(e,r){t.getImage(this._requestManager.transformRequest(e,t.ResourceType.Image),r)},i.prototype.listImages=function(){return this.style.listImages()},i.prototype.addLayer=function(t,e){return this.style.addLayer(t,e),this._update(!0)},i.prototype.moveLayer=function(t,e){return this.style.moveLayer(t,e),this._update(!0)},i.prototype.removeLayer=function(t){return this.style.removeLayer(t),this._update(!0)},i.prototype.getLayer=function(t){return this.style.getLayer(t)},i.prototype.setFilter=function(t,e,r){return void 0===r&&(r={}),this.style.setFilter(t,e,r),this._update(!0)},i.prototype.setLayerZoomRange=function(t,e,r){return this.style.setLayerZoomRange(t,e,r),this._update(!0)},i.prototype.getFilter=function(t){return this.style.getFilter(t)},i.prototype.setPaintProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setPaintProperty(t,e,r,n),this._update(!0)},i.prototype.getPaintProperty=function(t,e){return this.style.getPaintProperty(t,e)},i.prototype.setLayoutProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setLayoutProperty(t,e,r,n),this._update(!0)},i.prototype.getLayoutProperty=function(t,e){return this.style.getLayoutProperty(t,e)},i.prototype.setLight=function(t,e){return void 0===e&&(e={}),this.style.setLight(t,e),this._update(!0)},i.prototype.getLight=function(){return this.style.getLight()},i.prototype.setFeatureState=function(t,e){return this.style.setFeatureState(t,e),this._update()},i.prototype.removeFeatureState=function(t,e){return this.style.removeFeatureState(t,e),this._update()},i.prototype.getFeatureState=function(t){return this.style.getFeatureState(t)},i.prototype.getContainer=function(){return this._container},i.prototype.getCanvasContainer=function(){return this._canvasContainer},i.prototype.getCanvas=function(){return this._canvas},i.prototype._containerDimensions=function(){var t=0,e=0;return this._container&&(t=this._container.clientWidth||400,e=this._container.clientHeight||300),[t,e]},i.prototype._detectMissingCSS=function(){\"rgb(250, 128, 114)\"!==t.window.getComputedStyle(this._missingCSSCanary).getPropertyValue(\"background-color\")&&t.warnOnce(\"This page appears to be missing CSS declarations for Mapbox GL JS, which may cause the map to display incorrectly. Please ensure your page includes mapbox-gl.css, as described in https://www.mapbox.com/mapbox-gl-js/api/.\")},i.prototype._setupContainer=function(){var t=this._container;t.classList.add(\"mapboxgl-map\"),(this._missingCSSCanary=r.create(\"div\",\"mapboxgl-canary\",t)).style.visibility=\"hidden\",this._detectMissingCSS();var e=this._canvasContainer=r.create(\"div\",\"mapboxgl-canvas-container\",t);this._interactive&&e.classList.add(\"mapboxgl-interactive\"),this._canvas=r.create(\"canvas\",\"mapboxgl-canvas\",e),this._canvas.style.position=\"absolute\",this._canvas.addEventListener(\"webglcontextlost\",this._contextLost,!1),this._canvas.addEventListener(\"webglcontextrestored\",this._contextRestored,!1),this._canvas.setAttribute(\"tabindex\",\"0\"),this._canvas.setAttribute(\"aria-label\",\"Map\");var n=this._containerDimensions();this._resizeCanvas(n[0],n[1]);var i=this._controlContainer=r.create(\"div\",\"mapboxgl-control-container\",t),a=this._controlPositions={};[\"top-left\",\"top-right\",\"bottom-left\",\"bottom-right\"].forEach(function(t){a[t]=r.create(\"div\",\"mapboxgl-ctrl-\"+t,i)})},i.prototype._resizeCanvas=function(e,r){var n=t.window.devicePixelRatio||1;this._canvas.width=n*e,this._canvas.height=n*r,this._canvas.style.width=e+\"px\",this._canvas.style.height=r+\"px\"},i.prototype._setupPainter=function(){var r=t.extend({},e.webGLContextAttributes,{failIfMajorPerformanceCaveat:this._failIfMajorPerformanceCaveat,preserveDrawingBuffer:this._preserveDrawingBuffer,antialias:this._antialias||!1}),n=this._canvas.getContext(\"webgl\",r)||this._canvas.getContext(\"experimental-webgl\",r);n?(this.painter=new rn(n,this.transform),t.webpSupported.testSupport(n)):this.fire(new t.ErrorEvent(new Error(\"Failed to initialize WebGL\")))},i.prototype._contextLost=function(e){e.preventDefault(),this._frame&&(this._frame.cancel(),this._frame=null),this.fire(new t.Event(\"webglcontextlost\",{originalEvent:e}))},i.prototype._contextRestored=function(e){this._setupPainter(),this.resize(),this._update(),this.fire(new t.Event(\"webglcontextrestored\",{originalEvent:e}))},i.prototype.loaded=function(){return!this._styleDirty&&!this._sourcesDirty&&!!this.style&&this.style.loaded()},i.prototype._update=function(t){return this.style?(this._styleDirty=this._styleDirty||t,this._sourcesDirty=!0,this.triggerRepaint(),this):this},i.prototype._requestRenderFrame=function(t){return this._update(),this._renderTaskQueue.add(t)},i.prototype._cancelRenderFrame=function(t){this._renderTaskQueue.remove(t)},i.prototype._render=function(){this.painter.context.setDirty(),this.painter.setBaseState(),this._renderTaskQueue.run();var e=!1;if(this.style&&this._styleDirty){this._styleDirty=!1;var r=this.transform.zoom,n=t.browser.now();this.style.zoomHistory.update(r,n);var i=new t.EvaluationParameters(r,{now:n,fadeDuration:this._fadeDuration,zoomHistory:this.style.zoomHistory,transition:this.style.getTransition()}),a=i.crossFadingFactor();1===a&&a===this._crossFadingFactor||(e=!0,this._crossFadingFactor=a),this.style.update(i)}return this.style&&this._sourcesDirty&&(this._sourcesDirty=!1,this.style._updateSources(this.transform)),this._placementDirty=this.style&&this.style._updatePlacement(this.painter.transform,this.showCollisionBoxes,this._fadeDuration,this._crossSourceCollisions),this.painter.render(this.style,{showTileBoundaries:this.showTileBoundaries,showOverdrawInspector:this._showOverdrawInspector,rotating:this.isRotating(),zooming:this.isZooming(),moving:this.isMoving(),fadeDuration:this._fadeDuration}),this.fire(new t.Event(\"render\")),this.loaded()&&!this._loaded&&(this._loaded=!0,this.fire(new t.Event(\"load\"))),this.style&&(this.style.hasTransitions()||e)&&(this._styleDirty=!0),this.style&&!this._placementDirty&&this.style._releaseSymbolFadeTiles(),this._sourcesDirty||this._repaint||this._styleDirty||this._placementDirty?this.triggerRepaint():!this.isMoving()&&this.loaded()&&this.fire(new t.Event(\"idle\")),this},i.prototype.remove=function(){this._hash&&this._hash.remove();for(var e=0,r=this._controls;e<r.length;e+=1)r[e].onRemove(this);this._controls=[],this._frame&&(this._frame.cancel(),this._frame=null),this._renderTaskQueue.clear(),this.setStyle(null),void 0!==t.window&&(t.window.removeEventListener(\"resize\",this._onWindowResize,!1),t.window.removeEventListener(\"online\",this._onWindowOnline,!1));var n=this.painter.context.gl.getExtension(\"WEBGL_lose_context\");n&&n.loseContext(),zn(this._canvasContainer),zn(this._controlContainer),zn(this._missingCSSCanary),this._container.classList.remove(\"mapboxgl-map\"),this.fire(new t.Event(\"remove\"))},i.prototype.triggerRepaint=function(){var e=this;this.style&&!this._frame&&(this._frame=t.browser.frame(function(){e._frame=null,e._render()}))},i.prototype._onWindowOnline=function(){this._update()},i.prototype._onWindowResize=function(){this._trackResize&&this.resize()._update()},a.showTileBoundaries.get=function(){return!!this._showTileBoundaries},a.showTileBoundaries.set=function(t){this._showTileBoundaries!==t&&(this._showTileBoundaries=t,this._update())},a.showCollisionBoxes.get=function(){return!!this._showCollisionBoxes},a.showCollisionBoxes.set=function(t){this._showCollisionBoxes!==t&&(this._showCollisionBoxes=t,t?this.style._generateCollisionBoxes():this._update())},a.showOverdrawInspector.get=function(){return!!this._showOverdrawInspector},a.showOverdrawInspector.set=function(t){this._showOverdrawInspector!==t&&(this._showOverdrawInspector=t,this._update())},a.repaint.get=function(){return!!this._repaint},a.repaint.set=function(t){this._repaint!==t&&(this._repaint=t,this.triggerRepaint())},a.vertices.get=function(){return!!this._vertices},a.vertices.set=function(t){this._vertices=t,this._update()},i.prototype._setCacheLimits=function(e,r){t.setCacheLimits(e,r)},Object.defineProperties(i.prototype,a),i}(An);function zn(t){t.parentNode&&t.parentNode.removeChild(t)}var In={showCompass:!0,showZoom:!0},Dn=function(e){var n=this;this.options=t.extend({},In,e),this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),this._container.addEventListener(\"contextmenu\",function(t){return t.preventDefault()}),this.options.showZoom&&(t.bindAll([\"_updateZoomButtons\"],this),this._zoomInButton=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-zoom-in\",\"Zoom in\",function(){return n._map.zoomIn()}),this._zoomOutButton=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-zoom-out\",\"Zoom out\",function(){return n._map.zoomOut()})),this.options.showCompass&&(t.bindAll([\"_rotateCompassArrow\"],this),this._compass=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-compass\",\"Reset bearing to north\",function(){return n._map.resetNorth()}),this._compassArrow=r.create(\"span\",\"mapboxgl-ctrl-compass-arrow\",this._compass))};function Rn(e,r,n){if(e=new t.LngLat(e.lng,e.lat),r){var i=new t.LngLat(e.lng-360,e.lat),a=new t.LngLat(e.lng+360,e.lat),o=n.locationPoint(e).distSqr(r);n.locationPoint(i).distSqr(r)<o?e=i:n.locationPoint(a).distSqr(r)<o&&(e=a)}for(;Math.abs(e.lng-n.center.lng)>180;){var s=n.locationPoint(e);if(s.x>=0&&s.y>=0&&s.x<=n.width&&s.y<=n.height)break;e.lng>n.center.lng?e.lng-=360:e.lng+=360}return e}Dn.prototype._updateZoomButtons=function(){var t=this._map.getZoom();this._zoomInButton.classList.toggle(\"mapboxgl-ctrl-icon-disabled\",t===this._map.getMaxZoom()),this._zoomOutButton.classList.toggle(\"mapboxgl-ctrl-icon-disabled\",t===this._map.getMinZoom())},Dn.prototype._rotateCompassArrow=function(){var t=\"rotate(\"+this._map.transform.angle*(180/Math.PI)+\"deg)\";this._compassArrow.style.transform=t},Dn.prototype.onAdd=function(t){return this._map=t,this.options.showZoom&&(this._map.on(\"zoom\",this._updateZoomButtons),this._updateZoomButtons()),this.options.showCompass&&(this._map.on(\"rotate\",this._rotateCompassArrow),this._rotateCompassArrow(),this._handler=new vn(t,{button:\"left\",element:this._compass}),r.addEventListener(this._compass,\"mousedown\",this._handler.onMouseDown),this._handler.enable()),this._container},Dn.prototype.onRemove=function(){r.remove(this._container),this.options.showZoom&&this._map.off(\"zoom\",this._updateZoomButtons),this.options.showCompass&&(this._map.off(\"rotate\",this._rotateCompassArrow),r.removeEventListener(this._compass,\"mousedown\",this._handler.onMouseDown),this._handler.disable(),delete this._handler),delete this._map},Dn.prototype._createButton=function(t,e,n){var i=r.create(\"button\",t,this._container);return i.type=\"button\",i.title=e,i.setAttribute(\"aria-label\",e),i.addEventListener(\"click\",n),i};var Fn={center:\"translate(-50%,-50%)\",top:\"translate(-50%,0)\",\"top-left\":\"translate(0,0)\",\"top-right\":\"translate(-100%,0)\",bottom:\"translate(-50%,-100%)\",\"bottom-left\":\"translate(0,-100%)\",\"bottom-right\":\"translate(-100%,-100%)\",left:\"translate(0,-50%)\",right:\"translate(-100%,-50%)\"};function Bn(t,e,r){var n=t.classList;for(var i in Fn)n.remove(\"mapboxgl-\"+r+\"-anchor-\"+i);n.add(\"mapboxgl-\"+r+\"-anchor-\"+e)}var Nn,jn=function(e){function n(n,i){if(e.call(this),(n instanceof t.window.HTMLElement||i)&&(n=t.extend({element:n},i)),t.bindAll([\"_update\",\"_onMove\",\"_onUp\",\"_addDragHandler\",\"_onMapClick\"],this),this._anchor=n&&n.anchor||\"center\",this._color=n&&n.color||\"#3FB1CE\",this._draggable=n&&n.draggable||!1,this._state=\"inactive\",n&&n.element)this._element=n.element,this._offset=t.Point.convert(n&&n.offset||[0,0]);else{this._defaultMarker=!0,this._element=r.create(\"div\");var a=r.createNS(\"http://www.w3.org/2000/svg\",\"svg\");a.setAttributeNS(null,\"display\",\"block\"),a.setAttributeNS(null,\"height\",\"41px\"),a.setAttributeNS(null,\"width\",\"27px\"),a.setAttributeNS(null,\"viewBox\",\"0 0 27 41\");var o=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");o.setAttributeNS(null,\"stroke\",\"none\"),o.setAttributeNS(null,\"stroke-width\",\"1\"),o.setAttributeNS(null,\"fill\",\"none\"),o.setAttributeNS(null,\"fill-rule\",\"evenodd\");var s=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");s.setAttributeNS(null,\"fill-rule\",\"nonzero\");var l=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");l.setAttributeNS(null,\"transform\",\"translate(3.0, 29.0)\"),l.setAttributeNS(null,\"fill\",\"#000000\");for(var c=0,u=[{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"9.5\",ry:\"4.77275007\"},{rx:\"8.5\",ry:\"4.29549936\"},{rx:\"7.5\",ry:\"3.81822308\"},{rx:\"6.5\",ry:\"3.34094679\"},{rx:\"5.5\",ry:\"2.86367051\"},{rx:\"4.5\",ry:\"2.38636864\"}];c<u.length;c+=1){var h=u[c],f=r.createNS(\"http://www.w3.org/2000/svg\",\"ellipse\");f.setAttributeNS(null,\"opacity\",\"0.04\"),f.setAttributeNS(null,\"cx\",\"10.5\"),f.setAttributeNS(null,\"cy\",\"5.80029008\"),f.setAttributeNS(null,\"rx\",h.rx),f.setAttributeNS(null,\"ry\",h.ry),l.appendChild(f)}var p=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");p.setAttributeNS(null,\"fill\",this._color);var d=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");d.setAttributeNS(null,\"d\",\"M27,13.5 C27,19.074644 20.250001,27.000002 14.75,34.500002 C14.016665,35.500004 12.983335,35.500004 12.25,34.500002 C6.7499993,27.000002 0,19.222562 0,13.5 C0,6.0441559 6.0441559,0 13.5,0 C20.955844,0 27,6.0441559 27,13.5 Z\"),p.appendChild(d);var g=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");g.setAttributeNS(null,\"opacity\",\"0.25\"),g.setAttributeNS(null,\"fill\",\"#000000\");var v=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");v.setAttributeNS(null,\"d\",\"M13.5,0 C6.0441559,0 0,6.0441559 0,13.5 C0,19.222562 6.7499993,27 12.25,34.5 C13,35.522727 14.016664,35.500004 14.75,34.5 C20.250001,27 27,19.074644 27,13.5 C27,6.0441559 20.955844,0 13.5,0 Z M13.5,1 C20.415404,1 26,6.584596 26,13.5 C26,15.898657 24.495584,19.181431 22.220703,22.738281 C19.945823,26.295132 16.705119,30.142167 13.943359,33.908203 C13.743445,34.180814 13.612715,34.322738 13.5,34.441406 C13.387285,34.322738 13.256555,34.180814 13.056641,33.908203 C10.284481,30.127985 7.4148684,26.314159 5.015625,22.773438 C2.6163816,19.232715 1,15.953538 1,13.5 C1,6.584596 6.584596,1 13.5,1 Z\"),g.appendChild(v);var m=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");m.setAttributeNS(null,\"transform\",\"translate(6.0, 7.0)\"),m.setAttributeNS(null,\"fill\",\"#FFFFFF\");var y=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");y.setAttributeNS(null,\"transform\",\"translate(8.0, 8.0)\");var x=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");x.setAttributeNS(null,\"fill\",\"#000000\"),x.setAttributeNS(null,\"opacity\",\"0.25\"),x.setAttributeNS(null,\"cx\",\"5.5\"),x.setAttributeNS(null,\"cy\",\"5.5\"),x.setAttributeNS(null,\"r\",\"5.4999962\");var b=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");b.setAttributeNS(null,\"fill\",\"#FFFFFF\"),b.setAttributeNS(null,\"cx\",\"5.5\"),b.setAttributeNS(null,\"cy\",\"5.5\"),b.setAttributeNS(null,\"r\",\"5.4999962\"),y.appendChild(x),y.appendChild(b),s.appendChild(l),s.appendChild(p),s.appendChild(g),s.appendChild(m),s.appendChild(y),a.appendChild(s),this._element.appendChild(a),this._offset=t.Point.convert(n&&n.offset||[0,-14])}this._element.classList.add(\"mapboxgl-marker\"),this._element.addEventListener(\"dragstart\",function(t){t.preventDefault()}),Bn(this._element,this._anchor,\"marker\"),this._popup=null}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.addTo=function(t){return this.remove(),this._map=t,t.getCanvasContainer().appendChild(this._element),t.on(\"move\",this._update),t.on(\"moveend\",this._update),this.setDraggable(this._draggable),this._update(),this._map.on(\"click\",this._onMapClick),this},n.prototype.remove=function(){return this._map&&(this._map.off(\"click\",this._onMapClick),this._map.off(\"move\",this._update),this._map.off(\"moveend\",this._update),this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler),this._map.off(\"mouseup\",this._onUp),this._map.off(\"touchend\",this._onUp),delete this._map),r.remove(this._element),this._popup&&this._popup.remove(),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._popup&&this._popup.setLngLat(this._lngLat),this._update(),this},n.prototype.getElement=function(){return this._element},n.prototype.setPopup=function(t){if(this._popup&&(this._popup.remove(),this._popup=null),t){if(!(\"offset\"in t.options)){var e=Math.sqrt(Math.pow(13.5,2)/2);t.options.offset=this._defaultMarker?{top:[0,0],\"top-left\":[0,0],\"top-right\":[0,0],bottom:[0,-38.1],\"bottom-left\":[e,-1*(24.6+e)],\"bottom-right\":[-e,-1*(24.6+e)],left:[13.5,-24.6],right:[-13.5,-24.6]}:this._offset}this._popup=t,this._lngLat&&this._popup.setLngLat(this._lngLat)}return this},n.prototype._onMapClick=function(t){var e=t.originalEvent.target,r=this._element;this._popup&&(e===r||r.contains(e))&&this.togglePopup()},n.prototype.getPopup=function(){return this._popup},n.prototype.togglePopup=function(){var t=this._popup;return t?(t.isOpen()?t.remove():t.addTo(this._map),this):this},n.prototype._update=function(t){this._map&&(this._map.transform.renderWorldCopies&&(this._lngLat=Rn(this._lngLat,this._pos,this._map.transform)),this._pos=this._map.project(this._lngLat)._add(this._offset),t&&\"moveend\"!==t.type||(this._pos=this._pos.round()),r.setTransform(this._element,Fn[this._anchor]+\" translate(\"+this._pos.x+\"px, \"+this._pos.y+\"px)\"))},n.prototype.getOffset=function(){return this._offset},n.prototype.setOffset=function(e){return this._offset=t.Point.convert(e),this._update(),this},n.prototype._onMove=function(e){this._pos=e.point.sub(this._positionDelta),this._lngLat=this._map.unproject(this._pos),this.setLngLat(this._lngLat),this._element.style.pointerEvents=\"none\",\"pending\"===this._state&&(this._state=\"active\",this.fire(new t.Event(\"dragstart\"))),this.fire(new t.Event(\"drag\"))},n.prototype._onUp=function(){this._element.style.pointerEvents=\"auto\",this._positionDelta=null,this._map.off(\"mousemove\",this._onMove),this._map.off(\"touchmove\",this._onMove),\"active\"===this._state&&this.fire(new t.Event(\"dragend\")),this._state=\"inactive\"},n.prototype._addDragHandler=function(t){this._element.contains(t.originalEvent.target)&&(t.preventDefault(),this._positionDelta=t.point.sub(this._pos).add(this._offset),this._state=\"pending\",this._map.on(\"mousemove\",this._onMove),this._map.on(\"touchmove\",this._onMove),this._map.once(\"mouseup\",this._onUp),this._map.once(\"touchend\",this._onUp))},n.prototype.setDraggable=function(t){return this._draggable=!!t,this._map&&(t?(this._map.on(\"mousedown\",this._addDragHandler),this._map.on(\"touchstart\",this._addDragHandler)):(this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler))),this},n.prototype.isDraggable=function(){return this._draggable},n}(t.Evented),Un={positionOptions:{enableHighAccuracy:!1,maximumAge:0,timeout:6e3},fitBoundsOptions:{maxZoom:15},trackUserLocation:!1,showUserLocation:!0},Vn=function(e){function n(r){e.call(this),this.options=t.extend({},Un,r),t.bindAll([\"_onSuccess\",\"_onError\",\"_finish\",\"_setupUI\",\"_updateCamera\",\"_updateMarker\"],this)}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.onAdd=function(e){var n;return this._map=e,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),n=this._setupUI,void 0!==Nn?n(Nn):void 0!==t.window.navigator.permissions?t.window.navigator.permissions.query({name:\"geolocation\"}).then(function(t){Nn=\"denied\"!==t.state,n(Nn)}):(Nn=!!t.window.navigator.geolocation,n(Nn)),this._container},n.prototype.onRemove=function(){void 0!==this._geolocationWatchID&&(t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0),this.options.showUserLocation&&this._userLocationDotMarker&&this._userLocationDotMarker.remove(),r.remove(this._container),this._map=void 0},n.prototype._onSuccess=function(e){if(this.options.trackUserLocation)switch(this._lastKnownPosition=e,this._watchState){case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"BACKGROUND\":case\"BACKGROUND_ERROR\":this._watchState=\"BACKGROUND\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\")}this.options.showUserLocation&&\"OFF\"!==this._watchState&&this._updateMarker(e),this.options.trackUserLocation&&\"ACTIVE_LOCK\"!==this._watchState||this._updateCamera(e),this.options.showUserLocation&&this._dotElement.classList.remove(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"geolocate\",e)),this._finish()},n.prototype._updateCamera=function(e){var r=new t.LngLat(e.coords.longitude,e.coords.latitude),n=e.coords.accuracy,i=this._map.getBearing(),a=t.extend({bearing:i},this.options.fitBoundsOptions);this._map.fitBounds(r.toBounds(n),a,{geolocateSource:!0})},n.prototype._updateMarker=function(t){t?this._userLocationDotMarker.setLngLat([t.coords.longitude,t.coords.latitude]).addTo(this._map):this._userLocationDotMarker.remove()},n.prototype._onError=function(e){if(this.options.trackUserLocation)if(1===e.code)this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),void 0!==this._geolocationWatchID&&this._clearWatch();else switch(this._watchState){case\"WAITING_ACTIVE\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"ACTIVE_LOCK\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\");break;case\"BACKGROUND\":this._watchState=\"BACKGROUND_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\")}\"OFF\"!==this._watchState&&this.options.showUserLocation&&this._dotElement.classList.add(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"error\",e)),this._finish()},n.prototype._finish=function(){this._timeoutId&&clearTimeout(this._timeoutId),this._timeoutId=void 0},n.prototype._setupUI=function(e){var n=this;!1!==e?(this._container.addEventListener(\"contextmenu\",function(t){return t.preventDefault()}),this._geolocateButton=r.create(\"button\",\"mapboxgl-ctrl-icon mapboxgl-ctrl-geolocate\",this._container),this._geolocateButton.type=\"button\",this._geolocateButton.setAttribute(\"aria-label\",\"Geolocate\"),this.options.trackUserLocation&&(this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this._watchState=\"OFF\"),this.options.showUserLocation&&(this._dotElement=r.create(\"div\",\"mapboxgl-user-location-dot\"),this._userLocationDotMarker=new jn(this._dotElement),this.options.trackUserLocation&&(this._watchState=\"OFF\")),this._geolocateButton.addEventListener(\"click\",this.trigger.bind(this)),this._setup=!0,this.options.trackUserLocation&&this._map.on(\"movestart\",function(e){e.geolocateSource||\"ACTIVE_LOCK\"!==n._watchState||(n._watchState=\"BACKGROUND\",n._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\"),n._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),n.fire(new t.Event(\"trackuserlocationend\")))})):t.warnOnce(\"Geolocation support is not available, the GeolocateControl will not be visible.\")},n.prototype.trigger=function(){if(!this._setup)return t.warnOnce(\"Geolocate control triggered before added to a map\"),!1;if(this.options.trackUserLocation){switch(this._watchState){case\"OFF\":this._watchState=\"WAITING_ACTIVE\",this.fire(new t.Event(\"trackuserlocationstart\"));break;case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":case\"BACKGROUND_ERROR\":this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this.fire(new t.Event(\"trackuserlocationend\"));break;case\"BACKGROUND\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._lastKnownPosition&&this._updateCamera(this._lastKnownPosition),this.fire(new t.Event(\"trackuserlocationstart\"))}switch(this._watchState){case\"WAITING_ACTIVE\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_LOCK\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"BACKGROUND\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\");break;case\"BACKGROUND_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\")}\"OFF\"===this._watchState&&void 0!==this._geolocationWatchID?this._clearWatch():void 0===this._geolocationWatchID&&(this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"true\"),this._geolocationWatchID=t.window.navigator.geolocation.watchPosition(this._onSuccess,this._onError,this.options.positionOptions))}else t.window.navigator.geolocation.getCurrentPosition(this._onSuccess,this._onError,this.options.positionOptions),this._timeoutId=setTimeout(this._finish,1e4);return!0},n.prototype._clearWatch=function(){t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0,this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this.options.showUserLocation&&this._updateMarker(null)},n}(t.Evented),qn={maxWidth:100,unit:\"metric\"},Hn=function(e){this.options=t.extend({},qn,e),t.bindAll([\"_onMove\",\"setUnit\"],this)};function Gn(t,e,r){var n,i,a,o,s,l,c=r&&r.maxWidth||100,u=t._container.clientHeight/2,h=(n=t.unproject([0,u]),i=t.unproject([c,u]),a=Math.PI/180,o=n.lat*a,s=i.lat*a,l=Math.sin(o)*Math.sin(s)+Math.cos(o)*Math.cos(s)*Math.cos((i.lng-n.lng)*a),6371e3*Math.acos(Math.min(l,1)));if(r&&\"imperial\"===r.unit){var f=3.2808*h;f>5280?Yn(e,c,f/5280,\"mi\"):Yn(e,c,f,\"ft\")}else r&&\"nautical\"===r.unit?Yn(e,c,h/1852,\"nm\"):Yn(e,c,h,\"m\")}function Yn(t,e,r,n){var i,a,o,s=(i=r,(a=Math.pow(10,(\"\"+Math.floor(i)).length-1))*(o=(o=i/a)>=10?10:o>=5?5:o>=3?3:o>=2?2:o>=1?1:function(t){var e=Math.pow(10,Math.ceil(-Math.log(t)/Math.LN10));return Math.round(t*e)/e}(o))),l=s/r;\"m\"===n&&s>=1e3&&(s/=1e3,n=\"km\"),t.style.width=e*l+\"px\",t.innerHTML=s+n}Hn.prototype.getDefaultPosition=function(){return\"bottom-left\"},Hn.prototype._onMove=function(){Gn(this._map,this._container,this.options)},Hn.prototype.onAdd=function(t){return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-scale\",t.getContainer()),this._map.on(\"move\",this._onMove),this._onMove(),this._container},Hn.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"move\",this._onMove),this._map=void 0},Hn.prototype.setUnit=function(t){this.options.unit=t,Gn(this._map,this._container,this.options)};var Wn=function(e){this._fullscreen=!1,e&&e.container&&(e.container instanceof t.window.HTMLElement?this._container=e.container:t.warnOnce(\"Full screen control 'container' must be a DOM element.\")),t.bindAll([\"_onClickFullscreen\",\"_changeIcon\"],this),\"onfullscreenchange\"in t.window.document?this._fullscreenchange=\"fullscreenchange\":\"onmozfullscreenchange\"in t.window.document?this._fullscreenchange=\"mozfullscreenchange\":\"onwebkitfullscreenchange\"in t.window.document?this._fullscreenchange=\"webkitfullscreenchange\":\"onmsfullscreenchange\"in t.window.document&&(this._fullscreenchange=\"MSFullscreenChange\"),this._className=\"mapboxgl-ctrl\"};Wn.prototype.onAdd=function(e){return this._map=e,this._container||(this._container=this._map.getContainer()),this._controlContainer=r.create(\"div\",this._className+\" mapboxgl-ctrl-group\"),this._checkFullscreenSupport()?this._setupUI():(this._controlContainer.style.display=\"none\",t.warnOnce(\"This device does not support fullscreen mode.\")),this._controlContainer},Wn.prototype.onRemove=function(){r.remove(this._controlContainer),this._map=null,t.window.document.removeEventListener(this._fullscreenchange,this._changeIcon)},Wn.prototype._checkFullscreenSupport=function(){return!!(t.window.document.fullscreenEnabled||t.window.document.mozFullScreenEnabled||t.window.document.msFullscreenEnabled||t.window.document.webkitFullscreenEnabled)},Wn.prototype._setupUI=function(){(this._fullscreenButton=r.create(\"button\",this._className+\"-icon \"+this._className+\"-fullscreen\",this._controlContainer)).type=\"button\",this._updateTitle(),this._fullscreenButton.addEventListener(\"click\",this._onClickFullscreen),t.window.document.addEventListener(this._fullscreenchange,this._changeIcon)},Wn.prototype._updateTitle=function(){var t=this._isFullscreen()?\"Exit fullscreen\":\"Enter fullscreen\";this._fullscreenButton.setAttribute(\"aria-label\",t),this._fullscreenButton.title=t},Wn.prototype._isFullscreen=function(){return this._fullscreen},Wn.prototype._changeIcon=function(){(t.window.document.fullscreenElement||t.window.document.mozFullScreenElement||t.window.document.webkitFullscreenElement||t.window.document.msFullscreenElement)===this._container!==this._fullscreen&&(this._fullscreen=!this._fullscreen,this._fullscreenButton.classList.toggle(this._className+\"-shrink\"),this._fullscreenButton.classList.toggle(this._className+\"-fullscreen\"),this._updateTitle())},Wn.prototype._onClickFullscreen=function(){this._isFullscreen()?t.window.document.exitFullscreen?t.window.document.exitFullscreen():t.window.document.mozCancelFullScreen?t.window.document.mozCancelFullScreen():t.window.document.msExitFullscreen?t.window.document.msExitFullscreen():t.window.document.webkitCancelFullScreen&&t.window.document.webkitCancelFullScreen():this._container.requestFullscreen?this._container.requestFullscreen():this._container.mozRequestFullScreen?this._container.mozRequestFullScreen():this._container.msRequestFullscreen?this._container.msRequestFullscreen():this._container.webkitRequestFullscreen&&this._container.webkitRequestFullscreen()};var Xn={closeButton:!0,closeOnClick:!0,className:\"\",maxWidth:\"240px\"},Zn=function(e){function n(r){e.call(this),this.options=t.extend(Object.create(Xn),r),t.bindAll([\"_update\",\"_onClickClose\",\"remove\"],this)}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.addTo=function(e){var r=this;return this._map=e,this.options.closeOnClick&&this._map.on(\"click\",this._onClickClose),this._map.on(\"remove\",this.remove),this._update(),this._trackPointer?(this._map.on(\"mousemove\",function(t){r._update(t.point)}),this._map.on(\"mouseup\",function(t){r._update(t.point)}),this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")):this._map.on(\"move\",this._update),this.fire(new t.Event(\"open\")),this},n.prototype.isOpen=function(){return!!this._map},n.prototype.remove=function(){return this._content&&r.remove(this._content),this._container&&(r.remove(this._container),delete this._container),this._map&&(this._map.off(\"move\",this._update),this._map.off(\"click\",this._onClickClose),this._map.off(\"remove\",this.remove),this._map.off(\"mousemove\"),delete this._map),this.fire(new t.Event(\"close\")),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._map&&(this._map.on(\"move\",this._update),this._map.off(\"mousemove\"),this._container.classList.remove(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.remove(\"mapboxgl-track-pointer\")),this._trackPointer=!1,this._update(),this},n.prototype.trackPointer=function(){var t=this;return this._trackPointer=!0,this._pos=null,this._map&&(this._map.off(\"move\",this._update),this._map.on(\"mousemove\",function(e){t._update(e.point)}),this._map.on(\"drag\",function(e){t._update(e.point)}),this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")),this},n.prototype.getElement=function(){return this._container},n.prototype.setText=function(e){return this.setDOMContent(t.window.document.createTextNode(e))},n.prototype.setHTML=function(e){var r,n=t.window.document.createDocumentFragment(),i=t.window.document.createElement(\"body\");for(i.innerHTML=e;r=i.firstChild;)n.appendChild(r);return this.setDOMContent(n)},n.prototype.getMaxWidth=function(){return this._container.style.maxWidth},n.prototype.setMaxWidth=function(t){return this.options.maxWidth=t,this._update(),this},n.prototype.setDOMContent=function(t){return this._createContent(),this._content.appendChild(t),this._update(),this},n.prototype._createContent=function(){this._content&&r.remove(this._content),this._content=r.create(\"div\",\"mapboxgl-popup-content\",this._container),this.options.closeButton&&(this._closeButton=r.create(\"button\",\"mapboxgl-popup-close-button\",this._content),this._closeButton.type=\"button\",this._closeButton.setAttribute(\"aria-label\",\"Close popup\"),this._closeButton.innerHTML=\"&#215;\",this._closeButton.addEventListener(\"click\",this._onClickClose))},n.prototype._update=function(e){var n=this,i=this._lngLat||this._trackPointer;if(this._map&&i&&this._content&&(this._container||(this._container=r.create(\"div\",\"mapboxgl-popup\",this._map.getContainer()),this._tip=r.create(\"div\",\"mapboxgl-popup-tip\",this._container),this._container.appendChild(this._content),this.options.className&&this.options.className.split(\" \").forEach(function(t){return n._container.classList.add(t)})),this.options.maxWidth&&this._container.style.maxWidth!==this.options.maxWidth&&(this._container.style.maxWidth=this.options.maxWidth),this._map.transform.renderWorldCopies&&!this._trackPointer&&(this._lngLat=Rn(this._lngLat,this._pos,this._map.transform)),!this._trackPointer||e)){var a=this._pos=this._trackPointer&&e?e:this._map.project(this._lngLat),o=this.options.anchor,s=function e(r){if(r){if(\"number\"==typeof r){var n=Math.round(Math.sqrt(.5*Math.pow(r,2)));return{center:new t.Point(0,0),top:new t.Point(0,r),\"top-left\":new t.Point(n,n),\"top-right\":new t.Point(-n,n),bottom:new t.Point(0,-r),\"bottom-left\":new t.Point(n,-n),\"bottom-right\":new t.Point(-n,-n),left:new t.Point(r,0),right:new t.Point(-r,0)}}if(r instanceof t.Point||Array.isArray(r)){var i=t.Point.convert(r);return{center:i,top:i,\"top-left\":i,\"top-right\":i,bottom:i,\"bottom-left\":i,\"bottom-right\":i,left:i,right:i}}return{center:t.Point.convert(r.center||[0,0]),top:t.Point.convert(r.top||[0,0]),\"top-left\":t.Point.convert(r[\"top-left\"]||[0,0]),\"top-right\":t.Point.convert(r[\"top-right\"]||[0,0]),bottom:t.Point.convert(r.bottom||[0,0]),\"bottom-left\":t.Point.convert(r[\"bottom-left\"]||[0,0]),\"bottom-right\":t.Point.convert(r[\"bottom-right\"]||[0,0]),left:t.Point.convert(r.left||[0,0]),right:t.Point.convert(r.right||[0,0])}}return e(new t.Point(0,0))}(this.options.offset);if(!o){var l,c=this._container.offsetWidth,u=this._container.offsetHeight;l=a.y+s.bottom.y<u?[\"top\"]:a.y>this._map.transform.height-u?[\"bottom\"]:[],a.x<c/2?l.push(\"left\"):a.x>this._map.transform.width-c/2&&l.push(\"right\"),o=0===l.length?\"bottom\":l.join(\"-\")}var h=a.add(s[o]).round();r.setTransform(this._container,Fn[o]+\" translate(\"+h.x+\"px,\"+h.y+\"px)\"),Bn(this._container,o,\"popup\")}},n.prototype._onClickClose=function(){this.remove()},n}(t.Evented),Jn={version:t.version,supported:e,setRTLTextPlugin:t.setRTLTextPlugin,Map:On,NavigationControl:Dn,GeolocateControl:Vn,AttributionControl:Mn,ScaleControl:Hn,FullscreenControl:Wn,Popup:Zn,Marker:jn,Style:De,LngLat:t.LngLat,LngLatBounds:t.LngLatBounds,Point:t.Point,MercatorCoordinate:t.MercatorCoordinate,Evented:t.Evented,config:t.config,get accessToken(){return t.config.ACCESS_TOKEN},set accessToken(e){t.config.ACCESS_TOKEN=e},get baseApiUrl(){return t.config.API_URL},set baseApiUrl(e){t.config.API_URL=e},get workerCount(){return zt.workerCount},set workerCount(t){zt.workerCount=t},get maxParallelImageRequests(){return t.config.MAX_PARALLEL_IMAGE_REQUESTS},set maxParallelImageRequests(e){t.config.MAX_PARALLEL_IMAGE_REQUESTS=e},clearStorage:function(e){t.clearTileCache(e)},workerUrl:\"\"};return Jn}),r},\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=i():(n=n||self).mapboxgl=i()},{}],427:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1<<t+1,r=new Array(e),n=0;n<e;++n)r[n]=a(t,n);return r};var n=t(\"convex-hull\");function i(t,e,r){for(var n=new Array(t),i=0;i<t;++i)n[i]=0,i===e&&(n[i]+=.5),i===r&&(n[i]+=.5);return n}function a(t,e){if(0===e||e===(1<<t+1)-1)return[];for(var r=[],a=[],o=0;o<=t;++o)if(e&1<<o){r.push(i(t,o-1,o-1)),a.push(null);for(var s=0;s<=t;++s)~e&1<<s&&(r.push(i(t,o-1,s-1)),a.push([o,s]))}var l=n(r),c=[];t:for(o=0;o<l.length;++o){var u=l[o],h=[];for(s=0;s<u.length;++s){if(!a[u[s]])continue t;h.push(a[u[s]].slice())}c.push(h)}return c}},{\"convex-hull\":130}],428:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"gl-mat4/create\"),a=t(\"gl-mat4/clone\"),o=t(\"gl-mat4/determinant\"),s=t(\"gl-mat4/invert\"),l=t(\"gl-mat4/transpose\"),c={length:t(\"gl-vec3/length\"),normalize:t(\"gl-vec3/normalize\"),dot:t(\"gl-vec3/dot\"),cross:t(\"gl-vec3/cross\")},u=i(),h=i(),f=[0,0,0,0],p=[[0,0,0],[0,0,0],[0,0,0]],d=[0,0,0];function g(t,e,r,n,i){t[0]=e[0]*n+r[0]*i,t[1]=e[1]*n+r[1]*i,t[2]=e[2]*n+r[2]*i}e.exports=function(t,e,r,i,v,m){if(e||(e=[0,0,0]),r||(r=[0,0,0]),i||(i=[0,0,0]),v||(v=[0,0,0,1]),m||(m=[0,0,0,1]),!n(u,t))return!1;if(a(h,u),h[3]=0,h[7]=0,h[11]=0,h[15]=1,Math.abs(o(h)<1e-8))return!1;var y,x,b,_,w,k,T,A=u[3],M=u[7],S=u[11],E=u[12],C=u[13],L=u[14],P=u[15];if(0!==A||0!==M||0!==S){if(f[0]=A,f[1]=M,f[2]=S,f[3]=P,!s(h,h))return!1;l(h,h),y=v,b=h,_=(x=f)[0],w=x[1],k=x[2],T=x[3],y[0]=b[0]*_+b[4]*w+b[8]*k+b[12]*T,y[1]=b[1]*_+b[5]*w+b[9]*k+b[13]*T,y[2]=b[2]*_+b[6]*w+b[10]*k+b[14]*T,y[3]=b[3]*_+b[7]*w+b[11]*k+b[15]*T}else v[0]=v[1]=v[2]=0,v[3]=1;if(e[0]=E,e[1]=C,e[2]=L,function(t,e){t[0][0]=e[0],t[0][1]=e[1],t[0][2]=e[2],t[1][0]=e[4],t[1][1]=e[5],t[1][2]=e[6],t[2][0]=e[8],t[2][1]=e[9],t[2][2]=e[10]}(p,u),r[0]=c.length(p[0]),c.normalize(p[0],p[0]),i[0]=c.dot(p[0],p[1]),g(p[1],p[1],p[0],1,-i[0]),r[1]=c.length(p[1]),c.normalize(p[1],p[1]),i[0]/=r[1],i[1]=c.dot(p[0],p[2]),g(p[2],p[2],p[0],1,-i[1]),i[2]=c.dot(p[1],p[2]),g(p[2],p[2],p[1],1,-i[2]),r[2]=c.length(p[2]),c.normalize(p[2],p[2]),i[1]/=r[2],i[2]/=r[2],c.cross(d,p[1],p[2]),c.dot(p[0],d)<0)for(var O=0;O<3;O++)r[O]*=-1,p[O][0]*=-1,p[O][1]*=-1,p[O][2]*=-1;return m[0]=.5*Math.sqrt(Math.max(1+p[0][0]-p[1][1]-p[2][2],0)),m[1]=.5*Math.sqrt(Math.max(1-p[0][0]+p[1][1]-p[2][2],0)),m[2]=.5*Math.sqrt(Math.max(1-p[0][0]-p[1][1]+p[2][2],0)),m[3]=.5*Math.sqrt(Math.max(1+p[0][0]+p[1][1]+p[2][2],0)),p[2][1]>p[1][2]&&(m[0]=-m[0]),p[0][2]>p[2][0]&&(m[1]=-m[1]),p[1][0]>p[0][1]&&(m[2]=-m[2]),!0}},{\"./normalize\":429,\"gl-mat4/clone\":259,\"gl-mat4/create\":260,\"gl-mat4/determinant\":261,\"gl-mat4/invert\":265,\"gl-mat4/transpose\":276,\"gl-vec3/cross\":334,\"gl-vec3/dot\":339,\"gl-vec3/length\":349,\"gl-vec3/normalize\":356}],429:[function(t,e,r){e.exports=function(t,e){var r=e[15];if(0===r)return!1;for(var n=1/r,i=0;i<16;i++)t[i]=e[i]*n;return!0}},{}],430:[function(t,e,r){var n=t(\"gl-vec3/lerp\"),i=t(\"mat4-recompose\"),a=t(\"mat4-decompose\"),o=t(\"gl-mat4/determinant\"),s=t(\"quat-slerp\"),l=h(),c=h(),u=h();function h(){return{translate:f(),scale:f(1),skew:f(),perspective:[0,0,0,1],quaternion:[0,0,0,1]}}function f(t){return[t||0,t||0,t||0]}e.exports=function(t,e,r,h){if(0===o(e)||0===o(r))return!1;var f=a(e,l.translate,l.scale,l.skew,l.perspective,l.quaternion),p=a(r,c.translate,c.scale,c.skew,c.perspective,c.quaternion);return!(!f||!p||(n(u.translate,l.translate,c.translate,h),n(u.skew,l.skew,c.skew,h),n(u.scale,l.scale,c.scale,h),n(u.perspective,l.perspective,c.perspective,h),s(u.quaternion,l.quaternion,c.quaternion,h),i(t,u.translate,u.scale,u.skew,u.perspective,u.quaternion),0))}},{\"gl-mat4/determinant\":261,\"gl-vec3/lerp\":350,\"mat4-decompose\":428,\"mat4-recompose\":431,\"quat-slerp\":483}],431:[function(t,e,r){var n={identity:t(\"gl-mat4/identity\"),translate:t(\"gl-mat4/translate\"),multiply:t(\"gl-mat4/multiply\"),create:t(\"gl-mat4/create\"),scale:t(\"gl-mat4/scale\"),fromRotationTranslation:t(\"gl-mat4/fromRotationTranslation\")},i=(n.create(),n.create());e.exports=function(t,e,r,a,o,s){return n.identity(t),n.fromRotationTranslation(t,s,e),t[3]=o[0],t[7]=o[1],t[11]=o[2],t[15]=o[3],n.identity(i),0!==a[2]&&(i[9]=a[2],n.multiply(t,t,i)),0!==a[1]&&(i[9]=0,i[8]=a[1],n.multiply(t,t,i)),0!==a[0]&&(i[8]=0,i[4]=a[0],n.multiply(t,t,i)),n.scale(t,t,r),t}},{\"gl-mat4/create\":260,\"gl-mat4/fromRotationTranslation\":263,\"gl-mat4/identity\":264,\"gl-mat4/multiply\":267,\"gl-mat4/scale\":274,\"gl-mat4/translate\":275}],432:[function(t,e,r){\"use strict\";e.exports=Math.log2||function(t){return Math.log(t)*Math.LOG2E}},{}],433:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"mat4-interpolate\"),a=t(\"gl-mat4/invert\"),o=t(\"gl-mat4/rotateX\"),s=t(\"gl-mat4/rotateY\"),l=t(\"gl-mat4/rotateZ\"),c=t(\"gl-mat4/lookAt\"),u=t(\"gl-mat4/translate\"),h=(t(\"gl-mat4/scale\"),t(\"gl-vec3/normalize\")),f=[0,0,0];function p(t){this._components=t.slice(),this._time=[0],this.prevMatrix=t.slice(),this.nextMatrix=t.slice(),this.computedMatrix=t.slice(),this.computedInverse=t.slice(),this.computedEye=[0,0,0],this.computedUp=[0,0,0],this.computedCenter=[0,0,0],this.computedRadius=[0],this._limits=[-1/0,1/0]}e.exports=function(t){return new p((t=t||{}).matrix||[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1])};var d=p.prototype;d.recalcMatrix=function(t){var e=this._time,r=n.le(e,t),o=this.computedMatrix;if(!(r<0)){var s=this._components;if(r===e.length-1)for(var l=16*r,c=0;c<16;++c)o[c]=s[l++];else{var u=e[r+1]-e[r],f=(l=16*r,this.prevMatrix),p=!0;for(c=0;c<16;++c)f[c]=s[l++];var d=this.nextMatrix;for(c=0;c<16;++c)d[c]=s[l++],p=p&&f[c]===d[c];if(u<1e-6||p)for(c=0;c<16;++c)o[c]=f[c];else i(o,f,d,(t-e[r])/u)}var g=this.computedUp;g[0]=o[1],g[1]=o[5],g[2]=o[9],h(g,g);var v=this.computedInverse;a(v,o);var m=this.computedEye,y=v[15];m[0]=v[12]/y,m[1]=v[13]/y,m[2]=v[14]/y;var x=this.computedCenter,b=Math.exp(this.computedRadius[0]);for(c=0;c<3;++c)x[c]=m[c]-o[2+4*c]*b}},d.idle=function(t){if(!(t<this.lastT())){for(var e=this._components,r=e.length-16,n=0;n<16;++n)e.push(e[r++]);this._time.push(t)}},d.flush=function(t){var e=n.gt(this._time,t)-2;e<0||(this._time.splice(0,e),this._components.splice(0,16*e))},d.lastT=function(){return this._time[this._time.length-1]},d.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||f,n=n||this.computedUp,this.setMatrix(t,c(this.computedMatrix,e,r,n));for(var i=0,a=0;a<3;++a)i+=Math.pow(r[a]-e[a],2);i=Math.log(Math.sqrt(i)),this.computedRadius[0]=i},d.rotate=function(t,e,r,n){this.recalcMatrix(t);var i=this.computedInverse;e&&s(i,i,e),r&&o(i,i,r),n&&l(i,i,n),this.setMatrix(t,a(this.computedMatrix,i))};var g=[0,0,0];d.pan=function(t,e,r,n){g[0]=-(e||0),g[1]=-(r||0),g[2]=-(n||0),this.recalcMatrix(t);var i=this.computedInverse;u(i,i,g),this.setMatrix(t,a(i,i))},d.translate=function(t,e,r,n){g[0]=e||0,g[1]=r||0,g[2]=n||0,this.recalcMatrix(t);var i=this.computedMatrix;u(i,i,g),this.setMatrix(t,i)},d.setMatrix=function(t,e){if(!(t<this.lastT())){this._time.push(t);for(var r=0;r<16;++r)this._components.push(e[r])}},d.setDistance=function(t,e){this.computedRadius[0]=e},d.setDistanceLimits=function(t,e){var r=this._limits;r[0]=t,r[1]=e},d.getDistanceLimits=function(t){var e=this._limits;return t?(t[0]=e[0],t[1]=e[1],t):e}},{\"binary-search-bounds\":91,\"gl-mat4/invert\":265,\"gl-mat4/lookAt\":266,\"gl-mat4/rotateX\":271,\"gl-mat4/rotateY\":272,\"gl-mat4/rotateZ\":273,\"gl-mat4/scale\":274,\"gl-mat4/translate\":275,\"gl-vec3/normalize\":356,\"mat4-interpolate\":430}],434:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<3){for(var r=new Array(e),i=0;i<e;++i)r[i]=i;return 2===e&&t[0][0]===t[1][0]&&t[0][1]===t[1][1]?[0]:r}for(var a=new Array(e),i=0;i<e;++i)a[i]=i;a.sort(function(e,r){var n=t[e][0]-t[r][0];return n||t[e][1]-t[r][1]});for(var o=[a[0],a[1]],s=[a[0],a[1]],i=2;i<e;++i){for(var l=a[i],c=t[l],u=o.length;u>1&&n(t[o[u-2]],t[o[u-1]],c)<=0;)u-=1,o.pop();for(o.push(l),u=s.length;u>1&&n(t[s[u-2]],t[s[u-1]],c)>=0;)u-=1,s.pop();s.push(l)}for(var r=new Array(s.length+o.length-2),h=0,i=0,f=o.length;i<f;++i)r[h++]=o[i];for(var p=s.length-2;p>0;--p)r[h++]=s[p];return r};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":510}],435:[function(t,e,r){\"use strict\";e.exports=function(t,e){e||(e=t,t=window);var r=0,i=0,a=0,o={shift:!1,alt:!1,control:!1,meta:!1},s=!1;function l(t){var e=!1;return\"altKey\"in t&&(e=e||t.altKey!==o.alt,o.alt=!!t.altKey),\"shiftKey\"in t&&(e=e||t.shiftKey!==o.shift,o.shift=!!t.shiftKey),\"ctrlKey\"in t&&(e=e||t.ctrlKey!==o.control,o.control=!!t.ctrlKey),\"metaKey\"in t&&(e=e||t.metaKey!==o.meta,o.meta=!!t.metaKey),e}function c(t,s){var c=n.x(s),u=n.y(s);\"buttons\"in s&&(t=0|s.buttons),(t!==r||c!==i||u!==a||l(s))&&(r=0|t,i=c||0,a=u||0,e&&e(r,i,a,o))}function u(t){c(0,t)}function h(){(r||i||a||o.shift||o.alt||o.meta||o.control)&&(i=a=0,r=0,o.shift=o.alt=o.control=o.meta=!1,e&&e(0,0,0,o))}function f(t){l(t)&&e&&e(r,i,a,o)}function p(t){0===n.buttons(t)?c(0,t):c(r,t)}function d(t){c(r|n.buttons(t),t)}function g(t){c(r&~n.buttons(t),t)}function v(){s||(s=!0,t.addEventListener(\"mousemove\",p),t.addEventListener(\"mousedown\",d),t.addEventListener(\"mouseup\",g),t.addEventListener(\"mouseleave\",u),t.addEventListener(\"mouseenter\",u),t.addEventListener(\"mouseout\",u),t.addEventListener(\"mouseover\",u),t.addEventListener(\"blur\",h),t.addEventListener(\"keyup\",f),t.addEventListener(\"keydown\",f),t.addEventListener(\"keypress\",f),t!==window&&(window.addEventListener(\"blur\",h),window.addEventListener(\"keyup\",f),window.addEventListener(\"keydown\",f),window.addEventListener(\"keypress\",f)))}v();var m={element:t};return Object.defineProperties(m,{enabled:{get:function(){return s},set:function(e){e?v():s&&(s=!1,t.removeEventListener(\"mousemove\",p),t.removeEventListener(\"mousedown\",d),t.removeEventListener(\"mouseup\",g),t.removeEventListener(\"mouseleave\",u),t.removeEventListener(\"mouseenter\",u),t.removeEventListener(\"mouseout\",u),t.removeEventListener(\"mouseover\",u),t.removeEventListener(\"blur\",h),t.removeEventListener(\"keyup\",f),t.removeEventListener(\"keydown\",f),t.removeEventListener(\"keypress\",f),t!==window&&(window.removeEventListener(\"blur\",h),window.removeEventListener(\"keyup\",f),window.removeEventListener(\"keydown\",f),window.removeEventListener(\"keypress\",f)))},enumerable:!0},buttons:{get:function(){return r},enumerable:!0},x:{get:function(){return i},enumerable:!0},y:{get:function(){return a},enumerable:!0},mods:{get:function(){return o},enumerable:!0}}),m};var n=t(\"mouse-event\")},{\"mouse-event\":437}],436:[function(t,e,r){var n={left:0,top:0};e.exports=function(t,e,r){e=e||t.currentTarget||t.srcElement,Array.isArray(r)||(r=[0,0]);var i=t.clientX||0,a=t.clientY||0,o=(s=e,s===window||s===document||s===document.body?n:s.getBoundingClientRect());var s;return r[0]=i-o.left,r[1]=a-o.top,r}},{}],437:[function(t,e,r){\"use strict\";function n(t){return t.target||t.srcElement||window}r.buttons=function(t){if(\"object\"==typeof t){if(\"buttons\"in t)return t.buttons;if(\"which\"in t){if(2===(e=t.which))return 4;if(3===e)return 2;if(e>0)return 1<<e-1}else if(\"button\"in t){var e;if(1===(e=t.button))return 4;if(2===e)return 2;if(e>=0)return 1<<e}}return 0},r.element=n,r.x=function(t){if(\"object\"==typeof t){if(\"offsetX\"in t)return t.offsetX;var e=n(t).getBoundingClientRect();return t.clientX-e.left}return 0},r.y=function(t){if(\"object\"==typeof t){if(\"offsetY\"in t)return t.offsetY;var e=n(t).getBoundingClientRect();return t.clientY-e.top}return 0}},{}],438:[function(t,e,r){\"use strict\";var n=t(\"to-px\");e.exports=function(t,e,r){\"function\"==typeof t&&(r=!!e,e=t,t=window);var i=n(\"ex\",t),a=function(t){r&&t.preventDefault();var n=t.deltaX||0,a=t.deltaY||0,o=t.deltaZ||0,s=t.deltaMode,l=1;switch(s){case 1:l=i;break;case 2:l=window.innerHeight}if(a*=l,o*=l,(n*=l)||a||o)return e(n,a,o,t)};return t.addEventListener(\"wheel\",a),a}},{\"to-px\":539}],439:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\");function i(t){return\"a\"+t}function a(t){return\"d\"+t}function o(t,e){return\"c\"+t+\"_\"+e}function s(t){return\"s\"+t}function l(t,e){return\"t\"+t+\"_\"+e}function c(t){return\"o\"+t}function u(t){return\"x\"+t}function h(t){return\"p\"+t}function f(t,e){return\"d\"+t+\"_\"+e}function p(t){return\"i\"+t}function d(t,e){return\"u\"+t+\"_\"+e}function g(t){return\"b\"+t}function v(t){return\"y\"+t}function m(t){return\"e\"+t}function y(t){return\"v\"+t}e.exports=function(t){function e(t){throw new Error(\"ndarray-extract-contour: \"+t)}\"object\"!=typeof t&&e(\"Must specify arguments\");var r=t.order;Array.isArray(r)||e(\"Must specify order\");var M=t.arrayArguments||1;M<1&&e(\"Must have at least one array argument\");var S=t.scalarArguments||0;S<0&&e(\"Scalar arg count must be > 0\");\"function\"!=typeof t.vertex&&e(\"Must specify vertex creation function\");\"function\"!=typeof t.cell&&e(\"Must specify cell creation function\");\"function\"!=typeof t.phase&&e(\"Must specify phase function\");for(var E=t.getters||[],C=new Array(M),L=0;L<M;++L)E.indexOf(L)>=0?C[L]=!0:C[L]=!1;return function(t,e,r,M,S,E){var C=E.length,L=S.length;if(L<2)throw new Error(\"ndarray-extract-contour: Dimension must be at least 2\");for(var P=\"extractContour\"+S.join(\"_\"),O=[],z=[],I=[],D=0;D<C;++D)I.push(i(D));for(var D=0;D<M;++D)I.push(u(D));for(var D=0;D<L;++D)z.push(s(D)+\"=\"+i(0)+\".shape[\"+D+\"]|0\");for(var D=0;D<C;++D){z.push(a(D)+\"=\"+i(D)+\".data\",c(D)+\"=\"+i(D)+\".offset|0\");for(var R=0;R<L;++R)z.push(l(D,R)+\"=\"+i(D)+\".stride[\"+R+\"]|0\")}for(var D=0;D<C;++D){z.push(h(D)+\"=\"+c(D)),z.push(o(D,0));for(var R=1;R<1<<L;++R){for(var F=[],B=0;B<L;++B)R&1<<B&&F.push(\"-\"+l(D,B));z.push(f(D,R)+\"=(\"+F.join(\"\")+\")|0\"),z.push(o(D,R)+\"=0\")}}for(var D=0;D<C;++D)for(var R=0;R<L;++R){var N=[l(D,S[R])];R>0&&N.push(l(D,S[R-1])+\"*\"+s(S[R-1])),z.push(d(D,S[R])+\"=(\"+N.join(\"-\")+\")|0\")}for(var D=0;D<L;++D)z.push(p(D)+\"=0\");z.push(_+\"=0\");for(var j=[\"2\"],D=L-2;D>=0;--D)j.push(s(S[D]));z.push(w+\"=(\"+j.join(\"*\")+\")|0\",b+\"=mallocUint32(\"+w+\")\",x+\"=mallocUint32(\"+w+\")\",k+\"=0\"),z.push(g(0)+\"=0\");for(var R=1;R<1<<L;++R){for(var U=[],V=[],B=0;B<L;++B)R&1<<B&&(0===V.length?U.push(\"1\"):U.unshift(V.join(\"*\"))),V.push(s(S[B]));var q=\"\";U[0].indexOf(s(S[L-2]))<0&&(q=\"-\");var H=A(L,R,S);z.push(m(H)+\"=(-\"+U.join(\"-\")+\")|0\",v(H)+\"=(\"+q+U.join(\"-\")+\")|0\",g(H)+\"=0\")}function G(t,e){O.push(\"for(\",p(S[t]),\"=\",e,\";\",p(S[t]),\"<\",s(S[t]),\";\",\"++\",p(S[t]),\"){\")}function Y(t){for(var e=0;e<C;++e)O.push(h(e),\"+=\",d(e,S[t]),\";\");O.push(\"}\")}function W(){for(var t=1;t<1<<L;++t)O.push(T,\"=\",m(t),\";\",m(t),\"=\",v(t),\";\",v(t),\"=\",T,\";\")}z.push(y(0)+\"=0\",T+\"=0\"),function t(e,r){if(e<0)return void function(t){for(var e=0;e<C;++e)E[e]?O.push(o(e,0),\"=\",a(e),\".get(\",h(e),\");\"):O.push(o(e,0),\"=\",a(e),\"[\",h(e),\"];\");for(var r=[],e=0;e<C;++e)r.push(o(e,0));for(var e=0;e<M;++e)r.push(u(e));O.push(g(0),\"=\",b,\"[\",k,\"]=phase(\",r.join(),\");\");for(var n=1;n<1<<L;++n)O.push(g(n),\"=\",b,\"[\",k,\"+\",m(n),\"];\");for(var i=[],n=1;n<1<<L;++n)i.push(\"(\"+g(0)+\"!==\"+g(n)+\")\");O.push(\"if(\",i.join(\"||\"),\"){\");for(var s=[],e=0;e<L;++e)s.push(p(e));for(var e=0;e<C;++e){s.push(o(e,0));for(var n=1;n<1<<L;++n)E[e]?O.push(o(e,n),\"=\",a(e),\".get(\",h(e),\"+\",f(e,n),\");\"):O.push(o(e,n),\"=\",a(e),\"[\",h(e),\"+\",f(e,n),\"];\"),s.push(o(e,n))}for(var e=0;e<1<<L;++e)s.push(g(e));for(var e=0;e<M;++e)s.push(u(e));O.push(\"vertex(\",s.join(),\");\",y(0),\"=\",x,\"[\",k,\"]=\",_,\"++;\");for(var l=(1<<L)-1,c=g(l),n=0;n<L;++n)if(0==(t&~(1<<n))){for(var d=l^1<<n,v=g(d),w=[],T=d;T>0;T=T-1&d)w.push(x+\"[\"+k+\"+\"+m(T)+\"]\");w.push(y(0));for(var T=0;T<C;++T)1&n?w.push(o(T,l),o(T,d)):w.push(o(T,d),o(T,l));1&n?w.push(c,v):w.push(v,c);for(var T=0;T<M;++T)w.push(u(T));O.push(\"if(\",c,\"!==\",v,\"){\",\"face(\",w.join(),\")}\")}O.push(\"}\",k,\"+=1;\")}(r);!function(t){for(var e=t-1;e>=0;--e)G(e,0);for(var r=[],e=0;e<C;++e)E[e]?r.push(a(e)+\".get(\"+h(e)+\")\"):r.push(a(e)+\"[\"+h(e)+\"]\");for(var e=0;e<M;++e)r.push(u(e));O.push(b,\"[\",k,\"++]=phase(\",r.join(),\");\");for(var e=0;e<t;++e)Y(e);for(var n=0;n<C;++n)O.push(h(n),\"+=\",d(n,S[t]),\";\")}(e);O.push(\"if(\",s(S[e]),\">0){\",p(S[e]),\"=1;\");t(e-1,r|1<<S[e]);for(var n=0;n<C;++n)O.push(h(n),\"+=\",d(n,S[e]),\";\");e===L-1&&(O.push(k,\"=0;\"),W());G(e,2);t(e-1,r);e===L-1&&(O.push(\"if(\",p(S[L-1]),\"&1){\",k,\"=0;}\"),W());Y(e);O.push(\"}\")}(L-1,0),O.push(\"freeUint32(\",x,\");freeUint32(\",b,\");\");var X=[\"'use strict';\",\"function \",P,\"(\",I.join(),\"){\",\"var \",z.join(),\";\",O.join(\"\"),\"}\",\"return \",P].join(\"\");return new Function(\"vertex\",\"face\",\"phase\",\"mallocUint32\",\"freeUint32\",X)(t,e,r,n.mallocUint32,n.freeUint32)}(t.vertex,t.cell,t.phase,S,r,C)};var x=\"V\",b=\"P\",_=\"N\",w=\"Q\",k=\"X\",T=\"T\";function A(t,e,r){for(var n=0,i=0;i<t;++i)e&1<<i&&(n|=1<<r[i]);return n}},{\"typedarray-pool\":545}],440:[function(t,e,r){\"use strict\";var n=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{_inline_1_arg1_=_inline_1_arg2_.apply(void 0,_inline_1_arg0_)}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"cwise\",blockSize:64});e.exports=function(t,e){return n(t,e),t}},{\"cwise/lib/wrapper\":149}],441:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(Array.isArray(r)){if(r.length!==e.dimension)throw new Error(\"ndarray-gradient: invalid boundary conditions\")}else r=n(e.dimension,\"string\"==typeof r?r:\"clamp\");if(t.dimension!==e.dimension+1)throw new Error(\"ndarray-gradient: output dimension must be +1 input dimension\");if(t.shape[e.dimension]!==e.dimension)throw new Error(\"ndarray-gradient: output shape must match input shape\");for(var i=0;i<e.dimension;++i)if(t.shape[i]!==e.shape[i])throw new Error(\"ndarray-gradient: shape mismatch\");if(0===e.size)return t;if(e.dimension<=0)return t.set(0),t;return function(t){var e=t.join();if(m=o[e])return m;var r=t.length,n=[\"function gradient(dst,src){var s=src.shape.slice();\"];function i(e){for(var i=r-e.length,a=[],o=[],s=[],l=0;l<r;++l)e.indexOf(l+1)>=0?s.push(\"0\"):e.indexOf(-(l+1))>=0?s.push(\"s[\"+l+\"]-1\"):(s.push(\"-1\"),a.push(\"1\"),o.push(\"s[\"+l+\"]-2\"));var c=\".lo(\"+a.join()+\").hi(\"+o.join()+\")\";if(0===a.length&&(c=\"\"),i>0){n.push(\"if(1\");for(var l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\"&&s[\",l,\"]>2\");n.push(\"){grad\",i,\"(src.pick(\",s.join(),\")\",c);for(var l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\",dst.pick(\",s.join(),\",\",l,\")\",c);n.push(\");\")}for(var l=0;l<e.length;++l){var u=Math.abs(e[l])-1,h=\"dst.pick(\"+s.join()+\",\"+u+\")\"+c;switch(t[u]){case\"clamp\":var f=s.slice(),p=s.slice();e[l]<0?f[u]=\"s[\"+u+\"]-2\":p[u]=\"1\",0===i?n.push(\"if(s[\",u,\"]>1){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",f.join(),\")-src.get(\",p.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>1){diff(\",h,\",src.pick(\",f.join(),\")\",c,\",src.pick(\",p.join(),\")\",c,\");}else{zero(\",h,\");};\");break;case\"mirror\":0===i?n.push(\"dst.set(\",s.join(),\",\",u,\",0);\"):n.push(\"zero(\",h,\");\");break;case\"wrap\":var d=s.slice(),g=s.slice();e[l]<0?(d[u]=\"s[\"+u+\"]-2\",g[u]=\"0\"):(d[u]=\"s[\"+u+\"]-1\",g[u]=\"1\"),0===i?n.push(\"if(s[\",u,\"]>2){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",d.join(),\")-src.get(\",g.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>2){diff(\",h,\",src.pick(\",d.join(),\")\",c,\",src.pick(\",g.join(),\")\",c,\");}else{zero(\",h,\");};\");break;default:throw new Error(\"ndarray-gradient: Invalid boundary condition\")}}i>0&&n.push(\"};\")}for(var s=0;s<1<<r;++s){for(var h=[],f=0;f<r;++f)s&1<<f&&h.push(f+1);for(var p=0;p<1<<h.length;++p){for(var d=h.slice(),f=0;f<h.length;++f)p&1<<f&&(d[f]=-d[f]);i(d)}}n.push(\"return dst;};return gradient\");for(var g=[\"diff\",\"zero\"],v=[l,c],s=1;s<=r;++s)g.push(\"grad\"+s),v.push(u(s));g.push(n.join(\"\"));var m=Function.apply(void 0,g).apply(void 0,v);return a[e]=m,m}(r)(t,e)};var n=t(\"dup\"),i=t(\"cwise-compiler\"),a={},o={},s={body:\"\",args:[],thisVars:[],localVars:[]},l=i({args:[\"array\",\"array\",\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1},{name:\"left\",lvalue:!1,rvalue:!0,count:1},{name:\"right\",lvalue:!1,rvalue:!0,count:1}],body:\"out=0.5*(left-right)\",thisVars:[],localVars:[]},funcName:\"cdiff\"}),c=i({args:[\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1}],body:\"out=0\",thisVars:[],localVars:[]},funcName:\"zero\"});function u(t){if(t in a)return a[t];for(var e=[],r=0;r<t;++r)e.push(\"out\",r,\"s=0.5*(inp\",r,\"l-inp\",r,\"r);\");var o=[\"array\"],l=[\"junk\"];for(r=0;r<t;++r){o.push(\"array\"),l.push(\"out\"+r+\"s\");var c=n(t);c[r]=-1,o.push({array:0,offset:c.slice()}),c[r]=1,o.push({array:0,offset:c.slice()}),l.push(\"inp\"+r+\"l\",\"inp\"+r+\"r\")}return a[t]=i({args:o,pre:s,post:s,body:{body:e.join(\"\"),args:l.map(function(t){return{name:t,lvalue:0===t.indexOf(\"out\"),rvalue:0===t.indexOf(\"inp\"),count:\"junk\"!==t|0}}),thisVars:[],localVars:[]},funcName:\"fdTemplate\"+t})}},{\"cwise-compiler\":146,dup:170}],442:[function(t,e,r){\"use strict\";var n=t(\"ndarray-warp\"),i=t(\"gl-matrix-invert\");e.exports=function(t,e,r){var a=e.dimension,o=i([],r);return n(t,e,function(t,e){for(var r=0;r<a;++r){t[r]=o[(a+1)*a+r];for(var n=0;n<a;++n)t[r]+=o[(a+1)*n+r]*e[n]}var i=o[(a+1)*(a+1)-1];for(n=0;n<a;++n)i+=o[(a+1)*n+a]*e[n];var s=1/i;for(r=0;r<a;++r)t[r]*=s;return t}),t}},{\"gl-matrix-invert\":277,\"ndarray-warp\":449}],443:[function(t,e,r){\"use strict\";function n(t,e){var r=Math.floor(e),n=e-r,i=0<=r&&r<t.shape[0],a=0<=r+1&&r+1<t.shape[0];return(1-n)*(i?+t.get(r):0)+n*(a?+t.get(r+1):0)}function i(t,e,r){var n=Math.floor(e),i=e-n,a=0<=n&&n<t.shape[0],o=0<=n+1&&n+1<t.shape[0],s=Math.floor(r),l=r-s,c=0<=s&&s<t.shape[1],u=0<=s+1&&s+1<t.shape[1],h=a&&c?t.get(n,s):0,f=a&&u?t.get(n,s+1):0;return(1-l)*((1-i)*h+i*(o&&c?t.get(n+1,s):0))+l*((1-i)*f+i*(o&&u?t.get(n+1,s+1):0))}function a(t,e,r,n){var i=Math.floor(e),a=e-i,o=0<=i&&i<t.shape[0],s=0<=i+1&&i+1<t.shape[0],l=Math.floor(r),c=r-l,u=0<=l&&l<t.shape[1],h=0<=l+1&&l+1<t.shape[1],f=Math.floor(n),p=n-f,d=0<=f&&f<t.shape[2],g=0<=f+1&&f+1<t.shape[2],v=o&&u&&d?t.get(i,l,f):0,m=o&&h&&d?t.get(i,l+1,f):0,y=s&&u&&d?t.get(i+1,l,f):0,x=s&&h&&d?t.get(i+1,l+1,f):0,b=o&&u&&g?t.get(i,l,f+1):0,_=o&&h&&g?t.get(i,l+1,f+1):0;return(1-p)*((1-c)*((1-a)*v+a*y)+c*((1-a)*m+a*x))+p*((1-c)*((1-a)*b+a*(s&&u&&g?t.get(i+1,l,f+1):0))+c*((1-a)*_+a*(s&&h&&g?t.get(i+1,l+1,f+1):0)))}e.exports=function(t,e,r,o){switch(t.shape.length){case 0:return 0;case 1:return n(t,e);case 2:return i(t,e,r);case 3:return a(t,e,r,o);default:return function(t){var e,r,n=0|t.shape.length,i=new Array(n),a=new Array(n),o=new Array(n),s=new Array(n);for(e=0;e<n;++e)r=+arguments[e+1],i[e]=Math.floor(r),a[e]=r-i[e],o[e]=0<=i[e]&&i[e]<t.shape[e],s[e]=0<=i[e]+1&&i[e]+1<t.shape[e];var l,c,u,h=0;t:for(e=0;e<1<<n;++e){for(c=1,u=t.offset,l=0;l<n;++l)if(e&1<<l){if(!s[l])continue t;c*=a[l],u+=t.stride[l]*(i[l]+1)}else{if(!o[l])continue t;c*=1-a[l],u+=t.stride[l]*i[l]}h+=c*t.data[u]}return h}.apply(void 0,arguments)}},e.exports.d1=n,e.exports.d2=i,e.exports.d3=a},{}],444:[function(t,e,r){\"use strict\";var n=t(\"cwise-compiler\"),i={body:\"\",args:[],thisVars:[],localVars:[]};function a(t){if(!t)return i;for(var e=0;e<t.args.length;++e){var r=t.args[e];t.args[e]=0===e?{name:r,lvalue:!0,rvalue:!!t.rvalue,count:t.count||1}:{name:r,lvalue:!1,rvalue:!0,count:1}}return t.thisVars||(t.thisVars=[]),t.localVars||(t.localVars=[]),t}function o(t){for(var e=[],r=0;r<t.args.length;++r)e.push(\"a\"+r);return new Function(\"P\",[\"return function \",t.funcName,\"_ndarrayops(\",e.join(\",\"),\") {P(\",e.join(\",\"),\");return a0}\"].join(\"\"))(function(t){return n({args:t.args,pre:a(t.pre),body:a(t.body),post:a(t.proc),funcName:t.funcName})}(t))}var s={add:\"+\",sub:\"-\",mul:\"*\",div:\"/\",mod:\"%\",band:\"&\",bor:\"|\",bxor:\"^\",lshift:\"<<\",rshift:\">>\",rrshift:\">>>\"};!function(){for(var t in s){var e=s[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a\"+e+\"=b\"},rvalue:!0,funcName:t+\"eq\"}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a\"+e+\"=s\"},rvalue:!0,funcName:t+\"seq\"})}}();var l={not:\"!\",bnot:\"~\",neg:\"-\",recip:\"1.0/\"};!function(){for(var t in l){var e=l[t];r[t]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=\"+e+\"b\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\"],body:{args:[\"a\"],body:\"a=\"+e+\"a\"},rvalue:!0,count:2,funcName:t+\"eq\"})}}();var c={and:\"&&\",or:\"||\",eq:\"===\",neq:\"!==\",lt:\"<\",gt:\">\",leq:\"<=\",geq:\">=\"};!function(){for(var t in c){var e=c[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=a\"+e+\"b\"},rvalue:!0,count:2,funcName:t+\"eq\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a=a\"+e+\"s\"},rvalue:!0,count:2,funcName:t+\"seq\"})}}();var u=[\"abs\",\"acos\",\"asin\",\"atan\",\"ceil\",\"cos\",\"exp\",\"floor\",\"log\",\"round\",\"sin\",\"sqrt\",\"tan\"];!function(){for(var t=0;t<u.length;++t){var e=u[t];r[e]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"eq\"]=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f(a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"})}}();var h=[\"max\",\"min\",\"atan2\",\"pow\"];!function(){for(var t=0;t<h.length;++t){var e=h[t];r[e]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e+\"s\"}),r[e+\"eq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"}),r[e+\"seq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"seq\"})}}();var f=[\"atan2\",\"pow\"];!function(){for(var t=0;t<f.length;++t){var e=f[t];r[e+\"op\"]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"op\"}),r[e+\"ops\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"ops\"}),r[e+\"opeq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opeq\"}),r[e+\"opseq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opseq\"})}}(),r.any=n({args:[\"array\"],pre:i,body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"if(a){return true}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return false\"},funcName:\"any\"}),r.all=n({args:[\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1}],body:\"if(!x){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"all\"}),r.sum=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s+=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"sum\"}),r.prod=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=1\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s*=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"prod\"}),r.norm2squared=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm2squared\"}),r.norm2=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return Math.sqrt(this_s)\"},funcName:\"norm2\"}),r.norminf=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:4}],body:\"if(-a>this_s){this_s=-a}else if(a>this_s){this_s=a}\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norminf\"}),r.norm1=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:3}],body:\"this_s+=a<0?-a:a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm1\"}),r.sup=n({args:[\"array\"],pre:{body:\"this_h=-Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_>this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.inf=n({args:[\"array\"],pre:{body:\"this_h=Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_<this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.argmin=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_<this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.argmax=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=-Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_>this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.random=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.random\",thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f()\",thisVars:[\"this_f\"]},funcName:\"random\"}),r.assign=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assign\"}),r.assigns=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assigns\"}),r.equals=n({args:[\"array\",\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1},{name:\"y\",lvalue:!1,rvalue:!0,count:1}],body:\"if(x!==y){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"equals\"})},{\"cwise-compiler\":146}],445:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"./doConvert.js\");e.exports=function(t,e){for(var r=[],a=t,o=1;Array.isArray(a);)r.push(a.length),o*=a.length,a=a[0];return 0===r.length?n():(e||(e=n(new Float64Array(o),r)),i(e,t),e)}},{\"./doConvert.js\":446,ndarray:450}],446:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\nvar _inline_1_v=_inline_1_arg1_,_inline_1_i\\nfor(_inline_1_i=0;_inline_1_i<_inline_1_arg2_.length-1;++_inline_1_i) {\\n_inline_1_v=_inline_1_v[_inline_1_arg2_[_inline_1_i]]\\n}\\n_inline_1_arg0_=_inline_1_v[_inline_1_arg2_[_inline_1_arg2_.length-1]]\\n}\",args:[{name:\"_inline_1_arg0_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:4}],thisVars:[],localVars:[\"_inline_1_i\",\"_inline_1_v\"]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},funcName:\"convert\",blockSize:64})},{\"cwise-compiler\":146}],447:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=32;function a(t){switch(t){case\"uint8\":return[n.mallocUint8,n.freeUint8];case\"uint16\":return[n.mallocUint16,n.freeUint16];case\"uint32\":return[n.mallocUint32,n.freeUint32];case\"int8\":return[n.mallocInt8,n.freeInt8];case\"int16\":return[n.mallocInt16,n.freeInt16];case\"int32\":return[n.mallocInt32,n.freeInt32];case\"float32\":return[n.mallocFloat,n.freeFloat];case\"float64\":return[n.mallocDouble,n.freeDouble];default:return null}}function o(t){for(var e=[],r=0;r<t;++r)e.push(\"s\"+r);for(r=0;r<t;++r)e.push(\"n\"+r);for(r=1;r<t;++r)e.push(\"d\"+r);for(r=1;r<t;++r)e.push(\"e\"+r);for(r=1;r<t;++r)e.push(\"f\"+r);return e}e.exports=function(t,e){var r=[\"'use strict'\"],n=[\"ndarraySortWrapper\",t.join(\"d\"),e].join(\"\");r.push([\"function \",n,\"(\",[\"array\"].join(\",\"),\"){\"].join(\"\"));for(var s=[\"data=array.data,offset=array.offset|0,shape=array.shape,stride=array.stride\"],l=0;l<t.length;++l)s.push([\"s\",l,\"=stride[\",l,\"]|0,n\",l,\"=shape[\",l,\"]|0\"].join(\"\"));var c=new Array(t.length),u=[];for(l=0;l<t.length;++l)0!==(p=t[l])&&(0===u.length?c[p]=\"1\":c[p]=u.join(\"*\"),u.push(\"n\"+p));var h=-1,f=-1;for(l=0;l<t.length;++l){var p,d=t[l];0!==d&&(h>0?s.push([\"d\",d,\"=s\",d,\"-d\",h,\"*n\",h].join(\"\")):s.push([\"d\",d,\"=s\",d].join(\"\")),h=d),0!=(p=t.length-1-l)&&(f>0?s.push([\"e\",p,\"=s\",p,\"-e\",f,\"*n\",f,\",f\",p,\"=\",c[p],\"-f\",f,\"*n\",f].join(\"\")):s.push([\"e\",p,\"=s\",p,\",f\",p,\"=\",c[p]].join(\"\")),f=p)}r.push(\"var \"+s.join(\",\"));var g=[\"0\",\"n0-1\",\"data\",\"offset\"].concat(o(t.length));r.push([\"if(n0<=\",i,\"){\",\"insertionSort(\",g.join(\",\"),\")}else{\",\"quickSort(\",g.join(\",\"),\")}\"].join(\"\")),r.push(\"}return \"+n);var v=new Function(\"insertionSort\",\"quickSort\",r.join(\"\\n\")),m=function(t,e){var r=[\"'use strict'\"],n=[\"ndarrayInsertionSort\",t.join(\"d\"),e].join(\"\"),i=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),s=a(e),l=[\"i,j,cptr,ptr=left*s0+offset\"];if(t.length>1){for(var c=[],u=1;u<t.length;++u)l.push(\"i\"+u),c.push(\"n\"+u);s?l.push(\"scratch=malloc(\"+c.join(\"*\")+\")\"):l.push(\"scratch=new Array(\"+c.join(\"*\")+\")\"),l.push(\"dptr\",\"sptr\",\"a\",\"b\")}else l.push(\"scratch\");function h(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function f(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}if(r.push([\"function \",n,\"(\",i.join(\",\"),\"){var \",l.join(\",\")].join(\"\"),\"for(i=left+1;i<=right;++i){\",\"j=i;ptr+=s0\",\"cptr=ptr\"),t.length>1){for(r.push(\"dptr=0;sptr=ptr\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(\"scratch[dptr++]=\",h(\"sptr\")),u=0;u<t.length;++u)0!==(p=t[u])&&r.push(\"sptr+=d\"+p,\"}\");for(r.push(\"__g:while(j--\\x3eleft){\",\"dptr=0\",\"sptr=cptr-s0\"),u=1;u<t.length;++u)1===u&&r.push(\"__l:\"),r.push([\"for(i\",u,\"=0;i\",u,\"<n\",u,\";++i\",u,\"){\"].join(\"\"));for(r.push([\"a=\",h(\"sptr\"),\"\\nb=scratch[dptr]\\nif(a<b){break __g}\\nif(a>b){break __l}\"].join(\"\")),u=t.length-1;u>=1;--u)r.push(\"sptr+=e\"+u,\"dptr+=f\"+u,\"}\");for(r.push(\"dptr=cptr;sptr=cptr-s0\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(f(\"dptr\",h(\"sptr\"))),u=0;u<t.length;++u)0!==(p=t[u])&&r.push([\"dptr+=d\",p,\";sptr+=d\",p].join(\"\"),\"}\");for(r.push(\"cptr-=s0\\n}\"),r.push(\"dptr=cptr;sptr=0\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(f(\"dptr\",\"scratch[sptr++]\")),u=0;u<t.length;++u){var p;0!==(p=t[u])&&r.push(\"dptr+=d\"+p,\"}\")}}else r.push(\"scratch=\"+h(\"ptr\"),\"while((j--\\x3eleft)&&(\"+h(\"cptr-s0\")+\">scratch)){\",f(\"cptr\",h(\"cptr-s0\")),\"cptr-=s0\",\"}\",f(\"cptr\",\"scratch\"));return r.push(\"}\"),t.length>1&&s&&r.push(\"free(scratch)\"),r.push(\"} return \"+n),s?new Function(\"malloc\",\"free\",r.join(\"\\n\"))(s[0],s[1]):new Function(r.join(\"\\n\"))()}(t,e),y=function(t,e,r){var n=[\"'use strict'\"],s=[\"ndarrayQuickSort\",t.join(\"d\"),e].join(\"\"),l=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),c=a(e),u=0;n.push([\"function \",s,\"(\",l.join(\",\"),\"){\"].join(\"\"));var h=[\"sixth=((right-left+1)/6)|0\",\"index1=left+sixth\",\"index5=right-sixth\",\"index3=(left+right)>>1\",\"index2=index3-sixth\",\"index4=index3+sixth\",\"el1=index1\",\"el2=index2\",\"el3=index3\",\"el4=index4\",\"el5=index5\",\"less=left+1\",\"great=right-1\",\"pivots_are_equal=true\",\"tmp\",\"tmp0\",\"x\",\"y\",\"z\",\"k\",\"ptr0\",\"ptr1\",\"ptr2\",\"comp_pivot1=0\",\"comp_pivot2=0\",\"comp=0\"];if(t.length>1){for(var f=[],p=1;p<t.length;++p)f.push(\"n\"+p),h.push(\"i\"+p);for(p=0;p<8;++p)h.push(\"b_ptr\"+p);h.push(\"ptr3\",\"ptr4\",\"ptr5\",\"ptr6\",\"ptr7\",\"pivot_ptr\",\"ptr_shift\",\"elementSize=\"+f.join(\"*\")),c?h.push(\"pivot1=malloc(elementSize)\",\"pivot2=malloc(elementSize)\"):h.push(\"pivot1=new Array(elementSize),pivot2=new Array(elementSize)\")}else h.push(\"pivot1\",\"pivot2\");function d(t){return[\"(offset+\",t,\"*s0)\"].join(\"\")}function g(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function v(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}function m(e,r,i){if(1===e.length)n.push(\"ptr0=\"+d(e[0]));else for(var a=0;a<e.length;++a)n.push([\"b_ptr\",a,\"=s0*\",e[a]].join(\"\"));for(r&&n.push(\"pivot_ptr=0\"),n.push(\"ptr_shift=offset\"),a=t.length-1;a>=0;--a)0!==(o=t[a])&&n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"));if(e.length>1)for(a=0;a<e.length;++a)n.push([\"ptr\",a,\"=b_ptr\",a,\"+ptr_shift\"].join(\"\"));for(n.push(i),r&&n.push(\"++pivot_ptr\"),a=0;a<t.length;++a){var o;0!==(o=t[a])&&(e.length>1?n.push(\"ptr_shift+=d\"+o):n.push(\"ptr0+=d\"+o),n.push(\"}\"))}}function y(e,r,i,a){if(1===r.length)n.push(\"ptr0=\"+d(r[0]));else{for(var o=0;o<r.length;++o)n.push([\"b_ptr\",o,\"=s0*\",r[o]].join(\"\"));n.push(\"ptr_shift=offset\")}for(i&&n.push(\"pivot_ptr=0\"),e&&n.push(e+\":\"),o=1;o<t.length;++o)n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"));if(r.length>1)for(o=0;o<r.length;++o)n.push([\"ptr\",o,\"=b_ptr\",o,\"+ptr_shift\"].join(\"\"));for(n.push(a),o=t.length-1;o>=1;--o)i&&n.push(\"pivot_ptr+=f\"+o),r.length>1?n.push(\"ptr_shift+=e\"+o):n.push(\"ptr0+=e\"+o),n.push(\"}\")}function x(){t.length>1&&c&&n.push(\"free(pivot1)\",\"free(pivot2)\")}function b(e,r){var i=\"el\"+e,a=\"el\"+r;if(t.length>1){var o=\"__l\"+ ++u;y(o,[i,a],!1,[\"comp=\",g(\"ptr0\"),\"-\",g(\"ptr1\"),\"\\n\",\"if(comp>0){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0;break \",o,\"}\\n\",\"if(comp<0){break \",o,\"}\"].join(\"\"))}else n.push([\"if(\",g(d(i)),\">\",g(d(a)),\"){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0}\"].join(\"\"))}function _(e,r){t.length>1?m([e,r],!1,v(\"ptr0\",g(\"ptr1\"))):n.push(v(d(e),g(d(r))))}function w(e,r,i){if(t.length>1){var a=\"__l\"+ ++u;y(a,[r],!0,[e,\"=\",g(\"ptr0\"),\"-pivot\",i,\"[pivot_ptr]\\n\",\"if(\",e,\"!==0){break \",a,\"}\"].join(\"\"))}else n.push([e,\"=\",g(d(r)),\"-pivot\",i].join(\"\"))}function k(e,r){t.length>1?m([e,r],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",\"tmp\")].join(\"\")):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",\"tmp\")].join(\"\"))}function T(e,r,i){t.length>1?(m([e,r,i],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",g(\"ptr2\")),\"\\n\",v(\"ptr2\",\"tmp\")].join(\"\")),n.push(\"++\"+r,\"--\"+i)):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"ptr2=\",d(i),\"\\n\",\"++\",r,\"\\n\",\"--\",i,\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",g(\"ptr2\")),\"\\n\",v(\"ptr2\",\"tmp\")].join(\"\"))}function A(t,e){k(t,e),n.push(\"--\"+e)}function M(e,r,i){t.length>1?m([e,r],!0,[v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",[\"pivot\",i,\"[pivot_ptr]\"].join(\"\"))].join(\"\")):n.push(v(d(e),g(d(r))),v(d(r),\"pivot\"+i))}function S(e,r){n.push([\"if((\",r,\"-\",e,\")<=\",i,\"){\\n\",\"insertionSort(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}else{\\n\",s,\"(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}\"].join(\"\"))}function E(e,r,i){t.length>1?(n.push([\"__l\",++u,\":while(true){\"].join(\"\")),m([e],!0,[\"if(\",g(\"ptr0\"),\"!==pivot\",r,\"[pivot_ptr]){break __l\",u,\"}\"].join(\"\")),n.push(i,\"}\")):n.push([\"while(\",g(d(e)),\"===pivot\",r,\"){\",i,\"}\"].join(\"\"))}return n.push(\"var \"+h.join(\",\")),b(1,2),b(4,5),b(1,3),b(2,3),b(1,4),b(3,4),b(2,5),b(2,3),b(4,5),t.length>1?m([\"el1\",\"el2\",\"el3\",\"el4\",\"el5\",\"index1\",\"index3\",\"index5\"],!0,[\"pivot1[pivot_ptr]=\",g(\"ptr1\"),\"\\n\",\"pivot2[pivot_ptr]=\",g(\"ptr3\"),\"\\n\",\"pivots_are_equal=pivots_are_equal&&(pivot1[pivot_ptr]===pivot2[pivot_ptr])\\n\",\"x=\",g(\"ptr0\"),\"\\n\",\"y=\",g(\"ptr2\"),\"\\n\",\"z=\",g(\"ptr4\"),\"\\n\",v(\"ptr5\",\"x\"),\"\\n\",v(\"ptr6\",\"y\"),\"\\n\",v(\"ptr7\",\"z\")].join(\"\")):n.push([\"pivot1=\",g(d(\"el2\")),\"\\n\",\"pivot2=\",g(d(\"el4\")),\"\\n\",\"pivots_are_equal=pivot1===pivot2\\n\",\"x=\",g(d(\"el1\")),\"\\n\",\"y=\",g(d(\"el3\")),\"\\n\",\"z=\",g(d(\"el5\")),\"\\n\",v(d(\"index1\"),\"x\"),\"\\n\",v(d(\"index3\"),\"y\"),\"\\n\",v(d(\"index5\"),\"z\")].join(\"\")),_(\"index2\",\"left\"),_(\"index4\",\"right\"),n.push(\"if(pivots_are_equal){\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp\",\"k\",1),n.push(\"if(comp===0){continue}\"),n.push(\"if(comp<0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),n.push(\"while(true){\"),w(\"comp\",\"great\",1),n.push(\"if(comp>0){\"),n.push(\"great--\"),n.push(\"}else if(comp<0){\"),T(\"k\",\"less\",\"great\"),n.push(\"break\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}else{\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1<0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2>0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp>0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),T(\"k\",\"less\",\"great\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),M(\"left\",\"(less-1)\",1),M(\"right\",\"(great+1)\",2),S(\"left\",\"(less-2)\"),S(\"(great+2)\",\"right\"),n.push(\"if(pivots_are_equal){\"),x(),n.push(\"return\"),n.push(\"}\"),n.push(\"if(less<index1&&great>index5){\"),E(\"less\",1,\"++less\"),E(\"great\",2,\"--great\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1===0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2===0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp===0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),T(\"k\",\"less\",\"great\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),x(),S(\"less\",\"great\"),n.push(\"}return \"+s),t.length>1&&c?new Function(\"insertionSort\",\"malloc\",\"free\",n.join(\"\\n\"))(r,c[0],c[1]):new Function(\"insertionSort\",n.join(\"\\n\"))(r)}(t,e,m);return v(m,y)}},{\"typedarray-pool\":545}],448:[function(t,e,r){\"use strict\";var n=t(\"./lib/compile_sort.js\"),i={};e.exports=function(t){var e=t.order,r=t.dtype,a=[e,r].join(\":\"),o=i[a];return o||(i[a]=o=n(e,r)),o(t),t}},{\"./lib/compile_sort.js\":447}],449:[function(t,e,r){\"use strict\";var n=t(\"ndarray-linear-interpolate\"),i=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=new Array(_inline_3_arg4_)}\",args:[{name:\"_inline_3_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg2_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg3_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_4_arg2_(this_warped,_inline_4_arg0_),_inline_4_arg1_=_inline_4_arg3_.apply(void 0,this_warped)}\",args:[{name:\"_inline_4_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_4_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg4_\",lvalue:!1,rvalue:!1,count:0}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warpND\",blockSize:64}),a=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_7_arg2_(this_warped,_inline_7_arg0_),_inline_7_arg1_=_inline_7_arg3_(_inline_7_arg4_,this_warped[0])}\",args:[{name:\"_inline_7_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_7_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp1D\",blockSize:64}),o=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0,0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_10_arg2_(this_warped,_inline_10_arg0_),_inline_10_arg1_=_inline_10_arg3_(_inline_10_arg4_,this_warped[0],this_warped[1])}\",args:[{name:\"_inline_10_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_10_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp2D\",blockSize:64}),s=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0,0,0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_13_arg2_(this_warped,_inline_13_arg0_),_inline_13_arg1_=_inline_13_arg3_(_inline_13_arg4_,this_warped[0],this_warped[1],this_warped[2])}\",args:[{name:\"_inline_13_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_13_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp3D\",blockSize:64});e.exports=function(t,e,r){switch(e.shape.length){case 1:a(t,r,n.d1,e);break;case 2:o(t,r,n.d2,e);break;case 3:s(t,r,n.d3,e);break;default:i(t,r,n.bind(void 0,e),e.shape.length)}return t}},{\"cwise/lib/wrapper\":149,\"ndarray-linear-interpolate\":443}],450:[function(t,e,r){var n=t(\"iota-array\"),i=t(\"is-buffer\"),a=\"undefined\"!=typeof Float64Array;function o(t,e){return t[0]-e[0]}function s(){var t,e=this.stride,r=new Array(e.length);for(t=0;t<r.length;++t)r[t]=[Math.abs(e[t]),t];r.sort(o);var n=new Array(r.length);for(t=0;t<n.length;++t)n[t]=r[t][1];return n}function l(t,e){var r=[\"View\",e,\"d\",t].join(\"\");e<0&&(r=\"View_Nil\"+t);var i=\"generic\"===t;if(-1===e){var a=\"function \"+r+\"(a){this.data=a;};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return -1};proto.size=0;proto.dimension=-1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function(){return new \"+r+\"(this.data);};proto.get=proto.set=function(){};proto.pick=function(){return null};return function construct_\"+r+\"(a){return new \"+r+\"(a);}\";return new Function(a)()}if(0===e){a=\"function \"+r+\"(a,d) {this.data = a;this.offset = d};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return this.offset};proto.dimension=0;proto.size=1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function \"+r+\"_copy() {return new \"+r+\"(this.data,this.offset)};proto.pick=function \"+r+\"_pick(){return TrivialArray(this.data);};proto.valueOf=proto.get=function \"+r+\"_get(){return \"+(i?\"this.data.get(this.offset)\":\"this.data[this.offset]\")+\"};proto.set=function \"+r+\"_set(v){return \"+(i?\"this.data.set(this.offset,v)\":\"this.data[this.offset]=v\")+\"};return function construct_\"+r+\"(a,b,c,d){return new \"+r+\"(a,d)}\";return new Function(\"TrivialArray\",a)(c[t][0])}a=[\"'use strict'\"];var o=n(e),l=o.map(function(t){return\"i\"+t}),u=\"this.offset+\"+o.map(function(t){return\"this.stride[\"+t+\"]*i\"+t}).join(\"+\"),h=o.map(function(t){return\"b\"+t}).join(\",\"),f=o.map(function(t){return\"c\"+t}).join(\",\");a.push(\"function \"+r+\"(a,\"+h+\",\"+f+\",d){this.data=a\",\"this.shape=[\"+h+\"]\",\"this.stride=[\"+f+\"]\",\"this.offset=d|0}\",\"var proto=\"+r+\".prototype\",\"proto.dtype='\"+t+\"'\",\"proto.dimension=\"+e),a.push(\"Object.defineProperty(proto,'size',{get:function \"+r+\"_size(){return \"+o.map(function(t){return\"this.shape[\"+t+\"]\"}).join(\"*\"),\"}})\"),1===e?a.push(\"proto.order=[0]\"):(a.push(\"Object.defineProperty(proto,'order',{get:\"),e<4?(a.push(\"function \"+r+\"_order(){\"),2===e?a.push(\"return (Math.abs(this.stride[0])>Math.abs(this.stride[1]))?[1,0]:[0,1]}})\"):3===e&&a.push(\"var s0=Math.abs(this.stride[0]),s1=Math.abs(this.stride[1]),s2=Math.abs(this.stride[2]);if(s0>s1){if(s1>s2){return [2,1,0];}else if(s0>s2){return [1,2,0];}else{return [1,0,2];}}else if(s0>s2){return [2,0,1];}else if(s2>s1){return [0,1,2];}else{return [0,2,1];}}})\")):a.push(\"ORDER})\")),a.push(\"proto.set=function \"+r+\"_set(\"+l.join(\",\")+\",v){\"),i?a.push(\"return this.data.set(\"+u+\",v)}\"):a.push(\"return this.data[\"+u+\"]=v}\"),a.push(\"proto.get=function \"+r+\"_get(\"+l.join(\",\")+\"){\"),i?a.push(\"return this.data.get(\"+u+\")}\"):a.push(\"return this.data[\"+u+\"]}\"),a.push(\"proto.index=function \"+r+\"_index(\",l.join(),\"){return \"+u+\"}\"),a.push(\"proto.hi=function \"+r+\"_hi(\"+l.join(\",\")+\"){return new \"+r+\"(this.data,\"+o.map(function(t){return[\"(typeof i\",t,\"!=='number'||i\",t,\"<0)?this.shape[\",t,\"]:i\",t,\"|0\"].join(\"\")}).join(\",\")+\",\"+o.map(function(t){return\"this.stride[\"+t+\"]\"}).join(\",\")+\",this.offset)}\");var p=o.map(function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"}),d=o.map(function(t){return\"c\"+t+\"=this.stride[\"+t+\"]\"});a.push(\"proto.lo=function \"+r+\"_lo(\"+l.join(\",\")+\"){var b=this.offset,d=0,\"+p.join(\",\")+\",\"+d.join(\",\"));for(var g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){d=i\"+g+\"|0;b+=c\"+g+\"*d;a\"+g+\"-=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map(function(t){return\"a\"+t}).join(\",\")+\",\"+o.map(function(t){return\"c\"+t}).join(\",\")+\",b)}\"),a.push(\"proto.step=function \"+r+\"_step(\"+l.join(\",\")+\"){var \"+o.map(function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"}).join(\",\")+\",\"+o.map(function(t){return\"b\"+t+\"=this.stride[\"+t+\"]\"}).join(\",\")+\",c=this.offset,d=0,ceil=Math.ceil\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'){d=i\"+g+\"|0;if(d<0){c+=b\"+g+\"*(a\"+g+\"-1);a\"+g+\"=ceil(-a\"+g+\"/d)}else{a\"+g+\"=ceil(a\"+g+\"/d)}b\"+g+\"*=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map(function(t){return\"a\"+t}).join(\",\")+\",\"+o.map(function(t){return\"b\"+t}).join(\",\")+\",c)}\");var v=new Array(e),m=new Array(e);for(g=0;g<e;++g)v[g]=\"a[i\"+g+\"]\",m[g]=\"b[i\"+g+\"]\";a.push(\"proto.transpose=function \"+r+\"_transpose(\"+l+\"){\"+l.map(function(t,e){return t+\"=(\"+t+\"===undefined?\"+e+\":\"+t+\"|0)\"}).join(\";\"),\"var a=this.shape,b=this.stride;return new \"+r+\"(this.data,\"+v.join(\",\")+\",\"+m.join(\",\")+\",this.offset)}\"),a.push(\"proto.pick=function \"+r+\"_pick(\"+l+\"){var a=[],b=[],c=this.offset\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){c=(c+this.stride[\"+g+\"]*i\"+g+\")|0}else{a.push(this.shape[\"+g+\"]);b.push(this.stride[\"+g+\"])}\");return a.push(\"var ctor=CTOR_LIST[a.length+1];return ctor(this.data,a,b,c)}\"),a.push(\"return function construct_\"+r+\"(data,shape,stride,offset){return new \"+r+\"(data,\"+o.map(function(t){return\"shape[\"+t+\"]\"}).join(\",\")+\",\"+o.map(function(t){return\"stride[\"+t+\"]\"}).join(\",\")+\",offset)}\"),new Function(\"CTOR_LIST\",\"ORDER\",a.join(\"\\n\"))(c[t],s)}var c={float32:[],float64:[],int8:[],int16:[],int32:[],uint8:[],uint16:[],uint32:[],array:[],uint8_clamped:[],buffer:[],generic:[]};e.exports=function(t,e,r,n){if(void 0===t)return(0,c.array[0])([]);\"number\"==typeof t&&(t=[t]),void 0===e&&(e=[t.length]);var o=e.length;if(void 0===r){r=new Array(o);for(var s=o-1,u=1;s>=0;--s)r[s]=u,u*=e[s]}if(void 0===n)for(n=0,s=0;s<o;++s)r[s]<0&&(n-=(e[s]-1)*r[s]);for(var h=function(t){if(i(t))return\"buffer\";if(a)switch(Object.prototype.toString.call(t)){case\"[object Float64Array]\":return\"float64\";case\"[object Float32Array]\":return\"float32\";case\"[object Int8Array]\":return\"int8\";case\"[object Int16Array]\":return\"int16\";case\"[object Int32Array]\":return\"int32\";case\"[object Uint8Array]\":return\"uint8\";case\"[object Uint16Array]\":return\"uint16\";case\"[object Uint32Array]\":return\"uint32\";case\"[object Uint8ClampedArray]\":return\"uint8_clamped\"}return Array.isArray(t)?\"array\":\"generic\"}(t),f=c[h];f.length<=o+1;)f.push(l(h,f.length-1));return(0,f[o+1])(t,e,r,n)}},{\"iota-array\":416,\"is-buffer\":418}],451:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=Math.pow(2,-1074),a=-1>>>0;e.exports=function(t,e){if(isNaN(t)||isNaN(e))return NaN;if(t===e)return t;if(0===t)return e<0?-i:i;var r=n.hi(t),o=n.lo(t);e>t==t>0?o===a?(r+=1,o=0):o+=1:0===o?(o=a,r-=1):o-=1;return n.pack(o,r)}},{\"double-bits\":167}],452:[function(t,e,r){var n=Math.PI,i=c(120);function a(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function o(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}function s(t,e,r,a,o,c,u,h,f,p){if(p)k=p[0],T=p[1],_=p[2],w=p[3];else{var d=l(t,e,-o);t=d.x,e=d.y;var g=(t-(h=(d=l(h,f,-o)).x))/2,v=(e-(f=d.y))/2,m=g*g/(r*r)+v*v/(a*a);m>1&&(r*=m=Math.sqrt(m),a*=m);var y=r*r,x=a*a,b=(c==u?-1:1)*Math.sqrt(Math.abs((y*x-y*v*v-x*g*g)/(y*v*v+x*g*g)));b==1/0&&(b=1);var _=b*r*v/a+(t+h)/2,w=b*-a*g/r+(e+f)/2,k=Math.asin(((e-w)/a).toFixed(9)),T=Math.asin(((f-w)/a).toFixed(9));(k=t<_?n-k:k)<0&&(k=2*n+k),(T=h<_?n-T:T)<0&&(T=2*n+T),u&&k>T&&(k-=2*n),!u&&T>k&&(T-=2*n)}if(Math.abs(T-k)>i){var A=T,M=h,S=f;T=k+i*(u&&T>k?1:-1);var E=s(h=_+r*Math.cos(T),f=w+a*Math.sin(T),r,a,o,0,u,M,S,[T,A,_,w])}var C=Math.tan((T-k)/4),L=4/3*r*C,P=4/3*a*C,O=[2*t-(t+L*Math.sin(k)),2*e-(e-P*Math.cos(k)),h+L*Math.sin(T),f-P*Math.cos(T),h,f];if(p)return O;E&&(O=O.concat(E));for(var z=0;z<O.length;){var I=l(O[z],O[z+1],o);O[z++]=I.x,O[z++]=I.y}return O}function l(t,e,r){return{x:t*Math.cos(r)-e*Math.sin(r),y:t*Math.sin(r)+e*Math.cos(r)}}function c(t){return t*(n/180)}e.exports=function(t){for(var e,r=[],n=0,i=0,l=0,u=0,h=null,f=null,p=0,d=0,g=0,v=t.length;g<v;g++){var m=t[g],y=m[0];switch(y){case\"M\":l=m[1],u=m[2];break;case\"A\":(m=s(p,d,m[1],m[2],c(m[3]),m[4],m[5],m[6],m[7])).unshift(\"C\"),m.length>7&&(r.push(m.splice(0,7)),m.unshift(\"C\"));break;case\"S\":var x=p,b=d;\"C\"!=e&&\"S\"!=e||(x+=x-n,b+=b-i),m=[\"C\",x,b,m[1],m[2],m[3],m[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(h=2*p-h,f=2*d-f):(h=p,f=d),m=o(p,d,h,f,m[1],m[2]);break;case\"Q\":h=m[1],f=m[2],m=o(p,d,m[1],m[2],m[3],m[4]);break;case\"L\":m=a(p,d,m[1],m[2]);break;case\"H\":m=a(p,d,m[1],d);break;case\"V\":m=a(p,d,p,m[1]);break;case\"Z\":m=a(p,d,l,u)}e=y,p=m[m.length-2],d=m[m.length-1],m.length>4?(n=m[m.length-4],i=m[m.length-3]):(n=p,i=d),r.push(m)}return r}},{}],453:[function(t,e,r){r.vertexNormals=function(t,e,r){for(var n=e.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o)i[o]=[0,0,0];for(o=0;o<t.length;++o)for(var s=t[o],l=0,c=s[s.length-1],u=s[0],h=0;h<s.length;++h){l=c,c=u,u=s[(h+1)%s.length];for(var f=e[l],p=e[c],d=e[u],g=new Array(3),v=0,m=new Array(3),y=0,x=0;x<3;++x)g[x]=f[x]-p[x],v+=g[x]*g[x],m[x]=d[x]-p[x],y+=m[x]*m[x];if(v*y>a){var b=i[c],_=1/Math.sqrt(v*y);for(x=0;x<3;++x){var w=(x+1)%3,k=(x+2)%3;b[x]+=_*(m[w]*g[k]-m[k]*g[w])}}}for(o=0;o<n;++o){b=i[o];var T=0;for(x=0;x<3;++x)T+=b[x]*b[x];if(T>a)for(_=1/Math.sqrt(T),x=0;x<3;++x)b[x]*=_;else for(x=0;x<3;++x)b[x]=0}return i},r.faceNormals=function(t,e,r){for(var n=t.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o){for(var s=t[o],l=new Array(3),c=0;c<3;++c)l[c]=e[s[c]];var u=new Array(3),h=new Array(3);for(c=0;c<3;++c)u[c]=l[1][c]-l[0][c],h[c]=l[2][c]-l[0][c];var f=new Array(3),p=0;for(c=0;c<3;++c){var d=(c+1)%3,g=(c+2)%3;f[c]=u[d]*h[g]-u[g]*h[d],p+=f[c]*f[c]}p=p>a?1/Math.sqrt(p):0;for(c=0;c<3;++c)f[c]*=p;i[o]=f}return i}},{}],454:[function(t,e,r){\"use strict\";var n=Object.getOwnPropertySymbols,i=Object.prototype.hasOwnProperty,a=Object.prototype.propertyIsEnumerable;e.exports=function(){try{if(!Object.assign)return!1;var t=new String(\"abc\");if(t[5]=\"de\",\"5\"===Object.getOwnPropertyNames(t)[0])return!1;for(var e={},r=0;r<10;r++)e[\"_\"+String.fromCharCode(r)]=r;if(\"0123456789\"!==Object.getOwnPropertyNames(e).map(function(t){return e[t]}).join(\"\"))return!1;var n={};return\"abcdefghijklmnopqrst\".split(\"\").forEach(function(t){n[t]=t}),\"abcdefghijklmnopqrst\"===Object.keys(Object.assign({},n)).join(\"\")}catch(t){return!1}}()?Object.assign:function(t,e){for(var r,o,s=function(t){if(null==t)throw new TypeError(\"Object.assign cannot be called with null or undefined\");return Object(t)}(t),l=1;l<arguments.length;l++){for(var c in r=Object(arguments[l]))i.call(r,c)&&(s[c]=r[c]);if(n){o=n(r);for(var u=0;u<o.length;u++)a.call(r,o[u])&&(s[o[u]]=r[o[u]])}}return s}},{}],455:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a,o,s,l,c){var u=e+a+c;if(h>0){var h=Math.sqrt(u+1);t[0]=.5*(o-l)/h,t[1]=.5*(s-n)/h,t[2]=.5*(r-a)/h,t[3]=.5*h}else{var f=Math.max(e,a,c),h=Math.sqrt(2*f-u+1);e>=f?(t[0]=.5*h,t[1]=.5*(i+r)/h,t[2]=.5*(s+n)/h,t[3]=.5*(o-l)/h):a>=f?(t[0]=.5*(r+i)/h,t[1]=.5*h,t[2]=.5*(l+o)/h,t[3]=.5*(s-n)/h):(t[0]=.5*(n+s)/h,t[1]=.5*(o+l)/h,t[2]=.5*h,t[3]=.5*(r-i)/h)}return t}},{}],456:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.rotation||[0,0,0,1],n=t.radius||1;e=[].slice.call(e,0,3),u(r=[].slice.call(r,0,4),r);var i=new h(r,e,Math.log(n));i.setDistanceLimits(t.zoomMin,t.zoomMax),(\"eye\"in t||\"up\"in t)&&i.lookAt(0,t.eye,t.center,t.up);return i};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/lookAt\"),a=t(\"gl-mat4/fromQuat\"),o=t(\"gl-mat4/invert\"),s=t(\"./lib/quatFromFrame\");function l(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function c(t,e,r,n){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2)+Math.pow(n,2))}function u(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=c(r,n,i,a);o>1e-6?(t[0]=r/o,t[1]=n/o,t[2]=i/o,t[3]=a/o):(t[0]=t[1]=t[2]=0,t[3]=1)}function h(t,e,r){this.radius=n([r]),this.center=n(e),this.rotation=n(t),this.computedRadius=this.radius.curve(0),this.computedCenter=this.center.curve(0),this.computedRotation=this.rotation.curve(0),this.computedUp=[.1,0,0],this.computedEye=[.1,0,0],this.computedMatrix=[.1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],this.recalcMatrix(0)}var f=h.prototype;f.lastT=function(){return Math.max(this.radius.lastT(),this.center.lastT(),this.rotation.lastT())},f.recalcMatrix=function(t){this.radius.curve(t),this.center.curve(t),this.rotation.curve(t);var e=this.computedRotation;u(e,e);var r=this.computedMatrix;a(r,e);var n=this.computedCenter,i=this.computedEye,o=this.computedUp,s=Math.exp(this.computedRadius[0]);i[0]=n[0]+s*r[2],i[1]=n[1]+s*r[6],i[2]=n[2]+s*r[10],o[0]=r[1],o[1]=r[5],o[2]=r[9];for(var l=0;l<3;++l){for(var c=0,h=0;h<3;++h)c+=r[l+4*h]*i[h];r[12+l]=-c}},f.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r},f.idle=function(t){this.center.idle(t),this.radius.idle(t),this.rotation.idle(t)},f.flush=function(t){this.center.flush(t),this.radius.flush(t),this.rotation.flush(t)},f.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=i[1],o=i[5],s=i[9],c=l(a,o,s);a/=c,o/=c,s/=c;var u=i[0],h=i[4],f=i[8],p=u*a+h*o+f*s,d=l(u-=a*p,h-=o*p,f-=s*p);u/=d,h/=d,f/=d;var g=i[2],v=i[6],m=i[10],y=g*a+v*o+m*s,x=g*u+v*h+m*f,b=l(g-=y*a+x*u,v-=y*o+x*h,m-=y*s+x*f);g/=b,v/=b,m/=b;var _=u*e+a*r,w=h*e+o*r,k=f*e+s*r;this.center.move(t,_,w,k);var T=Math.exp(this.computedRadius[0]);T=Math.max(1e-4,T+n),this.radius.set(t,Math.log(T))},f.rotate=function(t,e,r,n){this.recalcMatrix(t),e=e||0,r=r||0;var i=this.computedMatrix,a=i[0],o=i[4],s=i[8],u=i[1],h=i[5],f=i[9],p=i[2],d=i[6],g=i[10],v=e*a+r*u,m=e*o+r*h,y=e*s+r*f,x=-(d*y-g*m),b=-(g*v-p*y),_=-(p*m-d*v),w=Math.sqrt(Math.max(0,1-Math.pow(x,2)-Math.pow(b,2)-Math.pow(_,2))),k=c(x,b,_,w);k>1e-6?(x/=k,b/=k,_/=k,w/=k):(x=b=_=0,w=1);var T=this.computedRotation,A=T[0],M=T[1],S=T[2],E=T[3],C=A*w+E*x+M*_-S*b,L=M*w+E*b+S*x-A*_,P=S*w+E*_+A*b-M*x,O=E*w-A*x-M*b-S*_;if(n){x=p,b=d,_=g;var z=Math.sin(n)/l(x,b,_);x*=z,b*=z,_*=z,O=O*(w=Math.cos(e))-(C=C*w+O*x+L*_-P*b)*x-(L=L*w+O*b+P*x-C*_)*b-(P=P*w+O*_+C*b-L*x)*_}var I=c(C,L,P,O);I>1e-6?(C/=I,L/=I,P/=I,O/=I):(C=L=P=0,O=1),this.rotation.set(t,C,L,P,O)},f.lookAt=function(t,e,r,n){this.recalcMatrix(t),r=r||this.computedCenter,e=e||this.computedEye,n=n||this.computedUp;var a=this.computedMatrix;i(a,e,r,n);var o=this.computedRotation;s(o,a[0],a[1],a[2],a[4],a[5],a[6],a[8],a[9],a[10]),u(o,o),this.rotation.set(t,o[0],o[1],o[2],o[3]);for(var l=0,c=0;c<3;++c)l+=Math.pow(r[c]-e[c],2);this.radius.set(t,.5*Math.log(Math.max(l,1e-6))),this.center.set(t,r[0],r[1],r[2])},f.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},f.setMatrix=function(t,e){var r=this.computedRotation;s(r,e[0],e[1],e[2],e[4],e[5],e[6],e[8],e[9],e[10]),u(r,r),this.rotation.set(t,r[0],r[1],r[2],r[3]);var n=this.computedMatrix;o(n,e);var i=n[15];if(Math.abs(i)>1e-6){var a=n[12]/i,l=n[13]/i,c=n[14]/i;this.recalcMatrix(t);var h=Math.exp(this.computedRadius[0]);this.center.set(t,a-n[2]*h,l-n[6]*h,c-n[10]*h),this.radius.idle(t)}else this.center.idle(t),this.radius.idle(t)},f.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},f.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},f.getDistanceLimits=function(t){var e=this.radius.bounds;return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},f.toJSON=function(){return this.recalcMatrix(this.lastT()),{center:this.computedCenter.slice(),rotation:this.computedRotation.slice(),distance:Math.log(this.computedRadius[0]),zoomMin:this.radius.bounds[0][0],zoomMax:this.radius.bounds[1][0]}},f.fromJSON=function(t){var e=this.lastT(),r=t.center;r&&this.center.set(e,r[0],r[1],r[2]);var n=t.rotation;n&&this.rotation.set(e,n[0],n[1],n[2],n[3]);var i=t.distance;i&&i>0&&this.radius.set(e,Math.log(i)),this.setDistanceLimits(t.zoomMin,t.zoomMax)}},{\"./lib/quatFromFrame\":455,\"filtered-vector\":226,\"gl-mat4/fromQuat\":262,\"gl-mat4/invert\":265,\"gl-mat4/lookAt\":266}],457:[function(t,e,r){\"use strict\";var n=t(\"repeat-string\");e.exports=function(t,e,r){return n(r=\"undefined\"!=typeof r?r+\"\":\" \",e)+t}},{\"repeat-string\":503}],458:[function(t,e,r){\"use strict\";function n(t,e){if(\"string\"!=typeof t)return[t];var r=[t];\"string\"==typeof e||Array.isArray(e)?e={brackets:e}:e||(e={});var n=e.brackets?Array.isArray(e.brackets)?e.brackets:[e.brackets]:[\"{}\",\"[]\",\"()\"],i=e.escape||\"___\",a=!!e.flat;n.forEach(function(t){var e=new RegExp([\"\\\\\",t[0],\"[^\\\\\",t[0],\"\\\\\",t[1],\"]*\\\\\",t[1]].join(\"\")),n=[];function a(e,a,o){var s=r.push(e.slice(t[0].length,-t[1].length))-1;return n.push(s),i+s+i}r.forEach(function(t,n){for(var i,o=0;t!=i;)if(i=t,t=t.replace(e,a),o++>1e4)throw Error(\"References have circular dependency. Please, check them.\");r[n]=t}),n=n.reverse(),r=r.map(function(e){return n.forEach(function(r){e=e.replace(new RegExp(\"(\\\\\"+i+r+\"\\\\\"+i+\")\",\"g\"),t[0]+\"$1\"+t[1])}),e})});var o=new RegExp(\"\\\\\"+i+\"([0-9]+)\\\\\"+i);return a?r:function t(e,r,n){for(var i,a=[],s=0;i=o.exec(e);){if(s++>1e4)throw Error(\"Circular references in parenthesis\");a.push(e.slice(0,i.index)),a.push(t(r[i[1]],r)),e=e.slice(i.index+i[0].length)}return a.push(e),a}(r[0],r)}function i(t,e){if(e&&e.flat){var r,n=e&&e.escape||\"___\",i=t[0];if(!i)return\"\";for(var a=new RegExp(\"\\\\\"+n+\"([0-9]+)\\\\\"+n),o=0;i!=r;){if(o++>1e4)throw Error(\"Circular references in \"+t);r=i,i=i.replace(a,s)}return i}return t.reduce(function t(e,r){return Array.isArray(r)&&(r=r.reduce(t,\"\")),e+r},\"\");function s(e,r){if(null==t[r])throw Error(\"Reference \"+r+\"is undefined\");return t[r]}}function a(t,e){return Array.isArray(t)?i(t,e):n(t,e)}a.parse=n,a.stringify=i,e.exports=a},{}],459:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\");e.exports=function(t){var e;arguments.length>1&&(t=arguments);\"string\"==typeof t?t=t.split(/\\s/).map(parseFloat):\"number\"==typeof t&&(t=[t]);t.length&&\"number\"==typeof t[0]?e=1===t.length?{width:t[0],height:t[0],x:0,y:0}:2===t.length?{width:t[0],height:t[1],x:0,y:0}:{x:t[0],y:t[1],width:t[2]-t[0]||0,height:t[3]-t[1]||0}:t&&(t=n(t,{left:\"x l left Left\",top:\"y t top Top\",width:\"w width W Width\",height:\"h height W Width\",bottom:\"b bottom Bottom\",right:\"r right Right\"}),e={x:t.left||0,y:t.top||0},null==t.width?t.right?e.width=t.right-e.x:e.width=0:e.width=t.width,null==t.height?t.bottom?e.height=t.bottom-e.y:e.height=0:e.height=t.height);return e}},{\"pick-by-alias\":465}],460:[function(t,e,r){e.exports=function(t){var e=[];return t.replace(i,function(t,r,i){var o=r.toLowerCase();for(i=function(t){var e=t.match(a);return e?e.map(Number):[]}(i),\"m\"==o&&i.length>2&&(e.push([r].concat(i.splice(0,2))),o=\"l\",r=\"m\"==r?\"l\":\"L\");;){if(i.length==n[o])return i.unshift(r),e.push(i);if(i.length<n[o])throw new Error(\"malformed path data\");e.push([r].concat(i.splice(0,n[o])))}}),e};var n={a:7,c:6,h:1,l:2,m:2,q:4,s:4,t:2,v:1,z:0},i=/([astvzqmhlc])([^astvzqmhlc]*)/gi;var a=/-?[0-9]*\\.?[0-9]+(?:e[-+]?\\d+)?/gi},{}],461:[function(t,e,r){e.exports=function(t,e){e||(e=[0,\"\"]),t=String(t);var r=parseFloat(t,10);return e[0]=r,e[1]=t.match(/[\\d.\\-\\+]*\\s*(.*)/)[1]||\"\",e}},{}],462:[function(t,e,r){(function(t){(function(){var r,n,i,a,o,s;\"undefined\"!=typeof performance&&null!==performance&&performance.now?e.exports=function(){return performance.now()}:\"undefined\"!=typeof t&&null!==t&&t.hrtime?(e.exports=function(){return(r()-o)/1e6},n=t.hrtime,a=(r=function(){var t;return 1e9*(t=n())[0]+t[1]})(),s=1e9*t.uptime(),o=a-s):Date.now?(e.exports=function(){return Date.now()-i},i=Date.now()):(e.exports=function(){return(new Date).getTime()-i},i=(new Date).getTime())}).call(this)}).call(this,t(\"_process\"))},{_process:482}],463:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<n){for(var r=1,a=0;a<e;++a)for(var o=0;o<a;++o)if(t[a]<t[o])r=-r;else if(t[a]===t[o])return 0;return r}for(var s=i.mallocUint8(e),a=0;a<e;++a)s[a]=0;for(var r=1,a=0;a<e;++a)if(!s[a]){var l=1;s[a]=1;for(var o=t[a];o!==a;o=t[o]){if(s[o])return i.freeUint8(s),0;l+=1,s[o]=1}1&l||(r=-r)}return i.freeUint8(s),r};var n=32,i=t(\"typedarray-pool\")},{\"typedarray-pool\":545}],464:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"invert-permutation\");r.rank=function(t){var e=t.length;switch(e){case 0:case 1:return 0;case 2:return t[1]}var r,a,o,s=n.mallocUint32(e),l=n.mallocUint32(e),c=0;for(i(t,l),o=0;o<e;++o)s[o]=t[o];for(o=e-1;o>0;--o)a=l[o],r=s[o],s[o]=s[a],s[a]=r,l[o]=l[r],l[r]=a,c=(c+r)*o;return n.freeUint32(l),n.freeUint32(s),c},r.unrank=function(t,e,r){switch(t){case 0:return r||[];case 1:return r?(r[0]=0,r):[0];case 2:return r?(e?(r[0]=0,r[1]=1):(r[0]=1,r[1]=0),r):e?[0,1]:[1,0]}var n,i,a,o=1;for((r=r||new Array(t))[0]=0,a=1;a<t;++a)r[a]=a,o=o*a|0;for(a=t-1;a>0;--a)e=e-(n=e/o|0)*o|0,o=o/a|0,i=0|r[a],r[a]=0|r[n],r[n]=0|i;return r}},{\"invert-permutation\":415,\"typedarray-pool\":545}],465:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n,a,o={};if(\"string\"==typeof e&&(e=i(e)),Array.isArray(e)){var s={};for(a=0;a<e.length;a++)s[e[a]]=!0;e=s}for(n in e)e[n]=i(e[n]);var l={};for(n in e){var c=e[n];if(Array.isArray(c))for(a=0;a<c.length;a++){var u=c[a];if(r&&(l[u]=!0),u in t){if(o[n]=t[u],r)for(var h=a;h<c.length;h++)l[c[h]]=!0;break}}else n in t&&(e[n]&&(o[n]=t[n]),r&&(l[n]=!0))}if(r)for(n in t)l[n]||(o[n]=t[n]);return o};var n={};function i(t){return n[t]?n[t]:(\"string\"==typeof t&&(t=n[t]=t.split(/\\s*,\\s*|\\s+/)),t)}},{}],466:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=0|e.length,i=t.length,a=[new Array(r),new Array(r)],o=0;o<r;++o)a[0][o]=[],a[1][o]=[];for(var o=0;o<i;++o){var s=t[o];a[0][s[0]].push(s),a[1][s[1]].push(s)}for(var l=[],o=0;o<r;++o)a[0][o].length+a[1][o].length===0&&l.push([o]);function c(t,e){var r=a[e][t[e]];r.splice(r.indexOf(t),1)}function u(t,r,i){for(var o,s,l,u=0;u<2;++u)if(a[u][r].length>0){o=a[u][r][0],l=u;break}s=o[1^l];for(var h=0;h<2;++h)for(var f=a[h][r],p=0;p<f.length;++p){var d=f[p],g=d[1^h],v=n(e[t],e[r],e[s],e[g]);v>0&&(o=d,s=g,l=h)}return i?s:(o&&c(o,l),s)}function h(t,r){var i=a[r][t][0],o=[t];c(i,r);for(var s=i[1^r];;){for(;s!==t;)o.push(s),s=u(o[o.length-2],s,!1);if(a[0][t].length+a[1][t].length===0)break;var l=o[o.length-1],h=t,f=o[1],p=u(l,h,!0);if(n(e[l],e[h],e[f],e[p])<0)break;o.push(t),s=u(l,h)}return o}function f(t,e){return e[1]===e[e.length-1]}for(var o=0;o<r;++o)for(var p=0;p<2;++p){for(var d=[];a[p][o].length>0;){a[0][o].length;var g=h(o,p);f(d,g)?d.push.apply(d,g):(d.length>0&&l.push(d),d=g)}d.length>0&&l.push(d)}return l};var n=t(\"compare-angle\")},{\"compare-angle\":127}],467:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=n(t,e.length),i=new Array(e.length),a=new Array(e.length),o=[],s=0;s<e.length;++s){var l=r[s].length;a[s]=l,i[s]=!0,l<=1&&o.push(s)}for(;o.length>0;){var c=o.pop();i[c]=!1;for(var u=r[c],s=0;s<u.length;++s){var h=u[s];0==--a[h]&&o.push(h)}}for(var f=new Array(e.length),p=[],s=0;s<e.length;++s)if(i[s]){var c=p.length;f[s]=c,p.push(e[s])}else f[s]=-1;for(var d=[],s=0;s<t.length;++s){var g=t[s];i[g[0]]&&i[g[1]]&&d.push([f[g[0]],f[g[1]]])}return[d,p]};var n=t(\"edges-to-adjacency-list\")},{\"edges-to-adjacency-list\":171}],468:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=c(t,e);t=r[0];for(var h=(e=r[1]).length,f=(t.length,n(t,e.length)),p=0;p<h;++p)if(f[p].length%2==1)throw new Error(\"planar-graph-to-polyline: graph must be manifold\");var d=i(t,e);for(var g=(d=d.filter(function(t){for(var r=t.length,n=[0],i=0;i<r;++i){var a=e[t[i]],l=e[t[(i+1)%r]],c=o(-a[0],a[1]),u=o(-a[0],l[1]),h=o(l[0],a[1]),f=o(l[0],l[1]);n=s(n,s(s(c,u),s(h,f)))}return n[n.length-1]>0})).length,v=new Array(g),m=new Array(g),p=0;p<g;++p){v[p]=p;var y=new Array(g),x=d[p].map(function(t){return e[t]}),b=a([x]),_=0;t:for(var w=0;w<g;++w)if(y[w]=0,p!==w){for(var k=d[w],T=k.length,A=0;A<T;++A){var M=b(e[k[A]]);if(0!==M){M<0&&(y[w]=1,_+=1);continue t}}y[w]=1,_+=1}m[p]=[_,p,y]}m.sort(function(t,e){return e[0]-t[0]});for(var p=0;p<g;++p)for(var y=m[p],S=y[1],E=y[2],w=0;w<g;++w)E[w]&&(v[w]=S);for(var C=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=[];return e}(g),p=0;p<g;++p)C[p].push(v[p]),C[v[p]].push(p);for(var L={},P=u(h,!1),p=0;p<g;++p)for(var k=d[p],T=k.length,w=0;w<T;++w){var O=k[w],z=k[(w+1)%T],I=Math.min(O,z)+\":\"+Math.max(O,z);if(I in L){var D=L[I];C[D].push(p),C[p].push(D),P[O]=P[z]=!0}else L[I]=p}function R(t){for(var e=t.length,r=0;r<e;++r)if(!P[t[r]])return!1;return!0}for(var F=[],B=u(g,-1),p=0;p<g;++p)v[p]!==p||R(d[p])?B[p]=-1:(F.push(p),B[p]=0);var r=[];for(;F.length>0;){var N=F.pop(),j=C[N];l(j,function(t,e){return t-e});var U,V=j.length,q=B[N];if(0===q){var k=d[N];U=[k]}for(var p=0;p<V;++p){var H=j[p];if(!(B[H]>=0)&&(B[H]=1^q,F.push(H),0===q)){var k=d[H];R(k)||(k.reverse(),U.push(k))}}0===q&&r.push(U)}return r};var n=t(\"edges-to-adjacency-list\"),i=t(\"planar-dual\"),a=t(\"point-in-big-polygon\"),o=t(\"two-product\"),s=t(\"robust-sum\"),l=t(\"uniq\"),c=t(\"./lib/trim-leaves\");function u(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}},{\"./lib/trim-leaves\":467,\"edges-to-adjacency-list\":171,\"planar-dual\":466,\"point-in-big-polygon\":472,\"robust-sum\":515,\"two-product\":543,uniq:547}],469:[function(t,e,r){\"use strict\";e.exports=t(\"./quad\")},{\"./quad\":471}],470:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],471:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"clamp\"),a=t(\"parse-rect\"),o=t(\"array-bounds\"),s=t(\"pick-by-alias\"),l=t(\"defined\"),c=t(\"flatten-vertex-data\"),u=t(\"is-obj\"),h=t(\"dtype\"),f=t(\"math-log2\");function p(t,e){for(var r=e[0],n=e[1],a=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=i((t[2*l]-r)*a,0,1),s[2*l+1]=i((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,\"float64\"),e=s(e,{bounds:\"range bounds dataBox databox\",maxDepth:\"depth maxDepth maxdepth level maxLevel maxlevel levels\",dtype:\"type dtype format out dst output destination\"});var r=l(e.maxDepth,255),i=l(e.bounds,o(t,2));i[0]===i[2]&&i[2]++,i[1]===i[3]&&i[3]++;var d,g=p(t,i),v=t.length>>>1;e.dtype||(e.dtype=\"array\"),\"string\"==typeof e.dtype?d=new(h(e.dtype))(v):e.dtype&&(d=e.dtype,Array.isArray(d)&&(d.length=v));for(var m=0;m<v;++m)d[m]=m;var y=[],x=[],b=[],_=[];!function t(e,n,i,a,o,s){if(!a.length)return null;var l=y[o]||(y[o]=[]);var c=b[o]||(b[o]=[]);var u=x[o]||(x[o]=[]);var h=l.length;o++;if(o>r){for(var f=0;f<a.length;f++)l.push(a[f]),c.push(s),u.push(null,null,null,null);return h}l.push(a[0]);c.push(s);if(a.length<=1)return u.push(null,null,null,null),h;var p=.5*i;var d=e+p,v=n+p;var m=[],_=[],w=[],k=[];for(var T=1,A=a.length;T<A;T++){var M=a[T],S=g[2*M],E=g[2*M+1];S<d?E<v?m.push(M):_.push(M):E<v?w.push(M):k.push(M)}s<<=2;u.push(t(e,n,p,m,o,s),t(e,v,p,_,o,s+1),t(d,n,p,w,o,s+2),t(d,v,p,k,o,s+3));return h}(0,0,1,d,0,1);for(var w=0,k=0;k<y.length;k++){var T=y[k];if(d.set)d.set(T,w);else for(var A=0,M=T.length;A<M;A++)d[A+w]=T[A];var S=w+y[k].length;_[k]=[w,S],w=S}return d.range=function(){var e,r=[],o=arguments.length;for(;o--;)r[o]=arguments[o];if(u(r[r.length-1])){var c=r.pop();r.length||null==c.x&&null==c.l&&null==c.left||(r=[c],e={}),e=s(c,{level:\"level maxLevel\",d:\"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize\",lod:\"lod details ranges offsets\"})}else e={};r.length||(r=i);var h=a.apply(void 0,r),d=[Math.min(h.x,h.x+h.width),Math.min(h.y,h.y+h.height),Math.max(h.x,h.x+h.width),Math.max(h.y,h.y+h.height)],g=d[0],v=d[1],m=d[2],w=d[3],k=p([g,v,m,w],i),T=k[0],A=k[1],M=k[2],S=k[3],C=l(e.level,y.length);if(null!=e.d){var L;\"number\"==typeof e.d?L=[e.d,e.d]:e.d.length&&(L=e.d),C=Math.min(Math.max(Math.ceil(-f(Math.abs(L[0])/(i[2]-i[0]))),Math.ceil(-f(Math.abs(L[1])/(i[3]-i[1])))),C)}if(C=Math.min(C,y.length),e.lod)return function(t,e,r,i,a){for(var o=[],s=0;s<a;s++){var l=b[s],c=_[s][0],u=E(t,e,s),h=E(r,i,s),f=n.ge(l,u),p=n.gt(l,h,f,l.length-1);o[s]=[f+c,p+c]}return o}(T,A,M,S,C);var P=[];return function e(r,n,i,a,o,s){if(null!==o&&null!==s){var l=r+i,c=n+i;if(!(T>l||A>c||M<r||S<n||a>=C||o===s)){var u=y[a];void 0===s&&(s=u.length);for(var h=o;h<s;h++){var f=u[h],p=t[2*f],d=t[2*f+1];p>=g&&p<=m&&d>=v&&d<=w&&P.push(f)}var b=x[a],_=b[4*o+0],k=b[4*o+1],E=b[4*o+2],L=b[4*o+3],O=function(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}(b,o+1),z=.5*i,I=a+1;e(r,n,z,I,_,k||E||L||O),e(r,n+z,z,I,k,E||L||O),e(r+z,n,z,I,E,L||O),e(r+z,n+z,z,I,L,O)}}}(0,0,1,0,0,1),P},d;function E(t,e,r){for(var n=1,i=.5,a=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<i?e<a?0:1:e<a?2:3,o*=.5,i+=t<i?-o:o,a+=e<a?-o:o;return n}}},{\"array-bounds\":65,\"binary-search-bounds\":470,clamp:115,defined:164,dtype:169,\"flatten-vertex-data\":227,\"is-obj\":421,\"math-log2\":432,\"parse-rect\":459,\"pick-by-alias\":465}],472:[function(t,e,r){e.exports=function(t){for(var e=t.length,r=[],a=[],s=0;s<e;++s)for(var u=t[s],h=u.length,f=h-1,p=0;p<h;f=p++){var d=u[f],g=u[p];d[0]===g[0]?a.push([d,g]):r.push([d,g])}if(0===r.length)return 0===a.length?c:(v=l(a),function(t){return v(t[0],t[1])?0:1});var v;var m=i(r),y=function(t,e){return function(r){var i=o.le(e,r[0]);if(i<0)return 1;var a=t[i];if(!a){if(!(i>0&&e[i]===r[0]))return 1;a=t[i-1]}for(var s=1;a;){var l=a.key,c=n(r,l[0],l[1]);if(l[0][0]<l[1][0])if(c<0)a=a.left;else{if(!(c>0))return 0;s=-1,a=a.right}else if(c>0)a=a.left;else{if(!(c<0))return 0;s=1,a=a.right}}return s}}(m.slabs,m.coordinates);return 0===a.length?y:function(t,e){return function(r){return t(r[0],r[1])?0:e(r)}}(l(a),y)};var n=t(\"robust-orientation\")[3],i=t(\"slab-decomposition\"),a=t(\"interval-tree-1d\"),o=t(\"binary-search-bounds\");function s(){return!0}function l(t){for(var e={},r=0;r<t.length;++r){var n=t[r],i=n[0][0],o=n[0][1],l=n[1][1],c=[Math.min(o,l),Math.max(o,l)];i in e?e[i].push(c):e[i]=[c]}var u={},h=Object.keys(e);for(r=0;r<h.length;++r){var f=e[h[r]];u[h[r]]=a(f)}return function(t){return function(e,r){var n=t[e];return!!n&&!!n.queryPoint(r,s)}}(u)}function c(t){return 1}},{\"binary-search-bounds\":91,\"interval-tree-1d\":414,\"robust-orientation\":510,\"slab-decomposition\":526}],473:[function(t,e,r){var n,i=t(\"./lib/build-log\"),a=t(\"./lib/epsilon\"),o=t(\"./lib/intersecter\"),s=t(\"./lib/segment-chainer\"),l=t(\"./lib/segment-selector\"),c=t(\"./lib/geojson\"),u=!1,h=a();function f(t,e,r){var i=n.segments(t),a=n.segments(e),o=r(n.combine(i,a));return n.polygon(o)}n={buildLog:function(t){return!0===t?u=i():!1===t&&(u=!1),!1!==u&&u.list},epsilon:function(t){return h.epsilon(t)},segments:function(t){var e=o(!0,h,u);return t.regions.forEach(e.addRegion),{segments:e.calculate(t.inverted),inverted:t.inverted}},combine:function(t,e){return{combined:o(!1,h,u).calculate(t.segments,t.inverted,e.segments,e.inverted),inverted1:t.inverted,inverted2:e.inverted}},selectUnion:function(t){return{segments:l.union(t.combined,u),inverted:t.inverted1||t.inverted2}},selectIntersect:function(t){return{segments:l.intersect(t.combined,u),inverted:t.inverted1&&t.inverted2}},selectDifference:function(t){return{segments:l.difference(t.combined,u),inverted:t.inverted1&&!t.inverted2}},selectDifferenceRev:function(t){return{segments:l.differenceRev(t.combined,u),inverted:!t.inverted1&&t.inverted2}},selectXor:function(t){return{segments:l.xor(t.combined,u),inverted:t.inverted1!==t.inverted2}},polygon:function(t){return{regions:s(t.segments,h,u),inverted:t.inverted}},polygonFromGeoJSON:function(t){return c.toPolygon(n,t)},polygonToGeoJSON:function(t){return c.fromPolygon(n,h,t)},union:function(t,e){return f(t,e,n.selectUnion)},intersect:function(t,e){return f(t,e,n.selectIntersect)},difference:function(t,e){return f(t,e,n.selectDifference)},differenceRev:function(t,e){return f(t,e,n.selectDifferenceRev)},xor:function(t,e){return f(t,e,n.selectXor)}},\"object\"==typeof window&&(window.PolyBool=n),e.exports=n},{\"./lib/build-log\":474,\"./lib/epsilon\":475,\"./lib/geojson\":476,\"./lib/intersecter\":477,\"./lib/segment-chainer\":479,\"./lib/segment-selector\":480}],474:[function(t,e,r){e.exports=function(){var t,e=0,r=!1;function n(e,r){return t.list.push({type:e,data:r?JSON.parse(JSON.stringify(r)):void 0}),t}return t={list:[],segmentId:function(){return e++},checkIntersection:function(t,e){return n(\"check\",{seg1:t,seg2:e})},segmentChop:function(t,e){return n(\"div_seg\",{seg:t,pt:e}),n(\"chop\",{seg:t,pt:e})},statusRemove:function(t){return n(\"pop_seg\",{seg:t})},segmentUpdate:function(t){return n(\"seg_update\",{seg:t})},segmentNew:function(t,e){return n(\"new_seg\",{seg:t,primary:e})},segmentRemove:function(t){return n(\"rem_seg\",{seg:t})},tempStatus:function(t,e,r){return n(\"temp_status\",{seg:t,above:e,below:r})},rewind:function(t){return n(\"rewind\",{seg:t})},status:function(t,e,r){return n(\"status\",{seg:t,above:e,below:r})},vert:function(e){return e===r?t:(r=e,n(\"vert\",{x:e}))},log:function(t){return\"string\"!=typeof t&&(t=JSON.stringify(t,!1,\"  \")),n(\"log\",{txt:t})},reset:function(){return n(\"reset\")},selected:function(t){return n(\"selected\",{segs:t})},chainStart:function(t){return n(\"chain_start\",{seg:t})},chainRemoveHead:function(t,e){return n(\"chain_rem_head\",{index:t,pt:e})},chainRemoveTail:function(t,e){return n(\"chain_rem_tail\",{index:t,pt:e})},chainNew:function(t,e){return n(\"chain_new\",{pt1:t,pt2:e})},chainMatch:function(t){return n(\"chain_match\",{index:t})},chainClose:function(t){return n(\"chain_close\",{index:t})},chainAddHead:function(t,e){return n(\"chain_add_head\",{index:t,pt:e})},chainAddTail:function(t,e){return n(\"chain_add_tail\",{index:t,pt:e})},chainConnect:function(t,e){return n(\"chain_con\",{index1:t,index2:e})},chainReverse:function(t){return n(\"chain_rev\",{index:t})},chainJoin:function(t,e){return n(\"chain_join\",{index1:t,index2:e})},done:function(){return n(\"done\")}}}},{}],475:[function(t,e,r){e.exports=function(t){\"number\"!=typeof t&&(t=1e-10);var e={epsilon:function(e){return\"number\"==typeof e&&(t=e),t},pointAboveOrOnLine:function(e,r,n){var i=r[0],a=r[1],o=n[0],s=n[1],l=e[0];return(o-i)*(e[1]-a)-(s-a)*(l-i)>=-t},pointBetween:function(e,r,n){var i=e[1]-r[1],a=n[0]-r[0],o=e[0]-r[0],s=n[1]-r[1],l=o*a+i*s;return!(l<t||l-(a*a+s*s)>-t)},pointsSameX:function(e,r){return Math.abs(e[0]-r[0])<t},pointsSameY:function(e,r){return Math.abs(e[1]-r[1])<t},pointsSame:function(t,r){return e.pointsSameX(t,r)&&e.pointsSameY(t,r)},pointsCompare:function(t,r){return e.pointsSameX(t,r)?e.pointsSameY(t,r)?0:t[1]<r[1]?-1:1:t[0]<r[0]?-1:1},pointsCollinear:function(e,r,n){var i=e[0]-r[0],a=e[1]-r[1],o=r[0]-n[0],s=r[1]-n[1];return Math.abs(i*s-o*a)<t},linesIntersect:function(e,r,n,i){var a=r[0]-e[0],o=r[1]-e[1],s=i[0]-n[0],l=i[1]-n[1],c=a*l-o*s;if(Math.abs(c)<t)return!1;var u=e[0]-n[0],h=e[1]-n[1],f=(s*h-l*u)/c,p=(a*h-o*u)/c,d={alongA:0,alongB:0,pt:[e[0]+f*a,e[1]+f*o]};return d.alongA=f<=-t?-2:f<t?-1:f-1<=-t?0:f-1<t?1:2,d.alongB=p<=-t?-2:p<t?-1:p-1<=-t?0:p-1<t?1:2,d},pointInsideRegion:function(e,r){for(var n=e[0],i=e[1],a=r[r.length-1][0],o=r[r.length-1][1],s=!1,l=0;l<r.length;l++){var c=r[l][0],u=r[l][1];u-i>t!=o-i>t&&(a-c)*(i-u)/(o-u)+c-n>t&&(s=!s),a=c,o=u}return s}};return e}},{}],476:[function(t,e,r){var n={toPolygon:function(t,e){function r(e){if(e.length<=0)return t.segments({inverted:!1,regions:[]});function r(e){var r=e.slice(0,e.length-1);return t.segments({inverted:!1,regions:[r]})}for(var n=r(e[0]),i=1;i<e.length;i++)n=t.selectDifference(t.combine(n,r(e[i])));return n}if(\"Polygon\"===e.type)return t.polygon(r(e.coordinates));if(\"MultiPolygon\"===e.type){for(var n=t.segments({inverted:!1,regions:[]}),i=0;i<e.coordinates.length;i++)n=t.selectUnion(t.combine(n,r(e.coordinates[i])));return t.polygon(n)}throw new Error(\"PolyBool: Cannot convert GeoJSON object to PolyBool polygon\")},fromPolygon:function(t,e,r){function n(t,r){return e.pointInsideRegion([.5*(t[0][0]+t[1][0]),.5*(t[0][1]+t[1][1])],r)}function i(t){return{region:t,children:[]}}r=t.polygon(t.segments(r));var a=i(null);function o(t,e){for(var r=0;r<t.children.length;r++){if(n(e,(s=t.children[r]).region))return void o(s,e)}var a=i(e);for(r=0;r<t.children.length;r++){var s;n((s=t.children[r]).region,e)&&(a.children.push(s),t.children.splice(r,1),r--)}t.children.push(a)}for(var s=0;s<r.regions.length;s++){var l=r.regions[s];l.length<3||o(a,l)}function c(t,e){for(var r=0,n=t[t.length-1][0],i=t[t.length-1][1],a=[],o=0;o<t.length;o++){var s=t[o][0],l=t[o][1];a.push([s,l]),r+=l*n-s*i,n=s,i=l}return r<0!==e&&a.reverse(),a.push([a[0][0],a[0][1]]),a}var u=[];function h(t){var e=[c(t.region,!1)];u.push(e);for(var r=0;r<t.children.length;r++)e.push(f(t.children[r]))}function f(t){for(var e=0;e<t.children.length;e++)h(t.children[e]);return c(t.region,!0)}for(s=0;s<a.children.length;s++)h(a.children[s]);return u.length<=0?{type:\"Polygon\",coordinates:[]}:1==u.length?{type:\"Polygon\",coordinates:u[0]}:{type:\"MultiPolygon\",coordinates:u}}};e.exports=n},{}],477:[function(t,e,r){var n=t(\"./linked-list\");e.exports=function(t,e,r){function i(t,e,n){return{id:r?r.segmentId():-1,start:t,end:e,myFill:{above:n.myFill.above,below:n.myFill.below},otherFill:null}}var a=n.create();function o(t,r){a.insertBefore(t,function(n){return function(t,r,n,i,a,o){var s=e.pointsCompare(r,a);return 0!==s?s:e.pointsSame(n,o)?0:t!==i?t?1:-1:e.pointAboveOrOnLine(n,i?a:o,i?o:a)?1:-1}(t.isStart,t.pt,r,n.isStart,n.pt,n.other.pt)<0})}function s(t,e){var r=function(t,e){var r=n.node({isStart:!0,pt:t.start,seg:t,primary:e,other:null,status:null});return o(r,t.end),r}(t,e);return function(t,e,r){var i=n.node({isStart:!1,pt:e.end,seg:e,primary:r,other:t,status:null});t.other=i,o(i,t.pt)}(r,t,e),r}function l(t,e){var n=i(e,t.seg.end,t.seg);return function(t,e){r&&r.segmentChop(t.seg,e),t.other.remove(),t.seg.end=e,t.other.pt=e,o(t.other,t.pt)}(t,e),s(n,t.primary)}function c(i,o){var s=n.create();function c(t){return s.findTransition(function(r){var n,i,a,o,s,l;return n=t,i=r.ev,a=n.seg.start,o=n.seg.end,s=i.seg.start,l=i.seg.end,(e.pointsCollinear(a,s,l)?e.pointsCollinear(o,s,l)?1:e.pointAboveOrOnLine(o,s,l)?1:-1:e.pointAboveOrOnLine(a,s,l)?1:-1)>0})}function u(t,n){var i=t.seg,a=n.seg,o=i.start,s=i.end,c=a.start,u=a.end;r&&r.checkIntersection(i,a);var h=e.linesIntersect(o,s,c,u);if(!1===h){if(!e.pointsCollinear(o,s,c))return!1;if(e.pointsSame(o,u)||e.pointsSame(s,c))return!1;var f=e.pointsSame(o,c),p=e.pointsSame(s,u);if(f&&p)return n;var d=!f&&e.pointBetween(o,c,u),g=!p&&e.pointBetween(s,c,u);if(f)return g?l(n,s):l(t,u),n;d&&(p||(g?l(n,s):l(t,u)),l(n,o))}else 0===h.alongA&&(-1===h.alongB?l(t,c):0===h.alongB?l(t,h.pt):1===h.alongB&&l(t,u)),0===h.alongB&&(-1===h.alongA?l(n,o):0===h.alongA?l(n,h.pt):1===h.alongA&&l(n,s));return!1}for(var h=[];!a.isEmpty();){var f=a.getHead();if(r&&r.vert(f.pt[0]),f.isStart){r&&r.segmentNew(f.seg,f.primary);var p=c(f),d=p.before?p.before.ev:null,g=p.after?p.after.ev:null;function v(){if(d){var t=u(f,d);if(t)return t}return!!g&&u(f,g)}r&&r.tempStatus(f.seg,!!d&&d.seg,!!g&&g.seg);var m,y,x=v();if(x)t?(y=null===f.seg.myFill.below||f.seg.myFill.above!==f.seg.myFill.below)&&(x.seg.myFill.above=!x.seg.myFill.above):x.seg.otherFill=f.seg.myFill,r&&r.segmentUpdate(x.seg),f.other.remove(),f.remove();if(a.getHead()!==f){r&&r.rewind(f.seg);continue}t?(y=null===f.seg.myFill.below||f.seg.myFill.above!==f.seg.myFill.below,f.seg.myFill.below=g?g.seg.myFill.above:i,f.seg.myFill.above=y?!f.seg.myFill.below:f.seg.myFill.below):null===f.seg.otherFill&&(m=g?f.primary===g.primary?g.seg.otherFill.above:g.seg.myFill.above:f.primary?o:i,f.seg.otherFill={above:m,below:m}),r&&r.status(f.seg,!!d&&d.seg,!!g&&g.seg),f.other.status=p.insert(n.node({ev:f}))}else{var b=f.status;if(null===b)throw new Error(\"PolyBool: Zero-length segment detected; your epsilon is probably too small or too large\");if(s.exists(b.prev)&&s.exists(b.next)&&u(b.prev.ev,b.next.ev),r&&r.statusRemove(b.ev.seg),b.remove(),!f.primary){var _=f.seg.myFill;f.seg.myFill=f.seg.otherFill,f.seg.otherFill=_}h.push(f.seg)}a.getHead().remove()}return r&&r.done(),h}return t?{addRegion:function(t){for(var n,i,a,o=t[t.length-1],l=0;l<t.length;l++){n=o,o=t[l];var c=e.pointsCompare(n,o);0!==c&&s((i=c<0?n:o,a=c<0?o:n,{id:r?r.segmentId():-1,start:i,end:a,myFill:{above:null,below:null},otherFill:null}),!0)}},calculate:function(t){return c(t,!1)}}:{calculate:function(t,e,r,n){return t.forEach(function(t){s(i(t.start,t.end,t),!0)}),r.forEach(function(t){s(i(t.start,t.end,t),!1)}),c(e,n)}}}},{\"./linked-list\":478}],478:[function(t,e,r){e.exports={create:function(){var t={root:{root:!0,next:null},exists:function(e){return null!==e&&e!==t.root},isEmpty:function(){return null===t.root.next},getHead:function(){return t.root.next},insertBefore:function(e,r){for(var n=t.root,i=t.root.next;null!==i;){if(r(i))return e.prev=i.prev,e.next=i,i.prev.next=e,void(i.prev=e);n=i,i=i.next}n.next=e,e.prev=n,e.next=null},findTransition:function(e){for(var r=t.root,n=t.root.next;null!==n&&!e(n);)r=n,n=n.next;return{before:r===t.root?null:r,after:n,insert:function(t){return t.prev=r,t.next=n,r.next=t,null!==n&&(n.prev=t),t}}}};return t},node:function(t){return t.prev=null,t.next=null,t.remove=function(){t.prev.next=t.next,t.next&&(t.next.prev=t.prev),t.prev=null,t.next=null},t}}},{}],479:[function(t,e,r){e.exports=function(t,e,r){var n=[],i=[];return t.forEach(function(t){var a=t.start,o=t.end;if(e.pointsSame(a,o))console.warn(\"PolyBool: Warning: Zero-length segment detected; your epsilon is probably too small or too large\");else{r&&r.chainStart(t);for(var s={index:0,matches_head:!1,matches_pt1:!1},l={index:0,matches_head:!1,matches_pt1:!1},c=s,u=0;u<n.length;u++){var h=(v=n[u])[0],f=(v[1],v[v.length-1]);if(v[v.length-2],e.pointsSame(h,a)){if(T(u,!0,!0))break}else if(e.pointsSame(h,o)){if(T(u,!0,!1))break}else if(e.pointsSame(f,a)){if(T(u,!1,!0))break}else if(e.pointsSame(f,o)&&T(u,!1,!1))break}if(c===s)return n.push([a,o]),void(r&&r.chainNew(a,o));if(c===l){r&&r.chainMatch(s.index);var p=s.index,d=s.matches_pt1?o:a,g=s.matches_head,v=n[p],m=g?v[0]:v[v.length-1],y=g?v[1]:v[v.length-2],x=g?v[v.length-1]:v[0],b=g?v[v.length-2]:v[1];return e.pointsCollinear(y,m,d)&&(g?(r&&r.chainRemoveHead(s.index,d),v.shift()):(r&&r.chainRemoveTail(s.index,d),v.pop()),m=y),e.pointsSame(x,d)?(n.splice(p,1),e.pointsCollinear(b,x,m)&&(g?(r&&r.chainRemoveTail(s.index,m),v.pop()):(r&&r.chainRemoveHead(s.index,m),v.shift())),r&&r.chainClose(s.index),void i.push(v)):void(g?(r&&r.chainAddHead(s.index,d),v.unshift(d)):(r&&r.chainAddTail(s.index,d),v.push(d)))}var _=s.index,w=l.index;r&&r.chainConnect(_,w);var k=n[_].length<n[w].length;s.matches_head?l.matches_head?k?(A(_),M(_,w)):(A(w),M(w,_)):M(w,_):l.matches_head?M(_,w):k?(A(_),M(w,_)):(A(w),M(_,w))}function T(t,e,r){return c.index=t,c.matches_head=e,c.matches_pt1=r,c===s?(c=l,!1):(c=null,!0)}function A(t){r&&r.chainReverse(t),n[t].reverse()}function M(t,i){var a=n[t],o=n[i],s=a[a.length-1],l=a[a.length-2],c=o[0],u=o[1];e.pointsCollinear(l,s,c)&&(r&&r.chainRemoveTail(t,s),a.pop(),s=l),e.pointsCollinear(s,c,u)&&(r&&r.chainRemoveHead(i,c),o.shift()),r&&r.chainJoin(t,i),n[t]=a.concat(o),n.splice(i,1)}}),i}},{}],480:[function(t,e,r){function n(t,e,r){var n=[];return t.forEach(function(t){var i=(t.myFill.above?8:0)+(t.myFill.below?4:0)+(t.otherFill&&t.otherFill.above?2:0)+(t.otherFill&&t.otherFill.below?1:0);0!==e[i]&&n.push({id:r?r.segmentId():-1,start:t.start,end:t.end,myFill:{above:1===e[i],below:2===e[i]},otherFill:null})}),r&&r.selected(n),n}var i={union:function(t,e){return n(t,[0,2,1,0,2,2,0,0,1,0,1,0,0,0,0,0],e)},intersect:function(t,e){return n(t,[0,0,0,0,0,2,0,2,0,0,1,1,0,2,1,0],e)},difference:function(t,e){return n(t,[0,0,0,0,2,0,2,0,1,1,0,0,0,1,2,0],e)},differenceRev:function(t,e){return n(t,[0,2,1,0,0,0,1,1,0,2,0,2,0,0,0,0],e)},xor:function(t,e){return n(t,[0,2,1,0,2,0,0,1,1,0,0,2,0,1,2,0],e)}};e.exports=i},{}],481:[function(t,e,r){\"use strict\";var n=new Float64Array(4),i=new Float64Array(4),a=new Float64Array(4);e.exports=function(t,e,r,o,s){n.length<o.length&&(n=new Float64Array(o.length),i=new Float64Array(o.length),a=new Float64Array(o.length));for(var l=0;l<o.length;++l)n[l]=t[l]-o[l],i[l]=e[l]-t[l],a[l]=r[l]-t[l];var c=0,u=0,h=0,f=0,p=0,d=0;for(l=0;l<o.length;++l){var g=i[l],v=a[l],m=n[l];c+=g*g,u+=g*v,h+=v*v,f+=m*g,p+=m*v,d+=m*m}var y,x,b,_,w,k=Math.abs(c*h-u*u),T=u*p-h*f,A=u*f-c*p;if(T+A<=k)if(T<0)A<0&&f<0?(A=0,-f>=c?(T=1,y=c+2*f+d):y=f*(T=-f/c)+d):(T=0,p>=0?(A=0,y=d):-p>=h?(A=1,y=h+2*p+d):y=p*(A=-p/h)+d);else if(A<0)A=0,f>=0?(T=0,y=d):-f>=c?(T=1,y=c+2*f+d):y=f*(T=-f/c)+d;else{var M=1/k;y=(T*=M)*(c*T+u*(A*=M)+2*f)+A*(u*T+h*A+2*p)+d}else T<0?(b=h+p)>(x=u+f)?(_=b-x)>=(w=c-2*u+h)?(T=1,A=0,y=c+2*f+d):y=(T=_/w)*(c*T+u*(A=1-T)+2*f)+A*(u*T+h*A+2*p)+d:(T=0,b<=0?(A=1,y=h+2*p+d):p>=0?(A=0,y=d):y=p*(A=-p/h)+d):A<0?(b=c+f)>(x=u+p)?(_=b-x)>=(w=c-2*u+h)?(A=1,T=0,y=h+2*p+d):y=(T=1-(A=_/w))*(c*T+u*A+2*f)+A*(u*T+h*A+2*p)+d:(A=0,b<=0?(T=1,y=c+2*f+d):f>=0?(T=0,y=d):y=f*(T=-f/c)+d):(_=h+p-u-f)<=0?(T=0,A=1,y=h+2*p+d):_>=(w=c-2*u+h)?(T=1,A=0,y=c+2*f+d):y=(T=_/w)*(c*T+u*(A=1-T)+2*f)+A*(u*T+h*A+2*p)+d;var S=1-T-A;for(l=0;l<o.length;++l)s[l]=S*t[l]+T*e[l]+A*r[l];return y<0?0:y}},{}],482:[function(t,e,r){var n,i,a=e.exports={};function o(){throw new Error(\"setTimeout has not been defined\")}function s(){throw new Error(\"clearTimeout has not been defined\")}function l(t){if(n===setTimeout)return setTimeout(t,0);if((n===o||!n)&&setTimeout)return n=setTimeout,setTimeout(t,0);try{return n(t,0)}catch(e){try{return n.call(null,t,0)}catch(e){return n.call(this,t,0)}}}!function(){try{n=\"function\"==typeof setTimeout?setTimeout:o}catch(t){n=o}try{i=\"function\"==typeof clearTimeout?clearTimeout:s}catch(t){i=s}}();var c,u=[],h=!1,f=-1;function p(){h&&c&&(h=!1,c.length?u=c.concat(u):f=-1,u.length&&d())}function d(){if(!h){var t=l(p);h=!0;for(var e=u.length;e;){for(c=u,u=[];++f<e;)c&&c[f].run();f=-1,e=u.length}c=null,h=!1,function(t){if(i===clearTimeout)return clearTimeout(t);if((i===s||!i)&&clearTimeout)return i=clearTimeout,clearTimeout(t);try{i(t)}catch(e){try{return i.call(null,t)}catch(e){return i.call(this,t)}}}(t)}}function g(t,e){this.fun=t,this.array=e}function v(){}a.nextTick=function(t){var e=new Array(arguments.length-1);if(arguments.length>1)for(var r=1;r<arguments.length;r++)e[r-1]=arguments[r];u.push(new g(t,e)),1!==u.length||h||l(d)},g.prototype.run=function(){this.fun.apply(null,this.array)},a.title=\"browser\",a.browser=!0,a.env={},a.argv=[],a.version=\"\",a.versions={},a.on=v,a.addListener=v,a.once=v,a.off=v,a.removeListener=v,a.removeAllListeners=v,a.emit=v,a.prependListener=v,a.prependOnceListener=v,a.listeners=function(t){return[]},a.binding=function(t){throw new Error(\"process.binding is not supported\")},a.cwd=function(){return\"/\"},a.chdir=function(t){throw new Error(\"process.chdir is not supported\")},a.umask=function(){return 0}},{}],483:[function(t,e,r){e.exports=t(\"gl-quat/slerp\")},{\"gl-quat/slerp\":293}],484:[function(t,e,r){(function(r){for(var n=t(\"performance-now\"),i=\"undefined\"==typeof window?r:window,a=[\"moz\",\"webkit\"],o=\"AnimationFrame\",s=i[\"request\"+o],l=i[\"cancel\"+o]||i[\"cancelRequest\"+o],c=0;!s&&c<a.length;c++)s=i[a[c]+\"Request\"+o],l=i[a[c]+\"Cancel\"+o]||i[a[c]+\"CancelRequest\"+o];if(!s||!l){var u=0,h=0,f=[];s=function(t){if(0===f.length){var e=n(),r=Math.max(0,1e3/60-(e-u));u=r+e,setTimeout(function(){var t=f.slice(0);f.length=0;for(var e=0;e<t.length;e++)if(!t[e].cancelled)try{t[e].callback(u)}catch(t){setTimeout(function(){throw t},0)}},Math.round(r))}return f.push({handle:++h,callback:t,cancelled:!1}),h},l=function(t){for(var e=0;e<f.length;e++)f[e].handle===t&&(f[e].cancelled=!0)}}e.exports=function(t){return s.call(i,t)},e.exports.cancel=function(){l.apply(i,arguments)},e.exports.polyfill=function(t){t||(t=i),t.requestAnimationFrame=s,t.cancelAnimationFrame=l}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"performance-now\":462}],485:[function(t,e,r){\"use strict\";var n=t(\"big-rat/add\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/add\":75}],486:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t.length),r=0;r<t.length;++r)e[r]=n(t[r]);return e};var n=t(\"big-rat\")},{\"big-rat\":78}],487:[function(t,e,r){\"use strict\";var n=t(\"big-rat\"),i=t(\"big-rat/mul\");e.exports=function(t,e){for(var r=n(e),a=t.length,o=new Array(a),s=0;s<a;++s)o[s]=i(t[s],r);return o}},{\"big-rat\":78,\"big-rat/mul\":87}],488:[function(t,e,r){\"use strict\";var n=t(\"big-rat/sub\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/sub\":89}],489:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"compare-oriented-cell\"),a=t(\"cell-orientation\");e.exports=function(t){t.sort(i);for(var e=t.length,r=0,o=0;o<e;++o){var s=t[o],l=a(s);if(0!==l){if(r>0){var c=t[r-1];if(0===n(s,c)&&a(c)!==l){r-=1;continue}}t[r++]=s}}return t.length=r,t}},{\"cell-orientation\":112,\"compare-cell\":128,\"compare-oriented-cell\":129}],490:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\"),i=t(\"color-normalize\"),a=t(\"update-diff\"),o=t(\"pick-by-alias\"),s=t(\"object-assign\"),l=t(\"flatten-vertex-data\"),c=t(\"to-float32\"),u=c.float32,h=c.fract32;e.exports=function(t,e){\"function\"==typeof t?(e||(e={}),e.regl=t):e=t;e.length&&(e.positions=e);if(!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");var r,c,p,d,g,v,m=t._gl,y={color:\"black\",capSize:5,lineWidth:1,opacity:1,viewport:null,range:null,offset:0,count:0,bounds:null,positions:[],errors:[]},x=[];return d=t.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array(0)}),c=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),p=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),g=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),v=t.buffer({usage:\"static\",type:\"float\",data:f}),k(e),r=t({vert:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tattribute vec2 position, positionFract;\\n\\t\\tattribute vec4 error;\\n\\t\\tattribute vec4 color;\\n\\n\\t\\tattribute vec2 direction, lineOffset, capOffset;\\n\\n\\t\\tuniform vec4 viewport;\\n\\t\\tuniform float lineWidth, capSize;\\n\\t\\tuniform vec2 scale, scaleFract, translate, translateFract;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tfragColor = color / 255.;\\n\\n\\t\\t\\tvec2 pixelOffset = lineWidth * lineOffset + (capSize + lineWidth) * capOffset;\\n\\n\\t\\t\\tvec2 dxy = -step(.5, direction.xy) * error.xz + step(direction.xy, vec2(-.5)) * error.yw;\\n\\n\\t\\t\\tvec2 position = position + dxy;\\n\\n\\t\\t\\tvec2 pos = (position + translate) * scale\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scale\\n\\t\\t\\t\\t+ (position + translate) * scaleFract\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scaleFract;\\n\\n\\t\\t\\tpos += pixelOffset / viewport.zw;\\n\\n\\t\\t\\tgl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\t\\t}\\n\\t\\t\",frag:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tuniform float opacity;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tgl_FragColor = fragColor;\\n\\t\\t\\tgl_FragColor.a *= opacity;\\n\\t\\t}\\n\\t\\t\",uniforms:{range:t.prop(\"range\"),lineWidth:t.prop(\"lineWidth\"),capSize:t.prop(\"capSize\"),opacity:t.prop(\"opacity\"),scale:t.prop(\"scale\"),translate:t.prop(\"translate\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{color:{buffer:d,offset:function(t,e){return 4*e.offset},divisor:1},position:{buffer:c,offset:function(t,e){return 8*e.offset},divisor:1},positionFract:{buffer:p,offset:function(t,e){return 8*e.offset},divisor:1},error:{buffer:g,offset:function(t,e){return 16*e.offset},divisor:1},direction:{buffer:v,stride:24,offset:0},lineOffset:{buffer:v,stride:24,offset:8},capOffset:{buffer:v,stride:24,offset:16}},primitive:\"triangles\",blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:!1,instances:t.prop(\"count\"),count:f.length}),s(b,{update:k,draw:_,destroy:T,regl:t,gl:m,canvas:m.canvas,groups:x}),b;function b(t){t?k(t):null===t&&T(),_()}function _(e){if(\"number\"==typeof e)return w(e);e&&!Array.isArray(e)&&(e=[e]),t._refresh(),x.forEach(function(t,r){t&&(e&&(e[r]?t.draw=!0:t.draw=!1),t.draw?w(r):t.draw=!0)})}function w(t){\"number\"==typeof t&&(t=x[t]),null!=t&&t&&t.count&&t.color&&t.opacity&&t.positions&&t.positions.length>1&&(t.scaleRatio=[t.scale[0]*t.viewport.width,t.scale[1]*t.viewport.height],r(t),t.after&&t.after(t))}function k(t){if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var e=0,r=0;if(b.groups=x=t.map(function(t,c){var u=x[c];return t?(\"function\"==typeof t?t={after:t}:\"number\"==typeof t[0]&&(t={positions:t}),t=o(t,{color:\"color colors fill\",capSize:\"capSize cap capsize cap-size\",lineWidth:\"lineWidth line-width width line thickness\",opacity:\"opacity alpha\",range:\"range dataBox\",viewport:\"viewport viewBox\",errors:\"errors error\",positions:\"positions position data points\"}),u||(x[c]=u={id:c,scale:null,translate:null,scaleFract:null,translateFract:null,draw:!0},t=s({},y,t)),a(u,t,[{lineWidth:function(t){return.5*+t},capSize:function(t){return.5*+t},opacity:parseFloat,errors:function(t){return t=l(t),r+=t.length,t},positions:function(t,r){return t=l(t,\"float64\"),r.count=Math.floor(t.length/2),r.bounds=n(t,2),r.offset=e,e+=r.count,t}},{color:function(t,e){var r=e.count;if(t||(t=\"transparent\"),!Array.isArray(t)||\"number\"==typeof t[0]){var n=t;t=Array(r);for(var a=0;a<r;a++)t[a]=n}if(t.length<r)throw Error(\"Not enough colors\");for(var o=new Uint8Array(4*r),s=0;s<r;s++){var l=i(t[s],\"uint8\");o.set(l,4*s)}return o},range:function(t,e,r){var n=e.bounds;return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=h(e.scale),e.translateFract=h(e.translate),t},viewport:function(t){var e;return Array.isArray(t)?e={x:t[0],y:t[1],width:t[2]-t[0],height:t[3]-t[1]}:t?(e={x:t.x||t.left||0,y:t.y||t.top||0},t.right?e.width=t.right-e.x:e.width=t.w||t.width||0,t.bottom?e.height=t.bottom-e.y:e.height=t.h||t.height||0):e={x:0,y:0,width:m.drawingBufferWidth,height:m.drawingBufferHeight},e}}]),u):u}),e||r){var f=x.reduce(function(t,e,r){return t+(e?e.count:0)},0),v=new Float64Array(2*f),_=new Uint8Array(4*f),w=new Float32Array(4*f);x.forEach(function(t,e){if(t){var r=t.positions,n=t.count,i=t.offset,a=t.color,o=t.errors;n&&(_.set(a,4*i),w.set(o,4*i),v.set(r,2*i))}}),c(u(v)),p(h(v)),d(_),g(w)}}}function T(){c.destroy(),p.destroy(),d.destroy(),g.destroy(),v.destroy()}};var f=[[1,0,0,1,0,0],[1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,1,0,0],[1,0,0,1,0,0],[1,0,-1,0,0,1],[1,0,-1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,1],[1,0,-1,0,0,1],[-1,0,-1,0,0,1],[-1,0,-1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,1],[-1,0,-1,0,0,1],[0,1,1,0,0,0],[0,1,-1,0,0,0],[0,-1,-1,0,0,0],[0,-1,-1,0,0,0],[0,1,1,0,0,0],[0,-1,1,0,0,0],[0,1,0,-1,1,0],[0,1,0,-1,-1,0],[0,1,0,1,-1,0],[0,1,0,1,1,0],[0,1,0,-1,1,0],[0,1,0,1,-1,0],[0,-1,0,-1,1,0],[0,-1,0,-1,-1,0],[0,-1,0,1,-1,0],[0,-1,0,1,1,0],[0,-1,0,-1,1,0],[0,-1,0,1,-1,0]]},{\"array-bounds\":65,\"color-normalize\":120,\"flatten-vertex-data\":227,\"object-assign\":454,\"pick-by-alias\":465,\"to-float32\":538,\"update-diff\":549}],491:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\"),i=t(\"array-bounds\"),a=t(\"object-assign\"),o=t(\"glslify\"),s=t(\"pick-by-alias\"),l=t(\"flatten-vertex-data\"),c=t(\"earcut\"),u=t(\"array-normalize\"),h=t(\"to-float32\"),f=h.float32,p=h.fract32,d=t(\"es6-weak-map\"),g=t(\"parse-rect\");function v(t,e){if(!(this instanceof v))return new v(t,e);if(\"function\"==typeof t?(e||(e={}),e.regl=t):e=t,e.length&&(e.positions=e),!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");this.gl=t._gl,this.regl=t,this.passes=[],this.shaders=v.shaders.has(t)?v.shaders.get(t):v.shaders.set(t,v.createShaders(t)).get(t),this.update(e)}e.exports=v,v.dashMult=2,v.maxPatternLength=256,v.precisionThreshold=3e6,v.maxPoints=1e4,v.maxLines=2048,v.shaders=new d,v.createShaders=function(t){var e,r=t.buffer({usage:\"static\",type:\"float\",data:[0,1,0,0,1,1,1,0]}),n={primitive:\"triangle strip\",instances:t.prop(\"count\"),count:4,offset:0,uniforms:{miterMode:function(t,e){return\"round\"===e.join?2:1},miterLimit:t.prop(\"miterLimit\"),scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),thickness:t.prop(\"thickness\"),dashPattern:t.prop(\"dashTexture\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),dashSize:t.prop(\"dashLength\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]},depth:t.prop(\"depth\")},blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:function(t,e){return!e.overlay}},stencil:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\")},i=t(a({vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, aCoordFract, bCoordFract;\\nattribute vec4 color;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvec2 project(vec2 position, vec2 positionFract, vec2 scale, vec2 scaleFract, vec2 translate, vec2 translateFract) {\\n\\t// the order is important\\n\\treturn position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n}\\n\\nvoid main() {\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineOffset = lineTop * 2. - 1.;\\n\\n\\tvec2 diff = (bCoord + bCoordFract - aCoord - aCoordFract);\\n\\ttangent = normalize(diff * scale * viewport.zw);\\n\\tvec2 normal = vec2(-tangent.y, tangent.x);\\n\\n\\tvec2 position = project(aCoord, aCoordFract, scale, scaleFract, translate, translateFract) * lineStart\\n\\t\\t+ project(bCoord, bCoordFract, scale, scaleFract, translate, translateFract) * lineEnd\\n\\n\\t\\t+ thickness * normal * .5 * lineOffset / viewport.zw;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\n\\nuniform float dashSize, pixelRatio, thickness, opacity, id;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvoid main() {\\n\\tfloat alpha = 1.;\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},aCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8,divisor:1},bCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:16,divisor:1},color:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1}}},n));try{e=t(a({cull:{enable:!0,face:\"back\"},vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, nextCoord, prevCoord;\\nattribute vec4 aColor, bColor;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, translate;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\nuniform float miterLimit, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 tangent;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nconst float REVERSE_THRESHOLD = -.875;\\nconst float MIN_DIFF = 1e-6;\\n\\n// TODO: possible optimizations: avoid overcalculating all for vertices and calc just one instead\\n// TODO: precalculate dot products, normalize things beforehead etc.\\n// TODO: refactor to rectangular algorithm\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nbool isNaN( float val ){\\n  return ( val < 0.0 || 0.0 < val || val == 0.0 ) ? false : true;\\n}\\n\\nvoid main() {\\n\\tvec2 aCoord = aCoord, bCoord = bCoord, prevCoord = prevCoord, nextCoord = nextCoord;\\n\\n  vec2 adjustedScale;\\n  adjustedScale.x = (abs(scale.x) < MIN_DIFF) ? MIN_DIFF : scale.x;\\n  adjustedScale.y = (abs(scale.y) < MIN_DIFF) ? MIN_DIFF : scale.y;\\n\\n  vec2 scaleRatio = adjustedScale * viewport.zw;\\n\\tvec2 normalWidth = thickness / scaleRatio;\\n\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineBot = 1. - lineTop;\\n\\n\\tfragColor = (lineStart * aColor + lineEnd * bColor) / 255.;\\n\\n\\tif (isNaN(aCoord.x) || isNaN(aCoord.y) || isNaN(bCoord.x) || isNaN(bCoord.y)) return;\\n\\n\\tif (aCoord == prevCoord) prevCoord = aCoord + normalize(bCoord - aCoord);\\n\\tif (bCoord == nextCoord) nextCoord = bCoord - normalize(bCoord - aCoord);\\n\\n\\tvec2 prevDiff = aCoord - prevCoord;\\n\\tvec2 currDiff = bCoord - aCoord;\\n\\tvec2 nextDiff = nextCoord - bCoord;\\n\\n\\tvec2 prevTangent = normalize(prevDiff * scaleRatio);\\n\\tvec2 currTangent = normalize(currDiff * scaleRatio);\\n\\tvec2 nextTangent = normalize(nextDiff * scaleRatio);\\n\\n\\tvec2 prevNormal = vec2(-prevTangent.y, prevTangent.x);\\n\\tvec2 currNormal = vec2(-currTangent.y, currTangent.x);\\n\\tvec2 nextNormal = vec2(-nextTangent.y, nextTangent.x);\\n\\n\\tvec2 startJoinDirection = normalize(prevTangent - currTangent);\\n\\tvec2 endJoinDirection = normalize(currTangent - nextTangent);\\n\\n\\t// collapsed/unidirectional segment cases\\n\\t// FIXME: there should be more elegant solution\\n\\tvec2 prevTanDiff = abs(prevTangent - currTangent);\\n\\tvec2 nextTanDiff = abs(nextTangent - currTangent);\\n\\tif (max(prevTanDiff.x, prevTanDiff.y) < MIN_DIFF) {\\n\\t\\tstartJoinDirection = currNormal;\\n\\t}\\n\\tif (max(nextTanDiff.x, nextTanDiff.y) < MIN_DIFF) {\\n\\t\\tendJoinDirection = currNormal;\\n\\t}\\n\\tif (aCoord == bCoord) {\\n\\t\\tendJoinDirection = startJoinDirection;\\n\\t\\tcurrNormal = prevNormal;\\n\\t\\tcurrTangent = prevTangent;\\n\\t}\\n\\n\\ttangent = currTangent;\\n\\n\\t//calculate join shifts relative to normals\\n\\tfloat startJoinShift = dot(currNormal, startJoinDirection);\\n\\tfloat endJoinShift = dot(currNormal, endJoinDirection);\\n\\n\\tfloat startMiterRatio = abs(1. / startJoinShift);\\n\\tfloat endMiterRatio = abs(1. / endJoinShift);\\n\\n\\tvec2 startJoin = startJoinDirection * startMiterRatio;\\n\\tvec2 endJoin = endJoinDirection * endMiterRatio;\\n\\n\\tvec2 startTopJoin, startBotJoin, endTopJoin, endBotJoin;\\n\\tstartTopJoin = sign(startJoinShift) * startJoin * .5;\\n\\tstartBotJoin = -startTopJoin;\\n\\n\\tendTopJoin = sign(endJoinShift) * endJoin * .5;\\n\\tendBotJoin = -endTopJoin;\\n\\n\\tvec2 aTopCoord = aCoord + normalWidth * startTopJoin;\\n\\tvec2 bTopCoord = bCoord + normalWidth * endTopJoin;\\n\\tvec2 aBotCoord = aCoord + normalWidth * startBotJoin;\\n\\tvec2 bBotCoord = bCoord + normalWidth * endBotJoin;\\n\\n\\t//miter anti-clipping\\n\\tfloat baClipping = distToLine(bCoord, aCoord, aBotCoord) / dot(normalize(normalWidth * endBotJoin), normalize(normalWidth.yx * vec2(-startBotJoin.y, startBotJoin.x)));\\n\\tfloat abClipping = distToLine(aCoord, bCoord, bTopCoord) / dot(normalize(normalWidth * startBotJoin), normalize(normalWidth.yx * vec2(-endBotJoin.y, endBotJoin.x)));\\n\\n\\t//prevent close to reverse direction switch\\n\\tbool prevReverse = dot(currTangent, prevTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, prevNormal)) * min(length(prevDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\tbool nextReverse = dot(currTangent, nextTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, nextNormal)) * min(length(nextDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\n\\tif (prevReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * startJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / startMiterRatio, 1.);\\n\\t\\taBotCoord = aCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\taTopCoord = aCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!nextReverse && baClipping > 0. && baClipping < length(normalWidth * endBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\tbTopCoord -= normalWidth * endTopJoin;\\n\\t\\tbTopCoord += normalize(endTopJoin * normalWidth) * baClipping;\\n\\t}\\n\\n\\tif (nextReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * endJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / endMiterRatio, 1.);\\n\\t\\tbBotCoord = bCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\tbTopCoord = bCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!prevReverse && abClipping > 0. && abClipping < length(normalWidth * startBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\taBotCoord -= normalWidth * startBotJoin;\\n\\t\\taBotCoord += normalize(startBotJoin * normalWidth) * abClipping;\\n\\t}\\n\\n\\tvec2 aTopPosition = (aTopCoord) * adjustedScale + translate;\\n\\tvec2 aBotPosition = (aBotCoord) * adjustedScale + translate;\\n\\n\\tvec2 bTopPosition = (bTopCoord) * adjustedScale + translate;\\n\\tvec2 bBotPosition = (bBotCoord) * adjustedScale + translate;\\n\\n\\t//position is normalized 0..1 coord on the screen\\n\\tvec2 position = (aTopPosition * lineTop + aBotPosition * lineBot) * lineStart + (bTopPosition * lineTop + bBotPosition * lineBot) * lineEnd;\\n\\n\\tstartCoord = aCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\tendCoord = bCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\n\\tgl_Position = vec4(position  * 2.0 - 1.0, depth, 1);\\n\\n\\tenableStartMiter = step(dot(currTangent, prevTangent), .5);\\n\\tenableEndMiter = step(dot(currTangent, nextTangent), .5);\\n\\n\\t//bevel miter cutoffs\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n\\n\\t//round miter cutoffs\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * abs(dot(startJoinDirection, currNormal)) * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * abs(dot(endJoinDirection, currNormal)) * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\nuniform float dashSize, pixelRatio, thickness, opacity, id, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nvoid main() {\\n\\tfloat alpha = 1., distToStart, distToEnd;\\n\\tfloat cutoff = thickness * .5;\\n\\n\\t//bevel miter\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToStart + 1., 0.), 1.);\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToEnd + 1., 0.), 1.);\\n\\t\\t}\\n\\t}\\n\\n\\t// round miter\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - startCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - endCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\t}\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1},bColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:4,divisor:1},prevCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:0,divisor:1},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},nextCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:24,divisor:1}}},n))}catch(t){e=i}return{fill:t({primitive:\"triangle\",elements:function(t,e){return e.triangles},offset:0,vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position, positionFract;\\n\\nuniform vec4 color;\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio, id;\\nuniform vec4 viewport;\\nuniform float opacity;\\n\\nvarying vec4 fragColor;\\n\\nconst float MAX_LINES = 256.;\\n\\nvoid main() {\\n\\tfloat depth = (MAX_LINES - 4. - id) / (MAX_LINES);\\n\\n\\tvec2 position = position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n\\tfragColor.a *= opacity;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n\\tgl_FragColor = fragColor;\\n}\\n\"]),uniforms:{scale:t.prop(\"scale\"),color:t.prop(\"fill\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{position:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8},positionFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8}},blend:n.blend,depth:{enable:!1},scissor:n.scissor,stencil:n.stencil,viewport:n.viewport}),rect:i,miter:e}},v.defaults={dashes:null,join:\"miter\",miterLimit:1,thickness:10,cap:\"square\",color:\"black\",opacity:1,overlay:!1,viewport:null,range:null,close:!1,fill:null},v.prototype.render=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];e.length&&(t=this).update.apply(t,e),this.draw()},v.prototype.draw=function(){for(var t=this,e=[],r=arguments.length;r--;)e[r]=arguments[r];return(e.length?e:this.passes).forEach(function(e,r){var n;if(e&&Array.isArray(e))return(n=t).draw.apply(n,e);\"number\"==typeof e&&(e=t.passes[e]),e&&e.count>1&&e.opacity&&(t.regl._refresh(),e.fill&&e.triangles&&e.triangles.length>2&&t.shaders.fill(e),e.thickness&&(e.scale[0]*e.viewport.width>v.precisionThreshold||e.scale[1]*e.viewport.height>v.precisionThreshold?t.shaders.rect(e):\"rect\"===e.join||!e.join&&(e.thickness<=2||e.count>=v.maxPoints)?t.shaders.rect(e):t.shaders.miter(e)))}),this},v.prototype.update=function(t){var e=this;if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var r=this.regl,o=this.gl;if(t.forEach(function(t,h){var d=e.passes[h];if(void 0!==t)if(null!==t){if(\"number\"==typeof t[0]&&(t={positions:t}),t=s(t,{positions:\"positions points data coords\",thickness:\"thickness lineWidth lineWidths line-width linewidth width stroke-width strokewidth strokeWidth\",join:\"lineJoin linejoin join type mode\",miterLimit:\"miterlimit miterLimit\",dashes:\"dash dashes dasharray dash-array dashArray\",color:\"color colour stroke colors colours stroke-color strokeColor\",fill:\"fill fill-color fillColor\",opacity:\"alpha opacity\",overlay:\"overlay crease overlap intersect\",close:\"closed close closed-path closePath\",range:\"range dataBox\",viewport:\"viewport viewBox\",hole:\"holes hole hollow\"}),d||(e.passes[h]=d={id:h,scale:null,scaleFract:null,translate:null,translateFract:null,count:0,hole:[],depth:0,dashLength:1,dashTexture:r.texture({channels:1,data:new Uint8Array([255]),width:1,height:1,mag:\"linear\",min:\"linear\"}),colorBuffer:r.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array}),positionBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),positionFractBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array})},t=a({},v.defaults,t)),null!=t.thickness&&(d.thickness=parseFloat(t.thickness)),null!=t.opacity&&(d.opacity=parseFloat(t.opacity)),null!=t.miterLimit&&(d.miterLimit=parseFloat(t.miterLimit)),null!=t.overlay&&(d.overlay=!!t.overlay,h<v.maxLines&&(d.depth=2*(v.maxLines-1-h%v.maxLines)/v.maxLines-1)),null!=t.join&&(d.join=t.join),null!=t.hole&&(d.hole=t.hole),null!=t.fill&&(d.fill=t.fill?n(t.fill,\"uint8\"):null),null!=t.viewport&&(d.viewport=g(t.viewport)),d.viewport||(d.viewport=g([o.drawingBufferWidth,o.drawingBufferHeight])),null!=t.close&&(d.close=t.close),null===t.positions&&(t.positions=[]),t.positions){var m,y;if(t.positions.x&&t.positions.y){var x=t.positions.x,b=t.positions.y;y=d.count=Math.max(x.length,b.length),m=new Float64Array(2*y);for(var _=0;_<y;_++)m[2*_]=x[_],m[2*_+1]=b[_]}else m=l(t.positions,\"float64\"),y=d.count=Math.floor(m.length/2);var w=d.bounds=i(m,2);if(d.fill){for(var k=[],T={},A=0,M=0,S=0,E=d.count;M<E;M++){var C=m[2*M],L=m[2*M+1];isNaN(C)||isNaN(L)||null==C||null==L?(C=m[2*A],L=m[2*A+1],T[M]=A):A=M,k[S++]=C,k[S++]=L}for(var P=c(k,d.hole||[]),O=0,z=P.length;O<z;O++)null!=T[P[O]]&&(P[O]=T[P[O]]);d.triangles=P}var I=new Float64Array(m);u(I,2,w);var D=new Float64Array(2*y+6);d.close?m[0]===m[2*y-2]&&m[1]===m[2*y-1]?(D[0]=I[2*y-4],D[1]=I[2*y-3]):(D[0]=I[2*y-2],D[1]=I[2*y-1]):(D[0]=I[0],D[1]=I[1]),D.set(I,2),d.close?m[0]===m[2*y-2]&&m[1]===m[2*y-1]?(D[2*y+2]=I[2],D[2*y+3]=I[3],d.count-=1):(D[2*y+2]=I[0],D[2*y+3]=I[1],D[2*y+4]=I[2],D[2*y+5]=I[3]):(D[2*y+2]=I[2*y-2],D[2*y+3]=I[2*y-1],D[2*y+4]=I[2*y-2],D[2*y+5]=I[2*y-1]),d.positionBuffer(f(D)),d.positionFractBuffer(p(D))}if(t.range?d.range=t.range:d.range||(d.range=d.bounds),(t.range||t.positions)&&d.count){var R=d.bounds,F=R[2]-R[0],B=R[3]-R[1],N=d.range[2]-d.range[0],j=d.range[3]-d.range[1];d.scale=[F/N,B/j],d.translate=[-d.range[0]/N+R[0]/N||0,-d.range[1]/j+R[1]/j||0],d.scaleFract=p(d.scale),d.translateFract=p(d.translate)}if(t.dashes){var U,V=0;if(!t.dashes||t.dashes.length<2)V=1,U=new Uint8Array([255,255,255,255,255,255,255,255]);else{V=0;for(var q=0;q<t.dashes.length;++q)V+=t.dashes[q];U=new Uint8Array(V*v.dashMult);for(var H=0,G=255,Y=0;Y<2;Y++)for(var W=0;W<t.dashes.length;++W){for(var X=0,Z=t.dashes[W]*v.dashMult*.5;X<Z;++X)U[H++]=G;G^=255}}d.dashLength=V,d.dashTexture({channels:1,data:U,width:U.length,height:1,mag:\"linear\",min:\"linear\"},0,0)}if(t.color){var J=d.count,K=t.color;K||(K=\"transparent\");var $=new Uint8Array(4*J+4);if(Array.isArray(K)&&\"number\"!=typeof K[0]){for(var Q=0;Q<J;Q++){var tt=n(K[Q],\"uint8\");$.set(tt,4*Q)}$.set(n(K[0],\"uint8\"),4*J)}else for(var et=n(K,\"uint8\"),rt=0;rt<J+1;rt++)$.set(et,4*rt);d.colorBuffer({usage:\"dynamic\",type:\"uint8\",data:$})}}else e.passes[h]=null}),t.length<this.passes.length){for(var h=t.length;h<this.passes.length;h++){var d=e.passes[h];d&&(d.colorBuffer.destroy(),d.positionBuffer.destroy(),d.dashTexture.destroy())}this.passes.length=t.length}for(var m=[],y=0;y<this.passes.length;y++)null!==e.passes[y]&&m.push(e.passes[y]);return this.passes=m,this}},v.prototype.destroy=function(){return this.passes.forEach(function(t){t.colorBuffer.destroy(),t.positionBuffer.destroy(),t.dashTexture.destroy()}),this.passes.length=0,this}},{\"array-bounds\":65,\"array-normalize\":66,\"color-normalize\":120,earcut:492,\"es6-weak-map\":493,\"flatten-vertex-data\":227,glslify:409,\"object-assign\":454,\"parse-rect\":459,\"pick-by-alias\":465,\"to-float32\":538}],492:[function(t,e,r){\"use strict\";function n(t,e,r){r=r||2;var n,s,l,c,u,p,g,v=e&&e.length,m=v?e[0]*r:t.length,y=i(t,0,m,r,!0),x=[];if(!y||y.next===y.prev)return x;if(v&&(y=function(t,e,r,n){var o,s,l,c,u,p=[];for(o=0,s=e.length;o<s;o++)l=e[o]*n,c=o<s-1?e[o+1]*n:t.length,(u=i(t,l,c,n,!1))===u.next&&(u.steiner=!0),p.push(d(u));for(p.sort(h),o=0;o<p.length;o++)f(p[o],r),r=a(r,r.next);return r}(t,e,y,r)),t.length>80*r){n=l=t[0],s=c=t[1];for(var b=r;b<m;b+=r)(u=t[b])<n&&(n=u),(p=t[b+1])<s&&(s=p),u>l&&(l=u),p>c&&(c=p);g=0!==(g=Math.max(l-n,c-s))?1/g:0}return o(y,x,r,n,s,g),x}function i(t,e,r,n,i){var a,o;if(i===A(t,e,r,n)>0)for(a=e;a<r;a+=n)o=w(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=w(a,t[a],t[a+1],o);return o&&y(o,o.next)&&(k(o),o=o.next),o}function a(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!y(n,n.next)&&0!==m(n.prev,n,n.next))n=n.next;else{if(k(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function o(t,e,r,n,i,h,f){if(t){!f&&h&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=p(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,h);for(var d,g,v=t;t.prev!==t.next;)if(d=t.prev,g=t.next,h?l(t,n,i,h):s(t))e.push(d.i/r),e.push(t.i/r),e.push(g.i/r),k(t),t=g.next,v=g.next;else if((t=g)===v){f?1===f?o(t=c(t,e,r),e,r,n,i,h,2):2===f&&u(t,e,r,n,i,h):o(a(t),e,r,n,i,h,1);break}}}function s(t){var e=t.prev,r=t,n=t.next;if(m(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(g(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&m(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function l(t,e,r,n){var i=t.prev,a=t,o=t.next;if(m(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,h=p(s,l,e,r,n),f=p(c,u,e,r,n),d=t.prevZ,v=t.nextZ;d&&d.z>=h&&v&&v.z<=f;){if(d!==t.prev&&d!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&m(d.prev,d,d.next)>=0)return!1;if(d=d.prevZ,v!==t.prev&&v!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,v.x,v.y)&&m(v.prev,v,v.next)>=0)return!1;v=v.nextZ}for(;d&&d.z>=h;){if(d!==t.prev&&d!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&m(d.prev,d,d.next)>=0)return!1;d=d.prevZ}for(;v&&v.z<=f;){if(v!==t.prev&&v!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,v.x,v.y)&&m(v.prev,v,v.next)>=0)return!1;v=v.nextZ}return!0}function c(t,e,r){var n=t;do{var i=n.prev,a=n.next.next;!y(i,a)&&x(i,n,n.next,a)&&b(i,a)&&b(a,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(a.i/r),k(n),k(n.next),n=t=a),n=n.next}while(n!==t);return n}function u(t,e,r,n,i,s){var l=t;do{for(var c=l.next.next;c!==l.prev;){if(l.i!==c.i&&v(l,c)){var u=_(l,c);return l=a(l,l.next),u=a(u,u.next),o(l,e,r,n,i,s),void o(u,e,r,n,i,s)}c=c.next}l=l.next}while(l!==t)}function h(t,e){return t.x-e.x}function f(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r.prev;var l,c=r,u=r.x,h=r.y,f=1/0;n=r.next;for(;n!==c;)i>=n.x&&n.x>=u&&i!==n.x&&g(a<h?i:o,a,u,h,a<h?o:i,a,n.x,n.y)&&((l=Math.abs(a-n.y)/(i-n.x))<f||l===f&&n.x>r.x)&&b(n,t)&&(r=n,f=l),n=n.next;return r}(t,e)){var r=_(e,t);a(r,r.next)}}function p(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function d(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function g(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function v(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&x(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&b(t,e)&&b(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)}function m(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function y(t,e){return t.x===e.x&&t.y===e.y}function x(t,e,r,n){return!!(y(t,e)&&y(r,n)||y(t,n)&&y(r,e))||m(t,e,r)>0!=m(t,e,n)>0&&m(r,n,t)>0!=m(r,n,e)>0}function b(t,e){return m(t.prev,t,t.next)<0?m(t,e,t.next)>=0&&m(t,t.prev,e)>=0:m(t,e,t.prev)<0||m(t,t.next,e)<0}function _(t,e){var r=new T(t.i,t.x,t.y),n=new T(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function w(t,e,r,n){var i=new T(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function k(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function T(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function A(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}e.exports=n,e.exports.default=n,n.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(A(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(A(t,c,u,r))}var h=0;for(s=0;s<n.length;s+=3){var f=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;h+=Math.abs((t[f]-t[d])*(t[p+1]-t[f+1])-(t[f]-t[p])*(t[d+1]-t[f+1]))}return 0===o&&0===h?0:Math.abs((h-o)/o)},n.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r}},{}],493:[function(t,e,r){arguments[4][318][0].apply(r,arguments)},{\"./is-implemented\":494,\"./polyfill\":496,dup:318}],494:[function(t,e,r){arguments[4][319][0].apply(r,arguments)},{dup:319}],495:[function(t,e,r){arguments[4][320][0].apply(r,arguments)},{dup:320}],496:[function(t,e,r){arguments[4][321][0].apply(r,arguments)},{\"./is-native-implemented\":495,d:151,dup:321,\"es5-ext/object/is-value\":194,\"es5-ext/object/set-prototype-of\":200,\"es5-ext/object/valid-object\":204,\"es5-ext/object/valid-value\":205,\"es5-ext/string/random-uniq\":210,\"es6-iterator/for-of\":212,\"es6-iterator/get\":213,\"es6-symbol\":219}],497:[function(t,e,r){\"use strict\";function n(t,e){return function(t){if(Array.isArray(t))return t}(t)||function(t,e){var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{n||null==s.return||s.return()}finally{if(i)throw a}}return r}(t,e)||function(){throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")}()}function i(t){return function(t){if(Array.isArray(t)){for(var e=0,r=new Array(t.length);e<t.length;e++)r[e]=t[e];return r}}(t)||function(t){if(Symbol.iterator in Object(t)||\"[object Arguments]\"===Object.prototype.toString.call(t))return Array.from(t)}(t)||function(){throw new TypeError(\"Invalid attempt to spread non-iterable instance\")}()}var a=t(\"color-normalize\"),o=t(\"array-bounds\"),s=t(\"color-id\"),l=t(\"point-cluster\"),c=t(\"object-assign\"),u=t(\"glslify\"),h=t(\"pick-by-alias\"),f=t(\"update-diff\"),p=t(\"flatten-vertex-data\"),d=t(\"is-iexplorer\"),g=t(\"to-float32\"),v=t(\"parse-rect\"),m=y;function y(t,e){var r=this;if(!(this instanceof y))return new y(t,e);\"function\"==typeof t?(e||(e={}),e.regl=t):(e=t,t=null),e&&e.length&&(e.positions=e);var n,i=(t=e.regl)._gl,a=[];this.tooManyColors=d,n=t.texture({data:new Uint8Array(1020),width:255,height:1,type:\"uint8\",format:\"rgba\",wrapS:\"clamp\",wrapT:\"clamp\",mag:\"nearest\",min:\"nearest\"}),c(this,{regl:t,gl:i,groups:[],markerCache:[null],markerTextures:[null],palette:a,paletteIds:{},paletteTexture:n,maxColors:255,maxSize:100,canvas:i.canvas}),this.update(e);var o={uniforms:{pixelRatio:t.context(\"pixelRatio\"),palette:n,paletteSize:function(t,e){return[r.tooManyColors?0:255,n.height]},scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translate:t.prop(\"translate\"),translateFract:t.prop(\"translateFract\"),opacity:t.prop(\"opacity\"),marker:t.prop(\"markerTexture\")},attributes:{x:function(t,e){return e.xAttr||{buffer:e.positionBuffer,stride:8,offset:0}},y:function(t,e){return e.yAttr||{buffer:e.positionBuffer,stride:8,offset:4}},xFract:function(t,e){return e.xAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:0}},yFract:function(t,e){return e.yAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:4}},size:function(t,e){return e.size.length?{buffer:e.sizeBuffer,stride:2,offset:0}:{constant:[Math.round(255*e.size/r.maxSize)]}},borderSize:function(t,e){return e.borderSize.length?{buffer:e.sizeBuffer,stride:2,offset:1}:{constant:[Math.round(255*e.borderSize/r.maxSize)]}},colorId:function(t,e){return e.color.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:0}:{constant:r.tooManyColors?a.slice(4*e.color,4*e.color+4):[e.color]}},borderColorId:function(t,e){return e.borderColor.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:r.tooManyColors?4:2}:{constant:r.tooManyColors?a.slice(4*e.borderColor,4*e.borderColor+4):[e.borderColor]}},isActive:function(t,e){return!0===e.activation?{constant:[1]}:e.activation?e.activation:{constant:[0]}}},blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:{enable:!1},depth:{enable:!1},elements:t.prop(\"elements\"),count:t.prop(\"count\"),offset:t.prop(\"offset\"),primitive:\"points\"},s=c({},o);s.frag=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nuniform sampler2D marker;\\nuniform float pixelRatio, opacity;\\n\\nfloat smoothStep(float x, float y) {\\n  return 1.0 / (1.0 + exp(50.0*(x - y)));\\n}\\n\\nvoid main() {\\n  float dist = texture2D(marker, gl_PointCoord).r, delta = fragWidth;\\n\\n  // max-distance alpha\\n  if (dist < 0.003) discard;\\n\\n  // null-border case\\n  if (fragBorderColorLevel == fragColorLevel || fragBorderColor.a == 0.) {\\n    float colorAmt = smoothstep(.5 - delta, .5 + delta, dist);\\n    gl_FragColor = vec4(fragColor.rgb, colorAmt * fragColor.a * opacity);\\n  }\\n  else {\\n    float borderColorAmt = smoothstep(fragBorderColorLevel - delta, fragBorderColorLevel + delta, dist);\\n    float colorAmt = smoothstep(fragColorLevel - delta, fragColorLevel + delta, dist);\\n\\n    vec4 color = fragBorderColor;\\n    color.a *= borderColorAmt;\\n    color = mix(color, fragColor, colorAmt);\\n    color.a *= opacity;\\n\\n    gl_FragColor = color;\\n  }\\n\\n}\\n\"]),s.vert=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract, paletteSize;\\nuniform float pixelRatio;\\nuniform sampler2D palette;\\n\\nconst float maxSize = 100.;\\nconst float borderLevel = .5;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragPointSize, fragBorderRadius, fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = 2. * size * pixelRatio;\\n  fragPointSize = size * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\n  fragColor = color;\\n  fragBorderColor = borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n\\n  fragBorderColorLevel = clamp(borderLevel - borderLevel * borderSize / size, 0., 1.);\\n  fragColorLevel = clamp(borderLevel + (1. - borderLevel) * borderSize / size, 0., 1.);\\n}\"]),this.drawMarker=t(s);var l=c({},o);l.frag=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\n\\nuniform float opacity;\\nvarying float fragBorderRadius, fragWidth;\\n\\nfloat smoothStep(float edge0, float edge1, float x) {\\n\\tfloat t;\\n\\tt = clamp((x - edge0) / (edge1 - edge0), 0.0, 1.0);\\n\\treturn t * t * (3.0 - 2.0 * t);\\n}\\n\\nvoid main() {\\n\\tfloat radius, alpha = 1.0, delta = fragWidth;\\n\\n\\tradius = length(2.0 * gl_PointCoord.xy - 1.0);\\n\\n\\tif (radius > 1.0 + delta) {\\n\\t\\tdiscard;\\n\\t}\\n\\n\\talpha -= smoothstep(1.0 - delta, 1.0 + delta, radius);\\n\\n\\tfloat borderRadius = fragBorderRadius;\\n\\tfloat ratio = smoothstep(borderRadius - delta, borderRadius + delta, radius);\\n\\tvec4 color = mix(fragColor, fragBorderColor, ratio);\\n\\tcolor.a *= alpha * opacity;\\n\\tgl_FragColor = color;\\n}\\n\"]),l.vert=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio;\\nuniform sampler2D palette;\\nuniform vec2 paletteSize;\\n\\nconst float maxSize = 100.;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragBorderRadius, fragWidth;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  // ignore inactive points\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = (size + borderSize) * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\n  fragBorderRadius = 1. - 2. * borderSize / (size + borderSize);\\n  fragColor = color;\\n  fragBorderColor = borderColor.a == 0. || borderSize == 0. ? vec4(color.rgb, 0.) : borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n}\\n\"]),d&&(l.frag=l.frag.replace(\"smoothstep\",\"smoothStep\"),s.frag=s.frag.replace(\"smoothstep\",\"smoothStep\")),this.drawCircle=t(l)}y.defaults={color:\"black\",borderColor:\"transparent\",borderSize:0,size:12,opacity:1,marker:void 0,viewport:null,range:null,pixelSize:null,count:0,offset:0,bounds:null,positions:[],snap:1e4},y.prototype.render=function(){return arguments.length&&this.update.apply(this,arguments),this.draw(),this},y.prototype.draw=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var i=this.groups;if(1===r.length&&Array.isArray(r[0])&&(null===r[0][0]||Array.isArray(r[0][0]))&&(r=r[0]),this.regl._refresh(),r.length)for(var a=0;a<r.length;a++)this.drawItem(a,r[a]);else i.forEach(function(e,r){t.drawItem(r)});return this},y.prototype.drawItem=function(t,e){var r=this.groups,n=r[t];if(\"number\"==typeof e&&(t=e,n=r[e],e=null),n&&n.count&&n.opacity){n.activation[0]&&this.drawCircle(this.getMarkerDrawOptions(0,n,e));for(var a=[],o=1;o<n.activation.length;o++)n.activation[o]&&(!0===n.activation[o]||n.activation[o].data.length)&&a.push.apply(a,i(this.getMarkerDrawOptions(o,n,e)));a.length&&this.drawMarker(a)}},y.prototype.getMarkerDrawOptions=function(t,e,r){var i=e.range,a=e.tree,o=e.viewport,s=e.activation,l=e.selectionBuffer,u=e.count;this.regl;if(!a)return r?[c({},e,{markerTexture:this.markerTextures[t],activation:s[t],count:r.length,elements:r,offset:0})]:[c({},e,{markerTexture:this.markerTextures[t],activation:s[t],offset:0})];var h=[],f=a.range(i,{lod:!0,px:[(i[2]-i[0])/o.width,(i[3]-i[1])/o.height]});if(r){for(var p=s[t].data,d=new Uint8Array(u),g=0;g<r.length;g++){var v=r[g];d[v]=p?p[v]:1}l.subdata(d)}for(var m=f.length;m--;){var y=n(f[m],2),x=y[0],b=y[1];h.push(c({},e,{markerTexture:this.markerTextures[t],activation:r?l:s[t],offset:x,count:b-x}))}return h},y.prototype.update=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];if(r.length){1===r.length&&Array.isArray(r[0])&&(r=r[0]);var i=this.groups,a=this.gl,s=this.regl,u=this.maxSize,d=this.maxColors,m=this.palette;this.groups=i=r.map(function(e,r){var n=i[r];if(void 0===e)return n;null===e?e={positions:null}:\"function\"==typeof e?e={ondraw:e}:\"number\"==typeof e[0]&&(e={positions:e}),null===(e=h(e,{positions:\"positions data points\",snap:\"snap cluster lod tree\",size:\"sizes size radius\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",color:\"colors color fill fill-color fillColor\",borderColor:\"borderColors borderColor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range dataBox databox\",viewport:\"viewport viewPort viewBox viewbox\",opacity:\"opacity alpha transparency\",bounds:\"bound bounds boundaries limits\",tooManyColors:\"tooManyColors palette paletteMode optimizePalette enablePalette\"})).positions&&(e.positions=[]),null!=e.tooManyColors&&(t.tooManyColors=e.tooManyColors),n||(i[r]=n={id:r,scale:null,translate:null,scaleFract:null,translateFract:null,activation:[],selectionBuffer:s.buffer({data:new Uint8Array(0),usage:\"stream\",type:\"uint8\"}),sizeBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),colorBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),positionBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"}),positionFractBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"})},e=c({},y.defaults,e)),!e.positions||\"marker\"in e||(e.marker=n.marker,delete n.marker),!e.marker||\"positions\"in e||(e.positions=n.positions,delete n.positions);var x=0,b=0;if(f(n,e,[{snap:!0,size:function(t,e){return null==t&&(t=y.defaults.size),x+=t&&t.length?1:0,t},borderSize:function(t,e){return null==t&&(t=y.defaults.borderSize),x+=t&&t.length?1:0,t},opacity:parseFloat,color:function(e,r){return null==e&&(e=y.defaults.color),e=t.updateColor(e),b++,e},borderColor:function(e,r){return null==e&&(e=y.defaults.borderColor),e=t.updateColor(e),b++,e},bounds:function(t,e,r){return\"range\"in r||(r.range=null),t},positions:function(t,e,r){var n=e.snap,i=e.positionBuffer,a=e.positionFractBuffer,c=e.selectionBuffer;if(t.x||t.y)return t.x.length?e.xAttr={buffer:s.buffer(t.x),offset:0,stride:4,count:t.x.length}:e.xAttr={buffer:t.x.buffer,offset:4*t.x.offset||0,stride:4*(t.x.stride||1),count:t.x.count},t.y.length?e.yAttr={buffer:s.buffer(t.y),offset:0,stride:4,count:t.y.length}:e.yAttr={buffer:t.y.buffer,offset:4*t.y.offset||0,stride:4*(t.y.stride||1),count:t.y.count},e.count=Math.max(e.xAttr.count,e.yAttr.count),t;t=p(t,\"float64\");var u=e.count=Math.floor(t.length/2),h=e.bounds=u?o(t,2):null;if(r.range||e.range||(delete e.range,r.range=h),r.marker||e.marker||(delete e.marker,r.marker=null),n&&(!0===n||u>n)?e.tree=l(t,{bounds:h}):n&&n.length&&(e.tree=n),e.tree){var f={primitive:\"points\",usage:\"static\",data:e.tree,type:\"uint32\"};e.elements?e.elements(f):e.elements=s.elements(f)}return i({data:g.float(t),usage:\"dynamic\"}),a({data:g.fract(t),usage:\"dynamic\"}),c({data:new Uint8Array(u),type:\"uint8\",usage:\"stream\"}),t}},{marker:function(e,r,n){var i=r.activation;if(i.forEach(function(t){return t&&t.destroy&&t.destroy()}),i.length=0,e&&\"number\"!=typeof e[0]){for(var a=[],o=0,l=Math.min(e.length,r.count);o<l;o++){var c=t.addMarker(e[o]);a[c]||(a[c]=new Uint8Array(r.count)),a[c][o]=1}for(var u=0;u<a.length;u++)if(a[u]){var h={data:a[u],type:\"uint8\",usage:\"static\"};i[u]?i[u](h):i[u]=s.buffer(h),i[u].data=a[u]}}else{i[t.addMarker(e)]=!0}return e},range:function(t,e,r){var n=e.bounds;if(n)return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=g.fract(e.scale),e.translateFract=g.fract(e.translate),t},viewport:function(t){return v(t||[a.drawingBufferWidth,a.drawingBufferHeight])}}]),x){var _=n,w=_.count,k=_.size,T=_.borderSize,A=_.sizeBuffer,M=new Uint8Array(2*w);if(k.length||T.length)for(var S=0;S<w;S++)M[2*S]=Math.round(255*(null==k[S]?k:k[S])/u),M[2*S+1]=Math.round(255*(null==T[S]?T:T[S])/u);A({data:M,usage:\"dynamic\"})}if(b){var E,C=n,L=C.count,P=C.color,O=C.borderColor,z=C.colorBuffer;if(t.tooManyColors){if(P.length||O.length){E=new Uint8Array(8*L);for(var I=0;I<L;I++){var D=P[I];E[8*I]=m[4*D],E[8*I+1]=m[4*D+1],E[8*I+2]=m[4*D+2],E[8*I+3]=m[4*D+3];var R=O[I];E[8*I+4]=m[4*R],E[8*I+5]=m[4*R+1],E[8*I+6]=m[4*R+2],E[8*I+7]=m[4*R+3]}}}else if(P.length||O.length){E=new Uint8Array(4*L+2);for(var F=0;F<L;F++)null!=P[F]&&(E[4*F]=P[F]%d,E[4*F+1]=Math.floor(P[F]/d)),null!=O[F]&&(E[4*F+2]=O[F]%d,E[4*F+3]=Math.floor(O[F]/d))}z({data:E||new Uint8Array(0),type:\"uint8\",usage:\"dynamic\"})}return n})}},y.prototype.addMarker=function(t){var e,r=this.markerTextures,n=this.regl,i=this.markerCache,a=null==t?0:i.indexOf(t);if(a>=0)return a;if(t instanceof Uint8Array||t instanceof Uint8ClampedArray)e=t;else{e=new Uint8Array(t.length);for(var o=0,s=t.length;o<s;o++)e[o]=255*t[o]}var l=Math.floor(Math.sqrt(e.length));return a=r.length,i.push(t),r.push(n.texture({channels:1,data:e,radius:l,mag:\"linear\",min:\"linear\"})),a},y.prototype.updateColor=function(t){var e=this.paletteIds,r=this.palette,n=this.maxColors;Array.isArray(t)||(t=[t]);var i=[];if(\"number\"==typeof t[0]){var o=[];if(Array.isArray(t))for(var l=0;l<t.length;l+=4)o.push(t.slice(l,l+4));else for(var c=0;c<t.length;c+=4)o.push(t.subarray(c,c+4));t=o}for(var u=0;u<t.length;u++){var h=t[u];h=a(h,\"uint8\");var f=s(h,!1);if(null==e[f]){var p=r.length;e[f]=Math.floor(p/4),r[p]=h[0],r[p+1]=h[1],r[p+2]=h[2],r[p+3]=h[3]}i[u]=e[f]}return!this.tooManyColors&&r.length>4*n&&(this.tooManyColors=!0),this.updatePalette(r),1===i.length?i[0]:i},y.prototype.updatePalette=function(t){if(!this.tooManyColors){var e=this.maxColors,r=this.paletteTexture,n=Math.ceil(.25*t.length/e);if(n>1)for(var i=.25*(t=t.slice()).length%e;i<n*e;i++)t.push(0,0,0,0);r.height<n&&r.resize(e,n),r.subimage({width:Math.min(.25*t.length,e),height:n,data:t},0,0)}},y.prototype.destroy=function(){return this.groups.forEach(function(t){t.sizeBuffer.destroy(),t.positionBuffer.destroy(),t.positionFractBuffer.destroy(),t.colorBuffer.destroy(),t.activation.forEach(function(t){return t&&t.destroy&&t.destroy()}),t.selectionBuffer.destroy(),t.elements&&t.elements.destroy()}),this.groups.length=0,this.paletteTexture.destroy(),this.markerTextures.forEach(function(t){return t&&t.destroy&&t.destroy()}),this};var x=t(\"object-assign\");e.exports=function(t,e){var r=new m(t,e),n=r.render.bind(r);return x(n,{render:n,update:r.update.bind(r),draw:r.draw.bind(r),destroy:r.destroy.bind(r),regl:r.regl,gl:r.gl,canvas:r.gl.canvas,groups:r.groups,markers:r.markerCache,palette:r.palette}),n}},{\"array-bounds\":65,\"color-id\":118,\"color-normalize\":120,\"flatten-vertex-data\":227,glslify:409,\"is-iexplorer\":419,\"object-assign\":454,\"parse-rect\":459,\"pick-by-alias\":465,\"point-cluster\":499,\"to-float32\":538,\"update-diff\":549}],498:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],499:[function(t,e,r){\"use strict\";e.exports=t(\"./quad\")},{\"./quad\":500}],500:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"clamp\"),a=t(\"parse-rect\"),o=t(\"array-bounds\"),s=t(\"pick-by-alias\"),l=t(\"defined\"),c=t(\"flatten-vertex-data\"),u=t(\"is-obj\"),h=t(\"dtype\"),f=t(\"math-log2\"),p=1073741824;function d(t,e){for(var r=e[0],n=e[1],a=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=i((t[2*l]-r)*a,0,1),s[2*l+1]=i((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,\"float64\"),e=s(e,{bounds:\"range bounds dataBox databox\",maxDepth:\"depth maxDepth maxdepth level maxLevel maxlevel levels\",dtype:\"type dtype format out dst output destination\"});var r=l(e.maxDepth,255),i=l(e.bounds,o(t,2));i[0]===i[2]&&i[2]++,i[1]===i[3]&&i[3]++;var g,v=d(t,i),m=t.length>>>1;e.dtype||(e.dtype=\"array\"),\"string\"==typeof e.dtype?g=new(h(e.dtype))(m):e.dtype&&(g=e.dtype,Array.isArray(g)&&(g.length=m));for(var y=0;y<m;++y)g[y]=y;var x=[],b=[],_=[],w=[];!function t(e,n,i,a,o,s){if(!a.length)return null;var l=x[o]||(x[o]=[]);var c=_[o]||(_[o]=[]);var u=b[o]||(b[o]=[]);var h=l.length;o++;if(o>r||s>p){for(var f=0;f<a.length;f++)l.push(a[f]),c.push(s),u.push(null,null,null,null);return h}l.push(a[0]);c.push(s);if(a.length<=1)return u.push(null,null,null,null),h;var d=.5*i;var g=e+d,m=n+d;var y=[],w=[],k=[],T=[];for(var A=1,M=a.length;A<M;A++){var S=a[A],E=v[2*S],C=v[2*S+1];E<g?C<m?y.push(S):w.push(S):C<m?k.push(S):T.push(S)}s<<=2;u.push(t(e,n,d,y,o,s),t(e,m,d,w,o,s+1),t(g,n,d,k,o,s+2),t(g,m,d,T,o,s+3));return h}(0,0,1,g,0,1);for(var k=0,T=0;T<x.length;T++){var A=x[T];if(g.set)g.set(A,k);else for(var M=0,S=A.length;M<S;M++)g[M+k]=A[M];var E=k+x[T].length;w[T]=[k,E],k=E}return g.range=function(){var e,r=[],o=arguments.length;for(;o--;)r[o]=arguments[o];if(u(r[r.length-1])){var c=r.pop();r.length||null==c.x&&null==c.l&&null==c.left||(r=[c],e={}),e=s(c,{level:\"level maxLevel\",d:\"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize\",lod:\"lod details ranges offsets\"})}else e={};r.length||(r=i);var h=a.apply(void 0,r),p=[Math.min(h.x,h.x+h.width),Math.min(h.y,h.y+h.height),Math.max(h.x,h.x+h.width),Math.max(h.y,h.y+h.height)],g=p[0],v=p[1],m=p[2],y=p[3],k=d([g,v,m,y],i),T=k[0],A=k[1],M=k[2],S=k[3],E=l(e.level,x.length);if(null!=e.d){var L;\"number\"==typeof e.d?L=[e.d,e.d]:e.d.length&&(L=e.d),E=Math.min(Math.max(Math.ceil(-f(Math.abs(L[0])/(i[2]-i[0]))),Math.ceil(-f(Math.abs(L[1])/(i[3]-i[1])))),E)}if(E=Math.min(E,x.length),e.lod)return function(t,e,r,i,a){for(var o=[],s=0;s<a;s++){var l=_[s],c=w[s][0],u=C(t,e,s),h=C(r,i,s),f=n.ge(l,u),p=n.gt(l,h,f,l.length-1);o[s]=[f+c,p+c]}return o}(T,A,M,S,E);var P=[];return function e(r,n,i,a,o,s){if(null!==o&&null!==s){var l=r+i,c=n+i;if(!(T>l||A>c||M<r||S<n||a>=E||o===s)){var u=x[a];void 0===s&&(s=u.length);for(var h=o;h<s;h++){var f=u[h],p=t[2*f],d=t[2*f+1];p>=g&&p<=m&&d>=v&&d<=y&&P.push(f)}var _=b[a],w=_[4*o+0],k=_[4*o+1],C=_[4*o+2],L=_[4*o+3],O=function(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}(_,o+1),z=.5*i,I=a+1;e(r,n,z,I,w,k||C||L||O),e(r,n+z,z,I,k,C||L||O),e(r+z,n,z,I,C,L||O),e(r+z,n+z,z,I,L,O)}}}(0,0,1,0,0,1),P},g;function C(t,e,r){for(var n=1,i=.5,a=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<i?e<a?0:1:e<a?2:3,o*=.5,i+=t<i?-o:o,a+=e<a?-o:o;return n}}},{\"array-bounds\":65,\"binary-search-bounds\":498,clamp:115,defined:164,dtype:169,\"flatten-vertex-data\":227,\"is-obj\":421,\"math-log2\":432,\"parse-rect\":459,\"pick-by-alias\":465}],501:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"pick-by-alias\"),a=t(\"array-bounds\"),o=t(\"raf\"),s=t(\"array-range\"),l=t(\"parse-rect\"),c=t(\"flatten-vertex-data\");function u(t,e){if(!(this instanceof u))return new u(t,e);this.traces=[],this.passes={},this.regl=t,this.scatter=n(t),this.canvas=this.scatter.canvas}function h(t,e,r){return(null!=t.id?t.id:t)<<16|(255&e)<<8|255&r}function f(t,e,r){var n,i,a,o,s=t[e],l=t[r];return s.length>2?(s[0],s[2],n=s[1],i=s[3]):s.length?(n=s[0],i=s[1]):(s.x,n=s.y,s.x+s.width,i=s.y+s.height),l.length>2?(a=l[0],o=l[2],l[1],l[3]):l.length?(a=l[0],o=l[1]):(a=l.x,l.y,o=l.x+l.width,l.y+l.height),[a,n,o,i]}function p(t){if(\"number\"==typeof t)return[t,t,t,t];if(2===t.length)return[t[0],t[1],t[0],t[1]];var e=l(t);return[e.x,e.y,e.x+e.width,e.y+e.height]}e.exports=u,u.prototype.render=function(){for(var t,e=this,r=[],n=arguments.length;n--;)r[n]=arguments[n];return r.length&&(t=this).update.apply(t,r),this.regl.attributes.preserveDrawingBuffer?this.draw():(this.dirty?null==this.planned&&(this.planned=o(function(){e.draw(),e.dirty=!0,e.planned=null})):(this.draw(),this.dirty=!0,o(function(){e.dirty=!1})),this)},u.prototype.update=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=0;n<e.length;n++)this.updateItem(n,e[n]);this.traces=this.traces.filter(Boolean);for(var i=[],a=0,o=0;o<this.traces.length;o++){for(var s=this.traces[o],l=this.traces[o].passes,c=0;c<l.length;c++)i.push(this.passes[l[c]]);s.passOffset=a,a+=s.passes.length}return(t=this.scatter).update.apply(t,i),this}},u.prototype.updateItem=function(t,e){var r=this.regl;if(null===e)return this.traces[t]=null,this;if(!e)return this;var n,o=i(e,{data:\"data items columns rows values dimensions samples x\",snap:\"snap cluster\",size:\"sizes size radius\",color:\"colors color fill fill-color fillColor\",opacity:\"opacity alpha transparency opaque\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",borderColor:\"borderColors borderColor bordercolor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range ranges databox dataBox\",viewport:\"viewport viewBox viewbox\",domain:\"domain domains area areas\",padding:\"pad padding paddings pads margin margins\",transpose:\"transpose transposed\",diagonal:\"diagonal diag showDiagonal\",upper:\"upper up top upperhalf upperHalf showupperhalf showUpper showUpperHalf\",lower:\"lower low bottom lowerhalf lowerHalf showlowerhalf showLowerHalf showLower\"}),s=this.traces[t]||(this.traces[t]={id:t,buffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),color:\"black\",marker:null,size:12,borderColor:\"transparent\",borderSize:1,viewport:l([r._gl.drawingBufferWidth,r._gl.drawingBufferHeight]),padding:[0,0,0,0],opacity:1,diagonal:!0,upper:!0,lower:!0});if(null!=o.color&&(s.color=o.color),null!=o.size&&(s.size=o.size),null!=o.marker&&(s.marker=o.marker),null!=o.borderColor&&(s.borderColor=o.borderColor),null!=o.borderSize&&(s.borderSize=o.borderSize),null!=o.opacity&&(s.opacity=o.opacity),o.viewport&&(s.viewport=l(o.viewport)),null!=o.diagonal&&(s.diagonal=o.diagonal),null!=o.upper&&(s.upper=o.upper),null!=o.lower&&(s.lower=o.lower),o.data){s.buffer(c(o.data)),s.columns=o.data.length,s.count=o.data[0].length,s.bounds=[];for(var u=0;u<s.columns;u++)s.bounds[u]=a(o.data[u],1)}o.range&&(s.range=o.range,n=s.range&&\"number\"!=typeof s.range[0]),o.domain&&(s.domain=o.domain);var d=!1;null!=o.padding&&(Array.isArray(o.padding)&&o.padding.length===s.columns&&\"number\"==typeof o.padding[o.padding.length-1]?(s.padding=o.padding.map(p),d=!0):s.padding=p(o.padding));var g=s.columns,v=s.count,m=s.viewport.width,y=s.viewport.height,x=s.viewport.x,b=s.viewport.y,_=m/g,w=y/g;s.passes=[];for(var k=0;k<g;k++)for(var T=0;T<g;T++)if((s.diagonal||T!==k)&&(s.upper||!(k>T))&&(s.lower||!(k<T))){var A=h(s.id,k,T),M=this.passes[A]||(this.passes[A]={});if(o.data&&(o.transpose?M.positions={x:{buffer:s.buffer,offset:T,count:v,stride:g},y:{buffer:s.buffer,offset:k,count:v,stride:g}}:M.positions={x:{buffer:s.buffer,offset:T*v,count:v},y:{buffer:s.buffer,offset:k*v,count:v}},M.bounds=f(s.bounds,k,T)),o.domain||o.viewport||o.data){var S=d?f(s.padding,k,T):s.padding;if(s.domain){var E=f(s.domain,k,T),C=E[0],L=E[1],P=E[2],O=E[3];M.viewport=[x+C*m+S[0],b+L*y+S[1],x+P*m-S[2],b+O*y-S[3]]}else M.viewport=[x+T*_+_*S[0],b+k*w+w*S[1],x+(T+1)*_-_*S[2],b+(k+1)*w-w*S[3]]}o.color&&(M.color=s.color),o.size&&(M.size=s.size),o.marker&&(M.marker=s.marker),o.borderSize&&(M.borderSize=s.borderSize),o.borderColor&&(M.borderColor=s.borderColor),o.opacity&&(M.opacity=s.opacity),o.range&&(M.range=n?f(s.range,k,T):s.range||M.bounds),s.passes.push(A)}return this},u.prototype.draw=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=[],i=0;i<e.length;i++)if(\"number\"==typeof e[i]){var a=this.traces[e[i]],o=a.passes,l=a.passOffset;n.push.apply(n,s(l,l+o.length))}else if(e[i].length){var c=e[i],u=this.traces[i],h=u.passes,f=u.passOffset;h=h.map(function(t,e){n[f+e]=c})}(t=this.scatter).draw.apply(t,n)}else this.scatter.draw();return this},u.prototype.destroy=function(){return this.traces.forEach(function(t){t.buffer&&t.buffer.destroy&&t.buffer.destroy()}),this.traces=null,this.passes=null,this.scatter.destroy(),this}},{\"array-bounds\":65,\"array-range\":67,\"flatten-vertex-data\":227,\"parse-rect\":459,\"pick-by-alias\":465,raf:484,\"regl-scatter2d\":497}],502:[function(t,e,r){var n,i;n=this,i=function(){function t(t,e){this.id=U++,this.type=t,this.data=e}function e(t){return\"[\"+function t(e){if(0===e.length)return[];var r=e.charAt(0),n=e.charAt(e.length-1);if(1<e.length&&r===n&&('\"'===r||\"'\"===r))return['\"'+e.substr(1,e.length-2).replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];if(r=/\\[(false|true|null|\\d+|'[^']*'|\"[^\"]*\")\\]/.exec(e))return t(e.substr(0,r.index)).concat(t(r[1])).concat(t(e.substr(r.index+r[0].length)));if(1===(r=e.split(\".\")).length)return['\"'+e.replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];for(e=[],n=0;n<r.length;++n)e=e.concat(t(r[n]));return e}(t).join(\"][\")+\"]\"}function r(t){return\"string\"==typeof t?t.split():t}function n(t){return\"string\"==typeof t?document.querySelector(t):t}function i(t){var e,i,a,o,s=t||{};t={};var l=[],c=[],u=\"undefined\"==typeof window?1:window.devicePixelRatio,h=!1,f=function(t){},p=function(){};if(\"string\"==typeof s?e=document.querySelector(s):\"object\"==typeof s&&(\"string\"==typeof s.nodeName&&\"function\"==typeof s.appendChild&&\"function\"==typeof s.getBoundingClientRect?e=s:\"function\"==typeof s.drawArrays||\"function\"==typeof s.drawElements?a=(o=s).canvas:(\"gl\"in s?o=s.gl:\"canvas\"in s?a=n(s.canvas):\"container\"in s&&(i=n(s.container)),\"attributes\"in s&&(t=s.attributes),\"extensions\"in s&&(l=r(s.extensions)),\"optionalExtensions\"in s&&(c=r(s.optionalExtensions)),\"onDone\"in s&&(f=s.onDone),\"profile\"in s&&(h=!!s.profile),\"pixelRatio\"in s&&(u=+s.pixelRatio))),e&&(\"canvas\"===e.nodeName.toLowerCase()?a=e:i=e),!o){if(!a){if(!(e=function(t,e,r){function n(){var e=window.innerWidth,n=window.innerHeight;t!==document.body&&(e=(n=t.getBoundingClientRect()).right-n.left,n=n.bottom-n.top),i.width=r*e,i.height=r*n,j(i.style,{width:e+\"px\",height:n+\"px\"})}var i=document.createElement(\"canvas\");return j(i.style,{border:0,margin:0,padding:0,top:0,left:0}),t.appendChild(i),t===document.body&&(i.style.position=\"absolute\",j(t.style,{margin:0,padding:0})),window.addEventListener(\"resize\",n,!1),n(),{canvas:i,onDestroy:function(){window.removeEventListener(\"resize\",n),t.removeChild(i)}}}(i||document.body,0,u)))return null;a=e.canvas,p=e.onDestroy}o=function(t,e){function r(r){try{return t.getContext(r,e)}catch(t){return null}}return r(\"webgl\")||r(\"experimental-webgl\")||r(\"webgl-experimental\")}(a,t)}return o?{gl:o,canvas:a,container:i,extensions:l,optionalExtensions:c,pixelRatio:u,profile:h,onDone:f,onDestroy:p}:(p(),f(\"webgl not supported, try upgrading your browser or graphics drivers http://get.webgl.org\"),null)}function a(t,e){for(var r=Array(t),n=0;n<t;++n)r[n]=e(n);return r}function o(t){var e,r;return e=(65535<t)<<4,e|=r=(255<(t>>>=e))<<3,(e|=r=(15<(t>>>=r))<<2)|(r=(3<(t>>>=r))<<1)|t>>>r>>1}function s(){function t(t){t:{for(var e=16;268435456>=e;e*=16)if(t<=e){t=e;break t}t=0}return 0<(e=r[o(t)>>2]).length?e.pop():new ArrayBuffer(t)}function e(t){r[o(t.byteLength)>>2].push(t)}var r=a(8,function(){return[]});return{alloc:t,free:e,allocType:function(e,r){var n=null;switch(e){case 5120:n=new Int8Array(t(r),0,r);break;case 5121:n=new Uint8Array(t(r),0,r);break;case 5122:n=new Int16Array(t(2*r),0,r);break;case 5123:n=new Uint16Array(t(2*r),0,r);break;case 5124:n=new Int32Array(t(4*r),0,r);break;case 5125:n=new Uint32Array(t(4*r),0,r);break;case 5126:n=new Float32Array(t(4*r),0,r);break;default:return null}return n.length!==r?n.subarray(0,r):n},freeType:function(t){e(t.buffer)}}}function l(t){return!!t&&\"object\"==typeof t&&Array.isArray(t.shape)&&Array.isArray(t.stride)&&\"number\"==typeof t.offset&&t.shape.length===t.stride.length&&(Array.isArray(t.data)||W(t.data))}function c(t,e,r,n,i,a){for(var o=0;o<e;++o)for(var s=t[o],l=0;l<r;++l)for(var c=s[l],u=0;u<n;++u)i[a++]=c[u]}function u(t){return 0|J[Object.prototype.toString.call(t)]}function h(t,e){for(var r=0;r<e.length;++r)t[r]=e[r]}function f(t,e,r,n,i,a,o){for(var s=0,l=0;l<r;++l)for(var c=0;c<n;++c)t[s++]=e[i*l+a*c+o]}function p(t,e,r,n){function i(e){this.id=c++,this.buffer=t.createBuffer(),this.type=e,this.usage=35044,this.byteLength=0,this.dimension=1,this.dtype=5121,this.persistentData=null,r.profile&&(this.stats={size:0})}function a(e,r,n){e.byteLength=r.byteLength,t.bufferData(e.type,r,n)}function o(t,e,r,n,i,o){if(t.usage=r,Array.isArray(e)){if(t.dtype=n||5126,0<e.length)if(Array.isArray(e[0])){i=tt(e);for(var s=n=1;s<i.length;++s)n*=i[s];t.dimension=n,a(t,e=Q(e,i,t.dtype),r),o?t.persistentData=e:G.freeType(e)}else\"number\"==typeof e[0]?(t.dimension=i,h(i=G.allocType(t.dtype,e.length),e),a(t,i,r),o?t.persistentData=i:G.freeType(i)):W(e[0])&&(t.dimension=e[0].length,t.dtype=n||u(e[0])||5126,a(t,e=Q(e,[e.length,e[0].length],t.dtype),r),o?t.persistentData=e:G.freeType(e))}else if(W(e))t.dtype=n||u(e),t.dimension=i,a(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e.buffer)));else if(l(e)){i=e.shape;var c=e.stride,p=(s=e.offset,0),d=0,g=0,v=0;1===i.length?(p=i[0],d=1,g=c[0],v=0):2===i.length&&(p=i[0],d=i[1],g=c[0],v=c[1]),t.dtype=n||u(e.data)||5126,t.dimension=d,f(i=G.allocType(t.dtype,p*d),e.data,p,d,g,v,s),a(t,i,r),o?t.persistentData=i:G.freeType(i)}}function s(r){e.bufferCount--;for(var i=0;i<n.state.length;++i){var a=n.state[i];a.buffer===r&&(t.disableVertexAttribArray(i),a.buffer=null)}t.deleteBuffer(r.buffer),r.buffer=null,delete p[r.id]}var c=0,p={};i.prototype.bind=function(){t.bindBuffer(this.type,this.buffer)},i.prototype.destroy=function(){s(this)};var d=[];return r.profile&&(e.getTotalBufferSize=function(){var t=0;return Object.keys(p).forEach(function(e){t+=p[e].stats.size}),t}),{create:function(n,a,c,d){function g(e){var n=35044,i=null,a=0,s=0,c=1;return Array.isArray(e)||W(e)||l(e)?i=e:\"number\"==typeof e?a=0|e:e&&(\"data\"in e&&(i=e.data),\"usage\"in e&&(n=$[e.usage]),\"type\"in e&&(s=K[e.type]),\"dimension\"in e&&(c=0|e.dimension),\"length\"in e&&(a=0|e.length)),v.bind(),i?o(v,i,n,s,c,d):(a&&t.bufferData(v.type,a,n),v.dtype=s||5121,v.usage=n,v.dimension=c,v.byteLength=a),r.profile&&(v.stats.size=v.byteLength*et[v.dtype]),g}e.bufferCount++;var v=new i(a);return p[v.id]=v,c||g(n),g._reglType=\"buffer\",g._buffer=v,g.subdata=function(e,r){var n,i=0|(r||0);if(v.bind(),W(e))t.bufferSubData(v.type,i,e);else if(Array.isArray(e)){if(0<e.length)if(\"number\"==typeof e[0]){var a=G.allocType(v.dtype,e.length);h(a,e),t.bufferSubData(v.type,i,a),G.freeType(a)}else(Array.isArray(e[0])||W(e[0]))&&(n=tt(e),a=Q(e,n,v.dtype),t.bufferSubData(v.type,i,a),G.freeType(a))}else if(l(e)){n=e.shape;var o=e.stride,s=a=0,c=0,p=0;1===n.length?(a=n[0],s=1,c=o[0],p=0):2===n.length&&(a=n[0],s=n[1],c=o[0],p=o[1]),n=Array.isArray(e.data)?v.dtype:u(e.data),f(n=G.allocType(n,a*s),e.data,a,s,c,p,e.offset),t.bufferSubData(v.type,i,n),G.freeType(n)}return g},r.profile&&(g.stats=v.stats),g.destroy=function(){s(v)},g},createStream:function(t,e){var r=d.pop();return r||(r=new i(t)),r.bind(),o(r,e,35040,0,1,!1),r},destroyStream:function(t){d.push(t)},clear:function(){X(p).forEach(s),d.forEach(s)},getBuffer:function(t){return t&&t._buffer instanceof i?t._buffer:null},restore:function(){X(p).forEach(function(e){e.buffer=t.createBuffer(),t.bindBuffer(e.type,e.buffer),t.bufferData(e.type,e.persistentData||e.byteLength,e.usage)})},_initBuffer:o}}function d(t,e,r,n){function i(t){this.id=c++,s[this.id]=this,this.buffer=t,this.primType=4,this.type=this.vertCount=0}function a(n,i,a,o,s,c,u){if(n.buffer.bind(),i){var h=u;u||W(i)&&(!l(i)||W(i.data))||(h=e.oes_element_index_uint?5125:5123),r._initBuffer(n.buffer,i,a,h,3)}else t.bufferData(34963,c,a),n.buffer.dtype=h||5121,n.buffer.usage=a,n.buffer.dimension=3,n.buffer.byteLength=c;if(h=u,!u){switch(n.buffer.dtype){case 5121:case 5120:h=5121;break;case 5123:case 5122:h=5123;break;case 5125:case 5124:h=5125}n.buffer.dtype=h}n.type=h,0>(i=s)&&(i=n.buffer.byteLength,5123===h?i>>=1:5125===h&&(i>>=2)),n.vertCount=i,i=o,0>o&&(i=4,1===(o=n.buffer.dimension)&&(i=0),2===o&&(i=1),3===o&&(i=4)),n.primType=i}function o(t){n.elementsCount--,delete s[t.id],t.buffer.destroy(),t.buffer=null}var s={},c=0,u={uint8:5121,uint16:5123};e.oes_element_index_uint&&(u.uint32=5125),i.prototype.bind=function(){this.buffer.bind()};var h=[];return{create:function(t,e){function s(t){if(t)if(\"number\"==typeof t)c(t),h.primType=4,h.vertCount=0|t,h.type=5121;else{var e=null,r=35044,n=-1,i=-1,o=0,f=0;Array.isArray(t)||W(t)||l(t)?e=t:(\"data\"in t&&(e=t.data),\"usage\"in t&&(r=$[t.usage]),\"primitive\"in t&&(n=rt[t.primitive]),\"count\"in t&&(i=0|t.count),\"type\"in t&&(f=u[t.type]),\"length\"in t?o=0|t.length:(o=i,5123===f||5122===f?o*=2:5125!==f&&5124!==f||(o*=4))),a(h,e,r,n,i,o,f)}else c(),h.primType=4,h.vertCount=0,h.type=5121;return s}var c=r.create(null,34963,!0),h=new i(c._buffer);return n.elementsCount++,s(t),s._reglType=\"elements\",s._elements=h,s.subdata=function(t,e){return c.subdata(t,e),s},s.destroy=function(){o(h)},s},createStream:function(t){var e=h.pop();return e||(e=new i(r.create(null,34963,!0,!1)._buffer)),a(e,t,35040,-1,-1,0,0),e},destroyStream:function(t){h.push(t)},getElements:function(t){return\"function\"==typeof t&&t._elements instanceof i?t._elements:null},clear:function(){X(s).forEach(o)}}}function g(t){for(var e=G.allocType(5123,t.length),r=0;r<t.length;++r)if(isNaN(t[r]))e[r]=65535;else if(1/0===t[r])e[r]=31744;else if(-1/0===t[r])e[r]=64512;else{nt[0]=t[r];var n=(a=it[0])>>>31<<15,i=(a<<1>>>24)-127,a=a>>13&1023;e[r]=-24>i?n:-14>i?n+(a+1024>>-14-i):15<i?n+31744:n+(i+15<<10)+a}return e}function v(t){return Array.isArray(t)||W(t)}function m(t){return\"[object \"+t+\"]\"}function y(t){return Array.isArray(t)&&(0===t.length||\"number\"==typeof t[0])}function x(t){return!(!Array.isArray(t)||0===t.length||!v(t[0]))}function b(t){return Object.prototype.toString.call(t)}function _(t){if(!t)return!1;var e=b(t);return 0<=pt.indexOf(e)||(y(t)||x(t)||l(t))}function w(t,e){36193===t.type?(t.data=g(e),G.freeType(e)):t.data=e}function k(t,e,r,n,i,a){if(t=\"undefined\"!=typeof gt[t]?gt[t]:st[t]*dt[e],a&&(t*=6),i){for(n=0;1<=r;)n+=t*r*r,r/=2;return n}return t*r*n}function T(t,e,r,n,i,a,o){function s(){this.format=this.internalformat=6408,this.type=5121,this.flipY=this.premultiplyAlpha=this.compressed=!1,this.unpackAlignment=1,this.colorSpace=37444,this.channels=this.height=this.width=0}function c(t,e){t.internalformat=e.internalformat,t.format=e.format,t.type=e.type,t.compressed=e.compressed,t.premultiplyAlpha=e.premultiplyAlpha,t.flipY=e.flipY,t.unpackAlignment=e.unpackAlignment,t.colorSpace=e.colorSpace,t.width=e.width,t.height=e.height,t.channels=e.channels}function u(t,e){if(\"object\"==typeof e&&e){\"premultiplyAlpha\"in e&&(t.premultiplyAlpha=e.premultiplyAlpha),\"flipY\"in e&&(t.flipY=e.flipY),\"alignment\"in e&&(t.unpackAlignment=e.alignment),\"colorSpace\"in e&&(t.colorSpace=q[e.colorSpace]),\"type\"in e&&(t.type=H[e.type]);var r=t.width,n=t.height,i=t.channels,a=!1;\"shape\"in e?(r=e.shape[0],n=e.shape[1],3===e.shape.length&&(i=e.shape[2],a=!0)):(\"radius\"in e&&(r=n=e.radius),\"width\"in e&&(r=e.width),\"height\"in e&&(n=e.height),\"channels\"in e&&(i=e.channels,a=!0)),t.width=0|r,t.height=0|n,t.channels=0|i,r=!1,\"format\"in e&&(r=e.format,n=t.internalformat=Y[r],t.format=pt[n],r in H&&!(\"type\"in e)&&(t.type=H[r]),r in K&&(t.compressed=!0),r=!0),!a&&r?t.channels=st[t.format]:a&&!r&&t.channels!==ot[t.format]&&(t.format=t.internalformat=ot[t.channels])}}function h(e){t.pixelStorei(37440,e.flipY),t.pixelStorei(37441,e.premultiplyAlpha),t.pixelStorei(37443,e.colorSpace),t.pixelStorei(3317,e.unpackAlignment)}function f(){s.call(this),this.yOffset=this.xOffset=0,this.data=null,this.needsFree=!1,this.element=null,this.needsCopy=!1}function p(t,e){var r=null;if(_(e)?r=e:e&&(u(t,e),\"x\"in e&&(t.xOffset=0|e.x),\"y\"in e&&(t.yOffset=0|e.y),_(e.data)&&(r=e.data)),e.copy){var n=i.viewportWidth,a=i.viewportHeight;t.width=t.width||n-t.xOffset,t.height=t.height||a-t.yOffset,t.needsCopy=!0}else if(r){if(W(r))t.channels=t.channels||4,t.data=r,\"type\"in e||5121!==t.type||(t.type=0|J[Object.prototype.toString.call(r)]);else if(y(r)){switch(t.channels=t.channels||4,a=(n=r).length,t.type){case 5121:case 5123:case 5125:case 5126:(a=G.allocType(t.type,a)).set(n),t.data=a;break;case 36193:t.data=g(n)}t.alignment=1,t.needsFree=!0}else if(l(r)){n=r.data,Array.isArray(n)||5121!==t.type||(t.type=0|J[Object.prototype.toString.call(n)]);a=r.shape;var o,s,c,h,f=r.stride;3===a.length?(c=a[2],h=f[2]):h=c=1,o=a[0],s=a[1],a=f[0],f=f[1],t.alignment=1,t.width=o,t.height=s,t.channels=c,t.format=t.internalformat=ot[c],t.needsFree=!0,o=h,r=r.offset,c=t.width,h=t.height,s=t.channels;for(var p=G.allocType(36193===t.type?5126:t.type,c*h*s),d=0,m=0;m<h;++m)for(var k=0;k<c;++k)for(var T=0;T<s;++T)p[d++]=n[a*k+f*m+o*T+r];w(t,p)}else if(b(r)===lt||b(r)===ct)b(r)===lt?t.element=r:t.element=r.canvas,t.width=t.element.width,t.height=t.element.height,t.channels=4;else if(b(r)===ut)t.element=r,t.width=r.width,t.height=r.height,t.channels=4;else if(b(r)===ht)t.element=r,t.width=r.naturalWidth,t.height=r.naturalHeight,t.channels=4;else if(b(r)===ft)t.element=r,t.width=r.videoWidth,t.height=r.videoHeight,t.channels=4;else if(x(r)){for(n=t.width||r[0].length,a=t.height||r.length,f=t.channels,f=v(r[0][0])?f||r[0][0].length:f||1,o=Z.shape(r),c=1,h=0;h<o.length;++h)c*=o[h];c=G.allocType(36193===t.type?5126:t.type,c),Z.flatten(r,o,\"\",c),w(t,c),t.alignment=1,t.width=n,t.height=a,t.channels=f,t.format=t.internalformat=ot[f],t.needsFree=!0}}else t.width=t.width||1,t.height=t.height||1,t.channels=t.channels||4}function d(e,r,i,a,o){var s=e.element,l=e.data,c=e.internalformat,u=e.format,f=e.type,p=e.width,d=e.height;h(e),s?t.texSubImage2D(r,o,i,a,u,f,s):e.compressed?t.compressedTexSubImage2D(r,o,i,a,c,p,d,l):e.needsCopy?(n(),t.copyTexSubImage2D(r,o,i,a,e.xOffset,e.yOffset,p,d)):t.texSubImage2D(r,o,i,a,p,d,u,f,l)}function m(){return dt.pop()||new f}function T(t){t.needsFree&&G.freeType(t.data),f.call(t),dt.push(t)}function A(){s.call(this),this.genMipmaps=!1,this.mipmapHint=4352,this.mipmask=0,this.images=Array(16)}function M(t,e,r){var n=t.images[0]=m();t.mipmask=1,n.width=t.width=e,n.height=t.height=r,n.channels=t.channels=4}function S(t,e){var r=null;if(_(e))c(r=t.images[0]=m(),t),p(r,e),t.mipmask=1;else if(u(t,e),Array.isArray(e.mipmap))for(var n=e.mipmap,i=0;i<n.length;++i)c(r=t.images[i]=m(),t),r.width>>=i,r.height>>=i,p(r,n[i]),t.mipmask|=1<<i;else c(r=t.images[0]=m(),t),p(r,e),t.mipmask=1;c(t,t.images[0])}function E(e,r){for(var i=e.images,a=0;a<i.length&&i[a];++a){var o=i[a],s=r,l=a,c=o.element,u=o.data,f=o.internalformat,p=o.format,d=o.type,g=o.width,v=o.height,m=o.channels;h(o),c?t.texImage2D(s,l,p,p,d,c):o.compressed?t.compressedTexImage2D(s,l,f,g,v,0,u):o.needsCopy?(n(),t.copyTexImage2D(s,l,p,o.xOffset,o.yOffset,g,v,0)):((o=!u)&&(u=G.zero.allocType(d,g*v*m)),t.texImage2D(s,l,p,g,v,0,p,d,u),o&&u&&G.zero.freeType(u))}}function C(){var t=gt.pop()||new A;s.call(t);for(var e=t.mipmask=0;16>e;++e)t.images[e]=null;return t}function L(t){for(var e=t.images,r=0;r<e.length;++r)e[r]&&T(e[r]),e[r]=null;gt.push(t)}function P(){this.magFilter=this.minFilter=9728,this.wrapT=this.wrapS=33071,this.anisotropic=1,this.genMipmaps=!1,this.mipmapHint=4352}function O(t,e){\"min\"in e&&(t.minFilter=V[e.min],0<=at.indexOf(t.minFilter)&&!(\"faces\"in e)&&(t.genMipmaps=!0)),\"mag\"in e&&(t.magFilter=U[e.mag]);var r=t.wrapS,n=t.wrapT;if(\"wrap\"in e){var i=e.wrap;\"string\"==typeof i?r=n=N[i]:Array.isArray(i)&&(r=N[i[0]],n=N[i[1]])}else\"wrapS\"in e&&(r=N[e.wrapS]),\"wrapT\"in e&&(n=N[e.wrapT]);if(t.wrapS=r,t.wrapT=n,\"anisotropic\"in e&&(t.anisotropic=e.anisotropic),\"mipmap\"in e){switch(r=!1,typeof e.mipmap){case\"string\":t.mipmapHint=B[e.mipmap],r=t.genMipmaps=!0;break;case\"boolean\":r=t.genMipmaps=e.mipmap;break;case\"object\":t.genMipmaps=!1,r=!0}!r||\"min\"in e||(t.minFilter=9984)}}function z(r,n){t.texParameteri(n,10241,r.minFilter),t.texParameteri(n,10240,r.magFilter),t.texParameteri(n,10242,r.wrapS),t.texParameteri(n,10243,r.wrapT),e.ext_texture_filter_anisotropic&&t.texParameteri(n,34046,r.anisotropic),r.genMipmaps&&(t.hint(33170,r.mipmapHint),t.generateMipmap(n))}function I(e){s.call(this),this.mipmask=0,this.internalformat=6408,this.id=vt++,this.refCount=1,this.target=e,this.texture=t.createTexture(),this.unit=-1,this.bindCount=0,this.texInfo=new P,o.profile&&(this.stats={size:0})}function D(e){t.activeTexture(33984),t.bindTexture(e.target,e.texture)}function R(){var e=xt[0];e?t.bindTexture(e.target,e.texture):t.bindTexture(3553,null)}function F(e){var r=e.texture,n=e.unit,i=e.target;0<=n&&(t.activeTexture(33984+n),t.bindTexture(i,null),xt[n]=null),t.deleteTexture(r),e.texture=null,e.params=null,e.pixels=null,e.refCount=0,delete mt[e.id],a.textureCount--}var B={\"don't care\":4352,\"dont care\":4352,nice:4354,fast:4353},N={repeat:10497,clamp:33071,mirror:33648},U={nearest:9728,linear:9729},V=j({mipmap:9987,\"nearest mipmap nearest\":9984,\"linear mipmap nearest\":9985,\"nearest mipmap linear\":9986,\"linear mipmap linear\":9987},U),q={none:0,browser:37444},H={uint8:5121,rgba4:32819,rgb565:33635,\"rgb5 a1\":32820},Y={alpha:6406,luminance:6409,\"luminance alpha\":6410,rgb:6407,rgba:6408,rgba4:32854,\"rgb5 a1\":32855,rgb565:36194},K={};e.ext_srgb&&(Y.srgb=35904,Y.srgba=35906),e.oes_texture_float&&(H.float32=H.float=5126),e.oes_texture_half_float&&(H.float16=H[\"half float\"]=36193),e.webgl_depth_texture&&(j(Y,{depth:6402,\"depth stencil\":34041}),j(H,{uint16:5123,uint32:5125,\"depth stencil\":34042})),e.webgl_compressed_texture_s3tc&&j(K,{\"rgb s3tc dxt1\":33776,\"rgba s3tc dxt1\":33777,\"rgba s3tc dxt3\":33778,\"rgba s3tc dxt5\":33779}),e.webgl_compressed_texture_atc&&j(K,{\"rgb atc\":35986,\"rgba atc explicit alpha\":35987,\"rgba atc interpolated alpha\":34798}),e.webgl_compressed_texture_pvrtc&&j(K,{\"rgb pvrtc 4bppv1\":35840,\"rgb pvrtc 2bppv1\":35841,\"rgba pvrtc 4bppv1\":35842,\"rgba pvrtc 2bppv1\":35843}),e.webgl_compressed_texture_etc1&&(K[\"rgb etc1\"]=36196);var $=Array.prototype.slice.call(t.getParameter(34467));Object.keys(K).forEach(function(t){var e=K[t];0<=$.indexOf(e)&&(Y[t]=e)});var Q=Object.keys(Y);r.textureFormats=Q;var tt=[];Object.keys(Y).forEach(function(t){tt[Y[t]]=t});var et=[];Object.keys(H).forEach(function(t){et[H[t]]=t});var rt=[];Object.keys(U).forEach(function(t){rt[U[t]]=t});var nt=[];Object.keys(V).forEach(function(t){nt[V[t]]=t});var it=[];Object.keys(N).forEach(function(t){it[N[t]]=t});var pt=Q.reduce(function(t,e){var r=Y[e];return 6409===r||6406===r||6409===r||6410===r||6402===r||34041===r?t[r]=r:32855===r||0<=e.indexOf(\"rgba\")?t[r]=6408:t[r]=6407,t},{}),dt=[],gt=[],vt=0,mt={},yt=r.maxTextureUnits,xt=Array(yt).map(function(){return null});return j(I.prototype,{bind:function(){this.bindCount+=1;var e=this.unit;if(0>e){for(var r=0;r<yt;++r){var n=xt[r];if(n){if(0<n.bindCount)continue;n.unit=-1}xt[r]=this,e=r;break}o.profile&&a.maxTextureUnits<e+1&&(a.maxTextureUnits=e+1),this.unit=e,t.activeTexture(33984+e),t.bindTexture(this.target,this.texture)}return e},unbind:function(){--this.bindCount},decRef:function(){0>=--this.refCount&&F(this)}}),o.profile&&(a.getTotalTextureSize=function(){var t=0;return Object.keys(mt).forEach(function(e){t+=mt[e].stats.size}),t}),{create2D:function(e,r){function n(t,e){var r=i.texInfo;P.call(r);var a=C();return\"number\"==typeof t?M(a,0|t,\"number\"==typeof e?0|e:0|t):t?(O(r,t),S(a,t)):M(a,1,1),r.genMipmaps&&(a.mipmask=(a.width<<1)-1),i.mipmask=a.mipmask,c(i,a),i.internalformat=a.internalformat,n.width=a.width,n.height=a.height,D(i),E(a,3553),z(r,3553),R(),L(a),o.profile&&(i.stats.size=k(i.internalformat,i.type,a.width,a.height,r.genMipmaps,!1)),n.format=tt[i.internalformat],n.type=et[i.type],n.mag=rt[r.magFilter],n.min=nt[r.minFilter],n.wrapS=it[r.wrapS],n.wrapT=it[r.wrapT],n}var i=new I(3553);return mt[i.id]=i,a.textureCount++,n(e,r),n.subimage=function(t,e,r,a){e|=0,r|=0,a|=0;var o=m();return c(o,i),o.width=0,o.height=0,p(o,t),o.width=o.width||(i.width>>a)-e,o.height=o.height||(i.height>>a)-r,D(i),d(o,3553,e,r,a),R(),T(o),n},n.resize=function(e,r){var a=0|e,s=0|r||a;if(a===i.width&&s===i.height)return n;n.width=i.width=a,n.height=i.height=s,D(i);for(var l,c=i.channels,u=i.type,h=0;i.mipmask>>h;++h){var f=a>>h,p=s>>h;if(!f||!p)break;l=G.zero.allocType(u,f*p*c),t.texImage2D(3553,h,i.format,f,p,0,i.format,i.type,l),l&&G.zero.freeType(l)}return R(),o.profile&&(i.stats.size=k(i.internalformat,i.type,a,s,!1,!1)),n},n._reglType=\"texture2d\",n._texture=i,o.profile&&(n.stats=i.stats),n.destroy=function(){i.decRef()},n},createCube:function(e,r,n,i,s,l){function h(t,e,r,n,i,a){var s,l=f.texInfo;for(P.call(l),s=0;6>s;++s)g[s]=C();if(\"number\"!=typeof t&&t){if(\"object\"==typeof t)if(e)S(g[0],t),S(g[1],e),S(g[2],r),S(g[3],n),S(g[4],i),S(g[5],a);else if(O(l,t),u(f,t),\"faces\"in t)for(t=t.faces,s=0;6>s;++s)c(g[s],f),S(g[s],t[s]);else for(s=0;6>s;++s)S(g[s],t)}else for(t=0|t||1,s=0;6>s;++s)M(g[s],t,t);for(c(f,g[0]),f.mipmask=l.genMipmaps?(g[0].width<<1)-1:g[0].mipmask,f.internalformat=g[0].internalformat,h.width=g[0].width,h.height=g[0].height,D(f),s=0;6>s;++s)E(g[s],34069+s);for(z(l,34067),R(),o.profile&&(f.stats.size=k(f.internalformat,f.type,h.width,h.height,l.genMipmaps,!0)),h.format=tt[f.internalformat],h.type=et[f.type],h.mag=rt[l.magFilter],h.min=nt[l.minFilter],h.wrapS=it[l.wrapS],h.wrapT=it[l.wrapT],s=0;6>s;++s)L(g[s]);return h}var f=new I(34067);mt[f.id]=f,a.cubeCount++;var g=Array(6);return h(e,r,n,i,s,l),h.subimage=function(t,e,r,n,i){r|=0,n|=0,i|=0;var a=m();return c(a,f),a.width=0,a.height=0,p(a,e),a.width=a.width||(f.width>>i)-r,a.height=a.height||(f.height>>i)-n,D(f),d(a,34069+t,r,n,i),R(),T(a),h},h.resize=function(e){if((e|=0)!==f.width){h.width=f.width=e,h.height=f.height=e,D(f);for(var r=0;6>r;++r)for(var n=0;f.mipmask>>n;++n)t.texImage2D(34069+r,n,f.format,e>>n,e>>n,0,f.format,f.type,null);return R(),o.profile&&(f.stats.size=k(f.internalformat,f.type,h.width,h.height,!1,!0)),h}},h._reglType=\"textureCube\",h._texture=f,o.profile&&(h.stats=f.stats),h.destroy=function(){f.decRef()},h},clear:function(){for(var e=0;e<yt;++e)t.activeTexture(33984+e),t.bindTexture(3553,null),xt[e]=null;X(mt).forEach(F),a.cubeCount=0,a.textureCount=0},getTexture:function(t){return null},restore:function(){for(var e=0;e<yt;++e){var r=xt[e];r&&(r.bindCount=0,r.unit=-1,xt[e]=null)}X(mt).forEach(function(e){e.texture=t.createTexture(),t.bindTexture(e.target,e.texture);for(var r=0;32>r;++r)if(0!=(e.mipmask&1<<r))if(3553===e.target)t.texImage2D(3553,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);else for(var n=0;6>n;++n)t.texImage2D(34069+n,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);z(e.texInfo,e.target)})}}}function A(t,e,r,n,i,a){function o(t,e,r){this.target=t,this.texture=e,this.renderbuffer=r;var n=t=0;e?(t=e.width,n=e.height):r&&(t=r.width,n=r.height),this.width=t,this.height=n}function s(t){t&&(t.texture&&t.texture._texture.decRef(),t.renderbuffer&&t.renderbuffer._renderbuffer.decRef())}function l(t,e,r){t&&(t.texture?t.texture._texture.refCount+=1:t.renderbuffer._renderbuffer.refCount+=1)}function c(e,r){r&&(r.texture?t.framebufferTexture2D(36160,e,r.target,r.texture._texture.texture,0):t.framebufferRenderbuffer(36160,e,36161,r.renderbuffer._renderbuffer.renderbuffer))}function u(t){var e=3553,r=null,n=null,i=t;return\"object\"==typeof t&&(i=t.data,\"target\"in t&&(e=0|t.target)),\"texture2d\"===(t=i._reglType)?r=i:\"textureCube\"===t?r=i:\"renderbuffer\"===t&&(n=i,e=36161),new o(e,r,n)}function h(t,e,r,a,s){return r?((t=n.create2D({width:t,height:e,format:a,type:s}))._texture.refCount=0,new o(3553,t,null)):((t=i.create({width:t,height:e,format:a}))._renderbuffer.refCount=0,new o(36161,null,t))}function f(t){return t&&(t.texture||t.renderbuffer)}function p(t,e,r){t&&(t.texture?t.texture.resize(e,r):t.renderbuffer&&t.renderbuffer.resize(e,r),t.width=e,t.height=r)}function d(){this.id=k++,T[this.id]=this,this.framebuffer=t.createFramebuffer(),this.height=this.width=0,this.colorAttachments=[],this.depthStencilAttachment=this.stencilAttachment=this.depthAttachment=null}function g(t){t.colorAttachments.forEach(s),s(t.depthAttachment),s(t.stencilAttachment),s(t.depthStencilAttachment)}function v(e){t.deleteFramebuffer(e.framebuffer),e.framebuffer=null,a.framebufferCount--,delete T[e.id]}function m(e){var n;t.bindFramebuffer(36160,e.framebuffer);var i=e.colorAttachments;for(n=0;n<i.length;++n)c(36064+n,i[n]);for(n=i.length;n<r.maxColorAttachments;++n)t.framebufferTexture2D(36160,36064+n,3553,null,0);t.framebufferTexture2D(36160,33306,3553,null,0),t.framebufferTexture2D(36160,36096,3553,null,0),t.framebufferTexture2D(36160,36128,3553,null,0),c(36096,e.depthAttachment),c(36128,e.stencilAttachment),c(33306,e.depthStencilAttachment),t.checkFramebufferStatus(36160),t.isContextLost(),t.bindFramebuffer(36160,x.next?x.next.framebuffer:null),x.cur=x.next,t.getError()}function y(t,e){function r(t,e){var i,a=0,o=0,s=!0,c=!0;i=null;var p=!0,d=\"rgba\",v=\"uint8\",y=1,x=null,w=null,k=null,T=!1;\"number\"==typeof t?(a=0|t,o=0|e||a):t?(\"shape\"in t?(a=(o=t.shape)[0],o=o[1]):(\"radius\"in t&&(a=o=t.radius),\"width\"in t&&(a=t.width),\"height\"in t&&(o=t.height)),(\"color\"in t||\"colors\"in t)&&(i=t.color||t.colors,Array.isArray(i)),i||(\"colorCount\"in t&&(y=0|t.colorCount),\"colorTexture\"in t&&(p=!!t.colorTexture,d=\"rgba4\"),\"colorType\"in t&&(v=t.colorType,!p)&&(\"half float\"===v||\"float16\"===v?d=\"rgba16f\":\"float\"!==v&&\"float32\"!==v||(d=\"rgba32f\")),\"colorFormat\"in t&&(d=t.colorFormat,0<=b.indexOf(d)?p=!0:0<=_.indexOf(d)&&(p=!1))),(\"depthTexture\"in t||\"depthStencilTexture\"in t)&&(T=!(!t.depthTexture&&!t.depthStencilTexture)),\"depth\"in t&&(\"boolean\"==typeof t.depth?s=t.depth:(x=t.depth,c=!1)),\"stencil\"in t&&(\"boolean\"==typeof t.stencil?c=t.stencil:(w=t.stencil,s=!1)),\"depthStencil\"in t&&(\"boolean\"==typeof t.depthStencil?s=c=t.depthStencil:(k=t.depthStencil,c=s=!1))):a=o=1;var A=null,M=null,S=null,E=null;if(Array.isArray(i))A=i.map(u);else if(i)A=[u(i)];else for(A=Array(y),i=0;i<y;++i)A[i]=h(a,o,p,d,v);for(a=a||A[0].width,o=o||A[0].height,x?M=u(x):s&&!c&&(M=h(a,o,T,\"depth\",\"uint32\")),w?S=u(w):c&&!s&&(S=h(a,o,!1,\"stencil\",\"uint8\")),k?E=u(k):!x&&!w&&c&&s&&(E=h(a,o,T,\"depth stencil\",\"depth stencil\")),s=null,i=0;i<A.length;++i)l(A[i]),A[i]&&A[i].texture&&(c=yt[A[i].texture._texture.format]*xt[A[i].texture._texture.type],null===s&&(s=c));return l(M),l(S),l(E),g(n),n.width=a,n.height=o,n.colorAttachments=A,n.depthAttachment=M,n.stencilAttachment=S,n.depthStencilAttachment=E,r.color=A.map(f),r.depth=f(M),r.stencil=f(S),r.depthStencil=f(E),r.width=n.width,r.height=n.height,m(n),r}var n=new d;return a.framebufferCount++,r(t,e),j(r,{resize:function(t,e){var i=Math.max(0|t,1),a=Math.max(0|e||i,1);if(i===n.width&&a===n.height)return r;for(var o=n.colorAttachments,s=0;s<o.length;++s)p(o[s],i,a);return p(n.depthAttachment,i,a),p(n.stencilAttachment,i,a),p(n.depthStencilAttachment,i,a),n.width=r.width=i,n.height=r.height=a,m(n),r},_reglType:\"framebuffer\",_framebuffer:n,destroy:function(){v(n),g(n)},use:function(t){x.setFBO({framebuffer:r},t)}})}var x={cur:null,next:null,dirty:!1,setFBO:null},b=[\"rgba\"],_=[\"rgba4\",\"rgb565\",\"rgb5 a1\"];e.ext_srgb&&_.push(\"srgba\"),e.ext_color_buffer_half_float&&_.push(\"rgba16f\",\"rgb16f\"),e.webgl_color_buffer_float&&_.push(\"rgba32f\");var w=[\"uint8\"];e.oes_texture_half_float&&w.push(\"half float\",\"float16\"),e.oes_texture_float&&w.push(\"float\",\"float32\");var k=0,T={};return j(x,{getFramebuffer:function(t){return\"function\"==typeof t&&\"framebuffer\"===t._reglType&&(t=t._framebuffer)instanceof d?t:null},create:y,createCube:function(t){function e(t){var i,a={color:null},o=0,s=null;i=\"rgba\";var l=\"uint8\",c=1;if(\"number\"==typeof t?o=0|t:t?(\"shape\"in t?o=t.shape[0]:(\"radius\"in t&&(o=0|t.radius),\"width\"in t?o=0|t.width:\"height\"in t&&(o=0|t.height)),(\"color\"in t||\"colors\"in t)&&(s=t.color||t.colors,Array.isArray(s)),s||(\"colorCount\"in t&&(c=0|t.colorCount),\"colorType\"in t&&(l=t.colorType),\"colorFormat\"in t&&(i=t.colorFormat)),\"depth\"in t&&(a.depth=t.depth),\"stencil\"in t&&(a.stencil=t.stencil),\"depthStencil\"in t&&(a.depthStencil=t.depthStencil)):o=1,s)if(Array.isArray(s))for(t=[],i=0;i<s.length;++i)t[i]=s[i];else t=[s];else for(t=Array(c),s={radius:o,format:i,type:l},i=0;i<c;++i)t[i]=n.createCube(s);for(a.color=Array(t.length),i=0;i<t.length;++i)c=t[i],o=o||c.width,a.color[i]={target:34069,data:t[i]};for(i=0;6>i;++i){for(c=0;c<t.length;++c)a.color[c].target=34069+i;0<i&&(a.depth=r[0].depth,a.stencil=r[0].stencil,a.depthStencil=r[0].depthStencil),r[i]?r[i](a):r[i]=y(a)}return j(e,{width:o,height:o,color:t})}var r=Array(6);return e(t),j(e,{faces:r,resize:function(t){var n=0|t;if(n===e.width)return e;var i=e.color;for(t=0;t<i.length;++t)i[t].resize(n);for(t=0;6>t;++t)r[t].resize(n);return e.width=e.height=n,e},_reglType:\"framebufferCube\",destroy:function(){r.forEach(function(t){t.destroy()})}})},clear:function(){X(T).forEach(v)},restore:function(){x.cur=null,x.next=null,x.dirty=!0,X(T).forEach(function(e){e.framebuffer=t.createFramebuffer(),m(e)})}})}function M(){this.w=this.z=this.y=this.x=this.state=0,this.buffer=null,this.size=0,this.normalized=!1,this.type=5126,this.divisor=this.stride=this.offset=0}function S(t,e,r,n){function i(t,e,r,n){this.name=t,this.id=e,this.location=r,this.info=n}function a(t,e){for(var r=0;r<t.length;++r)if(t[r].id===e.id)return void(t[r].location=e.location);t.push(e)}function o(r,n,i){if(!(o=(i=35632===r?c:u)[n])){var a=e.str(n),o=t.createShader(r);t.shaderSource(o,a),t.compileShader(o),i[n]=o}return o}function s(t,e){this.id=p++,this.fragId=t,this.vertId=e,this.program=null,this.uniforms=[],this.attributes=[],n.profile&&(this.stats={uniformsCount:0,attributesCount:0})}function l(r,s){var l,c;l=o(35632,r.fragId),c=o(35633,r.vertId);var u=r.program=t.createProgram();t.attachShader(u,l),t.attachShader(u,c),t.linkProgram(u);var h=t.getProgramParameter(u,35718);n.profile&&(r.stats.uniformsCount=h);var f=r.uniforms;for(l=0;l<h;++l)if(c=t.getActiveUniform(u,l))if(1<c.size)for(var p=0;p<c.size;++p){var d=c.name.replace(\"[0]\",\"[\"+p+\"]\");a(f,new i(d,e.id(d),t.getUniformLocation(u,d),c))}else a(f,new i(c.name,e.id(c.name),t.getUniformLocation(u,c.name),c));for(h=t.getProgramParameter(u,35721),n.profile&&(r.stats.attributesCount=h),f=r.attributes,l=0;l<h;++l)(c=t.getActiveAttrib(u,l))&&a(f,new i(c.name,e.id(c.name),t.getAttribLocation(u,c.name),c))}var c={},u={},h={},f=[],p=0;return n.profile&&(r.getMaxUniformsCount=function(){var t=0;return f.forEach(function(e){e.stats.uniformsCount>t&&(t=e.stats.uniformsCount)}),t},r.getMaxAttributesCount=function(){var t=0;return f.forEach(function(e){e.stats.attributesCount>t&&(t=e.stats.attributesCount)}),t}),{clear:function(){var e=t.deleteShader.bind(t);X(c).forEach(e),c={},X(u).forEach(e),u={},f.forEach(function(e){t.deleteProgram(e.program)}),f.length=0,h={},r.shaderCount=0},program:function(t,e,n){var i=h[e];i||(i=h[e]={});var a=i[t];return a||(a=new s(e,t),r.shaderCount++,l(a),i[t]=a,f.push(a)),a},restore:function(){c={},u={};for(var t=0;t<f.length;++t)l(f[t])},shader:o,frag:-1,vert:-1}}function E(t,e,r,n,i,a,o){function s(i){var a;a=null===e.next?5121:e.next.colorAttachments[0].texture._texture.type;var o=0,s=0,l=n.framebufferWidth,c=n.framebufferHeight,u=null;return W(i)?u=i:i&&(o=0|i.x,s=0|i.y,l=0|(i.width||n.framebufferWidth-o),c=0|(i.height||n.framebufferHeight-s),u=i.data||null),r(),i=l*c*4,u||(5121===a?u=new Uint8Array(i):5126===a&&(u=u||new Float32Array(i))),t.pixelStorei(3333,4),t.readPixels(o,s,l,c,6408,a,u),u}return function(t){return t&&\"framebuffer\"in t?function(t){var r;return e.setFBO({framebuffer:t.framebuffer},function(){r=s(t)}),r}(t):s(t)}}function C(t){return Array.prototype.slice.call(t)}function L(t){return C(t).join(\"\")}function P(){function t(){var t=[],e=[];return j(function(){t.push.apply(t,C(arguments))},{def:function(){var n=\"v\"+r++;return e.push(n),0<arguments.length&&(t.push(n,\"=\"),t.push.apply(t,C(arguments)),t.push(\";\")),n},toString:function(){return L([0<e.length?\"var \"+e+\";\":\"\",L(t)])}})}function e(){function e(t,e){n(t,e,\"=\",r.def(t,e),\";\")}var r=t(),n=t(),i=r.toString,a=n.toString;return j(function(){r.apply(r,C(arguments))},{def:r.def,entry:r,exit:n,save:e,set:function(t,n,i){e(t,n),r(t,n,\"=\",i,\";\")},toString:function(){return i()+a()}})}var r=0,n=[],i=[],a=t(),o={};return{global:a,link:function(t){for(var e=0;e<i.length;++e)if(i[e]===t)return n[e];return e=\"g\"+r++,n.push(e),i.push(t),e},block:t,proc:function(t,r){function n(){var t=\"a\"+i.length;return i.push(t),t}var i=[];r=r||0;for(var a=0;a<r;++a)n();var s=(a=e()).toString;return o[t]=j(a,{arg:n,toString:function(){return L([\"function(\",i.join(),\"){\",s(),\"}\"])}})},scope:e,cond:function(){var t=L(arguments),r=e(),n=e(),i=r.toString,a=n.toString;return j(r,{then:function(){return r.apply(r,C(arguments)),this},else:function(){return n.apply(n,C(arguments)),this},toString:function(){var e=a();return e&&(e=\"else{\"+e+\"}\"),L([\"if(\",t,\"){\",i(),\"}\",e])}})},compile:function(){var t=['\"use strict\";',a,\"return {\"];Object.keys(o).forEach(function(e){t.push('\"',e,'\":',o[e].toString(),\",\")}),t.push(\"}\");var e=L(t).replace(/;/g,\";\\n\").replace(/}/g,\"}\\n\").replace(/{/g,\"{\\n\");return Function.apply(null,n.concat(e)).apply(null,i)}}}function O(t){return Array.isArray(t)||W(t)||l(t)}function z(t){return t.sort(function(t,e){return\"viewport\"===t?-1:\"viewport\"===e?1:t<e?-1:1})}function I(t,e,r,n){this.thisDep=t,this.contextDep=e,this.propDep=r,this.append=n}function D(t){return t&&!(t.thisDep||t.contextDep||t.propDep)}function R(t){return new I(!1,!1,!1,t)}function F(t,e){var r=t.type;return 0===r?new I(!0,1<=(r=t.data.length),2<=r,e):4===r?new I((r=t.data).thisDep,r.contextDep,r.propDep,e):new I(3===r,2===r,1===r,e)}function B(t,e,r,n,i,o,s,l,c,u,h,f,p,d,g){function m(t){return t.replace(\".\",\"_\")}function y(t,e,r){var n=m(t);nt.push(t),et[n]=tt[n]=!!r,it[n]=e}function x(t,e,r){var n=m(t);nt.push(t),Array.isArray(r)?(tt[n]=r.slice(),et[n]=r.slice()):tt[n]=et[n]=r,at[n]=e}function b(){var t=P(),r=t.link,n=t.global;t.id=lt++,t.batchId=\"0\";var i=r(ot),a=t.shared={props:\"a0\"};Object.keys(ot).forEach(function(t){a[t]=n.def(i,\".\",t)});var o=t.next={},s=t.current={};Object.keys(at).forEach(function(t){Array.isArray(tt[t])&&(o[t]=n.def(a.next,\".\",t),s[t]=n.def(a.current,\".\",t))});var l=t.constants={};Object.keys(st).forEach(function(t){l[t]=n.def(JSON.stringify(st[t]))}),t.invoke=function(e,n){switch(n.type){case 0:var i=[\"this\",a.context,a.props,t.batchId];return e.def(r(n.data),\".call(\",i.slice(0,Math.max(n.data.length+1,4)),\")\");case 1:return e.def(a.props,n.data);case 2:return e.def(a.context,n.data);case 3:return e.def(\"this\",n.data);case 4:return n.data.append(t,e),n.data.ref}},t.attribCache={};var c={};return t.scopeAttrib=function(t){if((t=e.id(t))in c)return c[t];var n=u.scope[t];return n||(n=u.scope[t]=new Z),c[t]=r(n)},t}function _(t,e){var r=t.static,n=t.dynamic;if(\"framebuffer\"in r){var i=r.framebuffer;return i?(i=l.getFramebuffer(i),R(function(t,e){var r=t.link(i),n=t.shared;return e.set(n.framebuffer,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\".width\"),e.set(n,\".framebufferHeight\",r+\".height\"),r})):R(function(t,e){var r=t.shared;return e.set(r.framebuffer,\".next\",\"null\"),r=r.context,e.set(r,\".framebufferWidth\",r+\".drawingBufferWidth\"),e.set(r,\".framebufferHeight\",r+\".drawingBufferHeight\"),\"null\"})}if(\"framebuffer\"in n){var a=n.framebuffer;return F(a,function(t,e){var r=t.invoke(e,a),n=t.shared,i=n.framebuffer;r=e.def(i,\".getFramebuffer(\",r,\")\");return e.set(i,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\"?\"+r+\".width:\"+n+\".drawingBufferWidth\"),e.set(n,\".framebufferHeight\",r+\"?\"+r+\".height:\"+n+\".drawingBufferHeight\"),r})}return null}function w(t){function r(t){if(t in n){var r=e.id(n[t]);return(t=R(function(){return r})).id=r,t}if(t in i){var a=i[t];return F(a,function(t,e){var r=t.invoke(e,a);return e.def(t.shared.strings,\".id(\",r,\")\")})}return null}var n=t.static,i=t.dynamic,a=r(\"frag\"),o=r(\"vert\"),s=null;return D(a)&&D(o)?(s=h.program(o.id,a.id),t=R(function(t,e){return t.link(s)})):t=new I(a&&a.thisDep||o&&o.thisDep,a&&a.contextDep||o&&o.contextDep,a&&a.propDep||o&&o.propDep,function(t,e){var r,n,i=t.shared.shader;return r=a?a.append(t,e):e.def(i,\".\",\"frag\"),n=o?o.append(t,e):e.def(i,\".\",\"vert\"),e.def(i+\".program(\"+n+\",\"+r+\")\")}),{frag:a,vert:o,progVar:t,program:s}}function k(t,e){function r(t,e){if(t in n){var r=0|n[t];return R(function(t,n){return e&&(t.OFFSET=r),r})}if(t in i){var o=i[t];return F(o,function(t,r){var n=t.invoke(r,o);return e&&(t.OFFSET=n),n})}return e&&a?R(function(t,e){return t.OFFSET=\"0\",0}):null}var n=t.static,i=t.dynamic,a=function(){if(\"elements\"in n){var t=n.elements;O(t)?t=o.getElements(o.create(t,!0)):t&&(t=o.getElements(t));var e=R(function(e,r){if(t){var n=e.link(t);return e.ELEMENTS=n}return e.ELEMENTS=null});return e.value=t,e}if(\"elements\"in i){var r=i.elements;return F(r,function(t,e){var n=(i=t.shared).isBufferArgs,i=i.elements,a=t.invoke(e,r),o=e.def(\"null\");n=e.def(n,\"(\",a,\")\"),a=t.cond(n).then(o,\"=\",i,\".createStream(\",a,\");\").else(o,\"=\",i,\".getElements(\",a,\");\");return e.entry(a),e.exit(t.cond(n).then(i,\".destroyStream(\",o,\");\")),t.ELEMENTS=o})}return null}(),s=r(\"offset\",!0);return{elements:a,primitive:function(){if(\"primitive\"in n){var t=n.primitive;return R(function(e,r){return rt[t]})}if(\"primitive\"in i){var e=i.primitive;return F(e,function(t,r){var n=t.constants.primTypes,i=t.invoke(r,e);return r.def(n,\"[\",i,\"]\")})}return a?D(a)?a.value?R(function(t,e){return e.def(t.ELEMENTS,\".primType\")}):R(function(){return 4}):new I(a.thisDep,a.contextDep,a.propDep,function(t,e){var r=t.ELEMENTS;return e.def(r,\"?\",r,\".primType:\",4)}):null}(),count:function(){if(\"count\"in n){var t=0|n.count;return R(function(){return t})}if(\"count\"in i){var e=i.count;return F(e,function(t,r){return t.invoke(r,e)})}return a?D(a)?a?s?new I(s.thisDep,s.contextDep,s.propDep,function(t,e){return e.def(t.ELEMENTS,\".vertCount-\",t.OFFSET)}):R(function(t,e){return e.def(t.ELEMENTS,\".vertCount\")}):R(function(){return-1}):new I(a.thisDep||s.thisDep,a.contextDep||s.contextDep,a.propDep||s.propDep,function(t,e){var r=t.ELEMENTS;return t.OFFSET?e.def(r,\"?\",r,\".vertCount-\",t.OFFSET,\":-1\"):e.def(r,\"?\",r,\".vertCount:-1\")}):null}(),instances:r(\"instances\",!1),offset:s}}function T(t,r){var n=t.static,a=t.dynamic,o={};return Object.keys(n).forEach(function(t){var r=n[t],a=e.id(t),s=new Z;if(O(r))s.state=1,s.buffer=i.getBuffer(i.create(r,34962,!1,!0)),s.type=0;else if(c=i.getBuffer(r))s.state=1,s.buffer=c,s.type=0;else if(\"constant\"in r){var l=r.constant;s.buffer=\"null\",s.state=2,\"number\"==typeof l?s.x=l:bt.forEach(function(t,e){e<l.length&&(s[t]=l[e])})}else{var c=O(r.buffer)?i.getBuffer(i.create(r.buffer,34962,!1,!0)):i.getBuffer(r.buffer),u=0|r.offset,h=0|r.stride,f=0|r.size,p=!!r.normalized,d=0;\"type\"in r&&(d=K[r.type]),r=0|r.divisor,s.buffer=c,s.state=1,s.size=f,s.normalized=p,s.type=d||c.dtype,s.offset=u,s.stride=h,s.divisor=r}o[t]=R(function(t,e){var r=t.attribCache;if(a in r)return r[a];var n={isStream:!1};return Object.keys(s).forEach(function(t){n[t]=s[t]}),s.buffer&&(n.buffer=t.link(s.buffer),n.type=n.type||n.buffer+\".dtype\"),r[a]=n})}),Object.keys(a).forEach(function(t){var e=a[t];o[t]=F(e,function(t,r){function n(t){r(l[t],\"=\",i,\".\",t,\"|0;\")}var i=t.invoke(r,e),a=t.shared,o=a.isBufferArgs,s=a.buffer,l={isStream:r.def(!1)},c=new Z;c.state=1,Object.keys(c).forEach(function(t){l[t]=r.def(\"\"+c[t])});var u=l.buffer,h=l.type;return r(\"if(\",o,\"(\",i,\")){\",l.isStream,\"=true;\",u,\"=\",s,\".createStream(\",34962,\",\",i,\");\",h,\"=\",u,\".dtype;\",\"}else{\",u,\"=\",s,\".getBuffer(\",i,\");\",\"if(\",u,\"){\",h,\"=\",u,\".dtype;\",'}else if(\"constant\" in ',i,\"){\",l.state,\"=\",2,\";\",\"if(typeof \"+i+'.constant === \"number\"){',l[bt[0]],\"=\",i,\".constant;\",bt.slice(1).map(function(t){return l[t]}).join(\"=\"),\"=0;\",\"}else{\",bt.map(function(t,e){return l[t]+\"=\"+i+\".constant.length>\"+e+\"?\"+i+\".constant[\"+e+\"]:0;\"}).join(\"\"),\"}}else{\",\"if(\",o,\"(\",i,\".buffer)){\",u,\"=\",s,\".createStream(\",34962,\",\",i,\".buffer);\",\"}else{\",u,\"=\",s,\".getBuffer(\",i,\".buffer);\",\"}\",h,'=\"type\" in ',i,\"?\",a.glTypes,\"[\",i,\".type]:\",u,\".dtype;\",l.normalized,\"=!!\",i,\".normalized;\"),n(\"size\"),n(\"offset\"),n(\"stride\"),n(\"divisor\"),r(\"}}\"),r.exit(\"if(\",l.isStream,\"){\",s,\".destroyStream(\",u,\");\",\"}\"),l})}),o}function A(t,e,r,n,i){var o=_(t),s=function(t,e,r){function n(t){if(t in i){var r=i[t];t=!0;var n,o,s=0|r.x,l=0|r.y;return\"width\"in r?n=0|r.width:t=!1,\"height\"in r?o=0|r.height:t=!1,new I(!t&&e&&e.thisDep,!t&&e&&e.contextDep,!t&&e&&e.propDep,function(t,e){var i=t.shared.context,a=n;\"width\"in r||(a=e.def(i,\".\",\"framebufferWidth\",\"-\",s));var c=o;return\"height\"in r||(c=e.def(i,\".\",\"framebufferHeight\",\"-\",l)),[s,l,a,c]})}if(t in a){var c=a[t];return t=F(c,function(t,e){var r=t.invoke(e,c),n=t.shared.context,i=e.def(r,\".x|0\"),a=e.def(r,\".y|0\");return[i,a,e.def('\"width\" in ',r,\"?\",r,\".width|0:\",\"(\",n,\".\",\"framebufferWidth\",\"-\",i,\")\"),r=e.def('\"height\" in ',r,\"?\",r,\".height|0:\",\"(\",n,\".\",\"framebufferHeight\",\"-\",a,\")\")]}),e&&(t.thisDep=t.thisDep||e.thisDep,t.contextDep=t.contextDep||e.contextDep,t.propDep=t.propDep||e.propDep),t}return e?new I(e.thisDep,e.contextDep,e.propDep,function(t,e){var r=t.shared.context;return[0,0,e.def(r,\".\",\"framebufferWidth\"),e.def(r,\".\",\"framebufferHeight\")]}):null}var i=t.static,a=t.dynamic;if(t=n(\"viewport\")){var o=t;t=new I(t.thisDep,t.contextDep,t.propDep,function(t,e){var r=o.append(t,e),n=t.shared.context;return e.set(n,\".viewportWidth\",r[2]),e.set(n,\".viewportHeight\",r[3]),r})}return{viewport:t,scissor_box:n(\"scissor.box\")}}(t,o),l=k(t),c=function(t,e){var r=t.static,n=t.dynamic,i={};return nt.forEach(function(t){function e(e,a){if(t in r){var s=e(r[t]);i[o]=R(function(){return s})}else if(t in n){var l=n[t];i[o]=F(l,function(t,e){return a(t,e,t.invoke(e,l))})}}var o=m(t);switch(t){case\"cull.enable\":case\"blend.enable\":case\"dither\":case\"stencil.enable\":case\"depth.enable\":case\"scissor.enable\":case\"polygonOffset.enable\":case\"sample.alpha\":case\"sample.enable\":case\"depth.mask\":return e(function(t){return t},function(t,e,r){return r});case\"depth.func\":return e(function(t){return kt[t]},function(t,e,r){return e.def(t.constants.compareFuncs,\"[\",r,\"]\")});case\"depth.range\":return e(function(t){return t},function(t,e,r){return[e.def(\"+\",r,\"[0]\"),e=e.def(\"+\",r,\"[1]\")]});case\"blend.func\":return e(function(t){return[wt[\"srcRGB\"in t?t.srcRGB:t.src],wt[\"dstRGB\"in t?t.dstRGB:t.dst],wt[\"srcAlpha\"in t?t.srcAlpha:t.src],wt[\"dstAlpha\"in t?t.dstAlpha:t.dst]]},function(t,e,r){function n(t,n){return e.def('\"',t,n,'\" in ',r,\"?\",r,\".\",t,n,\":\",r,\".\",t)}t=t.constants.blendFuncs;var i=n(\"src\",\"RGB\"),a=n(\"dst\",\"RGB\"),o=(i=e.def(t,\"[\",i,\"]\"),e.def(t,\"[\",n(\"src\",\"Alpha\"),\"]\"));return[i,a=e.def(t,\"[\",a,\"]\"),o,t=e.def(t,\"[\",n(\"dst\",\"Alpha\"),\"]\")]});case\"blend.equation\":return e(function(t){return\"string\"==typeof t?[J[t],J[t]]:\"object\"==typeof t?[J[t.rgb],J[t.alpha]]:void 0},function(t,e,r){var n=t.constants.blendEquations,i=e.def(),a=e.def();return(t=t.cond(\"typeof \",r,'===\"string\"')).then(i,\"=\",a,\"=\",n,\"[\",r,\"];\"),t.else(i,\"=\",n,\"[\",r,\".rgb];\",a,\"=\",n,\"[\",r,\".alpha];\"),e(t),[i,a]});case\"blend.color\":return e(function(t){return a(4,function(e){return+t[e]})},function(t,e,r){return a(4,function(t){return e.def(\"+\",r,\"[\",t,\"]\")})});case\"stencil.mask\":return e(function(t){return 0|t},function(t,e,r){return e.def(r,\"|0\")});case\"stencil.func\":return e(function(t){return[kt[t.cmp||\"keep\"],t.ref||0,\"mask\"in t?t.mask:-1]},function(t,e,r){return[t=e.def('\"cmp\" in ',r,\"?\",t.constants.compareFuncs,\"[\",r,\".cmp]\",\":\",7680),e.def(r,\".ref|0\"),e=e.def('\"mask\" in ',r,\"?\",r,\".mask|0:-1\")]});case\"stencil.opFront\":case\"stencil.opBack\":return e(function(e){return[\"stencil.opBack\"===t?1029:1028,Tt[e.fail||\"keep\"],Tt[e.zfail||\"keep\"],Tt[e.zpass||\"keep\"]]},function(e,r,n){function i(t){return r.def('\"',t,'\" in ',n,\"?\",a,\"[\",n,\".\",t,\"]:\",7680)}var a=e.constants.stencilOps;return[\"stencil.opBack\"===t?1029:1028,i(\"fail\"),i(\"zfail\"),i(\"zpass\")]});case\"polygonOffset.offset\":return e(function(t){return[0|t.factor,0|t.units]},function(t,e,r){return[e.def(r,\".factor|0\"),e=e.def(r,\".units|0\")]});case\"cull.face\":return e(function(t){var e=0;return\"front\"===t?e=1028:\"back\"===t&&(e=1029),e},function(t,e,r){return e.def(r,'===\"front\"?',1028,\":\",1029)});case\"lineWidth\":return e(function(t){return t},function(t,e,r){return r});case\"frontFace\":return e(function(t){return At[t]},function(t,e,r){return e.def(r+'===\"cw\"?2304:2305')});case\"colorMask\":return e(function(t){return t.map(function(t){return!!t})},function(t,e,r){return a(4,function(t){return\"!!\"+r+\"[\"+t+\"]\"})});case\"sample.coverage\":return e(function(t){return[\"value\"in t?t.value:1,!!t.invert]},function(t,e,r){return[e.def('\"value\" in ',r,\"?+\",r,\".value:1\"),e=e.def(\"!!\",r,\".invert\")]})}}),i}(t),u=w(t),h=s.viewport;return h&&(c.viewport=h),(s=s[h=m(\"scissor.box\")])&&(c[h]=s),(o={framebuffer:o,draw:l,shader:u,state:c,dirty:s=0<Object.keys(c).length}).profile=function(t){var e,r=t.static;if(t=t.dynamic,\"profile\"in r){var n=!!r.profile;(e=R(function(t,e){return n})).enable=n}else if(\"profile\"in t){var i=t.profile;e=F(i,function(t,e){return t.invoke(e,i)})}return e}(t),o.uniforms=function(t,e){var r=t.static,n=t.dynamic,i={};return Object.keys(r).forEach(function(t){var e,n=r[t];if(\"number\"==typeof n||\"boolean\"==typeof n)e=R(function(){return n});else if(\"function\"==typeof n){var o=n._reglType;\"texture2d\"===o||\"textureCube\"===o?e=R(function(t){return t.link(n)}):\"framebuffer\"!==o&&\"framebufferCube\"!==o||(e=R(function(t){return t.link(n.color[0])}))}else v(n)&&(e=R(function(t){return t.global.def(\"[\",a(n.length,function(t){return n[t]}),\"]\")}));e.value=n,i[t]=e}),Object.keys(n).forEach(function(t){var e=n[t];i[t]=F(e,function(t,r){return t.invoke(r,e)})}),i}(r),o.attributes=T(e),o.context=function(t){var e=t.static,r=t.dynamic,n={};return Object.keys(e).forEach(function(t){var r=e[t];n[t]=R(function(t,e){return\"number\"==typeof r||\"boolean\"==typeof r?\"\"+r:t.link(r)})}),Object.keys(r).forEach(function(t){var e=r[t];n[t]=F(e,function(t,r){return t.invoke(r,e)})}),n}(n),o}function M(t,e,r){var n=t.shared.context,i=t.scope();Object.keys(r).forEach(function(a){e.save(n,\".\"+a),i(n,\".\",a,\"=\",r[a].append(t,e),\";\")}),e(i)}function S(t,e,r,n){var i,a=(s=t.shared).gl,o=s.framebuffer;Q&&(i=e.def(s.extensions,\".webgl_draw_buffers\"));var s=(l=t.constants).drawBuffer,l=l.backBuffer;t=r?r.append(t,e):e.def(o,\".next\"),n||e(\"if(\",t,\"!==\",o,\".cur){\"),e(\"if(\",t,\"){\",a,\".bindFramebuffer(\",36160,\",\",t,\".framebuffer);\"),Q&&e(i,\".drawBuffersWEBGL(\",s,\"[\",t,\".colorAttachments.length]);\"),e(\"}else{\",a,\".bindFramebuffer(\",36160,\",null);\"),Q&&e(i,\".drawBuffersWEBGL(\",l,\");\"),e(\"}\",o,\".cur=\",t,\";\"),n||e(\"}\")}function E(t,e,r){var n=t.shared,i=n.gl,o=t.current,s=t.next,l=n.current,c=n.next,u=t.cond(l,\".dirty\");nt.forEach(function(e){var n,h;if(!((e=m(e))in r.state))if(e in s){n=s[e],h=o[e];var f=a(tt[e].length,function(t){return u.def(n,\"[\",t,\"]\")});u(t.cond(f.map(function(t,e){return t+\"!==\"+h+\"[\"+e+\"]\"}).join(\"||\")).then(i,\".\",at[e],\"(\",f,\");\",f.map(function(t,e){return h+\"[\"+e+\"]=\"+t}).join(\";\"),\";\"))}else n=u.def(c,\".\",e),f=t.cond(n,\"!==\",l,\".\",e),u(f),e in it?f(t.cond(n).then(i,\".enable(\",it[e],\");\").else(i,\".disable(\",it[e],\");\"),l,\".\",e,\"=\",n,\";\"):f(i,\".\",at[e],\"(\",n,\");\",l,\".\",e,\"=\",n,\";\")}),0===Object.keys(r.state).length&&u(l,\".dirty=false;\"),e(u)}function C(t,e,r,n){var i=t.shared,a=t.current,o=i.current,s=i.gl;z(Object.keys(r)).forEach(function(i){var l=r[i];if(!n||n(l)){var c=l.append(t,e);if(it[i]){var u=it[i];D(l)?e(s,c?\".enable(\":\".disable(\",u,\");\"):e(t.cond(c).then(s,\".enable(\",u,\");\").else(s,\".disable(\",u,\");\")),e(o,\".\",i,\"=\",c,\";\")}else if(v(c)){var h=a[i];e(s,\".\",at[i],\"(\",c,\");\",c.map(function(t,e){return h+\"[\"+e+\"]=\"+t}).join(\";\"),\";\")}else e(s,\".\",at[i],\"(\",c,\");\",o,\".\",i,\"=\",c,\";\")}})}function L(t,e){$&&(t.instancing=e.def(t.shared.extensions,\".angle_instanced_arrays\"))}function B(t,e,r,n,i){function a(){return\"undefined\"==typeof performance?\"Date.now()\":\"performance.now()\"}function o(t){t(c=e.def(),\"=\",a(),\";\"),\"string\"==typeof i?t(f,\".count+=\",i,\";\"):t(f,\".count++;\"),d&&(n?t(u=e.def(),\"=\",g,\".getNumPendingQueries();\"):t(g,\".beginQuery(\",f,\");\"))}function s(t){t(f,\".cpuTime+=\",a(),\"-\",c,\";\"),d&&(n?t(g,\".pushScopeStats(\",u,\",\",g,\".getNumPendingQueries(),\",f,\");\"):t(g,\".endQuery();\"))}function l(t){var r=e.def(p,\".profile\");e(p,\".profile=\",t,\";\"),e.exit(p,\".profile=\",r,\";\")}var c,u,h=t.shared,f=t.stats,p=h.current,g=h.timer;if(r=r.profile){if(D(r))return void(r.enable?(o(e),s(e.exit),l(\"true\")):l(\"false\"));l(r=r.append(t,e))}else r=e.def(p,\".profile\");o(h=t.block()),e(\"if(\",r,\"){\",h,\"}\"),s(t=t.block()),e.exit(\"if(\",r,\"){\",t,\"}\")}function N(t,e,r,n,i){function a(r,n,i){function a(){e(\"if(!\",u,\".buffer){\",l,\".enableVertexAttribArray(\",c,\");}\");var r,a=i.type;r=i.size?e.def(i.size,\"||\",n):n,e(\"if(\",u,\".type!==\",a,\"||\",u,\".size!==\",r,\"||\",p.map(function(t){return u+\".\"+t+\"!==\"+i[t]}).join(\"||\"),\"){\",l,\".bindBuffer(\",34962,\",\",h,\".buffer);\",l,\".vertexAttribPointer(\",[c,r,a,i.normalized,i.stride,i.offset],\");\",u,\".type=\",a,\";\",u,\".size=\",r,\";\",p.map(function(t){return u+\".\"+t+\"=\"+i[t]+\";\"}).join(\"\"),\"}\"),$&&(a=i.divisor,e(\"if(\",u,\".divisor!==\",a,\"){\",t.instancing,\".vertexAttribDivisorANGLE(\",[c,a],\");\",u,\".divisor=\",a,\";}\"))}function s(){e(\"if(\",u,\".buffer){\",l,\".disableVertexAttribArray(\",c,\");\",\"}if(\",bt.map(function(t,e){return u+\".\"+t+\"!==\"+f[e]}).join(\"||\"),\"){\",l,\".vertexAttrib4f(\",c,\",\",f,\");\",bt.map(function(t,e){return u+\".\"+t+\"=\"+f[e]+\";\"}).join(\"\"),\"}\")}var l=o.gl,c=e.def(r,\".location\"),u=e.def(o.attributes,\"[\",c,\"]\");r=i.state;var h=i.buffer,f=[i.x,i.y,i.z,i.w],p=[\"buffer\",\"normalized\",\"offset\",\"stride\"];1===r?a():2===r?s():(e(\"if(\",r,\"===\",1,\"){\"),a(),e(\"}else{\"),s(),e(\"}\"))}var o=t.shared;n.forEach(function(n){var o,s=n.name,l=r.attributes[s];if(l){if(!i(l))return;o=l.append(t,e)}else{if(!i(Mt))return;var c=t.scopeAttrib(s);o={},Object.keys(new Z).forEach(function(t){o[t]=e.def(c,\".\",t)})}a(t.link(n),function(t){switch(t){case 35664:case 35667:case 35671:return 2;case 35665:case 35668:case 35672:return 3;case 35666:case 35669:case 35673:return 4;default:return 1}}(n.info.type),o)})}function j(t,r,n,i,o){for(var s,l=t.shared,c=l.gl,u=0;u<i.length;++u){var h,f=(g=i[u]).name,p=g.info.type,d=n.uniforms[f],g=t.link(g)+\".location\";if(d){if(!o(d))continue;if(D(d)){if(f=d.value,35678===p||35680===p)r(c,\".uniform1i(\",g,\",\",(p=t.link(f._texture||f.color[0]._texture))+\".bind());\"),r.exit(p,\".unbind();\");else if(35674===p||35675===p||35676===p)d=2,35675===p?d=3:35676===p&&(d=4),r(c,\".uniformMatrix\",d,\"fv(\",g,\",false,\",f=t.global.def(\"new Float32Array([\"+Array.prototype.slice.call(f)+\"])\"),\");\");else{switch(p){case 5126:s=\"1f\";break;case 35664:s=\"2f\";break;case 35665:s=\"3f\";break;case 35666:s=\"4f\";break;case 35670:case 5124:s=\"1i\";break;case 35671:case 35667:s=\"2i\";break;case 35672:case 35668:s=\"3i\";break;case 35673:s=\"4i\";break;case 35669:s=\"4i\"}r(c,\".uniform\",s,\"(\",g,\",\",v(f)?Array.prototype.slice.call(f):f,\");\")}continue}h=d.append(t,r)}else{if(!o(Mt))continue;h=r.def(l.uniforms,\"[\",e.id(f),\"]\")}switch(35678===p?r(\"if(\",h,\"&&\",h,'._reglType===\"framebuffer\"){',h,\"=\",h,\".color[0];\",\"}\"):35680===p&&r(\"if(\",h,\"&&\",h,'._reglType===\"framebufferCube\"){',h,\"=\",h,\".color[0];\",\"}\"),f=1,p){case 35678:case 35680:p=r.def(h,\"._texture\"),r(c,\".uniform1i(\",g,\",\",p,\".bind());\"),r.exit(p,\".unbind();\");continue;case 5124:case 35670:s=\"1i\";break;case 35667:case 35671:s=\"2i\",f=2;break;case 35668:case 35672:s=\"3i\",f=3;break;case 35669:case 35673:s=\"4i\",f=4;break;case 5126:s=\"1f\";break;case 35664:s=\"2f\",f=2;break;case 35665:s=\"3f\",f=3;break;case 35666:s=\"4f\",f=4;break;case 35674:s=\"Matrix2fv\";break;case 35675:s=\"Matrix3fv\";break;case 35676:s=\"Matrix4fv\"}if(r(c,\".uniform\",s,\"(\",g,\",\"),\"M\"===s.charAt(0)){g=Math.pow(p-35674+2,2);var m=t.global.def(\"new Float32Array(\",g,\")\");r(\"false,(Array.isArray(\",h,\")||\",h,\" instanceof Float32Array)?\",h,\":(\",a(g,function(t){return m+\"[\"+t+\"]=\"+h+\"[\"+t+\"]\"}),\",\",m,\")\")}else r(1<f?a(f,function(t){return h+\"[\"+t+\"]\"}):h);r(\");\")}}function U(t,e,r,n){function i(i){var a=f[i];return a?a.contextDep&&n.contextDynamic||a.propDep?a.append(t,r):a.append(t,e):e.def(h,\".\",i)}function a(){function t(){r(l,\".drawElementsInstancedANGLE(\",[d,v,m,g+\"<<((\"+m+\"-5121)>>1)\",s],\");\")}function e(){r(l,\".drawArraysInstancedANGLE(\",[d,g,v,s],\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}function o(){function t(){r(u+\".drawElements(\"+[d,v,m,g+\"<<((\"+m+\"-5121)>>1)\"]+\");\")}function e(){r(u+\".drawArrays(\"+[d,g,v]+\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}var s,l,c=t.shared,u=c.gl,h=c.draw,f=n.draw,p=function(){var i=f.elements,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(h,\".\",\"elements\"),i&&a(\"if(\"+i+\")\"+u+\".bindBuffer(34963,\"+i+\".buffer.buffer);\"),i}(),d=i(\"primitive\"),g=i(\"offset\"),v=function(){var i=f.count,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(h,\".\",\"count\"),i}();if(\"number\"==typeof v){if(0===v)return}else r(\"if(\",v,\"){\"),r.exit(\"}\");$&&(s=i(\"instances\"),l=t.instancing);var m=p+\".type\",y=f.elements&&D(f.elements);$&&(\"number\"!=typeof s||0<=s)?\"string\"==typeof s?(r(\"if(\",s,\">0){\"),a(),r(\"}else if(\",s,\"<0){\"),o(),r(\"}\")):a():o()}function q(t,e,r,n,i){return i=(e=b()).proc(\"body\",i),$&&(e.instancing=i.def(e.shared.extensions,\".angle_instanced_arrays\")),t(e,i,r,n),e.compile().body}function H(t,e,r,n){L(t,e),N(t,e,r,n.attributes,function(){return!0}),j(t,e,r,n.uniforms,function(){return!0}),U(t,e,e,r)}function G(t,e,r,n){function i(){return!0}t.batchId=\"a1\",L(t,e),N(t,e,r,n.attributes,i),j(t,e,r,n.uniforms,i),U(t,e,e,r)}function Y(t,e,r,n){function i(t){return t.contextDep&&o||t.propDep}function a(t){return!i(t)}L(t,e);var o=r.contextDep,s=e.def(),l=e.def();t.shared.props=l,t.batchId=s;var c=t.scope(),u=t.scope();e(c.entry,\"for(\",s,\"=0;\",s,\"<\",\"a1\",\";++\",s,\"){\",l,\"=\",\"a0\",\"[\",s,\"];\",u,\"}\",c.exit),r.needsContext&&M(t,u,r.context),r.needsFramebuffer&&S(t,u,r.framebuffer),C(t,u,r.state,i),r.profile&&i(r.profile)&&B(t,u,r,!1,!0),n?(N(t,c,r,n.attributes,a),N(t,u,r,n.attributes,i),j(t,c,r,n.uniforms,a),j(t,u,r,n.uniforms,i),U(t,c,u,r)):(e=t.global.def(\"{}\"),n=r.shader.progVar.append(t,u),l=u.def(n,\".id\"),c=u.def(e,\"[\",l,\"]\"),u(t.shared.gl,\".useProgram(\",n,\".program);\",\"if(!\",c,\"){\",c,\"=\",e,\"[\",l,\"]=\",t.link(function(e){return q(G,t,r,e,2)}),\"(\",n,\");}\",c,\".call(this,a0[\",s,\"],\",s,\");\"))}function W(t,r){function n(e){var n=r.shader[e];n&&i.set(a.shader,\".\"+e,n.append(t,i))}var i=t.proc(\"scope\",3);t.batchId=\"a2\";var a=t.shared,o=a.current;M(t,i,r.context),r.framebuffer&&r.framebuffer.append(t,i),z(Object.keys(r.state)).forEach(function(e){var n=r.state[e].append(t,i);v(n)?n.forEach(function(r,n){i.set(t.next[e],\"[\"+n+\"]\",r)}):i.set(a.next,\".\"+e,n)}),B(t,i,r,!0,!0),[\"elements\",\"offset\",\"count\",\"instances\",\"primitive\"].forEach(function(e){var n=r.draw[e];n&&i.set(a.draw,\".\"+e,\"\"+n.append(t,i))}),Object.keys(r.uniforms).forEach(function(n){i.set(a.uniforms,\"[\"+e.id(n)+\"]\",r.uniforms[n].append(t,i))}),Object.keys(r.attributes).forEach(function(e){var n=r.attributes[e].append(t,i),a=t.scopeAttrib(e);Object.keys(new Z).forEach(function(t){i.set(a,\".\"+t,n[t])})}),n(\"vert\"),n(\"frag\"),0<Object.keys(r.state).length&&(i(o,\".dirty=true;\"),i.exit(o,\".dirty=true;\")),i(\"a1(\",t.shared.context,\",a0,\",t.batchId,\");\")}function X(t,e,r){var n=e.static[r];if(n&&function(t){if(\"object\"==typeof t&&!v(t)){for(var e=Object.keys(t),r=0;r<e.length;++r)if(V.isDynamic(t[e[r]]))return!0;return!1}}(n)){var i=t.global,a=Object.keys(n),o=!1,s=!1,l=!1,c=t.global.def(\"{}\");a.forEach(function(e){var r=n[e];if(V.isDynamic(r))\"function\"==typeof r&&(r=n[e]=V.unbox(r)),e=F(r,null),o=o||e.thisDep,l=l||e.propDep,s=s||e.contextDep;else{switch(i(c,\".\",e,\"=\"),typeof r){case\"number\":i(r);break;case\"string\":i('\"',r,'\"');break;case\"object\":Array.isArray(r)&&i(\"[\",r.join(),\"]\");break;default:i(t.link(r))}i(\";\")}}),e.dynamic[r]=new V.DynamicVariable(4,{thisDep:o,contextDep:s,propDep:l,ref:c,append:function(t,e){a.forEach(function(r){var i=n[r];V.isDynamic(i)&&(i=t.invoke(e,i),e(c,\".\",r,\"=\",i,\";\"))})}}),delete e.static[r]}}var Z=u.Record,J={add:32774,subtract:32778,\"reverse subtract\":32779};r.ext_blend_minmax&&(J.min=32775,J.max=32776);var $=r.angle_instanced_arrays,Q=r.webgl_draw_buffers,tt={dirty:!0,profile:g.profile},et={},nt=[],it={},at={};y(\"dither\",3024),y(\"blend.enable\",3042),x(\"blend.color\",\"blendColor\",[0,0,0,0]),x(\"blend.equation\",\"blendEquationSeparate\",[32774,32774]),x(\"blend.func\",\"blendFuncSeparate\",[1,0,1,0]),y(\"depth.enable\",2929,!0),x(\"depth.func\",\"depthFunc\",513),x(\"depth.range\",\"depthRange\",[0,1]),x(\"depth.mask\",\"depthMask\",!0),x(\"colorMask\",\"colorMask\",[!0,!0,!0,!0]),y(\"cull.enable\",2884),x(\"cull.face\",\"cullFace\",1029),x(\"frontFace\",\"frontFace\",2305),x(\"lineWidth\",\"lineWidth\",1),y(\"polygonOffset.enable\",32823),x(\"polygonOffset.offset\",\"polygonOffset\",[0,0]),y(\"sample.alpha\",32926),y(\"sample.enable\",32928),x(\"sample.coverage\",\"sampleCoverage\",[1,!1]),y(\"stencil.enable\",2960),x(\"stencil.mask\",\"stencilMask\",-1),x(\"stencil.func\",\"stencilFunc\",[519,0,-1]),x(\"stencil.opFront\",\"stencilOpSeparate\",[1028,7680,7680,7680]),x(\"stencil.opBack\",\"stencilOpSeparate\",[1029,7680,7680,7680]),y(\"scissor.enable\",3089),x(\"scissor.box\",\"scissor\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]),x(\"viewport\",\"viewport\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]);var ot={gl:t,context:p,strings:e,next:et,current:tt,draw:f,elements:o,buffer:i,shader:h,attributes:u.state,uniforms:c,framebuffer:l,extensions:r,timer:d,isBufferArgs:O},st={primTypes:rt,compareFuncs:kt,blendFuncs:wt,blendEquations:J,stencilOps:Tt,glTypes:K,orientationType:At};Q&&(st.backBuffer=[1029],st.drawBuffer=a(n.maxDrawbuffers,function(t){return 0===t?[0]:a(t,function(t){return 36064+t})}));var lt=0;return{next:et,current:tt,procs:function(){var t=b(),e=t.proc(\"poll\"),r=t.proc(\"refresh\"),i=t.block();e(i),r(i);var o,s=t.shared,l=s.gl,c=s.next,u=s.current;i(u,\".dirty=false;\"),S(t,e),S(t,r,null,!0),$&&(o=t.link($));for(var h=0;h<n.maxAttributes;++h){var f=r.def(s.attributes,\"[\",h,\"]\"),p=t.cond(f,\".buffer\");p.then(l,\".enableVertexAttribArray(\",h,\");\",l,\".bindBuffer(\",34962,\",\",f,\".buffer.buffer);\",l,\".vertexAttribPointer(\",h,\",\",f,\".size,\",f,\".type,\",f,\".normalized,\",f,\".stride,\",f,\".offset);\").else(l,\".disableVertexAttribArray(\",h,\");\",l,\".vertexAttrib4f(\",h,\",\",f,\".x,\",f,\".y,\",f,\".z,\",f,\".w);\",f,\".buffer=null;\"),r(p),$&&r(o,\".vertexAttribDivisorANGLE(\",h,\",\",f,\".divisor);\")}return Object.keys(it).forEach(function(n){var a=it[n],o=i.def(c,\".\",n),s=t.block();s(\"if(\",o,\"){\",l,\".enable(\",a,\")}else{\",l,\".disable(\",a,\")}\",u,\".\",n,\"=\",o,\";\"),r(s),e(\"if(\",o,\"!==\",u,\".\",n,\"){\",s,\"}\")}),Object.keys(at).forEach(function(n){var o,s,h=at[n],f=tt[n],p=t.block();p(l,\".\",h,\"(\"),v(f)?(h=f.length,o=t.global.def(c,\".\",n),s=t.global.def(u,\".\",n),p(a(h,function(t){return o+\"[\"+t+\"]\"}),\");\",a(h,function(t){return s+\"[\"+t+\"]=\"+o+\"[\"+t+\"];\"}).join(\"\")),e(\"if(\",a(h,function(t){return o+\"[\"+t+\"]!==\"+s+\"[\"+t+\"]\"}).join(\"||\"),\"){\",p,\"}\")):(o=i.def(c,\".\",n),s=i.def(u,\".\",n),p(o,\");\",u,\".\",n,\"=\",o,\";\"),e(\"if(\",o,\"!==\",s,\"){\",p,\"}\")),r(p)}),t.compile()}(),compile:function(t,e,r,n,i){var a=b();return a.stats=a.link(i),Object.keys(e.static).forEach(function(t){X(a,e,t)}),_t.forEach(function(e){X(a,t,e)}),r=A(t,e,r,n),function(t,e){var r=t.proc(\"draw\",1);L(t,r),M(t,r,e.context),S(t,r,e.framebuffer),E(t,r,e),C(t,r,e.state),B(t,r,e,!1,!0);var n=e.shader.progVar.append(t,r);if(r(t.shared.gl,\".useProgram(\",n,\".program);\"),e.shader.program)H(t,r,e,e.shader.program);else{var i=t.global.def(\"{}\"),a=r.def(n,\".id\"),o=r.def(i,\"[\",a,\"]\");r(t.cond(o).then(o,\".call(this,a0);\").else(o,\"=\",i,\"[\",a,\"]=\",t.link(function(r){return q(H,t,e,r,1)}),\"(\",n,\");\",o,\".call(this,a0);\"))}0<Object.keys(e.state).length&&r(t.shared.current,\".dirty=true;\")}(a,r),W(a,r),function(t,e){function r(t){return t.contextDep&&i||t.propDep}var n=t.proc(\"batch\",2);t.batchId=\"0\",L(t,n);var i=!1,a=!0;Object.keys(e.context).forEach(function(t){i=i||e.context[t].propDep}),i||(M(t,n,e.context),a=!1);var o=!1;if((s=e.framebuffer)?(s.propDep?i=o=!0:s.contextDep&&i&&(o=!0),o||S(t,n,s)):S(t,n,null),e.state.viewport&&e.state.viewport.propDep&&(i=!0),E(t,n,e),C(t,n,e.state,function(t){return!r(t)}),e.profile&&r(e.profile)||B(t,n,e,!1,\"a1\"),e.contextDep=i,e.needsContext=a,e.needsFramebuffer=o,(a=e.shader.progVar).contextDep&&i||a.propDep)Y(t,n,e,null);else if(a=a.append(t,n),n(t.shared.gl,\".useProgram(\",a,\".program);\"),e.shader.program)Y(t,n,e,e.shader.program);else{var s=t.global.def(\"{}\"),l=(o=n.def(a,\".id\"),n.def(s,\"[\",o,\"]\"));n(t.cond(l).then(l,\".call(this,a0,a1);\").else(l,\"=\",s,\"[\",o,\"]=\",t.link(function(r){return q(Y,t,e,r,2)}),\"(\",a,\");\",l,\".call(this,a0,a1);\"))}0<Object.keys(e.state).length&&n(t.shared.current,\".dirty=true;\")}(a,r),a.compile()}}}function N(t,e){for(var r=0;r<t.length;++r)if(t[r]===e)return r;return-1}var j=function(t,e){for(var r=Object.keys(e),n=0;n<r.length;++n)t[r[n]]=e[r[n]];return t},U=0,V={DynamicVariable:t,define:function(r,n){return new t(r,e(n+\"\"))},isDynamic:function(e){return\"function\"==typeof e&&!e._reglType||e instanceof t},unbox:function(e,r){return\"function\"==typeof e?new t(0,e):e},accessor:e},q={next:\"function\"==typeof requestAnimationFrame?function(t){return requestAnimationFrame(t)}:function(t){return setTimeout(t,16)},cancel:\"function\"==typeof cancelAnimationFrame?function(t){return cancelAnimationFrame(t)}:clearTimeout},H=\"undefined\"!=typeof performance&&performance.now?function(){return performance.now()}:function(){return+new Date},G=s();G.zero=s();var Y=function(t,e){var r=1;e.ext_texture_filter_anisotropic&&(r=t.getParameter(34047));var n=1,i=1;e.webgl_draw_buffers&&(n=t.getParameter(34852),i=t.getParameter(36063));var a=!!e.oes_texture_float;if(a){a=t.createTexture(),t.bindTexture(3553,a),t.texImage2D(3553,0,6408,1,1,0,6408,5126,null);var o=t.createFramebuffer();if(t.bindFramebuffer(36160,o),t.framebufferTexture2D(36160,36064,3553,a,0),t.bindTexture(3553,null),36053!==t.checkFramebufferStatus(36160))a=!1;else{t.viewport(0,0,1,1),t.clearColor(1,0,0,1),t.clear(16384);var s=G.allocType(5126,4);t.readPixels(0,0,1,1,6408,5126,s),t.getError()?a=!1:(t.deleteFramebuffer(o),t.deleteTexture(a),a=1===s[0]),G.freeType(s)}}return s=!0,\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion)||/Edge/.test(navigator.userAgent))||(s=t.createTexture(),o=G.allocType(5121,36),t.activeTexture(33984),t.bindTexture(34067,s),t.texImage2D(34069,0,6408,3,3,0,6408,5121,o),G.freeType(o),t.bindTexture(34067,null),t.deleteTexture(s),s=!t.getError()),{colorBits:[t.getParameter(3410),t.getParameter(3411),t.getParameter(3412),t.getParameter(3413)],depthBits:t.getParameter(3414),stencilBits:t.getParameter(3415),subpixelBits:t.getParameter(3408),extensions:Object.keys(e).filter(function(t){return!!e[t]}),maxAnisotropic:r,maxDrawbuffers:n,maxColorAttachments:i,pointSizeDims:t.getParameter(33901),lineWidthDims:t.getParameter(33902),maxViewportDims:t.getParameter(3386),maxCombinedTextureUnits:t.getParameter(35661),maxCubeMapSize:t.getParameter(34076),maxRenderbufferSize:t.getParameter(34024),maxTextureUnits:t.getParameter(34930),maxTextureSize:t.getParameter(3379),maxAttributes:t.getParameter(34921),maxVertexUniforms:t.getParameter(36347),maxVertexTextureUnits:t.getParameter(35660),maxVaryingVectors:t.getParameter(36348),maxFragmentUniforms:t.getParameter(36349),glsl:t.getParameter(35724),renderer:t.getParameter(7937),vendor:t.getParameter(7936),version:t.getParameter(7938),readFloat:a,npotTextureCube:s}},W=function(t){return t instanceof Uint8Array||t instanceof Uint16Array||t instanceof Uint32Array||t instanceof Int8Array||t instanceof Int16Array||t instanceof Int32Array||t instanceof Float32Array||t instanceof Float64Array||t instanceof Uint8ClampedArray},X=function(t){return Object.keys(t).map(function(e){return t[e]})},Z={shape:function(t){for(var e=[];t.length;t=t[0])e.push(t.length);return e},flatten:function(t,e,r,n){var i=1;if(e.length)for(var a=0;a<e.length;++a)i*=e[a];else i=0;switch(r=n||G.allocType(r,i),e.length){case 0:break;case 1:for(n=e[0],e=0;e<n;++e)r[e]=t[e];break;case 2:for(n=e[0],e=e[1],a=i=0;a<n;++a)for(var o=t[a],s=0;s<e;++s)r[i++]=o[s];break;case 3:c(t,e[0],e[1],e[2],r,0);break;default:!function t(e,r,n,i,a){for(var o=1,s=n+1;s<r.length;++s)o*=r[s];var l=r[n];if(4==r.length-n){var u=r[n+1],h=r[n+2];for(r=r[n+3],s=0;s<l;++s)c(e[s],u,h,r,i,a),a+=o}else for(s=0;s<l;++s)t(e[s],r,n+1,i,a),a+=o}(t,e,0,r,0)}return r}},J={\"[object Int8Array]\":5120,\"[object Int16Array]\":5122,\"[object Int32Array]\":5124,\"[object Uint8Array]\":5121,\"[object Uint8ClampedArray]\":5121,\"[object Uint16Array]\":5123,\"[object Uint32Array]\":5125,\"[object Float32Array]\":5126,\"[object Float64Array]\":5121,\"[object ArrayBuffer]\":5121},K={int8:5120,int16:5122,int32:5124,uint8:5121,uint16:5123,uint32:5125,float:5126,float32:5126},$={dynamic:35048,stream:35040,static:35044},Q=Z.flatten,tt=Z.shape,et=[];et[5120]=1,et[5122]=2,et[5124]=4,et[5121]=1,et[5123]=2,et[5125]=4,et[5126]=4;var rt={points:0,point:0,lines:1,line:1,triangles:4,triangle:4,\"line loop\":2,\"line strip\":3,\"triangle strip\":5,\"triangle fan\":6},nt=new Float32Array(1),it=new Uint32Array(nt.buffer),at=[9984,9986,9985,9987],ot=[0,6409,6410,6407,6408],st={};st[6409]=st[6406]=st[6402]=1,st[34041]=st[6410]=2,st[6407]=st[35904]=3,st[6408]=st[35906]=4;var lt=m(\"HTMLCanvasElement\"),ct=m(\"CanvasRenderingContext2D\"),ut=m(\"ImageBitmap\"),ht=m(\"HTMLImageElement\"),ft=m(\"HTMLVideoElement\"),pt=Object.keys(J).concat([lt,ct,ut,ht,ft]),dt=[];dt[5121]=1,dt[5126]=4,dt[36193]=2,dt[5123]=2,dt[5125]=4;var gt=[];gt[32854]=2,gt[32855]=2,gt[36194]=2,gt[34041]=4,gt[33776]=.5,gt[33777]=.5,gt[33778]=1,gt[33779]=1,gt[35986]=.5,gt[35987]=1,gt[34798]=1,gt[35840]=.5,gt[35841]=.25,gt[35842]=.5,gt[35843]=.25,gt[36196]=.5;var vt=[];vt[32854]=2,vt[32855]=2,vt[36194]=2,vt[33189]=2,vt[36168]=1,vt[34041]=4,vt[35907]=4,vt[34836]=16,vt[34842]=8,vt[34843]=6;var mt=function(t,e,r,n,i){function a(t){this.id=c++,this.refCount=1,this.renderbuffer=t,this.format=32854,this.height=this.width=0,i.profile&&(this.stats={size:0})}function o(e){var r=e.renderbuffer;t.bindRenderbuffer(36161,null),t.deleteRenderbuffer(r),e.renderbuffer=null,e.refCount=0,delete u[e.id],n.renderbufferCount--}var s={rgba4:32854,rgb565:36194,\"rgb5 a1\":32855,depth:33189,stencil:36168,\"depth stencil\":34041};e.ext_srgb&&(s.srgba=35907),e.ext_color_buffer_half_float&&(s.rgba16f=34842,s.rgb16f=34843),e.webgl_color_buffer_float&&(s.rgba32f=34836);var l=[];Object.keys(s).forEach(function(t){l[s[t]]=t});var c=0,u={};return a.prototype.decRef=function(){0>=--this.refCount&&o(this)},i.profile&&(n.getTotalRenderbufferSize=function(){var t=0;return Object.keys(u).forEach(function(e){t+=u[e].stats.size}),t}),{create:function(e,r){function o(e,r){var n=0,a=0,u=32854;if(\"object\"==typeof e&&e?(\"shape\"in e?(n=0|(a=e.shape)[0],a=0|a[1]):(\"radius\"in e&&(n=a=0|e.radius),\"width\"in e&&(n=0|e.width),\"height\"in e&&(a=0|e.height)),\"format\"in e&&(u=s[e.format])):\"number\"==typeof e?(n=0|e,a=\"number\"==typeof r?0|r:n):e||(n=a=1),n!==c.width||a!==c.height||u!==c.format)return o.width=c.width=n,o.height=c.height=a,c.format=u,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,u,n,a),i.profile&&(c.stats.size=vt[c.format]*c.width*c.height),o.format=l[c.format],o}var c=new a(t.createRenderbuffer());return u[c.id]=c,n.renderbufferCount++,o(e,r),o.resize=function(e,r){var n=0|e,a=0|r||n;return n===c.width&&a===c.height?o:(o.width=c.width=n,o.height=c.height=a,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,c.format,n,a),i.profile&&(c.stats.size=vt[c.format]*c.width*c.height),o)},o._reglType=\"renderbuffer\",o._renderbuffer=c,i.profile&&(o.stats=c.stats),o.destroy=function(){c.decRef()},o},clear:function(){X(u).forEach(o)},restore:function(){X(u).forEach(function(e){e.renderbuffer=t.createRenderbuffer(),t.bindRenderbuffer(36161,e.renderbuffer),t.renderbufferStorage(36161,e.format,e.width,e.height)}),t.bindRenderbuffer(36161,null)}}},yt=[];yt[6408]=4,yt[6407]=3;var xt=[];xt[5121]=1,xt[5126]=4,xt[36193]=2;var bt=[\"x\",\"y\",\"z\",\"w\"],_t=\"blend.func blend.equation stencil.func stencil.opFront stencil.opBack sample.coverage viewport scissor.box polygonOffset.offset\".split(\" \"),wt={0:0,1:1,zero:0,one:1,\"src color\":768,\"one minus src color\":769,\"src alpha\":770,\"one minus src alpha\":771,\"dst color\":774,\"one minus dst color\":775,\"dst alpha\":772,\"one minus dst alpha\":773,\"constant color\":32769,\"one minus constant color\":32770,\"constant alpha\":32771,\"one minus constant alpha\":32772,\"src alpha saturate\":776},kt={never:512,less:513,\"<\":513,equal:514,\"=\":514,\"==\":514,\"===\":514,lequal:515,\"<=\":515,greater:516,\">\":516,notequal:517,\"!=\":517,\"!==\":517,gequal:518,\">=\":518,always:519},Tt={0:0,zero:0,keep:7680,replace:7681,increment:7682,decrement:7683,\"increment wrap\":34055,\"decrement wrap\":34056,invert:5386},At={cw:2304,ccw:2305},Mt=new I(!1,!1,!1,function(){});return function(t){function e(){if(0===Z.length)w&&w.update(),Q=null;else{Q=q.next(e),h();for(var t=Z.length-1;0<=t;--t){var r=Z[t];r&&r(P,null,0)}v.flush(),w&&w.update()}}function r(){!Q&&0<Z.length&&(Q=q.next(e))}function n(){Q&&(q.cancel(e),Q=null)}function a(t){t.preventDefault(),n(),J.forEach(function(t){t()})}function o(t){v.getError(),y.restore(),D.restore(),z.restore(),R.restore(),F.restore(),U.restore(),w&&w.restore(),G.procs.refresh(),r(),K.forEach(function(t){t()})}function s(t){function e(t){var e={},r={};return Object.keys(t).forEach(function(n){var i=t[n];V.isDynamic(i)?r[n]=V.unbox(i,n):e[n]=i}),{dynamic:r,static:e}}var r=e(t.context||{}),n=e(t.uniforms||{}),i=e(t.attributes||{}),a=e(function(t){function e(t){if(t in r){var e=r[t];delete r[t],Object.keys(e).forEach(function(n){r[t+\".\"+n]=e[n]})}}var r=j({},t);return delete r.uniforms,delete r.attributes,delete r.context,\"stencil\"in r&&r.stencil.op&&(r.stencil.opBack=r.stencil.opFront=r.stencil.op,delete r.stencil.op),e(\"blend\"),e(\"depth\"),e(\"cull\"),e(\"stencil\"),e(\"polygonOffset\"),e(\"scissor\"),e(\"sample\"),r}(t));t={gpuTime:0,cpuTime:0,count:0};var o=(r=G.compile(a,i,n,r,t)).draw,s=r.batch,l=r.scope,c=[];return j(function(t,e){var r;if(\"function\"==typeof t)return l.call(this,null,t,0);if(\"function\"==typeof e)if(\"number\"==typeof t)for(r=0;r<t;++r)l.call(this,null,e,r);else{if(!Array.isArray(t))return l.call(this,t,e,0);for(r=0;r<t.length;++r)l.call(this,t[r],e,r)}else if(\"number\"==typeof t){if(0<t)return s.call(this,function(t){for(;c.length<t;)c.push(null);return c}(0|t),0|t)}else{if(!Array.isArray(t))return o.call(this,t);if(t.length)return s.call(this,t,t.length)}},{stats:t})}function l(t,e){var r=0;G.procs.poll();var n=e.color;n&&(v.clearColor(+n[0]||0,+n[1]||0,+n[2]||0,+n[3]||0),r|=16384),\"depth\"in e&&(v.clearDepth(+e.depth),r|=256),\"stencil\"in e&&(v.clearStencil(0|e.stencil),r|=1024),v.clear(r)}function c(t){return Z.push(t),r(),{cancel:function(){var e=N(Z,t);Z[e]=function t(){var e=N(Z,t);Z[e]=Z[Z.length-1],--Z.length,0>=Z.length&&n()}}}}function u(){var t=W.viewport,e=W.scissor_box;t[0]=t[1]=e[0]=e[1]=0,P.viewportWidth=P.framebufferWidth=P.drawingBufferWidth=t[2]=e[2]=v.drawingBufferWidth,P.viewportHeight=P.framebufferHeight=P.drawingBufferHeight=t[3]=e[3]=v.drawingBufferHeight}function h(){P.tick+=1,P.time=g(),u(),G.procs.poll()}function f(){u(),G.procs.refresh(),w&&w.update()}function g(){return(H()-k)/1e3}if(!(t=i(t)))return null;var v=t.gl,m=v.getContextAttributes();v.isContextLost();var y=function(t,e){function r(e){var r;e=e.toLowerCase();try{r=n[e]=t.getExtension(e)}catch(t){}return!!r}for(var n={},i=0;i<e.extensions.length;++i){var a=e.extensions[i];if(!r(a))return e.onDestroy(),e.onDone('\"'+a+'\" extension is not supported by the current WebGL context, try upgrading your system or a different browser'),null}return e.optionalExtensions.forEach(r),{extensions:n,restore:function(){Object.keys(n).forEach(function(t){if(n[t]&&!r(t))throw Error(\"(regl): error restoring extension \"+t)})}}}(v,t);if(!y)return null;var x=function(){var t={\"\":0},e=[\"\"];return{id:function(r){var n=t[r];return n||(n=t[r]=e.length,e.push(r),n)},str:function(t){return e[t]}}}(),b={bufferCount:0,elementsCount:0,framebufferCount:0,shaderCount:0,textureCount:0,cubeCount:0,renderbufferCount:0,maxTextureUnits:0},_=y.extensions,w=function(t,e){function r(){this.endQueryIndex=this.startQueryIndex=-1,this.sum=0,this.stats=null}function n(t,e,n){var i=o.pop()||new r;i.startQueryIndex=t,i.endQueryIndex=e,i.sum=0,i.stats=n,s.push(i)}if(!e.ext_disjoint_timer_query)return null;var i=[],a=[],o=[],s=[],l=[],c=[];return{beginQuery:function(t){var r=i.pop()||e.ext_disjoint_timer_query.createQueryEXT();e.ext_disjoint_timer_query.beginQueryEXT(35007,r),a.push(r),n(a.length-1,a.length,t)},endQuery:function(){e.ext_disjoint_timer_query.endQueryEXT(35007)},pushScopeStats:n,update:function(){var t,r;if(0!==(t=a.length)){c.length=Math.max(c.length,t+1),l.length=Math.max(l.length,t+1),l[0]=0;var n=c[0]=0;for(r=t=0;r<a.length;++r){var u=a[r];e.ext_disjoint_timer_query.getQueryObjectEXT(u,34919)?(n+=e.ext_disjoint_timer_query.getQueryObjectEXT(u,34918),i.push(u)):a[t++]=u,l[r+1]=n,c[r+1]=t}for(a.length=t,r=t=0;r<s.length;++r){var h=(n=s[r]).startQueryIndex;u=n.endQueryIndex,n.sum+=l[u]-l[h],h=c[h],(u=c[u])===h?(n.stats.gpuTime+=n.sum/1e6,o.push(n)):(n.startQueryIndex=h,n.endQueryIndex=u,s[t++]=n)}s.length=t}},getNumPendingQueries:function(){return a.length},clear:function(){i.push.apply(i,a);for(var t=0;t<i.length;t++)e.ext_disjoint_timer_query.deleteQueryEXT(i[t]);a.length=0,i.length=0},restore:function(){a.length=0,i.length=0}}}(0,_),k=H(),C=v.drawingBufferWidth,L=v.drawingBufferHeight,P={tick:0,time:0,viewportWidth:C,viewportHeight:L,framebufferWidth:C,framebufferHeight:L,drawingBufferWidth:C,drawingBufferHeight:L,pixelRatio:t.pixelRatio},O=Y(v,_),z=(C=function(t,e,r,n){for(t=r.maxAttributes,e=Array(t),r=0;r<t;++r)e[r]=new M;return{Record:M,scope:{},state:e}}(v,_,O),p(v,b,t,C)),I=d(v,_,z,b),D=S(v,x,b,t),R=T(v,_,O,function(){G.procs.poll()},P,b,t),F=mt(v,_,0,b,t),U=A(v,_,O,R,F,b),G=B(v,x,_,O,z,I,0,U,{},C,D,{elements:null,primitive:4,count:-1,offset:0,instances:-1},P,w,t),W=(x=E(v,U,G.procs.poll,P),G.next),X=v.canvas,Z=[],J=[],K=[],$=[t.onDestroy],Q=null;X&&(X.addEventListener(\"webglcontextlost\",a,!1),X.addEventListener(\"webglcontextrestored\",o,!1));var tt=U.setFBO=s({framebuffer:V.define.call(null,1,\"framebuffer\")});return f(),m=j(s,{clear:function(t){if(\"framebuffer\"in t)if(t.framebuffer&&\"framebufferCube\"===t.framebuffer_reglType)for(var e=0;6>e;++e)tt(j({framebuffer:t.framebuffer.faces[e]},t),l);else tt(t,l);else l(0,t)},prop:V.define.bind(null,1),context:V.define.bind(null,2),this:V.define.bind(null,3),draw:s({}),buffer:function(t){return z.create(t,34962,!1,!1)},elements:function(t){return I.create(t,!1)},texture:R.create2D,cube:R.createCube,renderbuffer:F.create,framebuffer:U.create,framebufferCube:U.createCube,attributes:m,frame:c,on:function(t,e){var r;switch(t){case\"frame\":return c(e);case\"lost\":r=J;break;case\"restore\":r=K;break;case\"destroy\":r=$}return r.push(e),{cancel:function(){for(var t=0;t<r.length;++t)if(r[t]===e){r[t]=r[r.length-1],r.pop();break}}}},limits:O,hasExtension:function(t){return 0<=O.extensions.indexOf(t.toLowerCase())},read:x,destroy:function(){Z.length=0,n(),X&&(X.removeEventListener(\"webglcontextlost\",a),X.removeEventListener(\"webglcontextrestored\",o)),D.clear(),U.clear(),F.clear(),R.clear(),I.clear(),z.clear(),w&&w.clear(),$.forEach(function(t){t()})},_gl:v,_refresh:f,poll:function(){h(),w&&w.update()},now:g,stats:b}),t.onDone(null,m),m}},\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=i():n.createREGL=i()},{}],503:[function(t,e,r){\"use strict\";var n,i=\"\";e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"expected a string\");if(1===e)return t;if(2===e)return t+t;var r=t.length*e;if(n!==t||\"undefined\"==typeof n)n=t,i=\"\";else if(i.length>=r)return i.substr(0,r);for(;r>i.length&&e>1;)1&e&&(i+=t),e>>=1,t+=t;return i=(i+=t).substr(0,r)}},{}],504:[function(t,e,r){(function(t){e.exports=t.performance&&t.performance.now?function(){return performance.now()}:Date.now||function(){return+new Date}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{}],505:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=t[t.length-1],n=e,i=e-2;i>=0;--i){var a=r,o=t[i],s=(r=a+o)-a,l=o-s;l&&(t[--n]=r,r=l)}for(var c=0,i=n;i<e;++i){var a=t[i],o=r,s=(r=a+o)-a,l=o-s;l&&(t[c++]=l)}return t[c++]=r,t.length=c,t}},{}],506:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-compress\"),s=6;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(2===t.length)return[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\");for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(l(t,r)),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return function t(e){if(1===e.length)return e[0];if(2===e.length)return[\"sum(\",e[0],\",\",e[1],\")\"].join(\"\");var r=e.length>>1;return[\"sum(\",t(e.slice(0,r)),\",\",t(e.slice(r)),\")\"].join(\"\")}(e);var n}function u(t){return new Function(\"sum\",\"scale\",\"prod\",\"compress\",[\"function robustDeterminant\",t,\"(m){return compress(\",c(function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m[\",r,\"][\",n,\"]\"].join(\"\")}return e}(t)),\")};return robustDeterminant\",t].join(\"\"))(i,a,n,o)}var h=[function(){return[0]},function(t){return[t[0][0]]}];!function(){for(;h.length<s;)h.push(u(h.length));for(var t=[],r=[\"function robustDeterminant(m){switch(m.length){\"],n=0;n<s;++n)t.push(\"det\"+n),r.push(\"case \",n,\":return det\",n,\"(m);\");r.push(\"}var det=CACHE[m.length];if(!det)det=CACHE[m.length]=gen(m.length);return det(m);}return robustDeterminant\"),t.push(\"CACHE\",\"gen\",r.join(\"\"));var i=Function.apply(void 0,t);for(e.exports=i.apply(void 0,h.concat([h,u])),n=0;n<h.length;++n)e.exports[n]=h[n]}()},{\"robust-compress\":505,\"robust-scale\":512,\"robust-sum\":515,\"two-product\":543}],507:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\");e.exports=function(t,e){for(var r=n(t[0],e[0]),a=1;a<t.length;++a)r=i(r,n(t[a],e[a]));return r}},{\"robust-sum\":515,\"two-product\":543}],508:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-subtract\"),o=t(\"robust-scale\"),s=6;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",c(t.slice(0,e)),\",\",c(t.slice(e)),\")\"].join(\"\")}function u(t,e){if(\"m\"===t.charAt(0)){if(\"w\"===e.charAt(0)){var r=t.split(\"[\");return[\"w\",e.substr(1),\"m\",r[0].substr(1)].join(\"\")}return[\"prod(\",t,\",\",e,\")\"].join(\"\")}return u(e,t)}function h(t){if(2===t.length)return[[\"diff(\",u(t[0][0],t[1][1]),\",\",u(t[1][0],t[0][1]),\")\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(h(l(t,r))),\",\",(n=r,!0&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function f(t,e){for(var r=[],n=0;n<e-2;++n)r.push([\"prod(m\",t,\"[\",n,\"],m\",t,\"[\",n,\"])\"].join(\"\"));return c(r)}function p(t){for(var e=[],r=[],s=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-2,\"]\"].join(\"\")}return e}(t),u=0;u<t;++u)s[0][u]=\"1\",s[t-1][u]=\"w\"+u;for(u=0;u<t;++u)0==(1&u)?e.push.apply(e,h(l(s,u))):r.push.apply(r,h(l(s,u)));var p=c(e),d=c(r),g=\"exactInSphere\"+t,v=[];for(u=0;u<t;++u)v.push(\"m\"+u);var m=[\"function \",g,\"(\",v.join(),\"){\"];for(u=0;u<t;++u){m.push(\"var w\",u,\"=\",f(u,t),\";\");for(var y=0;y<t;++y)y!==u&&m.push(\"var w\",u,\"m\",y,\"=scale(w\",u,\",m\",y,\"[0]);\")}return m.push(\"var p=\",p,\",n=\",d,\",d=diff(p,n);return d[d.length-1];}return \",g),new Function(\"sum\",\"diff\",\"prod\",\"scale\",m.join(\"\"))(i,a,n,o)}var d=[function(){return 0},function(){return 0},function(){return 0}];!function(){for(;d.length<=s;)d.push(p(d.length));for(var t=[],r=[\"slow\"],n=0;n<=s;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function testInSphere(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=s;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return testInSphere\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[function(t){var e=d[t.length];return e||(e=d[t.length]=p(t.length)),e.apply(void 0,t)}].concat(d)),n=0;n<=s;++n)e.exports[n]=d[n]}()},{\"robust-scale\":512,\"robust-subtract\":514,\"robust-sum\":515,\"two-product\":543}],509:[function(t,e,r){\"use strict\";var n=t(\"robust-determinant\"),i=6;function a(t){for(var e=\"robustLinearSolve\"+t+\"d\",r=[\"function \",e,\"(A,b){return [\"],i=0;i<t;++i){r.push(\"det([\");for(var a=0;a<t;++a){a>0&&r.push(\",\"),r.push(\"[\");for(var o=0;o<t;++o)o>0&&r.push(\",\"),o===i?r.push(\"+b[\",a,\"]\"):r.push(\"+A[\",a,\"][\",o,\"]\");r.push(\"]\")}r.push(\"]),\")}r.push(\"det(A)]}return \",e);var s=new Function(\"det\",r.join(\"\"));return s(t<6?n[t]:n)}var o=[function(){return[0]},function(t,e){return[[e[0]],[t[0][0]]]}];!function(){for(;o.length<i;)o.push(a(o.length));for(var t=[],r=[\"function dispatchLinearSolve(A,b){switch(A.length){\"],n=0;n<i;++n)t.push(\"s\"+n),r.push(\"case \",n,\":return s\",n,\"(A,b);\");r.push(\"}var s=CACHE[A.length];if(!s)s=CACHE[A.length]=g(A.length);return s(A,b)}return dispatchLinearSolve\"),t.push(\"CACHE\",\"g\",r.join(\"\"));var s=Function.apply(void 0,t);for(e.exports=s.apply(void 0,o.concat([o,a])),n=0;n<i;++n)e.exports[n]=o[n]}()},{\"robust-determinant\":506}],510:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-subtract\"),s=5;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",c(t.slice(0,e)),\",\",c(t.slice(e)),\")\"].join(\"\")}function u(t){if(2===t.length)return[[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(u(l(t,r))),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function h(t){for(var e=[],r=[],s=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-1,\"]\"].join(\"\")}return e}(t),h=[],f=0;f<t;++f)0==(1&f)?e.push.apply(e,u(l(s,f))):r.push.apply(r,u(l(s,f))),h.push(\"m\"+f);var p=c(e),d=c(r),g=\"orientation\"+t+\"Exact\",v=[\"function \",g,\"(\",h.join(),\"){var p=\",p,\",n=\",d,\",d=sub(p,n);return d[d.length-1];};return \",g].join(\"\");return new Function(\"sum\",\"prod\",\"scale\",\"sub\",v)(i,n,a,o)}var f=h(3),p=h(4),d=[function(){return 0},function(){return 0},function(t,e){return e[0]-t[0]},function(t,e,r){var n,i=(t[1]-r[1])*(e[0]-r[0]),a=(t[0]-r[0])*(e[1]-r[1]),o=i-a;if(i>0){if(a<=0)return o;n=i+a}else{if(!(i<0))return o;if(a>=0)return o;n=-(i+a)}var s=3.3306690738754716e-16*n;return o>=s||o<=-s?o:f(t,e,r)},function(t,e,r,n){var i=t[0]-n[0],a=e[0]-n[0],o=r[0]-n[0],s=t[1]-n[1],l=e[1]-n[1],c=r[1]-n[1],u=t[2]-n[2],h=e[2]-n[2],f=r[2]-n[2],d=a*c,g=o*l,v=o*s,m=i*c,y=i*l,x=a*s,b=u*(d-g)+h*(v-m)+f*(y-x),_=7.771561172376103e-16*((Math.abs(d)+Math.abs(g))*Math.abs(u)+(Math.abs(v)+Math.abs(m))*Math.abs(h)+(Math.abs(y)+Math.abs(x))*Math.abs(f));return b>_||-b>_?b:p(t,e,r,n)}];!function(){for(;d.length<=s;)d.push(h(d.length));for(var t=[],r=[\"slow\"],n=0;n<=s;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function getOrientation(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=s;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return getOrientation\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[function(t){var e=d[t.length];return e||(e=d[t.length]=h(t.length)),e.apply(void 0,t)}].concat(d)),n=0;n<=s;++n)e.exports[n]=d[n]}()},{\"robust-scale\":512,\"robust-subtract\":514,\"robust-sum\":515,\"two-product\":543}],511:[function(t,e,r){\"use strict\";var n=t(\"robust-sum\"),i=t(\"robust-scale\");e.exports=function(t,e){if(1===t.length)return i(e,t[0]);if(1===e.length)return i(t,e[0]);if(0===t.length||0===e.length)return[0];var r=[0];if(t.length<e.length)for(var a=0;a<t.length;++a)r=n(r,i(e,t[a]));else for(var a=0;a<e.length;++a)r=n(r,i(t,e[a]));return r}},{\"robust-scale\":512,\"robust-sum\":515}],512:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"two-sum\");e.exports=function(t,e){var r=t.length;if(1===r){var a=n(t[0],e);return a[0]?a:[a[1]]}var o=new Array(2*r),s=[.1,.1],l=[.1,.1],c=0;n(t[0],e,s),s[0]&&(o[c++]=s[0]);for(var u=1;u<r;++u){n(t[u],e,l);var h=s[1];i(h,l[0],s),s[0]&&(o[c++]=s[0]);var f=l[1],p=s[1],d=f+p,g=d-f,v=p-g;s[1]=d,v&&(o[c++]=v)}s[1]&&(o[c++]=s[1]);0===c&&(o[c++]=0);return o.length=c,o}},{\"two-product\":543,\"two-sum\":544}],513:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){var a=n(t,r,i),o=n(e,r,i);if(a>0&&o>0||a<0&&o<0)return!1;var s=n(r,t,e),l=n(i,t,e);if(s>0&&l>0||s<0&&l<0)return!1;if(0===a&&0===o&&0===s&&0===l)return function(t,e,r,n){for(var i=0;i<2;++i){var a=t[i],o=e[i],s=Math.min(a,o),l=Math.max(a,o),c=r[i],u=n[i],h=Math.min(c,u),f=Math.max(c,u);if(f<s||l<h)return!1}return!0}(t,e,r,i);return!0};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":510}],514:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],-e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,h=t[l],f=u(h),p=-e[c],d=u(p);f<d?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=-e[c],d=u(p)));l<r&&f<d||c>=n?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p)));var g,v,m=i+a,y=m-i,x=a-y,b=x,_=m;for(;l<r&&c<n;)f<d?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p))),(x=(a=b)-(y=(m=i+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g;for(;l<r;)(x=(a=b)-(y=(m=(i=h)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(l+=1)<r&&(h=t[l]);for(;c<n;)(x=(a=b)-(y=(m=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(c+=1)<n&&(p=-e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],515:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,h=t[l],f=u(h),p=e[c],d=u(p);f<d?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=e[c],d=u(p)));l<r&&f<d||c>=n?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=e[c],d=u(p)));var g,v,m=i+a,y=m-i,x=a-y,b=x,_=m;for(;l<r&&c<n;)f<d?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=e[c],d=u(p))),(x=(a=b)-(y=(m=i+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g;for(;l<r;)(x=(a=b)-(y=(m=(i=h)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(l+=1)<r&&(h=t[l]);for(;c<n;)(x=(a=b)-(y=(m=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(c+=1)<n&&(p=e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],516:[function(t,e,r){\"use strict\";e.exports=function(t){return t<0?-1:t>0?1:0}},{}],517:[function(t,e,r){\"use strict\";e.exports=function(t){return i(n(t))};var n=t(\"boundary-cells\"),i=t(\"reduce-simplicial-complex\")},{\"boundary-cells\":95,\"reduce-simplicial-complex\":489}],518:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,s){r=r||0,\"undefined\"==typeof s&&(s=function(t){for(var e=t.length,r=0,n=0;n<e;++n)r=0|Math.max(r,t[n].length);return r-1}(t));if(0===t.length||s<1)return{cells:[],vertexIds:[],vertexWeights:[]};var l=function(t,e){for(var r=t.length,n=i.mallocUint8(r),a=0;a<r;++a)n[a]=t[a]<e|0;return n}(e,+r),c=function(t,e){for(var r=t.length,o=e*(e+1)/2*r|0,s=i.mallocUint32(2*o),l=0,c=0;c<r;++c)for(var u=t[c],e=u.length,h=0;h<e;++h)for(var f=0;f<h;++f){var p=u[f],d=u[h];s[l++]=0|Math.min(p,d),s[l++]=0|Math.max(p,d)}a(n(s,[l/2|0,2]));for(var g=2,c=2;c<l;c+=2)s[c-2]===s[c]&&s[c-1]===s[c+1]||(s[g++]=s[c],s[g++]=s[c+1]);return n(s,[g/2|0,2])}(t,s),u=function(t,e,r,a){for(var o=t.data,s=t.shape[0],l=i.mallocDouble(s),c=0,u=0;u<s;++u){var h=o[2*u],f=o[2*u+1];if(r[h]!==r[f]){var p=e[h],d=e[f];o[2*c]=h,o[2*c+1]=f,l[c++]=(d-a)/(d-p)}}return t.shape[0]=c,n(l,[c])}(c,e,l,+r),h=function(t,e){var r=i.mallocInt32(2*e),n=t.shape[0],a=t.data;r[0]=0;for(var o=0,s=0;s<n;++s){var l=a[2*s];if(l!==o){for(r[2*o+1]=s;++o<l;)r[2*o]=s,r[2*o+1]=s;r[2*o]=s}}r[2*o+1]=n;for(;++o<e;)r[2*o]=r[2*o+1]=n;return r}(c,0|e.length),f=o(s)(t,c.data,h,l),p=function(t){for(var e=0|t.shape[0],r=t.data,n=new Array(e),i=0;i<e;++i)n[i]=[r[2*i],r[2*i+1]];return n}(c),d=[].slice.call(u.data,0,u.shape[0]);return i.free(l),i.free(c.data),i.free(u.data),i.free(h),{cells:f,vertexIds:p,vertexWeights:d}};var n=t(\"ndarray\"),i=t(\"typedarray-pool\"),a=t(\"ndarray-sort\"),o=t(\"./lib/codegen\")},{\"./lib/codegen\":519,ndarray:450,\"ndarray-sort\":448,\"typedarray-pool\":545}],519:[function(t,e,r){\"use strict\";e.exports=function(t){var e=a[t];e||(e=a[t]=function(t){var e=0,r=new Array(t+1);r[0]=[[]];for(var a=1;a<=t;++a)for(var o=r[a]=i(a),s=0;s<o.length;++s)e=Math.max(e,o[a].length);var l=[\"function B(C,E,i,j){\",\"var a=Math.min(i,j)|0,b=Math.max(i,j)|0,l=C[2*a],h=C[2*a+1];\",\"while(l<h){\",\"var m=(l+h)>>1,v=E[2*m+1];\",\"if(v===b){return m}\",\"if(b<v){h=m}else{l=m+1}\",\"}\",\"return l;\",\"};\",\"function getContour\",t,\"d(F,E,C,S){\",\"var n=F.length,R=[];\",\"for(var i=0;i<n;++i){var c=F[i],l=c.length;\"];function c(t){if(!(t.length<=0)){l.push(\"R.push(\");for(var e=0;e<t.length;++e){var r=t[e];e>0&&l.push(\",\"),l.push(\"[\");for(var n=0;n<r.length;++n){var i=r[n];n>0&&l.push(\",\"),l.push(\"B(C,E,c[\",i[0],\"],c[\",i[1],\"])\")}l.push(\"]\")}l.push(\");\")}}for(var a=t+1;a>1;--a){a<t+1&&l.push(\"else \"),l.push(\"if(l===\",a,\"){\");for(var u=[],s=0;s<a;++s)u.push(\"(S[c[\"+s+\"]]<<\"+s+\")\");l.push(\"var M=\",u.join(\"+\"),\";if(M===0||M===\",(1<<a)-1,\"){continue}switch(M){\");for(var o=r[a-1],s=0;s<o.length;++s)l.push(\"case \",s,\":\"),c(o[s]),l.push(\"break;\");l.push(\"}}\")}return l.push(\"}return R;};return getContour\",t,\"d\"),new Function(\"pool\",l.join(\"\"))(n)}(t));return e};var n=t(\"typedarray-pool\"),i=t(\"marching-simplex-table\"),a={}},{\"marching-simplex-table\":427,\"typedarray-pool\":545}],520:[function(t,e,r){\"use strict\";var n=t(\"bit-twiddle\"),i=t(\"union-find\");function a(t,e){var r=t.length,n=t.length-e.length,i=Math.min;if(n)return n;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return(s=t[0]+t[1]-e[0]-e[1])||i(t[0],t[1])-i(e[0],e[1]);case 3:var a=t[0]+t[1],o=e[0]+e[1];if(s=a+t[2]-(o+e[2]))return s;var s,l=i(t[0],t[1]),c=i(e[0],e[1]);return(s=i(l,t[2])-i(c,e[2]))||i(l+t[2],a)-i(c+e[2],o);default:var u=t.slice(0);u.sort();var h=e.slice(0);h.sort();for(var f=0;f<r;++f)if(n=u[f]-h[f])return n;return 0}}function o(t,e){return a(t[0],e[0])}function s(t,e){if(e){for(var r=t.length,n=new Array(r),i=0;i<r;++i)n[i]=[t[i],e[i]];n.sort(o);for(i=0;i<r;++i)t[i]=n[i][0],e[i]=n[i][1];return t}return t.sort(a),t}function l(t){if(0===t.length)return[];for(var e=1,r=t.length,n=1;n<r;++n){var i=t[n];if(a(i,t[n-1])){if(n===e){e++;continue}t[e++]=i}}return t.length=e,t}function c(t,e){for(var r=0,n=t.length-1,i=-1;r<=n;){var o=r+n>>1,s=a(t[o],e);s<=0?(0===s&&(i=o),r=o+1):s>0&&(n=o-1)}return i}function u(t,e){for(var r=new Array(t.length),i=0,o=r.length;i<o;++i)r[i]=[];for(var s=[],l=(i=0,e.length);i<l;++i)for(var u=e[i],h=u.length,f=1,p=1<<h;f<p;++f){s.length=n.popCount(f);for(var d=0,g=0;g<h;++g)f&1<<g&&(s[d++]=u[g]);var v=c(t,s);if(!(v<0))for(;r[v++].push(i),!(v>=t.length||0!==a(t[v],s)););}return r}function h(t,e){if(e<0)return[];for(var r=[],i=(1<<e+1)-1,a=0;a<t.length;++a)for(var o=t[a],l=i;l<1<<o.length;l=n.nextCombination(l)){for(var c=new Array(e+1),u=0,h=0;h<o.length;++h)l&1<<h&&(c[u++]=o[h]);r.push(c)}return s(r)}r.dimension=function(t){for(var e=0,r=Math.max,n=0,i=t.length;n<i;++n)e=r(e,t[n].length);return e-1},r.countVertices=function(t){for(var e=-1,r=Math.max,n=0,i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)e=r(e,a[o]);return e+1},r.cloneCells=function(t){for(var e=new Array(t.length),r=0,n=t.length;r<n;++r)e[r]=t[r].slice(0);return e},r.compareCells=a,r.normalize=s,r.unique=l,r.findCell=c,r.incidence=u,r.dual=function(t,e){if(!e)return u(l(h(t,0)),t);for(var r=new Array(e),n=0;n<e;++n)r[n]=[];n=0;for(var i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)r[a[o]].push(n);return r},r.explode=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0|i.length,o=1,l=1<<a;o<l;++o){for(var c=[],u=0;u<a;++u)o>>>u&1&&c.push(i[u]);e.push(c)}return s(e)},r.skeleton=h,r.boundary=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;++a){for(var l=new Array(i.length-1),c=0,u=0;c<o;++c)c!==a&&(l[u++]=i[c]);e.push(l)}return s(e)},r.connectedComponents=function(t,e){return e?function(t,e){for(var r=new i(e),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var s=o+1;s<a.length;++s)r.link(a[o],a[s]);var l=[],c=r.ranks;for(n=0;n<c.length;++n)c[n]=-1;for(n=0;n<t.length;++n){var u=r.find(t[n][0]);c[u]<0?(c[u]=l.length,l.push([t[n].slice(0)])):l[c[u]].push(t[n].slice(0))}return l}(t,e):function(t){for(var e=l(s(h(t,0))),r=new i(e.length),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var u=c(e,[a[o]]),f=o+1;f<a.length;++f)r.link(u,c(e,[a[f]]));var p=[],d=r.ranks;for(n=0;n<d.length;++n)d[n]=-1;for(n=0;n<t.length;++n){var g=r.find(c(e,[t[n][0]]));d[g]<0?(d[g]=p.length,p.push([t[n].slice(0)])):p[d[g]].push(t[n].slice(0))}return p}(t)}},{\"bit-twiddle\":92,\"union-find\":546}],521:[function(t,e,r){arguments[4][92][0].apply(r,arguments)},{dup:92}],522:[function(t,e,r){arguments[4][520][0].apply(r,arguments)},{\"bit-twiddle\":521,dup:520,\"union-find\":523}],523:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n,n.prototype.length=function(){return this.roots.length},n.prototype.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},n.prototype.find=function(t){for(var e=this.roots;e[t]!==t;){var r=e[t];e[t]=e[r],t=r}return t},n.prototype.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],524:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){for(var a=e.length,o=t.length,s=new Array(a),l=new Array(a),c=new Array(a),u=new Array(a),h=0;h<a;++h)s[h]=l[h]=-1,c[h]=1/0,u[h]=!1;for(var h=0;h<o;++h){var f=t[h];if(2!==f.length)throw new Error(\"Input must be a graph\");var p=f[1],d=f[0];-1!==l[d]?l[d]=-2:l[d]=p,-1!==s[p]?s[p]=-2:s[p]=d}function g(t){if(u[t])return 1/0;var r,i,a,o,c,h=s[t],f=l[t];return h<0||f<0?1/0:(r=e[t],i=e[h],a=e[f],o=Math.abs(n(r,i,a)),c=Math.sqrt(Math.pow(i[0]-a[0],2)+Math.pow(i[1]-a[1],2)),o/c)}function v(t,e){var r=T[t],n=T[e];T[t]=n,T[e]=r,A[r]=e,A[n]=t}function m(t){return c[T[t]]}function y(t){return 1&t?t-1>>1:(t>>1)-1}function x(t){for(var e=m(t);;){var r=e,n=2*t+1,i=2*(t+1),a=t;if(n<S){var o=m(n);o<r&&(a=n,r=o)}if(i<S){var s=m(i);s<r&&(a=i)}if(a===t)return t;v(t,a),t=a}}function b(t){for(var e=m(t);t>0;){var r=y(t);if(r>=0){var n=m(r);if(e<n){v(t,r),t=r;continue}}return t}}function _(){if(S>0){var t=T[0];return v(0,S-1),S-=1,x(0),t}return-1}function w(t,e){var r=T[t];return c[r]===e?t:(c[r]=-1/0,b(t),_(),c[r]=e,b((S+=1)-1))}function k(t){if(!u[t]){u[t]=!0;var e=s[t],r=l[t];s[r]>=0&&(s[r]=e),l[e]>=0&&(l[e]=r),A[e]>=0&&w(A[e],g(e)),A[r]>=0&&w(A[r],g(r))}}for(var T=[],A=new Array(a),h=0;h<a;++h){var M=c[h]=g(h);M<1/0?(A[h]=T.length,T.push(h)):A[h]=-1}for(var S=T.length,h=S>>1;h>=0;--h)x(h);for(;;){var E=_();if(E<0||c[E]>r)break;k(E)}for(var C=[],h=0;h<a;++h)u[h]||(A[h]=C.length,C.push(e[h].slice()));C.length;function L(t,e){if(t[e]<0)return e;var r=e,n=e;do{var i=t[n];if(!u[n]||i<0||i===n)break;if(i=t[n=i],!u[n]||i<0||i===n)break;n=i,r=t[r]}while(r!==n);for(var a=e;a!==n;a=t[a])t[a]=n;return n}var P=[];return t.forEach(function(t){var e=L(s,t[0]),r=L(l,t[1]);if(e>=0&&r>=0&&e!==r){var n=A[e],i=A[r];n!==i&&P.push([n,i])}}),i.unique(i.normalize(P)),{positions:C,edges:P}};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\")},{\"robust-orientation\":510,\"simplicial-complex\":522}],525:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,a,o,s;if(e[0][0]<e[1][0])r=e[0],a=e[1];else{if(!(e[0][0]>e[1][0]))return i(e,t);r=e[1],a=e[0]}if(t[0][0]<t[1][0])o=t[0],s=t[1];else{if(!(t[0][0]>t[1][0]))return-i(t,e);o=t[1],s=t[0]}var l=n(r,a,s),c=n(r,a,o);if(l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;if(l=n(s,o,a),c=n(s,o,r),l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;return a[0]-s[0]};var n=t(\"robust-orientation\");function i(t,e){var r,i,a,o;if(e[0][0]<e[1][0])r=e[0],i=e[1];else{if(!(e[0][0]>e[1][0])){var s=Math.min(t[0][1],t[1][1]),l=Math.max(t[0][1],t[1][1]),c=Math.min(e[0][1],e[1][1]),u=Math.max(e[0][1],e[1][1]);return l<c?l-c:s>u?s-u:l-u}r=e[1],i=e[0]}t[0][1]<t[1][1]?(a=t[0],o=t[1]):(a=t[1],o=t[0]);var h=n(i,r,a);return h||((h=n(i,r,o))||o-i)}},{\"robust-orientation\":510}],526:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=2*e,n=new Array(r),a=0;a<e;++a){var l=t[a],c=l[0][0]<l[1][0];n[2*a]=new h(l[0][0],l,c,a),n[2*a+1]=new h(l[1][0],l,!c,a)}n.sort(function(t,e){var r=t.x-e.x;return r||((r=t.create-e.create)||Math.min(t.segment[0][1],t.segment[1][1])-Math.min(e.segment[0][1],e.segment[1][1]))});for(var f=i(o),p=[],d=[],g=[],a=0;a<r;){for(var v=n[a].x,m=[];a<r;){var y=n[a];if(y.x!==v)break;a+=1,y.segment[0][0]===y.x&&y.segment[1][0]===y.x?y.create&&(y.segment[0][1]<y.segment[1][1]?(m.push(new u(y.segment[0][1],y.index,!0,!0)),m.push(new u(y.segment[1][1],y.index,!1,!1))):(m.push(new u(y.segment[1][1],y.index,!0,!1)),m.push(new u(y.segment[0][1],y.index,!1,!0)))):f=y.create?f.insert(y.segment,y.index):f.remove(y.segment)}p.push(f.root),d.push(v),g.push(m)}return new s(p,d,g)};var n=t(\"binary-search-bounds\"),i=t(\"functional-red-black-tree\"),a=t(\"robust-orientation\"),o=t(\"./lib/order-segments\");function s(t,e,r){this.slabs=t,this.coordinates=e,this.horizontal=r}function l(t,e){return t.y-e}function c(t,e){for(var r=null;t;){var n,i,o=t.key;o[0][0]<o[1][0]?(n=o[0],i=o[1]):(n=o[1],i=o[0]);var s=a(n,i,e);if(s<0)t=t.left;else if(s>0)if(e[0]!==o[1][0])r=t,t=t.right;else{if(l=c(t.right,e))return l;t=t.left}else{if(e[0]!==o[1][0])return t;var l;if(l=c(t.right,e))return l;t=t.left}}return r}function u(t,e,r,n){this.y=t,this.index=e,this.start=r,this.closed=n}function h(t,e,r,n){this.x=t,this.segment=e,this.create=r,this.index=n}s.prototype.castUp=function(t){var e=n.le(this.coordinates,t[0]);if(e<0)return-1;this.slabs[e];var r=c(this.slabs[e],t),i=-1;if(r&&(i=r.value),this.coordinates[e]===t[0]){var s=null;if(r&&(s=r.key),e>0){var u=c(this.slabs[e-1],t);u&&(s?o(u.key,s)>0&&(s=u.key,i=u.value):(i=u.value,s=u.key))}var h=this.horizontal[e];if(h.length>0){var f=n.ge(h,t[1],l);if(f<h.length){var p=h[f];if(t[1]===p.y){if(p.closed)return p.index;for(;f<h.length-1&&h[f+1].y===t[1];)if((p=h[f+=1]).closed)return p.index;if(p.y===t[1]&&!p.start){if((f+=1)>=h.length)return i;p=h[f]}}if(p.start)if(s){var d=a(s[0],s[1],[t[0],p.y]);s[0][0]>s[1][0]&&(d=-d),d>0&&(i=p.index)}else i=p.index;else p.y!==t[1]&&(i=p.index)}}}return i}},{\"./lib/order-segments\":525,\"binary-search-bounds\":91,\"functional-red-black-tree\":230,\"robust-orientation\":510}],527:[function(t,e,r){\"use strict\";var n=t(\"robust-dot-product\"),i=t(\"robust-sum\");function a(t,e){var r=i(n(t,e),[e[e.length-1]]);return r[r.length-1]}function o(t,e,r,n){var i=-e/(n-e);i<0?i=0:i>1&&(i=1);for(var a=1-i,o=t.length,s=new Array(o),l=0;l<o;++l)s[l]=i*t[l]+a*r[l];return s}e.exports=function(t,e){for(var r=[],n=[],i=a(t[t.length-1],e),s=t[t.length-1],l=t[0],c=0;c<t.length;++c,s=l){var u=a(l=t[c],e);if(i<0&&u>0||i>0&&u<0){var h=o(s,u,l,i);r.push(h),n.push(h.slice())}u<0?n.push(l.slice()):u>0?r.push(l.slice()):(r.push(l.slice()),n.push(l.slice())),i=u}return{positive:r,negative:n}},e.exports.positive=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c>=0&&r.push(s.slice()),n=c}return r},e.exports.negative=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c<=0&&r.push(s.slice()),n=c}return r}},{\"robust-dot-product\":507,\"robust-sum\":515}],528:[function(t,e,r){!function(){\"use strict\";var t={not_string:/[^s]/,not_bool:/[^t]/,not_type:/[^T]/,not_primitive:/[^v]/,number:/[diefg]/,numeric_arg:/[bcdiefguxX]/,json:/[j]/,not_json:/[^j]/,text:/^[^\\x25]+/,modulo:/^\\x25{2}/,placeholder:/^\\x25(?:([1-9]\\d*)\\$|\\(([^)]+)\\))?(\\+)?(0|'[^$])?(-)?(\\d+)?(?:\\.(\\d+))?([b-gijostTuvxX])/,key:/^([a-z_][a-z_\\d]*)/i,key_access:/^\\.([a-z_][a-z_\\d]*)/i,index_access:/^\\[(\\d+)\\]/,sign:/^[+-]/};function e(r){return function(r,n){var i,a,o,s,l,c,u,h,f,p=1,d=r.length,g=\"\";for(a=0;a<d;a++)if(\"string\"==typeof r[a])g+=r[a];else if(\"object\"==typeof r[a]){if((s=r[a]).keys)for(i=n[p],o=0;o<s.keys.length;o++){if(null==i)throw new Error(e('[sprintf] Cannot access property \"%s\" of undefined value \"%s\"',s.keys[o],s.keys[o-1]));i=i[s.keys[o]]}else i=s.param_no?n[s.param_no]:n[p++];if(t.not_type.test(s.type)&&t.not_primitive.test(s.type)&&i instanceof Function&&(i=i()),t.numeric_arg.test(s.type)&&\"number\"!=typeof i&&isNaN(i))throw new TypeError(e(\"[sprintf] expecting number but found %T\",i));switch(t.number.test(s.type)&&(h=i>=0),s.type){case\"b\":i=parseInt(i,10).toString(2);break;case\"c\":i=String.fromCharCode(parseInt(i,10));break;case\"d\":case\"i\":i=parseInt(i,10);break;case\"j\":i=JSON.stringify(i,null,s.width?parseInt(s.width):0);break;case\"e\":i=s.precision?parseFloat(i).toExponential(s.precision):parseFloat(i).toExponential();break;case\"f\":i=s.precision?parseFloat(i).toFixed(s.precision):parseFloat(i);break;case\"g\":i=s.precision?String(Number(i.toPrecision(s.precision))):parseFloat(i);break;case\"o\":i=(parseInt(i,10)>>>0).toString(8);break;case\"s\":i=String(i),i=s.precision?i.substring(0,s.precision):i;break;case\"t\":i=String(!!i),i=s.precision?i.substring(0,s.precision):i;break;case\"T\":i=Object.prototype.toString.call(i).slice(8,-1).toLowerCase(),i=s.precision?i.substring(0,s.precision):i;break;case\"u\":i=parseInt(i,10)>>>0;break;case\"v\":i=i.valueOf(),i=s.precision?i.substring(0,s.precision):i;break;case\"x\":i=(parseInt(i,10)>>>0).toString(16);break;case\"X\":i=(parseInt(i,10)>>>0).toString(16).toUpperCase()}t.json.test(s.type)?g+=i:(!t.number.test(s.type)||h&&!s.sign?f=\"\":(f=h?\"+\":\"-\",i=i.toString().replace(t.sign,\"\")),c=s.pad_char?\"0\"===s.pad_char?\"0\":s.pad_char.charAt(1):\" \",u=s.width-(f+i).length,l=s.width&&u>0?c.repeat(u):\"\",g+=s.align?f+i+l:\"0\"===c?f+l+i:l+f+i)}return g}(function(e){if(i[e])return i[e];var r,n=e,a=[],o=0;for(;n;){if(null!==(r=t.text.exec(n)))a.push(r[0]);else if(null!==(r=t.modulo.exec(n)))a.push(\"%\");else{if(null===(r=t.placeholder.exec(n)))throw new SyntaxError(\"[sprintf] unexpected placeholder\");if(r[2]){o|=1;var s=[],l=r[2],c=[];if(null===(c=t.key.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");for(s.push(c[1]);\"\"!==(l=l.substring(c[0].length));)if(null!==(c=t.key_access.exec(l)))s.push(c[1]);else{if(null===(c=t.index_access.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");s.push(c[1])}r[2]=s}else o|=2;if(3===o)throw new Error(\"[sprintf] mixing positional and named placeholders is not (yet) supported\");a.push({placeholder:r[0],param_no:r[1],keys:r[2],sign:r[3],pad_char:r[4],align:r[5],width:r[6],precision:r[7],type:r[8]})}n=n.substring(r[0].length)}return i[e]=a}(r),arguments)}function n(t,r){return e.apply(null,[t].concat(r||[]))}var i=Object.create(null);\"undefined\"!=typeof r&&(r.sprintf=e,r.vsprintf=n),\"undefined\"!=typeof window&&(window.sprintf=e,window.vsprintf=n)}()},{}],529:[function(t,e,r){\"use strict\";var n=t(\"parenthesis\");e.exports=function(t,e,r){if(null==t)throw Error(\"First argument should be a string\");if(null==e)throw Error(\"Separator should be a string or a RegExp\");r?(\"string\"==typeof r||Array.isArray(r))&&(r={ignore:r}):r={},null==r.escape&&(r.escape=!0),null==r.ignore?r.ignore=[\"[]\",\"()\",\"{}\",\"<>\",'\"\"',\"''\",\"``\",\"\\u201c\\u201d\",\"\\xab\\xbb\"]:(\"string\"==typeof r.ignore&&(r.ignore=[r.ignore]),r.ignore=r.ignore.map(function(t){return 1===t.length&&(t+=t),t}));var i=n.parse(t,{flat:!0,brackets:r.ignore}),a=i[0].split(e);if(r.escape){for(var o=[],s=0;s<a.length;s++){var l=a[s],c=a[s+1];\"\\\\\"===l[l.length-1]&&\"\\\\\"!==l[l.length-2]?(o.push(l+e+c),s++):o.push(l)}a=o}for(s=0;s<a.length;s++)i[0]=a[s],a[s]=n.stringify(i,{flat:!0});return a}},{parenthesis:458}],530:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=new Array(e),n=new Array(e),i=new Array(e),a=new Array(e),o=new Array(e),s=new Array(e),l=0;l<e;++l)r[l]=-1,n[l]=0,i[l]=!1,a[l]=0,o[l]=-1,s[l]=[];var c,u=0,h=[],f=[];function p(e){var l=[e],c=[e];for(r[e]=n[e]=u,i[e]=!0,u+=1;c.length>0;){e=c[c.length-1];var p=t[e];if(a[e]<p.length){for(var d=a[e];d<p.length;++d){var g=p[d];if(r[g]<0){r[g]=n[g]=u,i[g]=!0,u+=1,l.push(g),c.push(g);break}i[g]&&(n[e]=0|Math.min(n[e],n[g])),o[g]>=0&&s[e].push(o[g])}a[e]=d}else{if(n[e]===r[e]){for(var v=[],m=[],y=0,d=l.length-1;d>=0;--d){var x=l[d];if(i[x]=!1,v.push(x),m.push(s[x]),y+=s[x].length,o[x]=h.length,x===e){l.length=d;break}}h.push(v);for(var b=new Array(y),d=0;d<m.length;d++)for(var _=0;_<m[d].length;_++)b[--y]=m[d][_];f.push(b)}c.pop()}}}for(var l=0;l<e;++l)r[l]<0&&p(l);for(var l=0;l<f.length;l++){var d=f[l];if(0!==d.length){d.sort(function(t,e){return t-e}),c=[d[0]];for(var g=1;g<d.length;g++)d[g]!==d[g-1]&&c.push(d[g]);f[l]=c}}return{components:h,adjacencyList:f}}},{}],531:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(t.dimension<=0)return{positions:[],cells:[]};if(1===t.dimension)return function(t,e){for(var r=a(t,e),n=r.length,i=new Array(n),o=new Array(n),s=0;s<n;++s)i[s]=[r[s]],o[s]=[s];return{positions:i,cells:o}}(t,e);var r=t.order.join()+\"-\"+t.dtype,s=o[r],e=+e||0;s||(s=o[r]=function(t,e){var r=t.length,a=[\"'use strict';\"],o=\"surfaceNets\"+t.join(\"_\")+\"d\"+e;a.push(\"var contour=genContour({\",\"order:[\",t.join(),\"],\",\"scalarArguments: 3,\",\"phase:function phaseFunc(p,a,b,c) { return (p > c)|0 },\"),\"generic\"===e&&a.push(\"getters:[0],\");for(var s=[],l=[],c=0;c<r;++c)s.push(\"d\"+c),l.push(\"d\"+c);for(var c=0;c<1<<r;++c)s.push(\"v\"+c),l.push(\"v\"+c);for(var c=0;c<1<<r;++c)s.push(\"p\"+c),l.push(\"p\"+c);s.push(\"a\",\"b\",\"c\"),l.push(\"a\",\"c\"),a.push(\"vertex:function vertexFunc(\",s.join(),\"){\");for(var u=[],c=0;c<1<<r;++c)u.push(\"(p\"+c+\"<<\"+c+\")\");a.push(\"var m=(\",u.join(\"+\"),\")|0;if(m===0||m===\",(1<<(1<<r))-1,\"){return}\");var h=[],f=[];1<<(1<<r)<=128?(a.push(\"switch(m){\"),f=a):a.push(\"switch(m>>>7){\");for(var c=0;c<1<<(1<<r);++c){if(1<<(1<<r)>128&&c%128==0){h.length>0&&f.push(\"}}\");var p=\"vExtra\"+h.length;a.push(\"case \",c>>>7,\":\",p,\"(m&0x7f,\",l.join(),\");break;\"),f=[\"function \",p,\"(m,\",l.join(),\"){switch(m){\"],h.push(f)}f.push(\"case \",127&c,\":\");for(var d=new Array(r),g=new Array(r),v=new Array(r),m=new Array(r),y=0,x=0;x<r;++x)d[x]=[],g[x]=[],v[x]=0,m[x]=0;for(var x=0;x<1<<r;++x)for(var b=0;b<r;++b){var _=x^1<<b;if(!(_>x)&&!(c&1<<_)!=!(c&1<<x)){var w=1;c&1<<_?g[b].push(\"v\"+_+\"-v\"+x):(g[b].push(\"v\"+x+\"-v\"+_),w=-w),w<0?(d[b].push(\"-v\"+x+\"-v\"+_),v[b]+=2):(d[b].push(\"v\"+x+\"+v\"+_),v[b]-=2),y+=1;for(var k=0;k<r;++k)k!==b&&(_&1<<k?m[k]+=1:m[k]-=1)}}for(var T=[],b=0;b<r;++b)if(0===d[b].length)T.push(\"d\"+b+\"-0.5\");else{var A=\"\";v[b]<0?A=v[b]+\"*c\":v[b]>0&&(A=\"+\"+v[b]+\"*c\");var M=d[b].length/y*.5,S=.5+m[b]/y*.5;T.push(\"d\"+b+\"-\"+S+\"-\"+M+\"*(\"+d[b].join(\"+\")+A+\")/(\"+g[b].join(\"+\")+\")\")}f.push(\"a.push([\",T.join(),\"]);\",\"break;\")}a.push(\"}},\"),h.length>0&&f.push(\"}}\");for(var E=[],c=0;c<1<<r-1;++c)E.push(\"v\"+c);E.push(\"c0\",\"c1\",\"p0\",\"p1\",\"a\",\"b\",\"c\"),a.push(\"cell:function cellFunc(\",E.join(),\"){\");var C=i(r-1);a.push(\"if(p0){b.push(\",C.map(function(t){return\"[\"+t.map(function(t){return\"v\"+t})+\"]\"}).join(),\")}else{b.push(\",C.map(function(t){var e=t.slice();return e.reverse(),\"[\"+e.map(function(t){return\"v\"+t})+\"]\"}).join(),\")}}});function \",o,\"(array,level){var verts=[],cells=[];contour(array,verts,cells,level);return {positions:verts,cells:cells};} return \",o,\";\");for(var c=0;c<h.length;++c)a.push(h[c].join(\"\"));return new Function(\"genContour\",a.join(\"\"))(n)}(t.order,t.dtype));return s(t,e)};var n=t(\"ndarray-extract-contour\"),i=t(\"triangulate-hypercube\"),a=t(\"zero-crossings\");var o={}},{\"ndarray-extract-contour\":439,\"triangulate-hypercube\":541,\"zero-crossings\":574}],532:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=function(){return function(t,e){if(Array.isArray(t))return t;if(Symbol.iterator in Object(t))return function(t,e){var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{!n&&s.return&&s.return()}finally{if(i)throw a}}return r}(t,e);throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")}}(),i=2*Math.PI,a=function(t,e,r,n,i,a,o){var s=t.x,l=t.y;return{x:n*(s*=e)-i*(l*=r)+a,y:i*s+n*l+o}},o=function(t,e){var r=.551915024494*(e<0?-1:1),n=Math.cos(t),i=Math.sin(t),a=Math.cos(t+e),o=Math.sin(t+e);return[{x:n-i*r,y:i+n*r},{x:a+o*r,y:o-a*r},{x:a,y:o}]},s=function(t,e,r,n){var i=t*n-e*r<0?-1:1,a=(t*r+e*n)/(Math.sqrt(t*t+e*e)*Math.sqrt(t*t+e*e));return a>1&&(a=1),a<-1&&(a=-1),i*Math.acos(a)};r.default=function(t){var e=t.px,r=t.py,l=t.cx,c=t.cy,u=t.rx,h=t.ry,f=t.xAxisRotation,p=void 0===f?0:f,d=t.largeArcFlag,g=void 0===d?0:d,v=t.sweepFlag,m=void 0===v?0:v,y=[];if(0===u||0===h)return[];var x=Math.sin(p*i/360),b=Math.cos(p*i/360),_=b*(e-l)/2+x*(r-c)/2,w=-x*(e-l)/2+b*(r-c)/2;if(0===_&&0===w)return[];u=Math.abs(u),h=Math.abs(h);var k=Math.pow(_,2)/Math.pow(u,2)+Math.pow(w,2)/Math.pow(h,2);k>1&&(u*=Math.sqrt(k),h*=Math.sqrt(k));var T=function(t,e,r,n,a,o,l,c,u,h,f,p){var d=Math.pow(a,2),g=Math.pow(o,2),v=Math.pow(f,2),m=Math.pow(p,2),y=d*g-d*m-g*v;y<0&&(y=0),y/=d*m+g*v;var x=(y=Math.sqrt(y)*(l===c?-1:1))*a/o*p,b=y*-o/a*f,_=h*x-u*b+(t+r)/2,w=u*x+h*b+(e+n)/2,k=(f-x)/a,T=(p-b)/o,A=(-f-x)/a,M=(-p-b)/o,S=s(1,0,k,T),E=s(k,T,A,M);return 0===c&&E>0&&(E-=i),1===c&&E<0&&(E+=i),[_,w,S,E]}(e,r,l,c,u,h,g,m,x,b,_,w),A=n(T,4),M=A[0],S=A[1],E=A[2],C=A[3],L=Math.abs(C)/(i/4);Math.abs(1-L)<1e-7&&(L=1);var P=Math.max(Math.ceil(L),1);C/=P;for(var O=0;O<P;O++)y.push(o(E,C)),E+=C;return y.map(function(t){var e=a(t[0],u,h,b,x,M,S),r=e.x,n=e.y,i=a(t[1],u,h,b,x,M,S),o=i.x,s=i.y,l=a(t[2],u,h,b,x,M,S);return{x1:r,y1:n,x2:o,y2:s,x:l.x,y:l.y}})},e.exports=r.default},{}],533:[function(t,e,r){\"use strict\";var n=t(\"parse-svg-path\"),i=t(\"abs-svg-path\"),a=t(\"normalize-svg-path\"),o=t(\"is-svg-path\"),s=t(\"assert\");e.exports=function(t){Array.isArray(t)&&1===t.length&&\"string\"==typeof t[0]&&(t=t[0]);\"string\"==typeof t&&(s(o(t),\"String is not an SVG path.\"),t=n(t));if(s(Array.isArray(t),\"Argument should be a string or an array of path segments.\"),t=i(t),!(t=a(t)).length)return[0,0,0,0];for(var e=[1/0,1/0,-1/0,-1/0],r=0,l=t.length;r<l;r++)for(var c=t[r].slice(1),u=0;u<c.length;u+=2)c[u+0]<e[0]&&(e[0]=c[u+0]),c[u+1]<e[1]&&(e[1]=c[u+1]),c[u+0]>e[2]&&(e[2]=c[u+0]),c[u+1]>e[3]&&(e[3]=c[u+1]);return e}},{\"abs-svg-path\":60,assert:68,\"is-svg-path\":424,\"normalize-svg-path\":534,\"parse-svg-path\":460}],534:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=[],o=0,s=0,l=0,c=0,u=null,h=null,f=0,p=0,d=0,g=t.length;d<g;d++){var v=t[d],m=v[0];switch(m){case\"M\":l=v[1],c=v[2];break;case\"A\":var y=n({px:f,py:p,cx:v[6],cy:v[7],rx:v[1],ry:v[2],xAxisRotation:v[3],largeArcFlag:v[4],sweepFlag:v[5]});if(!y.length)continue;for(var x,b=0;b<y.length;b++)x=y[b],v=[\"C\",x.x1,x.y1,x.x2,x.y2,x.x,x.y],b<y.length-1&&r.push(v);break;case\"S\":var _=f,w=p;\"C\"!=e&&\"S\"!=e||(_+=_-o,w+=w-s),v=[\"C\",_,w,v[1],v[2],v[3],v[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(u=2*f-u,h=2*p-h):(u=f,h=p),v=a(f,p,u,h,v[1],v[2]);break;case\"Q\":u=v[1],h=v[2],v=a(f,p,v[1],v[2],v[3],v[4]);break;case\"L\":v=i(f,p,v[1],v[2]);break;case\"H\":v=i(f,p,v[1],p);break;case\"V\":v=i(f,p,f,v[1]);break;case\"Z\":v=i(f,p,l,c)}e=m,f=v[v.length-2],p=v[v.length-1],v.length>4?(o=v[v.length-4],s=v[v.length-3]):(o=f,s=p),r.push(v)}return r};var n=t(\"svg-arc-to-cubic-bezier\");function i(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function a(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}},{\"svg-arc-to-cubic-bezier\":532}],535:[function(t,e,r){\"use strict\";var n,i=t(\"svg-path-bounds\"),a=t(\"parse-svg-path\"),o=t(\"draw-svg-path\"),s=t(\"is-svg-path\"),l=t(\"bitmap-sdf\"),c=document.createElement(\"canvas\"),u=c.getContext(\"2d\");e.exports=function(t,e){if(!s(t))throw Error(\"Argument should be valid svg path string\");e||(e={});var r,h;e.shape?(r=e.shape[0],h=e.shape[1]):(r=c.width=e.w||e.width||200,h=c.height=e.h||e.height||200);var f=Math.min(r,h),p=e.stroke||0,d=e.viewbox||e.viewBox||i(t),g=[r/(d[2]-d[0]),h/(d[3]-d[1])],v=Math.min(g[0]||0,g[1]||0)/2;u.fillStyle=\"black\",u.fillRect(0,0,r,h),u.fillStyle=\"white\",p&&(\"number\"!=typeof p&&(p=1),u.strokeStyle=p>0?\"white\":\"black\",u.lineWidth=Math.abs(p));if(u.translate(.5*r,.5*h),u.scale(v,v),function(){if(null!=n)return n;var t=document.createElement(\"canvas\").getContext(\"2d\");if(t.canvas.width=t.canvas.height=1,!window.Path2D)return n=!1;var e=new Path2D(\"M0,0h1v1h-1v-1Z\");t.fillStyle=\"black\",t.fill(e);var r=t.getImageData(0,0,1,1);return n=r&&r.data&&255===r.data[3]}()){var m=new Path2D(t);u.fill(m),p&&u.stroke(m)}else{var y=a(t);o(u,y),u.fill(),p&&u.stroke()}return u.setTransform(1,0,0,1,0,0),l(u,{cutoff:null!=e.cutoff?e.cutoff:.5,radius:null!=e.radius?e.radius:.5*f})}},{\"bitmap-sdf\":93,\"draw-svg-path\":168,\"is-svg-path\":424,\"parse-svg-path\":460,\"svg-path-bounds\":533}],536:[function(t,e,r){(function(r){\"use strict\";e.exports=function t(e,r,i){var i=i||{};var o=a[e];o||(o=a[e]={\" \":{data:new Float32Array(0),shape:.2}});var s=o[r];if(!s)if(r.length<=1||!/\\d/.test(r))s=o[r]=function(t){for(var e=t.cells,r=t.positions,n=new Float32Array(6*e.length),i=0,a=0,o=0;o<e.length;++o)for(var s=e[o],l=0;l<3;++l){var c=r[s[l]];n[i++]=c[0],n[i++]=c[1]+1.4,a=Math.max(c[0],a)}return{data:n,shape:a}}(n(r,{triangles:!0,font:e,textAlign:i.textAlign||\"left\",textBaseline:\"alphabetic\",styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0}}));else{for(var l=r.split(/(\\d|\\s)/),c=new Array(l.length),u=0,h=0,f=0;f<l.length;++f)c[f]=t(e,l[f]),u+=c[f].data.length,h+=c[f].shape,f>0&&(h+=.02);for(var p=new Float32Array(u),d=0,g=-.5*h,f=0;f<c.length;++f){for(var v=c[f].data,m=0;m<v.length;m+=2)p[d++]=v[m]+g,p[d++]=v[m+1];g+=c[f].shape+.02}s=o[r]={data:p,shape:h}}return s};var n=t(\"vectorize-text\"),i=window||r.global||{},a=i.__TEXT_CACHE||{};i.__TEXT_CACHE={}}).call(this,t(\"_process\"))},{_process:482,\"vectorize-text\":550}],537:[function(t,e,r){!function(t){var r=/^\\s+/,n=/\\s+$/,i=0,a=t.round,o=t.min,s=t.max,l=t.random;function c(e,l){if(l=l||{},(e=e||\"\")instanceof c)return e;if(!(this instanceof c))return new c(e,l);var u=function(e){var i={r:0,g:0,b:0},a=1,l=null,c=null,u=null,h=!1,f=!1;\"string\"==typeof e&&(e=function(t){t=t.replace(r,\"\").replace(n,\"\").toLowerCase();var e,i=!1;if(S[t])t=S[t],i=!0;else if(\"transparent\"==t)return{r:0,g:0,b:0,a:0,format:\"name\"};if(e=j.rgb.exec(t))return{r:e[1],g:e[2],b:e[3]};if(e=j.rgba.exec(t))return{r:e[1],g:e[2],b:e[3],a:e[4]};if(e=j.hsl.exec(t))return{h:e[1],s:e[2],l:e[3]};if(e=j.hsla.exec(t))return{h:e[1],s:e[2],l:e[3],a:e[4]};if(e=j.hsv.exec(t))return{h:e[1],s:e[2],v:e[3]};if(e=j.hsva.exec(t))return{h:e[1],s:e[2],v:e[3],a:e[4]};if(e=j.hex8.exec(t))return{r:O(e[1]),g:O(e[2]),b:O(e[3]),a:R(e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex6.exec(t))return{r:O(e[1]),g:O(e[2]),b:O(e[3]),format:i?\"name\":\"hex\"};if(e=j.hex4.exec(t))return{r:O(e[1]+\"\"+e[1]),g:O(e[2]+\"\"+e[2]),b:O(e[3]+\"\"+e[3]),a:R(e[4]+\"\"+e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex3.exec(t))return{r:O(e[1]+\"\"+e[1]),g:O(e[2]+\"\"+e[2]),b:O(e[3]+\"\"+e[3]),format:i?\"name\":\"hex\"};return!1}(e));\"object\"==typeof e&&(U(e.r)&&U(e.g)&&U(e.b)?(p=e.r,d=e.g,g=e.b,i={r:255*L(p,255),g:255*L(d,255),b:255*L(g,255)},h=!0,f=\"%\"===String(e.r).substr(-1)?\"prgb\":\"rgb\"):U(e.h)&&U(e.s)&&U(e.v)?(l=I(e.s),c=I(e.v),i=function(e,r,n){e=6*L(e,360),r=L(r,100),n=L(n,100);var i=t.floor(e),a=e-i,o=n*(1-r),s=n*(1-a*r),l=n*(1-(1-a)*r),c=i%6;return{r:255*[n,s,o,o,l,n][c],g:255*[l,n,n,s,o,o][c],b:255*[o,o,l,n,n,s][c]}}(e.h,l,c),h=!0,f=\"hsv\"):U(e.h)&&U(e.s)&&U(e.l)&&(l=I(e.s),u=I(e.l),i=function(t,e,r){var n,i,a;function o(t,e,r){return r<0&&(r+=1),r>1&&(r-=1),r<1/6?t+6*(e-t)*r:r<.5?e:r<2/3?t+(e-t)*(2/3-r)*6:t}if(t=L(t,360),e=L(e,100),r=L(r,100),0===e)n=i=a=r;else{var s=r<.5?r*(1+e):r+e-r*e,l=2*r-s;n=o(l,s,t+1/3),i=o(l,s,t),a=o(l,s,t-1/3)}return{r:255*n,g:255*i,b:255*a}}(e.h,l,u),h=!0,f=\"hsl\"),e.hasOwnProperty(\"a\")&&(a=e.a));var p,d,g;return a=C(a),{ok:h,format:e.format||f,r:o(255,s(i.r,0)),g:o(255,s(i.g,0)),b:o(255,s(i.b,0)),a:a}}(e);this._originalInput=e,this._r=u.r,this._g=u.g,this._b=u.b,this._a=u.a,this._roundA=a(100*this._a)/100,this._format=l.format||u.format,this._gradientType=l.gradientType,this._r<1&&(this._r=a(this._r)),this._g<1&&(this._g=a(this._g)),this._b<1&&(this._b=a(this._b)),this._ok=u.ok,this._tc_id=i++}function u(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=(a+l)/2;if(a==l)n=i=0;else{var u=a-l;switch(i=c>.5?u/(2-a-l):u/(a+l),a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,l:c}}function h(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=a,u=a-l;if(i=0===a?0:u/a,a==l)n=0;else{switch(a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,v:c}}function f(t,e,r,n){var i=[z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16))];return n&&i[0].charAt(0)==i[0].charAt(1)&&i[1].charAt(0)==i[1].charAt(1)&&i[2].charAt(0)==i[2].charAt(1)?i[0].charAt(0)+i[1].charAt(0)+i[2].charAt(0):i.join(\"\")}function p(t,e,r,n){return[z(D(n)),z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16))].join(\"\")}function d(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s-=e/100,r.s=P(r.s),c(r)}function g(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s+=e/100,r.s=P(r.s),c(r)}function v(t){return c(t).desaturate(100)}function m(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l+=e/100,r.l=P(r.l),c(r)}function y(t,e){e=0===e?0:e||10;var r=c(t).toRgb();return r.r=s(0,o(255,r.r-a(-e/100*255))),r.g=s(0,o(255,r.g-a(-e/100*255))),r.b=s(0,o(255,r.b-a(-e/100*255))),c(r)}function x(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l-=e/100,r.l=P(r.l),c(r)}function b(t,e){var r=c(t).toHsl(),n=(r.h+e)%360;return r.h=n<0?360+n:n,c(r)}function _(t){var e=c(t).toHsl();return e.h=(e.h+180)%360,c(e)}function w(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+120)%360,s:e.s,l:e.l}),c({h:(r+240)%360,s:e.s,l:e.l})]}function k(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+90)%360,s:e.s,l:e.l}),c({h:(r+180)%360,s:e.s,l:e.l}),c({h:(r+270)%360,s:e.s,l:e.l})]}function T(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+72)%360,s:e.s,l:e.l}),c({h:(r+216)%360,s:e.s,l:e.l})]}function A(t,e,r){e=e||6,r=r||30;var n=c(t).toHsl(),i=360/r,a=[c(t)];for(n.h=(n.h-(i*e>>1)+720)%360;--e;)n.h=(n.h+i)%360,a.push(c(n));return a}function M(t,e){e=e||6;for(var r=c(t).toHsv(),n=r.h,i=r.s,a=r.v,o=[],s=1/e;e--;)o.push(c({h:n,s:i,v:a})),a=(a+s)%1;return o}c.prototype={isDark:function(){return this.getBrightness()<128},isLight:function(){return!this.isDark()},isValid:function(){return this._ok},getOriginalInput:function(){return this._originalInput},getFormat:function(){return this._format},getAlpha:function(){return this._a},getBrightness:function(){var t=this.toRgb();return(299*t.r+587*t.g+114*t.b)/1e3},getLuminance:function(){var e,r,n,i=this.toRgb();return e=i.r/255,r=i.g/255,n=i.b/255,.2126*(e<=.03928?e/12.92:t.pow((e+.055)/1.055,2.4))+.7152*(r<=.03928?r/12.92:t.pow((r+.055)/1.055,2.4))+.0722*(n<=.03928?n/12.92:t.pow((n+.055)/1.055,2.4))},setAlpha:function(t){return this._a=C(t),this._roundA=a(100*this._a)/100,this},toHsv:function(){var t=h(this._r,this._g,this._b);return{h:360*t.h,s:t.s,v:t.v,a:this._a}},toHsvString:function(){var t=h(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.v);return 1==this._a?\"hsv(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsva(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHsl:function(){var t=u(this._r,this._g,this._b);return{h:360*t.h,s:t.s,l:t.l,a:this._a}},toHslString:function(){var t=u(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.l);return 1==this._a?\"hsl(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsla(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHex:function(t){return f(this._r,this._g,this._b,t)},toHexString:function(t){return\"#\"+this.toHex(t)},toHex8:function(t){return function(t,e,r,n,i){var o=[z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16)),z(D(n))];if(i&&o[0].charAt(0)==o[0].charAt(1)&&o[1].charAt(0)==o[1].charAt(1)&&o[2].charAt(0)==o[2].charAt(1)&&o[3].charAt(0)==o[3].charAt(1))return o[0].charAt(0)+o[1].charAt(0)+o[2].charAt(0)+o[3].charAt(0);return o.join(\"\")}(this._r,this._g,this._b,this._a,t)},toHex8String:function(t){return\"#\"+this.toHex8(t)},toRgb:function(){return{r:a(this._r),g:a(this._g),b:a(this._b),a:this._a}},toRgbString:function(){return 1==this._a?\"rgb(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\")\":\"rgba(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\", \"+this._roundA+\")\"},toPercentageRgb:function(){return{r:a(100*L(this._r,255))+\"%\",g:a(100*L(this._g,255))+\"%\",b:a(100*L(this._b,255))+\"%\",a:this._a}},toPercentageRgbString:function(){return 1==this._a?\"rgb(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%)\":\"rgba(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%, \"+this._roundA+\")\"},toName:function(){return 0===this._a?\"transparent\":!(this._a<1)&&(E[f(this._r,this._g,this._b,!0)]||!1)},toFilter:function(t){var e=\"#\"+p(this._r,this._g,this._b,this._a),r=e,n=this._gradientType?\"GradientType = 1, \":\"\";if(t){var i=c(t);r=\"#\"+p(i._r,i._g,i._b,i._a)}return\"progid:DXImageTransform.Microsoft.gradient(\"+n+\"startColorstr=\"+e+\",endColorstr=\"+r+\")\"},toString:function(t){var e=!!t;t=t||this._format;var r=!1,n=this._a<1&&this._a>=0;return e||!n||\"hex\"!==t&&\"hex6\"!==t&&\"hex3\"!==t&&\"hex4\"!==t&&\"hex8\"!==t&&\"name\"!==t?(\"rgb\"===t&&(r=this.toRgbString()),\"prgb\"===t&&(r=this.toPercentageRgbString()),\"hex\"!==t&&\"hex6\"!==t||(r=this.toHexString()),\"hex3\"===t&&(r=this.toHexString(!0)),\"hex4\"===t&&(r=this.toHex8String(!0)),\"hex8\"===t&&(r=this.toHex8String()),\"name\"===t&&(r=this.toName()),\"hsl\"===t&&(r=this.toHslString()),\"hsv\"===t&&(r=this.toHsvString()),r||this.toHexString()):\"name\"===t&&0===this._a?this.toName():this.toRgbString()},clone:function(){return c(this.toString())},_applyModification:function(t,e){var r=t.apply(null,[this].concat([].slice.call(e)));return this._r=r._r,this._g=r._g,this._b=r._b,this.setAlpha(r._a),this},lighten:function(){return this._applyModification(m,arguments)},brighten:function(){return this._applyModification(y,arguments)},darken:function(){return this._applyModification(x,arguments)},desaturate:function(){return this._applyModification(d,arguments)},saturate:function(){return this._applyModification(g,arguments)},greyscale:function(){return this._applyModification(v,arguments)},spin:function(){return this._applyModification(b,arguments)},_applyCombination:function(t,e){return t.apply(null,[this].concat([].slice.call(e)))},analogous:function(){return this._applyCombination(A,arguments)},complement:function(){return this._applyCombination(_,arguments)},monochromatic:function(){return this._applyCombination(M,arguments)},splitcomplement:function(){return this._applyCombination(T,arguments)},triad:function(){return this._applyCombination(w,arguments)},tetrad:function(){return this._applyCombination(k,arguments)}},c.fromRatio=function(t,e){if(\"object\"==typeof t){var r={};for(var n in t)t.hasOwnProperty(n)&&(r[n]=\"a\"===n?t[n]:I(t[n]));t=r}return c(t,e)},c.equals=function(t,e){return!(!t||!e)&&c(t).toRgbString()==c(e).toRgbString()},c.random=function(){return c.fromRatio({r:l(),g:l(),b:l()})},c.mix=function(t,e,r){r=0===r?0:r||50;var n=c(t).toRgb(),i=c(e).toRgb(),a=r/100;return c({r:(i.r-n.r)*a+n.r,g:(i.g-n.g)*a+n.g,b:(i.b-n.b)*a+n.b,a:(i.a-n.a)*a+n.a})},c.readability=function(e,r){var n=c(e),i=c(r);return(t.max(n.getLuminance(),i.getLuminance())+.05)/(t.min(n.getLuminance(),i.getLuminance())+.05)},c.isReadable=function(t,e,r){var n,i,a=c.readability(t,e);switch(i=!1,(n=function(t){var e,r;e=((t=t||{level:\"AA\",size:\"small\"}).level||\"AA\").toUpperCase(),r=(t.size||\"small\").toLowerCase(),\"AA\"!==e&&\"AAA\"!==e&&(e=\"AA\");\"small\"!==r&&\"large\"!==r&&(r=\"small\");return{level:e,size:r}}(r)).level+n.size){case\"AAsmall\":case\"AAAlarge\":i=a>=4.5;break;case\"AAlarge\":i=a>=3;break;case\"AAAsmall\":i=a>=7}return i},c.mostReadable=function(t,e,r){var n,i,a,o,s=null,l=0;i=(r=r||{}).includeFallbackColors,a=r.level,o=r.size;for(var u=0;u<e.length;u++)(n=c.readability(t,e[u]))>l&&(l=n,s=c(e[u]));return c.isReadable(t,s,{level:a,size:o})||!i?s:(r.includeFallbackColors=!1,c.mostReadable(t,[\"#fff\",\"#000\"],r))};var S=c.names={aliceblue:\"f0f8ff\",antiquewhite:\"faebd7\",aqua:\"0ff\",aquamarine:\"7fffd4\",azure:\"f0ffff\",beige:\"f5f5dc\",bisque:\"ffe4c4\",black:\"000\",blanchedalmond:\"ffebcd\",blue:\"00f\",blueviolet:\"8a2be2\",brown:\"a52a2a\",burlywood:\"deb887\",burntsienna:\"ea7e5d\",cadetblue:\"5f9ea0\",chartreuse:\"7fff00\",chocolate:\"d2691e\",coral:\"ff7f50\",cornflowerblue:\"6495ed\",cornsilk:\"fff8dc\",crimson:\"dc143c\",cyan:\"0ff\",darkblue:\"00008b\",darkcyan:\"008b8b\",darkgoldenrod:\"b8860b\",darkgray:\"a9a9a9\",darkgreen:\"006400\",darkgrey:\"a9a9a9\",darkkhaki:\"bdb76b\",darkmagenta:\"8b008b\",darkolivegreen:\"556b2f\",darkorange:\"ff8c00\",darkorchid:\"9932cc\",darkred:\"8b0000\",darksalmon:\"e9967a\",darkseagreen:\"8fbc8f\",darkslateblue:\"483d8b\",darkslategray:\"2f4f4f\",darkslategrey:\"2f4f4f\",darkturquoise:\"00ced1\",darkviolet:\"9400d3\",deeppink:\"ff1493\",deepskyblue:\"00bfff\",dimgray:\"696969\",dimgrey:\"696969\",dodgerblue:\"1e90ff\",firebrick:\"b22222\",floralwhite:\"fffaf0\",forestgreen:\"228b22\",fuchsia:\"f0f\",gainsboro:\"dcdcdc\",ghostwhite:\"f8f8ff\",gold:\"ffd700\",goldenrod:\"daa520\",gray:\"808080\",green:\"008000\",greenyellow:\"adff2f\",grey:\"808080\",honeydew:\"f0fff0\",hotpink:\"ff69b4\",indianred:\"cd5c5c\",indigo:\"4b0082\",ivory:\"fffff0\",khaki:\"f0e68c\",lavender:\"e6e6fa\",lavenderblush:\"fff0f5\",lawngreen:\"7cfc00\",lemonchiffon:\"fffacd\",lightblue:\"add8e6\",lightcoral:\"f08080\",lightcyan:\"e0ffff\",lightgoldenrodyellow:\"fafad2\",lightgray:\"d3d3d3\",lightgreen:\"90ee90\",lightgrey:\"d3d3d3\",lightpink:\"ffb6c1\",lightsalmon:\"ffa07a\",lightseagreen:\"20b2aa\",lightskyblue:\"87cefa\",lightslategray:\"789\",lightslategrey:\"789\",lightsteelblue:\"b0c4de\",lightyellow:\"ffffe0\",lime:\"0f0\",limegreen:\"32cd32\",linen:\"faf0e6\",magenta:\"f0f\",maroon:\"800000\",mediumaquamarine:\"66cdaa\",mediumblue:\"0000cd\",mediumorchid:\"ba55d3\",mediumpurple:\"9370db\",mediumseagreen:\"3cb371\",mediumslateblue:\"7b68ee\",mediumspringgreen:\"00fa9a\",mediumturquoise:\"48d1cc\",mediumvioletred:\"c71585\",midnightblue:\"191970\",mintcream:\"f5fffa\",mistyrose:\"ffe4e1\",moccasin:\"ffe4b5\",navajowhite:\"ffdead\",navy:\"000080\",oldlace:\"fdf5e6\",olive:\"808000\",olivedrab:\"6b8e23\",orange:\"ffa500\",orangered:\"ff4500\",orchid:\"da70d6\",palegoldenrod:\"eee8aa\",palegreen:\"98fb98\",paleturquoise:\"afeeee\",palevioletred:\"db7093\",papayawhip:\"ffefd5\",peachpuff:\"ffdab9\",peru:\"cd853f\",pink:\"ffc0cb\",plum:\"dda0dd\",powderblue:\"b0e0e6\",purple:\"800080\",rebeccapurple:\"663399\",red:\"f00\",rosybrown:\"bc8f8f\",royalblue:\"4169e1\",saddlebrown:\"8b4513\",salmon:\"fa8072\",sandybrown:\"f4a460\",seagreen:\"2e8b57\",seashell:\"fff5ee\",sienna:\"a0522d\",silver:\"c0c0c0\",skyblue:\"87ceeb\",slateblue:\"6a5acd\",slategray:\"708090\",slategrey:\"708090\",snow:\"fffafa\",springgreen:\"00ff7f\",steelblue:\"4682b4\",tan:\"d2b48c\",teal:\"008080\",thistle:\"d8bfd8\",tomato:\"ff6347\",turquoise:\"40e0d0\",violet:\"ee82ee\",wheat:\"f5deb3\",white:\"fff\",whitesmoke:\"f5f5f5\",yellow:\"ff0\",yellowgreen:\"9acd32\"},E=c.hexNames=function(t){var e={};for(var r in t)t.hasOwnProperty(r)&&(e[t[r]]=r);return e}(S);function C(t){return t=parseFloat(t),(isNaN(t)||t<0||t>1)&&(t=1),t}function L(e,r){(function(t){return\"string\"==typeof t&&-1!=t.indexOf(\".\")&&1===parseFloat(t)})(e)&&(e=\"100%\");var n=function(t){return\"string\"==typeof t&&-1!=t.indexOf(\"%\")}(e);return e=o(r,s(0,parseFloat(e))),n&&(e=parseInt(e*r,10)/100),t.abs(e-r)<1e-6?1:e%r/parseFloat(r)}function P(t){return o(1,s(0,t))}function O(t){return parseInt(t,16)}function z(t){return 1==t.length?\"0\"+t:\"\"+t}function I(t){return t<=1&&(t=100*t+\"%\"),t}function D(e){return t.round(255*parseFloat(e)).toString(16)}function R(t){return O(t)/255}var F,B,N,j=(B=\"[\\\\s|\\\\(]+(\"+(F=\"(?:[-\\\\+]?\\\\d*\\\\.\\\\d+%?)|(?:[-\\\\+]?\\\\d+%?)\")+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",N=\"[\\\\s|\\\\(]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",{CSS_UNIT:new RegExp(F),rgb:new RegExp(\"rgb\"+B),rgba:new RegExp(\"rgba\"+N),hsl:new RegExp(\"hsl\"+B),hsla:new RegExp(\"hsla\"+N),hsv:new RegExp(\"hsv\"+B),hsva:new RegExp(\"hsva\"+N),hex3:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex6:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/,hex4:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex8:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/});function U(t){return!!j.CSS_UNIT.exec(t)}\"undefined\"!=typeof e&&e.exports?e.exports=c:window.tinycolor=c}(Math)},{}],538:[function(t,e,r){\"use strict\";e.exports=i,e.exports.float32=e.exports.float=i,e.exports.fract32=e.exports.fract=function(t){if(t.length){for(var e=i(t),r=0,n=e.length;r<n;r++)e[r]=t[r]-e[r];return e}return i(t-i(t))};var n=new Float32Array(1);function i(t){if(t.length){if(t instanceof Float32Array)return t;var e=new Float32Array(t);return e.set(t),e}return n[0]=t,n[0]}},{}],539:[function(t,e,r){\"use strict\";var n=t(\"parse-unit\");e.exports=o;var i=96;function a(t,e){var r=n(getComputedStyle(t).getPropertyValue(e));return r[0]*o(r[1],t)}function o(t,e){switch(e=e||document.body,t=(t||\"px\").trim().toLowerCase(),e!==window&&e!==document||(e=document.body),t){case\"%\":return e.clientHeight/100;case\"ch\":case\"ex\":return function(t,e){var r=document.createElement(\"div\");r.style[\"font-size\"]=\"128\"+t,e.appendChild(r);var n=a(r,\"font-size\")/128;return e.removeChild(r),n}(t,e);case\"em\":return a(e,\"font-size\");case\"rem\":return a(document.body,\"font-size\");case\"vw\":return window.innerWidth/100;case\"vh\":return window.innerHeight/100;case\"vmin\":return Math.min(window.innerWidth,window.innerHeight)/100;case\"vmax\":return Math.max(window.innerWidth,window.innerHeight)/100;case\"in\":return i;case\"cm\":return i/2.54;case\"mm\":return i/25.4;case\"pt\":return i/72;case\"pc\":return i/6}return 1}},{\"parse-unit\":461}],540:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e=function(t){return t},r=function(t){if(null==(r=t.transform))return e;var r,n,i,a=r.scale[0],o=r.scale[1],s=r.translate[0],l=r.translate[1];return function(t,e){return e||(n=i=0),t[0]=(n+=t[0])*a+s,t[1]=(i+=t[1])*o+l,t}},n=function(t){var e=t.bbox;function n(t){l[0]=t[0],l[1]=t[1],s(l),l[0]<c&&(c=l[0]),l[0]>h&&(h=l[0]),l[1]<u&&(u=l[1]),l[1]>f&&(f=l[1])}function i(t){switch(t.type){case\"GeometryCollection\":t.geometries.forEach(i);break;case\"Point\":n(t.coordinates);break;case\"MultiPoint\":t.coordinates.forEach(n)}}if(!e){var a,o,s=r(t),l=new Array(2),c=1/0,u=c,h=-c,f=-c;for(o in t.arcs.forEach(function(t){for(var e=-1,r=t.length;++e<r;)a=t[e],l[0]=a[0],l[1]=a[1],s(l,e),l[0]<c&&(c=l[0]),l[0]>h&&(h=l[0]),l[1]<u&&(u=l[1]),l[1]>f&&(f=l[1])}),t.objects)i(t.objects[o]);e=t.bbox=[c,u,h,f]}return e},i=function(t,e){for(var r,n=t.length,i=n-e;i<--n;)r=t[i],t[i++]=t[n],t[n]=r};function a(t,e){var r=e.id,n=e.bbox,i=null==e.properties?{}:e.properties,a=o(t,e);return null==r&&null==n?{type:\"Feature\",properties:i,geometry:a}:null==n?{type:\"Feature\",id:r,properties:i,geometry:a}:{type:\"Feature\",id:r,bbox:n,properties:i,geometry:a}}function o(t,e){var n=r(t),a=t.arcs;function o(t,e){e.length&&e.pop();for(var r=a[t<0?~t:t],o=0,s=r.length;o<s;++o)e.push(n(r[o].slice(),o));t<0&&i(e,s)}function s(t){return n(t.slice())}function l(t){for(var e=[],r=0,n=t.length;r<n;++r)o(t[r],e);return e.length<2&&e.push(e[0].slice()),e}function c(t){for(var e=l(t);e.length<4;)e.push(e[0].slice());return e}function u(t){return t.map(c)}return function t(e){var r,n=e.type;switch(n){case\"GeometryCollection\":return{type:n,geometries:e.geometries.map(t)};case\"Point\":r=s(e.coordinates);break;case\"MultiPoint\":r=e.coordinates.map(s);break;case\"LineString\":r=l(e.arcs);break;case\"MultiLineString\":r=e.arcs.map(l);break;case\"Polygon\":r=u(e.arcs);break;case\"MultiPolygon\":r=e.arcs.map(u);break;default:return null}return{type:n,coordinates:r}}(e)}var s=function(t,e){var r={},n={},i={},a=[],o=-1;function s(t,e){for(var n in t){var i=t[n];delete e[i.start],delete i.start,delete i.end,i.forEach(function(t){r[t<0?~t:t]=1}),a.push(i)}}return e.forEach(function(r,n){var i,a=t.arcs[r<0?~r:r];a.length<3&&!a[1][0]&&!a[1][1]&&(i=e[++o],e[o]=r,e[n]=i)}),e.forEach(function(e){var r,a,o=function(e){var r,n=t.arcs[e<0?~e:e],i=n[0];t.transform?(r=[0,0],n.forEach(function(t){r[0]+=t[0],r[1]+=t[1]})):r=n[n.length-1];return e<0?[r,i]:[i,r]}(e),s=o[0],l=o[1];if(r=i[s])if(delete i[r.end],r.push(e),r.end=l,a=n[l]){delete n[a.start];var c=a===r?r:r.concat(a);n[c.start=r.start]=i[c.end=a.end]=c}else n[r.start]=i[r.end]=r;else if(r=n[l])if(delete n[r.start],r.unshift(e),r.start=s,a=i[s]){delete i[a.end];var u=a===r?r:a.concat(r);n[u.start=a.start]=i[u.end=r.end]=u}else n[r.start]=i[r.end]=r;else n[(r=[e]).start=s]=i[r.end=l]=r}),s(i,n),s(n,i),e.forEach(function(t){r[t<0?~t:t]||a.push([t])}),a};function l(t,e,r){var n,i,a;if(arguments.length>1)n=function(t,e,r){var n,i=[],a=[];function o(t){var e=t<0?~t:t;(a[e]||(a[e]=[])).push({i:t,g:n})}function s(t){t.forEach(o)}function l(t){t.forEach(s)}return function t(e){switch(n=e,e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"LineString\":s(e.arcs);break;case\"MultiLineString\":case\"Polygon\":l(e.arcs);break;case\"MultiPolygon\":e.arcs.forEach(l)}}(e),a.forEach(null==r?function(t){i.push(t[0].i)}:function(t){r(t[0].g,t[t.length-1].g)&&i.push(t[0].i)}),i}(0,e,r);else for(i=0,n=new Array(a=t.arcs.length);i<a;++i)n[i]=i;return{type:\"MultiLineString\",arcs:s(t,n)}}function c(t,e){var r={},n=[],i=[];function a(t){t.forEach(function(e){e.forEach(function(e){(r[e=e<0?~e:e]||(r[e]=[])).push(t)})}),n.push(t)}function l(e){return function(t){for(var e,r=-1,n=t.length,i=t[n-1],a=0;++r<n;)e=i,i=t[r],a+=e[0]*i[1]-e[1]*i[0];return Math.abs(a)}(o(t,{type:\"Polygon\",arcs:[e]}).coordinates[0])}return e.forEach(function t(e){switch(e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"Polygon\":a(e.arcs);break;case\"MultiPolygon\":e.arcs.forEach(a)}}),n.forEach(function(t){if(!t._){var e=[],n=[t];for(t._=1,i.push(e);t=n.pop();)e.push(t),t.forEach(function(t){t.forEach(function(t){r[t<0?~t:t].forEach(function(t){t._||(t._=1,n.push(t))})})})}}),n.forEach(function(t){delete t._}),{type:\"MultiPolygon\",arcs:i.map(function(e){var n,i=[];if(e.forEach(function(t){t.forEach(function(t){t.forEach(function(t){r[t<0?~t:t].length<2&&i.push(t)})})}),(n=(i=s(t,i)).length)>1)for(var a,o,c=1,u=l(i[0]);c<n;++c)(a=l(i[c]))>u&&(o=i[0],i[0]=i[c],i[c]=o,u=a);return i})}}var u=function(t,e){for(var r=0,n=t.length;r<n;){var i=r+n>>>1;t[i]<e?r=i+1:n=i}return r};t.bbox=n,t.feature=function(t,e){return\"GeometryCollection\"===e.type?{type:\"FeatureCollection\",features:e.geometries.map(function(e){return a(t,e)})}:a(t,e)},t.mesh=function(t){return o(t,l.apply(this,arguments))},t.meshArcs=l,t.merge=function(t){return o(t,c.apply(this,arguments))},t.mergeArcs=c,t.neighbors=function(t){var e={},r=t.map(function(){return[]});function n(t,r){t.forEach(function(t){t<0&&(t=~t);var n=e[t];n?n.push(r):e[t]=[r]})}function i(t,e){t.forEach(function(t){n(t,e)})}var a={LineString:n,MultiLineString:i,Polygon:i,MultiPolygon:function(t,e){t.forEach(function(t){i(t,e)})}};for(var o in t.forEach(function t(e,r){\"GeometryCollection\"===e.type?e.geometries.forEach(function(e){t(e,r)}):e.type in a&&a[e.type](e.arcs,r)}),e)for(var s=e[o],l=s.length,c=0;c<l;++c)for(var h=c+1;h<l;++h){var f,p=s[c],d=s[h];(f=r[p])[o=u(f,d)]!==d&&f.splice(o,0,d),(f=r[d])[o=u(f,p)]!==p&&f.splice(o,0,p)}return r},t.quantize=function(t,e){if(!((e=Math.floor(e))>=2))throw new Error(\"n must be \\u22652\");if(t.transform)throw new Error(\"already quantized\");var r,i=n(t),a=i[0],o=(i[2]-a)/(e-1)||1,s=i[1],l=(i[3]-s)/(e-1)||1;function c(t){t[0]=Math.round((t[0]-a)/o),t[1]=Math.round((t[1]-s)/l)}function u(t){switch(t.type){case\"GeometryCollection\":t.geometries.forEach(u);break;case\"Point\":c(t.coordinates);break;case\"MultiPoint\":t.coordinates.forEach(c)}}for(r in t.arcs.forEach(function(t){for(var e,r,n,i=1,c=1,u=t.length,h=t[0],f=h[0]=Math.round((h[0]-a)/o),p=h[1]=Math.round((h[1]-s)/l);i<u;++i)h=t[i],r=Math.round((h[0]-a)/o),n=Math.round((h[1]-s)/l),r===f&&n===p||((e=t[c++])[0]=r-f,f=r,e[1]=n-p,p=n);c<2&&((e=t[c++])[0]=0,e[1]=0),t.length=c}),t.objects)u(t.objects[r]);return t.transform={scale:[o,l],translate:[a,s]},t},t.transform=r,t.untransform=function(t){if(null==(r=t.transform))return e;var r,n,i,a=r.scale[0],o=r.scale[1],s=r.translate[0],l=r.translate[1];return function(t,e){e||(n=i=0);var r=Math.round((t[0]-s)/a),c=Math.round((t[1]-l)/o);return t[0]=r-n,n=r,t[1]=c-i,i=c,t}},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.topojson=n.topojson||{})},{}],541:[function(t,e,r){\"use strict\";e.exports=function(t){if(t<0)return[];if(0===t)return[[0]];for(var e=0|Math.round(a(t+1)),r=[],o=0;o<e;++o){for(var s=n.unrank(t,o),l=[0],c=0,u=0;u<s.length;++u)c+=1<<s[u],l.push(c);i(s)<1&&(l[0]=c,l[t]=0),r.push(l)}return r};var n=t(\"permutation-rank\"),i=t(\"permutation-parity\"),a=t(\"gamma\")},{gamma:231,\"permutation-parity\":463,\"permutation-rank\":464}],542:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.up||[0,1,0],n=t.right||h(r),i=t.radius||1,a=t.theta||0,u=t.phi||0;if(e=[].slice.call(e,0,3),r=[].slice.call(r,0,3),s(r,r),n=[].slice.call(n,0,3),s(n,n),\"eye\"in t){var p=t.eye,d=[p[0]-e[0],p[1]-e[1],p[2]-e[2]];o(n,d,r),c(n[0],n[1],n[2])<1e-6?n=h(r):s(n,n),i=c(d[0],d[1],d[2]);var g=l(r,d)/i,v=l(n,d)/i;u=Math.acos(g),a=Math.acos(v)}return i=Math.log(i),new f(t.zoomMin,t.zoomMax,e,r,n,i,a,u)};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/invert\"),a=t(\"gl-mat4/rotate\"),o=t(\"gl-vec3/cross\"),s=t(\"gl-vec3/normalize\"),l=t(\"gl-vec3/dot\");function c(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function u(t){return Math.min(1,Math.max(-1,t))}function h(t){var e=Math.abs(t[0]),r=Math.abs(t[1]),n=Math.abs(t[2]),i=[0,0,0];e>Math.max(r,n)?i[2]=1:r>Math.max(e,n)?i[0]=1:i[1]=1;for(var a=0,o=0,l=0;l<3;++l)a+=t[l]*t[l],o+=i[l]*t[l];for(l=0;l<3;++l)i[l]-=o/a*t[l];return s(i,i),i}function f(t,e,r,i,a,o,s,l){this.center=n(r),this.up=n(i),this.right=n(a),this.radius=n([o]),this.angle=n([s,l]),this.angle.bounds=[[-1/0,-Math.PI/2],[1/0,Math.PI/2]],this.setDistanceLimits(t,e),this.computedCenter=this.center.curve(0),this.computedUp=this.up.curve(0),this.computedRight=this.right.curve(0),this.computedRadius=this.radius.curve(0),this.computedAngle=this.angle.curve(0),this.computedToward=[0,0,0],this.computedEye=[0,0,0],this.computedMatrix=new Array(16);for(var c=0;c<16;++c)this.computedMatrix[c]=.5;this.recalcMatrix(0)}var p=f.prototype;p.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},p.getDistanceLimits=function(t){var e=this.radius.bounds[0];return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},p.recalcMatrix=function(t){this.center.curve(t),this.up.curve(t),this.right.curve(t),this.radius.curve(t),this.angle.curve(t);for(var e=this.computedUp,r=this.computedRight,n=0,i=0,a=0;a<3;++a)i+=e[a]*r[a],n+=e[a]*e[a];var l=Math.sqrt(n),u=0;for(a=0;a<3;++a)r[a]-=e[a]*i/n,u+=r[a]*r[a],e[a]/=l;var h=Math.sqrt(u);for(a=0;a<3;++a)r[a]/=h;var f=this.computedToward;o(f,e,r),s(f,f);var p=Math.exp(this.computedRadius[0]),d=this.computedAngle[0],g=this.computedAngle[1],v=Math.cos(d),m=Math.sin(d),y=Math.cos(g),x=Math.sin(g),b=this.computedCenter,_=v*y,w=m*y,k=x,T=-v*x,A=-m*x,M=y,S=this.computedEye,E=this.computedMatrix;for(a=0;a<3;++a){var C=_*r[a]+w*f[a]+k*e[a];E[4*a+1]=T*r[a]+A*f[a]+M*e[a],E[4*a+2]=C,E[4*a+3]=0}var L=E[1],P=E[5],O=E[9],z=E[2],I=E[6],D=E[10],R=P*D-O*I,F=O*z-L*D,B=L*I-P*z,N=c(R,F,B);R/=N,F/=N,B/=N,E[0]=R,E[4]=F,E[8]=B;for(a=0;a<3;++a)S[a]=b[a]+E[2+4*a]*p;for(a=0;a<3;++a){u=0;for(var j=0;j<3;++j)u+=E[a+4*j]*S[j];E[12+a]=-u}E[15]=1},p.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r};var d=[0,0,0];p.rotate=function(t,e,r,n){if(this.angle.move(t,e,r),n){this.recalcMatrix(t);var i=this.computedMatrix;d[0]=i[2],d[1]=i[6],d[2]=i[10];for(var o=this.computedUp,s=this.computedRight,l=this.computedToward,c=0;c<3;++c)i[4*c]=o[c],i[4*c+1]=s[c],i[4*c+2]=l[c];a(i,i,n,d);for(c=0;c<3;++c)o[c]=i[4*c],s[c]=i[4*c+1];this.up.set(t,o[0],o[1],o[2]),this.right.set(t,s[0],s[1],s[2])}},p.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=(Math.exp(this.computedRadius[0]),i[1]),o=i[5],s=i[9],l=c(a,o,s);a/=l,o/=l,s/=l;var u=i[0],h=i[4],f=i[8],p=u*a+h*o+f*s,d=c(u-=a*p,h-=o*p,f-=s*p),g=(u/=d)*e+a*r,v=(h/=d)*e+o*r,m=(f/=d)*e+s*r;this.center.move(t,g,v,m);var y=Math.exp(this.computedRadius[0]);y=Math.max(1e-4,y+n),this.radius.set(t,Math.log(y))},p.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},p.setMatrix=function(t,e,r,n){var a=1;\"number\"==typeof r&&(a=0|r),(a<0||a>3)&&(a=1);var o=(a+2)%3;e||(this.recalcMatrix(t),e=this.computedMatrix);var s=e[a],l=e[a+4],h=e[a+8];if(n){var f=Math.abs(s),p=Math.abs(l),d=Math.abs(h),g=Math.max(f,p,d);f===g?(s=s<0?-1:1,l=h=0):d===g?(h=h<0?-1:1,s=l=0):(l=l<0?-1:1,s=h=0)}else{var v=c(s,l,h);s/=v,l/=v,h/=v}var m,y,x=e[o],b=e[o+4],_=e[o+8],w=x*s+b*l+_*h,k=c(x-=s*w,b-=l*w,_-=h*w),T=l*(_/=k)-h*(b/=k),A=h*(x/=k)-s*_,M=s*b-l*x,S=c(T,A,M);if(T/=S,A/=S,M/=S,this.center.jump(t,H,G,Y),this.radius.idle(t),this.up.jump(t,s,l,h),this.right.jump(t,x,b,_),2===a){var E=e[1],C=e[5],L=e[9],P=E*x+C*b+L*_,O=E*T+C*A+L*M;m=R<0?-Math.PI/2:Math.PI/2,y=Math.atan2(O,P)}else{var z=e[2],I=e[6],D=e[10],R=z*s+I*l+D*h,F=z*x+I*b+D*_,B=z*T+I*A+D*M;m=Math.asin(u(R)),y=Math.atan2(B,F)}this.angle.jump(t,y,m),this.recalcMatrix(t);var N=e[2],j=e[6],U=e[10],V=this.computedMatrix;i(V,e);var q=V[15],H=V[12]/q,G=V[13]/q,Y=V[14]/q,W=Math.exp(this.computedRadius[0]);this.center.jump(t,H-N*W,G-j*W,Y-U*W)},p.lastT=function(){return Math.max(this.center.lastT(),this.up.lastT(),this.right.lastT(),this.radius.lastT(),this.angle.lastT())},p.idle=function(t){this.center.idle(t),this.up.idle(t),this.right.idle(t),this.radius.idle(t),this.angle.idle(t)},p.flush=function(t){this.center.flush(t),this.up.flush(t),this.right.flush(t),this.radius.flush(t),this.angle.flush(t)},p.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},p.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||this.computedCenter;var i=(n=n||this.computedUp)[0],a=n[1],o=n[2],s=c(i,a,o);if(!(s<1e-6)){i/=s,a/=s,o/=s;var l=e[0]-r[0],h=e[1]-r[1],f=e[2]-r[2],p=c(l,h,f);if(!(p<1e-6)){l/=p,h/=p,f/=p;var d=this.computedRight,g=d[0],v=d[1],m=d[2],y=i*g+a*v+o*m,x=c(g-=y*i,v-=y*a,m-=y*o);if(!(x<.01&&(x=c(g=a*f-o*h,v=o*l-i*f,m=i*h-a*l))<1e-6)){g/=x,v/=x,m/=x,this.up.set(t,i,a,o),this.right.set(t,g,v,m),this.center.set(t,r[0],r[1],r[2]),this.radius.set(t,Math.log(p));var b=a*m-o*v,_=o*g-i*m,w=i*v-a*g,k=c(b,_,w),T=i*l+a*h+o*f,A=g*l+v*h+m*f,M=(b/=k)*l+(_/=k)*h+(w/=k)*f,S=Math.asin(u(T)),E=Math.atan2(M,A),C=this.angle._state,L=C[C.length-1],P=C[C.length-2];L%=2*Math.PI;var O=Math.abs(L+2*Math.PI-E),z=Math.abs(L-E),I=Math.abs(L-2*Math.PI-E);O<z&&(L+=2*Math.PI),I<z&&(L-=2*Math.PI),this.angle.jump(this.angle.lastT(),L,P),this.angle.set(t,E,S)}}}}},{\"filtered-vector\":226,\"gl-mat4/invert\":265,\"gl-mat4/rotate\":270,\"gl-vec3/cross\":334,\"gl-vec3/dot\":339,\"gl-vec3/normalize\":356}],543:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var i=t*e,a=n*t,o=a-(a-t),s=t-o,l=n*e,c=l-(l-e),u=e-c,h=s*u-(i-o*c-s*c-o*u);if(r)return r[0]=h,r[1]=i,r;return[h,i]};var n=+(Math.pow(2,27)+1)},{}],544:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=t+e,i=n-t,a=e-i,o=t-(n-i);if(r)return r[0]=o+a,r[1]=n,r;return[o+a,n]}},{}],545:[function(t,e,r){(function(e,n){\"use strict\";var i=t(\"bit-twiddle\"),a=t(\"dup\");e.__TYPEDARRAY_POOL||(e.__TYPEDARRAY_POOL={UINT8:a([32,0]),UINT16:a([32,0]),UINT32:a([32,0]),INT8:a([32,0]),INT16:a([32,0]),INT32:a([32,0]),FLOAT:a([32,0]),DOUBLE:a([32,0]),DATA:a([32,0]),UINT8C:a([32,0]),BUFFER:a([32,0])});var o=\"undefined\"!=typeof Uint8ClampedArray,s=e.__TYPEDARRAY_POOL;s.UINT8C||(s.UINT8C=a([32,0])),s.BUFFER||(s.BUFFER=a([32,0]));var l=s.DATA,c=s.BUFFER;function u(t){if(t){var e=t.length||t.byteLength,r=i.log2(e);l[r].push(t)}}function h(t){t=i.nextPow2(t);var e=i.log2(t),r=l[e];return r.length>0?r.pop():new ArrayBuffer(t)}function f(t){return new Uint8Array(h(t),0,t)}function p(t){return new Uint16Array(h(2*t),0,t)}function d(t){return new Uint32Array(h(4*t),0,t)}function g(t){return new Int8Array(h(t),0,t)}function v(t){return new Int16Array(h(2*t),0,t)}function m(t){return new Int32Array(h(4*t),0,t)}function y(t){return new Float32Array(h(4*t),0,t)}function x(t){return new Float64Array(h(8*t),0,t)}function b(t){return o?new Uint8ClampedArray(h(t),0,t):f(t)}function _(t){return new DataView(h(t),0,t)}function w(t){t=i.nextPow2(t);var e=i.log2(t),r=c[e];return r.length>0?r.pop():new n(t)}r.free=function(t){if(n.isBuffer(t))c[i.log2(t.length)].push(t);else{if(\"[object ArrayBuffer]\"!==Object.prototype.toString.call(t)&&(t=t.buffer),!t)return;var e=t.length||t.byteLength,r=0|i.log2(e);l[r].push(t)}},r.freeUint8=r.freeUint16=r.freeUint32=r.freeInt8=r.freeInt16=r.freeInt32=r.freeFloat32=r.freeFloat=r.freeFloat64=r.freeDouble=r.freeUint8Clamped=r.freeDataView=function(t){u(t.buffer)},r.freeArrayBuffer=u,r.freeBuffer=function(t){c[i.log2(t.length)].push(t)},r.malloc=function(t,e){if(void 0===e||\"arraybuffer\"===e)return h(t);switch(e){case\"uint8\":return f(t);case\"uint16\":return p(t);case\"uint32\":return d(t);case\"int8\":return g(t);case\"int16\":return v(t);case\"int32\":return m(t);case\"float\":case\"float32\":return y(t);case\"double\":case\"float64\":return x(t);case\"uint8_clamped\":return b(t);case\"buffer\":return w(t);case\"data\":case\"dataview\":return _(t);default:return null}return null},r.mallocArrayBuffer=h,r.mallocUint8=f,r.mallocUint16=p,r.mallocUint32=d,r.mallocInt8=g,r.mallocInt16=v,r.mallocInt32=m,r.mallocFloat32=r.mallocFloat=y,r.mallocFloat64=r.mallocDouble=x,r.mallocUint8Clamped=b,r.mallocDataView=_,r.mallocBuffer=w,r.clearCache=function(){for(var t=0;t<32;++t)s.UINT8[t].length=0,s.UINT16[t].length=0,s.UINT32[t].length=0,s.INT8[t].length=0,s.INT16[t].length=0,s.INT32[t].length=0,s.FLOAT[t].length=0,s.DOUBLE[t].length=0,s.UINT8C[t].length=0,l[t].length=0,c[t].length=0}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{},t(\"buffer\").Buffer)},{\"bit-twiddle\":92,buffer:105,dup:170}],546:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n;var i=n.prototype;Object.defineProperty(i,\"length\",{get:function(){return this.roots.length}}),i.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},i.find=function(t){for(var e=t,r=this.roots;r[t]!==t;)t=r[t];for(;r[e]!==t;){var n=r[e];r[e]=t,e=n}return t},i.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],547:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return 0===t.length?t:e?(r||t.sort(e),function(t,e){for(var r=1,n=t.length,i=t[0],a=t[0],o=1;o<n;++o)if(a=i,e(i=t[o],a)){if(o===r){r++;continue}t[r++]=i}return t.length=r,t}(t,e)):(r||t.sort(),function(t){for(var e=1,r=t.length,n=t[0],i=t[0],a=1;a<r;++a,i=n)if(i=n,(n=t[a])!==i){if(a===e){e++;continue}t[e++]=n}return t.length=e,t}(t))}},{}],548:[function(t,e,r){var n=/[\\'\\\"]/;e.exports=function(t){return t?(n.test(t.charAt(0))&&(t=t.substr(1)),n.test(t.charAt(t.length-1))&&(t=t.substr(0,t.length-1)),t):\"\"}},{}],549:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){Array.isArray(r)||(r=[].slice.call(arguments,2));for(var n=0,i=r.length;n<i;n++){var a=r[n];for(var o in a)if((void 0===e[o]||Array.isArray(e[o])||t[o]!==e[o])&&o in e){var s;if(!0===a[o])s=e[o];else{if(!1===a[o])continue;if(\"function\"==typeof a[o]&&void 0===(s=a[o](e[o],t,e)))continue}t[o]=s}}return t}},{}],550:[function(t,e,r){\"use strict\";e.exports=function(t,e){\"object\"==typeof e&&null!==e||(e={});return n(t,e.canvas||i,e.context||a,e)};var n=t(\"./lib/vtext\"),i=null,a=null;\"undefined\"!=typeof document&&((i=document.createElement(\"canvas\")).width=8192,i.height=1024,a=i.getContext(\"2d\"))},{\"./lib/vtext\":551}],551:[function(t,e,r){e.exports=function(t,e,r,n){var a=64,o=1.25,s={breaklines:!1,bolds:!1,italics:!1,subscripts:!1,superscripts:!1};n&&(n.size&&n.size>0&&(a=n.size),n.lineSpacing&&n.lineSpacing>0&&(o=n.lineSpacing),n.styletags&&n.styletags.breaklines&&(s.breaklines=!!n.styletags.breaklines),n.styletags&&n.styletags.bolds&&(s.bolds=!!n.styletags.bolds),n.styletags&&n.styletags.italics&&(s.italics=!!n.styletags.italics),n.styletags&&n.styletags.subscripts&&(s.subscripts=!!n.styletags.subscripts),n.styletags&&n.styletags.superscripts&&(s.superscripts=!!n.styletags.superscripts));return r.font=[n.fontStyle,n.fontVariant,n.fontWeight,a+\"px\",n.font].filter(function(t){return t}).join(\" \"),r.textAlign=\"start\",r.textBaseline=\"alphabetic\",r.direction=\"ltr\",w(function(t,e,r,n,a,o){r=r.replace(/\\n/g,\"\"),r=!0===o.breaklines?r.replace(/\\<br\\>/g,\"\\n\"):r.replace(/\\<br\\>/g,\" \");var s=\"\",l=[];for(k=0;k<r.length;++k)l[k]=s;!0===o.bolds&&(l=x(c,u,r,l)),!0===o.italics&&(l=x(h,f,r,l)),!0===o.superscripts&&(l=x(p,g,r,l)),!0===o.subscripts&&(l=x(v,y,r,l));var b=[],_=\"\";for(k=0;k<r.length;++k)null!==l[k]&&(_+=r[k],b.push(l[k]));var w,k,T,A,M,S=_.split(\"\\n\"),E=S.length,C=Math.round(a*n),L=n,P=2*n,O=0,z=E*C+P;t.height<z&&(t.height=z),e.fillStyle=\"#000\",e.fillRect(0,0,t.width,t.height),e.fillStyle=\"#fff\";var I=0,D=\"\";function R(){if(\"\"!==D){var t=e.measureText(D).width;e.fillText(D,L+T,P+A),T+=t}}function F(){return Math.round(M)+\"px \"}function B(t,r){var n=\"\"+e.font;if(!0===o.subscripts){var i=t.indexOf(m),a=r.indexOf(m),s=i>-1?parseInt(t[1+i]):0,l=a>-1?parseInt(r[1+a]):0;s!==l&&(n=n.replace(F(),\"?px \"),M*=Math.pow(.75,l-s),n=n.replace(\"?px \",F())),A+=.25*C*(l-s)}if(!0===o.superscripts){var c=t.indexOf(d),h=r.indexOf(d),p=c>-1?parseInt(t[1+c]):0,g=h>-1?parseInt(r[1+h]):0;p!==g&&(n=n.replace(F(),\"?px \"),M*=Math.pow(.75,g-p),n=n.replace(\"?px \",F())),A-=.25*C*(g-p)}if(!0===o.bolds){var v=t.indexOf(u)>-1,y=r.indexOf(u)>-1;!v&&y&&(n=x?n.replace(\"italic \",\"italic bold \"):\"bold \"+n),v&&!y&&(n=n.replace(\"bold \",\"\"))}if(!0===o.italics){var x=t.indexOf(f)>-1,b=r.indexOf(f)>-1;!x&&b&&(n=\"italic \"+n),x&&!b&&(n=n.replace(\"italic \",\"\"))}e.font=n}for(w=0;w<E;++w){var N=S[w]+\"\\n\";for(T=0,A=w*C,M=n,D=\"\",k=0;k<N.length;++k){var j=k+I<b.length?b[k+I]:b[b.length-1];s===j?D+=N[k]:(R(),D=N[k],void 0!==j&&(B(s,j),s=j))}R(),I+=N.length;var U=0|Math.round(T+2*L);O<U&&(O=U)}var V=O,q=P+C*E;return i(e.getImageData(0,0,V,q).data,[q,V,4]).pick(-1,-1,0).transpose(1,0)}(e,r,t,a,o,s),n,a)},e.exports.processPixels=w;var n=t(\"surface-nets\"),i=t(\"ndarray\"),a=t(\"simplify-planar-graph\"),o=t(\"clean-pslg\"),s=t(\"cdt2d\"),l=t(\"planar-graph-to-polyline\"),c=\"b\",u=\"b|\",h=\"i\",f=\"i|\",p=\"sup\",d=\"+\",g=\"+1\",v=\"sub\",m=\"-\",y=\"-1\";function x(t,e,r,n){for(var i=\"<\"+t+\">\",a=\"</\"+t+\">\",o=i.length,s=a.length,l=e[0]===d||e[0]===m,c=0,u=-s;c>-1&&-1!==(c=r.indexOf(i,c))&&-1!==(u=r.indexOf(a,c+o))&&!(u<=c);){for(var h=c;h<u+s;++h)if(h<c+o||h>=u)n[h]=null,r=r.substr(0,h)+\" \"+r.substr(h+1);else if(null!==n[h]){var f=n[h].indexOf(e[0]);-1===f?n[h]+=e:l&&(n[h]=n[h].substr(0,f+1)+(1+parseInt(n[h][f+1]))+n[h].substr(f+2))}var p=c+o,g=r.substr(p,u-p).indexOf(i);c=-1!==g?g:u+s}return n}function b(t,e){var r=n(t,128);return e?a(r.cells,r.positions,.25):{edges:r.cells,positions:r.positions}}function _(t,e,r,n){var i=b(t,n),a=function(t,e,r){for(var n=e.textAlign||\"start\",i=e.textBaseline||\"alphabetic\",a=[1<<30,1<<30],o=[0,0],s=t.length,l=0;l<s;++l)for(var c=t[l],u=0;u<2;++u)a[u]=0|Math.min(a[u],c[u]),o[u]=0|Math.max(o[u],c[u]);var h=0;switch(n){case\"center\":h=-.5*(a[0]+o[0]);break;case\"right\":case\"end\":h=-o[0];break;case\"left\":case\"start\":h=-a[0];break;default:throw new Error(\"vectorize-text: Unrecognized textAlign: '\"+n+\"'\")}var f=0;switch(i){case\"hanging\":case\"top\":f=-a[1];break;case\"middle\":f=-.5*(a[1]+o[1]);break;case\"alphabetic\":case\"ideographic\":f=-3*r;break;case\"bottom\":f=-o[1];break;default:throw new Error(\"vectorize-text: Unrecoginized textBaseline: '\"+i+\"'\")}var p=1/r;return\"lineHeight\"in e?p*=+e.lineHeight:\"width\"in e?p=e.width/(o[0]-a[0]):\"height\"in e&&(p=e.height/(o[1]-a[1])),t.map(function(t){return[p*(t[0]+h),p*(t[1]+f)]})}(i.positions,e,r),c=i.edges,u=\"ccw\"===e.orientation;if(o(a,c),e.polygons||e.polygon||e.polyline){for(var h=l(c,a),f=new Array(h.length),p=0;p<h.length;++p){for(var d=h[p],g=new Array(d.length),v=0;v<d.length;++v){for(var m=d[v],y=new Array(m.length),x=0;x<m.length;++x)y[x]=a[m[x]].slice();u&&y.reverse(),g[v]=y}f[p]=g}return f}return e.triangles||e.triangulate||e.triangle?{cells:s(a,c,{delaunay:!1,exterior:!1,interior:!0}),positions:a}:{edges:c,positions:a}}function w(t,e,r){try{return _(t,e,r,!0)}catch(t){}try{return _(t,e,r,!1)}catch(t){}return e.polygons||e.polyline||e.polygon?[]:e.triangles||e.triangulate||e.triangle?{cells:[],positions:[]}:{edges:[],positions:[]}}},{cdt2d:106,\"clean-pslg\":116,ndarray:450,\"planar-graph-to-polyline\":468,\"simplify-planar-graph\":524,\"surface-nets\":531}],552:[function(t,e,r){!function(){\"use strict\";if(\"undefined\"==typeof ses||!ses.ok||ses.ok()){\"undefined\"!=typeof ses&&(ses.weakMapPermitHostObjects=v);var t=!1;if(\"function\"==typeof WeakMap){var r=WeakMap;if(\"undefined\"!=typeof navigator&&/Firefox/.test(navigator.userAgent));else{var n=new r,i=Object.freeze({});if(n.set(i,1),1===n.get(i))return void(e.exports=WeakMap);t=!0}}Object.prototype.hasOwnProperty;var a=Object.getOwnPropertyNames,o=Object.defineProperty,s=Object.isExtensible,l=\"weakmap:\",c=l+\"ident:\"+Math.random()+\"___\";if(\"undefined\"!=typeof crypto&&\"function\"==typeof crypto.getRandomValues&&\"function\"==typeof ArrayBuffer&&\"function\"==typeof Uint8Array){var u=new ArrayBuffer(25),h=new Uint8Array(u);crypto.getRandomValues(h),c=l+\"rand:\"+Array.prototype.map.call(h,function(t){return(t%36).toString(36)}).join(\"\")+\"___\"}if(o(Object,\"getOwnPropertyNames\",{value:function(t){return a(t).filter(m)}}),\"getPropertyNames\"in Object){var f=Object.getPropertyNames;o(Object,\"getPropertyNames\",{value:function(t){return f(t).filter(m)}})}!function(){var t=Object.freeze;o(Object,\"freeze\",{value:function(e){return y(e),t(e)}});var e=Object.seal;o(Object,\"seal\",{value:function(t){return y(t),e(t)}});var r=Object.preventExtensions;o(Object,\"preventExtensions\",{value:function(t){return y(t),r(t)}})}();var p=!1,d=0,g=function(){this instanceof g||b();var t=[],e=[],r=d++;return Object.create(g.prototype,{get___:{value:x(function(n,i){var a,o=y(n);return o?r in o?o[r]:i:(a=t.indexOf(n))>=0?e[a]:i})},has___:{value:x(function(e){var n=y(e);return n?r in n:t.indexOf(e)>=0})},set___:{value:x(function(n,i){var a,o=y(n);return o?o[r]=i:(a=t.indexOf(n))>=0?e[a]=i:(a=t.length,e[a]=i,t[a]=n),this})},delete___:{value:x(function(n){var i,a,o=y(n);return o?r in o&&delete o[r]:!((i=t.indexOf(n))<0||(a=t.length-1,t[i]=void 0,e[i]=e[a],t[i]=t[a],t.length=a,e.length=a,0))})}})};g.prototype=Object.create(Object.prototype,{get:{value:function(t,e){return this.get___(t,e)},writable:!0,configurable:!0},has:{value:function(t){return this.has___(t)},writable:!0,configurable:!0},set:{value:function(t,e){return this.set___(t,e)},writable:!0,configurable:!0},delete:{value:function(t){return this.delete___(t)},writable:!0,configurable:!0}}),\"function\"==typeof r?function(){function n(){this instanceof g||b();var e,n=new r,i=void 0,a=!1;return e=t?function(t,e){return n.set(t,e),n.has(t)||(i||(i=new g),i.set(t,e)),this}:function(t,e){if(a)try{n.set(t,e)}catch(r){i||(i=new g),i.set___(t,e)}else n.set(t,e);return this},Object.create(g.prototype,{get___:{value:x(function(t,e){return i?n.has(t)?n.get(t):i.get___(t,e):n.get(t,e)})},has___:{value:x(function(t){return n.has(t)||!!i&&i.has___(t)})},set___:{value:x(e)},delete___:{value:x(function(t){var e=!!n.delete(t);return i&&i.delete___(t)||e})},permitHostObjects___:{value:x(function(t){if(t!==v)throw new Error(\"bogus call to permitHostObjects___\");a=!0})}})}t&&\"undefined\"!=typeof Proxy&&(Proxy=void 0),n.prototype=g.prototype,e.exports=n,Object.defineProperty(WeakMap.prototype,\"constructor\",{value:WeakMap,enumerable:!1,configurable:!0,writable:!0})}():(\"undefined\"!=typeof Proxy&&(Proxy=void 0),e.exports=g)}function v(t){t.permitHostObjects___&&t.permitHostObjects___(v)}function m(t){return!(t.substr(0,l.length)==l&&\"___\"===t.substr(t.length-3))}function y(t){if(t!==Object(t))throw new TypeError(\"Not an object: \"+t);var e=t[c];if(e&&e.key===t)return e;if(s(t)){e={key:t};try{return o(t,c,{value:e,writable:!1,enumerable:!1,configurable:!1}),e}catch(t){return}}}function x(t){return t.prototype=null,Object.freeze(t)}function b(){p||\"undefined\"==typeof console||(p=!0,console.warn(\"WeakMap should be invoked as new WeakMap(), not WeakMap(). This will be an error in the future.\"))}}()},{}],553:[function(t,e,r){var n=t(\"./hidden-store.js\");e.exports=function(){var t={};return function(e){if((\"object\"!=typeof e||null===e)&&\"function\"!=typeof e)throw new Error(\"Weakmap-shim: Key must be object\");var r=e.valueOf(t);return r&&r.identity===t?r:n(e,t)}}},{\"./hidden-store.js\":554}],554:[function(t,e,r){e.exports=function(t,e){var r={identity:e},n=t.valueOf;return Object.defineProperty(t,\"valueOf\",{value:function(t){return t!==e?n.apply(this,arguments):r},writable:!0}),r}},{}],555:[function(t,e,r){var n=t(\"./create-store.js\");e.exports=function(){var t=n();return{get:function(e,r){var n=t(e);return n.hasOwnProperty(\"value\")?n.value:r},set:function(e,r){return t(e).value=r,this},has:function(e){return\"value\"in t(e)},delete:function(e){return delete t(e).value}}}},{\"./create-store.js\":553}],556:[function(t,e,r){var n=t(\"get-canvas-context\");e.exports=function(t){return n(\"webgl\",t)}},{\"get-canvas-context\":232}],557:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Chinese\",jdEpoch:1721425.5,hasYearZero:!1,minMonth:0,firstMonth:0,minDay:1,regionalOptions:{\"\":{name:\"Chinese\",epochs:[\"BEC\",\"EC\"],monthNumbers:function(t,e){if(\"string\"==typeof t){var r=t.match(l);return r?r[0]:\"\"}var n=this._validateYear(t),i=t.month(),a=\"\"+this.toChineseMonth(n,i);return e&&a.length<2&&(a=\"0\"+a),this.isIntercalaryMonth(n,i)&&(a+=\"i\"),a},monthNames:function(t){if(\"string\"==typeof t){var e=t.match(c);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\\u6708\",\"\\u4e8c\\u6708\",\"\\u4e09\\u6708\",\"\\u56db\\u6708\",\"\\u4e94\\u6708\",\"\\u516d\\u6708\",\"\\u4e03\\u6708\",\"\\u516b\\u6708\",\"\\u4e5d\\u6708\",\"\\u5341\\u6708\",\"\\u5341\\u4e00\\u6708\",\"\\u5341\\u4e8c\\u6708\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},monthNamesShort:function(t){if(\"string\"==typeof t){var e=t.match(u);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},parseMonth:function(t,e){t=this._validateYear(t);var r,n=parseInt(e);if(isNaN(n))\"\\u95f0\"===e[0]&&(r=!0,e=e.substring(1)),\"\\u6708\"===e[e.length-1]&&(e=e.substring(0,e.length-1)),n=1+[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"].indexOf(e);else{var i=e[e.length-1];r=\"i\"===i||\"I\"===i}return this.toMonthIndex(t,n,r)},dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},_validateYear:function(t,e){if(t.year&&(t=t.year()),\"number\"!=typeof t||t<1888||t>2111)throw e.replace(/\\{0\\}/,this.local.name);return t},toMonthIndex:function(t,e,r){var i=this.intercalaryMonth(t);if(r&&e!==i||e<1||e>12)throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return i?!r&&e<=i?e-1:e:e-1},toChineseMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);if(e<0||e>(r?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r?e<r?e+1:e:e+1},intercalaryMonth:function(t){return t=this._validateYear(t),h[t-h[0]]>>13},isIntercalaryMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);return!!r&&r===e},leapYear:function(t){return 0!==this.intercalaryMonth(t)},weekOfYear:function(t,e,r){var i,o=this._validateYear(t,n.local.invalidyear),s=f[o-f[0]],l=s>>9&4095,c=s>>5&15,u=31&s;(i=a.newDate(l,c,u)).add(4-(i.dayOfWeek()||7),\"d\");var h=this.toJD(t,e,r)-i.toJD();return 1+Math.floor(h/7)},monthsInYear:function(t){return this.leapYear(t)?13:12},daysInMonth:function(t,e){t.year&&(e=t.month(),t=t.year()),t=this._validateYear(t);var r=h[t-h[0]];if(e>(r>>13?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r&1<<12-e?30:29},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,s,r,n.local.invalidDate);t=this._validateYear(i.year()),e=i.month(),r=i.day();var o=this.isIntercalaryMonth(t,e),s=this.toChineseMonth(t,e),l=function(t,e,r,n,i){var a,o,s;if(\"object\"==typeof t)o=t,a=e||{};else{var l=\"number\"==typeof t&&t>=1888&&t<=2111;if(!l)throw new Error(\"Lunar year outside range 1888-2111\");var c=\"number\"==typeof e&&e>=1&&e<=12;if(!c)throw new Error(\"Lunar month outside range 1 - 12\");var u,p=\"number\"==typeof r&&r>=1&&r<=30;if(!p)throw new Error(\"Lunar day outside range 1 - 30\");\"object\"==typeof n?(u=!1,a=n):(u=!!n,a=i||{}),o={year:t,month:e,day:r,isIntercalary:u}}s=o.day-1;var d,g=h[o.year-h[0]],v=g>>13;d=v?o.month>v?o.month:o.isIntercalary?o.month:o.month-1:o.month-1;for(var m=0;m<d;m++){var y=g&1<<12-m?30:29;s+=y}var x=f[o.year-f[0]],b=new Date(x>>9&4095,(x>>5&15)-1,(31&x)+s);return a.year=b.getFullYear(),a.month=1+b.getMonth(),a.day=b.getDate(),a}(t,s,r,o);return a.toJD(l.year,l.month,l.day)},fromJD:function(t){var e=a.fromJD(t),r=function(t,e,r,n){var i,a;if(\"object\"==typeof t)i=t,a=e||{};else{var o=\"number\"==typeof t&&t>=1888&&t<=2111;if(!o)throw new Error(\"Solar year outside range 1888-2111\");var s=\"number\"==typeof e&&e>=1&&e<=12;if(!s)throw new Error(\"Solar month outside range 1 - 12\");var l=\"number\"==typeof r&&r>=1&&r<=31;if(!l)throw new Error(\"Solar day outside range 1 - 31\");i={year:t,month:e,day:r},a=n||{}}var c=f[i.year-f[0]],u=i.year<<9|i.month<<5|i.day;a.year=u>=c?i.year:i.year-1,c=f[a.year-f[0]];var p,d=new Date(c>>9&4095,(c>>5&15)-1,31&c),g=new Date(i.year,i.month-1,i.day);p=Math.round((g-d)/864e5);var v,m=h[a.year-h[0]];for(v=0;v<13;v++){var y=m&1<<12-v?30:29;if(p<y)break;p-=y}var x=m>>13;!x||v<x?(a.isIntercalary=!1,a.month=1+v):v===x?(a.isIntercalary=!0,a.month=v):(a.isIntercalary=!1,a.month=v);return a.day=1+p,a}(e.year(),e.month(),e.day()),n=this.toMonthIndex(r.year,r.month,r.isIntercalary);return this.newDate(r.year,n,r.day)},fromString:function(t){var e=t.match(s),r=this._validateYear(+e[1]),n=+e[2],i=!!e[3],a=this.toMonthIndex(r,n,i),o=+e[4];return this.newDate(r,a,o)},add:function(t,e,r){var n=t.year(),i=t.month(),a=this.isIntercalaryMonth(n,i),s=this.toChineseMonth(n,i),l=Object.getPrototypeOf(o.prototype).add.call(this,t,e,r);if(\"y\"===r){var c=l.year(),u=l.month(),h=this.isIntercalaryMonth(c,s),f=a&&h?this.toMonthIndex(c,s,!0):this.toMonthIndex(c,s,!1);f!==u&&l.month(f)}return l}});var s=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)[-\\/](\\d?\\d)([iI]?)[-\\/](\\d?\\d)/m,l=/^\\d?\\d[iI]?/m,c=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?\\u6708/m,u=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?/m;n.calendars.chinese=o;var h=[1887,5780,5802,19157,2742,50359,1198,2646,46378,7466,3412,30122,5482,67949,2396,5294,43597,6732,6954,36181,2772,4954,18781,2396,54427,5274,6730,47781,5800,6868,21210,4790,59703,2350,5270,46667,3402,3496,38325,1388,4782,18735,2350,52374,6804,7498,44457,2906,1388,29294,4700,63789,6442,6804,56138,5802,2772,38235,1210,4698,22827,5418,63125,3476,5802,43701,2484,5302,27223,2646,70954,7466,3412,54698,5482,2412,38062,5294,2636,32038,6954,60245,2772,4826,43357,2394,5274,39501,6730,72357,5800,5844,53978,4790,2358,38039,5270,87627,3402,3496,54708,5484,4782,43311,2350,3222,27978,7498,68965,2904,5484,45677,4700,6444,39573,6804,6986,19285,2772,62811,1210,4698,47403,5418,5780,38570,5546,76469,2420,5302,51799,2646,5414,36501,3412,5546,18869,2412,54446,5276,6732,48422,6822,2900,28010,4826,92509,2394,5274,55883,6730,6820,47956,5812,2778,18779,2358,62615,5270,5450,46757,3492,5556,27318,4718,67887,2350,3222,52554,7498,3428,38252,5468,4700,31022,6444,64149,6804,6986,43861,2772,5338,35421,2650,70955,5418,5780,54954,5546,2740,38074,5302,2646,29991,3366,61011,3412,5546,43445,2412,5294,35406,6732,72998,6820,6996,52586,2778,2396,38045,5274,6698,23333,6820,64338,5812,2746,43355,2358,5270,39499,5450,79525,3492,5548],f=[1887,966732,967231,967733,968265,968766,969297,969798,970298,970829,971330,971830,972362,972863,973395,973896,974397,974928,975428,975929,976461,976962,977462,977994,978494,979026,979526,980026,980558,981059,981559,982091,982593,983124,983624,984124,984656,985157,985656,986189,986690,987191,987722,988222,988753,989254,989754,990286,990788,991288,991819,992319,992851,993352,993851,994383,994885,995385,995917,996418,996918,997450,997949,998481,998982,999483,1000014,1000515,1001016,1001548,1002047,1002578,1003080,1003580,1004111,1004613,1005113,1005645,1006146,1006645,1007177,1007678,1008209,1008710,1009211,1009743,1010243,1010743,1011275,1011775,1012306,1012807,1013308,1013840,1014341,1014841,1015373,1015874,1016404,1016905,1017405,1017937,1018438,1018939,1019471,1019972,1020471,1021002,1021503,1022035,1022535,1023036,1023568,1024069,1024568,1025100,1025601,1026102,1026633,1027133,1027666,1028167,1028666,1029198,1029699,1030199,1030730,1031231,1031763,1032264,1032764,1033296,1033797,1034297,1034828,1035329,1035830,1036362,1036861,1037393,1037894,1038394,1038925,1039427,1039927,1040459,1040959,1041491,1041992,1042492,1043023,1043524,1044024,1044556,1045057,1045558,1046090,1046590,1047121,1047622,1048122,1048654,1049154,1049655,1050187,1050689,1051219,1051720,1052220,1052751,1053252,1053752,1054284,1054786,1055285,1055817,1056317,1056849,1057349,1057850,1058382,1058883,1059383,1059915,1060415,1060947,1061447,1061947,1062479,1062981,1063480,1064012,1064514,1065014,1065545,1066045,1066577,1067078,1067578,1068110,1068611,1069112,1069642,1070142,1070674,1071175,1071675,1072207,1072709,1073209,1073740,1074241,1074741,1075273,1075773,1076305,1076807,1077308,1077839,1078340,1078840,1079372,1079871,1080403,1080904]},{\"../main\":571,\"object-assign\":454}],558:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Coptic\",jdEpoch:1825029.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Coptic\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Thout\",\"Paopi\",\"Hathor\",\"Koiak\",\"Tobi\",\"Meshir\",\"Paremhat\",\"Paremoude\",\"Pashons\",\"Paoni\",\"Epip\",\"Mesori\",\"Pi Kogi Enavot\"],monthNamesShort:[\"Tho\",\"Pao\",\"Hath\",\"Koi\",\"Tob\",\"Mesh\",\"Pat\",\"Pad\",\"Pash\",\"Pao\",\"Epi\",\"Meso\",\"PiK\"],dayNames:[\"Tkyriaka\",\"Pesnau\",\"Pshoment\",\"Peftoou\",\"Ptiou\",\"Psoou\",\"Psabbaton\"],dayNamesShort:[\"Tky\",\"Pes\",\"Psh\",\"Pef\",\"Pti\",\"Pso\",\"Psa\"],dayNamesMin:[\"Tk\",\"Pes\",\"Psh\",\"Pef\",\"Pt\",\"Pso\",\"Psa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.coptic=a},{\"../main\":571,\"object-assign\":454}],559:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Discworld\",jdEpoch:1721425.5,daysPerMonth:[16,32,32,32,32,32,32,32,32,32,32,32,32],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Discworld\",epochs:[\"BUC\",\"UC\"],monthNames:[\"Ick\",\"Offle\",\"February\",\"March\",\"April\",\"May\",\"June\",\"Grune\",\"August\",\"Spune\",\"Sektober\",\"Ember\",\"December\"],monthNamesShort:[\"Ick\",\"Off\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Gru\",\"Aug\",\"Spu\",\"Sek\",\"Emb\",\"Dec\"],dayNames:[\"Sunday\",\"Octeday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Oct\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Oc\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:2,isRTL:!1}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),13},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),400},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/8)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]},daysInWeek:function(){return 8},dayOfWeek:function(t,e,r){return(this._validate(t,e,r,n.local.invalidDate).day()+1)%8},weekDay:function(t,e,r){var n=this.dayOfWeek(t,e,r);return n>=2&&n<=6},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{century:o[Math.floor((i.year()-1)/100)+1]||\"\"}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year()+(i.year()<0?1:0),e=i.month(),(r=i.day())+(e>1?16:0)+(e>2?32*(e-2):0)+400*(t-1)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t+.5)-Math.floor(this.jdEpoch)-1;var e=Math.floor(t/400)+1;t-=400*(e-1),t+=t>15?16:0;var r=Math.floor(t/32)+1,n=t-32*(r-1)+1;return this.newDate(e<=0?e-1:e,r,n)}});var o={20:\"Fruitbat\",21:\"Anchovy\"};n.calendars.discworld=a},{\"../main\":571,\"object-assign\":454}],560:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Ethiopian\",jdEpoch:1724220.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Ethiopian\",epochs:[\"BEE\",\"EE\"],monthNames:[\"Meskerem\",\"Tikemet\",\"Hidar\",\"Tahesas\",\"Tir\",\"Yekatit\",\"Megabit\",\"Miazia\",\"Genbot\",\"Sene\",\"Hamle\",\"Nehase\",\"Pagume\"],monthNamesShort:[\"Mes\",\"Tik\",\"Hid\",\"Tah\",\"Tir\",\"Yek\",\"Meg\",\"Mia\",\"Gen\",\"Sen\",\"Ham\",\"Neh\",\"Pag\"],dayNames:[\"Ehud\",\"Segno\",\"Maksegno\",\"Irob\",\"Hamus\",\"Arb\",\"Kidame\"],dayNamesShort:[\"Ehu\",\"Seg\",\"Mak\",\"Iro\",\"Ham\",\"Arb\",\"Kid\"],dayNamesMin:[\"Eh\",\"Se\",\"Ma\",\"Ir\",\"Ha\",\"Ar\",\"Ki\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.ethiopian=a},{\"../main\":571,\"object-assign\":454}],561:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Hebrew\",jdEpoch:347995.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29,29],hasYearZero:!1,minMonth:1,firstMonth:7,minDay:1,regionalOptions:{\"\":{name:\"Hebrew\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Nisan\",\"Iyar\",\"Sivan\",\"Tammuz\",\"Av\",\"Elul\",\"Tishrei\",\"Cheshvan\",\"Kislev\",\"Tevet\",\"Shevat\",\"Adar\",\"Adar II\"],monthNamesShort:[\"Nis\",\"Iya\",\"Siv\",\"Tam\",\"Av\",\"Elu\",\"Tis\",\"Che\",\"Kis\",\"Tev\",\"She\",\"Ada\",\"Ad2\"],dayNames:[\"Yom Rishon\",\"Yom Sheni\",\"Yom Shlishi\",\"Yom Revi'i\",\"Yom Chamishi\",\"Yom Shishi\",\"Yom Shabbat\"],dayNamesShort:[\"Ris\",\"She\",\"Shl\",\"Rev\",\"Cha\",\"Shi\",\"Sha\"],dayNamesMin:[\"Ri\",\"She\",\"Shl\",\"Re\",\"Ch\",\"Shi\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return this._leapYear(e.year())},_leapYear:function(t){return o(7*(t=t<0?t+1:t)+1,19)<7},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),this._leapYear(t.year?t.year():t)?13:12},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),this.toJD(-1===t?1:t+1,7,1)-this.toJD(t,7,1)},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),12===e&&this.leapYear(t)?30:8===e&&5===o(this.daysInYear(t),10)?30:9===e&&3===o(this.daysInYear(t),10)?29:this.daysPerMonth[e-1]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{yearType:(this.leapYear(i)?\"embolismic\":\"common\")+\" \"+[\"deficient\",\"regular\",\"complete\"][this.daysInYear(i)%10-3]}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t<=0?t+1:t,o=this.jdEpoch+this._delay1(a)+this._delay2(a)+r+1;if(e<7){for(var s=7;s<=this.monthsInYear(t);s++)o+=this.daysInMonth(t,s);for(s=1;s<e;s++)o+=this.daysInMonth(t,s)}else for(s=7;s<e;s++)o+=this.daysInMonth(t,s);return o},_delay1:function(t){var e=Math.floor((235*t-234)/19),r=12084+13753*e,n=29*e+Math.floor(r/25920);return o(3*(n+1),7)<3&&n++,n},_delay2:function(t){var e=this._delay1(t-1),r=this._delay1(t);return this._delay1(t+1)-r==356?2:r-e==382?1:0},fromJD:function(t){t=Math.floor(t)+.5;for(var e=Math.floor(98496*(t-this.jdEpoch)/35975351)-1;t>=this.toJD(-1===e?1:e+1,7,1);)e++;for(var r=t<this.toJD(e,1,1)?7:1;t>this.toJD(e,r,this.daysInMonth(e,r));)r++;var n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.hebrew=a},{\"../main\":571,\"object-assign\":454}],562:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Islamic\",jdEpoch:1948439.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Islamic\",epochs:[\"BH\",\"AH\"],monthNames:[\"Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' al-thani\",\"Jumada al-awwal\",\"Jumada al-thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-ahad\",\"Yawm al-ithnayn\",\"Yawm ath-thulaathaa'\",\"Yawm al-arbi'aa'\",\"Yawm al-kham\\u012bs\",\"Yawm al-jum'a\",\"Yawm as-sabt\"],dayNamesShort:[\"Aha\",\"Ith\",\"Thu\",\"Arb\",\"Kha\",\"Jum\",\"Sab\"],dayNamesMin:[\"Ah\",\"It\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){return(11*this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year()+14)%30<11},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return this.leapYear(t)?355:354},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),t=t<=0?t+1:t,(r=i.day())+Math.ceil(29.5*(e-1))+354*(t-1)+Math.floor((3+11*t)/30)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t)+.5;var e=Math.floor((30*(t-this.jdEpoch)+10646)/10631);e=e<=0?e-1:e;var r=Math.min(12,Math.ceil((t-29-this.toJD(e,1,1))/29.5)+1),n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.islamic=a},{\"../main\":571,\"object-assign\":454}],563:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Julian\",jdEpoch:1721423.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Julian\",epochs:[\"BC\",\"AD\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()<0?e.year()+1:e.year())%4==0},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),r=i.day(),t<0&&t++,e<=2&&(t--,e+=12),Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r-1524.5},fromJD:function(t){var e=Math.floor(t+.5)+1524,r=Math.floor((e-122.1)/365.25),n=Math.floor(365.25*r),i=Math.floor((e-n)/30.6001),a=i-Math.floor(i<14?1:13),o=r-Math.floor(a>2?4716:4715),s=e-n-Math.floor(30.6001*i);return o<=0&&o--,this.newDate(o,a,s)}}),n.calendars.julian=a},{\"../main\":571,\"object-assign\":454}],564:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}function s(t,e){return o(t-1,e)+1}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Mayan\",jdEpoch:584282.5,hasYearZero:!0,minMonth:0,firstMonth:0,minDay:0,regionalOptions:{\"\":{name:\"Mayan\",epochs:[\"\",\"\"],monthNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],monthNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],dayNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesMin:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],digits:null,dateFormat:\"YYYY.m.d\",firstDay:0,isRTL:!1,haabMonths:[\"Pop\",\"Uo\",\"Zip\",\"Zotz\",\"Tzec\",\"Xul\",\"Yaxkin\",\"Mol\",\"Chen\",\"Yax\",\"Zac\",\"Ceh\",\"Mac\",\"Kankin\",\"Muan\",\"Pax\",\"Kayab\",\"Cumku\",\"Uayeb\"],tzolkinMonths:[\"Imix\",\"Ik\",\"Akbal\",\"Kan\",\"Chicchan\",\"Cimi\",\"Manik\",\"Lamat\",\"Muluc\",\"Oc\",\"Chuen\",\"Eb\",\"Ben\",\"Ix\",\"Men\",\"Cib\",\"Caban\",\"Etznab\",\"Cauac\",\"Ahau\"]}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},formatYear:function(t){t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year();var e=Math.floor(t/400);return t%=400,t+=t<0?400:0,e+\".\"+Math.floor(t/20)+\".\"+t%20},forYear:function(t){if((t=t.split(\".\")).length<3)throw\"Invalid Mayan year\";for(var e=0,r=0;r<t.length;r++){var n=parseInt(t[r],10);if(Math.abs(n)>19||r>0&&n<0)throw\"Invalid Mayan year\";e=20*e+n}return e},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),18},weekOfYear:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),0},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),360},daysInMonth:function(t,e){return this._validate(t,e,this.minDay,n.local.invalidMonth),20},daysInWeek:function(){return 5},dayOfWeek:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate).day()},weekDay:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),!0},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate).toJD(),a=this._toHaab(i),o=this._toTzolkin(i);return{haabMonthName:this.local.haabMonths[a[0]-1],haabMonth:a[0],haabDay:a[1],tzolkinDayName:this.local.tzolkinMonths[o[0]-1],tzolkinDay:o[0],tzolkinTrecena:o[1]}},_toHaab:function(t){var e=o((t-=this.jdEpoch)+8+340,365);return[Math.floor(e/20)+1,o(e,20)]},_toTzolkin:function(t){return[s((t-=this.jdEpoch)+20,20),s(t+4,13)]},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return i.day()+20*i.month()+360*i.year()+this.jdEpoch},fromJD:function(t){t=Math.floor(t)+.5-this.jdEpoch;var e=Math.floor(t/360);t%=360,t+=t<0?360:0;var r=Math.floor(t/20),n=t%20;return this.newDate(e,r,n)}}),n.calendars.mayan=a},{\"../main\":571,\"object-assign\":454}],565:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar;var o=n.instance(\"gregorian\");i(a.prototype,{name:\"Nanakshahi\",jdEpoch:2257673.5,daysPerMonth:[31,31,31,31,31,30,30,30,30,30,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Nanakshahi\",epochs:[\"BN\",\"AN\"],monthNames:[\"Chet\",\"Vaisakh\",\"Jeth\",\"Harh\",\"Sawan\",\"Bhadon\",\"Assu\",\"Katak\",\"Maghar\",\"Poh\",\"Magh\",\"Phagun\"],monthNamesShort:[\"Che\",\"Vai\",\"Jet\",\"Har\",\"Saw\",\"Bha\",\"Ass\",\"Kat\",\"Mgr\",\"Poh\",\"Mgh\",\"Pha\"],dayNames:[\"Somvaar\",\"Mangalvar\",\"Budhvaar\",\"Veervaar\",\"Shukarvaar\",\"Sanicharvaar\",\"Etvaar\"],dayNamesShort:[\"Som\",\"Mangal\",\"Budh\",\"Veer\",\"Shukar\",\"Sanichar\",\"Et\"],dayNamesMin:[\"So\",\"Ma\",\"Bu\",\"Ve\",\"Sh\",\"Sa\",\"Et\"],digits:null,dateFormat:\"dd-mm-yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear);return o.leapYear(e.year()+(e.year()<1?1:0)+1469)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(1-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidMonth);(t=i.year())<0&&t++;for(var a=i.day(),s=1;s<i.month();s++)a+=this.daysPerMonth[s-1];return a+o.toJD(t+1468,3,13)},fromJD:function(t){t=Math.floor(t+.5);for(var e=Math.floor((t-(this.jdEpoch-1))/366);t>=this.toJD(e+1,1,1);)e++;for(var r=t-Math.floor(this.toJD(e,1,1)+.5)+1,n=1;r>this.daysInMonth(e,n);)r-=this.daysInMonth(e,n),n++;return this.newDate(e,n,r)}}),n.calendars.nanakshahi=a},{\"../main\":571,\"object-assign\":454}],566:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Nepali\",jdEpoch:1700709.5,daysPerMonth:[31,31,32,32,31,30,30,29,30,29,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,daysPerYear:365,regionalOptions:{\"\":{name:\"Nepali\",epochs:[\"BBS\",\"ABS\"],monthNames:[\"Baisakh\",\"Jestha\",\"Ashadh\",\"Shrawan\",\"Bhadra\",\"Ashwin\",\"Kartik\",\"Mangsir\",\"Paush\",\"Mangh\",\"Falgun\",\"Chaitra\"],monthNamesShort:[\"Bai\",\"Je\",\"As\",\"Shra\",\"Bha\",\"Ash\",\"Kar\",\"Mang\",\"Pau\",\"Ma\",\"Fal\",\"Chai\"],dayNames:[\"Aaitabaar\",\"Sombaar\",\"Manglbaar\",\"Budhabaar\",\"Bihibaar\",\"Shukrabaar\",\"Shanibaar\"],dayNamesShort:[\"Aaita\",\"Som\",\"Mangl\",\"Budha\",\"Bihi\",\"Shukra\",\"Shani\"],dayNamesMin:[\"Aai\",\"So\",\"Man\",\"Bu\",\"Bi\",\"Shu\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:1,isRTL:!1}},leapYear:function(t){return this.daysInYear(t)!==this.daysPerYear},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){if(t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t])return this.daysPerYear;for(var e=0,r=this.minMonth;r<=12;r++)e+=this.NEPALI_CALENDAR_DATA[t][r];return e},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t]?this.daysPerMonth[e-1]:this.NEPALI_CALENDAR_DATA[t][e]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=n.instance(),o=0,s=e,l=t;this._createMissingCalendarData(t);var c=t-(s>9||9===s&&r>=this.NEPALI_CALENDAR_DATA[l][0]?56:57);for(9!==e&&(o=r,s--);9!==s;)s<=0&&(s=12,l--),o+=this.NEPALI_CALENDAR_DATA[l][s],s--;return 9===e?(o+=r-this.NEPALI_CALENDAR_DATA[l][0])<0&&(o+=a.daysInYear(c)):o+=this.NEPALI_CALENDAR_DATA[l][9]-this.NEPALI_CALENDAR_DATA[l][0],a.newDate(c,1,1).add(o,\"d\").toJD()},fromJD:function(t){var e=n.instance().fromJD(t),r=e.year(),i=e.dayOfYear(),a=r+56;this._createMissingCalendarData(a);for(var o=9,s=this.NEPALI_CALENDAR_DATA[a][0],l=this.NEPALI_CALENDAR_DATA[a][o]-s+1;i>l;)++o>12&&(o=1,a++),l+=this.NEPALI_CALENDAR_DATA[a][o];var c=this.NEPALI_CALENDAR_DATA[a][o]-(l-i);return this.newDate(a,o,c)},_createMissingCalendarData:function(t){var e=this.daysPerMonth.slice(0);e.unshift(17);for(var r=t-1;r<t+2;r++)\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[r]&&(this.NEPALI_CALENDAR_DATA[r]=e)},NEPALI_CALENDAR_DATA:{1970:[18,31,31,32,31,31,31,30,29,30,29,30,30],1971:[18,31,31,32,31,32,30,30,29,30,29,30,30],1972:[17,31,32,31,32,31,30,30,30,29,29,30,30],1973:[19,30,32,31,32,31,30,30,30,29,30,29,31],1974:[19,31,31,32,30,31,31,30,29,30,29,30,30],1975:[18,31,31,32,32,30,31,30,29,30,29,30,30],1976:[17,31,32,31,32,31,30,30,30,29,29,30,31],1977:[18,31,32,31,32,31,31,29,30,29,30,29,31],1978:[18,31,31,32,31,31,31,30,29,30,29,30,30],1979:[18,31,31,32,32,31,30,30,29,30,29,30,30],1980:[17,31,32,31,32,31,30,30,30,29,29,30,31],1981:[18,31,31,31,32,31,31,29,30,30,29,30,30],1982:[18,31,31,32,31,31,31,30,29,30,29,30,30],1983:[18,31,31,32,32,31,30,30,29,30,29,30,30],1984:[17,31,32,31,32,31,30,30,30,29,29,30,31],1985:[18,31,31,31,32,31,31,29,30,30,29,30,30],1986:[18,31,31,32,31,31,31,30,29,30,29,30,30],1987:[18,31,32,31,32,31,30,30,29,30,29,30,30],1988:[17,31,32,31,32,31,30,30,30,29,29,30,31],1989:[18,31,31,31,32,31,31,30,29,30,29,30,30],1990:[18,31,31,32,31,31,31,30,29,30,29,30,30],1991:[18,31,32,31,32,31,30,30,29,30,29,30,30],1992:[17,31,32,31,32,31,30,30,30,29,30,29,31],1993:[18,31,31,31,32,31,31,30,29,30,29,30,30],1994:[18,31,31,32,31,31,31,30,29,30,29,30,30],1995:[17,31,32,31,32,31,30,30,30,29,29,30,30],1996:[17,31,32,31,32,31,30,30,30,29,30,29,31],1997:[18,31,31,32,31,31,31,30,29,30,29,30,30],1998:[18,31,31,32,31,31,31,30,29,30,29,30,30],1999:[17,31,32,31,32,31,30,30,30,29,29,30,31],2000:[17,30,32,31,32,31,30,30,30,29,30,29,31],2001:[18,31,31,32,31,31,31,30,29,30,29,30,30],2002:[18,31,31,32,32,31,30,30,29,30,29,30,30],2003:[17,31,32,31,32,31,30,30,30,29,29,30,31],2004:[17,30,32,31,32,31,30,30,30,29,30,29,31],2005:[18,31,31,32,31,31,31,30,29,30,29,30,30],2006:[18,31,31,32,32,31,30,30,29,30,29,30,30],2007:[17,31,32,31,32,31,30,30,30,29,29,30,31],2008:[17,31,31,31,32,31,31,29,30,30,29,29,31],2009:[18,31,31,32,31,31,31,30,29,30,29,30,30],2010:[18,31,31,32,32,31,30,30,29,30,29,30,30],2011:[17,31,32,31,32,31,30,30,30,29,29,30,31],2012:[17,31,31,31,32,31,31,29,30,30,29,30,30],2013:[18,31,31,32,31,31,31,30,29,30,29,30,30],2014:[18,31,31,32,32,31,30,30,29,30,29,30,30],2015:[17,31,32,31,32,31,30,30,30,29,29,30,31],2016:[17,31,31,31,32,31,31,29,30,30,29,30,30],2017:[18,31,31,32,31,31,31,30,29,30,29,30,30],2018:[18,31,32,31,32,31,30,30,29,30,29,30,30],2019:[17,31,32,31,32,31,30,30,30,29,30,29,31],2020:[17,31,31,31,32,31,31,30,29,30,29,30,30],2021:[18,31,31,32,31,31,31,30,29,30,29,30,30],2022:[17,31,32,31,32,31,30,30,30,29,29,30,30],2023:[17,31,32,31,32,31,30,30,30,29,30,29,31],2024:[17,31,31,31,32,31,31,30,29,30,29,30,30],2025:[18,31,31,32,31,31,31,30,29,30,29,30,30],2026:[17,31,32,31,32,31,30,30,30,29,29,30,31],2027:[17,30,32,31,32,31,30,30,30,29,30,29,31],2028:[17,31,31,32,31,31,31,30,29,30,29,30,30],2029:[18,31,31,32,31,32,30,30,29,30,29,30,30],2030:[17,31,32,31,32,31,30,30,30,30,30,30,31],2031:[17,31,32,31,32,31,31,31,31,31,31,31,31],2032:[17,32,32,32,32,32,32,32,32,32,32,32,32],2033:[18,31,31,32,32,31,30,30,29,30,29,30,30],2034:[17,31,32,31,32,31,30,30,30,29,29,30,31],2035:[17,30,32,31,32,31,31,29,30,30,29,29,31],2036:[17,31,31,32,31,31,31,30,29,30,29,30,30],2037:[18,31,31,32,32,31,30,30,29,30,29,30,30],2038:[17,31,32,31,32,31,30,30,30,29,29,30,31],2039:[17,31,31,31,32,31,31,29,30,30,29,30,30],2040:[17,31,31,32,31,31,31,30,29,30,29,30,30],2041:[18,31,31,32,32,31,30,30,29,30,29,30,30],2042:[17,31,32,31,32,31,30,30,30,29,29,30,31],2043:[17,31,31,31,32,31,31,29,30,30,29,30,30],2044:[17,31,31,32,31,31,31,30,29,30,29,30,30],2045:[18,31,32,31,32,31,30,30,29,30,29,30,30],2046:[17,31,32,31,32,31,30,30,30,29,29,30,31],2047:[17,31,31,31,32,31,31,30,29,30,29,30,30],2048:[17,31,31,32,31,31,31,30,29,30,29,30,30],2049:[17,31,32,31,32,31,30,30,30,29,29,30,30],2050:[17,31,32,31,32,31,30,30,30,29,30,29,31],2051:[17,31,31,31,32,31,31,30,29,30,29,30,30],2052:[17,31,31,32,31,31,31,30,29,30,29,30,30],2053:[17,31,32,31,32,31,30,30,30,29,29,30,30],2054:[17,31,32,31,32,31,30,30,30,29,30,29,31],2055:[17,31,31,32,31,31,31,30,29,30,30,29,30],2056:[17,31,31,32,31,32,30,30,29,30,29,30,30],2057:[17,31,32,31,32,31,30,30,30,29,29,30,31],2058:[17,30,32,31,32,31,30,30,30,29,30,29,31],2059:[17,31,31,32,31,31,31,30,29,30,29,30,30],2060:[17,31,31,32,32,31,30,30,29,30,29,30,30],2061:[17,31,32,31,32,31,30,30,30,29,29,30,31],2062:[17,30,32,31,32,31,31,29,30,29,30,29,31],2063:[17,31,31,32,31,31,31,30,29,30,29,30,30],2064:[17,31,31,32,32,31,30,30,29,30,29,30,30],2065:[17,31,32,31,32,31,30,30,30,29,29,30,31],2066:[17,31,31,31,32,31,31,29,30,30,29,29,31],2067:[17,31,31,32,31,31,31,30,29,30,29,30,30],2068:[17,31,31,32,32,31,30,30,29,30,29,30,30],2069:[17,31,32,31,32,31,30,30,30,29,29,30,31],2070:[17,31,31,31,32,31,31,29,30,30,29,30,30],2071:[17,31,31,32,31,31,31,30,29,30,29,30,30],2072:[17,31,32,31,32,31,30,30,29,30,29,30,30],2073:[17,31,32,31,32,31,30,30,30,29,29,30,31],2074:[17,31,31,31,32,31,31,30,29,30,29,30,30],2075:[17,31,31,32,31,31,31,30,29,30,29,30,30],2076:[16,31,32,31,32,31,30,30,30,29,29,30,30],2077:[17,31,32,31,32,31,30,30,30,29,30,29,31],2078:[17,31,31,31,32,31,31,30,29,30,29,30,30],2079:[17,31,31,32,31,31,31,30,29,30,29,30,30],2080:[16,31,32,31,32,31,30,30,30,29,29,30,30],2081:[17,31,31,32,32,31,30,30,30,29,30,30,30],2082:[17,31,32,31,32,31,30,30,30,29,30,30,30],2083:[17,31,31,32,31,31,30,30,30,29,30,30,30],2084:[17,31,31,32,31,31,30,30,30,29,30,30,30],2085:[17,31,32,31,32,31,31,30,30,29,30,30,30],2086:[17,31,32,31,32,31,30,30,30,29,30,30,30],2087:[16,31,31,32,31,31,31,30,30,29,30,30,30],2088:[16,30,31,32,32,30,31,30,30,29,30,30,30],2089:[17,31,32,31,32,31,30,30,30,29,30,30,30],2090:[17,31,32,31,32,31,30,30,30,29,30,30,30],2091:[16,31,31,32,31,31,31,30,30,29,30,30,30],2092:[16,31,31,32,32,31,30,30,30,29,30,30,30],2093:[17,31,32,31,32,31,30,30,30,29,30,30,30],2094:[17,31,31,32,31,31,30,30,30,29,30,30,30],2095:[17,31,31,32,31,31,31,30,29,30,30,30,30],2096:[17,30,31,32,32,31,30,30,29,30,29,30,30],2097:[17,31,32,31,32,31,30,30,30,29,30,30,30],2098:[17,31,31,32,31,31,31,29,30,29,30,30,31],2099:[17,31,31,32,31,31,31,30,29,29,30,30,30],2100:[17,31,32,31,32,30,31,30,29,30,29,30,30]}}),n.calendars.nepali=a},{\"../main\":571,\"object-assign\":454}],567:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Persian\",jdEpoch:1948320.5,daysPerMonth:[31,31,31,31,31,31,30,30,30,30,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Persian\",epochs:[\"BP\",\"AP\"],monthNames:[\"Farvardin\",\"Ordibehesht\",\"Khordad\",\"Tir\",\"Mordad\",\"Shahrivar\",\"Mehr\",\"Aban\",\"Azar\",\"Day\",\"Bahman\",\"Esfand\"],monthNamesShort:[\"Far\",\"Ord\",\"Kho\",\"Tir\",\"Mor\",\"Sha\",\"Meh\",\"Aba\",\"Aza\",\"Day\",\"Bah\",\"Esf\"],dayNames:[\"Yekshambe\",\"Doshambe\",\"Seshambe\",\"Ch\\xe6harshambe\",\"Panjshambe\",\"Jom'e\",\"Shambe\"],dayNamesShort:[\"Yek\",\"Do\",\"Se\",\"Ch\\xe6\",\"Panj\",\"Jom\",\"Sha\"],dayNamesMin:[\"Ye\",\"Do\",\"Se\",\"Ch\",\"Pa\",\"Jo\",\"Sh\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 682*((e.year()-(e.year()>0?474:473))%2820+474+38)%2816<682},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-(n.dayOfWeek()+1)%7,\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t-(t>=0?474:473),s=474+o(a,2820);return r+(e<=7?31*(e-1):30*(e-1)+6)+Math.floor((682*s-110)/2816)+365*(s-1)+1029983*Math.floor(a/2820)+this.jdEpoch-1},fromJD:function(t){var e=(t=Math.floor(t)+.5)-this.toJD(475,1,1),r=Math.floor(e/1029983),n=o(e,1029983),i=2820;if(1029982!==n){var a=Math.floor(n/366),s=o(n,366);i=Math.floor((2134*a+2816*s+2815)/1028522)+a+1}var l=i+2820*r+474;l=l<=0?l-1:l;var c=t-this.toJD(l,1,1)+1,u=c<=186?Math.ceil(c/31):Math.ceil((c-6)/30),h=t-this.toJD(l,u,1)+1;return this.newDate(l,u,h)}}),n.calendars.persian=a,n.calendars.jalali=a},{\"../main\":571,\"object-assign\":454}],568:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Taiwan\",jdEpoch:2419402.5,yearsOffset:1911,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Taiwan\",epochs:[\"BROC\",\"ROC\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)},_g2tYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)}}),n.calendars.taiwan=o},{\"../main\":571,\"object-assign\":454}],569:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Thai\",jdEpoch:1523098.5,yearsOffset:543,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Thai\",epochs:[\"BBE\",\"BE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)},_g2tYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)}}),n.calendars.thai=o},{\"../main\":571,\"object-assign\":454}],570:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"UmmAlQura\",hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Umm al-Qura\",epochs:[\"BH\",\"AH\"],monthNames:[\"Al-Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' Al-Thani\",\"Jumada Al-Awwal\",\"Jumada Al-Thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-Ahad\",\"Yawm al-Ithnain\",\"Yawm al-Thal\\u0101th\\u0101\\u2019\",\"Yawm al-Arba\\u2018\\u0101\\u2019\",\"Yawm al-Kham\\u012bs\",\"Yawm al-Jum\\u2018a\",\"Yawm al-Sabt\"],dayNamesMin:[\"Ah\",\"Ith\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!0}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 355===this.daysInYear(e.year())},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){for(var e=0,r=1;r<=12;r++)e+=this.daysInMonth(t,r);return e},daysInMonth:function(t,e){for(var r=this._validate(t,e,this.minDay,n.local.invalidMonth).toJD()-24e5+.5,i=0,a=0;a<o.length;a++){if(o[a]>r)return o[i]-o[i-1];i++}return 30},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate),a=12*(i.year()-1)+i.month()-15292;return i.day()+o[a-1]-1+24e5-.5},fromJD:function(t){for(var e=t-24e5+.5,r=0,n=0;n<o.length&&!(o[n]>e);n++)r++;var i=r+15292,a=Math.floor((i-1)/12),s=a+1,l=i-12*a,c=e-o[r-1]+1;return this.newDate(s,l,c)},isValid:function(t,e,r){var i=n.baseCalendar.prototype.isValid.apply(this,arguments);return i&&(i=(t=null!=t.year?t.year:t)>=1276&&t<=1500),i},_validate:function(t,e,r,i){var a=n.baseCalendar.prototype._validate.apply(this,arguments);if(a.year<1276||a.year>1500)throw i.replace(/\\{0\\}/,this.local.name);return a}}),n.calendars.ummalqura=a;var o=[20,50,79,109,138,168,197,227,256,286,315,345,374,404,433,463,492,522,551,581,611,641,670,700,729,759,788,818,847,877,906,936,965,995,1024,1054,1083,1113,1142,1172,1201,1231,1260,1290,1320,1350,1379,1409,1438,1468,1497,1527,1556,1586,1615,1645,1674,1704,1733,1763,1792,1822,1851,1881,1910,1940,1969,1999,2028,2058,2087,2117,2146,2176,2205,2235,2264,2294,2323,2353,2383,2413,2442,2472,2501,2531,2560,2590,2619,2649,2678,2708,2737,2767,2796,2826,2855,2885,2914,2944,2973,3003,3032,3062,3091,3121,3150,3180,3209,3239,3268,3298,3327,3357,3386,3416,3446,3476,3505,3535,3564,3594,3623,3653,3682,3712,3741,3771,3800,3830,3859,3889,3918,3948,3977,4007,4036,4066,4095,4125,4155,4185,4214,4244,4273,4303,4332,4362,4391,4421,4450,4480,4509,4539,4568,4598,4627,4657,4686,4716,4745,4775,4804,4834,4863,4893,4922,4952,4981,5011,5040,5070,5099,5129,5158,5188,5218,5248,5277,5307,5336,5366,5395,5425,5454,5484,5513,5543,5572,5602,5631,5661,5690,5720,5749,5779,5808,5838,5867,5897,5926,5956,5985,6015,6044,6074,6103,6133,6162,6192,6221,6251,6281,6311,6340,6370,6399,6429,6458,6488,6517,6547,6576,6606,6635,6665,6694,6724,6753,6783,6812,6842,6871,6901,6930,6960,6989,7019,7048,7078,7107,7137,7166,7196,7225,7255,7284,7314,7344,7374,7403,7433,7462,7492,7521,7551,7580,7610,7639,7669,7698,7728,7757,7787,7816,7846,7875,7905,7934,7964,7993,8023,8053,8083,8112,8142,8171,8201,8230,8260,8289,8319,8348,8378,8407,8437,8466,8496,8525,8555,8584,8614,8643,8673,8702,8732,8761,8791,8821,8850,8880,8909,8938,8968,8997,9027,9056,9086,9115,9145,9175,9205,9234,9264,9293,9322,9352,9381,9410,9440,9470,9499,9529,9559,9589,9618,9648,9677,9706,9736,9765,9794,9824,9853,9883,9913,9943,9972,10002,10032,10061,10090,10120,10149,10178,10208,10237,10267,10297,10326,10356,10386,10415,10445,10474,10504,10533,10562,10592,10621,10651,10680,10710,10740,10770,10799,10829,10858,10888,10917,10947,10976,11005,11035,11064,11094,11124,11153,11183,11213,11242,11272,11301,11331,11360,11389,11419,11448,11478,11507,11537,11567,11596,11626,11655,11685,11715,11744,11774,11803,11832,11862,11891,11921,11950,11980,12010,12039,12069,12099,12128,12158,12187,12216,12246,12275,12304,12334,12364,12393,12423,12453,12483,12512,12542,12571,12600,12630,12659,12688,12718,12747,12777,12807,12837,12866,12896,12926,12955,12984,13014,13043,13072,13102,13131,13161,13191,13220,13250,13280,13310,13339,13368,13398,13427,13456,13486,13515,13545,13574,13604,13634,13664,13693,13723,13752,13782,13811,13840,13870,13899,13929,13958,13988,14018,14047,14077,14107,14136,14166,14195,14224,14254,14283,14313,14342,14372,14401,14431,14461,14490,14520,14550,14579,14609,14638,14667,14697,14726,14756,14785,14815,14844,14874,14904,14933,14963,14993,15021,15051,15081,15110,15140,15169,15199,15228,15258,15287,15317,15347,15377,15406,15436,15465,15494,15524,15553,15582,15612,15641,15671,15701,15731,15760,15790,15820,15849,15878,15908,15937,15966,15996,16025,16055,16085,16114,16144,16174,16204,16233,16262,16292,16321,16350,16380,16409,16439,16468,16498,16528,16558,16587,16617,16646,16676,16705,16734,16764,16793,16823,16852,16882,16912,16941,16971,17001,17030,17060,17089,17118,17148,17177,17207,17236,17266,17295,17325,17355,17384,17414,17444,17473,17502,17532,17561,17591,17620,17650,17679,17709,17738,17768,17798,17827,17857,17886,17916,17945,17975,18004,18034,18063,18093,18122,18152,18181,18211,18241,18270,18300,18330,18359,18388,18418,18447,18476,18506,18535,18565,18595,18625,18654,18684,18714,18743,18772,18802,18831,18860,18890,18919,18949,18979,19008,19038,19068,19098,19127,19156,19186,19215,19244,19274,19303,19333,19362,19392,19422,19452,19481,19511,19540,19570,19599,19628,19658,19687,19717,19746,19776,19806,19836,19865,19895,19924,19954,19983,20012,20042,20071,20101,20130,20160,20190,20219,20249,20279,20308,20338,20367,20396,20426,20455,20485,20514,20544,20573,20603,20633,20662,20692,20721,20751,20780,20810,20839,20869,20898,20928,20957,20987,21016,21046,21076,21105,21135,21164,21194,21223,21253,21282,21312,21341,21371,21400,21430,21459,21489,21519,21548,21578,21607,21637,21666,21696,21725,21754,21784,21813,21843,21873,21902,21932,21962,21991,22021,22050,22080,22109,22138,22168,22197,22227,22256,22286,22316,22346,22375,22405,22434,22464,22493,22522,22552,22581,22611,22640,22670,22700,22730,22759,22789,22818,22848,22877,22906,22936,22965,22994,23024,23054,23083,23113,23143,23173,23202,23232,23261,23290,23320,23349,23379,23408,23438,23467,23497,23527,23556,23586,23616,23645,23674,23704,23733,23763,23792,23822,23851,23881,23910,23940,23970,23999,24029,24058,24088,24117,24147,24176,24206,24235,24265,24294,24324,24353,24383,24413,24442,24472,24501,24531,24560,24590,24619,24648,24678,24707,24737,24767,24796,24826,24856,24885,24915,24944,24974,25003,25032,25062,25091,25121,25150,25180,25210,25240,25269,25299,25328,25358,25387,25416,25446,25475,25505,25534,25564,25594,25624,25653,25683,25712,25742,25771,25800,25830,25859,25888,25918,25948,25977,26007,26037,26067,26096,26126,26155,26184,26214,26243,26272,26302,26332,26361,26391,26421,26451,26480,26510,26539,26568,26598,26627,26656,26686,26715,26745,26775,26805,26834,26864,26893,26923,26952,26982,27011,27041,27070,27099,27129,27159,27188,27218,27248,27277,27307,27336,27366,27395,27425,27454,27484,27513,27542,27572,27602,27631,27661,27691,27720,27750,27779,27809,27838,27868,27897,27926,27956,27985,28015,28045,28074,28104,28134,28163,28193,28222,28252,28281,28310,28340,28369,28399,28428,28458,28488,28517,28547,28577,28607,28636,28665,28695,28724,28754,28783,28813,28843,28872,28901,28931,28960,28990,29019,29049,29078,29108,29137,29167,29196,29226,29255,29285,29315,29345,29375,29404,29434,29463,29492,29522,29551,29580,29610,29640,29669,29699,29729,29759,29788,29818,29847,29876,29906,29935,29964,29994,30023,30053,30082,30112,30141,30171,30200,30230,30259,30289,30318,30348,30378,30408,30437,30467,30496,30526,30555,30585,30614,30644,30673,30703,30732,30762,30791,30821,30850,30880,30909,30939,30968,30998,31027,31057,31086,31116,31145,31175,31204,31234,31263,31293,31322,31352,31381,31411,31441,31471,31500,31530,31559,31589,31618,31648,31676,31706,31736,31766,31795,31825,31854,31884,31913,31943,31972,32002,32031,32061,32090,32120,32150,32180,32209,32239,32268,32298,32327,32357,32386,32416,32445,32475,32504,32534,32563,32593,32622,32652,32681,32711,32740,32770,32799,32829,32858,32888,32917,32947,32976,33006,33035,33065,33094,33124,33153,33183,33213,33243,33272,33302,33331,33361,33390,33420,33450,33479,33509,33539,33568,33598,33627,33657,33686,33716,33745,33775,33804,33834,33863,33893,33922,33952,33981,34011,34040,34069,34099,34128,34158,34187,34217,34247,34277,34306,34336,34365,34395,34424,34454,34483,34512,34542,34571,34601,34631,34660,34690,34719,34749,34778,34808,34837,34867,34896,34926,34955,34985,35015,35044,35074,35103,35133,35162,35192,35222,35251,35280,35310,35340,35370,35399,35429,35458,35488,35517,35547,35576,35605,35635,35665,35694,35723,35753,35782,35811,35841,35871,35901,35930,35960,35989,36019,36048,36078,36107,36136,36166,36195,36225,36254,36284,36314,36343,36373,36403,36433,36462,36492,36521,36551,36580,36610,36639,36669,36698,36728,36757,36786,36816,36845,36875,36904,36934,36963,36993,37022,37052,37081,37111,37141,37170,37200,37229,37259,37288,37318,37347,37377,37406,37436,37465,37495,37524,37554,37584,37613,37643,37672,37701,37731,37760,37790,37819,37849,37878,37908,37938,37967,37997,38027,38056,38085,38115,38144,38174,38203,38233,38262,38292,38322,38351,38381,38410,38440,38469,38499,38528,38558,38587,38617,38646,38676,38705,38735,38764,38794,38823,38853,38882,38912,38941,38971,39001,39030,39059,39089,39118,39148,39178,39208,39237,39267,39297,39326,39355,39385,39414,39444,39473,39503,39532,39562,39592,39621,39650,39680,39709,39739,39768,39798,39827,39857,39886,39916,39946,39975,40005,40035,40064,40094,40123,40153,40182,40212,40241,40271,40300,40330,40359,40389,40418,40448,40477,40507,40536,40566,40595,40625,40655,40685,40714,40744,40773,40803,40832,40862,40892,40921,40951,40980,41009,41039,41068,41098,41127,41157,41186,41216,41245,41275,41304,41334,41364,41393,41422,41452,41481,41511,41540,41570,41599,41629,41658,41688,41718,41748,41777,41807,41836,41865,41894,41924,41953,41983,42012,42042,42072,42102,42131,42161,42190,42220,42249,42279,42308,42337,42367,42397,42426,42456,42485,42515,42545,42574,42604,42633,42662,42692,42721,42751,42780,42810,42839,42869,42899,42929,42958,42988,43017,43046,43076,43105,43135,43164,43194,43223,43253,43283,43312,43342,43371,43401,43430,43460,43489,43519,43548,43578,43607,43637,43666,43696,43726,43755,43785,43814,43844,43873,43903,43932,43962,43991,44021,44050,44080,44109,44139,44169,44198,44228,44258,44287,44317,44346,44375,44405,44434,44464,44493,44523,44553,44582,44612,44641,44671,44700,44730,44759,44788,44818,44847,44877,44906,44936,44966,44996,45025,45055,45084,45114,45143,45172,45202,45231,45261,45290,45320,45350,45380,45409,45439,45468,45498,45527,45556,45586,45615,45644,45674,45704,45733,45763,45793,45823,45852,45882,45911,45940,45970,45999,46028,46058,46088,46117,46147,46177,46206,46236,46265,46295,46324,46354,46383,46413,46442,46472,46501,46531,46560,46590,46620,46649,46679,46708,46738,46767,46797,46826,46856,46885,46915,46944,46974,47003,47033,47063,47092,47122,47151,47181,47210,47240,47269,47298,47328,47357,47387,47417,47446,47476,47506,47535,47565,47594,47624,47653,47682,47712,47741,47771,47800,47830,47860,47890,47919,47949,47978,48008,48037,48066,48096,48125,48155,48184,48214,48244,48273,48303,48333,48362,48392,48421,48450,48480,48509,48538,48568,48598,48627,48657,48687,48717,48746,48776,48805,48834,48864,48893,48922,48952,48982,49011,49041,49071,49100,49130,49160,49189,49218,49248,49277,49306,49336,49365,49395,49425,49455,49484,49514,49543,49573,49602,49632,49661,49690,49720,49749,49779,49809,49838,49868,49898,49927,49957,49986,50016,50045,50075,50104,50133,50163,50192,50222,50252,50281,50311,50340,50370,50400,50429,50459,50488,50518,50547,50576,50606,50635,50665,50694,50724,50754,50784,50813,50843,50872,50902,50931,50960,50990,51019,51049,51078,51108,51138,51167,51197,51227,51256,51286,51315,51345,51374,51403,51433,51462,51492,51522,51552,51582,51611,51641,51670,51699,51729,51758,51787,51816,51846,51876,51906,51936,51965,51995,52025,52054,52083,52113,52142,52171,52200,52230,52260,52290,52319,52349,52379,52408,52438,52467,52497,52526,52555,52585,52614,52644,52673,52703,52733,52762,52792,52822,52851,52881,52910,52939,52969,52998,53028,53057,53087,53116,53146,53176,53205,53235,53264,53294,53324,53353,53383,53412,53441,53471,53500,53530,53559,53589,53619,53648,53678,53708,53737,53767,53796,53825,53855,53884,53913,53943,53973,54003,54032,54062,54092,54121,54151,54180,54209,54239,54268,54297,54327,54357,54387,54416,54446,54476,54505,54535,54564,54593,54623,54652,54681,54711,54741,54770,54800,54830,54859,54889,54919,54948,54977,55007,55036,55066,55095,55125,55154,55184,55213,55243,55273,55302,55332,55361,55391,55420,55450,55479,55508,55538,55567,55597,55627,55657,55686,55716,55745,55775,55804,55834,55863,55892,55922,55951,55981,56011,56040,56070,56100,56129,56159,56188,56218,56247,56276,56306,56335,56365,56394,56424,56454,56483,56513,56543,56572,56601,56631,56660,56690,56719,56749,56778,56808,56837,56867,56897,56926,56956,56985,57015,57044,57074,57103,57133,57162,57192,57221,57251,57280,57310,57340,57369,57399,57429,57458,57487,57517,57546,57576,57605,57634,57664,57694,57723,57753,57783,57813,57842,57871,57901,57930,57959,57989,58018,58048,58077,58107,58137,58167,58196,58226,58255,58285,58314,58343,58373,58402,58432,58461,58491,58521,58551,58580,58610,58639,58669,58698,58727,58757,58786,58816,58845,58875,58905,58934,58964,58994,59023,59053,59082,59111,59141,59170,59200,59229,59259,59288,59318,59348,59377,59407,59436,59466,59495,59525,59554,59584,59613,59643,59672,59702,59731,59761,59791,59820,59850,59879,59909,59939,59968,59997,60027,60056,60086,60115,60145,60174,60204,60234,60264,60293,60323,60352,60381,60411,60440,60469,60499,60528,60558,60588,60618,60648,60677,60707,60736,60765,60795,60824,60853,60883,60912,60942,60972,61002,61031,61061,61090,61120,61149,61179,61208,61237,61267,61296,61326,61356,61385,61415,61445,61474,61504,61533,61563,61592,61621,61651,61680,61710,61739,61769,61799,61828,61858,61888,61917,61947,61976,62006,62035,62064,62094,62123,62153,62182,62212,62242,62271,62301,62331,62360,62390,62419,62448,62478,62507,62537,62566,62596,62625,62655,62685,62715,62744,62774,62803,62832,62862,62891,62921,62950,62980,63009,63039,63069,63099,63128,63157,63187,63216,63246,63275,63305,63334,63363,63393,63423,63453,63482,63512,63541,63571,63600,63630,63659,63689,63718,63747,63777,63807,63836,63866,63895,63925,63955,63984,64014,64043,64073,64102,64131,64161,64190,64220,64249,64279,64309,64339,64368,64398,64427,64457,64486,64515,64545,64574,64603,64633,64663,64692,64722,64752,64782,64811,64841,64870,64899,64929,64958,64987,65017,65047,65076,65106,65136,65166,65195,65225,65254,65283,65313,65342,65371,65401,65431,65460,65490,65520,65549,65579,65608,65638,65667,65697,65726,65755,65785,65815,65844,65874,65903,65933,65963,65992,66022,66051,66081,66110,66140,66169,66199,66228,66258,66287,66317,66346,66376,66405,66435,66465,66494,66524,66553,66583,66612,66641,66671,66700,66730,66760,66789,66819,66849,66878,66908,66937,66967,66996,67025,67055,67084,67114,67143,67173,67203,67233,67262,67292,67321,67351,67380,67409,67439,67468,67497,67527,67557,67587,67617,67646,67676,67705,67735,67764,67793,67823,67852,67882,67911,67941,67971,68e3,68030,68060,68089,68119,68148,68177,68207,68236,68266,68295,68325,68354,68384,68414,68443,68473,68502,68532,68561,68591,68620,68650,68679,68708,68738,68768,68797,68827,68857,68886,68916,68946,68975,69004,69034,69063,69092,69122,69152,69181,69211,69240,69270,69300,69330,69359,69388,69418,69447,69476,69506,69535,69565,69595,69624,69654,69684,69713,69743,69772,69802,69831,69861,69890,69919,69949,69978,70008,70038,70067,70097,70126,70156,70186,70215,70245,70274,70303,70333,70362,70392,70421,70451,70481,70510,70540,70570,70599,70629,70658,70687,70717,70746,70776,70805,70835,70864,70894,70924,70954,70983,71013,71042,71071,71101,71130,71159,71189,71218,71248,71278,71308,71337,71367,71397,71426,71455,71485,71514,71543,71573,71602,71632,71662,71691,71721,71751,71781,71810,71839,71869,71898,71927,71957,71986,72016,72046,72075,72105,72135,72164,72194,72223,72253,72282,72311,72341,72370,72400,72429,72459,72489,72518,72548,72577,72607,72637,72666,72695,72725,72754,72784,72813,72843,72872,72902,72931,72961,72991,73020,73050,73080,73109,73139,73168,73197,73227,73256,73286,73315,73345,73375,73404,73434,73464,73493,73523,73552,73581,73611,73640,73669,73699,73729,73758,73788,73818,73848,73877,73907,73936,73965,73995,74024,74053,74083,74113,74142,74172,74202,74231,74261,74291,74320,74349,74379,74408,74437,74467,74497,74526,74556,74586,74615,74645,74675,74704,74733,74763,74792,74822,74851,74881,74910,74940,74969,74999,75029,75058,75088,75117,75147,75176,75206,75235,75264,75294,75323,75353,75383,75412,75442,75472,75501,75531,75560,75590,75619,75648,75678,75707,75737,75766,75796,75826,75856,75885,75915,75944,75974,76003,76032,76062,76091,76121,76150,76180,76210,76239,76269,76299,76328,76358,76387,76416,76446,76475,76505,76534,76564,76593,76623,76653,76682,76712,76741,76771,76801,76830,76859,76889,76918,76948,76977,77007,77036,77066,77096,77125,77155,77185,77214,77243,77273,77302,77332,77361,77390,77420,77450,77479,77509,77539,77569,77598,77627,77657,77686,77715,77745,77774,77804,77833,77863,77893,77923,77952,77982,78011,78041,78070,78099,78129,78158,78188,78217,78247,78277,78307,78336,78366,78395,78425,78454,78483,78513,78542,78572,78601,78631,78661,78690,78720,78750,78779,78808,78838,78867,78897,78926,78956,78985,79015,79044,79074,79104,79133,79163,79192,79222,79251,79281,79310,79340,79369,79399,79428,79458,79487,79517,79546,79576,79606,79635,79665,79695,79724,79753,79783,79812,79841,79871,79900,79930,79960,79990]},{\"../main\":571,\"object-assign\":454}],571:[function(t,e,r){var n=t(\"object-assign\");function i(){this.regionalOptions=[],this.regionalOptions[\"\"]={invalidCalendar:\"Calendar {0} not found\",invalidDate:\"Invalid {0} date\",invalidMonth:\"Invalid {0} month\",invalidYear:\"Invalid {0} year\",differentCalendars:\"Cannot mix {0} and {1} dates\"},this.local=this.regionalOptions[\"\"],this.calendars={},this._localCals={}}function a(t,e,r,n){if(this._calendar=t,this._year=e,this._month=r,this._day=n,0===this._calendar._validateLevel&&!this._calendar.isValid(this._year,this._month,this._day))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name)}function o(t,e){return\"000000\".substring(0,e-(t=\"\"+t).length)+t}function s(){this.shortYearCutoff=\"+10\"}function l(t){this.local=this.regionalOptions[t]||this.regionalOptions[\"\"]}n(i.prototype,{instance:function(t,e){t=(t||\"gregorian\").toLowerCase(),e=e||\"\";var r=this._localCals[t+\"-\"+e];if(!r&&this.calendars[t]&&(r=new this.calendars[t](e),this._localCals[t+\"-\"+e]=r),!r)throw(this.local.invalidCalendar||this.regionalOptions[\"\"].invalidCalendar).replace(/\\{0\\}/,t);return r},newDate:function(t,e,r,n,i){return(n=(null!=t&&t.year?t.calendar():\"string\"==typeof n?this.instance(n,i):n)||this.instance()).newDate(t,e,r)},substituteDigits:function(t){return function(e){return(e+\"\").replace(/[0-9]/g,function(e){return t[e]})}},substituteChineseDigits:function(t,e){return function(r){for(var n=\"\",i=0;r>0;){var a=r%10;n=(0===a?\"\":t[a]+e[i])+n,i++,r=Math.floor(r/10)}return 0===n.indexOf(t[1]+e[1])&&(n=n.substr(1)),n||t[0]}}}),n(a.prototype,{newDate:function(t,e,r){return this._calendar.newDate(null==t?this:t,e,r)},year:function(t){return 0===arguments.length?this._year:this.set(t,\"y\")},month:function(t){return 0===arguments.length?this._month:this.set(t,\"m\")},day:function(t){return 0===arguments.length?this._day:this.set(t,\"d\")},date:function(t,e,r){if(!this._calendar.isValid(t,e,r))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name);return this._year=t,this._month=e,this._day=r,this},leapYear:function(){return this._calendar.leapYear(this)},epoch:function(){return this._calendar.epoch(this)},formatYear:function(){return this._calendar.formatYear(this)},monthOfYear:function(){return this._calendar.monthOfYear(this)},weekOfYear:function(){return this._calendar.weekOfYear(this)},daysInYear:function(){return this._calendar.daysInYear(this)},dayOfYear:function(){return this._calendar.dayOfYear(this)},daysInMonth:function(){return this._calendar.daysInMonth(this)},dayOfWeek:function(){return this._calendar.dayOfWeek(this)},weekDay:function(){return this._calendar.weekDay(this)},extraInfo:function(){return this._calendar.extraInfo(this)},add:function(t,e){return this._calendar.add(this,t,e)},set:function(t,e){return this._calendar.set(this,t,e)},compareTo:function(t){if(this._calendar.name!==t._calendar.name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this._calendar.local.name).replace(/\\{1\\}/,t._calendar.local.name);var e=this._year!==t._year?this._year-t._year:this._month!==t._month?this.monthOfYear()-t.monthOfYear():this._day-t._day;return 0===e?0:e<0?-1:1},calendar:function(){return this._calendar},toJD:function(){return this._calendar.toJD(this)},fromJD:function(t){return this._calendar.fromJD(t)},toJSDate:function(){return this._calendar.toJSDate(this)},fromJSDate:function(t){return this._calendar.fromJSDate(t)},toString:function(){return(this.year()<0?\"-\":\"\")+o(Math.abs(this.year()),4)+\"-\"+o(this.month(),2)+\"-\"+o(this.day(),2)}}),n(s.prototype,{_validateLevel:0,newDate:function(t,e,r){return null==t?this.today():(t.year&&(this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),r=t.day(),e=t.month(),t=t.year()),new a(this,t,e,r))},today:function(){return this.fromJSDate(new Date)},epoch:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear).year()<0?this.local.epochs[0]:this.local.epochs[1]},formatYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(e.year()<0?\"-\":\"\")+o(Math.abs(e.year()),4)},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear),12},monthOfYear:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return(r.month()+this.monthsInYear(r)-this.firstMonth)%this.monthsInYear(r)+this.minMonth},fromMonthOfYear:function(t,e){var r=(e+this.firstMonth-2*this.minMonth)%this.monthsInYear(t)+this.minMonth;return this._validate(t,r,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth),r},daysInYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return this.leapYear(e)?366:365},dayOfYear:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return n.toJD()-this.newDate(n.year(),this.fromMonthOfYear(n.year(),this.minMonth),this.minDay).toJD()+1},daysInWeek:function(){return 7},dayOfWeek:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return(Math.floor(this.toJD(n))+2)%this.daysInWeek()},extraInfo:function(t,e,r){return this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),{}},add:function(t,e,r){return this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),this._correctAdd(t,this._add(t,e,r),e,r)},_add:function(t,e,r){if(this._validateLevel++,\"d\"===r||\"w\"===r){var n=t.toJD()+e*(\"w\"===r?this.daysInWeek():1),i=t.calendar().fromJD(n);return this._validateLevel--,[i.year(),i.month(),i.day()]}try{var a=t.year()+(\"y\"===r?e:0),o=t.monthOfYear()+(\"m\"===r?e:0);i=t.day();\"y\"===r?(t.month()!==this.fromMonthOfYear(a,o)&&(o=this.newDate(a,t.month(),this.minDay).monthOfYear()),o=Math.min(o,this.monthsInYear(a)),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o)))):\"m\"===r&&(!function(t){for(;o<t.minMonth;)a--,o+=t.monthsInYear(a);for(var e=t.monthsInYear(a);o>e-1+t.minMonth;)a++,o-=e,e=t.monthsInYear(a)}(this),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o))));var s=[a,this.fromMonthOfYear(a,o),i];return this._validateLevel--,s}catch(t){throw this._validateLevel--,t}},_correctAdd:function(t,e,r,n){if(!(this.hasYearZero||\"y\"!==n&&\"m\"!==n||0!==e[0]&&t.year()>0==e[0]>0)){var i={y:[1,1,\"y\"],m:[1,this.monthsInYear(-1),\"m\"],w:[this.daysInWeek(),this.daysInYear(-1),\"d\"],d:[1,this.daysInYear(-1),\"d\"]}[n],a=r<0?-1:1;e=this._add(t,r*i[0]+a*i[1],i[2])}return t.date(e[0],e[1],e[2])},set:function(t,e,r){this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);var n=\"y\"===r?e:t.year(),i=\"m\"===r?e:t.month(),a=\"d\"===r?e:t.day();return\"y\"!==r&&\"m\"!==r||(a=Math.min(a,this.daysInMonth(n,i))),t.date(n,i,a)},isValid:function(t,e,r){this._validateLevel++;var n=this.hasYearZero||0!==t;if(n){var i=this.newDate(t,e,this.minDay);n=e>=this.minMonth&&e-this.minMonth<this.monthsInYear(i)&&r>=this.minDay&&r-this.minDay<this.daysInMonth(i)}return this._validateLevel--,n},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return c.instance().fromJD(this.toJD(n)).toJSDate()},fromJSDate:function(t){return this.fromJD(c.instance().fromJSDate(t).toJD())},_validate:function(t,e,r,n){if(t.year){if(0===this._validateLevel&&this.name!==t.calendar().name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this.local.name).replace(/\\{1\\}/,t.calendar().local.name);return t}try{if(this._validateLevel++,1===this._validateLevel&&!this.isValid(t,e,r))throw n.replace(/\\{0\\}/,this.local.name);var i=this.newDate(t,e,r);return this._validateLevel--,i}catch(t){throw this._validateLevel--,t}}}),l.prototype=new s,n(l.prototype,{name:\"Gregorian\",jdEpoch:1721425.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Gregorian\",epochs:[\"BCE\",\"CE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==0&&(t%100!=0||t%400==0)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);t=n.year(),e=n.month(),r=n.day(),t<0&&t++,e<3&&(e+=12,t--);var i=Math.floor(t/100),a=2-i+Math.floor(i/4);return Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r+a-1524.5},fromJD:function(t){var e=Math.floor(t+.5),r=Math.floor((e-1867216.25)/36524.25),n=(r=e+1+r-Math.floor(r/4))+1524,i=Math.floor((n-122.1)/365.25),a=Math.floor(365.25*i),o=Math.floor((n-a)/30.6001),s=n-a-Math.floor(30.6001*o),l=o-(o>13.5?13:1),c=i-(l>2.5?4716:4715);return c<=0&&c--,this.newDate(c,l,s)},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),i=new Date(n.year(),n.month()-1,n.day());return i.setHours(0),i.setMinutes(0),i.setSeconds(0),i.setMilliseconds(0),i.setHours(i.getHours()>12?i.getHours()+2:0),i},fromJSDate:function(t){return this.newDate(t.getFullYear(),t.getMonth()+1,t.getDate())}});var c=e.exports=new i;c.cdate=a,c.baseCalendar=s,c.calendars.gregorian=l},{\"object-assign\":454}],572:[function(t,e,r){var n=t(\"object-assign\"),i=t(\"./main\");n(i.regionalOptions[\"\"],{invalidArguments:\"Invalid arguments\",invalidFormat:\"Cannot format a date from another calendar\",missingNumberAt:\"Missing number at position {0}\",unknownNameAt:\"Unknown name at position {0}\",unexpectedLiteralAt:\"Unexpected literal at position {0}\",unexpectedText:\"Additional text found at end\"}),i.local=i.regionalOptions[\"\"],n(i.cdate.prototype,{formatDate:function(t,e){return\"string\"!=typeof t&&(e=t,t=\"\"),this._calendar.formatDate(t||\"\",this,e)}}),n(i.baseCalendar.prototype,{UNIX_EPOCH:i.instance().newDate(1970,1,1).toJD(),SECS_PER_DAY:86400,TICKS_EPOCH:i.instance().jdEpoch,TICKS_PER_DAY:864e9,ATOM:\"yyyy-mm-dd\",COOKIE:\"D, dd M yyyy\",FULL:\"DD, MM d, yyyy\",ISO_8601:\"yyyy-mm-dd\",JULIAN:\"J\",RFC_822:\"D, d M yy\",RFC_850:\"DD, dd-M-yy\",RFC_1036:\"D, d M yy\",RFC_1123:\"D, d M yyyy\",RFC_2822:\"D, d M yyyy\",RSS:\"D, d M yy\",TICKS:\"!\",TIMESTAMP:\"@\",W3C:\"yyyy-mm-dd\",formatDate:function(t,e,r){if(\"string\"!=typeof t&&(r=e,e=t,t=\"\"),!e)return\"\";if(e.calendar()!==this)throw i.local.invalidFormat||i.regionalOptions[\"\"].invalidFormat;t=t||this.local.dateFormat;for(var n,a,o,s,l=(r=r||{}).dayNamesShort||this.local.dayNamesShort,c=r.dayNames||this.local.dayNames,u=r.monthNumbers||this.local.monthNumbers,h=r.monthNamesShort||this.local.monthNamesShort,f=r.monthNames||this.local.monthNames,p=(r.calculateWeek||this.local.calculateWeek,function(e,r){for(var n=1;w+n<t.length&&t.charAt(w+n)===e;)n++;return w+=n-1,Math.floor(n/(r||1))>1}),d=function(t,e,r,n){var i=\"\"+e;if(p(t,n))for(;i.length<r;)i=\"0\"+i;return i},g=this,v=function(t){return\"function\"==typeof u?u.call(g,t,p(\"m\")):x(d(\"m\",t.month(),2))},m=function(t,e){return e?\"function\"==typeof f?f.call(g,t):f[t.month()-g.minMonth]:\"function\"==typeof h?h.call(g,t):h[t.month()-g.minMonth]},y=this.local.digits,x=function(t){return r.localNumbers&&y?y(t):t},b=\"\",_=!1,w=0;w<t.length;w++)if(_)\"'\"!==t.charAt(w)||p(\"'\")?b+=t.charAt(w):_=!1;else switch(t.charAt(w)){case\"d\":b+=x(d(\"d\",e.day(),2));break;case\"D\":b+=(n=\"D\",a=e.dayOfWeek(),o=l,s=c,p(n)?s[a]:o[a]);break;case\"o\":b+=d(\"o\",e.dayOfYear(),3);break;case\"w\":b+=d(\"w\",e.weekOfYear(),2);break;case\"m\":b+=v(e);break;case\"M\":b+=m(e,p(\"M\"));break;case\"y\":b+=p(\"y\",2)?e.year():(e.year()%100<10?\"0\":\"\")+e.year()%100;break;case\"Y\":p(\"Y\",2),b+=e.formatYear();break;case\"J\":b+=e.toJD();break;case\"@\":b+=(e.toJD()-this.UNIX_EPOCH)*this.SECS_PER_DAY;break;case\"!\":b+=(e.toJD()-this.TICKS_EPOCH)*this.TICKS_PER_DAY;break;case\"'\":p(\"'\")?b+=\"'\":_=!0;break;default:b+=t.charAt(w)}return b},parseDate:function(t,e,r){if(null==e)throw i.local.invalidArguments||i.regionalOptions[\"\"].invalidArguments;if(\"\"===(e=\"object\"==typeof e?e.toString():e+\"\"))return null;t=t||this.local.dateFormat;var n=(r=r||{}).shortYearCutoff||this.shortYearCutoff;n=\"string\"!=typeof n?n:this.today().year()%100+parseInt(n,10);for(var a=r.dayNamesShort||this.local.dayNamesShort,o=r.dayNames||this.local.dayNames,s=r.parseMonth||this.local.parseMonth,l=r.monthNumbers||this.local.monthNumbers,c=r.monthNamesShort||this.local.monthNamesShort,u=r.monthNames||this.local.monthNames,h=-1,f=-1,p=-1,d=-1,g=-1,v=!1,m=!1,y=function(e,r){for(var n=1;M+n<t.length&&t.charAt(M+n)===e;)n++;return M+=n-1,Math.floor(n/(r||1))>1},x=function(t,r){var n=y(t,r),a=[2,3,n?4:2,n?4:2,10,11,20][\"oyYJ@!\".indexOf(t)+1],o=new RegExp(\"^-?\\\\d{1,\"+a+\"}\"),s=e.substring(A).match(o);if(!s)throw(i.local.missingNumberAt||i.regionalOptions[\"\"].missingNumberAt).replace(/\\{0\\}/,A);return A+=s[0].length,parseInt(s[0],10)},b=this,_=function(){if(\"function\"==typeof l){y(\"m\");var t=l.call(b,e.substring(A));return A+=t.length,t}return x(\"m\")},w=function(t,r,n,a){for(var o=y(t,a)?n:r,s=0;s<o.length;s++)if(e.substr(A,o[s].length).toLowerCase()===o[s].toLowerCase())return A+=o[s].length,s+b.minMonth;throw(i.local.unknownNameAt||i.regionalOptions[\"\"].unknownNameAt).replace(/\\{0\\}/,A)},k=function(){if(\"function\"==typeof u){var t=y(\"M\")?u.call(b,e.substring(A)):c.call(b,e.substring(A));return A+=t.length,t}return w(\"M\",c,u)},T=function(){if(e.charAt(A)!==t.charAt(M))throw(i.local.unexpectedLiteralAt||i.regionalOptions[\"\"].unexpectedLiteralAt).replace(/\\{0\\}/,A);A++},A=0,M=0;M<t.length;M++)if(m)\"'\"!==t.charAt(M)||y(\"'\")?T():m=!1;else switch(t.charAt(M)){case\"d\":d=x(\"d\");break;case\"D\":w(\"D\",a,o);break;case\"o\":g=x(\"o\");break;case\"w\":x(\"w\");break;case\"m\":p=_();break;case\"M\":p=k();break;case\"y\":var S=M;v=!y(\"y\",2),M=S,f=x(\"y\",2);break;case\"Y\":f=x(\"Y\",2);break;case\"J\":h=x(\"J\")+.5,\".\"===e.charAt(A)&&(A++,x(\"J\"));break;case\"@\":h=x(\"@\")/this.SECS_PER_DAY+this.UNIX_EPOCH;break;case\"!\":h=x(\"!\")/this.TICKS_PER_DAY+this.TICKS_EPOCH;break;case\"*\":A=e.length;break;case\"'\":y(\"'\")?T():m=!0;break;default:T()}if(A<e.length)throw i.local.unexpectedText||i.regionalOptions[\"\"].unexpectedText;if(-1===f?f=this.today().year():f<100&&v&&(f+=-1===n?1900:this.today().year()-this.today().year()%100-(f<=n?0:100)),\"string\"==typeof p&&(p=s.call(this,f,p)),g>-1){p=1,d=g;for(var E=this.daysInMonth(f,p);d>E;E=this.daysInMonth(f,p))p++,d-=E}return h>-1?this.fromJD(h):this.newDate(f,p,d)},determineDate:function(t,e,r,n,i){r&&\"object\"!=typeof r&&(i=n,n=r,r=null),\"string\"!=typeof n&&(i=n,n=\"\");var a=this;return e=e?e.newDate():null,t=null==t?e:\"string\"==typeof t?function(t){try{return a.parseDate(n,t,i)}catch(t){}for(var e=((t=t.toLowerCase()).match(/^c/)&&r?r.newDate():null)||a.today(),o=/([+-]?[0-9]+)\\s*(d|w|m|y)?/g,s=o.exec(t);s;)e.add(parseInt(s[1],10),s[2]||\"d\"),s=o.exec(t);return e}(t):\"number\"==typeof t?isNaN(t)||t===1/0||t===-1/0?e:a.today().add(t,\"d\"):a.newDate(t)}})},{\"./main\":571,\"object-assign\":454}],573:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",{offset:[1],array:0},\"scalar\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\n        var _inline_1_da = _inline_1_arg0_ - _inline_1_arg3_\\n        var _inline_1_db = _inline_1_arg1_ - _inline_1_arg3_\\n        if((_inline_1_da >= 0) !== (_inline_1_db >= 0)) {\\n          _inline_1_arg2_.push(_inline_1_arg4_[0] + 0.5 + 0.5 * (_inline_1_da + _inline_1_db) / (_inline_1_da - _inline_1_db))\\n        }\\n      }\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg3_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[\"_inline_1_da\",\"_inline_1_db\"]},funcName:\"zeroCrossings\"})},{\"cwise-compiler\":146}],574:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=[];return e=+e||0,n(t.hi(t.shape[0]-1),r,e),r};var n=t(\"./lib/zc-core\")},{\"./lib/zc-core\":573}],575:[function(t,e,r){\"use strict\";e.exports=[{path:\"\",backoff:0},{path:\"M-2.4,-3V3L0.6,0Z\",backoff:.6},{path:\"M-3.7,-2.5V2.5L1.3,0Z\",backoff:1.3},{path:\"M-4.45,-3L-1.65,-0.2V0.2L-4.45,3L1.55,0Z\",backoff:1.55},{path:\"M-2.2,-2.2L-0.2,-0.2V0.2L-2.2,2.2L-1.4,3L1.6,0L-1.4,-3Z\",backoff:1.6},{path:\"M-4.4,-2.1L-0.6,-0.2V0.2L-4.4,2.1L-4,3L2,0L-4,-3Z\",backoff:2},{path:\"M2,0A2,2 0 1,1 0,-2A2,2 0 0,1 2,0Z\",backoff:0,noRotate:!0},{path:\"M2,2V-2H-2V2Z\",backoff:0,noRotate:!0}]},{}],576:[function(t,e,r){\"use strict\";var n=t(\"./arrow_paths\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../plots/cartesian/constants\"),o=t(\"../../plot_api/plot_template\").templatedArray;e.exports=o(\"annotation\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},text:{valType:\"string\",editType:\"calc+arraydraw\"},textangle:{valType:\"angle\",dflt:0,editType:\"calc+arraydraw\"},font:i({editType:\"calc+arraydraw\",colorEditType:\"arraydraw\"}),width:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},height:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"center\",editType:\"arraydraw\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"arraydraw\"},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},borderpad:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},showarrow:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},arrowcolor:{valType:\"color\",editType:\"arraydraw\"},arrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},startarrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},arrowside:{valType:\"flaglist\",flags:[\"end\",\"start\"],extras:[\"none\"],dflt:\"end\",editType:\"arraydraw\"},arrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},startarrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},arrowwidth:{valType:\"number\",min:.1,editType:\"calc+arraydraw\"},standoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},startstandoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},ax:{valType:\"any\",editType:\"calc+arraydraw\"},ay:{valType:\"any\",editType:\"calc+arraydraw\"},axref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.x.toString()],editType:\"calc\"},ayref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.y.toString()],editType:\"calc\"},xref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.x.toString()],editType:\"calc\"},x:{valType:\"any\",editType:\"calc+arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"auto\",editType:\"calc+arraydraw\"},xshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.y.toString()],editType:\"calc\"},y:{valType:\"any\",editType:\"calc+arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"calc+arraydraw\"},yshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},clicktoshow:{valType:\"enumerated\",values:[!1,\"onoff\",\"onout\"],dflt:!1,editType:\"arraydraw\"},xclick:{valType:\"any\",editType:\"arraydraw\"},yclick:{valType:\"any\",editType:\"arraydraw\"},hovertext:{valType:\"string\",editType:\"arraydraw\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",editType:\"arraydraw\"},font:i({editType:\"arraydraw\"}),editType:\"arraydraw\"},captureevents:{valType:\"boolean\",editType:\"arraydraw\"},editType:\"calc\",_deprecated:{ref:{valType:\"string\",editType:\"calc\"}}})},{\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773,\"../../plots/font_attributes\":793,\"./arrow_paths\":575}],577:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./draw\").draw;function o(t){var e=t._fullLayout;n.filterVisible(e.annotations).forEach(function(e){var r=i.getFromId(t,e.xref),n=i.getFromId(t,e.yref);e._extremes={},r&&s(e,r),n&&s(e,n)})}function s(t,e){var r,n=e._id,a=n.charAt(0),o=t[a],s=t[\"a\"+a],l=t[a+\"ref\"],c=t[\"a\"+a+\"ref\"],u=t[\"_\"+a+\"padplus\"],h=t[\"_\"+a+\"padminus\"],f={x:1,y:-1}[a]*t[a+\"shift\"],p=3*t.arrowsize*t.arrowwidth||0,d=p+f,g=p-f,v=3*t.startarrowsize*t.arrowwidth||0,m=v+f,y=v-f;if(c===l){var x=i.findExtremes(e,[e.r2c(o)],{ppadplus:d,ppadminus:g}),b=i.findExtremes(e,[e.r2c(s)],{ppadplus:Math.max(u,m),ppadminus:Math.max(h,y)});r={min:[x.min[0],b.min[0]],max:[x.max[0],b.max[0]]}}else m=s?m+s:m,y=s?y-s:y,r=i.findExtremes(e,[e.r2c(o)],{ppadplus:Math.max(u,d,m),ppadminus:Math.max(h,g,y)});t._extremes[n]=r}e.exports=function(t){var e=t._fullLayout;if(n.filterVisible(e.annotations).length&&t._fullData.length)return n.syncOrAsync([a,o],t)}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./draw\":582}],578:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../plot_api/plot_template\").arrayEditor;function o(t,e){var r,n,i,a,o,l,c,u=t._fullLayout.annotations,h=[],f=[],p=[],d=(e||[]).length;for(r=0;r<u.length;r++)if(a=(i=u[r]).clicktoshow){for(n=0;n<d;n++)if(l=(o=e[n]).xaxis,c=o.yaxis,l._id===i.xref&&c._id===i.yref&&l.d2r(o.x)===s(i._xclick,l)&&c.d2r(o.y)===s(i._yclick,c)){(i.visible?\"onout\"===a?f:p:h).push(r);break}n===d&&i.visible&&\"onout\"===a&&f.push(r)}return{on:h,off:f,explicitOff:p}}function s(t,e){return\"log\"===e.type?e.l2r(t):e.d2r(t)}e.exports={hasClickToShow:function(t,e){var r=o(t,e);return r.on.length>0||r.explicitOff.length>0},onClick:function(t,e){var r,s,l=o(t,e),c=l.on,u=l.off.concat(l.explicitOff),h={},f=t._fullLayout.annotations;if(!c.length&&!u.length)return;for(r=0;r<c.length;r++)(s=a(t.layout,\"annotations\",f[c[r]])).modifyItem(\"visible\",!0),n.extendFlat(h,s.getUpdateObj());for(r=0;r<u.length;r++)(s=a(t.layout,\"annotations\",f[u[r]])).modifyItem(\"visible\",!1),n.extendFlat(h,s.getUpdateObj());return i.call(\"update\",t,{},h)}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../registry\":847}],579:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\");e.exports=function(t,e,r,a){a(\"opacity\");var o=a(\"bgcolor\"),s=a(\"bordercolor\"),l=i.opacity(s);a(\"borderpad\");var c=a(\"borderwidth\"),u=a(\"showarrow\");if(a(\"text\",u?\" \":r._dfltTitle.annotation),a(\"textangle\"),n.coerceFont(a,\"font\",r.font),a(\"width\"),a(\"align\"),a(\"height\")&&a(\"valign\"),u){var h,f,p=a(\"arrowside\");-1!==p.indexOf(\"end\")&&(h=a(\"arrowhead\"),f=a(\"arrowsize\")),-1!==p.indexOf(\"start\")&&(a(\"startarrowhead\",h),a(\"startarrowsize\",f)),a(\"arrowcolor\",l?e.bordercolor:i.defaultLine),a(\"arrowwidth\",2*(l&&c||1)),a(\"standoff\"),a(\"startstandoff\")}var d=a(\"hovertext\"),g=r.hoverlabel||{};if(d){var v=a(\"hoverlabel.bgcolor\",g.bgcolor||(i.opacity(o)?i.rgb(o):i.defaultLine)),m=a(\"hoverlabel.bordercolor\",g.bordercolor||i.contrast(v));n.coerceFont(a,\"hoverlabel.font\",{family:g.font.family,size:g.font.size,color:g.font.color||m})}a(\"captureevents\",!!d)}},{\"../../lib\":719,\"../color\":593}],580:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.annotations,h=e._id.charAt(0),f=0;f<u.length;f++)l=u[f],c=\"annotations[\"+f+\"].\",l[h+\"ref\"]===e._id&&p(h),l[\"a\"+h+\"ref\"]===e._id&&p(\"a\"+h);function p(t){var r=l[t],s=null;s=o?i(r,e.range):Math.pow(10,r),n(s)||(s=null),a(c+t,s)}}},{\"../../lib/to_log_range\":745,\"fast-isnumeric\":225}],581:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./common_defaults\"),s=t(\"./attributes\");function l(t,e,r){function a(r,i){return n.coerce(t,e,s,r,i)}var l=a(\"visible\"),c=a(\"clicktoshow\");if(l||c){o(t,e,r,a);for(var u=e.showarrow,h=[\"x\",\"y\"],f=[-10,-30],p={_fullLayout:r},d=0;d<2;d++){var g=h[d],v=i.coerceRef(t,e,p,g,\"\",\"paper\");if(\"paper\"!==v)i.getFromId(p,v)._annIndices.push(e._index);if(i.coercePosition(e,p,a,v,g,.5),u){var m=\"a\"+g,y=i.coerceRef(t,e,p,m,\"pixel\");\"pixel\"!==y&&y!==v&&(y=e[m]=\"pixel\");var x=\"pixel\"===y?f[d]:.4;i.coercePosition(e,p,a,y,m,x)}a(g+\"anchor\"),a(g+\"shift\")}if(n.noneOrAll(t,e,[\"x\",\"y\"]),u&&n.noneOrAll(t,e,[\"ax\",\"ay\"]),c){var b=a(\"xclick\"),_=a(\"yclick\");e._xclick=void 0===b?e.x:i.cleanPosition(b,p,e.xref),e._yclick=void 0===_?e.y:i.cleanPosition(_,p,e.yref)}}}e.exports=function(t,e){a(t,e,{name:\"annotations\",handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"./attributes\":576,\"./common_defaults\":579}],582:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../color\"),c=t(\"../drawing\"),u=t(\"../fx\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"../../lib/setcursor\"),p=t(\"../dragelement\"),d=t(\"../../plot_api/plot_template\").arrayEditor,g=t(\"./draw_arrow_head\");function v(t,e){var r=t._fullLayout.annotations[e]||{},n=s.getFromId(t,r.xref),i=s.getFromId(t,r.yref);n&&n.setScale(),i&&i.setScale(),m(t,r,e,!1,n,i)}function m(t,e,r,a,s,v){var m,y,x=t._fullLayout,b=t._fullLayout._size,_=t._context.edits;a?(m=\"annotation-\"+a,y=a+\".annotations\"):(m=\"annotation\",y=\"annotations\");var w=d(t.layout,y,e),k=w.modifyBase,T=w.modifyItem,A=w.getUpdateObj;x._infolayer.selectAll(\".\"+m+'[data-index=\"'+r+'\"]').remove();var M=\"clip\"+x._uid+\"_ann\"+r;if(e._input&&!1!==e.visible){var S={x:{},y:{}},E=+e.textangle||0,C=x._infolayer.append(\"g\").classed(m,!0).attr(\"data-index\",String(r)).style(\"opacity\",e.opacity),L=C.append(\"g\").classed(\"annotation-text-g\",!0),P=_[e.showarrow?\"annotationTail\":\"annotationPosition\"],O=e.captureevents||_.annotationText||P,z=L.append(\"g\").style(\"pointer-events\",O?\"all\":null).call(f,\"pointer\").on(\"click\",function(){t._dragging=!1,t.emit(\"plotly_clickannotation\",q(n.event))});e.hovertext&&z.on(\"mouseover\",function(){var r=e.hoverlabel,n=r.font,i=this.getBoundingClientRect(),a=t.getBoundingClientRect();u.loneHover({x0:i.left-a.left,x1:i.right-a.left,y:(i.top+i.bottom)/2-a.top,text:e.hovertext,color:r.bgcolor,borderColor:r.bordercolor,fontFamily:n.family,fontSize:n.size,fontColor:n.color},{container:x._hoverlayer.node(),outerContainer:x._paper.node(),gd:t})}).on(\"mouseout\",function(){u.loneUnhover(x._hoverlayer.node())});var I=e.borderwidth,D=e.borderpad,R=I+D,F=z.append(\"rect\").attr(\"class\",\"bg\").style(\"stroke-width\",I+\"px\").call(l.stroke,e.bordercolor).call(l.fill,e.bgcolor),B=e.width||e.height,N=x._topclips.selectAll(\"#\"+M).data(B?[0]:[]);N.enter().append(\"clipPath\").classed(\"annclip\",!0).attr(\"id\",M).append(\"rect\"),N.exit().remove();var j=e.font,U=x._meta?o.templateString(e.text,x._meta):e.text,V=z.append(\"text\").classed(\"annotation-text\",!0).text(U);_.annotationText?V.call(h.makeEditable,{delegate:z,gd:t}).call(H).on(\"edit\",function(r){e.text=r,this.call(H),T(\"text\",r),s&&s.autorange&&k(s._name+\".autorange\",!0),v&&v.autorange&&k(v._name+\".autorange\",!0),i.call(\"_guiRelayout\",t,A())}):V.call(H)}else n.selectAll(\"#\"+M).remove();function q(t){var n={index:r,annotation:e._input,fullAnnotation:e,event:t};return a&&(n.subplotId=a),n}function H(r){return r.call(c.font,j).attr({\"text-anchor\":{left:\"start\",right:\"end\"}[e.align]||\"middle\"}),h.convertToTspans(r,t,G),r}function G(){var r=V.selectAll(\"a\");1===r.size()&&r.text()===V.text()&&z.insert(\"a\",\":first-child\").attr({\"xlink:xlink:href\":r.attr(\"xlink:href\"),\"xlink:xlink:show\":r.attr(\"xlink:show\")}).style({cursor:\"pointer\"}).node().appendChild(F.node());var n=z.select(\".annotation-text-math-group\"),u=!n.empty(),d=c.bBox((u?n:V).node()),m=d.width,y=d.height,w=e.width||m,O=e.height||y,D=Math.round(w+2*R),j=Math.round(O+2*R);function U(t,e){return\"auto\"===e&&(e=t<1/3?\"left\":t>2/3?\"right\":\"center\"),{center:0,middle:0,left:.5,bottom:-.5,right:-.5,top:.5}[e]}for(var H=!1,G=[\"x\",\"y\"],Y=0;Y<G.length;Y++){var W,X,Z,J,K,$=G[Y],Q=e[$+\"ref\"]||$,tt=e[\"a\"+$+\"ref\"],et={x:s,y:v}[$],rt=(E+(\"x\"===$?0:-90))*Math.PI/180,nt=D*Math.cos(rt),it=j*Math.sin(rt),at=Math.abs(nt)+Math.abs(it),ot=e[$+\"anchor\"],st=e[$+\"shift\"]*(\"x\"===$?1:-1),lt=S[$];if(et){var ct=et.r2fraction(e[$]);(ct<0||ct>1)&&(tt===Q?((ct=et.r2fraction(e[\"a\"+$]))<0||ct>1)&&(H=!0):H=!0),W=et._offset+et.r2p(e[$]),J=.5}else\"x\"===$?(Z=e[$],W=b.l+b.w*Z):(Z=1-e[$],W=b.t+b.h*Z),J=e.showarrow?.5:Z;if(e.showarrow){lt.head=W;var ut=e[\"a\"+$];K=nt*U(.5,e.xanchor)-it*U(.5,e.yanchor),tt===Q?(lt.tail=et._offset+et.r2p(ut),X=K):(lt.tail=W+ut,X=K+ut),lt.text=lt.tail+K;var ht=x[\"x\"===$?\"width\":\"height\"];if(\"paper\"===Q&&(lt.head=o.constrain(lt.head,1,ht-1)),\"pixel\"===tt){var ft=-Math.max(lt.tail-3,lt.text),pt=Math.min(lt.tail+3,lt.text)-ht;ft>0?(lt.tail+=ft,lt.text+=ft):pt>0&&(lt.tail-=pt,lt.text-=pt)}lt.tail+=st,lt.head+=st}else X=K=at*U(J,ot),lt.text=W+K;lt.text+=st,K+=st,X+=st,e[\"_\"+$+\"padplus\"]=at/2+X,e[\"_\"+$+\"padminus\"]=at/2-X,e[\"_\"+$+\"size\"]=at,e[\"_\"+$+\"shift\"]=K}if(t._dragging||!H){var dt=0,gt=0;if(\"left\"!==e.align&&(dt=(w-m)*(\"center\"===e.align?.5:1)),\"top\"!==e.valign&&(gt=(O-y)*(\"middle\"===e.valign?.5:1)),u)n.select(\"svg\").attr({x:R+dt-1,y:R+gt}).call(c.setClipUrl,B?M:null,t);else{var vt=R+gt-d.top,mt=R+dt-d.left;V.call(h.positionText,mt,vt).call(c.setClipUrl,B?M:null,t)}N.select(\"rect\").call(c.setRect,R,R,w,O),F.call(c.setRect,I/2,I/2,D-I,j-I),z.call(c.setTranslate,Math.round(S.x.text-D/2),Math.round(S.y.text-j/2)),L.attr({transform:\"rotate(\"+E+\",\"+S.x.text+\",\"+S.y.text+\")\"});var yt,xt=function(r,n){C.selectAll(\".annotation-arrow-g\").remove();var u=S.x.head,h=S.y.head,f=S.x.tail+r,d=S.y.tail+n,m=S.x.text+r,y=S.y.text+n,x=o.rotationXYMatrix(E,m,y),w=o.apply2DTransform(x),M=o.apply2DTransform2(x),P=+F.attr(\"width\"),O=+F.attr(\"height\"),I=m-.5*P,D=I+P,R=y-.5*O,B=R+O,N=[[I,R,I,B],[I,B,D,B],[D,B,D,R],[D,R,I,R]].map(M);if(!N.reduce(function(t,e){return t^!!o.segmentsIntersect(u,h,u+1e6,h+1e6,e[0],e[1],e[2],e[3])},!1)){N.forEach(function(t){var e=o.segmentsIntersect(f,d,u,h,t[0],t[1],t[2],t[3]);e&&(f=e.x,d=e.y)});var j=e.arrowwidth,U=e.arrowcolor,V=e.arrowside,q=C.append(\"g\").style({opacity:l.opacity(U)}).classed(\"annotation-arrow-g\",!0),H=q.append(\"path\").attr(\"d\",\"M\"+f+\",\"+d+\"L\"+u+\",\"+h).style(\"stroke-width\",j+\"px\").call(l.stroke,l.rgb(U));if(g(H,V,e),_.annotationPosition&&H.node().parentNode&&!a){var G=u,Y=h;if(e.standoff){var W=Math.sqrt(Math.pow(u-f,2)+Math.pow(h-d,2));G+=e.standoff*(f-u)/W,Y+=e.standoff*(d-h)/W}var X,Z,J=q.append(\"path\").classed(\"annotation-arrow\",!0).classed(\"anndrag\",!0).classed(\"cursor-move\",!0).attr({d:\"M3,3H-3V-3H3ZM0,0L\"+(f-G)+\",\"+(d-Y),transform:\"translate(\"+G+\",\"+Y+\")\"}).style(\"stroke-width\",j+6+\"px\").call(l.stroke,\"rgba(0,0,0,0)\").call(l.fill,\"rgba(0,0,0,0)\");p.init({element:J.node(),gd:t,prepFn:function(){var t=c.getTranslate(z);X=t.x,Z=t.y,s&&s.autorange&&k(s._name+\".autorange\",!0),v&&v.autorange&&k(v._name+\".autorange\",!0)},moveFn:function(t,r){var n=w(X,Z),i=n[0]+t,a=n[1]+r;z.call(c.setTranslate,i,a),T(\"x\",s?s.p2r(s.r2p(e.x)+t):e.x+t/b.w),T(\"y\",v?v.p2r(v.r2p(e.y)+r):e.y-r/b.h),e.axref===e.xref&&T(\"ax\",s.p2r(s.r2p(e.ax)+t)),e.ayref===e.yref&&T(\"ay\",v.p2r(v.r2p(e.ay)+r)),q.attr(\"transform\",\"translate(\"+t+\",\"+r+\")\"),L.attr({transform:\"rotate(\"+E+\",\"+i+\",\"+a+\")\"})},doneFn:function(){i.call(\"_guiRelayout\",t,A());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}}};if(e.showarrow&&xt(0,0),P)p.init({element:z.node(),gd:t,prepFn:function(){yt=L.attr(\"transform\")},moveFn:function(t,r){var n=\"pointer\";if(e.showarrow)e.axref===e.xref?T(\"ax\",s.p2r(s.r2p(e.ax)+t)):T(\"ax\",e.ax+t),e.ayref===e.yref?T(\"ay\",v.p2r(v.r2p(e.ay)+r)):T(\"ay\",e.ay+r),xt(t,r);else{if(a)return;var i,o;if(s)i=s.p2r(s.r2p(e.x)+t);else{var l=e._xsize/b.w,c=e.x+(e._xshift-e.xshift)/b.w-l/2;i=p.align(c+t/b.w,l,0,1,e.xanchor)}if(v)o=v.p2r(v.r2p(e.y)+r);else{var u=e._ysize/b.h,h=e.y-(e._yshift+e.yshift)/b.h-u/2;o=p.align(h-r/b.h,u,0,1,e.yanchor)}T(\"x\",i),T(\"y\",o),s&&v||(n=p.getCursor(s?.5:i,v?.5:o,e.xanchor,e.yanchor))}L.attr({transform:\"translate(\"+t+\",\"+r+\")\"+yt}),f(z,n)},clickFn:function(r,n){e.captureevents&&t.emit(\"plotly_clickannotation\",q(n))},doneFn:function(){f(z),i.call(\"_guiRelayout\",t,A());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}else z.remove()}}e.exports={draw:function(t){var e=t._fullLayout;e._infolayer.selectAll(\".annotation\").remove();for(var r=0;r<e.annotations.length;r++)e.annotations[r].visible&&v(t,r);return a.previousPromises(t)},drawOne:v,drawRaw:m}},{\"../../lib\":719,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/axes\":767,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"../fx\":632,\"./draw_arrow_head\":583,d3:163}],583:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\"),a=t(\"./arrow_paths\");e.exports=function(t,e,r){var o,s,l,c,u=t.node(),h=a[r.arrowhead||0],f=a[r.startarrowhead||0],p=(r.arrowwidth||1)*(r.arrowsize||1),d=(r.arrowwidth||1)*(r.startarrowsize||1),g=e.indexOf(\"start\")>=0,v=e.indexOf(\"end\")>=0,m=h.backoff*p+r.standoff,y=f.backoff*d+r.startstandoff;if(\"line\"===u.nodeName){o={x:+t.attr(\"x1\"),y:+t.attr(\"y1\")},s={x:+t.attr(\"x2\"),y:+t.attr(\"y2\")};var x=o.x-s.x,b=o.y-s.y;if(c=(l=Math.atan2(b,x))+Math.PI,m&&y&&m+y>Math.sqrt(x*x+b*b))return void P();if(m){if(m*m>x*x+b*b)return void P();var _=m*Math.cos(l),w=m*Math.sin(l);s.x+=_,s.y+=w,t.attr({x2:s.x,y2:s.y})}if(y){if(y*y>x*x+b*b)return void P();var k=y*Math.cos(l),T=y*Math.sin(l);o.x-=k,o.y-=T,t.attr({x1:o.x,y1:o.y})}}else if(\"path\"===u.nodeName){var A=u.getTotalLength(),M=\"\";if(A<m+y)return void P();var S=u.getPointAtLength(0),E=u.getPointAtLength(.1);l=Math.atan2(S.y-E.y,S.x-E.x),o=u.getPointAtLength(Math.min(y,A)),M=\"0px,\"+y+\"px,\";var C=u.getPointAtLength(A),L=u.getPointAtLength(A-.1);c=Math.atan2(C.y-L.y,C.x-L.x),s=u.getPointAtLength(Math.max(0,A-m)),M+=A-(M?y+m:m)+\"px,\"+A+\"px\",t.style(\"stroke-dasharray\",M)}function P(){t.style(\"stroke-dasharray\",\"0px,100px\")}function O(e,a,o,s){e.path&&(e.noRotate&&(o=0),n.select(u.parentNode).append(\"path\").attr({class:t.attr(\"class\"),d:e.path,transform:\"translate(\"+a.x+\",\"+a.y+\")\"+(o?\"rotate(\"+180*o/Math.PI+\")\":\"\")+\"scale(\"+s+\")\"}).style({fill:i.rgb(r.arrowcolor),\"stroke-width\":0}))}g&&O(f,o,l,d),v&&O(h,s,c,p)}},{\"../color\":593,\"./arrow_paths\":575,d3:163}],584:[function(t,e,r){\"use strict\";var n=t(\"./draw\"),i=t(\"./click\");e.exports={moduleType:\"component\",name:\"annotations\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"annotations\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne,drawRaw:n.drawRaw,hasClickToShow:i.hasClickToShow,onClick:i.onClick,convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":777,\"./attributes\":576,\"./calc_autorange\":577,\"./click\":578,\"./convert_coords\":580,\"./defaults\":581,\"./draw\":582}],585:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"../../plot_api/plot_template\").templatedArray;e.exports=i(a(\"annotation\",{visible:n.visible,x:{valType:\"any\"},y:{valType:\"any\"},z:{valType:\"any\"},ax:{valType:\"number\"},ay:{valType:\"number\"},xanchor:n.xanchor,xshift:n.xshift,yanchor:n.yanchor,yshift:n.yshift,text:n.text,textangle:n.textangle,font:n.font,width:n.width,height:n.height,opacity:n.opacity,align:n.align,valign:n.valign,bgcolor:n.bgcolor,bordercolor:n.bordercolor,borderpad:n.borderpad,borderwidth:n.borderwidth,showarrow:n.showarrow,arrowcolor:n.arrowcolor,arrowhead:n.arrowhead,startarrowhead:n.startarrowhead,arrowside:n.arrowside,arrowsize:n.arrowsize,startarrowsize:n.startarrowsize,arrowwidth:n.arrowwidth,standoff:n.standoff,startstandoff:n.startstandoff,hovertext:n.hovertext,hoverlabel:n.hoverlabel,captureevents:n.captureevents}),\"calc\",\"from-root\")},{\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../annotations/attributes\":576}],586:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\");function a(t,e){var r=e.fullSceneLayout.domain,a=e.fullLayout._size,o={pdata:null,type:\"linear\",autorange:!1,range:[-1/0,1/0]};t._xa={},n.extendFlat(t._xa,o),i.setConvert(t._xa),t._xa._offset=a.l+r.x[0]*a.w,t._xa.l2p=function(){return.5*(1+t._pdata[0]/t._pdata[3])*a.w*(r.x[1]-r.x[0])},t._ya={},n.extendFlat(t._ya,o),i.setConvert(t._ya),t._ya._offset=a.t+(1-r.y[1])*a.h,t._ya.l2p=function(){return.5*(1-t._pdata[1]/t._pdata[3])*a.h*(r.y[1]-r.y[0])}}e.exports=function(t){for(var e=t.fullSceneLayout.annotations,r=0;r<e.length;r++)a(e[r],t);t.fullLayout._infolayer.selectAll(\".annotation-\"+t.id).remove()}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767}],587:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"../annotations/common_defaults\"),s=t(\"./attributes\");function l(t,e,r,a){function l(r,i){return n.coerce(t,e,s,r,i)}function c(t){var n=t+\"axis\",a={_fullLayout:{}};return a._fullLayout[n]=r[n],i.coercePosition(e,a,l,t,t,.5)}l(\"visible\")&&(o(t,e,a.fullLayout,l),c(\"x\"),c(\"y\"),c(\"z\"),n.noneOrAll(t,e,[\"x\",\"y\",\"z\"]),e.xref=\"x\",e.yref=\"y\",e.zref=\"z\",l(\"xanchor\"),l(\"yanchor\"),l(\"xshift\"),l(\"yshift\"),e.showarrow&&(e.axref=\"pixel\",e.ayref=\"pixel\",l(\"ax\",-10),l(\"ay\",-30),n.noneOrAll(t,e,[\"ax\",\"ay\"])))}e.exports=function(t,e,r){a(t,e,{name:\"annotations\",handleItemDefaults:l,fullLayout:r.fullLayout})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"../annotations/common_defaults\":579,\"./attributes\":585}],588:[function(t,e,r){\"use strict\";var n=t(\"../annotations/draw\").drawRaw,i=t(\"../../plots/gl3d/project\"),a=[\"x\",\"y\",\"z\"];e.exports=function(t){for(var e=t.fullSceneLayout,r=t.dataScale,o=e.annotations,s=0;s<o.length;s++){for(var l=o[s],c=!1,u=0;u<3;u++){var h=a[u],f=l[h],p=e[h+\"axis\"].r2fraction(f);if(p<0||p>1){c=!0;break}}c?t.fullLayout._infolayer.select(\".annotation-\"+t.id+'[data-index=\"'+s+'\"]').remove():(l._pdata=i(t.glplot.cameraParams,[e.xaxis.r2l(l.x)*r[0],e.yaxis.r2l(l.y)*r[1],e.zaxis.r2l(l.z)*r[2]]),n(t.graphDiv,l,s,t.id,l._xa,l._ya))}}},{\"../../plots/gl3d/project\":816,\"../annotations/draw\":582}],589:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports={moduleType:\"component\",name:\"annotations3d\",schema:{subplots:{scene:{annotations:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),includeBasePlot:function(t,e){var r=n.subplotsRegistry.gl3d;if(!r)return;for(var a=r.attrRegex,o=Object.keys(t),s=0;s<o.length;s++){var l=o[s];a.test(l)&&(t[l].annotations||[]).length&&(i.pushUnique(e._basePlotModules,r),i.pushUnique(e._subplots.gl3d,l))}},convert:t(\"./convert\"),draw:t(\"./draw\")}},{\"../../lib\":719,\"../../registry\":847,\"./attributes\":585,\"./convert\":586,\"./defaults\":587,\"./draw\":588}],590:[function(t,e,r){\"use strict\";e.exports=t(\"world-calendars/dist/main\"),t(\"world-calendars/dist/plus\"),t(\"world-calendars/dist/calendars/chinese\"),t(\"world-calendars/dist/calendars/coptic\"),t(\"world-calendars/dist/calendars/discworld\"),t(\"world-calendars/dist/calendars/ethiopian\"),t(\"world-calendars/dist/calendars/hebrew\"),t(\"world-calendars/dist/calendars/islamic\"),t(\"world-calendars/dist/calendars/julian\"),t(\"world-calendars/dist/calendars/mayan\"),t(\"world-calendars/dist/calendars/nanakshahi\"),t(\"world-calendars/dist/calendars/nepali\"),t(\"world-calendars/dist/calendars/persian\"),t(\"world-calendars/dist/calendars/taiwan\"),t(\"world-calendars/dist/calendars/thai\"),t(\"world-calendars/dist/calendars/ummalqura\")},{\"world-calendars/dist/calendars/chinese\":557,\"world-calendars/dist/calendars/coptic\":558,\"world-calendars/dist/calendars/discworld\":559,\"world-calendars/dist/calendars/ethiopian\":560,\"world-calendars/dist/calendars/hebrew\":561,\"world-calendars/dist/calendars/islamic\":562,\"world-calendars/dist/calendars/julian\":563,\"world-calendars/dist/calendars/mayan\":564,\"world-calendars/dist/calendars/nanakshahi\":565,\"world-calendars/dist/calendars/nepali\":566,\"world-calendars/dist/calendars/persian\":567,\"world-calendars/dist/calendars/taiwan\":568,\"world-calendars/dist/calendars/thai\":569,\"world-calendars/dist/calendars/ummalqura\":570,\"world-calendars/dist/main\":571,\"world-calendars/dist/plus\":572}],591:[function(t,e,r){\"use strict\";var n=t(\"./calendars\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\"),o=a.EPOCHJD,s=a.ONEDAY,l={valType:\"enumerated\",values:Object.keys(n.calendars),editType:\"calc\",dflt:\"gregorian\"},c=function(t,e,r,n){var a={};return a[r]=l,i.coerce(t,e,a,r,n)},u=\"##\",h={d:{0:\"dd\",\"-\":\"d\"},e:{0:\"d\",\"-\":\"d\"},a:{0:\"D\",\"-\":\"D\"},A:{0:\"DD\",\"-\":\"DD\"},j:{0:\"oo\",\"-\":\"o\"},W:{0:\"ww\",\"-\":\"w\"},m:{0:\"mm\",\"-\":\"m\"},b:{0:\"M\",\"-\":\"M\"},B:{0:\"MM\",\"-\":\"MM\"},y:{0:\"yy\",\"-\":\"yy\"},Y:{0:\"yyyy\",\"-\":\"yyyy\"},U:u,w:u,c:{0:\"D M d %X yyyy\",\"-\":\"D M d %X yyyy\"},x:{0:\"mm/dd/yyyy\",\"-\":\"mm/dd/yyyy\"}};var f={};function p(t){var e=f[t];return e||(e=f[t]=n.instance(t))}function d(t){return i.extendFlat({},l,{description:t})}function g(t){return\"Sets the calendar system to use with `\"+t+\"` date data.\"}var v={xcalendar:d(g(\"x\"))},m=i.extendFlat({},v,{ycalendar:d(g(\"y\"))}),y=i.extendFlat({},m,{zcalendar:d(g(\"z\"))}),x=d([\"Sets the calendar system to use for `range` and `tick0`\",\"if this is a date axis. This does not set the calendar for\",\"interpreting data on this axis, that's specified in the trace\",\"or via the global `layout.calendar`\"].join(\" \"));e.exports={moduleType:\"component\",name:\"calendars\",schema:{traces:{scatter:m,bar:m,box:m,heatmap:m,contour:m,histogram:m,histogram2d:m,histogram2dcontour:m,scatter3d:y,surface:y,mesh3d:y,scattergl:m,ohlc:v,candlestick:v},layout:{calendar:d([\"Sets the default calendar system to use for interpreting and\",\"displaying dates throughout the plot.\"].join(\" \"))},subplots:{xaxis:{calendar:x},yaxis:{calendar:x},scene:{xaxis:{calendar:x},yaxis:{calendar:x},zaxis:{calendar:x}},polar:{radialaxis:{calendar:x}}},transforms:{filter:{valuecalendar:d([\"Sets the calendar system to use for `value`, if it is a date.\"].join(\" \")),targetcalendar:d([\"Sets the calendar system to use for `target`, if it is an\",\"array of dates. If `target` is a string (eg *x*) we use the\",\"corresponding trace attribute (eg `xcalendar`) if it exists,\",\"even if `targetcalendar` is provided.\"].join(\" \"))}}},layoutAttributes:l,handleDefaults:c,handleTraceDefaults:function(t,e,r,n){for(var i=0;i<r.length;i++)c(t,e,r[i]+\"calendar\",n.calendar)},CANONICAL_SUNDAY:{chinese:\"2000-01-02\",coptic:\"2000-01-03\",discworld:\"2000-01-03\",ethiopian:\"2000-01-05\",hebrew:\"5000-01-01\",islamic:\"1000-01-02\",julian:\"2000-01-03\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-05\",nepali:\"2000-01-05\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-04\",thai:\"2000-01-04\",ummalqura:\"1400-01-06\"},CANONICAL_TICK:{chinese:\"2000-01-01\",coptic:\"2000-01-01\",discworld:\"2000-01-01\",ethiopian:\"2000-01-01\",hebrew:\"5000-01-01\",islamic:\"1000-01-01\",julian:\"2000-01-01\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-01\",nepali:\"2000-01-01\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-01\",thai:\"2000-01-01\",ummalqura:\"1400-01-01\"},DFLTRANGE:{chinese:[\"2000-01-01\",\"2001-01-01\"],coptic:[\"1700-01-01\",\"1701-01-01\"],discworld:[\"1800-01-01\",\"1801-01-01\"],ethiopian:[\"2000-01-01\",\"2001-01-01\"],hebrew:[\"5700-01-01\",\"5701-01-01\"],islamic:[\"1400-01-01\",\"1401-01-01\"],julian:[\"2000-01-01\",\"2001-01-01\"],mayan:[\"5200-01-01\",\"5201-01-01\"],nanakshahi:[\"0500-01-01\",\"0501-01-01\"],nepali:[\"2000-01-01\",\"2001-01-01\"],persian:[\"1400-01-01\",\"1401-01-01\"],jalali:[\"1400-01-01\",\"1401-01-01\"],taiwan:[\"0100-01-01\",\"0101-01-01\"],thai:[\"2500-01-01\",\"2501-01-01\"],ummalqura:[\"1400-01-01\",\"1401-01-01\"]},getCal:p,worldCalFmt:function(t,e,r){for(var n,i,a,l,c,f=Math.floor((e+.05)/s)+o,d=p(r).fromJD(f),g=0;-1!==(g=t.indexOf(\"%\",g));)\"0\"===(n=t.charAt(g+1))||\"-\"===n||\"_\"===n?(a=3,i=t.charAt(g+2),\"_\"===n&&(n=\"-\")):(i=n,n=\"0\",a=2),(l=h[i])?(c=l===u?u:d.formatDate(l[n]),t=t.substr(0,g)+c+t.substr(g+a),g+=c.length):g+=a;return t}}},{\"../../constants/numerical\":695,\"../../lib\":719,\"./calendars\":590}],592:[function(t,e,r){\"use strict\";r.defaults=[\"#1f77b4\",\"#ff7f0e\",\"#2ca02c\",\"#d62728\",\"#9467bd\",\"#8c564b\",\"#e377c2\",\"#7f7f7f\",\"#bcbd22\",\"#17becf\"],r.defaultLine=\"#444\",r.lightLine=\"#eee\",r.background=\"#fff\",r.borderLine=\"#BEC8D9\",r.lightFraction=1e3/11},{}],593:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i=t(\"fast-isnumeric\"),a=e.exports={},o=t(\"./attributes\");a.defaults=o.defaults;var s=a.defaultLine=o.defaultLine;a.lightLine=o.lightLine;var l=a.background=o.background;function c(t){if(i(t)||\"string\"!=typeof t)return t;var e=t.trim();if(\"rgb\"!==e.substr(0,3))return t;var r=e.match(/^rgba?\\s*\\(([^()]*)\\)$/);if(!r)return t;var n=r[1].trim().split(/\\s*[\\s,]\\s*/),a=\"a\"===e.charAt(3)&&4===n.length;if(!a&&3!==n.length)return t;for(var o=0;o<n.length;o++){if(!n[o].length)return t;if(n[o]=Number(n[o]),!(n[o]>=0))return t;if(3===o)n[o]>1&&(n[o]=1);else if(n[o]>=1)return t}var s=Math.round(255*n[0])+\", \"+Math.round(255*n[1])+\", \"+Math.round(255*n[2]);return a?\"rgba(\"+s+\", \"+n[3]+\")\":\"rgb(\"+s+\")\"}a.tinyRGB=function(t){var e=t.toRgb();return\"rgb(\"+Math.round(e.r)+\", \"+Math.round(e.g)+\", \"+Math.round(e.b)+\")\"},a.rgb=function(t){return a.tinyRGB(n(t))},a.opacity=function(t){return t?n(t).getAlpha():0},a.addOpacity=function(t,e){var r=n(t).toRgb();return\"rgba(\"+Math.round(r.r)+\", \"+Math.round(r.g)+\", \"+Math.round(r.b)+\", \"+e+\")\"},a.combine=function(t,e){var r=n(t).toRgb();if(1===r.a)return n(t).toRgbString();var i=n(e||l).toRgb(),a=1===i.a?i:{r:255*(1-i.a)+i.r*i.a,g:255*(1-i.a)+i.g*i.a,b:255*(1-i.a)+i.b*i.a},o={r:a.r*(1-r.a)+r.r*r.a,g:a.g*(1-r.a)+r.g*r.a,b:a.b*(1-r.a)+r.b*r.a};return n(o).toRgbString()},a.contrast=function(t,e,r){var i=n(t);return 1!==i.getAlpha()&&(i=n(a.combine(t,l))),(i.isDark()?e?i.lighten(e):l:r?i.darken(r):s).toString()},a.stroke=function(t,e){var r=n(e);t.style({stroke:a.tinyRGB(r),\"stroke-opacity\":r.getAlpha()})},a.fill=function(t,e){var r=n(e);t.style({fill:a.tinyRGB(r),\"fill-opacity\":r.getAlpha()})},a.clean=function(t){if(t&&\"object\"==typeof t){var e,r,n,i,o=Object.keys(t);for(e=0;e<o.length;e++)if(i=t[n=o[e]],\"color\"===n.substr(n.length-5))if(Array.isArray(i))for(r=0;r<i.length;r++)i[r]=c(i[r]);else t[n]=c(i);else if(\"colorscale\"===n.substr(n.length-10)&&Array.isArray(i))for(r=0;r<i.length;r++)Array.isArray(i[r])&&(i[r][1]=c(i[r][1]));else if(Array.isArray(i)){var s=i[0];if(!Array.isArray(s)&&s&&\"object\"==typeof s)for(r=0;r<i.length;r++)a.clean(i[r])}else i&&\"object\"==typeof i&&a.clean(i)}}},{\"./attributes\":592,\"fast-isnumeric\":225,tinycolor2:537}],594:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/layout_attributes\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll;e.exports=o({thicknessmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"pixels\"},thickness:{valType:\"number\",min:0,dflt:30},lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",dflt:1.02,min:-2,max:3},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},xpad:{valType:\"number\",min:0,dflt:10},y:{valType:\"number\",dflt:.5,min:-2,max:3},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\"},ypad:{valType:\"number\",min:0,dflt:10},outlinecolor:n.linecolor,outlinewidth:n.linewidth,bordercolor:n.linecolor,borderwidth:{valType:\"number\",min:0,dflt:0},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\"},tickmode:n.tickmode,nticks:n.nticks,tick0:n.tick0,dtick:n.dtick,tickvals:n.tickvals,ticktext:n.ticktext,ticks:a({},n.ticks,{dflt:\"\"}),ticklen:n.ticklen,tickwidth:n.tickwidth,tickcolor:n.tickcolor,showticklabels:n.showticklabels,tickfont:i({}),tickangle:n.tickangle,tickformat:n.tickformat,tickformatstops:n.tickformatstops,tickprefix:n.tickprefix,showtickprefix:n.showtickprefix,ticksuffix:n.ticksuffix,showticksuffix:n.showticksuffix,separatethousands:n.separatethousands,exponentformat:n.exponentformat,showexponent:n.showexponent,title:{text:{valType:\"string\"},font:i({}),side:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}},_deprecated:{title:{valType:\"string\"},titlefont:i({}),titleside:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}}},\"colorbars\",\"from-root\")},{\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/font_attributes\":793}],595:[function(t,e,r){\"use strict\";e.exports={cn:{colorbar:\"colorbar\",cbbg:\"cbbg\",cbfill:\"cbfill\",cbfills:\"cbfills\",cbline:\"cbline\",cblines:\"cblines\",cbaxis:\"cbaxis\",cbtitleunshift:\"cbtitleunshift\",cbtitle:\"cbtitle\",cboutline:\"cboutline\",crisp:\"crisp\",jsPlaceholder:\"js-placeholder\"}}},{}],596:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/tick_value_defaults\"),o=t(\"../../plots/cartesian/tick_mark_defaults\"),s=t(\"../../plots/cartesian/tick_label_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r){var c=i.newContainer(e,\"colorbar\"),u=t.colorbar||{};function h(t,e){return n.coerce(u,c,l,t,e)}var f=h(\"thicknessmode\");h(\"thickness\",\"fraction\"===f?30/(r.width-r.margin.l-r.margin.r):30);var p=h(\"lenmode\");h(\"len\",\"fraction\"===p?1:r.height-r.margin.t-r.margin.b),h(\"x\"),h(\"xanchor\"),h(\"xpad\"),h(\"y\"),h(\"yanchor\"),h(\"ypad\"),n.noneOrAll(u,c,[\"x\",\"y\"]),h(\"outlinecolor\"),h(\"outlinewidth\"),h(\"bordercolor\"),h(\"borderwidth\"),h(\"bgcolor\"),a(u,c,h,\"linear\");var d={outerTicks:!1,font:r.font};s(u,c,h,\"linear\",d),o(u,c,h,\"linear\",d),h(\"title.text\",r._dfltTitle.colorbar),n.coerceFont(h,\"title.font\",r.font),h(\"title.side\")}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/tick_label_defaults\":786,\"../../plots/cartesian/tick_mark_defaults\":787,\"../../plots/cartesian/tick_value_defaults\":788,\"./attributes\":594}],597:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../dragelement\"),c=t(\"../../lib\"),u=t(\"../../lib/extend\").extendFlat,h=t(\"../../lib/setcursor\"),f=t(\"../drawing\"),p=t(\"../color\"),d=t(\"../titles\"),g=t(\"../../lib/svg_text_utils\"),v=t(\"../colorscale/helpers\").flipScale,m=t(\"../../plots/cartesian/axis_defaults\"),y=t(\"../../plots/cartesian/position_defaults\"),x=t(\"../../plots/cartesian/layout_attributes\"),b=t(\"../../constants/alignment\"),_=b.LINE_SPACING,w=b.FROM_TL,k=b.FROM_BR,T=t(\"./constants\").cn;e.exports={draw:function(t){var e=t._fullLayout._infolayer.selectAll(\"g.\"+T.colorbar).data(function(t){var e,r,n,i,a=t._fullLayout,o=t.calcdata,s=[];function l(t){return u(t,{_fillcolor:null,_line:{color:null,width:null,dash:null},_levels:{start:null,end:null,size:null},_filllevels:null,_fillgradient:null,_zrange:null})}function c(){\"function\"==typeof i.calc?i.calc(t,n,e):(e._fillgradient=r.reversescale?v(r.colorscale):r.colorscale,e._zrange=[r[i.min],r[i.max]])}for(var h=0;h<o.length;h++){var f=o[h],p=(n=f[0].trace)._module.colorbar;if(!0===n.visible&&p)for(var d=Array.isArray(p),g=d?p:[p],m=0;m<g.length;m++){var y=(i=g[m]).container;(r=y?n[y]:n)&&r.showscale&&((e=l(r.colorbar))._id=\"cb\"+n.uid+(d&&y?\"-\"+y:\"\"),e._traceIndex=n.index,e._propPrefix=(y?y+\".\":\"\")+\"colorbar.\",e._meta=n._meta,c(),s.push(e))}}for(var x in a._colorAxes)if((r=a[x]).showscale){var b=a._colorAxes[x];(e=l(r.colorbar))._id=\"cb\"+x,e._propPrefix=x+\".colorbar.\",e._meta=a._meta,i={min:\"cmin\",max:\"cmax\"},\"heatmap\"!==b[0]&&(n=b[1],i.calc=n._module.colorbar.calc),c(),s.push(e)}return s}(t),function(t){return t._id});e.enter().append(\"g\").attr(\"class\",function(t){return t._id}).classed(T.colorbar,!0),e.each(function(e){var r=n.select(this);c.ensureSingle(r,\"rect\",T.cbbg),c.ensureSingle(r,\"g\",T.cbfills),c.ensureSingle(r,\"g\",T.cblines),c.ensureSingle(r,\"g\",T.cbaxis,function(t){t.classed(T.crisp,!0)}),c.ensureSingle(r,\"g\",T.cbtitleunshift,function(t){t.append(\"g\").classed(T.cbtitle,!0)}),c.ensureSingle(r,\"rect\",T.cboutline);var v=function(t,e,r){var o=r._fullLayout,l=o._size,h=e._fillcolor,v=e._line,b=e.title,A=b.side,M=e._zrange||n.extent((\"function\"==typeof h?h:v.color).domain()),S=\"function\"==typeof v.color?v.color:function(){return v.color},E=\"function\"==typeof h?h:function(){return h},C=e._levels,L=function(t,e,r){var n,i,a=e._levels,o=[],s=[],l=a.end+a.size/100,c=a.size,u=1.001*r[0]-.001*r[1],h=1.001*r[1]-.001*r[0];for(i=0;i<1e5&&(n=a.start+i*c,!(c>0?n>=l:n<=l));i++)n>u&&n<h&&o.push(n);if(e._fillgradient)s=[0];else if(\"function\"==typeof e._fillcolor){var f=e._filllevels;if(f)for(l=f.end+f.size/100,c=f.size,i=0;i<1e5&&(n=f.start+i*c,!(c>0?n>=l:n<=l));i++)n>r[0]&&n<r[1]&&s.push(n);else(s=o.map(function(t){return t-a.size/2})).push(s[s.length-1]+a.size)}else e._fillcolor&&\"string\"==typeof e._fillcolor&&(s=[0]);return a.size<0&&(o.reverse(),s.reverse()),{line:o,fill:s}}(0,e,M),P=L.fill,O=L.line,z=Math.round(e.thickness*(\"fraction\"===e.thicknessmode?l.w:1)),I=z/l.w,D=Math.round(e.len*(\"fraction\"===e.lenmode?l.h:1)),R=D/l.h,F=e.xpad/l.w,B=(e.borderwidth+e.outlinewidth)/2,N=e.ypad/l.h,j=Math.round(e.x*l.w+e.xpad),U=e.x-I*({middle:.5,right:1}[e.xanchor]||0),V=e.y+R*(({top:-.5,bottom:.5}[e.yanchor]||0)-.5),q=Math.round(l.h*(1-V)),H=q-D;e._lenFrac=R,e._thickFrac=I,e._xLeftFrac=U,e._yBottomFrac=V;var G=function(t,e,r){var n=t._fullLayout,i={type:\"linear\",range:r,tickmode:e.tickmode,nticks:e.nticks,tick0:e.tick0,dtick:e.dtick,tickvals:e.tickvals,ticktext:e.ticktext,ticks:e.ticks,ticklen:e.ticklen,tickwidth:e.tickwidth,tickcolor:e.tickcolor,showticklabels:e.showticklabels,tickfont:e.tickfont,tickangle:e.tickangle,tickformat:e.tickformat,exponentformat:e.exponentformat,separatethousands:e.separatethousands,showexponent:e.showexponent,showtickprefix:e.showtickprefix,tickprefix:e.tickprefix,showticksuffix:e.showticksuffix,ticksuffix:e.ticksuffix,title:e.title,showline:!0,anchor:\"free\",side:\"right\",position:1},a={type:\"linear\",_id:\"y\"+e._id},o={letter:\"y\",font:n.font,noHover:!0,noTickson:!0,calendar:n.calendar};function s(t,e){return c.coerce(i,a,x,t,e)}return m(i,a,s,o,n),y(i,a,s,o),a}(r,e,M);if(G.position=e.x+F+I,-1!==[\"top\",\"bottom\"].indexOf(A)&&(G.title.side=A,G.titlex=e.x+F,G.titley=V+(\"top\"===b.side?R-N:N)),v.color&&\"auto\"===e.tickmode){G.tickmode=\"linear\",G.tick0=C.start;var Y=C.size,W=c.constrain((q-H)/50,4,15)+1,X=(M[1]-M[0])/((e.nticks||W)*Y);if(X>1){var Z=Math.pow(10,Math.floor(Math.log(X)/Math.LN10));Y*=Z*c.roundUp(X/Z,[2,5,10]),(Math.abs(C.start)/C.size+1e-6)%1<2e-6&&(G.tick0=0)}G.dtick=Y}G.domain=[V+N,V+R-N],G.setScale(),t.attr(\"transform\",\"translate(\"+Math.round(l.l)+\",\"+Math.round(l.t)+\")\");var J,K=t.select(\".\"+T.cbtitleunshift).attr(\"transform\",\"translate(-\"+Math.round(l.l)+\",-\"+Math.round(l.t)+\")\"),$=t.select(\".\"+T.cbaxis),Q=0;function tt(n,i){var a={propContainer:G,propName:e._propPrefix+\"title\",traceIndex:e._traceIndex,_meta:e._meta,placeholder:o._dfltTitle.colorbar,containerGroup:t.select(\".\"+T.cbtitle)},s=\"h\"===n.charAt(0)?n.substr(1):\"h\"+n;t.selectAll(\".\"+s+\",.\"+s+\"-math-group\").remove(),d.draw(r,n,u(a,i||{}))}return c.syncOrAsync([a.previousPromises,function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var t,r=l.l+(e.x+F)*l.w,n=G.title.font.size;t=\"top\"===A?(1-(V+R-N))*l.h+l.t+3+.75*n:(1-(V+N))*l.h+l.t-3-.25*n,tt(G._id+\"title\",{attributes:{x:r,y:t,\"text-anchor\":\"start\"}})}},function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var a=t.select(\".\"+T.cbtitle),o=a.select(\"text\"),u=[-e.outlinewidth/2,e.outlinewidth/2],h=a.select(\".h\"+G._id+\"title-math-group\").node(),p=15.6;if(o.node()&&(p=parseInt(o.node().style.fontSize,10)*_),h?(Q=f.bBox(h).height)>p&&(u[1]-=(Q-p)/2):o.node()&&!o.classed(T.jsPlaceholder)&&(Q=f.bBox(o.node()).height),Q){if(Q+=5,\"top\"===A)G.domain[1]-=Q/l.h,u[1]*=-1;else{G.domain[0]+=Q/l.h;var d=g.lineCount(o);u[1]+=(1-d)*p}a.attr(\"transform\",\"translate(\"+u+\")\"),G.setScale()}}t.selectAll(\".\"+T.cbfills+\",.\"+T.cblines).attr(\"transform\",\"translate(0,\"+Math.round(l.h*(1-G.domain[1]))+\")\"),$.attr(\"transform\",\"translate(0,\"+Math.round(-l.t)+\")\");var m=t.select(\".\"+T.cbfills).selectAll(\"rect.\"+T.cbfill).data(P);m.enter().append(\"rect\").classed(T.cbfill,!0).style(\"stroke\",\"none\"),m.exit().remove();var y=M.map(G.c2p).map(Math.round).sort(function(t,e){return t-e});m.each(function(t,a){var o=[0===a?M[0]:(P[a]+P[a-1])/2,a===P.length-1?M[1]:(P[a]+P[a+1])/2].map(G.c2p).map(Math.round);o[1]=c.constrain(o[1]+(o[1]>o[0])?1:-1,y[0],y[1]);var s=n.select(this).attr({x:j,width:Math.max(z,2),y:n.min(o),height:Math.max(n.max(o)-n.min(o),2)});if(e._fillgradient)f.gradient(s,r,e._id,\"vertical\",e._fillgradient,\"fill\");else{var l=E(t).replace(\"e-\",\"\");s.attr(\"fill\",i(l).toHexString())}});var x=t.select(\".\"+T.cblines).selectAll(\"path.\"+T.cbline).data(v.color&&v.width?O:[]);x.enter().append(\"path\").classed(T.cbline,!0),x.exit().remove(),x.each(function(t){n.select(this).attr(\"d\",\"M\"+j+\",\"+(Math.round(G.c2p(t))+v.width/2%1)+\"h\"+z).call(f.lineGroupStyle,v.width,S(t),v.dash)}),$.selectAll(\"g.\"+G._id+\"tick,path\").remove();var b=j+z+(e.outlinewidth||0)/2-(\"outside\"===e.ticks?1:0),w=s.calcTicks(G),k=s.makeTransFn(G),C=s.getTickSigns(G)[2];return s.drawTicks(r,G,{vals:\"inside\"===G.ticks?s.clipEnds(G,w):w,layer:$,path:s.makeTickPath(G,b,C),transFn:k}),s.drawLabels(r,G,{vals:w,layer:$,transFn:k,labelFns:s.makeLabelFns(G,b)})},function(){if(-1===[\"top\",\"bottom\"].indexOf(A)){var t=G.title.font.size,e=G._offset+G._length/2,i=l.l+(G.position||0)*l.w+(\"right\"===G.side?10+t*(G.showticklabels?1:.5):-10-t*(G.showticklabels?.5:0));tt(\"h\"+G._id+\"title\",{avoid:{selection:n.select(r).selectAll(\"g.\"+G._id+\"tick\"),side:A,offsetLeft:l.l,offsetTop:0,maxShift:o.width},attributes:{x:i,y:e,\"text-anchor\":\"middle\"},transform:{rotate:\"-90\",offset:0}})}},a.previousPromises,function(){var n=z+e.outlinewidth/2+f.bBox($.node()).width;if((J=K.select(\"text\")).node()&&!J.classed(T.jsPlaceholder)){var i,o=K.select(\".h\"+G._id+\"title-math-group\").node();i=o&&-1!==[\"top\",\"bottom\"].indexOf(A)?f.bBox(o).width:f.bBox(K.node()).right-j-l.l,n=Math.max(n,i)}var s=2*e.xpad+n+e.borderwidth+e.outlinewidth/2,c=q-H;t.select(\".\"+T.cbbg).attr({x:j-e.xpad-(e.borderwidth+e.outlinewidth)/2,y:H-B,width:Math.max(s,2),height:Math.max(c+2*B,2)}).call(p.fill,e.bgcolor).call(p.stroke,e.bordercolor).style(\"stroke-width\",e.borderwidth),t.selectAll(\".\"+T.cboutline).attr({x:j,y:H+e.ypad+(\"top\"===A?Q:0),width:Math.max(z,2),height:Math.max(c-2*e.ypad-Q,2)}).call(p.stroke,e.outlinecolor).style({fill:\"none\",\"stroke-width\":e.outlinewidth});var u=({center:.5,right:1}[e.xanchor]||0)*s;t.attr(\"transform\",\"translate(\"+(l.l-u)+\",\"+l.t+\")\");var h={},d=w[e.yanchor],g=k[e.yanchor];\"pixels\"===e.lenmode?(h.y=e.y,h.t=c*d,h.b=c*g):(h.t=h.b=0,h.yt=e.y+e.len*d,h.yb=e.y-e.len*g);var v=w[e.xanchor],m=k[e.xanchor];if(\"pixels\"===e.thicknessmode)h.x=e.x,h.l=s*v,h.r=s*m;else{var y=s-z;h.l=y*v,h.r=y*m,h.xl=e.x-e.thickness*v,h.xr=e.x+e.thickness*m}a.autoMargin(r,e._id,h)}],r)}(r,e,t);v&&v.then&&(t._promises||[]).push(v),t._context.edits.colorbarPosition&&function(t,e,r){var n,i,a,s=r._fullLayout._size;l.init({element:t.node(),gd:r,prepFn:function(){n=t.attr(\"transform\"),h(t)},moveFn:function(r,o){t.attr(\"transform\",n+\" translate(\"+r+\",\"+o+\")\"),i=l.align(e._xLeftFrac+r/s.w,e._thickFrac,0,1,e.xanchor),a=l.align(e._yBottomFrac-o/s.h,e._lenFrac,0,1,e.yanchor);var c=l.getCursor(i,a,e.xanchor,e.yanchor);h(t,c)},doneFn:function(){if(h(t),void 0!==i&&void 0!==a){var n={};n[e._propPrefix+\"x\"]=i,n[e._propPrefix+\"y\"]=a,void 0!==e._traceIndex?o.call(\"_guiRestyle\",r,n,e._traceIndex):o.call(\"_guiRelayout\",r,n)}}})}(r,e,t)}),e.exit().each(function(e){a.autoMargin(t,e._id)}).remove(),e.order()}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/extend\":710,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_defaults\":769,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/cartesian/position_defaults\":782,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../colorscale/helpers\":604,\"../dragelement\":611,\"../drawing\":614,\"../titles\":681,\"./constants\":595,d3:163,tinycolor2:537}],598:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t){return n.isPlainObject(t.colorbar)}},{\"../../lib\":719}],599:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"colorbar\",attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),draw:t(\"./draw\").draw,hasColorbar:t(\"./has_colorbar\")}},{\"./attributes\":594,\"./defaults\":596,\"./draw\":597,\"./has_colorbar\":598}],600:[function(t,e,r){\"use strict\";var n=t(\"../colorbar/attributes\"),i=t(\"../../lib/regex\").counter,a=t(\"./scales.js\").scales;Object.keys(a);function o(t){return\"`\"+t+\"`\"}e.exports=function(t,e){t=t||\"\";var r,s=(e=e||{}).cLetter||\"c\",l=(\"onlyIfNumerical\"in e?e.onlyIfNumerical:Boolean(t),\"noScale\"in e?e.noScale:\"marker.line\"===t),c=\"showScaleDflt\"in e?e.showScaleDflt:\"z\"===s,u=\"string\"==typeof e.colorscaleDflt?a[e.colorscaleDflt]:null,h=e.editTypeOverride||\"\",f=t?t+\".\":\"\";\"colorAttr\"in e?(r=e.colorAttr,e.colorAttr):o(f+(r={z:\"z\",c:\"color\"}[s]));var p=s+\"auto\",d=s+\"min\",g=s+\"max\",v=s+\"mid\",m=(o(f+p),o(f+d),o(f+g),{});m[d]=m[g]=void 0;var y={};y[p]=!1;var x={};return\"color\"===r&&(x.color={valType:\"color\",arrayOk:!0,editType:h||\"style\"},e.anim&&(x.color.anim=!0)),x[p]={valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:m},x[d]={valType:\"number\",dflt:null,editType:h||\"plot\",impliedEdits:y},x[g]={valType:\"number\",dflt:null,editType:h||\"plot\",impliedEdits:y},x[v]={valType:\"number\",dflt:null,editType:\"calc\",impliedEdits:m},x.colorscale={valType:\"colorscale\",editType:\"calc\",dflt:u,impliedEdits:{autocolorscale:!1}},x.autocolorscale={valType:\"boolean\",dflt:!1!==e.autoColorDflt,editType:\"calc\",impliedEdits:{colorscale:void 0}},x.reversescale={valType:\"boolean\",dflt:!1,editType:\"plot\"},l||(x.showscale={valType:\"boolean\",dflt:c,editType:\"calc\"},x.colorbar=n),e.noColorAxis||(x.coloraxis={valType:\"subplotid\",regex:i(\"coloraxis\"),dflt:null,editType:\"calc\"}),x}},{\"../../lib/regex\":735,\"../colorbar/attributes\":594,\"./scales.js\":608}],601:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"./helpers\").extractOpts;e.exports=function(t,e,r){var o,s=t._fullLayout,l=r.vals,c=r.containerStr,u=c?i.nestedProperty(e,c).get():e,h=a(u),f=!1!==h.auto,p=h.min,d=h.max,g=h.mid,v=function(){return i.aggNums(Math.min,null,l)},m=function(){return i.aggNums(Math.max,null,l)};(void 0===p?p=v():f&&(p=u._colorAx&&n(p)?Math.min(p,v()):v()),void 0===d?d=m():f&&(d=u._colorAx&&n(d)?Math.max(d,m()):m()),f&&void 0!==g&&(d-g>g-p?p=g-(d-g):d-g<g-p&&(d=g+(g-p))),p===d&&(p-=.5,d+=.5),h._sync(\"min\",p),h._sync(\"max\",d),h.autocolorscale)&&(o=p*d<0?s.colorscale.diverging:p>=0?s.colorscale.sequential:s.colorscale.sequentialminus,h._sync(\"colorscale\",o))}},{\"../../lib\":719,\"./helpers\":604,\"fast-isnumeric\":225}],602:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./helpers\").hasColorscale,a=t(\"./helpers\").extractOpts;e.exports=function(t,e){function r(t,e){var r=t[\"_\"+e];void 0!==r&&(t[e]=r)}function o(t,i){var o=i.container?n.nestedProperty(t,i.container).get():t;if(o)if(o.coloraxis)o._colorAx=e[o.coloraxis];else{var s=a(o),l=s.auto;(l||void 0===s.min)&&r(o,i.min),(l||void 0===s.max)&&r(o,i.max),s.autocolorscale&&r(o,\"colorscale\")}}for(var s=0;s<t.length;s++){var l=t[s],c=l._module.colorbar;if(c)if(Array.isArray(c))for(var u=0;u<c.length;u++)o(l,c[u]);else o(l,c);i(l,\"marker.line\")&&o(l,{container:\"marker.line\",min:\"cmin\",max:\"cmax\"})}for(var h in e._colorAxes)o(e[h],{min:\"cmin\",max:\"cmax\"})}},{\"../../lib\":719,\"./helpers\":604}],603:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../colorbar/has_colorbar\"),o=t(\"../colorbar/defaults\"),s=t(\"./scales\").isValid,l=t(\"../../registry\").traceIs;function c(t,e){var r=e.slice(0,e.length-1);return e?i.nestedProperty(t,r).get()||{}:t}e.exports=function t(e,r,u,h,f){var p=f.prefix,d=f.cLetter,g=\"_module\"in r,v=c(e,p),m=c(r,p),y=c(r._template||{},p)||{},x=function(){return delete e.coloraxis,delete r.coloraxis,t(e,r,u,h,f)};if(g){var b=u._colorAxes||{},_=h(p+\"coloraxis\");if(_){var w=l(r,\"contour\")&&i.nestedProperty(r,\"contours.coloring\").get()||\"heatmap\",k=b[_];return void(k?(k[2].push(x),k[0]!==w&&(k[0]=!1,i.warn([\"Ignoring coloraxis:\",_,\"setting\",\"as it is linked to incompatible colorscales.\"].join(\" \")))):b[_]=[w,r,[x]])}}var T=v[d+\"min\"],A=v[d+\"max\"],M=n(T)&&n(A)&&T<A;h(p+d+\"auto\",!M)?h(p+d+\"mid\"):(h(p+d+\"min\"),h(p+d+\"max\"));var S,E,C=v.colorscale,L=y.colorscale;(void 0!==C&&(S=!s(C)),void 0!==L&&(S=!s(L)),h(p+\"autocolorscale\",S),h(p+\"colorscale\"),h(p+\"reversescale\"),\"marker.line.\"!==p)&&(p&&g&&(E=a(v)),h(p+\"showscale\",E)&&o(v,m,u))}},{\"../../lib\":719,\"../../registry\":847,\"../colorbar/defaults\":596,\"../colorbar/has_colorbar\":598,\"./scales\":608,\"fast-isnumeric\":225}],604:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"fast-isnumeric\"),o=t(\"../../lib\"),s=t(\"../color\"),l=t(\"./scales\").isValid;var c=[\"showscale\",\"autocolorscale\",\"colorscale\",\"reversescale\",\"colorbar\"],u=[\"min\",\"max\",\"mid\",\"auto\"];function h(t){var e,r,n,i=t._colorAx,a=i||t,o={};for(r=0;r<c.length;r++)o[n=c[r]]=a[n];if(i)for(e=\"c\",r=0;r<u.length;r++)o[n=u[r]]=a[\"c\"+n];else{var s;for(r=0;r<u.length;r++)(s=\"c\"+(n=u[r]))in a?o[n]=a[s]:(s=\"z\"+n)in a&&(o[n]=a[s]);e=s.charAt(0)}return o._sync=function(t,r){var n=-1!==u.indexOf(t)?e+t:t;a[n]=a[\"_\"+n]=r},o}function f(t){for(var e=h(t),r=e.min,n=e.max,i=e.reversescale?p(e.colorscale):e.colorscale,a=i.length,o=new Array(a),s=new Array(a),l=0;l<a;l++){var c=i[l];o[l]=r+c[0]*(n-r),s[l]=c[1]}return{domain:o,range:s}}function p(t){for(var e=t.length,r=new Array(e),n=e-1,i=0;n>=0;n--,i++){var a=t[n];r[i]=[1-a[0],a[1]]}return r}function d(t,e){e=e||{};for(var r=t.domain,o=t.range,l=o.length,c=new Array(l),u=0;u<l;u++){var h=i(o[u]).toRgb();c[u]=[h.r,h.g,h.b,h.a]}var f,p=n.scale.linear().domain(r).range(c).clamp(!0),d=e.noNumericCheck,v=e.returnArray;return(f=d&&v?p:d?function(t){return g(p(t))}:v?function(t){return a(t)?p(t):i(t).isValid()?t:s.defaultLine}:function(t){return a(t)?g(p(t)):i(t).isValid()?t:s.defaultLine}).domain=p.domain,f.range=function(){return o},f}function g(t){var e={r:t[0],g:t[1],b:t[2],a:t[3]};return i(e).toRgbString()}e.exports={hasColorscale:function(t,e){var r=e?o.nestedProperty(t,e).get()||{}:t,n=r.color,i=!1;if(o.isArrayOrTypedArray(n))for(var s=0;s<n.length;s++)if(a(n[s])){i=!0;break}return o.isPlainObject(r)&&(i||!0===r.showscale||a(r.cmin)&&a(r.cmax)||l(r.colorscale)||o.isPlainObject(r.colorbar))},extractOpts:h,extractScale:f,flipScale:p,makeColorScaleFunc:d,makeColorScaleFuncFromTrace:function(t,e){return d(f(t),e)}}},{\"../../lib\":719,\"../color\":593,\"./scales\":608,d3:163,\"fast-isnumeric\":225,tinycolor2:537}],605:[function(t,e,r){\"use strict\";var n=t(\"./scales\"),i=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"colorscale\",attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),handleDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\"),scales:n.scales,defaultScale:n.defaultScale,getScale:n.get,isValidScale:n.isValid,hasColorscale:i.hasColorscale,extractOpts:i.extractOpts,extractScale:i.extractScale,flipScale:i.flipScale,makeColorScaleFunc:i.makeColorScaleFunc,makeColorScaleFuncFromTrace:i.makeColorScaleFuncFromTrace}},{\"./attributes\":600,\"./calc\":601,\"./cross_trace_defaults\":602,\"./defaults\":603,\"./helpers\":604,\"./layout_attributes\":606,\"./layout_defaults\":607,\"./scales\":608}],606:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"./attributes\"),a=t(\"./scales\").scales;e.exports={editType:\"calc\",colorscale:{editType:\"calc\",sequential:{valType:\"colorscale\",dflt:a.Reds,editType:\"calc\"},sequentialminus:{valType:\"colorscale\",dflt:a.Blues,editType:\"calc\"},diverging:{valType:\"colorscale\",dflt:a.RdBu,editType:\"calc\"}},coloraxis:n({_isSubplotObj:!0,editType:\"calc\"},i(\"\",{colorAttr:\"corresponding trace color array(s)\",noColorAxis:!0,showScaleDflt:!0}))}},{\"../../lib/extend\":710,\"./attributes\":600,\"./scales\":608}],607:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"./layout_attributes\"),o=t(\"./defaults\");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r(\"colorscale.sequential\"),r(\"colorscale.sequentialminus\"),r(\"colorscale.diverging\");var s,l,c=e._colorAxes;function u(t,e){return n.coerce(s,l,a.coloraxis,t,e)}for(var h in c){var f=c[h];if(f[0])s=t[h]||{},(l=i.newContainer(e,h,\"coloraxis\"))._name=h,o(s,l,e,u,{prefix:\"\",cLetter:\"c\"});else{for(var p=0;p<f[2].length;p++)f[2][p]();delete e._colorAxes[h]}}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"./defaults\":603,\"./layout_attributes\":606}],608:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i={Greys:[[0,\"rgb(0,0,0)\"],[1,\"rgb(255,255,255)\"]],YlGnBu:[[0,\"rgb(8,29,88)\"],[.125,\"rgb(37,52,148)\"],[.25,\"rgb(34,94,168)\"],[.375,\"rgb(29,145,192)\"],[.5,\"rgb(65,182,196)\"],[.625,\"rgb(127,205,187)\"],[.75,\"rgb(199,233,180)\"],[.875,\"rgb(237,248,217)\"],[1,\"rgb(255,255,217)\"]],Greens:[[0,\"rgb(0,68,27)\"],[.125,\"rgb(0,109,44)\"],[.25,\"rgb(35,139,69)\"],[.375,\"rgb(65,171,93)\"],[.5,\"rgb(116,196,118)\"],[.625,\"rgb(161,217,155)\"],[.75,\"rgb(199,233,192)\"],[.875,\"rgb(229,245,224)\"],[1,\"rgb(247,252,245)\"]],YlOrRd:[[0,\"rgb(128,0,38)\"],[.125,\"rgb(189,0,38)\"],[.25,\"rgb(227,26,28)\"],[.375,\"rgb(252,78,42)\"],[.5,\"rgb(253,141,60)\"],[.625,\"rgb(254,178,76)\"],[.75,\"rgb(254,217,118)\"],[.875,\"rgb(255,237,160)\"],[1,\"rgb(255,255,204)\"]],Bluered:[[0,\"rgb(0,0,255)\"],[1,\"rgb(255,0,0)\"]],RdBu:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(106,137,247)\"],[.5,\"rgb(190,190,190)\"],[.6,\"rgb(220,170,132)\"],[.7,\"rgb(230,145,90)\"],[1,\"rgb(178,10,28)\"]],Reds:[[0,\"rgb(220,220,220)\"],[.2,\"rgb(245,195,157)\"],[.4,\"rgb(245,160,105)\"],[1,\"rgb(178,10,28)\"]],Blues:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(40,60,190)\"],[.5,\"rgb(70,100,245)\"],[.6,\"rgb(90,120,245)\"],[.7,\"rgb(106,137,247)\"],[1,\"rgb(220,220,220)\"]],Picnic:[[0,\"rgb(0,0,255)\"],[.1,\"rgb(51,153,255)\"],[.2,\"rgb(102,204,255)\"],[.3,\"rgb(153,204,255)\"],[.4,\"rgb(204,204,255)\"],[.5,\"rgb(255,255,255)\"],[.6,\"rgb(255,204,255)\"],[.7,\"rgb(255,153,255)\"],[.8,\"rgb(255,102,204)\"],[.9,\"rgb(255,102,102)\"],[1,\"rgb(255,0,0)\"]],Rainbow:[[0,\"rgb(150,0,90)\"],[.125,\"rgb(0,0,200)\"],[.25,\"rgb(0,25,255)\"],[.375,\"rgb(0,152,255)\"],[.5,\"rgb(44,255,150)\"],[.625,\"rgb(151,255,0)\"],[.75,\"rgb(255,234,0)\"],[.875,\"rgb(255,111,0)\"],[1,\"rgb(255,0,0)\"]],Portland:[[0,\"rgb(12,51,131)\"],[.25,\"rgb(10,136,186)\"],[.5,\"rgb(242,211,56)\"],[.75,\"rgb(242,143,56)\"],[1,\"rgb(217,30,30)\"]],Jet:[[0,\"rgb(0,0,131)\"],[.125,\"rgb(0,60,170)\"],[.375,\"rgb(5,255,255)\"],[.625,\"rgb(255,255,0)\"],[.875,\"rgb(250,0,0)\"],[1,\"rgb(128,0,0)\"]],Hot:[[0,\"rgb(0,0,0)\"],[.3,\"rgb(230,0,0)\"],[.6,\"rgb(255,210,0)\"],[1,\"rgb(255,255,255)\"]],Blackbody:[[0,\"rgb(0,0,0)\"],[.2,\"rgb(230,0,0)\"],[.4,\"rgb(230,210,0)\"],[.7,\"rgb(255,255,255)\"],[1,\"rgb(160,200,255)\"]],Earth:[[0,\"rgb(0,0,130)\"],[.1,\"rgb(0,180,180)\"],[.2,\"rgb(40,210,40)\"],[.4,\"rgb(230,230,50)\"],[.6,\"rgb(120,70,20)\"],[1,\"rgb(255,255,255)\"]],Electric:[[0,\"rgb(0,0,0)\"],[.15,\"rgb(30,0,100)\"],[.4,\"rgb(120,0,100)\"],[.6,\"rgb(160,90,0)\"],[.8,\"rgb(230,200,0)\"],[1,\"rgb(255,250,220)\"]],Viridis:[[0,\"#440154\"],[.06274509803921569,\"#48186a\"],[.12549019607843137,\"#472d7b\"],[.18823529411764706,\"#424086\"],[.25098039215686274,\"#3b528b\"],[.3137254901960784,\"#33638d\"],[.3764705882352941,\"#2c728e\"],[.4392156862745098,\"#26828e\"],[.5019607843137255,\"#21918c\"],[.5647058823529412,\"#1fa088\"],[.6274509803921569,\"#28ae80\"],[.6901960784313725,\"#3fbc73\"],[.7529411764705882,\"#5ec962\"],[.8156862745098039,\"#84d44b\"],[.8784313725490196,\"#addc30\"],[.9411764705882353,\"#d8e219\"],[1,\"#fde725\"]],Cividis:[[0,\"rgb(0,32,76)\"],[.058824,\"rgb(0,42,102)\"],[.117647,\"rgb(0,52,110)\"],[.176471,\"rgb(39,63,108)\"],[.235294,\"rgb(60,74,107)\"],[.294118,\"rgb(76,85,107)\"],[.352941,\"rgb(91,95,109)\"],[.411765,\"rgb(104,106,112)\"],[.470588,\"rgb(117,117,117)\"],[.529412,\"rgb(131,129,120)\"],[.588235,\"rgb(146,140,120)\"],[.647059,\"rgb(161,152,118)\"],[.705882,\"rgb(176,165,114)\"],[.764706,\"rgb(192,177,109)\"],[.823529,\"rgb(209,191,102)\"],[.882353,\"rgb(225,204,92)\"],[.941176,\"rgb(243,219,79)\"],[1,\"rgb(255,233,69)\"]]},a=i.RdBu;function o(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var i=t[r];if(2!==i.length||+i[0]<e||!n(i[1]).isValid())return!1;e=+i[0]}return!0}e.exports={scales:i,defaultScale:a,get:function(t,e){if(e||(e=a),!t)return e;function r(){try{t=i[t]||JSON.parse(t)}catch(r){t=e}}return\"string\"==typeof t&&(r(),\"string\"==typeof t&&r()),o(t)?t:e},isValid:function(t){return void 0!==i[t]||o(t)}}},{tinycolor2:537}],609:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=(t-r)/(n-r),o=a+e/(n-r),s=(a+o)/2;return\"left\"===i||\"bottom\"===i?a:\"center\"===i||\"middle\"===i?s:\"right\"===i||\"top\"===i?o:a<2/3-s?a:o>4/3-s?o:s}},{}],610:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[\"sw-resize\",\"s-resize\",\"se-resize\"],[\"w-resize\",\"move\",\"e-resize\"],[\"nw-resize\",\"n-resize\",\"ne-resize\"]];e.exports=function(t,e,r,a){return t=\"left\"===r?0:\"center\"===r?1:\"right\"===r?2:n.constrain(Math.floor(3*t),0,2),e=\"bottom\"===a?0:\"middle\"===a?1:\"top\"===a?2:n.constrain(Math.floor(3*e),0,2),i[e][t]}},{\"../../lib\":719}],611:[function(t,e,r){\"use strict\";var n=t(\"mouse-event-offset\"),i=t(\"has-hover\"),a=t(\"has-passive-events\"),o=t(\"../../lib\").removeElement,s=t(\"../../plots/cartesian/constants\"),l=e.exports={};l.align=t(\"./align\"),l.getCursor=t(\"./cursor\");var c=t(\"./unhover\");function u(){var t=document.createElement(\"div\");t.className=\"dragcover\";var e=t.style;return e.position=\"fixed\",e.left=0,e.right=0,e.top=0,e.bottom=0,e.zIndex=999999999,e.background=\"none\",document.body.appendChild(t),t}function h(t){return n(t.changedTouches?t.changedTouches[0]:t,document.body)}l.unhover=c.wrapped,l.unhoverRaw=c.raw,l.init=function(t){var e,r,n,c,f,p,d,g,v=t.gd,m=1,y=v._context.doubleClickDelay,x=t.element;v._mouseDownTime||(v._mouseDownTime=0),x.style.pointerEvents=\"all\",x.onmousedown=_,a?(x._ontouchstart&&x.removeEventListener(\"touchstart\",x._ontouchstart),x._ontouchstart=_,x.addEventListener(\"touchstart\",_,{passive:!1})):x.ontouchstart=_;var b=t.clampFn||function(t,e,r){return Math.abs(t)<r&&(t=0),Math.abs(e)<r&&(e=0),[t,e]};function _(a){v._dragged=!1,v._dragging=!0;var o=h(a);e=o[0],r=o[1],d=a.target,p=a,g=2===a.buttons||a.ctrlKey,\"undefined\"==typeof a.clientX&&\"undefined\"==typeof a.clientY&&(a.clientX=e,a.clientY=r),(n=(new Date).getTime())-v._mouseDownTime<y?m+=1:(m=1,v._mouseDownTime=n),t.prepFn&&t.prepFn(a,e,r),i&&!g?(f=u()).style.cursor=window.getComputedStyle(x).cursor:i||(f=document,c=window.getComputedStyle(document.documentElement).cursor,document.documentElement.style.cursor=window.getComputedStyle(x).cursor),document.addEventListener(\"mouseup\",k),document.addEventListener(\"touchend\",k),!1!==t.dragmode&&(a.preventDefault(),document.addEventListener(\"mousemove\",w),document.addEventListener(\"touchmove\",w))}function w(n){n.preventDefault();var i=h(n),a=t.minDrag||s.MINDRAG,o=b(i[0]-e,i[1]-r,a),c=o[0],u=o[1];(c||u)&&(v._dragged=!0,l.unhover(v)),v._dragged&&t.moveFn&&!g&&(v._dragdata={element:x,dx:c,dy:u},t.moveFn(c,u))}function k(e){if(delete v._dragdata,!1!==t.dragmode&&(e.preventDefault(),document.removeEventListener(\"mousemove\",w),document.removeEventListener(\"touchmove\",w)),document.removeEventListener(\"mouseup\",k),document.removeEventListener(\"touchend\",k),i?o(f):c&&(f.documentElement.style.cursor=c,c=null),v._dragging){if(v._dragging=!1,(new Date).getTime()-v._mouseDownTime>y&&(m=Math.max(m-1,1)),v._dragged)t.doneFn&&t.doneFn();else if(t.clickFn&&t.clickFn(m,p),!g){var r;try{r=new MouseEvent(\"click\",e)}catch(t){var n=h(e);(r=document.createEvent(\"MouseEvents\")).initMouseEvent(\"click\",e.bubbles,e.cancelable,e.view,e.detail,e.screenX,e.screenY,n[0],n[1],e.ctrlKey,e.altKey,e.shiftKey,e.metaKey,e.button,e.relatedTarget)}d.dispatchEvent(r)}v._dragging=!1,v._dragged=!1}else v._dragged=!1}},l.coverSlip=u},{\"../../lib\":719,\"../../plots/cartesian/constants\":773,\"./align\":609,\"./cursor\":610,\"./unhover\":612,\"has-hover\":410,\"has-passive-events\":411,\"mouse-event-offset\":436}],612:[function(t,e,r){\"use strict\";var n=t(\"../../lib/events\"),i=t(\"../../lib/throttle\"),a=t(\"../../lib/dom\").getGraphDiv,o=t(\"../fx/constants\"),s=e.exports={};s.wrapped=function(t,e,r){(t=a(t))._fullLayout&&i.clear(t._fullLayout._uid+o.HOVERID),s.raw(t,e,r)},s.raw=function(t,e){var r=t._fullLayout,i=t._hoverdata;e||(e={}),e.target&&!1===n.triggerHandler(t,\"plotly_beforehover\",e)||(r._hoverlayer.selectAll(\"g\").remove(),r._hoverlayer.selectAll(\"line\").remove(),r._hoverlayer.selectAll(\"circle\").remove(),t._hoverdata=void 0,e.target&&i&&t.emit(\"plotly_unhover\",{event:e,points:i}))}},{\"../../lib/dom\":708,\"../../lib/events\":709,\"../../lib/throttle\":744,\"../fx/constants\":626}],613:[function(t,e,r){\"use strict\";r.dash={valType:\"string\",values:[\"solid\",\"dot\",\"dash\",\"longdash\",\"dashdot\",\"longdashdot\"],dflt:\"solid\",editType:\"style\"}},{}],614:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../registry\"),s=t(\"../color\"),l=t(\"../colorscale\"),c=t(\"../../lib\"),u=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/xmlns_namespaces\"),f=t(\"../../constants/alignment\").LINE_SPACING,p=t(\"../../constants/interactions\").DESELECTDIM,d=t(\"../../traces/scatter/subtypes\"),g=t(\"../../traces/scatter/make_bubble_size_func\"),v=e.exports={};v.font=function(t,e,r,n){c.isPlainObject(e)&&(n=e.color,r=e.size,e=e.family),e&&t.style(\"font-family\",e),r+1&&t.style(\"font-size\",r+\"px\"),n&&t.call(s.fill,n)},v.setPosition=function(t,e,r){t.attr(\"x\",e).attr(\"y\",r)},v.setSize=function(t,e,r){t.attr(\"width\",e).attr(\"height\",r)},v.setRect=function(t,e,r,n,i){t.call(v.setPosition,e,r).call(v.setSize,n,i)},v.translatePoint=function(t,e,r,n){var a=r.c2p(t.x),o=n.c2p(t.y);return!!(i(a)&&i(o)&&e.node())&&(\"text\"===e.node().nodeName?e.attr(\"x\",a).attr(\"y\",o):e.attr(\"transform\",\"translate(\"+a+\",\"+o+\")\"),!0)},v.translatePoints=function(t,e,r){t.each(function(t){var i=n.select(this);v.translatePoint(t,i,e,r)})},v.hideOutsideRangePoint=function(t,e,r,n,i,a){e.attr(\"display\",r.isPtWithinRange(t,i)&&n.isPtWithinRange(t,a)?null:\"none\")},v.hideOutsideRangePoints=function(t,e){if(e._hasClipOnAxisFalse){var r=e.xaxis,i=e.yaxis;t.each(function(e){var a=e[0].trace,s=a.xcalendar,l=a.ycalendar,c=o.traceIs(a,\"bar-like\")?\".bartext\":\".point,.textpoint\";t.selectAll(c).each(function(t){v.hideOutsideRangePoint(t,n.select(this),r,i,s,l)})})}},v.crispRound=function(t,e,r){return e&&i(e)?t._context.staticPlot?e:e<1?1:Math.round(e):r||0},v.singleLineStyle=function(t,e,r,n,i){e.style(\"fill\",\"none\");var a=(((t||[])[0]||{}).trace||{}).line||{},o=r||a.width||0,l=i||a.dash||\"\";s.stroke(e,n||a.color),v.dashLine(e,l,o)},v.lineGroupStyle=function(t,e,r,i){t.style(\"fill\",\"none\").each(function(t){var a=(((t||[])[0]||{}).trace||{}).line||{},o=e||a.width||0,l=i||a.dash||\"\";n.select(this).call(s.stroke,r||a.color).call(v.dashLine,l,o)})},v.dashLine=function(t,e,r){r=+r||0,e=v.dashStyle(e,r),t.style({\"stroke-dasharray\":e,\"stroke-width\":r+\"px\"})},v.dashStyle=function(t,e){e=+e||1;var r=Math.max(e,3);return\"solid\"===t?t=\"\":\"dot\"===t?t=r+\"px,\"+r+\"px\":\"dash\"===t?t=3*r+\"px,\"+3*r+\"px\":\"longdash\"===t?t=5*r+\"px,\"+5*r+\"px\":\"dashdot\"===t?t=3*r+\"px,\"+r+\"px,\"+r+\"px,\"+r+\"px\":\"longdashdot\"===t&&(t=5*r+\"px,\"+2*r+\"px,\"+r+\"px,\"+2*r+\"px\"),t},v.singleFillStyle=function(t){var e=(((n.select(t.node()).data()[0]||[])[0]||{}).trace||{}).fillcolor;e&&t.call(s.fill,e)},v.fillGroupStyle=function(t){t.style(\"stroke-width\",0).each(function(t){var e=n.select(this);t[0].trace&&e.call(s.fill,t[0].trace.fillcolor)})};var m=t(\"./symbol_defs\");v.symbolNames=[],v.symbolFuncs=[],v.symbolNeedLines={},v.symbolNoDot={},v.symbolNoFill={},v.symbolList=[],Object.keys(m).forEach(function(t){var e=m[t];v.symbolList=v.symbolList.concat([e.n,t,e.n+100,t+\"-open\"]),v.symbolNames[e.n]=t,v.symbolFuncs[e.n]=e.f,e.needLine&&(v.symbolNeedLines[e.n]=!0),e.noDot?v.symbolNoDot[e.n]=!0:v.symbolList=v.symbolList.concat([e.n+200,t+\"-dot\",e.n+300,t+\"-open-dot\"]),e.noFill&&(v.symbolNoFill[e.n]=!0)});var y=v.symbolNames.length,x=\"M0,0.5L0.5,0L0,-0.5L-0.5,0Z\";function b(t,e){var r=t%100;return v.symbolFuncs[r](e)+(t>=200?x:\"\")}v.symbolNumber=function(t){if(\"string\"==typeof t){var e=0;t.indexOf(\"-open\")>0&&(e=100,t=t.replace(\"-open\",\"\")),t.indexOf(\"-dot\")>0&&(e+=200,t=t.replace(\"-dot\",\"\")),(t=v.symbolNames.indexOf(t))>=0&&(t+=e)}return t%100>=y||t>=400?0:Math.floor(Math.max(t,0))};var _={x1:1,x2:0,y1:0,y2:0},w={x1:0,x2:0,y1:1,y2:0},k=n.format(\"~.1f\"),T={radial:{node:\"radialGradient\"},radialreversed:{node:\"radialGradient\",reversed:!0},horizontal:{node:\"linearGradient\",attrs:_},horizontalreversed:{node:\"linearGradient\",attrs:_,reversed:!0},vertical:{node:\"linearGradient\",attrs:w},verticalreversed:{node:\"linearGradient\",attrs:w,reversed:!0}};v.gradient=function(t,e,r,i,o,l){for(var u=o.length,h=T[i],f=new Array(u),p=0;p<u;p++)h.reversed?f[u-1-p]=[k(100*(1-o[p][0])),o[p][1]]:f[p]=[k(100*o[p][0]),o[p][1]];var d=\"g\"+e._fullLayout._uid+\"-\"+r,g=e._fullLayout._defs.select(\".gradients\").selectAll(\"#\"+d).data([i+f.join(\";\")],c.identity);g.exit().remove(),g.enter().append(h.node).each(function(){var t=n.select(this);h.attrs&&t.attr(h.attrs),t.attr(\"id\",d);var e=t.selectAll(\"stop\").data(f);e.exit().remove(),e.enter().append(\"stop\"),e.each(function(t){var e=a(t[1]);n.select(this).attr({offset:t[0]+\"%\",\"stop-color\":s.tinyRGB(e),\"stop-opacity\":e.getAlpha()})})}),t.style(l,I(d,e)).style(l+\"-opacity\",null)},v.initGradients=function(t){c.ensureSingle(t._fullLayout._defs,\"g\",\"gradients\").selectAll(\"linearGradient,radialGradient\").remove()},v.pointStyle=function(t,e,r){if(t.size()){var i=v.makePointStyleFns(e);t.each(function(t){v.singlePointStyle(t,n.select(this),e,i,r)})}},v.singlePointStyle=function(t,e,r,n,i){var a=r.marker,o=a.line;if(e.style(\"opacity\",n.selectedOpacityFn?n.selectedOpacityFn(t):void 0===t.mo?a.opacity:t.mo),n.ms2mrc){var l;l=\"various\"===t.ms||\"various\"===a.size?3:n.ms2mrc(t.ms),t.mrc=l,n.selectedSizeFn&&(l=t.mrc=n.selectedSizeFn(t));var u=v.symbolNumber(t.mx||a.symbol)||0;t.om=u%200>=100,e.attr(\"d\",b(u,l))}var h,f,p,d=!1;if(t.so)p=o.outlierwidth,f=o.outliercolor,h=a.outliercolor;else{var g=(o||{}).width;p=(t.mlw+1||g+1||(t.trace?(t.trace.marker.line||{}).width:0)+1)-1||0,f=\"mlc\"in t?t.mlcc=n.lineScale(t.mlc):c.isArrayOrTypedArray(o.color)?s.defaultLine:o.color,c.isArrayOrTypedArray(a.color)&&(h=s.defaultLine,d=!0),h=\"mc\"in t?t.mcc=n.markerScale(t.mc):a.color||\"rgba(0,0,0,0)\",n.selectedColorFn&&(h=n.selectedColorFn(t))}if(t.om)e.call(s.stroke,h).style({\"stroke-width\":(p||1)+\"px\",fill:\"none\"});else{e.style(\"stroke-width\",p+\"px\");var m=a.gradient,y=t.mgt;if(y?d=!0:y=m&&m.type,Array.isArray(y)&&(y=y[0],T[y]||(y=0)),y&&\"none\"!==y){var x=t.mgc;x?d=!0:x=m.color;var _=r.uid;d&&(_+=\"-\"+t.i),v.gradient(e,i,_,y,[[0,x],[1,h]],\"fill\")}else s.fill(e,h);p&&s.stroke(e,f)}},v.makePointStyleFns=function(t){var e={},r=t.marker;return e.markerScale=v.tryColorscale(r,\"\"),e.lineScale=v.tryColorscale(r,\"line\"),o.traceIs(t,\"symbols\")&&(e.ms2mrc=d.isBubble(t)?g(t):function(){return(r.size||6)/2}),t.selectedpoints&&c.extendFlat(e,v.makeSelectedPointStyleFns(t)),e},v.makeSelectedPointStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.marker||{},a=r.marker||{},s=n.marker||{},l=i.opacity,u=a.opacity,h=s.opacity,f=void 0!==u,d=void 0!==h;(c.isArrayOrTypedArray(l)||f||d)&&(e.selectedOpacityFn=function(t){var e=void 0===t.mo?i.opacity:t.mo;return t.selected?f?u:e:d?h:p*e});var g=i.color,v=a.color,m=s.color;(v||m)&&(e.selectedColorFn=function(t){var e=t.mcc||g;return t.selected?v||e:m||e});var y=i.size,x=a.size,b=s.size,_=void 0!==x,w=void 0!==b;return o.traceIs(t,\"symbols\")&&(_||w)&&(e.selectedSizeFn=function(t){var e=t.mrc||y/2;return t.selected?_?x/2:e:w?b/2:e}),e},v.makeSelectedTextStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.textfont||{},a=r.textfont||{},o=n.textfont||{},l=i.color,c=a.color,u=o.color;return e.selectedTextColorFn=function(t){var e=t.tc||l;return t.selected?c||e:u||(c?e:s.addOpacity(e,p))},e},v.selectedPointStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=v.makeSelectedPointStyleFns(e),i=e.marker||{},a=[];r.selectedOpacityFn&&a.push(function(t,e){t.style(\"opacity\",r.selectedOpacityFn(e))}),r.selectedColorFn&&a.push(function(t,e){s.fill(t,r.selectedColorFn(e))}),r.selectedSizeFn&&a.push(function(t,e){var n=e.mx||i.symbol||0,a=r.selectedSizeFn(e);t.attr(\"d\",b(v.symbolNumber(n),a)),e.mrc2=a}),a.length&&t.each(function(t){for(var e=n.select(this),r=0;r<a.length;r++)a[r](e,t)})}},v.tryColorscale=function(t,e){var r=e?c.nestedProperty(t,e).get():t;if(r){var n=r.color;if((r.colorscale||r._colorAx)&&c.isArrayOrTypedArray(n))return l.makeColorScaleFuncFromTrace(r)}return c.identity};var A={start:1,end:-1,middle:0,bottom:1,top:-1};function M(t,e,r,i){var a=n.select(t.node().parentNode),o=-1!==e.indexOf(\"top\")?\"top\":-1!==e.indexOf(\"bottom\")?\"bottom\":\"middle\",s=-1!==e.indexOf(\"left\")?\"end\":-1!==e.indexOf(\"right\")?\"start\":\"middle\",l=i?i/.8+1:0,c=(u.lineCount(t)-1)*f+1,h=A[s]*l,p=.75*r+A[o]*l+(A[o]-1)*c*r/2;t.attr(\"text-anchor\",s),a.attr(\"transform\",\"translate(\"+h+\",\"+p+\")\")}function S(t,e){var r=t.ts||e.textfont.size;return i(r)&&r>0?r:0}v.textPointStyle=function(t,e,r){if(t.size()){var i;if(e.selectedpoints){var a=v.makeSelectedTextStyleFns(e);i=a.selectedTextColorFn}t.each(function(t){var a=n.select(this),o=c.extractOption(t,e,\"tx\",\"text\");if(o||0===o){var s=t.tp||e.textposition,l=S(t,e),h=i?i(t):t.tc||e.textfont.color;a.call(v.font,t.tf||e.textfont.family,l,h).text(o).call(u.convertToTspans,r).call(M,s,l,t.mrc)}else a.remove()})}},v.selectedTextStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=v.makeSelectedTextStyleFns(e);t.each(function(t){var i=n.select(this),a=r.selectedTextColorFn(t),o=t.tp||e.textposition,l=S(t,e);s.fill(i,a),M(i,o,l,t.mrc2||t.mrc)})}};var E=.5;function C(t,e,r,i){var a=t[0]-e[0],o=t[1]-e[1],s=r[0]-e[0],l=r[1]-e[1],c=Math.pow(a*a+o*o,E/2),u=Math.pow(s*s+l*l,E/2),h=(u*u*a-c*c*s)*i,f=(u*u*o-c*c*l)*i,p=3*u*(c+u),d=3*c*(c+u);return[[n.round(e[0]+(p&&h/p),2),n.round(e[1]+(p&&f/p),2)],[n.round(e[0]-(d&&h/d),2),n.round(e[1]-(d&&f/d),2)]]}v.smoothopen=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\");var r,n=\"M\"+t[0],i=[];for(r=1;r<t.length-1;r++)i.push(C(t[r-1],t[r],t[r+1],e));for(n+=\"Q\"+i[0][0]+\" \"+t[1],r=2;r<t.length-1;r++)n+=\"C\"+i[r-2][1]+\" \"+i[r-1][0]+\" \"+t[r];return n+=\"Q\"+i[t.length-3][1]+\" \"+t[t.length-1]},v.smoothclosed=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\")+\"Z\";var r,n=\"M\"+t[0],i=t.length-1,a=[C(t[i],t[0],t[1],e)];for(r=1;r<i;r++)a.push(C(t[r-1],t[r],t[r+1],e));for(a.push(C(t[i-1],t[i],t[0],e)),r=1;r<=i;r++)n+=\"C\"+a[r-1][1]+\" \"+a[r][0]+\" \"+t[r];return n+=\"C\"+a[i][1]+\" \"+a[0][0]+\" \"+t[0]+\"Z\"};var L={hv:function(t,e){return\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)},vh:function(t,e){return\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},hvh:function(t,e){return\"H\"+n.round((t[0]+e[0])/2,2)+\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},vhv:function(t,e){return\"V\"+n.round((t[1]+e[1])/2,2)+\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)}},P=function(t,e){return\"L\"+n.round(e[0],2)+\",\"+n.round(e[1],2)};v.steps=function(t){var e=L[t]||P;return function(t){for(var r=\"M\"+n.round(t[0][0],2)+\",\"+n.round(t[0][1],2),i=1;i<t.length;i++)r+=e(t[i-1],t[i]);return r}},v.makeTester=function(){var t=c.ensureSingleById(n.select(\"body\"),\"svg\",\"js-plotly-tester\",function(t){t.attr(h.svgAttrs).style({position:\"absolute\",left:\"-10000px\",top:\"-10000px\",width:\"9000px\",height:\"9000px\",\"z-index\":\"1\"})}),e=c.ensureSingle(t,\"path\",\"js-reference-point\",function(t){t.attr(\"d\",\"M0,0H1V1H0Z\").style({\"stroke-width\":0,fill:\"black\"})});v.tester=t,v.testref=e},v.savedBBoxes={};var O=0;function z(t){var e=t.getAttribute(\"data-unformatted\");if(null!==e)return e+t.getAttribute(\"data-math\")+t.getAttribute(\"text-anchor\")+t.getAttribute(\"style\")}function I(t,e){if(!t)return null;var r=e._context;return\"url('\"+(r._exportedPlot?\"\":r._baseUrl||\"\")+\"#\"+t+\"')\"}v.bBox=function(t,e,r){var i,a,o;if(r||(r=z(t)),r){if(i=v.savedBBoxes[r])return c.extendFlat({},i)}else if(1===t.childNodes.length){var s=t.childNodes[0];if(r=z(s)){var l=+s.getAttribute(\"x\")||0,h=+s.getAttribute(\"y\")||0,f=s.getAttribute(\"transform\");if(!f){var p=v.bBox(s,!1,r);return l&&(p.left+=l,p.right+=l),h&&(p.top+=h,p.bottom+=h),p}if(r+=\"~\"+l+\"~\"+h+\"~\"+f,i=v.savedBBoxes[r])return c.extendFlat({},i)}}e?a=t:(o=v.tester.node(),a=t.cloneNode(!0),o.appendChild(a)),n.select(a).attr(\"transform\",null).call(u.positionText,0,0);var d=a.getBoundingClientRect(),g=v.testref.node().getBoundingClientRect();e||o.removeChild(a);var m={height:d.height,width:d.width,left:d.left-g.left,top:d.top-g.top,right:d.right-g.left,bottom:d.bottom-g.top};return O>=1e4&&(v.savedBBoxes={},O=0),r&&(v.savedBBoxes[r]=m),O++,c.extendFlat({},m)},v.setClipUrl=function(t,e,r){t.attr(\"clip-path\",I(e,r))},v.getTranslate=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\btranslate\\((-?\\d*\\.?\\d*)[^-\\d]*(-?\\d*\\.?\\d*)[^\\d].*/,function(t,e,r){return[e,r].join(\" \")}).split(\" \");return{x:+e[0]||0,y:+e[1]||0}},v.setTranslate=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||0,r=r||0,a=a.replace(/(\\btranslate\\(.*?\\);?)/,\"\").trim(),a=(a+=\" translate(\"+e+\", \"+r+\")\").trim(),t[i](\"transform\",a),a},v.getScale=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\bscale\\((\\d*\\.?\\d*)[^\\d]*(\\d*\\.?\\d*)[^\\d].*/,function(t,e,r){return[e,r].join(\" \")}).split(\" \");return{x:+e[0]||1,y:+e[1]||1}},v.setScale=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||1,r=r||1,a=a.replace(/(\\bscale\\(.*?\\);?)/,\"\").trim(),a=(a+=\" scale(\"+e+\", \"+r+\")\").trim(),t[i](\"transform\",a),a};var D=/\\s*sc.*/;v.setPointGroupScale=function(t,e,r){if(e=e||1,r=r||1,t){var n=1===e&&1===r?\"\":\" scale(\"+e+\",\"+r+\")\";t.each(function(){var t=(this.getAttribute(\"transform\")||\"\").replace(D,\"\");t=(t+=n).trim(),this.setAttribute(\"transform\",t)})}};var R=/translate\\([^)]*\\)\\s*$/;v.setTextPointsScale=function(t,e,r){t&&t.each(function(){var t,i=n.select(this),a=i.select(\"text\");if(a.node()){var o=parseFloat(a.attr(\"x\")||0),s=parseFloat(a.attr(\"y\")||0),l=(i.attr(\"transform\")||\"\").match(R);t=1===e&&1===r?[]:[\"translate(\"+o+\",\"+s+\")\",\"scale(\"+e+\",\"+r+\")\",\"translate(\"+-o+\",\"+-s+\")\"],l&&t.push(l),i.attr(\"transform\",t.join(\" \"))}})}},{\"../../constants/alignment\":688,\"../../constants/interactions\":694,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../registry\":847,\"../../traces/scatter/make_bubble_size_func\":1128,\"../../traces/scatter/subtypes\":1135,\"../color\":593,\"../colorscale\":605,\"./symbol_defs\":615,d3:163,\"fast-isnumeric\":225,tinycolor2:537}],615:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports={circle:{n:0,f:function(t){var e=n.round(t,2);return\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"}},square:{n:1,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"}},diamond:{n:2,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"Z\"}},cross:{n:3,f:function(t){var e=n.round(.4*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H\"+e+\"V\"+r+\"H-\"+e+\"V\"+e+\"H-\"+r+\"V-\"+e+\"H-\"+e+\"V-\"+r+\"H\"+e+\"V-\"+e+\"H\"+r+\"Z\"}},x:{n:4,f:function(t){var e=n.round(.8*t/Math.sqrt(2),2),r=\"l\"+e+\",\"+e,i=\"l\"+e+\",-\"+e,a=\"l-\"+e+\",-\"+e,o=\"l-\"+e+\",\"+e;return\"M0,\"+e+r+i+a+i+a+o+a+o+r+o+r+\"Z\"}},\"triangle-up\":{n:5,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",\"+n.round(t/2,2)+\"H\"+e+\"L0,-\"+n.round(t,2)+\"Z\"}},\"triangle-down\":{n:6,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",-\"+n.round(t/2,2)+\"H\"+e+\"L0,\"+n.round(t,2)+\"Z\"}},\"triangle-left\":{n:7,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L-\"+n.round(t,2)+\",0Z\"}},\"triangle-right\":{n:8,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L\"+n.round(t,2)+\",0Z\"}},\"triangle-ne\":{n:9,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+r+\",-\"+e+\"H\"+e+\"V\"+r+\"Z\"}},\"triangle-se\":{n:10,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+e+\",-\"+r+\"V\"+e+\"H-\"+r+\"Z\"}},\"triangle-sw\":{n:11,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H-\"+e+\"V-\"+r+\"Z\"}},\"triangle-nw\":{n:12,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+e+\",\"+r+\"V-\"+e+\"H\"+r+\"Z\"}},pentagon:{n:13,f:function(t){var e=n.round(.951*t,2),r=n.round(.588*t,2),i=n.round(-t,2),a=n.round(-.309*t,2);return\"M\"+e+\",\"+a+\"L\"+r+\",\"+n.round(.809*t,2)+\"H-\"+r+\"L-\"+e+\",\"+a+\"L0,\"+i+\"Z\"}},hexagon:{n:14,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M\"+i+\",-\"+r+\"V\"+r+\"L0,\"+e+\"L-\"+i+\",\"+r+\"V-\"+r+\"L0,-\"+e+\"Z\"}},hexagon2:{n:15,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M-\"+r+\",\"+i+\"H\"+r+\"L\"+e+\",0L\"+r+\",-\"+i+\"H-\"+r+\"L-\"+e+\",0Z\"}},octagon:{n:16,f:function(t){var e=n.round(.924*t,2),r=n.round(.383*t,2);return\"M-\"+r+\",-\"+e+\"H\"+r+\"L\"+e+\",-\"+r+\"V\"+r+\"L\"+r+\",\"+e+\"H-\"+r+\"L-\"+e+\",\"+r+\"V-\"+r+\"Z\"}},star:{n:17,f:function(t){var e=1.4*t,r=n.round(.225*e,2),i=n.round(.951*e,2),a=n.round(.363*e,2),o=n.round(.588*e,2),s=n.round(-e,2),l=n.round(-.309*e,2),c=n.round(.118*e,2),u=n.round(.809*e,2);return\"M\"+r+\",\"+l+\"H\"+i+\"L\"+a+\",\"+c+\"L\"+o+\",\"+u+\"L0,\"+n.round(.382*e,2)+\"L-\"+o+\",\"+u+\"L-\"+a+\",\"+c+\"L-\"+i+\",\"+l+\"H-\"+r+\"L0,\"+s+\"Z\"}},hexagram:{n:18,f:function(t){var e=n.round(.66*t,2),r=n.round(.38*t,2),i=n.round(.76*t,2);return\"M-\"+i+\",0l-\"+r+\",-\"+e+\"h\"+i+\"l\"+r+\",-\"+e+\"l\"+r+\",\"+e+\"h\"+i+\"l-\"+r+\",\"+e+\"l\"+r+\",\"+e+\"h-\"+i+\"l-\"+r+\",\"+e+\"l-\"+r+\",-\"+e+\"h-\"+i+\"Z\"}},\"star-triangle-up\":{n:19,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M-\"+e+\",\"+r+o+e+\",\"+r+o+\"0,-\"+i+o+\"-\"+e+\",\"+r+\"Z\"}},\"star-triangle-down\":{n:20,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M\"+e+\",-\"+r+o+\"-\"+e+\",-\"+r+o+\"0,\"+i+o+e+\",-\"+r+\"Z\"}},\"star-square\":{n:21,f:function(t){var e=n.round(1.1*t,2),r=n.round(2*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",-\"+e+i+\"-\"+e+\",\"+e+i+e+\",\"+e+i+e+\",-\"+e+i+\"-\"+e+\",-\"+e+\"Z\"}},\"star-diamond\":{n:22,f:function(t){var e=n.round(1.4*t,2),r=n.round(1.9*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",0\"+i+\"0,\"+e+i+e+\",0\"+i+\"0,-\"+e+i+\"-\"+e+\",0Z\"}},\"diamond-tall\":{n:23,f:function(t){var e=n.round(.7*t,2),r=n.round(1.4*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},\"diamond-wide\":{n:24,f:function(t){var e=n.round(1.4*t,2),r=n.round(.7*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},hourglass:{n:25,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"L\"+e+\",-\"+e+\"H-\"+e+\"Z\"},noDot:!0},bowtie:{n:26,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"V-\"+e+\"L-\"+e+\",\"+e+\"V-\"+e+\"Z\"},noDot:!0},\"circle-cross\":{n:27,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"circle-x\":{n:28,f:function(t){var e=n.round(t,2),r=n.round(t/Math.sqrt(2),2);return\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"square-cross\":{n:29,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"square-x\":{n:30,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"diamond-cross\":{n:31,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM0,-\"+e+\"V\"+e+\"M-\"+e+\",0H\"+e},needLine:!0,noDot:!0},\"diamond-x\":{n:32,f:function(t){var e=n.round(1.3*t,2),r=n.round(.65*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM-\"+r+\",-\"+r+\"L\"+r+\",\"+r+\"M-\"+r+\",\"+r+\"L\"+r+\",-\"+r},needLine:!0,noDot:!0},\"cross-thin\":{n:33,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"x-thin\":{n:34,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},asterisk:{n:35,f:function(t){var e=n.round(1.2*t,2),r=n.round(.85*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r},needLine:!0,noDot:!0,noFill:!0},hash:{n:36,f:function(t){var e=n.round(t/2,2),r=n.round(t,2);return\"M\"+e+\",\"+r+\"V-\"+r+\"m-\"+r+\",0V\"+r+\"M\"+r+\",\"+e+\"H-\"+r+\"m0,-\"+r+\"H\"+r},needLine:!0,noFill:!0},\"y-up\":{n:37,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",\"+i+\"L0,0M\"+e+\",\"+i+\"L0,0M0,-\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-down\":{n:38,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",-\"+i+\"L0,0M\"+e+\",-\"+i+\"L0,0M0,\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-left\":{n:39,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M\"+i+\",\"+e+\"L0,0M\"+i+\",-\"+e+\"L0,0M-\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-right\":{n:40,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+i+\",\"+e+\"L0,0M-\"+i+\",-\"+e+\"L0,0M\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"line-ew\":{n:41,f:function(t){var e=n.round(1.4*t,2);return\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ns\":{n:42,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ne\":{n:43,f:function(t){var e=n.round(t,2);return\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-nw\":{n:44,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e},needLine:!0,noDot:!0,noFill:!0}}},{d3:163}],616:[function(t,e,r){\"use strict\";e.exports={visible:{valType:\"boolean\",editType:\"calc\"},type:{valType:\"enumerated\",values:[\"percent\",\"constant\",\"sqrt\",\"data\"],editType:\"calc\"},symmetric:{valType:\"boolean\",editType:\"calc\"},array:{valType:\"data_array\",editType:\"calc\"},arrayminus:{valType:\"data_array\",editType:\"calc\"},value:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},valueminus:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},traceref:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},tracerefminus:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},copy_ystyle:{valType:\"boolean\",editType:\"plot\"},copy_zstyle:{valType:\"boolean\",editType:\"style\"},color:{valType:\"color\",editType:\"style\"},thickness:{valType:\"number\",min:0,dflt:2,editType:\"style\"},width:{valType:\"number\",min:0,editType:\"plot\"},editType:\"calc\",_deprecated:{opacity:{valType:\"number\",editType:\"style\"}}}},{}],617:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=t(\"./compute_error\");function l(t,e,r,i){var l=e[\"error_\"+i]||{},c=[];if(l.visible&&-1!==[\"linear\",\"log\"].indexOf(r.type)){for(var u=s(l),h=0;h<t.length;h++){var f=t[h],p=f.i;if(void 0===p)p=h;else if(null===p)continue;var d=f[i];if(n(r.c2l(d))){var g=u(d,p);if(n(g[0])&&n(g[1])){var v=f[i+\"s\"]=d-g[0],m=f[i+\"h\"]=d+g[1];c.push(v,m)}}}var y=r._id,x=e._extremes[y],b=a.findExtremes(r,c,o.extendFlat({tozero:x.opts.tozero},{padded:!0}));x.min=x.min.concat(b.min),x.max=x.max.concat(b.max)}}e.exports=function(t){for(var e=t.calcdata,r=0;r<e.length;r++){var n=e[r],o=n[0].trace;if(!0===o.visible&&i.traceIs(o,\"errorBarsOK\")){var s=a.getFromId(t,o.xaxis),c=a.getFromId(t,o.yaxis);l(n,o,s,\"x\"),l(n,o,c,\"y\")}}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./compute_error\":618,\"fast-isnumeric\":225}],618:[function(t,e,r){\"use strict\";function n(t,e){return\"percent\"===t?function(t){return Math.abs(t*e/100)}:\"constant\"===t?function(){return Math.abs(e)}:\"sqrt\"===t?function(t){return Math.sqrt(Math.abs(t))}:void 0}e.exports=function(t){var e=t.type,r=t.symmetric;if(\"data\"===e){var i=t.array||[];if(r)return function(t,e){var r=+i[e];return[r,r]};var a=t.arrayminus||[];return function(t,e){var r=+i[e],n=+a[e];return isNaN(r)&&isNaN(n)?[NaN,NaN]:[n||0,r||0]}}var o=n(e,t.value),s=n(e,t.valueminus);return r||void 0===t.valueminus?function(t){var e=o(t);return[e,e]}:function(t){return[s(t),o(t)]}}},{}],619:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../plot_api/plot_template\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){var c=\"error_\"+l.axis,u=o.newContainer(e,c),h=t[c]||{};function f(t,e){return a.coerce(h,u,s,t,e)}if(!1!==f(\"visible\",void 0!==h.array||void 0!==h.value||\"sqrt\"===h.type)){var p=f(\"type\",\"array\"in h?\"data\":\"percent\"),d=!0;\"sqrt\"!==p&&(d=f(\"symmetric\",!((\"data\"===p?\"arrayminus\":\"valueminus\")in h))),\"data\"===p?(f(\"array\"),f(\"traceref\"),d||(f(\"arrayminus\"),f(\"tracerefminus\"))):\"percent\"!==p&&\"constant\"!==p||(f(\"value\"),d||f(\"valueminus\"));var g=\"copy_\"+l.inherit+\"style\";if(l.inherit)(e[\"error_\"+l.inherit]||{}).visible&&f(g,!(h.color||n(h.thickness)||n(h.width)));l.inherit&&u[g]||(f(\"color\",r),f(\"thickness\"),f(\"width\",i.traceIs(e,\"gl3d\")?0:4))}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../registry\":847,\"./attributes\":616,\"fast-isnumeric\":225}],620:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"./attributes\"),o={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a)};delete o.error_x.copy_zstyle,delete o.error_y.copy_zstyle,delete o.error_y.copy_ystyle;var s={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a),error_z:n.extendFlat({},a)};delete s.error_x.copy_ystyle,delete s.error_y.copy_ystyle,delete s.error_z.copy_ystyle,delete s.error_z.copy_zstyle,e.exports={moduleType:\"component\",name:\"errorbars\",schema:{traces:{scatter:o,bar:o,histogram:o,scatter3d:i(s,\"calc\",\"nested\"),scattergl:i(o,\"calc\",\"nested\")}},supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),makeComputeError:t(\"./compute_error\"),plot:t(\"./plot\"),style:t(\"./style\"),hoverInfo:function(t,e,r){(e.error_y||{}).visible&&(r.yerr=t.yh-t.y,e.error_y.symmetric||(r.yerrneg=t.y-t.ys));(e.error_x||{}).visible&&(r.xerr=t.xh-t.x,e.error_x.symmetric||(r.xerrneg=t.x-t.xs))}}},{\"../../lib\":719,\"../../plot_api/edit_types\":750,\"./attributes\":616,\"./calc\":617,\"./compute_error\":618,\"./defaults\":619,\"./plot\":621,\"./style\":622}],621:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../drawing\"),o=t(\"../../traces/scatter/subtypes\");e.exports=function(t,e,r,s){var l=r.xaxis,c=r.yaxis,u=s&&s.duration>0;e.each(function(e){var h,f=e[0].trace,p=f.error_x||{},d=f.error_y||{};f.ids&&(h=function(t){return t.id});var g=o.hasMarkers(f)&&f.marker.maxdisplayed>0;d.visible||p.visible||(e=[]);var v=n.select(this).selectAll(\"g.errorbar\").data(e,h);if(v.exit().remove(),e.length){p.visible||v.selectAll(\"path.xerror\").remove(),d.visible||v.selectAll(\"path.yerror\").remove(),v.style(\"opacity\",1);var m=v.enter().append(\"g\").classed(\"errorbar\",!0);u&&m.style(\"opacity\",0).transition().duration(s.duration).style(\"opacity\",1),a.setClipUrl(v,r.layerClipId,t),v.each(function(t){var e=n.select(this),r=function(t,e,r){var n={x:e.c2p(t.x),y:r.c2p(t.y)};void 0!==t.yh&&(n.yh=r.c2p(t.yh),n.ys=r.c2p(t.ys),i(n.ys)||(n.noYS=!0,n.ys=r.c2p(t.ys,!0)));void 0!==t.xh&&(n.xh=e.c2p(t.xh),n.xs=e.c2p(t.xs),i(n.xs)||(n.noXS=!0,n.xs=e.c2p(t.xs,!0)));return n}(t,l,c);if(!g||t.vis){var a,o=e.select(\"path.yerror\");if(d.visible&&i(r.x)&&i(r.yh)&&i(r.ys)){var h=d.width;a=\"M\"+(r.x-h)+\",\"+r.yh+\"h\"+2*h+\"m-\"+h+\",0V\"+r.ys,r.noYS||(a+=\"m-\"+h+\",0h\"+2*h),!o.size()?o=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"yerror\",!0):u&&(o=o.transition().duration(s.duration).ease(s.easing)),o.attr(\"d\",a)}else o.remove();var f=e.select(\"path.xerror\");if(p.visible&&i(r.y)&&i(r.xh)&&i(r.xs)){var v=(p.copy_ystyle?d:p).width;a=\"M\"+r.xh+\",\"+(r.y-v)+\"v\"+2*v+\"m0,-\"+v+\"H\"+r.xs,r.noXS||(a+=\"m0,-\"+v+\"v\"+2*v),!f.size()?f=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"xerror\",!0):u&&(f=f.transition().duration(s.duration).ease(s.easing)),f.attr(\"d\",a)}else f.remove()}})}})}},{\"../../traces/scatter/subtypes\":1135,\"../drawing\":614,d3:163,\"fast-isnumeric\":225}],622:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\");e.exports=function(t){t.each(function(t){var e=t[0].trace,r=e.error_y||{},a=e.error_x||{},o=n.select(this);o.selectAll(\"path.yerror\").style(\"stroke-width\",r.thickness+\"px\").call(i.stroke,r.color),a.copy_ystyle&&(a=r),o.selectAll(\"path.xerror\").style(\"stroke-width\",a.thickness+\"px\").call(i.stroke,a.color)})}},{\"../color\":593,d3:163}],623:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./layout_attributes\").hoverlabel,a=t(\"../../lib/extend\").extendFlat;e.exports={hoverlabel:{bgcolor:a({},i.bgcolor,{arrayOk:!0}),bordercolor:a({},i.bordercolor,{arrayOk:!0}),font:n({arrayOk:!0,editType:\"none\"}),align:a({},i.align,{arrayOk:!0}),namelength:a({},i.namelength,{arrayOk:!0}),editType:\"none\"}}},{\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"./layout_attributes\":633}],624:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");function a(t,e,r,i){i=i||n.identity,Array.isArray(t)&&(e[0][r]=i(t))}e.exports=function(t){var e=t.calcdata,r=t._fullLayout;function o(t){return function(e){return n.coerceHoverinfo({hoverinfo:e},{_module:t._module},r)}}for(var s=0;s<e.length;s++){var l=e[s],c=l[0].trace;if(!i.traceIs(c,\"pie-like\")){var u=i.traceIs(c,\"2dMap\")?a:n.fillArray;u(c.hoverinfo,l,\"hi\",o(c)),c.hovertemplate&&u(c.hovertemplate,l,\"ht\"),c.hoverlabel&&(u(c.hoverlabel.bgcolor,l,\"hbg\"),u(c.hoverlabel.bordercolor,l,\"hbc\"),u(c.hoverlabel.font.size,l,\"hts\"),u(c.hoverlabel.font.color,l,\"htc\"),u(c.hoverlabel.font.family,l,\"htf\"),u(c.hoverlabel.namelength,l,\"hnl\"),u(c.hoverlabel.align,l,\"hta\"))}}}},{\"../../lib\":719,\"../../registry\":847}],625:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./hover\").hover;e.exports=function(t,e,r){var a=n.getComponentMethod(\"annotations\",\"onClick\")(t,t._hoverdata);function o(){t.emit(\"plotly_click\",{points:t._hoverdata,event:e})}void 0!==r&&i(t,e,r,!0),t._hoverdata&&e&&e.target&&(a&&a.then?a.then(o):o(),e.stopImmediatePropagation&&e.stopImmediatePropagation())}},{\"../../registry\":847,\"./hover\":629}],626:[function(t,e,r){\"use strict\";e.exports={YANGLE:60,HOVERARROWSIZE:6,HOVERTEXTPAD:3,HOVERFONTSIZE:13,HOVERFONT:\"Arial, sans-serif\",HOVERMINTIME:50,HOVERID:\"-hover\"}},{}],627:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./hoverlabel_defaults\");e.exports=function(t,e,r,o){var s=n.extendFlat({},o.hoverlabel);e.hovertemplate&&(s.namelength=-1),a(t,e,function(r,a){return n.coerce(t,e,i,r,a)},s)}},{\"../../lib\":719,\"./attributes\":623,\"./hoverlabel_defaults\":630}],628:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");r.getSubplot=function(t){return t.subplot||t.xaxis+t.yaxis||t.geo},r.isTraceInSubplots=function(t,e){if(\"splom\"===t.type){for(var n=t.xaxes||[],i=t.yaxes||[],a=0;a<n.length;a++)for(var o=0;o<i.length;o++)if(-1!==e.indexOf(n[a]+i[o]))return!0;return!1}return-1!==e.indexOf(r.getSubplot(t))},r.flat=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=e;return r},r.p2c=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=t[n].p2c(e);return r},r.getDistanceFunction=function(t,e,n,i){return\"closest\"===t?i||r.quadrature(e,n):\"x\"===t?e:n},r.getClosest=function(t,e,r){if(!1!==r.index)r.index>=0&&r.index<t.length?r.distance=0:r.index=!1;else for(var n=0;n<t.length;n++){var i=e(t[n]);i<=r.distance&&(r.index=n,r.distance=i)}return r},r.inbox=function(t,e,r){return t*e<0||0===t?r:1/0},r.quadrature=function(t,e){return function(r){var n=t(r),i=e(r);return Math.sqrt(n*n+i*i)}},r.makeEventData=function(t,e,n){var i=\"index\"in t?t.index:t.pointNumber,a={data:e._input,fullData:e,curveNumber:e.index,pointNumber:i};if(e._indexToPoints){var o=e._indexToPoints[i];1===o.length?a.pointIndex=o[0]:a.pointIndices=o}else a.pointIndex=i;return e._module.eventData?a=e._module.eventData(a,t,e,n,i):(\"xVal\"in t?a.x=t.xVal:\"x\"in t&&(a.x=t.x),\"yVal\"in t?a.y=t.yVal:\"y\"in t&&(a.y=t.y),t.xa&&(a.xaxis=t.xa),t.ya&&(a.yaxis=t.ya),void 0!==t.zLabelVal&&(a.z=t.zLabelVal)),r.appendArrayPointValue(a,e,i),a},r.appendArrayPointValue=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){var u=o(n.nestedProperty(e,l).get(),r);void 0!==u&&(t[c]=u)}}},r.appendArrayMultiPointValues=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){for(var u=n.nestedProperty(e,l).get(),h=new Array(r.length),f=0;f<r.length;f++)h[f]=o(u,r[f]);t[c]=h}}};var i={ids:\"id\",locations:\"location\",labels:\"label\",values:\"value\",\"marker.colors\":\"color\",parents:\"parent\"};function a(t){return i[t]||t}function o(t,e){return Array.isArray(e)?Array.isArray(t)&&Array.isArray(t[e[0]])?t[e[0]][e[1]]:void 0:t[e]}},{\"../../lib\":719}],629:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../lib\"),s=t(\"../../lib/events\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib/override_cursor\"),u=t(\"../drawing\"),h=t(\"../color\"),f=t(\"../dragelement\"),p=t(\"../../plots/cartesian/axes\"),d=t(\"../../registry\"),g=t(\"./helpers\"),v=t(\"./constants\"),m=v.YANGLE,y=Math.PI*m/180,x=1/Math.sin(y),b=Math.cos(y),_=Math.sin(y),w=v.HOVERARROWSIZE,k=v.HOVERTEXTPAD;r.hover=function(t,e,r,a){t=o.getGraphDiv(t),o.throttle(t._fullLayout._uid+v.HOVERID,v.HOVERMINTIME,function(){!function(t,e,r,a){r||(r=\"xy\");var l=Array.isArray(r)?r:[r],u=t._fullLayout,v=u._plots||[],m=v[r],y=u._has(\"cartesian\");if(m){var b=m.overlays.map(function(t){return t.id});l=l.concat(b)}for(var _=l.length,w=new Array(_),k=new Array(_),T=!1,L=0;L<_;L++){var P=l[L],O=v[P];if(O)T=!0,w[L]=p.getFromId(t,O.xaxis._id),k[L]=p.getFromId(t,O.yaxis._id);else{var z=u[P]._subplot;w[L]=z.xaxis,k[L]=z.yaxis}}var I=e.hovermode||u.hovermode;I&&!T&&(I=\"closest\");if(-1===[\"x\",\"y\",\"closest\"].indexOf(I)||!t.calcdata||t.querySelector(\".zoombox\")||t._dragging)return f.unhoverRaw(t,e);var D,R,F,B,N,j,U,V,q,H,G,Y,W,X=-1===u.hoverdistance?1/0:u.hoverdistance,Z=-1===u.spikedistance?1/0:u.spikedistance,J=[],K=[],$={hLinePoint:null,vLinePoint:null},Q=!1;if(Array.isArray(e))for(I=\"array\",F=0;F<e.length;F++)(N=t.calcdata[e[F].curveNumber||0])&&(j=N[0].trace,\"skip\"!==N[0].trace.hoverinfo&&(K.push(N),\"h\"===j.orientation&&(Q=!0)));else{for(B=0;B<t.calcdata.length;B++)N=t.calcdata[B],\"skip\"!==(j=N[0].trace).hoverinfo&&g.isTraceInSubplots(j,l)&&(K.push(N),\"h\"===j.orientation&&(Q=!0));var tt,et,rt=!e.target;if(rt)tt=\"xpx\"in e?e.xpx:w[0]._length/2,et=\"ypx\"in e?e.ypx:k[0]._length/2;else{if(!1===s.triggerHandler(t,\"plotly_beforehover\",e))return;var nt=e.target.getBoundingClientRect();if(tt=e.clientX-nt.left,et=e.clientY-nt.top,tt<0||tt>w[0]._length||et<0||et>k[0]._length)return f.unhoverRaw(t,e)}if(e.pointerX=tt+w[0]._offset,e.pointerY=et+k[0]._offset,D=\"xval\"in e?g.flat(l,e.xval):g.p2c(w,tt),R=\"yval\"in e?g.flat(l,e.yval):g.p2c(k,et),!i(D[0])||!i(R[0]))return o.warn(\"Fx.hover failed\",e,t),f.unhoverRaw(t,e)}var it=1/0;for(B=0;B<K.length;B++)if((N=K[B])&&N[0]&&N[0].trace&&!0===(j=N[0].trace).visible&&0!==j._length&&-1===[\"carpet\",\"contourcarpet\"].indexOf(j._module.name)){if(\"splom\"===j.type?U=l[V=0]:(U=g.getSubplot(j),V=l.indexOf(U)),q=I,Y={cd:N,trace:j,xa:w[V],ya:k[V],maxHoverDistance:X,maxSpikeDistance:Z,index:!1,distance:Math.min(it,X),spikeDistance:1/0,xSpike:void 0,ySpike:void 0,color:h.defaultLine,name:j.name,x0:void 0,x1:void 0,y0:void 0,y1:void 0,xLabelVal:void 0,yLabelVal:void 0,zLabelVal:void 0,text:void 0},u[U]&&(Y.subplot=u[U]._subplot),u._splomScenes&&u._splomScenes[j.uid]&&(Y.scene=u._splomScenes[j.uid]),W=J.length,\"array\"===q){var at=e[B];\"pointNumber\"in at?(Y.index=at.pointNumber,q=\"closest\"):(q=\"\",\"xval\"in at&&(H=at.xval,q=\"x\"),\"yval\"in at&&(G=at.yval,q=q?\"closest\":\"y\"))}else H=D[V],G=R[V];if(0!==X)if(j._module&&j._module.hoverPoints){var ot=j._module.hoverPoints(Y,H,G,q,u._hoverlayer);if(ot)for(var st,lt=0;lt<ot.length;lt++)st=ot[lt],i(st.x0)&&i(st.y0)&&J.push(S(st,I))}else o.log(\"Unrecognized trace type in hover:\",j);if(\"closest\"===I&&J.length>W&&(J.splice(0,W),it=J[0].distance),y&&0!==Z&&0===J.length){Y.distance=Z,Y.index=!1;var ct=j._module.hoverPoints(Y,H,G,\"closest\",u._hoverlayer);if(ct&&(ct=ct.filter(function(t){return t.spikeDistance<=Z})),ct&&ct.length){var ut,ht=ct.filter(function(t){return t.xa.showspikes});if(ht.length){var ft=ht[0];i(ft.x0)&&i(ft.y0)&&(ut=vt(ft),(!$.vLinePoint||$.vLinePoint.spikeDistance>ut.spikeDistance)&&($.vLinePoint=ut))}var pt=ct.filter(function(t){return t.ya.showspikes});if(pt.length){var dt=pt[0];i(dt.x0)&&i(dt.y0)&&(ut=vt(dt),(!$.hLinePoint||$.hLinePoint.spikeDistance>ut.spikeDistance)&&($.hLinePoint=ut))}}}}function gt(t,e){for(var r,n=null,i=1/0,a=0;a<t.length;a++)(r=t[a].spikeDistance)<i&&r<=e&&(n=t[a],i=r);return n}function vt(t){return t?{xa:t.xa,ya:t.ya,x:void 0!==t.xSpike?t.xSpike:(t.x0+t.x1)/2,y:void 0!==t.ySpike?t.ySpike:(t.y0+t.y1)/2,distance:t.distance,spikeDistance:t.spikeDistance,curveNumber:t.trace.index,color:t.color,pointNumber:t.index}:null}var mt={fullLayout:u,container:u._hoverlayer,outerContainer:u._paperdiv,event:e},yt=t._spikepoints,xt={vLinePoint:$.vLinePoint,hLinePoint:$.hLinePoint};if(t._spikepoints=xt,y&&0!==Z&&0!==J.length){var bt=J.filter(function(t){return t.ya.showspikes}),_t=gt(bt,Z);$.hLinePoint=vt(_t);var wt=J.filter(function(t){return t.xa.showspikes}),kt=gt(wt,Z);$.vLinePoint=vt(kt)}if(0===J.length){var Tt=f.unhoverRaw(t,e);return!y||null===$.hLinePoint&&null===$.vLinePoint||C(yt)&&E($,mt),Tt}y&&C(yt)&&E($,mt);J.sort(function(t,e){return t.distance-e.distance});var At=t._hoverdata,Mt=[];for(F=0;F<J.length;F++){var St=J[F],Et=g.makeEventData(St,St.trace,St.cd);if(!1!==St.hovertemplate){var Ct=!1;St.cd[St.index]&&St.cd[St.index].ht&&(Ct=St.cd[St.index].ht),St.hovertemplate=Ct||St.trace.hovertemplate||!1}St.eventData=[Et],Mt.push(Et)}t._hoverdata=Mt;var Lt=\"y\"===I&&(K.length>1||J.length>1)||\"closest\"===I&&Q&&J.length>1,Pt=h.combine(u.plot_bgcolor||h.background,u.paper_bgcolor),Ot={hovermode:I,rotateLabels:Lt,bgColor:Pt,container:u._hoverlayer,outerContainer:u._paperdiv,commonLabelOpts:u.hoverlabel,hoverdistance:u.hoverdistance},zt=A(J,Ot,t);if(function(t,e,r){var n,i,a,o,s,l,c,u=0,h=1,f=t.size(),p=new Array(f),d=0;function g(t){var e=t[0],r=t[t.length-1];if(i=e.pmin-e.pos-e.dp+e.size,a=r.pos+r.dp+r.size-e.pmax,i>.01){for(s=t.length-1;s>=0;s--)t[s].dp+=i;n=!1}if(!(a<.01)){if(i<-.01){for(s=t.length-1;s>=0;s--)t[s].dp-=a;n=!1}if(n){var c=0;for(o=0;o<t.length;o++)(l=t[o]).pos+l.dp+l.size>e.pmax&&c++;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos>e.pmax-1&&(l.del=!0,c--);for(o=0;o<t.length&&!(c<=0);o++)if((l=t[o]).pos<e.pmin+1)for(l.del=!0,c--,a=2*l.size,s=t.length-1;s>=0;s--)t[s].dp-=a;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos+l.dp+l.size>e.pmax&&(l.del=!0,c--)}}}for(t.each(function(t){var n=t[e],i=\"x\"===n._id.charAt(0),a=n.range;0===d&&a&&a[0]>a[1]!==i&&(h=-1),p[d++]=[{datum:t,traceIndex:t.trace.index,dp:0,pos:t.pos,posref:t.posref,size:t.by*(i?x:1)/2,pmin:0,pmax:i?r.width:r.height}]}),p.sort(function(t,e){return t[0].posref-e[0].posref||h*(e[0].traceIndex-t[0].traceIndex)});!n&&u<=f;){for(u++,n=!0,o=0;o<p.length-1;){var v=p[o],m=p[o+1],y=v[v.length-1],b=m[0];if((i=y.pos+y.dp+y.size-b.pos-b.dp+b.size)>.01&&y.pmin===b.pmin&&y.pmax===b.pmax){for(s=m.length-1;s>=0;s--)m[s].dp+=i;for(v.push.apply(v,m),p.splice(o+1,1),c=0,s=v.length-1;s>=0;s--)c+=v[s].dp;for(a=c/v.length,s=v.length-1;s>=0;s--)v[s].dp-=a;n=!1}else o++}p.forEach(g)}for(o=p.length-1;o>=0;o--){var _=p[o];for(s=_.length-1;s>=0;s--){var w=_[s],k=w.datum;k.offset=w.dp,k.del=w.del}}}(zt,Lt?\"xa\":\"ya\",u),M(zt,Lt),e.target&&e.target.tagName){var It=d.getComponentMethod(\"annotations\",\"hasClickToShow\")(t,Mt);c(n.select(e.target),It?\"pointer\":\"\")}if(!e.target||a||!function(t,e,r){if(!r||r.length!==t._hoverdata.length)return!0;for(var n=r.length-1;n>=0;n--){var i=r[n],a=t._hoverdata[n];if(i.curveNumber!==a.curveNumber||String(i.pointNumber)!==String(a.pointNumber)||String(i.pointNumbers)!==String(a.pointNumbers))return!0}return!1}(t,0,At))return;At&&t.emit(\"plotly_unhover\",{event:e,points:At});t.emit(\"plotly_hover\",{event:e,points:t._hoverdata,xaxes:w,yaxes:k,xvals:D,yvals:R})}(t,e,r,a)})},r.loneHover=function(t,e){var r=!0;Array.isArray(t)||(r=!1,t=[t]);var i=t.map(function(t){return{color:t.color||h.defaultLine,x0:t.x0||t.x||0,x1:t.x1||t.x||0,y0:t.y0||t.y||0,y1:t.y1||t.y||0,xLabel:t.xLabel,yLabel:t.yLabel,zLabel:t.zLabel,text:t.text,name:t.name,idealAlign:t.idealAlign,borderColor:t.borderColor,fontFamily:t.fontFamily,fontSize:t.fontSize,fontColor:t.fontColor,nameLength:t.nameLength,textAlign:t.textAlign,trace:t.trace||{index:0,hoverinfo:\"\"},xa:{_offset:0},ya:{_offset:0},index:0,hovertemplate:t.hovertemplate||!1,eventData:t.eventData||!1,hovertemplateLabels:t.hovertemplateLabels||!1}}),a=n.select(e.container),o=e.outerContainer?n.select(e.outerContainer):a,s={hovermode:\"closest\",rotateLabels:!1,bgColor:e.bgColor||h.background,container:a,outerContainer:o},l=A(i,s,e.gd),c=0,u=0;return l.sort(function(t,e){return t.y0-e.y0}).each(function(t,r){var n=t.y0-t.by/2;t.offset=n-5<c?c-n+5:0,c=n+t.by+t.offset,r===e.anchorIndex&&(u=t.offset)}).each(function(t){t.offset-=u}),M(l,s.rotateLabels),r?l:l.node()};var T=/<extra>([\\s\\S]*)<\\/extra>/;function A(t,e,r){var i=r._fullLayout,a=e.hovermode,s=e.rotateLabels,c=e.bgColor,f=e.container,p=e.outerContainer,d=e.commonLabelOpts||{},g=e.fontFamily||v.HOVERFONT,y=e.fontSize||v.HOVERFONTSIZE,x=t[0],b=x.xa,_=x.ya,A=\"y\"===a?\"yLabel\":\"xLabel\",M=x[A],S=(String(M)||\"\").split(\" \")[0],E=p.node().getBoundingClientRect(),C=E.top,P=E.width,O=E.height,z=void 0!==M&&x.distance<=e.hoverdistance&&(\"x\"===a||\"y\"===a);if(z){var I,D,R=!0;for(I=0;I<t.length;I++)if(R&&void 0===t[I].zLabel&&(R=!1),D=t[I].hoverinfo||t[I].trace.hoverinfo){var F=Array.isArray(D)?D:D.split(\"+\");if(-1===F.indexOf(\"all\")&&-1===F.indexOf(a)){z=!1;break}}R&&(z=!1)}var B=f.selectAll(\"g.axistext\").data(z?[0]:[]);B.enter().append(\"g\").classed(\"axistext\",!0),B.exit().remove(),B.each(function(){var e=n.select(this),i=o.ensureSingle(e,\"path\",\"\",function(t){t.style({\"stroke-width\":\"1px\"})}),s=o.ensureSingle(e,\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),c=d.bgcolor||h.defaultLine,f=d.bordercolor||h.contrast(c),p=h.contrast(c);i.style({fill:c,stroke:f}),s.text(M).call(u.font,d.font.family||g,d.font.size||y,d.font.color||p).call(l.positionText,0,0).call(l.convertToTspans,r),e.attr(\"transform\",\"\");var v=s.node().getBoundingClientRect();if(\"x\"===a){s.attr(\"text-anchor\",\"middle\").call(l.positionText,0,\"top\"===b.side?C-v.bottom-w-k:C-v.top+w+k);var m=\"top\"===b.side?\"-\":\"\";i.attr(\"d\",\"M0,0L\"+w+\",\"+m+w+\"H\"+(k+v.width/2)+\"v\"+m+(2*k+v.height)+\"H-\"+(k+v.width/2)+\"V\"+m+w+\"H-\"+w+\"Z\"),e.attr(\"transform\",\"translate(\"+(b._offset+(x.x0+x.x1)/2)+\",\"+(_._offset+(\"top\"===b.side?0:_._length))+\")\")}else{s.attr(\"text-anchor\",\"right\"===_.side?\"start\":\"end\").call(l.positionText,(\"right\"===_.side?1:-1)*(k+w),C-v.top-v.height/2);var T=\"right\"===_.side?\"\":\"-\";i.attr(\"d\",\"M0,0L\"+T+w+\",\"+w+\"V\"+(k+v.height/2)+\"h\"+T+(2*k+v.width)+\"V-\"+(k+v.height/2)+\"H\"+T+w+\"V-\"+w+\"Z\"),e.attr(\"transform\",\"translate(\"+(b._offset+(\"right\"===_.side?b._length:0))+\",\"+(_._offset+(x.y0+x.y1)/2)+\")\")}t=t.filter(function(t){return void 0!==t.zLabelVal||(t[A]||\"\").split(\" \")[0]===S})});var N=f.selectAll(\"g.hovertext\").data(t,function(t){return[t.trace.index,t.index,t.x0,t.y0,t.name,t.attr,t.xa,t.ya||\"\"].join(\",\")});return N.enter().append(\"g\").classed(\"hovertext\",!0).each(function(){var t=n.select(this);t.append(\"rect\").call(h.fill,h.addOpacity(c,.8)),t.append(\"text\").classed(\"name\",!0),t.append(\"path\").style(\"stroke-width\",\"1px\"),t.append(\"text\").classed(\"nums\",!0).call(u.font,g,y)}),N.exit().remove(),N.each(function(t){var e=n.select(this).attr(\"transform\",\"\"),f=\"\",p=\"\",d=t.bgcolor||t.color,v=h.combine(h.opacity(d)?d:h.defaultLine,c),x=h.combine(h.opacity(t.color)?t.color:h.defaultLine,c),b=t.borderColor||h.contrast(v);void 0!==t.nameOverride&&(t.name=t.nameOverride),t.name&&(t.trace._meta&&(t.name=o.templateString(t.name,t.trace._meta)),f=L(t.name,t.nameLength)),void 0!==t.zLabel?(void 0!==t.xLabel&&(p+=\"x: \"+t.xLabel+\"<br>\"),void 0!==t.yLabel&&(p+=\"y: \"+t.yLabel+\"<br>\"),\"choropleth\"!==t.trace.type&&\"choroplethmapbox\"!==t.trace.type&&(p+=(p?\"z: \":\"\")+t.zLabel)):z&&t[a+\"Label\"]===M?p=t[(\"x\"===a?\"y\":\"x\")+\"Label\"]||\"\":void 0===t.xLabel?void 0!==t.yLabel&&\"scattercarpet\"!==t.trace.type&&(p=t.yLabel):p=void 0===t.yLabel?t.xLabel:\"(\"+t.xLabel+\", \"+t.yLabel+\")\",!t.text&&0!==t.text||Array.isArray(t.text)||(p+=(p?\"<br>\":\"\")+t.text),void 0!==t.extraText&&(p+=(p?\"<br>\":\"\")+t.extraText),\"\"!==p||t.hovertemplate||(\"\"===f&&e.remove(),p=f);var _=i._d3locale,A=t.hovertemplate||!1,S=t.hovertemplateLabels||t,E=t.eventData[0]||{};A&&(p=(p=o.hovertemplateString(A,S,_,E,t.trace._meta)).replace(T,function(e,r){return f=L(r,t.nameLength),\"\"}));var I=e.select(\"text.nums\").call(u.font,t.fontFamily||g,t.fontSize||y,t.fontColor||b).text(p).attr(\"data-notex\",1).call(l.positionText,0,0).call(l.convertToTspans,r),D=e.select(\"text.name\"),R=0,F=0;if(f&&f!==p){D.call(u.font,t.fontFamily||g,t.fontSize||y,x).text(f).attr(\"data-notex\",1).call(l.positionText,0,0).call(l.convertToTspans,r);var B=D.node().getBoundingClientRect();R=B.width+2*k,F=B.height+2*k}else D.remove(),e.select(\"rect\").remove();e.select(\"path\").style({fill:v,stroke:b});var N,j,U=I.node().getBoundingClientRect(),V=t.xa._offset+(t.x0+t.x1)/2,q=t.ya._offset+(t.y0+t.y1)/2,H=Math.abs(t.x1-t.x0),G=Math.abs(t.y1-t.y0),Y=U.width+w+k+R;if(t.ty0=C-U.top,t.bx=U.width+2*k,t.by=Math.max(U.height+2*k,F),t.anchor=\"start\",t.txwidth=U.width,t.tx2width=R,t.offset=0,s)t.pos=V,N=q+G/2+Y<=O,j=q-G/2-Y>=0,\"top\"!==t.idealAlign&&N||!j?N?(q+=G/2,t.anchor=\"start\"):t.anchor=\"middle\":(q-=G/2,t.anchor=\"end\");else if(t.pos=q,N=V+H/2+Y<=P,j=V-H/2-Y>=0,\"left\"!==t.idealAlign&&N||!j)if(N)V+=H/2,t.anchor=\"start\";else{t.anchor=\"middle\";var W=Y/2,X=V+W-P,Z=V-W;X>0&&(V-=X),Z<0&&(V+=-Z)}else V-=H/2,t.anchor=\"end\";I.attr(\"text-anchor\",t.anchor),R&&D.attr(\"text-anchor\",t.anchor),e.attr(\"transform\",\"translate(\"+V+\",\"+q+\")\"+(s?\"rotate(\"+m+\")\":\"\"))}),N}function M(t,e){t.each(function(t){var r=n.select(this);if(t.del)return r.remove();var i=r.select(\"text.nums\"),a=t.anchor,o=\"end\"===a?-1:1,s={start:1,end:-1,middle:0}[a],c=s*(w+k),h=c+s*(t.txwidth+k),f=0,p=t.offset;\"middle\"===a&&(c-=t.tx2width/2,h+=t.txwidth/2+k),e&&(p*=-_,f=t.offset*b),r.select(\"path\").attr(\"d\",\"middle\"===a?\"M-\"+(t.bx/2+t.tx2width/2)+\",\"+(p-t.by/2)+\"h\"+t.bx+\"v\"+t.by+\"h-\"+t.bx+\"Z\":\"M0,0L\"+(o*w+f)+\",\"+(w+p)+\"v\"+(t.by/2-w)+\"h\"+o*t.bx+\"v-\"+t.by+\"H\"+(o*w+f)+\"V\"+(p-w)+\"Z\");var d=c+f,g=p+t.ty0-t.by/2+k,v=t.textAlign||\"auto\";\"auto\"!==v&&(\"left\"===v&&\"start\"!==a?(i.attr(\"text-anchor\",\"start\"),d=\"middle\"===a?-t.bx/2-t.tx2width/2+k:-t.bx-k):\"right\"===v&&\"end\"!==a&&(i.attr(\"text-anchor\",\"end\"),d=\"middle\"===a?t.bx/2-t.tx2width/2-k:t.bx+k)),i.call(l.positionText,d,g),t.tx2width&&(r.select(\"text.name\").call(l.positionText,h+s*k+f,p+t.ty0-t.by/2+k),r.select(\"rect\").call(u.setRect,h+(s-1)*t.tx2width/2+f,p-t.by/2-1,t.tx2width,t.by+2))})}function S(t,e){var r=t.index,n=t.trace||{},a=t.cd[0],s=t.cd[r]||{};function l(t){return t||i(t)&&0===t}var c=Array.isArray(r)?function(t,e){var i=o.castOption(a,r,t);return l(i)?i:o.extractOption({},n,\"\",e)}:function(t,e){return o.extractOption(s,n,t,e)};function u(e,r,n){var i=c(r,n);l(i)&&(t[e]=i)}if(u(\"hoverinfo\",\"hi\",\"hoverinfo\"),u(\"bgcolor\",\"hbg\",\"hoverlabel.bgcolor\"),u(\"borderColor\",\"hbc\",\"hoverlabel.bordercolor\"),u(\"fontFamily\",\"htf\",\"hoverlabel.font.family\"),u(\"fontSize\",\"hts\",\"hoverlabel.font.size\"),u(\"fontColor\",\"htc\",\"hoverlabel.font.color\"),u(\"nameLength\",\"hnl\",\"hoverlabel.namelength\"),u(\"textAlign\",\"hta\",\"hoverlabel.align\"),t.posref=\"y\"===e||\"closest\"===e&&\"h\"===n.orientation?t.xa._offset+(t.x0+t.x1)/2:t.ya._offset+(t.y0+t.y1)/2,t.x0=o.constrain(t.x0,0,t.xa._length),t.x1=o.constrain(t.x1,0,t.xa._length),t.y0=o.constrain(t.y0,0,t.ya._length),t.y1=o.constrain(t.y1,0,t.ya._length),void 0!==t.xLabelVal&&(t.xLabel=\"xLabel\"in t?t.xLabel:p.hoverLabelText(t.xa,t.xLabelVal),t.xVal=t.xa.c2d(t.xLabelVal)),void 0!==t.yLabelVal&&(t.yLabel=\"yLabel\"in t?t.yLabel:p.hoverLabelText(t.ya,t.yLabelVal),t.yVal=t.ya.c2d(t.yLabelVal)),void 0!==t.zLabelVal&&void 0===t.zLabel&&(t.zLabel=String(t.zLabelVal)),!(isNaN(t.xerr)||\"log\"===t.xa.type&&t.xerr<=0)){var h=p.tickText(t.xa,t.xa.c2l(t.xerr),\"hover\").text;void 0!==t.xerrneg?t.xLabel+=\" +\"+h+\" / -\"+p.tickText(t.xa,t.xa.c2l(t.xerrneg),\"hover\").text:t.xLabel+=\" \\xb1 \"+h,\"x\"===e&&(t.distance+=1)}if(!(isNaN(t.yerr)||\"log\"===t.ya.type&&t.yerr<=0)){var f=p.tickText(t.ya,t.ya.c2l(t.yerr),\"hover\").text;void 0!==t.yerrneg?t.yLabel+=\" +\"+f+\" / -\"+p.tickText(t.ya,t.ya.c2l(t.yerrneg),\"hover\").text:t.yLabel+=\" \\xb1 \"+f,\"y\"===e&&(t.distance+=1)}var d=t.hoverinfo||t.trace.hoverinfo;return d&&\"all\"!==d&&(-1===(d=Array.isArray(d)?d:d.split(\"+\")).indexOf(\"x\")&&(t.xLabel=void 0),-1===d.indexOf(\"y\")&&(t.yLabel=void 0),-1===d.indexOf(\"z\")&&(t.zLabel=void 0),-1===d.indexOf(\"text\")&&(t.text=void 0),-1===d.indexOf(\"name\")&&(t.name=void 0)),t}function E(t,e){var r,n,i=e.container,o=e.fullLayout,s=e.event,l=!!t.hLinePoint,c=!!t.vLinePoint;if(i.selectAll(\".spikeline\").remove(),c||l){var f=h.combine(o.plot_bgcolor,o.paper_bgcolor);if(l){var p,d,g=t.hLinePoint;r=g&&g.xa,\"cursor\"===(n=g&&g.ya).spikesnap?(p=s.pointerX,d=s.pointerY):(p=r._offset+g.x,d=n._offset+g.y);var v,m,y=a.readability(g.color,f)<1.5?h.contrast(f):g.color,x=n.spikemode,b=n.spikethickness,_=n.spikecolor||y,w=n._boundingBox,k=(w.left+w.right)/2<p?w.right:w.left;-1===x.indexOf(\"toaxis\")&&-1===x.indexOf(\"across\")||(-1!==x.indexOf(\"toaxis\")&&(v=k,m=p),-1!==x.indexOf(\"across\")&&(v=n._counterSpan[0],m=n._counterSpan[1]),i.insert(\"line\",\":first-child\").attr({x1:v,x2:m,y1:d,y2:d,\"stroke-width\":b,stroke:_,\"stroke-dasharray\":u.dashStyle(n.spikedash,b)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),i.insert(\"line\",\":first-child\").attr({x1:v,x2:m,y1:d,y2:d,\"stroke-width\":b+2,stroke:f}).classed(\"spikeline\",!0).classed(\"crisp\",!0)),-1!==x.indexOf(\"marker\")&&i.insert(\"circle\",\":first-child\").attr({cx:k+(\"right\"!==n.side?b:-b),cy:d,r:b,fill:_}).classed(\"spikeline\",!0)}if(c){var T,A,M=t.vLinePoint;r=M&&M.xa,n=M&&M.ya,\"cursor\"===r.spikesnap?(T=s.pointerX,A=s.pointerY):(T=r._offset+M.x,A=n._offset+M.y);var S,E,C=a.readability(M.color,f)<1.5?h.contrast(f):M.color,L=r.spikemode,P=r.spikethickness,O=r.spikecolor||C,z=r._boundingBox,I=(z.top+z.bottom)/2<A?z.bottom:z.top;-1===L.indexOf(\"toaxis\")&&-1===L.indexOf(\"across\")||(-1!==L.indexOf(\"toaxis\")&&(S=I,E=A),-1!==L.indexOf(\"across\")&&(S=r._counterSpan[0],E=r._counterSpan[1]),i.insert(\"line\",\":first-child\").attr({x1:T,x2:T,y1:S,y2:E,\"stroke-width\":P,stroke:O,\"stroke-dasharray\":u.dashStyle(r.spikedash,P)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),i.insert(\"line\",\":first-child\").attr({x1:T,x2:T,y1:S,y2:E,\"stroke-width\":P+2,stroke:f}).classed(\"spikeline\",!0).classed(\"crisp\",!0)),-1!==L.indexOf(\"marker\")&&i.insert(\"circle\",\":first-child\").attr({cx:T,cy:I-(\"top\"!==r.side?P:-P),r:P,fill:O}).classed(\"spikeline\",!0)}}}function C(t,e){return!e||(e.vLinePoint!==t._spikepoints.vLinePoint||e.hLinePoint!==t._spikepoints.hLinePoint)}function L(t,e){return l.plainText(t||\"\",{len:e,allowedTags:[\"br\",\"sub\",\"sup\",\"b\",\"i\",\"em\"]})}},{\"../../lib\":719,\"../../lib/events\":709,\"../../lib/override_cursor\":730,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"./constants\":626,\"./helpers\":628,d3:163,\"fast-isnumeric\":225,tinycolor2:537}],630:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i){r(\"hoverlabel.bgcolor\",(i=i||{}).bgcolor),r(\"hoverlabel.bordercolor\",i.bordercolor),r(\"hoverlabel.namelength\",i.namelength),n.coerceFont(r,\"hoverlabel.font\",i.font),r(\"hoverlabel.align\",i.align)}},{\"../../lib\":719}],631:[function(t,e,r){\"use strict\";t(\"../../constants/docs\").FORMAT_LINK;e.exports=function(t,e){t=t||{};(e=e||{}).description&&e.description;var r=e.keys||[];if(r.length>0){for(var n=[],i=0;i<r.length;i++)n[i]=\"`\"+r[i]+\"`\";\"Finally, the template string has access to \",1===r.length?\"variable \"+n[0]:\"variables \"+n.slice(0,-1).join(\", \")+\" and \"+n.slice(-1)+\".\"}var a={valType:\"string\",dflt:\"\",editType:t.editType||\"none\"};return!1!==t.arrayOk&&(a.arrayOk=!0),a}},{\"../../constants/docs\":690}],632:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../dragelement\"),o=t(\"./helpers\"),s=t(\"./layout_attributes\"),l=t(\"./hover\");e.exports={moduleType:\"component\",name:\"fx\",constants:t(\"./constants\"),schema:{layout:s},attributes:t(\"./attributes\"),layoutAttributes:s,supplyLayoutGlobalDefaults:t(\"./layout_global_defaults\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),getDistanceFunction:o.getDistanceFunction,getClosest:o.getClosest,inbox:o.inbox,quadrature:o.quadrature,appendArrayPointValue:o.appendArrayPointValue,castHoverOption:function(t,e,r){return i.castOption(t,e,\"hoverlabel.\"+r)},castHoverinfo:function(t,e,r){return i.castOption(t,r,\"hoverinfo\",function(r){return i.coerceHoverinfo({hoverinfo:r},{_module:t._module},e)})},hover:l.hover,unhover:a.unhover,loneHover:l.loneHover,loneUnhover:function(t){var e=i.isD3Selection(t)?t:n.select(t);e.selectAll(\"g.hovertext\").remove(),e.selectAll(\".spikeline\").remove()},click:t(\"./click\")}},{\"../../lib\":719,\"../dragelement\":611,\"./attributes\":623,\"./calc\":624,\"./click\":625,\"./constants\":626,\"./defaults\":627,\"./helpers\":628,\"./hover\":629,\"./layout_attributes\":633,\"./layout_defaults\":634,\"./layout_global_defaults\":635,d3:163}],633:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../plots/font_attributes\")({editType:\"none\"});i.family.dflt=n.HOVERFONT,i.size.dflt=n.HOVERFONTSIZE,e.exports={clickmode:{valType:\"flaglist\",flags:[\"event\",\"select\"],dflt:\"event\",editType:\"plot\",extras:[\"none\"]},dragmode:{valType:\"enumerated\",values:[\"zoom\",\"pan\",\"select\",\"lasso\",\"orbit\",\"turntable\",!1],dflt:\"zoom\",editType:\"modebar\"},hovermode:{valType:\"enumerated\",values:[\"x\",\"y\",\"closest\",!1],editType:\"modebar\"},hoverdistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},spikedistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"none\"},bordercolor:{valType:\"color\",editType:\"none\"},font:i,align:{valType:\"enumerated\",values:[\"left\",\"right\",\"auto\"],dflt:\"auto\",editType:\"none\"},namelength:{valType:\"integer\",min:-1,dflt:15,editType:\"none\"},editType:\"none\"},selectdirection:{valType:\"enumerated\",values:[\"h\",\"v\",\"d\",\"any\"],dflt:\"any\",editType:\"none\"}}},{\"../../plots/font_attributes\":793,\"./constants\":626}],634:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){function a(r,a){return n.coerce(t,e,i,r,a)}var o,s=a(\"clickmode\");\"select\"===a(\"dragmode\")&&a(\"selectdirection\"),e._has(\"cartesian\")?s.indexOf(\"select\")>-1?o=\"closest\":(e._isHoriz=function(t,e){for(var r=e._scatterStackOpts||{},n=0;n<t.length;n++){var i=t[n],a=i.xaxis+i.yaxis,o=r[a]||{},s=o[i.stackgroup]||{};if(\"h\"!==i.orientation&&\"h\"!==s.orientation)return!1}return!0}(r,e),o=e._isHoriz?\"y\":\"x\"):o=\"closest\",a(\"hovermode\",o)&&(a(\"hoverdistance\"),a(\"spikedistance\"));var l=e._has(\"mapbox\"),c=e._has(\"geo\"),u=e._basePlotModules.length;\"zoom\"===e.dragmode&&((l||c)&&1===u||l&&c&&2===u)&&(e.dragmode=\"pan\")}},{\"../../lib\":719,\"./layout_attributes\":633}],635:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./hoverlabel_defaults\"),a=t(\"./layout_attributes\");e.exports=function(t,e){i(t,e,function(r,i){return n.coerce(t,e,a,r,i)})}},{\"../../lib\":719,\"./hoverlabel_defaults\":630,\"./layout_attributes\":633}],636:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/regex\").counter,a=t(\"../../plots/domain\").attributes,o=t(\"../../plots/cartesian/constants\").idRegex,s=t(\"../../plot_api/plot_template\"),l={rows:{valType:\"integer\",min:1,editType:\"plot\"},roworder:{valType:\"enumerated\",values:[\"top to bottom\",\"bottom to top\"],dflt:\"top to bottom\",editType:\"plot\"},columns:{valType:\"integer\",min:1,editType:\"plot\"},subplots:{valType:\"info_array\",freeLength:!0,dimensions:2,items:{valType:\"enumerated\",values:[i(\"xy\").toString(),\"\"],editType:\"plot\"},editType:\"plot\"},xaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.x.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},yaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.y.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},pattern:{valType:\"enumerated\",values:[\"independent\",\"coupled\"],dflt:\"coupled\",editType:\"plot\"},xgap:{valType:\"number\",min:0,max:1,editType:\"plot\"},ygap:{valType:\"number\",min:0,max:1,editType:\"plot\"},domain:a({name:\"grid\",editType:\"plot\",noGridCell:!0},{}),xside:{valType:\"enumerated\",values:[\"bottom\",\"bottom plot\",\"top plot\",\"top\"],dflt:\"bottom plot\",editType:\"plot\"},yside:{valType:\"enumerated\",values:[\"left\",\"left plot\",\"right plot\",\"right\"],dflt:\"left plot\",editType:\"plot\"},editType:\"plot\"};function c(t,e,r){var n=e[r+\"axes\"],i=Object.keys((t._splomAxes||{})[r]||{});return Array.isArray(n)?n:i.length?i:void 0}function u(t,e,r,n,i,a){var o=e(t+\"gap\",r),s=e(\"domain.\"+t);e(t+\"side\",n);for(var l=new Array(i),c=s[0],u=(s[1]-c)/(i-o),h=u*(1-o),f=0;f<i;f++){var p=c+u*f;l[a?i-1-f:f]=[p,p+h]}return l}function h(t,e,r,n,i){var a,o=new Array(r);function s(t,r){-1!==e.indexOf(r)&&void 0===n[r]?(o[t]=r,n[r]=t):o[t]=\"\"}if(Array.isArray(t))for(a=0;a<r;a++)s(a,t[a]);else for(s(0,i),a=1;a<r;a++)s(a,i+(a+1));return o}e.exports={moduleType:\"component\",name:\"grid\",schema:{layout:{grid:l}},layoutAttributes:l,sizeDefaults:function(t,e){var r=t.grid||{},i=c(e,r,\"x\"),a=c(e,r,\"y\");if(t.grid||i||a){var o,h,f=Array.isArray(r.subplots)&&Array.isArray(r.subplots[0]),p=Array.isArray(i),d=Array.isArray(a),g=p&&i!==r.xaxes&&d&&a!==r.yaxes;f?(o=r.subplots.length,h=r.subplots[0].length):(d&&(o=a.length),p&&(h=i.length));var v=s.newContainer(e,\"grid\"),m=T(\"rows\",o),y=T(\"columns\",h);if(m*y>1){f||p||d||\"independent\"===T(\"pattern\")&&(f=!0),v._hasSubplotGrid=f;var x,b,_=\"top to bottom\"===T(\"roworder\"),w=f?.2:.1,k=f?.3:.1;g&&e._splomGridDflt&&(x=e._splomGridDflt.xside,b=e._splomGridDflt.yside),v._domains={x:u(\"x\",T,w,x,y),y:u(\"y\",T,k,b,m,_)}}else delete e.grid}function T(t,e){return n.coerce(r,v,l,t,e)}},contentDefaults:function(t,e){var r=e.grid;if(r&&r._domains){var n,i,a,o,s,l,u,f=t.grid||{},p=e._subplots,d=r._hasSubplotGrid,g=r.rows,v=r.columns,m=\"independent\"===r.pattern,y=r._axisMap={};if(d){var x=f.subplots||[];l=r.subplots=new Array(g);var b=1;for(n=0;n<g;n++){var _=l[n]=new Array(v),w=x[n]||[];for(i=0;i<v;i++)if(m?(s=1===b?\"xy\":\"x\"+b+\"y\"+b,b++):s=w[i],_[i]=\"\",-1!==p.cartesian.indexOf(s)){if(u=s.indexOf(\"y\"),a=s.slice(0,u),o=s.slice(u),void 0!==y[a]&&y[a]!==i||void 0!==y[o]&&y[o]!==n)continue;_[i]=s,y[a]=i,y[o]=n}}}else{var k=c(e,f,\"x\"),T=c(e,f,\"y\");r.xaxes=h(k,p.xaxis,v,y,\"x\"),r.yaxes=h(T,p.yaxis,g,y,\"y\")}var A=r._anchors={},M=\"top to bottom\"===r.roworder;for(var S in y){var E,C,L,P=S.charAt(0),O=r[P+\"side\"];if(O.length<8)A[S]=\"free\";else if(\"x\"===P){if(\"t\"===O.charAt(0)===M?(E=0,C=1,L=g):(E=g-1,C=-1,L=-1),d){var z=y[S];for(n=E;n!==L;n+=C)if((s=l[n][z])&&(u=s.indexOf(\"y\"),s.slice(0,u)===S)){A[S]=s.slice(u);break}}else for(n=E;n!==L;n+=C)if(o=r.yaxes[n],-1!==p.cartesian.indexOf(S+o)){A[S]=o;break}}else if(\"l\"===O.charAt(0)?(E=0,C=1,L=v):(E=v-1,C=-1,L=-1),d){var I=y[S];for(n=E;n!==L;n+=C)if((s=l[I][n])&&(u=s.indexOf(\"y\"),s.slice(u)===S)){A[S]=s.slice(0,u);break}}else for(n=E;n!==L;n+=C)if(a=r.xaxes[n],-1!==p.cartesian.indexOf(a+S)){A[S]=a;break}}}}}},{\"../../lib\":719,\"../../lib/regex\":735,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773,\"../../plots/domain\":792}],637:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/constants\"),i=t(\"../../plot_api/plot_template\").templatedArray;e.exports=i(\"image\",{visible:{valType:\"boolean\",dflt:!0,editType:\"arraydraw\"},source:{valType:\"string\",editType:\"arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},sizex:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizey:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizing:{valType:\"enumerated\",values:[\"fill\",\"contain\",\"stretch\"],dflt:\"contain\",editType:\"arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},x:{valType:\"any\",dflt:0,editType:\"arraydraw\"},y:{valType:\"any\",dflt:0,editType:\"arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"top\",editType:\"arraydraw\"},xref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.x.toString()],dflt:\"paper\",editType:\"arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.y.toString()],dflt:\"paper\",editType:\"arraydraw\"},editType:\"arraydraw\"})},{\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773}],638:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.images,h=e._id.charAt(0),f=0;f<u.length;f++)if(c=\"images[\"+f+\"].\",(l=u[f])[h+\"ref\"]===e._id){var p=l[h],d=l[\"size\"+h],g=null,v=null;if(o){g=i(p,e.range);var m=d/Math.pow(10,g)/2;v=2*Math.log(m+Math.sqrt(1+m*m))/Math.LN10}else v=(g=Math.pow(10,p))*(Math.pow(10,d/2)-Math.pow(10,-d/2));n(g)?n(v)||(v=null):(g=null,v=null),a(c+h,g),a(c+\"size\"+h,v)}}},{\"../../lib/to_log_range\":745,\"fast-isnumeric\":225}],639:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\");function s(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}var s=a(\"source\");if(!a(\"visible\",!!s))return e;a(\"layer\"),a(\"xanchor\"),a(\"yanchor\"),a(\"sizex\"),a(\"sizey\"),a(\"sizing\"),a(\"opacity\");for(var l={_fullLayout:r},c=[\"x\",\"y\"],u=0;u<2;u++){var h=c[u],f=i.coerceRef(t,e,l,h,\"paper\");if(\"paper\"!==f)i.getFromId(l,f)._imgIndices.push(e._index);i.coercePosition(e,l,a,f,h,0)}return e}e.exports=function(t,e){a(t,e,{name:\"images\",handleItemDefaults:s})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"./attributes\":637}],640:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../drawing\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/xmlns_namespaces\");e.exports=function(t){var e,r,s=t._fullLayout,l=[],c={},u=[];for(r=0;r<s.images.length;r++){var h=s.images[r];if(h.visible)if(\"below\"===h.layer&&\"paper\"!==h.xref&&\"paper\"!==h.yref){e=h.xref+h.yref;var f=s._plots[e];if(!f){u.push(h);continue}f.mainplot&&(e=f.mainplot.id),c[e]||(c[e]=[]),c[e].push(h)}else\"above\"===h.layer?l.push(h):u.push(h)}var p={x:{left:{sizing:\"xMin\",offset:0},center:{sizing:\"xMid\",offset:-.5},right:{sizing:\"xMax\",offset:-1}},y:{top:{sizing:\"YMin\",offset:0},middle:{sizing:\"YMid\",offset:-.5},bottom:{sizing:\"YMax\",offset:-1}}};function d(e){var r=n.select(this);if(!this.img||this.img.src!==e.source){r.attr(\"xmlns\",o.svg);var i=new Promise(function(t){var n=new Image;function i(){r.remove(),t()}this.img=n,n.setAttribute(\"crossOrigin\",\"anonymous\"),n.onerror=i,n.onload=function(){var e=document.createElement(\"canvas\");e.width=this.width,e.height=this.height,e.getContext(\"2d\").drawImage(this,0,0);var n=e.toDataURL(\"image/png\");r.attr(\"xlink:href\",n),t()},r.on(\"error\",i),n.src=e.source}.bind(this));t._promises.push(i)}}function g(e){var r=n.select(this),o=a.getFromId(t,e.xref),l=a.getFromId(t,e.yref),c=s._size,u=o?Math.abs(o.l2p(e.sizex)-o.l2p(0)):e.sizex*c.w,h=l?Math.abs(l.l2p(e.sizey)-l.l2p(0)):e.sizey*c.h,f=u*p.x[e.xanchor].offset,d=h*p.y[e.yanchor].offset,g=p.x[e.xanchor].sizing+p.y[e.yanchor].sizing,v=(o?o.r2p(e.x)+o._offset:e.x*c.w+c.l)+f,m=(l?l.r2p(e.y)+l._offset:c.h-e.y*c.h+c.t)+d;switch(e.sizing){case\"fill\":g+=\" slice\";break;case\"stretch\":g=\"none\"}r.attr({x:v,y:m,width:u,height:h,preserveAspectRatio:g,opacity:e.opacity});var y=(o?o._id:\"\")+(l?l._id:\"\");i.setClipUrl(r,y?\"clip\"+s._uid+y:null,t)}var v=s._imageLowerLayer.selectAll(\"image\").data(u),m=s._imageUpperLayer.selectAll(\"image\").data(l);v.enter().append(\"image\"),m.enter().append(\"image\"),v.exit().remove(),m.exit().remove(),v.each(function(t){d.bind(this)(t),g.bind(this)(t)}),m.each(function(t){d.bind(this)(t),g.bind(this)(t)});var y=Object.keys(s._plots);for(r=0;r<y.length;r++){e=y[r];var x=s._plots[e];if(x.imagelayer){var b=x.imagelayer.selectAll(\"image\").data(c[e]||[]);b.enter().append(\"image\"),b.exit().remove(),b.each(function(t){d.bind(this)(t),g.bind(this)(t)})}}}},{\"../../constants/xmlns_namespaces\":696,\"../../plots/cartesian/axes\":767,\"../drawing\":614,d3:163}],641:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"images\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"images\"),draw:t(\"./draw\"),convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":777,\"./attributes\":637,\"./convert_coords\":638,\"./defaults\":639,\"./draw\":640}],642:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",editType:\"legend\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"legend\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"legend\"},font:n({editType:\"legend\"}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"v\",editType:\"legend\"},traceorder:{valType:\"flaglist\",flags:[\"reversed\",\"grouped\"],extras:[\"normal\"],editType:\"legend\"},tracegroupgap:{valType:\"number\",min:0,dflt:10,editType:\"legend\"},itemsizing:{valType:\"enumerated\",values:[\"trace\",\"constant\"],dflt:\"trace\",editType:\"legend\"},itemclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggle\",editType:\"legend\"},itemdoubleclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggleothers\",editType:\"legend\"},x:{valType:\"number\",min:-2,max:3,dflt:1.02,editType:\"legend\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"legend\"},y:{valType:\"number\",min:-2,max:3,dflt:1,editType:\"legend\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"legend\"},uirevision:{valType:\"any\",editType:\"none\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"legend\"},editType:\"legend\"}},{\"../../plots/font_attributes\":793,\"../color/attributes\":592}],643:[function(t,e,r){\"use strict\";e.exports={scrollBarWidth:6,scrollBarMinHeight:20,scrollBarColor:\"#808BA4\",scrollBarMargin:4,textOffsetX:40}},{}],644:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plot_api/plot_template\"),o=t(\"./attributes\"),s=t(\"../../plots/layout_attributes\"),l=t(\"./helpers\");e.exports=function(t,e,r){for(var c,u,h,f,p=t.legend||{},d=0,g=!1,v=\"normal\",m=0;m<r.length;m++){var y=r[m];y.visible&&((y.showlegend||y._dfltShowLegend)&&(d++,y.showlegend&&(g=!0,(n.traceIs(y,\"pie-like\")||!0===y._input.showlegend)&&d++)),(n.traceIs(y,\"bar\")&&\"stack\"===e.barmode||-1!==[\"tonextx\",\"tonexty\"].indexOf(y.fill))&&(v=l.isGrouped({traceorder:v})?\"grouped+reversed\":\"reversed\"),void 0!==y.legendgroup&&\"\"!==y.legendgroup&&(v=l.isReversed({traceorder:v})?\"reversed+grouped\":\"grouped\"))}var x=i.coerce(t,e,s,\"showlegend\",g&&d>1);if(!1!==x||p.uirevision){var b=a.newContainer(e,\"legend\");if(w(\"uirevision\",e.uirevision),!1!==x){if(w(\"bgcolor\",e.paper_bgcolor),w(\"bordercolor\"),w(\"borderwidth\"),i.coerceFont(w,\"font\",e.font),w(\"orientation\"),\"h\"===b.orientation){var _=t.xaxis;n.getComponentMethod(\"rangeslider\",\"isVisible\")(_)?(c=0,h=\"left\",u=1.1,f=\"bottom\"):(c=0,h=\"left\",u=-.1,f=\"top\")}w(\"traceorder\",v),l.isGrouped(e.legend)&&w(\"tracegroupgap\"),w(\"itemsizing\"),w(\"itemclick\"),w(\"itemdoubleclick\"),w(\"x\",c),w(\"xanchor\",h),w(\"y\",u),w(\"yanchor\",f),w(\"valign\"),i.noneOrAll(p,b,[\"x\",\"y\"])}}function w(t,e){return i.coerce(p,b,o,t,e)}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/layout_attributes\":819,\"../../registry\":847,\"./attributes\":642,\"./helpers\":648}],645:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib/events\"),l=t(\"../dragelement\"),c=t(\"../drawing\"),u=t(\"../color\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"./handle_click\"),p=t(\"./constants\"),d=t(\"../../constants/alignment\"),g=d.LINE_SPACING,v=d.FROM_TL,m=d.FROM_BR,y=t(\"./get_legend_data\"),x=t(\"./style\"),b=t(\"./helpers\");function _(t,e,r,n,i){var a=r.data()[0][0].trace,l={event:i,node:r.node(),curveNumber:a.index,expandedIndex:a._expandedIndex,data:t.data,layout:t.layout,frames:t._transitionData._frames,config:t._context,fullData:t._fullData,fullLayout:t._fullLayout};if(a._group&&(l.group=a._group),o.traceIs(a,\"pie-like\")&&(l.label=r.datum()[0].label),!1!==s.triggerHandler(t,\"plotly_legendclick\",l))if(1===n)e._clickTimeout=setTimeout(function(){f(r,t,n)},t._context.doubleClickDelay);else if(2===n){e._clickTimeout&&clearTimeout(e._clickTimeout),t._legendMouseDownTime=0,!1!==s.triggerHandler(t,\"plotly_legenddoubleclick\",l)&&f(r,t,n)}}function w(t,e,r){var n=t.data()[0][0],a=e._fullLayout,s=n.trace,l=o.traceIs(s,\"pie-like\"),u=s.index,f=e._context.edits.legendText&&!l,d=l?n.label:s.name;s._meta&&(d=i.templateString(d,s._meta));var v=i.ensureSingle(t,\"text\",\"legendtext\");function m(r){h.convertToTspans(r,e,function(){!function(t,e){var r=t.data()[0][0];if(!r.trace.showlegend)return void t.remove();var n,i,a=t.select(\"g[class*=math-group]\"),o=a.node(),s=e._fullLayout.legend.font.size*g;if(o){var l=c.bBox(o);n=l.height,i=l.width,c.setTranslate(a,0,n/4)}else{var u=t.select(\".legendtext\"),f=h.lineCount(u),d=u.node();n=s*f,i=d?c.bBox(d).width:0;var v=s*(.3+(1-f)/2);h.positionText(u,p.textOffsetX,v)}r.lineHeight=s,r.height=Math.max(n,16)+3,r.width=i}(t,e)})}v.attr(\"text-anchor\",\"start\").classed(\"user-select-none\",!0).call(c.font,a.legend.font).text(f?k(d,r):d),h.positionText(v,p.textOffsetX,0),f?v.call(h.makeEditable,{gd:e,text:d}).call(m).on(\"edit\",function(t){this.text(k(t,r)).call(m);var a=n.trace._fullInput||{},s={};if(o.hasTransform(a,\"groupby\")){var l=o.getTransformIndices(a,\"groupby\"),c=l[l.length-1],h=i.keyedContainer(a,\"transforms[\"+c+\"].styles\",\"target\",\"value.name\");h.set(n.trace._group,t),s=h.constructUpdate()}else s.name=t;return o.call(\"_guiRestyle\",e,s,u)}):m(v)}function k(t,e){var r=Math.max(4,e);if(t&&t.trim().length>=r/2)return t;for(var n=r-(t=t||\"\").length;n>0;n--)t+=\" \";return t}function T(t,e){var r,a=e._context.doubleClickDelay,o=1,s=i.ensureSingle(t,\"rect\",\"legendtoggle\",function(t){t.style(\"cursor\",\"pointer\").attr(\"pointer-events\",\"all\").call(u.fill,\"rgba(0,0,0,0)\")});s.on(\"mousedown\",function(){(r=(new Date).getTime())-e._legendMouseDownTime<a?o+=1:(o=1,e._legendMouseDownTime=r)}),s.on(\"mouseup\",function(){if(!e._dragged&&!e._editing){var r=e._fullLayout.legend;(new Date).getTime()-e._legendMouseDownTime>a&&(o=Math.max(o-1,1)),_(e,r,t,o,n.event)}})}function A(t,e,r){var a=t._fullLayout,o=a.legend,s=o.borderwidth,l=b.isGrouped(o),u=0;if(o._width=0,o._height=0,b.isVertical(o))l&&e.each(function(t,e){c.setTranslate(this,0,e*o.tracegroupgap)}),r.each(function(t){var e=t[0],r=e.height,n=e.width;c.setTranslate(this,s,5+s+o._height+r/2),o._height+=r,o._width=Math.max(o._width,n)}),o._width+=45+2*s,o._height+=10+2*s,l&&(o._height+=(o._lgroupsLength-1)*o.tracegroupgap),u=40;else if(l){var h,f=0,p=0,d=e.data(),g=0;for(h=0;h<d.length;h++){var v=d[h],m=v.map(function(t){return t[0].width}),y=i.aggNums(Math.max,null,m),x=v.reduce(function(t,e){return t+e[0].height},0);p=Math.max(p,y),f=Math.max(f,x),g=Math.max(g,v.length)}p+=5,p+=40;var _=[o._width],w=[],k=0;for(h=0;h<d.length;h++){a._size.w<s+o._width+5+p?(_[_.length-1]=_[0],o._width=p,k++):o._width+=p+s;var T=k*f;T+=k>0?o.tracegroupgap:0,w.push(T),_.push(o._width)}e.each(function(t,e){c.setTranslate(this,_[e],w[e])}),e.each(function(){var t=n.select(this).selectAll(\"g.traces\"),e=0;t.each(function(t){var r=t[0].height;c.setTranslate(this,0,5+s+e+r/2),e+=r})});var A=w[w.length-1]+f;o._height=10+2*s+A;var M=Math.max.apply(null,_);o._width=M+p+40,o._width+=2*s}else{var S=0,E=0,C=0,L=0,P=0;r.each(function(t){C=Math.max(40+t[0].width,C),P+=40+t[0].width+5});var O=a._size.w>s+P-5;r.each(function(t){var e=t[0],r=O?40+t[0].width:C;s+L+5+r>a._size.w&&(L=0,S+=E,o._height+=E,E=0),c.setTranslate(this,s+L,5+s+e.height/2+S),o._width+=5+r,L+=5+r,E=Math.max(e.height,E)}),O?o._height=E:o._height+=E,o._width+=2*s,o._height+=10+2*s}o._width=Math.ceil(o._width),o._height=Math.ceil(o._height);var z=t._context.edits.legendText||t._context.edits.legendPosition;r.each(function(t){var e=t[0],r=n.select(this).select(\".legendtoggle\");c.setRect(r,0,-e.height/2,(z?0:o._width)+u,e.height)})}function M(t){var e=t._fullLayout.legend,r=\"left\";i.isRightAnchor(e)?r=\"right\":i.isCenterAnchor(e)&&(r=\"center\");var n=\"top\";i.isBottomAnchor(e)?n=\"bottom\":i.isMiddleAnchor(e)&&(n=\"middle\"),a.autoMargin(t,\"legend\",{x:e.x,y:e.y,l:e._width*v[r],r:e._width*m[r],b:e._height*m[n],t:e._height*v[n]})}e.exports=function(t){var e=t._fullLayout,r=\"legend\"+e._uid;if(e._infolayer&&t.calcdata){t._legendMouseDownTime||(t._legendMouseDownTime=0);var s=e.legend,h=e.showlegend&&y(t.calcdata,s),f=e.hiddenlabels||[];if(!e.showlegend||!h.length)return e._infolayer.selectAll(\".legend\").remove(),e._topdefs.select(\"#\"+r).remove(),void a.autoMargin(t,\"legend\");for(var d=0,g=0;g<h.length;g++)for(var b=0;b<h[g].length;b++){var k=h[g][b][0],S=k.trace,E=o.traceIs(S,\"pie-like\")?k.label:S.name;d=Math.max(d,E&&E.length||0)}var C=!1,L=i.ensureSingle(e._infolayer,\"g\",\"legend\",function(t){t.attr(\"pointer-events\",\"all\"),C=!0}),P=i.ensureSingleById(e._topdefs,\"clipPath\",r,function(t){t.append(\"rect\")}),O=i.ensureSingle(L,\"rect\",\"bg\",function(t){t.attr(\"shape-rendering\",\"crispEdges\")});O.call(u.stroke,s.bordercolor).call(u.fill,s.bgcolor).style(\"stroke-width\",s.borderwidth+\"px\");var z=i.ensureSingle(L,\"g\",\"scrollbox\"),I=i.ensureSingle(L,\"rect\",\"scrollbar\",function(t){t.attr({rx:20,ry:3,width:0,height:0}).call(u.fill,\"#808BA4\")}),D=z.selectAll(\"g.groups\").data(h);D.enter().append(\"g\").attr(\"class\",\"groups\"),D.exit().remove();var R=D.selectAll(\"g.traces\").data(i.identity);R.enter().append(\"g\").attr(\"class\",\"traces\"),R.exit().remove(),R.style(\"opacity\",function(t){var e=t[0].trace;return o.traceIs(e,\"pie-like\")?-1!==f.indexOf(t[0].label)?.5:1:\"legendonly\"===e.visible?.5:1}).each(function(){n.select(this).call(w,t,d)}).call(x,t).each(function(){n.select(this).call(T,t)}),i.syncOrAsync([a.previousPromises,function(){C&&(A(t,D,R),M(t));var u=e.width,h=e.height;A(t,D,R),s._height>h?function(t){var e=t._fullLayout.legend,r=\"left\";i.isRightAnchor(e)?r=\"right\":i.isCenterAnchor(e)&&(r=\"center\");a.autoMargin(t,\"legend\",{x:e.x,y:.5,l:e._width*v[r],r:e._width*m[r],b:0,t:0})}(t):M(t);var f=e._size,d=f.l+f.w*s.x,g=f.t+f.h*(1-s.y);i.isRightAnchor(s)?d-=s._width:i.isCenterAnchor(s)&&(d-=s._width/2),i.isBottomAnchor(s)?g-=s._height:i.isMiddleAnchor(s)&&(g-=s._height/2);var y=s._width,x=f.w;y>x?(d=f.l,y=x):(d+y>u&&(d=u-y),d<0&&(d=0),y=Math.min(u-d,s._width));var b,w,k,T,S=s._height,E=f.h;if(S>E?(g=f.t,S=E):(g+S>h&&(g=h-S),g<0&&(g=0),S=Math.min(h-g,s._height)),c.setTranslate(L,d,g),I.on(\".drag\",null),L.on(\"wheel\",null),s._height<=S||t._context.staticPlot)O.attr({width:y-s.borderwidth,height:S-s.borderwidth,x:s.borderwidth/2,y:s.borderwidth/2}),c.setTranslate(z,0,0),P.select(\"rect\").attr({width:y-2*s.borderwidth,height:S-2*s.borderwidth,x:s.borderwidth,y:s.borderwidth}),c.setClipUrl(z,r,t),c.setRect(I,0,0,0,0),delete s._scrollY;else{var F,B,N=Math.max(p.scrollBarMinHeight,S*S/s._height),j=S-N-2*p.scrollBarMargin,U=s._height-S,V=j/U,q=Math.min(s._scrollY||0,U);O.attr({width:y-2*s.borderwidth+p.scrollBarWidth+p.scrollBarMargin,height:S-s.borderwidth,x:s.borderwidth/2,y:s.borderwidth/2}),P.select(\"rect\").attr({width:y-2*s.borderwidth+p.scrollBarWidth+p.scrollBarMargin,height:S-2*s.borderwidth,x:s.borderwidth,y:s.borderwidth+q}),c.setClipUrl(z,r,t),G(q,N,V),L.on(\"wheel\",function(){G(q=i.constrain(s._scrollY+n.event.deltaY/j*U,0,U),N,V),0!==q&&q!==U&&n.event.preventDefault()});var H=n.behavior.drag().on(\"dragstart\",function(){F=n.event.sourceEvent.clientY,B=q}).on(\"drag\",function(){var t=n.event.sourceEvent;2===t.buttons||t.ctrlKey||G(q=i.constrain((t.clientY-F)/V+B,0,U),N,V)});I.call(H)}function G(e,r,n){s._scrollY=t._fullLayout.legend._scrollY=e,c.setTranslate(z,0,-e),c.setRect(I,y,p.scrollBarMargin+e*n,p.scrollBarWidth,r),P.select(\"rect\").attr({y:s.borderwidth+e})}t._context.edits.legendPosition&&(L.classed(\"cursor-move\",!0),l.init({element:L.node(),gd:t,prepFn:function(){var t=c.getTranslate(L);k=t.x,T=t.y},moveFn:function(t,e){var r=k+t,n=T+e;c.setTranslate(L,r,n),b=l.align(r,0,f.l,f.l+f.w,s.xanchor),w=l.align(n,0,f.t+f.h,f.t,s.yanchor)},doneFn:function(){void 0!==b&&void 0!==w&&o.call(\"_guiRelayout\",t,{\"legend.x\":b,\"legend.y\":w})},clickFn:function(r,n){var i=e._infolayer.selectAll(\"g.traces\").filter(function(){var t=this.getBoundingClientRect();return n.clientX>=t.left&&n.clientX<=t.right&&n.clientY>=t.top&&n.clientY<=t.bottom});i.size()>0&&_(t,L,i,r,n)}}))}],t)}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/events\":709,\"../../lib/svg_text_utils\":743,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"./constants\":643,\"./get_legend_data\":646,\"./handle_click\":647,\"./helpers\":648,\"./style\":650,d3:163}],646:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./helpers\");e.exports=function(t,e){var r,a,o={},s=[],l=!1,c={},u=0;function h(t,r){if(\"\"!==t&&i.isGrouped(e))-1===s.indexOf(t)?(s.push(t),l=!0,o[t]=[[r]]):o[t].push([r]);else{var n=\"~~i\"+u;s.push(n),o[n]=[[r]],u++}}for(r=0;r<t.length;r++){var f=t[r],p=f[0],d=p.trace,g=d.legendgroup;if(d.visible&&d.showlegend)if(n.traceIs(d,\"pie-like\"))for(c[g]||(c[g]={}),a=0;a<f.length;a++){var v=f[a].label;c[g][v]||(h(g,{label:v,color:f[a].color,i:f[a].i,trace:d,pts:f[a].pts}),c[g][v]=!0)}else h(g,p)}if(!s.length)return[];var m,y,x=s.length;if(l&&i.isGrouped(e))for(y=new Array(x),r=0;r<x;r++)m=o[s[r]],y[r]=i.isReversed(e)?m.reverse():m;else{for(y=[new Array(x)],r=0;r<x;r++)m=o[s[r]][0],y[0][i.isReversed(e)?x-r-1:r]=m;x=1}return e._lgroupsLength=x,y}},{\"../../registry\":847,\"./helpers\":648}],647:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=!0;e.exports=function(t,e,r){var o=e._fullLayout;if(!e._dragged&&!e._editing){var s,l=o.legend.itemclick,c=o.legend.itemdoubleclick;if(1===r&&\"toggle\"===l&&\"toggleothers\"===c&&a&&e.data&&e._context.showTips?(n.notifier(n._(e,\"Double-click on legend to isolate one trace\"),\"long\"),a=!1):a=!1,1===r?s=l:2===r&&(s=c),s){var u,h,f,p,d,g=o.hiddenlabels?o.hiddenlabels.slice():[],v=t.data()[0][0],m=e._fullData,y=v.trace,x=y.legendgroup,b={},_=[],w=[],k=[];if(i.traceIs(y,\"pie-like\")){var T=v.label,A=g.indexOf(T);\"toggle\"===s?-1===A?g.push(T):g.splice(A,1):\"toggleothers\"===s&&(g=[],e.calcdata[0].forEach(function(t){T!==t.label&&g.push(t.label)}),e._fullLayout.hiddenlabels&&e._fullLayout.hiddenlabels.length===g.length&&-1===A&&(g=[])),i.call(\"_guiRelayout\",e,\"hiddenlabels\",g)}else{var M,S=x&&x.length,E=[];if(S)for(u=0;u<m.length;u++)(M=m[u]).visible&&M.legendgroup===x&&E.push(u);if(\"toggle\"===s){var C;switch(y.visible){case!0:C=\"legendonly\";break;case!1:C=!1;break;case\"legendonly\":C=!0}if(S)for(u=0;u<m.length;u++)!1!==m[u].visible&&m[u].legendgroup===x&&R(m[u],C);else R(y,C)}else if(\"toggleothers\"===s){var L,P,O=!0;for(u=0;u<m.length;u++)if(!(m[u]===y)&&!(L=S&&m[u].legendgroup===x)&&!0===m[u].visible&&!i.traceIs(m[u],\"notLegendIsolatable\")){O=!1;break}for(u=0;u<m.length;u++)if(!1!==m[u].visible&&!i.traceIs(m[u],\"notLegendIsolatable\"))switch(y.visible){case\"legendonly\":R(m[u],!0);break;case!0:P=!!O||\"legendonly\",L=m[u]===y||S&&m[u].legendgroup===x,R(m[u],!!L||P)}}for(u=0;u<w.length;u++)if(f=w[u]){var z=f.constructUpdate(),I=Object.keys(z);for(h=0;h<I.length;h++)p=I[h],(b[p]=b[p]||[])[k[u]]=z[p]}for(d=Object.keys(b),u=0;u<d.length;u++)for(p=d[u],h=0;h<_.length;h++)b[p].hasOwnProperty(h)||(b[p][h]=void 0);i.call(\"_guiRestyle\",e,b,_)}}}function D(t,e,r){var n=_.indexOf(t),i=b[e];return i||(i=b[e]=[]),-1===_.indexOf(t)&&(_.push(t),n=_.length-1),i[n]=r,n}function R(t,e){var r=t._fullInput;if(i.hasTransform(r,\"groupby\")){var a=w[r.index];if(!a){var o=i.getTransformIndices(r,\"groupby\"),s=o[o.length-1];a=n.keyedContainer(r,\"transforms[\"+s+\"].styles\",\"target\",\"value.visible\"),w[r.index]=a}var l=a.get(t._group);void 0===l&&(l=!0),!1!==l&&a.set(t._group,e),k[r.index]=D(r.index,\"visible\",!1!==r.visible)}else{var c=!1!==r.visible&&e;D(r.index,\"visible\",c)}}}},{\"../../lib\":719,\"../../registry\":847}],648:[function(t,e,r){\"use strict\";r.isGrouped=function(t){return-1!==(t.traceorder||\"\").indexOf(\"grouped\")},r.isVertical=function(t){return\"h\"!==t.orientation},r.isReversed=function(t){return-1!==(t.traceorder||\"\").indexOf(\"reversed\")}},{}],649:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"legend\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\"),style:t(\"./style\")}},{\"./attributes\":642,\"./defaults\":644,\"./draw\":645,\"./style\":650}],650:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../drawing\"),s=t(\"../color\"),l=t(\"../../traces/scatter/subtypes\"),c=t(\"../../traces/pie/style_one\"),u=t(\"../../traces/pie/helpers\").castOption,h=12,f=5,p=2,d=10,g=5;e.exports=function(t,e){var r=e._fullLayout.legend,v=\"constant\"===r.itemsizing;function m(t,e,r,n){var i;if(t+1)i=t;else{if(!(e&&e.width>0))return 0;i=e.width}return v?n:Math.min(i,r)}function y(t,e,r){var a=t[0].trace,o=a.marker||{},l=o.line||{},c=r?a.type===r&&a.visible:i.traceIs(a,\"bar\"),u=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(c?[t]:[]);u.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),u.exit().remove(),u.each(function(t){var e=n.select(this),r=t[0],i=m(r.mlw,o.line,g,p);e.style(\"stroke-width\",i+\"px\").call(s.fill,r.mc||o.color),i&&s.stroke(e,r.mlc||l.color)})}function x(t,e,r){var o=t[0],s=o.trace,l=r?s.type===r&&s.visible:i.traceIs(s,r),h=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(l?[t]:[]);if(h.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),h.exit().remove(),h.size()){var f=(s.marker||{}).line,d=m(u(f.width,o.pts),f,g,p),v=a.minExtend(s,{marker:{line:{width:d}}});v.marker.line.color=f.color;var y=a.minExtend(o,{trace:v});c(h,y,v)}}t.each(function(t){var e=n.select(this),i=a.ensureSingle(e,\"g\",\"layers\");i.style(\"opacity\",t[0].trace.opacity);var o=r.valign,s=t[0].lineHeight,l=t[0].height;if(\"middle\"!==o&&s&&l){var c={top:1,bottom:-1}[o]*(.5*(s-l+3));i.attr(\"transform\",\"translate(0,\"+c+\")\")}else i.attr(\"transform\",null);i.selectAll(\"g.legendfill\").data([t]).enter().append(\"g\").classed(\"legendfill\",!0),i.selectAll(\"g.legendlines\").data([t]).enter().append(\"g\").classed(\"legendlines\",!0);var u=i.selectAll(\"g.legendsymbols\").data([t]);u.enter().append(\"g\").classed(\"legendsymbols\",!0),u.selectAll(\"g.legendpoints\").data([t]).enter().append(\"g\").classed(\"legendpoints\",!0)}).each(function(t){var e=t[0].trace,r=[];\"waterfall\"===e.type&&e.visible&&(r=t[0].hasTotals?[[\"increasing\",\"M-6,-6V6H0Z\"],[\"totals\",\"M6,6H0L-6,-6H-0Z\"],[\"decreasing\",\"M6,6V-6H0Z\"]]:[[\"increasing\",\"M-6,-6V6H6Z\"],[\"decreasing\",\"M6,6V-6H-6Z\"]]);var i=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendwaterfall\").data(r);i.enter().append(\"path\").classed(\"legendwaterfall\",!0).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),i.exit().remove(),i.each(function(t){var r=n.select(this),i=e[t[0]].marker,a=m(void 0,i.line,g,p);r.attr(\"d\",t[1]).style(\"stroke-width\",a+\"px\").call(s.fill,i.color),a&&r.call(s.stroke,i.line.color)})}).each(function(t){y(t,this,\"funnel\")}).each(function(t){y(t,this)}).each(function(t){var r=t[0].trace,l=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendbox\").data(i.traceIs(r,\"box-violin\")&&r.visible?[t]:[]);l.enter().append(\"path\").classed(\"legendbox\",!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),l.exit().remove(),l.each(function(){var t=n.select(this);if(\"all\"!==r.boxpoints&&\"all\"!==r.points||0!==s.opacity(r.fillcolor)||0!==s.opacity((r.line||{}).color)){var i=m(void 0,r.line,g,p);t.style(\"stroke-width\",i+\"px\").call(s.fill,r.fillcolor),i&&s.stroke(t,r.line.color)}else{var c=a.minExtend(r,{marker:{size:v?h:a.constrain(r.marker.size,2,16),sizeref:1,sizemin:1,sizemode:\"diameter\"}});l.call(o.pointStyle,c,e)}})}).each(function(t){x(t,this,\"funnelarea\")}).each(function(t){x(t,this,\"pie\")}).each(function(t){var r,i,s=t[0],c=s.trace,u=c.visible&&c.fill&&\"none\"!==c.fill,h=l.hasLines(c),p=c.contours,g=!1,v=!1;if(p){var y=p.coloring;\"lines\"===y?g=!0:h=\"none\"===y||\"heatmap\"===y||p.showlines,\"constraint\"===p.type?u=\"=\"!==p._operation:\"fill\"!==y&&\"heatmap\"!==y||(v=!0)}var x=l.hasMarkers(c)||l.hasText(c),b=u||v,_=h||g,w=x||!b?\"M5,0\":_?\"M5,-2\":\"M5,-3\",k=n.select(this),T=k.select(\".legendfill\").selectAll(\"path\").data(u||v?[t]:[]);if(T.enter().append(\"path\").classed(\"js-fill\",!0),T.exit().remove(),T.attr(\"d\",w+\"h30v6h-30z\").call(u?o.fillGroupStyle:function(t){if(t.size()){var r=\"legendfill-\"+c.uid;o.gradient(t,e,r,\"horizontalreversed\",c.colorscale,\"fill\")}}),h||g){var A=m(void 0,c.line,d,f);i=a.minExtend(c,{line:{width:A}}),r=[a.minExtend(s,{trace:i})]}var M=k.select(\".legendlines\").selectAll(\"path\").data(h||g?[r]:[]);M.enter().append(\"path\").classed(\"js-line\",!0),M.exit().remove(),M.attr(\"d\",w+(g?\"l30,0.0001\":\"h30\")).call(h?o.lineGroupStyle:function(t){if(t.size()){var r=\"legendline-\"+c.uid;o.lineGroupStyle(t),o.gradient(t,e,r,\"horizontalreversed\",c.colorscale,\"stroke\")}})}).each(function(t){var r,i,s=t[0],c=s.trace,u=l.hasMarkers(c),d=l.hasText(c),g=l.hasLines(c);function m(t,e,r,n){var i=a.nestedProperty(c,t).get(),o=a.isArrayOrTypedArray(i)&&e?e(i):i;if(v&&o&&void 0!==n&&(o=n),r){if(o<r[0])return r[0];if(o>r[1])return r[1]}return o}function y(t){return t[0]}if(u||d||g){var x={},b={};if(u){x.mc=m(\"marker.color\",y),x.mx=m(\"marker.symbol\",y),x.mo=m(\"marker.opacity\",a.mean,[.2,1]),x.mlc=m(\"marker.line.color\",y),x.mlw=m(\"marker.line.width\",a.mean,[0,5],p),b.marker={sizeref:1,sizemin:1,sizemode:\"diameter\"};var _=m(\"marker.size\",a.mean,[2,16],h);x.ms=_,b.marker.size=_}g&&(b.line={width:m(\"line.width\",y,[0,10],f)}),d&&(x.tx=\"Aa\",x.tp=m(\"textposition\",y),x.ts=10,x.tc=m(\"textfont.color\",y),x.tf=m(\"textfont.family\",y)),r=[a.minExtend(s,x)],(i=a.minExtend(c,b)).selectedpoints=null}var w=n.select(this).select(\"g.legendpoints\"),k=w.selectAll(\"path.scatterpts\").data(u?r:[]);k.enter().insert(\"path\",\":first-child\").classed(\"scatterpts\",!0).attr(\"transform\",\"translate(20,0)\"),k.exit().remove(),k.call(o.pointStyle,i,e),u&&(r[0].mrc=3);var T=w.selectAll(\"g.pointtext\").data(d?r:[]);T.enter().append(\"g\").classed(\"pointtext\",!0).append(\"text\").attr(\"transform\",\"translate(20,0)\"),T.exit().remove(),T.selectAll(\"text\").call(o.textPointStyle,i,e)}).each(function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendcandle\").data(\"candlestick\"===e.type&&e.visible?[t,t]:[]);r.enter().append(\"path\").classed(\"legendcandle\",!0).attr(\"d\",function(t,e){return e?\"M-15,0H-8M-8,6V-6H8Z\":\"M15,0H8M8,-6V6H-8Z\"}).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),r.exit().remove(),r.each(function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],o=m(void 0,a.line,g,p);i.style(\"stroke-width\",o+\"px\").call(s.fill,a.fillcolor),o&&s.stroke(i,a.line.color)})}).each(function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendohlc\").data(\"ohlc\"===e.type&&e.visible?[t,t]:[]);r.enter().append(\"path\").classed(\"legendohlc\",!0).attr(\"d\",function(t,e){return e?\"M-15,0H0M-8,-6V0\":\"M15,0H0M8,6V0\"}).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),r.exit().remove(),r.each(function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],l=m(void 0,a.line,g,p);i.style(\"fill\",\"none\").call(o.dashLine,a.line.dash,l),l&&s.stroke(i,a.line.color)})})}},{\"../../lib\":719,\"../../registry\":847,\"../../traces/pie/helpers\":1091,\"../../traces/pie/style_one\":1097,\"../../traces/scatter/subtypes\":1135,\"../color\":593,\"../drawing\":614,d3:163}],651:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/plots\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../lib\"),s=t(\"../../fonts/ploticon\"),l=o._,c=e.exports={};function u(t,e){var r,i,o=e.currentTarget,s=o.getAttribute(\"data-attr\"),l=o.getAttribute(\"data-val\")||!0,c=t._fullLayout,u={},h=a.list(t,null,!0),f=\"on\";if(\"zoom\"===s){var p,d=\"in\"===l?.5:2,g=(1+d)/2,v=(1-d)/2;for(i=0;i<h.length;i++)if(!(r=h[i]).fixedrange)if(p=r._name,\"auto\"===l)u[p+\".autorange\"]=!0;else if(\"reset\"===l){if(void 0===r._rangeInitial)u[p+\".autorange\"]=!0;else{var m=r._rangeInitial.slice();u[p+\".range[0]\"]=m[0],u[p+\".range[1]\"]=m[1]}void 0!==r._showSpikeInitial&&(u[p+\".showspikes\"]=r._showSpikeInitial,\"on\"!==f||r._showSpikeInitial||(f=\"off\"))}else{var y=[r.r2l(r.range[0]),r.r2l(r.range[1])],x=[g*y[0]+v*y[1],g*y[1]+v*y[0]];u[p+\".range[0]\"]=r.l2r(x[0]),u[p+\".range[1]\"]=r.l2r(x[1])}c._cartesianSpikesEnabled=f}else{if(\"hovermode\"!==s||\"x\"!==l&&\"y\"!==l){if(\"hovermode\"===s&&\"closest\"===l){for(i=0;i<h.length;i++)r=h[i],\"on\"!==f||r.showspikes||(f=\"off\");c._cartesianSpikesEnabled=f}}else l=c._isHoriz?\"y\":\"x\",o.setAttribute(\"data-val\",l);u[s]=l}n.call(\"_guiRelayout\",t,u)}function h(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout._subplots.gl3d,s={},l=i.split(\".\"),c=0;c<o.length;c++)s[o[c]+\".\"+l[1]]=a;var u=\"pan\"===a?a:\"zoom\";s.dragmode=u,n.call(\"_guiRelayout\",t,s)}function f(t,e){for(var r=e.currentTarget.getAttribute(\"data-attr\"),i=t._fullLayout,a=i._subplots.gl3d,o={},s=0;s<a.length;s++){var l=a[s],c=l+\".camera\",u=i[l]._scene;\"resetLastSave\"===r?(o[c+\".up\"]=u.viewInitial.up,o[c+\".eye\"]=u.viewInitial.eye,o[c+\".center\"]=u.viewInitial.center):\"resetDefault\"===r&&(o[c+\".up\"]=null,o[c+\".eye\"]=null,o[c+\".center\"]=null)}n.call(\"_guiRelayout\",t,o)}function p(t,e){var r=e.currentTarget,n=r._previousVal,i=t._fullLayout,a=i._subplots.gl3d,o=[\"xaxis\",\"yaxis\",\"zaxis\"],s={},l={};if(n)l=n,r._previousVal=null;else{for(var c=0;c<a.length;c++){var u=a[c],h=i[u],f=u+\".hovermode\";s[f]=h.hovermode,l[f]=!1;for(var p=0;p<3;p++){var d=o[p],g=u+\".\"+d+\".showspikes\";l[g]=!1,s[g]=h[d].showspikes}}r._previousVal=s}return l}function d(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout,s=o._subplots.geo,l=0;l<s.length;l++){var c=s[l],u=o[c];if(\"zoom\"===i){var h=u.projection.scale,f=\"in\"===a?2*h:.5*h;n.call(\"_guiRelayout\",t,c+\".projection.scale\",f)}else\"reset\"===i&&m(t,\"geo\")}}function g(t){var e=t._fullLayout;return!e.hovermode&&(e._has(\"cartesian\")?e._isHoriz?\"y\":\"x\":\"closest\")}function v(t){var e=g(t);n.call(\"_guiRelayout\",t,\"hovermode\",e)}function m(t,e){for(var r=t._fullLayout,i=r._subplots[e],a={},o=0;o<i.length;o++)for(var s=i[o],l=r[s]._subplot.viewInitial,c=Object.keys(l),u=0;u<c.length;u++){var h=c[u];a[s+\".\"+h]=l[h]}n.call(\"_guiRelayout\",t,a)}c.toImage={name:\"toImage\",title:function(t){var e=(t._context.toImageButtonOptions||{}).format||\"png\";return l(t,\"png\"===e?\"Download plot as a png\":\"Download plot\")},icon:s.camera,click:function(t){var e=t._context.toImageButtonOptions,r={format:e.format||\"png\"};o.notifier(l(t,\"Taking snapshot - this may take a few seconds\"),\"long\"),\"svg\"!==r.format&&o.isIE()&&(o.notifier(l(t,\"IE only supports svg.  Changing format to svg.\"),\"long\"),r.format=\"svg\"),[\"filename\",\"width\",\"height\",\"scale\"].forEach(function(t){t in e&&(r[t]=e[t])}),n.call(\"downloadImage\",t,r).then(function(e){o.notifier(l(t,\"Snapshot succeeded\")+\" - \"+e,\"long\")}).catch(function(){o.notifier(l(t,\"Sorry, there was a problem downloading your snapshot!\"),\"long\")})}},c.sendDataToCloud={name:\"sendDataToCloud\",title:function(t){return l(t,\"Edit in Chart Studio\")},icon:s.disk,click:function(t){i.sendDataToCloud(t)}},c.editInChartStudio={name:\"editInChartStudio\",title:function(t){return l(t,\"Edit in Chart Studio\")},icon:s.pencil,click:function(t){i.sendDataToCloud(t)}},c.zoom2d={name:\"zoom2d\",title:function(t){return l(t,\"Zoom\")},attr:\"dragmode\",val:\"zoom\",icon:s.zoombox,click:u},c.pan2d={name:\"pan2d\",title:function(t){return l(t,\"Pan\")},attr:\"dragmode\",val:\"pan\",icon:s.pan,click:u},c.select2d={name:\"select2d\",title:function(t){return l(t,\"Box Select\")},attr:\"dragmode\",val:\"select\",icon:s.selectbox,click:u},c.lasso2d={name:\"lasso2d\",title:function(t){return l(t,\"Lasso Select\")},attr:\"dragmode\",val:\"lasso\",icon:s.lasso,click:u},c.zoomIn2d={name:\"zoomIn2d\",title:function(t){return l(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:s.zoom_plus,click:u},c.zoomOut2d={name:\"zoomOut2d\",title:function(t){return l(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:s.zoom_minus,click:u},c.autoScale2d={name:\"autoScale2d\",title:function(t){return l(t,\"Autoscale\")},attr:\"zoom\",val:\"auto\",icon:s.autoscale,click:u},c.resetScale2d={name:\"resetScale2d\",title:function(t){return l(t,\"Reset axes\")},attr:\"zoom\",val:\"reset\",icon:s.home,click:u},c.hoverClosestCartesian={name:\"hoverClosestCartesian\",title:function(t){return l(t,\"Show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:s.tooltip_basic,gravity:\"ne\",click:u},c.hoverCompareCartesian={name:\"hoverCompareCartesian\",title:function(t){return l(t,\"Compare data on hover\")},attr:\"hovermode\",val:function(t){return t._fullLayout._isHoriz?\"y\":\"x\"},icon:s.tooltip_compare,gravity:\"ne\",click:u},c.zoom3d={name:\"zoom3d\",title:function(t){return l(t,\"Zoom\")},attr:\"scene.dragmode\",val:\"zoom\",icon:s.zoombox,click:h},c.pan3d={name:\"pan3d\",title:function(t){return l(t,\"Pan\")},attr:\"scene.dragmode\",val:\"pan\",icon:s.pan,click:h},c.orbitRotation={name:\"orbitRotation\",title:function(t){return l(t,\"Orbital rotation\")},attr:\"scene.dragmode\",val:\"orbit\",icon:s[\"3d_rotate\"],click:h},c.tableRotation={name:\"tableRotation\",title:function(t){return l(t,\"Turntable rotation\")},attr:\"scene.dragmode\",val:\"turntable\",icon:s[\"z-axis\"],click:h},c.resetCameraDefault3d={name:\"resetCameraDefault3d\",title:function(t){return l(t,\"Reset camera to default\")},attr:\"resetDefault\",icon:s.home,click:f},c.resetCameraLastSave3d={name:\"resetCameraLastSave3d\",title:function(t){return l(t,\"Reset camera to last save\")},attr:\"resetLastSave\",icon:s.movie,click:f},c.hoverClosest3d={name:\"hoverClosest3d\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=p(t,e);n.call(\"_guiRelayout\",t,r)}},c.zoomInGeo={name:\"zoomInGeo\",title:function(t){return l(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:s.zoom_plus,click:d},c.zoomOutGeo={name:\"zoomOutGeo\",title:function(t){return l(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:s.zoom_minus,click:d},c.resetGeo={name:\"resetGeo\",title:function(t){return l(t,\"Reset\")},attr:\"reset\",val:null,icon:s.autoscale,click:d},c.hoverClosestGeo={name:\"hoverClosestGeo\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:v},c.hoverClosestGl2d={name:\"hoverClosestGl2d\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:v},c.hoverClosestPie={name:\"hoverClosestPie\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:s.tooltip_basic,gravity:\"ne\",click:v},c.resetViewSankey={name:\"resetSankeyGroup\",title:function(t){return l(t,\"Reset view\")},icon:s.home,click:function(t){for(var e={\"node.groups\":[],\"node.x\":[],\"node.y\":[]},r=0;r<t._fullData.length;r++){var i=t._fullData[r]._viewInitial;e[\"node.groups\"].push(i.node.groups.slice()),e[\"node.x\"].push(i.node.x.slice()),e[\"node.y\"].push(i.node.y.slice())}n.call(\"restyle\",t,e)}},c.toggleHover={name:\"toggleHover\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=p(t,e);r.hovermode=g(t),n.call(\"_guiRelayout\",t,r)}},c.resetViews={name:\"resetViews\",title:function(t){return l(t,\"Reset views\")},icon:s.home,click:function(t,e){var r=e.currentTarget;r.setAttribute(\"data-attr\",\"zoom\"),r.setAttribute(\"data-val\",\"reset\"),u(t,e),r.setAttribute(\"data-attr\",\"resetLastSave\"),f(t,e),m(t,\"geo\"),m(t,\"mapbox\")}},c.toggleSpikelines={name:\"toggleSpikelines\",title:function(t){return l(t,\"Toggle Spike Lines\")},icon:s.spikeline,attr:\"_cartesianSpikesEnabled\",val:\"on\",click:function(t){var e=t._fullLayout;e._cartesianSpikesEnabled=\"on\"===e._cartesianSpikesEnabled?\"off\":\"on\";var r=function(t){for(var e,r,n=t._fullLayout,i=a.list(t,null,!0),o={},s=0;s<i.length;s++)e=i[s],r=e._name,o[r+\".showspikes\"]=\"on\"===n._cartesianSpikesEnabled||e._showSpikeInitial;return o}(t);n.call(\"_guiRelayout\",t,r)}},c.resetViewMapbox={name:\"resetViewMapbox\",title:function(t){return l(t,\"Reset view\")},attr:\"reset\",icon:s.home,click:function(t){m(t,\"mapbox\")}}},{\"../../fonts/ploticon\":699,\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../../plots/plots\":828,\"../../registry\":847}],652:[function(t,e,r){\"use strict\";r.manage=t(\"./manage\")},{\"./manage\":653}],653:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"../../traces/scatter/subtypes\"),a=t(\"../../registry\"),o=t(\"./modebar\"),s=t(\"./buttons\");e.exports=function(t){var e=t._fullLayout,r=t._context,l=e._modeBar;if(r.displayModeBar||r.watermark){if(!Array.isArray(r.modeBarButtonsToRemove))throw new Error([\"*modeBarButtonsToRemove* configuration options\",\"must be an array.\"].join(\" \"));if(!Array.isArray(r.modeBarButtonsToAdd))throw new Error([\"*modeBarButtonsToAdd* configuration options\",\"must be an array.\"].join(\" \"));var c,u=r.modeBarButtons;c=Array.isArray(u)&&u.length?function(t){for(var e=0;e<t.length;e++)for(var r=t[e],n=0;n<r.length;n++){var i=r[n];if(\"string\"==typeof i){if(void 0===s[i])throw new Error([\"*modeBarButtons* configuration options\",\"invalid button name\"].join(\" \"));t[e][n]=s[i]}}return t}(u):!r.displayModeBar&&r.watermark?[]:function(t){var e=t._fullLayout,r=t._fullData,o=t._context,l=o.modeBarButtonsToRemove,c=o.modeBarButtonsToAdd,u=e._has(\"cartesian\"),h=e._has(\"gl3d\"),f=e._has(\"geo\"),p=e._has(\"pie\"),d=e._has(\"funnelarea\"),g=e._has(\"gl2d\"),v=e._has(\"ternary\"),m=e._has(\"mapbox\"),y=e._has(\"polar\"),x=e._has(\"sankey\"),b=function(t){for(var e=n.list({_fullLayout:t},null,!0),r=0;r<e.length;r++)if(!e[r].fixedrange)return!1;return!0}(e),_=[];function w(t){if(t.length){for(var e=[],r=0;r<t.length;r++){var n=t[r];-1===l.indexOf(n)&&e.push(s[n])}_.push(e)}}var k=[\"toImage\"];o.showEditInChartStudio?k.push(\"editInChartStudio\"):o.showSendToCloud&&k.push(\"sendDataToCloud\");w(k);var T=[],A=[],M=[],S=[];(u||g||p||d||v)+f+h+m+y>1?(A=[\"toggleHover\"],M=[\"resetViews\"]):f?(T=[\"zoomInGeo\",\"zoomOutGeo\"],A=[\"hoverClosestGeo\"],M=[\"resetGeo\"]):h?(A=[\"hoverClosest3d\"],M=[\"resetCameraDefault3d\",\"resetCameraLastSave3d\"]):m?(A=[\"toggleHover\"],M=[\"resetViewMapbox\"]):g?A=[\"hoverClosestGl2d\"]:p?A=[\"hoverClosestPie\"]:x?(A=[\"hoverClosestCartesian\",\"hoverCompareCartesian\"],M=[\"resetViewSankey\"]):A=[\"toggleHover\"];u&&(A=[\"toggleSpikelines\",\"hoverClosestCartesian\",\"hoverCompareCartesian\"]);(function(t){for(var e=0;e<t.length;e++)if(!a.traceIs(t[e],\"noHover\"))return!1;return!0})(r)&&(A=[]);!u&&!g||b||(T=[\"zoomIn2d\",\"zoomOut2d\",\"autoScale2d\"],\"resetViews\"!==M[0]&&(M=[\"resetScale2d\"]));h?S=[\"zoom3d\",\"pan3d\",\"orbitRotation\",\"tableRotation\"]:(u||g)&&!b||v?S=[\"zoom2d\",\"pan2d\"]:m||f?S=[\"pan2d\"]:y&&(S=[\"zoom2d\"]);(function(t){for(var e=!1,r=0;r<t.length&&!e;r++){var n=t[r];n._module&&n._module.selectPoints&&(a.traceIs(n,\"scatter-like\")?(i.hasMarkers(n)||i.hasText(n))&&(e=!0):a.traceIs(n,\"box-violin\")&&\"all\"!==n.boxpoints&&\"all\"!==n.points||(e=!0))}return e})(r)&&S.push(\"select2d\",\"lasso2d\");return w(S),w(T.concat(M)),w(A),function(t,e){if(e.length)if(Array.isArray(e[0]))for(var r=0;r<e.length;r++)t.push(e[r]);else t.push(e);return t}(_,c)}(t),l?l.update(t,c):e._modeBar=o(t,c)}else l&&(l.destroy(),delete e._modeBar)}},{\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../../traces/scatter/subtypes\":1135,\"./buttons\":651,\"./modebar\":654}],654:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../fonts/ploticon\"),s=new DOMParser;function l(t){this.container=t.container,this.element=document.createElement(\"div\"),this.update(t.graphInfo,t.buttons),this.container.appendChild(this.element)}var c=l.prototype;c.update=function(t,e){this.graphInfo=t;var r=this.graphInfo._context,n=this.graphInfo._fullLayout,i=\"modebar-\"+n._uid;this.element.setAttribute(\"id\",i),this._uid=i,this.element.className=\"modebar\",\"hover\"===r.displayModeBar&&(this.element.className+=\" modebar--hover ease-bg\"),\"v\"===n.modebar.orientation&&(this.element.className+=\" vertical\",e=e.reverse());var o=n.modebar,s=\"hover\"===r.displayModeBar?\".js-plotly-plot .plotly:hover \":\"\";a.deleteRelatedStyleRule(i),a.addRelatedStyleRule(i,s+\"#\"+i+\" .modebar-group\",\"background-color: \"+o.bgcolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn .icon path\",\"fill: \"+o.color),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn:hover .icon path\",\"fill: \"+o.activecolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn.active .icon path\",\"fill: \"+o.activecolor);var l=!this.hasButtons(e),c=this.hasLogo!==r.displaylogo,u=this.locale!==r.locale;if(this.locale=r.locale,(l||c||u)&&(this.removeAllButtons(),this.updateButtons(e),r.watermark||r.displaylogo)){var h=this.getLogo();r.watermark&&(h.className=h.className+\" watermark\"),\"v\"===n.modebar.orientation?this.element.insertBefore(h,this.element.childNodes[0]):this.element.appendChild(h),this.hasLogo=!0}this.updateActiveButton()},c.updateButtons=function(t){var e=this;this.buttons=t,this.buttonElements=[],this.buttonsNames=[],this.buttons.forEach(function(t){var r=e.createGroup();t.forEach(function(t){var n=t.name;if(!n)throw new Error(\"must provide button 'name' in button config\");if(-1!==e.buttonsNames.indexOf(n))throw new Error(\"button name '\"+n+\"' is taken\");e.buttonsNames.push(n);var i=e.createButton(t);e.buttonElements.push(i),r.appendChild(i)}),e.element.appendChild(r)})},c.createGroup=function(){var t=document.createElement(\"div\");return t.className=\"modebar-group\",t},c.createButton=function(t){var e=this,r=document.createElement(\"a\");r.setAttribute(\"rel\",\"tooltip\"),r.className=\"modebar-btn\";var i=t.title;void 0===i?i=t.name:\"function\"==typeof i&&(i=i(this.graphInfo)),(i||0===i)&&r.setAttribute(\"data-title\",i),void 0!==t.attr&&r.setAttribute(\"data-attr\",t.attr);var a=t.val;if(void 0!==a&&(\"function\"==typeof a&&(a=a(this.graphInfo)),r.setAttribute(\"data-val\",a)),\"function\"!=typeof t.click)throw new Error(\"must provide button 'click' function in button config\");r.addEventListener(\"click\",function(r){t.click(e.graphInfo,r),e.updateActiveButton(r.currentTarget)}),r.setAttribute(\"data-toggle\",t.toggle||!1),t.toggle&&n.select(r).classed(\"active\",!0);var s=t.icon;return\"function\"==typeof s?r.appendChild(s()):r.appendChild(this.createIcon(s||o.question)),r.setAttribute(\"data-gravity\",t.gravity||\"n\"),r},c.createIcon=function(t){var e,r=i(t.height)?Number(t.height):t.ascent-t.descent,n=\"http://www.w3.org/2000/svg\";if(t.path){(e=document.createElementNS(n,\"svg\")).setAttribute(\"viewBox\",[0,0,t.width,r].join(\" \")),e.setAttribute(\"class\",\"icon\");var a=document.createElementNS(n,\"path\");a.setAttribute(\"d\",t.path),t.transform?a.setAttribute(\"transform\",t.transform):void 0!==t.ascent&&a.setAttribute(\"transform\",\"matrix(1 0 0 -1 0 \"+t.ascent+\")\"),e.appendChild(a)}t.svg&&(e=s.parseFromString(t.svg,\"application/xml\").childNodes[0]);return e.setAttribute(\"height\",\"1em\"),e.setAttribute(\"width\",\"1em\"),e},c.updateActiveButton=function(t){var e=this.graphInfo._fullLayout,r=void 0!==t?t.getAttribute(\"data-attr\"):null;this.buttonElements.forEach(function(t){var i=t.getAttribute(\"data-val\")||!0,o=t.getAttribute(\"data-attr\"),s=\"true\"===t.getAttribute(\"data-toggle\"),l=n.select(t);if(s)o===r&&l.classed(\"active\",!l.classed(\"active\"));else{var c=null===o?o:a.nestedProperty(e,o).get();l.classed(\"active\",c===i)}})},c.hasButtons=function(t){var e=this.buttons;if(!e)return!1;if(t.length!==e.length)return!1;for(var r=0;r<t.length;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;n++)if(t[r][n].name!==e[r][n].name)return!1}return!0},c.getLogo=function(){var t=this.createGroup(),e=document.createElement(\"a\");return e.href=\"https://plot.ly/\",e.target=\"_blank\",e.setAttribute(\"data-title\",a._(this.graphInfo,\"Produced with Plotly\")),e.className=\"modebar-btn plotlyjsicon modebar-btn--logo\",e.appendChild(this.createIcon(o.newplotlylogo)),t.appendChild(e),t},c.removeAllButtons=function(){for(;this.element.firstChild;)this.element.removeChild(this.element.firstChild);this.hasLogo=!1},c.destroy=function(){a.removeElement(this.container.querySelector(\".modebar\")),a.deleteRelatedStyleRule(this._uid)},e.exports=function(t,e){var r=t._fullLayout,i=new l({graphInfo:t,container:r._modebardiv.node(),buttons:e});return r._privateplot&&n.select(i.element).append(\"span\").classed(\"badge-private float--left\",!0).text(\"PRIVATE\"),i}},{\"../../fonts/ploticon\":699,\"../../lib\":719,d3:163,\"fast-isnumeric\":225}],655:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=(0,t(\"../../plot_api/plot_template\").templatedArray)(\"button\",{visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},step:{valType:\"enumerated\",values:[\"month\",\"year\",\"day\",\"hour\",\"minute\",\"second\",\"all\"],dflt:\"month\",editType:\"plot\"},stepmode:{valType:\"enumerated\",values:[\"backward\",\"todate\"],dflt:\"backward\",editType:\"plot\"},count:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},label:{valType:\"string\",editType:\"plot\"},editType:\"plot\"});e.exports={visible:{valType:\"boolean\",editType:\"plot\"},buttons:a,x:{valType:\"number\",min:-2,max:3,editType:\"plot\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"plot\"},y:{valType:\"number\",min:-2,max:3,editType:\"plot\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"bottom\",editType:\"plot\"},font:n({editType:\"plot\"}),bgcolor:{valType:\"color\",dflt:i.lightLine,editType:\"plot\"},activecolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"plot\"}},{\"../../plot_api/plot_template\":757,\"../../plots/font_attributes\":793,\"../color/attributes\":592}],656:[function(t,e,r){\"use strict\";e.exports={yPad:.02,minButtonWidth:30,rx:3,ry:3,lightAmount:25,darkAmount:10}},{}],657:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../../plots/array_container_defaults\"),s=t(\"./attributes\"),l=t(\"./constants\");function c(t,e,r,i){var a=i.calendar;function o(r,i){return n.coerce(t,e,s.buttons,r,i)}if(o(\"visible\")){var l=o(\"step\");\"all\"!==l&&(!a||\"gregorian\"===a||\"month\"!==l&&\"year\"!==l?o(\"stepmode\"):e.stepmode=\"backward\",o(\"count\")),o(\"label\")}}e.exports=function(t,e,r,u,h){var f=t.rangeselector||{},p=a.newContainer(e,\"rangeselector\");function d(t,e){return n.coerce(f,p,s,t,e)}if(d(\"visible\",o(f,p,{name:\"buttons\",handleItemDefaults:c,calendar:h}).length>0)){var g=function(t,e,r){for(var n=r.filter(function(r){return e[r].anchor===t._id}),i=0,a=0;a<n.length;a++){var o=e[n[a]].domain;o&&(i=Math.max(o[1],i))}return[t.domain[0],i+l.yPad]}(e,r,u);d(\"x\",g[0]),d(\"y\",g[1]),n.noneOrAll(t,e,[\"x\",\"y\"]),d(\"xanchor\"),d(\"yanchor\"),n.coerceFont(d,\"font\",r.font);var v=d(\"bgcolor\");d(\"activecolor\",i.contrast(v,l.lightAmount,l.darkAmount)),d(\"bordercolor\"),d(\"borderwidth\")}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/array_container_defaults\":763,\"../color\":593,\"./attributes\":655,\"./constants\":656}],658:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../color\"),s=t(\"../drawing\"),l=t(\"../../lib\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"../../plots/cartesian/axis_ids\"),h=t(\"../../constants/alignment\"),f=h.LINE_SPACING,p=h.FROM_TL,d=h.FROM_BR,g=t(\"./constants\"),v=t(\"./get_update_object\");function m(t){return t._id}function y(t,e,r){var n=l.ensureSingle(t,\"rect\",\"selector-rect\",function(t){t.attr(\"shape-rendering\",\"crispEdges\")});n.attr({rx:g.rx,ry:g.ry}),n.call(o.stroke,e.bordercolor).call(o.fill,function(t,e){return e._isActive||e._isHovered?t.activecolor:t.bgcolor}(e,r)).style(\"stroke-width\",e.borderwidth+\"px\")}function x(t,e,r,n){l.ensureSingle(t,\"text\",\"selector-text\",function(t){t.classed(\"user-select-none\",!0).attr(\"text-anchor\",\"middle\")}).call(s.font,e.font).text(function(t,e){if(t.label)return e?l.templateString(t.label,e):t.label;return\"all\"===t.step?\"all\":t.count+t.step.charAt(0)}(r,n._fullLayout._meta)).call(function(t){c.convertToTspans(t,n)})}e.exports=function(t){var e=t._fullLayout._infolayer.selectAll(\".rangeselector\").data(function(t){for(var e=u.list(t,\"x\",!0),r=[],n=0;n<e.length;n++){var i=e[n];i.rangeselector&&i.rangeselector.visible&&r.push(i)}return r}(t),m);e.enter().append(\"g\").classed(\"rangeselector\",!0),e.exit().remove(),e.style({cursor:\"pointer\",\"pointer-events\":\"all\"}),e.each(function(e){var r=n.select(this),o=e,u=o.rangeselector,h=r.selectAll(\"g.button\").data(l.filterVisible(u.buttons));h.enter().append(\"g\").classed(\"button\",!0),h.exit().remove(),h.each(function(e){var r=n.select(this),a=v(o,e);e._isActive=function(t,e,r){if(\"all\"===e.step)return!0===t.autorange;var n=Object.keys(r);return t.range[0]===r[n[0]]&&t.range[1]===r[n[1]]}(o,e,a),r.call(y,u,e),r.call(x,u,e,t),r.on(\"click\",function(){t._dragged||i.call(\"_guiRelayout\",t,a)}),r.on(\"mouseover\",function(){e._isHovered=!0,r.call(y,u,e)}),r.on(\"mouseout\",function(){e._isHovered=!1,r.call(y,u,e)})}),function(t,e,r,i,o){var u=0,h=0,v=r.borderwidth;e.each(function(){var t=n.select(this),e=t.select(\".selector-text\"),i=r.font.size*f,a=Math.max(i*c.lineCount(e),16)+3;h=Math.max(h,a)}),e.each(function(){var t=n.select(this),e=t.select(\".selector-rect\"),i=t.select(\".selector-text\"),a=i.node()&&s.bBox(i.node()).width,o=r.font.size*f,l=c.lineCount(i),p=Math.max(a+10,g.minButtonWidth);t.attr(\"transform\",\"translate(\"+(v+u)+\",\"+v+\")\"),e.attr({x:0,y:0,width:p,height:h}),c.positionText(i,p/2,h/2-(l-1)*o/2+3),u+=p+5});var m=t._fullLayout._size,y=m.l+m.w*r.x,x=m.t+m.h*(1-r.y),b=\"left\";l.isRightAnchor(r)&&(y-=u,b=\"right\");l.isCenterAnchor(r)&&(y-=u/2,b=\"center\");var _=\"top\";l.isBottomAnchor(r)&&(x-=h,_=\"bottom\");l.isMiddleAnchor(r)&&(x-=h/2,_=\"middle\");u=Math.ceil(u),h=Math.ceil(h),y=Math.round(y),x=Math.round(x),a.autoMargin(t,i+\"-range-selector\",{x:r.x,y:r.y,l:u*p[b],r:u*d[b],b:h*d[_],t:h*p[_]}),o.attr(\"transform\",\"translate(\"+y+\",\"+x+\")\")}(t,h,u,o._name,r)})}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axis_ids\":770,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../drawing\":614,\"./constants\":656,\"./get_update_object\":659,d3:163}],659:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e){var r=t._name,i={};if(\"all\"===e.step)i[r+\".autorange\"]=!0;else{var a=function(t,e){var r,i=t.range,a=new Date(t.r2l(i[1])),o=e.step,s=e.count;switch(e.stepmode){case\"backward\":r=t.l2r(+n.time[o].utc.offset(a,-s));break;case\"todate\":var l=n.time[o].utc.offset(a,-s);r=t.l2r(+n.time[o].utc.ceil(l))}var c=i[1];return[r,c]}(t,e);i[r+\".range[0]\"]=a[0],i[r+\".range[1]\"]=a[1]}return i}},{d3:163}],660:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"rangeselector\",schema:{subplots:{xaxis:{rangeselector:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":655,\"./defaults\":657,\"./draw\":658}],661:[function(t,e,r){\"use strict\";var n=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",dflt:n.background,editType:\"plot\"},bordercolor:{valType:\"color\",dflt:n.defaultLine,editType:\"plot\"},borderwidth:{valType:\"integer\",dflt:0,min:0,editType:\"plot\"},autorange:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}}],editType:\"calc\",impliedEdits:{autorange:!1}},thickness:{valType:\"number\",dflt:.15,min:0,max:1,editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"}},{\"../color/attributes\":592}],662:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\").list,i=t(\"../../plots/cartesian/autorange\").getAutoRange,a=t(\"./constants\");e.exports=function(t){for(var e=n(t,\"x\",!0),r=0;r<e.length;r++){var o=e[r],s=o[a.name];s&&s.visible&&s.autorange&&(s._input.autorange=!0,s._input.range=s.range=i(t,o))}}},{\"../../plots/cartesian/autorange\":766,\"../../plots/cartesian/axis_ids\":770,\"./constants\":663}],663:[function(t,e,r){\"use strict\";e.exports={name:\"rangeslider\",containerClassName:\"rangeslider-container\",bgClassName:\"rangeslider-bg\",rangePlotClassName:\"rangeslider-rangeplot\",maskMinClassName:\"rangeslider-mask-min\",maskMaxClassName:\"rangeslider-mask-max\",slideBoxClassName:\"rangeslider-slidebox\",grabberMinClassName:\"rangeslider-grabber-min\",grabAreaMinClassName:\"rangeslider-grabarea-min\",handleMinClassName:\"rangeslider-handle-min\",grabberMaxClassName:\"rangeslider-grabber-max\",grabAreaMaxClassName:\"rangeslider-grabarea-max\",handleMaxClassName:\"rangeslider-handle-max\",maskMinOppAxisClassName:\"rangeslider-mask-min-opp-axis\",maskMaxOppAxisClassName:\"rangeslider-mask-max-opp-axis\",maskColor:\"rgba(0,0,0,0.4)\",maskOppAxisColor:\"rgba(0,0,0,0.2)\",slideBoxFill:\"transparent\",slideBoxCursor:\"ew-resize\",grabAreaFill:\"transparent\",grabAreaCursor:\"col-resize\",grabAreaWidth:10,handleWidth:4,handleRadius:1,handleStrokeWidth:1,extraPad:15}},{}],664:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"./attributes\"),s=t(\"./oppaxis_attributes\");e.exports=function(t,e,r){var l=t[r],c=e[r];if(l.rangeslider||e._requestRangeslider[c._id]){n.isPlainObject(l.rangeslider)||(l.rangeslider={});var u,h,f=l.rangeslider,p=i.newContainer(c,\"rangeslider\");if(_(\"visible\")){_(\"bgcolor\",e.plot_bgcolor),_(\"bordercolor\"),_(\"borderwidth\"),_(\"thickness\"),_(\"autorange\",!c.isValidRange(f.range)),_(\"range\");var d=e._subplots;if(d)for(var g=d.cartesian.filter(function(t){return t.substr(0,t.indexOf(\"y\"))===a.name2id(r)}).map(function(t){return t.substr(t.indexOf(\"y\"),t.length)}),v=n.simpleMap(g,a.id2name),m=0;m<v.length;m++){var y=v[m];u=f[y]||{},h=i.newContainer(p,y,\"yaxis\");var x,b=e[y];u.range&&b.isValidRange(u.range)&&(x=\"fixed\"),\"match\"!==w(\"rangemode\",x)&&w(\"range\",b.range.slice())}p._input=f}}function _(t,e){return n.coerce(f,p,o,t,e)}function w(t,e){return n.coerce(u,h,s,t,e)}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/axis_ids\":770,\"./attributes\":661,\"./oppaxis_attributes\":668}],665:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=t(\"../drawing\"),l=t(\"../color\"),c=t(\"../titles\"),u=t(\"../../plots/cartesian\"),h=t(\"../../plots/cartesian/axis_ids\"),f=t(\"../dragelement\"),p=t(\"../../lib/setcursor\"),d=t(\"./constants\");function g(t,e,r,n){var i=o.ensureSingle(t,\"rect\",d.bgClassName,function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})}),a=n.borderwidth%2==0?n.borderwidth:n.borderwidth-1,l=-n._offsetShift,c=s.crispRound(e,n.borderwidth);i.attr({width:n._width+a,height:n._height+a,transform:\"translate(\"+l+\",\"+l+\")\",fill:n.bgcolor,stroke:n.bordercolor,\"stroke-width\":c})}function v(t,e,r,n){var i=e._fullLayout;o.ensureSingleById(i._topdefs,\"clipPath\",n._clipId,function(t){t.append(\"rect\").attr({x:0,y:0})}).select(\"rect\").attr({width:n._width,height:n._height})}function m(t,e,r,i){var l,c=e.calcdata,f=t.selectAll(\"g.\"+d.rangePlotClassName).data(r._subplotsWith,o.identity);f.enter().append(\"g\").attr(\"class\",function(t){return d.rangePlotClassName+\" \"+t}).call(s.setClipUrl,i._clipId,e),f.order(),f.exit().remove(),f.each(function(t,o){var s=n.select(this),f=0===o,p=h.getFromId(e,t,\"y\"),d=p._name,g=i[d],v={data:[],layout:{xaxis:{type:r.type,domain:[0,1],range:i.range.slice(),calendar:r.calendar},width:i._width,height:i._height,margin:{t:0,b:0,l:0,r:0}},_context:e._context};v.layout[d]={type:p.type,domain:[0,1],range:\"match\"!==g.rangemode?g.range.slice():p.range.slice(),calendar:p.calendar},a.supplyDefaults(v);var m=v._fullLayout.xaxis,y=v._fullLayout[d];m.clearCalc(),m.setScale(),y.clearCalc(),y.setScale();var x={id:t,plotgroup:s,xaxis:m,yaxis:y,isRangePlot:!0};f?l=x:(x.mainplot=\"xy\",x.mainplotinfo=l),u.rangePlot(e,x,function(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n],a=i[0].trace;a.xaxis+a.yaxis===e&&r.push(i)}return r}(c,t))})}function y(t,e,r,n,i){(o.ensureSingle(t,\"rect\",d.maskMinClassName,function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"height\",n._height).call(l.fill,d.maskColor),o.ensureSingle(t,\"rect\",d.maskMaxClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"height\",n._height).call(l.fill,d.maskColor),\"match\"!==i.rangemode)&&(o.ensureSingle(t,\"rect\",d.maskMinOppAxisClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"width\",n._width).call(l.fill,d.maskOppAxisColor),o.ensureSingle(t,\"rect\",d.maskMaxOppAxisClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"width\",n._width).style(\"border-top\",d.maskOppBorder).call(l.fill,d.maskOppAxisColor))}function x(t,e,r,n){e._context.staticPlot||o.ensureSingle(t,\"rect\",d.slideBoxClassName,function(t){t.attr({y:0,cursor:d.slideBoxCursor,\"shape-rendering\":\"crispEdges\"})}).attr({height:n._height,fill:d.slideBoxFill})}function b(t,e,r,n){var i=o.ensureSingle(t,\"g\",d.grabberMinClassName),a=o.ensureSingle(t,\"g\",d.grabberMaxClassName),s={x:0,width:d.handleWidth,rx:d.handleRadius,fill:l.background,stroke:l.defaultLine,\"stroke-width\":d.handleStrokeWidth,\"shape-rendering\":\"crispEdges\"},c={y:Math.round(n._height/4),height:Math.round(n._height/2)};if(o.ensureSingle(i,\"rect\",d.handleMinClassName,function(t){t.attr(s)}).attr(c),o.ensureSingle(a,\"rect\",d.handleMaxClassName,function(t){t.attr(s)}).attr(c),!e._context.staticPlot){var u={width:d.grabAreaWidth,x:0,y:0,fill:d.grabAreaFill,cursor:d.grabAreaCursor};o.ensureSingle(i,\"rect\",d.grabAreaMinClassName,function(t){t.attr(u)}).attr(\"height\",n._height),o.ensureSingle(a,\"rect\",d.grabAreaMaxClassName,function(t){t.attr(u)}).attr(\"height\",n._height)}}e.exports=function(t){for(var e=t._fullLayout,r=e._rangeSliderData,a=0;a<r.length;a++){var s=r[a][d.name];s._clipId=s._id+\"-\"+e._uid}var l=e._infolayer.selectAll(\"g.\"+d.containerClassName).data(r,function(t){return t._name});l.exit().each(function(t){var r=t[d.name];e._topdefs.select(\"#\"+r._clipId).remove()}).remove(),0!==r.length&&(l.enter().append(\"g\").classed(d.containerClassName,!0).attr(\"pointer-events\",\"all\"),l.each(function(r){var a=n.select(this),s=r[d.name],l=e[h.id2name(r.anchor)],u=s[h.id2name(r.anchor)];if(s.range){var _,w=o.simpleMap(s.range,r.r2l),k=o.simpleMap(r.range,r.r2l);_=k[0]<k[1]?[Math.min(w[0],k[0]),Math.max(w[1],k[1])]:[Math.max(w[0],k[0]),Math.min(w[1],k[1])],s.range=s._input.range=o.simpleMap(_,r.l2r)}r.cleanRange(\"rangeslider.range\");var T=e.margin,A=e._size,M=r.domain,S=s._tickHeight,E=s._oppBottom;s._width=A.w*(M[1]-M[0]);var C=Math.round(T.l+A.w*M[0]),L=Math.round(A.t+A.h*(1-E)+S+s._offsetShift+d.extraPad);a.attr(\"transform\",\"translate(\"+C+\",\"+L+\")\");var P=r.r2l(s.range[0]),O=r.r2l(s.range[1]),z=O-P;if(s.p2d=function(t){return t/s._width*z+P},s.d2p=function(t){return(t-P)/z*s._width},s._rl=[P,O],\"match\"!==u.rangemode){var I=l.r2l(u.range[0]),D=l.r2l(u.range[1])-I;s.d2pOppAxis=function(t){return(t-I)/D*s._height}}a.call(g,t,r,s).call(v,t,r,s).call(m,t,r,s).call(y,t,r,s,u).call(x,t,r,s).call(b,t,r,s),function(t,e,r,a){var s=t.select(\"rect.\"+d.slideBoxClassName).node(),l=t.select(\"rect.\"+d.grabAreaMinClassName).node(),c=t.select(\"rect.\"+d.grabAreaMaxClassName).node();t.on(\"mousedown\",function(){var u=n.event,h=u.target,d=u.clientX,g=d-t.node().getBoundingClientRect().left,v=a.d2p(r._rl[0]),m=a.d2p(r._rl[1]),y=f.coverSlip();function x(t){var u,f,x,b=+t.clientX-d;switch(h){case s:x=\"ew-resize\",u=v+b,f=m+b;break;case l:x=\"col-resize\",u=v+b,f=m;break;case c:x=\"col-resize\",u=v,f=m+b;break;default:x=\"ew-resize\",u=g,f=g+b}if(f<u){var _=f;f=u,u=_}a._pixelMin=u,a._pixelMax=f,p(n.select(y),x),function(t,e,r,n){function a(t){return r.l2r(o.constrain(t,n._rl[0],n._rl[1]))}var s=a(n.p2d(n._pixelMin)),l=a(n.p2d(n._pixelMax));window.requestAnimationFrame(function(){i.call(\"_guiRelayout\",e,r._name+\".range\",[s,l])})}(0,e,r,a)}y.addEventListener(\"mousemove\",x),y.addEventListener(\"mouseup\",function t(){y.removeEventListener(\"mousemove\",x);y.removeEventListener(\"mouseup\",t);o.removeElement(y)})})}(a,t,r,s),function(t,e,r,n,i,a){var s=d.handleWidth/2;function l(t){return o.constrain(t,0,n._width)}function c(t){return o.constrain(t,0,n._height)}function u(t){return o.constrain(t,-s,n._width+s)}var h=l(n.d2p(r._rl[0])),f=l(n.d2p(r._rl[1]));if(t.select(\"rect.\"+d.slideBoxClassName).attr(\"x\",h).attr(\"width\",f-h),t.select(\"rect.\"+d.maskMinClassName).attr(\"width\",h),t.select(\"rect.\"+d.maskMaxClassName).attr(\"x\",f).attr(\"width\",n._width-f),\"match\"!==a.rangemode){var p=n._height-c(n.d2pOppAxis(i._rl[1])),g=n._height-c(n.d2pOppAxis(i._rl[0]));t.select(\"rect.\"+d.maskMinOppAxisClassName).attr(\"x\",h).attr(\"height\",p).attr(\"width\",f-h),t.select(\"rect.\"+d.maskMaxOppAxisClassName).attr(\"x\",h).attr(\"y\",g).attr(\"height\",n._height-g).attr(\"width\",f-h),t.select(\"rect.\"+d.slideBoxClassName).attr(\"y\",p).attr(\"height\",g-p)}var v=Math.round(u(h-s))-.5,m=Math.round(u(f-s))+.5;t.select(\"g.\"+d.grabberMinClassName).attr(\"transform\",\"translate(\"+v+\",0.5)\"),t.select(\"g.\"+d.grabberMaxClassName).attr(\"transform\",\"translate(\"+m+\",0.5)\")}(a,0,r,s,l,u),\"bottom\"===r.side&&c.draw(t,r._id+\"title\",{propContainer:r,propName:r._name+\".title\",placeholder:e._dfltTitle.x,attributes:{x:r._offset+r._length/2,y:L+s._height+s._offsetShift+10+1.5*r.title.font.size,\"text-anchor\":\"middle\"}})}))}},{\"../../lib\":719,\"../../lib/setcursor\":739,\"../../plots/cartesian\":778,\"../../plots/cartesian/axis_ids\":770,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"../titles\":681,\"./constants\":663,d3:163}],666:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"./constants\"),a=i.name;function o(t){var e=t&&t[a];return e&&e.visible}r.isVisible=o,r.makeData=function(t){var e=n.list({_fullLayout:t},\"x\",!0),r=t.margin,i=[];if(!t._has(\"gl2d\"))for(var s=0;s<e.length;s++){var l=e[s];if(o(l)){i.push(l);var c=l[a];c._id=a+l._id,c._height=(t.height-r.b-r.t)*c.thickness,c._offsetShift=Math.floor(c.borderwidth/2)}}t._rangeSliderData=i},r.autoMarginOpts=function(t,e){for(var r=e[a],o=1/0,s=e._counterAxes,l=0;l<s.length;l++){var c=s[l],u=n.getFromId(t,c);o=Math.min(o,u.domain[0])}r._oppBottom=o;var h=\"bottom\"===e.side&&e._boundingBox.height||0;return r._tickHeight=h,{x:0,y:o,l:0,r:0,t:0,b:r._height+t._fullLayout.margin.b+h,pad:i.extraPad+2*r._offsetShift}}},{\"../../plots/cartesian/axis_ids\":770,\"./constants\":663}],667:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./oppaxis_attributes\"),o=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"rangeslider\",schema:{subplots:{xaxis:{rangeslider:n.extendFlat({},i,{yaxis:a})}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),calcAutorange:t(\"./calc_autorange\"),draw:t(\"./draw\"),isVisible:o.isVisible,makeData:o.makeData,autoMarginOpts:o.autoMarginOpts}},{\"../../lib\":719,\"./attributes\":661,\"./calc_autorange\":662,\"./defaults\":664,\"./draw\":665,\"./helpers\":666,\"./oppaxis_attributes\":668}],668:[function(t,e,r){\"use strict\";e.exports={_isSubplotObj:!0,rangemode:{valType:\"enumerated\",values:[\"auto\",\"fixed\",\"match\"],dflt:\"match\",editType:\"calc\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"plot\"},{valType:\"any\",editType:\"plot\"}],editType:\"plot\"},editType:\"calc\"}},{}],669:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../traces/scatter/attributes\").line,a=t(\"../drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray;e.exports=s(\"shape\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},type:{valType:\"enumerated\",values:[\"circle\",\"rect\",\"path\",\"line\"],editType:\"calc+arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},xref:o({},n.xref,{}),xsizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},xanchor:{valType:\"any\",editType:\"calc+arraydraw\"},x0:{valType:\"any\",editType:\"calc+arraydraw\"},x1:{valType:\"any\",editType:\"calc+arraydraw\"},yref:o({},n.yref,{}),ysizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},yanchor:{valType:\"any\",editType:\"calc+arraydraw\"},y0:{valType:\"any\",editType:\"calc+arraydraw\"},y1:{valType:\"any\",editType:\"calc+arraydraw\"},path:{valType:\"string\",editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},line:{color:o({},i.color,{editType:\"arraydraw\"}),width:o({},i.width,{editType:\"calc+arraydraw\"}),dash:o({},a,{editType:\"arraydraw\"}),editType:\"calc+arraydraw\"},fillcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},editType:\"arraydraw\"})},{\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../../traces/scatter/attributes\":1112,\"../annotations/attributes\":576,\"../drawing/attributes\":613}],670:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./constants\"),o=t(\"./helpers\");function s(t){return c(t.line.width,t.xsizemode,t.x0,t.x1,t.path,!1)}function l(t){return c(t.line.width,t.ysizemode,t.y0,t.y1,t.path,!0)}function c(t,e,r,i,s,l){var c=t/2,u=l;if(\"pixel\"===e){var h=s?o.extractPathCoords(s,l?a.paramIsY:a.paramIsX):[r,i],f=n.aggNums(Math.max,null,h),p=n.aggNums(Math.min,null,h),d=p<0?Math.abs(p)+c:c,g=f>0?f+c:c;return{ppad:c,ppadplus:u?d:g,ppadminus:u?g:d}}return{ppad:c}}function u(t,e,r,n,i){var s=\"category\"===t.type||\"multicategory\"===t.type?t.r2c:t.d2c;if(void 0!==e)return[s(e),s(r)];if(n){var l,c,u,h,f=1/0,p=-1/0,d=n.match(a.segmentRE);for(\"date\"===t.type&&(s=o.decodeDate(s)),l=0;l<d.length;l++)void 0!==(c=i[d[l].charAt(0)].drawn)&&(!(u=d[l].substr(1).match(a.paramRE))||u.length<c||((h=s(u[c]))<f&&(f=h),h>p&&(p=h)));return p>=f?[f,p]:void 0}}e.exports=function(t){var e=t._fullLayout,r=n.filterVisible(e.shapes);if(r.length&&t._fullData.length)for(var o=0;o<r.length;o++){var c,h,f=r[o];if(f._extremes={},\"paper\"!==f.xref){var p=\"pixel\"===f.xsizemode?f.xanchor:f.x0,d=\"pixel\"===f.xsizemode?f.xanchor:f.x1;(h=u(c=i.getFromId(t,f.xref),p,d,f.path,a.paramIsX))&&(f._extremes[c._id]=i.findExtremes(c,h,s(f)))}if(\"paper\"!==f.yref){var g=\"pixel\"===f.ysizemode?f.yanchor:f.y0,v=\"pixel\"===f.ysizemode?f.yanchor:f.y1;(h=u(c=i.getFromId(t,f.yref),g,v,f.path,a.paramIsY))&&(f._extremes[c._id]=i.findExtremes(c,h,l(f)))}}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./constants\":671,\"./helpers\":674}],671:[function(t,e,r){\"use strict\";e.exports={segmentRE:/[MLHVQCTSZ][^MLHVQCTSZ]*/g,paramRE:/[^\\s,]+/g,paramIsX:{M:{0:!0,drawn:0},L:{0:!0,drawn:0},H:{0:!0,drawn:0},V:{},Q:{0:!0,2:!0,drawn:2},C:{0:!0,2:!0,4:!0,drawn:4},T:{0:!0,drawn:0},S:{0:!0,2:!0,drawn:2},Z:{}},paramIsY:{M:{1:!0,drawn:1},L:{1:!0,drawn:1},H:{},V:{0:!0,drawn:0},Q:{1:!0,3:!0,drawn:3},C:{1:!0,3:!0,5:!0,drawn:5},T:{1:!0,drawn:1},S:{1:!0,3:!0,drawn:5},Z:{}},numParams:{M:2,L:2,H:1,V:1,Q:4,C:6,T:2,S:4,Z:0}}},{}],672:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\"),s=t(\"./helpers\");function l(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}if(a(\"visible\")){a(\"layer\"),a(\"opacity\"),a(\"fillcolor\"),a(\"line.color\"),a(\"line.width\"),a(\"line.dash\");for(var l=a(\"type\",t.path?\"path\":\"rect\"),c=a(\"xsizemode\"),u=a(\"ysizemode\"),h=[\"x\",\"y\"],f=0;f<2;f++){var p,d,g,v=h[f],m=v+\"anchor\",y=\"x\"===v?c:u,x={_fullLayout:r},b=i.coerceRef(t,e,x,v,\"\",\"paper\");if(\"paper\"!==b?((p=i.getFromId(x,b))._shapeIndices.push(e._index),g=s.rangeToShapePosition(p),d=s.shapePositionToRange(p)):d=g=n.identity,\"path\"!==l){var _=v+\"0\",w=v+\"1\",k=t[_],T=t[w];t[_]=d(t[_],!0),t[w]=d(t[w],!0),\"pixel\"===y?(a(_,0),a(w,10)):(i.coercePosition(e,x,a,b,_,.25),i.coercePosition(e,x,a,b,w,.75)),e[_]=g(e[_]),e[w]=g(e[w]),t[_]=k,t[w]=T}if(\"pixel\"===y){var A=t[m];t[m]=d(t[m],!0),i.coercePosition(e,x,a,b,m,.25),e[m]=g(e[m]),t[m]=A}}\"path\"===l?a(\"path\"):n.noneOrAll(t,e,[\"x0\",\"x1\",\"y0\",\"y1\"])}}e.exports=function(t,e){a(t,e,{name:\"shapes\",handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"./attributes\":669,\"./helpers\":674}],673:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../color\"),s=t(\"../drawing\"),l=t(\"../../plot_api/plot_template\").arrayEditor,c=t(\"../dragelement\"),u=t(\"../../lib/setcursor\"),h=t(\"./constants\"),f=t(\"./helpers\");function p(t,e){t._fullLayout._paperdiv.selectAll('.shapelayer [data-index=\"'+e+'\"]').remove();var r=t._fullLayout.shapes[e]||{};if(r._input&&!1!==r.visible)if(\"below\"!==r.layer)m(t._fullLayout._shapeUpperLayer);else if(\"paper\"===r.xref||\"paper\"===r.yref)m(t._fullLayout._shapeLowerLayer);else{var p=t._fullLayout._plots[r.xref+r.yref];if(p)m((p.mainplotinfo||p).shapelayer);else m(t._fullLayout._shapeLowerLayer)}function m(p){var m={\"data-index\":e,\"fill-rule\":\"evenodd\",d:g(t,r)},y=r.line.width?r.line.color:\"rgba(0,0,0,0)\",x=p.append(\"path\").attr(m).style(\"opacity\",r.opacity).call(o.stroke,y).call(o.fill,r.fillcolor).call(s.dashLine,r.line.dash,r.line.width);d(x,t,r),t._context.edits.shapePosition&&function(t,e,r,o,p){var m,y,x,b,_,w,k,T,A,M,S,E,C,L,P,O,z=10,I=10,D=\"pixel\"===r.xsizemode,R=\"pixel\"===r.ysizemode,F=\"line\"===r.type,B=\"path\"===r.type,N=l(t.layout,\"shapes\",r),j=N.modifyItem,U=a.getFromId(t,r.xref),V=a.getFromId(t,r.yref),q=f.getDataToPixel(t,U),H=f.getDataToPixel(t,V,!0),G=f.getPixelToData(t,U),Y=f.getPixelToData(t,V,!0),W=F?function(){var t=Math.max(r.line.width,10),n=p.append(\"g\").attr(\"data-index\",o);n.append(\"path\").attr(\"d\",e.attr(\"d\")).style({cursor:\"move\",\"stroke-width\":t,\"stroke-opacity\":\"0\"});var i={\"fill-opacity\":\"0\"},a=t/2>10?t/2:10;return n.append(\"circle\").attr({\"data-line-point\":\"start-point\",cx:D?q(r.xanchor)+r.x0:q(r.x0),cy:R?H(r.yanchor)-r.y0:H(r.y0),r:a}).style(i).classed(\"cursor-grab\",!0),n.append(\"circle\").attr({\"data-line-point\":\"end-point\",cx:D?q(r.xanchor)+r.x1:q(r.x1),cy:R?H(r.yanchor)-r.y1:H(r.y1),r:a}).style(i).classed(\"cursor-grab\",!0),n}():e,X={element:W.node(),gd:t,prepFn:function(n){D&&(_=q(r.xanchor));R&&(w=H(r.yanchor));\"path\"===r.type?P=r.path:(m=D?r.x0:q(r.x0),y=R?r.y0:H(r.y0),x=D?r.x1:q(r.x1),b=R?r.y1:H(r.y1));m<x?(A=m,C=\"x0\",M=x,L=\"x1\"):(A=x,C=\"x1\",M=m,L=\"x0\");!R&&y<b||R&&y>b?(k=y,S=\"y0\",T=b,E=\"y1\"):(k=b,S=\"y1\",T=y,E=\"y0\");Z(n),$(p,r),function(t,e,r){var n=e.xref,i=e.yref,o=a.getFromId(r,n),l=a.getFromId(r,i),c=\"\";\"paper\"===n||o.autorange||(c+=n);\"paper\"===i||l.autorange||(c+=i);s.setClipUrl(t,c?\"clip\"+r._fullLayout._uid+c:null,r)}(e,r,t),X.moveFn=\"move\"===O?J:K},doneFn:function(){u(e),Q(p),d(e,t,r),n.call(\"_guiRelayout\",t,N.getUpdateObj())},clickFn:function(){Q(p)}};function Z(t){if(F)O=\"path\"===t.target.tagName?\"move\":\"start-point\"===t.target.attributes[\"data-line-point\"].value?\"resize-over-start-point\":\"resize-over-end-point\";else{var r=X.element.getBoundingClientRect(),n=r.right-r.left,i=r.bottom-r.top,a=t.clientX-r.left,o=t.clientY-r.top,s=!B&&n>z&&i>I&&!t.shiftKey?c.getCursor(a/n,1-o/i):\"move\";u(e,s),O=s.split(\"-\")[0]}}function J(n,i){if(\"path\"===r.type){var a=function(t){return t},o=a,s=a;D?j(\"xanchor\",r.xanchor=G(_+n)):(o=function(t){return G(q(t)+n)},U&&\"date\"===U.type&&(o=f.encodeDate(o))),R?j(\"yanchor\",r.yanchor=Y(w+i)):(s=function(t){return Y(H(t)+i)},V&&\"date\"===V.type&&(s=f.encodeDate(s))),j(\"path\",r.path=v(P,o,s))}else D?j(\"xanchor\",r.xanchor=G(_+n)):(j(\"x0\",r.x0=G(m+n)),j(\"x1\",r.x1=G(x+n))),R?j(\"yanchor\",r.yanchor=Y(w+i)):(j(\"y0\",r.y0=Y(y+i)),j(\"y1\",r.y1=Y(b+i)));e.attr(\"d\",g(t,r)),$(p,r)}function K(n,i){if(B){var a=function(t){return t},o=a,s=a;D?j(\"xanchor\",r.xanchor=G(_+n)):(o=function(t){return G(q(t)+n)},U&&\"date\"===U.type&&(o=f.encodeDate(o))),R?j(\"yanchor\",r.yanchor=Y(w+i)):(s=function(t){return Y(H(t)+i)},V&&\"date\"===V.type&&(s=f.encodeDate(s))),j(\"path\",r.path=v(P,o,s))}else if(F){if(\"resize-over-start-point\"===O){var l=m+n,c=R?y-i:y+i;j(\"x0\",r.x0=D?l:G(l)),j(\"y0\",r.y0=R?c:Y(c))}else if(\"resize-over-end-point\"===O){var u=x+n,h=R?b-i:b+i;j(\"x1\",r.x1=D?u:G(u)),j(\"y1\",r.y1=R?h:Y(h))}}else{var d=~O.indexOf(\"n\")?k+i:k,N=~O.indexOf(\"s\")?T+i:T,W=~O.indexOf(\"w\")?A+n:A,X=~O.indexOf(\"e\")?M+n:M;~O.indexOf(\"n\")&&R&&(d=k-i),~O.indexOf(\"s\")&&R&&(N=T-i),(!R&&N-d>I||R&&d-N>I)&&(j(S,r[S]=R?d:Y(d)),j(E,r[E]=R?N:Y(N))),X-W>z&&(j(C,r[C]=D?W:G(W)),j(L,r[L]=D?X:G(X)))}e.attr(\"d\",g(t,r)),$(p,r)}function $(t,e){(D||R)&&function(){var r=\"path\"!==e.type,n=t.selectAll(\".visual-cue\").data([0]);n.enter().append(\"path\").attr({fill:\"#fff\",\"fill-rule\":\"evenodd\",stroke:\"#000\",\"stroke-width\":1}).classed(\"visual-cue\",!0);var a=q(D?e.xanchor:i.midRange(r?[e.x0,e.x1]:f.extractPathCoords(e.path,h.paramIsX))),o=H(R?e.yanchor:i.midRange(r?[e.y0,e.y1]:f.extractPathCoords(e.path,h.paramIsY)));if(a=f.roundPositionForSharpStrokeRendering(a,1),o=f.roundPositionForSharpStrokeRendering(o,1),D&&R){var s=\"M\"+(a-1-1)+\",\"+(o-1-1)+\"h-8v2h8 v8h2v-8 h8v-2h-8 v-8h-2 Z\";n.attr(\"d\",s)}else if(D){var l=\"M\"+(a-1-1)+\",\"+(o-9-1)+\"v18 h2 v-18 Z\";n.attr(\"d\",l)}else{var c=\"M\"+(a-9-1)+\",\"+(o-1-1)+\"h18 v2 h-18 Z\";n.attr(\"d\",c)}}()}function Q(t){t.selectAll(\".visual-cue\").remove()}c.init(X),W.node().onmousemove=Z}(t,x,r,e,p)}}function d(t,e,r){var n=(r.xref+r.yref).replace(/paper/g,\"\");s.setClipUrl(t,n?\"clip\"+e._fullLayout._uid+n:null,e)}function g(t,e){var r,n,o,s,l,c,u,p,d=e.type,g=a.getFromId(t,e.xref),v=a.getFromId(t,e.yref),m=t._fullLayout._size;if(g?(r=f.shapePositionToRange(g),n=function(t){return g._offset+g.r2p(r(t,!0))}):n=function(t){return m.l+m.w*t},v?(o=f.shapePositionToRange(v),s=function(t){return v._offset+v.r2p(o(t,!0))}):s=function(t){return m.t+m.h*(1-t)},\"path\"===d)return g&&\"date\"===g.type&&(n=f.decodeDate(n)),v&&\"date\"===v.type&&(s=f.decodeDate(s)),function(t,e,r){var n=t.path,a=t.xsizemode,o=t.ysizemode,s=t.xanchor,l=t.yanchor;return n.replace(h.segmentRE,function(t){var n=0,c=t.charAt(0),u=h.paramIsX[c],f=h.paramIsY[c],p=h.numParams[c],d=t.substr(1).replace(h.paramRE,function(t){return u[n]?t=\"pixel\"===a?e(s)+Number(t):e(t):f[n]&&(t=\"pixel\"===o?r(l)-Number(t):r(t)),++n>p&&(t=\"X\"),t});return n>p&&(d=d.replace(/[\\s,]*X.*/,\"\"),i.log(\"Ignoring extra params in segment \"+t)),c+d})}(e,n,s);if(\"pixel\"===e.xsizemode){var y=n(e.xanchor);l=y+e.x0,c=y+e.x1}else l=n(e.x0),c=n(e.x1);if(\"pixel\"===e.ysizemode){var x=s(e.yanchor);u=x-e.y0,p=x-e.y1}else u=s(e.y0),p=s(e.y1);if(\"line\"===d)return\"M\"+l+\",\"+u+\"L\"+c+\",\"+p;if(\"rect\"===d)return\"M\"+l+\",\"+u+\"H\"+c+\"V\"+p+\"H\"+l+\"Z\";var b=(l+c)/2,_=(u+p)/2,w=Math.abs(b-l),k=Math.abs(_-u),T=\"A\"+w+\",\"+k,A=b+w+\",\"+_;return\"M\"+A+T+\" 0 1,1 \"+(b+\",\"+(_-k))+T+\" 0 0,1 \"+A+\"Z\"}function v(t,e,r){return t.replace(h.segmentRE,function(t){var n=0,i=t.charAt(0),a=h.paramIsX[i],o=h.paramIsY[i],s=h.numParams[i];return i+t.substr(1).replace(h.paramRE,function(t){return n>=s?t:(a[n]?t=e(t):o[n]&&(t=r(t)),n++,t)})})}e.exports={draw:function(t){var e=t._fullLayout;for(var r in e._shapeUpperLayer.selectAll(\"path\").remove(),e._shapeLowerLayer.selectAll(\"path\").remove(),e._plots){var n=e._plots[r].shapelayer;n&&n.selectAll(\"path\").remove()}for(var i=0;i<e.shapes.length;i++)e.shapes[i].visible&&p(t,i)},drawOne:p}},{\"../../lib\":719,\"../../lib/setcursor\":739,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"./constants\":671,\"./helpers\":674}],674:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib\");r.rangeToShapePosition=function(t){return\"log\"===t.type?t.r2d:function(t){return t}},r.shapePositionToRange=function(t){return\"log\"===t.type?t.d2r:function(t){return t}},r.decodeDate=function(t){return function(e){return e.replace&&(e=e.replace(\"_\",\" \")),t(e)}},r.encodeDate=function(t){return function(e){return t(e).replace(\" \",\"_\")}},r.extractPathCoords=function(t,e){var r=[];return t.match(n.segmentRE).forEach(function(t){var a=e[t.charAt(0)].drawn;if(void 0!==a){var o=t.substr(1).match(n.paramRE);!o||o.length<a||r.push(i.cleanNumber(o[a]))}}),r},r.getDataToPixel=function(t,e,n){var i,a=t._fullLayout._size;if(e){var o=r.shapePositionToRange(e);i=function(t){return e._offset+e.r2p(o(t,!0))},\"date\"===e.type&&(i=r.decodeDate(i))}else i=n?function(t){return a.t+a.h*(1-t)}:function(t){return a.l+a.w*t};return i},r.getPixelToData=function(t,e,n){var i,a=t._fullLayout._size;if(e){var o=r.rangeToShapePosition(e);i=function(t){return o(e.p2r(t-e._offset))}}else i=n?function(t){return 1-(t-a.t)/a.h}:function(t){return(t-a.l)/a.w};return i},r.roundPositionForSharpStrokeRendering=function(t,e){var r=1===Math.round(e%2),n=Math.round(t);return r?n+.5:n}},{\"../../lib\":719,\"./constants\":671}],675:[function(t,e,r){\"use strict\";var n=t(\"./draw\");e.exports={moduleType:\"component\",name:\"shapes\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"shapes\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne}},{\"../../plots/cartesian/include_components\":777,\"./attributes\":669,\"./calc_autorange\":670,\"./defaults\":672,\"./draw\":673}],676:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/pad_attributes\"),a=t(\"../../lib/extend\").extendDeepAll,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/animation_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"./constants\"),u=l(\"step\",{visible:{valType:\"boolean\",dflt:!0},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\"},value:{valType:\"string\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"slider\",{visible:{valType:\"boolean\",dflt:!0},active:{valType:\"number\",min:0,dflt:0},steps:u,lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",min:-2,max:3,dflt:0},pad:a(i({editType:\"arraydraw\"}),{},{t:{dflt:20}}),xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\"},y:{valType:\"number\",min:-2,max:3,dflt:0},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},transition:{duration:{valType:\"number\",min:0,dflt:150},easing:{valType:\"enumerated\",values:s.transition.easing.values,dflt:\"cubic-in-out\"}},currentvalue:{visible:{valType:\"boolean\",dflt:!0},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},offset:{valType:\"number\",dflt:10},prefix:{valType:\"string\"},suffix:{valType:\"string\"},font:n({})},font:n({}),activebgcolor:{valType:\"color\",dflt:c.gripBgActiveColor},bgcolor:{valType:\"color\",dflt:c.railBgColor},bordercolor:{valType:\"color\",dflt:c.railBorderColor},borderwidth:{valType:\"number\",min:0,dflt:c.railBorderWidth},ticklen:{valType:\"number\",min:0,dflt:c.tickLength},tickcolor:{valType:\"color\",dflt:c.tickColor},tickwidth:{valType:\"number\",min:0,dflt:1},minorticklen:{valType:\"number\",min:0,dflt:c.minorTickLength}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/animation_attributes\":762,\"../../plots/font_attributes\":793,\"../../plots/pad_attributes\":827,\"./constants\":677}],677:[function(t,e,r){\"use strict\";e.exports={name:\"sliders\",containerClassName:\"slider-container\",groupClassName:\"slider-group\",inputAreaClass:\"slider-input-area\",railRectClass:\"slider-rail-rect\",railTouchRectClass:\"slider-rail-touch-rect\",gripRectClass:\"slider-grip-rect\",tickRectClass:\"slider-tick-rect\",inputProxyClass:\"slider-input-proxy\",labelsClass:\"slider-labels\",labelGroupClass:\"slider-label-group\",labelClass:\"slider-label\",currentValueClass:\"slider-current-value\",railHeight:5,menuIndexAttrName:\"slider-active-index\",autoMarginIdRoot:\"slider-\",minWidth:30,minHeight:30,textPadX:40,arrowOffsetX:4,railRadius:2,railWidth:5,railBorder:4,railBorderWidth:1,railBorderColor:\"#bec8d9\",railBgColor:\"#f8fafc\",railInset:8,stepInset:10,gripRadius:10,gripWidth:20,gripHeight:20,gripBorder:20,gripBorderWidth:1,gripBorderColor:\"#bec8d9\",gripBgColor:\"#f6f8fa\",gripBgActiveColor:\"#dbdde0\",labelPadding:8,labelOffset:0,tickWidth:1,tickColor:\"#333\",tickOffset:25,tickLength:7,minorTickOffset:25,minorTickColor:\"#333\",minorTickLength:4,currentValuePadding:8,currentValueInset:0}},{}],678:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.steps;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}for(var s=i(t,e,{name:\"steps\",handleItemDefaults:c}),l=0,u=0;u<s.length;u++)s[u].visible&&l++;if(l<2?e.visible=!1:o(\"visible\")){e._stepCount=l;var h=e._visibleSteps=n.filterVisible(s);(s[o(\"active\")]||{}).visible||(e.active=h[0]._index),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"len\"),o(\"lenmode\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"currentvalue.visible\")&&(o(\"currentvalue.xanchor\"),o(\"currentvalue.prefix\"),o(\"currentvalue.suffix\"),o(\"currentvalue.offset\"),n.coerceFont(o,\"currentvalue.font\",e.font)),o(\"transition.duration\"),o(\"transition.easing\"),o(\"bgcolor\"),o(\"activebgcolor\"),o(\"bordercolor\"),o(\"borderwidth\"),o(\"ticklen\"),o(\"tickwidth\"),o(\"tickcolor\"),o(\"minorticklen\")}}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}if(\"skip\"===t.method||Array.isArray(t.args)?r(\"visible\"):e.visible=!1){r(\"method\"),r(\"args\");var i=r(\"label\",\"step-\"+e._index);r(\"value\",i),r(\"execute\")}}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"./attributes\":676,\"./constants\":677}],679:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"./constants\"),h=t(\"../../constants/alignment\"),f=h.LINE_SPACING,p=h.FROM_TL,d=h.FROM_BR;function g(t){return u.autoMarginIdRoot+t._index}function v(t){return t._index}function m(t,e){var r=o.tester.selectAll(\"g.\"+u.labelGroupClass).data(e._visibleSteps);r.enter().append(\"g\").classed(u.labelGroupClass,!0);var a=0,c=0;r.each(function(t){var r=b(n.select(this),{step:t},e).node();if(r){var i=o.bBox(r);c=Math.max(c,i.height),a=Math.max(a,i.width)}}),r.remove();var h=e._dims={};h.inputAreaWidth=Math.max(u.railWidth,u.gripHeight);var f=t._fullLayout._size;h.lx=f.l+f.w*e.x,h.ly=f.t+f.h*(1-e.y),\"fraction\"===e.lenmode?h.outerLength=Math.round(f.w*e.len):h.outerLength=e.len,h.inputAreaStart=0,h.inputAreaLength=Math.round(h.outerLength-e.pad.l-e.pad.r);var v=(h.inputAreaLength-2*u.stepInset)/(e._stepCount-1),m=a+u.labelPadding;if(h.labelStride=Math.max(1,Math.ceil(m/v)),h.labelHeight=c,h.currentValueMaxWidth=0,h.currentValueHeight=0,h.currentValueTotalHeight=0,h.currentValueMaxLines=1,e.currentvalue.visible){var x=o.tester.append(\"g\");r.each(function(t){var r=y(x,e,t.label),n=r.node()&&o.bBox(r.node())||{width:0,height:0},i=l.lineCount(r);h.currentValueMaxWidth=Math.max(h.currentValueMaxWidth,Math.ceil(n.width)),h.currentValueHeight=Math.max(h.currentValueHeight,Math.ceil(n.height)),h.currentValueMaxLines=Math.max(h.currentValueMaxLines,i)}),h.currentValueTotalHeight=h.currentValueHeight+e.currentvalue.offset,x.remove()}h.height=h.currentValueTotalHeight+u.tickOffset+e.ticklen+u.labelOffset+h.labelHeight+e.pad.t+e.pad.b;var _=\"left\";s.isRightAnchor(e)&&(h.lx-=h.outerLength,_=\"right\"),s.isCenterAnchor(e)&&(h.lx-=h.outerLength/2,_=\"center\");var w=\"top\";s.isBottomAnchor(e)&&(h.ly-=h.height,w=\"bottom\"),s.isMiddleAnchor(e)&&(h.ly-=h.height/2,w=\"middle\"),h.outerLength=Math.ceil(h.outerLength),h.height=Math.ceil(h.height),h.lx=Math.round(h.lx),h.ly=Math.round(h.ly);var k={y:e.y,b:h.height*d[w],t:h.height*p[w]};\"fraction\"===e.lenmode?(k.l=0,k.xl=e.x-e.len*p[_],k.r=0,k.xr=e.x+e.len*d[_]):(k.x=e.x,k.l=h.outerLength*p[_],k.r=h.outerLength*d[_]),i.autoMargin(t,g(e),k)}function y(t,e,r){if(e.currentvalue.visible){var n,i,a=e._dims;switch(e.currentvalue.xanchor){case\"right\":n=a.inputAreaLength-u.currentValueInset-a.currentValueMaxWidth,i=\"left\";break;case\"center\":n=.5*a.inputAreaLength,i=\"middle\";break;default:n=u.currentValueInset,i=\"left\"}var c=s.ensureSingle(t,\"text\",u.labelClass,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":i,\"data-notex\":1})}),h=e.currentvalue.prefix?e.currentvalue.prefix:\"\";if(\"string\"==typeof r)h+=r;else{var p=e.steps[e.active].label,d=e._gd._fullLayout._meta;d&&(p=s.templateString(p,d)),h+=p}e.currentvalue.suffix&&(h+=e.currentvalue.suffix),c.call(o.font,e.currentvalue.font).text(h).call(l.convertToTspans,e._gd);var g=l.lineCount(c),v=(a.currentValueMaxLines+1-g)*e.currentvalue.font.size*f;return l.positionText(c,n,v),c}}function x(t,e,r){s.ensureSingle(t,\"rect\",u.gripRectClass,function(n){n.call(T,e,t,r).style(\"pointer-events\",\"all\")}).attr({width:u.gripWidth,height:u.gripHeight,rx:u.gripRadius,ry:u.gripRadius}).call(a.stroke,r.bordercolor).call(a.fill,r.bgcolor).style(\"stroke-width\",r.borderwidth+\"px\")}function b(t,e,r){var n=s.ensureSingle(t,\"text\",u.labelClass,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":\"middle\",\"data-notex\":1})}),i=e.step.label,a=r._gd._fullLayout._meta;return a&&(i=s.templateString(i,a)),n.call(o.font,r.font).text(i).call(l.convertToTspans,r._gd),n}function _(t,e){var r=s.ensureSingle(t,\"g\",u.labelsClass),i=e._dims,a=r.selectAll(\"g.\"+u.labelGroupClass).data(i.labelSteps);a.enter().append(\"g\").classed(u.labelGroupClass,!0),a.exit().remove(),a.each(function(t){var r=n.select(this);r.call(b,t,e),o.setTranslate(r,S(e,t.fraction),u.tickOffset+e.ticklen+e.font.size*f+u.labelOffset+i.currentValueTotalHeight)})}function w(t,e,r,n,i){var a=Math.round(n*(r._stepCount-1)),o=r._visibleSteps[a]._index;o!==r.active&&k(t,e,r,o,!0,i)}function k(t,e,r,n,a,o){var s=r.active;r.active=n,c(t.layout,u.name,r).applyUpdate(\"active\",n);var l=r.steps[r.active];e.call(M,r,o),e.call(y,r),t.emit(\"plotly_sliderchange\",{slider:r,step:r.steps[r.active],interaction:a,previousActive:s}),l&&l.method&&a&&(e._nextMethod?(e._nextMethod.step=l,e._nextMethod.doCallback=a,e._nextMethod.doTransition=o):(e._nextMethod={step:l,doCallback:a,doTransition:o},e._nextMethodRaf=window.requestAnimationFrame(function(){var r=e._nextMethod.step;r.method&&(r.execute&&i.executeAPICommand(t,r.method,r.args),e._nextMethod=null,e._nextMethodRaf=null)})))}function T(t,e,r){var i=r.node(),o=n.select(e);function s(){return r.data()[0]}t.on(\"mousedown\",function(){var t=s();e.emit(\"plotly_sliderstart\",{slider:t});var l=r.select(\".\"+u.gripRectClass);n.event.stopPropagation(),n.event.preventDefault(),l.call(a.fill,t.activebgcolor);var c=E(t,n.mouse(i)[0]);w(e,r,t,c,!0),t._dragging=!0,o.on(\"mousemove\",function(){var t=s(),a=E(t,n.mouse(i)[0]);w(e,r,t,a,!1)}),o.on(\"mouseup\",function(){var t=s();t._dragging=!1,l.call(a.fill,t.bgcolor),o.on(\"mouseup\",null),o.on(\"mousemove\",null),e.emit(\"plotly_sliderend\",{slider:t,step:t.steps[t.active]})})})}function A(t,e){var r=t.selectAll(\"rect.\"+u.tickRectClass).data(e._visibleSteps),i=e._dims;r.enter().append(\"rect\").classed(u.tickRectClass,!0),r.exit().remove(),r.attr({width:e.tickwidth+\"px\",\"shape-rendering\":\"crispEdges\"}),r.each(function(t,r){var s=r%i.labelStride==0,l=n.select(this);l.attr({height:s?e.ticklen:e.minorticklen}).call(a.fill,e.tickcolor),o.setTranslate(l,S(e,r/(e._stepCount-1))-.5*e.tickwidth,(s?u.tickOffset:u.minorTickOffset)+i.currentValueTotalHeight)})}function M(t,e,r){for(var n=t.select(\"rect.\"+u.gripRectClass),i=0,a=0;a<e._stepCount;a++)if(e._visibleSteps[a]._index===e.active){i=a;break}var o=S(e,i/(e._stepCount-1));if(!e._invokingCommand){var s=n;r&&e.transition.duration>0&&(s=s.transition().duration(e.transition.duration).ease(e.transition.easing)),s.attr(\"transform\",\"translate(\"+(o-.5*u.gripWidth)+\",\"+e._dims.currentValueTotalHeight+\")\")}}function S(t,e){var r=t._dims;return r.inputAreaStart+u.stepInset+(r.inputAreaLength-2*u.stepInset)*Math.min(1,Math.max(0,e))}function E(t,e){var r=t._dims;return Math.min(1,Math.max(0,(e-u.stepInset-r.inputAreaStart)/(r.inputAreaLength-2*u.stepInset-2*r.inputAreaStart)))}function C(t,e,r){var n=r._dims,i=s.ensureSingle(t,\"rect\",u.railTouchRectClass,function(n){n.call(T,e,t,r).style(\"pointer-events\",\"all\")});i.attr({width:n.inputAreaLength,height:Math.max(n.inputAreaWidth,u.tickOffset+r.ticklen+n.labelHeight)}).call(a.fill,r.bgcolor).attr(\"opacity\",0),o.setTranslate(i,0,n.currentValueTotalHeight)}function L(t,e){var r=e._dims,n=r.inputAreaLength-2*u.railInset,i=s.ensureSingle(t,\"rect\",u.railRectClass);i.attr({width:n,height:u.railWidth,rx:u.railRadius,ry:u.railRadius,\"shape-rendering\":\"crispEdges\"}).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\"),o.setTranslate(i,u.railInset,.5*(r.inputAreaWidth-u.railWidth)+r.currentValueTotalHeight)}e.exports=function(t){var e=t._fullLayout,r=function(t,e){for(var r=t[u.name],n=[],i=0;i<r.length;i++){var a=r[i];a.visible&&(a._gd=e,n.push(a))}return n}(e,t),a=e._infolayer.selectAll(\"g.\"+u.containerClassName).data(r.length>0?[0]:[]);function s(e){e._commandObserver&&(e._commandObserver.remove(),delete e._commandObserver),i.autoMargin(t,g(e))}if(a.enter().append(\"g\").classed(u.containerClassName,!0).style(\"cursor\",\"ew-resize\"),a.exit().each(function(){n.select(this).selectAll(\"g.\"+u.groupClassName).each(s)}).remove(),0!==r.length){var l=a.selectAll(\"g.\"+u.groupClassName).data(r,v);l.enter().append(\"g\").classed(u.groupClassName,!0),l.exit().each(s).remove();for(var c=0;c<r.length;c++){var h=r[c];m(t,h)}l.each(function(e){var r=n.select(this);!function(t){var e=t._dims;e.labelSteps=[];for(var r=t._stepCount,n=0;n<r;n+=e.labelStride)e.labelSteps.push({fraction:n/(r-1),step:t._visibleSteps[n]})}(e),i.manageCommandObserver(t,e,e._visibleSteps,function(e){var n=r.data()[0];n.active!==e.index&&(n._dragging||k(t,r,n,e.index,!1,!0))}),function(t,e,r){(r.steps[r.active]||{}).visible||(r.active=r._visibleSteps[0]._index);e.call(y,r).call(L,r).call(_,r).call(A,r).call(C,t,r).call(x,t,r);var n=r._dims;o.setTranslate(e,n.lx+r.pad.l,n.ly+r.pad.t),e.call(M,r,!1),e.call(y,r)}(t,n.select(this),e)})}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_template\":757,\"../../plots/plots\":828,\"../color\":593,\"../drawing\":614,\"./constants\":677,d3:163}],680:[function(t,e,r){\"use strict\";var n=t(\"./constants\");e.exports={moduleType:\"component\",name:n.name,layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":676,\"./constants\":677,\"./defaults\":678,\"./draw\":679}],681:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../drawing\"),c=t(\"../color\"),u=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/interactions\");e.exports={draw:function(t,e,r){var p,d=r.propContainer,g=r.propName,v=r.placeholder,m=r.traceIndex,y=r.avoid||{},x=r.attributes,b=r.transform,_=r.containerGroup,w=t._fullLayout,k=1,T=!1,A=d.title,M=(A&&A.text?A.text:\"\").trim(),S=A&&A.font?A.font:{},E=S.family,C=S.size,L=S.color;\"title.text\"===g?p=\"titleText\":-1!==g.indexOf(\"axis\")?p=\"axisTitleText\":g.indexOf(!0)&&(p=\"colorbarTitleText\");var P=t._context.edits[p];\"\"===M?k=0:M.replace(f,\" % \")===v.replace(f,\" % \")&&(k=.2,T=!0,P||(M=\"\"));r._meta?M=s.templateString(M,r._meta):w._meta&&(M=s.templateString(M,w._meta));var O=M||P;_||(_=s.ensureSingle(w._infolayer,\"g\",\"g-\"+e));var z=_.selectAll(\"text\").data(O?[0]:[]);if(z.enter().append(\"text\"),z.text(M).attr(\"class\",e),z.exit().remove(),!O)return _;function I(t){s.syncOrAsync([D,R],t)}function D(e){var r;return b?(r=\"\",b.rotate&&(r+=\"rotate(\"+[b.rotate,x.x,x.y]+\")\"),b.offset&&(r+=\"translate(0, \"+b.offset+\")\")):r=null,e.attr(\"transform\",r),e.style({\"font-family\":E,\"font-size\":n.round(C,2)+\"px\",fill:c.rgb(L),opacity:k*c.opacity(L),\"font-weight\":a.fontWeight}).attr(x).call(u.convertToTspans,t),a.previousPromises(t)}function R(t){var e=n.select(t.node().parentNode);if(y&&y.selection&&y.side&&M){e.attr(\"transform\",null);var r=0,a={left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}[y.side],o=-1!==[\"left\",\"top\"].indexOf(y.side)?-1:1,c=i(y.pad)?y.pad:2,u=l.bBox(e.node()),h={left:0,top:0,right:w.width,bottom:w.height},f=y.maxShift||(h[y.side]-u[y.side])*(\"left\"===y.side||\"top\"===y.side?-1:1);if(f<0)r=f;else{var p=y.offsetLeft||0,d=y.offsetTop||0;u.left-=p,u.right-=p,u.top-=d,u.bottom-=d,y.selection.each(function(){var t=l.bBox(this);s.bBoxIntersect(u,t,c)&&(r=Math.max(r,o*(t[y.side]-u[a])+c))}),r=Math.min(f,r)}if(r>0||f<0){var g={left:[-r,0],right:[r,0],top:[0,-r],bottom:[0,r]}[y.side];e.attr(\"transform\",\"translate(\"+g+\")\")}}}z.call(I),P&&(M?z.on(\".opacity\",null):(k=0,T=!0,z.text(v).on(\"mouseover.opacity\",function(){n.select(this).transition().duration(h.SHOW_PLACEHOLDER).style(\"opacity\",1)}).on(\"mouseout.opacity\",function(){n.select(this).transition().duration(h.HIDE_PLACEHOLDER).style(\"opacity\",0)})),z.call(u.makeEditable,{gd:t}).on(\"edit\",function(e){void 0!==m?o.call(\"_guiRestyle\",t,g,e,m):o.call(\"_guiRelayout\",t,g,e)}).on(\"cancel\",function(){this.text(this.attr(\"data-unformatted\")).call(I)}).on(\"input\",function(t){this.text(t||\" \").call(u.positionText,x.x,x.y)}));return z.classed(\"js-placeholder\",T),_}};var f=/ [XY][0-9]* /},{\"../../constants/interactions\":694,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../drawing\":614,d3:163,\"fast-isnumeric\":225}],682:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/pad_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=l(\"button\",{visible:{valType:\"boolean\"},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\",dflt:\"\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"updatemenu\",{_arrayAttrRegexps:[/^updatemenus\\[(0|[1-9][0-9]+)\\]\\.buttons/],visible:{valType:\"boolean\"},type:{valType:\"enumerated\",values:[\"dropdown\",\"buttons\"],dflt:\"dropdown\"},direction:{valType:\"enumerated\",values:[\"left\",\"right\",\"up\",\"down\"],dflt:\"down\"},active:{valType:\"integer\",min:-1,dflt:0},showactive:{valType:\"boolean\",dflt:!0},buttons:c,x:{valType:\"number\",min:-2,max:3,dflt:-.05},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"right\"},y:{valType:\"number\",min:-2,max:3,dflt:1},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},pad:a(s({editType:\"arraydraw\"}),{}),font:n({}),bgcolor:{valType:\"color\"},bordercolor:{valType:\"color\",dflt:i.borderLine},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"arraydraw\"}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/font_attributes\":793,\"../../plots/pad_attributes\":827,\"../color/attributes\":592}],683:[function(t,e,r){\"use strict\";e.exports={name:\"updatemenus\",containerClassName:\"updatemenu-container\",headerGroupClassName:\"updatemenu-header-group\",headerClassName:\"updatemenu-header\",headerArrowClassName:\"updatemenu-header-arrow\",dropdownButtonGroupClassName:\"updatemenu-dropdown-button-group\",dropdownButtonClassName:\"updatemenu-dropdown-button\",buttonClassName:\"updatemenu-button\",itemRectClassName:\"updatemenu-item-rect\",itemTextClassName:\"updatemenu-item-text\",menuIndexAttrName:\"updatemenu-active-index\",autoMarginIdRoot:\"updatemenu-\",blankHeaderOpts:{label:\"  \"},minWidth:30,minHeight:30,textPadX:24,arrowPadX:16,rx:2,ry:2,textOffsetX:12,textOffsetY:3,arrowOffsetX:4,gapButtonHeader:5,gapButton:2,activeColor:\"#F4FAFF\",hoverColor:\"#F4FAFF\",arrowSymbol:{left:\"\\u25c4\",right:\"\\u25ba\",up:\"\\u25b2\",down:\"\\u25bc\"}}},{}],684:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.buttons;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}o(\"visible\",i(t,e,{name:\"buttons\",handleItemDefaults:c}).length>0)&&(o(\"active\"),o(\"direction\"),o(\"type\"),o(\"showactive\"),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"bgcolor\",r.paper_bgcolor),o(\"bordercolor\"),o(\"borderwidth\"))}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}r(\"visible\",\"skip\"===t.method||Array.isArray(t.args))&&(r(\"method\"),r(\"args\"),r(\"label\"),r(\"execute\"))}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"./attributes\":682,\"./constants\":683}],685:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"../../constants/alignment\").LINE_SPACING,h=t(\"./constants\"),f=t(\"./scrollbox\");function p(t){return t._index}function d(t,e){return+t.attr(h.menuIndexAttrName)===e._index}function g(t,e,r,n,i,a,o,s){e.active=o,c(t.layout,h.name,e).applyUpdate(\"active\",o),\"buttons\"===e.type?m(t,n,null,null,e):\"dropdown\"===e.type&&(i.attr(h.menuIndexAttrName,\"-1\"),v(t,n,i,a,e),s||m(t,n,i,a,e))}function v(t,e,r,n,i){var a=s.ensureSingle(e,\"g\",h.headerClassName,function(t){t.style(\"pointer-events\",\"all\")}),l=i._dims,c=i.active,u=i.buttons[c]||h.blankHeaderOpts,f={y:i.pad.t,yPad:0,x:i.pad.l,xPad:0,index:0},p={width:l.headerWidth,height:l.headerHeight};a.call(y,i,u,t).call(M,i,f,p),s.ensureSingle(e,\"text\",h.headerArrowClassName,function(t){t.classed(\"user-select-none\",!0).attr(\"text-anchor\",\"end\").call(o.font,i.font).text(h.arrowSymbol[i.direction])}).attr({x:l.headerWidth-h.arrowOffsetX+i.pad.l,y:l.headerHeight/2+h.textOffsetY+i.pad.t}),a.on(\"click\",function(){r.call(S,String(d(r,i)?-1:i._index)),m(t,e,r,n,i)}),a.on(\"mouseover\",function(){a.call(w)}),a.on(\"mouseout\",function(){a.call(k,i)}),o.setTranslate(e,l.lx,l.ly)}function m(t,e,r,a,o){r||(r=e).attr(\"pointer-events\",\"all\");var l=function(t){return-1==+t.attr(h.menuIndexAttrName)}(r)&&\"buttons\"!==o.type?[]:o.buttons,c=\"dropdown\"===o.type?h.dropdownButtonClassName:h.buttonClassName,u=r.selectAll(\"g.\"+c).data(s.filterVisible(l)),f=u.enter().append(\"g\").classed(c,!0),p=u.exit();\"dropdown\"===o.type?(f.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\"),p.transition().attr(\"opacity\",\"0\").remove()):p.remove();var d=0,v=0,m=o._dims,x=-1!==[\"up\",\"down\"].indexOf(o.direction);\"dropdown\"===o.type&&(x?v=m.headerHeight+h.gapButtonHeader:d=m.headerWidth+h.gapButtonHeader),\"dropdown\"===o.type&&\"up\"===o.direction&&(v=-h.gapButtonHeader+h.gapButton-m.openHeight),\"dropdown\"===o.type&&\"left\"===o.direction&&(d=-h.gapButtonHeader+h.gapButton-m.openWidth);var b={x:m.lx+d+o.pad.l,y:m.ly+v+o.pad.t,yPad:h.gapButton,xPad:h.gapButton,index:0},T={l:b.x+o.borderwidth,t:b.y+o.borderwidth};u.each(function(s,l){var c=n.select(this);c.call(y,o,s,t).call(M,o,b),c.on(\"click\",function(){n.event.defaultPrevented||(g(t,o,0,e,r,a,l),s.execute&&i.executeAPICommand(t,s.method,s.args),t.emit(\"plotly_buttonclicked\",{menu:o,button:s,active:o.active}))}),c.on(\"mouseover\",function(){c.call(w)}),c.on(\"mouseout\",function(){c.call(k,o),u.call(_,o)})}),u.call(_,o),x?(T.w=Math.max(m.openWidth,m.headerWidth),T.h=b.y-T.t):(T.w=b.x-T.l,T.h=Math.max(m.openHeight,m.headerHeight)),T.direction=o.direction,a&&(u.size()?function(t,e,r,n,i,a){var o,s,l,c=i.direction,u=\"up\"===c||\"down\"===c,f=i._dims,p=i.active;if(u)for(s=0,l=0;l<p;l++)s+=f.heights[l]+h.gapButton;else for(o=0,l=0;l<p;l++)o+=f.widths[l]+h.gapButton;n.enable(a,o,s),n.hbar&&n.hbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\");n.vbar&&n.vbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\")}(0,0,0,a,o,T):function(t){var e=!!t.hbar,r=!!t.vbar;e&&t.hbar.transition().attr(\"opacity\",\"0\").each(\"end\",function(){e=!1,r||t.disable()});r&&t.vbar.transition().attr(\"opacity\",\"0\").each(\"end\",function(){r=!1,e||t.disable()})}(a))}function y(t,e,r,n){t.call(x,e).call(b,e,r,n)}function x(t,e){s.ensureSingle(t,\"rect\",h.itemRectClassName,function(t){t.attr({rx:h.rx,ry:h.ry,\"shape-rendering\":\"crispEdges\"})}).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\")}function b(t,e,r,n){var i=s.ensureSingle(t,\"text\",h.itemTextClassName,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":\"start\",\"data-notex\":1})}),a=r.label,c=n._fullLayout._meta;c&&(a=s.templateString(a,c)),i.call(o.font,e.font).text(a).call(l.convertToTspans,n)}function _(t,e){var r=e.active;t.each(function(t,i){var o=n.select(this);i===r&&e.showactive&&o.select(\"rect.\"+h.itemRectClassName).call(a.fill,h.activeColor)})}function w(t){t.select(\"rect.\"+h.itemRectClassName).call(a.fill,h.hoverColor)}function k(t,e){t.select(\"rect.\"+h.itemRectClassName).call(a.fill,e.bgcolor)}function T(t,e){var r=e._dims={width1:0,height1:0,heights:[],widths:[],totalWidth:0,totalHeight:0,openWidth:0,openHeight:0,lx:0,ly:0},a=o.tester.selectAll(\"g.\"+h.dropdownButtonClassName).data(s.filterVisible(e.buttons));a.enter().append(\"g\").classed(h.dropdownButtonClassName,!0);var c=-1!==[\"up\",\"down\"].indexOf(e.direction);a.each(function(i,a){var s=n.select(this);s.call(y,e,i,t);var f=s.select(\".\"+h.itemTextClassName),p=f.node()&&o.bBox(f.node()).width,d=Math.max(p+h.textPadX,h.minWidth),g=e.font.size*u,v=l.lineCount(f),m=Math.max(g*v,h.minHeight)+h.textOffsetY;m=Math.ceil(m),d=Math.ceil(d),r.widths[a]=d,r.heights[a]=m,r.height1=Math.max(r.height1,m),r.width1=Math.max(r.width1,d),c?(r.totalWidth=Math.max(r.totalWidth,d),r.openWidth=r.totalWidth,r.totalHeight+=m+h.gapButton,r.openHeight+=m+h.gapButton):(r.totalWidth+=d+h.gapButton,r.openWidth+=d+h.gapButton,r.totalHeight=Math.max(r.totalHeight,m),r.openHeight=r.totalHeight)}),c?r.totalHeight-=h.gapButton:r.totalWidth-=h.gapButton,r.headerWidth=r.width1+h.arrowPadX,r.headerHeight=r.height1,\"dropdown\"===e.type&&(c?(r.width1+=h.arrowPadX,r.totalHeight=r.height1):r.totalWidth=r.width1,r.totalWidth+=h.arrowPadX),a.remove();var f=r.totalWidth+e.pad.l+e.pad.r,p=r.totalHeight+e.pad.t+e.pad.b,d=t._fullLayout._size;r.lx=d.l+d.w*e.x,r.ly=d.t+d.h*(1-e.y);var g=\"left\";s.isRightAnchor(e)&&(r.lx-=f,g=\"right\"),s.isCenterAnchor(e)&&(r.lx-=f/2,g=\"center\");var v=\"top\";s.isBottomAnchor(e)&&(r.ly-=p,v=\"bottom\"),s.isMiddleAnchor(e)&&(r.ly-=p/2,v=\"middle\"),r.totalWidth=Math.ceil(r.totalWidth),r.totalHeight=Math.ceil(r.totalHeight),r.lx=Math.round(r.lx),r.ly=Math.round(r.ly),i.autoMargin(t,A(e),{x:e.x,y:e.y,l:f*({right:1,center:.5}[g]||0),r:f*({left:1,center:.5}[g]||0),b:p*({top:1,middle:.5}[v]||0),t:p*({bottom:1,middle:.5}[v]||0)})}function A(t){return h.autoMarginIdRoot+t._index}function M(t,e,r,n){n=n||{};var i=t.select(\".\"+h.itemRectClassName),a=t.select(\".\"+h.itemTextClassName),s=e.borderwidth,c=r.index,f=e._dims;o.setTranslate(t,s+r.x,s+r.y);var p=-1!==[\"up\",\"down\"].indexOf(e.direction),d=n.height||(p?f.heights[c]:f.height1);i.attr({x:0,y:0,width:n.width||(p?f.width1:f.widths[c]),height:d});var g=e.font.size*u,v=(l.lineCount(a)-1)*g/2;l.positionText(a,h.textOffsetX,d/2-v+h.textOffsetY),p?r.y+=f.heights[c]+r.yPad:r.x+=f.widths[c]+r.xPad,r.index++}function S(t,e){t.attr(h.menuIndexAttrName,e||\"-1\").selectAll(\"g.\"+h.dropdownButtonClassName).remove()}e.exports=function(t){var e=t._fullLayout,r=s.filterVisible(e[h.name]);function a(e){i.autoMargin(t,A(e))}var o=e._menulayer.selectAll(\"g.\"+h.containerClassName).data(r.length>0?[0]:[]);if(o.enter().append(\"g\").classed(h.containerClassName,!0).style(\"cursor\",\"pointer\"),o.exit().each(function(){n.select(this).selectAll(\"g.\"+h.headerGroupClassName).each(a)}).remove(),0!==r.length){var l=o.selectAll(\"g.\"+h.headerGroupClassName).data(r,p);l.enter().append(\"g\").classed(h.headerGroupClassName,!0);for(var c=s.ensureSingle(o,\"g\",h.dropdownButtonGroupClassName,function(t){t.style(\"pointer-events\",\"all\")}),u=0;u<r.length;u++){var y=r[u];T(t,y)}var x=\"updatemenus\"+e._uid,b=new f(t,c,x);l.enter().size()&&(c.node().parentNode.appendChild(c.node()),c.call(S)),l.exit().each(function(t){c.call(S),a(t)}).remove(),l.each(function(e){var r=n.select(this),a=\"dropdown\"===e.type?c:null;i.manageCommandObserver(t,e,e.buttons,function(n){g(t,e,e.buttons[n.index],r,a,b,n.index,!0)}),\"dropdown\"===e.type?(v(t,r,c,b,e),d(c,e)&&m(t,r,c,b,e)):m(t,r,null,null,e)})}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_template\":757,\"../../plots/plots\":828,\"../color\":593,\"../drawing\":614,\"./constants\":683,\"./scrollbox\":687,d3:163}],686:[function(t,e,r){arguments[4][680][0].apply(r,arguments)},{\"./attributes\":682,\"./constants\":683,\"./defaults\":684,\"./draw\":685,dup:680}],687:[function(t,e,r){\"use strict\";e.exports=s;var n=t(\"d3\"),i=t(\"../color\"),a=t(\"../drawing\"),o=t(\"../../lib\");function s(t,e,r){this.gd=t,this.container=e,this.id=r,this.position=null,this.translateX=null,this.translateY=null,this.hbar=null,this.vbar=null,this.bg=this.container.selectAll(\"rect.scrollbox-bg\").data([0]),this.bg.exit().on(\".drag\",null).on(\"wheel\",null).remove(),this.bg.enter().append(\"rect\").classed(\"scrollbox-bg\",!0).style(\"pointer-events\",\"all\").attr({opacity:0,x:0,y:0,width:0,height:0})}s.barWidth=2,s.barLength=20,s.barRadius=2,s.barPad=1,s.barColor=\"#808BA4\",s.prototype.enable=function(t,e,r){var o=this.gd._fullLayout,l=o.width,c=o.height;this.position=t;var u,h,f,p,d=this.position.l,g=this.position.w,v=this.position.t,m=this.position.h,y=this.position.direction,x=\"down\"===y,b=\"left\"===y,_=\"up\"===y,w=g,k=m;x||b||\"right\"===y||_||(this.position.direction=\"down\",x=!0),x||_?(h=(u=d)+w,x?(f=v,k=(p=Math.min(f+k,c))-f):k=(p=v+k)-(f=Math.max(p-k,0))):(p=(f=v)+k,b?w=(h=d+w)-(u=Math.max(h-w,0)):(u=d,w=(h=Math.min(u+w,l))-u)),this._box={l:u,t:f,w:w,h:k};var T=g>w,A=s.barLength+2*s.barPad,M=s.barWidth+2*s.barPad,S=d,E=v+m;E+M>c&&(E=c-M);var C=this.container.selectAll(\"rect.scrollbar-horizontal\").data(T?[0]:[]);C.exit().on(\".drag\",null).remove(),C.enter().append(\"rect\").classed(\"scrollbar-horizontal\",!0).call(i.fill,s.barColor),T?(this.hbar=C.attr({rx:s.barRadius,ry:s.barRadius,x:S,y:E,width:A,height:M}),this._hbarXMin=S+A/2,this._hbarTranslateMax=w-A):(delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax);var L=m>k,P=s.barWidth+2*s.barPad,O=s.barLength+2*s.barPad,z=d+g,I=v;z+P>l&&(z=l-P);var D=this.container.selectAll(\"rect.scrollbar-vertical\").data(L?[0]:[]);D.exit().on(\".drag\",null).remove(),D.enter().append(\"rect\").classed(\"scrollbar-vertical\",!0).call(i.fill,s.barColor),L?(this.vbar=D.attr({rx:s.barRadius,ry:s.barRadius,x:z,y:I,width:P,height:O}),this._vbarYMin=I+O/2,this._vbarTranslateMax=k-O):(delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax);var R=this.id,F=u-.5,B=L?h+P+.5:h+.5,N=f-.5,j=T?p+M+.5:p+.5,U=o._topdefs.selectAll(\"#\"+R).data(T||L?[0]:[]);if(U.exit().remove(),U.enter().append(\"clipPath\").attr(\"id\",R).append(\"rect\"),T||L?(this._clipRect=U.select(\"rect\").attr({x:Math.floor(F),y:Math.floor(N),width:Math.ceil(B)-Math.floor(F),height:Math.ceil(j)-Math.floor(N)}),this.container.call(a.setClipUrl,R,this.gd),this.bg.attr({x:d,y:v,width:g,height:m})):(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),T||L){var V=n.behavior.drag().on(\"dragstart\",function(){n.event.sourceEvent.preventDefault()}).on(\"drag\",this._onBoxDrag.bind(this));this.container.on(\"wheel\",null).on(\"wheel\",this._onBoxWheel.bind(this)).on(\".drag\",null).call(V);var q=n.behavior.drag().on(\"dragstart\",function(){n.event.sourceEvent.preventDefault(),n.event.sourceEvent.stopPropagation()}).on(\"drag\",this._onBarDrag.bind(this));T&&this.hbar.on(\".drag\",null).call(q),L&&this.vbar.on(\".drag\",null).call(q)}this.setTranslate(e,r)},s.prototype.disable=function(){(this.hbar||this.vbar)&&(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),this.hbar&&(this.hbar.on(\".drag\",null),this.hbar.remove(),delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax),this.vbar&&(this.vbar.on(\".drag\",null),this.vbar.remove(),delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax)},s.prototype._onBoxDrag=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t-=n.event.dx),this.vbar&&(e-=n.event.dy),this.setTranslate(t,e)},s.prototype._onBoxWheel=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t+=n.event.deltaY),this.vbar&&(e+=n.event.deltaY),this.setTranslate(t,e)},s.prototype._onBarDrag=function(){var t=this.translateX,e=this.translateY;if(this.hbar){var r=t+this._hbarXMin,i=r+this._hbarTranslateMax;t=(o.constrain(n.event.x,r,i)-r)/(i-r)*(this.position.w-this._box.w)}if(this.vbar){var a=e+this._vbarYMin,s=a+this._vbarTranslateMax;e=(o.constrain(n.event.y,a,s)-a)/(s-a)*(this.position.h-this._box.h)}this.setTranslate(t,e)},s.prototype.setTranslate=function(t,e){var r=this.position.w-this._box.w,n=this.position.h-this._box.h;if(t=o.constrain(t||0,0,r),e=o.constrain(e||0,0,n),this.translateX=t,this.translateY=e,this.container.call(a.setTranslate,this._box.l-this.position.l-t,this._box.t-this.position.t-e),this._clipRect&&this._clipRect.attr({x:Math.floor(this.position.l+t-.5),y:Math.floor(this.position.t+e-.5)}),this.hbar){var i=t/r;this.hbar.call(a.setTranslate,t+i*this._hbarTranslateMax,e)}if(this.vbar){var s=e/n;this.vbar.call(a.setTranslate,t,e+s*this._vbarTranslateMax)}}},{\"../../lib\":719,\"../color\":593,\"../drawing\":614,d3:163}],688:[function(t,e,r){\"use strict\";e.exports={FROM_BL:{left:0,center:.5,right:1,bottom:0,middle:.5,top:1},FROM_TL:{left:0,center:.5,right:1,bottom:1,middle:.5,top:0},FROM_BR:{left:1,center:.5,right:0,bottom:0,middle:.5,top:1},LINE_SPACING:1.3,CAP_SHIFT:.7,MID_SHIFT:.35,OPPOSITE_SIDE:{left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}}},{}],689:[function(t,e,r){\"use strict\";e.exports={INCREASING:{COLOR:\"#3D9970\",SYMBOL:\"\\u25b2\"},DECREASING:{COLOR:\"#FF4136\",SYMBOL:\"\\u25bc\"}}},{}],690:[function(t,e,r){\"use strict\";e.exports={FORMAT_LINK:\"https://github.com/d3/d3-3.x-api-reference/blob/master/Formatting.md#d3_format\",DATE_FORMAT_LINK:\"https://github.com/d3/d3-3.x-api-reference/blob/master/Time-Formatting.md#format\"}},{}],691:[function(t,e,r){\"use strict\";e.exports={COMPARISON_OPS:[\"=\",\"!=\",\"<\",\">=\",\">\",\"<=\"],COMPARISON_OPS2:[\"=\",\"<\",\">=\",\">\",\"<=\"],INTERVAL_OPS:[\"[]\",\"()\",\"[)\",\"(]\",\"][\",\")(\",\"](\",\")[\"],SET_OPS:[\"{}\",\"}{\"],CONSTRAINT_REDUCTION:{\"=\":\"=\",\"<\":\"<\",\"<=\":\"<\",\">\":\">\",\">=\":\">\",\"[]\":\"[]\",\"()\":\"[]\",\"[)\":\"[]\",\"(]\":\"[]\",\"][\":\"][\",\")(\":\"][\",\"](\":\"][\",\")[\":\"][\"}}},{}],692:[function(t,e,r){\"use strict\";e.exports={solid:[[],0],dot:[[.5,1],200],dash:[[.5,1],50],longdash:[[.5,1],10],dashdot:[[.5,.625,.875,1],50],longdashdot:[[.5,.7,.8,1],10]}},{}],693:[function(t,e,r){\"use strict\";e.exports={circle:\"\\u25cf\",\"circle-open\":\"\\u25cb\",square:\"\\u25a0\",\"square-open\":\"\\u25a1\",diamond:\"\\u25c6\",\"diamond-open\":\"\\u25c7\",cross:\"+\",x:\"\\u274c\"}},{}],694:[function(t,e,r){\"use strict\";e.exports={SHOW_PLACEHOLDER:100,HIDE_PLACEHOLDER:1e3,DESELECTDIM:.2}},{}],695:[function(t,e,r){\"use strict\";e.exports={BADNUM:void 0,FP_SAFE:Number.MAX_VALUE/1e4,ONEAVGYEAR:315576e5,ONEAVGMONTH:26298e5,ONEDAY:864e5,ONEHOUR:36e5,ONEMIN:6e4,ONESEC:1e3,EPOCHJD:2440587.5,ALMOST_EQUAL:1-1e-6,LOG_CLIP:10,MINUS_SIGN:\"\\u2212\"}},{}],696:[function(t,e,r){\"use strict\";r.xmlns=\"http://www.w3.org/2000/xmlns/\",r.svg=\"http://www.w3.org/2000/svg\",r.xlink=\"http://www.w3.org/1999/xlink\",r.svgAttrs={xmlns:r.svg,\"xmlns:xlink\":r.xlink}},{}],697:[function(t,e,r){\"use strict\";r.version=\"1.49.1\",t(\"es6-promise\").polyfill(),t(\"../build/plotcss\"),t(\"./fonts/mathjax_config\")();for(var n=t(\"./registry\"),i=r.register=n.register,a=t(\"./plot_api\"),o=Object.keys(a),s=0;s<o.length;s++){var l=o[s];\"_\"!==l.charAt(0)&&(r[l]=a[l]),i({moduleType:\"apiMethod\",name:l,fn:a[l]})}i(t(\"./traces/scatter\")),i([t(\"./components/fx\"),t(\"./components/legend\"),t(\"./components/annotations\"),t(\"./components/annotations3d\"),t(\"./components/shapes\"),t(\"./components/images\"),t(\"./components/updatemenus\"),t(\"./components/sliders\"),t(\"./components/rangeslider\"),t(\"./components/rangeselector\"),t(\"./components/grid\"),t(\"./components/errorbars\"),t(\"./components/colorscale\"),t(\"./components/colorbar\")]),i([t(\"./locale-en\"),t(\"./locale-en-us\")]),r.Icons=t(\"./fonts/ploticon\"),r.Plots=t(\"./plots/plots\"),r.Fx=t(\"./components/fx\"),r.Snapshot=t(\"./snapshot\"),r.PlotSchema=t(\"./plot_api/plot_schema\"),r.Queue=t(\"./lib/queue\"),r.d3=t(\"d3\")},{\"../build/plotcss\":1,\"./components/annotations\":584,\"./components/annotations3d\":589,\"./components/colorbar\":599,\"./components/colorscale\":605,\"./components/errorbars\":620,\"./components/fx\":632,\"./components/grid\":636,\"./components/images\":641,\"./components/legend\":649,\"./components/rangeselector\":660,\"./components/rangeslider\":667,\"./components/shapes\":675,\"./components/sliders\":680,\"./components/updatemenus\":686,\"./fonts/mathjax_config\":698,\"./fonts/ploticon\":699,\"./lib/queue\":734,\"./locale-en\":748,\"./locale-en-us\":747,\"./plot_api\":752,\"./plot_api/plot_schema\":756,\"./plots/plots\":828,\"./registry\":847,\"./snapshot\":852,\"./traces/scatter\":1123,d3:163,\"es6-promise\":218}],698:[function(t,e,r){\"use strict\";e.exports=function(){\"undefined\"!=typeof MathJax&&(\"local\"!==(window.PlotlyConfig||{}).MathJaxConfig&&(MathJax.Hub.Config({messageStyle:\"none\",skipStartupTypeset:!0,displayAlign:\"left\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]}}),MathJax.Hub.Configured()))}},{}],699:[function(t,e,r){\"use strict\";e.exports={undo:{width:857.1,height:1e3,path:\"m857 350q0-87-34-166t-91-137-137-92-166-34q-96 0-183 41t-147 114q-4 6-4 13t5 11l76 77q6 5 14 5 9-1 13-7 41-53 100-82t126-29q58 0 110 23t92 61 61 91 22 111-22 111-61 91-92 61-110 23q-55 0-105-20t-90-57l77-77q17-16 8-38-10-23-33-23h-250q-15 0-25 11t-11 25v250q0 24 22 33 22 10 39-8l72-72q60 57 137 88t159 31q87 0 166-34t137-92 91-137 34-166z\",transform:\"matrix(1 0 0 -1 0 850)\"},home:{width:928.6,height:1e3,path:\"m786 296v-267q0-15-11-26t-25-10h-214v214h-143v-214h-214q-15 0-25 10t-11 26v267q0 1 0 2t0 2l321 264 321-264q1-1 1-4z m124 39l-34-41q-5-5-12-6h-2q-7 0-12 3l-386 322-386-322q-7-4-13-4-7 2-12 7l-35 41q-4 5-3 13t6 12l401 334q18 15 42 15t43-15l136-114v109q0 8 5 13t13 5h107q8 0 13-5t5-13v-227l122-102q5-5 6-12t-4-13z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"camera-retro\":{width:1e3,height:1e3,path:\"m518 386q0 8-5 13t-13 5q-37 0-63-27t-26-63q0-8 5-13t13-5 12 5 5 13q0 23 16 38t38 16q8 0 13 5t5 13z m125-73q0-59-42-101t-101-42-101 42-42 101 42 101 101 42 101-42 42-101z m-572-320h858v71h-858v-71z m643 320q0 89-62 152t-152 62-151-62-63-152 63-151 151-63 152 63 62 151z m-571 358h214v72h-214v-72z m-72-107h858v143h-462l-36-71h-360v-72z m929 143v-714q0-30-21-51t-50-21h-858q-29 0-50 21t-21 51v714q0 30 21 51t50 21h858q29 0 50-21t21-51z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoombox:{width:1e3,height:1e3,path:\"m1000-25l-250 251c40 63 63 138 63 218 0 224-182 406-407 406-224 0-406-182-406-406s183-406 407-406c80 0 155 22 218 62l250-250 125 125z m-812 250l0 438 437 0 0-438-437 0z m62 375l313 0 0-312-313 0 0 312z\",transform:\"matrix(1 0 0 -1 0 850)\"},pan:{width:1e3,height:1e3,path:\"m1000 350l-187 188 0-125-250 0 0 250 125 0-188 187-187-187 125 0 0-250-250 0 0 125-188-188 186-187 0 125 252 0 0-250-125 0 187-188 188 188-125 0 0 250 250 0 0-126 187 188z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_plus:{width:875,height:1e3,path:\"m1 787l0-875 875 0 0 875-875 0z m687-500l-187 0 0-187-125 0 0 187-188 0 0 125 188 0 0 187 125 0 0-187 187 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_minus:{width:875,height:1e3,path:\"m0 788l0-876 875 0 0 876-875 0z m688-500l-500 0 0 125 500 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},autoscale:{width:1e3,height:1e3,path:\"m250 850l-187 0-63 0 0-62 0-188 63 0 0 188 187 0 0 62z m688 0l-188 0 0-62 188 0 0-188 62 0 0 188 0 62-62 0z m-875-938l0 188-63 0 0-188 0-62 63 0 187 0 0 62-187 0z m875 188l0-188-188 0 0-62 188 0 62 0 0 62 0 188-62 0z m-125 188l-1 0-93-94-156 156 156 156 92-93 2 0 0 250-250 0 0-2 93-92-156-156-156 156 94 92 0 2-250 0 0-250 0 0 93 93 157-156-157-156-93 94 0 0 0-250 250 0 0 0-94 93 156 157 156-157-93-93 0 0 250 0 0 250z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_basic:{width:1500,height:1e3,path:\"m375 725l0 0-375-375 375-374 0-1 1125 0 0 750-1125 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_compare:{width:1125,height:1e3,path:\"m187 786l0 2-187-188 188-187 0 0 937 0 0 373-938 0z m0-499l0 1-187-188 188-188 0 0 937 0 0 376-938-1z\",transform:\"matrix(1 0 0 -1 0 850)\"},plotlylogo:{width:1542,height:1e3,path:\"m0-10h182v-140h-182v140z m228 146h183v-286h-183v286z m225 714h182v-1000h-182v1000z m225-285h182v-715h-182v715z m225 142h183v-857h-183v857z m231-428h182v-429h-182v429z m225-291h183v-138h-183v138z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"z-axis\":{width:1e3,height:1e3,path:\"m833 5l-17 108v41l-130-65 130-66c0 0 0 38 0 39 0-1 36-14 39-25 4-15-6-22-16-30-15-12-39-16-56-20-90-22-187-23-279-23-261 0-341 34-353 59 3 60 228 110 228 110-140-8-351-35-351-116 0-120 293-142 474-142 155 0 477 22 477 142 0 50-74 79-163 96z m-374 94c-58-5-99-21-99-40 0-24 65-43 144-43 79 0 143 19 143 43 0 19-42 34-98 40v216h87l-132 135-133-135h88v-216z m167 515h-136v1c16 16 31 34 46 52l84 109v54h-230v-71h124v-1c-16-17-28-32-44-51l-89-114v-51h245v72z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"3d_rotate\":{width:1e3,height:1e3,path:\"m922 660c-5 4-9 7-14 11-359 263-580-31-580-31l-102 28 58-400c0 1 1 1 2 2 118 108 351 249 351 249s-62 27-100 42c88 83 222 183 347 122 16-8 30-17 44-27-2 1-4 2-6 4z m36-329c0 0 64 229-88 296-62 27-124 14-175-11 157-78 225-208 249-266 8-19 11-31 11-31 2 5 6 15 11 32-5-13-8-20-8-20z m-775-239c70-31 117-50 198-32-121 80-199 346-199 346l-96-15-58-12c0 0 55-226 155-287z m603 133l-317-139c0 0 4-4 19-14 7-5 24-15 24-15s-177-147-389 4c235-287 536-112 536-112l31-22 100 299-4-1z m-298-153c6-4 14-9 24-15 0 0-17 10-24 15z\",transform:\"matrix(1 0 0 -1 0 850)\"},camera:{width:1e3,height:1e3,path:\"m500 450c-83 0-150-67-150-150 0-83 67-150 150-150 83 0 150 67 150 150 0 83-67 150-150 150z m400 150h-120c-16 0-34 13-39 29l-31 93c-6 15-23 28-40 28h-340c-16 0-34-13-39-28l-31-94c-6-15-23-28-40-28h-120c-55 0-100-45-100-100v-450c0-55 45-100 100-100h800c55 0 100 45 100 100v450c0 55-45 100-100 100z m-400-550c-138 0-250 112-250 250 0 138 112 250 250 250 138 0 250-112 250-250 0-138-112-250-250-250z m365 380c-19 0-35 16-35 35 0 19 16 35 35 35 19 0 35-16 35-35 0-19-16-35-35-35z\",transform:\"matrix(1 0 0 -1 0 850)\"},movie:{width:1e3,height:1e3,path:\"m938 413l-188-125c0 37-17 71-44 94 64 38 107 107 107 187 0 121-98 219-219 219-121 0-219-98-219-219 0-61 25-117 66-156h-115c30 33 49 76 49 125 0 103-84 187-187 187s-188-84-188-187c0-57 26-107 65-141-38-22-65-62-65-109v-250c0-70 56-126 125-126h500c69 0 125 56 125 126l188-126c34 0 62 28 62 63v375c0 35-28 63-62 63z m-750 0c-69 0-125 56-125 125s56 125 125 125 125-56 125-125-56-125-125-125z m406-1c-87 0-157 70-157 157 0 86 70 156 157 156s156-70 156-156-70-157-156-157z\",transform:\"matrix(1 0 0 -1 0 850)\"},question:{width:857.1,height:1e3,path:\"m500 82v107q0 8-5 13t-13 5h-107q-8 0-13-5t-5-13v-107q0-8 5-13t13-5h107q8 0 13 5t5 13z m143 375q0 49-31 91t-77 65-95 23q-136 0-207-119-9-14 4-24l74-55q4-4 10-4 9 0 14 7 30 38 48 51 19 14 48 14 27 0 48-15t21-33q0-21-11-34t-38-25q-35-16-65-48t-29-70v-20q0-8 5-13t13-5h107q8 0 13 5t5 13q0 10 12 27t30 28q18 10 28 16t25 19 25 27 16 34 7 45z m214-107q0-117-57-215t-156-156-215-58-216 58-155 156-58 215 58 215 155 156 216 58 215-58 156-156 57-215z\",transform:\"matrix(1 0 0 -1 0 850)\"},disk:{width:857.1,height:1e3,path:\"m214-7h429v214h-429v-214z m500 0h72v500q0 8-6 21t-11 20l-157 156q-5 6-19 12t-22 5v-232q0-22-15-38t-38-16h-322q-22 0-37 16t-16 38v232h-72v-714h72v232q0 22 16 38t37 16h465q22 0 38-16t15-38v-232z m-214 518v178q0 8-5 13t-13 5h-107q-7 0-13-5t-5-13v-178q0-8 5-13t13-5h107q7 0 13 5t5 13z m357-18v-518q0-22-15-38t-38-16h-750q-23 0-38 16t-16 38v750q0 22 16 38t38 16h517q23 0 50-12t42-26l156-157q16-15 27-42t11-49z\",transform:\"matrix(1 0 0 -1 0 850)\"},lasso:{width:1031,height:1e3,path:\"m1018 538c-36 207-290 336-568 286-277-48-473-256-436-463 10-57 36-108 76-151-13-66 11-137 68-183 34-28 75-41 114-42l-55-70 0 0c-2-1-3-2-4-3-10-14-8-34 5-45 14-11 34-8 45 4 1 1 2 3 2 5l0 0 113 140c16 11 31 24 45 40 4 3 6 7 8 11 48-3 100 0 151 9 278 48 473 255 436 462z m-624-379c-80 14-149 48-197 96 42 42 109 47 156 9 33-26 47-66 41-105z m-187-74c-19 16-33 37-39 60 50-32 109-55 174-68-42-25-95-24-135 8z m360 75c-34-7-69-9-102-8 8 62-16 128-68 170-73 59-175 54-244-5-9 20-16 40-20 61-28 159 121 317 333 354s407-60 434-217c28-159-121-318-333-355z\",transform:\"matrix(1 0 0 -1 0 850)\"},selectbox:{width:1e3,height:1e3,path:\"m0 850l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-285l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},spikeline:{width:1e3,height:1e3,path:\"M512 409c0-57-46-104-103-104-57 0-104 47-104 104 0 57 47 103 104 103 57 0 103-46 103-103z m-327-39l92 0 0 92-92 0z m-185 0l92 0 0 92-92 0z m370-186l92 0 0 93-92 0z m0-184l92 0 0 92-92 0z\",transform:\"matrix(1.5 0 0 -1.5 0 850)\"},pencil:{width:1792,height:1792,path:\"M491 1536l91-91-235-235-91 91v107h128v128h107zm523-928q0-22-22-22-10 0-17 7l-542 542q-7 7-7 17 0 22 22 22 10 0 17-7l542-542q7-7 7-17zm-54-192l416 416-832 832h-416v-416zm683 96q0 53-37 90l-166 166-416-416 166-165q36-38 90-38 53 0 91 38l235 234q37 39 37 91z\",transform:\"matrix(1 0 0 1 0 1)\"},newplotlylogo:{name:\"newplotlylogo\",svg:\"<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 132 132'><defs><style>.cls-1 {fill: #119dff;} .cls-2 {fill: #25fefd;} .cls-3 {fill: #fff;}</style></defs><title>plotly-logomark</title><g id='symbol'><rect class='cls-1' width='132' height='132' rx='6' ry='6'/><circle class='cls-2' cx='78' cy='54' r='6'/><circle class='cls-2' cx='102' cy='30' r='6'/><circle class='cls-2' cx='78' cy='30' r='6'/><circle class='cls-2' cx='54' cy='30' r='6'/><circle class='cls-2' cx='30' cy='30' r='6'/><circle class='cls-2' cx='30' cy='54' r='6'/><path class='cls-3' d='M30,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,30,72Z'/><path class='cls-3' d='M78,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,78,72Z'/><path class='cls-3' d='M54,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,54,48Z'/><path class='cls-3' d='M102,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,102,48Z'/></g></svg>\"}}},{}],700:[function(t,e,r){\"use strict\";r.isLeftAnchor=function(t){return\"left\"===t.xanchor||\"auto\"===t.xanchor&&t.x<=1/3},r.isCenterAnchor=function(t){return\"center\"===t.xanchor||\"auto\"===t.xanchor&&t.x>1/3&&t.x<2/3},r.isRightAnchor=function(t){return\"right\"===t.xanchor||\"auto\"===t.xanchor&&t.x>=2/3},r.isTopAnchor=function(t){return\"top\"===t.yanchor||\"auto\"===t.yanchor&&t.y>=2/3},r.isMiddleAnchor=function(t){return\"middle\"===t.yanchor||\"auto\"===t.yanchor&&t.y>1/3&&t.y<2/3},r.isBottomAnchor=function(t){return\"bottom\"===t.yanchor||\"auto\"===t.yanchor&&t.y<=1/3}},{}],701:[function(t,e,r){\"use strict\";var n=t(\"./mod\"),i=n.mod,a=n.modHalf,o=Math.PI,s=2*o;function l(t){return Math.abs(t[1]-t[0])>s-1e-14}function c(t,e){return a(e-t,s)}function u(t,e){if(l(e))return!0;var r,n;e[0]<e[1]?(r=e[0],n=e[1]):(r=e[1],n=e[0]),(r=i(r,s))>(n=i(n,s))&&(n+=s);var a=i(t,s),o=a+s;return a>=r&&a<=n||o>=r&&o<=n}function h(t,e,r,n,i,a,c){i=i||0,a=a||0;var u,h,f,p,d,g=l([r,n]);function v(t,e){return[t*Math.cos(e)+i,a-t*Math.sin(e)]}g?(u=0,h=o,f=s):r<n?(u=r,f=n):(u=n,f=r),t<e?(p=t,d=e):(p=e,d=t);var m,y=Math.abs(f-u)<=o?0:1;function x(t,e,r){return\"A\"+[t,t]+\" \"+[0,y,r]+\" \"+v(t,e)}return g?m=null===p?\"M\"+v(d,u)+x(d,h,0)+x(d,f,0)+\"Z\":\"M\"+v(p,u)+x(p,h,0)+x(p,f,0)+\"ZM\"+v(d,u)+x(d,h,1)+x(d,f,1)+\"Z\":null===p?(m=\"M\"+v(d,u)+x(d,f,0),c&&(m+=\"L0,0Z\")):m=\"M\"+v(p,u)+\"L\"+v(d,u)+x(d,f,0)+\"L\"+v(p,f)+x(p,u,1)+\"Z\",m}e.exports={deg2rad:function(t){return t/180*o},rad2deg:function(t){return t/o*180},angleDelta:c,angleDist:function(t,e){return Math.abs(c(t,e))},isFullCircle:l,isAngleInsideSector:u,isPtInsideSector:function(t,e,r,n){return!!u(e,n)&&(r[0]<r[1]?(i=r[0],a=r[1]):(i=r[1],a=r[0]),t>=i&&t<=a);var i,a},pathArc:function(t,e,r,n,i){return h(null,t,e,r,n,i,0)},pathSector:function(t,e,r,n,i){return h(null,t,e,r,n,i,1)},pathAnnulus:function(t,e,r,n,i,a){return h(t,e,r,n,i,a,1)}}},{\"./mod\":726}],702:[function(t,e,r){\"use strict\";var n=Array.isArray,i=\"undefined\"!=typeof ArrayBuffer&&ArrayBuffer.isView?ArrayBuffer:{isView:function(){return!1}},a=\"undefined\"==typeof DataView?function(){}:DataView;function o(t){return i.isView(t)&&!(t instanceof a)}function s(t){return n(t)||o(t)}function l(t,e,r){if(s(t)){if(s(t[0])){for(var n=r,i=0;i<t.length;i++)n=e(n,t[i].length);return n}return t.length}return 0}r.isTypedArray=o,r.isArrayOrTypedArray=s,r.isArray1D=function(t){return!s(t[0])},r.ensureArray=function(t,e){return n(t)||(t=[]),t.length=e,t},r.concat=function(){var t,e,r,i,a,o,s,l,c=[],u=!0,h=0;for(r=0;r<arguments.length;r++)(o=(i=arguments[r]).length)&&(e?c.push(i):(e=i,a=o),n(i)?t=!1:(u=!1,h?t!==i.constructor&&(t=!1):t=i.constructor),h+=o);if(!h)return[];if(!c.length)return e;if(u)return e.concat.apply(e,c);if(t){for((s=new t(h)).set(e),r=0;r<c.length;r++)i=c[r],s.set(i,a),a+=i.length;return s}for(s=new Array(h),l=0;l<e.length;l++)s[l]=e[l];for(r=0;r<c.length;r++){for(i=c[r],l=0;l<i.length;l++)s[a+l]=i[l];a+=l}return s},r.maxRowLength=function(t){return l(t,Math.max,0)},r.minRowLength=function(t){return l(t,Math.min,1/0)}},{}],703:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../constants/numerical\").BADNUM,a=/^['\"%,$#\\s']+|[, ]|['\"%,$#\\s']+$/g;e.exports=function(t){return\"string\"==typeof t&&(t=t.replace(a,\"\")),n(t)?Number(t):i}},{\"../constants/numerical\":695,\"fast-isnumeric\":225}],704:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t._fullLayout;e._glcanvas&&e._glcanvas.size()&&e._glcanvas.each(function(t){t.regl&&t.regl.clear({color:!0,depth:!0})})}},{}],705:[function(t,e,r){\"use strict\";e.exports=function(t){t._responsiveChartHandler&&(window.removeEventListener(\"resize\",t._responsiveChartHandler),delete t._responsiveChartHandler)}},{}],706:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../plots/attributes\"),o=t(\"../components/colorscale/scales\"),s=t(\"../constants/interactions\").DESELECTDIM,l=t(\"./nested_property\"),c=t(\"./regex\").counter,u=t(\"./mod\").modHalf,h=t(\"./array\").isArrayOrTypedArray;function f(t,e){var n=r.valObjectMeta[e.valType];if(e.arrayOk&&h(t))return!0;if(n.validateFunction)return n.validateFunction(t,e);var i={},a=i,o={set:function(t){a=t}};return n.coerceFunction(t,o,i,e),a!==i}r.valObjectMeta={data_array:{coerceFunction:function(t,e,r){h(t)?e.set(t):void 0!==r&&e.set(r)}},enumerated:{coerceFunction:function(t,e,r,n){n.coerceNumber&&(t=+t),-1===n.values.indexOf(t)?e.set(r):e.set(t)},validateFunction:function(t,e){e.coerceNumber&&(t=+t);for(var r=e.values,n=0;n<r.length;n++){var i=String(r[n]);if(\"/\"===i.charAt(0)&&\"/\"===i.charAt(i.length-1)){if(new RegExp(i.substr(1,i.length-2)).test(t))return!0}else if(t===r[n])return!0}return!1}},boolean:{coerceFunction:function(t,e,r){!0===t||!1===t?e.set(t):e.set(r)}},number:{coerceFunction:function(t,e,r,i){!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},integer:{coerceFunction:function(t,e,r,i){t%1||!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},string:{coerceFunction:function(t,e,r,n){if(\"string\"!=typeof t){var i=\"number\"==typeof t;!0!==n.strict&&i?e.set(String(t)):e.set(r)}else n.noBlank&&!t?e.set(r):e.set(t)}},color:{coerceFunction:function(t,e,r){i(t).isValid()?e.set(t):e.set(r)}},colorlist:{coerceFunction:function(t,e,r){Array.isArray(t)&&t.length&&t.every(function(t){return i(t).isValid()})?e.set(t):e.set(r)}},colorscale:{coerceFunction:function(t,e,r){e.set(o.get(t,r))}},angle:{coerceFunction:function(t,e,r){\"auto\"===t?e.set(\"auto\"):n(t)?e.set(u(+t,360)):e.set(r)}},subplotid:{coerceFunction:function(t,e,r,n){var i=n.regex||c(r);\"string\"==typeof t&&i.test(t)?e.set(t):e.set(r)},validateFunction:function(t,e){var r=e.dflt;return t===r||\"string\"==typeof t&&!!c(r).test(t)}},flaglist:{coerceFunction:function(t,e,r,n){if(\"string\"==typeof t)if(-1===(n.extras||[]).indexOf(t)){for(var i=t.split(\"+\"),a=0;a<i.length;){var o=i[a];-1===n.flags.indexOf(o)||i.indexOf(o)<a?i.splice(a,1):a++}i.length?e.set(i.join(\"+\")):e.set(r)}else e.set(t);else e.set(r)}},any:{coerceFunction:function(t,e,r){void 0===t?e.set(r):e.set(t)}},info_array:{coerceFunction:function(t,e,n,i){function a(t,e,n){var i,a={set:function(t){i=t}};return void 0===n&&(n=e.dflt),r.valObjectMeta[e.valType].coerceFunction(t,a,n,e),i}var o=2===i.dimensions||\"1-2\"===i.dimensions&&Array.isArray(t)&&Array.isArray(t[0]);if(Array.isArray(t)){var s,l,c,u,h,f,p=i.items,d=[],g=Array.isArray(p),v=g&&o&&Array.isArray(p[0]),m=o&&g&&!v,y=g&&!m?p.length:t.length;if(n=Array.isArray(n)?n:[],o)for(s=0;s<y;s++)for(d[s]=[],c=Array.isArray(t[s])?t[s]:[],h=m?p.length:g?p[s].length:c.length,l=0;l<h;l++)u=m?p[l]:g?p[s][l]:p,void 0!==(f=a(c[l],u,(n[s]||[])[l]))&&(d[s][l]=f);else for(s=0;s<y;s++)void 0!==(f=a(t[s],g?p[s]:p,n[s]))&&(d[s]=f);e.set(d)}else e.set(n)},validateFunction:function(t,e){if(!Array.isArray(t))return!1;var r=e.items,n=Array.isArray(r),i=2===e.dimensions;if(!e.freeLength&&t.length!==r.length)return!1;for(var a=0;a<t.length;a++)if(i){if(!Array.isArray(t[a])||!e.freeLength&&t[a].length!==r[a].length)return!1;for(var o=0;o<t[a].length;o++)if(!f(t[a][o],n?r[a][o]:r))return!1}else if(!f(t[a],n?r[a]:r))return!1;return!0}}},r.coerce=function(t,e,n,i,a){var o=l(n,i).get(),s=l(t,i),c=l(e,i),u=s.get(),p=e._template;if(void 0===u&&p&&(u=l(p,i).get(),p=0),void 0===a&&(a=o.dflt),o.arrayOk&&h(u))return c.set(u),u;var d=r.valObjectMeta[o.valType].coerceFunction;d(u,c,a,o);var g=c.get();return p&&g===a&&!f(u,o)&&(d(u=l(p,i).get(),c,a,o),g=c.get()),g},r.coerce2=function(t,e,n,i,a){var o=l(t,i),s=r.coerce(t,e,n,i,a),c=o.get();return null!=c&&s},r.coerceFont=function(t,e,r){var n={};return r=r||{},n.family=t(e+\".family\",r.family),n.size=t(e+\".size\",r.size),n.color=t(e+\".color\",r.color),n},r.coerceHoverinfo=function(t,e,n){var i,o=e._module.attributes,s=o.hoverinfo?o:a,l=s.hoverinfo;if(1===n._dataLength){var c=\"all\"===l.dflt?l.flags.slice():l.dflt.split(\"+\");c.splice(c.indexOf(\"name\"),1),i=c.join(\"+\")}return r.coerce(t,e,s,\"hoverinfo\",i)},r.coerceSelectionMarkerOpacity=function(t,e){if(t.marker){var r,n,i=t.marker.opacity;if(void 0!==i)h(i)||t.selected||t.unselected||(r=i,n=s*i),e(\"selected.marker.opacity\",r),e(\"unselected.marker.opacity\",n)}},r.validate=f},{\"../components/colorscale/scales\":608,\"../constants/interactions\":694,\"../plots/attributes\":764,\"./array\":702,\"./mod\":726,\"./nested_property\":727,\"./regex\":735,\"fast-isnumeric\":225,tinycolor2:537}],707:[function(t,e,r){\"use strict\";var n,i,a=t(\"d3\"),o=t(\"fast-isnumeric\"),s=t(\"./loggers\"),l=t(\"./mod\").mod,c=t(\"../constants/numerical\"),u=c.BADNUM,h=c.ONEDAY,f=c.ONEHOUR,p=c.ONEMIN,d=c.ONESEC,g=c.EPOCHJD,v=t(\"../registry\"),m=a.time.format.utc,y=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\d)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d:?\\d\\d)?)?)?)?)?\\s*$/m,x=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\di?)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d:?\\d\\d)?)?)?)?)?\\s*$/m,b=(new Date).getFullYear()-70;function _(t){return t&&v.componentsRegistry.calendars&&\"string\"==typeof t&&\"gregorian\"!==t}function w(t,e){return String(t+Math.pow(10,e)).substr(1)}r.dateTick0=function(t,e){return _(t)?e?v.getComponentMethod(\"calendars\",\"CANONICAL_SUNDAY\")[t]:v.getComponentMethod(\"calendars\",\"CANONICAL_TICK\")[t]:e?\"2000-01-02\":\"2000-01-01\"},r.dfltRange=function(t){return _(t)?v.getComponentMethod(\"calendars\",\"DFLTRANGE\")[t]:[\"2000-01-01\",\"2001-01-01\"]},r.isJSDate=function(t){return\"object\"==typeof t&&null!==t&&\"function\"==typeof t.getTime},r.dateTime2ms=function(t,e){if(r.isJSDate(t)){var a=t.getTimezoneOffset()*p,o=(t.getUTCMinutes()-t.getMinutes())*p+(t.getUTCSeconds()-t.getSeconds())*d+(t.getUTCMilliseconds()-t.getMilliseconds());if(o){var s=3*p;a=a-s/2+l(o-a+s/2,s)}return(t=Number(t)-a)>=n&&t<=i?t:u}if(\"string\"!=typeof t&&\"number\"!=typeof t)return u;t=String(t);var c=_(e),m=t.charAt(0);!c||\"G\"!==m&&\"g\"!==m||(t=t.substr(1),e=\"\");var w=c&&\"chinese\"===e.substr(0,7),k=t.match(w?x:y);if(!k)return u;var T=k[1],A=k[3]||\"1\",M=Number(k[5]||1),S=Number(k[7]||0),E=Number(k[9]||0),C=Number(k[11]||0);if(c){if(2===T.length)return u;var L;T=Number(T);try{var P=v.getComponentMethod(\"calendars\",\"getCal\")(e);if(w){var O=\"i\"===A.charAt(A.length-1);A=parseInt(A,10),L=P.newDate(T,P.toMonthIndex(T,A,O),M)}else L=P.newDate(T,Number(A),M)}catch(t){return u}return L?(L.toJD()-g)*h+S*f+E*p+C*d:u}T=2===T.length?(Number(T)+2e3-b)%100+b:Number(T),A-=1;var z=new Date(Date.UTC(2e3,A,M,S,E));return z.setUTCFullYear(T),z.getUTCMonth()!==A?u:z.getUTCDate()!==M?u:z.getTime()+C*d},n=r.MIN_MS=r.dateTime2ms(\"-9999\"),i=r.MAX_MS=r.dateTime2ms(\"9999-12-31 23:59:59.9999\"),r.isDateTime=function(t,e){return r.dateTime2ms(t,e)!==u};var k=90*h,T=3*f,A=5*p;function M(t,e,r,n,i){if((e||r||n||i)&&(t+=\" \"+w(e,2)+\":\"+w(r,2),(n||i)&&(t+=\":\"+w(n,2),i))){for(var a=4;i%10==0;)a-=1,i/=10;t+=\".\"+w(i,a)}return t}r.ms2DateTime=function(t,e,r){if(\"number\"!=typeof t||!(t>=n&&t<=i))return u;e||(e=0);var a,o,s,c,y,x,b=Math.floor(10*l(t+.05,1)),w=Math.round(t-b/10);if(_(r)){var S=Math.floor(w/h)+g,E=Math.floor(l(t,h));try{a=v.getComponentMethod(\"calendars\",\"getCal\")(r).fromJD(S).formatDate(\"yyyy-mm-dd\")}catch(t){a=m(\"G%Y-%m-%d\")(new Date(w))}if(\"-\"===a.charAt(0))for(;a.length<11;)a=\"-0\"+a.substr(1);else for(;a.length<10;)a=\"0\"+a;o=e<k?Math.floor(E/f):0,s=e<k?Math.floor(E%f/p):0,c=e<T?Math.floor(E%p/d):0,y=e<A?E%d*10+b:0}else x=new Date(w),a=m(\"%Y-%m-%d\")(x),o=e<k?x.getUTCHours():0,s=e<k?x.getUTCMinutes():0,c=e<T?x.getUTCSeconds():0,y=e<A?10*x.getUTCMilliseconds()+b:0;return M(a,o,s,c,y)},r.ms2DateTimeLocal=function(t){if(!(t>=n+h&&t<=i-h))return u;var e=Math.floor(10*l(t+.05,1)),r=new Date(Math.round(t-e/10));return M(a.time.format(\"%Y-%m-%d\")(r),r.getHours(),r.getMinutes(),r.getSeconds(),10*r.getUTCMilliseconds()+e)},r.cleanDate=function(t,e,n){if(t===u)return e;if(r.isJSDate(t)||\"number\"==typeof t&&isFinite(t)){if(_(n))return s.error(\"JS Dates and milliseconds are incompatible with world calendars\",t),e;if(!(t=r.ms2DateTimeLocal(+t))&&void 0!==e)return e}else if(!r.isDateTime(t,n))return s.error(\"unrecognized date\",t),e;return t};var S=/%\\d?f/g;function E(t,e,r,n){t=t.replace(S,function(t){var r=Math.min(+t.charAt(1)||6,6);return(e/1e3%1+2).toFixed(r).substr(2).replace(/0+$/,\"\")||\"0\"});var i=new Date(Math.floor(e+.05));if(_(n))try{t=v.getComponentMethod(\"calendars\",\"worldCalFmt\")(t,e,n)}catch(t){return\"Invalid\"}return r(t)(i)}var C=[59,59.9,59.99,59.999,59.9999];r.formatDate=function(t,e,r,n,i,a){if(i=_(i)&&i,!e)if(\"y\"===r)e=a.year;else if(\"m\"===r)e=a.month;else{if(\"d\"!==r)return function(t,e){var r=l(t+.05,h),n=w(Math.floor(r/f),2)+\":\"+w(l(Math.floor(r/p),60),2);if(\"M\"!==e){o(e)||(e=0);var i=(100+Math.min(l(t/d,60),C[e])).toFixed(e).substr(1);e>0&&(i=i.replace(/0+$/,\"\").replace(/[\\.]$/,\"\")),n+=\":\"+i}return n}(t,r)+\"\\n\"+E(a.dayMonthYear,t,n,i);e=a.dayMonth+\"\\n\"+a.year}return E(e,t,n,i)};var L=3*h;r.incrementMonth=function(t,e,r){r=_(r)&&r;var n=l(t,h);if(t=Math.round(t-n),r)try{var i=Math.round(t/h)+g,a=v.getComponentMethod(\"calendars\",\"getCal\")(r),o=a.fromJD(i);return e%12?a.add(o,e,\"m\"):a.add(o,e/12,\"y\"),(o.toJD()-g)*h+n}catch(e){s.error(\"invalid ms \"+t+\" in calendar \"+r)}var c=new Date(t+L);return c.setUTCMonth(c.getUTCMonth()+e)+n-L},r.findExactDates=function(t,e){for(var r,n,i=0,a=0,s=0,l=0,c=_(e)&&v.getComponentMethod(\"calendars\",\"getCal\")(e),u=0;u<t.length;u++)if(n=t[u],o(n)){if(!(n%h))if(c)try{1===(r=c.fromJD(n/h+g)).day()?1===r.month()?i++:a++:s++}catch(t){}else 1===(r=new Date(n)).getUTCDate()?0===r.getUTCMonth()?i++:a++:s++}else l++;s+=a+=i;var f=t.length-l;return{exactYears:i/f,exactMonths:a/f,exactDays:s/f}}},{\"../constants/numerical\":695,\"../registry\":847,\"./loggers\":723,\"./mod\":726,d3:163,\"fast-isnumeric\":225}],708:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./loggers\");function a(t){var e=t&&t.parentNode;e&&e.removeChild(t)}function o(t,e,r){var n=\"plotly.js-style-\"+t,a=document.getElementById(n);a||((a=document.createElement(\"style\")).setAttribute(\"id\",n),a.appendChild(document.createTextNode(\"\")),document.head.appendChild(a));var o=a.sheet;o.insertRule?o.insertRule(e+\"{\"+r+\"}\",0):o.addRule?o.addRule(e,r,0):i.warn(\"addStyleRule failed\")}e.exports={getGraphDiv:function(t){var e;if(\"string\"==typeof t){if(null===(e=document.getElementById(t)))throw new Error(\"No DOM element with id '\"+t+\"' exists on the page.\");return e}if(null==t)throw new Error(\"DOM element provided is null or undefined\");return t},isPlotDiv:function(t){var e=n.select(t);return e.node()instanceof HTMLElement&&e.size()&&e.classed(\"js-plotly-plot\")},removeElement:a,addStyleRule:function(t,e){o(\"global\",t,e)},addRelatedStyleRule:o,deleteRelatedStyleRule:function(t){var e=\"plotly.js-style-\"+t,r=document.getElementById(e);r&&a(r)}}},{\"./loggers\":723,d3:163}],709:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i={init:function(t){if(t._ev instanceof n)return t;var e=new n,r=new n;return t._ev=e,t._internalEv=r,t.on=e.on.bind(e),t.once=e.once.bind(e),t.removeListener=e.removeListener.bind(e),t.removeAllListeners=e.removeAllListeners.bind(e),t._internalOn=r.on.bind(r),t._internalOnce=r.once.bind(r),t._removeInternalListener=r.removeListener.bind(r),t._removeAllInternalListeners=r.removeAllListeners.bind(r),t.emit=function(n,i){\"undefined\"!=typeof jQuery&&jQuery(t).trigger(n,i),e.emit(n,i),r.emit(n,i)},t},triggerHandler:function(t,e,r){var n,i;\"undefined\"!=typeof jQuery&&(n=jQuery(t).triggerHandler(e,r));var a=t._ev;if(!a)return n;var o,s=a._events[e];if(!s)return n;function l(t){return t.listener?(a.removeListener(e,t.listener),t.fired?void 0:(t.fired=!0,t.listener.apply(a,[r]))):t.apply(a,[r])}for(s=Array.isArray(s)?s:[s],o=0;o<s.length-1;o++)l(s[o]);return i=l(s[o]),void 0!==n?n:i},purge:function(t){return delete t._ev,delete t.on,delete t.once,delete t.removeListener,delete t.removeAllListeners,delete t.emit,delete t._ev,delete t._internalEv,delete t._internalOn,delete t._internalOnce,delete t._removeInternalListener,delete t._removeAllInternalListeners,t}};e.exports=i},{events:104}],710:[function(t,e,r){\"use strict\";var n=t(\"./is_plain_object.js\"),i=Array.isArray;function a(t,e,r,o){var s,l,c,u,h,f,p=t[0],d=t.length;if(2===d&&i(p)&&i(t[1])&&0===p.length){if(function(t,e){var r,n;for(r=0;r<t.length;r++){if(null!==(n=t[r])&&\"object\"==typeof n)return!1;void 0!==n&&(e[r]=n)}return!0}(t[1],p))return p;p.splice(0,p.length)}for(var g=1;g<d;g++)for(l in s=t[g])c=p[l],u=s[l],o&&i(u)?p[l]=u:e&&u&&(n(u)||(h=i(u)))?(h?(h=!1,f=c&&i(c)?c:[]):f=c&&n(c)?c:{},p[l]=a([f,u],e,r,o)):(\"undefined\"!=typeof u||r)&&(p[l]=u);return p}r.extendFlat=function(){return a(arguments,!1,!1,!1)},r.extendDeep=function(){return a(arguments,!0,!1,!1)},r.extendDeepAll=function(){return a(arguments,!0,!0,!1)},r.extendDeepNoArrays=function(){return a(arguments,!0,!1,!0)}},{\"./is_plain_object.js\":720}],711:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e={},r=[],n=0,i=0;i<t.length;i++){var a=t[i];1!==e[a]&&(e[a]=1,r[n++]=a)}return r}},{}],712:[function(t,e,r){\"use strict\";function n(t){return!0===t.visible}function i(t){var e=t[0].trace;return!0===e.visible&&0!==e._length}e.exports=function(t){for(var e,r=(e=t,Array.isArray(e)&&Array.isArray(e[0])&&e[0][0]&&e[0][0].trace?i:n),a=[],o=0;o<t.length;o++){var s=t[o];r(s)&&a.push(s)}return a}},{}],713:[function(t,e,r){\"use strict\";var n=t(\"country-regex\"),i=t(\"../lib\"),a=Object.keys(n),o={\"ISO-3\":i.identity,\"USA-states\":i.identity,\"country names\":function(t){for(var e=0;e<a.length;e++){var r=a[e],o=new RegExp(n[r]);if(o.test(t.trim().toLowerCase()))return r}return i.log(\"Unrecognized country name: \"+t+\".\"),!1}};e.exports={locationToFeature:function(t,e,r){if(!e||\"string\"!=typeof e)return!1;var n,a,s,l=o[t](e);if(l){if(\"USA-states\"===t)for(n=[],s=0;s<r.length;s++)(a=r[s]).properties&&a.properties.gu&&\"USA\"===a.properties.gu&&n.push(a);else n=r;for(s=0;s<n.length;s++)if((a=n[s]).id===l)return a;i.log([\"Location with id\",l,\"does not have a matching topojson feature at this resolution.\"].join(\" \"))}return!1}}},{\"../lib\":719,\"country-regex\":134}],714:[function(t,e,r){\"use strict\";var n=t(\"../constants/numerical\").BADNUM;r.calcTraceToLineCoords=function(t){for(var e=t[0].trace.connectgaps,r=[],i=[],a=0;a<t.length;a++){var o=t[a].lonlat;o[0]!==n?i.push(o):!e&&i.length>0&&(r.push(i),i=[])}return i.length>0&&r.push(i),r},r.makeLine=function(t){return 1===t.length?{type:\"LineString\",coordinates:t[0]}:{type:\"MultiLineString\",coordinates:t}},r.makePolygon=function(t){if(1===t.length)return{type:\"Polygon\",coordinates:t};for(var e=new Array(t.length),r=0;r<t.length;r++)e[r]=[t[r]];return{type:\"MultiPolygon\",coordinates:e}},r.makeBlank=function(){return{type:\"Point\",coordinates:[]}}},{\"../constants/numerical\":695}],715:[function(t,e,r){\"use strict\";var n,i,a,o=t(\"./mod\").mod;function s(t,e,r,n,i,a,o,s){var l=r-t,c=i-t,u=o-i,h=n-e,f=a-e,p=s-a,d=l*p-u*h;if(0===d)return null;var g=(c*p-u*f)/d,v=(c*h-l*f)/d;return v<0||v>1||g<0||g>1?null:{x:t+l*g,y:e+h*g}}function l(t,e,r,n,i){var a=n*t+i*e;if(a<0)return n*n+i*i;if(a>r){var o=n-t,s=i-e;return o*o+s*s}var l=n*e-i*t;return l*l/r}r.segmentsIntersect=s,r.segmentDistance=function(t,e,r,n,i,a,o,c){if(s(t,e,r,n,i,a,o,c))return 0;var u=r-t,h=n-e,f=o-i,p=c-a,d=u*u+h*h,g=f*f+p*p,v=Math.min(l(u,h,d,i-t,a-e),l(u,h,d,o-t,c-e),l(f,p,g,t-i,e-a),l(f,p,g,r-i,n-a));return Math.sqrt(v)},r.getTextLocation=function(t,e,r,s){if(t===i&&s===a||(n={},i=t,a=s),n[r])return n[r];var l=t.getPointAtLength(o(r-s/2,e)),c=t.getPointAtLength(o(r+s/2,e)),u=Math.atan((c.y-l.y)/(c.x-l.x)),h=t.getPointAtLength(o(r,e)),f={x:(4*h.x+l.x+c.x)/6,y:(4*h.y+l.y+c.y)/6,theta:u};return n[r]=f,f},r.clearLocationCache=function(){i=null},r.getVisibleSegment=function(t,e,r){var n,i,a=e.left,o=e.right,s=e.top,l=e.bottom,c=0,u=t.getTotalLength(),h=u;function f(e){var r=t.getPointAtLength(e);0===e?n=r:e===u&&(i=r);var c=r.x<a?a-r.x:r.x>o?r.x-o:0,h=r.y<s?s-r.y:r.y>l?r.y-l:0;return Math.sqrt(c*c+h*h)}for(var p=f(c);p;){if((c+=p+r)>h)return;p=f(c)}for(p=f(h);p;){if(c>(h-=p+r))return;p=f(h)}return{min:c,max:h,len:h-c,total:u,isClosed:0===c&&h===u&&Math.abs(n.x-i.x)<.1&&Math.abs(n.y-i.y)<.1}},r.findPointOnPath=function(t,e,r,n){for(var i,a,o,s=(n=n||{}).pathLength||t.getTotalLength(),l=n.tolerance||.001,c=n.iterationLimit||30,u=t.getPointAtLength(0)[r]>t.getPointAtLength(s)[r]?-1:1,h=0,f=0,p=s;h<c;){if(i=(f+p)/2,o=(a=t.getPointAtLength(i))[r]-e,Math.abs(o)<l)return a;u*o>0?p=i:f=i,h++}return a}},{\"./mod\":726}],716:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"color-normalize\"),o=t(\"../components/colorscale\"),s=t(\"../components/color/attributes\").defaultLine,l=t(\"./array\").isArrayOrTypedArray,c=a(s),u=1;function h(t,e){var r=t;return r[3]*=e,r}function f(t){if(n(t))return c;var e=a(t);return e.length?e:c}function p(t){return n(t)?t:u}e.exports={formatColor:function(t,e,r){var n,i,s,d,g,v=t.color,m=l(v),y=l(e),x=o.extractOpts(t),b=[];if(n=void 0!==x.colorscale?o.makeColorScaleFuncFromTrace(t):f,i=m?function(t,e){return void 0===t[e]?c:a(n(t[e]))}:f,s=y?function(t,e){return void 0===t[e]?u:p(t[e])}:p,m||y)for(var _=0;_<r;_++)d=i(v,_),g=s(e,_),b[_]=h(d,g);else b=h(a(v),e);return b},parseColorScale:function(t,e){void 0===e&&(e=1);var r=o.extractOpts(t);return(r.reversescale?o.flipScale(r.colorscale):r.colorscale).map(function(t){var r=t[0],n=i(t[1]).toRgb();return{index:r,rgb:[n.r,n.g,n.b,e]}})}}},{\"../components/color/attributes\":592,\"../components/colorscale\":605,\"./array\":702,\"color-normalize\":120,\"fast-isnumeric\":225,tinycolor2:537}],717:[function(t,e,r){\"use strict\";var n=t(\"./identity\");function i(t){return[t]}e.exports={keyFun:function(t){return t.key},repeat:i,descend:n,wrap:i,unwrap:function(t){return t[0]}}},{\"./identity\":718}],718:[function(t,e,r){\"use strict\";e.exports=function(t){return t}},{}],719:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../constants/numerical\"),o=a.FP_SAFE,s=a.BADNUM,l=e.exports={};l.nestedProperty=t(\"./nested_property\"),l.keyedContainer=t(\"./keyed_container\"),l.relativeAttr=t(\"./relative_attr\"),l.isPlainObject=t(\"./is_plain_object\"),l.toLogRange=t(\"./to_log_range\"),l.relinkPrivateKeys=t(\"./relink_private\");var c=t(\"./array\");l.isTypedArray=c.isTypedArray,l.isArrayOrTypedArray=c.isArrayOrTypedArray,l.isArray1D=c.isArray1D,l.ensureArray=c.ensureArray,l.concat=c.concat,l.maxRowLength=c.maxRowLength,l.minRowLength=c.minRowLength;var u=t(\"./mod\");l.mod=u.mod,l.modHalf=u.modHalf;var h=t(\"./coerce\");l.valObjectMeta=h.valObjectMeta,l.coerce=h.coerce,l.coerce2=h.coerce2,l.coerceFont=h.coerceFont,l.coerceHoverinfo=h.coerceHoverinfo,l.coerceSelectionMarkerOpacity=h.coerceSelectionMarkerOpacity,l.validate=h.validate;var f=t(\"./dates\");l.dateTime2ms=f.dateTime2ms,l.isDateTime=f.isDateTime,l.ms2DateTime=f.ms2DateTime,l.ms2DateTimeLocal=f.ms2DateTimeLocal,l.cleanDate=f.cleanDate,l.isJSDate=f.isJSDate,l.formatDate=f.formatDate,l.incrementMonth=f.incrementMonth,l.dateTick0=f.dateTick0,l.dfltRange=f.dfltRange,l.findExactDates=f.findExactDates,l.MIN_MS=f.MIN_MS,l.MAX_MS=f.MAX_MS;var p=t(\"./search\");l.findBin=p.findBin,l.sorterAsc=p.sorterAsc,l.sorterDes=p.sorterDes,l.distinctVals=p.distinctVals,l.roundUp=p.roundUp,l.sort=p.sort,l.findIndexOfMin=p.findIndexOfMin;var d=t(\"./stats\");l.aggNums=d.aggNums,l.len=d.len,l.mean=d.mean,l.median=d.median,l.midRange=d.midRange,l.variance=d.variance,l.stdev=d.stdev,l.interp=d.interp;var g=t(\"./matrix\");l.init2dArray=g.init2dArray,l.transposeRagged=g.transposeRagged,l.dot=g.dot,l.translationMatrix=g.translationMatrix,l.rotationMatrix=g.rotationMatrix,l.rotationXYMatrix=g.rotationXYMatrix,l.apply2DTransform=g.apply2DTransform,l.apply2DTransform2=g.apply2DTransform2;var v=t(\"./angles\");l.deg2rad=v.deg2rad,l.rad2deg=v.rad2deg,l.angleDelta=v.angleDelta,l.angleDist=v.angleDist,l.isFullCircle=v.isFullCircle,l.isAngleInsideSector=v.isAngleInsideSector,l.isPtInsideSector=v.isPtInsideSector,l.pathArc=v.pathArc,l.pathSector=v.pathSector,l.pathAnnulus=v.pathAnnulus;var m=t(\"./anchor_utils\");l.isLeftAnchor=m.isLeftAnchor,l.isCenterAnchor=m.isCenterAnchor,l.isRightAnchor=m.isRightAnchor,l.isTopAnchor=m.isTopAnchor,l.isMiddleAnchor=m.isMiddleAnchor,l.isBottomAnchor=m.isBottomAnchor;var y=t(\"./geometry2d\");l.segmentsIntersect=y.segmentsIntersect,l.segmentDistance=y.segmentDistance,l.getTextLocation=y.getTextLocation,l.clearLocationCache=y.clearLocationCache,l.getVisibleSegment=y.getVisibleSegment,l.findPointOnPath=y.findPointOnPath;var x=t(\"./extend\");l.extendFlat=x.extendFlat,l.extendDeep=x.extendDeep,l.extendDeepAll=x.extendDeepAll,l.extendDeepNoArrays=x.extendDeepNoArrays;var b=t(\"./loggers\");l.log=b.log,l.warn=b.warn,l.error=b.error;var _=t(\"./regex\");l.counterRegex=_.counter;var w=t(\"./throttle\");l.throttle=w.throttle,l.throttleDone=w.done,l.clearThrottle=w.clear;var k=t(\"./dom\");function T(t){var e={};for(var r in t)for(var n=t[r],i=0;i<n.length;i++)e[n[i]]=+r;return e}l.getGraphDiv=k.getGraphDiv,l.isPlotDiv=k.isPlotDiv,l.removeElement=k.removeElement,l.addStyleRule=k.addStyleRule,l.addRelatedStyleRule=k.addRelatedStyleRule,l.deleteRelatedStyleRule=k.deleteRelatedStyleRule,l.clearResponsive=t(\"./clear_responsive\"),l.makeTraceGroups=t(\"./make_trace_groups\"),l._=t(\"./localize\"),l.notifier=t(\"./notifier\"),l.filterUnique=t(\"./filter_unique\"),l.filterVisible=t(\"./filter_visible\"),l.pushUnique=t(\"./push_unique\"),l.cleanNumber=t(\"./clean_number\"),l.ensureNumber=function(t){return i(t)?(t=Number(t))<-o||t>o?s:i(t)?Number(t):s:s},l.isIndex=function(t,e){return!(void 0!==e&&t>=e)&&(i(t)&&t>=0&&t%1==0)},l.noop=t(\"./noop\"),l.identity=t(\"./identity\"),l.repeat=function(t,e){for(var r=new Array(e),n=0;n<e;n++)r[n]=t;return r},l.swapAttrs=function(t,e,r,n){r||(r=\"x\"),n||(n=\"y\");for(var i=0;i<e.length;i++){var a=e[i],o=l.nestedProperty(t,a.replace(\"?\",r)),s=l.nestedProperty(t,a.replace(\"?\",n)),c=o.get();o.set(s.get()),s.set(c)}},l.raiseToTop=function(t){t.parentNode.appendChild(t)},l.cancelTransition=function(t){return t.transition().duration(0)},l.constrain=function(t,e,r){return e>r?Math.max(r,Math.min(e,t)):Math.max(e,Math.min(r,t))},l.bBoxIntersect=function(t,e,r){return r=r||0,t.left<=e.right+r&&e.left<=t.right+r&&t.top<=e.bottom+r&&e.top<=t.bottom+r},l.simpleMap=function(t,e,r,n){for(var i=t.length,a=new Array(i),o=0;o<i;o++)a[o]=e(t[o],r,n);return a},l.randstr=function t(e,r,n,i){if(n||(n=16),void 0===r&&(r=24),r<=0)return\"0\";var a,o,s=Math.log(Math.pow(2,r))/Math.log(n),c=\"\";for(a=2;s===1/0;a*=2)s=Math.log(Math.pow(2,r/a))/Math.log(n)*a;var u=s-Math.floor(s);for(a=0;a<Math.floor(s);a++)c=Math.floor(Math.random()*n).toString(n)+c;u&&(o=Math.pow(n,u),c=Math.floor(Math.random()*o).toString(n)+c);var h=parseInt(c,n);return e&&e[c]||h!==1/0&&h>=Math.pow(2,r)?i>10?(l.warn(\"randstr failed uniqueness\"),c):t(e,r,n,(i||0)+1):c},l.OptionControl=function(t,e){t||(t={}),e||(e=\"opt\");var r={optionList:[],_newoption:function(n){n[e]=t,r[n.name]=n,r.optionList.push(n)}};return r[\"_\"+e]=t,r},l.smooth=function(t,e){if((e=Math.round(e)||0)<2)return t;var r,n,i,a,o=t.length,s=2*o,l=2*e-1,c=new Array(l),u=new Array(o);for(r=0;r<l;r++)c[r]=(1-Math.cos(Math.PI*(r+1)/e))/(2*e);for(r=0;r<o;r++){for(a=0,n=0;n<l;n++)(i=r+n+1-e)<-o?i-=s*Math.round(i/s):i>=s&&(i-=s*Math.floor(i/s)),i<0?i=-1-i:i>=o&&(i=s-1-i),a+=t[i]*c[n];u[r]=a}return u},l.syncOrAsync=function(t,e,r){var n;function i(){return l.syncOrAsync(t,e,r)}for(;t.length;)if((n=(0,t.splice(0,1)[0])(e))&&n.then)return n.then(i).then(void 0,l.promiseError);return r&&r(e)},l.stripTrailingSlash=function(t){return\"/\"===t.substr(-1)?t.substr(0,t.length-1):t},l.noneOrAll=function(t,e,r){if(t){var n,i=!1,a=!0;for(n=0;n<r.length;n++)null!=t[r[n]]?i=!0:a=!1;if(i&&!a)for(n=0;n<r.length;n++)t[r[n]]=e[r[n]]}},l.mergeArray=function(t,e,r,n){var i=\"function\"==typeof n;if(l.isArrayOrTypedArray(t))for(var a=Math.min(t.length,e.length),o=0;o<a;o++){var s=t[o];e[o][r]=i?n(s):s}},l.mergeArrayCastPositive=function(t,e,r){return l.mergeArray(t,e,r,function(t){var e=+t;return isFinite(e)&&e>0?e:0})},l.fillArray=function(t,e,r,n){if(n=n||l.identity,l.isArrayOrTypedArray(t))for(var i=0;i<e.length;i++)e[i][r]=n(t[i])},l.castOption=function(t,e,r,n){n=n||l.identity;var i=l.nestedProperty(t,r).get();return l.isArrayOrTypedArray(i)?Array.isArray(e)&&l.isArrayOrTypedArray(i[e[0]])?n(i[e[0]][e[1]]):n(i[e]):i},l.extractOption=function(t,e,r,n){if(r in t)return t[r];var i=l.nestedProperty(e,n).get();return Array.isArray(i)?void 0:i},l.tagSelected=function(t,e,r){var n,i,a=e.selectedpoints,o=e._indexToPoints;o&&(n=T(o));for(var s=0;s<a.length;s++){var c=a[s];if(l.isIndex(c)){var u=n?n[c]:c,h=r?r[u]:u;void 0!==(i=h)&&i<t.length&&(t[h].selected=1)}}},l.selIndices2selPoints=function(t){var e=t.selectedpoints,r=t._indexToPoints;if(r){for(var n=T(r),i=[],a=0;a<e.length;a++){var o=e[a];if(l.isIndex(o)){var s=n[o];l.isIndex(s)&&i.push(s)}}return i}return e},l.getTargetArray=function(t,e){var r=e.target;if(\"string\"==typeof r&&r){var n=l.nestedProperty(t,r).get();return!!Array.isArray(n)&&n}return!!Array.isArray(r)&&r},l.minExtend=function(t,e){var r={};\"object\"!=typeof e&&(e={});var n,i,a,o=Object.keys(t);for(n=0;n<o.length;n++)a=t[i=o[n]],\"_\"!==i.charAt(0)&&\"function\"!=typeof a&&(\"module\"===i?r[i]=a:Array.isArray(a)?r[i]=\"colorscale\"===i?a.slice():a.slice(0,3):r[i]=a&&\"object\"==typeof a?l.minExtend(t[i],e[i]):a);for(o=Object.keys(e),n=0;n<o.length;n++)\"object\"==typeof(a=e[i=o[n]])&&i in r&&\"object\"==typeof r[i]||(r[i]=a);return r},l.titleCase=function(t){return t.charAt(0).toUpperCase()+t.substr(1)},l.containsAny=function(t,e){for(var r=0;r<e.length;r++)if(-1!==t.indexOf(e[r]))return!0;return!1},l.isIE=function(){return\"undefined\"!=typeof window.navigator.msSaveBlob};var A=/MSIE [1-9]\\./;l.isIE9orBelow=function(){return l.isIE()&&A.test(window.navigator.userAgent)};var M=/Version\\/[\\d\\.]+.*Safari/;l.isSafari=function(){return M.test(window.navigator.userAgent)},l.isD3Selection=function(t){return t&&\"function\"==typeof t.classed},l.ensureSingle=function(t,e,r,n){var i=t.select(e+(r?\".\"+r:\"\"));if(i.size())return i;var a=t.append(e);return r&&a.classed(r,!0),n&&a.call(n),a},l.ensureSingleById=function(t,e,r,n){var i=t.select(e+\"#\"+r);if(i.size())return i;var a=t.append(e).attr(\"id\",r);return n&&a.call(n),a},l.objectFromPath=function(t,e){for(var r,n=t.split(\".\"),i=r={},a=0;a<n.length;a++){var o=n[a],s=null,l=n[a].match(/(.*)\\[([0-9]+)\\]/);l?(o=l[1],s=l[2],r=r[o]=[],a===n.length-1?r[s]=e:r[s]={},r=r[s]):(a===n.length-1?r[o]=e:r[o]={},r=r[o])}return i};var S=/^([^\\[\\.]+)\\.(.+)?/,E=/^([^\\.]+)\\[([0-9]+)\\](\\.)?(.+)?/;l.expandObjectPaths=function(t){var e,r,n,i,a,o,s;if(\"object\"==typeof t&&!Array.isArray(t))for(r in t)t.hasOwnProperty(r)&&((e=r.match(S))?(i=t[r],n=e[1],delete t[r],t[n]=l.extendDeepNoArrays(t[n]||{},l.objectFromPath(r,l.expandObjectPaths(i))[n])):(e=r.match(E))?(i=t[r],n=e[1],a=parseInt(e[2]),delete t[r],t[n]=t[n]||[],\".\"===e[3]?(s=e[4],o=t[n][a]=t[n][a]||{},l.extendDeepNoArrays(o,l.objectFromPath(s,l.expandObjectPaths(i)))):t[n][a]=l.expandObjectPaths(i)):t[r]=l.expandObjectPaths(t[r]));return t},l.numSeparate=function(t,e,r){if(r||(r=!1),\"string\"!=typeof e||0===e.length)throw new Error(\"Separator string required for formatting!\");\"number\"==typeof t&&(t=String(t));var n=/(\\d+)(\\d{3})/,i=e.charAt(0),a=e.charAt(1),o=t.split(\".\"),s=o[0],l=o.length>1?i+o[1]:\"\";if(a&&(o.length>1||s.length>4||r))for(;n.test(s);)s=s.replace(n,\"$1\"+a+\"$2\");return s+l},l.TEMPLATE_STRING_REGEX=/%{([^\\s%{}:]*)(:[^}]*)?}/g;var C=/^\\w*$/;l.templateString=function(t,e){var r={};return t.replace(l.TEMPLATE_STRING_REGEX,function(t,n){return C.test(n)?e[n]||\"\":(r[n]=r[n]||l.nestedProperty(e,n).get,r[n]()||\"\")})};var L=/^:/,P=0;l.hovertemplateString=function(t,e,r){var i=arguments,a={};return t.replace(l.TEMPLATE_STRING_REGEX,function(t,o,s){var c,u,h;for(h=3;h<i.length;h++){if((c=i[h]).hasOwnProperty(o)){u=c[o];break}if(C.test(o)||(u=a[o]||l.nestedProperty(c,o).get())&&(a[o]=u),void 0!==u)break}(void 0===u&&(P<10&&(l.warn(\"Variable '\"+o+\"' in hovertemplate could not be found!\"),u=t),10===P&&l.warn(\"Too many hovertemplate warnings - additional warnings will be suppressed\"),P++),s)?u=(r?r.numberFormat:n.format)(s.replace(L,\"\"))(u):e.hasOwnProperty(o+\"Label\")&&(u=e[o+\"Label\"]);return u})};l.subplotSort=function(t,e){for(var r=Math.min(t.length,e.length)+1,n=0,i=0,a=0;a<r;a++){var o=t.charCodeAt(a)||0,s=e.charCodeAt(a)||0,l=o>=48&&o<=57,c=s>=48&&s<=57;if(l&&(n=10*n+o-48),c&&(i=10*i+s-48),!l||!c){if(n!==i)return n-i;if(o!==s)return o-s}}return i-n};var O=2e9;l.seedPseudoRandom=function(){O=2e9},l.pseudoRandom=function(){var t=O;return O=(69069*O+1)%4294967296,Math.abs(O-t)<429496729?l.pseudoRandom():O/4294967296},l.fillText=function(t,e,r){var n=Array.isArray(r)?function(t){r.push(t)}:function(t){r.text=t},i=l.extractOption(t,e,\"htx\",\"hovertext\");if(l.isValidTextValue(i))return n(i);var a=l.extractOption(t,e,\"tx\",\"text\");return l.isValidTextValue(a)?n(a):void 0},l.isValidTextValue=function(t){return t||0===t},l.formatPercent=function(t,e){e=e||0;for(var r=(Math.round(100*t*Math.pow(10,e))*Math.pow(.1,e)).toFixed(e)+\"%\",n=0;n<e;n++)-1!==r.indexOf(\".\")&&(r=(r=r.replace(\"0%\",\"%\")).replace(\".%\",\"%\"));return r},l.isHidden=function(t){var e=window.getComputedStyle(t).display;return!e||\"none\"===e}},{\"../constants/numerical\":695,\"./anchor_utils\":700,\"./angles\":701,\"./array\":702,\"./clean_number\":703,\"./clear_responsive\":705,\"./coerce\":706,\"./dates\":707,\"./dom\":708,\"./extend\":710,\"./filter_unique\":711,\"./filter_visible\":712,\"./geometry2d\":715,\"./identity\":718,\"./is_plain_object\":720,\"./keyed_container\":721,\"./localize\":722,\"./loggers\":723,\"./make_trace_groups\":724,\"./matrix\":725,\"./mod\":726,\"./nested_property\":727,\"./noop\":728,\"./notifier\":729,\"./push_unique\":733,\"./regex\":735,\"./relative_attr\":736,\"./relink_private\":737,\"./search\":738,\"./stats\":741,\"./throttle\":744,\"./to_log_range\":745,d3:163,\"fast-isnumeric\":225}],720:[function(t,e,r){\"use strict\";e.exports=function(t){return window&&window.process&&window.process.versions?\"[object Object]\"===Object.prototype.toString.call(t):\"[object Object]\"===Object.prototype.toString.call(t)&&Object.getPrototypeOf(t)===Object.prototype}},{}],721:[function(t,e,r){\"use strict\";var n=t(\"./nested_property\"),i=/^\\w*$/;e.exports=function(t,e,r,a){var o,s,l;r=r||\"name\",a=a||\"value\";var c={};e&&e.length?(l=n(t,e),s=l.get()):s=t,e=e||\"\";var u={};if(s)for(o=0;o<s.length;o++)u[s[o][r]]=o;var h=i.test(a),f={set:function(t,e){var i=null===e?4:0;if(!s){if(!l||4===i)return;s=[],l.set(s)}var o=u[t];if(void 0===o){if(4===i)return;i|=3,o=s.length,u[t]=o}else e!==(h?s[o][a]:n(s[o],a).get())&&(i|=2);var p=s[o]=s[o]||{};return p[r]=t,h?p[a]=e:n(p,a).set(e),null!==e&&(i&=-5),c[o]=c[o]|i,f},get:function(t){if(s){var e=u[t];return void 0===e?void 0:h?s[e][a]:n(s[e],a).get()}},rename:function(t,e){var n=u[t];return void 0===n?f:(c[n]=1|c[n],u[e]=n,delete u[t],s[n][r]=e,f)},remove:function(t){var e=u[t];if(void 0===e)return f;var i=s[e];if(Object.keys(i).length>2)return c[e]=2|c[e],f.set(t,null);if(h){for(o=e;o<s.length;o++)c[o]=3|c[o];for(o=e;o<s.length;o++)u[s[o][r]]--;s.splice(e,1),delete u[t]}else n(i,a).set(null),c[e]=6|c[e];return f},constructUpdate:function(){for(var t,i,o={},l=Object.keys(c),u=0;u<l.length;u++)i=l[u],t=e+\"[\"+i+\"]\",s[i]?(1&c[i]&&(o[t+\".\"+r]=s[i][r]),2&c[i]&&(o[t+\".\"+a]=h?4&c[i]?null:s[i][a]:4&c[i]?null:n(s[i],a).get())):o[t]=null;return o}};return f}},{\"./nested_property\":727}],722:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t,e){for(var r=t._context.locale,i=0;i<2;i++){for(var a=t._context.locales,o=0;o<2;o++){var s=(a[r]||{}).dictionary;if(s){var l=s[e];if(l)return l}a=n.localeRegistry}var c=r.split(\"-\")[0];if(c===r)break;r=c}return e}},{\"../registry\":847}],723:[function(t,e,r){\"use strict\";var n=t(\"../plot_api/plot_config\").dfltConfig,i=e.exports={};function a(t,e){if(t&&t.apply)try{return void t.apply(console,e)}catch(t){}for(var r=0;r<e.length;r++)try{t(e[r])}catch(t){console.log(e[r])}}i.log=function(){if(n.logging>1){for(var t=[\"LOG:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.trace||console.log,t)}},i.warn=function(){if(n.logging>0){for(var t=[\"WARN:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.trace||console.log,t)}},i.error=function(){if(n.logging>0){for(var t=[\"ERROR:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.error,t)}}},{\"../plot_api/plot_config\":755}],724:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e,r){var i=t.selectAll(\"g.\"+r.replace(/\\s/g,\".\")).data(e,function(t){return t[0].trace.uid});i.exit().remove(),i.enter().append(\"g\").attr(\"class\",r),i.order();var a=t.classed(\"rangeplot\")?\"nodeRangePlot3\":\"node3\";return i.each(function(t){t[0][a]=n.select(this)}),i}},{d3:163}],725:[function(t,e,r){\"use strict\";r.init2dArray=function(t,e){for(var r=new Array(t),n=0;n<t;n++)r[n]=new Array(e);return r},r.transposeRagged=function(t){var e,r,n=0,i=t.length;for(e=0;e<i;e++)n=Math.max(n,t[e].length);var a=new Array(n);for(e=0;e<n;e++)for(a[e]=new Array(i),r=0;r<i;r++)a[e][r]=t[r][e];return a},r.dot=function(t,e){if(!t.length||!e.length||t.length!==e.length)return null;var n,i,a=t.length;if(t[0].length)for(n=new Array(a),i=0;i<a;i++)n[i]=r.dot(t[i],e);else if(e[0].length){var o=r.transposeRagged(e);for(n=new Array(o.length),i=0;i<o.length;i++)n[i]=r.dot(t,o[i])}else for(n=0,i=0;i<a;i++)n+=t[i]*e[i];return n},r.translationMatrix=function(t,e){return[[1,0,t],[0,1,e],[0,0,1]]},r.rotationMatrix=function(t){var e=t*Math.PI/180;return[[Math.cos(e),-Math.sin(e),0],[Math.sin(e),Math.cos(e),0],[0,0,1]]},r.rotationXYMatrix=function(t,e,n){return r.dot(r.dot(r.translationMatrix(e,n),r.rotationMatrix(t)),r.translationMatrix(-e,-n))},r.apply2DTransform=function(t){return function(){var e=arguments;3===e.length&&(e=e[0]);var n=1===arguments.length?e[0]:[e[0],e[1]];return r.dot(t,[n[0],n[1],1]).slice(0,2)}},r.apply2DTransform2=function(t){var e=r.apply2DTransform(t);return function(t){return e(t.slice(0,2)).concat(e(t.slice(2,4)))}}},{}],726:[function(t,e,r){\"use strict\";e.exports={mod:function(t,e){var r=t%e;return r<0?r+e:r},modHalf:function(t,e){return Math.abs(t)>e/2?t-Math.round(t/e)*e:t}}},{}],727:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;e.exports=function(t,e){if(n(e))e=String(e);else if(\"string\"!=typeof e||\"[-1]\"===e.substr(e.length-4))throw\"bad property string\";for(var r,a,o,l=0,c=e.split(\".\");l<c.length;){if(r=String(c[l]).match(/^([^\\[\\]]*)((\\[\\-?[0-9]*\\])+)$/)){if(r[1])c[l]=r[1];else{if(0!==l)throw\"bad property string\";c.splice(0,1)}for(a=r[2].substr(1,r[2].length-2).split(\"][\"),o=0;o<a.length;o++)l++,c.splice(l,0,Number(a[o]))}l++}return\"object\"!=typeof t?function(t,e,r){return{set:function(){throw\"bad container\"},get:function(){},astr:e,parts:r,obj:t}}(t,e,c):{set:s(t,c,e),get:function t(e,r){return function(){var n,a,o,s,l,c=e;for(s=0;s<r.length-1;s++){if(-1===(n=r[s])){for(a=!0,o=[],l=0;l<c.length;l++)o[l]=t(c[l],r.slice(s+1))(),o[l]!==o[0]&&(a=!1);return a?o[0]:o}if(\"number\"==typeof n&&!i(c))return;if(\"object\"!=typeof(c=c[n])||null===c)return}if(\"object\"==typeof c&&null!==c&&null!==(o=c[r[s]]))return o}}(t,c),astr:e,parts:c,obj:t}};var a=/(^|\\.)args\\[/;function o(t,e){return void 0===t||null===t&&!e.match(a)}function s(t,e,r){return function(n){var a,s,h=t,f=\"\",p=[[t,f]],d=o(n,r);for(s=0;s<e.length-1;s++){if(\"number\"==typeof(a=e[s])&&!i(h))throw\"array index but container is not an array\";if(-1===a){if(d=!c(h,e.slice(s+1),n,r))break;return}if(!u(h,a,e[s+1],d))break;if(\"object\"!=typeof(h=h[a])||null===h)throw\"container is not an object\";f=l(f,a),p.push([h,f])}if(d){if(s===e.length-1&&(delete h[e[s]],Array.isArray(h)&&+e[s]==h.length-1))for(;h.length&&void 0===h[h.length-1];)h.pop()}else h[e[s]]=n}}function l(t,e){var r=e;return n(e)?r=\"[\"+e+\"]\":t&&(r=\".\"+e),t+r}function c(t,e,r,n){var a,l=i(r),c=!0,h=r,f=n.replace(\"-1\",0),p=!l&&o(r,f),d=e[0];for(a=0;a<t.length;a++)f=n.replace(\"-1\",a),l&&(p=o(h=r[a%r.length],f)),p&&(c=!1),u(t,a,d,p)&&s(t[a],e,n.replace(\"-1\",a))(h);return c}function u(t,e,r,n){if(void 0===t[e]){if(n)return!1;t[e]=\"number\"==typeof r?[]:{}}return!0}},{\"./array\":702,\"fast-isnumeric\":225}],728:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],729:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=[];e.exports=function(t,e){if(-1===a.indexOf(t)){a.push(t);var r=1e3;i(e)?r=e:\"long\"===e&&(r=3e3);var o=n.select(\"body\").selectAll(\".plotly-notifier\").data([0]);o.enter().append(\"div\").classed(\"plotly-notifier\",!0),o.selectAll(\".notifier-note\").data(a).enter().append(\"div\").classed(\"notifier-note\",!0).style(\"opacity\",0).each(function(t){var e=n.select(this);e.append(\"button\").classed(\"notifier-close\",!0).html(\"&times;\").on(\"click\",function(){e.transition().call(s)});for(var i=e.append(\"p\"),a=t.split(/<br\\s*\\/?>/g),o=0;o<a.length;o++)o&&i.append(\"br\"),i.append(\"span\").text(a[o]);e.transition().duration(700).style(\"opacity\",1).transition().delay(r).call(s)})}function s(t){t.duration(700).style(\"opacity\",0).each(\"end\",function(t){var e=a.indexOf(t);-1!==e&&a.splice(e,1),n.select(this).remove()})}}},{d3:163,\"fast-isnumeric\":225}],730:[function(t,e,r){\"use strict\";var n=t(\"./setcursor\"),i=\"data-savedcursor\";e.exports=function(t,e){var r=t.attr(i);if(e){if(!r){for(var a=(t.attr(\"class\")||\"\").split(\" \"),o=0;o<a.length;o++){var s=a[o];0===s.indexOf(\"cursor-\")&&t.attr(i,s.substr(7)).classed(s,!1)}t.attr(i)||t.attr(i,\"!!\")}n(t,e)}else r&&(t.attr(i,null),\"!!\"===r?n(t):n(t,r))}},{\"./setcursor\":739}],731:[function(t,e,r){\"use strict\";var n=t(\"./matrix\").dot,i=t(\"../constants/numerical\").BADNUM,a=e.exports={};a.tester=function(t){var e,r=t.slice(),n=r[0][0],a=n,o=r[0][1],s=o;for(r.push(r[0]),e=1;e<r.length;e++)n=Math.min(n,r[e][0]),a=Math.max(a,r[e][0]),o=Math.min(o,r[e][1]),s=Math.max(s,r[e][1]);var l,c=!1;5===r.length&&(r[0][0]===r[1][0]?r[2][0]===r[3][0]&&r[0][1]===r[3][1]&&r[1][1]===r[2][1]&&(c=!0,l=function(t){return t[0]===r[0][0]}):r[0][1]===r[1][1]&&r[2][1]===r[3][1]&&r[0][0]===r[3][0]&&r[1][0]===r[2][0]&&(c=!0,l=function(t){return t[1]===r[0][1]}));var u=!0,h=r[0];for(e=1;e<r.length;e++)if(h[0]!==r[e][0]||h[1]!==r[e][1]){u=!1;break}return{xmin:n,xmax:a,ymin:o,ymax:s,pts:r,contains:c?function(t,e){var r=t[0],c=t[1];return!(r===i||r<n||r>a||c===i||c<o||c>s||e&&l(t))}:function(t,e){var l=t[0],c=t[1];if(l===i||l<n||l>a||c===i||c<o||c>s)return!1;var u,h,f,p,d,g=r.length,v=r[0][0],m=r[0][1],y=0;for(u=1;u<g;u++)if(h=v,f=m,v=r[u][0],m=r[u][1],!(l<(p=Math.min(h,v))||l>Math.max(h,v)||c>Math.max(f,m)))if(c<Math.min(f,m))l!==p&&y++;else{if(c===(d=v===h?c:f+(l-h)*(m-f)/(v-h)))return 1!==u||!e;c<=d&&l!==p&&y++}return y%2==1},isRect:c,degenerate:u}},a.isSegmentBent=function(t,e,r,i){var a,o,s,l=t[e],c=[t[r][0]-l[0],t[r][1]-l[1]],u=n(c,c),h=Math.sqrt(u),f=[-c[1]/h,c[0]/h];for(a=e+1;a<r;a++)if(o=[t[a][0]-l[0],t[a][1]-l[1]],(s=n(o,c))<0||s>u||Math.abs(n(o,f))>i)return!0;return!1},a.filter=function(t,e){var r=[t[0]],n=0,i=0;function o(o){t.push(o);var s=r.length,l=n;r.splice(i+1);for(var c=l+1;c<t.length;c++)(c===t.length-1||a.isSegmentBent(t,l,c+1,e))&&(r.push(t[c]),r.length<s-2&&(n=c,i=r.length-1),l=c)}t.length>1&&o(t.pop());return{addPt:o,raw:t,filtered:r}}},{\"../constants/numerical\":695,\"./matrix\":725}],732:[function(t,e,r){(function(r){\"use strict\";var n=t(\"./show_no_webgl_msg\"),i=t(\"regl\");e.exports=function(t,e){var a=t._fullLayout,o=!0;return a._glcanvas.each(function(n){if(!n.regl&&(!n.pick||a._has(\"parcoords\"))){try{n.regl=i({canvas:this,attributes:{antialias:!n.pick,preserveDrawingBuffer:!0},pixelRatio:t._context.plotGlPixelRatio||r.devicePixelRatio,extensions:e||[]})}catch(t){o=!1}o&&this.addEventListener(\"webglcontextlost\",function(e){t&&t.emit&&t.emit(\"plotly_webglcontextlost\",{event:e,layer:n.key})},!1)}}),o||n({container:a._glcontainer.node()}),o}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./show_no_webgl_msg\":740,regl:502}],733:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(e instanceof RegExp){for(var r=e.toString(),n=0;n<t.length;n++)if(t[n]instanceof RegExp&&t[n].toString()===r)return t;t.push(e)}else!e&&0!==e||-1!==t.indexOf(e)||t.push(e);return t}},{}],734:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_config\").dfltConfig;var a={add:function(t,e,r,n,a){var o,s;t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},s=t.undoQueue.index,t.autoplay?t.undoQueue.inSequence||(t.autoplay=!1):(!t.undoQueue.sequence||t.undoQueue.beginSequence?(o={undo:{calls:[],args:[]},redo:{calls:[],args:[]}},t.undoQueue.queue.splice(s,t.undoQueue.queue.length-s,o),t.undoQueue.index+=1):o=t.undoQueue.queue[s-1],t.undoQueue.beginSequence=!1,o&&(o.undo.calls.unshift(e),o.undo.args.unshift(r),o.redo.calls.push(n),o.redo.args.push(a)),t.undoQueue.queue.length>i.queueLength&&(t.undoQueue.queue.shift(),t.undoQueue.index--))},startSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!0,t.undoQueue.beginSequence=!0},stopSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!1,t.undoQueue.beginSequence=!1},undo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.undo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index<=0)){for(t.undoQueue.index--,e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.undo.calls.length;r++)a.plotDo(t,e.undo.calls[r],e.undo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1}},redo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.redo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index>=t.undoQueue.queue.length)){for(e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.redo.calls.length;r++)a.plotDo(t,e.redo.calls[r],e.redo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1,t.undoQueue.index++}}};a.plotDo=function(t,e,r){t.autoplay=!0,r=function(t,e){for(var r,i=[],a=0;a<e.length;a++)r=e[a],i[a]=r===t?r:\"object\"==typeof r?Array.isArray(r)?n.extendDeep([],r):n.extendDeepAll({},r):r;return i}(t,r),e.apply(null,r)},e.exports=a},{\"../lib\":719,\"../plot_api/plot_config\":755}],735:[function(t,e,r){\"use strict\";r.counter=function(t,e,r,n){var i=(e||\"\")+(r?\"\":\"$\"),a=!1===n?\"\":\"^\";return\"xy\"===t?new RegExp(a+\"x([2-9]|[1-9][0-9]+)?y([2-9]|[1-9][0-9]+)?\"+i):new RegExp(a+t+\"([2-9]|[1-9][0-9]+)?\"+i)}},{}],736:[function(t,e,r){\"use strict\";var n=/^(.*)(\\.[^\\.\\[\\]]+|\\[\\d\\])$/,i=/^[^\\.\\[\\]]+$/;e.exports=function(t,e){for(;e;){var r=t.match(n);if(r)t=r[1];else{if(!t.match(i))throw new Error(\"bad relativeAttr call:\"+[t,e]);t=\"\"}if(\"^\"!==e.charAt(0))break;e=e.slice(1)}return t&&\"[\"!==e.charAt(0)?t+\".\"+e:t+e}},{}],737:[function(t,e,r){\"use strict\";var n=t(\"./array\").isArrayOrTypedArray,i=t(\"./is_plain_object\");e.exports=function t(e,r){for(var a in r){var o=r[a],s=e[a];if(s!==o)if(\"_\"===a.charAt(0)||\"function\"==typeof o){if(a in e)continue;e[a]=o}else if(n(o)&&n(s)&&i(o[0])){if(\"customdata\"===a||\"ids\"===a)continue;for(var l=Math.min(o.length,s.length),c=0;c<l;c++)s[c]!==o[c]&&i(o[c])&&i(s[c])&&t(s[c],o[c])}else i(o)&&i(s)&&(t(s,o),Object.keys(s).length||delete e[a])}}},{\"./array\":702,\"./is_plain_object\":720}],738:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./loggers\"),a=t(\"./identity\");function o(t,e){return t<e}function s(t,e){return t<=e}function l(t,e){return t>e}function c(t,e){return t>=e}r.findBin=function(t,e,r){if(n(e.start))return r?Math.ceil((t-e.start)/e.size-1e-9)-1:Math.floor((t-e.start)/e.size+1e-9);var a,u,h=0,f=e.length,p=0,d=f>1?(e[f-1]-e[0])/(f-1):1;for(u=d>=0?r?o:s:r?c:l,t+=1e-9*d*(r?-1:1)*(d>=0?1:-1);h<f&&p++<100;)u(e[a=Math.floor((h+f)/2)],t)?h=a+1:f=a;return p>90&&i.log(\"Long binary search...\"),h-1},r.sorterAsc=function(t,e){return t-e},r.sorterDes=function(t,e){return e-t},r.distinctVals=function(t){var e=t.slice();e.sort(r.sorterAsc);for(var n=e.length-1,i=e[n]-e[0]||1,a=i/(n||1)/1e4,o=[e[0]],s=0;s<n;s++)e[s+1]>e[s]+a&&(i=Math.min(i,e[s+1]-e[s]),o.push(e[s+1]));return{vals:o,minDiff:i}},r.roundUp=function(t,e,r){for(var n,i=0,a=e.length-1,o=0,s=r?0:1,l=r?1:0,c=r?Math.ceil:Math.floor;i<a&&o++<100;)e[n=c((i+a)/2)]<=t?i=n+s:a=n-l;return e[i]},r.sort=function(t,e){for(var r=0,n=0,i=1;i<t.length;i++){var a=e(t[i],t[i-1]);if(a<0?r=1:a>0&&(n=1),r&&n)return t.sort(e)}return n?t:t.reverse()},r.findIndexOfMin=function(t,e){e=e||a;for(var r,n=1/0,i=0;i<t.length;i++){var o=e(t[i]);o<n&&(n=o,r=i)}return r}},{\"./identity\":718,\"./loggers\":723,\"fast-isnumeric\":225}],739:[function(t,e,r){\"use strict\";e.exports=function(t,e){(t.attr(\"class\")||\"\").split(\" \").forEach(function(e){0===e.indexOf(\"cursor-\")&&t.classed(e,!1)}),e&&t.classed(\"cursor-\"+e,!0)}},{}],740:[function(t,e,r){\"use strict\";var n=t(\"../components/color\"),i=function(){};e.exports=function(t){for(var e in t)\"function\"==typeof t[e]&&(t[e]=i);t.destroy=function(){t.container.parentNode.removeChild(t.container)};var r=document.createElement(\"div\");r.className=\"no-webgl\",r.style.cursor=\"pointer\",r.style.fontSize=\"24px\",r.style.color=n.defaults[0],r.style.position=\"absolute\",r.style.left=r.style.top=\"0px\",r.style.width=r.style.height=\"100%\",r.style[\"background-color\"]=n.lightLine,r.style[\"z-index\"]=30;var a=document.createElement(\"p\");return a.textContent=\"WebGL is not supported by your browser - visit https://get.webgl.org for more info\",a.style.position=\"relative\",a.style.top=\"50%\",a.style.left=\"50%\",a.style.height=\"30%\",a.style.width=\"50%\",a.style.margin=\"-15% 0 0 -25%\",r.appendChild(a),t.container.appendChild(r),t.container.style.background=\"#FFFFFF\",t.container.onclick=function(){window.open(\"https://get.webgl.org\")},!1}},{\"../components/color\":593}],741:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;r.aggNums=function(t,e,a,o){var s,l;if((!o||o>a.length)&&(o=a.length),n(e)||(e=!1),i(a[0])){for(l=new Array(o),s=0;s<o;s++)l[s]=r.aggNums(t,e,a[s]);a=l}for(s=0;s<o;s++)n(e)?n(a[s])&&(e=t(+e,+a[s])):e=a[s];return e},r.len=function(t){return r.aggNums(function(t){return t+1},0,t)},r.mean=function(t,e){return e||(e=r.len(t)),r.aggNums(function(t,e){return t+e},0,t)/e},r.midRange=function(t){if(void 0!==t&&0!==t.length)return(r.aggNums(Math.max,null,t)+r.aggNums(Math.min,null,t))/2},r.variance=function(t,e,i){return e||(e=r.len(t)),n(i)||(i=r.mean(t,e)),r.aggNums(function(t,e){return t+Math.pow(e-i,2)},0,t)/e},r.stdev=function(t,e,n){return Math.sqrt(r.variance(t,e,n))},r.median=function(t){var e=t.slice().sort();return r.interp(e,.5)},r.interp=function(t,e){if(!n(e))throw\"n should be a finite number\";if((e=e*t.length-.5)<0)return t[0];if(e>t.length-1)return t[t.length-1];var r=e%1;return r*t[Math.ceil(e)]+(1-r)*t[Math.floor(e)]}},{\"./array\":702,\"fast-isnumeric\":225}],742:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\");e.exports=function(t){return t?n(t):[0,0,0,1]}},{\"color-normalize\":120}],743:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=t(\"../constants/xmlns_namespaces\"),o=t(\"../constants/alignment\").LINE_SPACING;function s(t,e){return t.node().getBoundingClientRect()[e]}var l=/([^$]*)([$]+[^$]*[$]+)([^$]*)/;r.convertToTspans=function(t,e,M){var S=t.text(),C=!t.attr(\"data-notex\")&&\"undefined\"!=typeof MathJax&&S.match(l),L=n.select(t.node().parentNode);if(!L.empty()){var P=t.attr(\"class\")?t.attr(\"class\").split(\" \")[0]:\"text\";return P+=\"-math\",L.selectAll(\"svg.\"+P).remove(),L.selectAll(\"g.\"+P+\"-group\").remove(),t.style(\"display\",null).attr({\"data-unformatted\":S,\"data-math\":\"N\"}),C?(e&&e._promises||[]).push(new Promise(function(e){t.style(\"display\",\"none\");var r=parseInt(t.node().style.fontSize,10),a={fontSize:r};!function(t,e,r){var a,o,s,l;MathJax.Hub.Queue(function(){return o=i.extendDeepAll({},MathJax.Hub.config),s=MathJax.Hub.processSectionDelay,void 0!==MathJax.Hub.processSectionDelay&&(MathJax.Hub.processSectionDelay=0),MathJax.Hub.Config({messageStyle:\"none\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]},displayAlign:\"left\"})},function(){if(\"SVG\"!==(a=MathJax.Hub.config.menuSettings.renderer))return MathJax.Hub.setRenderer(\"SVG\")},function(){var r=\"math-output-\"+i.randstr({},64);return l=n.select(\"body\").append(\"div\").attr({id:r}).style({visibility:\"hidden\",position:\"absolute\"}).style({\"font-size\":e.fontSize+\"px\"}).text(t.replace(c,\"\\\\lt \").replace(u,\"\\\\gt \")),MathJax.Hub.Typeset(l.node())},function(){var e=n.select(\"body\").select(\"#MathJax_SVG_glyphs\");if(l.select(\".MathJax_SVG\").empty()||!l.select(\"svg\").node())i.log(\"There was an error in the tex syntax.\",t),r();else{var o=l.select(\"svg\").node().getBoundingClientRect();r(l.select(\".MathJax_SVG\"),e,o)}if(l.remove(),\"SVG\"!==a)return MathJax.Hub.setRenderer(a)},function(){return void 0!==s&&(MathJax.Hub.processSectionDelay=s),MathJax.Hub.Config(o)})}(C[2],a,function(n,i,a){L.selectAll(\"svg.\"+P).remove(),L.selectAll(\"g.\"+P+\"-group\").remove();var o=n&&n.select(\"svg\");if(!o||!o.node())return O(),void e();var l=L.append(\"g\").classed(P+\"-group\",!0).attr({\"pointer-events\":\"none\",\"data-unformatted\":S,\"data-math\":\"Y\"});l.node().appendChild(o.node()),i&&i.node()&&o.node().insertBefore(i.node().cloneNode(!0),o.node().firstChild),o.attr({class:P,height:a.height,preserveAspectRatio:\"xMinYMin meet\"}).style({overflow:\"visible\",\"pointer-events\":\"none\"});var c=t.node().style.fill||\"black\",u=o.select(\"g\");u.attr({fill:c,stroke:c});var h=s(u,\"width\"),f=s(u,\"height\"),p=+t.attr(\"x\")-h*{start:0,middle:.5,end:1}[t.attr(\"text-anchor\")||\"start\"],d=-(r||s(t,\"height\"))/4;\"y\"===P[0]?(l.attr({transform:\"rotate(\"+[-90,+t.attr(\"x\"),+t.attr(\"y\")]+\") translate(\"+[-h/2,d-f/2]+\")\"}),o.attr({x:+t.attr(\"x\"),y:+t.attr(\"y\")})):\"l\"===P[0]?o.attr({x:t.attr(\"x\"),y:d-f/2}):\"a\"===P[0]&&0!==P.indexOf(\"atitle\")?o.attr({x:0,y:d}):o.attr({x:p,y:+t.attr(\"y\")+d-f/2}),M&&M.call(t,l),e(l)})})):O(),t}function O(){L.empty()||(P=t.attr(\"class\")+\"-math\",L.select(\"svg.\"+P).remove()),t.text(\"\").style(\"white-space\",\"pre\"),function(t,e){e=e.replace(v,\" \");var r,s=!1,l=[],c=-1;function u(){c++;var e=document.createElementNS(a.svg,\"tspan\");n.select(e).attr({class:\"line\",dy:c*o+\"em\"}),t.appendChild(e),r=e;var i=l;if(l=[{node:e}],i.length>1)for(var s=1;s<i.length;s++)M(i[s])}function M(t){var e,i=t.type,o={};if(\"a\"===i){e=\"a\";var s=t.target,c=t.href,u=t.popup;c&&(o={\"xlink:xlink:show\":\"_blank\"===s||\"_\"!==s.charAt(0)?\"new\":\"replace\",target:s,\"xlink:xlink:href\":c},u&&(o.onclick='window.open(this.href.baseVal,this.target.baseVal,\"'+u+'\");return false;'))}else e=\"tspan\";t.style&&(o.style=t.style);var h=document.createElementNS(a.svg,e);if(\"sup\"===i||\"sub\"===i){S(r,d),r.appendChild(h);var g=document.createElementNS(a.svg,\"tspan\");S(g,d),n.select(g).attr(\"dy\",p[i]),o.dy=f[i],r.appendChild(h),r.appendChild(g)}else r.appendChild(h);n.select(h).attr(o),r=t.node=h,l.push(t)}function S(t,e){t.appendChild(document.createTextNode(e))}function C(t){if(1!==l.length){var n=l.pop();t!==n.type&&i.log(\"Start tag <\"+n.type+\"> doesnt match end tag <\"+t+\">. Pretending it did match.\",e),r=l[l.length-1].node}else i.log(\"Ignoring unexpected end tag </\"+t+\">.\",e)}x.test(e)?u():(r=t,l=[{node:t}]);for(var L=e.split(m),P=0;P<L.length;P++){var O=L[P],z=O.match(y),I=z&&z[2].toLowerCase(),D=h[I];if(\"br\"===I)u();else if(void 0===D)S(r,E(O));else if(z[1])C(I);else{var R=z[4],F={type:I},B=T(R,b);if(B?(B=B.replace(A,\"$1 fill:\"),D&&(B+=\";\"+D)):D&&(B=D),B&&(F.style=B),\"a\"===I){s=!0;var N=T(R,_);if(N){var j=document.createElement(\"a\");j.href=N,-1!==g.indexOf(j.protocol)&&(F.href=encodeURI(decodeURI(N)),F.target=T(R,w)||\"_blank\",F.popup=T(R,k))}}M(F)}}return s}(t.node(),S)&&t.style(\"pointer-events\",\"all\"),r.positionText(t),M&&M.call(t)}};var c=/(<|&lt;|&#60;)/g,u=/(>|&gt;|&#62;)/g;var h={sup:\"font-size:70%\",sub:\"font-size:70%\",b:\"font-weight:bold\",i:\"font-style:italic\",a:\"cursor:pointer\",span:\"\",em:\"font-style:italic;font-weight:bold\"},f={sub:\"0.3em\",sup:\"-0.6em\"},p={sub:\"-0.21em\",sup:\"0.42em\"},d=\"\\u200b\",g=[\"http:\",\"https:\",\"mailto:\",\"\",void 0,\":\"],v=/(\\r\\n?|\\n)/g,m=/(<[^<>]*>)/,y=/<(\\/?)([^ >]*)(\\s+(.*))?>/i,x=/<br(\\s+.*)?>/i,b=/(^|[\\s\"'])style\\s*=\\s*(\"([^\"]*);?\"|'([^']*);?')/i,_=/(^|[\\s\"'])href\\s*=\\s*(\"([^\"]*)\"|'([^']*)')/i,w=/(^|[\\s\"'])target\\s*=\\s*(\"([^\"\\s]*)\"|'([^'\\s]*)')/i,k=/(^|[\\s\"'])popup\\s*=\\s*(\"([\\w=,]*)\"|'([\\w=,]*)')/i;function T(t,e){if(!t)return null;var r=t.match(e),n=r&&(r[3]||r[4]);return n&&E(n)}var A=/(^|;)\\s*color:/;r.plainText=function(t,e){for(var r=void 0!==(e=e||{}).len&&-1!==e.len?e.len:1/0,n=void 0!==e.allowedTags?e.allowedTags:[\"br\"],i=\"...\".length,a=t.split(m),o=[],s=\"\",l=0,c=0;c<a.length;c++){var u=a[c],h=u.match(y),f=h&&h[2].toLowerCase();if(f)-1!==n.indexOf(f)&&(o.push(u),s=f);else{var p=u.length;if(l+p<r)o.push(u),l+=p;else if(l<r){var d=r-l;s&&(\"br\"!==s||d<=i||p<=i)&&o.pop(),r>i?o.push(u.substr(0,d-i)+\"...\"):o.push(u.substr(0,d));break}s=\"\"}}return o.join(\"\")};var M={mu:\"\\u03bc\",amp:\"&\",lt:\"<\",gt:\">\",nbsp:\"\\xa0\",times:\"\\xd7\",plusmn:\"\\xb1\",deg:\"\\xb0\"},S=/&(#\\d+|#x[\\da-fA-F]+|[a-z]+);/g;function E(t){return t.replace(S,function(t,e){return(\"#\"===e.charAt(0)?function(t){if(t>1114111)return;var e=String.fromCodePoint;if(e)return e(t);var r=String.fromCharCode;return t<=65535?r(t):r(55232+(t>>10),t%1024+56320)}(\"x\"===e.charAt(1)?parseInt(e.substr(2),16):parseInt(e.substr(1),10)):M[e])||t})}function C(t,e,r){var n,i,a,o=r.horizontalAlign,s=r.verticalAlign||\"top\",l=t.node().getBoundingClientRect(),c=e.node().getBoundingClientRect();return i=\"bottom\"===s?function(){return l.bottom-n.height}:\"middle\"===s?function(){return l.top+(l.height-n.height)/2}:function(){return l.top},a=\"right\"===o?function(){return l.right-n.width}:\"center\"===o?function(){return l.left+(l.width-n.width)/2}:function(){return l.left},function(){return n=this.node().getBoundingClientRect(),this.style({top:i()-c.top+\"px\",left:a()-c.left+\"px\",\"z-index\":1e3}),this}}r.convertEntities=E,r.lineCount=function(t){return t.selectAll(\"tspan.line\").size()||1},r.positionText=function(t,e,r){return t.each(function(){var t=n.select(this);function i(e,r){return void 0===r?null===(r=t.attr(e))&&(t.attr(e,0),r=0):t.attr(e,r),r}var a=i(\"x\",e),o=i(\"y\",r);\"text\"===this.nodeName&&t.selectAll(\"tspan.line\").attr({x:a,y:o})})},r.makeEditable=function(t,e){var r=e.gd,i=e.delegate,a=n.dispatch(\"edit\",\"input\",\"cancel\"),o=i||t;if(t.style({\"pointer-events\":i?\"none\":\"all\"}),1!==t.size())throw new Error(\"boo\");function s(){!function(){var i=n.select(r).select(\".svg-container\"),o=i.append(\"div\"),s=t.node().style,c=parseFloat(s.fontSize||12),u=e.text;void 0===u&&(u=t.attr(\"data-unformatted\"));o.classed(\"plugin-editable editable\",!0).style({position:\"absolute\",\"font-family\":s.fontFamily||\"Arial\",\"font-size\":c,color:e.fill||s.fill||\"black\",opacity:1,\"background-color\":e.background||\"transparent\",outline:\"#ffffff33 1px solid\",margin:[-c/8+1,0,0,-1].join(\"px \")+\"px\",padding:\"0\",\"box-sizing\":\"border-box\"}).attr({contenteditable:!0}).text(u).call(C(t,i,e)).on(\"blur\",function(){r._editing=!1,t.text(this.textContent).style({opacity:1});var e,i=n.select(this).attr(\"class\");(e=i?\".\"+i.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(e).style({opacity:0});var o=this.textContent;n.select(this).transition().duration(0).remove(),n.select(document).on(\"mouseup\",null),a.edit.call(t,o)}).on(\"focus\",function(){var t=this;r._editing=!0,n.select(document).on(\"mouseup\",function(){if(n.event.target===t)return!1;document.activeElement===o.node()&&o.node().blur()})}).on(\"keyup\",function(){27===n.event.which?(r._editing=!1,t.style({opacity:1}),n.select(this).style({opacity:0}).on(\"blur\",function(){return!1}).transition().remove(),a.cancel.call(t,this.textContent)):(a.input.call(t,this.textContent),n.select(this).call(C(t,i,e)))}).on(\"keydown\",function(){13===n.event.which&&this.blur()}).call(l)}(),t.style({opacity:0});var i,s=o.attr(\"class\");(i=s?\".\"+s.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(i).style({opacity:0})}function l(t){var e=t.node(),r=document.createRange();r.selectNodeContents(e);var n=window.getSelection();n.removeAllRanges(),n.addRange(r),e.focus()}return e.immediate?s():o.on(\"click\",s),n.rebind(t,a,\"on\")}},{\"../constants/alignment\":688,\"../constants/xmlns_namespaces\":696,\"../lib\":719,d3:163}],744:[function(t,e,r){\"use strict\";var n={};function i(t){t&&null!==t.timer&&(clearTimeout(t.timer),t.timer=null)}r.throttle=function(t,e,r){var a=n[t],o=Date.now();if(!a){for(var s in n)n[s].ts<o-6e4&&delete n[s];a=n[t]={ts:0,timer:null}}function l(){r(),a.ts=Date.now(),a.onDone&&(a.onDone(),a.onDone=null)}i(a),o>a.ts+e?l():a.timer=setTimeout(function(){l(),a.timer=null},e)},r.done=function(t){var e=n[t];return e&&e.timer?new Promise(function(t){var r=e.onDone;e.onDone=function(){r&&r(),t(),e.onDone=null}}):Promise.resolve()},r.clear=function(t){if(t)i(n[t]),delete n[t];else for(var e in n)r.clear(e)}},{}],745:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t,e){if(t>0)return Math.log(t)/Math.LN10;var r=Math.log(Math.min(e[0],e[1]))/Math.LN10;return n(r)||(r=Math.log(Math.max(e[0],e[1]))/Math.LN10-6),r}},{\"fast-isnumeric\":225}],746:[function(t,e,r){\"use strict\";var n=e.exports={},i=t(\"../plots/geo/constants\").locationmodeToLayer,a=t(\"topojson-client\").feature;n.getTopojsonName=function(t){return[t.scope.replace(/ /g,\"-\"),\"_\",t.resolution.toString(),\"m\"].join(\"\")},n.getTopojsonPath=function(t,e){return t+e+\".json\"},n.getTopojsonFeatures=function(t,e){var r=i[t.locationmode],n=e.objects[r];return a(e,n).features}},{\"../plots/geo/constants\":795,\"topojson-client\":540}],747:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en-US\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colorscale title\"},format:{date:\"%m/%d/%Y\"}}},{}],748:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colourscale title\"},format:{days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],periods:[\"AM\",\"PM\"],dateTime:\"%a %b %e %X %Y\",date:\"%d/%m/%Y\",time:\"%H:%M:%S\",decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],year:\"%Y\",month:\"%b %Y\",dayMonth:\"%b %-d\",dayMonthYear:\"%b %-d, %Y\"}}},{}],749:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t){for(var e,r,i=n.layoutArrayContainers,a=n.layoutArrayRegexes,o=t.split(\"[\")[0],s=0;s<a.length;s++)if((r=t.match(a[s]))&&0===r.index){e=r[0];break}if(e||(e=i[i.indexOf(o)]),!e)return!1;var l=t.substr(e.length);return l?!!(r=l.match(/^\\[(0|[1-9][0-9]*)\\](\\.(.+))?$/))&&{array:e,index:Number(r[1]),property:r[3]||\"\"}:{array:e,index:\"\",property:\"\"}}},{\"../registry\":847}],750:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.extendFlat,a=n.isPlainObject,o={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"clearAxisTypes\",\"plot\",\"style\",\"markerSize\",\"colorbars\"]},s={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"plot\",\"legend\",\"ticks\",\"axrange\",\"layoutstyle\",\"modebar\",\"camera\",\"arraydraw\",\"colorbars\"]},l=o.flags.slice().concat([\"fullReplot\"]),c=s.flags.slice().concat(\"layoutReplot\");function u(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=!1;return e}function h(t,e,r){var n=i({},t);for(var o in n){var s=n[o];a(s)&&(n[o]=f(s,e,r,o))}return\"from-root\"===r&&(n.editType=e),n}function f(t,e,r,n){if(t.valType){var a=i({},t);if(a.editType=e,Array.isArray(t.items)){a.items=new Array(t.items.length);for(var o=0;o<t.items.length;o++)a.items[o]=f(t.items[o],e,\"from-root\")}return a}return h(t,e,\"_\"===n.charAt(0)?\"nested\":\"from-root\")}e.exports={traces:o,layout:s,traceFlags:function(){return u(l)},layoutFlags:function(){return u(c)},update:function(t,e){var r=e.editType;if(r&&\"none\"!==r)for(var n=r.split(\"+\"),i=0;i<n.length;i++)t[n[i]]=!0},overrideAll:h}},{\"../lib\":719}],751:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"gl-mat4/fromQuat\"),a=t(\"../registry\"),o=t(\"../lib\"),s=t(\"../plots/plots\"),l=t(\"../plots/cartesian/axis_ids\"),c=t(\"../components/color\"),u=l.cleanId,h=l.getFromTrace,f=a.traceIs;function p(t,e){var r=t[e],n=e.charAt(0);r&&\"paper\"!==r&&(t[e]=u(r,n))}function d(t){function e(e,r){var n=t[e],i=t.title&&t.title[r];n&&!i&&(t.title||(t.title={}),t.title[r]=t[e],delete t[e])}t&&(\"string\"!=typeof t.title&&\"number\"!=typeof t.title||(t.title={text:t.title}),e(\"titlefont\",\"font\"),e(\"titleposition\",\"position\"),e(\"titleside\",\"side\"),e(\"titleoffset\",\"offset\"))}function g(t){if(!o.isPlainObject(t))return!1;var e=t.name;return delete t.name,delete t.showlegend,(\"string\"==typeof e||\"number\"==typeof e)&&String(e)}function v(t,e,r,n){if(r&&!n)return t;if(n&&!r)return e;if(!t.trim())return e;if(!e.trim())return t;var i,a=Math.min(t.length,e.length);for(i=0;i<a&&t.charAt(i)===e.charAt(i);i++);return t.substr(0,i).trim()}function m(t){var e=\"middle\",r=\"center\";return\"string\"==typeof t&&(-1!==t.indexOf(\"top\")?e=\"top\":-1!==t.indexOf(\"bottom\")&&(e=\"bottom\"),-1!==t.indexOf(\"left\")?r=\"left\":-1!==t.indexOf(\"right\")&&(r=\"right\")),e+\" \"+r}function y(t,e){return e in t&&\"object\"==typeof t[e]&&0===Object.keys(t[e]).length}r.clearPromiseQueue=function(t){Array.isArray(t._promises)&&t._promises.length>0&&o.log(\"Clearing previous rejected promises from queue.\"),t._promises=[]},r.cleanLayout=function(t){var e,n;t||(t={}),t.xaxis1&&(t.xaxis||(t.xaxis=t.xaxis1),delete t.xaxis1),t.yaxis1&&(t.yaxis||(t.yaxis=t.yaxis1),delete t.yaxis1),t.scene1&&(t.scene||(t.scene=t.scene1),delete t.scene1);var a=(s.subplotsRegistry.cartesian||{}).attrRegex,l=(s.subplotsRegistry.polar||{}).attrRegex,h=(s.subplotsRegistry.ternary||{}).attrRegex,f=(s.subplotsRegistry.gl3d||{}).attrRegex,g=Object.keys(t);for(e=0;e<g.length;e++){var v=g[e];if(a&&a.test(v)){var m=t[v];m.anchor&&\"free\"!==m.anchor&&(m.anchor=u(m.anchor)),m.overlaying&&(m.overlaying=u(m.overlaying)),m.type||(m.isdate?m.type=\"date\":m.islog?m.type=\"log\":!1===m.isdate&&!1===m.islog&&(m.type=\"linear\")),\"withzero\"!==m.autorange&&\"tozero\"!==m.autorange||(m.autorange=!0,m.rangemode=\"tozero\"),delete m.islog,delete m.isdate,delete m.categories,y(m,\"domain\")&&delete m.domain,void 0!==m.autotick&&(void 0===m.tickmode&&(m.tickmode=m.autotick?\"auto\":\"linear\"),delete m.autotick),d(m)}else if(l&&l.test(v)){d(t[v].radialaxis)}else if(h&&h.test(v)){var x=t[v];d(x.aaxis),d(x.baxis),d(x.caxis)}else if(f&&f.test(v)){var b=t[v],_=b.cameraposition;if(Array.isArray(_)&&4===_[0].length){var w=_[0],k=_[1],T=_[2],A=i([],w),M=[];for(n=0;n<3;++n)M[n]=k[n]+T*A[2+4*n];b.camera={eye:{x:M[0],y:M[1],z:M[2]},center:{x:k[0],y:k[1],z:k[2]},up:{x:0,y:0,z:1}},delete b.cameraposition}d(b.xaxis),d(b.yaxis),d(b.zaxis)}}var S=Array.isArray(t.annotations)?t.annotations.length:0;for(e=0;e<S;e++){var E=t.annotations[e];o.isPlainObject(E)&&(E.ref&&(\"paper\"===E.ref?(E.xref=\"paper\",E.yref=\"paper\"):\"data\"===E.ref&&(E.xref=\"x\",E.yref=\"y\"),delete E.ref),p(E,\"xref\"),p(E,\"yref\"))}var C=Array.isArray(t.shapes)?t.shapes.length:0;for(e=0;e<C;e++){var L=t.shapes[e];o.isPlainObject(L)&&(p(L,\"xref\"),p(L,\"yref\"))}var P=t.legend;return P&&(P.x>3?(P.x=1.02,P.xanchor=\"left\"):P.x<-2&&(P.x=-.02,P.xanchor=\"right\"),P.y>3?(P.y=1.02,P.yanchor=\"bottom\"):P.y<-2&&(P.y=-.02,P.yanchor=\"top\")),d(t),\"rotate\"===t.dragmode&&(t.dragmode=\"orbit\"),c.clean(t),t.template&&t.template.layout&&r.cleanLayout(t.template.layout),t},r.cleanData=function(t){for(var e=0;e<t.length;e++){var n,i=t[e];if(\"histogramy\"===i.type&&\"xbins\"in i&&!(\"ybins\"in i)&&(i.ybins=i.xbins,delete i.xbins),i.error_y&&\"opacity\"in i.error_y){var l=c.defaults,h=i.error_y.color||(f(i,\"bar\")?c.defaultLine:l[e%l.length]);i.error_y.color=c.addOpacity(c.rgb(h),c.opacity(h)*i.error_y.opacity),delete i.error_y.opacity}if(\"bardir\"in i&&(\"h\"!==i.bardir||!f(i,\"bar\")&&\"histogram\"!==i.type.substr(0,9)||(i.orientation=\"h\",r.swapXYData(i)),delete i.bardir),\"histogramy\"===i.type&&r.swapXYData(i),\"histogramx\"!==i.type&&\"histogramy\"!==i.type||(i.type=\"histogram\"),\"scl\"in i&&!(\"colorscale\"in i)&&(i.colorscale=i.scl,delete i.scl),\"reversescl\"in i&&!(\"reversescale\"in i)&&(i.reversescale=i.reversescl,delete i.reversescl),i.xaxis&&(i.xaxis=u(i.xaxis,\"x\")),i.yaxis&&(i.yaxis=u(i.yaxis,\"y\")),f(i,\"gl3d\")&&i.scene&&(i.scene=s.subplotsRegistry.gl3d.cleanId(i.scene)),!f(i,\"pie-like\")&&!f(i,\"bar-like\"))if(Array.isArray(i.textposition))for(n=0;n<i.textposition.length;n++)i.textposition[n]=m(i.textposition[n]);else i.textposition&&(i.textposition=m(i.textposition));var p=a.getModule(i);if(p&&p.colorbar){var x=p.colorbar.container,b=x?i[x]:i;b&&b.colorscale&&(\"YIGnBu\"===b.colorscale&&(b.colorscale=\"YlGnBu\"),\"YIOrRd\"===b.colorscale&&(b.colorscale=\"YlOrRd\"))}if(\"surface\"===i.type&&o.isPlainObject(i.contours)){var _=[\"x\",\"y\",\"z\"];for(n=0;n<_.length;n++){var w=i.contours[_[n]];o.isPlainObject(w)&&(w.highlightColor&&(w.highlightcolor=w.highlightColor,delete w.highlightColor),w.highlightWidth&&(w.highlightwidth=w.highlightWidth,delete w.highlightWidth))}}if(\"candlestick\"===i.type||\"ohlc\"===i.type){var k=!1!==(i.increasing||{}).showlegend,T=!1!==(i.decreasing||{}).showlegend,A=g(i.increasing),M=g(i.decreasing);if(!1!==A&&!1!==M){var S=v(A,M,k,T);S&&(i.name=S)}else!A&&!M||i.name||(i.name=A||M)}if(Array.isArray(i.transforms)){var E=i.transforms;for(n=0;n<E.length;n++){var C=E[n];if(o.isPlainObject(C))switch(C.type){case\"filter\":C.filtersrc&&(C.target=C.filtersrc,delete C.filtersrc),C.calendar&&(C.valuecalendar||(C.valuecalendar=C.calendar),delete C.calendar);break;case\"groupby\":if(C.styles=C.styles||C.style,C.styles&&!Array.isArray(C.styles)){var L=C.styles,P=Object.keys(L);C.styles=[];for(var O=0;O<P.length;O++)C.styles.push({target:P[O],value:L[P[O]]})}}}}y(i,\"line\")&&delete i.line,\"marker\"in i&&(y(i.marker,\"line\")&&delete i.marker.line,y(i,\"marker\")&&delete i.marker),c.clean(i),i.autobinx&&(delete i.autobinx,delete i.xbins),i.autobiny&&(delete i.autobiny,delete i.ybins),d(i),i.colorbar&&d(i.colorbar),i.marker&&i.marker.colorbar&&d(i.marker.colorbar),i.line&&i.line.colorbar&&d(i.line.colorbar),i.aaxis&&d(i.aaxis),i.baxis&&d(i.baxis)}},r.swapXYData=function(t){var e;if(o.swapAttrs(t,[\"?\",\"?0\",\"d?\",\"?bins\",\"nbins?\",\"autobin?\",\"?src\",\"error_?\"]),Array.isArray(t.z)&&Array.isArray(t.z[0])&&(t.transpose?delete t.transpose:t.transpose=!0),t.error_x&&t.error_y){var r=t.error_y,n=\"copy_ystyle\"in r?r.copy_ystyle:!(r.color||r.thickness||r.width);o.swapAttrs(t,[\"error_?.copy_ystyle\"]),n&&o.swapAttrs(t,[\"error_?.color\",\"error_?.thickness\",\"error_?.width\"])}if(\"string\"==typeof t.hoverinfo){var i=t.hoverinfo.split(\"+\");for(e=0;e<i.length;e++)\"x\"===i[e]?i[e]=\"y\":\"y\"===i[e]&&(i[e]=\"x\");t.hoverinfo=i.join(\"+\")}},r.coerceTraceIndices=function(t,e){if(n(e))return[e];if(!Array.isArray(e)||!e.length)return t.data.map(function(t,e){return e});if(Array.isArray(e)){for(var r=[],i=0;i<e.length;i++)o.isIndex(e[i],t.data.length)?r.push(e[i]):o.warn(\"trace index (\",e[i],\") is not a number or is out of bounds\");return r}return e},r.manageArrayContainers=function(t,e,r){var i=t.obj,a=t.parts,s=a.length,l=a[s-1],c=n(l);if(c&&null===e){var u=a.slice(0,s-1).join(\".\");o.nestedProperty(i,u).get().splice(l,1)}else c&&void 0===t.get()?(void 0===t.get()&&(r[t.astr]=null),t.set(e)):t.set(e)};var x=/(\\.[^\\[\\]\\.]+|\\[[^\\[\\]\\.]+\\])$/;function b(t){var e=t.search(x);if(e>0)return t.substr(0,e)}r.hasParent=function(t,e){for(var r=b(e);r;){if(r in t)return!0;r=b(r)}return!1};var _=[\"x\",\"y\",\"z\"];r.clearAxisTypes=function(t,e,r){for(var n=0;n<e.length;n++)for(var i=t._fullData[n],a=0;a<3;a++){var s=h(t,i,_[a]);if(s&&\"log\"!==s.type){var l=s._name,c=s._id.substr(1);if(\"scene\"===c.substr(0,5)){if(void 0!==r[c])continue;l=c+\".\"+l}var u=l+\".type\";void 0===r[l]&&void 0===r[u]&&o.nestedProperty(t.layout,u).set(null)}}}},{\"../components/color\":593,\"../lib\":719,\"../plots/cartesian/axis_ids\":770,\"../plots/plots\":828,\"../registry\":847,\"fast-isnumeric\":225,\"gl-mat4/fromQuat\":262}],752:[function(t,e,r){\"use strict\";var n=t(\"./plot_api\");r.plot=n.plot,r.newPlot=n.newPlot,r.restyle=n.restyle,r.relayout=n.relayout,r.redraw=n.redraw,r.update=n.update,r._guiRestyle=n._guiRestyle,r._guiRelayout=n._guiRelayout,r._guiUpdate=n._guiUpdate,r._storeDirectGUIEdit=n._storeDirectGUIEdit,r.react=n.react,r.extendTraces=n.extendTraces,r.prependTraces=n.prependTraces,r.addTraces=n.addTraces,r.deleteTraces=n.deleteTraces,r.moveTraces=n.moveTraces,r.purge=n.purge,r.addFrames=n.addFrames,r.deleteFrames=n.deleteFrames,r.animate=n.animate,r.setPlotConfig=n.setPlotConfig,r.toImage=t(\"./to_image\"),r.validate=t(\"./validate\"),r.downloadImage=t(\"../snapshot/download\");var i=t(\"./template_api\");r.makeTemplate=i.makeTemplate,r.validateTemplate=i.validateTemplate},{\"../snapshot/download\":849,\"./plot_api\":754,\"./template_api\":759,\"./to_image\":760,\"./validate\":761}],753:[function(t,e,r){\"use strict\";var n=t(\"../lib/is_plain_object\"),i=t(\"../lib/noop\"),a=t(\"../lib/loggers\"),o=t(\"../lib/search\").sorterAsc,s=t(\"../registry\");r.containerArrayMatch=t(\"./container_array_match\");var l=r.isAddVal=function(t){return\"add\"===t||n(t)},c=r.isRemoveVal=function(t){return null===t||\"remove\"===t};r.applyContainerArrayChanges=function(t,e,r,n,u){var h=e.astr,f=s.getComponentMethod(h,\"supplyLayoutDefaults\"),p=s.getComponentMethod(h,\"draw\"),d=s.getComponentMethod(h,\"drawOne\"),g=n.replot||n.recalc||f===i||p===i,v=t.layout,m=t._fullLayout;if(r[\"\"]){Object.keys(r).length>1&&a.warn(\"Full array edits are incompatible with other edits\",h);var y=r[\"\"][\"\"];if(c(y))e.set(null);else{if(!Array.isArray(y))return a.warn(\"Unrecognized full array edit value\",h,y),!0;e.set(y)}return!g&&(f(v,m),p(t),!0)}var x,b,_,w,k,T,A,M,S=Object.keys(r).map(Number).sort(o),E=e.get(),C=E||[],L=u(m,h).get(),P=[],O=-1,z=C.length;for(x=0;x<S.length;x++)if(w=r[_=S[x]],k=Object.keys(w),T=w[\"\"],A=l(T),_<0||_>C.length-(A?0:1))a.warn(\"index out of range\",h,_);else if(void 0!==T)k.length>1&&a.warn(\"Insertion & removal are incompatible with edits to the same index.\",h,_),c(T)?P.push(_):A?(\"add\"===T&&(T={}),C.splice(_,0,T),L&&L.splice(_,0,{})):a.warn(\"Unrecognized full object edit value\",h,_,T),-1===O&&(O=_);else for(b=0;b<k.length;b++)M=h+\"[\"+_+\"].\",u(C[_],k[b],M).set(w[k[b]]);for(x=P.length-1;x>=0;x--)C.splice(P[x],1),L&&L.splice(P[x],1);if(C.length?E||e.set(C):e.set(null),g)return!1;if(f(v,m),d!==i){var I;if(-1===O)I=S;else{for(z=Math.max(C.length,z),I=[],x=0;x<S.length&&!((_=S[x])>=O);x++)I.push(_);for(x=O;x<z;x++)I.push(x)}for(x=0;x<I.length;x++)d(t,I[x])}else p(t);return!0}},{\"../lib/is_plain_object\":720,\"../lib/loggers\":723,\"../lib/noop\":728,\"../lib/search\":738,\"../registry\":847,\"./container_array_match\":749}],754:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"has-hover\"),o=t(\"../lib\"),s=o.nestedProperty,l=t(\"../lib/events\"),c=t(\"../lib/queue\"),u=t(\"../registry\"),h=t(\"./plot_schema\"),f=t(\"../plots/plots\"),p=t(\"../plots/polar/legacy\"),d=t(\"../plots/cartesian/axes\"),g=t(\"../components/drawing\"),v=t(\"../components/color\"),m=t(\"../plots/cartesian/graph_interact\").initInteractions,y=t(\"../constants/xmlns_namespaces\"),x=t(\"../lib/svg_text_utils\"),b=t(\"../plots/cartesian/select\").clearSelect,_=t(\"./plot_config\").dfltConfig,w=t(\"./manage_arrays\"),k=t(\"./helpers\"),T=t(\"./subroutines\"),A=t(\"./edit_types\"),M=t(\"../plots/cartesian/constants\").AX_NAME_PATTERN,S=0,E=5;function C(t){var e=t._fullLayout;e._redrawFromAutoMarginCount?e._redrawFromAutoMarginCount--:t.emit(\"plotly_afterplot\")}function L(t,e){try{t._fullLayout._paper.style(\"background\",e)}catch(t){o.error(t)}}function P(t,e){L(t,v.combine(e,\"white\"))}function O(t,e){if(!t._context){t._context=o.extendDeep({},_);var r=n.select(\"base\");t._context._baseUrl=r.size()&&r.attr(\"href\")?window.location.href.split(\"#\")[0]:\"\"}var i,s,l,c=t._context;if(e){for(s=Object.keys(e),i=0;i<s.length;i++)\"editable\"!==(l=s[i])&&\"edits\"!==l&&l in c&&(\"setBackground\"===l&&\"opaque\"===e[l]?c[l]=P:c[l]=e[l]);e.plot3dPixelRatio&&!c.plotGlPixelRatio&&(c.plotGlPixelRatio=c.plot3dPixelRatio);var u=e.editable;if(void 0!==u)for(c.editable=u,s=Object.keys(c.edits),i=0;i<s.length;i++)c.edits[s[i]]=u;if(e.edits)for(s=Object.keys(e.edits),i=0;i<s.length;i++)(l=s[i])in c.edits&&(c.edits[l]=e.edits[l]);c._exportedPlot=e._exportedPlot}c.staticPlot&&(c.editable=!1,c.edits={},c.autosizable=!1,c.scrollZoom=!1,c.doubleClick=!1,c.showTips=!1,c.showLink=!1,c.displayModeBar=!1),\"hover\"!==c.displayModeBar||a||(c.displayModeBar=!0),\"transparent\"!==c.setBackground&&\"function\"==typeof c.setBackground||(c.setBackground=L),c._hasZeroHeight=c._hasZeroHeight||0===t.clientHeight,c._hasZeroWidth=c._hasZeroWidth||0===t.clientWidth;var h=c.scrollZoom,f=c._scrollZoom={};if(!0===h)f.cartesian=1,f.gl3d=1,f.geo=1,f.mapbox=1;else if(\"string\"==typeof h){var p=h.split(\"+\");for(i=0;i<p.length;i++)f[p[i]]=1}else!1!==h&&(f.gl3d=1,f.geo=1,f.mapbox=1)}function z(t,e){var r,n,i=e+1,a=[];for(r=0;r<t.length;r++)(n=t[r])<0?a.push(i+n):a.push(n);return a}function I(t,e,r){var n,i;for(n=0;n<e.length;n++){if((i=e[n])!==parseInt(i,10))throw new Error(\"all values in \"+r+\" must be integers\");if(i>=t.data.length||i<-t.data.length)throw new Error(r+\" must be valid indices for gd.data.\");if(e.indexOf(i,n+1)>-1||i>=0&&e.indexOf(-t.data.length+i)>-1||i<0&&e.indexOf(t.data.length+i)>-1)throw new Error(\"each index in \"+r+\" must be unique.\")}}function D(t,e,r){if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"currentIndices is a required argument.\");if(Array.isArray(e)||(e=[e]),I(t,e,\"currentIndices\"),\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&I(t,r,\"newIndices\"),\"undefined\"!=typeof r&&e.length!==r.length)throw new Error(\"current and new indices must be of equal length.\")}function R(t,e,r,n,a){!function(t,e,r,n){var i=o.isPlainObject(n);if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array\");if(!o.isPlainObject(e))throw new Error(\"update must be a key:value object\");if(\"undefined\"==typeof r)throw new Error(\"indices must be an integer or array of integers\");for(var a in I(t,r,\"indices\"),e){if(!Array.isArray(e[a])||e[a].length!==r.length)throw new Error(\"attribute \"+a+\" must be an array of length equal to indices array length\");if(i&&(!(a in n)||!Array.isArray(n[a])||n[a].length!==e[a].length))throw new Error(\"when maxPoints is set as a key:value object it must contain a 1:1 corrispondence with the keys and number of traces in the update object\")}}(t,e,r,n);for(var l=function(t,e,r,n){var a,l,c,u,h,f=o.isPlainObject(n),p=[];for(var d in Array.isArray(r)||(r=[r]),r=z(r,t.data.length-1),e)for(var g=0;g<r.length;g++){if(a=t.data[r[g]],l=(c=s(a,d)).get(),u=e[d][g],!o.isArrayOrTypedArray(u))throw new Error(\"attribute: \"+d+\" index: \"+g+\" must be an array\");if(!o.isArrayOrTypedArray(l))throw new Error(\"cannot extend missing or non-array attribute: \"+d);if(l.constructor!==u.constructor)throw new Error(\"cannot extend array with an array of a different type: \"+d);h=f?n[d][g]:n,i(h)||(h=-1),p.push({prop:c,target:l,insert:u,maxp:Math.floor(h)})}return p}(t,e,r,n),c={},u={},h=0;h<l.length;h++){var f=l[h].prop,p=l[h].maxp,d=a(l[h].target,l[h].insert,p);f.set(d[0]),Array.isArray(c[f.astr])||(c[f.astr]=[]),c[f.astr].push(d[1]),Array.isArray(u[f.astr])||(u[f.astr]=[]),u[f.astr].push(l[h].target.length)}return{update:c,maxPoints:u}}function F(t,e){var r=new t.constructor(t.length+e.length);return r.set(t),r.set(e,t.length),r}function B(t,e,n,i){t=o.getGraphDiv(t),k.clearPromiseQueue(t);var a={};if(\"string\"==typeof e)a[e]=n;else{if(!o.isPlainObject(e))return o.warn(\"Restyle fail.\",e,n,i),Promise.reject();a=o.extendFlat({},e),void 0===i&&(i=n)}Object.keys(a).length&&(t.changed=!0);var s=k.coerceTraceIndices(t,i),l=V(t,a,s),u=l.flags;u.calc&&(t.calcdata=void 0),u.clearAxisTypes&&k.clearAxisTypes(t,s,{});var h=[];u.fullReplot?h.push(r.plot):(h.push(f.previousPromises),f.supplyDefaults(t),u.markerSize&&(f.doCalcdata(t),Y(h)),u.style&&h.push(T.doTraceStyle),u.colorbars&&h.push(T.doColorBars),h.push(C)),h.push(f.rehover,f.redrag),c.add(t,B,[t,l.undoit,l.traces],B,[t,l.redoit,l.traces]);var p=o.syncOrAsync(h,t);return p&&p.then||(p=Promise.resolve()),p.then(function(){return t.emit(\"plotly_restyle\",l.eventData),t})}function N(t){return void 0===t?null:t}function j(t,e){return e?function(e,r,n){var i=s(e,r),a=i.set;return i.set=function(e){U((n||\"\")+r,i.get(),e,t),a(e)},i}:s}function U(t,e,r,n){if(Array.isArray(e)||Array.isArray(r))for(var i=Array.isArray(e)?e:[],a=Array.isArray(r)?r:[],s=Math.max(i.length,a.length),l=0;l<s;l++)U(t+\"[\"+l+\"]\",i[l],a[l],n);else if(o.isPlainObject(e)||o.isPlainObject(r)){var c=o.isPlainObject(e)?e:{},u=o.isPlainObject(r)?r:{},h=o.extendFlat({},c,u);for(var f in h)U(t+\".\"+f,c[f],u[f],n)}else void 0===n[t]&&(n[t]=N(e))}function V(t,e,r){var n,i=t._fullLayout,a=t._fullData,l=t.data,c=i._guiEditing,p=j(i._preGUI,c),g=o.extendDeepAll({},e);q(e);var v,m=A.traceFlags(),y={},x={};function b(){return r.map(function(){})}function _(t){var e=d.id2name(t);-1===v.indexOf(e)&&v.push(e)}function w(t){return\"LAYOUT\"+t+\".autorange\"}function T(t){return\"LAYOUT\"+t+\".range\"}function M(t){for(var e=t;e<a.length;e++)if(a[e]._input===l[t])return a[e]}function S(n,a,o){if(Array.isArray(n))n.forEach(function(t){S(t,a,o)});else if(!(n in e||k.hasParent(e,n))){var s;if(\"LAYOUT\"===n.substr(0,6))s=p(t.layout,n.replace(\"LAYOUT\",\"\"));else{var u=r[o];s=j(i._tracePreGUI[M(u)._fullInput.uid],c)(l[u],n)}n in x||(x[n]=b()),void 0===x[n][o]&&(x[n][o]=N(s.get())),void 0!==a&&s.set(a)}}function E(t){return function(e){return a[e][t]}}function C(t){return function(e,n){return!1===e?a[r[n]][t]:null}}for(var L in e){if(k.hasParent(e,L))throw new Error(\"cannot set \"+L+\" and a parent attribute simultaneously\");var P,O,z,I,D,R,F=e[L];if(\"autobinx\"!==L&&\"autobiny\"!==L||(L=L.charAt(L.length-1)+\"bins\",F=Array.isArray(F)?F.map(C(L)):!1===F?r.map(E(L)):null),y[L]=F,\"LAYOUT\"!==L.substr(0,6)){for(x[L]=b(),n=0;n<r.length;n++){if(P=l[r[n]],O=M(r[n]),I=(z=j(i._tracePreGUI[O._fullInput.uid],c)(P,L)).get(),void 0!==(D=Array.isArray(F)?F[n%F.length]:F)){var B=z.parts[z.parts.length-1],U=L.substr(0,L.length-B.length-1),V=U?U+\".\":\"\",H=U?s(O,U).get():O;if((R=h.getTraceValObject(O,z.parts))&&R.impliedEdits&&null!==D)for(var G in R.impliedEdits)S(o.relativeAttr(L,G),R.impliedEdits[G],n);else if(\"thicknessmode\"!==B&&\"lenmode\"!==B||I===D||\"fraction\"!==D&&\"pixels\"!==D||!H){if(\"type\"===L&&(\"pie\"===D!=(\"pie\"===I)||\"funnelarea\"===D!=(\"funnelarea\"===I))){var Y=\"x\",W=\"y\";\"bar\"!==D&&\"bar\"!==I||\"h\"!==P.orientation||(Y=\"y\",W=\"x\"),o.swapAttrs(P,[\"?\",\"?src\"],\"labels\",Y),o.swapAttrs(P,[\"d?\",\"?0\"],\"label\",Y),o.swapAttrs(P,[\"?\",\"?src\"],\"values\",W),\"pie\"===I||\"funnelarea\"===I?(s(P,\"marker.color\").set(s(P,\"marker.colors\").get()),i._pielayer.selectAll(\"g.trace\").remove()):u.traceIs(P,\"cartesian\")&&s(P,\"marker.colors\").set(s(P,\"marker.color\").get())}}else{var X=i._size,Z=H.orient,J=\"top\"===Z||\"bottom\"===Z;if(\"thicknessmode\"===B){var K=J?X.h:X.w;S(V+\"thickness\",H.thickness*(\"fraction\"===D?1/K:K),n)}else{var $=J?X.w:X.h;S(V+\"len\",H.len*(\"fraction\"===D?1/$:$),n)}}x[L][n]=N(I);if(-1!==[\"swapxy\",\"swapxyaxes\",\"orientation\",\"orientationaxes\"].indexOf(L)){if(\"orientation\"===L){z.set(D);var Q=P.x&&!P.y?\"h\":\"v\";if((z.get()||Q)===O.orientation)continue}else\"orientationaxes\"===L&&(P.orientation={v:\"h\",h:\"v\"}[O.orientation]);k.swapXYData(P),m.calc=m.clearAxisTypes=!0}else-1!==f.dataArrayContainers.indexOf(z.parts[0])?(k.manageArrayContainers(z,D,x),m.calc=!0):(R?R.arrayOk&&!u.traceIs(O,\"regl\")&&(o.isArrayOrTypedArray(D)||o.isArrayOrTypedArray(I))?m.calc=!0:A.update(m,R):m.calc=!0,z.set(D))}}if(-1!==[\"swapxyaxes\",\"orientationaxes\"].indexOf(L)&&d.swap(t,r),\"orientationaxes\"===L){var tt=s(t.layout,\"hovermode\");\"x\"===tt.get()?tt.set(\"y\"):\"y\"===tt.get()&&tt.set(\"x\")}if(-1!==[\"orientation\",\"type\"].indexOf(L)){for(v=[],n=0;n<r.length;n++){var et=l[r[n]];u.traceIs(et,\"cartesian\")&&(_(et.xaxis||\"x\"),_(et.yaxis||\"y\"))}S(v.map(w),!0,0),S(v.map(T),[0,1],0)}}else z=p(t.layout,L.replace(\"LAYOUT\",\"\")),x[L]=[N(z.get())],z.set(Array.isArray(F)?F[0]:F),m.calc=!0}return(m.calc||m.plot)&&(m.fullReplot=!0),{flags:m,undoit:x,redoit:y,traces:r,eventData:o.extendDeepNoArrays([],[g,r])}}function q(t){var e,r,n,i=o.counterRegex(\"axis\",\".title\",!1,!1),a=/colorbar\\.title$/,s=Object.keys(t);for(e=0;e<s.length;e++)r=s[e],n=t[r],\"title\"!==r&&!i.test(r)&&!a.test(r)||\"string\"!=typeof n&&\"number\"!=typeof n?r.indexOf(\"titlefont\")>-1?l(r,r.replace(\"titlefont\",\"title.font\")):r.indexOf(\"titleposition\")>-1?l(r,r.replace(\"titleposition\",\"title.position\")):r.indexOf(\"titleside\")>-1?l(r,r.replace(\"titleside\",\"title.side\")):r.indexOf(\"titleoffset\")>-1&&l(r,r.replace(\"titleoffset\",\"title.offset\")):l(r,r.replace(\"title\",\"title.text\"));function l(e,r){t[r]=t[e],delete t[e]}}function H(t,e,r){if(t=o.getGraphDiv(t),k.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);var n={};if(\"string\"==typeof e)n[e]=r;else{if(!o.isPlainObject(e))return o.warn(\"Relayout fail.\",e,r),Promise.reject();n=o.extendFlat({},e)}Object.keys(n).length&&(t.changed=!0);var i=J(t,n),a=i.flags;a.calc&&(t.calcdata=void 0);var s=[f.previousPromises];a.layoutReplot?s.push(T.layoutReplot):Object.keys(n).length&&(G(t,a,i)||f.supplyDefaults(t),a.legend&&s.push(T.doLegend),a.layoutstyle&&s.push(T.layoutStyles),a.axrange&&Y(s,i.rangesAltered),a.ticks&&s.push(T.doTicksRelayout),a.modebar&&s.push(T.doModeBar),a.camera&&s.push(T.doCamera),a.colorbars&&s.push(T.doColorBars),s.push(C)),s.push(f.rehover,f.redrag),c.add(t,H,[t,i.undoit],H,[t,i.redoit]);var l=o.syncOrAsync(s,t);return l&&l.then||(l=Promise.resolve(t)),l.then(function(){return t.emit(\"plotly_relayout\",i.eventData),t})}function G(t,e,r){var n=t._fullLayout;if(!e.axrange)return!1;for(var i in e)if(\"axrange\"!==i&&e[i])return!1;for(var a in r.rangesAltered){var o=d.id2name(a),s=t.layout[o],l=n[o];if(l.autorange=s.autorange,l.range=s.range.slice(),l.cleanRange(),l._matchGroup)for(var c in l._matchGroup)if(c!==a){var u=n[d.id2name(c)];u.autorange=l.autorange,u.range=l.range.slice(),u._input.range=l.range.slice()}}return!0}function Y(t,e){var r=e?function(t){var r=[],n=!0;for(var i in e){var a=d.getFromId(t,i);if(r.push(i),a._matchGroup)for(var o in a._matchGroup)e[o]||r.push(o);a.automargin&&(n=!1)}return d.draw(t,r,{skipTitle:n})}:function(t){return d.draw(t,\"redraw\")};t.push(b,T.doAutoRangeAndConstraints,r,T.drawData,T.finalDraw)}var W=/^[xyz]axis[0-9]*\\.range(\\[[0|1]\\])?$/,X=/^[xyz]axis[0-9]*\\.autorange$/,Z=/^[xyz]axis[0-9]*\\.domain(\\[[0|1]\\])?$/;function J(t,e){var r,n,i,a=t.layout,l=t._fullLayout,c=l._guiEditing,f=j(l._preGUI,c),p=Object.keys(e),g=d.list(t),v=o.extendDeepAll({},e),m={};for(q(e),p=Object.keys(e),n=0;n<p.length;n++)if(0===p[n].indexOf(\"allaxes\")){for(i=0;i<g.length;i++){var y=g[i]._id.substr(1),x=-1!==y.indexOf(\"scene\")?y+\".\":\"\",b=p[n].replace(\"allaxes\",x+g[i]._name);e[b]||(e[b]=e[p[n]])}delete e[p[n]]}var _=A.layoutFlags(),T={},S={};function E(t,r){if(Array.isArray(t))t.forEach(function(t){E(t,r)});else if(!(t in e||k.hasParent(e,t))){var n=f(a,t);t in S||(S[t]=N(n.get())),void 0!==r&&n.set(r)}}var C,L={};function P(t){var e=d.name2id(t.split(\".\")[0]);return L[e]=1,e}for(var O in e){if(k.hasParent(e,O))throw new Error(\"cannot set \"+O+\" and a parent attribute simultaneously\");for(var z=f(a,O),I=e[O],D=z.parts.length-1;D>0&&\"string\"!=typeof z.parts[D];)D--;var R=z.parts[D],F=z.parts[D-1]+\".\"+R,B=z.parts.slice(0,D).join(\".\"),U=s(t.layout,B).get(),V=s(l,B).get(),H=z.get();if(void 0!==I){T[O]=I,S[O]=\"reverse\"===R?I:N(H);var G=h.getLayoutValObject(l,z.parts);if(G&&G.impliedEdits&&null!==I)for(var Y in G.impliedEdits)E(o.relativeAttr(O,Y),G.impliedEdits[Y]);if(-1!==[\"width\",\"height\"].indexOf(O))if(I){E(\"autosize\",null);var J=\"height\"===O?\"width\":\"height\";E(J,l[J])}else l[O]=t._initialAutoSize[O];else if(\"autosize\"===O)E(\"width\",I?null:l.width),E(\"height\",I?null:l.height);else if(F.match(W))P(F),s(l,B+\"._inputRange\").set(null);else if(F.match(X)){P(F),s(l,B+\"._inputRange\").set(null);var $=s(l,B).get();$._inputDomain&&($._input.domain=$._inputDomain.slice())}else F.match(Z)&&s(l,B+\"._inputDomain\").set(null);if(\"type\"===R){var Q=U,tt=\"linear\"===V.type&&\"log\"===I,et=\"log\"===V.type&&\"linear\"===I;if(tt||et){if(Q&&Q.range)if(V.autorange)tt&&(Q.range=Q.range[1]>Q.range[0]?[1,2]:[2,1]);else{var rt=Q.range[0],nt=Q.range[1];tt?(rt<=0&&nt<=0&&E(B+\".autorange\",!0),rt<=0?rt=nt/1e6:nt<=0&&(nt=rt/1e6),E(B+\".range[0]\",Math.log(rt)/Math.LN10),E(B+\".range[1]\",Math.log(nt)/Math.LN10)):(E(B+\".range[0]\",Math.pow(10,rt)),E(B+\".range[1]\",Math.pow(10,nt)))}else E(B+\".autorange\",!0);Array.isArray(l._subplots.polar)&&l._subplots.polar.length&&l[z.parts[0]]&&\"radialaxis\"===z.parts[1]&&delete l[z.parts[0]]._subplot.viewInitial[\"radialaxis.range\"],u.getComponentMethod(\"annotations\",\"convertCoords\")(t,V,I,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,V,I,E)}else E(B+\".autorange\",!0),E(B+\".range\",null);s(l,B+\"._inputRange\").set(null)}else if(R.match(M)){var it=s(l,O).get(),at=(I||{}).type;at&&\"-\"!==at||(at=\"linear\"),u.getComponentMethod(\"annotations\",\"convertCoords\")(t,it,at,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,it,at,E)}var ot=w.containerArrayMatch(O);if(ot){r=ot.array,n=ot.index;var st=ot.property,lt=G||{editType:\"calc\"};\"\"!==n&&\"\"===st&&(w.isAddVal(I)?S[O]=null:w.isRemoveVal(I)?S[O]=(s(a,r).get()||[])[n]:o.warn(\"unrecognized full object value\",e)),A.update(_,lt),m[r]||(m[r]={});var ct=m[r][n];ct||(ct=m[r][n]={}),ct[st]=I,delete e[O]}else\"reverse\"===R?(U.range?U.range.reverse():(E(B+\".autorange\",!0),U.range=[1,0]),V.autorange?_.calc=!0:_.plot=!0):(l._has(\"scatter-like\")&&l._has(\"regl\")&&\"dragmode\"===O&&(\"lasso\"===I||\"select\"===I)&&\"lasso\"!==H&&\"select\"!==H?_.plot=!0:l._has(\"gl2d\")?_.plot=!0:G?A.update(_,G):_.calc=!0,z.set(I))}}for(r in m){w.applyContainerArrayChanges(t,f(a,r),m[r],_,f)||(_.plot=!0)}var ut=l._axisConstraintGroups||[];for(C in L)for(n=0;n<ut.length;n++){var ht=ut[n];if(ht[C])for(var ft in _.calc=!0,ht)L[ft]||(d.getFromId(t,ft)._constraintShrinkable=!0)}return(K(t)||e.height||e.width)&&(_.plot=!0),(_.plot||_.calc)&&(_.layoutReplot=!0),{flags:_,rangesAltered:L,undoit:S,redoit:T,eventData:v}}function K(t){var e=t._fullLayout,r=e.width,n=e.height;return t.layout.autosize&&f.plotAutoSize(t,t.layout,e),e.width!==r||e.height!==n}function $(t,e,n,i){if(t=o.getGraphDiv(t),k.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);o.isPlainObject(e)||(e={}),o.isPlainObject(n)||(n={}),Object.keys(e).length&&(t.changed=!0),Object.keys(n).length&&(t.changed=!0);var a=k.coerceTraceIndices(t,i),s=V(t,o.extendFlat({},e),a),l=s.flags,u=J(t,o.extendFlat({},n)),h=u.flags;(l.calc||h.calc)&&(t.calcdata=void 0),l.clearAxisTypes&&k.clearAxisTypes(t,a,n);var p=[];h.layoutReplot?p.push(T.layoutReplot):l.fullReplot?p.push(r.plot):(p.push(f.previousPromises),G(t,h,u)||f.supplyDefaults(t),l.style&&p.push(T.doTraceStyle),(l.colorbars||h.colorbars)&&p.push(T.doColorBars),h.legend&&p.push(T.doLegend),h.layoutstyle&&p.push(T.layoutStyles),h.axrange&&Y(p,u.rangesAltered),h.ticks&&p.push(T.doTicksRelayout),h.modebar&&p.push(T.doModeBar),h.camera&&p.push(T.doCamera),p.push(C)),p.push(f.rehover,f.redrag),c.add(t,$,[t,s.undoit,u.undoit,s.traces],$,[t,s.redoit,u.redoit,s.traces]);var d=o.syncOrAsync(p,t);return d&&d.then||(d=Promise.resolve(t)),d.then(function(){return t.emit(\"plotly_update\",{data:s.eventData,layout:u.eventData}),t})}function Q(t){return function(e){e._fullLayout._guiEditing=!0;var r=t.apply(null,arguments);return e._fullLayout._guiEditing=!1,r}}var tt=[{pattern:/^hiddenlabels/,attr:\"legend.uirevision\"},{pattern:/^((x|y)axis\\d*)\\.((auto)?range|title\\.text)/},{pattern:/axis\\d*\\.showspikes$/,attr:\"modebar.uirevision\"},{pattern:/(hover|drag)mode$/,attr:\"modebar.uirevision\"},{pattern:/^(scene\\d*)\\.camera/},{pattern:/^(geo\\d*)\\.(projection|center)/},{pattern:/^(ternary\\d*\\.[abc]axis)\\.(min|title\\.text)$/},{pattern:/^(polar\\d*\\.radialaxis)\\.((auto)?range|angle|title\\.text)/},{pattern:/^(polar\\d*\\.angularaxis)\\.rotation/},{pattern:/^(mapbox\\d*)\\.(center|zoom|bearing|pitch)/},{pattern:/^legend\\.(x|y)$/,attr:\"editrevision\"},{pattern:/^(shapes|annotations)/,attr:\"editrevision\"},{pattern:/^title\\.text$/,attr:\"editrevision\"}],et=[{pattern:/^selectedpoints$/,attr:\"selectionrevision\"},{pattern:/(^|value\\.)visible$/,attr:\"legend.uirevision\"},{pattern:/^dimensions\\[\\d+\\]\\.constraintrange/},{pattern:/^node\\.(x|y|groups)/},{pattern:/^level$/},{pattern:/(^|value\\.)name$/},{pattern:/colorbar\\.title\\.text$/},{pattern:/colorbar\\.(x|y)$/,attr:\"editrevision\"}];function rt(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=t.match(n.pattern);if(i)return{head:i[1],attr:n.attr}}}function nt(t,e){var r=s(e,t).get();if(void 0!==r)return r;var n=t.split(\".\");for(n.pop();n.length>1;)if(n.pop(),void 0!==(r=s(e,n.join(\".\")+\".uirevision\").get()))return r;return e.uirevision}function it(t,e){for(var r=0;r<e.length;r++)if(e[r]._fullInput.uid===t)return r;return-1}function at(t,e,r){for(var n=0;n<e.length;n++)if(e[n].uid===t)return n;return!e[r]||e[r].uid?-1:r}function ot(t,e){var r=o.isPlainObject(t),n=Array.isArray(t);return r||n?(r&&o.isPlainObject(e)||n&&Array.isArray(e))&&JSON.stringify(t)===JSON.stringify(e):t===e}function st(t,e,r,n){var i,a,l,c=n.getValObject,u=n.flags,h=n.immutable,f=n.inArray,p=n.arrayIndex;function d(){var t=i.editType;f&&-1!==t.indexOf(\"arraydraw\")?o.pushUnique(u.arrays[f],p):(A.update(u,i),\"none\"!==t&&u.nChanges++,n.transition&&i.anim&&u.nChangesAnim++,(W.test(l)||X.test(l))&&(u.rangesAltered[r[0]]=1),Z.test(l)&&s(e,\"_inputDomain\").set(null),\"datarevision\"===a&&(u.newDataRevision=1))}function g(t){return\"data_array\"===t.valType||t.arrayOk}for(a in t){if(u.calc&&!n.transition)return;var v=t[a],m=e[a],y=r.concat(a);if(l=y.join(\".\"),\"_\"!==a.charAt(0)&&\"function\"!=typeof v&&v!==m){if((\"tick0\"===a||\"dtick\"===a)&&\"geo\"!==r[0]){var x=e.tickmode;if(\"auto\"===x||\"array\"===x||!x)continue}if((\"range\"!==a||!e.autorange)&&(\"zmin\"!==a&&\"zmax\"!==a||\"contourcarpet\"!==e.type)&&(i=c(y))&&(!i._compareAsJSON||JSON.stringify(v)!==JSON.stringify(m))){var b,_=i.valType,w=g(i),k=Array.isArray(v),T=Array.isArray(m);if(k&&T){var M=\"_input_\"+a,S=t[M],E=e[M];if(Array.isArray(S)&&S===E)continue}if(void 0===m)w&&k?u.calc=!0:d();else if(i._isLinkedToArray){var C=[],L=!1;f||(u.arrays[a]=C);var P=Math.min(v.length,m.length),O=Math.max(v.length,m.length);if(P!==O){if(\"arraydraw\"!==i.editType){d();continue}L=!0}for(b=0;b<P;b++)st(v[b],m[b],y.concat(b),o.extendFlat({inArray:a,arrayIndex:b},n));if(L)for(b=P;b<O;b++)C.push(b)}else!_&&o.isPlainObject(v)?st(v,m,y,n):w?k&&T?(h&&(u.calc=!0),(h||n.newDataRevision)&&d()):k!==T?u.calc=!0:d():k&&T&&v.length===m.length&&String(v)===String(m)||d()}}}for(a in e)if(!(a in t||\"_\"===a.charAt(0)||\"function\"==typeof e[a])){if(g(i=c(r.concat(a)))&&Array.isArray(e[a]))return void(u.calc=!0);d()}}function lt(t){var e=n.select(t),r=t._fullLayout;if(r._container=e.selectAll(\".plot-container\").data([0]),r._container.enter().insert(\"div\",\":first-child\").classed(\"plot-container\",!0).classed(\"plotly\",!0),r._paperdiv=r._container.selectAll(\".svg-container\").data([0]),r._paperdiv.enter().append(\"div\").classed(\"svg-container\",!0).style(\"position\",\"relative\"),r._glcontainer=r._paperdiv.selectAll(\".gl-container\").data([{}]),r._glcontainer.enter().append(\"div\").classed(\"gl-container\",!0),r._paperdiv.selectAll(\".main-svg\").remove(),r._paperdiv.select(\".modebar-container\").remove(),r._paper=r._paperdiv.insert(\"svg\",\":first-child\").classed(\"main-svg\",!0),r._toppaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),r._modebardiv=r._paperdiv.append(\"div\"),r._hoverpaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),!r._uid){var i={};n.selectAll(\"defs\").each(function(){this.id&&(i[this.id.split(\"-\")[1]]=1)}),r._uid=o.randstr(i)}r._paperdiv.selectAll(\".main-svg\").attr(y.svgAttrs),r._defs=r._paper.append(\"defs\").attr(\"id\",\"defs-\"+r._uid),r._clips=r._defs.append(\"g\").classed(\"clips\",!0),r._topdefs=r._toppaper.append(\"defs\").attr(\"id\",\"topdefs-\"+r._uid),r._topclips=r._topdefs.append(\"g\").classed(\"clips\",!0),r._bgLayer=r._paper.append(\"g\").classed(\"bglayer\",!0),r._draggers=r._paper.append(\"g\").classed(\"draglayer\",!0);var a=r._paper.append(\"g\").classed(\"layer-below\",!0);r._imageLowerLayer=a.append(\"g\").classed(\"imagelayer\",!0),r._shapeLowerLayer=a.append(\"g\").classed(\"shapelayer\",!0),r._cartesianlayer=r._paper.append(\"g\").classed(\"cartesianlayer\",!0),r._polarlayer=r._paper.append(\"g\").classed(\"polarlayer\",!0),r._ternarylayer=r._paper.append(\"g\").classed(\"ternarylayer\",!0),r._geolayer=r._paper.append(\"g\").classed(\"geolayer\",!0),r._funnelarealayer=r._paper.append(\"g\").classed(\"funnelarealayer\",!0),r._pielayer=r._paper.append(\"g\").classed(\"pielayer\",!0),r._sunburstlayer=r._paper.append(\"g\").classed(\"sunburstlayer\",!0),r._indicatorlayer=r._toppaper.append(\"g\").classed(\"indicatorlayer\",!0),r._glimages=r._paper.append(\"g\").classed(\"glimages\",!0);var s=r._toppaper.append(\"g\").classed(\"layer-above\",!0);r._imageUpperLayer=s.append(\"g\").classed(\"imagelayer\",!0),r._shapeUpperLayer=s.append(\"g\").classed(\"shapelayer\",!0),r._infolayer=r._toppaper.append(\"g\").classed(\"infolayer\",!0),r._menulayer=r._toppaper.append(\"g\").classed(\"menulayer\",!0),r._zoomlayer=r._toppaper.append(\"g\").classed(\"zoomlayer\",!0),r._hoverlayer=r._hoverpaper.append(\"g\").classed(\"hoverlayer\",!0),r._modebardiv.classed(\"modebar-container\",!0).style(\"position\",\"absolute\").style(\"top\",\"0px\").style(\"right\",\"0px\"),t.emit(\"plotly_framework\")}r.animate=function(t,e,r){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before animating it. For more details, see https://plot.ly/javascript/animations/\");var n=t._transitionData;n._frameQueue||(n._frameQueue=[]);var i=(r=f.supplyAnimationDefaults(r)).transition,a=r.frame;function s(t){return Array.isArray(i)?t>=i.length?i[0]:i[t]:i}function l(t){return Array.isArray(a)?t>=a.length?a[0]:a[t]:a}function c(t,e){var r=0;return function(){if(t&&++r===e)return t()}}return void 0===n._frameWaitingCnt&&(n._frameWaitingCnt=0),new Promise(function(a,u){function h(){n._currentFrame&&n._currentFrame.onComplete&&n._currentFrame.onComplete();var e=n._currentFrame=n._frameQueue.shift();if(e){var r=e.name?e.name.toString():null;t._fullLayout._currentFrame=r,n._lastFrameAt=Date.now(),n._timeToNext=e.frameOpts.duration,f.transition(t,e.frame.data,e.frame.layout,k.coerceTraceIndices(t,e.frame.traces),e.frameOpts,e.transitionOpts).then(function(){e.onComplete&&e.onComplete()}),t.emit(\"plotly_animatingframe\",{name:r,frame:e.frame,animation:{frame:e.frameOpts,transition:e.transitionOpts}})}else t.emit(\"plotly_animated\"),window.cancelAnimationFrame(n._animationRaf),n._animationRaf=null}function p(){t.emit(\"plotly_animating\"),n._lastFrameAt=-1/0,n._timeToNext=0,n._runningTransitions=0,n._currentFrame=null;var e=function(){n._animationRaf=window.requestAnimationFrame(e),Date.now()-n._lastFrameAt>n._timeToNext&&h()};e()}var d,g,v=0;function m(t){return Array.isArray(i)?v>=i.length?t.transitionOpts=i[v]:t.transitionOpts=i[0]:t.transitionOpts=i,v++,t}var y=[],x=null==e,b=Array.isArray(e);if(x||b||!o.isPlainObject(e)){if(x||-1!==[\"string\",\"number\"].indexOf(typeof e))for(d=0;d<n._frames.length;d++)(g=n._frames[d])&&(x||String(g.group)===String(e))&&y.push({type:\"byname\",name:String(g.name),data:m({name:g.name})});else if(b)for(d=0;d<e.length;d++){var _=e[d];-1!==[\"number\",\"string\"].indexOf(typeof _)?(_=String(_),y.push({type:\"byname\",name:_,data:m({name:_})})):o.isPlainObject(_)&&y.push({type:\"object\",data:m(o.extendFlat({},_))})}}else y.push({type:\"object\",data:m(o.extendFlat({},e))});for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&!n._frameHash[g.data.name])return o.warn('animate failure: frame not found: \"'+g.data.name+'\"'),void u();-1!==[\"next\",\"immediate\"].indexOf(r.mode)&&function(){if(0!==n._frameQueue.length){for(;n._frameQueue.length;){var e=n._frameQueue.pop();e.onInterrupt&&e.onInterrupt()}t.emit(\"plotly_animationinterrupted\",[])}}(),\"reverse\"===r.direction&&y.reverse();var w=t._fullLayout._currentFrame;if(w&&r.fromcurrent){var T=-1;for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&g.name===w){T=d;break}if(T>0&&T<y.length-1){var A=[];for(d=0;d<y.length;d++)g=y[d],(\"byname\"!==y[d].type||d>T)&&A.push(g);y=A}}y.length>0?function(e){if(0!==e.length){for(var i=0;i<e.length;i++){var o;o=\"byname\"===e[i].type?f.computeFrame(t,e[i].name):e[i].data;var h=l(i),d=s(i);d.duration=Math.min(d.duration,h.duration);var g={frame:o,name:e[i].name,frameOpts:h,transitionOpts:d};i===e.length-1&&(g.onComplete=c(a,2),g.onInterrupt=u),n._frameQueue.push(g)}\"immediate\"===r.mode&&(n._lastFrameAt=-1/0),n._animationRaf||p()}}(y):(t.emit(\"plotly_animated\"),a())})},r.addFrames=function(t,e,r){if(t=o.getGraphDiv(t),null==e)return Promise.resolve();if(!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before adding frames. For more details, see https://plot.ly/javascript/animations/\");var n,i,a,s,l=t._transitionData._frames,u=t._transitionData._frameHash;if(!Array.isArray(e))throw new Error(\"addFrames failure: frameList must be an Array of frame definitions\"+e);var h=l.length+2*e.length,p=[],d={};for(n=e.length-1;n>=0;n--)if(o.isPlainObject(e[n])){var g=e[n].name,v=(u[g]||d[g]||{}).name,m=e[n].name,y=u[v]||d[v];v&&m&&\"number\"==typeof m&&y&&S<E&&(S++,o.warn('addFrames: overwriting frame \"'+(u[v]||d[v]).name+'\" with a frame whose name of type \"number\" also equates to \"'+v+'\". This is valid but may potentially lead to unexpected behavior since all plotly.js frame names are stored internally as strings.'),S===E&&o.warn(\"addFrames: This API call has yielded too many of these warnings. For the rest of this call, further warnings about numeric frame names will be suppressed.\")),d[g]={name:g},p.push({frame:f.supplyFrameDefaults(e[n]),index:r&&void 0!==r[n]&&null!==r[n]?r[n]:h+n})}p.sort(function(t,e){return t.index>e.index?-1:t.index<e.index?1:0});var x=[],b=[],_=l.length;for(n=p.length-1;n>=0;n--){if(\"number\"==typeof(i=p[n].frame).name&&o.warn(\"Warning: addFrames accepts frames with numeric names, but the numbers areimplicitly cast to strings\"),!i.name)for(;u[i.name=\"frame \"+t._transitionData._counter++];);if(u[i.name]){for(a=0;a<l.length&&(l[a]||{}).name!==i.name;a++);x.push({type:\"replace\",index:a,value:i}),b.unshift({type:\"replace\",index:a,value:l[a]})}else s=Math.max(0,Math.min(p[n].index,_)),x.push({type:\"insert\",index:s,value:i}),b.unshift({type:\"delete\",index:s}),_++}var w=f.modifyFrames,k=f.modifyFrames,T=[t,b],A=[t,x];return c&&c.add(t,w,T,k,A),f.modifyFrames(t,x)},r.deleteFrames=function(t,e){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);var r,n,i=t._transitionData._frames,a=[],s=[];if(!e)for(e=[],r=0;r<i.length;r++)e.push(r);for((e=e.slice()).sort(),r=e.length-1;r>=0;r--)n=e[r],a.push({type:\"delete\",index:n}),s.unshift({type:\"insert\",index:n,value:i[n]});var l=f.modifyFrames,u=f.modifyFrames,h=[t,s],p=[t,a];return c&&c.add(t,l,h,u,p),f.modifyFrames(t,a)},r.addTraces=function t(e,n,i){e=o.getGraphDiv(e);var a,s,l=[],u=r.deleteTraces,h=t,f=[e,l],p=[e,n];for(function(t,e,r){var n,i;if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"traces must be defined.\");for(Array.isArray(e)||(e=[e]),n=0;n<e.length;n++)if(\"object\"!=typeof(i=e[n])||Array.isArray(i)||null===i)throw new Error(\"all values in traces array must be non-array objects\");if(\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&r.length!==e.length)throw new Error(\"if indices is specified, traces.length must equal indices.length\")}(e,n,i),Array.isArray(n)||(n=[n]),n=n.map(function(t){return o.extendFlat({},t)}),k.cleanData(n),a=0;a<n.length;a++)e.data.push(n[a]);for(a=0;a<n.length;a++)l.push(-n.length+a);if(\"undefined\"==typeof i)return s=r.redraw(e),c.add(e,u,f,h,p),s;Array.isArray(i)||(i=[i]);try{D(e,l,i)}catch(t){throw e.data.splice(e.data.length-n.length,n.length),t}return c.startSequence(e),c.add(e,u,f,h,p),s=r.moveTraces(e,l,i),c.stopSequence(e),s},r.deleteTraces=function t(e,n){e=o.getGraphDiv(e);var i,a,s=[],l=r.addTraces,u=t,h=[e,s,n],f=[e,n];if(\"undefined\"==typeof n)throw new Error(\"indices must be an integer or array of integers.\");for(Array.isArray(n)||(n=[n]),I(e,n,\"indices\"),(n=z(n,e.data.length-1)).sort(o.sorterDes),i=0;i<n.length;i+=1)a=e.data.splice(n[i],1)[0],s.push(a);var p=r.redraw(e);return c.add(e,l,h,u,f),p},r.extendTraces=function t(e,n,i,a){var s=R(e=o.getGraphDiv(e),n,i,a,function(t,e,r){var n,i;if(o.isTypedArray(t))if(r<0){var a=new t.constructor(0),s=F(t,e);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(l)),i.set(t),i.set(e.subarray(0,l),t.length)}else{var c=r-e.length,u=t.length-c;n.set(t.subarray(u)),n.set(e,c),i.set(t.subarray(0,u))}else n=t.concat(e),i=r>=0&&r<n.length?n.splice(0,n.length-r):[];return[n,i]}),l=r.redraw(e),u=[e,s.update,i,s.maxPoints];return c.add(e,r.prependTraces,u,t,arguments),l},r.moveTraces=function t(e,n,i){var a,s=[],l=[],u=t,h=t,f=[e=o.getGraphDiv(e),i,n],p=[e,n,i];if(D(e,n,i),n=Array.isArray(n)?n:[n],\"undefined\"==typeof i)for(i=[],a=0;a<n.length;a++)i.push(-n.length+a);for(i=Array.isArray(i)?i:[i],n=z(n,e.data.length-1),i=z(i,e.data.length-1),a=0;a<e.data.length;a++)-1===n.indexOf(a)&&s.push(e.data[a]);for(a=0;a<n.length;a++)l.push({newIndex:i[a],trace:e.data[n[a]]});for(l.sort(function(t,e){return t.newIndex-e.newIndex}),a=0;a<l.length;a+=1)s.splice(l[a].newIndex,0,l[a].trace);e.data=s;var d=r.redraw(e);return c.add(e,u,f,h,p),d},r.prependTraces=function t(e,n,i,a){var s=R(e=o.getGraphDiv(e),n,i,a,function(t,e,r){var n,i;if(o.isTypedArray(t))if(r<=0){var a=new t.constructor(0),s=F(e,t);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(0,l)),i.set(e.subarray(l)),i.set(t,l)}else{var c=r-e.length;n.set(e),n.set(t.subarray(0,c),e.length),i.set(t.subarray(c))}else n=e.concat(t),i=r>=0&&r<n.length?n.splice(r,n.length):[];return[n,i]}),l=r.redraw(e),u=[e,s.update,i,s.maxPoints];return c.add(e,r.extendTraces,u,t,arguments),l},r.newPlot=function(t,e,n,i){return t=o.getGraphDiv(t),f.cleanPlot([],{},t._fullData||[],t._fullLayout||{}),f.purge(t),r.plot(t,e,n,i)},r.plot=function(t,e,i,a){var s;if(t=o.getGraphDiv(t),l.init(t),o.isPlainObject(e)){var c=e;e=c.data,i=c.layout,a=c.config,s=c.frames}if(!1===l.triggerHandler(t,\"plotly_beforeplot\",[e,i,a]))return Promise.reject();e||i||o.isPlotDiv(t)||o.warn(\"Calling Plotly.plot as if redrawing but this container doesn't yet have a plot.\",t),O(t,a),i||(i={}),n.select(t).classed(\"js-plotly-plot\",!0),g.makeTester(),Array.isArray(t._promises)||(t._promises=[]);var h=0===(t.data||[]).length&&Array.isArray(e);Array.isArray(e)&&(k.cleanData(e),h?t.data=e:t.data.push.apply(t.data,e),t.empty=!1),t.layout&&!h||(t.layout=k.cleanLayout(i)),f.supplyDefaults(t);var v=t._fullLayout,y=v._has(\"cartesian\");if(!v._has(\"polar\")&&e&&e[0]&&e[0].r)return o.log(\"Legacy polar charts are deprecated!\"),function(t,e,r){var i=n.select(t).selectAll(\".plot-container\").data([0]);i.enter().insert(\"div\",\":first-child\").classed(\"plot-container plotly\",!0);var a=i.selectAll(\".svg-container\").data([0]);a.enter().append(\"div\").classed(\"svg-container\",!0).style(\"position\",\"relative\"),a.html(\"\"),e&&(t.data=e),r&&(t.layout=r),p.manager.fillLayout(t),a.style({width:t._fullLayout.width+\"px\",height:t._fullLayout.height+\"px\"}),t.framework=p.manager.framework(t),t.framework({data:t.data,layout:t.layout},a.node()),t.framework.setUndoPoint();var s=t.framework.svg(),l=1,c=t._fullLayout.title?t._fullLayout.title.text:\"\";\"\"!==c&&c||(l=0);var u=function(){this.call(x.convertToTspans,t)},h=s.select(\".title-group text\").call(u);if(t._context.edits.titleText){var d=o._(t,\"Click to enter Plot title\");c&&c!==d||(l=.2,h.attr({\"data-unformatted\":d}).text(d).style({opacity:l}).on(\"mouseover.opacity\",function(){n.select(this).transition().duration(100).style(\"opacity\",1)}).on(\"mouseout.opacity\",function(){n.select(this).transition().duration(1e3).style(\"opacity\",0)}));var g=function(){this.call(x.makeEditable,{gd:t}).on(\"edit\",function(e){t.framework({layout:{title:{text:e}}}),this.text(e).call(u),this.call(g)}).on(\"cancel\",function(){var t=this.attr(\"data-unformatted\");this.text(t).call(u)})};h.call(g)}return t._context.setBackground(t,t._fullLayout.paper_bgcolor),f.addLinks(t),Promise.resolve()}(t,e,i);v._replotting=!0,h&&lt(t),t.framework!==lt&&(t.framework=lt,lt(t)),g.initGradients(t),h&&d.saveShowSpikeInitial(t);var b=!t.calcdata||t.calcdata.length!==(t._fullData||[]).length;b&&f.doCalcdata(t);for(var _=0;_<t.calcdata.length;_++)t.calcdata[_][0].trace=t._fullData[_];t._context.responsive?t._responsiveChartHandler||(t._responsiveChartHandler=function(){o.isHidden(t)||f.resize(t)},window.addEventListener(\"resize\",t._responsiveChartHandler)):o.clearResponsive(t);var w=o.extendFlat({},v._size),A=0;function M(){return f.clearAutoMarginIds(t),T.drawMarginPushers(t),d.allowAutoMargin(t),f.doAutoMargin(t),f.previousPromises(t)}function S(){t._transitioning||(T.doAutoRangeAndConstraints(t),h&&d.saveRangeInitial(t),u.getComponentMethod(\"rangeslider\",\"calcAutorange\")(t))}var E=[f.previousPromises,function(){if(s)return r.addFrames(t,s)},function e(){for(var r=v._basePlotModules,n=0;n<r.length;n++)r[n].drawFramework&&r[n].drawFramework(t);if(!v._glcanvas&&v._has(\"gl\")&&(v._glcanvas=v._glcontainer.selectAll(\".gl-canvas\").data([{key:\"contextLayer\",context:!0,pick:!1},{key:\"focusLayer\",context:!1,pick:!1},{key:\"pickLayer\",context:!1,pick:!0}],function(t){return t.key}),v._glcanvas.enter().append(\"canvas\").attr(\"class\",function(t){return\"gl-canvas gl-canvas-\"+t.key.replace(\"Layer\",\"\")}).style({position:\"absolute\",top:0,left:0,overflow:\"visible\",\"pointer-events\":\"none\"})),v._glcanvas){v._glcanvas.attr(\"width\",v.width).attr(\"height\",v.height);var i=v._glcanvas.data()[0].regl;if(i&&(Math.floor(v.width)!==i._gl.drawingBufferWidth||Math.floor(v.height)!==i._gl.drawingBufferHeight)){var a=\"WebGL context buffer and canvas dimensions do not match due to browser/WebGL bug.\";if(!A)return o.log(a+\" Clearing graph and plotting again.\"),f.cleanPlot([],{},t._fullData,v),f.supplyDefaults(t),v=t._fullLayout,f.doCalcdata(t),A++,e();o.error(a)}}return\"h\"===v.modebar.orientation?v._modebardiv.style(\"height\",null).style(\"width\",\"100%\"):v._modebardiv.style(\"width\",null).style(\"height\",v.height+\"px\"),f.previousPromises(t)},M,function(){if(f.didMarginChange(w,v._size))return o.syncOrAsync([M,T.layoutStyles],t)}];y&&E.push(function(){if(b)return o.syncOrAsync([u.getComponentMethod(\"shapes\",\"calcAutorange\"),u.getComponentMethod(\"annotations\",\"calcAutorange\"),S],t);S()}),E.push(T.layoutStyles),y&&E.push(function(){return d.draw(t,h?\"\":\"redraw\")}),E.push(T.drawData,T.finalDraw,m,f.addLinks,f.rehover,f.redrag,f.doAutoMargin,f.previousPromises);var L=o.syncOrAsync(E,t);return L&&L.then||(L=Promise.resolve()),L.then(function(){return C(t),t})},r.purge=function(t){var e=(t=o.getGraphDiv(t))._fullLayout||{},r=t._fullData||[];return f.cleanPlot([],{},r,e),f.purge(t),l.purge(t),e._container&&e._container.remove(),delete t._context,t},r.react=function(t,e,n,i){var a,l,c=(t=o.getGraphDiv(t))._fullData,p=t._fullLayout;if(o.isPlotDiv(t)&&c&&p){if(o.isPlainObject(e)){var d=e;e=d.data,n=d.layout,i=d.config,a=d.frames}var g=!1;if(i){var v=o.extendDeep({},t._context);t._context=void 0,O(t,i),g=function t(e,r){var n;for(n in e)if(\"_\"!==n.charAt(0)){var i=e[n],a=r[n];if(i!==a)if(o.isPlainObject(i)&&o.isPlainObject(a)){if(t(i,a))return!0}else{if(!Array.isArray(i)||!Array.isArray(a))return!0;if(i.length!==a.length)return!0;for(var s=0;s<i.length;s++)if(i[s]!==a[s]){if(!o.isPlainObject(i[s])||!o.isPlainObject(a[s]))return!0;if(t(i[s],a[s]))return!0}}}}(v,t._context)}t.data=e||[],k.cleanData(t.data),t.layout=n||{},k.cleanLayout(t.layout),function(t,e,r,n){var i,a,l,c,u,h,f,p,d=n._preGUI,g=[],v={};for(i in d){if(u=rt(i,tt)){if(a=u.attr||u.head+\".uirevision\",(c=(l=s(n,a).get())&&nt(a,e))&&c===l&&(null===(h=d[i])&&(h=void 0),ot(p=(f=s(e,i)).get(),h))){void 0===p&&\"autorange\"===i.substr(i.length-9)&&g.push(i.substr(0,i.length-10)),f.set(N(s(n,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i);delete d[i],\"range[\"===i.substr(i.length-8,6)&&(v[i.substr(0,i.length-9)]=1)}for(var m=0;m<g.length;m++){var y=g[m];if(v[y]){var x=s(e,y).get();x&&delete x.autorange}}var b=n._tracePreGUI;for(var _ in b){var w,k=b[_],T=null;for(i in k){if(!T){var A=it(_,r);if(A<0){delete b[_];break}var M=at(_,t,(w=r[A]._fullInput).index);if(M<0){delete b[_];break}T=t[M]}if(u=rt(i,et)){if(u.attr?c=(l=s(n,u.attr).get())&&nt(u.attr,e):(l=w.uirevision,void 0===(c=T.uirevision)&&(c=e.uirevision)),c&&c===l&&(null===(h=k[i])&&(h=void 0),ot(p=(f=s(T,i)).get(),h))){f.set(N(s(w,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i+\" in trace uid \"+_);delete k[i]}}}(t.data,t.layout,c,p),f.supplyDefaults(t,{skipUpdateCalc:!0});var m=t._fullData,y=t._fullLayout,x=void 0===y.datarevision,b=y.transition,_=function(t,e,r,n,i){var a=A.layoutFlags();return a.arrays={},a.rangesAltered={},a.nChanges=0,a.nChangesAnim=0,st(e,r,[],{getValObject:function(t){return h.getLayoutValObject(r,t)},flags:a,immutable:n,transition:i,gd:t}),(a.plot||a.calc)&&(a.layoutReplot=!0),i&&a.nChanges&&a.nChangesAnim&&(a.anim=a.nChanges===a.nChangesAnim?\"all\":\"some\"),a}(t,p,y,x,b),w=_.newDataRevision,M=function(t,e,r,n,i,a){var o=e.length===r.length;if(!i&&!o)return{fullReplot:!0,calc:!0};var s,l,c=A.traceFlags();c.arrays={},c.nChanges=0,c.nChangesAnim=0;var u={getValObject:function(t){var e=h.getTraceValObject(l,t);return!l._module.animatable&&e.anim&&(e.anim=!1),e},flags:c,immutable:n,transition:i,newDataRevision:a,gd:t},p={};for(s=0;s<e.length;s++)if(r[s]){if(l=r[s]._fullInput,f.hasMakesDataTransform(l)&&(l=r[s]),p[l.uid])continue;p[l.uid]=1,st(e[s]._fullInput,l,[],u)}return(c.calc||c.plot)&&(c.fullReplot=!0),i&&c.nChanges&&c.nChangesAnim&&(c.anim=c.nChanges===c.nChangesAnim&&o?\"all\":\"some\"),c}(t,c,m,x,b,w);K(t)&&(_.layoutReplot=!0),M.calc||_.calc?t.calcdata=void 0:f.supplyDefaultsUpdateCalc(t.calcdata,m);var S=[];if(a&&(t._transitionData={},f.createTransitionData(t),S.push(function(){return r.addFrames(t,a)})),y.transition&&!g&&(M.anim||_.anim))f.doCalcdata(t),T.doAutoRangeAndConstraints(t),S.push(function(){return f.transitionFromReact(t,M,_,p)});else if(M.fullReplot||_.layoutReplot||g)t._fullLayout._skipDefaults=!0,S.push(r.plot);else{for(var E in _.arrays){var L=_.arrays[E];if(L.length){var P=u.getComponentMethod(E,\"drawOne\");if(P!==o.noop)for(var z=0;z<L.length;z++)P(t,L[z]);else{var I=u.getComponentMethod(E,\"draw\");if(I===o.noop)throw new Error(\"cannot draw components: \"+E);I(t)}}}S.push(f.previousPromises),M.style&&S.push(T.doTraceStyle),(M.colorbars||_.colorbars)&&S.push(T.doColorBars),_.legend&&S.push(T.doLegend),_.layoutstyle&&S.push(T.layoutStyles),_.axrange&&Y(S),_.ticks&&S.push(T.doTicksRelayout),_.modebar&&S.push(T.doModeBar),_.camera&&S.push(T.doCamera),S.push(C)}S.push(f.rehover,f.redrag),(l=o.syncOrAsync(S,t))&&l.then||(l=Promise.resolve(t))}else l=r.newPlot(t,e,n,i);return l.then(function(){return t.emit(\"plotly_react\",{data:e,layout:n}),t})},r.redraw=function(t){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);return k.cleanData(t.data),k.cleanLayout(t.layout),t.calcdata=void 0,r.plot(t).then(function(){return t.emit(\"plotly_redraw\"),t})},r.relayout=H,r.restyle=B,r.setPlotConfig=function(t){return o.extendFlat(_,t)},r.update=$,r._guiRelayout=Q(H),r._guiRestyle=Q(B),r._guiUpdate=Q($),r._storeDirectGUIEdit=function(t,e,r){for(var n in r)U(n,s(t,n).get(),r[n],e)}},{\"../components/color\":593,\"../components/drawing\":614,\"../constants/xmlns_namespaces\":696,\"../lib\":719,\"../lib/events\":709,\"../lib/queue\":734,\"../lib/svg_text_utils\":743,\"../plots/cartesian/axes\":767,\"../plots/cartesian/constants\":773,\"../plots/cartesian/graph_interact\":776,\"../plots/cartesian/select\":784,\"../plots/plots\":828,\"../plots/polar/legacy\":836,\"../registry\":847,\"./edit_types\":750,\"./helpers\":751,\"./manage_arrays\":753,\"./plot_config\":755,\"./plot_schema\":756,\"./subroutines\":758,d3:163,\"fast-isnumeric\":225,\"has-hover\":410}],755:[function(t,e,r){\"use strict\";var n={staticPlot:{valType:\"boolean\",dflt:!1},plotlyServerURL:{valType:\"string\",dflt:\"https://plot.ly\"},editable:{valType:\"boolean\",dflt:!1},edits:{annotationPosition:{valType:\"boolean\",dflt:!1},annotationTail:{valType:\"boolean\",dflt:!1},annotationText:{valType:\"boolean\",dflt:!1},axisTitleText:{valType:\"boolean\",dflt:!1},colorbarPosition:{valType:\"boolean\",dflt:!1},colorbarTitleText:{valType:\"boolean\",dflt:!1},legendPosition:{valType:\"boolean\",dflt:!1},legendText:{valType:\"boolean\",dflt:!1},shapePosition:{valType:\"boolean\",dflt:!1},titleText:{valType:\"boolean\",dflt:!1}},autosizable:{valType:\"boolean\",dflt:!1},responsive:{valType:\"boolean\",dflt:!1},fillFrame:{valType:\"boolean\",dflt:!1},frameMargins:{valType:\"number\",dflt:0,min:0,max:.5},scrollZoom:{valType:\"flaglist\",flags:[\"cartesian\",\"gl3d\",\"geo\",\"mapbox\"],extras:[!0,!1],dflt:\"gl3d+geo+mapbox\"},doubleClick:{valType:\"enumerated\",values:[!1,\"reset\",\"autosize\",\"reset+autosize\"],dflt:\"reset+autosize\"},doubleClickDelay:{valType:\"number\",dflt:300,min:0},showAxisDragHandles:{valType:\"boolean\",dflt:!0},showAxisRangeEntryBoxes:{valType:\"boolean\",dflt:!0},showTips:{valType:\"boolean\",dflt:!0},showLink:{valType:\"boolean\",dflt:!1},linkText:{valType:\"string\",dflt:\"Edit chart\",noBlank:!0},sendData:{valType:\"boolean\",dflt:!0},showSources:{valType:\"any\",dflt:!1},displayModeBar:{valType:\"enumerated\",values:[\"hover\",!0,!1],dflt:\"hover\"},showSendToCloud:{valType:\"boolean\",dflt:!1},showEditInChartStudio:{valType:\"boolean\",dflt:!1},modeBarButtonsToRemove:{valType:\"any\",dflt:[]},modeBarButtonsToAdd:{valType:\"any\",dflt:[]},modeBarButtons:{valType:\"any\",dflt:!1},toImageButtonOptions:{valType:\"any\",dflt:{}},displaylogo:{valType:\"boolean\",dflt:!0},watermark:{valType:\"boolean\",dflt:!1},plotGlPixelRatio:{valType:\"number\",dflt:2,min:1,max:4},setBackground:{valType:\"any\",dflt:\"transparent\"},topojsonURL:{valType:\"string\",noBlank:!0,dflt:\"https://cdn.plot.ly/\"},mapboxAccessToken:{valType:\"string\",dflt:null},logging:{valType:\"boolean\",dflt:1},queueLength:{valType:\"integer\",min:0,dflt:0},globalTransforms:{valType:\"any\",dflt:[]},locale:{valType:\"string\",dflt:\"en-US\"},locales:{valType:\"any\",dflt:{}}},i={};!function t(e,r){for(var n in e){var i=e[n];i.valType?r[n]=i.dflt:(r[n]||(r[n]={}),t(i,r[n]))}}(n,i),e.exports={configAttributes:n,dfltConfig:i}},{}],756:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=t(\"../plots/attributes\"),o=t(\"../plots/layout_attributes\"),s=t(\"../plots/frame_attributes\"),l=t(\"../plots/animation_attributes\"),c=t(\"./plot_config\").configAttributes,u=t(\"../plots/polar/legacy/area_attributes\"),h=t(\"../plots/polar/legacy/axis_attributes\"),f=t(\"./edit_types\"),p=i.extendFlat,d=i.extendDeepAll,g=i.isPlainObject,v=i.isArrayOrTypedArray,m=i.nestedProperty,y=i.valObjectMeta,x=\"_isSubplotObj\",b=\"_isLinkedToArray\",_=[x,b,\"_arrayAttrRegexps\",\"_deprecated\"];function w(t,e,r){if(!t)return!1;if(t._isLinkedToArray)if(k(e[r]))r++;else if(r<e.length)return!1;for(;r<e.length;r++){var n=t[e[r]];if(!g(n))break;if(t=n,r===e.length-1)break;if(t._isLinkedToArray){if(!k(e[++r]))return!1}else if(\"info_array\"===t.valType){var i=e[++r];if(!k(i))return!1;var a=t.items;if(Array.isArray(a)){if(i>=a.length)return!1;if(2===t.dimensions){if(r++,e.length===r)return t;var o=e[r];if(!k(o))return!1;t=a[i][o]}else t=a[i]}else t=a}}return t}function k(t){return t===Math.round(t)&&t>=0}function T(t){return function(t){r.crawl(t,function(t,e,n){r.isValObject(t)?\"data_array\"===t.valType?(t.role=\"data\",n[e+\"src\"]={valType:\"string\",editType:\"none\"}):!0===t.arrayOk&&(n[e+\"src\"]={valType:\"string\",editType:\"none\"}):g(t)&&(t.role=\"object\")})}(t),function(t){r.crawl(t,function(t,e,r){if(!t)return;var n=t[b];if(!n)return;delete t[b],r[e]={items:{}},r[e].items[n]=t,r[e].role=\"object\"})}(t),function(t){!function t(e){for(var r in e)if(g(e[r]))t(e[r]);else if(Array.isArray(e[r]))for(var n=0;n<e[r].length;n++)t(e[r][n]);else e[r]instanceof RegExp&&(e[r]=e[r].toString())}(t)}(t),t}function A(t,e,r){var n=m(t,r),i=d({},e.layoutAttributes);i[x]=!0,n.set(i)}function M(t,e,r){var n=m(t,r);n.set(d(n.get()||{},e))}r.IS_SUBPLOT_OBJ=x,r.IS_LINKED_TO_ARRAY=b,r.DEPRECATED=\"_deprecated\",r.UNDERSCORE_ATTRS=_,r.get=function(){var t={};n.allTypes.concat(\"area\").forEach(function(e){t[e]=function(t){var e,i;\"area\"===t?(e={attributes:u},i={}):(e=n.modules[t]._module,i=e.basePlotModule);var o={type:null},s=d({},a),l=d({},e.attributes);r.crawl(l,function(t,e,r,n,i){m(s,i).set(void 0),void 0===t&&m(l,i).set(void 0)}),d(o,s),n.traceIs(t,\"noOpacity\")&&delete o.opacity;n.traceIs(t,\"showLegend\")||(delete o.showlegend,delete o.legendgroup);n.traceIs(t,\"noHover\")&&(delete o.hoverinfo,delete o.hoverlabel);e.selectPoints||delete o.selectedpoints;d(o,l),i.attributes&&d(o,i.attributes);o.type=t;var c={meta:e.meta||{},categories:e.categories||{},animatable:Boolean(e.animatable),type:t,attributes:T(o)};if(e.layoutAttributes){var h={};d(h,e.layoutAttributes),c.layoutAttributes=T(h)}e.animatable||r.crawl(c,function(t){r.isValObject(t)&&\"anim\"in t&&delete t.anim});return c}(e)});var e,i={};return Object.keys(n.transformsRegistry).forEach(function(t){i[t]=function(t){var e=n.transformsRegistry[t],r=d({},e.attributes);return Object.keys(n.componentsRegistry).forEach(function(e){var i=n.componentsRegistry[e];i.schema&&i.schema.transforms&&i.schema.transforms[t]&&Object.keys(i.schema.transforms[t]).forEach(function(e){M(r,i.schema.transforms[t][e],e)})}),{attributes:T(r)}}(t)}),{defs:{valObjects:y,metaKeys:_.concat([\"description\",\"role\",\"editType\",\"impliedEdits\"]),editType:{traces:f.traces,layout:f.layout},impliedEdits:{}},traces:t,layout:function(){var t,e,r={};for(t in d(r,o),n.subplotsRegistry)if((e=n.subplotsRegistry[t]).layoutAttributes)if(Array.isArray(e.attr))for(var i=0;i<e.attr.length;i++)A(r,e,e.attr[i]);else{var a=\"subplot\"===e.attr?e.name:e.attr;A(r,e,a)}for(t in r=function(t){return p(t,{radialaxis:h.radialaxis,angularaxis:h.angularaxis}),p(t,h.layout),t}(r),n.componentsRegistry){var s=(e=n.componentsRegistry[t]).schema;if(s&&(s.subplots||s.layout)){var l=s.subplots;if(l&&l.xaxis&&!l.yaxis)for(var c in l.xaxis)delete r.yaxis[c]}else\"colorscale\"===e.name?d(r,e.layoutAttributes):e.layoutAttributes&&M(r,e.layoutAttributes,e.name)}return{layoutAttributes:T(r)}}(),transforms:i,frames:(e={frames:d({},s)},T(e),e.frames),animation:T(l),config:T(c)}},r.crawl=function(t,e,n,i){var a=n||0;i=i||\"\",Object.keys(t).forEach(function(n){var o=t[n];if(-1===_.indexOf(n)){var s=(i?i+\".\":\"\")+n;e(o,n,t,a,s),r.isValObject(o)||g(o)&&\"impliedEdits\"!==n&&r.crawl(o,e,a+1,s)}})},r.isValObject=function(t){return t&&void 0!==t.valType},r.findArrayAttributes=function(t){var e,n,i=[],o=[],s=[];function l(t,r,a,l){o=o.slice(0,l).concat([r]),s=s.slice(0,l).concat([t&&t._isLinkedToArray]),t&&(\"data_array\"===t.valType||!0===t.arrayOk)&&!(\"colorbar\"===o[l-1]&&(\"ticktext\"===r||\"tickvals\"===r))&&function t(e,r,a){var l=e[o[r]];var c=a+o[r];if(r===o.length-1)v(l)&&i.push(n+c);else if(s[r]){if(Array.isArray(l))for(var u=0;u<l.length;u++)g(l[u])&&t(l[u],r+1,c+\"[\"+u+\"].\")}else g(l)&&t(l,r+1,c+\".\")}(e,0,\"\")}e=t,n=\"\",r.crawl(a,l),t._module&&t._module.attributes&&r.crawl(t._module.attributes,l);var c=t.transforms;if(c)for(var u=0;u<c.length;u++){var h=c[u],f=h._module;f&&(n=\"transforms[\"+u+\"].\",e=h,r.crawl(f.attributes,l))}return i},r.getTraceValObject=function(t,e){var r,i,o=e[0],s=1;if(\"transforms\"===o){if(1===e.length)return a.transforms;var l=t.transforms;if(!Array.isArray(l)||!l.length)return!1;var c=e[1];if(!k(c)||c>=l.length)return!1;i=(r=(n.transformsRegistry[l[c].type]||{}).attributes)&&r[e[2]],s=3}else if(\"area\"===t.type)i=u[o];else{var h=t._module;if(h||(h=(n.modules[t.type||a.type.dflt]||{})._module),!h)return!1;if(!(i=(r=h.attributes)&&r[o])){var f=h.basePlotModule;f&&f.attributes&&(i=f.attributes[o])}i||(i=a[o])}return w(i,e,s)},r.getLayoutValObject=function(t,e){return w(function(t,e){var r,i,a,s,l=t._basePlotModules;if(l){var c;for(r=0;r<l.length;r++){if((a=l[r]).attrRegex&&a.attrRegex.test(e)){if(a.layoutAttrOverrides)return a.layoutAttrOverrides;!c&&a.layoutAttributes&&(c=a.layoutAttributes)}var u=a.baseLayoutAttrOverrides;if(u&&e in u)return u[e]}if(c)return c}var f=t._modules;if(f)for(r=0;r<f.length;r++)if((s=f[r].layoutAttributes)&&e in s)return s[e];for(i in n.componentsRegistry){if(\"colorscale\"===(a=n.componentsRegistry[i]).name&&0===e.indexOf(\"coloraxis\"))return a.layoutAttributes[e];if(!a.schema&&e===a.name)return a.layoutAttributes}if(e in o)return o[e];if(\"radialaxis\"===e||\"angularaxis\"===e)return h[e];return h.layout[e]||!1}(t,e[0]),e,1)}},{\"../lib\":719,\"../plots/animation_attributes\":762,\"../plots/attributes\":764,\"../plots/frame_attributes\":794,\"../plots/layout_attributes\":819,\"../plots/polar/legacy/area_attributes\":834,\"../plots/polar/legacy/axis_attributes\":835,\"../registry\":847,\"./edit_types\":750,\"./plot_config\":755}],757:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/attributes\"),a=\"templateitemname\",o={name:{valType:\"string\",editType:\"none\"}};function s(t){return t&&\"string\"==typeof t}function l(t){var e=t.length-1;return\"s\"!==t.charAt(e)&&n.warn(\"bad argument to arrayDefaultKey: \"+t),t.substr(0,t.length-1)+\"defaults\"}o[a]={valType:\"string\",editType:\"calc\"},r.templatedArray=function(t,e){return e._isLinkedToArray=t,e.name=o.name,e[a]=o[a],e},r.traceTemplater=function(t){var e,r,a={};for(e in t)r=t[e],Array.isArray(r)&&r.length&&(a[e]=0);return{newTrace:function(o){var s={type:e=n.coerce(o,{},i,\"type\"),_template:null};if(e in a){r=t[e];var l=a[e]%r.length;a[e]++,s._template=r[l]}return s}}},r.newContainer=function(t,e,r){var i=t._template,a=i&&(i[e]||r&&i[r]);return n.isPlainObject(a)||(a=null),t[e]={_template:a}},r.arrayTemplater=function(t,e,r){var n=t._template,i=n&&n[l(e)],o=n&&n[e];Array.isArray(o)&&o.length||(o=[]);var c={};return{newItem:function(t){var e={name:t.name,_input:t},n=e[a]=t[a];if(!s(n))return e._template=i,e;for(var l=0;l<o.length;l++){var u=o[l];if(u.name===n)return c[n]=1,e._template=u,e}return e[r]=t[r]||!1,e._template=!1,e},defaultItems:function(){for(var t=[],e=0;e<o.length;e++){var r=o[e],n=r.name;if(s(n)&&!c[n]){var i={_template:r,name:n,_input:{_templateitemname:n}};i[a]=r[a],t.push(i),c[n]=1}}return t}}},r.arrayDefaultKey=l,r.arrayEditor=function(t,e,r){var i=(n.nestedProperty(t,e).get()||[]).length,o=r._index,s=o>=i&&(r._input||{})._templateitemname;s&&(o=i);var l,c=e+\"[\"+o+\"]\";function u(){l={},s&&(l[c]={},l[c][a]=s)}function h(t,e){s?n.nestedProperty(l[c],t).set(e):l[c+\".\"+t]=e}function f(){var t=l;return u(),t}return u(),{modifyBase:function(t,e){l[t]=e},modifyItem:h,getUpdateObj:f,applyUpdate:function(e,r){e&&h(e,r);var i=f();for(var a in i)n.nestedProperty(t,a).set(i[a])}}}},{\"../lib\":719,\"../plots/attributes\":764}],758:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../registry\"),a=t(\"../plots/plots\"),o=t(\"../lib\"),s=t(\"../lib/clear_gl_canvases\"),l=t(\"../components/color\"),c=t(\"../components/drawing\"),u=t(\"../components/titles\"),h=t(\"../components/modebar\"),f=t(\"../plots/cartesian/axes\"),p=t(\"../constants/alignment\"),d=t(\"../plots/cartesian/constraints\"),g=d.enforce,v=d.clean,m=t(\"../plots/cartesian/autorange\").doAutoRange,y=\"start\",x=\"middle\",b=\"end\";function _(t,e,r){for(var n=0;n<r.length;n++){var i=r[n][0],a=r[n][1];if(!(i[0]>=t[1]||i[1]<=t[0])&&(a[0]<e[1]&&a[1]>e[0]))return!0}return!1}function w(t){var e,i,a,s,u,d,g=t._fullLayout,v=g._size,m=v.p,y=f.list(t,\"\",!0);if(g._paperdiv.style({width:t._context.responsive&&g.autosize&&!t._context._hasZeroWidth&&!t.layout.width?\"100%\":g.width+\"px\",height:t._context.responsive&&g.autosize&&!t._context._hasZeroHeight&&!t.layout.height?\"100%\":g.height+\"px\"}).selectAll(\".main-svg\").call(c.setSize,g.width,g.height),t._context.setBackground(t,g.paper_bgcolor),r.drawMainTitle(t),h.manage(t),!g._has(\"cartesian\"))return t._promises.length&&Promise.all(t._promises);function x(t,e,r){var n=t._lw/2;return\"x\"===t._id.charAt(0)?e?\"top\"===r?e._offset-m-n:e._offset+e._length+m+n:v.t+v.h*(1-(t.position||0))+n%1:e?\"right\"===r?e._offset+e._length+m+n:e._offset-m-n:v.l+v.w*(t.position||0)+n%1}for(e=0;e<y.length;e++){var b=(s=y[e])._anchorAxis;s._linepositions={},s._lw=c.crispRound(t,s.linewidth,1),s._mainLinePosition=x(s,b,s.side),s._mainMirrorPosition=s.mirror&&b?x(s,b,p.OPPOSITE_SIDE[s.side]):null}var w=[],T=[],M=[],S=1===l.opacity(g.paper_bgcolor)&&1===l.opacity(g.plot_bgcolor)&&g.paper_bgcolor===g.plot_bgcolor;for(i in g._plots)if((a=g._plots[i]).mainplot)a.bg&&a.bg.remove(),a.bg=void 0;else{var E=a.xaxis.domain,C=a.yaxis.domain,L=a.plotgroup;if(_(E,C,M)){var P=L.node(),O=a.bg=o.ensureSingle(L,\"rect\",\"bg\");P.insertBefore(O.node(),P.childNodes[0]),T.push(i)}else L.select(\"rect.bg\").remove(),M.push([E,C]),S||(w.push(i),T.push(i))}var z,I,D,R,F,B,N,j,U,V,q,H,G,Y=g._bgLayer.selectAll(\".bg\").data(w);for(Y.enter().append(\"rect\").classed(\"bg\",!0),Y.exit().remove(),Y.each(function(t){g._plots[t].bg=n.select(this)}),e=0;e<T.length;e++)a=g._plots[T[e]],u=a.xaxis,d=a.yaxis,a.bg&&a.bg.call(c.setRect,u._offset-m,d._offset-m,u._length+2*m,d._length+2*m).call(l.fill,g.plot_bgcolor).style(\"stroke-width\",0);if(!g._hasOnlyLargeSploms)for(i in g._plots){a=g._plots[i],u=a.xaxis,d=a.yaxis;var W,X,Z=a.clipId=\"clip\"+g._uid+i+\"plot\",J=o.ensureSingleById(g._clips,\"clipPath\",Z,function(t){t.classed(\"plotclip\",!0).append(\"rect\")});a.clipRect=J.select(\"rect\").attr({width:u._length,height:d._length}),c.setTranslate(a.plot,u._offset,d._offset),a._hasClipOnAxisFalse?(W=null,X=Z):(W=Z,X=null),c.setClipUrl(a.plot,W,t),a.layerClipId=X}function K(t){return\"M\"+z+\",\"+t+\"H\"+I}function $(t){return\"M\"+u._offset+\",\"+t+\"h\"+u._length}function Q(t){return\"M\"+t+\",\"+j+\"V\"+N}function tt(t){return\"M\"+t+\",\"+d._offset+\"v\"+d._length}function et(t,e,r){if(!t.showline||i!==t._mainSubplot)return\"\";if(!t._anchorAxis)return r(t._mainLinePosition);var n=e(t._mainLinePosition);return t.mirror&&(n+=e(t._mainMirrorPosition)),n}for(i in g._plots){a=g._plots[i],u=a.xaxis,d=a.yaxis;var rt=\"M0,0\";k(u,i)&&(F=A(u,\"left\",d,y),z=u._offset-(F?m+F:0),B=A(u,\"right\",d,y),I=u._offset+u._length+(B?m+B:0),D=x(u,d,\"bottom\"),R=x(u,d,\"top\"),!(G=!u._anchorAxis||i!==u._mainSubplot)||\"allticks\"!==u.mirror&&\"all\"!==u.mirror||(u._linepositions[i]=[D,R]),rt=et(u,K,$),G&&u.showline&&(\"all\"===u.mirror||\"allticks\"===u.mirror)&&(rt+=K(D)+K(R)),a.xlines.style(\"stroke-width\",u._lw+\"px\").call(l.stroke,u.showline?u.linecolor:\"rgba(0,0,0,0)\")),a.xlines.attr(\"d\",rt);var nt=\"M0,0\";k(d,i)&&(q=A(d,\"bottom\",u,y),N=d._offset+d._length+(q?m:0),H=A(d,\"top\",u,y),j=d._offset-(H?m:0),U=x(d,u,\"left\"),V=x(d,u,\"right\"),!(G=!d._anchorAxis||i!==d._mainSubplot)||\"allticks\"!==d.mirror&&\"all\"!==d.mirror||(d._linepositions[i]=[U,V]),nt=et(d,Q,tt),G&&d.showline&&(\"all\"===d.mirror||\"allticks\"===d.mirror)&&(nt+=Q(U)+Q(V)),a.ylines.style(\"stroke-width\",d._lw+\"px\").call(l.stroke,d.showline?d.linecolor:\"rgba(0,0,0,0)\")),a.ylines.attr(\"d\",nt)}return f.makeClipPaths(t),t._promises.length&&Promise.all(t._promises)}function k(t,e){return(t.ticks||t.showline)&&(e===t._mainSubplot||\"all\"===t.mirror||\"allticks\"===t.mirror)}function T(t,e,r){if(!r.showline||!r._lw)return!1;if(\"all\"===r.mirror||\"allticks\"===r.mirror)return!0;var n=r._anchorAxis;if(!n)return!1;var i=p.FROM_BL[e];return r.side===e?n.domain[i]===t.domain[i]:r.mirror&&n.domain[1-i]===t.domain[1-i]}function A(t,e,r,n){if(T(t,e,r))return r._lw;for(var i=0;i<n.length;i++){var a=n[i];if(a._mainAxis===r._mainAxis&&T(t,e,a))return a._lw}return 0}r.layoutStyles=function(t){return o.syncOrAsync([a.doAutoMargin,w],t)},r.drawMainTitle=function(t){var e=t._fullLayout,r=function(t){var e=t.title,r=x;o.isRightAnchor(e)?r=b:o.isLeftAnchor(e)&&(r=y);return r}(e),n=function(t){var e=t.title,r=\"0em\";o.isTopAnchor(e)?r=p.CAP_SHIFT+\"em\":o.isMiddleAnchor(e)&&(r=p.MID_SHIFT+\"em\");return r}(e);u.draw(t,\"gtitle\",{propContainer:e,propName:\"title.text\",placeholder:e._dfltTitle.plot,attributes:{x:function(t,e){var r=t.title,n=t._size,i=0;e===y?i=r.pad.l:e===b&&(i=-r.pad.r);switch(r.xref){case\"paper\":return n.l+n.w*r.x+i;case\"container\":default:return t.width*r.x+i}}(e,r),y:function(t,e){var r=t.title,n=t._size,i=0;\"0em\"!==e&&e?e===p.CAP_SHIFT+\"em\"&&(i=r.pad.t):i=-r.pad.b;if(\"auto\"===r.y)return n.t/2;switch(r.yref){case\"paper\":return n.t+n.h-n.h*r.y+i;case\"container\":default:return t.height-t.height*r.y+i}}(e,n),\"text-anchor\":r,dy:n}})},r.doTraceStyle=function(t){var e,n=t.calcdata,o=[];for(e=0;e<n.length;e++){var l=n[e],c=l[0]||{},u=c.trace||{},h=u._module||{},f=h.arraysToCalcdata;f&&f(l,u);var p=h.editStyle;p&&o.push({fn:p,cd0:c})}if(o.length){for(e=0;e<o.length;e++){var d=o[e];d.fn(t,d.cd0)}s(t),r.redrawReglTraces(t)}return a.style(t),i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doColorBars=function(t){return i.getComponentMethod(\"colorbar\",\"draw\")(t),a.previousPromises(t)},r.layoutReplot=function(t){var e=t.layout;return t.layout=void 0,i.call(\"plot\",t,\"\",e)},r.doLegend=function(t){return i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doTicksRelayout=function(t){return f.draw(t,\"redraw\"),t._fullLayout._hasOnlyLargeSploms&&(i.subplotsRegistry.splom.updateGrid(t),s(t),r.redrawReglTraces(t)),r.drawMainTitle(t),a.previousPromises(t)},r.doModeBar=function(t){var e=t._fullLayout;h.manage(t);for(var r=0;r<e._basePlotModules.length;r++){var n=e._basePlotModules[r].updateFx;n&&n(t)}return a.previousPromises(t)},r.doCamera=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){var i=e[r[n]],a=i._scene,o=i.camera;a.setCamera(o)}},r.drawData=function(t){var e=t._fullLayout;s(t);for(var n=e._basePlotModules,o=0;o<n.length;o++)n[o].plot(t);return r.redrawReglTraces(t),a.style(t),i.getComponentMethod(\"shapes\",\"draw\")(t),i.getComponentMethod(\"annotations\",\"draw\")(t),e._replotting=!1,a.previousPromises(t)},r.redrawReglTraces=function(t){var e=t._fullLayout;if(e._has(\"regl\")){var r,n,i=t._fullData,a=[],s=[];for(e._hasOnlyLargeSploms&&e._splomGrid.draw(),r=0;r<i.length;r++){var l=i[r];!0===l.visible&&0!==l._length&&(\"splom\"===l.type?e._splomScenes[l.uid].draw():\"scattergl\"===l.type?o.pushUnique(a,l.xaxis+l.yaxis):\"scatterpolargl\"===l.type&&o.pushUnique(s,l.subplot))}for(r=0;r<a.length;r++)(n=e._plots[a[r]])._scene&&n._scene.draw();for(r=0;r<s.length;r++)(n=e[s[r]]._subplot)._scene&&n._scene.draw()}},r.doAutoRangeAndConstraints=function(t){for(var e,r,n=t._fullLayout,i=f.list(t,\"\",!0),a=n._axisMatchGroups||[],s=0;s<i.length;s++)e=i[s],v(t,e),m(t,e);g(t);t:for(var l=0;l<a.length;l++){var c,u=a[l],h=null;for(c in u){if(!1===(e=f.getFromId(t,c)).autorange)continue t;r=o.simpleMap(e.range,e.r2l),h?h[0]<h[1]?(h[0]=Math.min(h[0],r[0]),h[1]=Math.max(h[1],r[1])):(h[0]=Math.max(h[0],r[0]),h[1]=Math.min(h[1],r[1])):h=r}for(c in u)(e=f.getFromId(t,c)).range=o.simpleMap(h,e.l2r),e._input.range=e.range.slice(),e.setScale()}},r.finalDraw=function(t){i.getComponentMethod(\"shapes\",\"draw\")(t),i.getComponentMethod(\"images\",\"draw\")(t),i.getComponentMethod(\"annotations\",\"draw\")(t),i.getComponentMethod(\"rangeslider\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t)},r.drawMarginPushers=function(t){i.getComponentMethod(\"legend\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t),i.getComponentMethod(\"sliders\",\"draw\")(t),i.getComponentMethod(\"updatemenus\",\"draw\")(t),i.getComponentMethod(\"colorbar\",\"draw\")(t)}},{\"../components/color\":593,\"../components/drawing\":614,\"../components/modebar\":652,\"../components/titles\":681,\"../constants/alignment\":688,\"../lib\":719,\"../lib/clear_gl_canvases\":704,\"../plots/cartesian/autorange\":766,\"../plots/cartesian/axes\":767,\"../plots/cartesian/constraints\":774,\"../plots/plots\":828,\"../registry\":847,d3:163}],759:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.isPlainObject,a=t(\"./plot_schema\"),o=t(\"../plots/plots\"),s=t(\"../plots/attributes\"),l=t(\"./plot_template\"),c=t(\"./plot_config\").dfltConfig;function u(t,e){t=n.extendDeep({},t);var r,a,o=Object.keys(t).sort();function s(e,r,n){if(i(r)&&i(e))u(e,r);else if(Array.isArray(r)&&Array.isArray(e)){var o=l.arrayTemplater({_template:t},n);for(a=0;a<r.length;a++){var s=r[a],c=o.newItem(s)._template;c&&u(c,s)}var h=o.defaultItems();for(a=0;a<h.length;a++)r.push(h[a]._template);for(a=0;a<r.length;a++)delete r[a].templateitemname}}for(r=0;r<o.length;r++){var c=o[r],f=t[c];if(c in e?s(f,e[c],c):e[c]=f,h(c)===c)for(var p in e){var d=h(p);p===d||d!==c||p in t||s(f,e[p],c)}}}function h(t){return t.replace(/[0-9]+$/,\"\")}function f(t,e,r,a,o){var s=o&&r(o);for(var c in t){var u=t[c],d=p(t,c,a),g=p(t,c,o),v=r(g);if(!v){var m=h(c);m!==c&&(v=r(g=p(t,m,o)))}if((!s||s!==v)&&!(!v||v._noTemplating||\"data_array\"===v.valType||v.arrayOk&&Array.isArray(u)))if(!v.valType&&i(u))f(u,e,r,d,g);else if(v._isLinkedToArray&&Array.isArray(u))for(var y=!1,x=0,b={},_=0;_<u.length;_++){var w=u[_];if(i(w)){var k=w.name;if(k)b[k]||(f(w,e,r,p(u,x,d),p(u,x,g)),x++,b[k]=1);else if(!y){var T=p(t,l.arrayDefaultKey(c),a),A=p(u,x,d);f(w,e,r,A,p(u,x,g));var M=n.nestedProperty(e,A);n.nestedProperty(e,T).set(M.get()),M.set(null),y=!0}}}else{n.nestedProperty(e,d).set(u)}}}function p(t,e,r){return r?Array.isArray(t)?r+\"[\"+e+\"]\":r+\".\"+e:e}function d(t){for(var e=0;e<t.length;e++)if(i(t[e]))return!0}function g(t){var e;switch(t.code){case\"data\":e=\"The template has no key data.\";break;case\"layout\":e=\"The template has no key layout.\";break;case\"missing\":e=t.path?\"There are no templates for item \"+t.path+\" with name \"+t.templateitemname:\"There are no templates for trace \"+t.index+\", of type \"+t.traceType+\".\";break;case\"unused\":e=t.path?\"The template item at \"+t.path+\" was not used in constructing the plot.\":t.dataCount?\"Some of the templates of type \"+t.traceType+\" were not used. The template has \"+t.templateCount+\" traces, the data only has \"+t.dataCount+\" of this type.\":\"The template has \"+t.templateCount+\" traces of type \"+t.traceType+\" but there are none in the data.\";break;case\"reused\":e=\"Some of the templates of type \"+t.traceType+\" were used more than once. The template has \"+t.templateCount+\" traces, the data has \"+t.dataCount+\" of this type.\"}return t.msg=e,t}r.makeTemplate=function(t){t=n.isPlainObject(t)?t:n.getGraphDiv(t),t=n.extendDeep({_context:c},{data:t.data,layout:t.layout}),o.supplyDefaults(t);var e=t.data||[],r=t.layout||{};r._basePlotModules=t._fullLayout._basePlotModules,r._modules=t._fullLayout._modules;var l={data:{},layout:{}};e.forEach(function(t){var e={};f(t,e,function(t,e){return a.getTraceValObject(t,n.nestedProperty({},e).parts)}.bind(null,t));var r=n.coerce(t,{},s,\"type\"),i=l.data[r];i||(i=l.data[r]=[]),i.push(e)}),f(r,l.layout,function(t,e){return a.getLayoutValObject(t,n.nestedProperty({},e).parts)}.bind(null,r)),delete l.layout.template;var h=r.template;if(i(h)){var p,d,g,v,m,y,x=h.layout;i(x)&&u(x,l.layout);var b=h.data;if(i(b)){for(d in l.data)if(g=b[d],Array.isArray(g)){for(y=(m=l.data[d]).length,v=g.length,p=0;p<y;p++)u(g[p%v],m[p]);for(p=y;p<v;p++)m.push(n.extendDeep({},g[p]))}for(d in b)d in l.data||(l.data[d]=n.extendDeep([],b[d]))}}return l},r.validateTemplate=function(t,e){var r=n.extendDeep({},{_context:c,data:t.data,layout:t.layout}),a=r.layout||{};i(e)||(e=a.template||{});var s=e.layout,l=e.data,u=[];r.layout=a,r.layout.template=e,o.supplyDefaults(r);var f=r._fullLayout,v=r._fullData,m={};if(i(s)?(!function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)&&i(e[n])){var a,o=h(n),s=[];for(a=0;a<r.length;a++)s.push(p(e,n,r[a])),o!==n&&s.push(p(e,o,r[a]));for(a=0;a<s.length;a++)m[s[a]]=1;t(e[n],s)}}(f,[\"layout\"]),function t(e,r){for(var n in e)if(-1===n.indexOf(\"defaults\")&&i(e[n])){var a=p(e,n,r);m[a]?t(e[n],a):u.push({code:\"unused\",path:a})}}(s,\"layout\")):u.push({code:\"layout\"}),i(l)){for(var y,x={},b=0;b<v.length;b++){var _=v[b];x[y=_.type]=(x[y]||0)+1,_._fullInput._template||u.push({code:\"missing\",index:_._fullInput.index,traceType:y})}for(y in l){var w=l[y].length,k=x[y]||0;w>k?u.push({code:\"unused\",traceType:y,templateCount:w,dataCount:k}):k>w&&u.push({code:\"reused\",traceType:y,templateCount:w,dataCount:k})}}else u.push({code:\"data\"});if(function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)){var a=e[n],o=p(e,n,r);i(a)?(Array.isArray(e)&&!1===a._template&&a.templateitemname&&u.push({code:\"missing\",path:o,templateitemname:a.templateitemname}),t(a,o)):Array.isArray(a)&&d(a)&&t(a,o)}}({data:v,layout:f},\"\"),u.length)return u.map(g)}},{\"../lib\":719,\"../plots/attributes\":764,\"../plots/plots\":828,\"./plot_config\":755,\"./plot_schema\":756,\"./plot_template\":757}],760:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./plot_api\"),a=t(\"../lib\"),o=t(\"../snapshot/helpers\"),s=t(\"../snapshot/tosvg\"),l=t(\"../snapshot/svgtoimg\"),c={format:{valType:\"enumerated\",values:[\"png\",\"jpeg\",\"webp\",\"svg\"],dflt:\"png\"},width:{valType:\"number\",min:1},height:{valType:\"number\",min:1},scale:{valType:\"number\",min:0,dflt:1},setBackground:{valType:\"any\",dflt:!1},imageDataOnly:{valType:\"boolean\",dflt:!1}};e.exports=function(t,e){var r,u,h,f;function p(t){return!(t in e)||a.validate(e[t],c[t])}if(e=e||{},a.isPlainObject(t)?(r=t.data||[],u=t.layout||{},h=t.config||{},f={}):(t=a.getGraphDiv(t),r=a.extendDeep([],t.data),u=a.extendDeep({},t.layout),h=t._context,f=t._fullLayout||{}),!p(\"width\")&&null!==e.width||!p(\"height\")&&null!==e.height)throw new Error(\"Height and width should be pixel values.\");if(!p(\"format\"))throw new Error(\"Image format is not jpeg, png, svg or webp.\");var d={};function g(t,r){return a.coerce(e,d,c,t,r)}var v=g(\"format\"),m=g(\"width\"),y=g(\"height\"),x=g(\"scale\"),b=g(\"setBackground\"),_=g(\"imageDataOnly\"),w=document.createElement(\"div\");w.style.position=\"absolute\",w.style.left=\"-5000px\",document.body.appendChild(w);var k=a.extendFlat({},u);m?k.width=m:null===e.width&&n(f.width)&&(k.width=f.width),y?k.height=y:null===e.height&&n(f.height)&&(k.height=f.height);var T=a.extendFlat({},h,{_exportedPlot:!0,staticPlot:!0,setBackground:b}),A=o.getRedrawFunc(w);function M(){return new Promise(function(t){setTimeout(t,o.getDelay(w._fullLayout))})}function S(){return new Promise(function(t,e){var r=s(w,v,x),n=w._fullLayout.width,c=w._fullLayout.height;if(i.purge(w),document.body.removeChild(w),\"svg\"===v)return t(_?r:o.encodeSVG(r));var u=document.createElement(\"canvas\");u.id=a.randstr(),l({format:v,width:n,height:c,scale:x,canvas:u,svg:r,promise:!0}).then(t).catch(e)})}return new Promise(function(t,e){i.plot(w,r,k,T).then(A).then(M).then(S).then(function(e){t(function(t){return _?t.replace(o.IMAGE_URL_PREFIX,\"\"):t}(e))}).catch(function(t){e(t)})})}},{\"../lib\":719,\"../snapshot/helpers\":851,\"../snapshot/svgtoimg\":853,\"../snapshot/tosvg\":855,\"./plot_api\":754,\"fast-isnumeric\":225}],761:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/plots\"),a=t(\"./plot_schema\"),o=t(\"./plot_config\").dfltConfig,s=n.isPlainObject,l=Array.isArray,c=n.isArrayOrTypedArray;function u(t,e,r,i,a,o){o=o||[];for(var h=Object.keys(t),f=0;f<h.length;f++){var v=h[f];if(\"transforms\"!==v){var m=o.slice();m.push(v);var y=t[v],x=e[v],b=g(r,v),_=\"info_array\"===(b||{}).valType,w=\"colorscale\"===(b||{}).valType,k=(b||{}).items;if(d(r,v))if(s(y)&&s(x))u(y,x,b,i,a,m);else if(_&&l(y)){y.length>x.length&&i.push(p(\"unused\",a,m.concat(x.length)));var T,A,M,S,E,C=x.length,L=Array.isArray(k);if(L&&(C=Math.min(C,k.length)),2===b.dimensions)for(A=0;A<C;A++)if(l(y[A])){y[A].length>x[A].length&&i.push(p(\"unused\",a,m.concat(A,x[A].length)));var P=x[A].length;for(T=0;T<(L?Math.min(P,k[A].length):P);T++)M=L?k[A][T]:k,S=y[A][T],E=x[A][T],n.validate(S,M)?E!==S&&E!==+S&&i.push(p(\"dynamic\",a,m.concat(A,T),S,E)):i.push(p(\"value\",a,m.concat(A,T),S))}else i.push(p(\"array\",a,m.concat(A),y[A]));else for(A=0;A<C;A++)M=L?k[A]:k,S=y[A],E=x[A],n.validate(S,M)?E!==S&&E!==+S&&i.push(p(\"dynamic\",a,m.concat(A),S,E)):i.push(p(\"value\",a,m.concat(A),S))}else if(b.items&&!_&&l(y)){var O,z,I=k[Object.keys(k)[0]],D=[];for(O=0;O<x.length;O++){var R=x[O]._index||O;if((z=m.slice()).push(R),s(y[R])&&s(x[O])){D.push(R);var F=y[R],B=x[O];s(F)&&!1!==F.visible&&!1===B.visible?i.push(p(\"invisible\",a,z)):u(F,B,I,i,a,z)}}for(O=0;O<y.length;O++)(z=m.slice()).push(O),s(y[O])?-1===D.indexOf(O)&&i.push(p(\"unused\",a,z)):i.push(p(\"object\",a,z,y[O]))}else!s(y)&&s(x)?i.push(p(\"object\",a,m,y)):c(y)||!c(x)||_||w?v in e?n.validate(y,b)?\"enumerated\"===b.valType&&(b.coerceNumber&&y!==+x||y!==x)&&i.push(p(\"dynamic\",a,m,y,x)):i.push(p(\"value\",a,m,y)):i.push(p(\"unused\",a,m,y)):i.push(p(\"array\",a,m,y));else i.push(p(\"schema\",a,m))}}return i}e.exports=function(t,e){var r,c,h=a.get(),f=[],d={_context:n.extendFlat({},o)};l(t)?(d.data=n.extendDeep([],t),r=t):(d.data=[],r=[],f.push(p(\"array\",\"data\"))),s(e)?(d.layout=n.extendDeep({},e),c=e):(d.layout={},c={},arguments.length>1&&f.push(p(\"object\",\"layout\"))),i.supplyDefaults(d);for(var g=d._fullData,v=r.length,m=0;m<v;m++){var y=r[m],x=[\"data\",m];if(s(y)){var b=g[m],_=b.type,w=h.traces[_].attributes;w.type={valType:\"enumerated\",values:[_]},!1===b.visible&&!1!==y.visible&&f.push(p(\"invisible\",x)),u(y,b,w,f,x);var k=y.transforms,T=b.transforms;if(k){l(k)||f.push(p(\"array\",x,[\"transforms\"])),x.push(\"transforms\");for(var A=0;A<k.length;A++){var M=[\"transforms\",A],S=k[A].type;if(s(k[A])){var E=h.transforms[S]?h.transforms[S].attributes:{};E.type={valType:\"enumerated\",values:Object.keys(h.transforms)},u(k[A],T[A],E,f,x,M)}else f.push(p(\"object\",x,M))}}}else f.push(p(\"object\",x))}return u(c,d._fullLayout,function(t,e){for(var r=t.layout.layoutAttributes,i=0;i<e.length;i++){var a=e[i],o=t.traces[a.type],s=o.layoutAttributes;s&&(a.subplot?n.extendFlat(r[o.attributes.subplot.dflt],s):n.extendFlat(r,s))}return r}(h,g),f,\"layout\"),0===f.length?void 0:f};var h={object:function(t,e){return(\"layout\"===t&&\"\"===e?\"The layout argument\":\"data\"===t[0]&&\"\"===e?\"Trace \"+t[1]+\" in the data argument\":f(t)+\"key \"+e)+\" must be linked to an object container\"},array:function(t,e){return(\"data\"===t?\"The data argument\":f(t)+\"key \"+e)+\" must be linked to an array container\"},schema:function(t,e){return f(t)+\"key \"+e+\" is not part of the schema\"},unused:function(t,e,r){var n=s(r)?\"container\":\"key\";return f(t)+n+\" \"+e+\" did not get coerced\"},dynamic:function(t,e,r,n){return[f(t)+\"key\",e,\"(set to '\"+r+\"')\",\"got reset to\",\"'\"+n+\"'\",\"during defaults.\"].join(\" \")},invisible:function(t,e){return(e?f(t)+\"item \"+e:\"Trace \"+t[1])+\" got defaulted to be not visible\"},value:function(t,e,r){return[f(t)+\"key \"+e,\"is set to an invalid value (\"+r+\")\"].join(\" \")}};function f(t){return l(t)?\"In data trace \"+t[1]+\", \":\"In \"+t+\", \"}function p(t,e,r,i,a){var o,s;r=r||\"\",l(e)?(o=e[0],s=e[1]):(o=e,s=null);var c=function(t){if(!l(t))return String(t);for(var e=\"\",r=0;r<t.length;r++){var n=t[r];\"number\"==typeof n?e=e.substr(0,e.length-1)+\"[\"+n+\"]\":e+=n,r<t.length-1&&(e+=\".\")}return e}(r),u=h[t](e,c,i,a);return n.log(u),{code:t,container:o,trace:s,path:r,astr:c,msg:u}}function d(t,e){var r=m(e),n=r.keyMinusId,i=r.id;return!!(n in t&&t[n]._isSubplotObj&&i)||e in t}function g(t,e){return e in t?t[e]:t[m(e).keyMinusId]}var v=n.counterRegex(\"([a-z]+)\");function m(t){var e=t.match(v);return{keyMinusId:e&&e[1],id:e&&e[2]}}},{\"../lib\":719,\"../plots/plots\":828,\"./plot_config\":755,\"./plot_schema\":756}],762:[function(t,e,r){\"use strict\";e.exports={mode:{valType:\"enumerated\",dflt:\"afterall\",values:[\"immediate\",\"next\",\"afterall\"]},direction:{valType:\"enumerated\",values:[\"forward\",\"reverse\"],dflt:\"forward\"},fromcurrent:{valType:\"boolean\",dflt:!1},frame:{duration:{valType:\"number\",min:0,dflt:500},redraw:{valType:\"boolean\",dflt:!0}},transition:{duration:{valType:\"number\",min:0,dflt:500,editType:\"none\"},easing:{valType:\"enumerated\",dflt:\"cubic-in-out\",values:[\"linear\",\"quad\",\"cubic\",\"sin\",\"exp\",\"circle\",\"elastic\",\"back\",\"bounce\",\"linear-in\",\"quad-in\",\"cubic-in\",\"sin-in\",\"exp-in\",\"circle-in\",\"elastic-in\",\"back-in\",\"bounce-in\",\"linear-out\",\"quad-out\",\"cubic-out\",\"sin-out\",\"exp-out\",\"circle-out\",\"elastic-out\",\"back-out\",\"bounce-out\",\"linear-in-out\",\"quad-in-out\",\"cubic-in-out\",\"sin-in-out\",\"exp-in-out\",\"circle-in-out\",\"elastic-in-out\",\"back-in-out\",\"bounce-in-out\"],editType:\"none\"},ordering:{valType:\"enumerated\",values:[\"layout first\",\"traces first\"],dflt:\"layout first\",editType:\"none\"}}}},{}],763:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\");e.exports=function(t,e,r){var a,o,s=r.name,l=r.inclusionAttr||\"visible\",c=e[s],u=n.isArrayOrTypedArray(t[s])?t[s]:[],h=e[s]=[],f=i.arrayTemplater(e,s,l);for(a=0;a<u.length;a++){var p=u[a];n.isPlainObject(p)?o=f.newItem(p):(o=f.newItem({}))[l]=!1,o._index=a,!1!==o[l]&&r.handleItemDefaults(p,o,e,r),h.push(o)}var d=f.defaultItems();for(a=0;a<d.length;a++)(o=d[a])._index=h.length,r.handleItemDefaults({},o,e,r,{}),h.push(o);if(n.isArrayOrTypedArray(c)){var g=Math.min(c.length,h.length);for(a=0;a<g;a++)n.relinkPrivateKeys(h[a],c[a])}return h}},{\"../lib\":719,\"../plot_api/plot_template\":757}],764:[function(t,e,r){\"use strict\";var n=t(\"../components/fx/attributes\");e.exports={type:{valType:\"enumerated\",values:[],dflt:\"scatter\",editType:\"calc+clearAxisTypes\",_noTemplating:!0},visible:{valType:\"enumerated\",values:[!0,!1,\"legendonly\"],dflt:!0,editType:\"calc\"},showlegend:{valType:\"boolean\",dflt:!0,editType:\"style\"},legendgroup:{valType:\"string\",dflt:\"\",editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"style\"},name:{valType:\"string\",editType:\"style\"},uid:{valType:\"string\",editType:\"plot\",anim:!0},ids:{valType:\"data_array\",editType:\"calc\",anim:!0},customdata:{valType:\"data_array\",editType:\"calc\"},meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},selectedpoints:{valType:\"any\",editType:\"calc\"},hoverinfo:{valType:\"flaglist\",flags:[\"x\",\"y\",\"z\",\"text\",\"name\"],extras:[\"all\",\"none\",\"skip\"],arrayOk:!0,dflt:\"all\",editType:\"none\"},hoverlabel:n.hoverlabel,stream:{token:{valType:\"string\",noBlank:!0,strict:!0,editType:\"calc\"},maxpoints:{valType:\"number\",min:0,max:1e4,dflt:500,editType:\"calc\"},editType:\"calc\"},transforms:{_isLinkedToArray:\"transform\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"}}},{\"../components/fx/attributes\":623}],765:[function(t,e,r){\"use strict\";e.exports={xaxis:{valType:\"subplotid\",dflt:\"x\",editType:\"calc+clearAxisTypes\"},yaxis:{valType:\"subplotid\",dflt:\"y\",editType:\"calc+clearAxisTypes\"}}},{}],766:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").FP_SAFE,o=t(\"../../registry\");function s(t,e){var r,n,a=[],o=l(e),s=c(t,e),u=s.min,h=s.max;if(0===u.length||0===h.length)return i.simpleMap(e.range,e.r2l);var f=u[0].val,p=h[0].val;for(r=1;r<u.length&&f===p;r++)f=Math.min(f,u[r].val);for(r=1;r<h.length&&f===p;r++)p=Math.max(p,h[r].val);var d=!1;if(e.range){var g=i.simpleMap(e.range,e.r2l);d=g[1]<g[0]}\"reversed\"===e.autorange&&(d=!0,e.autorange=!0);var v,m,y,x,b,_,w=e.rangemode,k=\"tozero\"===w,T=\"nonnegative\"===w,A=e._length,M=A/10,S=0;for(r=0;r<u.length;r++)for(v=u[r],n=0;n<h.length;n++)(_=(m=h[n]).val-v.val)>0&&((b=A-o(v)-o(m))>M?_/b>S&&(y=v,x=m,S=_/b):_/A>S&&(y={val:v.val,pad:0},x={val:m.val,pad:0},S=_/A));if(f===p){var E=f-1,C=f+1;if(k)if(0===f)a=[0,1];else{var L=(f>0?h:u).reduce(function(t,e){return Math.max(t,o(e))},0),P=f/(1-Math.min(.5,L/A));a=f>0?[0,P]:[P,0]}else a=T?[Math.max(0,E),Math.max(1,C)]:[E,C]}else k?(y.val>=0&&(y={val:0,pad:0}),x.val<=0&&(x={val:0,pad:0})):T&&(y.val-S*o(y)<0&&(y={val:0,pad:0}),x.val<=0&&(x={val:1,pad:0})),S=(x.val-y.val)/(A-o(y)-o(x)),a=[y.val-S*o(y),x.val+S*o(x)];return d&&a.reverse(),i.simpleMap(a,e.l2r||Number)}function l(t){var e=t._length/20;return\"domain\"===t.constrain&&t._inputDomain&&(e*=(t._inputDomain[1]-t._inputDomain[0])/(t.domain[1]-t.domain[0])),function(t){return t.pad+(t.extrapad?e:0)}}function c(t,e){var r,n,i,a=e._id,o=t._fullData,s=t._fullLayout,l=[],c=[];function f(t,e){for(r=0;r<e.length;r++){var o=t[e[r]],s=(o._extremes||{})[a];if(!0===o.visible&&s){for(n=0;n<s.min.length;n++)i=s.min[n],u(l,i.val,i.pad,{extrapad:i.extrapad});for(n=0;n<s.max.length;n++)i=s.max[n],h(c,i.val,i.pad,{extrapad:i.extrapad})}}}return f(o,e._traceIndices),f(s.annotations||[],e._annIndices||[]),f(s.shapes||[],e._shapeIndices||[]),{min:l,max:c}}function u(t,e,r,n){f(t,e,r,n,d)}function h(t,e,r,n){f(t,e,r,n,g)}function f(t,e,r,n,i){for(var a=n.tozero,o=n.extrapad,s=!0,l=0;l<t.length&&s;l++){var c=t[l];if(i(c.val,e)&&c.pad>=r&&(c.extrapad||!o)){s=!1;break}i(e,c.val)&&c.pad<=r&&(o||!c.extrapad)&&(t.splice(l,1),l--)}if(s){var u=a&&0===e;t.push({val:e,pad:u?0:r,extrapad:!u&&o})}}function p(t){return n(t)&&Math.abs(t)<a}function d(t,e){return t<=e}function g(t,e){return t>=e}e.exports={getAutoRange:s,makePadFn:l,doAutoRange:function(t,e){if(e.setScale(),e.autorange){e.range=s(t,e),e._r=e.range.slice(),e._rl=i.simpleMap(e._r,e.r2l);var r=e._input,n={};n[e._attr+\".range\"]=e.range,n[e._attr+\".autorange\"]=e.autorange,o.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,n),r.range=e.range.slice(),r.autorange=e.autorange}var a=e._anchorAxis;if(a&&a.rangeslider){var l=a.rangeslider[e._name];l&&\"auto\"===l.rangemode&&(l.range=s(t,e)),a._input.rangeslider[e._name]=i.extendFlat({},l)}},findExtremes:function(t,e,r){r||(r={});t._m||t.setScale();var i,o,s,l,c,f,d,g,v,m=[],y=[],x=e.length,b=r.padded||!1,_=r.tozero&&(\"linear\"===t.type||\"-\"===t.type),w=\"log\"===t.type,k=!1;function T(t){if(Array.isArray(t))return k=!0,function(e){return Math.max(Number(t[e]||0),0)};var e=Math.max(Number(t||0),0);return function(){return e}}var A=T((t._m>0?r.ppadplus:r.ppadminus)||r.ppad||0),M=T((t._m>0?r.ppadminus:r.ppadplus)||r.ppad||0),S=T(r.vpadplus||r.vpad),E=T(r.vpadminus||r.vpad);if(!k){if(g=1/0,v=-1/0,w)for(i=0;i<x;i++)(o=e[i])<g&&o>0&&(g=o),o>v&&o<a&&(v=o);else for(i=0;i<x;i++)(o=e[i])<g&&o>-a&&(g=o),o>v&&o<a&&(v=o);e=[g,v],x=2}var C={tozero:_,extrapad:b};function L(r){s=e[r],n(s)&&(f=A(r),d=M(r),g=s-E(r),v=s+S(r),w&&g<v/10&&(g=v/10),l=t.c2l(g),c=t.c2l(v),_&&(l=Math.min(0,l),c=Math.max(0,c)),p(l)&&u(m,l,d,C),p(c)&&h(y,c,f,C))}var P=Math.min(6,x);for(i=0;i<P;i++)L(i);for(i=x-1;i>=P;i--)L(i);return{min:m,max:y,opts:r}},concatExtremes:c}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../registry\":847,\"fast-isnumeric\":225}],767:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../components/titles\"),u=t(\"../../components/color\"),h=t(\"../../components/drawing\"),f=t(\"./layout_attributes\"),p=t(\"./clean_ticks\"),d=t(\"../../constants/numerical\"),g=d.ONEAVGYEAR,v=d.ONEAVGMONTH,m=d.ONEDAY,y=d.ONEHOUR,x=d.ONEMIN,b=d.ONESEC,_=d.MINUS_SIGN,w=d.BADNUM,k=t(\"../../constants/alignment\").MID_SHIFT,T=t(\"../../constants/alignment\").LINE_SPACING,A=e.exports={};A.setConvert=t(\"./set_convert\");var M=t(\"./axis_autotype\"),S=t(\"./axis_ids\");A.id2name=S.id2name,A.name2id=S.name2id,A.cleanId=S.cleanId,A.list=S.list,A.listIds=S.listIds,A.getFromId=S.getFromId,A.getFromTrace=S.getFromTrace;var E=t(\"./autorange\");A.getAutoRange=E.getAutoRange,A.findExtremes=E.findExtremes,A.coerceRef=function(t,e,r,n,i,a){var o=n.charAt(n.length-1),l=r._fullLayout._subplots[o+\"axis\"],c=n+\"ref\",u={};return i||(i=l[0]||a),a||(a=i),u[c]={valType:\"enumerated\",values:l.concat(a?[a]:[]),dflt:i},s.coerce(t,e,u,c)},A.coercePosition=function(t,e,r,n,i,a){var o,l;if(\"paper\"===n||\"pixel\"===n)o=s.ensureNumber,l=r(i,a);else{var c=A.getFromId(e,n);l=r(i,a=c.fraction2r(a)),o=c.cleanPos}t[i]=o(l)},A.cleanPosition=function(t,e,r){return(\"paper\"===r||\"pixel\"===r?s.ensureNumber:A.getFromId(e,r).cleanPos)(t)},A.redrawComponents=function(t,e){e=e||A.listIds(t);var r=t._fullLayout;function n(n,i,a,s){for(var l=o.getComponentMethod(n,i),c={},u=0;u<e.length;u++)for(var h=r[A.id2name(e[u])][a],f=0;f<h.length;f++){var p=h[f];if(!c[p]&&(l(t,p),c[p]=1,s))return}}n(\"annotations\",\"drawOne\",\"_annIndices\"),n(\"shapes\",\"drawOne\",\"_shapeIndices\"),n(\"images\",\"draw\",\"_imgIndices\",!0)};var C=A.getDataConversions=function(t,e,r,n){var i,a=\"x\"===r||\"y\"===r||\"z\"===r?r:n;if(Array.isArray(a)){if(i={type:M(n),_categories:[]},A.setConvert(i),\"category\"===i.type)for(var o=0;o<n.length;o++)i.d2c(n[o])}else i=A.getFromTrace(t,e,a);return i?{d2c:i.d2c,c2d:i.c2d}:\"ids\"===a?{d2c:P,c2d:P}:{d2c:L,c2d:L}};function L(t){return+t}function P(t){return String(t)}A.getDataToCoordFunc=function(t,e,r,n){return C(t,e,r,n).d2c},A.counterLetter=function(t){var e=t.charAt(0);return\"x\"===e?\"y\":\"y\"===e?\"x\":void 0},A.minDtick=function(t,e,r,n){-1===[\"log\",\"category\",\"multicategory\"].indexOf(t.type)&&n?void 0===t._minDtick?(t._minDtick=e,t._forceTick0=r):t._minDtick&&((t._minDtick/e+1e-6)%1<2e-6&&((r-t._forceTick0)/e%1+1.000001)%1<2e-6?(t._minDtick=e,t._forceTick0=r):((e/t._minDtick+1e-6)%1>2e-6||((r-t._forceTick0)/t._minDtick%1+1.000001)%1>2e-6)&&(t._minDtick=0)):t._minDtick=0},A.saveRangeInitial=function(t,e){for(var r=A.list(t,\"\",!0),n=!1,i=0;i<r.length;i++){var a=r[i],o=void 0===a._rangeInitial,s=o||!(a.range[0]===a._rangeInitial[0]&&a.range[1]===a._rangeInitial[1]);(o&&!1===a.autorange||e&&s)&&(a._rangeInitial=a.range.slice(),n=!0)}return n},A.saveShowSpikeInitial=function(t,e){for(var r=A.list(t,\"\",!0),n=!1,i=\"on\",a=0;a<r.length;a++){var o=r[a],s=void 0===o._showSpikeInitial,l=s||!(o.showspikes===o._showspikes);(s||e&&l)&&(o._showSpikeInitial=o.showspikes,n=!0),\"on\"!==i||o.showspikes||(i=\"off\")}return t._fullLayout._cartesianSpikesEnabled=i,n},A.autoBin=function(t,e,r,n,a,o){var l,c=s.aggNums(Math.min,null,t),u=s.aggNums(Math.max,null,t);if(\"category\"===e.type||\"multicategory\"===e.type)return{start:c-.5,end:u+.5,size:Math.max(1,Math.round(o)||1),_dataSpan:u-c};if(a||(a=e.calendar),l=\"log\"===e.type?{type:\"linear\",range:[c,u]}:{type:e.type,range:s.simpleMap([c,u],e.c2r,0,a),calendar:a},A.setConvert(l),o=o&&p.dtick(o,l.type))l.dtick=o,l.tick0=p.tick0(void 0,l.type,a);else{var h;if(r)h=(u-c)/r;else{var f=s.distinctVals(t),d=Math.pow(10,Math.floor(Math.log(f.minDiff)/Math.LN10)),g=d*s.roundUp(f.minDiff/d,[.9,1.9,4.9,9.9],!0);h=Math.max(g,2*s.stdev(t)/Math.pow(t.length,n?.25:.4)),i(h)||(h=1)}A.autoTicks(l,h)}var v,y=l.dtick,x=A.tickIncrement(A.tickFirst(l),y,\"reverse\",a);if(\"number\"==typeof y)v=(x=function(t,e,r,n,a){var o=0,s=0,l=0,c=0;function u(e){return(1+100*(e-t)/r.dtick)%100<2}for(var h=0;h<e.length;h++)e[h]%1==0?l++:i(e[h])||c++,u(e[h])&&o++,u(e[h]+r.dtick/2)&&s++;var f=e.length-c;if(l===f&&\"date\"!==r.type)r.dtick<1?t=n-.5*r.dtick:(t-=.5)+r.dtick<n&&(t+=r.dtick);else if(s<.1*f&&(o>.3*f||u(n)||u(a))){var p=r.dtick/2;t+=t+p<n?p:-p}return t}(x,t,l,c,u))+(1+Math.floor((u-x)/y))*y;else for(\"M\"===l.dtick.charAt(0)&&(x=function(t,e,r,n,i){var a=s.findExactDates(e,i);if(a.exactDays>.8){var o=Number(r.substr(1));a.exactYears>.8&&o%12==0?t=A.tickIncrement(t,\"M6\",\"reverse\")+1.5*m:a.exactMonths>.8?t=A.tickIncrement(t,\"M1\",\"reverse\")+15.5*m:t-=m/2;var l=A.tickIncrement(t,r);if(l<=n)return l}return t}(x,t,y,c,a)),v=x,0;v<=u;)v=A.tickIncrement(v,y,!1,a),0;return{start:e.c2r(x,0,a),end:e.c2r(v,0,a),size:y,_dataSpan:u-c}},A.prepTicks=function(t){var e=s.simpleMap(t.range,t.r2l);if(\"auto\"===t.tickmode||!t.dtick){var r,n=t.nticks;n||(\"category\"===t.type||\"multicategory\"===t.type?(r=t.tickfont?1.2*(t.tickfont.size||12):15,n=t._length/r):(r=\"y\"===t._id.charAt(0)?40:80,n=s.constrain(t._length/r,4,9)+1),\"radialaxis\"===t._name&&(n*=2)),\"array\"===t.tickmode&&(n*=100),A.autoTicks(t,Math.abs(e[1]-e[0])/n),t._minDtick>0&&t.dtick<2*t._minDtick&&(t.dtick=t._minDtick,t.tick0=t.l2r(t._forceTick0))}t.tick0||(t.tick0=\"date\"===t.type?\"2000-01-01\":0),\"date\"===t.type&&t.dtick<.1&&(t.dtick=.1),j(t)},A.calcTicks=function(t){A.prepTicks(t);var e=s.simpleMap(t.range,t.r2l);if(\"array\"===t.tickmode)return function(t){var e=t.tickvals,r=t.ticktext,n=new Array(e.length),i=s.simpleMap(t.range,t.r2l),a=1.0001*i[0]-1e-4*i[1],o=1.0001*i[1]-1e-4*i[0],l=Math.min(a,o),c=Math.max(a,o),u=0;Array.isArray(r)||(r=[]);var h=\"category\"===t.type?t.d2l_noadd:t.d2l;\"log\"===t.type&&\"L\"!==String(t.dtick).charAt(0)&&(t.dtick=\"L\"+Math.pow(10,Math.floor(Math.min(t.range[0],t.range[1]))-1));for(var f=0;f<e.length;f++){var p=h(e[f]);p>l&&p<c&&(void 0===r[f]?n[u]=A.tickText(t,p):n[u]=U(t,p,String(r[f])),u++)}u<e.length&&n.splice(u,e.length-u);return n}(t);t._tmin=A.tickFirst(t);var r=1.0001*e[0]-1e-4*e[1],n=1.0001*e[1]-1e-4*e[0],a=e[1]<e[0];if(t._tmin<r!==a)return[];var o=[];\"category\"!==t.type&&\"multicategory\"!==t.type||(n=a?Math.max(-.5,n):Math.min(t._categories.length-.5,n));for(var l=\"log\"===t.type&&!(i(t.dtick)||\"L\"===t.dtick.charAt(0)),c=null,u=Math.max(1e3,t._length||0),h=t._tmin;(a?h>=n:h<=n)&&!(o.length>u||h===c);h=A.tickIncrement(h,t.dtick,a,t.calendar)){c=h;var f=!1;l&&h!==(0|h)&&(f=!0),o.push({minor:f,value:h})}rt(t)&&360===Math.abs(e[1]-e[0])&&o.pop(),t._tmax=(o[o.length-1]||{}).value,t._prevDateHead=\"\",t._inCalcTicks=!0;for(var p=new Array(o.length),d=0;d<o.length;d++)p[d]=A.tickText(t,o[d].value,!1,o[d].minor);return t._inCalcTicks=!1,p};var O=[2,5,10],z=[1,2,3,6,12],I=[1,2,5,10,15,30],D=[1,2,3,7,14],R=[-.046,0,.301,.477,.602,.699,.778,.845,.903,.954,1],F=[-.301,0,.301,.699,1],B=[15,30,45,90,180];function N(t,e,r){return e*s.roundUp(t/e,r)}function j(t){var e=t.dtick;if(t._tickexponent=0,i(e)||\"string\"==typeof e||(e=1),\"category\"!==t.type&&\"multicategory\"!==t.type||(t._tickround=null),\"date\"===t.type){var r=t.r2l(t.tick0),n=t.l2r(r).replace(/(^-|i)/g,\"\"),a=n.length;if(\"M\"===String(e).charAt(0))a>10||\"01-01\"!==n.substr(5)?t._tickround=\"d\":t._tickround=+e.substr(1)%12==0?\"y\":\"m\";else if(e>=m&&a<=10||e>=15*m)t._tickround=\"d\";else if(e>=x&&a<=16||e>=y)t._tickround=\"M\";else if(e>=b&&a<=19||e>=x)t._tickround=\"S\";else{var o=t.l2r(r+e).replace(/^-/,\"\").length;t._tickround=Math.max(a,o)-20,t._tickround<0&&(t._tickround=4)}}else if(i(e)||\"L\"===e.charAt(0)){var s=t.range.map(t.r2d||Number);i(e)||(e=Number(e.substr(1))),t._tickround=2-Math.floor(Math.log(e)/Math.LN10+.01);var l=Math.max(Math.abs(s[0]),Math.abs(s[1])),c=Math.floor(Math.log(l)/Math.LN10+.01);Math.abs(c)>3&&(q(t.exponentformat)&&!H(c)?t._tickexponent=3*Math.round((c-1)/3):t._tickexponent=c)}else t._tickround=null}function U(t,e,r){var n=t.tickfont||{};return{x:e,dx:0,dy:0,text:r||\"\",fontSize:n.size,font:n.family,fontColor:n.color}}A.autoTicks=function(t,e){var r;function n(t){return Math.pow(t,Math.floor(Math.log(e)/Math.LN10))}if(\"date\"===t.type){t.tick0=s.dateTick0(t.calendar);var a=2*e;a>g?(e/=g,r=n(10),t.dtick=\"M\"+12*N(e,r,O)):a>v?(e/=v,t.dtick=\"M\"+N(e,1,z)):a>m?(t.dtick=N(e,m,D),t.tick0=s.dateTick0(t.calendar,!0)):a>y?t.dtick=N(e,y,z):a>x?t.dtick=N(e,x,I):a>b?t.dtick=N(e,b,I):(r=n(10),t.dtick=N(e,r,O))}else if(\"log\"===t.type){t.tick0=0;var o=s.simpleMap(t.range,t.r2l);if(e>.7)t.dtick=Math.ceil(e);else if(Math.abs(o[1]-o[0])<1){var l=1.5*Math.abs((o[1]-o[0])/e);e=Math.abs(Math.pow(10,o[1])-Math.pow(10,o[0]))/l,r=n(10),t.dtick=\"L\"+N(e,r,O)}else t.dtick=e>.3?\"D2\":\"D1\"}else\"category\"===t.type||\"multicategory\"===t.type?(t.tick0=0,t.dtick=Math.ceil(Math.max(e,1))):rt(t)?(t.tick0=0,r=1,t.dtick=N(e,r,B)):(t.tick0=0,r=n(10),t.dtick=N(e,r,O));if(0===t.dtick&&(t.dtick=1),!i(t.dtick)&&\"string\"!=typeof t.dtick){var c=t.dtick;throw t.dtick=1,\"ax.dtick error: \"+String(c)}},A.tickIncrement=function(t,e,r,a){var o=r?-1:1;if(i(e))return t+o*e;var l=e.charAt(0),c=o*Number(e.substr(1));if(\"M\"===l)return s.incrementMonth(t,c,a);if(\"L\"===l)return Math.log(Math.pow(10,t)+c)/Math.LN10;if(\"D\"===l){var u=\"D2\"===e?F:R,h=t+.01*o,f=s.roundUp(s.mod(h,1),u,r);return Math.floor(h)+Math.log(n.round(Math.pow(10,f),1))/Math.LN10}throw\"unrecognized dtick \"+String(e)},A.tickFirst=function(t){var e=t.r2l||Number,r=s.simpleMap(t.range,e),a=r[1]<r[0],o=a?Math.floor:Math.ceil,l=1.0001*r[0]-1e-4*r[1],c=t.dtick,u=e(t.tick0);if(i(c)){var h=o((l-u)/c)*c+u;return\"category\"!==t.type&&\"multicategory\"!==t.type||(h=s.constrain(h,0,t._categories.length-1)),h}var f=c.charAt(0),p=Number(c.substr(1));if(\"M\"===f){for(var d,g,v,m=0,y=u;m<10;){if(((d=A.tickIncrement(y,c,a,t.calendar))-l)*(y-l)<=0)return a?Math.min(y,d):Math.max(y,d);g=(l-(y+d)/2)/(d-y),v=f+(Math.abs(Math.round(g))||1)*p,y=A.tickIncrement(y,v,g<0?!a:a,t.calendar),m++}return s.error(\"tickFirst did not converge\",t),y}if(\"L\"===f)return Math.log(o((Math.pow(10,l)-u)/p)*p+u)/Math.LN10;if(\"D\"===f){var x=\"D2\"===c?F:R,b=s.roundUp(s.mod(l,1),x,a);return Math.floor(l)+Math.log(n.round(Math.pow(10,b),1))/Math.LN10}throw\"unrecognized dtick \"+String(c)},A.tickText=function(t,e,r,n){var a,o=U(t,e),l=\"array\"===t.tickmode,c=r||l,u=t.type,h=\"category\"===u?t.d2l_noadd:t.d2l;if(l&&Array.isArray(t.ticktext)){var f=s.simpleMap(t.range,t.r2l),p=Math.abs(f[1]-f[0])/1e4;for(a=0;a<t.ticktext.length&&!(Math.abs(e-h(t.tickvals[a]))<p);a++);if(a<t.ticktext.length)return o.text=String(t.ticktext[a]),o}function d(n){if(void 0===n)return!0;if(r)return\"none\"===n;var i={first:t._tmin,last:t._tmax}[n];return\"all\"!==n&&e!==i}var g=r?\"never\":\"none\"!==t.exponentformat&&d(t.showexponent)?\"hide\":\"\";if(\"date\"===u?function(t,e,r,n){var a=t._tickround,o=r&&t.hoverformat||A.getTickFormat(t);n&&(a=i(a)?4:{y:\"m\",m:\"d\",d:\"M\",M:\"S\",S:4}[a]);var l,c=s.formatDate(e.x,o,a,t._dateFormat,t.calendar,t._extraFormat),u=c.indexOf(\"\\n\");-1!==u&&(l=c.substr(u+1),c=c.substr(0,u));n&&(\"00:00:00\"===c||\"00:00\"===c?(c=l,l=\"\"):8===c.length&&(c=c.replace(/:00$/,\"\")));l&&(r?\"d\"===a?c+=\", \"+l:c=l+(c?\", \"+c:\"\"):t._inCalcTicks&&l===t._prevDateHead||(c+=\"<br>\"+l,t._prevDateHead=l));e.text=c}(t,o,r,c):\"log\"===u?function(t,e,r,n,a){var o=t.dtick,l=e.x,c=t.tickformat,u=\"string\"==typeof o&&o.charAt(0);\"never\"===a&&(a=\"\");n&&\"L\"!==u&&(o=\"L3\",u=\"L\");if(c||\"L\"===u)e.text=G(Math.pow(10,l),t,a,n);else if(i(o)||\"D\"===u&&s.mod(l+.01,1)<.1){var h=Math.round(l),f=Math.abs(h),p=t.exponentformat;\"power\"===p||q(p)&&H(h)?(e.text=0===h?1:1===h?\"10\":\"10<sup>\"+(h>1?\"\":_)+f+\"</sup>\",e.fontSize*=1.25):(\"e\"===p||\"E\"===p)&&f>2?e.text=\"1\"+p+(h>0?\"+\":_)+f:(e.text=G(Math.pow(10,l),t,\"\",\"fakehover\"),\"D1\"===o&&\"y\"===t._id.charAt(0)&&(e.dy-=e.fontSize/6))}else{if(\"D\"!==u)throw\"unrecognized dtick \"+String(o);e.text=String(Math.round(Math.pow(10,s.mod(l,1)))),e.fontSize*=.75}if(\"D1\"===t.dtick){var d=String(e.text).charAt(0);\"0\"!==d&&\"1\"!==d||(\"y\"===t._id.charAt(0)?e.dx-=e.fontSize/4:(e.dy+=e.fontSize/2,e.dx+=(t.range[1]>t.range[0]?1:-1)*e.fontSize*(l<0?.5:.25)))}}(t,o,0,c,g):\"category\"===u?function(t,e){var r=t._categories[Math.round(e.x)];void 0===r&&(r=\"\");e.text=String(r)}(t,o):\"multicategory\"===u?function(t,e,r){var n=Math.round(e.x),i=t._categories[n]||[],a=void 0===i[1]?\"\":String(i[1]),o=void 0===i[0]?\"\":String(i[0]);r?e.text=o+\" - \"+a:(e.text=a,e.text2=o)}(t,o,r):rt(t)?function(t,e,r,n,i){if(\"radians\"!==t.thetaunit||r)e.text=G(e.x,t,i,n);else{var a=e.x/180;if(0===a)e.text=\"0\";else{var o=function(t){function e(t,e){return Math.abs(t-e)<=1e-6}var r=function(t){var r=1;for(;!e(Math.round(t*r)/r,t);)r*=10;return r}(t),n=t*r,i=Math.abs(function t(r,n){return e(n,0)?r:t(n,r%n)}(n,r));return[Math.round(n/i),Math.round(r/i)]}(a);if(o[1]>=100)e.text=G(s.deg2rad(e.x),t,i,n);else{var l=e.x<0;1===o[1]?1===o[0]?e.text=\"\\u03c0\":e.text=o[0]+\"\\u03c0\":e.text=[\"<sup>\",o[0],\"</sup>\",\"\\u2044\",\"<sub>\",o[1],\"</sub>\",\"\\u03c0\"].join(\"\"),l&&(e.text=_+e.text)}}}}(t,o,r,c,g):function(t,e,r,n,i){\"never\"===i?i=\"\":\"all\"===t.showexponent&&Math.abs(e.x/t.dtick)<1e-6&&(i=\"hide\");e.text=G(e.x,t,i,n)}(t,o,0,c,g),n||(t.tickprefix&&!d(t.showtickprefix)&&(o.text=t.tickprefix+o.text),t.ticksuffix&&!d(t.showticksuffix)&&(o.text+=t.ticksuffix)),\"boundaries\"===t.tickson||t.showdividers){var v=function(e){var r=t.l2p(e);return r>=0&&r<=t._length?e:null};o.xbnd=[v(o.x-.5),v(o.x+t.dtick-.5)]}return o},A.hoverLabelText=function(t,e,r){if(r!==w&&r!==e)return A.hoverLabelText(t,e)+\" - \"+A.hoverLabelText(t,r);var n=\"log\"===t.type&&e<=0,i=A.tickText(t,t.c2l(n?-e:e),\"hover\").text;return n?0===e?\"0\":_+i:i};var V=[\"f\",\"p\",\"n\",\"\\u03bc\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\"];function q(t){return\"SI\"===t||\"B\"===t}function H(t){return t>14||t<-15}function G(t,e,r,n){var a=t<0,o=e._tickround,l=r||e.exponentformat||\"B\",c=e._tickexponent,u=A.getTickFormat(e),h=e.separatethousands;if(n){var f={exponentformat:l,dtick:\"none\"===e.showexponent?e.dtick:i(t)&&Math.abs(t)||1,range:\"none\"===e.showexponent?e.range.map(e.r2d):[0,t||1]};j(f),o=(Number(f._tickround)||0)+4,c=f._tickexponent,e.hoverformat&&(u=e.hoverformat)}if(u)return e._numFormat(u)(t).replace(/-/g,_);var p,d=Math.pow(10,-o)/2;if(\"none\"===l&&(c=0),(t=Math.abs(t))<d)t=\"0\",a=!1;else{if(t+=d,c&&(t*=Math.pow(10,-c),o+=c),0===o)t=String(Math.floor(t));else if(o<0){t=(t=String(Math.round(t))).substr(0,t.length+o);for(var g=o;g<0;g++)t+=\"0\"}else{var v=(t=String(t)).indexOf(\".\")+1;v&&(t=t.substr(0,v+o).replace(/\\.?0+$/,\"\"))}t=s.numSeparate(t,e._separators,h)}c&&\"hide\"!==l&&(q(l)&&H(c)&&(l=\"power\"),p=c<0?_+-c:\"power\"!==l?\"+\"+c:String(c),\"e\"===l||\"E\"===l?t+=l+p:\"power\"===l?t+=\"\\xd710<sup>\"+p+\"</sup>\":\"B\"===l&&9===c?t+=\"B\":q(l)&&(t+=V[c/3+5]));return a?_+t:t}function Y(t,e){var r=t._id.charAt(0),n=t._tickAngles[e]||0,i=s.deg2rad(n),a=Math.sin(i),o=Math.cos(i),l=0,c=0;return t._selections[e].each(function(){var t=J(this),e=h.bBox(t.node()),r=e.width,n=e.height;l=Math.max(l,o*r,a*n),c=Math.max(c,a*r,o*n)}),{x:c,y:l}[r]}function W(t){return[t.text,t.x,t.axInfo,t.font,t.fontSize,t.fontColor].join(\"_\")}function X(t,e){var r,n=t._fullLayout._size,i=e._id.charAt(0),a=e.side;return\"free\"!==e.anchor?r=S.getFromId(t,e.anchor):\"x\"===i?r={_offset:n.t+(1-(e.position||0))*n.h,_length:0}:\"y\"===i&&(r={_offset:n.l+(e.position||0)*n.w,_length:0}),\"top\"===a||\"left\"===a?r._offset:\"bottom\"===a||\"right\"===a?r._offset+r._length:void 0}function Z(t,e){var r=t.l2p(e);return r>1&&r<t._length-1}function J(t){var e=n.select(t),r=e.select(\".text-math-group\");return r.empty()?e.select(\"text\"):r}function K(t){return t._id+\".automargin\"}function $(t){return t._id+\".rangeslider\"}function Q(t,e){for(var r=0;r<e.length;r++)-1===t.indexOf(e[r])&&t.push(e[r])}function tt(t,e,r){var n,i,a=[],o=[],l=t.layout;for(n=0;n<e.length;n++)a.push(A.getFromId(t,e[n]));for(n=0;n<r.length;n++)o.push(A.getFromId(t,r[n]));var c=Object.keys(f),u=[\"anchor\",\"domain\",\"overlaying\",\"position\",\"side\",\"tickangle\",\"editType\"],h=[\"linear\",\"log\"];for(n=0;n<c.length;n++){var p=c[n],d=a[0][p],g=o[0][p],v=!0,m=!1,y=!1;if(\"_\"!==p.charAt(0)&&\"function\"!=typeof d&&-1===u.indexOf(p)){for(i=1;i<a.length&&v;i++){var x=a[i][p];\"type\"===p&&-1!==h.indexOf(d)&&-1!==h.indexOf(x)&&d!==x?m=!0:x!==d&&(v=!1)}for(i=1;i<o.length&&v;i++){var b=o[i][p];\"type\"===p&&-1!==h.indexOf(g)&&-1!==h.indexOf(b)&&g!==b?y=!0:o[i][p]!==g&&(v=!1)}v&&(m&&(l[a[0]._name].type=\"linear\"),y&&(l[o[0]._name].type=\"linear\"),et(l,p,a,o,t._fullLayout._dfltTitle))}}for(n=0;n<t._fullLayout.annotations.length;n++){var _=t._fullLayout.annotations[n];-1!==e.indexOf(_.xref)&&-1!==r.indexOf(_.yref)&&s.swapAttrs(l.annotations[n],[\"?\"])}}function et(t,e,r,n,i){var a,o=s.nestedProperty,l=o(t[r[0]._name],e).get(),c=o(t[n[0]._name],e).get();for(\"title\"===e&&(l&&l.text===i.x&&(l.text=i.y),c&&c.text===i.y&&(c.text=i.x)),a=0;a<r.length;a++)o(t,r[a]._name+\".\"+e).set(c);for(a=0;a<n.length;a++)o(t,n[a]._name+\".\"+e).set(l)}function rt(t){return\"angularaxis\"===t._id}A.getTickFormat=function(t){var e,r,n,i,a,o,s,l;function c(t){return\"string\"!=typeof t?t:Number(t.replace(\"M\",\"\"))*v}function u(t,e){var r=[\"L\",\"D\"];if(typeof t==typeof e){if(\"number\"==typeof t)return t-e;var n=r.indexOf(t.charAt(0)),i=r.indexOf(e.charAt(0));return n===i?Number(t.replace(/(L|D)/g,\"\"))-Number(e.replace(/(L|D)/g,\"\")):n-i}return\"number\"==typeof t?1:-1}function h(t,e){var r=null===e[0],n=null===e[1],i=u(t,e[0])>=0,a=u(t,e[1])<=0;return(r||i)&&(n||a)}if(t.tickformatstops&&t.tickformatstops.length>0)switch(t.type){case\"date\":case\"linear\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&(i=t.dtick,a=n.dtickrange,o=void 0,void 0,void 0,o=c||function(t){return t},s=a[0],l=a[1],(!s&&\"number\"!=typeof s||o(s)<=o(i))&&(!l&&\"number\"!=typeof l||o(l)>=o(i)))){r=n;break}break;case\"log\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&h(t.dtick,n.dtickrange)){r=n;break}}return r?r.value:t.tickformat},A.getSubplots=function(t,e){var r=t._fullLayout._subplots,n=r.cartesian.concat(r.gl2d||[]),i=e?A.findSubplotsWithAxis(n,e):n;return i.sort(function(t,e){var r=t.substr(1).split(\"y\"),n=e.substr(1).split(\"y\");return r[0]===n[0]?+r[1]-+n[1]:+r[0]-+n[0]}),i},A.findSubplotsWithAxis=function(t,e){for(var r=new RegExp(\"x\"===e._id.charAt(0)?\"^\"+e._id+\"y\":e._id+\"$\"),n=[],i=0;i<t.length;i++){var a=t[i];r.test(a)&&n.push(a)}return n},A.makeClipPaths=function(t){var e=t._fullLayout;if(!e._hasOnlyLargeSploms){var r,i,a={_offset:0,_length:e.width,_id:\"\"},o={_offset:0,_length:e.height,_id:\"\"},s=A.list(t,\"x\",!0),l=A.list(t,\"y\",!0),c=[];for(r=0;r<s.length;r++)for(c.push({x:s[r],y:o}),i=0;i<l.length;i++)0===r&&c.push({x:a,y:l[i]}),c.push({x:s[r],y:l[i]});var u=e._clips.selectAll(\".axesclip\").data(c,function(t){return t.x._id+t.y._id});u.enter().append(\"clipPath\").classed(\"axesclip\",!0).attr(\"id\",function(t){return\"clip\"+e._uid+t.x._id+t.y._id}).append(\"rect\"),u.exit().remove(),u.each(function(t){n.select(this).select(\"rect\").attr({x:t.x._offset||0,y:t.y._offset||0,width:t.x._length||1,height:t.y._length||1})})}},A.draw=function(t,e,r){var n=t._fullLayout;\"redraw\"===e&&n._paper.selectAll(\"g.subplot\").each(function(t){var e=t[0],r=n._plots[e],i=r.xaxis,a=r.yaxis;r.xaxislayer.selectAll(\".\"+i._id+\"tick\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"tick2\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick2\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"divider\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"divider\").remove(),r.gridlayer&&r.gridlayer.selectAll(\"path\").remove(),r.zerolinelayer&&r.zerolinelayer.selectAll(\"path\").remove(),n._infolayer.select(\".g-\"+i._id+\"title\").remove(),n._infolayer.select(\".g-\"+a._id+\"title\").remove()});var i=e&&\"redraw\"!==e?e:A.listIds(t);return s.syncOrAsync(i.map(function(e){return function(){if(e){var n=A.getFromId(t,e),i=A.drawOne(t,n,r);return n._r=n.range.slice(),n._rl=s.simpleMap(n._r,n.r2l),i}}}))},A.drawOne=function(t,e,r){var n,i,l;r=r||{},e.setScale();var f=t._fullLayout,p=e._id,d=p.charAt(0),g=A.counterLetter(p),v=e._mainSubplot,m=e._mainLinePosition,y=e._mainMirrorPosition,x=f._plots[v][d+\"axislayer\"],b=e._subplotsWith,_=e._vals=A.calcTicks(e),w=[e.mirror,m,y].join(\"_\");for(n=0;n<_.length;n++)_[n].axInfo=w;if(e.visible){e._selections={},e._tickAngles={};var k,M,S=A.makeTransFn(e);if(\"boundaries\"===e.tickson){var E=function(t,e){var r,n=[],i=function(t,e){var r=t.xbnd[e];null!==r&&n.push(s.extendFlat({},t,{x:r}))};if(e.length){for(r=0;r<e.length;r++)i(e[r],0);i(e[r-1],1)}return n}(0,_);M=A.clipEnds(e,E),k=\"inside\"===e.ticks?M:E}else M=A.clipEnds(e,_),k=\"inside\"===e.ticks?M:_;var C=e._gridVals=M,L=function(t,e){var r,n,i=[],a=function(t,e){var r=t.xbnd[e];null!==r&&i.push(s.extendFlat({},t,{x:r}))};if(t.showdividers&&e.length){for(r=0;r<e.length;r++){var o=e[r];o.text2!==n&&a(o,0),n=o.text2}a(e[r-1],1)}return i}(e,_);if(!f._hasOnlyLargeSploms){var P={};for(n=0;n<b.length;n++){i=b[n];var O=(l=f._plots[i])[g+\"axis\"],z=O._mainAxis._id;if(!P[z]){P[z]=1;var I=\"x\"===d?\"M0,\"+O._offset+\"v\"+O._length:\"M\"+O._offset+\",0h\"+O._length;A.drawGrid(t,e,{vals:C,counterAxis:O,layer:l.gridlayer.select(\".\"+p),path:I,transFn:S}),A.drawZeroLine(t,e,{counterAxis:O,layer:l.zerolinelayer,path:I,transFn:S})}}}var D=A.getTickSigns(e),R=[];if(e.ticks){var F,B,N,j=A.makeTickPath(e,m,D[2]);if(e._anchorAxis&&e.mirror&&!0!==e.mirror?(F=A.makeTickPath(e,y,D[3]),B=j+F):(F=\"\",B=j),e.showdividers&&\"outside\"===e.ticks&&\"boundaries\"===e.tickson){var V={};for(n=0;n<L.length;n++)V[L[n].x]=1;N=function(t){return V[t.x]?F:B}}else N=B;A.drawTicks(t,e,{vals:k,layer:x,path:N,transFn:S}),R=Object.keys(e._linepositions||{})}for(n=0;n<R.length;n++){i=R[n],l=f._plots[i];var q=e._linepositions[i]||[],H=A.makeTickPath(e,q[0],D[0])+A.makeTickPath(e,q[1],D[1]);A.drawTicks(t,e,{vals:k,layer:l[d+\"axislayer\"],path:H,transFn:S})}var G=[];if(G.push(function(){return A.drawLabels(t,e,{vals:_,layer:x,transFn:S,labelFns:A.makeLabelFns(e,m)})}),\"multicategory\"===e.type){var Z=0,J={x:2,y:10}[d],Q=D[2]*(\"inside\"===e.ticks?-1:1);G.push(function(){return Z+=Y(e,p+\"tick\")+J,Z+=e._tickAngles[p+\"tick\"]?e.tickfont.size*T:0,A.drawLabels(t,e,{vals:function(t,e){for(var r=[],n={},i=0;i<e.length;i++){var a=e[i];n[a.text2]?n[a.text2].push(a.x):n[a.text2]=[a.x]}for(var o in n)r.push(U(t,s.interp(n[o],.5),o));return r}(e,_),layer:x,cls:p+\"tick2\",repositionOnUpdate:!0,secondary:!0,transFn:S,labelFns:A.makeLabelFns(e,m+Z*Q)})}),G.push(function(){return Z+=Y(e,p+\"tick2\"),e._labelLength=Z,function(t,e,r){var n=e._id+\"divider\",i=r.vals,a=r.layer.selectAll(\"path.\"+n).data(i,W);a.exit().remove(),a.enter().insert(\"path\",\":first-child\").classed(n,1).classed(\"crisp\",1).call(u.stroke,e.dividercolor).style(\"stroke-width\",h.crispRound(t,e.dividerwidth,1)+\"px\"),a.attr(\"transform\",r.transFn).attr(\"d\",r.path)}(t,e,{vals:L,layer:x,path:A.makeTickPath(e,m,Q,Z),transFn:S})})}var tt=o.getComponentMethod(\"rangeslider\",\"isVisible\")(e);return G.push(function(){if(e.showticklabels){var r=t.getBoundingClientRect(),n=x.node().getBoundingClientRect();e._boundingBox={width:n.width,height:n.height,left:n.left-r.left,right:n.right-r.left,top:n.top-r.top,bottom:n.bottom-r.top}}else{var i,a=f._size;\"x\"===d?(i=\"free\"===e.anchor?a.t+a.h*(1-e.position):a.t+a.h*(1-e._anchorAxis.domain[{bottom:0,top:1}[e.side]]),e._boundingBox={top:i,bottom:i,left:e._offset,right:e._offset+e._length,width:e._length,height:0}):(i=\"free\"===e.anchor?a.l+a.w*e.position:a.l+a.w*e._anchorAxis.domain[{left:0,right:1}[e.side]],e._boundingBox={left:i,right:i,bottom:e._offset+e._length,top:e._offset,height:e._length,width:0})}if(b){for(var o=e._counterSpan=[1/0,-1/0],s=0;s<b.length;s++){var l=f._plots[b[s]][\"x\"===d?\"yaxis\":\"xaxis\"];et(o,[l._offset,l._offset+l._length])}\"free\"===e.anchor&&et(o,\"x\"===d?[e._boundingBox.bottom,e._boundingBox.top]:[e._boundingBox.right,e._boundingBox.left])}},function(){var r,n,i=e.side.charAt(0);if(tt&&(n=o.getComponentMethod(\"rangeslider\",\"autoMarginOpts\")(t,e)),a.autoMargin(t,$(e),n),e.automargin&&(!tt||\"b\"!==i)){r={x:0,y:0,r:0,l:0,t:0,b:0};var s,l,c=e._boundingBox,u=X(t,e);switch(d+i){case\"xb\":s=0,l=c.top-u,r[i]=c.height;break;case\"xt\":s=1,l=u-c.bottom,r[i]=c.height;break;case\"yl\":s=0,l=u-c.right,r[i]=c.width;break;case\"yr\":s=1,l=c.left-u,r[i]=c.width}if(r[g]=\"free\"===e.anchor?e.position:e._anchorAxis.domain[s],r[i]>0&&(r[i]+=l),e.title.text!==f._dfltTitle[d]&&(r[i]+=e.title.font.size),\"x\"===d&&c.width>0){var h=c.right-(e._offset+e._length);h>0&&(r.x=1,r.r=h);var p=e._offset-c.left;p>0&&(r.x=0,r.l=p)}else if(\"y\"===d&&c.height>0){var v=c.bottom-(e._offset+e._length);v>0&&(r.y=0,r.b=v);var m=e._offset-c.top;m>0&&(r.y=1,r.t=m)}}a.autoMargin(t,K(e),r)}),r.skipTitle||tt&&e._boundingBox&&\"bottom\"===e.side||G.push(function(){return function(t,e){var r,n=t._fullLayout,i=e._id,a=i.charAt(0),o=e.title.font.size;if(\"multicategory\"===e.type)r=e._labelLength;else{r=10+1.5*o+(e.linewidth?e.linewidth-1:0)}var s,l,u,f,p=X(t,e);\"x\"===a?(l=e._offset+e._length/2,u=\"top\"===e.side?-r-o*(e.showticklabels?1:0):r+o*(e.showticklabels?1.5:.5),u+=p):(u=e._offset+e._length/2,l=\"right\"===e.side?r+o*(e.showticklabels?1:.5):-r-o*(e.showticklabels?.5:0),l+=p,s={rotate:\"-90\",offset:0});if(\"multicategory\"!==e.type){var d=e._selections[e._id+\"tick\"];if(f={selection:d,side:e.side},d&&d.node()&&d.node().parentNode){var g=h.getTranslate(d.node().parentNode);f.offsetLeft=g.x,f.offsetTop=g.y}}return c.draw(t,i+\"title\",{propContainer:e,propName:e._name+\".title.text\",placeholder:n._dfltTitle[a],avoid:f,transform:s,attributes:{x:l,y:u,\"text-anchor\":\"middle\"}})}(t,e)}),s.syncOrAsync(G)}function et(t,e){t[0]=Math.min(t[0],e[0]),t[1]=Math.max(t[1],e[1])}},A.getTickSigns=function(t){var e=t._id.charAt(0),r={x:\"top\",y:\"right\"}[e],n=t.side===r?1:-1,i=[-1,1,n,-n];return\"inside\"!==t.ticks==(\"x\"===e)&&(i=i.map(function(t){return-t})),i},A.makeTransFn=function(t){var e=t._id.charAt(0),r=t._offset;return\"x\"===e?function(e){return\"translate(\"+(r+t.l2p(e.x))+\",0)\"}:function(e){return\"translate(0,\"+(r+t.l2p(e.x))+\")\"}},A.makeTickPath=function(t,e,r,n){n=void 0!==n?n:t.ticklen;var i=t._id.charAt(0),a=(t.linewidth||1)/2;return\"x\"===i?\"M0,\"+(e+a*r)+\"v\"+n*r:\"M\"+(e+a*r)+\",0h\"+n*r},A.makeLabelFns=function(t,e,r){var n=t._id.charAt(0),a=\"boundaries\"!==t.tickson&&\"outside\"===t.ticks,o=0,l=0;if(a&&(o+=t.ticklen),r&&\"outside\"===t.ticks){var c=s.deg2rad(r);o=t.ticklen*Math.cos(c)+1,l=t.ticklen*Math.sin(c)}t.showticklabels&&(a||t.showline)&&(o+=.2*t.tickfont.size);var u,h,f,p,d={labelStandoff:o+=(t.linewidth||1)/2,labelShift:l};return\"x\"===n?(p=\"bottom\"===t.side?1:-1,u=l*p,h=e+o*p,f=\"bottom\"===t.side?1:-.2,d.xFn=function(t){return t.dx+u},d.yFn=function(t){return t.dy+h+t.fontSize*f},d.anchorFn=function(t,e){return i(e)&&0!==e&&180!==e?e*p<0?\"end\":\"start\":\"middle\"},d.heightFn=function(e,r,n){return r<-60||r>60?-.5*n:\"top\"===t.side?-n:0}):\"y\"===n&&(p=\"right\"===t.side?1:-1,u=o,h=-l*p,f=90===Math.abs(t.tickangle)?.5:0,d.xFn=function(t){return t.dx+e+(u+t.fontSize*f)*p},d.yFn=function(t){return t.dy+h+t.fontSize*k},d.anchorFn=function(e,r){return i(r)&&90===Math.abs(r)?\"middle\":\"right\"===t.side?\"start\":\"end\"},d.heightFn=function(e,r,n){return(r*=\"left\"===t.side?1:-1)<-30?-n:r<30?-.5*n:0}),d},A.drawTicks=function(t,e,r){r=r||{};var n=e._id+\"tick\",i=r.layer.selectAll(\"path.\"+n).data(e.ticks?r.vals:[],W);i.exit().remove(),i.enter().append(\"path\").classed(n,1).classed(\"ticks\",1).classed(\"crisp\",!1!==r.crisp).call(u.stroke,e.tickcolor).style(\"stroke-width\",h.crispRound(t,e.tickwidth,1)+\"px\").attr(\"d\",r.path),i.attr(\"transform\",r.transFn)},A.drawGrid=function(t,e,r){r=r||{};var n=e._id+\"grid\",i=r.vals,a=r.counterAxis;if(!1===e.showgrid)i=[];else if(a&&A.shouldShowZeroLine(t,e,a))for(var o=\"array\"===e.tickmode,s=0;s<i.length;s++){var l=i[s].x;if(o?!l:Math.abs(l)<e.dtick/100){if(i=i.slice(0,s).concat(i.slice(s+1)),!o)break;s--}}var c=r.layer.selectAll(\"path.\"+n).data(i,W);c.exit().remove(),c.enter().append(\"path\").classed(n,1).classed(\"crisp\",!1!==r.crisp),e._gw=h.crispRound(t,e.gridwidth,1),c.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(u.stroke,e.gridcolor||\"#ddd\").style(\"stroke-width\",e._gw+\"px\"),\"function\"==typeof r.path&&c.attr(\"d\",r.path)},A.drawZeroLine=function(t,e,r){r=r||r;var n=e._id+\"zl\",i=A.shouldShowZeroLine(t,e,r.counterAxis),a=r.layer.selectAll(\"path.\"+n).data(i?[{x:0,id:e._id}]:[]);a.exit().remove(),a.enter().append(\"path\").classed(n,1).classed(\"zl\",1).classed(\"crisp\",!1!==r.crisp).each(function(){r.layer.selectAll(\"path\").sort(function(t,e){return S.idSort(t.id,e.id)})}),a.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(u.stroke,e.zerolinecolor||u.defaultLine).style(\"stroke-width\",h.crispRound(t,e.zerolinewidth,e._gw||1)+\"px\")},A.drawLabels=function(t,e,r){r=r||{};var a=e._id,o=a.charAt(0),c=r.cls||a+\"tick\",u=r.vals,f=r.labelFns,p=r.secondary?0:e.tickangle,d=(e._tickAngles||{})[c],g=r.layer.selectAll(\"g.\"+c).data(e.showticklabels?u:[],W),v=[];function m(t,e){t.each(function(t){var a=n.select(this),o=a.select(\".text-math-group\"),s=f.anchorFn(t,e),c=r.transFn.call(a.node(),t)+(i(e)&&0!=+e?\" rotate(\"+e+\",\"+f.xFn(t)+\",\"+(f.yFn(t)-t.fontSize/2)+\")\":\"\"),u=l.lineCount(a),p=T*t.fontSize,d=f.heightFn(t,i(e)?+e:0,(u-1)*p);if(d&&(c+=\" translate(0, \"+d+\")\"),o.empty())a.select(\"text\").attr({transform:c,\"text-anchor\":s});else{var g=h.bBox(o.node()).width*{end:-.5,start:.5}[s];o.attr(\"transform\",c+(g?\"translate(\"+g+\",0)\":\"\"))}})}g.enter().append(\"g\").classed(c,1).append(\"text\").attr(\"text-anchor\",\"middle\").each(function(e){var r=n.select(this),i=t._promises.length;r.call(l.positionText,f.xFn(e),f.yFn(e)).call(h.font,e.font,e.fontSize,e.fontColor).text(e.text).call(l.convertToTspans,t),t._promises[i]?v.push(t._promises.pop().then(function(){m(r,p)})):m(r,p)}),g.exit().remove(),r.repositionOnUpdate&&g.each(function(t){n.select(this).select(\"text\").call(l.positionText,f.xFn(t),f.yFn(t))}),m(g,d||p),e._selections&&(e._selections[c]=g);var y=s.syncOrAsync([function(){return v.length&&Promise.all(v)},function(){m(g,p);var t=null;if(u.length&&\"x\"===o&&!i(p)&&(\"log\"!==e.type||\"D\"!==String(e.dtick).charAt(0))){t=0;var n,a=0,l=[];if(g.each(function(t){a=Math.max(a,t.fontSize);var r=e.l2p(t.x),n=J(this),i=h.bBox(n.node());l.push({top:0,bottom:10,height:10,left:r-i.width/2,right:r+i.width/2+2,width:i.width+2})}),\"boundaries\"!==e.tickson&&!e.showdividers||r.secondary){var f=u.length,d=Math.abs((u[f-1].x-u[0].x)*e._m)/(f-1)<2.5*a||\"multicategory\"===e.type;for(n=0;n<l.length-1;n++)if(s.bBoxIntersect(l[n],l[n+1])){t=d?90:30;break}}else{var v=2;for(e.ticks&&(v+=e.tickwidth/2),n=0;n<l.length;n++){var y=u[n].xbnd,x=l[n];if(null!==y[0]&&x.left-e.l2p(y[0])<v||null!==y[1]&&e.l2p(y[1])-x.right<v){t=90;break}}}t&&m(g,t)}e._tickAngles&&(e._tickAngles[c]=null===t?i(p)?p:0:t)}]);return y&&y.then&&t._promises.push(y),y},A.shouldShowZeroLine=function(t,e,r){var n=s.simpleMap(e.range,e.r2l);return n[0]*n[1]<=0&&e.zeroline&&(\"linear\"===e.type||\"-\"===e.type)&&e._gridVals.length&&(Z(e,0)||!function(t,e,r,n){var i=r._mainAxis;if(!i)return;var a=t._fullLayout,o=e._id.charAt(0),s=A.counterLetter(e._id),l=e._offset+(Math.abs(n[0])<Math.abs(n[1])==(\"x\"===o)?0:e._length);function c(t){if(!t.showline||!t.linewidth)return!1;var r=Math.max((t.linewidth+e.zerolinewidth)/2,1);function n(t){return\"number\"==typeof t&&Math.abs(t-l)<r}if(n(t._mainLinePosition)||n(t._mainMirrorPosition))return!0;var i=t._linepositions||{};for(var a in i)if(n(i[a][0])||n(i[a][1]))return!0}var u=a._plots[r._mainSubplot];if(!(u.mainplotinfo||u).overlays.length)return c(r);for(var h=A.list(t,s),f=0;f<h.length;f++){var p=h[f];if(p._mainAxis===i&&c(p))return!0}}(t,e,r,n)||function(t,e){for(var r=t._fullData,n=e._mainSubplot,i=e._id.charAt(0),a=0;a<r.length;a++){var s=r[a];if(!0===s.visible&&s.xaxis+s.yaxis===n){if(o.traceIs(s,\"bar-like\")&&s.orientation==={x:\"h\",y:\"v\"}[i])return!0;if(s.fill&&s.fill.charAt(s.fill.length-1)===i)return!0}}return!1}(t,e))},A.clipEnds=function(t,e){return e.filter(function(e){return Z(t,e.x)})},A.allowAutoMargin=function(t){for(var e=A.list(t,\"\",!0),r=0;r<e.length;r++){var n=e[r];n.automargin&&a.allowAutoMargin(t,K(n)),o.getComponentMethod(\"rangeslider\",\"isVisible\")(n)&&a.allowAutoMargin(t,$(n))}},A.swap=function(t,e){for(var r=function(t,e){var r,n,i=[];for(r=0;r<e.length;r++){var a=[],o=t._fullData[e[r]].xaxis,s=t._fullData[e[r]].yaxis;if(o&&s){for(n=0;n<i.length;n++)-1===i[n].x.indexOf(o)&&-1===i[n].y.indexOf(s)||a.push(n);if(a.length){var l,c=i[a[0]];if(a.length>1)for(n=1;n<a.length;n++)l=i[a[n]],Q(c.x,l.x),Q(c.y,l.y);Q(c.x,[o]),Q(c.y,[s])}else i.push({x:[o],y:[s]})}}return i}(t,e),n=0;n<r.length;n++)tt(t,r[n].x,r[n].y)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../components/titles\":681,\"../../constants/alignment\":688,\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/plots\":828,\"../../registry\":847,\"./autorange\":766,\"./axis_autotype\":768,\"./axis_ids\":770,\"./clean_ticks\":772,\"./layout_attributes\":779,\"./set_convert\":785,d3:163,\"fast-isnumeric\":225}],768:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){return!(r=r||{}).noMultiCategory&&(o=t,i.isArrayOrTypedArray(o[0])&&i.isArrayOrTypedArray(o[1]))?\"multicategory\":function(t,e){for(var r=Math.max(1,(t.length-1)/1e3),a=0,o=0,s={},l=0;l<t.length;l+=r){var c=t[Math.round(l)],u=String(c);s[u]||(s[u]=1,i.isDateTime(c,e)&&(a+=1),n(c)&&(o+=1))}return a>2*o}(t,e)?\"date\":function(t){for(var e=Math.max(1,(t.length-1)/1e3),r=0,n=0,o={},s=0;s<t.length;s+=e){var l=t[Math.round(s)],c=String(l);o[c]||(o[c]=1,\"boolean\"==typeof l?n++:i.cleanNumber(l)!==a?r++:\"string\"==typeof l&&n++)}return n>2*r}(t)?\"category\":function(t){if(!t)return!1;for(var e=0;e<t.length;e++)if(n(t[e]))return!0;return!1}(t)?\"linear\":\"-\";var o}},{\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],769:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./layout_attributes\"),o=t(\"./tick_value_defaults\"),s=t(\"./tick_mark_defaults\"),l=t(\"./tick_label_defaults\"),c=t(\"./category_order_defaults\"),u=t(\"./line_grid_defaults\"),h=t(\"./set_convert\");e.exports=function(t,e,r,f,p){var d=f.letter,g=f.font||{},v=f.splomStash||{},m=r(\"visible\",!f.visibleDflt),y=e.type;\"date\"===y&&n.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",f.calendar);h(e,p);var x=!e.isValidRange(t.range);x&&f.reverseDflt&&(x=\"reversed\"),!r(\"autorange\",x)||\"linear\"!==y&&\"-\"!==y||r(\"rangemode\"),r(\"range\"),e.cleanRange(),c(t,e,r,f),\"category\"===y||f.noHover||r(\"hoverformat\");var b=r(\"color\"),_=b!==a.color.dflt?b:g.color,w=v.label||p._dfltTitle[d];if(l(t,e,r,y,f,{pass:1}),!m)return e;r(\"title.text\",w),i.coerceFont(r,\"title.font\",{family:g.family,size:Math.round(1.2*g.size),color:_}),o(t,e,r,y),l(t,e,r,y,f,{pass:2}),s(t,e,r,f),u(t,e,r,{dfltColor:b,bgColor:f.bgColor,showGrid:f.showGrid,attributes:a}),(e.showline||e.ticks)&&r(\"mirror\"),f.automargin&&r(\"automargin\");var k,T=\"multicategory\"===e.type;f.noTickson||\"category\"!==e.type&&!T||!e.ticks&&!e.showgrid||(T&&(k=\"boundaries\"),r(\"tickson\",k));T&&(r(\"showdividers\")&&(r(\"dividercolor\"),r(\"dividerwidth\")));return e}},{\"../../lib\":719,\"../../registry\":847,\"./category_order_defaults\":771,\"./layout_attributes\":779,\"./line_grid_defaults\":781,\"./set_convert\":785,\"./tick_label_defaults\":786,\"./tick_mark_defaults\":787,\"./tick_value_defaults\":788}],770:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./constants\");r.id2name=function(t){if(\"string\"==typeof t&&t.match(i.AX_ID_PATTERN)){var e=t.substr(1);return\"1\"===e&&(e=\"\"),t.charAt(0)+\"axis\"+e}},r.name2id=function(t){if(t.match(i.AX_NAME_PATTERN)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),t.charAt(0)+e}},r.cleanId=function(t,e){if(t.match(i.AX_ID_PATTERN)&&(!e||t.charAt(0)===e)){var r=t.substr(1).replace(/^0+/,\"\");return\"1\"===r&&(r=\"\"),t.charAt(0)+r}},r.list=function(t,e,n){var i=t._fullLayout;if(!i)return[];var a,o=r.listIds(t,e),s=new Array(o.length);for(a=0;a<o.length;a++){var l=o[a];s[a]=i[l.charAt(0)+\"axis\"+l.substr(1)]}if(!n){var c=i._subplots.gl3d||[];for(a=0;a<c.length;a++){var u=i[c[a]];e?s.push(u[e+\"axis\"]):s.push(u.xaxis,u.yaxis,u.zaxis)}}return s},r.listIds=function(t,e){var r=t._fullLayout;if(!r)return[];var n=r._subplots;return e?n[e+\"axis\"]:n.xaxis.concat(n.yaxis)},r.getFromId=function(t,e,n){var i=t._fullLayout;return\"x\"===n?e=e.replace(/y[0-9]*/,\"\"):\"y\"===n&&(e=e.replace(/x[0-9]*/,\"\")),i[r.id2name(e)]},r.getFromTrace=function(t,e,i){var a=t._fullLayout,o=null;if(n.traceIs(e,\"gl3d\")){var s=e.scene;\"scene\"===s.substr(0,5)&&(o=a[s][i+\"axis\"])}else o=r.getFromId(t,e[i+\"axis\"]||i);return o},r.idSort=function(t,e){var r=t.charAt(0),n=e.charAt(0);return r!==n?r>n?1:-1:+(t.substr(1)||1)-+(e.substr(1)||1)},r.getAxisGroup=function(t,e){for(var r=t._axisMatchGroups,n=0;n<r.length;n++){if(r[n][e])return\"g\"+n}return e}},{\"../../registry\":847,\"./constants\":773}],771:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){if(\"category\"===e.type){var i,a=t.categoryarray,o=Array.isArray(a)&&a.length>0;o&&(i=\"array\");var s,l=r(\"categoryorder\",i);\"array\"===l&&(s=r(\"categoryarray\")),o||\"array\"!==l||(l=e.categoryorder=\"trace\"),\"trace\"===l?e._initialCategories=[]:\"array\"===l?e._initialCategories=s.slice():(s=function(t,e){var r,n,i,a=e.dataAttr||t._id.charAt(0),o={};if(e.axData)r=e.axData;else for(r=[],n=0;n<e.data.length;n++){var s=e.data[n];s[a+\"axis\"]===t._id&&r.push(s)}for(n=0;n<r.length;n++){var l=r[n][a];for(i=0;i<l.length;i++){var c=l[i];null!=c&&(o[c]=1)}}return Object.keys(o)}(e,n).sort(),\"category ascending\"===l?e._initialCategories=s:\"category descending\"===l&&(e._initialCategories=s.reverse()))}}},{}],772:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").ONEDAY;r.dtick=function(t,e){var r=\"log\"===e,i=\"date\"===e,o=\"category\"===e,s=i?a:1;if(!t)return s;if(n(t))return(t=Number(t))<=0?s:o?Math.max(1,Math.round(t)):i?Math.max(.1,t):t;if(\"string\"!=typeof t||!i&&!r)return s;var l=t.charAt(0),c=t.substr(1);return(c=n(c)?Number(c):0)<=0||!(i&&\"M\"===l&&c===Math.round(c)||r&&\"L\"===l||r&&\"D\"===l&&(1===c||2===c))?s:t},r.tick0=function(t,e,r,a){return\"date\"===e?i.cleanDate(t,i.dateTick0(r)):\"D1\"!==a&&\"D2\"!==a?n(t)?Number(t):0:void 0}},{\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],773:[function(t,e,r){\"use strict\";var n=t(\"../../lib/regex\").counter;e.exports={idRegex:{x:n(\"x\"),y:n(\"y\")},attrRegex:n(\"[xy]axis\"),xAxisMatch:n(\"xaxis\"),yAxisMatch:n(\"yaxis\"),AX_ID_PATTERN:/^[xyz][0-9]*$/,AX_NAME_PATTERN:/^[xyz]axis[0-9]*$/,SUBPLOT_PATTERN:/^x([0-9]*)y([0-9]*)$/,MINDRAG:8,MINSELECT:12,MINZOOM:20,DRAGGERSIZE:20,BENDPX:1.5,REDRAWDELAY:50,SELECTDELAY:100,SELECTID:\"-select\",DFLTRANGEX:[-1,6],DFLTRANGEY:[-1,4],traceLayerClasses:[\"heatmaplayer\",\"contourcarpetlayer\",\"contourlayer\",\"funnellayer\",\"waterfalllayer\",\"barlayer\",\"carpetlayer\",\"violinlayer\",\"boxlayer\",\"ohlclayer\",\"scattercarpetlayer\",\"scatterlayer\"],clipOnAxisFalseQuery:[\".scatterlayer\",\".barlayer\",\".funnellayer\",\".waterfalllayer\"],layerValue2layerClass:{\"above traces\":\"above\",\"below traces\":\"below\"}}},{\"../../lib/regex\":735}],774:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./axis_ids\").id2name,a=t(\"./scale_zoom\"),o=t(\"./autorange\").makePadFn,s=t(\"./autorange\").concatExtremes,l=t(\"../../constants/numerical\").ALMOST_EQUAL,c=t(\"../../constants/alignment\").FROM_BL;function u(t,e,r,n,a){var o,s,l,c,u=\"range\"!==a,h=n[i(e)].type,f=[];for(s=0;s<r.length;s++)if((l=r[s])!==e&&(c=n[i(l)]).type===h)if(c.fixedrange){if(u&&c.anchor){n[i(c.anchor)].fixedrange&&f.push(l)}}else f.push(l);for(o=0;o<t.length;o++)if(t[o][e]){var p=t[o],d=[];for(s=0;s<f.length;s++)p[l=f[s]]||d.push(l);return{linkableAxes:d,thisGroup:p}}return{linkableAxes:f,thisGroup:null}}function h(t,e,r,n,i){var a,o,s,l,c;null===e?((e={})[r]=1,c=t.length,t.push(e)):c=t.indexOf(e);var u=Object.keys(e);for(a=0;a<t.length;a++)if(s=t[a],a!==c&&s[n]){var h=s[n];for(o=0;o<u.length;o++)s[l=u[o]]=h*i*e[l];return void t.splice(c,1)}if(1!==i)for(o=0;o<u.length;o++)e[u[o]]*=i;e[n]=1}function f(t,e){var r=t._inputDomain,n=c[t.constraintoward],i=r[0]+(r[1]-r[0])*n;t.domain=t._input.domain=[i+(r[0]-i)/e,i+(r[1]-i)/e],t.setScale()}r.handleConstraintDefaults=function(t,e,r,i,a){var o,s,l,c,f=a._axisConstraintGroups,p=a._axisMatchGroups,d=e._id,g=d.charAt(0),v=((a._splomAxes||{})[g]||{})[d]||{},m=e._id,y=m.charAt(0),x=r(\"constrain\");if(n.coerce(t,e,{constraintoward:{valType:\"enumerated\",values:\"x\"===y?[\"left\",\"center\",\"right\"]:[\"bottom\",\"middle\",\"top\"],dflt:\"x\"===y?\"center\":\"middle\"}},\"constraintoward\"),!t.matches&&!v.matches||e.fixedrange||(s=u(p,m,i,a),o=n.coerce(t,e,{matches:{valType:\"enumerated\",values:s.linkableAxes||[],dflt:v.matches}},\"matches\")),o||!t.scaleanchor||e.fixedrange&&\"domain\"!==x||(c=u(f,m,i,a,x),l=n.coerce(t,e,{scaleanchor:{valType:\"enumerated\",values:c.linkableAxes||[]}},\"scaleanchor\")),o?(delete e.constrain,h(p,s.thisGroup,m,o,1)):-1!==i.indexOf(t.matches)&&n.warn(\"ignored \"+e._name+'.matches: \"'+t.matches+'\" to avoid either an infinite loop or because the target axis has fixed range.'),l){var b=r(\"scaleratio\");b||(b=e.scaleratio=1),h(f,c.thisGroup,m,l,b)}else-1!==i.indexOf(t.scaleanchor)&&n.warn(\"ignored \"+e._name+'.scaleanchor: \"'+t.scaleanchor+'\" to avoid either an infinite loop and possibly inconsistent scaleratios, or because the target axis has fixed range or this axis declares a *matches* constraint.')},r.enforce=function(t){var e,r,n,c,u,h,p,d=t._fullLayout,g=d._axisConstraintGroups||[];for(e=0;e<g.length;e++){var v=g[e],m=Object.keys(v),y=1/0,x=0,b=1/0,_={},w={},k=!1;for(r=0;r<m.length;r++)w[n=m[r]]=c=d[i(n)],c._inputDomain?c.domain=c._inputDomain.slice():c._inputDomain=c.domain.slice(),c._inputRange||(c._inputRange=c.range.slice()),c.setScale(),_[n]=u=Math.abs(c._m)/v[n],y=Math.min(y,u),\"domain\"!==c.constrain&&c._constraintShrinkable||(b=Math.min(b,u)),delete c._constraintShrinkable,x=Math.max(x,u),\"domain\"===c.constrain&&(k=!0);if(!(y>l*x)||k)for(r=0;r<m.length;r++)if(u=_[n=m[r]],h=(c=w[n]).constrain,u!==b||\"domain\"===h)if(p=u/b,\"range\"===h)a(c,p);else{var T=c._inputDomain,A=(c.domain[1]-c.domain[0])/(T[1]-T[0]),M=(c.r2l(c.range[1])-c.r2l(c.range[0]))/(c.r2l(c._inputRange[1])-c.r2l(c._inputRange[0]));if((p/=A)*M<1){c.domain=c._input.domain=T.slice(),a(c,p);continue}if(M<1&&(c.range=c._input.range=c._inputRange.slice(),p*=M),c.autorange){var S=c.r2l(c.range[0]),E=c.r2l(c.range[1]),C=(S+E)/2,L=C,P=C,O=Math.abs(E-C),z=C-O*p*1.0001,I=C+O*p*1.0001,D=o(c);f(c,p);var R,F,B=Math.abs(c._m),N=s(t,c),j=N.min,U=N.max;for(F=0;F<j.length;F++)(R=j[F].val-D(j[F])/B)>z&&R<L&&(L=R);for(F=0;F<U.length;F++)(R=U[F].val+D(U[F])/B)<I&&R>P&&(P=R);p/=(P-L)/(2*O),L=c.l2r(L),P=c.l2r(P),c.range=c._input.range=S<E?[L,P]:[P,L]}f(c,p)}}},r.clean=function(t,e){if(e._inputDomain){for(var r=!1,n=e._id,i=t._fullLayout._axisConstraintGroups,a=0;a<i.length;a++)if(i[a][n]){r=!0;break}r&&\"domain\"===e.constrain||(e._input.domain=e.domain=e._inputDomain,delete e._inputDomain)}}},{\"../../constants/alignment\":688,\"../../constants/numerical\":695,\"../../lib\":719,\"./autorange\":766,\"./axis_ids\":770,\"./scale_zoom\":783}],775:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"has-passive-events\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../components/color\"),u=t(\"../../components/drawing\"),h=t(\"../../components/fx\"),f=t(\"./axes\"),p=t(\"../../lib/setcursor\"),d=t(\"../../components/dragelement\"),g=t(\"../../constants/alignment\").FROM_TL,v=t(\"../../lib/clear_gl_canvases\"),m=t(\"../../plot_api/subroutines\").redrawReglTraces,y=t(\"../plots\"),x=t(\"./axis_ids\").getFromId,b=t(\"./select\").prepSelect,_=t(\"./select\").clearSelect,w=t(\"./select\").selectOnClick,k=t(\"./scale_zoom\"),T=t(\"./constants\"),A=T.MINDRAG,M=T.MINZOOM,S=!0;function E(t,e,r,n){var i=s.ensureSingle(t.draglayer,e,r,function(e){e.classed(\"drag\",!0).style({fill:\"transparent\",\"stroke-width\":0}).attr(\"data-subplot\",t.id)});return i.call(p,n),i.node()}function C(t,e,r,i,a,o,s){var l=E(t,\"rect\",e,r);return n.select(l).call(u.setRect,i,a,o,s),l}function L(t,e){for(var r=0;r<t.length;r++)if(!t[r].fixedrange)return e;return\"\"}function P(t,e,r,n,i){for(var a=0;a<t.length;a++){var o=t[a];if(!o.fixedrange){var s=o._rl[0],l=o._rl[1]-s;n[o._name+\".range[0]\"]=o.l2r(s+l*e),n[o._name+\".range[1]\"]=o.l2r(s+l*r)}}if(i&&i.length){var c=(e+(1-r))/2;P(i,c,1-c,n,[])}}function O(t,e){for(var r=0;r<t.length;r++){var n=t[r];n.fixedrange||(n.range=[n.l2r(n._rl[0]-e/n._m),n.l2r(n._rl[1]-e/n._m)])}}function z(t){return 1-(t>=0?Math.min(t,.9):1/(1/Math.max(t,-.3)+3.222))}function I(t,e,r,n,i){return t.append(\"path\").attr(\"class\",\"zoombox\").style({fill:e>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"transform\",\"translate(\"+r+\", \"+n+\")\").attr(\"d\",i+\"Z\")}function D(t,e,r){return t.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:c.background,stroke:c.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"transform\",\"translate(\"+e+\", \"+r+\")\").attr(\"d\",\"M0,0Z\")}function R(t,e,r,n,i,a){t.attr(\"d\",n+\"M\"+r.l+\",\"+r.t+\"v\"+r.h+\"h\"+r.w+\"v-\"+r.h+\"h-\"+r.w+\"Z\"),F(t,e,i,a)}function F(t,e,r,n){r||(t.transition().style(\"fill\",n>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),e.transition().style(\"opacity\",1).duration(200))}function B(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}function N(t){S&&t.data&&t._context.showTips&&(s.notifier(s._(t,\"Double-click to zoom back out\"),\"long\"),S=!1)}function j(t){return\"lasso\"===t||\"select\"===t}function U(t){var e=Math.floor(Math.min(t.b-t.t,t.r-t.l,M)/2);return\"M\"+(t.l-3.5)+\",\"+(t.t-.5+e)+\"h3v\"+-e+\"h\"+e+\"v-3h-\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.t-.5+e)+\"h-3v\"+-e+\"h\"+-e+\"v-3h\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.b+.5-e)+\"h-3v\"+e+\"h\"+-e+\"v3h\"+(e+3)+\"ZM\"+(t.l-3.5)+\",\"+(t.b+.5-e)+\"h3v\"+e+\"h\"+e+\"v3h-\"+(e+3)+\"Z\"}function V(t,e,r,n){for(var i,a,o,l,c=!1,u={},h={},f=0;f<e.length;f++){var p=e[f];for(i in r)if(p[i]){for(o in p)(\"x\"===o.charAt(0)?r:n)[o]||(u[o]=i);for(a in n)p[a]&&(c=!0)}for(a in n)if(p[a])for(l in p)(\"x\"===l.charAt(0)?r:n)[l]||(h[l]=a)}c&&(s.extendFlat(u,h),h={});var d={},g=[];for(o in u){var v=x(t,o);g.push(v),d[v._id]=v}var m={},y=[];for(l in h){var b=x(t,l);y.push(b),m[b._id]=b}return{xaHash:d,yaHash:m,xaxes:g,yaxes:y,xLinks:u,yLinks:h,isSubplotConstrained:c}}function q(t,e){if(a){var r=void 0!==t.onwheel?\"wheel\":\"mousewheel\";t._onwheel&&t.removeEventListener(r,t._onwheel),t._onwheel=e,t.addEventListener(r,e,{passive:!1})}else void 0!==t.onwheel?t.onwheel=e:void 0!==t.onmousewheel&&(t.onmousewheel=e)}function H(t){var e=[];for(var r in t)e.push(t[r]);return e}e.exports={makeDragBox:function(t,e,r,a,c,p,S,E){var F,G,Y,W,X,Z,J,K,$,Q,tt,et,rt,nt,it,at,ot,st,lt,ct,ut,ht=t._fullLayout._zoomlayer,ft=S+E===\"nsew\",pt=1===(S+E).length;function dt(){if(F=e.xaxis,G=e.yaxis,$=F._length,Q=G._length,J=F._offset,K=G._offset,(Y={})[F._id]=F,(W={})[G._id]=G,S&&E)for(var r=e.overlays,n=0;n<r.length;n++){var i=r[n].xaxis;Y[i._id]=i;var a=r[n].yaxis;W[a._id]=a}X=H(Y),Z=H(W),rt=L(X,E),nt=L(Z,S),it=!nt&&!rt,tt=V(t,t._fullLayout._axisConstraintGroups,Y,W),et=V(t,t._fullLayout._axisMatchGroups,Y,W),at=E||tt.isSubplotConstrained||et.isSubplotConstrained,ot=S||tt.isSubplotConstrained||et.isSubplotConstrained;var o=t._fullLayout;st=o._has(\"scattergl\"),lt=o._has(\"splom\"),ct=o._has(\"svg\")}dt();var gt=function(t,e,r){return t?\"nsew\"===t?r?\"\":\"pan\"===e?\"move\":\"crosshair\":t.toLowerCase()+\"-resize\":\"pointer\"}(nt+rt,t._fullLayout.dragmode,ft),vt=C(e,S+E+\"drag\",gt,r,a,c,p);if(it&&!ft)return vt.onmousedown=null,vt.style.pointerEvents=\"none\",vt;var mt,yt,xt,bt,_t,wt,kt,Tt,At,Mt,St={element:vt,gd:t,plotinfo:e};function Et(){St.plotinfo.selection=!1,_(t)}function Ct(r,i){var a=t._fullLayout.clickmode;if(B(t),2!==r||pt||function(){if(!t._transitioningWithDuration){var e=t._context.doubleClick,r=[];rt&&(r=r.concat(X)),nt&&(r=r.concat(Z)),et.xaxes&&(r=r.concat(et.xaxes)),et.yaxes&&(r=r.concat(et.yaxes));var n,i,a,s={};if(\"reset+autosize\"===e)for(e=\"autosize\",i=0;i<r.length;i++)if((n=r[i])._rangeInitial&&(n.range[0]!==n._rangeInitial[0]||n.range[1]!==n._rangeInitial[1])||!n._rangeInitial&&!n.autorange){e=\"reset\";break}if(\"autosize\"===e)for(i=0;i<r.length;i++)(n=r[i]).fixedrange||(s[n._name+\".autorange\"]=!0);else if(\"reset\"===e)for((rt||tt.isSubplotConstrained)&&(r=r.concat(tt.xaxes)),nt&&!tt.isSubplotConstrained&&(r=r.concat(tt.yaxes)),tt.isSubplotConstrained&&(rt?nt||(r=r.concat(Z)):r=r.concat(X)),i=0;i<r.length;i++)(n=r[i]).fixedrange||(n._rangeInitial?(a=n._rangeInitial,s[n._name+\".range[0]\"]=a[0],s[n._name+\".range[1]\"]=a[1]):s[n._name+\".autorange\"]=!0);t.emit(\"plotly_doubleclick\",null),o.call(\"_guiRelayout\",t,s)}}(),ft)a.indexOf(\"select\")>-1&&w(i,t,X,Z,e.id,St),a.indexOf(\"event\")>-1&&h.click(t,i,e.id);else if(1===r&&pt){var s=S?G:F,c=\"s\"===S||\"w\"===E?0:1,u=s._name+\".range[\"+c+\"]\",f=function(t,e){var r,i=t.range[e],a=Math.abs(i-t.range[1-e]);return\"date\"===t.type?i:\"log\"===t.type?(r=Math.ceil(Math.max(0,-Math.log(a)/Math.LN10))+3,n.format(\".\"+r+\"g\")(Math.pow(10,i))):(r=Math.floor(Math.log(Math.abs(i))/Math.LN10)-Math.floor(Math.log(a)/Math.LN10)+4,n.format(\".\"+String(r)+\"g\")(i))}(s,c),p=\"left\",d=\"middle\";if(s.fixedrange)return;S?(d=\"n\"===S?\"top\":\"bottom\",\"right\"===s.side&&(p=\"right\")):\"e\"===E&&(p=\"right\"),t._context.showAxisRangeEntryBoxes&&n.select(vt).call(l.makeEditable,{gd:t,immediate:!0,background:t._fullLayout.paper_bgcolor,text:String(f),fill:s.tickfont?s.tickfont.color:\"#444\",horizontalAlign:p,verticalAlign:d}).on(\"edit\",function(e){var r=s.d2r(e);void 0!==r&&o.call(\"_guiRelayout\",t,u,r)})}}function Lt(e,r){if(t._transitioningWithDuration)return!1;var n=Math.max(0,Math.min($,e+mt)),i=Math.max(0,Math.min(Q,r+yt)),a=Math.abs(n-mt),o=Math.abs(i-yt);function s(){kt=\"\",xt.r=xt.l,xt.t=xt.b,At.attr(\"d\",\"M0,0Z\")}if(xt.l=Math.min(mt,n),xt.r=Math.max(mt,n),xt.t=Math.min(yt,i),xt.b=Math.max(yt,i),tt.isSubplotConstrained)a>M||o>M?(kt=\"xy\",a/$>o/Q?(o=a*Q/$,yt>i?xt.t=yt-o:xt.b=yt+o):(a=o*$/Q,mt>n?xt.l=mt-a:xt.r=mt+a),At.attr(\"d\",U(xt))):s();else if(et.isSubplotConstrained)if(a>M||o>M){kt=\"xy\";var l=Math.min(xt.l/$,(Q-xt.b)/Q),c=Math.max(xt.r/$,(Q-xt.t)/Q);xt.l=l*$,xt.r=c*$,xt.b=(1-l)*Q,xt.t=(1-c)*Q,At.attr(\"d\",U(xt))}else s();else!nt||o<Math.min(Math.max(.6*a,A),M)?a<A||!rt?s():(xt.t=0,xt.b=Q,kt=\"x\",At.attr(\"d\",function(t,e){return\"M\"+(t.l-.5)+\",\"+(e-M-.5)+\"h-3v\"+(2*M+1)+\"h3ZM\"+(t.r+.5)+\",\"+(e-M-.5)+\"h3v\"+(2*M+1)+\"h-3Z\"}(xt,yt))):!rt||a<Math.min(.6*o,M)?(xt.l=0,xt.r=$,kt=\"y\",At.attr(\"d\",function(t,e){return\"M\"+(e-M-.5)+\",\"+(t.t-.5)+\"v-3h\"+(2*M+1)+\"v3ZM\"+(e-M-.5)+\",\"+(t.b+.5)+\"v3h\"+(2*M+1)+\"v-3Z\"}(xt,mt))):(kt=\"xy\",At.attr(\"d\",U(xt)));xt.w=xt.r-xt.l,xt.h=xt.b-xt.t,kt&&(Mt=!0),t._dragged=Mt,R(Tt,At,xt,_t,wt,bt),Pt(),t.emit(\"plotly_relayouting\",ut),wt=!0}function Pt(){ut={},\"xy\"!==kt&&\"x\"!==kt||(P(X,xt.l/$,xt.r/$,ut,tt.xaxes),Bt(\"x\",ut)),\"xy\"!==kt&&\"y\"!==kt||(P(Z,(Q-xt.b)/Q,(Q-xt.t)/Q,ut,tt.yaxes),Bt(\"y\",ut))}function Ot(){if(Math.min(xt.h,xt.w)<2*A)return B(t);Pt(),B(t),jt(),N(t)}St.prepFn=function(e,r,n){var a=St.dragmode,o=t._fullLayout.dragmode;o!==a&&(St.dragmode=o),dt(),it||(ft?e.shiftKey?\"pan\"===o?o=\"zoom\":j(o)||(o=\"pan\"):e.ctrlKey&&(o=\"pan\"):o=\"pan\"),St.minDrag=\"lasso\"===o?1:void 0,j(o)?(St.xaxes=X,St.yaxes=Z,b(e,r,n,St,o)):(St.clickFn=Ct,j(a)&&Et(),it||(\"zoom\"===o?(St.moveFn=Lt,St.doneFn=Ot,St.minDrag=1,function(e,r,n){var a=vt.getBoundingClientRect();mt=r-a.left,yt=n-a.top,xt={l:mt,r:mt,w:0,t:yt,b:yt,h:0},bt=t._hmpixcount?t._hmlumcount/t._hmpixcount:i(t._fullLayout.plot_bgcolor).getLuminance(),wt=!1,kt=\"xy\",Mt=!1,Tt=I(ht,bt,J,K,_t=\"M0,0H\"+$+\"V\"+Q+\"H0V0\"),At=D(ht,J,K)}(0,r,n)):\"pan\"===o&&(St.moveFn=Ft,St.doneFn=jt))),t._fullLayout._redrag=function(){var e=t._dragdata;e&&e.element===vt&&(j(t._fullLayout.dragmode)||(dt(),Ut([0,0,$,Q]),St.moveFn(e.dx,e.dy)))}},d.init(St);var zt=[0,0,$,Q],It=null,Dt=T.REDRAWDELAY,Rt=e.mainplot?t._fullLayout._plots[e.mainplot]:e;function Ft(e,r){if(!t._transitioningWithDuration){if(t._fullLayout._replotting=!0,\"ew\"===rt||\"ns\"===nt)return rt&&(O(X,e),Bt(\"x\")),nt&&(O(Z,r),Bt(\"y\")),Ut([rt?-e:0,nt?-r:0,$,Q]),Nt(),void t.emit(\"plotly_relayouting\",ut);if(tt.isSubplotConstrained&&rt&&nt){var n=\"w\"===rt==(\"n\"===nt)?1:-1,i=(e/$+n*r/Q)/2;e=i*$,r=n*i*Q}\"w\"===rt?e=l(X,0,e):\"e\"===rt?e=l(X,1,-e):rt||(e=0),\"n\"===nt?r=l(Z,1,r):\"s\"===nt?r=l(Z,0,-r):nt||(r=0);var a=\"w\"===rt?e:0,o=\"n\"===nt?r:0;if(tt.isSubplotConstrained){var s;if(!rt&&1===nt.length){for(s=0;s<X.length;s++)X[s].range=X[s]._r.slice(),k(X[s],1-r/Q);a=(e=r*$/Q)/2}if(!nt&&1===rt.length){for(s=0;s<Z.length;s++)Z[s].range=Z[s]._r.slice(),k(Z[s],1-e/$);o=(r=e*Q/$)/2}}Bt(\"x\"),Bt(\"y\"),Ut([a,o,$-e,Q-r]),Nt(),t.emit(\"plotly_relayouting\",ut)}function l(t,e,r){for(var n,i,a=1-e,o=0;o<t.length;o++){var s=t[o];if(!s.fixedrange){n=s,i=s._rl[a]+(s._rl[e]-s._rl[a])/z(r/s._length);var l=s.l2r(i);!1!==l&&void 0!==l&&(s.range[e]=l)}}return n._length*(n._rl[e]-i)/(n._rl[e]-n._rl[a])}}function Bt(t,e){for(var r=et.isSubplotConstrained?{x:Z,y:X}[t]:et[t+\"axes\"],n=et.isSubplotConstrained?{x:X,y:Z}[t]:[],i=0;i<r.length;i++){var a=r[i],o=a._id,s=et.xLinks[o]||et.yLinks[o],l=n[0]||Y[s]||W[s];l&&(e?(e[a._name+\".range[0]\"]=e[l._name+\".range[0]\"],e[a._name+\".range[1]\"]=e[l._name+\".range[1]\"]):a.range=l.range.slice())}}function Nt(){var e,r=[];function n(t){for(e=0;e<t.length;e++)t[e].fixedrange||r.push(t[e]._id)}for(at&&(n(X),n(tt.xaxes),n(et.xaxes)),ot&&(n(Z),n(tt.yaxes),n(et.yaxes)),ut={},e=0;e<r.length;e++){var i=r[e],a=x(t,i);f.drawOne(t,a,{skipTitle:!0}),ut[a._name+\".range[0]\"]=a.range[0],ut[a._name+\".range[1]\"]=a.range[1]}f.redrawComponents(t,r)}function jt(){Ut([0,0,$,Q]),s.syncOrAsync([y.previousPromises,function(){t._fullLayout._replotting=!1,o.call(\"_guiRelayout\",t,ut)}],t)}function Ut(e){var r,n,i,a,l=t._fullLayout,c=l._plots,h=l._subplots.cartesian;if(lt&&o.subplotsRegistry.splom.drag(t),st)for(r=0;r<h.length;r++)if(i=(n=c[h[r]]).xaxis,a=n.yaxis,n._scene){var f=s.simpleMap(i.range,i.r2l),p=s.simpleMap(a.range,a.r2l);n._scene.update({range:[f[0],p[0],f[1],p[1]]})}if((lt||st)&&(v(t),m(t)),ct){var d=e[2]/F._length,g=e[3]/G._length;for(r=0;r<h.length;r++){i=(n=c[h[r]]).xaxis,a=n.yaxis;var y,x,b,_,w=at&&!i.fixedrange&&Y[i._id],k=ot&&!a.fixedrange&&W[a._id];if(w?(y=d,b=E?e[0]:Ht(i,y)):et.xaHash[i._id]?(y=d,b=e[0]*i._length/F._length):et.yaHash[i._id]?(y=g,b=\"ns\"===nt?-e[1]*i._length/G._length:Ht(i,y,{n:\"top\",s:\"bottom\"}[nt])):b=qt(i,y=Vt(i,d,g)),k?(x=g,_=S?e[1]:Ht(a,x)):et.yaHash[a._id]?(x=g,_=e[1]*a._length/G._length):et.xaHash[a._id]?(x=d,_=\"ew\"===rt?-e[0]*a._length/F._length:Ht(a,x,{e:\"right\",w:\"left\"}[rt])):_=qt(a,x=Vt(a,d,g)),y||x){y||(y=1),x||(x=1);var T=i._offset-b/y,A=a._offset-_/x;n.clipRect.call(u.setTranslate,b,_).call(u.setScale,y,x),n.plot.call(u.setTranslate,T,A).call(u.setScale,1/y,1/x),y===n.xScaleFactor&&x===n.yScaleFactor||(u.setPointGroupScale(n.zoomScalePts,y,x),u.setTextPointsScale(n.zoomScaleTxt,y,x)),u.hideOutsideRangePoints(n.clipOnAxisFalseTraces,n),n.xScaleFactor=y,n.yScaleFactor=x}}}}function Vt(t,e,r){return t.fixedrange?0:at&&tt.xaHash[t._id]?e:ot&&(tt.isSubplotConstrained?tt.xaHash:tt.yaHash)[t._id]?r:0}function qt(t,e){return e?(t.range=t._r.slice(),k(t,e),Ht(t,e)):0}function Ht(t,e,r){return t._length*(1-e)*g[r||t.constraintoward||\"middle\"]}return S.length*E.length!=1&&q(vt,function(e){if(t._context._scrollZoom.cartesian||t._fullLayout._enablescrollzoom){if(Et(),t._transitioningWithDuration)return e.preventDefault(),void e.stopPropagation();dt(),clearTimeout(It);var r=-e.deltaY;if(isFinite(r)||(r=e.wheelDelta/10),isFinite(r)){var n,i=Math.exp(-Math.min(Math.max(r,-20),20)/200),a=Rt.draglayer.select(\".nsewdrag\").node().getBoundingClientRect(),o=(e.clientX-a.left)/a.width,l=(a.bottom-e.clientY)/a.height;if(at){for(E||(o=.5),n=0;n<X.length;n++)c(X[n],o,i);Bt(\"x\"),zt[2]*=i,zt[0]+=zt[2]*o*(1/i-1)}if(ot){for(S||(l=.5),n=0;n<Z.length;n++)c(Z[n],l,i);Bt(\"y\"),zt[3]*=i,zt[1]+=zt[3]*(1-l)*(1/i-1)}Ut(zt),Nt(),t.emit(\"plotly_relayouting\",ut),It=setTimeout(function(){zt=[0,0,$,Q],jt()},Dt),e.preventDefault()}else s.log(\"Did not find wheel motion attributes: \",e)}function c(t,e,r){if(!t.fixedrange){var n=s.simpleMap(t.range,t.r2l),i=n[0]+(n[1]-n[0])*e;t.range=n.map(function(e){return t.l2r(i+(e-i)*r)})}}}),vt},makeDragger:E,makeRectDragger:C,makeZoombox:I,makeCorners:D,updateZoombox:R,xyCorners:U,transitionZoombox:F,removeZoombox:B,showDoubleClickNotifier:N,attachWheelEventHandler:q}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/clear_gl_canvases\":704,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../plot_api/subroutines\":758,\"../../registry\":847,\"../plots\":828,\"./axes\":767,\"./axis_ids\":770,\"./constants\":773,\"./scale_zoom\":783,\"./select\":784,d3:163,\"has-passive-events\":411,tinycolor2:537}],776:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/fx\"),a=t(\"../../components/dragelement\"),o=t(\"../../lib/setcursor\"),s=t(\"./dragbox\").makeDragBox,l=t(\"./constants\").DRAGGERSIZE;r.initInteractions=function(t){var e=t._fullLayout;if(t._context.staticPlot)n.select(t).selectAll(\".drag\").remove();else if(e._has(\"cartesian\")||e._has(\"splom\")){Object.keys(e._plots||{}).sort(function(t,r){if((e._plots[t].mainplot&&!0)===(e._plots[r].mainplot&&!0)){var n=t.split(\"y\"),i=r.split(\"y\");return n[0]===i[0]?Number(n[1]||1)-Number(i[1]||1):Number(n[0]||1)-Number(i[0]||1)}return e._plots[t].mainplot?1:-1}).forEach(function(r){var n=e._plots[r],o=n.xaxis,c=n.yaxis;if(!n.mainplot){var u=s(t,n,o._offset,c._offset,o._length,c._length,\"ns\",\"ew\");u.onmousemove=function(e){t._fullLayout._rehover=function(){t._fullLayout._hoversubplot===r&&i.hover(t,e,r)},i.hover(t,e,r),t._fullLayout._lasthover=u,t._fullLayout._hoversubplot=r},u.onmouseout=function(e){t._dragging||(t._fullLayout._hoversubplot=null,a.unhover(t,e))},t._context.showAxisDragHandles&&(s(t,n,o._offset-l,c._offset-l,l,l,\"n\",\"w\"),s(t,n,o._offset+o._length,c._offset-l,l,l,\"n\",\"e\"),s(t,n,o._offset-l,c._offset+c._length,l,l,\"s\",\"w\"),s(t,n,o._offset+o._length,c._offset+c._length,l,l,\"s\",\"e\"))}if(t._context.showAxisDragHandles){if(r===o._mainSubplot){var h=o._mainLinePosition;\"top\"===o.side&&(h-=l),s(t,n,o._offset+.1*o._length,h,.8*o._length,l,\"\",\"ew\"),s(t,n,o._offset,h,.1*o._length,l,\"\",\"w\"),s(t,n,o._offset+.9*o._length,h,.1*o._length,l,\"\",\"e\")}if(r===c._mainSubplot){var f=c._mainLinePosition;\"right\"!==c.side&&(f-=l),s(t,n,f,c._offset+.1*c._length,l,.8*c._length,\"ns\",\"\"),s(t,n,f,c._offset+.9*c._length,l,.1*c._length,\"s\",\"\"),s(t,n,f,c._offset,l,.1*c._length,\"n\",\"\")}}});var o=e._hoverlayer.node();o.onmousemove=function(r){r.target=t._fullLayout._lasthover,i.hover(t,r,e._hoversubplot)},o.onclick=function(e){e.target=t._fullLayout._lasthover,i.click(t,e)},o.onmousedown=function(e){t._fullLayout._lasthover.onmousedown(e)},r.updateFx(t)}},r.updateFx=function(t){var e=t._fullLayout,r=\"pan\"===e.dragmode?\"move\":\"crosshair\";o(e._draggers,r)}},{\"../../components/dragelement\":611,\"../../components/fx\":632,\"../../lib/setcursor\":739,\"./constants\":773,\"./dragbox\":775,d3:163}],777:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t){return function(e,r){var a=e[t];if(Array.isArray(a))for(var o=n.subplotsRegistry.cartesian,s=o.idRegex,l=r._subplots,c=l.xaxis,u=l.yaxis,h=l.cartesian,f=r._has(\"cartesian\")||r._has(\"gl2d\"),p=0;p<a.length;p++){var d=a[p];if(i.isPlainObject(d)){var g=d.xref,v=d.yref,m=s.x.test(g),y=s.y.test(v);if(m||y){f||i.pushUnique(r._basePlotModules,o);var x=!1;m&&-1===c.indexOf(g)&&(c.push(g),x=!0),y&&-1===u.indexOf(v)&&(u.push(v),x=!0),x&&m&&y&&h.push(g+v)}}}}}},{\"../../lib\":719,\"../../registry\":847}],778:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../plots\"),s=t(\"../../components/drawing\"),l=t(\"../get_data\").getModuleCalcData,c=t(\"./axis_ids\"),u=t(\"./constants\"),h=t(\"../../constants/xmlns_namespaces\"),f=a.ensureSingle;function p(t,e,r){return a.ensureSingle(t,e,r,function(t){t.datum(r)})}function d(t,e,r,a,o){for(var c,h,f,p=u.traceLayerClasses,d=t._fullLayout,g=d._modules,v=[],m=[],y=0;y<g.length;y++){var x=(c=g[y]).name,b=i.modules[x].categories;if(b.svg){var _=c.layerName||x+\"layer\",w=c.plot;f=(h=l(r,w))[0],r=h[1],f.length&&v.push({i:p.indexOf(_),className:_,plotMethod:w,cdModule:f}),b.zoomScale&&m.push(\".\"+_)}}v.sort(function(t,e){return t.i-e.i});var k=e.plot.selectAll(\"g.mlayer\").data(v,function(t){return t.className});if(k.enter().append(\"g\").attr(\"class\",function(t){return t.className}).classed(\"mlayer\",!0).classed(\"rangeplot\",e.isRangePlot),k.exit().remove(),k.order(),k.each(function(r){var i=n.select(this),l=r.className;r.plotMethod(t,e,r.cdModule,i,a,o),-1===u.clipOnAxisFalseQuery.indexOf(\".\"+l)&&s.setClipUrl(i,e.layerClipId,t)}),d._has(\"scattergl\")&&(c=i.getModule(\"scattergl\"),f=l(r,c)[0],c.plot(t,e,f)),!t._context.staticPlot&&(e._hasClipOnAxisFalse&&(e.clipOnAxisFalseTraces=e.plot.selectAll(u.clipOnAxisFalseQuery.join(\",\")).selectAll(\".trace\")),m.length)){var T=e.plot.selectAll(m.join(\",\")).selectAll(\".trace\");e.zoomScalePts=T.selectAll(\"path.point\"),e.zoomScaleTxt=T.selectAll(\".textpoint\")}}function g(t,e){var r=e.plotgroup,n=e.id,i=u.layerValue2layerClass[e.xaxis.layer],a=u.layerValue2layerClass[e.yaxis.layer],o=t._fullLayout._hasOnlyLargeSploms;if(e.mainplot){var s=e.mainplotinfo,l=s.plotgroup,h=n+\"-x\",d=n+\"-y\";e.gridlayer=s.gridlayer,e.zerolinelayer=s.zerolinelayer,f(s.overlinesBelow,\"path\",h),f(s.overlinesBelow,\"path\",d),f(s.overaxesBelow,\"g\",h),f(s.overaxesBelow,\"g\",d),e.plot=f(s.overplot,\"g\",n),f(s.overlinesAbove,\"path\",h),f(s.overlinesAbove,\"path\",d),f(s.overaxesAbove,\"g\",h),f(s.overaxesAbove,\"g\",d),e.xlines=l.select(\".overlines-\"+i).select(\".\"+h),e.ylines=l.select(\".overlines-\"+a).select(\".\"+d),e.xaxislayer=l.select(\".overaxes-\"+i).select(\".\"+h),e.yaxislayer=l.select(\".overaxes-\"+a).select(\".\"+d)}else if(o)e.xlines=f(r,\"path\",\"xlines-above\"),e.ylines=f(r,\"path\",\"ylines-above\"),e.xaxislayer=f(r,\"g\",\"xaxislayer-above\"),e.yaxislayer=f(r,\"g\",\"yaxislayer-above\");else{var g=f(r,\"g\",\"layer-subplot\");e.shapelayer=f(g,\"g\",\"shapelayer\"),e.imagelayer=f(g,\"g\",\"imagelayer\"),e.gridlayer=f(r,\"g\",\"gridlayer\"),e.zerolinelayer=f(r,\"g\",\"zerolinelayer\"),f(r,\"path\",\"xlines-below\"),f(r,\"path\",\"ylines-below\"),e.overlinesBelow=f(r,\"g\",\"overlines-below\"),f(r,\"g\",\"xaxislayer-below\"),f(r,\"g\",\"yaxislayer-below\"),e.overaxesBelow=f(r,\"g\",\"overaxes-below\"),e.plot=f(r,\"g\",\"plot\"),e.overplot=f(r,\"g\",\"overplot\"),e.xlines=f(r,\"path\",\"xlines-above\"),e.ylines=f(r,\"path\",\"ylines-above\"),e.overlinesAbove=f(r,\"g\",\"overlines-above\"),f(r,\"g\",\"xaxislayer-above\"),f(r,\"g\",\"yaxislayer-above\"),e.overaxesAbove=f(r,\"g\",\"overaxes-above\"),e.xlines=r.select(\".xlines-\"+i),e.ylines=r.select(\".ylines-\"+a),e.xaxislayer=r.select(\".xaxislayer-\"+i),e.yaxislayer=r.select(\".yaxislayer-\"+a)}o||(p(e.gridlayer,\"g\",e.xaxis._id),p(e.gridlayer,\"g\",e.yaxis._id),e.gridlayer.selectAll(\"g\").map(function(t){return t[0]}).sort(c.idSort)),e.xlines.style(\"fill\",\"none\").classed(\"crisp\",!0),e.ylines.style(\"fill\",\"none\").classed(\"crisp\",!0)}function v(t,e){if(t){var r={};for(var i in t.each(function(t){var i=t[0];n.select(this).remove(),m(i,e),r[i]=!0}),e._plots)for(var a=e._plots[i].overlays||[],o=0;o<a.length;o++){var s=a[o];r[s.id]&&s.plot.selectAll(\".trace\").remove()}}}function m(t,e){e._draggers.selectAll(\"g.\"+t).remove(),e._defs.select(\"#clip\"+e._uid+t+\"plot\").remove()}r.name=\"cartesian\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=u.idRegex,r.attrRegex=u.attrRegex,r.attributes=t(\"./attributes\"),r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.transitionAxes=t(\"./transition_axes\"),r.finalizeSubplots=function(t,e){var r,n,i,o=e._subplots,s=o.xaxis,l=o.yaxis,h=o.cartesian,f=h.concat(o.gl2d||[]),p={},d={};for(r=0;r<f.length;r++){var g=f[r].split(\"y\");p[g[0]]=1,d[\"y\"+g[1]]=1}for(r=0;r<s.length;r++)p[n=s[r]]||(i=(t[c.id2name(n)]||{}).anchor,u.idRegex.y.test(i)||(i=\"y\"),h.push(n+i),f.push(n+i),d[i]||(d[i]=1,a.pushUnique(l,i)));for(r=0;r<l.length;r++)d[i=l[r]]||(n=(t[c.id2name(i)]||{}).anchor,u.idRegex.x.test(n)||(n=\"x\"),h.push(n+i),f.push(n+i),p[n]||(p[n]=1,a.pushUnique(s,n)));if(!f.length){for(var v in n=\"\",i=\"\",t){if(u.attrRegex.test(v))\"x\"===v.charAt(0)?(!n||+v.substr(5)<+n.substr(5))&&(n=v):(!i||+v.substr(5)<+i.substr(5))&&(i=v)}n=n?c.name2id(n):\"x\",i=i?c.name2id(i):\"y\",s.push(n),l.push(i),h.push(n+i)}},r.plot=function(t,e,r,n){var i,a=t._fullLayout,o=a._subplots.cartesian,s=t.calcdata;if(!Array.isArray(e))for(e=[],i=0;i<s.length;i++)e.push(i);for(i=0;i<o.length;i++){for(var l,c=o[i],u=a._plots[c],h=[],f=0;f<s.length;f++){var p=s[f],g=p[0].trace;g.xaxis+g.yaxis===c&&((-1!==e.indexOf(g.index)||g.carpet)&&(l&&l[0].trace.xaxis+l[0].trace.yaxis===c&&-1!==[\"tonextx\",\"tonexty\",\"tonext\"].indexOf(g.fill)&&-1===h.indexOf(l)&&h.push(l),h.push(p)),l=p)}d(t,u,h,r,n)}},r.clean=function(t,e,r,n){var i,a,o,s=n._plots||{},l=e._plots||{},u=n._subplots||{};if(n._hasOnlyLargeSploms&&!e._hasOnlyLargeSploms)for(o in s)(i=s[o]).plotgroup&&i.plotgroup.remove();var h=n._has&&n._has(\"gl\"),f=e._has&&e._has(\"gl\");if(h&&!f)for(o in s)(i=s[o])._scene&&i._scene.destroy();if(u.xaxis&&u.yaxis){var p=c.listIds({_fullLayout:n});for(a=0;a<p.length;a++){var d=p[a];e[c.id2name(d)]||n._infolayer.selectAll(\".g-\"+d+\"title\").remove()}}var g=n._has&&n._has(\"cartesian\"),y=e._has&&e._has(\"cartesian\");if(g&&!y)v(n._cartesianlayer.selectAll(\".subplot\"),n),n._defs.selectAll(\".axesclip\").remove(),delete n._axisConstraintGroups;else if(u.cartesian)for(a=0;a<u.cartesian.length;a++){var x=u.cartesian[a];if(!l[x]){var b=\".\"+x+\",.\"+x+\"-x,.\"+x+\"-y\";n._cartesianlayer.selectAll(b).remove(),m(x,n)}}},r.drawFramework=function(t){var e=t._fullLayout,r=function(t){var e,r,n,i,a,o,s=t._fullLayout,l=s._subplots.cartesian,c=l.length,u=[],h=[];for(e=0;e<c;e++){n=l[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var f=a._mainAxis,p=o._mainAxis,d=f._id+p._id,g=s._plots[d];i.overlays=[],d!==n&&g?(i.mainplot=d,i.mainplotinfo=g,h.push(n)):(i.mainplot=void 0,i.mainPlotinfo=void 0,u.push(n))}for(e=0;e<h.length;e++)n=h[e],(i=s._plots[n]).mainplotinfo.overlays.push(i);var v=u.concat(h),m=new Array(c);for(e=0;e<c;e++){n=v[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var y=[n,a.layer,o.layer,a.overlaying||\"\",o.overlaying||\"\"];for(r=0;r<i.overlays.length;r++)y.push(i.overlays[r].id);m[e]=y}return m}(t),i=e._cartesianlayer.selectAll(\".subplot\").data(r,String);i.enter().append(\"g\").attr(\"class\",function(t){return\"subplot \"+t[0]}),i.order(),i.exit().call(v,e),i.each(function(r){var i=r[0],a=e._plots[i];a.plotgroup=n.select(this),g(t,a),a.draglayer=f(e._draggers,\"g\",i)})},r.rangePlot=function(t,e,r){g(t,e),d(t,e,r),o.style(t)},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter(function(t,e){return e===r.size()-1}).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each(function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:h.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})})},r.updateFx=t(\"./graph_interact\").updateFx},{\"../../components/drawing\":614,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../registry\":847,\"../get_data\":802,\"../plots\":828,\"./attributes\":765,\"./axis_ids\":770,\"./constants\":773,\"./graph_interact\":776,\"./layout_attributes\":779,\"./layout_defaults\":780,\"./transition_axes\":789,d3:163}],779:[function(t,e,r){\"use strict\";var n=t(\"../font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray,l=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").DATE_FORMAT_LINK,t(\"./constants\"));e.exports={visible:{valType:\"boolean\",editType:\"plot\"},color:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},title:{text:{valType:\"string\",editType:\"ticks\"},font:n({editType:\"ticks\"}),editType:\"ticks\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"log\",\"date\",\"category\",\"multicategory\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"axrange\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0},{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0}],editType:\"axrange\",impliedEdits:{autorange:!1},anim:!0},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},scaleanchor:{valType:\"enumerated\",values:[l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},scaleratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},constrain:{valType:\"enumerated\",values:[\"range\",\"domain\"],dflt:\"range\",editType:\"plot\"},constraintoward:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\",\"top\",\"middle\",\"bottom\"],editType:\"plot\"},matches:{valType:\"enumerated\",values:[l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"calc\"},tickmode:{valType:\"enumerated\",values:[\"auto\",\"linear\",\"array\"],editType:\"ticks\",impliedEdits:{tick0:void 0,dtick:void 0}},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"ticks\"},tick0:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},dtick:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},tickvals:{valType:\"data_array\",editType:\"ticks\"},ticktext:{valType:\"data_array\",editType:\"ticks\"},ticks:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"\"],editType:\"ticks\"},tickson:{valType:\"enumerated\",values:[\"labels\",\"boundaries\"],dflt:\"labels\",editType:\"ticks\"},mirror:{valType:\"enumerated\",values:[!0,\"ticks\",!1,\"all\",\"allticks\"],dflt:!1,editType:\"ticks+layoutstyle\"},ticklen:{valType:\"number\",min:0,dflt:5,editType:\"ticks\"},tickwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},tickcolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},showticklabels:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},automargin:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},showspikes:{valType:\"boolean\",dflt:!1,editType:\"modebar\"},spikecolor:{valType:\"color\",dflt:null,editType:\"none\"},spikethickness:{valType:\"number\",dflt:3,editType:\"none\"},spikedash:o({},a,{dflt:\"dash\",editType:\"none\"}),spikemode:{valType:\"flaglist\",flags:[\"toaxis\",\"across\",\"marker\"],dflt:\"toaxis\",editType:\"none\"},spikesnap:{valType:\"enumerated\",values:[\"data\",\"cursor\"],dflt:\"data\",editType:\"none\"},tickfont:n({editType:\"ticks\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"ticks\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"ticks\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"ticks\"},tickformatstops:s(\"tickformatstop\",{enabled:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dtickrange:{valType:\"info_array\",items:[{valType:\"any\",editType:\"ticks\"},{valType:\"any\",editType:\"ticks\"}],editType:\"ticks\"},value:{valType:\"string\",dflt:\"\",editType:\"ticks\"},editType:\"ticks\"}),hoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},showline:{valType:\"boolean\",dflt:!1,editType:\"ticks+layoutstyle\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"layoutstyle\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks+layoutstyle\"},showgrid:{valType:\"boolean\",editType:\"ticks\"},gridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"ticks\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},zeroline:{valType:\"boolean\",editType:\"ticks\"},zerolinecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},zerolinewidth:{valType:\"number\",dflt:1,editType:\"ticks\"},showdividers:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dividercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},dividerwidth:{valType:\"number\",dflt:1,editType:\"ticks\"},anchor:{valType:\"enumerated\",values:[\"free\",l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},side:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],editType:\"plot\"},overlaying:{valType:\"enumerated\",values:[\"free\",l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},layer:{valType:\"enumerated\",values:[\"above traces\",\"below traces\"],dflt:\"above traces\",editType:\"plot\"},domain:{valType:\"info_array\",items:[{valType:\"number\",min:0,max:1,editType:\"plot\"},{valType:\"number\",min:0,max:1,editType:\"plot\"}],dflt:[0,1],editType:\"plot\"},position:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\",\"total ascending\",\"total descending\",\"min ascending\",\"min descending\",\"max ascending\",\"max descending\",\"sum ascending\",\"sum descending\",\"mean ascending\",\"mean descending\",\"median ascending\",\"median descending\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{autotick:{valType:\"boolean\",editType:\"ticks\"},title:{valType:\"string\",editType:\"ticks\"},titlefont:n({editType:\"ticks\"})}}},{\"../../components/color/attributes\":592,\"../../components/drawing/attributes\":613,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../font_attributes\":793,\"./constants\":773}],780:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../layout_attributes\"),s=t(\"./layout_attributes\"),l=t(\"./type_defaults\"),c=t(\"./axis_defaults\"),u=t(\"./constraints\").handleConstraintDefaults,h=t(\"./position_defaults\"),f=t(\"./axis_ids\"),p=f.id2name,d=f.name2id,g=t(\"../../registry\"),v=g.traceIs,m=g.getComponentMethod;function y(t,e,r){Array.isArray(t[e])?t[e].push(r):t[e]=[r]}e.exports=function(t,e,r){var f,g,x={},b={},_={},w={},k={},T={},A={},M={},S={};for(f=0;f<r.length;f++){var E=r[f];if(v(E,\"cartesian\")||v(E,\"gl2d\")){var C,L;if(E.xaxis)y(x,C=p(E.xaxis),E);else if(E.xaxes)for(g=0;g<E.xaxes.length;g++)y(x,p(E.xaxes[g]),E);if(E.yaxis)y(x,L=p(E.yaxis),E);else if(E.yaxes)for(g=0;g<E.yaxes.length;g++)y(x,p(E.yaxes[g]),E);if(\"funnel\"===E.type?\"h\"===E.orientation?(C&&(b[C]=!0),L&&(A[L]=!0)):L&&(_[L]=!0):(L&&(k[L]=!0,T[L]=!0),v(E,\"carpet\")&&(\"carpet\"!==E.type||E._cheater)||C&&(w[C]=!0)),\"carpet\"===E.type&&E._cheater&&C&&(b[C]=!0),v(E,\"2dMap\")&&(M[C]=!0,M[L]=!0),v(E,\"oriented\"))S[\"h\"===E.orientation?L:C]=!0}}var P=e._subplots,O=P.xaxis,z=P.yaxis,I=n.simpleMap(O,p),D=n.simpleMap(z,p),R=I.concat(D),F=i.background;O.length&&z.length&&(F=n.coerce(t,e,o,\"plot_bgcolor\"));var B,N,j,U,V=i.combine(F,e.paper_bgcolor);function q(t,e){return n.coerce(j,U,s,t,e)}function H(t,e){return n.coerce2(j,U,s,t,e)}function G(t){return\"x\"===t?z:O}var Y={x:G(\"x\"),y:G(\"y\")},W=Y.x.concat(Y.y);function X(e,r){for(var n=\"x\"===e?I:D,i=[],a=0;a<n.length;a++){var o=n[a];o===r||(t[o]||{}).overlaying||i.push(d(o))}return i}for(f=0;f<R.length;f++){N=(B=R[f]).charAt(0),n.isPlainObject(t[B])||(t[B]={}),j=t[B],U=a.newContainer(e,B,N+\"axis\");var Z=x[B]||[];U._traceIndices=Z.map(function(t){return t._expandedIndex}),U._annIndices=[],U._shapeIndices=[],U._imgIndices=[],U._subplotsWith=[],U._counterAxes=[],U._name=U._attr=B;var J=U._id=d(B),K=X(N,B),$=\"x\"===N&&!w[B]&&b[B]||\"y\"===N&&!k[B]&&_[B],Q=\"y\"===N&&!T[B]&&A[B],tt={letter:N,font:e.font,outerTicks:M[B],showGrid:!S[B],data:Z,bgColor:V,calendar:e.calendar,automargin:!0,visibleDflt:$,reverseDflt:Q,splomStash:((e._splomAxes||{})[N]||{})[J]};q(\"uirevision\",e.uirevision),l(j,U,q,tt),c(j,U,q,tt,e);var et=H(\"spikecolor\"),rt=H(\"spikethickness\"),nt=H(\"spikedash\"),it=H(\"spikemode\"),at=H(\"spikesnap\");q(\"showspikes\",!!(et||rt||nt||it||at))||(delete U.spikecolor,delete U.spikethickness,delete U.spikedash,delete U.spikemode,delete U.spikesnap),h(j,U,q,{letter:N,counterAxes:Y[N],overlayableAxes:K,grid:e.grid}),U._input=j}var ot=m(\"rangeslider\",\"handleDefaults\"),st=m(\"rangeselector\",\"handleDefaults\");for(f=0;f<I.length;f++)B=I[f],j=t[B],U=e[B],ot(t,e,B),\"date\"===U.type&&st(j,U,e,D,U.calendar),q(\"fixedrange\");for(f=0;f<D.length;f++){B=D[f],j=t[B],U=e[B];var lt=e[p(U.anchor)];q(\"fixedrange\",m(\"rangeslider\",\"isVisible\")(lt))}var ct=e._axisConstraintGroups=[],ut=e._axisMatchGroups=[];for(f=0;f<R.length;f++)N=(B=R[f]).charAt(0),j=t[B],U=e[B],u(j,U,q,W,e);for(f=0;f<ut.length;f++){var ht,ft=ut[f],pt=null,dt=null;for(ht in ft)(U=e[p(ht)]).matches||(pt=U.range,dt=U.autorange);if(null===pt||null===dt)for(ht in ft){pt=(U=e[p(ht)]).range,dt=U.autorange;break}for(ht in ft)(U=e[p(ht)]).matches&&(U.range=pt.slice(),U.autorange=dt),U._matchGroup=ft;if(ct.length)for(ht in ft)for(g=0;g<ct.length;g++){var gt=ct[g];for(var vt in gt)ht===vt&&(n.warn(\"Axis \"+vt+\" is set with both a *scaleanchor* and *matches* constraint; ignoring the scale constraint.\"),delete gt[vt],Object.keys(gt).length<2&&ct.splice(g,1))}}}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../registry\":847,\"../layout_attributes\":819,\"./axis_defaults\":769,\"./axis_ids\":770,\"./constraints\":774,\"./layout_attributes\":779,\"./position_defaults\":782,\"./type_defaults\":790}],781:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../components/color/attributes\").lightFraction,a=t(\"../../lib\");e.exports=function(t,e,r,o){var s=(o=o||{}).dfltColor;function l(r,n){return a.coerce2(t,e,o.attributes,r,n)}var c=l(\"linecolor\",s),u=l(\"linewidth\");r(\"showline\",o.showLine||!!c||!!u)||(delete e.linecolor,delete e.linewidth);var h=l(\"gridcolor\",n(s,o.bgColor,o.blend||i).toRgbString()),f=l(\"gridwidth\");if(r(\"showgrid\",o.showGrid||!!h||!!f)||(delete e.gridcolor,delete e.gridwidth),!o.noZeroLine){var p=l(\"zerolinecolor\",s),d=l(\"zerolinewidth\");r(\"zeroline\",o.showGrid||!!p||!!d)||(delete e.zerolinecolor,delete e.zerolinewidth)}}},{\"../../components/color/attributes\":592,\"../../lib\":719,tinycolor2:537}],782:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o,s,l,c,u=a.counterAxes||[],h=a.overlayableAxes||[],f=a.letter,p=a.grid;p&&(s=p._domains[f][p._axisMap[e._id]],o=p._anchors[e._id],s&&(l=p[f+\"side\"].split(\" \")[0],c=p.domain[f][\"right\"===l||\"top\"===l?1:0])),s=s||[0,1],o=o||(n(t.position)?\"free\":u[0]||\"free\"),l=l||(\"x\"===f?\"bottom\":\"left\"),c=c||0,\"free\"===i.coerce(t,e,{anchor:{valType:\"enumerated\",values:[\"free\"].concat(u),dflt:o}},\"anchor\")&&r(\"position\",c),i.coerce(t,e,{side:{valType:\"enumerated\",values:\"x\"===f?[\"bottom\",\"top\"]:[\"left\",\"right\"],dflt:l}},\"side\");var d=!1;if(h.length&&(d=i.coerce(t,e,{overlaying:{valType:\"enumerated\",values:[!1].concat(h),dflt:!1}},\"overlaying\")),!d){var g=r(\"domain\",s);g[0]>g[1]-1/4096&&(e.domain=s),i.noneOrAll(t.domain,e.domain,s)}return r(\"layer\"),e}},{\"../../lib\":719,\"fast-isnumeric\":225}],783:[function(t,e,r){\"use strict\";var n=t(\"../../constants/alignment\").FROM_BL;e.exports=function(t,e,r){void 0===r&&(r=n[t.constraintoward||\"center\"]);var i=[t.r2l(t.range[0]),t.r2l(t.range[1])],a=i[0]+(i[1]-i[0])*r;t.range=t._input.range=[t.l2r(a+(i[0]-a)*e),t.l2r(a+(i[1]-a)*e)]}},{\"../../constants/alignment\":688}],784:[function(t,e,r){\"use strict\";var n=t(\"polybooljs\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../../components/fx\"),s=t(\"../../lib\"),l=t(\"../../lib/polygon\"),c=t(\"../../lib/throttle\"),u=t(\"../../components/fx/helpers\").makeEventData,h=t(\"./axis_ids\").getFromId,f=t(\"../../lib/clear_gl_canvases\"),p=t(\"../../plot_api/subroutines\").redrawReglTraces,d=t(\"./constants\"),g=d.MINSELECT,v=l.filter,m=l.tester;function y(t){return t._id}function x(t,e,r,n,i,a,o){var s,l,c,u,h,f,p,d,g,v=e._hoverdata,m=e._fullLayout.clickmode.indexOf(\"event\")>-1,y=[];if(function(t){return t&&Array.isArray(t)&&!0!==t[0].hoverOnBox}(v)){k(t,e,a);var x=function(t,e){var r,n,i=t[0],a=-1,o=[];for(n=0;n<e.length;n++)if(r=e[n],i.fullData._expandedIndex===r.cd[0].trace._expandedIndex){if(!0===i.hoverOnBox)break;void 0!==i.pointNumber?a=i.pointNumber:void 0!==i.binNumber&&(a=i.binNumber,o=i.pointNumbers);break}return{pointNumber:a,pointNumbers:o,searchInfo:r}}(v,s=A(e,r,n,i));if(x.pointNumbers.length>0?function(t,e){var r,n,i,a=[];for(i=0;i<t.length;i++)(r=t[i]).cd[0].trace.selectedpoints&&r.cd[0].trace.selectedpoints.length>0&&a.push(r);if(1===a.length&&a[0]===e.searchInfo&&(n=e.searchInfo.cd[0].trace).selectedpoints.length===e.pointNumbers.length){for(i=0;i<e.pointNumbers.length;i++)if(n.selectedpoints.indexOf(e.pointNumbers[i])<0)return!1;return!0}return!1}(s,x):function(t){var e,r,n,i=0;for(n=0;n<t.length;n++)if(e=t[n],(r=e.cd[0].trace).selectedpoints){if(r.selectedpoints.length>1)return!1;if((i+=r.selectedpoints.length)>1)return!1}return 1===i}(s)&&(f=S(x))){for(o&&o.remove(),g=0;g<s.length;g++)(l=s[g])._module.selectPoints(l,!1);E(e,s),T(a),m&&e.emit(\"plotly_deselect\",null)}else{for(p=t.shiftKey&&(void 0!==f?f:S(x)),c=function(t,e,r){return{pointNumber:t,searchInfo:e,subtract:r}}(x.pointNumber,x.searchInfo,p),u=w(a.selectionDefs.concat([c])),g=0;g<s.length;g++)if(h=C(s[g]._module.selectPoints(s[g],u),s[g]),y.length)for(var b=0;b<h.length;b++)y.push(h[b]);else y=h;E(e,s,d={points:y}),c&&a&&a.selectionDefs.push(c),o&&M(a.mergedPolygons,o),m&&e.emit(\"plotly_selected\",d)}}}function b(t){return\"pointNumber\"in t&&\"searchInfo\"in t}function _(t){return{xmin:0,xmax:0,ymin:0,ymax:0,pts:[],contains:function(e,r,n,i){var a=t.searchInfo.cd[0].trace._expandedIndex;return i.cd[0].trace._expandedIndex===a&&n===t.pointNumber},isRect:!1,degenerate:!1,subtract:t.subtract}}function w(t){for(var e=[],r=b(t[0])?0:t[0][0][0],n=r,i=b(t[0])?0:t[0][0][1],a=i,o=0;o<t.length;o++)if(b(t[o]))e.push(_(t[o]));else{var s=l.tester(t[o]);s.subtract=t[o].subtract,e.push(s),r=Math.min(r,s.xmin),n=Math.max(n,s.xmax),i=Math.min(i,s.ymin),a=Math.max(a,s.ymax)}return{xmin:r,xmax:n,ymin:i,ymax:a,pts:[],contains:function(t,r,n,i){for(var a=!1,o=0;o<e.length;o++)e[o].contains(t,r,n,i)&&(a=!1===e[o].subtract);return a},isRect:!1,degenerate:!1}}function k(t,e,r){var n=e._fullLayout,i=r.plotinfo,a=n._lastSelectedSubplot&&n._lastSelectedSubplot===i.id,o=t.shiftKey||t.altKey;a&&o&&i.selection&&i.selection.selectionDefs&&!r.selectionDefs?(r.selectionDefs=i.selection.selectionDefs,r.mergedPolygons=i.selection.mergedPolygons):o&&i.selection||T(r),a||(L(e),n._lastSelectedSubplot=i.id)}function T(t){var e=t.plotinfo;e.selection={},e.selection.selectionDefs=t.selectionDefs=[],e.selection.mergedPolygons=t.mergedPolygons=[]}function A(t,e,r,n){var i,a,o,s=[],l=e.map(y),c=r.map(y);for(o=0;o<t.calcdata.length;o++)if(!0===(a=(i=t.calcdata[o])[0].trace).visible&&a._module&&a._module.selectPoints)if(!n||a.subplot!==n&&a.geo!==n)if(\"splom\"===a.type&&a._xaxes[l[0]]&&a._yaxes[c[0]]){var u=p(a._module,i,e[0],r[0]);u.scene=t._fullLayout._splomScenes[a.uid],s.push(u)}else if(\"sankey\"===a.type){var f=p(a._module,i,e[0],r[0]);s.push(f)}else{if(-1===l.indexOf(a.xaxis))continue;if(-1===c.indexOf(a.yaxis))continue;s.push(p(a._module,i,h(t,a.xaxis),h(t,a.yaxis)))}else s.push(p(a._module,i,e[0],r[0]));return s;function p(t,e,r,n){return{_module:t,cd:e,xaxis:r,yaxis:n}}}function M(t,e){var r,n,i=[];for(r=0;r<t.length;r++){var a=t[r];i.push(a.join(\"L\")+\"L\"+a[0])}n=t.length>0?\"M\"+i.join(\"M\")+\"Z\":\"M0,0Z\",e.attr(\"d\",n)}function S(t){var e=t.searchInfo.cd[0].trace,r=t.pointNumber,n=t.pointNumbers,i=n.length>0?n[0]:r;return!!e.selectedpoints&&e.selectedpoints.indexOf(i)>-1}function E(t,e,r){var n,a,o,s;for(n=0;n<e.length;n++){var l=e[n].cd[0].trace._fullInput,c=t._fullLayout._tracePreGUI[l.uid]||{};void 0===c.selectedpoints&&(c.selectedpoints=l._input.selectedpoints||null)}if(r){var u=r.points||[];for(n=0;n<e.length;n++)(s=e[n].cd[0].trace)._input.selectedpoints=s._fullInput.selectedpoints=[],s._fullInput!==s&&(s.selectedpoints=[]);for(n=0;n<u.length;n++){var h=u[n],d=h.data,g=h.fullData;h.pointIndices?([].push.apply(d.selectedpoints,h.pointIndices),s._fullInput!==s&&[].push.apply(g.selectedpoints,h.pointIndices)):(d.selectedpoints.push(h.pointIndex),s._fullInput!==s&&g.selectedpoints.push(h.pointIndex))}}else for(n=0;n<e.length;n++)delete(s=e[n].cd[0].trace).selectedpoints,delete s._input.selectedpoints,s._fullInput!==s&&delete s._fullInput.selectedpoints;var v=!1;for(n=0;n<e.length;n++){s=(o=(a=e[n]).cd)[0].trace,i.traceIs(s,\"regl\")&&(v=!0);var m=a._module,y=m.styleOnSelect||m.style;y&&(y(t,o,o[0].node3),o[0].nodeRangePlot3&&y(t,o,o[0].nodeRangePlot3))}v&&(f(t),p(t))}function C(t,e){if(Array.isArray(t))for(var r=e.cd,n=e.cd[0].trace,i=0;i<t.length;i++)t[i]=u(t[i],n,r);return t}function L(t){var e=(t._fullLayout||{})._zoomlayer;e&&e.selectAll(\".select-outline\").remove()}e.exports={prepSelect:function(t,e,r,i,l){var u,h,f,p,y,b,_,S=i.gd,L=S._fullLayout,P=L._zoomlayer,O=i.element.getBoundingClientRect(),z=i.plotinfo,I=z.xaxis._offset,D=z.yaxis._offset,R=e-O.left,F=r-O.top,B=R,N=F,j=\"M\"+R+\",\"+F,U=i.xaxes[0]._length,V=i.yaxes[0]._length,q=i.xaxes.concat(i.yaxes),H=t.altKey;k(t,S,i),\"lasso\"===l&&(u=v([[R,F]],d.BENDPX));var G=P.selectAll(\"path.select-outline-\"+z.id).data([1,2]);G.enter().append(\"path\").attr(\"class\",function(t){return\"select-outline select-outline-\"+t+\" select-outline-\"+z.id}).attr(\"transform\",\"translate(\"+I+\", \"+D+\")\").attr(\"d\",j+\"Z\");var Y,W=P.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:a.background,stroke:a.defaultLine,\"stroke-width\":1}).attr(\"transform\",\"translate(\"+I+\", \"+D+\")\").attr(\"d\",\"M0,0Z\"),X=L._uid+d.SELECTID,Z=[],J=A(S,i.xaxes,i.yaxes,i.subplot);function K(t,e){return\"log\"===t.type?t.p2d(e):t.p2r(e)}function $(t){var e=\"y\"===t._id.charAt(0)?1:0;return function(r){return K(t,r[e])}}function Q(t,e){return t-e}Y=z.fillRangeItems?z.fillRangeItems:\"select\"===l?function(t,e){var r=t.range={};for(y=0;y<q.length;y++){var n=q[y],i=n._id.charAt(0);r[n._id]=[K(n,e[i+\"min\"]),K(n,e[i+\"max\"])].sort(Q)}}:function(t,e,r){var n=t.lassoPoints={};for(y=0;y<q.length;y++){var i=q[y];n[i._id]=r.filtered.map($(i))}},i.moveFn=function(t,e){B=Math.max(0,Math.min(U,t+R)),N=Math.max(0,Math.min(V,e+F));var r=Math.abs(B-R),a=Math.abs(N-F);if(\"select\"===l){var o=L.selectdirection;\"h\"===(o=\"any\"===L.selectdirection?a<Math.min(.6*r,g)?\"h\":r<Math.min(.6*a,g)?\"v\":\"d\":L.selectdirection)?((p=[[R,0],[R,V],[B,V],[B,0]]).xmin=Math.min(R,B),p.xmax=Math.max(R,B),p.ymin=Math.min(0,V),p.ymax=Math.max(0,V),W.attr(\"d\",\"M\"+p.xmin+\",\"+(F-g)+\"h-4v\"+2*g+\"h4ZM\"+(p.xmax-1)+\",\"+(F-g)+\"h4v\"+2*g+\"h-4Z\")):\"v\"===o?((p=[[0,F],[0,N],[U,N],[U,F]]).xmin=Math.min(0,U),p.xmax=Math.max(0,U),p.ymin=Math.min(F,N),p.ymax=Math.max(F,N),W.attr(\"d\",\"M\"+(R-g)+\",\"+p.ymin+\"v-4h\"+2*g+\"v4ZM\"+(R-g)+\",\"+(p.ymax-1)+\"v4h\"+2*g+\"v-4Z\")):\"d\"===o&&((p=[[R,F],[R,N],[B,N],[B,F]]).xmin=Math.min(R,B),p.xmax=Math.max(R,B),p.ymin=Math.min(F,N),p.ymax=Math.max(F,N),W.attr(\"d\",\"M0,0Z\"))}else\"lasso\"===l&&(u.addPt([B,N]),p=u.filtered);i.selectionDefs&&i.selectionDefs.length?(f=function(t,e,r){return r?n.difference({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions:n.union({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions}(i.mergedPolygons,p,H),p.subtract=H,h=w(i.selectionDefs.concat([p]))):(f=[p],h=m(p)),M(f,G),c.throttle(X,d.SELECTDELAY,function(){var t;Z=[];var e,r=[];for(y=0;y<J.length;y++)if(e=(b=J[y])._module.selectPoints(b,h),r.push(e),t=C(e,b),Z.length)for(var n=0;n<t.length;n++)Z.push(t[n]);else Z=t;E(S,J,_={points:Z}),Y(_,p,u),i.gd.emit(\"plotly_selecting\",_)})},i.clickFn=function(t,e){var r=L.clickmode;W.remove(),c.done(X).then(function(){if(c.clear(X),2===t){for(G.remove(),y=0;y<J.length;y++)(b=J[y])._module.selectPoints(b,!1);E(S,J),T(i),S.emit(\"plotly_deselect\",null)}else r.indexOf(\"select\")>-1&&x(e,S,i.xaxes,i.yaxes,i.subplot,i,G),\"event\"===r&&S.emit(\"plotly_selected\",void 0);o.click(S,e)}).catch(s.error)},i.doneFn=function(){W.remove(),c.done(X).then(function(){c.clear(X),i.gd.emit(\"plotly_selected\",_),p&&i.selectionDefs&&(p.subtract=H,i.selectionDefs.push(p),i.mergedPolygons.length=0,[].push.apply(i.mergedPolygons,f)),i.doneFnCompleted&&i.doneFnCompleted(Z)}).catch(s.error)}},clearSelect:L,selectOnClick:x}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../components/fx/helpers\":628,\"../../lib\":719,\"../../lib/clear_gl_canvases\":704,\"../../lib/polygon\":731,\"../../lib/throttle\":744,\"../../plot_api/subroutines\":758,\"../../registry\":847,\"./axis_ids\":770,\"./constants\":773,polybooljs:473}],785:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=a.cleanNumber,s=a.ms2DateTime,l=a.dateTime2ms,c=a.ensureNumber,u=a.isArrayOrTypedArray,h=t(\"../../constants/numerical\"),f=h.FP_SAFE,p=h.BADNUM,d=h.LOG_CLIP,g=t(\"./constants\"),v=t(\"./axis_ids\");function m(t){return Math.pow(10,t)}function y(t){return null!=t}e.exports=function(t,e){e=e||{};var r=t._id||\"x\",h=r.charAt(0);function x(e,r){if(e>0)return Math.log(e)/Math.LN10;if(e<=0&&r&&t.range&&2===t.range.length){var n=t.range[0],i=t.range[1];return.5*(n+i-2*d*Math.abs(n-i))}return p}function b(e,r,n){var o=l(e,n||t.calendar);if(o===p){if(!i(e))return p;e=+e;var s=Math.floor(10*a.mod(e+.05,1)),c=Math.round(e-s/10);o=l(new Date(c))+s/10}return o}function _(e,r,n){return s(e,r,n||t.calendar)}function w(e){return t._categories[Math.round(e)]}function k(e){if(y(e)){if(void 0===t._categoriesMap&&(t._categoriesMap={}),void 0!==t._categoriesMap[e])return t._categoriesMap[e];t._categories.push(\"number\"==typeof e?String(e):e);var r=t._categories.length-1;return t._categoriesMap[e]=r,r}return p}function T(e){if(t._categoriesMap)return t._categoriesMap[e]}function A(t){var e=T(t);return void 0!==e?e:i(t)?+t:void 0}function M(e){return i(e)?n.round(t._b+t._m*e,2):p}function S(e){return(e-t._b)/t._m}t.c2l=\"log\"===t.type?x:c,t.l2c=\"log\"===t.type?m:c,t.l2p=M,t.p2l=S,t.c2p=\"log\"===t.type?function(t,e){return M(x(t,e))}:M,t.p2c=\"log\"===t.type?function(t){return m(S(t))}:S,-1!==[\"linear\",\"-\"].indexOf(t.type)?(t.d2r=t.r2d=t.d2c=t.r2c=t.d2l=t.r2l=o,t.c2d=t.c2r=t.l2d=t.l2r=c,t.d2p=t.r2p=function(e){return t.l2p(o(e))},t.p2d=t.p2r=S,t.cleanPos=c):\"log\"===t.type?(t.d2r=t.d2l=function(t,e){return x(o(t),e)},t.r2d=t.r2c=function(t){return m(o(t))},t.d2c=t.r2l=o,t.c2d=t.l2r=c,t.c2r=x,t.l2d=m,t.d2p=function(e,r){return t.l2p(t.d2r(e,r))},t.p2d=function(t){return m(S(t))},t.r2p=function(e){return t.l2p(o(e))},t.p2r=S,t.cleanPos=c):\"date\"===t.type?(t.d2r=t.r2d=a.identity,t.d2c=t.r2c=t.d2l=t.r2l=b,t.c2d=t.c2r=t.l2d=t.l2r=_,t.d2p=t.r2p=function(e,r,n){return t.l2p(b(e,0,n))},t.p2d=t.p2r=function(t,e,r){return _(S(t),e,r)},t.cleanPos=function(e){return a.cleanDate(e,p,t.calendar)}):\"category\"===t.type?(t.d2c=t.d2l=k,t.r2d=t.c2d=t.l2d=w,t.d2r=t.d2l_noadd=A,t.r2c=function(e){var r=A(e);return void 0!==r?r:t.fraction2r(.5)},t.l2r=t.c2r=c,t.r2l=A,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return w(S(t))},t.r2p=t.d2p,t.p2r=S,t.cleanPos=function(t){return\"string\"==typeof t&&\"\"!==t?t:c(t)}):\"multicategory\"===t.type&&(t.r2d=t.c2d=t.l2d=w,t.d2r=t.d2l_noadd=A,t.r2c=function(e){var r=A(e);return void 0!==r?r:t.fraction2r(.5)},t.r2c_just_indices=T,t.l2r=t.c2r=c,t.r2l=A,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return w(S(t))},t.r2p=t.d2p,t.p2r=S,t.cleanPos=function(t){return Array.isArray(t)||\"string\"==typeof t&&\"\"!==t?t:c(t)},t.setupMultiCategory=function(n){var i,o,s=t._traceIndices,l=e._axisMatchGroups;if(l&&l.length&&0===t._categories.length)for(i=0;i<l.length;i++){var c=l[i];if(c[r])for(var f in c)if(f!==r){var p=e[v.id2name(f)];s=s.concat(p._traceIndices)}}var d=[[0,{}],[0,{}]],g=[];for(i=0;i<s.length;i++){var m=n[s[i]];if(h in m){var x=m[h],b=m._length||a.minRowLength(x);if(u(x[0])&&u(x[1]))for(o=0;o<b;o++){var _=x[0][o],w=x[1][o];y(_)&&y(w)&&(g.push([_,w]),_ in d[0][1]||(d[0][1][_]=d[0][0]++),w in d[1][1]||(d[1][1][w]=d[1][0]++))}}}for(g.sort(function(t,e){var r=d[0][1],n=r[t[0]]-r[e[0]];if(n)return n;var i=d[1][1];return i[t[1]]-i[e[1]]}),i=0;i<g.length;i++)k(g[i])}),t.fraction2r=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return t.l2r(r+e*(n-r))},t.r2fraction=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return(t.r2l(e)-r)/(n-r)},t.cleanRange=function(e,r){r||(r={}),e||(e=\"range\");var n,o,s=a.nestedProperty(t,e).get();if(o=(o=\"date\"===t.type?a.dfltRange(t.calendar):\"y\"===h?g.DFLTRANGEY:r.dfltRange||g.DFLTRANGEX).slice(),s&&2===s.length)for(\"date\"!==t.type||t.autorange||(s[0]=a.cleanDate(s[0],p,t.calendar),s[1]=a.cleanDate(s[1],p,t.calendar)),n=0;n<2;n++)if(\"date\"===t.type){if(!a.isDateTime(s[n],t.calendar)){t[e]=o;break}if(t.r2l(s[0])===t.r2l(s[1])){var l=a.constrain(t.r2l(s[0]),a.MIN_MS+1e3,a.MAX_MS-1e3);s[0]=t.l2r(l-1e3),s[1]=t.l2r(l+1e3);break}}else{if(!i(s[n])){if(!i(s[1-n])){t[e]=o;break}s[n]=s[1-n]*(n?10:.1)}if(s[n]<-f?s[n]=-f:s[n]>f&&(s[n]=f),s[0]===s[1]){var c=Math.max(1,Math.abs(1e-6*s[0]));s[0]-=c,s[1]+=c}}else a.nestedProperty(t,e).set(o)},t.setScale=function(r){var n=e._size;if(t.overlaying){var i=v.getFromId({_fullLayout:e},t.overlaying);t.domain=i.domain}var a=r&&t._r?\"_r\":\"range\",o=t.calendar;t.cleanRange(a);var s=t.r2l(t[a][0],o),l=t.r2l(t[a][1],o);if(\"y\"===h?(t._offset=n.t+(1-t.domain[1])*n.h,t._length=n.h*(t.domain[1]-t.domain[0]),t._m=t._length/(s-l),t._b=-t._m*l):(t._offset=n.l+t.domain[0]*n.w,t._length=n.w*(t.domain[1]-t.domain[0]),t._m=t._length/(l-s),t._b=-t._m*s),!isFinite(t._m)||!isFinite(t._b)||t._length<0)throw e._replotting=!1,new Error(\"Something went wrong with axis scaling\")},t.makeCalcdata=function(e,r){var n,i,o,s,l=t.type,c=\"date\"===l&&e[r+\"calendar\"];if(r in e){if(n=e[r],s=e._length||a.minRowLength(n),a.isTypedArray(n)&&(\"linear\"===l||\"log\"===l)){if(s===n.length)return n;if(n.subarray)return n.subarray(0,s)}if(\"multicategory\"===l)return function(t,e){for(var r=new Array(e),n=0;n<e;n++){var i=(t[0]||[])[n],a=(t[1]||[])[n];r[n]=T([i,a])}return r}(n,s);for(i=new Array(s),o=0;o<s;o++)i[o]=t.d2c(n[o],0,c)}else{var u=r+\"0\"in e?t.d2c(e[r+\"0\"],0,c):0,h=e[\"d\"+r]?Number(e[\"d\"+r]):1;for(n=e[{x:\"y\",y:\"x\"}[r]],s=e._length||n.length,i=new Array(s),o=0;o<s;o++)i[o]=u+o*h}return i},t.isValidRange=function(e){return Array.isArray(e)&&2===e.length&&i(t.r2l(e[0]))&&i(t.r2l(e[1]))},t.isPtWithinRange=function(e,r){var n=t.c2l(e[h],null,r),i=t.r2l(t.range[0]),a=t.r2l(t.range[1]);return i<a?i<=n&&n<=a:a<=n&&n<=i},t.clearCalc=function(){var n=function(){t._categories=[],t._categoriesMap={}},i=e._axisMatchGroups;if(i&&i.length){for(var a=!1,o=0;o<i.length;o++){var s=i[o];if(s[r]){a=!0;var l=null,c=null;for(var u in s){var h=e[v.id2name(u)];if(h._categories){l=h._categories,c=h._categoriesMap;break}}l&&c?(t._categories=l,t._categoriesMap=c):n();break}}a||n()}else n();if(t._initialCategories)for(var f=0;f<t._initialCategories.length;f++)k(t._initialCategories[f])},t.sortByInitialCategories=function(){var n=[];if(t._categories=[],t._categoriesMap={},t._initialCategories)for(var i=0;i<t._initialCategories.length;i++)k(t._initialCategories[i]);n=n.concat(t._traceIndices);var a=t._matchGroup;for(var o in a)if(r!==o){var s=e[v.id2name(o)];s._categories=t._categories,s._categoriesMap=t._categoriesMap,n=n.concat(s._traceIndices)}return n};var E=e._d3locale;\"date\"===t.type&&(t._dateFormat=E?E.timeFormat.utc:n.time.format.utc,t._extraFormat=e._extraFormat),t._separators=e.separators,t._numFormat=E?E.numberFormat:n.format,delete t._minDtick,delete t._forceTick0}},{\"../../constants/numerical\":695,\"../../lib\":719,\"./axis_ids\":770,\"./constants\":773,d3:163,\"fast-isnumeric\":225}],786:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"../array_container_defaults\");function o(t){var e=[\"showexponent\",\"showtickprefix\",\"showticksuffix\"].filter(function(e){return void 0!==t[e]});if(e.every(function(r){return t[r]===t[e[0]]})||1===e.length)return t[e[0]]}function s(t,e){function r(r,a){return n.coerce(t,e,i.tickformatstops,r,a)}r(\"enabled\")&&(r(\"dtickrange\"),r(\"value\"))}e.exports=function(t,e,r,l,c,u){u&&1!==u.pass||function(t,e,r,n,i){var a=o(t);r(\"tickprefix\")&&r(\"showtickprefix\",a);r(\"ticksuffix\",i.tickSuffixDflt)&&r(\"showticksuffix\",a)}(t,0,r,0,c),u&&2!==u.pass||function(t,e,r,l,c){var u=o(t);r(\"tickprefix\")&&r(\"showtickprefix\",u);r(\"ticksuffix\",c.tickSuffixDflt)&&r(\"showticksuffix\",u);if(r(\"showticklabels\")){var h=c.font||{},f=e.color,p=f&&f!==i.color.dflt?f:h.color;if(n.coerceFont(r,\"tickfont\",{family:h.family,size:h.size,color:p}),r(\"tickangle\"),\"category\"!==l){var d=r(\"tickformat\"),g=t.tickformatstops;Array.isArray(g)&&g.length&&a(t,e,{name:\"tickformatstops\",inclusionAttr:\"enabled\",handleItemDefaults:s}),d||\"date\"===l||(r(\"showexponent\",u),r(\"exponentformat\"),r(\"separatethousands\"))}}}(t,e,r,l,c)}},{\"../../lib\":719,\"../array_container_defaults\":763,\"./layout_attributes\":779}],787:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r,a){var o=n.coerce2(t,e,i,\"ticklen\"),s=n.coerce2(t,e,i,\"tickwidth\"),l=n.coerce2(t,e,i,\"tickcolor\",e.color);r(\"ticks\",a.outerTicks||o||s||l?\"outside\":\"\")||(delete e.ticklen,delete e.tickwidth,delete e.tickcolor)}},{\"../../lib\":719,\"./layout_attributes\":779}],788:[function(t,e,r){\"use strict\";var n=t(\"./clean_ticks\");e.exports=function(t,e,r,i){var a;\"array\"!==t.tickmode||\"log\"!==i&&\"date\"!==i?a=r(\"tickmode\",Array.isArray(t.tickvals)?\"array\":t.dtick?\"linear\":\"auto\"):a=e.tickmode=\"auto\";if(\"auto\"===a)r(\"nticks\");else if(\"linear\"===a){var o=e.dtick=n.dtick(t.dtick,i);e.tick0=n.tick0(t.tick0,i,e.calendar,o)}else if(\"multicategory\"!==i){void 0===r(\"tickvals\")?e.tickmode=\"auto\":r(\"ticktext\")}}},{\"./clean_ticks\":772}],789:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../components/drawing\"),o=t(\"./axes\");e.exports=function(t,e,r,s){var l=t._fullLayout;if(0!==e.length){var c,u,h,f;s&&(c=s());var p=n.ease(r.easing);return t._transitionData._interruptCallbacks.push(function(){return window.cancelAnimationFrame(f),f=null,function(){for(var r={},n=0;n<e.length;n++){var a=e[n];a.xr0&&(r[a.plotinfo.xaxis._name+\".range\"]=a.xr0.slice()),a.yr0&&(r[a.plotinfo.yaxis._name+\".range\"]=a.yr0.slice())}return i.call(\"relayout\",t,r).then(function(){for(var t=0;t<e.length;t++)d(e[t].plotinfo)})}()}),u=Date.now(),f=window.requestAnimationFrame(function n(){h=Date.now();for(var a=Math.min(1,(h-u)/r.duration),o=p(a),s=0;s<e.length;s++)g(e[s],o);h-u>r.duration?(function(){for(var r={},n=0;n<e.length;n++){var a=e[n];a.xr1&&(r[a.plotinfo.xaxis._name+\".range\"]=a.xr1.slice()),a.yr1&&(r[a.plotinfo.yaxis._name+\".range\"]=a.yr1.slice())}c&&c(),i.call(\"relayout\",t,r).then(function(){for(var t=0;t<e.length;t++)d(e[t].plotinfo)})}(),f=window.cancelAnimationFrame(n)):f=window.requestAnimationFrame(n)}),Promise.resolve()}function d(t){var e=t.xaxis,r=t.yaxis;l._defs.select(\"#\"+t.clipId+\"> rect\").call(a.setTranslate,0,0).call(a.setScale,1,1),t.plot.call(a.setTranslate,e._offset,r._offset).call(a.setScale,1,1);var n=t.plot.selectAll(\".scatterlayer .trace\");n.selectAll(\".point\").call(a.setPointGroupScale,1,1),n.selectAll(\".textpoint\").call(a.setTextPointsScale,1,1),n.call(a.hideOutsideRangePoints,t)}function g(e,r){var n=e.plotinfo,i=n.xaxis,s=n.yaxis,l=e.xr0,c=e.xr1,u=i._length,h=e.yr0,f=e.yr1,p=s._length,d=!!c,g=!!f,v=[];if(d){var m=l[1]-l[0],y=c[1]-c[0];v[0]=(l[0]*(1-r)+r*c[0]-l[0])/(l[1]-l[0])*u,v[2]=u*(1-r+r*y/m),i.range[0]=l[0]*(1-r)+r*c[0],i.range[1]=l[1]*(1-r)+r*c[1]}else v[0]=0,v[2]=u;if(g){var x=h[1]-h[0],b=f[1]-f[0];v[1]=(h[1]*(1-r)+r*f[1]-h[1])/(h[0]-h[1])*p,v[3]=p*(1-r+r*b/x),s.range[0]=h[0]*(1-r)+r*f[0],s.range[1]=h[1]*(1-r)+r*f[1]}else v[1]=0,v[3]=p;o.drawOne(t,i,{skipTitle:!0}),o.drawOne(t,s,{skipTitle:!0}),o.redrawComponents(t,[i._id,s._id]);var _=d?u/v[2]:1,w=g?p/v[3]:1,k=d?v[0]:0,T=g?v[1]:0,A=d?v[0]/v[2]*u:0,M=g?v[1]/v[3]*p:0,S=i._offset-A,E=s._offset-M;n.clipRect.call(a.setTranslate,k,T).call(a.setScale,1/_,1/w),n.plot.call(a.setTranslate,S,E).call(a.setScale,_,w),a.setPointGroupScale(n.zoomScalePts,1/_,1/w),a.setTextPointsScale(n.zoomScaleTxt,1/_,1/w)}o.redrawComponents(t)}},{\"../../components/drawing\":614,\"../../registry\":847,\"./axes\":767,d3:163}],790:[function(t,e,r){\"use strict\";var n=t(\"../../registry\").traceIs,i=t(\"./axis_autotype\");function a(t){return{v:\"x\",h:\"y\"}[t.orientation||\"v\"]}function o(t,e){var r=a(t),i=n(t,\"box-violin\"),o=n(t._fullInput||{},\"candlestick\");return i&&!o&&e===r&&void 0===t[r]&&void 0===t[r+\"0\"]}e.exports=function(t,e,r,s){\"-\"===r(\"type\",(s.splomStash||{}).type)&&(!function(t,e){if(\"-\"!==t.type)return;var r=t._id,s=r.charAt(0);-1!==r.indexOf(\"scene\")&&(r=s);var l=function(t,e,r){for(var n=0;n<t.length;n++){var i=t[n];if(\"splom\"===i.type&&i._length>0&&(i[\"_\"+r+\"axes\"]||{})[e])return i;if((i[r+\"axis\"]||r)===e){if(o(i,r))return i;if((i[r]||[]).length||i[r+\"0\"])return i}}}(e,r,s);if(!l)return;if(\"histogram\"===l.type&&s==={v:\"y\",h:\"x\"}[l.orientation||\"v\"])return void(t.type=\"linear\");var c,u=s+\"calendar\",h=l[u],f={noMultiCategory:!n(l,\"cartesian\")||n(l,\"noMultiCategory\")};if(o(l,s)){var p=a(l),d=[];for(c=0;c<e.length;c++){var g=e[c];n(g,\"box-violin\")&&(g[s+\"axis\"]||s)===r&&(void 0!==g[p]?d.push(g[p][0]):void 0!==g.name?d.push(g.name):d.push(\"text\"),g[u]!==h&&(h=void 0))}t.type=i(d,h,f)}else if(\"splom\"===l.type){var v=l.dimensions,m=v[l._axesDim[r]];m.visible&&(t.type=i(m.values,h,f))}else t.type=i(l[s]||[l[s+\"0\"]],h,f)}(e,s.data),\"-\"===e.type?e.type=\"linear\":t.type=e.type)}},{\"../../registry\":847,\"./axis_autotype\":768}],791:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\");function a(t,e,r){var n,a,o,s=!1;if(\"data\"===e.type)n=t._fullData[null!==e.traces?e.traces[0]:0];else{if(\"layout\"!==e.type)return!1;n=t._fullLayout}return a=i.nestedProperty(n,e.prop).get(),(o=r[e.type]=r[e.type]||{}).hasOwnProperty(e.prop)&&o[e.prop]!==a&&(s=!0),o[e.prop]=a,{changed:s,value:a}}function o(t,e){var r=[],n=e[0],a={};if(\"string\"==typeof n)a[n]=e[1];else{if(!i.isPlainObject(n))return r;a=n}return l(a,function(t,e,n){r.push({type:\"layout\",prop:t,value:n})},\"\",0),r}function s(t,e){var r,n,a,o,s=[];if(n=e[0],a=e[1],r=e[2],o={},\"string\"==typeof n)o[n]=a;else{if(!i.isPlainObject(n))return s;o=n,void 0===r&&(r=a)}return void 0===r&&(r=null),l(o,function(e,n,i){var a,o;if(Array.isArray(i)){o=i.slice();var l=Math.min(o.length,t.data.length);r&&(l=Math.min(l,r.length)),a=[];for(var c=0;c<l;c++)a[c]=r?r[c]:c}else o=i,a=r?r.slice():null;if(null===a)Array.isArray(o)&&(o=o[0]);else if(Array.isArray(a)){if(!Array.isArray(o)){var u=o;o=[];for(var h=0;h<a.length;h++)o[h]=u}o.length=Math.min(a.length,o.length)}s.push({type:\"data\",prop:e,traces:a,value:o})},\"\",0),s}function l(t,e,r,n){Object.keys(t).forEach(function(a){var o=t[a];if(\"_\"!==a[0]){var s=r+(n>0?\".\":\"\")+a;i.isPlainObject(o)?l(o,e,s,n+1):e(s,a,o)}})}r.manageCommandObserver=function(t,e,n,o){var s={},l=!0;e&&e._commandObserver&&(s=e._commandObserver),s.cache||(s.cache={}),s.lookupTable={};var c=r.hasSimpleAPICommandBindings(t,n,s.lookupTable);if(e&&e._commandObserver){if(c)return s;if(e._commandObserver.remove)return e._commandObserver.remove(),e._commandObserver=null,s}if(c){a(t,c,s.cache),s.check=function(){if(l){var e=a(t,c,s.cache);return e.changed&&o&&void 0!==s.lookupTable[e.value]&&(s.disable(),Promise.resolve(o({value:e.value,type:c.type,prop:c.prop,traces:c.traces,index:s.lookupTable[e.value]})).then(s.enable,s.enable)),e.changed}};for(var u=[\"plotly_relayout\",\"plotly_redraw\",\"plotly_restyle\",\"plotly_update\",\"plotly_animatingframe\",\"plotly_afterplot\"],h=0;h<u.length;h++)t._internalOn(u[h],s.check);s.remove=function(){for(var e=0;e<u.length;e++)t._removeInternalListener(u[e],s.check)}}else i.log(\"Unable to automatically bind plot updates to API command\"),s.lookupTable={},s.remove=function(){};return s.disable=function(){l=!1},s.enable=function(){l=!0},e&&(e._commandObserver=s),s},r.hasSimpleAPICommandBindings=function(t,e,n){var i,a,o=e.length;for(i=0;i<o;i++){var s,l=e[i],c=l.method,u=l.args;if(Array.isArray(u)||(u=[]),!c)return!1;var h=r.computeAPICommandBindings(t,c,u);if(1!==h.length)return!1;if(a){if((s=h[0]).type!==a.type)return!1;if(s.prop!==a.prop)return!1;if(Array.isArray(a.traces)){if(!Array.isArray(s.traces))return!1;s.traces.sort();for(var f=0;f<a.traces.length;f++)if(a.traces[f]!==s.traces[f])return!1}else if(s.prop!==a.prop)return!1}else a=h[0],Array.isArray(a.traces)&&a.traces.sort();var p=(s=h[0]).value;if(Array.isArray(p)){if(1!==p.length)return!1;p=p[0]}n&&(n[p]=i)}return a},r.executeAPICommand=function(t,e,r){if(\"skip\"===e)return Promise.resolve();var a=n.apiMethodRegistry[e],o=[t];Array.isArray(r)||(r=[]);for(var s=0;s<r.length;s++)o.push(r[s]);return a.apply(null,o).catch(function(t){return i.warn(\"API call to Plotly.\"+e+\" rejected.\",t),Promise.reject(t)})},r.computeAPICommandBindings=function(t,e,r){var n;switch(Array.isArray(r)||(r=[]),e){case\"restyle\":n=s(t,r);break;case\"relayout\":n=o(t,r);break;case\"update\":n=s(t,[r[0],r[2]]).concat(o(t,[r[1]]));break;case\"animate\":n=function(t,e){return Array.isArray(e[0])&&1===e[0].length&&-1!==[\"string\",\"number\"].indexOf(typeof e[0][0])?[{type:\"layout\",prop:\"_currentFrame\",value:e[0][0].toString()}]:[]}(0,r);break;default:n=[]}return n}},{\"../lib\":719,\"../registry\":847}],792:[function(t,e,r){\"use strict\";var n=t(\"../lib/extend\").extendFlat;r.attributes=function(t,e){e=e||{};var r={valType:\"info_array\",editType:(t=t||{}).editType,items:[{valType:\"number\",min:0,max:1,editType:t.editType},{valType:\"number\",min:0,max:1,editType:t.editType}],dflt:[0,1]},i=(t.name&&t.name,t.trace,e.description&&e.description,{x:n({},r,{}),y:n({},r,{}),editType:t.editType});return t.noGridCell||(i.row={valType:\"integer\",min:0,dflt:0,editType:t.editType},i.column={valType:\"integer\",min:0,dflt:0,editType:t.editType}),i},r.defaults=function(t,e,r,n){var i=n&&n.x||[0,1],a=n&&n.y||[0,1],o=e.grid;if(o){var s=r(\"domain.column\");void 0!==s&&(s<o.columns?i=o._domains.x[s]:delete t.domain.column);var l=r(\"domain.row\");void 0!==l&&(l<o.rows?a=o._domains.y[l]:delete t.domain.row)}r(\"domain.x\",i),r(\"domain.y\",a)}},{\"../lib/extend\":710}],793:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType,r=t.colorEditType;void 0===r&&(r=e);var n={family:{valType:\"string\",noBlank:!0,strict:!0,editType:e},size:{valType:\"number\",min:1,editType:e},color:{valType:\"color\",editType:r},editType:e};return t.arrayOk&&(n.family.arrayOk=!0,n.size.arrayOk=!0,n.color.arrayOk=!0),n}},{}],794:[function(t,e,r){\"use strict\";e.exports={_isLinkedToArray:\"frames_entry\",group:{valType:\"string\"},name:{valType:\"string\"},traces:{valType:\"any\"},baseframe:{valType:\"string\"},data:{valType:\"any\"},layout:{valType:\"any\"}}},{}],795:[function(t,e,r){\"use strict\";r.projNames={equirectangular:\"equirectangular\",mercator:\"mercator\",orthographic:\"orthographic\",\"natural earth\":\"naturalEarth\",kavrayskiy7:\"kavrayskiy7\",miller:\"miller\",robinson:\"robinson\",eckert4:\"eckert4\",\"azimuthal equal area\":\"azimuthalEqualArea\",\"azimuthal equidistant\":\"azimuthalEquidistant\",\"conic equal area\":\"conicEqualArea\",\"conic conformal\":\"conicConformal\",\"conic equidistant\":\"conicEquidistant\",gnomonic:\"gnomonic\",stereographic:\"stereographic\",mollweide:\"mollweide\",hammer:\"hammer\",\"transverse mercator\":\"transverseMercator\",\"albers usa\":\"albersUsa\",\"winkel tripel\":\"winkel3\",aitoff:\"aitoff\",sinusoidal:\"sinusoidal\"},r.axesNames=[\"lonaxis\",\"lataxis\"],r.lonaxisSpan={orthographic:180,\"azimuthal equal area\":360,\"azimuthal equidistant\":360,\"conic conformal\":180,gnomonic:160,stereographic:180,\"transverse mercator\":180,\"*\":360},r.lataxisSpan={\"conic conformal\":150,stereographic:179.5,\"*\":180},r.scopeDefaults={world:{lonaxisRange:[-180,180],lataxisRange:[-90,90],projType:\"equirectangular\",projRotate:[0,0,0]},usa:{lonaxisRange:[-180,-50],lataxisRange:[15,80],projType:\"albers usa\"},europe:{lonaxisRange:[-30,60],lataxisRange:[30,85],projType:\"conic conformal\",projRotate:[15,0,0],projParallels:[0,60]},asia:{lonaxisRange:[22,160],lataxisRange:[-15,55],projType:\"mercator\",projRotate:[0,0,0]},africa:{lonaxisRange:[-30,60],lataxisRange:[-40,40],projType:\"mercator\",projRotate:[0,0,0]},\"north america\":{lonaxisRange:[-180,-45],lataxisRange:[5,85],projType:\"conic conformal\",projRotate:[-100,0,0],projParallels:[29.5,45.5]},\"south america\":{lonaxisRange:[-100,-30],lataxisRange:[-60,15],projType:\"mercator\",projRotate:[0,0,0]}},r.clipPad=.001,r.precision=.1,r.landColor=\"#F0DC82\",r.waterColor=\"#3399FF\",r.locationmodeToLayer={\"ISO-3\":\"countries\",\"USA-states\":\"subunits\",\"country names\":\"countries\"},r.sphereSVG={type:\"Sphere\"},r.fillLayers={ocean:1,land:1,lakes:1},r.lineLayers={subunits:1,countries:1,coastlines:1,rivers:1,frame:1},r.layers=[\"bg\",\"ocean\",\"land\",\"lakes\",\"subunits\",\"countries\",\"coastlines\",\"rivers\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"frontplot\"],r.layersForChoropleth=[\"bg\",\"ocean\",\"land\",\"subunits\",\"countries\",\"coastlines\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"rivers\",\"lakes\",\"frontplot\"],r.layerNameToAdjective={ocean:\"ocean\",land:\"land\",lakes:\"lake\",subunits:\"subunit\",countries:\"country\",coastlines:\"coastline\",rivers:\"river\",frame:\"frame\"}},{}],796:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"../../components/fx\"),c=t(\"../plots\"),u=t(\"../cartesian/axes\"),h=t(\"../../components/dragelement\"),f=t(\"../cartesian/select\").prepSelect,p=t(\"../cartesian/select\").selectOnClick,d=t(\"./zoom\"),g=t(\"./constants\"),v=t(\"../../lib/topojson_utils\"),m=t(\"topojson-client\").feature;function y(t){this.id=t.id,this.graphDiv=t.graphDiv,this.container=t.container,this.topojsonURL=t.topojsonURL,this.isStatic=t.staticPlot,this.topojsonName=null,this.topojson=null,this.projection=null,this.scope=null,this.viewInitial=null,this.fitScale=null,this.bounds=null,this.midPt=null,this.hasChoropleth=!1,this.traceHash={},this.layers={},this.basePaths={},this.dataPaths={},this.dataPoints={},this.clipDef=null,this.clipRect=null,this.bgRect=null,this.makeFramework()}t(\"./projections\")(n);var x=y.prototype;e.exports=function(t){return new y(t)},x.plot=function(t,e,r){var n=this,i=e[this.id],a=!1;for(var o in g.layerNameToAdjective)if(\"frame\"!==o&&i[\"show\"+o]){a=!0;break}for(var s=0;s<t.length;s++)if(t[0][0].trace.locationmode){a=!0;break}if(!a)return n.update(t,e);var l=v.getTopojsonName(i);null===n.topojson||l!==n.topojsonName?(n.topojsonName=l,void 0===PlotlyGeoAssets.topojson[n.topojsonName]?r.push(n.fetchTopojson().then(function(r){PlotlyGeoAssets.topojson[n.topojsonName]=r,n.topojson=r,n.update(t,e)})):(n.topojson=PlotlyGeoAssets.topojson[n.topojsonName],n.update(t,e))):n.update(t,e)},x.fetchTopojson=function(){var t=v.getTopojsonPath(this.topojsonURL,this.topojsonName);return new Promise(function(e,r){n.json(t,function(n,i){if(n)return 404===n.status?r(new Error([\"plotly.js could not find topojson file at\",t,\".\",\"Make sure the *topojsonURL* plot config option\",\"is set properly.\"].join(\" \"))):r(new Error([\"unexpected error while fetching topojson file at\",t].join(\" \")));e(i)})})},x.update=function(t,e){var r=e[this.id];if(!this.updateProjection(e,r)){this.hasChoropleth=!1;for(var n=0;n<t.length;n++)if(\"choropleth\"===t[n][0].trace.type){this.hasChoropleth=!0;break}this.viewInitial&&this.scope===r.scope||this.saveViewInitial(r),this.scope=r.scope,this.updateBaseLayers(e,r),this.updateDims(e,r),this.updateFx(e,r),c.generalUpdatePerTraceModule(this.graphDiv,this,t,r);var i=this.layers.frontplot.select(\".scatterlayer\");this.dataPoints.point=i.selectAll(\".point\"),this.dataPoints.text=i.selectAll(\"text\"),this.dataPaths.line=i.selectAll(\".js-line\");var a=this.layers.backplot.select(\".choroplethlayer\");this.dataPaths.choropleth=a.selectAll(\"path\"),this.render()}},x.updateProjection=function(t,e){var r=t._size,o=e.domain,s=e.projection,l=s.rotation||{},c=e.center||{},u=this.projection=function(t){for(var e=t.projection.type,r=n.geo[g.projNames[e]](),i=t._isClipped?g.lonaxisSpan[e]/2:null,a=[\"center\",\"rotate\",\"parallels\",\"clipExtent\"],o=function(t){return t?r:[]},s=0;s<a.length;s++){var l=a[s];\"function\"!=typeof r[l]&&(r[l]=o)}r.isLonLatOverEdges=function(t){if(null===r(t))return!0;if(i){var e=r.rotate();return n.geo.distance(t,[-e[0],-e[1]])>i*Math.PI/180}return!1},r.getPath=function(){return n.geo.path().projection(r)},r.getBounds=function(t){return r.getPath().bounds(t)},r.fitExtent=function(t,e){var n=t[1][0]-t[0][0],i=t[1][1]-t[0][1],a=r.clipExtent&&r.clipExtent();r.scale(150).translate([0,0]),a&&r.clipExtent(null);var o=r.getBounds(e),s=Math.min(n/(o[1][0]-o[0][0]),i/(o[1][1]-o[0][1])),l=+t[0][0]+(n-s*(o[1][0]+o[0][0]))/2,c=+t[0][1]+(i-s*(o[1][1]+o[0][1]))/2;return a&&r.clipExtent(a),r.scale(150*s).translate([l,c])},r.precision(g.precision),i&&r.clipAngle(i-g.clipPad);return r}(e);u.center([c.lon-l.lon,c.lat-l.lat]).rotate([-l.lon,-l.lat,l.roll]).parallels(s.parallels);var h=[[r.l+r.w*o.x[0],r.t+r.h*(1-o.y[1])],[r.l+r.w*o.x[1],r.t+r.h*(1-o.y[0])]],f=e.lonaxis,p=e.lataxis,d=function(t,e){var r=g.clipPad,n=t[0]+r,i=t[1]-r,a=e[0]+r,o=e[1]-r;n>0&&i<0&&(i+=360);var s=(i-n)/4;return{type:\"Polygon\",coordinates:[[[n,a],[n,o],[n+s,o],[n+2*s,o],[n+3*s,o],[i,o],[i,a],[i-s,a],[i-2*s,a],[i-3*s,a],[n,a]]]}}(f.range,p.range);u.fitExtent(h,d);var v=this.bounds=u.getBounds(d),m=this.fitScale=u.scale(),y=u.translate();if(!isFinite(v[0][0])||!isFinite(v[0][1])||!isFinite(v[1][0])||!isFinite(v[1][1])||isNaN(y[0])||isNaN(y[0])){for(var x=this.graphDiv,b=[\"projection.rotation\",\"center\",\"lonaxis.range\",\"lataxis.range\"],_=\"Invalid geo settings, relayout'ing to default view.\",w={},k=0;k<b.length;k++)w[this.id+\".\"+b[k]]=null;return this.viewInitial=null,a.warn(_),x._promises.push(i.call(\"relayout\",x,w)),_}var T=this.midPt=[(v[0][0]+v[1][0])/2,(v[0][1]+v[1][1])/2];if(u.scale(s.scale*m).translate([y[0]+(T[0]-y[0]),y[1]+(T[1]-y[1])]).clipExtent(v),e._isAlbersUsa){var A=u([c.lon,c.lat]),M=u.translate();u.translate([M[0]-(A[0]-M[0]),M[1]-(A[1]-M[1])])}},x.updateBaseLayers=function(t,e){var r=this,i=r.topojson,a=r.layers,l=r.basePaths;function c(t){return\"lonaxis\"===t||\"lataxis\"===t}function h(t){return Boolean(g.lineLayers[t])}function f(t){return Boolean(g.fillLayers[t])}var p=(this.hasChoropleth?g.layersForChoropleth:g.layers).filter(function(t){return h(t)||f(t)?e[\"show\"+t]:!c(t)||e[t].showgrid}),d=r.framework.selectAll(\".layer\").data(p,String);d.exit().each(function(t){delete a[t],delete l[t],n.select(this).remove()}),d.enter().append(\"g\").attr(\"class\",function(t){return\"layer \"+t}).each(function(t){var e=a[t]=n.select(this);\"bg\"===t?r.bgRect=e.append(\"rect\").style(\"pointer-events\",\"all\"):c(t)?l[t]=e.append(\"path\").style(\"fill\",\"none\"):\"backplot\"===t?e.append(\"g\").classed(\"choroplethlayer\",!0):\"frontplot\"===t?e.append(\"g\").classed(\"scatterlayer\",!0):h(t)?l[t]=e.append(\"path\").style(\"fill\",\"none\").style(\"stroke-miterlimit\",2):f(t)&&(l[t]=e.append(\"path\").style(\"stroke\",\"none\"))}),d.order(),d.each(function(r){var n=l[r],a=g.layerNameToAdjective[r];\"frame\"===r?n.datum(g.sphereSVG):h(r)||f(r)?n.datum(m(i,i.objects[r])):c(r)&&n.datum(function(t,e,r){var n,i,a,o=e[t],s=g.scopeDefaults[e.scope];\"lonaxis\"===t?(n=s.lonaxisRange,i=s.lataxisRange,a=function(t,e){return[t,e]}):\"lataxis\"===t&&(n=s.lataxisRange,i=s.lonaxisRange,a=function(t,e){return[e,t]});var l={type:\"linear\",range:[n[0],n[1]-1e-6],tick0:o.tick0,dtick:o.dtick};u.setConvert(l,r);var c=u.calcTicks(l);e.isScoped||\"lonaxis\"!==t||c.pop();for(var h=c.length,f=new Array(h),p=0;p<h;p++)for(var d=c[p].x,v=f[p]=[],m=i[0];m<i[1]+2.5;m+=2.5)v.push(a(d,m));return{type:\"MultiLineString\",coordinates:f}}(r,e,t)).call(o.stroke,e[r].gridcolor).call(s.dashLine,\"\",e[r].gridwidth),h(r)?n.call(o.stroke,e[a+\"color\"]).call(s.dashLine,\"\",e[a+\"width\"]):f(r)&&n.call(o.fill,e[a+\"color\"])})},x.updateDims=function(t,e){var r=this.bounds,n=(e.framewidth||0)/2,i=r[0][0]-n,a=r[0][1]-n,l=r[1][0]-i+n,c=r[1][1]-a+n;s.setRect(this.clipRect,i,a,l,c),this.bgRect.call(s.setRect,i,a,l,c).call(o.fill,e.bgcolor),this.xaxis._offset=i,this.xaxis._length=l,this.yaxis._offset=a,this.yaxis._length=c},x.updateFx=function(t,e){var r=this,a=r.graphDiv,o=r.bgRect,s=t.dragmode,c=t.clickmode;if(!r.isStatic){var u;\"select\"===s?u=function(t,e){(t.range={})[r.id]=[v([e.xmin,e.ymin]),v([e.xmax,e.ymax])]}:\"lasso\"===s&&(u=function(t,e,n){(t.lassoPoints={})[r.id]=n.filtered.map(v)});var g={element:r.bgRect.node(),gd:a,plotinfo:{id:r.id,xaxis:r.xaxis,yaxis:r.yaxis,fillRangeItems:u},xaxes:[r.xaxis],yaxes:[r.yaxis],subplot:r.id,clickFn:function(e){2===e&&t._zoomlayer.selectAll(\".select-outline\").remove()}};\"pan\"===s?(o.node().onmousedown=null,o.call(d(r,e)),o.on(\"dblclick.zoom\",function(){var t=r.viewInitial,e={};for(var n in t)e[r.id+\".\"+n]=t[n];i.call(\"_guiRelayout\",a,e),a.emit(\"plotly_doubleclick\",null)}),a._context._scrollZoom.geo||o.on(\"wheel.zoom\",null)):\"select\"!==s&&\"lasso\"!==s||(o.on(\".zoom\",null),g.prepFn=function(t,e,r){f(t,e,r,g,s)},h.init(g)),o.on(\"mousemove\",function(){var t=r.projection.invert(n.mouse(this));if(!t||isNaN(t[0])||isNaN(t[1]))return h.unhover(a,n.event);r.xaxis.p2c=function(){return t[0]},r.yaxis.p2c=function(){return t[1]},l.hover(a,n.event,r.id)}),o.on(\"mouseout\",function(){a._dragging||h.unhover(a,n.event)}),o.on(\"click\",function(){\"select\"!==s&&\"lasso\"!==s&&(c.indexOf(\"select\")>-1&&p(n.event,a,[r.xaxis],[r.yaxis],r.id,g),c.indexOf(\"event\")>-1&&l.click(a,n.event))})}function v(t){return r.projection.invert([t[0]+r.xaxis._offset,t[1]+r.yaxis._offset])}},x.makeFramework=function(){var t=this,e=t.graphDiv,r=e._fullLayout,i=\"clip\"+r._uid+t.id;t.clipDef=r._clips.append(\"clipPath\").attr(\"id\",i),t.clipRect=t.clipDef.append(\"rect\"),t.framework=n.select(t.container).append(\"g\").attr(\"class\",\"geo \"+t.id).call(s.setClipUrl,i,e),t.project=function(e){var r=t.projection(e);return r?[r[0]-t.xaxis._offset,r[1]-t.yaxis._offset]:[null,null]},t.xaxis={_id:\"x\",c2p:function(e){return t.project(e)[0]}},t.yaxis={_id:\"y\",c2p:function(e){return t.project(e)[1]}},t.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},u.setConvert(t.mockAxis,r)},x.saveViewInitial=function(t){var e=t.center||{},r=t.projection,n=r.rotation||{};t._isScoped?this.viewInitial={\"center.lon\":e.lon,\"center.lat\":e.lat,\"projection.scale\":r.scale}:t._isClipped?this.viewInitial={\"projection.scale\":r.scale,\"projection.rotation.lon\":n.lon,\"projection.rotation.lat\":n.lat}:this.viewInitial={\"center.lon\":e.lon,\"center.lat\":e.lat,\"projection.scale\":r.scale,\"projection.rotation.lon\":n.lon}},x.render=function(){var t,e=this.projection,r=e.getPath();function n(t){var r=e(t.lonlat);return r?\"translate(\"+r[0]+\",\"+r[1]+\")\":null}function i(t){return e.isLonLatOverEdges(t.lonlat)?\"none\":null}for(t in this.basePaths)this.basePaths[t].attr(\"d\",r);for(t in this.dataPaths)this.dataPaths[t].attr(\"d\",function(t){return r(t.geojson)});for(t in this.dataPoints)this.dataPoints[t].attr(\"display\",i).attr(\"transform\",n)}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../lib\":719,\"../../lib/topojson_utils\":746,\"../../registry\":847,\"../cartesian/axes\":767,\"../cartesian/select\":784,\"../plots\":828,\"./constants\":795,\"./projections\":800,\"./zoom\":801,d3:163,\"topojson-client\":540}],797:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./geo\"),o=\"geo\",s=i(o),l={};l[o]={valType:\"subplotid\",dflt:o,editType:\"calc\"},e.exports={attr:o,name:o,idRoot:o,idRegex:s,attrRegex:s,attributes:l,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[o],s=0;s<i.length;s++){var l=i[s],c=n(r,o,l),u=e[l]._subplot;u||(u=a({id:l,graphDiv:t,container:e._geolayer.node(),topojsonURL:t._context.topojsonURL,staticPlot:t._context.staticPlot}),e[l]._subplot=u),u.plot(c,e,t._promises)}},updateFx:function(t){for(var e=t._fullLayout,r=e._subplots[o],n=0;n<r.length;n++){var i=e[r[n]];i._subplot.updateFx(e,i)}},clean:function(t,e,r,n){for(var i=n._subplots[o]||[],a=0;a<i.length;a++){var s=i[a],l=n[s]._subplot;!e[s]&&l&&(l.framework.remove(),l.clipDef.remove())}}}},{\"../../lib\":719,\"../../plots/get_data\":802,\"./geo\":796,\"./layout_attributes\":798,\"./layout_defaults\":799}],798:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"./constants\"),o=t(\"../../plot_api/edit_types\").overrideAll,s={range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},showgrid:{valType:\"boolean\",dflt:!1},tick0:{valType:\"number\",dflt:0},dtick:{valType:\"number\"},gridcolor:{valType:\"color\",dflt:n.lightLine},gridwidth:{valType:\"number\",min:0,dflt:1}};(e.exports=o({domain:i({name:\"geo\"},{}),resolution:{valType:\"enumerated\",values:[110,50],dflt:110,coerceNumber:!0},scope:{valType:\"enumerated\",values:Object.keys(a.scopeDefaults),dflt:\"world\"},projection:{type:{valType:\"enumerated\",values:Object.keys(a.projNames)},rotation:{lon:{valType:\"number\"},lat:{valType:\"number\"},roll:{valType:\"number\"}},parallels:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},scale:{valType:\"number\",min:0,dflt:1}},center:{lon:{valType:\"number\"},lat:{valType:\"number\"}},showcoastlines:{valType:\"boolean\"},coastlinecolor:{valType:\"color\",dflt:n.defaultLine},coastlinewidth:{valType:\"number\",min:0,dflt:1},showland:{valType:\"boolean\",dflt:!1},landcolor:{valType:\"color\",dflt:a.landColor},showocean:{valType:\"boolean\",dflt:!1},oceancolor:{valType:\"color\",dflt:a.waterColor},showlakes:{valType:\"boolean\",dflt:!1},lakecolor:{valType:\"color\",dflt:a.waterColor},showrivers:{valType:\"boolean\",dflt:!1},rivercolor:{valType:\"color\",dflt:a.waterColor},riverwidth:{valType:\"number\",min:0,dflt:1},showcountries:{valType:\"boolean\"},countrycolor:{valType:\"color\",dflt:n.defaultLine},countrywidth:{valType:\"number\",min:0,dflt:1},showsubunits:{valType:\"boolean\"},subunitcolor:{valType:\"color\",dflt:n.defaultLine},subunitwidth:{valType:\"number\",min:0,dflt:1},showframe:{valType:\"boolean\"},framecolor:{valType:\"color\",dflt:n.defaultLine},framewidth:{valType:\"number\",min:0,dflt:1},bgcolor:{valType:\"color\",dflt:n.background},lonaxis:s,lataxis:s},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":592,\"../../plot_api/edit_types\":750,\"../domain\":792,\"./constants\":795}],799:[function(t,e,r){\"use strict\";var n=t(\"../subplot_defaults\"),i=t(\"./constants\"),a=t(\"./layout_attributes\"),o=i.axesNames;function s(t,e,r){var n=r(\"resolution\"),a=r(\"scope\"),s=i.scopeDefaults[a],l=r(\"projection.type\",s.projType),c=e._isAlbersUsa=\"albers usa\"===l;c&&(a=e.scope=\"usa\");var u=e._isScoped=\"world\"!==a,h=e._isConic=-1!==l.indexOf(\"conic\");e._isClipped=!!i.lonaxisSpan[l];for(var f=0;f<o.length;f++){var p,d=o[f],g=[30,10][f];if(u)p=s[d+\"Range\"];else{var v=i[d+\"Span\"],m=(v[l]||v[\"*\"])/2,y=r(\"projection.rotation.\"+d.substr(0,3),s.projRotate[f]);p=[y-m,y+m]}r(d+\".range\",p),r(d+\".tick0\"),r(d+\".dtick\",g),r(d+\".showgrid\")&&(r(d+\".gridcolor\"),r(d+\".gridwidth\"))}var x=e.lonaxis.range,b=e.lataxis.range,_=x[0],w=x[1];_>0&&w<0&&(w+=360);var k,T,A,M=(_+w)/2;if(!c){var S=u?s.projRotate:[M,0,0];k=r(\"projection.rotation.lon\",S[0]),r(\"projection.rotation.lat\",S[1]),r(\"projection.rotation.roll\",S[2]),r(\"showcoastlines\",!u)&&(r(\"coastlinecolor\"),r(\"coastlinewidth\")),r(\"showocean\")&&r(\"oceancolor\")}(c?(T=-96.6,A=38.7):(T=u?M:k,A=(b[0]+b[1])/2),r(\"center.lon\",T),r(\"center.lat\",A),h)&&r(\"projection.parallels\",s.projParallels||[0,60]);r(\"projection.scale\"),r(\"showland\")&&r(\"landcolor\"),r(\"showlakes\")&&r(\"lakecolor\"),r(\"showrivers\")&&(r(\"rivercolor\"),r(\"riverwidth\")),r(\"showcountries\",u&&\"usa\"!==a)&&(r(\"countrycolor\"),r(\"countrywidth\")),(\"usa\"===a||\"north america\"===a&&50===n)&&(r(\"showsubunits\",!0),r(\"subunitcolor\"),r(\"subunitwidth\")),u||r(\"showframe\",!0)&&(r(\"framecolor\"),r(\"framewidth\")),r(\"bgcolor\")}e.exports=function(t,e,r){n(t,e,r,{type:\"geo\",attributes:a,handleDefaults:s,partition:\"y\"})}},{\"../subplot_defaults\":842,\"./constants\":795,\"./layout_attributes\":798}],800:[function(t,e,r){\"use strict\";e.exports=function(t){function e(t,e){return{type:\"Feature\",id:t.id,properties:t.properties,geometry:r(t.geometry,e)}}function r(e,n){if(!e)return null;if(\"GeometryCollection\"===e.type)return{type:\"GeometryCollection\",geometries:object.geometries.map(function(t){return r(t,n)})};if(!c.hasOwnProperty(e.type))return null;var i=c[e.type];return t.geo.stream(e,n(i)),i.result()}t.geo.project=function(t,e){var i=e.stream;if(!i)throw new Error(\"not yet supported\");return(t&&n.hasOwnProperty(t.type)?n[t.type]:r)(t,i)};var n={Feature:e,FeatureCollection:function(t,r){return{type:\"FeatureCollection\",features:t.features.map(function(t){return e(t,r)})}}},i=[],a=[],o={point:function(t,e){i.push([t,e])},result:function(){var t=i.length?i.length<2?{type:\"Point\",coordinates:i[0]}:{type:\"MultiPoint\",coordinates:i}:null;return i=[],t}},s={lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){i.length&&(a.push(i),i=[])},result:function(){var t=a.length?a.length<2?{type:\"LineString\",coordinates:a[0]}:{type:\"MultiLineString\",coordinates:a}:null;return a=[],t}},l={polygonStart:u,lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){var t=i.length;if(t){do{i.push(i[0].slice())}while(++t<4);a.push(i),i=[]}},polygonEnd:u,result:function(){if(!a.length)return null;var t=[],e=[];return a.forEach(function(r){!function(t){if((e=t.length)<4)return!1;for(var e,r=0,n=t[e-1][1]*t[0][0]-t[e-1][0]*t[0][1];++r<e;)n+=t[r-1][1]*t[r][0]-t[r-1][0]*t[r][1];return n<=0}(r)?e.push(r):t.push([r])}),e.forEach(function(e){var r=e[0];t.some(function(t){if(function(t,e){for(var r=e[0],n=e[1],i=!1,a=0,o=t.length,s=o-1;a<o;s=a++){var l=t[a],c=l[0],u=l[1],h=t[s],f=h[0],p=h[1];u>n^p>n&&r<(f-c)*(n-u)/(p-u)+c&&(i=!i)}return i}(t[0],r))return t.push(e),!0})||t.push([e])}),a=[],t.length?t.length>1?{type:\"MultiPolygon\",coordinates:t}:{type:\"Polygon\",coordinates:t[0]}:null}},c={Point:o,MultiPoint:o,LineString:s,MultiLineString:s,Polygon:l,MultiPolygon:l,Sphere:l};function u(){}var h=1e-6,f=h*h,p=Math.PI,d=p/2,g=(Math.sqrt(p),p/180),v=180/p;function m(t){return t>1?d:t<-1?-d:Math.asin(t)}function y(t){return t>1?0:t<-1?p:Math.acos(t)}var x=t.geo.projection,b=t.geo.projectionMutator;function _(t,e){var r=(2+d)*Math.sin(e);e/=2;for(var n=0,i=1/0;n<10&&Math.abs(i)>h;n++){var a=Math.cos(e);e-=i=(e+Math.sin(e)*(a+2)-r)/(2*a*(1+a))}return[2/Math.sqrt(p*(4+p))*t*(1+Math.cos(e)),2*Math.sqrt(p/(4+p))*Math.sin(e)]}t.geo.interrupt=function(e){var r,n=[[[[-p,0],[0,d],[p,0]]],[[[-p,0],[0,-d],[p,0]]]];function i(t,r){for(var i=r<0?-1:1,a=n[+(r<0)],o=0,s=a.length-1;o<s&&t>a[o][2][0];++o);var l=e(t-a[o][1][0],r);return l[0]+=e(a[o][1][0],i*r>i*a[o][0][1]?a[o][0][1]:r)[0],l}e.invert&&(i.invert=function(t,a){for(var o=r[+(a<0)],s=n[+(a<0)],c=0,u=o.length;c<u;++c){var h=o[c];if(h[0][0]<=t&&t<h[1][0]&&h[0][1]<=a&&a<h[1][1]){var f=e.invert(t-e(s[c][1][0],0)[0],a);return f[0]+=s[c][1][0],l(i(f[0],f[1]),[t,a])?f:null}}});var a=t.geo.projection(i),o=a.stream;function s(t,e){for(var r,n,i,a=-1,o=t.length,s=t[0],l=[];++a<o;){n=((r=t[a])[0]-s[0])/e,i=(r[1]-s[1])/e;for(var c=0;c<e;++c)l.push([s[0]+c*n,s[1]+c*i]);s=r}return l.push(r),l}function l(t,e){return Math.abs(t[0]-e[0])<h&&Math.abs(t[1]-e[1])<h}return a.stream=function(e){var r=a.rotate(),i=o(e),l=(a.rotate([0,0]),o(e));return a.rotate(r),i.sphere=function(){t.geo.stream(function(){for(var e=1e-6,r=[],i=0,a=n[0].length;i<a;++i){var o=n[0][i],l=180*o[0][0]/p,c=180*o[0][1]/p,u=180*o[1][1]/p,h=180*o[2][0]/p,f=180*o[2][1]/p;r.push(s([[l+e,c+e],[l+e,u-e],[h-e,u-e],[h-e,f+e]],30))}for(var i=n[1].length-1;i>=0;--i){var o=n[1][i],l=180*o[0][0]/p,c=180*o[0][1]/p,u=180*o[1][1]/p,h=180*o[2][0]/p,f=180*o[2][1]/p;r.push(s([[h-e,f-e],[h-e,u+e],[l+e,u+e],[l+e,c-e]],30))}return{type:\"Polygon\",coordinates:[t.merge(r)]}}(),l)},i},a.lobes=function(t){return arguments.length?(n=t.map(function(t){return t.map(function(t){return[[t[0][0]*p/180,t[0][1]*p/180],[t[1][0]*p/180,t[1][1]*p/180],[t[2][0]*p/180,t[2][1]*p/180]]})}),r=n.map(function(t){return t.map(function(t){var r,n=e(t[0][0],t[0][1])[0],i=e(t[2][0],t[2][1])[0],a=e(t[1][0],t[0][1])[1],o=e(t[1][0],t[1][1])[1];return a>o&&(r=a,a=o,o=r),[[n,a],[i,o]]})}),a):n.map(function(t){return t.map(function(t){return[[180*t[0][0]/p,180*t[0][1]/p],[180*t[1][0]/p,180*t[1][1]/p],[180*t[2][0]/p,180*t[2][1]/p]]})})},a},_.invert=function(t,e){var r=.5*e*Math.sqrt((4+p)/p),n=m(r),i=Math.cos(n);return[t/(2/Math.sqrt(p*(4+p))*(1+i)),m((n+r*(i+2))/(2+d))]},(t.geo.eckert4=function(){return x(_)}).raw=_;var w=t.geo.azimuthalEqualArea.raw;function k(t,e){if(arguments.length<2&&(e=t),1===e)return w;if(e===1/0)return T;function r(r,n){var i=w(r/e,n);return i[0]*=t,i}return r.invert=function(r,n){var i=w.invert(r/t,n);return i[0]*=e,i},r}function T(t,e){return[t*Math.cos(e)/Math.cos(e/=2),2*Math.sin(e)]}function A(t,e){return[3*t/(2*p)*Math.sqrt(p*p/3-e*e),e]}function M(t,e){return[t,1.25*Math.log(Math.tan(p/4+.4*e))]}function S(t){return function(e){var r,n=t*Math.sin(e),i=30;do{e-=r=(e+Math.sin(e)-n)/(1+Math.cos(e))}while(Math.abs(r)>h&&--i>0);return e/2}}T.invert=function(t,e){var r=2*m(e/2);return[t*Math.cos(r/2)/Math.cos(r),r]},(t.geo.hammer=function(){var t=2,e=b(k),r=e(t);return r.coefficient=function(r){return arguments.length?e(t=+r):t},r}).raw=k,A.invert=function(t,e){return[2/3*p*t/Math.sqrt(p*p/3-e*e),e]},(t.geo.kavrayskiy7=function(){return x(A)}).raw=A,M.invert=function(t,e){return[t,2.5*Math.atan(Math.exp(.8*e))-.625*p]},(t.geo.miller=function(){return x(M)}).raw=M,S(p);var E=function(t,e,r){var n=S(r);function i(r,i){return[t*r*Math.cos(i=n(i)),e*Math.sin(i)]}return i.invert=function(n,i){var a=m(i/e);return[n/(t*Math.cos(a)),m((2*a+Math.sin(2*a))/r)]},i}(Math.SQRT2/d,Math.SQRT2,p);function C(t,e){var r=e*e,n=r*r;return[t*(.8707-.131979*r+n*(n*(.003971*r-.001529*n)-.013791)),e*(1.007226+r*(.015085+n*(.028874*r-.044475-.005916*n)))]}(t.geo.mollweide=function(){return x(E)}).raw=E,C.invert=function(t,e){var r,n=e,i=25;do{var a=n*n,o=a*a;n-=r=(n*(1.007226+a*(.015085+o*(.028874*a-.044475-.005916*o)))-e)/(1.007226+a*(.045255+o*(.259866*a-.311325-.005916*11*o)))}while(Math.abs(r)>h&&--i>0);return[t/(.8707+(a=n*n)*(a*(a*a*a*(.003971-.001529*a)-.013791)-.131979)),n]},(t.geo.naturalEarth=function(){return x(C)}).raw=C;var L=[[.9986,-.062],[1,0],[.9986,.062],[.9954,.124],[.99,.186],[.9822,.248],[.973,.31],[.96,.372],[.9427,.434],[.9216,.4958],[.8962,.5571],[.8679,.6176],[.835,.6769],[.7986,.7346],[.7597,.7903],[.7186,.8435],[.6732,.8936],[.6213,.9394],[.5722,.9761],[.5322,1]];function P(t,e){var r,n=Math.min(18,36*Math.abs(e)/p),i=Math.floor(n),a=n-i,o=(r=L[i])[0],s=r[1],l=(r=L[++i])[0],c=r[1],u=(r=L[Math.min(19,++i)])[0],h=r[1];return[t*(l+a*(u-o)/2+a*a*(u-2*l+o)/2),(e>0?d:-d)*(c+a*(h-s)/2+a*a*(h-2*c+s)/2)]}function O(t,e){return[t*Math.cos(e),e]}function z(t,e){var r,n=Math.cos(e),i=(r=y(n*Math.cos(t/=2)))?r/Math.sin(r):1;return[2*n*Math.sin(t)*i,Math.sin(e)*i]}function I(t,e){var r=z(t,e);return[(r[0]+t/d)/2,(r[1]+e)/2]}L.forEach(function(t){t[1]*=1.0144}),P.invert=function(t,e){var r=e/d,n=90*r,i=Math.min(18,Math.abs(n/5)),a=Math.max(0,Math.floor(i));do{var o=L[a][1],s=L[a+1][1],l=L[Math.min(19,a+2)][1],c=l-o,u=l-2*s+o,h=2*(Math.abs(r)-s)/c,p=u/c,m=h*(1-p*h*(1-2*p*h));if(m>=0||1===a){n=(e>=0?5:-5)*(m+i);var y,x=50;do{m=(i=Math.min(18,Math.abs(n)/5))-(a=Math.floor(i)),o=L[a][1],s=L[a+1][1],l=L[Math.min(19,a+2)][1],n-=(y=(e>=0?d:-d)*(s+m*(l-o)/2+m*m*(l-2*s+o)/2)-e)*v}while(Math.abs(y)>f&&--x>0);break}}while(--a>=0);var b=L[a][0],_=L[a+1][0],w=L[Math.min(19,a+2)][0];return[t/(_+m*(w-b)/2+m*m*(w-2*_+b)/2),n*g]},(t.geo.robinson=function(){return x(P)}).raw=P,O.invert=function(t,e){return[t/Math.cos(e),e]},(t.geo.sinusoidal=function(){return x(O)}).raw=O,z.invert=function(t,e){if(!(t*t+4*e*e>p*p+h)){var r=t,n=e,i=25;do{var a,o=Math.sin(r),s=Math.sin(r/2),l=Math.cos(r/2),c=Math.sin(n),u=Math.cos(n),f=Math.sin(2*n),d=c*c,g=u*u,v=s*s,m=1-g*l*l,x=m?y(u*l)*Math.sqrt(a=1/m):a=0,b=2*x*u*s-t,_=x*c-e,w=a*(g*v+x*u*l*d),k=a*(.5*o*f-2*x*c*s),T=.25*a*(f*s-x*c*g*o),A=a*(d*l+x*v*u),M=k*T-A*w;if(!M)break;var S=(_*k-b*A)/M,E=(b*T-_*w)/M;r-=S,n-=E}while((Math.abs(S)>h||Math.abs(E)>h)&&--i>0);return[r,n]}},(t.geo.aitoff=function(){return x(z)}).raw=z,I.invert=function(t,e){var r=t,n=e,i=25;do{var a,o=Math.cos(n),s=Math.sin(n),l=Math.sin(2*n),c=s*s,u=o*o,f=Math.sin(r),p=Math.cos(r/2),g=Math.sin(r/2),v=g*g,m=1-u*p*p,x=m?y(o*p)*Math.sqrt(a=1/m):a=0,b=.5*(2*x*o*g+r/d)-t,_=.5*(x*s+n)-e,w=.5*a*(u*v+x*o*p*c)+.5/d,k=a*(f*l/4-x*s*g),T=.125*a*(l*g-x*s*u*f),A=.5*a*(c*p+x*v*o)+.5,M=k*T-A*w,S=(_*k-b*A)/M,E=(b*T-_*w)/M;r-=S,n-=E}while((Math.abs(S)>h||Math.abs(E)>h)&&--i>0);return[r,n]},(t.geo.winkel3=function(){return x(I)}).raw=I}},{}],801:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=Math.PI/180,s=180/Math.PI,l={cursor:\"pointer\"},c={cursor:\"auto\"};function u(t,e){return n.behavior.zoom().translate(e.translate()).scale(e.scale())}function h(t,e,r){var n=t.id,o=t.graphDiv,s=o.layout,l=s[n],c=o._fullLayout,u=c[n],h={},f={};function p(t,e){h[n+\".\"+t]=i.nestedProperty(l,t).get(),a.call(\"_storeDirectGUIEdit\",s,c._preGUI,h);var r=i.nestedProperty(u,t);r.get()!==e&&(r.set(e),i.nestedProperty(l,t).set(e),f[n+\".\"+t]=e)}r(p),p(\"projection.scale\",e.scale()/t.fitScale),o.emit(\"plotly_relayout\",f)}function f(t,e){var r=u(0,e);function i(r){var n=e.invert(t.midPt);r(\"center.lon\",n[0]),r(\"center.lat\",n[1])}return r.on(\"zoomstart\",function(){n.select(this).style(l)}).on(\"zoom\",function(){e.scale(n.event.scale).translate(n.event.translate),t.render();var r=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":r[0],\"geo.center.lat\":r[1]})}).on(\"zoomend\",function(){n.select(this).style(c),h(t,e,i)}),r}function p(t,e){var r,i,a,o,s,f,p,d,g,v=u(0,e),m=2;function y(t){return e.invert(t)}function x(r){var n=e.rotate(),i=e.invert(t.midPt);r(\"projection.rotation.lon\",-n[0]),r(\"center.lon\",i[0]),r(\"center.lat\",i[1])}return v.on(\"zoomstart\",function(){n.select(this).style(l),r=n.mouse(this),i=e.rotate(),a=e.translate(),o=i,s=y(r)}).on(\"zoom\",function(){if(f=n.mouse(this),function(t){var r=y(t);if(!r)return!0;var n=e(r);return Math.abs(n[0]-t[0])>m||Math.abs(n[1]-t[1])>m}(r))return v.scale(e.scale()),void v.translate(e.translate());e.scale(n.event.scale),e.translate([a[0],n.event.translate[1]]),s?y(f)&&(d=y(f),p=[o[0]+(d[0]-s[0]),i[1],i[2]],e.rotate(p),o=p):s=y(r=f),g=!0,t.render();var l=e.rotate(),c=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":c[0],\"geo.center.lat\":c[1],\"geo.projection.rotation.lon\":-l[0]})}).on(\"zoomend\",function(){n.select(this).style(c),g&&h(t,e,x)}),v}function d(t,e){var r,i={r:e.rotate(),k:e.scale()},a=u(0,e),f=function(t){var e=0,r=arguments.length,i=[];for(;++e<r;)i.push(arguments[e]);var a=n.dispatch.apply(null,i);return a.of=function(e,r){return function(i){var o;try{o=i.sourceEvent=n.event,i.target=t,n.event=i,a[i.type].apply(e,r)}finally{n.event=o}}},a}(a,\"zoomstart\",\"zoom\",\"zoomend\"),p=0,d=a.on;function m(t){var r=e.rotate();t(\"projection.rotation.lon\",-r[0]),t(\"projection.rotation.lat\",-r[1])}return a.on(\"zoomstart\",function(){n.select(this).style(l);var t,c,u,h,m,b,_,w,k,T,A,M=n.mouse(this),S=e.rotate(),E=S,C=e.translate(),L=(c=.5*(t=S)[0]*o,u=.5*t[1]*o,h=.5*t[2]*o,m=Math.sin(c),b=Math.cos(c),_=Math.sin(u),w=Math.cos(u),k=Math.sin(h),T=Math.cos(h),[b*w*T+m*_*k,m*w*T-b*_*k,b*_*T+m*w*k,b*w*k-m*_*T]);r=g(e,M),d.call(a,\"zoom\",function(){var t,a,o,l,c,u,h,p,d,m,b=n.mouse(this);if(e.scale(i.k=n.event.scale),r){if(g(e,b)){e.rotate(S).translate(C);var _=g(e,b),w=function(t,e){if(!t||!e)return;var r=function(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}(t,e),n=Math.sqrt(x(r,r)),i=.5*Math.acos(Math.max(-1,Math.min(1,x(t,e)))),a=Math.sin(i)/n;return n&&[Math.cos(i),r[2]*a,-r[1]*a,r[0]*a]}(r,_),k=function(t){return[Math.atan2(2*(t[0]*t[1]+t[2]*t[3]),1-2*(t[1]*t[1]+t[2]*t[2]))*s,Math.asin(Math.max(-1,Math.min(1,2*(t[0]*t[2]-t[3]*t[1]))))*s,Math.atan2(2*(t[0]*t[3]+t[1]*t[2]),1-2*(t[2]*t[2]+t[3]*t[3]))*s]}((a=w,o=(t=L)[0],l=t[1],c=t[2],u=t[3],h=a[0],p=a[1],d=a[2],m=a[3],[o*h-l*p-c*d-u*m,o*p+l*h+c*m-u*d,o*d-l*m+c*h+u*p,o*m+l*d-c*p+u*h])),T=i.r=function(t,e,r){var n=y(e,2,t[0]);n=y(n,1,t[1]),n=y(n,0,t[2]-r[2]);var i,a,o=e[0],l=e[1],c=e[2],u=n[0],h=n[1],f=n[2],p=Math.atan2(l,o)*s,d=Math.sqrt(o*o+l*l);Math.abs(h)>d?(a=(h>0?90:-90)-p,i=0):(a=Math.asin(h/d)*s-p,i=Math.sqrt(d*d-h*h));var g=180-a-2*p,m=(Math.atan2(f,u)-Math.atan2(c,i))*s,x=(Math.atan2(f,u)-Math.atan2(c,-i))*s,b=v(r[0],r[1],a,m),_=v(r[0],r[1],g,x);return b<=_?[a,m,r[2]]:[g,x,r[2]]}(k,r,E);isFinite(T[0])&&isFinite(T[1])&&isFinite(T[2])||(T=E),e.rotate(T),E=T}}else r=g(e,M=b);f.of(this,arguments)({type:\"zoom\"})}),A=f.of(this,arguments),p++||A({type:\"zoomstart\"})}).on(\"zoomend\",function(){var r;n.select(this).style(c),d.call(a,\"zoom\",null),r=f.of(this,arguments),--p||r({type:\"zoomend\"}),h(t,e,m)}).on(\"zoom.redraw\",function(){t.render();var r=e.rotate();t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.projection.rotation.lon\":-r[0],\"geo.projection.rotation.lat\":-r[1]})}),n.rebind(a,f,\"on\")}function g(t,e){var r=t.invert(e);return r&&isFinite(r[0])&&isFinite(r[1])&&function(t){var e=t[0]*o,r=t[1]*o,n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}(r)}function v(t,e,r,n){var i=m(r-t),a=m(n-e);return Math.sqrt(i*i+a*a)}function m(t){return(t%360+540)%360-180}function y(t,e,r){var n=r*o,i=t.slice(),a=0===e?1:0,s=2===e?1:2,l=Math.cos(n),c=Math.sin(n);return i[a]=t[a]*l-t[s]*c,i[s]=t[s]*l+t[a]*c,i}function x(t,e){for(var r=0,n=0,i=t.length;n<i;++n)r+=t[n]*e[n];return r}e.exports=function(t,e){var r=t.projection;return(e._isScoped?f:e._isClipped?d:p)(t,r)}},{\"../../lib\":719,\"../../registry\":847,d3:163}],802:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"./cartesian/constants\").SUBPLOT_PATTERN;r.getSubplotCalcData=function(t,e,r){var i=n.subplotsRegistry[e];if(!i)return[];for(var a=i.attr,o=[],s=0;s<t.length;s++){var l=t[s];l[0].trace[a]===r&&o.push(l)}return o},r.getModuleCalcData=function(t,e){var r,i=[],a=[];if(!(r=\"string\"==typeof e?n.getModule(e).plot:\"function\"==typeof e?e:e.plot))return[i,t];for(var o=0;o<t.length;o++){var s=t[o],l=s[0].trace;!0===l.visible&&0!==l._length&&(l._module.plot===r?i.push(s):a.push(s))}return[i,a]},r.getSubplotData=function(t,e,r){if(!n.subplotsRegistry[e])return[];var a,o,s,l=n.subplotsRegistry[e].attr,c=[];if(\"gl2d\"===e){var u=r.match(i);o=\"x\"+u[1],s=\"y\"+u[2]}for(var h=0;h<t.length;h++)a=t[h],\"gl2d\"===e&&n.traceIs(a,\"gl2d\")?a[l[0]]===o&&a[l[1]]===s&&c.push(a):a[l]===r&&c.push(a);return c}},{\"../registry\":847,\"./cartesian/constants\":773}],803:[function(t,e,r){\"use strict\";var n=t(\"mouse-change\"),i=t(\"mouse-wheel\"),a=t(\"mouse-event-offset\"),o=t(\"../cartesian/constants\"),s=t(\"has-passive-events\");function l(t,e){this.element=t,this.plot=e,this.mouseListener=null,this.wheelListener=null,this.lastInputTime=Date.now(),this.lastPos=[0,0],this.boxEnabled=!1,this.boxInited=!1,this.boxStart=[0,0],this.boxEnd=[0,0],this.dragStart=[0,0]}e.exports=function(t){var e=t.mouseContainer,r=t.glplot,c=new l(e,r);function u(){t.xaxis.autorange=!1,t.yaxis.autorange=!1}function h(e,n,i){var a,s,l=t.calcDataBox(),h=r.viewBox,f=c.lastPos[0],p=c.lastPos[1],d=o.MINDRAG*r.pixelRatio,g=o.MINZOOM*r.pixelRatio;function v(e,r,n){var i=Math.min(r,n),a=Math.max(r,n);i!==a?(l[e]=i,l[e+2]=a,c.dataBox=l,t.setRanges(l)):(t.selectBox.selectBox=[0,0,1,1],t.glplot.setDirty())}switch(n*=r.pixelRatio,i*=r.pixelRatio,i=h[3]-h[1]-i,t.fullLayout.dragmode){case\"zoom\":if(e){var m=n/(h[2]-h[0])*(l[2]-l[0])+l[0],y=i/(h[3]-h[1])*(l[3]-l[1])+l[1];c.boxInited||(c.boxStart[0]=m,c.boxStart[1]=y,c.dragStart[0]=n,c.dragStart[1]=i),c.boxEnd[0]=m,c.boxEnd[1]=y,c.boxInited=!0,c.boxEnabled||c.boxStart[0]===c.boxEnd[0]&&c.boxStart[1]===c.boxEnd[1]||(c.boxEnabled=!0);var x=Math.abs(c.dragStart[0]-n)<g,b=Math.abs(c.dragStart[1]-i)<g;if(!function(){for(var e=t.graphDiv._fullLayout._axisConstraintGroups,r=t.xaxis._id,n=t.yaxis._id,i=0;i<e.length;i++)if(-1!==e[i][r]){if(-1!==e[i][n])return!0;break}return!1}()||x&&b)x&&(c.boxEnd[0]=c.boxStart[0]),b&&(c.boxEnd[1]=c.boxStart[1]);else{a=c.boxEnd[0]-c.boxStart[0],s=c.boxEnd[1]-c.boxStart[1];var _=(l[3]-l[1])/(l[2]-l[0]);Math.abs(a*_)>Math.abs(s)?(c.boxEnd[1]=c.boxStart[1]+Math.abs(a)*_*(s>=0?1:-1),c.boxEnd[1]<l[1]?(c.boxEnd[1]=l[1],c.boxEnd[0]=c.boxStart[0]+(l[1]-c.boxStart[1])/Math.abs(_)):c.boxEnd[1]>l[3]&&(c.boxEnd[1]=l[3],c.boxEnd[0]=c.boxStart[0]+(l[3]-c.boxStart[1])/Math.abs(_))):(c.boxEnd[0]=c.boxStart[0]+Math.abs(s)/_*(a>=0?1:-1),c.boxEnd[0]<l[0]?(c.boxEnd[0]=l[0],c.boxEnd[1]=c.boxStart[1]+(l[0]-c.boxStart[0])*Math.abs(_)):c.boxEnd[0]>l[2]&&(c.boxEnd[0]=l[2],c.boxEnd[1]=c.boxStart[1]+(l[2]-c.boxStart[0])*Math.abs(_)))}}else c.boxEnabled?(a=c.boxStart[0]!==c.boxEnd[0],s=c.boxStart[1]!==c.boxEnd[1],a||s?(a&&(v(0,c.boxStart[0],c.boxEnd[0]),t.xaxis.autorange=!1),s&&(v(1,c.boxStart[1],c.boxEnd[1]),t.yaxis.autorange=!1),t.relayoutCallback()):t.glplot.setDirty(),c.boxEnabled=!1,c.boxInited=!1):c.boxInited&&(c.boxInited=!1);break;case\"pan\":c.boxEnabled=!1,c.boxInited=!1,e?(c.panning||(c.dragStart[0]=n,c.dragStart[1]=i),Math.abs(c.dragStart[0]-n)<d&&(n=c.dragStart[0]),Math.abs(c.dragStart[1]-i)<d&&(i=c.dragStart[1]),a=(f-n)*(l[2]-l[0])/(r.viewBox[2]-r.viewBox[0]),s=(p-i)*(l[3]-l[1])/(r.viewBox[3]-r.viewBox[1]),l[0]+=a,l[2]+=a,l[1]+=s,l[3]+=s,t.setRanges(l),c.panning=!0,c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations()):c.panning&&(c.panning=!1,t.relayoutCallback())}c.lastPos[0]=n,c.lastPos[1]=i}return c.mouseListener=n(e,h),e.addEventListener(\"touchstart\",function(t){var r=a(t.changedTouches[0],e);h(0,r[0],r[1]),h(1,r[0],r[1]),t.preventDefault()},!!s&&{passive:!1}),e.addEventListener(\"touchmove\",function(t){t.preventDefault();var r=a(t.changedTouches[0],e);h(1,r[0],r[1]),t.preventDefault()},!!s&&{passive:!1}),e.addEventListener(\"touchend\",function(t){h(0,c.lastPos[0],c.lastPos[1]),t.preventDefault()},!!s&&{passive:!1}),c.wheelListener=i(e,function(e,n){if(!t.scrollZoom)return!1;var i=t.calcDataBox(),a=r.viewBox,o=c.lastPos[0],s=c.lastPos[1],l=Math.exp(5*n/(a[3]-a[1])),h=o/(a[2]-a[0])*(i[2]-i[0])+i[0],f=s/(a[3]-a[1])*(i[3]-i[1])+i[1];return i[0]=(i[0]-h)*l+h,i[2]=(i[2]-h)*l+h,i[1]=(i[1]-f)*l+f,i[3]=(i[3]-f)*l+f,t.setRanges(i),c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations(),t.relayoutCallback(),!0},!0),c}},{\"../cartesian/constants\":773,\"has-passive-events\":411,\"mouse-change\":435,\"mouse-event-offset\":436,\"mouse-wheel\":438}],804:[function(t,e,r){\"use strict\";var n=t(\"../cartesian/axes\"),i=t(\"../../lib/str2rgbarray\");function a(t){this.scene=t,this.gl=t.gl,this.pixelRatio=t.pixelRatio,this.screenBox=[0,0,1,1],this.viewBox=[0,0,1,1],this.dataBox=[-1,-1,1,1],this.borderLineEnable=[!1,!1,!1,!1],this.borderLineWidth=[1,1,1,1],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.ticks=[[],[]],this.tickEnable=[!0,!0,!1,!1],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labels=[\"x\",\"y\"],this.labelEnable=[!0,!0,!1,!1],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelPad=[15,15,15,15],this.labelSize=[12,12],this.labelFont=[\"sans-serif\",\"sans-serif\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.title=\"\",this.titleEnable=!0,this.titleCenter=[0,0,0,0],this.titleAngle=0,this.titleColor=[0,0,0,1],this.titleFont=\"sans-serif\",this.titleSize=18,this.gridLineEnable=[!0,!0],this.gridLineColor=[[0,0,0,.5],[0,0,0,.5]],this.gridLineWidth=[1,1],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[1,1],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.static=this.scene.staticPlot}var o=a.prototype,s=[\"xaxis\",\"yaxis\"];o.merge=function(t){var e,r,n,a,o,l,c,u,h,f,p;for(this.titleEnable=!1,this.backgroundColor=i(t.plot_bgcolor),f=0;f<2;++f){var d=(e=s[f]).charAt(0);for(n=(r=t[this.scene[e]._name]).title.text===this.scene.fullLayout._dfltTitle[d]?\"\":r.title.text,p=0;p<=2;p+=2)this.labelEnable[f+p]=!1,this.labels[f+p]=n,this.labelColor[f+p]=i(r.title.font.color),this.labelFont[f+p]=r.title.font.family,this.labelSize[f+p]=r.title.font.size,this.labelPad[f+p]=this.getLabelPad(e,r),this.tickEnable[f+p]=!1,this.tickColor[f+p]=i((r.tickfont||{}).color),this.tickAngle[f+p]=\"auto\"===r.tickangle?0:Math.PI*-r.tickangle/180,this.tickPad[f+p]=this.getTickPad(r),this.tickMarkLength[f+p]=0,this.tickMarkWidth[f+p]=r.tickwidth||0,this.tickMarkColor[f+p]=i(r.tickcolor),this.borderLineEnable[f+p]=!1,this.borderLineColor[f+p]=i(r.linecolor),this.borderLineWidth[f+p]=r.linewidth||0;c=this.hasSharedAxis(r),o=this.hasAxisInDfltPos(e,r)&&!c,l=this.hasAxisInAltrPos(e,r)&&!c,a=r.mirror||!1,u=c?-1!==String(a).indexOf(\"all\"):!!a,h=c?\"allticks\"===a:-1!==String(a).indexOf(\"ticks\"),o?this.labelEnable[f]=!0:l&&(this.labelEnable[f+2]=!0),o?this.tickEnable[f]=r.showticklabels:l&&(this.tickEnable[f+2]=r.showticklabels),(o||u)&&(this.borderLineEnable[f]=r.showline),(l||u)&&(this.borderLineEnable[f+2]=r.showline),(o||h)&&(this.tickMarkLength[f]=this.getTickMarkLength(r)),(l||h)&&(this.tickMarkLength[f+2]=this.getTickMarkLength(r)),this.gridLineEnable[f]=r.showgrid,this.gridLineColor[f]=i(r.gridcolor),this.gridLineWidth[f]=r.gridwidth,this.zeroLineEnable[f]=r.zeroline,this.zeroLineColor[f]=i(r.zerolinecolor),this.zeroLineWidth[f]=r.zerolinewidth}},o.hasSharedAxis=function(t){var e=this.scene,r=e.fullLayout._subplots.gl2d;return 0!==n.findSubplotsWithAxis(r,t).indexOf(e.id)},o.hasAxisInDfltPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"bottom\"===r:\"yaxis\"===t?\"left\"===r:void 0},o.hasAxisInAltrPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"top\"===r:\"yaxis\"===t?\"right\"===r:void 0},o.getLabelPad=function(t,e){var r=e.title.font.size,n=e.showticklabels;return\"xaxis\"===t?\"top\"===e.side?r*(1.5+(n?1:0))-10:r*(1.5+(n?.5:0))-10:\"yaxis\"===t?\"right\"===e.side?10+r*(1.5+(n?1:.5)):10+r*(1.5+(n?.5:0)):void 0},o.getTickPad=function(t){return\"outside\"===t.ticks?10+t.ticklen:15},o.getTickMarkLength=function(t){if(!t.ticks)return 0;var e=t.ticklen;return\"inside\"===t.ticks?-e:e},e.exports=function(t){return new a(t)}},{\"../../lib/str2rgbarray\":742,\"../cartesian/axes\":767}],805:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"./scene2d\"),a=t(\"../layout_attributes\"),o=t(\"../../constants/xmlns_namespaces\"),s=t(\"../cartesian/constants\"),l=t(\"../cartesian\"),c=t(\"../../components/fx/layout_attributes\"),u=t(\"../get_data\").getSubplotData;r.name=\"gl2d\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=s.idRegex,r.attrRegex=s.attrRegex,r.attributes=t(\"../cartesian/attributes\"),r.supplyLayoutDefaults=function(t,e,r){e._has(\"cartesian\")||l.supplyLayoutDefaults(t,e,r)},r.layoutAttrOverrides=n(l.layoutAttributes,\"plot\",\"from-root\"),r.baseLayoutAttrOverrides=n({plot_bgcolor:a.plot_bgcolor,hoverlabel:c.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl2d,a=0;a<n.length;a++){var o=n[a],s=e._plots[o],l=u(r,\"gl2d\",o),c=s._scene2d;void 0===c&&(c=new i({id:o,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio},e),s._scene2d=c),c.plot(l,t.calcdata,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl2d||[],a=0;a<i.length;a++){var o=i[a],s=n._plots[o];if(s._scene2d)0===u(t,\"gl2d\",o).length&&(s._scene2d.destroy(),delete n._plots[o])}l.clean.apply(this,arguments)},r.drawFramework=function(t){t._context.staticPlot||l.drawFramework(t)},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){var i=e._plots[r[n]]._scene2d,a=i.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":a,x:0,y:0,width:\"100%\",height:\"100%\",preserveAspectRatio:\"none\"}),i.destroy()}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){e._plots[r[n]]._scene2d.updateFx(e.dragmode)}}},{\"../../components/fx/layout_attributes\":633,\"../../constants/xmlns_namespaces\":696,\"../../plot_api/edit_types\":750,\"../cartesian\":778,\"../cartesian/attributes\":765,\"../cartesian/constants\":773,\"../get_data\":802,\"../layout_attributes\":819,\"./scene2d\":806}],806:[function(t,e,r){\"use strict\";var n,i,a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../../components/fx\"),l=t(\"gl-plot2d\"),c=t(\"gl-spikes2d\"),u=t(\"gl-select-box\"),h=t(\"webgl-context\"),f=t(\"./convert\"),p=t(\"./camera\"),d=t(\"../../lib/show_no_webgl_msg\"),g=t(\"../cartesian/constraints\"),v=g.enforce,m=g.clean,y=t(\"../cartesian/autorange\").doAutoRange,x=[\"xaxis\",\"yaxis\"],b=t(\"../cartesian/constants\").SUBPLOT_PATTERN;function _(t,e){this.container=t.container,this.graphDiv=t.graphDiv,this.pixelRatio=t.plotGlPixelRatio||window.devicePixelRatio,this.id=t.id,this.staticPlot=!!t.staticPlot,this.scrollZoom=this.graphDiv._context._scrollZoom.cartesian,this.fullData=null,this.updateRefs(e),this.makeFramework(),this.stopped||(this.glplotOptions=f(this),this.glplotOptions.merge(e),this.glplot=l(this.glplotOptions),this.camera=p(this),this.traces={},this.spikes=c(this.glplot),this.selectBox=u(this.glplot,{innerFill:!1,outerFill:!0}),this.lastButtonState=0,this.pickResult=null,this.isMouseOver=!0,this.stopped=!1,this.redraw=this.draw.bind(this),this.redraw())}e.exports=_;var w=_.prototype;w.makeFramework=function(){if(this.staticPlot){if(!(i||(n=document.createElement(\"canvas\"),i=h({canvas:n,preserveDrawingBuffer:!1,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"Error creating static canvas/context for image server\");this.canvas=n,this.gl=i}else{var t=this.container.querySelector(\".gl-canvas-focus\"),e=h({canvas:t,preserveDrawingBuffer:!0,premultipliedAlpha:!0});if(!e)return d(this),void(this.stopped=!0);this.canvas=t,this.gl=e}var r=this.canvas;r.style.width=\"100%\",r.style.height=\"100%\",r.style.position=\"absolute\",r.style.top=\"0px\",r.style.left=\"0px\",r.style[\"pointer-events\"]=\"none\",this.updateSize(r),r.className+=\" user-select-none\";var a=this.svgContainer=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");a.style.position=\"absolute\",a.style.top=a.style.left=\"0px\",a.style.width=a.style.height=\"100%\",a.style[\"z-index\"]=20,a.style[\"pointer-events\"]=\"none\";var o=this.mouseContainer=document.createElement(\"div\");o.style.position=\"absolute\",o.style[\"pointer-events\"]=\"auto\",this.pickCanvas=this.container.querySelector(\".gl-canvas-pick\");var s=this.container;s.appendChild(a),s.appendChild(o);var l=this;o.addEventListener(\"mouseout\",function(){l.isMouseOver=!1,l.unhover()}),o.addEventListener(\"mouseover\",function(){l.isMouseOver=!0})},w.toImage=function(t){t||(t=\"png\"),this.stopped=!0,this.staticPlot&&this.container.appendChild(n),this.updateSize(this.canvas);var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.clearColor(1,1,1,0),e.clear(e.COLOR_BUFFER_BIT|e.DEPTH_BUFFER_BIT),this.glplot.setDirty(),this.glplot.draw(),e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a);for(var o=0,s=i-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=a[4*(r*o+l)+c];a[4*(r*o+l)+c]=a[4*(r*s+l)+c],a[4*(r*s+l)+c]=u}var h=document.createElement(\"canvas\");h.width=r,h.height=i;var f,p=h.getContext(\"2d\"),d=p.createImageData(r,i);switch(d.data.set(a),p.putImageData(d,0,0),t){case\"jpeg\":f=h.toDataURL(\"image/jpeg\");break;case\"webp\":f=h.toDataURL(\"image/webp\");break;default:f=h.toDataURL(\"image/png\")}return this.staticPlot&&this.container.removeChild(n),f},w.updateSize=function(t){t||(t=this.canvas);var e=this.pixelRatio,r=this.fullLayout,n=r.width,i=r.height,a=0|Math.ceil(e*n),o=0|Math.ceil(e*i);return t.width===a&&t.height===o||(t.width=a,t.height=o),t},w.computeTickMarks=function(){this.xaxis.setScale(),this.yaxis.setScale();for(var t=[o.calcTicks(this.xaxis),o.calcTicks(this.yaxis)],e=0;e<2;++e)for(var r=0;r<t[e].length;++r)t[e][r].text=t[e][r].text+\"\";return t},w.updateRefs=function(t){this.fullLayout=t;var e=this.id.match(b),r=\"xaxis\"+e[1],n=\"yaxis\"+e[2];this.xaxis=this.fullLayout[r],this.yaxis=this.fullLayout[n]},w.relayoutCallback=function(){var t=this.graphDiv,e=this.xaxis,r=this.yaxis,n=t.layout,i={},o=i[e._name+\".range\"]=e.range.slice(),s=i[r._name+\".range\"]=r.range.slice();i[e._name+\".autorange\"]=e.autorange,i[r._name+\".autorange\"]=r.autorange,a.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,i);var l=n[e._name];l.range=o,l.autorange=e.autorange;var c=n[r._name];c.range=s,c.autorange=r.autorange,i.lastInputTime=this.camera.lastInputTime,t.emit(\"plotly_relayout\",i)},w.cameraChanged=function(){var t=this.camera;this.glplot.setDataBox(this.calcDataBox());var e=this.computeTickMarks();(function(t,e){for(var r=0;r<2;++r){var n=t[r],i=e[r];if(n.length!==i.length)return!0;for(var a=0;a<n.length;++a)if(n[a].x!==i[a].x)return!0}return!1})(e,this.glplotOptions.ticks)&&(this.glplotOptions.ticks=e,this.glplotOptions.dataBox=t.dataBox,this.glplot.update(this.glplotOptions),this.handleAnnotations())},w.handleAnnotations=function(){for(var t=this.graphDiv,e=this.fullLayout.annotations,r=0;r<e.length;r++){var n=e[r];n.xref===this.xaxis._id&&n.yref===this.yaxis._id&&a.getComponentMethod(\"annotations\",\"drawOne\")(t,r)}},w.destroy=function(){if(this.glplot){var t=this.traces;t&&Object.keys(t).map(function(e){t[e].dispose(),delete t[e]}),this.glplot.dispose(),this.container.removeChild(this.svgContainer),this.container.removeChild(this.mouseContainer),this.fullData=null,this.glplot=null,this.stopped=!0,this.camera.mouseListener.enabled=!1,this.mouseContainer.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=null}},w.plot=function(t,e,r){var n=this.glplot;this.updateRefs(r),this.xaxis.clearCalc(),this.yaxis.clearCalc(),this.updateTraces(t,e),this.updateFx(r.dragmode);var i=r.width,a=r.height;this.updateSize(this.canvas);var o=this.glplotOptions;o.merge(r),o.screenBox=[0,0,i,a];var s={_fullLayout:{_axisConstraintGroups:this.graphDiv._fullLayout._axisConstraintGroups,xaxis:this.xaxis,yaxis:this.yaxis}};m(s,this.xaxis),m(s,this.yaxis);var l,c,u=r._size,h=this.xaxis.domain,f=this.yaxis.domain;for(o.viewBox=[u.l+h[0]*u.w,u.b+f[0]*u.h,i-u.r-(1-h[1])*u.w,a-u.t-(1-f[1])*u.h],this.mouseContainer.style.width=u.w*(h[1]-h[0])+\"px\",this.mouseContainer.style.height=u.h*(f[1]-f[0])+\"px\",this.mouseContainer.height=u.h*(f[1]-f[0]),this.mouseContainer.style.left=u.l+h[0]*u.w+\"px\",this.mouseContainer.style.top=u.t+(1-f[1])*u.h+\"px\",c=0;c<2;++c)(l=this[x[c]])._length=o.viewBox[c+2]-o.viewBox[c],y(this.graphDiv,l),l.setScale();v(s),o.ticks=this.computeTickMarks(),o.dataBox=this.calcDataBox(),o.merge(r),n.update(o),this.glplot.draw()},w.calcDataBox=function(){var t=this.xaxis,e=this.yaxis,r=t.range,n=e.range,i=t.r2l,a=e.r2l;return[i(r[0]),a(n[0]),i(r[1]),a(n[1])]},w.setRanges=function(t){var e=this.xaxis,r=this.yaxis,n=e.l2r,i=r.l2r;e.range=[n(t[0]),n(t[2])],r.range=[i(t[1]),i(t[3])]},w.updateTraces=function(t,e){var r,n,i,a=Object.keys(this.traces);this.fullData=t;t:for(r=0;r<a.length;r++){var o=a[r],s=this.traces[o];for(n=0;n<t.length;n++)if((i=t[n]).uid===o&&i.type===s.type)continue t;s.dispose(),delete this.traces[o]}for(r=0;r<t.length;r++){i=t[r];var l=e[r],c=this.traces[i.uid];c?c.update(i,l):(c=i._module.plot(this,i,l),this.traces[i.uid]=c)}this.glplot.objects.sort(function(t,e){return t._trace.index-e._trace.index})},w.updateFx=function(t){\"lasso\"===t||\"select\"===t?(this.pickCanvas.style[\"pointer-events\"]=\"none\",this.mouseContainer.style[\"pointer-events\"]=\"none\"):(this.pickCanvas.style[\"pointer-events\"]=\"auto\",this.mouseContainer.style[\"pointer-events\"]=\"auto\"),this.mouseContainer.style.cursor=\"pan\"===t?\"move\":\"zoom\"===t?\"crosshair\":null},w.emitPointAction=function(t,e){for(var r,n=t.trace.uid,i=t.pointIndex,a=0;a<this.fullData.length;a++)this.fullData[a].uid===n&&(r=this.fullData[a]);var o={x:t.traceCoord[0],y:t.traceCoord[1],curveNumber:r.index,pointNumber:i,data:r._input,fullData:this.fullData,xaxis:this.xaxis,yaxis:this.yaxis};s.appendArrayPointValue(o,r,i),this.graphDiv.emit(e,{points:[o]})},w.draw=function(){if(!this.stopped){requestAnimationFrame(this.redraw);var t=this.glplot,e=this.camera,r=e.mouseListener,n=1===this.lastButtonState&&0===r.buttons,i=this.fullLayout;this.lastButtonState=r.buttons,this.cameraChanged();var a,o=r.x*t.pixelRatio,l=this.canvas.height-t.pixelRatio*r.y;if(e.boxEnabled&&\"zoom\"===i.dragmode){this.selectBox.enabled=!0;for(var c=this.selectBox.selectBox=[Math.min(e.boxStart[0],e.boxEnd[0]),Math.min(e.boxStart[1],e.boxEnd[1]),Math.max(e.boxStart[0],e.boxEnd[0]),Math.max(e.boxStart[1],e.boxEnd[1])],u=0;u<2;u++)e.boxStart[u]===e.boxEnd[u]&&(c[u]=t.dataBox[u],c[u+2]=t.dataBox[u+2]);t.setDirty()}else if(!e.panning&&this.isMouseOver){this.selectBox.enabled=!1;var h=i._size,f=this.xaxis.domain,p=this.yaxis.domain,d=(a=t.pick(o/t.pixelRatio+h.l+f[0]*h.w,l/t.pixelRatio-(h.t+(1-p[1])*h.h)))&&a.object._trace.handlePick(a);if(d&&n&&this.emitPointAction(d,\"plotly_click\"),a&&\"skip\"!==a.object._trace.hoverinfo&&i.hovermode&&d&&(!this.lastPickResult||this.lastPickResult.traceUid!==d.trace.uid||this.lastPickResult.dataCoord[0]!==d.dataCoord[0]||this.lastPickResult.dataCoord[1]!==d.dataCoord[1])){var g=d;this.lastPickResult={traceUid:d.trace?d.trace.uid:null,dataCoord:d.dataCoord.slice()},this.spikes.update({center:a.dataCoord}),g.screenCoord=[((t.viewBox[2]-t.viewBox[0])*(a.dataCoord[0]-t.dataBox[0])/(t.dataBox[2]-t.dataBox[0])+t.viewBox[0])/t.pixelRatio,(this.canvas.height-(t.viewBox[3]-t.viewBox[1])*(a.dataCoord[1]-t.dataBox[1])/(t.dataBox[3]-t.dataBox[1])-t.viewBox[1])/t.pixelRatio],this.emitPointAction(d,\"plotly_hover\");var v=this.fullData[g.trace.index]||{},m=g.pointIndex,y=s.castHoverinfo(v,i,m);if(y&&\"all\"!==y){var x=y.split(\"+\");-1===x.indexOf(\"x\")&&(g.traceCoord[0]=void 0),-1===x.indexOf(\"y\")&&(g.traceCoord[1]=void 0),-1===x.indexOf(\"z\")&&(g.traceCoord[2]=void 0),-1===x.indexOf(\"text\")&&(g.textLabel=void 0),-1===x.indexOf(\"name\")&&(g.name=void 0)}s.loneHover({x:g.screenCoord[0],y:g.screenCoord[1],xLabel:this.hoverFormatter(\"xaxis\",g.traceCoord[0]),yLabel:this.hoverFormatter(\"yaxis\",g.traceCoord[1]),zLabel:g.traceCoord[2],text:g.textLabel,name:g.name,color:s.castHoverOption(v,m,\"bgcolor\")||g.color,borderColor:s.castHoverOption(v,m,\"bordercolor\"),fontFamily:s.castHoverOption(v,m,\"font.family\"),fontSize:s.castHoverOption(v,m,\"font.size\"),fontColor:s.castHoverOption(v,m,\"font.color\"),nameLength:s.castHoverOption(v,m,\"namelength\"),textAlign:s.castHoverOption(v,m,\"align\")},{container:this.svgContainer,gd:this.graphDiv})}}a||this.unhover(),t.draw()}},w.unhover=function(){this.lastPickResult&&(this.spikes.update({}),this.lastPickResult=null,this.graphDiv.emit(\"plotly_unhover\"),s.loneUnhover(this.svgContainer))},w.hoverFormatter=function(t,e){if(void 0!==e){var r=this[t];return o.tickText(r,r.c2l(e),\"hover\").text}}},{\"../../components/fx\":632,\"../../lib/show_no_webgl_msg\":740,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../cartesian/autorange\":766,\"../cartesian/constants\":773,\"../cartesian/constraints\":774,\"./camera\":803,\"./convert\":804,\"gl-plot2d\":287,\"gl-select-box\":299,\"gl-spikes2d\":308,\"webgl-context\":556}],807:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../components/fx/layout_attributes\"),a=t(\"./scene\"),o=t(\"../get_data\").getSubplotData,s=t(\"../../lib\"),l=t(\"../../constants/xmlns_namespaces\");r.name=\"gl3d\",r.attr=\"scene\",r.idRoot=\"scene\",r.idRegex=r.attrRegex=s.counterRegex(\"scene\"),r.attributes=t(\"./layout/attributes\"),r.layoutAttributes=t(\"./layout/layout_attributes\"),r.baseLayoutAttrOverrides=n({hoverlabel:i.hoverlabel},\"plot\",\"nested\"),r.supplyLayoutDefaults=t(\"./layout/defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl3d,i=0;i<n.length;i++){var s=n[i],l=o(r,\"gl3d\",s),c=e[s],u=c.camera,h=c._scene;h||(h=new a({id:s,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio,camera:u},e),c._scene=h),h.viewInitial||(h.viewInitial={up:{x:u.up.x,y:u.up.y,z:u.up.z},eye:{x:u.eye.x,y:u.eye.y,z:u.eye.z},center:{x:u.center.x,y:u.center.y,z:u.center.z}}),h.plot(l,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl3d||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._scene&&(n[o]._scene.destroy(),n._infolayer&&n._infolayer.selectAll(\".annotation-\"+o).remove())}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=e._size,i=0;i<r.length;i++){var a=e[r[i]],o=a.domain,s=a._scene,c=s.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:l.svg,\"xlink:href\":c,x:n.l+n.w*o.x[0],y:n.t+n.h*(1-o.y[1]),width:n.w*(o.x[1]-o.x[0]),height:n.h*(o.y[1]-o.y[0]),preserveAspectRatio:\"none\"}),s.destroy()}},r.cleanId=function(t){if(t.match(/^scene[0-9]*$/)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),\"scene\"+e}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){e[r[n]]._scene.updateFx(e.dragmode,e.hovermode)}}},{\"../../components/fx/layout_attributes\":633,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../plot_api/edit_types\":750,\"../get_data\":802,\"./layout/attributes\":808,\"./layout/defaults\":812,\"./layout/layout_attributes\":813,\"./scene\":817}],808:[function(t,e,r){\"use strict\";e.exports={scene:{valType:\"subplotid\",dflt:\"scene\",editType:\"calc+clearAxisTypes\"}}},{}],809:[function(t,e,r){\"use strict\";var n=t(\"../../../components/color\"),i=t(\"../../cartesian/layout_attributes\"),a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../plot_api/edit_types\").overrideAll;e.exports=o({visible:i.visible,showspikes:{valType:\"boolean\",dflt:!0},spikesides:{valType:\"boolean\",dflt:!0},spikethickness:{valType:\"number\",min:0,dflt:2},spikecolor:{valType:\"color\",dflt:n.defaultLine},showbackground:{valType:\"boolean\",dflt:!1},backgroundcolor:{valType:\"color\",dflt:\"rgba(204, 204, 204, 0.5)\"},showaxeslabels:{valType:\"boolean\",dflt:!0},color:i.color,categoryorder:i.categoryorder,categoryarray:i.categoryarray,title:i.title,type:a({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autorange:i.autorange,rangemode:i.rangemode,range:a({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],anim:!1}),tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,mirror:i.mirror,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,tickfont:i.tickfont,tickangle:i.tickangle,tickprefix:i.tickprefix,showtickprefix:i.showtickprefix,ticksuffix:i.ticksuffix,showticksuffix:i.showticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,separatethousands:i.separatethousands,tickformat:i.tickformat,tickformatstops:i.tickformatstops,hoverformat:i.hoverformat,showline:i.showline,linecolor:i.linecolor,linewidth:i.linewidth,showgrid:i.showgrid,gridcolor:a({},i.gridcolor,{dflt:\"rgb(204, 204, 204)\"}),gridwidth:i.gridwidth,zeroline:i.zeroline,zerolinecolor:i.zerolinecolor,zerolinewidth:i.zerolinewidth,_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}},\"plot\",\"from-root\")},{\"../../../components/color\":593,\"../../../lib/extend\":710,\"../../../plot_api/edit_types\":750,\"../../cartesian/layout_attributes\":779}],810:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../../lib\"),a=t(\"../../../plot_api/plot_template\"),o=t(\"./axis_attributes\"),s=t(\"../../cartesian/type_defaults\"),l=t(\"../../cartesian/axis_defaults\"),c=[\"xaxis\",\"yaxis\",\"zaxis\"];e.exports=function(t,e,r){var u,h;function f(t,e){return i.coerce(u,h,o,t,e)}for(var p=0;p<c.length;p++){var d=c[p];u=t[d]||{},(h=a.newContainer(e,d))._id=d[0]+r.scene,h._name=d,s(u,h,f,r),l(u,h,f,{font:r.font,letter:d[0],data:r.data,showGrid:!0,noTickson:!0,bgColor:r.bgColor,calendar:r.calendar},r.fullLayout),f(\"gridcolor\",n(h.color,r.bgColor,13600/187).toRgbString()),f(\"title.text\",d[0]),h.setScale=i.noop,f(\"showspikes\")&&(f(\"spikesides\"),f(\"spikethickness\"),f(\"spikecolor\",h.color)),f(\"showaxeslabels\"),f(\"showbackground\")&&f(\"backgroundcolor\")}}},{\"../../../lib\":719,\"../../../plot_api/plot_template\":757,\"../../cartesian/axis_defaults\":769,\"../../cartesian/type_defaults\":790,\"./axis_attributes\":809,tinycolor2:537}],811:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"];function o(){this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[18,18,18],this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=[\"Open Sans\",\"Open Sans\",\"Open Sans\"],this.labelSize=[20,20,20],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[30,30,30],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[10,10,10],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!0,!0,!0],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._defaultTickPad=this.tickPad.slice(),this._defaultLabelPad=this.labelPad.slice(),this._defaultLineTickLength=this.lineTickLength.slice()}o.prototype.merge=function(t,e){for(var r=0;r<3;++r){var o=e[a[r]];o.visible?(this.labels[r]=t._meta?i.templateString(o.title.text,t._meta):o.title.text,\"font\"in o.title&&(o.title.font.color&&(this.labelColor[r]=n(o.title.font.color)),o.title.font.family&&(this.labelFont[r]=o.title.font.family),o.title.font.size&&(this.labelSize[r]=o.title.font.size)),\"showline\"in o&&(this.lineEnable[r]=o.showline),\"linecolor\"in o&&(this.lineColor[r]=n(o.linecolor)),\"linewidth\"in o&&(this.lineWidth[r]=o.linewidth),\"showgrid\"in o&&(this.gridEnable[r]=o.showgrid),\"gridcolor\"in o&&(this.gridColor[r]=n(o.gridcolor)),\"gridwidth\"in o&&(this.gridWidth[r]=o.gridwidth),\"log\"===o.type?this.zeroEnable[r]=!1:\"zeroline\"in o&&(this.zeroEnable[r]=o.zeroline),\"zerolinecolor\"in o&&(this.zeroLineColor[r]=n(o.zerolinecolor)),\"zerolinewidth\"in o&&(this.zeroLineWidth[r]=o.zerolinewidth),\"ticks\"in o&&o.ticks?this.lineTickEnable[r]=!0:this.lineTickEnable[r]=!1,\"ticklen\"in o&&(this.lineTickLength[r]=this._defaultLineTickLength[r]=o.ticklen),\"tickcolor\"in o&&(this.lineTickColor[r]=n(o.tickcolor)),\"tickwidth\"in o&&(this.lineTickWidth[r]=o.tickwidth),\"tickangle\"in o&&(this.tickAngle[r]=\"auto\"===o.tickangle?-3600:Math.PI*-o.tickangle/180),\"showticklabels\"in o&&(this.tickEnable[r]=o.showticklabels),\"tickfont\"in o&&(o.tickfont.color&&(this.tickColor[r]=n(o.tickfont.color)),o.tickfont.family&&(this.tickFont[r]=o.tickfont.family),o.tickfont.size&&(this.tickSize[r]=o.tickfont.size)),\"mirror\"in o?-1!==[\"ticks\",\"all\",\"allticks\"].indexOf(o.mirror)?(this.lineTickMirror[r]=!0,this.lineMirror[r]=!0):!0===o.mirror?(this.lineTickMirror[r]=!1,this.lineMirror[r]=!0):(this.lineTickMirror[r]=!1,this.lineMirror[r]=!1):this.lineMirror[r]=!1,\"showbackground\"in o&&!1!==o.showbackground?(this.backgroundEnable[r]=!0,this.backgroundColor[r]=n(o.backgroundcolor)):this.backgroundEnable[r]=!1):(this.tickEnable[r]=!1,this.labelEnable[r]=!1,this.lineEnable[r]=!1,this.lineTickEnable[r]=!1,this.gridEnable[r]=!1,this.zeroEnable[r]=!1,this.backgroundEnable[r]=!1)}},e.exports=function(t,e){var r=new o;return r.merge(t,e),r}},{\"../../../lib\":719,\"../../../lib/str2rgbarray\":742}],812:[function(t,e,r){\"use strict\";var n=t(\"../../../lib\"),i=t(\"../../../components/color\"),a=t(\"../../../registry\"),o=t(\"../../subplot_defaults\"),s=t(\"./axis_defaults\"),l=t(\"./layout_attributes\"),c=t(\"../../get_data\").getSubplotData,u=\"gl3d\";function h(t,e,r,n){for(var o=r(\"bgcolor\"),l=i.combine(o,n.paper_bgcolor),h=[\"up\",\"center\",\"eye\"],f=0;f<h.length;f++)r(\"camera.\"+h[f]+\".x\"),r(\"camera.\"+h[f]+\".y\"),r(\"camera.\"+h[f]+\".z\");r(\"camera.projection.type\");var p=!!r(\"aspectratio.x\")&&!!r(\"aspectratio.y\")&&!!r(\"aspectratio.z\"),d=r(\"aspectmode\",p?\"manual\":\"auto\");p||(t.aspectratio=e.aspectratio={x:1,y:1,z:1},\"manual\"===d&&(e.aspectmode=\"auto\"),t.aspectmode=e.aspectmode);var g=c(n.fullData,u,n.id);s(t,e,{font:n.font,scene:n.id,data:g,bgColor:l,calendar:n.calendar,fullLayout:n.fullLayout}),a.getComponentMethod(\"annotations3d\",\"handleDefaults\")(t,e,n);var v=n.getDfltFromLayout(\"dragmode\");if(!1!==v&&!v)if(v=\"orbit\",t.camera&&t.camera.up){var m=t.camera.up.x,y=t.camera.up.y,x=t.camera.up.z;0!==x&&(m&&y&&x?x/Math.sqrt(m*m+y*y+x*x)>.999&&(v=\"turntable\"):v=\"turntable\")}else v=\"turntable\";r(\"dragmode\",v),r(\"hovermode\",n.getDfltFromLayout(\"hovermode\"))}e.exports=function(t,e,r){var i=e._basePlotModules.length>1;o(t,e,r,{type:u,attributes:l,handleDefaults:h,fullLayout:e,font:e.font,fullData:r,getDfltFromLayout:function(e){if(!i)return n.validate(t[e],l[e])?t[e]:void 0},paper_bgcolor:e.paper_bgcolor,calendar:e.calendar})}},{\"../../../components/color\":593,\"../../../lib\":719,\"../../../registry\":847,\"../../get_data\":802,\"../../subplot_defaults\":842,\"./axis_defaults\":810,\"./layout_attributes\":813}],813:[function(t,e,r){\"use strict\";var n=t(\"./axis_attributes\"),i=t(\"../../domain\").attributes,a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../lib\").counterRegex;function s(t,e,r){return{x:{valType:\"number\",dflt:t,editType:\"camera\"},y:{valType:\"number\",dflt:e,editType:\"camera\"},z:{valType:\"number\",dflt:r,editType:\"camera\"},editType:\"camera\"}}e.exports={_arrayAttrRegexps:[o(\"scene\",\".annotations\",!0)],bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"plot\"},camera:{up:a(s(0,0,1),{}),center:a(s(0,0,0),{}),eye:a(s(1.25,1.25,1.25),{}),projection:{type:{valType:\"enumerated\",values:[\"perspective\",\"orthographic\"],dflt:\"perspective\",editType:\"calc\"},editType:\"calc\"},editType:\"camera\"},domain:i({name:\"scene\",editType:\"plot\"}),aspectmode:{valType:\"enumerated\",values:[\"auto\",\"cube\",\"data\",\"manual\"],dflt:\"auto\",editType:\"plot\",impliedEdits:{\"aspectratio.x\":void 0,\"aspectratio.y\":void 0,\"aspectratio.z\":void 0}},aspectratio:{x:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},y:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},z:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},editType:\"plot\",impliedEdits:{aspectmode:\"manual\"}},xaxis:n,yaxis:n,zaxis:n,dragmode:{valType:\"enumerated\",values:[\"orbit\",\"turntable\",\"zoom\",\"pan\",!1],editType:\"plot\"},hovermode:{valType:\"enumerated\",values:[\"closest\",!1],dflt:\"closest\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"plot\",_deprecated:{cameraposition:{valType:\"info_array\",editType:\"camera\"}}}},{\"../../../lib\":719,\"../../../lib/extend\":710,\"../../domain\":792,\"./axis_attributes\":809}],814:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=[\"xaxis\",\"yaxis\",\"zaxis\"];function a(){this.enabled=[!0,!0,!0],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.drawSides=[!0,!0,!0],this.lineWidth=[1,1,1]}a.prototype.merge=function(t){for(var e=0;e<3;++e){var r=t[i[e]];r.visible?(this.enabled[e]=r.showspikes,this.colors[e]=n(r.spikecolor),this.drawSides[e]=r.spikesides,this.lineWidth[e]=r.spikethickness):(this.enabled[e]=!1,this.drawSides[e]=!1)}},e.exports=function(t){var e=new a;return e.merge(t),e}},{\"../../../lib/str2rgbarray\":742}],815:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.axesOptions,r=t.glplot.axesPixels,s=t.fullSceneLayout,l=[[],[],[]],c=0;c<3;++c){var u=s[a[c]];if(u._length=(r[c].hi-r[c].lo)*r[c].pixelsPerDataUnit/t.dataScale[c],Math.abs(u._length)===1/0||isNaN(u._length))l[c]=[];else{u._input_range=u.range.slice(),u.range[0]=r[c].lo/t.dataScale[c],u.range[1]=r[c].hi/t.dataScale[c],u._m=1/(t.dataScale[c]*r[c].pixelsPerDataUnit),u.range[0]===u.range[1]&&(u.range[0]-=1,u.range[1]+=1);var h=u.tickmode;if(\"auto\"===u.tickmode){u.tickmode=\"linear\";var f=u.nticks||i.constrain(u._length/40,4,9);n.autoTicks(u,Math.abs(u.range[1]-u.range[0])/f)}for(var p=n.calcTicks(u),d=0;d<p.length;++d)p[d].x=p[d].x*t.dataScale[c],\"date\"===u.type&&(p[d].text=p[d].text.replace(/\\<br\\>/g,\" \"));l[c]=p,u.tickmode=h}}e.ticks=l;for(var c=0;c<3;++c){o[c]=.5*(t.glplot.bounds[0][c]+t.glplot.bounds[1][c]);for(var d=0;d<2;++d)e.bounds[d][c]=t.glplot.bounds[d][c]}t.contourLevels=function(t){for(var e=new Array(3),r=0;r<3;++r){for(var n=t[r],i=new Array(n.length),a=0;a<n.length;++a)i[a]=n[a].x;e[r]=i}return e}(l)};var n=t(\"../../cartesian/axes\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"],o=[0,0,0]},{\"../../../lib\":719,\"../../cartesian/axes\":767}],816:[function(t,e,r){\"use strict\";function n(t,e){var r,n,i=[0,0,0,0];for(r=0;r<4;++r)for(n=0;n<4;++n)i[n]+=t[4*r+n]*e[r];return i}e.exports=function(t,e){return n(t.projection,n(t.view,n(t.model,[e[0],e[1],e[2],1])))}},{}],817:[function(t,e,r){\"use strict\";var n,i,a=t(\"gl-plot3d\").createCamera,o=t(\"gl-plot3d\").createScene,s=t(\"webgl-context\"),l=t(\"has-passive-events\"),c=t(\"../../registry\"),u=t(\"../../lib\"),h=t(\"../../plots/cartesian/axes\"),f=t(\"../../components/fx\"),p=t(\"../../lib/str2rgbarray\"),d=t(\"../../lib/show_no_webgl_msg\"),g=t(\"./project\"),v=t(\"./layout/convert\"),m=t(\"./layout/spikes\"),y=t(\"./layout/tick_marks\");function x(t,e,r,a){if(t.initializeGLCamera(),!function(t,e,r,a,l){var c={canvas:a,gl:l,container:t.container,axes:t.axesOptions,spikes:t.spikeOptions,pickRadius:10,snapToData:!0,autoScale:!0,autoBounds:!1,cameraObject:e,pixelRatio:r};if(t.staticMode){if(!(i||(n=document.createElement(\"canvas\"),i=s({canvas:n,preserveDrawingBuffer:!0,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"error creating static canvas/context for image server\");c.pixelRatio=t.pixelRatio,c.gl=i,c.canvas=n}try{t.glplot=o(c)}catch(t){return!1}return!0}(t,t.camera,e,r,a))return d(t);var c=t.graphDiv,p=function(t){if(!1!==t.fullSceneLayout.dragmode){var e={};e[t.id+\".camera\"]=T(t.camera),t.saveCamera(c.layout),t.graphDiv.emit(\"plotly_relayout\",e)}};return t.glplot.canvas.addEventListener(\"mouseup\",function(){p(t)}),t.glplot.canvas.addEventListener(\"wheel\",function(){c._context._scrollZoom.gl3d&&p(t)},!!l&&{passive:!1}),t.glplot.canvas.addEventListener(\"mousemove\",function(){if(!1!==t.fullSceneLayout.dragmode&&0!==t.camera.mouseListener.buttons){var e={};e[t.id+\".camera\"]=T(t.camera),t.graphDiv.emit(\"plotly_relayouting\",e)}}),t.staticMode||t.glplot.canvas.addEventListener(\"webglcontextlost\",function(e){c&&c.emit&&c.emit(\"plotly_webglcontextlost\",{event:e,layer:t.id})},!1),t.glplot.camera=t.camera,t.glplot.oncontextloss=function(){t.recoverContext()},t.glplot.onrender=function(t){var e,r=t.graphDiv,n=t.svgContainer,i=t.container.getBoundingClientRect(),a=i.width,o=i.height;n.setAttributeNS(null,\"viewBox\",\"0 0 \"+a+\" \"+o),n.setAttributeNS(null,\"width\",a),n.setAttributeNS(null,\"height\",o),y(t),t.glplot.axes.update(t.axesOptions);for(var s,l=Object.keys(t.traces),c=null,p=t.glplot.selection,d=0;d<l.length;++d)\"skip\"!==(e=t.traces[l[d]]).data.hoverinfo&&e.handlePick(p)&&(c=e),e.setContourLevels&&e.setContourLevels();function v(e,r){var n=t.fullSceneLayout[e];return h.tickText(n,n.d2l(r),\"hover\").text}if(null!==c){var m=g(t.glplot.cameraParams,p.dataCoordinate);e=c.data;var x,b=r._fullData[e.index],_=p.index,w={xLabel:v(\"xaxis\",p.traceCoordinate[0]),yLabel:v(\"yaxis\",p.traceCoordinate[1]),zLabel:v(\"zaxis\",p.traceCoordinate[2])},k=f.castHoverinfo(b,t.fullLayout,_),T=(k||\"\").split(\"+\"),A=k&&\"all\"===k;b.hovertemplate||A||(-1===T.indexOf(\"x\")&&(w.xLabel=void 0),-1===T.indexOf(\"y\")&&(w.yLabel=void 0),-1===T.indexOf(\"z\")&&(w.zLabel=void 0),-1===T.indexOf(\"text\")&&(p.textLabel=void 0),-1===T.indexOf(\"name\")&&(c.name=void 0));var M=[];\"cone\"===e.type||\"streamtube\"===e.type?(w.uLabel=v(\"xaxis\",p.traceCoordinate[3]),(A||-1!==T.indexOf(\"u\"))&&M.push(\"u: \"+w.uLabel),w.vLabel=v(\"yaxis\",p.traceCoordinate[4]),(A||-1!==T.indexOf(\"v\"))&&M.push(\"v: \"+w.vLabel),w.wLabel=v(\"zaxis\",p.traceCoordinate[5]),(A||-1!==T.indexOf(\"w\"))&&M.push(\"w: \"+w.wLabel),w.normLabel=p.traceCoordinate[6].toPrecision(3),(A||-1!==T.indexOf(\"norm\"))&&M.push(\"norm: \"+w.normLabel),\"streamtube\"===e.type&&(w.divergenceLabel=p.traceCoordinate[7].toPrecision(3),(A||-1!==T.indexOf(\"divergence\"))&&M.push(\"divergence: \"+w.divergenceLabel)),p.textLabel&&M.push(p.textLabel),x=M.join(\"<br>\")):\"isosurface\"===e.type||\"volume\"===e.type?(w.valueLabel=h.tickText(t.mockAxis,t.mockAxis.d2l(p.traceCoordinate[3]),\"hover\").text,M.push(\"value: \"+w.valueLabel),p.textLabel&&M.push(p.textLabel),x=M.join(\"<br>\")):x=p.textLabel;var S={x:p.traceCoordinate[0],y:p.traceCoordinate[1],z:p.traceCoordinate[2],data:b._input,fullData:b,curveNumber:b.index,pointNumber:_};f.appendArrayPointValue(S,b,_),e._module.eventData&&(S=b._module.eventData(S,p,b,{},_));var E={points:[S]};t.fullSceneLayout.hovermode&&f.loneHover({trace:b,x:(.5+.5*m[0]/m[3])*a,y:(.5-.5*m[1]/m[3])*o,xLabel:w.xLabel,yLabel:w.yLabel,zLabel:w.zLabel,text:x,name:c.name,color:f.castHoverOption(b,_,\"bgcolor\")||c.color,borderColor:f.castHoverOption(b,_,\"bordercolor\"),fontFamily:f.castHoverOption(b,_,\"font.family\"),fontSize:f.castHoverOption(b,_,\"font.size\"),fontColor:f.castHoverOption(b,_,\"font.color\"),nameLength:f.castHoverOption(b,_,\"namelength\"),textAlign:f.castHoverOption(b,_,\"align\"),hovertemplate:u.castOption(b,_,\"hovertemplate\"),hovertemplateLabels:u.extendFlat({},S,w),eventData:[S]},{container:n,gd:r}),p.buttons&&p.distance<5?r.emit(\"plotly_click\",E):r.emit(\"plotly_hover\",E),s=E}else f.loneUnhover(n),r.emit(\"plotly_unhover\",s);t.drawAnnotations(t)}.bind(null,t),t.traces={},t.make4thDimension(),!0}function b(t,e){var r=document.createElement(\"div\"),n=t.container;this.graphDiv=t.graphDiv;var i=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");i.style.position=\"absolute\",i.style.top=i.style.left=\"0px\",i.style.width=i.style.height=\"100%\",i.style[\"z-index\"]=20,i.style[\"pointer-events\"]=\"none\",r.appendChild(i),this.svgContainer=i,r.id=t.id,r.style.position=\"absolute\",r.style.top=r.style.left=\"0px\",r.style.width=r.style.height=\"100%\",n.appendChild(r),this.fullLayout=e,this.id=t.id||\"scene\",this.fullSceneLayout=e[this.id],this.plotArgs=[[],{},{}],this.axesOptions=v(e,e[this.id]),this.spikeOptions=m(e[this.id]),this.container=r,this.staticMode=!!t.staticPlot,this.pixelRatio=this.pixelRatio||t.plotGlPixelRatio||2,this.dataScale=[1,1,1],this.contourLevels=[[],[],[]],this.convertAnnotations=c.getComponentMethod(\"annotations3d\",\"convert\"),this.drawAnnotations=c.getComponentMethod(\"annotations3d\",\"draw\"),x(this,this.pixelRatio)}var _=b.prototype;_.initializeGLCamera=function(){var t=this.fullSceneLayout.camera,e=\"orthographic\"===t.projection.type;this.camera=a(this.container,{center:[t.center.x,t.center.y,t.center.z],eye:[t.eye.x,t.eye.y,t.eye.z],up:[t.up.x,t.up.y,t.up.z],_ortho:e,zoomMin:.01,zoomMax:100,mode:\"orbit\"})},_.recoverContext=function(){var t=this,e=this.glplot.gl,r=this.glplot.canvas,n=this.glplot.camera,i=this.glplot.pixelRatio;this.glplot.dispose(),requestAnimationFrame(function a(){e.isContextLost()?requestAnimationFrame(a):x(t,n,i,r)?t.plot.apply(t,t.plotArgs):u.error(\"Catastrophic and unrecoverable WebGL error. Context lost.\")})};var w=[\"xaxis\",\"yaxis\",\"zaxis\"];function k(t,e,r){for(var n=t.fullSceneLayout,i=0;i<3;i++){var a=w[i],o=a.charAt(0),s=n[a],l=e[o],c=e[o+\"calendar\"],h=e[\"_\"+o+\"length\"];if(u.isArrayOrTypedArray(l))for(var f,p=0;p<(h||l.length);p++)if(u.isArrayOrTypedArray(l[p]))for(var d=0;d<l[p].length;++d)f=s.d2l(l[p][d],0,c),!isNaN(f)&&isFinite(f)&&(r[0][i]=Math.min(r[0][i],f),r[1][i]=Math.max(r[1][i],f));else f=s.d2l(l[p],0,c),!isNaN(f)&&isFinite(f)&&(r[0][i]=Math.min(r[0][i],f),r[1][i]=Math.max(r[1][i],f));else r[0][i]=Math.min(r[0][i],0),r[1][i]=Math.max(r[1][i],h-1)}}function T(t){return{up:{x:t.up[0],y:t.up[1],z:t.up[2]},center:{x:t.center[0],y:t.center[1],z:t.center[2]},eye:{x:t.eye[0],y:t.eye[1],z:t.eye[2]},projection:{type:!0===t._ortho?\"orthographic\":\"perspective\"}}}_.plot=function(t,e,r){if(this.plotArgs=[t,e,r],!this.glplot.contextLost){var n,i,a,o,s,l,c=e[this.id],u=r[this.id];c.bgcolor?this.glplot.clearColor=p(c.bgcolor):this.glplot.clearColor=[0,0,0,0],this.glplot.snapToData=!0,this.fullLayout=e,this.fullSceneLayout=c,this.glplotLayout=c,this.axesOptions.merge(e,c),this.spikeOptions.merge(c),this.setCamera(c.camera),this.updateFx(c.dragmode,c.hovermode),this.camera.enableWheel=this.graphDiv._context._scrollZoom.gl3d,this.glplot.update({}),this.setConvert(s),t?Array.isArray(t)||(t=[t]):t=[];var h=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&k(this,n,h);!function(t,e){for(var r=t.fullSceneLayout,n=r.annotations||[],i=0;i<3;i++)for(var a=w[i],o=a.charAt(0),s=r[a],l=0;l<n.length;l++){var c=n[l];if(c.visible){var u=s.r2l(c[o]);!isNaN(u)&&isFinite(u)&&(e[0][i]=Math.min(e[0][i],u),e[1][i]=Math.max(e[1][i],u))}}}(this,h);var f=[1,1,1];for(o=0;o<3;++o)h[1][o]===h[0][o]?f[o]=1:f[o]=1/(h[1][o]-h[0][o]);for(this.dataScale=f,this.convertAnnotations(this),a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&((i=this.traces[n.uid])?i.data.type===n.type?i.update(n):(i.dispose(),i=n._module.plot(this,n),this.traces[n.uid]=i):(i=n._module.plot(this,n),this.traces[n.uid]=i),i.name=n.name);var d=Object.keys(this.traces);t:for(a=0;a<d.length;++a){for(o=0;o<t.length;++o)if(t[o].uid===d[a]&&!0===t[o].visible&&0!==t[o]._length)continue t;(i=this.traces[d[a]]).dispose(),delete this.traces[d[a]]}this.glplot.objects.sort(function(t,e){return t._trace.data.index-e._trace.data.index});var g=[[0,0,0],[0,0,0]],v=[],m={};for(a=0;a<3;++a){if((l=(s=c[w[a]]).type)in m?(m[l].acc*=f[a],m[l].count+=1):m[l]={acc:f[a],count:1},s.autorange){g[0][a]=1/0,g[1][a]=-1/0;var y=this.glplot.objects,x=this.fullSceneLayout.annotations||[],b=s._name.charAt(0);for(o=0;o<y.length;o++){var _=y[o],T=_.bounds,A=_._trace.data._pad||0;\"ErrorBars\"===_.constructor.name&&s._lowerLogErrorBound?g[0][a]=Math.min(g[0][a],s._lowerLogErrorBound):g[0][a]=Math.min(g[0][a],T[0][a]/f[a]-A),g[1][a]=Math.max(g[1][a],T[1][a]/f[a]+A)}for(o=0;o<x.length;o++){var M=x[o];if(M.visible){var S=s.r2l(M[b]);g[0][a]=Math.min(g[0][a],S),g[1][a]=Math.max(g[1][a],S)}}if(\"rangemode\"in s&&\"tozero\"===s.rangemode&&(g[0][a]=Math.min(g[0][a],0),g[1][a]=Math.max(g[1][a],0)),g[0][a]>g[1][a])g[0][a]=-1,g[1][a]=1;else{var E=g[1][a]-g[0][a];g[0][a]-=E/32,g[1][a]+=E/32}if(\"reversed\"===s.autorange){var C=g[0][a];g[0][a]=g[1][a],g[1][a]=C}}else{var L=s.range;g[0][a]=s.r2l(L[0]),g[1][a]=s.r2l(L[1])}g[0][a]===g[1][a]&&(g[0][a]-=1,g[1][a]+=1),v[a]=g[1][a]-g[0][a],this.glplot.bounds[0][a]=g[0][a]*f[a],this.glplot.bounds[1][a]=g[1][a]*f[a]}var P=[1,1,1];for(a=0;a<3;++a){var O=m[l=(s=c[w[a]]).type];P[a]=Math.pow(O.acc,1/O.count)/f[a]}var z;if(\"auto\"===c.aspectmode)z=Math.max.apply(null,P)/Math.min.apply(null,P)<=4?P:[1,1,1];else if(\"cube\"===c.aspectmode)z=[1,1,1];else if(\"data\"===c.aspectmode)z=P;else{if(\"manual\"!==c.aspectmode)throw new Error(\"scene.js aspectRatio was not one of the enumerated types\");var I=c.aspectratio;z=[I.x,I.y,I.z]}c.aspectratio.x=u.aspectratio.x=z[0],c.aspectratio.y=u.aspectratio.y=z[1],c.aspectratio.z=u.aspectratio.z=z[2],this.glplot.aspect=z;var D=c.domain||null,R=e._size||null;if(D&&R){var F=this.container.style;F.position=\"absolute\",F.left=R.l+D.x[0]*R.w+\"px\",F.top=R.t+(1-D.y[1])*R.h+\"px\",F.width=R.w*(D.x[1]-D.x[0])+\"px\",F.height=R.h*(D.y[1]-D.y[0])+\"px\"}this.glplot.redraw()}},_.destroy=function(){this.glplot&&(this.camera.mouseListener.enabled=!1,this.container.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=this.glplot.camera=null,this.glplot.dispose(),this.container.parentNode.removeChild(this.container),this.glplot=null)},_.getCamera=function(){return this.glplot.camera.view.recalcMatrix(this.camera.view.lastT()),T(this.glplot.camera)},_.setCamera=function(t){var e;this.glplot.camera.lookAt.apply(this,[[(e=t).eye.x,e.eye.y,e.eye.z],[e.center.x,e.center.y,e.center.z],[e.up.x,e.up.y,e.up.z]]);var r=\"orthographic\"===t.projection.type;if(r!==this.glplot.camera._ortho){this.glplot.redraw();var n=this.glplot.pixelRatio,i=this.glplot.clearColor;this.glplot.gl.clearColor(i[0],i[1],i[2],i[3]),this.glplot.gl.clear(this.glplot.gl.DEPTH_BUFFER_BIT|this.glplot.gl.COLOR_BUFFER_BIT),this.glplot.dispose(),x(this,n),this.glplot.camera._ortho=r}},_.saveCamera=function(t){var e=this.fullLayout,r=this.getCamera(),n=u.nestedProperty(t,this.id+\".camera\"),i=n.get(),a=!1;function o(t,e,r,n){var i=[\"up\",\"center\",\"eye\"],a=[\"x\",\"y\",\"z\"];return e[i[r]]&&t[i[r]][a[n]]===e[i[r]][a[n]]}if(void 0===i)a=!0;else{for(var s=0;s<3;s++)for(var l=0;l<3;l++)if(!o(r,i,s,l)){a=!0;break}(!i.projection||r.projection&&r.projection.type!==i.projection.type)&&(a=!0)}if(a){var h={};h[this.id+\".camera\"]=i,c.call(\"_storeDirectGUIEdit\",t,e._preGUI,h),n.set(r),u.nestedProperty(e,this.id+\".camera\").set(r)}return a},_.updateFx=function(t,e){var r=this.camera;if(r)if(\"orbit\"===t)r.mode=\"orbit\",r.keyBindingMode=\"rotate\";else if(\"turntable\"===t){r.up=[0,0,1],r.mode=\"turntable\",r.keyBindingMode=\"rotate\";var n=this.graphDiv,i=n._fullLayout,a=this.fullSceneLayout.camera,o=a.up.x,s=a.up.y,l=a.up.z;if(l/Math.sqrt(o*o+s*s+l*l)<.999){var h=this.id+\".camera.up\",f={x:0,y:0,z:1},p={};p[h]=f;var d=n.layout;c.call(\"_storeDirectGUIEdit\",d,i._preGUI,p),a.up=f,u.nestedProperty(d,h).set(f)}}else r.keyBindingMode=t;this.fullSceneLayout.hovermode=e},_.toImage=function(t){t||(t=\"png\"),this.staticMode&&this.container.appendChild(n),this.glplot.redraw();var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a);for(var o=0,s=i-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=a[4*(r*o+l)+c];a[4*(r*o+l)+c]=a[4*(r*s+l)+c],a[4*(r*s+l)+c]=u}var h=document.createElement(\"canvas\");h.width=r,h.height=i;var f,p=h.getContext(\"2d\"),d=p.createImageData(r,i);switch(d.data.set(a),p.putImageData(d,0,0),t){case\"jpeg\":f=h.toDataURL(\"image/jpeg\");break;case\"webp\":f=h.toDataURL(\"image/webp\");break;default:f=h.toDataURL(\"image/png\")}return this.staticMode&&this.container.removeChild(n),f},_.setConvert=function(){for(var t=0;t<3;t++){var e=this.fullSceneLayout[w[t]];h.setConvert(e,this.fullLayout),e.setScale=u.noop}},_.make4thDimension=function(){var t=this.graphDiv._fullLayout;this.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},h.setConvert(this.mockAxis,t)},e.exports=b},{\"../../components/fx\":632,\"../../lib\":719,\"../../lib/show_no_webgl_msg\":740,\"../../lib/str2rgbarray\":742,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./layout/convert\":811,\"./layout/spikes\":814,\"./layout/tick_marks\":815,\"./project\":816,\"gl-plot3d\":290,\"has-passive-events\":411,\"webgl-context\":556}],818:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){n=n||t.length;for(var i=new Array(n),a=0;a<n;a++)i[a]=[t[a],e[a],r[a]];return i}},{}],819:[function(t,e,r){\"use strict\";var n=t(\"./font_attributes\"),i=t(\"./animation_attributes\"),a=t(\"../components/color/attributes\"),o=t(\"./pad_attributes\"),s=t(\"../lib/extend\").extendFlat,l=n({editType:\"calc\"});l.family.dflt='\"Open Sans\", verdana, arial, sans-serif',l.size.dflt=12,l.color.dflt=a.defaultLine,e.exports={font:l,title:{text:{valType:\"string\",editType:\"layoutstyle\"},font:n({editType:\"layoutstyle\"}),xref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},yref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},x:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"layoutstyle\"},y:{valType:\"number\",min:0,max:1,dflt:\"auto\",editType:\"layoutstyle\"},xanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"left\",\"center\",\"right\"],editType:\"layoutstyle\"},yanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],editType:\"layoutstyle\"},pad:s(o({editType:\"layoutstyle\"}),{}),editType:\"layoutstyle\"},autosize:{valType:\"boolean\",dflt:!1,editType:\"none\"},width:{valType:\"number\",min:10,dflt:700,editType:\"plot\"},height:{valType:\"number\",min:10,dflt:450,editType:\"plot\"},margin:{l:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},r:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},t:{valType:\"number\",min:0,dflt:100,editType:\"plot\"},b:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},pad:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},autoexpand:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},paper_bgcolor:{valType:\"color\",dflt:a.background,editType:\"plot\"},plot_bgcolor:{valType:\"color\",dflt:a.background,editType:\"layoutstyle\"},separators:{valType:\"string\",editType:\"plot\"},hidesources:{valType:\"boolean\",dflt:!1,editType:\"plot\"},showlegend:{valType:\"boolean\",editType:\"legend\"},colorway:{valType:\"colorlist\",dflt:a.defaults,editType:\"calc\"},datarevision:{valType:\"any\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editrevision:{valType:\"any\",editType:\"none\"},selectionrevision:{valType:\"any\",editType:\"none\"},template:{valType:\"any\",editType:\"calc\"},modebar:{orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\",editType:\"modebar\"},bgcolor:{valType:\"color\",editType:\"modebar\"},color:{valType:\"color\",editType:\"modebar\"},activecolor:{valType:\"color\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"modebar\"},meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},transition:s({},i.transition,{editType:\"none\"}),_deprecated:{title:{valType:\"string\",editType:\"layoutstyle\"},titlefont:n({editType:\"layoutstyle\"})}}},{\"../components/color/attributes\":592,\"../lib/extend\":710,\"./animation_attributes\":762,\"./font_attributes\":793,\"./pad_attributes\":827}],820:[function(t,e,r){\"use strict\";var n={\"open-street-map\":{id:\"osm\",version:8,sources:{\"plotly-osm-tiles\":{type:\"raster\",attribution:'<a href=\"http://www.openstreetmap.org/about/\" target=\"_blank\">\\xa9 OpenStreetMap</a>',tiles:[\"https://a.tile.openstreetmap.org/{z}/{x}/{y}.png\",\"https://b.tile.openstreetmap.org/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-osm-tiles\",type:\"raster\",source:\"plotly-osm-tiles\",minzoom:0,maxzoom:22}]},\"white-bg\":{id:\"white-bg\",version:8,sources:{},layers:[{id:\"white-bg\",type:\"background\",paint:{\"background-color\":\"#FFFFFF\"},minzoom:0,maxzoom:22}]},\"carto-positron\":{id:\"carto-positron\",version:8,sources:{\"plotly-carto-positron\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/light_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-positron\",type:\"raster\",source:\"plotly-carto-positron\",minzoom:0,maxzoom:22}]},\"carto-darkmatter\":{id:\"carto-darkmatter\",version:8,sources:{\"plotly-carto-darkmatter\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/dark_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-darkmatter\",type:\"raster\",source:\"plotly-carto-darkmatter\",minzoom:0,maxzoom:22}]},\"stamen-terrain\":{id:\"stamen-terrain\",version:8,sources:{\"plotly-stamen-terrain\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/terrain/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-terrain\",type:\"raster\",source:\"plotly-stamen-terrain\",minzoom:0,maxzoom:22}]},\"stamen-toner\":{id:\"stamen-toner\",version:8,sources:{\"plotly-stamen-toner\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/toner/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-toner\",type:\"raster\",source:\"plotly-stamen-toner\",minzoom:0,maxzoom:22}]},\"stamen-watercolor\":{id:\"stamen-watercolor\",version:8,sources:{\"plotly-stamen-watercolor\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://creativecommons.org/licenses/by-sa/3.0\">CC BY SA</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/watercolor/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-watercolor\",type:\"raster\",source:\"plotly-stamen-watercolor\",minzoom:0,maxzoom:22}]}},i=Object.keys(n);e.exports={requiredVersion:\"1.1.1\",styleUrlPrefix:\"mapbox://styles/mapbox/\",styleUrlSuffix:\"v9\",styleValuesMapbox:[\"basic\",\"streets\",\"outdoors\",\"light\",\"dark\",\"satellite\",\"satellite-streets\"],styleValueDflt:\"basic\",stylesNonMapbox:n,styleValuesNonMapbox:i,traceLayerPrefix:\"plotly-trace-layer-\",layoutLayerPrefix:\"plotly-layout-layer-\",wrongVersionErrorMsg:[\"Your custom plotly.js bundle is not using the correct mapbox-gl version\",\"Please install mapbox-gl@1.1.1.\"].join(\"\\n\"),noAccessTokenErrorMsg:[\"Missing Mapbox access token.\",\"Mapbox trace type require a Mapbox access token to be registered.\",\"For example:\",\"  Plotly.plot(gd, data, layout, { mapboxAccessToken: 'my-access-token' });\",\"More info here: https://www.mapbox.com/help/define-access-token/\"].join(\"\\n\"),missingStyleErrorMsg:[\"No valid mapbox style found, please set `mapbox.style` to one of:\",i.join(\", \"),\"or register a Mapbox access token to use a Mapbox-served style.\"].join(\"\\n\"),multipleTokensErrorMsg:[\"Set multiple mapbox access token across different mapbox subplot,\",\"using first token found as mapbox-gl does not allow multipleaccess tokens on the same page.\"].join(\"\\n\"),mapOnErrorMsg:\"Mapbox error.\",mapboxLogo:{path0:\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\",path1:\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\",path2:\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\",polygon:\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34\"},styleRules:{map:\"overflow:hidden;position:relative;\",\"missing-css\":\"display:none;\",canary:\"background-color:salmon;\",\"ctrl-bottom-left\":\"position: absolute; pointer-events: none; z-index: 2; bottom: 0; left: 0;\",\"ctrl-bottom-right\":\"position: absolute; pointer-events: none; z-index: 2; right: 0; bottom: 0;\",ctrl:\"clear: both; pointer-events: auto; transform: translate(0, 0);\",\"ctrl-attrib.mapboxgl-compact .mapboxgl-ctrl-attrib-inner\":\"display: none;\",\"ctrl-attrib.mapboxgl-compact:hover .mapboxgl-ctrl-attrib-inner\":\"display: block; margin-top:2px\",\"ctrl-attrib.mapboxgl-compact:hover\":\"padding: 2px 24px 2px 4px; visibility: visible; margin-top: 6px;\",\"ctrl-attrib.mapboxgl-compact::after\":'content: \"\"; cursor: pointer; position: absolute; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3Csvg viewBox=\"0 0 20 20\" xmlns=\"http://www.w3.org/2000/svg\"%3E %3Cpath fill=\"%23333333\" fill-rule=\"evenodd\" d=\"M4,10a6,6 0 1,0 12,0a6,6 0 1,0 -12,0 M9,7a1,1 0 1,0 2,0a1,1 0 1,0 -2,0 M9,10a1,1 0 1,1 2,0l0,3a1,1 0 1,1 -2,0\"/%3E %3C/svg%3E\\'); background-color: rgba(255, 255, 255, 0.5); width: 24px; height: 24px; box-sizing: border-box; border-radius: 12px;',\"ctrl-attrib.mapboxgl-compact\":\"min-height: 20px; padding: 0; margin: 10px; position: relative; background-color: #fff; border-radius: 3px 12px 12px 3px;\",\"ctrl-bottom-right > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; right: 0\",\"ctrl-bottom-left > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; left: 0\",\"ctrl-bottom-left .mapboxgl-ctrl\":\"margin: 0 0 10px 10px; float: left;\",\"ctrl-bottom-right .mapboxgl-ctrl\":\"margin: 0 10px 10px 0; float: right;\",\"ctrl-attrib\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a:hover\":\"color: inherit; text-decoration: underline;\",\"ctrl-attrib .mapbox-improve-map\":\"font-weight: bold; margin-left: 2px;\",\"attrib-empty\":\"display: none;\",\"ctrl-logo\":'display:block; width: 21px; height: 21px; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3C?xml version=\"1.0\" encoding=\"utf-8\"?%3E %3Csvg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\" viewBox=\"0 0 21 21\" style=\"enable-background:new 0 0 21 21;\" xml:space=\"preserve\"%3E%3Cg transform=\"translate(0,0.01)\"%3E%3Cpath d=\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3Cpath d=\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpath d=\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpolygon points=\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34 \" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3C/g%3E%3C/svg%3E\\')'}}},{}],821:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t.split(\" \"),i=r[0],a=r[1],o=n.isArrayOrTypedArray(e)?n.mean(e):e,s=.5+o/100,l=1.5+o/100,c=[\"\",\"\"],u=[0,0];switch(i){case\"top\":c[0]=\"top\",u[1]=-l;break;case\"bottom\":c[0]=\"bottom\",u[1]=l}switch(a){case\"left\":c[1]=\"right\",u[0]=-s;break;case\"right\":c[1]=\"left\",u[0]=s}return{anchor:c[0]&&c[1]?c.join(\"-\"):c[0]?c[0]:c[1]?c[1]:\"center\",offset:u}}},{\"../../lib\":719}],822:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"../../lib\"),a=t(\"../../plots/get_data\").getSubplotCalcData,o=t(\"../../constants/xmlns_namespaces\"),s=t(\"d3\"),l=t(\"../../components/drawing\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"./mapbox\"),h=r.constants=t(\"./constants\");function f(t){return\"string\"==typeof t&&-1!==h.styleValuesMapbox.indexOf(t)}r.name=\"mapbox\",r.attr=\"subplot\",r.idRoot=\"mapbox\",r.idRegex=r.attrRegex=i.counterRegex(\"mapbox\"),r.attributes={subplot:{valType:\"subplotid\",dflt:\"mapbox\",editType:\"calc\"}},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){var e=t._fullLayout,r=t.calcdata,o=e._subplots.mapbox;if(n.version!==h.requiredVersion)throw new Error(h.wrongVersionErrorMsg);var s=function(t,e){var r=t._fullLayout;if(\"\"===t._context.mapboxAccessToken)return\"\";for(var n=[],a=[],o=!1,s=!1,l=0;l<e.length;l++){var c=r[e[l]],u=c.accesstoken;f(c.style)&&(u?i.pushUnique(n,u):(f(c._input.style)&&(i.error(\"Uses Mapbox map style, but did not set an access token.\"),o=!0),s=!0)),u&&i.pushUnique(a,u)}if(s){var p=o?h.noAccessTokenErrorMsg:h.missingStyleErrorMsg;throw new Error(p)}return n.length?(n.length>1&&i.warn(h.multipleTokensErrorMsg),n[0]):(a.length&&i.log([\"Listed mapbox access token(s)\",a.join(\",\"),\"but did not use a Mapbox map style, ignoring token(s).\"].join(\" \")),\"\")}(t,o);n.accessToken=s;for(var l=0;l<o.length;l++){var c=o[l],p=a(r,\"mapbox\",c),d=e[c],g=d._subplot;g||(g=new u(t,c),e[c]._subplot=g),g.viewInitial||(g.viewInitial={center:i.extendFlat({},d.center),zoom:d.zoom,bearing:d.bearing,pitch:d.pitch}),g.plot(p,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.mapbox||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._subplot&&n[o]._subplot.destroy()}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=e._size,i=0;i<r.length;i++){var a=e[r[i]],u=a.domain,f=a._subplot.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":f,x:n.l+n.w*u.x[0],y:n.t+n.h*(1-u.y[1]),width:n.w*(u.x[1]-u.x[0]),height:n.h*(u.y[1]-u.y[0]),preserveAspectRatio:\"none\"});var p=s.select(a._subplot.div);if(!(null===p.select(\".mapboxgl-ctrl-logo\").node().offsetParent)){var d=e._glimages.append(\"g\");d.attr(\"transform\",\"translate(\"+(n.l+n.w*u.x[0]+10)+\", \"+(n.t+n.h*(1-u.y[0])-31)+\")\"),d.append(\"path\").attr(\"d\",h.mapboxLogo.path0).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"}),d.append(\"path\").attr(\"d\",h.mapboxLogo.path1).style(\"opacity\",.35).style(\"enable-background\",\"new\"),d.append(\"path\").attr(\"d\",h.mapboxLogo.path2).style(\"opacity\",.35).style(\"enable-background\",\"new\"),d.append(\"polygon\").attr(\"points\",h.mapboxLogo.polygon).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"})}var g=p.select(\".mapboxgl-ctrl-attrib\").text().replace(\"Improve this map\",\"\"),v=e._glimages.append(\"g\"),m=v.append(\"text\");m.text(g).classed(\"static-attribution\",!0).attr({\"font-size\":12,\"font-family\":\"Arial\",color:\"rgba(0, 0, 0, 0.75)\",\"text-anchor\":\"end\",\"data-unformatted\":g});var y=l.bBox(m.node()),x=n.w*(u.x[1]-u.x[0]);if(y.width>x/2){var b=g.split(\"|\").join(\"<br>\");m.text(b).attr(\"data-unformatted\",b).call(c.convertToTspans,t),y=l.bBox(m.node())}m.attr(\"transform\",\"translate(-3, \"+(8-y.height)+\")\"),v.insert(\"rect\",\".static-attribution\").attr({x:-y.width-6,y:-y.height-3,width:y.width+6,height:y.height+3,fill:\"rgba(255, 255, 255, 0.75)\"});var _=1;y.width+6>x&&(_=x/(y.width+6));var w=[n.l+n.w*u.x[1],n.t+n.h*(1-u.y[0])];v.attr(\"transform\",\"translate(\"+w[0]+\",\"+w[1]+\") scale(\"+_+\")\")}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=0;n<r.length;n++){e[r[n]]._subplot.updateFx(e)}}},{\"../../components/drawing\":614,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/get_data\":802,\"./constants\":820,\"./layout_attributes\":824,\"./layout_defaults\":825,\"./mapbox\":826,d3:163,\"mapbox-gl\":426}],823:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./convert_text_opts\"),a=t(\"./constants\");function o(t,e){this.subplot=t,this.uid=t.uid+\"-\"+e,this.index=e,this.idSource=\"source-\"+this.uid,this.idLayer=a.layoutLayerPrefix+this.uid,this.sourceType=null,this.source=null,this.layerType=null,this.below=null,this.visible=!1}var s=o.prototype;function l(t){var e=t.source;return t.visible&&(n.isPlainObject(e)||(\"string\"==typeof e||Array.isArray(e))&&e.length>0)}function c(t){var e={},r={};switch(t.type){case\"circle\":n.extendFlat(r,{\"circle-radius\":t.circle.radius,\"circle-color\":t.color,\"circle-opacity\":t.opacity});break;case\"line\":n.extendFlat(r,{\"line-width\":t.line.width,\"line-color\":t.color,\"line-opacity\":t.opacity,\"line-dasharray\":t.line.dash});break;case\"fill\":n.extendFlat(r,{\"fill-color\":t.color,\"fill-outline-color\":t.fill.outlinecolor,\"fill-opacity\":t.opacity});break;case\"symbol\":var a=t.symbol,o=i(a.textposition,a.iconsize);n.extendFlat(e,{\"icon-image\":a.icon+\"-15\",\"icon-size\":a.iconsize/10,\"text-field\":a.text,\"text-size\":a.textfont.size,\"text-anchor\":o.anchor,\"text-offset\":o.offset,\"symbol-placement\":a.placement}),n.extendFlat(r,{\"icon-color\":t.color,\"text-color\":a.textfont.color,\"text-opacity\":t.opacity})}return{layout:e,paint:r}}s.update=function(t){this.visible?this.needsNewSource(t)?(this.removeLayer(),this.updateSource(t),this.updateLayer(t)):this.needsNewLayer(t)?this.updateLayer(t):this.updateStyle(t):(this.updateSource(t),this.updateLayer(t)),this.visible=l(t)},s.needsNewSource=function(t){return this.sourceType!==t.sourcetype||this.source!==t.source||this.layerType!==t.type},s.needsNewLayer=function(t){return this.layerType!==t.type||this.below!==this.subplot.belowLookup[\"layout-\"+this.index]},s.updateSource=function(t){var e=this.subplot.map;if(e.getSource(this.idSource)&&e.removeSource(this.idSource),this.sourceType=t.sourcetype,this.source=t.source,l(t)){var r=function(t){var e,r=t.sourcetype,n=t.source,i={type:r};\"geojson\"===r?e=\"data\":\"vector\"===r?e=\"string\"==typeof n?\"url\":\"tiles\":\"raster\"===r?(e=\"tiles\",i.tileSize=256):\"image\"===r&&(e=\"url\",i.coordinates=t.coordinates);i[e]=n,t.sourceattribution&&(i.attribution=t.sourceattribution);return i}(t);e.addSource(this.idSource,r)}},s.updateLayer=function(t){var e,r=this.subplot,n=c(t),i=this.subplot.belowLookup[\"layout-\"+this.index];if(\"traces\"===i)for(var o=r.getMapLayers(),s=0;s<o.length;s++){var u=o[s].id;if(\"string\"==typeof u&&0===u.indexOf(a.traceLayerPrefix)){e=u;break}}else e=i;this.removeLayer(),l(t)&&r.addLayer({id:this.idLayer,source:this.idSource,\"source-layer\":t.sourcelayer||\"\",type:t.type,minzoom:t.minzoom,maxzoom:t.maxzoom,layout:n.layout,paint:n.paint},e),this.layerType=t.type,this.below=i},s.updateStyle=function(t){if(l(t)){var e=c(t);this.subplot.setOptions(this.idLayer,\"setLayoutProperty\",e.layout),this.subplot.setOptions(this.idLayer,\"setPaintProperty\",e.paint)}},s.removeLayer=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer)},s.dispose=function(){var t=this.subplot.map;t.removeLayer(this.idLayer),t.removeSource(this.idSource)},e.exports=function(t,e,r){var n=new o(t,e);return n.update(r),n}},{\"../../lib\":719,\"./constants\":820,\"./convert_text_opts\":821}],824:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\").defaultLine,a=t(\"../domain\").attributes,o=t(\"../font_attributes\"),s=t(\"../../traces/scatter/attributes\").textposition,l=t(\"../../plot_api/edit_types\").overrideAll,c=t(\"../../plot_api/plot_template\").templatedArray,u=t(\"./constants\"),h=o({});h.family.dflt=\"Open Sans Regular, Arial Unicode MS Regular\",(e.exports=l({_arrayAttrRegexps:[n.counterRegex(\"mapbox\",\".layers\",!0)],domain:a({name:\"mapbox\"}),accesstoken:{valType:\"string\",noBlank:!0,strict:!0},style:{valType:\"any\",values:u.styleValuesMapbox.concat(u.styleValuesNonMapbox),dflt:u.styleValueDflt},center:{lon:{valType:\"number\",dflt:0},lat:{valType:\"number\",dflt:0}},zoom:{valType:\"number\",dflt:1},bearing:{valType:\"number\",dflt:0},pitch:{valType:\"number\",dflt:0},layers:c(\"layer\",{visible:{valType:\"boolean\",dflt:!0},sourcetype:{valType:\"enumerated\",values:[\"geojson\",\"vector\",\"raster\",\"image\"],dflt:\"geojson\"},source:{valType:\"any\"},sourcelayer:{valType:\"string\",dflt:\"\"},sourceattribution:{valType:\"string\"},type:{valType:\"enumerated\",values:[\"circle\",\"line\",\"fill\",\"symbol\",\"raster\"],dflt:\"circle\"},coordinates:{valType:\"any\"},below:{valType:\"string\"},color:{valType:\"color\",dflt:i},opacity:{valType:\"number\",min:0,max:1,dflt:1},minzoom:{valType:\"number\",min:0,max:24,dflt:0},maxzoom:{valType:\"number\",min:0,max:24,dflt:24},circle:{radius:{valType:\"number\",dflt:15}},line:{width:{valType:\"number\",dflt:2},dash:{valType:\"data_array\"}},fill:{outlinecolor:{valType:\"color\",dflt:i}},symbol:{icon:{valType:\"string\",dflt:\"marker\"},iconsize:{valType:\"number\",dflt:10},text:{valType:\"string\",dflt:\"\"},placement:{valType:\"enumerated\",values:[\"point\",\"line\",\"line-center\"],dflt:\"point\"},textfont:h,textposition:n.extendFlat({},s,{arrayOk:!1})}})},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../traces/scatter/attributes\":1112,\"../domain\":792,\"../font_attributes\":793,\"./constants\":820}],825:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../subplot_defaults\"),a=t(\"../array_container_defaults\"),o=t(\"./layout_attributes\");function s(t,e,r,n){r(\"accesstoken\",n.accessToken),r(\"style\"),r(\"center.lon\"),r(\"center.lat\"),r(\"zoom\"),r(\"bearing\"),r(\"pitch\"),a(t,e,{name:\"layers\",handleItemDefaults:l}),e._input=t}function l(t,e){function r(r,i){return n.coerce(t,e,o.layers,r,i)}if(r(\"visible\")){var i,a=r(\"sourcetype\"),s=\"raster\"===a||\"image\"===a;r(\"source\"),r(\"sourceattribution\"),\"vector\"===a&&r(\"sourcelayer\"),\"image\"===a&&r(\"coordinates\"),s&&(i=\"raster\");var l=r(\"type\",i);s&&\"raster\"!==l&&(l=e.type=\"raster\",n.log(\"Source types *raster* and *image* must drawn *raster* layer type.\")),r(\"below\"),r(\"color\"),r(\"opacity\"),r(\"minzoom\"),r(\"maxzoom\"),\"circle\"===l&&r(\"circle.radius\"),\"line\"===l&&(r(\"line.width\"),r(\"line.dash\")),\"fill\"===l&&r(\"fill.outlinecolor\"),\"symbol\"===l&&(r(\"symbol.icon\"),r(\"symbol.iconsize\"),r(\"symbol.text\"),n.coerceFont(r,\"symbol.textfont\"),r(\"symbol.textposition\"),r(\"symbol.placement\"))}}e.exports=function(t,e,r){i(t,e,r,{type:\"mapbox\",attributes:o,handleDefaults:s,partition:\"y\",accessToken:e._mapboxAccessToken})}},{\"../../lib\":719,\"../array_container_defaults\":763,\"../subplot_defaults\":842,\"./layout_attributes\":824}],826:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"d3\"),a=t(\"../../components/fx\"),o=t(\"../../lib\"),s=t(\"../../registry\"),l=t(\"../cartesian/axes\"),c=t(\"../../components/dragelement\"),u=t(\"../cartesian/select\").prepSelect,h=t(\"../cartesian/select\").selectOnClick,f=t(\"./constants\"),p=t(\"./layers\");function d(t,e){this.id=e,this.gd=t;var r=t._fullLayout,n=t._context;this.container=r._glcontainer.node(),this.isStatic=n.staticPlot,this.uid=r._uid+\"-\"+this.id,this.div=null,this.xaxis=null,this.yaxis=null,this.createFramework(r),this.map=null,this.accessToken=null,this.styleObj=null,this.traceHash={},this.layerList=[],this.belowLookup={}}var g=d.prototype;g.plot=function(t,e,r){var n,i=this,a=e[i.id];i.map&&a.accesstoken!==i.accessToken&&(i.map.remove(),i.map=null,i.styleObj=null,i.traceHash=[],i.layerList={}),n=i.map?new Promise(function(r,n){i.updateMap(t,e,r,n)}):new Promise(function(r,n){i.createMap(t,e,r,n)}),r.push(n)},g.createMap=function(t,e,r,i){var a=this,o=e[a.id],s=a.styleObj=m(o.style);a.accessToken=o.accesstoken;var l=a.map=new n.Map({container:a.div,style:s.style,center:x(o.center),zoom:o.zoom,bearing:o.bearing,pitch:o.pitch,interactive:!a.isStatic,preserveDrawingBuffer:a.isStatic,doubleClickZoom:!1,boxZoom:!1,attributionControl:!1}).addControl(new n.AttributionControl({compact:!0}));l._canvas.style.left=\"0px\",l._canvas.style.top=\"0px\",a.rejectOnError(i),a.isStatic||a.initFx(t,e);var c=[];c.push(new Promise(function(t){l.once(\"load\",t)})),c=c.concat(a.fetchMapData(t,e)),Promise.all(c).then(function(){a.fillBelowLookup(t,e),a.updateData(t),a.updateLayout(e),a.resolveOnRender(r)}).catch(i)},g.fetchMapData=function(t){var e=[];function r(t){return new Promise(function(e,r){i.json(t,function(n,i){if(n){delete PlotlyGeoAssets[t];var a=404===n.status?'GeoJSON at URL \"'+t+'\" does not exist.':\"Unexpected error while fetching from \"+t;return r(new Error(a))}PlotlyGeoAssets[t]=i,e(i)})})}for(var n=0;n<t.length;n++){var a=t[n][0].trace.geojson;\"string\"!=typeof a||PlotlyGeoAssets[a]||(PlotlyGeoAssets[a]=\"pending\",e.push(r(a)))}return e},g.updateMap=function(t,e,r,n){var i=this,a=i.map,o=e[this.id];i.rejectOnError(n);var s=[],l=m(o.style);i.styleObj.id!==l.id&&(i.styleObj=l,a.setStyle(l.style),i.traceHash={},s.push(new Promise(function(t){a.once(\"styledata\",t)}))),s=s.concat(i.fetchMapData(t,e)),Promise.all(s).then(function(){i.fillBelowLookup(t,e),i.updateData(t),i.updateLayout(e),i.resolveOnRender(r)}).catch(n)},g.fillBelowLookup=function(t,e){var r,n,i=e[this.id].layers,a=this.belowLookup={},o=!1;for(r=0;r<t.length;r++){var s=t[r][0].trace,l=s._module;\"string\"==typeof s.below?n=s.below:l.getBelow&&(n=l.getBelow(s,this)),\"\"===n&&(o=!0),a[\"trace-\"+s.uid]=n||\"\"}for(r=0;r<i.length;r++){var c=i[r];n=\"string\"==typeof c.below?c.below:o?\"traces\":\"\",a[\"layout-\"+r]=n}var u,h,f={};for(u in a)f[n=a[u]]?f[n].push(u):f[n]=[u];for(n in f){var p=f[n];if(p.length>1)for(r=0;r<p.length;r++)0===(u=p[r]).indexOf(\"trace-\")?(h=u.split(\"trace-\")[1],this.traceHash[h]&&(this.traceHash[h].below=null)):0===u.indexOf(\"layout-\")&&(h=u.split(\"layout-\")[1],this.layerList[h]&&(this.layerList[h].below=null))}};var v={choroplethmapbox:0,densitymapbox:1,scattermapbox:2};function m(t){var e={};return o.isPlainObject(t)?(e.id=t.id,e.style=t):\"string\"==typeof t?(e.id=t,-1!==f.styleValuesMapbox.indexOf(t)?e.style=y(t):f.stylesNonMapbox[t]?e.style=f.stylesNonMapbox[t]:e.style=t):(e.id=f.styleValueDflt,e.style=y(f.styleValueDflt)),e.transition={duration:0,delay:0},e}function y(t){return f.styleUrlPrefix+t+\"-\"+f.styleUrlSuffix}function x(t){return[t.lon,t.lat]}g.updateData=function(t){var e,r,n,i,a=this.traceHash,o=t.slice().sort(function(t,e){return v[t[0].trace.type]-v[e[0].trace.type]});for(n=0;n<o.length;n++){var s=o[n];(e=a[(r=s[0].trace).uid])?e.update(s):r._module&&(a[r.uid]=r._module.plot(this,s))}var l=Object.keys(a);t:for(n=0;n<l.length;n++){var c=l[n];for(i=0;i<t.length;i++)if(c===(r=t[i][0].trace).uid)continue t;(e=a[c]).dispose(),delete a[c]}},g.updateLayout=function(t){var e=this.map,r=t[this.id];e.setCenter(x(r.center)),e.setZoom(r.zoom),e.setBearing(r.bearing),e.setPitch(r.pitch),this.updateLayers(t),this.updateFramework(t),this.updateFx(t),this.map.resize(),this.gd._context._scrollZoom.mapbox?e.scrollZoom.enable():e.scrollZoom.disable()},g.resolveOnRender=function(t){var e=this.map;e.on(\"render\",function r(){e.loaded()&&(e.off(\"render\",r),setTimeout(t,0))})},g.rejectOnError=function(t){var e=this.map;function r(){t(new Error(f.mapOnErrorMsg))}e.once(\"error\",r),e.once(\"style.error\",r),e.once(\"source.error\",r),e.once(\"tile.error\",r),e.once(\"layer.error\",r)},g.createFramework=function(t){var e=this,r=e.div=document.createElement(\"div\");r.id=e.uid,r.style.position=\"absolute\",e.container.appendChild(r),e.xaxis={_id:\"x\",c2p:function(t){return e.project(t).x}},e.yaxis={_id:\"y\",c2p:function(t){return e.project(t).y}},e.updateFramework(t),e.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},l.setConvert(e.mockAxis,t)},g.initFx=function(t,e){var r=this,n=r.gd,i=r.map,o=!1;function l(){a.loneUnhover(e._hoverlayer)}function c(){var t=r.getView();n.emit(\"plotly_relayouting\",r.getViewEdits(t))}i.on(\"moveend\",function(t){if(r.map){var e=n._fullLayout;if(t.originalEvent||o){var i=e[r.id];s.call(\"_storeDirectGUIEdit\",n.layout,e._preGUI,r.getViewEdits(i));var a=r.getView();i._input.center=i.center=a.center,i._input.zoom=i.zoom=a.zoom,i._input.bearing=i.bearing=a.bearing,i._input.pitch=i.pitch=a.pitch,n.emit(\"plotly_relayout\",r.getViewEdits(a))}o=!1,e._rehover&&e._rehover()}}),i.on(\"wheel\",function(){o=!0}),i.on(\"mousemove\",function(t){var e=r.div.getBoundingClientRect();t.clientX=t.point.x+e.left,t.clientY=t.point.y+e.top,t.target.getBoundingClientRect=function(){return e},r.xaxis.p2c=function(){return t.lngLat.lng},r.yaxis.p2c=function(){return t.lngLat.lat},n._fullLayout._rehover=function(){n._fullLayout._hoversubplot===r.id&&a.hover(n,t,r.id)},a.hover(n,t,r.id),n._fullLayout._hoversubplot=r.id}),i.on(\"dragstart\",l),i.on(\"zoomstart\",l),i.on(\"mouseout\",function(){n._fullLayout._hoversubplot=null}),i.on(\"drag\",c),i.on(\"zoom\",c),i.on(\"dblclick\",function(){var t=n._fullLayout[r.id];s.call(\"_storeDirectGUIEdit\",n.layout,n._fullLayout._preGUI,r.getViewEdits(t));var e=r.viewInitial;i.setCenter(x(e.center)),i.setZoom(e.zoom),i.setBearing(e.bearing),i.setPitch(e.pitch);var a=r.getView();t._input.center=t.center=a.center,t._input.zoom=t.zoom=a.zoom,t._input.bearing=t.bearing=a.bearing,t._input.pitch=t.pitch=a.pitch,n.emit(\"plotly_doubleclick\",null),n.emit(\"plotly_relayout\",r.getViewEdits(a))}),r.clearSelect=function(){n._fullLayout._zoomlayer.selectAll(\".select-outline\").remove()},r.onClickInPanFn=function(t){return function(e){var i=n._fullLayout.clickmode;i.indexOf(\"select\")>-1&&h(e.originalEvent,n,[r.xaxis],[r.yaxis],r.id,t),i.indexOf(\"event\")>-1&&a.click(n,e.originalEvent)}}},g.updateFx=function(t){var e=this,r=e.map,n=e.gd;if(!e.isStatic){var i,a=t.dragmode;i=\"select\"===a?function(t,r){(t.range={})[e.id]=[l([r.xmin,r.ymin]),l([r.xmax,r.ymax])]}:function(t,r,n){(t.lassoPoints={})[e.id]=n.filtered.map(l)};var s=e.dragOptions;e.dragOptions=o.extendDeep(s||{},{element:e.div,gd:n,plotinfo:{id:e.id,xaxis:e.xaxis,yaxis:e.yaxis,fillRangeItems:i},xaxes:[e.xaxis],yaxes:[e.yaxis],subplot:e.id}),r.off(\"click\",e.onClickInPanHandler),\"select\"===a||\"lasso\"===a?(r.dragPan.disable(),r.on(\"zoomstart\",e.clearSelect),e.dragOptions.prepFn=function(t,r,n){u(t,r,n,e.dragOptions,a)},c.init(e.dragOptions)):(r.dragPan.enable(),r.off(\"zoomstart\",e.clearSelect),e.div.onmousedown=null,e.onClickInPanHandler=e.onClickInPanFn(e.dragOptions),r.on(\"click\",e.onClickInPanHandler))}function l(t){var r=e.map.unproject(t);return[r.lng,r.lat]}},g.updateFramework=function(t){var e=t[this.id].domain,r=t._size,n=this.div.style;n.width=r.w*(e.x[1]-e.x[0])+\"px\",n.height=r.h*(e.y[1]-e.y[0])+\"px\",n.left=r.l+e.x[0]*r.w+\"px\",n.top=r.t+(1-e.y[1])*r.h+\"px\",this.xaxis._offset=r.l+e.x[0]*r.w,this.xaxis._length=r.w*(e.x[1]-e.x[0]),this.yaxis._offset=r.t+(1-e.y[1])*r.h,this.yaxis._length=r.h*(e.y[1]-e.y[0])},g.updateLayers=function(t){var e,r=t[this.id].layers,n=this.layerList;if(r.length!==n.length){for(e=0;e<n.length;e++)n[e].dispose();for(n=this.layerList=[],e=0;e<r.length;e++)n.push(p(this,e,r[e]))}else for(e=0;e<r.length;e++)n[e].update(r[e])},g.destroy=function(){this.map&&(this.map.remove(),this.map=null,this.container.removeChild(this.div))},g.toImage=function(){return this.map.stop(),this.map.getCanvas().toDataURL()},g.setOptions=function(t,e,r){for(var n in r)this.map[e](t,n,r[n])},g.getMapLayers=function(){return this.map.getStyle().layers},g.addLayer=function(t,e){var r=this.map;if(\"string\"==typeof e){if(\"\"===e)return void r.addLayer(t,e);for(var n=this.getMapLayers(),i=0;i<n.length;i++)if(e===n[i].id)return void r.addLayer(t,e);o.warn([\"Trying to add layer with *below* value\",e,\"referencing a layer that does not exist\",\"or that does not yet exist.\"].join(\" \"))}r.addLayer(t)},g.project=function(t){return this.map.project(new n.LngLat(t[0],t[1]))},g.getView=function(){var t=this.map,e=t.getCenter();return{center:{lon:e.lng,lat:e.lat},zoom:t.getZoom(),bearing:t.getBearing(),pitch:t.getPitch()}},g.getViewEdits=function(t){for(var e=this.id,r=[\"center\",\"zoom\",\"bearing\",\"pitch\"],n={},i=0;i<r.length;i++){var a=r[i];n[e+\".\"+a]=t[a]}return n},e.exports=d},{\"../../components/dragelement\":611,\"../../components/fx\":632,\"../../lib\":719,\"../../registry\":847,\"../cartesian/axes\":767,\"../cartesian/select\":784,\"./constants\":820,\"./layers\":823,d3:163,\"mapbox-gl\":426}],827:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType;return{t:{valType:\"number\",dflt:0,editType:e},r:{valType:\"number\",dflt:0,editType:e},b:{valType:\"number\",dflt:0,editType:e},l:{valType:\"number\",dflt:0,editType:e},editType:e}}},{}],828:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../registry\"),o=t(\"../plot_api/plot_schema\"),s=t(\"../plot_api/plot_template\"),l=t(\"../lib\"),c=t(\"../components/color\"),u=t(\"../constants/numerical\").BADNUM,h=t(\"./cartesian/axis_ids\"),f=t(\"./animation_attributes\"),p=t(\"./frame_attributes\"),d=l.relinkPrivateKeys,g=l._,v=e.exports={};l.extendFlat(v,a),v.attributes=t(\"./attributes\"),v.attributes.type.values=v.allTypes,v.fontAttrs=t(\"./font_attributes\"),v.layoutAttributes=t(\"./layout_attributes\"),v.fontWeight=\"normal\";var m=v.transformsRegistry,y=t(\"./command\");v.executeAPICommand=y.executeAPICommand,v.computeAPICommandBindings=y.computeAPICommandBindings,v.manageCommandObserver=y.manageCommandObserver,v.hasSimpleAPICommandBindings=y.hasSimpleAPICommandBindings,v.redrawText=function(t){var e=(t=l.getGraphDiv(t))._fullLayout||{};if(!(!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r))return new Promise(function(e){setTimeout(function(){a.getComponentMethod(\"annotations\",\"draw\")(t),a.getComponentMethod(\"legend\",\"draw\")(t),a.getComponentMethod(\"colorbar\",\"draw\")(t),e(v.previousPromises(t))},300)})},v.resize=function(t){return t=l.getGraphDiv(t),new Promise(function(e,r){t&&!l.isHidden(t)||r(new Error(\"Resize must be passed a displayed plot div element.\")),t._redrawTimer&&clearTimeout(t._redrawTimer),t._redrawTimer=setTimeout(function(){if(!t.layout||t.layout.width&&t.layout.height||l.isHidden(t))e(t);else{delete t.layout.width,delete t.layout.height;var r=t.changed;t.autoplay=!0,a.call(\"relayout\",t,{autosize:!0}).then(function(){t.changed=r,e(t)})}},100)})},v.previousPromises=function(t){if((t._promises||[]).length)return Promise.all(t._promises).then(function(){t._promises=[]})},v.addLinks=function(t){if(t._context.showLink||t._context.showSources){var e=t._fullLayout,r=l.ensureSingle(e._paper,\"text\",\"js-plot-link-container\",function(t){t.style({\"font-family\":'\"Open Sans\", Arial, sans-serif',\"font-size\":\"12px\",fill:c.defaultLine,\"pointer-events\":\"all\"}).each(function(){var t=n.select(this);t.append(\"tspan\").classed(\"js-link-to-tool\",!0),t.append(\"tspan\").classed(\"js-link-spacer\",!0),t.append(\"tspan\").classed(\"js-sourcelinks\",!0)})}),i=r.node(),a={y:e._paper.attr(\"height\")-9};document.body.contains(i)&&i.getComputedTextLength()>=e.width-20?(a[\"text-anchor\"]=\"start\",a.x=5):(a[\"text-anchor\"]=\"end\",a.x=e._paper.attr(\"width\")-7),r.attr(a);var o=r.select(\".js-link-to-tool\"),s=r.select(\".js-link-spacer\"),u=r.select(\".js-sourcelinks\");t._context.showSources&&t._context.showSources(t),t._context.showLink&&function(t,e){e.text(\"\");var r=e.append(\"a\").attr({\"xlink:xlink:href\":\"#\",class:\"link--impt link--embedview\",\"font-weight\":\"bold\"}).text(t._context.linkText+\" \"+String.fromCharCode(187));if(t._context.sendData)r.on(\"click\",function(){v.sendDataToCloud(t)});else{var n=window.location.pathname.split(\"/\"),i=window.location.search;r.attr({\"xlink:xlink:show\":\"new\",\"xlink:xlink:href\":\"/\"+n[2].split(\".\")[0]+\"/\"+n[1]+i})}}(t,o),s.text(o.text()&&u.text()?\" - \":\"\")}},v.sendDataToCloud=function(t){t.emit(\"plotly_beforeexport\");var e=(window.PLOTLYENV||{}).BASE_URL||t._context.plotlyServerURL,r=n.select(t).append(\"div\").attr(\"id\",\"hiddenform\").style(\"display\",\"none\"),i=r.append(\"form\").attr({action:e+\"/external\",method:\"post\",target:\"_blank\"});return i.append(\"input\").attr({type:\"text\",name:\"data\"}).node().value=v.graphJson(t,!1,\"keepdata\"),i.node().submit(),r.remove(),t.emit(\"plotly_afterexport\"),!1};var x=[\"days\",\"shortDays\",\"months\",\"shortMonths\",\"periods\",\"dateTime\",\"date\",\"time\",\"decimal\",\"thousands\",\"grouping\",\"currency\"],b=[\"year\",\"month\",\"dayMonth\",\"dayMonthYear\"];function _(t,e){var r=t._context.locale,n=!1,i={};function o(t){for(var r=!0,a=0;a<e.length;a++){var o=e[a];i[o]||(t[o]?i[o]=t[o]:r=!1)}r&&(n=!0)}for(var s=0;s<2;s++){for(var l=t._context.locales,c=0;c<2;c++){var u=(l[r]||{}).format;if(u&&(o(u),n))break;l=a.localeRegistry}var h=r.split(\"-\")[0];if(n||h===r)break;r=h}return n||o(a.localeRegistry.en.format),i}function w(t,e){var r={_fullLayout:e},n=\"x\"===t._id.charAt(0),i=t._mainAxis._anchorAxis,a=\"\",o=\"\",s=\"\";if(i&&(s=i._mainAxis._id,a=n?t._id+s:s+t._id),!a||!e._plots[a]){a=\"\";for(var l=t._counterAxes,c=0;c<l.length;c++){var u=l[c],f=n?t._id+u:u+t._id;o||(o=f);var p=h.getFromId(r,u);if(s&&p.overlaying===s){a=f;break}}}return a||o}function k(t){var e=t.transforms;if(Array.isArray(e)&&e.length)for(var r=0;r<e.length;r++){var n=e[r],i=n._module||m[n.type];if(i&&i.makesData)return!0}return!1}function T(t,e,r,n){for(var i=t.transforms,a=[t],o=0;o<i.length;o++){var s=i[o],l=m[s.type];l&&l.transform&&(a=l.transform(a,{transform:s,fullTrace:t,fullData:e,layout:r,fullLayout:n,transformIndex:o}))}return a}function A(t){var e=t.margin;if(!t._size){var r=t._size={l:Math.round(e.l),r:Math.round(e.r),t:Math.round(e.t),b:Math.round(e.b),p:Math.round(e.pad)};r.w=Math.round(t.width)-r.l-r.r,r.h=Math.round(t.height)-r.t-r.b}t._pushmargin||(t._pushmargin={}),t._pushmarginIds||(t._pushmarginIds={})}v.supplyDefaults=function(t,e){var r=e&&e.skipUpdateCalc,i=t._fullLayout||{};if(i._skipDefaults)delete i._skipDefaults;else{var o,s=t._fullLayout={},c=t.layout||{},u=t._fullData||[],h=t._fullData=[],f=t.data||[],p=t.calcdata||[],m=t._context||{};t._transitionData||v.createTransitionData(t),s._dfltTitle={plot:g(t,\"Click to enter Plot title\"),x:g(t,\"Click to enter X axis title\"),y:g(t,\"Click to enter Y axis title\"),colorbar:g(t,\"Click to enter Colorscale title\"),annotation:g(t,\"new text\")},s._traceWord=g(t,\"trace\");var y=_(t,x);if(s._mapboxAccessToken=m.mapboxAccessToken,i._initialAutoSizeIsDone){var w=i.width,k=i.height;v.supplyLayoutGlobalDefaults(c,s,y),c.width||(s.width=w),c.height||(s.height=k),v.sanitizeMargins(s)}else{v.supplyLayoutGlobalDefaults(c,s,y);var T=!c.width||!c.height,M=s.autosize,S=m.autosizable;T&&(M||S)?v.plotAutoSize(t,c,s):T&&v.sanitizeMargins(s),!M&&T&&(c.width=s.width,c.height=s.height)}s._d3locale=function(t,e){return t.decimal=e.charAt(0),t.thousands=e.charAt(1),n.locale(t)}(y,s.separators),s._extraFormat=_(t,b),s._initialAutoSizeIsDone=!0,s._dataLength=f.length,s._modules=[],s._visibleModules=[],s._basePlotModules=[];var E=s._subplots=function(){var t,e,r=a.collectableSubplotTypes,n={};if(!r){r=[];var i=a.subplotsRegistry;for(var o in i){var s=i[o],c=s.attr;if(c&&(r.push(o),Array.isArray(c)))for(e=0;e<c.length;e++)l.pushUnique(r,c[e])}}for(t=0;t<r.length;t++)n[r[t]]=[];return n}(),C=s._splomAxes={x:{},y:{}},L=s._splomSubplots={};s._splomGridDflt={},s._scatterStackOpts={},s._firstScatter={},s._alignmentOpts={},s._colorAxes={},s._requestRangeslider={},s._traceUids=function(t,e){var r,n,i=e.length,a=[];for(r=0;r<t.length;r++){var o=t[r]._fullInput;o!==n&&a.push(o),n=o}var s=a.length,c=new Array(i),u={};function h(t,e){c[e]=t,u[t]=1}function f(t,e){if(t&&\"string\"==typeof t&&!u[t])return h(t,e),!0}for(r=0;r<i;r++){var p=e[r].uid;\"number\"==typeof p&&(p=String(p)),f(p,r)||(r<s&&f(a[r].uid,r)||h(l.randstr(u),r))}return c}(u,f),s._globalTransforms=(t._context||{}).globalTransforms,v.supplyDataDefaults(f,h,c,s);var P=Object.keys(C.x),O=Object.keys(C.y);if(P.length>1&&O.length>1){for(a.getComponentMethod(\"grid\",\"sizeDefaults\")(c,s),o=0;o<P.length;o++)l.pushUnique(E.xaxis,P[o]);for(o=0;o<O.length;o++)l.pushUnique(E.yaxis,O[o]);for(var z in L)l.pushUnique(E.cartesian,z)}if(s._has=v._hasPlotType.bind(s),u.length===h.length)for(o=0;o<h.length;o++)d(h[o],u[o]);v.supplyLayoutModuleDefaults(c,s,h,t._transitionData);var I=s._visibleModules,D=[];for(o=0;o<I.length;o++){var R=I[o].crossTraceDefaults;R&&l.pushUnique(D,R)}for(o=0;o<D.length;o++)D[o](h,s);s._hasOnlyLargeSploms=1===s._basePlotModules.length&&\"splom\"===s._basePlotModules[0].name&&P.length>15&&O.length>15&&0===s.shapes.length&&0===s.images.length,s._hasCartesian=s._has(\"cartesian\"),s._hasGeo=s._has(\"geo\"),s._hasGL3D=s._has(\"gl3d\"),s._hasGL2D=s._has(\"gl2d\"),s._hasTernary=s._has(\"ternary\"),s._hasPie=s._has(\"pie\"),v.linkSubplots(h,s,u,i),v.cleanPlot(h,s,u,i),i._zoomlayer&&!t._dragging&&i._zoomlayer.selectAll(\".select-outline\").remove(),function(t,e){var r,n=[];e.meta&&(r=e._meta={meta:e.meta,layout:{meta:e.meta}});for(var i=0;i<t.length;i++){var a=t[i];a.meta?n[a.index]=a._meta={meta:a.meta}:e.meta&&(a._meta={meta:e.meta}),e.meta&&(a._meta.layout={meta:e.meta})}n.length&&(r||(r=e._meta={}),r.data=n)}(h,s),d(s,i),a.getComponentMethod(\"colorscale\",\"crossTraceDefaults\")(h,s),s._preGUI||(s._preGUI={}),s._tracePreGUI||(s._tracePreGUI={});var F,B=s._tracePreGUI,N={};for(F in B)N[F]=\"old\";for(o=0;o<h.length;o++)N[F=h[o]._fullInput.uid]||(B[F]={}),N[F]=\"new\";for(F in N)\"old\"===N[F]&&delete B[F];A(s),a.getComponentMethod(\"rangeslider\",\"makeData\")(s),r||p.length!==h.length||v.supplyDefaultsUpdateCalc(p,h)}},v.supplyDefaultsUpdateCalc=function(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=(t[r]||[])[0];if(i&&i.trace){var a=i.trace;if(a._hasCalcTransform){var o,s,c,u=a._arrayAttrs;for(o=0;o<u.length;o++)s=u[o],c=l.nestedProperty(a,s).get().slice(),l.nestedProperty(n,s).set(c)}i.trace=n}}},v.createTransitionData=function(t){t._transitionData||(t._transitionData={}),t._transitionData._frames||(t._transitionData._frames=[]),t._transitionData._frameHash||(t._transitionData._frameHash={}),t._transitionData._counter||(t._transitionData._counter=0),t._transitionData._interruptCallbacks||(t._transitionData._interruptCallbacks=[])},v._hasPlotType=function(t){var e,r=this._basePlotModules||[];for(e=0;e<r.length;e++)if(r[e].name===t)return!0;var n=this._modules||[];for(e=0;e<n.length;e++){var i=n[e].name;if(i===t)return!0;var o=a.modules[i];if(o&&o.categories[t])return!0}return!1},v.cleanPlot=function(t,e,r,n){var i,a,o=n._basePlotModules||[];for(i=0;i<o.length;i++){var s=o[i];s.clean&&s.clean(t,e,r,n)}var l=n._has&&n._has(\"gl\"),c=e._has&&e._has(\"gl\");l&&!c&&void 0!==n._glcontainer&&(n._glcontainer.selectAll(\".gl-canvas\").remove(),n._glcontainer.selectAll(\".no-webgl\").remove(),n._glcanvas=null);var u=!!n._infolayer;t:for(i=0;i<r.length;i++){var h=r[i].uid;for(a=0;a<t.length;a++){if(h===t[a].uid)continue t}u&&n._infolayer.select(\".cb\"+h).remove()}},v.linkSubplots=function(t,e,r,n){var i,a,o=n._plots||{},s=e._plots={},c=e._subplots,u={_fullData:t,_fullLayout:e},f=c.cartesian.concat(c.gl2d||[]);for(i=0;i<f.length;i++){var p,d=f[i],g=o[d],v=h.getFromId(u,d,\"x\"),m=h.getFromId(u,d,\"y\");for(g?p=s[d]=g:(p=s[d]={}).id=d,v._counterAxes.push(m._id),m._counterAxes.push(v._id),v._subplotsWith.push(d),m._subplotsWith.push(d),p.xaxis=v,p.yaxis=m,p._hasClipOnAxisFalse=!1,a=0;a<t.length;a++){var y=t[a];if(y.xaxis===p.xaxis._id&&y.yaxis===p.yaxis._id&&!1===y.cliponaxis){p._hasClipOnAxisFalse=!0;break}}}var x,b=h.list(u,null,!0);for(i=0;i<b.length;i++){var _=null;(x=b[i]).overlaying&&(_=h.getFromId(u,x.overlaying))&&_.overlaying&&(x.overlaying=!1,_=null),x._mainAxis=_||x,_&&(x.domain=_.domain.slice()),x._anchorAxis=\"free\"===x.anchor?null:h.getFromId(u,x.anchor)}for(i=0;i<b.length;i++)(x=b[i])._counterAxes.sort(h.idSort),x._subplotsWith.sort(l.subplotSort),x._mainSubplot=w(x,e)},v.clearExpandedTraceDefaultColors=function(t){var e,r,n;for(r=[],(e=t._module._colorAttrs)||(t._module._colorAttrs=e=[],o.crawl(t._module.attributes,function(t,n,i,a){r[a]=n,r.length=a+1,\"color\"===t.valType&&void 0===t.dflt&&e.push(r.join(\".\"))})),n=0;n<e.length;n++){l.nestedProperty(t,\"_input.\"+e[n]).get()||l.nestedProperty(t,e[n]).set(null)}},v.supplyDataDefaults=function(t,e,r,n){var i,o,c,u=n._modules,h=n._visibleModules,f=n._basePlotModules,p=0,g=0;function m(t){e.push(t);var r=t._module;r&&(l.pushUnique(u,r),!0===t.visible&&l.pushUnique(h,r),l.pushUnique(f,t._module.basePlotModule),p++,!1!==t._input.visible&&g++)}n._transformModules=[];var y={},x=[],b=(r.template||{}).data||{},_=s.traceTemplater(b);for(i=0;i<t.length;i++){if(c=t[i],(o=_.newTrace(c)).uid=n._traceUids[i],v.supplyTraceDefaults(c,o,g,n,i),o.index=i,o._input=c,o._expandedIndex=p,o.transforms&&o.transforms.length)for(var w=!1!==c.visible&&!1===o.visible,k=T(o,e,r,n),A=0;A<k.length;A++){var M=k[A],S={_template:o._template,type:o.type,uid:o.uid+A};w&&!1===M.visible&&delete M.visible,v.supplyTraceDefaults(M,S,p,n,i),d(S,M),S.index=i,S._input=c,S._fullInput=o,S._expandedIndex=p,S._expandedInput=M,m(S)}else o._fullInput=o,o._expandedInput=o,m(o);a.traceIs(o,\"carpetAxis\")&&(y[o.carpet]=o),a.traceIs(o,\"carpetDependent\")&&x.push(i)}for(i=0;i<x.length;i++)if((o=e[x[i]]).visible){var E=y[o.carpet];o._carpet=E,E&&E.visible?(o.xaxis=E.xaxis,o.yaxis=E.yaxis):o.visible=!1}},v.supplyAnimationDefaults=function(t){var e;t=t||{};var r={};function n(e,n){return l.coerce(t||{},r,f,e,n)}if(n(\"mode\"),n(\"direction\"),n(\"fromcurrent\"),Array.isArray(t.frame))for(r.frame=[],e=0;e<t.frame.length;e++)r.frame[e]=v.supplyAnimationFrameDefaults(t.frame[e]||{});else r.frame=v.supplyAnimationFrameDefaults(t.frame||{});if(Array.isArray(t.transition))for(r.transition=[],e=0;e<t.transition.length;e++)r.transition[e]=v.supplyAnimationTransitionDefaults(t.transition[e]||{});else r.transition=v.supplyAnimationTransitionDefaults(t.transition||{});return r},v.supplyAnimationFrameDefaults=function(t){var e={};function r(r,n){return l.coerce(t||{},e,f.frame,r,n)}return r(\"duration\"),r(\"redraw\"),e},v.supplyAnimationTransitionDefaults=function(t){var e={};function r(r,n){return l.coerce(t||{},e,f.transition,r,n)}return r(\"duration\"),r(\"easing\"),e},v.supplyFrameDefaults=function(t){var e={};function r(r,n){return l.coerce(t,e,p,r,n)}return r(\"group\"),r(\"name\"),r(\"traces\"),r(\"baseframe\"),r(\"data\"),r(\"layout\"),e},v.supplyTraceDefaults=function(t,e,r,n,i){var o,s=n.colorway||c.defaults,u=s[r%s.length];function h(r,n){return l.coerce(t,e,v.attributes,r,n)}var f=h(\"visible\");h(\"type\"),h(\"name\",n._traceWord+\" \"+i),h(\"uirevision\",n.uirevision);var p=v.getModule(e);if(e._module=p,p){var d=p.basePlotModule,g=d.attr,m=d.attributes;if(g&&m){var y=n._subplots,x=\"\";if(\"gl2d\"!==d.name||f){if(Array.isArray(g))for(o=0;o<g.length;o++){var b=g[o],_=l.coerce(t,e,m,b);y[b]&&l.pushUnique(y[b],_),x+=_}else x=l.coerce(t,e,m,g);y[d.name]&&l.pushUnique(y[d.name],x)}}}return f&&(h(\"customdata\"),h(\"ids\"),h(\"meta\"),a.traceIs(e,\"showLegend\")?(e._dfltShowLegend=!0,h(\"showlegend\"),h(\"legendgroup\")):e._dfltShowLegend=!1,p&&p.supplyDefaults(t,e,u,n),a.traceIs(e,\"noOpacity\")||h(\"opacity\"),a.traceIs(e,\"notLegendIsolatable\")&&(e.visible=!!e.visible),a.traceIs(e,\"noHover\")||(e.hovertemplate||l.coerceHoverinfo(t,e,n),\"parcats\"!==e.type&&a.getComponentMethod(\"fx\",\"supplyDefaults\")(t,e,u,n)),p&&p.selectPoints&&h(\"selectedpoints\"),v.supplyTransformDefaults(t,e,n)),e},v.hasMakesDataTransform=k,v.supplyTransformDefaults=function(t,e,r){if(e._length||k(t)){var n=r._globalTransforms||[],i=r._transformModules||[];if(Array.isArray(t.transforms)||0!==n.length)for(var a=t.transforms||[],o=n.concat(a),s=e.transforms=[],c=0;c<o.length;c++){var u,h=o[c],f=h.type,p=m[f],d=!(h._module&&h._module===p),g=p&&\"function\"==typeof p.transform;p||l.warn(\"Unrecognized transform type \"+f+\".\"),p&&p.supplyDefaults&&(d||g)?((u=p.supplyDefaults(h,e,r,t)).type=f,u._module=p,l.pushUnique(i,p)):u=l.extendFlat({},h),s.push(u)}}},v.supplyLayoutGlobalDefaults=function(t,e,r){function n(r,n){return l.coerce(t,e,v.layoutAttributes,r,n)}var i=t.template;l.isPlainObject(i)&&(e.template=i,e._template=i.layout,e._dataTemplate=i.data);var o=l.coerceFont(n,\"font\");n(\"title.text\",e._dfltTitle.plot),l.coerceFont(n,\"title.font\",{family:o.family,size:Math.round(1.4*o.size),color:o.color}),n(\"title.xref\"),n(\"title.yref\"),n(\"title.x\"),n(\"title.y\"),n(\"title.xanchor\"),n(\"title.yanchor\"),n(\"title.pad.t\"),n(\"title.pad.r\"),n(\"title.pad.b\"),n(\"title.pad.l\"),n(\"autosize\",!(t.width&&t.height)),n(\"width\"),n(\"height\"),n(\"margin.l\"),n(\"margin.r\"),n(\"margin.t\"),n(\"margin.b\"),n(\"margin.pad\"),n(\"margin.autoexpand\"),t.width&&t.height&&v.sanitizeMargins(e),a.getComponentMethod(\"grid\",\"sizeDefaults\")(t,e),n(\"paper_bgcolor\"),n(\"separators\",r.decimal+r.thousands),n(\"hidesources\"),n(\"colorway\"),n(\"datarevision\");var s=n(\"uirevision\");n(\"editrevision\",s),n(\"selectionrevision\",s),n(\"modebar.orientation\"),n(\"modebar.bgcolor\",c.addOpacity(e.paper_bgcolor,.5));var u=c.contrast(c.rgb(e.modebar.bgcolor));n(\"modebar.color\",c.addOpacity(u,.3)),n(\"modebar.activecolor\",c.addOpacity(u,.7)),n(\"modebar.uirevision\",s),n(\"meta\"),l.isPlainObject(t.transition)&&(n(\"transition.duration\"),n(\"transition.easing\"),n(\"transition.ordering\")),a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\"),a.getComponentMethod(\"fx\",\"supplyLayoutGlobalDefaults\")(t,e,n)},v.plotAutoSize=function(t,e,r){var n,a,o=t._context||{},s=o.frameMargins,c=l.isPlotDiv(t);if(c&&t.emit(\"plotly_autosize\"),o.fillFrame)n=window.innerWidth,a=window.innerHeight,document.body.style.overflow=\"hidden\";else{var u=c?window.getComputedStyle(t):{};if(n=parseFloat(u.width)||parseFloat(u.maxWidth)||r.width,a=parseFloat(u.height)||parseFloat(u.maxHeight)||r.height,i(s)&&s>0){var h=1-2*s;n=Math.round(h*n),a=Math.round(h*a)}}var f=v.layoutAttributes.width.min,p=v.layoutAttributes.height.min;n<f&&(n=f),a<p&&(a=p);var d=!e.width&&Math.abs(r.width-n)>1,g=!e.height&&Math.abs(r.height-a)>1;(g||d)&&(d&&(r.width=n),g&&(r.height=a)),t._initialAutoSize||(t._initialAutoSize={width:n,height:a}),v.sanitizeMargins(r)},v.supplyLayoutModuleDefaults=function(t,e,r,n){var i,o,s,c=a.componentsRegistry,u=e._basePlotModules,h=a.subplotsRegistry.cartesian;for(i in c)(s=c[i]).includeBasePlot&&s.includeBasePlot(t,e);for(var f in u.length||u.push(h),e._has(\"cartesian\")&&(a.getComponentMethod(\"grid\",\"contentDefaults\")(t,e),h.finalizeSubplots(t,e)),e._subplots)e._subplots[f].sort(l.subplotSort);for(o=0;o<u.length;o++)(s=u[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var p=e._modules;for(o=0;o<p.length;o++)(s=p[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var d=e._transformModules;for(o=0;o<d.length;o++)(s=d[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r,n);for(i in c)(s=c[i]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r)},v.purge=function(t){var e=t._fullLayout||{};void 0!==e._glcontainer&&(e._glcontainer.selectAll(\".gl-canvas\").remove(),e._glcontainer.remove(),e._glcanvas=null),void 0!==e._geocontainer&&e._geocontainer.remove(),e._modeBar&&e._modeBar.destroy(),t._transitionData&&(t._transitionData._interruptCallbacks&&(t._transitionData._interruptCallbacks.length=0),t._transitionData._animationRaf&&window.cancelAnimationFrame(t._transitionData._animationRaf)),l.clearThrottle(),l.clearResponsive(t),delete t.data,delete t.layout,delete t._fullData,delete t._fullLayout,delete t.calcdata,delete t.framework,delete t.empty,delete t.fid,delete t.undoqueue,delete t.undonum,delete t.autoplay,delete t.changed,delete t._promises,delete t._redrawTimer,delete t._hmlumcount,delete t._hmpixcount,delete t._transitionData,delete t._transitioning,delete t._initialAutoSize,delete t._transitioningWithDuration,delete t._dragging,delete t._dragged,delete t._dragdata,delete t._hoverdata,delete t._snapshotInProgress,delete t._editing,delete t._mouseDownTime,delete t._legendMouseDownTime,t.removeAllListeners&&t.removeAllListeners()},v.style=function(t){var e,r=t._fullLayout._visibleModules,n=[];for(e=0;e<r.length;e++){var i=r[e];i.style&&l.pushUnique(n,i.style)}for(e=0;e<n.length;e++)n[e](t)},v.sanitizeMargins=function(t){if(t&&t.margin){var e,r=t.width,n=t.height,i=t.margin,a=r-(i.l+i.r),o=n-(i.t+i.b);a<0&&(e=(r-1)/(i.l+i.r),i.l=Math.floor(e*i.l),i.r=Math.floor(e*i.r)),o<0&&(e=(n-1)/(i.t+i.b),i.t=Math.floor(e*i.t),i.b=Math.floor(e*i.b))}},v.clearAutoMarginIds=function(t){t._fullLayout._pushmarginIds={}},v.allowAutoMargin=function(t,e){t._fullLayout._pushmarginIds[e]=1},v.autoMargin=function(t,e,r){var n=t._fullLayout,i=n._pushmargin,a=n._pushmarginIds;if(!1!==n.margin.autoexpand){if(r){var o=r.pad;if(void 0===o){var s=n.margin;o=Math.min(12,s.l,s.r,s.t,s.b)}r.l+r.r>.5*n.width&&(r.l=r.r=0),r.b+r.t>.5*n.height&&(r.b=r.t=0);var l=void 0!==r.xl?r.xl:r.x,c=void 0!==r.xr?r.xr:r.x,u=void 0!==r.yt?r.yt:r.y,h=void 0!==r.yb?r.yb:r.y;i[e]={l:{val:l,size:r.l+o},r:{val:c,size:r.r+o},b:{val:h,size:r.b+o},t:{val:u,size:r.t+o}},a[e]=1}else delete i[e],delete a[e];n._replotting||v.doAutoMargin(t)}},v.doAutoMargin=function(t){var e=t._fullLayout;e._size||(e._size={}),A(e);var r=e._size,n=e.margin,o=l.extendFlat({},r),s=n.l,c=n.r,u=n.t,h=n.b,f=e.width,p=e.height,d=e._pushmargin,g=e._pushmarginIds;if(!1!==e.margin.autoexpand){for(var m in d)g[m]||delete d[m];for(var y in d.base={l:{val:0,size:s},r:{val:1,size:c},t:{val:1,size:u},b:{val:0,size:h}},d){var x=d[y].l||{},b=d[y].b||{},_=x.val,w=x.size,k=b.val,T=b.size;for(var M in d){if(i(w)&&d[M].r){var S=d[M].r.val,E=d[M].r.size;if(S>_){var C=(w*S+(E-f)*_)/(S-_),L=(E*(1-_)+(w-f)*(1-S))/(S-_);C>=0&&L>=0&&f-(C+L)>0&&C+L>s+c&&(s=C,c=L)}}if(i(T)&&d[M].t){var P=d[M].t.val,O=d[M].t.size;if(P>k){var z=(T*P+(O-p)*k)/(P-k),I=(O*(1-k)+(T-p)*(1-P))/(P-k);z>=0&&I>=0&&p-(I+z)>0&&z+I>h+u&&(h=z,u=I)}}}}}if(r.l=Math.round(s),r.r=Math.round(c),r.t=Math.round(u),r.b=Math.round(h),r.p=Math.round(n.pad),r.w=Math.round(f)-r.l-r.r,r.h=Math.round(p)-r.t-r.b,!e._replotting&&v.didMarginChange(o,r))return\"_redrawFromAutoMarginCount\"in e?e._redrawFromAutoMarginCount++:e._redrawFromAutoMarginCount=1,a.call(\"plot\",t)};var M=[\"l\",\"r\",\"t\",\"b\",\"p\",\"w\",\"h\"];function S(t,e,r){var n=!1;var i=[v.previousPromises,function(){if(t._transitionData)return t._transitioning=!1,function(t){var e=Promise.resolve();if(!t)return e;for(;t.length;)e=e.then(t.shift());return e}(t._transitionData._interruptCallbacks)},r.prepareFn,v.rehover,function(){return t.emit(\"plotly_transitioning\",[]),new Promise(function(i){t._transitioning=!0,e.duration>0&&(t._transitioningWithDuration=!0),t._transitionData._interruptCallbacks.push(function(){n=!0}),r.redraw&&t._transitionData._interruptCallbacks.push(function(){return a.call(\"redraw\",t)}),t._transitionData._interruptCallbacks.push(function(){t.emit(\"plotly_transitioninterrupted\",[])});var o=0,s=0;function l(){return o++,function(){var e;s++,n||s!==o||(e=i,t._transitionData&&(function(t){if(t)for(;t.length;)t.shift()}(t._transitionData._interruptCallbacks),Promise.resolve().then(function(){if(r.redraw)return a.call(\"redraw\",t)}).then(function(){t._transitioning=!1,t._transitioningWithDuration=!1,t.emit(\"plotly_transitioned\",[])}).then(e)))}}r.runFn(l),setTimeout(l())})}],o=l.syncOrAsync(i,t);return o&&o.then||(o=Promise.resolve()),o.then(function(){return t})}v.didMarginChange=function(t,e){for(var r=0;r<M.length;r++){var n=M[r],a=t[n],o=e[n];if(!i(a)||Math.abs(o-a)>1)return!0}return!1},v.graphJson=function(t,e,r,n,i){(i&&e&&!t._fullData||i&&!e&&!t._fullLayout)&&v.supplyDefaults(t);var a=i?t._fullData:t.data,o=i?t._fullLayout:t.layout,s=(t._transitionData||{})._frames;function c(t){if(\"function\"==typeof t)return null;if(l.isPlainObject(t)){var e,n,i={};for(e in t)if(\"function\"!=typeof t[e]&&-1===[\"_\",\"[\"].indexOf(e.charAt(0))){if(\"keepdata\"===r){if(\"src\"===e.substr(e.length-3))continue}else if(\"keepstream\"===r){if(\"string\"==typeof(n=t[e+\"src\"])&&n.indexOf(\":\")>0&&!l.isPlainObject(t.stream))continue}else if(\"keepall\"!==r&&\"string\"==typeof(n=t[e+\"src\"])&&n.indexOf(\":\")>0)continue;i[e]=c(t[e])}return i}return Array.isArray(t)?t.map(c):l.isTypedArray(t)?l.simpleMap(t,l.identity):l.isJSDate(t)?l.ms2DateTimeLocal(+t):t}var u={data:(a||[]).map(function(t){var r=c(t);return e&&delete r.fit,r})};return e||(u.layout=c(o)),t.framework&&t.framework.isPolar&&(u=t.framework.getConfig()),s&&(u.frames=c(s)),\"object\"===n?u:JSON.stringify(u)},v.modifyFrames=function(t,e){var r,n,i,a=t._transitionData._frames,o=t._transitionData._frameHash;for(r=0;r<e.length;r++)switch((n=e[r]).type){case\"replace\":i=n.value;var s=(a[n.index]||{}).name,l=i.name;a[n.index]=o[l]=i,l!==s&&(delete o[s],o[l]=i);break;case\"insert\":o[(i=n.value).name]=i,a.splice(n.index,0,i);break;case\"delete\":delete o[(i=a[n.index]).name],a.splice(n.index,1)}return Promise.resolve()},v.computeFrame=function(t,e){var r,n,i,a,o=t._transitionData._frameHash;if(!e)throw new Error(\"computeFrame must be given a string frame name\");var s=o[e.toString()];if(!s)return!1;for(var l=[s],c=[s.name];s.baseframe&&(s=o[s.baseframe.toString()])&&-1===c.indexOf(s.name);)l.push(s),c.push(s.name);for(var u={};s=l.pop();)if(s.layout&&(u.layout=v.extendLayout(u.layout,s.layout)),s.data){if(u.data||(u.data=[]),!(n=s.traces))for(n=[],r=0;r<s.data.length;r++)n[r]=r;for(u.traces||(u.traces=[]),r=0;r<s.data.length;r++)null!=(i=n[r])&&(-1===(a=u.traces.indexOf(i))&&(a=u.data.length,u.traces[a]=i),u.data[a]=v.extendTrace(u.data[a],s.data[r]))}return u},v.recomputeFrameHash=function(t){for(var e=t._transitionData._frameHash={},r=t._transitionData._frames,n=0;n<r.length;n++){var i=r[n];i&&i.name&&(e[i.name]=i)}},v.extendObjectWithContainers=function(t,e,r){var n,i,a,o,s,c,u,h=l.extendDeepNoArrays({},e||{}),f=l.expandObjectPaths(h),p={};if(r&&r.length)for(a=0;a<r.length;a++)void 0===(i=(n=l.nestedProperty(f,r[a])).get())?l.nestedProperty(p,r[a]).set(null):(n.set(null),l.nestedProperty(p,r[a]).set(i));if(t=l.extendDeepNoArrays(t||{},f),r&&r.length)for(a=0;a<r.length;a++)if(c=l.nestedProperty(p,r[a]).get()){for(u=(s=l.nestedProperty(t,r[a])).get(),Array.isArray(u)||(u=[],s.set(u)),o=0;o<c.length;o++){var d=c[o];u[o]=null===d?null:v.extendObjectWithContainers(u[o],d)}s.set(u)}return t},v.dataArrayContainers=[\"transforms\",\"dimensions\"],v.layoutArrayContainers=a.layoutArrayContainers,v.extendTrace=function(t,e){return v.extendObjectWithContainers(t,e,v.dataArrayContainers)},v.extendLayout=function(t,e){return v.extendObjectWithContainers(t,e,v.layoutArrayContainers)},v.transition=function(t,e,r,n,i,a){var o={redraw:i.redraw},s={},c=[];return o.prepareFn=function(){for(var i=Array.isArray(e)?e.length:0,a=n.slice(0,i),o=0;o<a.length;o++){var u=a[o],h=t._fullData[u]._module;if(h){if(h.animatable){var f=h.basePlotModule.name;s[f]||(s[f]=[]),s[f].push(u)}t.data[a[o]]=v.extendTrace(t.data[a[o]],e[o])}}var p=l.expandObjectPaths(l.extendDeepNoArrays({},r)),d=/^[xy]axis[0-9]*$/;for(var g in p)d.test(g)&&delete p[g].range;v.extendLayout(t.layout,p),delete t.calcdata,v.supplyDefaults(t),v.doCalcdata(t);var m=l.expandObjectPaths(r);if(m){var y=t._fullLayout._plots;for(var x in y){var b,_,w,k,T=y[x],A=T.xaxis,M=T.yaxis,S=A.range.slice(),E=M.range.slice();Array.isArray(m[A._name+\".range\"])?b=m[A._name+\".range\"].slice():Array.isArray((m[A._name]||{}).range)&&(b=m[A._name].range.slice()),Array.isArray(m[M._name+\".range\"])?_=m[M._name+\".range\"].slice():Array.isArray((m[M._name]||{}).range)&&(_=m[M._name].range.slice()),S&&b&&(S[0]!==b[0]||S[1]!==b[1])&&(w={xr0:S,xr1:b}),E&&_&&(E[0]!==_[0]||E[1]!==_[1])&&(k={yr0:E,yr1:_}),(w||k)&&c.push(l.extendFlat({plotinfo:T},w,k))}}return Promise.resolve()},o.runFn=function(e){var n,i,o=t._fullLayout._basePlotModules,u=c.length;if(r)for(i=0;i<o.length;i++)o[i].transitionAxes&&o[i].transitionAxes(t,c,a,e);for(var h in u?((n=l.extendFlat({},a)).duration=0,delete s.cartesian):n=a,s){var f=s[h];t._fullData[f[0]]._module.basePlotModule.plot(t,f,n,e)}},S(t,a,o)},v.transitionFromReact=function(t,e,r,n){var i=t._fullLayout,a=i.transition,o={},s=[];return o.prepareFn=function(){var t=i._plots;for(var a in o.redraw=!1,\"some\"===e.anim&&(o.redraw=!0),\"some\"===r.anim&&(o.redraw=!0),t){var c,u,h=t[a],f=h.xaxis,p=h.yaxis,d=n[f._name].range.slice(),g=n[p._name].range.slice(),v=f.range.slice(),m=p.range.slice();f.setScale(),p.setScale(),d[0]===v[0]&&d[1]===v[1]||(c={xr0:d,xr1:v}),g[0]===m[0]&&g[1]===m[1]||(u={yr0:g,yr1:m}),(c||u)&&s.push(l.extendFlat({plotinfo:h},c,u))}return Promise.resolve()},o.runFn=function(r){for(var n,i,o,c=t._fullData,u=t._fullLayout._basePlotModules,h=[],f=0;f<c.length;f++)h.push(f);function p(){for(var e=0;e<u.length;e++)u[e].transitionAxes&&u[e].transitionAxes(t,s,n,r)}function d(){for(var e=0;e<u.length;e++)u[e].plot(t,o,i,r)}s.length&&e.anim?\"traces first\"===a.ordering?(n=l.extendFlat({},a,{duration:0}),o=h,i=a,d(),setTimeout(p,a.duration)):(n=a,o=null,i=l.extendFlat({},a,{duration:0}),p(),d()):s.length?(n=a,p()):e.anim&&(o=h,i=a,d())},S(t,a,o)},v.doCalcdata=function(t,e){var r,n,i,s,c=h.list(t),f=t._fullData,p=t._fullLayout,d=new Array(f.length),g=(t.calcdata||[]).slice();for(t.calcdata=d,p._numBoxes=0,p._numViolins=0,p._violinScaleGroupStats={},t._hmpixcount=0,t._hmlumcount=0,p._piecolormap={},p._sunburstcolormap={},p._funnelareacolormap={},i=0;i<f.length;i++)Array.isArray(e)&&-1===e.indexOf(i)&&(d[i]=g[i]);for(i=0;i<f.length;i++)(r=f[i])._arrayAttrs=o.findArrayAttributes(r),r._extremes={};var v=p._subplots.polar||[];for(i=0;i<v.length;i++)c.push(p[v[i]].radialaxis,p[v[i]].angularaxis);var y=!1;function x(e){if(r=f[e],n=r._module,!0===r.visible&&r.transforms){if(n&&n.calc){var i=n.calc(t,r);i[0]&&i[0].t&&i[0].t._scene&&delete i[0].t._scene.dirty}for(s=0;s<r.transforms.length;s++){var a=r.transforms[s];(n=m[a.type])&&n.calcTransform&&(r._hasCalcTransform=!0,y=!0,n.calcTransform(t,r,a))}}}function b(e,i){if(r=f[e],!!(n=r._module).isContainer===i){var a=[];if(!0===r.visible&&0!==r._length){delete r._indexToPoints;var o=r.transforms||[];for(s=o.length-1;s>=0;s--)if(o[s].enabled){r._indexToPoints=o[s]._indexToPoints;break}n&&n.calc&&(a=n.calc(t,r))}Array.isArray(a)&&a[0]||(a=[{x:u,y:u}]),a[0].t||(a[0].t={}),a[0].trace=r,d[e]=a}}for(C(c,f),i=0;i<f.length;i++)b(i,!0);for(i=0;i<f.length;i++)x(i);for(y&&C(c,f),i=0;i<f.length;i++)b(i,!0);for(i=0;i<f.length;i++)b(i,!1);L(t);var _=function(t,e){var r,n,i,o,s,c=[];function u(t,r,n){var i=r._id.charAt(0);if(\"histogram2dcontour\"===t){var a=r._counterAxes[0],o=h.getFromId(e,a),s=\"x\"===i||\"x\"===a&&\"category\"===o.type,l=\"y\"===i||\"y\"===a&&\"category\"===o.type;return function(t,e){return 0===t||0===e?-1:s&&t===n[e].length-1?-1:l&&e===n.length-1?-1:(\"y\"===i?e:t)-1}}return function(t,e){return\"y\"===i?e:t}}var f={min:function(t){return l.aggNums(Math.min,null,t)},max:function(t){return l.aggNums(Math.max,null,t)},sum:function(t){return l.aggNums(function(t,e){return t+e},null,t)},total:function(t){return l.aggNums(function(t,e){return t+e},null,t)},mean:function(t){return l.mean(t)},median:function(t){return l.median(t)}};for(r=0;r<t.length;r++){var p=t[r];if(\"category\"===p.type){var d=p.categoryorder.match(E);if(d){var g=d[1],v=d[2],m=[];for(n=0;n<p._categories.length;n++)m.push([p._categories[n],[]]);for(n=0;n<p._traceIndices.length;n++){var y=p._traceIndices[n],x=e._fullData[y],b=p._id.charAt(0);if(!0===x.visible){var _=x.type;a.traceIs(x,\"histogram\")&&(delete x._xautoBinFinished,delete x._yautoBinFinished);var w=e.calcdata[y];for(i=0;i<w.length;i++){var k,T,A,M=w[i];if(\"splom\"===_){var S=x._axesDim[p._id];if(\"y\"===b){var C=x._diag[S][0];C&&(p=e._fullLayout[h.id2name(C)])}var L=M.trace.dimensions[S].values;for(o=0;o<L.length;o++)for(k=L[o],T=p._categoriesMap[k],s=0;s<M.trace.dimensions.length;s++)if(s!==S){var P=M.trace.dimensions[s];m[T][1].push(P.values[o])}}else if(\"scattergl\"===_){for(o=0;o<M.t.x.length;o++)\"x\"===b&&(k=M.t.x[o],T=k,A=M.t.y[o]),\"y\"===b&&(k=M.t.y[o],T=k,A=M.t.x[o]),m[T][1].push(A);M.t&&M.t._scene&&delete M.t._scene.dirty}else if(M.hasOwnProperty(\"z\")){A=M.z;var O=u(x.type,p,A);for(o=0;o<A.length;o++)for(s=0;s<A[o].length;s++)(T=O(s,o))+1&&m[T][1].push(A[o][s])}else for(\"x\"===b?(k=M.p+1?M.p:M.x,A=M.s||M.v||M.y):\"y\"===b&&(k=M.p+1?M.p:M.y,A=M.s||M.v||M.x),Array.isArray(A)||(A=[A]),o=0;o<A.length;o++)m[k][1].push(A[o])}}}p._categoriesValue=m;var z=[];for(n=0;n<m.length;n++)z.push([m[n][0],f[g](m[n][1])]);z.sort(function(t,e){return t[1]-e[1]}),p._categoriesAggregatedValue=z,p._initialCategories=z.map(function(t){return t[0]}),\"descending\"===v&&p._initialCategories.reverse(),c=c.concat(p.sortByInitialCategories())}}}return c}(c,t);if(_.length){for(p._numBoxes=0,p._numViolins=0,i=0;i<_.length;i++)b(_[i],!0);for(i=0;i<_.length;i++)b(_[i],!1);L(t)}a.getComponentMethod(\"fx\",\"calc\")(t),a.getComponentMethod(\"errorbars\",\"calc\")(t)};var E=/(total|sum|min|max|mean|median) (ascending|descending)/;function C(t,e){for(var r=0;r<t.length;r++){var n=t[r];n.clearCalc(),\"multicategory\"===n.type&&n.setupMultiCategory(e)}}function L(t){var e,r,n,i=t._fullLayout,a=i._visibleModules,o={};for(r=0;r<a.length;r++){var s=a[r],c=s.crossTraceCalc;if(c){var u=s.basePlotModule.name;o[u]?l.pushUnique(o[u],c):o[u]=[c]}}for(n in o){var h=o[n],f=i._subplots[n];if(Array.isArray(f))for(e=0;e<f.length;e++){var p=f[e],d=\"cartesian\"===n?i._plots[p]:i[p];for(r=0;r<h.length;r++)h[r](t,d,p)}else for(r=0;r<h.length;r++)h[r](t)}}v.rehover=function(t){t._fullLayout._rehover&&t._fullLayout._rehover()},v.redrag=function(t){t._fullLayout._redrag&&t._fullLayout._redrag()},v.generalUpdatePerTraceModule=function(t,e,r,n){var i,a=e.traceHash,o={};for(i=0;i<r.length;i++){var s=r[i],c=s[0].trace;c.visible&&(o[c.type]=o[c.type]||[],o[c.type].push(s))}for(var u in a)if(!o[u]){var h=a[u][0];h[0].trace.visible=!1,o[u]=[h]}for(var f in o){var p=o[f];p[0][0].trace._module.plot(t,e,l.filterVisible(p),n)}e.traceHash=o}},{\"../components/color\":593,\"../constants/numerical\":695,\"../lib\":719,\"../plot_api/plot_schema\":756,\"../plot_api/plot_template\":757,\"../registry\":847,\"./animation_attributes\":762,\"./attributes\":764,\"./cartesian/axis_ids\":770,\"./command\":791,\"./font_attributes\":793,\"./frame_attributes\":794,\"./layout_attributes\":819,d3:163,\"fast-isnumeric\":225}],829:[function(t,e,r){\"use strict\";e.exports={attr:\"subplot\",name:\"polar\",axisNames:[\"angularaxis\",\"radialaxis\"],axisName2dataArray:{angularaxis:\"theta\",radialaxis:\"r\"},layerNames:[\"draglayer\",\"plotbg\",\"backplot\",\"angular-grid\",\"radial-grid\",\"frontplot\",\"angular-line\",\"radial-line\",\"angular-axis\",\"radial-axis\"],radialDragBoxSize:50,angularDragBoxSize:30,cornerLen:25,cornerHalfWidth:2,MINDRAG:8,MINZOOM:20,OFFEDGE:20}},{}],830:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/polygon\").tester,a=n.findIndexOfMin,o=n.isAngleInsideSector,s=n.angleDelta,l=n.angleDist;function c(t,e,r,n){var i,a,o=n[0],s=n[1],l=h(Math.sin(e)-Math.sin(t)),c=h(Math.cos(e)-Math.cos(t)),u=Math.tan(r),f=h(1/u),p=l/c,d=s-p*o;return f?l&&c?a=u*(i=d/(u-p)):c?(i=s*f,a=s):(i=o,a=o*u):l&&c?(i=0,a=d):c?(i=0,a=s):i=a=NaN,[i,a]}function u(t,e,r,i){return n.isFullCircle([e,r])?function(t,e){var r,n=e.length,i=new Array(n+1);for(r=0;r<n;r++){var a=e[r];i[r]=[t*Math.cos(a),t*Math.sin(a)]}return i[r]=i[0].slice(),i}(t,i):function(t,e,r,i){var s,u,h=i.length,f=[];function p(e){return[t*Math.cos(e),t*Math.sin(e)]}function d(t,e,r){return c(t,e,r,p(t))}function g(t){return n.mod(t,h)}function v(t){return o(t,[e,r])}var m=a(i,function(t){return v(t)?l(t,e):1/0}),y=d(i[m],i[g(m-1)],e);for(f.push(y),s=m,u=0;u<h;s++,u++){var x=i[g(s)];if(!v(x))break;f.push(p(x))}var b=a(i,function(t){return v(t)?l(t,r):1/0}),_=d(i[b],i[g(b+1)],r);return f.push(_),f.push([0,0]),f.push(f[0].slice()),f}(t,e,r,i)}function h(t){return Math.abs(t)>1e-10?t:0}function f(t,e,r){e=e||0,r=r||0;for(var n=t.length,i=new Array(n),a=0;a<n;a++){var o=t[a];i[a]=[e+o[0],r-o[1]]}return i}e.exports={isPtInsidePolygon:function(t,e,r,n,a){if(!o(e,n))return!1;var s,l;r[0]<r[1]?(s=r[0],l=r[1]):(s=r[1],l=r[0]);var c=i(u(s,n[0],n[1],a)),h=i(u(l,n[0],n[1],a)),f=[t*Math.cos(e),t*Math.sin(e)];return h.contains(f)&&!c.contains(f)},findPolygonOffset:function(t,e,r,n){for(var i=1/0,a=1/0,o=u(t,e,r,n),s=0;s<o.length;s++){var l=o[s];i=Math.min(i,l[0]),a=Math.min(a,-l[1])}return[i,a]},findEnclosingVertexAngles:function(t,e){var r=a(e,function(e){var r=s(e,t);return r>0?r:1/0}),i=n.mod(r+1,e.length);return[e[r],e[i]]},findIntersectionXY:c,findXYatLength:function(t,e,r,n){var i=-e*r,a=e*e+1,o=2*(e*i-r),s=i*i+r*r-t*t,l=Math.sqrt(o*o-4*a*s),c=(-o+l)/(2*a),u=(-o-l)/(2*a);return[[c,e*c+i+n],[u,e*u+i+n]]},clampTiny:h,pathPolygon:function(t,e,r,n,i,a){return\"M\"+f(u(t,e,r,n),i,a).join(\"L\")},pathPolygonAnnulus:function(t,e,r,n,i,a,o){var s,l;t<e?(s=t,l=e):(s=e,l=t);var c=f(u(s,r,n,i),a,o);return\"M\"+f(u(l,r,n,i),a,o).reverse().join(\"L\")+\"M\"+c.join(\"L\")}}},{\"../../lib\":719,\"../../lib/polygon\":731}],831:[function(t,e,r){\"use strict\";var n=t(\"../get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./polar\"),o=t(\"./constants\"),s=o.attr,l=o.name,c=i(l),u={};u[s]={valType:\"subplotid\",dflt:l,editType:\"calc\"},e.exports={attr:s,name:l,idRoot:l,idRegex:c,attrRegex:c,attributes:u,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[l],o=0;o<i.length;o++){var s=i[o],c=n(r,l,s),u=e[s]._subplot;u||(u=a(t,s),e[s]._subplot=u),u.plot(c,e,t._promises)}},clean:function(t,e,r,n){for(var i=n._subplots[l]||[],a=n._has&&n._has(\"gl\"),o=e._has&&e._has(\"gl\"),s=a&&!o,c=0;c<i.length;c++){var u=i[c],h=n[u]._subplot;if(!e[u]&&h)for(var f in h.framework.remove(),h.layers[\"radial-axis-title\"].remove(),h.clipPaths)h.clipPaths[f].remove();s&&h._scene&&(h._scene.destroy(),h._scene=null)}},toSVG:t(\"../cartesian\").toSVG}},{\"../../lib\":719,\"../cartesian\":778,\"../get_data\":802,\"./constants\":829,\"./layout_attributes\":832,\"./layout_defaults\":833,\"./polar\":840}],832:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../cartesian/layout_attributes\"),a=t(\"../domain\").attributes,o=t(\"../../lib\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=s({color:i.color,showline:o({},i.showline,{dflt:!0}),linecolor:i.linecolor,linewidth:i.linewidth,showgrid:o({},i.showgrid,{dflt:!0}),gridcolor:i.gridcolor,gridwidth:i.gridwidth},\"plot\",\"from-root\"),c=s({tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,showtickprefix:i.showtickprefix,tickprefix:i.tickprefix,showticksuffix:i.showticksuffix,ticksuffix:i.ticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,separatethousands:i.separatethousands,tickfont:i.tickfont,tickangle:i.tickangle,tickformat:i.tickformat,tickformatstops:i.tickformatstops,layer:i.layer},\"plot\",\"from-root\"),u={visible:o({},i.visible,{dflt:!0}),type:o({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autorange:o({},i.autorange,{editType:\"plot\"}),rangemode:{valType:\"enumerated\",values:[\"tozero\",\"nonnegative\",\"normal\"],dflt:\"tozero\",editType:\"calc\"},range:o({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],editType:\"plot\"}),categoryorder:i.categoryorder,categoryarray:i.categoryarray,angle:{valType:\"angle\",editType:\"plot\"},side:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"clockwise\",editType:\"plot\"},title:s(i.title,\"plot\",\"from-root\"),hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}};u.title.text.dflt=\"\",o(u,l,c);var h={visible:o({},i.visible,{dflt:!0}),type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"category\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},categoryorder:i.categoryorder,categoryarray:i.categoryarray,thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\"],dflt:\"degrees\",editType:\"calc\"},period:{valType:\"number\",editType:\"calc\",min:0},direction:{valType:\"enumerated\",values:[\"counterclockwise\",\"clockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"angle\",editType:\"calc\"},hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"};o(h,l,c),e.exports={domain:a({name:\"polar\",editType:\"plot\"}),sector:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],dflt:[0,360],editType:\"plot\"},hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},bgcolor:{valType:\"color\",editType:\"plot\",dflt:n.background},radialaxis:u,angularaxis:h,gridshape:{valType:\"enumerated\",values:[\"circular\",\"linear\"],dflt:\"circular\",editType:\"plot\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"}},{\"../../components/color/attributes\":592,\"../../lib\":719,\"../../plot_api/edit_types\":750,\"../cartesian/layout_attributes\":779,\"../domain\":792}],833:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../subplot_defaults\"),s=t(\"../get_data\").getSubplotData,l=t(\"../cartesian/tick_value_defaults\"),c=t(\"../cartesian/tick_mark_defaults\"),u=t(\"../cartesian/tick_label_defaults\"),h=t(\"../cartesian/category_order_defaults\"),f=t(\"../cartesian/line_grid_defaults\"),p=t(\"../cartesian/axis_autotype\"),d=t(\"./layout_attributes\"),g=t(\"./set_convert\"),v=t(\"./constants\"),m=v.axisNames;function y(t,e,r,o){var p=r(\"bgcolor\");o.bgColor=i.combine(p,o.paper_bgcolor);var y=r(\"sector\");r(\"hole\");var b,_=s(o.fullData,v.name,o.id),w=o.layoutOut;function k(t,e){return r(b+\".\"+t,e)}for(var T=0;T<m.length;T++){b=m[T],n.isPlainObject(t[b])||(t[b]={});var A=t[b],M=a.newContainer(e,b);M._id=M._name=b,M._attr=o.id+\".\"+b,M._traceIndices=_.map(function(t){return t._expandedIndex});var S=v.axisName2dataArray[b],E=x(A,M,k,_,S);h(A,M,k,{axData:_,dataAttr:S});var C,L,P=k(\"visible\");switch(g(M,e,w),k(\"uirevision\",e.uirevision),P&&(L=(C=k(\"color\"))===A.color?C:o.font.color),M._m=1,b){case\"radialaxis\":var O=k(\"autorange\",!M.isValidRange(A.range));A.autorange=O,!O||\"linear\"!==E&&\"-\"!==E||k(\"rangemode\"),\"reversed\"===O&&(M._m=-1),k(\"range\"),M.cleanRange(\"range\",{dfltRange:[0,1]}),P&&(k(\"side\"),k(\"angle\",y[0]),k(\"title.text\"),n.coerceFont(k,\"title.font\",{family:o.font.family,size:Math.round(1.2*o.font.size),color:L}));break;case\"angularaxis\":if(\"date\"===E){n.log(\"Polar plots do not support date angular axes yet.\");for(var z=0;z<_.length;z++)_[z].visible=!1;E=A.type=M.type=\"linear\"}k(\"linear\"===E?\"thetaunit\":\"period\");var I=k(\"direction\");k(\"rotation\",{counterclockwise:0,clockwise:90}[I])}if(P)l(A,M,k,M.type),u(A,M,k,M.type,{tickSuffixDflt:\"degrees\"===M.thetaunit?\"\\xb0\":void 0}),c(A,M,k,{outerTicks:!0}),k(\"showticklabels\")&&(n.coerceFont(k,\"tickfont\",{family:o.font.family,size:o.font.size,color:L}),k(\"tickangle\"),k(\"tickformat\")),f(A,M,k,{dfltColor:C,bgColor:o.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:d[b]}),k(\"layer\");\"category\"!==E&&k(\"hoverformat\"),M._input=A}\"category\"===e.angularaxis.type&&r(\"gridshape\")}function x(t,e,r,n,i){if(\"-\"===r(\"type\")){for(var a,o=0;o<n.length;o++)if(n[o].visible){a=n[o];break}a&&a[i]&&(e.type=p(a[i],\"gregorian\")),\"-\"===e.type?e.type=\"linear\":t.type=e.type}return e.type}e.exports=function(t,e,r){o(t,e,r,{type:v.name,attributes:d,handleDefaults:y,font:e.font,paper_bgcolor:e.paper_bgcolor,fullData:r,layoutOut:e})}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../cartesian/axis_autotype\":768,\"../cartesian/category_order_defaults\":771,\"../cartesian/line_grid_defaults\":781,\"../cartesian/tick_label_defaults\":786,\"../cartesian/tick_mark_defaults\":787,\"../cartesian/tick_value_defaults\":788,\"../get_data\":802,\"../subplot_defaults\":842,\"./constants\":829,\"./layout_attributes\":832,\"./set_convert\":841}],834:[function(t,e,r){\"use strict\";var n=t(\"../../../traces/scatter/attributes\"),i=n.marker,a=t(\"../../../lib/extend\").extendFlat;[\"Area traces are deprecated!\",\"Please switch to the *barpolar* trace type.\"].join(\" \");e.exports={r:a({},n.r,{}),t:a({},n.t,{}),marker:{color:a({},i.color,{}),size:a({},i.size,{}),symbol:a({},i.symbol,{}),opacity:a({},i.opacity,{}),editType:\"calc\"}}},{\"../../../lib/extend\":710,\"../../../traces/scatter/attributes\":1112}],835:[function(t,e,r){\"use strict\";var n=t(\"../../cartesian/layout_attributes\"),i=t(\"../../../lib/extend\").extendFlat,a=t(\"../../../plot_api/edit_types\").overrideAll,o=[\"Legacy polar charts are deprecated!\",\"Please switch to *polar* subplots.\"].join(\" \"),s=i({},n.domain,{});function l(t,e){return i({},e,{showline:{valType:\"boolean\"},showticklabels:{valType:\"boolean\"},tickorientation:{valType:\"enumerated\",values:[\"horizontal\",\"vertical\"]},ticklen:{valType:\"number\",min:0},tickcolor:{valType:\"color\"},ticksuffix:{valType:\"string\"},endpadding:{valType:\"number\",description:o},visible:{valType:\"boolean\"}})}e.exports=a({radialaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},domain:s,orientation:{valType:\"number\"}}),angularaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\",dflt:0},{valType:\"number\",dflt:360}]},domain:s}),layout:{direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"]},orientation:{valType:\"angle\"}}},\"plot\",\"nested\")},{\"../../../lib/extend\":710,\"../../../plot_api/edit_types\":750,\"../../cartesian/layout_attributes\":779}],836:[function(t,e,r){\"use strict\";(e.exports=t(\"./micropolar\")).manager=t(\"./micropolar_manager\")},{\"./micropolar\":837,\"./micropolar_manager\":838}],837:[function(t,e,r){var n=t(\"d3\"),i=t(\"../../../lib\").extendDeepAll,a=t(\"../../../constants/alignment\").MID_SHIFT,o=e.exports={version:\"0.2.2\"};o.Axis=function(){var t,e,r,s,l={data:[],layout:{}},c={},u={},h=n.dispatch(\"hover\"),f={};return f.render=function(c){return function(c){e=c||e;var h=l.data,f=l.layout;(\"string\"==typeof e||e.nodeName)&&(e=n.select(e)),e.datum(h).each(function(e,l){var c=e.slice();u={data:o.util.cloneJson(c),layout:o.util.cloneJson(f)};var h=0;c.forEach(function(t,e){t.color||(t.color=f.defaultColorRange[h],h=(h+1)%f.defaultColorRange.length),t.strokeColor||(t.strokeColor=\"LinePlot\"===t.geometry?t.color:n.rgb(t.color).darker().toString()),u.data[e].color=t.color,u.data[e].strokeColor=t.strokeColor,u.data[e].strokeDash=t.strokeDash,u.data[e].strokeSize=t.strokeSize});var p=c.filter(function(t,e){var r=t.visible;return\"undefined\"==typeof r||!0===r}),d=!1,g=p.map(function(t,e){return d=d||\"undefined\"!=typeof t.groupId,t});if(d){var v=n.nest().key(function(t,e){return\"undefined\"!=typeof t.groupId?t.groupId:\"unstacked\"}).entries(g),m=[],y=v.map(function(t,e){if(\"unstacked\"===t.key)return t.values;var r=t.values[0].r.map(function(t,e){return 0});return t.values.forEach(function(t,e,n){t.yStack=[r],m.push(r),r=o.util.sumArrays(t.r,r)}),t.values});p=n.merge(y)}p.forEach(function(t,e){t.t=Array.isArray(t.t[0])?t.t:[t.t],t.r=Array.isArray(t.r[0])?t.r:[t.r]});var x=Math.min(f.width-f.margin.left-f.margin.right,f.height-f.margin.top-f.margin.bottom)/2;x=Math.max(10,x);var b,_=[f.margin.left+x,f.margin.top+x];b=d?[0,n.max(o.util.sumArrays(o.util.arrayLast(p).r[0],o.util.arrayLast(m)))]:n.extent(o.util.flattenArray(p.map(function(t,e){return t.r}))),f.radialAxis.domain!=o.DATAEXTENT&&(b[0]=0),r=n.scale.linear().domain(f.radialAxis.domain!=o.DATAEXTENT&&f.radialAxis.domain?f.radialAxis.domain:b).range([0,x]),u.layout.radialAxis.domain=r.domain();var w,k=o.util.flattenArray(p.map(function(t,e){return t.t})),T=\"string\"==typeof k[0];T&&(k=o.util.deduplicate(k),w=k.slice(),k=n.range(k.length),p=p.map(function(t,e){var r=t;return t.t=[k],d&&(r.yStack=t.yStack),r}));var A=p.filter(function(t,e){return\"LinePlot\"===t.geometry||\"DotPlot\"===t.geometry}).length===p.length,M=null===f.needsEndSpacing?T||!A:f.needsEndSpacing,S=f.angularAxis.domain&&f.angularAxis.domain!=o.DATAEXTENT&&!T&&f.angularAxis.domain[0]>=0?f.angularAxis.domain:n.extent(k),E=Math.abs(k[1]-k[0]);A&&!T&&(E=0);var C=S.slice();M&&T&&(C[1]+=E);var L=f.angularAxis.ticksCount||4;L>8&&(L=L/(L/8)+L%8),f.angularAxis.ticksStep&&(L=(C[1]-C[0])/L);var P=f.angularAxis.ticksStep||(C[1]-C[0])/(L*(f.minorTicks+1));w&&(P=Math.max(Math.round(P),1)),C[2]||(C[2]=P);var O=n.range.apply(this,C);if(O=O.map(function(t,e){return parseFloat(t.toPrecision(12))}),s=n.scale.linear().domain(C.slice(0,2)).range(\"clockwise\"===f.direction?[0,360]:[360,0]),u.layout.angularAxis.domain=s.domain(),u.layout.angularAxis.endPadding=M?E:0,\"undefined\"==typeof(t=n.select(this).select(\"svg.chart-root\"))||t.empty()){var z=(new DOMParser).parseFromString(\"<svg xmlns='http://www.w3.org/2000/svg' class='chart-root'>' + '<g class='outer-group'>' + '<g class='chart-group'>' + '<circle class='background-circle'></circle>' + '<g class='geometry-group'></g>' + '<g class='radial axis-group'>' + '<circle class='outside-circle'></circle>' + '</g>' + '<g class='angular axis-group'></g>' + '<g class='guides-group'><line></line><circle r='0'></circle></g>' + '</g>' + '<g class='legend-group'></g>' + '<g class='tooltips-group'></g>' + '<g class='title-group'><text></text></g>' + '</g>' + '</svg>\",\"application/xml\"),I=this.appendChild(this.ownerDocument.importNode(z.documentElement,!0));t=n.select(I)}t.select(\".guides-group\").style({\"pointer-events\":\"none\"}),t.select(\".angular.axis-group\").style({\"pointer-events\":\"none\"}),t.select(\".radial.axis-group\").style({\"pointer-events\":\"none\"});var D,R=t.select(\".chart-group\"),F={fill:\"none\",stroke:f.tickColor},B={\"font-size\":f.font.size,\"font-family\":f.font.family,fill:f.font.color,\"text-shadow\":[\"-1px 0px\",\"1px -1px\",\"-1px 1px\",\"1px 1px\"].map(function(t,e){return\" \"+t+\" 0 \"+f.font.outlineColor}).join(\",\")};if(f.showLegend){D=t.select(\".legend-group\").attr({transform:\"translate(\"+[x,f.margin.top]+\")\"}).style({display:\"block\"});var N=p.map(function(t,e){var r=o.util.cloneJson(t);return r.symbol=\"DotPlot\"===t.geometry?t.dotType||\"circle\":\"LinePlot\"!=t.geometry?\"square\":\"line\",r.visibleInLegend=\"undefined\"==typeof t.visibleInLegend||t.visibleInLegend,r.color=\"LinePlot\"===t.geometry?t.strokeColor:t.color,r});o.Legend().config({data:p.map(function(t,e){return t.name||\"Element\"+e}),legendConfig:i({},o.Legend.defaultConfig().legendConfig,{container:D,elements:N,reverseOrder:f.legend.reverseOrder})})();var j=D.node().getBBox();x=Math.min(f.width-j.width-f.margin.left-f.margin.right,f.height-f.margin.top-f.margin.bottom)/2,x=Math.max(10,x),_=[f.margin.left+x,f.margin.top+x],r.range([0,x]),u.layout.radialAxis.domain=r.domain(),D.attr(\"transform\",\"translate(\"+[_[0]+x,_[1]-x]+\")\")}else D=t.select(\".legend-group\").style({display:\"none\"});t.attr({width:f.width,height:f.height}).style({opacity:f.opacity}),R.attr(\"transform\",\"translate(\"+_+\")\").style({cursor:\"crosshair\"});var U=[(f.width-(f.margin.left+f.margin.right+2*x+(j?j.width:0)))/2,(f.height-(f.margin.top+f.margin.bottom+2*x))/2];if(U[0]=Math.max(0,U[0]),U[1]=Math.max(0,U[1]),t.select(\".outer-group\").attr(\"transform\",\"translate(\"+U+\")\"),f.title&&f.title.text){var V=t.select(\"g.title-group text\").style(B).text(f.title.text),q=V.node().getBBox();V.attr({x:_[0]-q.width/2,y:_[1]-x-20})}var H=t.select(\".radial.axis-group\");if(f.radialAxis.gridLinesVisible){var G=H.selectAll(\"circle.grid-circle\").data(r.ticks(5));G.enter().append(\"circle\").attr({class:\"grid-circle\"}).style(F),G.attr(\"r\",r),G.exit().remove()}H.select(\"circle.outside-circle\").attr({r:x}).style(F);var Y=t.select(\"circle.background-circle\").attr({r:x}).style({fill:f.backgroundColor,stroke:f.stroke});function W(t,e){return s(t)%360+f.orientation}if(f.radialAxis.visible){var X=n.svg.axis().scale(r).ticks(5).tickSize(5);H.call(X).attr({transform:\"rotate(\"+f.radialAxis.orientation+\")\"}),H.selectAll(\".domain\").style(F),H.selectAll(\"g>text\").text(function(t,e){return this.textContent+f.radialAxis.ticksSuffix}).style(B).style({\"text-anchor\":\"start\"}).attr({x:0,y:0,dx:0,dy:0,transform:function(t,e){return\"horizontal\"===f.radialAxis.tickOrientation?\"rotate(\"+-f.radialAxis.orientation+\") translate(\"+[0,B[\"font-size\"]]+\")\":\"translate(\"+[0,B[\"font-size\"]]+\")\"}}),H.selectAll(\"g>line\").style({stroke:\"black\"})}var Z=t.select(\".angular.axis-group\").selectAll(\"g.angular-tick\").data(O),J=Z.enter().append(\"g\").classed(\"angular-tick\",!0);Z.attr({transform:function(t,e){return\"rotate(\"+W(t)+\")\"}}).style({display:f.angularAxis.visible?\"block\":\"none\"}),Z.exit().remove(),J.append(\"line\").classed(\"grid-line\",!0).classed(\"major\",function(t,e){return e%(f.minorTicks+1)==0}).classed(\"minor\",function(t,e){return!(e%(f.minorTicks+1)==0)}).style(F),J.selectAll(\".minor\").style({stroke:f.minorTickColor}),Z.select(\"line.grid-line\").attr({x1:f.tickLength?x-f.tickLength:0,x2:x}).style({display:f.angularAxis.gridLinesVisible?\"block\":\"none\"}),J.append(\"text\").classed(\"axis-text\",!0).style(B);var K=Z.select(\"text.axis-text\").attr({x:x+f.labelOffset,dy:a+\"em\",transform:function(t,e){var r=W(t),n=x+f.labelOffset,i=f.angularAxis.tickOrientation;return\"horizontal\"==i?\"rotate(\"+-r+\" \"+n+\" 0)\":\"radial\"==i?r<270&&r>90?\"rotate(180 \"+n+\" 0)\":null:\"rotate(\"+(r<=180&&r>0?-90:90)+\" \"+n+\" 0)\"}}).style({\"text-anchor\":\"middle\",display:f.angularAxis.labelsVisible?\"block\":\"none\"}).text(function(t,e){return e%(f.minorTicks+1)!=0?\"\":w?w[t]+f.angularAxis.ticksSuffix:t+f.angularAxis.ticksSuffix}).style(B);f.angularAxis.rewriteTicks&&K.text(function(t,e){return e%(f.minorTicks+1)!=0?\"\":f.angularAxis.rewriteTicks(this.textContent,e)});var $=n.max(R.selectAll(\".angular-tick text\")[0].map(function(t,e){return t.getCTM().e+t.getBBox().width}));D.attr({transform:\"translate(\"+[x+$,f.margin.top]+\")\"});var Q=t.select(\"g.geometry-group\").selectAll(\"g\").size()>0,tt=t.select(\"g.geometry-group\").selectAll(\"g.geometry\").data(p);if(tt.enter().append(\"g\").attr({class:function(t,e){return\"geometry geometry\"+e}}),tt.exit().remove(),p[0]||Q){var et=[];p.forEach(function(t,e){var n={};n.radialScale=r,n.angularScale=s,n.container=tt.filter(function(t,r){return r==e}),n.geometry=t.geometry,n.orientation=f.orientation,n.direction=f.direction,n.index=e,et.push({data:t,geometryConfig:n})});var rt=n.nest().key(function(t,e){return\"undefined\"!=typeof t.data.groupId||\"unstacked\"}).entries(et),nt=[];rt.forEach(function(t,e){\"unstacked\"===t.key?nt=nt.concat(t.values.map(function(t,e){return[t]})):nt.push(t.values)}),nt.forEach(function(t,e){var r;r=Array.isArray(t)?t[0].geometryConfig.geometry:t.geometryConfig.geometry;var n=t.map(function(t,e){return i(o[r].defaultConfig(),t)});o[r]().config(n)()})}var it,at,ot=t.select(\".guides-group\"),st=t.select(\".tooltips-group\"),lt=o.tooltipPanel().config({container:st,fontSize:8})(),ct=o.tooltipPanel().config({container:st,fontSize:8})(),ut=o.tooltipPanel().config({container:st,hasTick:!0})();if(!T){var ht=ot.select(\"line\").attr({x1:0,y1:0,y2:0}).style({stroke:\"grey\",\"pointer-events\":\"none\"});R.on(\"mousemove.angular-guide\",function(t,e){var r=o.util.getMousePos(Y).angle;ht.attr({x2:-x,transform:\"rotate(\"+r+\")\"}).style({opacity:.5});var n=(r+180+360-f.orientation)%360;it=s.invert(n);var i=o.util.convertToCartesian(x+12,r+180);lt.text(o.util.round(it)).move([i[0]+_[0],i[1]+_[1]])}).on(\"mouseout.angular-guide\",function(t,e){ot.select(\"line\").style({opacity:0})})}var ft=ot.select(\"circle\").style({stroke:\"grey\",fill:\"none\"});R.on(\"mousemove.radial-guide\",function(t,e){var n=o.util.getMousePos(Y).radius;ft.attr({r:n}).style({opacity:.5}),at=r.invert(o.util.getMousePos(Y).radius);var i=o.util.convertToCartesian(n,f.radialAxis.orientation);ct.text(o.util.round(at)).move([i[0]+_[0],i[1]+_[1]])}).on(\"mouseout.radial-guide\",function(t,e){ft.style({opacity:0}),ut.hide(),lt.hide(),ct.hide()}),t.selectAll(\".geometry-group .mark\").on(\"mouseover.tooltip\",function(e,r){var i=n.select(this),a=this.style.fill,s=\"black\",l=this.style.opacity||1;if(i.attr({\"data-opacity\":l}),a&&\"none\"!==a){i.attr({\"data-fill\":a}),s=n.hsl(a).darker().toString(),i.style({fill:s,opacity:1});var c={t:o.util.round(e[0]),r:o.util.round(e[1])};T&&(c.t=w[e[0]]);var u=\"t: \"+c.t+\", r: \"+c.r,h=this.getBoundingClientRect(),f=t.node().getBoundingClientRect(),p=[h.left+h.width/2-U[0]-f.left,h.top+h.height/2-U[1]-f.top];ut.config({color:s}).text(u),ut.move(p)}else a=this.style.stroke||\"black\",i.attr({\"data-stroke\":a}),s=n.hsl(a).darker().toString(),i.style({stroke:s,opacity:1})}).on(\"mousemove.tooltip\",function(t,e){if(0!=n.event.which)return!1;n.select(this).attr(\"data-fill\")&&ut.show()}).on(\"mouseout.tooltip\",function(t,e){ut.hide();var r=n.select(this),i=r.attr(\"data-fill\");i?r.style({fill:i,opacity:r.attr(\"data-opacity\")}):r.style({stroke:r.attr(\"data-stroke\"),opacity:r.attr(\"data-opacity\")})})})}(c),this},f.config=function(t){if(!arguments.length)return l;var e=o.util.cloneJson(t);return e.data.forEach(function(t,e){l.data[e]||(l.data[e]={}),i(l.data[e],o.Axis.defaultConfig().data[0]),i(l.data[e],t)}),i(l.layout,o.Axis.defaultConfig().layout),i(l.layout,e.layout),this},f.getLiveConfig=function(){return u},f.getinputConfig=function(){return c},f.radialScale=function(t){return r},f.angularScale=function(t){return s},f.svg=function(){return t},n.rebind(f,h,\"on\"),f},o.Axis.defaultConfig=function(t,e){return{data:[{t:[1,2,3,4],r:[10,11,12,13],name:\"Line1\",geometry:\"LinePlot\",color:null,strokeDash:\"solid\",strokeColor:null,strokeSize:\"1\",visibleInLegend:!0,opacity:1}],layout:{defaultColorRange:n.scale.category10().range(),title:null,height:450,width:500,margin:{top:40,right:40,bottom:40,left:40},font:{size:12,color:\"gray\",outlineColor:\"white\",family:\"Tahoma, sans-serif\"},direction:\"clockwise\",orientation:0,labelOffset:10,radialAxis:{domain:null,orientation:-45,ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null},angularAxis:{domain:[0,360],ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,labelsVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null,ticksCount:null,ticksStep:null},minorTicks:0,tickLength:null,tickColor:\"silver\",minorTickColor:\"#eee\",backgroundColor:\"none\",needsEndSpacing:null,showLegend:!0,legend:{reverseOrder:!1},opacity:1}}},o.util={},o.DATAEXTENT=\"dataExtent\",o.AREA=\"AreaChart\",o.LINE=\"LinePlot\",o.DOT=\"DotPlot\",o.BAR=\"BarChart\",o.util._override=function(t,e){for(var r in t)r in e&&(e[r]=t[r])},o.util._extend=function(t,e){for(var r in t)e[r]=t[r]},o.util._rndSnd=function(){return 2*Math.random()-1+(2*Math.random()-1)+(2*Math.random()-1)},o.util.dataFromEquation2=function(t,e){var r=e||6;return n.range(0,360+r,r).map(function(e,r){var n=e*Math.PI/180;return[e,t(n)]})},o.util.dataFromEquation=function(t,e,r){var i=e||6,a=[],o=[];n.range(0,360+i,i).forEach(function(e,r){var n=e*Math.PI/180,i=t(n);a.push(e),o.push(i)});var s={t:a,r:o};return r&&(s.name=r),s},o.util.ensureArray=function(t,e){if(\"undefined\"==typeof t)return null;var r=[].concat(t);return n.range(e).map(function(t,e){return r[e]||r[0]})},o.util.fillArrays=function(t,e,r){return e.forEach(function(e,n){t[e]=o.util.ensureArray(t[e],r)}),t},o.util.cloneJson=function(t){return JSON.parse(JSON.stringify(t))},o.util.validateKeys=function(t,e){\"string\"==typeof e&&(e=e.split(\".\"));var r=e.shift();return t[r]&&(!e.length||objHasKeys(t[r],e))},o.util.sumArrays=function(t,e){return n.zip(t,e).map(function(t,e){return n.sum(t)})},o.util.arrayLast=function(t){return t[t.length-1]},o.util.arrayEqual=function(t,e){for(var r=Math.max(t.length,e.length,1);r-- >=0&&t[r]===e[r];);return-2===r},o.util.flattenArray=function(t){for(var e=[];!o.util.arrayEqual(e,t);)e=t,t=[].concat.apply([],t);return t},o.util.deduplicate=function(t){return t.filter(function(t,e,r){return r.indexOf(t)==e})},o.util.convertToCartesian=function(t,e){var r=e*Math.PI/180;return[t*Math.cos(r),t*Math.sin(r)]},o.util.round=function(t,e){var r=e||2,n=Math.pow(10,r);return Math.round(t*n)/n},o.util.getMousePos=function(t){var e=n.mouse(t.node()),r=e[0],i=e[1],a={};return a.x=r,a.y=i,a.pos=e,a.angle=180*(Math.atan2(i,r)+Math.PI)/Math.PI,a.radius=Math.sqrt(r*r+i*i),a},o.util.duplicatesCount=function(t){for(var e,r={},n={},i=0,a=t.length;i<a;i++)(e=t[i])in r?(r[e]++,n[e]=r[e]):r[e]=1;return n},o.util.duplicates=function(t){return Object.keys(o.util.duplicatesCount(t))},o.util.translator=function(t,e,r,n){if(n){var i=r.slice();r=e,e=i}var a=e.reduce(function(t,e){if(\"undefined\"!=typeof t)return t[e]},t);\"undefined\"!=typeof a&&(e.reduce(function(t,r,n){if(\"undefined\"!=typeof t)return n===e.length-1&&delete t[r],t[r]},t),r.reduce(function(t,e,n){return\"undefined\"==typeof t[e]&&(t[e]={}),n===r.length-1&&(t[e]=a),t[e]},t))},o.PolyChart=function(){var t=[o.PolyChart.defaultConfig()],e=n.dispatch(\"hover\"),r={solid:\"none\",dash:[5,2],dot:[2,5]};function a(){var e=t[0].geometryConfig,i=e.container;\"string\"==typeof i&&(i=n.select(i)),i.datum(t).each(function(t,i){var a=!!t[0].data.yStack,o=t.map(function(t,e){return a?n.zip(t.data.t[0],t.data.r[0],t.data.yStack[0]):n.zip(t.data.t[0],t.data.r[0])}),s=e.angularScale,l=e.radialScale.domain()[0],c={bar:function(r,i,a){var o=t[a].data,l=e.radialScale(r[1])-e.radialScale(0),c=e.radialScale(r[2]||0),u=o.barWidth;n.select(this).attr({class:\"mark bar\",d:\"M\"+[[l+c,-u/2],[l+c,u/2],[c,u/2],[c,-u/2]].join(\"L\")+\"Z\",transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0]))+\")\"}})}};c.dot=function(r,i,a){var o=r[2]?[r[0],r[1]+r[2]]:r,s=n.svg.symbol().size(t[a].data.dotSize).type(t[a].data.dotType)(r,i);n.select(this).attr({class:\"mark dot\",d:s,transform:function(t,r){var n,i,a,s=(n=function(t,r){var n=e.radialScale(t[1]),i=(e.angularScale(t[0])+e.orientation)*Math.PI/180;return{r:n,t:i}}(o),i=n.r*Math.cos(n.t),a=n.r*Math.sin(n.t),{x:i,y:a});return\"translate(\"+[s.x,s.y]+\")\"}})};var u=n.svg.line.radial().interpolate(t[0].data.lineInterpolation).radius(function(t){return e.radialScale(t[1])}).angle(function(t){return e.angularScale(t[0])*Math.PI/180});c.line=function(r,i,a){var s=r[2]?o[a].map(function(t,e){return[t[0],t[1]+t[2]]}):o[a];if(n.select(this).each(c.dot).style({opacity:function(e,r){return+t[a].data.dotVisible},fill:d.stroke(r,i,a)}).attr({class:\"mark dot\"}),!(i>0)){var l=n.select(this.parentNode).selectAll(\"path.line\").data([0]);l.enter().insert(\"path\"),l.attr({class:\"line\",d:u(s),transform:function(t,r){return\"rotate(\"+(e.orientation+90)+\")\"},\"pointer-events\":\"none\"}).style({fill:function(t,e){return d.fill(r,i,a)},\"fill-opacity\":0,stroke:function(t,e){return d.stroke(r,i,a)},\"stroke-width\":function(t,e){return d[\"stroke-width\"](r,i,a)},\"stroke-dasharray\":function(t,e){return d[\"stroke-dasharray\"](r,i,a)},opacity:function(t,e){return d.opacity(r,i,a)},display:function(t,e){return d.display(r,i,a)}})}};var h=e.angularScale.range(),f=Math.abs(h[1]-h[0])/o[0].length*Math.PI/180,p=n.svg.arc().startAngle(function(t){return-f/2}).endAngle(function(t){return f/2}).innerRadius(function(t){return e.radialScale(l+(t[2]||0))}).outerRadius(function(t){return e.radialScale(l+(t[2]||0))+e.radialScale(t[1])});c.arc=function(t,r,i){n.select(this).attr({class:\"mark arc\",d:p,transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0])+90)+\")\"}})};var d={fill:function(e,r,n){return t[n].data.color},stroke:function(e,r,n){return t[n].data.strokeColor},\"stroke-width\":function(e,r,n){return t[n].data.strokeSize+\"px\"},\"stroke-dasharray\":function(e,n,i){return r[t[i].data.strokeDash]},opacity:function(e,r,n){return t[n].data.opacity},display:function(e,r,n){return\"undefined\"==typeof t[n].data.visible||t[n].data.visible?\"block\":\"none\"}},g=n.select(this).selectAll(\"g.layer\").data(o);g.enter().append(\"g\").attr({class:\"layer\"});var v=g.selectAll(\"path.mark\").data(function(t,e){return t});v.enter().append(\"path\").attr({class:\"mark\"}),v.style(d).each(c[e.geometryType]),v.exit().remove(),g.exit().remove()})}return a.config=function(e){return arguments.length?(e.forEach(function(e,r){t[r]||(t[r]={}),i(t[r],o.PolyChart.defaultConfig()),i(t[r],e)}),this):t},a.getColorScale=function(){},n.rebind(a,e,\"on\"),a},o.PolyChart.defaultConfig=function(){return{data:{name:\"geom1\",t:[[1,2,3,4]],r:[[1,2,3,4]],dotType:\"circle\",dotSize:64,dotVisible:!1,barWidth:20,color:\"#ffa500\",strokeSize:1,strokeColor:\"silver\",strokeDash:\"solid\",opacity:1,index:0,visible:!0,visibleInLegend:!0},geometryConfig:{geometry:\"LinePlot\",geometryType:\"arc\",direction:\"clockwise\",orientation:0,container:\"body\",radialScale:null,angularScale:null,colorScale:n.scale.category20()}}},o.BarChart=function(){return o.PolyChart()},o.BarChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"bar\"}}},o.AreaChart=function(){return o.PolyChart()},o.AreaChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"arc\"}}},o.DotPlot=function(){return o.PolyChart()},o.DotPlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"dot\",dotType:\"circle\"}}},o.LinePlot=function(){return o.PolyChart()},o.LinePlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"line\"}}},o.Legend=function(){var t=o.Legend.defaultConfig(),e=n.dispatch(\"hover\");function r(){var e=t.legendConfig,a=t.data.map(function(t,r){return[].concat(t).map(function(t,n){var a=i({},e.elements[r]);return a.name=t,a.color=[].concat(e.elements[r].color)[n],a})}),o=n.merge(a);o=o.filter(function(t,r){return e.elements[r]&&(e.elements[r].visibleInLegend||\"undefined\"==typeof e.elements[r].visibleInLegend)}),e.reverseOrder&&(o=o.reverse());var s=e.container;(\"string\"==typeof s||s.nodeName)&&(s=n.select(s));var l=o.map(function(t,e){return t.color}),c=e.fontSize,u=null==e.isContinuous?\"number\"==typeof o[0]:e.isContinuous,h=u?e.height:c*o.length,f=s.classed(\"legend-group\",!0).selectAll(\"svg\").data([0]),p=f.enter().append(\"svg\").attr({width:300,height:h+c,xmlns:\"http://www.w3.org/2000/svg\",\"xmlns:xlink\":\"http://www.w3.org/1999/xlink\",version:\"1.1\"});p.append(\"g\").classed(\"legend-axis\",!0),p.append(\"g\").classed(\"legend-marks\",!0);var d=n.range(o.length),g=n.scale[u?\"linear\":\"ordinal\"]().domain(d).range(l),v=n.scale[u?\"linear\":\"ordinal\"]().domain(d)[u?\"range\":\"rangePoints\"]([0,h]);if(u){var m=f.select(\".legend-marks\").append(\"defs\").append(\"linearGradient\").attr({id:\"grad1\",x1:\"0%\",y1:\"0%\",x2:\"0%\",y2:\"100%\"}).selectAll(\"stop\").data(l);m.enter().append(\"stop\"),m.attr({offset:function(t,e){return e/(l.length-1)*100+\"%\"}}).style({\"stop-color\":function(t,e){return t}}),f.append(\"rect\").classed(\"legend-mark\",!0).attr({height:e.height,width:e.colorBandWidth,fill:\"url(#grad1)\"})}else{var y=f.select(\".legend-marks\").selectAll(\"path.legend-mark\").data(o);y.enter().append(\"path\").classed(\"legend-mark\",!0),y.attr({transform:function(t,e){return\"translate(\"+[c/2,v(e)+c/2]+\")\"},d:function(t,e){var r,i,a,o=t.symbol;return a=3*(i=c),\"line\"===(r=o)?\"M\"+[[-i/2,-i/12],[i/2,-i/12],[i/2,i/12],[-i/2,i/12]]+\"Z\":-1!=n.svg.symbolTypes.indexOf(r)?n.svg.symbol().type(r).size(a)():n.svg.symbol().type(\"square\").size(a)()},fill:function(t,e){return g(e)}}),y.exit().remove()}var x=n.svg.axis().scale(v).orient(\"right\"),b=f.select(\"g.legend-axis\").attr({transform:\"translate(\"+[u?e.colorBandWidth:c,c/2]+\")\"}).call(x);return b.selectAll(\".domain\").style({fill:\"none\",stroke:\"none\"}),b.selectAll(\"line\").style({fill:\"none\",stroke:u?e.textColor:\"none\"}),b.selectAll(\"text\").style({fill:e.textColor,\"font-size\":e.fontSize}).text(function(t,e){return o[e].name}),r}return r.config=function(e){return arguments.length?(i(t,e),this):t},n.rebind(r,e,\"on\"),r},o.Legend.defaultConfig=function(t,e){return{data:[\"a\",\"b\",\"c\"],legendConfig:{elements:[{symbol:\"line\",color:\"red\"},{symbol:\"square\",color:\"yellow\"},{symbol:\"diamond\",color:\"limegreen\"}],height:150,colorBandWidth:30,fontSize:12,container:\"body\",isContinuous:null,textColor:\"grey\",reverseOrder:!1}}},o.tooltipPanel=function(){var t,e,r,a={container:null,hasTick:!1,fontSize:12,color:\"white\",padding:5},s=\"tooltip-\"+o.tooltipPanel.uid++,l=10,c=function(){var n=(t=a.container.selectAll(\"g.\"+s).data([0])).enter().append(\"g\").classed(s,!0).style({\"pointer-events\":\"none\",display:\"none\"});return r=n.append(\"path\").style({fill:\"white\",\"fill-opacity\":.9}).attr({d:\"M0 0\"}),e=n.append(\"text\").attr({dx:a.padding+l,dy:.3*+a.fontSize}),c};return c.text=function(i){var o=n.hsl(a.color).l,s=o>=.5?\"#aaa\":\"white\",u=o>=.5?\"black\":\"white\",h=i||\"\";e.style({fill:u,\"font-size\":a.fontSize+\"px\"}).text(h);var f=a.padding,p=e.node().getBBox(),d={fill:a.color,stroke:s,\"stroke-width\":\"2px\"},g=p.width+2*f+l,v=p.height+2*f;return r.attr({d:\"M\"+[[l,-v/2],[l,-v/4],[a.hasTick?0:l,0],[l,v/4],[l,v/2],[g,v/2],[g,-v/2]].join(\"L\")+\"Z\"}).style(d),t.attr({transform:\"translate(\"+[l,-v/2+2*f]+\")\"}),t.style({display:\"block\"}),c},c.move=function(e){if(t)return t.attr({transform:\"translate(\"+[e[0],e[1]]+\")\"}).style({display:\"block\"}),c},c.hide=function(){if(t)return t.style({display:\"none\"}),c},c.show=function(){if(t)return t.style({display:\"block\"}),c},c.config=function(t){return i(a,t),c},c},o.tooltipPanel.uid=1,o.adapter={},o.adapter.plotly=function(){var t={convert:function(t,e){var r={};if(t.data&&(r.data=t.data.map(function(t,r){var n=i({},t);return[[n,[\"marker\",\"color\"],[\"color\"]],[n,[\"marker\",\"opacity\"],[\"opacity\"]],[n,[\"marker\",\"line\",\"color\"],[\"strokeColor\"]],[n,[\"marker\",\"line\",\"dash\"],[\"strokeDash\"]],[n,[\"marker\",\"line\",\"width\"],[\"strokeSize\"]],[n,[\"marker\",\"symbol\"],[\"dotType\"]],[n,[\"marker\",\"size\"],[\"dotSize\"]],[n,[\"marker\",\"barWidth\"],[\"barWidth\"]],[n,[\"line\",\"interpolation\"],[\"lineInterpolation\"]],[n,[\"showlegend\"],[\"visibleInLegend\"]]].forEach(function(t,r){o.util.translator.apply(null,t.concat(e))}),e||delete n.marker,e&&delete n.groupId,e?(\"LinePlot\"===n.geometry?(n.type=\"scatter\",!0===n.dotVisible?(delete n.dotVisible,n.mode=\"lines+markers\"):n.mode=\"lines\"):\"DotPlot\"===n.geometry?(n.type=\"scatter\",n.mode=\"markers\"):\"AreaChart\"===n.geometry?n.type=\"area\":\"BarChart\"===n.geometry&&(n.type=\"bar\"),delete n.geometry):(\"scatter\"===n.type?\"lines\"===n.mode?n.geometry=\"LinePlot\":\"markers\"===n.mode?n.geometry=\"DotPlot\":\"lines+markers\"===n.mode&&(n.geometry=\"LinePlot\",n.dotVisible=!0):\"area\"===n.type?n.geometry=\"AreaChart\":\"bar\"===n.type&&(n.geometry=\"BarChart\"),delete n.mode,delete n.type),n}),!e&&t.layout&&\"stack\"===t.layout.barmode)){var a=o.util.duplicates(r.data.map(function(t,e){return t.geometry}));r.data.forEach(function(t,e){var n=a.indexOf(t.geometry);-1!=n&&(r.data[e].groupId=n)})}if(t.layout){var s=i({},t.layout);if([[s,[\"plot_bgcolor\"],[\"backgroundColor\"]],[s,[\"showlegend\"],[\"showLegend\"]],[s,[\"radialaxis\"],[\"radialAxis\"]],[s,[\"angularaxis\"],[\"angularAxis\"]],[s.angularaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularaxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularaxis,[\"nticks\"],[\"ticksCount\"]],[s.angularaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularaxis,[\"range\"],[\"domain\"]],[s.angularaxis,[\"endpadding\"],[\"endPadding\"]],[s.radialaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialaxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularAxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularAxis,[\"nticks\"],[\"ticksCount\"]],[s.angularAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularAxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"endpadding\"],[\"endPadding\"]],[s.radialAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialAxis,[\"range\"],[\"domain\"]],[s.font,[\"outlinecolor\"],[\"outlineColor\"]],[s.legend,[\"traceorder\"],[\"reverseOrder\"]],[s,[\"labeloffset\"],[\"labelOffset\"]],[s,[\"defaultcolorrange\"],[\"defaultColorRange\"]]].forEach(function(t,r){o.util.translator.apply(null,t.concat(e))}),e?(\"undefined\"!=typeof s.tickLength&&(s.angularaxis.ticklen=s.tickLength,delete s.tickLength),s.tickColor&&(s.angularaxis.tickcolor=s.tickColor,delete s.tickColor)):(s.angularAxis&&\"undefined\"!=typeof s.angularAxis.ticklen&&(s.tickLength=s.angularAxis.ticklen),s.angularAxis&&\"undefined\"!=typeof s.angularAxis.tickcolor&&(s.tickColor=s.angularAxis.tickcolor)),s.legend&&\"boolean\"!=typeof s.legend.reverseOrder&&(s.legend.reverseOrder=\"normal\"!=s.legend.reverseOrder),s.legend&&\"boolean\"==typeof s.legend.traceorder&&(s.legend.traceorder=s.legend.traceorder?\"reversed\":\"normal\",delete s.legend.reverseOrder),s.margin&&\"undefined\"!=typeof s.margin.t){var l=[\"t\",\"r\",\"b\",\"l\",\"pad\"],c=[\"top\",\"right\",\"bottom\",\"left\",\"pad\"],u={};n.entries(s.margin).forEach(function(t,e){u[c[l.indexOf(t.key)]]=t.value}),s.margin=u}e&&(delete s.needsEndSpacing,delete s.minorTickColor,delete s.minorTicks,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksStep,delete s.angularaxis.rewriteTicks,delete s.angularaxis.nticks,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksStep,delete s.radialaxis.rewriteTicks,delete s.radialaxis.nticks),r.layout=s}return r}};return t}},{\"../../../constants/alignment\":688,\"../../../lib\":719,d3:163}],838:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../../lib\"),a=t(\"../../../components/color\"),o=t(\"./micropolar\"),s=t(\"./undo_manager\"),l=i.extendDeepAll,c=e.exports={};c.framework=function(t){var e,r,i,a,u,h=new s;function f(r,s){return s&&(u=s),n.select(n.select(u).node().parentNode).selectAll(\".svg-container>*:not(.chart-root)\").remove(),e=e?l(e,r):r,i||(i=o.Axis()),a=o.adapter.plotly().convert(e),i.config(a).render(u),t.data=e.data,t.layout=e.layout,c.fillLayout(t),e}return f.isPolar=!0,f.svg=function(){return i.svg()},f.getConfig=function(){return e},f.getLiveConfig=function(){return o.adapter.plotly().convert(i.getLiveConfig(),!0)},f.getLiveScales=function(){return{t:i.angularScale(),r:i.radialScale()}},f.setUndoPoint=function(){var t,n,i=this,a=o.util.cloneJson(e);t=a,n=r,h.add({undo:function(){n&&i(n)},redo:function(){i(t)}}),r=o.util.cloneJson(a)},f.undo=function(){h.undo()},f.redo=function(){h.redo()},f},c.fillLayout=function(t){var e=n.select(t).selectAll(\".plot-container\"),r=e.selectAll(\".svg-container\"),i=t.framework&&t.framework.svg&&t.framework.svg(),o={width:800,height:600,paper_bgcolor:a.background,_container:e,_paperdiv:r,_paper:i};t._fullLayout=l(o,t.layout)}},{\"../../../components/color\":593,\"../../../lib\":719,\"./micropolar\":837,\"./undo_manager\":839,d3:163}],839:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=[],r=-1,n=!1;function i(t,e){return t?(n=!0,t[e](),n=!1,this):this}return{add:function(t){return n?this:(e.splice(r+1,e.length-r),e.push(t),r=e.length-1,this)},setCallback:function(e){t=e},undo:function(){var n=e[r];return n?(i(n,\"undo\"),r-=1,t&&t(n.undo),this):this},redo:function(){var n=e[r+1];return n?(i(n,\"redo\"),r+=1,t&&t(n.redo),this):this},clear:function(){e=[],r=-1},hasUndo:function(){return-1!==r},hasRedo:function(){return r<e.length-1},getCommands:function(){return e},getPreviousCommand:function(){return e[r-1]},getIndex:function(){return r}}}},{}],840:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../plots\"),u=t(\"../../plots/cartesian/axes\"),h=t(\"../cartesian/set_convert\"),f=t(\"./set_convert\"),p=t(\"../cartesian/autorange\").doAutoRange,d=t(\"../cartesian/dragbox\"),g=t(\"../../components/dragelement\"),v=t(\"../../components/fx\"),m=t(\"../../components/titles\"),y=t(\"../cartesian/select\").prepSelect,x=t(\"../cartesian/select\").selectOnClick,b=t(\"../cartesian/select\").clearSelect,_=t(\"../../lib/setcursor\"),w=t(\"../../lib/clear_gl_canvases\"),k=t(\"../../plot_api/subroutines\").redrawReglTraces,T=t(\"../../constants/alignment\").MID_SHIFT,A=t(\"./constants\"),M=t(\"./helpers\"),S=o._,E=o.mod,C=o.deg2rad,L=o.rad2deg;function P(t,e){this.id=e,this.gd=t,this._hasClipOnAxisFalse=null,this.vangles=null,this.radialAxisAngle=null,this.traceHash={},this.layers={},this.clipPaths={},this.clipIds={},this.viewInitial={};var r=t._fullLayout,n=\"clip\"+r._uid+e;this.clipIds.forTraces=n+\"-for-traces\",this.clipPaths.forTraces=r._clips.append(\"clipPath\").attr(\"id\",this.clipIds.forTraces),this.clipPaths.forTraces.append(\"path\"),this.framework=r._polarlayer.append(\"g\").attr(\"class\",e),this.radialTickLayout=null,this.angularTickLayout=null}var O=P.prototype;function z(t){var e=t.ticks+String(t.ticklen)+String(t.showticklabels);return\"side\"in t&&(e+=t.side),e}function I(t,e){return e[o.findIndexOfMin(e,function(e){return o.angleDist(t,e)})]}function D(t,e,r){return e?(t.attr(\"display\",null),t.attr(r)):t&&t.attr(\"display\",\"none\"),t}function R(t,e){return\"translate(\"+t+\",\"+e+\")\"}function F(t){return\"rotate(\"+t+\")\"}e.exports=function(t,e){return new P(t,e)},O.plot=function(t,e){var r=e[this.id];this._hasClipOnAxisFalse=!1;for(var n=0;n<t.length;n++){if(!1===t[n][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(e,r),this.updateLayout(e,r),c.generalUpdatePerTraceModule(this.gd,this,t,r),this.updateFx(e,r)},O.updateLayers=function(t,e){var r=this.layers,i=e.radialaxis,a=e.angularaxis,o=A.layerNames,s=o.indexOf(\"frontplot\"),l=o.slice(0,s),c=\"below traces\"===a.layer,u=\"below traces\"===i.layer;c&&l.push(\"angular-line\"),u&&l.push(\"radial-line\"),c&&l.push(\"angular-axis\"),u&&l.push(\"radial-axis\"),l.push(\"frontplot\"),c||l.push(\"angular-line\"),u||l.push(\"radial-line\"),c||l.push(\"angular-axis\"),u||l.push(\"radial-axis\");var h=this.framework.selectAll(\".polarsublayer\").data(l,String);h.enter().append(\"g\").attr(\"class\",function(t){return\"polarsublayer \"+t}).each(function(t){var e=r[t]=n.select(this);switch(t){case\"frontplot\":e.append(\"g\").classed(\"barlayer\",!0),e.append(\"g\").classed(\"scatterlayer\",!0);break;case\"backplot\":e.append(\"g\").classed(\"maplayer\",!0);break;case\"plotbg\":r.bg=e.append(\"path\");break;case\"radial-grid\":case\"angular-grid\":e.style(\"fill\",\"none\");break;case\"radial-line\":e.append(\"line\").style(\"fill\",\"none\");break;case\"angular-line\":e.append(\"path\").style(\"fill\",\"none\")}}),h.order()},O.updateLayout=function(t,e){var r=this.layers,n=t._size,i=e.radialaxis,a=e.angularaxis,o=e.domain.x,c=e.domain.y;this.xOffset=n.l+n.w*o[0],this.yOffset=n.t+n.h*(1-c[1]);var u=this.xLength=n.w*(o[1]-o[0]),h=this.yLength=n.h*(c[1]-c[0]),f=e.sector;this.sectorInRad=f.map(C);var p,d,g,v,m,y=this.sectorBBox=function(t){var e,r,n,i,a=t[0],o=t[1]-a,s=E(a,360),l=s+o,c=Math.cos(C(s)),u=Math.sin(C(s)),h=Math.cos(C(l)),f=Math.sin(C(l));i=s<=90&&l>=90||s>90&&l>=450?1:u<=0&&f<=0?0:Math.max(u,f);e=s<=180&&l>=180||s>180&&l>=540?-1:c>=0&&h>=0?0:Math.min(c,h);r=s<=270&&l>=270||s>270&&l>=630?-1:u>=0&&f>=0?0:Math.min(u,f);n=l>=360?1:c<=0&&h<=0?0:Math.max(c,h);return[e,r,n,i]}(f),x=y[2]-y[0],b=y[3]-y[1],_=h/u,w=Math.abs(b/x);_>w?(p=u,m=(h-(d=u*w))/n.h/2,g=[o[0],o[1]],v=[c[0]+m,c[1]-m]):(d=h,m=(u-(p=h/w))/n.w/2,g=[o[0]+m,o[1]-m],v=[c[0],c[1]]),this.xLength2=p,this.yLength2=d,this.xDomain2=g,this.yDomain2=v;var k=this.xOffset2=n.l+n.w*g[0],T=this.yOffset2=n.t+n.h*(1-v[1]),A=this.radius=p/x,M=this.innerRadius=e.hole*A,S=this.cx=k-A*y[0],L=this.cy=T+A*y[3],P=this.cxx=S-k,O=this.cyy=L-T;this.radialAxis=this.mockAxis(t,e,i,{_id:\"x\",side:{counterclockwise:\"top\",clockwise:\"bottom\"}[i.side],domain:[M/n.w,A/n.w]}),this.angularAxis=this.mockAxis(t,e,a,{side:\"right\",domain:[0,Math.PI],autorange:!1}),this.doAutoRange(t,e),this.updateAngularAxis(t,e),this.updateRadialAxis(t,e),this.updateRadialAxisTitle(t,e),this.xaxis=this.mockCartesianAxis(t,e,{_id:\"x\",domain:g}),this.yaxis=this.mockCartesianAxis(t,e,{_id:\"y\",domain:v});var z=this.pathSubplot();this.clipPaths.forTraces.select(\"path\").attr(\"d\",z).attr(\"transform\",R(P,O)),r.frontplot.attr(\"transform\",R(k,T)).call(l.setClipUrl,this._hasClipOnAxisFalse?null:this.clipIds.forTraces,this.gd),r.bg.attr(\"d\",z).attr(\"transform\",R(S,L)).call(s.fill,e.bgcolor)},O.mockAxis=function(t,e,r,n){var i=o.extendFlat({anchor:\"free\",position:0},r,n);return f(i,e,t),i},O.mockCartesianAxis=function(t,e,r){var n=this,i=r._id,a=o.extendFlat({type:\"linear\"},r);h(a,t);var s={x:[0,2],y:[1,3]};return a.setRange=function(){var t=n.sectorBBox,r=s[i],o=n.radialAxis._rl,l=(o[1]-o[0])/(1-e.hole);a.range=[t[r[0]]*l,t[r[1]]*l]},a.isPtWithinRange=\"x\"===i?function(t){return n.isPtInside(t)}:function(){return!0},a.setRange(),a.setScale(),a},O.doAutoRange=function(t,e){var r=this.gd,n=this.radialAxis,i=e.radialaxis;n.setScale(),p(r,n);var a=n.range;i.range=a.slice(),i._input.range=a.slice(),n._rl=[n.r2l(a[0],null,\"gregorian\"),n.r2l(a[1],null,\"gregorian\")]},O.updateRadialAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,l=r.innerRadius,c=r.cx,h=r.cy,f=e.radialaxis,p=E(e.sector[0],360),d=r.radialAxis,g=l<a;r.fillViewInitialKey(\"radialaxis.angle\",f.angle),r.fillViewInitialKey(\"radialaxis.range\",d.range.slice()),d.setGeometry(),\"auto\"===d.tickangle&&p>90&&p<=270&&(d.tickangle=180);var v=function(t){return\"translate(\"+(d.l2p(t.x)+l)+\",0)\"},m=z(f);if(r.radialTickLayout!==m&&(i[\"radial-axis\"].selectAll(\".xtick\").remove(),r.radialTickLayout=m),g){d.setScale();var y=u.calcTicks(d),x=u.clipEnds(d,y),b=u.getTickSigns(d)[2];u.drawTicks(n,d,{vals:y,layer:i[\"radial-axis\"],path:u.makeTickPath(d,0,b),transFn:v,crisp:!1}),u.drawGrid(n,d,{vals:x,layer:i[\"radial-grid\"],path:function(t){return r.pathArc(d.r2p(t.x)+l)},transFn:o.noop,crisp:!1}),u.drawLabels(n,d,{vals:y,layer:i[\"radial-axis\"],transFn:v,labelFns:u.makeLabelFns(d,0)})}var _=r.radialAxisAngle=r.vangles?L(I(C(f.angle),r.vangles)):f.angle,w=R(c,h),k=w+F(-_);D(i[\"radial-axis\"],g&&(f.showticklabels||f.ticks),{transform:k}),D(i[\"radial-grid\"],g&&f.showgrid,{transform:w}),D(i[\"radial-line\"].select(\"line\"),g&&f.showline,{x1:l,y1:0,x2:a,y2:0,transform:k}).attr(\"stroke-width\",f.linewidth).call(s.stroke,f.linecolor)},O.updateRadialAxisTitle=function(t,e,r){var n=this.gd,i=this.radius,a=this.cx,o=this.cy,s=e.radialaxis,c=this.id+\"title\",u=void 0!==r?r:this.radialAxisAngle,h=C(u),f=Math.cos(h),p=Math.sin(h),d=0;if(s.title){var g=l.bBox(this.layers[\"radial-axis\"].node()).height,v=s.title.font.size;d=\"counterclockwise\"===s.side?-g-.4*v:g+.8*v}this.layers[\"radial-axis-title\"]=m.draw(n,c,{propContainer:s,propName:this.id+\".radialaxis.title\",placeholder:S(n,\"Click to enter radial axis title\"),attributes:{x:a+i/2*f+d*p,y:o-i/2*p+d*f,\"text-anchor\":\"middle\"},transform:{rotate:-u}})},O.updateAngularAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,l=r.innerRadius,c=r.cx,h=r.cy,f=e.angularaxis,p=r.angularAxis;r.fillViewInitialKey(\"angularaxis.rotation\",f.rotation),p.setGeometry(),p.setScale();var d=function(t){return p.t2g(t.x)};\"linear\"===p.type&&\"radians\"===p.thetaunit&&(p.tick0=L(p.tick0),p.dtick=L(p.dtick));var g=function(t){return R(c+a*Math.cos(t),h-a*Math.sin(t))},v=u.makeLabelFns(p,0).labelStandoff,m={xFn:function(t){var e=d(t);return Math.cos(e)*v},yFn:function(t){var e=d(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(v+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*T)},anchorFn:function(t){var e=d(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},heightFn:function(t,e,r){var n=d(t);return-.5*(1+Math.sin(n))*r}},y=z(f);r.angularTickLayout!==y&&(i[\"angular-axis\"].selectAll(\".\"+p._id+\"tick\").remove(),r.angularTickLayout=y);var x,b=u.calcTicks(p);if(\"linear\"===e.gridshape?(x=b.map(d),o.angleDelta(x[0],x[1])<0&&(x=x.slice().reverse())):x=null,r.vangles=x,\"category\"===p.type&&(b=b.filter(function(t){return o.isAngleInsideSector(d(t),r.sectorInRad)})),p.visible){var _=\"inside\"===p.ticks?-1:1,w=(p.linewidth||1)/2;u.drawTicks(n,p,{vals:b,layer:i[\"angular-axis\"],path:\"M\"+_*w+\",0h\"+_*p.ticklen,transFn:function(t){var e=d(t);return g(e)+F(-L(e))},crisp:!1}),u.drawGrid(n,p,{vals:b,layer:i[\"angular-grid\"],path:function(t){var e=d(t),r=Math.cos(e),n=Math.sin(e);return\"M\"+[c+l*r,h-l*n]+\"L\"+[c+a*r,h-a*n]},transFn:o.noop,crisp:!1}),u.drawLabels(n,p,{vals:b,layer:i[\"angular-axis\"],repositionOnUpdate:!0,transFn:function(t){return g(d(t))},labelFns:m})}D(i[\"angular-line\"].select(\"path\"),f.showline,{d:r.pathSubplot(),transform:R(c,h)}).attr(\"stroke-width\",f.linewidth).call(s.stroke,f.linecolor)},O.updateFx=function(t,e){this.gd._context.staticPlot||(this.updateAngularDrag(t),this.updateRadialDrag(t,e,0),this.updateRadialDrag(t,e,1),this.updateMainDrag(t))},O.updateMainDrag=function(t){var e=this,r=e.gd,o=e.layers,s=t._zoomlayer,l=A.MINZOOM,c=A.OFFEDGE,u=e.radius,h=e.innerRadius,f=e.cx,p=e.cy,m=e.cxx,_=e.cyy,w=e.sectorInRad,k=e.vangles,T=e.radialAxis,S=M.clampTiny,E=M.findXYatLength,C=M.findEnclosingVertexAngles,L=A.cornerHalfWidth,P=A.cornerLen/2,O=d.makeDragger(o,\"path\",\"maindrag\",\"crosshair\");n.select(O).attr(\"d\",e.pathSubplot()).attr(\"transform\",R(f,p));var z,I,D,F,B,N,j,U,V,q={element:O,gd:r,subplot:e.id,plotinfo:{id:e.id,xaxis:e.xaxis,yaxis:e.yaxis},xaxes:[e.xaxis],yaxes:[e.yaxis]};function H(t,e){return Math.sqrt(t*t+e*e)}function G(t,e){return H(t-m,e-_)}function Y(t,e){return Math.atan2(_-e,t-m)}function W(t,e){return[t*Math.cos(e),t*Math.sin(-e)]}function X(t,r){if(0===t)return e.pathSector(2*L);var n=P/t,i=r-n,a=r+n,o=Math.max(0,Math.min(t,u)),s=o-L,l=o+L;return\"M\"+W(s,i)+\"A\"+[s,s]+\" 0,0,0 \"+W(s,a)+\"L\"+W(l,a)+\"A\"+[l,l]+\" 0,0,1 \"+W(l,i)+\"Z\"}function Z(t,r,n){if(0===t)return e.pathSector(2*L);var i,a,o=W(t,r),s=W(t,n),l=S((o[0]+s[0])/2),c=S((o[1]+s[1])/2);if(l&&c){var u=c/l,h=-1/u,f=E(L,u,l,c);i=E(P,h,f[0][0],f[0][1]),a=E(P,h,f[1][0],f[1][1])}else{var p,d;c?(p=P,d=L):(p=L,d=P),i=[[l-p,c-d],[l+p,c-d]],a=[[l-p,c+d],[l+p,c+d]]}return\"M\"+i.join(\"L\")+\"L\"+a.reverse().join(\"L\")+\"Z\"}function J(t,e){return e=Math.max(Math.min(e,u),h),t<c?t=0:u-t<c?t=u:e<c?e=0:u-e<c&&(e=u),Math.abs(e-t)>l?(t<e?(D=t,F=e):(D=e,F=t),!0):(D=null,F=null,!1)}function K(t,e){t=t||B,e=e||\"M0,0Z\",U.attr(\"d\",t),V.attr(\"d\",e),d.transitionZoombox(U,V,N,j),N=!0;var n={};rt(n),r.emit(\"plotly_relayouting\",n)}function $(t,r){var n,i,a=z+t,o=I+r,s=G(z,I),l=Math.min(G(a,o),u),c=Y(z,I);J(s,l)&&(n=B+e.pathSector(F),D&&(n+=e.pathSector(D)),i=X(D,c)+X(F,c)),K(n,i)}function Q(t,e,r,n){var i=M.findIntersectionXY(r,n,r,[t-m,_-e]);return H(i[0],i[1])}function tt(t,r){var n,i,a=z+t,o=I+r,s=Y(z,I),l=Y(a,o),c=C(s,k),h=C(l,k);J(Q(z,I,c[0],c[1]),Math.min(Q(a,o,h[0],h[1]),u))&&(n=B+e.pathSector(F),D&&(n+=e.pathSector(D)),i=[Z(D,c[0],c[1]),Z(F,c[0],c[1])].join(\" \")),K(n,i)}function et(){if(d.removeZoombox(r),null!==D&&null!==F){var t={};rt(t),d.showDoubleClickNotifier(r),a.call(\"_guiRelayout\",r,t)}}function rt(t){var r=T._rl,n=(r[1]-r[0])/(1-h/u)/u,i=[r[0]+(D-h)*n,r[0]+(F-h)*n];t[e.id+\".radialaxis.range\"]=i}function nt(t,n){var i=r._fullLayout.clickmode;if(d.removeZoombox(r),2===t){var o={};for(var s in e.viewInitial)o[e.id+\".\"+s]=e.viewInitial[s];r.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",r,o)}i.indexOf(\"select\")>-1&&1===t&&x(n,r,[e.xaxis],[e.yaxis],e.id,q),i.indexOf(\"event\")>-1&&v.click(r,n,e.id)}q.prepFn=function(t,n,a){var o=r._fullLayout.dragmode,l=O.getBoundingClientRect();if(z=n-l.left,I=a-l.top,k){var c=M.findPolygonOffset(u,w[0],w[1],k);z+=m+c[0],I+=_+c[1]}switch(o){case\"zoom\":q.moveFn=k?tt:$,q.clickFn=nt,q.doneFn=et,function(){D=null,F=null,B=e.pathSubplot(),N=!1;var t=r._fullLayout[e.id];j=i(t.bgcolor).getLuminance(),(U=d.makeZoombox(s,j,f,p,B)).attr(\"fill-rule\",\"evenodd\"),V=d.makeCorners(s,f,p),b(r)}();break;case\"select\":case\"lasso\":y(t,n,a,q,o)}},O.onmousemove=function(t){v.hover(r,t,e.id),r._fullLayout._lasthover=O,r._fullLayout._hoversubplot=e.id},O.onmouseout=function(t){r._dragging||g.unhover(r,t)},g.init(q)},O.updateRadialDrag=function(t,e,r){var i=this,s=i.gd,l=i.layers,c=i.radius,u=i.innerRadius,h=i.cx,f=i.cy,p=i.radialAxis,v=A.radialDragBoxSize,m=v/2;if(p.visible){var y,x,_,T=C(i.radialAxisAngle),M=p._rl,S=M[0],E=M[1],P=M[r],O=.75*(M[1]-M[0])/(1-e.hole)/c;r?(y=h+(c+m)*Math.cos(T),x=f-(c+m)*Math.sin(T),_=\"radialdrag\"):(y=h+(u-m)*Math.cos(T),x=f-(u-m)*Math.sin(T),_=\"radialdrag-inner\");var z,B,N,j=d.makeRectDragger(l,_,\"crosshair\",-m,-m,v,v),U={element:j,gd:s};D(n.select(j),p.visible&&u<c,{transform:R(y,x)}),U.prepFn=function(){z=null,B=null,N=null,U.moveFn=V,U.doneFn=q,b(s)},U.clampFn=function(t,e){return Math.sqrt(t*t+e*e)<A.MINDRAG&&(t=0,e=0),[t,e]},g.init(U)}function V(t,e){if(z)z(t,e);else{var n=[t,-e],a=[Math.cos(T),Math.sin(T)],l=Math.abs(o.dot(n,a)/Math.sqrt(o.dot(n,n)));isNaN(l)||(z=l<.5?H:G)}var c={};!function(t){null!==B?t[i.id+\".radialaxis.angle\"]=B:null!==N&&(t[i.id+\".radialaxis.range[\"+r+\"]\"]=N)}(c),s.emit(\"plotly_relayouting\",c)}function q(){null!==B?a.call(\"_guiRelayout\",s,i.id+\".radialaxis.angle\",B):null!==N&&a.call(\"_guiRelayout\",s,i.id+\".radialaxis.range[\"+r+\"]\",N)}function H(t,e){if(0!==r){var n=y+t,a=x+e;B=Math.atan2(f-a,n-h),i.vangles&&(B=I(B,i.vangles)),B=L(B);var o=R(h,f)+F(-B);l[\"radial-axis\"].attr(\"transform\",o),l[\"radial-line\"].select(\"line\").attr(\"transform\",o);var s=i.gd._fullLayout,c=s[i.id];i.updateRadialAxisTitle(s,c,B)}}function G(t,e){var n=o.dot([t,-e],[Math.cos(T),Math.sin(T)]);if(N=P-O*n,O>0==(r?N>S:N<E)){var l=s._fullLayout,c=l[i.id];p.range[r]=N,p._rl[r]=N,i.updateRadialAxis(l,c),i.xaxis.setRange(),i.xaxis.setScale(),i.yaxis.setRange(),i.yaxis.setScale();var u=!1;for(var h in i.traceHash){var f=i.traceHash[h],d=o.filterVisible(f);f[0][0].trace._module.plot(s,i,d,c),a.traceIs(h,\"gl\")&&d.length&&(u=!0)}u&&(w(s),k(s))}else N=null}},O.updateAngularDrag=function(t){var e=this,r=e.gd,i=e.layers,s=e.radius,c=e.angularAxis,u=e.cx,h=e.cy,f=e.cxx,p=e.cyy,v=A.angularDragBoxSize,m=d.makeDragger(i,\"path\",\"angulardrag\",\"move\"),y={element:m,gd:r};function x(t,e){return Math.atan2(p+v-e,t-f-v)}n.select(m).attr(\"d\",e.pathAnnulus(s,s+v)).attr(\"transform\",R(u,h)).call(_,\"move\");var T,M,S,E,C,P,O=i.frontplot.select(\".scatterlayer\").selectAll(\".trace\"),z=O.selectAll(\".point\"),I=O.selectAll(\".textpoint\");function D(t,s){var d=e.gd._fullLayout,g=d[e.id],v=x(T+t,M+s),m=L(v-P);if(E=S+m,i.frontplot.attr(\"transform\",R(e.xOffset2,e.yOffset2)+F([-m,f,p])),e.vangles){C=e.radialAxisAngle+m;var y=R(u,h)+F(-m),b=R(u,h)+F(-C);i.bg.attr(\"transform\",y),i[\"radial-grid\"].attr(\"transform\",y),i[\"radial-axis\"].attr(\"transform\",b),i[\"radial-line\"].select(\"line\").attr(\"transform\",b),e.updateRadialAxisTitle(d,g,C)}else e.clipPaths.forTraces.select(\"path\").attr(\"transform\",R(f,p)+F(m));z.each(function(){var t=n.select(this),e=l.getTranslate(t);t.attr(\"transform\",R(e.x,e.y)+F([m]))}),I.each(function(){var t=n.select(this),e=t.select(\"text\"),r=l.getTranslate(t);t.attr(\"transform\",F([m,e.attr(\"x\"),e.attr(\"y\")])+R(r.x,r.y))}),c.rotation=o.modHalf(E,360),e.updateAngularAxis(d,g),e._hasClipOnAxisFalse&&!o.isFullCircle(e.sectorInRad)&&O.call(l.hideOutsideRangePoints,e);var _=!1;for(var A in e.traceHash)if(a.traceIs(A,\"gl\")){var D=e.traceHash[A],N=o.filterVisible(D);D[0][0].trace._module.plot(r,e,N,g),N.length&&(_=!0)}_&&(w(r),k(r));var j={};B(j),r.emit(\"plotly_relayouting\",j)}function B(t){t[e.id+\".angularaxis.rotation\"]=E,e.vangles&&(t[e.id+\".radialaxis.angle\"]=C)}function N(){I.select(\"text\").attr(\"transform\",null);var t={};B(t),a.call(\"_guiRelayout\",r,t)}y.prepFn=function(n,i,a){var o=t[e.id];S=o.angularaxis.rotation;var s=m.getBoundingClientRect();T=i-s.left,M=a-s.top,P=x(T,M),y.moveFn=D,y.doneFn=N,b(r)},e.vangles&&!o.isFullCircle(e.sectorInRad)&&(y.prepFn=o.noop,_(n.select(m),null)),g.init(y)},O.isPtInside=function(t){var e=this.sectorInRad,r=this.vangles,n=this.angularAxis.c2g(t.theta),i=this.radialAxis,a=i.c2l(t.r),s=i._rl;return(r?M.isPtInsidePolygon:o.isPtInsideSector)(a,n,s,e,r)},O.pathArc=function(t){var e=this.sectorInRad,r=this.vangles;return(r?M.pathPolygon:o.pathArc)(t,e[0],e[1],r)},O.pathSector=function(t){var e=this.sectorInRad,r=this.vangles;return(r?M.pathPolygon:o.pathSector)(t,e[0],e[1],r)},O.pathAnnulus=function(t,e){var r=this.sectorInRad,n=this.vangles;return(n?M.pathPolygonAnnulus:o.pathAnnulus)(t,e,r[0],r[1],n)},O.pathSubplot=function(){var t=this.innerRadius,e=this.radius;return t?this.pathAnnulus(t,e):this.pathSector(e)},O.fillViewInitialKey=function(t,e){t in this.viewInitial||(this.viewInitial[t]=e)}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../components/titles\":681,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/clear_gl_canvases\":704,\"../../lib/setcursor\":739,\"../../plot_api/subroutines\":758,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../cartesian/autorange\":766,\"../cartesian/dragbox\":775,\"../cartesian/select\":784,\"../cartesian/set_convert\":785,\"../plots\":828,\"./constants\":829,\"./helpers\":830,\"./set_convert\":841,d3:163,tinycolor2:537}],841:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../cartesian/set_convert\"),a=n.deg2rad,o=n.rad2deg;e.exports=function(t,e,r){switch(i(t,r),t._id){case\"x\":case\"radialaxis\":!function(t,e){var r=e._subplot;t.setGeometry=function(){var e=t._rl[0],n=t._rl[1],i=r.innerRadius,a=(r.radius-i)/(n-e),o=i/a,s=e>n?function(t){return t<=0}:function(t){return t>=0};t.c2g=function(r){var n=t.c2l(r)-e;return(s(n)?n:0)+o},t.g2c=function(r){return t.l2c(r+e-o)},t.g2p=function(t){return t*a},t.c2p=function(e){return t.g2p(t.c2g(e))}}}(t,e);break;case\"angularaxis\":!function(t,e){var r=t.type;if(\"linear\"===r){var i=t.d2c,s=t.c2d;t.d2c=function(t,e){return function(t,e){return\"degrees\"===e?a(t):t}(i(t),e)},t.c2d=function(t,e){return s(function(t,e){return\"degrees\"===e?o(t):t}(t,e))}}t.makeCalcdata=function(e,i){var a,o,s=e[i],l=e._length,c=function(r){return t.d2c(r,e.thetaunit)};if(s){if(n.isTypedArray(s)&&\"linear\"===r){if(l===s.length)return s;if(s.subarray)return s.subarray(0,l)}for(a=new Array(l),o=0;o<l;o++)a[o]=c(s[o])}else{var u=i+\"0\",h=\"d\"+i,f=u in e?c(e[u]):0,p=e[h]?c(e[h]):(t.period||2*Math.PI)/l;for(a=new Array(l),o=0;o<l;o++)a[o]=f+o*p}return a},t.setGeometry=function(){var i,s,l,c,u=e.sector,h=u.map(a),f={clockwise:-1,counterclockwise:1}[t.direction],p=a(t.rotation),d=function(t){return f*t+p},g=function(t){return(t-p)/f};switch(r){case\"linear\":s=i=n.identity,c=a,l=o,t.range=n.isFullCircle(h)?[u[0],u[0]+360]:h.map(g).map(o);break;case\"category\":var v=t._categories.length,m=t.period?Math.max(t.period,v):v;0===m&&(m=1),s=c=function(t){return 2*t*Math.PI/m},i=l=function(t){return t*m/Math.PI/2},t.range=[0,m]}t.c2g=function(t){return d(s(t))},t.g2c=function(t){return i(g(t))},t.t2g=function(t){return d(c(t))},t.g2t=function(t){return l(g(t))}}}(t,e)}}},{\"../../lib\":719,\"../cartesian/set_convert\":785}],842:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\"),a=t(\"./domain\").defaults;e.exports=function(t,e,r,o){var s,l,c=o.type,u=o.attributes,h=o.handleDefaults,f=o.partition||\"x\",p=e._subplots[c],d=p.length,g=d&&p[0].replace(/\\d+$/,\"\");function v(t,e){return n.coerce(s,l,u,t,e)}for(var m=0;m<d;m++){var y=p[m];s=t[y]?t[y]:t[y]={},l=i.newContainer(e,y,g),v(\"uirevision\",e.uirevision);var x={};x[f]=[m/d,(m+1)/d],a(l,e,v,x),o.id=y,h(s,l,v,o)}}},{\"../lib\":719,\"../plot_api/plot_template\":757,\"./domain\":792}],843:[function(t,e,r){\"use strict\";var n=t(\"./ternary\"),i=t(\"../../plots/get_data\").getSubplotCalcData,a=t(\"../../lib\").counterRegex;r.name=\"ternary\";var o=r.attr=\"subplot\";r.idRoot=\"ternary\",r.idRegex=r.attrRegex=a(\"ternary\"),(r.attributes={})[o]={valType:\"subplotid\",dflt:\"ternary\",editType:\"calc\"},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t.calcdata,a=e._subplots.ternary,o=0;o<a.length;o++){var s=a[o],l=i(r,\"ternary\",s),c=e[s]._subplot;c||(c=new n({id:s,graphDiv:t,container:e._ternarylayer.node()},e),e[s]._subplot=c),c.plot(l,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.ternary||[],a=0;a<i.length;a++){var o=i[a],s=n[o]._subplot;!e[o]&&s&&(s.plotContainer.remove(),s.clipDef.remove(),s.clipDefRelative.remove(),s.layers[\"a-title\"].remove(),s.layers[\"b-title\"].remove(),s.layers[\"c-title\"].remove())}}},{\"../../lib\":719,\"../../plots/get_data\":802,\"./layout_attributes\":844,\"./layout_defaults\":845,\"./ternary\":846}],844:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"../cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../lib/extend\").extendFlat,l={title:a.title,color:a.color,tickmode:a.tickmode,nticks:s({},a.nticks,{dflt:6,min:1}),tick0:a.tick0,dtick:a.dtick,tickvals:a.tickvals,ticktext:a.ticktext,ticks:a.ticks,ticklen:a.ticklen,tickwidth:a.tickwidth,tickcolor:a.tickcolor,showticklabels:a.showticklabels,showtickprefix:a.showtickprefix,tickprefix:a.tickprefix,showticksuffix:a.showticksuffix,ticksuffix:a.ticksuffix,showexponent:a.showexponent,exponentformat:a.exponentformat,separatethousands:a.separatethousands,tickfont:a.tickfont,tickangle:a.tickangle,tickformat:a.tickformat,tickformatstops:a.tickformatstops,hoverformat:a.hoverformat,showline:s({},a.showline,{dflt:!0}),linecolor:a.linecolor,linewidth:a.linewidth,showgrid:s({},a.showgrid,{dflt:!0}),gridcolor:a.gridcolor,gridwidth:a.gridwidth,layer:a.layer,min:{valType:\"number\",dflt:0,min:0},_deprecated:{title:a._deprecated.title,titlefont:a._deprecated.titlefont}},c=e.exports=o({domain:i({name:\"ternary\"}),bgcolor:{valType:\"color\",dflt:n.background},sum:{valType:\"number\",dflt:1,min:0},aaxis:l,baxis:l,caxis:l},\"plot\",\"from-root\");c.uirevision={valType:\"any\",editType:\"none\"},c.aaxis.uirevision=c.baxis.uirevision=c.caxis.uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":592,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../cartesian/layout_attributes\":779,\"../domain\":792}],845:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../lib\"),o=t(\"../subplot_defaults\"),s=t(\"../cartesian/tick_label_defaults\"),l=t(\"../cartesian/tick_mark_defaults\"),c=t(\"../cartesian/tick_value_defaults\"),u=t(\"../cartesian/line_grid_defaults\"),h=t(\"./layout_attributes\"),f=[\"aaxis\",\"baxis\",\"caxis\"];function p(t,e,r,a){var o,s,l,c=r(\"bgcolor\"),u=r(\"sum\");a.bgColor=n.combine(c,a.paper_bgcolor);for(var h=0;h<f.length;h++)s=t[o=f[h]]||{},(l=i.newContainer(e,o))._name=o,d(s,l,a,e);var p=e.aaxis,g=e.baxis,v=e.caxis;p.min+g.min+v.min>=u&&(p.min=0,g.min=0,v.min=0,t.aaxis&&delete t.aaxis.min,t.baxis&&delete t.baxis.min,t.caxis&&delete t.caxis.min)}function d(t,e,r,n){var i=h[e._name];function o(r,n){return a.coerce(t,e,i,r,n)}o(\"uirevision\",n.uirevision),e.type=\"linear\";var f=o(\"color\"),p=f!==i.color.dflt?f:r.font.color,d=e._name.charAt(0).toUpperCase(),g=\"Component \"+d,v=o(\"title.text\",g);e._hovertitle=v===g?v:d,a.coerceFont(o,\"title.font\",{family:r.font.family,size:Math.round(1.2*r.font.size),color:p}),o(\"min\"),c(t,e,o,\"linear\"),s(t,e,o,\"linear\",{}),l(t,e,o,{outerTicks:!0}),o(\"showticklabels\")&&(a.coerceFont(o,\"tickfont\",{family:r.font.family,size:r.font.size,color:p}),o(\"tickangle\"),o(\"tickformat\")),u(t,e,o,{dfltColor:f,bgColor:r.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:i}),o(\"hoverformat\"),o(\"layer\")}e.exports=function(t,e,r){o(t,e,r,{type:\"ternary\",attributes:h,handleDefaults:p,font:e.font,paper_bgcolor:e.paper_bgcolor})}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../cartesian/line_grid_defaults\":781,\"../cartesian/tick_label_defaults\":786,\"../cartesian/tick_mark_defaults\":787,\"../cartesian/tick_value_defaults\":788,\"../subplot_defaults\":842,\"./layout_attributes\":844}],846:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=o._,l=t(\"../../components/color\"),c=t(\"../../components/drawing\"),u=t(\"../cartesian/set_convert\"),h=t(\"../../lib/extend\").extendFlat,f=t(\"../plots\"),p=t(\"../cartesian/axes\"),d=t(\"../../components/dragelement\"),g=t(\"../../components/fx\"),v=t(\"../../components/titles\"),m=t(\"../cartesian/select\").prepSelect,y=t(\"../cartesian/select\").selectOnClick,x=t(\"../cartesian/select\").clearSelect,b=t(\"../cartesian/constants\");function _(t,e){this.id=t.id,this.graphDiv=t.graphDiv,this.init(e),this.makeFramework(e),this.aTickLayout=null,this.bTickLayout=null,this.cTickLayout=null}e.exports=_;var w=_.prototype;w.init=function(t){this.container=t._ternarylayer,this.defs=t._defs,this.layoutId=t._uid,this.traceHash={},this.layers={}},w.plot=function(t,e){var r=e[this.id],n=e._size;this._hasClipOnAxisFalse=!1;for(var i=0;i<t.length;i++){if(!1===t[i][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(r),this.adjustLayout(r,n),f.generalUpdatePerTraceModule(this.graphDiv,this,t,r),this.layers.plotbg.select(\"path\").call(l.fill,r.bgcolor)},w.makeFramework=function(t){var e=this.graphDiv,r=t[this.id],n=this.clipId=\"clip\"+this.layoutId+this.id,i=this.clipIdRelative=\"clip-relative\"+this.layoutId+this.id;this.clipDef=o.ensureSingleById(t._clips,\"clipPath\",n,function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")}),this.clipDefRelative=o.ensureSingleById(t._clips,\"clipPath\",i,function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")}),this.plotContainer=o.ensureSingle(this.container,\"g\",this.id),this.updateLayers(r),c.setClipUrl(this.layers.backplot,n,e),c.setClipUrl(this.layers.grids,n,e)},w.updateLayers=function(t){var e=this.layers,r=[\"draglayer\",\"plotbg\",\"backplot\",\"grids\"];\"below traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"below traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"below traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\"),r.push(\"frontplot\"),\"above traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"above traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"above traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\");var i=this.plotContainer.selectAll(\"g.toplevel\").data(r,String),a=[\"agrid\",\"bgrid\",\"cgrid\"];i.enter().append(\"g\").attr(\"class\",function(t){return\"toplevel \"+t}).each(function(t){var r=n.select(this);e[t]=r,\"frontplot\"===t?r.append(\"g\").classed(\"scatterlayer\",!0):\"backplot\"===t?r.append(\"g\").classed(\"maplayer\",!0):\"plotbg\"===t?r.append(\"path\").attr(\"d\",\"M0,0Z\"):\"aline\"===t||\"bline\"===t||\"cline\"===t?r.append(\"path\"):\"grids\"===t&&a.forEach(function(t){e[t]=r.append(\"g\").classed(\"grid \"+t,!0)})}),i.order()};var k=Math.sqrt(4/3);w.adjustLayout=function(t,e){var r,n,i,a,o,s,f=this,p=t.domain,d=(p.x[0]+p.x[1])/2,g=(p.y[0]+p.y[1])/2,v=p.x[1]-p.x[0],m=p.y[1]-p.y[0],y=v*e.w,x=m*e.h,b=t.sum,_=t.aaxis.min,w=t.baxis.min,T=t.caxis.min;y>k*x?i=(a=x)*k:a=(i=y)/k,o=v*i/y,s=m*a/x,r=e.l+e.w*d-i/2,n=e.t+e.h*(1-g)-a/2,f.x0=r,f.y0=n,f.w=i,f.h=a,f.sum=b,f.xaxis={type:\"linear\",range:[_+2*T-b,b-_-2*w],domain:[d-o/2,d+o/2],_id:\"x\"},u(f.xaxis,f.graphDiv._fullLayout),f.xaxis.setScale(),f.xaxis.isPtWithinRange=function(t){return t.a>=f.aaxis.range[0]&&t.a<=f.aaxis.range[1]&&t.b>=f.baxis.range[1]&&t.b<=f.baxis.range[0]&&t.c>=f.caxis.range[1]&&t.c<=f.caxis.range[0]},f.yaxis={type:\"linear\",range:[_,b-w-T],domain:[g-s/2,g+s/2],_id:\"y\"},u(f.yaxis,f.graphDiv._fullLayout),f.yaxis.setScale(),f.yaxis.isPtWithinRange=function(){return!0};var A=f.yaxis.domain[0],M=f.aaxis=h({},t.aaxis,{range:[_,b-w-T],side:\"left\",tickangle:(+t.aaxis.tickangle||0)-30,domain:[A,A+s*k],anchor:\"free\",position:0,_id:\"y\",_length:i});u(M,f.graphDiv._fullLayout),M.setScale();var S=f.baxis=h({},t.baxis,{range:[b-_-T,w],side:\"bottom\",domain:f.xaxis.domain,anchor:\"free\",position:0,_id:\"x\",_length:i});u(S,f.graphDiv._fullLayout),S.setScale();var E=f.caxis=h({},t.caxis,{range:[b-_-w,T],side:\"right\",tickangle:(+t.caxis.tickangle||0)+30,domain:[A,A+s*k],anchor:\"free\",position:0,_id:\"y\",_length:i});u(E,f.graphDiv._fullLayout),E.setScale();var C=\"M\"+r+\",\"+(n+a)+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";f.clipDef.select(\"path\").attr(\"d\",C),f.layers.plotbg.select(\"path\").attr(\"d\",C);var L=\"M0,\"+a+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";f.clipDefRelative.select(\"path\").attr(\"d\",L);var P=\"translate(\"+r+\",\"+n+\")\";f.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",P),f.clipDefRelative.select(\"path\").attr(\"transform\",null);var O=\"translate(\"+(r-S._offset)+\",\"+(n+a)+\")\";f.layers.baxis.attr(\"transform\",O),f.layers.bgrid.attr(\"transform\",O);var z=\"translate(\"+(r+i/2)+\",\"+n+\")rotate(30)translate(0,\"+-M._offset+\")\";f.layers.aaxis.attr(\"transform\",z),f.layers.agrid.attr(\"transform\",z);var I=\"translate(\"+(r+i/2)+\",\"+n+\")rotate(-30)translate(0,\"+-E._offset+\")\";f.layers.caxis.attr(\"transform\",I),f.layers.cgrid.attr(\"transform\",I),f.drawAxes(!0),f.layers.aline.select(\"path\").attr(\"d\",M.showline?\"M\"+r+\",\"+(n+a)+\"l\"+i/2+\",-\"+a:\"M0,0\").call(l.stroke,M.linecolor||\"#000\").style(\"stroke-width\",(M.linewidth||0)+\"px\"),f.layers.bline.select(\"path\").attr(\"d\",S.showline?\"M\"+r+\",\"+(n+a)+\"h\"+i:\"M0,0\").call(l.stroke,S.linecolor||\"#000\").style(\"stroke-width\",(S.linewidth||0)+\"px\"),f.layers.cline.select(\"path\").attr(\"d\",E.showline?\"M\"+(r+i/2)+\",\"+n+\"l\"+i/2+\",\"+a:\"M0,0\").call(l.stroke,E.linecolor||\"#000\").style(\"stroke-width\",(E.linewidth||0)+\"px\"),f.graphDiv._context.staticPlot||f.initInteractions(),c.setClipUrl(f.layers.frontplot,f._hasClipOnAxisFalse?null:f.clipId,f.graphDiv)},w.drawAxes=function(t){var e=this.graphDiv,r=this.id.substr(7)+\"title\",n=this.layers,i=this.aaxis,a=this.baxis,o=this.caxis;if(this.drawAx(i),this.drawAx(a),this.drawAx(o),t){var l=Math.max(i.showticklabels?i.tickfont.size/2:0,(o.showticklabels?.75*o.tickfont.size:0)+(\"outside\"===o.ticks?.87*o.ticklen:0)),c=(a.showticklabels?a.tickfont.size:0)+(\"outside\"===a.ticks?a.ticklen:0)+3;n[\"a-title\"]=v.draw(e,\"a\"+r,{propContainer:i,propName:this.id+\".aaxis.title\",placeholder:s(e,\"Click to enter Component A title\"),attributes:{x:this.x0+this.w/2,y:this.y0-i.title.font.size/3-l,\"text-anchor\":\"middle\"}}),n[\"b-title\"]=v.draw(e,\"b\"+r,{propContainer:a,propName:this.id+\".baxis.title\",placeholder:s(e,\"Click to enter Component B title\"),attributes:{x:this.x0-c,y:this.y0+this.h+.83*a.title.font.size+c,\"text-anchor\":\"middle\"}}),n[\"c-title\"]=v.draw(e,\"c\"+r,{propContainer:o,propName:this.id+\".caxis.title\",placeholder:s(e,\"Click to enter Component C title\"),attributes:{x:this.x0+this.w+c,y:this.y0+this.h+.83*o.title.font.size+c,\"text-anchor\":\"middle\"}})}},w.drawAx=function(t){var e,r=this.graphDiv,n=t._name,i=n.charAt(0),a=t._id,s=this.layers[n],l=i+\"tickLayout\",c=(e=t).ticks+String(e.ticklen)+String(e.showticklabels);this[l]!==c&&(s.selectAll(\".\"+a+\"tick\").remove(),this[l]=c),t.setScale();var u=p.calcTicks(t),h=p.clipEnds(t,u),f=p.makeTransFn(t),d=p.getTickSigns(t)[2],g=o.deg2rad(30),v=d*(t.linewidth||1)/2,m=d*t.ticklen,y=this.w,x=this.h,b=\"b\"===i?\"M0,\"+v+\"l\"+Math.sin(g)*m+\",\"+Math.cos(g)*m:\"M\"+v+\",0l\"+Math.cos(g)*m+\",\"+-Math.sin(g)*m,_={a:\"M0,0l\"+x+\",-\"+y/2,b:\"M0,0l-\"+y/2+\",-\"+x,c:\"M0,0l-\"+x+\",\"+y/2}[i];p.drawTicks(r,t,{vals:\"inside\"===t.ticks?h:u,layer:s,path:b,transFn:f,crisp:!1}),p.drawGrid(r,t,{vals:h,layer:this.layers[i+\"grid\"],path:_,transFn:f,crisp:!1}),p.drawLabels(r,t,{vals:u,layer:s,transFn:f,labelFns:p.makeLabelFns(t,0,30)})};var T=b.MINZOOM/2+.87,A=\"m-0.87,.5h\"+T+\"v3h-\"+(T+5.2)+\"l\"+(T/2+2.6)+\",-\"+(.87*T+4.5)+\"l2.6,1.5l-\"+T/2+\",\"+.87*T+\"Z\",M=\"m0.87,.5h-\"+T+\"v3h\"+(T+5.2)+\"l-\"+(T/2+2.6)+\",-\"+(.87*T+4.5)+\"l-2.6,1.5l\"+T/2+\",\"+.87*T+\"Z\",S=\"m0,1l\"+T/2+\",\"+.87*T+\"l2.6,-1.5l-\"+(T/2+2.6)+\",-\"+(.87*T+4.5)+\"l-\"+(T/2+2.6)+\",\"+(.87*T+4.5)+\"l2.6,1.5l\"+T/2+\",-\"+.87*T+\"Z\",E=\"m0.5,0.5h5v-2h-5v-5h-2v5h-5v2h5v5h2Z\",C=!0;function L(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}w.initInteractions=function(){var t,e,r,n,u,h,f,p,v,_,w=this,T=w.layers.plotbg.select(\"path\").node(),P=w.graphDiv,O=P._fullLayout._zoomlayer,z={element:T,gd:P,plotinfo:{id:w.id,xaxis:w.xaxis,yaxis:w.yaxis},subplot:w.id,prepFn:function(a,o,s){z.xaxes=[w.xaxis],z.yaxes=[w.yaxis];var c=P._fullLayout.dragmode;z.minDrag=\"lasso\"===c?1:void 0,\"zoom\"===c?(z.moveFn=N,z.clickFn=D,z.doneFn=j,function(a,o,s){var c=T.getBoundingClientRect();t=o-c.left,e=s-c.top,r={a:w.aaxis.range[0],b:w.baxis.range[1],c:w.caxis.range[1]},u=r,n=w.aaxis.range[1]-r.a,h=i(w.graphDiv._fullLayout[w.id].bgcolor).getLuminance(),f=\"M0,\"+w.h+\"L\"+w.w/2+\", 0L\"+w.w+\",\"+w.h+\"Z\",p=!1,v=O.append(\"path\").attr(\"class\",\"zoombox\").attr(\"transform\",\"translate(\"+w.x0+\", \"+w.y0+\")\").style({fill:h>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"d\",f),_=O.append(\"path\").attr(\"class\",\"zoombox-corners\").attr(\"transform\",\"translate(\"+w.x0+\", \"+w.y0+\")\").style({fill:l.background,stroke:l.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"d\",\"M0,0Z\"),x(P)}(0,o,s)):\"pan\"===c?(z.moveFn=U,z.clickFn=D,z.doneFn=V,r={a:w.aaxis.range[0],b:w.baxis.range[1],c:w.caxis.range[1]},u=r,x(P)):\"select\"!==c&&\"lasso\"!==c||m(a,o,s,z,c)}};function I(t){var e={};return e[w.id+\".aaxis.min\"]=t.a,e[w.id+\".baxis.min\"]=t.b,e[w.id+\".caxis.min\"]=t.c,e}function D(t,e){var r=P._fullLayout.clickmode;L(P),2===t&&(P.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",P,I({a:0,b:0,c:0}))),r.indexOf(\"select\")>-1&&1===t&&y(e,P,[w.xaxis],[w.yaxis],w.id,z),r.indexOf(\"event\")>-1&&g.click(P,e,w.id)}function R(t,e){return 1-e/w.h}function F(t,e){return 1-(t+(w.h-e)/Math.sqrt(3))/w.w}function B(t,e){return(t-(w.h-e)/Math.sqrt(3))/w.w}function N(i,a){var o=t+i,s=e+a,l=Math.max(0,Math.min(1,R(0,e),R(0,s))),c=Math.max(0,Math.min(1,F(t,e),F(o,s))),d=Math.max(0,Math.min(1,B(t,e),B(o,s))),g=(l/2+d)*w.w,m=(1-l/2-c)*w.w,y=(g+m)/2,x=m-g,T=(1-l)*w.h,C=T-x/k;x<b.MINZOOM?(u=r,v.attr(\"d\",f),_.attr(\"d\",\"M0,0Z\")):(u={a:r.a+l*n,b:r.b+c*n,c:r.c+d*n},v.attr(\"d\",f+\"M\"+g+\",\"+T+\"H\"+m+\"L\"+y+\",\"+C+\"L\"+g+\",\"+T+\"Z\"),_.attr(\"d\",\"M\"+t+\",\"+e+E+\"M\"+g+\",\"+T+A+\"M\"+m+\",\"+T+M+\"M\"+y+\",\"+C+S)),p||(v.transition().style(\"fill\",h>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),_.transition().style(\"opacity\",1).duration(200),p=!0),P.emit(\"plotly_relayouting\",I(u))}function j(){L(P),u!==r&&(a.call(\"_guiRelayout\",P,I(u)),C&&P.data&&P._context.showTips&&(o.notifier(s(P,\"Double-click to zoom back out\"),\"long\"),C=!1))}function U(t,e){var n=t/w.xaxis._m,i=e/w.yaxis._m,a=[(u={a:r.a-i,b:r.b+(n+i)/2,c:r.c-(n-i)/2}).a,u.b,u.c].sort(),o=a.indexOf(u.a),s=a.indexOf(u.b),l=a.indexOf(u.c);a[0]<0&&(a[1]+a[0]/2<0?(a[2]+=a[0]+a[1],a[0]=a[1]=0):(a[2]+=a[0]/2,a[1]+=a[0]/2,a[0]=0),u={a:a[o],b:a[s],c:a[l]},e=(r.a-u.a)*w.yaxis._m,t=(r.c-u.c-r.b+u.b)*w.xaxis._m);var h=\"translate(\"+(w.x0+t)+\",\"+(w.y0+e)+\")\";w.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",h);var f=\"translate(\"+-t+\",\"+-e+\")\";w.clipDefRelative.select(\"path\").attr(\"transform\",f),w.aaxis.range=[u.a,w.sum-u.b-u.c],w.baxis.range=[w.sum-u.a-u.c,u.b],w.caxis.range=[w.sum-u.a-u.b,u.c],w.drawAxes(!1),w._hasClipOnAxisFalse&&w.plotContainer.select(\".scatterlayer\").selectAll(\".trace\").call(c.hideOutsideRangePoints,w),P.emit(\"plotly_relayouting\",I(u))}function V(){a.call(\"_guiRelayout\",P,I(u))}T.onmousemove=function(t){g.hover(P,t,w.id),P._fullLayout._lasthover=T,P._fullLayout._hoversubplot=w.id},T.onmouseout=function(t){P._dragging||d.unhover(P,t)},d.init(z)}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../components/titles\":681,\"../../lib\":719,\"../../lib/extend\":710,\"../../registry\":847,\"../cartesian/axes\":767,\"../cartesian/constants\":773,\"../cartesian/select\":784,\"../cartesian/set_convert\":785,\"../plots\":828,d3:163,tinycolor2:537}],847:[function(t,e,r){\"use strict\";var n=t(\"./lib/loggers\"),i=t(\"./lib/noop\"),a=t(\"./lib/push_unique\"),o=t(\"./lib/is_plain_object\"),s=t(\"./lib/dom\").addStyleRule,l=t(\"./lib/extend\"),c=t(\"./plots/attributes\"),u=t(\"./plots/layout_attributes\"),h=l.extendFlat,f=l.extendDeepAll;function p(t){var e=t.name,i=t.categories,a=t.meta;if(r.modules[e])n.log(\"Type \"+e+\" already registered\");else{r.subplotsRegistry[t.basePlotModule.name]||function(t){var e=t.name;if(r.subplotsRegistry[e])return void n.log(\"Plot type \"+e+\" already registered.\");for(var i in m(t),r.subplotsRegistry[e]=t,r.componentsRegistry)b(i,t.name)}(t.basePlotModule);for(var o={},l=0;l<i.length;l++)o[i[l]]=!0,r.allCategories[i[l]]=!0;for(var c in r.modules[e]={_module:t,categories:o},a&&Object.keys(a).length&&(r.modules[e].meta=a),r.allTypes.push(e),r.componentsRegistry)y(c,e);t.layoutAttributes&&h(r.traceLayoutAttributes,t.layoutAttributes);var u=t.basePlotModule,f=u.name;if(\"mapbox\"===f){var p=u.constants.styleRules;for(var d in p)s(\".js-plotly-plot .plotly .mapboxgl-\"+d,p[d])}\"geo\"!==f&&\"mapbox\"!==f||void 0===typeof window||void 0!==window.PlotlyGeoAssets||(window.PlotlyGeoAssets={topojson:{}})}}function d(t){if(\"string\"!=typeof t.name)throw new Error(\"Component module *name* must be a string.\");var e=t.name;for(var n in r.componentsRegistry[e]=t,t.layoutAttributes&&(t.layoutAttributes._isLinkedToArray&&a(r.layoutArrayContainers,e),m(t)),r.modules)y(e,n);for(var i in r.subplotsRegistry)b(e,i);for(var o in r.transformsRegistry)x(e,o);t.schema&&t.schema.layout&&f(u,t.schema.layout)}function g(t){if(\"string\"!=typeof t.name)throw new Error(\"Transform module *name* must be a string.\");var e=\"Transform module \"+t.name,i=\"function\"==typeof t.transform,a=\"function\"==typeof t.calcTransform;if(!i&&!a)throw new Error(e+\" is missing a *transform* or *calcTransform* method.\");for(var s in i&&a&&n.log([e+\" has both a *transform* and *calcTransform* methods.\",\"Please note that all *transform* methods are executed\",\"before all *calcTransform* methods.\"].join(\" \")),o(t.attributes)||n.log(e+\" registered without an *attributes* object.\"),\"function\"!=typeof t.supplyDefaults&&n.log(e+\" registered without a *supplyDefaults* method.\"),r.transformsRegistry[t.name]=t,r.componentsRegistry)x(s,t.name)}function v(t){var e=t.name,n=e.split(\"-\")[0],i=t.dictionary,a=t.format,o=i&&Object.keys(i).length,s=a&&Object.keys(a).length,l=r.localeRegistry,c=l[e];if(c||(l[e]=c={}),n!==e){var u=l[n];u||(l[n]=u={}),o&&u.dictionary===c.dictionary&&(u.dictionary=i),s&&u.format===c.format&&(u.format=a)}o&&(c.dictionary=i),s&&(c.format=a)}function m(t){if(t.layoutAttributes){var e=t.layoutAttributes._arrayAttrRegexps;if(e)for(var n=0;n<e.length;n++)a(r.layoutArrayRegexes,e[n])}}function y(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.traces){var i=n.traces[e];i&&f(r.modules[e]._module.attributes,i)}}function x(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.transforms){var i=n.transforms[e];i&&f(r.transformsRegistry[e].attributes,i)}}function b(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.subplots){var i=r.subplotsRegistry[e],a=i.layoutAttributes,o=\"subplot\"===i.attr?i.name:i.attr;Array.isArray(o)&&(o=o[0]);var s=n.subplots[o];a&&s&&f(a,s)}}function _(t){return\"object\"==typeof t&&(t=t.type),t}r.modules={},r.allCategories={},r.allTypes=[],r.subplotsRegistry={},r.transformsRegistry={},r.componentsRegistry={},r.layoutArrayContainers=[],r.layoutArrayRegexes=[],r.traceLayoutAttributes={},r.localeRegistry={},r.apiMethodRegistry={},r.collectableSubplotTypes=null,r.register=function(t){if(r.collectableSubplotTypes=null,!t)throw new Error(\"No argument passed to Plotly.register.\");t&&!Array.isArray(t)&&(t=[t]);for(var e=0;e<t.length;e++){var n=t[e];if(!n)throw new Error(\"Invalid module was attempted to be registered!\");switch(n.moduleType){case\"trace\":p(n);break;case\"transform\":g(n);break;case\"component\":d(n);break;case\"locale\":v(n);break;case\"apiMethod\":var i=n.name;r.apiMethodRegistry[i]=n.fn;break;default:throw new Error(\"Invalid module was attempted to be registered!\")}}},r.getModule=function(t){var e=r.modules[_(t)];return!!e&&e._module},r.traceIs=function(t,e){if(\"various\"===(t=_(t)))return!1;var i=r.modules[t];return i||(t&&\"area\"!==t&&n.log(\"Unrecognized trace type \"+t+\".\"),i=r.modules[c.type.dflt]),!!i.categories[e]},r.getTransformIndices=function(t,e){for(var r=[],n=t.transforms||[],i=0;i<n.length;i++)n[i].type===e&&r.push(i);return r},r.hasTransform=function(t,e){for(var r=t.transforms||[],n=0;n<r.length;n++)if(r[n].type===e)return!0;return!1},r.getComponentMethod=function(t,e){var n=r.componentsRegistry[t];return n&&n[e]||i},r.call=function(){var t=arguments[0],e=[].slice.call(arguments,1);return r.apiMethodRegistry[t].apply(null,e)}},{\"./lib/dom\":708,\"./lib/extend\":710,\"./lib/is_plain_object\":720,\"./lib/loggers\":723,\"./lib/noop\":728,\"./lib/push_unique\":733,\"./plots/attributes\":764,\"./plots/layout_attributes\":819}],848:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=i.extendFlat,o=i.extendDeep;function s(t){var e;switch(t){case\"themes__thumb\":e={autosize:!0,width:150,height:150,title:{text:\"\"},showlegend:!1,margin:{l:5,r:5,t:5,b:5,pad:0},annotations:[]};break;case\"thumbnail\":e={title:{text:\"\"},hidesources:!0,showlegend:!1,borderwidth:0,bordercolor:\"\",margin:{l:1,r:1,t:1,b:1,pad:0},annotations:[]};break;default:e={}}return e}e.exports=function(t,e){var r;t.framework&&t.framework.isPolar&&(t=t.framework.getConfig());var i,l=t.data,c=t.layout,u=o([],l),h=o({},c,s(e.tileClass)),f=t._context||{};if(e.width&&(h.width=e.width),e.height&&(h.height=e.height),\"thumbnail\"===e.tileClass||\"themes__thumb\"===e.tileClass){h.annotations=[];var p=Object.keys(h);for(r=0;r<p.length;r++)i=p[r],[\"xaxis\",\"yaxis\",\"zaxis\"].indexOf(i.slice(0,5))>-1&&(h[p[r]].title={text:\"\"});for(r=0;r<u.length;r++){var d=u[r];d.showscale=!1,d.marker&&(d.marker.showscale=!1),n.traceIs(d,\"pie-like\")&&(d.textposition=\"none\")}}if(Array.isArray(e.annotations))for(r=0;r<e.annotations.length;r++)h.annotations.push(e.annotations[r]);var g=Object.keys(h).filter(function(t){return t.match(/^scene\\d*$/)});if(g.length){var v={};for(\"thumbnail\"===e.tileClass&&(v={title:{text:\"\"},showaxeslabels:!1,showticklabels:!1,linetickenable:!1}),r=0;r<g.length;r++){var m=h[g[r]];m.xaxis||(m.xaxis={}),m.yaxis||(m.yaxis={}),m.zaxis||(m.zaxis={}),a(m.xaxis,v),a(m.yaxis,v),a(m.zaxis,v),m._scene=null}}var y=document.createElement(\"div\");e.tileClass&&(y.className=e.tileClass);var x={gd:y,td:y,layout:h,data:u,config:{staticPlot:void 0===e.staticPlot||e.staticPlot,plotGlPixelRatio:void 0===e.plotGlPixelRatio?2:e.plotGlPixelRatio,displaylogo:e.displaylogo||!1,showLink:e.showLink||!1,showTips:e.showTips||!1,mapboxAccessToken:f.mapboxAccessToken}};return\"transparent\"!==e.setBackground&&(x.config.setBackground=e.setBackground||\"opaque\"),x.gd.defaultLayout=s(e.tileClass),x}},{\"../lib\":719,\"../registry\":847}],849:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/to_image\"),a=t(\"./filesaver\"),o=t(\"./helpers\");e.exports=function(t,e){var r;return n.isPlainObject(t)||(r=n.getGraphDiv(t)),(e=e||{}).format=e.format||\"png\",e.imageDataOnly=!0,new Promise(function(s,l){r&&r._snapshotInProgress&&l(new Error(\"Snapshotting already in progress.\")),n.isIE()&&\"svg\"!==e.format&&l(new Error(o.MSG_IE_BAD_FORMAT)),r&&(r._snapshotInProgress=!0);var c=i(t,e),u=e.filename||t.fn||\"newplot\";u+=\".\"+e.format,c.then(function(t){return r&&(r._snapshotInProgress=!1),a(t,u,e.format)}).then(function(t){s(t)}).catch(function(t){r&&(r._snapshotInProgress=!1),l(t)})})}},{\"../lib\":719,\"../plot_api/to_image\":760,\"./filesaver\":850,\"./helpers\":851}],850:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"./helpers\");e.exports=function(t,e,r){var a=document.createElement(\"a\"),o=\"download\"in a;return new Promise(function(s,l){var c,u;if(n.isIE9orBelow()&&l(new Error(\"IE < 10 unsupported\")),n.isSafari()){var h=\"svg\"===r?\",\":\";base64,\";return i.octetStream(h+encodeURIComponent(t)),s(e)}return n.isIE()?(c=i.createBlob(t,\"svg\"),window.navigator.msSaveBlob(c,e),c=null,s(e)):o?(c=i.createBlob(t,r),u=i.createObjectURL(c),a.href=u,a.download=e,document.body.appendChild(a),a.click(),document.body.removeChild(a),i.revokeObjectURL(u),c=null,s(e)):void l(new Error(\"download error\"))})}},{\"../lib\":719,\"./helpers\":851}],851:[function(t,e,r){\"use strict\";var n=t(\"../registry\");r.getDelay=function(t){return t._has&&(t._has(\"gl3d\")||t._has(\"gl2d\")||t._has(\"mapbox\"))?500:0},r.getRedrawFunc=function(t){return function(){var e=t._fullLayout||{};!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r||n.getComponentMethod(\"colorbar\",\"draw\")(t)}},r.encodeSVG=function(t){return\"data:image/svg+xml,\"+encodeURIComponent(t)};var i=window.URL||window.webkitURL;r.createObjectURL=function(t){return i.createObjectURL(t)},r.revokeObjectURL=function(t){return i.revokeObjectURL(t)},r.createBlob=function(t,e){if(\"svg\"===e)return new window.Blob([t],{type:\"image/svg+xml;charset=utf-8\"});var r=function(t){for(var e=t.length,r=new ArrayBuffer(e),n=new Uint8Array(r),i=0;i<e;i++)n[i]=t.charCodeAt(i);return r}(window.atob(t));return new window.Blob([r],{type:\"image/\"+e})},r.octetStream=function(t){document.location.href=\"data:application/octet-stream\"+t},r.IMAGE_URL_PREFIX=/^data:image\\/\\w+;base64,/,r.MSG_IE_BAD_FORMAT=\"Sorry IE does not support downloading from canvas. Try {format:'svg'} instead.\"},{\"../registry\":847}],852:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i={getDelay:n.getDelay,getRedrawFunc:n.getRedrawFunc,clone:t(\"./cloneplot\"),toSVG:t(\"./tosvg\"),svgToImg:t(\"./svgtoimg\"),toImage:t(\"./toimage\"),downloadImage:t(\"./download\")};e.exports=i},{\"./cloneplot\":848,\"./download\":849,\"./helpers\":851,\"./svgtoimg\":853,\"./toimage\":854,\"./tosvg\":855}],853:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"events\").EventEmitter,a=t(\"./helpers\");e.exports=function(t){var e=t.emitter||new i,r=new Promise(function(i,o){var s=window.Image,l=t.svg,c=t.format||\"png\";if(n.isIE()&&\"svg\"!==c){var u=new Error(a.MSG_IE_BAD_FORMAT);return o(u),t.promise?r:e.emit(\"error\",u)}var h,f,p=t.canvas,d=t.scale||1,g=t.width||300,v=t.height||150,m=d*g,y=d*v,x=p.getContext(\"2d\"),b=new s;\"svg\"===c||n.isIE9orBelow()||n.isSafari()?f=a.encodeSVG(l):(h=a.createBlob(l,\"svg\"),f=a.createObjectURL(h)),p.width=m,p.height=y,b.onload=function(){var r;switch(h=null,a.revokeObjectURL(f),\"svg\"!==c&&x.drawImage(b,0,0,m,y),c){case\"jpeg\":r=p.toDataURL(\"image/jpeg\");break;case\"png\":r=p.toDataURL(\"image/png\");break;case\"webp\":r=p.toDataURL(\"image/webp\");break;case\"svg\":r=f;break;default:var n=\"Image format is not jpeg, png, svg or webp.\";if(o(new Error(n)),!t.promise)return e.emit(\"error\",n)}i(r),t.promise||e.emit(\"success\",r)},b.onerror=function(r){if(h=null,a.revokeObjectURL(f),o(r),!t.promise)return e.emit(\"error\",r)},b.src=f});return t.promise?r:e}},{\"../lib\":719,\"./helpers\":851,events:104}],854:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i=t(\"../registry\"),a=t(\"../lib\"),o=t(\"./helpers\"),s=t(\"./cloneplot\"),l=t(\"./tosvg\"),c=t(\"./svgtoimg\");e.exports=function(t,e){var r=new n,u=s(t,{format:\"png\"}),h=u.gd;h.style.position=\"absolute\",h.style.left=\"-5000px\",document.body.appendChild(h);var f=o.getRedrawFunc(h);return i.call(\"plot\",h,u.data,u.layout,u.config).then(f).then(function(){var t=o.getDelay(h._fullLayout);setTimeout(function(){var t=l(h),n=document.createElement(\"canvas\");n.id=a.randstr(),(r=c({format:e.format,width:h._fullLayout.width,height:h._fullLayout.height,canvas:n,emitter:r,svg:t})).clean=function(){h&&document.body.removeChild(h)}},t)}).catch(function(t){r.emit(\"error\",t)}),r}},{\"../lib\":719,\"../registry\":847,\"./cloneplot\":848,\"./helpers\":851,\"./svgtoimg\":853,\"./tosvg\":855,events:104}],855:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=t(\"../components/drawing\"),o=t(\"../components/color\"),s=t(\"../constants/xmlns_namespaces\"),l=/\"/g,c=new RegExp('(\"TOBESTRIPPED)|(TOBESTRIPPED\")',\"g\");e.exports=function(t,e,r){var u,h=t._fullLayout,f=h._paper,p=h._toppaper,d=h.width,g=h.height;f.insert(\"rect\",\":first-child\").call(a.setRect,0,0,d,g).call(o.fill,h.paper_bgcolor);var v=h._basePlotModules||[];for(u=0;u<v.length;u++){var m=v[u];m.toSVG&&m.toSVG(t)}if(p){var y=p.node().childNodes,x=Array.prototype.slice.call(y);for(u=0;u<x.length;u++){var b=x[u];b.childNodes.length&&f.node().appendChild(b)}}h._draggers&&h._draggers.remove(),f.node().style.background=\"\",f.selectAll(\"text\").attr({\"data-unformatted\":null,\"data-math\":null}).each(function(){var t=n.select(this);if(\"hidden\"!==this.style.visibility&&\"none\"!==this.style.display){t.style({visibility:null,display:null});var e=this.style.fontFamily;e&&-1!==e.indexOf('\"')&&t.style(\"font-family\",e.replace(l,\"TOBESTRIPPED\"))}else t.remove()}),f.selectAll(\".point, .scatterpts, .legendfill>path, .legendlines>path, .cbfill\").each(function(){var t=n.select(this),e=this.style.fill;e&&-1!==e.indexOf(\"url(\")&&t.style(\"fill\",e.replace(l,\"TOBESTRIPPED\"));var r=this.style.stroke;r&&-1!==r.indexOf(\"url(\")&&t.style(\"stroke\",r.replace(l,\"TOBESTRIPPED\"))}),\"pdf\"!==e&&\"eps\"!==e||f.selectAll(\"#MathJax_SVG_glyphs path\").attr(\"stroke-width\",0),f.node().setAttributeNS(s.xmlns,\"xmlns\",s.svg),f.node().setAttributeNS(s.xmlns,\"xmlns:xlink\",s.xlink),\"svg\"===e&&r&&(f.attr(\"width\",r*d),f.attr(\"height\",r*g),f.attr(\"viewBox\",\"0 0 \"+d+\" \"+g));var _=(new window.XMLSerializer).serializeToString(f.node());return _=function(t){var e=n.select(\"body\").append(\"div\").style({display:\"none\"}).html(\"\"),r=t.replace(/(&[^;]*;)/gi,function(t){return\"&lt;\"===t?\"&#60;\":\"&rt;\"===t?\"&#62;\":-1!==t.indexOf(\"<\")||-1!==t.indexOf(\">\")?\"\":e.html(t).text()});return e.remove(),r}(_),_=(_=_.replace(/&(?!\\w+;|\\#[0-9]+;| \\#x[0-9A-F]+;)/g,\"&amp;\")).replace(c,\"'\"),i.isIE()&&(_=(_=(_=_.replace(/\"/gi,\"'\")).replace(/(\\('#)([^']*)('\\))/gi,'(\"#$2\")')).replace(/(\\\\')/gi,'\"')),_}},{\"../components/color\":593,\"../components/drawing\":614,\"../constants/xmlns_namespaces\":696,\"../lib\":719,d3:163}],856:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\",!0),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":719}],857:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/font_attributes\"),s=t(\"./constants.js\"),l=t(\"../../lib/extend\").extendFlat,c=o({editType:\"calc\",arrayOk:!0,colorEditType:\"style\"}),u=l({},n.marker.line.width,{dflt:0}),h=l({width:u,editType:\"calc\"},a(\"marker.line\")),f=l({line:h,editType:\"calc\"},a(\"marker\"),{opacity:{valType:\"number\",arrayOk:!0,dflt:1,min:0,max:1,editType:\"style\"}});e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,text:n.text,hovertext:n.hovertext,hovertemplate:i({},{keys:s.eventDataKeys}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"none\",arrayOk:!0,editType:\"calc\"},insidetextanchor:{valType:\"enumerated\",values:[\"end\",\"middle\",\"start\"],dflt:\"end\",editType:\"plot\"},textangle:{valType:\"angle\",dflt:\"auto\",editType:\"plot\"},textfont:l({},c,{}),insidetextfont:l({},c,{}),outsidetextfont:l({},c,{}),constraintext:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"both\",\"none\"],dflt:\"both\",editType:\"calc\"},cliponaxis:l({},n.cliponaxis,{}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},base:{valType:\"any\",dflt:null,arrayOk:!0,editType:\"calc\"},offset:{valType:\"number\",dflt:null,arrayOk:!0,editType:\"calc\"},width:{valType:\"number\",dflt:null,min:0,arrayOk:!0,editType:\"calc\"},marker:f,offsetgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},alignmentgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},selected:{marker:{opacity:n.selected.marker.opacity,color:n.selected.marker.color,editType:\"style\"},textfont:n.selected.textfont,editType:\"style\"},unselected:{marker:{opacity:n.unselected.marker.opacity,color:n.unselected.marker.color,editType:\"style\"},textfont:n.unselected.textfont,editType:\"style\"},r:n.r,t:n.t,_deprecated:{bardir:{valType:\"enumerated\",editType:\"calc\",values:[\"v\",\"h\"]}}}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"../scatter/attributes\":1112,\"./constants.js\":859}],858:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),o=t(\"./arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\");e.exports=function(t,e){var r,l,c=n.getFromId(t,e.xaxis||\"x\"),u=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=c.makeCalcdata(e,\"x\"),l=u.makeCalcdata(e,\"y\")):(r=u.makeCalcdata(e,\"y\"),l=c.makeCalcdata(e,\"x\"));for(var h=Math.min(l.length,r.length),f=new Array(h),p=0;p<h;p++)f[p]={p:l[p],s:r[p]},e.ids&&(f[p].id=String(e.ids[p]));return i(e,\"marker\")&&a(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),i(e,\"marker.line\")&&a(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),o(f,e),s(f,e),f}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"../../plots/cartesian/axes\":767,\"../scatter/calc_selection\":1114,\"./arrays_to_calcdata\":856}],859:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[]}},{}],860:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,c=t(\"./sieve.js\");function u(t,e,r,o,u){if(o.length){var b,_,w,k;switch(function(t,e){var r,a;for(r=0;r<e.length;r++){var o,s=e[r],l=s[0].trace,c=\"funnel\"===l.type?l._base:l.base,u=\"h\"===l.orientation?l.xcalendar:l.ycalendar,h=\"category\"===t.type||\"multicategory\"===t.type?function(){return null}:t.d2c;if(i(c)){for(a=0;a<Math.min(c.length,s.length);a++)o=h(c[a],0,u),n(o)?(s[a].b=+o,s[a].hasB=1):s[a].b=0;for(;a<s.length;a++)s[a].b=0}else{o=h(c,0,u);var f=n(o);for(o=f?o:0,a=0;a<s.length;a++)s[a].b=o,f&&(s[a].hasB=1)}}}(r,o),u.mode){case\"overlay\":h(e,r,o,u);break;case\"group\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(k=o[w])[0].trace.offset?_.push(k):b.push(k);_.length&&function(t,e,r,n,i){var o=new c(n,{sepNegVal:!1,overlapNoMerge:!i.norm});(function(t,e,r,n){for(var i=t._fullLayout,a=r.positions,o=r.distinctPositions,s=r.minDiff,c=r.traces,u=c.length,h=a.length!==o.length,f=s*(1-n.gap),v=l(i,e._id)+c[0][0].trace.orientation,m=i._alignmentOpts[v]||{},y=0;y<u;y++){var x,b,_=c[y],w=_[0].trace,k=m[w.alignmentgroup]||{},T=Object.keys(k.offsetGroups||{}).length,A=(x=T?f/T:h?f/u:f)*(1-(n.groupgap||0));b=T?((2*w._offsetIndex+1-T)*x-A)/2:h?((2*y+1-u)*x-A)/2:-A/2;var M=_[0].t;M.barwidth=A,M.poffset=b,M.bargroupwidth=f,M.bardelta=s}r.binWidth=c[0][0].t.barwidth/100,p(r),d(e,r),g(e,r,h)})(t,e,o,i),function(t){for(var e=t.traces,r=0;r<e.length;r++){var n=e[r],i=n[0].trace;if(void 0===i.base)for(var o=new c([n],{sepNegVal:!0,overlapNoMerge:!0}),s=0;s<n.length;s++){var l=n[s];if(l.p!==a){var u=o.put(l.p,l.b+l.s);u&&(l.b=u)}}}}(o),i.norm?(m(o),y(r,o,i)):v(r,o)}(t,e,r,_,u),b.length&&h(e,r,b,u);break;case\"stack\":case\"relative\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(k=o[w])[0].trace.base?_.push(k):b.push(k);_.length&&function(t,e,r,n,i){var o=new c(n,{sepNegVal:\"relative\"===i.mode,overlapNoMerge:!(i.norm||\"stack\"===i.mode||\"relative\"===i.mode)});f(e,o,i),function(t,e,r){var n,i,o,l,c,u,h=x(t),f=e.traces;for(l=0;l<f.length;l++)if(n=f[l],\"funnel\"===(i=n[0].trace).type)for(c=0;c<n.length;c++)(u=n[c]).s!==a&&e.put(u.p,-.5*u.s);for(l=0;l<f.length;l++){n=f[l],i=n[0].trace,o=\"funnel\"===i.type;var p=[];for(c=0;c<n.length;c++)if((u=n[c]).s!==a){var d;d=o?u.s:u.s+u.b;var g=e.put(u.p,d),v=g+d;u.b=g,u[h]=v,r.norm||(p.push(v),u.hasB&&p.push(g))}r.norm||(i._extremes[t._id]=s.findExtremes(t,p,{tozero:!0,padded:!0}))}}(r,o,i);for(var l=0;l<n.length;l++)for(var u=n[l],h=0;h<u.length;h++){var p=u[h];if(p.s!==a){var d=p.b+p.s===o.get(p.p,p.s);d&&(p._outmost=!0)}}i.norm&&y(r,o,i)}(0,e,r,_,u),b.length&&h(e,r,b,u)}!function(t,e){var r,i,a,o=x(e),s={},l=1/0,c=-1/0;for(r=0;r<t.length;r++)for(a=t[r],i=0;i<a.length;i++){var u=a[i].p;n(u)&&(l=Math.min(l,u),c=Math.max(c,u))}var h=1e4/(c-l),f=s.round=function(t){return String(Math.round(h*(t-l)))};for(r=0;r<t.length;r++){(a=t[r])[0].t.extents=s;var p=a[0].t.poffset,d=Array.isArray(p);for(i=0;i<a.length;i++){var g=a[i],v=g[o]-g.w/2;if(n(v)){var m=g[o]+g.w/2,y=f(g.p);s[y]?s[y]=[Math.min(v,s[y][0]),Math.max(m,s[y][1])]:s[y]=[v,m]}g.p0=g.p+(d?p[i]:p),g.p1=g.p0+g.w,g.s0=g.b,g.s1=g.s0+g.s}}}(o,e)}}function h(t,e,r,n){for(var i=0;i<r.length;i++){var a=r[i],o=new c([a],{sepNegVal:!1,overlapNoMerge:!n.norm});f(t,o,n),n.norm?(m(o),y(e,o,n)):v(e,o)}}function f(t,e,r){for(var n=e.minDiff,i=e.traces,a=n*(1-r.gap),o=a*(1-(r.groupgap||0)),s=-o/2,l=0;l<i.length;l++){var c=i[l][0].t;c.barwidth=o,c.poffset=s,c.bargroupwidth=a,c.bardelta=n}e.binWidth=i[0][0].t.barwidth/100,p(e),d(t,e),g(t,e)}function p(t){var e,r,a=t.traces;for(e=0;e<a.length;e++){var o,s=a[e],l=s[0],c=l.trace,u=l.t,h=c._offset||c.offset,f=u.poffset;if(i(h)){for(o=Array.prototype.slice.call(h,0,s.length),r=0;r<o.length;r++)n(o[r])||(o[r]=f);for(r=o.length;r<s.length;r++)o.push(f);u.poffset=o}else void 0!==h&&(u.poffset=h);var p=c._width||c.width,d=u.barwidth;if(i(p)){var g=Array.prototype.slice.call(p,0,s.length);for(r=0;r<g.length;r++)n(g[r])||(g[r]=d);for(r=g.length;r<s.length;r++)g.push(d);if(u.barwidth=g,void 0===h){for(o=[],r=0;r<s.length;r++)o.push(f+(d-g[r])/2);u.poffset=o}}else void 0!==p&&(u.barwidth=p,void 0===h&&(u.poffset=f+(d-p)/2))}}function d(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++)for(var a=r[i],o=a[0].t,s=o.poffset,l=Array.isArray(s),c=o.barwidth,u=Array.isArray(c),h=0;h<a.length;h++){var f=a[h],p=f.w=u?c[h]:c;f[n]=f.p+(l?s[h]:s)+p/2}}function g(t,e,r){var n=e.traces,i=e.minDiff/2;s.minDtick(t,e.minDiff,e.distinctPositions[0],r);for(var a=0;a<n.length;a++){var o,l,c,u,h=n[a],f=h[0],p=f.trace,d=[];for(u=0;u<h.length;u++)l=(o=h[u]).p-i,c=o.p+i,d.push(l,c);if(p.width||p.offset){var g=f.t,v=g.poffset,m=g.barwidth,y=Array.isArray(v),x=Array.isArray(m);for(u=0;u<h.length;u++){o=h[u];var b=y?v[u]:v,_=x?m[u]:m;c=(l=o.p+b)+_,d.push(l,c)}}p._extremes[t._id]=s.findExtremes(t,d,{padded:!1})}}function v(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++){for(var a=r[i],o=a[0].trace,l=[],c=!0,u=0;u<a.length;u++){var h=a[u],f=h.b,p=f+h.s;h[n]=p,l.push(p),h.hasB&&l.push(f),h.hasB&&h.b>0&&h.s>0||(c=!1)}o._extremes[t._id]=s.findExtremes(t,l,{tozero:!c,padded:!0})}}function m(t){for(var e=t.traces,r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++){var o=n[i];o.s!==a&&t.put(o.p,o.b+o.s)}}function y(t,e,r){var i=e.traces,o=x(t),l=\"fraction\"===r.norm?1:100,c=l/1e9,u=t.l2c(t.c2l(0)),h=\"stack\"===r.mode?l:u;function f(e){return n(t.c2l(e))&&(e<u-c||e>h+c||!n(u))}for(var p=0;p<i.length;p++){for(var d=i[p],g=d[0].trace,v=[],m=!0,y=!1,b=0;b<d.length;b++){var _=d[b];if(_.s!==a){var w=Math.abs(l/e.get(_.p,_.s));_.b*=w,_.s*=w;var k=_.b,T=k+_.s;_[o]=T,v.push(T),y=y||f(T),_.hasB&&(v.push(k),y=y||f(k)),_.hasB&&_.b>0&&_.s>0||(m=!1)}}g._extremes[t._id]=s.findExtremes(t,v,{tozero:!m,padded:y})}}function x(t){return t._id.charAt(0)}e.exports={crossTraceCalc:function(t,e){for(var r=e.xaxis,n=e.yaxis,i=t._fullLayout,a=t._fullData,s=t.calcdata,l=[],c=[],h=0;h<a.length;h++){var f=a[h];!0===f.visible&&o.traceIs(f,\"bar\")&&f.xaxis===r._id&&f.yaxis===n._id&&(\"h\"===f.orientation?l.push(s[h]):c.push(s[h]))}var p={mode:i.barmode,norm:i.barnorm,gap:i.bargap,groupgap:i.bargroupgap};u(t,r,n,c,p),u(t,n,r,l,p)},setGroupPositions:u}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"./sieve.js\":869,\"fast-isnumeric\":225}],861:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../registry\"),o=t(\"../scatter/xy_defaults\"),s=t(\"./style_defaults\"),l=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,c=t(\"./attributes\"),u=n.coerceFont;function h(t,e,r,n){var i=e.orientation,a=e[{v:\"x\",h:\"y\"}[i]+\"axis\"],o=l(r,a)+i,s=r._alignmentOpts||{},c=n(\"alignmentgroup\"),u=s[o];u||(u=s[o]={});var h=u[c];h?h.traces.push(e):h=u[c]={traces:[e],alignmentIndex:Object.keys(u).length,offsetGroups:{}};var f=n(\"offsetgroup\"),p=h.offsetGroups,d=p[f];f&&(d||(d=p[f]={offsetIndex:Object.keys(p).length}),e._offsetIndex=d.offsetIndex)}function f(t,e,r,i,a,o){var s=!(!1===(o=o||{}).moduleHasSelected),l=!(!1===o.moduleHasUnselected),c=!(!1===o.moduleHasConstrain),h=!(!1===o.moduleHasCliponaxis),f=!(!1===o.moduleHasTextangle),p=!(!1===o.moduleHasInsideanchor),d=Array.isArray(a)||\"auto\"===a,g=d||\"inside\"===a,v=d||\"outside\"===a;if(g||v){var m=u(i,\"textfont\",r.font),y=n.extendFlat({},m);!(t.textfont&&t.textfont.color)&&delete y.color,u(i,\"insidetextfont\",y),v&&u(i,\"outsidetextfont\",m),s&&i(\"selected.textfont.color\"),l&&i(\"unselected.textfont.color\"),c&&i(\"constraintext\"),h&&i(\"cliponaxis\"),f&&i(\"textangle\")}g&&p&&i(\"insidetextanchor\")}e.exports={supplyDefaults:function(t,e,r,l){function u(r,i){return n.coerce(t,e,c,r,i)}if(o(t,e,l,u)){u(\"orientation\",e.x&&!e.y?\"h\":\"v\"),u(\"base\"),u(\"offset\"),u(\"width\"),u(\"text\"),u(\"hovertext\"),u(\"hovertemplate\");var h=u(\"textposition\");f(t,0,l,u,h,{moduleHasSelected:!0,moduleHasUnselected:!0,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),s(t,e,u,r,l);var p=(e.marker.line||{}).color,d=a.getComponentMethod(\"errorbars\",\"supplyDefaults\");d(t,e,p||i.defaultLine,{axis:\"y\"}),d(t,e,p||i.defaultLine,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,u)}else e.visible=!1},crossTraceDefaults:function(t,e){var r;function i(t){return n.coerce(r._input,r,c,t)}if(\"group\"===e.barmode)for(var a=0;a<t.length;a++)\"bar\"===(r=t[a]).type&&(r._input,h(0,r,e,i))},handleGroupingDefaults:h,handleText:f}},{\"../../components/color\":593,\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../scatter/xy_defaults\":1137,\"./attributes\":857,\"./style_defaults\":871}],862:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../../lib\").isArrayOrTypedArray;r.coerceString=function(t,e,r){if(\"string\"==typeof e){if(e||!t.noBlank)return e}else if((\"number\"==typeof e||!0===e)&&!t.strict)return String(e);return void 0!==r?r:t.dflt},r.coerceNumber=function(t,e,r){if(n(e)){e=+e;var i=t.min,a=t.max;if(!(void 0!==i&&e<i||void 0!==a&&e>a))return e}return void 0!==r?r:t.dflt},r.coerceColor=function(t,e,r){return i(e).isValid()?e:void 0!==r?r:t.dflt},r.coerceEnumerated=function(t,e,r){return t.coerceNumber&&(e=+e),-1!==t.values.indexOf(e)?e:void 0!==r?r:t.dflt},r.getValue=function(t,e){var r;return Array.isArray(t)?e<t.length&&(r=t[e]):r=t,r},r.getLineWidth=function(t,e){return 0<e.mlw?e.mlw:a(t.marker.line.width)?0:t.marker.line.width}},{\"../../lib\":719,\"fast-isnumeric\":225,tinycolor2:537}],863:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../../lib\").fillText,s=t(\"./helpers\").getLineWidth;function l(t,e,r,i){var a,s,l,c,u,h,f,p=t.cd,d=p[0].trace,g=p[0].t,v=\"closest\"===i,m=\"waterfall\"===d.type,y=t.maxHoverDistance,x=t.maxSpikeDistance;function b(t){return t[l]-t.w/2}function _(t){return t[l]+t.w/2}var w=v?b:function(t){return Math.min(b(t),t.p-g.bardelta/2)},k=v?_:function(t){return Math.max(_(t),t.p+g.bardelta/2)};function T(t,e){return n.inbox(t-a,e-a,y+Math.min(1,Math.abs(e-t)/f)-1)}function A(t){return T(w(t),k(t))}function M(t){var e=s,r=t.b,i=t[c];return m&&(i+=Math.abs(t.rawS||0)),n.inbox(r-e,i-e,y+(i-e)/(i-r)-1)}\"h\"===d.orientation?(a=r,s=e,l=\"y\",c=\"x\",u=M,h=A):(a=e,s=r,l=\"x\",c=\"y\",h=M,u=A);var S=t[l+\"a\"],E=t[c+\"a\"];f=Math.abs(S.r2c(S.range[1])-S.r2c(S.range[0]));var C=n.getDistanceFunction(i,u,h,function(t){return(u(t)+h(t))/2});if(n.getClosest(p,C,t),!1!==t.index){v||(w=function(t){return Math.min(b(t),t.p-g.bargroupwidth/2)},k=function(t){return Math.max(_(t),t.p+g.bargroupwidth/2)});var L=p[t.index],P=d.base?L.b+L.s:L.s;t[c+\"0\"]=t[c+\"1\"]=E.c2p(L[c],!0),t[c+\"LabelVal\"]=P;var O=g.extents[g.extents.round(L.p)];return t[l+\"0\"]=S.c2p(v?w(L):O[0],!0),t[l+\"1\"]=S.c2p(v?k(L):O[1],!0),t[l+\"LabelVal\"]=L.p,t.spikeDistance=(M(L)+function(t){return T(b(t),_(t))}(L))/2+x-y,t[l+\"Spike\"]=S.c2p(L.p,!0),o(L,d,t),t.hovertemplate=d.hovertemplate,t}}function c(t,e){var r=e.mcc||t.marker.color,n=e.mlcc||t.marker.line.color,i=s(t,e);return a.opacity(r)?r:a.opacity(n)&&i?n:void 0}e.exports={hoverPoints:function(t,e,r,n){var a=l(t,e,r,n);if(a){var o=a.cd,s=o[0].trace,u=o[a.index];return a.color=c(s,u),i.getComponentMethod(\"errorbars\",\"hoverInfo\")(u,s,a),[a]}},hoverOnBars:l,getTraceColor:c}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"../../registry\":847,\"./helpers\":862}],864:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,colorbar:t(\"../scatter/marker_colorbar\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"bar\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"oriented\",\"errorBarsOK\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../scatter/marker_colorbar\":1129,\"./arrays_to_calcdata\":856,\"./attributes\":857,\"./calc\":858,\"./cross_trace_calc\":860,\"./defaults\":861,\"./hover\":863,\"./layout_attributes\":865,\"./layout_defaults\":866,\"./plot\":867,\"./select\":868,\"./style\":870}],865:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\",\"relative\"],dflt:\"group\",editType:\"calc\"},barnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},bargap:{valType:\"number\",min:0,max:1,editType:\"calc\"},bargroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],866:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\"),o=t(\"./layout_attributes\");e.exports=function(t,e,r){function s(r,n){return a.coerce(t,e,o,r,n)}for(var l=!1,c=!1,u=!1,h={},f=s(\"barmode\"),p=0;p<r.length;p++){var d=r[p];if(n.traceIs(d,\"bar\")&&d.visible){if(l=!0,\"group\"===f){var g=d.xaxis+d.yaxis;h[g]&&(u=!0),h[g]=!0}if(d.visible&&\"histogram\"===d.type)\"category\"!==i.getFromId({_fullLayout:e},d[\"v\"===d.orientation?\"xaxis\":\"yaxis\"]).type&&(c=!0)}}l?(\"overlay\"!==f&&s(\"barnorm\"),s(\"bargap\",c&&!u?0:.2),s(\"bargroupgap\")):delete e.barmode}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./layout_attributes\":865}],867:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../registry\"),u=t(\"../../plots/cartesian/axes\").tickText,h=t(\"./style\"),f=t(\"./helpers\"),p=t(\"./attributes\"),d=p.text,g=p.textposition,v=3;function m(t,e){return t<e?1:-1}function y(t){return\"auto\"===t?0:t}function x(t,e,r,n,i,a){var o=!!a.isHorizontal,s=!!a.constrained,l=a.angle||0,c=a.anchor||0,u=i.width,h=i.height,f=Math.abs(e-t),p=Math.abs(n-r),d=f>2*v&&p>2*v?v:0;f-=2*d,p-=2*d;var g=!1;if(!(\"auto\"===l)||u<=f&&h<=p||!(u>f||h>p)||(u>p||h>f)&&u<h==f<p||(g=!0),g){var x=p;p=f,f=x}var b=y(l),_=Math.abs(Math.sin(Math.PI/180*b)),w=Math.abs(Math.cos(Math.PI/180*b)),k=Math.max(f*w,p*_),T=Math.max(f*_,p*w),A=s?Math.min(k/u,T/h):Math.max(w,_);A=Math.min(1,A);var M=(t+e)/2,S=(r+n)/2;\"middle\"!==c&&(d+=.5*(A*(o!==g?h:u)*_+A*(o!==g?u:h)*w),o?(d*=m(t,e),M=\"start\"===c?t+d:e-d):(d*=m(r,n),S=\"start\"===c?r+d:n-d));return g&&(b+=90),{textX:(i.left+i.right)/2,textY:(i.top+i.bottom)/2,targetX:M,targetY:S,scale:A,rotate:b}}function b(t,e,r,n,i,a){var o,s=!!a.isHorizontal,l=!!a.constrained,c=a.angle||0,u=i.width,h=i.height,f=Math.abs(e-t),p=Math.abs(n-r);o=s?p>2*v?v:0:f>2*v?v:0;var d=1;l&&(d=s?Math.min(1,p/h):Math.min(1,f/u));var g=y(c);o+=.5*(d*(s?h:u)*Math.abs(Math.sin(Math.PI/180*g))+d*(s?u:h)*Math.abs(Math.cos(Math.PI/180*g)));var x=(t+e)/2,b=(r+n)/2;return s?x=e-o*m(e,t):b=n+o*m(r,n),{textX:(i.left+i.right)/2,textY:(i.top+i.bottom)/2,targetX:x,targetY:b,scale:d,rotate:g}}function _(t){var e,r=t.textX,n=t.textY,i=t.targetX,a=t.targetY,o=t.scale,s=t.rotate;return o<1?e=\"scale(\"+o+\") \":(o=1,e=\"\"),\"translate(\"+(i-o*r)+\" \"+(a-o*n)+\")\"+e+(s?\"rotate(\"+s+\" \"+r+\" \"+n+\") \":\"\")}e.exports={plot:function(t,e,r,p,y){var w=e.xaxis,k=e.yaxis,T=t._fullLayout;y||(y={mode:T.barmode,norm:T.barmode,gap:T.bargap,groupgap:T.bargroupgap});var A=a.makeTraceGroups(p,r,\"trace bars\").each(function(r){var c=n.select(this),p=r[0].trace,T=\"waterfall\"===p.type,A=\"funnel\"===p.type,M=\"bar\"===p.type||A,S=0;T&&p.connector.visible&&\"between\"===p.connector.mode&&(S=p.connector.line.width/2);var E=\"h\"===p.orientation,C=a.ensureSingle(c,\"g\",\"points\").selectAll(\"g.point\").data(a.identity);C.enter().append(\"g\").classed(\"point\",!0),C.exit().remove(),C.each(function(c,T){var A,C,L=n.select(this),P=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),n?[i,a]:[a,i]}(c,w,k,E),O=P[0][0],z=P[0][1],I=P[1][0],D=P[1][1],R=!(O!==z&&I!==D&&i(O)&&i(z)&&i(I)&&i(D));if(R&&M&&f.getLineWidth(p,c)&&(E?z-O==0:D-I==0)&&(R=!1),c.isBlank=R,S&&(E?(O-=m(O,z)*S,z+=m(O,z)*S):(I-=m(I,D)*S,D+=m(I,D)*S)),\"waterfall\"===p.type){if(!R){var F=p[c.dir].marker;A=F.line.width,C=F.color}}else A=f.getLineWidth(p,c),C=c.mc||p.marker.color;var B=n.round(A/2%1,2);function N(t){return 0===y.gap&&0===y.groupgap?n.round(Math.round(t)-B,2):t}if(!t._context.staticPlot){var j=s.opacity(C)<1||A>.01?N:function(t,e){return Math.abs(t-e)>=2?N(t):t>e?Math.ceil(t):Math.floor(t)};O=j(O,z),z=j(z,O),I=j(I,D),D=j(D,I)}a.ensureSingle(L,\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"d\",R?\"M0,0Z\":\"M\"+O+\",\"+I+\"V\"+D+\"H\"+z+\"V\"+I+\"Z\").call(l.setClipUrl,e.layerClipId,t),function(t,e,r,n,i,s,c,p,m,y){var w,k=e.xaxis,T=e.yaxis,A=t._fullLayout;function M(e,r,n){var i=a.ensureSingle(e,\"text\").text(r).attr({class:\"bartext bartext-\"+w,transform:\"\",\"text-anchor\":\"middle\",\"data-notex\":1}).call(l.font,n).call(o.convertToTspans,t);return i}var S=n[0].trace,E=\"h\"===S.orientation,C=function(t,e,r,n){var i,o=t[0].trace;return i=o.textinfo?function(t,e,r,n){var i=t[0].trace,o=\"h\"===i.orientation,s=\"waterfall\"===i.type,l=\"funnel\"===i.type;function c(t){var e=o?r:n;return u(e,+t,!0).text}var h,f,p=i.textinfo,d=t[e],g=p.split(\"+\"),v=[],m=function(t){return-1!==g.indexOf(t)};if(m(\"label\")&&v.push((f=t[e].p,u(o?n:r,f,!0).text)),m(\"text\")&&(0===(h=a.castOption(i,d.i,\"text\"))||h)&&v.push(h),s){var y=+d.rawS||d.s,x=d.v,b=x-y;m(\"initial\")&&v.push(c(b)),m(\"delta\")&&v.push(c(y)),m(\"final\")&&v.push(c(x))}if(l){m(\"value\")&&v.push(c(d.s));var _=0;m(\"percent initial\")&&_++,m(\"percent previous\")&&_++,m(\"percent total\")&&_++;var w=_>1;m(\"percent initial\")&&(h=a.formatPercent(d.begR),w&&(h+=\" of initial\"),v.push(h)),m(\"percent previous\")&&(h=a.formatPercent(d.difR),w&&(h+=\" of previous\"),v.push(h)),m(\"percent total\")&&(h=a.formatPercent(d.sumR),w&&(h+=\" of total\"),v.push(h))}return v.join(\"<br>\")}(t,e,r,n):f.getValue(o.text,e),f.coerceString(d,i)}(n,i,k,T);w=function(t,e){var r=f.getValue(t.textposition,e);return f.coerceEnumerated(g,r)}(S,i);var L=\"stack\"===y.mode||\"relative\"===y.mode,P=n[i],O=!L||P._outmost;if(C&&\"none\"!==w&&(!P.isBlank&&s!==c&&p!==m||\"auto\"!==w&&\"inside\"!==w)){var z=A.font,I=h.getBarColor(n[i],S),D=h.getInsideTextFont(S,i,z,I),R=h.getOutsideTextFont(S,i,z),F=r.datum();E?\"log\"===k.type&&F.s0<=0&&(s=k.range[0]<k.range[1]?0:k._length):\"log\"===T.type&&F.s0<=0&&(p=T.range[0]<T.range[1]?T._length:0);var B,N,j,U,V,q,H=Math.abs(c-s)-2*v,G=Math.abs(m-p)-2*v;if(\"outside\"===w&&(O||P.hasB||(w=\"inside\")),\"auto\"===w)if(O){w=\"inside\",B=M(r,C,D),N=l.bBox(B.node()),j=N.width,U=N.height;var Y=j>0&&U>0,W=j<=H&&U<=G,X=j<=G&&U<=H,Z=E?H>=j*(G/U):G>=U*(H/j);Y&&(W||X||Z)?w=\"inside\":(w=\"outside\",B.remove(),B=null)}else w=\"inside\";!B&&(B=M(r,C,\"outside\"===w?R:D),N=l.bBox(B.node()),j=N.width,U=N.height,j<=0||U<=0)?B.remove():(\"outside\"===w?(q=\"both\"===S.constraintext||\"outside\"===S.constraintext,V=_(b(s,c,p,m,N,{isHorizontal:E,constrained:q,angle:S.textangle}))):(q=\"both\"===S.constraintext||\"inside\"===S.constraintext,V=_(x(s,c,p,m,N,{isHorizontal:E,constrained:q,angle:S.textangle,anchor:S.insidetextanchor}))),B.attr(\"transform\",V))}else r.select(\"text\").remove()}(t,e,L,r,T,O,z,I,D,y),e.layerClipId&&l.hideOutsideRangePoint(c,L.select(\"text\"),w,k,p.xcalendar,p.ycalendar)});var L=!1===p.cliponaxis;l.setClipUrl(c,L?null:e.layerClipId,t)});c.getComponentMethod(\"errorbars\",\"plot\")(t,A,e)},getTransform:_,toMoveInsideBar:x,toMoveOutsideBar:b}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./attributes\":857,\"./helpers\":862,\"./style\":870,d3:163,\"fast-isnumeric\":225}],868:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=e.c2p(n?t.s0:t.p0,!0),o=e.c2p(n?t.s1:t.p1,!0),s=r.c2p(n?t.p0:t.s0,!0),l=r.c2p(n?t.p1:t.s1,!0);return i?[(a+o)/2,(s+l)/2]:n?[o,(s+l)/2]:[(a+o)/2,l]}e.exports=function(t,e){var r,i=t.cd,a=t.xaxis,o=t.yaxis,s=i[0].trace,l=\"funnel\"===s.type,c=\"h\"===s.orientation,u=[];if(!1===e)for(r=0;r<i.length;r++)i[r].selected=0;else for(r=0;r<i.length;r++){var h=i[r],f=\"ct\"in h?h.ct:n(h,a,o,c,l);e.contains(f,!1,r,t)?(u.push({pointNumber:r,x:a.c2d(h.x),y:o.c2d(h.y)}),h.selected=1):h.selected=0}return u}},{}],869:[function(t,e,r){\"use strict\";e.exports=a;var n=t(\"../../lib\").distinctVals,i=t(\"../../constants/numerical\").BADNUM;function a(t,e){this.traces=t,this.sepNegVal=e.sepNegVal,this.overlapNoMerge=e.overlapNoMerge;for(var r=1/0,a=[],o=0;o<t.length;o++){for(var s=t[o],l=0;l<s.length;l++){var c=s[l];c.p!==i&&a.push(c.p)}s[0]&&s[0].width1&&(r=Math.min(s[0].width1,r))}this.positions=a;var u=n(a);this.distinctPositions=u.vals,1===u.vals.length&&r!==1/0?this.minDiff=r:this.minDiff=Math.min(u.minDiff,r),this.binWidth=this.minDiff,this.bins={}}a.prototype.put=function(t,e){var r=this.getLabel(t,e),n=this.bins[r]||0;return this.bins[r]=n+e,n},a.prototype.get=function(t,e){var r=this.getLabel(t,e);return this.bins[r]||0},a.prototype.getLabel=function(t,e){return(e<0&&this.sepNegVal?\"v\":\"^\")+(this.overlapNoMerge?t:Math.round(t/this.binWidth))}},{\"../../constants/numerical\":695,\"../../lib\":719}],870:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../lib\"),s=t(\"../../registry\"),l=t(\"./attributes\"),c=l.textfont,u=l.insidetextfont,h=l.outsidetextfont,f=t(\"./helpers\");function p(t,e,r){a.pointStyle(t.selectAll(\"path\"),e,r),d(t,e,r)}function d(t,e,r){t.selectAll(\"text\").each(function(t){var i=n.select(this),o=g(i,t,e,r);a.font(i,o)})}function g(t,e,r,n){var i=n._fullLayout.font,a=r.textfont;if(t.classed(\"bartext-inside\")){var o=b(e,r);a=m(r,e.i,i,o)}else t.classed(\"bartext-outside\")&&(a=y(r,e.i,i));return a}function v(t,e,r){return x(c,t.textfont,e,r)}function m(t,e,r,n){var a=v(t,e,r);return(void 0===t._input.textfont||void 0===t._input.textfont.color||Array.isArray(t.textfont.color)&&void 0===t.textfont.color[e])&&(a={color:i.contrast(n),family:a.family,size:a.size}),x(u,t.insidetextfont,e,a)}function y(t,e,r){var n=v(t,e,r);return x(h,t.outsidetextfont,e,n)}function x(t,e,r,n){e=e||{};var i=f.getValue(e.family,r),a=f.getValue(e.size,r),o=f.getValue(e.color,r);return{family:f.coerceString(t.family,i,n.family),size:f.coerceNumber(t.size,a,n.size),color:f.coerceColor(t.color,o,n.color)}}function b(t,e){return\"waterfall\"===e.type?e[t.dir].marker.color:t.mc||e.marker.color}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.barlayer\").selectAll(\"g.trace\"),r=e.size(),i=t._fullLayout;e.style(\"opacity\",function(t){return t[0].trace.opacity}).each(function(t){(\"stack\"===i.barmode&&r>1||0===i.bargap&&0===i.bargroupgap&&!t[0].trace.marker.line.width)&&n.select(this).attr(\"shape-rendering\",\"crispEdges\")}),e.selectAll(\"g.points\").each(function(e){p(n.select(this),e[0].trace,t)}),s.getComponentMethod(\"errorbars\",\"style\")(e)},styleTextPoints:d,styleOnSelect:function(t,e,r){var i=e[0].trace;i.selectedpoints?function(t,e,r){a.selectedPointStyle(t.selectAll(\"path\"),e),function(t,e,r){t.each(function(t){var i,s=n.select(this);if(t.selected){i=o.extendFlat({},g(s,t,e,r));var l=e.selected.textfont&&e.selected.textfont.color;l&&(i.color=l),a.font(s,i)}else a.selectedTextStyle(s,e)})}(t.selectAll(\"text\"),e,r)}(r,i,t):(p(r,i,t),s.getComponentMethod(\"errorbars\",\"style\")(r))},getInsideTextFont:m,getOutsideTextFont:y,getBarColor:b}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../registry\":847,\"./attributes\":857,\"./helpers\":862,d3:163}],871:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s){r(\"marker.color\",o),i(t,\"marker\")&&a(t,e,s,r,{prefix:\"marker.\",cLetter:\"c\"}),r(\"marker.line.color\",n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,r,{prefix:\"marker.line.\",cLetter:\"c\"}),r(\"marker.line.width\"),r(\"marker.opacity\"),r(\"selected.marker.color\"),r(\"unselected.marker.color\")}},{\"../../components/color\":593,\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604}],872:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../scatterpolar/attributes\"),o=t(\"../bar/attributes\");e.exports={r:a.r,theta:a.theta,r0:a.r0,dr:a.dr,theta0:a.theta0,dtheta:a.dtheta,thetaunit:a.thetaunit,base:i({},o.base,{}),offset:i({},o.offset,{}),width:i({},o.width,{}),text:i({},o.text,{}),hovertext:i({},o.hovertext,{}),marker:o.marker,hoverinfo:a.hoverinfo,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../bar/attributes\":857,\"../scatterpolar/attributes\":1179}],873:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"../bar/arrays_to_calcdata\"),o=t(\"../bar/cross_trace_calc\").setGroupPositions,s=t(\"../scatter/calc_selection\"),l=t(\"../../registry\").traceIs,c=t(\"../../lib\").extendFlat;e.exports={calc:function(t,e){for(var r=t._fullLayout,o=e.subplot,l=r[o].radialaxis,c=r[o].angularaxis,u=l.makeCalcdata(e,\"r\"),h=c.makeCalcdata(e,\"theta\"),f=e._length,p=new Array(f),d=u,g=h,v=0;v<f;v++)p[v]={p:g[v],s:d[v]};function m(t){var r=e[t];void 0!==r&&(e[\"_\"+t]=Array.isArray(r)?c.makeCalcdata(e,t):c.d2c(r,e.thetaunit))}return\"linear\"===c.type&&(m(\"width\"),m(\"offset\")),n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),a(p,e),s(p,e),p},crossTraceCalc:function(t,e,r){for(var n=t.calcdata,i=[],a=0;a<n.length;a++){var s=n[a],u=s[0].trace;!0===u.visible&&l(u,\"bar\")&&u.subplot===r&&i.push(s)}var h=c({},e.radialaxis,{_id:\"x\"}),f=e.angularaxis;o(t,f,h,i,{mode:e.barmode,norm:e.barnorm,gap:e.bargap,groupgap:e.bargroupgap})}}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"../../lib\":719,\"../../registry\":847,\"../bar/arrays_to_calcdata\":856,\"../bar/cross_trace_calc\":860,\"../scatter/calc_selection\":1114}],874:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatterpolar/defaults\").handleRThetaDefaults,a=t(\"../bar/style_defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}i(t,e,s,l)?(l(\"thetaunit\"),l(\"base\"),l(\"offset\"),l(\"width\"),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),a(t,e,l,r,s),n.coerceSelectionMarkerOpacity(e,l)):e.visible=!1}},{\"../../lib\":719,\"../bar/style_defaults\":871,\"../scatterpolar/defaults\":1181,\"./attributes\":872}],875:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../bar/hover\").getTraceColor,o=i.fillText,s=t(\"../scatterpolar/hover\").makeHoverPointText,l=t(\"../../plots/polar/helpers\").isPtInsidePolygon;e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,h=t.subplot,f=h.radialAxis,p=h.angularAxis,d=h.vangles,g=d?l:i.isPtInsideSector,v=t.maxHoverDistance,m=p._period||2*Math.PI,y=Math.abs(f.g2p(Math.sqrt(e*e+r*r))),x=Math.atan2(r,e);f.range[0]>f.range[1]&&(x+=Math.PI);if(n.getClosest(c,function(t){return g(y,x,[t.rp0,t.rp1],[t.thetag0,t.thetag1],d)?v+Math.min(1,Math.abs(t.thetag1-t.thetag0)/m)-1+(t.rp1-y)/(t.rp1-t.rp0)-1:1/0},t),!1!==t.index){var b=c[t.index];t.x0=t.x1=b.ct[0],t.y0=t.y1=b.ct[1];var _=i.extendFlat({},b,{r:b.s,theta:b.p});return o(b,u,t),s(_,u,h,t),t.hovertemplate=u.hovertemplate,t.color=a(u,b),t.xLabelVal=t.yLabelVal=void 0,b.s<0&&(t.idealAlign=\"left\"),[t]}}},{\"../../components/fx\":632,\"../../lib\":719,\"../../plots/polar/helpers\":830,\"../bar/hover\":863,\"../scatterpolar/hover\":1182}],876:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"barpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"bar\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),colorbar:t(\"../scatter/marker_colorbar\"),style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),meta:{}}},{\"../../plots/polar\":831,\"../bar/select\":868,\"../bar/style\":870,\"../scatter/marker_colorbar\":1129,\"./attributes\":872,\"./calc\":873,\"./defaults\":874,\"./hover\":875,\"./layout_attributes\":877,\"./layout_defaults\":878,\"./plot\":879}],877:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},bargap:{valType:\"number\",dflt:.1,min:0,max:1,editType:\"calc\"}}},{}],878:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a,o={};function s(r,o){return n.coerce(t[a]||{},e[a],i,r,o)}for(var l=0;l<r.length;l++){var c=r[l];\"barpolar\"===c.type&&!0===c.visible&&(o[a=c.subplot]||(s(\"barmode\"),s(\"bargap\"),o[a]=1))}}},{\"../../lib\":719,\"./layout_attributes\":877}],879:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../components/drawing\"),s=t(\"../../plots/polar/helpers\");e.exports=function(t,e,r){var l=e.xaxis,c=e.yaxis,u=e.radialAxis,h=e.angularAxis,f=function(t){var e=t.cxx,r=t.cyy;if(t.vangles)return function(n,i,o,l){var c,u;a.angleDelta(o,l)>0?(c=o,u=l):(c=l,u=o);var h=s.findEnclosingVertexAngles(c,t.vangles)[0],f=s.findEnclosingVertexAngles(u,t.vangles)[1],p=[h,(c+u)/2,f];return s.pathPolygonAnnulus(n,i,c,u,p,e,r)};return function(t,n,i,o){return a.pathAnnulus(t,n,i,o,e,r)}}(e),p=e.layers.frontplot.select(\"g.barlayer\");a.makeTraceGroups(p,r,\"trace bars\").each(function(){var r=n.select(this),s=a.ensureSingle(r,\"g\",\"points\").selectAll(\"g.point\").data(a.identity);s.enter().append(\"g\").style(\"vector-effect\",\"non-scaling-stroke\").style(\"stroke-miterlimit\",2).classed(\"point\",!0),s.exit().remove(),s.each(function(t){var e,r=n.select(this),o=t.rp0=u.c2p(t.s0),s=t.rp1=u.c2p(t.s1),p=t.thetag0=h.c2g(t.p0),d=t.thetag1=h.c2g(t.p1);if(i(o)&&i(s)&&i(p)&&i(d)&&o!==s&&p!==d){var g=u.c2g(t.s1),v=(p+d)/2;t.ct=[l.c2p(g*Math.cos(v)),c.c2p(g*Math.sin(v))],e=f(o,s,p,d)}else e=\"M0,0Z\";a.ensureSingle(r,\"path\").attr(\"d\",e)}),o.setClipUrl(r,e._hasClipOnAxisFalse?e.clipIds.forTraces:null,t)})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../plots/polar/helpers\":830,d3:163,\"fast-isnumeric\":225}],880:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../bar/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../lib/extend\").extendFlat,l=n.marker,c=l.line;e.exports={y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},y0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},name:{valType:\"string\",editType:\"calc+clearAxisTypes\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),hovertemplate:o({}),whiskerwidth:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"calc\"},notched:{valType:\"boolean\",editType:\"calc\"},notchwidth:{valType:\"number\",min:0,max:.5,dflt:.25,editType:\"calc\"},boxpoints:{valType:\"enumerated\",values:[\"all\",\"outliers\",\"suspectedoutliers\",!1],dflt:\"outliers\",editType:\"calc\"},boxmean:{valType:\"enumerated\",values:[!0,\"sd\",!1],dflt:!1,editType:\"calc\"},jitter:{valType:\"number\",min:0,max:1,editType:\"calc\"},pointpos:{valType:\"number\",min:-2,max:2,editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},width:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},marker:{outliercolor:{valType:\"color\",dflt:\"rgba(0, 0, 0, 0)\",editType:\"style\"},symbol:s({},l.symbol,{arrayOk:!1,editType:\"plot\"}),opacity:s({},l.opacity,{arrayOk:!1,dflt:1,editType:\"style\"}),size:s({},l.size,{arrayOk:!1,editType:\"calc\"}),color:s({},l.color,{arrayOk:!1,editType:\"style\"}),line:{color:s({},c.color,{arrayOk:!1,dflt:a.defaultLine,editType:\"style\"}),width:s({},c.width,{arrayOk:!1,dflt:0,editType:\"style\"}),outliercolor:{valType:\"color\",editType:\"style\"},outlierwidth:{valType:\"number\",min:0,dflt:1,editType:\"style\"},editType:\"style\"},editType:\"plot\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,offsetgroup:i.offsetgroup,alignmentgroup:i.alignmentgroup,selected:{marker:n.selected.marker,editType:\"style\"},unselected:{marker:n.unselected.marker,editType:\"style\"},hoveron:{valType:\"flaglist\",flags:[\"boxes\",\"points\"],dflt:\"boxes+points\",editType:\"style\"}}},{\"../../components/color/attributes\":592,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../bar/attributes\":857,\"../scatter/attributes\":1112}],881:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=i._,o=t(\"../../plots/cartesian/axes\");function s(t,e,r){var n={text:\"tx\",hovertext:\"htx\"};for(var i in n)Array.isArray(e[i])&&(t[n[i]]=e[i][r])}function l(t,e){return t.v-e.v}function c(t){return t.v}e.exports=function(t,e){var r,u,h,f,p,d=t._fullLayout,g=o.getFromId(t,e.xaxis||\"x\"),v=o.getFromId(t,e.yaxis||\"y\"),m=[],y=\"violin\"===e.type?\"_numViolins\":\"_numBoxes\";\"h\"===e.orientation?(u=g,h=\"x\",f=v,p=\"y\"):(u=v,h=\"y\",f=g,p=\"x\");var x,b=u.makeCalcdata(e,h),_=function(t,e,r,a,o){if(e in t)return r.makeCalcdata(t,e);var s;s=e+\"0\"in t?t[e+\"0\"]:\"name\"in t&&(\"category\"===r.type||n(t.name)&&-1!==[\"linear\",\"log\"].indexOf(r.type)||i.isDateTime(t.name)&&\"date\"===r.type)?t.name:o;var l=\"multicategory\"===r.type?r.r2c_just_indices(s):r.d2c(s,0,t[e+\"calendar\"]);return a.map(function(){return l})}(e,p,f,b,d[y]),w=i.distinctVals(_),k=w.vals,T=w.minDiff/2,A=function(t,e){for(var r=t.length,n=new Array(r+1),i=0;i<r;i++)n[i]=t[i]-e;return n[r]=t[r-1]+e,n}(k,T),M=k.length,S=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=[];return e}(M);for(r=0;r<e._length;r++){var E=b[r];if(n(E)){var C=i.findBin(_[r],A);if(C>=0&&C<M){var L={v:E,i:r};s(L,e,r),S[C].push(L)}}}var P=\"all\"===(e.boxpoints||e.points)?i.identity:function(t){return t.v<x.lf||t.v>x.uf};for(r=0;r<M;r++)if(S[r].length>0){var O=S[r].sort(l),z=O.map(c),I=z.length;(x={}).pos=k[r],x.pts=O,x[p]=x.pos,x[h]=x.pts.map(function(t){return t.v}),x.min=z[0],x.max=z[I-1],x.mean=i.mean(z,I),x.sd=i.stdev(z,I,x.mean),x.q1=i.interp(z,.25),x.med=i.interp(z,.5),x.q3=i.interp(z,.75),x.lf=Math.min(x.q1,z[Math.min(i.findBin(2.5*x.q1-1.5*x.q3,z,!0)+1,I-1)]),x.uf=Math.max(x.q3,z[Math.max(i.findBin(2.5*x.q3-1.5*x.q1,z),0)]),x.lo=4*x.q1-3*x.q3,x.uo=4*x.q3-3*x.q1;var D=1.57*(x.q3-x.q1)/Math.sqrt(I);x.ln=x.med-D,x.un=x.med+D,x.pts2=O.filter(P),m.push(x)}!function(t,e){if(i.isArrayOrTypedArray(e.selectedpoints))for(var r=0;r<t.length;r++){for(var n=t[r].pts||[],a={},o=0;o<n.length;o++)a[n[o].i]=o;i.tagSelected(n,e,a)}}(m,e);var R=o.findExtremes(u,b,{padded:!0});return e._extremes[u._id]=R,m.length>0?(m[0].t={num:d[y],dPos:T,posLetter:p,valLetter:h,labels:{med:a(t,\"median:\"),min:a(t,\"min:\"),q1:a(t,\"q1:\"),q3:a(t,\"q3:\"),max:a(t,\"max:\"),mean:\"sd\"===e.boxmean?a(t,\"mean \\xb1 \\u03c3:\"):a(t,\"mean:\"),lf:a(t,\"lower fence:\"),uf:a(t,\"upper fence:\")}},d[y]++,m):[{t:{empty:!0}}]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"fast-isnumeric\":225}],882:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,o=[\"v\",\"h\"];function s(t,e,r,o){var s,l,c,u=e.calcdata,h=e._fullLayout,f=o._id,p=f.charAt(0),d=[],g=0;for(s=0;s<r.length;s++)for(c=u[r[s]],l=0;l<c.length;l++)d.push(c[l].pos),g+=(c[l].pts2||[]).length;if(d.length){var v=i.distinctVals(d),m=v.minDiff/2;n.minDtick(o,v.minDiff,v.vals[0],!0);var y=h[\"violin\"===t?\"_numViolins\":\"_numBoxes\"],x=\"group\"===h[t+\"mode\"]&&y>1,b=1-h[t+\"gap\"],_=1-h[t+\"groupgap\"];for(s=0;s<r.length;s++){var w,k,T,A,M,S,E=(c=u[r[s]])[0].trace,C=c[0].t,L=E.width,P=E.side;if(L)w=k=A=L/2,T=0;else if(w=m,x){var O=a(h,o._id)+E.orientation,z=(h._alignmentOpts[O]||{})[E.alignmentgroup]||{},I=Object.keys(z.offsetGroups||{}).length,D=I||y;k=w*b*_/D,T=2*w*(((I?E._offsetIndex:C.num)+.5)/D-.5)*b,A=w*b/D}else k=w*b*_,T=0,A=w;C.dPos=w,C.bPos=T,C.bdPos=k,C.wHover=A;var R,F,B,N,j,U,V=T+k,q=Boolean(L);if(\"positive\"===P?(M=w*(L?1:.5),R=V,S=R=T):\"negative\"===P?(M=R=T,S=w*(L?1:.5),F=V):(M=S=w,R=F=V),(E.boxpoints||E.points)&&g>0){var H=E.pointpos,G=E.jitter,Y=E.marker.size/2,W=0;H+G>=0&&((W=V*(H+G))>M?(q=!0,j=Y,B=W):W>R&&(j=Y,B=M)),W<=M&&(B=M);var X=0;H-G<=0&&((X=-V*(H-G))>S?(q=!0,U=Y,N=X):X>F&&(U=Y,N=S)),X<=S&&(N=S)}else B=M,N=S;var Z=new Array(c.length);for(l=0;l<c.length;l++)Z[l]=c[l].pos;E._extremes[f]=n.findExtremes(o,Z,{padded:q,vpadminus:N,vpadplus:B,ppadminus:{x:U,y:j}[p],ppadplus:{x:j,y:U}[p]})}}}e.exports={crossTraceCalc:function(t,e){for(var r=t.calcdata,n=e.xaxis,i=e.yaxis,a=0;a<o.length;a++){for(var l=o[a],c=\"h\"===l?i:n,u=[],h=0;h<r.length;h++){var f=r[h],p=f[0].t,d=f[0].trace;!0!==d.visible||\"box\"!==d.type&&\"candlestick\"!==d.type||p.empty||(d.orientation||\"v\")!==l||d.xaxis!==n._id||d.yaxis!==i._id||u.push(h)}s(\"box\",t,u,c)}},setPositionOffset:s}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_ids\":770}],883:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../bar/defaults\").handleGroupingDefaults,s=t(\"./attributes\");function l(t,e,r,a){var o,s,l=r(\"y\"),c=r(\"x\"),u=c&&c.length;if(l&&l.length)o=\"v\",u?s=Math.min(n.minRowLength(c),n.minRowLength(l)):(r(\"x0\"),s=n.minRowLength(l));else{if(!u)return void(e.visible=!1);o=\"h\",r(\"y0\"),s=n.minRowLength(c)}e._length=s,i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a),r(\"orientation\",o)}function c(t,e,r,i){var a=i.prefix,o=n.coerce2(t,e,s,\"marker.outliercolor\"),l=r(\"marker.line.outliercolor\"),c=r(a+\"points\",o||l?\"suspectedoutliers\":void 0);c?(r(\"jitter\",\"all\"===c?.3:0),r(\"pointpos\",\"all\"===c?-1.5:0),r(\"marker.symbol\"),r(\"marker.opacity\"),r(\"marker.size\"),r(\"marker.color\",e.line.color),r(\"marker.line.color\"),r(\"marker.line.width\"),\"suspectedoutliers\"===c&&(r(\"marker.line.outliercolor\",e.marker.color),r(\"marker.line.outlierwidth\")),r(\"selected.marker.color\"),r(\"unselected.marker.color\"),r(\"selected.marker.size\"),r(\"unselected.marker.size\"),r(\"text\"),r(\"hovertext\")):delete e.marker;var u=r(\"hoveron\");\"all\"!==u&&-1===u.indexOf(\"points\")||r(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,r)}e.exports={supplyDefaults:function(t,e,r,i){function o(r,i){return n.coerce(t,e,s,r,i)}l(t,e,o,i),!1!==e.visible&&(o(\"line.color\",(t.marker||{}).color||r),o(\"line.width\"),o(\"fillcolor\",a.addOpacity(e.line.color,.5)),o(\"whiskerwidth\"),o(\"boxmean\"),o(\"width\"),o(\"notched\",void 0!==t.notchwidth)&&o(\"notchwidth\"),c(t,e,o,{prefix:\"box\"}))},crossTraceDefaults:function(t,e){var r,i;function a(t){return n.coerce(i._input,i,s,t)}for(var l=0;l<t.length;l++){var c=(i=t[l]).type;\"box\"!==c&&\"violin\"!==c||(r=i._input,\"group\"===e[c+\"mode\"]&&o(r,i,e,a))}},handleSampleDefaults:l,handlePointsDefaults:c}},{\"../../components/color\":593,\"../../lib\":719,\"../../registry\":847,\"../bar/defaults\":861,\"./attributes\":880}],884:[function(t,e,r){\"use strict\";e.exports=function(t,e){return e.hoverOnBox&&(t.hoverOnBox=e.hoverOnBox),\"xVal\"in e&&(t.x=e.xVal),\"yVal\"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],885:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=i.fillText;function l(t,e,r,s){var l,c,u,h,f,p,d,g,v,m,y,x,b,_,w=t.cd,k=t.xa,T=t.ya,A=w[0].trace,M=w[0].t,S=\"violin\"===A.type,E=[],C=M.bdPos,L=M.wHover,P=function(t){return t.pos+M.bPos-p};S&&\"both\"!==A.side?(\"positive\"===A.side&&(v=function(t){var e=P(t);return a.inbox(e,e+L,m)},x=C,b=0),\"negative\"===A.side&&(v=function(t){var e=P(t);return a.inbox(e-L,e,m)},x=0,b=C)):(v=function(t){var e=P(t);return a.inbox(e-L,e+L,m)},x=b=C),_=S?function(t){return a.inbox(t.span[0]-f,t.span[1]-f,m)}:function(t){return a.inbox(t.min-f,t.max-f,m)},\"h\"===A.orientation?(f=e,p=r,d=_,g=v,l=\"y\",u=T,c=\"x\",h=k):(f=r,p=e,d=v,g=_,l=\"x\",u=k,c=\"y\",h=T);var O=Math.min(1,C/Math.abs(u.r2c(u.range[1])-u.r2c(u.range[0])));function z(t){return(d(t)+g(t))/2}m=t.maxHoverDistance-O,y=t.maxSpikeDistance-O;var I=a.getDistanceFunction(s,d,g,z);if(a.getClosest(w,I,t),!1===t.index)return[];var D=w[t.index],R=A.line.color,F=(A.marker||{}).color;o.opacity(R)&&A.line.width?t.color=R:o.opacity(F)&&A.boxpoints?t.color=F:t.color=A.fillcolor,t[l+\"0\"]=u.c2p(D.pos+M.bPos-b,!0),t[l+\"1\"]=u.c2p(D.pos+M.bPos+x,!0),t[l+\"LabelVal\"]=D.pos;var B=l+\"Spike\";t.spikeDistance=z(D)*y/m,t[B]=u.c2p(D.pos,!0);var N={},j=[\"med\",\"q1\",\"q3\",\"min\",\"max\"];(A.boxmean||(A.meanline||{}).visible)&&j.push(\"mean\"),(A.boxpoints||A.points)&&j.push(\"lf\",\"uf\");for(var U=0;U<j.length;U++){var V=j[U];if(V in D&&!(D[V]in N)){N[D[V]]=!0;var q=D[V],H=h.c2p(q,!0),G=i.extendFlat({},t);G.attr=V,G[c+\"0\"]=G[c+\"1\"]=H,G[c+\"LabelVal\"]=q,G[c+\"Label\"]=(M.labels?M.labels[V]+\" \":\"\")+n.hoverLabelText(h,q),G.hoverOnBox=!0,\"mean\"===V&&\"sd\"in D&&\"sd\"===A.boxmean&&(G[c+\"err\"]=D.sd),t.name=\"\",t.spikeDistance=void 0,t[B]=void 0,G.hovertemplate=!1,E.push(G)}}return E}function c(t,e,r){for(var n,o,l,c=t.cd,u=t.xa,h=t.ya,f=c[0].trace,p=u.c2p(e),d=h.c2p(r),g=a.quadrature(function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(u.c2p(t.x)-p)-e,1-3/e)},function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(h.c2p(t.y)-d)-e,1-3/e)}),v=!1,m=0;m<c.length;m++){o=c[m];for(var y=0;y<(o.pts||[]).length;y++){var x=g(l=o.pts[y]);x<=t.distance&&(t.distance=x,v=[m,y])}}if(!v)return!1;l=(o=c[v[0]]).pts[v[1]];var b,_=u.c2p(l.x,!0),w=h.c2p(l.y,!0),k=l.mrc||1;return n=i.extendFlat({},t,{index:l.i,color:(f.marker||{}).color,name:f.name,x0:_-k,x1:_+k,y0:w-k,y1:w+k,spikeDistance:t.distance,hovertemplate:f.hovertemplate}),\"h\"===f.orientation?(b=h,n.xLabelVal=l.x,n.yLabelVal=o.pos):(b=u,n.xLabelVal=o.pos,n.yLabelVal=l.y),n[b._id.charAt(0)+\"Spike\"]=b.c2p(o.pos,!0),s(l,f,n),n}e.exports={hoverPoints:function(t,e,r,n){var i,a=t.cd[0].trace.hoveron,o=[];return-1!==a.indexOf(\"boxes\")&&(o=o.concat(l(t,e,r,n))),-1!==a.indexOf(\"points\")&&(i=c(t,e,r)),\"closest\"===n?i?[i]:o:i?(o.push(i),o):o},hoverOnBoxes:l,hoverOnPoints:c}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],886:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\").supplyLayoutDefaults,calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"box\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"boxLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":880,\"./calc\":881,\"./cross_trace_calc\":882,\"./defaults\":883,\"./event_data\":884,\"./hover\":885,\"./layout_attributes\":887,\"./layout_defaults\":888,\"./plot\":889,\"./select\":890,\"./style\":891}],887:[function(t,e,r){\"use strict\";e.exports={boxmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"overlay\",editType:\"calc\"},boxgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"},boxgroupgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"}}},{}],888:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./layout_attributes\");function o(t,e,r,i,a){for(var o=a+\"Layout\",s=!1,l=0;l<r.length;l++){var c=r[l];if(n.traceIs(c,o)){s=!0;break}}s&&(i(a+\"mode\"),i(a+\"gap\"),i(a+\"groupgap\"))}e.exports={supplyLayoutDefaults:function(t,e,r){o(0,0,r,function(r,n){return i.coerce(t,e,a,r,n)},\"box\")},_supply:o}},{\"../../lib\":719,\"../../registry\":847,\"./layout_attributes\":887}],889:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=5,s=.01;function l(t,e,r,a){var o,s,l=e.pos,c=e.val,u=a.bPos,h=a.wdPos||0,f=a.bPosPxOffset||0,p=r.whiskerwidth||0,d=r.notched||!1,g=d?1-2*r.notchwidth:1;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var v=t.selectAll(\"path.box\").data(\"violin\"!==r.type||r.box.visible?i.identity:[]);v.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"box\"),v.exit().remove(),v.each(function(t){if(t.empty)return\"M0,0Z\";var e=t.pos,a=l.c2p(e+u,!0)+f,v=l.c2p(e+u-o,!0)+f,m=l.c2p(e+u+s,!0)+f,y=l.c2p(e+u-h,!0)+f,x=l.c2p(e+u+h,!0)+f,b=l.c2p(e+u-o*g,!0)+f,_=l.c2p(e+u+s*g,!0)+f,w=c.c2p(t.q1,!0),k=c.c2p(t.q3,!0),T=i.constrain(c.c2p(t.med,!0),Math.min(w,k)+1,Math.max(w,k)-1),A=void 0===t.lf||!1===r.boxpoints,M=c.c2p(A?t.min:t.lf,!0),S=c.c2p(A?t.max:t.uf,!0),E=c.c2p(t.ln,!0),C=c.c2p(t.un,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+T+\",\"+b+\"V\"+_+\"M\"+w+\",\"+v+\"V\"+m+(d?\"H\"+E+\"L\"+T+\",\"+_+\"L\"+C+\",\"+m:\"\")+\"H\"+k+\"V\"+v+(d?\"H\"+C+\"L\"+T+\",\"+b+\"L\"+E+\",\"+v:\"\")+\"ZM\"+w+\",\"+a+\"H\"+M+\"M\"+k+\",\"+a+\"H\"+S+(0===p?\"\":\"M\"+M+\",\"+y+\"V\"+x+\"M\"+S+\",\"+y+\"V\"+x)):n.select(this).attr(\"d\",\"M\"+b+\",\"+T+\"H\"+_+\"M\"+v+\",\"+w+\"H\"+m+(d?\"V\"+E+\"L\"+_+\",\"+T+\"L\"+m+\",\"+C:\"\")+\"V\"+k+\"H\"+v+(d?\"V\"+C+\"L\"+b+\",\"+T+\"L\"+v+\",\"+E:\"\")+\"ZM\"+a+\",\"+w+\"V\"+M+\"M\"+a+\",\"+k+\"V\"+S+(0===p?\"\":\"M\"+y+\",\"+M+\"H\"+x+\"M\"+y+\",\"+S+\"H\"+x))})}function c(t,e,r,n){var l=e.x,c=e.y,u=n.bdPos,h=n.bPos,f=r.boxpoints||r.points;i.seedPseudoRandom();var p=t.selectAll(\"g.points\").data(f?function(t){return t.forEach(function(t){t.t=n,t.trace=r}),t}:[]);p.enter().append(\"g\").attr(\"class\",\"points\"),p.exit().remove();var d=p.selectAll(\"path\").data(function(t){var e,n,a=t.pts2,l=Math.max((t.max-t.min)/10,t.q3-t.q1),c=1e-9*l,p=l*s,d=[],g=0;if(r.jitter){if(0===l)for(g=1,d=new Array(a.length),e=0;e<a.length;e++)d[e]=1;else for(e=0;e<a.length;e++){var v=Math.max(0,e-o),m=a[v].v,y=Math.min(a.length-1,e+o),x=a[y].v;\"all\"!==f&&(a[e].v<t.lf?x=Math.min(x,t.lf):m=Math.max(m,t.uf));var b=Math.sqrt(p*(y-v)/(x-m+c))||0;b=i.constrain(Math.abs(b),0,1),d.push(b),g=Math.max(b,g)}n=2*r.jitter/(g||1)}for(e=0;e<a.length;e++){var _=a[e],w=_.v,k=r.jitter?n*d[e]*(i.pseudoRandom()-.5):0,T=t.pos+h+u*(r.pointpos+k);\"h\"===r.orientation?(_.y=T,_.x=w):(_.x=T,_.y=w),\"suspectedoutliers\"===f&&w<t.uo&&w>t.lo&&(_.so=!0)}return a});d.enter().append(\"path\").classed(\"point\",!0),d.exit().remove(),d.call(a.translatePoints,l,c)}function u(t,e,r,a){var o,s,l=e.pos,c=e.val,u=a.bPos,h=a.bPosPxOffset||0,f=r.boxmean||(r.meanline||{}).visible;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var p=t.selectAll(\"path.mean\").data(\"box\"===r.type&&r.boxmean||\"violin\"===r.type&&r.box.visible&&r.meanline.visible?i.identity:[]);p.enter().append(\"path\").attr(\"class\",\"mean\").style({fill:\"none\",\"vector-effect\":\"non-scaling-stroke\"}),p.exit().remove(),p.each(function(t){var e=l.c2p(t.pos+u,!0)+h,i=l.c2p(t.pos+u-o,!0)+h,a=l.c2p(t.pos+u+s,!0)+h,p=c.c2p(t.mean,!0),d=c.c2p(t.mean-t.sd,!0),g=c.c2p(t.mean+t.sd,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+p+\",\"+i+\"V\"+a+(\"sd\"===f?\"m0,0L\"+d+\",\"+e+\"L\"+p+\",\"+i+\"L\"+g+\",\"+e+\"Z\":\"\")):n.select(this).attr(\"d\",\"M\"+i+\",\"+p+\"H\"+a+(\"sd\"===f?\"m0,0L\"+e+\",\"+d+\"L\"+i+\",\"+p+\"L\"+e+\",\"+g+\"Z\":\"\"))})}e.exports={plot:function(t,e,r,a){var o=e.xaxis,s=e.yaxis;i.makeTraceGroups(a,r,\"trace boxes\").each(function(t){var e,r,i=n.select(this),a=t[0],h=a.t,f=a.trace;h.wdPos=h.bdPos*f.whiskerwidth,!0!==f.visible||h.empty?i.remove():(\"h\"===f.orientation?(e=s,r=o):(e=o,r=s),l(i,{pos:e,val:r},f,h),c(i,{x:o,y:s},f,h),u(i,{pos:e,val:r},f,h))})},plotBoxAndWhiskers:l,plotPoints:c,plotBoxMean:u}},{\"../../components/drawing\":614,\"../../lib\":719,d3:163}],890:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i=t.cd,a=t.xaxis,o=t.yaxis,s=[];if(!1===e)for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++)i[r].pts[n].selected=0;else for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++){var l=i[r].pts[n],c=a.c2p(l.x),u=o.c2p(l.y);e.contains([c,u],null,l.i,t)?(s.push({pointNumber:l.i,x:a.c2d(l.x),y:o.c2d(l.y)}),l.selected=1):l.selected=0}return s}},{}],891:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\");e.exports={style:function(t,e,r){var o=r||n.select(t).selectAll(\"g.trace.boxes\");o.style(\"opacity\",function(t){return t[0].trace.opacity}),o.each(function(e){var r=n.select(this),o=e[0].trace,s=o.line.width;function l(t,e,r,n){t.style(\"stroke-width\",e+\"px\").call(i.stroke,r).call(i.fill,n)}var c=r.selectAll(\"path.box\");if(\"candlestick\"===o.type)c.each(function(t){if(!t.empty){var e=n.select(this),r=o[t.dir];l(e,r.line.width,r.line.color,r.fillcolor),e.style(\"opacity\",o.selectedpoints&&!t.selected?.3:1)}});else{l(c,s,o.line.color,o.fillcolor),r.selectAll(\"path.mean\").style({\"stroke-width\":s,\"stroke-dasharray\":2*s+\"px,\"+s+\"px\"}).call(i.stroke,o.line.color);var u=r.selectAll(\"path.point\");a.pointStyle(u,o,t)}})},styleOnSelect:function(t,e,r){var n=e[0].trace,i=r.selectAll(\"path.point\");n.selectedpoints?a.selectedPointStyle(i,n):a.pointStyle(i,n,t)}}},{\"../../components/color\":593,\"../../components/drawing\":614,d3:163}],892:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../ohlc/attributes\"),a=t(\"../box/attributes\");function o(t){return{line:{color:n({},a.line.color,{dflt:t}),width:a.line.width,editType:\"style\"},fillcolor:a.fillcolor,editType:\"style\"}}e.exports={x:i.x,open:i.open,high:i.high,low:i.low,close:i.close,line:{width:n({},a.line.width,{}),editType:\"style\"},increasing:o(i.increasing.line.color.dflt),decreasing:o(i.decreasing.line.color.dflt),text:i.text,hovertext:i.hovertext,whiskerwidth:n({},a.whiskerwidth,{dflt:0}),hoverlabel:i.hoverlabel}},{\"../../lib\":719,\"../box/attributes\":880,\"../ohlc/attributes\":1058}],893:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../ohlc/calc\").calcCommon;function o(t,e,r,n){return{min:r,q1:Math.min(t,n),med:n,q3:Math.max(t,n),max:e}}e.exports=function(t,e){var r=t._fullLayout,s=i.getFromId(t,e.xaxis),l=i.getFromId(t,e.yaxis),c=s.makeCalcdata(e,\"x\"),u=a(t,e,c,l,o);return u.length?(n.extendFlat(u[0].t,{num:r._numBoxes,dPos:n.distinctVals(c).minDiff/2,posLetter:\"x\",valLetter:\"y\"}),r._numBoxes++,u):[{t:{empty:!0}}]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../ohlc/calc\":1059}],894:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../ohlc/ohlc_defaults\"),o=t(\"./attributes\");function s(t,e,r,n){var a=r(n+\".line.color\");r(n+\".line.width\",e.line.width),r(n+\".fillcolor\",i.addOpacity(a,.5))}e.exports=function(t,e,r,i){function l(r,i){return n.coerce(t,e,o,r,i)}a(t,e,l,i)?(l(\"line.width\"),s(t,e,l,\"increasing\"),s(t,e,l,\"decreasing\"),l(\"text\"),l(\"hovertext\"),l(\"whiskerwidth\"),i._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../components/color\":593,\"../../lib\":719,\"../ohlc/ohlc_defaults\":1063,\"./attributes\":892}],895:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"candlestick\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\",\"candlestick\",\"boxLayout\"],meta:{},attributes:t(\"./attributes\"),layoutAttributes:t(\"../box/layout_attributes\"),supplyLayoutDefaults:t(\"../box/layout_defaults\").supplyLayoutDefaults,crossTraceCalc:t(\"../box/cross_trace_calc\").crossTraceCalc,supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"../box/plot\").plot,layerName:\"boxlayer\",style:t(\"../box/style\").style,hoverPoints:t(\"../ohlc/hover\").hoverPoints,selectPoints:t(\"../ohlc/select\")}},{\"../../plots/cartesian\":778,\"../box/cross_trace_calc\":882,\"../box/layout_attributes\":887,\"../box/layout_defaults\":888,\"../box/plot\":889,\"../box/style\":891,\"../ohlc/hover\":1061,\"../ohlc/select\":1065,\"./attributes\":892,\"./calc\":893,\"./defaults\":894}],896:[function(t,e,r){\"use strict\";var n=t(\"./axis_defaults\"),i=t(\"../../plot_api/plot_template\");e.exports=function(t,e,r,a,o){a(\"a\")||(a(\"da\"),a(\"a0\")),a(\"b\")||(a(\"db\"),a(\"b0\")),function(t,e,r,a){[\"aaxis\",\"baxis\"].forEach(function(o){var s=o.charAt(0),l=t[o]||{},c=i.newContainer(e,o),u={tickfont:\"x\",id:s+\"axis\",letter:s,font:e.font,name:o,data:t[s],calendar:e.calendar,dfltColor:a,bgColor:r.paper_bgcolor,fullLayout:r};n(l,c,u),c._categories=c._categories||[],t[o]||\"-\"===l.type||(t[o]={type:l.type})})}(t,e,r,o)}},{\"../../plot_api/plot_template\":757,\"./axis_defaults\":901}],897:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t){return function t(e,r){if(!n(e)||r>=10)return null;var i=1/0;var a=-1/0;var o=e.length;for(var s=0;s<o;s++){var l=e[s];if(n(l)){var c=t(l,r+1);c&&(i=Math.min(c[0],i),a=Math.max(c[1],a))}else i=Math.min(l,i),a=Math.max(l,a)}return[i,a]}(t,0)}},{\"../../lib\":719}],898:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./axis_attributes\"),a=t(\"../../components/color/attributes\"),o=n({editType:\"calc\"});o.family.dflt='\"Open Sans\", verdana, arial, sans-serif',o.size.dflt=12,o.color.dflt=a.defaultLine,e.exports={carpet:{valType:\"string\",editType:\"calc\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},a:{valType:\"data_array\",editType:\"calc\"},a0:{valType:\"number\",dflt:0,editType:\"calc\"},da:{valType:\"number\",dflt:1,editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},b0:{valType:\"number\",dflt:0,editType:\"calc\"},db:{valType:\"number\",dflt:1,editType:\"calc\"},cheaterslope:{valType:\"number\",dflt:1,editType:\"calc\"},aaxis:i,baxis:i,font:o,color:{valType:\"color\",dflt:a.defaultLine,editType:\"plot\"},transforms:void 0}},{\"../../components/color/attributes\":592,\"../../plots/font_attributes\":793,\"./axis_attributes\":900}],899:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,i){var a,o,s,l,c,u,h,f,p,d,g,v,m,y=n(r)?\"a\":\"b\",x=(\"a\"===y?t.aaxis:t.baxis).smoothing,b=\"a\"===y?t.a2i:t.b2j,_=\"a\"===y?r:i,w=\"a\"===y?i:r,k=\"a\"===y?e.a.length:e.b.length,T=\"a\"===y?e.b.length:e.a.length,A=Math.floor(\"a\"===y?t.b2j(w):t.a2i(w)),M=\"a\"===y?function(e){return t.evalxy([],e,A)}:function(e){return t.evalxy([],A,e)};x&&(s=Math.max(0,Math.min(T-2,A)),l=A-s,o=\"a\"===y?function(e,r){return t.dxydi([],e,s,r,l)}:function(e,r){return t.dxydj([],s,e,l,r)});var S=b(_[0]),E=b(_[1]),C=S<E?1:-1,L=1e-8*(E-S),P=C>0?Math.floor:Math.ceil,O=C>0?Math.ceil:Math.floor,z=C>0?Math.min:Math.max,I=C>0?Math.max:Math.min,D=P(S+L),R=O(E-L),F=[[h=M(S)]];for(a=D;a*C<R*C;a+=C)c=[],g=I(S,a),m=(v=z(E,a+C))-g,u=Math.max(0,Math.min(k-2,Math.floor(.5*(g+v)))),f=M(v),x&&(p=o(u,g-u),d=o(u,v-u),c.push([h[0]+p[0]/3*m,h[1]+p[1]/3*m]),c.push([f[0]-d[0]/3*m,f[1]-d[1]/3*m])),c.push(f),F.push(c),h=f;return F}},{\"../../lib\":719}],900:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../plots/cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").TIME_FORMAT_LINK;e.exports={color:{valType:\"color\",editType:\"calc\"},smoothing:{valType:\"number\",dflt:1,min:0,max:1.3,editType:\"calc\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"calc\"},font:n({editType:\"calc\"}),offset:{valType:\"number\",dflt:10,editType:\"calc\"},editType:\"calc\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"date\",\"category\"],dflt:\"-\",editType:\"calc\"},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"calc\"},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"calc\"},range:{valType:\"info_array\",editType:\"calc\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}]},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cheatertype:{valType:\"enumerated\",values:[\"index\",\"value\"],dflt:\"value\",editType:\"calc\"},tickmode:{valType:\"enumerated\",values:[\"linear\",\"array\"],dflt:\"array\",editType:\"calc\"},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},tickvals:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},showticklabels:{valType:\"enumerated\",values:[\"start\",\"end\",\"both\",\"none\"],dflt:\"start\",editType:\"calc\"},tickfont:n({editType:\"calc\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"calc\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"calc\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"calc\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"calc\"},tickformatstops:o(a.tickformatstops,\"calc\",\"from-root\"),categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},labelpadding:{valType:\"integer\",dflt:10,editType:\"calc\"},labelprefix:{valType:\"string\",editType:\"calc\"},labelsuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showline:{valType:\"boolean\",dflt:!1,editType:\"calc\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"calc\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},gridcolor:{valType:\"color\",editType:\"calc\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},showgrid:{valType:\"boolean\",dflt:!0,editType:\"calc\"},minorgridcount:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},minorgridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},minorgridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"calc\"},startline:{valType:\"boolean\",editType:\"calc\"},startlinecolor:{valType:\"color\",editType:\"calc\"},startlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endline:{valType:\"boolean\",editType:\"calc\"},endlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endlinecolor:{valType:\"color\",editType:\"calc\"},tick0:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},dtick:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},arraytick0:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},arraydtick:{valType:\"integer\",min:1,dflt:1,editType:\"calc\"},_deprecated:{title:{valType:\"string\",editType:\"calc\"},titlefont:n({editType:\"calc\"}),titleoffset:{valType:\"number\",dflt:10,editType:\"calc\"}},editType:\"calc\"}},{\"../../components/color/attributes\":592,\"../../constants/docs\":690,\"../../plot_api/edit_types\":750,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/font_attributes\":793}],901:[function(t,e,r){\"use strict\";var n=t(\"./attributes\"),i=t(\"../../components/color\").addOpacity,a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/tick_value_defaults\"),l=t(\"../../plots/cartesian/tick_label_defaults\"),c=t(\"../../plots/cartesian/category_order_defaults\"),u=t(\"../../plots/cartesian/set_convert\"),h=t(\"../../plots/cartesian/axis_autotype\");e.exports=function(t,e,r){var f=r.letter,p=r.font||{},d=n[f+\"axis\"];function g(r,n){return o.coerce(t,e,d,r,n)}function v(r,n){return o.coerce2(t,e,d,r,n)}r.name&&(e._name=r.name,e._id=r.name);var m=g(\"type\");(\"-\"===m&&(r.data&&function(t,e){if(\"-\"!==t.type)return;var r=t._id.charAt(0),n=t[r+\"calendar\"];t.type=h(e,n)}(e,r.data),\"-\"===e.type?e.type=\"linear\":m=t.type=e.type),g(\"smoothing\"),g(\"cheatertype\"),g(\"showticklabels\"),g(\"labelprefix\",f+\" = \"),g(\"labelsuffix\"),g(\"showtickprefix\"),g(\"showticksuffix\"),g(\"separatethousands\"),g(\"tickformat\"),g(\"exponentformat\"),g(\"showexponent\"),g(\"categoryorder\"),g(\"tickmode\"),g(\"tickvals\"),g(\"ticktext\"),g(\"tick0\"),g(\"dtick\"),\"array\"===e.tickmode&&(g(\"arraytick0\"),g(\"arraydtick\")),g(\"labelpadding\"),e._hovertitle=f,\"date\"===m)&&a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",r.calendar);u(e,r.fullLayout),e.c2p=o.identity;var y=g(\"color\",r.dfltColor),x=y===t.color?y:p.color;g(\"title.text\")&&(o.coerceFont(g,\"title.font\",{family:p.family,size:Math.round(1.2*p.size),color:x}),g(\"title.offset\")),g(\"tickangle\"),g(\"autorange\",!e.isValidRange(t.range))&&g(\"rangemode\"),g(\"range\"),e.cleanRange(),g(\"fixedrange\"),s(t,e,g,m),l(t,e,g,m,r),c(t,e,g,{data:r.data,dataAttr:f});var b=v(\"gridcolor\",i(y,.3)),_=v(\"gridwidth\"),w=g(\"showgrid\");w||(delete e.gridcolor,delete e.gridwidth);var k=v(\"startlinecolor\",y),T=v(\"startlinewidth\",_);g(\"startline\",e.showgrid||!!k||!!T)||(delete e.startlinecolor,delete e.startlinewidth);var A=v(\"endlinecolor\",y),M=v(\"endlinewidth\",_);return g(\"endline\",e.showgrid||!!A||!!M)||(delete e.endlinecolor,delete e.endlinewidth),w?(g(\"minorgridcount\"),g(\"minorgridwidth\",_),g(\"minorgridcolor\",i(b,.06)),e.minorgridcount||(delete e.minorgridwidth,delete e.minorgridcolor)):(delete e.gridcolor,delete e.gridWidth),\"none\"===e.showticklabels&&(delete e.tickfont,delete e.tickangle,delete e.showexponent,delete e.exponentformat,delete e.tickformat,delete e.showticksuffix,delete e.showtickprefix),e.showticksuffix||delete e.ticksuffix,e.showtickprefix||delete e.tickprefix,g(\"tickmode\"),e}},{\"../../components/color\":593,\"../../lib\":719,\"../../plots/cartesian/axis_autotype\":768,\"../../plots/cartesian/category_order_defaults\":771,\"../../plots/cartesian/set_convert\":785,\"../../plots/cartesian/tick_label_defaults\":786,\"../../plots/cartesian/tick_value_defaults\":788,\"../../registry\":847,\"./attributes\":898}],902:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\").isArray1D,a=t(\"./cheater_basis\"),o=t(\"./array_minmax\"),s=t(\"./calc_gridlines\"),l=t(\"./calc_labels\"),c=t(\"./calc_clippath\"),u=t(\"../heatmap/clean_2d_array\"),h=t(\"./smooth_fill_2d_array\"),f=t(\"../heatmap/convert_column_xyz\"),p=t(\"./set_convert\");e.exports=function(t,e){var r=n.getFromId(t,e.xaxis),d=n.getFromId(t,e.yaxis),g=e.aaxis,v=e.baxis,m=e.x,y=e.y,x=[];m&&i(m)&&x.push(\"x\"),y&&i(y)&&x.push(\"y\"),x.length&&f(e,g,v,\"a\",\"b\",x);var b=e._a=e._a||e.a,_=e._b=e._b||e.b;m=e._x||e.x,y=e._y||e.y;var w={};if(e._cheater){var k=\"index\"===g.cheatertype?b.length:b,T=\"index\"===v.cheatertype?_.length:_;m=a(k,T,e.cheaterslope)}e._x=m=u(m),e._y=y=u(y),h(m,b,_),h(y,b,_),p(e),e.setScale();var A=o(m),M=o(y),S=.5*(A[1]-A[0]),E=.5*(A[1]+A[0]),C=.5*(M[1]-M[0]),L=.5*(M[1]+M[0]);return A=[E-1.3*S,E+1.3*S],M=[L-1.3*C,L+1.3*C],e._extremes[r._id]=n.findExtremes(r,A,{padded:!0}),e._extremes[d._id]=n.findExtremes(d,M,{padded:!0}),s(e,\"a\",\"b\"),s(e,\"b\",\"a\"),l(e,g),l(e,v),w.clipsegments=c(e._xctrl,e._yctrl,g,v),w.x=m,w.y=y,w.a=b,w.b=_,[w]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../heatmap/clean_2d_array\":1003,\"../heatmap/convert_column_xyz\":1005,\"./array_minmax\":897,\"./calc_clippath\":903,\"./calc_gridlines\":904,\"./calc_labels\":905,\"./cheater_basis\":907,\"./set_convert\":920,\"./smooth_fill_2d_array\":921}],903:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a,o,s=[],l=!!r.smoothing,c=!!n.smoothing,u=t[0].length-1,h=t.length-1;for(i=0,a=[],o=[];i<=u;i++)a[i]=t[0][i],o[i]=e[0][i];for(s.push({x:a,y:o,bicubic:l}),i=0,a=[],o=[];i<=h;i++)a[i]=t[i][u],o[i]=e[i][u];for(s.push({x:a,y:o,bicubic:c}),i=u,a=[],o=[];i>=0;i--)a[u-i]=t[h][i],o[u-i]=e[h][i];for(s.push({x:a,y:o,bicubic:l}),i=h,a=[],o=[];i>=0;i--)a[h-i]=t[i][0],o[h-i]=e[i][0];return s.push({x:a,y:o,bicubic:c}),s}},{}],904:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e,r){var a,o,s,l,c,u,h,f,p,d,g,v,m,y,x=t[\"_\"+e],b=t[e+\"axis\"],_=b._gridlines=[],w=b._minorgridlines=[],k=b._boundarylines=[],T=t[\"_\"+r],A=t[r+\"axis\"];\"array\"===b.tickmode&&(b.tickvals=x.slice());var M=t._xctrl,S=t._yctrl,E=M[0].length,C=M.length,L=t._a.length,P=t._b.length;n.prepTicks(b),\"array\"===b.tickmode&&delete b.tickvals;var O=b.smoothing?3:1;function z(n){var i,a,o,s,l,c,u,h,p,d,g,v,m=[],y=[],x={};if(\"b\"===e)for(a=t.b2j(n),o=Math.floor(Math.max(0,Math.min(P-2,a))),s=a-o,x.length=P,x.crossLength=L,x.xy=function(e){return t.evalxy([],e,a)},x.dxy=function(e,r){return t.dxydi([],e,o,r,s)},i=0;i<L;i++)c=Math.min(L-2,i),u=i-c,h=t.evalxy([],i,a),A.smoothing&&i>0&&(p=t.dxydi([],i-1,o,0,s),m.push(l[0]+p[0]/3),y.push(l[1]+p[1]/3),d=t.dxydi([],i-1,o,1,s),m.push(h[0]-d[0]/3),y.push(h[1]-d[1]/3)),m.push(h[0]),y.push(h[1]),l=h;else for(i=t.a2i(n),c=Math.floor(Math.max(0,Math.min(L-2,i))),u=i-c,x.length=L,x.crossLength=P,x.xy=function(e){return t.evalxy([],i,e)},x.dxy=function(e,r){return t.dxydj([],c,e,u,r)},a=0;a<P;a++)o=Math.min(P-2,a),s=a-o,h=t.evalxy([],i,a),A.smoothing&&a>0&&(g=t.dxydj([],c,a-1,u,0),m.push(l[0]+g[0]/3),y.push(l[1]+g[1]/3),v=t.dxydj([],c,a-1,u,1),m.push(h[0]-v[0]/3),y.push(h[1]-v[1]/3)),m.push(h[0]),y.push(h[1]),l=h;return x.axisLetter=e,x.axis=b,x.crossAxis=A,x.value=n,x.constvar=r,x.index=f,x.x=m,x.y=y,x.smoothing=A.smoothing,x}function I(n){var i,a,o,s,l,c=[],u=[],h={};if(h.length=x.length,h.crossLength=T.length,\"b\"===e)for(o=Math.max(0,Math.min(P-2,n)),l=Math.min(1,Math.max(0,n-o)),h.xy=function(e){return t.evalxy([],e,n)},h.dxy=function(e,r){return t.dxydi([],e,o,r,l)},i=0;i<E;i++)c[i]=M[n*O][i],u[i]=S[n*O][i];else for(a=Math.max(0,Math.min(L-2,n)),s=Math.min(1,Math.max(0,n-a)),h.xy=function(e){return t.evalxy([],n,e)},h.dxy=function(e,r){return t.dxydj([],a,e,s,r)},i=0;i<C;i++)c[i]=M[i][n*O],u[i]=S[i][n*O];return h.axisLetter=e,h.axis=b,h.crossAxis=A,h.value=x[n],h.constvar=r,h.index=n,h.x=c,h.y=u,h.smoothing=A.smoothing,h}if(\"array\"===b.tickmode){for(l=5e-15,u=(c=[Math.floor((x.length-1-b.arraytick0)/b.arraydtick*(1+l)),Math.ceil(-b.arraytick0/b.arraydtick/(1+l))].sort(function(t,e){return t-e}))[0]-1,h=c[1]+1,f=u;f<h;f++)(o=b.arraytick0+b.arraydtick*f)<0||o>x.length-1||_.push(i(I(o),{color:b.gridcolor,width:b.gridwidth}));for(f=u;f<h;f++)if(s=b.arraytick0+b.arraydtick*f,g=Math.min(s+b.arraydtick,x.length-1),!(s<0||s>x.length-1||g<0||g>x.length-1))for(v=x[s],m=x[g],a=0;a<b.minorgridcount;a++)(y=g-s)<=0||(d=v+(m-v)*(a+1)/(b.minorgridcount+1)*(b.arraydtick/y))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&k.push(i(I(0),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&k.push(i(I(x.length-1),{color:b.endlinecolor,width:b.endlinewidth}))}else{for(l=5e-15,u=(c=[Math.floor((x[x.length-1]-b.tick0)/b.dtick*(1+l)),Math.ceil((x[0]-b.tick0)/b.dtick/(1+l))].sort(function(t,e){return t-e}))[0],h=c[1],f=u;f<=h;f++)p=b.tick0+b.dtick*f,_.push(i(z(p),{color:b.gridcolor,width:b.gridwidth}));for(f=u-1;f<h+1;f++)for(p=b.tick0+b.dtick*f,a=0;a<b.minorgridcount;a++)(d=p+b.dtick*(a+1)/(b.minorgridcount+1))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&k.push(i(z(x[0]),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&k.push(i(z(x[x.length-1]),{color:b.endlinecolor,width:b.endlinewidth}))}}},{\"../../lib/extend\":710,\"../../plots/cartesian/axes\":767}],905:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e){var r,a,o,s=e._labels=[],l=e._gridlines;for(r=0;r<l.length;r++)o=l[r],-1!==[\"start\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{prefix:void 0,suffix:void 0,endAnchor:!0,xy:o.xy(0),dxy:o.dxy(0,0),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a)),-1!==[\"end\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{endAnchor:!1,xy:o.xy(o.crossLength-1),dxy:o.dxy(o.crossLength-2,1),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a))}},{\"../../lib/extend\":710,\"../../plots/cartesian/axes\":767}],906:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=t[0]-e[0],a=t[1]-e[1],o=r[0]-e[0],s=r[1]-e[1],l=Math.pow(i*i+a*a,.25),c=Math.pow(o*o+s*s,.25),u=(c*c*i-l*l*o)*n,h=(c*c*a-l*l*s)*n,f=c*(l+c)*3,p=l*(l+c)*3;return[[e[0]+(f&&u/f),e[1]+(f&&h/f)],[e[0]-(p&&u/p),e[1]-(p&&h/p)]]}},{}],907:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i,a,o,s,l,c,u=[],h=n(t)?t.length:t,f=n(e)?e.length:e,p=n(t)?t:null,d=n(e)?e:null;p&&(o=(p.length-1)/(p[p.length-1]-p[0])/(h-1)),d&&(s=(d.length-1)/(d[d.length-1]-d[0])/(f-1));var g=1/0,v=-1/0;for(a=0;a<f;a++)for(u[a]=[],l=d?(d[a]-d[0])*s:a/(f-1),i=0;i<h;i++)c=(p?(p[i]-p[0])*o:i/(h-1))-l*r,g=Math.min(c,g),v=Math.max(c,v),u[a][i]=c;var m=1/(v-g),y=-g*m;for(a=0;a<f;a++)for(i=0;i<h;i++)u[a][i]=m*u[a][i]+y;return u}},{\"../../lib\":719}],908:[function(t,e,r){\"use strict\";var n=t(\"./catmull_rom\"),i=t(\"../../lib\").ensureArray;function a(t,e,r){var n=-.5*r[0]+1.5*e[0],i=-.5*r[1]+1.5*e[1];return[(2*n+t[0])/3,(2*i+t[1])/3]}e.exports=function(t,e,r,o,s,l){var c,u,h,f,p,d,g,v,m,y,x=r[0].length,b=r.length,_=s?3*x-2:x,w=l?3*b-2:b;for(t=i(t,w),e=i(e,w),h=0;h<w;h++)t[h]=i(t[h],_),e[h]=i(e[h],_);for(u=0,f=0;u<b;u++,f+=l?3:1)for(p=t[f],d=e[f],g=r[u],v=o[u],c=0,h=0;c<x;c++,h+=s?3:1)p[h]=g[c],d[h]=v[c];if(s)for(u=0,f=0;u<b;u++,f+=l?3:1){for(c=1,h=3;c<x-1;c++,h+=3)m=n([r[u][c-1],o[u][c-1]],[r[u][c],o[u][c]],[r[u][c+1],o[u][c+1]],s),t[f][h-1]=m[0][0],e[f][h-1]=m[0][1],t[f][h+1]=m[1][0],e[f][h+1]=m[1][1];y=a([t[f][0],e[f][0]],[t[f][2],e[f][2]],[t[f][3],e[f][3]]),t[f][1]=y[0],e[f][1]=y[1],y=a([t[f][_-1],e[f][_-1]],[t[f][_-3],e[f][_-3]],[t[f][_-4],e[f][_-4]]),t[f][_-2]=y[0],e[f][_-2]=y[1]}if(l)for(h=0;h<_;h++){for(f=3;f<w-3;f+=3)m=n([t[f-3][h],e[f-3][h]],[t[f][h],e[f][h]],[t[f+3][h],e[f+3][h]],l),t[f-1][h]=m[0][0],e[f-1][h]=m[0][1],t[f+1][h]=m[1][0],e[f+1][h]=m[1][1];y=a([t[0][h],e[0][h]],[t[2][h],e[2][h]],[t[3][h],e[3][h]]),t[1][h]=y[0],e[1][h]=y[1],y=a([t[w-1][h],e[w-1][h]],[t[w-3][h],e[w-3][h]],[t[w-4][h],e[w-4][h]]),t[w-2][h]=y[0],e[w-2][h]=y[1]}if(s&&l)for(f=1;f<w;f+=(f+1)%3==0?2:1){for(h=3;h<_-3;h+=3)m=n([t[f][h-3],e[f][h-3]],[t[f][h],e[f][h]],[t[f][h+3],e[f][h+3]],s),t[f][h-1]=.5*(t[f][h-1]+m[0][0]),e[f][h-1]=.5*(e[f][h-1]+m[0][1]),t[f][h+1]=.5*(t[f][h+1]+m[1][0]),e[f][h+1]=.5*(e[f][h+1]+m[1][1]);y=a([t[f][0],e[f][0]],[t[f][2],e[f][2]],[t[f][3],e[f][3]]),t[f][1]=.5*(t[f][1]+y[0]),e[f][1]=.5*(e[f][1]+y[1]),y=a([t[f][_-1],e[f][_-1]],[t[f][_-3],e[f][_-3]],[t[f][_-4],e[f][_-4]]),t[f][_-2]=.5*(t[f][_-2]+y[0]),e[f][_-2]=.5*(e[f][_-2]+y[1])}return[t,e]}},{\"../../lib\":719,\"./catmull_rom\":906}],909:[function(t,e,r){\"use strict\";e.exports={RELATIVE_CULL_TOLERANCE:1e-6}},{}],910:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3,n*=3;var f=i*i,p=1-i,d=p*p,g=p*i*2,v=-3*d,m=3*(d-g),y=3*(g-f),x=3*f,b=a*a,_=b*a,w=1-a,k=w*w,T=k*w;for(h=0;h<t.length;h++)o=v*(u=t[h])[n][r]+m*u[n][r+1]+y*u[n][r+2]+x*u[n][r+3],s=v*u[n+1][r]+m*u[n+1][r+1]+y*u[n+1][r+2]+x*u[n+1][r+3],l=v*u[n+2][r]+m*u[n+2][r+1]+y*u[n+2][r+2]+x*u[n+2][r+3],c=v*u[n+3][r]+m*u[n+3][r+1]+y*u[n+3][r+2]+x*u[n+3][r+3],e[h]=T*o+3*(k*a*s+w*b*l)+_*c;return e}:e?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),r*=3;var u=i*i,h=1-i,f=h*h,p=h*i*2,d=-3*f,g=3*(f-p),v=3*(p-u),m=3*u,y=1-a;for(l=0;l<t.length;l++)o=d*(c=t[l])[n][r]+g*c[n][r+1]+v*c[n][r+2]+m*c[n][r+3],s=d*c[n+1][r]+g*c[n+1][r+1]+v*c[n+1][r+2]+m*c[n+1][r+3],e[l]=y*o+a*s;return e}:r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),n*=3;var f=a*a,p=f*a,d=1-a,g=d*d,v=g*d;for(u=0;u<t.length;u++)o=(h=t[u])[n][r+1]-h[n][r],s=h[n+1][r+1]-h[n+1][r],l=h[n+2][r+1]-h[n+2][r],c=h[n+3][r+1]-h[n+3][r],e[u]=v*o+3*(g*a*s+d*f*l)+p*c;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-a;for(l=0;l<t.length;l++)o=(c=t[l])[n][r+1]-c[n][r],s=c[n+1][r+1]-c[n+1][r],e[l]=u*o+a*s;return e}}},{}],911:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3,n*=3;var f=i*i,p=f*i,d=1-i,g=d*d,v=g*d,m=a*a,y=1-a,x=y*y,b=y*a*2,_=-3*x,w=3*(x-b),k=3*(b-m),T=3*m;for(h=0;h<t.length;h++)o=_*(u=t[h])[n][r]+w*u[n+1][r]+k*u[n+2][r]+T*u[n+3][r],s=_*u[n][r+1]+w*u[n+1][r+1]+k*u[n+2][r+1]+T*u[n+3][r+1],l=_*u[n][r+2]+w*u[n+1][r+2]+k*u[n+2][r+2]+T*u[n+3][r+2],c=_*u[n][r+3]+w*u[n+1][r+3]+k*u[n+2][r+3]+T*u[n+3][r+3],e[h]=v*o+3*(g*i*s+d*f*l)+p*c;return e}:e?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3;var f=a*a,p=f*a,d=1-a,g=d*d,v=g*d;for(u=0;u<t.length;u++)o=(h=t[u])[n+1][r]-h[n][r],s=h[n+1][r+1]-h[n][r+1],l=h[n+1][r+2]-h[n][r+2],c=h[n+1][r+3]-h[n][r+3],e[u]=v*o+3*(g*a*s+d*f*l)+p*c;return e}:r?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),n*=3;var u=1-i,h=a*a,f=1-a,p=f*f,d=f*a*2,g=-3*p,v=3*(p-d),m=3*(d-h),y=3*h;for(l=0;l<t.length;l++)o=g*(c=t[l])[n][r]+v*c[n+1][r]+m*c[n+2][r]+y*c[n+3][r],s=g*c[n][r+1]+v*c[n+1][r+1]+m*c[n+2][r+1]+y*c[n+3][r+1],e[l]=u*o+i*s;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-i;for(l=0;l<t.length;l++)o=(c=t[l])[n+1][r]-c[n][r],s=c[n+1][r+1]-c[n][r+1],e[l]=u*o+i*s;return e}}},{}],912:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=e-2,o=r-2;return n&&i?function(e,r,n){var i,s,l,c,u,h;e||(e=[]);var f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));f*=3,p*=3;var v=d*d,m=v*d,y=1-d,x=y*y,b=x*y,_=g*g,w=_*g,k=1-g,T=k*k,A=T*k;for(h=0;h<t.length;h++)i=b*(u=t[h])[p][f]+3*(x*d*u[p][f+1]+y*v*u[p][f+2])+m*u[p][f+3],s=b*u[p+1][f]+3*(x*d*u[p+1][f+1]+y*v*u[p+1][f+2])+m*u[p+1][f+3],l=b*u[p+2][f]+3*(x*d*u[p+2][f+1]+y*v*u[p+2][f+2])+m*u[p+2][f+3],c=b*u[p+3][f]+3*(x*d*u[p+3][f+1]+y*v*u[p+3][f+2])+m*u[p+3][f+3],e[h]=A*i+3*(T*g*s+k*_*l)+w*c;return e}:n?function(e,r,n){e||(e=[]);var i,s,l,c,u,h,f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));f*=3;var v=d*d,m=v*d,y=1-d,x=y*y,b=x*y,_=1-g;for(u=0;u<t.length;u++)i=_*(h=t[u])[p][f]+g*h[p+1][f],s=_*h[p][f+1]+g*h[p+1][f+1],l=_*h[p][f+2]+g*h[p+1][f+1],c=_*h[p][f+3]+g*h[p+1][f+1],e[u]=b*i+3*(x*d*s+y*v*l)+m*c;return e}:i?function(e,r,n){e||(e=[]);var i,s,l,c,u,h,f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));p*=3;var v=g*g,m=v*g,y=1-g,x=y*y,b=x*y,_=1-d;for(u=0;u<t.length;u++)i=_*(h=t[u])[p][f]+d*h[p][f+1],s=_*h[p+1][f]+d*h[p+1][f+1],l=_*h[p+2][f]+d*h[p+2][f+1],c=_*h[p+3][f]+d*h[p+3][f+1],e[u]=b*i+3*(x*g*s+y*v*l)+m*c;return e}:function(e,r,n){e||(e=[]);var i,s,l,c,u=Math.max(0,Math.min(Math.floor(r),a)),h=Math.max(0,Math.min(Math.floor(n),o)),f=Math.max(0,Math.min(1,r-u)),p=Math.max(0,Math.min(1,n-h)),d=1-p,g=1-f;for(l=0;l<t.length;l++)i=g*(c=t[l])[h][u]+f*c[h][u+1],s=g*c[h+1][u]+f*c[h+1][u+1],e[l]=d*i+p*s;return e}}},{}],913:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xy_defaults\"),a=t(\"./ab_defaults\"),o=t(\"./attributes\"),s=t(\"../../components/color/attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,o,r,i)}e._clipPathId=\"clip\"+e.uid+\"carpet\";var u=c(\"color\",s.defaultLine);(n.coerceFont(c,\"font\"),c(\"carpet\"),a(t,e,l,c,u),e.a&&e.b)?(e.a.length<3&&(e.aaxis.smoothing=0),e.b.length<3&&(e.baxis.smoothing=0),i(t,e,c)||(e.visible=!1),e._cheater&&c(\"cheaterslope\")):e.visible=!1}},{\"../../components/color/attributes\":592,\"../../lib\":719,\"./ab_defaults\":896,\"./attributes\":898,\"./xy_defaults\":922}],914:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),plot:t(\"./plot\"),calc:t(\"./calc\"),animatable:!0,isContainer:!0,moduleType:\"trace\",name:\"carpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"carpetAxis\",\"notLegendIsolatable\",\"noMultiCategory\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":898,\"./calc\":902,\"./defaults\":913,\"./plot\":919}],915:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r,n=t._fullData.length,i=0;i<n;i++){var a=t._fullData[i];if(a.index!==e.index&&(\"carpet\"===a.type&&(r||(r=a),a.carpet===e.carpet)))return a}return r}},{}],916:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(0===t.length)return\"\";var n,i=[],a=r?3:1;for(n=0;n<t.length;n+=a)i.push(t[n]+\",\"+e[n]),r&&n<t.length-a&&(i.push(\"C\"),i.push([t[n+1]+\",\"+e[n+1],t[n+2]+\",\"+e[n+2]+\" \"].join(\" \")));return i.join(r?\"\":\"L\")}},{}],917:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i;for(n(t)?t.length>e.length&&(t=t.slice(0,e.length)):t=[],i=0;i<e.length;i++)t[i]=r(e[i]);return t}},{\"../../lib\":719}],918:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i[0]*t.dpdx(e),s=i[1]*t.dpdy(r),l=1,c=1;if(a){var u=Math.sqrt(i[0]*i[0]+i[1]*i[1]),h=Math.sqrt(a[0]*a[0]+a[1]*a[1]),f=(i[0]*a[0]+i[1]*a[1])/u/h;c=Math.max(0,f)}var p=180*Math.atan2(s,o)/Math.PI;return p<-90?(p+=180,l=-l):p>90&&(p-=180,l=-l),{angle:p,flip:l,p:t.c2p(n,e,r),offsetMultplier:c}}},{}],919:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"./map_1d_array\"),o=t(\"./makepath\"),s=t(\"./orient_text\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib\"),u=t(\"../../constants/alignment\");function h(t,e,r,i,s,l){var c=\"const-\"+s+\"-lines\",u=r.selectAll(\".\"+c).data(l);u.enter().append(\"path\").classed(c,!0).style(\"vector-effect\",\"non-scaling-stroke\"),u.each(function(r){var i=r,s=i.x,l=i.y,c=a([],s,t.c2p),u=a([],l,e.c2p),h=\"M\"+o(c,u,i.smoothing);n.select(this).attr(\"d\",h).style(\"stroke-width\",i.width).style(\"stroke\",i.color).style(\"fill\",\"none\")}),u.exit().remove()}function f(t,e,r,a,o,c,u,h){var f=c.selectAll(\"text.\"+h).data(u);f.enter().append(\"text\").classed(h,!0);var p=0,d={};return f.each(function(o,c){var u;if(\"auto\"===o.axis.tickangle)u=s(a,e,r,o.xy,o.dxy);else{var h=(o.axis.tickangle+180)*Math.PI/180;u=s(a,e,r,o.xy,[Math.cos(h),Math.sin(h)])}c||(d={angle:u.angle,flip:u.flip});var f=(o.endAnchor?-1:1)*u.flip,g=n.select(this).attr({\"text-anchor\":f>0?\"start\":\"end\",\"data-notex\":1}).call(i.font,o.font).text(o.text).call(l.convertToTspans,t),v=i.bBox(this);g.attr(\"transform\",\"translate(\"+u.p[0]+\",\"+u.p[1]+\") rotate(\"+u.angle+\")translate(\"+o.axis.labelpadding*f+\",\"+.3*v.height+\")\"),p=Math.max(p,v.width+o.axis.labelpadding)}),f.exit().remove(),d.maxExtent=p,d}e.exports=function(t,e,r,i){var l=e.xaxis,u=e.yaxis,p=t._fullLayout._clips;c.makeTraceGroups(i,r,\"trace\").each(function(e){var r=n.select(this),i=e[0],d=i.trace,v=d.aaxis,m=d.baxis,y=c.ensureSingle(r,\"g\",\"minorlayer\"),x=c.ensureSingle(r,\"g\",\"majorlayer\"),b=c.ensureSingle(r,\"g\",\"boundarylayer\"),_=c.ensureSingle(r,\"g\",\"labellayer\");r.style(\"opacity\",d.opacity),h(l,u,x,v,\"a\",v._gridlines),h(l,u,x,m,\"b\",m._gridlines),h(l,u,y,v,\"a\",v._minorgridlines),h(l,u,y,m,\"b\",m._minorgridlines),h(l,u,b,v,\"a-boundary\",v._boundarylines),h(l,u,b,m,\"b-boundary\",m._boundarylines);var w=f(t,l,u,d,i,_,v._labels,\"a-label\"),k=f(t,l,u,d,i,_,m._labels,\"b-label\");!function(t,e,r,n,i,a,o,l){var u,h,f,p,d=c.aggNums(Math.min,null,r.a),v=c.aggNums(Math.max,null,r.a),m=c.aggNums(Math.min,null,r.b),y=c.aggNums(Math.max,null,r.b);u=.5*(d+v),h=m,f=r.ab2xy(u,h,!0),p=r.dxyda_rough(u,h),void 0===o.angle&&c.extendFlat(o,s(r,i,a,f,r.dxydb_rough(u,h)));g(t,e,r,n,f,p,r.aaxis,i,a,o,\"a-title\"),u=d,h=.5*(m+y),f=r.ab2xy(u,h,!0),p=r.dxydb_rough(u,h),void 0===l.angle&&c.extendFlat(l,s(r,i,a,f,r.dxyda_rough(u,h)));g(t,e,r,n,f,p,r.baxis,i,a,l,\"b-title\")}(t,_,d,i,l,u,w,k),function(t,e,r,n,i){var s,l,u,h,f=r.select(\"#\"+t._clipPathId);f.size()||(f=r.append(\"clipPath\").classed(\"carpetclip\",!0));var p=c.ensureSingle(f,\"path\",\"carpetboundary\"),d=e.clipsegments,g=[];for(h=0;h<d.length;h++)s=d[h],l=a([],s.x,n.c2p),u=a([],s.y,i.c2p),g.push(o(l,u,s.bicubic));var v=\"M\"+g.join(\"L\")+\"Z\";f.attr(\"id\",t._clipPathId),p.attr(\"d\",v)}(d,i,p,l,u)})};var p=u.LINE_SPACING,d=(1-u.MID_SHIFT)/p+1;function g(t,e,r,a,o,c,u,h,f,g,v){var m=[];u.title.text&&m.push(u.title.text);var y=e.selectAll(\"text.\"+v).data(m),x=g.maxExtent;y.enter().append(\"text\").classed(v,!0),y.each(function(){var e=s(r,h,f,o,c);-1===[\"start\",\"both\"].indexOf(u.showticklabels)&&(x=0);var a=u.title.font.size;x+=a+u.title.offset;var v=(g.angle+(g.flip<0?180:0)-e.angle+450)%360,m=v>90&&v<270,y=n.select(this);y.text(u.title.text).call(l.convertToTspans,t),m&&(x=(-l.lineCount(y)+d)*p*a-x),y.attr(\"transform\",\"translate(\"+e.p[0]+\",\"+e.p[1]+\") rotate(\"+e.angle+\") translate(0,\"+x+\")\").classed(\"user-select-none\",!0).attr(\"text-anchor\",\"middle\").call(i.font,u.title.font)}),y.exit().remove()}},{\"../../components/drawing\":614,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"./makepath\":916,\"./map_1d_array\":917,\"./orient_text\":918,d3:163}],920:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/search\").findBin,a=t(\"./compute_control_points\"),o=t(\"./create_spline_evaluator\"),s=t(\"./create_i_derivative_evaluator\"),l=t(\"./create_j_derivative_evaluator\");e.exports=function(t){var e=t._a,r=t._b,c=e.length,u=r.length,h=t.aaxis,f=t.baxis,p=e[0],d=e[c-1],g=r[0],v=r[u-1],m=e[e.length-1]-e[0],y=r[r.length-1]-r[0],x=m*n.RELATIVE_CULL_TOLERANCE,b=y*n.RELATIVE_CULL_TOLERANCE;p-=x,d+=x,g-=b,v+=b,t.isVisible=function(t,e){return t>p&&t<d&&e>g&&e<v},t.isOccluded=function(t,e){return t<p||t>d||e<g||e>v},t.setScale=function(){var e=t._x,r=t._y,n=a(t._xctrl,t._yctrl,e,r,h.smoothing,f.smoothing);t._xctrl=n[0],t._yctrl=n[1],t.evalxy=o([t._xctrl,t._yctrl],c,u,h.smoothing,f.smoothing),t.dxydi=s([t._xctrl,t._yctrl],h.smoothing,f.smoothing),t.dxydj=l([t._xctrl,t._yctrl],h.smoothing,f.smoothing)},t.i2a=function(t){var r=Math.max(0,Math.floor(t[0]),c-2),n=t[0]-r;return(1-n)*e[r]+n*e[r+1]},t.j2b=function(t){var e=Math.max(0,Math.floor(t[1]),c-2),n=t[1]-e;return(1-n)*r[e]+n*r[e+1]},t.ij2ab=function(e){return[t.i2a(e[0]),t.j2b(e[1])]},t.a2i=function(t){var r=Math.max(0,Math.min(i(t,e),c-2)),n=e[r],a=e[r+1];return Math.max(0,Math.min(c-1,r+(t-n)/(a-n)))},t.b2j=function(t){var e=Math.max(0,Math.min(i(t,r),u-2)),n=r[e],a=r[e+1];return Math.max(0,Math.min(u-1,e+(t-n)/(a-n)))},t.ab2ij=function(e){return[t.a2i(e[0]),t.b2j(e[1])]},t.i2c=function(e,r){return t.evalxy([],e,r)},t.ab2xy=function(n,i,a){if(!a&&(n<e[0]||n>e[c-1]|i<r[0]||i>r[u-1]))return[!1,!1];var o=t.a2i(n),s=t.b2j(i),l=t.evalxy([],o,s);if(a){var h,f,p,d,g=0,v=0,m=[];n<e[0]?(h=0,f=0,g=(n-e[0])/(e[1]-e[0])):n>e[c-1]?(h=c-2,f=1,g=(n-e[c-1])/(e[c-1]-e[c-2])):f=o-(h=Math.max(0,Math.min(c-2,Math.floor(o)))),i<r[0]?(p=0,d=0,v=(i-r[0])/(r[1]-r[0])):i>r[u-1]?(p=u-2,d=1,v=(i-r[u-1])/(r[u-1]-r[u-2])):d=s-(p=Math.max(0,Math.min(u-2,Math.floor(s)))),g&&(t.dxydi(m,h,p,f,d),l[0]+=m[0]*g,l[1]+=m[1]*g),v&&(t.dxydj(m,h,p,f,d),l[0]+=m[0]*v,l[1]+=m[1]*v)}return l},t.c2p=function(t,e,r){return[e.c2p(t[0]),r.c2p(t[1])]},t.p2x=function(t,e,r){return[e.p2c(t[0]),r.p2c(t[1])]},t.dadi=function(t){var r=Math.max(0,Math.min(e.length-2,t));return e[r+1]-e[r]},t.dbdj=function(t){var e=Math.max(0,Math.min(r.length-2,t));return r[e+1]-r[e]},t.dxyda=function(e,r,n,i){var a=t.dxydi(null,e,r,n,i),o=t.dadi(e,n);return[a[0]/o,a[1]/o]},t.dxydb=function(e,r,n,i){var a=t.dxydj(null,e,r,n,i),o=t.dbdj(r,i);return[a[0]/o,a[1]/o]},t.dxyda_rough=function(e,r,n){var i=m*(n||.1),a=t.ab2xy(e+i,r,!0),o=t.ab2xy(e-i,r,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dxydb_rough=function(e,r,n){var i=y*(n||.1),a=t.ab2xy(e,r+i,!0),o=t.ab2xy(e,r-i,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dpdx=function(t){return t._m},t.dpdy=function(t){return t._m}}},{\"../../lib/search\":738,\"./compute_control_points\":908,\"./constants\":909,\"./create_i_derivative_evaluator\":910,\"./create_j_derivative_evaluator\":911,\"./create_spline_evaluator\":912}],921:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r){var i,a,o,s=[],l=[],c=t[0].length,u=t.length;function h(e,r){var n,i=0,a=0;return e>0&&void 0!==(n=t[r][e-1])&&(a++,i+=n),e<c-1&&void 0!==(n=t[r][e+1])&&(a++,i+=n),r>0&&void 0!==(n=t[r-1][e])&&(a++,i+=n),r<u-1&&void 0!==(n=t[r+1][e])&&(a++,i+=n),i/Math.max(1,a)}var f,p,d,g,v,m,y,x,b,_,w,k=0;for(i=0;i<c;i++)for(a=0;a<u;a++)void 0===t[a][i]&&(s.push(i),l.push(a),t[a][i]=h(i,a)),k=Math.max(k,Math.abs(t[a][i]));if(!s.length)return t;var T=0,A=0,M=s.length;do{for(T=0,o=0;o<M;o++){i=s[o],a=l[o];var S,E,C,L,P,O,z=0,I=0;0===i?(C=e[P=Math.min(c-1,2)],L=e[1],S=t[a][P],I+=(E=t[a][1])+(E-S)*(e[0]-L)/(L-C),z++):i===c-1&&(C=e[P=Math.max(0,c-3)],L=e[c-2],S=t[a][P],I+=(E=t[a][c-2])+(E-S)*(e[c-1]-L)/(L-C),z++),(0===i||i===c-1)&&a>0&&a<u-1&&(f=r[a+1]-r[a],I+=((p=r[a]-r[a-1])*t[a+1][i]+f*t[a-1][i])/(p+f),z++),0===a?(C=r[O=Math.min(u-1,2)],L=r[1],S=t[O][i],I+=(E=t[1][i])+(E-S)*(r[0]-L)/(L-C),z++):a===u-1&&(C=r[O=Math.max(0,u-3)],L=r[u-2],S=t[O][i],I+=(E=t[u-2][i])+(E-S)*(r[u-1]-L)/(L-C),z++),(0===a||a===u-1)&&i>0&&i<c-1&&(f=e[i+1]-e[i],I+=((p=e[i]-e[i-1])*t[a][i+1]+f*t[a][i-1])/(p+f),z++),z?I/=z:(d=e[i+1]-e[i],g=e[i]-e[i-1],x=(v=r[a+1]-r[a])*(m=r[a]-r[a-1])*(v+m),I=((y=d*g*(d+g))*(m*t[a+1][i]+v*t[a-1][i])+x*(g*t[a][i+1]+d*t[a][i-1]))/(x*(g+d)+y*(m+v))),T+=(_=(b=I-t[a][i])/k)*_,w=z?0:.85,t[a][i]+=b*(1+w)}T=Math.sqrt(T)}while(A++<100&&T>1e-5);return n.log(\"Smoother converged to\",T,\"after\",A,\"iterations\"),t}},{\"../../lib\":719}],922:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArray1D;e.exports=function(t,e,r){var i=r(\"x\"),a=i&&i.length,o=r(\"y\"),s=o&&o.length;if(!a&&!s)return!1;if(e._cheater=!i,a&&!n(i)||s&&!n(o))e._length=null;else{var l=a?i.length:1/0;s&&(l=Math.min(l,o.length)),e.a&&e.a.length&&(l=Math.min(l,e.a.length)),e.b&&e.b.length&&(l=Math.min(l,e.b.length)),e._length=l}return!0}},{\"../../lib\":719}],923:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scattergeo/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/color/attributes\").defaultLine,l=t(\"../../lib/extend\").extendFlat,c=i.marker.line;e.exports=l({locations:{valType:\"data_array\",editType:\"calc\"},locationmode:i.locationmode,z:{valType:\"data_array\",editType:\"calc\"},text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),marker:{line:{color:l({},c.color,{dflt:s}),width:l({},c.width,{dflt:1}),editType:\"calc\"},opacity:{valType:\"number\",arrayOk:!0,min:0,max:1,dflt:1,editType:\"style\"},editType:\"calc\"},selected:{marker:{opacity:i.selected.marker.opacity,editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:i.unselected.marker.opacity,editType:\"plot\"},editType:\"plot\"},hoverinfo:l({},o.hoverinfo,{editType:\"calc\",flags:[\"location\",\"z\",\"text\",\"name\"]}),hovertemplate:n()},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/color/attributes\":592,\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scattergeo/attributes\":1151}],924:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../components/colorscale/calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\");function l(t){return t&&\"string\"==typeof t}e.exports=function(t,e){var r,c=e._length,u=new Array(c);r=e.geojson?function(t){return l(t)||n(t)}:l;for(var h=0;h<c;h++){var f=u[h]={},p=e.locations[h],d=e.z[h];r(p)&&n(d)?(f.loc=p,f.z=d):(f.loc=null,f.z=i),f.index=h}return o(u,e),a(t,e,{vals:e.z,containerStr:\"\",cLetter:\"z\"}),s(u,e),u}},{\"../../components/colorscale/calc\":601,\"../../constants/numerical\":695,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc_selection\":1114,\"fast-isnumeric\":225}],925:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\");l&&l.length&&n.isArrayOrTypedArray(c)&&c.length?(e._length=Math.min(l.length,c.length),s(\"locationmode\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":923}],926:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){t.location=e.location,t.z=e.z;var a=n[i];return a.fIn&&(t.properties=a.fIn.properties),t}},{}],927:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"./attributes\"),a=t(\"../../lib\").fillText;e.exports=function(t,e,r){var o,s,l,c,u=t.cd,h=u[0].trace,f=t.subplot;for(s=0;s<u.length;s++)if(c=!1,(o=u[s])._polygons){for(l=0;l<o._polygons.length;l++)o._polygons[l].contains([e,r])&&(c=!c),o._polygons[l].contains([e+360,r])&&(c=!c);if(c)break}if(c&&o)return t.x0=t.x1=t.xa.c2p(o.ct),t.y0=t.y1=t.ya.c2p(o.ct),t.index=o.index,t.location=o.loc,t.z=o.z,t.zLabel=n.tickText(f.mockAxis,f.mockAxis.c2l(o.z),\"hover\").text,t.hovertemplate=o.hovertemplate,function(t,e,r){if(e.hovertemplate)return;var n=r.hi||e.hoverinfo,o=\"all\"===n?i.hoverinfo.flags:n.split(\"+\"),s=-1!==o.indexOf(\"name\"),l=-1!==o.indexOf(\"location\"),c=-1!==o.indexOf(\"z\"),u=-1!==o.indexOf(\"text\"),h=[];!s&&l?t.nameOverride=r.loc:(s&&(t.nameOverride=e.name),l&&h.push(r.loc));c&&h.push(t.zLabel);u&&a(r,e,h);t.extraText=h.join(\"<br>\")}(t,h,o,f.mockAxis),[t]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./attributes\":923}],928:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"choropleth\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"noOpacity\"],meta:{}}},{\"../../plots/geo\":797,\"../heatmap/colorbar\":1004,\"./attributes\":923,\"./calc\":924,\"./defaults\":925,\"./event_data\":926,\"./hover\":927,\"./plot\":929,\"./select\":930,\"./style\":931}],929:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../lib/polygon\"),o=t(\"../../lib/topojson_utils\").getTopojsonFeatures,s=t(\"../../lib/geo_location_utils\").locationToFeature,l=t(\"./style\").style;function c(t,e){for(var r=t[0].trace,n=t.length,i=o(r,e),a=0;a<n;a++){var l=t[a],c=s(r.locationmode,l.loc,i);c?(l.geojson=c,l.ct=c.properties.ct,l._polygons=u(c)):l.geojson=null}}function u(t){var e,r,n,i,o=t.geometry,s=o.coordinates,l=t.id,c=[];function u(t){for(var e=0;e<t.length-1;e++)if(t[e][0]>0&&t[e+1][0]<0)return e;return null}switch(e=\"RUS\"===l||\"FJI\"===l?function(t){var e;if(null===u(t))e=t;else for(e=new Array(t.length),i=0;i<t.length;i++)e[i]=[t[i][0]<0?t[i][0]+360:t[i][0],t[i][1]];c.push(a.tester(e))}:\"ATA\"===l?function(t){var e=u(t);if(null===e)return c.push(a.tester(t));var r=new Array(t.length+1),n=0;for(i=0;i<t.length;i++)i>e?r[n++]=[t[i][0]+360,t[i][1]]:i===e?(r[n++]=t[i],r[n++]=[t[i][0],-90]):r[n++]=t[i];var o=a.tester(r);o.pts.pop(),c.push(o)}:function(t){c.push(a.tester(t))},o.type){case\"MultiPolygon\":for(r=0;r<s.length;r++)for(n=0;n<s[r].length;n++)e(s[r][n]);break;case\"Polygon\":for(r=0;r<s.length;r++)e(s[r])}return c}e.exports={plot:function(t,e,r){for(var a=0;a<r.length;a++)c(r[a],e.topojson);var o=e.layers.backplot.select(\".choroplethlayer\");i.makeTraceGroups(o,r,\"trace choropleth\").each(function(e){var r=n.select(this).selectAll(\"path.choroplethlocation\").data(i.identity);r.enter().append(\"path\").classed(\"choroplethlocation\",!0),r.exit().remove(),l(t,e)})},feature2polygons:u}},{\"../../lib\":719,\"../../lib/geo_location_utils\":713,\"../../lib/polygon\":731,\"../../lib/topojson_utils\":746,\"./style\":931,d3:163}],930:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)(i=(n=s[r]).ct)&&(a=l.c2p(i),o=c.c2p(i),e.contains([a,o],null,r,t)?(u.push({pointNumber:r,lon:i[0],lat:i[1]}),n.selected=1):n.selected=0);return u}},{}],931:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../components/colorscale\");function s(t,e){var r=e[0].trace,s=e[0].node3.selectAll(\".choroplethlocation\"),l=r.marker||{},c=l.line||{},u=o.makeColorScaleFuncFromTrace(r);s.each(function(t){n.select(this).attr(\"fill\",u(t.z)).call(i.stroke,t.mlc||c.color).call(a.dashLine,\"\",t.mlw||c.width||0).style(\"opacity\",l.opacity)}),a.selectedPointStyle(s,r,t)}e.exports={style:function(t,e){e&&s(t,e)},styleOnSelect:function(t,e){var r=e[0].node3,n=e[0].trace;n.selectedpoints?a.selectedPointStyle(r.selectAll(\".choroplethlocation\"),n,t):s(t,e)}}},{\"../../components/color\":593,\"../../components/colorscale\":605,\"../../components/drawing\":614,d3:163}],932:[function(t,e,r){\"use strict\";var n=t(\"../choropleth/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../lib/extend\").extendFlat;e.exports=o({locations:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},geojson:{valType:\"any\",editType:\"calc\"},below:{valType:\"string\",editType:\"plot\"},text:n.text,hovertext:n.hovertext,marker:{line:{color:o({},n.marker.line.color,{editType:\"plot\"}),width:o({},n.marker.line.width,{editType:\"plot\"}),editType:\"calc\"},opacity:o({},n.marker.opacity,{editType:\"plot\"}),editType:\"calc\"},selected:{marker:{opacity:o({},n.selected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:o({},n.unselected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},hoverinfo:n.hoverinfo,hovertemplate:a({},{keys:[\"properties\"]})},i(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../choropleth/attributes\":923}],933:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"@turf/area\"),a=t(\"@turf/centroid\"),o=t(\"../../lib\"),s=t(\"../../components/colorscale\"),l=t(\"../../components/drawing\"),c=t(\"../../lib/geojson_utils\").makeBlank,u=t(\"../choropleth/plot\").feature2polygons;function h(t){var e,r=t[0].trace,n=r._opts;if(r.selectedpoints){for(var i=l.makeSelectedPointStyleFns(r),a=0;a<t.length;a++){var s=t[a];s.fOut&&(s.fOut.properties.mo2=i.selectedOpacityFn(s))}e={type:\"identity\",property:\"mo2\"}}else e=o.isArrayOrTypedArray(r.marker.opacity)?{type:\"identity\",property:\"mo\"}:r.marker.opacity;return o.extendFlat(n.fill.paint,{\"fill-opacity\":e}),o.extendFlat(n.line.paint,{\"line-opacity\":e}),n}e.exports={convert:function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,l={layout:{visibility:\"none\"},paint:{}},f={layout:{visibility:\"none\"},paint:{}},p=e._opts={fill:l,line:f,geojson:c()};if(!r)return p;var d=\"string\"==typeof e.geojson?(window.PlotlyGeoAssets||{})[e.geojson]:e.geojson;if(!o.isPlainObject(d))return o.error(\"Oops ... something when wrong when fetching \"+e.geojson),p;var g,v={},m=[];for(g=0;g<t.length;g++){var y=t[g];y.loc&&(v[y.loc]=y)}var x,b,_,w=s.makeColorScaleFuncFromTrace(e),k=e.marker,T=k.line||{};function A(t){var e=v[t.id];if(e){var r=t.geometry;if(\"Polygon\"===r.type||\"MultiPolygon\"===r.type){var n={fc:w(e.z)};x&&(n.mo=x(e)),b&&(n.mlc=b(e)),_&&(n.mlw=_(e));var s={type:\"Feature\",geometry:r,properties:n};e._polygons=u(s),e.ct=function(t){var e,r=t.geometry;if(\"MultiPolygon\"===r.type)for(var n=r.coordinates,o=0,s=0;s<n.length;s++){var l={type:\"Polygon\",coordinates:n[s]},c=i.default(l);c>o&&(o=c,e=l)}else e=r;return a.default(e).geometry.coordinates}(s),e.fIn=t,e.fOut=s,m.push(s)}else o.log([\"Location with id\",e.loc,\"does not have a valid GeoJSON geometry,\",\"choroplethmapbox traces only support *Polygon* and *MultiPolygon* geometries.\"].join(\" \"))}delete v[t.id]}switch(o.isArrayOrTypedArray(k.opacity)&&(x=function(t){var e=t.mo;return n(e)?+o.constrain(e,0,1):0}),o.isArrayOrTypedArray(T.color)&&(b=function(t){return t.mlc}),o.isArrayOrTypedArray(T.width)&&(_=function(t){return t.mlw}),d.type){case\"FeatureCollection\":var M=d.features;for(g=0;g<M.length;g++)A(M[g]);break;case\"Feature\":A(d);break;default:return o.warn([\"Invalid GeoJSON type\",(d.type||\"none\")+\",\",\"choroplethmapbox traces only support *FeatureCollection* and *Feature* types.\"].join(\" \")),p}for(var S in v)o.log(\"Location with id \"+S+\" does not have a matching feature\");var E=x?{type:\"identity\",property:\"mo\"}:k.opacity;return o.extendFlat(l.paint,{\"fill-color\":{type:\"identity\",property:\"fc\"},\"fill-opacity\":E}),o.extendFlat(f.paint,{\"line-color\":b?{type:\"identity\",property:\"mlc\"}:T.color,\"line-width\":_?{type:\"identity\",property:\"mlw\"}:T.width,\"line-opacity\":E}),l.layout.visibility=\"visible\",f.layout.visibility=\"visible\",p.geojson={type:\"FeatureCollection\",features:m},h(t),p},convertOnSelect:h}},{\"../../components/colorscale\":605,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/geojson_utils\":714,\"../choropleth/plot\":929,\"@turf/area\":55,\"@turf/centroid\":56,\"fast-isnumeric\":225}],934:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\"),u=s(\"geojson\");n.isArrayOrTypedArray(l)&&l.length&&n.isArrayOrTypedArray(c)&&c.length&&(\"string\"==typeof u&&\"\"!==u||n.isPlainObject(u))?(e._length=Math.min(l.length,c.length),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":932}],935:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../choropleth/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"../choropleth/hover\"),eventData:t(\"../choropleth/event_data\"),selectPoints:t(\"../choropleth/select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.updateOnSelect(e)},getBelow:function(t,e){for(var r=e.getMapLayers(),n=r.length-2;n>=0;n--){var i=r[n].id;if(\"string\"==typeof i&&0===i.indexOf(\"water\"))for(var a=n+1;a<r.length;a++)if(\"string\"==typeof(i=r[a].id)&&-1===i.indexOf(\"plotly-\"))return i}},moduleType:\"trace\",name:\"choroplethmapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"noOpacity\"],meta:{hr_name:\"choropleth_mapbox\"}}},{\"../../plots/mapbox\":822,\"../choropleth/calc\":924,\"../choropleth/event_data\":926,\"../choropleth/hover\":927,\"../choropleth/select\":930,\"../heatmap/colorbar\":1004,\"./attributes\":932,\"./defaults\":934,\"./plot\":936}],936:[function(t,e,r){\"use strict\";var n=t(\"./convert\").convert,i=t(\"./convert\").convertOnSelect,a=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function o(t,e){this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"fill\",a+e+\"-fill\"],[\"line\",a+e+\"-line\"]],this.below=null}var s=o.prototype;s.update=function(t){this._update(n(t))},s.updateOnSelect=function(t){this._update(i(t))},s._update=function(t){var e=this.subplot,r=this.layerList,n=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(t.geojson),n!==this.below&&(this._removeLayers(),this._addLayers(t,n),this.below=n);for(var i=0;i<r.length;i++){var a=r[i],o=a[0],s=a[1],l=t[o];e.setOptions(s,\"setLayoutProperty\",l.layout),\"visible\"===l.layout.visibility&&e.setOptions(s,\"setPaintProperty\",l.paint)}},s._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},s._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},s.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new o(t,r.uid),a=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(a,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":820,\"./convert\":933}],937:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"scaled\",\"absolute\"],editType:\"calc\",dflt:\"scaled\"},sizeref:{valType:\"number\",editType:\"calc\",min:0},anchor:{valType:\"enumerated\",editType:\"calc\",values:[\"tip\",\"tail\",\"cm\",\"center\"],dflt:\"cm\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:i({editType:\"calc\"},{keys:[\"norm\"]})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach(function(t){l[t]=a[t]}),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../mesh3d/attributes\":1053}],938:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){for(var r=e.u,i=e.v,a=e.w,o=Math.min(e.x.length,e.y.length,e.z.length,r.length,i.length,a.length),s=-1/0,l=1/0,c=0;c<o;c++){var u=r[c],h=i[c],f=a[c],p=Math.sqrt(u*u+h*h+f*f);s=Math.max(s,p),l=Math.min(l,p)}e._len=o,e._normMax=s,n(t,e,{vals:[l,s],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],939:[function(t,e,r){\"use strict\";var n=t(\"gl-cone3d\"),i=t(\"gl-cone3d\").createConeMesh,a=t(\"../../lib\").simpleMap,o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\");function c(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var u=c.prototype;u.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index,r=this.data.x[e],n=this.data.y[e],i=this.data.z[e],a=this.data.u[e],o=this.data.v[e],s=this.data.w[e];t.traceCoordinate=[r,n,i,a,o,s,Math.sqrt(a*a+o*o+s*s)];var l=this.data.hovertext||this.data.text;return Array.isArray(l)&&void 0!==l[e]?t.textLabel=l[e]:l&&(t.textLabel=l),!0}};var h={xaxis:0,yaxis:1,zaxis:2},f={tip:1,tail:0,cm:.25,center:.5},p={tip:1,tail:1,cm:.75,center:.5};function d(t,e){var r=t.fullSceneLayout,i=t.dataScale,c={};function u(t,e){var n=r[e],o=i[h[e]];return a(t,function(t){return n.d2l(t)*o})}c.vectors=l(u(e.u,\"xaxis\"),u(e.v,\"yaxis\"),u(e.w,\"zaxis\"),e._len),c.positions=l(u(e.x,\"xaxis\"),u(e.y,\"yaxis\"),u(e.z,\"zaxis\"),e._len);var d=s(e);c.colormap=o(e),c.vertexIntensityBounds=[d.min/e._normMax,d.max/e._normMax],c.coneOffset=f[e.anchor],\"scaled\"===e.sizemode?c.coneSize=e.sizeref||.5:c.coneSize=e.sizeref&&e._normMax?e.sizeref/e._normMax:.5;var g=n(c),v=e.lightposition;return g.lightPosition=[v.x,v.y,v.z],g.ambient=e.lighting.ambient,g.diffuse=e.lighting.diffuse,g.specular=e.lighting.specular,g.roughness=e.lighting.roughness,g.fresnel=e.lighting.fresnel,g.opacity=e.opacity,e._pad=p[e.anchor]*g.vectorScale*g.coneScale*e._normMax,g}u.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),a=i(r,n),o=new c(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../plots/gl3d/zip3\":818,\"gl-cone3d\":242}],940:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),h=s(\"x\"),f=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length&&p&&p.length?(s(\"sizeref\"),s(\"sizemode\"),s(\"anchor\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":937}],941:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"cone\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),eventData:function(t,e){return t.norm=e.traceCoordinate[6],t},meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":937,\"./calc\":938,\"./convert\":939,\"./defaults\":940}],942:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../components/drawing/attributes\").dash,s=t(\"../../plots/font_attributes\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../constants/filter_ops\"),u=c.COMPARISON_OPS2,h=c.INTERVAL_OPS,f=(t(\"../../constants/docs\").FORMAT_LINK,i.line);e.exports=l({z:n.z,x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,xtype:n.xtype,ytype:n.ytype,zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate,connectgaps:n.connectgaps,fillcolor:{valType:\"color\",editType:\"calc\"},autocontour:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"contours.start\":void 0,\"contours.end\":void 0,\"contours.size\":void 0}},ncontours:{valType:\"integer\",dflt:15,min:1,editType:\"calc\"},contours:{type:{valType:\"enumerated\",values:[\"levels\",\"constraint\"],dflt:\"levels\",editType:\"calc\"},start:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},end:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},coloring:{valType:\"enumerated\",values:[\"fill\",\"heatmap\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:{valType:\"boolean\",dflt:!0,editType:\"plot\"},showlabels:{valType:\"boolean\",dflt:!1,editType:\"plot\"},labelfont:s({editType:\"plot\",colorEditType:\"style\"}),labelformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},operation:{valType:\"enumerated\",values:[].concat(u).concat(h),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:l({},f.color,{editType:\"style+colorbars\"}),width:l({},f.width,{editType:\"style+colorbars\"}),dash:o,smoothing:l({},f.smoothing,{}),editType:\"plot\"}},a(\"\",{cLetter:\"z\",autoColorDflt:!1,editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../components/drawing/attributes\":613,\"../../constants/docs\":690,\"../../constants/filter_ops\":691,\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"../heatmap/attributes\":1001,\"../scatter/attributes\":1112}],943:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\"),i=t(\"../heatmap/calc\"),a=t(\"./set_contours\"),o=t(\"./end_plus\");e.exports=function(t,e){var r=i(t,e),s=r[0].z;a(e,s);var l,c=e.contours,u=n.extractOpts(e);if(\"heatmap\"===c.coloring&&u.auto&&!1===e.autocontour){var h=c.start,f=o(c),p=c.size||1,d=Math.floor((f-h)/p)+1;isFinite(p)||(p=1,d=1);var g=h-p/2;l=[g,g+d*p]}else l=s;return n.calc(t,e,{vals:l,cLetter:\"z\"}),r}},{\"../../components/colorscale\":605,\"../heatmap/calc\":1002,\"./end_plus\":953,\"./set_contours\":961}],944:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a,o,s=t[0],l=s.x.length,c=s.y.length,u=s.z,h=n.contours,f=-1/0,p=1/0;for(i=0;i<c;i++)p=Math.min(p,u[i][0]),p=Math.min(p,u[i][l-1]),f=Math.max(f,u[i][0]),f=Math.max(f,u[i][l-1]);for(i=1;i<l-1;i++)p=Math.min(p,u[0][i]),p=Math.min(p,u[c-1][i]),f=Math.max(f,u[0][i]),f=Math.max(f,u[c-1][i]);switch(s.prefixBoundary=!1,e){case\">\":h.value>f&&(s.prefixBoundary=!0);break;case\"<\":h.value<p&&(s.prefixBoundary=!0);break;case\"[]\":a=Math.min.apply(null,h.value),((o=Math.max.apply(null,h.value))<p||a>f)&&(s.prefixBoundary=!0);break;case\"][\":a=Math.min.apply(null,h.value),o=Math.max.apply(null,h.value),a<p&&o>f&&(s.prefixBoundary=!0)}}},{}],945:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\").extractOpts,i=t(\"./make_color_map\"),a=t(\"./end_plus\");e.exports={min:\"zmin\",max:\"zmax\",calc:function(t,e,r){var o=e.contours,s=e.line,l=o.size||1,c=o.coloring,u=i(e,{isColorbar:!0});if(\"heatmap\"===c){var h=n(e);r._fillgradient=e.colorscale,r._zrange=[h.min,h.max]}else\"fill\"===c&&(r._fillcolor=u);r._line={color:\"lines\"===c?u:s.color,width:!1!==o.showlines?s.width:0,dash:s.dash},r._levels={start:o.start,end:a(o),size:l}}}},{\"../../components/colorscale\":605,\"./end_plus\":953,\"./make_color_map\":958}],946:[function(t,e,r){\"use strict\";e.exports={BOTTOMSTART:[1,9,13,104,713],TOPSTART:[4,6,7,104,713],LEFTSTART:[8,12,14,208,1114],RIGHTSTART:[2,3,11,208,1114],NEWDELTA:[null,[-1,0],[0,-1],[-1,0],[1,0],null,[0,-1],[-1,0],[0,1],[0,1],null,[0,1],[1,0],[1,0],[0,-1]],CHOOSESADDLE:{104:[4,1],208:[2,8],713:[7,13],1114:[11,14]},SADDLEREMAINDER:{1:4,2:8,4:1,7:13,8:2,11:14,13:7,14:11},LABELDISTANCE:2,LABELINCREASE:10,LABELMIN:3,LABELMAX:10,LABELOPTIMIZER:{EDGECOST:1,ANGLECOST:1,NEIGHBORCOST:5,SAMELEVELFACTOR:10,SAMELEVELDISTANCE:5,MAXCOST:100,INITIALSEARCHPOINTS:10,ITERATIONS:5}}},{}],947:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./label_defaults\"),a=t(\"../../components/color\"),o=a.addOpacity,s=a.opacity,l=t(\"../../constants/filter_ops\"),c=l.CONSTRAINT_REDUCTION,u=l.COMPARISON_OPS2;e.exports=function(t,e,r,a,l,h){var f,p,d,g=e.contours,v=r(\"contours.operation\");(g._operation=c[v],function(t,e){var r;-1===u.indexOf(e.operation)?(t(\"contours.value\",[0,1]),Array.isArray(e.value)?e.value.length>2?e.value=e.value.slice(2):0===e.length?e.value=[0,1]:e.length<2?(r=parseFloat(e.value[0]),e.value=[r,r+1]):e.value=[parseFloat(e.value[0]),parseFloat(e.value[1])]:n(e.value)&&(r=parseFloat(e.value),e.value=[r,r+1])):(t(\"contours.value\",0),n(e.value)||(Array.isArray(e.value)?e.value=parseFloat(e.value[0]):e.value=0))}(r,g),\"=\"===v?f=g.showlines=!0:(f=r(\"contours.showlines\"),d=r(\"fillcolor\",o((t.line||{}).color||l,.5))),f)&&(p=r(\"line.color\",d&&s(d)?o(e.fillcolor,1):l),r(\"line.width\",2),r(\"line.dash\"));r(\"line.smoothing\"),i(r,a,p,h)}},{\"../../components/color\":593,\"../../constants/filter_ops\":691,\"./label_defaults\":957,\"fast-isnumeric\":225}],948:[function(t,e,r){\"use strict\";var n=t(\"../../constants/filter_ops\"),i=t(\"fast-isnumeric\");function a(t,e){var r,a=Array.isArray(e);function o(t){return i(t)?+t:null}return-1!==n.COMPARISON_OPS2.indexOf(t)?r=o(a?e[0]:e):-1!==n.INTERVAL_OPS.indexOf(t)?r=a?[o(e[0]),o(e[1])]:[o(e),o(e)]:-1!==n.SET_OPS.indexOf(t)&&(r=a?e.map(o):[o(e)]),r}function o(t){return function(e){e=a(t,e);var r=Math.min(e[0],e[1]),n=Math.max(e[0],e[1]);return{start:r,end:n,size:n-r}}}function s(t){return function(e){return{start:e=a(t,e),end:1/0,size:1/0}}}e.exports={\"[]\":o(\"[]\"),\"][\":o(\"][\"),\">\":s(\">\"),\"<\":s(\"<\"),\"=\":s(\"=\")}},{\"../../constants/filter_ops\":691,\"fast-isnumeric\":225}],949:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=n(\"contours.start\"),a=n(\"contours.end\"),o=!1===i||!1===a,s=r(\"contours.size\");!(o?e.autocontour=!0:r(\"autocontour\",!1))&&s||r(\"ncontours\")}},{}],950:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");function i(t){return n.extendFlat({},t,{edgepaths:n.extendDeep([],t.edgepaths),paths:n.extendDeep([],t.paths)})}e.exports=function(t,e){var r,a,o,s=function(t){return t.reverse()},l=function(t){return t};switch(e){case\"=\":case\"<\":return t;case\">\":for(1!==t.length&&n.warn(\"Contour data invalid for the specified inequality operation.\"),a=t[0],r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);return t;case\"][\":var c=s;s=l,l=c;case\"[]\":for(2!==t.length&&n.warn(\"Contour data invalid for the specified inequality range operation.\"),a=i(t[0]),o=i(t[1]),r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);for(;o.edgepaths.length;)a.edgepaths.push(l(o.edgepaths.shift()));for(;o.paths.length;)a.paths.push(l(o.paths.shift()));return[a]}}},{\"../../lib\":719}],951:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"./constraint_defaults\"),o=t(\"./contours_defaults\"),s=t(\"./style_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,l,r,i)}if(i(t,e,u,c)){u(\"text\"),u(\"hovertext\"),u(\"hovertemplate\");var h=\"constraint\"===u(\"contours.type\");u(\"connectgaps\",n.isArray1D(e.z)),h?a(t,e,u,c,r):(o(t,e,u,function(r){return n.coerce2(t,e,l,r)}),s(t,e,u,c))}else e.visible=!1}},{\"../../lib\":719,\"../heatmap/xyz_defaults\":1015,\"./attributes\":942,\"./constraint_defaults\":947,\"./contours_defaults\":949,\"./style_defaults\":963}],952:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constraint_mapping\"),a=t(\"./end_plus\");e.exports=function(t,e,r){for(var o=\"constraint\"===t.type?i[t._operation](t.value):t,s=o.size,l=[],c=a(o),u=r.trace._carpetTrace,h=u?{xaxis:u.aaxis,yaxis:u.baxis,x:r.a,y:r.b}:{xaxis:e.xaxis,yaxis:e.yaxis,x:r.x,y:r.y},f=o.start;f<c;f+=s)if(l.push(n.extendFlat({level:f,crossings:{},starts:[],edgepaths:[],paths:[],z:r.z,smoothing:r.trace.line.smoothing},h)),l.length>1e3){n.warn(\"Too many contours, clipping at 1000\",t);break}return l}},{\"../../lib\":719,\"./constraint_mapping\":948,\"./end_plus\":953}],953:[function(t,e,r){\"use strict\";e.exports=function(t){return t.end+t.size/1e6}},{}],954:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constants\");function a(t,e,r,n){return Math.abs(t[0]-e[0])<r&&Math.abs(t[1]-e[1])<n}function o(t,e,r,o,l){var c,u=e.join(\",\"),h=u,f=t.crossings[h],p=function(t,e,r){var n=0,a=0;t>20&&e?208===t||1114===t?n=0===r[0]?1:-1:a=0===r[1]?1:-1:-1!==i.BOTTOMSTART.indexOf(t)?a=1:-1!==i.LEFTSTART.indexOf(t)?n=1:-1!==i.TOPSTART.indexOf(t)?a=-1:n=-1;return[n,a]}(f,r,e),d=[s(t,e,[-p[0],-p[1]])],g=p.join(\",\"),v=t.z.length,m=t.z[0].length;for(c=0;c<1e4;c++){if(f>20?(f=i.CHOOSESADDLE[f][(p[0]||p[1])<0?0:1],t.crossings[h]=i.SADDLEREMAINDER[f]):delete t.crossings[h],!(p=i.NEWDELTA[f])){n.log(\"Found bad marching index:\",f,e,t.level);break}d.push(s(t,e,p)),e[0]+=p[0],e[1]+=p[1],a(d[d.length-1],d[d.length-2],o,l)&&d.pop(),h=e.join(\",\");var y=p[0]&&(e[0]<0||e[0]>m-2)||p[1]&&(e[1]<0||e[1]>v-2);if(h===u&&p.join(\",\")===g||r&&y)break;f=t.crossings[h]}1e4===c&&n.log(\"Infinite loop in contour?\");var x,b,_,w,k,T,A,M,S,E,C,L,P,O,z,I=a(d[0],d[d.length-1],o,l),D=0,R=.2*t.smoothing,F=[],B=0;for(c=1;c<d.length;c++)L=d[c],P=d[c-1],void 0,void 0,O=L[2]-P[2],z=L[3]-P[3],D+=A=Math.sqrt(O*O+z*z),F.push(A);var N=D/F.length*R;function j(t){return d[t%d.length]}for(c=d.length-2;c>=B;c--)if((x=F[c])<N){for(_=0,b=c-1;b>=B&&x+F[b]<N;b--)x+=F[b];if(I&&c===d.length-2)for(_=0;_<b&&x+F[_]<N;_++)x+=F[_];k=c-b+_+1,T=Math.floor((c+b+_+2)/2),w=I||c!==d.length-2?I||-1!==b?k%2?j(T):[(j(T)[0]+j(T+1)[0])/2,(j(T)[1]+j(T+1)[1])/2]:d[0]:d[d.length-1],d.splice(b+1,c-b+1,w),c=b+1,_&&(B=_),I&&(c===d.length-2?d[_]=d[d.length-1]:0===c&&(d[d.length-1]=d[0]))}for(d.splice(0,B),c=0;c<d.length;c++)d[c].length=2;if(!(d.length<2))if(I)d.pop(),t.paths.push(d);else{r||n.log(\"Unclosed interior contour?\",t.level,u,d.join(\"L\"));var U=!1;for(M=0;M<t.edgepaths.length;M++)if(E=t.edgepaths[M],!U&&a(E[0],d[d.length-1],o,l)){d.pop(),U=!0;var V=!1;for(S=0;S<t.edgepaths.length;S++)if(a((C=t.edgepaths[S])[C.length-1],d[0],o,l)){V=!0,d.shift(),t.edgepaths.splice(M,1),S===M?t.paths.push(d.concat(C)):(S>M&&S--,t.edgepaths[S]=C.concat(d,E));break}V||(t.edgepaths[M]=d.concat(E))}for(M=0;M<t.edgepaths.length&&!U;M++)a((E=t.edgepaths[M])[E.length-1],d[0],o,l)&&(d.shift(),t.edgepaths[M]=E.concat(d),U=!0);U||t.edgepaths.push(d)}}function s(t,e,r){var n=e[0]+Math.max(r[0],0),i=e[1]+Math.max(r[1],0),a=t.z[i][n],o=t.xaxis,s=t.yaxis;if(r[1]){var l=(t.level-a)/(t.z[i][n+1]-a);return[o.c2p((1-l)*t.x[n]+l*t.x[n+1],!0),s.c2p(t.y[i],!0),n+l,i]}var c=(t.level-a)/(t.z[i+1][n]-a);return[o.c2p(t.x[n],!0),s.c2p((1-c)*t.y[i]+c*t.y[i+1],!0),n,i+c]}e.exports=function(t,e,r){var i,a,s,l;for(e=e||.01,r=r||.01,a=0;a<t.length;a++){for(s=t[a],l=0;l<s.starts.length;l++)o(s,s.starts[l],\"edge\",e,r);for(i=0;Object.keys(s.crossings).length&&i<1e4;)i++,o(s,Object.keys(s.crossings)[0].split(\",\").map(Number),void 0,e,r);1e4===i&&n.log(\"Infinite loop in contour?\")}}},{\"../../lib\":719,\"./constants\":946}],955:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../heatmap/hover\");e.exports=function(t,e,r,a,o){var s=i(t,e,r,a,o,!0);return s&&s.forEach(function(t){var e=t.trace;\"constraint\"===e.contours.type&&(e.fillcolor&&n.opacity(e.fillcolor)?t.color=n.addOpacity(e.fillcolor,1):e.contours.showlines&&n.opacity(e.line.color)&&(t.color=n.addOpacity(e.line.color,1)))}),s}},{\"../../components/color\":593,\"../heatmap/hover\":1008}],956:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\").plot,style:t(\"./style\"),colorbar:t(\"./colorbar\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"contour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":942,\"./calc\":943,\"./colorbar\":945,\"./defaults\":951,\"./hover\":955,\"./plot\":960,\"./style\":962}],957:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i){if(i||(i={}),t(\"contours.showlabels\")){var a=e.font;n.coerceFont(t,\"contours.labelfont\",{family:a.family,size:a.size,color:r}),t(\"contours.labelformat\")}!1!==i.hasHover&&t(\"zhoverformat\")}},{\"../../lib\":719}],958:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/colorscale\"),a=t(\"./end_plus\");e.exports=function(t){var e=t.contours,r=e.start,o=a(e),s=e.size||1,l=Math.floor((o-r)/s)+1,c=\"lines\"===e.coloring?0:1,u=i.extractOpts(t);isFinite(s)||(s=1,l=1);var h,f,p=u.reversescale?i.flipScale(u.colorscale):u.colorscale,d=p.length,g=new Array(d),v=new Array(d);if(\"heatmap\"===e.coloring){var m=u.min,y=u.max;for(f=0;f<d;f++)h=p[f],g[f]=h[0]*(y-m)+m,v[f]=h[1];var x=n.extent([m,y,e.start,e.start+s*(l-1)]),b=x[m<y?0:1],_=x[m<y?1:0];b!==m&&(g.splice(0,0,b),v.splice(0,0,v[0])),_!==y&&(g.push(_),v.push(v[v.length-1]))}else for(f=0;f<d;f++)h=p[f],g[f]=(h[0]*(l+c-1)-c/2)*s+r,v[f]=h[1];return i.makeColorScaleFunc({domain:g,range:v},{noNumericCheck:!0})}},{\"../../components/colorscale\":605,\"./end_plus\":953,d3:163}],959:[function(t,e,r){\"use strict\";var n=t(\"./constants\");function i(t,e){var r=(e[0][0]>t?0:1)+(e[0][1]>t?0:2)+(e[1][1]>t?0:4)+(e[1][0]>t?0:8);return 5===r||10===r?t>(e[0][0]+e[0][1]+e[1][0]+e[1][1])/4?5===r?713:1114:5===r?104:208:15===r?0:r}e.exports=function(t){var e,r,a,o,s,l,c,u,h,f=t[0].z,p=f.length,d=f[0].length,g=2===p||2===d;for(r=0;r<p-1;r++)for(o=[],0===r&&(o=o.concat(n.BOTTOMSTART)),r===p-2&&(o=o.concat(n.TOPSTART)),e=0;e<d-1;e++)for(a=o.slice(),0===e&&(a=a.concat(n.LEFTSTART)),e===d-2&&(a=a.concat(n.RIGHTSTART)),s=e+\",\"+r,l=[[f[r][e],f[r][e+1]],[f[r+1][e],f[r+1][e+1]]],h=0;h<t.length;h++)(c=i((u=t[h]).level,l))&&(u.crossings[s]=c,-1!==a.indexOf(c)&&(u.starts.push([e,r]),g&&-1!==a.indexOf(c,a.indexOf(c)+1)&&u.starts.push([e,r])))}},{\"./constants\":946}],960:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../../plots/cartesian/set_convert\"),c=t(\"../heatmap/plot\"),u=t(\"./make_crossings\"),h=t(\"./find_all_paths\"),f=t(\"./empty_pathinfo\"),p=t(\"./convert_to_constraints\"),d=t(\"./close_boundaries\"),g=t(\"./constants\"),v=g.LABELOPTIMIZER;function m(t,e){var r,n,o,s,l,c,u,h=function(t,e){var r=t.prefixBoundary;if(void 0===r){var n=Math.min(t.z[0][0],t.z[0][1]);r=!t.edgepaths.length&&n>t.level}return r?\"M\"+e.join(\"L\")+\"Z\":\"\"}(t,e),f=0,p=t.edgepaths.map(function(t,e){return e}),d=!0;function g(t){return Math.abs(t[1]-e[2][1])<.01}function v(t){return Math.abs(t[0]-e[0][0])<.01}function m(t){return Math.abs(t[0]-e[2][0])<.01}for(;p.length;){for(c=a.smoothopen(t.edgepaths[f],t.smoothing),h+=d?c:c.replace(/^M/,\"L\"),p.splice(p.indexOf(f),1),r=t.edgepaths[f][t.edgepaths[f].length-1],s=-1,o=0;o<4;o++){if(!r){i.log(\"Missing end?\",f,t);break}for(u=r,Math.abs(u[1]-e[0][1])<.01&&!m(r)?n=e[1]:v(r)?n=e[0]:g(r)?n=e[3]:m(r)&&(n=e[2]),l=0;l<t.edgepaths.length;l++){var y=t.edgepaths[l][0];Math.abs(r[0]-n[0])<.01?Math.abs(r[0]-y[0])<.01&&(y[1]-r[1])*(n[1]-y[1])>=0&&(n=y,s=l):Math.abs(r[1]-n[1])<.01?Math.abs(r[1]-y[1])<.01&&(y[0]-r[0])*(n[0]-y[0])>=0&&(n=y,s=l):i.log(\"endpt to newendpt is not vert. or horz.\",r,n,y)}if(r=n,s>=0)break;h+=\"L\"+n}if(s===t.edgepaths.length){i.log(\"unclosed perimeter path\");break}f=s,(d=-1===p.indexOf(f))&&(f=p[0],h+=\"Z\")}for(f=0;f<t.paths.length;f++)h+=a.smoothclosed(t.paths[f],t.smoothing);return h}function y(t,e,r,n){var a=e.width/2,o=e.height/2,s=t.x,l=t.y,c=t.theta,u=Math.cos(c)*a,h=Math.sin(c)*a,f=(s>n.center?n.right-s:s-n.left)/(u+Math.abs(Math.sin(c)*o)),p=(l>n.middle?n.bottom-l:l-n.top)/(Math.abs(h)+Math.cos(c)*o);if(f<1||p<1)return 1/0;var d=v.EDGECOST*(1/(f-1)+1/(p-1));d+=v.ANGLECOST*c*c;for(var g=s-u,m=l-h,y=s+u,x=l+h,b=0;b<r.length;b++){var _=r[b],w=Math.cos(_.theta)*_.width/2,k=Math.sin(_.theta)*_.width/2,T=2*i.segmentDistance(g,m,y,x,_.x-w,_.y-k,_.x+w,_.y+k)/(e.height+_.height),A=_.level===e.level,M=A?v.SAMELEVELDISTANCE:1;if(T<=M)return 1/0;d+=v.NEIGHBORCOST*(A?v.SAMELEVELFACTOR:1)/(T-M)}return d}r.plot=function(t,e,o,s){var l=e.xaxis,v=e.yaxis;i.makeTraceGroups(s,o,\"contour\").each(function(o){var s=n.select(this),y=o[0],x=y.trace,b=y.x,_=y.y,w=x.contours,k=f(w,e,y),T=i.ensureSingle(s,\"g\",\"heatmapcoloring\"),A=[];\"heatmap\"===w.coloring&&(A=[o]),c(t,e,A,T),u(k),h(k);var M=l.c2p(b[0],!0),S=l.c2p(b[b.length-1],!0),E=v.c2p(_[0],!0),C=v.c2p(_[_.length-1],!0),L=[[M,C],[S,C],[S,E],[M,E]],P=k;\"constraint\"===w.type&&(P=p(k,w._operation),d(P,w._operation,L,x)),function(t,e,r){var n=i.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"===r.coloring?[0]:[]);n.enter().append(\"path\"),n.exit().remove(),n.attr(\"d\",\"M\"+e.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(s,L,w),function(t,e,r,a){var o=i.ensureSingle(t,\"g\",\"contourfill\").selectAll(\"path\").data(\"fill\"===a.coloring||\"constraint\"===a.type&&\"=\"!==a._operation?e:[]);o.enter().append(\"path\"),o.exit().remove(),o.each(function(t){var e=m(t,r);e?n.select(this).attr(\"d\",e).style(\"stroke\",\"none\"):n.select(this).remove()})}(s,P,L,w),function(t,e,o,s,l){var c=i.ensureSingle(t,\"g\",\"contourlines\"),u=!1!==l.showlines,h=l.showlabels,f=u&&h,p=r.createLines(c,u||h,e),d=r.createLineClip(c,f,o,s.trace.uid),v=t.selectAll(\"g.contourlabels\").data(h?[0]:[]);if(v.exit().remove(),v.enter().append(\"g\").classed(\"contourlabels\",!0),h){var m=[],y=[];i.clearLocationCache();var x=r.labelFormatter(l,s.t.cb,o._fullLayout),b=a.tester.append(\"text\").attr(\"data-notex\",1).call(a.font,l.labelfont),_=e[0].xaxis,w=e[0].yaxis,k=_._length,T=w._length,A=_.range,M=w.range,S=i.aggNums(Math.min,null,s.x),E=i.aggNums(Math.max,null,s.x),C=i.aggNums(Math.min,null,s.y),L=i.aggNums(Math.max,null,s.y),P=Math.max(_.c2p(S,!0),0),O=Math.min(_.c2p(E,!0),k),z=Math.max(w.c2p(L,!0),0),I=Math.min(w.c2p(C,!0),T),D={};A[0]<A[1]?(D.left=P,D.right=O):(D.left=O,D.right=P),M[0]<M[1]?(D.top=z,D.bottom=I):(D.top=I,D.bottom=z),D.middle=(D.top+D.bottom)/2,D.center=(D.left+D.right)/2,m.push([[D.left,D.top],[D.right,D.top],[D.right,D.bottom],[D.left,D.bottom]]);var R=Math.sqrt(k*k+T*T),F=g.LABELDISTANCE*R/Math.max(1,e.length/g.LABELINCREASE);p.each(function(t){var e=r.calcTextOpts(t.level,x,b,o);n.select(this).selectAll(\"path\").each(function(){var t=i.getVisibleSegment(this,D,e.height/2);if(t&&!(t.len<(e.width+e.height)*g.LABELMIN))for(var n=Math.min(Math.ceil(t.len/F),g.LABELMAX),a=0;a<n;a++){var o=r.findBestTextLocation(this,t,e,y,D);if(!o)break;r.addLabelData(o,e,y,m)}})}),b.remove(),r.drawLabels(v,y,o,d,f?m:null)}h&&!u&&p.remove()}(s,k,t,y,w),function(t,e,r,n,o){var s=r._fullLayout._clips,l=\"clip\"+n.trace.uid,c=s.selectAll(\"#\"+l).data(n.trace.connectgaps?[]:[0]);if(c.enter().append(\"clipPath\").classed(\"contourclip\",!0).attr(\"id\",l),c.exit().remove(),!1===n.trace.connectgaps){var f={level:.9,crossings:{},starts:[],edgepaths:[],paths:[],xaxis:e.xaxis,yaxis:e.yaxis,x:n.x,y:n.y,z:function(t){var e,r,n=t.trace._emptypoints,i=[],a=t.z.length,o=t.z[0].length,s=[];for(e=0;e<o;e++)s.push(1);for(e=0;e<a;e++)i.push(s.slice());for(e=0;e<n.length;e++)r=n[e],i[r[0]][r[1]]=0;return t.zmask=i,i}(n),smoothing:0};u([f]),h([f]);var p=m(f,o),d=i.ensureSingle(c,\"path\",\"\");d.attr(\"d\",p)}else l=null;a.setClipUrl(t,l,r)}(s,e,t,y,L)})},r.createLines=function(t,e,r){var n=r[0].smoothing,i=t.selectAll(\"g.contourlevel\").data(e?r:[]);if(i.exit().remove(),i.enter().append(\"g\").classed(\"contourlevel\",!0),e){var o=i.selectAll(\"path.openline\").data(function(t){return t.pedgepaths||t.edgepaths});o.exit().remove(),o.enter().append(\"path\").classed(\"openline\",!0),o.attr(\"d\",function(t){return a.smoothopen(t,n)}).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\");var s=i.selectAll(\"path.closedline\").data(function(t){return t.ppaths||t.paths});s.exit().remove(),s.enter().append(\"path\").classed(\"closedline\",!0),s.attr(\"d\",function(t){return a.smoothclosed(t,n)}).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\")}return i},r.createLineClip=function(t,e,r,n){var i=e?\"clipline\"+n:null,o=r._fullLayout._clips.selectAll(\"#\"+i).data(e?[0]:[]);return o.exit().remove(),o.enter().append(\"clipPath\").classed(\"contourlineclip\",!0).attr(\"id\",i),a.setClipUrl(t,i,r),o},r.labelFormatter=function(t,e,r){if(t.labelformat)return r._d3locale.numberFormat(t.labelformat);var n;if(e)n=e.axis;else{if(n={type:\"linear\",_id:\"ycontour\",showexponent:\"all\",exponentformat:\"B\"},\"constraint\"===t.type){var i=t.value;Array.isArray(i)?n.range=[i[0],i[i.length-1]]:n.range=[i,i]}else n.range=[t.start,t.end],n.nticks=(t.end-t.start)/t.size;n.range[0]===n.range[1]&&(n.range[1]+=n.range[0]||1),n.nticks||(n.nticks=1e3),l(n,r),s.prepTicks(n),n._tmin=null,n._tmax=null}return function(t){return s.tickText(n,t).text}},r.calcTextOpts=function(t,e,r,n){var i=e(t);r.text(i).call(o.convertToTspans,n);var s=a.bBox(r.node(),!0);return{text:i,width:s.width,height:s.height,level:t,dy:(s.top+s.bottom)/2}},r.findBestTextLocation=function(t,e,r,n,a){var o,s,l,c,u,h=r.width;e.isClosed?(s=e.len/v.INITIALSEARCHPOINTS,o=e.min+s/2,l=e.max):(s=(e.len-h)/(v.INITIALSEARCHPOINTS+1),o=e.min+s+h/2,l=e.max-(s+h)/2);for(var f=1/0,p=0;p<v.ITERATIONS;p++){for(var d=o;d<l;d+=s){var g=i.getTextLocation(t,e.total,d,h),m=y(g,r,n,a);m<f&&(f=m,u=g,c=d)}if(f>2*v.MAXCOST)break;p&&(s/=2),l=(o=c-s/2)+1.5*s}if(f<=v.MAXCOST)return u},r.addLabelData=function(t,e,r,n){var i=e.width/2,a=e.height/2,o=t.x,s=t.y,l=t.theta,c=Math.sin(l),u=Math.cos(l),h=i*u,f=a*c,p=i*c,d=-a*u,g=[[o-h-f,s-p-d],[o+h-f,s+p-d],[o+h+f,s+p+d],[o-h+f,s-p+d]];r.push({text:e.text,x:o,y:s,dy:e.dy,theta:l,level:e.level,width:e.width,height:e.height}),n.push(g)},r.drawLabels=function(t,e,r,a,s){var l=t.selectAll(\"text\").data(e,function(t){return t.text+\",\"+t.x+\",\"+t.y+\",\"+t.theta});if(l.exit().remove(),l.enter().append(\"text\").attr({\"data-notex\":1,\"text-anchor\":\"middle\"}).each(function(t){var e=t.x+Math.sin(t.theta)*t.dy,i=t.y-Math.cos(t.theta)*t.dy;n.select(this).text(t.text).attr({x:e,y:i,transform:\"rotate(\"+180*t.theta/Math.PI+\" \"+e+\" \"+i+\")\"}).call(o.convertToTspans,r)}),s){for(var c=\"\",u=0;u<s.length;u++)c+=\"M\"+s[u].join(\"L\")+\"Z\";i.ensureSingle(a,\"path\",\"\").attr(\"d\",c)}}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/set_convert\":785,\"../heatmap/plot\":1012,\"./close_boundaries\":944,\"./constants\":946,\"./convert_to_constraints\":950,\"./empty_pathinfo\":952,\"./find_all_paths\":954,\"./make_crossings\":959,d3:163}],961:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\");function a(t,e,r){var i={type:\"linear\",range:[t,e]};return n.autoTicks(i,(e-t)/(r||15)),i}e.exports=function(t,e){var r=t.contours;if(t.autocontour){var o=t.zmin,s=t.zmax;(t.zauto||void 0===o)&&(o=i.aggNums(Math.min,null,e)),(t.zauto||void 0===s)&&(s=i.aggNums(Math.max,null,e));var l=a(o,s,t.ncontours);r.size=l.dtick,r.start=n.tickFirst(l),l.range.reverse(),r.end=n.tickFirst(l),r.start===o&&(r.start+=r.size),r.end===s&&(r.end-=r.size),r.start>r.end&&(r.start=r.end=(r.start+r.end)/2),t._input.contours||(t._input.contours={}),i.extendFlat(t._input.contours,{start:r.start,end:r.end,size:r.size}),t._input.autocontour=!0}else if(\"constraint\"!==r.type){var c,u=r.start,h=r.end,f=t._input.contours;if(u>h&&(r.start=f.start=h,h=r.end=f.end=u,u=r.start),!(r.size>0))c=u===h?1:a(u,h,t.ncontours).dtick,f.size=r.size=c}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767}],962:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../heatmap/style\"),o=t(\"./make_color_map\");e.exports=function(t){var e=n.select(t).selectAll(\"g.contour\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.each(function(t){var e=n.select(this),r=t[0].trace,a=r.contours,s=r.line,l=a.size||1,c=a.start,u=\"constraint\"===a.type,h=!u&&\"lines\"===a.coloring,f=!u&&\"fill\"===a.coloring,p=h||f?o(r):null;e.selectAll(\"g.contourlevel\").each(function(t){n.select(this).selectAll(\"path\").call(i.lineGroupStyle,s.width,h?p(t.level):s.color,s.dash)});var d=a.labelfont;if(e.selectAll(\"g.contourlabels text\").each(function(t){i.font(n.select(this),{family:d.family,size:d.size,color:d.color||(h?p(t.level):s.color)})}),u)e.selectAll(\"g.contourfill path\").style(\"fill\",r.fillcolor);else if(f){var g;e.selectAll(\"g.contourfill path\").style(\"fill\",function(t){return void 0===g&&(g=t.level),p(t.level+.5*l)}),void 0===g&&(g=c),e.selectAll(\"g.contourbg path\").style(\"fill\",p(g-.5*l))}}),a(t)}},{\"../../components/drawing\":614,\"../heatmap/style\":1013,\"./make_color_map\":958,d3:163}],963:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/defaults\"),i=t(\"./label_defaults\");e.exports=function(t,e,r,a,o){var s,l=r(\"contours.coloring\"),c=\"\";\"fill\"===l&&(s=r(\"contours.showlines\")),!1!==s&&(\"lines\"!==l&&(c=r(\"line.color\",\"#000\")),r(\"line.width\",.5),r(\"line.dash\")),\"none\"!==l&&(!0!==t.showlegend&&(e.showlegend=!1),e._dfltShowLegend=!1,n(t,e,a,r,{prefix:\"\",cLetter:\"z\"})),r(\"line.smoothing\"),i(r,a,c,o)}},{\"../../components/colorscale/defaults\":603,\"./label_defaults\":957}],964:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../contour/attributes\"),a=i.contours,o=t(\"../scatter/attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../lib/extend\").extendFlat,c=o.line;e.exports=l({carpet:{valType:\"string\",editType:\"calc\"},z:n.z,a:n.x,a0:n.x0,da:n.dx,b:n.y,b0:n.y0,db:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,atype:n.xtype,btype:n.ytype,fillcolor:i.fillcolor,autocontour:i.autocontour,ncontours:i.ncontours,contours:{type:a.type,start:a.start,end:a.end,size:a.size,coloring:{valType:\"enumerated\",values:[\"fill\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:a.showlines,showlabels:a.showlabels,labelfont:a.labelfont,labelformat:a.labelformat,operation:a.operation,value:a.value,editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:l({},c.color,{}),width:c.width,dash:c.dash,smoothing:l({},c.smoothing,{}),editType:\"plot\"},transforms:void 0},s(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../contour/attributes\":942,\"../heatmap/attributes\":1001,\"../scatter/attributes\":1112}],965:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\"),i=t(\"../../lib\"),a=t(\"../heatmap/convert_column_xyz\"),o=t(\"../heatmap/clean_2d_array\"),s=t(\"../heatmap/interp2d\"),l=t(\"../heatmap/find_empties\"),c=t(\"../heatmap/make_bound_array\"),u=t(\"./defaults\"),h=t(\"../carpet/lookup_carpetid\"),f=t(\"../contour/set_contours\");e.exports=function(t,e){var r=e._carpetTrace=h(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){if(!e.a||!e.b){var p=t.data[r.index],d=t.data[e.index];d.a||(d.a=p.a),d.b||(d.b=p.b),u(d,e,e._defaultColor,t._fullLayout)}var g=function(t,e){var r,u,h,f,p,d,g,v=e._carpetTrace,m=v.aaxis,y=v.baxis;m._minDtick=0,y._minDtick=0,i.isArray1D(e.z)&&a(e,m,y,\"a\",\"b\",[\"z\"]);r=e._a=e._a||e.a,f=e._b=e._b||e.b,r=r?m.makeCalcdata(e,\"_a\"):[],f=f?y.makeCalcdata(e,\"_b\"):[],u=e.a0||0,h=e.da||1,p=e.b0||0,d=e.db||1,g=e._z=o(e._z||e.z,e.transpose),e._emptypoints=l(g),s(g,e._emptypoints);var x=i.maxRowLength(g),b=\"scaled\"===e.xtype?\"\":r,_=c(e,b,u,h,x,m),w=\"scaled\"===e.ytype?\"\":f,k=c(e,w,p,d,g.length,y),T={a:_,b:k,z:g};\"levels\"===e.contours.type&&\"none\"!==e.contours.coloring&&n(t,e,{vals:g,containerStr:\"\",cLetter:\"z\"});return[T]}(t,e);return f(e,e._z),g}}},{\"../../components/colorscale/calc\":601,\"../../lib\":719,\"../carpet/lookup_carpetid\":915,\"../contour/set_contours\":961,\"../heatmap/clean_2d_array\":1003,\"../heatmap/convert_column_xyz\":1005,\"../heatmap/find_empties\":1007,\"../heatmap/interp2d\":1010,\"../heatmap/make_bound_array\":1011,\"./defaults\":966}],966:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"./attributes\"),o=t(\"../contour/constraint_defaults\"),s=t(\"../contour/contours_defaults\"),l=t(\"../contour/style_defaults\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,a,r,i)}if(u(\"carpet\"),t.a&&t.b){if(!i(t,e,u,c,\"a\",\"b\"))return void(e.visible=!1);u(\"text\"),\"constraint\"===u(\"contours.type\")?o(t,e,u,c,r,{hasHover:!1}):(s(t,e,u,function(r){return n.coerce2(t,e,a,r)}),l(t,e,u,c,{hasHover:!1}))}else e._defaultColor=r,e._length=null}},{\"../../lib\":719,\"../contour/constraint_defaults\":947,\"../contour/contours_defaults\":949,\"../contour/style_defaults\":963,\"../heatmap/xyz_defaults\":1015,\"./attributes\":964}],967:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../contour/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../contour/style\"),moduleType:\"trace\",name:\"contourcarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"contour\",\"symbols\",\"showLegend\",\"hasLines\",\"carpetDependent\"],meta:{}}},{\"../../plots/cartesian\":778,\"../contour/colorbar\":945,\"../contour/style\":962,\"./attributes\":964,\"./calc\":965,\"./defaults\":966,\"./plot\":970}],968:[function(t,e,r){\"use strict\";var n=t(\"../../components/drawing\"),i=t(\"../carpet/axis_aligned_line\"),a=t(\"../../lib\");e.exports=function(t,e,r,o,s,l,c,u){var h,f,p,d,g,v,m,y=\"\",x=e.edgepaths.map(function(t,e){return e}),b=!0,_=1e-4*Math.abs(r[0][0]-r[2][0]),w=1e-4*Math.abs(r[0][1]-r[2][1]);function k(t){return Math.abs(t[1]-r[0][1])<w}function T(t){return Math.abs(t[1]-r[2][1])<w}function A(t){return Math.abs(t[0]-r[0][0])<_}function M(t){return Math.abs(t[0]-r[2][0])<_}function S(t,e){var r,n,a,o,h=\"\";for(k(t)&&!M(t)||T(t)&&!A(t)?(o=s.aaxis,a=i(s,l,[t[0],e[0]],.5*(t[1]+e[1]))):(o=s.baxis,a=i(s,l,.5*(t[0]+e[0]),[t[1],e[1]])),r=1;r<a.length;r++)for(h+=o.smoothing?\"C\":\"L\",n=0;n<a[r].length;n++){var f=a[r][n];h+=[c.c2p(f[0]),u.c2p(f[1])]+\" \"}return h}for(h=0,f=null;x.length;){var E=e.edgepaths[h][0];for(f&&(y+=S(f,E)),m=n.smoothopen(e.edgepaths[h].map(o),e.smoothing),y+=b?m:m.replace(/^M/,\"L\"),x.splice(x.indexOf(h),1),f=e.edgepaths[h][e.edgepaths[h].length-1],g=-1,d=0;d<4;d++){if(!f){a.log(\"Missing end?\",h,e);break}for(k(f)&&!M(f)?p=r[1]:A(f)?p=r[0]:T(f)?p=r[3]:M(f)&&(p=r[2]),v=0;v<e.edgepaths.length;v++){var C=e.edgepaths[v][0];Math.abs(f[0]-p[0])<_?Math.abs(f[0]-C[0])<_&&(C[1]-f[1])*(p[1]-C[1])>=0&&(p=C,g=v):Math.abs(f[1]-p[1])<w?Math.abs(f[1]-C[1])<w&&(C[0]-f[0])*(p[0]-C[0])>=0&&(p=C,g=v):a.log(\"endpt to newendpt is not vert. or horz.\",f,p,C)}if(g>=0)break;y+=S(f,p),f=p}if(g===e.edgepaths.length){a.log(\"unclosed perimeter path\");break}h=g,(b=-1===x.indexOf(h))&&(h=x[0],y+=S(f,p)+\"Z\",f=null)}for(h=0;h<e.paths.length;h++)y+=n.smoothclosed(e.paths[h].map(o),e.smoothing);return y}},{\"../../components/drawing\":614,\"../../lib\":719,\"../carpet/axis_aligned_line\":899}],969:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i,a,o,s,l,c,u;for(r=0;r<t.length;r++){for(o=(a=t[r]).pedgepaths=[],s=a.ppaths=[],n=0;n<a.edgepaths.length;n++){for(u=a.edgepaths[n],l=[],i=0;i<u.length;i++)l[i]=e(u[i]);o.push(l)}for(n=0;n<a.paths.length;n++){for(u=a.paths[n],c=[],i=0;i<u.length;i++)c[i]=e(u[i]);s.push(c)}}}},{}],970:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../carpet/map_1d_array\"),a=t(\"../carpet/makepath\"),o=t(\"../../components/drawing\"),s=t(\"../../lib\"),l=t(\"../contour/make_crossings\"),c=t(\"../contour/find_all_paths\"),u=t(\"../contour/plot\"),h=t(\"../contour/constants\"),f=t(\"../contour/convert_to_constraints\"),p=t(\"./join_all_paths\"),d=t(\"../contour/empty_pathinfo\"),g=t(\"./map_pathinfo\"),v=t(\"../carpet/lookup_carpetid\"),m=t(\"../contour/close_boundaries\");function y(t,e,r){var n=t.getPointAtLength(e),i=t.getPointAtLength(r),a=i.x-n.x,o=i.y-n.y,s=Math.sqrt(a*a+o*o);return[a/s,o/s]}function x(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]);return[t[0]/e,t[1]/e]}function b(t,e){var r=Math.abs(t[0]*e[0]+t[1]*e[1]);return Math.sqrt(1-r*r)/r}e.exports=function(t,e,r,_){var w=e.xaxis,k=e.yaxis;s.makeTraceGroups(_,r,\"contour\").each(function(r){var _=n.select(this),T=r[0],A=T.trace,M=A._carpetTrace=v(t,A),S=t.calcdata[M.index][0];if(M.visible&&\"legendonly\"!==M.visible){var E=T.a,C=T.b,L=A.contours,P=d(L,e,T),O=\"constraint\"===L.type,z=L._operation,I=O?\"=\"===z?\"lines\":\"fill\":L.coloring,D=[[E[0],C[C.length-1]],[E[E.length-1],C[C.length-1]],[E[E.length-1],C[0]],[E[0],C[0]]];l(P);var R=1e-8*(E[E.length-1]-E[0]),F=1e-8*(C[C.length-1]-C[0]);c(P,R,F);var B,N,j,U,V=P;\"constraint\"===L.type&&(V=f(P,z),m(V,z,D,A)),g(P,G);var q=[];for(U=S.clipsegments.length-1;U>=0;U--)B=S.clipsegments[U],N=i([],B.x,w.c2p),j=i([],B.y,k.c2p),N.reverse(),j.reverse(),q.push(a(N,j,B.bicubic));var H=\"M\"+q.join(\"L\")+\"Z\";!function(t,e,r,n,o,l){var c,u,h,f,p=s.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"!==l||o?[]:[0]);p.enter().append(\"path\"),p.exit().remove();var d=[];for(f=0;f<e.length;f++)c=e[f],u=i([],c.x,r.c2p),h=i([],c.y,n.c2p),d.push(a(u,h,c.bicubic));p.attr(\"d\",\"M\"+d.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(_,S.clipsegments,w,k,O,I),function(t,e,r,i,a,o,l,c,u,h,f){var d=s.ensureSingle(e,\"g\",\"contourfill\").selectAll(\"path\").data(\"fill\"===h?a:[]);d.enter().append(\"path\"),d.exit().remove(),d.each(function(e){var a=p(t,e,o,l,c,u,r,i);e.prefixBoundary&&(a=f+a),a?n.select(this).attr(\"d\",a).style(\"stroke\",\"none\"):n.select(this).remove()})}(A,_,w,k,V,D,G,M,S,I,H),function(t,e,r,i,a,l,c){var f=s.ensureSingle(t,\"g\",\"contourlines\"),p=!1!==a.showlines,d=a.showlabels,g=p&&d,v=u.createLines(f,p||d,e),m=u.createLineClip(f,g,r,i.trace.uid),_=t.selectAll(\"g.contourlabels\").data(d?[0]:[]);if(_.exit().remove(),_.enter().append(\"g\").classed(\"contourlabels\",!0),d){var w=l.xaxis,k=l.yaxis,T=w._length,A=k._length,M=[[[0,0],[T,0],[T,A],[0,A]]],S=[];s.clearLocationCache();var E=u.labelFormatter(a,i.t.cb,r._fullLayout),C=o.tester.append(\"text\").attr(\"data-notex\",1).call(o.font,a.labelfont),L={left:0,right:T,center:T/2,top:0,bottom:A,middle:A/2},P=Math.sqrt(T*T+A*A),O=h.LABELDISTANCE*P/Math.max(1,e.length/h.LABELINCREASE);v.each(function(t){var e=u.calcTextOpts(t.level,E,C,r);n.select(this).selectAll(\"path\").each(function(r){var n=s.getVisibleSegment(this,L,e.height/2);if(n&&(function(t,e,r,n,i,a){for(var o,s=0;s<r.pedgepaths.length;s++)e===r.pedgepaths[s]&&(o=r.edgepaths[s]);if(!o)return;var l=i.a[0],c=i.a[i.a.length-1],u=i.b[0],h=i.b[i.b.length-1];function f(t,e){var r,n=0;return(Math.abs(t[0]-l)<.1||Math.abs(t[0]-c)<.1)&&(r=x(i.dxydb_rough(t[0],t[1],.1)),n=Math.max(n,a*b(e,r)/2)),(Math.abs(t[1]-u)<.1||Math.abs(t[1]-h)<.1)&&(r=x(i.dxyda_rough(t[0],t[1],.1)),n=Math.max(n,a*b(e,r)/2)),n}var p=y(t,0,1),d=y(t,n.total,n.total-1),g=f(o[0],p),v=n.total-f(o[o.length-1],d);n.min<g&&(n.min=g);n.max>v&&(n.max=v);n.len=n.max-n.min}(this,r,t,n,c,e.height),!(n.len<(e.width+e.height)*h.LABELMIN)))for(var i=Math.min(Math.ceil(n.len/O),h.LABELMAX),a=0;a<i;a++){var o=u.findBestTextLocation(this,n,e,S,L);if(!o)break;u.addLabelData(o,e,S,M)}})}),C.remove(),u.drawLabels(_,S,r,m,g?M:null)}d&&!p&&v.remove()}(_,P,t,T,L,e,M),o.setClipUrl(_,M._clipPathId,t)}function G(t){var e=M.ab2xy(t[0],t[1],!0);return[w.c2p(e[0]),k.c2p(e[1])]}})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../carpet/lookup_carpetid\":915,\"../carpet/makepath\":916,\"../carpet/map_1d_array\":917,\"../contour/close_boundaries\":944,\"../contour/constants\":946,\"../contour/convert_to_constraints\":950,\"../contour/empty_pathinfo\":952,\"../contour/find_all_paths\":954,\"../contour/make_crossings\":959,\"../contour/plot\":960,\"./join_all_paths\":968,\"./map_pathinfo\":969,d3:163}],971:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../scattermapbox/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({lon:o.lon,lat:o.lat,z:{valType:\"data_array\",editType:\"calc\"},radius:{valType:\"number\",editType:\"plot\",arrayOk:!0,min:1,dflt:30},below:{valType:\"string\",editType:\"plot\"},text:o.text,hovertext:o.hovertext,hoverinfo:s({},a.hoverinfo,{flags:[\"lon\",\"lat\",\"z\",\"text\",\"name\"]}),hovertemplate:i()},n(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scattermapbox/attributes\":1171}],972:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../components/colorscale/calc\"),s=t(\"../../lib\")._;e.exports=function(t,e){for(var r=e._length,l=new Array(r),c=e.z,u=i(c)&&c.length,h=0;h<r;h++){var f=l[h]={},p=e.lon[h],d=e.lat[h];if(f.lonlat=n(p)&&n(d)?[+p,+d]:[a,a],u){var g=c[h];f.z=n(g)?g:a}}return o(t,e,{vals:u?c:[0,1],containerStr:\"\",cLetter:\"z\"}),r&&(l[0].t={labels:{lat:s(t,\"lat:\")+\" \",lon:s(t,\"lon:\")+\" \"}}),l}},{\"../../components/colorscale/calc\":601,\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],973:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../../components/colorscale\"),s=t(\"../../constants/numerical\").BADNUM,l=t(\"../../lib/geojson_utils\").makeBlank;e.exports=function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,c=e._opts={heatmap:{layout:{visibility:\"none\"},paint:{}},geojson:l()};if(!r)return c;var u,h=[],f=e.z,p=e.radius,d=i.isArrayOrTypedArray(f)&&f.length,g=i.isArrayOrTypedArray(p);for(u=0;u<t.length;u++){var v=t[u],m=v.lonlat;if(m[0]!==s){var y={};if(d){var x=v.z;y.z=x!==s?x:0}g&&(y.r=n(p[u])&&p[u]>0?+p[u]:0),h.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:m},properties:y})}}var b=o.extractOpts(e),_=b.reversescale?o.flipScale(b.colorscale):b.colorscale,w=_[0][1],k=[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,a.opacity(w)<1?w:a.addOpacity(w,0)];for(u=1;u<_.length;u++)k.push(_[u][0],_[u][1]);var T=[\"interpolate\",[\"linear\"],[\"get\",\"z\"],b.min,0,b.max,1];return i.extendFlat(c.heatmap.paint,{\"heatmap-weight\":d?T:1/(b.max-b.min),\"heatmap-color\":k,\"heatmap-radius\":g?{type:\"identity\",property:\"r\"}:e.radius,\"heatmap-opacity\":e.opacity}),c.geojson={type:\"FeatureCollection\",features:h},c.heatmap.layout.visibility=\"visible\",c}},{\"../../components/color\":593,\"../../components/colorscale\":605,\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/geojson_utils\":714,\"fast-isnumeric\":225}],974:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"lon\")||[],c=s(\"lat\")||[],u=Math.min(l.length,c.length);u?(e._length=u,s(\"z\"),s(\"radius\"),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":971}],975:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.z=e.z,t}},{}],976:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../scattermapbox/hover\");e.exports=function(t,e,r){var o=a(t,e,r);if(o){var s=o[0],l=s.cd,c=l[0].trace,u=l[s.index];if(delete s.color,\"z\"in u){var h=s.subplot.mockAxis;s.z=u.z,s.zLabel=i.tickText(h,h.c2l(u.z),\"hover\").text}return s.extraText=function(t,e,r){if(t.hovertemplate)return;var i=(e.hi||t.hoverinfo).split(\"+\"),a=-1!==i.indexOf(\"all\"),o=-1!==i.indexOf(\"lon\"),s=-1!==i.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}a||o&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):o?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(a||-1!==i.indexOf(\"text\"))&&n.fillText(e,t,c);return c.join(\"<br>\")}(c,u,l[0].t.labels),[s]}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scattermapbox/hover\":1175}],977:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),getBelow:function(t,e){for(var r=e.getMapLayers(),n=0;n<r.length;n++){var i=r[n],a=i.id;if(\"symbol\"===i.type&&\"string\"==typeof a&&-1===a.indexOf(\"plotly-\"))return a}},moduleType:\"trace\",name:\"densitymapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\"],meta:{hr_name:\"density_mapbox\"}}},{\"../../plots/mapbox\":822,\"../heatmap/colorbar\":1004,\"./attributes\":971,\"./calc\":972,\"./defaults\":974,\"./event_data\":975,\"./hover\":976,\"./plot\":978}],978:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function a(t,e){this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"heatmap\",i+e+\"-heatmap\"]],this.below=null}var o=a.prototype;o.update=function(t){var e=this.subplot,r=this.layerList,i=n(t),a=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(i.geojson),a!==this.below&&(this._removeLayers(),this._addLayers(i,a),this.below=a);for(var o=0;o<r.length;o++){var s=r[o],l=s[0],c=s[1],u=i[l];e.setOptions(c,\"setLayoutProperty\",u.layout),\"visible\"===u.layout.visibility&&e.setOptions(c,\"setPaintProperty\",u.paint)}},o._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},o._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},o.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new a(t,r.uid),o=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(o,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),i}},{\"../../plots/mapbox/constants\":820,\"./convert\":973}],979:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":719}],980:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"./constants\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../components/color\");e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,hovertext:n.hovertext,hovertemplate:o({},{keys:s.eventDataKeys}),hoverinfo:l({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"percent initial\",\"percent previous\",\"percent total\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"percent initial\",\"percent previous\",\"percent total\",\"value\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},text:n.text,textposition:l({},n.textposition,{dflt:\"auto\"}),insidetextanchor:l({},n.insidetextanchor,{dflt:\"middle\"}),textangle:l({},n.textangle,{dflt:0}),textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:l({},n.orientation,{}),offset:l({},n.offset,{arrayOk:!1}),width:l({},n.width,{arrayOk:!1}),marker:n.marker,connector:{fillcolor:{valType:\"color\",editType:\"style\"},line:{color:l({},i.color,{dflt:c.defaultLine}),width:l({},i.width,{dflt:0,editType:\"plot\"}),dash:i.dash,editType:\"style\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":593,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../bar/attributes\":857,\"../scatter/attributes\":1112,\"./constants\":982}],981:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"./arrays_to_calcdata\"),a=t(\"../scatter/calc_selection\"),o=t(\"../../constants/numerical\").BADNUM;function s(t){return t===o?0:t}e.exports=function(t,e){var r,l,c,u,h=n.getFromId(t,e.xaxis||\"x\"),f=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=h.makeCalcdata(e,\"x\"),l=f.makeCalcdata(e,\"y\")):(r=f.makeCalcdata(e,\"y\"),l=h.makeCalcdata(e,\"x\"));var p,d=Math.min(l.length,r.length),g=new Array(d);for(e._base=[],c=0;c<d;c++){r[c]<0&&(r[c]=o);var v=!1;r[c]!==o&&c+1<d&&r[c+1]!==o&&(v=!0),u=g[c]={p:l[c],s:r[c],cNext:v},e._base[c]=-.5*u.s,e.ids&&(u.id=String(e.ids[c])),0===c&&(g[0].vTotal=0),g[0].vTotal+=s(u.s),u.begR=s(u.s)/s(g[0].s)}for(c=0;c<d;c++)(u=g[c]).s!==o&&(u.sumR=u.s/g[0].vTotal,u.difR=void 0!==p?u.s/p:1,p=u.s);return i(g,e),a(g,e),g}},{\"../../constants/numerical\":695,\"../../plots/cartesian/axes\":767,\"../scatter/calc_selection\":1114,\"./arrays_to_calcdata\":979}],982:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"percentInitial\",\"percentPrevious\",\"percentTotal\"]}},{}],983:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],h=[],f=[];for(i=0;i<o.length;i++){var p=o[i],d=\"h\"===p.orientation;!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"funnel\"===p.type&&(r=s[i],d?f.push(r):h.push(r),u.push(r))}var g={mode:a.funnelmode,norm:a.funnelnorm,gap:a.funnelgap,groupgap:a.funnelgroupgap};for(n(t,l,c,h,g),n(t,c,l,f,g),i=0;i<u.length;i++){r=u[i];for(var v=0;v<r.length;v++)v+1<r.length&&(r[v].nextP0=r[v+1].p0,r[v].nextS0=r[v+1].s0,r[v].nextP1=r[v+1].p1,r[v].nextS1=r[v+1].s1)}}},{\"../bar/cross_trace_calc\":860}],984:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"./attributes\"),l=t(\"../../components/color\");e.exports={supplyDefaults:function(t,e,r,i){function c(r,i){return n.coerce(t,e,s,r,i)}if(o(t,e,i,c)){c(\"orientation\",e.y&&!e.x?\"v\":\"h\"),c(\"offset\"),c(\"width\");var u=c(\"text\");c(\"hovertext\"),c(\"hovertemplate\");var h=c(\"textposition\");a(t,e,i,c,h,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"!==e.textposition&&c(\"textinfo\",Array.isArray(u)?\"text+value\":\"value\");var f=c(\"marker.color\",r);c(\"marker.line.color\",l.defaultLine),c(\"marker.line.width\"),c(\"connector.visible\")&&(c(\"connector.fillcolor\",function(t){var e=n.isArrayOrTypedArray(t)?\"#000\":t;return l.addOpacity(e,.5*l.opacity(e))}(f)),c(\"connector.line.width\")&&(c(\"connector.line.color\"),c(\"connector.line.dash\")))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,s,t)}if(\"group\"===e.funnelmode)for(var l=0;l<t.length;l++)r=(a=t[l])._input,i(r,a,e,o)}}},{\"../../components/color\":593,\"../../lib\":719,\"../bar/defaults\":861,\"../scatter/xy_defaults\":1137,\"./attributes\":980}],985:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"percentInitial\"in e&&(t.percentInitial=e.percentInitial),\"percentPrevious\"in e&&(t.percentPrevious=e.percentPrevious),\"percentTotal\"in e&&(t.percentTotal=e.percentTotal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],986:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\").opacity,i=t(\"../bar/hover\").hoverOnBars,a=t(\"../../lib\").formatPercent;e.exports=function(t,e,r,o){var s=i(t,e,r,o);if(s){var l=s.cd,c=l[0].trace,u=\"h\"===c.orientation,h=l[s.index];s[(u?\"x\":\"y\")+\"LabelVal\"]=h.s,s.percentInitial=h.begR,s.percentInitialLabel=a(h.begR,1),s.percentPrevious=h.difR,s.percentPreviousLabel=a(h.difR,1),s.percentTotal=h.sumR,s.percentTotalLabel=a(h.sumR,1);var f=h.hi||c.hoverinfo,p=[];if(f&&\"none\"!==f&&\"skip\"!==f){var d=\"all\"===f,g=f.split(\"+\"),v=function(t){return d||-1!==g.indexOf(t)};v(\"percent initial\")&&p.push(s.percentInitialLabel+\" of initial\"),v(\"percent previous\")&&p.push(s.percentPreviousLabel+\" of previous\"),v(\"percent total\")&&p.push(s.percentTotalLabel+\" of total\")}return s.extraText=p.join(\"<br>\"),s.color=function(t,e){var r=t.marker,i=e.mc||r.color,a=e.mlc||r.line.color,o=e.mlw||r.line.width;if(n(i))return i;if(n(a)&&o)return a}(c,h),[s]}}},{\"../../components/color\":593,\"../../lib\":719,\"../bar/hover\":863}],987:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"funnel\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../bar/select\":868,\"./attributes\":980,\"./calc\":981,\"./cross_trace_calc\":983,\"./defaults\":984,\"./event_data\":985,\"./hover\":986,\"./layout_attributes\":988,\"./layout_defaults\":989,\"./plot\":990,\"./style\":991}],988:[function(t,e,r){\"use strict\";e.exports={funnelmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},funnelgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},funnelgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],989:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"funnel\"===l.type){a=!0;break}}a&&(o(\"funnelmode\"),o(\"funnelgap\",.2),o(\"funnelgroupgap\"))}},{\"../../lib\":719,\"./layout_attributes\":988}],990:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../bar/plot\").plot;function s(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),i[3]=o.c2p(t.nextS1,!0),a[3]=s.c2p(t.nextP1,!0),n?[i,a]:[a,i]}e.exports=function(t,e,r,l){var c=t._fullLayout;!function(t,e,r,o){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each(function(r){var o=n.select(this),u=r[0].trace,h=i.ensureSingle(o,\"g\",\"regions\");if(u.connector&&u.connector.visible){var f=\"h\"===u.orientation,p=h.selectAll(\"g.region\").data(i.identity);p.enter().append(\"g\").classed(\"region\",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var u=s(r,l,c,f),h=u[0],p=u[1],g=\"\";void 0!==h[3]&&void 0!==p[3]&&(g+=f?\"M\"+h[0]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[2]+\"H\"+h[3]+\"L\"+h[1]+\",\"+p[1]+\"Z\":\"M\"+h[1]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[3]+\"V\"+p[2]+\"L\"+h[1]+\",\"+p[0]+\"Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}})}else h.remove()})}(t,e,r,l),function(t,e,r,o){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each(function(r){var o=n.select(this),u=r[0].trace,h=i.ensureSingle(o,\"g\",\"lines\");if(u.connector&&u.connector.visible&&u.connector.line.width){var f=\"h\"===u.orientation,p=h.selectAll(\"g.line\").data(i.identity);p.enter().append(\"g\").classed(\"line\",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var u=s(r,l,c,f),h=u[0],p=u[1],g=\"\";void 0!==h[3]&&void 0!==p[3]&&(f?(g+=\"M\"+h[0]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[2],g+=\"M\"+h[1]+\",\"+p[1]+\"L\"+h[3]+\",\"+p[2]):(g+=\"M\"+h[1]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[3],g+=\"M\"+h[1]+\",\"+p[0]+\"L\"+h[2]+\",\"+p[2])),\"\"===g&&(g=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}})}else h.remove()})}(t,e,r,l),o(t,e,r,l,{mode:c.funnelmode,norm:c.funnelmode,gap:c.funnelgap,groupgap:c.funnelgroupgap})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../bar/plot\":867,d3:163}],991:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\").styleTextPoints;e.exports={style:function(t,e,r){var l=r||n.select(t).selectAll(\"g.funnellayer\").selectAll(\"g.trace\");l.style(\"opacity\",function(t){return t[0].trace.opacity}),l.each(function(e){var r=n.select(this),l=e[0].trace;r.selectAll(\".point > path\").each(function(t){if(!t.isBlank){var e=l.marker;n.select(this).call(a.fill,t.mc||e.color).call(a.stroke,t.mlc||e.line.color).call(i.dashLine,e.line.dash,t.mlw||e.line.width).style(\"opacity\",l.selectedpoints&&!t.selected?o:1)}}),s(r,l,t),r.selectAll(\".regions\").each(function(){n.select(this).selectAll(\"path\").style(\"stroke-width\",0).call(a.fill,l.connector.fillcolor)}),r.selectAll(\".lines\").each(function(){var t=l.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)})})}}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../constants/interactions\":694,\"../bar/style\":870,d3:163}],992:[function(t,e,r){\"use strict\";var n=t(\"../pie/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../plots/domain\").attributes,o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports={labels:n.labels,label0:n.label0,dlabel:n.dlabel,values:n.values,marker:{colors:n.marker.colors,line:{color:s({},n.marker.line.color,{dflt:null}),width:s({},n.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},text:n.text,hovertext:n.hovertext,scalegroup:s({},n.scalegroup,{}),textinfo:s({},n.textinfo,{flags:[\"label\",\"text\",\"value\",\"percent\"]}),hoverinfo:s({},i.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:o({},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),textposition:s({},n.textposition,{values:[\"inside\",\"none\"],dflt:\"inside\"}),textfont:n.textfont,insidetextfont:n.insidetextfont,title:{text:n.title.text,font:n.title.font,position:s({},n.title.position,{values:[\"top left\",\"top center\",\"top right\"],dflt:\"top center\"}),editType:\"plot\"},domain:a({name:\"funnelarea\",trace:!0,editType:\"calc\"}),aspectratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},baseratio:{valType:\"number\",min:0,max:1,dflt:.333,editType:\"plot\"}}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../pie/attributes\":1086}],993:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData;r.name=\"funnelarea\",r.plot=function(t){var e=n.getModule(\"funnelarea\"),r=i(t.calcdata,e)[0];e.plot(t,r)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"funnelarea\"),a=e._has&&e._has(\"funnelarea\");i&&!a&&n._funnelarealayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],994:[function(t,e,r){\"use strict\";var n=t(\"../pie/calc\");e.exports={calc:function(t,e){return n.calc(t,e)},crossTraceCalc:function(t){n.crossTraceCalc(t,{type:\"funnelarea\"})}}},{\"../pie/calc\":1088}],995:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}var c,u=l(\"values\"),h=n.isArrayOrTypedArray(u),f=l(\"labels\");if(Array.isArray(f)?(c=f.length,h&&(c=Math.min(c,u.length))):h&&(c=u.length,l(\"label0\"),l(\"dlabel\")),c){e._length=c,l(\"marker.line.width\")&&l(\"marker.line.color\",s.paper_bgcolor),l(\"marker.colors\"),l(\"scalegroup\");var p=l(\"text\"),d=l(\"textinfo\",Array.isArray(p)?\"text+percent\":\"percent\");if(l(\"hovertext\"),l(\"hovertemplate\"),d&&\"none\"!==d){var g=l(\"textposition\");o(t,e,s,l,g,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}a(e,s,l),l(\"title.text\")&&(l(\"title.position\"),n.coerceFont(l,\"title.font\",s.font)),l(\"aspectratio\"),l(\"baseratio\")}else e.visible=!1}},{\"../../lib\":719,\"../../plots/domain\":792,\"../bar/defaults\":861,\"./attributes\":992}],996:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"funnelarea\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"funnelarea\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\"),styleOne:t(\"../pie/style_one\"),meta:{}}},{\"../pie/style_one\":1097,\"./attributes\":992,\"./base_plot\":993,\"./calc\":994,\"./defaults\":995,\"./layout_attributes\":997,\"./layout_defaults\":998,\"./plot\":999,\"./style\":1e3}],997:[function(t,e,r){\"use strict\";var n=t(\"../pie/layout_attributes\").hiddenlabels;e.exports={hiddenlabels:n,funnelareacolorway:{valType:\"colorlist\",editType:\"calc\"},extendfunnelareacolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{\"../pie/layout_attributes\":1093}],998:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"funnelareacolorway\",e.colorway),r(\"extendfunnelareacolors\")}},{\"../../lib\":719,\"./layout_attributes\":997}],999:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../lib\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../bar/plot\"),l=s.getTransform,c=s.toMoveInsideBar,u=t(\"../pie/helpers\"),h=t(\"../pie/plot\"),f=h.attachFxHandlers,p=h.determineInsideTextFont,d=h.layoutAreas,g=h.prerenderTitles,v=h.positionTitleOutside;function m(t,e){return\"l\"+(e[0]-t[0])+\",\"+(e[1]-t[1])}e.exports=function(t,e){var r=t._fullLayout;g(e,t),d(e,r._size),a.makeTraceGroups(r._funnelarealayer,e,\"trace\").each(function(e){var s=n.select(this),h=e[0],d=h.trace;!function(t){if(!t.length)return;var e=t[0],r=e.trace,n=r.aspectratio,i=r.baseratio;i>.999&&(i=.999);var a,o=Math.pow(i,2),s=e.vTotal,l=s,c=s*o/(1-o)/s;function u(){var t,e={x:t=Math.sqrt(c),y:-t};return[e.x,e.y]}var h,f,p=[];for(p.push(u()),h=t.length-1;h>-1;h--)if(!(f=t[h]).hidden){var d=f.v/l;c+=d,p.push(u())}var g=1/0,v=-1/0;for(h=0;h<p.length;h++)a=p[h],g=Math.min(g,a[1]),v=Math.max(v,a[1]);for(h=0;h<p.length;h++)p[h][1]-=(v+g)/2;var m=p[p.length-1][0],y=e.r,x=(v-g)/2,b=y/m,_=y/x*n;for(e.r=_*x,h=0;h<p.length;h++)p[h][0]*=b,p[h][1]*=_;var w=[-(a=p[0])[0],a[1]],k=[a[0],a[1]],T=0;for(h=t.length-1;h>-1;h--)if(!(f=t[h]).hidden){var A=p[T+=1][0],M=p[T][1];f.TL=[-A,M],f.TR=[A,M],f.BL=w,f.BR=k,f.pxmid=(S=f.TR,E=f.BR,[.5*(S[0]+E[0]),.5*(S[1]+E[1])]),w=f.TL,k=f.TR}var S,E}(e),s.each(function(){var s=n.select(this).selectAll(\"g.slice\").data(e);s.enter().append(\"g\").classed(\"slice\",!0),s.exit().remove(),s.each(function(r){if(r.hidden)n.select(this).selectAll(\"path,g\").remove();else{r.pointNumber=r.i,r.curveNumber=d.index;var s=h.cx,g=h.cy,v=n.select(this),y=v.selectAll(\"path.surface\").data([r]);y.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),v.call(f,t,e);var x=\"M\"+(s+r.TR[0])+\",\"+(g+r.TR[1])+m(r.TR,r.BR)+m(r.BR,r.BL)+m(r.BL,r.TL)+\"Z\";y.attr(\"d\",x);var b=u.castOption(d.textposition,r.pts),_=v.selectAll(\"g.slicetext\").data(r.text&&\"none\"!==b?[0]:[]);_.enter().append(\"g\").classed(\"slicetext\",!0),_.exit().remove(),_.each(function(){var e=a.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)});e.text(r.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,p(d,r,t._fullLayout.font)).call(o.convertToTspans,t);var u,h,f,v=i.bBox(e.node()),m=Math.min(r.BL[1],r.BR[1]),y=Math.max(r.TL[1],r.TR[1]);h=Math.max(r.TL[0],r.BL[0]),f=Math.min(r.TR[0],r.BR[0]),u=l(c(h,f,m,y,v,{isHorizontal:!0,constrained:!0,angle:0,anchor:\"middle\"})),e.attr(\"transform\",\"translate(\"+s+\",\"+g+\")\"+u)})}});var g=n.select(this).selectAll(\"g.titletext\").data(d.title.text?[0]:[]);g.enter().append(\"g\").classed(\"titletext\",!0),g.exit().remove(),g.each(function(){var e=a.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),s=d.title.text;d._meta&&(s=a.templateString(s,d._meta)),e.text(s).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,d.title.font).call(o.convertToTspans,t);var l=v(h,r._size);e.attr(\"transform\",\"translate(\"+l.x+\",\"+l.y+\")\"+(l.scale<1?\"scale(\"+l.scale+\")\":\"\")+\"translate(\"+l.tx+\",\"+l.ty+\")\")})})})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../bar/plot\":867,\"../pie/helpers\":1091,\"../pie/plot\":1095,d3:163}],1000:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../pie/style_one\");e.exports=function(t){t._fullLayout._funnelarealayer.selectAll(\".trace\").each(function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each(function(t){n.select(this).call(i,t,e)})})}},{\"../pie/style_one\":1097,d3:163}],1001:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../components/colorscale/attributes\"),o=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../lib/extend\").extendFlat);e.exports=o({z:{valType:\"data_array\",editType:\"calc\"},x:o({},n.x,{impliedEdits:{xtype:\"array\"}}),x0:o({},n.x0,{impliedEdits:{xtype:\"scaled\"}}),dx:o({},n.dx,{impliedEdits:{xtype:\"scaled\"}}),y:o({},n.y,{impliedEdits:{ytype:\"array\"}}),y0:o({},n.y0,{impliedEdits:{ytype:\"scaled\"}}),dy:o({},n.dy,{impliedEdits:{ytype:\"scaled\"}}),text:{valType:\"data_array\",editType:\"calc\"},hovertext:{valType:\"data_array\",editType:\"calc\"},transpose:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xtype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},ytype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},zsmooth:{valType:\"enumerated\",values:[\"fast\",\"best\",!1],dflt:!1,editType:\"calc\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xgap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},ygap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},zhoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},hovertemplate:i()},{transforms:void 0},a(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../scatter/attributes\":1112}],1002:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../histogram2d/calc\"),s=t(\"../../components/colorscale/calc\"),l=t(\"./convert_column_xyz\"),c=t(\"./clean_2d_array\"),u=t(\"./interp2d\"),h=t(\"./find_empties\"),f=t(\"./make_bound_array\");e.exports=function(t,e){var r,p,d,g,v,m,y,x,b,_=a.getFromId(t,e.xaxis||\"x\"),w=a.getFromId(t,e.yaxis||\"y\"),k=n.traceIs(e,\"contour\"),T=n.traceIs(e,\"histogram\"),A=n.traceIs(e,\"gl2d\"),M=k?\"best\":e.zsmooth;if(_._minDtick=0,w._minDtick=0,T)r=(b=o(t,e)).x,p=b.x0,d=b.dx,g=b.y,v=b.y0,m=b.dy,y=b.z;else{var S=e.z;i.isArray1D(S)?(l(e,_,w,\"x\",\"y\",[\"z\"]),r=e._x,g=e._y,S=e._z):(r=e._x=e.x?_.makeCalcdata(e,\"x\"):[],g=e._y=e.y?w.makeCalcdata(e,\"y\"):[]),p=e.x0,d=e.dx,v=e.y0,m=e.dy,y=c(S,e,_,w),(k||e.connectgaps)&&(e._emptypoints=h(y),u(y,e._emptypoints))}function E(t){M=e._input.zsmooth=e.zsmooth=!1,i.warn('cannot use zsmooth: \"fast\": '+t)}if(\"fast\"===M)if(\"log\"===_.type||\"log\"===w.type)E(\"log axis found\");else if(!T){if(r.length){var C=(r[r.length-1]-r[0])/(r.length-1),L=Math.abs(C/100);for(x=0;x<r.length-1;x++)if(Math.abs(r[x+1]-r[x]-C)>L){E(\"x scale is not linear\");break}}if(g.length&&\"fast\"===M){var P=(g[g.length-1]-g[0])/(g.length-1),O=Math.abs(P/100);for(x=0;x<g.length-1;x++)if(Math.abs(g[x+1]-g[x]-P)>O){E(\"y scale is not linear\");break}}}var z=i.maxRowLength(y),I=\"scaled\"===e.xtype?\"\":r,D=f(e,I,p,d,z,_),R=\"scaled\"===e.ytype?\"\":g,F=f(e,R,v,m,y.length,w);A||(e._extremes[_._id]=a.findExtremes(_,D),e._extremes[w._id]=a.findExtremes(w,F));var B={x:D,y:F,z:y,text:e._text||e.text,hovertext:e._hovertext||e.hovertext};if(I&&I.length===D.length-1&&(B.xCenter=I),R&&R.length===F.length-1&&(B.yCenter=R),T&&(B.xRanges=b.xRanges,B.yRanges=b.yRanges,B.pts=b.pts),k||s(t,e,{vals:y,cLetter:\"z\"}),k&&e.contours&&\"heatmap\"===e.contours.coloring){var N={type:\"contour\"===e.type?\"heatmap\":\"histogram2d\",xcalendar:e.xcalendar,ycalendar:e.ycalendar};B.xfill=f(N,I,p,d,z,_),B.yfill=f(N,R,v,m,y.length,w)}return[B]}},{\"../../components/colorscale/calc\":601,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../histogram2d/calc\":1033,\"./clean_2d_array\":1003,\"./convert_column_xyz\":1005,\"./find_empties\":1007,\"./interp2d\":1010,\"./make_bound_array\":1011}],1003:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r,o){var s,l,c,u,h,f;function p(t){if(n(t))return+t}if(e&&e.transpose){for(s=0,h=0;h<t.length;h++)s=Math.max(s,t[h].length);if(0===s)return!1;c=function(t){return t.length},u=function(t,e,r){return(t[r]||[])[e]}}else s=t.length,c=function(t,e){return t[e].length},u=function(t,e,r){return(t[e]||[])[r]};var d=function(t,e,r){return e===a||r===a?a:u(t,e,r)};function g(t){if(e&&\"carpet\"!==e.type&&\"contourcarpet\"!==e.type&&t&&\"category\"===t.type&&e[\"_\"+t._id.charAt(0)].length){var r=t._id.charAt(0),n={},o=e[\"_\"+r+\"CategoryMap\"]||e[r];for(h=0;h<o.length;h++)n[o[h]]=h;return function(e){var r=n[t._categories[e]];return r+1?r:a}}return i.identity}var v=g(r),m=g(o);o&&\"category\"===o.type&&(s=o._categories.length);var y=new Array(s);for(h=0;h<s;h++)for(l=r&&\"category\"===r.type?r._categories.length:c(t,h),y[h]=new Array(l),f=0;f<l;f++)y[h][f]=p(d(t,m(h),v(f)));return y}},{\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],1004:[function(t,e,r){\"use strict\";e.exports={min:\"zmin\",max:\"zmax\"}},{}],1005:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r,a,o,s){var l,c,u,h,f=t._length,p=e.makeCalcdata(t,a),d=r.makeCalcdata(t,o),g=t.text,v=void 0!==g&&n.isArray1D(g),m=t.hovertext,y=void 0!==m&&n.isArray1D(m),x=n.distinctVals(p),b=x.vals,_=n.distinctVals(d),w=_.vals,k=[];for(l=0;l<s.length;l++)k[l]=n.init2dArray(w.length,b.length);for(v&&(u=n.init2dArray(w.length,b.length)),y&&(h=n.init2dArray(w.length,b.length)),l=0;l<f;l++)if(p[l]!==i&&d[l]!==i){var T=n.findBin(p[l]+x.minDiff/2,b),A=n.findBin(d[l]+_.minDiff/2,w);for(c=0;c<s.length;c++){var M=t[s[c]];k[c][A][T]=M[l]}v&&(u[A][T]=g[l]),y&&(h[A][T]=m[l])}for(t[\"_\"+a]=b,t[\"_\"+o]=w,c=0;c<s.length;c++)t[\"_\"+s[c]]=k[c];v&&(t._text=u),y&&(t._hovertext=h),e&&\"category\"===e.type&&(t[\"_\"+a+\"CategoryMap\"]=b.map(function(t){return e._categories[t]})),r&&\"category\"===r.type&&(t[\"_\"+o+\"CategoryMap\"]=w.map(function(t){return r._categories[t]}))}},{\"../../constants/numerical\":695,\"../../lib\":719}],1006:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xyz_defaults\"),a=t(\"./style_defaults\"),o=t(\"../../components/colorscale/defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l)?(c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\"),a(t,e,c,l),c(\"connectgaps\",n.isArray1D(e.z)&&!1!==e.zsmooth),o(t,e,l,c,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":1001,\"./style_defaults\":1014,\"./xyz_defaults\":1015}],1007:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").maxRowLength;e.exports=function(t){var e,r,i,a,o,s,l,c,u=[],h={},f=[],p=t[0],d=[],g=[0,0,0],v=n(t);for(r=0;r<t.length;r++)for(e=d,d=p,p=t[r+1]||[],i=0;i<v;i++)void 0===d[i]&&((s=(void 0!==d[i-1]?1:0)+(void 0!==d[i+1]?1:0)+(void 0!==e[i]?1:0)+(void 0!==p[i]?1:0))?(0===r&&s++,0===i&&s++,r===t.length-1&&s++,i===d.length-1&&s++,s<4&&(h[[r,i]]=[r,i,s]),u.push([r,i,s])):f.push([r,i]));for(;f.length;){for(l={},c=!1,o=f.length-1;o>=0;o--)(s=((h[[(r=(a=f[o])[0])-1,i=a[1]]]||g)[2]+(h[[r+1,i]]||g)[2]+(h[[r,i-1]]||g)[2]+(h[[r,i+1]]||g)[2])/20)&&(l[a]=[r,i,s],f.splice(o,1),c=!0);if(!c)throw\"findEmpties iterated with no new neighbors\";for(a in l)h[a]=l[a],u.push(l[a])}return u.sort(function(t,e){return e[2]-t[2]})}},{\"../../lib\":719}],1008:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../components/colorscale\").extractOpts;e.exports=function(t,e,r,s,l,c){var u,h,f,p,d=t.cd[0],g=d.trace,v=t.xa,m=t.ya,y=d.x,x=d.y,b=d.z,_=d.xCenter,w=d.yCenter,k=d.zmask,T=g.zhoverformat,A=y,M=x;if(!1!==t.index){try{f=Math.round(t.index[1]),p=Math.round(t.index[0])}catch(e){return void i.error(\"Error hovering on heatmap, pointNumber must be [row,col], found:\",t.index)}if(f<0||f>=b[0].length||p<0||p>b.length)return}else{if(n.inbox(e-y[0],e-y[y.length-1],0)>0||n.inbox(r-x[0],r-x[x.length-1],0)>0)return;if(c){var S;for(A=[2*y[0]-y[1]],S=1;S<y.length;S++)A.push((y[S]+y[S-1])/2);for(A.push([2*y[y.length-1]-y[y.length-2]]),M=[2*x[0]-x[1]],S=1;S<x.length;S++)M.push((x[S]+x[S-1])/2);M.push([2*x[x.length-1]-x[x.length-2]])}f=Math.max(0,Math.min(A.length-2,i.findBin(e,A))),p=Math.max(0,Math.min(M.length-2,i.findBin(r,M)))}var E=v.c2p(y[f]),C=v.c2p(y[f+1]),L=m.c2p(x[p]),P=m.c2p(x[p+1]);c?(C=E,u=y[f],P=L,h=x[p]):(u=_?_[f]:(y[f]+y[f+1])/2,h=w?w[p]:(x[p]+x[p+1])/2,v&&\"category\"===v.type&&(u=y[f]),m&&\"category\"===m.type&&(h=x[p]),g.zsmooth&&(E=C=v.c2p(u),L=P=m.c2p(h)));var O,z=b[p][f];k&&!k[p][f]&&(z=void 0),Array.isArray(d.hovertext)&&Array.isArray(d.hovertext[p])?O=d.hovertext[p][f]:Array.isArray(d.text)&&Array.isArray(d.text[p])&&(O=d.text[p][f]);var I=o(g),D={type:\"linear\",range:[I.min,I.max],hoverformat:T,_separators:v._separators,_numFormat:v._numFormat},R=a.tickText(D,z,\"hover\").text;return[i.extendFlat(t,{index:[p,f],distance:t.maxHoverDistance,spikeDistance:t.maxSpikeDistance,x0:E,x1:C,y0:L,y1:P,xLabelVal:u,yLabelVal:h,zLabelVal:z,zLabel:R,text:O})]}},{\"../../components/colorscale\":605,\"../../components/fx\":632,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],1009:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:t(\"./colorbar\"),style:t(\"./style\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"heatmap\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":1001,\"./calc\":1002,\"./colorbar\":1004,\"./defaults\":1006,\"./hover\":1008,\"./plot\":1012,\"./style\":1013}],1010:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[-1,0],[1,0],[0,-1],[0,1]];function a(t){return.5-.25*Math.min(1,.5*t)}function o(t,e,r){var n,a,o,s,l,c,u,h,f,p,d,g,v,m=0;for(s=0;s<e.length;s++){for(a=(n=e[s])[0],o=n[1],d=t[a][o],p=0,f=0,l=0;l<4;l++)(u=t[a+(c=i[l])[0]])&&void 0!==(h=u[o+c[1]])&&(0===p?g=v=h:(g=Math.min(g,h),v=Math.max(v,h)),f++,p+=h);if(0===f)throw\"iterateInterp2d order is wrong: no defined neighbors\";t[a][o]=p/f,void 0===d?f<4&&(m=1):(t[a][o]=(1+r)*t[a][o]-r*d,v>g&&(m=Math.max(m,Math.abs(t[a][o]-d)/(v-g))))}return m}e.exports=function(t,e){var r,i=1;for(o(t,e),r=0;r<e.length&&!(e[r][2]<4);r++);for(e=e.slice(r),r=0;r<100&&i>.01;r++)i=o(t,e,a(i));return i>.01&&n.log(\"interp2d didn't converge quickly\",i),t}},{\"../../lib\":719}],1011:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a,o,s){var l,c,u,h=[],f=n.traceIs(t,\"contour\"),p=n.traceIs(t,\"histogram\"),d=n.traceIs(t,\"gl2d\");if(i(e)&&e.length>1&&!p&&\"category\"!==s.type){var g=e.length;if(!(g<=o))return f?e.slice(0,o):e.slice(0,o+1);if(f||d)h=e.slice(0,o);else if(1===o)h=[e[0]-.5,e[0]+.5];else{for(h=[1.5*e[0]-.5*e[1]],u=1;u<g;u++)h.push(.5*(e[u-1]+e[u]));h.push(1.5*e[g-1]-.5*e[g-2])}if(g<o){var v=h[h.length-1],m=v-h[h.length-2];for(u=g;u<o;u++)v+=m,h.push(v)}}else{var y=t[s._id.charAt(0)+\"calendar\"];if(p)l=s.r2c(r,0,y);else if(i(e)&&1===e.length)l=e[0];else if(void 0===r)l=0;else{l=(\"log\"===s.type?s.d2c:s.r2c)(r,0,y)}for(c=a||1,u=f||d?0:-.5;u<o;u++)h.push(l+c*u)}return h}},{\"../../lib\":719,\"../../registry\":847}],1012:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/colorscale\").makeColorScaleFuncFromTrace,l=t(\"../../constants/xmlns_namespaces\");function c(t,e){var r=e.length-2,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=e[n+1],s=o.constrain(n+(t-i)/(a-i)-.5,0,r),l=Math.round(s),c=Math.abs(s-l);return s&&s!==r&&c?{bin0:l,frac:c,bin1:Math.round(l+c/(s-l))}:{bin0:l,bin1:l,frac:0}}function u(t,e){var r=e.length-1,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=(t-i)/(e[n+1]-i)||0;return a<=0?{bin0:n,bin1:n,frac:0}:a<.5?{bin0:n,bin1:n+1,frac:a}:{bin0:n+1,bin1:n,frac:1-a}}function h(t,e,r){t[e]=r[0],t[e+1]=r[1],t[e+2]=r[2],t[e+3]=Math.round(255*r[3])}e.exports=function(t,e,r,f){var p=e.xaxis,d=e.yaxis;o.makeTraceGroups(f,r,\"hm\").each(function(e){var r,f,g,v,m,y,x=n.select(this),b=e[0],_=b.trace,w=b.z,k=b.x,T=b.y,A=b.xCenter,M=b.yCenter,S=a.traceIs(_,\"contour\"),E=S?\"best\":_.zsmooth,C=w.length,L=o.maxRowLength(w),P=!1,O=!1;for(y=0;void 0===r&&y<k.length-1;)r=p.c2p(k[y]),y++;for(y=k.length-1;void 0===f&&y>0;)f=p.c2p(k[y]),y--;for(f<r&&(g=f,f=r,r=g,P=!0),y=0;void 0===v&&y<T.length-1;)v=d.c2p(T[y]),y++;for(y=T.length-1;void 0===m&&y>0;)m=d.c2p(T[y]),y--;if(m<v&&(g=v,v=m,m=g,O=!0),S&&(A=k,M=T,k=b.xfill,T=b.yfill),\"fast\"!==E){var z=\"best\"===E?0:.5;r=Math.max(-z*p._length,r),f=Math.min((1+z)*p._length,f),v=Math.max(-z*d._length,v),m=Math.min((1+z)*d._length,m)}var I=Math.round(f-r),D=Math.round(m-v);if(I<=0||D<=0){x.selectAll(\"image\").data([]).exit().remove()}else{var R,F;\"fast\"===E?(R=L,F=C):(R=I,F=D);var B=document.createElement(\"canvas\");B.width=R,B.height=F;var N,j,U=B.getContext(\"2d\"),V=s(_,{noNumericCheck:!0,returnArray:!0});\"fast\"===E?(N=P?function(t){return L-1-t}:o.identity,j=O?function(t){return C-1-t}:o.identity):(N=function(t){return o.constrain(Math.round(p.c2p(k[t])-r),0,I)},j=function(t){return o.constrain(Math.round(d.c2p(T[t])-v),0,D)});var q,H,G,Y,W,X=j(0),Z=[X,X],J=P?0:1,K=O?0:1,$=0,Q=0,tt=0,et=0;if(E){var rt,nt=0;try{rt=new Uint8Array(I*D*4)}catch(t){rt=new Array(I*D*4)}if(\"best\"===E){var it,at,ot,st=A||k,lt=M||T,ct=new Array(st.length),ut=new Array(lt.length),ht=new Array(I),ft=A?u:c,pt=M?u:c;for(y=0;y<st.length;y++)ct[y]=Math.round(p.c2p(st[y])-r);for(y=0;y<lt.length;y++)ut[y]=Math.round(d.c2p(lt[y])-v);for(y=0;y<I;y++)ht[y]=ft(y,ct);for(H=0;H<D;H++)for(at=w[(it=pt(H,ut)).bin0],ot=w[it.bin1],y=0;y<I;y++,nt+=4)h(rt,nt,W=Tt(at,ot,ht[y],it))}else for(H=0;H<C;H++)for(Y=w[H],Z=j(H),y=0;y<I;y++)W=kt(Y[y],1),h(rt,nt=4*(Z*I+N(y)),W);var dt=U.createImageData(I,D);try{dt.data.set(rt)}catch(t){var gt=dt.data,vt=gt.length;for(H=0;H<vt;H++)gt[H]=rt[H]}U.putImageData(dt,0,0)}else{var mt=_.xgap,yt=_.ygap,xt=Math.floor(mt/2),bt=Math.floor(yt/2);for(H=0;H<C;H++)if(Y=w[H],Z.reverse(),Z[K]=j(H+1),Z[0]!==Z[1]&&void 0!==Z[0]&&void 0!==Z[1])for(q=[G=N(0),G],y=0;y<L;y++)q.reverse(),q[J]=N(y+1),q[0]!==q[1]&&void 0!==q[0]&&void 0!==q[1]&&(W=kt(Y[y],(q[1]-q[0])*(Z[1]-Z[0])),U.fillStyle=\"rgba(\"+W.join(\",\")+\")\",U.fillRect(q[0]+xt,Z[0]+bt,q[1]-q[0]-mt,Z[1]-Z[0]-yt))}Q=Math.round(Q/$),tt=Math.round(tt/$),et=Math.round(et/$);var _t=i(\"rgb(\"+Q+\",\"+tt+\",\"+et+\")\");t._hmpixcount=(t._hmpixcount||0)+$,t._hmlumcount=(t._hmlumcount||0)+$*_t.getLuminance();var wt=x.selectAll(\"image\").data(e);wt.enter().append(\"svg:image\").attr({xmlns:l.svg,preserveAspectRatio:\"none\"}),wt.attr({height:D,width:I,x:r,y:v,\"xlink:href\":B.toDataURL(\"image/png\")})}function kt(t,e){if(void 0!==t){var r=V(t);return r[0]=Math.round(r[0]),r[1]=Math.round(r[1]),r[2]=Math.round(r[2]),$+=e,Q+=r[0]*e,tt+=r[1]*e,et+=r[2]*e,r}return[0,0,0,0]}function Tt(t,e,r,n){var i=t[r.bin0];if(void 0===i)return kt(void 0,1);var a,o=t[r.bin1],s=e[r.bin0],l=e[r.bin1],c=o-i||0,u=s-i||0;return a=void 0===o?void 0===l?0:void 0===s?2*(l-i):2*(2*l-s-i)/3:void 0===l?void 0===s?0:2*(2*i-o-s)/3:void 0===s?2*(2*l-o-i)/3:l+i-o-s,kt(i+r.frac*c+n.frac*(u+r.frac*a))}})}},{\"../../components/colorscale\":605,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../registry\":847,d3:163,tinycolor2:537}],1013:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t){n.select(t).selectAll(\".hm image\").style(\"opacity\",function(t){return t.trace.opacity})}},{d3:163}],1014:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){!1===r(\"zsmooth\")&&(r(\"xgap\"),r(\"ygap\")),r(\"zhoverformat\")}},{}],1015:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\");function o(t,e){var r=e(t);return\"scaled\"===(r?e(t+\"type\",\"array\"):\"scaled\")&&(e(t+\"0\"),e(\"d\"+t)),r}e.exports=function(t,e,r,s,l,c){var u,h,f=r(\"z\");if(l=l||\"x\",c=c||\"y\",void 0===f||!f.length)return 0;if(i.isArray1D(t.z)){u=r(l),h=r(c);var p=i.minRowLength(u),d=i.minRowLength(h);if(0===p||0===d)return 0;e._length=Math.min(p,d,f.length)}else{if(u=o(l,r),h=o(c,r),!function(t){for(var e,r=!0,a=!1,o=!1,s=0;s<t.length;s++){if(e=t[s],!i.isArrayOrTypedArray(e)){r=!1;break}e.length>0&&(a=!0);for(var l=0;l<e.length;l++)if(n(e[l])){o=!0;break}}return r&&a&&o}(f))return 0;r(\"transpose\"),e._length=null}return a.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[l,c],s),!0}},{\"../../lib\":719,\"../../registry\":847,\"fast-isnumeric\":225}],1016:[function(t,e,r){\"use strict\";for(var n=t(\"../heatmap/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=[\"z\",\"x\",\"x0\",\"dx\",\"y\",\"y0\",\"dy\",\"text\",\"transpose\",\"xtype\",\"ytype\"],l={},c=0;c<s.length;c++){var u=s[c];l[u]=n[u]}a(l,i(\"\",{cLetter:\"z\",autoColorDflt:!1})),e.exports=o(l,\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../heatmap/attributes\":1001}],1017:[function(t,e,r){\"use strict\";var n=t(\"gl-heatmap2d\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib/str2rgbarray\");function o(t,e){this.scene=t,this.uid=e,this.type=\"heatmapgl\",this.name=\"\",this.hoverinfo=\"all\",this.xData=[],this.yData=[],this.zData=[],this.textLabels=[],this.idToIndex=[],this.bounds=[0,0,0,0],this.options={z:[],x:[],y:[],shape:[0,0],colorLevels:[0],colorValues:[0,0,0,1]},this.heatmap=n(t.glplot,this.options),this.heatmap._trace=this}var s=o.prototype;s.handlePick=function(t){var e=this.options,r=e.shape,n=t.pointId,i=n%r[0],a=Math.floor(n/r[0]),o=n;return{trace:this,dataCoord:t.dataCoord,traceCoord:[e.x[i],e.y[a],e.z[o]],textLabel:this.textLabels[n],name:this.name,pointIndex:[a,i],hoverinfo:this.hoverinfo}},s.update=function(t,e){var r=e[0];this.index=t.index,this.name=t.name,this.hoverinfo=t.hoverinfo;var n=r.z;this.options.z=[].concat.apply([],n);var o=n[0].length,s=n.length;this.options.shape=[o,s],this.options.x=r.x,this.options.y=r.y;var l=function(t){for(var e=t.colorscale,r=t.zmin,n=t.zmax,i=e.length,o=new Array(i),s=new Array(4*i),l=0;l<i;l++){var c=e[l],u=a(c[1]);o[l]=r+c[0]*(n-r);for(var h=0;h<4;h++)s[4*l+h]=u[h]}return{colorLevels:o,colorValues:s}}(t);this.options.colorLevels=l.colorLevels,this.options.colorValues=l.colorValues,this.textLabels=[].concat.apply([],t.text),this.heatmap.update(this.options);var c=this.scene.xaxis,u=this.scene.yaxis;t._extremes[c._id]=i.findExtremes(c,r.x),t._extremes[u._id]=i.findExtremes(u,r.y)},s.dispose=function(){this.heatmap.dispose()},e.exports=function(t,e,r){var n=new o(t,e.uid);return n.update(e,r),n}},{\"../../lib/str2rgbarray\":742,\"../../plots/cartesian/axes\":767,\"gl-heatmap2d\":251}],1018:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"../heatmap/defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../heatmap/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"heatmapgl\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"2dMap\"],meta:{}}},{\"../../plots/gl2d\":805,\"../heatmap/calc\":1002,\"../heatmap/colorbar\":1004,\"../heatmap/defaults\":1006,\"./attributes\":1016,\"./convert\":1017}],1019:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"./bin_attributes\"),o=t(\"./constants\"),s=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),orientation:n.orientation,histfunc:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"min\",\"max\"],dflt:\"count\",editType:\"calc\"},histnorm:{valType:\"enumerated\",values:[\"\",\"percent\",\"probability\",\"density\",\"probability density\"],dflt:\"\",editType:\"calc\"},cumulative:{enabled:{valType:\"boolean\",dflt:!1,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"increasing\",\"decreasing\"],dflt:\"increasing\",editType:\"calc\"},currentbin:{valType:\"enumerated\",values:[\"include\",\"exclude\",\"half\"],dflt:\"include\",editType:\"calc\"},editType:\"calc\"},nbinsx:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},xbins:a(\"x\",!0),nbinsy:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},ybins:a(\"y\",!0),autobinx:{valType:\"boolean\",dflt:null,editType:\"calc\"},autobiny:{valType:\"boolean\",dflt:null,editType:\"calc\"},bingroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:i({},{keys:o.eventDataKeys}),marker:n.marker,offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,_deprecated:{bardir:n._deprecated.bardir}}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../bar/attributes\":857,\"./bin_attributes\":1021,\"./constants\":1025}],1020:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=t.length,n=0,i=0;i<r;i++)e[i]?(t[i]/=e[i],n+=t[i]):t[i]=null;return n}},{}],1021:[function(t,e,r){\"use strict\";e.exports=function(t,e){return{start:{valType:\"any\",editType:\"calc\"},end:{valType:\"any\",editType:\"calc\"},size:{valType:\"any\",editType:\"calc\"},editType:\"calc\"}}},{}],1022:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports={count:function(t,e,r){return r[t]++,1},sum:function(t,e,r,i){var a=i[e];return n(a)?(a=Number(a),r[t]+=a,a):0},avg:function(t,e,r,i,a){var o=i[e];return n(o)&&(o=Number(o),r[t]+=o,a[t]++),0},min:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]>a){var o=a-r[t];return r[t]=a,o}}return 0},max:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]<a){var o=a-r[t];return r[t]=a,o}}return 0}}},{\"fast-isnumeric\":225}],1023:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.ONEAVGYEAR,a=n.ONEAVGMONTH,o=n.ONEDAY,s=n.ONEHOUR,l=n.ONEMIN,c=n.ONESEC,u=t(\"../../plots/cartesian/axes\").tickIncrement;function h(t,e,r,n){if(t*e<=0)return 1/0;for(var i=Math.abs(e-t),a=\"date\"===r.type,o=f(i,a),s=0;s<10;s++){var l=f(80*o,a);if(o===l)break;if(!p(l,t,e,a,r,n))break;o=l}return o}function f(t,e){return e&&t>c?t>o?t>1.1*i?i:t>1.1*a?a:o:t>s?s:t>l?l:c:Math.pow(10,Math.floor(Math.log(t)/Math.LN10))}function p(t,e,r,n,a,s){if(n&&t>o){var l=d(e,a,s),c=d(r,a,s),u=t===i?0:1;return l[u]!==c[u]}return Math.floor(r/t)-Math.floor(e/t)>.1}function d(t,e,r){var n=e.c2d(t,i,r).split(\"-\");return\"\"===n[0]&&(n.unshift(),n[0]=\"-\"+n[0]),n}e.exports=function(t,e,r,n,a){var s,l,c=-1.1*e,f=-.1*e,p=t-f,d=r[0],g=r[1],v=Math.min(h(d+f,d+p,n,a),h(g+f,g+p,n,a)),m=Math.min(h(d+c,d+f,n,a),h(g+c,g+f,n,a));if(v>m&&m<Math.abs(g-d)/4e3?(s=v,l=!1):(s=Math.min(v,m),l=!0),\"date\"===n.type&&s>o){var y=s===i?1:6,x=s===i?\"M12\":\"M1\";return function(e,r){var o=n.c2d(e,i,a),s=o.indexOf(\"-\",y);s>0&&(o=o.substr(0,s));var c=n.d2c(o,0,a);if(c<e){var h=u(c,x,!1,a);(c+h)/2<e+t&&(c=h)}return r&&l?u(c,x,!0,a):c}}return function(e,r){var n=s*Math.round(e/s);return n+s/10<e&&n+.9*s<e+t&&(n+=s),r&&l&&(n-=s),n}}},{\"../../constants/numerical\":695,\"../../plots/cartesian/axes\":767}],1024:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../bar/arrays_to_calcdata\"),l=t(\"./bin_functions\"),c=t(\"./norm_functions\"),u=t(\"./average\"),h=t(\"./bin_label_vals\");function f(t,e,r,s,l){var c,u,h,p,d,g,v,m=s+\"bins\",y=t._fullLayout,x=e[\"_\"+s+\"bingroup\"],b=y._histogramBinOpts[x],_=\"overlay\"===y.barmode,w=function(t){return r.r2c(t,0,p)},k=function(t){return r.c2r(t,0,p)},T=\"date\"===r.type?function(t){return t||0===t?i.cleanDate(t,null,p):null}:function(t){return n(t)?Number(t):null};function A(t,e,r){e[t+\"Found\"]?(e[t]=T(e[t]),null===e[t]&&(e[t]=r[t])):(g[t]=e[t]=r[t],i.nestedProperty(u[0],m+\".\"+t).set(r[t]))}if(e[\"_\"+s+\"autoBinFinished\"])delete e[\"_\"+s+\"autoBinFinished\"];else{u=b.traces;var M=[],S=!0,E=!1,C=!1;for(c=0;c<u.length;c++)if((h=u[c]).visible){var L=b.dirs[c];d=h[\"_\"+L+\"pos0\"]=r.makeCalcdata(h,L),M=i.concat(M,d),delete h[\"_\"+s+\"autoBinFinished\"],!0===e.visible&&(S?S=!1:(delete h._autoBin,h[\"_\"+s+\"autoBinFinished\"]=1),a.traceIs(h,\"2dMap\")&&(E=!0),\"histogram2dcontour\"===h.type&&(C=!0))}p=u[0][s+\"calendar\"];var P=o.autoBin(M,r,b.nbins,E,p,b.sizeFound&&b.size),O=u[0]._autoBin={};if(g=O[b.dirs[0]]={},C&&(b.size||(P.start=k(o.tickIncrement(w(P.start),P.size,!0,p))),void 0===b.end&&(P.end=k(o.tickIncrement(w(P.end),P.size,!1,p)))),_&&!a.traceIs(e,\"2dMap\")&&0===P._dataSpan&&\"category\"!==r.type&&\"multicategory\"!==r.type){if(l)return[P,d,!0];P=function(t,e,r,n,a){var o,s,l,c=t._fullLayout,u=function(t,e){for(var r=e.xaxis,n=e.yaxis,i=e.orientation,a=[],o=t._fullData,s=0;s<o.length;s++){var l=o[s];\"histogram\"===l.type&&!0===l.visible&&l.orientation===i&&l.xaxis===r&&l.yaxis===n&&a.push(l)}return a}(t,e),h=!1,p=1/0,d=[e];for(o=0;o<u.length;o++)if((s=u[o])===e)h=!0;else if(h){var g=f(t,s,r,n,!0),v=g[0],m=g[2];s[\"_\"+n+\"autoBinFinished\"]=1,s[\"_\"+n+\"pos0\"]=g[1],m?d.push(s):p=Math.min(p,v.size)}else l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]],p=Math.min(p,l.size||s[a].size);var y=new Array(d.length);for(o=0;o<d.length;o++)for(var x=d[o][\"_\"+n+\"pos0\"],b=0;b<x.length;b++)if(void 0!==x[b]){y[o]=x[b];break}isFinite(p)||(p=i.distinctVals(y).minDiff);for(o=0;o<d.length;o++){var _=(s=d[o])[n+\"calendar\"],w={start:r.c2r(y[o]-p/2,0,_),end:r.c2r(y[o]+p/2,0,_),size:p};s._input[a]=s[a]=w,(l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]])&&i.extendFlat(l,w)}return e[a]}(t,e,r,s,m)}(v=h.cumulative||{}).enabled&&\"include\"!==v.currentbin&&(\"decreasing\"===v.direction?P.start=k(o.tickIncrement(w(P.start),P.size,!0,p)):P.end=k(o.tickIncrement(w(P.end),P.size,!1,p))),b.size=P.size,b.sizeFound||(g.size=P.size,i.nestedProperty(u[0],m+\".size\").set(P.size)),A(\"start\",b,P),A(\"end\",b,P)}d=e[\"_\"+s+\"pos0\"],delete e[\"_\"+s+\"pos0\"];var z=e._input[m]||{},I=i.extendFlat({},b),D=b.start,R=r.r2l(z.start),F=void 0!==R;if((b.startFound||F)&&R!==r.r2l(D)){var B=F?R:i.aggNums(Math.min,null,d),N={type:\"category\"===r.type||\"multicategory\"===r.type?\"linear\":r.type,r2l:r.r2l,dtick:b.size,tick0:D,calendar:p,range:[B,o.tickIncrement(B,b.size,!1,p)].map(r.l2r)},j=o.tickFirst(N);j>r.r2l(B)&&(j=o.tickIncrement(j,b.size,!0,p)),I.start=r.l2r(j),F||i.nestedProperty(e,m+\".start\").set(I.start)}var U=b.end,V=r.r2l(z.end),q=void 0!==V;if((b.endFound||q)&&V!==r.r2l(U)){var H=q?V:i.aggNums(Math.max,null,d);I.end=r.l2r(H),q||i.nestedProperty(e,m+\".start\").set(I.end)}var G=\"autobin\"+s;return!1===e._input[G]&&(e._input[m]=i.extendFlat({},e[m]||{}),delete e._input[G],delete e[G]),[I,d]}e.exports={calc:function(t,e){var r,a,p,d,g=[],v=[],m=o.getFromId(t,\"h\"===e.orientation?e.yaxis:e.xaxis),y=\"h\"===e.orientation?\"y\":\"x\",x={x:\"y\",y:\"x\"}[y],b=e[y+\"calendar\"],_=e.cumulative,w=f(t,e,m,y),k=w[0],T=w[1],A=\"string\"==typeof k.size,M=[],S=A?M:k,E=[],C=[],L=[],P=0,O=e.histnorm,z=e.histfunc,I=-1!==O.indexOf(\"density\");_.enabled&&I&&(O=O.replace(/ ?density$/,\"\"),I=!1);var D,R=\"max\"===z||\"min\"===z?null:0,F=l.count,B=c[O],N=!1,j=function(t){return m.r2c(t,0,b)};for(i.isArrayOrTypedArray(e[x])&&\"count\"!==z&&(D=e[x],N=\"avg\"===z,F=l[z]),r=j(k.start),p=j(k.end)+(r-o.tickIncrement(r,k.size,!1,b))/1e6;r<p&&g.length<1e6&&(a=o.tickIncrement(r,k.size,!1,b),g.push((r+a)/2),v.push(R),L.push([]),M.push(r),I&&E.push(1/(a-r)),N&&C.push(0),!(a<=r));)r=a;M.push(r),A||\"date\"!==m.type||(S={start:j(S.start),end:j(S.end),size:S.size});var U,V=v.length,q=!0,H=1/0,G=1/0,Y={};for(r=0;r<T.length;r++){var W=T[r];(d=i.findBin(W,S))>=0&&d<V&&(P+=F(d,r,v,D,C),q&&L[d].length&&W!==T[L[d][0]]&&(q=!1),L[d].push(r),Y[r]=d,H=Math.min(H,W-M[d]),G=Math.min(G,M[d+1]-W))}q||(U=h(H,G,M,m,b)),N&&(P=u(v,C)),B&&B(v,P,E),_.enabled&&function(t,e,r){var n,i,a;function o(e){a=t[e],t[e]/=2}function s(e){i=t[e],t[e]=a+i/2,a+=i}if(\"half\"===r)if(\"increasing\"===e)for(o(0),n=1;n<t.length;n++)s(n);else for(o(t.length-1),n=t.length-2;n>=0;n--)s(n);else if(\"increasing\"===e){for(n=1;n<t.length;n++)t[n]+=t[n-1];\"exclude\"===r&&(t.unshift(0),t.pop())}else{for(n=t.length-2;n>=0;n--)t[n]+=t[n+1];\"exclude\"===r&&(t.push(0),t.shift())}}(v,_.direction,_.currentbin);var X=Math.min(g.length,v.length),Z=[],J=0,K=X-1;for(r=0;r<X;r++)if(v[r]){J=r;break}for(r=X-1;r>=J;r--)if(v[r]){K=r;break}for(r=J;r<=K;r++)if(n(g[r])&&n(v[r])){var $={p:g[r],s:v[r],b:0};_.enabled||($.pts=L[r],q?$.ph0=$.ph1=L[r].length?T[L[r][0]]:g[r]:($.ph0=U(M[r]),$.ph1=U(M[r+1],!0))),Z.push($)}return 1===Z.length&&(Z[0].width1=o.tickIncrement(Z[0].p,k.size,!1,b)-Z[0].p),s(Z,e),i.isArrayOrTypedArray(e.selectedpoints)&&i.tagSelected(Z,e,Y),Z},calcAllAutoBins:f}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../bar/arrays_to_calcdata\":856,\"./average\":1020,\"./bin_functions\":1022,\"./bin_label_vals\":1023,\"./norm_functions\":1031,\"fast-isnumeric\":225}],1025:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"binNumber\"]}},{}],1026:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../../registry\").traceIs,o=t(\"../bar/defaults\").handleGroupingDefaults,s=n.nestedProperty,l=i.getAxisGroup,c=[{aStr:{x:\"xbins.start\",y:\"ybins.start\"},name:\"start\"},{aStr:{x:\"xbins.end\",y:\"ybins.end\"},name:\"end\"},{aStr:{x:\"xbins.size\",y:\"ybins.size\"},name:\"size\"},{aStr:{x:\"nbinsx\",y:\"nbinsy\"},name:\"nbins\"}],u=[\"x\",\"y\"];e.exports=function(t,e){var r,h,f,p,d,g,v,m=e._histogramBinOpts={},y=[],x={},b=[];function _(t,e){return n.coerce(r._input,r,r._module.attributes,t,e)}function w(t){return\"v\"===t.orientation?\"x\":\"y\"}function k(t,r,a){var o=t.uid+\"__\"+a;r||(r=o);var s=function(t,r){return i.getFromTrace({_fullLayout:e},t,r).type}(t,a),l=t[a+\"calendar\"],c=m[r],u=!0;c&&(s===c.axType&&l===c.calendar?(u=!1,c.traces.push(t),c.dirs.push(a)):(r=o,s!==c.axType&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set on a\",\"type:\"+s,\"axis\",\"with bins on\",\"type:\"+c.axType,\"axis.\"].join(\" \")),l!==c.calendar&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set with a\",l,\"calendar\",\"with bins\",c.calendar?\"on a \"+c.calendar+\" calendar\":\"w/o a set calendar\"].join(\" \")))),u&&(m[r]={traces:[t],dirs:[a],axType:s,calendar:t[a+\"calendar\"]||\"\"}),t[\"_\"+a+\"bingroup\"]=r}for(d=0;d<t.length;d++)r=t[d],a(r,\"histogram\")&&(y.push(r),delete r._xautoBinFinished,delete r._yautoBinFinished,a(r,\"2dMap\")||o(r._input,r,e,_));var T=e._alignmentOpts||{};for(d=0;d<y.length;d++){if(r=y[d],f=\"\",!a(r,\"2dMap\")){if(p=w(r),\"group\"===e.barmode&&r.alignmentgroup){var A=r[p+\"axis\"],M=l(e,A)+r.orientation;(T[M]||{})[r.alignmentgroup]&&(f=M)}f||\"overlay\"===e.barmode||(f=l(e,r.xaxis)+l(e,r.yaxis)+w(r))}f?(x[f]||(x[f]=[]),x[f].push(r)):b.push(r)}for(f in x)if(1!==(h=x[f]).length){var S=!1;for(d=0;d<h.length;d++){r=h[d],S=_(\"bingroup\");break}for(f=S||f,d=0;d<h.length;d++){var E=(r=h[d])._input.bingroup;E&&E!==f&&n.warn([\"Trace\",r.index,\"must match\",\"within bingroup\",f+\".\",\"Ignoring its bingroup:\",E,\"setting.\"].join(\" \")),r.bingroup=f,k(r,f,w(r))}}else b.push(h[0]);for(d=0;d<b.length;d++){r=b[d];var C=_(\"bingroup\");if(a(r,\"2dMap\"))for(v=0;v<2;v++){var L=_((p=u[v])+\"bingroup\",C?C+\"__\"+p:null);k(r,L,p)}else k(r,C,w(r))}for(f in m){var P=m[f];for(h=P.traces,g=0;g<c.length;g++){var O,z,I=c[g],D=I.name;if(\"nbins\"!==D||!P.sizeFound){for(d=0;d<h.length;d++){if(r=h[d],p=P.dirs[d],O=I.aStr[p],void 0!==s(r._input,O).get()){P[D]=_(O),P[D+\"Found\"]=!0;break}(z=(r._autoBin||{})[p]||{})[D]&&s(r,O).set(z[D])}if(\"start\"===D||\"end\"===D)for(;d<h.length;d++)(r=h[d])[\"_\"+p+\"bingroup\"]&&_(O,(z=(r._autoBin||{})[p]||{})[D]);\"nbins\"!==D||P.sizeFound||P.nbinsFound||(r=h[0],P[D]=_(O))}}}}},{\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../bar/defaults\":861}],1027:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../bar/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,n){return i.coerce(t,e,s,r,n)}var u=c(\"x\"),h=c(\"y\");c(\"cumulative.enabled\")&&(c(\"cumulative.direction\"),c(\"cumulative.currentbin\")),c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\");var f=c(\"orientation\",h&&!u?\"h\":\"v\"),p=\"v\"===f?\"x\":\"y\",d=\"v\"===f?\"y\":\"x\",g=u&&h?Math.min(i.minRowLength(u)&&i.minRowLength(h)):i.minRowLength(e[p]||[]);if(g){e._length=g,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],l),e[d]&&c(\"histfunc\"),c(\"histnorm\"),c(\"autobin\"+p),o(t,e,c,r,l),i.coerceSelectionMarkerOpacity(e,c);var v=(e.marker.line||{}).color,m=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");m(t,e,v||a.defaultLine,{axis:\"y\"}),m(t,e,v||a.defaultLine,{axis:\"x\",inherit:\"y\"})}else e.visible=!1}},{\"../../components/color\":593,\"../../lib\":719,\"../../registry\":847,\"../bar/style_defaults\":871,\"./attributes\":1019}],1028:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"zLabelVal\"in e&&(t.z=e.zLabelVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),!(r.cumulative||{}).enabled){var a,o=Array.isArray(i)?n[0].pts[i[0]][i[1]]:n[i].pts;if(t.pointNumbers=o,t.binNumber=t.pointNumber,delete t.pointNumber,delete t.pointIndex,r._indexToPoints){a=[];for(var s=0;s<o.length;s++)a=a.concat(r._indexToPoints[o[s]])}else a=o;t.pointIndices=a}return t}},{}],1029:[function(t,e,r){\"use strict\";var n=t(\"../bar/hover\").hoverPoints,i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o){var s=(t=o[0]).cd[t.index],l=t.cd[0].trace;if(!l.cumulative.enabled){var c=\"h\"===l.orientation?\"y\":\"x\";t[c+\"Label\"]=i(t[c+\"a\"],s.ph0,s.ph1)}return l.hovermplate&&(t.hovertemplate=l.hovertemplate),o}}},{\"../../plots/cartesian/axes\":767,\"../bar/hover\":863}],1030:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"../bar/layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),supplyLayoutDefaults:t(\"../bar/layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"../bar/cross_trace_calc\").crossTraceCalc,plot:t(\"../bar/plot\").plot,layerName:\"barlayer\",style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,colorbar:t(\"../scatter/marker_colorbar\"),hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"histogram\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"histogram\",\"oriented\",\"errorBarsOK\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":778,\"../bar/cross_trace_calc\":860,\"../bar/layout_attributes\":865,\"../bar/layout_defaults\":866,\"../bar/plot\":867,\"../bar/select\":868,\"../bar/style\":870,\"../scatter/marker_colorbar\":1129,\"./attributes\":1019,\"./calc\":1024,\"./cross_trace_defaults\":1026,\"./defaults\":1027,\"./event_data\":1028,\"./hover\":1029}],1031:[function(t,e,r){\"use strict\";e.exports={percent:function(t,e){for(var r=t.length,n=100/e,i=0;i<r;i++)t[i]*=n},probability:function(t,e){for(var r=t.length,n=0;n<r;n++)t[n]/=e},density:function(t,e,r,n){var i=t.length;n=n||1;for(var a=0;a<i;a++)t[a]*=r[a]*n},\"probability density\":function(t,e,r,n){var i=t.length;n&&(e/=n);for(var a=0;a<i;a++)t[a]*=r[a]/e}}},{}],1032:[function(t,e,r){\"use strict\";var n=t(\"../histogram/attributes\"),i=t(\"../histogram/bin_attributes\"),a=t(\"../heatmap/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../lib/extend\").extendFlat;e.exports=l({x:n.x,y:n.y,z:{valType:\"data_array\",editType:\"calc\"},marker:{color:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:i(\"x\"),nbinsy:n.nbinsy,ybins:i(\"y\"),autobinx:n.autobinx,autobiny:n.autobiny,bingroup:l({},n.bingroup,{}),xbingroup:l({},n.bingroup,{}),ybingroup:l({},n.bingroup,{}),xgap:a.xgap,ygap:a.ygap,zsmooth:a.zsmooth,zhoverformat:a.zhoverformat,hovertemplate:o({},{keys:\"z\"})},s(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../heatmap/attributes\":1001,\"../histogram/attributes\":1019,\"../histogram/bin_attributes\":1021}],1033:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../histogram/bin_functions\"),o=t(\"../histogram/norm_functions\"),s=t(\"../histogram/average\"),l=t(\"../histogram/bin_label_vals\"),c=t(\"../histogram/calc\").calcAllAutoBins;function u(t,e,r,n){var i,a=new Array(t);if(n)for(i=0;i<t;i++)a[i]=1/(e[i+1]-e[i]);else{var o=1/r;for(i=0;i<t;i++)a[i]=o}return a}function h(t,e){return{start:t(e.start),end:t(e.end),size:e.size}}function f(t,e,r,n,i,a){var o,s=t.length-1,c=new Array(s),u=l(r,n,t,i,a);for(o=0;o<s;o++){var h=(e||[])[o];c[o]=void 0===h?[u(t[o]),u(t[o+1],!0)]:[h,h]}return c}e.exports=function(t,e){var r,l,p,d,g=i.getFromId(t,e.xaxis),v=i.getFromId(t,e.yaxis),m=e.xcalendar,y=e.ycalendar,x=function(t){return g.r2c(t,0,m)},b=function(t){return v.r2c(t,0,y)},_=c(t,e,g,\"x\"),w=_[0],k=_[1],T=c(t,e,v,\"y\"),A=T[0],M=T[1],S=e._length;k.length>S&&k.splice(S,k.length-S),M.length>S&&M.splice(S,M.length-S);var E=[],C=[],L=[],P=\"string\"==typeof w.size,O=\"string\"==typeof A.size,z=[],I=[],D=P?z:w,R=O?I:A,F=0,B=[],N=[],j=e.histnorm,U=e.histfunc,V=-1!==j.indexOf(\"density\"),q=\"max\"===U||\"min\"===U?null:0,H=a.count,G=o[j],Y=!1,W=[],X=[],Z=\"z\"in e?e.z:\"marker\"in e&&Array.isArray(e.marker.color)?e.marker.color:\"\";Z&&\"count\"!==U&&(Y=\"avg\"===U,H=a[U]);var J=w.size,K=x(w.start),$=x(w.end)+(K-i.tickIncrement(K,J,!1,m))/1e6;for(r=K;r<$;r=i.tickIncrement(r,J,!1,m))C.push(q),z.push(r),Y&&L.push(0);z.push(r);var Q,tt=C.length,et=(r-K)/tt,rt=(Q=K+et/2,g.c2r(Q,0,m)),nt=A.size,it=b(A.start),at=b(A.end)+(it-i.tickIncrement(it,nt,!1,y))/1e6;for(r=it;r<at;r=i.tickIncrement(r,nt,!1,y)){E.push(C.slice()),I.push(r);var ot=new Array(tt);for(l=0;l<tt;l++)ot[l]=[];N.push(ot),Y&&B.push(L.slice())}I.push(r);var st=E.length,lt=(r-it)/st,ct=function(t){return v.c2r(t,0,y)}(it+lt/2);V&&(W=u(C.length,D,et,P),X=u(E.length,R,lt,O)),P||\"date\"!==g.type||(D=h(x,D)),O||\"date\"!==v.type||(R=h(b,R));var ut=!0,ht=!0,ft=new Array(tt),pt=new Array(st),dt=1/0,gt=1/0,vt=1/0,mt=1/0;for(r=0;r<S;r++){var yt=k[r],xt=M[r];p=n.findBin(yt,D),d=n.findBin(xt,R),p>=0&&p<tt&&d>=0&&d<st&&(F+=H(p,r,E[d],Z,B[d]),N[d][p].push(r),ut&&(void 0===ft[p]?ft[p]=yt:ft[p]!==yt&&(ut=!1)),ht&&(void 0===pt[d]?pt[d]=xt:pt[d]!==xt&&(ht=!1)),dt=Math.min(dt,yt-z[p]),gt=Math.min(gt,z[p+1]-yt),vt=Math.min(vt,xt-I[d]),mt=Math.min(mt,I[d+1]-xt))}if(Y)for(d=0;d<st;d++)F+=s(E[d],B[d]);if(G)for(d=0;d<st;d++)G(E[d],F,W,X[d]);return{x:k,xRanges:f(z,ut&&ft,dt,gt,g,m),x0:rt,dx:et,y:M,yRanges:f(I,ht&&pt,vt,mt,v,y),y0:ct,dy:lt,z:E,pts:N}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../histogram/average\":1020,\"../histogram/bin_functions\":1022,\"../histogram/bin_label_vals\":1023,\"../histogram/calc\":1024,\"../histogram/norm_functions\":1031}],1034:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./sample_defaults\"),a=t(\"../heatmap/style_defaults\"),o=t(\"../../components/colorscale/defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,l),o(t,e,l,c,{prefix:\"\",cLetter:\"z\"}),c(\"hovertemplate\"))}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../heatmap/style_defaults\":1014,\"./attributes\":1032,\"./sample_defaults\":1037}],1035:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/hover\"),i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a,o,s){var l=n(t,e,r,a,o,s);if(l){var c=(t=l[0]).index,u=c[0],h=c[1],f=t.cd[0],p=f.xRanges[h],d=f.yRanges[u];return t.xLabel=i(t.xa,p[0],p[1]),t.yLabel=i(t.ya,d[0],d[1]),l}}},{\"../../plots/cartesian/axes\":767,\"../heatmap/hover\":1008}],1036:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../heatmap/calc\"),plot:t(\"../heatmap/plot\"),layerName:\"heatmaplayer\",colorbar:t(\"../heatmap/colorbar\"),style:t(\"../heatmap/style\"),hoverPoints:t(\"./hover\"),eventData:t(\"../histogram/event_data\"),moduleType:\"trace\",name:\"histogram2d\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"histogram\"],meta:{}}},{\"../../plots/cartesian\":778,\"../heatmap/calc\":1002,\"../heatmap/colorbar\":1004,\"../heatmap/plot\":1012,\"../heatmap/style\":1013,\"../histogram/cross_trace_defaults\":1026,\"../histogram/event_data\":1028,\"./attributes\":1032,\"./defaults\":1034,\"./hover\":1035}],1037:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"y\"),l=i.minRowLength(o),c=i.minRowLength(s);l&&c?(e._length=Math.min(l,c),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a),(r(\"z\")||r(\"marker.color\"))&&r(\"histfunc\"),r(\"histnorm\"),r(\"autobinx\"),r(\"autobiny\")):e.visible=!1}},{\"../../lib\":719,\"../../registry\":847}],1038:[function(t,e,r){\"use strict\";var n=t(\"../histogram2d/attributes\"),i=t(\"../contour/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat;e.exports=o({x:n.x,y:n.y,z:n.z,marker:n.marker,histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:n.xbins,nbinsy:n.nbinsy,ybins:n.ybins,autobinx:n.autobinx,autobiny:n.autobiny,bingroup:n.bingroup,xbingroup:n.xbingroup,ybingroup:n.ybingroup,autocontour:i.autocontour,ncontours:i.ncontours,contours:i.contours,line:i.line,zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../contour/attributes\":942,\"../histogram2d/attributes\":1032}],1039:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../histogram2d/sample_defaults\"),a=t(\"../contour/contours_defaults\"),o=t(\"../contour/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,function(r){return n.coerce2(t,e,s,r)}),o(t,e,c,l),c(\"hovertemplate\"))}},{\"../../lib\":719,\"../contour/contours_defaults\":949,\"../contour/style_defaults\":963,\"../histogram2d/sample_defaults\":1037,\"./attributes\":1038}],1040:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../contour/calc\"),plot:t(\"../contour/plot\").plot,layerName:\"contourlayer\",style:t(\"../contour/style\"),colorbar:t(\"../contour/colorbar\"),hoverPoints:t(\"../contour/hover\"),moduleType:\"trace\",name:\"histogram2dcontour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"histogram\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":778,\"../contour/calc\":943,\"../contour/colorbar\":945,\"../contour/hover\":955,\"../contour/plot\":960,\"../contour/style\":962,\"../histogram/cross_trace_defaults\":1026,\"./attributes\":1038,\"./defaults\":1039}],1041:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../lib/extend\").extendDeep,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../components/color/attributes\"),l=t(\"../../plots/domain\").attributes,c=t(\"../../plots/cartesian/layout_attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,h=t(\"../../constants/delta.js\"),f=(t(\"../../constants/docs\").FORMAT_LINK,o({editType:\"plot\",colorEditType:\"plot\"})),p={color:{valType:\"color\",editType:\"plot\"},line:{color:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},width:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"calc\"},thickness:{valType:\"number\",min:0,max:1,dflt:1,editType:\"plot\"},editType:\"calc\"},d={valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},g=u(\"steps\",i({},p,{range:d}));e.exports={mode:{valType:\"flaglist\",editType:\"calc\",flags:[\"number\",\"delta\",\"gauge\"],dflt:\"number\"},value:{valType:\"number\",editType:\"calc\",anim:!0},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},domain:l({name:\"indicator\",trace:!0,editType:\"calc\"}),title:{text:{valType:\"string\",editType:\"plot\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},font:n({},f,{}),editType:\"plot\"},number:{valueformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:n({},f,{}),prefix:{valType:\"string\",dflt:\"\",editType:\"plot\"},suffix:{valType:\"string\",dflt:\"\",editType:\"plot\"},editType:\"plot\"},delta:{reference:{valType:\"number\",editType:\"calc\"},position:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],dflt:\"bottom\",editType:\"plot\"},relative:{valType:\"boolean\",editType:\"plot\",dflt:!1},valueformat:{valType:\"string\",editType:\"plot\"},increasing:{symbol:{valType:\"string\",dflt:h.INCREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:h.INCREASING.COLOR,editType:\"plot\"},editType:\"plot\"},decreasing:{symbol:{valType:\"string\",dflt:h.DECREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:h.DECREASING.COLOR,editType:\"plot\"},editType:\"plot\"},font:n({},f,{}),editType:\"calc\"},gauge:{shape:{valType:\"enumerated\",editType:\"plot\",dflt:\"angular\",values:[\"angular\",\"bullet\"]},bar:i({},p,{color:{dflt:\"green\"}}),bgcolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},axis:a({range:d,visible:n({},c.visible,{dflt:!0}),tickmode:c.tickmode,nticks:c.nticks,tick0:c.tick0,dtick:c.dtick,tickvals:c.tickvals,ticktext:c.ticktext,ticks:n({},c.ticks,{dflt:\"outside\"}),ticklen:c.ticklen,tickwidth:c.tickwidth,tickcolor:c.tickcolor,showticklabels:c.showticklabels,tickfont:o({}),tickangle:c.tickangle,tickformat:c.tickformat,tickformatstops:c.tickformatstops,tickprefix:c.tickprefix,showtickprefix:c.showtickprefix,ticksuffix:c.ticksuffix,showticksuffix:c.showticksuffix,separatethousands:c.separatethousands,exponentformat:c.exponentformat,showexponent:c.showexponent,editType:\"plot\"},\"plot\"),steps:g,threshold:{line:{color:n({},p.line.color,{}),width:n({},p.line.width,{dflt:1}),editType:\"plot\"},thickness:n({},p.thickness,{dflt:.85}),value:{valType:\"number\",editType:\"calc\",dflt:!1},editType:\"plot\"},editType:\"plot\"}}},{\"../../components/color/attributes\":592,\"../../constants/delta.js\":689,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1042:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=r.name=\"indicator\";r.plot=function(t,e,r,o){var s=n.getModule(a),l=i(t.calcdata,s)[0];s.plot(t,l,r,o)},r.clean=function(t,e,r,n){var i=n._has&&n._has(a),o=e._has&&e._has(a);i&&!o&&n._indicatorlayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],1043:[function(t,e,r){\"use strict\";e.exports={calc:function(t,e){var r=[],n=e.value;\"number\"!=typeof e._lastValue&&(e._lastValue=e.value);var i=e._lastValue,a=i;return e._hasDelta&&\"number\"==typeof e.delta.reference&&(a=e.delta.reference),r[0]={y:n,lastY:i,delta:n-a,relativeDelta:(n-a)/a},r}}},{}],1044:[function(t,e,r){\"use strict\";e.exports={defaultNumberFontSize:80,bulletNumberDomainSize:.25,bulletPadding:.025,innerRadius:.75,valueThickness:.5,titlePadding:5,horizontalPadding:10}},{}],1045:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../../plot_api/plot_template\"),s=t(\"../../plots/array_container_defaults\"),l=t(\"./constants.js\"),c=t(\"../../plots/cartesian/tick_value_defaults\"),u=t(\"../../plots/cartesian/tick_mark_defaults\"),h=t(\"../../plots/cartesian/tick_label_defaults\");function f(t,e){function r(r,a){return n.coerce(t,e,i.gauge.steps,r,a)}r(\"color\"),r(\"line.color\"),r(\"line.width\"),r(\"range\"),r(\"thickness\")}e.exports={supplyDefaults:function(t,e,r,p){function d(r,a){return n.coerce(t,e,i,r,a)}a(e,p,d),d(\"mode\"),e._hasNumber=-1!==e.mode.indexOf(\"number\"),e._hasDelta=-1!==e.mode.indexOf(\"delta\"),e._hasGauge=-1!==e.mode.indexOf(\"gauge\");var g=d(\"value\");e._range=[0,\"number\"==typeof g?1.5*g:1];var v,m,y,x,b,_,w=new Array(2);function k(t,e){return n.coerce(y,x,i.gauge,t,e)}function T(t,e){return n.coerce(b,_,i.gauge.axis,t,e)}if(e._hasNumber&&(d(\"number.valueformat\"),d(\"number.font.color\",p.font.color),d(\"number.font.family\",p.font.family),d(\"number.font.size\"),void 0===e.number.font.size&&(e.number.font.size=l.defaultNumberFontSize,w[0]=!0),d(\"number.prefix\"),d(\"number.suffix\"),v=e.number.font.size),e._hasDelta&&(d(\"delta.font.color\",p.font.color),d(\"delta.font.family\",p.font.family),d(\"delta.font.size\"),void 0===e.delta.font.size&&(e.delta.font.size=(e._hasNumber?.5:1)*(v||l.defaultNumberFontSize),w[1]=!0),d(\"delta.reference\",e.value),d(\"delta.relative\"),d(\"delta.valueformat\",e.delta.relative?\"2%\":\"\"),d(\"delta.increasing.symbol\"),d(\"delta.increasing.color\"),d(\"delta.decreasing.symbol\"),d(\"delta.decreasing.color\"),d(\"delta.position\"),m=e.delta.font.size),e._scaleNumbers=(!e._hasNumber||w[0])&&(!e._hasDelta||w[1])||!1,d(\"title.font.color\",p.font.color),d(\"title.font.family\",p.font.family),d(\"title.font.size\",.25*(v||m||l.defaultNumberFontSize)),d(\"title.text\"),e._hasGauge){(y=t.gauge)||(y={}),x=o.newContainer(e,\"gauge\"),k(\"shape\"),(e._isBullet=\"bullet\"===e.gauge.shape)||d(\"title.align\",\"center\"),(e._isAngular=\"angular\"===e.gauge.shape)||d(\"align\",\"center\"),k(\"bgcolor\",p.paper_bgcolor),k(\"borderwidth\"),k(\"bordercolor\"),k(\"bar.color\"),k(\"bar.line.color\"),k(\"bar.line.width\"),k(\"bar.thickness\",l.valueThickness*(\"bullet\"===e.gauge.shape?.5:1)),s(y,x,{name:\"steps\",handleItemDefaults:f}),k(\"threshold.value\"),k(\"threshold.thickness\"),k(\"threshold.line.width\"),k(\"threshold.line.color\"),b={},y&&(b=y.axis||{}),_=o.newContainer(x,\"axis\"),T(\"visible\"),e._range=T(\"range\",e._range);var A={outerTicks:!0};c(b,_,T,\"linear\"),h(b,_,T,\"linear\",A),u(b,_,T,A)}else d(\"title.align\",\"center\"),d(\"align\",\"center\"),e._isAngular=e._isBullet=!1;e._length=null}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/tick_label_defaults\":786,\"../../plots/cartesian/tick_mark_defaults\":787,\"../../plots/cartesian/tick_value_defaults\":788,\"../../plots/domain\":792,\"./attributes\":1041,\"./constants.js\":1044}],1046:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"indicator\",basePlotModule:t(\"./base_plot\"),categories:[\"svg\",\"noOpacity\",\"noHover\"],animatable:!0,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\").calc,plot:t(\"./plot\"),meta:{}}},{\"./attributes\":1041,\"./base_plot\":1042,\"./calc\":1043,\"./defaults\":1045,\"./plot\":1047}],1047:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=i.rad2deg,o=t(\"../../constants/alignment\").MID_SHIFT,s=t(\"../../components/drawing\"),l=t(\"./constants\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"../../plots/cartesian/axes\"),h=t(\"../../plots/cartesian/axis_defaults\"),f=t(\"../../plots/cartesian/position_defaults\"),p=t(\"../../plots/cartesian/layout_attributes\"),d=t(\"../../components/color\"),g={left:\"start\",center:\"middle\",right:\"end\"},v={left:0,center:.5,right:1},m=/[yzafpn\\xb5mkMGTPEZY]/;function y(t){return t&&t.duration>0}function x(t){t.each(function(t){d.stroke(n.select(this),t.line.color)}).each(function(t){d.fill(n.select(this),t.color)}).style(\"stroke-width\",function(t){return t.line.width})}function b(t,e,r){var n=t._fullLayout,a=i.extendFlat({type:\"linear\",ticks:\"outside\",range:r,showline:!0},e),o={type:\"linear\",_id:\"x\"+e._id},s={letter:\"x\",font:n.font,noHover:!0,noTickson:!0};function l(t,e){return i.coerce(a,o,p,t,e)}return h(a,o,l,s,n),f(a,o,l,s),o}function _(t,e){return\"translate(\"+t+\",\"+e+\")\"}function w(t,e,r){return[Math.min(e/t.width,r/t.height),t,e+\"x\"+r]}function k(t,e,r,i){var a=document.createElementNS(\"http://www.w3.org/2000/svg\",\"text\"),o=n.select(a);return o.text(t).attr(\"x\",0).attr(\"y\",0).attr(\"text-anchor\",r).attr(\"data-unformatted\",t).call(c.convertToTspans,i).call(s.font,e),s.bBox(o.node())}function T(t,e,r,n,a,o){var s=\"_cache\"+e;t[s]&&t[s].key===a||(t[s]={key:a,value:r});var l=i.aggNums(o,null,[t[s].value,n],2);return t[s].value=l,l}e.exports=function(t,e,r,h){var f,p=t._fullLayout;y(r)&&h&&(f=h()),i.makeTraceGroups(p._indicatorlayer,e,\"trace\").each(function(e){var h,A,M,S,E,C=e[0].trace,L=n.select(this),P=C._hasGauge,O=C._isAngular,z=C._isBullet,I=C.domain,D={w:p._size.w*(I.x[1]-I.x[0]),h:p._size.h*(I.y[1]-I.y[0]),l:p._size.l+p._size.w*I.x[0],r:p._size.r+p._size.w*(1-I.x[1]),t:p._size.t+p._size.h*(1-I.y[1]),b:p._size.b+p._size.h*I.y[0]},R=D.l+D.w/2,F=D.t+D.h/2,B=Math.min(D.w/2,D.h),N=l.innerRadius*B,j=C.align||\"center\";if(A=F,P){if(O&&(h=R,A=F+B/2,M=function(t){return e=t,r=.9*N,n=Math.sqrt(e.width/2*(e.width/2)+e.height*e.height),[r/n,e,r];var e,r,n}),z){var U=l.bulletPadding,V=1-l.bulletNumberDomainSize+U;h=D.l+(V+(1-V)*v[j])*D.w,M=function(t){return w(t,(l.bulletNumberDomainSize-U)*D.w,D.h)}}}else h=D.l+v[j]*D.w,M=function(t){return w(t,D.w,D.h)};!function(t,e,r,a){var o,l,h,f=r[0].trace,p=a.numbersX,x=a.numbersY,w=f.align||\"center\",A=g[w],M=a.transitionOpts,S=a.onComplete,E=i.ensureSingle(e,\"g\",\"numbers\"),C=[];f._hasNumber&&C.push(\"number\");f._hasDelta&&(C.push(\"delta\"),\"left\"===f.delta.position&&C.reverse());var L=E.selectAll(\"text\").data(C);function P(e,r,n,i){if(!e.match(\"s\")||n>=0==i>=0||r(n).slice(-1).match(m)||r(i).slice(-1).match(m))return r;var a=e.slice().replace(\"s\",\"f\").replace(/\\d+/,function(t){return parseInt(t)-1}),o=b(t,{tickformat:a});return function(t){return Math.abs(t)<1?u.tickText(o,t).text:r(t)}}L.enter().append(\"text\"),L.attr(\"text-anchor\",function(){return A}).attr(\"class\",function(t){return t}).attr(\"x\",null).attr(\"y\",null).attr(\"dx\",null).attr(\"dy\",null),L.exit().remove();var O,z=f.mode+f.align;f._hasDelta&&(O=function(){var e=b(t,{tickformat:f.delta.valueformat},f._range);e.setScale(),u.calcTicks(e);var i=function(t){return u.tickText(e,t).text},a=function(t){var e=f.delta.relative?t.relativeDelta:t.delta;return e},o=function(t,e){return 0===t||\"number\"!=typeof t||isNaN(t)?\"-\":(t>0?f.delta.increasing.symbol:f.delta.decreasing.symbol)+e(t)},h=function(t){return t.delta>=0?f.delta.increasing.color:f.delta.decreasing.color};void 0===f._deltaLastValue&&(f._deltaLastValue=a(r[0]));var p=E.select(\"text.delta\");function g(){p.text(o(a(r[0]),i)).call(d.fill,h(r[0])).call(c.convertToTspans,t)}p.call(s.font,f.delta.font).call(d.fill,h({delta:f._deltaLastValue})),y(M)?p.transition().duration(M.duration).ease(M.easing).tween(\"text\",function(){var t=n.select(this),e=a(r[0]),s=f._deltaLastValue,l=P(f.delta.valueformat,i,s,e),c=n.interpolateNumber(s,e);return f._deltaLastValue=e,function(e){t.text(o(c(e),l)),t.call(d.fill,h({delta:c(e)}))}}).each(\"end\",function(){g(),S&&S()}).each(\"interrupt\",function(){g(),S&&S()}):g();return l=k(o(a(r[0]),i),f.delta.font,A,t),p}(),z+=f.delta.position+f.delta.font.size+f.delta.font.family+f.delta.valueformat,z+=f.delta.increasing.symbol+f.delta.decreasing.symbol,h=l);f._hasNumber&&(!function(){var e=b(t,{tickformat:f.number.valueformat},f._range);e.setScale(),u.calcTicks(e);var i=function(t){return u.tickText(e,t).text},a=f.number.suffix,l=f.number.prefix,h=E.select(\"text.number\");function p(){var e=\"number\"==typeof r[0].y?l+i(r[0].y)+a:\"-\";h.text(e).call(s.font,f.number.font).call(c.convertToTspans,t)}y(M)?h.transition().duration(M.duration).ease(M.easing).each(\"end\",function(){p(),S&&S()}).each(\"interrupt\",function(){p(),S&&S()}).attrTween(\"text\",function(){var t=n.select(this),e=n.interpolateNumber(r[0].lastY,r[0].y);f._lastValue=r[0].y;var o=P(f.number.valueformat,i,r[0].lastY,r[0].y);return function(r){t.text(l+o(e(r))+a)}}):p();o=k(l+i(r[0].y)+a,f.number.font,A,t)}(),z+=f.number.font.size+f.number.font.family+f.number.valueformat+f.number.suffix+f.number.prefix,h=o);if(f._hasDelta&&f._hasNumber){var I,D,R=[(o.left+o.right)/2,(o.top+o.bottom)/2],F=[(l.left+l.right)/2,(l.top+l.bottom)/2],B=.75*f.delta.font.size;\"left\"===f.delta.position&&(I=T(f,\"deltaPos\",0,-1*(o.width*v[f.align]+l.width*(1-v[f.align])+B),z,Math.min),D=R[1]-F[1],h={width:o.width+l.width+B,height:Math.max(o.height,l.height),left:l.left+I,right:o.right,top:Math.min(o.top,l.top+D),bottom:Math.max(o.bottom,l.bottom+D)}),\"right\"===f.delta.position&&(I=T(f,\"deltaPos\",0,o.width*(1-v[f.align])+l.width*v[f.align]+B,z,Math.max),D=R[1]-F[1],h={width:o.width+l.width+B,height:Math.max(o.height,l.height),left:o.left,right:l.right+I,top:Math.min(o.top,l.top+D),bottom:Math.max(o.bottom,l.bottom+D)}),\"bottom\"===f.delta.position&&(I=null,D=l.height,h={width:Math.max(o.width,l.width),height:o.height+l.height,left:Math.min(o.left,l.left),right:Math.max(o.right,l.right),top:o.bottom-o.height,bottom:o.bottom+l.height}),\"top\"===f.delta.position&&(I=null,D=o.top,h={width:Math.max(o.width,l.width),height:o.height+l.height,left:Math.min(o.left,l.left),right:Math.max(o.right,l.right),top:o.bottom-o.height-l.height,bottom:o.bottom}),O.attr({dx:I,dy:D})}(f._hasNumber||f._hasDelta)&&E.attr(\"transform\",function(){var t=a.numbersScaler(h);z+=t[2];var e,r=T(f,\"numbersScale\",1,t[0],z,Math.min);f._scaleNumbers||(r=1),e=f._isAngular?x-r*h.bottom:x-r*(h.top+h.bottom)/2,f._numbersTop=r*h.top+e;var n=h[w];\"center\"===w&&(n=(h.left+h.right)/2);var i=p-r*n;return _(i=T(f,\"numbersTranslate\",0,i,z,Math.max),e)+\" scale(\"+r+\")\"})}(t,L,e,{numbersX:h,numbersY:A,numbersScaler:M,transitionOpts:r,onComplete:f}),P&&(S={range:C.gauge.axis.range,color:C.gauge.bgcolor,line:{color:C.gauge.bordercolor,width:0},thickness:1},E={range:C.gauge.axis.range,color:\"rgba(0, 0, 0, 0)\",line:{color:C.gauge.bordercolor,width:C.gauge.borderwidth},thickness:1});var q=L.selectAll(\"g.angular\").data(O?e:[]);q.exit().remove();var H=L.selectAll(\"g.angularaxis\").data(O?e:[]);H.exit().remove(),O&&function(t,e,r,i){var s,l,c,h,f=r[0].trace,p=i.size,d=i.radius,g=i.innerRadius,v=i.gaugeBg,m=i.gaugeOutline,w=[p.l+p.w/2,p.t+p.h/2+d/2],k=i.gauge,T=i.layer,A=i.transitionOpts,M=i.onComplete,S=Math.PI/2;function E(t){var e=f.gauge.axis.range[0],r=f.gauge.axis.range[1],n=(t-e)/(r-e)*Math.PI-S;return n<-S?-S:n>S?S:n}function C(t){return n.svg.arc().innerRadius((g+d)/2-t/2*(d-g)).outerRadius((g+d)/2+t/2*(d-g)).startAngle(-S)}function L(t){t.attr(\"d\",function(t){return C(t.thickness).startAngle(E(t.range[0])).endAngle(E(t.range[1]))()})}k.enter().append(\"g\").classed(\"angular\",!0),k.attr(\"transform\",_(w[0],w[1])),T.enter().append(\"g\").classed(\"angularaxis\",!0).classed(\"crisp\",!0),T.selectAll(\"g.xangularaxistick,path,text\").remove(),(s=b(t,f.gauge.axis)).type=\"linear\",s.range=f.gauge.axis.range,s._id=\"xangularaxis\",s.setScale();var P=function(t){return(s.range[0]-t.x)/(s.range[1]-s.range[0])*Math.PI+Math.PI},O={},z=u.makeLabelFns(s,0).labelStandoff;O.xFn=function(t){var e=P(t);return Math.cos(e)*z},O.yFn=function(t){var e=P(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(z+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*o)},O.anchorFn=function(t){var e=P(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},O.heightFn=function(t,e,r){var n=P(t);return-.5*(1+Math.sin(n))*r};var I=function(t){return _(w[0]+d*Math.cos(t),w[1]-d*Math.sin(t))};c=function(t){return I(P(t))};if(l=u.calcTicks(s),h=u.getTickSigns(s)[2],s.visible){h=\"inside\"===s.ticks?-1:1;var D=(s.linewidth||1)/2;u.drawTicks(t,s,{vals:l,layer:T,path:\"M\"+h*D+\",0h\"+h*s.ticklen,transFn:function(t){var e=P(t);return I(e)+\"rotate(\"+-a(e)+\")\"}}),u.drawLabels(t,s,{vals:l,layer:T,transFn:c,labelFns:O})}var R=[v].concat(f.gauge.steps),F=k.selectAll(\"g.bg-arc\").data(R);F.enter().append(\"g\").classed(\"bg-arc\",!0).append(\"path\"),F.select(\"path\").call(L).call(x),F.exit().remove();var B=C(f.gauge.bar.thickness),N=k.selectAll(\"g.value-arc\").data([f.gauge.bar]);N.enter().append(\"g\").classed(\"value-arc\",!0).append(\"path\");var j=N.select(\"path\");y(A)?(j.transition().duration(A.duration).ease(A.easing).each(\"end\",function(){M&&M()}).each(\"interrupt\",function(){M&&M()}).attrTween(\"d\",(U=B,V=E(r[0].lastY),q=E(r[0].y),function(){var t=n.interpolate(V,q);return function(e){return U.endAngle(t(e))()}})),f._lastValue=r[0].y):j.attr(\"d\",\"number\"==typeof r[0].y?B.endAngle(E(r[0].y)):\"M0,0Z\");var U,V,q;j.call(x),N.exit().remove(),R=[];var H=f.gauge.threshold.value;H&&R.push({range:[H,H],color:f.gauge.threshold.color,line:{color:f.gauge.threshold.line.color,width:f.gauge.threshold.line.width},thickness:f.gauge.threshold.thickness});var G=k.selectAll(\"g.threshold-arc\").data(R);G.enter().append(\"g\").classed(\"threshold-arc\",!0).append(\"path\"),G.select(\"path\").call(L).call(x),G.exit().remove();var Y=k.selectAll(\"g.gauge-outline\").data([m]);Y.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"path\"),Y.select(\"path\").call(L).call(x),Y.exit().remove()}(t,0,e,{radius:B,innerRadius:N,gauge:q,layer:H,size:D,gaugeBg:S,gaugeOutline:E,transitionOpts:r,onComplete:f});var G=L.selectAll(\"g.bullet\").data(z?e:[]);G.exit().remove();var Y=L.selectAll(\"g.bulletaxis\").data(z?e:[]);Y.exit().remove(),z&&function(t,e,r,n){var i,a,o,s,c,h=r[0].trace,f=n.gauge,p=n.layer,g=n.gaugeBg,v=n.gaugeOutline,m=n.size,_=h.domain,w=n.transitionOpts,k=n.onComplete;f.enter().append(\"g\").classed(\"bullet\",!0),f.attr(\"transform\",\"translate(\"+m.l+\", \"+m.t+\")\"),p.enter().append(\"g\").classed(\"bulletaxis\",!0).classed(\"crisp\",!0),p.selectAll(\"g.xbulletaxistick,path,text\").remove();var T=m.h,A=h.gauge.bar.thickness*T,M=_.x[0],S=_.x[0]+(_.x[1]-_.x[0])*(h._hasNumber||h._hasDelta?1-l.bulletNumberDomainSize:1);(i=b(t,h.gauge.axis))._id=\"xbulletaxis\",i.domain=[M,S],i.setScale(),a=u.calcTicks(i),o=u.makeTransFn(i),s=u.getTickSigns(i)[2],c=m.t+m.h,i.visible&&(u.drawTicks(t,i,{vals:\"inside\"===i.ticks?u.clipEnds(i,a):a,layer:p,path:u.makeTickPath(i,c,s),transFn:o}),u.drawLabels(t,i,{vals:a,layer:p,transFn:o,labelFns:u.makeLabelFns(i,c)}));function E(t){t.attr(\"width\",function(t){return Math.max(0,i.c2p(t.range[1])-i.c2p(t.range[0]))}).attr(\"x\",function(t){return i.c2p(t.range[0])}).attr(\"y\",function(t){return.5*(1-t.thickness)*T}).attr(\"height\",function(t){return t.thickness*T})}var C=[g].concat(h.gauge.steps),L=f.selectAll(\"g.bg-bullet\").data(C);L.enter().append(\"g\").classed(\"bg-bullet\",!0).append(\"rect\"),L.select(\"rect\").call(E).call(x),L.exit().remove();var P=f.selectAll(\"g.value-bullet\").data([h.gauge.bar]);P.enter().append(\"g\").classed(\"value-bullet\",!0).append(\"rect\"),P.select(\"rect\").attr(\"height\",A).attr(\"y\",(T-A)/2).call(x),y(w)?P.select(\"rect\").transition().duration(w.duration).ease(w.easing).each(\"end\",function(){k&&k()}).each(\"interrupt\",function(){k&&k()}).attr(\"width\",Math.max(0,i.c2p(Math.min(h.gauge.axis.range[1],r[0].y)))):P.select(\"rect\").attr(\"width\",\"number\"==typeof r[0].y?Math.max(0,i.c2p(Math.min(h.gauge.axis.range[1],r[0].y))):0);P.exit().remove();var O=r.filter(function(){return h.gauge.threshold.value}),z=f.selectAll(\"g.threshold-bullet\").data(O);z.enter().append(\"g\").classed(\"threshold-bullet\",!0).append(\"line\"),z.select(\"line\").attr(\"x1\",i.c2p(h.gauge.threshold.value)).attr(\"x2\",i.c2p(h.gauge.threshold.value)).attr(\"y1\",(1-h.gauge.threshold.thickness)/2*T).attr(\"y2\",(1-(1-h.gauge.threshold.thickness)/2)*T).call(d.stroke,h.gauge.threshold.line.color).style(\"stroke-width\",h.gauge.threshold.line.width),z.exit().remove();var I=f.selectAll(\"g.gauge-outline\").data([v]);I.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"rect\"),I.select(\"rect\").call(E).call(x),I.exit().remove()}(t,0,e,{gauge:G,layer:Y,size:D,gaugeBg:S,gaugeOutline:E,transitionOpts:r,onComplete:f});var W=L.selectAll(\"text.title\").data(e);W.exit().remove(),W.enter().append(\"text\").classed(\"title\",!0),W.attr(\"text-anchor\",function(){return z?g.right:g[C.title.align]}).text(C.title.text).call(s.font,C.title.font).call(c.convertToTspans,t),W.attr(\"transform\",function(){var t,e=D.l+D.w*v[C.title.align],r=l.titlePadding,n=s.bBox(W.node());if(P){if(O)if(C.gauge.axis.visible)t=s.bBox(H.node()).top-r-n.bottom;else t=D.t+D.h/2-B/2-n.bottom-r;z&&(t=A-(n.top+n.bottom)/2,e=D.l-l.bulletPadding*D.w)}else t=C._numbersTop-r-n.bottom;return _(e,t)})})}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_defaults\":769,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/cartesian/position_defaults\":782,\"./constants\":1044,d3:163}],1048:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;var c=e.exports=l(s({x:{valType:\"data_array\"},y:{valType:\"data_array\"},z:{valType:\"data_array\"},value:{valType:\"data_array\"},isomin:{valType:\"number\"},isomax:{valType:\"number\"},surface:{show:{valType:\"boolean\",dflt:!0},count:{valType:\"integer\",dflt:2,min:1},fill:{valType:\"number\",min:0,max:1,dflt:1},pattern:{valType:\"flaglist\",flags:[\"A\",\"B\",\"C\",\"D\",\"E\"],extras:[\"all\",\"odd\",\"even\"],dflt:\"all\"}},spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:.15}},slices:{x:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}}},caps:{x:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}}},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:i()},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:a.opacity,lightposition:a.lightposition,lighting:a.lighting,flatshading:a.flatshading,contour:a.contour,hoverinfo:s({},o.hoverinfo)}),\"calc\",\"nested\");c.flatshading.dflt=!0,c.lighting.facenormalsepsilon.dflt=0,c.x.editType=c.y.editType=c.z.editType=c.value.editType=\"calc+clearAxisTypes\",c.transforms=void 0},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../mesh3d/attributes\":1053}],1049:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e._len=Math.min(e.x.length,e.y.length,e.z.length,e.value.length);for(var r=1/0,i=-1/0,a=e.value.length,o=0;o<a;o++){var s=e.value[o];r=Math.min(r,s),i=Math.max(i,s)}e._minValues=r,e._maxValues=i,e._vMin=void 0===e.isomin||null===e.isomin?r:e.isomin,e._vMax=void 0===e.isomax||null===e.isomin?i:e.isomax,n(t,e,{vals:[e._vMin,e._vMax],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],1050:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib\"),a=t(\"../../lib/gl_format_color\").parseColorScale,o=t(\"../../lib/str2rgbarray\"),s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\");function c(t){return i.distinctVals(t).vals}var u=function(t,e){for(var r=e.length-1;r>0;r--){var n=Math.min(e[r],e[r-1]),i=Math.max(e[r],e[r-1]);if(i>n&&n<t&&t<=i)return{id:r,distRatio:(i-t)/(i-n)}}return{id:0,distRatio:0}};function h(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var f=h.prototype;function p(t){t._i=[],t._j=[],t._k=[];var e,r,n=t.surface.show,i=t.spaceframe.show,a=t.surface.fill,o=t.spaceframe.fill,s=!1,l=!1,h=0,f=c(t.x.slice(0,t._len)),p=c(t.y.slice(0,t._len)),d=c(t.z.slice(0,t._len)),g=f.length,v=p.length,m=d.length;function y(t,e,r){return r+m*e+m*v*t}var x,b,_,w,k,T=t._minValues,A=t._maxValues,M=t._vMin,S=t._vMax;function E(t,e,n){for(var i=w.length,a=r;a<i;a++)if(t===x[a]&&e===b[a]&&n===_[a])return a;return-1}function C(){r=e}function L(){x=[],b=[],_=[],w=[],e=0,C()}function P(t,r,n,i){return x.push(t),b.push(r),_.push(n),w.push(i),++e-1}function O(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=t[i]*(1-r)+r*e[i];return n}function z(t){k=t}function I(t,e){return\"all\"===t||null===t||t.indexOf(e)>-1}function D(t,e){return null===t?e:t}function R(e,r,n){C();var i,a,o,s=[r],l=[n];if(k>=1)s=[r],l=[n];else if(k>0){var c=function(t,e){var r=t[0],n=t[1],i=t[2],a=function(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=(t[i]+e[i]+r[i])/3;return n}(r,n,i),o=Math.sqrt(1-k),s=O(a,r,o),l=O(a,n,o),c=O(a,i,o),u=e[0],h=e[1],f=e[2];return{xyzv:[[r,n,l],[l,s,r],[n,i,c],[c,l,n],[i,r,s],[s,c,i]],abc:[[u,h,-1],[-1,-1,u],[h,f,-1],[-1,-1,h],[f,u,-1],[-1,-1,f]]}}(r,n);s=c.xyzv,l=c.abc}for(var u=0;u<s.length;u++){r=s[u],n=l[u];for(var f=[],p=0;p<3;p++){var d=r[p][0],g=r[p][1],v=r[p][2],m=r[p][3],y=n[p]>-1?n[p]:E(d,g,v);f[p]=y>-1?y:P(d,g,v,D(e,m))}i=f[0],a=f[1],o=f[2],t._i.push(i),t._j.push(a),t._k.push(o),++h}}function F(t,e,r,n){var i=t[3];i<r&&(i=r),i>n&&(i=n);for(var a=(t[3]-i)/(t[3]-e[3]+1e-9),o=[],s=0;s<4;s++)o[s]=(1-a)*t[s]+a*e[s];return o}function B(t,e,r){return t>=e&&t<=r}function N(t){var e=.001*(S-M);return t>=M-e&&t<=S+e}function j(e){for(var r=[],n=0;n<4;n++){var i=e[n];r.push([t.x[i],t.y[i],t.z[i],t.value[i]])}return r}var U=3;function V(t,e,r,n,i,a){a||(a=1),r=[-1,-1,-1];var o=!1,s=[B(e[0][3],n,i),B(e[1][3],n,i),B(e[2][3],n,i)];if(!s[0]&&!s[1]&&!s[2])return!1;var l=function(t,e,r){return N(e[0][3])&&N(e[1][3])&&N(e[2][3])?(R(t,e,r),!0):a<U&&V(t,e,r,M,S,++a)};if(s[0]&&s[1]&&s[2])return l(t,e,r)||o;var c=!1;return[[0,1,2],[2,0,1],[1,2,0]].forEach(function(a){if(s[a[0]]&&s[a[1]]&&!s[a[2]]){var u=e[a[0]],h=e[a[1]],f=e[a[2]],p=F(f,u,n,i),d=F(f,h,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,o=l(t,[u,h,d],[r[a[0]],r[a[1]],-1])||o,c=!0}}),c?o:([[0,1,2],[1,2,0],[2,0,1]].forEach(function(a){if(s[a[0]]&&!s[a[1]]&&!s[a[2]]){var u=e[a[0]],h=e[a[1]],f=e[a[2]],p=F(h,u,n,i),d=F(f,u,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,c=!0}}),o)}function q(t,e,r,n){var i=!1,a=j(e),o=[B(a[0][3],r,n),B(a[1][3],r,n),B(a[2][3],r,n),B(a[3][3],r,n)];if(!(o[0]||o[1]||o[2]||o[3]))return i;if(o[0]&&o[1]&&o[2]&&o[3])return l&&(i=function(t,e,r){var n=function(n,i,a){R(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(3,0,1),n(2,3,0),n(1,2,3)}(t,a,e)||i),i;var s=!1;return[[0,1,2,3],[3,0,1,2],[2,3,0,1],[1,2,3,0]].forEach(function(c){if(o[c[0]]&&o[c[1]]&&o[c[2]]&&!o[c[3]]){var u=a[c[0]],h=a[c[1]],f=a[c[2]],p=a[c[3]];if(l)i=R(t,[u,h,f],[e[c[0]],e[c[1]],e[c[2]]])||i;else{var d=F(p,u,r,n),g=F(p,h,r,n),v=F(p,f,r,n);i=R(null,[d,g,v],[-1,-1,-1])||i}s=!0}}),s?i:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2],[0,2,3,1],[1,3,2,0]].forEach(function(c){if(o[c[0]]&&o[c[1]]&&!o[c[2]]&&!o[c[3]]){var u=a[c[0]],h=a[c[1]],f=a[c[2]],p=a[c[3]],d=F(f,u,r,n),g=F(f,h,r,n),v=F(p,h,r,n),m=F(p,u,r,n);l?(i=R(t,[u,m,d],[e[c[0]],-1,-1])||i,i=R(t,[h,g,v],[e[c[1]],-1,-1])||i):i=function(t,e,r){var n=function(n,i,a){R(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(2,3,0)}(null,[d,g,v,m],[-1,-1,-1,-1])||i,s=!0}}),s?i:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2]].forEach(function(c){if(o[c[0]]&&!o[c[1]]&&!o[c[2]]&&!o[c[3]]){var u=a[c[0]],h=a[c[1]],f=a[c[2]],p=a[c[3]],d=F(h,u,r,n),g=F(f,u,r,n),v=F(p,u,r,n);l?(i=R(t,[u,d,g],[e[c[0]],-1,-1])||i,i=R(t,[u,g,v],[e[c[0]],-1,-1])||i,i=R(t,[u,v,d],[e[c[0]],-1,-1])||i):i=R(null,[d,g,v],[-1,-1,-1])||i,s=!0}}),i))}function H(t,e,r,n,i,a,o,c,u,h,f){var p=!1;return s&&(I(t,\"A\")&&(p=q(null,[e,r,n,a],h,f)||p),I(t,\"B\")&&(p=q(null,[r,n,i,u],h,f)||p),I(t,\"C\")&&(p=q(null,[r,a,o,u],h,f)||p),I(t,\"D\")&&(p=q(null,[n,a,c,u],h,f)||p),I(t,\"E\")&&(p=q(null,[r,n,a,u],h,f)||p)),l&&(p=q(t,[r,n,a,u],h,f)||p),p}function G(t,e,r,n,i,a,o,s){return[!0===s[0]||V(t,j([e,r,n]),[e,r,n],a,o),!0===s[1]||V(t,j([n,i,e]),[n,i,e],a,o)]}function Y(t,e,r,n,i,a,o,s,l){return s?G(t,e,r,i,n,a,o,l):G(t,r,i,n,e,a,o,l)}function W(t,e,r,n,i,a,o){var s,l,c,u,h=!1,f=function(){h=V(t,[s,l,c],[-1,-1,-1],i,a)||h,h=V(t,[c,u,s],[-1,-1,-1],i,a)||h},p=o[0],d=o[1],g=o[2];return p&&(s=O(j([y(e,r-0,n-0)])[0],j([y(e-1,r-0,n-0)])[0],p),l=O(j([y(e,r-0,n-1)])[0],j([y(e-1,r-0,n-1)])[0],p),c=O(j([y(e,r-1,n-1)])[0],j([y(e-1,r-1,n-1)])[0],p),u=O(j([y(e,r-1,n-0)])[0],j([y(e-1,r-1,n-0)])[0],p),f()),d&&(s=O(j([y(e-0,r,n-0)])[0],j([y(e-0,r-1,n-0)])[0],d),l=O(j([y(e-0,r,n-1)])[0],j([y(e-0,r-1,n-1)])[0],d),c=O(j([y(e-1,r,n-1)])[0],j([y(e-1,r-1,n-1)])[0],d),u=O(j([y(e-1,r,n-0)])[0],j([y(e-1,r-1,n-0)])[0],d),f()),g&&(s=O(j([y(e-0,r-0,n)])[0],j([y(e-0,r-0,n-1)])[0],g),l=O(j([y(e-0,r-1,n)])[0],j([y(e-0,r-1,n-1)])[0],g),c=O(j([y(e-1,r-1,n)])[0],j([y(e-1,r-1,n-1)])[0],g),u=O(j([y(e-1,r-0,n)])[0],j([y(e-1,r-0,n-1)])[0],g),f()),h}function X(t,e,r,n,i,a,o,l,c,u,h,f){var p=t;return f?(s&&\"even\"===t&&(p=null),H(p,e,r,n,i,a,o,l,c,u,h)):(s&&\"odd\"===t&&(p=null),H(p,c,l,o,a,i,n,r,e,u,h))}function Z(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<m;c++)for(var u=1;u<v;u++)a.push(Y(t,y(l,u-1,c-1),y(l,u-1,c),y(l,u,c-1),y(l,u,c),r,n,(l+u+c)%2,i&&i[o]?i[o]:[])),o++;return a}function J(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<g;c++)for(var u=1;u<m;u++)a.push(Y(t,y(c-1,l,u-1),y(c,l,u-1),y(c-1,l,u),y(c,l,u),r,n,(c+l+u)%2,i&&i[o]?i[o]:[])),o++;return a}function K(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<v;c++)for(var u=1;u<g;u++)a.push(Y(t,y(u-1,c-1,l),y(u-1,c,l),y(u,c-1,l),y(u,c,l),r,n,(u+c+l)%2,i&&i[o]?i[o]:[])),o++;return a}function $(t,e,r){for(var n=1;n<m;n++)for(var i=1;i<v;i++)for(var a=1;a<g;a++)X(t,y(a-1,i-1,n-1),y(a-1,i-1,n),y(a-1,i,n-1),y(a-1,i,n),y(a,i-1,n-1),y(a,i-1,n),y(a,i,n-1),y(a,i,n),e,r,(a+i+n)%2)}function Q(t,e,r){s=!0,$(t,e,r),s=!1}function tt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<m;u++)for(var h=1;h<v;h++)o.push(W(t,c,h,u,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function et(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<g;u++)for(var h=1;h<m;h++)o.push(W(t,u,c,h,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function rt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<v;u++)for(var h=1;h<g;h++)o.push(W(t,h,u,c,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function nt(t,e){for(var r=[],n=t;n<e;n++)r.push(n);return r}return function(){if(L(),function(){for(var e=0;e<g;e++)for(var r=0;r<v;r++)for(var n=0;n<m;n++){var i=y(e,r,n);P(t.x[i],t.y[i],t.z[i],t.value[i])}}(),i&&o&&(z(o),l=!0,$(null,M,S),l=!1),n&&a){z(a);for(var e=t.surface.pattern,r=t.surface.count,s=0;s<r;s++){var c=1===r?.5:s/(r-1),k=(1-c)*M+c*S,E=Math.abs(k-T)>Math.abs(k-A)?[T,k]:[k,A];Q(e,E[0],E[1])}}var C=[[Math.min(M,A),Math.max(M,A)],[Math.min(T,S),Math.max(T,S)]];[\"x\",\"y\",\"z\"].forEach(function(e){for(var r=[],n=0;n<C.length;n++){var i=0,a=C[n][0],o=C[n][1],s=t.slices[e];if(s.show&&s.fill){z(s.fill);var l=[],c=[],h=[];if(s.locations.length)for(var y=0;y<s.locations.length;y++){var x=u(s.locations[y],\"x\"===e?f:\"y\"===e?p:d);0===x.distRatio?l.push(x.id):x.id>0&&(c.push(x.id),\"x\"===e?h.push([x.distRatio,0,0]):\"y\"===e?h.push([0,x.distRatio,0]):h.push([0,0,x.distRatio]))}else l=nt(1,\"x\"===e?g-1:\"y\"===e?v-1:m-1);c.length>0&&(r[i]=\"x\"===e?tt(null,c,a,o,h,r[i]):\"y\"===e?et(null,c,a,o,h,r[i]):rt(null,c,a,o,h,r[i]),i++),l.length>0&&(r[i]=\"x\"===e?Z(null,l,a,o,r[i]):\"y\"===e?J(null,l,a,o,r[i]):K(null,l,a,o,r[i]),i++)}var b=t.caps[e];b.show&&b.fill&&(z(b.fill),r[i]=\"x\"===e?Z(null,[0,g-1],a,o,r[i]):\"y\"===e?J(null,[0,v-1],a,o,r[i]):K(null,[0,m-1],a,o,r[i]),i++)}}),0===h&&L(),t._x=x,t._y=b,t._z=_,t._intensity=w,t._Xs=f,t._Ys=p,t._Zs=d}(),t}f.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._x[e],n=this.data._y[e],i=this.data._z[e],a=this.data._Ys.length,o=this.data._Zs.length,s=u(r,this.data._Xs).id,l=u(n,this.data._Ys).id,c=u(i,this.data._Zs).id,h=t.index=c+o*l+o*a*s;t.traceCoordinate=[this.data._x[h],this.data._y[h],this.data._z[h],this.data.value[h]];var f=this.data.hovertext||this.data.text;return Array.isArray(f)&&void 0!==f[h]?t.textLabel=f[h]:f&&(t.textLabel=f),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map(function(e){return t.d2l(e,0,n)*r})}this.data=p(t);var i={positions:l(n(r.xaxis,t._x,e.dataScale[0],t.xcalendar),n(r.yaxis,t._y,e.dataScale[1],t.ycalendar),n(r.zaxis,t._z,e.dataScale[2],t.zcalendar)),cells:l(t._i,t._j,t._k),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:o(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},c=s(t);i.vertexIntensity=t._intensity,i.vertexIntensityBounds=[c.min,c.max],i.colormap=a(t),this.mesh.update(i)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports={findNearestOnAxis:u,generateIsoMeshes:p,createIsosurfaceTrace:function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new h(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../../plots/gl3d/zip3\":818,\"gl-mesh3d\":280}],1051:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"../../components/colorscale/defaults\");function s(t,e,r,n,a){var s=a(\"isomin\"),l=a(\"isomax\");null!=l&&null!=s&&s>l&&(e.isomin=null,e.isomax=null);var c=a(\"x\"),u=a(\"y\"),h=a(\"z\"),f=a(\"value\");c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length?(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],n),[\"x\",\"y\",\"z\"].forEach(function(t){var e=\"caps.\"+t;a(e+\".show\")&&a(e+\".fill\");var r=\"slices.\"+t;a(r+\".show\")&&(a(r+\".fill\"),a(r+\".locations\"))}),a(\"spaceframe.show\")&&a(\"spaceframe.fill\"),a(\"surface.show\")&&(a(\"surface.count\"),a(\"surface.fill\"),a(\"surface.pattern\")),a(\"contour.show\")&&(a(\"contour.color\"),a(\"contour.width\")),[\"text\",\"hovertext\",\"hovertemplate\",\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"flatshading\",\"opacity\"].forEach(function(t){a(t)}),o(t,e,n,a,{prefix:\"\",cLetter:\"c\"}),e._length=null):e.visible=!1}e.exports={supplyDefaults:function(t,e,r,i){s(t,e,0,i,function(r,i){return n.coerce(t,e,a,r,i)})},supplyIsoDefaults:s}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../../registry\":847,\"./attributes\":1048}],1052:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\").createIsosurfaceTrace,moduleType:\"trace\",name:\"isosurface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1048,\"./calc\":1049,\"./convert\":1050,\"./defaults\":1051}],1053:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../surface/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},i:{valType:\"data_array\",editType:\"calc\"},j:{valType:\"data_array\",editType:\"calc\"},k:{valType:\"data_array\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:i({editType:\"calc\"}),delaunayaxis:{valType:\"enumerated\",values:[\"x\",\"y\",\"z\"],dflt:\"z\",editType:\"calc\"},alphahull:{valType:\"number\",dflt:-1,editType:\"calc\"},intensity:{valType:\"data_array\",editType:\"calc\"},color:{valType:\"color\",editType:\"calc\"},vertexcolor:{valType:\"data_array\",editType:\"calc\"},facecolor:{valType:\"data_array\",editType:\"calc\"},transforms:void 0},n(\"\",{colorAttr:\"`intensity`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:a.opacity,flatshading:{valType:\"boolean\",dflt:!1,editType:\"calc\"},contour:{show:s({},a.contours.x.show,{}),color:a.contours.x.color,width:a.contours.x.width,editType:\"calc\"},lightposition:{x:s({},a.lightposition.x,{dflt:1e5}),y:s({},a.lightposition.y,{dflt:1e5}),z:s({},a.lightposition.z,{dflt:0}),editType:\"calc\"},lighting:s({vertexnormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-12,editType:\"calc\"},facenormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-6,editType:\"calc\"},editType:\"calc\"},a.lighting),hoverinfo:s({},o.hoverinfo,{editType:\"calc\"})})},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../surface/attributes\":1224}],1054:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.intensity&&n(t,e,{vals:e.intensity,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],1055:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"delaunay-triangulate\"),a=t(\"alpha-shape\"),o=t(\"convex-hull\"),s=t(\"../../lib/gl_format_color\").parseColorScale,l=t(\"../../lib/str2rgbarray\"),c=t(\"../../components/colorscale\").extractOpts,u=t(\"../../plots/gl3d/zip3\");function h(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.color=\"#fff\",this.data=null,this.showContour=!1}var f=h.prototype;function p(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=l(t[n]);return e}function d(t,e,r,n){for(var i=[],a=e.length,o=0;o<a;o++)i[o]=t.d2l(e[o],0,n)*r;return i}function g(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=Math.round(t[n]);return e}function v(t,e){for(var r=t.length,n=0;n<r;n++)if(t[n]<=-.5||t[n]>=e-.5)return!1;return!0}f.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index;t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]];var r=this.data.hovertext||this.data.text;return Array.isArray(r)&&void 0!==r[e]?t.textLabel=r[e]:r&&(t.textLabel=r),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;this.data=t;var n,h=t.x.length,f=u(d(r.xaxis,t.x,e.dataScale[0],t.xcalendar),d(r.yaxis,t.y,e.dataScale[1],t.ycalendar),d(r.zaxis,t.z,e.dataScale[2],t.zcalendar));if(t.i&&t.j&&t.k){if(t.i.length!==t.j.length||t.j.length!==t.k.length||!v(t.i,h)||!v(t.j,h)||!v(t.k,h))return;n=u(g(t.i),g(t.j),g(t.k))}else n=0===t.alphahull?o(f):t.alphahull>0?a(t.alphahull,f):function(t,e){for(var r=[\"x\",\"y\",\"z\"].indexOf(t),n=[],a=e.length,o=0;o<a;o++)n[o]=[e[o][(r+1)%3],e[o][(r+2)%3]];return i(n)}(t.delaunayaxis,f);var m={positions:f,cells:n,lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:l(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading};if(t.intensity){var y=c(t);this.color=\"#fff\",m.vertexIntensity=t.intensity,m.vertexIntensityBounds=[y.min,y.max],m.colormap=s(t)}else t.vertexcolor?(this.color=t.vertexcolor[0],m.vertexColors=p(t.vertexcolor)):t.facecolor?(this.color=t.facecolor[0],m.cellColors=p(t.facecolor)):(this.color=t.color,m.meshColor=l(t.color));this.mesh.update(m)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new h(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":605,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../../plots/gl3d/zip3\":818,\"alpha-shape\":64,\"convex-hull\":130,\"delaunay-triangulate\":165,\"gl-mesh3d\":280}],1056:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,n){return i.coerce(t,e,o,r,n)}function c(t){var e=t.map(function(t){var e=l(t);return e&&i.isArrayOrTypedArray(e)?e:null});return e.every(function(t){return t&&t.length===e[0].length})&&e}c([\"x\",\"y\",\"z\"])?(c([\"i\",\"j\",\"k\"]),(!e.i||e.j&&e.k)&&(!e.j||e.k&&e.i)&&(!e.k||e.i&&e.j)?(n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],s),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"contour.show\",\"contour.color\",\"contour.width\",\"colorscale\",\"reversescale\",\"flatshading\",\"alphahull\",\"delaunayaxis\",\"opacity\"].forEach(function(t){l(t)}),\"intensity\"in t?(l(\"intensity\"),a(t,e,s,l,{prefix:\"\",cLetter:\"c\"})):(e.showscale=!1,\"facecolor\"in t?l(\"facecolor\"):\"vertexcolor\"in t?l(\"vertexcolor\"):l(\"color\",r)),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),e._length=null):e.visible=!1):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../../registry\":847,\"./attributes\":1053}],1057:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"mesh3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1053,\"./calc\":1054,\"./convert\":1055,\"./defaults\":1056}],1058:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../scatter/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../components/fx/attributes\"),s=t(\"../../constants/delta.js\"),l=s.INCREASING.COLOR,c=s.DECREASING.COLOR,u=i.line;function h(t){return{line:{color:n({},u.color,{dflt:t}),width:u.width,dash:a,editType:\"style\"},editType:\"style\"}}e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},open:{valType:\"data_array\",editType:\"calc\"},high:{valType:\"data_array\",editType:\"calc\"},low:{valType:\"data_array\",editType:\"calc\"},close:{valType:\"data_array\",editType:\"calc\"},line:{width:n({},u.width,{}),dash:n({},a,{}),editType:\"style\"},increasing:h(l),decreasing:h(c),text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},tickwidth:{valType:\"number\",min:0,max:.5,dflt:.3,editType:\"calc\"},hoverlabel:n({},o.hoverlabel,{split:{valType:\"boolean\",dflt:!1,editType:\"style\"}})}},{\"../../components/drawing/attributes\":613,\"../../components/fx/attributes\":623,\"../../constants/delta.js\":689,\"../../lib\":719,\"../scatter/attributes\":1112}],1059:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=n._,a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/numerical\").BADNUM;function s(t,e,r,n){return{o:t,h:e,l:r,c:n}}function l(t,e,r,s,l){for(var c=s.makeCalcdata(e,\"open\"),u=s.makeCalcdata(e,\"high\"),h=s.makeCalcdata(e,\"low\"),f=s.makeCalcdata(e,\"close\"),p=Array.isArray(e.text),d=Array.isArray(e.hovertext),g=!0,v=null,m=[],y=0;y<r.length;y++){var x=r[y],b=c[y],_=u[y],w=h[y],k=f[y];if(x!==o&&b!==o&&_!==o&&w!==o&&k!==o){k===b?null!==v&&k!==v&&(g=k>v):g=k>b,v=k;var T=l(b,_,w,k);T.pos=x,T.yc=(b+k)/2,T.i=y,T.dir=g?\"increasing\":\"decreasing\",T.x=T.pos,T.y=[w,_],p&&(T.tx=e.text[y]),d&&(T.htx=e.hovertext[y]),m.push(T)}else m.push({pos:x,empty:!0})}return e._extremes[s._id]=a.findExtremes(s,n.concat(h,u),{padded:!0}),m.length&&(m[0].t={labels:{open:i(t,\"open:\")+\" \",high:i(t,\"high:\")+\" \",low:i(t,\"low:\")+\" \",close:i(t,\"close:\")+\" \"}}),m}e.exports={calc:function(t,e){var r=a.getFromId(t,e.xaxis),i=a.getFromId(t,e.yaxis),o=function(t,e,r){var i=r._minDiff;if(!i){var a,o=t._fullData,s=[];for(i=1/0,a=0;a<o.length;a++){var l=o[a];if(\"ohlc\"===l.type&&!0===l.visible&&l.xaxis===e._id){s.push(l);var c=e.makeCalcdata(l,\"x\");l._xcalc=c;var u=n.distinctVals(c).minDiff;u&&isFinite(u)&&(i=Math.min(i,u))}}for(i===1/0&&(i=1),a=0;a<s.length;a++)s[a]._minDiff=i}return i*r.tickwidth}(t,r,e),c=e._minDiff;e._minDiff=null;var u=e._xcalc;e._xcalc=null;var h=l(t,e,u,i,s);return e._extremes[r._id]=a.findExtremes(r,u,{vpad:c/2}),h.length?(n.extendFlat(h[0].t,{wHover:c/2,tickLen:o}),h):[{t:{empty:!0}}]},calcCommon:l}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],1060:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./ohlc_defaults\"),a=t(\"./attributes\");function o(t,e,r,n){r(n+\".line.color\"),r(n+\".line.width\",e.line.width),r(n+\".line.dash\",e.line.dash)}e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,a,r,i)}i(t,e,l,s)?(l(\"line.width\"),l(\"line.dash\"),o(t,e,l,\"increasing\"),o(t,e,l,\"decreasing\"),l(\"text\"),l(\"hovertext\"),l(\"tickwidth\"),s._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../lib\":719,\"./attributes\":1058,\"./ohlc_defaults\":1063}],1061:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\").fillText,l=t(\"../../constants/delta.js\"),c={increasing:l.INCREASING.SYMBOL,decreasing:l.DECREASING.SYMBOL};function u(t,e,r,n){var i,s,l=t.cd,c=t.xa,u=l[0].trace,h=l[0].t,f=u.type,p=\"ohlc\"===f?\"l\":\"min\",d=\"ohlc\"===f?\"h\":\"max\",g=h.bPos||0,v=function(t){return t.pos+g-e},m=h.bdPos||h.tickLen,y=h.wHover,x=Math.min(1,m/Math.abs(c.r2c(c.range[1])-c.r2c(c.range[0])));function b(t){var e=v(t);return a.inbox(e-y,e+y,i)}function _(t){var e=t[p],n=t[d];return e===n||a.inbox(e-r,n-r,i)}function w(t){return(b(t)+_(t))/2}i=t.maxHoverDistance-x,s=t.maxSpikeDistance-x;var k=a.getDistanceFunction(n,b,_,w);if(a.getClosest(l,k,t),!1===t.index)return null;var T=l[t.index];if(T.empty)return null;var A=u[T.dir],M=A.line.color;return o.opacity(M)&&A.line.width?t.color=M:t.color=A.fillcolor,t.x0=c.c2p(T.pos+g-m,!0),t.x1=c.c2p(T.pos+g+m,!0),t.xLabelVal=T.pos,t.spikeDistance=w(T)*s/i,t.xSpike=c.c2p(T.pos,!0),t}function h(t,e,r,a){var o=t.cd,s=t.ya,l=o[0].trace,c=o[0].t,h=[],f=u(t,e,r,a);if(!f)return[];var p=o[f.index].hi||l.hoverinfo,d=p.split(\"+\");if(!(\"all\"===p||-1!==d.indexOf(\"y\")))return[];for(var g=[\"high\",\"open\",\"close\",\"low\"],v={},m=0;m<g.length;m++){var y,x=g[m],b=l[x][f.index],_=s.c2p(b,!0);b in v?(y=v[b]).yLabel+=\"<br>\"+c.labels[x]+n.hoverLabelText(s,b):((y=i.extendFlat({},f)).y0=y.y1=_,y.yLabelVal=b,y.yLabel=c.labels[x]+n.hoverLabelText(s,b),y.name=\"\",h.push(y),v[b]=y)}return h}function f(t,e,r,i){var a=t.cd,o=t.ya,l=a[0].trace,h=a[0].t,f=u(t,e,r,i);if(!f)return[];var p=a[f.index],d=f.index=p.i,g=p.dir;function v(t){return h.labels[t]+n.hoverLabelText(o,l[t][d])}var m=p.hi||l.hoverinfo,y=m.split(\"+\"),x=\"all\"===m,b=x||-1!==y.indexOf(\"y\"),_=x||-1!==y.indexOf(\"text\"),w=b?[v(\"open\"),v(\"high\"),v(\"low\"),v(\"close\")+\"  \"+c[g]]:[];return _&&s(p,l,w),f.extraText=w.join(\"<br>\"),f.y0=f.y1=o.c2p(p.yc,!0),[f]}e.exports={hoverPoints:function(t,e,r,n){return t.cd[0].trace.hoverlabel.split?h(t,e,r,n):f(t,e,r,n)},hoverSplit:h,hoverOnPoints:f}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../constants/delta.js\":689,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],1062:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"ohlc\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\"],meta:{},attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\").calc,plot:t(\"./plot\"),style:t(\"./style\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\")}},{\"../../plots/cartesian\":778,\"./attributes\":1058,\"./calc\":1059,\"./defaults\":1060,\"./hover\":1061,\"./plot\":1064,\"./select\":1065,\"./style\":1066}],1063:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"open\"),l=r(\"high\"),c=r(\"low\"),u=r(\"close\");if(r(\"hoverlabel.split\"),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\"],a),s&&l&&c&&u){var h=Math.min(s.length,l.length,c.length,u.length);return o&&(h=Math.min(h,i.minRowLength(o))),e._length=h,h}}},{\"../../lib\":719,\"../../registry\":847}],1064:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=e.xaxis,s=e.yaxis;i.makeTraceGroups(a,r,\"trace ohlc\").each(function(t){var e=n.select(this),r=t[0],a=r.t;if(!0!==r.trace.visible||a.empty)e.remove();else{var l=a.tickLen,c=e.selectAll(\"path\").data(i.identity);c.enter().append(\"path\"),c.exit().remove(),c.attr(\"d\",function(t){if(t.empty)return\"M0,0Z\";var e=o.c2p(t.pos,!0),r=o.c2p(t.pos-l,!0),n=o.c2p(t.pos+l,!0);return\"M\"+r+\",\"+s.c2p(t.o,!0)+\"H\"+e+\"M\"+e+\",\"+s.c2p(t.h,!0)+\"V\"+s.c2p(t.l,!0)+\"M\"+n+\",\"+s.c2p(t.c,!0)+\"H\"+e})}})}},{\"../../lib\":719,d3:163}],1065:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n=t.cd,i=t.xaxis,a=t.yaxis,o=[],s=n[0].t.bPos||0;if(!1===e)for(r=0;r<n.length;r++)n[r].selected=0;else for(r=0;r<n.length;r++){var l=n[r];e.contains([i.c2p(l.pos+s),a.c2p(l.yc)],null,l.i,t)?(o.push({pointNumber:l.i,x:i.c2d(l.pos),y:a.c2d(l.yc)}),l.selected=1):l.selected=0}return o}},{}],1066:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\");e.exports=function(t,e,r){var o=r||n.select(t).selectAll(\"g.ohlclayer\").selectAll(\"g.trace\");o.style(\"opacity\",function(t){return t[0].trace.opacity}),o.each(function(t){var e=t[0].trace;n.select(this).selectAll(\"path\").each(function(t){if(!t.empty){var r=e[t.dir].line;n.select(this).style(\"fill\",\"none\").call(a.stroke,r.color).call(i.dashLine,r.dash,r.width).style(\"opacity\",e.selectedpoints&&!t.selected?.3:1)}})})}},{\"../../components/color\":593,\"../../components/drawing\":614,d3:163}],1067:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../plots/attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/fx/hovertemplate_attributes\"),l=t(\"../../plots/domain\").attributes,c=n({editType:\"calc\"},o(\"line\",{editTypeOverride:\"calc\"}),{shape:{valType:\"enumerated\",values:[\"linear\",\"hspline\"],dflt:\"linear\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\"]})});e.exports={domain:l({name:\"parcats\",trace:!0,editType:\"calc\"}),hoverinfo:n({},i.hoverinfo,{flags:[\"count\",\"probability\"],editType:\"plot\",arrayOk:!1}),hoveron:{valType:\"enumerated\",values:[\"category\",\"color\",\"dimension\"],dflt:\"category\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\",\"category\",\"categorycount\",\"colorcount\",\"bandcolorcount\"]}),arrangement:{valType:\"enumerated\",values:[\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"perpendicular\",editType:\"plot\"},bundlecolors:{valType:\"boolean\",dflt:!0,editType:\"plot\"},sortpaths:{valType:\"enumerated\",values:[\"forward\",\"backward\"],dflt:\"forward\",editType:\"plot\"},labelfont:a({editType:\"calc\"}),tickfont:a({editType:\"calc\"}),dimensions:{_isLinkedToArray:\"dimension\",label:{valType:\"string\",editType:\"calc\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",dflt:[],editType:\"calc\"},displayindex:{valType:\"integer\",editType:\"calc\"},editType:\"calc\",visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"}},line:c,counts:{valType:\"number\",min:0,dflt:1,arrayOk:!0,editType:\"calc\"},customdata:void 0,hoverlabel:void 0,ids:void 0,legendgroup:void 0,opacity:void 0,selectedpoints:void 0,showlegend:void 0}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1068:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"parcats\",r.plot=function(t,e,r,a){var o=n(t.calcdata,\"parcats\");if(o.length){var s=o[0];i(t,s,r,a)}},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcats\"),a=e._has&&e._has(\"parcats\");i&&!a&&n._paperdiv.selectAll(\".parcats\").remove()}},{\"../../plots/get_data\":802,\"./plot\":1073}],1069:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),o=t(\"../../lib/filter_unique.js\"),s=t(\"../../components/drawing\"),l=t(\"../../lib\");function c(t,e,r){t.valueInds.push(e),t.count+=r}function u(t,e,r){t.valueInds.push(e),t.count+=r}e.exports=function(t,e){var r=l.filterVisible(e.dimensions);if(0===r.length)return[];var h,f,p,d=r.map(function(t){var e;return\"trace\"===t.categoryorder?e=null:\"array\"===t.categoryorder?e=t.categoryarray:(e=o(t.values).sort(),\"category descending\"===t.categoryorder&&(e=e.reverse())),function(t,e){e=null==e?[]:e.map(function(t){return t});var r={},n={},i=[];e.forEach(function(t,e){r[t]=0,n[t]=e});for(var a=0;a<t.length;a++){var o,s=t[a];void 0===r[s]?(r[s]=1,o=e.push(s)-1,n[s]=o):(r[s]++,o=n[s]),i.push(o)}var l=e.map(function(t){return r[t]});return{uniqueValues:e,uniqueCounts:l,inds:i}}(t.values,e)});h=l.isArrayOrTypedArray(e.counts)?e.counts:[e.counts],function(t){var e;if(function(t){for(var e=new Array(t.length),r=0;r<t.length;r++){if(t[r]<0||t[r]>=t.length)return!1;if(void 0!==e[t[r]])return!1;e[t[r]]=!0}return!0}(t.map(function(t){return t.displayindex})))for(e=0;e<t.length;e++)t[e]._displayindex=t[e].displayindex;else for(e=0;e<t.length;e++)t[e]._displayindex=e}(r),r.forEach(function(t,e){!function(t,e){t._categoryarray=e.uniqueValues,null===t.ticktext||void 0===t.ticktext?t._ticktext=[]:t._ticktext=t.ticktext.slice();for(var r=t._ticktext.length;r<e.uniqueValues.length;r++)t._ticktext.push(e.uniqueValues[r])}(t,d[e])});var g,v=e.line;v?(i(e,\"line\")&&a(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),g=s.tryColorscale(v)):g=l.identity;var m,y,x,b,_=r[0].values.length,w={},k=d.map(function(t){return t.inds});for(p=0,m=0;m<_;m++){var T=[];for(y=0;y<k.length;y++)T.push(k[y][m]);f=h[m%h.length],p+=f;var A=(x=m,b=void 0,b=l.isArrayOrTypedArray(v.color)?v.color[x%v.color.length]:v.color,{color:g(b),rawColor:b}),M=T+\"-\"+A.rawColor;void 0===w[M]&&(w[M]={categoryInds:T,color:A.color,rawColor:A.rawColor,valueInds:[],count:0}),u(w[M],m,f)}var S,E=r.map(function(t,e){return r=e,n=t._index,i=t._displayindex,a=t.label,{dimensionInd:r,containerInd:n,displayInd:i,dimensionLabel:a,count:p,categories:[],dragX:null};var r,n,i,a});for(m=0;m<_;m++)for(f=h[m%h.length],y=0;y<E.length;y++){var C=E[y].containerInd,L=d[y].inds[m],P=E[y].categories;if(void 0===P[L]){var O=e.dimensions[C]._categoryarray[L],z=e.dimensions[C]._ticktext[L];P[L]={dimensionInd:y,categoryInd:S=L,categoryValue:O,displayInd:S,categoryLabel:z,valueInds:[],count:0,dragY:null}}c(P[L],m,f)}return n(function(t,e,r){var n=t.map(function(t){return t.categories.length}).reduce(function(t,e){return Math.max(t,e)});return{dimensions:t,paths:e,trace:void 0,maxCats:n,count:r}}(E,w,p))}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/filter_unique.js\":711,\"../../lib/gup\":717}],1070:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"./attributes\"),c=t(\"../parcoords/merge_length\");function u(t,e){function r(r,i){return n.coerce(t,e,l.dimensions,r,i)}var i=r(\"values\"),a=r(\"visible\");if(i&&i.length||(a=e.visible=!1),a){r(\"label\"),r(\"displayindex\",e._index);var o,s=t.categoryarray,c=Array.isArray(s)&&s.length>0;c&&(o=\"array\");var u=r(\"categoryorder\",o);\"array\"===u?(r(\"categoryarray\"),r(\"ticktext\")):(delete t.categoryarray,delete t.ticktext),c||\"array\"!==u||(e.categoryorder=\"trace\")}}e.exports=function(t,e,r,h){function f(r,i){return n.coerce(t,e,l,r,i)}var p=s(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=function(t,e,r,o,s){s(\"line.shape\"),s(\"line.hovertemplate\");var l=s(\"line.color\",o.colorway[0]);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,h,f);o(e,h,f),Array.isArray(p)&&p.length||(e.visible=!1),c(e,p,\"values\",d),f(\"hoveron\"),f(\"hovertemplate\"),f(\"arrangement\"),f(\"bundlecolors\"),f(\"sortpaths\"),f(\"counts\");var g={family:h.font.family,size:Math.round(h.font.size),color:h.font.color};n.coerceFont(f,\"labelfont\",g);var v={family:h.font.family,size:Math.round(h.font.size/1.2),color:h.font.color};n.coerceFont(f,\"tickfont\",v)}},{\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/domain\":792,\"../parcoords/merge_length\":1083,\"./attributes\":1067}],1071:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcats\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1067,\"./base_plot\":1068,\"./calc\":1069,\"./defaults\":1070,\"./plot\":1073}],1072:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plot_api/plot_api\"),a=t(\"../../components/fx\"),o=t(\"../../lib\"),s=t(\"../../components/drawing\"),l=t(\"tinycolor2\"),c=t(\"../../lib/svg_text_utils\");function u(t,e,r,i){var a=t.map(function(t,e,r){var n,i=r[0],a=e.margin||{l:80,r:80,t:100,b:80},o=i.trace,s=o.domain,l=e.width,c=e.height,u=Math.floor(l*(s.x[1]-s.x[0])),h=Math.floor(c*(s.y[1]-s.y[0])),f=s.x[0]*l+a.l,p=e.height-s.y[1]*e.height+a.t,d=o.line.shape;n=\"all\"===o.hoverinfo?[\"count\",\"probability\"]:(o.hoverinfo||\"\").split(\"+\");var g={trace:o,key:o.uid,model:i,x:f,y:p,width:u,height:h,hoveron:o.hoveron,hoverinfoItems:n,arrangement:o.arrangement,bundlecolors:o.bundlecolors,sortpaths:o.sortpaths,labelfont:o.labelfont,categorylabelfont:o.tickfont,pathShape:d,dragDimension:null,margin:a,paths:[],dimensions:[],graphDiv:t,traceSelection:null,pathSelection:null,dimensionSelection:null};i.dimensions&&(R(g),D(g));return g}.bind(0,e,r)),l=i.selectAll(\"g.parcatslayer\").data([null]);l.enter().append(\"g\").attr(\"class\",\"parcatslayer\").style(\"pointer-events\",\"all\");var u=l.selectAll(\"g.trace.parcats\").data(a,h),v=u.enter().append(\"g\").attr(\"class\",\"trace parcats\");u.attr(\"transform\",function(t){return\"translate(\"+t.x+\", \"+t.y+\")\"}),v.append(\"g\").attr(\"class\",\"paths\");var x=u.select(\"g.paths\").selectAll(\"path.path\").data(function(t){return t.paths},h);x.attr(\"fill\",function(t){return t.model.color});var w=x.enter().append(\"path\").attr(\"class\",\"path\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.model.color}).attr(\"fill-opacity\",0);y(w),x.attr(\"d\",function(t){return t.svgD}),w.empty()||x.sort(p),x.exit().remove(),x.on(\"mouseover\",d).on(\"mouseout\",g).on(\"click\",m),v.append(\"g\").attr(\"class\",\"dimensions\");var k=u.select(\"g.dimensions\").selectAll(\"g.dimension\").data(function(t){return t.dimensions},h);k.enter().append(\"g\").attr(\"class\",\"dimension\"),k.attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),k.exit().remove();var T=k.selectAll(\"g.category\").data(function(t){return t.categories},h),A=T.enter().append(\"g\").attr(\"class\",\"category\");T.attr(\"transform\",function(t){return\"translate(0, \"+t.y+\")\"}),A.append(\"rect\").attr(\"class\",\"catrect\").attr(\"pointer-events\",\"none\"),T.select(\"rect.catrect\").attr(\"fill\",\"none\").attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}),b(A);var P=T.selectAll(\"rect.bandrect\").data(function(t){return t.bands},h);P.each(function(){o.raiseToTop(this)}),P.attr(\"fill\",function(t){return t.color});var O=P.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.color}).attr(\"fill-opacity\",0);P.attr(\"fill\",function(t){return t.color}).attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}).attr(\"y\",function(t){return t.y}).attr(\"cursor\",function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"perpendicular\"===t.parcatsViewModel.arrangement?\"ns-resize\":\"move\"}),_(O),P.exit().remove(),A.append(\"text\").attr(\"class\",\"catlabel\").attr(\"pointer-events\",\"none\");var z=e._fullLayout.paper_bgcolor;T.select(\"text.catlabel\").attr(\"text-anchor\",function(t){return f(t)?\"start\":\"end\"}).attr(\"alignment-baseline\",\"middle\").style(\"text-shadow\",z+\" -1px  1px 2px, \"+z+\" 1px  1px 2px, \"+z+\"  1px -1px 2px, \"+z+\" -1px -1px 2px\").style(\"fill\",\"rgb(0, 0, 0)\").attr(\"x\",function(t){return f(t)?t.width+5:-5}).attr(\"y\",function(t){return t.height/2}).text(function(t){return t.model.categoryLabel}).each(function(t){s.font(n.select(this),t.parcatsViewModel.categorylabelfont),c.convertToTspans(n.select(this),e)}),A.append(\"text\").attr(\"class\",\"dimlabel\"),T.select(\"text.dimlabel\").attr(\"text-anchor\",\"middle\").attr(\"alignment-baseline\",\"baseline\").attr(\"cursor\",function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"ew-resize\"}).attr(\"x\",function(t){return t.width/2}).attr(\"y\",-5).text(function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null}).each(function(t){s.font(n.select(this),t.parcatsViewModel.labelfont)}),T.selectAll(\"rect.bandrect\").on(\"mouseover\",M).on(\"mouseout\",S),T.exit().remove(),k.call(n.behavior.drag().origin(function(t){return{x:t.x,y:0}}).on(\"dragstart\",E).on(\"drag\",C).on(\"dragend\",L)),u.each(function(t){t.traceSelection=n.select(this),t.pathSelection=n.select(this).selectAll(\"g.paths\").selectAll(\"path.path\"),t.dimensionSelection=n.select(this).selectAll(\"g.dimensions\").selectAll(\"g.dimension\")}),u.exit().remove()}function h(t){return t.key}function f(t){var e=t.parcatsViewModel.dimensions.length,r=t.parcatsViewModel.dimensions[e-1].model.dimensionInd;return t.model.dimensionInd===r}function p(t,e){return t.model.rawColor>e.model.rawColor?1:t.model.rawColor<e.model.rawColor?-1:0}function d(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){o.raiseToTop(this),x(n.select(this));var e=v(t);if(t.parcatsViewModel.graphDiv.emit(\"plotly_hover\",{points:e,event:n.event}),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\")){var r,i,s,c=n.mouse(this)[0],u=t.parcatsViewModel.graphDiv,h=t.parcatsViewModel.trace,f=u._fullLayout,p=f._paperdiv.node().getBoundingClientRect(),d=t.parcatsViewModel.graphDiv.getBoundingClientRect();for(s=0;s<t.leftXs.length-1;s++)if(t.leftXs[s]+t.dimWidths[s]-2<=c&&c<=t.leftXs[s+1]+2){var g=t.parcatsViewModel.dimensions[s],m=t.parcatsViewModel.dimensions[s+1];r=(g.x+g.width+m.x)/2,i=(t.topYs[s]+t.topYs[s+1]+t.height)/2;break}var y=t.parcatsViewModel.x+r,b=t.parcatsViewModel.y+i,_=l.mostReadable(t.model.color,[\"black\",\"white\"]),w=t.model.count,k=w/t.parcatsViewModel.model.count,T={countLabel:w,probabilityLabel:k.toFixed(3)},A=[];-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&A.push([\"Count:\",T.countLabel].join(\" \")),-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&A.push([\"P:\",T.probabilityLabel].join(\" \"));var M=A.join(\"<br>\"),S=n.mouse(u)[0];a.loneHover({trace:h,x:y-p.left+d.left,y:b-p.top+d.top,text:M,color:t.model.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:10,fontColor:_,idealAlign:S<y?\"right\":\"left\",hovertemplate:(h.line||{}).hovertemplate,hovertemplateLabels:T,eventData:[{data:h._input,fullData:h,count:w,probability:k}]},{container:f._hoverlayer.node(),outerContainer:f._paper.node(),gd:u})}}}function g(t){if(!t.parcatsViewModel.dragDimension&&(y(n.select(this)),a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()),t.parcatsViewModel.pathSelection.sort(p),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\"))){var e=v(t);t.parcatsViewModel.graphDiv.emit(\"plotly_unhover\",{points:e,event:n.event})}}function v(t){for(var e=[],r=P(t.parcatsViewModel),n=0;n<t.model.valueInds.length;n++){var i=t.model.valueInds[n];e.push({curveNumber:r,pointNumber:i})}return e}function m(t){if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){var e=v(t);t.parcatsViewModel.graphDiv.emit(\"plotly_click\",{points:e,event:n.event})}}function y(t){t.attr(\"fill\",function(t){return t.model.color}).attr(\"fill-opacity\",.6).attr(\"stroke\",\"lightgray\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1)}function x(t){t.attr(\"fill-opacity\",.8).attr(\"stroke\",function(t){return l.mostReadable(t.model.color,[\"black\",\"white\"])}).attr(\"stroke-width\",.3)}function b(t){t.select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",1).attr(\"stroke-opacity\",1)}function _(t){t.attr(\"stroke\",\"black\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1).attr(\"fill-opacity\",1)}function w(t){var e=t.parcatsViewModel.pathSelection,r=t.categoryViewModel.model.dimensionInd,n=t.categoryViewModel.model.categoryInd;return e.filter(function(e){return e.model.categoryInds[r]===n&&e.model.color===t.color})}function k(t,e,r){var i=n.select(t).datum().parcatsViewModel.graphDiv,a=n.select(t.parentNode).selectAll(\"rect.bandrect\"),o=[];a.each(function(t){w(t).each(function(t){Array.prototype.push.apply(o,v(t))})}),i.emit(e,{points:o,event:r})}function T(t,e,r){var i=n.select(t).datum(),a=i.parcatsViewModel.graphDiv,o=w(i),s=[];o.each(function(t){Array.prototype.push.apply(s,v(t))}),a.emit(e,{points:s,event:r})}function A(t,e){var r,i,a=n.select(e.parentNode).select(\"rect.catrect\"),o=a.node().getBoundingClientRect(),s=a.datum(),l=s.parcatsViewModel,c=l.model.dimensions[s.model.dimensionInd],u=l.trace,h=o.top+o.height/2;l.dimensions.length>1&&c.displayInd===l.dimensions.length-1?(r=o.left,i=\"left\"):(r=o.left+o.width,i=\"right\");var f=s.model.count,p=s.model.categoryLabel,d=f/s.parcatsViewModel.model.count,g={countLabel:f,categoryLabel:p,probabilityLabel:d.toFixed(3)},v=[];-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&v.push([\"Count:\",g.countLabel].join(\" \")),-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&v.push([\"P(\"+g.categoryLabel+\"):\",g.probabilityLabel].join(\" \"));var m=v.join(\"<br>\");return{trace:u,x:r-t.left,y:h-t.top,text:m,color:\"lightgray\",borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:12,fontColor:\"black\",idealAlign:i,hovertemplate:u.hovertemplate,hovertemplateLabels:g,eventData:[{data:u._input,fullData:u,count:f,category:p,probability:d}]}}function M(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){if(n.mouse(this)[1]<-1)return;var e,r=t.parcatsViewModel.graphDiv,i=r._fullLayout,s=i._paperdiv.node().getBoundingClientRect(),c=t.parcatsViewModel.hoveron;if(\"color\"===c?(!function(t){var e=n.select(t).datum(),r=w(e);x(r),r.each(function(){o.raiseToTop(this)}),n.select(t.parentNode).selectAll(\"rect.bandrect\").filter(function(t){return t.color===e.color}).each(function(){o.raiseToTop(this),n.select(this).attr(\"stroke\",\"black\").attr(\"stroke-width\",1.5)})}(this),T(this,\"plotly_hover\",n.event)):(!function(t){n.select(t.parentNode).selectAll(\"rect.bandrect\").each(function(t){var e=w(t);x(e),e.each(function(){o.raiseToTop(this)})}),n.select(t.parentNode).select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",2.5)}(this),k(this,\"plotly_hover\",n.event)),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\"))\"category\"===c?e=A(s,this):\"color\"===c?e=function(t,e){var r,i,a=e.getBoundingClientRect(),o=n.select(e).datum(),s=o.categoryViewModel,c=s.parcatsViewModel,u=c.model.dimensions[s.model.dimensionInd],h=c.trace,f=a.y+a.height/2;c.dimensions.length>1&&u.displayInd===c.dimensions.length-1?(r=a.left,i=\"left\"):(r=a.left+a.width,i=\"right\");var p=s.model.categoryLabel,d=o.parcatsViewModel.model.count,g=0;o.categoryViewModel.bands.forEach(function(t){t.color===o.color&&(g+=t.count)});var v=s.model.count,m=0;c.pathSelection.each(function(t){t.model.color===o.color&&(m+=t.model.count)});var y=g/d,x=g/m,b=g/v,_={countLabel:d,categoryLabel:p,probabilityLabel:y.toFixed(3)},w=[];-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&w.push([\"Count:\",_.countLabel].join(\" \")),-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&(w.push(\"P(color \\u2229 \"+p+\"): \"+_.probabilityLabel),w.push(\"P(\"+p+\" | color): \"+x.toFixed(3)),w.push(\"P(color | \"+p+\"): \"+b.toFixed(3)));var k=w.join(\"<br>\"),T=l.mostReadable(o.color,[\"black\",\"white\"]);return{trace:h,x:r-t.left,y:f-t.top,text:k,color:o.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontColor:T,fontSize:10,idealAlign:i,hovertemplate:h.hovertemplate,hovertemplateLabels:_,eventData:[{data:h._input,fullData:h,category:p,count:d,probability:y,categorycount:v,colorcount:m,bandcolorcount:g}]}}(s,this):\"dimension\"===c&&(e=function(t,e){var r=[];return n.select(e.parentNode.parentNode).selectAll(\"g.category\").select(\"rect.catrect\").each(function(){r.push(A(t,this))}),r}(s,this)),e&&a.loneHover(e,{container:i._hoverlayer.node(),outerContainer:i._paper.node(),gd:r})}}function S(t){var e=t.parcatsViewModel;if(!e.dragDimension&&(y(e.pathSelection),b(e.dimensionSelection.selectAll(\"g.category\")),_(e.dimensionSelection.selectAll(\"g.category\").selectAll(\"rect.bandrect\")),a.loneUnhover(e.graphDiv._fullLayout._hoverlayer.node()),e.pathSelection.sort(p),-1===e.hoverinfoItems.indexOf(\"skip\"))){\"color\"===t.parcatsViewModel.hoveron?T(this,\"plotly_unhover\",n.event):k(this,\"plotly_unhover\",n.event)}}function E(t){\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragDimensionDisplayInd=t.model.displayInd,t.initialDragDimensionDisplayInds=t.parcatsViewModel.model.dimensions.map(function(t){return t.displayInd}),t.dragHasMoved=!1,t.dragCategoryDisplayInd=null,n.select(this).selectAll(\"g.category\").select(\"rect.catrect\").each(function(e){var r=n.mouse(this)[0],i=n.mouse(this)[1];-2<=r&&r<=e.width+2&&-2<=i&&i<=e.height+2&&(t.dragCategoryDisplayInd=e.model.displayInd,t.initialDragCategoryDisplayInds=t.model.categories.map(function(t){return t.displayInd}),e.model.dragY=e.y,o.raiseToTop(this.parentNode),n.select(this.parentNode).selectAll(\"rect.bandrect\").each(function(e){e.y<i&&i<=e.y+e.height&&(t.potentialClickBand=this)}))}),t.parcatsViewModel.dragDimension=t,a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()))}function C(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragHasMoved=!0,null!==t.dragDimensionDisplayInd)){var e=t.dragDimensionDisplayInd,r=e-1,i=e+1,a=t.parcatsViewModel.dimensions[e];if(null!==t.dragCategoryDisplayInd){var o=a.categories[t.dragCategoryDisplayInd];o.model.dragY+=n.event.dy;var s=o.model.dragY,l=o.model.displayInd,c=a.categories,u=c[l-1],h=c[l+1];void 0!==u&&s<u.y+u.height/2&&(o.model.displayInd=u.model.displayInd,u.model.displayInd=l),void 0!==h&&s+o.height>h.y+h.height/2&&(o.model.displayInd=h.model.displayInd,h.model.displayInd=l),t.dragCategoryDisplayInd=o.model.displayInd}if(null===t.dragCategoryDisplayInd||\"freeform\"===t.parcatsViewModel.arrangement){a.model.dragX=n.event.x;var f=t.parcatsViewModel.dimensions[r],p=t.parcatsViewModel.dimensions[i];void 0!==f&&a.model.dragX<f.x+f.width&&(a.model.displayInd=f.model.displayInd,f.model.displayInd=e),void 0!==p&&a.model.dragX+a.width>p.x&&(a.model.displayInd=p.model.displayInd,p.model.displayInd=t.dragDimensionDisplayInd),t.dragDimensionDisplayInd=a.model.displayInd}R(t.parcatsViewModel),D(t.parcatsViewModel),z(t.parcatsViewModel),O(t.parcatsViewModel)}}function L(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&null!==t.dragDimensionDisplayInd){n.select(this).selectAll(\"text\").attr(\"font-weight\",\"normal\");var e={},r=P(t.parcatsViewModel),a=t.parcatsViewModel.model.dimensions.map(function(t){return t.displayInd}),o=t.initialDragDimensionDisplayInds.some(function(t,e){return t!==a[e]});o&&a.forEach(function(r,n){var i=t.parcatsViewModel.model.dimensions[n].containerInd;e[\"dimensions[\"+i+\"].displayindex\"]=r});var s=!1;if(null!==t.dragCategoryDisplayInd){var l=t.model.categories.map(function(t){return t.displayInd});if(s=t.initialDragCategoryDisplayInds.some(function(t,e){return t!==l[e]})){var c=t.model.categories.slice().sort(function(t,e){return t.displayInd-e.displayInd}),u=c.map(function(t){return t.categoryValue}),h=c.map(function(t){return t.categoryLabel});e[\"dimensions[\"+t.model.containerInd+\"].categoryarray\"]=[u],e[\"dimensions[\"+t.model.containerInd+\"].ticktext\"]=[h],e[\"dimensions[\"+t.model.containerInd+\"].categoryorder\"]=\"array\"}}if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")&&!t.dragHasMoved&&t.potentialClickBand&&(\"color\"===t.parcatsViewModel.hoveron?T(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent):k(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent)),t.model.dragX=null,null!==t.dragCategoryDisplayInd)t.parcatsViewModel.dimensions[t.dragDimensionDisplayInd].categories[t.dragCategoryDisplayInd].model.dragY=null,t.dragCategoryDisplayInd=null;t.dragDimensionDisplayInd=null,t.parcatsViewModel.dragDimension=null,t.dragHasMoved=null,t.potentialClickBand=null,R(t.parcatsViewModel),D(t.parcatsViewModel),n.transition().duration(300).ease(\"cubic-in-out\").each(function(){z(t.parcatsViewModel,!0),O(t.parcatsViewModel,!0)}).each(\"end\",function(){(o||s)&&i.restyle(t.parcatsViewModel.graphDiv,e,[r])})}}function P(t){for(var e,r=t.graphDiv._fullData,n=0;n<r.length;n++)if(t.key===r[n].uid){e=n;break}return e}function O(t,e){var r;void 0===e&&(e=!1),t.pathSelection.data(function(t){return t.paths},h),(r=t.pathSelection,e?r.transition():r).attr(\"d\",function(t){return t.svgD})}function z(t,e){function r(t){return e?t.transition():t}void 0===e&&(e=!1),t.dimensionSelection.data(function(t){return t.dimensions},h);var i=t.dimensionSelection.selectAll(\"g.category\").data(function(t){return t.categories},h);r(t.dimensionSelection).attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),r(i).attr(\"transform\",function(t){return\"translate(0, \"+t.y+\")\"}),i.select(\".dimlabel\").text(function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null}),i.select(\".catlabel\").attr(\"text-anchor\",function(t){return f(t)?\"start\":\"end\"}).attr(\"x\",function(t){return f(t)?t.width+5:-5}).each(function(t){var e,r;f(t)?(e=t.width+5,r=\"start\"):(e=-5,r=\"end\"),n.select(this).selectAll(\"tspan\").attr(\"x\",e).attr(\"text-anchor\",r)});var a=i.selectAll(\"rect.bandrect\").data(function(t){return t.bands},h),s=a.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"cursor\",\"move\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.color}).attr(\"fill-opacity\",0);a.attr(\"fill\",function(t){return t.color}).attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}).attr(\"y\",function(t){return t.y}),_(s),a.each(function(){o.raiseToTop(this)}),a.exit().remove()}function I(t,e,r,i,a){var o,s,l=[],c=[];for(s=0;s<r.length-1;s++)o=n.interpolateNumber(r[s]+t[s],t[s+1]),l.push(o(a)),c.push(o(1-a));var u=\"M \"+t[0]+\",\"+e[0];for(u+=\"l\"+r[0]+\",0 \",s=1;s<r.length;s++)u+=\"C\"+l[s-1]+\",\"+e[s-1]+\" \"+c[s-1]+\",\"+e[s]+\" \"+t[s]+\",\"+e[s],u+=\"l\"+r[s]+\",0 \";for(u+=\"l0,\"+i+\" \",u+=\"l -\"+r[r.length-1]+\",0 \",s=r.length-2;s>=0;s--)u+=\"C\"+c[s]+\",\"+(e[s+1]+i)+\" \"+l[s]+\",\"+(e[s]+i)+\" \"+(t[s]+r[s])+\",\"+(e[s]+i),u+=\"l-\"+r[s]+\",0 \";return u+=\"Z\"}function D(t){var e=t.dimensions,r=t.model,n=e.map(function(t){return t.categories.map(function(t){return t.y})}),i=t.model.dimensions.map(function(t){return t.categories.map(function(t){return t.displayInd})}),a=t.model.dimensions.map(function(t){return t.displayInd}),o=t.dimensions.map(function(t){return t.model.dimensionInd}),s=e.map(function(t){return t.x}),l=e.map(function(t){return t.width}),c=[];for(var u in r.paths)r.paths.hasOwnProperty(u)&&c.push(r.paths[u]);function h(t){var e=t.categoryInds.map(function(t,e){return i[e][t]});return o.map(function(t){return e[t]})}c.sort(function(e,r){var n=h(e),i=h(r);return\"backward\"===t.sortpaths&&(n.reverse(),i.reverse()),n.push(e.valueInds[0]),i.push(r.valueInds[0]),t.bundlecolors&&(n.unshift(e.rawColor),i.unshift(r.rawColor)),n<i?-1:n>i?1:0});for(var f=new Array(c.length),p=e[0].model.count,d=e[0].categories.map(function(t){return t.height}).reduce(function(t,e){return t+e}),g=0;g<c.length;g++){var v,m=c[g];v=p>0?d*(m.count/p):0;for(var y,x=new Array(n.length),b=0;b<m.categoryInds.length;b++){var _=m.categoryInds[b],w=i[b][_],k=a[b];x[k]=n[k][w],n[k][w]+=v;var T=t.dimensions[k].categories[w],A=T.bands.length,M=T.bands[A-1];if(void 0===M||m.rawColor!==M.rawColor){var S=void 0===M?0:M.y+M.height;T.bands.push({key:S,color:m.color,rawColor:m.rawColor,height:v,width:T.width,count:m.count,y:S,categoryViewModel:T,parcatsViewModel:t})}else{var E=T.bands[A-1];E.height+=v,E.count+=m.count}}y=\"hspline\"===t.pathShape?I(s,x,l,v,.5):I(s,x,l,v,0),f[g]={key:m.valueInds[0],model:m,height:v,leftXs:s,topYs:x,dimWidths:l,svgD:y,parcatsViewModel:t}}t.paths=f}function R(t){var e=t.model.dimensions.map(function(t){return{displayInd:t.displayInd,dimensionInd:t.dimensionInd}});e.sort(function(t,e){return t.displayInd-e.displayInd});var r=[];for(var n in e){var i=e[n].dimensionInd,a=t.model.dimensions[i];r.push(F(t,a))}t.dimensions=r}function F(t,e){var r,n=t.model.dimensions.length,i=e.displayInd;r=40+(n>1?(t.width-80-16)/(n-1):0)*i;var a,o,s,l,c,u=[],h=t.model.maxCats,f=e.categories.length,p=e.count,d=t.height-8*(h-1),g=8*(h-f)/2,v=e.categories.map(function(t){return{displayInd:t.displayInd,categoryInd:t.categoryInd}});for(v.sort(function(t,e){return t.displayInd-e.displayInd}),c=0;c<f;c++)l=v[c].categoryInd,o=e.categories[l],a=p>0?o.count/p*d:0,s={key:o.valueInds[0],model:o,width:16,height:a,y:null!==o.dragY?o.dragY:g,bands:[],parcatsViewModel:t},g=g+a+8,u.push(s);return{key:e.dimensionInd,x:null!==e.dragX?e.dragX:r,y:0,width:16,model:e,categories:u,parcatsViewModel:t,dragCategoryDisplayInd:null,dragDimensionDisplayInd:null,initialDragDimensionDisplayInds:null,initialDragCategoryDisplayInds:null,dragHasMoved:null,potentialClickBand:null}}e.exports=function(t,e,r,n){u(r,t,n,e)}},{\"../../components/drawing\":614,\"../../components/fx\":632,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_api\":754,d3:163,tinycolor2:537}],1073:[function(t,e,r){\"use strict\";var n=t(\"./parcats\");e.exports=function(t,e,r,i){var a=t._fullLayout,o=a._paper,s=a._size;n(t,o,e,{width:s.w,height:s.h,margin:{t:s.t,r:s.r,b:s.b,l:s.l}},r,i)}},{\"./parcats\":1072}],1074:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/cartesian/layout_attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../plots/domain\").attributes,s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/plot_template\").templatedArray;e.exports={domain:o({name:\"parcoords\",trace:!0,editType:\"plot\"}),labelangle:{valType:\"angle\",dflt:0,editType:\"plot\"},labelside:{valType:\"enumerated\",values:[\"top\",\"bottom\"],dflt:\"top\",editType:\"plot\"},labelfont:a({editType:\"plot\"}),tickfont:a({editType:\"plot\"}),rangefont:a({editType:\"plot\"}),dimensions:l(\"dimension\",{label:{valType:\"string\",editType:\"plot\"},tickvals:s({},i.tickvals,{editType:\"plot\"}),ticktext:s({},i.ticktext,{editType:\"plot\"}),tickformat:s({},i.tickformat,{editType:\"plot\"}),visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},constraintrange:{valType:\"info_array\",freeLength:!0,dimensions:\"1-2\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},multiselect:{valType:\"boolean\",dflt:!0,editType:\"plot\"},values:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"}),line:s({editType:\"calc\"},n(\"line\",{colorscaleDflt:\"Viridis\",autoColorDflt:!1,editTypeOverride:\"calc\"}))}},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1075:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\").keyFun,o=t(\"../../lib/gup\").repeat,s=t(\"../../lib\").sorterAsc,l=n.bar.snapRatio;function c(t,e){return t*(1-l)+e*l}var u=n.bar.snapClose;function h(t,e){return t*(1-u)+e*u}function f(t,e,r,n){if(function(t,e){for(var r=0;r<e.length;r++)if(t>=e[r][0]&&t<=e[r][1])return!0;return!1}(r,n))return r;var i=t?-1:1,a=0,o=e.length-1;if(i<0){var s=a;a=o,o=s}for(var l=e[a],u=l,f=a;i*f<i*o;f+=i){var p=f+i,d=e[p];if(i*r<i*h(l,d))return c(l,u);if(i*r<i*d||p===o)return c(d,l);u=l,l=d}}function p(t){t.attr(\"x\",-n.bar.captureWidth/2).attr(\"width\",n.bar.captureWidth)}function d(t){t.attr(\"visibility\",\"visible\").style(\"visibility\",\"visible\").attr(\"fill\",\"yellow\").attr(\"opacity\",0)}function g(t){if(!t.brush.filterSpecified)return\"0,\"+t.height;for(var e,r,n,i=v(t.brush.filter.getConsolidated(),t.height),a=[0],o=i.length?i[0][0]:null,s=0;s<i.length;s++)r=(e=i[s])[1]-e[0],a.push(o),a.push(r),(n=s+1)<i.length&&(o=i[n][0]-e[1]);return a.push(t.height),a}function v(t,e){return t.map(function(t){return t.map(function(t){return Math.max(0,t*e)}).sort(s)})}function m(){i.select(document.body).style(\"cursor\",null)}function y(t){t.attr(\"stroke-dasharray\",g)}function x(t,e){var r=i.select(t).selectAll(\".highlight, .highlight-shadow\");y(e?r.transition().duration(n.bar.snapDuration).each(\"end\",e):r)}function b(t,e){var r,i=t.brush,a=NaN,o={};if(i.filterSpecified){var s=t.height,l=i.filter.getConsolidated(),c=v(l,s),u=NaN,h=NaN,f=NaN;for(r=0;r<=c.length;r++){var p=c[r];if(p&&p[0]<=e&&e<=p[1]){u=r;break}if(h=r?r-1:NaN,p&&p[0]>e){f=r;break}}if(a=u,isNaN(a)&&(a=isNaN(h)||isNaN(f)?isNaN(h)?f:h:e-c[h][1]<c[f][0]-e?h:f),!isNaN(a)){var d=c[a],g=function(t,e){var r=n.bar.handleHeight;if(!(e>t[1]+r||e<t[0]-r))return e>=.9*t[1]+.1*t[0]?\"n\":e<=.9*t[0]+.1*t[1]?\"s\":\"ns\"}(d,e);g&&(o.interval=l[a],o.intervalPix=d,o.region=g)}}if(t.ordinal&&!o.region){var m=t.unitTickvals,y=t.unitToPaddedPx.invert(e);for(r=0;r<m.length;r++){var x=[.25*m[Math.max(r-1,0)]+.75*m[r],.25*m[Math.min(r+1,m.length-1)]+.75*m[r]];if(y>=x[0]&&y<=x[1]){o.clickableOrdinalRange=x;break}}}return o}function _(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.brush.svgBrush;a.wasDragged=!0,a._dragging=!0,a.grabbingBar?a.newExtent=[r-a.grabPoint,r+a.barLength-a.grabPoint].map(e.unitToPaddedPx.invert):a.newExtent=[a.startExtent,e.unitToPaddedPx.invert(r)].sort(s),e.brush.filterSpecified=!0,a.extent=a.stayingIntervals.concat([a.newExtent]),a.brushCallback(e),x(t.parentNode)}function w(t,e){var r=b(e,e.height-i.mouse(t)[1]-2*n.verticalPadding),a=\"crosshair\";r.clickableOrdinalRange?a=\"pointer\":r.region&&(a=r.region+\"-resize\"),i.select(document.body).style(\"cursor\",a)}function k(t){t.on(\"mousemove\",function(t){i.event.preventDefault(),t.parent.inBrushDrag||w(this,t)}).on(\"mouseleave\",function(t){t.parent.inBrushDrag||m()}).call(i.behavior.drag().on(\"dragstart\",function(t){!function(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.unitToPaddedPx.invert(r),o=e.brush,s=b(e,r),l=s.interval,c=o.svgBrush;if(c.wasDragged=!1,c.grabbingBar=\"ns\"===s.region,c.grabbingBar){var u=l.map(e.unitToPaddedPx);c.grabPoint=r-u[0]-n.verticalPadding,c.barLength=u[1]-u[0]}c.clickableOrdinalRange=s.clickableOrdinalRange,c.stayingIntervals=e.multiselect&&o.filterSpecified?o.filter.getConsolidated():[],l&&(c.stayingIntervals=c.stayingIntervals.filter(function(t){return t[0]!==l[0]&&t[1]!==l[1]})),c.startExtent=s.region?l[\"s\"===s.region?1:0]:a,e.parent.inBrushDrag=!0,c.brushStartCallback()}(this,t)}).on(\"drag\",function(t){_(this,t)}).on(\"dragend\",function(t){!function(t,e){var r=e.brush,n=r.filter,a=r.svgBrush;a._dragging||(w(t,e),_(t,e),e.brush.svgBrush.wasDragged=!1),a._dragging=!1,i.event.sourceEvent.stopPropagation();var o=a.grabbingBar;if(a.grabbingBar=!1,a.grabLocation=void 0,e.parent.inBrushDrag=!1,m(),!a.wasDragged)return a.wasDragged=void 0,a.clickableOrdinalRange?r.filterSpecified&&e.multiselect?a.extent.push(a.clickableOrdinalRange):(a.extent=[a.clickableOrdinalRange],r.filterSpecified=!0):o?(a.extent=a.stayingIntervals,0===a.extent.length&&A(r)):A(r),a.brushCallback(e),x(t.parentNode),void a.brushEndCallback(r.filterSpecified?n.getConsolidated():[]);var s=function(){n.set(n.getConsolidated())};if(e.ordinal){var l=e.unitTickvals;l[l.length-1]<l[0]&&l.reverse(),a.newExtent=[f(0,l,a.newExtent[0],a.stayingIntervals),f(1,l,a.newExtent[1],a.stayingIntervals)];var c=a.newExtent[1]>a.newExtent[0];a.extent=a.stayingIntervals.concat(c?[a.newExtent]:[]),a.extent.length||A(r),a.brushCallback(e),c?x(t.parentNode,s):(s(),x(t.parentNode))}else s();a.brushEndCallback(r.filterSpecified?n.getConsolidated():[])}(this,t)}))}function T(t,e){return t[0]-e[0]}function A(t){t.filterSpecified=!1,t.svgBrush.extent=[[-1/0,1/0]]}function M(t){for(var e,r=t.slice(),n=[],i=r.shift();i;){for(e=i.slice();(i=r.shift())&&i[0]<=e[1];)e[1]=Math.max(e[1],i[1]);n.push(e)}return n}e.exports={makeBrush:function(t,e,r,n,i,a){var o,l=function(){var t,e,r=[];return{set:function(n){1===(r=n.map(function(t){return t.slice().sort(s)}).sort(T)).length&&r[0][0]===-1/0&&r[0][1]===1/0&&(r=[[0,-1]]),t=M(r),e=r.reduce(function(t,e){return[Math.min(t[0],e[0]),Math.max(t[1],e[1])]},[1/0,-1/0])},get:function(){return r.slice()},getConsolidated:function(){return t},getBounds:function(){return e}}}();return l.set(r),{filter:l,filterSpecified:e,svgBrush:{extent:[],brushStartCallback:n,brushCallback:(o=i,function(t){var e=t.brush,r=function(t){return t.svgBrush.extent.map(function(t){return t.slice()})}(e).slice();e.filter.set(r),o()}),brushEndCallback:a}}},ensureAxisBrush:function(t){var e=t.selectAll(\".\"+n.cn.axisBrush).data(o,a);e.enter().append(\"g\").classed(n.cn.axisBrush,!0),function(t){var e=t.selectAll(\".background\").data(o);e.enter().append(\"rect\").classed(\"background\",!0).call(p).call(d).style(\"pointer-events\",\"auto\").attr(\"transform\",\"translate(0 \"+n.verticalPadding+\")\"),e.call(k).attr(\"height\",function(t){return t.height-n.verticalPadding});var r=t.selectAll(\".highlight-shadow\").data(o);r.enter().append(\"line\").classed(\"highlight-shadow\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width+n.bar.strokeWidth).attr(\"stroke\",n.bar.strokeColor).attr(\"opacity\",n.bar.strokeOpacity).attr(\"stroke-linecap\",\"butt\"),r.attr(\"y1\",function(t){return t.height}).call(y);var i=t.selectAll(\".highlight\").data(o);i.enter().append(\"line\").classed(\"highlight\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width-n.bar.strokeWidth).attr(\"stroke\",n.bar.fillColor).attr(\"opacity\",n.bar.fillOpacity).attr(\"stroke-linecap\",\"butt\"),i.attr(\"y1\",function(t){return t.height}).call(y)}(e)},cleanRanges:function(t,e){if(Array.isArray(t[0])?(t=t.map(function(t){return t.sort(s)}),t=e.multiselect?M(t.sort(T)):[t[0]]):t=[t.sort(s)],e.tickvals){var r=e.tickvals.slice().sort(s);if(!(t=t.map(function(t){var e=[f(0,r,t[0],[]),f(1,r,t[1],[])];if(e[1]>e[0])return e}).filter(function(t){return t})).length)return}return t.length>1?t:t[0]}}},{\"../../lib\":719,\"../../lib/gup\":717,\"./constants\":1078,d3:163}],1076:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../constants/xmlns_namespaces\");r.name=\"parcoords\",r.plot=function(t){var e=i(t.calcdata,\"parcoords\")[0];e.length&&a(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcoords\"),a=e._has&&e._has(\"parcoords\");i&&!a&&(n._paperdiv.selectAll(\".parcoords\").remove(),n._glimages.selectAll(\"*\").remove())},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter(function(t,e){return e===r.size()-1}).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each(function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})}),window.setTimeout(function(){n.selectAll(\"#filterBarPattern\").attr(\"id\",\"filterBarPattern\")},60)}},{\"../../constants/xmlns_namespaces\":696,\"../../plots/get_data\":802,\"./plot\":1085,d3:163}],1077:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale\"),a=t(\"../../lib/gup\").wrap;e.exports=function(t,e){var r,o;return i.hasColorscale(e,\"line\")&&n(e.line.color)?(r=e.line.color,o=i.extractOpts(e.line).colorscale,i.calc(t,e,{vals:r,containerStr:\"line\",cLetter:\"c\"})):(r=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=.5;return e}(e._length),o=[[0,e.line.color],[1,e.line.color]]),a({lineColor:r,cscale:o})}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gup\":717}],1078:[function(t,e,r){\"use strict\";e.exports={maxDimensionCount:60,overdrag:45,verticalPadding:2,tickDistance:50,canvasPixelRatio:1,blockLineCount:5e3,layers:[\"contextLineLayer\",\"focusLineLayer\",\"pickLineLayer\"],axisTitleOffset:28,axisExtentOffset:10,deselectedLineColor:\"#777\",bar:{width:4,captureWidth:10,fillColor:\"magenta\",fillOpacity:1,snapDuration:150,snapRatio:.25,snapClose:.01,strokeColor:\"white\",strokeOpacity:1,strokeWidth:1,handleHeight:8,handleOpacity:1,handleOverlap:0},cn:{axisExtentText:\"axis-extent-text\",parcoordsLineLayers:\"parcoords-line-layers\",parcoordsLineLayer:\"parcoords-lines\",parcoords:\"parcoords\",parcoordsControlView:\"parcoords-control-view\",yAxis:\"y-axis\",axisOverlays:\"axis-overlays\",axis:\"axis\",axisHeading:\"axis-heading\",axisTitle:\"axis-title\",axisExtent:\"axis-extent\",axisExtentTop:\"axis-extent-top\",axisExtentTopText:\"axis-extent-top-text\",axisExtentBottom:\"axis-extent-bottom\",axisExtentBottomText:\"axis-extent-bottom-text\",axisBrush:\"axis-brush\"},id:{filterBarPattern:\"filter-bar-pattern\"}}},{}],1079:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"../../plots/cartesian/axes\"),c=t(\"./attributes\"),u=t(\"./axisbrush\"),h=t(\"./constants\").maxDimensionCount,f=t(\"./merge_length\");function p(t,e,r,i){function a(r,i){return n.coerce(t,e,c.dimensions,r,i)}var o=a(\"values\"),s=a(\"visible\");if(o&&o.length||(s=e.visible=!1),s){a(\"label\"),a(\"tickvals\"),a(\"ticktext\"),a(\"tickformat\");var h=a(\"range\");e._ax={_id:\"y\",type:\"linear\",showexponent:\"all\",exponentformat:\"B\",range:h},l.setConvert(e._ax,i.layout),a(\"multiselect\");var f=a(\"constraintrange\");f&&(e.constraintrange=u.cleanRanges(f,e))}}e.exports=function(t,e,r,l){function u(r,i){return n.coerce(t,e,c,r,i)}var d=t.dimensions;Array.isArray(d)&&d.length>h&&(n.log(\"parcoords traces support up to \"+h+\" dimensions at the moment\"),d.splice(h));var g=s(t,e,{name:\"dimensions\",layout:l,handleItemDefaults:p}),v=function(t,e,r,o,s){var l=s(\"line.color\",r);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,l,u);o(e,l,u),Array.isArray(g)&&g.length||(e.visible=!1),f(e,g,\"values\",v);var m={family:l.font.family,size:Math.round(l.font.size/1.2),color:l.font.color};n.coerceFont(u,\"labelfont\",m),n.coerceFont(u,\"tickfont\",m),n.coerceFont(u,\"rangefont\",m),u(\"labelangle\"),u(\"labelside\")}},{\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"../../plots/domain\":792,\"./attributes\":1074,\"./axisbrush\":1075,\"./constants\":1078,\"./merge_length\":1083}],1080:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isTypedArray;r.convertTypedArray=function(t){return n(t)?Array.prototype.slice.call(t):t},r.isOrdinal=function(t){return!!t.tickvals},r.isVisible=function(t){return t.visible||!(\"visible\"in t)}},{\"../../lib\":719}],1081:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcoords\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"noOpacity\",\"noHover\"],meta:{}}},{\"./attributes\":1074,\"./base_plot\":1076,\"./calc\":1077,\"./defaults\":1079,\"./plot\":1085}],1082:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nattribute vec4 p01_04, p05_08, p09_12, p13_16,\\n               p17_20, p21_24, p25_28, p29_32,\\n               p33_36, p37_40, p41_44, p45_48,\\n               p49_52, p53_56, p57_60, colors;\\n\\nuniform mat4 dim0A, dim1A, dim0B, dim1B, dim0C, dim1C, dim0D, dim1D,\\n             loA, hiA, loB, hiB, loC, hiC, loD, hiD;\\n\\nuniform vec2 resolution, viewBoxPos, viewBoxSize;\\nuniform sampler2D mask, palette;\\nuniform float maskHeight;\\nuniform float drwLayer; // 0: context, 1: focus, 2: pick\\nuniform vec4 contextColor;\\n\\nbool isPick    = (drwLayer > 1.5);\\nbool isContext = (drwLayer < 0.5);\\n\\nconst vec4 ZEROS = vec4(0.0, 0.0, 0.0, 0.0);\\nconst vec4 UNITS = vec4(1.0, 1.0, 1.0, 1.0);\\n\\nfloat val(mat4 p, mat4 v) {\\n    return dot(matrixCompMult(p, v) * UNITS, UNITS);\\n}\\n\\nfloat axisY(float ratio, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float y1 = val(A, dim0A) + val(B, dim0B) + val(C, dim0C) + val(D, dim0D);\\n    float y2 = val(A, dim1A) + val(B, dim1B) + val(C, dim1C) + val(D, dim1D);\\n    return y1 * (1.0 - ratio) + y2 * ratio;\\n}\\n\\nint iMod(int a, int b) {\\n    return a - b * (a / b);\\n}\\n\\nbool fOutside(float p, float lo, float hi) {\\n    return (lo < hi) && (lo > p || p > hi);\\n}\\n\\nbool vOutside(vec4 p, vec4 lo, vec4 hi) {\\n    return (\\n        fOutside(p[0], lo[0], hi[0]) ||\\n        fOutside(p[1], lo[1], hi[1]) ||\\n        fOutside(p[2], lo[2], hi[2]) ||\\n        fOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool mOutside(mat4 p, mat4 lo, mat4 hi) {\\n    return (\\n        vOutside(p[0], lo[0], hi[0]) ||\\n        vOutside(p[1], lo[1], hi[1]) ||\\n        vOutside(p[2], lo[2], hi[2]) ||\\n        vOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool outsideBoundingBox(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    return mOutside(A, loA, hiA) ||\\n           mOutside(B, loB, hiB) ||\\n           mOutside(C, loC, hiC) ||\\n           mOutside(D, loD, hiD);\\n}\\n\\nbool outsideRasterMask(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    mat4 pnts[4];\\n    pnts[0] = A;\\n    pnts[1] = B;\\n    pnts[2] = C;\\n    pnts[3] = D;\\n\\n    for(int i = 0; i < 4; ++i) {\\n        for(int j = 0; j < 4; ++j) {\\n            for(int k = 0; k < 4; ++k) {\\n                if(0 == iMod(\\n                    int(255.0 * texture2D(mask,\\n                        vec2(\\n                            (float(i * 2 + j / 2) + 0.5) / 8.0,\\n                            (pnts[i][j][k] * (maskHeight - 1.0) + 1.0) / maskHeight\\n                        ))[3]\\n                    ) / int(pow(2.0, float(iMod(j * 4 + k, 8)))),\\n                    2\\n                )) return true;\\n            }\\n        }\\n    }\\n    return false;\\n}\\n\\nvec4 position(bool isContext, float v, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float x = 0.5 * sign(v) + 0.5;\\n    float y = axisY(x, A, B, C, D);\\n    float z = 1.0 - abs(v);\\n\\n    z += isContext ? 0.0 : 2.0 * float(\\n        outsideBoundingBox(A, B, C, D) ||\\n        outsideRasterMask(A, B, C, D)\\n    );\\n\\n    return vec4(\\n        2.0 * (vec2(x, y) * viewBoxSize + viewBoxPos) / resolution - 1.0,\\n        z,\\n        1.0\\n    );\\n}\\n\\nvoid main() {\\n    mat4 A = mat4(p01_04, p05_08, p09_12, p13_16);\\n    mat4 B = mat4(p17_20, p21_24, p25_28, p29_32);\\n    mat4 C = mat4(p33_36, p37_40, p41_44, p45_48);\\n    mat4 D = mat4(p49_52, p53_56, p57_60, ZEROS);\\n\\n    float v = colors[3];\\n\\n    gl_Position = position(isContext, v, A, B, C, D);\\n\\n    fragColor =\\n        isContext ? vec4(contextColor) :\\n        isPick ? vec4(colors.rgb, 1.0) : texture2D(palette, vec2(abs(v), 0.5));\\n}\\n\"]),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n    gl_FragColor = fragColor;\\n}\\n\"]),o=t(\"./constants\").maxDimensionCount,s=t(\"../../lib\"),l=1e-6,c=2048,u=new Uint8Array(4),h=new Uint8Array(4),f={shape:[256,1],format:\"rgba\",type:\"uint8\",mag:\"nearest\",min:\"nearest\"};function p(t,e,r,n,i){var a=t._gl;a.enable(a.SCISSOR_TEST),a.scissor(e,r,n,i),t.clear({color:[0,0,0,0],depth:1})}function d(t,e,r,n,i,a){var o=a.key;r.drawCompleted||(!function(t){t.read({x:0,y:0,width:1,height:1,data:u})}(t),r.drawCompleted=!0),function s(l){var c=Math.min(n,i-l*n);0===l&&(window.cancelAnimationFrame(r.currentRafs[o]),delete r.currentRafs[o],p(t,a.scissorX,a.scissorY,a.scissorWidth,a.viewBoxSize[1])),r.clearOnly||(a.count=2*c,a.offset=2*l*n,e(a),l*n+c<i&&(r.currentRafs[o]=window.requestAnimationFrame(function(){s(l+1)})),r.drawCompleted=!1)}(0)}function g(t,e){return(t>>>8*e)%256/255}function v(t,e,r){for(var n=new Array(8*e),i=0,a=0;a<e;a++)for(var o=0;o<2;o++)for(var s=0;s<4;s++){var l=4*t+s,c=r[64*a+l];63===l&&0===o&&(c*=-1),n[i++]=c}return n}function m(t){var e=\"0\"+t;return e.substr(e.length-2)}function y(t){return t<o?\"p\"+m(t+1)+\"_\"+m(t+4):\"colors\"}function x(t,e,r,n,i,a,o,l,c,u,h,f,p){for(var d=[[],[]],g=0;g<64;g++)d[0][g]=g===i?1:0,d[1][g]=g===a?1:0;var v=t.lines.canvasOverdrag,m=t.domain,y=t.canvasWidth,x=t.canvasHeight,b=t.deselectedLines.color;return s.extendFlat({key:h,resolution:[y,x],viewBoxPos:[o+v,l],viewBoxSize:[c,u],i0:i,i1:a,dim0A:d[0].slice(0,16),dim0B:d[0].slice(16,32),dim0C:d[0].slice(32,48),dim0D:d[0].slice(48,64),dim1A:d[1].slice(0,16),dim1B:d[1].slice(16,32),dim1C:d[1].slice(32,48),dim1D:d[1].slice(48,64),drwLayer:f,contextColor:[b[0]/255,b[1]/255,b[2]/255,b[3]<1?b[3]:Math.max(1/255,Math.pow(1/t.lines.color.length,1/3))],scissorX:(n===e?0:o+v)+(t.pad.l-v)+t.layoutWidth*m.x[0],scissorWidth:(n===r?y-o+v:c+.5)+(n===e?o+v:0),scissorY:l+t.pad.b+t.layoutHeight*m.y[0],scissorHeight:u,viewportX:t.pad.l-v+t.layoutWidth*m.x[0],viewportY:t.pad.b+t.layoutHeight*m.y[0],viewportWidth:y,viewportHeight:x},p)}function b(t){var e=c-1,r=Math.max(0,Math.floor(t[0]*e),0),n=Math.min(e,Math.ceil(t[1]*e),e);return[Math.min(r,n),Math.max(r,n)]}e.exports=function(t,e){var r,n,u,m,_,w=e.context,k=e.pick,T=e.regl,A={currentRafs:{},drawCompleted:!0,clearOnly:!1},M=function(t){for(var e={},r=0;r<=o;r+=4)e[y(r)]=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)});return e}(T),S=T.texture(f),E=[];L(e);var C=T({profile:!1,blend:{enable:w,func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:1,dstAlpha:1},equation:{rgb:\"add\",alpha:\"add\"},color:[0,0,0,0]},depth:{enable:!w,mask:!0,func:\"less\",range:[0,1]},cull:{enable:!0,face:\"back\"},scissor:{enable:!0,box:{x:T.prop(\"scissorX\"),y:T.prop(\"scissorY\"),width:T.prop(\"scissorWidth\"),height:T.prop(\"scissorHeight\")}},viewport:{x:T.prop(\"viewportX\"),y:T.prop(\"viewportY\"),width:T.prop(\"viewportWidth\"),height:T.prop(\"viewportHeight\")},dither:!1,vert:i,frag:a,primitive:\"lines\",lineWidth:1,attributes:M,uniforms:{resolution:T.prop(\"resolution\"),viewBoxPos:T.prop(\"viewBoxPos\"),viewBoxSize:T.prop(\"viewBoxSize\"),dim0A:T.prop(\"dim0A\"),dim1A:T.prop(\"dim1A\"),dim0B:T.prop(\"dim0B\"),dim1B:T.prop(\"dim1B\"),dim0C:T.prop(\"dim0C\"),dim1C:T.prop(\"dim1C\"),dim0D:T.prop(\"dim0D\"),dim1D:T.prop(\"dim1D\"),loA:T.prop(\"loA\"),hiA:T.prop(\"hiA\"),loB:T.prop(\"loB\"),hiB:T.prop(\"hiB\"),loC:T.prop(\"loC\"),hiC:T.prop(\"hiC\"),loD:T.prop(\"loD\"),hiD:T.prop(\"hiD\"),palette:S,contextColor:T.prop(\"contextColor\"),mask:T.prop(\"maskTexture\"),drwLayer:T.prop(\"drwLayer\"),maskHeight:T.prop(\"maskHeight\")},offset:T.prop(\"offset\"),count:T.prop(\"count\")});function L(t){r=t.model,n=t.viewModel,u=n.dimensions.slice(),m=u[0]?u[0].values.length:0;var e=r.lines,i=k?e.color.map(function(t,r){return r/e.color.length}):e.color,a=function(t,e,r){for(var n,i=new Array(t*(o+4)),a=0,s=0;s<t;s++){for(var c=0;c<o;c++)i[a++]=c<e.length?e[c].paddedUnitValues[s]:.5;i[a++]=g(s,2),i[a++]=g(s,1),i[a++]=g(s,0),i[a++]=(n=r[s],Math.max(l,Math.min(1-l,n)))}return i}(m,u,i);!function(t,e,r){for(var n=0;n<=o;n+=4)t[y(n)](v(n/4,e,r))}(M,m,a),w||k||(S=T.texture(s.extendFlat({data:function(t,e){for(var r=new Array(256),n=0;n<256;n++)r[n]=t(n/255).concat(e);return r}(r.unitToColor,255)},f)))}return{render:function(t,e,n){var i,a,o,s=t.length,l=1/0,h=-1/0;for(i=0;i<s;i++)t[i].dim0.canvasX<l&&(l=t[i].dim0.canvasX,a=i),t[i].dim1.canvasX>h&&(h=t[i].dim1.canvasX,o=i);0===s&&p(T,0,0,r.canvasWidth,r.canvasHeight);var f=function(t){var e,r,n,i=[[],[]];for(n=0;n<64;n++){var a=!t&&n<u.length?u[n].brush.filter.getBounds():[-1/0,1/0];i[0][n]=a[0],i[1][n]=a[1]}var o=8*c,s=new Array(o);for(e=0;e<o;e++)s[e]=255;if(!t)for(e=0;e<u.length;e++){var l=e%8,h=(e-l)/8,f=Math.pow(2,l),p=u[e].brush.filter.get();if(!(p.length<2)){var d=b(p[0])[1];for(r=1;r<p.length;r++){var g=b(p[r]);for(n=d+1;n<g[0];n++)s[8*n+h]&=~f;d=Math.max(d,g[1])}}}var v={shape:[8,c],format:\"alpha\",type:\"uint8\",mag:\"nearest\",min:\"nearest\",data:s};return _?_(v):_=T.texture(v),{maskTexture:_,maskHeight:c,loA:i[0].slice(0,16),loB:i[0].slice(16,32),loC:i[0].slice(32,48),loD:i[0].slice(48,64),hiA:i[1].slice(0,16),hiB:i[1].slice(16,32),hiC:i[1].slice(32,48),hiD:i[1].slice(48,64)}}(w);for(i=0;i<s;i++){var g=t[i],v=g.dim0.crossfilterDimensionIndex,y=g.dim1.crossfilterDimensionIndex,M=g.canvasX,S=g.canvasY,L=M+g.panelSizeX;if(e||!E[v]||E[v][0]!==M||E[v][1]!==L){E[v]=[M,L];var P=x(r,a,o,i,v,y,M,S,g.panelSizeX,g.panelSizeY,g.dim0.crossfilterDimensionIndex,w?0:k?2:1,f);A.clearOnly=n;var O=e?r.lines.blockLineCount:m;d(T,C,A,O,m,P)}}},readPixel:function(t,e){return T.read({x:t,y:e,width:1,height:1,data:h}),h},readPixels:function(t,e,r,n){var i=new Uint8Array(4*r*n);return T.read({x:t,y:e,width:r,height:n,data:i}),i},destroy:function(){for(var e in t.style[\"pointer-events\"]=\"none\",S.destroy(),_&&_.destroy(),M)M[e].destroy()},update:L}}},{\"../../lib\":719,\"./constants\":1078,glslify:409}],1083:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a;for(n||(n=1/0),i=0;i<e.length;i++)(a=e[i]).visible&&(n=Math.min(n,a[r].length));for(n===1/0&&(n=0),t._length=n,i=0;i<e.length;i++)(a=e[i]).visible&&(a._length=n);return n}},{}],1084:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"color-rgba\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../components/drawing\"),c=t(\"../../components/colorscale\"),u=t(\"../../lib/gup\"),h=u.keyFun,f=u.repeat,p=u.unwrap,d=t(\"./helpers\"),g=t(\"./constants\"),v=t(\"./axisbrush\"),m=t(\"./lines\");function y(t,e,r){return o.aggNums(t,null,e,r)}function x(t,e){return _(y(Math.min,t,e),y(Math.max,t,e))}function b(t){var e=t.range;return e?_(e[0],e[1]):x(t.values,t._length)}function _(t,e){return!isNaN(t)&&isFinite(t)||(t=0),!isNaN(e)&&isFinite(e)||(e=0),t===e&&(0===t?(t-=1,e+=1):(t*=.9,e*=1.1)),[t,e]}function w(t){return t.dimensions.some(function(t){return t.brush.filterSpecified})}function k(t,e,r){var a=p(e),s=a.trace,l=d.convertTypedArray(a.lineColor),u=s.line,h={color:i(g.deselectedLineColor)},f=c.extractOpts(u),v=f.reversescale?c.flipScale(a.cscale):a.cscale,m=s.domain,y=s.dimensions,x=t.width,_=s.labelangle,w=s.labelside,k=s.labelfont,T=s.tickfont,A=s.rangefont,M=o.extendDeepNoArrays({},u,{color:l.map(n.scale.linear().domain(b({values:l,range:[f.min,f.max],_length:s._length}))),blockLineCount:g.blockLineCount,canvasOverdrag:g.overdrag*g.canvasPixelRatio}),S=Math.floor(x*(m.x[1]-m.x[0])),E=Math.floor(t.height*(m.y[1]-m.y[0])),C=t.margin||{l:80,r:80,t:100,b:80},L=S,P=E;return{key:r,colCount:y.filter(d.isVisible).length,dimensions:y,tickDistance:g.tickDistance,unitToColor:function(t){var e=t.map(function(t){return t[0]}),r=t.map(function(t){var e=i(t[1]);return n.rgb(\"rgb(\"+e[0]+\",\"+e[1]+\",\"+e[2]+\")\")}),a=\"rgb\".split(\"\").map(function(t){return n.scale.linear().clamp(!0).domain(e).range(r.map((i=t,function(t){return t[i]})));var i});return function(t){return a.map(function(e){return e(t)})}}(v),lines:M,deselectedLines:h,labelAngle:_,labelSide:w,labelFont:k,tickFont:T,rangeFont:A,layoutWidth:x,layoutHeight:t.height,domain:m,translateX:m.x[0]*x,translateY:t.height-m.y[1]*t.height,pad:C,canvasWidth:L*g.canvasPixelRatio+2*M.canvasOverdrag,canvasHeight:P*g.canvasPixelRatio,width:L,height:P,canvasPixelRatio:g.canvasPixelRatio}}function T(t,e,r){var i=r.width,a=r.height,s=r.dimensions,l=r.canvasPixelRatio,c=function(t){return i*t/Math.max(1,r.colCount-1)},u=g.verticalPadding/a,h=function(t,e){return n.scale.linear().range([e,t-e])}(a,g.verticalPadding),f={key:r.key,xScale:c,model:r,inBrushDrag:!1},p={};return f.dimensions=s.filter(d.isVisible).map(function(i,s){var m=function(t,e){return n.scale.linear().domain(b(t)).range([e,1-e])}(i,u),y=p[i.label];p[i.label]=(y||0)+1;var x=i.label+(y?\"__\"+y:\"\"),_=i.constraintrange,k=_&&_.length;k&&!Array.isArray(_[0])&&(_=[_]);var T=k?_.map(function(t){return t.map(m)}):[[-1/0,1/0]],A=i.values;A.length>i._length&&(A=A.slice(0,i._length));var M,S=i.tickvals;function E(t,e){return{val:t,text:M[e]}}function C(t,e){return t.val-e.val}if(Array.isArray(S)&&S.length){M=i.ticktext,Array.isArray(M)&&M.length?M.length>S.length?M=M.slice(0,S.length):S.length>M.length&&(S=S.slice(0,M.length)):M=S.map(n.format(i.tickformat));for(var L=1;L<S.length;L++)if(S[L]<S[L-1]){for(var P=S.map(E).sort(C),O=0;O<S.length;O++)S[O]=P[O].val,M[O]=P[O].text;break}}else S=void 0;return A=d.convertTypedArray(A),A=d.convertTypedArray(A),{key:x,label:i.label,tickFormat:i.tickformat,tickvals:S,ticktext:M,ordinal:d.isOrdinal(i),multiselect:i.multiselect,xIndex:s,crossfilterDimensionIndex:s,visibleIndex:i._index,height:a,values:A,paddedUnitValues:A.map(m),unitTickvals:S&&S.map(m),xScale:c,x:c(s),canvasX:c(s)*l,unitToPaddedPx:h,domainScale:function(t,e,r,i,a){var o,s,l=b(r);return i?n.scale.ordinal().domain(i.map((o=n.format(r.tickformat),s=a,s?function(t,e){var r=s[e];return null==r?o(t):r}:o))).range(i.map(function(r){var n=(r-l[0])/(l[1]-l[0]);return t-e+n*(2*e-t)})):n.scale.linear().domain(l).range([t-e,e])}(a,g.verticalPadding,i,S,M),ordinalScale:function(t){if(t.tickvals){var e=b(t);return n.scale.ordinal().domain(t.tickvals).range(t.tickvals.map(function(t){return(t-e[0])/(e[1]-e[0])}))}}(i),parent:f,model:r,brush:v.makeBrush(t,k,T,function(){t.linePickActive(!1)},function(){var e=f;e.focusLayer&&e.focusLayer.render(e.panels,!0);var r=w(e);!t.contextShown()&&r?(e.contextLayer&&e.contextLayer.render(e.panels,!0),t.contextShown(!0)):t.contextShown()&&!r&&(e.contextLayer&&e.contextLayer.render(e.panels,!0,!0),t.contextShown(!1))},function(r){if(f.focusLayer.render(f.panels,!0),f.pickLayer&&f.pickLayer.render(f.panels,!0),t.linePickActive(!0),e&&e.filterChanged){var n=m.invert,a=r.map(function(t){return t.map(n).sort(o.sorterAsc)}).sort(function(t,e){return t[0]-e[0]});e.filterChanged(f.key,i._index,a)}})}}),f}function A(t){t.classed(g.cn.axisExtentText,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"default\").style(\"user-select\",\"none\")}function M(t,e){var r=\"top\"===e?1:-1,n=t*Math.PI/180;return{dir:r,dx:Math.sin(n),dy:Math.cos(n),degrees:t}}function S(t,e){for(var r=e.panels||(e.panels=[]),n=t.data(),i=0;i<n.length-1;i++){var a=r[i]||(r[i]={}),o=n[i],s=n[i+1];a.dim0=o,a.dim1=s,a.canvasX=o.canvasX,a.panelSizeX=s.canvasX-o.canvasX,a.panelSizeY=e.model.canvasHeight,a.y=0,a.canvasY=0}}function E(t,e){return a.tickText(t._ax,e,!1).text}function C(t,e){if(t.ordinal)return\"\";var r=t.domainScale.domain(),n=r[e?r.length-1:0];return E(t.model.dimensions[t.visibleIndex],n)}e.exports=function(t,e,r,i){var c=t._fullLayout,u=c._toppaper,y=c._glcontainer;!function(t){for(var e=0;e<t.length;e++)for(var r=0;r<t[e].length;r++)for(var n=t[e][r].trace,i=n.dimensions,o=0;o<i.length;o++){var s=i[o].values,l=i[o]._ax;l&&(l.range?l.range=_(l.range[0],l.range[1]):l.range=x(s,n._length),l.dtick||(l.dtick=.01*(Math.abs(l.range[1]-l.range[0])||1)),l.tickformat=i[o].tickformat,a.calcTicks(l),l.cleanRange())}}(e);var b,L,P=(b=!0,L=!1,{linePickActive:function(t){return arguments.length?b=!!t:b},contextShown:function(t){return arguments.length?L=!!t:L}}),O=e.filter(function(t){return p(t).trace.visible}).map(k.bind(0,r)).map(T.bind(0,P,i));y.each(function(t,e){return o.extendFlat(t,O[e])});var z=y.selectAll(\".gl-canvas\").each(function(t){t.viewModel=O[0],t.model=t.viewModel?t.viewModel.model:null}),I=null;z.filter(function(t){return t.pick}).style(\"pointer-events\",\"auto\").on(\"mousemove\",function(t){if(P.linePickActive()&&t.lineLayer&&i&&i.hover){var e=n.event,r=this.width,a=this.height,o=n.mouse(this),s=o[0],l=o[1];if(s<0||l<0||s>=r||l>=a)return;var c=t.lineLayer.readPixel(s,a-1-l),u=0!==c[3],h=u?c[2]+256*(c[1]+256*c[0]):null,f={x:s,y:l,clientX:e.clientX,clientY:e.clientY,dataIndex:t.model.key,curveNumber:h};h!==I&&(u?i.hover(f):i.unhover&&i.unhover(f),I=h)}}),z.style(\"opacity\",function(t){return t.pick?0:1}),u.style(\"background\",\"rgba(255, 255, 255, 0)\");var D=u.selectAll(\".\"+g.cn.parcoords).data(O,h);D.exit().remove(),D.enter().append(\"g\").classed(g.cn.parcoords,!0).style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"none\"),D.attr(\"transform\",function(t){return\"translate(\"+t.model.translateX+\",\"+t.model.translateY+\")\"});var R=D.selectAll(\".\"+g.cn.parcoordsControlView).data(f,h);R.enter().append(\"g\").classed(g.cn.parcoordsControlView,!0),R.attr(\"transform\",function(t){return\"translate(\"+t.model.pad.l+\",\"+t.model.pad.t+\")\"});var F=R.selectAll(\".\"+g.cn.yAxis).data(function(t){return t.dimensions},h);F.enter().append(\"g\").classed(g.cn.yAxis,!0),R.each(function(t){S(F,t)}),z.each(function(t){if(t.viewModel){!t.lineLayer||i?t.lineLayer=m(this,t):t.lineLayer.update(t),(t.key||0===t.key)&&(t.viewModel[t.key]=t.lineLayer);var e=!t.context||i;t.lineLayer.render(t.viewModel.panels,e)}}),F.attr(\"transform\",function(t){return\"translate(\"+t.xScale(t.xIndex)+\", 0)\"}),F.call(n.behavior.drag().origin(function(t){return t}).on(\"drag\",function(t){var e=t.parent;P.linePickActive(!1),t.x=Math.max(-g.overdrag,Math.min(t.model.width+g.overdrag,n.event.x)),t.canvasX=t.x*t.model.canvasPixelRatio,F.sort(function(t,e){return t.x-e.x}).each(function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e.xIndex),e.canvasX=e.x*e.model.canvasPixelRatio}),S(F,e),F.filter(function(e){return 0!==Math.abs(t.xIndex-e.xIndex)}).attr(\"transform\",function(t){return\"translate(\"+t.xScale(t.xIndex)+\", 0)\"}),n.select(this).attr(\"transform\",\"translate(\"+t.x+\", 0)\"),F.each(function(r,n,i){i===t.parent.key&&(e.dimensions[n]=r)}),e.contextLayer&&e.contextLayer.render(e.panels,!1,!w(e)),e.focusLayer.render&&e.focusLayer.render(e.panels)}).on(\"dragend\",function(t){var e=t.parent;t.x=t.xScale(t.xIndex),t.canvasX=t.x*t.model.canvasPixelRatio,S(F,e),n.select(this).attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),e.contextLayer&&e.contextLayer.render(e.panels,!1,!w(e)),e.focusLayer&&e.focusLayer.render(e.panels),e.pickLayer&&e.pickLayer.render(e.panels,!0),P.linePickActive(!0),i&&i.axesMoved&&i.axesMoved(e.key,e.dimensions.map(function(t){return t.crossfilterDimensionIndex}))})),F.exit().remove();var B=F.selectAll(\".\"+g.cn.axisOverlays).data(f,h);B.enter().append(\"g\").classed(g.cn.axisOverlays,!0),B.selectAll(\".\"+g.cn.axis).remove();var N=B.selectAll(\".\"+g.cn.axis).data(f,h);N.enter().append(\"g\").classed(g.cn.axis,!0),N.each(function(t){var e=t.model.height/t.model.tickDistance,r=t.domainScale,i=r.domain();n.select(this).call(n.svg.axis().orient(\"left\").tickSize(4).outerTickSize(2).ticks(e,t.tickFormat).tickValues(t.ordinal?i:null).tickFormat(function(e){return d.isOrdinal(t)?e:E(t.model.dimensions[t.visibleIndex],e)}).scale(r)),l.font(N.selectAll(\"text\"),t.model.tickFont)}),N.selectAll(\".domain, .tick>line\").attr(\"fill\",\"none\").attr(\"stroke\",\"black\").attr(\"stroke-opacity\",.25).attr(\"stroke-width\",\"1px\"),N.selectAll(\"text\").style(\"text-shadow\",\"1px 1px 1px #fff, -1px -1px 1px #fff, 1px -1px 1px #fff, -1px 1px 1px #fff\").style(\"cursor\",\"default\").style(\"user-select\",\"none\");var j=B.selectAll(\".\"+g.cn.axisHeading).data(f,h);j.enter().append(\"g\").classed(g.cn.axisHeading,!0);var U=j.selectAll(\".\"+g.cn.axisTitle).data(f,h);U.enter().append(\"text\").classed(g.cn.axisTitle,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"ew-resize\").style(\"user-select\",\"none\").style(\"pointer-events\",\"auto\"),U.text(function(t){return t.label}).each(function(e){var r=n.select(this);l.font(r,e.model.labelFont),s.convertToTspans(r,t)}).attr(\"transform\",function(t){var e=M(t.model.labelAngle,t.model.labelSide),r=g.axisTitleOffset;return(e.dir>0?\"\":\"translate(0,\"+(2*r+t.model.height)+\")\")+\"rotate(\"+e.degrees+\")translate(\"+-r*e.dx+\",\"+-r*e.dy+\")\"}).attr(\"text-anchor\",function(t){var e=M(t.model.labelAngle,t.model.labelSide);return 2*Math.abs(e.dx)>Math.abs(e.dy)?e.dir*e.dx<0?\"start\":\"end\":\"middle\"});var V=B.selectAll(\".\"+g.cn.axisExtent).data(f,h);V.enter().append(\"g\").classed(g.cn.axisExtent,!0);var q=V.selectAll(\".\"+g.cn.axisExtentTop).data(f,h);q.enter().append(\"g\").classed(g.cn.axisExtentTop,!0),q.attr(\"transform\",\"translate(0,\"+-g.axisExtentOffset+\")\");var H=q.selectAll(\".\"+g.cn.axisExtentTopText).data(f,h);H.enter().append(\"text\").classed(g.cn.axisExtentTopText,!0).call(A),H.text(function(t){return C(t,!0)}).each(function(t){l.font(n.select(this),t.model.rangeFont)});var G=V.selectAll(\".\"+g.cn.axisExtentBottom).data(f,h);G.enter().append(\"g\").classed(g.cn.axisExtentBottom,!0),G.attr(\"transform\",function(t){return\"translate(0,\"+(t.model.height+g.axisExtentOffset)+\")\"});var Y=G.selectAll(\".\"+g.cn.axisExtentBottomText).data(f,h);Y.enter().append(\"text\").classed(g.cn.axisExtentBottomText,!0).attr(\"dy\",\"0.75em\").call(A),Y.text(function(t){return C(t,!1)}).each(function(t){l.font(n.select(this),t.model.rangeFont)}),v.ensureAxisBrush(B)}},{\"../../components/colorscale\":605,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/gup\":717,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"./axisbrush\":1075,\"./constants\":1078,\"./helpers\":1080,\"./lines\":1082,\"color-rgba\":122,d3:163}],1085:[function(t,e,r){\"use strict\";var n=t(\"./parcoords\"),i=t(\"../../lib/prepare_regl\"),a=t(\"./helpers\").isVisible;function o(t,e,r){var n=e.indexOf(r),i=t.indexOf(n);return-1===i&&(i+=e.length),i}e.exports=function(t,e){var r=t._fullLayout;if(i(t)){var s={},l={},c={},u={},h=r._size;e.forEach(function(e,r){var n=e[0].trace;c[r]=n.index;var i=u[r]=n._fullInput.index;s[r]=t.data[i].dimensions,l[r]=t.data[i].dimensions.slice()});n(t,e,{width:h.w,height:h.h,margin:{t:h.t,r:h.r,b:h.b,l:h.l}},{filterChanged:function(e,n,i){var a=l[e][n],o=i.map(function(t){return t.slice()}),s=\"dimensions[\"+n+\"].constraintrange\",h=r._tracePreGUI[t._fullData[c[e]]._fullInput.uid];if(void 0===h[s]){var f=a.constraintrange;h[s]=f||null}var p=t._fullData[c[e]].dimensions[n];o.length?(1===o.length&&(o=o[0]),a.constraintrange=o,p.constraintrange=o.slice(),o=[o]):(delete a.constraintrange,delete p.constraintrange,o=null);var d={};d[s]=o,t.emit(\"plotly_restyle\",[d,[u[e]]])},hover:function(e){t.emit(\"plotly_hover\",e)},unhover:function(e){t.emit(\"plotly_unhover\",e)},axesMoved:function(e,r){var n=function(t,e){return function(r,n){return o(t,e,r)-o(t,e,n)}}(r,l[e].filter(a));s[e].sort(n),l[e].filter(function(t){return!a(t)}).sort(function(t){return l[e].indexOf(t)}).forEach(function(t){s[e].splice(s[e].indexOf(t),1),s[e].splice(l[e].indexOf(t),0,t)}),t.emit(\"plotly_restyle\",[{dimensions:[s[e]]},[u[e]]])}})}}},{\"../../lib/prepare_regl\":732,\"./helpers\":1080,\"./parcoords\":1084}],1086:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../plots/domain\").attributes,a=t(\"../../plots/font_attributes\"),o=t(\"../../components/color/attributes\"),s=t(\"../../components/fx/hovertemplate_attributes\"),l=t(\"../../lib/extend\").extendFlat,c=a({editType:\"plot\",arrayOk:!0,colorEditType:\"plot\"});e.exports={labels:{valType:\"data_array\",editType:\"calc\"},label0:{valType:\"number\",dflt:0,editType:\"calc\"},dlabel:{valType:\"number\",dflt:1,editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},marker:{colors:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:o.defaultLine,arrayOk:!0,editType:\"style\"},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0,editType:\"style\"},editType:\"calc\"},editType:\"calc\"},text:{valType:\"data_array\",editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"value\",\"percent\"],extras:[\"none\"],editType:\"calc\"},hoverinfo:l({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:s({},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"auto\",arrayOk:!0,editType:\"plot\"},textfont:l({},c,{}),insidetextfont:l({},c,{}),outsidetextfont:l({},c,{}),title:{text:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:l({},c,{}),position:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"plot\"},editType:\"plot\"},domain:i({name:\"pie\",trace:!0,editType:\"calc\"}),hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},sort:{valType:\"boolean\",dflt:!0,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"number\",min:-360,max:360,dflt:0,editType:\"calc\"},pull:{valType:\"number\",min:0,max:1,dflt:0,arrayOk:!0,editType:\"calc\"},_deprecated:{title:{valType:\"string\",dflt:\"\",editType:\"calc\"},titlefont:l({},c,{}),titleposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"calc\"}}}},{\"../../components/color/attributes\":592,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1087:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData;r.name=\"pie\",r.plot=function(t){var e=n.getModule(\"pie\"),r=i(t.calcdata,e)[0];e.plot(t,r)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"pie\"),a=e._has&&e._has(\"pie\");i&&!a&&n._pielayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],1088:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"tinycolor2\"),o=t(\"../../components/color\"),s=t(\"./helpers\"),l=t(\"../../lib\").isValidTextValue,c={};function u(t){return function(e,r){return!!e&&(!!(e=a(e)).isValid()&&(e=o.addOpacity(e,e.getAlpha()),t[r]||(t[r]=e),e))}}function h(t,e){var r,n=JSON.stringify(t),i=e[n];if(!i){for(i=t.slice(),r=0;r<t.length;r++)i.push(a(t[r]).lighten(20).toHexString());for(r=0;r<t.length;r++)i.push(a(t[r]).darken(20).toHexString());e[n]=i}return i}e.exports={calc:function(t,e){var r,a,o=[],c=t._fullLayout,h=c.hiddenlabels||[],f=e.labels,p=e.marker.colors||[],d=e.values,g=i(d)&&d.length;if(e.dlabel)for(f=new Array(d.length),r=0;r<d.length;r++)f[r]=String(e.label0+r*e.dlabel);var v={},m=u(c[\"_\"+e.type+\"colormap\"]),y=(g?d:f).length,x=0,b=!1;for(r=0;r<y;r++){var _,w,k;if(g){if(_=d[r],!n(_))continue;if((_=+_)<0)continue}else _=1;void 0!==(w=f[r])&&\"\"!==w||(w=r);var T=v[w=String(w)];void 0===T?(v[w]=o.length,(k=-1!==h.indexOf(w))||(x+=_),o.push({v:_,label:w,color:m(p[r],w),i:r,pts:[r],hidden:k})):(b=!0,(a=o[T]).v+=_,a.pts.push(r),a.hidden||(x+=_),!1===a.color&&p[r]&&(a.color=m(p[r],w)))}(\"funnelarea\"===e.type?b:e.sort)&&o.sort(function(t,e){return e.v-t.v}),o[0]&&(o[0].vTotal=x);var A=e.textinfo;if(A&&\"none\"!==A){var M,S=A.split(\"+\"),E=function(t){return-1!==S.indexOf(t)},C=E(\"label\"),L=E(\"text\"),P=E(\"value\"),O=E(\"percent\"),z=c.separators;for(r=0;r<o.length;r++){if(a=o[r],M=C?[a.label]:[],L){var I=s.getFirstFilled(e.text,a.pts);l(I)&&M.push(I)}P&&M.push(s.formatPieValue(a.v,z)),O&&M.push(s.formatPiePercent(a.v/x,z)),a.text=M.join(\"<br>\")}}return o},crossTraceCalc:function(t,e){var r=(e||{}).type;r||(r=\"pie\");var n=t._fullLayout,i=t.calcdata,a=n[r+\"colorway\"],o=n[\"_\"+r+\"colormap\"];n[\"extend\"+r+\"colors\"]&&(a=h(a,c));for(var s=0,l=0;l<i.length;l++){var u=i[l];if(u[0].trace.type===r)for(var f=0;f<u.length;f++){var p=u[f];!1===p.color&&(o[p.label]?p.color=o[p.label]:(o[p.label]=p.color=a[s%a.length],s++))}}},makePullColorFn:u,generateExtendedColors:h}},{\"../../components/color\":593,\"../../lib\":719,\"./helpers\":1091,\"fast-isnumeric\":225,tinycolor2:537}],1089:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}var c,u=l(\"values\"),h=n.isArrayOrTypedArray(u),f=l(\"labels\");if(Array.isArray(f)?(c=f.length,h&&(c=Math.min(c,u.length))):h&&(c=u.length,l(\"label0\"),l(\"dlabel\")),c){e._length=c,l(\"marker.line.width\")&&l(\"marker.line.color\"),l(\"marker.colors\"),l(\"scalegroup\");var p=l(\"text\"),d=l(\"textinfo\",Array.isArray(p)?\"text+percent\":\"percent\");if(l(\"hovertext\"),l(\"hovertemplate\"),d&&\"none\"!==d){var g=l(\"textposition\");o(t,e,s,l,g,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}a(e,s,l);var v=l(\"hole\");if(l(\"title.text\")){var m=l(\"title.position\",v?\"middle center\":\"top center\");v||\"middle center\"!==m||(e.title.position=\"top center\"),n.coerceFont(l,\"title.font\",s.font)}l(\"sort\"),l(\"direction\"),l(\"rotation\"),l(\"pull\")}else e.visible=!1}},{\"../../lib\":719,\"../../plots/domain\":792,\"../bar/defaults\":861,\"./attributes\":1086}],1090:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/helpers\").appendArrayMultiPointValues;e.exports=function(t,e){var r={curveNumber:e.index,pointNumbers:t.pts,data:e._input,fullData:e,label:t.label,color:t.color,value:t.v,percent:t.percent,text:t.text,v:t.v};return 1===t.pts.length&&(r.pointNumber=r.i=t.pts[0]),n(r,e,t.pts),\"funnelarea\"===e.type&&(delete r.v,delete r.i),r}},{\"../../components/fx/helpers\":628}],1091:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");r.formatPiePercent=function(t,e){var r=(100*t).toPrecision(3);return-1!==r.lastIndexOf(\".\")&&(r=r.replace(/[.]?0+$/,\"\")),n.numSeparate(r,e)+\"%\"},r.formatPieValue=function(t,e){var r=t.toPrecision(10);return-1!==r.lastIndexOf(\".\")&&(r=r.replace(/[.]?0+$/,\"\")),n.numSeparate(r,e)},r.getFirstFilled=function(t,e){if(Array.isArray(t))for(var r=0;r<e.length;r++){var n=t[e[r]];if(n||0===n)return n}},r.castOption=function(t,e){return Array.isArray(t)?r.getFirstFilled(t,e):t||void 0}},{\"../../lib\":719}],1092:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),layoutAttributes:t(\"./layout_attributes\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\"),styleOne:t(\"./style_one\"),moduleType:\"trace\",name:\"pie\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"pie\",\"showLegend\"],meta:{}}},{\"./attributes\":1086,\"./base_plot\":1087,\"./calc\":1088,\"./defaults\":1089,\"./layout_attributes\":1093,\"./layout_defaults\":1094,\"./plot\":1095,\"./style\":1096,\"./style_one\":1097}],1093:[function(t,e,r){\"use strict\";e.exports={hiddenlabels:{valType:\"data_array\",editType:\"calc\"},piecolorway:{valType:\"colorlist\",editType:\"calc\"},extendpiecolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1094:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"piecolorway\",e.colorway),r(\"extendpiecolors\")}},{\"../../lib\":719,\"./layout_attributes\":1093}],1095:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/fx\"),a=t(\"../../components/color\"),o=t(\"../../components/drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"./helpers\"),u=t(\"./event_data\");function h(t,e,r){var a=r[0],o=a.trace,l=a.cx,h=a.cy;\"_hasHoverLabel\"in o||(o._hasHoverLabel=!1),\"_hasHoverEvent\"in o||(o._hasHoverEvent=!1),t.on(\"mouseover\",function(t){var r=e._fullLayout,f=e._fullData[o.index];if(!e._dragging&&!1!==r.hovermode){var p=f.hoverinfo;if(Array.isArray(p)&&(p=i.castHoverinfo({hoverinfo:[c.castOption(p,t.pts)],_module:o._module},r,0)),\"all\"===p&&(p=\"label+text+value+percent+name\"),f.hovertemplate||\"none\"!==p&&\"skip\"!==p&&p){var d=t.rInscribed||0,g=l+t.pxmid[0]*(1-d),v=h+t.pxmid[1]*(1-d),m=r.separators,y=[];if(p&&-1!==p.indexOf(\"label\")&&y.push(t.label),t.text=c.castOption(f.hovertext||f.text,t.pts),p&&-1!==p.indexOf(\"text\")){var x=t.text;s.isValidTextValue(x)&&y.push(x)}t.value=t.v,t.valueLabel=c.formatPieValue(t.v,m),p&&-1!==p.indexOf(\"value\")&&y.push(t.valueLabel),t.percent=t.v/a.vTotal,t.percentLabel=c.formatPiePercent(t.percent,m),p&&-1!==p.indexOf(\"percent\")&&y.push(t.percentLabel);var b=f.hoverlabel,_=b.font;i.loneHover({trace:o,x0:g-d*a.r,x1:g+d*a.r,y:v,text:y.join(\"<br>\"),name:f.hovertemplate||-1!==p.indexOf(\"name\")?f.name:void 0,idealAlign:t.pxmid[0]<0?\"left\":\"right\",color:c.castOption(b.bgcolor,t.pts)||t.color,borderColor:c.castOption(b.bordercolor,t.pts),fontFamily:c.castOption(_.family,t.pts),fontSize:c.castOption(_.size,t.pts),fontColor:c.castOption(_.color,t.pts),nameLength:c.castOption(b.namelength,t.pts),textAlign:c.castOption(b.align,t.pts),hovertemplate:c.castOption(f.hovertemplate,t.pts),hovertemplateLabels:t,eventData:[u(t,f)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e}),o._hasHoverLabel=!0}o._hasHoverEvent=!0,e.emit(\"plotly_hover\",{points:[u(t,f)],event:n.event})}}),t.on(\"mouseout\",function(t){var r=e._fullLayout,a=e._fullData[o.index],s=n.select(this).datum();o._hasHoverEvent&&(t.originalEvent=n.event,e.emit(\"plotly_unhover\",{points:[u(s,a)],event:n.event}),o._hasHoverEvent=!1),o._hasHoverLabel&&(i.loneUnhover(r._hoverlayer.node()),o._hasHoverLabel=!1)}),t.on(\"click\",function(t){var r=e._fullLayout,a=e._fullData[o.index];e._dragging||!1===r.hovermode||(e._hoverdata=[u(t,a)],i.click(e,n.event))})}function f(t,e,r){var n=c.castOption(t.insidetextfont.color,e.pts);!n&&t._input.textfont&&(n=c.castOption(t._input.textfont.color,e.pts));var i=c.castOption(t.insidetextfont.family,e.pts)||c.castOption(t.textfont.family,e.pts)||r.family,o=c.castOption(t.insidetextfont.size,e.pts)||c.castOption(t.textfont.size,e.pts)||r.size;return{color:n||a.contrast(e.color),family:i,size:o}}function p(t,e){for(var r,n,i=0;i<t.length;i++)if((n=(r=t[i][0]).trace).title.text){var a=n.title.text;n._meta&&(a=s.templateString(a,n._meta));var c=o.tester.append(\"text\").attr(\"data-notex\",1).text(a).call(o.font,n.title.font).call(l.convertToTspans,e),u=o.bBox(c.node(),!0);r.titleBox={width:u.width,height:u.height},c.remove()}}function d(t,e,r){var n=Math.sqrt(t.width*t.width+t.height*t.height),i=t.width/t.height,a=e.halfangle,o=e.ring,s=e.rInscribed,l=r.r||e.rpx1,c={scale:s*l*2/n,rCenter:1-s,rotate:0};if(c.scale>=1)return c;var u=i+1/(2*Math.tan(a)),h=l*Math.min(1/(Math.sqrt(u*u+.5)+u),o/(Math.sqrt(i*i+o/2)+i)),f={scale:2*h/t.height,rCenter:Math.cos(h/l)-h*i/l,rotate:(180/Math.PI*e.midangle+720)%180-90},p=1/i,d=p+1/(2*Math.tan(a)),g=l*Math.min(1/(Math.sqrt(d*d+.5)+d),o/(Math.sqrt(p*p+o/2)+p)),v={scale:2*g/t.width,rCenter:Math.cos(g/l)-g/i/l,rotate:(180/Math.PI*e.midangle+810)%180-90},m=v.scale>f.scale?v:f;return c.scale<1&&m.scale>c.scale?m:c}function g(t,e){return t.v!==e.vTotal||e.trace.hole?Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2):1}function v(t,e){var r=e.pxmid[0],n=e.pxmid[1],i=t.width/2,a=t.height/2;return r<0&&(i*=-1),n<0&&(a*=-1),{scale:1,rCenter:1,rotate:0,x:i+Math.abs(a)*(i>0?1:-1)/2,y:a/(1+r*r/(n*n)),outside:!0}}function m(t,e){var r,n,i,a=t.trace,o={x:t.cx,y:t.cy},s={tx:0,ty:0};s.ty+=a.title.font.size,i=x(a),-1!==a.title.position.indexOf(\"top\")?(o.y-=(1+i)*t.r,s.ty-=t.titleBox.height):-1!==a.title.position.indexOf(\"bottom\")&&(o.y+=(1+i)*t.r);var l,c,u=(l=t.r,c=t.trace.aspectratio,l/(void 0===c?1:c)),h=e.w*(a.domain.x[1]-a.domain.x[0])/2;return-1!==a.title.position.indexOf(\"left\")?(h+=u,o.x-=(1+i)*u,s.tx+=t.titleBox.width/2):-1!==a.title.position.indexOf(\"center\")?h*=2:-1!==a.title.position.indexOf(\"right\")&&(h+=u,o.x+=(1+i)*u,s.tx-=t.titleBox.width/2),r=h/t.titleBox.width,n=y(t,e)/t.titleBox.height,{x:o.x,y:o.y,scale:Math.min(r,n),tx:s.tx,ty:s.ty}}function y(t,e){var r=t.trace,n=e.h*(r.domain.y[1]-r.domain.y[0]);return Math.min(t.titleBox.height,n/2)}function x(t){var e,r=t.pull;if(!r)return 0;if(Array.isArray(r))for(r=0,e=0;e<t.pull.length;e++)t.pull[e]>r&&(r=t.pull[e]);return r}function b(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n][0],a=i.trace,o=a.domain,s=e.w*(o.x[1]-o.x[0]),l=e.h*(o.y[1]-o.y[0]);a.title.text&&\"middle center\"!==a.title.position&&(l-=y(i,e));var c=s/2,u=l/2;\"funnelarea\"!==a.type||a.scalegroup||(u/=a.aspectratio),i.r=Math.min(c,u)/(1+x(a)),i.cx=e.l+e.w*(a.domain.x[1]+a.domain.x[0])/2,i.cy=e.t+e.h*(1-a.domain.y[0])-l/2,a.title.text&&-1!==a.title.position.indexOf(\"bottom\")&&(i.cy-=y(i,e)),a.scalegroup&&-1===r.indexOf(a.scalegroup)&&r.push(a.scalegroup)}!function(t,e){for(var r,n,i,a=0;a<e.length;a++){var o=1/0,s=e[a];for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var l;if(\"pie\"===i.type)l=r.r*r.r;else if(\"funnelarea\"===i.type){var c,u;i.aspectratio>1?(c=r.r,u=c/i.aspectratio):(u=r.r,c=u*i.aspectratio),c*=(1+i.baseratio)/2,l=c*u}o=Math.min(o,l/r.vTotal)}for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var h=o*r.vTotal;\"funnelarea\"===i.type&&(h/=(1+i.baseratio)/2,h/=i.aspectratio),r.r=Math.sqrt(h)}}}(t,r)}e.exports={plot:function(t,e){var r=t._fullLayout;p(e,t),b(e,r._size);var i=s.makeTraceGroups(r._pielayer,e,\"trace\").each(function(e){var i=n.select(this),u=e[0],p=u.trace;!function(t){var e,r,n,i=t[0],a=i.trace,o=a.rotation*Math.PI/180,s=2*Math.PI/i.vTotal,l=\"px0\",c=\"px1\";if(\"counterclockwise\"===a.direction){for(e=0;e<t.length&&t[e].hidden;e++);if(e===t.length)return;o+=s*t[e].v,s*=-1,l=\"px1\",c=\"px0\"}function u(t){return[i.r*Math.sin(t),-i.r*Math.cos(t)]}for(n=u(o),e=0;e<t.length;e++)(r=t[e]).hidden||(r[l]=n,o+=s*r.v/2,r.pxmid=u(o),r.midangle=o,o+=s*r.v/2,n=u(o),r[c]=n,r.largeArc=r.v>i.vTotal/2?1:0,r.halfangle=Math.PI*Math.min(r.v/i.vTotal,.5),r.ring=1-a.hole,r.rInscribed=g(r,i))}(e),i.attr(\"stroke-linejoin\",\"round\"),i.each(function(){var i=n.select(this).selectAll(\"g.slice\").data(e);i.enter().append(\"g\").classed(\"slice\",!0),i.exit().remove();var g=[[[],[]],[[],[]]],y=!1;i.each(function(r){if(r.hidden)n.select(this).selectAll(\"path,g\").remove();else{r.pointNumber=r.i,r.curveNumber=p.index,g[r.pxmid[1]<0?0:1][r.pxmid[0]<0?0:1].push(r);var i=u.cx,a=u.cy,m=n.select(this),x=m.selectAll(\"path.surface\").data([r]);if(x.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),m.call(h,t,e),p.pull){var b=+c.castOption(p.pull,r.pts)||0;b>0&&(i+=b*r.pxmid[0],a+=b*r.pxmid[1])}r.cxFinal=i,r.cyFinal=a;var _=p.hole;if(r.v===u.vTotal){var w=\"M\"+(i+r.px0[0])+\",\"+(a+r.px0[1])+S(r.px0,r.pxmid,!0,1)+S(r.pxmid,r.px0,!0,1)+\"Z\";_?x.attr(\"d\",\"M\"+(i+_*r.px0[0])+\",\"+(a+_*r.px0[1])+S(r.px0,r.pxmid,!1,_)+S(r.pxmid,r.px0,!1,_)+\"Z\"+w):x.attr(\"d\",w)}else{var k=S(r.px0,r.px1,!0,1);if(_){var T=1-_;x.attr(\"d\",\"M\"+(i+_*r.px1[0])+\",\"+(a+_*r.px1[1])+S(r.px1,r.px0,!1,_)+\"l\"+T*r.px0[0]+\",\"+T*r.px0[1]+k+\"Z\")}else x.attr(\"d\",\"M\"+i+\",\"+a+\"l\"+r.px0[0]+\",\"+r.px0[1]+k+\"Z\")}var A=c.castOption(p.textposition,r.pts),M=m.selectAll(\"g.slicetext\").data(r.text&&\"none\"!==A?[0]:[]);M.enter().append(\"g\").classed(\"slicetext\",!0),M.exit().remove(),M.each(function(){var e=s.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)});e.text(r.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(o.font,\"outside\"===A?function(t,e,r){var n=c.castOption(t.outsidetextfont.color,e.pts)||c.castOption(t.textfont.color,e.pts)||r.color,i=c.castOption(t.outsidetextfont.family,e.pts)||c.castOption(t.textfont.family,e.pts)||r.family,a=c.castOption(t.outsidetextfont.size,e.pts)||c.castOption(t.textfont.size,e.pts)||r.size;return{color:n,family:i,size:a}}(p,r,t._fullLayout.font):f(p,r,t._fullLayout.font)).call(l.convertToTspans,t);var h,g=o.bBox(e.node());\"outside\"===A?h=v(g,r):(h=d(g,r,u),\"auto\"===A&&h.scale<1&&(e.call(o.font,p.outsidetextfont),p.outsidetextfont.family===p.insidetextfont.family&&p.outsidetextfont.size===p.insidetextfont.size||(g=o.bBox(e.node())),h=v(g,r)));var m=i+r.pxmid[0]*h.rCenter+(h.x||0),x=a+r.pxmid[1]*h.rCenter+(h.y||0);h.outside&&(r.yLabelMin=x-g.height/2,r.yLabelMid=x,r.yLabelMax=x+g.height/2,r.labelExtraX=0,r.labelExtraY=0,y=!0),e.attr(\"transform\",\"translate(\"+m+\",\"+x+\")\"+(h.scale<1?\"scale(\"+h.scale+\")\":\"\")+(h.rotate?\"rotate(\"+h.rotate+\")\":\"\")+\"translate(\"+-(g.left+g.right)/2+\",\"+-(g.top+g.bottom)/2+\")\")})}function S(t,e,n,i){var a=i*(e[0]-t[0]),o=i*(e[1]-t[1]);return\"a\"+i*u.r+\",\"+i*u.r+\" 0 \"+r.largeArc+(n?\" 1 \":\" 0 \")+a+\",\"+o}});var x=n.select(this).selectAll(\"g.titletext\").data(p.title.text?[0]:[]);x.enter().append(\"g\").classed(\"titletext\",!0),x.exit().remove(),x.each(function(){var e,i=s.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),a=p.title.text;p._meta&&(a=s.templateString(a,p._meta)),i.text(a).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(o.font,p.title.font).call(l.convertToTspans,t),e=\"middle center\"===p.title.position?function(t){var e=Math.sqrt(t.titleBox.width*t.titleBox.width+t.titleBox.height*t.titleBox.height);return{x:t.cx,y:t.cy,scale:t.trace.hole*t.r*2/e,tx:0,ty:-t.titleBox.height/2+t.trace.title.font.size}}(u):m(u,r._size),i.attr(\"transform\",\"translate(\"+e.x+\",\"+e.y+\")\"+(e.scale<1?\"scale(\"+e.scale+\")\":\"\")+\"translate(\"+e.tx+\",\"+e.ty+\")\")}),y&&function(t,e){var r,n,i,a,o,s,l,u,h,f,p,d,g;function v(t,e){return t.pxmid[1]-e.pxmid[1]}function m(t,e){return e.pxmid[1]-t.pxmid[1]}function y(t,r){r||(r={});var i,u,h,p,d,g,v=r.labelExtraY+(n?r.yLabelMax:r.yLabelMin),m=n?t.yLabelMin:t.yLabelMax,y=n?t.yLabelMax:t.yLabelMin,x=t.cyFinal+o(t.px0[1],t.px1[1]),b=v-m;if(b*l>0&&(t.labelExtraY=b),Array.isArray(e.pull))for(u=0;u<f.length;u++)(h=f[u])===t||(c.castOption(e.pull,t.pts)||0)>=(c.castOption(e.pull,h.pts)||0)||((t.pxmid[1]-h.pxmid[1])*l>0?(p=h.cyFinal+o(h.px0[1],h.px1[1]),(b=p-m-t.labelExtraY)*l>0&&(t.labelExtraY+=b)):(y+t.labelExtraY-x)*l>0&&(i=3*s*Math.abs(u-f.indexOf(t)),d=h.cxFinal+a(h.px0[0],h.px1[0]),(g=d+i-(t.cxFinal+t.pxmid[0])-t.labelExtraX)*s>0&&(t.labelExtraX+=g)))}for(n=0;n<2;n++)for(i=n?v:m,o=n?Math.max:Math.min,l=n?1:-1,r=0;r<2;r++){for(a=r?Math.max:Math.min,s=r?1:-1,(u=t[n][r]).sort(i),h=t[1-n][r],f=h.concat(u),d=[],p=0;p<u.length;p++)void 0!==u[p].yLabelMid&&d.push(u[p]);for(g=!1,p=0;n&&p<h.length;p++)if(void 0!==h[p].yLabelMid){g=h[p];break}for(p=0;p<d.length;p++){var x=p&&d[p-1];g&&!p&&(x=g),y(d[p],x)}}}(g,p),function(t,e){t.each(function(t){var r=n.select(this);if(t.labelExtraX||t.labelExtraY){var i=r.select(\"g.slicetext text\");i.attr(\"transform\",\"translate(\"+t.labelExtraX+\",\"+t.labelExtraY+\")\"+i.attr(\"transform\"));var o=t.cxFinal+t.pxmid[0],l=t.cyFinal+t.pxmid[1],c=\"M\"+o+\",\"+l,u=(t.yLabelMax-t.yLabelMin)*(t.pxmid[0]<0?-1:1)/4;if(t.labelExtraX){var h=t.labelExtraX*t.pxmid[1]/t.pxmid[0],f=t.yLabelMid+t.labelExtraY-(t.cyFinal+t.pxmid[1]);Math.abs(h)>Math.abs(f)?c+=\"l\"+f*t.pxmid[0]/t.pxmid[1]+\",\"+f+\"H\"+(o+t.labelExtraX+u):c+=\"l\"+t.labelExtraX+\",\"+h+\"v\"+(f-h)+\"h\"+u}else c+=\"V\"+(t.yLabelMid+t.labelExtraY)+\"h\"+u;s.ensureSingle(r,\"path\",\"textline\").call(a.stroke,e.outsidetextfont.color).attr({\"stroke-width\":Math.min(2,e.outsidetextfont.size/8),d:c,fill:\"none\"})}else r.select(\"path.textline\").remove()})}(i,p)})});setTimeout(function(){i.selectAll(\"tspan\").each(function(){var t=n.select(this);t.attr(\"dy\")&&t.attr(\"dy\",t.attr(\"dy\"))})},0)},transformInsideText:d,determineInsideTextFont:f,positionTitleOutside:m,prerenderTitles:p,layoutAreas:b,attachFxHandlers:h}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"./event_data\":1090,\"./helpers\":1091,d3:163}],1096:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./style_one\");e.exports=function(t){t._fullLayout._pielayer.selectAll(\".trace\").each(function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each(function(t){n.select(this).call(i,t,e)})})}},{\"./style_one\":1097,d3:163}],1097:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./helpers\").castOption;e.exports=function(t,e,r){var a=r.marker.line,o=i(a.color,e.pts)||n.defaultLine,s=i(a.width,e.pts)||0;t.style(\"stroke-width\",s).call(n.fill,e.color).call(n.stroke,o)}},{\"../../components/color\":593,\"./helpers\":1091}],1098:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\");e.exports={x:n.x,y:n.y,xy:{valType:\"data_array\",editType:\"calc\"},indices:{valType:\"data_array\",editType:\"calc\"},xbounds:{valType:\"data_array\",editType:\"calc\"},ybounds:{valType:\"data_array\",editType:\"calc\"},text:n.text,marker:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,arrayOk:!1,editType:\"calc\"},blend:{valType:\"boolean\",dflt:null,editType:\"calc\"},sizemin:{valType:\"number\",min:.1,max:2,dflt:.5,editType:\"calc\"},sizemax:{valType:\"number\",min:.1,dflt:20,editType:\"calc\"},border:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},arearatio:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},transforms:void 0}},{\"../scatter/attributes\":1112}],1099:[function(t,e,r){\"use strict\";var n=t(\"gl-pointcloud2d\"),i=t(\"../../lib/str2rgbarray\"),a=t(\"../../plots/cartesian/autorange\").findExtremes,o=t(\"../scatter/get_trace_color\");function s(t,e){this.scene=t,this.uid=e,this.type=\"pointcloud\",this.pickXData=[],this.pickYData=[],this.xData=[],this.yData=[],this.textLabels=[],this.color=\"rgb(0, 0, 0)\",this.name=\"\",this.hoverinfo=\"all\",this.idToIndex=new Int32Array(0),this.bounds=[0,0,0,0],this.pointcloudOptions={positions:new Float32Array(0),idToIndex:this.idToIndex,sizemin:.5,sizemax:12,color:[0,0,0,1],areaRatio:1,borderColor:[0,0,0,1]},this.pointcloud=n(t.glplot,this.pointcloudOptions),this.pointcloud._trace=this}var l=s.prototype;l.handlePick=function(t){var e=this.idToIndex[t.pointId];return{trace:this,dataCoord:t.dataCoord,traceCoord:this.pickXYData?[this.pickXYData[2*e],this.pickXYData[2*e+1]]:[this.pickXData[e],this.pickYData[e]],textLabel:Array.isArray(this.textLabels)?this.textLabels[e]:this.textLabels,color:this.color,name:this.name,pointIndex:e,hoverinfo:this.hoverinfo}},l.update=function(t){this.index=t.index,this.textLabels=t.text,this.name=t.name,this.hoverinfo=t.hoverinfo,this.bounds=[1/0,1/0,-1/0,-1/0],this.updateFast(t),this.color=o(t,{})},l.updateFast=function(t){var e,r,n,o,s,l,c=this.xData=this.pickXData=t.x,u=this.yData=this.pickYData=t.y,h=this.pickXYData=t.xy,f=t.xbounds&&t.ybounds,p=t.indices,d=this.bounds;if(h){if(n=h,e=h.length>>>1,f)d[0]=t.xbounds[0],d[2]=t.xbounds[1],d[1]=t.ybounds[0],d[3]=t.ybounds[1];else for(l=0;l<e;l++)o=n[2*l],s=n[2*l+1],o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);if(p)r=p;else for(r=new Int32Array(e),l=0;l<e;l++)r[l]=l}else for(e=c.length,n=new Float32Array(2*e),r=new Int32Array(e),l=0;l<e;l++)o=c[l],s=u[l],r[l]=l,n[2*l]=o,n[2*l+1]=s,o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);this.idToIndex=r,this.pointcloudOptions.idToIndex=r,this.pointcloudOptions.positions=n;var g=i(t.marker.color),v=i(t.marker.border.color),m=t.opacity*t.marker.opacity;g[3]*=m,this.pointcloudOptions.color=g;var y=t.marker.blend;if(null===y){y=c.length<100||u.length<100}this.pointcloudOptions.blend=y,v[3]*=m,this.pointcloudOptions.borderColor=v;var x=t.marker.sizemin,b=Math.max(t.marker.sizemax,t.marker.sizemin);this.pointcloudOptions.sizeMin=x,this.pointcloudOptions.sizeMax=b,this.pointcloudOptions.areaRatio=t.marker.border.arearatio,this.pointcloud.update(this.pointcloudOptions);var _=this.scene.xaxis,w=this.scene.yaxis,k=b/2||.5;t._extremes[_._id]=a(_,[d[0],d[2]],{ppad:k}),t._extremes[w._id]=a(w,[d[1],d[3]],{ppad:k})},l.dispose=function(){this.pointcloud.dispose()},e.exports=function(t,e){var r=new s(t,e.uid);return r.update(e),r}},{\"../../lib/str2rgbarray\":742,\"../../plots/cartesian/autorange\":766,\"../scatter/get_trace_color\":1121,\"gl-pointcloud2d\":292}],1100:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\");e.exports=function(t,e,r){function a(r,a){return n.coerce(t,e,i,r,a)}a(\"x\"),a(\"y\"),a(\"xbounds\"),a(\"ybounds\"),t.xy&&t.xy instanceof Float32Array&&(e.xy=t.xy),t.indices&&t.indices instanceof Int32Array&&(e.indices=t.indices),a(\"text\"),a(\"marker.color\",r),a(\"marker.opacity\"),a(\"marker.blend\"),a(\"marker.sizemin\"),a(\"marker.sizemax\"),a(\"marker.border.color\",r),a(\"marker.border.arearatio\"),e._length=null}},{\"../../lib\":719,\"./attributes\":1098}],1101:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../scatter3d/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"pointcloud\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"showLegend\"],meta:{}}},{\"../../plots/gl2d\":805,\"../scatter3d/calc\":1139,\"./attributes\":1098,\"./convert\":1099,\"./defaults\":1100}],1102:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../components/fx/attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../../components/fx/hovertemplate_attributes\"),c=t(\"../../components/colorscale/attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,h=t(\"../../lib/extend\").extendFlat,f=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=f({hoverinfo:h({},i.hoverinfo,{flags:[],arrayOk:!1}),hoverlabel:o.hoverlabel,domain:s({name:\"sankey\",trace:!0}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\"},valueformat:{valType:\"string\",dflt:\".3s\"},valuesuffix:{valType:\"string\",dflt:\"\"},arrangement:{valType:\"enumerated\",values:[\"snap\",\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"snap\"},textfont:n({}),node:{label:{valType:\"data_array\",dflt:[]},groups:{valType:\"info_array\",impliedEdits:{x:[],y:[]},dimensions:2,freeLength:!0,dflt:[],items:{valType:\"number\",editType:\"calc\"}},x:{valType:\"data_array\",dflt:[]},y:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:.5,arrayOk:!0}},pad:{valType:\"number\",arrayOk:!1,min:0,dflt:20},thickness:{valType:\"number\",arrayOk:!1,min:1,dflt:20},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]})},link:{label:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0}},source:{valType:\"data_array\",dflt:[]},target:{valType:\"data_array\",dflt:[]},value:{valType:\"data_array\",dflt:[]},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]}),colorscales:u(\"concentrationscales\",{editType:\"calc\",label:{valType:\"string\",editType:\"calc\",dflt:\"\"},cmax:{valType:\"number\",editType:\"calc\",dflt:1},cmin:{valType:\"number\",editType:\"calc\",dflt:0},colorscale:h(c().colorscale,{dflt:[[0,\"white\"],[1,\"black\"]]})})}},\"calc\",\"nested\")).transforms=void 0},{\"../../components/color/attributes\":592,\"../../components/colorscale/attributes\":600,\"../../components/fx/attributes\":623,\"../../components/fx/hovertemplate_attributes\":631,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1103:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../components/fx/layout_attributes\"),s=t(\"../../lib/setcursor\"),l=t(\"../../components/dragelement\"),c=t(\"../../plots/cartesian/select\").prepSelect,u=t(\"../../lib\"),h=t(\"../../registry\");function f(t,e){var r=t._fullData[e],n=t._fullLayout,i=n.dragmode,a=\"pan\"===n.dragmode?\"move\":\"crosshair\",o=r._bgRect;if(\"pan\"!==i&&\"zoom\"!==i){s(o,a);var f={_id:\"x\",c2p:u.identity,_offset:r._sankey.translateX,_length:r._sankey.width},p={_id:\"y\",c2p:u.identity,_offset:r._sankey.translateY,_length:r._sankey.height},d={gd:t,element:o.node(),plotinfo:{id:e,xaxis:f,yaxis:p,fillRangeItems:u.noop},subplot:e,xaxes:[f],yaxes:[p],doneFnCompleted:function(r){var n,i=t._fullData[e],a=i.node.groups.slice(),o=[];function s(t){for(var e=i._sankey.graph.nodes,r=0;r<e.length;r++)if(e[r].pointNumber===t)return e[r]}for(var l=0;l<r.length;l++){var c=s(r[l].pointNumber);if(c)if(c.group){for(var u=0;u<c.childrenNodes.length;u++)o.push(c.childrenNodes[u].pointNumber);a[c.pointNumber-i.node._count]=!1}else o.push(c.pointNumber)}n=a.filter(Boolean).concat([o]),h.call(\"_guiRestyle\",t,{\"node.groups\":[n]},e)},prepFn:function(t,e,r){c(t,e,r,d,i)}};l.init(d)}}r.name=\"sankey\",r.baseLayoutAttrOverrides=n({hoverlabel:o.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){var e=i(t.calcdata,\"sankey\")[0];a(t,e),r.updateFx(t)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"sankey\"),a=e._has&&e._has(\"sankey\");i&&!a&&(n._paperdiv.selectAll(\".sankey\").remove(),n._paperdiv.selectAll(\".bgsankey\").remove())},r.updateFx=function(t){for(var e=0;e<t._fullData.length;e++)f(t,e)}},{\"../../components/dragelement\":611,\"../../components/fx/layout_attributes\":633,\"../../lib\":719,\"../../lib/setcursor\":739,\"../../plot_api/edit_types\":750,\"../../plots/cartesian/select\":784,\"../../plots/get_data\":802,\"../../registry\":847,\"./plot\":1108}],1104:[function(t,e,r){\"use strict\";var n=t(\"strongly-connected-components\"),i=t(\"../../lib\"),a=t(\"../../lib/gup\").wrap,o=i.isArrayOrTypedArray,s=i.isIndex,l=t(\"../../components/colorscale\");function c(t){var e,r=t.node,a=t.link,c=[],u=o(a.color),h={},f={},p=a.colorscales.length;for(e=0;e<p;e++){var d=a.colorscales[e],g=l.extractScale(d,{cLetter:\"c\"}),v=l.makeColorScaleFunc(g);f[d.label]=v}var m=0;for(e=0;e<a.value.length;e++)a.source[e]>m&&(m=a.source[e]),a.target[e]>m&&(m=a.target[e]);var y,x=m+1;t.node._count=x;var b=t.node.groups,_={};for(e=0;e<b.length;e++){var w=b[e];for(y=0;y<w.length;y++){var k=w[y],T=x+e;_.hasOwnProperty(k)?i.warn(\"Node \"+k+\" is already part of a group.\"):_[k]=T}}var A={source:[],target:[]};for(e=0;e<a.value.length;e++){var M=a.value[e],S=a.source[e],E=a.target[e];if(M>0&&s(S,x)&&s(E,x)&&(!_.hasOwnProperty(S)||!_.hasOwnProperty(E)||_[S]!==_[E])){_.hasOwnProperty(E)&&(E=_[E]),_.hasOwnProperty(S)&&(S=_[S]),E=+E,h[S=+S]=h[E]=!0;var C=\"\";a.label&&a.label[e]&&(C=a.label[e]);var L=null;C&&f.hasOwnProperty(C)&&(L=f[C]),c.push({pointNumber:e,label:C,color:u?a.color[e]:a.color,concentrationscale:L,source:S,target:E,value:+M}),A.source.push(S),A.target.push(E)}}var P=x+b.length,O=o(r.color),z=[];for(e=0;e<P;e++)if(h[e]){var I=r.label[e];z.push({group:e>x-1,childrenNodes:[],pointNumber:e,label:I,color:O?r.color[e]:r.color})}var D=!1;return function(t,e,r){for(var a=i.init2dArray(t,0),o=0;o<Math.min(e.length,r.length);o++)if(i.isIndex(e[o],t)&&i.isIndex(r[o],t)){if(e[o]===r[o])return!0;a[e[o]].push(r[o])}return n(a).components.some(function(t){return t.length>1})}(P,A.source,A.target)&&(D=!0),{circular:D,links:c,nodes:z,groups:b,groupLookup:_}}e.exports=function(t,e){var r=c(e);return a({circular:r.circular,_nodes:r.nodes,_links:r.links,_groups:r.groups,_groupLookup:r.groupLookup})}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gup\":717,\"strongly-connected-components\":530}],1105:[function(t,e,r){\"use strict\";e.exports={nodeTextOffsetHorizontal:4,nodeTextOffsetVertical:3,nodePadAcross:10,sankeyIterations:50,forceIterations:5,forceTicksPerFrame:10,duration:500,ease:\"linear\",cn:{sankey:\"sankey\",sankeyLinks:\"sankey-links\",sankeyLink:\"sankey-link\",sankeyNodeSet:\"sankey-node-set\",sankeyNode:\"sankey-node\",nodeRect:\"node-rect\",nodeCapture:\"node-capture\",nodeCentered:\"node-entered\",nodeLabelGuide:\"node-label-guide\",nodeLabel:\"node-label\",nodeLabelTextPath:\"node-label-text-path\"}}},{}],1106:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../components/color\"),o=t(\"tinycolor2\"),s=t(\"../../plots/domain\").defaults,l=t(\"../../components/fx/hoverlabel_defaults\"),c=t(\"../../plot_api/plot_template\"),u=t(\"../../plots/array_container_defaults\");function h(t,e){function r(r,a){return n.coerce(t,e,i.link.colorscales,r,a)}r(\"label\"),r(\"cmin\"),r(\"cmax\"),r(\"colorscale\")}e.exports=function(t,e,r,f){function p(r,a){return n.coerce(t,e,i,r,a)}var d=n.extendDeep(f.hoverlabel,t.hoverlabel),g=t.node,v=c.newContainer(e,\"node\");function m(t,e){return n.coerce(g,v,i.node,t,e)}m(\"label\"),m(\"groups\"),m(\"x\"),m(\"y\"),m(\"pad\"),m(\"thickness\"),m(\"line.color\"),m(\"line.width\"),m(\"hoverinfo\",t.hoverinfo),l(g,v,m,d),m(\"hovertemplate\");var y=f.colorway;m(\"color\",v.label.map(function(t,e){return a.addOpacity(function(t){return y[t%y.length]}(e),.8)}));var x=t.link||{},b=c.newContainer(e,\"link\");function _(t,e){return n.coerce(x,b,i.link,t,e)}_(\"label\"),_(\"source\"),_(\"target\"),_(\"value\"),_(\"line.color\"),_(\"line.width\"),_(\"hoverinfo\",t.hoverinfo),l(x,b,_,d),_(\"hovertemplate\");var w,k=o(f.paper_bgcolor).getLuminance()<.333?\"rgba(255, 255, 255, 0.6)\":\"rgba(0, 0, 0, 0.2)\";_(\"color\",n.repeat(k,b.value.length)),u(x,b,{name:\"colorscales\",handleItemDefaults:h}),s(e,f,p),p(\"orientation\"),p(\"valueformat\"),p(\"valuesuffix\"),v.x.length&&v.y.length&&(w=\"freeform\"),p(\"arrangement\",w),n.coerceFont(p,\"textfont\",n.extendFlat({},f.font)),e._length=null}},{\"../../components/color\":593,\"../../components/fx/hoverlabel_defaults\":630,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/array_container_defaults\":763,\"../../plots/domain\":792,\"./attributes\":1102,tinycolor2:537}],1107:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"sankey\",basePlotModule:t(\"./base_plot\"),selectPoints:t(\"./select.js\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1102,\"./base_plot\":1103,\"./calc\":1104,\"./defaults\":1106,\"./plot\":1108,\"./select.js\":1110}],1108:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./render\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\"),l=t(\"./constants\").cn,c=s._;function u(t){return\"\"!==t}function h(t,e){return t.filter(function(t){return t.key===e.traceId})}function f(t,e){n.select(t).select(\"path\").style(\"fill-opacity\",e),n.select(t).select(\"rect\").style(\"fill-opacity\",e)}function p(t){n.select(t).select(\"text.name\").style(\"fill\",\"black\")}function d(t){return function(e){return-1!==t.node.sourceLinks.indexOf(e.link)||-1!==t.node.targetLinks.indexOf(e.link)}}function g(t){return function(e){return-1!==e.node.sourceLinks.indexOf(t.link)||-1!==e.node.targetLinks.indexOf(t.link)}}function v(t,e,r){e&&r&&h(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(y.bind(0,e,r,!1))}function m(t,e,r){e&&r&&h(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(x.bind(0,e,r,!1))}function y(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",function(t){if(!t.link.concentrationscale)return.4}),i&&h(e,t).selectAll(\".\"+l.sankeyLink).filter(function(t){return t.link.label===i}).style(\"fill-opacity\",function(t){if(!t.link.concentrationscale)return.4}),r&&h(e,t).selectAll(\".\"+l.sankeyNode).filter(g(t)).call(v)}function x(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),i&&h(e,t).selectAll(\".\"+l.sankeyLink).filter(function(t){return t.link.label===i}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),r&&h(e,t).selectAll(l.sankeyNode).filter(g(t)).call(m)}function b(t,e){var r=t.hoverlabel||{},n=s.nestedProperty(r,e).get();return!Array.isArray(n)&&n}e.exports=function(t,e){for(var r=t._fullLayout,s=r._paper,h=r._size,d=0;d<t._fullData.length;d++)if(t._fullData[d].type===l.sankey&&!t._fullData[d]._viewInitial){var g=t._fullData[d].node;t._fullData[d]._viewInitial={node:{groups:g.groups.slice(),x:g.x.slice(),y:g.y.slice()}}}var _=c(t,\"source:\")+\" \",w=c(t,\"target:\")+\" \",k=c(t,\"concentration:\")+\" \",T=c(t,\"incoming flow count:\")+\" \",A=c(t,\"outgoing flow count:\")+\" \";i(t,s,e,{width:h.w,height:h.h,margin:{t:h.t,r:h.r,b:h.b,l:h.l}},{linkEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(y.bind(0,r,i,!0)),\"skip\"!==r.link.trace.link.hoverinfo&&(r.link.fullData=r.link.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.link]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var s=i.link.trace.link;if(\"none\"!==s.hoverinfo&&\"skip\"!==s.hoverinfo){for(var l=[],c=0,h=0;h<i.flow.links.length;h++){var d=i.flow.links[h];if(\"closest\"!==t._fullLayout.hovermode||i.link.pointNumber===d.pointNumber){i.link.pointNumber===d.pointNumber&&(c=h),d.fullData=d.trace,s=i.link.trace.link;var g=m(d),v={valueLabel:n.format(i.valueFormat)(d.value)+i.valueSuffix};l.push({x:g[0],y:g[1],name:v.valueLabel,text:[d.label||\"\",_+d.source.label,w+d.target.label,d.concentrationscale?k+n.format(\"%0.2f\")(d.flow.labelConcentration):\"\"].filter(u).join(\"<br>\"),color:b(s,\"bgcolor\")||o.addOpacity(d.color,1),borderColor:b(s,\"bordercolor\"),fontFamily:b(s,\"font.family\"),fontSize:b(s,\"font.size\"),fontColor:b(s,\"font.color\"),nameLength:b(s,\"namelength\"),textAlign:b(s,\"align\"),idealAlign:n.event.x<g[0]?\"right\":\"left\",hovertemplate:s.hovertemplate,hovertemplateLabels:v,eventData:[d]})}}a.loneHover(l,{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t,anchorIndex:c}).each(function(){i.link.concentrationscale||f(this,.65),p(this)})}}function m(t){var e,r;return t.circular?(e=(t.circularPathData.leftInnerExtent+t.circularPathData.rightInnerExtent)/2+i.parent.translateX,r=t.circularPathData.verticalFullExtent+i.parent.translateY):(e=(t.source.x1+t.target.x0)/2+i.parent.translateX,r=(t.y0+t.y1)/2+i.parent.translateY),[e,r]}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(x.bind(0,i,o,!0)),\"skip\"!==i.link.trace.link.hoverinfo&&(i.link.fullData=i.link.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.link]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r){var i=r.link;i.originalEvent=n.event,t._hoverdata=[i],a.click(t,{target:!0})}},nodeEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(v,r,i),\"skip\"!==r.node.trace.node.hoverinfo&&(r.node.fullData=r.node.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.node]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var o=i.node.trace.node;if(\"none\"!==o.hoverinfo&&\"skip\"!==o.hoverinfo){var s=n.select(e).select(\".\"+l.nodeRect),c=t._fullLayout._paperdiv.node().getBoundingClientRect(),h=s.node().getBoundingClientRect(),d=h.left-2-c.left,g=h.right+2-c.left,v=h.top+h.height/4-c.top,m={valueLabel:n.format(i.valueFormat)(i.node.value)+i.valueSuffix};i.node.fullData=i.node.trace;var y=a.loneHover({x0:d,x1:g,y:v,name:n.format(i.valueFormat)(i.node.value)+i.valueSuffix,text:[i.node.label,T+i.node.targetLinks.length,A+i.node.sourceLinks.length].filter(u).join(\"<br>\"),color:b(o,\"bgcolor\")||i.tinyColorHue,borderColor:b(o,\"bordercolor\"),fontFamily:b(o,\"font.family\"),fontSize:b(o,\"font.size\"),fontColor:b(o,\"font.color\"),nameLength:b(o,\"namelength\"),textAlign:b(o,\"align\"),idealAlign:\"left\",hovertemplate:o.hovertemplate,hovertemplateLabels:m,eventData:[i.node]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t});f(y,.85),p(y)}}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(m,i,o),\"skip\"!==i.node.trace.node.hoverinfo&&(i.node.fullData=i.node.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.node]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r,i){var o=r.node;o.originalEvent=n.event,t._hoverdata=[o],n.select(e).call(m,r,i),a.click(t,{target:!0})}}})}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"./constants\":1105,\"./render\":1109,d3:163}],1109:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"tinycolor2\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"@plotly/d3-sankey\"),c=t(\"@plotly/d3-sankey-circular\"),u=t(\"d3-force\"),h=t(\"../../lib\"),f=t(\"../../lib/gup\"),p=f.keyFun,d=f.repeat,g=f.unwrap,v=t(\"d3-interpolate\").interpolateNumber,m=t(\"../../registry\");function y(){var t=.5;return function(e){if(e.link.circular)return r=e.link,n=r.width/2,i=r.circularPathData,\"top\"===r.circularLinkType?\"M \"+i.targetX+\" \"+(i.targetY+n)+\" L\"+i.rightInnerExtent+\" \"+(i.targetY+n)+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightSmallArcRadius+n)+\" 0 0 1 \"+(i.rightFullExtent-n)+\" \"+(i.targetY-i.rightSmallArcRadius)+\"L\"+(i.rightFullExtent-n)+\" \"+i.verticalRightInnerExtent+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightLargeArcRadius+n)+\" 0 0 1 \"+i.rightInnerExtent+\" \"+(i.verticalFullExtent-n)+\"L\"+i.leftInnerExtent+\" \"+(i.verticalFullExtent-n)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftLargeArcRadius+n)+\" 0 0 1 \"+(i.leftFullExtent+n)+\" \"+i.verticalLeftInnerExtent+\"L\"+(i.leftFullExtent+n)+\" \"+(i.sourceY-i.leftSmallArcRadius)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftSmallArcRadius+n)+\" 0 0 1 \"+i.leftInnerExtent+\" \"+(i.sourceY+n)+\"L\"+i.sourceX+\" \"+(i.sourceY+n)+\"L\"+i.sourceX+\" \"+(i.sourceY-n)+\"L\"+i.leftInnerExtent+\" \"+(i.sourceY-n)+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftSmallArcRadius-n)+\" 0 0 0 \"+(i.leftFullExtent-n)+\" \"+(i.sourceY-i.leftSmallArcRadius)+\"L\"+(i.leftFullExtent-n)+\" \"+i.verticalLeftInnerExtent+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftLargeArcRadius-n)+\" 0 0 0 \"+i.leftInnerExtent+\" \"+(i.verticalFullExtent+n)+\"L\"+i.rightInnerExtent+\" \"+(i.verticalFullExtent+n)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightLargeArcRadius-n)+\" 0 0 0 \"+(i.rightFullExtent+n)+\" \"+i.verticalRightInnerExtent+\"L\"+(i.rightFullExtent+n)+\" \"+(i.targetY-i.rightSmallArcRadius)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightSmallArcRadius-n)+\" 0 0 0 \"+i.rightInnerExtent+\" \"+(i.targetY-n)+\"L\"+i.targetX+\" \"+(i.targetY-n)+\"Z\":\"M \"+i.targetX+\" \"+(i.targetY-n)+\" L\"+i.rightInnerExtent+\" \"+(i.targetY-n)+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightSmallArcRadius+n)+\" 0 0 0 \"+(i.rightFullExtent-n)+\" \"+(i.targetY+i.rightSmallArcRadius)+\"L\"+(i.rightFullExtent-n)+\" \"+i.verticalRightInnerExtent+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightLargeArcRadius+n)+\" 0 0 0 \"+i.rightInnerExtent+\" \"+(i.verticalFullExtent+n)+\"L\"+i.leftInnerExtent+\" \"+(i.verticalFullExtent+n)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftLargeArcRadius+n)+\" 0 0 0 \"+(i.leftFullExtent+n)+\" \"+i.verticalLeftInnerExtent+\"L\"+(i.leftFullExtent+n)+\" \"+(i.sourceY+i.leftSmallArcRadius)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftSmallArcRadius+n)+\" 0 0 0 \"+i.leftInnerExtent+\" \"+(i.sourceY-n)+\"L\"+i.sourceX+\" \"+(i.sourceY-n)+\"L\"+i.sourceX+\" \"+(i.sourceY+n)+\"L\"+i.leftInnerExtent+\" \"+(i.sourceY+n)+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftSmallArcRadius-n)+\" 0 0 1 \"+(i.leftFullExtent-n)+\" \"+(i.sourceY+i.leftSmallArcRadius)+\"L\"+(i.leftFullExtent-n)+\" \"+i.verticalLeftInnerExtent+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftLargeArcRadius-n)+\" 0 0 1 \"+i.leftInnerExtent+\" \"+(i.verticalFullExtent-n)+\"L\"+i.rightInnerExtent+\" \"+(i.verticalFullExtent-n)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightLargeArcRadius-n)+\" 0 0 1 \"+(i.rightFullExtent+n)+\" \"+i.verticalRightInnerExtent+\"L\"+(i.rightFullExtent+n)+\" \"+(i.targetY+i.rightSmallArcRadius)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightSmallArcRadius-n)+\" 0 0 1 \"+i.rightInnerExtent+\" \"+(i.targetY+n)+\"L\"+i.targetX+\" \"+(i.targetY+n)+\"Z\";var r,n,i,a=e.link.source.x1,o=e.link.target.x0,s=v(a,o),l=s(t),c=s(1-t),u=e.link.y0-e.link.width/2,h=e.link.y0+e.link.width/2,f=e.link.y1-e.link.width/2,p=e.link.y1+e.link.width/2;return\"M\"+a+\",\"+u+\"C\"+l+\",\"+u+\" \"+c+\",\"+f+\" \"+o+\",\"+f+\"L\"+o+\",\"+p+\"C\"+c+\",\"+p+\" \"+l+\",\"+h+\" \"+a+\",\"+h+\"Z\"}}function x(t){t.attr(\"transform\",function(t){return\"translate(\"+t.node.x0.toFixed(3)+\", \"+t.node.y0.toFixed(3)+\")\"})}function b(t){t.call(x)}function _(t,e){t.call(b),e.attr(\"d\",y())}function w(t){t.attr(\"width\",function(t){return t.node.x1-t.node.x0}).attr(\"height\",function(t){return t.visibleHeight})}function k(t){return t.link.width>1||t.linkLineWidth>0}function T(t){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"+(t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\")}function A(t){return\"translate(\"+(t.horizontal?0:t.labelY)+\" \"+(t.horizontal?t.labelY:0)+\")\"}function M(t){return i.svg.line()([[t.horizontal?t.left?-t.sizeAcross:t.visibleWidth+n.nodeTextOffsetHorizontal:n.nodeTextOffsetHorizontal,0],[t.horizontal?t.left?-n.nodeTextOffsetHorizontal:t.sizeAcross:t.visibleHeight-n.nodeTextOffsetHorizontal,0]])}function S(t){return t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\"}function E(t){return t.horizontal?\"scale(1 1)\":\"scale(-1 1)\"}function C(t){return t.darkBackground&&!t.horizontal?\"rgb(255,255,255)\":\"rgb(0,0,0)\"}function L(t){return t.horizontal&&t.left?\"100%\":\"0%\"}function P(t,e,r){t.on(\".basic\",null).on(\"mouseover.basic\",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.hover(this,t,e),t.interactionState.hovered=[this,t])}).on(\"mousemove.basic\",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.follow(this,t),t.interactionState.hovered=[this,t])}).on(\"mouseout.basic\",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.unhover(this,t,e),t.interactionState.hovered=!1)}).on(\"click.basic\",function(t){t.interactionState.hovered&&(r.unhover(this,t,e),t.interactionState.hovered=!1),t.interactionState.dragInProgress||t.partOfGroup||r.select(this,t,e)})}function O(t,e,r,a){var o=i.behavior.drag().origin(function(t){return{x:t.node.x0+t.visibleWidth/2,y:t.node.y0+t.visibleHeight/2}}).on(\"dragstart\",function(i){if(\"fixed\"!==i.arrangement&&(h.ensureSingle(a._fullLayout._infolayer,\"g\",\"dragcover\",function(t){a._fullLayout._dragCover=t}),h.raiseToTop(this),i.interactionState.dragInProgress=i.node,I(i.node),i.interactionState.hovered&&(r.nodeEvents.unhover.apply(0,i.interactionState.hovered),i.interactionState.hovered=!1),\"snap\"===i.arrangement)){var o=i.traceId+\"|\"+i.key;i.forceLayouts[o]?i.forceLayouts[o].alpha(1):function(t,e,r,i){!function(t){for(var e=0;e<t.length;e++)t[e].y=(t[e].y0+t[e].y1)/2,t[e].x=(t[e].x0+t[e].x1)/2}(r.graph.nodes);var a=r.graph.nodes.filter(function(t){return t.originalX===r.node.originalX}).filter(function(t){return!t.partOfGroup});r.forceLayouts[e]=u.forceSimulation(a).alphaDecay(0).force(\"collide\",u.forceCollide().radius(function(t){return t.dy/2+r.nodePad/2}).strength(1).iterations(n.forceIterations)).force(\"constrain\",function(t,e,r,i){return function(){for(var t=0,a=0;a<r.length;a++){var o=r[a];o===i.interactionState.dragInProgress?(o.x=o.lastDraggedX,o.y=o.lastDraggedY):(o.vx=(o.originalX-o.x)/n.forceTicksPerFrame,o.y=Math.min(i.size-o.dy/2,Math.max(o.dy/2,o.y))),t=Math.max(t,Math.abs(o.vx),Math.abs(o.vy))}!i.interactionState.dragInProgress&&t<.1&&i.forceLayouts[e].alpha()>0&&i.forceLayouts[e].alpha(0)}}(0,e,a,r)).stop()}(0,o,i),function(t,e,r,i,a){window.requestAnimationFrame(function o(){var s;for(s=0;s<n.forceTicksPerFrame;s++)r.forceLayouts[i].tick();var l=r.graph.nodes;if(function(t){for(var e=0;e<t.length;e++)t[e].y0=t[e].y-t[e].dy/2,t[e].y1=t[e].y0+t[e].dy,t[e].x0=t[e].x-t[e].dx/2,t[e].x1=t[e].x0+t[e].dx}(l),r.sankey.update(r.graph),_(t.filter(D(r)),e),r.forceLayouts[i].alpha()>0)window.requestAnimationFrame(o);else{var c=r.node.originalX;r.node.x0=c-r.visibleWidth/2,r.node.x1=c+r.visibleWidth/2,z(r,a)}})}(t,e,i,o,a)}}).on(\"drag\",function(r){if(\"fixed\"!==r.arrangement){var n=i.event.x,a=i.event.y;\"snap\"===r.arrangement?(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2,r.node.y0=a-r.visibleHeight/2,r.node.y1=a+r.visibleHeight/2):(\"freeform\"===r.arrangement&&(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2),a=Math.max(0,Math.min(r.size-r.visibleHeight/2,a)),r.node.y0=a-r.visibleHeight/2,r.node.y1=a+r.visibleHeight/2),I(r.node),\"snap\"!==r.arrangement&&(r.sankey.update(r.graph),_(t.filter(D(r)),e))}}).on(\"dragend\",function(t){if(\"fixed\"!==t.arrangement){t.interactionState.dragInProgress=!1;for(var e=0;e<t.node.childrenNodes.length;e++)t.node.childrenNodes[e].x=t.node.x,t.node.childrenNodes[e].y=t.node.y;\"snap\"!==t.arrangement&&z(t,a)}});t.on(\".drag\",null).call(o)}function z(t,e){for(var r=[],n=[],i=0;i<t.graph.nodes.length;i++){var a=(t.graph.nodes[i].x0+t.graph.nodes[i].x1)/2,o=(t.graph.nodes[i].y0+t.graph.nodes[i].y1)/2;r.push(a/t.figure.width),n.push(o/t.figure.height)}m.call(\"_guiRestyle\",e,{\"node.x\":[r],\"node.y\":[n]},t.trace.index).then(function(){e._fullLayout._dragCover&&e._fullLayout._dragCover.remove()})}function I(t){t.lastDraggedX=t.x0+t.dx/2,t.lastDraggedY=t.y0+t.dy/2}function D(t){return function(e){return e.node.originalX===t.node.originalX}}e.exports=function(t,e,r,u,f){var v=!1;h.ensureSingle(t._fullLayout._infolayer,\"g\",\"first-render\",function(){v=!0});var m=t._fullLayout._dragCover,b=r.filter(function(t){return g(t).trace.visible}).map(function(t,e,r){var i,o=g(e),s=o.trace,u=s.domain,f=\"h\"===s.orientation,p=s.node.pad,d=s.node.thickness,v=t.width*(u.x[1]-u.x[0]),m=t.height*(u.y[1]-u.y[0]),y=o._nodes,x=o._links,b=o.circular;(i=b?c.sankeyCircular().circularLinkGap(0):l.sankey()).iterations(n.sankeyIterations).size(f?[v,m]:[m,v]).nodeWidth(d).nodePadding(p).nodeId(function(t){return t.pointNumber}).nodes(y).links(x);var _,w,k,T=i();for(var A in i.nodePadding()<p&&h.warn(\"node.pad was reduced to \",i.nodePadding(),\" to fit within the figure.\"),o._groupLookup){var M,S=parseInt(o._groupLookup[A]);for(_=0;_<T.nodes.length;_++)if(T.nodes[_].pointNumber===S){M=T.nodes[_];break}if(M){var E={pointNumber:parseInt(A),x0:M.x0,x1:M.x1,y0:M.y0,y1:M.y1,partOfGroup:!0,sourceLinks:[],targetLinks:[]};T.nodes.unshift(E),M.childrenNodes.unshift(E)}}if(function(){for(_=0;_<T.nodes.length;_++){var t,e,r=T.nodes[_],n={};for(w=0;w<r.targetLinks.length;w++)t=(e=r.targetLinks[w]).source.pointNumber+\":\"+e.target.pointNumber,n.hasOwnProperty(t)||(n[t]=[]),n[t].push(e);var i=Object.keys(n);for(w=0;w<i.length;w++){var o=n[t=i[w]],s=0,l={};for(k=0;k<o.length;k++)l[(e=o[k]).label]||(l[e.label]=0),l[e.label]+=e.value,s+=e.value;for(k=0;k<o.length;k++)(e=o[k]).flow={value:s,labelConcentration:l[e.label]/s,concentration:e.value/s,links:o},e.concentrationscale&&(e.color=a(e.concentrationscale(e.flow.labelConcentration)))}var c=0;for(w=0;w<r.sourceLinks.length;w++)c+=r.sourceLinks[w].value;for(w=0;w<r.sourceLinks.length;w++)(e=r.sourceLinks[w]).concentrationOut=e.value/c;var u=0;for(w=0;w<r.targetLinks.length;w++)u+=r.targetLinks[w].value;for(w=0;w<r.targetLinks.length;w++)(e=r.targetLinks[w]).concenrationIn=e.value/u}}(),s.node.x.length&&s.node.y.length){for(_=0;_<Math.min(s.node.x.length,s.node.y.length,T.nodes.length);_++)if(s.node.x[_]&&s.node.y[_]){var C=[s.node.x[_]*v,s.node.y[_]*m];T.nodes[_].x0=C[0]-d/2,T.nodes[_].x1=C[0]+d/2;var L=T.nodes[_].y1-T.nodes[_].y0;T.nodes[_].y0=C[1]-L/2,T.nodes[_].y1=C[1]+L/2}\"snap\"===s.arrangement&&function(t){t.forEach(function(t){var e,r,n,i=0,a=t.length;for(t.sort(function(t,e){return t.y0-e.y0}),n=0;n<a;++n)(e=t[n]).y0>=i||(r=i-e.y0)>1e-6&&(e.y0+=r,e.y1+=r),i=e.y1+p})}(function(t){var e,r,n=t.map(function(t,e){return{x0:t.x0,index:e}}).sort(function(t,e){return t.x0-e.x0}),i=[],a=-1,o=-1/0;for(_=0;_<n.length;_++){var s=t[n[_].index];s.x0>o+d&&(a+=1,e=s.x0),o=s.x0,i[a]||(i[a]=[]),i[a].push(s),r=e-s.x0,s.x0+=r,s.x1+=r}return i}(y=T.nodes)),i.update(T)}return{circular:b,key:r,trace:s,guid:h.randstr(),horizontal:f,width:v,height:m,nodePad:s.node.pad,nodeLineColor:s.node.line.color,nodeLineWidth:s.node.line.width,linkLineColor:s.link.line.color,linkLineWidth:s.link.line.width,valueFormat:s.valueformat,valueSuffix:s.valuesuffix,textFont:s.textfont,translateX:u.x[0]*t.width+t.margin.l,translateY:t.height-u.y[1]*t.height+t.margin.t,dragParallel:f?m:v,dragPerpendicular:f?v:m,arrangement:s.arrangement,sankey:i,graph:T,forceLayouts:{},interactionState:{dragInProgress:!1,hovered:!1}}}.bind(null,u)),_=e.selectAll(\".\"+n.cn.sankey).data(b,p);_.exit().remove(),_.enter().append(\"g\").classed(n.cn.sankey,!0).style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"shape-rendering\",\"geometricPrecision\").style(\"pointer-events\",\"auto\").attr(\"transform\",T),_.each(function(e,r){t._fullData[r]._sankey=e;var n=\"bgsankey-\"+e.trace.uid+\"-\"+r;h.ensureSingle(t._fullLayout._draggers,\"rect\",n),t._fullData[r]._bgRect=i.select(\".\"+n),t._fullData[r]._bgRect.style(\"pointer-events\",\"all\").attr(\"width\",e.width).attr(\"height\",e.height).attr(\"x\",e.translateX).attr(\"y\",e.translateY).classed(\"bgsankey\",!0).style({fill:\"transparent\",\"stroke-width\":0})}),_.transition().ease(n.ease).duration(n.duration).attr(\"transform\",T);var z=_.selectAll(\".\"+n.cn.sankeyLinks).data(d,p);z.enter().append(\"g\").classed(n.cn.sankeyLinks,!0).style(\"fill\",\"none\");var I=z.selectAll(\".\"+n.cn.sankeyLink).data(function(t){return t.graph.links.filter(function(t){return t.value}).map(function(t,e,r){var n=a(e.color),i=e.source.label+\"|\"+e.target.label+\"__\"+r;return e.trace=t.trace,e.curveNumber=t.trace.index,{circular:t.circular,key:i,traceId:t.key,pointNumber:e.pointNumber,link:e,tinyColorHue:o.tinyRGB(n),tinyColorAlpha:n.getAlpha(),linkPath:y,linkLineColor:t.linkLineColor,linkLineWidth:t.linkLineWidth,valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,parent:t,interactionState:t.interactionState,flow:e.flow}}.bind(null,t))},p);I.enter().append(\"path\").classed(n.cn.sankeyLink,!0).call(P,_,f.linkEvents),I.style(\"stroke\",function(t){return k(t)?o.tinyRGB(a(t.linkLineColor)):t.tinyColorHue}).style(\"stroke-opacity\",function(t){return k(t)?o.opacity(t.linkLineColor):t.tinyColorAlpha}).style(\"fill\",function(t){return t.tinyColorHue}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}).style(\"stroke-width\",function(t){return k(t)?t.linkLineWidth:1}).attr(\"d\",y()),I.style(\"opacity\",function(){return t._context.staticPlot||v||m?1:0}).transition().ease(n.ease).duration(n.duration).style(\"opacity\",1),I.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var D=_.selectAll(\".\"+n.cn.sankeyNodeSet).data(d,p);D.enter().append(\"g\").classed(n.cn.sankeyNodeSet,!0),D.style(\"cursor\",function(t){switch(t.arrangement){case\"fixed\":return\"default\";case\"perpendicular\":return\"ns-resize\";default:return\"move\"}});var R=D.selectAll(\".\"+n.cn.sankeyNode).data(function(t){var e=t.graph.nodes;return function(t){var e,r=[];for(e=0;e<t.length;e++)t[e].originalX=(t[e].x0+t[e].x1)/2,t[e].originalY=(t[e].y0+t[e].y1)/2,-1===r.indexOf(t[e].originalX)&&r.push(t[e].originalX);for(r.sort(function(t,e){return t-e}),e=0;e<t.length;e++)t[e].originalLayerIndex=r.indexOf(t[e].originalX),t[e].originalLayer=t[e].originalLayerIndex/(r.length-1)}(e),e.map(function(t,e){var r=a(e.color),i=n.nodePadAcross,s=t.nodePad/2;e.dx=e.x1-e.x0,e.dy=e.y1-e.y0;var l=e.dx,c=Math.max(.5,e.dy),u=\"node_\"+e.pointNumber;return e.group&&(u=h.randstr()),e.trace=t.trace,e.curveNumber=t.trace.index,{index:e.pointNumber,key:u,partOfGroup:e.partOfGroup||!1,group:e.group,traceId:t.key,trace:t.trace,node:e,nodePad:t.nodePad,nodeLineColor:t.nodeLineColor,nodeLineWidth:t.nodeLineWidth,textFont:t.textFont,size:t.horizontal?t.height:t.width,visibleWidth:Math.ceil(l),visibleHeight:c,zoneX:-i,zoneY:-s,zoneWidth:l+2*i,zoneHeight:c+2*s,labelY:t.horizontal?e.dy/2+1:e.dx/2+1,left:1===e.originalLayer,sizeAcross:t.width,forceLayouts:t.forceLayouts,horizontal:t.horizontal,darkBackground:r.getBrightness()<=128,tinyColorHue:o.tinyRGB(r),tinyColorAlpha:r.getAlpha(),valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,graph:t.graph,arrangement:t.arrangement,uniqueNodeLabelPathId:[t.guid,t.key,u].join(\"_\"),interactionState:t.interactionState,figure:t}}.bind(null,t))},p);R.enter().append(\"g\").classed(n.cn.sankeyNode,!0).call(x).style(\"opacity\",function(e){return!t._context.staticPlot&&!v||e.partOfGroup?0:1}),R.call(P,_,f.nodeEvents).call(O,I,f,t),R.transition().ease(n.ease).duration(n.duration).call(x).style(\"opacity\",function(t){return t.partOfGroup?0:1}),R.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var F=R.selectAll(\".\"+n.cn.nodeRect).data(d);F.enter().append(\"rect\").classed(n.cn.nodeRect,!0).call(w),F.style(\"stroke-width\",function(t){return t.nodeLineWidth}).style(\"stroke\",function(t){return o.tinyRGB(a(t.nodeLineColor))}).style(\"stroke-opacity\",function(t){return o.opacity(t.nodeLineColor)}).style(\"fill\",function(t){return t.tinyColorHue}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),F.transition().ease(n.ease).duration(n.duration).call(w);var B=R.selectAll(\".\"+n.cn.nodeCapture).data(d);B.enter().append(\"rect\").classed(n.cn.nodeCapture,!0).style(\"fill-opacity\",0),B.attr(\"x\",function(t){return t.zoneX}).attr(\"y\",function(t){return t.zoneY}).attr(\"width\",function(t){return t.zoneWidth}).attr(\"height\",function(t){return t.zoneHeight});var N=R.selectAll(\".\"+n.cn.nodeCentered).data(d);N.enter().append(\"g\").classed(n.cn.nodeCentered,!0).attr(\"transform\",A),N.transition().ease(n.ease).duration(n.duration).attr(\"transform\",A);var j=N.selectAll(\".\"+n.cn.nodeLabelGuide).data(d);j.enter().append(\"path\").classed(n.cn.nodeLabelGuide,!0).attr(\"id\",function(t){return t.uniqueNodeLabelPathId}).attr(\"d\",M).attr(\"transform\",S),j.transition().ease(n.ease).duration(n.duration).attr(\"d\",M).attr(\"transform\",S);var U=N.selectAll(\".\"+n.cn.nodeLabel).data(d);U.enter().append(\"text\").classed(n.cn.nodeLabel,!0).attr(\"transform\",E).style(\"user-select\",\"none\").style(\"cursor\",\"default\").style(\"fill\",\"black\"),U.style(\"text-shadow\",function(t){return t.horizontal?\"-1px 1px 1px #fff, 1px 1px 1px #fff, 1px -1px 1px #fff, -1px -1px 1px #fff\":\"none\"}).each(function(t){s.font(U,t.textFont)}),U.transition().ease(n.ease).duration(n.duration).attr(\"transform\",E);var V=U.selectAll(\".\"+n.cn.nodeLabelTextPath).data(d);V.enter().append(\"textPath\").classed(n.cn.nodeLabelTextPath,!0).attr(\"alignment-baseline\",\"middle\").attr(\"xlink:href\",function(t){return\"#\"+t.uniqueNodeLabelPathId}).attr(\"startOffset\",L).style(\"fill\",C),V.text(function(t){return t.horizontal||t.node.dy>5?t.node.label:\"\"}).attr(\"text-anchor\",function(t){return t.horizontal&&t.left?\"end\":\"start\"}),V.transition().ease(n.ease).duration(n.duration).attr(\"startOffset\",L).style(\"fill\",C)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/gup\":717,\"../../registry\":847,\"./constants\":1105,\"@plotly/d3-sankey\":54,\"@plotly/d3-sankey-circular\":53,d3:163,\"d3-force\":156,\"d3-interpolate\":158,tinycolor2:537}],1110:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=[],n=t.cd[0].trace,i=n._sankey.graph.nodes,a=0;a<i.length;a++){var o=i[a];if(!o.partOfGroup){var s=[(o.x0+o.x1)/2,(o.y0+o.y1)/2];\"v\"===n.orientation&&s.reverse(),e&&e.contains(s,!1,a,t)&&r.push({pointNumber:o.pointNumber})}}return r}},{}],1111:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\"),n.mergeArray(e.customdata,t,\"data\"),n.mergeArray(e.textposition,t,\"tp\"),e.textfont&&(n.mergeArrayCastPositive(e.textfont.size,t,\"ts\"),n.mergeArray(e.textfont.color,t,\"tc\"),n.mergeArray(e.textfont.family,t,\"tf\"));var i=e.marker;if(i){n.mergeArrayCastPositive(i.size,t,\"ms\"),n.mergeArrayCastPositive(i.opacity,t,\"mo\"),n.mergeArray(i.symbol,t,\"mx\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;i.line&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"));var o=i.gradient;o&&\"none\"!==o.type&&(n.mergeArray(o.type,t,\"mgt\"),n.mergeArray(o.color,t,\"mgc\"))}}},{\"../../lib\":719}],1112:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../components/drawing/attributes\").dash,s=t(\"../../components/drawing\"),l=t(\"./constants\"),c=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},x0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dx:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},y0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dy:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},stackgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc\"},groupnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},stackgaps:{valType:\"enumerated\",values:[\"infer zero\",\"interpolate\"],dflt:\"infer zero\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"],editType:\"calc\"},hoveron:{valType:\"flaglist\",flags:[\"points\",\"fills\"],editType:\"style\"},hovertemplate:n({},{keys:l.eventDataKeys}),line:{color:{valType:\"color\",editType:\"style\",anim:!0},width:{valType:\"number\",min:0,dflt:2,editType:\"style\",anim:!0},shape:{valType:\"enumerated\",values:[\"linear\",\"spline\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},smoothing:{valType:\"number\",min:0,max:1.3,dflt:1,editType:\"plot\"},dash:c({},o,{editType:\"style\"}),simplify:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cliponaxis:{valType:\"boolean\",dflt:!0,editType:\"plot\"},fill:{valType:\"enumerated\",values:[\"none\",\"tozeroy\",\"tozerox\",\"tonexty\",\"tonextx\",\"toself\",\"tonext\"],editType:\"calc\"},fillcolor:{valType:\"color\",editType:\"style\",anim:!0},marker:c({symbol:{valType:\"enumerated\",values:s.symbolList,dflt:\"circle\",arrayOk:!0,editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,arrayOk:!0,editType:\"style\",anim:!0},size:{valType:\"number\",min:0,dflt:6,arrayOk:!0,editType:\"calc\",anim:!0},maxdisplayed:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},sizeref:{valType:\"number\",dflt:1,editType:\"calc\"},sizemin:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"diameter\",\"area\"],dflt:\"diameter\",editType:\"calc\"},line:c({width:{valType:\"number\",min:0,arrayOk:!0,editType:\"style\",anim:!0},editType:\"calc\"},i(\"marker.line\",{anim:!0})),gradient:{type:{valType:\"enumerated\",values:[\"radial\",\"horizontal\",\"vertical\",\"none\"],arrayOk:!0,dflt:\"none\",editType:\"calc\"},color:{valType:\"color\",arrayOk:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},i(\"marker\",{anim:!0})),selected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},unselected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\"],dflt:\"middle center\",arrayOk:!0,editType:\"calc\"},textfont:a({editType:\"calc\",colorEditType:\"style\",arrayOk:!0}),r:{valType:\"data_array\",editType:\"calc\"},t:{valType:\"data_array\",editType:\"calc\"}}},{\"../../components/colorscale/attributes\":600,\"../../components/drawing\":614,\"../../components/drawing/attributes\":613,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"./constants\":1116}],1113:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/numerical\").BADNUM,s=t(\"./subtypes\"),l=t(\"./colorscale_calc\"),c=t(\"./arrays_to_calcdata\"),u=t(\"./calc_selection\");function h(t,e,r,n,i,o,l){var c=e._length,u=t._fullLayout,h=r._id,f=n._id,p=u._firstScatter[d(e)]===e.uid,v=(g(e,u,r,n)||{}).orientation,m=e.fill;r._minDtick=0,n._minDtick=0;var y={padded:!0},x={padded:!0};l&&(y.ppad=x.ppad=l);var b=c<2||i[0]!==i[c-1]||o[0]!==o[c-1];b&&(\"tozerox\"===m||\"tonextx\"===m&&(p||\"h\"===v))?y.tozero=!0:(e.error_y||{}).visible||\"tonexty\"!==m&&\"tozeroy\"!==m&&(s.hasMarkers(e)||s.hasText(e))||(y.padded=!1,y.ppad=0),b&&(\"tozeroy\"===m||\"tonexty\"===m&&(p||\"v\"===v))?x.tozero=!0:\"tonextx\"!==m&&\"tozerox\"!==m||(x.padded=!1),h&&(e._extremes[h]=a.findExtremes(r,i,y)),f&&(e._extremes[f]=a.findExtremes(n,o,x))}function f(t,e){if(s.hasMarkers(t)){var r,n=t.marker,o=1.6*(t.marker.sizeref||1);if(r=\"area\"===t.marker.sizemode?function(t){return Math.max(Math.sqrt((t||0)/o),3)}:function(t){return Math.max((t||0)/o,3)},i.isArrayOrTypedArray(n.size)){var l={type:\"linear\"};a.setConvert(l);for(var c=l.makeCalcdata(t.marker,\"size\"),u=new Array(e),h=0;h<e;h++)u[h]=r(c[h]);return u}return r(n.size)}}function p(t,e){var r=d(e),n=t._firstScatter;n[r]||(n[r]=e.uid)}function d(t){var e=t.stackgroup;return t.xaxis+t.yaxis+t.type+(e?\"-\"+e:\"\")}function g(t,e,r,n){var i=t.stackgroup;if(i){var a=e._scatterStackOpts[r._id+n._id][i],o=\"v\"===a.orientation?n:r;return\"linear\"===o.type||\"log\"===o.type?a:void 0}}e.exports={calc:function(t,e){var r,s,d,v,m,y,x=t._fullLayout,b=a.getFromId(t,e.xaxis||\"x\"),_=a.getFromId(t,e.yaxis||\"y\"),w=b.makeCalcdata(e,\"x\"),k=_.makeCalcdata(e,\"y\"),T=e._length,A=new Array(T),M=e.ids,S=g(e,x,b,_),E=!1;p(x,e);var C,L=\"x\",P=\"y\";for(S?(i.pushUnique(S.traceIndices,e._expandedIndex),(r=\"v\"===S.orientation)?(P=\"s\",C=\"x\"):(L=\"s\",C=\"y\"),m=\"interpolate\"===S.stackgaps):h(t,e,b,_,w,k,f(e,T)),s=0;s<T;s++){var O=A[s]={},z=n(w[s]),I=n(k[s]);z&&I?(O[L]=w[s],O[P]=k[s]):S&&(r?z:I)?(O[C]=r?w[s]:k[s],O.gap=!0,m?(O.s=o,E=!0):O.s=0):O[L]=O[P]=o,M&&(O.id=String(M[s]))}if(c(A,e),l(t,e),u(A,e),S){for(s=0;s<A.length;)A[s][C]===o?A.splice(s,1):s++;if(i.sort(A,function(t,e){return t[C]-e[C]||t.i-e.i}),E){for(s=0;s<A.length-1&&A[s].gap;)s++;for((y=A[s].s)||(y=A[s].s=0),d=0;d<s;d++)A[d].s=y;for(v=A.length-1;v>s&&A[v].gap;)v--;for(y=A[v].s,d=A.length-1;d>v;d--)A[d].s=y;for(;s<v;)if(A[++s].gap){for(d=s+1;A[d].gap;)d++;for(var D=A[s-1][C],R=A[s-1].s,F=(A[d].s-R)/(A[d][C]-D);s<d;)A[s].s=R+(A[s][C]-D)*F,s++}}}return A},calcMarkerSize:f,calcAxisExpansion:h,setFirstScatter:p,getStackOpts:g}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./arrays_to_calcdata\":1111,\"./calc_selection\":1114,\"./colorscale_calc\":1115,\"./subtypes\":1135,\"fast-isnumeric\":225}],1114:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){n.isArrayOrTypedArray(e.selectedpoints)&&n.tagSelected(t,e)}},{\"../../lib\":719}],1115:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"./subtypes\");e.exports=function(t,e){a.hasLines(e)&&n(e,\"line\")&&i(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),a.hasMarkers(e)&&(n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}))}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"./subtypes\":1135}],1116:[function(t,e,r){\"use strict\";e.exports={PTS_LINESONLY:20,minTolerance:.2,toleranceGrowth:10,maxScreensAway:20,eventDataKeys:[]}},{}],1117:[function(t,e,r){\"use strict\";var n=t(\"./calc\");function i(t,e,r,n,i,a,o){i[n]=!0;var s={i:null,gap:!0,s:0};if(s[o]=r,t.splice(e,0,s),e&&r===t[e-1][o]){var l=t[e-1];s.s=l.s,s.i=l.i,s.gap=l.gap}else a&&(s.s=function(t,e,r,n){var i=t[e-1],a=t[e+1];return a?i?i.s+(a.s-i.s)*(r-i[n])/(a[n]-i[n]):a.s:i.s}(t,e,r,o));e||(t[0].t=t[1].t,t[0].trace=t[1].trace,delete t[1].t,delete t[1].trace)}e.exports=function(t,e){var r=e.xaxis,a=e.yaxis,o=r._id+a._id,s=t._fullLayout._scatterStackOpts[o];if(s){var l,c,u,h,f,p,d,g,v,m,y,x,b,_,w,k=t.calcdata;for(var T in s){var A=(m=s[T]).traceIndices;if(A.length){for(y=\"interpolate\"===m.stackgaps,x=m.groupnorm,\"v\"===m.orientation?(b=\"x\",_=\"y\"):(b=\"y\",_=\"x\"),w=new Array(A.length),l=0;l<w.length;l++)w[l]=!1;p=k[A[0]];var M=new Array(p.length);for(l=0;l<p.length;l++)M[l]=p[l][b];for(l=1;l<A.length;l++){for(f=k[A[l]],c=u=0;c<f.length;c++){for(d=f[c][b];d>M[u]&&u<M.length;u++)i(f,c,M[u],l,w,y,b),c++;if(d!==M[u]){for(h=0;h<l;h++)i(k[A[h]],u,d,h,w,y,b);M.splice(u,0,d)}u++}for(;u<M.length;u++)i(f,c,M[u],l,w,y,b),c++}var S=M.length;for(c=0;c<p.length;c++){for(g=p[c][_]=p[c].s,l=1;l<A.length;l++)(f=k[A[l]])[0].trace._rawLength=f[0].trace._length,f[0].trace._length=S,g+=f[c].s,f[c][_]=g;if(x)for(v=(\"fraction\"===x?g:g/100)||1,l=0;l<A.length;l++){var E=k[A[l]][c];E[_]/=v,E.sNorm=E.s/v}}for(l=0;l<A.length;l++){var C=(f=k[A[l]])[0].trace,L=n.calcMarkerSize(C,C._rawLength),P=Array.isArray(L);if(L&&w[l]||P){var O=L;for(L=new Array(S),c=0;c<S;c++)L[c]=f[c].gap?0:P?O[f[c].i]:O}var z=new Array(S),I=new Array(S);for(c=0;c<S;c++)z[c]=f[c].x,I[c]=f[c].y;n.calcAxisExpansion(t,C,r,a,z,I,L),f[0].t.orientation=m.orientation}}}}}},{\"./calc\":1113}],1118:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0;e<t.length;e++){var r=t[e];if(\"scatter\"===r.type){var n=r.fill;if(\"none\"!==n&&\"toself\"!==n&&(r.opacity=void 0,\"tonexty\"===n||\"tonextx\"===n))for(var i=e-1;i>=0;i--){var a=t[i];if(\"scatter\"===a.type&&a.xaxis===r.xaxis&&a.yaxis===r.yaxis){a.opacity=void 0;break}}}}}},{}],1119:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"./constants\"),s=t(\"./subtypes\"),l=t(\"./xy_defaults\"),c=t(\"./stack_defaults\"),u=t(\"./marker_defaults\"),h=t(\"./line_defaults\"),f=t(\"./line_shape_defaults\"),p=t(\"./text_defaults\"),d=t(\"./fillcolor_defaults\");e.exports=function(t,e,r,g){function v(r,i){return n.coerce(t,e,a,r,i)}var m=l(t,e,g,v);if(m||(e.visible=!1),e.visible){var y=c(t,e,g,v),x=!y&&m<o.PTS_LINESONLY?\"lines+markers\":\"lines\";v(\"text\"),v(\"hovertext\"),v(\"mode\",x),s.hasLines(e)&&(h(t,e,r,g,v),f(t,e,v),v(\"connectgaps\"),v(\"line.simplify\")),s.hasMarkers(e)&&u(t,e,r,g,v,{gradient:!0}),s.hasText(e)&&p(t,e,g,v);var b=[];(s.hasMarkers(e)||s.hasText(e))&&(v(\"cliponaxis\"),v(\"marker.maxdisplayed\"),b.push(\"points\")),v(\"fill\",y?y.fillDflt:\"none\"),\"none\"!==e.fill&&(d(t,e,r,v),s.hasLines(e)||f(t,e,v));var _=(e.line||{}).color,w=(e.marker||{}).color;\"tonext\"!==e.fill&&\"toself\"!==e.fill||b.push(\"fills\"),v(\"hoveron\",b.join(\"+\")||\"points\"),\"fills\"!==e.hoveron&&v(\"hovertemplate\");var k=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");k(t,e,_||w||r,{axis:\"y\"}),k(t,e,_||w||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,v)}}},{\"../../lib\":719,\"../../registry\":847,\"./attributes\":1112,\"./constants\":1116,\"./fillcolor_defaults\":1120,\"./line_defaults\":1124,\"./line_shape_defaults\":1126,\"./marker_defaults\":1130,\"./stack_defaults\":1133,\"./subtypes\":1135,\"./text_defaults\":1136,\"./xy_defaults\":1137}],1120:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a){var o=!1;if(e.marker){var s=e.marker.color,l=(e.marker.line||{}).color;s&&!i(s)?o=s:l&&!i(l)&&(o=l)}a(\"fillcolor\",n.addOpacity((e.line||{}).color||o||r,.5))}},{\"../../components/color\":593,\"../../lib\":719}],1121:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./subtypes\");e.exports=function(t,e){var r,a;if(\"lines\"===t.mode)return(r=t.line.color)&&n.opacity(r)?r:t.fillcolor;if(\"none\"===t.mode)return t.fill?t.fillcolor:\"\";var o=e.mcc||(t.marker||{}).color,s=e.mlcc||((t.marker||{}).line||{}).color;return(a=o&&n.opacity(o)?o:s&&n.opacity(s)&&(e.mlw||((t.marker||{}).line||{}).width)?s:\"\")?n.opacity(a)<.3?n.addOpacity(a,.3):a:(r=(t.line||{}).color)&&n.opacity(r)&&i.hasLines(t)&&t.line.width?r:t.fillcolor}},{\"../../components/color\":593,\"./subtypes\":1135}],1122:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/fx\"),a=t(\"../../registry\"),o=t(\"./get_trace_color\"),s=t(\"../../components/color\"),l=n.fillText;e.exports=function(t,e,r,c){var u=t.cd,h=u[0].trace,f=t.xa,p=t.ya,d=f.c2p(e),g=p.c2p(r),v=[d,g],m=h.hoveron||\"\",y=-1!==h.mode.indexOf(\"markers\")?3:.5;if(-1!==m.indexOf(\"points\")){var x=function(t){var e=Math.max(y,t.mrc||0),r=f.c2p(t.x)-d,n=p.c2p(t.y)-g;return Math.max(Math.sqrt(r*r+n*n)-e,1-y/e)},b=i.getDistanceFunction(c,function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(f.c2p(t.x)-d);return n<e?r*n/e:n-e+r},function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(p.c2p(t.y)-g);return n<e?r*n/e:n-e+r},x);if(i.getClosest(u,b,t),!1!==t.index){var _=u[t.index],w=f.c2p(_.x,!0),k=p.c2p(_.y,!0),T=_.mrc||1;t.index=_.i;var A=u[0].t.orientation,M=A&&(_.sNorm||_.s),S=\"h\"===A?M:_.x,E=\"v\"===A?M:_.y;return n.extendFlat(t,{color:o(h,_),x0:w-T,x1:w+T,xLabelVal:S,y0:k-T,y1:k+T,yLabelVal:E,spikeDistance:x(_),hovertemplate:h.hovertemplate}),l(_,h,t),a.getComponentMethod(\"errorbars\",\"hoverInfo\")(_,h,t),[t]}}if(-1!==m.indexOf(\"fills\")&&h._polygons){var C,L,P,O,z,I,D,R,F,B=h._polygons,N=[],j=!1,U=1/0,V=-1/0,q=1/0,H=-1/0;for(C=0;C<B.length;C++)(P=B[C]).contains(v)&&(j=!j,N.push(P),q=Math.min(q,P.ymin),H=Math.max(H,P.ymax));if(j){var G=((q=Math.max(q,0))+(H=Math.min(H,p._length)))/2;for(C=0;C<N.length;C++)for(O=N[C].pts,L=1;L<O.length;L++)(R=O[L-1][1])>G!=(F=O[L][1])>=G&&(I=O[L-1][0],D=O[L][0],F-R&&(z=I+(D-I)*(G-R)/(F-R),U=Math.min(U,z),V=Math.max(V,z)));U=Math.max(U,0),V=Math.min(V,f._length);var Y=s.defaultLine;return s.opacity(h.fillcolor)?Y=h.fillcolor:s.opacity((h.line||{}).color)&&(Y=h.line.color),n.extendFlat(t,{distance:t.maxHoverDistance,x0:U,x1:V,y0:G,y1:G,color:Y,hovertemplate:!1}),delete t.index,h.text&&!Array.isArray(h.text)?t.text=String(h.text):t.text=h.name,[t]}}}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"../../registry\":847,\"./get_trace_color\":1121}],1123:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports={hasLines:n.hasLines,hasMarkers:n.hasMarkers,hasText:n.hasText,isBubble:n.isBubble,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./cross_trace_calc\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\"),colorbar:t(\"./marker_colorbar\"),style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"./select\"),animatable:!0,moduleType:\"trace\",name:\"scatter\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"./arrays_to_calcdata\":1111,\"./attributes\":1112,\"./calc\":1113,\"./cross_trace_calc\":1117,\"./cross_trace_defaults\":1118,\"./defaults\":1119,\"./hover\":1122,\"./marker_colorbar\":1129,\"./plot\":1131,\"./select\":1132,\"./style\":1134,\"./subtypes\":1135}],1124:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s,l){var c=(t.marker||{}).color;(s(\"line.color\",r),i(t,\"line\"))?a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}):s(\"line.color\",!n(c)&&c||r);s(\"line.width\"),(l||{}).noDash||s(\"line.dash\")}},{\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"../../lib\":719}],1125:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.BADNUM,a=n.LOG_CLIP,o=a+.5,s=a-.5,l=t(\"../../lib\"),c=l.segmentsIntersect,u=l.constrain,h=t(\"./constants\");e.exports=function(t,e){var r,n,a,f,p,d,g,v,m,y,x,b,_,w,k,T,A,M,S=e.xaxis,E=e.yaxis,C=\"log\"===S.type,L=\"log\"===E.type,P=S._length,O=E._length,z=e.connectGaps,I=e.baseTolerance,D=e.shape,R=\"linear\"===D,F=e.fill&&\"none\"!==e.fill,B=[],N=h.minTolerance,j=t.length,U=new Array(j),V=0;function q(e){var r=t[e];if(!r)return!1;var n=S.c2p(r.x),a=E.c2p(r.y);if(n===i){if(C&&(n=S.c2p(r.x,!0)),n===i)return!1;L&&a===i&&(n*=Math.abs(S._m*O*(S._m>0?o:s)/(E._m*P*(E._m>0?o:s)))),n*=1e3}if(a===i){if(L&&(a=E.c2p(r.y,!0)),a===i)return!1;a*=1e3}return[n,a]}function H(t,e,r,n){var i=r-t,a=n-e,o=.5-t,s=.5-e,l=i*i+a*a,c=i*o+a*s;if(c>0&&c<l){var u=o*a-s*i;if(u*u<l)return!0}}function G(t,e){var r=t[0]/P,n=t[1]/O,i=Math.max(0,-r,r-1,-n,n-1);return i&&void 0!==A&&H(r,n,A,M)&&(i=0),i&&e&&H(r,n,e[0]/P,e[1]/O)&&(i=0),(1+h.toleranceGrowth*i)*I}function Y(t,e){var r=t[0]-e[0],n=t[1]-e[1];return Math.sqrt(r*r+n*n)}var W,X,Z,J,K,$,Q,tt=h.maxScreensAway,et=-P*tt,rt=P*(1+tt),nt=-O*tt,it=O*(1+tt),at=[[et,nt,rt,nt],[rt,nt,rt,it],[rt,it,et,it],[et,it,et,nt]];function ot(t){if(t[0]<et||t[0]>rt||t[1]<nt||t[1]>it)return[u(t[0],et,rt),u(t[1],nt,it)]}function st(t,e){return t[0]===e[0]&&(t[0]===et||t[0]===rt)||(t[1]===e[1]&&(t[1]===nt||t[1]===it)||void 0)}function lt(t,e,r){return function(n,i){var a=ot(n),o=ot(i),s=[];if(a&&o&&st(a,o))return s;a&&s.push(a),o&&s.push(o);var c=2*l.constrain((n[t]+i[t])/2,e,r)-((a||n)[t]+(o||i)[t]);c&&((a&&o?c>0==a[t]>o[t]?a:o:a||o)[t]+=c);return s}}function ct(t){var e=t[0],r=t[1],n=e===U[V-1][0],i=r===U[V-1][1];if(!n||!i)if(V>1){var a=e===U[V-2][0],o=r===U[V-2][1];n&&(e===et||e===rt)&&a?o?V--:U[V-1]=t:i&&(r===nt||r===it)&&o?a?V--:U[V-1]=t:U[V++]=t}else U[V++]=t}function ut(t){U[V-1][0]!==t[0]&&U[V-1][1]!==t[1]&&ct([Z,J]),ct(t),K=null,Z=J=0}function ht(t){if(A=t[0]/P,M=t[1]/O,W=t[0]<et?et:t[0]>rt?rt:0,X=t[1]<nt?nt:t[1]>it?it:0,W||X){if(V)if(K){var e=Q(K,t);e.length>1&&(ut(e[0]),U[V++]=e[1])}else $=Q(U[V-1],t)[0],U[V++]=$;else U[V++]=[W||t[0],X||t[1]];var r=U[V-1];W&&X&&(r[0]!==W||r[1]!==X)?(K&&(Z!==W&&J!==X?ct(Z&&J?(n=K,a=(i=t)[0]-n[0],o=(i[1]-n[1])/a,(n[1]*i[0]-i[1]*n[0])/a>0?[o>0?et:rt,it]:[o>0?rt:et,nt]):[Z||W,J||X]):Z&&J&&ct([Z,J])),ct([W,X])):Z-W&&J-X&&ct([W||Z,X||J]),K=t,Z=W,J=X}else K&&ut(Q(K,t)[0]),U[V++]=t;var n,i,a,o}for(\"linear\"===D||\"spline\"===D?Q=function(t,e){for(var r=[],n=0,i=0;i<4;i++){var a=at[i],o=c(t[0],t[1],e[0],e[1],a[0],a[1],a[2],a[3]);o&&(!n||Math.abs(o.x-r[0][0])>1||Math.abs(o.y-r[0][1])>1)&&(o=[o.x,o.y],n&&Y(o,t)<Y(r[0],t)?r.unshift(o):r.push(o),n++)}return r}:\"hv\"===D||\"vh\"===D?Q=function(t,e){var r=[],n=ot(t),i=ot(e);return n&&i&&st(n,i)?r:(n&&r.push(n),i&&r.push(i),r)}:\"hvh\"===D?Q=lt(0,et,rt):\"vhv\"===D&&(Q=lt(1,nt,it)),r=0;r<j;r++)if(n=q(r)){for(V=0,K=null,ht(n),r++;r<j;r++){if(!(f=q(r))){if(z)continue;break}if(R&&e.simplify){var ft=q(r+1);if(y=Y(f,n),F&&(0===V||V===j-1)||!(y<G(f,ft)*N)){for(v=[(f[0]-n[0])/y,(f[1]-n[1])/y],p=n,x=y,b=w=k=0,g=!1,a=f,r++;r<t.length;r++){if(d=ft,ft=q(r+1),!d){if(z)continue;break}if(T=(m=[d[0]-n[0],d[1]-n[1]])[0]*v[1]-m[1]*v[0],w=Math.min(w,T),(k=Math.max(k,T))-w>G(d,ft))break;a=d,(_=m[0]*v[0]+m[1]*v[1])>x?(x=_,f=d,g=!1):_<b&&(b=_,p=d,g=!0)}if(g?(ht(f),a!==p&&ht(p)):(p!==n&&ht(p),a!==f&&ht(f)),ht(a),r>=t.length||!d)break;ht(d),n=d}}else ht(f)}K&&ct([Z||K[0],J||K[1]]),B.push(U.slice(0,V))}return B}},{\"../../constants/numerical\":695,\"../../lib\":719,\"./constants\":1116}],1126:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){\"spline\"===r(\"line.shape\")&&r(\"line.smoothing\")}},{}],1127:[function(t,e,r){\"use strict\";var n={tonextx:1,tonexty:1,tonext:1};e.exports=function(t,e,r){var i,a,o,s,l,c={},u=!1,h=-1,f=0,p=-1;for(a=0;a<r.length;a++)(o=(i=r[a][0].trace).stackgroup||\"\")?o in c?l=c[o]:(l=c[o]=f,f++):i.fill in n&&p>=0?l=p:(l=p=f,f++),l<h&&(u=!0),i._groupIndex=h=l;var d=r.slice();u&&d.sort(function(t,e){var r=t[0].trace,n=e[0].trace;return r._groupIndex-n._groupIndex||r.index-n.index});var g={};for(a=0;a<d.length;a++)o=(i=d[a][0].trace).stackgroup||\"\",!0===i.visible?(i._nexttrace=null,i.fill in n&&(s=g[o],i._prevtrace=s||null,s&&(s._nexttrace=i)),i._ownfill=i.fill&&(\"tozero\"===i.fill.substr(0,6)||\"toself\"===i.fill||\"to\"===i.fill.substr(0,2)&&!i._prevtrace),g[o]=i):i._prevtrace=i._nexttrace=i._ownfill=null;return d}},{}],1128:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t){var e=t.marker,r=e.sizeref||1,i=e.sizemin||0,a=\"area\"===e.sizemode?function(t){return Math.sqrt(t/r)}:function(t){return t/r};return function(t){var e=a(t/2);return n(e)&&e>0?Math.max(e,i):0}}},{\"fast-isnumeric\":225}],1129:[function(t,e,r){\"use strict\";e.exports={container:\"marker\",min:\"cmin\",max:\"cmax\"}},{}],1130:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"./subtypes\");e.exports=function(t,e,r,s,l,c){var u=o.isBubble(t),h=(t.line||{}).color;(c=c||{},h&&(r=h),l(\"marker.symbol\"),l(\"marker.opacity\",u?.7:1),l(\"marker.size\"),l(\"marker.color\",r),i(t,\"marker\")&&a(t,e,s,l,{prefix:\"marker.\",cLetter:\"c\"}),c.noSelect||(l(\"selected.marker.color\"),l(\"unselected.marker.color\"),l(\"selected.marker.size\"),l(\"unselected.marker.size\")),c.noLine||(l(\"marker.line.color\",h&&!Array.isArray(h)&&e.marker.color!==h?h:u?n.background:n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,l,{prefix:\"marker.line.\",cLetter:\"c\"}),l(\"marker.line.width\",u?1:0)),u&&(l(\"marker.sizeref\"),l(\"marker.sizemin\"),l(\"marker.sizemode\")),c.gradient)&&(\"none\"!==l(\"marker.gradient.type\")&&l(\"marker.gradient.color\"))}},{\"../../components/color\":593,\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"./subtypes\":1135}],1131:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=a.ensureSingle,s=a.identity,l=t(\"../../components/drawing\"),c=t(\"./subtypes\"),u=t(\"./line_points\"),h=t(\"./link_traces\"),f=t(\"../../lib/polygon\").tester;function p(t,e,r,h,p,d,g){var v;!function(t,e,r,i,o){var s=r.xaxis,l=r.yaxis,u=n.extent(a.simpleMap(s.range,s.r2c)),h=n.extent(a.simpleMap(l.range,l.r2c)),f=i[0].trace;if(!c.hasMarkers(f))return;var p=f.marker.maxdisplayed;if(0===p)return;var d=i.filter(function(t){return t.x>=u[0]&&t.x<=u[1]&&t.y>=h[0]&&t.y<=h[1]}),g=Math.ceil(d.length/p),v=0;o.forEach(function(t,r){var n=t[0].trace;c.hasMarkers(n)&&n.marker.maxdisplayed>0&&r<e&&v++});var m=Math.round(v*g/3+Math.floor(v/3)*g/7.1);i.forEach(function(t){delete t.vis}),d.forEach(function(t,e){0===Math.round((e+m)%g)&&(t.vis=!0)})}(0,e,r,h,p);var m=!!g&&g.duration>0;function y(t){return m?t.transition():t}var x=r.xaxis,b=r.yaxis,_=h[0].trace,w=_.line,k=n.select(d),T=o(k,\"g\",\"errorbars\"),A=o(k,\"g\",\"lines\"),M=o(k,\"g\",\"points\"),S=o(k,\"g\",\"text\");if(i.getComponentMethod(\"errorbars\",\"plot\")(t,T,r,g),!0===_.visible){var E,C;y(k).style(\"opacity\",_.opacity);var L=_.fill.charAt(_.fill.length-1);\"x\"!==L&&\"y\"!==L&&(L=\"\"),h[0][r.isRangePlot?\"nodeRangePlot3\":\"node3\"]=k;var P,O,z=\"\",I=[],D=_._prevtrace;D&&(z=D._prevRevpath||\"\",C=D._nextFill,I=D._polygons);var R,F,B,N,j,U,V,q=\"\",H=\"\",G=[],Y=a.noop;if(E=_._ownFill,c.hasLines(_)||\"none\"!==_.fill){for(C&&C.datum(h),-1!==[\"hv\",\"vh\",\"hvh\",\"vhv\"].indexOf(w.shape)?(R=l.steps(w.shape),F=l.steps(w.shape.split(\"\").reverse().join(\"\"))):R=F=\"spline\"===w.shape?function(t){var e=t[t.length-1];return t.length>1&&t[0][0]===e[0]&&t[0][1]===e[1]?l.smoothclosed(t.slice(1),w.smoothing):l.smoothopen(t,w.smoothing)}:function(t){return\"M\"+t.join(\"L\")},B=function(t){return F(t.reverse())},G=u(h,{xaxis:x,yaxis:b,connectGaps:_.connectgaps,baseTolerance:Math.max(w.width||1,3)/4,shape:w.shape,simplify:w.simplify,fill:_.fill}),V=_._polygons=new Array(G.length),v=0;v<G.length;v++)_._polygons[v]=f(G[v]);G.length&&(N=G[0][0],U=(j=G[G.length-1])[j.length-1]),Y=function(t){return function(e){if(P=R(e),O=B(e),q?L?(q+=\"L\"+P.substr(1),H=O+\"L\"+H.substr(1)):(q+=\"Z\"+P,H=O+\"Z\"+H):(q=P,H=O),c.hasLines(_)&&e.length>1){var r=n.select(this);if(r.datum(h),t)y(r.style(\"opacity\",0).attr(\"d\",P).call(l.lineGroupStyle)).style(\"opacity\",1);else{var i=y(r);i.attr(\"d\",P),l.singleLineStyle(h,i)}}}}}var W=A.selectAll(\".js-line\").data(G);y(W.exit()).style(\"opacity\",0).remove(),W.each(Y(!1)),W.enter().append(\"path\").classed(\"js-line\",!0).style(\"vector-effect\",\"non-scaling-stroke\").call(l.lineGroupStyle).each(Y(!0)),l.setClipUrl(W,r.layerClipId,t),G.length?(E?(E.datum(h),N&&U&&(L?(\"y\"===L?N[1]=U[1]=b.c2p(0,!0):\"x\"===L&&(N[0]=U[0]=x.c2p(0,!0)),y(E).attr(\"d\",\"M\"+U+\"L\"+N+\"L\"+q.substr(1)).call(l.singleFillStyle)):y(E).attr(\"d\",q+\"Z\").call(l.singleFillStyle))):C&&(\"tonext\"===_.fill.substr(0,6)&&q&&z?(\"tonext\"===_.fill?y(C).attr(\"d\",q+\"Z\"+z+\"Z\").call(l.singleFillStyle):y(C).attr(\"d\",q+\"L\"+z.substr(1)+\"Z\").call(l.singleFillStyle),_._polygons=_._polygons.concat(I)):(Z(C),_._polygons=null)),_._prevRevpath=H,_._prevPolygons=V):(E?Z(E):C&&Z(C),_._polygons=_._prevRevpath=_._prevPolygons=null),M.datum(h),S.datum(h),function(e,i,a){var o,u=a[0].trace,h=c.hasMarkers(u),f=c.hasText(u),p=tt(u),d=et,g=et;if(h||f){var v=s,_=u.stackgroup,w=_&&\"infer zero\"===t._fullLayout._scatterStackOpts[x._id+b._id][_].stackgaps;u.marker.maxdisplayed||u._needsCull?v=w?K:J:_&&!w&&(v=$),h&&(d=v),f&&(g=v)}var k,T=(o=e.selectAll(\"path.point\").data(d,p)).enter().append(\"path\").classed(\"point\",!0);m&&T.call(l.pointStyle,u,t).call(l.translatePoints,x,b).style(\"opacity\",0).transition().style(\"opacity\",1),o.order(),h&&(k=l.makePointStyleFns(u)),o.each(function(e){var i=n.select(this),a=y(i);l.translatePoint(e,a,x,b)?(l.singlePointStyle(e,a,u,k,t),r.layerClipId&&l.hideOutsideRangePoint(e,a,x,b,u.xcalendar,u.ycalendar),u.customdata&&i.classed(\"plotly-customdata\",null!==e.data&&void 0!==e.data)):a.remove()}),m?o.exit().transition().style(\"opacity\",0).remove():o.exit().remove(),(o=i.selectAll(\"g\").data(g,p)).enter().append(\"g\").classed(\"textpoint\",!0).append(\"text\"),o.order(),o.each(function(t){var e=n.select(this),i=y(e.select(\"text\"));l.translatePoint(t,i,x,b)?r.layerClipId&&l.hideOutsideRangePoint(t,e,x,b,u.xcalendar,u.ycalendar):e.remove()}),o.selectAll(\"text\").call(l.textPointStyle,u,t).each(function(t){var e=x.c2p(t.x),r=b.c2p(t.y);n.select(this).selectAll(\"tspan.line\").each(function(){y(n.select(this)).attr({x:e,y:r})})}),o.exit().remove()}(M,S,h);var X=!1===_.cliponaxis?null:r.layerClipId;l.setClipUrl(M,X,t),l.setClipUrl(S,X,t)}function Z(t){y(t).attr(\"d\",\"M0,0Z\")}function J(t){return t.filter(function(t){return!t.gap&&t.vis})}function K(t){return t.filter(function(t){return t.vis})}function $(t){return t.filter(function(t){return!t.gap})}function Q(t){return t.id}function tt(t){if(t.ids)return Q}function et(){return!1}}e.exports=function(t,e,r,i,a,c){var u,f,d=!a,g=!!a&&a.duration>0,v=h(t,e,r);((u=i.selectAll(\"g.trace\").data(v,function(t){return t[0].trace.uid})).enter().append(\"g\").attr(\"class\",function(t){return\"trace scatter trace\"+t[0].trace.uid}).style(\"stroke-miterlimit\",2),u.order(),function(t,e,r){e.each(function(e){var i=o(n.select(this),\"g\",\"fills\");l.setClipUrl(i,r.layerClipId,t);var a=e[0].trace,c=[];a._ownfill&&c.push(\"_ownFill\"),a._nexttrace&&c.push(\"_nextFill\");var u=i.selectAll(\"g\").data(c,s);u.enter().append(\"g\"),u.exit().each(function(t){a[t]=null}).remove(),u.order().each(function(t){a[t]=o(n.select(this),\"path\",\"js-fill\")})})}(t,u,e),g)?(c&&(f=c()),n.transition().duration(a.duration).ease(a.easing).each(\"end\",function(){f&&f()}).each(\"interrupt\",function(){f&&f()}).each(function(){i.selectAll(\"g.trace\").each(function(r,n){p(t,n,e,r,v,this,a)})})):u.each(function(r,n){p(t,n,e,r,v,this,a)});d&&u.exit().remove(),i.selectAll(\"path:not([d])\").remove()}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/polygon\":731,\"../../registry\":847,\"./line_points\":1125,\"./link_traces\":1127,\"./subtypes\":1135,d3:163}],1132:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports=function(t,e){var r,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[],h=s[0].trace;if(!n.hasMarkers(h)&&!n.hasText(h))return[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)i=s[r],a=l.c2p(i.x),o=c.c2p(i.y),null!==i.i&&e.contains([a,o],!1,r,t)?(u.push({pointNumber:i.i,x:l.c2d(i.x),y:c.c2d(i.y)}),i.selected=1):i.selected=0;return u}},{\"./subtypes\":1135}],1133:[function(t,e,r){\"use strict\";var n=[\"orientation\",\"groupnorm\",\"stackgaps\"];e.exports=function(t,e,r,i){var a=r._scatterStackOpts,o=i(\"stackgroup\");if(o){var s=e.xaxis+e.yaxis,l=a[s];l||(l=a[s]={});var c=l[o],u=!1;c?c.traces.push(e):(c=l[o]={traceIndices:[],traces:[e]},u=!0);for(var h={orientation:e.x&&!e.y?\"h\":\"v\"},f=0;f<n.length;f++){var p=n[f],d=p+\"Found\";if(!c[d]){var g=void 0!==t[p],v=\"orientation\"===p;if((g||u)&&(c[p]=i(p,h[p]),v&&(c.fillDflt=\"h\"===c[p]?\"tonextx\":\"tonexty\"),g&&(c[d]=!0,!u&&(delete c.traces[0][p],v))))for(var m=0;m<c.traces.length-1;m++){var y=c.traces[m];y._input.fill!==y.fill&&(y.fill=c.fillDflt)}}}return c}}},{}],1134:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../registry\");function o(t,e,r){i.pointStyle(t.selectAll(\"path.point\"),e,r)}function s(t,e,r){i.textPointStyle(t.selectAll(\"text\"),e,r)}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.trace.scatter\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.selectAll(\"g.points\").each(function(e){o(n.select(this),e.trace||e[0].trace,t)}),e.selectAll(\"g.text\").each(function(e){s(n.select(this),e.trace||e[0].trace,t)}),e.selectAll(\"g.trace path.js-line\").call(i.lineGroupStyle),e.selectAll(\"g.trace path.js-fill\").call(i.fillGroupStyle),a.getComponentMethod(\"errorbars\",\"style\")(e)},stylePoints:o,styleText:s,styleOnSelect:function(t,e,r){var n=e[0].trace;n.selectedpoints?(i.selectedPointStyle(r.selectAll(\"path.point\"),n),i.selectedTextStyle(r.selectAll(\"text\"),n)):(o(r,n,t),s(r,n,t))}}},{\"../../components/drawing\":614,\"../../registry\":847,d3:163}],1135:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports={hasLines:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"lines\")},hasMarkers:function(t){return t.visible&&(t.mode&&-1!==t.mode.indexOf(\"markers\")||\"splom\"===t.type)},hasText:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"text\")},isBubble:function(t){return n.isPlainObject(t.marker)&&n.isArrayOrTypedArray(t.marker.size)}}},{\"../../lib\":719}],1136:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i,a){a=a||{},i(\"textposition\"),n.coerceFont(i,\"textfont\",r.font),a.noSelect||(i(\"selected.textfont.color\"),i(\"unselected.textfont.color\"))}},{\"../../lib\":719}],1137:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");e.exports=function(t,e,r,a){var o,s=a(\"x\"),l=a(\"y\");if(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],r),s){var c=n.minRowLength(s);l?o=Math.min(c,n.minRowLength(l)):(o=c,a(\"y0\"),a(\"dy\"))}else{if(!l)return 0;o=n.minRowLength(l),a(\"x0\"),a(\"dx\")}return e._length=o,o}},{\"../../lib\":719,\"../../registry\":847}],1138:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../constants/gl3d_dashes\"),l=t(\"../../constants/gl3d_markers\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../plot_api/edit_types\").overrideAll,h=n.line,f=n.marker,p=f.line,d=c({width:h.width,dash:{valType:\"enumerated\",values:Object.keys(s),dflt:\"solid\"}},i(\"line\"));var g=e.exports=u({x:n.x,y:n.y,z:{valType:\"data_array\"},text:c({},n.text,{}),hovertext:c({},n.hovertext,{}),hovertemplate:a(),mode:c({},n.mode,{dflt:\"lines+markers\"}),surfaceaxis:{valType:\"enumerated\",values:[-1,0,1,2],dflt:-1},surfacecolor:{valType:\"color\"},projection:{x:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},y:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},z:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}}},connectgaps:n.connectgaps,line:d,marker:c({symbol:{valType:\"enumerated\",values:Object.keys(l),dflt:\"circle\",arrayOk:!0},size:c({},f.size,{dflt:8}),sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode,opacity:c({},f.opacity,{arrayOk:!1}),colorbar:f.colorbar,line:c({width:c({},p.width,{arrayOk:!1})},i(\"marker.line\"))},i(\"marker\")),textposition:c({},n.textposition,{dflt:\"top center\"}),textfont:{color:n.textfont.color,size:n.textfont.size,family:c({},n.textfont.family,{arrayOk:!1})},hoverinfo:c({},o.hoverinfo)},\"calc\",\"nested\");g.x.editType=g.y.editType=g.z.editType=\"calc+clearAxisTypes\"},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../constants/gl3d_dashes\":692,\"../../constants/gl3d_markers\":693,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1139:[function(t,e,r){\"use strict\";var n=t(\"../scatter/arrays_to_calcdata\"),i=t(\"../scatter/colorscale_calc\");e.exports=function(t,e){var r=[{x:!1,y:!1,trace:e,t:{}}];return n(r,e),i(t,e),r}},{\"../scatter/arrays_to_calcdata\":1111,\"../scatter/colorscale_calc\":1115}],1140:[function(t,e,r){\"use strict\";var n=t(\"../../registry\");function i(t,e,r,i){if(!e||!e.visible)return null;for(var a=n.getComponentMethod(\"errorbars\",\"makeComputeError\")(e),o=new Array(t.length),s=0;s<t.length;s++){var l=a(+t[s],s);if(\"log\"===i.type){var c=i.c2l(t[s]),u=t[s]-l[0],h=t[s]+l[1];if(o[s]=[(i.c2l(u,!0)-c)*r,(i.c2l(h,!0)-c)*r],u>0){var f=i.c2l(u);i._lowerLogErrorBound||(i._lowerLogErrorBound=f),i._lowerErrorBound=Math.min(i._lowerLogErrorBound,f)}}else o[s]=[-l[0]*r,l[1]*r]}return o}e.exports=function(t,e,r){var n=[i(t.x,t.error_x,e[0],r.xaxis),i(t.y,t.error_y,e[1],r.yaxis),i(t.z,t.error_z,e[2],r.zaxis)],a=function(t){for(var e=0;e<t.length;e++)if(t[e])return t[e].length;return 0}(n);if(0===a)return null;for(var o=new Array(a),s=0;s<a;s++){for(var l=[[0,0,0],[0,0,0]],c=0;c<3;c++)if(n[c])for(var u=0;u<2;u++)l[u][c]=n[c][s][u];o[s]=l}return o}},{\"../../registry\":847}],1141:[function(t,e,r){\"use strict\";var n=t(\"gl-line3d\"),i=t(\"gl-scatter3d\"),a=t(\"gl-error3d\"),o=t(\"gl-mesh3d\"),s=t(\"delaunay-triangulate\"),l=t(\"../../lib\"),c=t(\"../../lib/str2rgbarray\"),u=t(\"../../lib/gl_format_color\").formatColor,h=t(\"../scatter/make_bubble_size_func\"),f=t(\"../../constants/gl3d_dashes\"),p=t(\"../../constants/gl3d_markers\"),d=t(\"./calc_errors\");function g(t,e){this.scene=t,this.uid=e,this.linePlot=null,this.scatterPlot=null,this.errorBars=null,this.textMarkers=null,this.delaunayMesh=null,this.color=null,this.mode=\"\",this.dataPoints=[],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.textLabels=null,this.data=null}var v=g.prototype;function m(t){return null==t?0:t.indexOf(\"left\")>-1?-1:t.indexOf(\"right\")>-1?1:0}function y(t){return null==t?0:t.indexOf(\"top\")>-1?-1:t.indexOf(\"bottom\")>-1?1:0}function x(t,e){return e(4*t)}function b(t){return p[t]}function _(t,e,r,n,i){var a=null;if(l.isArrayOrTypedArray(t)){a=[];for(var o=0;o<e;o++)void 0===t[o]?a[o]=n:a[o]=r(t[o],i)}else a=r(t,l.identity);return a}function w(t,e){var r,n,i,a,o,s,f=[],p=t.fullSceneLayout,g=t.dataScale,v=p.xaxis,w=p.yaxis,k=p.zaxis,T=e.marker,A=e.line,M=e.x||[],S=e.y||[],E=e.z||[],C=M.length,L=e.xcalendar,P=e.ycalendar,O=e.zcalendar;for(o=0;o<C;o++)r=v.d2l(M[o],0,L)*g[0],n=w.d2l(S[o],0,P)*g[1],i=k.d2l(E[o],0,O)*g[2],f[o]=[r,n,i];if(Array.isArray(e.text))s=e.text;else if(void 0!==e.text)for(s=new Array(C),o=0;o<C;o++)s[o]=e.text;if(a={position:f,mode:e.mode,text:s},\"line\"in e&&(a.lineColor=u(A,1,C),a.lineWidth=A.width,a.lineDashes=A.dash),\"marker\"in e){var z=h(e);a.scatterColor=u(T,1,C),a.scatterSize=_(T.size,C,x,20,z),a.scatterMarker=_(T.symbol,C,b,\"\\u25cf\"),a.scatterLineWidth=T.line.width,a.scatterLineColor=u(T.line,1,C),a.scatterAngle=0}\"textposition\"in e&&(a.textOffset=function(t){var e=[0,0];if(Array.isArray(t))for(var r=0;r<t.length;r++)e[r]=[0,0],t[r]&&(e[r][0]=m(t[r]),e[r][1]=y(t[r]));else e[0]=m(t),e[1]=y(t);return e}(e.textposition),a.textColor=u(e.textfont,1,C),a.textSize=_(e.textfont.size,C,l.identity,12),a.textFont=e.textfont.family,a.textAngle=0);var I=[\"x\",\"y\",\"z\"];for(a.project=[!1,!1,!1],a.projectScale=[1,1,1],a.projectOpacity=[1,1,1],o=0;o<3;++o){var D=e.projection[I[o]];(a.project[o]=D.show)&&(a.projectOpacity[o]=D.opacity,a.projectScale[o]=D.scale)}a.errorBounds=d(e,g,p);var R=function(t){for(var e=[0,0,0],r=[[0,0,0],[0,0,0],[0,0,0]],n=[1,1,1],i=0;i<3;i++){var a=t[i];a&&!1!==a.copy_zstyle&&!1!==t[2].visible&&(a=t[2]),a&&a.visible&&(e[i]=a.width/2,r[i]=c(a.color),n[i]=a.thickness)}return{capSize:e,color:r,lineWidth:n}}([e.error_x,e.error_y,e.error_z]);return a.errorColor=R.color,a.errorLineWidth=R.lineWidth,a.errorCapSize=R.capSize,a.delaunayAxis=e.surfaceaxis,a.delaunayColor=c(e.surfacecolor),a}function k(t){if(Array.isArray(t)){var e=t[0];return Array.isArray(e)&&(t=e),\"rgb(\"+t.slice(0,3).map(function(t){return Math.round(255*t)})+\")\"}return null}v.handlePick=function(t){if(t.object&&(t.object===this.linePlot||t.object===this.delaunayMesh||t.object===this.textMarkers||t.object===this.scatterPlot)){var e=t.index=t.data.index;return t.object.highlight&&t.object.highlight(null),this.scatterPlot&&(t.object=this.scatterPlot,this.scatterPlot.highlight(t.data)),t.textLabel=\"\",this.textLabels&&(Array.isArray(this.textLabels)?(this.textLabels[e]||0===this.textLabels[e])&&(t.textLabel=this.textLabels[e]):t.textLabel=this.textLabels),t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]],!0}},v.update=function(t){var e,r,l,c,u=this.scene.glplot.gl,h=f.solid;this.data=t;var p=w(this.scene,t);\"mode\"in p&&(this.mode=p.mode),\"lineDashes\"in p&&p.lineDashes in f&&(h=f[p.lineDashes]),this.color=k(p.scatterColor)||k(p.lineColor),this.dataPoints=p.position,e={gl:this.scene.glplot.gl,position:p.position,color:p.lineColor,lineWidth:p.lineWidth||1,dashes:h[0],dashScale:h[1],opacity:t.opacity,connectGaps:t.connectgaps},-1!==this.mode.indexOf(\"lines\")?this.linePlot?this.linePlot.update(e):(this.linePlot=n(e),this.linePlot._trace=this,this.scene.glplot.add(this.linePlot)):this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose(),this.linePlot=null);var d=t.opacity;if(t.marker&&t.marker.opacity&&(d*=t.marker.opacity),r={gl:this.scene.glplot.gl,position:p.position,color:p.scatterColor,size:p.scatterSize,glyph:p.scatterMarker,opacity:d,orthographic:!0,lineWidth:p.scatterLineWidth,lineColor:p.scatterLineColor,project:p.project,projectScale:p.projectScale,projectOpacity:p.projectOpacity},-1!==this.mode.indexOf(\"markers\")?this.scatterPlot?this.scatterPlot.update(r):(this.scatterPlot=i(r),this.scatterPlot._trace=this,this.scatterPlot.highlightScale=1,this.scene.glplot.add(this.scatterPlot)):this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose(),this.scatterPlot=null),c={gl:this.scene.glplot.gl,position:p.position,glyph:p.text,color:p.textColor,size:p.textSize,angle:p.textAngle,alignment:p.textOffset,font:p.textFont,orthographic:!0,lineWidth:0,project:!1,opacity:t.opacity},this.textLabels=t.hovertext||t.text,-1!==this.mode.indexOf(\"text\")?this.textMarkers?this.textMarkers.update(c):(this.textMarkers=i(c),this.textMarkers._trace=this,this.textMarkers.highlightScale=1,this.scene.glplot.add(this.textMarkers)):this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose(),this.textMarkers=null),l={gl:this.scene.glplot.gl,position:p.position,color:p.errorColor,error:p.errorBounds,lineWidth:p.errorLineWidth,capSize:p.errorCapSize,opacity:t.opacity},this.errorBars?p.errorBounds?this.errorBars.update(l):(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose(),this.errorBars=null):p.errorBounds&&(this.errorBars=a(l),this.errorBars._trace=this,this.scene.glplot.add(this.errorBars)),p.delaunayAxis>=0){var g=function(t,e,r){var n,i=(r+1)%3,a=(r+2)%3,o=[],l=[];for(n=0;n<t.length;++n){var c=t[n];!isNaN(c[i])&&isFinite(c[i])&&!isNaN(c[a])&&isFinite(c[a])&&(o.push([c[i],c[a]]),l.push(n))}var u=s(o);for(n=0;n<u.length;++n)for(var h=u[n],f=0;f<h.length;++f)h[f]=l[h[f]];return{positions:t,cells:u,meshColor:e}}(p.position,p.delaunayColor,p.delaunayAxis);g.opacity=t.opacity,this.delaunayMesh?this.delaunayMesh.update(g):(g.gl=u,this.delaunayMesh=o(g),this.delaunayMesh._trace=this,this.scene.glplot.add(this.delaunayMesh))}else this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose(),this.delaunayMesh=null)},v.dispose=function(){this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose()),this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose()),this.errorBars&&(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose()),this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose()),this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose())},e.exports=function(t,e){var r=new g(t,e.uid);return r.update(e),r}},{\"../../constants/gl3d_dashes\":692,\"../../constants/gl3d_markers\":693,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../scatter/make_bubble_size_func\":1128,\"./calc_errors\":1140,\"delaunay-triangulate\":165,\"gl-error3d\":247,\"gl-line3d\":255,\"gl-mesh3d\":280,\"gl-scatter3d\":297}],1142:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,n){return i.coerce(t,e,c,r,n)}if(function(t,e,r,i){var a=0,o=r(\"x\"),s=r(\"y\"),l=r(\"z\");n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],i),o&&s&&l&&(a=Math.min(o.length,s.length,l.length),e._length=e._xlength=e._ylength=e._zlength=a);return a}(t,e,h,u)){h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),a.hasLines(e)&&(h(\"connectgaps\"),s(t,e,r,u,h)),a.hasMarkers(e)&&o(t,e,r,u,h,{noSelect:!0}),a.hasText(e)&&l(t,e,u,h,{noSelect:!0});var f=(e.line||{}).color,p=(e.marker||{}).color;h(\"surfaceaxis\")>=0&&h(\"surfacecolor\",f||p);for(var d=[\"x\",\"y\",\"z\"],g=0;g<3;++g){var v=\"projection.\"+d[g];h(v+\".show\")&&(h(v+\".opacity\"),h(v+\".scale\"))}var m=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");m(t,e,f||p||r,{axis:\"z\"}),m(t,e,f||p||r,{axis:\"y\",inherit:\"z\"}),m(t,e,f||p||r,{axis:\"x\",inherit:\"z\"})}else e.visible=!1}},{\"../../lib\":719,\"../../registry\":847,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1138}],1143:[function(t,e,r){\"use strict\";e.exports={plot:t(\"./convert\"),attributes:t(\"./attributes\"),markerSymbols:t(\"../../constants/gl3d_markers\"),supplyDefaults:t(\"./defaults\"),colorbar:[{container:\"marker\",min:\"cmin\",max:\"cmax\"},{container:\"line\",min:\"cmin\",max:\"cmax\"}],calc:t(\"./calc\"),moduleType:\"trace\",name:\"scatter3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"symbols\",\"showLegend\"],meta:{}}},{\"../../constants/gl3d_markers\":693,\"../../plots/gl3d\":807,\"./attributes\":1138,\"./calc\":1139,\"./convert\":1141,\"./defaults\":1142}],1144:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=n.marker,c=n.line,u=l.line;e.exports={carpet:{valType:\"string\",editType:\"calc\"},a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},mode:s({},n.mode,{dflt:\"markers\"}),text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),line:{color:c.color,width:c.width,dash:c.dash,shape:s({},c.shape,{values:[\"linear\",\"spline\"]}),smoothing:c.smoothing,editType:\"calc\"},connectgaps:n.connectgaps,fill:s({},n.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:n.fillcolor,marker:s({symbol:l.symbol,opacity:l.opacity,maxdisplayed:l.maxdisplayed,size:l.size,sizeref:l.sizeref,sizemin:l.sizemin,sizemode:l.sizemode,line:s({width:u.width,editType:\"calc\"},o(\"marker.line\")),gradient:l.gradient,editType:\"calc\"},o(\"marker\")),textfont:n.textfont,textposition:n.textposition,selected:n.selected,unselected:n.unselected,hoverinfo:s({},i.hoverinfo,{flags:[\"a\",\"b\",\"text\",\"name\"]}),hoveron:n.hoveron,hovertemplate:a()}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1145:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=t(\"../carpet/lookup_carpetid\");e.exports=function(t,e){var r=e._carpetTrace=l(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){var c;e.xaxis=r.xaxis,e.yaxis=r.yaxis;var u,h,f=e._length,p=new Array(f),d=!1;for(c=0;c<f;c++)if(u=e.a[c],h=e.b[c],n(u)&&n(h)){var g=r.ab2xy(+u,+h,!0),v=r.isVisible(+u,+h);v||(d=!0),p[c]={x:g[0],y:g[1],a:u,b:h,vis:v}}else p[c]={x:!1,y:!1};return e._needsCull=d,p[0].carpet=r,p[0].trace=e,s(e,f),i(t,e),a(p,e),o(p,e),p}}},{\"../carpet/lookup_carpetid\":915,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc\":1113,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1146:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}p(\"carpet\"),e.xaxis=\"x\",e.yaxis=\"y\";var d=p(\"a\"),g=p(\"b\"),v=Math.min(d.length,g.length);if(v){e._length=v,p(\"text\"),p(\"hovertext\"),p(\"mode\",v<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,f,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,f,p,{gradient:!0}),a.hasText(e)&&c(t,e,f,p);var m=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"marker.maxdisplayed\"),m.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||m.push(\"fills\"),\"fills\"!==p(\"hoveron\",m.join(\"+\")||\"points\")&&p(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/line_shape_defaults\":1126,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1144}],1147:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=n[i];return t.a=a.a,t.b=a.b,t.y=a.y,t}},{}],1148:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../lib\").fillText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,h=c-u;return s.x0=Math.max(Math.min(s.x0,h),u),s.x1=Math.max(Math.min(s.x1,h),u),o}var f=s.cd[s.index];s.a=f.a,s.b=f.b,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.trace,d=p._carpet,g=d.ab2ij([f.a,f.b]),v=Math.floor(g[0]),m=g[0]-v,y=Math.floor(g[1]),x=g[1]-y,b=d.evalxy([],v,y,m,x);s.yLabel=b[1].toFixed(3),delete s.text;var _=[];if(!p.hovertemplate){var w=(f.hi||p.hoverinfo).split(\"+\");-1!==w.indexOf(\"all\")&&(w=[\"a\",\"b\",\"text\"]),-1!==w.indexOf(\"a\")&&k(d.aaxis,f.a),-1!==w.indexOf(\"b\")&&k(d.baxis,f.b),_.push(\"y: \"+s.yLabel),-1!==w.indexOf(\"text\")&&i(f,p,_),s.extraText=_.join(\"<br>\")}return o}function k(t,e){var r;r=t.labelprefix&&t.labelprefix.length>0?t.labelprefix.replace(/ = $/,\"\"):t._hovertitle,_.push(r+\": \"+e.toFixed(3)+t.labelsuffix)}}},{\"../../lib\":719,\"../scatter/hover\":1122}],1149:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scattercarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"svg\",\"carpet\",\"symbols\",\"showLegend\",\"carpetDependent\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../scatter/marker_colorbar\":1129,\"../scatter/select\":1132,\"../scatter/style\":1134,\"./attributes\":1144,\"./calc\":1145,\"./defaults\":1146,\"./event_data\":1147,\"./hover\":1148,\"./plot\":1150}],1150:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../components/drawing\");e.exports=function(t,e,r,o){var s,l,c,u=r[0][0].carpet,h={xaxis:i.getFromId(t,u.xaxis||\"x\"),yaxis:i.getFromId(t,u.yaxis||\"y\"),plot:e.plot};for(n(t,h,r,o),s=0;s<r.length;s++)l=r[s][0].trace,c=o.selectAll(\"g.trace\"+l.uid+\" .js-line\"),a.setClipUrl(c,r[s][0].carpet._clipPathId,t)}},{\"../../components/drawing\":614,\"../../plots/cartesian/axes\":767,\"../scatter/plot\":1131}],1151:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/drawing/attributes\").dash,l=t(\"../../lib/extend\").extendFlat,c=t(\"../../plot_api/edit_types\").overrideAll,u=i.marker,h=i.line,f=u.line;e.exports=c({lon:{valType:\"data_array\"},lat:{valType:\"data_array\"},locations:{valType:\"data_array\"},locationmode:{valType:\"enumerated\",values:[\"ISO-3\",\"USA-states\",\"country names\"],dflt:\"ISO-3\"},mode:l({},i.mode,{dflt:\"markers\"}),text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),textfont:i.textfont,textposition:i.textposition,line:{color:h.color,width:h.width,dash:s},connectgaps:i.connectgaps,marker:l({symbol:u.symbol,opacity:u.opacity,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,colorbar:u.colorbar,line:l({width:f.width},o(\"marker.line\")),gradient:u.gradient},o(\"marker\")),fill:{valType:\"enumerated\",values:[\"none\",\"toself\"],dflt:\"none\"},fillcolor:i.fillcolor,selected:i.selected,unselected:i.unselected,hoverinfo:l({},a.hoverinfo,{flags:[\"lon\",\"lat\",\"location\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":600,\"../../components/drawing/attributes\":613,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1152:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../scatter/colorscale_calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\"),l=t(\"../../lib\")._;e.exports=function(t,e){for(var r=Array.isArray(e.locations),c=r?e.locations.length:e._length,u=new Array(c),h=0;h<c;h++){var f=u[h]={};if(r){var p=e.locations[h];f.loc=\"string\"==typeof p?p:null}else{var d=e.lon[h],g=e.lat[h];n(d)&&n(g)?f.lonlat=[+d,+g]:f.lonlat=[i,i]}}return o(u,e),a(t,e),s(u,e),c&&(u[0].t={labels:{lat:l(t,\"lat:\")+\" \",lon:l(t,\"lon:\")+\" \"}}),u}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1153:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,i){return n.coerce(t,e,c,r,i)}!function(t,e,r){var n,i,a=0,o=r(\"locations\");if(o)return r(\"locationmode\"),a=o.length;return n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length),e._length=a,a}(0,e,h)?e.visible=!1:(h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),i.hasLines(e)&&(o(t,e,r,u,h),h(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,u,h,{gradient:!0}),i.hasText(e)&&s(t,e,u,h),h(\"fill\"),\"none\"!==e.fill&&l(t,e,r,h),n.coerceSelectionMarkerOpacity(e,h))}},{\"../../lib\":719,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1151}],1154:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.location=e.loc?e.loc:null,t}},{}],1155:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../scatter/get_trace_color\"),s=t(\"../../lib\").fillText,l=t(\"./attributes\");e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,h=t.xa,f=t.ya,p=t.subplot,d=p.projection.isLonLatOverEdges,g=p.project;if(n.getClosest(c,function(t){var n=t.lonlat;if(n[0]===a)return 1/0;if(d(n))return 1/0;var i=g(n),o=g([e,r]),s=Math.abs(i[0]-o[0]),l=Math.abs(i[1]-o[1]),c=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(s*s+l*l)-c,1-3/c)},t),!1!==t.index){var v=c[t.index],m=v.lonlat,y=[h.c2p(m),f.c2p(m)],x=v.mrc||1;t.x0=y[0]-x,t.x1=y[0]+x,t.y0=y[1]-x,t.y1=y[1]+x,t.loc=v.loc,t.lon=m[0],t.lat=m[1];var b=p.mockAxis;return t.lonLabel=i.tickText(b,b.c2l(t.lon),\"hover\").text,t.latLabel=i.tickText(b,b.c2l(t.lat),\"hover\").text,t.color=o(u,v),t.extraText=function(t,e,r,n){if(t.hovertemplate)return;var i=e.hi||t.hoverinfo,a=\"all\"===i?l.hoverinfo.flags:i.split(\"+\"),o=-1!==a.indexOf(\"location\")&&Array.isArray(t.locations),c=-1!==a.indexOf(\"lon\"),u=-1!==a.indexOf(\"lat\"),h=-1!==a.indexOf(\"text\"),f=[];function p(t){return t+\"\\xb0\"}o?f.push(e.loc):c&&u?f.push(\"(\"+p(r.lonLabel)+\", \"+p(r.latLabel)+\")\"):c?f.push(n.lon+p(r.lonLabel)):u&&f.push(n.lat+p(r.latLabel));h&&s(e,t,f);return f.join(\"<br>\")}(u,v,t,c[0].t.labels),t.hovertemplate=u.hovertemplate,[t]}}},{\"../../components/fx\":632,\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scatter/get_trace_color\":1121,\"./attributes\":1151}],1156:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"scattergeo\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/geo\":797,\"../scatter/marker_colorbar\":1129,\"../scatter/style\":1134,\"./attributes\":1151,\"./calc\":1152,\"./defaults\":1153,\"./event_data\":1154,\"./hover\":1155,\"./plot\":1157,\"./select\":1158,\"./style\":1159}],1157:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../lib/topojson_utils\").getTopojsonFeatures,s=t(\"../../lib/geo_location_utils\").locationToFeature,l=t(\"../../lib/geojson_utils\"),c=t(\"../scatter/subtypes\"),u=t(\"./style\");function h(t,e){var r=t[0].trace;if(Array.isArray(r.locations))for(var n=o(r,e),i=r.locationmode,l=0;l<t.length;l++){var c=t[l],u=s(i,c.loc,n);c.lonlat=u?u.properties.ct:[a,a]}}e.exports=function(t,e,r){for(var o=0;o<r.length;o++)h(r[o],e.topojson);function s(t,e){t.lonlat[0]===a&&n.select(e).remove()}var f=e.layers.frontplot.select(\".scatterlayer\"),p=i.makeTraceGroups(f,r,\"trace scattergeo\");p.selectAll(\"*\").remove(),p.each(function(e){var r=n.select(this),a=e[0].trace;if(c.hasLines(a)||\"none\"!==a.fill){var o=l.calcTraceToLineCoords(e),h=\"none\"!==a.fill?l.makePolygon(o):l.makeLine(o);r.selectAll(\"path.js-line\").data([{geojson:h,trace:a}]).enter().append(\"path\").classed(\"js-line\",!0).style(\"stroke-miterlimit\",2)}c.hasMarkers(a)&&r.selectAll(\"path.point\").data(i.identity).enter().append(\"path\").classed(\"point\",!0).each(function(t){s(t,this)}),c.hasText(a)&&r.selectAll(\"g\").data(i.identity).enter().append(\"g\").append(\"text\").each(function(t){s(t,this)}),u(t,e)})}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/geo_location_utils\":713,\"../../lib/geojson_utils\":714,\"../../lib/topojson_utils\":746,\"../scatter/subtypes\":1135,\"./style\":1159,d3:163}],1158:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,a,o,s,l,c=t.cd,u=t.xaxis,h=t.yaxis,f=[],p=c[0].trace;if(!n.hasMarkers(p)&&!n.hasText(p))return[];if(!1===e)for(l=0;l<c.length;l++)c[l].selected=0;else for(l=0;l<c.length;l++)(a=(r=c[l]).lonlat)[0]!==i&&(o=u.c2p(a),s=h.c2p(a),e.contains([o,s],null,l,t)?(f.push({pointNumber:l,lon:a[0],lat:a[1]}),r.selected=1):r.selected=0);return f}},{\"../../constants/numerical\":695,\"../scatter/subtypes\":1135}],1159:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../scatter/style\"),s=o.stylePoints,l=o.styleText;e.exports=function(t,e){e&&function(t,e){var r=e[0].trace,o=e[0].node3;o.style(\"opacity\",e[0].trace.opacity),s(o,r,t),l(o,r,t),o.selectAll(\"path.js-line\").style(\"fill\",\"none\").each(function(t){var e=n.select(this),r=t.trace,o=r.line||{};e.call(a.stroke,o.color).call(i.dashLine,o.dash||\"\",o.width||0),\"none\"!==r.fill&&e.call(a.fill,r.fillcolor)})}(t,e)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../scatter/style\":1134,d3:163}],1160:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=t(\"./constants\").DASHES,c=i.line,u=i.marker,h=u.line,f=e.exports=s({x:i.x,x0:i.x0,dx:i.dx,y:i.y,y0:i.y0,dy:i.dy,text:i.text,hovertext:i.hovertext,textposition:i.textposition,textfont:i.textfont,mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"]},line:{color:c.color,width:c.width,shape:{valType:\"enumerated\",values:[\"linear\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},dash:{valType:\"enumerated\",values:Object.keys(l),dflt:\"solid\"}},marker:o({},a(\"marker\"),{symbol:u.symbol,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:o({},a(\"marker.line\"),{width:h.width})}),connectgaps:i.connectgaps,fill:o({},i.fill,{dflt:\"none\"}),fillcolor:i.fillcolor,selected:{marker:i.selected.marker,textfont:i.selected.textfont},unselected:{marker:i.unselected.marker,textfont:i.unselected.textfont},opacity:n.opacity},\"calc\",\"nested\");f.x.editType=f.y.editType=f.x0.editType=f.y0.editType=\"calc+clearAxisTypes\",f.hovertemplate=i.hovertemplate},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../scatter/attributes\":1112,\"./constants\":1162}],1161:[function(t,e,r){\"use strict\";var n=t(\"point-cluster\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../plots/cartesian/autorange\").findExtremes,s=t(\"../scatter/calc\"),l=s.calcMarkerSize,c=s.calcAxisExpansion,u=s.setFirstScatter,h=t(\"../scatter/colorscale_calc\"),f=t(\"./convert\"),p=t(\"./scene_update\"),d=t(\"../../constants/numerical\").BADNUM,g=t(\"./constants\").TOO_MANY_POINTS;function v(t,e,r){var n=t._extremes[e._id],i=o(e,r._bnds,{padded:!0});n.min=n.min.concat(i.min),n.max=n.max.concat(i.max)}e.exports=function(t,e){var r,o,s,m=t._fullLayout,y=a.getFromId(t,e.xaxis),x=a.getFromId(t,e.yaxis),b=m._plots[e.xaxis+e.yaxis],_=e._length,w=_>=g,k=2*_,T={},A=y.makeCalcdata(e,\"x\"),M=x.makeCalcdata(e,\"y\"),S=new Array(k);for(r=0;r<_;r++)o=A[r],s=M[r],S[2*r]=o===d?NaN:o,S[2*r+1]=s===d?NaN:s;if(\"log\"===y.type)for(r=0;r<k;r+=2)S[r]=y.c2l(S[r]);if(\"log\"===x.type)for(r=1;r<k;r+=2)S[r]=x.c2l(S[r]);if(w&&\"log\"!==y.type&&\"log\"!==x.type)T.tree=n(S);else{var E=T.ids=new Array(_);for(r=0;r<_;r++)E[r]=r}h(t,e);var C,L=function(t,e,r,n,a,o){var s=f.style(t,r);s.marker&&(s.marker.positions=n);s.line&&n.length>1&&i.extendFlat(s.line,f.linePositions(t,r,n));if(s.errorX||s.errorY){var l=f.errorBarPositions(t,r,n,a,o);s.errorX&&i.extendFlat(s.errorX,l.x),s.errorY&&i.extendFlat(s.errorY,l.y)}s.text&&(i.extendFlat(s.text,{positions:n},f.textPosition(t,r,s.text,s.marker)),i.extendFlat(s.textSel,{positions:n},f.textPosition(t,r,s.text,s.markerSel)),i.extendFlat(s.textUnsel,{positions:n},f.textPosition(t,r,s.text,s.markerUnsel)));return s}(t,0,e,S,A,M),P=p(t,b);return u(m,e),w?L.marker&&(C=2*(L.marker.sizeAvg||Math.max(L.marker.size,3))):C=l(e,_),c(t,e,y,x,A,M,C),L.errorX&&v(e,y,L.errorX),L.errorY&&v(e,x,L.errorY),L.fill&&!P.fill2d&&(P.fill2d=!0),L.marker&&!P.scatter2d&&(P.scatter2d=!0),L.line&&!P.line2d&&(P.line2d=!0),!L.errorX&&!L.errorY||P.error2d||(P.error2d=!0),L.text&&!P.glText&&(P.glText=!0),L.marker&&(L.marker.snap=T.tree||g),P.lineOptions.push(L.line),P.errorXOptions.push(L.errorX),P.errorYOptions.push(L.errorY),P.fillOptions.push(L.fill),P.markerOptions.push(L.marker),P.markerSelectedOptions.push(L.markerSel),P.markerUnselectedOptions.push(L.markerUnsel),P.textOptions.push(L.text),P.textSelectedOptions.push(L.textSel),P.textUnselectedOptions.push(L.textUnsel),P.selectBatch.push([]),P.unselectBatch.push([]),T._scene=P,T.index=P.count,T.x=A,T.y=M,T.positions=S,P.count++,[{x:!1,y:!1,t:T,trace:e}]}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/autorange\":766,\"../../plots/cartesian/axis_ids\":770,\"../scatter/calc\":1113,\"../scatter/colorscale_calc\":1115,\"./constants\":1162,\"./convert\":1163,\"./scene_update\":1169,\"point-cluster\":469}],1162:[function(t,e,r){\"use strict\";e.exports={TOO_MANY_POINTS:1e5,SYMBOL_SDF_SIZE:200,SYMBOL_SIZE:20,SYMBOL_STROKE:1,DOT_RE:/-dot/,OPEN_RE:/-open/,DASHES:{solid:[1],dot:[1,1],dash:[4,1],longdash:[8,1],dashdot:[4,1,1,1],longdashdot:[8,1,1,1]}}},{}],1163:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"svg-path-sdf\"),a=t(\"color-normalize\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../components/drawing\"),c=t(\"../../plots/cartesian/axis_ids\"),u=t(\"../../lib/gl_format_color\").formatColor,h=t(\"../scatter/subtypes\"),f=t(\"../scatter/make_bubble_size_func\"),p=t(\"./constants\"),d=t(\"../../constants/interactions\").DESELECTDIM,g={start:1,left:1,end:-1,right:-1,middle:0,center:0,bottom:1,top:-1};function v(t){var e,r=t._length,i=t.textfont,a=t.textposition,o=Array.isArray(a)?a:[a],s=i.color,l=i.size,c=i.family,u={};for(u.text=t.text,u.opacity=t.opacity,u.font={},u.align=[],u.baseline=[],e=0;e<o.length;e++){var h=o[e].split(/\\s+/);switch(h[1]){case\"left\":u.align.push(\"right\");break;case\"right\":u.align.push(\"left\");break;default:u.align.push(h[1])}switch(h[0]){case\"top\":u.baseline.push(\"bottom\");break;case\"bottom\":u.baseline.push(\"top\");break;default:u.baseline.push(h[0])}}if(Array.isArray(s))for(u.color=new Array(r),e=0;e<r;e++)u.color[e]=s[e];else u.color=s;if(Array.isArray(l)||Array.isArray(c))for(u.font=new Array(r),e=0;e<r;e++){var f=u.font[e]={};f.size=Array.isArray(l)?n(l[e])?l[e]:0:l,f.family=Array.isArray(c)?c[e]:c}else u.font={size:l,family:c};return u}function m(t){var e,r,n=t._length,i=t.marker,o={},l=Array.isArray(i.symbol),c=s.isArrayOrTypedArray(i.color),h=s.isArrayOrTypedArray(i.line.color),d=s.isArrayOrTypedArray(i.opacity),g=s.isArrayOrTypedArray(i.size),v=s.isArrayOrTypedArray(i.line.width);if(l||(r=p.OPEN_RE.test(i.symbol)),l||c||h||d){o.colors=new Array(n),o.borderColors=new Array(n);var m=u(i,i.opacity,n),y=u(i.line,i.opacity,n);if(!Array.isArray(y[0])){var x=y;for(y=Array(n),e=0;e<n;e++)y[e]=x}if(!Array.isArray(m[0])){var b=m;for(m=Array(n),e=0;e<n;e++)m[e]=b}for(o.colors=m,o.borderColors=y,e=0;e<n;e++){if(l){var _=i.symbol[e];r=p.OPEN_RE.test(_)}r&&(y[e]=m[e].slice(),m[e]=m[e].slice(),m[e][3]=0)}o.opacity=t.opacity}else r?(o.color=a(i.color,\"uint8\"),o.color[3]=0,o.borderColor=a(i.color,\"uint8\")):(o.color=a(i.color,\"uint8\"),o.borderColor=a(i.line.color,\"uint8\")),o.opacity=t.opacity*i.opacity;if(l)for(o.markers=new Array(n),e=0;e<n;e++)o.markers[e]=M(i.symbol[e]);else o.marker=M(i.symbol);var w,k=f(t);if(g||v){var T,A=o.sizes=new Array(n),S=o.borderSizes=new Array(n),E=0;if(g){for(e=0;e<n;e++)A[e]=k(i.size[e]),E+=A[e];T=E/n}else for(w=k(i.size),e=0;e<n;e++)A[e]=w;if(v)for(e=0;e<n;e++)S[e]=i.line.width[e]/2;else for(w=i.line.width/2,e=0;e<n;e++)S[e]=w;o.sizeAvg=T}else o.size=k(i&&i.size||10),o.borderSizes=k(i.line.width);return o}function y(t,e){var r=t.marker,n={};return e?(e.marker&&e.marker.symbol?n=m(s.extendFlat({},r,e.marker)):e.marker&&(e.marker.size&&(n.size=e.marker.size/2),e.marker.color&&(n.colors=e.marker.color),void 0!==e.marker.opacity&&(n.opacity=e.marker.opacity)),n):n}function x(t,e){var r={};if(!e)return r;if(e.textfont){var n={opacity:1,text:t.text,textposition:t.textposition,textfont:s.extendFlat({},t.textfont)};e.textfont&&s.extendFlat(n.textfont,e.textfont),r=v(n)}return r}function b(t,e){var r={capSize:2*e.width,lineWidth:e.thickness,color:e.color};return e.copy_ystyle&&(r=t.error_y),r}var _=p.SYMBOL_SDF_SIZE,w=p.SYMBOL_SIZE,k=p.SYMBOL_STROKE,T={},A=l.symbolFuncs[0](.05*w);function M(t){if(\"circle\"===t)return null;var e,r,n=l.symbolNumber(t),a=l.symbolFuncs[n%100],o=!!l.symbolNoDot[n%100],s=!!l.symbolNoFill[n%100],c=p.DOT_RE.test(t);return T[t]?T[t]:(e=c&&!o?a(1.1*w)+A:a(w),r=i(e,{w:_,h:_,viewBox:[-w,-w,w,w],stroke:s?k:-k}),T[t]=r,r||null)}e.exports={style:function(t,e){var r,n={marker:void 0,markerSel:void 0,markerUnsel:void 0,line:void 0,fill:void 0,errorX:void 0,errorY:void 0,text:void 0,textSel:void 0,textUnsel:void 0};if(!0!==e.visible)return n;if(h.hasText(e)&&(n.text=v(e),n.textSel=x(e,e.selected),n.textUnsel=x(e,e.unselected)),h.hasMarkers(e)&&(n.marker=m(e),n.markerSel=y(e,e.selected),n.markerUnsel=y(e,e.unselected),!e.unselected&&Array.isArray(e.marker.opacity))){var i=e.marker.opacity;for(n.markerUnsel.opacity=new Array(i.length),r=0;r<i.length;r++)n.markerUnsel.opacity[r]=d*i[r]}if(h.hasLines(e)){n.line={overlay:!0,thickness:e.line.width,color:e.line.color,opacity:e.opacity};var a=(p.DASHES[e.line.dash]||[1]).slice();for(r=0;r<a.length;++r)a[r]*=e.line.width;n.line.dashes=a}return e.error_x&&e.error_x.visible&&(n.errorX=b(e,e.error_x)),e.error_y&&e.error_y.visible&&(n.errorY=b(e,e.error_y)),e.fill&&\"none\"!==e.fill&&(n.fill={closed:!0,fill:e.fillcolor,thickness:0}),n},markerStyle:m,markerSelection:y,linePositions:function(t,e,r){var n,i,a=r.length,o=a/2;if(h.hasLines(e)&&o)if(\"hv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i+2],r[2*i+1]));n.push(r[a-2],r[a-1])}else if(\"hvh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var s=(r[2*i]+r[2*i+2])/2;n.push(r[2*i],r[2*i+1],s,r[2*i+1],s,r[2*i+3])}n.push(r[a-2],r[a-1])}else if(\"vhv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var l=(r[2*i+1]+r[2*i+3])/2;n.push(r[2*i],r[2*i+1],r[2*i],l,r[2*i+2],l)}n.push(r[a-2],r[a-1])}else if(\"vh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+3]));n.push(r[a-2],r[a-1])}else n=r;var c=!1;for(i=0;i<n.length;i++)if(isNaN(n[i])){c=!0;break}var u=c||n.length>p.TOO_MANY_POINTS?\"rect\":h.hasMarkers(e)?\"rect\":\"round\";if(c&&e.connectgaps){var f=n[0],d=n[1];for(i=0;i<n.length;i+=2)isNaN(n[i])||isNaN(n[i+1])?(n[i]=f,n[i+1]=d):(f=n[i],d=n[i+1])}return{join:u,positions:n}},errorBarPositions:function(t,e,r,i,a){var s=o.getComponentMethod(\"errorbars\",\"makeComputeError\"),l=c.getFromId(t,e.xaxis),u=c.getFromId(t,e.yaxis),h=r.length/2,f={};function p(t,i){var a=i._id.charAt(0),o=e[\"error_\"+a];if(o&&o.visible&&(\"linear\"===i.type||\"log\"===i.type)){for(var l=s(o),c={x:0,y:1}[a],u={x:[0,1,2,3],y:[2,3,0,1]}[a],p=new Float64Array(4*h),d=1/0,g=-1/0,v=0,m=0;v<h;v++,m+=4){var y=t[v];if(n(y)){var x=r[2*v+c],b=l(y,v),_=b[0],w=b[1];if(n(_)&&n(w)){var k=y-_,T=y+w;p[m+u[0]]=x-i.c2l(k),p[m+u[1]]=i.c2l(T)-x,p[m+u[2]]=0,p[m+u[3]]=0,d=Math.min(d,y-_),g=Math.max(g,y+w)}}}f[a]={positions:r,errors:p,_bnds:[d,g]}}}return p(i,l),p(a,u),f},textPosition:function(t,e,r,n){var i,a=e._length,o={};if(h.hasMarkers(e)){var s=r.font,l=r.align,c=r.baseline;for(o.offset=new Array(a),i=0;i<a;i++){var u=n.sizes?n.sizes[i]:n.size,f=Array.isArray(s)?s[i].size:s.size,p=Array.isArray(l)?l.length>1?l[i]:l[0]:l,d=Array.isArray(c)?c.length>1?c[i]:c[0]:c,v=g[p],m=g[d],y=u?u/.8+1:0,x=-m*y-.5*m;o.offset[i]=[v*y/f,x/f]}}return o}}},{\"../../components/drawing\":614,\"../../constants/interactions\":694,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../scatter/make_bubble_size_func\":1128,\"../scatter/subtypes\":1135,\"./constants\":1162,\"color-normalize\":120,\"fast-isnumeric\":225,\"svg-path-sdf\":535}],1164:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"../scatter/constants\"),s=t(\"../scatter/subtypes\"),l=t(\"../scatter/xy_defaults\"),c=t(\"../scatter/marker_defaults\"),u=t(\"../scatter/line_defaults\"),h=t(\"../scatter/fillcolor_defaults\"),f=t(\"../scatter/text_defaults\");e.exports=function(t,e,r,p){function d(r,i){return n.coerce(t,e,a,r,i)}var g=!!t.marker&&/-open/.test(t.marker.symbol),v=s.isBubble(t),m=l(t,e,p,d);if(m){var y=m<o.PTS_LINESONLY?\"lines+markers\":\"lines\";d(\"text\"),d(\"hovertext\"),d(\"hovertemplate\"),d(\"mode\",y),s.hasLines(e)&&(d(\"connectgaps\"),u(t,e,r,p,d),d(\"line.shape\")),s.hasMarkers(e)&&(c(t,e,r,p,d),d(\"marker.line.width\",g||v?1:0)),s.hasText(e)&&f(t,e,p,d);var x=(e.line||{}).color,b=(e.marker||{}).color;d(\"fill\"),\"none\"!==e.fill&&h(t,e,r,d);var _=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");_(t,e,x||b||r,{axis:\"y\"}),_(t,e,x||b||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}},{\"../../lib\":719,\"../../registry\":847,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"../scatter/xy_defaults\":1137,\"./attributes\":1160}],1165:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../constants/interactions\").DESELECTDIM;e.exports={styleTextSelection:function(t){var e,r,o=t[0],s=o.trace,l=o.t,c=l._scene,u=l.index,h=c.selectBatch[u],f=c.unselectBatch[u],p=c.textOptions[u],d=c.textSelectedOptions[u]||{},g=c.textUnselectedOptions[u]||{},v=n.extendFlat({},p);if(h.length||f.length){var m=d.color,y=g.color,x=p.color,b=Array.isArray(x);for(v.color=new Array(s._length),e=0;e<h.length;e++)r=h[e],v.color[r]=m||(b?x[r]:x);for(e=0;e<f.length;e++){r=f[e];var _=b?x[r]:x;v.color[r]=y||(m?_:i.addOpacity(_,a))}}c.glText[u].update(v)}}},{\"../../components/color\":593,\"../../constants/interactions\":694,\"../../lib\":719}],1166:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\");function o(t,e,r,o){var s=t.xa,l=t.ya,c=t.distance,u=t.dxy,h=t.index,f={pointNumber:h,x:e[h],y:r[h]};f.tx=Array.isArray(o.text)?o.text[h]:o.text,f.htx=Array.isArray(o.hovertext)?o.hovertext[h]:o.hovertext,f.data=Array.isArray(o.customdata)?o.customdata[h]:o.customdata,f.tp=Array.isArray(o.textposition)?o.textposition[h]:o.textposition;var p=o.textfont;p&&(f.ts=Array.isArray(p.size)?p.size[h]:p.size,f.tc=Array.isArray(p.color)?p.color[h]:p.color,f.tf=Array.isArray(p.family)?p.family[h]:p.family);var d=o.marker;d&&(f.ms=i.isArrayOrTypedArray(d.size)?d.size[h]:d.size,f.mo=i.isArrayOrTypedArray(d.opacity)?d.opacity[h]:d.opacity,f.mx=Array.isArray(d.symbol)?d.symbol[h]:d.symbol,f.mc=i.isArrayOrTypedArray(d.color)?d.color[h]:d.color);var g=d&&d.line;g&&(f.mlc=Array.isArray(g.color)?g.color[h]:g.color,f.mlw=i.isArrayOrTypedArray(g.width)?g.width[h]:g.width);var v=d&&d.gradient;v&&\"none\"!==v.type&&(f.mgt=Array.isArray(v.type)?v.type[h]:v.type,f.mgc=Array.isArray(v.color)?v.color[h]:v.color);var m=s.c2p(f.x,!0),y=l.c2p(f.y,!0),x=f.mrc||1,b=o.hoverlabel;b&&(f.hbg=Array.isArray(b.bgcolor)?b.bgcolor[h]:b.bgcolor,f.hbc=Array.isArray(b.bordercolor)?b.bordercolor[h]:b.bordercolor,f.hts=Array.isArray(b.font.size)?b.font.size[h]:b.font.size,f.htc=Array.isArray(b.font.color)?b.font.color[h]:b.font.color,f.htf=Array.isArray(b.font.family)?b.font.family[h]:b.font.family,f.hnl=Array.isArray(b.namelength)?b.namelength[h]:b.namelength);var _=o.hoverinfo;_&&(f.hi=Array.isArray(_)?_[h]:_);var w=o.hovertemplate;w&&(f.ht=Array.isArray(w)?w[h]:w);var k={};return k[t.index]=f,i.extendFlat(t,{color:a(o,f),x0:m-x,x1:m+x,xLabelVal:f.x,y0:y-x,y1:y+x,yLabelVal:f.y,cd:k,distance:c,spikeDistance:u,hovertemplate:f.ht}),f.htx?t.text=f.htx:f.tx?t.text=f.tx:o.text&&(t.text=o.text),i.fillText(f,o,t),n.getComponentMethod(\"errorbars\",\"hoverInfo\")(f,o,t),t}e.exports={hoverPoints:function(t,e,r,n){var i,a,s,l,c,u,h,f,p,d=t.cd,g=d[0].t,v=d[0].trace,m=t.xa,y=t.ya,x=g.x,b=g.y,_=m.c2p(e),w=y.c2p(r),k=t.distance;if(g.tree){var T=m.p2c(_-k),A=m.p2c(_+k),M=y.p2c(w-k),S=y.p2c(w+k);i=\"x\"===n?g.tree.range(Math.min(T,A),Math.min(y._rl[0],y._rl[1]),Math.max(T,A),Math.max(y._rl[0],y._rl[1])):g.tree.range(Math.min(T,A),Math.min(M,S),Math.max(T,A),Math.max(M,S))}else{if(!g.ids)return[t];i=g.ids}var E=k;if(\"x\"===n)for(c=0;c<i.length;c++)s=x[i[c]],(u=Math.abs(m.c2p(s)-_))<E&&(E=u,h=y.c2p(b[i[c]])-w,p=Math.sqrt(u*u+h*h),a=i[c]);else for(c=i.length-1;c>-1;c--)s=x[i[c]],l=b[i[c]],u=m.c2p(s)-_,h=y.c2p(l)-w,(f=Math.sqrt(u*u+h*h))<E&&(E=p=f,a=i[c]);return t.index=a,t.distance=E,t.dxy=p,void 0===a?[t]:(o(t,x,b,v),[t])},calcHover:o}},{\"../../lib\":719,\"../../registry\":847,\"../scatter/get_trace_color\":1121}],1167:[function(t,e,r){\"use strict\";var n=t(\"./hover\");e.exports={moduleType:\"trace\",name:\"scattergl\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../scatter/cross_trace_defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:n.hoverPoints,selectPoints:t(\"./select\"),meta:{}}},{\"../../plots/cartesian\":778,\"../scatter/cross_trace_defaults\":1118,\"../scatter/marker_colorbar\":1129,\"./attributes\":1160,\"./calc\":1161,\"./defaults\":1164,\"./hover\":1166,\"./plot\":1168,\"./select\":1170}],1168:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"regl-line2d\"),a=t(\"regl-error2d\"),o=t(\"gl-text\"),s=t(\"../../lib\"),l=t(\"../../lib/prepare_regl\"),c=t(\"../scatter/subtypes\"),u=t(\"../scatter/link_traces\"),h=t(\"./edit_style\").styleTextSelection;e.exports=function(t,e,r){if(r.length){var f,p,d=t._fullLayout,g=e._scene,v=e.xaxis,m=e.yaxis;if(g)if(l(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])){var y=g.count,x=d._glcanvas.data()[0].regl;if(u(t,e,r),g.dirty){if(!0===g.error2d&&(g.error2d=a(x)),!0===g.line2d&&(g.line2d=i(x)),!0===g.scatter2d&&(g.scatter2d=n(x)),!0===g.fill2d&&(g.fill2d=i(x)),!0===g.glText)for(g.glText=new Array(y),f=0;f<y;f++)g.glText[f]=new o(x);if(g.glText){if(y>g.glText.length){var b=y-g.glText.length;for(f=0;f<b;f++)g.glText.push(new o(x))}else if(y<g.glText.length){var _=g.glText.length-y;g.glText.splice(y,_).forEach(function(t){t.destroy()})}for(f=0;f<y;f++)g.glText[f].update(g.textOptions[f])}if(g.line2d&&(g.line2d.update(g.lineOptions),g.lineOptions=g.lineOptions.map(function(t){if(t&&t.positions){for(var e=t.positions,r=0;r<e.length&&(isNaN(e[r])||isNaN(e[r+1]));)r+=2;for(var n=e.length-2;n>r&&(isNaN(e[n])||isNaN(e[n+1]));)n-=2;t.positions=e.slice(r,n+2)}return t}),g.line2d.update(g.lineOptions)),g.error2d){var w=(g.errorXOptions||[]).concat(g.errorYOptions||[]);g.error2d.update(w)}g.scatter2d&&g.scatter2d.update(g.markerOptions),g.fillOrder=s.repeat(null,y),g.fill2d&&(g.fillOptions=g.fillOptions.map(function(t,e){var n=r[e];if(t&&n&&n[0]&&n[0].trace){var i,a,o=n[0],s=o.trace,l=o.t,c=g.lineOptions[e],u=[];s._ownfill&&u.push(e),s._nexttrace&&u.push(e+1),u.length&&(g.fillOrder[e]=u);var h,f,p=[],d=c&&c.positions||l.positions;if(\"tozeroy\"===s.fill){for(h=0;h<d.length&&isNaN(d[h+1]);)h+=2;for(f=d.length-2;f>h&&isNaN(d[f+1]);)f-=2;0!==d[h+1]&&(p=[d[h],0]),p=p.concat(d.slice(h,f+2)),0!==d[f+1]&&(p=p.concat([d[f],0]))}else if(\"tozerox\"===s.fill){for(h=0;h<d.length&&isNaN(d[h]);)h+=2;for(f=d.length-2;f>h&&isNaN(d[f]);)f-=2;0!==d[h]&&(p=[0,d[h+1]]),p=p.concat(d.slice(h,f+2)),0!==d[f]&&(p=p.concat([0,d[f+1]]))}else if(\"toself\"===s.fill||\"tonext\"===s.fill){for(p=[],i=0,a=0;a<d.length;a+=2)(isNaN(d[a])||isNaN(d[a+1]))&&((p=p.concat(d.slice(i,a))).push(d[i],d[i+1]),i=a+2);p=p.concat(d.slice(i)),i&&p.push(d[i],d[i+1])}else{var v=s._nexttrace;if(v){var m=g.lineOptions[e+1];if(m){var y=m.positions;if(\"tonexty\"===s.fill){for(p=d.slice(),e=Math.floor(y.length/2);e--;){var x=y[2*e],b=y[2*e+1];isNaN(x)||isNaN(b)||p.push(x,b)}t.fill=v.fillcolor}}}}if(s._prevtrace&&\"tonext\"===s._prevtrace.fill){var _=g.lineOptions[e-1].positions,w=p.length/2,k=[i=w];for(a=0;a<_.length;a+=2)(isNaN(_[a])||isNaN(_[a+1]))&&(k.push(a/2+w+1),i=a+2);p=p.concat(_),t.hole=k}return t.fillmode=s.fill,t.opacity=s.opacity,t.positions=p,t}}),g.fill2d.update(g.fillOptions))}var k=d.dragmode,T=\"lasso\"===k||\"select\"===k,A=d.clickmode.indexOf(\"select\")>-1;for(f=0;f<y;f++){var M=r[f][0],S=M.trace,E=M.t,C=E.index,L=S._length,P=E.x,O=E.y;if(S.selectedpoints||T||A){if(T||(T=!0),S.selectedpoints){var z=g.selectBatch[C]=s.selIndices2selPoints(S),I={};for(p=0;p<z.length;p++)I[z[p]]=1;var D=[];for(p=0;p<L;p++)I[p]||D.push(p);g.unselectBatch[C]=D}var R=E.xpx=new Array(L),F=E.ypx=new Array(L);for(p=0;p<L;p++)R[p]=v.c2p(P[p]),F[p]=m.c2p(O[p])}else E.xpx=E.ypx=null}if(T){if(g.select2d||(g.select2d=n(d._glcanvas.data()[1].regl)),g.scatter2d){var B=new Array(y);for(f=0;f<y;f++)B[f]=g.selectBatch[f].length||g.unselectBatch[f].length?g.markerUnselectedOptions[f]:{};g.scatter2d.update(B)}g.select2d&&(g.select2d.update(g.markerOptions),g.select2d.update(g.markerSelectedOptions)),g.glText&&r.forEach(function(t){var e=((t||[])[0]||{}).trace||{};c.hasText(e)&&h(t)})}else g.scatter2d&&g.scatter2d.update(g.markerOptions);var N={viewport:function(t,e,r){var n=t._size,i=t.width,a=t.height;return[n.l+e.domain[0]*n.w,n.b+r.domain[0]*n.h,i-n.r-(1-e.domain[1])*n.w,a-n.t-(1-r.domain[1])*n.h]}(d,v,m),range:[(v._rl||v.range)[0],(m._rl||m.range)[0],(v._rl||v.range)[1],(m._rl||m.range)[1]]},j=s.repeat(N,g.count);g.fill2d&&g.fill2d.update(j),g.line2d&&g.line2d.update(j),g.error2d&&g.error2d.update(j.concat(j)),g.scatter2d&&g.scatter2d.update(j),g.select2d&&g.select2d.update(j),g.glText&&g.glText.forEach(function(t){t.update(N)})}else g.init()}}},{\"../../lib\":719,\"../../lib/prepare_regl\":732,\"../scatter/link_traces\":1127,\"../scatter/subtypes\":1135,\"./edit_style\":1165,\"gl-text\":317,\"regl-error2d\":490,\"regl-line2d\":491,\"regl-scatter2d\":497}],1169:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=e._scene,i={count:0,dirty:!0,lineOptions:[],fillOptions:[],markerOptions:[],markerSelectedOptions:[],markerUnselectedOptions:[],errorXOptions:[],errorYOptions:[],textOptions:[],textSelectedOptions:[],textUnselectedOptions:[],selectBatch:[],unselectBatch:[]},a={fill2d:!1,scatter2d:!1,error2d:!1,line2d:!1,glText:!1,select2d:!1};return e._scene||((r=e._scene={}).init=function(){n.extendFlat(r,a,i)},r.init(),r.update=function(t){var e=n.repeat(t,r.count);if(r.fill2d&&r.fill2d.update(e),r.scatter2d&&r.scatter2d.update(e),r.line2d&&r.line2d.update(e),r.error2d&&r.error2d.update(e.concat(e)),r.select2d&&r.select2d.update(e),r.glText)for(var i=0;i<r.count;i++)r.glText[i].update(t)},r.draw=function(){for(var t=r.count,e=r.fill2d,i=r.error2d,a=r.line2d,o=r.scatter2d,s=r.glText,l=r.select2d,c=r.selectBatch,u=r.unselectBatch,h=0;h<t;h++){if(e&&r.fillOrder[h]&&e.draw(r.fillOrder[h]),a&&r.lineOptions[h]&&a.draw(h),i&&(r.errorXOptions[h]&&i.draw(h),r.errorYOptions[h]&&i.draw(h+t)),o&&r.markerOptions[h])if(u[h].length){var f=n.repeat([],r.count);f[h]=u[h],o.draw(f)}else c[h].length||o.draw(h);s[h]&&r.textOptions[h]&&s[h].render()}l&&l.draw(c),r.dirty=!1},r.destroy=function(){r.fill2d&&r.fill2d.destroy&&r.fill2d.destroy(),r.scatter2d&&r.scatter2d.destroy&&r.scatter2d.destroy(),r.error2d&&r.error2d.destroy&&r.error2d.destroy(),r.line2d&&r.line2d.destroy&&r.line2d.destroy(),r.select2d&&r.select2d.destroy&&r.select2d.destroy(),r.glText&&r.glText.forEach(function(t){t.destroy&&t.destroy()}),r.lineOptions=null,r.fillOptions=null,r.markerOptions=null,r.markerSelectedOptions=null,r.markerUnselectedOptions=null,r.errorXOptions=null,r.errorYOptions=null,r.textOptions=null,r.textSelectedOptions=null,r.textUnselectedOptions=null,r.selectBatch=null,r.unselectBatch=null,e._scene=null}),r.dirty||n.extendFlat(r,i),r}},{\"../../lib\":719}],1170:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"./edit_style\").styleTextSelection;e.exports=function(t,e){var r=t.cd,a=[],o=r[0].trace,s=r[0].t,l=o._length,c=s.x,u=s.y,h=s._scene,f=s.index;if(!h)return a;var p=n.hasText(o),d=n.hasMarkers(o),g=!d&&!p;if(!0!==o.visible||g)return a;var v=[],m=[];if(!1!==e&&!e.degenerate)for(var y=0;y<l;y++)e.contains([s.xpx[y],s.ypx[y]],!1,y,t)?(v.push(y),a.push({pointNumber:y,x:c[y],y:u[y]})):m.push(y);if(d){var x=h.scatter2d;if(v.length||m.length){if(!h.selectBatch[f].length&&!h.unselectBatch[f].length){var b=new Array(h.count);b[f]=h.markerUnselectedOptions[f],x.update.apply(x,b)}}else{var _=new Array(h.count);_[f]=h.markerOptions[f],x.update.apply(x,_)}}return h.selectBatch[f]=v,h.unselectBatch[f]=m,p&&i(r),a}},{\"../scatter/subtypes\":1135,\"./edit_style\":1165}],1171:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scattergeo/attributes\"),a=t(\"../scatter/attributes\"),o=t(\"../../plots/mapbox/layout_attributes\"),s=t(\"../../plots/attributes\"),l=t(\"../../components/colorscale/attributes\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../plot_api/edit_types\").overrideAll,h=i.line,f=i.marker;e.exports=u({lon:i.lon,lat:i.lat,mode:c({},a.mode,{dflt:\"markers\"}),text:c({},a.text,{}),hovertext:c({},a.hovertext,{}),line:{color:h.color,width:h.width},connectgaps:a.connectgaps,marker:c({symbol:{valType:\"string\",dflt:\"circle\",arrayOk:!0},opacity:f.opacity,size:f.size,sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode},l(\"marker\")),fill:i.fill,fillcolor:a.fillcolor,textfont:o.layers.symbol.textfont,textposition:o.layers.symbol.textposition,below:{valType:\"string\"},selected:{marker:a.selected.marker},unselected:{marker:a.unselected.marker},hoverinfo:c({},s.hoverinfo,{flags:[\"lon\",\"lat\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../../plots/mapbox/layout_attributes\":824,\"../scatter/attributes\":1112,\"../scattergeo/attributes\":1151}],1172:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../lib/geojson_utils\"),s=t(\"../../components/colorscale\"),l=t(\"../../components/drawing\"),c=t(\"../scatter/make_bubble_size_func\"),u=t(\"../scatter/subtypes\"),h=t(\"../../plots/mapbox/convert_text_opts\");function f(){return{geojson:o.makeBlank(),layout:{visibility:\"none\"},paint:{}}}function p(t){return i.isArrayOrTypedArray(t)?function(t){return t}:t?function(){return t}:d}function d(){return\"\"}function g(t){return t[0]===a}e.exports=function(t){var e,r=t[0].trace,a=!0===r.visible&&0!==r._length,v=\"none\"!==r.fill,m=u.hasLines(r),y=u.hasMarkers(r),x=u.hasText(r),b=y&&\"circle\"===r.marker.symbol,_=y&&\"circle\"!==r.marker.symbol,w=f(),k=f(),T=f(),A=f(),M={fill:w,line:k,circle:T,symbol:A};if(!a)return M;if((v||m)&&(e=o.calcTraceToLineCoords(t)),v&&(w.geojson=o.makePolygon(e),w.layout.visibility=\"visible\",i.extendFlat(w.paint,{\"fill-color\":r.fillcolor})),m&&(k.geojson=o.makeLine(e),k.layout.visibility=\"visible\",i.extendFlat(k.paint,{\"line-width\":r.line.width,\"line-color\":r.line.color,\"line-opacity\":r.opacity})),b){var S=function(t){var e,r,a,o,u=t[0].trace,h=u.marker,f=u.selectedpoints,p=i.isArrayOrTypedArray(h.color),d=i.isArrayOrTypedArray(h.size),v=i.isArrayOrTypedArray(h.opacity);function m(t){return u.opacity*t}p&&(r=s.hasColorscale(u,\"marker\")?s.makeColorScaleFuncFromTrace(h):i.identity);d&&(a=c(u));v&&(o=function(t){var e=n(t)?+i.constrain(t,0,1):0;return m(e)});var y,x=[];for(e=0;e<t.length;e++){var b=t[e],_=b.lonlat;if(!g(_)){var w={};r&&(w.mcc=b.mcc=r(b.mc)),a&&(w.mrc=b.mrc=a(b.ms)),o&&(w.mo=o(b.mo)),f&&(w.selected=b.selected||0),x.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:_},properties:w})}}if(f)for(y=l.makeSelectedPointStyleFns(u),e=0;e<x.length;e++){var k=x[e].properties;y.selectedOpacityFn&&(k.mo=m(y.selectedOpacityFn(k))),y.selectedColorFn&&(k.mcc=y.selectedColorFn(k)),y.selectedSizeFn&&(k.mrc=y.selectedSizeFn(k))}return{geojson:{type:\"FeatureCollection\",features:x},mcc:p||y&&y.selectedColorFn?{type:\"identity\",property:\"mcc\"}:h.color,mrc:d||y&&y.selectedSizeFn?{type:\"identity\",property:\"mrc\"}:(T=h.size,T/2),mo:v||y&&y.selectedOpacityFn?{type:\"identity\",property:\"mo\"}:m(h.opacity)};var T}(t);T.geojson=S.geojson,T.layout.visibility=\"visible\",i.extendFlat(T.paint,{\"circle-color\":S.mcc,\"circle-radius\":S.mrc,\"circle-opacity\":S.mo})}if((_||x)&&(A.geojson=function(t){for(var e=t[0].trace,r=(e.marker||{}).symbol,n=e.text,i=\"circle\"!==r?p(r):d,a=u.hasText(e)?p(n):d,o=[],s=0;s<t.length;s++){var l=t[s];g(l.lonlat)||o.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:l.lonlat},properties:{symbol:i(l.mx),text:a(l.tx)}})}return{type:\"FeatureCollection\",features:o}}(t),i.extendFlat(A.layout,{visibility:\"visible\",\"icon-image\":\"{symbol}-15\",\"text-field\":\"{text}\"}),_&&(i.extendFlat(A.layout,{\"icon-size\":r.marker.size/10}),i.extendFlat(A.paint,{\"icon-opacity\":r.opacity*r.marker.opacity,\"icon-color\":r.marker.color})),x)){var E=(r.marker||{}).size,C=h(r.textposition,E);i.extendFlat(A.layout,{\"text-size\":r.textfont.size,\"text-anchor\":C.anchor,\"text-offset\":C.offset}),i.extendFlat(A.paint,{\"text-color\":r.textfont.color,\"text-opacity\":r.opacity})}return M}},{\"../../components/colorscale\":605,\"../../components/drawing\":614,\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/geojson_utils\":714,\"../../plots/mapbox/convert_text_opts\":821,\"../scatter/make_bubble_size_func\":1128,\"../scatter/subtypes\":1135,\"fast-isnumeric\":225}],1173:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,i){return n.coerce(t,e,c,r,i)}if(function(t,e,r){var n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length);return e._length=a,a}(0,e,h)){if(h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),h(\"below\"),i.hasLines(e)&&(o(t,e,r,u,h,{noDash:!0}),h(\"connectgaps\")),i.hasMarkers(e)){a(t,e,r,u,h,{noLine:!0});var f=e.marker;\"circle\"!==f.symbol&&(n.isArrayOrTypedArray(f.size)&&(f.size=f.size[0]),n.isArrayOrTypedArray(f.color)&&(f.color=f.color[0]))}i.hasText(e)&&s(t,e,u,h,{noSelect:!0}),h(\"fill\"),\"none\"!==e.fill&&l(t,e,r,h),n.coerceSelectionMarkerOpacity(e,h)}else e.visible=!1}},{\"../../lib\":719,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1171}],1174:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t}},{}],1175:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\"),o=i.fillText,s=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,h=t.ya,f=t.subplot,p=360*(e>=0?Math.floor((e+180)/360):Math.ceil((e-180)/360)),d=e-p;if(n.getClosest(l,function(t){var e=t.lonlat;if(e[0]===s)return 1/0;var n=i.modHalf(e[0],360),a=e[1],o=f.project([n,a]),l=o.x-u.c2p([d,a]),c=o.y-h.c2p([n,r]),p=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(l*l+c*c)-p,1-3/p)},t),!1!==t.index){var g=l[t.index],v=g.lonlat,m=[i.modHalf(v[0],360)+p,v[1]],y=u.c2p(m),x=h.c2p(m),b=g.mrc||1;return t.x0=y-b,t.x1=y+b,t.y0=x-b,t.y1=x+b,t.color=a(c,g),t.extraText=function(t,e,r){if(t.hovertemplate)return;var n=(e.hi||t.hoverinfo).split(\"+\"),i=-1!==n.indexOf(\"all\"),a=-1!==n.indexOf(\"lon\"),s=-1!==n.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}i||a&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):a?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(i||-1!==n.indexOf(\"text\"))&&o(e,t,c);return c.join(\"<br>\")}(c,g,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},{\"../../components/fx\":632,\"../../constants/numerical\":695,\"../../lib\":719,\"../scatter/get_trace_color\":1121}],1176:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"../scattergeo/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.update(e)},moduleType:\"trace\",name:\"scattermapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"symbols\",\"showLegend\",\"scatterlike\"],meta:{}}},{\"../../plots/mapbox\":822,\"../scatter/marker_colorbar\":1129,\"../scattergeo/calc\":1152,\"./attributes\":1171,\"./defaults\":1173,\"./event_data\":1174,\"./hover\":1175,\"./plot\":1177,\"./select\":1178}],1177:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix,a=[\"fill\",\"line\",\"circle\",\"symbol\"];function o(t,e){this.subplot=t,this.uid=e,this.sourceIds={fill:\"source-\"+e+\"-fill\",line:\"source-\"+e+\"-line\",circle:\"source-\"+e+\"-circle\",symbol:\"source-\"+e+\"-symbol\"},this.layerIds={fill:i+e+\"-fill\",line:i+e+\"-line\",circle:i+e+\"-circle\",symbol:i+e+\"-symbol\"},this.below=null}var s=o.prototype;s.addSource=function(t,e){this.subplot.map.addSource(this.sourceIds[t],{type:\"geojson\",data:e.geojson})},s.setSourceData=function(t,e){this.subplot.map.getSource(this.sourceIds[t]).setData(e.geojson)},s.addLayer=function(t,e,r){this.subplot.addLayer({type:t,id:this.layerIds[t],source:this.sourceIds[t],layout:e.layout,paint:e.paint},r)},s.update=function(t){var e,r,i,o=this.subplot,s=o.map,l=n(t),c=o.belowLookup[\"trace-\"+this.uid];if(c!==this.below){for(e=a.length-1;e>=0;e--)r=a[e],s.removeLayer(this.layerIds[r]);for(e=0;e<a.length;e++)i=l[r=a[e]],this.addLayer(r,i,c);this.below=c}for(e=0;e<a.length;e++)i=l[r=a[e]],o.setOptions(this.layerIds[r],\"setLayoutProperty\",i.layout),\"visible\"===i.layout.visibility&&(this.setSourceData(r,i),o.setOptions(this.layerIds[r],\"setPaintProperty\",i.paint));t[0].trace._glTrace=this},s.dispose=function(){for(var t=this.subplot.map,e=a.length-1;e>=0;e--){var r=a[e];t.removeLayer(this.layerIds[r]),t.removeSource(this.sourceIds[r])}},e.exports=function(t,e){for(var r=e[0].trace,i=new o(t,r.uid),s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid],c=0;c<a.length;c++){var u=a[c],h=s[u];i.addSource(u,h),i.addLayer(u,h,l)}return e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":820,\"./convert\":1172}],1178:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,o=t.cd,s=t.xaxis,l=t.yaxis,c=[],u=o[0].trace;if(!i.hasMarkers(u))return[];if(!1===e)for(r=0;r<o.length;r++)o[r].selected=0;else for(r=0;r<o.length;r++){var h=o[r],f=h.lonlat;if(f[0]!==a){var p=[n.modHalf(f[0],360),f[1]],d=[s.c2p(p),l.c2p(p)];e.contains(d,null,r,t)?(c.push({pointNumber:r,lon:f[0],lat:f[1]}),h.selected=1):h.selected=0}}return c}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../scatter/subtypes\":1135}],1179:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../scatter/attributes\"),o=t(\"../../plots/attributes\"),s=a.line;e.exports={mode:a.mode,r:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},theta:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},r0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dr:{valType:\"number\",dflt:1,editType:\"calc\"},theta0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dtheta:{valType:\"number\",editType:\"calc\"},thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\",\"gradians\"],dflt:\"degrees\",editType:\"calc+clearAxisTypes\"},text:a.text,hovertext:a.hovertext,line:{color:s.color,width:s.width,dash:s.dash,shape:i({},s.shape,{values:[\"linear\",\"spline\"]}),smoothing:s.smoothing,editType:\"calc\"},connectgaps:a.connectgaps,marker:a.marker,cliponaxis:i({},a.cliponaxis,{dflt:!1}),textposition:a.textposition,textfont:a.textfont,fill:i({},a.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:a.fillcolor,hoverinfo:i({},o.hoverinfo,{flags:[\"r\",\"theta\",\"text\",\"name\"]}),hoveron:a.hoveron,hovertemplate:n(),selected:a.selected,unselected:a.unselected}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1180:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../plots/cartesian/axes\"),o=t(\"../scatter/colorscale_calc\"),s=t(\"../scatter/arrays_to_calcdata\"),l=t(\"../scatter/calc_selection\"),c=t(\"../scatter/calc\").calcMarkerSize;e.exports=function(t,e){for(var r=t._fullLayout,u=e.subplot,h=r[u].radialaxis,f=r[u].angularaxis,p=h.makeCalcdata(e,\"r\"),d=f.makeCalcdata(e,\"theta\"),g=e._length,v=new Array(g),m=0;m<g;m++){var y=p[m],x=d[m],b=v[m]={};n(y)&&n(x)?(b.r=y,b.theta=x):b.r=i}var _=c(e,g);return e._extremes.x=a.findExtremes(h,p,{ppad:_}),o(t,e),s(v,e),l(v,e),v}},{\"../../constants/numerical\":695,\"../../plots/cartesian/axes\":767,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc\":1113,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1181:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/line_shape_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,h=t(\"./attributes\");function f(t,e,r,n){var i,a=n(\"r\"),o=n(\"theta\");if(a)o?i=Math.min(a.length,o.length):(i=a.length,n(\"theta0\"),n(\"dtheta\"));else{if(!o)return 0;i=e.theta.length,n(\"r0\"),n(\"dr\")}return e._length=i,i}e.exports={handleRThetaDefaults:f,supplyDefaults:function(t,e,r,p){function d(r,i){return n.coerce(t,e,h,r,i)}var g=f(0,e,0,d);if(g){d(\"thetaunit\"),d(\"mode\",g<u?\"lines+markers\":\"lines\"),d(\"text\"),d(\"hovertext\"),\"fills\"!==e.hoveron&&d(\"hovertemplate\"),i.hasLines(e)&&(o(t,e,r,p,d),s(t,e,d),d(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,p,d,{gradient:!0}),i.hasText(e)&&l(t,e,p,d);var v=[];(i.hasMarkers(e)||i.hasText(e))&&(d(\"cliponaxis\"),d(\"marker.maxdisplayed\"),v.push(\"points\")),d(\"fill\"),\"none\"!==e.fill&&(c(t,e,r,d),i.hasLines(e)||s(t,e,d)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||v.push(\"fills\"),d(\"hoveron\",v.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/line_shape_defaults\":1126,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1179}],1182:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\");function o(t,e,r,n){var o=r.radialAxis,s=r.angularAxis;o._hovertitle=\"r\",s._hovertitle=\"\\u03b8\";var l=o.c2l(t.r);n.rLabel=i.tickText(o,l,\"hover\").text;var c=\"degrees\"===s.thetaunit?a.rad2deg(t.theta):t.theta;n.thetaLabel=i.tickText(s,c,\"hover\").text;var u=t.hi||e.hoverinfo,h=[];function f(t,e){h.push(t._hovertitle+\": \"+e)}if(!e.hovertemplate){var p=u.split(\"+\");-1!==p.indexOf(\"all\")&&(p=[\"r\",\"theta\",\"text\"]),-1!==p.indexOf(\"r\")&&f(o,n.rLabel),-1!==p.indexOf(\"theta\")&&f(s,n.thetaLabel),-1!==p.indexOf(\"text\")&&n.text&&(h.push(n.text),delete n.text),n.extraText=h.join(\"<br>\")}}e.exports={hoverPoints:function(t,e,r,i){var a=n(t,e,r,i);if(a&&!1!==a[0].index){var s=a[0];if(void 0===s.index)return a;var l=t.subplot,c=s.cd[s.index],u=s.trace;if(l.isPtInside(c))return s.xLabelVal=void 0,s.yLabelVal=void 0,o(c,u,l,s),s.hovertemplate=u.hovertemplate,a}},makeHoverPointText:o}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scatter/hover\":1122}],1183:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scatter/select\"),meta:{}}},{\"../../plots/polar\":831,\"../scatter/marker_colorbar\":1129,\"../scatter/select\":1132,\"../scatter/style\":1134,\"./attributes\":1179,\"./calc\":1180,\"./defaults\":1181,\"./hover\":1182,\"./plot\":1184}],1184:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){for(var a=e.layers.frontplot.select(\"g.scatterlayer\"),o={xaxis:e.xaxis,yaxis:e.yaxis,plot:e.framework,layerClipId:e._hasClipOnAxisFalse?e.clipIds.forTraces:null},s=e.radialAxis,l=e.angularAxis,c=0;c<r.length;c++)for(var u=r[c],h=0;h<u.length;h++){var f=u[h],p=f.r;if(p===i)f.x=f.y=i;else{var d=s.c2g(p),g=l.c2g(f.theta);f.x=d*Math.cos(g),f.y=d*Math.sin(g)}}n(t,o,r,a)}},{\"../../constants/numerical\":695,\"../scatter/plot\":1131}],1185:[function(t,e,r){\"use strict\";var n=t(\"../scatterpolar/attributes\"),i=t(\"../scattergl/attributes\");e.exports={mode:n.mode,r:n.r,theta:n.theta,r0:n.r0,dr:n.dr,theta0:n.theta0,dtheta:n.dtheta,thetaunit:n.thetaunit,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,line:i.line,connectgaps:i.connectgaps,marker:i.marker,fill:i.fill,fillcolor:i.fillcolor,textposition:i.textposition,textfont:i.textfont,hoverinfo:n.hoverinfo,selected:n.selected,unselected:n.unselected}},{\"../scattergl/attributes\":1160,\"../scatterpolar/attributes\":1179}],1186:[function(t,e,r){\"use strict\";var n=t(\"../scatter/colorscale_calc\"),i=t(\"../scatter/calc\").calcMarkerSize,a=t(\"../scattergl/convert\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r=t._fullLayout,l=e.subplot,c=r[l].radialaxis,u=r[l].angularaxis,h=c.makeCalcdata(e,\"r\"),f=u.makeCalcdata(e,\"theta\"),p=e._length,d={};p<h.length&&(h=h.slice(0,p)),p<f.length&&(f=f.slice(0,p)),d.r=h,d.theta=f,n(t,e);var g,v=d.opts=a.style(t,e);return p<s?g=i(e,p):v.marker&&(g=2*(v.marker.sizeAvg||Math.max(v.marker.size,3))),e._extremes.x=o.findExtremes(c,h,{ppad:g}),[{x:!1,y:!1,t:d,trace:e}]}},{\"../../plots/cartesian/axes\":767,\"../scatter/calc\":1113,\"../scatter/colorscale_calc\":1115,\"../scattergl/constants\":1162,\"../scattergl/convert\":1163}],1187:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatterpolar/defaults\").handleRThetaDefaults,o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}var d=a(t,e,f,p);d?(p(\"thetaunit\"),p(\"mode\",d<u?\"lines+markers\":\"lines\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),i.hasLines(e)&&(s(t,e,r,f,p),p(\"connectgaps\")),i.hasMarkers(e)&&o(t,e,r,f,p),i.hasText(e)&&l(t,e,f,p),p(\"fill\"),\"none\"!==e.fill&&c(t,e,r,p),n.coerceSelectionMarkerOpacity(e,p)):e.visible=!1}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"../scatterpolar/defaults\":1181,\"./attributes\":1185}],1188:[function(t,e,r){\"use strict\";var n=t(\"../scattergl/hover\"),i=t(\"../scatterpolar/hover\").makeHoverPointText;e.exports={hoverPoints:function(t,e,r,a){var o=t.cd[0].t,s=o.r,l=o.theta,c=n.hoverPoints(t,e,r,a);if(c&&!1!==c[0].index){var u=c[0];if(void 0===u.index)return c;var h=t.subplot,f=u.cd[u.index],p=u.trace;if(f.r=s[u.index],f.theta=l[u.index],h.isPtInside(f))return u.xLabelVal=void 0,u.yLabelVal=void 0,i(f,p,h,u),c}}}},{\"../scattergl/hover\":1166,\"../scatterpolar/hover\":1182}],1189:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolargl\",basePlotModule:t(\"../../plots/polar\"),categories:[\"gl\",\"regl\",\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scattergl/select\"),meta:{}}},{\"../../plots/polar\":831,\"../scatter/marker_colorbar\":1129,\"../scattergl/select\":1170,\"./attributes\":1185,\"./calc\":1186,\"./defaults\":1187,\"./hover\":1188,\"./plot\":1190}],1190:[function(t,e,r){\"use strict\";var n=t(\"point-cluster\"),i=t(\"fast-isnumeric\"),a=t(\"../scattergl/plot\"),o=t(\"../scattergl/scene_update\"),s=t(\"../scattergl/convert\"),l=t(\"../../lib\"),c=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e,r){if(r.length){var u=e.radialAxis,h=e.angularAxis,f=o(t,e);return r.forEach(function(r){if(r&&r[0]&&r[0].trace){var a,o=r[0],p=o.trace,d=o.t,g=p._length,v=d.r,m=d.theta,y=d.opts,x=v.slice(),b=m.slice();for(a=0;a<v.length;a++)e.isPtInside({r:v[a],theta:m[a]})||(x[a]=NaN,b[a]=NaN);var _=new Array(2*g),w=Array(g),k=Array(g);for(a=0;a<g;a++){var T,A,M=x[a];if(i(M)){var S=u.c2g(M),E=h.c2g(b[a],p.thetaunit);T=S*Math.cos(E),A=S*Math.sin(E)}else T=A=NaN;w[a]=_[2*a]=T,k[a]=_[2*a+1]=A}d.tree=n(_),y.marker&&g>=c&&(y.marker.cluster=d.tree),y.marker&&(y.markerSel.positions=y.markerUnsel.positions=y.marker.positions=_),y.line&&_.length>1&&l.extendFlat(y.line,s.linePositions(t,p,_)),y.text&&(l.extendFlat(y.text,{positions:_},s.textPosition(t,p,y.text,y.marker)),l.extendFlat(y.textSel,{positions:_},s.textPosition(t,p,y.text,y.markerSel)),l.extendFlat(y.textUnsel,{positions:_},s.textPosition(t,p,y.text,y.markerUnsel))),y.fill&&!f.fill2d&&(f.fill2d=!0),y.marker&&!f.scatter2d&&(f.scatter2d=!0),y.line&&!f.line2d&&(f.line2d=!0),y.text&&!f.glText&&(f.glText=!0),f.lineOptions.push(y.line),f.fillOptions.push(y.fill),f.markerOptions.push(y.marker),f.markerSelectedOptions.push(y.markerSel),f.markerUnselectedOptions.push(y.markerUnsel),f.textOptions.push(y.text),f.textSelectedOptions.push(y.textSel),f.textUnselectedOptions.push(y.textUnsel),f.selectBatch.push([]),f.unselectBatch.push([]),d.x=w,d.y=k,d.rawx=w,d.rawy=k,d.r=v,d.theta=m,d.positions=_,d._scene=f,d.index=f.count,f.count++}}),a(t,e,r)}}},{\"../../lib\":719,\"../scattergl/constants\":1162,\"../scattergl/convert\":1163,\"../scattergl/plot\":1168,\"../scattergl/scene_update\":1169,\"fast-isnumeric\":225,\"point-cluster\":469}],1191:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/drawing/attributes\").dash,l=t(\"../../lib/extend\").extendFlat,c=i.marker,u=i.line,h=c.line;e.exports={a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},c:{valType:\"data_array\",editType:\"calc\"},sum:{valType:\"number\",dflt:0,min:0,editType:\"calc\"},mode:l({},i.mode,{dflt:\"markers\"}),text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),line:{color:u.color,width:u.width,dash:s,shape:l({},u.shape,{values:[\"linear\",\"spline\"]}),smoothing:u.smoothing,editType:\"calc\"},connectgaps:i.connectgaps,cliponaxis:i.cliponaxis,fill:l({},i.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:i.fillcolor,marker:l({symbol:c.symbol,opacity:c.opacity,maxdisplayed:c.maxdisplayed,size:c.size,sizeref:c.sizeref,sizemin:c.sizemin,sizemode:c.sizemode,line:l({width:h.width,editType:\"calc\"},o(\"marker.line\")),gradient:c.gradient,editType:\"calc\"},o(\"marker\")),textfont:i.textfont,textposition:i.textposition,selected:i.selected,unselected:i.unselected,hoverinfo:l({},a.hoverinfo,{flags:[\"a\",\"b\",\"c\",\"text\",\"name\"]}),hoveron:i.hoveron,hovertemplate:n()}},{\"../../components/colorscale/attributes\":600,\"../../components/drawing/attributes\":613,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1192:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=[\"a\",\"b\",\"c\"],c={a:[\"b\",\"c\"],b:[\"a\",\"c\"],c:[\"a\",\"b\"]};e.exports=function(t,e){var r,u,h,f,p,d,g=t._fullLayout[e.subplot].sum,v=e.sum||g,m={a:e.a,b:e.b,c:e.c};for(r=0;r<l.length;r++)if(!m[h=l[r]]){for(p=m[c[h][0]],d=m[c[h][1]],f=new Array(p.length),u=0;u<p.length;u++)f[u]=v-p[u]-d[u];m[h]=f}var y,x,b,_,w,k,T=e._length,A=new Array(T);for(r=0;r<T;r++)y=m.a[r],x=m.b[r],b=m.c[r],n(y)&&n(x)&&n(b)?(1!==(_=g/((y=+y)+(x=+x)+(b=+b)))&&(y*=_,x*=_,b*=_),k=y,w=b-x,A[r]={x:w,y:k,a:y,b:x,c:b}):A[r]={x:!1,y:!1};return s(e,T),i(t,e),a(A,e),o(A,e),A}},{\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc\":1113,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1193:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}var d,g=p(\"a\"),v=p(\"b\"),m=p(\"c\");if(g?(d=g.length,v?(d=Math.min(d,v.length),m&&(d=Math.min(d,m.length))):d=m?Math.min(d,m.length):0):v&&m&&(d=Math.min(v.length,m.length)),d){e._length=d,p(\"sum\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),p(\"mode\",d<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,f,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,f,p,{gradient:!0}),a.hasText(e)&&c(t,e,f,p);var y=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"cliponaxis\"),p(\"marker.maxdisplayed\"),y.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||y.push(\"fills\"),p(\"hoveron\",y.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/line_shape_defaults\":1126,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1191}],1194:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),n[i]){var a=n[i];t.a=a.a,t.b=a.b,t.c=a.c}else t.a=e.a,t.b=e.b,t.c=e.c;return t}},{}],1195:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,h=c-u;return s.x0=Math.max(Math.min(s.x0,h),u),s.x1=Math.max(Math.min(s.x1,h),u),o}var f=s.cd[s.index];s.a=f.a,s.b=f.b,s.c=f.c,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.subplot;s.aLabel=i.tickText(p.aaxis,f.a,\"hover\").text,s.bLabel=i.tickText(p.baxis,f.b,\"hover\").text,s.cLabel=i.tickText(p.caxis,f.c,\"hover\").text;var d=s.trace,g=f.hi||d.hoverinfo,v=[];if(!d.hovertemplate){var m=g.split(\"+\");-1!==m.indexOf(\"all\")&&(m=[\"a\",\"b\",\"c\"]),-1!==m.indexOf(\"a\")&&y(p.aaxis,s.aLabel),-1!==m.indexOf(\"b\")&&y(p.baxis,s.bLabel),-1!==m.indexOf(\"c\")&&y(p.caxis,s.cLabel)}return s.extraText=v.join(\"<br>\"),s.hovertemplate=d.hovertemplate,o}function y(t,e){v.push(t._hovertitle+\": \"+e)}}},{\"../../plots/cartesian/axes\":767,\"../scatter/hover\":1122}],1196:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scatterternary\",basePlotModule:t(\"../../plots/ternary\"),categories:[\"ternary\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/ternary\":843,\"../scatter/marker_colorbar\":1129,\"../scatter/select\":1132,\"../scatter/style\":1134,\"./attributes\":1191,\"./calc\":1192,\"./defaults\":1193,\"./event_data\":1194,\"./hover\":1195,\"./plot\":1197}],1197:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\");e.exports=function(t,e,r){var i=e.plotContainer;i.select(\".scatterlayer\").selectAll(\"*\").remove();var a={xaxis:e.xaxis,yaxis:e.yaxis,plot:i,layerClipId:e._hasClipOnAxisFalse?e.clipIdRelative:null},o=e.layers.frontplot.select(\"g.scatterlayer\");n(t,a,r,o)}},{\"../scatter/plot\":1131}],1198:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../scattergl/attributes\"),s=t(\"../../plots/cartesian/constants\").idRegex,l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"../../lib/extend\").extendFlat,u=n.marker,h=u.line,f=c(i(\"marker.line\",{editTypeOverride:\"calc\"}),{width:c({},h.width,{editType:\"calc\"}),editType:\"calc\"}),p=c(i(\"marker\"),{symbol:u.symbol,size:c({},u.size,{editType:\"markerSize\"}),sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:f,editType:\"calc\"});function d(t){return{valType:\"info_array\",freeLength:!0,editType:\"calc\",items:{valType:\"subplotid\",regex:s[t],editType:\"plot\"}}}p.color.editType=p.cmin.editType=p.cmax.editType=\"style\",e.exports={dimensions:l(\"dimension\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},label:{valType:\"string\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},axis:{type:{valType:\"enumerated\",values:[\"linear\",\"log\",\"date\",\"category\"],editType:\"calc+clearAxisTypes\"},matches:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc+clearAxisTypes\"},editType:\"calc+clearAxisTypes\"}),text:c({},o.text,{}),hovertext:c({},o.hovertext,{}),hovertemplate:a(),marker:p,xaxes:d(\"x\"),yaxes:d(\"y\"),diagonal:{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},showupperhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},showlowerhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},selected:{marker:o.selected.marker,editType:\"calc\"},unselected:{marker:o.unselected.marker,editType:\"calc\"},opacity:o.opacity}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773,\"../scatter/attributes\":1112,\"../scattergl/attributes\":1160}],1199:[function(t,e,r){\"use strict\";var n=t(\"regl-line2d\"),i=t(\"../../registry\"),a=t(\"../../lib/prepare_regl\"),o=t(\"../../plots/get_data\").getModuleCalcData,s=t(\"../../plots/cartesian\"),l=t(\"../../plots/cartesian/axis_ids\").getFromId,c=t(\"../../plots/cartesian/axes\").shouldShowZeroLine,u=\"splom\";function h(t,e,r){for(var n=r.matrixOptions.data.length,i=e._visibleDims,a=r.viewOpts.ranges=new Array(n),o=0;o<i.length;o++){var s=i[o],c=a[o]=new Array(4),u=l(t,e._diag[s][0]);u&&(c[0]=u.r2l(u.range[0]),c[2]=u.r2l(u.range[1]));var h=l(t,e._diag[s][1]);h&&(c[1]=h.r2l(h.range[0]),c[3]=h.r2l(h.range[1]))}r.selectBatch.length||r.unselectBatch.length?r.matrix.update({ranges:a},{ranges:a}):r.matrix.update({ranges:a})}function f(t){var e=t._fullLayout,r=e._glcanvas.data()[0].regl,i=e._splomGrid;i||(i=e._splomGrid=n(r)),i.update(function(t){var e,r=t._fullLayout,n=r._size,i=[0,0,r.width,r.height],a={};function o(t,e,r,n,o,s){var l=e[t+\"color\"],c=e[t+\"width\"],u=String(l+c);u in a?a[u].data.push(NaN,NaN,r,n,o,s):a[u]={data:[r,n,o,s],join:\"rect\",thickness:c,color:l,viewport:i,range:i,overlay:!1}}for(e in r._splomSubplots){var s,l,u=r._plots[e],h=u.xaxis,f=u.yaxis,p=h._vals,d=f._vals,g=n.b+f.domain[0]*n.h,v=-f._m,m=-v*f.r2l(f.range[0],f.calendar);if(h.showgrid)for(e=0;e<p.length;e++)s=h._offset+h.l2p(p[e].x),o(\"grid\",h,s,g,s,g+f._length);if(f.showgrid)for(e=0;e<d.length;e++)l=g+m+v*d[e].x,o(\"grid\",f,h._offset,l,h._offset+h._length,l);c(t,h,f)&&(s=h._offset+h.l2p(0),o(\"zeroline\",h,s,g,s,g+f._length)),c(t,f,h)&&(l=g+m+0,o(\"zeroline\",f,h._offset,l,h._offset+h._length,l))}var y=[];for(e in a)y.push(a[e]);return y}(t))}e.exports={name:u,attr:s.attr,attrRegex:s.attrRegex,layoutAttributes:s.layoutAttributes,supplyLayoutDefaults:s.supplyLayoutDefaults,drawFramework:s.drawFramework,plot:function(t){var e=t._fullLayout,r=i.getModule(u),n=o(t.calcdata,r)[0];a(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])&&(e._hasOnlyLargeSploms&&f(t),r.plot(t,{},n))},drag:function(t){var e=t.calcdata,r=t._fullLayout;r._hasOnlyLargeSploms&&f(t);for(var n=0;n<e.length;n++){var i=e[n][0].trace,a=r._splomScenes[i.uid];\"splom\"===i.type&&a&&a.matrix&&h(t,i,a)}},updateGrid:f,clean:function(t,e,r,n){var i,a={};if(n._splomScenes){for(i=0;i<t.length;i++){var o=t[i];\"splom\"===o.type&&(a[o.uid]=1)}for(i=0;i<r.length;i++){var l=r[i];if(!a[l.uid]){var c=n._splomScenes[l.uid];c&&c.destroy&&c.destroy(),n._splomScenes[l.uid]=null,delete n._splomScenes[l.uid]}}}0===Object.keys(n._splomScenes||{}).length&&delete n._splomScenes,n._splomGrid&&!e._hasOnlyLargeSploms&&n._hasOnlyLargeSploms&&(n._splomGrid.destroy(),n._splomGrid=null,delete n._splomGrid),s.clean(t,e,r,n)},updateFx:s.updateFx,toSVG:s.toSVG}},{\"../../lib/prepare_regl\":732,\"../../plots/cartesian\":778,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_ids\":770,\"../../plots/get_data\":802,\"../../registry\":847,\"regl-line2d\":491}],1200:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../scatter/calc\").calcMarkerSize,o=t(\"../scatter/calc\").calcAxisExpansion,s=t(\"../scatter/colorscale_calc\"),l=t(\"../scattergl/convert\").markerSelection,c=t(\"../scattergl/convert\").markerStyle,u=t(\"./scene_update\"),h=t(\"../../constants/numerical\").BADNUM,f=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r,p,d,g,v,m,y=e.dimensions,x=e._length,b={},_=b.cdata=[],w=b.data=[],k=e._visibleDims=[];function T(t,r){for(var i=t.makeCalcdata({v:r.values,vcalendar:e.calendar},\"v\"),a=0;a<i.length;a++)i[a]=i[a]===h?NaN:i[a];_.push(i),w.push(\"log\"===t.type?n.simpleMap(i,t.c2l):i)}for(r=0;r<y.length;r++)if((d=y[r]).visible){if(g=i.getFromId(t,e._diag[r][0]),v=i.getFromId(t,e._diag[r][1]),g&&v&&g.type!==v.type){n.log(\"Skipping splom dimension \"+r+\" with conflicting axis types\");continue}g?(T(g,d),v&&\"category\"===v.type&&(v._categories=g._categories.slice())):T(v,d),k.push(r)}for(s(t,e),n.extendFlat(b,c(e)),m=_.length*x>f?2*(b.sizeAvg||Math.max(b.size,3)):a(e,x),p=0;p<k.length;p++)d=y[r=k[p]],g=i.getFromId(t,e._diag[r][0])||{},v=i.getFromId(t,e._diag[r][1])||{},o(t,e,g,v,_[p],_[p],m);var A=u(t,e);return A.matrix||(A.matrix=!0),A.matrixOptions=b,A.selectedOptions=l(e,e.selected),A.unselectedOptions=l(e,e.unselected),[{x:!1,y:!1,t:{},trace:e}]}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../scatter/calc\":1113,\"../scatter/colorscale_calc\":1115,\"../scattergl/constants\":1162,\"../scattergl/convert\":1163,\"./scene_update\":1207}],1201:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"../scatter/subtypes\"),s=t(\"../scatter/marker_defaults\"),l=t(\"../parcoords/merge_length\"),c=/-open/;function u(t,e){function r(r,i){return n.coerce(t,e,a.dimensions,r,i)}r(\"label\");var i=r(\"values\");i&&i.length?r(\"visible\"):e.visible=!1,r(\"axis.type\"),r(\"axis.matches\")}e.exports=function(t,e,r,h){function f(r,i){return n.coerce(t,e,a,r,i)}var p=i(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=f(\"diagonal.visible\"),g=f(\"showupperhalf\"),v=f(\"showlowerhalf\");if(l(e,p,\"values\")&&(d||g||v)){f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),s(t,e,r,h,f);var m=c.test(e.marker.symbol),y=o.isBubble(e);f(\"marker.line.width\",m||y?1:0),function(t,e,r,n){var i,a,o=e.dimensions,s=o.length,l=e.showupperhalf,c=e.showlowerhalf,u=e.diagonal.visible,h=new Array(s),f=new Array(s);for(i=0;i<s;i++){var p=i?i+1:\"\";h[i]=\"x\"+p,f[i]=\"y\"+p}var d=n(\"xaxes\",h),g=n(\"yaxes\",f),v=e._diag=new Array(s);e._xaxes={},e._yaxes={};var m=[],y=[];function x(t,n,i,a){if(t){var o=t.charAt(0),s=r._splomAxes[o];if(e[\"_\"+o+\"axes\"][t]=1,a.push(t),!(t in s)){var l=s[t]={};i&&(l.label=i.label||\"\",i.visible&&i.axis&&(i.axis.type&&(l.type=i.axis.type),i.axis.matches&&(l.matches=n)))}}}var b=!u&&!c,_=!u&&!l;for(e._axesDim={},i=0;i<s;i++){var w=o[i],k=0===i,T=i===s-1,A=k&&b||T&&_?void 0:d[i],M=k&&_||T&&b?void 0:g[i];x(A,M,w,m),x(M,A,w,y),v[i]=[A,M],e._axesDim[A]=i,e._axesDim[M]=i}for(i=0;i<m.length;i++)for(a=0;a<y.length;a++){var S=m[i]+y[a];i>a&&l?r._splomSubplots[S]=1:i<a&&c?r._splomSubplots[S]=1:i!==a||!u&&c&&l||(r._splomSubplots[S]=1)}(!c||!u&&l&&c)&&(r._splomGridDflt.xside=\"bottom\",r._splomGridDflt.yside=\"left\")}(0,e,h,f),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../parcoords/merge_length\":1083,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"./attributes\":1198}],1202:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scattergl/convert\").markerStyle;e.exports=function(t,e){var r=e.trace,o=t._fullLayout._splomScenes[r.uid];if(o){i(t,r),n.extendFlat(o.matrixOptions,a(r));var s=n.extendFlat({},o.matrixOptions,o.viewOpts);o.matrix.update(s,null)}}},{\"../../lib\":719,\"../scatter/colorscale_calc\":1115,\"../scattergl/convert\":1163}],1203:[function(t,e,r){\"use strict\";r.getDimIndex=function(t,e){for(var r=e._id,n={x:0,y:1}[r.charAt(0)],i=t._visibleDims,a=0;a<i.length;a++){var o=i[a];if(t._diag[o][n]===r)return a}return!1}},{}],1204:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i=t(\"../scattergl/hover\").calcHover;e.exports={hoverPoints:function(t,e,r){var a=t.cd[0].trace,o=t.scene.matrixOptions.cdata,s=t.xa,l=t.ya,c=s.c2p(e),u=l.c2p(r),h=t.distance,f=n.getDimIndex(a,s),p=n.getDimIndex(a,l);if(!1===f||!1===p)return[t];for(var d,g,v=o[f],m=o[p],y=h,x=0;x<v.length;x++){var b=v[x],_=m[x],w=s.c2p(b)-c,k=l.c2p(_)-u,T=Math.sqrt(w*w+k*k);T<y&&(y=g=T,d=x)}return t.index=d,t.distance=y,t.dxy=g,void 0===d?[t]:(i(t,v,m,a),[t])}}},{\"../scattergl/hover\":1166,\"./helpers\":1203}],1205:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../components/grid\");e.exports={moduleType:\"trace\",name:\"splom\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\"),editStyle:t(\"./edit_style\"),meta:{}},n.register(i)},{\"../../components/grid\":636,\"../../registry\":847,\"../scatter/marker_colorbar\":1129,\"./attributes\":1198,\"./base_plot\":1199,\"./calc\":1200,\"./defaults\":1201,\"./edit_style\":1202,\"./hover\":1204,\"./plot\":1206,\"./select\":1208}],1206:[function(t,e,r){\"use strict\";var n=t(\"regl-splom\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\");function o(t,e){var r,o,s,l,c,u=t._fullLayout,h=u._size,f=e.trace,p=e.t,d=u._splomScenes[f.uid],g=d.matrixOptions,v=g.cdata,m=u._glcanvas.data()[0].regl,y=u.dragmode;if(0!==v.length){g.lower=f.showupperhalf,g.upper=f.showlowerhalf,g.diagonal=f.diagonal.visible;var x=f._visibleDims,b=v.length,_=d.viewOpts={};for(_.ranges=new Array(b),_.domains=new Array(b),c=0;c<x.length;c++){s=x[c];var w=_.ranges[c]=new Array(4),k=_.domains[c]=new Array(4);(r=a.getFromId(t,f._diag[s][0]))&&(w[0]=r._rl[0],w[2]=r._rl[1],k[0]=r.domain[0],k[2]=r.domain[1]),(o=a.getFromId(t,f._diag[s][1]))&&(w[1]=o._rl[0],w[3]=o._rl[1],k[1]=o.domain[0],k[3]=o.domain[1])}_.viewport=[h.l,h.b,h.w+h.l,h.h+h.b],!0===d.matrix&&(d.matrix=n(m));var T=u.clickmode.indexOf(\"select\")>-1,A=!0;if(\"lasso\"===y||\"select\"===y||!!f.selectedpoints||T){var M=f._length;if(f.selectedpoints){d.selectBatch=f.selectedpoints;var S=f.selectedpoints,E={};for(s=0;s<S.length;s++)E[S[s]]=!0;var C=[];for(s=0;s<M;s++)E[s]||C.push(s);d.unselectBatch=C}var L=p.xpx=new Array(b),P=p.ypx=new Array(b);for(c=0;c<x.length;c++){if(s=x[c],r=a.getFromId(t,f._diag[s][0]))for(L[c]=new Array(M),l=0;l<M;l++)L[c][l]=r.c2p(v[c][l]);if(o=a.getFromId(t,f._diag[s][1]))for(P[c]=new Array(M),l=0;l<M;l++)P[c][l]=o.c2p(v[c][l])}if(d.selectBatch.length||d.unselectBatch.length){var O=i.extendFlat({},g,d.unselectedOptions,_),z=i.extendFlat({},g,d.selectedOptions,_);d.matrix.update(O,z),A=!1}}else p.xpx=p.ypx=null;if(A){var I=i.extendFlat({},g,_);d.matrix.update(I,null)}}}e.exports=function(t,e,r){if(r.length)for(var n=0;n<r.length;n++)o(t,r[n][0])}},{\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"regl-splom\":501}],1207:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t._fullLayout,i=e.uid,a=r._splomScenes;a||(a=r._splomScenes={});var o={dirty:!0},s=a[e.uid];return s||((s=a[i]=n.extendFlat({},o,{matrix:!1,selectBatch:[],unselectBatch:[]})).draw=function(){s.matrix&&s.matrix.draw&&(s.selectBatch.length||s.unselectBatch.length?s.matrix.draw(s.unselectBatch,s.selectBatch):s.matrix.draw()),s.dirty=!1},s.destroy=function(){s.matrix&&s.matrix.destroy&&s.matrix.destroy(),s.matrixOptions=null,s.selectBatch=null,s.unselectBatch=null,s=null}),s.dirty||n.extendFlat(s,o),s}},{\"../../lib\":719}],1208:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"./helpers\");e.exports=function(t,e){var r=t.cd,o=r[0].trace,s=r[0].t,l=t.scene,c=l.matrixOptions.cdata,u=t.xaxis,h=t.yaxis,f=[];if(!l)return f;var p=!i.hasMarkers(o)&&!i.hasText(o);if(!0!==o.visible||p)return f;var d=a.getDimIndex(o,u),g=a.getDimIndex(o,h);if(!1===d||!1===g)return f;var v=s.xpx[d],m=s.ypx[g],y=c[d],x=c[g],b=[],_=[];if(!1!==e&&!e.degenerate)for(var w=0;w<y.length;w++)e.contains([v[w],m[w]],null,w,t)?(b.push(w),f.push({pointNumber:w,x:y[w],y:x[w]})):_.push(w);var k=l.matrixOptions;return b.length||_.length?l.selectBatch.length||l.unselectBatch.length||l.matrix.update(l.unselectedOptions,n.extendFlat({},k,l.selectedOptions,l.viewOpts)):l.matrix.update(k,null),l.selectBatch=b,l.unselectBatch=_,f}},{\"../../lib\":719,\"../scatter/subtypes\":1135,\"./helpers\":1203}],1209:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},starts:{x:{valType:\"data_array\",editType:\"calc\"},y:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},maxdisplayed:{valType:\"integer\",min:0,dflt:1e3,editType:\"calc\"},sizeref:{valType:\"number\",editType:\"calc\",min:0,dflt:1},text:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:i({editType:\"calc\"},{keys:[\"tubex\",\"tubey\",\"tubez\",\"tubeu\",\"tubev\",\"tubew\",\"norm\",\"divergence\"]})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach(function(t){l[t]=a[t]}),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"divergence\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../mesh3d/attributes\":1053}],1210:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){var r,i,a,o,s=e.u,l=e.v,c=e.w,u=e.x,h=e.y,f=e.z,p=Math.min(u.length,h.length,f.length,s.length,l.length,c.length),d=0;e.starts&&(i=e.starts.x||[],a=e.starts.y||[],o=e.starts.z||[],d=Math.min(i.length,a.length,o.length));var g=0,v=1/0;for(r=0;r<p;r++){var m=s[r],y=l[r],x=c[r],b=Math.sqrt(m*m+y*y+x*x);g=Math.max(g,b),v=Math.min(v,b)}n(t,e,{vals:[v,g],containerStr:\"\",cLetter:\"c\"});var _=-1/0,w=1/0,k=-1/0,T=1/0,A=-1/0,M=1/0;for(r=0;r<p;r++){var S=u[r];_=Math.max(_,S),w=Math.min(w,S);var E=h[r];k=Math.max(k,E),T=Math.min(T,E);var C=f[r];A=Math.max(A,C),M=Math.min(M,C)}for(r=0;r<d;r++){var L=i[r];_=Math.max(_,L),w=Math.min(w,L);var P=a[r];k=Math.max(k,P),T=Math.min(T,P);var O=o[r];A=Math.max(A,O),M=Math.min(M,O)}e._len=p,e._slen=d,e._normMax=g,e._xbnds=[w,_],e._ybnds=[T,k],e._zbnds=[M,A]}},{\"../../components/colorscale/calc\":601}],1211:[function(t,e,r){\"use strict\";var n=t(\"gl-streamtube3d\"),i=n.createTubeMesh,a=t(\"../../lib\"),o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\"),c={xaxis:0,yaxis:1,zaxis:2};function u(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var h=u.prototype;function f(t){return a.distinctVals(t).vals}function p(t){var e=t.length;return e>2?t.slice(1,e-1):2===e?[(t[0]+t[1])/2]:t}function d(t){var e=t.length;return 1===e?[.5,.5]:[t[1]-t[0],t[e-1]-t[e-2]]}function g(t,e){var r=t.fullSceneLayout,i=t.dataScale,u=e._len,h={};function g(t,e){var n=r[e],o=i[c[e]];return a.simpleMap(t,function(t){return n.d2l(t)*o})}h.vectors=l(g(e.u,\"xaxis\"),g(e.v,\"yaxis\"),g(e.w,\"zaxis\"),u);var v=f(e.x.slice(0,u)),m=f(e.y.slice(0,u)),y=f(e.z.slice(0,u));if(v.length*m.length*y.length>u)return{positions:[],cells:[]};var x=g(v,\"xaxis\"),b=g(m,\"yaxis\"),_=g(y,\"zaxis\");if(h.meshgrid=[x,b,_],e.starts){var w=e._slen;h.startingPositions=l(g(e.starts.x.slice(0,w),\"xaxis\"),g(e.starts.y.slice(0,w),\"yaxis\"),g(e.starts.z.slice(0,w),\"zaxis\"))}else{for(var k=b[0],T=p(x),A=p(_),M=new Array(T.length*A.length),S=0,E=0;E<T.length;E++)for(var C=0;C<A.length;C++)M[S++]=[T[E],k,A[C]];h.startingPositions=M}h.colormap=o(e),h.tubeSize=e.sizeref,h.maxLength=e.maxdisplayed;var L=g(e._xbnds,\"xaxis\"),P=g(e._ybnds,\"yaxis\"),O=g(e._zbnds,\"zaxis\"),z=d(x),I=d(b),D=d(_),R=[[L[0]-z[0],P[0]-I[0],O[0]-D[0]],[L[1]+z[1],P[1]+I[1],O[1]+D[1]]],F=n(h,R),B=s(e);F.vertexIntensityBounds=[B.min/e._normMax,B.max/e._normMax];var N=e.lightposition;return F.lightPosition=[N.x,N.y,N.z],F.ambient=e.lighting.ambient,F.diffuse=e.lighting.diffuse,F.specular=e.lighting.specular,F.roughness=e.lighting.roughness,F.fresnel=e.lighting.fresnel,F.opacity=e.opacity,e._pad=F.tubeScale*e.sizeref*2,F}h.handlePick=function(t){var e=this.scene.fullSceneLayout,r=this.scene.dataScale;function n(t,n){var i=e[n],a=r[c[n]];return i.l2c(t)/a}if(t.object===this.mesh){var i=t.data.position,a=t.data.velocity;return t.traceCoordinate=[n(i[0],\"xaxis\"),n(i[1],\"yaxis\"),n(i[2],\"zaxis\"),n(a[0],\"xaxis\"),n(a[1],\"yaxis\"),n(a[2],\"zaxis\"),t.data.intensity*this.data._normMax,t.data.divergence],t.textLabel=this.data.hovertext||this.data.text,!0}},h.update=function(t){this.data=t;var e=g(this.scene,t);this.mesh.update(e)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=g(t,e),a=i(r,n),o=new u(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../plots/gl3d/zip3\":818,\"gl-streamtube3d\":313}],1212:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),h=s(\"x\"),f=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length&&p&&p.length?(s(\"starts.x\"),s(\"starts.y\"),s(\"starts.z\"),s(\"maxdisplayed\"),s(\"sizeref\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":1209}],1213:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"streamtube\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),eventData:function(t,e){return t.tubex=t.x,t.tubey=t.y,t.tubez=t.z,t.tubeu=e.traceCoordinate[3],t.tubev=e.traceCoordinate[4],t.tubew=e.traceCoordinate[5],t.norm=e.traceCoordinate[6],t.divergence=e.traceCoordinate[7],delete t.x,delete t.y,delete t.z,t},meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1209,\"./calc\":1210,\"./convert\":1211,\"./defaults\":1212}],1214:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../plots/domain\").attributes,o=t(\"../pie/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports={labels:{valType:\"data_array\",editType:\"calc\"},parents:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},branchvalues:{valType:\"enumerated\",values:[\"remainder\",\"total\"],dflt:\"remainder\",editType:\"calc\"},level:{valType:\"any\",editType:\"plot\",anim:!0},maxdepth:{valType:\"integer\",editType:\"plot\",dflt:-1},marker:{colors:{valType:\"data_array\",editType:\"calc\"},line:{color:s({},o.marker.line.color,{dflt:null}),width:s({},o.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},leaf:{opacity:{valType:\"number\",editType:\"style\",min:0,max:1,dflt:.7},editType:\"plot\"},text:o.text,textinfo:s({},o.textinfo,{editType:\"plot\",flags:[\"label\",\"text\",\"value\"]}),textfont:o.textfont,hovertext:o.hovertext,hoverinfo:s({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"name\"]}),hovertemplate:i(),insidetextfont:o.insidetextfont,outsidetextfont:o.outsidetextfont,domain:a({name:\"sunburst\",trace:!0,editType:\"calc\"})}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../pie/attributes\":1086}],1215:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=r.name=\"sunburst\";r.plot=function(t,e,r,o){var s=n.getModule(a),l=i(t.calcdata,s)[0];s.plot(t,l,r,o)},r.clean=function(t,e,r,n){var i=n._has&&n._has(a),o=e._has&&e._has(a);i&&!o&&n._sunburstlayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],1216:[function(t,e,r){\"use strict\";var n=t(\"d3-hierarchy\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../pie/calc\").makePullColorFn,s=t(\"../pie/calc\").generateExtendedColors,l=a.isArrayOrTypedArray,c={};r.calc=function(t,e){var r,s,c,u,h,f,p=t._fullLayout,d=e.ids,g=l(d),v=e.labels,m=e.parents,y=e.values,x=l(y),b=[],_={},w={},k=function(t){return t||\"number\"==typeof t},T=function(t){return!x||i(y[t])&&y[t]>=0};g?(r=Math.min(d.length,m.length),s=function(t){return k(d[t])&&T(t)},c=function(t){return String(d[t])}):(r=Math.min(v.length,m.length),s=function(t){return k(v[t])&&T(t)},c=function(t){return String(v[t])}),x&&(r=Math.min(r,y.length));for(var A=0;A<r;A++)if(s(A)){var M=c(A),S=k(m[A])?String(m[A]):\"\",E={i:A,id:M,pid:S,label:k(v[A])?String(v[A]):\"\"};x&&(E.v=+y[A]),b.push(E),h=M,_[u=S]?_[u].push(h):_[u]=[h],w[h]=1}if(_[\"\"]){if(_[\"\"].length>1){for(var C=a.randstr(),L=0;L<b.length;L++)\"\"===b[L].pid&&(b[L].pid=C);b.unshift({hasMultipleRoots:!0,id:C,pid:\"\"})}}else{var P,O=[];for(P in _)w[P]||O.push(P);if(1!==O.length)return a.warn(\"Multiple implied roots, cannot build sunburst hierarchy.\");P=O[0],b.unshift({id:P,pid:\"\",label:P})}try{f=n.stratify().id(function(t){return t.id}).parentId(function(t){return t.pid})(b)}catch(t){return a.warn(\"Failed to build sunburst hierarchy. Error: \"+t.message)}var z=n.hierarchy(f),I=!1;if(x)switch(e.branchvalues){case\"remainder\":z.sum(function(t){return t.data.v});break;case\"total\":z.each(function(t){var e=t.data.data.v;if(t.children&&e<t.children.reduce(function(t,e){return t+e.data.data.v},0))return I=!0,a.warn([\"Total value for node\",t.data.data.id,\"is smaller than the sum of its children.\"].join(\" \"));t.value=e})}else z.count();if(!I){z.sort(function(t,e){return e.value-t.value});var D=e.marker.colors||[],R=o(p._sunburstcolormap);return z.each(function(t){var e=t.data.data,r=e.id;e.color=R(D[e.i],r)}),b[0].hierarchy=z,b}},r.crossTraceCalc=function(t){var e=t._fullLayout,r=t.calcdata,n=e.sunburstcolorway,i=e._sunburstcolormap;e.extendsunburstcolors&&(n=s(n,c));var a=0;function o(t){var e=t.data.data,r=e.id;!1===e.color&&(i[r]?e.color=i[r]:t.parent?t.parent.parent?e.color=t.parent.data.data.color:(i[r]=e.color=n[a%n.length],a++):e.color=\"rgba(0,0,0,0)\")}for(var l=0;l<r.length;l++){var u=r[l][0];\"sunburst\"===u.trace.type&&u.hierarchy&&u.hierarchy.each(o)}}},{\"../../lib\":719,\"../pie/calc\":1088,\"d3-hierarchy\":157,\"fast-isnumeric\":225}],1217:[function(t,e,r){\"use strict\";e.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:\"linear\"}},{}],1218:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}var c=l(\"labels\"),u=l(\"parents\");if(c&&c.length&&u&&u.length){var h=l(\"values\");h&&h.length&&l(\"branchvalues\"),l(\"level\"),l(\"maxdepth\"),l(\"marker.line.width\")&&l(\"marker.line.color\",s.paper_bgcolor),l(\"marker.colors\"),l(\"leaf.opacity\");var f=l(\"text\");l(\"textinfo\",Array.isArray(f)?\"text+label\":\"label\"),l(\"hovertext\"),l(\"hovertemplate\");o(t,e,s,l,\"auto\",{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),a(e,s,l),e._length=null}else e.visible=!1}},{\"../../lib\":719,\"../../plots/domain\":792,\"../bar/defaults\":861,\"./attributes\":1214}],1219:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"sunburst\",basePlotModule:t(\"./base_plot\"),categories:[],animatable:!0,attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\").style,meta:{}}},{\"./attributes\":1214,\"./base_plot\":1215,\"./calc\":1216,\"./defaults\":1218,\"./layout_attributes\":1220,\"./layout_defaults\":1221,\"./plot\":1222,\"./style\":1223}],1220:[function(t,e,r){\"use strict\";e.exports={sunburstcolorway:{valType:\"colorlist\",editType:\"calc\"},extendsunburstcolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1221:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"sunburstcolorway\",e.colorway),r(\"extendsunburstcolors\")}},{\"../../lib\":719,\"./layout_attributes\":1220}],1222:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"d3-hierarchy\"),a=t(\"../../registry\"),o=t(\"../../components/fx\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../lib\"),u=t(\"../../lib/events\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"../../lib/setcursor\"),p=t(\"../../components/fx/helpers\").appendArrayPointValue,d=t(\"../pie/plot\").transformInsideText,g=t(\"../pie/helpers\").formatPieValue,v=t(\"./style\").styleOne,m=t(\"./constants\");function y(t,e,r,a){var o=t._fullLayout,u=a&&a.duration>0,f=n.select(r).selectAll(\"g.slice\"),p=e[0],m=p.trace,y=x(p.hierarchy,m.level),w=m.maxdepth>=0?m.maxdepth:1/0,M=o._size,S=m.domain,E=M.w*(S.x[1]-S.x[0]),C=M.h*(S.y[1]-S.y[0]),L=.5*Math.min(E,C),P=p.cx=M.l+M.w*(S.x[1]+S.x[0])/2,O=p.cy=M.t+M.h*(1-S.y[0])-C/2;if(!y)return f.remove();var z=null,I={};u&&f.each(function(t){I[k(t)]={rpx0:t.rpx0,rpx1:t.rpx1,x0:t.x0,x1:t.x1,transform:t.transform},!z&&_(t)&&(z=t)});var D=function(t){return i.partition().size([2*Math.PI,t.height+1])(t)}(y).descendants(),R=y.height+1,F=0,B=w;p.hasMultipleRoots&&b(y)&&(D=D.slice(1),R-=1,F=1,B+=1),D=D.filter(function(t){return t.y1<=B});var N=Math.min(R,w),j=function(t){return(t-F)/N*L},U=function(t,e){return[t*Math.cos(e),-t*Math.sin(e)]},V=function(t){return c.pathAnnulus(t.rpx0,t.rpx1,t.x0,t.x1,P,O)},q=function(t){return P+t.pxmid[0]*t.transform.rCenter+(t.transform.x||0)},H=function(t){return O+t.pxmid[1]*t.transform.rCenter+(t.transform.y||0)};(f=f.data(D,function(t){return k(t)})).enter().append(\"g\").classed(\"slice\",!0),u?f.exit().transition().each(function(){var t=n.select(this);t.select(\"path.surface\").transition().attrTween(\"d\",function(t){var e=function(t){var e,r=k(t),i=I[r],a=I[k(y)];if(a){var o=t.x1>a.x1?2*Math.PI:0;e=t.rpx1<a.rpx1?{rpx0:0,rpx1:0}:{x0:o,x1:o}}else{var s,l=k(t.parent);f.each(function(t){if(k(t)===l)return s=t});var c,u=s.children;u.forEach(function(t,e){if(k(t)===r)return c=e});var h=u.length,p=n.interpolate(s.x0,s.x1);e={rpx0:L,rpx1:L,x0:p(c/h),x1:p((c+1)/h)}}return n.interpolate(i,e)}(t);return function(t){return V(e(t))}}),t.select(\"g.slicetext\").attr(\"opacity\",0)}).remove():f.exit().remove(),f.order();var G=null;if(u&&z){var Y=k(z);f.each(function(t){null===G&&k(t)===Y&&(G=t.x1)})}var W=f;function X(t){var e=t.parent,r=I[k(e)],i={};if(r){var a=e.children,o=a.indexOf(t),s=a.length,l=n.interpolate(r.x0,r.x1);i.x0=l(o/s),i.x1=l(o/s)}else i.x0=i.x1=0;return i}u&&(W=W.transition().each(\"end\",function(){T(n.select(this),t,{isTransitioning:!1})})),W.each(function(r){var i=n.select(this),a=c.ensureSingle(i,\"path\",\"surface\",function(t){t.style(\"pointer-events\",\"all\")});r.rpx0=j(r.y0),r.rpx1=j(r.y1),r.xmid=(r.x0+r.x1)/2,r.pxmid=U(r.rpx1,r.xmid),r.midangle=-(r.xmid-Math.PI/2),r.halfangle=.5*Math.min(c.angleDelta(r.x0,r.x1)||Math.PI,Math.PI),r.ring=1-r.rpx0/r.rpx1,r.rInscribed=function(t){return 0===t.rpx0&&c.isFullCircle([t.x0,t.x1])?1:Math.max(0,Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2))}(r),u?a.transition().attrTween(\"d\",function(t){var e=function(t){var e,r=I[k(t)],i={x0:t.x0,x1:t.x1,rpx0:t.rpx0,rpx1:t.rpx1};if(r)e=r;else if(z)if(t.parent)if(G){var a=t.x1>G?2*Math.PI:0;e={x0:a,x1:a}}else e={rpx0:L,rpx1:L},c.extendFlat(e,X(t));else e={rpx0:0,rpx1:0};else e={x0:0,x1:0};return n.interpolate(e,i)}(t);return function(t){return V(e(t))}}):a.attr(\"d\",V),i.call(A,t,e).call(T,t,{isTransitioning:t._transitioning}),a.call(v,r,m);var f=c.ensureSingle(i,\"g\",\"slicetext\"),y=c.ensureSingle(f,\"text\",\"\",function(t){t.attr(\"data-notex\",1)});y.text(function(t,e,r){var n=e.textinfo;if(!n||\"none\"===n)return\"\";var i=t.data.data,a=r.separators,o=n.split(\"+\"),s=function(t){return-1!==o.indexOf(t)},l=[];s(\"label\")&&i.label&&l.push(i.label);i.hasOwnProperty(\"v\")&&s(\"value\")&&l.push(g(i.v,a));if(s(\"text\")){var u=c.castOption(e,i.i,\"text\");c.isValidTextValue(u)&&l.push(u)}return l.join(\"<br>\")}(r,m,o)).classed(\"slicetext\",!0).attr(\"text-anchor\",\"middle\").call(l.font,b(r)?function(t,e,r){var n=e.data.data.i,i=c.castOption(t,n,\"outsidetextfont.color\")||c.castOption(t,n,\"textfont.color\")||r.color,a=c.castOption(t,n,\"outsidetextfont.family\")||c.castOption(t,n,\"textfont.family\")||r.family,o=c.castOption(t,n,\"outsidetextfont.size\")||c.castOption(t,n,\"textfont.size\")||r.size;return{color:i,family:a,size:o}}(m,r,o.font):function(t,e,r){var n=e.data.data,i=n.i,a=c.castOption(t,i,\"insidetextfont.color\");!a&&t._input.textfont&&(a=c.castOption(t._input,i,\"textfont.color\"));var o=c.castOption(t,i,\"insidetextfont.family\")||c.castOption(t,i,\"textfont.family\")||r.family,l=c.castOption(t,i,\"insidetextfont.size\")||c.castOption(t,i,\"textfont.size\")||r.size;return{color:a||s.contrast(n.color),family:o,size:l}}(m,r,o.font)).call(h.convertToTspans,t);var x=l.bBox(y.node());r.transform=d(x,r,p),r.translateX=q(r),r.translateY=H(r);var _=function(t,e){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"+(t.transform.scale<1?\"scale(\"+t.transform.scale+\")\":\"\")+(t.transform.rotate?\"rotate(\"+t.transform.rotate+\")\":\"\")+\"translate(\"+-(e.left+e.right)/2+\",\"+-(e.top+e.bottom)/2+\")\"};u?y.transition().attrTween(\"transform\",function(t){var e=function(t){var e,r=I[k(t)],i=t.transform;if(r)e=r;else if(e={rpx1:t.rpx1,transform:{scale:0,rotate:i.rotate,rCenter:i.rCenter,x:i.x,y:i.y}},z)if(t.parent)if(G){var a=t.x1>G?2*Math.PI:0;e.x0=e.x1=a}else c.extendFlat(e,X(t));else e.x0=e.x1=0;else e.x0=e.x1=0;var o=n.interpolate(e.rpx1,t.rpx1),s=n.interpolate(e.x0,t.x0),l=n.interpolate(e.x1,t.x1),u=n.interpolate(e.transform.scale,i.scale),h=n.interpolate(e.transform.rotate,i.rotate),f=0===i.rCenter?3:0===e.transform.rCenter?1/3:1,p=n.interpolate(e.transform.rCenter,i.rCenter);return function(t){var e=o(t),r=s(t),n=l(t),a=function(t){return p(Math.pow(t,f))}(t),c={pxmid:U(e,(r+n)/2),transform:{rCenter:a,x:i.x,y:i.y}},d={rpx1:o(t),translateX:q(c),translateY:H(c),transform:{scale:u(t),rotate:h(t),rCenter:a}};return d}}(t);return function(t){return _(e(t),x)}}):y.attr(\"transform\",_(r,x))})}function x(t,e){var r;return e&&t.eachAfter(function(t){if(k(t)===e)return r=t.copy()}),r||t}function b(t){return\"\"===t.data.data.pid}function _(t){return!t.parent}function w(t){return!t.children}function k(t){return t.data.data.id}function T(t,e,r){var n=t.datum(),i=(r||{}).isTransitioning;f(t,i||w(n)||b(n)?null:\"pointer\")}function A(t,e,r){var i=r[0],s=i.trace;\"_hasHoverLabel\"in s||(s._hasHoverLabel=!1),\"_hasHoverEvent\"in s||(s._hasHoverEvent=!1),t.on(\"mouseover\",function(t){var r=e._fullLayout;if(!e._dragging&&!1!==r.hovermode){var a=e._fullData[s.index],l=t.data.data,u=l.i,h=function(t){return c.castOption(a,u,t)},f=h(\"hovertemplate\"),p=o.castHoverinfo(a,r,u),d=r.separators;if(f||p&&\"none\"!==p&&\"skip\"!==p){var v=t.rInscribed,m=i.cx+t.pxmid[0]*(1-v),y=i.cy+t.pxmid[1]*(1-v),x={},b=[],_=[],w=function(t){return-1!==b.indexOf(t)};if(p&&(b=\"all\"===p?a._module.attributes.hoverinfo.flags:p.split(\"+\")),x.label=l.label,w(\"label\")&&x.label&&_.push(x.label),l.hasOwnProperty(\"v\")&&(x.value=l.v,x.valueLabel=g(x.value,d),w(\"value\")&&_.push(x.valueLabel)),x.text=h(\"hovertext\")||h(\"text\"),w(\"text\")){var k=x.text;c.isValidTextValue(k)&&_.push(k)}o.loneHover({trace:a,x0:m-v*t.rpx1,x1:m+v*t.rpx1,y:y,idealAlign:t.pxmid[0]<0?\"left\":\"right\",text:_.join(\"<br>\"),name:f||w(\"name\")?a.name:void 0,color:h(\"hoverlabel.bgcolor\")||l.color,borderColor:h(\"hoverlabel.bordercolor\"),fontFamily:h(\"hoverlabel.font.family\"),fontSize:h(\"hoverlabel.font.size\"),fontColor:h(\"hoverlabel.font.color\"),nameLength:h(\"hoverlabel.namelength\"),textAlign:h(\"hoverlabel.align\"),hovertemplate:f,hovertemplateLabels:x,eventData:[M(t,a)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e}),s._hasHoverLabel=!0}s._hasHoverEvent=!0,e.emit(\"plotly_hover\",{points:[M(t,a)],event:n.event})}}),t.on(\"mouseout\",function(t){var r=e._fullLayout,i=e._fullData[s.index],a=n.select(this).datum();s._hasHoverEvent&&(t.originalEvent=n.event,e.emit(\"plotly_unhover\",{points:[M(a,i)],event:n.event}),s._hasHoverEvent=!1),s._hasHoverLabel&&(o.loneUnhover(r._hoverlayer.node()),s._hasHoverLabel=!1)}),t.on(\"click\",function(t){var r=e._fullLayout,l=e._fullData[s.index];if(!1===u.triggerHandler(e,\"plotly_sunburstclick\",{points:[M(t,l)],event:n.event})||w(t)||b(t))r.hovermode&&(e._hoverdata=[M(t,l)],o.click(e,n.event));else if(!e._dragging&&!e._transitioning){a.call(\"_storeDirectGUIEdit\",l,r._tracePreGUI[l.uid],{level:l.level});var c=i.hierarchy,h=k(t),f=_(t)?function(t,e){var r;return t.eachAfter(function(t){for(var n=t.children||[],i=0;i<n.length;i++)if(k(n[i])===e)return r=t.copy()}),r||t}(c,h):x(c,h),p={data:[{level:k(f)}],traces:[s.index]},d={frame:{redraw:!1,duration:m.CLICK_TRANSITION_TIME},transition:{duration:m.CLICK_TRANSITION_TIME,easing:m.CLICK_TRANSITION_EASING},mode:\"immediate\",fromcurrent:!0};o.loneUnhover(r._hoverlayer.node()),a.call(\"animate\",e,p,d)}})}function M(t,e){var r=t.data.data,n={curveNumber:e.index,pointNumber:r.i,data:e._input,fullData:e};return p(n,e,r.i),n}e.exports=function(t,e,r,i){var a,o,s=t._fullLayout._sunburstlayer,l=!r,c=r&&r.duration>0;((a=s.selectAll(\"g.trace.sunburst\").data(e,function(t){return t[0].trace.uid})).enter().append(\"g\").classed(\"trace\",!0).classed(\"sunburst\",!0).attr(\"stroke-linejoin\",\"round\"),a.order(),c)?(i&&(o=i()),n.transition().duration(r.duration).ease(r.easing).each(\"end\",function(){o&&o()}).each(\"interrupt\",function(){o&&o()}).each(function(){s.selectAll(\"g.trace\").each(function(e){y(t,e,this,r)})})):a.each(function(e){y(t,e,this,r)});l&&a.exit().remove()}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../components/fx/helpers\":628,\"../../lib\":719,\"../../lib/events\":709,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../registry\":847,\"../pie/helpers\":1091,\"../pie/plot\":1095,\"./constants\":1217,\"./style\":1223,d3:163,\"d3-hierarchy\":157}],1223:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../lib\");function o(t,e,r){var n=e.data.data,o=!e.children,s=n.i,l=a.castOption(r,s,\"marker.line.color\")||i.defaultLine,c=a.castOption(r,s,\"marker.line.width\")||0;t.style(\"stroke-width\",c).call(i.fill,n.color).call(i.stroke,l).style(\"opacity\",o?r.leaf.opacity:null)}e.exports={style:function(t){t._fullLayout._sunburstlayer.selectAll(\".trace\").each(function(t){var e=n.select(this),r=t[0].trace;e.style(\"opacity\",r.opacity),e.selectAll(\"path.surface\").each(function(t){n.select(this).call(o,t,r)})})},styleOne:o}},{\"../../components/color\":593,\"../../lib\":719,d3:163}],1224:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;function c(t){return{show:{valType:\"boolean\",dflt:!1},start:{valType:\"number\",dflt:null,editType:\"plot\"},end:{valType:\"number\",dflt:null,editType:\"plot\"},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\"},project:{x:{valType:\"boolean\",dflt:!1},y:{valType:\"boolean\",dflt:!1},z:{valType:\"boolean\",dflt:!1}},color:{valType:\"color\",dflt:n.defaultLine},usecolormap:{valType:\"boolean\",dflt:!1},width:{valType:\"number\",min:1,max:16,dflt:2},highlight:{valType:\"boolean\",dflt:!0},highlightcolor:{valType:\"color\",dflt:n.defaultLine},highlightwidth:{valType:\"number\",min:1,max:16,dflt:2}}}var u=e.exports=l(s({z:{valType:\"data_array\"},x:{valType:\"data_array\"},y:{valType:\"data_array\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:a(),connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},surfacecolor:{valType:\"data_array\"}},i(\"\",{colorAttr:\"z or surfacecolor\",showScaleDflt:!0,autoColorDflt:!1,editTypeOverride:\"calc\"}),{contours:{x:c(),y:c(),z:c()},hidesurface:{valType:\"boolean\",dflt:!1},lightposition:{x:{valType:\"number\",min:-1e5,max:1e5,dflt:10},y:{valType:\"number\",min:-1e5,max:1e5,dflt:1e4},z:{valType:\"number\",min:-1e5,max:1e5,dflt:0}},lighting:{ambient:{valType:\"number\",min:0,max:1,dflt:.8},diffuse:{valType:\"number\",min:0,max:1,dflt:.8},specular:{valType:\"number\",min:0,max:2,dflt:.05},roughness:{valType:\"number\",min:0,max:1,dflt:.5},fresnel:{valType:\"number\",min:0,max:5,dflt:.2}},opacity:{valType:\"number\",min:0,max:1,dflt:1},_deprecated:{zauto:s({},i.zauto,{}),zmin:s({},i.zmin,{}),zmax:s({},i.zmax,{})},hoverinfo:s({},o.hoverinfo)}),\"calc\",\"nested\");u.x.editType=u.y.editType=u.z.editType=\"calc+clearAxisTypes\",u.transforms=void 0},{\"../../components/color\":593,\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764}],1225:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.surfacecolor?n(t,e,{vals:e.surfacecolor,containerStr:\"\",cLetter:\"c\"}):n(t,e,{vals:e.z,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],1226:[function(t,e,r){\"use strict\";var n=t(\"gl-surface3d\"),i=t(\"ndarray\"),a=t(\"ndarray-homography\"),o=t(\"ndarray-fill\"),s=t(\"../../lib\").isArrayOrTypedArray,l=t(\"../../lib/gl_format_color\").parseColorScale,c=t(\"../../lib/str2rgbarray\"),u=t(\"../../components/colorscale\").extractOpts,h=t(\"../heatmap/interp2d\"),f=t(\"../heatmap/find_empties\");function p(t,e,r){this.scene=t,this.uid=r,this.surface=e,this.data=null,this.showContour=[!1,!1,!1],this.contourStart=[null,null,null],this.contourEnd=[null,null,null],this.contourSize=[0,0,0],this.minValues=[1/0,1/0,1/0],this.maxValues=[-1/0,-1/0,-1/0],this.dataScaleX=1,this.dataScaleY=1,this.refineData=!0,this.objectOffset=[0,0,0]}var d=p.prototype;d.getXat=function(t,e,r,n){var i=s(this.data.x)?s(this.data.x[0])?this.data.x[e][t]:this.data.x[t]:t;return void 0===r?i:n.d2l(i,0,r)},d.getYat=function(t,e,r,n){var i=s(this.data.y)?s(this.data.y[0])?this.data.y[e][t]:this.data.y[e]:e;return void 0===r?i:n.d2l(i,0,r)},d.getZat=function(t,e,r,n){var i=this.data.z[e][t];return null===i&&this.data.connectgaps&&this.data._interpolatedZ&&(i=this.data._interpolatedZ[e][t]),void 0===r?i:n.d2l(i,0,r)},d.handlePick=function(t){if(t.object===this.surface){var e=(t.data.index[0]-1)/this.dataScaleX-1,r=(t.data.index[1]-1)/this.dataScaleY-1,n=Math.max(Math.min(Math.round(e),this.data.z[0].length-1),0),i=Math.max(Math.min(Math.round(r),this.data._ylength-1),0);t.index=[n,i],t.traceCoordinate=[this.getXat(n,i),this.getYat(n,i),this.getZat(n,i)],t.dataCoordinate=[this.getXat(n,i,this.data.xcalendar,this.scene.fullSceneLayout.xaxis),this.getYat(n,i,this.data.ycalendar,this.scene.fullSceneLayout.yaxis),this.getZat(n,i,this.data.zcalendar,this.scene.fullSceneLayout.zaxis)];for(var a=0;a<3;a++){var o=t.dataCoordinate[a];null!=o&&(t.dataCoordinate[a]*=this.scene.dataScale[a])}var s=this.data.hovertext||this.data.text;return Array.isArray(s)&&s[i]&&void 0!==s[i][n]?t.textLabel=s[i][n]:t.textLabel=s||\"\",t.data.dataCoordinate=t.dataCoordinate.slice(),this.surface.highlight(t.data),this.scene.glplot.spikes.position=t.dataCoordinate,!0}};var g=[2,3,5,7,11,13,17,19,23,29,31,37,41,43,47,53,59,61,67,71,73,79,83,89,97,101,103,107,109,113,127,131,137,139,149,151,157,163,167,173,179,181,191,193,197,199,211,223,227,229,233,239,241,251,257,263,269,271,277,281,283,293,307,311,313,317,331,337,347,349,353,359,367,373,379,383,389,397,401,409,419,421,431,433,439,443,449,457,461,463,467,479,487,491,499,503,509,521,523,541,547,557,563,569,571,577,587,593,599,601,607,613,617,619,631,641,643,647,653,659,661,673,677,683,691,701,709,719,727,733,739,743,751,757,761,769,773,787,797,809,811,821,823,827,829,839,853,857,859,863,877,881,883,887,907,911,919,929,937,941,947,953,967,971,977,983,991,997,1009,1013,1019,1021,1031,1033,1039,1049,1051,1061,1063,1069,1087,1091,1093,1097,1103,1109,1117,1123,1129,1151,1153,1163,1171,1181,1187,1193,1201,1213,1217,1223,1229,1231,1237,1249,1259,1277,1279,1283,1289,1291,1297,1301,1303,1307,1319,1321,1327,1361,1367,1373,1381,1399,1409,1423,1427,1429,1433,1439,1447,1451,1453,1459,1471,1481,1483,1487,1489,1493,1499,1511,1523,1531,1543,1549,1553,1559,1567,1571,1579,1583,1597,1601,1607,1609,1613,1619,1621,1627,1637,1657,1663,1667,1669,1693,1697,1699,1709,1721,1723,1733,1741,1747,1753,1759,1777,1783,1787,1789,1801,1811,1823,1831,1847,1861,1867,1871,1873,1877,1879,1889,1901,1907,1913,1931,1933,1949,1951,1973,1979,1987,1993,1997,1999,2003,2011,2017,2027,2029,2039,2053,2063,2069,2081,2083,2087,2089,2099,2111,2113,2129,2131,2137,2141,2143,2153,2161,2179,2203,2207,2213,2221,2237,2239,2243,2251,2267,2269,2273,2281,2287,2293,2297,2309,2311,2333,2339,2341,2347,2351,2357,2371,2377,2381,2383,2389,2393,2399,2411,2417,2423,2437,2441,2447,2459,2467,2473,2477,2503,2521,2531,2539,2543,2549,2551,2557,2579,2591,2593,2609,2617,2621,2633,2647,2657,2659,2663,2671,2677,2683,2687,2689,2693,2699,2707,2711,2713,2719,2729,2731,2741,2749,2753,2767,2777,2789,2791,2797,2801,2803,2819,2833,2837,2843,2851,2857,2861,2879,2887,2897,2903,2909,2917,2927,2939,2953,2957,2963,2969,2971,2999];function v(t,e){if(t<e)return 0;for(var r=0;0===Math.floor(t%e);)t/=e,r++;return r}function m(t){for(var e=[],r=0;r<g.length;r++){var n=g[r];e.push(v(t,n))}return e}function y(t){for(var e=m(t),r=t,n=0;n<g.length;n++)if(e[n]>0){r=g[n];break}return r}function x(t,e){if(!(t<1||e<1)){for(var r=m(t),n=m(e),i=1,a=0;a<g.length;a++)i*=Math.pow(g[a],Math.max(r[a],n[a]));return i}}d.calcXnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getXat(e-1,0),i=this.getXat(e,0);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r},d.calcYnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getYat(0,e-1),i=this.getYat(0,e);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r};var b=[1,2,4,6,12,24,36,48,60,120,180,240,360,720,840,1260],_=b[9],w=b[13];function k(t,e){for(var r=!1,n=0;n<t.length;n++)if(e===t[n]){r=!0;break}!1===r&&t.push(e)}d.estimateScale=function(t,e){for(var r=1+function(t){if(0!==t.length){for(var e=1,r=0;r<t.length;r++)e=x(e,t[r]);return e}}(0===e?this.calcXnums(t):this.calcYnums(t));r<_;)r*=2;for(;r>w;)r--,r/=y(r),++r<_&&(r=w);var n=Math.round(r/t);return n>1?n:1},d.refineCoords=function(t){for(var e=this.dataScaleX,r=this.dataScaleY,n=t[0].shape[0],o=t[0].shape[1],s=0|Math.floor(t[0].shape[0]*e+1),l=0|Math.floor(t[0].shape[1]*r+1),c=1+n+1,u=1+o+1,h=i(new Float32Array(c*u),[c,u]),f=0;f<t.length;++f){this.surface.padField(h,t[f]);var p=i(new Float32Array(s*l),[s,l]);a(p,h,[e,0,0,0,r,0,0,0,1]),t[f]=p}},d.setContourLevels=function(){var t,e,r,n=[[],[],[]],i=[!1,!1,!1],a=!1;for(t=0;t<3;++t)if(this.showContour[t]&&(a=!0,this.contourSize[t]>0&&null!==this.contourStart[t]&&null!==this.contourEnd[t]&&this.contourEnd[t]>this.contourStart[t]))for(i[t]=!0,e=this.contourStart[t];e<this.contourEnd[t];e+=this.contourSize[t])r=e*this.scene.dataScale[t],k(n[t],r);if(a){var o=[[],[],[]];for(t=0;t<3;++t)this.showContour[t]&&(o[t]=i[t]?n[t]:this.scene.contourLevels[t]);this.surface.update({levels:o})}},d.update=function(t){var e,r,n,a,s=this.scene,p=s.fullSceneLayout,d=this.surface,g=t.opacity,v=l(t,g),m=s.dataScale,y=t.z[0].length,x=t._ylength,b=s.contourLevels;this.data=t;var _=[];for(e=0;e<3;e++)for(_[e]=[],r=0;r<y;r++)_[e][r]=[];for(r=0;r<y;r++)for(n=0;n<x;n++)_[0][r][n]=this.getXat(r,n,t.xcalendar,p.xaxis),_[1][r][n]=this.getYat(r,n,t.ycalendar,p.yaxis),_[2][r][n]=this.getZat(r,n,t.zcalendar,p.zaxis);if(t.connectgaps)for(t._emptypoints=f(_[2]),h(_[2],t._emptypoints),t._interpolatedZ=[],r=0;r<y;r++)for(t._interpolatedZ[r]=[],n=0;n<x;n++)t._interpolatedZ[r][n]=_[2][r][n];for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null==(a=_[e][r][n])?_[e][r][n]=NaN:a=_[e][r][n]*=m[e];for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null!=(a=_[e][r][n])&&(this.minValues[e]>a&&(this.minValues[e]=a),this.maxValues[e]<a&&(this.maxValues[e]=a));for(e=0;e<3;e++)this.objectOffset[e]=.5*(this.minValues[e]+this.maxValues[e]);for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null!=(a=_[e][r][n])&&(_[e][r][n]-=this.objectOffset[e]);var k=[i(new Float32Array(y*x),[y,x]),i(new Float32Array(y*x),[y,x]),i(new Float32Array(y*x),[y,x])];o(k[0],function(t,e){return _[0][t][e]}),o(k[1],function(t,e){return _[1][t][e]}),o(k[2],function(t,e){return _[2][t][e]}),_=[];var T={colormap:v,levels:[[],[],[]],showContour:[!0,!0,!0],showSurface:!t.hidesurface,contourProject:[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],contourWidth:[1,1,1],contourColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],contourTint:[1,1,1],dynamicColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],dynamicWidth:[1,1,1],dynamicTint:[1,1,1],opacity:t.opacity},A=u(t);if(T.intensityBounds=[A.min,A.max],t.surfacecolor){var M=i(new Float32Array(y*x),[y,x]);o(M,function(e,r){return t.surfacecolor[r][e]}),k.push(M)}else T.intensityBounds[0]*=m[2],T.intensityBounds[1]*=m[2];(w<k[0].shape[0]||w<k[0].shape[1])&&(this.refineData=!1),!0===this.refineData&&(this.dataScaleX=this.estimateScale(k[0].shape[0],0),this.dataScaleY=this.estimateScale(k[0].shape[1],1),1===this.dataScaleX&&1===this.dataScaleY||this.refineCoords(k)),t.surfacecolor&&(T.intensity=k.pop());var S=[!0,!0,!0],E=[\"x\",\"y\",\"z\"];for(e=0;e<3;++e){var C=t.contours[E[e]];S[e]=C.highlight,T.showContour[e]=C.show||C.highlight,T.showContour[e]&&(T.contourProject[e]=[C.project.x,C.project.y,C.project.z],C.show?(this.showContour[e]=!0,T.levels[e]=b[e],d.highlightColor[e]=T.contourColor[e]=c(C.color),C.usecolormap?d.highlightTint[e]=T.contourTint[e]=0:d.highlightTint[e]=T.contourTint[e]=1,T.contourWidth[e]=C.width,this.contourStart[e]=C.start,this.contourEnd[e]=C.end,this.contourSize[e]=C.size):(this.showContour[e]=!1,this.contourStart[e]=null,this.contourEnd[e]=null,this.contourSize[e]=0),C.highlight&&(T.dynamicColor[e]=c(C.highlightcolor),T.dynamicWidth[e]=C.highlightwidth))}(function(t){var e=t[0].rgb,r=t[t.length-1].rgb;return e[0]===r[0]&&e[1]===r[1]&&e[2]===r[2]&&e[3]===r[3]})(v)&&(T.vertexColor=!0),T.objectOffset=this.objectOffset,T.coords=k,d.update(T),d.visible=t.visible,d.enableDynamic=S,d.enableHighlight=S,d.snapToData=!0,\"lighting\"in t&&(d.ambientLight=t.lighting.ambient,d.diffuseLight=t.lighting.diffuse,d.specularLight=t.lighting.specular,d.roughness=t.lighting.roughness,d.fresnel=t.lighting.fresnel),\"lightposition\"in t&&(d.lightPosition=[t.lightposition.x,t.lightposition.y,t.lightposition.z]),g&&g<1&&(d.supportsTransparency=!0)},d.dispose=function(){this.scene.glplot.remove(this.surface),this.surface.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new p(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../heatmap/find_empties\":1007,\"../heatmap/interp2d\":1010,\"gl-surface3d\":316,ndarray:450,\"ndarray-fill\":440,\"ndarray-homography\":442}],1227:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");function s(t,e,r){e in t&&!(r in t)&&(t[r]=t[e])}e.exports=function(t,e,r,l){var c,u;function h(r,n){return i.coerce(t,e,o,r,n)}var f=h(\"x\"),p=h(\"y\"),d=h(\"z\");if(!d||!d.length||f&&f.length<1||p&&p.length<1)e.visible=!1;else{e._xlength=Array.isArray(f)&&i.isArrayOrTypedArray(f[0])?d.length:d[0].length,e._ylength=d.length,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],l),h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"hidesurface\",\"connectgaps\",\"opacity\"].forEach(function(t){h(t)});var g=h(\"surfacecolor\"),v=[\"x\",\"y\",\"z\"];for(c=0;c<3;++c){var m=\"contours.\"+v[c],y=h(m+\".show\"),x=h(m+\".highlight\");if(y||x)for(u=0;u<3;++u)h(m+\".project.\"+v[u]);y&&(h(m+\".color\"),h(m+\".width\"),h(m+\".usecolormap\")),x&&(h(m+\".highlightcolor\"),h(m+\".highlightwidth\")),h(m+\".start\"),h(m+\".end\"),h(m+\".size\")}g||(s(t,\"zmin\",\"cmin\"),s(t,\"zmax\",\"cmax\"),s(t,\"zauto\",\"cauto\")),a(t,e,l,h,{prefix:\"\",cLetter:\"c\"}),e._length=null}}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../../registry\":847,\"./attributes\":1224}],1228:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"surface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"2dMap\",\"noOpacity\"],meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1224,\"./calc\":1225,\"./convert\":1226,\"./defaults\":1227}],1229:[function(t,e,r){\"use strict\";var n=t(\"../../components/annotations/attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../plots/domain\").attributes;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=a({domain:s({name:\"table\",trace:!0}),columnwidth:{valType:\"number\",arrayOk:!0,dflt:null},columnorder:{valType:\"data_array\"},header:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:28},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))},cells:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:20},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))}},\"calc\",\"from-root\")).transforms=void 0},{\"../../components/annotations/attributes\":576,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1230:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"table\",r.plot=function(t){var e=n(t.calcdata,\"table\")[0];e.length&&i(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"table\"),a=e._has&&e._has(\"table\");i&&!a&&n._paperdiv.selectAll(\".table\").remove()}},{\"../../plots/get_data\":802,\"./plot\":1237}],1231:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap;e.exports=function(){return n({})}},{\"../../lib/gup\":717}],1232:[function(t,e,r){\"use strict\";e.exports={cellPad:8,columnExtentOffset:10,columnTitleOffset:28,emptyHeaderHeight:16,latexCheck:/^\\$.*\\$$/,goldenRatio:1.618,lineBreaker:\"<br>\",maxDimensionCount:60,overdrag:45,releaseTransitionDuration:120,releaseTransitionEase:\"cubic-out\",scrollbarCaptureWidth:18,scrollbarHideDelay:1e3,scrollbarHideDuration:1e3,scrollbarOffset:5,scrollbarWidth:8,transitionDuration:100,transitionEase:\"cubic-out\",uplift:5,wrapSpacer:\" \",wrapSplitCharacter:\" \",cn:{table:\"table\",tableControlView:\"table-control-view\",scrollBackground:\"scroll-background\",yColumn:\"y-column\",columnBlock:\"column-block\",scrollAreaClip:\"scroll-area-clip\",scrollAreaClipRect:\"scroll-area-clip-rect\",columnBoundary:\"column-boundary\",columnBoundaryClippath:\"column-boundary-clippath\",columnBoundaryRect:\"column-boundary-rect\",columnCells:\"column-cells\",columnCell:\"column-cell\",cellRect:\"cell-rect\",cellText:\"cell-text\",cellTextHolder:\"cell-text-holder\",scrollbarKit:\"scrollbar-kit\",scrollbar:\"scrollbar\",scrollbarSlider:\"scrollbar-slider\",scrollbarGlyph:\"scrollbar-glyph\",scrollbarCaptureZone:\"scrollbar-capture-zone\"}}},{}],1233:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"fast-isnumeric\");function o(t){if(Array.isArray(t)){for(var e=0,r=0;r<t.length;r++)e=Math.max(e,o(t[r]));return e}return t}function s(t,e){return t+e}function l(t){var e,r=t.slice(),n=1/0,i=0;for(e=0;e<r.length;e++)Array.isArray(r[e])||(r[e]=[r[e]]),n=Math.min(n,r[e].length),i=Math.max(i,r[e].length);if(n!==i)for(e=0;e<r.length;e++){var a=i-r[e].length;a&&(r[e]=r[e].concat(c(a)))}return r}function c(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=\"\";return e}function u(t){return t.calcdata.columns.reduce(function(e,r){return r.xIndex<t.xIndex?e+r.columnWidth:e},0)}function h(t,e){return Object.keys(t).map(function(r){return i({},t[r],{auxiliaryBlocks:e})})}function f(t,e){for(var r,n={},i=0,a=0,o={firstRowIndex:null,lastRowIndex:null,rows:[]},s=0,l=0,c=0;c<t.length;c++)r=t[c],o.rows.push({rowIndex:c,rowHeight:r}),((a+=r)>=e||c===t.length-1)&&(n[i]=o,o.key=l++,o.firstRowIndex=s,o.lastRowIndex=c,o={firstRowIndex:null,lastRowIndex:null,rows:[]},i+=a,s=c+1,a=0);return n}e.exports=function(t,e){var r=l(e.cells.values),p=function(t){return t.slice(e.header.values.length,t.length)},d=l(e.header.values);d.length&&!d[0].length&&(d[0]=[\"\"],d=l(d));var g=d.concat(p(r).map(function(){return c((d[0]||[\"\"]).length)})),v=e.domain,m=Math.floor(t._fullLayout._size.w*(v.x[1]-v.x[0])),y=Math.floor(t._fullLayout._size.h*(v.y[1]-v.y[0])),x=e.header.values.length?g[0].map(function(){return e.header.height}):[n.emptyHeaderHeight],b=r.length?r[0].map(function(){return e.cells.height}):[],_=x.reduce(s,0),w=f(b,y-_+n.uplift),k=h(f(x,_),[]),T=h(w,k),A={},M=e._fullInput.columnorder.concat(p(r.map(function(t,e){return e}))),S=g.map(function(t,r){var n=Array.isArray(e.columnwidth)?e.columnwidth[Math.min(r,e.columnwidth.length-1)]:e.columnwidth;return a(n)?Number(n):1}),E=S.reduce(s,0);S=S.map(function(t){return t/E*m});var C=Math.max(o(e.header.line.width),o(e.cells.line.width)),L={key:e.uid+t._context.staticPlot,translateX:v.x[0]*t._fullLayout._size.w,translateY:t._fullLayout._size.h*(1-v.y[1]),size:t._fullLayout._size,width:m,maxLineWidth:C,height:y,columnOrder:M,groupHeight:y,rowBlocks:T,headerRowBlocks:k,scrollY:0,cells:i({},e.cells,{values:r}),headerCells:i({},e.header,{values:g}),gdColumns:g.map(function(t){return t[0]}),gdColumnsOriginalOrder:g.map(function(t){return t[0]}),prevPages:[0,0],scrollbarState:{scrollbarScrollInProgress:!1},columns:g.map(function(t,e){var r=A[t];return A[t]=(r||0)+1,{key:t+\"__\"+A[t],label:t,specIndex:e,xIndex:M[e],xScale:u,x:void 0,calcdata:void 0,columnWidth:S[e]}})};return L.columns.forEach(function(t){t.calcdata=L,t.x=u(t)}),L}},{\"../../lib/extend\":710,\"./constants\":1232,\"fast-isnumeric\":225}],1234:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat;r.splitToPanels=function(t){var e=[0,0],r=n({},t,{key:\"header\",type:\"header\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!0,values:t.calcdata.headerCells.values[t.specIndex],rowBlocks:t.calcdata.headerRowBlocks,calcdata:n({},t.calcdata,{cells:t.calcdata.headerCells})});return[n({},t,{key:\"cells1\",type:\"cells\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),n({},t,{key:\"cells2\",type:\"cells\",page:1,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),r]},r.splitToCells=function(t){var e=function(t){var e=t.rowBlocks[t.page],r=e?e.rows[0].rowIndex:0,n=e?r+e.rows.length:0;return[r,n]}(t);return(t.values||[]).slice(e[0],e[1]).map(function(r,n){return{keyWithinBlock:n+(\"string\"==typeof r&&r.match(/[<$&> ]/)?\"_keybuster_\"+Math.random():\"\"),key:e[0]+n,column:t,calcdata:t.calcdata,page:t.page,rowBlocks:t.rowBlocks,value:r}})}},{\"../../lib/extend\":710}],1235:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults;e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}a(e,o,s),s(\"columnwidth\"),s(\"header.values\"),s(\"header.format\"),s(\"header.align\"),s(\"header.prefix\"),s(\"header.suffix\"),s(\"header.height\"),s(\"header.line.width\"),s(\"header.line.color\"),s(\"header.fill.color\"),n.coerceFont(s,\"header.font\",n.extendFlat({},o.font)),function(t,e){for(var r=t.columnorder||[],n=t.header.values.length,i=r.slice(0,n),a=i.slice().sort(function(t,e){return t-e}),o=i.map(function(t){return a.indexOf(t)}),s=o.length;s<n;s++)o.push(s);e(\"columnorder\",o)}(e,s),s(\"cells.values\"),s(\"cells.format\"),s(\"cells.align\"),s(\"cells.prefix\"),s(\"cells.suffix\"),s(\"cells.height\"),s(\"cells.line.width\"),s(\"cells.line.color\"),s(\"cells.fill.color\"),n.coerceFont(s,\"cells.font\",n.extendFlat({},o.font)),e._length=null}},{\"../../lib\":719,\"../../plots/domain\":792,\"./attributes\":1229}],1236:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"table\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1229,\"./base_plot\":1230,\"./calc\":1231,\"./defaults\":1235,\"./plot\":1237}],1237:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\"),o=t(\"../../components/drawing\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../lib\").raiseToTop,c=t(\"../../lib\").cancelTransition,u=t(\"./data_preparation_helper\"),h=t(\"./data_split_helpers\"),f=t(\"../../components/color\");function p(t){return Math.ceil(t.calcdata.maxLineWidth/2)}function d(t,e){return\"clip\"+t._fullLayout._uid+\"_scrollAreaBottomClip_\"+e.key}function g(t,e){return\"clip\"+t._fullLayout._uid+\"_columnBoundaryClippath_\"+e.calcdata.key+\"_\"+e.specIndex}function v(t){return[].concat.apply([],t.map(function(t){return t})).map(function(t){return t.__data__})}function m(t,e,r){var o=t.selectAll(\".\"+n.cn.scrollbarKit).data(a.repeat,a.keyFun);o.enter().append(\"g\").classed(n.cn.scrollbarKit,!0).style(\"shape-rendering\",\"geometricPrecision\"),o.each(function(t){var e=t.scrollbarState;e.totalHeight=function(t){var e=t.rowBlocks;return z(e,e.length-1)+(e.length?I(e[e.length-1],1/0):1)}(t),e.scrollableAreaHeight=t.groupHeight-A(t),e.currentlyVisibleHeight=Math.min(e.totalHeight,e.scrollableAreaHeight),e.ratio=e.currentlyVisibleHeight/e.totalHeight,e.barLength=Math.max(e.ratio*e.currentlyVisibleHeight,n.goldenRatio*n.scrollbarWidth),e.barWiggleRoom=e.currentlyVisibleHeight-e.barLength,e.wiggleRoom=Math.max(0,e.totalHeight-e.scrollableAreaHeight),e.topY=0===e.barWiggleRoom?0:t.scrollY/e.wiggleRoom*e.barWiggleRoom,e.bottomY=e.topY+e.barLength,e.dragMultiplier=e.wiggleRoom/e.barWiggleRoom}).attr(\"transform\",function(t){return\"translate(\"+(t.width+n.scrollbarWidth/2+n.scrollbarOffset)+\" \"+A(t)+\")\"});var s=o.selectAll(\".\"+n.cn.scrollbar).data(a.repeat,a.keyFun);s.enter().append(\"g\").classed(n.cn.scrollbar,!0);var l=s.selectAll(\".\"+n.cn.scrollbarSlider).data(a.repeat,a.keyFun);l.enter().append(\"g\").classed(n.cn.scrollbarSlider,!0),l.attr(\"transform\",function(t){return\"translate(0 \"+(t.scrollbarState.topY||0)+\")\"});var c=l.selectAll(\".\"+n.cn.scrollbarGlyph).data(a.repeat,a.keyFun);c.enter().append(\"line\").classed(n.cn.scrollbarGlyph,!0).attr(\"stroke\",\"black\").attr(\"stroke-width\",n.scrollbarWidth).attr(\"stroke-linecap\",\"round\").attr(\"y1\",n.scrollbarWidth/2),c.attr(\"y2\",function(t){return t.scrollbarState.barLength-n.scrollbarWidth/2}).attr(\"stroke-opacity\",function(t){return t.columnDragInProgress||!t.scrollbarState.barWiggleRoom||r?0:.4}),c.transition().delay(0).duration(0),c.transition().delay(n.scrollbarHideDelay).duration(n.scrollbarHideDuration).attr(\"stroke-opacity\",0);var u=s.selectAll(\".\"+n.cn.scrollbarCaptureZone).data(a.repeat,a.keyFun);u.enter().append(\"line\").classed(n.cn.scrollbarCaptureZone,!0).attr(\"stroke\",\"white\").attr(\"stroke-opacity\",.01).attr(\"stroke-width\",n.scrollbarCaptureWidth).attr(\"stroke-linecap\",\"butt\").attr(\"y1\",0).on(\"mousedown\",function(r){var n=i.event.y,a=this.getBoundingClientRect(),o=r.scrollbarState,s=n-a.top,l=i.scale.linear().domain([0,o.scrollableAreaHeight]).range([0,o.totalHeight]).clamp(!0);o.topY<=s&&s<=o.bottomY||S(e,t,null,l(s-o.barLength/2))(r)}).call(i.behavior.drag().origin(function(t){return i.event.stopPropagation(),t.scrollbarState.scrollbarScrollInProgress=!0,t}).on(\"drag\",S(e,t)).on(\"dragend\",function(){})),u.attr(\"y2\",function(t){return t.scrollbarState.scrollableAreaHeight}),e._context.staticPlot&&(c.remove(),u.remove())}function y(t,e,r,s){var l=function(t){var e=t.selectAll(\".\"+n.cn.columnCell).data(h.splitToCells,function(t){return t.keyWithinBlock});return e.enter().append(\"g\").classed(n.cn.columnCell,!0),e.exit().remove(),e}(function(t){var e=t.selectAll(\".\"+n.cn.columnCells).data(a.repeat,a.keyFun);return e.enter().append(\"g\").classed(n.cn.columnCells,!0),e.exit().remove(),e}(r));!function(t){t.each(function(t,e){var r=t.calcdata.cells.font,n=t.column.specIndex,i={size:_(r.size,n,e),color:_(r.color,n,e),family:_(r.family,n,e)};t.rowNumber=t.key,t.align=_(t.calcdata.cells.align,n,e),t.cellBorderWidth=_(t.calcdata.cells.line.width,n,e),t.font=i})}(l),function(t){t.attr(\"width\",function(t){return t.column.columnWidth}).attr(\"stroke-width\",function(t){return t.cellBorderWidth}).each(function(t){var e=i.select(this);f.stroke(e,_(t.calcdata.cells.line.color,t.column.specIndex,t.rowNumber)),f.fill(e,_(t.calcdata.cells.fill.color,t.column.specIndex,t.rowNumber))})}(function(t){var e=t.selectAll(\".\"+n.cn.cellRect).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"rect\").classed(n.cn.cellRect,!0),e}(l));var c=function(t){var e=t.selectAll(\".\"+n.cn.cellText).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"text\").classed(n.cn.cellText,!0).style(\"cursor\",function(){return\"auto\"}).on(\"mousedown\",function(){i.event.stopPropagation()}),e}(function(t){var e=t.selectAll(\".\"+n.cn.cellTextHolder).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"g\").classed(n.cn.cellTextHolder,!0).style(\"shape-rendering\",\"geometricPrecision\"),e}(l));!function(t){t.each(function(t){o.font(i.select(this),t.font)})}(c),x(c,e,s,t),O(l)}function x(t,e,r,a){t.text(function(t){var e=t.column.specIndex,r=t.rowNumber,a=t.value,o=\"string\"==typeof a,s=o&&a.match(/<br>/i),l=!o||s;t.mayHaveMarkup=o&&a.match(/[<&>]/);var c,u=\"string\"==typeof(c=a)&&c.match(n.latexCheck);t.latex=u;var h,f,p=u?\"\":_(t.calcdata.cells.prefix,e,r)||\"\",d=u?\"\":_(t.calcdata.cells.suffix,e,r)||\"\",g=u?null:_(t.calcdata.cells.format,e,r)||null,v=p+(g?i.format(g)(t.value):t.value)+d;if(t.wrappingNeeded=!t.wrapped&&!l&&!u&&(h=b(v)),t.cellHeightMayIncrease=s||u||t.mayHaveMarkup||(void 0===h?b(v):h),t.needsConvertToTspans=t.mayHaveMarkup||t.wrappingNeeded||t.latex,t.wrappingNeeded){var m=(\" \"===n.wrapSplitCharacter?v.replace(/<a href=/gi,\"<a_href=\"):v).split(n.wrapSplitCharacter),y=\" \"===n.wrapSplitCharacter?m.map(function(t){return t.replace(/<a_href=/gi,\"<a href=\")}):m;t.fragments=y.map(function(t){return{text:t,width:null}}),t.fragments.push({fragment:n.wrapSpacer,width:null}),f=y.join(n.lineBreaker)+n.lineBreaker+n.wrapSpacer}else delete t.fragments,f=v;return f}).attr(\"dy\",function(t){return t.needsConvertToTspans?0:\"0.75em\"}).each(function(t){var o=i.select(this),l=t.wrappingNeeded?C:L;t.needsConvertToTspans?s.convertToTspans(o,a,l(r,this,e,a,t)):i.select(this.parentNode).attr(\"transform\",function(t){return\"translate(\"+P(t)+\" \"+n.cellPad+\")\"}).attr(\"text-anchor\",function(t){return{left:\"start\",center:\"middle\",right:\"end\"}[t.align]})})}function b(t){return-1!==t.indexOf(n.wrapSplitCharacter)}function _(t,e,r){if(Array.isArray(t)){var n=t[Math.min(e,t.length-1)];return Array.isArray(n)?n[Math.min(r,n.length-1)]:n}return t}function w(t,e,r){t.transition().ease(n.releaseTransitionEase).duration(n.releaseTransitionDuration).attr(\"transform\",\"translate(\"+e.x+\" \"+r+\")\")}function k(t){return\"cells\"===t.type}function T(t){return\"header\"===t.type}function A(t){return(t.rowBlocks.length?t.rowBlocks[0].auxiliaryBlocks:[]).reduce(function(t,e){return t+I(e,1/0)},0)}function M(t,e,r){var n=v(e)[0];if(void 0!==n){var i=n.rowBlocks,a=n.calcdata,o=z(i,i.length),s=n.calcdata.groupHeight-A(n),l=a.scrollY=Math.max(0,Math.min(o-s,a.scrollY)),c=function(t,e,r){for(var n=[],i=0,a=0;a<t.length;a++){for(var o=t[a],s=o.rows,l=0,c=0;c<s.length;c++)l+=s[c].rowHeight;o.allRowsHeight=l,e<i+l&&e+r>i&&n.push(a),i+=l}return n}(i,l,s);1===c.length&&(c[0]===i.length-1?c.unshift(c[0]-1):c.push(c[0]+1)),c[0]%2&&c.reverse(),e.each(function(t,e){t.page=c[e],t.scrollY=l}),e.attr(\"transform\",function(t){return\"translate(0 \"+(z(t.rowBlocks,t.page)-t.scrollY)+\")\"}),t&&(E(t,r,e,c,n.prevPages,n,0),E(t,r,e,c,n.prevPages,n,1),m(r,t))}}function S(t,e,r,a){return function(o){var s=o.calcdata?o.calcdata:o,l=e.filter(function(t){return s.key===t.key}),c=r||s.scrollbarState.dragMultiplier,u=s.scrollY;s.scrollY=void 0===a?s.scrollY+c*i.event.dy:a;var h=l.selectAll(\".\"+n.cn.yColumn).selectAll(\".\"+n.cn.columnBlock).filter(k);return M(t,h,l),s.scrollY===u}}function E(t,e,r,n,i,a,o){n[o]!==i[o]&&(clearTimeout(a.currentRepaint[o]),a.currentRepaint[o]=setTimeout(function(){var a=r.filter(function(t,e){return e===o&&n[e]!==i[e]});y(t,e,a,r),i[o]=n[o]}))}function C(t,e,r,a){return function(){var o=i.select(e.parentNode);o.each(function(t){var e=t.fragments;o.selectAll(\"tspan.line\").each(function(t,r){e[r].width=this.getComputedTextLength()});var r,i,a=e[e.length-1].width,s=e.slice(0,-1),l=[],c=0,u=t.column.columnWidth-2*n.cellPad;for(t.value=\"\";s.length;)c+(i=(r=s.shift()).width+a)>u&&(t.value+=l.join(n.wrapSpacer)+n.lineBreaker,l=[],c=0),l.push(r.text),c+=i;c&&(t.value+=l.join(n.wrapSpacer)),t.wrapped=!0}),o.selectAll(\"tspan.line\").remove(),x(o.select(\".\"+n.cn.cellText),r,t,a),i.select(e.parentNode.parentNode).call(O)}}function L(t,e,r,a,o){return function(){if(!o.settledY){var s=i.select(e.parentNode),l=R(o),c=o.key-l.firstRowIndex,u=l.rows[c].rowHeight,h=o.cellHeightMayIncrease?e.parentNode.getBoundingClientRect().height+2*n.cellPad:u,f=Math.max(h,u);f-l.rows[c].rowHeight&&(l.rows[c].rowHeight=f,t.selectAll(\".\"+n.cn.columnCell).call(O),M(null,t.filter(k),0),m(r,a,!0)),s.attr(\"transform\",function(){var t=this.parentNode.getBoundingClientRect(),e=i.select(this.parentNode).select(\".\"+n.cn.cellRect).node().getBoundingClientRect(),r=this.transform.baseVal.consolidate(),a=e.top-t.top+(r?r.matrix.f:n.cellPad);return\"translate(\"+P(o,i.select(this.parentNode).select(\".\"+n.cn.cellTextHolder).node().getBoundingClientRect().width)+\" \"+a+\")\"}),o.settledY=!0}}}function P(t,e){switch(t.align){case\"left\":return n.cellPad;case\"right\":return t.column.columnWidth-(e||0)-n.cellPad;case\"center\":return(t.column.columnWidth-(e||0))/2;default:return n.cellPad}}function O(t){t.attr(\"transform\",function(t){var e=t.rowBlocks[0].auxiliaryBlocks.reduce(function(t,e){return t+I(e,1/0)},0);return\"translate(0 \"+(I(R(t),t.key)+e)+\")\"}).selectAll(\".\"+n.cn.cellRect).attr(\"height\",function(t){return(e=R(t),r=t.key,e.rows[r-e.firstRowIndex]).rowHeight;var e,r})}function z(t,e){for(var r=0,n=e-1;n>=0;n--)r+=D(t[n]);return r}function I(t,e){for(var r=0,n=0;n<t.rows.length&&t.rows[n].rowIndex<e;n++)r+=t.rows[n].rowHeight;return r}function D(t){var e=t.allRowsHeight;if(void 0!==e)return e;for(var r=0,n=0;n<t.rows.length;n++)r+=t.rows[n].rowHeight;return t.allRowsHeight=r,r}function R(t){return t.rowBlocks[t.page]}e.exports=function(t,e){var r=!t._context.staticPlot,s=t._fullLayout._paper.selectAll(\".\"+n.cn.table).data(e.map(function(e){var r=a.unwrap(e).trace;return u(t,r)}),a.keyFun);s.exit().remove(),s.enter().append(\"g\").classed(n.cn.table,!0).attr(\"overflow\",\"visible\").style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"overflow\",\"visible\").style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"all\"),s.attr(\"width\",function(t){return t.width+t.size.l+t.size.r}).attr(\"height\",function(t){return t.height+t.size.t+t.size.b}).attr(\"transform\",function(t){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"});var f=s.selectAll(\".\"+n.cn.tableControlView).data(a.repeat,a.keyFun),x=f.enter().append(\"g\").classed(n.cn.tableControlView,!0).style(\"box-sizing\",\"content-box\");r&&x.on(\"mousemove\",function(e){f.filter(function(t){return e===t}).call(m,t)}).on(\"mousewheel\",function(e){if(!e.scrollbarState.wheeling){e.scrollbarState.wheeling=!0;var r=e.scrollY+i.event.deltaY;S(t,f,null,r)(e)||(i.event.stopPropagation(),i.event.preventDefault()),e.scrollbarState.wheeling=!1}}).call(m,t,!0),f.attr(\"transform\",function(t){return\"translate(\"+t.size.l+\" \"+t.size.t+\")\"});var b=f.selectAll(\".\"+n.cn.scrollBackground).data(a.repeat,a.keyFun);b.enter().append(\"rect\").classed(n.cn.scrollBackground,!0).attr(\"fill\",\"none\"),b.attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}),f.each(function(e){o.setClipUrl(i.select(this),d(t,e),t)});var _=f.selectAll(\".\"+n.cn.yColumn).data(function(t){return t.columns},a.keyFun);_.enter().append(\"g\").classed(n.cn.yColumn,!0),_.exit().remove(),_.attr(\"transform\",function(t){return\"translate(\"+t.x+\" 0)\"}),r&&_.call(i.behavior.drag().origin(function(e){return w(i.select(this),e,-n.uplift),l(this),e.calcdata.columnDragInProgress=!0,m(f.filter(function(t){return e.calcdata.key===t.key}),t),e}).on(\"drag\",function(t){var e=i.select(this),r=function(e){return(t===e?i.event.x:e.x)+e.columnWidth/2};t.x=Math.max(-n.overdrag,Math.min(t.calcdata.width+n.overdrag-t.columnWidth,i.event.x)),v(_).filter(function(e){return e.calcdata.key===t.calcdata.key}).sort(function(t,e){return r(t)-r(e)}).forEach(function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e)}),_.filter(function(e){return t!==e}).transition().ease(n.transitionEase).duration(n.transitionDuration).attr(\"transform\",function(t){return\"translate(\"+t.x+\" 0)\"}),e.call(c).attr(\"transform\",\"translate(\"+t.x+\" -\"+n.uplift+\" )\")}).on(\"dragend\",function(e){var r=i.select(this),n=e.calcdata;e.x=e.xScale(e),e.calcdata.columnDragInProgress=!1,w(r,e,0),function(t,e,r){var n=e.gdColumnsOriginalOrder;e.gdColumns.sort(function(t,e){return r[n.indexOf(t)]-r[n.indexOf(e)]}),e.columnorder=r,t.emit(\"plotly_restyle\")}(t,n,n.columns.map(function(t){return t.xIndex}))})),_.each(function(e){o.setClipUrl(i.select(this),g(t,e),t)});var A=_.selectAll(\".\"+n.cn.columnBlock).data(h.splitToPanels,a.keyFun);A.enter().append(\"g\").classed(n.cn.columnBlock,!0).attr(\"id\",function(t){return t.key}),A.style(\"cursor\",function(t){return t.dragHandle?\"ew-resize\":t.calcdata.scrollbarState.barWiggleRoom?\"ns-resize\":\"default\"});var E=A.filter(T),C=A.filter(k);r&&C.call(i.behavior.drag().origin(function(t){return i.event.stopPropagation(),t}).on(\"drag\",S(t,f,-1)).on(\"dragend\",function(){})),y(t,f,E,A),y(t,f,C,A);var L=f.selectAll(\".\"+n.cn.scrollAreaClip).data(a.repeat,a.keyFun);L.enter().append(\"clipPath\").classed(n.cn.scrollAreaClip,!0).attr(\"id\",function(e){return d(t,e)});var P=L.selectAll(\".\"+n.cn.scrollAreaClipRect).data(a.repeat,a.keyFun);P.enter().append(\"rect\").classed(n.cn.scrollAreaClipRect,!0).attr(\"x\",-n.overdrag).attr(\"y\",-n.uplift).attr(\"fill\",\"none\"),P.attr(\"width\",function(t){return t.width+2*n.overdrag}).attr(\"height\",function(t){return t.height+n.uplift}),_.selectAll(\".\"+n.cn.columnBoundary).data(a.repeat,a.keyFun).enter().append(\"g\").classed(n.cn.columnBoundary,!0);var O=_.selectAll(\".\"+n.cn.columnBoundaryClippath).data(a.repeat,a.keyFun);O.enter().append(\"clipPath\").classed(n.cn.columnBoundaryClippath,!0),O.attr(\"id\",function(e){return g(t,e)});var z=O.selectAll(\".\"+n.cn.columnBoundaryRect).data(a.repeat,a.keyFun);z.enter().append(\"rect\").classed(n.cn.columnBoundaryRect,!0).attr(\"fill\",\"none\"),z.attr(\"width\",function(t){return t.columnWidth+2*p(t)}).attr(\"height\",function(t){return t.calcdata.height+2*p(t)+n.uplift}).attr(\"x\",function(t){return-p(t)}).attr(\"y\",function(t){return-p(t)}),M(null,C,f)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/gup\":717,\"../../lib/svg_text_utils\":743,\"./constants\":1232,\"./data_preparation_helper\":1233,\"./data_split_helpers\":1234,d3:163}],1238:[function(t,e,r){\"use strict\";var n=t(\"../box/attributes\"),i=t(\"../../lib/extend\").extendFlat;e.exports={y:n.y,x:n.x,x0:n.x0,y0:n.y0,name:i({},n.name,{}),orientation:i({},n.orientation,{}),bandwidth:{valType:\"number\",min:0,editType:\"calc\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},scalemode:{valType:\"enumerated\",values:[\"width\",\"count\"],dflt:\"width\",editType:\"calc\"},spanmode:{valType:\"enumerated\",values:[\"soft\",\"hard\",\"manual\"],dflt:\"soft\",editType:\"calc\"},span:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}],editType:\"calc\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,points:i({},n.boxpoints,{}),jitter:i({},n.jitter,{}),pointpos:i({},n.pointpos,{}),width:i({},n.width,{}),marker:n.marker,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,box:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},width:{valType:\"number\",min:0,max:1,dflt:.25,editType:\"plot\"},fillcolor:{valType:\"color\",editType:\"style\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},editType:\"plot\"},meanline:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"plot\"},side:{valType:\"enumerated\",values:[\"both\",\"positive\",\"negative\"],dflt:\"both\",editType:\"calc\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,hoveron:{valType:\"flaglist\",flags:[\"violins\",\"points\",\"kde\"],dflt:\"violins+points+kde\",extras:[\"all\"],editType:\"style\"}}},{\"../../lib/extend\":710,\"../box/attributes\":880}],1239:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/calc\"),o=t(\"./helpers\"),s=t(\"../../constants/numerical\").BADNUM;function l(t,e,r){var i=e.max-e.min;if(!i)return t.bandwidth?t.bandwidth:0;if(t.bandwidth)return Math.max(t.bandwidth,i/1e4);var a=r.length,o=n.stdev(r,a-1,e.mean);return Math.max(function(t,e,r){return 1.059*Math.min(e,r/1.349)*Math.pow(t,-.2)}(a,o,e.q3-e.q1),i/100)}function c(t,e,r,n){var a,o=t.spanmode,l=t.span||[],c=[e.min,e.max],u=[e.min-2*n,e.max+2*n];function h(n){var i=l[n],a=\"multicategory\"===r.type?r.r2c(i):r.d2c(i,0,t[e.valLetter+\"calendar\"]);return a===s?u[n]:a}var f={type:\"linear\",range:a=\"soft\"===o?u:\"hard\"===o?c:[h(0),h(1)]};return i.setConvert(f),f.cleanRange(),a}e.exports=function(t,e){var r=a(t,e);if(r[0].t.empty)return r;for(var s=t._fullLayout,u=i.getFromId(t,e[\"h\"===e.orientation?\"xaxis\":\"yaxis\"]),h=1/0,f=-1/0,p=0,d=0,g=0;g<r.length;g++){var v=r[g],m=v.pts.map(o.extractVal),y=v.bandwidth=l(e,v,m),x=v.span=c(e,v,u,y);if(v.min===v.max&&0===y)x=v.span=[v.min,v.max],v.density=[{v:1,t:x[0]}],v.bandwidth=y,p=Math.max(p,1);else{var b=x[1]-x[0],_=Math.ceil(b/(y/3)),w=b/_;if(!isFinite(w)||!isFinite(_))return n.error(\"Something went wrong with computing the violin span\"),r[0].t.empty=!0,r;var k=o.makeKDE(v,e,m);v.density=new Array(_);for(var T=0,A=x[0];A<x[1]+w/2;T++,A+=w){var M=k(A);v.density[T]={v:M,t:A},p=Math.max(p,M)}}d=Math.max(d,m.length),h=Math.min(h,x[0]),f=Math.max(f,x[1])}var S=i.findExtremes(u,[h,f],{padded:!0});if(e._extremes[u._id]=S,e.width)r[0].t.maxKDE=p;else{var E=s._violinScaleGroupStats,C=e.scalegroup,L=E[C];L?(L.maxKDE=Math.max(L.maxKDE,p),L.maxCount=Math.max(L.maxCount,d)):E[C]={maxKDE:p,maxCount:d}}return r[0].t.labels.kde=n._(t,\"kde:\"),r}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../box/calc\":881,\"./helpers\":1242}],1240:[function(t,e,r){\"use strict\";var n=t(\"../box/cross_trace_calc\").setPositionOffset,i=[\"v\",\"h\"];e.exports=function(t,e){for(var r=t.calcdata,a=e.xaxis,o=e.yaxis,s=0;s<i.length;s++){for(var l=i[s],c=\"h\"===l?o:a,u=[],h=0;h<r.length;h++){var f=r[h],p=f[0].t,d=f[0].trace;!0!==d.visible||\"violin\"!==d.type||p.empty||d.orientation!==l||d.xaxis!==a._id||d.yaxis!==o._id||u.push(h)}n(\"violin\",t,u,c)}}},{\"../box/cross_trace_calc\":882}],1241:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../box/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}function c(r,i){return n.coerce2(t,e,o,r,i)}if(a.handleSampleDefaults(t,e,l,s),!1!==e.visible){l(\"bandwidth\"),l(\"side\"),l(\"width\")||(l(\"scalegroup\",e.name),l(\"scalemode\"));var u,h=l(\"span\");Array.isArray(h)&&(u=\"manual\"),l(\"spanmode\",u);var f=l(\"line.color\",(t.marker||{}).color||r),p=l(\"line.width\"),d=l(\"fillcolor\",i.addOpacity(e.line.color,.5));a.handlePointsDefaults(t,e,l,{prefix:\"\"});var g=c(\"box.width\"),v=c(\"box.fillcolor\",d),m=c(\"box.line.color\",f),y=c(\"box.line.width\",p);l(\"box.visible\",Boolean(g||v||m||y))||(e.box={visible:!1});var x=c(\"meanline.color\",f),b=c(\"meanline.width\",p);l(\"meanline.visible\",Boolean(x||b))||(e.meanline={visible:!1})}}},{\"../../components/color\":593,\"../../lib\":719,\"../box/defaults\":883,\"./attributes\":1238}],1242:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=function(t){return 1/Math.sqrt(2*Math.PI)*Math.exp(-.5*t*t)};r.makeKDE=function(t,e,r){var n=r.length,a=i,o=t.bandwidth,s=1/(n*o);return function(t){for(var e=0,i=0;i<n;i++)e+=a((t-r[i])/o);return s*e}},r.getPositionOnKdePath=function(t,e,r){var i,a;\"h\"===e.orientation?(i=\"y\",a=\"x\"):(i=\"x\",a=\"y\");var o=n.findPointOnPath(t.path,r,a,{pathLength:t.pathLength}),s=t.posCenterPx,l=o[i];return[l,\"both\"===e.side?2*s-l:s]},r.getKdeValue=function(t,e,n){var i=t.pts.map(r.extractVal);return r.makeKDE(t,e,i)(n)/t.posDensityScale},r.extractVal=function(t){return t.v}},{\"../../lib\":719}],1243:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/hover\"),o=t(\"./helpers\");e.exports=function(t,e,r,s,l){var c,u,h=t.cd,f=h[0].trace,p=f.hoveron,d=-1!==p.indexOf(\"violins\"),g=-1!==p.indexOf(\"kde\"),v=[];if(d||g){var m=a.hoverOnBoxes(t,e,r,s);if(g&&m.length>0){var y,x,b,_,w,k=t.xa,T=t.ya;\"h\"===f.orientation?(w=e,y=\"y\",b=T,x=\"x\",_=k):(w=r,y=\"x\",b=k,x=\"y\",_=T);var A=h[t.index];if(w>=A.span[0]&&w<=A.span[1]){var M=n.extendFlat({},t),S=_.c2p(w,!0),E=o.getKdeValue(A,f,w),C=o.getPositionOnKdePath(A,f,S),L=b._offset,P=b._length;M[y+\"0\"]=C[0],M[y+\"1\"]=C[1],M[x+\"0\"]=M[x+\"1\"]=S,M[x+\"Label\"]=x+\": \"+i.hoverLabelText(_,w)+\", \"+h[0].t.labels.kde+\" \"+E.toFixed(3),M.spikeDistance=m[0].spikeDistance;var O=y+\"Spike\";M[O]=m[0][O],m[0].spikeDistance=void 0,m[0][O]=void 0,M.hovertemplate=!1,v.push(M),(u={stroke:t.color})[y+\"1\"]=n.constrain(L+C[0],L,L+P),u[y+\"2\"]=n.constrain(L+C[1],L,L+P),u[x+\"1\"]=u[x+\"2\"]=_._offset+S}}d&&(v=v.concat(m))}-1!==p.indexOf(\"points\")&&(c=a.hoverOnPoints(t,e,r));var z=l.selectAll(\".violinline-\"+f.uid).data(u?[0]:[]);return z.enter().append(\"line\").classed(\"violinline-\"+f.uid,!0).attr(\"stroke-width\",1.5),z.exit().remove(),z.attr(u),\"closest\"===s?c?[c]:v:c?(v.push(c),v):v}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../box/hover\":885,\"./helpers\":1242}],1244:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../box/defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../box/select\"),moduleType:\"trace\",name:\"violin\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"violinLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../box/defaults\":883,\"../box/select\":890,\"../scatter/style\":1134,\"./attributes\":1238,\"./calc\":1239,\"./cross_trace_calc\":1240,\"./defaults\":1241,\"./hover\":1243,\"./layout_attributes\":1245,\"./layout_defaults\":1246,\"./plot\":1247,\"./style\":1248}],1245:[function(t,e,r){\"use strict\";var n=t(\"../box/layout_attributes\"),i=t(\"../../lib\").extendFlat;e.exports={violinmode:i({},n.boxmode,{}),violingap:i({},n.boxgap,{}),violingroupgap:i({},n.boxgroupgap,{})}},{\"../../lib\":719,\"../box/layout_attributes\":887}],1246:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"../box/layout_defaults\");e.exports=function(t,e,r){a._supply(t,e,r,function(r,a){return n.coerce(t,e,i,r,a)},\"violin\")}},{\"../../lib\":719,\"../box/layout_defaults\":888,\"./layout_attributes\":1245}],1247:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../box/plot\"),s=t(\"../scatter/line_points\"),l=t(\"./helpers\");e.exports=function(t,e,r,c){var u=t._fullLayout,h=e.xaxis,f=e.yaxis;function p(t){var e=s(t,{xaxis:h,yaxis:f,connectGaps:!0,baseTolerance:.75,shape:\"spline\",simplify:!0});return a.smoothopen(e[0],1)}i.makeTraceGroups(c,r,\"trace violins\").each(function(t){var r=n.select(this),a=t[0],s=a.t,c=a.trace;if(!0!==c.visible||s.empty)r.remove();else{var d=s.bPos,g=s.bdPos,v=e[s.valLetter+\"axis\"],m=e[s.posLetter+\"axis\"],y=\"both\"===c.side,x=y||\"positive\"===c.side,b=y||\"negative\"===c.side,_=r.selectAll(\"path.violin\").data(i.identity);_.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"violin\"),_.exit().remove(),_.each(function(t){var e,r,i,a,o,l,h,f,_=n.select(this),w=t.density,k=w.length,T=t.pos+d,A=m.c2p(T);if(c.width)e=s.maxKDE/g;else{var M=u._violinScaleGroupStats[c.scalegroup];e=\"count\"===c.scalemode?M.maxKDE/g*(M.maxCount/t.pts.length):M.maxKDE/g}if(x){for(h=new Array(k),o=0;o<k;o++)(f=h[o]={})[s.posLetter]=T+w[o].v/e,f[s.valLetter]=w[o].t;r=p(h)}if(b){for(h=new Array(k),l=0,o=k-1;l<k;l++,o--)(f=h[l]={})[s.posLetter]=T-w[o].v/e,f[s.valLetter]=w[o].t;i=p(h)}if(y)a=r+\"L\"+i.substr(1)+\"Z\";else{var S=[A,v.c2p(w[0].t)],E=[A,v.c2p(w[k-1].t)];\"h\"===c.orientation&&(S.reverse(),E.reverse()),a=x?\"M\"+S+\"L\"+r.substr(1)+\"L\"+E:\"M\"+E+\"L\"+i.substr(1)+\"L\"+S}_.attr(\"d\",a),t.posCenterPx=A,t.posDensityScale=e*g,t.path=_.node(),t.pathLength=t.path.getTotalLength()/(y?2:1)});var w,k,T,A=c.box,M=A.width,S=(A.line||{}).width;y?(w=g*M,k=0):x?(w=[0,g*M/2],k=-S):(w=[g*M/2,0],k=S),o.plotBoxAndWhiskers(r,{pos:m,val:v},c,{bPos:d,bdPos:w,bPosPxOffset:k}),o.plotBoxMean(r,{pos:m,val:v},c,{bPos:d,bdPos:w,bPosPxOffset:k}),!c.box.visible&&c.meanline.visible&&(T=i.identity);var E=r.selectAll(\"path.meanline\").data(T||[]);E.enter().append(\"path\").attr(\"class\",\"meanline\").style(\"fill\",\"none\").style(\"vector-effect\",\"non-scaling-stroke\"),E.exit().remove(),E.each(function(t){var e=v.c2p(t.mean,!0),r=l.getPositionOnKdePath(t,c,e);n.select(this).attr(\"d\",\"h\"===c.orientation?\"M\"+e+\",\"+r[0]+\"V\"+r[1]:\"M\"+r[0]+\",\"+e+\"H\"+r[1])}),o.plotPoints(r,{x:h,y:f},c,s)}})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../box/plot\":889,\"../scatter/line_points\":1125,\"./helpers\":1242,d3:163}],1248:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../scatter/style\").stylePoints;e.exports=function(t){var e=n.select(t).selectAll(\"g.trace.violins\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.each(function(e){var r=e[0].trace,o=n.select(this),s=r.box||{},l=s.line||{},c=r.meanline||{},u=c.width;o.selectAll(\"path.violin\").style(\"stroke-width\",r.line.width+\"px\").call(i.stroke,r.line.color).call(i.fill,r.fillcolor),o.selectAll(\"path.box\").style(\"stroke-width\",l.width+\"px\").call(i.stroke,l.color).call(i.fill,s.fillcolor);var h={\"stroke-width\":u+\"px\",\"stroke-dasharray\":2*u+\"px,\"+u+\"px\"};o.selectAll(\"path.mean\").style(h).call(i.stroke,c.color),o.selectAll(\"path.meanline\").style(h).call(i.stroke,c.color),a(o,r,t)})}},{\"../../components/color\":593,\"../scatter/style\":1134,d3:163}],1249:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../isosurface/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=e.exports=s(o({x:i.x,y:i.y,z:i.z,value:i.value,isomin:i.isomin,isomax:i.isomax,surface:i.surface,spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:1}},slices:i.slices,caps:i.caps,text:i.text,hovertext:i.hovertext,hovertemplate:i.hovertemplate},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{colorbar:i.colorbar,opacity:i.opacity,opacityscale:{valType:\"any\",editType:\"calc\"},lightposition:i.lightposition,lighting:i.lighting,flatshading:i.flatshading,contour:i.contour,hoverinfo:o({},a.hoverinfo)}),\"calc\",\"nested\");l.x.editType=l.y.editType=l.z.editType=l.value.editType=\"calc+clearAxisTypes\",l.transforms=void 0},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../isosurface/attributes\":1048}],1250:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib/gl_format_color\").parseColorScale,a=t(\"../../lib/str2rgbarray\"),o=t(\"../../components/colorscale\").extractOpts,s=t(\"../../plots/gl3d/zip3\"),l=t(\"../isosurface/convert\").findNearestOnAxis,c=t(\"../isosurface/convert\").generateIsoMeshes;function u(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var h=u.prototype;h.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._x[e],n=this.data._y[e],i=this.data._z[e],a=this.data._Ys.length,o=this.data._Zs.length,s=l(r,this.data._Xs).id,c=l(n,this.data._Ys).id,u=l(i,this.data._Zs).id,h=t.index=u+o*c+o*a*s;t.traceCoordinate=[this.data._x[h],this.data._y[h],this.data._z[h],this.data.value[h]];var f=this.data.hovertext||this.data.text;return Array.isArray(f)&&void 0!==f[h]?t.textLabel=f[h]:f&&(t.textLabel=f),!0}},h.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map(function(e){return t.d2l(e,0,n)*r})}this.data=c(t);var l={positions:s(n(r.xaxis,t._x,e.dataScale[0],t.xcalendar),n(r.yaxis,t._y,e.dataScale[1],t.ycalendar),n(r.zaxis,t._z,e.dataScale[2],t.zcalendar)),cells:s(t._i,t._j,t._k),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,opacityscale:t.opacityscale,contourEnable:t.contour.show,contourColor:a(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},u=o(t);l.vertexIntensity=t._intensity,l.vertexIntensityBounds=[u.min,u.max],l.colormap=i(t),this.mesh.update(l)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new u(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":605,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../../plots/gl3d/zip3\":818,\"../isosurface/convert\":1050,\"gl-mesh3d\":280}],1251:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../isosurface/defaults\").supplyIsoDefaults;e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}a(t,e,r,o,s);var l=s(\"opacityscale\");\"max\"===l?e.opacityscale=[[0,.1],[1,1]]:\"min\"===l?e.opacityscale=[[0,1],[1,.1]]:\"extremes\"===l?e.opacityscale=function(t,e){for(var r=[],n=0;n<32;n++){var i=n/31,a=e+(1-e)*(1-Math.pow(Math.sin(t*i*Math.PI),2));r.push([i,Math.max(1,Math.min(0,a))])}return r}(1,.1):function(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var n=t[r];if(2!==n.length||+n[0]<e)return!1;e=+n[0]}return!0}(l)||(e.opacityscale=void 0)}},{\"../../lib\":719,\"../isosurface/defaults\":1051,\"./attributes\":1249}],1252:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../isosurface/calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"volume\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],meta:{}}},{\"../../plots/gl3d\":807,\"../isosurface/calc\":1049,\"./attributes\":1249,\"./convert\":1250,\"./defaults\":1251}],1253:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"./constants\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../components/color\");function u(t){return{marker:{color:l({},n.marker.color,{arrayOk:!1,editType:\"style\"}),line:{color:l({},n.marker.line.color,{arrayOk:!1,editType:\"style\"}),width:l({},n.marker.line.width,{arrayOk:!1,editType:\"style\"}),editType:\"style\"},editType:\"style\"},editType:\"style\"}}e.exports={measure:{valType:\"data_array\",dflt:[],editType:\"calc\"},base:{valType:\"number\",dflt:null,arrayOk:!1,editType:\"calc\"},x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,hovertext:n.hovertext,hovertemplate:o({},{keys:s.eventDataKeys}),hoverinfo:l({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"initial\",\"delta\",\"final\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"initial\",\"delta\",\"final\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},text:n.text,textposition:n.textposition,insidetextanchor:n.insidetextanchor,textangle:n.textangle,textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:n.orientation,offset:n.offset,width:n.width,increasing:u(),decreasing:u(),totals:u(),connector:{line:{color:l({},i.color,{dflt:c.defaultLine}),width:l({},i.width,{editType:\"plot\"}),dash:i.dash,editType:\"plot\"},mode:{valType:\"enumerated\",values:[\"spanning\",\"between\"],dflt:\"between\",editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":593,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../bar/attributes\":857,\"../scatter/attributes\":1112,\"./constants\":1255}],1254:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\").mergeArray,a=t(\"../scatter/calc_selection\"),o=t(\"../../constants/numerical\").BADNUM;function s(t){return\"a\"===t||\"absolute\"===t}function l(t){return\"t\"===t||\"total\"===t}e.exports=function(t,e){var r,c,u=n.getFromId(t,e.xaxis||\"x\"),h=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=u.makeCalcdata(e,\"x\"),c=h.makeCalcdata(e,\"y\")):(r=h.makeCalcdata(e,\"y\"),c=u.makeCalcdata(e,\"x\"));for(var f,p=Math.min(c.length,r.length),d=new Array(p),g=0,v=!1,m=0;m<p;m++){var y=r[m]||0,x=!1;(r[m]!==o||l(e.measure[m])||s(e.measure[m]))&&m+1<p&&(r[m+1]!==o||l(e.measure[m+1])||s(e.measure[m+1]))&&(x=!0);var b=d[m]={i:m,p:c[m],s:y,rawS:y,cNext:x};s(e.measure[m])?(g=b.s,b.isSum=!0,b.dir=\"totals\",b.s=g):l(e.measure[m])?(b.isSum=!0,b.dir=\"totals\",b.s=g):(b.isSum=!1,b.dir=b.rawS<0?\"decreasing\":\"increasing\",f=b.s,b.s=g+f,g+=f),\"totals\"===b.dir&&(v=!0),e.ids&&(b.id=String(e.ids[m])),b.v=(e.base||0)+g}return d.length&&(d[0].hasTotals=v),i(e.text,d,\"tx\"),i(e.hovertext,d,\"htx\"),a(d,e),d}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scatter/calc_selection\":1114}],1255:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"initial\",\"delta\",\"final\"]}},{}],1256:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],h=[],f=[];for(i=0;i<o.length;i++){var p=o[i];!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"waterfall\"===p.type&&(r=s[i],\"h\"===p.orientation?f.push(r):h.push(r),u.push(r))}var d={mode:a.waterfallmode,norm:a.waterfallnorm,gap:a.waterfallgap,groupgap:a.waterfallgroupgap};for(n(t,l,c,h,d),n(t,c,l,f,d),i=0;i<u.length;i++){r=u[i];for(var g=0;g<r.length;g++){var v=r[g];!1===v.isSum&&(v.s0+=0===g?0:r[g-1].s),g+1<r.length&&(r[g].nextP0=r[g+1].p0,r[g].nextS0=r[g+1].s0)}}}},{\"../bar/cross_trace_calc\":860}],1257:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"./attributes\"),l=t(\"../../components/color\"),c=t(\"../../constants/delta.js\"),u=c.INCREASING.COLOR,h=c.DECREASING.COLOR,f=\"#4499FF\";function p(t,e,r){t(e+\".marker.color\",r),t(e+\".marker.line.color\",l.defaultLine),t(e+\".marker.line.width\")}e.exports={supplyDefaults:function(t,e,r,i){function l(r,i){return n.coerce(t,e,s,r,i)}if(o(t,e,i,l)){l(\"measure\"),l(\"orientation\",e.x&&!e.y?\"h\":\"v\"),l(\"base\"),l(\"offset\"),l(\"width\"),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\");var c=l(\"textposition\");a(t,e,i,l,c,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"!==e.textposition&&l(\"textinfo\"),p(l,\"increasing\",u),p(l,\"decreasing\",h),p(l,\"totals\",f),l(\"connector.visible\")&&(l(\"connector.mode\"),l(\"connector.line.width\")&&(l(\"connector.line.color\"),l(\"connector.line.dash\")))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,s,t)}if(\"group\"===e.waterfallmode)for(var l=0;l<t.length;l++)r=(a=t[l])._input,i(r,a,e,o)}}},{\"../../components/color\":593,\"../../constants/delta.js\":689,\"../../lib\":719,\"../bar/defaults\":861,\"../scatter/xy_defaults\":1137,\"./attributes\":1253}],1258:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"initial\"in e&&(t.initial=e.initial),\"delta\"in e&&(t.delta=e.delta),\"final\"in e&&(t.final=e.final),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],1259:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\").hoverLabelText,i=t(\"../../components/color\").opacity,a=t(\"../bar/hover\").hoverOnBars,o=t(\"../../constants/delta.js\"),s=o.INCREASING.SYMBOL,l=o.DECREASING.SYMBOL;e.exports=function(t,e,r,o){var c=a(t,e,r,o);if(c){var u=c.cd,h=u[0].trace,f=\"h\"===h.orientation,p=f?t.xa:t.ya,d=u[c.index],g=d.isSum?d.b+d.s:d.rawS;if(!d.isSum){c.initial=d.b+d.s-g,c.delta=g,c.final=c.initial+c.delta;var v=w(Math.abs(c.delta));c.deltaLabel=g<0?\"(\"+v+\")\":v,c.finalLabel=w(c.final),c.initialLabel=w(c.initial)}var m=d.hi||h.hoverinfo,y=[];if(m&&\"none\"!==m&&\"skip\"!==m){var x=\"all\"===m,b=m.split(\"+\"),_=function(t){return x||-1!==b.indexOf(t)};d.isSum||(!_(\"final\")||_(f?\"x\":\"y\")||y.push(c.finalLabel),_(\"delta\")&&(g<0?y.push(c.deltaLabel+\" \"+l):y.push(c.deltaLabel+\" \"+s)),_(\"initial\")&&y.push(\"Initial: \"+c.initialLabel))}return y.length&&(c.extraText=y.join(\"<br>\")),c.color=function(t,e){var r=t[e.dir].marker,n=r.color,a=r.line.color,o=r.line.width;if(i(n))return n;if(i(a)&&o)return a}(h,d),[c]}function w(t){return n(p,t)}}},{\"../../components/color\":593,\"../../constants/delta.js\":689,\"../../plots/cartesian/axes\":767,\"../bar/hover\":863}],1260:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"waterfall\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../bar/select\":868,\"./attributes\":1253,\"./calc\":1254,\"./cross_trace_calc\":1256,\"./defaults\":1257,\"./event_data\":1258,\"./hover\":1259,\"./layout_attributes\":1261,\"./layout_defaults\":1262,\"./plot\":1263,\"./style\":1264}],1261:[function(t,e,r){\"use strict\";e.exports={waterfallmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"group\",editType:\"calc\"},waterfallgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},waterfallgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],1262:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"waterfall\"===l.type){a=!0;break}}a&&(o(\"waterfallmode\"),o(\"waterfallgap\",.2),o(\"waterfallgroupgap\"))}},{\"../../lib\":719,\"./layout_attributes\":1261}],1263:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../bar/plot\").plot;e.exports=function(t,e,r,s){var l=t._fullLayout;o(t,e,r,s,{mode:l.waterfallmode,norm:l.waterfallmode,gap:l.waterfallgap,groupgap:l.waterfallgroupgap}),function(t,e,r,o){var s=e.xaxis,l=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each(function(r){var o=n.select(this),c=r[0].trace,u=i.ensureSingle(o,\"g\",\"lines\");if(c.connector&&c.connector.visible){var h=\"h\"===c.orientation,f=c.connector.mode,p=u.selectAll(\"g.line\").data(i.identity);p.enter().append(\"g\").classed(\"line\",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var c=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),n?[i,a]:[a,i]}(r,s,l,h),u=c[0],p=c[1],g=\"\";\"spanning\"===f&&!r.isSum&&o>0&&(g+=h?\"M\"+u[0]+\",\"+p[1]+\"V\"+p[0]:\"M\"+u[1]+\",\"+p[0]+\"H\"+u[0]),\"between\"!==f&&(r.isSum||o<d-1)&&(g+=h?\"M\"+u[1]+\",\"+p[0]+\"V\"+p[1]:\"M\"+u[0]+\",\"+p[1]+\"H\"+u[1]),void 0!==u[2]&&void 0!==p[2]&&(g+=h?\"M\"+u[1]+\",\"+p[1]+\"V\"+p[2]:\"M\"+u[1]+\",\"+p[1]+\"H\"+u[2]),\"\"===g&&(g=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}})}else u.remove()})}(t,e,r,s)}},{\"../../components/drawing\":614,\"../../lib\":719,\"../bar/plot\":867,d3:163}],1264:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\").styleTextPoints;e.exports={style:function(t,e,r){var l=r||n.select(t).selectAll(\"g.waterfalllayer\").selectAll(\"g.trace\");l.style(\"opacity\",function(t){return t[0].trace.opacity}),l.each(function(e){var r=n.select(this),l=e[0].trace;r.selectAll(\".point > path\").each(function(t){if(!t.isBlank){var e=l[t.dir].marker;n.select(this).call(a.fill,e.color).call(a.stroke,e.line.color).call(i.dashLine,e.line.dash,e.line.width).style(\"opacity\",l.selectedpoints&&!t.selected?o:1)}}),s(r,l,t),r.selectAll(\".lines\").each(function(){var t=l.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)})})}}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../constants/interactions\":694,\"../bar/style\":870,d3:163}],1265:[function(t,e,r){\"use strict\";var n=t(\"../plots/cartesian/axes\"),i=t(\"../lib\"),a=t(\"../plot_api/plot_schema\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/numerical\").BADNUM;r.moduleType=\"transform\",r.name=\"aggregate\";var l=r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},aggregations:{_isLinkedToArray:\"aggregation\",target:{valType:\"string\",editType:\"calc\"},func:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"median\",\"mode\",\"rms\",\"stddev\",\"min\",\"max\",\"first\",\"last\",\"change\",\"range\"],dflt:\"first\",editType:\"calc\"},funcmode:{valType:\"enumerated\",values:[\"sample\",\"population\"],dflt:\"sample\",editType:\"calc\"},enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},c=l.aggregations;function u(t,e,r,a){if(a.enabled){for(var o=a.target,l=i.nestedProperty(e,o),c=l.get(),u=function(t,e){var r=t.func,n=e.d2c,i=e.c2d;switch(r){case\"count\":return h;case\"first\":return f;case\"last\":return p;case\"sum\":return function(t,e){for(var r=0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r+=o)}return i(r)};case\"avg\":return function(t,e){for(var r=0,a=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l,a++)}return a?i(r/a):s};case\"min\":return function(t,e){for(var r=1/0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r=Math.min(r,o))}return r===1/0?s:i(r)};case\"max\":return function(t,e){for(var r=-1/0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r=Math.max(r,o))}return r===-1/0?s:i(r)};case\"range\":return function(t,e){for(var r=1/0,a=-1/0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r=Math.min(r,l),a=Math.max(a,l))}return a===-1/0||r===1/0?s:i(a-r)};case\"change\":return function(t,e){var r=n(t[e[0]]),a=n(t[e[e.length-1]]);return r===s||a===s?s:i(a-r)};case\"median\":return function(t,e){for(var r=[],a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&r.push(o)}if(!r.length)return s;r.sort();var l=(r.length-1)/2;return i((r[Math.floor(l)]+r[Math.ceil(l)])/2)};case\"mode\":return function(t,e){for(var r={},a=0,o=s,l=0;l<e.length;l++){var c=n(t[e[l]]);if(c!==s){var u=r[c]=(r[c]||0)+1;u>a&&(a=u,o=c)}}return a?i(o):s};case\"rms\":return function(t,e){for(var r=0,a=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l*l,a++)}return a?i(Math.sqrt(r/a)):s};case\"stddev\":return function(e,r){var i,a=0,o=0,l=1,c=s;for(i=0;i<r.length&&c===s;i++)c=n(e[r[i]]);if(c===s)return s;for(;i<r.length;i++){var u=n(e[r[i]]);if(u!==s){var h=u-c;a+=h,o+=h*h,l++}}var f=\"sample\"===t.funcmode?l-1:l;return f?Math.sqrt((o-a*a/l)/f):0}}}(a,n.getDataConversions(t,e,o,c)),d=new Array(r.length),g=0;g<r.length;g++)d[g]=u(c,r[g]);l.set(d),\"count\"===a.func&&i.pushUnique(e._arrayAttrs,o)}}function h(t,e){return e.length}function f(t,e){return t[e[0]]}function p(t,e){return t[e[e.length-1]]}r.supplyDefaults=function(t,e){var r,n={};function o(e,r){return i.coerce(t,n,l,e,r)}if(!o(\"enabled\"))return n;var s=a.findArrayAttributes(e),u={};for(r=0;r<s.length;r++)u[s[r]]=1;var h=o(\"groups\");if(!Array.isArray(h)){if(!u[h])return n.enabled=!1,n;u[h]=0}var f,p=t.aggregations||[],d=n.aggregations=new Array(p.length);function g(t,e){return i.coerce(p[r],f,c,t,e)}for(r=0;r<p.length;r++){f={_index:r};var v=g(\"target\"),m=g(\"func\");g(\"enabled\")&&v&&(u[v]||\"count\"===m&&void 0===u[v])?(\"stddev\"===m&&g(\"funcmode\"),u[v]=0,d[r]=f):d[r]={enabled:!1,_index:r}}for(r=0;r<s.length;r++)u[s[r]]&&d.push({target:s[r],func:c.func.dflt,enabled:!0,_index:-1});return n},r.calcTransform=function(t,e,r){if(r.enabled){var n=r.groups,a=i.getTargetArray(e,{target:n});if(a){var s,l,c,h,f={},p={},d=[],g=o(e.transforms,r),v=a.length;for(e._length&&(v=Math.min(v,e._length)),s=0;s<v;s++)void 0===(c=f[l=a[s]])?(f[l]=d.length,h=[s],d.push(h),p[f[l]]=g(s)):(d[c].push(s),p[f[l]]=(p[f[l]]||[]).concat(g(s)));r._indexToPoints=p;var m=r.aggregations;for(s=0;s<m.length;s++)u(t,e,d,m[s]);\"string\"==typeof n&&u(t,e,d,{target:n,func:\"first\",enabled:!0}),e._length=d.length}}}},{\"../constants/numerical\":695,\"../lib\":719,\"../plot_api/plot_schema\":756,\"../plots/cartesian/axes\":767,\"./helpers\":1268}],1266:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../registry\"),a=t(\"../plots/cartesian/axes\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/filter_ops\"),l=s.COMPARISON_OPS,c=s.INTERVAL_OPS,u=s.SET_OPS;r.moduleType=\"transform\",r.name=\"filter\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},operation:{valType:\"enumerated\",values:[].concat(l).concat(c).concat(u),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},preservegaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function a(i,a){return n.coerce(t,e,r.attributes,i,a)}if(a(\"enabled\")){var o=a(\"target\");if(n.isArrayOrTypedArray(o)&&0===o.length)return e.enabled=!1,e;a(\"preservegaps\"),a(\"operation\"),a(\"value\");var s=i.getComponentMethod(\"calendars\",\"handleDefaults\");s(t,e,\"valuecalendar\",null),s(t,e,\"targetcalendar\",null)}return e},r.calcTransform=function(t,e,r){if(r.enabled){var i=n.getTargetArray(e,r);if(i){var s=r.target,h=i.length;e._length&&(h=Math.min(h,e._length));var f=r.targetcalendar,p=e._arrayAttrs,d=r.preservegaps;if(\"string\"==typeof s){var g=n.nestedProperty(e,s+\"calendar\").get();g&&(f=g)}var v,m,y=function(t,e,r){var n=t.operation,i=t.value,a=Array.isArray(i);function o(t){return-1!==t.indexOf(n)}var s,h=function(r){return e(r,0,t.valuecalendar)},f=function(t){return e(t,0,r)};o(l)?s=h(a?i[0]:i):o(c)?s=a?[h(i[0]),h(i[1])]:[h(i),h(i)]:o(u)&&(s=a?i.map(h):[h(i)]);switch(n){case\"=\":return function(t){return f(t)===s};case\"!=\":return function(t){return f(t)!==s};case\"<\":return function(t){return f(t)<s};case\"<=\":return function(t){return f(t)<=s};case\">\":return function(t){return f(t)>s};case\">=\":return function(t){return f(t)>=s};case\"[]\":return function(t){var e=f(t);return e>=s[0]&&e<=s[1]};case\"()\":return function(t){var e=f(t);return e>s[0]&&e<s[1]};case\"[)\":return function(t){var e=f(t);return e>=s[0]&&e<s[1]};case\"(]\":return function(t){var e=f(t);return e>s[0]&&e<=s[1]};case\"][\":return function(t){var e=f(t);return e<=s[0]||e>=s[1]};case\")(\":return function(t){var e=f(t);return e<s[0]||e>s[1]};case\"](\":return function(t){var e=f(t);return e<=s[0]||e>s[1]};case\")[\":return function(t){var e=f(t);return e<s[0]||e>=s[1]};case\"{}\":return function(t){return-1!==s.indexOf(f(t))};case\"}{\":return function(t){return-1===s.indexOf(f(t))}}}(r,a.getDataToCoordFunc(t,e,s,i),f),x={},b={},_=0;d?(v=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set(new Array(h))},m=function(t,e){var r=x[t.astr][e];t.get()[e]=r}):(v=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set([])},m=function(t,e){var r=x[t.astr][e];t.get().push(r)}),T(v);for(var w=o(e.transforms,r),k=0;k<h;k++){y(i[k])?(T(m,k),b[_++]=w(k)):d&&_++}r._indexToPoints=b,e._length=_}}function T(t,r){for(var i=0;i<p.length;i++){t(n.nestedProperty(e,p[i]),r)}}}},{\"../constants/filter_ops\":691,\"../lib\":719,\"../plots/cartesian/axes\":767,\"../registry\":847,\"./helpers\":1268}],1267:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_schema\"),a=t(\"../plots/plots\"),o=t(\"./helpers\").pointsAccessorFunction;function s(t,e){var r,s,l,c,u,h,f,p,d,g,v=e.transform,m=e.transformIndex,y=t.transforms[m].groups,x=o(t.transforms,v);if(!Array.isArray(y)||0===y.length)return[t];var b=n.filterUnique(y),_=new Array(b.length),w=y.length,k=i.findArrayAttributes(t),T=v.styles||[],A={};for(r=0;r<T.length;r++)A[T[r].target]=T[r].value;v.styles&&(g=n.keyedContainer(v,\"styles\",\"target\",\"value.name\"));var M={},S={};for(r=0;r<b.length;r++){M[h=b[r]]=r,S[h]=0,(f=_[r]=n.extendDeepNoArrays({},t))._group=h,f.transforms[m]._indexToPoints={};var E=null;for(g&&(E=g.get(h)),f.name=E||\"\"===E?E:n.templateString(v.nameformat,{trace:t.name,group:h}),p=f.transforms,f.transforms=[],s=0;s<p.length;s++)f.transforms[s]=n.extendDeepNoArrays({},p[s]);for(s=0;s<k.length;s++)n.nestedProperty(f,k[s]).set([])}for(l=0;l<k.length;l++){for(c=k[l],s=0,d=[];s<b.length;s++)d[s]=n.nestedProperty(_[s],c).get();for(u=n.nestedProperty(t,c).get(),s=0;s<w;s++)d[M[y[s]]].push(u[s])}for(s=0;s<w;s++){(f=_[M[y[s]]]).transforms[m]._indexToPoints[S[y[s]]]=x(s),S[y[s]]++}for(r=0;r<b.length;r++)h=b[r],f=_[r],a.clearExpandedTraceDefaultColors(f),f=n.extendDeepNoArrays(f,A[h]||{});return _}r.moduleType=\"transform\",r.name=\"groupby\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"data_array\",dflt:[],editType:\"calc\"},nameformat:{valType:\"string\",editType:\"calc\"},styles:{_isLinkedToArray:\"style\",target:{valType:\"string\",editType:\"calc\"},value:{valType:\"any\",dflt:{},editType:\"calc\",_compareAsJSON:!0},editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t,e,i){var a,o={};function s(e,i){return n.coerce(t,o,r.attributes,e,i)}if(!s(\"enabled\"))return o;s(\"groups\"),s(\"nameformat\",i._dataLength>1?\"%{group} (%{trace})\":\"%{group}\");var l=t.styles,c=o.styles=[];if(l)for(a=0;a<l.length;a++){var u=c[a]={};n.coerce(l[a],c[a],r.attributes.styles,\"target\");var h=n.coerce(l[a],c[a],r.attributes.styles,\"value\");n.isPlainObject(h)?u.value=n.extendDeep({},h):h&&delete u.value}return o},r.transform=function(t,e){var r,n,i,a=[];for(n=0;n<t.length;n++)for(r=s(t[n],e),i=0;i<r.length;i++)a.push(r[i]);return a}},{\"../lib\":719,\"../plot_api/plot_schema\":756,\"../plots/plots\":828,\"./helpers\":1268}],1268:[function(t,e,r){\"use strict\";r.pointsAccessorFunction=function(t,e){for(var r,n,i=0;i<t.length&&(r=t[i])!==e;i++)r._indexToPoints&&!1!==r.enabled&&(n=r._indexToPoints);return n?function(t){return n[t]}:function(t){return[t]}}},{}],1269:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/cartesian/axes\"),a=t(\"./helpers\").pointsAccessorFunction;r.moduleType=\"transform\",r.name=\"sort\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},order:{valType:\"enumerated\",values:[\"ascending\",\"descending\"],dflt:\"ascending\",editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function i(i,a){return n.coerce(t,e,r.attributes,i,a)}return i(\"enabled\")&&(i(\"target\"),i(\"order\")),e},r.calcTransform=function(t,e,r){if(r.enabled){var o=n.getTargetArray(e,r);if(o){var s=r.target,l=o.length;e._length&&(l=Math.min(l,e._length));var c,u,h=e._arrayAttrs,f=function(t,e,r,n){var i,a=new Array(n),o=new Array(n);for(i=0;i<n;i++)a[i]={v:e[i],i:i};for(a.sort(function(t,e){switch(t.order){case\"ascending\":return function(t,r){return e(t.v)-e(r.v)};case\"descending\":return function(t,r){return e(r.v)-e(t.v)}}}(t,r)),i=0;i<n;i++)o[i]=a[i].i;return o}(r,o,i.getDataToCoordFunc(t,e,s,o),l),p=a(e.transforms,r),d={};for(c=0;c<h.length;c++){var g=n.nestedProperty(e,h[c]),v=g.get(),m=new Array(l);for(u=0;u<l;u++)m[u]=v[f[u]];g.set(m)}for(u=0;u<l;u++)d[u]=p(f[u]);r._indexToPoints=d,e._length=l}}}},{\"../lib\":719,\"../plots/cartesian/axes\":767,\"./helpers\":1268}]},{},[25])(25)});</script>    \n",
       "            <div id=\"aa0ceca4-81f6-4d13-96ac-59a888c7cd84\" class=\"plotly-graph-div\" style=\"height:500px; width:500px;\"></div>\n",
       "            <script type=\"text/javascript\">\n",
       "                \n",
       "                    window.PLOTLYENV=window.PLOTLYENV || {};\n",
       "                    \n",
       "                if (document.getElementById(\"aa0ceca4-81f6-4d13-96ac-59a888c7cd84\")) {\n",
       "                    Plotly.newPlot(\n",
       "                        'aa0ceca4-81f6-4d13-96ac-59a888c7cd84',\n",
       "                        [{\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 0.5\", \"showscale\": false, \"type\": \"surface\", \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.31622776601683794, 0.3760603093086393, 0.4161791450287817, 0.4472135954999579, 0.47287080450158786, 0.4949232003839765, 0.5143686723610401, 0.5318295896944989, 0.5477225575051661, 0.5623413251903491, 0.575901449065324, 0.5885661912765424, 0.6004624280888846, 0.6116908849062523, 0.6223329772884783, 0.6324555320336759, 0.6421141351518171, 0.6513555624326306, 0.6602195804079635, 0.668740304976422, 0.6769472427712399, 0.6848661007688606, 0.6925194237934933, 0.6999271023161167, 0.7071067811865476, 0.7140741917751113, 0.7208434242404264, 0.727427152512826, 0.7338368215846426, 0.7400828044922851, 0.7461745347323253, 0.7521206186172786, 0.7579289311365565, 0.7636066981663598, 0.7691605673134586, 0.7745966692414834, 0.7799206709850829, 0.7851378224852613, 0.7902529973621358, 0.7952707287670507, 0.8001952410151443, 0.8050304775850329, 0.8097801259787746, 0.8144476398584993, 0.81903625881272, 0.8235490260528069, 0.827988804296353, 0.8323582900575635, 0.8366600265340756, 0.8408964152537145, 0.8450697266227711, 0.8491821094987799, 0.8532355998949246, 0.8572321289096398, 0.861173529963367, 0.8650615454144222, 0.8688978326173192, 0.8726839694794393, 0.8764214595654655, 0.8801117367933934, 0.8837561697610181, 0.8873560657375262, 0.8909126743510709, 0.8944271909999159, 0.8979007600118484, 0.9013344775740003, 0.904729394452974, 0.9080865185231703, 0.9114068171194505, 0.9146912192286943, 0.9179406175334197, 0.9211558703193814, 0.9243378032579611, 0.9274872110731568, 0.9306048591020996, 0.9336914847572161, 0.9367477988974472, 0.9397744871152784, 0.9427722109457612, 0.9457416090031757, 0.9486832980505138, 0.9515978740065268, 0.9544859128947005, 0.9573479717381596, 0.9601845894041878, 0.9629962874017586, 0.9657835706352026, 0.9685469281169012, 0.9712868336416696, 0.9740037464252967, 0.9766981117095218, 0.9793703613355592, 0.9820209142881303, 0.9846501772118187, 0.9872585449014338, 0.989846400767953, 0.9924141172814958, 0.9949620563926881, 0.997490569933681, 1.0, 1.0024906793143211], [0.0, 0.3760603093086393, 0.4472135954999579, 0.4949232003839765, 0.5318295896944988, 0.5623413251903491, 0.5885661912765423, 0.6116908849062525, 0.6324555320336759, 0.6513555624326306, 0.668740304976422, 0.6848661007688605, 0.6999271023161167, 0.7140741917751113, 0.7274271525128259, 0.7400828044922851, 0.7521206186172786, 0.7636066981663597, 0.7745966692414834, 0.7851378224852613, 0.7952707287670506, 0.8050304775850328, 0.8144476398584994, 0.823549026052807, 0.8323582900575635, 0.8408964152537146, 0.8491821094987798, 0.85723212890964, 0.8650615454144222, 0.8726839694794393, 0.8801117367933933, 0.8873560657375262, 0.8944271909999159, 0.9013344775740003, 0.9080865185231703, 0.9146912192286943, 0.9211558703193814, 0.9274872110731568, 0.9336914847572162, 0.9397744871152784, 0.9457416090031758, 0.9515978740065267, 0.9573479717381597, 0.9629962874017586, 0.9685469281169012, 0.9740037464252967, 0.9793703613355592, 0.9846501772118186, 0.989846400767953, 0.9949620563926881, 1.0, 1.0049629315732038, 1.0098534065489688, 1.0146738461686593, 1.0194265469082735, 1.0241136890844451, 1.0287373447220802, 1.0332994847589594, 1.0378019856537666, 1.0422466354563211, 1.0466351393921056, 1.0509691250073554, 1.0552501469158886, 1.0594796911843958, 1.0636591793889976, 1.0677899723724407, 1.0718733737282615, 1.07591063303558, 1.0799029488658045, 1.0838514715804344, 1.0877573059372772, 1.0916215135207343, 1.0954451150103321, 1.0992290923003527, 1.1029743904822287, 1.1066819197003215, 1.110352556890736, 1.1139871474119822, 1.1175865065755222, 1.1211514210835454, 1.1246826503806981, 1.128180927925918, 1.1316469623900245, 1.1350814387842454, 1.1384850195244434, 1.1418583454354265, 1.1452020366993765, 1.148516693752116, 1.1518028981306478, 1.1550612132751377, 1.158292185288269, 1.161496343654686, 1.164674201923033, 1.167826258352922, 1.1709529965289849, 1.1740548859440185, 1.1771323825530846, 1.1801859293002996, 1.1832159566199232, 1.1862228829132528, 1.189207115002721, 1.1921690485645018], [0.0, 0.4161791450287817, 0.4949232003839765, 0.5477225575051661, 0.5885661912765423, 0.6223329772884783, 0.6513555624326306, 0.6769472427712399, 0.6999271023161167, 0.7208434242404262, 0.7400828044922853, 0.7579289311365563, 0.7745966692414834, 0.7902529973621358, 0.8050304775850328, 0.8190362588127199, 0.8323582900575635, 0.8450697266227711, 0.8572321289096398, 0.8688978326173193, 0.8801117367933934, 0.8909126743510708, 0.9013344775740003, 0.9114068171194506, 0.9211558703193815, 0.9306048591020997, 0.9397744871152784, 0.9486832980505139, 0.9573479717381597, 0.9657835706352028, 0.9740037464252967, 0.9820209142881303, 0.989846400767953, 0.9974905699336811, 1.0049629315732038, 1.0122722344290391, 1.0194265469082735, 1.0264333272479387, 1.0332994847589596, 1.0400314334861216, 1.0466351393921056, 1.0531161619882878, 1.0594796911843958, 1.0657305800060608, 1.0718733737282615, 1.0779123358892526, 1.0838514715804344, 1.0896945483500373, 1.0954451150103321, 1.1011065185976396, 1.1066819197003215, 1.112174306341096, 1.1175865065755222, 1.1229211999476407, 1.128180927925918, 1.133368103427352, 1.1384850195244434, 1.1435338574183984, 1.148516693752116, 1.1534355073280027, 1.158292185288269, 1.1630885288089072, 1.167826258352922, 1.172507018523451, 1.1771323825530846, 1.1817038564618862, 1.1862228829132528, 1.190690844793804, 1.1951090685408468, 1.1994788272386536, 1.203801343502716, 1.2080777921692967, 1.212309302805974, 1.2164969620573964, 1.220641815839165, 1.224744871391589, 1.2288070992040003, 1.2328294348193778, 1.236812780528175, 1.2407580069594817, 1.2446659545769565, 1.2485374350863452, 1.2523732327608301, 1.2561741056899516, 1.259940786957369, 1.2636739857523107, 1.2673743884191842, 1.2710426594494582, 1.2746794424196195, 1.2782853608787121, 1.281861019188702, 1.2854070033206721, 1.288923881609622, 1.2924122054704554, 1.295872510077541, 1.2993053150100684, 1.3027111248652612, 1.3060904298413636, 1.309443706292189, 1.3127714172548886, 1.3160740129524924, 1.319351931272669], [0.0, 0.4472135954999579, 0.5318295896944988, 0.5885661912765423, 0.6324555320336758, 0.668740304976422, 0.6999271023161167, 0.7274271525128259, 0.7521206186172787, 0.7745966692414833, 0.7952707287670506, 0.8144476398584993, 0.8323582900575635, 0.8491821094987799, 0.865061545414422, 0.8801117367933933, 0.8944271909999159, 0.9080865185231702, 0.9211558703193814, 0.9336914847572161, 0.9457416090031757, 0.9573479717381596, 0.9685469281169012, 0.9793703613355593, 0.9898464007679532, 1.0, 1.0098534065489688, 1.0194265469082735, 1.0287373447220802, 1.0378019856537666, 1.0466351393921054, 1.0552501469158886, 1.0636591793889976, 1.0718733737282617, 1.0799029488658043, 1.087757305937277, 1.0954451150103321, 1.1029743904822287, 1.1103525568907362, 1.1175865065755222, 1.1246826503806981, 1.1316469623900245, 1.1384850195244434, 1.1452020366993765, 1.1518028981306478, 1.158292185288269, 1.164674201923033, 1.1709529965289847, 1.1771323825530846, 1.1832159566199232, 1.189207115002721, 1.1951090685408465, 1.2009248561777692, 1.206657357270946, 1.212309302805974, 1.2178832856309065, 1.223381769812505, 1.2288070992040003, 1.2341615053034112, 1.2394471144723045, 1.2446659545769567, 1.2498199611069312, 1.2549109828200413, 1.259940786957369, 1.2649110640673515, 1.2698234324738655, 1.2746794424196195, 1.2794805799129934, 1.2842282703036343, 1.288923881609622, 1.2935687276168015, 1.2981640707688962, 1.3027111248652612, 1.3072110575815623, 1.311664992827256, 1.3160740129524924, 1.320439160815927, 1.3247614417239144, 1.3290418252506462, 1.333281246947964, 1.337480609952844, 1.3416407864998738, 1.345762619345434, 1.34984692310975, 1.3538944855424797, 1.357906068717044, 1.3618824101585059, 1.3658242239094176, 1.369732201537721, 1.3736070130904692, 1.3774493079968595, 1.381259715923798, 1.3850388475869866, 1.3887872955203007, 1.3925056348060254, 1.3961944237683348, 1.3998542046322333, 1.4034855041500147, 1.4070888341971637, 1.4106646923394799, 1.414213562373095, 1.4177359148389301], [0.0, 0.47287080450158786, 0.5623413251903491, 0.6223329772884783, 0.668740304976422, 0.7071067811865475, 0.7400828044922853, 0.7691605673134586, 0.7952707287670506, 0.81903625881272, 0.8408964152537145, 0.861173529963367, 0.8801117367933934, 0.8979007600118484, 0.9146912192286943, 0.9306048591020994, 0.9457416090031757, 0.9601845894041878, 0.9740037464252967, 0.9872585449014338, 0.9999999999999999, 1.0122722344290394, 1.0241136890844451, 1.0355580763416221, 1.0466351393921056, 1.057371263440564, 1.0677899723724407, 1.0779123358892526, 1.0877573059372772, 1.0973419967718494, 1.1066819197003215, 1.1157911810902938, 1.1246826503806981, 1.133368103427352, 1.1418583454354265, 1.150163316895603, 1.158292185288269, 1.1662534248067802, 1.1740548859440185, 1.181703856461886, 1.189207115002721, 1.1965709783910168, 1.203801343502716, 1.210903724439527, 1.2178832856309065, 1.224744871391589, 1.2314930323839879, 1.238132049369367, 1.2446659545769565, 1.2510985509742438, 1.2574334296829353, 1.2636739857523107, 1.2698234324738655, 1.2758848143974324, 1.281861019188702, 1.287754788450697, 1.2935687276168015, 1.2993053150100684, 1.3049669101523764, 1.310555761397342, 1.3160740129524924, 1.3215237113488725, 1.3269068114098672, 1.332225181765412, 1.337480609952844, 1.342674807141325, 1.3478094125129467, 1.3528859973302676, 1.3579060687170441, 1.362871073176282, 1.3677823998673804, 1.3726413836620537, 1.3774493079968595, 1.3822074075384925, 1.386916870676514, 1.3915788418568702, 1.3961944237683348, 1.4007646793929587, 1.4052906339306293, 1.4097732766069795, 1.414213562373095, 1.4186124135047635, 1.4229707211083644, 1.4272893465399143, 1.4315691227432643, 1.4358108555129503, 1.4400153246867797, 1.4441832852728287, 1.4483154685151653, 1.452412582902289, 1.45647531512197, 1.460504330965901, 1.4645002761873147, 1.4684637773145044, 1.4723954424229517, 1.4762958618685946, 1.4801656089845705, 1.484005240743618, 1.4878152983881654, 1.4915963080299905, 1.4953487812212205, 1.4990732154983035], [0.0, 0.4949232003839765, 0.5885661912765423, 0.6513555624326306, 0.6999271023161167, 0.7400828044922853, 0.7745966692414834, 0.8050304775850328, 0.8323582900575635, 0.8572321289096398, 0.8801117367933934, 0.9013344775740003, 0.9211558703193815, 0.9397744871152784, 0.9573479717381596, 0.9740037464252966, 0.989846400767953, 1.0049629315732038, 1.0194265469082735, 1.0332994847589596, 1.0466351393921054, 1.0594796911843958, 1.0718733737282617, 1.0838514715804344, 1.0954451150103324, 1.1066819197003217, 1.1175865065755222, 1.128180927925918, 1.1384850195244434, 1.148516693752116, 1.158292185288269, 1.167826258352922, 1.1771323825530846, 1.1862228829132528, 1.1951090685408468, 1.2038013435027157, 1.2123093028059742, 1.220641815839165, 1.2288070992040003, 1.236812780528175, 1.2446659545769567, 1.25237323276083, 1.259940786957369, 1.2673743884191842, 1.2746794424196195, 1.281861019188702, 1.288923881609622, 1.2958725100775408, 1.3027111248652612, 1.309443706292189, 1.3160740129524924, 1.3226055982240474, 1.3290418252506462, 1.3353858805651275, 1.3416407864998738, 1.3478094125129467, 1.35389448554248, 1.3598985994884667, 1.3658242239094178, 1.3716737120112341, 1.3774493079968597, 1.3831531538375998, 1.3887872955203007, 1.3943536888187151, 1.3998542046322333, 1.4052906339306293, 1.41066469233948, 1.4159780243973923, 1.4212322075130495, 1.4264287556473265, 1.4315691227432643, 1.4366547059245063, 1.4416868484808525, 1.4466668426578508, 1.451595932265776, 1.4564753151219703, 1.4613061453392517, 1.4660895354719874, 1.4708265585304046, 1.4755182498728112, 1.4801656089845705, 1.4847696011519296, 1.489331159038138, 1.4938511841686706, 1.4983305483318308, 1.502770094900495, 1.507170640080316, 1.5115329740892762, 1.5158578622731127, 1.5201460461607854, 1.5243982444638442, 1.5286151540232695, 1.5327974507070874, 1.5369457902618242, 1.541060809120647, 1.5451431251708252, 1.5491933384829668, 1.553212032004312, 1.5571997722182047, 1.5611571097717192, 1.5650845800732873, 1.5689827038620388], [0.0, 0.5143686723610401, 0.6116908849062525, 0.6769472427712399, 0.7274271525128259, 0.7691605673134586, 0.8050304775850328, 0.8366600265340756, 0.8650615454144222, 0.8909126743510708, 0.9146912192286945, 0.9367477988974472, 0.9573479717381597, 0.9766981117095219, 0.9949620563926881, 1.0122722344290391, 1.0287373447220802, 1.04444780217279, 1.0594796911843958, 1.0738976950655401, 1.0877573059372772, 1.1011065185976396, 1.1139871474119825, 1.126435863262952, 1.1384850195244434, 1.1501633168956031, 1.161496343654686, 1.172507018523451, 1.1832159566199234, 1.1936417741003793, 1.203801343502716, 1.2137100091313509, 1.223381769812505, 1.2328294348193778, 1.2420647575928365, 1.2510985509742438, 1.259940786957369, 1.2686006834079462, 1.277086779756963, 1.2854070033206721, 1.2935687276168018, 1.3015788238173445, 1.309443706292189, 1.317169373045755, 1.3247614417239144, 1.3322251817654118, 1.3395655431865348, 1.3467871824166227, 1.3538944855424797, 1.3608915892697748, 1.3677823998673804, 1.3745706103249549, 1.381259715923798, 1.3878530283952342, 1.3943536888187151, 1.4007646793929587, 1.4070888341971637, 1.4133288490453373, 1.4194872905246418, 1.4255666042981499, 1.4315691227432645, 1.4374970719890816, 1.44335257840902, 1.449137674618944, 1.4548543050256517, 1.460504330965901, 1.4660895354719874, 1.4716116276962383, 1.4770722470235311, 1.4824729668980785, 1.4878152983881654, 1.493100693510252, 1.4983305483318308, 1.5035062058706188, 1.508628958806044, 1.5137000520175454, 1.5187206849628931, 1.5236920139085786, 1.5286151540232698, 1.533491181344376, 1.5383211346269172, 1.5431060170831203, 1.547846798020459, 1.5525444143852343, 1.5571997722182047, 1.561813748028264, 1.5663871900896853, 1.5709209196680185, 1.5754157321793416, 1.5798723982871963, 1.584291664941221, 1.588674256361194, 1.593020874969912, 1.5973322022781031, 1.6016088997243154, 1.6058516094725332, 1.6100609551700655, 1.6142375426680784, 1.618381960706977, 1.6224947815686916, 1.6265765616977856, 1.630627842293166], [0.0, 0.5318295896944989, 0.6324555320336759, 0.6999271023161167, 0.7521206186172787, 0.7952707287670506, 0.8323582900575635, 0.8650615454144222, 0.894427190999916, 0.9211558703193814, 0.9457416090031758, 0.9685469281169012, 0.9898464007679532, 1.0098534065489688, 1.0287373447220802, 1.0466351393921054, 1.0636591793889978, 1.0799029488658045, 1.0954451150103321, 1.1103525568907362, 1.1246826503806981, 1.1384850195244434, 1.151802898130648, 1.164674201923033, 1.1771323825530848, 1.1892071150027212, 1.2009248561777692, 1.2123093028059742, 1.223381769812505, 1.2341615053034112, 1.2446659545769565, 1.2549109828200413, 1.2649110640673518, 1.2746794424196195, 1.2842282703036343, 1.2935687276168015, 1.3027111248652612, 1.311664992827256, 1.3204391608159272, 1.3290418252506462, 1.3374806099528442, 1.345762619345434, 1.35389448554248, 1.3618824101585059, 1.369732201537721, 1.3774493079968597, 1.3850388475869866, 1.3925056348060254, 1.3998542046322333, 1.4070888341971637, 1.4142135623730951, 1.4212322075130495, 1.4281483835502227, 1.4349655146369895, 1.4416868484808525, 1.4483154685151653, 1.454854305025652, 1.4613061453392517, 1.4676736431692852, 1.4739593272000566, 1.4801656089845705, 1.4862947902207868, 1.4923490694646506, 1.498330548331831, 1.5042412372345575, 1.5100830606950983, 1.515857862273113, 1.5215674091403395, 1.5272133963327197, 1.5327974507070874, 1.5383211346269172, 1.5437859493992674, 1.5491933384829668, 1.5545446904862257, 1.5598413419701658, 1.5650845800732873, 1.5702756449705226, 1.5754157321793416, 1.5805059947242717, 1.5855475451702188, 1.5905414575341013, 1.5954887690834967, 1.6003904820302886, 1.6052475651266458, 1.6100609551700658, 1.6148315584236825, 1.6195602519575492, 1.624247884916149, 1.6288952797169989, 1.633503233184822, 1.63807251762544, 1.642603881843218, 1.6470980521056138, 1.6515557330581283, 1.6559776085927063, 1.6603643426724282, 1.664716580115127, 1.6690349473383785, 1.6733200530681511, 1.6775724890132342, 1.681792830507429, 1.6859816371213476], [0.0, 0.5477225575051661, 0.6513555624326306, 0.7208434242404262, 0.7745966692414833, 0.81903625881272, 0.8572321289096398, 0.8909126743510708, 0.9211558703193814, 0.9486832980505138, 0.9740037464252967, 0.997490569933681, 1.0194265469082735, 1.0400314334861216, 1.0594796911843956, 1.0779123358892526, 1.0954451150103321, 1.112174306341096, 1.128180927925918, 1.1435338574183984, 1.158292185288269, 1.172507018523451, 1.1862228829132528, 1.1994788272386536, 1.2123093028059742, 1.2247448713915892, 1.2368127805281748, 1.2485374350863452, 1.259940786957369, 1.2710426594494582, 1.281861019188702, 1.2924122054704554, 1.3027111248652612, 1.3127714172548886, 1.3226055982240474, 1.3322251817654118, 1.3416407864998738, 1.3508622280193734, 1.3598985994884667, 1.368758342264813, 1.3774493079968597, 1.385978813413053, 1.3943536888187151, 1.4025803211547638, 1.4106646923394799, 1.4186124135047637, 1.4264287556473265, 1.4341186771394874, 1.4416868484808525, 1.449137674618944, 1.4564753151219703, 1.463703702448981, 1.4708265585304046, 1.4778474098445196, 1.4847696011519296, 1.4915963080299905, 1.4983305483318308, 1.504975192679675, 1.5115329740892762, 1.5180064968110587, 1.5243982444638442, 1.5307105875285492, 1.5369457902618242, 1.5431060170831206, 1.5491933384829666, 1.5552097364952306, 1.5611571097717192, 1.5670372782935749, 1.5728519877504674, 1.5786029136155242, 1.584291664941221, 1.5899197878990334, 1.5954887690834965, 1.6010000385993937, 1.6064549729490671, 1.6118548977353129, 1.6172010901939202, 1.6224947815686916, 1.6277371593406456, 1.6329293693221016, 1.63807251762544, 1.6431676725154982, 1.6482158661538315, 1.653218096242383, 1.658175327573506, 1.6630884934927144, 1.6679584972800465, 1.6727862134554565, 1.6775724890132342, 1.6823181445900717, 1.6870239755710472, 1.6916907531374747, 1.6963192252602786, 1.7009101176422834, 1.7054641346125685, 1.709981959975803, 1.7144642578192797, 1.7189116732801692, 1.7233248332753461, 1.7277043471959719, 1.7320508075688772, 1.7363647906866422], [0.0, 0.5623413251903491, 0.668740304976422, 0.7400828044922853, 0.7952707287670506, 0.8408964152537145, 0.8801117367933934, 0.9146912192286945, 0.9457416090031758, 0.9740037464252967, 1.0, 1.0241136890844451, 1.0466351393921056, 1.0677899723724409, 1.0877573059372772, 1.1066819197003215, 1.1246826503806981, 1.1418583454354265, 1.158292185288269, 1.1740548859440185, 1.189207115002721, 1.203801343502716, 1.2178832856309068, 1.231493032383988, 1.2446659545769567, 1.2574334296829355, 1.2698234324738655, 1.2818610191887023, 1.2935687276168018, 1.3049669101523764, 1.3160740129524924, 1.3269068114098672, 1.337480609952844, 1.347809412512947, 1.3579060687170441, 1.3677823998673804, 1.3774493079968597, 1.386916870676514, 1.396194423768335, 1.4052906339306293, 1.4142135623730951, 1.4229707211083644, 1.4315691227432645, 1.44001532468678, 1.4483154685151653, 1.4564753151219703, 1.464500276187315, 1.4723954424229517, 1.4801656089845705, 1.4878152983881654, 1.4953487812212205, 1.5027700949004952, 1.5100830606950983, 1.5172912992053529, 1.5243982444638442, 1.531407156804393, 1.5383211346269174, 1.5451431251708252, 1.5518759343963227, 1.5585222360615276, 1.5650845800732873, 1.5715654001808814, 1.5779670210741878, 1.5842916649412213, 1.5905414575341013, 1.59671843378737, 1.602824543028034, 1.6088616538127065, 1.6148315584236828, 1.6207359770526288, 1.6265765616977856, 1.6323548997980941, 1.63807251762544, 1.643730883454241, 1.6493314105258192, 1.6548754598234365, 1.6603643426724282, 1.665799323178612, 1.6711816205169887, 1.6765124110817191, 1.681792830507429, 1.6870239755710472, 1.6922069059826197, 1.6973426460728507, 1.7024321863844938, 1.7074764851741444, 1.7124764698304722, 1.7174330382144525, 1.722347059926734, 1.7272193775068816, 1.7320508075688772, 1.7368421418769384, 1.741594148365405, 1.74630757210618, 1.7509831362269537, 1.7556215427832071, 1.7602234735867868, 1.7647895909936366, 1.7693205386531028, 1.7738169422210552, 1.7782794100389228, 1.78270853378059], [0.0, 0.575901449065324, 0.6848661007688605, 0.7579289311365563, 0.8144476398584993, 0.861173529963367, 0.9013344775740003, 0.9367477988974472, 0.9685469281169012, 0.997490569933681, 1.0241136890844451, 1.0488088481701514, 1.0718733737282617, 1.093538327773718, 1.1139871474119822, 1.133368103427352, 1.151802898130648, 1.1693927625557354, 1.1862228829132528, 1.2023656804317462, 1.2178832856309065, 1.2328294348193778, 1.247250944521753, 1.261188872476556, 1.2746794424196195, 1.2877547884506972, 1.3004435599166833, 1.3127714172548886, 1.3247614417239146, 1.33643447648928, 1.3478094125129467, 1.3589034297042373, 1.369732201537721, 1.3803100696313728, 1.3906501934639681, 1.4007646793929585, 1.41066469233948, 1.4203605528819792, 1.4298618220045207, 1.4391773753505153, 1.4483154685151656, 1.4572837946534403, 1.4660895354719874, 1.4747394065031132, 1.4832396974191324, 1.4915963080299908, 1.4998147805113797, 1.5079003283308927, 1.5158578622731127, 1.5236920139085786, 1.531407156804393, 1.5390074257343278, 1.5464967341123872, 1.5538787898449244, 1.5611571097717194, 1.568335032845268, 1.5754157321793418, 1.5824022260821624, 1.5892973881759884, 1.5961039566931094, 1.602824543028034, 1.6094616396167147, 1.6160176272058788, 1.6224947815686919, 1.6288952797169987, 1.635221205655121, 1.6414745557155297, 1.6476572435126322, 1.6537711045472614, 1.6598179004912503, 1.665799323178612, 1.671716998327296, 1.6775724890132342, 1.6833672989163568, 1.689102875356448, 1.694780612135097, 1.7004018521985302, 1.70596789013482, 1.7114799745177744, 1.716939310108757, 1.722347059926734, 1.7277043471959719, 1.7330122571800355, 1.7382718389100207, 1.7434841068143216, 1.748650042256635, 1.7537705949883924, 1.7588466845213098, 1.7638792014253155, 1.7688690085567114, 1.7738169422210552, 1.7787238132749206, 1.7835904081703773, 1.7884174899457608, 1.793205799166037, 1.7979560548158353, 1.8026689551480006, 1.8073451784903223, 1.8119853840129068, 1.816590212458495, 1.8211602868378718, 1.825696213092362], [0.0, 0.5885661912765424, 0.6999271023161167, 0.7745966692414834, 0.8323582900575635, 0.8801117367933934, 0.9211558703193815, 0.9573479717381597, 0.9898464007679532, 1.0194265469082735, 1.0466351393921056, 1.0718733737282617, 1.0954451150103324, 1.1175865065755222, 1.1384850195244434, 1.158292185288269, 1.1771323825530848, 1.1951090685408468, 1.2123093028059742, 1.2288070992040006, 1.2446659545769567, 1.259940786957369, 1.2746794424196197, 1.2889238816096222, 1.3027111248652612, 1.3160740129524926, 1.3290418252506462, 1.341640786499874, 1.35389448554248, 1.3658242239094178, 1.3774493079968597, 1.3887872955203007, 1.3998542046322333, 1.41066469233948, 1.4212322075130497, 1.4315691227432643, 1.4416868484808527, 1.451595932265776, 1.461306145339252, 1.4708265585304046, 1.4801656089845707, 1.489331159038138, 1.498330548331831, 1.5071706400803162, 1.515857862273113, 1.5243982444638442, 1.5327974507070876, 1.541060809120647, 1.5491933384829668, 1.5571997722182047, 1.5650845800732873, 1.5728519877504676, 1.5805059947242717, 1.5880503904422236, 1.5954887690834967, 1.602824543028034, 1.6100609551700658, 1.6172010901939202, 1.6242478849161492, 1.6312041377859532, 1.6380725176254403, 1.6448555716821271, 1.6515557330581283, 1.6581753275735063, 1.664716580115127, 1.6711816205169887, 1.6775724890132342, 1.6838911413008757, 1.6901394532455423, 1.6963192252602788, 1.7024321863844938, 1.708479998087565, 1.71446425781928, 1.7203865023272384, 1.726248210759469, 1.7320508075688774, 1.7377956652346387, 1.7434841068143216, 1.7491174083393235, 1.75469680106511, 1.7602234735867868, 1.7656985738296271, 1.771123210923403, 1.7764984569686235, 1.7818253487021418, 1.7871048890689831, 1.7923380487067173, 1.797525767348191, 1.8026689551480006, 1.8077684939376608, 1.8128252384140608, 1.8178400172654527, 1.822813634238901, 1.8277468691528413, 1.8326404788581239, 1.8374951981506855, 1.842311740638763, 1.847090799567362, 1.8518330486025056, 1.8565391425776128, 1.8612097182041993, 1.865845394748944], [0.0, 0.6004624280888846, 0.7140741917751113, 0.7902529973621358, 0.8491821094987799, 0.8979007600118484, 0.9397744871152784, 0.9766981117095219, 1.0098534065489688, 1.0400314334861216, 1.0677899723724409, 1.093538327773718, 1.1175865065755222, 1.140175425099138, 1.161496343654686, 1.181703856461886, 1.2009248561777692, 1.219264891125735, 1.236812780528175, 1.2536440342258928, 1.2698234324738655, 1.2854070033206724, 1.3004435599166835, 1.314975911026152, 1.3290418252506464, 1.3426748071413253, 1.355904727879147, 1.3687583422648133, 1.3812597159237983, 1.3934305809385557, 1.4052906339306293, 1.4168577874961457, 1.4281483835502227, 1.4391773753505155, 1.4499584835997423, 1.460504330965901, 1.4708265585304046, 1.480935927022547, 1.4908424051821465, 1.5005552471800365, 1.5100830606950986, 1.5194338669790928, 1.52861515402327, 1.5376339237631882, 1.5464967341123872, 1.5552097364952309, 1.563778709449485, 1.5722090887861115, 1.5805059947242717, 1.588674256361194, 1.59671843378737, 1.6046428381159301, 1.61245154965971, 1.6201484344594288, 1.6277371593406456, 1.635221205655121, 1.642603881843218, 1.6498883349376223, 1.6570775611145052, 1.6641744153859734, 1.6711816205169887, 1.6781017752406273, 1.68493736183743, 1.6916907531374752, 1.6983642189975598, 1.704959932300383, 1.7114799745177744, 1.7179263408757495, 1.72430094515537, 1.7306056241600476, 1.7368421418769384, 1.7430121933574254, 1.7491174083393233, 1.7551593546313318, 1.7611395412783635, 1.7670594215246977, 1.772920395590378, 1.7787238132749208, 1.7844709764011664, 1.790163141111003, 1.7958015200236968, 1.8013872842666538, 1.8069215653876352, 1.812405457156695, 1.8178400172654527, 1.8232262689306922, 1.828565202408735, 1.8338577764265274, 1.8391049195349223, 1.8443075313892177, 1.8494664839616353, 1.854582622690067, 1.8596567675671005, 1.8646897141730423, 1.8696822346563888, 1.8746350786649428, 1.879548974230557, 1.8844246286102666, 1.8892627290863888, 1.8940639437279883, 1.8988289221159418, 1.9035582960336908], [0.0, 0.6116908849062523, 0.7274271525128259, 0.8050304775850328, 0.865061545414422, 0.9146912192286943, 0.9573479717381596, 0.9949620563926881, 1.0287373447220802, 1.0594796911843956, 1.0877573059372772, 1.1139871474119822, 1.1384850195244434, 1.161496343654686, 1.1832159566199232, 1.2038013435027157, 1.2233817698125047, 1.2420647575928363, 1.2599407869573689, 1.2770867797569627, 1.2935687276168015, 1.309443706292189, 1.3247614417239146, 1.339565543186535, 1.35389448554248, 1.3677823998673806, 1.381259715923798, 1.3943536888187151, 1.4070888341971637, 1.4194872905246418, 1.4315691227432643, 1.4433525784090198, 1.4548543050256517, 1.4660895354719874, 1.4770722470235311, 1.4878152983881652, 1.4983305483318308, 1.508628958806044, 1.5187206849628931, 1.5286151540232695, 1.5383211346269174, 1.547846798020459, 1.5571997722182047, 1.5663871900896853, 1.5754157321793416, 1.584291664941221, 1.593020874969912, 1.6016088997243152, 1.6100609551700655, 1.618381960706977, 1.6265765616977856, 1.634649149872069, 1.642603881843218, 1.6504446959456858, 1.658175327573506, 1.665799323178612, 1.6733200530681511, 1.6807407231233218, 1.6880643855478386, 1.6952939487416283, 1.7024321863844938, 1.7094817458049945, 1.7164451557015292, 1.7233248332753464, 1.730123090828844, 1.7368421418769384, 1.7434841068143214, 1.7500510181771018, 1.75654482553344, 1.7629674000343882, 1.7693205386531026, 1.7756059681378888, 1.7818253487021416, 1.7879802774720857, 1.7940722917112943, 1.800102871839254, 1.8060734442596784, 1.8119853840129065, 1.8178400172654527, 1.8236386236486597, 1.8293824384573887, 1.8350726547187572, 1.8407104251401096, 1.8462968639446533, 1.8518330486025054, 1.8573200214642784, 1.8627587913037733, 1.8681503347758255, 1.8734955977948944, 1.8787954968395464, 1.884050920187607, 1.8892627290863886, 1.8944317588620794, 1.8995588199720859, 1.9046446990038355, 1.9096901596233076, 1.914695943476319, 1.9196627710453875, 1.9245913424647911, 1.9294823382962738, 1.9343364202676692, 1.939154231976568], [0.0, 0.6223329772884783, 0.7400828044922851, 0.8190362588127199, 0.8801117367933933, 0.9306048591020994, 0.9740037464252966, 1.0122722344290391, 1.0466351393921054, 1.0779123358892526, 1.1066819197003215, 1.133368103427352, 1.158292185288269, 1.181703856461886, 1.2038013435027157, 1.2247448713915887, 1.2446659545769565, 1.2636739857523107, 1.281861019188702, 1.2993053150100684, 1.3160740129524924, 1.3322251817654118, 1.347809412512947, 1.362871073176282, 1.3774493079968595, 1.3915788418568702, 1.405290633930629, 1.4186124135047637, 1.4315691227432645, 1.444183285272829, 1.45647531512197, 1.4684637773145044, 1.4801656089845703, 1.4915963080299905, 1.502770094900495, 1.5137000520175452, 1.5243982444638442, 1.5348758249050471, 1.5451431251708252, 1.5552097364952304, 1.5650845800732873, 1.5747759693135555, 1.584291664941221, 1.5936389239222475, 1.6028245430280337, 1.6118548977353127, 1.6207359770526286, 1.6294734147786363, 1.6380725176254398, 1.6465382905797215, 1.6548754598234363, 1.6630884934927144, 1.6711816205169885, 1.6791588477491748, 1.687023975571047, 1.6947806121350968, 1.7024321863844938, 1.709981959975803, 1.7174330382144525, 1.724788380100209, 1.7320508075688772, 1.7392230140067817, 1.7463075721061798, 1.7533069411223694, 1.7602234735867865, 1.7670594215246973, 1.773816942221055, 1.78049810357368, 1.7871048890689831, 1.7936392024119794, 1.8001028718392538, 1.8064976541407807, 1.8128252384140606, 1.8190872495718449, 1.8252852516227527, 1.831420750742353, 1.8374951981506853, 1.8435099928108025, 1.8494664839616353, 1.8553659734973313, 1.861209718204199, 1.8669989318654348, 1.872734787242987, 1.8784184179451258, 1.884050920187607, 1.8896333544556796, 1.8951667470736167, 1.900652091687926, 1.9060903506699227, 1.91148245644291, 1.9168293127388172, 1.9221317957887882, 1.9273907554518728, 1.932607016285675, 1.9377813785625346, 1.9429146192345597, 1.9480074928505933, 1.953060732427983, 1.9580750502818227, 1.9630511388141516, 1.9679896712654301, 1.9728913024304486], [0.0, 0.6324555320336759, 0.7521206186172786, 0.8323582900575635, 0.8944271909999159, 0.9457416090031757, 0.989846400767953, 1.0287373447220802, 1.0636591793889978, 1.0954451150103321, 1.1246826503806981, 1.151802898130648, 1.1771323825530848, 1.2009248561777692, 1.2233817698125047, 1.2446659545769565, 1.2649110640673518, 1.2842282703036343, 1.3027111248652612, 1.320439160815927, 1.337480609952844, 1.3538944855424797, 1.3697322015377211, 1.3850388475869866, 1.3998542046322333, 1.4142135623730951, 1.4281483835502227, 1.4416868484808527, 1.454854305025652, 1.4676736431692852, 1.4801656089845703, 1.4923490694646506, 1.5042412372345573, 1.515857862273113, 1.5272133963327197, 1.5383211346269172, 1.5491933384829668, 1.5598413419701658, 1.5702756449705226, 1.5805059947242717, 1.5905414575341015, 1.6003904820302886, 1.6100609551700658, 1.6195602519575492, 1.6288952797169987, 1.63807251762544, 1.6470980521056138, 1.655977608592706, 1.664716580115127, 1.6733200530681511, 1.681792830507429, 1.6901394532455423, 1.6983642189975598, 1.7064711997898492, 1.7144642578192797, 1.722347059926734, 1.7301230908288443, 1.7377956652346385, 1.7453679389588785, 1.752842919130931, 1.7602234735867868, 1.7675123395220362, 1.7747121314750525, 1.7818253487021418, 1.7888543819998317, 1.7958015200236968, 1.8026689551480006, 1.809458788905948, 1.8161730370463407, 1.822813634238901, 1.8293824384573887, 1.8358812350668394, 1.8423117406387628, 1.8486756065159222, 1.8549744221463136, 1.8612097182041991, 1.8673829695144322, 1.8734955977948944, 1.879548974230557, 1.8855444218915225, 1.8914832180063514, 1.8973665961010275, 1.9031957480130537, 1.908971825789401, 1.914695943476319, 1.9203691788083757, 1.9259925748035172, 1.9315671412704052, 1.9370938562338025, 1.9425736672833391, 1.9480074928505935, 1.9533962234190436, 1.9587407226711184, 1.9640418285762606, 1.9693003544236374, 1.9745170898028677, 1.979692801535906, 1.9848282345629915, 1.9899241127853762, 1.994981139867362, 2.0, 2.0049813586286422], [0.0, 0.6421141351518171, 0.7636066981663597, 0.8450697266227711, 0.9080865185231702, 0.9601845894041878, 1.0049629315732038, 1.04444780217279, 1.0799029488658045, 1.112174306341096, 1.1418583454354265, 1.1693927625557354, 1.1951090685408468, 1.219264891125735, 1.2420647575928363, 1.2636739857523107, 1.2842282703036343, 1.3038404810405297, 1.3226055982240474, 1.3406043695144154, 1.3579060687170441, 1.3745706103249549, 1.3906501934639681, 1.4061905963732368, 1.4212322075130495, 1.4358108555129505, 1.449958483599742, 1.4637037024489812, 1.4770722470235311, 1.4900873568745734, 1.502770094900495, 1.5151396162234685, 1.5272133963327195, 1.5390074257343278, 1.5505363768819687, 1.561813748028264, 1.5728519877504674, 1.5836626032071637, 1.5942562546302799, 1.60464283811593, 1.6148315584236828, 1.6248309932078528, 1.634649149872069, 1.644293516048505, 1.6537711045472614, 1.6630884934927144, 1.6722518622569726, 1.6812670237117344, 1.6901394532455423, 1.698874314931026, 1.7074764851741444, 1.7159505741329184, 1.7243009451553697, 1.732531732454193, 1.740646857208154, 1.748650042256635, 1.75654482553344, 1.7643345723684827, 1.7720224867708414, 1.7796116217935372, 1.7871048890689831, 1.7945050675941052, 1.801814811835441, 1.80903665921692, 1.8161730370463405, 1.8232262689306922, 1.8301985807252843, 1.837092106057081, 1.8439088914585777, 1.850650901144984, 1.8573200214642784, 1.8639180650468632, 1.8704467746790285, 1.8769078269221715, 1.8833028354976902, 1.8896333544556798, 1.8959008811439184, 1.9021068589921832, 1.9082526801256237, 1.9143396878197294, 1.9203691788083757, 1.9263424054554514, 1.9322605777997164, 1.938124865481734, 1.9439363995610137, 1.9496962742308461, 1.955405548437723, 1.9610652474116923, 1.966676364113512, 1.9722398606040152, 1.9777566693406925, 1.9832276944061233, 1.988653812672542, 1.9940358749065195, 1.9993747068174434, 2.004671110053224, 2.0099258631464076, 2.015139722413657, 2.0203134228113497, 2.025447678749862, 2.0305431848689306, 2.0356006167763194], [0.0, 0.6513555624326306, 0.7745966692414834, 0.8572321289096398, 0.9211558703193814, 0.9740037464252967, 1.0194265469082735, 1.0594796911843958, 1.0954451150103321, 1.128180927925918, 1.158292185288269, 1.1862228829132528, 1.2123093028059742, 1.236812780528175, 1.2599407869573689, 1.281861019188702, 1.3027111248652612, 1.3226055982240474, 1.3416407864998738, 1.3598985994884667, 1.3774493079968597, 1.3943536888187151, 1.41066469233948, 1.4264287556473267, 1.4416868484808527, 1.4564753151219703, 1.4708265585304046, 1.4847696011519298, 1.498330548331831, 1.5115329740892764, 1.5243982444638442, 1.5369457902618242, 1.5491933384829668, 1.5611571097717194, 1.5728519877504674, 1.584291664941221, 1.5954887690834967, 1.6064549729490671, 1.6172010901939204, 1.6277371593406456, 1.6380725176254403, 1.6482158661538315, 1.658175327573506, 1.6679584972800467, 1.6775724890132342, 1.6870239755710472, 1.6963192252602786, 1.7054641346125685, 1.7144642578192797, 1.7233248332753461, 1.7320508075688772, 1.740646857208154, 1.7491174083393233, 1.7574666546754452, 1.7656985738296271, 1.7738169422210552, 1.7818253487021418, 1.7897272070372605, 1.797525767348191, 1.8052241266280664, 1.8128252384140608, 1.8203319216989462, 1.8277468691528411, 1.8350726547187575, 1.8423117406387628, 1.8494664839616353, 1.8565391425776125, 1.8635318808212185, 1.8704467746790285, 1.8772858166356072, 1.8840509201876072, 1.8907439240531478, 1.8973665961010275, 1.9039206370220298, 1.9104076837625343, 1.9168293127388174, 1.9231870428487672, 1.9294823382962738, 1.9357166112422137, 1.9418912242947493, 1.9480074928505935, 1.9540666872978918, 1.960070035090509, 1.9660187227026953, 1.971913897472381, 1.9777566693406925, 1.983548112494678, 1.9892892669196895, 1.994981139867362, 2.0006247072446897, 2.006220914929266, 2.0117706800153967, 2.017274891995427, 2.0227344138803187, 2.028150083263225, 2.0335227133295235, 2.038853093816547, 2.04414199192601, 2.04939015319192, 2.0545983023065815, 2.0597671439071177, 2.0648973633247656], [0.0, 0.6602195804079635, 0.7851378224852613, 0.8688978326173193, 0.9336914847572161, 0.9872585449014338, 1.0332994847589596, 1.0738976950655401, 1.1103525568907362, 1.1435338574183984, 1.1740548859440185, 1.2023656804317462, 1.2288070992040006, 1.2536440342258928, 1.2770867797569627, 1.2993053150100684, 1.320439160815927, 1.3406043695144154, 1.3598985994884667, 1.3784048752090223, 1.396194423768335, 1.4133288490453375, 1.4298618220045207, 1.4458404116764367, 1.461306145339252, 1.4762958618685948, 1.4908424051821463, 1.5049751926796753, 1.5187206849628934, 1.5321027768596667, 1.5451431251708252, 1.5578614251281528, 1.5702756449705226, 1.5824022260821626, 1.5942562546302799, 1.6058516094725332, 1.6172010901939204, 1.6283165284159498, 1.6392088849530073, 1.6498883349376223, 1.6603643426724284, 1.6706457276725586, 1.680740723123322, 1.6906570277827762, 1.7004018521985302, 1.7099819599758033, 1.7194037047240815, 1.7286730632183713, 1.7377956652346387, 1.7467768204548835, 1.7556215427832071, 1.7643345723684827, 1.772920395590378, 1.7813832632323923, 1.7897272070372607, 1.7979560548158353, 1.8060734442596786, 1.8140828355896175, 1.8219875231569418, 1.8297906461004336, 1.8374951981506855, 1.8451040366629305, 1.8526198909506784, 1.8600453699846249, 1.8673829695144322, 1.8746350786649426, 1.881803986053052, 1.8888918854667822, 1.8959008811439186, 1.9028329926838916, 1.9096901596233076, 1.9164742457026112, 1.9231870428487672, 1.9298302748965297, 1.9364056010687778, 1.9429146192345599, 1.949358868961793, 1.9557398343800885, 1.9620589468678131, 1.9683175875762793, 1.9745170898028677, 1.9806587412238905, 1.986743785997105, 1.9927734267429793, 1.9987488264130728, 2.004671110053224, 2.0105413664686305, 2.0163606497973583, 2.0221299809982973, 2.0278503492591406, 2.0335227133295235, 2.039148002784094, 2.0447271192199157, 2.0502609373922973, 2.0557503062928357, 2.0611960501732, 2.066598969517919, 2.071959841969225, 2.077279423206778, 2.082558447784909, 2.087797629929844, 2.0929976642991988], [0.0, 0.668740304976422, 0.7952707287670506, 0.8801117367933934, 0.9457416090031757, 0.9999999999999999, 1.0466351393921054, 1.0877573059372772, 1.1246826503806981, 1.158292185288269, 1.189207115002721, 1.2178832856309065, 1.2446659545769567, 1.2698234324738655, 1.2935687276168015, 1.3160740129524924, 1.337480609952844, 1.3579060687170441, 1.3774493079968597, 1.396194423768335, 1.414213562373095, 1.4315691227432643, 1.4483154685151656, 1.464500276187315, 1.4801656089845705, 1.4953487812212205, 1.5100830606950981, 1.5243982444638442, 1.5383211346269174, 1.5518759343963227, 1.565084580073287, 1.5779670210741878, 1.5905414575341013, 1.602824543028034, 1.6148315584236828, 1.6265765616977856, 1.63807251762544, 1.6493314105258192, 1.6603643426724282, 1.6711816205169885, 1.6817928305074292, 1.6922069059826197, 1.7024321863844938, 1.7124764698304722, 1.722347059926734, 1.7320508075688772, 1.741594148365405, 1.7509831362269535, 1.7602234735867868, 1.7693205386531028, 1.7782794100389228, 1.7871048890689831, 1.7958015200236968, 1.8043736085467281, 1.8128252384140608, 1.8211602868378718, 1.829382438457389, 1.8374951981506853, 1.8455019027856028, 1.853405732014319, 1.8612097182041991, 1.8689167555872028, 1.8765296087010728, 1.8840509201876074, 1.8914832180063514, 1.8988289221159416, 1.906090350669923, 1.9132697257691151, 1.9203691788083757, 1.927390755451873, 1.9343364202676692, 1.9412080610494473, 1.9480074928505935, 1.954736461753492, 1.961396648394778, 1.9679896712654303, 1.9745170898028677, 1.9809804072907224, 1.9873810735805804, 1.993720487648747, 1.9999999999999998, 2.006220914929266, 2.0123844926512717, 2.0184919513073796, 2.0245444688580787, 2.0305431848689306, 2.03648920219714, 2.042383588585367, 2.0482273781688902, 2.0540215729017546, 2.0597671439071177, 2.0654650327566206, 2.0711161526832442, 2.0767213897317967, 2.082281603850872, 2.087797629929844, 2.093270278784211, 2.0987003380923746, 2.1040885732867167, 2.1094357284016496, 2.114742526881128, 2.1200096723479462], [0.0, 0.6769472427712399, 0.8050304775850328, 0.8909126743510708, 0.9573479717381596, 1.0122722344290394, 1.0594796911843958, 1.1011065185976396, 1.1384850195244434, 1.172507018523451, 1.203801343502716, 1.2328294348193778, 1.259940786957369, 1.2854070033206724, 1.309443706292189, 1.3322251817654118, 1.3538944855424797, 1.3745706103249549, 1.3943536888187151, 1.4133288490453375, 1.4315691227432643, 1.449137674618944, 1.4660895354719874, 1.4824729668980785, 1.498330548331831, 1.5137000520175456, 1.5286151540232695, 1.5431060170831206, 1.5571997722182047, 1.5709209196680187, 1.584291664941221, 1.5973322022781031, 1.6100609551700655, 1.6224947815686919, 1.634649149872069, 1.6465382905797215, 1.658175327573506, 1.66957239224697, 1.680740723123322, 1.691690753137475, 1.702432186384494, 1.7129740658352777, 1.7233248332753464, 1.7334923825224455, 1.7434841068143216, 1.7533069411223694, 1.7629674000343882, 1.772471611756025, 1.7818253487021416, 1.7910340550835677, 1.800102871839254, 1.80903665921692, 1.8178400172654527, 1.8265173044683851, 1.8350726547187572, 1.8435099928108027, 1.8518330486025056, 1.8600453699846247, 1.868150334775826, 1.876151161649724, 1.8840509201876072, 1.8918525401401285, 1.8995588199720859, 1.907172434756397, 1.914695943476319, 1.9221317957887885, 1.929482338296274, 1.9367498203697375, 1.943936399561014, 1.9510441466391415, 1.9580750502818227, 1.965031021450187, 1.971913897472381, 1.9787254458591215, 1.9854673678722108, 1.9921413018651277, 1.9987488264130728, 2.005291463248328, 2.011770680015397, 2.0181878928591512, 2.0245444688580787, 2.0308417283137197, 2.037080946906452, 2.0432633577269526, 2.04939015319192, 2.0554624868519302, 2.0614814750987107, 2.0674481987785094, 2.0733637047177553, 2.0792290071667088, 2.0850450891663783, 2.0908129038435934, 2.0965333756387428, 2.1022074014703853, 2.1078358518406057, 2.1134195718847355, 2.1189593823687916, 2.1244560806377484, 2.1299104415175543, 2.135323218173586, 2.1406951429280725, 2.146026928038831], [0.0, 0.6848661007688606, 0.8144476398584994, 0.9013344775740003, 0.9685469281169012, 1.0241136890844451, 1.0718733737282617, 1.1139871474119825, 1.151802898130648, 1.1862228829132528, 1.2178832856309068, 1.247250944521753, 1.2746794424196197, 1.3004435599166835, 1.3247614417239146, 1.347809412512947, 1.3697322015377211, 1.3906501934639681, 1.41066469233948, 1.4298618220045207, 1.4483154685151656, 1.4660895354719874, 1.4832396974191329, 1.4998147805113802, 1.515857862273113, 1.5314071568043932, 1.5464967341123872, 1.5611571097717196, 1.575415732179342, 1.5892973881759884, 1.602824543028034, 1.616017627205879, 1.6288952797169989, 1.64147455571553, 1.6537711045472616, 1.665799323178612, 1.6775724890132344, 1.6891028753564483, 1.7004018521985305, 1.7114799745177747, 1.7223470599267343, 1.7330122571800355, 1.7434841068143219, 1.7537705949883926, 1.7638792014253157, 1.7738169422210555, 1.7835904081703775, 1.793205799166037, 1.8026689551480006, 1.8119853840129068, 1.821160286837872, 1.8301985807252845, 1.8391049195349223, 1.8478837127354024, 1.8565391425776128, 1.8650751797676193, 1.8734955977948946, 1.881803986053052, 1.890003761874127, 1.898098181583441, 1.9060903506699232, 1.9139832331561426, 1.9217796602430461, 1.9294823382962742, 1.9370938562338025, 1.9446166923683978, 1.9520532207528385, 1.9594057170709935, 1.9666763641135123, 1.9738672568730735, 1.9809804072907224, 1.9880177486818125, 1.9949811398673623, 2.001872369034244, 2.0086931573454425, 2.0154451623197245, 2.0221299809982978, 2.0287491529145085, 2.0353041628812134, 2.0417964436091975, 2.0482273781688902, 2.0545983023065815, 2.0609105066254236, 2.0671652386406607, 2.0733637047177553, 2.079507071901399, 2.085596469642752, 2.091632991431688, 2.0976176963403033, 2.1035516104834504, 2.1094357284016496, 2.115271014371307, 2.12105840364682, 2.126798803638806, 2.132493095032392, 2.138142132849214, 2.1437467474565235, 2.149307745526554, 2.1548259109490866, 2.160302005699947, 2.1657367706679937, 2.1711309264429612], [0.0, 0.6925194237934933, 0.823549026052807, 0.9114068171194506, 0.9793703613355593, 1.0355580763416221, 1.0838514715804344, 1.126435863262952, 1.164674201923033, 1.1994788272386536, 1.231493032383988, 1.261188872476556, 1.2889238816096222, 1.314975911026152, 1.339565543186535, 1.362871073176282, 1.3850388475869866, 1.4061905963732368, 1.4264287556473267, 1.4458404116764367, 1.464500276187315, 1.4824729668980785, 1.4998147805113802, 1.5165750888103104, 1.5327974507070876, 1.5485205073412365, 1.563778709449485, 1.5786029136155246, 1.5930208749699124, 1.6070576573443134, 1.6207359770526288, 1.634076492874106, 1.647098052105614, 1.6598179004912506, 1.6722518622569729, 1.684414495254129, 1.6963192252602788, 1.7079784627339318, 1.7194037047240818, 1.7306056241600476, 1.7415941483654052, 1.75237852833137, 1.7629674000343885, 1.7733688388779358, 1.7835904081703775, 1.7936392024119798, 1.8035218860491045, 1.8132447282578046, 1.8228136342389012, 1.83223417343933, 1.8415116050578217, 1.8506509011449843, 1.8596567675671005, 1.868533663068241, 1.8772858166356075, 1.8859172433475835, 1.8944317588620798, 1.9028329926838916, 1.9111244003334624, 1.9193092745252844, 1.9273907554518732, 1.9353718402585094, 1.94325539178458, 1.951044146639142, 1.9587407226711187, 1.9663476258882207, 1.9738672568730735, 1.981301916740128, 1.9886538126725424, 1.9959250630743677, 2.003117702369927, 2.010233685479216, 2.017274891995427, 2.024243130088275, 2.0311401401546014, 2.0379675982358108, 2.0447271192199157, 2.0514202598444236, 2.058048521514854, 2.0646133529524175, 2.0711161526832442, 2.07755827138048, 2.0839410140696626, 2.090265642206917, 2.096533375638743, 2.102745394451461, 2.1089028407177555, 2.115006820147162, 2.12105840364682, 2.1270586287983337, 2.133008501256132, 2.138908996072332, 2.1447610589527217, 2.1505656074481596, 2.156323532085357, 2.1620356974407473, 2.1677029431608688, 2.1733260849324516, 2.178905915405181, 2.1844432050699005, 2.1899387030948425, 2.195393138122272], [0.0, 0.6999271023161167, 0.8323582900575635, 0.9211558703193815, 0.9898464007679532, 1.0466351393921056, 1.0954451150103324, 1.1384850195244434, 1.1771323825530848, 1.2123093028059742, 1.2446659545769567, 1.2746794424196195, 1.3027111248652612, 1.3290418252506464, 1.35389448554248, 1.3774493079968595, 1.3998542046322333, 1.4212322075130495, 1.4416868484808527, 1.461306145339252, 1.4801656089845705, 1.498330548331831, 1.515857862273113, 1.5327974507070876, 1.5491933384829668, 1.5650845800732875, 1.5805059947242717, 1.595488769083497, 1.610060955170066, 1.6242478849161492, 1.63807251762544, 1.6515557330581283, 1.664716580115127, 1.6775724890132344, 1.6901394532455423, 1.7024321863844938, 1.71446425781928, 1.726248210759469, 1.7377956652346387, 1.7491174083393233, 1.760223473586787, 1.771123210923403, 1.7818253487021418, 1.7923380487067173, 1.8026689551480006, 1.812825238414061, 1.8228136342389012, 1.8326404788581236, 1.842311740638763, 1.8518330486025056, 1.8612097182041993, 1.8704467746790288, 1.8795489742305571, 1.8885208232967414, 1.8973665961010278, 1.906090350669923, 1.9146959434763193, 1.9231870428487672, 1.9315671412704056, 1.9398395666769344, 1.9480074928505937, 1.9560739489962538, 1.9640418285762609, 1.9719138974723813, 1.9796928015359063, 1.9873810735805804, 1.9949811398673623, 2.0024953261250538, 2.0099258631464076, 2.017274891995427, 2.0245444688580787, 2.031736569565567, 2.038853093816547, 2.045895869122197, 2.0528666544958774, 2.0597671439071177, 2.066598969517919, 2.0733637047177553, 2.080062866972243, 2.086697920499143, 2.0932702787842112, 2.09978130694835, 2.1062323239765757, 2.1126246048184423, 2.1189593823687916, 2.1252378493369832, 2.1314611600121216, 2.1376304319311945, 2.1437467474565235, 2.1498111552684196, 2.1558246717785052, 2.1617882824687458, 2.1677029431608688, 2.1735695812205065, 2.1793890967000746, 2.18516236342413, 2.1908902300206647, 2.196573520901572, 2.2022130371952793, 2.207809557634348, 2.2133638394006434, 2.218876618930505], [0.0, 0.7071067811865476, 0.8408964152537146, 0.9306048591020997, 1.0, 1.057371263440564, 1.1066819197003217, 1.1501633168956031, 1.1892071150027212, 1.2247448713915892, 1.2574334296829355, 1.2877547884506972, 1.3160740129524926, 1.3426748071413253, 1.3677823998673806, 1.3915788418568702, 1.4142135623730951, 1.4358108555129505, 1.4564753151219703, 1.4762958618685948, 1.4953487812212205, 1.5137000520175456, 1.5314071568043932, 1.5485205073412365, 1.5650845800732875, 1.5811388300841898, 1.59671843378737, 1.611854897735313, 1.626576561697786, 1.6409090174556458, 1.6548754598234365, 1.6684969827407574, 1.6817928305074292, 1.6947806121350972, 1.7074764851741446, 1.7198953141251965, 1.7320508075688774, 1.7439556373798932, 1.7556215427832074, 1.7670594215246977, 1.778279410038923, 1.7892909541816906, 1.8001028718392544, 1.8107234085168835, 1.821160286837872, 1.8314207507423532, 1.8415116050578217, 1.8514392510154154, 1.8612097182041993, 1.8708286933869709, 1.880301546543197, 1.88963335445568, 1.898828922115942, 1.9078928021878638, 1.9168293127388176, 1.925642553421541, 1.9343364202676696, 1.9429146192345599, 1.9513806786303782, 1.9597379605279643, 1.9679896712654306, 1.9761388711204808, 1.984188483235881, 1.992141301865128, 2.0, 2.007767136435218, 2.0154451623197245, 2.023036427239071, 2.030543184868931, 2.0379675982358103, 2.0453117446175235, 2.052577620112862, 2.0597671439071177, 2.066882162257628, 2.0739244522212745, 2.080895725143909, 2.087797629929844, 2.0946317561079946, 2.101399636709763, 2.1081027509724937, 2.114742526881128, 2.121320343559643, 2.1278375335228743, 2.1342953847984933, 2.1406951429280725, 2.1470380128554885, 2.153325160710257, 2.1595577154927827, 2.1657367706679937, 2.171863385673303, 2.177938587346431, 2.1839633712781743, 2.1899387030948425, 2.1958655196747543, 2.201744730302841, 2.2075772177671347, 2.2133638394006434, 2.2191054280718734, 2.2248027931270298, 2.230456721286719, 2.23606797749979, 2.2416373057567642], [0.0, 0.7140741917751113, 0.8491821094987798, 0.9397744871152784, 1.0098534065489688, 1.0677899723724407, 1.1175865065755222, 1.161496343654686, 1.2009248561777692, 1.2368127805281748, 1.2698234324738655, 1.3004435599166833, 1.3290418252506462, 1.355904727879147, 1.381259715923798, 1.405290633930629, 1.4281483835502227, 1.449958483599742, 1.4708265585304046, 1.4908424051821463, 1.5100830606950981, 1.5286151540232695, 1.5464967341123872, 1.563778709449485, 1.5805059947242717, 1.59671843378737, 1.6124515496597098, 1.6277371593406456, 1.642603881843218, 1.6570775611145052, 1.6711816205169885, 1.6849373618374297, 1.6983642189975596, 1.7114799745177744, 1.7243009451553697, 1.7368421418769382, 1.7491174083393233, 1.7611395412783633, 1.772920395590378, 1.7844709764011661, 1.7958015200236968, 1.806921565387635, 1.8178400172654527, 1.8285652024087349, 1.839104919534922, 1.8494664839616353, 1.8596567675671003, 1.8696822346563884, 1.879548974230557, 1.8892627290863886, 1.8988289221159416, 1.9082526801256234, 1.9175388554524904, 1.9266920456196721, 1.9357166112422135, 1.9446166923683976, 1.9533962234190436, 1.962058946867813, 1.9706084257887257, 1.9790480553824932, 1.9873810735805801, 1.995610570814851, 2.003739499030986, 2.0117706800153967, 2.0197068130979376, 2.027550482286173, 2.035304162881213, 2.0429702276200308, 2.0505509523846825, 2.0580485215148534, 2.0654650327566206, 2.0728025018771485, 2.0800628669722427, 2.0872479924911636, 2.094359673000858, 2.101399636709763, 2.108369548769516, 2.115271014371307, 2.1221055816521197, 2.128874744424825, 2.1355799447448813, 2.142222575325334, 2.14880398181083, 2.1553254649205007, 2.1617882824687453, 2.1681936512722433, 2.1745427489508584, 2.1808367156294954, 2.187076655547436, 2.1932636385811617, 2.1993987016862424, 2.2054828502634343, 2.211517059453757, 2.217502275366972, 2.2234394162475644, 2.2293293735820354, 2.2351730131510443, 2.240971176029689, 2.2467246795389917, 2.252434318151437, 2.2581008643532257, 2.2637250694657207], [0.0, 0.7208434242404264, 0.85723212890964, 0.9486832980505139, 1.0194265469082735, 1.0779123358892526, 1.128180927925918, 1.172507018523451, 1.2123093028059742, 1.2485374350863452, 1.2818610191887023, 1.3127714172548886, 1.341640786499874, 1.3687583422648133, 1.3943536888187151, 1.4186124135047637, 1.4416868484808527, 1.4637037024489812, 1.4847696011519298, 1.5049751926796753, 1.5243982444638442, 1.5431060170831206, 1.5611571097717196, 1.5786029136155246, 1.595488769083497, 1.611854897735313, 1.6277371593406456, 1.6431676725154987, 1.6581753275735063, 1.672786213455457, 1.6870239755710472, 1.7009101176422836, 1.71446425781928, 1.7277043471959723, 1.7406468572081542, 1.7533069411223694, 1.7656985738296274, 1.777834673375402, 1.789727207037261, 1.801387284266654, 1.8128252384140613, 1.8240506988356506, 1.8350726547187575, 1.8458995117503458, 1.8565391425776128, 1.8669989318654352, 1.8772858166356075, 1.8874063224730853, 1.8973665961010278, 1.907172434756397, 1.9168293127388176, 1.9263424054554517, 1.9357166112422137, 1.944956571205524, 1.954066687297892, 1.963051138814152, 1.9719138974723813, 1.9806587412238905, 1.98928926691969, 1.9978089019460852, 2.0062209149292665, 2.0145284255975655, 2.022734413880319, 2.03084172831372, 2.038853093816547, 2.0467711188920665, 2.0545983023065815, 2.0623370392899774, 2.0699896272990626, 2.07755827138048, 2.0850450891663788, 2.092452115532857, 2.09978130694835, 2.1070345455365995, 2.1142136428765665, 2.121320343559643, 2.1283563285226585, 2.135323218173586, 2.1422225753253343, 2.149055907951721, 2.1558246717785052, 2.162530272721279, 2.1691740691810413, 2.175757374207393, 2.182281457538478, 2.188747547526072, 2.1951568329535602, 2.2015104647539276, 2.207809557634348, 2.2140551916134474, 2.2202484134768556, 2.226390238156261, 2.232481650036758, 2.2385236041969763, 2.244517027586113, 2.250462820141724, 2.256361855851836, 2.262214983764716, 2.26802302894937, 2.2737867934096694, 2.279507056954778, 2.285184578028384], [0.0, 0.727427152512826, 0.8650615454144222, 0.9573479717381597, 1.0287373447220802, 1.0877573059372772, 1.1384850195244434, 1.1832159566199234, 1.223381769812505, 1.259940786957369, 1.2935687276168018, 1.3247614417239146, 1.35389448554248, 1.3812597159237983, 1.4070888341971637, 1.4315691227432645, 1.454854305025652, 1.4770722470235311, 1.498330548331831, 1.5187206849628934, 1.5383211346269174, 1.5571997722182047, 1.575415732179342, 1.5930208749699124, 1.610060955170066, 1.626576561697786, 1.642603881843218, 1.6581753275735063, 1.6733200530681513, 1.6880643855478388, 1.7024321863844938, 1.7164451557015294, 1.7301230908288443, 1.7434841068143219, 1.7565448255334402, 1.7693205386531028, 1.7818253487021418, 1.7940722917112946, 1.8060734442596789, 1.8178400172654527, 1.8293824384573891, 1.8407104251401099, 1.8518330486025059, 1.8627587913037735, 1.8734955977948946, 1.8840509201876074, 1.8944317588620798, 1.9046446990038355, 1.9146959434763193, 1.9245913424647914, 1.9343364202676694, 1.943936399561014, 1.953396223419044, 1.9627205753371124, 1.9719138974723813, 1.9809804072907227, 1.9899241127853764, 1.998748826413073, 2.0074581778761864, 2.016055625864603, 2.0245444688580787, 2.0329278550785728, 2.0412087916722124, 2.04939015319192, 2.0574746894441605, 2.065465032756621, 2.0733637047177553, 2.0811731224339662, 2.08889560434558, 2.096533375638743, 2.1040885732867167, 2.1115632507508724, 2.1189593823687916, 2.126278867454344, 2.133523534132309, 2.1406951429280725, 2.1477953901310802, 2.1548259109490866, 2.1617882824687458, 2.1686840264367557, 2.1755146118745543, 2.182281457538478, 2.1889859342363023, 2.1956293670101927, 2.2022130371952797, 2.208738184362327, 2.2152060081523164, 2.2216176700101276, 2.227974294823965, 2.2342769724766613, 2.2405267593145264, 2.2467246795389917, 2.252871726525904, 2.2589688640769774, 2.2650170276075774, 2.2710171252747196, 2.2769700390488867, 2.2828766257330146, 2.2887377179317685, 2.2945541249740162, 2.3003266337912063, 2.306056009754172], [0.0, 0.7338368215846426, 0.8726839694794393, 0.9657835706352028, 1.0378019856537666, 1.0973419967718494, 1.148516693752116, 1.1936417741003793, 1.2341615053034112, 1.2710426594494582, 1.3049669101523764, 1.33643447648928, 1.3658242239094178, 1.3934305809385557, 1.4194872905246418, 1.444183285272829, 1.4676736431692852, 1.4900873568745734, 1.5115329740892764, 1.5321027768596667, 1.5518759343963227, 1.5709209196680187, 1.5892973881759884, 1.6070576573443134, 1.6242478849161492, 1.6409090174556458, 1.6570775611145052, 1.672786213455457, 1.6880643855478388, 1.7029386365926404, 1.7174330382144527, 1.7315694817456764, 1.7453679389588785, 1.75884668452131, 1.7720224867708416, 1.7849107721157376, 1.797525767348191, 1.8098806233649336, 1.8219875231569418, 1.8338577764265276, 1.845501902785603, 1.8569297051620812, 1.868150334775826, 1.8791723488285783, 1.8900037618741268, 1.9006520916879264, 1.9111244003334622, 1.9214273310211205, 1.9315671412704056, 1.9415497328150402, 1.951380678630378, 1.9610652474116927, 1.970608425788726, 1.9800149385250942, 1.9892892669196898, 1.9984356656002646, 2.0074581778761864, 2.0163606497973583, 2.0251467430490013, 2.033819946796984, 2.042383588585367, 2.050840844376428, 2.0591947478135326, 2.06744819877851, 2.075603971307533, 2.083664720922846, 2.091632991431688, 2.09951122123861, 2.1073017492127, 2.115006820147162, 2.1226285898450357, 2.1301691298616108, 2.1376304319311945, 2.145014412103317, 2.152322914611139, 2.159557715492783, 2.16672052598442, 2.173812995702313, 2.180836715629496, 2.1877932209214217, 2.194683993543699, 2.2015104647539276, 2.208274017438652, 2.2149759883155467, 2.2216176700101276, 2.228200313015543, 2.2347251275433204, 2.241193285272322, 2.24760592100262, 2.253964134220466, 2.260268990580086, 2.266521523307584, 2.272722734531862, 2.2788735965471, 2.2849750530110056, 2.29102802008275, 2.297033387504232, 2.302992019628042, 2.308904756395278, 2.3147724142661468, 2.320595787106084, 2.3263756470299297], [0.0, 0.7400828044922851, 0.8801117367933933, 0.9740037464252967, 1.0466351393921054, 1.1066819197003215, 1.158292185288269, 1.203801343502716, 1.2446659545769565, 1.281861019188702, 1.3160740129524924, 1.3478094125129467, 1.3774493079968597, 1.4052906339306293, 1.4315691227432643, 1.45647531512197, 1.4801656089845703, 1.502770094900495, 1.5243982444638442, 1.5451431251708252, 1.565084580073287, 1.584291664941221, 1.602824543028034, 1.6207359770526288, 1.63807251762544, 1.6548754598234365, 1.6711816205169885, 1.6870239755710472, 1.7024321863844938, 1.7174330382144527, 1.732050807568877, 1.74630757210618, 1.7602234735867865, 1.7738169422210552, 1.7871048890689831, 1.8001028718392538, 1.8128252384140608, 1.8252852516227527, 1.8374951981506853, 1.8494664839616353, 1.8612097182041991, 1.872734787242987, 1.8840509201876072, 1.8951667470736167, 1.9060903506699227, 1.9168293127388174, 1.927390755451873, 1.9377813785625346, 1.9480074928505935, 1.9580750502818227, 1.9679896712654303, 1.9777566693406925, 1.9873810735805801, 1.9968676489630897, 2.006220914929266, 2.015445162319724, 2.0245444688580787, 2.033522713329523, 2.042383588585367, 2.0511306134891862, 2.0597671439071177, 2.068296382833342, 2.0767213897317967, 2.0850450891663788, 2.093270278784211, 2.1013996367097625, 2.109435728401649, 2.1173810130186723, 2.1252378493369832, 2.133008501256132, 2.140695142928072, 2.1482998635399415, 2.1558246717785052, 2.1632715000015685, 2.1706422081393097, 2.177938587346431, 2.1851623634241295, 2.1923152000292214, 2.1993987016862424, 2.2064144166169766, 2.213363839400643, 2.2202484134768556, 2.2270695335024673, 2.2338285475724984, 2.2405267593145264, 2.247165429865153, 2.2537457797365072, 2.2602689905800855, 2.266736206854704, 2.2731485374047877, 2.2795070569547775, 2.2858128075249846, 2.2920667997738366, 2.2982700142711043, 2.3044234027063477, 2.3105278890365413, 2.316584370576538, 2.3225937190357833, 2.3285567815044543, 2.3344743813919835, 2.3403473193207156, 2.3461763739772747], [0.0, 0.7461745347323253, 0.8873560657375262, 0.9820209142881303, 1.0552501469158886, 1.1157911810902938, 1.167826258352922, 1.2137100091313509, 1.2549109828200413, 1.2924122054704554, 1.3269068114098672, 1.3589034297042373, 1.3887872955203007, 1.4168577874961457, 1.4433525784090198, 1.4684637773145044, 1.4923490694646506, 1.5151396162234685, 1.5369457902618242, 1.5578614251281528, 1.5779670210741878, 1.5973322022781031, 1.616017627205879, 1.634076492874106, 1.6515557330581283, 1.6684969827407574, 1.6849373618374297, 1.7009101176422836, 1.7164451557015294, 1.7315694817456764, 1.74630757210618, 1.760681686165901, 1.7747121314750525, 1.7884174899457608, 1.8018148118354411, 1.8149197829105617, 1.8277468691528413, 1.8403094425599245, 1.8526198909506784, 1.8646897141730423, 1.876529608701073, 1.8881495422754992, 1.8995588199720859, 1.9107661428614797, 1.921779660243046, 1.9326070162856752, 1.9432553917845798, 1.9537315416398595, 1.9640418285762606, 1.9741922535510608, 1.984188483235881, 1.9940358749065197, 2.003739499030986, 2.0133041598085097, 2.0227344138803187, 2.0320345874055676, 2.041208791672212, 2.050260937392297, 2.0591947478135326, 2.068013770763778, 2.0767213897317967, 2.0853208340760854, 2.0938151884434775, 2.1022074014703858, 2.110500293831777, 2.1186965656961565, 2.126798803638806, 2.134809487060224, 2.1427309941519956, 2.1505656074481596, 2.158315518996434, 2.1659828351803623, 2.173569581220506, 2.181077705380191, 2.1885090828989533, 2.195865519674754, 2.203148755714112, 2.210360468367647, 2.2175022753669724, 2.2245757376775126, 2.2315823621805877, 2.238523604196976, 2.245400869863155, 2.2522155183705133, 2.2589688640769774, 2.2656621784997513, 2.2722966921971777, 2.2788735965470996, 2.2853940454285424, 2.291859156812992, 2.2982700142711043, 2.3046276684002125, 2.3109331381776226, 2.3171874122443183, 2.3233914501233563, 2.3295461833769373, 2.335652516705844, 2.3417113289946903, 2.3477234743061772, 2.353689782827341, 2.359611061770567, 2.365488096231962], [0.0, 0.7521206186172786, 0.8944271909999159, 0.989846400767953, 1.0636591793889976, 1.1246826503806981, 1.1771323825530846, 1.223381769812505, 1.2649110640673518, 1.3027111248652612, 1.337480609952844, 1.369732201537721, 1.3998542046322333, 1.4281483835502227, 1.4548543050256517, 1.4801656089845703, 1.5042412372345573, 1.5272133963327195, 1.5491933384829668, 1.5702756449705226, 1.5905414575341013, 1.6100609551700655, 1.6288952797169989, 1.647098052105614, 1.664716580115127, 1.6817928305074292, 1.6983642189975596, 1.71446425781928, 1.7301230908288443, 1.7453679389588785, 1.7602234735867865, 1.7747121314750525, 1.7888543819998317, 1.8026689551480006, 1.8161730370463407, 1.8293824384573887, 1.8423117406387628, 1.8549744221463136, 1.8673829695144324, 1.879548974230557, 1.8914832180063517, 1.9031957480130535, 1.9146959434763193, 1.9259925748035172, 1.9370938562338025, 1.9480074928505935, 1.9587407226711184, 1.9693003544236372, 1.979692801535906, 1.9899241127853762, 2.0, 2.0099258631464076, 2.0197068130979376, 2.0293476923373186, 2.038853093816547, 2.0482273781688902, 2.0574746894441605, 2.0665989695179188, 2.075603971307533, 2.0844932709126422, 2.0932702787842112, 2.101938250014711, 2.110500293831777, 2.1189593823687916, 2.127318358777995, 2.1355799447448813, 2.143746747456523, 2.15182126607116, 2.159805897731609, 2.1677029431608688, 2.1755146118745543, 2.1832430270414687, 2.1908902300206643, 2.1984581846007054, 2.2059487809644573, 2.213363839400643, 2.220705113781472, 2.2279742948239645, 2.2351730131510443, 2.2423028421670907, 2.2493653007613963, 2.256361855851836, 2.263293924780049, 2.2701628775684908, 2.2769700390488867, 2.283716690870853, 2.290404073398753, 2.297033387504232, 2.3036057962612957, 2.3101224265502753, 2.316584370576538, 2.322992687309372, 2.329348403846066, 2.335652516705844, 2.3419059930579698, 2.348109771888037, 2.354264765106169, 2.3603718586005993, 2.3664319132398464, 2.3724457658265057, 2.378414230005442, 2.3843380971290036], [0.0, 0.7579289311365565, 0.9013344775740003, 0.9974905699336811, 1.0718733737282617, 1.133368103427352, 1.1862228829132528, 1.2328294348193778, 1.2746794424196195, 1.3127714172548886, 1.347809412512947, 1.3803100696313728, 1.41066469233948, 1.4391773753505155, 1.4660895354719874, 1.4915963080299905, 1.515857862273113, 1.5390074257343278, 1.5611571097717194, 1.5824022260821626, 1.602824543028034, 1.6224947815686919, 1.64147455571553, 1.6598179004912506, 1.6775724890132344, 1.6947806121350972, 1.7114799745177744, 1.7277043471959723, 1.7434841068143219, 1.75884668452131, 1.7738169422210552, 1.7884174899457608, 1.8026689551480006, 1.8165902124584952, 1.8301985807252845, 1.8435099928108025, 1.8565391425776128, 1.8692996126708072, 1.8818039860530522, 1.8940639437279883, 1.9060903506699232, 1.9178933316401892, 1.9294823382962742, 1.9408662087757294, 1.9520532207528385, 1.963051138814152, 1.9738672568730735, 1.9845084362388192, 1.9949811398673623, 2.005291463248328, 2.0154451623197245, 2.025447678749862, 2.0353041628812134, 2.0450194945929727, 2.0545983023065815, 2.0640449803306513, 2.0733637047177558, 2.082558447784909, 2.091632991431688, 2.100590939374452, 2.1094357284016496, 2.118170638743468, 2.126798803638806, 2.135323218173586, 2.1437467474565235, 2.152072134191548, 2.160302005699947, 2.168438880439912, 2.1764851740663906, 2.1844432050699005, 2.192315200029222, 2.2001032985094997, 2.207809557634348, 2.215435956357848, 2.2229843994599547, 2.230456721286719, 2.2378546892547706, 2.2451800071378294, 2.2524343181514372, 2.259619207850716, 2.266736206854704, 2.2737867934096694, 2.2807723958027863, 2.2876943946366195, 2.2945541249740162, 2.301352878362235, 2.308091904744454, 2.3147724142661468, 2.3213955789832528, 2.327962534478528, 2.3344743813919835, 2.340932186870885, 2.3473369859443625, 2.3536897828273413, 2.3599915521581276, 2.366243240173708, 2.3724457658265057, 2.3786000218460974, 2.384706875749129, 2.3907671708004723, 2.39678172692843, 2.402751341596634], [0.0, 0.7636066981663598, 0.9080865185231703, 1.0049629315732038, 1.0799029488658043, 1.1418583454354265, 1.1951090685408468, 1.2420647575928365, 1.2842282703036343, 1.3226055982240474, 1.3579060687170441, 1.3906501934639681, 1.4212322075130497, 1.4499584835997423, 1.4770722470235311, 1.502770094900495, 1.5272133963327197, 1.5505363768819687, 1.5728519877504674, 1.5942562546302799, 1.6148315584236828, 1.634649149872069, 1.6537711045472616, 1.6722518622569729, 1.6901394532455423, 1.7074764851741446, 1.7243009451553697, 1.7406468572081542, 1.7565448255334402, 1.7720224867708416, 1.7871048890689831, 1.8018148118354411, 1.8161730370463407, 1.8301985807252845, 1.8439088914585777, 1.8573200214642784, 1.8704467746790288, 1.8833028354976902, 1.8959008811439186, 1.9082526801256234, 1.9203691788083759, 1.9322605777997166, 1.943936399561014, 1.9554055484377233, 1.966676364113512, 1.9777566693406927, 1.9886538126725422, 1.9993747068174432, 2.0099258631464076, 2.0203134228113497, 2.0305431848689306, 2.040620631751871, 2.0505509523846825, 2.060339063202517, 2.069989627299062, 2.079507071901399, 2.08889560434558, 2.098159226705883, 2.1073017492127, 2.116326802578406, 2.1252378493369832, 2.134038194291349, 2.1427309941519956, 2.151319266441514, 2.1598058977316086, 2.1681936512722437, 2.17648517406639, 2.184683003438414, 2.1927895731393208, 2.2008072190278125, 2.2087381843623266, 2.2165846247358343, 2.224348612682192, 2.232032141980142, 2.2396371316786525, 2.2471654298651536, 2.254618817196276, 2.2619990102089815, 2.2693076644284034, 2.27654637728731, 2.283716690870853, 2.2908200944990793, 2.297858027158692, 2.3048318797945697, 2.31174299747073, 2.3185926814096187, 2.325382190917938, 2.332112745206556, 2.338785525111471, 2.34540167472227, 2.3519623029240355, 2.358468484858204, 2.3649212633074757, 2.371321650009509, 2.3776706269037833, 2.3839691473156965, 2.3902181370816935, 2.396418495618929, 2.402571096942758, 2.408676790635081, 2.414736402766418, 2.420750736774327], [0.0, 0.7691605673134586, 0.9146912192286943, 1.0122722344290391, 1.087757305937277, 1.150163316895603, 1.2038013435027157, 1.2510985509742438, 1.2935687276168015, 1.3322251817654118, 1.3677823998673804, 1.4007646793929585, 1.4315691227432643, 1.460504330965901, 1.4878152983881652, 1.5137000520175452, 1.5383211346269172, 1.561813748028264, 1.584291664941221, 1.6058516094725332, 1.6265765616977856, 1.6465382905797215, 1.665799323178612, 1.684414495254129, 1.7024321863844938, 1.7198953141251965, 1.7368421418769382, 1.7533069411223694, 1.7693205386531028, 1.7849107721157376, 1.8001028718392538, 1.8149197829105617, 1.8293824384573887, 1.8435099928108025, 1.8573200214642784, 1.8708286933869704, 1.8840509201876072, 1.8970004857904796, 1.9096901596233076, 1.9221317957887885, 1.9343364202676694, 1.9463143078586156, 1.9580750502818227, 1.9696276166458888, 1.9809804072907222, 1.9921413018651275, 2.003117702369927, 2.013916571791058, 2.0245444688580783, 2.0350075793887674, 2.0453117446175235, 2.0554624868519302, 2.0654650327566206, 2.075324334524993, 2.0850450891663783, 2.094631756107994, 2.1040885732867167, 2.1134195718847355, 2.1226285898450357, 2.131719284286912, 2.140695142928072, 2.149559494607946, 2.158315518996434, 2.1669662555631914, 2.175514611874554, 2.183963371278174, 2.1923152000292214, 2.2005726539065464, 2.2087381843623266, 2.2168141442444482, 2.2248027931270293, 2.232706302281114, 2.240526759314526, 2.248266172507171, 2.2559264748656567, 2.263509527918935, 2.271017125274719, 2.2784509959547, 2.2858128075249846, 2.293104169036802, 2.300326633791206, 2.3074817019403757, 2.3145708229370623, 2.3215953978427732, 2.3285567815044543, 2.3354562846086107, 2.342295175621143, 2.3490746826204902, 2.3557959950311154, 2.362460265263805, 2.3690686102687932, 2.37562211300724, 2.3821218238462203, 2.3885687618819693, 2.394963916195815, 2.401308247046888, 2.4076026870054315, 2.413848142030249, 2.4200454924935872, 2.426195594156533, 2.432299279097787, 2.438357356598474], [0.0, 0.7745966692414834, 0.9211558703193814, 1.0194265469082735, 1.0954451150103321, 1.158292185288269, 1.2123093028059742, 1.259940786957369, 1.3027111248652612, 1.3416407864998738, 1.3774493079968597, 1.41066469233948, 1.4416868484808527, 1.4708265585304046, 1.4983305483318308, 1.5243982444638442, 1.5491933384829668, 1.5728519877504674, 1.5954887690834967, 1.6172010901939204, 1.63807251762544, 1.658175327573506, 1.6775724890132344, 1.6963192252602788, 1.71446425781928, 1.7320508075688774, 1.7491174083393233, 1.7656985738296274, 1.7818253487021418, 1.797525767348191, 1.8128252384140608, 1.8277468691528413, 1.8423117406387628, 1.8565391425776128, 1.8704467746790288, 1.8840509201876072, 1.8973665961010278, 1.9104076837625343, 1.9231870428487674, 1.9357166112422135, 1.9480074928505937, 1.9600700350905091, 1.9719138974723813, 1.9835481124946783, 1.9949811398673623, 2.006220914929266, 2.017274891995427, 2.028150083263225, 2.038853093816547, 2.04939015319192, 2.0597671439071177, 2.069989627299062, 2.080062866972243, 2.0899918501200694, 2.09978130694835, 2.1094357284016496, 2.1189593823687916, 2.1283563285226585, 2.1376304319311945, 2.1467853755606696, 2.1558246717785052, 2.164751672950963, 2.173569581220506, 2.182281457538478, 2.1908902300206643, 2.1993987016862424, 2.207809557634348, 2.2161253717069958, 2.2243486126821925, 2.2324816500367577, 2.2405267593145264, 2.248486127132168, 2.256361855851836, 2.264155967947111, 2.271870410086274, 2.2795070569547775, 2.287067714836797, 2.2945541249740162, 2.301967966718197, 2.3093108604926607, 2.316584370576538, 2.32379000772445, 2.3309292316332666, 2.338003453266607, 2.345014037046902, 2.3519623029240355, 2.3588495283288893, 2.365676950019442, 2.3724457658265057, 2.3791571363056208, 2.385812186301152, 2.3924120064281724, 2.3989576544773072, 2.405450156747334, 2.4118905093099885, 2.418279679211108, 2.4246186056119483, 2.4309082008742458, 2.4371493515923475, 2.4433429195754983, 2.4494897427831783, 2.45559063621617], [0.0, 0.7799206709850829, 0.9274872110731568, 1.0264333272479387, 1.1029743904822287, 1.1662534248067802, 1.220641815839165, 1.2686006834079462, 1.311664992827256, 1.3508622280193734, 1.386916870676514, 1.4203605528819792, 1.451595932265776, 1.480935927022547, 1.508628958806044, 1.5348758249050471, 1.5598413419701658, 1.5836626032071637, 1.6064549729490671, 1.6283165284159498, 1.6493314105258192, 1.66957239224697, 1.6891028753564483, 1.7079784627339318, 1.726248210759469, 1.7439556373798932, 1.7611395412783633, 1.777834673375402, 1.7940722917112946, 1.8098806233649336, 1.8252852516227527, 1.8403094425599245, 1.8549744221463136, 1.8692996126708072, 1.8833028354976902, 1.8970004857904796, 1.9104076837625343, 1.9235384061671343, 1.936405601068778, 1.949021288402083, 1.9613966483947782, 1.9735420995839155, 1.9854673678722108, 1.9971815478408133, 2.0086931573454425, 2.0200101862665525, 2.0311401401546014, 2.0420900794036014, 2.0528666544958774, 2.0634761377851585, 2.0739244522212745, 2.0842171973656427, 2.094359673000858, 2.1043569005985905, 2.1142136428765665, 2.123934421646766, 2.133523534132309, 2.14298506790925, 2.152322914611139, 2.1615407825182174, 2.1706422081393097, 2.1796305668823517, 2.1885090828989533, 2.197280838179163, 2.2059487809644573, 2.214515733539884, 2.2229843994599543, 2.23135737025736, 2.2396371316786525, 2.2478260694866745, 2.2559264748656567, 2.2639405494614473, 2.271870410086274, 2.2797180931146976, 2.28748555859495, 2.295174694097678, 2.3027873183221113, 2.3103251844779353, 2.3177899834595275, 2.3251833468277954, 2.3325068496135604, 2.3397620129552488, 2.3469503065826007, 2.3540731511571518, 2.361131920479358, 2.3681279435714577, 2.375062506644442, 2.3819368549568463, 2.3887521945724806, 2.395509694023681, 2.402210485886156, 2.4088556682710576, 2.4154463062394758, 2.421983433144204, 2.4284680519032347, 2.4349011362091595, 2.44128363167833, 2.4476164569433796, 2.4539005046924456, 2.4601366426582087, 2.46632571455966, 2.4724685409992926], [0.0, 0.7851378224852613, 0.9336914847572162, 1.0332994847589596, 1.1103525568907362, 1.1740548859440185, 1.2288070992040003, 1.277086779756963, 1.3204391608159272, 1.3598985994884667, 1.396194423768335, 1.4298618220045207, 1.461306145339252, 1.4908424051821465, 1.5187206849628931, 1.5451431251708252, 1.5702756449705226, 1.5942562546302799, 1.6172010901939204, 1.6392088849530073, 1.6603643426724282, 1.680740723123322, 1.7004018521985305, 1.7194037047240818, 1.7377956652346387, 1.7556215427832074, 1.772920395590378, 1.789727207037261, 1.8060734442596789, 1.8219875231569418, 1.8374951981506853, 1.8526198909506784, 1.8673829695144324, 1.8818039860530522, 1.8959008811439186, 1.9096901596233076, 1.9231870428487674, 1.936405601068778, 1.9493588689617931, 1.9620589468678131, 1.9745170898028679, 1.986743785997105, 1.998748826413073, 2.0105413664686305, 2.0221299809982973, 2.0335227133295235, 2.0447271192199157, 2.0557503062928357, 2.066598969517919, 2.077279423206778, 2.087797629929844, 2.098159226705883, 2.1083695487695167, 2.118433651182726, 2.1283563285226585, 2.1381421328492136, 2.1477953901310802, 2.1573202152874846, 2.16672052598442, 2.1760000553080614, 2.18516236342413, 2.1942108483197984, 2.203148755714112, 2.2119791882135846, 2.2207051137814724, 2.2293293735820354, 2.2378546892547706, 2.2462836696680024, 2.254618817196276, 2.2628625335616044, 2.2710171252747196, 2.279084808709018, 2.2870677148367973, 2.29496789365461, 2.3027873183221113, 2.3105278890365413, 2.3181914366630214, 2.3257797261390447, 2.333294459669949, 2.340737279730703, 2.348109771888037, 2.355413467455784, 2.362649845995201, 2.3698203376711047, 2.376926325473765, 2.3839691473156965, 2.3909500980117886, 2.3978704311505283, 2.4047313608634924, 2.411534063499723, 2.418279679211108, 2.424969313454433, 2.431604038415341, 2.4381848943590683, 2.444712890912464, 2.4511890082814753, 2.4576141984080007, 2.463989386069716, 2.470315469926249, 2.476593323514836, 2.4828237961983883, 2.489007714068684], [0.0, 0.7902529973621358, 0.9397744871152784, 1.0400314334861216, 1.1175865065755222, 1.181703856461886, 1.236812780528175, 1.2854070033206721, 1.3290418252506462, 1.368758342264813, 1.4052906339306293, 1.4391773753505153, 1.4708265585304046, 1.5005552471800365, 1.5286151540232695, 1.5552097364952304, 1.5805059947242717, 1.60464283811593, 1.6277371593406456, 1.6498883349376223, 1.6711816205169885, 1.691690753137475, 1.7114799745177747, 1.7306056241600476, 1.7491174083393233, 1.7670594215246977, 1.7844709764011661, 1.801387284266654, 1.8178400172654527, 1.8338577764265276, 1.8494664839616353, 1.8646897141730423, 1.879548974230557, 1.8940639437279883, 1.9082526801256234, 1.9221317957887885, 1.9357166112422135, 1.949021288402083, 1.9620589468678131, 1.9748417658131499, 1.9873810735805804, 1.999687426731098, 2.011770680015397, 2.023640048498906, 2.035304162881213, 2.0467711188920665, 2.0580485215148534, 2.069143524679119, 2.080062866972243, 2.0908129038435934, 2.101399636709763, 2.1118287393147086, 2.1221055816521197, 2.1322352517177183, 2.142222575325334, 2.152072134191548, 2.1617882824687458, 2.1713751618848627, 2.180836715629496, 2.190176701109886, 2.1993987016862424, 2.208506137483634, 2.217502275366972, 2.226390238156261, 2.2351730131510443, 2.243853460025775, 2.252434318151437, 2.260918213393139, 2.269307664428403, 2.2776050886264665, 2.2858128075249846, 2.2939330519370325, 2.3019679667181965, 2.3099196152207635, 2.3177899834595275, 2.325580984011519, 2.333294459669949, 2.3409321868708846, 2.348495878909535, 2.355987188961597, 2.363407712923772, 2.370758992086407, 2.378042515650104, 2.385259723097208, 2.3924120064281724, 2.3995007122720162, 2.4065271438793503, 2.4134925630057946, 2.4203981916929957, 2.4272452139539125, 2.4340347773685256, 2.440767994595675, 2.447445944806294, 2.454069675042952, 2.460640201510217, 2.4671585108000826, 2.47362556105635, 2.4800422830816236, 2.4864095813903013, 2.492728335210717, 2.4989993994393833, 2.505223605550068], [0.0, 0.7952707287670507, 0.9457416090031758, 1.0466351393921056, 1.1246826503806981, 1.189207115002721, 1.2446659545769567, 1.2935687276168018, 1.3374806099528442, 1.3774493079968597, 1.4142135623730951, 1.4483154685151656, 1.4801656089845707, 1.5100830606950986, 1.5383211346269174, 1.5650845800732873, 1.5905414575341015, 1.6148315584236828, 1.6380725176254403, 1.6603643426724284, 1.6817928305074292, 1.702432186384494, 1.7223470599267343, 1.7415941483654052, 1.760223473586787, 1.778279410038923, 1.7958015200236968, 1.8128252384140613, 1.8293824384573891, 1.845501902785603, 1.8612097182041991, 1.876529608701073, 1.8914832180063517, 1.9060903506699232, 1.9203691788083759, 1.9343364202676694, 1.9480074928505937, 1.9613966483947782, 1.9745170898028679, 1.9873810735805804, 2.0000000000000004, 2.012384492651272, 2.0245444688580787, 2.0364892021971404, 2.0482273781688902, 2.0597671439071177, 2.0711161526832442, 2.082281603850872, 2.0932702787842112, 2.1040885732867167, 2.114742526881128, 2.1252378493369837, 2.1355799447448818, 2.145773933406904, 2.1558246717785057, 2.1657367706679937, 2.1755146118745547, 2.18516236342413, 2.1946839935436993, 2.204083283498255, 2.2133638394006434, 2.222529103092103, 2.231582362180588, 2.240526759314527, 2.2493653007613963, 2.2581008643532257, 2.2667362068547043, 2.275273970803937, 2.2837166908708535, 2.292066799773837, 2.300326633791206, 2.3084984379006395, 2.316584370576538, 2.324586508272497, 2.332506849613561, 2.340347319320716, 2.348109771888037, 2.3557959950311154, 2.3634077129237725, 2.370946589238585, 2.378414230005442, 2.3858121863011523, 2.393141956782034, 2.4004049900704616, 2.407602687005432, 2.414736402766418, 2.421807448879054, 2.428817095110509, 2.4357665712618135, 2.4426570688638467, 2.4494897427831783, 2.4562657127435017, 2.462986064767976, 2.4696518525473916, 2.4762640987387345, 2.4828237961983888, 2.4893319091539134, 2.4957893743180684, 2.502197101948488, 2.508555976856189, 2.514866859365871, 2.521130586230765], [0.0, 0.8001952410151443, 0.9515978740065267, 1.0531161619882878, 1.1316469623900245, 1.1965709783910168, 1.25237323276083, 1.3015788238173445, 1.345762619345434, 1.385978813413053, 1.4229707211083644, 1.4572837946534403, 1.489331159038138, 1.5194338669790928, 1.547846798020459, 1.5747759693135555, 1.6003904820302886, 1.6248309932078528, 1.6482158661538315, 1.6706457276725586, 1.6922069059826197, 1.7129740658352777, 1.7330122571800355, 1.75237852833137, 1.771123210923403, 1.7892909541816906, 1.806921565387635, 1.8240506988356506, 1.8407104251401099, 1.8569297051620812, 1.872734787242987, 1.8881495422754992, 1.9031957480130535, 1.9178933316401892, 1.9322605777997166, 1.9463143078586156, 1.9600700350905091, 1.9735420995839155, 1.986743785997105, 1.999687426731098, 2.012384492651272, 2.024845673131659, 2.037080946906452, 2.0490996449766428, 2.0609105066254236, 2.072521729435642, 2.0839410140696626, 2.095175604461257, 2.1062323239765757, 2.117117608023464, 2.127837533522874, 2.1383978456006427, 2.14880398181083, 2.159061094161688, 2.1691740691810413, 2.179147546228457, 2.1889859342363023, 2.1986934270399607, 2.208274017438652, 2.2177315101118924, 2.2270695335024673, 2.236291550764344, 2.245400869863155, 2.254400652907381, 2.263293924780049, 2.2720835811334323, 2.280772395802786, 2.2893630276894625, 2.297858027158692, 2.3062598419928486, 2.314570822937062, 2.322793228870466, 2.3309292316332666, 2.33898092053697, 2.3469503065826007, 2.3548393264094916, 2.362649845995201, 2.3703836641252947, 2.3780425156501046, 2.3856280745440763, 2.3931419567820336, 2.400585723045433, 2.407960881270643, 2.415268889050264, 2.4225111558976327, 2.4296890453838276, 2.436803877155773, 2.4438569288433487, 2.450849437862816, 2.4577826031233077, 2.46465758664261, 2.471475515078023, 2.478237481177628, 2.484944545156928, 2.491597736005454, 2.4981980527275995, 2.50474646552166, 2.5112439169007508, 2.5176913227590454, 2.524089573386529, 2.5304395344352426, 2.536742047839801], [0.0, 0.8050304775850329, 0.9573479717381597, 1.0594796911843958, 1.1384850195244434, 1.203801343502716, 1.259940786957369, 1.309443706292189, 1.35389448554248, 1.3943536888187151, 1.4315691227432645, 1.4660895354719874, 1.498330548331831, 1.52861515402327, 1.5571997722182047, 1.584291664941221, 1.6100609551700658, 1.634649149872069, 1.658175327573506, 1.680740723123322, 1.7024321863844938, 1.7233248332753464, 1.7434841068143219, 1.7629674000343885, 1.7818253487021418, 1.8001028718392544, 1.8178400172654527, 1.8350726547187575, 1.8518330486025059, 1.868150334775826, 1.8840509201876072, 1.8995588199720859, 1.9146959434763193, 1.9294823382962742, 1.943936399561014, 1.9580750502818227, 1.9719138974723813, 1.9854673678722108, 1.998748826413073, 2.011770680015397, 2.0245444688580787, 2.037080946906452, 2.04939015319192, 2.0614814750987107, 2.0733637047177553, 2.0850450891663788, 2.096533375638743, 2.1078358518406057, 2.1189593823687916, 2.1299104415175543, 2.1406951429280725, 2.151319266441514, 2.1617882824687458, 2.172107374149395, 2.182281457538478, 2.192315200029222, 2.2022130371952797, 2.211979188213584, 2.2216176700101276, 2.231132310254472, 2.2405267593145264, 2.249804501270612, 2.2589688640769774, 2.2680230289493704, 2.2769700390488867, 2.2858128075249846, 2.2945541249740162, 2.303196666363934, 2.31174299747073, 2.3201955808676797, 2.3285567815044543, 2.3368288719096273, 2.345014037046902, 2.3531143788525988, 2.361131920479358, 2.3690686102687937, 2.376926325473765, 2.384706875749129, 2.392412006428173, 2.4000434016004517, 2.407602687005432, 2.4150914327550987, 2.4225111558976327, 2.429863322833242, 2.4371493515923475, 2.4443706139855026, 2.4515284376336917, 2.4586241078869633, 2.4656588696387556, 2.472633929042694, 2.47955045513814, 2.4864095813903013, 2.4932124071502657, 2.499959999039964, 2.5066533922666703, 2.5132935918713324, 2.519881573914738, 2.526418286605205, 2.5329046513712625, 2.539341563882536, 2.5457298950218306, 2.5520704918112105], [0.0, 0.8097801259787746, 0.9629962874017586, 1.0657305800060608, 1.1452020366993765, 1.210903724439527, 1.2673743884191842, 1.317169373045755, 1.3618824101585059, 1.4025803211547638, 1.44001532468678, 1.4747394065031132, 1.5071706400803162, 1.5376339237631882, 1.5663871900896853, 1.5936389239222475, 1.6195602519575492, 1.644293516048505, 1.6679584972800467, 1.6906570277827762, 1.7124764698304722, 1.7334923825224455, 1.7537705949883926, 1.7733688388779358, 1.7923380487067173, 1.8107234085168835, 1.8285652024087349, 1.8458995117503458, 1.8627587913037735, 1.8791723488285783, 1.8951667470736167, 1.9107661428614797, 1.9259925748035172, 1.9408662087757294, 1.9554055484377233, 1.9696276166458888, 1.9835481124946783, 1.9971815478408133, 2.0105413664686305, 2.023640048498906, 2.0364892021971404, 2.0490996449766428, 2.0614814750987107, 2.0736441353327724, 2.0855964696427516, 2.097346773803644, 2.108902840717755, 2.120272001088022, 2.1314611600121216, 2.1424768299823924, 2.1533251607102564, 2.1640119661377195, 2.1745427489508584, 2.1849227228696226, 2.19515683295356, 2.2052497741333363, 2.2152060081523164, 2.225029779080412, 2.2347251275433204, 2.244295903793707, 2.2537457797365077, 2.263078260007981, 2.2722966921971777, 2.281404276288892, 2.290404073398753, 2.2992990138636866, 2.308091904744454, 2.316785436791214, 2.325382190917938, 2.3338846442269867, 2.342295175621143, 2.3506160710368085, 2.3588495283288893, 2.3669976618350463, 2.375062506644442, 2.38304602259383, 2.3909500980117886, 2.398776553230067, 2.4065271438793507, 2.414203563985258, 2.421807448879054, 2.429340377936324, 2.4368038771557736, 2.4441994215893144, 2.4515284376336917, 2.4587923051930876, 2.465992359721398, 2.4731298941521875, 2.480206160723717, 2.48722237270587, 2.494179706035296, 2.501079300864602, 2.5079222630310047, 2.5147096654494634, 2.521442549434933, 2.5281219259580654, 2.5347487768383683, 2.541324055878551, 2.547848689943536, 2.554323579987364, 2.5607496020310148, 2.5671276080939496], [0.0, 0.8144476398584993, 0.9685469281169012, 1.0718733737282615, 1.1518028981306478, 1.2178832856309065, 1.2746794424196195, 1.3247614417239144, 1.369732201537721, 1.4106646923394799, 1.4483154685151653, 1.4832396974191324, 1.515857862273113, 1.5464967341123872, 1.5754157321793416, 1.6028245430280337, 1.6288952797169987, 1.6537711045472614, 1.6775724890132342, 1.7004018521985302, 1.722347059926734, 1.7434841068143216, 1.7638792014253157, 1.7835904081703775, 1.8026689551480006, 1.821160286837872, 1.839104919534922, 1.8565391425776128, 1.8734955977948946, 1.8900037618741268, 1.9060903506699227, 1.921779660243046, 1.9370938562338025, 1.9520532207528385, 1.966676364113512, 1.9809804072907222, 1.9949811398673623, 2.0086931573454425, 2.0221299809982973, 2.035304162881213, 2.0482273781688902, 2.0609105066254236, 2.0733637047177553, 2.0855964696427516, 2.097617696340303, 2.1094357284016496, 2.12105840364682, 2.1324930950323915, 2.143746747456523, 2.154825910949086, 2.1657367706679933, 2.17648517406639, 2.187076655547436, 2.1975164588825846, 2.207809557634348, 2.217960673794632, 2.2279742948239645, 2.2378546892547706, 2.24760592100262, 2.2572318625127545, 2.266736206854704, 2.276122478865197, 2.285394045428542, 2.2945541249740162, 2.3036057962612957, 2.312552006517556, 2.3213955789832528, 2.3301392199178337, 2.338785525111471, 2.3473369859443625, 2.3557959950311154, 2.3641648514841025, 2.3724457658265057, 2.3806408645828756, 2.3887521945724806, 2.39678172692843, 2.4047313608634924, 2.4126029272016765, 2.4203981916929957, 2.4281188581273097, 2.435766571261813, 2.4433429195754983, 2.450849437862816, 2.4582876096777713, 2.4656588696387556, 2.4729646056036185, 2.480206160723717, 2.487384835384989, 2.4945018890435056, 2.5015585419623516, 2.5085559768561887, 2.515495340449381, 2.5223777449531117, 2.529204269466543, 2.535975961306694, 2.542693837271378, 2.549358884839239, 2.555972063310636, 2.5625343048928735, 2.569046515733026, 2.575509576901394, 2.5819243453284186], [0.0, 0.81903625881272, 0.9740037464252967, 1.0779123358892526, 1.158292185288269, 1.224744871391589, 1.281861019188702, 1.3322251817654118, 1.3774493079968597, 1.4186124135047637, 1.4564753151219703, 1.4915963080299908, 1.5243982444638442, 1.5552097364952309, 1.584291664941221, 1.6118548977353127, 1.63807251762544, 1.6630884934927144, 1.6870239755710472, 1.7099819599758033, 1.7320508075688772, 1.7533069411223694, 1.7738169422210555, 1.7936392024119798, 1.812825238414061, 1.8314207507423532, 1.8494664839616353, 1.8669989318654352, 1.8840509201876074, 1.9006520916879264, 1.9168293127388174, 1.9326070162856752, 1.9480074928505935, 1.963051138814152, 1.9777566693406927, 1.9921413018651275, 2.006220914929266, 2.0200101862665525, 2.0335227133295235, 2.0467711188920665, 2.0597671439071177, 2.072521729435642, 2.0850450891663788, 2.097346773803644, 2.1094357284016496, 2.1213203435596424, 2.133008501256132, 2.1445076159871213, 2.1558246717785052, 2.1669662555631914, 2.177938587346431, 2.188747547526072, 2.199398701686243, 2.20989732314194, 2.2202484134768556, 2.230456721286719, 2.2405267593145264, 2.2504628201417236, 2.260268990580086, 2.2699491648923114, 2.2795070569547775, 2.2889462114632346, 2.2982700142711043, 2.307481701940376, 2.316584370576538, 2.3255809840115185, 2.3344743813919835, 2.343267284224516, 2.3519623029240355, 2.3605619429072418, 2.3690686102687932, 2.3774846170743213, 2.385812186301152, 2.3940534564547304, 2.4022104858861564, 2.410285256833955, 2.418279679211108, 2.4261955941565336, 2.434034777368526, 2.441798942236141, 2.449489742783178, 2.45710877643816, 2.4646575866426104, 2.472137665308914, 2.47955045513814, 2.4868973518073663, 2.4941797060352964, 2.5013988255342774, 2.508555976856189, 2.5156523871391085, 2.5226892457611436, 2.5296677059073316, 2.5365888860550827, 2.5434538713832313, 2.5502637151094083, 2.5570194397600914, 2.563722038377404, 2.57037247566643, 2.576971689086552, 2.5835205898901012, 2.5900200641113513, 2.59647097350871], [0.0, 0.8235490260528069, 0.9793703613355592, 1.0838514715804344, 1.164674201923033, 1.2314930323839879, 1.288923881609622, 1.3395655431865348, 1.3850388475869866, 1.4264287556473265, 1.464500276187315, 1.4998147805113797, 1.5327974507070876, 1.563778709449485, 1.593020874969912, 1.6207359770526286, 1.6470980521056138, 1.6722518622569726, 1.6963192252602786, 1.7194037047240815, 1.741594148365405, 1.7629674000343882, 1.7835904081703775, 1.8035218860491045, 1.8228136342389012, 1.8415116050578217, 1.8596567675671003, 1.8772858166356075, 1.8944317588620798, 1.9111244003334622, 1.927390755451873, 1.9432553917845798, 1.9587407226711184, 1.9738672568730735, 1.9886538126725422, 2.003117702369927, 2.017274891995427, 2.0311401401546014, 2.0447271192199157, 2.0580485215148534, 2.0711161526832442, 2.0839410140696626, 2.096533375638743, 2.108902840717755, 2.12105840364682, 2.133008501256132, 2.1447610589527217, 2.1563235320853567, 2.1677029431608688, 2.1789059154051804, 2.189938703094842, 2.2008072190278125, 2.211517059453757, 2.2220735267428493, 2.2324816500367577, 2.242746204095264, 2.252871726525904, 2.2628625335616044, 2.272722734531862, 2.2824562451561787, 2.292066799773837, 2.301557962611329, 2.3109331381776226, 2.3201955808676797, 2.329348403846066, 2.3383945872749803, 2.3473369859443625, 2.356178336355889, 2.3649212633074757, 2.3735682860202925, 2.3821218238462203, 2.3905842015900256, 2.3989576544773072, 2.4072443327963553, 2.4154463062394758, 2.4235655679670325, 2.431604038415341, 2.4395635688677193, 2.4474459448062946, 2.455252889060639, 2.4629860647679758, 2.4706470781584207, 2.478237481177628, 2.4857587739581977, 2.4932124071502657, 2.50059978412088, 2.5079222630310047, 2.515181158798285, 2.5223777449531117, 2.5295132553949102, 2.5365888860550827, 2.543605796472544, 2.550565111287347, 2.5574679216575, 2.5643152866037044, 2.571108234286407, 2.577847763219244, 2.5845348434226794, 2.591170417521358, 2.597755401788474, 2.604290687140218, 2.610777140083157], [0.0, 0.827988804296353, 0.9846501772118186, 1.0896945483500373, 1.1709529965289847, 1.238132049369367, 1.2958725100775408, 1.3467871824166227, 1.3925056348060254, 1.4341186771394874, 1.4723954424229517, 1.5079003283308927, 1.541060809120647, 1.5722090887861115, 1.6016088997243152, 1.6294734147786363, 1.655977608592706, 1.6812670237117344, 1.7054641346125685, 1.7286730632183713, 1.7509831362269535, 1.772471611756025, 1.793205799166037, 1.8132447282578046, 1.8326404788581236, 1.8514392510154154, 1.8696822346563884, 1.8874063224730853, 1.9046446990038355, 1.9214273310211205, 1.9377813785625346, 1.9537315416398595, 1.9693003544236372, 1.9845084362388192, 1.9993747068174432, 2.013916571791058, 2.028150083263225, 2.0420900794036014, 2.0557503062928357, 2.069143524679119, 2.082281603850872, 2.095175604461257, 2.1078358518406057, 2.120272001088022, 2.1324930950323915, 2.1445076159871213, 2.1563235320853567, 2.16794833886788, 2.1793890967000746, 2.1906524645138785, 2.2017447303028406, 2.2126718387409956, 2.2234394162475644, 2.234052793777961, 2.2445170275861126, 2.254836918172679, 2.2650170276075774, 2.2750616953926794, 2.284975053011005, 2.294761037291821, 2.3044234027063477, 2.313965732695932, 2.323391450123356, 2.332703826928124, 2.3419059930579693, 2.351000944741237, 2.3599915521581276, 2.368880566562882, 2.377670626903783, 2.3863642659832003, 2.3949639161958145, 2.403471914879488, 2.411890509309988, 2.4202218613678763, 2.4284680519032347, 2.4366310848216144, 2.4447128909124634, 2.4527153314394257, 2.460640201510217, 2.4684892332422375, 2.476264098738734, 2.483966412889059, 2.4915977360054535, 2.4991595763077785, 2.50665339226667, 2.514080594814771, 2.5214425494349326, 2.528740578133563, 2.535975961306694, 2.5431499395057404, 2.550263715109408, 2.557318453907722, 2.5643152866037044, 2.5712553102378295, 2.578139589540013, 2.5849691582135454, 2.5917450201550816, 2.5984681506144955, 2.6051394972981505, 2.611759981418898, 2.6183304986958853, 2.624851920307043], [0.0, 0.8323582900575635, 0.989846400767953, 1.0954451150103321, 1.1771323825530846, 1.2446659545769565, 1.3027111248652612, 1.3538944855424797, 1.3998542046322333, 1.4416868484808525, 1.4801656089845705, 1.5158578622731127, 1.5491933384829668, 1.5805059947242717, 1.6100609551700655, 1.6380725176254398, 1.664716580115127, 1.6901394532455423, 1.7144642578192797, 1.7377956652346387, 1.7602234735867868, 1.7818253487021416, 1.8026689551480006, 1.8228136342389012, 1.842311740638763, 1.8612097182041993, 1.879548974230557, 1.8973665961010278, 1.9146959434763193, 1.9315671412704056, 1.9480074928505935, 1.9640418285762606, 1.979692801535906, 1.9949811398673623, 2.0099258631464076, 2.0245444688580783, 2.038853093816547, 2.0528666544958774, 2.066598969517919, 2.080062866972243, 2.0932702787842112, 2.1062323239765757, 2.1189593823687916, 2.1314611600121216, 2.143746747456523, 2.1558246717785052, 2.1677029431608688, 2.1793890967000746, 2.1908902300206643, 2.2022130371952793, 2.213363839400643, 2.224348612682192, 2.2351730131510443, 2.2458423998952814, 2.256361855851836, 2.266736206854704, 2.2769700390488867, 2.287067714836797, 2.297033387504232, 2.3068710146560054, 2.316584370576538, 2.3261770576178145, 2.335652516705844, 2.345014037046902, 2.354264765106169, 2.3634077129237725, 2.3724457658265057, 2.381381689587608, 2.3902181370816935, 2.3989576544773072, 2.407602687005432, 2.4161555843385933, 2.424618605611948, 2.432993924114793, 2.44128363167833, 2.449489742783178, 2.4576141984080007, 2.4656588696387556, 2.47362556105635, 2.4815160139189634, 2.489331909153913, 2.4970748701726904, 2.5047464655216602, 2.512348211379903, 2.519881573914738, 2.5273479715046214, 2.5347487768383683, 2.5420853188989163, 2.549358884839239, 2.5565707217574243, 2.563722038377404, 2.5708140066413443, 2.577847763219244, 2.584824410940911, 2.591745020155082, 2.598610630020137, 2.6054222497305224, 2.612180859682727, 2.618887412584378, 2.625542834509777, 2.6321480259049848, 2.638703862545338], [0.0, 0.8366600265340756, 0.9949620563926881, 1.1011065185976396, 1.1832159566199232, 1.2510985509742438, 1.309443706292189, 1.3608915892697748, 1.4070888341971637, 1.449137674618944, 1.4878152983881654, 1.5236920139085786, 1.5571997722182047, 1.588674256361194, 1.618381960706977, 1.6465382905797215, 1.6733200530681511, 1.698874314931026, 1.7233248332753461, 1.7467768204548835, 1.7693205386531028, 1.7910340550835677, 1.8119853840129068, 1.83223417343933, 1.8518330486025056, 1.8708286933869709, 1.8892627290863886, 1.907172434756397, 1.9245913424647914, 1.9415497328150402, 1.9580750502818227, 1.9741922535510608, 1.9899241127853762, 2.005291463248328, 2.0203134228113497, 2.0350075793887674, 2.04939015319192, 2.0634761377851585, 2.077279423206778, 2.0908129038435934, 2.1040885732867167, 2.117117608023464, 2.1299104415175543, 2.1424768299823924, 2.154825910949086, 2.1669662555631914, 2.1789059154051804, 2.1906524645138785, 2.2022130371952793, 2.2135943621178655, 2.2248027931270298, 2.2358443371531918, 2.2467246795389917, 2.257449207068979, 2.26802302894937, 2.2784509959547, 2.2887377179317685, 2.298887579828454, 2.3089047563952776, 2.3187932256904724, 2.3285567815044543, 2.3381990448066348, 2.3477234743061772, 2.3571333762084064, 2.3664319132398464, 2.3756221130072404, 2.384706875749129, 2.393688981532629, 2.402571096942758, 2.411355781306992, 2.4200454924935872, 2.4286425923184853, 2.4371493515923475, 2.4455679548363145, 2.4539005046924456, 2.4621490260524586, 2.470315469926249, 2.4784017170697905, 2.4864095813903013, 2.4943408131450107, 2.5021971019484877, 2.5099800796022267, 2.5176913227590454, 2.5253323554338367, 2.5329046513712625, 2.5404096362801454, 2.547848689943536, 2.555223148212729, 2.5625343048928735, 2.5697834135272224, 2.5769716890865517, 2.584100309569777, 2.591170417521358, 2.5981831214706688, 2.6051394972981505, 2.612040589532689, 2.618887412584378, 2.625680951916526, 2.6324221651604756, 2.6391119831766026, 2.6457513110645907, 2.652341029125897], [0.0, 0.8408964152537145, 1.0, 1.1066819197003215, 1.189207115002721, 1.2574334296829353, 1.3160740129524924, 1.3677823998673804, 1.4142135623730951, 1.4564753151219703, 1.4953487812212205, 1.531407156804393, 1.5650845800732873, 1.59671843378737, 1.6265765616977856, 1.6548754598234363, 1.681792830507429, 1.7074764851741444, 1.7320508075688772, 1.7556215427832071, 1.7782794100389228, 1.800102871839254, 1.821160286837872, 1.8415116050578217, 1.8612097182041993, 1.880301546543197, 1.8988289221159416, 1.9168293127388176, 1.9343364202676694, 1.951380678630378, 1.9679896712654303, 1.984188483235881, 2.0, 2.0154451623197245, 2.0305431848689306, 2.0453117446175235, 2.0597671439071177, 2.0739244522212745, 2.087797629929844, 2.101399636709763, 2.114742526881128, 2.127837533522874, 2.1406951429280725, 2.1533251607102564, 2.1657367706679933, 2.177938587346431, 2.189938703094842, 2.2017447303028406, 2.213363839400643, 2.2248027931270298, 2.2360679774997894, 2.2471654298651536, 2.2581008643532257, 2.2688796950242867, 2.2795070569547775, 2.2899878254809036, 2.3003266337912063, 2.3105278890365413, 2.320595787106084, 2.3305343262007767, 2.340347319320716, 2.350038405769921, 2.3596110617705666, 2.3690686102687937, 2.378414230005442, 2.3876509639174, 2.39678172692843, 2.4058093131823877, 2.414736402766418, 2.4235655679670325, 2.432299279097787, 2.4409399099335674, 2.449489742783178, 2.4579509732289795, 2.46632571455966, 2.4746160019198826, 2.4828237961983883, 2.4909509876742715, 2.4989993994393833, 2.5069707906132983, 2.5148668593658705, 2.5226892457611436, 2.5304395344352426, 2.5381192571198388, 2.5457298950218306, 2.5532728810690504, 2.5607496020310148, 2.5681614005230395, 2.575509576901394, 2.5827953910565906, 2.5900200641113513, 2.597184780029334, 2.604290687140218, 2.611338899586365, 2.6183304986958853, 2.6252665342865877, 2.6321480259049848, 2.638975964004231, 2.6457513110645907, 2.652475002659807, 2.6591479484724942, 2.665771033261474], [0.0, 0.8450697266227711, 1.0049629315732038, 1.112174306341096, 1.1951090685408465, 1.2636739857523107, 1.3226055982240474, 1.3745706103249549, 1.4212322075130495, 1.463703702448981, 1.5027700949004952, 1.5390074257343278, 1.5728519877504676, 1.6046428381159301, 1.634649149872069, 1.6630884934927144, 1.6901394532455423, 1.7159505741329184, 1.740646857208154, 1.7643345723684827, 1.7871048890689831, 1.80903665921692, 1.8301985807252845, 1.8506509011449843, 1.8704467746790288, 1.88963335445568, 1.9082526801256234, 1.9263424054554517, 1.943936399561014, 1.9610652474116927, 1.9777566693406925, 1.9940358749065197, 2.0099258631464076, 2.025447678749862, 2.040620631751871, 2.0554624868519302, 2.069989627299062, 2.0842171973656427, 2.098159226705883, 2.1118287393147086, 2.1252378493369837, 2.1383978456006427, 2.151319266441514, 2.1640119661377195, 2.17648517406639, 2.188747547526072, 2.2008072190278125, 2.2126718387409956, 2.224348612682192, 2.2358443371531918, 2.2471654298651536, 2.2583179581272432, 2.2693076644284034, 2.2801399896985237, 2.2908200944990793, 2.301352878362235, 2.31174299747073, 2.3219948808478086, 2.3321127452065564, 2.3421006085907137, 2.3519623029240355, 2.3617014855721576, 2.371321650009509, 2.3808261356737828, 2.390218137081693, 2.3995007122720162, 2.408676790635081, 2.4177491801818887, 2.4267205743006723, 2.435593558044026, 2.4443706139855026, 2.45305412768087, 2.4616463927658754, 2.4701496157194045, 2.478565920318253, 2.4868973518073663, 2.495145880807243, 2.5033134069783034, 2.5114017624602782, 2.519412715103133, 2.5273479715046214, 2.535209179868313, 2.542997932694775, 2.5507157693175553, 2.558364178294683, 2.565944599665513, 2.5734584270820036, 2.5809070098227784, 2.588291654697687, 2.595613627849991, 2.602874156462761, 2.610074430375586, 2.6172156036172267, 2.6242987958594575, 2.6313250937969457, 2.638295552457674, 2.645211196448095, 2.6520730211369132, 2.6588819937811183, 2.665639054597641, 2.6723451177837885, 2.67900107248938], [0.0, 0.8491821094987799, 1.0098534065489688, 1.1175865065755222, 1.2009248561777692, 1.2698234324738655, 1.3290418252506462, 1.381259715923798, 1.4281483835502227, 1.4708265585304046, 1.5100830606950983, 1.5464967341123872, 1.5805059947242717, 1.61245154965971, 1.642603881843218, 1.6711816205169885, 1.6983642189975598, 1.7243009451553697, 1.7491174083393233, 1.772920395590378, 1.7958015200236968, 1.8178400172654527, 1.8391049195349223, 1.8596567675671005, 1.8795489742305571, 1.898828922115942, 1.9175388554524904, 1.9357166112422137, 1.953396223419044, 1.970608425788726, 1.9873810735805801, 2.003739499030986, 2.0197068130979376, 2.0353041628812134, 2.0505509523846825, 2.0654650327566206, 2.080062866972243, 2.094359673000858, 2.1083695487695167, 2.1221055816521197, 2.1355799447448818, 2.14880398181083, 2.1617882824687458, 2.1745427489508584, 2.187076655547436, 2.199398701686243, 2.211517059453757, 2.2234394162475644, 2.2351730131510443, 2.2467246795389917, 2.2581008643532257, 2.2693076644284034, 2.280350850198276, 2.2912358890700615, 2.3019679667181965, 2.312552006517556, 2.322992687309372, 2.333294459669949, 2.3434615608322646, 2.3534980283931604, 2.3634077129237725, 2.3731942895876625, 2.3828612688596364, 2.392412006428173, 2.4018497123555385, 2.4111774595619155, 2.4203981916929957, 2.4295147304244695, 2.43852978225147, 2.4474459448062946, 2.4562657127435017, 2.4649914832277466, 2.47362556105635, 2.4821701634456383, 2.4906274245073927, 2.4989993994393833, 2.5072880684517855, 2.5154953404493816, 2.5236230564876885, 2.531672993019601, 2.539646864947731, 2.54754632849634, 2.5553729839156167, 2.5631283780300076, 2.5708140066413443, 2.5784313167966806, 2.585981708929937, 2.593466538885762, 2.6008871198333665, 2.6082447240774744, 2.615540584773027, 2.6227758975497575, 2.6299518220523037, 2.6370694834011266, 2.6441299735791004, 2.6511343527483158, 2.6580836505012924, 2.6649788670505217, 2.6718209743599775, 2.6786109172219916, 2.68534961428265, 2.6920379590186645], [0.0, 0.8532355998949246, 1.0146738461686593, 1.1229211999476407, 1.206657357270946, 1.2758848143974324, 1.3353858805651275, 1.3878530283952342, 1.4349655146369895, 1.4778474098445196, 1.5172912992053529, 1.5538787898449244, 1.5880503904422236, 1.6201484344594288, 1.6504446959456858, 1.6791588477491748, 1.7064711997898492, 1.732531732454193, 1.7574666546754452, 1.7813832632323923, 1.8043736085467281, 1.8265173044683851, 1.8478837127354024, 1.868533663068241, 1.8885208232967414, 1.9078928021878638, 1.9266920456196721, 1.944956571205524, 1.9627205753371124, 1.9800149385250942, 1.9968676489630897, 2.0133041598085097, 2.0293476923373186, 2.0450194945929727, 2.060339063202517, 2.075324334524993, 2.0899918501200694, 2.1043569005985905, 2.118433651182726, 2.1322352517177183, 2.145773933406904, 2.159061094161688, 2.172107374149395, 2.1849227228696226, 2.1975164588825846, 2.20989732314194, 2.2220735267428493, 2.234052793777961, 2.2458423998952814, 2.257449207068979, 2.2688796950242867, 2.2801399896985237, 2.2912358890700615, 2.302172886644268, 2.312956192848905, 2.323590754560113, 2.334081272953128, 2.3444322198486605, 2.3546478527057175, 2.364732228394227, 2.3746892158656623, 2.38452250782663, 2.394235631508855, 2.4038319586188774, 2.413314714541892, 2.422686986866375, 2.4319517332892318, 2.4411117889551543, 2.4501698732784742, 2.4591285962910403, 2.467990464555409, 2.476757886678874, 2.4854331784604873, 2.4940185677002478, 2.5025161986969175, 2.5109281364585576, 2.5192563706476903, 2.5275028192810733, 2.5356693322023287, 2.5437576943440803, 2.551769628794865, 2.5597067996847738, 2.5675708149026395, 2.575363228656527, 2.583085543888338, 2.590739214552467, 2.5983256477676733, 2.605846205850603, 2.6133022082387543, 2.620694933310077, 2.6280256201058623, 2.6352954699630677, 2.6425056480617855, 2.6496572848931312, 2.656751477652458, 2.6637892915624386, 2.670771761130255, 2.6776998913428183, 2.684574658803681, 2.691397012815051, 2.6981678764080854, 2.704888147324421], [0.0, 0.8572321289096398, 1.0194265469082735, 1.128180927925918, 1.212309302805974, 1.281861019188702, 1.3416407864998738, 1.3943536888187151, 1.4416868484808525, 1.4847696011519296, 1.5243982444638442, 1.5611571097717194, 1.5954887690834967, 1.6277371593406456, 1.658175327573506, 1.687023975571047, 1.7144642578192797, 1.740646857208154, 1.7656985738296271, 1.7897272070372607, 1.8128252384140608, 1.8350726547187572, 1.8565391425776128, 1.8772858166356075, 1.8973665961010278, 1.9168293127388176, 1.9357166112422135, 1.954066687297892, 1.9719138974723813, 1.9892892669196898, 2.006220914929266, 2.0227344138803187, 2.038853093816547, 2.0545983023065815, 2.069989627299062, 2.0850450891663783, 2.09978130694835, 2.1142136428765665, 2.1283563285226585, 2.142222575325334, 2.1558246717785057, 2.1691740691810413, 2.182281457538478, 2.19515683295356, 2.207809557634348, 2.2202484134768556, 2.2324816500367577, 2.2445170275861126, 2.256361855851836, 2.26802302894937, 2.2795070569547775, 2.2908200944990793, 2.3019679667181965, 2.312956192848905, 2.32379000772445, 2.3344743813919835, 2.345014037046902, 2.355413467455784, 2.365676950019442, 2.3758085606100576, 2.385812186301152, 2.3956915370958543, 2.405450156747334, 2.4150914327550987, 2.424618605611948, 2.434034777368526, 2.4433429195754983, 2.452545880657287, 2.461646392765876, 2.4706470781584207, 2.47955045513814, 2.488358943594169, 2.4970748701726904, 2.5057004731086487, 2.5142379067446345, 2.5226892457611436, 2.531056489140214, 2.5393415638825356, 2.54754632849634, 2.5556725762748194, 2.563722038377404, 2.5716963867289198, 2.579597236749499, 2.5874261499270697, 2.5951846362432662, 2.602874156462761, 2.610496124295213, 2.618051908438318, 2.625542834509777, 2.6329701868754243, 2.64033521038018, 2.647639111988028, 2.654883062336727, 2.662068197212579, 2.669195618950164, 2.676266397761627, 2.6832815729997477, 2.6902421543587653, 2.697149123016613, 2.7040034327220006, 2.7108060108295344, 2.717557759285845], [0.0, 0.861173529963367, 1.0241136890844451, 1.133368103427352, 1.2178832856309065, 1.287754788450697, 1.3478094125129467, 1.4007646793929587, 1.4483154685151653, 1.4915963080299905, 1.531407156804393, 1.568335032845268, 1.602824543028034, 1.635221205655121, 1.665799323178612, 1.6947806121350968, 1.722347059926734, 1.748650042256635, 1.7738169422210552, 1.7979560548158353, 1.8211602868378718, 1.8435099928108027, 1.8650751797676193, 1.8859172433475835, 1.906090350669923, 1.925642553421541, 1.9446166923683976, 1.963051138814152, 1.9809804072907227, 1.9984356656002646, 2.015445162319724, 2.0320345874055676, 2.0482273781688902, 2.0640449803306513, 2.079507071901399, 2.094631756107994, 2.1094357284016496, 2.123934421646766, 2.1381421328492136, 2.152072134191548, 2.1657367706679937, 2.179147546228457, 2.192315200029222, 2.2052497741333363, 2.217960673794632, 2.230456721286719, 2.242746204095264, 2.254836918172679, 2.266736206854704, 2.2784509959547, 2.2899878254809036, 2.301352878362235, 2.312552006517556, 2.323590754560113, 2.3344743813919835, 2.345207879911715, 2.3557959950311154, 2.366243240173708, 2.376553912407033, 2.386732106343409, 2.39678172692843, 2.406706501223162, 2.41650998927432, 2.4261955941565336, 2.435766571261813, 2.4452260369034797, 2.4545769762948617, 2.4638222509569303, 2.472964605603619, 2.482006674548756, 2.490950987674271, 2.499799975995519, 2.508555976856189, 2.5172212387822324, 2.5257979260215238, 2.5342881227935714, 2.542693837271378, 2.5510170053156402, 2.55925949397968, 2.567423104801933, 2.575509576901394, 2.5835205898901012, 2.5914577666156022, 2.5993226757452694, 2.607116834203364, 2.6148417094708947, 2.6224987217575073, 2.630089246053925, 2.637614614072805, 2.645076116085267, 2.652475002659807, 2.6598124863098143, 2.667089743055433, 2.674307913905108, 2.6814681062617582, 2.6885713952581733, 2.6956188250258935, 2.702611409901553, 2.709550135574365, 2.7164359601782087, 2.7232698153315003, 2.7300526071278615], [0.0, 0.8650615454144222, 1.0287373447220802, 1.1384850195244434, 1.223381769812505, 1.2935687276168015, 1.35389448554248, 1.4070888341971637, 1.454854305025652, 1.4983305483318308, 1.5383211346269174, 1.5754157321793418, 1.6100609551700658, 1.642603881843218, 1.6733200530681511, 1.7024321863844938, 1.7301230908288443, 1.75654482553344, 1.7818253487021418, 1.8060734442596786, 1.829382438457389, 1.8518330486025056, 1.8734955977948946, 1.8944317588620798, 1.9146959434763193, 1.9343364202676696, 1.9533962234190436, 1.9719138974723813, 1.9899241127853764, 2.0074581778761864, 2.0245444688580787, 2.041208791672212, 2.0574746894441605, 2.0733637047177558, 2.08889560434558, 2.1040885732867167, 2.1189593823687916, 2.133523534132309, 2.1477953901310802, 2.1617882824687458, 2.1755146118745547, 2.1889859342363023, 2.2022130371952797, 2.2152060081523164, 2.2279742948239645, 2.2405267593145264, 2.252871726525904, 2.2650170276075774, 2.2769700390488867, 2.2887377179317685, 2.3003266337912063, 2.31174299747073, 2.322992687309372, 2.334081272953128, 2.345014037046902, 2.3557959950311154, 2.366431913239847, 2.376926325473765, 2.3872835482007586, 2.3975076945194496, 2.407602687005432, 2.417572269546659, 2.4274200182627017, 2.4371493515923475, 2.44676353962501, 2.4562657127435017, 2.4656588696387556, 2.4749458847509014, 2.484129515185673, 2.4932124071502657, 2.5021971019484877, 2.5110860415712124, 2.519881573914738, 2.5285859576566336, 2.5372013668158924, 2.5457298950218306, 2.5541735595139254, 2.5625343048928735, 2.5708140066413447, 2.579014474431339, 2.587137455233603, 2.5951846362432662, 2.603157647634689, 2.611058065157442, 2.618887412584378, 2.626647164021871, 2.63433874609151, 2.6419635399918104, 2.649522883447829, 2.657018072555984, 2.6644503635308237, 2.6718209743599775, 2.6791310863730695, 2.686381845729956, 2.6935743648332457, 2.7007097236697226, 2.70778897108496, 2.7148131259951045, 2.7217831785395497, 2.728700091177943, 2.735564799734761, 2.7423782143944453], [0.0, 0.8688978326173192, 1.0332994847589594, 1.1435338574183984, 1.2288070992040003, 1.2993053150100684, 1.3598985994884667, 1.4133288490453373, 1.4613061453392517, 1.504975192679675, 1.5451431251708252, 1.5824022260821624, 1.6172010901939202, 1.6498883349376223, 1.6807407231233218, 1.709981959975803, 1.7377956652346385, 1.7643345723684827, 1.7897272070372605, 1.8140828355896175, 1.8374951981506853, 1.8600453699846247, 1.881803986053052, 1.9028329926838916, 1.9231870428487672, 1.9429146192345599, 1.962058946867813, 1.9806587412238905, 1.998748826413073, 2.0163606497973583, 2.033522713329523, 2.050260937392297, 2.0665989695179188, 2.082558447784909, 2.098159226705883, 2.1134195718847355, 2.1283563285226585, 2.14298506790925, 2.1573202152874846, 2.1713751618848627, 2.18516236342413, 2.1986934270399607, 2.211979188213584, 2.225029779080412, 2.2378546892547706, 2.2504628201417236, 2.2628625335616044, 2.2750616953926794, 2.287067714836797, 2.298887579828454, 2.3105278890365413, 2.3219948808478086, 2.333294459669949, 2.3444322198486605, 2.355413467455784, 2.366243240173708, 2.376926325473765, 2.3874672772626644, 2.3978704311505283, 2.4081399184763312, 2.418279679211108, 2.4282934738458257, 2.438184894359068, 2.4479573743493686, 2.4576141984080007, 2.467158510800082, 2.476593323514836, 2.4859215237396675, 2.495145880807243, 2.5042690526598896, 2.513293591871332, 2.5222219512619364, 2.531056489140214, 2.5397994742002874, 2.5484530901022695, 2.557019439760091, 2.5655005493590783, 2.573898372123646, 2.582214791853664, 2.5904516262464825, 2.598610630020137, 2.606693497851958, 2.6147018671456377, 2.6226373206387223, 2.6305013888615374, 2.6382955524576737, 2.6460212443753583, 2.6536798519383042, 2.6612727188039766, 2.66880114681659, 2.6762663977616263, 2.6836696950281222, 2.6910122251845436, 2.698295139473619, 2.705519555231128, 2.7126865572332703, 2.7197971989769334, 2.72685250389685, 2.733853466523383, 2.7408010535843985, 2.7476962050544724, 2.75453983515444], [0.0, 0.8726839694794393, 1.0378019856537666, 1.148516693752116, 1.2341615053034112, 1.3049669101523764, 1.3658242239094178, 1.4194872905246418, 1.4676736431692852, 1.5115329740892762, 1.5518759343963227, 1.5892973881759884, 1.6242478849161492, 1.6570775611145052, 1.6880643855478386, 1.7174330382144525, 1.7453679389588785, 1.7720224867708414, 1.797525767348191, 1.8219875231569418, 1.8455019027856028, 1.868150334775826, 1.890003761874127, 1.9111244003334624, 1.9315671412704056, 1.9513806786303782, 1.9706084257887257, 1.98928926691969, 2.0074581778761864, 2.0251467430490013, 2.042383588585367, 2.0591947478135326, 2.075603971307533, 2.091632991431688, 2.1073017492127, 2.1226285898450357, 2.1376304319311945, 2.152322914611139, 2.16672052598442, 2.180836715629496, 2.1946839935436993, 2.208274017438652, 2.2216176700101276, 2.2347251275433204, 2.24760592100262, 2.260268990580086, 2.272722734531862, 2.284975053011005, 2.297033387504232, 2.3089047563952776, 2.320595787106084, 2.3321127452065564, 2.3434615608322646, 2.3546478527057175, 2.365676950019442, 2.376553912407033, 2.3872835482007586, 2.3978704311505283, 2.4083189157584597, 2.4186331513654293, 2.4288170951105092, 2.438874523870636, 2.448809045276087, 2.4586241078869637, 2.4683230106068224, 2.4779089114016077, 2.487384835384989, 2.4967536823250067, 2.5060182336214227, 2.5151811587982853, 2.5242450215519088, 2.533212285390583, 2.5420853188989163, 2.550866400656643, 2.5595577238389606, 2.5681614005230395, 2.5766794657231107, 2.5851138811745704, 2.5934665388857625, 2.6017392644744746, 2.609933820304753, 2.618051908438318, 2.626095173413688, 2.6340652048650317, 2.641963539991811, 2.6497916658893743, 2.65755102174988, 2.665243000942169, 2.6728689529785594, 2.6804301853759265, 2.6879279654178565, 2.6953635218241843, 2.7027380463337307, 2.710052695205652, 2.717308590644407, 2.7245068221530033, 2.7316484478188356, 2.738734495536154, 2.7457659641688887, 2.752743824657328, 2.7596690210718946, 2.7665424716170515], [0.0, 0.8764214595654655, 1.0422466354563211, 1.1534355073280027, 1.2394471144723045, 1.310555761397342, 1.3716737120112341, 1.4255666042981499, 1.4739593272000566, 1.5180064968110587, 1.5585222360615276, 1.5961039566931094, 1.6312041377859532, 1.6641744153859734, 1.6952939487416283, 1.724788380100209, 1.752842919130931, 1.7796116217935372, 1.8052241266280664, 1.8297906461004336, 1.853405732014319, 1.876151161649724, 1.898098181583441, 1.9193092745252844, 1.9398395666769344, 1.9597379605279643, 1.9790480553824932, 1.9978089019460852, 2.016055625864603, 2.033819946796984, 2.0511306134891862, 2.068013770763778, 2.0844932709126422, 2.100590939374452, 2.116326802578406, 2.131719284286912, 2.1467853755606696, 2.1615407825182174, 2.1760000553080614, 2.190176701109886, 2.204083283498255, 2.2177315101118924, 2.231132310254472, 2.244295903793707, 2.2572318625127545, 2.2699491648923114, 2.2824562451561787, 2.294761037291821, 2.3068710146560054, 2.3187932256904724, 2.3305343262007767, 2.3421006085907137, 2.3534980283931604, 2.364732228394227, 2.3758085606100576, 2.386732106343409, 2.3975076945194496, 2.4081399184763312, 2.4186331513654293, 2.428991560298224, 2.439219119361237, 2.4493196216068367, 2.459296690115891, 2.4691537882178327, 2.478894228944609, 2.4885211837869523, 2.4980376908143476, 2.5074466622138267, 2.5167508912971996, 2.5259530590214276, 2.535055740062504, 2.5440614084793167, 2.5529724430005367, 2.561791131964494, 2.570519677939213, 2.579160202047371, 2.5877147480186613, 2.5961852859901096, 2.6045737160730646, 2.612881871703984, 2.621111522794684, 2.6292643786963965, 2.6373420909907916, 2.645346256120049, 2.6532784178670767, 2.6611400696960854, 2.6689326569629386, 2.6766575790039315, 2.6843161911110114, 2.691909806400825, 2.6994396975844213, 2.706907098643939, 2.7143132064221227, 2.721659182130101, 2.7289461527784584, 2.736175212536273, 2.7433474240224682, 2.750463819533511, 2.75752540221122, 2.7645331471541805, 2.771488002476036, 2.7783908903136925], [0.0, 0.8801117367933934, 1.0466351393921056, 1.158292185288269, 1.2446659545769567, 1.3160740129524924, 1.3774493079968597, 1.4315691227432645, 1.4801656089845705, 1.5243982444638442, 1.5650845800732873, 1.602824543028034, 1.6380725176254403, 1.6711816205169887, 1.7024321863844938, 1.7320508075688772, 1.7602234735867868, 1.7871048890689831, 1.8128252384140608, 1.8374951981506855, 1.8612097182041991, 1.8840509201876072, 1.9060903506699232, 1.9273907554518732, 1.9480074928505937, 1.9679896712654306, 1.9873810735805801, 2.0062209149292665, 2.0245444688580787, 2.042383588585367, 2.0597671439071177, 2.0767213897317967, 2.0932702787842112, 2.1094357284016496, 2.1252378493369832, 2.140695142928072, 2.1558246717785052, 2.1706422081393097, 2.18516236342413, 2.1993987016862424, 2.2133638394006434, 2.2270695335024673, 2.2405267593145264, 2.2537457797365077, 2.266736206854704, 2.2795070569547775, 2.292066799773837, 2.3044234027063477, 2.316584370576538, 2.3285567815044543, 2.340347319320716, 2.3519623029240355, 2.3634077129237725, 2.3746892158656623, 2.385812186301152, 2.39678172692843, 2.407602687005432, 2.418279679211108, 2.4288170951105092, 2.439219119361237, 2.4494897427831783, 2.4596327743998025, 2.4696518525473916, 2.4795504551381407, 2.4893319091539134, 2.4989993994393833, 2.508555976856189, 2.518004565853474, 2.527347971504622, 2.5365888860550827, 2.5457298950218306, 2.5547734828810733, 2.563722038377404, 2.5725778594844746, 2.5813431580444846, 2.5900200641113513, 2.598610630020137, 2.607116834203364, 2.615540584773027, 2.6238837228854868, 2.6321480259049848, 2.6403352103801803, 2.648446934846925, 2.65648480246941, 2.6644503635308237, 2.6723451177837885, 2.6801705166700103, 2.6879279654178565, 2.6956188250258935, 2.7032444141398027, 2.7108060108295344, 2.718304854273057, 2.725742146352564, 2.7331190531686027, 2.7404367064771695, 2.7476962050544724, 2.7548986159937194, 2.762044975937984, 2.769136292252934, 2.7761735441429227, 2.7831576837137404, 2.7900896369850603], [0.0, 0.8837561697610181, 1.0509691250073554, 1.1630885288089072, 1.2498199611069312, 1.3215237113488725, 1.3831531538375998, 1.4374970719890816, 1.4862947902207868, 1.5307105875285492, 1.5715654001808814, 1.6094616396167147, 1.6448555716821271, 1.6781017752406273, 1.7094817458049945, 1.7392230140067817, 1.7675123395220362, 1.7945050675941052, 1.8203319216989462, 1.8451040366629305, 1.8689167555872028, 1.8918525401401285, 1.9139832331561426, 1.9353718402585094, 1.9560739489962538, 1.9761388711204808, 1.995610570814851, 2.0145284255975655, 2.0329278550785728, 2.050840844376428, 2.068296382833342, 2.0853208340760854, 2.101938250014711, 2.118170638743468, 2.134038194291349, 2.149559494607946, 2.164751672950963, 2.1796305668823517, 2.1942108483197984, 2.208506137483634, 2.222529103092103, 2.236291550764344, 2.249804501270612, 2.263078260007981, 2.276122478865197, 2.2889462114632346, 2.301557962611329, 2.313965732695932, 2.3261770576178145, 2.3381990448066348, 2.350038405769921, 2.3617014855721576, 2.3731942895876625, 2.38452250782663, 2.3956915370958543, 2.406706501223162, 2.417572269546659, 2.4282934738458257, 2.438874523870636, 2.4493196216068367, 2.4596327743998025, 2.4698178070456938, 2.4798783729466893, 2.489817964416585, 2.4996399222138623, 2.5093474443712385, 2.5189435943835905, 2.5284313088098407, 2.537813404338831, 2.5470925843642664, 2.556271445109423, 2.5653524813384143, 2.5743380916873284, 2.583230583645438, 2.592032178213907, 2.600745014266939, 2.6093711526380607, 2.6179125799522365, 2.626371212222715, 2.6347488982298564, 2.643047422697745, 2.6512685092830544, 2.659413823389427, 2.6674849748195557, 2.6754835202761598, 2.683410965722149, 2.691268768609469, 2.699058339985363, 2.706781046484122, 2.714438212211775, 2.7220311205306014, 2.7295610157498498, 2.737029104728559, 2.7444365583959525, 2.751784513194487, 2.7590740724502676, 2.7663063076751997, 2.7734822598049687, 2.780602940376616, 2.7876693326492603, 2.794682392671241, 2.8016430502967653], [0.0, 0.8873560657375262, 1.0552501469158886, 1.167826258352922, 1.2549109828200413, 1.3269068114098672, 1.3887872955203007, 1.44335257840902, 1.4923490694646506, 1.5369457902618242, 1.5779670210741878, 1.6160176272058788, 1.6515557330581283, 1.68493736183743, 1.7164451557015292, 1.7463075721061798, 1.7747121314750525, 1.801814811835441, 1.8277468691528411, 1.8526198909506784, 1.8765296087010728, 1.8995588199720859, 1.9217796602430461, 1.94325539178458, 1.9640418285762609, 1.984188483235881, 2.003739499030986, 2.022734413880319, 2.0412087916722124, 2.0591947478135326, 2.0767213897317967, 2.0938151884434775, 2.110500293831777, 2.126798803638806, 2.1427309941519956, 2.158315518996434, 2.173569581220506, 2.1885090828989533, 2.203148755714112, 2.217502275366972, 2.231582362180588, 2.245400869863155, 2.2589688640769774, 2.2722966921971777, 2.285394045428542, 2.2982700142711043, 2.3109331381776226, 2.323391450123356, 2.335652516705844, 2.3477234743061772, 2.3596110617705666, 2.371321650009509, 2.3828612688596364, 2.394235631508855, 2.405450156747334, 2.41650998927432, 2.4274200182627017, 2.438184894359068, 2.448809045276087, 2.459296690115891, 2.4696518525473916, 2.4798783729466893, 2.4899799195977463, 2.499959999039964, 2.5098219656400826, 2.519569030457699, 2.529204269466543, 2.538730631187328, 2.548150943782407, 2.5574679216575, 2.5666841716113495, 2.575802198570253, 2.584824410940911, 2.593753125611932, 2.6025905726315153, 2.611338899586365, 2.6200001757046136, 2.6285763957035524, 2.6370694834011266, 2.6454812951085245, 2.6538136228197344, 2.662068197212579, 2.6702466904745625, 2.678350718965756, 2.686381845729956, 2.6943415828644692, 2.7022313937580313, 2.7100526952056514, 2.717806859408474, 2.725495215866147, 2.7331190531686027, 2.7406796206936646, 2.7481781302163952, 2.7556157574356863, 2.7629936434231848, 2.7703128959992873, 2.7775745910406013, 2.7847797737229634, 2.7919294597038142, 2.7990246362474833, 2.806066263296683, 2.8130552744932906], [0.0, 0.8909126743510709, 1.0594796911843958, 1.172507018523451, 1.259940786957369, 1.332225181765412, 1.3943536888187151, 1.449137674618944, 1.498330548331831, 1.5431060170831206, 1.5842916649412213, 1.6224947815686919, 1.6581753275735063, 1.6916907531374752, 1.7233248332753464, 1.7533069411223694, 1.7818253487021418, 1.80903665921692, 1.8350726547187575, 1.8600453699846249, 1.8840509201876074, 1.907172434756397, 1.9294823382962742, 1.951044146639142, 1.9719138974723813, 1.992141301865128, 2.0117706800153967, 2.03084172831372, 2.04939015319192, 2.06744819877851, 2.0850450891663788, 2.1022074014703858, 2.1189593823687916, 2.135323218173586, 2.151319266441514, 2.1669662555631914, 2.182281457538478, 2.197280838179163, 2.2119791882135846, 2.226390238156261, 2.240526759314527, 2.254400652907381, 2.2680230289493704, 2.281404276288892, 2.2945541249740162, 2.307481701940376, 2.3201955808676797, 2.332703826928124, 2.345014037046902, 2.3571333762084064, 2.3690686102687937, 2.3808261356737828, 2.392412006428173, 2.4038319586188774, 2.4150914327550987, 2.4261955941565336, 2.4371493515923475, 2.4479573743493686, 2.4586241078869637, 2.4691537882178327, 2.4795504551381407, 2.489817964416585, 2.499959999039964, 2.509980079602227, 2.519881573914738, 2.529667705907332, 2.539341563882536, 2.5489061081790196, 2.5583641782946835, 2.5677184995148465, 2.576971689086552, 2.586126261976083, 2.5951846362432667, 2.604149138063024, 2.613022006421803, 2.6218053975140414, 2.630501388861538, 2.6391119831766026, 2.6476391119880285, 2.656084639047278, 2.664450363530824, 2.6727380230532125, 2.680949296504237, 2.6890858067224945, 2.6971491230166134, 2.70514076354453, 2.713062197560384, 2.720914847537835, 2.728700091177943, 2.7364192633091173, 2.7440736576860836, 2.751664528694292, 2.759193092965716, 2.7666605309115617, 2.7740679881770016, 2.7814165770226826, 2.7887073776374303, 2.7959414393862456, 2.803119781997423, 2.810243396692342, 2.8173132472612576, 2.8243302710881744], [0.0, 0.8944271909999159, 1.0636591793889976, 1.1771323825530846, 1.2649110640673515, 1.337480609952844, 1.3998542046322333, 1.4548543050256517, 1.5042412372345575, 1.5491933384829666, 1.5905414575341013, 1.6288952797169987, 1.664716580115127, 1.6983642189975598, 1.730123090828844, 1.7602234735867865, 1.7888543819998317, 1.8161730370463405, 1.8423117406387628, 1.8673829695144322, 1.8914832180063514, 1.914695943476319, 1.9370938562338025, 1.9587407226711187, 1.9796928015359063, 2.0, 2.0197068130979376, 2.038853093816547, 2.0574746894441605, 2.075603971307533, 2.093270278784211, 2.110500293831777, 2.127318358777995, 2.1437467474565235, 2.1598058977316086, 2.175514611874554, 2.1908902300206643, 2.2059487809644573, 2.2207051137814724, 2.2351730131510443, 2.2493653007613963, 2.263293924780049, 2.2769700390488867, 2.290404073398753, 2.3036057962612957, 2.316584370576538, 2.329348403846066, 2.3419059930579693, 2.354264765106169, 2.3664319132398464, 2.378414230005442, 2.390218137081693, 2.4018497123555385, 2.413314714541892, 2.424618605611948, 2.435766571261813, 2.44676353962501, 2.4576141984080007, 2.4683230106068224, 2.478894228944609, 2.4893319091539134, 2.4996399222138623, 2.5098219656400826, 2.519881573914738, 2.529822128134703, 2.539646864947731, 2.549358884839239, 2.5589611598259867, 2.5684565406072686, 2.577847763219244, 2.587137455233603, 2.5963281415377923, 2.6054222497305224, 2.6144221151631246, 2.623329985654512, 2.6321480259049848, 2.640878321631854, 2.649522883447829, 2.6580836505012924, 2.666562493895928, 2.674961219905688, 2.6832815729997477, 2.691525238690868, 2.6996938462195, 2.7077889710849594, 2.715812137434088, 2.7237648203170117, 2.731648447818835, 2.739464403075442, 2.7472140261809384, 2.754898615993719, 2.762519431847596, 2.770077695173973, 2.7775745910406013, 2.785011269612051, 2.7923888475366696, 2.7997084092644666, 2.8069710083000294, 2.8141776683943274, 2.8213293846789598, 2.82842712474619, 2.8354718296778603], [0.0, 0.8979007600118484, 1.0677899723724407, 1.1817038564618862, 1.2698234324738655, 1.342674807141325, 1.4052906339306293, 1.460504330965901, 1.5100830606950983, 1.5552097364952306, 1.59671843378737, 1.635221205655121, 1.6711816205169887, 1.704959932300383, 1.7368421418769384, 1.7670594215246973, 1.7958015200236968, 1.8232262689306922, 1.8494664839616353, 1.8746350786649426, 1.8988289221159416, 1.9221317957887885, 1.9446166923683978, 1.9663476258882207, 1.9873810735805804, 2.007767136435218, 2.027550482286173, 2.0467711188920665, 2.065465032756621, 2.083664720922846, 2.1013996367097625, 2.1186965656961565, 2.1355799447448813, 2.152072134191548, 2.1681936512722437, 2.183963371278174, 2.1993987016862424, 2.214515733539884, 2.2293293735820354, 2.243853460025775, 2.2581008643532257, 2.2720835811334323, 2.2858128075249846, 2.2992990138636866, 2.312552006517556, 2.3255809840115185, 2.3383945872749803, 2.351000944741237, 2.3634077129237725, 2.3756221130072404, 2.3876509639174, 2.3995007122720162, 2.4111774595619155, 2.422686986866375, 2.434034777368526, 2.4452260369034797, 2.4562657127435017, 2.467158510800082, 2.4779089114016077, 2.4885211837869523, 2.4989993994393833, 2.5093474443712385, 2.519569030457699, 2.529667705907332, 2.539646864947731, 2.5495097567963922, 2.5592594939796793, 2.5688990600563826, 2.5784313167966806, 2.5878590108623167, 2.597184780029334, 2.606411158990752, 2.6155405847730266, 2.624575401796986, 2.6335178666111, 2.6423701523224317, 2.6511343527483158, 2.6598124863098143, 2.6684064996861254, 2.67691827124749, 2.68534961428265, 2.693702280035545, 2.70197796056474, 2.7101782914379524, 2.718304854273057, 2.7263591791360233, 2.734342746805436, 2.742256990912465, 2.7501032999644965, 2.7578830192599844, 2.765597452701527, 2.7732478645136465, 2.780835480871258, 2.788361491444405, 2.795827050864399, 2.803233280116169, 2.8105812678612585, 2.817872071695613, 2.8251067193460084, 2.8322862098087054, 2.839411514433677, 2.8464835779575224], [0.0, 0.9013344775740003, 1.0718733737282615, 1.1862228829132528, 1.2746794424196195, 1.3478094125129467, 1.41066469233948, 1.4660895354719874, 1.515857862273113, 1.5611571097717192, 1.602824543028034, 1.6414745557155297, 1.6775724890132342, 1.7114799745177744, 1.7434841068143214, 1.773816942221055, 1.8026689551480006, 1.8301985807252843, 1.8565391425776125, 1.881803986053052, 1.906090350669923, 1.929482338296274, 1.9520532207528385, 1.9738672568730735, 1.9949811398673623, 2.0154451623197245, 2.035304162881213, 2.0545983023065815, 2.0733637047177553, 2.091632991431688, 2.109435728401649, 2.126798803638806, 2.143746747456523, 2.160302005699947, 2.17648517406639, 2.1923152000292214, 2.207809557634348, 2.2229843994599543, 2.2378546892547706, 2.252434318151437, 2.2667362068547043, 2.280772395802786, 2.2945541249740162, 2.308091904744454, 2.3213955789832528, 2.3344743813919835, 2.3473369859443625, 2.3599915521581276, 2.3724457658265057, 2.384706875749129, 2.39678172692843, 2.408676790635081, 2.4203981916929957, 2.4319517332892318, 2.4433429195754983, 2.4545769762948617, 2.4656588696387556, 2.476593323514836, 2.487384835384989, 2.4980376908143476, 2.508555976856189, 2.5189435943835905, 2.529204269466543, 2.539341563882536, 2.549358884839239, 2.5592594939796793, 2.569046515733026, 2.5787229450676783, 2.588291654697687, 2.597755401788474, 2.6071168342033637, 2.616378496328452, 2.625542834509777, 2.6346122021336105, 2.6435888643778287, 2.652475002659807, 2.6612727188039766, 2.6699840389501666, 2.6786109172219916, 2.687155239172884, 2.6956188250258935, 2.7040034327220006, 2.7123107607904755, 2.720542451053711, 2.728700091177943, 2.7367852170803615, 2.7447993152022874, 2.7527438246573275, 2.760620139262745, 2.7684296094616325, 2.7761735441429227, 2.7838532123657354, 2.791469844994078, 2.7990246362474833, 2.8065187451727605, 2.813953297041666, 2.82132938467896, 2.8286480697250065, 2.835910383836774, 2.8431173298308474, 2.8502698827717983, 2.8573689910090505], [0.0, 0.904729394452974, 1.07591063303558, 1.190690844793804, 1.2794805799129934, 1.3528859973302676, 1.4159780243973923, 1.4716116276962383, 1.5215674091403395, 1.5670372782935749, 1.6088616538127065, 1.6476572435126322, 1.6838911413008757, 1.7179263408757495, 1.7500510181771018, 1.78049810357368, 1.809458788905948, 1.837092106057081, 1.8635318808212185, 1.8888918854667822, 1.9132697257691151, 1.9367498203697375, 1.9594057170709935, 1.981301916740128, 2.0024953261250538, 2.023036427239071, 2.0429702276200308, 2.0623370392899774, 2.0811731224339662, 2.09951122123861, 2.1173810130186723, 2.134809487060224, 2.15182126607116, 2.168438880439912, 2.184683003438414, 2.2005726539065464, 2.2161253717069958, 2.23135737025736, 2.2462836696680024, 2.260918213393139, 2.275273970803937, 2.2893630276894625, 2.303196666363934, 2.316785436791214, 2.3301392199178337, 2.343267284224516, 2.356178336355889, 2.368880566562882, 2.381381689587608, 2.393688981532629, 2.4058093131823877, 2.4177491801818887, 2.4295147304244695, 2.4411117889551543, 2.452545880657287, 2.4638222509569303, 2.4749458847509014, 2.4859215237396675, 2.4967536823250067, 2.5074466622138267, 2.518004565853474, 2.5284313088098407, 2.538730631187328, 2.5489061081790196, 2.5589611598259867, 2.5688990600563826, 2.5787229450676783, 2.5884358211089573, 2.5980405717144763, 2.607539964434645, 2.6169366571060855, 2.6262332036984364, 2.6354320597720093, 2.644535587577211, 2.6535460608238135, 2.6624656691455972, 2.67129652228361, 2.6800406540092285, 2.6887000258063614, 2.6972765303304627, 2.705771994660535, 2.714188183358922, 2.7225268013524806, 2.730789496647602, 2.7389778628905384, 2.7470934417835813, 2.755137725366799, 2.7631121581742852, 2.771018139273178, 2.778857024193075, 2.7866301267528977, 2.7943387207917345, 2.8019840418096975, 2.809567288524401, 2.8170896243482564, 2.824552178791406, 2.8319560487947846, 2.839302299997472, 2.84659196794222, 2.853826059222765, 2.861005552576305, 2.8681313999242652], [0.0, 0.9080865185231703, 1.0799029488658045, 1.1951090685408468, 1.2842282703036343, 1.3579060687170441, 1.4212322075130495, 1.4770722470235311, 1.5272133963327197, 1.5728519877504674, 1.6148315584236828, 1.6537711045472614, 1.6901394532455423, 1.72430094515537, 1.75654482553344, 1.7871048890689831, 1.8161730370463407, 1.8439088914585777, 1.8704467746790285, 1.8959008811439186, 1.9203691788083757, 1.943936399561014, 1.9666763641135123, 1.9886538126725424, 2.0099258631464076, 2.030543184868931, 2.0505509523846825, 2.0699896272990626, 2.08889560434558, 2.1073017492127, 2.1252378493369832, 2.1427309941519956, 2.159805897731609, 2.1764851740663906, 2.1927895731393208, 2.2087381843623266, 2.2243486126821925, 2.2396371316786525, 2.254618817196276, 2.269307664428403, 2.2837166908708535, 2.297858027158692, 2.31174299747073, 2.325382190917938, 2.338785525111471, 2.3519623029240355, 2.3649212633074757, 2.377670626903783, 2.3902181370816935, 2.402571096942758, 2.414736402766418, 2.4267205743006723, 2.43852978225147, 2.4501698732784742, 2.461646392765876, 2.472964605603619, 2.484129515185673, 2.495145880807243, 2.5060182336214227, 2.5167508912971996, 2.527347971504622, 2.537813404338831, 2.548150943782407, 2.5583641782946835, 2.5684565406072686, 2.5784313167966806, 2.588291654697687, 2.5980405717144763, 2.60768096208106, 2.6172156036172267, 2.626647164021871, 2.6359782067414907, 2.645211196448095, 2.6543485041575487, 2.6633924120165395, 2.6723451177837885, 2.681208739028831, 2.6899853170696337, 2.6986768206684646, 2.7072851495037384, 2.7158121374340882, 2.7242595555695113, 2.732629115163232, 2.7409224703367987, 2.7491412206499097, 2.7572869135255558, 2.765361046540228, 2.7733650695881646, 2.7813003869279362, 2.789168359119021, 2.7969703048554484, 2.8047075027030637, 2.8123811927464732, 2.8199925781513007, 2.827542826646959, 2.8350330719347965, 2.842464415026099, 2.849837925514148, 2.8571546427842196, 2.864415577165158, 2.8716217110259006, 2.8787739998201083], [0.0, 0.9114068171194505, 1.0838514715804344, 1.1994788272386536, 1.288923881609622, 1.362871073176282, 1.4264287556473265, 1.4824729668980785, 1.5327974507070874, 1.5786029136155242, 1.6207359770526288, 1.6598179004912503, 1.6963192252602788, 1.7306056241600476, 1.7629674000343882, 1.7936392024119794, 1.822813634238901, 1.850650901144984, 1.8772858166356072, 1.9028329926838916, 1.927390755451873, 1.9510441466391415, 1.9738672568730735, 1.9959250630743677, 2.017274891995427, 2.0379675982358103, 2.0580485215148534, 2.07755827138048, 2.096533375638743, 2.115006820147162, 2.133008501256132, 2.1505656074481596, 2.1677029431608688, 2.1844432050699005, 2.2008072190278125, 2.2168141442444482, 2.2324816500367577, 2.2478260694866745, 2.2628625335616044, 2.2776050886264665, 2.292066799773837, 2.3062598419928486, 2.3201955808676797, 2.3338846442269867, 2.3473369859443625, 2.3605619429072418, 2.3735682860202925, 2.3863642659832003, 2.3989576544773072, 2.411355781306992, 2.4235655679670325, 2.435593558044026, 2.4474459448062946, 2.4591285962910403, 2.4706470781584207, 2.482006674548756, 2.4932124071502657, 2.5042690526598896, 2.5151811587982853, 2.5259530590214276, 2.5365888860550827, 2.5470925843642664, 2.5574679216575, 2.5677184995148465, 2.577847763219244, 2.5878590108623167, 2.597755401788474, 2.607539964434645, 2.6172156036172267, 2.6267851073127395, 2.6362511529741663, 2.64561631342091, 2.654883062336727, 2.6640537794067902, 2.673130755122154, 2.682116195277356, 2.6910122251845436, 2.6998208936254953, 2.708544176560997, 2.7171839806153884, 2.725742146352564, 2.7342204513583517, 2.742620613142947, 2.750944291875976, 2.759193092965716, 2.7673685694931054, 2.775472224510327, 2.7835055132129654, 2.791469844994078, 2.7993665853878493, 2.807197057909939, 2.8149625458011003, 2.8226642936801456, 2.8303035091119138, 2.837881364095468, 2.845398996477385, 2.852857511294653, 2.860257982051381, 2.8676014519332202, 2.8748889349631486, 2.882121417102006, 2.889299857296944], [0.0, 0.9146912192286943, 1.0877573059372772, 1.203801343502716, 1.2935687276168015, 1.3677823998673804, 1.4315691227432643, 1.4878152983881654, 1.5383211346269172, 1.584291664941221, 1.6265765616977856, 1.665799323178612, 1.7024321863844938, 1.7368421418769384, 1.7693205386531026, 1.8001028718392538, 1.8293824384573887, 1.8573200214642784, 1.8840509201876072, 1.9096901596233076, 1.9343364202676692, 1.9580750502818227, 1.9809804072907224, 2.003117702369927, 2.0245444688580787, 2.0453117446175235, 2.0654650327566206, 2.0850450891663788, 2.1040885732867167, 2.1226285898450357, 2.140695142928072, 2.158315518996434, 2.1755146118745543, 2.192315200029222, 2.2087381843623266, 2.2248027931270293, 2.2405267593145264, 2.2559264748656567, 2.2710171252747196, 2.2858128075249846, 2.300326633791206, 2.314570822937062, 2.3285567815044543, 2.342295175621143, 2.3557959950311154, 2.3690686102687932, 2.3821218238462203, 2.3949639161958145, 2.407602687005432, 2.4200454924935872, 2.432299279097787, 2.4443706139855026, 2.4562657127435017, 2.467990464555409, 2.47955045513814, 2.490950987674271, 2.5021971019484877, 2.513293591871332, 2.5242450215519088, 2.535055740062504, 2.5457298950218306, 2.556271445109423, 2.5666841716113495, 2.576971689086552, 2.587137455233603, 2.597184780029334, 2.6071168342033637, 2.6169366571060855, 2.626647164021871, 2.6362511529741663, 2.6457513110645903, 2.6551502203841175, 2.6644503635308237, 2.673654128765463, 2.682763814833246, 2.6917816354776476, 2.700709723669722, 2.709550135574365, 2.718304854273057, 2.726975793260967, 2.7355647997347607, 2.744073657686083, 2.7525040908144573, 2.760857765272199, 2.7691362922529335, 2.77734123043438, 2.7854740882852114, 2.7935363262450457, 2.801529358785917, 2.809454556362933, 2.817313247261257, 2.825106719346008, 2.8328362217211835, 2.840502966303278, 2.8481081293148436, 2.855652852702871, 2.8631382454865286, 2.870565385038471, 2.877935318303638, 2.8852490629592036, 2.8925076085190775, 2.8997119173861328], [0.0, 0.9179406175334197, 1.0916215135207343, 1.2080777921692967, 1.2981640707688962, 1.3726413836620537, 1.4366547059245063, 1.493100693510252, 1.5437859493992674, 1.5899197878990334, 1.6323548997980941, 1.671716998327296, 1.708479998087565, 1.7430121933574254, 1.7756059681378888, 1.8064976541407807, 1.8358812350668394, 1.8639180650468632, 1.8907439240531478, 1.9164742457026112, 1.9412080610494473, 1.965031021450187, 1.9880177486818125, 2.010233685479216, 2.031736569565567, 2.052577620112862, 2.0728025018771485, 2.092452115532857, 2.1115632507508724, 2.1301691298616108, 2.1482998635399415, 2.1659828351803623, 2.1832430270414687, 2.2001032985094997, 2.2165846247358343, 2.232706302281114, 2.248486127132168, 2.2639405494614473, 2.279084808709018, 2.2939330519370325, 2.3084984379006395, 2.322793228870466, 2.3368288719096273, 2.3506160710368085, 2.3641648514841025, 2.3774846170743213, 2.3905842015900256, 2.403471914879488, 2.4161555843385933, 2.4286425923184853, 2.4409399099335674, 2.45305412768087, 2.4649914832277466, 2.476757886678874, 2.488358943594169, 2.499799975995519, 2.5110860415712124, 2.5222219512619364, 2.533212285390583, 2.5440614084793167, 2.5547734828810733, 2.5653524813384143, 2.575802198570253, 2.586126261976083, 2.5963281415377923, 2.606411158990752, 2.616378496328452, 2.6262332036984364, 2.6359782067414907, 2.64561631342091, 2.6551502203841175, 2.664582518894846, 2.673915700370487, 2.6831521615559804, 2.6922942093627227, 2.701344065398411, 2.71030387021138, 2.719175687270956, 2.7279615067034255, 2.7366632488015608, 2.7452827673241074, 2.753821852600259, 2.762282234452902, 2.77066558495328, 2.7789735210187105, 2.7872076068640426, 2.7953693563167143, 2.803460235004489, 2.8114816624242462, 2.819435013899572, 2.8273216224343027, 2.835142780468637, 2.8428997415439574, 2.8505937218820367, 2.8582259018839014, 2.8657974275532574, 2.8733094118490126, 2.8807629359711373, 2.8881590505837953, 2.8954987769794123, 2.9027831081870996, 2.910013010028622], [0.0, 0.9211558703193814, 1.0954451150103321, 1.212309302805974, 1.3027111248652612, 1.3774493079968595, 1.4416868484808525, 1.4983305483318308, 1.5491933384829668, 1.5954887690834965, 1.63807251762544, 1.6775724890132342, 1.71446425781928, 1.7491174083393233, 1.7818253487021416, 1.8128252384140606, 1.8423117406387628, 1.8704467746790285, 1.8973665961010275, 1.9231870428487672, 1.9480074928505935, 1.971913897472381, 1.9949811398673623, 2.017274891995427, 2.038853093816547, 2.0597671439071177, 2.0800628669722427, 2.09978130694835, 2.1189593823687916, 2.1376304319311945, 2.1558246717785052, 2.173569581220506, 2.1908902300206643, 2.207809557634348, 2.224348612682192, 2.240526759314526, 2.256361855851836, 2.271870410086274, 2.2870677148367973, 2.3019679667181965, 2.316584370576538, 2.3309292316332666, 2.345014037046902, 2.3588495283288893, 2.3724457658265057, 2.385812186301152, 2.3989576544773072, 2.411890509309988, 2.424618605611948, 2.4371493515923475, 2.449489742783178, 2.4616463927658754, 2.47362556105635, 2.4854331784604873, 2.4970748701726904, 2.508555976856189, 2.519881573914738, 2.531056489140214, 2.5420853188989163, 2.5529724430005367, 2.563722038377404, 2.5743380916873284, 2.584824410940911, 2.5951846362432667, 2.6054222497305224, 2.6155405847730266, 2.625542834509777, 2.6354320597720093, 2.645211196448095, 2.654883062336727, 2.6644503635308237, 2.673915700370487, 2.6832815729997477, 2.6925503865585774, 2.701724456038747, 2.7108060108295344, 2.7197971989769334, 2.728700091177943, 2.7375166845296266, 2.746248906050928, 2.754898615993719, 2.763467610958144, 2.771957626826106, 2.7803703415255807, 2.7887073776374303, 2.796970304855448, 2.8051606423095277, 2.8132798607610567, 2.8213293846789598, 2.8293105942041428, 2.837224827009527, 2.8450733800623182, 2.852857511294653, 2.86057844118834, 2.8682373542789747, 2.8758354005843474, 2.883373696961705, 2.890853328398117, 2.898275349237888, 2.9056407843507035, 2.9129506302439405, 2.920205856122328], [0.0, 0.9243378032579611, 1.0992290923003527, 1.2164969620573964, 1.3072110575815623, 1.3822074075384925, 1.4466668426578508, 1.5035062058706188, 1.5545446904862257, 1.6010000385993937, 1.643730883454241, 1.6833672989163568, 1.7203865023272384, 1.7551593546313318, 1.7879802774720857, 1.8190872495718449, 1.8486756065159222, 1.8769078269221715, 1.9039206370220298, 1.9298302748965297, 1.954736461753492, 1.9787254458591215, 2.001872369034244, 2.024243130088275, 2.045895869122197, 2.066882162257628, 2.0872479924911636, 2.1070345455365995, 2.126278867454344, 2.145014412103317, 2.1632715000015685, 2.181077705380191, 2.1984581846007054, 2.215435956357848, 2.232032141980142, 2.248266172507171, 2.264155967947111, 2.2797180931146976, 2.29496789365461, 2.3099196152207635, 2.324586508272497, 2.33898092053697, 2.3531143788525988, 2.3669976618350463, 2.3806408645828756, 2.3940534564547304, 2.4072443327963553, 2.4202218613678763, 2.432993924114793, 2.4455679548363145, 2.4579509732289795, 2.4701496157194045, 2.4821701634456383, 2.4940185677002478, 2.5057004731086487, 2.5172212387822324, 2.5285859576566336, 2.5397994742002874, 2.550866400656643, 2.561791131964494, 2.5725778594844746, 2.583230583645438, 2.593753125611932, 2.604149138063024, 2.6144221151631246, 2.624575401796986, 2.6346122021336105, 2.644535587577211, 2.6543485041575487, 2.6640537794067902, 2.673654128765463, 2.6831521615559804, 2.6925503865585774, 2.7018512172212596, 2.711056976532434, 2.7201699015823206, 2.7291921478368706, 2.7381257931458567, 2.74697284150488, 2.755735226589354, 2.764414815076985, 2.7730134097738834, 2.7815327525581792, 2.789974527153886, 2.798340361746719, 2.8066318314526386, 2.814850460649042, 2.822997725177743, 2.8310750544281853, 2.8390838333086705, 2.8470254041128222, 2.854901068287936, 2.8627120881114037, 2.870459688280922, 2.8781450574238083, 2.8857693495303387, 2.8933336853157017, 2.900839153514819, 2.908286812113998, 2.9156776895231156, 2.923012785691765, 2.930293073172584], [0.0, 0.9274872110731568, 1.1029743904822287, 1.220641815839165, 1.311664992827256, 1.386916870676514, 1.451595932265776, 1.508628958806044, 1.5598413419701658, 1.6064549729490671, 1.6493314105258192, 1.689102875356448, 1.726248210759469, 1.7611395412783635, 1.7940722917112943, 1.8252852516227527, 1.8549744221463136, 1.8833028354976902, 1.9104076837625343, 1.9364056010687778, 1.961396648394778, 1.9854673678722108, 2.0086931573454425, 2.0311401401546014, 2.0528666544958774, 2.0739244522212745, 2.094359673000858, 2.1142136428765665, 2.133523534132309, 2.152322914611139, 2.1706422081393097, 2.1885090828989533, 2.2059487809644573, 2.2229843994599547, 2.2396371316786525, 2.2559264748656567, 2.271870410086274, 2.28748555859495, 2.3027873183221113, 2.3177899834595275, 2.332506849613561, 2.3469503065826007, 2.361131920479358, 2.375062506644442, 2.3887521945724806, 2.4022104858861564, 2.4154463062394758, 2.4284680519032347, 2.44128363167833, 2.4539005046924456, 2.46632571455966, 2.478565920318253, 2.4906274245073927, 2.5025161986969175, 2.5142379067446345, 2.5257979260215238, 2.5372013668158924, 2.5484530901022695, 2.5595577238389606, 2.570519677939213, 2.5813431580444846, 2.592032178213907, 2.6025905726315153, 2.613022006421803, 2.623329985654512, 2.6335178666111, 2.6435888643778287, 2.6535460608238135, 2.6633924120165395, 2.673130755122154, 2.682763814833246, 2.6922942093627227, 2.701724456038747, 2.711056976532434, 2.7202941017470885, 2.7294380763951525, 2.738491063286691, 2.747455147351135, 2.7563323394121095, 2.765124579733454, 2.773833741353028, 2.7824616332194707, 2.7910100031458467, 2.799480540592961, 2.8078748792940913, 2.8161945997319395, 2.8244412314777683, 2.832616255401886, 2.840721105763958, 2.8487571721909526, 2.8567258015499606, 2.864628299722576, 2.8724659332870264, 2.8802399311138047, 2.8879514858801243, 2.895601755508142, 2.903191864531552, 2.9107229053948185, 2.9181959396890242, 2.9256119993280487, 2.932972087668518, 2.9402771805767554], [0.0, 0.9306048591020996, 1.1066819197003215, 1.224744871391589, 1.3160740129524924, 1.3915788418568702, 1.4564753151219703, 1.5137000520175454, 1.5650845800732873, 1.6118548977353129, 1.6548754598234365, 1.694780612135097, 1.7320508075688774, 1.7670594215246977, 1.800102871839254, 1.831420750742353, 1.8612097182041991, 1.8896333544556798, 1.9168293127388174, 1.9429146192345599, 1.9679896712654303, 1.9921413018651277, 2.0154451623197245, 2.0379675982358108, 2.0597671439071177, 2.080895725143909, 2.101399636709763, 2.121320343559643, 2.1406951429280725, 2.159557715492783, 2.177938587346431, 2.195865519674754, 2.213363839400643, 2.230456721286719, 2.2471654298651536, 2.263509527918935, 2.2795070569547775, 2.295174694097678, 2.3105278890365413, 2.325580984011519, 2.340347319320716, 2.3548393264094916, 2.3690686102687937, 2.38304602259383, 2.39678172692843, 2.410285256833955, 2.4235655679670325, 2.4366310848216144, 2.449489742783178, 2.4621490260524586, 2.4746160019198826, 2.4868973518073663, 2.4989993994393833, 2.5109281364585576, 2.5226892457611436, 2.5342881227935714, 2.5457298950218306, 2.557019439760091, 2.5681614005230395, 2.579160202047371, 2.5900200641113513, 2.600745014266939, 2.611338899586365, 2.6218053975140414, 2.6321480259049848, 2.6423701523224317, 2.652475002659807, 2.6624656691455972, 2.6723451177837885, 2.682116195277356, 2.6917816354776476, 2.701344065398411, 2.7108060108295344, 2.7201699015823206, 2.7294380763951525, 2.7386127875258306, 2.7476962050544724, 2.756690420918775, 2.7655974527015275, 2.774419247188558, 2.7831576837137404, 2.791814577306299, 2.8003916816543826, 2.808890691897737, 2.8173132472612576, 2.8256609335402674, 2.833935285447518, 2.8421377888311037, 2.8502698827717983, 2.8583329615676507, 2.8663283766131, 2.874257438179321, 2.882121417102006, 2.8899215463823635, 2.8976590227066628, 2.905335007889291, 2.9129506302439405, 2.920506985887209, 2.928005139978604, 2.9354461279006707, 2.9428309563827115, 2.9501606045713182], [0.0, 0.9336914847572161, 1.110352556890736, 1.2288070992040003, 1.320439160815927, 1.3961944237683348, 1.4613061453392517, 1.5187206849628931, 1.5702756449705226, 1.6172010901939202, 1.6603643426724282, 1.7004018521985302, 1.7377956652346387, 1.772920395590378, 1.8060734442596784, 1.8374951981506853, 1.8673829695144322, 1.8959008811439184, 1.9231870428487672, 1.949358868961793, 1.9745170898028677, 1.9987488264130728, 2.0221299809982978, 2.0447271192199157, 2.066598969517919, 2.087797629929844, 2.108369548769516, 2.1283563285226585, 2.1477953901310802, 2.16672052598442, 2.1851623634241295, 2.203148755714112, 2.220705113781472, 2.2378546892547706, 2.254618817196276, 2.271017125274719, 2.287067714836797, 2.3027873183221113, 2.3181914366630214, 2.333294459669949, 2.348109771888037, 2.362649845995201, 2.376926325473765, 2.3909500980117886, 2.4047313608634924, 2.418279679211108, 2.431604038415341, 2.4447128909124634, 2.4576141984080007, 2.470315469926249, 2.4828237961983883, 2.495145880807243, 2.5072880684517855, 2.5192563706476903, 2.531056489140214, 2.542693837271378, 2.5541735595139254, 2.5655005493590783, 2.5766794657231107, 2.5877147480186613, 2.598610630020137, 2.6093711526380607, 2.6200001757046136, 2.630501388861538, 2.640878321631854, 2.6511343527483158, 2.6612727188039766, 2.67129652228361, 2.681208739028831, 2.6910122251845436, 2.700709723669722, 2.71030387021138, 2.7197971989769334, 2.7291921478368706, 2.738491063286691, 2.7476962050544724, 2.7568097504180447, 2.765833798253632, 2.7747703728359334, 2.783621427407866, 2.7923888475366696, 2.801074454271648, 2.8096800071175756, 2.8182072068366284, 2.8266576980906746, 2.8350330719347965, 2.843334868172072, 2.8515645775788507, 2.859723644009041, 2.867813466385294, 2.875835400584347, 2.883790761223275, 2.891680823352873, 2.8995068240639617, 2.907269964011973, 2.914971408864794, 2.9226122906785035, 2.9301937092052928, 2.9377167331375857, 2.9451824012920786, 2.9525917237371893, 2.9599456828671373], [0.0, 0.9367477988974472, 1.1139871474119822, 1.2328294348193778, 1.3247614417239144, 1.4007646793929587, 1.4660895354719874, 1.5236920139085786, 1.5754157321793416, 1.6224947815686916, 1.665799323178612, 1.70596789013482, 1.7434841068143216, 1.7787238132749208, 1.8119853840129065, 1.8435099928108025, 1.8734955977948944, 1.9021068589921832, 1.9294823382962738, 1.9557398343800885, 1.9809804072907224, 2.005291463248328, 2.0287491529145085, 2.0514202598444236, 2.0733637047177553, 2.0946317561079946, 2.115271014371307, 2.135323218173586, 2.1548259109490866, 2.173812995702313, 2.1923152000292214, 2.210360468367647, 2.2279742948239645, 2.2451800071378294, 2.2619990102089815, 2.2784509959547, 2.2945541249740162, 2.3103251844779353, 2.3257797261390447, 2.3409321868708846, 2.3557959950311154, 2.3703836641252947, 2.384706875749129, 2.398776553230067, 2.4126029272016765, 2.4261955941565336, 2.4395635688677193, 2.4527153314394257, 2.4656588696387556, 2.4784017170697905, 2.4909509876742715, 2.5033134069783034, 2.5154953404493816, 2.5275028192810733, 2.5393415638825356, 2.5510170053156402, 2.5625343048928735, 2.573898372123646, 2.5851138811745704, 2.5961852859901096, 2.607116834203364, 2.6179125799522365, 2.6285763957035524, 2.6391119831766026, 2.649522883447829, 2.6598124863098143, 2.6699840389501666, 2.6800406540092285, 2.6899853170696337, 2.6998208936254953, 2.709550135574365, 2.719175687270956, 2.728700091177943, 2.7381257931458567, 2.747455147351135, 2.756690420918775, 2.765833798253632, 2.7748873851023217, 2.783853212365736, 2.7927332396804703, 2.8015293587859174, 2.8102433966923415, 2.818877118664021, 2.827432231030349, 2.835910383836774, 2.844313173346485, 2.8526421444028993, 2.8608987926622222, 2.869084566704626, 2.8772008700319467, 2.8852490629592036, 2.893230464406695, 2.9011463535989224, 2.90899797167616, 2.9167865232240224, 2.9245131777260567, 2.932179070943975, 2.9397853062298593, 2.9473329557743555, 2.9548230617945888, 2.962256637665299, 2.9696346689964424], [0.0, 0.9397744871152784, 1.1175865065755222, 1.236812780528175, 1.3290418252506462, 1.4052906339306293, 1.4708265585304046, 1.5286151540232698, 1.5805059947242717, 1.6277371593406456, 1.6711816205169887, 1.7114799745177744, 1.7491174083393235, 1.7844709764011664, 1.8178400172654527, 1.8494664839616353, 1.879548974230557, 1.9082526801256237, 1.9357166112422137, 1.9620589468678131, 1.9873810735805804, 2.011770680015397, 2.0353041628812134, 2.058048521514854, 2.080062866972243, 2.101399636709763, 2.1221055816521197, 2.1422225753253343, 2.1617882824687458, 2.180836715629496, 2.1993987016862424, 2.2175022753669724, 2.2351730131510443, 2.2524343181514372, 2.2693076644284034, 2.2858128075249846, 2.301967966718197, 2.3177899834595275, 2.333294459669949, 2.348495878909535, 2.3634077129237725, 2.3780425156501046, 2.392412006428173, 2.4065271438793507, 2.4203981916929957, 2.434034777368526, 2.4474459448062946, 2.460640201510217, 2.47362556105635, 2.4864095813903013, 2.4989993994393833, 2.5114017624602782, 2.5236230564876885, 2.5356693322023287, 2.54754632849634, 2.55925949397968, 2.5708140066413447, 2.582214791853664, 2.5934665388857625, 2.6045737160730646, 2.615540584773027, 2.626371212222715, 2.6370694834011266, 2.6476391119880285, 2.6580836505012924, 2.6684064996861254, 2.6786109172219916, 2.6887000258063614, 2.6986768206684646, 2.708544176560997, 2.718304854273057, 2.7279615067034255, 2.7375166845296266, 2.74697284150488, 2.7563323394121095, 2.7655974527015275, 2.7747703728359334, 2.783853212365736, 2.7928480087537886, 2.8017567279683915, 2.8105812678612585, 2.8193234613458356, 2.827985079390074, 2.8365678338366203, 2.8450733800623187, 2.8535033194879786, 2.8618592019485005, 2.8701425279326442, 2.8783547507010305, 2.8864972782902947, 2.8945714754107152, 2.9025786652440995, 2.910520131148202, 2.9183971182734942, 2.9262108350976797, 2.933962454882976, 2.941653117060809, 2.9492839285482595, 2.9568559650002837, 2.9643702720014726, 2.9718278662008415, 2.979229736392911], [0.0, 0.9427722109457612, 1.1211514210835454, 1.2407580069594817, 1.333281246947964, 1.4097732766069795, 1.4755182498728112, 1.533491181344376, 1.5855475451702188, 1.6329293693221016, 1.6765124110817191, 1.716939310108757, 1.75469680106511, 1.790163141111003, 1.8236386236486597, 1.8553659734973313, 1.8855444218915225, 1.9143396878197294, 1.9418912242947493, 1.9683175875762793, 1.993720487648747, 2.0181878928591512, 2.0417964436091975, 2.0646133529524175, 2.086697920499143, 2.1081027509724937, 2.128874744424825, 2.149055907951721, 2.1686840264367557, 2.1877932209214217, 2.2064144166169766, 2.2245757376775126, 2.2423028421670907, 2.259619207850716, 2.27654637728731, 2.293104169036802, 2.3093108604926607, 2.3251833468277954, 2.340737279730703, 2.355987188961597, 2.370946589238585, 2.3856280745440763, 2.4000434016004517, 2.414203563985258, 2.4281188581273097, 2.441798942236141, 2.455252889060639, 2.4684892332422375, 2.4815160139189634, 2.4943408131450107, 2.5069707906132983, 2.519412715103133, 2.531672993019601, 2.5437576943440803, 2.5556725762748194, 2.567423104801933, 2.579014474431339, 2.5904516262464825, 2.6017392644744746, 2.612881871703984, 2.6238837228854868, 2.6347488982298564, 2.6454812951085245, 2.656084639047278, 2.666562493895928, 2.67691827124749, 2.687155239172884, 2.6972765303304627, 2.7072851495037384, 2.7171839806153884, 2.726975793260967, 2.7366632488015608, 2.746248906050928, 2.755735226589354, 2.765124579733454, 2.774419247188558, 2.783621427407866, 2.7927332396804703, 2.8017567279683915, 2.8106938645110393, 2.819546553213959, 2.8283166328372835, 2.8370058799980575, 2.84561601199942, 2.85414868949859, 2.862605519024644, 2.8709880553561957, 2.879297803768314, 2.887536222157279, 2.895704723051128, 2.903804675513337, 2.9118374069464434, 2.919804204801898, 2.927706318201995, 2.93554495947928, 2.943321305638482, 2.9510364997456224, 2.9586916522486626, 2.9662878422337196, 2.973826118620624, 2.9813075013013313, 2.988732982224453], [0.0, 0.9457416090031757, 1.1246826503806981, 1.2446659545769565, 1.337480609952844, 1.414213562373095, 1.4801656089845705, 1.5383211346269172, 1.5905414575341013, 1.63807251762544, 1.681792830507429, 1.722347059926734, 1.7602234735867868, 1.7958015200236968, 1.8293824384573887, 1.861209718204199, 1.8914832180063514, 1.9203691788083757, 1.9480074928505935, 1.9745170898028677, 1.9999999999999998, 2.0245444688580787, 2.0482273781688902, 2.0711161526832442, 2.0932702787842112, 2.114742526881128, 2.1355799447448813, 2.1558246717785052, 2.1755146118745543, 2.194683993543699, 2.213363839400643, 2.2315823621805877, 2.2493653007613963, 2.266736206854704, 2.283716690870853, 2.300326633791206, 2.316584370576538, 2.3325068496135604, 2.348109771888037, 2.363407712923772, 2.378414230005442, 2.3931419567820336, 2.407602687005432, 2.421807448879054, 2.435766571261813, 2.449489742783178, 2.4629860647679758, 2.476264098738734, 2.489331909153913, 2.5021971019484877, 2.5148668593658705, 2.5273479715046214, 2.539646864947731, 2.551769628794865, 2.563722038377404, 2.575509576901394, 2.587137455233603, 2.598610630020137, 2.609933820304753, 2.621111522794684, 2.6321480259049848, 2.643047422697745, 2.6538136228197344, 2.664450363530824, 2.674961219905688, 2.68534961428265, 2.6956188250258935, 2.705771994660535, 2.7158121374340882, 2.725742146352564, 2.7355647997347607, 2.7452827673241074, 2.754898615993719, 2.764414815076985, 2.773833741353028, 2.7831576837137404, 2.7923888475366696, 2.8015293587859174, 2.8105812678612585, 2.819546553213959, 2.82842712474619, 2.837224827009527, 2.845941442216729, 2.8545786930798287, 2.8631382454865286, 2.8716217110259006, 2.8800306493735595, 2.8883665705456574, 2.8966309370303307, 2.904825165804578, 2.91295063024394, 2.921008661931802, 2.9290005523746294, 2.936927554629009, 2.9447908848459035, 2.9525917237371893, 2.960331217969141, 2.968010481487236, 2.975630596776331, 2.983192616059981, 2.990697562442441, 2.998146430996607], [0.0, 0.9486832980505138, 1.128180927925918, 1.2485374350863452, 1.3416407864998738, 1.4186124135047635, 1.4847696011519296, 1.5431060170831203, 1.5954887690834967, 1.6431676725154982, 1.6870239755710472, 1.7277043471959719, 1.7656985738296271, 1.8013872842666538, 1.8350726547187572, 1.8669989318654348, 1.8973665961010275, 1.9263424054554514, 1.9540666872978918, 1.9806587412238905, 2.006220914929266, 2.0308417283137197, 2.0545983023065815, 2.07755827138048, 2.09978130694835, 2.121320343559643, 2.142222575325334, 2.162530272721279, 2.182281457538478, 2.2015104647539276, 2.2202484134768556, 2.238523604196976, 2.256361855851836, 2.2737867934096694, 2.2908200944990793, 2.3074817019403757, 2.32379000772445, 2.3397620129552488, 2.355413467455784, 2.370758992086407, 2.3858121863011523, 2.400585723045433, 2.4150914327550987, 2.429340377936324, 2.4433429195754983, 2.45710877643816, 2.4706470781584207, 2.483966412889059, 2.4970748701726904, 2.5099800796022267, 2.5226892457611436, 2.535209179868313, 2.54754632849634, 2.5597067996847738, 2.5716963867289198, 2.5835205898901012, 2.5951846362432662, 2.606693497851958, 2.618051908438318, 2.6292643786963965, 2.6403352103801803, 2.6512685092830544, 2.662068197212579, 2.6727380230532125, 2.6832815729997477, 2.693702280035545, 2.7040034327220006, 2.714188183358922, 2.7242595555695113, 2.7342204513583517, 2.744073657686083, 2.753821852600259, 2.763467610958144, 2.7730134097738834, 2.7824616332194707, 2.791814577306299, 2.801074454271648, 2.8102433966923415, 2.8193234613458356, 2.8283166328372835, 2.837224827009527, 2.8460498941515415, 2.85479362201958, 2.8634577386841014, 2.8720439152144785, 2.8805537682125633, 2.8889888622052755, 2.8973507119056077, 2.9056407843507035, 2.9138605009250087, 2.92201123927589, 2.9300943351285653, 2.9381110840066778, 2.946062742864391, 2.953950531635456, 2.9617756347043014, 2.969539202303859, 2.9772423518444873, 2.9848861691780644, 2.9924717098010434, 3.0, 3.0074720379429634], [0.0, 0.9515978740065268, 1.1316469623900245, 1.2523732327608301, 1.345762619345434, 1.4229707211083644, 1.489331159038138, 1.547846798020459, 1.6003904820302886, 1.6482158661538315, 1.6922069059826197, 1.7330122571800355, 1.771123210923403, 1.8069215653876352, 1.8407104251401096, 1.872734787242987, 1.9031957480130537, 1.9322605777997164, 1.960070035090509, 1.986743785997105, 2.0123844926512717, 2.037080946906452, 2.0609105066254236, 2.0839410140696626, 2.1062323239765757, 2.1278375335228743, 2.14880398181083, 2.1691740691810413, 2.1889859342363023, 2.208274017438652, 2.2270695335024673, 2.245400869863155, 2.263293924780049, 2.2807723958027863, 2.297858027158692, 2.3145708229370623, 2.3309292316332666, 2.3469503065826007, 2.362649845995201, 2.378042515650104, 2.393141956782034, 2.407960881270643, 2.4225111558976327, 2.4368038771557736, 2.450849437862816, 2.4646575866426104, 2.478237481177628, 2.4915977360054535, 2.5047464655216602, 2.5176913227590454, 2.5304395344352426, 2.542997932694775, 2.5553729839156167, 2.5675708149026395, 2.579597236749499, 2.5914577666156022, 2.603157647634689, 2.6147018671456377, 2.626095173413688, 2.6373420909907916, 2.648446934846925, 2.659413823389427, 2.6702466904745625, 2.680949296504237, 2.691525238690868, 2.70197796056474, 2.7123107607904755, 2.7225268013524806, 2.732629115163232, 2.742620613142947, 2.7525040908144573, 2.762282234452902, 2.771957626826106, 2.7815327525581792, 2.7910100031458467, 2.8003916816543826, 2.8096800071175756, 2.818877118664021, 2.827985079390074, 2.8370058799980575, 2.845941442216729, 2.85479362201958, 2.8635642126552705, 2.8722549475032912, 2.8808675027669306, 2.8894035000146174, 2.8978645085798624, 2.906252047829209, 2.9145675893068805, 2.9228125587641465, 2.9309883380808275, 2.9390962670858003, 2.9471376452828575, 2.9551137334878192, 2.963025755382357, 2.9708748989896043, 2.978662318076276, 2.986389133485675, 2.9940564344056693, 3.0016652795754433, 3.009216698434564, 3.0167116922176644], [0.0, 0.9544859128947005, 1.1350814387842454, 1.2561741056899516, 1.34984692310975, 1.4272893465399143, 1.4938511841686706, 1.5525444143852343, 1.6052475651266458, 1.653218096242383, 1.6973426460728507, 1.7382718389100207, 1.7764984569686235, 1.812405457156695, 1.8462968639446533, 1.8784184179451258, 1.908971825789401, 1.938124865481734, 1.9660187227026953, 1.9927734267429793, 2.0184919513073796, 2.0432633577269526, 2.0671652386406607, 2.090265642206917, 2.1126246048184423, 2.1342953847984933, 2.1553254649205007, 2.175757374207393, 2.1956293670101927, 2.2149759883155467, 2.2338285475724984, 2.2522155183705133, 2.2701628775684908, 2.2876943946366195, 2.3048318797945697, 2.3215953978427732, 2.338003453266607, 2.3540731511571518, 2.3698203376711047, 2.385259723097208, 2.4004049900704616, 2.415268889050264, 2.429863322833242, 2.4441994215893144, 2.4582876096777713, 2.472137665308914, 2.4857587739581977, 2.4991595763077785, 2.512348211379903, 2.5253323554338367, 2.5381192571198388, 2.5507157693175553, 2.5631283780300076, 2.575363228656527, 2.5874261499270697, 2.5993226757452694, 2.611058065157442, 2.6226373206387223, 2.6340652048650317, 2.645346256120049, 2.65648480246941, 2.6674849748195557, 2.678350718965756, 2.6890858067224945, 2.6996938462195, 2.7101782914379524, 2.720542451053711, 2.730789496647602, 2.7409224703367987, 2.750944291875976, 2.760857765272199, 2.77066558495328, 2.7803703415255807, 2.789974527153886, 2.799480540592961, 2.808890691897737, 2.8182072068366284, 2.827432231030349, 2.8365678338366203, 2.84561601199942, 2.8545786930798287, 2.8634577386841014, 2.8722549475032912, 2.8809720581775866, 2.889610751997445, 2.898172655452653, 2.9066593426395477, 2.9150723375358543, 2.9234131161518375, 2.9316831085658324, 2.939883700851576, 2.94801623690424, 2.956082020171529, 2.964082315295759, 2.972018349672396, 2.9798913149301494, 2.987702368337341, 2.995452634138963, 3.003143204828499, 3.0107751423583387, 3.018349479292333, 3.0258672199037986], [0.0, 0.9573479717381596, 1.1384850195244434, 1.259940786957369, 1.3538944855424797, 1.4315691227432643, 1.4983305483318308, 1.5571997722182047, 1.6100609551700658, 1.658175327573506, 1.7024321863844938, 1.7434841068143216, 1.7818253487021418, 1.8178400172654527, 1.8518330486025054, 1.884050920187607, 1.914695943476319, 1.9439363995610137, 1.971913897472381, 1.9987488264130728, 2.0245444688580787, 2.04939015319192, 2.0733637047177553, 2.096533375638743, 2.1189593823687916, 2.1406951429280725, 2.1617882824687453, 2.182281457538478, 2.2022130371952797, 2.2216176700101276, 2.2405267593145264, 2.2589688640769774, 2.2769700390488867, 2.2945541249740162, 2.31174299747073, 2.3285567815044543, 2.345014037046902, 2.361131920479358, 2.376926325473765, 2.3924120064281724, 2.407602687005432, 2.4225111558976327, 2.4371493515923475, 2.4515284376336917, 2.4656588696387556, 2.47955045513814, 2.4932124071502657, 2.50665339226667, 2.519881573914738, 2.5329046513712625, 2.5457298950218306, 2.558364178294683, 2.5708140066413443, 2.583085543888338, 2.5951846362432662, 2.607116834203364, 2.618887412584378, 2.6305013888615374, 2.641963539991811, 2.6532784178670767, 2.6644503635308237, 2.6754835202761598, 2.686381845729956, 2.6971491230166134, 2.7077889710849594, 2.718304854273057, 2.728700091177943, 2.7389778628905384, 2.7491412206499097, 2.759193092965716, 2.7691362922529335, 2.7789735210187105, 2.7887073776374303, 2.798340361746719, 2.8078748792940913, 2.8173132472612576, 2.8266576980906746, 2.835910383836774, 2.8450733800623187, 2.85414868949859, 2.8631382454865286, 2.8720439152144785, 2.8808675027669306, 2.889610751997445, 2.898275349237888, 2.9068629258551293, 2.9153750606654905, 2.9238132822163942, 2.932179070943975, 2.9404738612147048, 2.948699043258512, 2.9568559650002832, 2.9649459337961566, 2.9729702180805213, 2.9809300489292307, 2.9888266215441335, 2.9966610966636615, 3.004434601903893, 3.012148233034192, 3.0198030551912485, 3.027400104035091, 3.034940386850385], [0.0, 0.9601845894041878, 1.1418583454354265, 1.2636739857523107, 1.357906068717044, 1.4358108555129503, 1.502770094900495, 1.561813748028264, 1.6148315584236825, 1.6630884934927144, 1.7074764851741444, 1.748650042256635, 1.7871048890689831, 1.8232262689306922, 1.8573200214642784, 1.8896333544556796, 1.9203691788083757, 1.9496962742308461, 1.9777566693406925, 2.004671110053224, 2.0305431848689306, 2.0554624868519302, 2.079507071901399, 2.102745394451461, 2.1252378493369832, 2.1470380128554885, 2.1681936512722433, 2.188747547526072, 2.208738184362327, 2.228200313015543, 2.247165429865153, 2.2656621784997513, 2.283716690870853, 2.301352878362235, 2.3185926814096187, 2.3354562846086107, 2.3519623029240355, 2.3681279435714577, 2.3839691473156965, 2.3995007122720162, 2.414736402766418, 2.4296890453838276, 2.4443706139855026, 2.4587923051930876, 2.4729646056036185, 2.4868973518073663, 2.50059978412088, 2.514080594814771, 2.5273479715046214, 2.5404096362801454, 2.5532728810690504, 2.565944599665513, 2.5784313167966806, 2.590739214552467, 2.602874156462761, 2.6148417094708947, 2.626647164021871, 2.6382955524576737, 2.6497916658893743, 2.6611400696960854, 2.6723451177837885, 2.683410965722149, 2.6943415828644692, 2.70514076354453, 2.715812137434088, 2.7263591791360233, 2.7367852170803615, 2.7470934417835813, 2.7572869135255558, 2.7673685694931054, 2.77734123043438, 2.7872076068640426, 2.796970304855448, 2.8066318314526386, 2.8161945997319395, 2.8256609335402674, 2.8350330719347965, 2.844313173346485, 2.8535033194879786, 2.862605519024644, 2.8716217110259006, 2.8805537682125633, 2.8894035000146174, 2.898172655452653, 2.9068629258551293, 2.9154759474226504, 2.9240133036495615, 2.932476527612365, 2.9408671041337215, 2.949186471830124, 2.957436025050745, 2.9656171157143674, 2.973731055050819, 2.981779115252854, 2.989762531043999, 2.9976825011674793, 3.00554018980099, 3.0133367279017307, 3.0210732144858237, 3.0287507178459556, 3.036370276710811, 3.0439329013496343], [0.0, 0.9629962874017586, 1.1452020366993765, 1.2673743884191842, 1.3618824101585059, 1.4400153246867797, 1.507170640080316, 1.5663871900896853, 1.6195602519575492, 1.6679584972800465, 1.7124764698304722, 1.7537705949883924, 1.7923380487067173, 1.828565202408735, 1.8627587913037733, 1.8951667470736167, 1.9259925748035172, 1.955405548437723, 1.983548112494678, 2.0105413664686305, 2.03648920219714, 2.0614814750987107, 2.085596469642752, 2.1089028407177555, 2.1314611600121216, 2.153325160710257, 2.1745427489508584, 2.1951568329535602, 2.2152060081523164, 2.2347251275433204, 2.2537457797365072, 2.2722966921971777, 2.290404073398753, 2.308091904744454, 2.325382190917938, 2.342295175621143, 2.3588495283288893, 2.375062506644442, 2.3909500980117886, 2.4065271438793503, 2.421807448879054, 2.436803877155773, 2.4515284376336917, 2.465992359721398, 2.480206160723717, 2.4941797060352964, 2.5079222630310047, 2.5214425494349326, 2.5347487768383683, 2.547848689943536, 2.5607496020310148, 2.5734584270820036, 2.585981708929937, 2.5983256477676733, 2.610496124295213, 2.6224987217575073, 2.63433874609151, 2.6460212443753583, 2.65755102174988, 2.6689326569629386, 2.6801705166700103, 2.691268768609469, 2.7022313937580313, 2.713062197560384, 2.7237648203170117, 2.734342746805436, 2.7447993152022874, 2.755137725366799, 2.765361046540228, 2.775472224510327, 2.7854740882852114, 2.7953693563167143, 2.8051606423095277, 2.814850460649042, 2.8244412314777683, 2.833935285447518, 2.843334868172072, 2.8526421444028993, 2.8618592019485005, 2.8709880553561957, 2.8800306493735595, 2.8889888622052755, 2.8978645085798624, 2.9066593426395477, 2.9153750606654905, 2.9240133036495615, 2.932575659723036, 2.9410636664517082, 2.9494788130062264, 2.9578225422157702, 2.9660962525125694, 2.9743012997742158, 2.9824389990701965, 2.990510626318614, 2.9985174198586226, 3.006460581943714, 3.014341280160632, 3.0221606487783457, 3.029919790031215, 3.0376197753401954, 3.045261646475669, 3.0528464166652416], [0.0, 0.9657835706352026, 1.148516693752116, 1.2710426594494582, 1.3658242239094176, 1.4441832852728287, 1.5115329740892762, 1.5709209196680185, 1.624247884916149, 1.6727862134554565, 1.7174330382144525, 1.7588466845213098, 1.797525767348191, 1.8338577764265274, 1.8681503347758255, 1.900652091687926, 1.9315671412704052, 1.9610652474116923, 1.9892892669196895, 2.0163606497973583, 2.042383588585367, 2.0674481987785094, 2.091632991431688, 2.115006820147162, 2.1376304319311945, 2.1595577154927827, 2.1808367156294954, 2.2015104647539276, 2.2216176700101276, 2.241193285272322, 2.2602689905800855, 2.2788735965470996, 2.297033387504232, 2.3147724142661468, 2.332112745206556, 2.3490746826204902, 2.365676950019442, 2.3819368549568463, 2.3978704311505283, 2.4134925630057946, 2.428817095110509, 2.4438569288433487, 2.4586241078869633, 2.4731298941521875, 2.487384835384989, 2.5013988255342774, 2.515181158798285, 2.528740578133563, 2.5420853188989163, 2.555223148212729, 2.5681614005230395, 2.5809070098227784, 2.593466538885762, 2.605846205850603, 2.618051908438318, 2.630089246053925, 2.6419635399918104, 2.6536798519383042, 2.665243000942169, 2.6766575790039315, 2.6879279654178565, 2.699058339985363, 2.7100526952056514, 2.720914847537835, 2.731648447818835, 2.742256990912465, 2.7527438246573275, 2.7631121581742852, 2.7733650695881646, 2.7835055132129654, 2.7935363262450457, 2.803460235004489, 2.8132798607610567, 2.822997725177743, 2.832616255401886, 2.8421377888311037, 2.8515645775788507, 2.8608987926622222, 2.8701425279326442, 2.879297803768314, 2.8883665705456574, 2.8973507119056077, 2.906252047829209, 2.9150723375358543, 2.9238132822163942, 2.932476527612365, 2.9410636664517082, 2.949576240750525, 2.9580157439897006, 2.966383623174519, 2.9746812807848126, 2.9829100766226073, 2.9910713295637095, 2.9991663192192206, 3.0071962875125275, 3.015162440176908, 3.0230659481785525, 3.030907949069442, 3.0386895482742298, 3.046411820314977, 3.054075809977351, 3.06168253342163], [0.0, 0.9685469281169012, 1.1518028981306478, 1.2746794424196195, 1.369732201537721, 1.4483154685151653, 1.5158578622731127, 1.5754157321793416, 1.6288952797169989, 1.6775724890132342, 1.722347059926734, 1.7638792014253155, 1.8026689551480006, 1.8391049195349223, 1.8734955977948944, 1.9060903506699227, 1.9370938562338025, 1.966676364113512, 1.994981139867362, 2.0221299809982973, 2.0482273781688902, 2.0733637047177553, 2.0976176963403033, 2.12105840364682, 2.1437467474565235, 2.1657367706679937, 2.187076655547436, 2.207809557634348, 2.227974294823965, 2.24760592100262, 2.266736206854704, 2.2853940454285424, 2.3036057962612957, 2.3213955789832528, 2.338785525111471, 2.3557959950311154, 2.3724457658265057, 2.3887521945724806, 2.4047313608634924, 2.4203981916929957, 2.4357665712618135, 2.450849437862816, 2.4656588696387556, 2.480206160723717, 2.4945018890435056, 2.508555976856189, 2.5223777449531117, 2.535975961306694, 2.549358884839239, 2.5625343048928735, 2.575509576901394, 2.588291654697687, 2.6008871198333665, 2.6133022082387543, 2.625542834509777, 2.637614614072805, 2.649522883447829, 2.6612727188039766, 2.6728689529785594, 2.6843161911110114, 2.6956188250258935, 2.706781046484122, 2.717806859408474, 2.728700091177943, 2.739464403075442, 2.7501032999644965, 2.760620139262745, 2.771018139273178, 2.7813003869279362, 2.791469844994078, 2.801529358785917, 2.8114816624242462, 2.8213293846789598, 2.8310750544281853, 2.840721105763958, 2.8502698827717983, 2.859723644009041, 2.869084566704626, 2.8783547507010305, 2.887536222157279, 2.8966309370303307, 2.9056407843507035, 2.9145675893068805, 2.9234131161518375, 2.932179070943975, 2.9408671041337215, 2.9494788130062264, 2.9580157439897006, 2.966479394838265, 2.974871216697461, 2.983192616059981, 2.9914449566185963, 2.9996295610227595, 3.0077477125448726, 3.015800656661786, 3.0237896025566937, 3.0317157245462254, 3.0395801634371935, 3.047384027817157, 3.0551283952826642, 3.062814313608786, 3.070442801863298], [0.0, 0.9712868336416696, 1.1550612132751377, 1.2782853608787121, 1.3736070130904692, 1.452412582902289, 1.5201460461607854, 1.5798723982871963, 1.633503233184822, 1.6823181445900717, 1.7272193775068816, 1.7688690085567114, 1.8077684939376608, 1.8443075313892177, 1.8787954968395464, 1.91148245644291, 1.9425736672833391, 1.9722398606040152, 2.0006247072446897, 2.0278503492591406, 2.0540215729017546, 2.0792290071667088, 2.1035516104834504, 2.1270586287983337, 2.1498111552684196, 2.171863385673303, 2.1932636385811617, 2.2140551916134474, 2.2342769724766613, 2.253964134220466, 2.2731485374047877, 2.291859156812992, 2.3101224265502753, 2.327962534478528, 2.34540167472227, 2.362460265263805, 2.3791571363056208, 2.395509694023681, 2.411534063499723, 2.4272452139539125, 2.4426570688638467, 2.4577826031233077, 2.472633929042694, 2.48722237270587, 2.5015585419623516, 2.5156523871391085, 2.5295132553949102, 2.5431499395057404, 2.5565707217574243, 2.5697834135272224, 2.5827953910565906, 2.595613627849991, 2.6082447240774744, 2.620694933310077, 2.6329701868754243, 2.645076116085267, 2.657018072555984, 2.66880114681659, 2.6804301853759265, 2.691909806400825, 2.7032444141398027, 2.714438212211775, 2.725495215866147, 2.7364192633091173, 2.7472140261809384, 2.7578830192599844, 2.7684296094616325, 2.778857024193075, 2.789168359119021, 2.7993665853878493, 2.809454556362933, 2.819435013899572, 2.8293105942041428, 2.8390838333086705, 2.8487571721909526, 2.8583329615676507, 2.867813466385294, 2.8772008700319467, 2.8864972782902947, 2.895704723051128, 2.904825165804578, 2.9138605009250087, 2.9228125587641465, 2.9316831085658324, 2.9404738612147048, 2.949186471830124, 2.9578225422157702, 2.966383623174519, 2.974871216697461, 2.9832867780352594, 2.991631717659408, 2.9999074031204045, 3.0081151608093224, 3.01625627762879, 3.024332002578966, 3.032343548263682, 3.040292092321571, 3.0481787787866534, 3.056004719382553, 3.0637709947542113, 3.0714786556407327, 3.0791287239927163], [0.0, 0.9740037464252967, 1.158292185288269, 1.281861019188702, 1.3774493079968595, 1.45647531512197, 1.5243982444638442, 1.584291664941221, 1.63807251762544, 1.6870239755710472, 1.7320508075688772, 1.7738169422210552, 1.8128252384140608, 1.8494664839616353, 1.884050920187607, 1.9168293127388172, 1.9480074928505935, 1.9777566693406925, 2.006220914929266, 2.0335227133295235, 2.0597671439071177, 2.0850450891663783, 2.1094357284016496, 2.133008501256132, 2.1558246717785052, 2.177938587346431, 2.1993987016862424, 2.2202484134768556, 2.2405267593145264, 2.260268990580086, 2.2795070569547775, 2.2982700142711043, 2.316584370576538, 2.3344743813919835, 2.3519623029240355, 2.3690686102687932, 2.385812186301152, 2.402210485886156, 2.418279679211108, 2.4340347773685256, 2.4494897427831783, 2.46465758664261, 2.47955045513814, 2.494179706035296, 2.5085559768561887, 2.5226892457611436, 2.5365888860550827, 2.550263715109408, 2.563722038377404, 2.5769716890865517, 2.5900200641113513, 2.602874156462761, 2.615540584773027, 2.6280256201058623, 2.64033521038018, 2.652475002659807, 2.6644503635308237, 2.6762663977616263, 2.6879279654178565, 2.6994396975844213, 2.7108060108295344, 2.7220311205306014, 2.7331190531686027, 2.7440736576860836, 2.754898615993719, 2.765597452701527, 2.7761735441429227, 2.7866301267528977, 2.7969703048554484, 2.807197057909939, 2.817313247261257, 2.8273216224343027, 2.837224827009527, 2.8470254041128222, 2.8567258015499606, 2.8663283766131, 2.875835400584347, 2.8852490629592036, 2.8945714754107152, 2.903804675513337, 2.91295063024394, 2.92201123927589, 2.9309883380808275, 2.939883700851576, 2.948699043258512, 2.957436025050745, 2.9660962525125694, 2.9746812807848126, 2.983192616059981, 2.991631717659408, 2.9999999999999996, 3.0082988344576096, 3.0165295511335306, 3.024693440530154, 3.0327917551413806, 3.040825710962972, 3.0487964889276884, 3.0567052362696767, 3.0645530678223074, 3.072341067253335, 3.0800702882410227, 3.0877417555945996], [0.0, 0.9766981117095218, 1.161496343654686, 1.2854070033206721, 1.381259715923798, 1.460504330965901, 1.5286151540232695, 1.588674256361194, 1.642603881843218, 1.6916907531374747, 1.7368421418769384, 1.7787238132749206, 1.8178400172654527, 1.854582622690067, 1.8892627290863886, 1.9221317957887882, 1.9533962234190436, 1.9832276944061233, 2.0117706800153967, 2.039148002784094, 2.0654650327566206, 2.0908129038435934, 2.115271014371307, 2.138908996072332, 2.1617882824687458, 2.1839633712781743, 2.2054828502634343, 2.226390238156261, 2.2467246795389917, 2.266521523307584, 2.2858128075249846, 2.3046276684002125, 2.322992687309372, 2.340932186870885, 2.358468484858204, 2.37562211300724, 2.3924120064281724, 2.4088556682710576, 2.424969313454433, 2.440767994595675, 2.4562657127435017, 2.471475515078023, 2.4864095813903013, 2.501079300864602, 2.515495340449381, 2.5296677059073316, 2.543605796472544, 2.557318453907722, 2.5708140066413443, 2.584100309569777, 2.597184780029334, 2.610074430375586, 2.6227758975497575, 2.6352954699630677, 2.647639111988028, 2.6598124863098143, 2.6718209743599775, 2.6836696950281222, 2.6953635218241843, 2.706907098643939, 2.718304854273057, 2.7295610157498498, 2.7406796206936646, 2.751664528694292, 2.762519431847596, 2.7732478645136465, 2.7838532123657354, 2.7943387207917345, 2.8047075027030637, 2.8149625458011003, 2.825106719346008, 2.835142780468637, 2.8450733800623182, 2.854901068287936, 2.864628299722576, 2.874257438179321, 2.883790761223275, 2.893230464406695, 2.9025786652440995, 2.9118374069464434, 2.921008661931802, 2.9300943351285653, 2.9390962670858003, 2.94801623690424, 2.9568559650002832, 2.9656171157143674, 2.9743012997742158, 2.9829100766226073, 2.9914449566185963, 2.9999074031204045, 3.0082988344576096, 3.0166206257996713, 3.0248741109273123, 3.033060583912814, 3.0411813007148214, 3.0492374806928804, 3.057230308046539, 3.065160933183514, 3.0730304740211136, 3.080840017224819, 3.088590619387661, 3.0962833081537764], [0.0, 0.9793703613355592, 1.164674201923033, 1.288923881609622, 1.3850388475869866, 1.4645002761873147, 1.5327974507070874, 1.593020874969912, 1.6470980521056138, 1.6963192252602786, 1.741594148365405, 1.7835904081703773, 1.822813634238901, 1.8596567675671005, 1.8944317588620794, 1.9273907554518728, 1.9587407226711184, 1.988653812672542, 2.017274891995427, 2.0447271192199157, 2.0711161526832442, 2.0965333756387428, 2.12105840364682, 2.1447610589527217, 2.1677029431608688, 2.1899387030948425, 2.211517059453757, 2.232481650036758, 2.252871726525904, 2.272722734531862, 2.2920667997738366, 2.3109331381776226, 2.329348403846066, 2.3473369859443625, 2.3649212633074757, 2.3821218238462203, 2.3989576544773072, 2.4154463062394758, 2.431604038415341, 2.447445944806294, 2.462986064767976, 2.478237481177628, 2.4932124071502657, 2.5079222630310047, 2.5223777449531117, 2.5365888860550827, 2.550565111287347, 2.5643152866037044, 2.577847763219244, 2.591170417521358, 2.604290687140218, 2.6172156036172267, 2.6299518220523037, 2.6425056480617855, 2.654883062336727, 2.667089743055433, 2.6791310863730695, 2.6910122251845436, 2.7027380463337307, 2.7143132064221227, 2.725742146352564, 2.737029104728559, 2.7481781302163952, 2.759193092965716, 2.770077695173973, 2.780835480871258, 2.791469844994078, 2.8019840418096975, 2.8123811927464732, 2.8226642936801456, 2.8328362217211835, 2.8428997415439574, 2.852857511294653, 2.8627120881114037, 2.8724659332870264, 2.882121417102006, 2.891680823352873, 2.9011463535989224, 2.910520131148202, 2.919804204801898, 2.9290005523746294, 2.9381110840066778, 2.9471376452828575, 2.956082020171529, 2.9649459337961566, 2.973731055050819, 2.9824389990701965, 2.9910713295637095, 2.9996295610227595, 3.0081151608093224, 3.0165295511335306, 3.0248741109273123, 3.03315017762062, 3.0413590488263207, 3.049501983939367, 3.057580205655478, 3.065594901414175, 3.073547224770694, 3.08143829670097, 3.089269206843605, 3.0970410146824725, 3.1047547506733464], [0.0, 0.9820209142881303, 1.167826258352922, 1.2924122054704554, 1.3887872955203007, 1.4684637773145044, 1.5369457902618242, 1.5973322022781031, 1.6515557330581283, 1.7009101176422834, 1.74630757210618, 1.7884174899457608, 1.8277468691528413, 1.8646897141730423, 1.8995588199720859, 1.932607016285675, 1.9640418285762606, 1.9940358749065195, 2.0227344138803187, 2.0502609373922973, 2.0767213897317967, 2.1022074014703853, 2.126798803638806, 2.1505656074481596, 2.1735695812205065, 2.1958655196747543, 2.217502275366972, 2.2385236041969763, 2.2589688640769774, 2.2788735965471, 2.2982700142711043, 2.3171874122443183, 2.335652516705844, 2.3536897828273413, 2.371321650009509, 2.3885687618819693, 2.405450156747334, 2.421983433144204, 2.4381848943590683, 2.454069675042952, 2.4696518525473916, 2.484944545156928, 2.499959999039964, 2.5147096654494634, 2.529204269466543, 2.5434538713832313, 2.5574679216575, 2.5712553102378295, 2.584824410940911, 2.5981831214706688, 2.611338899586365, 2.6242987958594575, 2.6370694834011266, 2.6496572848931312, 2.662068197212579, 2.674307913905108, 2.686381845729956, 2.698295139473619, 2.710052695205652, 2.721659182130101, 2.7331190531686027, 2.7444365583959525, 2.7556157574356863, 2.7666605309115617, 2.7775745910406013, 2.788361491444405, 2.7990246362474833, 2.809567288524401, 2.8199925781513007, 2.8303035091119138, 2.840502966303278, 2.8505937218820367, 2.86057844118834, 2.870459688280922, 2.8802399311138047, 2.8899215463823635, 2.8995068240639617, 2.90899797167616, 2.9183971182734942, 2.927706318201995, 2.936927554629009, 2.946062742864391, 2.9551137334878192, 2.964082315295759, 2.9729702180805213, 2.981779115252854, 2.990510626318614, 2.9991663192192206, 3.0077477125448726, 3.01625627762879, 3.024693440530154, 3.033060583912814, 3.0413590488263207, 3.049590136395381, 3.0577551094233564, 3.0658551939150485, 3.0738915805236484, 3.081865425926356, 3.0897778541328984, 3.097629957730859, 3.1054227990714813, 3.11315741139935], [0.0, 0.9846501772118187, 1.1709529965289849, 1.295872510077541, 1.3925056348060254, 1.4723954424229517, 1.541060809120647, 1.6016088997243154, 1.6559776085927063, 1.7054641346125685, 1.7509831362269537, 1.793205799166037, 1.8326404788581239, 1.8696822346563888, 1.9046446990038355, 1.9377813785625346, 1.9693003544236374, 1.9993747068174434, 2.028150083263225, 2.0557503062928357, 2.082281603850872, 2.1078358518406057, 2.132493095032392, 2.156323532085357, 2.1793890967000746, 2.201744730302841, 2.2234394162475644, 2.244517027586113, 2.2650170276075774, 2.2849750530110056, 2.3044234027063477, 2.3233914501233563, 2.3419059930579698, 2.3599915521581276, 2.3776706269037833, 2.394963916195815, 2.4118905093099885, 2.4284680519032347, 2.444712890912464, 2.460640201510217, 2.4762640987387345, 2.491597736005454, 2.5066533922666703, 2.521442549434933, 2.535975961306694, 2.5502637151094083, 2.5643152866037044, 2.578139589540013, 2.591745020155082, 2.6051394972981505, 2.6183304986958853, 2.6313250937969457, 2.6441299735791004, 2.656751477652458, 2.669195618950164, 2.6814681062617582, 2.6935743648332457, 2.705519555231128, 2.717308590644407, 2.7289461527784584, 2.7404367064771695, 2.751784513194487, 2.7629936434231848, 2.7740679881770016, 2.785011269612051, 2.795827050864399, 2.8065187451727605, 2.8170896243482564, 2.827542826646959, 2.837881364095468, 2.8481081293148436, 2.8582259018839014, 2.8682373542789747, 2.8781450574238083, 2.8879514858801243, 2.8976590227066628, 2.907269964011973, 2.9167865232240224, 2.9262108350976797, 2.93554495947928, 2.9447908848459035, 2.953950531635456, 2.963025755382357, 2.972018349672396, 2.9809300489292307, 2.989762531043999, 2.9985174198586226, 3.0071962875125275, 3.015800656661786, 3.024332002578966, 3.0327917551413806, 3.0411813007148214, 3.049501983939367, 3.0577551094233564, 3.0659419433511785, 3.074063715010143, 3.082121618241294, 3.090116812818721, 3.098050425761573, 3.1059235525827282, 3.11373725847777, 3.1214925794576915], [0.0, 0.9872585449014338, 1.1740548859440185, 1.2993053150100684, 1.3961944237683348, 1.4762958618685946, 1.5451431251708252, 1.6058516094725332, 1.6603643426724282, 1.709981959975803, 1.7556215427832071, 1.7979560548158353, 1.8374951981506855, 1.8746350786649428, 1.9096901596233076, 1.9429146192345597, 1.9745170898028677, 2.004671110053224, 2.0335227133295235, 2.0611960501732, 2.087797629929844, 2.1134195718847355, 2.138142132849214, 2.1620356974407473, 2.18516236342413, 2.2075772177671347, 2.2293293735820354, 2.250462820141724, 2.2710171252747196, 2.29102802008275, 2.3105278890365413, 2.3295461833769373, 2.348109771888037, 2.366243240173708, 2.3839691473156965, 2.401308247046888, 2.418279679211108, 2.4349011362091595, 2.4511890082814753, 2.4671585108000826, 2.4828237961983888, 2.4981980527275995, 2.5132935918713324, 2.5281219259580654, 2.542693837271378, 2.5570194397600914, 2.571108234286407, 2.5849691582135454, 2.598610630020137, 2.612040589532689, 2.6252665342865877, 2.638295552457674, 2.6511343527483158, 2.6637892915624386, 2.676266397761627, 2.6885713952581733, 2.7007097236697226, 2.7126865572332703, 2.7245068221530033, 2.736175212536273, 2.7476962050544724, 2.7590740724502676, 2.7703128959992873, 2.7814165770226826, 2.7923888475366696, 2.803233280116169, 2.813953297041666, 2.824552178791406, 2.8350330719347965, 2.845398996477385, 2.855652852702871, 2.8657974275532574, 2.8758354005843474, 2.8857693495303387, 2.895601755508142, 2.905335007889291, 2.914971408864794, 2.9245131777260567, 2.933962454882976, 2.943321305638482, 2.9525917237371893, 2.9617756347043014, 2.9708748989896043, 2.9798913149301494, 2.9888266215441335, 2.9976825011674793, 3.006460581943714, 3.015162440176908, 3.0237896025566937, 3.032343548263682, 3.040825710962972, 3.0492374806928804, 3.057580205655478, 3.0658551939150485, 3.074063715010143, 3.0822070014844885, 3.0902862503416504, 3.0983026244279936, 3.1062572537481756, 3.11415123671712, 3.121985641352145, 3.1297615064086686], [0.0, 0.989846400767953, 1.1771323825530846, 1.3027111248652612, 1.3998542046322333, 1.4801656089845705, 1.5491933384829668, 1.6100609551700655, 1.664716580115127, 1.7144642578192797, 1.7602234735867868, 1.8026689551480006, 1.842311740638763, 1.879548974230557, 1.914695943476319, 1.9480074928505933, 1.979692801535906, 2.0099258631464076, 2.038853093816547, 2.066598969517919, 2.093270278784211, 2.1189593823687916, 2.1437467474565235, 2.1677029431608688, 2.1908902300206647, 2.2133638394006434, 2.2351730131510443, 2.256361855851836, 2.2769700390488867, 2.297033387504232, 2.316584370576538, 2.335652516705844, 2.354264765106169, 2.3724457658265057, 2.3902181370816935, 2.4076026870054315, 2.4246186056119483, 2.44128363167833, 2.4576141984080007, 2.47362556105635, 2.4893319091539134, 2.50474646552166, 2.519881573914738, 2.5347487768383683, 2.549358884839239, 2.563722038377404, 2.577847763219244, 2.5917450201550816, 2.6054222497305224, 2.618887412584378, 2.6321480259049848, 2.645211196448095, 2.6580836505012924, 2.670771761130255, 2.6832815729997477, 2.6956188250258935, 2.70778897108496, 2.7197971989769334, 2.7316484478188356, 2.7433474240224682, 2.7548986159937194, 2.7663063076751997, 2.7775745910406013, 2.7887073776374303, 2.7997084092644666, 2.8105812678612585, 2.82132938467896, 2.8319560487947846, 2.842464415026099, 2.852857511294653, 2.8631382454865286, 2.8733094118490126, 2.883373696961705, 2.8933336853157017, 2.903191864531552, 2.9129506302439405, 2.9226122906785035, 2.932179070943975, 2.941653117060809, 2.9510364997456224, 2.960331217969141, 2.969539202303859, 2.978662318076276, 2.987702368337341, 2.9966610966636615, 3.00554018980099, 3.014341280160632, 3.0230659481785525, 3.0317157245462254, 3.040292092321571, 3.0487964889276884, 3.057230308046539, 3.065594901414175, 3.0738915805236484, 3.082121618241294, 3.0902862503416504, 3.0983866769659336, 3.106424064008624, 3.1143995444364094, 3.1223142195434384, 3.1301691601465746, 3.1379654077240775], [0.0, 0.9924141172814958, 1.1801859293002996, 1.3060904298413636, 1.4034855041500147, 1.484005240743618, 1.553212032004312, 1.6142375426680784, 1.6690349473383785, 1.7189116732801692, 1.7647895909936366, 1.8073451784903223, 1.847090799567362, 1.8844246286102666, 1.9196627710453875, 1.953060732427983, 1.9848282345629915, 2.015139722413657, 2.04414199192601, 2.071959841969225, 2.0987003380923746, 2.1244560806377484, 2.149307745526554, 2.1733260849324516, 2.196573520901572, 2.2191054280718734, 2.240971176029689, 2.262214983764716, 2.2828766257330146, 2.302992019628042, 2.3225937190357833, 2.3417113289946903, 2.3603718586005993, 2.3786000218460974, 2.396418495618929, 2.413848142030249, 2.4309082008742458, 2.4476164569433796, 2.463989386069716, 2.4800422830816236, 2.4957893743180684, 2.5112439169007508, 2.526418286605205, 2.541324055878551, 2.555972063310636, 2.57037247566643, 2.5845348434226794, 2.5984681506144955, 2.612180859682727, 2.625680951916526, 2.638975964004231, 2.6520730211369132, 2.6649788670505217, 2.6776998913428183, 2.6902421543587653, 2.702611409901553, 2.7148131259951045, 2.72685250389685, 2.738734495536154, 2.750463819533511, 2.762044975937984, 2.7734822598049687, 2.7847797737229634, 2.7959414393862456, 2.8069710083000294, 2.817872071695613, 2.8286480697250065, 2.839302299997472, 2.849837925514148, 2.860257982051381, 2.870565385038471, 2.8807629359711373, 2.890853328398117, 2.900839153514819, 2.9107229053948185, 2.920506985887209, 2.9301937092052928, 2.9397853062298593, 2.9492839285482595, 2.9586916522486626, 2.968010481487236, 2.9772423518444873, 2.986389133485675, 2.995452634138963, 3.004434601903893, 3.0133367279017307, 3.0221606487783457, 3.030907949069442, 3.0395801634371935, 3.0481787787866534, 3.0567052362696767, 3.065160933183514, 3.073547224770694, 3.081865425926356, 3.090116812818721, 3.0983026244279936, 3.106424064008624, 3.1144823004794873, 3.12247846974625, 3.130413675959879, 3.138288992714996, 3.1461054641915127], [0.0, 0.9949620563926881, 1.1832159566199232, 1.309443706292189, 1.4070888341971637, 1.4878152983881654, 1.5571997722182047, 1.618381960706977, 1.6733200530681511, 1.7233248332753461, 1.7693205386531028, 1.8119853840129068, 1.8518330486025056, 1.8892627290863888, 1.9245913424647911, 1.9580750502818227, 1.9899241127853762, 2.0203134228113497, 2.04939015319192, 2.077279423206778, 2.1040885732867167, 2.1299104415175543, 2.1548259109490866, 2.178905915405181, 2.2022130371952793, 2.2248027931270298, 2.2467246795389917, 2.26802302894937, 2.2887377179317685, 2.308904756395278, 2.3285567815044543, 2.3477234743061772, 2.3664319132398464, 2.384706875749129, 2.402571096942758, 2.4200454924935872, 2.4371493515923475, 2.4539005046924456, 2.470315469926249, 2.4864095813903013, 2.502197101948488, 2.5176913227590454, 2.5329046513712625, 2.547848689943536, 2.5625343048928735, 2.576971689086552, 2.591170417521358, 2.6051394972981505, 2.618887412584378, 2.6324221651604756, 2.6457513110645907, 2.6588819937811183, 2.6718209743599775, 2.684574658803681, 2.697149123016613, 2.709550135574365, 2.7217831785395497, 2.733853466523383, 2.7457659641688887, 2.75752540221122, 2.769136292252934, 2.780602940376616, 2.7919294597038142, 2.803119781997423, 2.8141776683943274, 2.8251067193460084, 2.835910383836774, 2.84659196794222, 2.8571546427842196, 2.8676014519332202, 2.877935318303638, 2.8881590505837953, 2.898275349237888, 2.908286812113998, 2.9181959396890242, 2.928005139978604, 2.9377167331375857, 2.9473329557743555, 2.9568559650002837, 2.9662878422337196, 2.975630596776331, 2.9848861691780644, 2.9940564344056693, 3.003143204828499, 3.012148233034192, 3.0210732144858237, 3.029919790031215, 3.0386895482742298, 3.047384027817157, 3.056004719382553, 3.0645530678223074, 3.0730304740211136, 3.08143829670097, 3.0897778541328984, 3.098050425761573, 3.1062572537481756, 3.1143995444364094, 3.12247846974625, 3.130495168499706, 3.1384507476825574, 3.1463462836457885, 3.1541828232501565], [0.0, 0.997490569933681, 1.1862228829132528, 1.3127714172548886, 1.4106646923394799, 1.4915963080299905, 1.5611571097717192, 1.6224947815686916, 1.6775724890132342, 1.7277043471959719, 1.7738169422210552, 1.816590212458495, 1.8565391425776128, 1.8940639437279883, 1.9294823382962738, 1.9630511388141516, 1.994981139867362, 2.025447678749862, 2.0545983023065815, 2.082558447784909, 2.1094357284016496, 2.135323218173586, 2.160302005699947, 2.1844432050699005, 2.207809557634348, 2.230456721286719, 2.252434318151437, 2.2737867934096694, 2.2945541249740162, 2.3147724142661468, 2.3344743813919835, 2.353689782827341, 2.3724457658265057, 2.3907671708004723, 2.408676790635081, 2.426195594156533, 2.4433429195754983, 2.4601366426582087, 2.476593323514836, 2.492728335210717, 2.508555976856189, 2.524089573386529, 2.539341563882536, 2.554323579987364, 2.569046515733026, 2.5835205898901012, 2.597755401788474, 2.611759981418898, 2.625542834509777, 2.6391119831766026, 2.652475002659807, 2.665639054597641, 2.6786109172219916, 2.691397012815051, 2.7040034327220006, 2.7164359601782087, 2.728700091177943, 2.7408010535843985, 2.752743824657328, 2.7645331471541805, 2.7761735441429227, 2.7876693326492603, 2.7990246362474833, 2.810243396692342, 2.8213293846789598, 2.8322862098087054, 2.8431173298308474, 2.853826059222765, 2.864415577165158, 2.8748889349631486, 2.8852490629592036, 2.8954987769794123, 2.9056407843507035, 2.9156776895231156, 2.9256119993280487, 2.9354461279006707, 2.9451824012920786, 2.9548230617945888, 2.9643702720014726, 2.973826118620624, 2.983192616059981, 2.9924717098010434, 3.0016652795754433, 3.0107751423583387, 3.0198030551912485, 3.0287507178459556, 3.0376197753401954, 3.046411820314977, 3.0551283952826642, 3.0637709947542113, 3.072341067253335, 3.080840017224819, 3.089269206843605, 3.097629957730859, 3.1059235525827282, 3.11415123671712, 3.1223142195434384, 3.130413675959879, 3.1384507476825574, 3.1464265445104544, 3.154342145529904, 3.162198600262067], [0.0, 1.0, 1.189207115002721, 1.3160740129524924, 1.414213562373095, 1.4953487812212205, 1.5650845800732873, 1.6265765616977856, 1.681792830507429, 1.7320508075688772, 1.7782794100389228, 1.8211602868378718, 1.8612097182041993, 1.8988289221159418, 1.9343364202676692, 1.9679896712654301, 2.0, 2.0305431848689306, 2.0597671439071177, 2.087797629929844, 2.114742526881128, 2.1406951429280725, 2.1657367706679937, 2.1899387030948425, 2.2133638394006434, 2.23606797749979, 2.2581008643532257, 2.279507056954778, 2.3003266337912063, 2.320595787106084, 2.3403473193207156, 2.359611061770567, 2.378414230005442, 2.39678172692843, 2.414736402766418, 2.432299279097787, 2.4494897427831783, 2.46632571455966, 2.4828237961983883, 2.4989993994393833, 2.514866859365871, 2.5304395344352426, 2.5457298950218306, 2.5607496020310148, 2.575509576901394, 2.5900200641113513, 2.604290687140218, 2.6183304986958853, 2.6321480259049848, 2.6457513110645907, 2.6591479484724942, 2.6723451177837885, 2.68534961428265, 2.6981678764080854, 2.7108060108295344, 2.7232698153315003, 2.735564799734761, 2.7476962050544724, 2.7596690210718946, 2.771488002476036, 2.7831576837137404, 2.794682392671241, 2.806066263296683, 2.8173132472612576, 2.82842712474619, 2.839411514433677, 2.8502698827717983, 2.861005552576305, 2.8716217110259006, 2.882121417102006, 2.8925076085190775, 2.9027831081870996, 2.9129506302439405, 2.923012785691765, 2.932972087668518, 2.9428309563827115, 2.9525917237371893, 2.962256637665299, 2.9718278662008415, 2.9813075013013313, 2.990697562442441, 3.0, 3.009216698434564, 3.018349479292333, 3.027400104035091, 3.036370276710811, 3.045261646475669, 3.054075809977351, 3.062814313608786, 3.0714786556407327, 3.0800702882410227, 3.088590619387661, 3.0970410146824725, 3.1054227990714813, 3.11373725847777, 3.121985641352145, 3.1301691601465746, 3.138288992714996, 3.1463462836457885, 3.154342145529904, 3.162277660168379, 3.1701538797227005], [0.0, 1.0024906793143211, 1.1921690485645018, 1.319351931272669, 1.4177359148389301, 1.4990732154983035, 1.5689827038620388, 1.630627842293166, 1.6859816371213476, 1.7363647906866422, 1.78270853378059, 1.825696213092362, 1.865845394748944, 1.9035582960336908, 1.939154231976568, 1.9728913024304486, 2.0049813586286422, 2.0356006167763194, 2.0648973633247656, 2.0929976642991988, 2.1200096723479462, 2.146026928038831, 2.1711309264429612, 2.195393138122272, 2.218876618930505, 2.2416373057567642, 2.2637250694657207, 2.285184578028384, 2.306056009754172, 2.3263756470299297, 2.3461763739772747, 2.365488096231962, 2.3843380971290036, 2.402751341596634, 2.420750736774327, 2.438357356598474, 2.45559063621617, 2.4724685409992926, 2.489007714068684, 2.505223605550068, 2.521130586230765, 2.536742047839801, 2.5520704918112105, 2.5671276080939496, 2.5819243453284186, 2.59647097350871, 2.610777140083157, 2.624851920307043, 2.638703862545338, 2.652341029125897, 2.665771033261474, 2.67900107248938, 2.6920379590186645, 2.704888147324421, 2.717557759285845, 2.7300526071278615, 2.7423782143944453, 2.75453983515444, 2.7665424716170515, 2.7783908903136925, 2.7900896369850603, 2.8016430502967653, 2.8130552744932906, 2.8243302710881744, 2.8354718296778603, 2.8464835779575224, 2.8573689910090505, 2.8681313999242652, 2.8787739998201083, 2.889299857296944, 2.8997119173861328, 2.910013010028622, 2.920205856122328, 2.930293073172584, 2.9402771805767554, 2.9501606045713182, 2.9599456828671373, 2.9696346689964424, 2.979229736392911, 2.988732982224453, 2.998146430996607, 3.0074720379429634, 3.0167116922176644, 3.0258672199037986, 3.034940386850385, 3.0439329013496343, 3.0528464166652416, 3.06168253342163, 3.070442801863298, 3.0791287239927163, 3.0877417555945996, 3.0962833081537764, 3.1047547506733464, 3.11315741139935, 3.1214925794576915, 3.1297615064086686, 3.1379654077240775, 3.1461054641915127, 3.1541828232501565, 3.162198600262067, 3.1701538797227005, 3.1780497164141406]]}, {\"colorscale\": [[0.0, \"#440154\"], [0.1111111111111111, \"#482878\"], [0.2222222222222222, \"#3e4989\"], [0.3333333333333333, \"#31688e\"], [0.4444444444444444, \"#26828e\"], [0.5555555555555556, \"#1f9e89\"], [0.6666666666666666, \"#35b779\"], [0.7777777777777778, \"#6ece58\"], [0.8888888888888888, \"#b5de2b\"], [1.0, \"#fde725\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 1\", \"showscale\": false, \"type\": \"surface\", \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.1, 0.1414213562373095, 0.17320508075688776, 0.2, 0.223606797749979, 0.24494897427831783, 0.2645751311064591, 0.282842712474619, 0.3, 0.31622776601683794, 0.33166247903554, 0.3464101615137755, 0.36055512754639896, 0.37416573867739417, 0.38729833462074165, 0.4, 0.41231056256176607, 0.4242640687119285, 0.43588989435406744, 0.447213595499958, 0.45825756949558405, 0.469041575982343, 0.479583152331272, 0.48989794855663565, 0.5, 0.5099019513592785, 0.5196152422706632, 0.5291502622129182, 0.5385164807134505, 0.5477225575051661, 0.5567764362830022, 0.565685424949238, 0.574456264653803, 0.5830951894845301, 0.5916079783099616, 0.6, 0.608276253029822, 0.6164414002968976, 0.6244997998398399, 0.6324555320336759, 0.6403124237432849, 0.6480740698407861, 0.6557438524302001, 0.66332495807108, 0.6708203932499369, 0.6782329983125268, 0.6855654600401044, 0.692820323027551, 0.7000000000000001, 0.7071067811865476, 0.7141428428542851, 0.7211102550927979, 0.7280109889280519, 0.7348469228349535, 0.7416198487095663, 0.7483314773547883, 0.754983443527075, 0.7615773105863909, 0.7681145747868608, 0.7745966692414833, 0.7810249675906654, 0.787400787401181, 0.7937253933193772, 0.8, 0.8062257748298549, 0.812403840463596, 0.8185352771872451, 0.8246211251235321, 0.8306623862918076, 0.8366600265340756, 0.8426149773176359, 0.848528137423857, 0.8544003745317531, 0.8602325267042626, 0.8660254037844387, 0.8717797887081349, 0.8774964387392122, 0.8831760866327848, 0.8888194417315589, 0.894427190999916, 0.9, 0.9055385138137417, 0.9110433579144299, 0.9165151389911681, 0.9219544457292888, 0.9273618495495705, 0.9327379053088816, 0.938083151964686, 0.9433981132056604, 0.9486832980505138, 0.9539392014169457, 0.959166304662544, 0.9643650760992956, 0.9695359714832659, 0.9746794344808963, 0.9797958971132713, 0.9848857801796106, 0.9899494936611666, 0.9949874371066201, 1.0, 1.0049875621120892], [0.0, 0.1414213562373095, 0.19999999999999998, 0.24494897427831783, 0.282842712474619, 0.31622776601683794, 0.34641016151377546, 0.3741657386773941, 0.39999999999999997, 0.4242640687119285, 0.4472135954999579, 0.469041575982343, 0.48989794855663565, 0.5099019513592785, 0.529150262212918, 0.5477225575051661, 0.565685424949238, 0.58309518948453, 0.6, 0.6164414002968976, 0.6324555320336759, 0.6480740698407861, 0.6633249580710799, 0.6782329983125268, 0.6928203230275509, 0.7071067811865476, 0.7211102550927979, 0.7348469228349535, 0.7483314773547882, 0.7615773105863909, 0.7745966692414833, 0.7874007874011811, 0.7999999999999999, 0.812403840463596, 0.8246211251235321, 0.8366600265340756, 0.848528137423857, 0.8602325267042626, 0.8717797887081348, 0.8831760866327847, 0.8944271909999159, 0.9055385138137417, 0.9165151389911681, 0.9273618495495702, 0.938083151964686, 0.9486832980505137, 0.9591663046625439, 0.9695359714832658, 0.9797958971132713, 0.9899494936611665, 1.0, 1.0099504938362078, 1.019803902718557, 1.0295630140987002, 1.0392304845413265, 1.0488088481701516, 1.058300524425836, 1.0677078252031311, 1.0770329614269007, 1.0862780491200215, 1.0954451150103321, 1.104536101718726, 1.1135528725660042, 1.1224972160321824, 1.131370849898476, 1.1401754250991378, 1.1489125293076057, 1.1575836902790224, 1.16619037896906, 1.174734012447073, 1.1832159566199232, 1.1916375287812984, 1.2, 1.2083045973594573, 1.2165525060596438, 1.224744871391589, 1.2328828005937953, 1.2409673645990857, 1.2489995996796797, 1.2569805089976536, 1.2649110640673518, 1.2727922061357855, 1.2806248474865698, 1.2884098726725124, 1.2961481396815722, 1.3038404810405297, 1.3114877048604001, 1.3190905958272918, 1.3266499161421599, 1.3341664064126333, 1.3416407864998738, 1.349073756323204, 1.3564659966250536, 1.3638181696985856, 1.3711309200802089, 1.378404875209022, 1.3856406460551018, 1.392838827718412, 1.4, 1.407124727947029, 1.4142135623730951, 1.4212670403551897], [0.0, 0.17320508075688776, 0.24494897427831783, 0.3000000000000001, 0.3464101615137755, 0.38729833462074176, 0.42426406871192857, 0.45825756949558405, 0.48989794855663565, 0.5196152422706632, 0.5477225575051662, 0.574456264653803, 0.6000000000000002, 0.6244997998398399, 0.6480740698407861, 0.6708203932499369, 0.692820323027551, 0.7141428428542851, 0.7348469228349536, 0.7549834435270751, 0.7745966692414835, 0.7937253933193773, 0.8124038404635961, 0.8306623862918077, 0.8485281374238571, 0.8660254037844388, 0.8831760866327849, 0.9000000000000001, 0.9165151389911681, 0.9327379053088817, 0.9486832980505139, 0.9643650760992957, 0.9797958971132713, 0.9949874371066202, 1.009950493836208, 1.02469507659596, 1.0392304845413265, 1.053565375285274, 1.0677078252031313, 1.081665382639197, 1.0954451150103324, 1.1090536506409419, 1.1224972160321827, 1.1357816691600549, 1.148912529307606, 1.161895003862225, 1.1747340124470733, 1.187434208703792, 1.2000000000000004, 1.2124355652982142, 1.2247448713915892, 1.2369316876852985, 1.2489995996796799, 1.2609520212918495, 1.2727922061357857, 1.2845232578665131, 1.2961481396815722, 1.3076696830622023, 1.3190905958272923, 1.3304134695650072, 1.3416407864998738, 1.3527749258468684, 1.3638181696985856, 1.3747727084867523, 1.385640646055102, 1.3964240043768943, 1.4071247279470291, 1.4177446878757827, 1.4282856857085702, 1.4387494569938162, 1.4491376746189442, 1.4594519519326425, 1.4696938456699071, 1.4798648586948744, 1.489966442575134, 1.5000000000000002, 1.5099668870541503, 1.5198684153570665, 1.5297058540778359, 1.5394804318340656, 1.549193338482967, 1.5588457268119897, 1.5684387141358125, 1.5779733838059502, 1.5874507866387546, 1.5968719422671316, 1.6062378404209012, 1.6155494421403516, 1.6248076809271923, 1.6340134638368193, 1.6431676725154984, 1.6522711641858308, 1.6613247725836153, 1.670329308849007, 1.6792855623746668, 1.6881943016134133, 1.6970562748477143, 1.7058722109231985, 1.7146428199482249, 1.7233687939614089, 1.7320508075688776, 1.7406895185529214], [0.0, 0.2, 0.282842712474619, 0.3464101615137755, 0.4, 0.447213595499958, 0.48989794855663565, 0.5291502622129182, 0.565685424949238, 0.6, 0.6324555320336759, 0.66332495807108, 0.692820323027551, 0.7211102550927979, 0.7483314773547883, 0.7745966692414833, 0.8, 0.8246211251235321, 0.848528137423857, 0.8717797887081349, 0.894427190999916, 0.9165151389911681, 0.938083151964686, 0.959166304662544, 0.9797958971132713, 1.0, 1.019803902718557, 1.0392304845413265, 1.0583005244258363, 1.077032961426901, 1.0954451150103321, 1.1135528725660044, 1.131370849898476, 1.148912529307606, 1.1661903789690602, 1.1832159566199232, 1.2, 1.216552506059644, 1.2328828005937953, 1.2489995996796799, 1.2649110640673518, 1.2806248474865698, 1.2961481396815722, 1.3114877048604001, 1.32664991614216, 1.3416407864998738, 1.3564659966250536, 1.3711309200802089, 1.385640646055102, 1.4000000000000001, 1.4142135623730951, 1.4282856857085702, 1.4422205101855958, 1.4560219778561039, 1.469693845669907, 1.4832396974191326, 1.4966629547095767, 1.50996688705415, 1.5231546211727818, 1.5362291495737217, 1.5491933384829666, 1.5620499351813308, 1.574801574802362, 1.5874507866387544, 1.6, 1.6124515496597098, 1.624807680927192, 1.6370705543744901, 1.6492422502470643, 1.661324772583615, 1.6733200530681511, 1.6852299546352718, 1.697056274847714, 1.7088007490635062, 1.7204650534085253, 1.7320508075688774, 1.7435595774162698, 1.7549928774784245, 1.7663521732655696, 1.7776388834631178, 1.788854381999832, 1.8, 1.8110770276274835, 1.8220867158288598, 1.8330302779823362, 1.8439088914585775, 1.854723699099141, 1.8654758106177631, 1.876166303929372, 1.8867962264113207, 1.8973665961010275, 1.9078784028338913, 1.918332609325088, 1.9287301521985911, 1.9390719429665317, 1.9493588689617927, 1.9595917942265426, 1.9697715603592212, 1.9798989873223332, 1.9899748742132402, 2.0, 2.0099751242241783], [0.0, 0.223606797749979, 0.31622776601683794, 0.38729833462074176, 0.447213595499958, 0.5000000000000001, 0.5477225575051662, 0.5916079783099617, 0.6324555320336759, 0.6708203932499369, 0.7071067811865476, 0.7416198487095664, 0.7745966692414835, 0.806225774829855, 0.8366600265340756, 0.8660254037844386, 0.894427190999916, 0.9219544457292888, 0.9486832980505139, 0.9746794344808966, 1.0000000000000002, 1.02469507659596, 1.0488088481701516, 1.072380529476361, 1.0954451150103324, 1.118033988749895, 1.140175425099138, 1.1618950038622253, 1.1832159566199234, 1.2041594578792296, 1.2247448713915892, 1.2449899597988734, 1.2649110640673518, 1.2845232578665131, 1.30384048104053, 1.3228756555322954, 1.3416407864998738, 1.3601470508735445, 1.3784048752090223, 1.3964240043768943, 1.4142135623730951, 1.4317821063276355, 1.4491376746189442, 1.466287829861518, 1.4832396974191329, 1.5, 1.5165750888103102, 1.5329709716755893, 1.549193338482967, 1.565247584249853, 1.5811388300841898, 1.5968719422671316, 1.61245154965971, 1.627882059609971, 1.6431676725154984, 1.6583123951777001, 1.6733200530681511, 1.6881943016134133, 1.7029386365926404, 1.7175564037317668, 1.7320508075688772, 1.746424919657298, 1.760681686165901, 1.7748239349298849, 1.788854381999832, 1.8027756377319946, 1.8165902124584952, 1.8303005217723127, 1.8439088914585775, 1.8574175621006712, 1.8708286933869709, 1.8841443681416774, 1.8973665961010278, 1.91049731745428, 1.9235384061671346, 1.9364916731037085, 1.9493588689617931, 1.9621416870348585, 1.9748417658131503, 1.9874606914351793, 2.0000000000000004, 2.012461179749811, 2.024845673131659, 2.0371548787463363, 2.04939015319192, 2.0615528128088303, 2.0736441353327724, 2.0856653614614213, 2.0976176963403033, 2.1095023109728985, 2.121320343559643, 2.1330729007701543, 2.144761058952722, 2.1563858652847827, 2.1679483388678804, 2.179449471770337, 2.1908902300206647, 2.2022715545545246, 2.2135943621178655, 2.224859546128699, 2.23606797749979, 2.2472205054244236], [0.0, 0.24494897427831783, 0.34641016151377546, 0.42426406871192857, 0.48989794855663565, 0.5477225575051662, 0.6000000000000001, 0.6480740698407861, 0.6928203230275509, 0.7348469228349535, 0.7745966692414834, 0.8124038404635961, 0.8485281374238571, 0.8831760866327848, 0.916515138991168, 0.9486832980505138, 0.9797958971132713, 1.0099504938362078, 1.0392304845413265, 1.0677078252031313, 1.0954451150103324, 1.1224972160321824, 1.148912529307606, 1.174734012447073, 1.2000000000000002, 1.2247448713915892, 1.2489995996796799, 1.2727922061357857, 1.2961481396815722, 1.319090595827292, 1.3416407864998738, 1.3638181696985856, 1.3856406460551018, 1.4071247279470291, 1.4282856857085702, 1.449137674618944, 1.469693845669907, 1.489966442575134, 1.50996688705415, 1.5297058540778357, 1.5491933384829668, 1.5684387141358125, 1.5874507866387546, 1.606237840420901, 1.6248076809271923, 1.6431676725154982, 1.661324772583615, 1.6792855623746665, 1.6970562748477143, 1.7146428199482247, 1.7320508075688774, 1.7492855684535904, 1.7663521732655696, 1.7832554500127011, 1.8, 1.8165902124584952, 1.833030277982336, 1.849324200890693, 1.8654758106177631, 1.8814887722226779, 1.8973665961010275, 1.9131126469708992, 1.928730152198591, 1.9442222095223582, 1.9595917942265426, 1.9748417658131499, 1.98997487421324, 2.004993765576342, 2.0199009876724157, 2.0346989949375804, 2.04939015319192, 2.0639767440550294, 2.078460969082653, 2.092844953645635, 2.1071307505705477, 2.121320343559643, 2.1354156504062627, 2.149418526020468, 2.1633307652783937, 2.177154105707724, 2.1908902300206647, 2.2045407685048604, 2.2181073012818837, 2.2315913604421396, 2.244994432064365, 2.2583179581272432, 2.2715633383201097, 2.2847319317591728, 2.297825058615212, 2.3108440016582685, 2.32379000772445, 2.3366642891095846, 2.349468024894146, 2.3622023622035435, 2.374868417407584, 2.3874672772626644, 2.4000000000000004, 2.412467616362964, 2.4248711305964283, 2.4372115213907883, 2.4494897427831783, 2.4617067250182347], [0.0, 0.2645751311064591, 0.3741657386773941, 0.45825756949558405, 0.5291502622129182, 0.5916079783099617, 0.6480740698407861, 0.7000000000000001, 0.7483314773547882, 0.7937253933193772, 0.8366600265340756, 0.8774964387392122, 0.9165151389911681, 0.9539392014169458, 0.9899494936611666, 1.0246950765959597, 1.0583005244258363, 1.0908712114635715, 1.1224972160321824, 1.1532562594670797, 1.1832159566199234, 1.2124355652982142, 1.2409673645990857, 1.2688577540449522, 1.2961481396815722, 1.3228756555322954, 1.3490737563232043, 1.374772708486752, 1.4000000000000001, 1.4247806848775009, 1.4491376746189437, 1.4730919862656235, 1.4966629547095764, 1.5198684153570665, 1.5427248620541514, 1.5652475842498528, 1.5874507866387544, 1.6093476939431082, 1.6309506430300091, 1.6522711641858308, 1.6733200530681511, 1.6941074346097418, 1.7146428199482249, 1.7349351572897471, 1.7549928774784245, 1.7748239349298847, 1.7944358444926363, 1.8138357147217055, 1.8330302779823362, 1.8520259177452134, 1.8708286933869709, 1.8894443627691186, 1.9078784028338915, 1.9261360284258224, 1.9442222095223582, 1.9621416870348585, 1.9798989873223332, 1.997498435543818, 2.0149441679609885, 2.0322401432901573, 2.0493901531919194, 2.0663978319771825, 2.083266665599966, 2.1, 2.1166010488516727, 2.133072900770154, 2.149418526020468, 2.1656407827707715, 2.181742422927143, 2.1977260975835913, 2.2135943621178655, 2.2293496809607953, 2.244994432064365, 2.260530911091463, 2.2759613353482084, 2.29128784747792, 2.3065125189341593, 2.32163735324878, 2.336664289109585, 2.3515952032609695, 2.366431913239847, 2.3811761799581315, 2.395829710142188, 2.41039415863879, 2.4248711305964283, 2.4392621835300936, 2.4535688292770597, 2.4677925358506134, 2.4819347291981715, 2.495996794869737, 2.5099800796022267, 2.5238858928247927, 2.5377155080899043, 2.551470164434615, 2.5651510676761324, 2.578759391645525, 2.5922962793631443, 2.6057628441590768, 2.619160170741759, 2.632489316217637, 2.6457513110645907, 2.6589471600616665], [0.0, 0.282842712474619, 0.39999999999999997, 0.48989794855663565, 0.565685424949238, 0.6324555320336759, 0.6928203230275509, 0.7483314773547882, 0.7999999999999999, 0.848528137423857, 0.8944271909999159, 0.938083151964686, 0.9797958971132713, 1.019803902718557, 1.058300524425836, 1.0954451150103321, 1.131370849898476, 1.16619037896906, 1.2, 1.2328828005937953, 1.2649110640673518, 1.2961481396815722, 1.3266499161421599, 1.3564659966250536, 1.3856406460551018, 1.4142135623730951, 1.4422205101855958, 1.469693845669907, 1.4966629547095764, 1.5231546211727818, 1.5491933384829666, 1.5748015748023623, 1.5999999999999999, 1.624807680927192, 1.6492422502470643, 1.6733200530681511, 1.697056274847714, 1.7204650534085253, 1.7435595774162695, 1.7663521732655694, 1.7888543819998317, 1.8110770276274835, 1.8330302779823362, 1.8547236990991405, 1.876166303929372, 1.8973665961010273, 1.9183326093250879, 1.9390719429665315, 1.9595917942265426, 1.979898987322333, 2.0, 2.0199009876724157, 2.039607805437114, 2.0591260281974004, 2.078460969082653, 2.0976176963403033, 2.116601048851672, 2.1354156504062622, 2.1540659228538015, 2.172556098240043, 2.1908902300206643, 2.209072203437452, 2.2271057451320084, 2.244994432064365, 2.262741699796952, 2.2803508501982757, 2.2978250586152114, 2.315167380558045, 2.33238075793812, 2.349468024894146, 2.3664319132398464, 2.3832750575625967, 2.4, 2.4166091947189146, 2.4331050121192876, 2.449489742783178, 2.4657656011875906, 2.4819347291981715, 2.4979991993593593, 2.513961017995307, 2.5298221281347035, 2.545584412271571, 2.5612496949731396, 2.576819745345025, 2.5922962793631443, 2.6076809620810595, 2.6229754097208002, 2.6381811916545836, 2.6532998322843198, 2.6683328128252666, 2.6832815729997477, 2.698147512646408, 2.7129319932501073, 2.727636339397171, 2.7422618401604177, 2.756809750418044, 2.7712812921102037, 2.785677655436824, 2.8, 2.814249455894058, 2.8284271247461903, 2.8425340807103794], [0.0, 0.3, 0.4242640687119285, 0.5196152422706632, 0.6, 0.6708203932499369, 0.7348469228349535, 0.7937253933193772, 0.848528137423857, 0.8999999999999999, 0.9486832980505138, 0.99498743710662, 1.0392304845413265, 1.0816653826391969, 1.1224972160321824, 1.1618950038622249, 1.2, 1.236931687685298, 1.2727922061357855, 1.307669683062202, 1.3416407864998738, 1.374772708486752, 1.407124727947029, 1.438749456993816, 1.469693845669907, 1.5, 1.5297058540778354, 1.5588457268119895, 1.5874507866387544, 1.6155494421403513, 1.6431676725154982, 1.6703293088490065, 1.697056274847714, 1.7233687939614086, 1.7492855684535902, 1.7748239349298847, 1.7999999999999998, 1.8248287590894658, 1.849324200890693, 1.8734993995195195, 1.8973665961010275, 1.9209372712298547, 1.9442222095223582, 1.9672315572906, 1.98997487421324, 2.0124611797498106, 2.0346989949375804, 2.056696380120313, 2.078460969082653, 2.1, 2.1213203435596424, 2.142428528562855, 2.1633307652783937, 2.1840329667841556, 2.2045407685048604, 2.224859546128699, 2.244994432064365, 2.264950330581225, 2.2847319317591723, 2.3043437243605824, 2.3237900077244498, 2.3430749027719964, 2.362202362203543, 2.3811761799581315, 2.4, 2.4186773244895647, 2.437211521390788, 2.455605831561735, 2.473863375370596, 2.4919871588754225, 2.5099800796022267, 2.5278449319529073, 2.545584412271571, 2.563201123595259, 2.580697580112788, 2.598076211353316, 2.615339366124404, 2.6324893162176366, 2.6495282598983545, 2.6664583251946765, 2.6832815729997477, 2.7, 2.716615541441225, 2.7331300737432893, 2.749545416973504, 2.765863337187866, 2.7820855486487113, 2.7982137159266447, 2.814249455894058, 2.830194339616981, 2.846049894151541, 2.8618176042508368, 2.877498913987632, 2.8930952282978866, 2.9086079144497976, 2.9240383034426887, 2.939387691339814, 2.9546573405388314, 2.9698484809834995, 2.98496231131986, 3.0, 3.0149626863362675], [0.0, 0.31622776601683794, 0.4472135954999579, 0.5477225575051662, 0.6324555320336759, 0.7071067811865476, 0.7745966692414834, 0.8366600265340756, 0.8944271909999159, 0.9486832980505138, 1.0, 1.0488088481701516, 1.0954451150103324, 1.140175425099138, 1.1832159566199232, 1.224744871391589, 1.2649110640673518, 1.3038404810405297, 1.3416407864998738, 1.3784048752090223, 1.4142135623730951, 1.449137674618944, 1.4832396974191326, 1.5165750888103102, 1.5491933384829668, 1.5811388300841898, 1.61245154965971, 1.6431676725154984, 1.6733200530681511, 1.7029386365926402, 1.7320508075688772, 1.760681686165901, 1.7888543819998317, 1.8165902124584952, 1.8439088914585775, 1.8708286933869707, 1.8973665961010275, 1.9235384061671346, 1.949358868961793, 1.97484176581315, 2.0, 2.024845673131659, 2.04939015319192, 2.073644135332772, 2.0976176963403033, 2.1213203435596424, 2.1447610589527217, 2.16794833886788, 2.1908902300206647, 2.2135943621178655, 2.23606797749979, 2.2583179581272432, 2.280350850198276, 2.302172886644268, 2.32379000772445, 2.345207879911715, 2.3664319132398464, 2.3874672772626644, 2.4083189157584592, 2.4289915602982237, 2.449489742783178, 2.4698178070456938, 2.4899799195977463, 2.5099800796022267, 2.5298221281347035, 2.5495097567963922, 2.569046515733026, 2.588435821108957, 2.6076809620810595, 2.6267851073127395, 2.6457513110645907, 2.6645825188948455, 2.6832815729997477, 2.701851217221259, 2.7202941017470885, 2.7386127875258306, 2.7568097504180447, 2.7748873851023217, 2.7928480087537886, 2.8106938645110393, 2.8284271247461903, 2.8460498941515415, 2.863564212655271, 2.8809720581775866, 2.898275349237888, 2.9154759474226504, 2.932575659723036, 2.9495762407505253, 2.9664793948382653, 2.9832867780352594, 3.0, 3.0166206257996713, 3.0331501776206204, 3.0495901363953815, 3.0659419433511785, 3.082207001484488, 3.0983866769659336, 3.1144823004794877, 3.1304951684997055, 3.146426544510455, 3.1622776601683795, 3.178049716414141], [0.0, 0.33166247903554, 0.469041575982343, 0.574456264653803, 0.66332495807108, 0.7416198487095664, 0.8124038404635961, 0.8774964387392122, 0.938083151964686, 0.99498743710662, 1.0488088481701516, 1.1, 1.148912529307606, 1.1958260743101399, 1.2409673645990857, 1.284523257866513, 1.32664991614216, 1.3674794331177345, 1.407124727947029, 1.4456832294800963, 1.4832396974191329, 1.5198684153570665, 1.5556349186104048, 1.5905973720586868, 1.6248076809271923, 1.6583123951777001, 1.6911534525287766, 1.7233687939614089, 1.7549928774784245, 1.7860571099491753, 1.816590212458495, 1.846618531261939, 1.876166303929372, 1.9052558883257653, 1.9339079605813718, 1.9621416870348585, 1.98997487421324, 2.017424100183202, 2.0445048300260877, 2.0712315177207983, 2.0976176963403033, 2.1236760581595306, 2.149418526020468, 2.1748563170931545, 2.2, 2.224859546128699, 2.249444375840399, 2.273763400180415, 2.297825058615212, 2.32163735324878, 2.345207879911715, 2.368543856465403, 2.3916521486202797, 2.4145392935299275, 2.4372115213907883, 2.459674775249769, 2.4819347291981715, 2.503996805109783, 2.525866188063018, 2.5475478405713994, 2.569046515733026, 2.5903667693977237, 2.6115129714401193, 2.632489316217637, 2.65329983228432, 2.6739483914241875, 2.6944387170614963, 2.714774392099646, 2.734958866235469, 2.7549954627911823, 2.774887385102322, 2.7946377224964243, 2.814249455894058, 2.833725463060951, 2.8530685235374214, 2.8722813232690148, 2.8913664589601926, 2.91032644217105, 2.9291637031753623, 2.9478805945967355, 2.9664793948382657, 2.9849623113198605, 3.003331483536242, 3.0215889859476257, 3.039736830714133, 3.0577769702841313, 3.07571129984594, 3.093541659651604, 3.1112698372208096, 3.1288975694324033, 3.146426544510455, 3.1638584039112754, 3.1811947441173736, 3.1984371183438958, 3.2155870381627056, 3.2326459750489227, 3.2496153618543846, 3.2664965942122155, 3.283291031876401, 3.3000000000000007, 3.3166247903554003, 3.333166662499792], [0.0, 0.3464101615137755, 0.48989794855663565, 0.6000000000000002, 0.692820323027551, 0.7745966692414835, 0.8485281374238571, 0.9165151389911681, 0.9797958971132713, 1.0392304845413265, 1.0954451150103324, 1.148912529307606, 1.2000000000000004, 1.2489995996796799, 1.2961481396815722, 1.3416407864998738, 1.385640646055102, 1.4282856857085702, 1.4696938456699071, 1.5099668870541503, 1.549193338482967, 1.5874507866387546, 1.6248076809271923, 1.6613247725836153, 1.6970562748477143, 1.7320508075688776, 1.7663521732655698, 1.8000000000000003, 1.8330302779823362, 1.8654758106177634, 1.8973665961010278, 1.9287301521985913, 1.9595917942265426, 1.9899748742132404, 2.019900987672416, 2.04939015319192, 2.078460969082653, 2.107130750570548, 2.1354156504062627, 2.163330765278394, 2.1908902300206647, 2.2181073012818837, 2.2449944320643653, 2.2715633383201097, 2.297825058615212, 2.32379000772445, 2.3494680248941466, 2.374868417407584, 2.400000000000001, 2.4248711305964283, 2.4494897427831783, 2.473863375370597, 2.4979991993593598, 2.521904042583699, 2.5455844122715714, 2.5690465157330262, 2.5922962793631443, 2.6153393661244047, 2.6381811916545845, 2.6608269391300143, 2.6832815729997477, 2.705549851693737, 2.727636339397171, 2.7495454169735045, 2.771281292110204, 2.7928480087537886, 2.8142494558940583, 2.8354893757515653, 2.8565713714171403, 2.8774989139876324, 2.8982753492378883, 2.918903903865285, 2.9393876913398143, 2.9597297173897488, 2.979932885150268, 3.0000000000000004, 3.0199337741083006, 3.039736830714133, 3.0594117081556718, 3.078960863668131, 3.098386676965934, 3.1176914536239795, 3.136877428271625, 3.1559467676119004, 3.174901573277509, 3.193743884534263, 3.2124756808418025, 3.231098884280703, 3.2496153618543846, 3.2680269276736387, 3.286335345030997, 3.3045423283716615, 3.3226495451672307, 3.340658617698014, 3.3585711247493335, 3.3763886032268267, 3.3941125496954285, 3.411744421846397, 3.4292856398964497, 3.4467375879228177, 3.4641016151377553, 3.481379037105843], [0.0, 0.36055512754639896, 0.5099019513592785, 0.6244997998398399, 0.7211102550927979, 0.806225774829855, 0.8831760866327848, 0.9539392014169458, 1.019803902718557, 1.0816653826391969, 1.140175425099138, 1.1958260743101399, 1.2489995996796799, 1.3000000000000003, 1.3490737563232043, 1.396424004376894, 1.4422205101855958, 1.4866068747318506, 1.5297058540778357, 1.5716233645501714, 1.61245154965971, 1.6522711641858308, 1.6911534525287764, 1.7291616465790585, 1.7663521732655696, 1.8027756377319948, 1.8384776310850237, 1.8734993995195197, 1.9078784028338915, 1.94164878389476, 1.9748417658131499, 2.0074859899884734, 2.039607805437114, 2.0712315177207983, 2.102379604162864, 2.1330729007701543, 2.1633307652783937, 2.193171219946131, 2.222611077089287, 2.2516660498395407, 2.280350850198276, 2.3086792761230397, 2.336664289109585, 2.364318083507378, 2.3916521486202797, 2.4186773244895647, 2.445403852127497, 2.471841418861655, 2.4979991993593598, 2.5238858928247927, 2.5495097567963927, 2.574878637916747, 2.6000000000000005, 2.624880949681338, 2.6495282598983545, 2.673948391424188, 2.6981475126464085, 2.72213151776324, 2.7459060435491964, 2.7694764848252458, 2.792848008753788, 2.816025568065745, 2.839013913315678, 2.861817604250837, 2.8844410203711917, 2.9068883707497264, 2.9291637031753623, 2.951270912674741, 2.973213749463701, 2.994995826374388, 3.0166206257996717, 3.0380915061926625, 3.0594117081556713, 3.0805843601498726, 3.1016124838541645, 3.122498999199199, 3.1432467291003428, 3.1638584039112754, 3.1843366656181322, 3.204684071792413, 3.22490309931942, 3.2449961479175906, 3.264965543462902, 3.2848135411313684, 3.3045423283716615, 3.3241540277189325, 3.343650699460098, 3.363034344160048, 3.3823069050575527, 3.4014702703389896, 3.420526275297414, 3.439476704383968, 3.458323293158117, 3.4770677301427426, 3.4957116585897072, 3.5142566781611158, 3.532704346531139, 3.5510561809129415, 3.5693136595149495, 3.58747822293042, 3.6055512754639896, 3.6235341863986883], [0.0, 0.37416573867739417, 0.529150262212918, 0.6480740698407861, 0.7483314773547883, 0.8366600265340756, 0.916515138991168, 0.9899494936611666, 1.058300524425836, 1.1224972160321824, 1.1832159566199232, 1.2409673645990857, 1.2961481396815722, 1.3490737563232043, 1.4, 1.4491376746189437, 1.4966629547095767, 1.5427248620541512, 1.5874507866387544, 1.6309506430300091, 1.6733200530681511, 1.7146428199482247, 1.7549928774784245, 1.7944358444926363, 1.833030277982336, 1.8708286933869707, 1.9078784028338913, 1.9442222095223582, 1.9798989873223332, 2.0149441679609885, 2.0493901531919194, 2.083266665599966, 2.116601048851672, 2.149418526020468, 2.181742422927143, 2.2135943621178655, 2.244994432064365, 2.2759613353482084, 2.3065125189341593, 2.3366642891095846, 2.3664319132398464, 2.395829710142188, 2.4248711305964283, 2.453568829277059, 2.4819347291981715, 2.5099800796022262, 2.5377155080899043, 2.565151067676132, 2.5922962793631443, 2.619160170741759, 2.6457513110645907, 2.672077843177478, 2.6981475126464085, 2.7239676943752476, 2.749545416973504, 2.7748873851023217, 2.8, 2.824889378365107, 2.8495613697550017, 2.8740215726399825, 2.8982753492378874, 2.9223278392404914, 2.9461839725312466, 2.9698484809834995, 2.9933259094191533, 3.016620625799671, 3.0397368307141326, 3.062678566222711, 3.0854497241083023, 3.1080540535840107, 3.1304951684997055, 3.152776554086889, 3.1749015732775088, 3.196873472629156, 3.218695387886216, 3.24037034920393, 3.2619012860600183, 3.283291031876401, 3.3045423283716615, 3.3256578296631782, 3.3466401061363023, 3.3674916480965473, 3.3882148692194836, 3.408812109811862, 3.4292856398964493, 3.449637662132068, 3.4698703145794947, 3.4899856733230297, 3.509985754956849, 3.529872518944558, 3.5496478698597693, 3.5693136595149495, 3.5888716889852725, 3.6083237105337433, 3.627671429443411, 3.6469165057620936, 3.666060555964672, 3.685105154537656, 3.704051835490427, 3.722902093797257, 3.7416573867739413, 3.7603191353926335], [0.0, 0.38729833462074165, 0.5477225575051661, 0.6708203932499369, 0.7745966692414833, 0.8660254037844386, 0.9486832980505138, 1.0246950765959597, 1.0954451150103321, 1.1618950038622249, 1.224744871391589, 1.284523257866513, 1.3416407864998738, 1.396424004376894, 1.4491376746189437, 1.4999999999999998, 1.5491933384829666, 1.5968719422671311, 1.6431676725154982, 1.6881943016134133, 1.7320508075688772, 1.7748239349298847, 1.816590212458495, 1.857417562100671, 1.8973665961010275, 1.9364916731037083, 1.9748417658131499, 2.0124611797498106, 2.0493901531919194, 2.085665361461421, 2.1213203435596424, 2.1563858652847823, 2.1908902300206643, 2.224859546128699, 2.258317958127243, 2.29128784747792, 2.3237900077244498, 2.355843797877949, 2.3874672772626644, 2.4186773244895647, 2.449489742783178, 2.479919353527449, 2.5099800796022267, 2.5396850198400585, 2.569046515733026, 2.5980762113533156, 2.626785107312739, 2.6551836094703507, 2.6832815729997477, 2.7110883423451915, 2.7386127875258306, 2.765863337187866, 2.792848008753788, 2.819574435974337, 2.846049894151541, 2.8722813232690143, 2.8982753492378874, 2.924038303442689, 2.9495762407505253, 2.974894956128703, 2.9999999999999996, 3.0248966924508345, 3.049590136395381, 3.074085229787879, 3.098386676965933, 3.1224989991991987, 3.1464265445104544, 3.1701734968294715, 3.1937438845342623, 3.217141588429082, 3.24037034920393, 3.2634337744161437, 3.2863353450309964, 3.309078421554859, 3.3316662497915357, 3.3541019662496843, 3.3763886032268267, 3.3985290935932855, 3.420526275297414, 3.442382895611701, 3.4641016151377544, 3.485685011586675, 3.5071355833500366, 3.5284557528754696, 3.5496478698597693, 3.5707142142714248, 3.591656999213594, 3.6124783736376886, 3.63318042491699, 3.6537651812890215, 3.674234614174767, 3.694590640382233, 3.714835124201342, 3.7349698793966195, 3.7549966711037173, 3.7749172176353745, 3.794733192202055, 3.8144462245521304, 3.8340579025361623, 3.853569773599539, 3.8729833462074166, 3.892300091205713], [0.0, 0.4, 0.565685424949238, 0.692820323027551, 0.8, 0.894427190999916, 0.9797958971132713, 1.0583005244258363, 1.131370849898476, 1.2, 1.2649110640673518, 1.32664991614216, 1.385640646055102, 1.4422205101855958, 1.4966629547095767, 1.5491933384829666, 1.6, 1.6492422502470643, 1.697056274847714, 1.7435595774162698, 1.788854381999832, 1.8330302779823362, 1.876166303929372, 1.918332609325088, 1.9595917942265426, 2.0, 2.039607805437114, 2.078460969082653, 2.1166010488516727, 2.154065922853802, 2.1908902300206643, 2.227105745132009, 2.262741699796952, 2.297825058615212, 2.3323807579381204, 2.3664319132398464, 2.4, 2.433105012119288, 2.4657656011875906, 2.4979991993593598, 2.5298221281347035, 2.5612496949731396, 2.5922962793631443, 2.6229754097208002, 2.65329983228432, 2.6832815729997477, 2.7129319932501073, 2.7422618401604177, 2.771281292110204, 2.8000000000000003, 2.8284271247461903, 2.8565713714171403, 2.8844410203711917, 2.9120439557122078, 2.939387691339814, 2.9664793948382653, 2.9933259094191533, 3.0199337741083, 3.0463092423455636, 3.0724582991474434, 3.098386676965933, 3.1240998703626617, 3.149603149604724, 3.1749015732775088, 3.2, 3.2249030993194197, 3.249615361854384, 3.2741411087489802, 3.2984845004941286, 3.32264954516723, 3.3466401061363023, 3.3704599092705436, 3.394112549695428, 3.4176014981270124, 3.4409301068170506, 3.464101615137755, 3.4871191548325395, 3.509985754956849, 3.532704346531139, 3.5552777669262356, 3.577708763999664, 3.6, 3.622154055254967, 3.6441734316577197, 3.6660605559646724, 3.687817782917155, 3.709447398198282, 3.7309516212355263, 3.752332607858744, 3.7735924528226414, 3.794733192202055, 3.8157568056677826, 3.836665218650176, 3.8574603043971822, 3.8781438859330635, 3.8987177379235853, 3.9191835884530852, 3.9395431207184424, 3.9597979746446663, 3.9799497484264803, 4.0, 4.019950248448357], [0.0, 0.41231056256176607, 0.58309518948453, 0.7141428428542851, 0.8246211251235321, 0.9219544457292888, 1.0099504938362078, 1.0908712114635715, 1.16619037896906, 1.236931687685298, 1.3038404810405297, 1.3674794331177345, 1.4282856857085702, 1.4866068747318506, 1.5427248620541512, 1.5968719422671311, 1.6492422502470643, 1.7, 1.7492855684535902, 1.797220075561143, 1.8439088914585775, 1.8894443627691184, 1.9339079605813716, 1.977371993328519, 2.0199009876724157, 2.0615528128088303, 2.102379604162864, 2.142428528562855, 2.181742422927143, 2.220360331117452, 2.258317958127243, 2.2956480566497994, 2.33238075793812, 2.3685438564654024, 2.4041630560342617, 2.4392621835300936, 2.473863375370596, 2.5079872407968904, 2.541653005427767, 2.574878637916747, 2.6076809620810595, 2.6400757564888173, 2.672077843177478, 2.7037011669191546, 2.734958866235469, 2.765863337187866, 2.7964262908219126, 2.826658805020514, 2.8565713714171403, 2.8861739379323623, 2.9154759474226504, 2.944486372867092, 2.973213749463701, 3.001666203960727, 3.0298514815086235, 3.0577769702841313, 3.0854497241083023, 3.1128764832546763, 3.1400636936215167, 3.167017524422623, 3.1937438845342623, 3.2202484376209237, 3.246536616149585, 3.2726136343907144, 3.2984845004941286, 3.324154027718932, 3.3496268448888453, 3.374907406137241, 3.4, 3.424908757908742, 3.4496376621320683, 3.4741905532080417, 3.4985711369071804, 3.522782990761707, 3.5468295701936396, 3.570714214271425, 3.594440151122286, 3.6180105030251086, 3.6414282912066254, 3.664696440361739, 3.687817782917155, 3.710795063055895, 3.733630940518894, 3.7563279941985894, 3.778888725538237, 3.8013155617496426, 3.8236108588610325, 3.845776904605882, 3.867815921162743, 3.8897300677553446, 3.9115214431215892, 3.9331920878594273, 3.954743986657038, 3.976179070414209, 3.9974992182613374, 4.018706259482023, 4.039801975344831, 4.060788100849391, 4.08166632639171, 4.102438299353203, 4.123105625617661, 4.1436698710201325], [0.0, 0.4242640687119285, 0.6, 0.7348469228349536, 0.848528137423857, 0.9486832980505139, 1.0392304845413265, 1.1224972160321824, 1.2, 1.2727922061357855, 1.3416407864998738, 1.407124727947029, 1.4696938456699071, 1.5297058540778357, 1.5874507866387544, 1.6431676725154982, 1.697056274847714, 1.7492855684535902, 1.8, 1.8493242008906932, 1.8973665961010278, 1.9442222095223582, 1.98997487421324, 2.0346989949375804, 2.078460969082653, 2.121320343559643, 2.1633307652783937, 2.2045407685048604, 2.244994432064365, 2.2847319317591728, 2.32379000772445, 2.3622023622035435, 2.4, 2.4372115213907883, 2.4738633753705965, 2.5099800796022267, 2.545584412271571, 2.5806975801127883, 2.615339366124404, 2.6495282598983545, 2.6832815729997477, 2.716615541441225, 2.749545416973504, 2.782085548648711, 2.814249455894058, 2.846049894151541, 2.877498913987632, 2.9086079144497976, 2.9393876913398143, 2.9698484809834995, 3.0, 3.029851481508624, 3.0594117081556713, 3.0886890422961004, 3.1176914536239795, 3.146426544510455, 3.1749015732775088, 3.2031234756093934, 3.2310988842807027, 3.2588341473600644, 3.2863353450309964, 3.3136083051561784, 3.340658617698013, 3.3674916480965473, 3.394112549695428, 3.420526275297414, 3.4467375879228173, 3.4727510708370675, 3.4985711369071804, 3.5242020373412193, 3.5496478698597698, 3.5749125863438955, 3.6, 3.6249137920783716, 3.6496575181789317, 3.6742346141747673, 3.6986484017813863, 3.722902093797257, 3.7469987990390394, 3.7709415269929605, 3.7947331922020555, 3.8183766184073566, 3.84187454245971, 3.8652296180175374, 3.8884444190447165, 3.9115214431215897, 3.9344631145812006, 3.957271787481876, 3.97994974842648, 4.0024992192379, 4.024922359499621, 4.047221268969612, 4.069397989875161, 4.091454509095757, 4.113392760240627, 4.135214625627066, 4.156921938165306, 4.178516483155236, 4.2, 4.221374183841087, 4.242640687119286, 4.263801121065569], [0.0, 0.43588989435406744, 0.6164414002968976, 0.7549834435270751, 0.8717797887081349, 0.9746794344808966, 1.0677078252031313, 1.1532562594670797, 1.2328828005937953, 1.307669683062202, 1.3784048752090223, 1.4456832294800963, 1.5099668870541503, 1.5716233645501714, 1.6309506430300091, 1.6881943016134133, 1.7435595774162698, 1.797220075561143, 1.8493242008906932, 1.9000000000000004, 1.9493588689617931, 1.9974984355438181, 2.0445048300260877, 2.0904544960366875, 2.1354156504062627, 2.179449471770337, 2.2226110770892875, 2.2649503305812253, 2.3065125189341593, 2.3473389188611007, 2.3874672772626644, 2.4269322199023198, 2.4657656011875906, 2.503996805109783, 2.5416530054277673, 2.5787593916455256, 2.615339366124404, 2.651414716712571, 2.687005768508881, 2.7221315177632404, 2.7568097504180447, 2.791057147390573, 2.8248893783651075, 2.8583211855912904, 2.8913664589601926, 2.924038303442689, 2.956349099818897, 2.9883105594967874, 3.0199337741083006, 3.051229260478472, 3.082207001484489, 3.1128764832546767, 3.1432467291003428, 3.1733263305244868, 3.203123475609394, 3.232645975048923, 3.2619012860600183, 3.290896534380867, 3.319638534539567, 3.3481338085566414, 3.3763886032268267, 3.4044089061098406, 3.432200460346103, 3.4597687784012394, 3.4871191548325395, 3.5142566781611158, 3.541186241925155, 3.567912554982255, 3.594440151122286, 3.6207733980463352, 3.6469165057620945, 3.672873534441392, 3.6986484017813863, 3.7242448899072147, 3.749666651850535, 3.7749172176353754, 3.8000000000000007, 3.824918299781056, 3.8496753109840323, 3.874274125562104, 3.8987177379235862, 3.9230090491866068, 3.947150871198111, 3.9711459303329564, 3.9949968710876362, 4.018706259482024, 4.042276586281548, 4.065710270051225, 4.0890096600521755, 4.112177038990418, 4.135214625627067, 4.158124577258358, 4.180908992073375, 4.203569911396741, 4.226109321823088, 4.2485291572496005, 4.270831300812525, 4.293017586733137, 4.315089802078284, 4.337049688440289, 4.358898943540674, 4.380639222761903], [0.0, 0.447213595499958, 0.6324555320336759, 0.7745966692414835, 0.894427190999916, 1.0000000000000002, 1.0954451150103324, 1.1832159566199234, 1.2649110640673518, 1.3416407864998738, 1.4142135623730951, 1.4832396974191329, 1.549193338482967, 1.61245154965971, 1.6733200530681511, 1.7320508075688772, 1.788854381999832, 1.8439088914585775, 1.8973665961010278, 1.9493588689617931, 2.0000000000000004, 2.04939015319192, 2.0976176963403033, 2.144761058952722, 2.1908902300206647, 2.23606797749979, 2.280350850198276, 2.3237900077244507, 2.366431913239847, 2.4083189157584592, 2.4494897427831783, 2.489979919597747, 2.5298221281347035, 2.5690465157330262, 2.60768096208106, 2.6457513110645907, 2.6832815729997477, 2.720294101747089, 2.7568097504180447, 2.7928480087537886, 2.8284271247461903, 2.863564212655271, 2.8982753492378883, 2.932575659723036, 2.9664793948382657, 3.0, 3.0331501776206204, 3.0659419433511785, 3.098386676965934, 3.130495168499706, 3.1622776601683795, 3.193743884534263, 3.22490309931942, 3.255764119219942, 3.286335345030997, 3.3166247903554003, 3.3466401061363023, 3.3763886032268267, 3.405877273185281, 3.4351128074635335, 3.4641016151377544, 3.492849839314596, 3.521363372331802, 3.5496478698597698, 3.577708763999664, 3.605551275463989, 3.6331804249169903, 3.6606010435446255, 3.687817782917155, 3.7148351242013424, 3.7416573867739418, 3.768288736283355, 3.7947331922020555, 3.82099463490856, 3.847076812334269, 3.872983346207417, 3.8987177379235862, 3.924283374069717, 3.9496835316263006, 3.9749213828703587, 4.000000000000001, 4.024922359499622, 4.049691346263318, 4.0743097574926725, 4.09878030638384, 4.123105625617661, 4.147288270665545, 4.171330722922843, 4.1952353926806065, 4.219004621945797, 4.242640687119286, 4.266145801540309, 4.289522117905444, 4.312771730569565, 4.335896677735761, 4.358898943540674, 4.3817804600413295, 4.404543109109049, 4.427188724235731, 4.449719092257398, 4.47213595499958, 4.494441010848847], [0.0, 0.45825756949558405, 0.6480740698407861, 0.7937253933193773, 0.9165151389911681, 1.02469507659596, 1.1224972160321824, 1.2124355652982142, 1.2961481396815722, 1.374772708486752, 1.449137674618944, 1.5198684153570665, 1.5874507866387546, 1.6522711641858308, 1.7146428199482247, 1.7748239349298847, 1.8330302779823362, 1.8894443627691184, 1.9442222095223582, 1.9974984355438181, 2.04939015319192, 2.1, 2.149418526020468, 2.1977260975835913, 2.244994432064365, 2.2912878474779204, 2.336664289109585, 2.381176179958132, 2.4248711305964283, 2.4677925358506134, 2.5099800796022267, 2.551470164434615, 2.5922962793631443, 2.632489316217637, 2.672077843177478, 2.711088342345192, 2.749545416973504, 2.787471972953271, 2.824889378365107, 2.861817604250837, 2.898275349237888, 2.934280150224242, 2.9698484809835, 3.004995840263344, 3.039736830714133, 3.0740852297878796, 3.108054053584011, 3.1416556144810017, 3.174901573277509, 3.2078029864690882, 3.2403703492039306, 3.272613634390715, 3.3045423283716615, 3.336165463522456, 3.3674916480965478, 3.398529093593286, 3.4292856398964493, 3.459768778401239, 3.48998567332303, 3.5199431813596083, 3.5496478698597693, 3.5791060336346563, 3.608323710533743, 3.6373066958946425, 3.6660605559646724, 3.6945906403822333, 3.722902093797257, 3.7509998667022106, 3.778888725538237, 3.8065732621348563, 3.834057902536163, 3.861346915261565, 3.8884444190447165, 3.915354390090379, 3.9420806688854046, 3.968626966596886, 3.9949968710876362, 4.02119385257662, 4.047221268969613, 4.07308237088326, 4.09878030638384, 4.124318125460256, 4.149698784249287, 4.174925149029621, 4.2, 4.224926034855522, 4.249705872175156, 4.274342054632503, 4.298837052040936, 4.323193264243457, 4.347413023856832, 4.371498598878879, 4.3954521951671826, 4.419275958796871, 4.442971978304612, 4.466542286825459, 4.48998886412873, 4.513313638558704, 4.536518488885503, 4.559605246071199, 4.582575694955841, 4.605431575867782], [0.0, 0.469041575982343, 0.6633249580710799, 0.8124038404635961, 0.938083151964686, 1.0488088481701516, 1.148912529307606, 1.2409673645990857, 1.3266499161421599, 1.407124727947029, 1.4832396974191326, 1.5556349186104048, 1.6248076809271923, 1.6911534525287764, 1.7549928774784245, 1.816590212458495, 1.876166303929372, 1.9339079605813716, 1.98997487421324, 2.0445048300260877, 2.0976176963403033, 2.149418526020468, 2.2, 2.249444375840399, 2.297825058615212, 2.345207879911715, 2.3916521486202797, 2.4372115213907883, 2.4819347291981715, 2.5258661880630178, 2.569046515733026, 2.6115129714401193, 2.6532998322843198, 2.6944387170614963, 2.734958866235469, 2.7748873851023217, 2.814249455894058, 2.8530685235374214, 2.891366458960192, 2.9291637031753623, 2.9664793948382653, 3.0033314835362415, 3.039736830714133, 3.0757112998459397, 3.1112698372208096, 3.1464265445104544, 3.1811947441173736, 3.2155870381627056, 3.2496153618543846, 3.283291031876401, 3.3166247903554003, 3.3496268448888458, 3.3823069050575527, 3.414674215792775, 3.4467375879228173, 3.4785054261852175, 3.509985754956849, 3.5411862419251547, 3.5721142198983507, 3.602776706930364, 3.63318042491699, 3.6633318168028404, 3.6932370625238775, 3.722902093797257, 3.752332607858744, 3.7815340802378072, 3.81051177665153, 3.8392707640904935, 3.867815921162743, 3.8961519477556315, 3.924283374069717, 3.952214569073901, 3.97994974842648, 4.007492981902776, 4.034848200366403, 4.06201920231798, 4.0890096600521755, 4.115823125451336, 4.1424630354415966, 4.168932717135166, 4.1952353926806065, 4.221374183841087, 4.247352116319061, 4.273172123844299, 4.298837052040936, 4.324349662087931, 4.349712634186309, 4.374928570845472, 4.4, 4.424929377967517, 4.449719092257398, 4.474371464239419, 4.498888751680798, 4.523273151159457, 4.54752680036083, 4.571651780264984, 4.595650117230424, 4.61952378498044, 4.64327470649756, 4.666904755831214, 4.69041575982343, 4.713809499757071], [0.0, 0.479583152331272, 0.6782329983125268, 0.8306623862918077, 0.959166304662544, 1.072380529476361, 1.174734012447073, 1.2688577540449522, 1.3564659966250536, 1.438749456993816, 1.5165750888103102, 1.5905973720586868, 1.6613247725836153, 1.7291616465790585, 1.7944358444926363, 1.857417562100671, 1.918332609325088, 1.977371993328519, 2.0346989949375804, 2.0904544960366875, 2.144761058952722, 2.1977260975835913, 2.249444375840399, 2.3000000000000003, 2.349468024894146, 2.39791576165636, 2.4454038521274972, 2.491987158875423, 2.5377155080899043, 2.582634314028992, 2.6267851073127395, 2.670205984563738, 2.7129319932501073, 2.754995462791183, 2.7964262908219126, 2.8372521918222215, 2.877498913987632, 2.917190429162965, 2.956349099818897, 2.994995826374388, 3.0331501776206204, 3.0708305065568178, 3.108054053584011, 3.1448370387032774, 3.1811947441173736, 3.2171415884290826, 3.252691193458119, 3.2878564445547194, 3.3226495451672307, 3.357082066318904, 3.3911649915626345, 3.4249087579087423, 3.458323293158117, 3.491418050019219, 3.5242020373412197, 3.5566838487557484, 3.5888716889852725, 3.620773398046335, 3.6523964735499352, 3.6837480912787726, 3.714835124201342, 3.745664160065609, 3.7762415176998414, 3.8065732621348563, 3.836665218650176, 3.866522985836241, 3.8961519477556315, 3.9255572852781047, 3.954743986657038, 3.9837168574084183, 4.012480529547776, 4.041039470235351, 4.069397989875161, 4.097560249709576, 4.125530268947254, 4.153311931459037, 4.180908992073375, 4.2083250825001635, 4.235563716909475, 4.262628297189424, 4.289522117905444, 4.316248370981448, 4.342810150121694, 4.369210454990696, 4.3954521951671826, 4.421538193886829, 4.447471191587417, 4.473253849269009, 4.498888751680798, 4.524378410345448, 4.549725266430931, 4.57493169347915, 4.6000000000000005, 4.624932431938872, 4.649731175025068, 4.674398357008098, 4.698936049788292, 4.723346271447818, 4.747630988187688, 4.77179211617606, 4.79583152331272, 4.819751030914357], [0.0, 0.48989794855663565, 0.6928203230275509, 0.8485281374238571, 0.9797958971132713, 1.0954451150103324, 1.2000000000000002, 1.2961481396815722, 1.3856406460551018, 1.469693845669907, 1.5491933384829668, 1.6248076809271923, 1.6970562748477143, 1.7663521732655696, 1.833030277982336, 1.8973665961010275, 1.9595917942265426, 2.0199009876724157, 2.078460969082653, 2.1354156504062627, 2.1908902300206647, 2.244994432064365, 2.297825058615212, 2.349468024894146, 2.4000000000000004, 2.4494897427831783, 2.4979991993593598, 2.5455844122715714, 2.5922962793631443, 2.638181191654584, 2.6832815729997477, 2.727636339397171, 2.7712812921102037, 2.8142494558940583, 2.8565713714171403, 2.898275349237888, 2.939387691339814, 2.979932885150268, 3.0199337741083, 3.0594117081556713, 3.0983866769659336, 3.136877428271625, 3.174901573277509, 3.212475680841802, 3.2496153618543846, 3.2863353450309964, 3.32264954516723, 3.358571124749333, 3.3941125496954285, 3.4292856398964493, 3.464101615137755, 3.498571136907181, 3.532704346531139, 3.5665109000254023, 3.6, 3.6331804249169903, 3.666060555964672, 3.698648401781386, 3.7309516212355263, 3.7629775444453557, 3.794733192202055, 3.8262252939417984, 3.857460304397182, 3.8884444190447165, 3.9191835884530852, 3.9496835316262997, 3.97994974842648, 4.009987531152684, 4.039801975344831, 4.069397989875161, 4.09878030638384, 4.127953488110059, 4.156921938165306, 4.18568990729127, 4.214261501141095, 4.242640687119286, 4.270831300812525, 4.298837052040936, 4.3266615305567875, 4.354308211415448, 4.3817804600413295, 4.409081537009721, 4.436214602563767, 4.463182720884279, 4.48998886412873, 4.5166359162544865, 4.543126676640219, 4.5694638635183455, 4.595650117230424, 4.621688003316537, 4.6475800154489, 4.673328578219169, 4.698936049788292, 4.724404724407087, 4.749736834815168, 4.774934554525329, 4.800000000000001, 4.824935232725928, 4.849742261192857, 4.874423042781577, 4.898979485566357, 4.9234134500364695], [0.0, 0.5, 0.7071067811865476, 0.8660254037844388, 1.0, 1.118033988749895, 1.2247448713915892, 1.3228756555322954, 1.4142135623730951, 1.5, 1.5811388300841898, 1.6583123951777001, 1.7320508075688776, 1.8027756377319948, 1.8708286933869707, 1.9364916731037083, 2.0, 2.0615528128088303, 2.121320343559643, 2.179449471770337, 2.23606797749979, 2.2912878474779204, 2.345207879911715, 2.39791576165636, 2.4494897427831783, 2.5000000000000004, 2.5495097567963927, 2.5980762113533165, 2.6457513110645907, 2.6925824035672523, 2.7386127875258306, 2.783882181415011, 2.8284271247461903, 2.8722813232690148, 2.9154759474226504, 2.958039891549808, 3.0, 3.04138126514911, 3.0822070014844885, 3.1224989991991996, 3.1622776601683795, 3.2015621187164247, 3.2403703492039306, 3.278719262151, 3.3166247903554003, 3.3541019662496843, 3.3911649915626345, 3.4278273002005224, 3.4641016151377553, 3.5, 3.535533905932738, 3.5707142142714257, 3.6055512754639896, 3.64005494464026, 3.6742346141747677, 3.708099243547832, 3.7416573867739413, 3.774917217635375, 3.8078865529319548, 3.840572873934304, 3.8729833462074166, 3.9051248379533274, 3.9370039370059056, 3.968626966596886, 4.0, 4.031128874149275, 4.06201920231798, 4.092676385936225, 4.123105625617661, 4.153311931459037, 4.183300132670378, 4.2130748865881795, 4.242640687119286, 4.272001872658766, 4.301162633521313, 4.330127018922194, 4.358898943540674, 4.387482193696061, 4.415880433163924, 4.444097208657795, 4.47213595499958, 4.500000000000001, 4.527692569068709, 4.55521678957215, 4.582575694955841, 4.609772228646444, 4.636809247747852, 4.663689526544408, 4.69041575982343, 4.716990566028302, 4.743416490252569, 4.769696007084729, 4.79583152331272, 4.821825380496478, 4.847679857416329, 4.873397172404482, 4.898979485566357, 4.924428900898053, 4.949747468305833, 4.974937185533101, 5.000000000000001, 5.024937810560446], [0.0, 0.5099019513592785, 0.7211102550927979, 0.8831760866327849, 1.019803902718557, 1.140175425099138, 1.2489995996796799, 1.3490737563232043, 1.4422205101855958, 1.5297058540778354, 1.61245154965971, 1.6911534525287766, 1.7663521732655698, 1.8384776310850237, 1.9078784028338913, 1.9748417658131499, 2.039607805437114, 2.102379604162864, 2.1633307652783937, 2.2226110770892875, 2.280350850198276, 2.336664289109585, 2.3916521486202797, 2.4454038521274972, 2.4979991993593598, 2.5495097567963927, 2.6000000000000005, 2.6495282598983545, 2.6981475126464085, 2.7459060435491964, 2.792848008753788, 2.839013913315678, 2.8844410203711917, 2.9291637031753623, 2.973213749463701, 3.0166206257996713, 3.059411708155671, 3.101612483854165, 3.1432467291003428, 3.1843366656181322, 3.22490309931942, 3.264965543462902, 3.304542328371662, 3.3436506994600976, 3.382306905057553, 3.420526275297414, 3.458323293158117, 3.4957116585897072, 3.5327043465311396, 3.5693136595149495, 3.6055512754639896, 3.6414282912066254, 3.6769552621700474, 3.712142238654118, 3.7469987990390394, 3.7815340802378077, 3.8157568056677826, 3.849675310984032, 3.8832975677895205, 3.916631205513228, 3.9496835316262997, 3.9824615503479754, 4.014971979976946, 4.047221268969613, 4.079215610874228, 4.110960958218893, 4.142463035441596, 4.173727350941841, 4.204759208325728, 4.235563716909475, 4.266145801540309, 4.296510211788167, 4.3266615305567875, 4.356604182158393, 4.386342439892262, 4.415880433163924, 4.445222154178575, 4.474371464239419, 4.503332099679082, 4.532107677449864, 4.560701700396552, 4.589117562233507, 4.617358552246079, 4.645427859734774, 4.67332857821917, 4.701063709417264, 4.7286361670147565, 4.756048780237647, 4.7833042972405595, 4.810405388322278, 4.83735464897913, 4.864154602806124, 4.8908077042549944, 4.917316341257699, 4.943682837723311, 4.969909455915671, 4.9959983987187195, 5.021951811795889, 5.047771785649585, 5.073460357586329, 5.099019513592785, 5.1244511901275835], [0.0, 0.5196152422706632, 0.7348469228349535, 0.9000000000000001, 1.0392304845413265, 1.1618950038622253, 1.2727922061357857, 1.374772708486752, 1.469693845669907, 1.5588457268119895, 1.6431676725154984, 1.7233687939614089, 1.8000000000000003, 1.8734993995195197, 1.9442222095223582, 2.0124611797498106, 2.078460969082653, 2.142428528562855, 2.2045407685048604, 2.2649503305812253, 2.3237900077244507, 2.381176179958132, 2.4372115213907883, 2.491987158875423, 2.5455844122715714, 2.5980762113533165, 2.6495282598983545, 2.7, 2.749545416973504, 2.7982137159266447, 2.8460498941515415, 2.8930952282978866, 2.939387691339814, 2.9849623113198605, 3.0298514815086235, 3.0740852297878796, 3.117691453623979, 3.160696125855822, 3.203123475609394, 3.244996147917591, 3.286335345030997, 3.3271609519228256, 3.3674916480965478, 3.407345007480164, 3.4467375879228177, 3.4856850115866753, 3.5242020373412197, 3.5623026261113755, 3.6000000000000005, 3.6373066958946425, 3.6742346141747677, 3.7107950630558952, 3.7469987990390394, 3.782856063875548, 3.818376618407357, 3.853569773599539, 3.8884444190447165, 3.9230090491866063, 3.957271787481876, 3.9912404086950213, 4.024922359499621, 4.058324777540605, 4.091454509095756, 4.124318125460256, 4.156921938165306, 4.189272013130682, 4.221374183841087, 4.253234063627348, 4.28485705712571, 4.316248370981448, 4.3474130238568325, 4.378355855797928, 4.409081537009721, 4.439594576084623, 4.469899327725402, 4.5, 4.529900661162451, 4.559605246071199, 4.589117562233508, 4.618441295502196, 4.647580015448901, 4.676537180435969, 4.705316142407438, 4.73392015141785, 4.762352359916264, 4.790615826801394, 4.818713521262704, 4.846648326421054, 4.874423042781577, 4.902040391510457, 4.929503017546495, 4.956813492557492, 4.983974317750846, 5.0109879265470205, 5.037856687124, 5.06458290484024, 5.091168824543143, 5.117616632769595, 5.143928459844674, 5.170106381884226, 5.196152422706633, 5.222068555658764], [0.0, 0.5291502622129182, 0.7483314773547882, 0.9165151389911681, 1.0583005244258363, 1.1832159566199234, 1.2961481396815722, 1.4000000000000001, 1.4966629547095764, 1.5874507866387544, 1.6733200530681511, 1.7549928774784245, 1.8330302779823362, 1.9078784028338915, 1.9798989873223332, 2.0493901531919194, 2.1166010488516727, 2.181742422927143, 2.244994432064365, 2.3065125189341593, 2.366431913239847, 2.4248711305964283, 2.4819347291981715, 2.5377155080899043, 2.5922962793631443, 2.6457513110645907, 2.6981475126464085, 2.749545416973504, 2.8000000000000003, 2.8495613697550017, 2.8982753492378874, 2.946183972531247, 2.993325909419153, 3.039736830714133, 3.0854497241083028, 3.1304951684997055, 3.1749015732775088, 3.2186953878862163, 3.2619012860600183, 3.3045423283716615, 3.3466401061363023, 3.3882148692194836, 3.4292856398964497, 3.4698703145794942, 3.509985754956849, 3.5496478698597693, 3.5888716889852725, 3.627671429443411, 3.6660605559646724, 3.704051835490427, 3.7416573867739418, 3.7788887255382373, 3.815756805667783, 3.852272056851645, 3.8884444190447165, 3.924283374069717, 3.9597979746446663, 3.994996871087636, 4.029888335921977, 4.064480286580315, 4.098780306383839, 4.132795663954365, 4.166533331199932, 4.2, 4.233202097703345, 4.266145801540308, 4.298837052040936, 4.331281565541543, 4.363484845854286, 4.3954521951671826, 4.427188724235731, 4.458699361921591, 4.48998886412873, 4.521061822182926, 4.551922670696417, 4.58257569495584, 4.613025037868319, 4.64327470649756, 4.67332857821917, 4.703190406521939, 4.732863826479694, 4.762352359916263, 4.791659420284376, 4.82078831727758, 4.849742261192857, 4.878524367060187, 4.907137658554119, 4.935585071701227, 4.963869458396343, 4.991993589739474, 5.019960159204453, 5.047771785649585, 5.075431016179809, 5.10294032886923, 5.130302135352265, 5.15751878329105, 5.184592558726289, 5.2115256883181535, 5.238320341483518, 5.264978632435274, 5.291502622129181, 5.317894320123333], [0.0, 0.5385164807134505, 0.7615773105863909, 0.9327379053088817, 1.077032961426901, 1.2041594578792296, 1.319090595827292, 1.4247806848775009, 1.5231546211727818, 1.6155494421403513, 1.7029386365926402, 1.7860571099491753, 1.8654758106177634, 1.94164878389476, 2.0149441679609885, 2.085665361461421, 2.154065922853802, 2.220360331117452, 2.2847319317591728, 2.3473389188611007, 2.4083189157584592, 2.4677925358506134, 2.5258661880630178, 2.582634314028992, 2.638181191654584, 2.6925824035672523, 2.7459060435491964, 2.7982137159266447, 2.8495613697550017, 2.9000000000000004, 2.9495762407505253, 2.99833287011299, 3.0463092423455636, 3.0935416596516045, 3.1400636936215167, 3.1859064644147983, 3.2310988842807027, 3.2756678708318403, 3.3196385345395667, 3.363034344160048, 3.4058772731852804, 3.448187929913334, 3.48998567332303, 3.531288716601915, 3.5721142198983507, 3.6124783736376886, 3.6523964735499352, 3.691882988394947, 3.7309516212355267, 3.769615364994153, 3.8078865529319548, 3.845776904605883, 3.88329756778952, 3.9204591567825324, 3.957271787481876, 3.993745109543172, 4.029888335921977, 4.065710270051224, 4.101219330881976, 4.136423575989287, 4.171330722922842, 4.205948168962618, 4.240283009422838, 4.274342054632503, 4.308131845707604, 4.341658669218482, 4.374928570845472, 4.407947368106838, 4.440720662234904, 4.473253849269009, 4.505552130427525, 4.537620521815371, 4.5694638635183455, 4.601086828130937, 4.632493928760188, 4.663689526544408, 4.694677837722201, 4.725462940284264, 4.756048780237647, 4.786439177509728, 4.8166378315169185, 4.846648326421054, 4.876474136094644, 4.906118628814432, 4.935585071701227, 4.964876634922565, 4.993996395673509, 5.022947341949744, 5.0517323761260355, 5.0803543183522155, 5.10881590977792, 5.137119815616529, 5.165268628057984, 5.193264869039514, 5.221110992882646, 5.2488093888042835, 5.276362383309168, 5.3037722424704485, 5.331041174104736, 5.358171329847527, 5.385164807134505, 5.412023651093924], [0.0, 0.5477225575051661, 0.7745966692414833, 0.9486832980505139, 1.0954451150103321, 1.2247448713915892, 1.3416407864998738, 1.4491376746189437, 1.5491933384829666, 1.6431676725154982, 1.7320508075688772, 1.816590212458495, 1.8973665961010278, 1.9748417658131499, 2.0493901531919194, 2.1213203435596424, 2.1908902300206643, 2.258317958127243, 2.32379000772445, 2.3874672772626644, 2.4494897427831783, 2.5099800796022267, 2.569046515733026, 2.6267851073127395, 2.6832815729997477, 2.7386127875258306, 2.792848008753788, 2.8460498941515415, 2.8982753492378874, 2.9495762407505253, 2.9999999999999996, 3.049590136395381, 3.098386676965933, 3.146426544510455, 3.1937438845342623, 3.2403703492039297, 3.2863353450309964, 3.331666249791536, 3.376388603226826, 3.420526275297414, 3.4641016151377544, 3.5071355833500366, 3.5496478698597698, 3.5916569992135936, 3.63318042491699, 3.674234614174767, 3.714835124201342, 3.7549966711037173, 3.7947331922020555, 3.8340579025361627, 3.872983346207417, 3.9115214431215892, 3.9496835316262997, 3.9874804074753776, 4.024922359499621, 4.06201920231798, 4.098780306383839, 4.135214625627066, 4.171330722922842, 4.207136793592525, 4.242640687119285, 4.277849927241487, 4.3127717305695645, 4.347413023856832, 4.381780460041329, 4.415880433163923, 4.449719092257397, 4.483302354291978, 4.516635916254486, 4.54972526643093, 4.58257569495584, 4.61519230368573, 4.6475800154489, 4.679743582719036, 4.711687595755898, 4.743416490252569, 4.774934554525329, 4.806245936279166, 4.83735464897913, 4.868264577855234, 4.898979485566357, 4.929503017546495, 4.959838707054898, 4.9899899799498595, 5.019960159204453, 5.049752469181039, 5.079370039680118, 5.10881590977792, 5.138093031466052, 5.167204273105525, 5.196152422706632, 5.224940191045253, 5.253570214625479, 5.282045058497703, 5.310367218940701, 5.338539126015655, 5.366563145999495, 5.394441583704471, 5.422176684690383, 5.449770637375485, 5.477225575051661, 5.504543577809154], [0.0, 0.5567764362830022, 0.7874007874011811, 0.9643650760992957, 1.1135528725660044, 1.2449899597988734, 1.3638181696985856, 1.4730919862656235, 1.5748015748023623, 1.6703293088490065, 1.760681686165901, 1.846618531261939, 1.9287301521985913, 2.0074859899884734, 2.083266665599966, 2.1563858652847823, 2.227105745132009, 2.2956480566497994, 2.3622023622035435, 2.4269322199023198, 2.489979919597747, 2.551470164434615, 2.6115129714401193, 2.670205984563738, 2.727636339397171, 2.783882181415011, 2.839013913315678, 2.8930952282978866, 2.946183972531247, 2.99833287011299, 3.049590136395381, 3.1, 3.1496031496047245, 3.1984371183438953, 3.2465366161495854, 3.2939338184001206, 3.340658617698013, 3.38673884437522, 3.432200460346103, 3.477067730142742, 3.521363372331802, 3.5651086939951777, 3.6083237105337433, 3.6510272527057364, 3.693237062523878, 3.7349698793966195, 3.7762415176998414, 3.817066936798463, 3.8574603043971827, 3.8974350539810154, 3.9370039370059056, 3.9761790704142093, 4.014971979976947, 4.053393639902249, 4.091454509095757, 4.129164564412516, 4.166533331199932, 4.20356991139674, 4.240283009422838, 4.276680956068619, 4.3127717305695645, 4.34856298103178, 4.384062043356595, 4.419275958796871, 4.454211490264018, 4.488875137492688, 4.523273151159456, 4.557411546042337, 4.591296113299599, 4.624932431938872, 4.658325879540847, 4.69148164229596, 4.724404724407087, 4.757099956906519, 4.789572005931219, 4.8218253804964775, 4.8538644398046396, 4.8856934001224435, 4.917316341257699, 4.948737212663449, 4.979959839195494, 5.01098792654702, 5.041825066382213, 5.072474741188959, 5.10294032886923, 5.13322510708424, 5.163332257370235, 5.193264869039514, 5.223025942880239, 5.252618394667558, 5.282045058497703, 5.3113086899558, 5.340411969127476, 5.36935750346352, 5.398147830506312, 5.426785420486054, 5.455272678794342, 5.483611948342078, 5.511805511808268, 5.539855593785817, 5.567764362830022, 5.595533933415113], [0.0, 0.565685424949238, 0.7999999999999999, 0.9797958971132713, 1.131370849898476, 1.2649110640673518, 1.3856406460551018, 1.4966629547095764, 1.5999999999999999, 1.697056274847714, 1.7888543819998317, 1.876166303929372, 1.9595917942265426, 2.039607805437114, 2.116601048851672, 2.1908902300206643, 2.262741699796952, 2.33238075793812, 2.4, 2.4657656011875906, 2.5298221281347035, 2.5922962793631443, 2.6532998322843198, 2.7129319932501073, 2.7712812921102037, 2.8284271247461903, 2.8844410203711917, 2.939387691339814, 2.993325909419153, 3.0463092423455636, 3.098386676965933, 3.1496031496047245, 3.1999999999999997, 3.249615361854384, 3.2984845004941286, 3.3466401061363023, 3.394112549695428, 3.4409301068170506, 3.487119154832539, 3.5327043465311387, 3.5777087639996634, 3.622154055254967, 3.6660605559646724, 3.709447398198281, 3.752332607858744, 3.7947331922020546, 3.8366652186501757, 3.878143885933063, 3.9191835884530852, 3.959797974644666, 4.0, 4.039801975344831, 4.079215610874228, 4.118252056394801, 4.156921938165306, 4.1952353926806065, 4.233202097703344, 4.2708313008125245, 4.308131845707603, 4.345112196480086, 4.381780460041329, 4.418144406874904, 4.454211490264017, 4.48998886412873, 4.525483399593904, 4.560701700396551, 4.595650117230423, 4.63033476111609, 4.66476151587624, 4.698936049788292, 4.732863826479693, 4.766550115125193, 4.8, 4.833218389437829, 4.866210024238575, 4.898979485566356, 4.931531202375181, 4.963869458396343, 4.995998398718719, 5.027922035990614, 5.059644256269407, 5.091168824543142, 5.122499389946279, 5.15363949069005, 5.184592558726289, 5.215361924162119, 5.2459508194416005, 5.276362383309167, 5.3065996645686395, 5.336665625650533, 5.366563145999495, 5.396295025292816, 5.4258639865002145, 5.455272678794342, 5.4845236803208355, 5.513619500836088, 5.542562584220407, 5.571355310873648, 5.6, 5.628498911788116, 5.656854249492381, 5.685068161420759], [0.0, 0.574456264653803, 0.812403840463596, 0.9949874371066202, 1.148912529307606, 1.2845232578665131, 1.4071247279470291, 1.5198684153570665, 1.624807680927192, 1.7233687939614086, 1.8165902124584952, 1.9052558883257653, 1.9899748742132404, 2.0712315177207983, 2.149418526020468, 2.224859546128699, 2.297825058615212, 2.3685438564654024, 2.4372115213907883, 2.503996805109783, 2.5690465157330262, 2.632489316217637, 2.6944387170614963, 2.754995462791183, 2.8142494558940583, 2.8722813232690148, 2.9291637031753623, 2.9849623113198605, 3.039736830714133, 3.0935416596516045, 3.146426544510455, 3.1984371183438953, 3.249615361854384, 3.3000000000000007, 3.3496268448888458, 3.398529093593286, 3.4467375879228173, 3.49428104193123, 3.541186241925155, 3.58747822293042, 3.6331804249169903, 3.678314831549905, 3.7229020937972575, 3.7669616403674726, 3.8105117766515306, 3.853569773599539, 3.896151947755632, 3.9382737335030438, 3.9799497484264807, 4.02119385257662, 4.06201920231798, 4.102438299353204, 4.1424630354415966, 4.182104733265298, 4.221374183841087, 4.260281680828159, 4.298837052040936, 4.337049688440288, 4.374928570845472, 4.412482294582042, 4.449719092257398, 4.486646854834912, 4.523273151159457, 4.559605246071199, 4.595650117230424, 4.631414470763764, 4.666904755831214, 4.702127178203499, 4.737087712930805, 4.77179211617606, 4.806245936279167, 4.8404545241123795, 4.874423042781577, 4.908156476723211, 4.941659640242335, 4.974937185533101, 5.007993610219566, 5.040833264451424, 5.07346035758633, 5.105878964487898, 5.1380930314660525, 5.170106381884226, 5.201922721455982, 5.23354564325181, 5.264978632435274, 5.296225070746145, 5.327288240746882, 5.358171329847526, 5.388877434122993, 5.419409561935692, 5.449770637375486, 5.479963503528103, 5.509990925582366, 5.539855593785817, 5.569560126257729, 5.599107071667768, 5.628498911788117, 5.657738063926256, 5.686826883245173, 5.715767664977296, 5.7445626465380295, 5.773214009544425], [0.0, 0.5830951894845301, 0.8246211251235321, 1.009950493836208, 1.1661903789690602, 1.30384048104053, 1.4282856857085702, 1.5427248620541514, 1.6492422502470643, 1.7492855684535902, 1.8439088914585775, 1.9339079605813718, 2.019900987672416, 2.102379604162864, 2.181742422927143, 2.258317958127243, 2.3323807579381204, 2.4041630560342617, 2.4738633753705965, 2.5416530054277673, 2.60768096208106, 2.672077843177478, 2.734958866235469, 2.7964262908219126, 2.8565713714171403, 2.9154759474226504, 2.973213749463701, 3.0298514815086235, 3.0854497241083028, 3.1400636936215167, 3.1937438845342623, 3.2465366161495854, 3.2984845004941286, 3.3496268448888458, 3.4000000000000004, 3.449637662132068, 3.4985711369071804, 3.54682957019364, 3.594440151122286, 3.6414282912066254, 3.687817782917155, 3.733630940518894, 3.7788887255382373, 3.823610858861032, 3.8678159211627436, 3.911521443121589, 3.954743986657038, 3.997499218261337, 4.039801975344832, 4.08166632639171, 4.123105625617661, 4.164132562731403, 4.204759208325728, 4.244997055358225, 4.28485705712571, 4.324349662087931, 4.363484845854286, 4.402272140611028, 4.440720662234904, 4.4788391353117385, 4.516635916254486, 4.5541190146942805, 4.591296113299598, 4.628174586162454, 4.664761515876241, 4.701063709417263, 4.737087712930805, 4.77283982551269, 4.8083261120685235, 4.843552415324934, 4.878524367060187, 4.913247398615299, 4.947726750741193, 4.98196748283246, 5.015974481593781, 5.049752469181039, 5.083306010855535, 5.1166395221864125, 5.149757275833494, 5.182663407939976, 5.21536192416212, 5.247856705360771, 5.280151512977635, 5.31224999411737, 5.344155686354956, 5.375872022286245, 5.40740233383831, 5.4387498563548595, 5.469917732470938, 5.500909015790026, 5.531726674375733, 5.562373594069352, 5.592852581643825, 5.62316636780382, 5.653317610041029, 5.683308895353129, 5.713142742834281, 5.742821606144492, 5.772347875864725, 5.801723881744115, 5.830951894845301, 5.860034129593445], [0.0, 0.5916079783099616, 0.8366600265340756, 1.02469507659596, 1.1832159566199232, 1.3228756555322954, 1.449137674618944, 1.5652475842498528, 1.6733200530681511, 1.7748239349298847, 1.8708286933869707, 1.9621416870348585, 2.04939015319192, 2.1330729007701543, 2.2135943621178655, 2.29128784747792, 2.3664319132398464, 2.4392621835300936, 2.5099800796022267, 2.5787593916455256, 2.6457513110645907, 2.711088342345192, 2.7748873851023217, 2.8372521918222215, 2.898275349237888, 2.958039891549808, 3.0166206257996713, 3.0740852297878796, 3.1304951684997055, 3.1859064644147983, 3.2403703492039297, 3.2939338184001206, 3.3466401061363023, 3.398529093593286, 3.449637662132068, 3.5, 3.5496478698597693, 3.5986108430893164, 3.646916505762094, 3.6945906403822333, 3.7416573867739413, 3.7881393849751626, 3.834057902536163, 3.879432948254164, 3.924283374069717, 3.9686269665968856, 4.012480529547776, 4.05585995813465, 4.09878030638384, 4.141255848169731, 4.183300132670378, 4.224926034855522, 4.266145801540309, 4.306971093471606, 4.347413023856832, 4.387482193696061, 4.427188724235731, 4.466542286825459, 4.505552130427525, 4.544227107000705, 4.58257569495584, 4.620606020859168, 4.658325879540846, 4.695742752749559, 4.732863826479693, 4.769696007084728, 4.806245936279166, 4.8425200051213, 4.878524367060187, 4.914264950122246, 4.949747468305833, 4.984977432245807, 5.019960159204453, 5.054700782440045, 5.089204259999788, 5.123475382979799, 5.157518783291051, 5.191338940966964, 5.2249401910452535, 5.2583267300539625, 5.291502622129181, 5.324471804789654, 5.35723809439155, 5.389805191284746, 5.422176684690384, 5.454356057317858, 5.486346689738081, 5.518151864528558, 5.549774770204643, 5.58121850495033, 5.612486080160912, 5.643580423808984, 5.674504383644443, 5.705260730238365, 5.735852159879995, 5.766281297335397, 5.796550698475776, 5.826662852782887, 5.856620185738529, 5.886425061104576, 5.916079783099616, 5.9455865984779], [0.0, 0.6, 0.848528137423857, 1.0392304845413265, 1.2, 1.3416407864998738, 1.469693845669907, 1.5874507866387544, 1.697056274847714, 1.7999999999999998, 1.8973665961010275, 1.98997487421324, 2.078460969082653, 2.1633307652783937, 2.244994432064365, 2.3237900077244498, 2.4, 2.473863375370596, 2.545584412271571, 2.615339366124404, 2.6832815729997477, 2.749545416973504, 2.814249455894058, 2.877498913987632, 2.939387691339814, 3.0, 3.059411708155671, 3.117691453623979, 3.1749015732775088, 3.2310988842807027, 3.2863353450309964, 3.340658617698013, 3.394112549695428, 3.4467375879228173, 3.4985711369071804, 3.5496478698597693, 3.5999999999999996, 3.6496575181789317, 3.698648401781386, 3.746998799039039, 3.794733192202055, 3.8418745424597094, 3.8884444190447165, 3.9344631145812, 3.97994974842648, 4.024922359499621, 4.069397989875161, 4.113392760240626, 4.156921938165306, 4.2, 4.242640687119285, 4.28485705712571, 4.3266615305567875, 4.368065933568311, 4.409081537009721, 4.449719092257398, 4.48998886412873, 4.52990066116245, 4.569463863518345, 4.608687448721165, 4.6475800154488995, 4.686149805543993, 4.724404724407086, 4.762352359916263, 4.8, 4.8373546489791295, 4.874423042781576, 4.91121166312347, 4.947726750741192, 4.983974317750845, 5.019960159204453, 5.0556898639058145, 5.091168824543142, 5.126402247190518, 5.161395160225576, 5.196152422706632, 5.230678732248808, 5.264978632435273, 5.299056519796709, 5.332916650389353, 5.366563145999495, 5.4, 5.43323108288245, 5.466260147486579, 5.499090833947008, 5.531726674375732, 5.5641710972974225, 5.596427431853289, 5.628498911788116, 5.660388679233962, 5.692099788303082, 5.7236352085016735, 5.754997827975264, 5.786190456595773, 5.817215828899595, 5.848076606885377, 5.878775382679628, 5.909314681077663, 5.939696961966999, 5.96992462263972, 6.0, 6.029925372672535], [0.0, 0.608276253029822, 0.8602325267042626, 1.053565375285274, 1.216552506059644, 1.3601470508735445, 1.489966442575134, 1.6093476939431082, 1.7204650534085253, 1.8248287590894658, 1.9235384061671346, 2.017424100183202, 2.107130750570548, 2.193171219946131, 2.2759613353482084, 2.355843797877949, 2.433105012119288, 2.5079872407968904, 2.5806975801127883, 2.651414716712571, 2.720294101747089, 2.787471972953271, 2.8530685235374214, 2.917190429162965, 2.979932885150268, 3.04138126514911, 3.101612483854165, 3.160696125855822, 3.2186953878862163, 3.2756678708318403, 3.331666249791536, 3.38673884437522, 3.4409301068170506, 3.49428104193123, 3.54682957019364, 3.5986108430893164, 3.6496575181789317, 3.7, 3.7496666518505353, 3.7986839826445165, 3.847076812334269, 3.89486841883009, 3.942080668885405, 3.988734135035826, 4.034848200366404, 4.080441152620633, 4.125530268947254, 4.170131892398609, 4.214261501141096, 4.257933771208754, 4.301162633521314, 4.343961325794695, 4.386342439892262, 4.428317965096906, 4.469899327725402, 4.511097427455985, 4.551922670696417, 4.592385001282014, 4.632493928760188, 4.672258554489466, 4.711687595755898, 4.750789408087881, 4.789572005931219, 4.828043081829325, 4.866210024238576, 4.904079934095691, 4.941659640242335, 4.978955713801841, 5.015974481593781, 5.052722038663912, 5.089204259999789, 5.1254268114957995, 5.1613951602255765, 5.197114584074513, 5.232590180780452, 5.26782687642637, 5.302829433425142, 5.3376024580330075, 5.372150407425318, 5.406477596365309, 5.440588203494178, 5.474486277268398, 5.508175741568166, 5.541660400998964, 5.574943945906542, 5.608029957123981, 5.640921910468182, 5.673623181001714, 5.706137047074843, 5.7384666941614295, 5.770615218501404, 5.8025856305616035, 5.83438085832593, 5.866003750424986, 5.897457079114693, 5.928743543112655, 5.959865770300536, 5.990826320300065, 6.021627686929839, 6.052272300549605, 6.08276253029822, 6.113100686231171], [0.0, 0.6164414002968976, 0.8717797887081348, 1.0677078252031313, 1.2328828005937953, 1.3784048752090223, 1.50996688705415, 1.6309506430300091, 1.7435595774162695, 1.849324200890693, 1.949358868961793, 2.0445048300260877, 2.1354156504062627, 2.222611077089287, 2.3065125189341593, 2.3874672772626644, 2.4657656011875906, 2.541653005427767, 2.615339366124404, 2.687005768508881, 2.7568097504180447, 2.824889378365107, 2.891366458960192, 2.956349099818897, 3.0199337741083, 3.0822070014844885, 3.1432467291003428, 3.203123475609394, 3.2619012860600183, 3.3196385345395667, 3.376388603226826, 3.432200460346103, 3.487119154832539, 3.541186241925155, 3.594440151122286, 3.646916505762094, 3.698648401781386, 3.7496666518505353, 3.8000000000000003, 3.8496753109840323, 3.898717737923586, 3.9471508711981107, 3.9949968710876362, 4.042276586281547, 4.0890096600521755, 4.135214625627066, 4.180908992073375, 4.226109321823088, 4.270831300812525, 4.315089802078284, 4.358898943540674, 4.402272140611029, 4.445222154178574, 4.487761134463376, 4.529900661162451, 4.571651780264984, 4.613025037868319, 4.654030511288038, 4.694677837722201, 4.734976240700686, 4.774934554525329, 4.814561246884289, 4.853864439804639, 4.892851929090027, 4.931531202375181, 4.969909455915671, 5.007993610219566, 5.045790324617146, 5.083306010855534, 5.120546845796843, 5.157518783291051, 5.194227565288221, 5.230678732248808, 5.266877632905477, 5.302829433425141, 5.338539126015656, 5.374011537017762, 5.409251334519409, 5.444263035526481, 5.47905101272109, 5.513619500836089, 5.547972602672079, 5.582114294781146, 5.616048432839589, 5.649778756730214, 5.68330889535313, 5.716642371182581, 5.749782604586021, 5.782732917920384, 5.815496539419485, 5.848076606885378, 5.880476171195663, 5.912698199637794, 5.944745579080741, 5.976621118993575, 6.008327554319921, 6.0398675482166, 6.071243694664217, 6.102458520956943, 6.133514490078262, 6.164414002968977, 6.1951594006934165], [0.0, 0.6244997998398399, 0.8831760866327847, 1.081665382639197, 1.2489995996796799, 1.3964240043768943, 1.5297058540778357, 1.6522711641858308, 1.7663521732655694, 1.8734993995195195, 1.97484176581315, 2.0712315177207983, 2.163330765278394, 2.2516660498395407, 2.3366642891095846, 2.4186773244895647, 2.4979991993593598, 2.574878637916747, 2.6495282598983545, 2.7221315177632404, 2.7928480087537886, 2.861817604250837, 2.9291637031753623, 2.994995826374388, 3.0594117081556713, 3.1224989991991996, 3.1843366656181322, 3.244996147917591, 3.3045423283716615, 3.363034344160048, 3.420526275297414, 3.477067730142742, 3.5327043465311387, 3.58747822293042, 3.6414282912066254, 3.6945906403822333, 3.746998799039039, 3.7986839826445165, 3.8496753109840323, 3.900000000000001, 3.9496835316263, 3.9987498046264416, 4.047221268969613, 4.095119045888654, 4.1424630354415966, 4.189272013130682, 4.235563716909475, 4.281354925721529, 4.326661530556788, 4.371498598878879, 4.415880433163924, 4.459820624195553, 4.503332099679081, 4.546427168667723, 4.589117562233507, 4.631414470763765, 4.673328578219169, 4.7148700936505135, 4.756048780237647, 4.796873982084583, 4.8373546489791295, 4.87749935930288, 4.917316341257699, 4.956813492557492, 4.9959983987187195, 5.034878350069642, 5.073460357586329, 5.111751167652823, 5.149757275833494, 5.187484939737176, 5.2249401910452535, 5.262128846769148, 5.299056519796709, 5.335728628781641, 5.372150407425317, 5.408326913195984, 5.444263035526481, 5.479963503528103, 5.515432893255072, 5.550675634551168, 5.585696017507577, 5.620498198558559, 5.655086206239478, 5.68946394662977, 5.723635208501674, 5.757603668193913, 5.791372894228104, 5.8249463516842805, 5.858327406350725, 5.8915193286621745, 5.92452529743945, 5.957348403442593, 5.989991652748776, 6.02245796996542, 6.054750201288242, 6.08687111741328, 6.118823416311343, 6.150609725872713, 6.182232606429493, 6.213694553162394, 6.244997998398399, 6.276145313805283], [0.0, 0.6324555320336759, 0.8944271909999159, 1.0954451150103324, 1.2649110640673518, 1.4142135623730951, 1.5491933384829668, 1.6733200530681511, 1.7888543819998317, 1.8973665961010275, 2.0, 2.0976176963403033, 2.1908902300206647, 2.280350850198276, 2.3664319132398464, 2.449489742783178, 2.5298221281347035, 2.6076809620810595, 2.6832815729997477, 2.7568097504180447, 2.8284271247461903, 2.898275349237888, 2.9664793948382653, 3.0331501776206204, 3.0983866769659336, 3.1622776601683795, 3.22490309931942, 3.286335345030997, 3.3466401061363023, 3.4058772731852804, 3.4641016151377544, 3.521363372331802, 3.5777087639996634, 3.6331804249169903, 3.687817782917155, 3.7416573867739413, 3.794733192202055, 3.847076812334269, 3.898717737923586, 3.9496835316263, 4.0, 4.049691346263318, 4.09878030638384, 4.147288270665544, 4.1952353926806065, 4.242640687119285, 4.2895221179054435, 4.33589667773576, 4.3817804600413295, 4.427188724235731, 4.47213595499958, 4.5166359162544865, 4.560701700396552, 4.604345773288536, 4.6475800154489, 4.69041575982343, 4.732863826479693, 4.774934554525329, 4.8166378315169185, 4.857983120596447, 4.898979485566356, 4.9396356140913875, 4.979959839195493, 5.019960159204453, 5.059644256269407, 5.0990195135927845, 5.138093031466052, 5.176871642217914, 5.215361924162119, 5.253570214625479, 5.291502622129181, 5.329165037789691, 5.366563145999495, 5.403702434442518, 5.440588203494177, 5.477225575051661, 5.513619500836089, 5.549774770204643, 5.585696017507577, 5.621387729022079, 5.656854249492381, 5.692099788303083, 5.727128425310542, 5.761944116355173, 5.796550698475776, 5.830951894845301, 5.865151319446072, 5.8991524815010505, 5.932958789676531, 5.966573556070519, 6.0, 6.0332412515993425, 6.066300355241241, 6.099180272790763, 6.131883886702357, 6.164414002968976, 6.196773353931867, 6.228964600958975, 6.260990336999411, 6.29285308902091, 6.324555320336759, 6.356099432828282], [0.0, 0.6403124237432849, 0.9055385138137417, 1.1090536506409419, 1.2806248474865698, 1.4317821063276355, 1.5684387141358125, 1.6941074346097418, 1.8110770276274835, 1.9209372712298547, 2.024845673131659, 2.1236760581595306, 2.2181073012818837, 2.3086792761230397, 2.395829710142188, 2.479919353527449, 2.5612496949731396, 2.6400757564888173, 2.716615541441225, 2.791057147390573, 2.863564212655271, 2.934280150224242, 3.0033314835362415, 3.0708305065568178, 3.136877428271625, 3.2015621187164247, 3.264965543462902, 3.3271609519228256, 3.3882148692194836, 3.448187929913334, 3.5071355833500366, 3.5651086939951777, 3.622154055254967, 3.678314831549905, 3.733630940518894, 3.7881393849751626, 3.8418745424597094, 3.89486841883009, 3.9471508711981107, 3.9987498046264416, 4.049691346263318, 4.1000000000000005, 4.149698784249287, 4.198809355043403, 4.247352116319061, 4.295346318982906, 4.342810150121693, 4.389760813529594, 4.436214602563767, 4.4821869662029945, 4.527692569068709, 4.572745346069471, 4.617358552246079, 4.661544808322667, 4.705316142407437, 4.748684028233507, 4.791659420284376, 4.8342527861087286, 4.876474136094644, 4.9183330509431755, 4.959838707054898, 5.000999900019996, 5.041825066382213, 5.082322303829225, 5.122499389946279, 5.162363799656123, 5.201922721455982, 5.241183072551464, 5.280151512977635, 5.3188344587888805, 5.35723809439155, 5.395368384086485, 5.43323108288245, 5.470831746635972, 5.508175741568165, 5.545268253204709, 5.582114294781146, 5.61871871515206, 5.655086206239478, 5.691221310052879, 5.727128425310542, 5.762811813689565, 5.798275605729691, 5.833523806414096, 5.868560300448484, 5.903388857258177, 5.93801313572141, 5.9724366886556455, 6.006662967072483, 6.040695324215583, 6.074537019394977, 6.1081912216301815, 6.1416610131136355, 6.174949392505174, 6.208059278067504, 6.24099351065197, 6.27375485654325, 6.306346010171025, 6.338769596696192, 6.3710281744785915, 6.403124237432849, 6.435060217278469], [0.0, 0.6480740698407861, 0.9165151389911681, 1.1224972160321827, 1.2961481396815722, 1.4491376746189442, 1.5874507866387546, 1.7146428199482249, 1.8330302779823362, 1.9442222095223582, 2.04939015319192, 2.149418526020468, 2.2449944320643653, 2.336664289109585, 2.4248711305964283, 2.5099800796022267, 2.5922962793631443, 2.672077843177478, 2.749545416973504, 2.8248893783651075, 2.8982753492378883, 2.9698484809835, 3.039736830714133, 3.108054053584011, 3.174901573277509, 3.2403703492039306, 3.304542328371662, 3.3674916480965478, 3.4292856398964497, 3.48998567332303, 3.5496478698597698, 3.6083237105337433, 3.6660605559646724, 3.7229020937972575, 3.7788887255382373, 3.834057902536163, 3.8884444190447165, 3.942080668885405, 3.9949968710876362, 4.047221268969613, 4.09878030638384, 4.149698784249287, 4.200000000000001, 4.249705872175156, 4.298837052040936, 4.347413023856832, 4.3954521951671826, 4.442971978304612, 4.489988864128731, 4.536518488885503, 4.582575694955841, 4.628174586162455, 4.67332857821917, 4.718050444834181, 4.762352359916264, 4.806245936279167, 4.849742261192857, 4.892851929090027, 4.935585071701227, 4.9779513858614575, 5.019960159204453, 5.061620293937506, 5.10294032886923, 5.143928459844674, 5.184592558726289, 5.224940191045253, 5.264978632435274, 5.304714883949938, 5.344155686354956, 5.383307533477909, 5.422176684690385, 5.46076917659042, 5.499090833947008, 5.537147279962851, 5.574943945906542, 5.612486080160912, 5.649778756730215, 5.686826883245173, 5.723635208501675, 5.760208329565868, 5.796550698475777, 5.832666628567075, 5.868560300448485, 5.904235767650205, 5.939696961967, 5.974947698515863, 6.009991680526689, 6.044832503882966, 6.079473661428266, 6.113918547053109, 6.148170459575759, 6.182232606429493, 6.216108107168022, 6.249799996799899, 6.283311228962004, 6.316644678941503, 6.349803146555018, 6.38278935889318, 6.4156059729381765, 6.448255578061405, 6.480740698407861, 6.5130637951735135], [0.0, 0.6557438524302001, 0.9273618495495702, 1.1357816691600549, 1.3114877048604001, 1.466287829861518, 1.606237840420901, 1.7349351572897471, 1.8547236990991405, 1.9672315572906, 2.073644135332772, 2.1748563170931545, 2.2715633383201097, 2.364318083507378, 2.453568829277059, 2.5396850198400585, 2.6229754097208002, 2.7037011669191546, 2.782085548648711, 2.8583211855912904, 2.932575659723036, 3.004995840263344, 3.0757112998459397, 3.1448370387032774, 3.212475680841802, 3.278719262151, 3.3436506994600976, 3.407345007480164, 3.4698703145794942, 3.531288716601915, 3.5916569992135936, 3.6510272527057364, 3.709447398198281, 3.7669616403674726, 3.823610858861032, 3.879432948254164, 3.9344631145812, 3.988734135035826, 4.042276586281547, 4.095119045888654, 4.147288270665544, 4.198809355043403, 4.249705872175156, 4.299999999999999, 4.349712634186309, 4.398863489584553, 4.447471191587417, 4.495553358597804, 4.543126676640219, 4.5902069670114, 4.636809247747852, 4.682947789587239, 4.728636167014756, 4.773887304912004, 4.818713521262703, 4.863126566315131, 4.907137658554118, 4.950757517794625, 4.993996395673509, 5.03686410378521, 5.079370039680117, 5.121523210920751, 5.163332257370234, 5.204805471869242, 5.2459508194416005, 5.28677595515452, 5.3272882407468805, 5.367494760127856, 5.407402333838309, 5.447017532558529, 5.486346689738081, 5.525395913416522, 5.564171097297422, 5.602677931132575, 5.6409219104681805, 5.678908345800274, 5.716642371182581, 5.754128952326321, 5.791372894228104, 5.8283788483591215, 5.865151319446072, 5.9016946718718, 5.938013135721409, 5.974110812497538, 6.009991680526688, 6.0456596000767355, 6.081118318204308, 6.1163714733492105, 6.151422599691879, 6.186275131288617, 6.220932405998315, 6.255397669213365, 6.289674077406555, 6.323764701504951, 6.357672530100933, 6.3914004725099165, 6.424951361683604, 6.458327956987009, 6.491532946846992, 6.524568951279464, 6.557438524302, 6.590144156238162], [0.0, 0.66332495807108, 0.938083151964686, 1.148912529307606, 1.32664991614216, 1.4832396974191329, 1.6248076809271923, 1.7549928774784245, 1.876166303929372, 1.98997487421324, 2.0976176963403033, 2.2, 2.297825058615212, 2.3916521486202797, 2.4819347291981715, 2.569046515733026, 2.65329983228432, 2.734958866235469, 2.814249455894058, 2.8913664589601926, 2.9664793948382657, 3.039736830714133, 3.1112698372208096, 3.1811947441173736, 3.2496153618543846, 3.3166247903554003, 3.382306905057553, 3.4467375879228177, 3.509985754956849, 3.5721142198983507, 3.63318042491699, 3.693237062523878, 3.752332607858744, 3.8105117766515306, 3.8678159211627436, 3.924283374069717, 3.97994974842648, 4.034848200366404, 4.0890096600521755, 4.1424630354415966, 4.1952353926806065, 4.247352116319061, 4.298837052040936, 4.349712634186309, 4.4, 4.449719092257398, 4.498888751680798, 4.54752680036083, 4.595650117230424, 4.64327470649756, 4.69041575982343, 4.737087712930806, 4.7833042972405595, 4.829078587059855, 4.874423042781577, 4.919349550499538, 4.963869458396343, 5.007993610219566, 5.051732376126036, 5.095095681142799, 5.138093031466052, 5.180733538795447, 5.223025942880239, 5.264978632435274, 5.30659966456864, 5.347896782848375, 5.388877434122993, 5.429548784199292, 5.469917732470938, 5.509990925582365, 5.549774770204644, 5.589275444992849, 5.628498911788116, 5.667450926121902, 5.706137047074843, 5.7445626465380295, 5.782732917920385, 5.8206528843421, 5.858327406350725, 5.895761189193471, 5.9329587896765315, 5.969924622639721, 6.006662967072484, 6.043177971895251, 6.079473661428266, 6.115553940568263, 6.15142259969188, 6.187083319303208, 6.222539674441619, 6.2577951388648065, 6.29285308902091, 6.327716807822551, 6.362389488234747, 6.3968742366877915, 6.431174076325411, 6.465291950097845, 6.499230723708769, 6.532993188424431, 6.566582063752802, 6.600000000000001, 6.6332495807108005, 6.666333324999584], [0.0, 0.6708203932499369, 0.9486832980505137, 1.161895003862225, 1.3416407864998738, 1.5, 1.6431676725154982, 1.7748239349298847, 1.8973665961010273, 2.0124611797498106, 2.1213203435596424, 2.224859546128699, 2.32379000772445, 2.4186773244895647, 2.5099800796022262, 2.5980762113533156, 2.6832815729997477, 2.765863337187866, 2.846049894151541, 2.924038303442689, 3.0, 3.0740852297878796, 3.1464265445104544, 3.2171415884290826, 3.2863353450309964, 3.3541019662496843, 3.420526275297414, 3.4856850115866753, 3.5496478698597693, 3.6124783736376886, 3.674234614174767, 3.7349698793966195, 3.7947331922020546, 3.853569773599539, 3.911521443121589, 3.9686269665968856, 4.024922359499621, 4.080441152620633, 4.135214625627066, 4.189272013130682, 4.242640687119285, 4.295346318982906, 4.347413023856832, 4.398863489584553, 4.449719092257398, 4.499999999999999, 4.54972526643093, 4.598912915026768, 4.6475800154489, 4.695742752749558, 4.743416490252569, 4.790615826801393, 4.8373546489791295, 4.883646178829912, 4.9295030175464944, 4.9749371855331, 5.0199601592044525, 5.064582904840239, 5.10881590977792, 5.1526692111953, 5.196152422706631, 5.239274758971893, 5.282045058497702, 5.324471804789654, 5.366563145999495, 5.4083269131959835, 5.449770637375485, 5.490901565316937, 5.531726674375732, 5.572252686302012, 5.612486080160912, 5.652433104425031, 5.692099788303082, 5.731491952362839, 5.770615218501403, 5.809475019311125, 5.848076606885378, 5.886425061104575, 5.92452529743945, 5.962382074305537, 6.0, 6.037383539249432, 6.074537019394977, 6.111464636239008, 6.148170459575759, 6.18465843842649, 6.220932405998316, 6.256996084384263, 6.292853089020909, 6.328506932918695, 6.363961030678928, 6.399218702310462, 6.434283176858165, 6.469157595854347, 6.5038450166036395, 6.53834841531101, 6.572670690061993, 6.606814663663572, 6.640783086353596, 6.674578638386096, 6.7082039324993685, 6.74166151627327], [0.0, 0.6782329983125268, 0.9591663046625439, 1.1747340124470733, 1.3564659966250536, 1.5165750888103102, 1.661324772583615, 1.7944358444926363, 1.9183326093250879, 2.0346989949375804, 2.1447610589527217, 2.249444375840399, 2.3494680248941466, 2.445403852127497, 2.5377155080899043, 2.626785107312739, 2.7129319932501073, 2.7964262908219126, 2.877498913987632, 2.956349099818897, 3.0331501776206204, 3.108054053584011, 3.1811947441173736, 3.252691193458119, 3.32264954516723, 3.3911649915626345, 3.458323293158117, 3.5242020373412197, 3.5888716889852725, 3.6523964735499352, 3.714835124201342, 3.7762415176998414, 3.8366652186501757, 3.896151947755632, 3.954743986657038, 4.012480529547776, 4.069397989875161, 4.125530268947254, 4.180908992073375, 4.235563716909475, 4.2895221179054435, 4.342810150121693, 4.3954521951671826, 4.447471191587417, 4.498888751680798, 4.54972526643093, 4.6000000000000005, 4.649731175025068, 4.698936049788293, 4.747630988187688, 4.79583152331272, 4.843552415324934, 4.890807704254994, 4.937610758251404, 4.983974317750845, 5.029910535983717, 5.075431016179809, 5.120546845796843, 5.165268628057984, 5.209606511052442, 5.253570214625478, 5.297169055259611, 5.340411969127476, 5.383307533477908, 5.4258639865002145, 5.468089245796926, 5.509990925582365, 5.551576352712804, 5.592852581643825, 5.63382640840131, 5.674504383644443, 5.71489282489182, 5.754997827975264, 5.794825277780168, 5.834380858325929, 5.873670062235366, 5.912698199637794, 5.951470406546605, 5.989991652748776, 6.028266749240615, 6.066300355241241, 6.104096984812742, 6.1416610131136355, 6.178996682310163, 6.216108107168022, 6.252999280345393, 6.289674077406556, 6.326136261573884, 6.362389488234747, 6.398437309218556, 6.434283176858165, 6.469930447848725, 6.505382386916238, 6.540642170307134, 6.57571288910944, 6.6105975524153635, 6.64529909033446, 6.679820356865895, 6.714164132637808, 6.748333127521196, 6.782329983125269, 6.81615727518079], [0.0, 0.6855654600401044, 0.9695359714832658, 1.187434208703792, 1.3711309200802089, 1.5329709716755893, 1.6792855623746665, 1.8138357147217055, 1.9390719429665315, 2.056696380120313, 2.16794833886788, 2.273763400180415, 2.374868417407584, 2.471841418861655, 2.565151067676132, 2.6551836094703507, 2.7422618401604177, 2.826658805020514, 2.9086079144497976, 2.9883105594967874, 3.0659419433511785, 3.1416556144810017, 3.2155870381627056, 3.2878564445547194, 3.358571124749333, 3.4278273002005224, 3.4957116585897072, 3.5623026261113755, 3.627671429443411, 3.691882988394947, 3.7549966711037173, 3.817066936798463, 3.878143885933063, 3.9382737335030438, 3.997499218261337, 4.05585995813465, 4.113392760240626, 4.170131892398609, 4.226109321823088, 4.281354925721529, 4.33589667773576, 4.389760813529594, 4.442971978304612, 4.495553358597804, 4.54752680036083, 4.598912915026768, 4.649731175025068, 4.7, 4.749736834815168, 4.798958220280731, 4.847679857416329, 4.89591666595746, 4.94368283772331, 4.990991885387113, 5.037856687124, 5.084289527554465, 5.130302135352264, 5.175905717843014, 5.221110992882646, 5.265928218272634, 5.310367218940701, 5.354437412091022, 5.3981478305063115, 5.441507144165117, 5.4845236803208355, 5.527205442174191, 5.569560126257728, 5.61159513863928, 5.653317610041028, 5.69473440996154, 5.735852159879995, 5.776677245614472, 5.817215828899595, 5.857473858242988, 5.897457079114692, 5.937171043518958, 5.976621118993575, 6.015812497078014, 6.054750201288242, 6.09343909463285, 6.131883886702357, 6.17008914036094, 6.208059278067503, 6.245798587850876, 6.2833112289620034, 6.320601237224193, 6.357672530100934, 6.394528911499267, 6.431174076325411, 6.4676116148080505, 6.5038450166036395, 6.539877674696982, 6.575712889109439, 6.611353870426239, 6.646803743153547, 6.682065548915245, 6.717142249498666, 6.7520367297579185, 6.786751800382861, 6.821290200541244, 6.855654600401045, 6.889847603539574], [0.0, 0.692820323027551, 0.9797958971132713, 1.2000000000000004, 1.385640646055102, 1.549193338482967, 1.6970562748477143, 1.8330302779823362, 1.9595917942265426, 2.078460969082653, 2.1908902300206647, 2.297825058615212, 2.400000000000001, 2.4979991993593598, 2.5922962793631443, 2.6832815729997477, 2.771281292110204, 2.8565713714171403, 2.9393876913398143, 3.0199337741083006, 3.098386676965934, 3.174901573277509, 3.2496153618543846, 3.3226495451672307, 3.3941125496954285, 3.4641016151377553, 3.5327043465311396, 3.6000000000000005, 3.6660605559646724, 3.7309516212355267, 3.7947331922020555, 3.8574603043971827, 3.9191835884530852, 3.9799497484264807, 4.039801975344832, 4.09878030638384, 4.156921938165306, 4.214261501141096, 4.270831300812525, 4.326661530556788, 4.3817804600413295, 4.436214602563767, 4.489988864128731, 4.543126676640219, 4.595650117230424, 4.6475800154489, 4.698936049788293, 4.749736834815168, 4.800000000000002, 4.849742261192857, 4.898979485566357, 4.947726750741194, 4.9959983987187195, 5.043808085167398, 5.091168824543143, 5.1380930314660525, 5.184592558726289, 5.230678732248809, 5.276362383309169, 5.321653878260029, 5.366563145999495, 5.411099703387474, 5.455272678794342, 5.499090833947009, 5.542562584220408, 5.585696017507577, 5.628498911788117, 5.670978751503131, 5.713142742834281, 5.754997827975265, 5.796550698475777, 5.83780780773057, 5.8787753826796285, 5.9194594347794975, 5.959865770300536, 6.000000000000001, 6.039867548216601, 6.079473661428266, 6.1188234163113435, 6.157921727336262, 6.196773353931868, 6.235382907247959, 6.27375485654325, 6.311893535223801, 6.349803146555018, 6.387487769068526, 6.424951361683605, 6.462197768561406, 6.499230723708769, 6.536053855347277, 6.572670690061994, 6.609084656743323, 6.645299090334461, 6.681317235396028, 6.717142249498667, 6.752777206453653, 6.788225099390857, 6.823488843692794, 6.8585712797928995, 6.893475175845635, 6.9282032302755105, 6.962758074211686], [0.0, 0.7000000000000001, 0.9899494936611665, 1.2124355652982142, 1.4000000000000001, 1.565247584249853, 1.7146428199482247, 1.8520259177452134, 1.979898987322333, 2.1, 2.2135943621178655, 2.32163735324878, 2.4248711305964283, 2.5238858928247927, 2.619160170741759, 2.7110883423451915, 2.8000000000000003, 2.8861739379323623, 2.9698484809834995, 3.051229260478472, 3.130495168499706, 3.2078029864690882, 3.283291031876401, 3.357082066318904, 3.4292856398964493, 3.5, 3.5693136595149495, 3.6373066958946425, 3.704051835490427, 3.769615364994153, 3.8340579025361627, 3.8974350539810154, 3.959797974644666, 4.02119385257662, 4.08166632639171, 4.141255848169731, 4.2, 4.257933771208754, 4.315089802078284, 4.371498598878879, 4.427188724235731, 4.4821869662029945, 4.536518488885503, 4.5902069670114, 4.64327470649756, 4.695742752749558, 4.747630988187688, 4.798958220280731, 4.849742261192857, 4.9, 4.949747468305833, 4.998999899979996, 5.047771785649585, 5.096076922496363, 5.143928459844674, 5.191338940966964, 5.238320341483518, 5.2848841046895245, 5.331041174104736, 5.376802023508025, 5.422176684690383, 5.467174773134658, 5.511805511808268, 5.55607775323564, 5.6000000000000005, 5.643580423808984, 5.686826883245172, 5.729746940310715, 5.772347875864725, 5.814636704042653, 5.856620185738529, 5.898304841223451, 5.939696961966999, 5.980802621722272, 6.021627686929839, 6.06217782649107, 6.102458520956944, 6.142475071174486, 6.182232606429493, 6.221736092120913, 6.260990336999412, 6.300000000000001, 6.338769596696192, 6.377303505401009, 6.4156059729381765, 6.4536811201050215, 6.491532946846993, 6.529165337162171, 6.566582063752802, 6.603786792439623, 6.640783086353597, 6.67757440991862, 6.714164132637808, 6.750555532695069, 6.786751800382861, 6.822756041366274, 6.858571279792899, 6.894200461257274, 6.929646455628165, 6.96491205974634, 7.0, 7.034912934784624], [0.0, 0.7071067811865476, 1.0, 1.2247448713915892, 1.4142135623730951, 1.5811388300841898, 1.7320508075688774, 1.8708286933869709, 2.0, 2.1213203435596424, 2.23606797749979, 2.345207879911715, 2.4494897427831783, 2.5495097567963927, 2.6457513110645907, 2.7386127875258306, 2.8284271247461903, 2.9154759474226504, 3.0, 3.082207001484489, 3.1622776601683795, 3.2403703492039306, 3.3166247903554003, 3.3911649915626345, 3.464101615137755, 3.535533905932738, 3.6055512754639896, 3.6742346141747677, 3.7416573867739418, 3.8078865529319548, 3.872983346207417, 3.9370039370059056, 4.0, 4.06201920231798, 4.123105625617661, 4.183300132670378, 4.242640687119285, 4.301162633521314, 4.358898943540674, 4.415880433163924, 4.47213595499958, 4.527692569068709, 4.582575694955841, 4.636809247747852, 4.69041575982343, 4.743416490252569, 4.79583152331272, 4.847679857416329, 4.898979485566357, 4.949747468305833, 5.000000000000001, 5.04975246918104, 5.099019513592785, 5.147815070493501, 5.196152422706632, 5.244044240850759, 5.291502622129181, 5.338539126015656, 5.385164807134505, 5.431390245600108, 5.477225575051661, 5.522680508593631, 5.5677643628300215, 5.612486080160912, 5.656854249492381, 5.70087712549569, 5.744562646538029, 5.787918451395113, 5.830951894845301, 5.873670062235366, 5.916079783099617, 5.958187643906493, 6.0, 6.041522986797286, 6.082762530298219, 6.123724356957946, 6.164414002968978, 6.2048368229954285, 6.244997998398399, 6.284902544988268, 6.324555320336759, 6.3639610306789285, 6.403124237432849, 6.442049363362563, 6.480740698407861, 6.519202405202649, 6.557438524302001, 6.59545297913646, 6.6332495807108005, 6.670832032063167, 6.708203932499369, 6.745368781616021, 6.782329983125269, 6.8190908484929285, 6.855654600401045, 6.892024376045111, 6.92820323027551, 6.9641941385920605, 7.0, 7.035623639735145, 7.071067811865476, 7.1063352017759485], [0.0, 0.7141428428542851, 1.0099504938362078, 1.2369316876852985, 1.4282856857085702, 1.5968719422671316, 1.7492855684535904, 1.8894443627691186, 2.0199009876724157, 2.142428528562855, 2.2583179581272432, 2.368543856465403, 2.473863375370597, 2.574878637916747, 2.672077843177478, 2.765863337187866, 2.8565713714171403, 2.944486372867092, 3.029851481508624, 3.1128764832546767, 3.193743884534263, 3.272613634390715, 3.3496268448888458, 3.4249087579087423, 3.498571136907181, 3.5707142142714257, 3.6414282912066254, 3.7107950630558952, 3.7788887255382373, 3.845776904605883, 3.9115214431215892, 3.9761790704142093, 4.039801975344831, 4.102438299353204, 4.164132562731403, 4.224926034855522, 4.28485705712571, 4.343961325794695, 4.402272140611029, 4.459820624195553, 4.5166359162544865, 4.572745346069471, 4.628174586162455, 4.682947789587239, 4.737087712930806, 4.790615826801393, 4.843552415324934, 4.89591666595746, 4.947726750741194, 4.998999899979996, 5.04975246918104, 5.100000000000001, 5.149757275833494, 5.199038372622384, 5.247856705360771, 5.296225070746145, 5.344155686354956, 5.391660226683429, 5.43874985635486, 5.485435260760991, 5.531726674375732, 5.577633906953737, 5.62316636780382, 5.668333088307356, 5.713142742834281, 5.757603668193913, 5.801723881744115, 5.845511098270194, 5.888972745734184, 5.932115979985557, 5.974947698515863, 6.017474553332154, 6.059702963017248, 6.101639124038721, 6.143289021363068, 6.184658438426491, 6.225752966509353, 6.266578013557321, 6.307138812488593, 6.347440429023341, 6.387487769068526, 6.427285585688566, 6.466838485689898, 6.506150935845249, 6.54522726878143, 6.584071688552609, 6.62268827591938, 6.661080993352356, 6.6992536897776915, 6.73721010508059, 6.77495387438173, 6.81248853210044, 6.8498175158174845, 6.886944169949399, 6.923871749245506, 6.960603422117942, 6.997142273814362, 7.033491309442276, 7.069653456853455, 7.105631569396208, 7.141428428542851, 7.177046746399247], [0.0, 0.7211102550927979, 1.019803902718557, 1.2489995996796799, 1.4422205101855958, 1.61245154965971, 1.7663521732655696, 1.9078784028338915, 2.039607805437114, 2.1633307652783937, 2.280350850198276, 2.3916521486202797, 2.4979991993593598, 2.6000000000000005, 2.6981475126464085, 2.792848008753788, 2.8844410203711917, 2.973213749463701, 3.0594117081556713, 3.1432467291003428, 3.22490309931942, 3.3045423283716615, 3.3823069050575527, 3.458323293158117, 3.532704346531139, 3.6055512754639896, 3.6769552621700474, 3.7469987990390394, 3.815756805667783, 3.88329756778952, 3.9496835316262997, 4.014971979976947, 4.079215610874228, 4.1424630354415966, 4.204759208325728, 4.266145801540309, 4.3266615305567875, 4.386342439892262, 4.445222154178574, 4.503332099679081, 4.560701700396552, 4.617358552246079, 4.67332857821917, 4.728636167014756, 4.7833042972405595, 4.8373546489791295, 4.890807704254994, 4.94368283772331, 4.9959983987187195, 5.047771785649585, 5.099019513592785, 5.149757275833494, 5.200000000000001, 5.249761899362676, 5.299056519796709, 5.347896782848376, 5.396295025292817, 5.44426303552648, 5.491812087098393, 5.5389529696504916, 5.585696017507576, 5.63205113613149, 5.678027826631356, 5.723635208501674, 5.768882040742383, 5.813776741499453, 5.858327406350725, 5.902541825349482, 5.946427498927402, 5.989991652748776, 6.033241251599343, 6.076183012385325, 6.118823416311343, 6.161168720299745, 6.203224967708329, 6.244997998398398, 6.2864934582006855, 6.327716807822551, 6.3686733312362644, 6.409368143584826, 6.44980619863884, 6.489992295835181, 6.529931086925804, 6.569627082262737, 6.609084656743323, 6.648308055437865, 6.687301398920196, 6.726068688320096, 6.764613810115105, 6.802940540677979, 6.841052550594828, 6.878953408767936, 6.916646586316234, 6.954135460285485, 6.9914233171794145, 7.0285133563222315, 7.065408693062278, 7.102112361825883, 7.138627319029899, 7.17495644586084, 7.211102550927979, 7.247068372797377], [0.0, 0.7280109889280519, 1.0295630140987002, 1.2609520212918495, 1.4560219778561039, 1.627882059609971, 1.7832554500127011, 1.9261360284258224, 2.0591260281974004, 2.1840329667841556, 2.302172886644268, 2.4145392935299275, 2.521904042583699, 2.624880949681338, 2.7239676943752476, 2.819574435974337, 2.9120439557122078, 3.001666203960727, 3.0886890422961004, 3.1733263305244868, 3.255764119219942, 3.336165463522456, 3.414674215792775, 3.491418050019219, 3.5665109000254023, 3.64005494464026, 3.712142238654118, 3.782856063875548, 3.852272056851645, 3.9204591567825324, 3.9874804074753776, 4.053393639902249, 4.118252056394801, 4.182104733265298, 4.244997055358225, 4.306971093471606, 4.368065933568311, 4.428317965096906, 4.487761134463376, 4.546427168667723, 4.604345773288536, 4.661544808322667, 4.718050444834181, 4.773887304912004, 4.829078587059855, 4.883646178829912, 4.937610758251404, 4.990991885387113, 5.043808085167398, 5.096076922496363, 5.147815070493501, 5.199038372622384, 5.249761899362676, 5.300000000000001, 5.349766350038103, 5.399073994677236, 5.447935388750495, 5.496362433464519, 5.5443665102516455, 5.591958512006326, 5.639148871948674, 5.6859475903318, 5.732364259186606, 5.7784080852774675, 5.8240879114244155, 5.869412236331676, 5.914389233048499, 5.959026766175833, 6.003332407921454, 6.047313453096343, 6.090976933136425, 6.134329629226001, 6.177378084592201, 6.220128616033596, 6.262587324740471, 6.304760106459247, 6.3466526610489735, 6.388270501473776, 6.429618962271405, 6.470703207534712, 6.511528238439884, 6.552098900352467, 6.592419889539805, 6.632495759516172, 6.672330927044912, 6.711929677819935, 6.751296171847301, 6.790434448545985, 6.82934843158555, 6.868041933477111, 6.906518659932804, 6.944782214007867, 6.982836100038438, 7.020683727387242, 7.058328414008519, 7.095773389842717, 7.1330218000508046, 7.170076708097342, 7.206941098690901, 7.243617880589783, 7.28010988928052, 7.31641988953614], [0.0, 0.7348469228349535, 1.0392304845413265, 1.2727922061357857, 1.469693845669907, 1.6431676725154984, 1.8, 1.9442222095223582, 2.078460969082653, 2.2045407685048604, 2.32379000772445, 2.4372115213907883, 2.5455844122715714, 2.6495282598983545, 2.749545416973504, 2.846049894151541, 2.939387691339814, 3.0298514815086235, 3.1176914536239795, 3.203123475609394, 3.286335345030997, 3.3674916480965478, 3.4467375879228173, 3.5242020373412197, 3.6, 3.6742346141747677, 3.7469987990390394, 3.818376618407357, 3.8884444190447165, 3.957271787481876, 4.024922359499621, 4.091454509095757, 4.156921938165306, 4.221374183841087, 4.28485705712571, 4.347413023856832, 4.409081537009721, 4.469899327725402, 4.529900661162451, 4.589117562233507, 4.6475800154489, 4.705316142407437, 4.762352359916264, 4.818713521262703, 4.874423042781577, 4.9295030175464944, 4.983974317750845, 5.037856687124, 5.091168824543143, 5.143928459844674, 5.196152422706632, 5.247856705360771, 5.299056519796709, 5.349766350038103, 5.4, 5.449770637375486, 5.499090833947008, 5.547972602672079, 5.596427431853289, 5.644466316668034, 5.692099788303082, 5.739337940912697, 5.786190456595773, 5.8326666285670745, 5.878775382679628, 5.924525297439449, 5.96992462263972, 6.014981296729027, 6.059702963017247, 6.104096984812742, 6.148170459575759, 6.191930232165088, 6.235382907247959, 6.278534860936905, 6.321392251711643, 6.363961030678928, 6.406246951218788, 6.448255578061404, 6.489992295835182, 6.5314623171231725, 6.572670690061994, 6.613622305514581, 6.654321903845651, 6.694774081326419, 6.7349832961930955, 6.77495387438173, 6.814690014960329, 6.854195795277518, 6.8934751758456345, 6.932532004974806, 6.971370023173351, 7.009992867328754, 7.0484040746824395, 7.0866070866106305, 7.124605252222751, 7.162401831787993, 7.2, 7.237402849088892, 7.274613391789285, 7.3116345641723655, 7.348469228349535, 7.385120175054704], [0.0, 0.7416198487095663, 1.0488088481701516, 1.2845232578665131, 1.4832396974191326, 1.6583123951777001, 1.8165902124584952, 1.9621416870348585, 2.0976176963403033, 2.224859546128699, 2.345207879911715, 2.459674775249769, 2.5690465157330262, 2.673948391424188, 2.7748873851023217, 2.8722813232690143, 2.9664793948382653, 3.0577769702841313, 3.146426544510455, 3.232645975048923, 3.3166247903554003, 3.398529093593286, 3.4785054261852175, 3.5566838487557484, 3.6331804249169903, 3.708099243547832, 3.7815340802378077, 3.853569773599539, 3.924283374069717, 3.993745109543172, 4.06201920231798, 4.129164564412516, 4.1952353926806065, 4.260281680828159, 4.324349662087931, 4.387482193696061, 4.449719092257398, 4.511097427455985, 4.571651780264984, 4.631414470763765, 4.69041575982343, 4.748684028233507, 4.806245936279167, 4.863126566315131, 4.919349550499538, 4.9749371855331, 5.029910535983717, 5.084289527554465, 5.1380930314660525, 5.191338940966964, 5.244044240850759, 5.296225070746145, 5.347896782848376, 5.399073994677236, 5.449770637375486, 5.5, 5.549774770204643, 5.599107071667768, 5.648008498577176, 5.6964901474504455, 5.744562646538029, 5.792236183029832, 5.839520528262573, 5.886425061104576, 5.932958789676531, 5.979130371550699, 6.024948132556827, 6.070420084310475, 6.115553940568263, 6.1603571325045765, 6.2048368229954285, 6.248999919987198, 6.29285308902091, 6.336402764976356, 6.3796551630946325, 6.422616289332565, 6.465291950097846, 6.507687761409578, 6.549809157525127, 6.591661399070799, 6.6332495807108005, 6.674578638386097, 6.715653356152327, 6.756478372643548, 6.797058187186572, 6.837397165588672, 6.87749954561976, 6.917369442208505, 6.957010852370435, 6.996427659884722, 7.035623639735144, 7.074602462329597, 7.113367697511497, 7.15192281837549, 7.1902712048990205, 7.2284161474004796, 7.266360849833981, 7.30410843293006, 7.341661937191061, 7.379024325749307, 7.416198487095664, 7.4531872376856345], [0.0, 0.7483314773547883, 1.058300524425836, 1.2961481396815722, 1.4966629547095767, 1.6733200530681511, 1.833030277982336, 1.9798989873223332, 2.116601048851672, 2.244994432064365, 2.3664319132398464, 2.4819347291981715, 2.5922962793631443, 2.6981475126464085, 2.8, 2.8982753492378874, 2.9933259094191533, 3.0854497241083023, 3.1749015732775088, 3.2619012860600183, 3.3466401061363023, 3.4292856398964493, 3.509985754956849, 3.5888716889852725, 3.666060555964672, 3.7416573867739413, 3.8157568056677826, 3.8884444190447165, 3.9597979746446663, 4.029888335921977, 4.098780306383839, 4.166533331199932, 4.233202097703344, 4.298837052040936, 4.363484845854286, 4.427188724235731, 4.48998886412873, 4.551922670696417, 4.613025037868319, 4.673328578219169, 4.732863826479693, 4.791659420284376, 4.849742261192857, 4.907137658554118, 4.963869458396343, 5.0199601592044525, 5.075431016179809, 5.130302135352264, 5.184592558726289, 5.238320341483518, 5.291502622129181, 5.344155686354956, 5.396295025292817, 5.447935388750495, 5.499090833947008, 5.549774770204643, 5.6, 5.649778756730214, 5.6991227395100035, 5.748043145279965, 5.796550698475775, 5.844655678480983, 5.892367945062493, 5.939696961966999, 5.986651818838307, 6.033241251599342, 6.079473661428265, 6.125357132445422, 6.170899448216605, 6.216108107168021, 6.260990336999411, 6.305553108173778, 6.3498031465550175, 6.393746945258312, 6.437390775772432, 6.48074069840786, 6.523802572120037, 6.566582063752802, 6.609084656743323, 6.6513156593263565, 6.6932802122726045, 6.734983296193095, 6.776429738438967, 6.817624219623724, 6.858571279792899, 6.899275324264136, 6.939740629158989, 6.979971346646059, 7.019971509913698, 7.059745037889116, 7.099295739719539, 7.138627319029899, 7.177743377970545, 7.216647421067487, 7.255342858886822, 7.293833011524187, 7.332121111929344, 7.370210309075312, 7.408103670980854, 7.445804187594514, 7.483314773547883, 7.520638270785267], [0.0, 0.754983443527075, 1.0677078252031311, 1.3076696830622023, 1.50996688705415, 1.6881943016134133, 1.849324200890693, 1.997498435543818, 2.1354156504062622, 2.264950330581225, 2.3874672772626644, 2.503996805109783, 2.6153393661244047, 2.72213151776324, 2.824889378365107, 2.924038303442689, 3.0199337741083, 3.1128764832546763, 3.2031234756093934, 3.290896534380867, 3.3763886032268267, 3.459768778401239, 3.5411862419251547, 3.620773398046335, 3.698648401781386, 3.774917217635375, 3.849675310984032, 3.9230090491866063, 3.994996871087636, 4.065710270051224, 4.135214625627066, 4.20356991139674, 4.2708313008125245, 4.337049688440288, 4.402272140611028, 4.466542286825459, 4.52990066116245, 4.592385001282014, 4.654030511288038, 4.7148700936505135, 4.774934554525329, 4.8342527861087286, 4.892851929090027, 4.950757517794625, 5.007993610219566, 5.064582904840239, 5.120546845796843, 5.175905717843014, 5.230678732248809, 5.2848841046895245, 5.338539126015656, 5.391660226683429, 5.44426303552648, 5.496362433464519, 5.547972602672079, 5.599107071667768, 5.649778756730214, 5.7, 5.749782604586021, 5.799137866959191, 5.848076606885378, 5.8966091951222275, 5.944745579080739, 5.9924953066314535, 6.0398675482166, 6.08687111741328, 6.133514490078261, 6.17980582219215, 6.2257529665093525, 6.271363488110062, 6.316644678941503, 6.361603571427569, 6.406246951218787, 6.450581369148055, 6.494613152451807, 6.5383484153110105, 6.581793068761734, 6.624952830020755, 6.667833231267862, 6.710439627923047, 6.752777206453653, 6.794850991743675, 6.836665854054885, 6.878226515607057, 6.919537556802478, 6.960603422117942, 7.001428425685718, 7.042016756583302, 7.0823724838503095, 7.122499561249548, 7.162401831787993, 7.202083032012336, 7.24154679609267, 7.280796659706959, 7.31983606373804, 7.358668357794092, 7.397296803562772, 7.4357245780085215, 7.473954776421918, 7.5119904153293495, 7.54983443527075, 7.587489703452652], [0.0, 0.7615773105863909, 1.0770329614269007, 1.3190905958272923, 1.5231546211727818, 1.7029386365926404, 1.8654758106177631, 2.0149441679609885, 2.1540659228538015, 2.2847319317591723, 2.4083189157584592, 2.525866188063018, 2.6381811916545845, 2.7459060435491964, 2.8495613697550017, 2.9495762407505253, 3.0463092423455636, 3.1400636936215167, 3.2310988842807027, 3.319638534539567, 3.405877273185281, 3.48998567332303, 3.5721142198983507, 3.6523964735499352, 3.7309516212355263, 3.8078865529319548, 3.8832975677895205, 3.957271787481876, 4.029888335921977, 4.101219330881976, 4.171330722922842, 4.240283009422838, 4.308131845707603, 4.374928570845472, 4.440720662234904, 4.505552130427525, 4.569463863518345, 4.632493928760188, 4.694677837722201, 4.756048780237647, 4.8166378315169185, 4.876474136094644, 4.935585071701227, 4.993996395673509, 5.051732376126036, 5.10881590977792, 5.165268628057984, 5.221110992882646, 5.276362383309169, 5.331041174104736, 5.385164807134505, 5.43874985635486, 5.491812087098393, 5.5443665102516455, 5.596427431853289, 5.648008498577176, 5.6991227395100035, 5.749782604586021, 5.800000000000001, 5.849786320883866, 5.8991524815010505, 5.948108943185221, 5.99666574022598, 6.044832503882966, 6.092618484691127, 6.1400325732035, 6.187083319303208, 6.23377895020348, 6.280127387243033, 6.326136261573885, 6.3718129288295975, 6.417164482853779, 6.462197768561405, 6.5069193939989765, 6.55133574166368, 6.59545297913646, 6.639277069079134, 6.682813778641449, 6.726068688320096, 6.76904720030818, 6.811754546370562, 6.854195795277518, 6.8963758598266685, 6.938299503480662, 6.97997134664606, 7.021395872616784, 7.062577433203831, 7.103520254071217, 7.144228439796701, 7.184705978674423, 7.224956747275378, 7.264984514780469, 7.3047929470998705, 7.3443856107914165, 7.383765976789894, 7.4229374239582535, 7.4619032424710525, 7.5006666370396715, 7.539230729988306, 7.577598564189055, 7.6157731058639095, 7.653757247260983], [0.0, 0.7681145747868608, 1.0862780491200215, 1.3304134695650072, 1.5362291495737217, 1.7175564037317668, 1.8814887722226779, 2.0322401432901573, 2.172556098240043, 2.3043437243605824, 2.4289915602982237, 2.5475478405713994, 2.6608269391300143, 2.7694764848252458, 2.8740215726399825, 2.974894956128703, 3.0724582991474434, 3.167017524422623, 3.2588341473600644, 3.3481338085566414, 3.4351128074635335, 3.5199431813596083, 3.602776706930364, 3.6837480912787726, 3.7629775444453557, 3.840572873934304, 3.916631205513228, 3.9912404086950213, 4.064480286580315, 4.136423575989287, 4.207136793592525, 4.276680956068619, 4.345112196480086, 4.412482294582042, 4.4788391353117385, 4.544227107000705, 4.608687448721165, 4.672258554489466, 4.734976240700686, 4.796873982084583, 4.857983120596447, 4.9183330509431755, 4.9779513858614575, 5.03686410378521, 5.095095681142799, 5.1526692111953, 5.209606511052442, 5.265928218272634, 5.321653878260029, 5.376802023508025, 5.431390245600108, 5.485435260760991, 5.5389529696504916, 5.591958512006326, 5.644466316668034, 5.6964901474504455, 5.748043145279965, 5.799137866959191, 5.849786320883866, 5.8999999999999995, 5.949789912257406, 5.999166608788257, 6.048140210014975, 6.096720429870472, 6.144916598294887, 6.192737682156413, 6.240192304729077, 6.287288763847259, 6.334035048845246, 6.380438856379708, 6.4265076052238514, 6.472248450113762, 6.517668294720129, 6.562773803811921, 6.607571414672716, 6.652067347825035, 6.696267617113283, 6.740178039191546, 6.783804242458652, 6.827151675479314, 6.870225614927067, 6.913031173081747, 6.955573304911681, 6.997856814768361, 7.0398863627192165, 7.0816664705420855, 7.123201527403251, 7.164495795239188, 7.205553413860728, 7.246378405796926, 7.286974680894671, 7.327346040688948, 7.367496182557545, 7.407428703673091, 7.447147104764348, 7.486654793697916, 7.525955088890711, 7.565051222562872, 7.603946343840151, 7.642643521714199, 7.681145747868608, 7.719455939378112], [0.0, 0.7745966692414833, 1.0954451150103321, 1.3416407864998738, 1.5491933384829666, 1.7320508075688772, 1.8973665961010275, 2.0493901531919194, 2.1908902300206643, 2.3237900077244498, 2.449489742783178, 2.569046515733026, 2.6832815729997477, 2.792848008753788, 2.8982753492378874, 2.9999999999999996, 3.098386676965933, 3.1937438845342623, 3.2863353450309964, 3.3763886032268267, 3.4641016151377544, 3.5496478698597693, 3.63318042491699, 3.714835124201342, 3.794733192202055, 3.8729833462074166, 3.9496835316262997, 4.024922359499621, 4.098780306383839, 4.171330722922842, 4.242640687119285, 4.3127717305695645, 4.381780460041329, 4.449719092257398, 4.516635916254486, 4.58257569495584, 4.6475800154488995, 4.711687595755898, 4.774934554525329, 4.8373546489791295, 4.898979485566356, 4.959838707054898, 5.019960159204453, 5.079370039680117, 5.138093031466052, 5.196152422706631, 5.253570214625478, 5.310367218940701, 5.366563145999495, 5.422176684690383, 5.477225575051661, 5.531726674375732, 5.585696017507576, 5.639148871948674, 5.692099788303082, 5.744562646538029, 5.796550698475775, 5.848076606885378, 5.8991524815010505, 5.949789912257406, 5.999999999999999, 6.049793384901669, 6.099180272790762, 6.148170459575758, 6.196773353931866, 6.244997998398397, 6.292853089020909, 6.340346993658943, 6.387487769068525, 6.434283176858164, 6.48074069840786, 6.526867548832287, 6.572670690061993, 6.618156843109718, 6.663332499583071, 6.7082039324993685, 6.752777206453653, 6.797058187186571, 6.841052550594828, 6.884765791223402, 6.928203230275509, 6.97137002317335, 7.014271166700073, 7.056911505750939, 7.099295739719539, 7.1414284285428495, 7.183313998427188, 7.224956747275377, 7.26636084983398, 7.307530362578043, 7.348469228349534, 7.389181280764466, 7.429670248402684, 7.469939758793239, 7.5099933422074345, 7.549834435270749, 7.58946638440411, 7.628892449104261, 7.668115805072325, 7.707139547199078, 7.745966692414833, 7.784600182411426], [0.0, 0.7810249675906654, 1.104536101718726, 1.3527749258468684, 1.5620499351813308, 1.746424919657298, 1.9131126469708992, 2.0663978319771825, 2.209072203437452, 2.3430749027719964, 2.4698178070456938, 2.5903667693977237, 2.705549851693737, 2.816025568065745, 2.9223278392404914, 3.0248966924508345, 3.1240998703626617, 3.2202484376209237, 3.3136083051561784, 3.4044089061098406, 3.492849839314596, 3.5791060336346563, 3.6633318168028404, 3.745664160065609, 3.8262252939417984, 3.9051248379533274, 3.9824615503479754, 4.058324777540605, 4.132795663954365, 4.205948168962618, 4.277849927241487, 4.34856298103178, 4.418144406874904, 4.486646854834912, 4.5541190146942805, 4.620606020859168, 4.686149805543993, 4.750789408087881, 4.814561246884289, 4.87749935930288, 4.9396356140913875, 5.000999900019996, 5.061620293937506, 5.121523210920751, 5.180733538795447, 5.239274758971893, 5.297169055259611, 5.354437412091022, 5.411099703387474, 5.467174773134658, 5.522680508593631, 5.577633906953737, 5.63205113613149, 5.6859475903318, 5.739337940912697, 5.792236183029832, 5.844655678480983, 5.8966091951222275, 5.948108943185221, 5.999166608788257, 6.049793384901669, 6.1, 6.149796744608719, 6.199193495931548, 6.248199740725323, 6.296824596572465, 6.345076831686122, 6.392964883369843, 6.440496875241847, 6.487680633323437, 6.534523701081817, 6.5810333535091585, 6.627216610312357, 6.673080248281149, 6.71863081289633, 6.7638746292343415, 6.808817812219681, 6.853466276272176, 6.897825744392215, 6.941901756723442, 6.985699678629192, 7.029224708315989, 7.07248188403477, 7.115476090888086, 7.158212067269313, 7.200694410957877, 7.242927584892728, 7.284915922644544, 7.326663633605681, 7.368174807915458, 7.409453421137082, 7.450503338701353, 7.491328320131218, 7.531932023060219, 7.572318007057021, 7.6124897372673015, 7.652450587883597, 7.692203845452876, 7.731752712031082, 7.771100308193172, 7.810249675906655, 7.849203781276163], [0.0, 0.787400787401181, 1.1135528725660042, 1.3638181696985856, 1.574801574802362, 1.760681686165901, 1.928730152198591, 2.083266665599966, 2.2271057451320084, 2.362202362203543, 2.4899799195977463, 2.6115129714401193, 2.727636339397171, 2.839013913315678, 2.9461839725312466, 3.049590136395381, 3.149603149604724, 3.246536616149585, 3.340658617698013, 3.432200460346103, 3.521363372331802, 3.608323710533743, 3.6932370625238775, 3.7762415176998414, 3.857460304397182, 3.9370039370059056, 4.014971979976946, 4.091454509095756, 4.166533331199932, 4.240283009422838, 4.3127717305695645, 4.384062043356595, 4.454211490264017, 4.523273151159457, 4.591296113299598, 4.658325879540846, 4.724404724407086, 4.789572005931219, 4.853864439804639, 4.917316341257699, 4.979959839195493, 5.041825066382213, 5.10294032886923, 5.163332257370234, 5.223025942880239, 5.282045058497702, 5.340411969127476, 5.3981478305063115, 5.455272678794342, 5.511805511808268, 5.5677643628300215, 5.62316636780382, 5.678027826631356, 5.732364259186606, 5.786190456595773, 5.839520528262573, 5.892367945062493, 5.944745579080739, 5.99666574022598, 6.048140210014975, 6.099180272790762, 6.149796744608719, 6.199999999999999, 6.249799996799897, 6.299206299209448, 6.348228099241551, 6.39687423668779, 6.445153217728807, 6.49307323229917, 6.540642170307133, 6.587867636800241, 6.6347569661593475, 6.681317235396026, 6.727555276621664, 6.773477688750439, 6.819090848492928, 6.864400920692206, 6.90941386804988, 6.954135460285484, 6.998571282769077, 7.042726744663604, 7.08660708661063, 7.130217387990355, 7.173562573784381, 7.216647421067486, 7.259476565152615, 7.302054505411474, 7.344385610791416, 7.386474125047755, 7.428324171709255, 7.469939758793239, 7.511324783285569, 7.552483035399683, 7.593418202627852, 7.634133873596926, 7.674633541739956, 7.714920608794364, 7.754998388136519, 7.79487010796203, 7.834538914320357, 7.874007874011811, 7.913279977354524], [0.0, 0.7937253933193772, 1.1224972160321824, 1.3747727084867523, 1.5874507866387544, 1.7748239349298849, 1.9442222095223582, 2.1, 2.244994432064365, 2.3811761799581315, 2.5099800796022267, 2.632489316217637, 2.7495454169735045, 2.861817604250837, 2.9698484809834995, 3.074085229787879, 3.1749015732775088, 3.2726136343907144, 3.3674916480965473, 3.4597687784012394, 3.5496478698597698, 3.6373066958946425, 3.722902093797257, 3.8065732621348563, 3.8884444190447165, 3.968626966596886, 4.047221268969613, 4.124318125460256, 4.2, 4.274342054632503, 4.347413023856832, 4.419275958796871, 4.48998886412873, 4.559605246071199, 4.628174586162454, 4.695742752749559, 4.762352359916263, 4.828043081829325, 4.892851929090027, 4.956813492557492, 5.019960159204453, 5.082322303829225, 5.143928459844674, 5.204805471869242, 5.264978632435274, 5.324471804789654, 5.383307533477908, 5.441507144165117, 5.499090833947009, 5.55607775323564, 5.612486080160912, 5.668333088307356, 5.723635208501674, 5.7784080852774675, 5.8326666285670745, 5.886425061104576, 5.939696961966999, 5.9924953066314535, 6.044832503882966, 6.096720429870472, 6.148170459575758, 6.199193495931548, 6.249799996799897, 6.3, 6.3498031465550175, 6.3992187023104625, 6.448255578061403, 6.496922348312315, 6.545227268781429, 6.593178292750774, 6.640783086353597, 6.688049042882386, 6.734983296193095, 6.7815927332743895, 6.827884006044625, 6.87386354243376, 6.919537556802479, 6.96491205974634, 7.009992867328754, 7.0547856097829085, 7.0992957397195395, 7.143528539874395, 7.187489130426565, 7.23118247591637, 7.274613391789285, 7.317786550590281, 7.3607064878311785, 7.40337760755184, 7.445804187594514, 7.487990384609211, 7.52994023880668, 7.571657678474378, 7.6131465242697125, 7.654410493303845, 7.695453203028396, 7.736278174936576, 7.776888838089433, 7.817288532477231, 7.857480512225277, 7.897467948652911, 7.937253933193772, 7.976841480185], [0.0, 0.8, 1.131370849898476, 1.385640646055102, 1.6, 1.788854381999832, 1.9595917942265426, 2.1166010488516727, 2.262741699796952, 2.4, 2.5298221281347035, 2.65329983228432, 2.771281292110204, 2.8844410203711917, 2.9933259094191533, 3.098386676965933, 3.2, 3.2984845004941286, 3.394112549695428, 3.4871191548325395, 3.577708763999664, 3.6660605559646724, 3.752332607858744, 3.836665218650176, 3.9191835884530852, 4.0, 4.079215610874228, 4.156921938165306, 4.233202097703345, 4.308131845707604, 4.381780460041329, 4.454211490264018, 4.525483399593904, 4.595650117230424, 4.664761515876241, 4.732863826479693, 4.8, 4.866210024238576, 4.931531202375181, 4.9959983987187195, 5.059644256269407, 5.122499389946279, 5.184592558726289, 5.2459508194416005, 5.30659966456864, 5.366563145999495, 5.4258639865002145, 5.4845236803208355, 5.542562584220408, 5.6000000000000005, 5.656854249492381, 5.713142742834281, 5.768882040742383, 5.8240879114244155, 5.878775382679628, 5.932958789676531, 5.986651818838307, 6.0398675482166, 6.092618484691127, 6.144916598294887, 6.196773353931866, 6.248199740725323, 6.299206299209448, 6.3498031465550175, 6.4, 6.449806198638839, 6.499230723708768, 6.5482822174979605, 6.596969000988257, 6.64529909033446, 6.6932802122726045, 6.740919818541087, 6.788225099390856, 6.835202996254025, 6.881860213634101, 6.92820323027551, 6.974238309665079, 7.019971509913698, 7.065408693062278, 7.110555533852471, 7.155417527999328, 7.2, 7.244308110509934, 7.288346863315439, 7.332121111929345, 7.37563556583431, 7.418894796396564, 7.4619032424710525, 7.504665215717488, 7.547184905645283, 7.58946638440411, 7.631513611335565, 7.673330437300352, 7.7149206087943645, 7.756287771866127, 7.797435475847171, 7.8383671769061705, 7.879086241436885, 7.919595949289333, 7.959899496852961, 8.0, 8.039900496896713], [0.0, 0.8062257748298549, 1.1401754250991378, 1.3964240043768943, 1.6124515496597098, 1.8027756377319946, 1.9748417658131499, 2.133072900770154, 2.2803508501982757, 2.4186773244895647, 2.5495097567963922, 2.6739483914241875, 2.7928480087537886, 2.9068883707497264, 3.016620625799671, 3.1224989991991987, 3.2249030993194197, 3.324154027718932, 3.420526275297414, 3.5142566781611158, 3.605551275463989, 3.6945906403822333, 3.7815340802378072, 3.866522985836241, 3.9496835316262997, 4.031128874149275, 4.110960958218893, 4.189272013130682, 4.266145801540308, 4.341658669218482, 4.415880433163923, 4.488875137492688, 4.560701700396551, 4.631414470763764, 4.701063709417263, 4.769696007084728, 4.8373546489791295, 4.904079934095691, 4.969909455915671, 5.034878350069642, 5.0990195135927845, 5.162363799656123, 5.224940191045253, 5.28677595515452, 5.347896782848375, 5.4083269131959835, 5.468089245796926, 5.527205442174191, 5.585696017507577, 5.643580423808984, 5.70087712549569, 5.757603668193913, 5.813776741499453, 5.869412236331676, 5.924525297439449, 5.979130371550699, 6.033241251599342, 6.08687111741328, 6.1400325732035, 6.192737682156413, 6.244997998398397, 6.296824596572465, 6.348228099241551, 6.3992187023104625, 6.449806198638839, 6.499999999999999, 6.549809157525125, 6.599242380758566, 6.648308055437864, 6.697014260101287, 6.745368781616021, 6.793379129711516, 6.841052550594828, 6.888396039717809, 6.93541635375988, 6.98212002188447, 7.0285133563222315, 7.074602462329597, 7.12039324756716, 7.165891430938652, 7.211102550927978, 7.256031973468694, 7.300684899377592, 7.345066371381541, 7.389181280764467, 7.433034373659253, 7.476630257007497, 7.519973404208288, 7.5630681604756145, 7.6059187479225665, 7.648529270389177, 7.6909037180295, 7.733045971672482, 7.774959806970066, 7.816648898345122, 7.858116822750854, 7.899367063252599, 7.940403012442127, 7.981227975693965, 8.021845174272563, 8.06225774829855, 8.10246875958186], [0.0, 0.812403840463596, 1.1489125293076057, 1.4071247279470291, 1.624807680927192, 1.8165902124584952, 1.98997487421324, 2.149418526020468, 2.2978250586152114, 2.437211521390788, 2.569046515733026, 2.6944387170614963, 2.8142494558940583, 2.9291637031753623, 3.0397368307141326, 3.1464265445104544, 3.249615361854384, 3.3496268448888453, 3.4467375879228173, 3.541186241925155, 3.6331804249169903, 3.722902093797257, 3.81051177665153, 3.8961519477556315, 3.97994974842648, 4.06201920231798, 4.142463035441596, 4.221374183841087, 4.298837052040936, 4.374928570845472, 4.449719092257397, 4.523273151159456, 4.595650117230423, 4.666904755831214, 4.737087712930805, 4.806245936279166, 4.874423042781576, 4.941659640242335, 5.007993610219566, 5.073460357586329, 5.138093031466052, 5.201922721455982, 5.264978632435274, 5.3272882407468805, 5.388877434122993, 5.449770637375485, 5.509990925582365, 5.569560126257728, 5.628498911788117, 5.686826883245172, 5.744562646538029, 5.801723881744115, 5.858327406350725, 5.914389233048499, 5.96992462263972, 6.024948132556827, 6.079473661428265, 6.133514490078261, 6.187083319303208, 6.240192304729077, 6.292853089020909, 6.345076831686122, 6.39687423668779, 6.448255578061403, 6.499230723708768, 6.549809157525125, 6.6, 6.649812027418519, 6.699253689777691, 6.748333127521196, 6.797058187186572, 6.8454364360499325, 6.8934751758456345, 6.941181455631311, 6.988562083862459, 7.035623639735144, 7.08237248385031, 7.128814768248646, 7.17495644586084, 7.2208032794142785, 7.266360849833981, 7.311634564172365, 7.356629663099809, 7.401351227985333, 7.445804187594514, 7.489993324429602, 7.533923280734945, 7.577598564189054, 7.62102355330306, 7.664202502543888, 7.707139547199077, 7.749838707999025, 7.792303895511263, 7.834538914320357, 7.8765474670060875, 7.918333157931661, 7.95989949685296, 8.001249902359007, 8.04238770515324, 8.083316151184489, 8.12403840463596, 8.16455755078008], [0.0, 0.8185352771872451, 1.1575836902790224, 1.4177446878757827, 1.6370705543744901, 1.8303005217723127, 2.004993765576342, 2.1656407827707715, 2.315167380558045, 2.455605831561735, 2.588435821108957, 2.714774392099646, 2.8354893757515653, 2.951270912674741, 3.062678566222711, 3.1701734968294715, 3.2741411087489802, 3.374907406137241, 3.4727510708370675, 3.567912554982255, 3.6606010435446255, 3.7509998667022106, 3.8392707640904935, 3.9255572852781047, 4.009987531152684, 4.092676385936225, 4.173727350941841, 4.253234063627348, 4.331281565541543, 4.407947368106838, 4.483302354291978, 4.557411546042337, 4.63033476111609, 4.702127178203499, 4.77283982551269, 4.8425200051213, 4.91121166312347, 4.978955713801841, 5.045790324617146, 5.111751167652823, 5.176871642217914, 5.241183072551464, 5.304714883949938, 5.367494760127856, 5.429548784199292, 5.490901565316937, 5.551576352712804, 5.61159513863928, 5.670978751503131, 5.729746940310715, 5.787918451395113, 5.845511098270194, 5.902541825349482, 5.959026766175833, 6.014981296729027, 6.070420084310475, 6.125357132445422, 6.17980582219215, 6.23377895020348, 6.287288763847259, 6.340346993658943, 6.392964883369843, 6.445153217728807, 6.496922348312315, 6.5482822174979605, 6.599242380758566, 6.649812027418519, 6.7, 6.749814812274482, 6.79926466612383, 6.848357467305573, 6.897100840208152, 6.945502141674135, 6.993568473962345, 7.041306696913577, 7.088723439378913, 7.13582510996451, 7.182617907142214, 7.229107828771128, 7.275300681071539, 7.321202087089251, 7.366817494685205, 7.4121521840825695, 7.457211275000863, 7.501999733404421, 7.546522377890362, 7.590783885739338, 7.634788798650556, 7.678541528180987, 7.722046360907191, 7.76530746332687, 7.808328886515987, 7.851114570556209, 7.893668348746355, 7.935993951610599, 7.978095010715276, 8.019975062305368, 8.061637550770936, 8.103085831953157, 8.144323176298936, 8.18535277187245, 8.226177727231525], [0.0, 0.8246211251235321, 1.16619037896906, 1.4282856857085702, 1.6492422502470643, 1.8439088914585775, 2.0199009876724157, 2.181742422927143, 2.33238075793812, 2.473863375370596, 2.6076809620810595, 2.734958866235469, 2.8565713714171403, 2.973213749463701, 3.0854497241083023, 3.1937438845342623, 3.2984845004941286, 3.4, 3.4985711369071804, 3.594440151122286, 3.687817782917155, 3.778888725538237, 3.867815921162743, 3.954743986657038, 4.039801975344831, 4.123105625617661, 4.204759208325728, 4.28485705712571, 4.363484845854286, 4.440720662234904, 4.516635916254486, 4.591296113299599, 4.66476151587624, 4.737087712930805, 4.8083261120685235, 4.878524367060187, 4.947726750741192, 5.015974481593781, 5.083306010855534, 5.149757275833494, 5.215361924162119, 5.280151512977635, 5.344155686354956, 5.407402333838309, 5.469917732470938, 5.531726674375732, 5.592852581643825, 5.653317610041028, 5.713142742834281, 5.772347875864725, 5.830951894845301, 5.888972745734184, 5.946427498927402, 6.003332407921454, 6.059702963017247, 6.115553940568263, 6.170899448216605, 6.2257529665093525, 6.280127387243033, 6.334035048845246, 6.387487769068525, 6.440496875241847, 6.49307323229917, 6.545227268781429, 6.596969000988257, 6.648308055437864, 6.699253689777691, 6.749814812274482, 6.8, 6.849817515817484, 6.899275324264137, 6.948381106416083, 6.997142273814361, 7.045565981523414, 7.093659140387279, 7.14142842854285, 7.188880302244572, 7.236021006050217, 7.282856582413251, 7.329392880723478, 7.37563556583431, 7.42159012611179, 7.467261881037788, 7.512655988397179, 7.557777451076474, 7.602631123499285, 7.647221717722065, 7.691553809211764, 7.735631842325486, 7.779460135510689, 7.8230428862431785, 7.866384175718855, 7.909487973314076, 7.952358140828418, 7.994998436522675, 8.037412518964047, 8.079603950689663, 8.121576201698781, 8.16333265278342, 8.204876598706406, 8.246211251235321, 8.287339742040265], [0.0, 0.8306623862918076, 1.174734012447073, 1.4387494569938162, 1.661324772583615, 1.8574175621006712, 2.0346989949375804, 2.1977260975835913, 2.349468024894146, 2.4919871588754225, 2.6267851073127395, 2.7549954627911823, 2.8774989139876324, 2.994995826374388, 3.1080540535840107, 3.217141588429082, 3.32264954516723, 3.424908757908742, 3.5242020373412193, 3.6207733980463352, 3.7148351242013424, 3.8065732621348563, 3.8961519477556315, 3.9837168574084183, 4.069397989875161, 4.153311931459037, 4.235563716909475, 4.316248370981448, 4.3954521951671826, 4.473253849269009, 4.54972526643093, 4.624932431938872, 4.698936049788292, 4.77179211617606, 4.843552415324934, 4.914264950122246, 4.983974317750845, 5.052722038663912, 5.120546845796843, 5.187484939737176, 5.253570214625479, 5.3188344587888805, 5.383307533477909, 5.447017532558529, 5.509990925582365, 5.572252686302012, 5.63382640840131, 5.69473440996154, 5.754997827975265, 5.814636704042653, 5.873670062235366, 5.932115979985557, 5.989991652748776, 6.047313453096343, 6.104096984812742, 6.1603571325045765, 6.216108107168021, 6.271363488110062, 6.326136261573885, 6.380438856379708, 6.434283176858164, 6.487680633323437, 6.540642170307133, 6.593178292750774, 6.64529909033446, 6.697014260101287, 6.748333127521196, 6.79926466612383, 6.849817515817484, 6.9, 6.949820141557622, 6.999285677838847, 7.048404074682439, 7.097182539571601, 7.145628033979938, 7.19374728496908, 7.2415467960926705, 7.289032857656769, 7.336211556382492, 7.383088784512889, 7.429670248402685, 7.475961476626268, 7.521967827636597, 7.567694497005016, 7.6131465242697125, 7.658328799418317, 7.703246069028303, 7.747902942086975, 7.792303895511263, 7.836453279386026, 7.880355321938218, 7.924014134263013, 7.967433714816837, 8.010617953691215, 8.053570636680355, 8.096295449154509, 8.138795979750322, 8.18107572388864, 8.223138087129511, 8.264986388373547, 8.306623862918075, 8.34805366537614], [0.0, 0.8366600265340756, 1.1832159566199232, 1.4491376746189442, 1.6733200530681511, 1.8708286933869709, 2.04939015319192, 2.2135943621178655, 2.3664319132398464, 2.5099800796022267, 2.6457513110645907, 2.774887385102322, 2.8982753492378883, 3.0166206257996717, 3.1304951684997055, 3.24037034920393, 3.3466401061363023, 3.4496376621320683, 3.5496478698597698, 3.6469165057620945, 3.7416573867739418, 3.834057902536163, 3.924283374069717, 4.012480529547776, 4.09878030638384, 4.183300132670378, 4.266145801540309, 4.3474130238568325, 4.427188724235731, 4.505552130427525, 4.58257569495584, 4.658325879540847, 4.732863826479693, 4.806245936279167, 4.878524367060187, 4.949747468305833, 5.019960159204453, 5.089204259999789, 5.157518783291051, 5.2249401910452535, 5.291502622129181, 5.35723809439155, 5.422176684690385, 5.486346689738081, 5.549774770204644, 5.612486080160912, 5.674504383644443, 5.735852159879995, 5.796550698475777, 5.856620185738529, 5.916079783099617, 5.974947698515863, 6.033241251599343, 6.090976933136425, 6.148170459575759, 6.2048368229954285, 6.260990336999411, 6.316644678941503, 6.3718129288295975, 6.4265076052238514, 6.48074069840786, 6.534523701081817, 6.587867636800241, 6.640783086353597, 6.6932802122726045, 6.745368781616021, 6.797058187186572, 6.848357467305573, 6.899275324264137, 6.949820141557622, 7.000000000000001, 7.049822692805827, 7.0992957397195395, 7.148426400264607, 7.197221686178633, 7.24568837309472, 7.293833011524189, 7.341661937191062, 7.3891812807644675, 7.436396977031284, 7.4833147735478835, 7.529940238806681, 7.576278769950325, 7.622335600063802, 7.668115805072326, 7.713624310270757, 7.75886589650833, 7.803845206050669, 7.848566748139434, 7.893034904268446, 7.937253933193772, 7.981227975693966, 8.024961059095553, 8.068457101577724, 8.1117199162693, 8.154753215150045, 8.19756061276768, 8.240145629781066, 8.282511696339462, 8.324662155306966, 8.366600265340756, 8.408329203831164], [0.0, 0.8426149773176359, 1.1916375287812984, 1.4594519519326425, 1.6852299546352718, 1.8841443681416774, 2.0639767440550294, 2.2293496809607953, 2.3832750575625967, 2.5278449319529073, 2.6645825188948455, 2.7946377224964243, 2.918903903865285, 3.0380915061926625, 3.152776554086889, 3.2634337744161437, 3.3704599092705436, 3.4741905532080417, 3.5749125863438955, 3.672873534441392, 3.768288736283355, 3.861346915261565, 3.952214569073901, 4.041039470235351, 4.127953488110059, 4.2130748865881795, 4.296510211788167, 4.378355855797928, 4.458699361921591, 4.537620521815371, 4.61519230368573, 4.69148164229596, 4.766550115125193, 4.8404545241123795, 4.913247398615299, 4.984977432245807, 5.0556898639058145, 5.1254268114957995, 5.194227565288221, 5.262128846769148, 5.329165037789691, 5.395368384086485, 5.46076917659042, 5.525395913416522, 5.589275444992849, 5.652433104425031, 5.71489282489182, 5.776677245614472, 5.83780780773057, 5.898304841223451, 5.958187643906493, 6.017474553332154, 6.076183012385325, 6.134329629226001, 6.191930232165088, 6.248999919987198, 6.305553108173778, 6.361603571427569, 6.417164482853779, 6.472248450113762, 6.526867548832287, 6.5810333535091585, 6.6347569661593475, 6.688049042882386, 6.740919818541087, 6.793379129711516, 6.8454364360499325, 6.897100840208152, 6.948381106416083, 6.999285677838847, 7.049822692805827, 7.1, 7.149825172687791, 7.199305522062527, 7.248448109768049, 7.297259759663212, 7.345747068882784, 7.3939164182454755, 7.441773982055624, 7.489325737341113, 7.53657747256671, 7.583534795858723, 7.630203142774117, 7.676587783644501, 7.72269383052313, 7.768526243760782, 7.814089838234521, 7.859389289251424, 7.904429138147802, 7.949213797602879, 7.993747556684537, 8.038034585643434, 8.082078940470701, 8.125884567233282, 8.16945530620004, 8.212794895770866, 8.255906976220118, 8.298795093265047, 8.341462701469089, 8.383913167489272, 8.426149773176359, 8.468175718535841], [0.0, 0.848528137423857, 1.2, 1.4696938456699071, 1.697056274847714, 1.8973665961010278, 2.078460969082653, 2.244994432064365, 2.4, 2.545584412271571, 2.6832815729997477, 2.814249455894058, 2.9393876913398143, 3.0594117081556713, 3.1749015732775088, 3.2863353450309964, 3.394112549695428, 3.4985711369071804, 3.6, 3.6986484017813863, 3.7947331922020555, 3.8884444190447165, 3.97994974842648, 4.069397989875161, 4.156921938165306, 4.242640687119286, 4.3266615305567875, 4.409081537009721, 4.48998886412873, 4.5694638635183455, 4.6475800154489, 4.724404724407087, 4.8, 4.874423042781577, 4.947726750741193, 5.019960159204453, 5.091168824543142, 5.1613951602255765, 5.230678732248808, 5.299056519796709, 5.366563145999495, 5.43323108288245, 5.499090833947008, 5.564171097297422, 5.628498911788116, 5.692099788303082, 5.754997827975264, 5.817215828899595, 5.8787753826796285, 5.939696961966999, 6.0, 6.059702963017248, 6.118823416311343, 6.177378084592201, 6.235382907247959, 6.29285308902091, 6.3498031465550175, 6.406246951218787, 6.462197768561405, 6.517668294720129, 6.572670690061993, 6.627216610312357, 6.681317235396026, 6.734983296193095, 6.788225099390856, 6.841052550594828, 6.8934751758456345, 6.945502141674135, 6.997142273814361, 7.048404074682439, 7.0992957397195395, 7.149825172687791, 7.2, 7.249827584156743, 7.299315036357863, 7.3484692283495345, 7.397296803562773, 7.445804187594514, 7.493997598078079, 7.541883053985921, 7.589466384404111, 7.636753236814713, 7.68374908491942, 7.730459236035075, 7.776888838089433, 7.823042886243179, 7.868926229162401, 7.914543574963752, 7.95989949685296, 8.0049984384758, 8.049844718999243, 8.094442537939225, 8.138795979750322, 8.182909018191515, 8.226785520481254, 8.270429251254132, 8.313843876330612, 8.357032966310472, 8.4, 8.442748367682174, 8.485281374238571, 8.527602242131138], [0.0, 0.8544003745317531, 1.2083045973594573, 1.4798648586948744, 1.7088007490635062, 1.91049731745428, 2.092844953645635, 2.260530911091463, 2.4166091947189146, 2.563201123595259, 2.701851217221259, 2.833725463060951, 2.9597297173897488, 3.0805843601498726, 3.196873472629156, 3.309078421554859, 3.4176014981270124, 3.522782990761707, 3.6249137920783716, 3.7242448899072147, 3.82099463490856, 3.915354390090379, 4.007492981902776, 4.097560249709576, 4.18568990729127, 4.272001872658766, 4.356604182158393, 4.439594576084623, 4.521061822182926, 4.601086828130937, 4.679743582719036, 4.757099956906519, 4.833218389437829, 4.908156476723211, 4.98196748283246, 5.054700782440045, 5.126402247190518, 5.197114584074513, 5.266877632905477, 5.335728628781641, 5.403702434442518, 5.470831746635972, 5.537147279962851, 5.602677931132575, 5.667450926121902, 5.731491952362839, 5.794825277780168, 5.857473858242988, 5.9194594347794975, 5.980802621722272, 6.041522986797286, 6.101639124038721, 6.161168720299745, 6.220128616033596, 6.278534860936905, 6.336402764976356, 6.393746945258312, 6.450581369148055, 6.5069193939989765, 6.562773803811921, 6.618156843109718, 6.673080248281149, 6.727555276621664, 6.7815927332743895, 6.835202996254025, 6.888396039717809, 6.941181455631311, 6.993568473962345, 7.045565981523414, 7.097182539571601, 7.148426400264607, 7.199305522062527, 7.249827584156743, 7.3, 7.349829930005183, 7.399324293474371, 7.448489779814429, 7.4973328590906245, 7.545859791965394, 7.594076639065476, 7.64198926981712, 7.689603370785778, 7.736924453553881, 7.783957862167549, 7.830708780180758, 7.877182237323192, 7.923383115816122, 7.969316156358713, 8.014985963805552, 8.060397012554654, 8.105553651663778, 8.150460109711599, 8.195120499419152, 8.239538822045807, 8.283718971573094, 8.327664738688751, 8.37137981458254, 8.414867794564572, 8.4581321815162, 8.501176389182852, 8.544003745317532, 8.586617494683225], [0.0, 0.8602325267042626, 1.2165525060596438, 1.489966442575134, 1.7204650534085253, 1.9235384061671346, 2.1071307505705477, 2.2759613353482084, 2.4331050121192876, 2.580697580112788, 2.7202941017470885, 2.8530685235374214, 2.979932885150268, 3.1016124838541645, 3.218695387886216, 3.3316662497915357, 3.4409301068170506, 3.5468295701936396, 3.6496575181789317, 3.749666651850535, 3.847076812334269, 3.9420806688854046, 4.034848200366403, 4.125530268947254, 4.214261501141095, 4.301162633521313, 4.386342439892262, 4.469899327725402, 4.551922670696417, 4.632493928760188, 4.711687595755898, 4.789572005931219, 4.866210024238575, 4.941659640242335, 5.015974481593781, 5.089204259999788, 5.161395160225576, 5.232590180780452, 5.302829433425141, 5.372150407425317, 5.440588203494177, 5.508175741568165, 5.574943945906542, 5.6409219104681805, 5.706137047074843, 5.770615218501403, 5.834380858325929, 5.897457079114692, 5.959865770300536, 6.021627686929839, 6.082762530298219, 6.143289021363068, 6.203224967708329, 6.262587324740471, 6.321392251711643, 6.3796551630946325, 6.437390775772432, 6.494613152451807, 6.55133574166368, 6.607571414672716, 6.663332499583071, 6.71863081289633, 6.773477688750439, 6.827884006044625, 6.881860213634101, 6.93541635375988, 6.988562083862459, 7.041306696913577, 7.093659140387279, 7.145628033979938, 7.197221686178633, 7.248448109768049, 7.299315036357863, 7.349829930005183, 7.3999999999999995, 7.44983221287567, 7.49933330370107, 7.548509786706248, 7.597367965289032, 7.645913941446111, 7.694153624668538, 7.742092740338364, 7.789736837660179, 7.837091297158659, 7.884161337770809, 7.930952023559341, 7.977468270071652, 8.023714850367003, 8.069696400732806, 8.115417426109392, 8.160882305241266, 8.206095295571457, 8.251060537894508, 8.295782060782456, 8.340263784797218, 8.384509526501832, 8.42852300228219, 8.472307831990054, 8.515867542417507, 8.559205570612264, 8.602325267042627, 8.645229898620395], [0.0, 0.8660254037844387, 1.224744871391589, 1.5000000000000002, 1.7320508075688774, 1.9364916731037085, 2.121320343559643, 2.29128784747792, 2.449489742783178, 2.598076211353316, 2.7386127875258306, 2.8722813232690148, 3.0000000000000004, 3.122498999199199, 3.24037034920393, 3.3541019662496843, 3.464101615137755, 3.570714214271425, 3.6742346141747673, 3.7749172176353754, 3.872983346207417, 3.968626966596886, 4.06201920231798, 4.153311931459037, 4.242640687119286, 4.330127018922194, 4.415880433163924, 4.5, 4.58257569495584, 4.663689526544408, 4.743416490252569, 4.8218253804964775, 4.898979485566356, 4.974937185533101, 5.049752469181039, 5.123475382979799, 5.196152422706632, 5.26782687642637, 5.338539126015656, 5.408326913195984, 5.477225575051661, 5.545268253204709, 5.612486080160912, 5.678908345800274, 5.7445626465380295, 5.809475019311125, 5.873670062235366, 5.937171043518958, 6.000000000000001, 6.06217782649107, 6.123724356957946, 6.184658438426491, 6.244997998398398, 6.304760106459247, 6.363961030678928, 6.422616289332565, 6.48074069840786, 6.5383484153110105, 6.59545297913646, 6.652067347825035, 6.7082039324993685, 6.7638746292343415, 6.819090848492928, 6.87386354243376, 6.92820323027551, 6.98212002188447, 7.035623639735144, 7.088723439378913, 7.14142842854285, 7.19374728496908, 7.24568837309472, 7.297259759663212, 7.3484692283495345, 7.399324293474371, 7.44983221287567, 7.5, 7.549834435270751, 7.599342076785332, 7.6485292703891785, 7.697402159170327, 7.745966692414834, 7.794228634059948, 7.842193570679062, 7.88986691902975, 7.937253933193772, 7.984359711335657, 8.031189202104505, 8.077747210701757, 8.12403840463596, 8.170067319184096, 8.215838362577491, 8.261355820929154, 8.306623862918075, 8.351646544245034, 8.396427811873334, 8.440971508067065, 8.485281374238571, 8.529361054615991, 8.573214099741124, 8.616843969807043, 8.660254037844387, 8.703447592764606], [0.0, 0.8717797887081349, 1.2328828005937953, 1.5099668870541503, 1.7435595774162698, 1.9493588689617931, 2.1354156504062627, 2.3065125189341593, 2.4657656011875906, 2.615339366124404, 2.7568097504180447, 2.8913664589601926, 3.0199337741083006, 3.1432467291003428, 3.2619012860600183, 3.3763886032268267, 3.4871191548325395, 3.594440151122286, 3.6986484017813863, 3.8000000000000007, 3.8987177379235862, 3.9949968710876362, 4.0890096600521755, 4.180908992073375, 4.270831300812525, 4.358898943540674, 4.445222154178575, 4.529900661162451, 4.613025037868319, 4.694677837722201, 4.774934554525329, 4.8538644398046396, 4.931531202375181, 5.007993610219566, 5.083306010855535, 5.157518783291051, 5.230678732248808, 5.302829433425142, 5.374011537017762, 5.444263035526481, 5.513619500836089, 5.582114294781146, 5.649778756730215, 5.716642371182581, 5.782732917920385, 5.848076606885378, 5.912698199637794, 5.976621118993575, 6.039867548216601, 6.102458520956944, 6.164414002968978, 6.225752966509353, 6.2864934582006855, 6.3466526610489735, 6.406246951218788, 6.465291950097846, 6.523802572120037, 6.581793068761734, 6.639277069079134, 6.696267617113283, 6.752777206453653, 6.808817812219681, 6.864400920692206, 6.919537556802479, 6.974238309665079, 7.0285133563222315, 7.08237248385031, 7.13582510996451, 7.188880302244572, 7.2415467960926705, 7.293833011524189, 7.345747068882784, 7.397296803562773, 7.448489779814429, 7.49933330370107, 7.549834435270751, 7.600000000000001, 7.649836599562112, 7.6993506219680645, 7.748548251124208, 7.7974354758471724, 7.8460180983732135, 7.894301742396222, 7.942291860665913, 7.9899937421752725, 8.037412518964048, 8.084553172563096, 8.13142054010245, 8.178019320104351, 8.224354077980836, 8.270429251254134, 8.316249154516717, 8.36181798414675, 8.407139822793482, 8.452218643646177, 8.497058314499201, 8.54166260162505, 8.586035173466273, 8.630179604156568, 8.674099376880578, 8.717797887081348, 8.761278445523805], [0.0, 0.8774964387392122, 1.2409673645990857, 1.5198684153570665, 1.7549928774784245, 1.9621416870348585, 2.149418526020468, 2.32163735324878, 2.4819347291981715, 2.6324893162176366, 2.7748873851023217, 2.91032644217105, 3.039736830714133, 3.1638584039112754, 3.283291031876401, 3.3985290935932855, 3.509985754956849, 3.6180105030251086, 3.722902093797257, 3.824918299781056, 3.924283374069717, 4.02119385257662, 4.115823125451336, 4.2083250825001635, 4.298837052040936, 4.387482193696061, 4.474371464239419, 4.559605246071199, 4.64327470649756, 4.725462940284264, 4.806245936279166, 4.8856934001224435, 4.963869458396343, 5.040833264451424, 5.1166395221864125, 5.191338940966964, 5.264978632435273, 5.3376024580330075, 5.409251334519409, 5.479963503528103, 5.549774770204643, 5.61871871515206, 5.686826883245173, 5.754128952326321, 5.8206528843421, 5.886425061104575, 5.951470406546605, 6.015812497078014, 6.079473661428266, 6.142475071174486, 6.2048368229954285, 6.266578013557321, 6.327716807822551, 6.388270501473776, 6.448255578061404, 6.507687761409578, 6.566582063752802, 6.624952830020755, 6.682813778641449, 6.740178039191546, 6.797058187186571, 6.853466276272176, 6.90941386804988, 6.96491205974634, 7.019971509913698, 7.074602462329597, 7.128814768248646, 7.182617907142214, 7.236021006050217, 7.289032857656769, 7.341661937191062, 7.3939164182454755, 7.445804187594514, 7.4973328590906245, 7.548509786706248, 7.599342076785332, 7.649836599562112, 7.7, 7.749838707999026, 7.799358948016177, 7.848566748139434, 7.897467948652911, 7.9460682101275735, 7.994373021069257, 8.04238770515324, 8.090117428072352, 8.137567204023572, 8.184741901856162, 8.231646250902672, 8.278284846512591, 8.324662155306966, 8.370782520170978, 8.416650165000327, 8.462269199216012, 8.507643622061282, 8.55277732669336, 8.597674104081872, 8.64233764672499, 8.6867715521936, 8.73097932651315, 8.774964387392123, 8.81873006730561], [0.0, 0.8831760866327848, 1.2489995996796797, 1.5297058540778359, 1.7663521732655696, 1.9748417658131503, 2.1633307652783937, 2.336664289109585, 2.4979991993593593, 2.6495282598983545, 2.7928480087537886, 2.9291637031753623, 3.0594117081556718, 3.1843366656181322, 3.3045423283716615, 3.420526275297414, 3.532704346531139, 3.6414282912066254, 3.7469987990390394, 3.8496753109840323, 3.9496835316263006, 4.047221268969613, 4.1424630354415966, 4.235563716909475, 4.3266615305567875, 4.415880433163924, 4.503332099679082, 4.589117562233508, 4.67332857821917, 4.756048780237647, 4.83735464897913, 4.917316341257699, 4.995998398718719, 5.07346035758633, 5.149757275833494, 5.2249401910452535, 5.299056519796709, 5.372150407425318, 5.444263035526481, 5.515432893255072, 5.585696017507577, 5.655086206239478, 5.723635208501675, 5.791372894228104, 5.858327406350725, 5.92452529743945, 5.989991652748776, 6.054750201288242, 6.1188234163113435, 6.182232606429493, 6.244997998398399, 6.307138812488593, 6.3686733312362644, 6.429618962271405, 6.489992295835182, 6.549809157525127, 6.609084656743323, 6.667833231267862, 6.726068688320096, 6.783804242458652, 6.841052550594828, 6.897825744392215, 6.954135460285484, 7.009992867328754, 7.065408693062278, 7.12039324756716, 7.17495644586084, 7.229107828771128, 7.282856582413251, 7.336211556382492, 7.3891812807644675, 7.441773982055624, 7.493997598078079, 7.545859791965394, 7.597367965289032, 7.6485292703891785, 7.6993506219680645, 7.749838707999026, 7.800000000000002, 7.849840762716147, 7.899367063252601, 7.9485847796950635, 7.997499609252884, 8.046117075956577, 8.094442537939226, 8.142481194328914, 8.19023809177731, 8.23771813064759, 8.284926070883193, 8.33186653757728, 8.378544026261366, 8.424962907930219, 8.47112743381895, 8.517041739947036, 8.56270985144306, 8.608135686662937, 8.653323061113575, 8.698275691193055, 8.742997197757758, 8.787491109526087, 8.831760866327848, 8.875809822207776], [0.0, 0.8888194417315589, 1.2569805089976536, 1.5394804318340656, 1.7776388834631178, 1.9874606914351793, 2.177154105707724, 2.3515952032609695, 2.513961017995307, 2.6664583251946765, 2.8106938645110393, 2.9478805945967355, 3.078960863668131, 3.204684071792413, 3.3256578296631782, 3.442382895611701, 3.5552777669262356, 3.664696440361739, 3.7709415269929605, 3.874274125562104, 3.9749213828703587, 4.07308237088326, 4.168932717135166, 4.262628297189424, 4.354308211415448, 4.444097208657795, 4.532107677449864, 4.618441295502196, 4.703190406521939, 4.786439177509728, 4.868264577855234, 4.948737212663449, 5.027922035990614, 5.105878964487898, 5.182663407939976, 5.2583267300539625, 5.332916650389353, 5.406477596365309, 5.47905101272109, 5.550675634551168, 5.621387729022079, 5.691221310052879, 5.760208329565868, 5.8283788483591215, 5.895761189193471, 5.962382074305537, 6.028266749240615, 6.09343909463285, 6.157921727336262, 6.221736092120913, 6.284902544988268, 6.347440429023341, 6.409368143584826, 6.470703207534712, 6.5314623171231725, 6.591661399070799, 6.6513156593263565, 6.710439627923047, 6.76904720030818, 6.827151675479314, 6.884765791223402, 6.941901756723442, 6.998571282769077, 7.0547856097829085, 7.110555533852471, 7.165891430938652, 7.2208032794142785, 7.275300681071539, 7.329392880723478, 7.383088784512889, 7.436396977031284, 7.489325737341113, 7.541883053985921, 7.594076639065476, 7.645913941446111, 7.697402159170327, 7.748548251124208, 7.799358948016177, 7.849840762716147, 7.9, 7.949842765740717, 7.999374975584031, 8.048602363143555, 8.097530487747484, 8.14616474176652, 8.194510357550353, 8.242572413997951, 8.290355842785038, 8.337865434270332, 8.385105843100611, 8.432081593533118, 8.478797084492587, 8.525256594378847, 8.571464285639882, 8.61742420912421, 8.663140308225419, 8.708616422830897, 8.753856293085923, 8.798863562983575, 8.843641783790206, 8.88819441731559, 8.932524839036274], [0.0, 0.894427190999916, 1.2649110640673518, 1.549193338482967, 1.788854381999832, 2.0000000000000004, 2.1908902300206647, 2.366431913239847, 2.5298221281347035, 2.6832815729997477, 2.8284271247461903, 2.9664793948382657, 3.098386676965934, 3.22490309931942, 3.3466401061363023, 3.4641016151377544, 3.577708763999664, 3.687817782917155, 3.7947331922020555, 3.8987177379235862, 4.000000000000001, 4.09878030638384, 4.1952353926806065, 4.289522117905444, 4.3817804600413295, 4.47213595499958, 4.560701700396552, 4.647580015448901, 4.732863826479694, 4.8166378315169185, 4.898979485566357, 4.979959839195494, 5.059644256269407, 5.1380930314660525, 5.21536192416212, 5.291502622129181, 5.366563145999495, 5.440588203494178, 5.513619500836089, 5.585696017507577, 5.656854249492381, 5.727128425310542, 5.796550698475777, 5.865151319446072, 5.9329587896765315, 6.0, 6.066300355241241, 6.131883886702357, 6.196773353931868, 6.260990336999412, 6.324555320336759, 6.387487769068526, 6.44980619863884, 6.511528238439884, 6.572670690061994, 6.6332495807108005, 6.6932802122726045, 6.752777206453653, 6.811754546370562, 6.870225614927067, 6.928203230275509, 6.985699678629192, 7.042726744663604, 7.0992957397195395, 7.155417527999328, 7.211102550927978, 7.266360849833981, 7.321202087089251, 7.37563556583431, 7.429670248402685, 7.4833147735478835, 7.53657747256671, 7.589466384404111, 7.64198926981712, 7.694153624668538, 7.745966692414834, 7.7974354758471724, 7.848566748139434, 7.899367063252601, 7.949842765740717, 8.000000000000002, 8.049844718999244, 8.099382692526635, 8.148619514985345, 8.19756061276768, 8.246211251235321, 8.29457654133109, 8.342661445845685, 8.390470785361213, 8.438009243891594, 8.485281374238571, 8.532291603080617, 8.579044235810889, 8.62554346113913, 8.671793355471522, 8.717797887081348, 8.763560920082659, 8.809086218218098, 8.854377448471462, 8.899438184514796, 8.94427190999916, 8.988882021697695], [0.0, 0.9, 1.2727922061357855, 1.5588457268119897, 1.8, 2.012461179749811, 2.2045407685048604, 2.3811761799581315, 2.545584412271571, 2.7, 2.8460498941515415, 2.9849623113198605, 3.1176914536239795, 3.2449961479175906, 3.3674916480965473, 3.485685011586675, 3.6, 3.710795063055895, 3.8183766184073566, 3.9230090491866068, 4.024922359499622, 4.124318125460256, 4.221374183841087, 4.316248370981448, 4.409081537009721, 4.500000000000001, 4.589117562233507, 4.676537180435969, 4.762352359916263, 4.846648326421054, 4.929503017546495, 5.01098792654702, 5.091168824543142, 5.170106381884226, 5.247856705360771, 5.324471804789654, 5.4, 5.474486277268398, 5.547972602672079, 5.620498198558559, 5.692099788303083, 5.762811813689565, 5.832666628567075, 5.9016946718718, 5.969924622639721, 6.037383539249432, 6.104096984812742, 6.17008914036094, 6.235382907247959, 6.300000000000001, 6.3639610306789285, 6.427285585688566, 6.489992295835181, 6.552098900352467, 6.613622305514581, 6.674578638386097, 6.734983296193095, 6.794850991743675, 6.854195795277518, 6.913031173081747, 6.97137002317335, 7.029224708315989, 7.08660708661063, 7.143528539874395, 7.2, 7.256031973468694, 7.311634564172365, 7.366817494685205, 7.42159012611179, 7.475961476626268, 7.529940238806681, 7.583534795858723, 7.636753236814713, 7.689603370785778, 7.742092740338364, 7.794228634059948, 7.8460180983732135, 7.897467948652911, 7.9485847796950635, 7.999374975584031, 8.049844718999244, 8.100000000000001, 8.149846624323676, 8.19939022122987, 8.248636250920512, 8.2975900115636, 8.346256645946134, 8.394641147779934, 8.442748367682174, 8.490583018850943, 8.538149682454625, 8.58545281275251, 8.632496741962896, 8.67928568489366, 8.725823743349393, 8.772114910328067, 8.818163074019441, 8.863972021616496, 8.909545442950499, 8.95488693395958, 9.000000000000002, 9.044888059008803], [0.0, 0.9055385138137417, 1.2806248474865698, 1.5684387141358125, 1.8110770276274835, 2.024845673131659, 2.2181073012818837, 2.395829710142188, 2.5612496949731396, 2.716615541441225, 2.863564212655271, 3.003331483536242, 3.136877428271625, 3.264965543462902, 3.3882148692194836, 3.5071355833500366, 3.622154055254967, 3.733630940518894, 3.84187454245971, 3.947150871198111, 4.049691346263318, 4.149698784249287, 4.247352116319061, 4.342810150121694, 4.436214602563767, 4.527692569068709, 4.617358552246079, 4.705316142407438, 4.791659420284376, 4.876474136094644, 4.959838707054898, 5.041825066382213, 5.122499389946279, 5.201922721455982, 5.280151512977635, 5.35723809439155, 5.43323108288245, 5.508175741568166, 5.582114294781146, 5.655086206239478, 5.727128425310542, 5.798275605729691, 5.868560300448485, 5.938013135721409, 6.006662967072484, 6.074537019394977, 6.1416610131136355, 6.208059278067503, 6.27375485654325, 6.338769596696192, 6.403124237432849, 6.466838485689898, 6.529931086925804, 6.592419889539805, 6.654321903845651, 6.715653356152327, 6.776429738438967, 6.836665854054885, 6.8963758598266685, 6.955573304911681, 7.014271166700073, 7.07248188403477, 7.130217387990355, 7.187489130426565, 7.244308110509934, 7.300684899377592, 7.356629663099809, 7.4121521840825695, 7.467261881037788, 7.521967827636597, 7.576278769950325, 7.630203142774117, 7.68374908491942, 7.736924453553881, 7.789736837660179, 7.842193570679062, 7.894301742396222, 7.9460682101275735, 7.997499609252884, 8.048602363143555, 8.099382692526635, 8.149846624323676, 8.200000000000001, 8.249848483457136, 8.299397568498573, 8.348652585896723, 8.397618710086808, 8.446300965511472, 8.494704232638123, 8.542833253669418, 8.590692637965812, 8.638286867197687, 8.685620300243388, 8.732697177848321, 8.77952162705919, 8.826097665446492, 8.872429205127535, 8.918520056601322, 8.964373932405989, 9.009994450608726, 9.055385138137417, 9.100549433962767], [0.0, 0.9110433579144299, 1.2884098726725124, 1.5779733838059502, 1.8220867158288598, 2.0371548787463363, 2.2315913604421396, 2.41039415863879, 2.576819745345025, 2.7331300737432893, 2.8809720581775866, 3.0215889859476257, 3.1559467676119004, 3.2848135411313684, 3.408812109811862, 3.5284557528754696, 3.6441734316577197, 3.7563279941985894, 3.8652296180175374, 3.9711459303329564, 4.0743097574926725, 4.174925149029621, 4.273172123844299, 4.369210454990696, 4.463182720884279, 4.55521678957215, 4.645427859734774, 4.73392015141785, 4.82078831727758, 4.906118628814432, 4.9899899799498595, 5.072474741188959, 5.15363949069005, 5.23354564325181, 5.31224999411737, 5.389805191284746, 5.466260147486579, 5.541660400998964, 5.616048432839589, 5.68946394662977, 5.761944116355173, 5.833523806414096, 5.904235767650205, 5.974110812497538, 6.043177971895251, 6.111464636239008, 6.178996682310163, 6.245798587850876, 6.311893535223801, 6.377303505401009, 6.442049363362563, 6.506150935845249, 6.569627082262737, 6.632495759516172, 6.694774081326419, 6.756478372643548, 6.817624219623724, 6.878226515607057, 6.938299503480662, 6.997856814768361, 7.056911505750939, 7.115476090888086, 7.173562573784381, 7.23118247591637, 7.288346863315439, 7.345066371381541, 7.401351227985333, 7.457211275000863, 7.512655988397179, 7.567694497005016, 7.622335600063802, 7.676587783644501, 7.730459236035075, 7.783957862167549, 7.837091297158659, 7.88986691902975, 7.942291860665913, 7.994373021069257, 8.046117075956577, 8.097530487747484, 8.148619514985345, 8.19939022122987, 8.249848483457136, 8.299999999999999, 8.349850298059241, 8.399404740813482, 8.44866853415377, 8.49764673306675, 8.546344247688598, 8.594765849050223, 8.64291617453276, 8.690799733051039, 8.738420909981391, 8.78578397184907, 8.832893070789435, 8.879752248796134, 8.926365441768558, 8.972736483370054, 9.018869108707587, 9.064766957842878, 9.1104335791443, 9.155872432488342], [0.0, 0.9165151389911681, 1.2961481396815722, 1.5874507866387546, 1.8330302779823362, 2.04939015319192, 2.244994432064365, 2.4248711305964283, 2.5922962793631443, 2.749545416973504, 2.898275349237888, 3.039736830714133, 3.174901573277509, 3.3045423283716615, 3.4292856398964493, 3.5496478698597693, 3.6660605559646724, 3.778888725538237, 3.8884444190447165, 3.9949968710876362, 4.09878030638384, 4.2, 4.298837052040936, 4.3954521951671826, 4.48998886412873, 4.582575694955841, 4.67332857821917, 4.762352359916264, 4.849742261192857, 4.935585071701227, 5.019960159204453, 5.10294032886923, 5.184592558726289, 5.264978632435274, 5.344155686354956, 5.422176684690384, 5.499090833947008, 5.574943945906542, 5.649778756730214, 5.723635208501674, 5.796550698475776, 5.868560300448484, 5.939696961967, 6.009991680526688, 6.079473661428266, 6.148170459575759, 6.216108107168022, 6.2833112289620034, 6.349803146555018, 6.4156059729381765, 6.480740698407861, 6.54522726878143, 6.609084656743323, 6.672330927044912, 6.7349832961930955, 6.797058187186572, 6.858571279792899, 6.919537556802478, 6.97997134664606, 7.0398863627192165, 7.099295739719539, 7.158212067269313, 7.216647421067486, 7.274613391789285, 7.332121111929345, 7.389181280764467, 7.445804187594514, 7.501999733404421, 7.557777451076474, 7.6131465242697125, 7.668115805072326, 7.72269383052313, 7.776888838089433, 7.830708780180758, 7.884161337770809, 7.937253933193772, 7.9899937421752725, 8.04238770515324, 8.094442537939226, 8.14616474176652, 8.19756061276768, 8.248636250920512, 8.299397568498573, 8.349850298059241, 8.4, 8.449852069711044, 8.499411744350311, 8.548684109265006, 8.597674104081872, 8.646386528486914, 8.694826047713663, 8.742997197757758, 8.790904390334365, 8.838551917593742, 8.885943956609225, 8.933084573650918, 8.97997772825746, 9.026627277117408, 9.073036977771006, 9.119210492142399, 9.165151389911681, 9.210863151735564], [0.0, 0.9219544457292888, 1.3038404810405297, 1.5968719422671316, 1.8439088914585775, 2.0615528128088303, 2.2583179581272432, 2.4392621835300936, 2.6076809620810595, 2.765863337187866, 2.9154759474226504, 3.0577769702841313, 3.193743884534263, 3.3241540277189325, 3.449637662132068, 3.5707142142714248, 3.687817782917155, 3.8013155617496426, 3.9115214431215897, 4.018706259482024, 4.123105625617661, 4.224926034855522, 4.324349662087931, 4.421538193886829, 4.5166359162544865, 4.609772228646444, 4.701063709417264, 4.790615826801394, 4.878524367060187, 4.964876634922565, 5.049752469181039, 5.13322510708424, 5.215361924162119, 5.296225070746145, 5.375872022286245, 5.454356057317858, 5.531726674375732, 5.608029957123981, 5.68330889535313, 5.757603668193913, 5.830951894845301, 5.903388857258177, 5.974947698515863, 6.0456596000767355, 6.115553940568263, 6.18465843842649, 6.252999280345393, 6.320601237224193, 6.387487769068526, 6.4536811201050215, 6.519202405202649, 6.584071688552609, 6.648308055437865, 6.711929677819935, 6.77495387438173, 6.837397165588672, 6.899275324264136, 6.960603422117942, 7.021395872616784, 7.0816664705420855, 7.1414284285428495, 7.200694410957877, 7.259476565152615, 7.317786550590281, 7.37563556583431, 7.433034373659253, 7.489993324429602, 7.546522377890362, 7.602631123499285, 7.658328799418317, 7.713624310270757, 7.768526243760782, 7.823042886243179, 7.877182237323192, 7.930952023559341, 7.984359711335657, 8.037412518964048, 8.090117428072352, 8.142481194328914, 8.194510357550353, 8.246211251235321, 8.2975900115636, 8.348652585896723, 8.399404740813482, 8.449852069711044, 8.5, 8.549853799919623, 8.599418584997478, 8.648699324175862, 8.697700845625814, 8.746427842267952, 8.794884877018005, 8.843076387773658, 8.891006692158093, 8.938679992034618, 8.986100377805714, 9.033271832508973, 9.080198235721511, 9.126883367283709, 9.173330910852394, 9.219544457292889, 9.265527507918803], [0.0, 0.9273618495495705, 1.3114877048604001, 1.6062378404209012, 1.854723699099141, 2.0736441353327724, 2.2715633383201097, 2.4535688292770597, 2.6229754097208002, 2.7820855486487113, 2.932575659723036, 3.07571129984594, 3.2124756808418025, 3.343650699460098, 3.4698703145794947, 3.591656999213594, 3.709447398198282, 3.8236108588610325, 3.9344631145812006, 4.042276586281548, 4.147288270665545, 4.249705872175156, 4.349712634186309, 4.447471191587417, 4.543126676640219, 4.636809247747852, 4.7286361670147565, 4.818713521262704, 4.907137658554119, 4.993996395673509, 5.079370039680118, 5.163332257370235, 5.2459508194416005, 5.327288240746882, 5.40740233383831, 5.486346689738081, 5.5641710972974225, 5.640921910468182, 5.716642371182581, 5.791372894228104, 5.865151319446072, 5.93801313572141, 6.009991680526689, 6.081118318204308, 6.15142259969188, 6.220932405998316, 6.289674077406556, 6.357672530100934, 6.424951361683605, 6.491532946846993, 6.557438524302001, 6.62268827591938, 6.687301398920196, 6.751296171847301, 6.814690014960329, 6.87749954561976, 6.939740629158989, 7.001428425685718, 7.062577433203831, 7.123201527403251, 7.183313998427188, 7.242927584892728, 7.302054505411474, 7.3607064878311785, 7.418894796396564, 7.476630257007497, 7.533923280734945, 7.590783885739338, 7.647221717722065, 7.703246069028303, 7.75886589650833, 7.814089838234521, 7.868926229162401, 7.923383115816122, 7.977468270071652, 8.031189202104505, 8.084553172563096, 8.137567204023572, 8.19023809177731, 8.242572413997951, 8.29457654133109, 8.346256645946134, 8.397618710086808, 8.44866853415377, 8.499411744350311, 8.549853799919623, 8.600000000000001, 8.649855490122365, 8.699425268372618, 8.748714191239761, 8.79772697916911, 8.84646822183859, 8.894942383174834, 8.943153806124549, 8.99110671719561, 9.038805230781334, 9.086253353280439, 9.133454987024352, 9.180413934022802, 9.22713389953782, 9.273618495495704, 9.319871243745807], [0.0, 0.9327379053088816, 1.3190905958272918, 1.6155494421403516, 1.8654758106177631, 2.0856653614614213, 2.2847319317591728, 2.4677925358506134, 2.6381811916545836, 2.7982137159266447, 2.9495762407505253, 3.093541659651604, 3.231098884280703, 3.363034344160048, 3.4899856733230297, 3.6124783736376886, 3.7309516212355263, 3.845776904605882, 3.957271787481876, 4.065710270051225, 4.171330722922843, 4.274342054632503, 4.374928570845472, 4.473253849269009, 4.5694638635183455, 4.663689526544408, 4.756048780237647, 4.846648326421054, 4.935585071701227, 5.022947341949744, 5.10881590977792, 5.193264869039514, 5.276362383309167, 5.358171329847526, 5.4387498563548595, 5.518151864528558, 5.596427431853289, 5.673623181001714, 5.749782604586021, 5.8249463516842805, 5.8991524815010505, 5.9724366886556455, 6.044832503882966, 6.1163714733492105, 6.187083319303208, 6.256996084384263, 6.326136261573884, 6.394528911499267, 6.462197768561406, 6.529165337162171, 6.59545297913646, 6.661080993352356, 6.726068688320096, 6.790434448545985, 6.854195795277518, 6.917369442208505, 6.979971346646059, 7.042016756583302, 7.103520254071217, 7.164495795239188, 7.224956747275377, 7.284915922644544, 7.344385610791416, 7.40337760755184, 7.4619032424710525, 7.519973404208288, 7.577598564189054, 7.634788798650556, 7.691553809211764, 7.747902942086975, 7.803845206050669, 7.859389289251424, 7.914543574963752, 7.969316156358713, 8.023714850367003, 8.077747210701757, 8.13142054010245, 8.184741901856162, 8.23771813064759, 8.290355842785038, 8.342661445845685, 8.394641147779934, 8.446300965511472, 8.49764673306675, 8.548684109265006, 8.599418584997478, 8.649855490122365, 8.700000000000001, 8.749857141690944, 8.799431799837988, 8.848728722251575, 8.897752525216692, 8.946507698538017, 8.994998610338971, 9.043229511629129, 9.091204540653564, 9.138927727036691, 9.186402995732335, 9.233634170791044, 9.280624978954814, 9.327379053088816, 9.373899935459095], [0.0, 0.938083151964686, 1.3266499161421599, 1.6248076809271923, 1.876166303929372, 2.0976176963403033, 2.297825058615212, 2.4819347291981715, 2.6532998322843198, 2.814249455894058, 2.9664793948382653, 3.1112698372208096, 3.2496153618543846, 3.3823069050575527, 3.509985754956849, 3.63318042491699, 3.752332607858744, 3.867815921162743, 3.97994974842648, 4.0890096600521755, 4.1952353926806065, 4.298837052040936, 4.4, 4.498888751680798, 4.595650117230424, 4.69041575982343, 4.7833042972405595, 4.874423042781577, 4.963869458396343, 5.0517323761260355, 5.138093031466052, 5.223025942880239, 5.3065996645686395, 5.388877434122993, 5.469917732470938, 5.549774770204643, 5.628498911788116, 5.706137047074843, 5.782732917920384, 5.858327406350725, 5.932958789676531, 6.006662967072483, 6.079473661428266, 6.151422599691879, 6.222539674441619, 6.292853089020909, 6.362389488234747, 6.431174076325411, 6.499230723708769, 6.566582063752802, 6.6332495807108005, 6.6992536897776915, 6.764613810115105, 6.82934843158555, 6.8934751758456345, 6.957010852370435, 7.019971509913698, 7.0823724838503095, 7.144228439796701, 7.205553413860728, 7.26636084983398, 7.326663633605681, 7.386474125047755, 7.445804187594514, 7.504665215717488, 7.5630681604756145, 7.62102355330306, 7.678541528180987, 7.735631842325486, 7.792303895511263, 7.848566748139434, 7.904429138147802, 7.95989949685296, 8.014985963805552, 8.069696400732806, 8.12403840463596, 8.178019320104351, 8.231646250902672, 8.284926070883193, 8.337865434270332, 8.390470785361213, 8.442748367682174, 8.494704232638123, 8.546344247688598, 8.597674104081872, 8.648699324175862, 8.699425268372618, 8.749857141690944, 8.8, 8.849858755935035, 8.899438184514796, 8.948742928478838, 8.997777503361595, 9.046546302318914, 9.09505360072166, 9.143303560529969, 9.191300234460847, 9.23904756996088, 9.28654941299512, 9.333809511662428, 9.38083151964686, 9.427618999514142], [0.0, 0.9433981132056604, 1.3341664064126333, 1.6340134638368193, 1.8867962264113207, 2.1095023109728985, 2.3108440016582685, 2.495996794869737, 2.6683328128252666, 2.830194339616981, 2.9832867780352594, 3.1288975694324033, 3.2680269276736387, 3.4014702703389896, 3.529872518944558, 3.6537651812890215, 3.7735924528226414, 3.8897300677553446, 4.0024992192379, 4.112177038990418, 4.219004621945797, 4.323193264243457, 4.424929377967517, 4.524378410345448, 4.621688003316537, 4.716990566028302, 4.810405388322278, 4.902040391510457, 4.991993589739474, 5.0803543183522155, 5.167204273105525, 5.252618394667558, 5.336665625650533, 5.419409561935692, 5.500909015790026, 5.58121850495033, 5.660388679233962, 5.7384666941614295, 5.815496539419485, 5.8915193286621745, 5.966573556070519, 6.040695324215583, 6.113918547053109, 6.186275131288617, 6.2577951388648065, 6.328506932918695, 6.398437309218556, 6.4676116148080505, 6.536053855347277, 6.603786792439623, 6.670832032063167, 6.73721010508059, 6.802940540677979, 6.868041933477111, 6.932532004974806, 6.996427659884722, 7.059745037889116, 7.122499561249548, 7.184705978674423, 7.246378405796926, 7.307530362578043, 7.368174807915458, 7.428324171709255, 7.487990384609211, 7.547184905645283, 7.6059187479225665, 7.664202502543888, 7.722046360907191, 7.779460135510689, 7.836453279386026, 7.893034904268446, 7.949213797602879, 8.0049984384758, 8.060397012554654, 8.115417426109392, 8.170067319184096, 8.224354077980836, 8.278284846512591, 8.33186653757728, 8.385105843100611, 8.438009243891594, 8.490583018850943, 8.542833253669418, 8.594765849050223, 8.646386528486914, 8.697700845625814, 8.748714191239761, 8.799431799837988, 8.849858755935035, 8.899999999999999, 8.949860334105779, 8.99944442729661, 9.048756820690896, 9.097801932335084, 9.1465840618233, 9.195107394696377, 9.243376006633074, 9.291393867445294, 9.339164844888433, 9.38669270829721, 9.433981132056603, 9.481033698917013], [0.0, 0.9486832980505138, 1.3416407864998738, 1.6431676725154984, 1.8973665961010275, 2.121320343559643, 2.32379000772445, 2.5099800796022267, 2.6832815729997477, 2.846049894151541, 3.0, 3.146426544510455, 3.286335345030997, 3.420526275297414, 3.5496478698597693, 3.674234614174767, 3.794733192202055, 3.9115214431215892, 4.024922359499621, 4.135214625627067, 4.242640687119286, 4.347413023856832, 4.449719092257398, 4.549725266430931, 4.6475800154489, 4.743416490252569, 4.83735464897913, 4.929503017546495, 5.019960159204453, 5.10881590977792, 5.196152422706632, 5.282045058497703, 5.366563145999495, 5.449770637375486, 5.531726674375733, 5.612486080160912, 5.692099788303082, 5.770615218501404, 5.848076606885378, 5.92452529743945, 6.0, 6.074537019394977, 6.148170459575759, 6.220932405998315, 6.29285308902091, 6.363961030678928, 6.434283176858165, 6.5038450166036395, 6.572670690061994, 6.640783086353597, 6.708203932499369, 6.77495387438173, 6.841052550594828, 6.906518659932804, 6.971370023173351, 7.035623639735144, 7.099295739719539, 7.162401831787993, 7.224956747275378, 7.286974680894671, 7.348469228349534, 7.409453421137082, 7.469939758793239, 7.52994023880668, 7.58946638440411, 7.648529270389177, 7.707139547199077, 7.76530746332687, 7.8230428862431785, 7.880355321938218, 7.937253933193772, 7.993747556684537, 8.049844718999243, 8.105553651663778, 8.160882305241266, 8.215838362577491, 8.270429251254134, 8.324662155306966, 8.378544026261366, 8.432081593533118, 8.485281374238571, 8.538149682454625, 8.590692637965812, 8.64291617453276, 8.694826047713663, 8.746427842267952, 8.79772697916911, 8.848728722251575, 8.899438184514796, 8.949860334105779, 9.0, 9.049861877399014, 9.099450532861862, 9.148770409186145, 9.197825830053535, 9.246621004453464, 9.2951600308978, 9.343446901438464, 9.391485505499116, 9.439279633531365, 9.486832980505138, 9.534149149242424], [0.0, 0.9539392014169457, 1.349073756323204, 1.6522711641858308, 1.9078784028338913, 2.1330729007701543, 2.3366642891095846, 2.5238858928247927, 2.698147512646408, 2.8618176042508368, 3.0166206257996713, 3.1638584039112754, 3.3045423283716615, 3.439476704383968, 3.5693136595149495, 3.694590640382233, 3.8157568056677826, 3.9331920878594273, 4.047221268969612, 4.158124577258358, 4.266145801540309, 4.371498598878879, 4.474371464239419, 4.57493169347915, 4.673328578219169, 4.769696007084729, 4.864154602806124, 4.956813492557492, 5.047771785649585, 5.137119815616529, 5.224940191045253, 5.3113086899558, 5.396295025292816, 5.479963503528103, 5.562373594069352, 5.643580423808984, 5.7236352085016735, 5.8025856305616035, 5.880476171195663, 5.957348403442593, 6.0332412515993425, 6.1081912216301815, 6.182232606429493, 6.255397669213365, 6.327716807822551, 6.399218702310462, 6.469930447848725, 6.539877674696982, 6.609084656743323, 6.67757440991862, 6.745368781616021, 6.81248853210044, 6.878953408767936, 6.944782214007867, 7.009992867328754, 7.074602462329597, 7.138627319029899, 7.202083032012336, 7.264984514780469, 7.327346040688948, 7.389181280764466, 7.450503338701353, 7.511324783285569, 7.571657678474378, 7.631513611335565, 7.6909037180295, 7.749838707999025, 7.808328886515987, 7.866384175718855, 7.924014134263013, 7.981227975693966, 8.038034585643434, 8.094442537939225, 8.150460109711599, 8.206095295571457, 8.261355820929154, 8.316249154516717, 8.370782520170978, 8.424962907930219, 8.478797084492587, 8.532291603080617, 8.58545281275251, 8.638286867197687, 8.690799733051039, 8.742997197757758, 8.794884877018005, 8.84646822183859, 8.897752525216692, 8.948742928478838, 8.99944442729661, 9.049861877399014, 9.1, 9.1498633869583, 9.199456505685541, 9.248783703817493, 9.297849213662264, 9.346657156438338, 9.395211546314432, 9.443516294262428, 9.491575211733826, 9.539392014169458, 9.586970324351693], [0.0, 0.959166304662544, 1.3564659966250536, 1.6613247725836153, 1.918332609325088, 2.144761058952722, 2.349468024894146, 2.5377155080899043, 2.7129319932501073, 2.877498913987632, 3.0331501776206204, 3.1811947441173736, 3.3226495451672307, 3.458323293158117, 3.5888716889852725, 3.714835124201342, 3.836665218650176, 3.954743986657038, 4.069397989875161, 4.180908992073375, 4.289522117905444, 4.3954521951671826, 4.498888751680798, 4.6000000000000005, 4.698936049788292, 4.79583152331272, 4.8908077042549944, 4.983974317750846, 5.075431016179809, 5.165268628057984, 5.253570214625479, 5.340411969127476, 5.4258639865002145, 5.509990925582366, 5.592852581643825, 5.674504383644443, 5.754997827975264, 5.83438085832593, 5.912698199637794, 5.989991652748776, 6.066300355241241, 6.1416610131136355, 6.216108107168022, 6.289674077406555, 6.362389488234747, 6.434283176858165, 6.505382386916238, 6.575712889109439, 6.645299090334461, 6.714164132637808, 6.782329983125269, 6.8498175158174845, 6.916646586316234, 6.982836100038438, 7.0484040746824395, 7.113367697511497, 7.177743377970545, 7.24154679609267, 7.3047929470998705, 7.367496182557545, 7.429670248402684, 7.491328320131218, 7.552483035399683, 7.6131465242697125, 7.673330437300352, 7.733045971672482, 7.792303895511263, 7.851114570556209, 7.909487973314076, 7.967433714816837, 8.024961059095553, 8.082078940470701, 8.138795979750322, 8.195120499419152, 8.251060537894508, 8.306623862918075, 8.36181798414675, 8.416650165000327, 8.47112743381895, 8.525256594378847, 8.579044235810889, 8.632496741962896, 8.685620300243388, 8.738420909981391, 8.790904390334365, 8.843076387773658, 8.894942383174834, 8.946507698538017, 8.997777503361595, 9.048756820690896, 9.099450532861862, 9.1498633869583, 9.200000000000001, 9.249864863877743, 9.299462350050137, 9.348796714016196, 9.397872099576585, 9.446692542895637, 9.495261976375376, 9.54358423235212, 9.59166304662544, 9.639502061828715], [0.0, 0.9643650760992956, 1.3638181696985856, 1.670329308849007, 1.9287301521985911, 2.1563858652847827, 2.3622023622035435, 2.551470164434615, 2.727636339397171, 2.8930952282978866, 3.0495901363953815, 3.1984371183438958, 3.340658617698014, 3.4770677301427426, 3.6083237105337433, 3.7349698793966195, 3.8574603043971822, 3.976179070414209, 4.091454509095757, 4.203569911396741, 4.312771730569565, 4.419275958796871, 4.523273151159457, 4.624932431938872, 4.724404724407087, 4.821825380496478, 4.917316341257699, 5.0109879265470205, 5.10294032886923, 5.193264869039514, 5.282045058497703, 5.36935750346352, 5.455272678794342, 5.539855593785817, 5.62316636780382, 5.705260730238365, 5.786190456595773, 5.866003750424986, 5.944745579080741, 6.02245796996542, 6.099180272790763, 6.174949392505174, 6.249799996799899, 6.323764701504951, 6.3968742366877915, 6.469157595854347, 6.540642170307134, 6.611353870426239, 6.681317235396028, 6.750555532695069, 6.8190908484929285, 6.886944169949399, 6.954135460285485, 7.020683727387242, 7.0866070866106305, 7.15192281837549, 7.216647421067487, 7.280796659706959, 7.3443856107914165, 7.407428703673091, 7.469939758793239, 7.531932023060219, 7.593418202627852, 7.654410493303845, 7.7149206087943645, 7.774959806970066, 7.834538914320357, 7.893668348746355, 7.952358140828418, 8.010617953691215, 8.068457101577724, 8.125884567233282, 8.182909018191515, 8.239538822045807, 8.295782060782456, 8.351646544245034, 8.407139822793482, 8.462269199216012, 8.517041739947036, 8.571464285639882, 8.62554346113913, 8.67928568489366, 8.732697177848321, 8.78578397184907, 8.838551917593742, 8.891006692158093, 8.943153806124549, 8.994998610338971, 9.046546302318914, 9.097801932335084, 9.148770409186145, 9.199456505685541, 9.249864863877743, 9.3, 9.349866309204641, 9.39946807005588, 9.448809448814174, 9.497894503520243, 9.5467271878901, 9.595311355031686, 9.643650760992957, 9.691749068150704], [0.0, 0.9695359714832659, 1.3711309200802089, 1.6792855623746668, 1.9390719429665317, 2.1679483388678804, 2.374868417407584, 2.5651510676761324, 2.7422618401604177, 2.9086079144497976, 3.0659419433511785, 3.2155870381627056, 3.3585711247493335, 3.4957116585897072, 3.627671429443411, 3.7549966711037173, 3.8781438859330635, 3.9974992182613374, 4.113392760240627, 4.226109321823088, 4.335896677735761, 4.442971978304612, 4.54752680036083, 4.649731175025068, 4.749736834815168, 4.847679857416329, 4.943682837723311, 5.037856687124, 5.130302135352265, 5.221110992882646, 5.310367218940701, 5.398147830506312, 5.4845236803208355, 5.569560126257729, 5.653317610041029, 5.735852159879995, 5.817215828899595, 5.897457079114693, 5.976621118993575, 6.054750201288242, 6.131883886702357, 6.208059278067504, 6.283311228962004, 6.357672530100933, 6.431174076325411, 6.5038450166036395, 6.57571288910944, 6.646803743153547, 6.717142249498667, 6.786751800382861, 6.855654600401045, 6.923871749245506, 6.9914233171794145, 7.058328414008519, 7.124605252222751, 7.1902712048990205, 7.255342858886822, 7.31983606373804, 7.383765976789894, 7.447147104764348, 7.5099933422074345, 7.572318007057021, 7.634133873596926, 7.695453203028396, 7.756287771866127, 7.816648898345122, 7.8765474670060875, 7.935993951610599, 7.994998436522675, 8.053570636680355, 8.1117199162693, 8.16945530620004, 8.226785520481254, 8.283718971573094, 8.340263784797218, 8.396427811873334, 8.452218643646177, 8.507643622061282, 8.56270985144306, 8.61742420912421, 8.671793355471522, 8.725823743349393, 8.77952162705919, 8.832893070789435, 8.885943956609225, 8.938679992034618, 8.99110671719561, 9.043229511629129, 9.09505360072166, 9.1465840618233, 9.197825830053535, 9.248783703817493, 9.299462350050137, 9.349866309204641, 9.4, 9.44986772394196, 9.499473669630335, 9.548821916864929, 9.597916440561463, 9.646761114488118, 9.695359714832659, 9.743715923609434], [0.0, 0.9746794344808963, 1.378404875209022, 1.6881943016134133, 1.9493588689617927, 2.179449471770337, 2.3874672772626644, 2.578759391645525, 2.756809750418044, 2.9240383034426887, 3.082207001484488, 3.2326459750489227, 3.3763886032268267, 3.5142566781611158, 3.6469165057620936, 3.7749172176353745, 3.8987177379235853, 4.018706259482023, 4.135214625627066, 4.2485291572496005, 4.358898943540674, 4.466542286825459, 4.571651780264984, 4.674398357008098, 4.774934554525329, 4.873397172404482, 4.969909455915671, 5.06458290484024, 5.15751878329105, 5.2488093888042835, 5.338539126015655, 5.426785420486054, 5.513619500836088, 5.599107071667768, 5.683308895353129, 5.766281297335397, 5.848076606885377, 5.928743543112655, 6.008327554319921, 6.08687111741328, 6.164414002968976, 6.24099351065197, 6.316644678941503, 6.3914004725099165, 6.465291950097845, 6.53834841531101, 6.6105975524153635, 6.682065548915245, 6.752777206453653, 6.822756041366274, 6.892024376045111, 6.960603422117942, 7.0285133563222315, 7.095773389842717, 7.162401831787993, 7.2284161474004796, 7.293833011524187, 7.358668357794092, 7.4229374239582535, 7.486654793697916, 7.549834435270749, 7.6124897372673015, 7.674633541739956, 7.736278174936576, 7.797435475847171, 7.858116822750854, 7.918333157931661, 7.978095010715276, 8.037412518964047, 8.096295449154509, 8.154753215150045, 8.212794895770866, 8.270429251254132, 8.327664738688751, 8.384509526501832, 8.440971508067065, 8.497058314499201, 8.55277732669336, 8.608135686662937, 8.663140308225419, 8.717797887081348, 8.772114910328067, 8.826097665446492, 8.879752248796134, 8.933084573650918, 8.986100377805714, 9.038805230781334, 9.091204540653564, 9.143303560529969, 9.195107394696377, 9.246621004453464, 9.297849213662264, 9.348796714016196, 9.39946807005588, 9.44986772394196, 9.499999999999998, 9.549869109050658, 9.599479152537391, 9.648834126463154, 9.697937925146768, 9.746794344808963, 9.795407086997457], [0.0, 0.9797958971132713, 1.3856406460551018, 1.6970562748477143, 1.9595917942265426, 2.1908902300206647, 2.4000000000000004, 2.5922962793631443, 2.7712812921102037, 2.939387691339814, 3.0983866769659336, 3.2496153618543846, 3.3941125496954285, 3.532704346531139, 3.666060555964672, 3.794733192202055, 3.9191835884530852, 4.039801975344831, 4.156921938165306, 4.270831300812525, 4.3817804600413295, 4.48998886412873, 4.595650117230424, 4.698936049788292, 4.800000000000001, 4.898979485566357, 4.9959983987187195, 5.091168824543143, 5.184592558726289, 5.276362383309168, 5.366563145999495, 5.455272678794342, 5.542562584220407, 5.628498911788117, 5.713142742834281, 5.796550698475776, 5.878775382679628, 5.959865770300536, 6.0398675482166, 6.118823416311343, 6.196773353931867, 6.27375485654325, 6.349803146555018, 6.424951361683604, 6.499230723708769, 6.572670690061993, 6.64529909033446, 6.717142249498666, 6.788225099390857, 6.858571279792899, 6.92820323027551, 6.997142273814362, 7.065408693062278, 7.1330218000508046, 7.2, 7.266360849833981, 7.332121111929344, 7.397296803562772, 7.4619032424710525, 7.525955088890711, 7.58946638440411, 7.652450587883597, 7.714920608794364, 7.776888838089433, 7.8383671769061705, 7.899367063252599, 7.95989949685296, 8.019975062305368, 8.079603950689663, 8.138795979750322, 8.19756061276768, 8.255906976220118, 8.313843876330612, 8.37137981458254, 8.42852300228219, 8.485281374238571, 8.54166260162505, 8.597674104081872, 8.653323061113575, 8.708616422830897, 8.763560920082659, 8.818163074019441, 8.872429205127535, 8.926365441768558, 8.97997772825746, 9.033271832508973, 9.086253353280439, 9.138927727036691, 9.191300234460847, 9.243376006633074, 9.2951600308978, 9.346657156438338, 9.397872099576585, 9.448809448814174, 9.499473669630335, 9.549869109050658, 9.600000000000001, 9.649870465451857, 9.699484522385713, 9.748846085563153, 9.797958971132713, 9.846826900072939], [0.0, 0.9848857801796106, 1.392838827718412, 1.7058722109231985, 1.9697715603592212, 2.2022715545545246, 2.412467616362964, 2.6057628441590768, 2.785677655436824, 2.9546573405388314, 3.1144823004794877, 3.2664965942122155, 3.411744421846397, 3.5510561809129415, 3.685105154537656, 3.8144462245521304, 3.9395431207184424, 4.060788100849391, 4.178516483155236, 4.293017586733137, 4.404543109109049, 4.513313638558704, 4.61952378498044, 4.723346271447818, 4.824935232725928, 4.924428900898053, 5.021951811795889, 5.117616632769595, 5.2115256883181535, 5.3037722424704485, 5.394441583704471, 5.483611948342078, 5.571355310873648, 5.657738063926256, 5.742821606144492, 5.826662852782887, 5.909314681077663, 5.990826320300065, 6.071243694664217, 6.150609725872713, 6.228964600958975, 6.306346010171025, 6.38278935889318, 6.458327956987009, 6.532993188424431, 6.606814663663572, 6.679820356865895, 6.7520367297579185, 6.823488843692794, 6.894200461257274, 6.9641941385920605, 7.033491309442276, 7.102112361825883, 7.170076708097342, 7.237402849088892, 7.30410843293006, 7.370210309075312, 7.4357245780085215, 7.5006666370396715, 7.565051222562872, 7.628892449104261, 7.692203845452876, 7.754998388136519, 7.817288532477231, 7.879086241436885, 7.940403012442127, 8.001249902359007, 8.061637550770936, 8.121576201698781, 8.18107572388864, 8.240145629781066, 8.298795093265047, 8.357032966310472, 8.414867794564572, 8.472307831990054, 8.529361054615991, 8.586035173466273, 8.64233764672499, 8.698275691193055, 8.753856293085923, 8.809086218218098, 8.863972021616496, 8.918520056601322, 8.972736483370054, 9.026627277117408, 9.080198235721511, 9.133454987024352, 9.186402995732335, 9.23904756996088, 9.291393867445294, 9.343446901438464, 9.395211546314432, 9.446692542895637, 9.497894503520243, 9.548821916864929, 9.599479152537391, 9.649870465451857, 9.700000000000003, 9.749871794028884, 9.799489782636646, 9.848857801796106, 9.897979591815698], [0.0, 0.9899494936611666, 1.4, 1.7146428199482249, 1.9798989873223332, 2.2135943621178655, 2.4248711305964283, 2.619160170741759, 2.8, 2.9698484809834995, 3.1304951684997055, 3.283291031876401, 3.4292856398964497, 3.5693136595149495, 3.704051835490427, 3.8340579025361623, 3.9597979746446663, 4.08166632639171, 4.2, 4.315089802078284, 4.427188724235731, 4.536518488885503, 4.64327470649756, 4.747630988187688, 4.849742261192857, 4.949747468305833, 5.047771785649585, 5.143928459844674, 5.238320341483518, 5.331041174104736, 5.422176684690383, 5.511805511808268, 5.6, 5.686826883245173, 5.772347875864725, 5.856620185738529, 5.939696961966999, 6.021627686929839, 6.102458520956943, 6.182232606429493, 6.260990336999411, 6.338769596696192, 6.4156059729381765, 6.491532946846992, 6.566582063752802, 6.640783086353596, 6.714164132637808, 6.786751800382861, 6.8585712797928995, 6.929646455628165, 7.0, 7.069653456853455, 7.138627319029899, 7.206941098690901, 7.274613391789285, 7.341661937191061, 7.408103670980854, 7.473954776421918, 7.539230729988306, 7.603946343840151, 7.668115805072325, 7.731752712031082, 7.79487010796203, 7.857480512225277, 7.919595949289333, 7.981227975693965, 8.04238770515324, 8.103085831953157, 8.16333265278342, 8.223138087129511, 8.282511696339462, 8.341462701469089, 8.4, 8.4581321815162, 8.515867542417507, 8.573214099741124, 8.630179604156568, 8.6867715521936, 8.742997197757758, 8.798863562983575, 8.854377448471462, 8.909545442950499, 8.964373932405989, 9.018869108707587, 9.073036977771006, 9.126883367283709, 9.180413934022802, 9.233634170791044, 9.28654941299512, 9.339164844888433, 9.391485505499116, 9.443516294262428, 9.495261976375376, 9.5467271878901, 9.597916440561463, 9.648834126463154, 9.699484522385713, 9.749871794028884, 9.8, 9.849873095629203, 9.899494936611665, 9.948869282486328], [0.0, 0.9949874371066201, 1.407124727947029, 1.7233687939614089, 1.9899748742132402, 2.224859546128699, 2.4372115213907883, 2.632489316217637, 2.814249455894058, 2.98496231131986, 3.146426544510455, 3.3000000000000007, 3.4467375879228177, 3.58747822293042, 3.722902093797257, 3.853569773599539, 3.9799497484264803, 4.102438299353203, 4.221374183841087, 4.337049688440289, 4.449719092257398, 4.559605246071199, 4.666904755831214, 4.77179211617606, 4.874423042781577, 4.974937185533101, 5.073460357586329, 5.170106381884226, 5.264978632435274, 5.358171329847527, 5.449770637375485, 5.539855593785817, 5.628498911788116, 5.715767664977296, 5.801723881744115, 5.886425061104576, 5.96992462263972, 6.052272300549605, 6.133514490078262, 6.213694553162394, 6.29285308902091, 6.3710281744785915, 6.448255578061405, 6.524568951279464, 6.600000000000001, 6.674578638386096, 6.748333127521196, 6.821290200541244, 6.893475175845635, 6.96491205974634, 7.035623639735145, 7.105631569396208, 7.17495644586084, 7.243617880589783, 7.3116345641723655, 7.379024325749307, 7.445804187594514, 7.5119904153293495, 7.577598564189055, 7.642643521714199, 7.707139547199078, 7.771100308193172, 7.834538914320357, 7.897467948652911, 7.959899496852961, 8.021845174272563, 8.083316151184489, 8.144323176298936, 8.204876598706406, 8.264986388373547, 8.324662155306966, 8.383913167489272, 8.442748367682174, 8.501176389182852, 8.559205570612264, 8.616843969807043, 8.674099376880578, 8.73097932651315, 8.787491109526087, 8.843641783790206, 8.899438184514796, 8.95488693395958, 9.009994450608726, 9.064766957842878, 9.119210492142399, 9.173330910852394, 9.22713389953782, 9.280624978954814, 9.333809511662428, 9.38669270829721, 9.439279633531365, 9.491575211733826, 9.54358423235212, 9.595311355031686, 9.646761114488118, 9.697937925146768, 9.748846085563153, 9.799489782636646, 9.849873095629203, 9.900000000000002, 9.949874371066201, 9.999499987499377], [0.0, 1.0, 1.4142135623730951, 1.7320508075688776, 2.0, 2.23606797749979, 2.4494897427831783, 2.6457513110645907, 2.8284271247461903, 3.0, 3.1622776601683795, 3.3166247903554003, 3.4641016151377553, 3.6055512754639896, 3.7416573867739413, 3.8729833462074166, 4.0, 4.123105625617661, 4.242640687119286, 4.358898943540674, 4.47213595499958, 4.582575694955841, 4.69041575982343, 4.79583152331272, 4.898979485566357, 5.000000000000001, 5.099019513592785, 5.196152422706633, 5.291502622129181, 5.385164807134505, 5.477225575051661, 5.567764362830022, 5.656854249492381, 5.7445626465380295, 5.830951894845301, 5.916079783099616, 6.0, 6.08276253029822, 6.164414002968977, 6.244997998398399, 6.324555320336759, 6.403124237432849, 6.480740698407861, 6.557438524302, 6.6332495807108005, 6.7082039324993685, 6.782329983125269, 6.855654600401045, 6.9282032302755105, 7.0, 7.071067811865476, 7.141428428542851, 7.211102550927979, 7.28010988928052, 7.348469228349535, 7.416198487095664, 7.483314773547883, 7.54983443527075, 7.6157731058639095, 7.681145747868608, 7.745966692414833, 7.810249675906655, 7.874007874011811, 7.937253933193772, 8.0, 8.06225774829855, 8.12403840463596, 8.18535277187245, 8.246211251235321, 8.306623862918075, 8.366600265340756, 8.426149773176359, 8.485281374238571, 8.544003745317532, 8.602325267042627, 8.660254037844387, 8.717797887081348, 8.774964387392123, 8.831760866327848, 8.88819441731559, 8.94427190999916, 9.000000000000002, 9.055385138137417, 9.1104335791443, 9.165151389911681, 9.219544457292889, 9.273618495495704, 9.327379053088816, 9.38083151964686, 9.433981132056603, 9.486832980505138, 9.539392014169458, 9.59166304662544, 9.643650760992957, 9.695359714832659, 9.746794344808963, 9.797958971132713, 9.848857801796106, 9.899494936611665, 9.949874371066201, 10.000000000000002, 10.049875621120892], [0.0, 1.0049875621120892, 1.4212670403551897, 1.7406895185529214, 2.0099751242241783, 2.2472205054244236, 2.4617067250182347, 2.6589471600616665, 2.8425340807103794, 3.0149626863362675, 3.178049716414141, 3.333166662499792, 3.481379037105843, 3.6235341863986883, 3.7603191353926335, 3.892300091205713, 4.019950248448357, 4.1436698710201325, 4.263801121065569, 4.380639222761903, 4.494441010848847, 4.605431575867782, 4.713809499757071, 4.819751030914357, 4.9234134500364695, 5.024937810560446, 5.1244511901275835, 5.222068555658764, 5.317894320123333, 5.412023651093924, 5.504543577809154, 5.595533933415113, 5.685068161420759, 5.773214009544425, 5.860034129593445, 5.9455865984779, 6.029925372672535, 6.113100686231171, 6.1951594006934165, 6.276145313805283, 6.356099432828282, 6.435060217278469, 6.5130637951735135, 6.590144156238162, 6.666333324999584, 6.74166151627327, 6.81615727518079, 6.889847603539574, 6.962758074211686, 7.034912934784624, 7.1063352017759485, 7.177046746399247, 7.247068372797377, 7.31641988953614, 7.385120175054704, 7.4531872376856345, 7.520638270785267, 7.587489703452652, 7.653757247260983, 7.719455939378112, 7.784600182411426, 7.849203781276163, 7.913279977354524, 7.976841480185, 8.039900496896713, 8.10246875958186, 8.16455755078008, 8.226177727231525, 8.287339742040265, 8.34805366537614, 8.408329203831164, 8.468175718535841, 8.527602242131138, 8.586617494683225, 8.645229898620395, 8.703447592764606, 8.761278445523805, 8.81873006730561, 8.875809822207776, 8.932524839036274, 8.988882021697695, 9.044888059008803, 9.100549433962767, 9.155872432488342, 9.210863151735564, 9.265527507918803, 9.319871243745807, 9.373899935459095, 9.427618999514142, 9.481033698917013, 9.534149149242424, 9.586970324351693, 9.639502061828715, 9.691749068150704, 9.743715923609434, 9.795407086997457, 9.846826900072939, 9.897979591815698, 9.948869282486328, 9.999499987499377, 10.049875621120892, 10.100000000000001]]}],\n",
       "                        {\"autosize\": false, \"height\": 500, \"margin\": {\"b\": 65, \"l\": 65, \"r\": 50, \"t\": 90}, \"scene\": {\"xaxis\": {\"title\": {\"text\": \"K\"}}, \"yaxis\": {\"title\": {\"text\": \"L\"}}, \"zaxis\": {\"title\": {\"text\": \"Y\"}}}, \"template\": {\"data\": {\"bar\": [{\"error_x\": {\"color\": \"#2a3f5f\"}, \"error_y\": {\"color\": \"#2a3f5f\"}, \"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"bar\"}], \"barpolar\": [{\"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"barpolar\"}], \"carpet\": [{\"aaxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"baxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"type\": \"carpet\"}], \"choropleth\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"choropleth\"}], \"contour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"contour\"}], \"contourcarpet\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"contourcarpet\"}], \"heatmap\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmap\"}], \"heatmapgl\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmapgl\"}], \"histogram\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"histogram\"}], \"histogram2d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2d\"}], \"histogram2dcontour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2dcontour\"}], \"mesh3d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"mesh3d\"}], \"parcoords\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"parcoords\"}], \"scatter\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter\"}], \"scatter3d\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter3d\"}], \"scattercarpet\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattercarpet\"}], \"scattergeo\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergeo\"}], \"scattergl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergl\"}], \"scattermapbox\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattermapbox\"}], \"scatterpolar\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolar\"}], \"scatterpolargl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolargl\"}], \"scatterternary\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterternary\"}], \"surface\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"surface\"}], \"table\": [{\"cells\": {\"fill\": {\"color\": \"#EBF0F8\"}, \"line\": {\"color\": \"white\"}}, \"header\": {\"fill\": {\"color\": \"#C8D4E3\"}, \"line\": {\"color\": \"white\"}}, \"type\": \"table\"}]}, \"layout\": {\"annotationdefaults\": {\"arrowcolor\": \"#2a3f5f\", \"arrowhead\": 0, \"arrowwidth\": 1}, \"colorscale\": {\"diverging\": [[0, \"#8e0152\"], [0.1, \"#c51b7d\"], [0.2, \"#de77ae\"], [0.3, \"#f1b6da\"], [0.4, \"#fde0ef\"], [0.5, \"#f7f7f7\"], [0.6, \"#e6f5d0\"], [0.7, \"#b8e186\"], [0.8, \"#7fbc41\"], [0.9, \"#4d9221\"], [1, \"#276419\"]], \"sequential\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"sequentialminus\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]]}, \"colorway\": [\"#636efa\", \"#EF553B\", \"#00cc96\", \"#ab63fa\", \"#FFA15A\", \"#19d3f3\", \"#FF6692\", \"#B6E880\", \"#FF97FF\", \"#FECB52\"], \"font\": {\"color\": \"#2a3f5f\"}, \"geo\": {\"bgcolor\": \"white\", \"lakecolor\": \"white\", \"landcolor\": \"#E5ECF6\", \"showlakes\": true, \"showland\": true, \"subunitcolor\": \"white\"}, \"hoverlabel\": {\"align\": \"left\"}, \"hovermode\": \"closest\", \"mapbox\": {\"style\": \"light\"}, \"paper_bgcolor\": \"white\", \"plot_bgcolor\": \"#E5ECF6\", \"polar\": {\"angularaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"radialaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"scene\": {\"xaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"yaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"zaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}}, \"shapedefaults\": {\"line\": {\"color\": \"#2a3f5f\"}}, \"ternary\": {\"aaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"baxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"caxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"title\": {\"x\": 0.05}, \"xaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}, \"yaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}}}, \"title\": {\"text\": \"Cobb-Douglas Production Function\"}, \"width\": 500},\n",
       "                        {\"responsive\": true}\n",
       "                    )\n",
       "                };\n",
       "                \n",
       "            </script>\n",
       "        </div>\n",
       "</body>\n",
       "</html>"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "change_alpha_beta(0.5, filename=\"fig5.html\")\n",
    "display(HTML(\"fig5.html\"))"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "The above graph exhibits decreasing returns to scale as $\\alpha + \\beta = 0.5$ (the purple-yellow surface) with constant returns to scale for comparison (the blue-yellow surface). This time, the orange production function flattens out far faster than the regular constant returns to scale function. You can prove this to yourself using the slider below, which adjusts the value of $\\alpha + \\beta$."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 18,
   "metadata": {
    "tags": [
     "remove_input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<html>\n",
       "<head><meta charset=\"utf-8\" /></head>\n",
       "<body>\n",
       "    <div>\n",
       "            <script src=\"https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.5/MathJax.js?config=TeX-AMS-MML_SVG\"></script><script type=\"text/javascript\">if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}</script>\n",
       "                <script type=\"text/javascript\">window.PlotlyConfig = {MathJaxConfig: 'local'};</script>\n",
       "        <script type=\"text/javascript\">/**\n",
       "* plotly.js v1.49.1\n",
       "* Copyright 2012-2019, Plotly, Inc.\n",
       "* All rights reserved.\n",
       "* Licensed under the MIT license\n",
       "*/\n",
       "!function(t){if(\"object\"==typeof exports&&\"undefined\"!=typeof module)module.exports=t();else if(\"function\"==typeof define&&define.amd)define([],t);else{(\"undefined\"!=typeof window?window:\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:this).Plotly=t()}}(function(){return function(){return function t(e,r,n){function i(o,s){if(!r[o]){if(!e[o]){var l=\"function\"==typeof require&&require;if(!s&&l)return l(o,!0);if(a)return a(o,!0);var c=new Error(\"Cannot find module '\"+o+\"'\");throw c.code=\"MODULE_NOT_FOUND\",c}var u=r[o]={exports:{}};e[o][0].call(u.exports,function(t){return i(e[o][1][t]||t)},u,u.exports,t,e,r,n)}return r[o].exports}for(var a=\"function\"==typeof require&&require,o=0;o<n.length;o++)i(n[o]);return i}}()({1:[function(t,e,r){\"use strict\";var n=t(\"../src/lib\"),i={\"X,X div\":\"direction:ltr;font-family:'Open Sans', verdana, arial, sans-serif;margin:0;padding:0;\",\"X input,X button\":\"font-family:'Open Sans', verdana, arial, sans-serif;\",\"X input:focus,X button:focus\":\"outline:none;\",\"X a\":\"text-decoration:none;\",\"X a:hover\":\"text-decoration:none;\",\"X .crisp\":\"shape-rendering:crispEdges;\",\"X .user-select-none\":\"-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;\",\"X svg\":\"overflow:hidden;\",\"X svg a\":\"fill:#447adb;\",\"X svg a:hover\":\"fill:#3c6dc5;\",\"X .main-svg\":\"position:absolute;top:0;left:0;pointer-events:none;\",\"X .main-svg .draglayer\":\"pointer-events:all;\",\"X .cursor-default\":\"cursor:default;\",\"X .cursor-pointer\":\"cursor:pointer;\",\"X .cursor-crosshair\":\"cursor:crosshair;\",\"X .cursor-move\":\"cursor:move;\",\"X .cursor-col-resize\":\"cursor:col-resize;\",\"X .cursor-row-resize\":\"cursor:row-resize;\",\"X .cursor-ns-resize\":\"cursor:ns-resize;\",\"X .cursor-ew-resize\":\"cursor:ew-resize;\",\"X .cursor-sw-resize\":\"cursor:sw-resize;\",\"X .cursor-s-resize\":\"cursor:s-resize;\",\"X .cursor-se-resize\":\"cursor:se-resize;\",\"X .cursor-w-resize\":\"cursor:w-resize;\",\"X .cursor-e-resize\":\"cursor:e-resize;\",\"X .cursor-nw-resize\":\"cursor:nw-resize;\",\"X .cursor-n-resize\":\"cursor:n-resize;\",\"X .cursor-ne-resize\":\"cursor:ne-resize;\",\"X .cursor-grab\":\"cursor:-webkit-grab;cursor:grab;\",\"X .modebar\":\"position:absolute;top:2px;right:2px;\",\"X .ease-bg\":\"-webkit-transition:background-color 0.3s ease 0s;-moz-transition:background-color 0.3s ease 0s;-ms-transition:background-color 0.3s ease 0s;-o-transition:background-color 0.3s ease 0s;transition:background-color 0.3s ease 0s;\",\"X .modebar--hover>:not(.watermark)\":\"opacity:0;-webkit-transition:opacity 0.3s ease 0s;-moz-transition:opacity 0.3s ease 0s;-ms-transition:opacity 0.3s ease 0s;-o-transition:opacity 0.3s ease 0s;transition:opacity 0.3s ease 0s;\",\"X:hover .modebar--hover .modebar-group\":\"opacity:1;\",\"X .modebar-group\":\"float:left;display:inline-block;box-sizing:border-box;padding-left:8px;position:relative;vertical-align:middle;white-space:nowrap;\",\"X .modebar-btn\":\"position:relative;font-size:16px;padding:3px 4px;height:22px;cursor:pointer;line-height:normal;box-sizing:border-box;\",\"X .modebar-btn svg\":\"position:relative;top:2px;\",\"X .modebar.vertical\":\"display:flex;flex-direction:column;flex-wrap:wrap;align-content:flex-end;max-height:100%;\",\"X .modebar.vertical svg\":\"top:-1px;\",\"X .modebar.vertical .modebar-group\":\"display:block;float:none;padding-left:0px;padding-bottom:8px;\",\"X .modebar.vertical .modebar-group .modebar-btn\":\"display:block;text-align:center;\",\"X [data-title]:before,X [data-title]:after\":\"position:absolute;-webkit-transform:translate3d(0, 0, 0);-moz-transform:translate3d(0, 0, 0);-ms-transform:translate3d(0, 0, 0);-o-transform:translate3d(0, 0, 0);transform:translate3d(0, 0, 0);display:none;opacity:0;z-index:1001;pointer-events:none;top:110%;right:50%;\",\"X [data-title]:hover:before,X [data-title]:hover:after\":\"display:block;opacity:1;\",\"X [data-title]:before\":\"content:'';position:absolute;background:transparent;border:6px solid transparent;z-index:1002;margin-top:-12px;border-bottom-color:#69738a;margin-right:-6px;\",\"X [data-title]:after\":\"content:attr(data-title);background:#69738a;color:white;padding:8px 10px;font-size:12px;line-height:12px;white-space:nowrap;margin-right:-18px;border-radius:2px;\",\"X .vertical [data-title]:before,X .vertical [data-title]:after\":\"top:0%;right:200%;\",\"X .vertical [data-title]:before\":\"border:6px solid transparent;border-left-color:#69738a;margin-top:8px;margin-right:-30px;\",\"X .select-outline\":\"fill:none;stroke-width:1;shape-rendering:crispEdges;\",\"X .select-outline-1\":\"stroke:white;\",\"X .select-outline-2\":\"stroke:black;stroke-dasharray:2px 2px;\",Y:\"font-family:'Open Sans';position:fixed;top:50px;right:20px;z-index:10000;font-size:10pt;max-width:180px;\",\"Y p\":\"margin:0;\",\"Y .notifier-note\":\"min-width:180px;max-width:250px;border:1px solid #fff;z-index:3000;margin:0;background-color:#8c97af;background-color:rgba(140,151,175,0.9);color:#fff;padding:10px;overflow-wrap:break-word;word-wrap:break-word;-ms-hyphens:auto;-webkit-hyphens:auto;hyphens:auto;\",\"Y .notifier-close\":\"color:#fff;opacity:0.8;float:right;padding:0 5px;background:none;border:none;font-size:20px;font-weight:bold;line-height:20px;\",\"Y .notifier-close:hover\":\"color:#444;text-decoration:none;cursor:pointer;\"};for(var a in i){var o=a.replace(/^,/,\" ,\").replace(/X/g,\".js-plotly-plot .plotly\").replace(/Y/g,\".plotly-notifier\");n.addStyleRule(o,i[a])}},{\"../src/lib\":719}],2:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/aggregate\")},{\"../src/transforms/aggregate\":1265}],3:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/bar\")},{\"../src/traces/bar\":864}],4:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/barpolar\")},{\"../src/traces/barpolar\":876}],5:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/box\")},{\"../src/traces/box\":886}],6:[function(t,e,r){\"use strict\";e.exports=t(\"../src/components/calendars\")},{\"../src/components/calendars\":591}],7:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/candlestick\")},{\"../src/traces/candlestick\":895}],8:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/carpet\")},{\"../src/traces/carpet\":914}],9:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choropleth\")},{\"../src/traces/choropleth\":928}],10:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choroplethmapbox\")},{\"../src/traces/choroplethmapbox\":935}],11:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/cone\")},{\"../src/traces/cone\":941}],12:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contour\")},{\"../src/traces/contour\":956}],13:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contourcarpet\")},{\"../src/traces/contourcarpet\":967}],14:[function(t,e,r){\"use strict\";e.exports=t(\"../src/core\")},{\"../src/core\":697}],15:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/densitymapbox\")},{\"../src/traces/densitymapbox\":977}],16:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/filter\")},{\"../src/transforms/filter\":1266}],17:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnel\")},{\"../src/traces/funnel\":987}],18:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnelarea\")},{\"../src/traces/funnelarea\":996}],19:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/groupby\")},{\"../src/transforms/groupby\":1267}],20:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmap\")},{\"../src/traces/heatmap\":1009}],21:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmapgl\")},{\"../src/traces/heatmapgl\":1018}],22:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram\")},{\"../src/traces/histogram\":1030}],23:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2d\")},{\"../src/traces/histogram2d\":1036}],24:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2dcontour\")},{\"../src/traces/histogram2dcontour\":1040}],25:[function(t,e,r){\"use strict\";var n=t(\"./core\");n.register([t(\"./bar\"),t(\"./box\"),t(\"./heatmap\"),t(\"./histogram\"),t(\"./histogram2d\"),t(\"./histogram2dcontour\"),t(\"./contour\"),t(\"./scatterternary\"),t(\"./violin\"),t(\"./funnel\"),t(\"./waterfall\"),t(\"./pie\"),t(\"./sunburst\"),t(\"./funnelarea\"),t(\"./scatter3d\"),t(\"./surface\"),t(\"./isosurface\"),t(\"./volume\"),t(\"./mesh3d\"),t(\"./cone\"),t(\"./streamtube\"),t(\"./scattergeo\"),t(\"./choropleth\"),t(\"./scattergl\"),t(\"./splom\"),t(\"./pointcloud\"),t(\"./heatmapgl\"),t(\"./parcoords\"),t(\"./parcats\"),t(\"./scattermapbox\"),t(\"./choroplethmapbox\"),t(\"./densitymapbox\"),t(\"./sankey\"),t(\"./indicator\"),t(\"./table\"),t(\"./carpet\"),t(\"./scattercarpet\"),t(\"./contourcarpet\"),t(\"./ohlc\"),t(\"./candlestick\"),t(\"./scatterpolar\"),t(\"./scatterpolargl\"),t(\"./barpolar\")]),n.register([t(\"./aggregate\"),t(\"./filter\"),t(\"./groupby\"),t(\"./sort\")]),n.register([t(\"./calendars\")]),e.exports=n},{\"./aggregate\":2,\"./bar\":3,\"./barpolar\":4,\"./box\":5,\"./calendars\":6,\"./candlestick\":7,\"./carpet\":8,\"./choropleth\":9,\"./choroplethmapbox\":10,\"./cone\":11,\"./contour\":12,\"./contourcarpet\":13,\"./core\":14,\"./densitymapbox\":15,\"./filter\":16,\"./funnel\":17,\"./funnelarea\":18,\"./groupby\":19,\"./heatmap\":20,\"./heatmapgl\":21,\"./histogram\":22,\"./histogram2d\":23,\"./histogram2dcontour\":24,\"./indicator\":26,\"./isosurface\":27,\"./mesh3d\":28,\"./ohlc\":29,\"./parcats\":30,\"./parcoords\":31,\"./pie\":32,\"./pointcloud\":33,\"./sankey\":34,\"./scatter3d\":35,\"./scattercarpet\":36,\"./scattergeo\":37,\"./scattergl\":38,\"./scattermapbox\":39,\"./scatterpolar\":40,\"./scatterpolargl\":41,\"./scatterternary\":42,\"./sort\":43,\"./splom\":44,\"./streamtube\":45,\"./sunburst\":46,\"./surface\":47,\"./table\":48,\"./violin\":49,\"./volume\":50,\"./waterfall\":51}],26:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/indicator\")},{\"../src/traces/indicator\":1046}],27:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/isosurface\")},{\"../src/traces/isosurface\":1052}],28:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/mesh3d\")},{\"../src/traces/mesh3d\":1057}],29:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/ohlc\")},{\"../src/traces/ohlc\":1062}],30:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcats\")},{\"../src/traces/parcats\":1071}],31:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcoords\")},{\"../src/traces/parcoords\":1081}],32:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pie\")},{\"../src/traces/pie\":1092}],33:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pointcloud\")},{\"../src/traces/pointcloud\":1101}],34:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sankey\")},{\"../src/traces/sankey\":1107}],35:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatter3d\")},{\"../src/traces/scatter3d\":1143}],36:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattercarpet\")},{\"../src/traces/scattercarpet\":1149}],37:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergeo\")},{\"../src/traces/scattergeo\":1156}],38:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergl\")},{\"../src/traces/scattergl\":1167}],39:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattermapbox\")},{\"../src/traces/scattermapbox\":1176}],40:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolar\")},{\"../src/traces/scatterpolar\":1183}],41:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolargl\")},{\"../src/traces/scatterpolargl\":1189}],42:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterternary\")},{\"../src/traces/scatterternary\":1196}],43:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/sort\")},{\"../src/transforms/sort\":1269}],44:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/splom\")},{\"../src/traces/splom\":1205}],45:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/streamtube\")},{\"../src/traces/streamtube\":1213}],46:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sunburst\")},{\"../src/traces/sunburst\":1219}],47:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/surface\")},{\"../src/traces/surface\":1228}],48:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/table\")},{\"../src/traces/table\":1236}],49:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/violin\")},{\"../src/traces/violin\":1244}],50:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/volume\")},{\"../src/traces/volume\":1252}],51:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/waterfall\")},{\"../src/traces/waterfall\":1260}],52:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).eye||[0,0,1],r=t.center||[0,0,0],s=t.up||[0,1,0],l=t.distanceLimits||[0,1/0],c=t.mode||\"turntable\",u=n(),h=i(),f=a();return u.setDistanceLimits(l[0],l[1]),u.lookAt(0,e,r,s),h.setDistanceLimits(l[0],l[1]),h.lookAt(0,e,r,s),f.setDistanceLimits(l[0],l[1]),f.lookAt(0,e,r,s),new o({turntable:u,orbit:h,matrix:f},c)};var n=t(\"turntable-camera-controller\"),i=t(\"orbit-camera-controller\"),a=t(\"matrix-camera-controller\");function o(t,e){this._controllerNames=Object.keys(t),this._controllerList=this._controllerNames.map(function(e){return t[e]}),this._mode=e,this._active=t[e],this._active||(this._mode=\"turntable\",this._active=t.turntable),this.modes=this._controllerNames,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}var s=o.prototype;[[\"flush\",1],[\"idle\",1],[\"lookAt\",4],[\"rotate\",4],[\"pan\",4],[\"translate\",4],[\"setMatrix\",2],[\"setDistanceLimits\",2],[\"setDistance\",2]].forEach(function(t){for(var e=t[0],r=[],n=0;n<t[1];++n)r.push(\"a\"+n);var i=\"var cc=this._controllerList;for(var i=0;i<cc.length;++i){cc[i].\"+t[0]+\"(\"+r.join()+\")}\";s[e]=Function.apply(null,r.concat(i))}),s.recalcMatrix=function(t){this._active.recalcMatrix(t)},s.getDistance=function(t){return this._active.getDistance(t)},s.getDistanceLimits=function(t){return this._active.getDistanceLimits(t)},s.lastT=function(){return this._active.lastT()},s.setMode=function(t){if(t!==this._mode){var e=this._controllerNames.indexOf(t);if(!(e<0)){var r=this._active,n=this._controllerList[e],i=Math.max(r.lastT(),n.lastT());r.recalcMatrix(i),n.setMatrix(i,r.computedMatrix),this._active=n,this._mode=t,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}}},s.getMode=function(){return this._mode}},{\"matrix-camera-controller\":433,\"orbit-camera-controller\":456,\"turntable-camera-controller\":542}],53:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n,i){\"use strict\";function a(t){return t.target.depth}function o(t,e){return t.sourceLinks.length?t.depth:e-1}function s(t){return function(){return t}}i=i&&i.hasOwnProperty(\"default\")?i.default:i;var l=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&\"function\"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?\"symbol\":typeof t};function c(t,e){return h(t.source,e.source)||t.index-e.index}function u(t,e){return h(t.target,e.target)||t.index-e.index}function h(t,e){return t.partOfCycle===e.partOfCycle?t.y0-e.y0:\"top\"===t.circularLinkType||\"bottom\"===e.circularLinkType?-1:1}function f(t){return t.value}function p(t){return(t.y0+t.y1)/2}function d(t){return p(t.source)}function g(t){return p(t.target)}function v(t){return t.index}function m(t){return t.nodes}function y(t){return t.links}function x(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function b(t,e){return e(t)}var _=25,w=10,k=.3;function T(t,e){var r=0,n=0;t.links.forEach(function(i){i.circular&&(i.source.circularLinkType||i.target.circularLinkType?i.circularLinkType=i.source.circularLinkType?i.source.circularLinkType:i.target.circularLinkType:i.circularLinkType=r<n?\"top\":\"bottom\",\"top\"==i.circularLinkType?r+=1:n+=1,t.nodes.forEach(function(t){b(t,e)!=b(i.source,e)&&b(t,e)!=b(i.target,e)||(t.circularLinkType=i.circularLinkType)}))}),t.links.forEach(function(t){t.circular&&(t.source.circularLinkType==t.target.circularLinkType&&(t.circularLinkType=t.source.circularLinkType),Y(t,e)&&(t.circularLinkType=t.source.circularLinkType))})}function A(t){var e=Math.abs(t.y1-t.y0),r=Math.abs(t.target.x0-t.source.x1);return Math.atan(r/e)}function M(t,e){var r=0;t.sourceLinks.forEach(function(t){r=t.circular&&!Y(t,e)?r+1:r});var n=0;return t.targetLinks.forEach(function(t){n=t.circular&&!Y(t,e)?n+1:n}),r+n}function S(t){var e=t.source.sourceLinks,r=0;e.forEach(function(t){r=t.circular?r+1:r});var n=t.target.targetLinks,i=0;return n.forEach(function(t){i=t.circular?i+1:i}),!(r>1||i>1)}function E(t,e,r){return t.sort(L),t.forEach(function(n,i){var a,o,s=0;if(Y(n,r)&&S(n))n.circularPathData.verticalBuffer=s+n.width/2;else{for(var l=0;l<i;l++)if(a=t[i],o=t[l],!(a.source.column<o.target.column||a.target.column>o.source.column)){var c=t[l].circularPathData.verticalBuffer+t[l].width/2+e;s=c>s?c:s}n.circularPathData.verticalBuffer=s+n.width/2}}),t}function C(t,r,i,a){var o=e.min(t.links,function(t){return t.source.y0});t.links.forEach(function(t){t.circular&&(t.circularPathData={})}),E(t.links.filter(function(t){return\"top\"==t.circularLinkType}),r,a),E(t.links.filter(function(t){return\"bottom\"==t.circularLinkType}),r,a),t.links.forEach(function(e){if(e.circular){if(e.circularPathData.arcRadius=e.width+w,e.circularPathData.leftNodeBuffer=5,e.circularPathData.rightNodeBuffer=5,e.circularPathData.sourceWidth=e.source.x1-e.source.x0,e.circularPathData.sourceX=e.source.x0+e.circularPathData.sourceWidth,e.circularPathData.targetX=e.target.x0,e.circularPathData.sourceY=e.y0,e.circularPathData.targetY=e.y1,Y(e,a)&&S(e))e.circularPathData.leftSmallArcRadius=w+e.width/2,e.circularPathData.leftLargeArcRadius=w+e.width/2,e.circularPathData.rightSmallArcRadius=w+e.width/2,e.circularPathData.rightLargeArcRadius=w+e.width/2,\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=e.source.y1+_+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=e.source.y0-_-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius);else{var s=e.source.column,l=e.circularLinkType,c=t.links.filter(function(t){return t.source.column==s&&t.circularLinkType==l});\"bottom\"==e.circularLinkType?c.sort(O):c.sort(P);var u=0;c.forEach(function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.leftSmallArcRadius=w+e.width/2+u,e.circularPathData.leftLargeArcRadius=w+e.width/2+n*r+u),u+=t.width}),s=e.target.column,c=t.links.filter(function(t){return t.target.column==s&&t.circularLinkType==l}),\"bottom\"==e.circularLinkType?c.sort(I):c.sort(z),u=0,c.forEach(function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.rightSmallArcRadius=w+e.width/2+u,e.circularPathData.rightLargeArcRadius=w+e.width/2+n*r+u),u+=t.width}),\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=Math.max(i,e.source.y1,e.target.y1)+_+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=o-_-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius)}e.circularPathData.leftInnerExtent=e.circularPathData.sourceX+e.circularPathData.leftNodeBuffer,e.circularPathData.rightInnerExtent=e.circularPathData.targetX-e.circularPathData.rightNodeBuffer,e.circularPathData.leftFullExtent=e.circularPathData.sourceX+e.circularPathData.leftLargeArcRadius+e.circularPathData.leftNodeBuffer,e.circularPathData.rightFullExtent=e.circularPathData.targetX-e.circularPathData.rightLargeArcRadius-e.circularPathData.rightNodeBuffer}if(e.circular)e.path=function(t){var e=\"\";e=\"top\"==t.circularLinkType?\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 0 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY-t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 0 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 0 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY-t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 0 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY:\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 1 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY+t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 1 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 1 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY+t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 1 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY;return e}(e);else{var h=n.linkHorizontal().source(function(t){return[t.source.x0+(t.source.x1-t.source.x0),t.y0]}).target(function(t){return[t.target.x0,t.y1]});e.path=h(e)}})}function L(t,e){return D(t)==D(e)?\"bottom\"==t.circularLinkType?O(t,e):P(t,e):D(e)-D(t)}function P(t,e){return t.y0-e.y0}function O(t,e){return e.y0-t.y0}function z(t,e){return t.y1-e.y1}function I(t,e){return e.y1-t.y1}function D(t){return t.target.column-t.source.column}function R(t){return t.target.x0-t.source.x1}function F(t,e){var r=A(t),n=R(e)/Math.tan(r);return\"up\"==G(t)?t.y1+n:t.y1-n}function B(t,e){var r=A(t),n=R(e)/Math.tan(r);return\"up\"==G(t)?t.y1-n:t.y1+n}function N(t,e,r,n){t.links.forEach(function(i){if(!i.circular&&i.target.column-i.source.column>1){var a=i.source.column+1,o=i.target.column-1,s=1,l=o-a+1;for(s=1;a<=o;a++,s++)t.nodes.forEach(function(o){if(o.column==a){var c,u=s/(l+1),h=Math.pow(1-u,3),f=3*u*Math.pow(1-u,2),p=3*Math.pow(u,2)*(1-u),d=Math.pow(u,3),g=h*i.y0+f*i.y0+p*i.y1+d*i.y1,v=g-i.width/2,m=g+i.width/2;v>o.y0&&v<o.y1?(c=o.y1-v+10,c=\"bottom\"==o.circularLinkType?c:-c,o=U(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&j(o,t)&&U(t,c,e,r)})):m>o.y0&&m<o.y1?(c=m-o.y0+10,o=U(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&U(t,c,e,r)})):v<o.y0&&m>o.y1&&(c=m-o.y0+10,o=U(o,c,e,r),t.nodes.forEach(function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&U(t,c,e,r)}))}})}})}function j(t,e){return t.y0>e.y0&&t.y0<e.y1||(t.y1>e.y0&&t.y1<e.y1||t.y0<e.y0&&t.y1>e.y1)}function U(t,e,r,n){return t.y0+e>=r&&t.y1+e<=n&&(t.y0=t.y0+e,t.y1=t.y1+e,t.targetLinks.forEach(function(t){t.y1=t.y1+e}),t.sourceLinks.forEach(function(t){t.y0=t.y0+e})),t}function V(t,e,r,n){t.nodes.forEach(function(i){n&&i.y+(i.y1-i.y0)>e&&(i.y=i.y-(i.y+(i.y1-i.y0)-e));var a=t.links.filter(function(t){return b(t.source,r)==b(i,r)}),o=a.length;o>1&&a.sort(function(t,e){if(!t.circular&&!e.circular){if(t.target.column==e.target.column)return t.y1-e.y1;if(!H(t,e))return t.y1-e.y1;if(t.target.column>e.target.column){var r=B(e,t);return t.y1-r}if(e.target.column>t.target.column)return B(t,e)-e.y1}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.target.column===e.target.column?t.target.y1-e.target.y1:e.target.column-t.target.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.target.column===e.target.column?e.target.y1-t.target.y1:t.target.column-e.target.column:\"top\"==t.circularLinkType?-1:1:void 0});var s=i.y0;a.forEach(function(t){t.y0=s+t.width/2,s+=t.width}),a.forEach(function(t,e){if(\"bottom\"==t.circularLinkType){for(var r=e+1,n=0;r<o;r++)n+=a[r].width;t.y0=i.y1-n-t.width/2}})})}function q(t,e,r){t.nodes.forEach(function(e){var n=t.links.filter(function(t){return b(t.target,r)==b(e,r)}),i=n.length;i>1&&n.sort(function(t,e){if(!t.circular&&!e.circular){if(t.source.column==e.source.column)return t.y0-e.y0;if(!H(t,e))return t.y0-e.y0;if(e.source.column<t.source.column){var r=F(e,t);return t.y0-r}if(t.source.column<e.source.column)return F(t,e)-e.y0}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:t.source.column-e.source.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:e.source.column-t.source.column:\"top\"==t.circularLinkType?-1:1:void 0});var a=e.y0;n.forEach(function(t){t.y1=a+t.width/2,a+=t.width}),n.forEach(function(t,r){if(\"bottom\"==t.circularLinkType){for(var a=r+1,o=0;a<i;a++)o+=n[a].width;t.y1=e.y1-o-t.width/2}})})}function H(t,e){return G(t)==G(e)}function G(t){return t.y0-t.y1>0?\"up\":\"down\"}function Y(t,e){return b(t.source,e)==b(t.target,e)}t.sankeyCircular=function(){var t,n,a=0,b=0,A=1,S=1,E=24,L=v,P=o,O=m,z=y,I=32,D=2,R=null;function F(){var o={nodes:O.apply(null,arguments),links:z.apply(null,arguments)};!function(t){t.nodes.forEach(function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]});var e=r.map(t.nodes,L);t.links.forEach(function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!==(\"undefined\"==typeof n?\"undefined\":l(n))&&(n=t.source=x(e,n)),\"object\"!==(\"undefined\"==typeof i?\"undefined\":l(i))&&(i=t.target=x(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)})}(o),function(t,e,r){var n=0;if(null===r){for(var a=[],o=0;o<t.links.length;o++){var s=t.links[o],l=s.source.index,c=s.target.index;a[l]||(a[l]=[]),a[c]||(a[c]=[]),-1===a[l].indexOf(c)&&a[l].push(c)}var u=i(a);u.sort(function(t,e){return t.length-e.length});var h={};for(o=0;o<u.length;o++){var f=u[o],p=f.slice(-2);h[p[0]]||(h[p[0]]={}),h[p[0]][p[1]]=!0}t.links.forEach(function(t){var e=t.target.index,r=t.source.index;e===r||h[r]&&h[r][e]?(t.circular=!0,t.circularLinkID=n,n+=1):t.circular=!1})}else t.links.forEach(function(t){t.source[r]<t.target[r]?t.circular=!1:(t.circular=!0,t.circularLinkID=n,n+=1)})}(o,0,R),function(t){t.nodes.forEach(function(t){t.partOfCycle=!1,t.value=Math.max(e.sum(t.sourceLinks,f),e.sum(t.targetLinks,f)),t.sourceLinks.forEach(function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)}),t.targetLinks.forEach(function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)})})}(o),function(t){var e,r,n;for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach(function(t){t.depth=n,t.sourceLinks.forEach(function(t){r.indexOf(t.target)<0&&!t.circular&&r.push(t.target)})});for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach(function(t){t.height=n,t.targetLinks.forEach(function(t){r.indexOf(t.source)<0&&!t.circular&&r.push(t.source)})});t.nodes.forEach(function(t){t.column=Math.floor(P.call(null,t,n))})}(o),T(o,L),function(i,o,s){var l=r.nest().key(function(t){return t.column}).sortKeys(e.ascending).entries(i.nodes).map(function(t){return t.values});(function(r){if(n){var o=1/0;l.forEach(function(t){var e=S*n/(t.length+1);o=e<o?e:o}),t=o}var s=e.min(l,function(r){return(S-b-(r.length-1)*t)/e.sum(r,f)});s*=k,i.links.forEach(function(t){t.width=t.value*s});var c=function(t){var r=0,n=0,i=0,a=0,o=e.max(t.nodes,function(t){return t.column});return t.links.forEach(function(t){t.circular&&(\"top\"==t.circularLinkType?r+=t.width:n+=t.width,0==t.target.column&&(a+=t.width),t.source.column==o&&(i+=t.width))}),{top:r=r>0?r+_+w:r,bottom:n=n>0?n+_+w:n,left:a=a>0?a+_+w:a,right:i=i>0?i+_+w:i}}(i),u=function(t,r){var n=e.max(t.nodes,function(t){return t.column}),i=A-a,o=S-b,s=i+r.right+r.left,l=o+r.top+r.bottom,c=i/s,u=o/l;return a=a*c+r.left,A=0==r.right?A:A*c,b=b*u+r.top,S*=u,t.nodes.forEach(function(t){t.x0=a+t.column*((A-a-E)/n),t.x1=t.x0+E}),u}(i,c);s*=u,i.links.forEach(function(t){t.width=t.value*s}),l.forEach(function(t){var e=t.length;t.forEach(function(t,n){t.depth==l.length-1&&1==e?(t.y0=S/2-t.value*s,t.y1=t.y0+t.value*s):0==t.depth&&1==e?(t.y0=S/2-t.value*s,t.y1=t.y0+t.value*s):t.partOfCycle?0==M(t,r)?(t.y0=S/2+n,t.y1=t.y0+t.value*s):\"top\"==t.circularLinkType?(t.y0=b+n,t.y1=t.y0+t.value*s):(t.y0=S-t.value*s-n,t.y1=t.y0+t.value*s):0==c.top||0==c.bottom?(t.y0=(S-b)/e*n,t.y1=t.y0+t.value*s):(t.y0=(S-b)/2-e/2+n,t.y1=t.y0+t.value*s)})})})(s),m();for(var c=1,u=o;u>0;--u)v(c*=.99,s),m();function v(t,r){var n=l.length;l.forEach(function(i){var a=i.length,o=i[0].depth;i.forEach(function(i){var s;if(i.sourceLinks.length||i.targetLinks.length)if(i.partOfCycle&&M(i,r)>0);else if(0==o&&1==a)s=i.y1-i.y0,i.y0=S/2-s/2,i.y1=S/2+s/2;else if(o==n-1&&1==a)s=i.y1-i.y0,i.y0=S/2-s/2,i.y1=S/2+s/2;else{var l=e.mean(i.sourceLinks,g),c=e.mean(i.targetLinks,d),u=((l&&c?(l+c)/2:l||c)-p(i))*t;i.y0+=u,i.y1+=u}})})}function m(){l.forEach(function(e){var r,n,i,a=b,o=e.length;for(e.sort(h),i=0;i<o;++i)r=e[i],(n=a-r.y0)>0&&(r.y0+=n,r.y1+=n),a=r.y1+t;if((n=a-t-S)>0)for(a=r.y0-=n,r.y1-=n,i=o-2;i>=0;--i)r=e[i],(n=r.y1+t-a)>0&&(r.y0-=n,r.y1-=n),a=r.y0})}}(o,I,L),B(o);for(var s=0;s<4;s++)V(o,S,L),q(o,0,L),N(o,b,S,L),V(o,S,L),q(o,0,L);return function(t,r,n){var i=t.nodes,a=t.links,o=!1,s=!1;if(a.forEach(function(t){\"top\"==t.circularLinkType?o=!0:\"bottom\"==t.circularLinkType&&(s=!0)}),0==o||0==s){var l=e.min(i,function(t){return t.y0}),c=e.max(i,function(t){return t.y1}),u=c-l,h=n-r,f=h/u;i.forEach(function(t){var e=(t.y1-t.y0)*f;t.y0=(t.y0-l)*f,t.y1=t.y0+e}),a.forEach(function(t){t.y0=(t.y0-l)*f,t.y1=(t.y1-l)*f,t.width=t.width*f})}}(o,b,S),C(o,D,S,L),o}function B(t){t.nodes.forEach(function(t){t.sourceLinks.sort(u),t.targetLinks.sort(c)}),t.nodes.forEach(function(t){var e=t.y0,r=e,n=t.y1,i=n;t.sourceLinks.forEach(function(t){t.circular?(t.y0=n-t.width/2,n-=t.width):(t.y0=e+t.width/2,e+=t.width)}),t.targetLinks.forEach(function(t){t.circular?(t.y1=i-t.width/2,i-=t.width):(t.y1=r+t.width/2,r+=t.width)})})}return F.nodeId=function(t){return arguments.length?(L=\"function\"==typeof t?t:s(t),F):L},F.nodeAlign=function(t){return arguments.length?(P=\"function\"==typeof t?t:s(t),F):P},F.nodeWidth=function(t){return arguments.length?(E=+t,F):E},F.nodePadding=function(e){return arguments.length?(t=+e,F):t},F.nodes=function(t){return arguments.length?(O=\"function\"==typeof t?t:s(t),F):O},F.links=function(t){return arguments.length?(z=\"function\"==typeof t?t:s(t),F):z},F.size=function(t){return arguments.length?(a=b=0,A=+t[0],S=+t[1],F):[A-a,S-b]},F.extent=function(t){return arguments.length?(a=+t[0][0],A=+t[1][0],b=+t[0][1],S=+t[1][1],F):[[a,b],[A,S]]},F.iterations=function(t){return arguments.length?(I=+t,F):I},F.circularLinkGap=function(t){return arguments.length?(D=+t,F):D},F.nodePaddingRatio=function(t){return arguments.length?(n=+t,F):n},F.sortNodes=function(t){return arguments.length?(R=t,F):R},F.update=function(t){return T(t,L),B(t),t.links.forEach(function(t){t.circular&&(t.circularLinkType=t.y0+t.y1<S?\"top\":\"bottom\",t.source.circularLinkType=t.circularLinkType,t.target.circularLinkType=t.circularLinkType)}),V(t,S,L,!1),q(t,0,L),C(t,D,S,L),t},F},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,a)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=o,Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\"),t(\"elementary-circuits-directed-graph\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,null)},{\"d3-array\":152,\"d3-collection\":153,\"d3-shape\":161,\"elementary-circuits-directed-graph\":172}],54:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n){\"use strict\";function i(t){return t.target.depth}function a(t,e){return t.sourceLinks.length?t.depth:e-1}function o(t){return function(){return t}}function s(t,e){return c(t.source,e.source)||t.index-e.index}function l(t,e){return c(t.target,e.target)||t.index-e.index}function c(t,e){return t.y0-e.y0}function u(t){return t.value}function h(t){return(t.y0+t.y1)/2}function f(t){return h(t.source)*t.value}function p(t){return h(t.target)*t.value}function d(t){return t.index}function g(t){return t.nodes}function v(t){return t.links}function m(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function y(t){return[t.source.x1,t.y0]}function x(t){return[t.target.x0,t.y1]}t.sankey=function(){var t=0,n=0,i=1,y=1,x=24,b=8,_=d,w=a,k=g,T=v,A=32,M=2/3;function S(){var a={nodes:k.apply(null,arguments),links:T.apply(null,arguments)};return function(t){t.nodes.forEach(function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]});var e=r.map(t.nodes,_);t.links.forEach(function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!=typeof n&&(n=t.source=m(e,n)),\"object\"!=typeof i&&(i=t.target=m(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)})}(a),function(t){t.nodes.forEach(function(t){t.value=Math.max(e.sum(t.sourceLinks,u),e.sum(t.targetLinks,u))})}(a),function(e){var r,n,a;for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach(function(t){t.depth=a,t.sourceLinks.forEach(function(t){n.indexOf(t.target)<0&&n.push(t.target)})});for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach(function(t){t.height=a,t.targetLinks.forEach(function(t){n.indexOf(t.source)<0&&n.push(t.source)})});var o=(i-t-x)/(a-1);e.nodes.forEach(function(e){e.x1=(e.x0=t+Math.max(0,Math.min(a-1,Math.floor(w.call(null,e,a))))*o)+x})}(a),function(t){var i=r.nest().key(function(t){return t.x0}).sortKeys(e.ascending).entries(t.nodes).map(function(t){return t.values});(function(){var r=e.max(i,function(t){return t.length}),a=M*(y-n)/(r-1);b>a&&(b=a);var o=e.min(i,function(t){return(y-n-(t.length-1)*b)/e.sum(t,u)});i.forEach(function(t){t.forEach(function(t,e){t.y1=(t.y0=e)+t.value*o})}),t.links.forEach(function(t){t.width=t.value*o})})(),d();for(var a=1,o=A;o>0;--o)l(a*=.99),d(),s(a),d();function s(t){i.forEach(function(r){r.forEach(function(r){if(r.targetLinks.length){var n=(e.sum(r.targetLinks,f)/e.sum(r.targetLinks,u)-h(r))*t;r.y0+=n,r.y1+=n}})})}function l(t){i.slice().reverse().forEach(function(r){r.forEach(function(r){if(r.sourceLinks.length){var n=(e.sum(r.sourceLinks,p)/e.sum(r.sourceLinks,u)-h(r))*t;r.y0+=n,r.y1+=n}})})}function d(){i.forEach(function(t){var e,r,i,a=n,o=t.length;for(t.sort(c),i=0;i<o;++i)e=t[i],(r=a-e.y0)>0&&(e.y0+=r,e.y1+=r),a=e.y1+b;if((r=a-b-y)>0)for(a=e.y0-=r,e.y1-=r,i=o-2;i>=0;--i)e=t[i],(r=e.y1+b-a)>0&&(e.y0-=r,e.y1-=r),a=e.y0})}}(a),E(a),a}function E(t){t.nodes.forEach(function(t){t.sourceLinks.sort(l),t.targetLinks.sort(s)}),t.nodes.forEach(function(t){var e=t.y0,r=e;t.sourceLinks.forEach(function(t){t.y0=e+t.width/2,e+=t.width}),t.targetLinks.forEach(function(t){t.y1=r+t.width/2,r+=t.width})})}return S.update=function(t){return E(t),t},S.nodeId=function(t){return arguments.length?(_=\"function\"==typeof t?t:o(t),S):_},S.nodeAlign=function(t){return arguments.length?(w=\"function\"==typeof t?t:o(t),S):w},S.nodeWidth=function(t){return arguments.length?(x=+t,S):x},S.nodePadding=function(t){return arguments.length?(b=+t,S):b},S.nodes=function(t){return arguments.length?(k=\"function\"==typeof t?t:o(t),S):k},S.links=function(t){return arguments.length?(T=\"function\"==typeof t?t:o(t),S):T},S.size=function(e){return arguments.length?(t=n=0,i=+e[0],y=+e[1],S):[i-t,y-n]},S.extent=function(e){return arguments.length?(t=+e[0][0],i=+e[1][0],n=+e[0][1],y=+e[1][1],S):[[t,n],[i,y]]},S.iterations=function(t){return arguments.length?(A=+t,S):A},S},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,i)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=a,t.sankeyLinkHorizontal=function(){return n.linkHorizontal().source(y).target(x)},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3)},{\"d3-array\":152,\"d3-collection\":153,\"d3-shape\":161}],55:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\"),i=6378137;function a(t){var e=0;if(t&&t.length>0){e+=Math.abs(o(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(o(t[r]))}return e}function o(t){var e,r,n,a,o,l,c=0,u=t.length;if(u>2){for(l=0;l<u;l++)l===u-2?(n=u-2,a=u-1,o=0):l===u-1?(n=u-1,a=0,o=1):(n=l,a=l+1,o=l+2),e=t[n],r=t[a],c+=(s(t[o][0])-s(e[0]))*Math.sin(s(r[1]));c=c*i*i/2}return c}function s(t){return t*Math.PI/180}r.default=function(t){return n.geomReduce(t,function(t,e){return t+function(t){var e,r=0;switch(t.type){case\"Polygon\":return a(t.coordinates);case\"MultiPolygon\":for(e=0;e<t.coordinates.length;e++)r+=a(t.coordinates[e]);return r;case\"Point\":case\"MultiPoint\":case\"LineString\":case\"MultiLineString\":return 0}return 0}(e)},0)}},{\"@turf/meta\":58}],56:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\"),i=t(\"@turf/helpers\");r.default=function(t,e){void 0===e&&(e={});var r=0,a=0,o=0;return n.coordEach(t,function(t){r+=t[0],a+=t[1],o++}),i.point([r/o,a/o],e.properties)}},{\"@turf/helpers\":57,\"@turf/meta\":58}],57:[function(t,e,r){\"use strict\";function n(t,e,r){void 0===r&&(r={});var n={type:\"Feature\"};return(0===r.id||r.id)&&(n.id=r.id),r.bbox&&(n.bbox=r.bbox),n.properties=e||{},n.geometry=t,n}function i(t,e,r){return void 0===r&&(r={}),n({type:\"Point\",coordinates:t},e,r)}function a(t,e,r){void 0===r&&(r={});for(var i=0,a=t;i<a.length;i++){var o=a[i];if(o.length<4)throw new Error(\"Each LinearRing of a Polygon must have 4 or more Positions.\");for(var s=0;s<o[o.length-1].length;s++)if(o[o.length-1][s]!==o[0][s])throw new Error(\"First and last Position are not equivalent.\")}return n({type:\"Polygon\",coordinates:t},e,r)}function o(t,e,r){if(void 0===r&&(r={}),t.length<2)throw new Error(\"coordinates must be an array of two or more positions\");return n({type:\"LineString\",coordinates:t},e,r)}function s(t,e){void 0===e&&(e={});var r={type:\"FeatureCollection\"};return e.id&&(r.id=e.id),e.bbox&&(r.bbox=e.bbox),r.features=t,r}function l(t,e,r){return void 0===r&&(r={}),n({type:\"MultiLineString\",coordinates:t},e,r)}function c(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPoint\",coordinates:t},e,r)}function u(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPolygon\",coordinates:t},e,r)}function h(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t*n}function f(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t/n}function p(t){return 180*(t%(2*Math.PI))/Math.PI}function d(t){return!isNaN(t)&&null!==t&&!Array.isArray(t)&&!/^\\s*$/.test(t)}Object.defineProperty(r,\"__esModule\",{value:!0}),r.earthRadius=6371008.8,r.factors={centimeters:100*r.earthRadius,centimetres:100*r.earthRadius,degrees:r.earthRadius/111325,feet:3.28084*r.earthRadius,inches:39.37*r.earthRadius,kilometers:r.earthRadius/1e3,kilometres:r.earthRadius/1e3,meters:r.earthRadius,metres:r.earthRadius,miles:r.earthRadius/1609.344,millimeters:1e3*r.earthRadius,millimetres:1e3*r.earthRadius,nauticalmiles:r.earthRadius/1852,radians:1,yards:r.earthRadius/1.0936},r.unitsFactors={centimeters:100,centimetres:100,degrees:1/111325,feet:3.28084,inches:39.37,kilometers:.001,kilometres:.001,meters:1,metres:1,miles:1/1609.344,millimeters:1e3,millimetres:1e3,nauticalmiles:1/1852,radians:1/r.earthRadius,yards:1/1.0936},r.areaFactors={acres:247105e-9,centimeters:1e4,centimetres:1e4,feet:10.763910417,inches:1550.003100006,kilometers:1e-6,kilometres:1e-6,meters:1,metres:1,miles:3.86e-7,millimeters:1e6,millimetres:1e6,yards:1.195990046},r.feature=n,r.geometry=function(t,e,r){switch(void 0===r&&(r={}),t){case\"Point\":return i(e).geometry;case\"LineString\":return o(e).geometry;case\"Polygon\":return a(e).geometry;case\"MultiPoint\":return c(e).geometry;case\"MultiLineString\":return l(e).geometry;case\"MultiPolygon\":return u(e).geometry;default:throw new Error(t+\" is invalid\")}},r.point=i,r.points=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return i(t,e)}),r)},r.polygon=a,r.polygons=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return a(t,e)}),r)},r.lineString=o,r.lineStrings=function(t,e,r){return void 0===r&&(r={}),s(t.map(function(t){return o(t,e)}),r)},r.featureCollection=s,r.multiLineString=l,r.multiPoint=c,r.multiPolygon=u,r.geometryCollection=function(t,e,r){return void 0===r&&(r={}),n({type:\"GeometryCollection\",geometries:t},e,r)},r.round=function(t,e){if(void 0===e&&(e=0),e&&!(e>=0))throw new Error(\"precision must be a positive number\");var r=Math.pow(10,e||0);return Math.round(t*r)/r},r.radiansToLength=h,r.lengthToRadians=f,r.lengthToDegrees=function(t,e){return p(f(t,e))},r.bearingToAzimuth=function(t){var e=t%360;return e<0&&(e+=360),e},r.radiansToDegrees=p,r.degreesToRadians=function(t){return t%360*Math.PI/180},r.convertLength=function(t,e,r){if(void 0===e&&(e=\"kilometers\"),void 0===r&&(r=\"kilometers\"),!(t>=0))throw new Error(\"length must be a positive number\");return h(f(t,e),r)},r.convertArea=function(t,e,n){if(void 0===e&&(e=\"meters\"),void 0===n&&(n=\"kilometers\"),!(t>=0))throw new Error(\"area must be a positive number\");var i=r.areaFactors[e];if(!i)throw new Error(\"invalid original units\");var a=r.areaFactors[n];if(!a)throw new Error(\"invalid final units\");return t/i*a},r.isNumber=d,r.isObject=function(t){return!!t&&t.constructor===Object},r.validateBBox=function(t){if(!t)throw new Error(\"bbox is required\");if(!Array.isArray(t))throw new Error(\"bbox must be an Array\");if(4!==t.length&&6!==t.length)throw new Error(\"bbox must be an Array of 4 or 6 numbers\");t.forEach(function(t){if(!d(t))throw new Error(\"bbox must only contain numbers\")})},r.validateId=function(t){if(!t)throw new Error(\"id is required\");if(-1===[\"string\",\"number\"].indexOf(typeof t))throw new Error(\"id must be a number or a string\")},r.radians2degrees=function(){throw new Error(\"method has been renamed to `radiansToDegrees`\")},r.degrees2radians=function(){throw new Error(\"method has been renamed to `degreesToRadians`\")},r.distanceToDegrees=function(){throw new Error(\"method has been renamed to `lengthToDegrees`\")},r.distanceToRadians=function(){throw new Error(\"method has been renamed to `lengthToRadians`\")},r.radiansToDistance=function(){throw new Error(\"method has been renamed to `radiansToLength`\")},r.bearingToAngle=function(){throw new Error(\"method has been renamed to `bearingToAzimuth`\")},r.convertDistance=function(){throw new Error(\"method has been renamed to `convertLength`\")}},{}],58:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/helpers\");function i(t,e,r){if(null!==t)for(var n,a,o,s,l,c,u,h,f=0,p=0,d=t.type,g=\"FeatureCollection\"===d,v=\"Feature\"===d,m=g?t.features.length:1,y=0;y<m;y++){l=(h=!!(u=g?t.features[y].geometry:v?t.geometry:t)&&\"GeometryCollection\"===u.type)?u.geometries.length:1;for(var x=0;x<l;x++){var b=0,_=0;if(null!==(s=h?u.geometries[x]:u)){c=s.coordinates;var w=s.type;switch(f=!r||\"Polygon\"!==w&&\"MultiPolygon\"!==w?0:1,w){case null:break;case\"Point\":if(!1===e(c,p,y,b,_))return!1;p++,b++;break;case\"LineString\":case\"MultiPoint\":for(n=0;n<c.length;n++){if(!1===e(c[n],p,y,b,_))return!1;p++,\"MultiPoint\"===w&&b++}\"LineString\"===w&&b++;break;case\"Polygon\":case\"MultiLineString\":for(n=0;n<c.length;n++){for(a=0;a<c[n].length-f;a++){if(!1===e(c[n][a],p,y,b,_))return!1;p++}\"MultiLineString\"===w&&b++,\"Polygon\"===w&&_++}\"Polygon\"===w&&b++;break;case\"MultiPolygon\":for(n=0;n<c.length;n++){for(_=0,a=0;a<c[n].length;a++){for(o=0;o<c[n][a].length-f;o++){if(!1===e(c[n][a][o],p,y,b,_))return!1;p++}_++}b++}break;case\"GeometryCollection\":for(n=0;n<s.geometries.length;n++)if(!1===i(s.geometries[n],e,r))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}}}}}function a(t,e){var r;switch(t.type){case\"FeatureCollection\":for(r=0;r<t.features.length&&!1!==e(t.features[r].properties,r);r++);break;case\"Feature\":e(t.properties,0)}}function o(t,e){if(\"Feature\"===t.type)e(t,0);else if(\"FeatureCollection\"===t.type)for(var r=0;r<t.features.length&&!1!==e(t.features[r],r);r++);}function s(t,e){var r,n,i,a,o,s,l,c,u,h,f=0,p=\"FeatureCollection\"===t.type,d=\"Feature\"===t.type,g=p?t.features.length:1;for(r=0;r<g;r++){for(s=p?t.features[r].geometry:d?t.geometry:t,c=p?t.features[r].properties:d?t.properties:{},u=p?t.features[r].bbox:d?t.bbox:void 0,h=p?t.features[r].id:d?t.id:void 0,o=(l=!!s&&\"GeometryCollection\"===s.type)?s.geometries.length:1,i=0;i<o;i++)if(null!==(a=l?s.geometries[i]:s))switch(a.type){case\"Point\":case\"LineString\":case\"MultiPoint\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":if(!1===e(a,f,c,u,h))return!1;break;case\"GeometryCollection\":for(n=0;n<a.geometries.length;n++)if(!1===e(a.geometries[n],f,c,u,h))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}else if(!1===e(null,f,c,u,h))return!1;f++}}function l(t,e){s(t,function(t,r,i,a,o){var s,l=null===t?null:t.type;switch(l){case null:case\"Point\":case\"LineString\":case\"Polygon\":return!1!==e(n.feature(t,i,{bbox:a,id:o}),r,0)&&void 0}switch(l){case\"MultiPoint\":s=\"Point\";break;case\"MultiLineString\":s=\"LineString\";break;case\"MultiPolygon\":s=\"Polygon\"}for(var c=0;c<t.coordinates.length;c++){var u={type:s,coordinates:t.coordinates[c]};if(!1===e(n.feature(u,i),r,c))return!1}})}function c(t,e){l(t,function(t,r,a){var o=0;if(t.geometry){var s=t.geometry.type;if(\"Point\"!==s&&\"MultiPoint\"!==s){var l,c=0,u=0,h=0;return!1!==i(t,function(i,s,f,p,d){if(void 0===l||r>c||p>u||d>h)return l=i,c=r,u=p,h=d,void(o=0);var g=n.lineString([l,i],t.properties);if(!1===e(g,r,a,d,o))return!1;o++,l=i})&&void 0}}})}function u(t,e){if(!t)throw new Error(\"geojson is required\");l(t,function(t,r,i){if(null!==t.geometry){var a=t.geometry.type,o=t.geometry.coordinates;switch(a){case\"LineString\":if(!1===e(t,r,i,0,0))return!1;break;case\"Polygon\":for(var s=0;s<o.length;s++)if(!1===e(n.lineString(o[s],t.properties),r,i,s))return!1}}})}r.coordEach=i,r.coordReduce=function(t,e,r,n){var a=r;return i(t,function(t,n,i,o,s){a=0===n&&void 0===r?t:e(a,t,n,i,o,s)},n),a},r.propEach=a,r.propReduce=function(t,e,r){var n=r;return a(t,function(t,i){n=0===i&&void 0===r?t:e(n,t,i)}),n},r.featureEach=o,r.featureReduce=function(t,e,r){var n=r;return o(t,function(t,i){n=0===i&&void 0===r?t:e(n,t,i)}),n},r.coordAll=function(t){var e=[];return i(t,function(t){e.push(t)}),e},r.geomEach=s,r.geomReduce=function(t,e,r){var n=r;return s(t,function(t,i,a,o,s){n=0===i&&void 0===r?t:e(n,t,i,a,o,s)}),n},r.flattenEach=l,r.flattenReduce=function(t,e,r){var n=r;return l(t,function(t,i,a){n=0===i&&0===a&&void 0===r?t:e(n,t,i,a)}),n},r.segmentEach=c,r.segmentReduce=function(t,e,r){var n=r,i=!1;return c(t,function(t,a,o,s,l){n=!1===i&&void 0===r?t:e(n,t,a,o,s,l),i=!0}),n},r.lineEach=u,r.lineReduce=function(t,e,r){var n=r;return u(t,function(t,i,a,o){n=0===i&&void 0===r?t:e(n,t,i,a,o)}),n},r.findSegment=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.segmentIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":case\"MultiPoint\":return null;case\"LineString\":return s<0&&(s=c.length+s-1),n.lineString([c[s],c[s+1]],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s-1),n.lineString([c[o][s],c[o][s+1]],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s-1),n.lineString([c[a][s],c[a][s+1]],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s-1),n.lineString([c[a][o][s],c[a][o][s+1]],l,e)}throw new Error(\"geojson is invalid\")},r.findPoint=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.coordIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":return n.point(c,l,e);case\"MultiPoint\":return a<0&&(a=c.length+a),n.point(c[a],l,e);case\"LineString\":return s<0&&(s=c.length+s),n.point(c[s],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s),n.point(c[o][s],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s),n.point(c[a][s],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s),n.point(c[a][o][s],l,e)}throw new Error(\"geojson is invalid\")}},{\"@turf/helpers\":57}],59:[function(t,e,r){\"use strict\";var n=\"undefined\"==typeof WeakMap?t(\"weak-map\"):WeakMap,i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=new n;e.exports=function(t){var e=o.get(t),r=e&&(e._triangleBuffer.handle||e._triangleBuffer.buffer);if(!r||!t.isBuffer(r)){var n=i(t,new Float32Array([-1,-1,-1,4,4,-1]));(e=a(t,[{buffer:n,type:t.FLOAT,size:2}]))._triangleBuffer=n,o.set(t,e)}e.bind(),t.drawArrays(t.TRIANGLES,0,3),e.unbind()}},{\"gl-buffer\":241,\"gl-vao\":327,\"weak-map\":552}],60:[function(t,e,r){e.exports=function(t){var e=0,r=0,n=0,i=0;return t.map(function(t){var a=(t=t.slice())[0],o=a.toUpperCase();if(a!=o)switch(t[0]=o,a){case\"a\":t[6]+=n,t[7]+=i;break;case\"v\":t[1]+=i;break;case\"h\":t[1]+=n;break;default:for(var s=1;s<t.length;)t[s++]+=n,t[s++]+=i}switch(o){case\"Z\":n=e,i=r;break;case\"H\":n=t[1];break;case\"V\":i=t[1];break;case\"M\":n=e=t[1],i=r=t[2];break;default:n=t[t.length-2],i=t[t.length-1]}return t})}},{}],61:[function(t,e,r){var n=t(\"pad-left\");e.exports=function(t,e,r){e=\"number\"==typeof e?e:1,r=r||\": \";var i=t.split(/\\r?\\n/),a=String(i.length+e-1).length;return i.map(function(t,i){var o=i+e,s=String(o).length,l=n(o,a-s);return l+r+t}).join(\"\\n\")}},{\"pad-left\":457}],62:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[0];for(var r=t[0].length,n=[t[0]],a=[0],o=1;o<e;++o)if(n.push(t[o]),i(n,r)){if(a.push(o),a.length===r+1)return a}else n.pop();return a};var n=t(\"robust-orientation\");function i(t,e){for(var r=new Array(e+1),i=0;i<t.length;++i)r[i]=t[i];for(i=0;i<=t.length;++i){for(var a=t.length;a<=e;++a){for(var o=new Array(e),s=0;s<e;++s)o[s]=Math.pow(a+1-i,s);r[a]=o}if(n.apply(void 0,r))return!0}return!1}},{\"robust-orientation\":510}],63:[function(t,e,r){\"use strict\";e.exports=function(t,e){return n(e).filter(function(r){for(var n=new Array(r.length),a=0;a<r.length;++a)n[a]=e[r[a]];return i(n)*t<1})};var n=t(\"delaunay-triangulate\"),i=t(\"circumradius\")},{circumradius:114,\"delaunay-triangulate\":165}],64:[function(t,e,r){e.exports=function(t,e){return i(n(t,e))};var n=t(\"alpha-complex\"),i=t(\"simplicial-complex-boundary\")},{\"alpha-complex\":63,\"simplicial-complex-boundary\":517}],65:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(!t||null==t.length)throw Error(\"Argument should be an array\");e=null==e?1:Math.floor(e);for(var r=Array(2*e),n=0;n<e;n++){for(var i=-1/0,a=1/0,o=n,s=t.length;o<s;o+=e)t[o]>i&&(i=t[o]),t[o]<a&&(a=t[o]);r[n]=a,r[e+n]=i}return r}},{}],66:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\");e.exports=function(t,e,r){if(!t||null==t.length)throw Error(\"Argument should be an array\");null==e&&(e=1);null==r&&(r=n(t,e));for(var i=0;i<e;i++){var a=r[e+i],o=r[i],s=i,l=t.length;if(a===1/0&&o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:t[s]===o?0:.5;else if(a===1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:0;else if(o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===o?0:1;else{var c=a-o;for(s=i;s<l;s+=e)t[s]=0===c?.5:(t[s]-o)/c}}return t}},{\"array-bounds\":65}],67:[function(t,e,r){e.exports=function(t,e){var r=\"number\"==typeof t,n=\"number\"==typeof e;r&&!n?(e=t,t=0):r||n||(t=0,e=0);var i=(e|=0)-(t|=0);if(i<0)throw new Error(\"array length must be positive\");for(var a=new Array(i),o=0,s=t;o<i;o++,s++)a[o]=s;return a}},{}],68:[function(t,e,r){(function(r){\"use strict\";var n=t(\"object-assign\");function i(t,e){if(t===e)return 0;for(var r=t.length,n=e.length,i=0,a=Math.min(r,n);i<a;++i)if(t[i]!==e[i]){r=t[i],n=e[i];break}return r<n?-1:n<r?1:0}function a(t){return r.Buffer&&\"function\"==typeof r.Buffer.isBuffer?r.Buffer.isBuffer(t):!(null==t||!t._isBuffer)}var o=t(\"util/\"),s=Object.prototype.hasOwnProperty,l=Array.prototype.slice,c=\"foo\"===function(){}.name;function u(t){return Object.prototype.toString.call(t)}function h(t){return!a(t)&&(\"function\"==typeof r.ArrayBuffer&&(\"function\"==typeof ArrayBuffer.isView?ArrayBuffer.isView(t):!!t&&(t instanceof DataView||!!(t.buffer&&t.buffer instanceof ArrayBuffer))))}var f=e.exports=y,p=/\\s*function\\s+([^\\(\\s]*)\\s*/;function d(t){if(o.isFunction(t)){if(c)return t.name;var e=t.toString().match(p);return e&&e[1]}}function g(t,e){return\"string\"==typeof t?t.length<e?t:t.slice(0,e):t}function v(t){if(c||!o.isFunction(t))return o.inspect(t);var e=d(t);return\"[Function\"+(e?\": \"+e:\"\")+\"]\"}function m(t,e,r,n,i){throw new f.AssertionError({message:r,actual:t,expected:e,operator:n,stackStartFunction:i})}function y(t,e){t||m(t,!0,e,\"==\",f.ok)}function x(t,e,r,n){if(t===e)return!0;if(a(t)&&a(e))return 0===i(t,e);if(o.isDate(t)&&o.isDate(e))return t.getTime()===e.getTime();if(o.isRegExp(t)&&o.isRegExp(e))return t.source===e.source&&t.global===e.global&&t.multiline===e.multiline&&t.lastIndex===e.lastIndex&&t.ignoreCase===e.ignoreCase;if(null!==t&&\"object\"==typeof t||null!==e&&\"object\"==typeof e){if(h(t)&&h(e)&&u(t)===u(e)&&!(t instanceof Float32Array||t instanceof Float64Array))return 0===i(new Uint8Array(t.buffer),new Uint8Array(e.buffer));if(a(t)!==a(e))return!1;var s=(n=n||{actual:[],expected:[]}).actual.indexOf(t);return-1!==s&&s===n.expected.indexOf(e)||(n.actual.push(t),n.expected.push(e),function(t,e,r,n){if(null==t||null==e)return!1;if(o.isPrimitive(t)||o.isPrimitive(e))return t===e;if(r&&Object.getPrototypeOf(t)!==Object.getPrototypeOf(e))return!1;var i=b(t),a=b(e);if(i&&!a||!i&&a)return!1;if(i)return t=l.call(t),e=l.call(e),x(t,e,r);var s,c,u=k(t),h=k(e);if(u.length!==h.length)return!1;for(u.sort(),h.sort(),c=u.length-1;c>=0;c--)if(u[c]!==h[c])return!1;for(c=u.length-1;c>=0;c--)if(s=u[c],!x(t[s],e[s],r,n))return!1;return!0}(t,e,r,n))}return r?t===e:t==e}function b(t){return\"[object Arguments]\"==Object.prototype.toString.call(t)}function _(t,e){if(!t||!e)return!1;if(\"[object RegExp]\"==Object.prototype.toString.call(e))return e.test(t);try{if(t instanceof e)return!0}catch(t){}return!Error.isPrototypeOf(e)&&!0===e.call({},t)}function w(t,e,r,n){var i;if(\"function\"!=typeof e)throw new TypeError('\"block\" argument must be a function');\"string\"==typeof r&&(n=r,r=null),i=function(t){var e;try{t()}catch(t){e=t}return e}(e),n=(r&&r.name?\" (\"+r.name+\").\":\".\")+(n?\" \"+n:\".\"),t&&!i&&m(i,r,\"Missing expected exception\"+n);var a=\"string\"==typeof n,s=!t&&i&&!r;if((!t&&o.isError(i)&&a&&_(i,r)||s)&&m(i,r,\"Got unwanted exception\"+n),t&&i&&r&&!_(i,r)||!t&&i)throw i}f.AssertionError=function(t){var e;this.name=\"AssertionError\",this.actual=t.actual,this.expected=t.expected,this.operator=t.operator,t.message?(this.message=t.message,this.generatedMessage=!1):(this.message=g(v((e=this).actual),128)+\" \"+e.operator+\" \"+g(v(e.expected),128),this.generatedMessage=!0);var r=t.stackStartFunction||m;if(Error.captureStackTrace)Error.captureStackTrace(this,r);else{var n=new Error;if(n.stack){var i=n.stack,a=d(r),o=i.indexOf(\"\\n\"+a);if(o>=0){var s=i.indexOf(\"\\n\",o+1);i=i.substring(s+1)}this.stack=i}}},o.inherits(f.AssertionError,Error),f.fail=m,f.ok=y,f.equal=function(t,e,r){t!=e&&m(t,e,r,\"==\",f.equal)},f.notEqual=function(t,e,r){t==e&&m(t,e,r,\"!=\",f.notEqual)},f.deepEqual=function(t,e,r){x(t,e,!1)||m(t,e,r,\"deepEqual\",f.deepEqual)},f.deepStrictEqual=function(t,e,r){x(t,e,!0)||m(t,e,r,\"deepStrictEqual\",f.deepStrictEqual)},f.notDeepEqual=function(t,e,r){x(t,e,!1)&&m(t,e,r,\"notDeepEqual\",f.notDeepEqual)},f.notDeepStrictEqual=function t(e,r,n){x(e,r,!0)&&m(e,r,n,\"notDeepStrictEqual\",t)},f.strictEqual=function(t,e,r){t!==e&&m(t,e,r,\"===\",f.strictEqual)},f.notStrictEqual=function(t,e,r){t===e&&m(t,e,r,\"!==\",f.notStrictEqual)},f.throws=function(t,e,r){w(!0,t,e,r)},f.doesNotThrow=function(t,e,r){w(!1,t,e,r)},f.ifError=function(t){if(t)throw t},f.strict=n(function t(e,r){e||m(e,!0,r,\"==\",t)},f,{equal:f.strictEqual,deepEqual:f.deepStrictEqual,notEqual:f.notStrictEqual,notDeepEqual:f.notDeepStrictEqual}),f.strict.strict=f.strict;var k=Object.keys||function(t){var e=[];for(var r in t)s.call(t,r)&&e.push(r);return e}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"object-assign\":454,\"util/\":71}],69:[function(t,e,r){\"function\"==typeof Object.create?e.exports=function(t,e){t.super_=e,t.prototype=Object.create(e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}})}:e.exports=function(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}},{}],70:[function(t,e,r){e.exports=function(t){return t&&\"object\"==typeof t&&\"function\"==typeof t.copy&&\"function\"==typeof t.fill&&\"function\"==typeof t.readUInt8}},{}],71:[function(t,e,r){(function(e,n){var i=/%[sdj%]/g;r.format=function(t){if(!m(t)){for(var e=[],r=0;r<arguments.length;r++)e.push(s(arguments[r]));return e.join(\" \")}r=1;for(var n=arguments,a=n.length,o=String(t).replace(i,function(t){if(\"%%\"===t)return\"%\";if(r>=a)return t;switch(t){case\"%s\":return String(n[r++]);case\"%d\":return Number(n[r++]);case\"%j\":try{return JSON.stringify(n[r++])}catch(t){return\"[Circular]\"}default:return t}}),l=n[r];r<a;l=n[++r])g(l)||!b(l)?o+=\" \"+l:o+=\" \"+s(l);return o},r.deprecate=function(t,i){if(y(n.process))return function(){return r.deprecate(t,i).apply(this,arguments)};if(!0===e.noDeprecation)return t;var a=!1;return function(){if(!a){if(e.throwDeprecation)throw new Error(i);e.traceDeprecation?console.trace(i):console.error(i),a=!0}return t.apply(this,arguments)}};var a,o={};function s(t,e){var n={seen:[],stylize:c};return arguments.length>=3&&(n.depth=arguments[2]),arguments.length>=4&&(n.colors=arguments[3]),d(e)?n.showHidden=e:e&&r._extend(n,e),y(n.showHidden)&&(n.showHidden=!1),y(n.depth)&&(n.depth=2),y(n.colors)&&(n.colors=!1),y(n.customInspect)&&(n.customInspect=!0),n.colors&&(n.stylize=l),u(n,t,n.depth)}function l(t,e){var r=s.styles[e];return r?\"\\x1b[\"+s.colors[r][0]+\"m\"+t+\"\\x1b[\"+s.colors[r][1]+\"m\":t}function c(t,e){return t}function u(t,e,n){if(t.customInspect&&e&&k(e.inspect)&&e.inspect!==r.inspect&&(!e.constructor||e.constructor.prototype!==e)){var i=e.inspect(n,t);return m(i)||(i=u(t,i,n)),i}var a=function(t,e){if(y(e))return t.stylize(\"undefined\",\"undefined\");if(m(e)){var r=\"'\"+JSON.stringify(e).replace(/^\"|\"$/g,\"\").replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"')+\"'\";return t.stylize(r,\"string\")}if(v(e))return t.stylize(\"\"+e,\"number\");if(d(e))return t.stylize(\"\"+e,\"boolean\");if(g(e))return t.stylize(\"null\",\"null\")}(t,e);if(a)return a;var o=Object.keys(e),s=function(t){var e={};return t.forEach(function(t,r){e[t]=!0}),e}(o);if(t.showHidden&&(o=Object.getOwnPropertyNames(e)),w(e)&&(o.indexOf(\"message\")>=0||o.indexOf(\"description\")>=0))return h(e);if(0===o.length){if(k(e)){var l=e.name?\": \"+e.name:\"\";return t.stylize(\"[Function\"+l+\"]\",\"special\")}if(x(e))return t.stylize(RegExp.prototype.toString.call(e),\"regexp\");if(_(e))return t.stylize(Date.prototype.toString.call(e),\"date\");if(w(e))return h(e)}var c,b=\"\",T=!1,A=[\"{\",\"}\"];(p(e)&&(T=!0,A=[\"[\",\"]\"]),k(e))&&(b=\" [Function\"+(e.name?\": \"+e.name:\"\")+\"]\");return x(e)&&(b=\" \"+RegExp.prototype.toString.call(e)),_(e)&&(b=\" \"+Date.prototype.toUTCString.call(e)),w(e)&&(b=\" \"+h(e)),0!==o.length||T&&0!=e.length?n<0?x(e)?t.stylize(RegExp.prototype.toString.call(e),\"regexp\"):t.stylize(\"[Object]\",\"special\"):(t.seen.push(e),c=T?function(t,e,r,n,i){for(var a=[],o=0,s=e.length;o<s;++o)S(e,String(o))?a.push(f(t,e,r,n,String(o),!0)):a.push(\"\");return i.forEach(function(i){i.match(/^\\d+$/)||a.push(f(t,e,r,n,i,!0))}),a}(t,e,n,s,o):o.map(function(r){return f(t,e,n,s,r,T)}),t.seen.pop(),function(t,e,r){if(t.reduce(function(t,e){return 0,e.indexOf(\"\\n\")>=0&&0,t+e.replace(/\\u001b\\[\\d\\d?m/g,\"\").length+1},0)>60)return r[0]+(\"\"===e?\"\":e+\"\\n \")+\" \"+t.join(\",\\n  \")+\" \"+r[1];return r[0]+e+\" \"+t.join(\", \")+\" \"+r[1]}(c,b,A)):A[0]+b+A[1]}function h(t){return\"[\"+Error.prototype.toString.call(t)+\"]\"}function f(t,e,r,n,i,a){var o,s,l;if((l=Object.getOwnPropertyDescriptor(e,i)||{value:e[i]}).get?s=l.set?t.stylize(\"[Getter/Setter]\",\"special\"):t.stylize(\"[Getter]\",\"special\"):l.set&&(s=t.stylize(\"[Setter]\",\"special\")),S(n,i)||(o=\"[\"+i+\"]\"),s||(t.seen.indexOf(l.value)<0?(s=g(r)?u(t,l.value,null):u(t,l.value,r-1)).indexOf(\"\\n\")>-1&&(s=a?s.split(\"\\n\").map(function(t){return\"  \"+t}).join(\"\\n\").substr(2):\"\\n\"+s.split(\"\\n\").map(function(t){return\"   \"+t}).join(\"\\n\")):s=t.stylize(\"[Circular]\",\"special\")),y(o)){if(a&&i.match(/^\\d+$/))return s;(o=JSON.stringify(\"\"+i)).match(/^\"([a-zA-Z_][a-zA-Z_0-9]*)\"$/)?(o=o.substr(1,o.length-2),o=t.stylize(o,\"name\")):(o=o.replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"').replace(/(^\"|\"$)/g,\"'\"),o=t.stylize(o,\"string\"))}return o+\": \"+s}function p(t){return Array.isArray(t)}function d(t){return\"boolean\"==typeof t}function g(t){return null===t}function v(t){return\"number\"==typeof t}function m(t){return\"string\"==typeof t}function y(t){return void 0===t}function x(t){return b(t)&&\"[object RegExp]\"===T(t)}function b(t){return\"object\"==typeof t&&null!==t}function _(t){return b(t)&&\"[object Date]\"===T(t)}function w(t){return b(t)&&(\"[object Error]\"===T(t)||t instanceof Error)}function k(t){return\"function\"==typeof t}function T(t){return Object.prototype.toString.call(t)}function A(t){return t<10?\"0\"+t.toString(10):t.toString(10)}r.debuglog=function(t){if(y(a)&&(a=e.env.NODE_DEBUG||\"\"),t=t.toUpperCase(),!o[t])if(new RegExp(\"\\\\b\"+t+\"\\\\b\",\"i\").test(a)){var n=e.pid;o[t]=function(){var e=r.format.apply(r,arguments);console.error(\"%s %d: %s\",t,n,e)}}else o[t]=function(){};return o[t]},r.inspect=s,s.colors={bold:[1,22],italic:[3,23],underline:[4,24],inverse:[7,27],white:[37,39],grey:[90,39],black:[30,39],blue:[34,39],cyan:[36,39],green:[32,39],magenta:[35,39],red:[31,39],yellow:[33,39]},s.styles={special:\"cyan\",number:\"yellow\",boolean:\"yellow\",undefined:\"grey\",null:\"bold\",string:\"green\",date:\"magenta\",regexp:\"red\"},r.isArray=p,r.isBoolean=d,r.isNull=g,r.isNullOrUndefined=function(t){return null==t},r.isNumber=v,r.isString=m,r.isSymbol=function(t){return\"symbol\"==typeof t},r.isUndefined=y,r.isRegExp=x,r.isObject=b,r.isDate=_,r.isError=w,r.isFunction=k,r.isPrimitive=function(t){return null===t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||\"symbol\"==typeof t||\"undefined\"==typeof t},r.isBuffer=t(\"./support/isBuffer\");var M=[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"];function S(t,e){return Object.prototype.hasOwnProperty.call(t,e)}r.log=function(){var t,e;console.log(\"%s - %s\",(t=new Date,e=[A(t.getHours()),A(t.getMinutes()),A(t.getSeconds())].join(\":\"),[t.getDate(),M[t.getMonth()],e].join(\" \")),r.format.apply(r,arguments))},r.inherits=t(\"inherits\"),r._extend=function(t,e){if(!e||!b(e))return t;for(var r=Object.keys(e),n=r.length;n--;)t[r[n]]=e[r[n]];return t}}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./support/isBuffer\":70,_process:482,inherits:69}],72:[function(t,e,r){e.exports=function(t){return atob(t)}},{}],73:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=e.length,a=new Array(r+1),o=0;o<r;++o){for(var s=new Array(r+1),l=0;l<=r;++l)s[l]=t[l][o];a[o]=s}a[r]=new Array(r+1);for(var o=0;o<=r;++o)a[r][o]=1;for(var c=new Array(r+1),o=0;o<r;++o)c[o]=e[o];c[r]=1;var u=n(a,c),h=i(u[r+1]);0===h&&(h=1);for(var f=new Array(r+1),o=0;o<=r;++o)f[o]=i(u[o])/h;return f};var n=t(\"robust-linear-solve\");function i(t){for(var e=0,r=0;r<t.length;++r)e+=t[r];return e}},{\"robust-linear-solve\":509}],74:[function(t,e,r){\"use strict\";r.byteLength=function(t){var e=c(t),r=e[0],n=e[1];return 3*(r+n)/4-n},r.toByteArray=function(t){for(var e,r=c(t),n=r[0],o=r[1],s=new a(function(t,e,r){return 3*(e+r)/4-r}(0,n,o)),l=0,u=o>0?n-4:n,h=0;h<u;h+=4)e=i[t.charCodeAt(h)]<<18|i[t.charCodeAt(h+1)]<<12|i[t.charCodeAt(h+2)]<<6|i[t.charCodeAt(h+3)],s[l++]=e>>16&255,s[l++]=e>>8&255,s[l++]=255&e;2===o&&(e=i[t.charCodeAt(h)]<<2|i[t.charCodeAt(h+1)]>>4,s[l++]=255&e);1===o&&(e=i[t.charCodeAt(h)]<<10|i[t.charCodeAt(h+1)]<<4|i[t.charCodeAt(h+2)]>>2,s[l++]=e>>8&255,s[l++]=255&e);return s},r.fromByteArray=function(t){for(var e,r=t.length,i=r%3,a=[],o=0,s=r-i;o<s;o+=16383)a.push(u(t,o,o+16383>s?s:o+16383));1===i?(e=t[r-1],a.push(n[e>>2]+n[e<<4&63]+\"==\")):2===i&&(e=(t[r-2]<<8)+t[r-1],a.push(n[e>>10]+n[e>>4&63]+n[e<<2&63]+\"=\"));return a.join(\"\")};for(var n=[],i=[],a=\"undefined\"!=typeof Uint8Array?Uint8Array:Array,o=\"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/\",s=0,l=o.length;s<l;++s)n[s]=o[s],i[o.charCodeAt(s)]=s;function c(t){var e=t.length;if(e%4>0)throw new Error(\"Invalid string. Length must be a multiple of 4\");var r=t.indexOf(\"=\");return-1===r&&(r=e),[r,r===e?0:4-r%4]}function u(t,e,r){for(var i,a,o=[],s=e;s<r;s+=3)i=(t[s]<<16&16711680)+(t[s+1]<<8&65280)+(255&t[s+2]),o.push(n[(a=i)>>18&63]+n[a>>12&63]+n[a>>6&63]+n[63&a]);return o.join(\"\")}i[\"-\".charCodeAt(0)]=62,i[\"_\".charCodeAt(0)]=63},{}],75:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).add(e[0].mul(t[1])),t[1].mul(e[1]))}},{\"./lib/rationalize\":85}],76:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t[0].mul(e[1]).cmp(e[0].mul(t[1]))}},{}],77:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]),t[1].mul(e[0]))}},{\"./lib/rationalize\":85}],78:[function(t,e,r){\"use strict\";var n=t(\"./is-rat\"),i=t(\"./lib/is-bn\"),a=t(\"./lib/num-to-bn\"),o=t(\"./lib/str-to-bn\"),s=t(\"./lib/rationalize\"),l=t(\"./div\");e.exports=function t(e,r){if(n(e))return r?l(e,t(r)):[e[0].clone(),e[1].clone()];var c=0;var u,h;if(i(e))u=e.clone();else if(\"string\"==typeof e)u=o(e);else{if(0===e)return[a(0),a(1)];if(e===Math.floor(e))u=a(e);else{for(;e!==Math.floor(e);)e*=Math.pow(2,256),c-=256;u=a(e)}}if(n(r))u.mul(r[1]),h=r[0].clone();else if(i(r))h=r.clone();else if(\"string\"==typeof r)h=o(r);else if(r)if(r===Math.floor(r))h=a(r);else{for(;r!==Math.floor(r);)r*=Math.pow(2,256),c+=256;h=a(r)}else h=a(1);c>0?u=u.ushln(c):c<0&&(h=h.ushln(-c));return s(u,h)}},{\"./div\":77,\"./is-rat\":79,\"./lib/is-bn\":83,\"./lib/num-to-bn\":84,\"./lib/rationalize\":85,\"./lib/str-to-bn\":86}],79:[function(t,e,r){\"use strict\";var n=t(\"./lib/is-bn\");e.exports=function(t){return Array.isArray(t)&&2===t.length&&n(t[0])&&n(t[1])}},{\"./lib/is-bn\":83}],80:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return t.cmp(new n(0))}},{\"bn.js\":94}],81:[function(t,e,r){\"use strict\";var n=t(\"./bn-sign\");e.exports=function(t){var e=t.length,r=t.words,i=0;if(1===e)i=r[0];else if(2===e)i=r[0]+67108864*r[1];else for(var a=0;a<e;a++){var o=r[a];i+=o*Math.pow(67108864,a)}return n(t)*i}},{\"./bn-sign\":80}],82:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=t(\"bit-twiddle\").countTrailingZeros;e.exports=function(t){var e=i(n.lo(t));if(e<32)return e;var r=i(n.hi(t));if(r>20)return 52;return r+32}},{\"bit-twiddle\":92,\"double-bits\":167}],83:[function(t,e,r){\"use strict\";t(\"bn.js\");e.exports=function(t){return t&&\"object\"==typeof t&&Boolean(t.words)}},{\"bn.js\":94}],84:[function(t,e,r){\"use strict\";var n=t(\"bn.js\"),i=t(\"double-bits\");e.exports=function(t){var e=i.exponent(t);return e<52?new n(t):new n(t*Math.pow(2,52-e)).ushln(e-52)}},{\"bn.js\":94,\"double-bits\":167}],85:[function(t,e,r){\"use strict\";var n=t(\"./num-to-bn\"),i=t(\"./bn-sign\");e.exports=function(t,e){var r=i(t),a=i(e);if(0===r)return[n(0),n(1)];if(0===a)return[n(0),n(0)];a<0&&(t=t.neg(),e=e.neg());var o=t.gcd(e);if(o.cmpn(1))return[t.div(o),e.div(o)];return[t,e]}},{\"./bn-sign\":80,\"./num-to-bn\":84}],86:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return new n(t)}},{\"bn.js\":94}],87:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[0]),t[1].mul(e[1]))}},{\"./lib/rationalize\":85}],88:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-sign\");e.exports=function(t){return n(t[0])*n(t[1])}},{\"./lib/bn-sign\":80}],89:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).sub(t[1].mul(e[0])),t[1].mul(e[1]))}},{\"./lib/rationalize\":85}],90:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-to-num\"),i=t(\"./lib/ctz\");e.exports=function(t){var e=t[0],r=t[1];if(0===e.cmpn(0))return 0;var a=e.abs().divmod(r.abs()),o=a.div,s=n(o),l=a.mod,c=e.negative!==r.negative?-1:1;if(0===l.cmpn(0))return c*s;if(s){var u=i(s)+4,h=n(l.ushln(u).divRound(r));return c*(s+h*Math.pow(2,-u))}var f=r.bitLength()-l.bitLength()+53,h=n(l.ushln(f).divRound(r));return f<1023?c*h*Math.pow(2,-f):(h*=Math.pow(2,-1023),c*h*Math.pow(2,1023-f))}},{\"./lib/bn-to-num\":81,\"./lib/ctz\":82}],91:[function(t,e,r){\"use strict\";function n(t,e,r,n,i,a){var o=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",a?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a\",i?\".get(m)\":\"[m]\"];return a?e.indexOf(\"c\")<0?o.push(\";if(x===y){return m}else if(x<=y){\"):o.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):o.push(\";if(\",e,\"){i=m;\"),r?o.push(\"l=m+1}else{h=m-1}\"):o.push(\"h=m-1}else{l=m+1}\"),o.push(\"}\"),a?o.push(\"return -1};\"):o.push(\"return i};\"),o.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],!1,i),n(\"B\",\"x\"+t+\"y\",e,[\"y\"],!0,i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!1,i),n(\"Q\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!0,i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(a.shape){if(typeof(c)==='function'){return Q(a,(l===undefined)?0:l|0,(h===undefined)?a.shape[0]-1:h|0,y,c)}else{return B(a,(c===undefined)?0:c|0,(l===undefined)?a.shape[0]-1:l|0,y)}}else{if(typeof(c)==='function'){return P(a,(l===undefined)?0:l|0,(h===undefined)?a.length-1:h|0,y,c)}else{return A(a,(c===undefined)?0:c|0,(l===undefined)?a.length-1:l|0,y)}}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],92:[function(t,e,r){\"use strict\";function n(t){var e=32;return(t&=-t)&&e--,65535&t&&(e-=16),16711935&t&&(e-=8),252645135&t&&(e-=4),858993459&t&&(e-=2),1431655765&t&&(e-=1),e}r.INT_BITS=32,r.INT_MAX=2147483647,r.INT_MIN=-1<<31,r.sign=function(t){return(t>0)-(t<0)},r.abs=function(t){var e=t>>31;return(t^e)-e},r.min=function(t,e){return e^(t^e)&-(t<e)},r.max=function(t,e){return t^(t^e)&-(t<e)},r.isPow2=function(t){return!(t&t-1||!t)},r.log2=function(t){var e,r;return e=(t>65535)<<4,e|=r=((t>>>=e)>255)<<3,e|=r=((t>>>=r)>15)<<2,(e|=r=((t>>>=r)>3)<<1)|(t>>>=r)>>1},r.log10=function(t){return t>=1e9?9:t>=1e8?8:t>=1e7?7:t>=1e6?6:t>=1e5?5:t>=1e4?4:t>=1e3?3:t>=100?2:t>=10?1:0},r.popCount=function(t){return 16843009*((t=(858993459&(t-=t>>>1&1431655765))+(t>>>2&858993459))+(t>>>4)&252645135)>>>24},r.countTrailingZeros=n,r.nextPow2=function(t){return t+=0===t,--t,t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)+1},r.prevPow2=function(t){return t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)-(t>>>1)},r.parity=function(t){return t^=t>>>16,t^=t>>>8,t^=t>>>4,27030>>>(t&=15)&1};var i=new Array(256);!function(t){for(var e=0;e<256;++e){var r=e,n=e,i=7;for(r>>>=1;r;r>>>=1)n<<=1,n|=1&r,--i;t[e]=n<<i&255}}(i),r.reverse=function(t){return i[255&t]<<24|i[t>>>8&255]<<16|i[t>>>16&255]<<8|i[t>>>24&255]},r.interleave2=function(t,e){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t&=65535)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e&=65535)|e<<8))|e<<4))|e<<2))|e<<1))<<1},r.deinterleave2=function(t,e){return(t=65535&((t=16711935&((t=252645135&((t=858993459&((t=t>>>e&1431655765)|t>>>1))|t>>>2))|t>>>4))|t>>>16))<<16>>16},r.interleave3=function(t,e,r){return t=1227133513&((t=3272356035&((t=251719695&((t=4278190335&((t&=1023)|t<<16))|t<<8))|t<<4))|t<<2),(t|=(e=1227133513&((e=3272356035&((e=251719695&((e=4278190335&((e&=1023)|e<<16))|e<<8))|e<<4))|e<<2))<<1)|(r=1227133513&((r=3272356035&((r=251719695&((r=4278190335&((r&=1023)|r<<16))|r<<8))|r<<4))|r<<2))<<2},r.deinterleave3=function(t,e){return(t=1023&((t=4278190335&((t=251719695&((t=3272356035&((t=t>>>e&1227133513)|t>>>2))|t>>>4))|t>>>8))|t>>>16))<<22>>22},r.nextCombination=function(t){var e=t|t-1;return e+1|(~e&-~e)-1>>>n(t)+1}},{}],93:[function(t,e,r){\"use strict\";var n=t(\"clamp\");e.exports=function(t,e){e||(e={});var r,o,s,l,c,u,h,f,p,d,g,v=null==e.cutoff?.25:e.cutoff,m=null==e.radius?8:e.radius,y=e.channel||0;if(ArrayBuffer.isView(t)||Array.isArray(t)){if(!e.width||!e.height)throw Error(\"For raw data width and height should be provided by options\");r=e.width,o=e.height,l=t,u=e.stride?e.stride:Math.floor(t.length/r/o)}else window.HTMLCanvasElement&&t instanceof window.HTMLCanvasElement?(h=(f=t).getContext(\"2d\"),r=f.width,o=f.height,p=h.getImageData(0,0,r,o),l=p.data,u=4):window.CanvasRenderingContext2D&&t instanceof window.CanvasRenderingContext2D?(f=t.canvas,h=t,r=f.width,o=f.height,p=h.getImageData(0,0,r,o),l=p.data,u=4):window.ImageData&&t instanceof window.ImageData&&(p=t,r=t.width,o=t.height,l=p.data,u=4);if(s=Math.max(r,o),window.Uint8ClampedArray&&l instanceof window.Uint8ClampedArray||window.Uint8Array&&l instanceof window.Uint8Array)for(c=l,l=Array(r*o),d=0,g=c.length;d<g;d++)l[d]=c[d*u+y]/255;else if(1!==u)throw Error(\"Raw data can have only 1 value per pixel\");var x=Array(r*o),b=Array(r*o),_=Array(s),w=Array(s),k=Array(s+1),T=Array(s);for(d=0,g=r*o;d<g;d++){var A=l[d];x[d]=1===A?0:0===A?i:Math.pow(Math.max(0,.5-A),2),b[d]=1===A?i:0===A?0:Math.pow(Math.max(0,A-.5),2)}a(x,r,o,_,w,T,k),a(b,r,o,_,w,T,k);var M=window.Float32Array?new Float32Array(r*o):new Array(r*o);for(d=0,g=r*o;d<g;d++)M[d]=n(1-((x[d]-b[d])/m+v),0,1);return M};var i=1e20;function a(t,e,r,n,i,a,s){for(var l=0;l<e;l++){for(var c=0;c<r;c++)n[c]=t[c*e+l];for(o(n,i,a,s,r),c=0;c<r;c++)t[c*e+l]=i[c]}for(c=0;c<r;c++){for(l=0;l<e;l++)n[l]=t[c*e+l];for(o(n,i,a,s,e),l=0;l<e;l++)t[c*e+l]=Math.sqrt(i[l])}}function o(t,e,r,n,a){r[0]=0,n[0]=-i,n[1]=+i;for(var o=1,s=0;o<a;o++){for(var l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);l<=n[s];)s--,l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);r[++s]=o,n[s]=l,n[s+1]=+i}for(o=0,s=0;o<a;o++){for(;n[s+1]<o;)s++;e[o]=(o-r[s])*(o-r[s])+t[r[s]]}}},{clamp:115}],94:[function(t,e,r){!function(e,r){\"use strict\";function n(t,e){if(!t)throw new Error(e||\"Assertion failed\")}function i(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}function a(t,e,r){if(a.isBN(t))return t;this.negative=0,this.words=null,this.length=0,this.red=null,null!==t&&(\"le\"!==e&&\"be\"!==e||(r=e,e=10),this._init(t||0,e||10,r||\"be\"))}var o;\"object\"==typeof e?e.exports=a:r.BN=a,a.BN=a,a.wordSize=26;try{o=t(\"buffer\").Buffer}catch(t){}function s(t,e,r){for(var n=0,i=Math.min(t.length,r),a=e;a<i;a++){var o=t.charCodeAt(a)-48;n<<=4,n|=o>=49&&o<=54?o-49+10:o>=17&&o<=22?o-17+10:15&o}return n}function l(t,e,r,n){for(var i=0,a=Math.min(t.length,r),o=e;o<a;o++){var s=t.charCodeAt(o)-48;i*=n,i+=s>=49?s-49+10:s>=17?s-17+10:s}return i}a.isBN=function(t){return t instanceof a||null!==t&&\"object\"==typeof t&&t.constructor.wordSize===a.wordSize&&Array.isArray(t.words)},a.max=function(t,e){return t.cmp(e)>0?t:e},a.min=function(t,e){return t.cmp(e)<0?t:e},a.prototype._init=function(t,e,r){if(\"number\"==typeof t)return this._initNumber(t,e,r);if(\"object\"==typeof t)return this._initArray(t,e,r);\"hex\"===e&&(e=16),n(e===(0|e)&&e>=2&&e<=36);var i=0;\"-\"===(t=t.toString().replace(/\\s+/g,\"\"))[0]&&i++,16===e?this._parseHex(t,i):this._parseBase(t,e,i),\"-\"===t[0]&&(this.negative=1),this.strip(),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initNumber=function(t,e,r){t<0&&(this.negative=1,t=-t),t<67108864?(this.words=[67108863&t],this.length=1):t<4503599627370496?(this.words=[67108863&t,t/67108864&67108863],this.length=2):(n(t<9007199254740992),this.words=[67108863&t,t/67108864&67108863,1],this.length=3),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initArray=function(t,e,r){if(n(\"number\"==typeof t.length),t.length<=0)return this.words=[0],this.length=1,this;this.length=Math.ceil(t.length/3),this.words=new Array(this.length);for(var i=0;i<this.length;i++)this.words[i]=0;var a,o,s=0;if(\"be\"===r)for(i=t.length-1,a=0;i>=0;i-=3)o=t[i]|t[i-1]<<8|t[i-2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);else if(\"le\"===r)for(i=0,a=0;i<t.length;i+=3)o=t[i]|t[i+1]<<8|t[i+2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);return this.strip()},a.prototype._parseHex=function(t,e){this.length=Math.ceil((t.length-e)/6),this.words=new Array(this.length);for(var r=0;r<this.length;r++)this.words[r]=0;var n,i,a=0;for(r=t.length-6,n=0;r>=e;r-=6)i=s(t,r,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303,(a+=24)>=26&&(a-=26,n++);r+6!==e&&(i=s(t,e,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303),this.strip()},a.prototype._parseBase=function(t,e,r){this.words=[0],this.length=1;for(var n=0,i=1;i<=67108863;i*=e)n++;n--,i=i/e|0;for(var a=t.length-r,o=a%n,s=Math.min(a,a-o)+r,c=0,u=r;u<s;u+=n)c=l(t,u,u+n,e),this.imuln(i),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c);if(0!==o){var h=1;for(c=l(t,u,t.length,e),u=0;u<o;u++)h*=e;this.imuln(h),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c)}},a.prototype.copy=function(t){t.words=new Array(this.length);for(var e=0;e<this.length;e++)t.words[e]=this.words[e];t.length=this.length,t.negative=this.negative,t.red=this.red},a.prototype.clone=function(){var t=new a(null);return this.copy(t),t},a.prototype._expand=function(t){for(;this.length<t;)this.words[this.length++]=0;return this},a.prototype.strip=function(){for(;this.length>1&&0===this.words[this.length-1];)this.length--;return this._normSign()},a.prototype._normSign=function(){return 1===this.length&&0===this.words[0]&&(this.negative=0),this},a.prototype.inspect=function(){return(this.red?\"<BN-R: \":\"<BN: \")+this.toString(16)+\">\"};var c=[\"\",\"0\",\"00\",\"000\",\"0000\",\"00000\",\"000000\",\"0000000\",\"00000000\",\"000000000\",\"0000000000\",\"00000000000\",\"000000000000\",\"0000000000000\",\"00000000000000\",\"000000000000000\",\"0000000000000000\",\"00000000000000000\",\"000000000000000000\",\"0000000000000000000\",\"00000000000000000000\",\"000000000000000000000\",\"0000000000000000000000\",\"00000000000000000000000\",\"000000000000000000000000\",\"0000000000000000000000000\"],u=[0,0,25,16,12,11,10,9,8,8,7,7,7,7,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5],h=[0,0,33554432,43046721,16777216,48828125,60466176,40353607,16777216,43046721,1e7,19487171,35831808,62748517,7529536,11390625,16777216,24137569,34012224,47045881,64e6,4084101,5153632,6436343,7962624,9765625,11881376,14348907,17210368,20511149,243e5,28629151,33554432,39135393,45435424,52521875,60466176];function f(t,e,r){r.negative=e.negative^t.negative;var n=t.length+e.length|0;r.length=n,n=n-1|0;var i=0|t.words[0],a=0|e.words[0],o=i*a,s=67108863&o,l=o/67108864|0;r.words[0]=s;for(var c=1;c<n;c++){for(var u=l>>>26,h=67108863&l,f=Math.min(c,e.length-1),p=Math.max(0,c-t.length+1);p<=f;p++){var d=c-p|0;u+=(o=(i=0|t.words[d])*(a=0|e.words[p])+h)/67108864|0,h=67108863&o}r.words[c]=0|h,l=0|u}return 0!==l?r.words[c]=0|l:r.length--,r.strip()}a.prototype.toString=function(t,e){var r;if(e=0|e||1,16===(t=t||10)||\"hex\"===t){r=\"\";for(var i=0,a=0,o=0;o<this.length;o++){var s=this.words[o],l=(16777215&(s<<i|a)).toString(16);r=0!==(a=s>>>24-i&16777215)||o!==this.length-1?c[6-l.length]+l+r:l+r,(i+=2)>=26&&(i-=26,o--)}for(0!==a&&(r=a.toString(16)+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}if(t===(0|t)&&t>=2&&t<=36){var f=u[t],p=h[t];r=\"\";var d=this.clone();for(d.negative=0;!d.isZero();){var g=d.modn(p).toString(t);r=(d=d.idivn(p)).isZero()?g+r:c[f-g.length]+g+r}for(this.isZero()&&(r=\"0\"+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}n(!1,\"Base should be between 2 and 36\")},a.prototype.toNumber=function(){var t=this.words[0];return 2===this.length?t+=67108864*this.words[1]:3===this.length&&1===this.words[2]?t+=4503599627370496+67108864*this.words[1]:this.length>2&&n(!1,\"Number can only safely store up to 53 bits\"),0!==this.negative?-t:t},a.prototype.toJSON=function(){return this.toString(16)},a.prototype.toBuffer=function(t,e){return n(\"undefined\"!=typeof o),this.toArrayLike(o,t,e)},a.prototype.toArray=function(t,e){return this.toArrayLike(Array,t,e)},a.prototype.toArrayLike=function(t,e,r){var i=this.byteLength(),a=r||Math.max(1,i);n(i<=a,\"byte array longer than desired length\"),n(a>0,\"Requested array length <= 0\"),this.strip();var o,s,l=\"le\"===e,c=new t(a),u=this.clone();if(l){for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[s]=o;for(;s<a;s++)c[s]=0}else{for(s=0;s<a-i;s++)c[s]=0;for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[a-s-1]=o}return c},Math.clz32?a.prototype._countBits=function(t){return 32-Math.clz32(t)}:a.prototype._countBits=function(t){var e=t,r=0;return e>=4096&&(r+=13,e>>>=13),e>=64&&(r+=7,e>>>=7),e>=8&&(r+=4,e>>>=4),e>=2&&(r+=2,e>>>=2),r+e},a.prototype._zeroBits=function(t){if(0===t)return 26;var e=t,r=0;return 0==(8191&e)&&(r+=13,e>>>=13),0==(127&e)&&(r+=7,e>>>=7),0==(15&e)&&(r+=4,e>>>=4),0==(3&e)&&(r+=2,e>>>=2),0==(1&e)&&r++,r},a.prototype.bitLength=function(){var t=this.words[this.length-1],e=this._countBits(t);return 26*(this.length-1)+e},a.prototype.zeroBits=function(){if(this.isZero())return 0;for(var t=0,e=0;e<this.length;e++){var r=this._zeroBits(this.words[e]);if(t+=r,26!==r)break}return t},a.prototype.byteLength=function(){return Math.ceil(this.bitLength()/8)},a.prototype.toTwos=function(t){return 0!==this.negative?this.abs().inotn(t).iaddn(1):this.clone()},a.prototype.fromTwos=function(t){return this.testn(t-1)?this.notn(t).iaddn(1).ineg():this.clone()},a.prototype.isNeg=function(){return 0!==this.negative},a.prototype.neg=function(){return this.clone().ineg()},a.prototype.ineg=function(){return this.isZero()||(this.negative^=1),this},a.prototype.iuor=function(t){for(;this.length<t.length;)this.words[this.length++]=0;for(var e=0;e<t.length;e++)this.words[e]=this.words[e]|t.words[e];return this.strip()},a.prototype.ior=function(t){return n(0==(this.negative|t.negative)),this.iuor(t)},a.prototype.or=function(t){return this.length>t.length?this.clone().ior(t):t.clone().ior(this)},a.prototype.uor=function(t){return this.length>t.length?this.clone().iuor(t):t.clone().iuor(this)},a.prototype.iuand=function(t){var e;e=this.length>t.length?t:this;for(var r=0;r<e.length;r++)this.words[r]=this.words[r]&t.words[r];return this.length=e.length,this.strip()},a.prototype.iand=function(t){return n(0==(this.negative|t.negative)),this.iuand(t)},a.prototype.and=function(t){return this.length>t.length?this.clone().iand(t):t.clone().iand(this)},a.prototype.uand=function(t){return this.length>t.length?this.clone().iuand(t):t.clone().iuand(this)},a.prototype.iuxor=function(t){var e,r;this.length>t.length?(e=this,r=t):(e=t,r=this);for(var n=0;n<r.length;n++)this.words[n]=e.words[n]^r.words[n];if(this!==e)for(;n<e.length;n++)this.words[n]=e.words[n];return this.length=e.length,this.strip()},a.prototype.ixor=function(t){return n(0==(this.negative|t.negative)),this.iuxor(t)},a.prototype.xor=function(t){return this.length>t.length?this.clone().ixor(t):t.clone().ixor(this)},a.prototype.uxor=function(t){return this.length>t.length?this.clone().iuxor(t):t.clone().iuxor(this)},a.prototype.inotn=function(t){n(\"number\"==typeof t&&t>=0);var e=0|Math.ceil(t/26),r=t%26;this._expand(e),r>0&&e--;for(var i=0;i<e;i++)this.words[i]=67108863&~this.words[i];return r>0&&(this.words[i]=~this.words[i]&67108863>>26-r),this.strip()},a.prototype.notn=function(t){return this.clone().inotn(t)},a.prototype.setn=function(t,e){n(\"number\"==typeof t&&t>=0);var r=t/26|0,i=t%26;return this._expand(r+1),this.words[r]=e?this.words[r]|1<<i:this.words[r]&~(1<<i),this.strip()},a.prototype.iadd=function(t){var e,r,n;if(0!==this.negative&&0===t.negative)return this.negative=0,e=this.isub(t),this.negative^=1,this._normSign();if(0===this.negative&&0!==t.negative)return t.negative=0,e=this.isub(t),t.negative=1,e._normSign();this.length>t.length?(r=this,n=t):(r=t,n=this);for(var i=0,a=0;a<n.length;a++)e=(0|r.words[a])+(0|n.words[a])+i,this.words[a]=67108863&e,i=e>>>26;for(;0!==i&&a<r.length;a++)e=(0|r.words[a])+i,this.words[a]=67108863&e,i=e>>>26;if(this.length=r.length,0!==i)this.words[this.length]=i,this.length++;else if(r!==this)for(;a<r.length;a++)this.words[a]=r.words[a];return this},a.prototype.add=function(t){var e;return 0!==t.negative&&0===this.negative?(t.negative=0,e=this.sub(t),t.negative^=1,e):0===t.negative&&0!==this.negative?(this.negative=0,e=t.sub(this),this.negative=1,e):this.length>t.length?this.clone().iadd(t):t.clone().iadd(this)},a.prototype.isub=function(t){if(0!==t.negative){t.negative=0;var e=this.iadd(t);return t.negative=1,e._normSign()}if(0!==this.negative)return this.negative=0,this.iadd(t),this.negative=1,this._normSign();var r,n,i=this.cmp(t);if(0===i)return this.negative=0,this.length=1,this.words[0]=0,this;i>0?(r=this,n=t):(r=t,n=this);for(var a=0,o=0;o<n.length;o++)a=(e=(0|r.words[o])-(0|n.words[o])+a)>>26,this.words[o]=67108863&e;for(;0!==a&&o<r.length;o++)a=(e=(0|r.words[o])+a)>>26,this.words[o]=67108863&e;if(0===a&&o<r.length&&r!==this)for(;o<r.length;o++)this.words[o]=r.words[o];return this.length=Math.max(this.length,o),r!==this&&(this.negative=1),this.strip()},a.prototype.sub=function(t){return this.clone().isub(t)};var p=function(t,e,r){var n,i,a,o=t.words,s=e.words,l=r.words,c=0,u=0|o[0],h=8191&u,f=u>>>13,p=0|o[1],d=8191&p,g=p>>>13,v=0|o[2],m=8191&v,y=v>>>13,x=0|o[3],b=8191&x,_=x>>>13,w=0|o[4],k=8191&w,T=w>>>13,A=0|o[5],M=8191&A,S=A>>>13,E=0|o[6],C=8191&E,L=E>>>13,P=0|o[7],O=8191&P,z=P>>>13,I=0|o[8],D=8191&I,R=I>>>13,F=0|o[9],B=8191&F,N=F>>>13,j=0|s[0],U=8191&j,V=j>>>13,q=0|s[1],H=8191&q,G=q>>>13,Y=0|s[2],W=8191&Y,X=Y>>>13,Z=0|s[3],J=8191&Z,K=Z>>>13,$=0|s[4],Q=8191&$,tt=$>>>13,et=0|s[5],rt=8191&et,nt=et>>>13,it=0|s[6],at=8191&it,ot=it>>>13,st=0|s[7],lt=8191&st,ct=st>>>13,ut=0|s[8],ht=8191&ut,ft=ut>>>13,pt=0|s[9],dt=8191&pt,gt=pt>>>13;r.negative=t.negative^e.negative,r.length=19;var vt=(c+(n=Math.imul(h,U))|0)+((8191&(i=(i=Math.imul(h,V))+Math.imul(f,U)|0))<<13)|0;c=((a=Math.imul(f,V))+(i>>>13)|0)+(vt>>>26)|0,vt&=67108863,n=Math.imul(d,U),i=(i=Math.imul(d,V))+Math.imul(g,U)|0,a=Math.imul(g,V);var mt=(c+(n=n+Math.imul(h,H)|0)|0)+((8191&(i=(i=i+Math.imul(h,G)|0)+Math.imul(f,H)|0))<<13)|0;c=((a=a+Math.imul(f,G)|0)+(i>>>13)|0)+(mt>>>26)|0,mt&=67108863,n=Math.imul(m,U),i=(i=Math.imul(m,V))+Math.imul(y,U)|0,a=Math.imul(y,V),n=n+Math.imul(d,H)|0,i=(i=i+Math.imul(d,G)|0)+Math.imul(g,H)|0,a=a+Math.imul(g,G)|0;var yt=(c+(n=n+Math.imul(h,W)|0)|0)+((8191&(i=(i=i+Math.imul(h,X)|0)+Math.imul(f,W)|0))<<13)|0;c=((a=a+Math.imul(f,X)|0)+(i>>>13)|0)+(yt>>>26)|0,yt&=67108863,n=Math.imul(b,U),i=(i=Math.imul(b,V))+Math.imul(_,U)|0,a=Math.imul(_,V),n=n+Math.imul(m,H)|0,i=(i=i+Math.imul(m,G)|0)+Math.imul(y,H)|0,a=a+Math.imul(y,G)|0,n=n+Math.imul(d,W)|0,i=(i=i+Math.imul(d,X)|0)+Math.imul(g,W)|0,a=a+Math.imul(g,X)|0;var xt=(c+(n=n+Math.imul(h,J)|0)|0)+((8191&(i=(i=i+Math.imul(h,K)|0)+Math.imul(f,J)|0))<<13)|0;c=((a=a+Math.imul(f,K)|0)+(i>>>13)|0)+(xt>>>26)|0,xt&=67108863,n=Math.imul(k,U),i=(i=Math.imul(k,V))+Math.imul(T,U)|0,a=Math.imul(T,V),n=n+Math.imul(b,H)|0,i=(i=i+Math.imul(b,G)|0)+Math.imul(_,H)|0,a=a+Math.imul(_,G)|0,n=n+Math.imul(m,W)|0,i=(i=i+Math.imul(m,X)|0)+Math.imul(y,W)|0,a=a+Math.imul(y,X)|0,n=n+Math.imul(d,J)|0,i=(i=i+Math.imul(d,K)|0)+Math.imul(g,J)|0,a=a+Math.imul(g,K)|0;var bt=(c+(n=n+Math.imul(h,Q)|0)|0)+((8191&(i=(i=i+Math.imul(h,tt)|0)+Math.imul(f,Q)|0))<<13)|0;c=((a=a+Math.imul(f,tt)|0)+(i>>>13)|0)+(bt>>>26)|0,bt&=67108863,n=Math.imul(M,U),i=(i=Math.imul(M,V))+Math.imul(S,U)|0,a=Math.imul(S,V),n=n+Math.imul(k,H)|0,i=(i=i+Math.imul(k,G)|0)+Math.imul(T,H)|0,a=a+Math.imul(T,G)|0,n=n+Math.imul(b,W)|0,i=(i=i+Math.imul(b,X)|0)+Math.imul(_,W)|0,a=a+Math.imul(_,X)|0,n=n+Math.imul(m,J)|0,i=(i=i+Math.imul(m,K)|0)+Math.imul(y,J)|0,a=a+Math.imul(y,K)|0,n=n+Math.imul(d,Q)|0,i=(i=i+Math.imul(d,tt)|0)+Math.imul(g,Q)|0,a=a+Math.imul(g,tt)|0;var _t=(c+(n=n+Math.imul(h,rt)|0)|0)+((8191&(i=(i=i+Math.imul(h,nt)|0)+Math.imul(f,rt)|0))<<13)|0;c=((a=a+Math.imul(f,nt)|0)+(i>>>13)|0)+(_t>>>26)|0,_t&=67108863,n=Math.imul(C,U),i=(i=Math.imul(C,V))+Math.imul(L,U)|0,a=Math.imul(L,V),n=n+Math.imul(M,H)|0,i=(i=i+Math.imul(M,G)|0)+Math.imul(S,H)|0,a=a+Math.imul(S,G)|0,n=n+Math.imul(k,W)|0,i=(i=i+Math.imul(k,X)|0)+Math.imul(T,W)|0,a=a+Math.imul(T,X)|0,n=n+Math.imul(b,J)|0,i=(i=i+Math.imul(b,K)|0)+Math.imul(_,J)|0,a=a+Math.imul(_,K)|0,n=n+Math.imul(m,Q)|0,i=(i=i+Math.imul(m,tt)|0)+Math.imul(y,Q)|0,a=a+Math.imul(y,tt)|0,n=n+Math.imul(d,rt)|0,i=(i=i+Math.imul(d,nt)|0)+Math.imul(g,rt)|0,a=a+Math.imul(g,nt)|0;var wt=(c+(n=n+Math.imul(h,at)|0)|0)+((8191&(i=(i=i+Math.imul(h,ot)|0)+Math.imul(f,at)|0))<<13)|0;c=((a=a+Math.imul(f,ot)|0)+(i>>>13)|0)+(wt>>>26)|0,wt&=67108863,n=Math.imul(O,U),i=(i=Math.imul(O,V))+Math.imul(z,U)|0,a=Math.imul(z,V),n=n+Math.imul(C,H)|0,i=(i=i+Math.imul(C,G)|0)+Math.imul(L,H)|0,a=a+Math.imul(L,G)|0,n=n+Math.imul(M,W)|0,i=(i=i+Math.imul(M,X)|0)+Math.imul(S,W)|0,a=a+Math.imul(S,X)|0,n=n+Math.imul(k,J)|0,i=(i=i+Math.imul(k,K)|0)+Math.imul(T,J)|0,a=a+Math.imul(T,K)|0,n=n+Math.imul(b,Q)|0,i=(i=i+Math.imul(b,tt)|0)+Math.imul(_,Q)|0,a=a+Math.imul(_,tt)|0,n=n+Math.imul(m,rt)|0,i=(i=i+Math.imul(m,nt)|0)+Math.imul(y,rt)|0,a=a+Math.imul(y,nt)|0,n=n+Math.imul(d,at)|0,i=(i=i+Math.imul(d,ot)|0)+Math.imul(g,at)|0,a=a+Math.imul(g,ot)|0;var kt=(c+(n=n+Math.imul(h,lt)|0)|0)+((8191&(i=(i=i+Math.imul(h,ct)|0)+Math.imul(f,lt)|0))<<13)|0;c=((a=a+Math.imul(f,ct)|0)+(i>>>13)|0)+(kt>>>26)|0,kt&=67108863,n=Math.imul(D,U),i=(i=Math.imul(D,V))+Math.imul(R,U)|0,a=Math.imul(R,V),n=n+Math.imul(O,H)|0,i=(i=i+Math.imul(O,G)|0)+Math.imul(z,H)|0,a=a+Math.imul(z,G)|0,n=n+Math.imul(C,W)|0,i=(i=i+Math.imul(C,X)|0)+Math.imul(L,W)|0,a=a+Math.imul(L,X)|0,n=n+Math.imul(M,J)|0,i=(i=i+Math.imul(M,K)|0)+Math.imul(S,J)|0,a=a+Math.imul(S,K)|0,n=n+Math.imul(k,Q)|0,i=(i=i+Math.imul(k,tt)|0)+Math.imul(T,Q)|0,a=a+Math.imul(T,tt)|0,n=n+Math.imul(b,rt)|0,i=(i=i+Math.imul(b,nt)|0)+Math.imul(_,rt)|0,a=a+Math.imul(_,nt)|0,n=n+Math.imul(m,at)|0,i=(i=i+Math.imul(m,ot)|0)+Math.imul(y,at)|0,a=a+Math.imul(y,ot)|0,n=n+Math.imul(d,lt)|0,i=(i=i+Math.imul(d,ct)|0)+Math.imul(g,lt)|0,a=a+Math.imul(g,ct)|0;var Tt=(c+(n=n+Math.imul(h,ht)|0)|0)+((8191&(i=(i=i+Math.imul(h,ft)|0)+Math.imul(f,ht)|0))<<13)|0;c=((a=a+Math.imul(f,ft)|0)+(i>>>13)|0)+(Tt>>>26)|0,Tt&=67108863,n=Math.imul(B,U),i=(i=Math.imul(B,V))+Math.imul(N,U)|0,a=Math.imul(N,V),n=n+Math.imul(D,H)|0,i=(i=i+Math.imul(D,G)|0)+Math.imul(R,H)|0,a=a+Math.imul(R,G)|0,n=n+Math.imul(O,W)|0,i=(i=i+Math.imul(O,X)|0)+Math.imul(z,W)|0,a=a+Math.imul(z,X)|0,n=n+Math.imul(C,J)|0,i=(i=i+Math.imul(C,K)|0)+Math.imul(L,J)|0,a=a+Math.imul(L,K)|0,n=n+Math.imul(M,Q)|0,i=(i=i+Math.imul(M,tt)|0)+Math.imul(S,Q)|0,a=a+Math.imul(S,tt)|0,n=n+Math.imul(k,rt)|0,i=(i=i+Math.imul(k,nt)|0)+Math.imul(T,rt)|0,a=a+Math.imul(T,nt)|0,n=n+Math.imul(b,at)|0,i=(i=i+Math.imul(b,ot)|0)+Math.imul(_,at)|0,a=a+Math.imul(_,ot)|0,n=n+Math.imul(m,lt)|0,i=(i=i+Math.imul(m,ct)|0)+Math.imul(y,lt)|0,a=a+Math.imul(y,ct)|0,n=n+Math.imul(d,ht)|0,i=(i=i+Math.imul(d,ft)|0)+Math.imul(g,ht)|0,a=a+Math.imul(g,ft)|0;var At=(c+(n=n+Math.imul(h,dt)|0)|0)+((8191&(i=(i=i+Math.imul(h,gt)|0)+Math.imul(f,dt)|0))<<13)|0;c=((a=a+Math.imul(f,gt)|0)+(i>>>13)|0)+(At>>>26)|0,At&=67108863,n=Math.imul(B,H),i=(i=Math.imul(B,G))+Math.imul(N,H)|0,a=Math.imul(N,G),n=n+Math.imul(D,W)|0,i=(i=i+Math.imul(D,X)|0)+Math.imul(R,W)|0,a=a+Math.imul(R,X)|0,n=n+Math.imul(O,J)|0,i=(i=i+Math.imul(O,K)|0)+Math.imul(z,J)|0,a=a+Math.imul(z,K)|0,n=n+Math.imul(C,Q)|0,i=(i=i+Math.imul(C,tt)|0)+Math.imul(L,Q)|0,a=a+Math.imul(L,tt)|0,n=n+Math.imul(M,rt)|0,i=(i=i+Math.imul(M,nt)|0)+Math.imul(S,rt)|0,a=a+Math.imul(S,nt)|0,n=n+Math.imul(k,at)|0,i=(i=i+Math.imul(k,ot)|0)+Math.imul(T,at)|0,a=a+Math.imul(T,ot)|0,n=n+Math.imul(b,lt)|0,i=(i=i+Math.imul(b,ct)|0)+Math.imul(_,lt)|0,a=a+Math.imul(_,ct)|0,n=n+Math.imul(m,ht)|0,i=(i=i+Math.imul(m,ft)|0)+Math.imul(y,ht)|0,a=a+Math.imul(y,ft)|0;var Mt=(c+(n=n+Math.imul(d,dt)|0)|0)+((8191&(i=(i=i+Math.imul(d,gt)|0)+Math.imul(g,dt)|0))<<13)|0;c=((a=a+Math.imul(g,gt)|0)+(i>>>13)|0)+(Mt>>>26)|0,Mt&=67108863,n=Math.imul(B,W),i=(i=Math.imul(B,X))+Math.imul(N,W)|0,a=Math.imul(N,X),n=n+Math.imul(D,J)|0,i=(i=i+Math.imul(D,K)|0)+Math.imul(R,J)|0,a=a+Math.imul(R,K)|0,n=n+Math.imul(O,Q)|0,i=(i=i+Math.imul(O,tt)|0)+Math.imul(z,Q)|0,a=a+Math.imul(z,tt)|0,n=n+Math.imul(C,rt)|0,i=(i=i+Math.imul(C,nt)|0)+Math.imul(L,rt)|0,a=a+Math.imul(L,nt)|0,n=n+Math.imul(M,at)|0,i=(i=i+Math.imul(M,ot)|0)+Math.imul(S,at)|0,a=a+Math.imul(S,ot)|0,n=n+Math.imul(k,lt)|0,i=(i=i+Math.imul(k,ct)|0)+Math.imul(T,lt)|0,a=a+Math.imul(T,ct)|0,n=n+Math.imul(b,ht)|0,i=(i=i+Math.imul(b,ft)|0)+Math.imul(_,ht)|0,a=a+Math.imul(_,ft)|0;var St=(c+(n=n+Math.imul(m,dt)|0)|0)+((8191&(i=(i=i+Math.imul(m,gt)|0)+Math.imul(y,dt)|0))<<13)|0;c=((a=a+Math.imul(y,gt)|0)+(i>>>13)|0)+(St>>>26)|0,St&=67108863,n=Math.imul(B,J),i=(i=Math.imul(B,K))+Math.imul(N,J)|0,a=Math.imul(N,K),n=n+Math.imul(D,Q)|0,i=(i=i+Math.imul(D,tt)|0)+Math.imul(R,Q)|0,a=a+Math.imul(R,tt)|0,n=n+Math.imul(O,rt)|0,i=(i=i+Math.imul(O,nt)|0)+Math.imul(z,rt)|0,a=a+Math.imul(z,nt)|0,n=n+Math.imul(C,at)|0,i=(i=i+Math.imul(C,ot)|0)+Math.imul(L,at)|0,a=a+Math.imul(L,ot)|0,n=n+Math.imul(M,lt)|0,i=(i=i+Math.imul(M,ct)|0)+Math.imul(S,lt)|0,a=a+Math.imul(S,ct)|0,n=n+Math.imul(k,ht)|0,i=(i=i+Math.imul(k,ft)|0)+Math.imul(T,ht)|0,a=a+Math.imul(T,ft)|0;var Et=(c+(n=n+Math.imul(b,dt)|0)|0)+((8191&(i=(i=i+Math.imul(b,gt)|0)+Math.imul(_,dt)|0))<<13)|0;c=((a=a+Math.imul(_,gt)|0)+(i>>>13)|0)+(Et>>>26)|0,Et&=67108863,n=Math.imul(B,Q),i=(i=Math.imul(B,tt))+Math.imul(N,Q)|0,a=Math.imul(N,tt),n=n+Math.imul(D,rt)|0,i=(i=i+Math.imul(D,nt)|0)+Math.imul(R,rt)|0,a=a+Math.imul(R,nt)|0,n=n+Math.imul(O,at)|0,i=(i=i+Math.imul(O,ot)|0)+Math.imul(z,at)|0,a=a+Math.imul(z,ot)|0,n=n+Math.imul(C,lt)|0,i=(i=i+Math.imul(C,ct)|0)+Math.imul(L,lt)|0,a=a+Math.imul(L,ct)|0,n=n+Math.imul(M,ht)|0,i=(i=i+Math.imul(M,ft)|0)+Math.imul(S,ht)|0,a=a+Math.imul(S,ft)|0;var Ct=(c+(n=n+Math.imul(k,dt)|0)|0)+((8191&(i=(i=i+Math.imul(k,gt)|0)+Math.imul(T,dt)|0))<<13)|0;c=((a=a+Math.imul(T,gt)|0)+(i>>>13)|0)+(Ct>>>26)|0,Ct&=67108863,n=Math.imul(B,rt),i=(i=Math.imul(B,nt))+Math.imul(N,rt)|0,a=Math.imul(N,nt),n=n+Math.imul(D,at)|0,i=(i=i+Math.imul(D,ot)|0)+Math.imul(R,at)|0,a=a+Math.imul(R,ot)|0,n=n+Math.imul(O,lt)|0,i=(i=i+Math.imul(O,ct)|0)+Math.imul(z,lt)|0,a=a+Math.imul(z,ct)|0,n=n+Math.imul(C,ht)|0,i=(i=i+Math.imul(C,ft)|0)+Math.imul(L,ht)|0,a=a+Math.imul(L,ft)|0;var Lt=(c+(n=n+Math.imul(M,dt)|0)|0)+((8191&(i=(i=i+Math.imul(M,gt)|0)+Math.imul(S,dt)|0))<<13)|0;c=((a=a+Math.imul(S,gt)|0)+(i>>>13)|0)+(Lt>>>26)|0,Lt&=67108863,n=Math.imul(B,at),i=(i=Math.imul(B,ot))+Math.imul(N,at)|0,a=Math.imul(N,ot),n=n+Math.imul(D,lt)|0,i=(i=i+Math.imul(D,ct)|0)+Math.imul(R,lt)|0,a=a+Math.imul(R,ct)|0,n=n+Math.imul(O,ht)|0,i=(i=i+Math.imul(O,ft)|0)+Math.imul(z,ht)|0,a=a+Math.imul(z,ft)|0;var Pt=(c+(n=n+Math.imul(C,dt)|0)|0)+((8191&(i=(i=i+Math.imul(C,gt)|0)+Math.imul(L,dt)|0))<<13)|0;c=((a=a+Math.imul(L,gt)|0)+(i>>>13)|0)+(Pt>>>26)|0,Pt&=67108863,n=Math.imul(B,lt),i=(i=Math.imul(B,ct))+Math.imul(N,lt)|0,a=Math.imul(N,ct),n=n+Math.imul(D,ht)|0,i=(i=i+Math.imul(D,ft)|0)+Math.imul(R,ht)|0,a=a+Math.imul(R,ft)|0;var Ot=(c+(n=n+Math.imul(O,dt)|0)|0)+((8191&(i=(i=i+Math.imul(O,gt)|0)+Math.imul(z,dt)|0))<<13)|0;c=((a=a+Math.imul(z,gt)|0)+(i>>>13)|0)+(Ot>>>26)|0,Ot&=67108863,n=Math.imul(B,ht),i=(i=Math.imul(B,ft))+Math.imul(N,ht)|0,a=Math.imul(N,ft);var zt=(c+(n=n+Math.imul(D,dt)|0)|0)+((8191&(i=(i=i+Math.imul(D,gt)|0)+Math.imul(R,dt)|0))<<13)|0;c=((a=a+Math.imul(R,gt)|0)+(i>>>13)|0)+(zt>>>26)|0,zt&=67108863;var It=(c+(n=Math.imul(B,dt))|0)+((8191&(i=(i=Math.imul(B,gt))+Math.imul(N,dt)|0))<<13)|0;return c=((a=Math.imul(N,gt))+(i>>>13)|0)+(It>>>26)|0,It&=67108863,l[0]=vt,l[1]=mt,l[2]=yt,l[3]=xt,l[4]=bt,l[5]=_t,l[6]=wt,l[7]=kt,l[8]=Tt,l[9]=At,l[10]=Mt,l[11]=St,l[12]=Et,l[13]=Ct,l[14]=Lt,l[15]=Pt,l[16]=Ot,l[17]=zt,l[18]=It,0!==c&&(l[19]=c,r.length++),r};function d(t,e,r){return(new g).mulp(t,e,r)}function g(t,e){this.x=t,this.y=e}Math.imul||(p=f),a.prototype.mulTo=function(t,e){var r=this.length+t.length;return 10===this.length&&10===t.length?p(this,t,e):r<63?f(this,t,e):r<1024?function(t,e,r){r.negative=e.negative^t.negative,r.length=t.length+e.length;for(var n=0,i=0,a=0;a<r.length-1;a++){var o=i;i=0;for(var s=67108863&n,l=Math.min(a,e.length-1),c=Math.max(0,a-t.length+1);c<=l;c++){var u=a-c,h=(0|t.words[u])*(0|e.words[c]),f=67108863&h;s=67108863&(f=f+s|0),i+=(o=(o=o+(h/67108864|0)|0)+(f>>>26)|0)>>>26,o&=67108863}r.words[a]=s,n=o,o=i}return 0!==n?r.words[a]=n:r.length--,r.strip()}(this,t,e):d(this,t,e)},g.prototype.makeRBT=function(t){for(var e=new Array(t),r=a.prototype._countBits(t)-1,n=0;n<t;n++)e[n]=this.revBin(n,r,t);return e},g.prototype.revBin=function(t,e,r){if(0===t||t===r-1)return t;for(var n=0,i=0;i<e;i++)n|=(1&t)<<e-i-1,t>>=1;return n},g.prototype.permute=function(t,e,r,n,i,a){for(var o=0;o<a;o++)n[o]=e[t[o]],i[o]=r[t[o]]},g.prototype.transform=function(t,e,r,n,i,a){this.permute(a,t,e,r,n,i);for(var o=1;o<i;o<<=1)for(var s=o<<1,l=Math.cos(2*Math.PI/s),c=Math.sin(2*Math.PI/s),u=0;u<i;u+=s)for(var h=l,f=c,p=0;p<o;p++){var d=r[u+p],g=n[u+p],v=r[u+p+o],m=n[u+p+o],y=h*v-f*m;m=h*m+f*v,v=y,r[u+p]=d+v,n[u+p]=g+m,r[u+p+o]=d-v,n[u+p+o]=g-m,p!==s&&(y=l*h-c*f,f=l*f+c*h,h=y)}},g.prototype.guessLen13b=function(t,e){var r=1|Math.max(e,t),n=1&r,i=0;for(r=r/2|0;r;r>>>=1)i++;return 1<<i+1+n},g.prototype.conjugate=function(t,e,r){if(!(r<=1))for(var n=0;n<r/2;n++){var i=t[n];t[n]=t[r-n-1],t[r-n-1]=i,i=e[n],e[n]=-e[r-n-1],e[r-n-1]=-i}},g.prototype.normalize13b=function(t,e){for(var r=0,n=0;n<e/2;n++){var i=8192*Math.round(t[2*n+1]/e)+Math.round(t[2*n]/e)+r;t[n]=67108863&i,r=i<67108864?0:i/67108864|0}return t},g.prototype.convert13b=function(t,e,r,i){for(var a=0,o=0;o<e;o++)a+=0|t[o],r[2*o]=8191&a,a>>>=13,r[2*o+1]=8191&a,a>>>=13;for(o=2*e;o<i;++o)r[o]=0;n(0===a),n(0==(-8192&a))},g.prototype.stub=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=0;return e},g.prototype.mulp=function(t,e,r){var n=2*this.guessLen13b(t.length,e.length),i=this.makeRBT(n),a=this.stub(n),o=new Array(n),s=new Array(n),l=new Array(n),c=new Array(n),u=new Array(n),h=new Array(n),f=r.words;f.length=n,this.convert13b(t.words,t.length,o,n),this.convert13b(e.words,e.length,c,n),this.transform(o,a,s,l,n,i),this.transform(c,a,u,h,n,i);for(var p=0;p<n;p++){var d=s[p]*u[p]-l[p]*h[p];l[p]=s[p]*h[p]+l[p]*u[p],s[p]=d}return this.conjugate(s,l,n),this.transform(s,l,f,a,n,i),this.conjugate(f,a,n),this.normalize13b(f,n),r.negative=t.negative^e.negative,r.length=t.length+e.length,r.strip()},a.prototype.mul=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),this.mulTo(t,e)},a.prototype.mulf=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),d(this,t,e)},a.prototype.imul=function(t){return this.clone().mulTo(t,this)},a.prototype.imuln=function(t){n(\"number\"==typeof t),n(t<67108864);for(var e=0,r=0;r<this.length;r++){var i=(0|this.words[r])*t,a=(67108863&i)+(67108863&e);e>>=26,e+=i/67108864|0,e+=a>>>26,this.words[r]=67108863&a}return 0!==e&&(this.words[r]=e,this.length++),this},a.prototype.muln=function(t){return this.clone().imuln(t)},a.prototype.sqr=function(){return this.mul(this)},a.prototype.isqr=function(){return this.imul(this.clone())},a.prototype.pow=function(t){var e=function(t){for(var e=new Array(t.bitLength()),r=0;r<e.length;r++){var n=r/26|0,i=r%26;e[r]=(t.words[n]&1<<i)>>>i}return e}(t);if(0===e.length)return new a(1);for(var r=this,n=0;n<e.length&&0===e[n];n++,r=r.sqr());if(++n<e.length)for(var i=r.sqr();n<e.length;n++,i=i.sqr())0!==e[n]&&(r=r.mul(i));return r},a.prototype.iushln=function(t){n(\"number\"==typeof t&&t>=0);var e,r=t%26,i=(t-r)/26,a=67108863>>>26-r<<26-r;if(0!==r){var o=0;for(e=0;e<this.length;e++){var s=this.words[e]&a,l=(0|this.words[e])-s<<r;this.words[e]=l|o,o=s>>>26-r}o&&(this.words[e]=o,this.length++)}if(0!==i){for(e=this.length-1;e>=0;e--)this.words[e+i]=this.words[e];for(e=0;e<i;e++)this.words[e]=0;this.length+=i}return this.strip()},a.prototype.ishln=function(t){return n(0===this.negative),this.iushln(t)},a.prototype.iushrn=function(t,e,r){var i;n(\"number\"==typeof t&&t>=0),i=e?(e-e%26)/26:0;var a=t%26,o=Math.min((t-a)/26,this.length),s=67108863^67108863>>>a<<a,l=r;if(i-=o,i=Math.max(0,i),l){for(var c=0;c<o;c++)l.words[c]=this.words[c];l.length=o}if(0===o);else if(this.length>o)for(this.length-=o,c=0;c<this.length;c++)this.words[c]=this.words[c+o];else this.words[0]=0,this.length=1;var u=0;for(c=this.length-1;c>=0&&(0!==u||c>=i);c--){var h=0|this.words[c];this.words[c]=u<<26-a|h>>>a,u=h&s}return l&&0!==u&&(l.words[l.length++]=u),0===this.length&&(this.words[0]=0,this.length=1),this.strip()},a.prototype.ishrn=function(t,e,r){return n(0===this.negative),this.iushrn(t,e,r)},a.prototype.shln=function(t){return this.clone().ishln(t)},a.prototype.ushln=function(t){return this.clone().iushln(t)},a.prototype.shrn=function(t){return this.clone().ishrn(t)},a.prototype.ushrn=function(t){return this.clone().iushrn(t)},a.prototype.testn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26,i=1<<e;return!(this.length<=r)&&!!(this.words[r]&i)},a.prototype.imaskn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26;if(n(0===this.negative,\"imaskn works only with positive numbers\"),this.length<=r)return this;if(0!==e&&r++,this.length=Math.min(r,this.length),0!==e){var i=67108863^67108863>>>e<<e;this.words[this.length-1]&=i}return this.strip()},a.prototype.maskn=function(t){return this.clone().imaskn(t)},a.prototype.iaddn=function(t){return n(\"number\"==typeof t),n(t<67108864),t<0?this.isubn(-t):0!==this.negative?1===this.length&&(0|this.words[0])<t?(this.words[0]=t-(0|this.words[0]),this.negative=0,this):(this.negative=0,this.isubn(t),this.negative=1,this):this._iaddn(t)},a.prototype._iaddn=function(t){this.words[0]+=t;for(var e=0;e<this.length&&this.words[e]>=67108864;e++)this.words[e]-=67108864,e===this.length-1?this.words[e+1]=1:this.words[e+1]++;return this.length=Math.max(this.length,e+1),this},a.prototype.isubn=function(t){if(n(\"number\"==typeof t),n(t<67108864),t<0)return this.iaddn(-t);if(0!==this.negative)return this.negative=0,this.iaddn(t),this.negative=1,this;if(this.words[0]-=t,1===this.length&&this.words[0]<0)this.words[0]=-this.words[0],this.negative=1;else for(var e=0;e<this.length&&this.words[e]<0;e++)this.words[e]+=67108864,this.words[e+1]-=1;return this.strip()},a.prototype.addn=function(t){return this.clone().iaddn(t)},a.prototype.subn=function(t){return this.clone().isubn(t)},a.prototype.iabs=function(){return this.negative=0,this},a.prototype.abs=function(){return this.clone().iabs()},a.prototype._ishlnsubmul=function(t,e,r){var i,a,o=t.length+r;this._expand(o);var s=0;for(i=0;i<t.length;i++){a=(0|this.words[i+r])+s;var l=(0|t.words[i])*e;s=((a-=67108863&l)>>26)-(l/67108864|0),this.words[i+r]=67108863&a}for(;i<this.length-r;i++)s=(a=(0|this.words[i+r])+s)>>26,this.words[i+r]=67108863&a;if(0===s)return this.strip();for(n(-1===s),s=0,i=0;i<this.length;i++)s=(a=-(0|this.words[i])+s)>>26,this.words[i]=67108863&a;return this.negative=1,this.strip()},a.prototype._wordDiv=function(t,e){var r=(this.length,t.length),n=this.clone(),i=t,o=0|i.words[i.length-1];0!==(r=26-this._countBits(o))&&(i=i.ushln(r),n.iushln(r),o=0|i.words[i.length-1]);var s,l=n.length-i.length;if(\"mod\"!==e){(s=new a(null)).length=l+1,s.words=new Array(s.length);for(var c=0;c<s.length;c++)s.words[c]=0}var u=n.clone()._ishlnsubmul(i,1,l);0===u.negative&&(n=u,s&&(s.words[l]=1));for(var h=l-1;h>=0;h--){var f=67108864*(0|n.words[i.length+h])+(0|n.words[i.length+h-1]);for(f=Math.min(f/o|0,67108863),n._ishlnsubmul(i,f,h);0!==n.negative;)f--,n.negative=0,n._ishlnsubmul(i,1,h),n.isZero()||(n.negative^=1);s&&(s.words[h]=f)}return s&&s.strip(),n.strip(),\"div\"!==e&&0!==r&&n.iushrn(r),{div:s||null,mod:n}},a.prototype.divmod=function(t,e,r){return n(!t.isZero()),this.isZero()?{div:new a(0),mod:new a(0)}:0!==this.negative&&0===t.negative?(s=this.neg().divmod(t,e),\"mod\"!==e&&(i=s.div.neg()),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.iadd(t)),{div:i,mod:o}):0===this.negative&&0!==t.negative?(s=this.divmod(t.neg(),e),\"mod\"!==e&&(i=s.div.neg()),{div:i,mod:s.mod}):0!=(this.negative&t.negative)?(s=this.neg().divmod(t.neg(),e),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.isub(t)),{div:s.div,mod:o}):t.length>this.length||this.cmp(t)<0?{div:new a(0),mod:this}:1===t.length?\"div\"===e?{div:this.divn(t.words[0]),mod:null}:\"mod\"===e?{div:null,mod:new a(this.modn(t.words[0]))}:{div:this.divn(t.words[0]),mod:new a(this.modn(t.words[0]))}:this._wordDiv(t,e);var i,o,s},a.prototype.div=function(t){return this.divmod(t,\"div\",!1).div},a.prototype.mod=function(t){return this.divmod(t,\"mod\",!1).mod},a.prototype.umod=function(t){return this.divmod(t,\"mod\",!0).mod},a.prototype.divRound=function(t){var e=this.divmod(t);if(e.mod.isZero())return e.div;var r=0!==e.div.negative?e.mod.isub(t):e.mod,n=t.ushrn(1),i=t.andln(1),a=r.cmp(n);return a<0||1===i&&0===a?e.div:0!==e.div.negative?e.div.isubn(1):e.div.iaddn(1)},a.prototype.modn=function(t){n(t<=67108863);for(var e=(1<<26)%t,r=0,i=this.length-1;i>=0;i--)r=(e*r+(0|this.words[i]))%t;return r},a.prototype.idivn=function(t){n(t<=67108863);for(var e=0,r=this.length-1;r>=0;r--){var i=(0|this.words[r])+67108864*e;this.words[r]=i/t|0,e=i%t}return this.strip()},a.prototype.divn=function(t){return this.clone().idivn(t)},a.prototype.egcd=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i=new a(1),o=new a(0),s=new a(0),l=new a(1),c=0;e.isEven()&&r.isEven();)e.iushrn(1),r.iushrn(1),++c;for(var u=r.clone(),h=e.clone();!e.isZero();){for(var f=0,p=1;0==(e.words[0]&p)&&f<26;++f,p<<=1);if(f>0)for(e.iushrn(f);f-- >0;)(i.isOdd()||o.isOdd())&&(i.iadd(u),o.isub(h)),i.iushrn(1),o.iushrn(1);for(var d=0,g=1;0==(r.words[0]&g)&&d<26;++d,g<<=1);if(d>0)for(r.iushrn(d);d-- >0;)(s.isOdd()||l.isOdd())&&(s.iadd(u),l.isub(h)),s.iushrn(1),l.iushrn(1);e.cmp(r)>=0?(e.isub(r),i.isub(s),o.isub(l)):(r.isub(e),s.isub(i),l.isub(o))}return{a:s,b:l,gcd:r.iushln(c)}},a.prototype._invmp=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i,o=new a(1),s=new a(0),l=r.clone();e.cmpn(1)>0&&r.cmpn(1)>0;){for(var c=0,u=1;0==(e.words[0]&u)&&c<26;++c,u<<=1);if(c>0)for(e.iushrn(c);c-- >0;)o.isOdd()&&o.iadd(l),o.iushrn(1);for(var h=0,f=1;0==(r.words[0]&f)&&h<26;++h,f<<=1);if(h>0)for(r.iushrn(h);h-- >0;)s.isOdd()&&s.iadd(l),s.iushrn(1);e.cmp(r)>=0?(e.isub(r),o.isub(s)):(r.isub(e),s.isub(o))}return(i=0===e.cmpn(1)?o:s).cmpn(0)<0&&i.iadd(t),i},a.prototype.gcd=function(t){if(this.isZero())return t.abs();if(t.isZero())return this.abs();var e=this.clone(),r=t.clone();e.negative=0,r.negative=0;for(var n=0;e.isEven()&&r.isEven();n++)e.iushrn(1),r.iushrn(1);for(;;){for(;e.isEven();)e.iushrn(1);for(;r.isEven();)r.iushrn(1);var i=e.cmp(r);if(i<0){var a=e;e=r,r=a}else if(0===i||0===r.cmpn(1))break;e.isub(r)}return r.iushln(n)},a.prototype.invm=function(t){return this.egcd(t).a.umod(t)},a.prototype.isEven=function(){return 0==(1&this.words[0])},a.prototype.isOdd=function(){return 1==(1&this.words[0])},a.prototype.andln=function(t){return this.words[0]&t},a.prototype.bincn=function(t){n(\"number\"==typeof t);var e=t%26,r=(t-e)/26,i=1<<e;if(this.length<=r)return this._expand(r+1),this.words[r]|=i,this;for(var a=i,o=r;0!==a&&o<this.length;o++){var s=0|this.words[o];a=(s+=a)>>>26,s&=67108863,this.words[o]=s}return 0!==a&&(this.words[o]=a,this.length++),this},a.prototype.isZero=function(){return 1===this.length&&0===this.words[0]},a.prototype.cmpn=function(t){var e,r=t<0;if(0!==this.negative&&!r)return-1;if(0===this.negative&&r)return 1;if(this.strip(),this.length>1)e=1;else{r&&(t=-t),n(t<=67108863,\"Number is too big\");var i=0|this.words[0];e=i===t?0:i<t?-1:1}return 0!==this.negative?0|-e:e},a.prototype.cmp=function(t){if(0!==this.negative&&0===t.negative)return-1;if(0===this.negative&&0!==t.negative)return 1;var e=this.ucmp(t);return 0!==this.negative?0|-e:e},a.prototype.ucmp=function(t){if(this.length>t.length)return 1;if(this.length<t.length)return-1;for(var e=0,r=this.length-1;r>=0;r--){var n=0|this.words[r],i=0|t.words[r];if(n!==i){n<i?e=-1:n>i&&(e=1);break}}return e},a.prototype.gtn=function(t){return 1===this.cmpn(t)},a.prototype.gt=function(t){return 1===this.cmp(t)},a.prototype.gten=function(t){return this.cmpn(t)>=0},a.prototype.gte=function(t){return this.cmp(t)>=0},a.prototype.ltn=function(t){return-1===this.cmpn(t)},a.prototype.lt=function(t){return-1===this.cmp(t)},a.prototype.lten=function(t){return this.cmpn(t)<=0},a.prototype.lte=function(t){return this.cmp(t)<=0},a.prototype.eqn=function(t){return 0===this.cmpn(t)},a.prototype.eq=function(t){return 0===this.cmp(t)},a.red=function(t){return new w(t)},a.prototype.toRed=function(t){return n(!this.red,\"Already a number in reduction context\"),n(0===this.negative,\"red works only with positives\"),t.convertTo(this)._forceRed(t)},a.prototype.fromRed=function(){return n(this.red,\"fromRed works only with numbers in reduction context\"),this.red.convertFrom(this)},a.prototype._forceRed=function(t){return this.red=t,this},a.prototype.forceRed=function(t){return n(!this.red,\"Already a number in reduction context\"),this._forceRed(t)},a.prototype.redAdd=function(t){return n(this.red,\"redAdd works only with red numbers\"),this.red.add(this,t)},a.prototype.redIAdd=function(t){return n(this.red,\"redIAdd works only with red numbers\"),this.red.iadd(this,t)},a.prototype.redSub=function(t){return n(this.red,\"redSub works only with red numbers\"),this.red.sub(this,t)},a.prototype.redISub=function(t){return n(this.red,\"redISub works only with red numbers\"),this.red.isub(this,t)},a.prototype.redShl=function(t){return n(this.red,\"redShl works only with red numbers\"),this.red.shl(this,t)},a.prototype.redMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.mul(this,t)},a.prototype.redIMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.imul(this,t)},a.prototype.redSqr=function(){return n(this.red,\"redSqr works only with red numbers\"),this.red._verify1(this),this.red.sqr(this)},a.prototype.redISqr=function(){return n(this.red,\"redISqr works only with red numbers\"),this.red._verify1(this),this.red.isqr(this)},a.prototype.redSqrt=function(){return n(this.red,\"redSqrt works only with red numbers\"),this.red._verify1(this),this.red.sqrt(this)},a.prototype.redInvm=function(){return n(this.red,\"redInvm works only with red numbers\"),this.red._verify1(this),this.red.invm(this)},a.prototype.redNeg=function(){return n(this.red,\"redNeg works only with red numbers\"),this.red._verify1(this),this.red.neg(this)},a.prototype.redPow=function(t){return n(this.red&&!t.red,\"redPow(normalNum)\"),this.red._verify1(this),this.red.pow(this,t)};var v={k256:null,p224:null,p192:null,p25519:null};function m(t,e){this.name=t,this.p=new a(e,16),this.n=this.p.bitLength(),this.k=new a(1).iushln(this.n).isub(this.p),this.tmp=this._tmp()}function y(){m.call(this,\"k256\",\"ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffe fffffc2f\")}function x(){m.call(this,\"p224\",\"ffffffff ffffffff ffffffff ffffffff 00000000 00000000 00000001\")}function b(){m.call(this,\"p192\",\"ffffffff ffffffff ffffffff fffffffe ffffffff ffffffff\")}function _(){m.call(this,\"25519\",\"7fffffffffffffff ffffffffffffffff ffffffffffffffff ffffffffffffffed\")}function w(t){if(\"string\"==typeof t){var e=a._prime(t);this.m=e.p,this.prime=e}else n(t.gtn(1),\"modulus must be greater than 1\"),this.m=t,this.prime=null}function k(t){w.call(this,t),this.shift=this.m.bitLength(),this.shift%26!=0&&(this.shift+=26-this.shift%26),this.r=new a(1).iushln(this.shift),this.r2=this.imod(this.r.sqr()),this.rinv=this.r._invmp(this.m),this.minv=this.rinv.mul(this.r).isubn(1).div(this.m),this.minv=this.minv.umod(this.r),this.minv=this.r.sub(this.minv)}m.prototype._tmp=function(){var t=new a(null);return t.words=new Array(Math.ceil(this.n/13)),t},m.prototype.ireduce=function(t){var e,r=t;do{this.split(r,this.tmp),e=(r=(r=this.imulK(r)).iadd(this.tmp)).bitLength()}while(e>this.n);var n=e<this.n?-1:r.ucmp(this.p);return 0===n?(r.words[0]=0,r.length=1):n>0?r.isub(this.p):r.strip(),r},m.prototype.split=function(t,e){t.iushrn(this.n,0,e)},m.prototype.imulK=function(t){return t.imul(this.k)},i(y,m),y.prototype.split=function(t,e){for(var r=Math.min(t.length,9),n=0;n<r;n++)e.words[n]=t.words[n];if(e.length=r,t.length<=9)return t.words[0]=0,void(t.length=1);var i=t.words[9];for(e.words[e.length++]=4194303&i,n=10;n<t.length;n++){var a=0|t.words[n];t.words[n-10]=(4194303&a)<<4|i>>>22,i=a}i>>>=22,t.words[n-10]=i,0===i&&t.length>10?t.length-=10:t.length-=9},y.prototype.imulK=function(t){t.words[t.length]=0,t.words[t.length+1]=0,t.length+=2;for(var e=0,r=0;r<t.length;r++){var n=0|t.words[r];e+=977*n,t.words[r]=67108863&e,e=64*n+(e/67108864|0)}return 0===t.words[t.length-1]&&(t.length--,0===t.words[t.length-1]&&t.length--),t},i(x,m),i(b,m),i(_,m),_.prototype.imulK=function(t){for(var e=0,r=0;r<t.length;r++){var n=19*(0|t.words[r])+e,i=67108863&n;n>>>=26,t.words[r]=i,e=n}return 0!==e&&(t.words[t.length++]=e),t},a._prime=function(t){if(v[t])return v[t];var e;if(\"k256\"===t)e=new y;else if(\"p224\"===t)e=new x;else if(\"p192\"===t)e=new b;else{if(\"p25519\"!==t)throw new Error(\"Unknown prime \"+t);e=new _}return v[t]=e,e},w.prototype._verify1=function(t){n(0===t.negative,\"red works only with positives\"),n(t.red,\"red works only with red numbers\")},w.prototype._verify2=function(t,e){n(0==(t.negative|e.negative),\"red works only with positives\"),n(t.red&&t.red===e.red,\"red works only with red numbers\")},w.prototype.imod=function(t){return this.prime?this.prime.ireduce(t)._forceRed(this):t.umod(this.m)._forceRed(this)},w.prototype.neg=function(t){return t.isZero()?t.clone():this.m.sub(t)._forceRed(this)},w.prototype.add=function(t,e){this._verify2(t,e);var r=t.add(e);return r.cmp(this.m)>=0&&r.isub(this.m),r._forceRed(this)},w.prototype.iadd=function(t,e){this._verify2(t,e);var r=t.iadd(e);return r.cmp(this.m)>=0&&r.isub(this.m),r},w.prototype.sub=function(t,e){this._verify2(t,e);var r=t.sub(e);return r.cmpn(0)<0&&r.iadd(this.m),r._forceRed(this)},w.prototype.isub=function(t,e){this._verify2(t,e);var r=t.isub(e);return r.cmpn(0)<0&&r.iadd(this.m),r},w.prototype.shl=function(t,e){return this._verify1(t),this.imod(t.ushln(e))},w.prototype.imul=function(t,e){return this._verify2(t,e),this.imod(t.imul(e))},w.prototype.mul=function(t,e){return this._verify2(t,e),this.imod(t.mul(e))},w.prototype.isqr=function(t){return this.imul(t,t.clone())},w.prototype.sqr=function(t){return this.mul(t,t)},w.prototype.sqrt=function(t){if(t.isZero())return t.clone();var e=this.m.andln(3);if(n(e%2==1),3===e){var r=this.m.add(new a(1)).iushrn(2);return this.pow(t,r)}for(var i=this.m.subn(1),o=0;!i.isZero()&&0===i.andln(1);)o++,i.iushrn(1);n(!i.isZero());var s=new a(1).toRed(this),l=s.redNeg(),c=this.m.subn(1).iushrn(1),u=this.m.bitLength();for(u=new a(2*u*u).toRed(this);0!==this.pow(u,c).cmp(l);)u.redIAdd(l);for(var h=this.pow(u,i),f=this.pow(t,i.addn(1).iushrn(1)),p=this.pow(t,i),d=o;0!==p.cmp(s);){for(var g=p,v=0;0!==g.cmp(s);v++)g=g.redSqr();n(v<d);var m=this.pow(h,new a(1).iushln(d-v-1));f=f.redMul(m),h=m.redSqr(),p=p.redMul(h),d=v}return f},w.prototype.invm=function(t){var e=t._invmp(this.m);return 0!==e.negative?(e.negative=0,this.imod(e).redNeg()):this.imod(e)},w.prototype.pow=function(t,e){if(e.isZero())return new a(1).toRed(this);if(0===e.cmpn(1))return t.clone();var r=new Array(16);r[0]=new a(1).toRed(this),r[1]=t;for(var n=2;n<r.length;n++)r[n]=this.mul(r[n-1],t);var i=r[0],o=0,s=0,l=e.bitLength()%26;for(0===l&&(l=26),n=e.length-1;n>=0;n--){for(var c=e.words[n],u=l-1;u>=0;u--){var h=c>>u&1;i!==r[0]&&(i=this.sqr(i)),0!==h||0!==o?(o<<=1,o|=h,(4===++s||0===n&&0===u)&&(i=this.mul(i,r[o]),s=0,o=0)):s=0}l=26}return i},w.prototype.convertTo=function(t){var e=t.umod(this.m);return e===t?e.clone():e},w.prototype.convertFrom=function(t){var e=t.clone();return e.red=null,e},a.mont=function(t){return new k(t)},i(k,w),k.prototype.convertTo=function(t){return this.imod(t.ushln(this.shift))},k.prototype.convertFrom=function(t){var e=this.imod(t.mul(this.rinv));return e.red=null,e},k.prototype.imul=function(t,e){if(t.isZero()||e.isZero())return t.words[0]=0,t.length=1,t;var r=t.imul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),a=i;return i.cmp(this.m)>=0?a=i.isub(this.m):i.cmpn(0)<0&&(a=i.iadd(this.m)),a._forceRed(this)},k.prototype.mul=function(t,e){if(t.isZero()||e.isZero())return new a(0)._forceRed(this);var r=t.mul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),o=i;return i.cmp(this.m)>=0?o=i.isub(this.m):i.cmpn(0)<0&&(o=i.iadd(this.m)),o._forceRed(this)},k.prototype.invm=function(t){return this.imod(t._invmp(this.m).mul(this.r2))._forceRed(this)}}(\"undefined\"==typeof e||e,this)},{buffer:103}],95:[function(t,e,r){\"use strict\";e.exports=function(t){var e,r,n,i=t.length,a=0;for(e=0;e<i;++e)a+=t[e].length;var o=new Array(a),s=0;for(e=0;e<i;++e){var l=t[e],c=l.length;for(r=0;r<c;++r){var u=o[s++]=new Array(c-1),h=0;for(n=0;n<c;++n)n!==r&&(u[h++]=l[n]);if(1&r){var f=u[1];u[1]=u[0],u[0]=f}}}return o}},{}],96:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 1:return n=[],c(i=t,i,u,!0),n;case 2:return\"function\"==typeof e?c(t,t,e,!0):function(t,e){return n=[],c(t,e,u,!1),n}(t,e);case 3:return c(t,e,r,!1);default:throw new Error(\"box-intersect: Invalid arguments\")}var i};var n,i=t(\"typedarray-pool\"),a=t(\"./lib/sweep\"),o=t(\"./lib/intersect\");function s(t,e){for(var r=0;r<t;++r)if(!(e[r]<=e[r+t]))return!0;return!1}function l(t,e,r,n){for(var i=0,a=0,o=0,l=t.length;o<l;++o){var c=t[o];if(!s(e,c)){for(var u=0;u<2*e;++u)r[i++]=c[u];n[a++]=o}}return a}function c(t,e,r,n){var s=t.length,c=e.length;if(!(s<=0||c<=0)){var u=t[0].length>>>1;if(!(u<=0)){var h,f=i.mallocDouble(2*u*s),p=i.mallocInt32(s);if((s=l(t,u,f,p))>0){if(1===u&&n)a.init(s),h=a.sweepComplete(u,r,0,s,f,p,0,s,f,p);else{var d=i.mallocDouble(2*u*c),g=i.mallocInt32(c);(c=l(e,u,d,g))>0&&(a.init(s+c),h=1===u?a.sweepBipartite(u,r,0,s,f,p,0,c,d,g):o(u,r,n,s,f,p,c,d,g),i.free(d),i.free(g))}i.free(f),i.free(p)}return h}}}function u(t,e){n.push([t,e])}},{\"./lib/intersect\":98,\"./lib/sweep\":102,\"typedarray-pool\":545}],97:[function(t,e,r){\"use strict\";var n=\"d\",i=\"ax\",a=\"vv\",o=\"fp\",s=\"es\",l=\"rs\",c=\"re\",u=\"rb\",h=\"ri\",f=\"rp\",p=\"bs\",d=\"be\",g=\"bb\",v=\"bi\",m=\"bp\",y=\"rv\",x=\"Q\",b=[n,i,a,l,c,u,h,p,d,g,v];function _(t){var e=\"bruteForce\"+(t?\"Full\":\"Partial\"),r=[],_=b.slice();t||_.splice(3,0,o);var w=[\"function \"+e+\"(\"+_.join()+\"){\"];function k(e,o){var _=function(t,e,r){var o=\"bruteForce\"+(t?\"Red\":\"Blue\")+(e?\"Flip\":\"\")+(r?\"Full\":\"\"),_=[\"function \",o,\"(\",b.join(),\"){\",\"var \",s,\"=2*\",n,\";\"],w=\"for(var i=\"+l+\",\"+f+\"=\"+s+\"*\"+l+\";i<\"+c+\";++i,\"+f+\"+=\"+s+\"){var x0=\"+u+\"[\"+i+\"+\"+f+\"],x1=\"+u+\"[\"+i+\"+\"+f+\"+\"+n+\"],xi=\"+h+\"[i];\",k=\"for(var j=\"+p+\",\"+m+\"=\"+s+\"*\"+p+\";j<\"+d+\";++j,\"+m+\"+=\"+s+\"){var y0=\"+g+\"[\"+i+\"+\"+m+\"],\"+(r?\"y1=\"+g+\"[\"+i+\"+\"+m+\"+\"+n+\"],\":\"\")+\"yi=\"+v+\"[j];\";return t?_.push(w,x,\":\",k):_.push(k,x,\":\",w),r?_.push(\"if(y1<x0||x1<y0)continue;\"):e?_.push(\"if(y0<=x0||x1<y0)continue;\"):_.push(\"if(y0<x0||x1<y0)continue;\"),_.push(\"for(var k=\"+i+\"+1;k<\"+n+\";++k){var r0=\"+u+\"[k+\"+f+\"],r1=\"+u+\"[k+\"+n+\"+\"+f+\"],b0=\"+g+\"[k+\"+m+\"],b1=\"+g+\"[k+\"+n+\"+\"+m+\"];if(r1<b0||b1<r0)continue \"+x+\";}var \"+y+\"=\"+a+\"(\"),e?_.push(\"yi,xi\"):_.push(\"xi,yi\"),_.push(\");if(\"+y+\"!==void 0)return \"+y+\";}}}\"),{name:o,code:_.join(\"\")}}(e,o,t);r.push(_.code),w.push(\"return \"+_.name+\"(\"+b.join()+\");\")}w.push(\"if(\"+c+\"-\"+l+\">\"+d+\"-\"+p+\"){\"),t?(k(!0,!1),w.push(\"}else{\"),k(!1,!1)):(w.push(\"if(\"+o+\"){\"),k(!0,!0),w.push(\"}else{\"),k(!0,!1),w.push(\"}}else{if(\"+o+\"){\"),k(!1,!0),w.push(\"}else{\"),k(!1,!1),w.push(\"}\")),w.push(\"}}return \"+e);var T=r.join(\"\")+w.join(\"\");return new Function(T)()}r.partial=_(!1),r.full=_(!0)},{}],98:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,u,S,E,C,L){!function(t,e){var r=8*i.log2(e+1)*(t+1)|0,a=i.nextPow2(b*r);w.length<a&&(n.free(w),w=n.mallocInt32(a));var o=i.nextPow2(_*r);k<o&&(n.free(k),k=n.mallocDouble(o))}(t,a+E);var P,O=0,z=2*t;T(O++,0,0,a,0,E,r?16:0,-1/0,1/0),r||T(O++,0,0,E,0,a,1,-1/0,1/0);for(;O>0;){var I=(O-=1)*b,D=w[I],R=w[I+1],F=w[I+2],B=w[I+3],N=w[I+4],j=w[I+5],U=O*_,V=k[U],q=k[U+1],H=1&j,G=!!(16&j),Y=u,W=S,X=C,Z=L;if(H&&(Y=C,W=L,X=u,Z=S),!(2&j&&(F=v(t,D,R,F,Y,W,q),R>=F)||4&j&&(R=m(t,D,R,F,Y,W,V))>=F)){var J=F-R,K=N-B;if(G){if(t*J*(J+K)<p){if(void 0!==(P=l.scanComplete(t,D,e,R,F,Y,W,B,N,X,Z)))return P;continue}}else{if(t*Math.min(J,K)<h){if(void 0!==(P=o(t,D,e,H,R,F,Y,W,B,N,X,Z)))return P;continue}if(t*J*K<f){if(void 0!==(P=l.scanBipartite(t,D,e,H,R,F,Y,W,B,N,X,Z)))return P;continue}}var $=d(t,D,R,F,Y,W,V,q);if(R<$)if(t*($-R)<h){if(void 0!==(P=s(t,D+1,e,R,$,Y,W,B,N,X,Z)))return P}else if(D===t-2){if(void 0!==(P=H?l.sweepBipartite(t,e,B,N,X,Z,R,$,Y,W):l.sweepBipartite(t,e,R,$,Y,W,B,N,X,Z)))return P}else T(O++,D+1,R,$,B,N,H,-1/0,1/0),T(O++,D+1,B,N,R,$,1^H,-1/0,1/0);if($<F){var Q=c(t,D,B,N,X,Z),tt=X[z*Q+D],et=g(t,D,Q,N,X,Z,tt);if(et<N&&T(O++,D,$,F,et,N,(4|H)+(G?16:0),tt,q),B<Q&&T(O++,D,$,F,B,Q,(2|H)+(G?16:0),V,tt),Q+1===et){if(void 0!==(P=G?M(t,D,e,$,F,Y,W,Q,X,Z[Q]):A(t,D,e,H,$,F,Y,W,Q,X,Z[Q])))return P}else if(Q<et){var rt;if(G){if(rt=y(t,D,$,F,Y,W,tt),$<rt){var nt=g(t,D,$,rt,Y,W,tt);if(D===t-2){if($<nt&&void 0!==(P=l.sweepComplete(t,e,$,nt,Y,W,Q,et,X,Z)))return P;if(nt<rt&&void 0!==(P=l.sweepBipartite(t,e,nt,rt,Y,W,Q,et,X,Z)))return P}else $<nt&&T(O++,D+1,$,nt,Q,et,16,-1/0,1/0),nt<rt&&(T(O++,D+1,nt,rt,Q,et,0,-1/0,1/0),T(O++,D+1,Q,et,nt,rt,1,-1/0,1/0))}}else rt=H?x(t,D,$,F,Y,W,tt):y(t,D,$,F,Y,W,tt),$<rt&&(D===t-2?P=H?l.sweepBipartite(t,e,Q,et,X,Z,$,rt,Y,W):l.sweepBipartite(t,e,$,rt,Y,W,Q,et,X,Z):(T(O++,D+1,$,rt,Q,et,H,-1/0,1/0),T(O++,D+1,Q,et,$,rt,1^H,-1/0,1/0)))}}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./brute\"),o=a.partial,s=a.full,l=t(\"./sweep\"),c=t(\"./median\"),u=t(\"./partition\"),h=128,f=1<<22,p=1<<22,d=u(\"!(lo>=p0)&&!(p1>=hi)\",[\"p0\",\"p1\"]),g=u(\"lo===p0\",[\"p0\"]),v=u(\"lo<p0\",[\"p0\"]),m=u(\"hi<=p0\",[\"p0\"]),y=u(\"lo<=p0&&p0<=hi\",[\"p0\"]),x=u(\"lo<p0&&p0<=hi\",[\"p0\"]),b=6,_=2,w=n.mallocInt32(1024),k=n.mallocDouble(1024);function T(t,e,r,n,i,a,o,s,l){var c=b*t;w[c]=e,w[c+1]=r,w[c+2]=n,w[c+3]=i,w[c+4]=a,w[c+5]=o;var u=_*t;k[u]=s,k[u+1]=l}function A(t,e,r,n,i,a,o,s,l,c,u){var h=2*t,f=l*h,p=c[f+e];t:for(var d=i,g=i*h;d<a;++d,g+=h){var v=o[g+e],m=o[g+e+t];if(!(p<v||m<p)&&(!n||p!==v)){for(var y,x=s[d],b=e+1;b<t;++b){v=o[g+b],m=o[g+b+t];var _=c[f+b],w=c[f+b+t];if(m<_||w<v)continue t}if(void 0!==(y=n?r(u,x):r(x,u)))return y}}}function M(t,e,r,n,i,a,o,s,l,c){var u=2*t,h=s*u,f=l[h+e];t:for(var p=n,d=n*u;p<i;++p,d+=u){var g=o[p];if(g!==c){var v=a[d+e],m=a[d+e+t];if(!(f<v||m<f)){for(var y=e+1;y<t;++y){v=a[d+y],m=a[d+y+t];var x=l[h+y],b=l[h+y+t];if(m<x||b<v)continue t}var _=r(g,c);if(void 0!==_)return _}}}}},{\"./brute\":97,\"./median\":99,\"./partition\":100,\"./sweep\":102,\"bit-twiddle\":92,\"typedarray-pool\":545}],99:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,o,s,l){if(o<=r+1)return r;var c=r,u=o,h=o+r>>>1,f=2*t,p=h,d=s[f*h+e];for(;c<u;){if(u-c<i){a(t,e,c,u,s,l),d=s[f*h+e];break}var g=u-c,v=Math.random()*g+c|0,m=s[f*v+e],y=Math.random()*g+c|0,x=s[f*y+e],b=Math.random()*g+c|0,_=s[f*b+e];m<=x?_>=x?(p=y,d=x):m>=_?(p=v,d=m):(p=b,d=_):x>=_?(p=y,d=x):_>=m?(p=v,d=m):(p=b,d=_);for(var w=f*(u-1),k=f*p,T=0;T<f;++T,++w,++k){var A=s[w];s[w]=s[k],s[k]=A}var M=l[u-1];l[u-1]=l[p],l[p]=M,p=n(t,e,c,u-1,s,l,d);for(var w=f*(u-1),k=f*p,T=0;T<f;++T,++w,++k){var A=s[w];s[w]=s[k],s[k]=A}var M=l[u-1];if(l[u-1]=l[p],l[p]=M,h<p){for(u=p-1;c<u&&s[f*(u-1)+e]===d;)u-=1;u+=1}else{if(!(p<h))break;for(c=p+1;c<u&&s[f*c+e]===d;)c+=1}}return n(t,e,r,h,s,l,s[f*h+e])};var n=t(\"./partition\")(\"lo<p0\",[\"p0\"]),i=8;function a(t,e,r,n,i,a){for(var o=2*t,s=o*(r+1)+e,l=r+1;l<n;++l,s+=o)for(var c=i[s],u=l,h=o*(l-1);u>r&&i[h+e]>c;--u,h-=o){for(var f=h,p=h+o,d=0;d<o;++d,++f,++p){var g=i[f];i[f]=i[p],i[p]=g}var v=a[u];a[u]=a[u-1],a[u-1]=v}}},{\"./partition\":100}],100:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=\"abcdef\".split(\"\").concat(e),i=[];t.indexOf(\"lo\")>=0&&i.push(\"lo=e[k+n]\");t.indexOf(\"hi\")>=0&&i.push(\"hi=e[k+o]\");return r.push(n.replace(\"_\",i.join()).replace(\"$\",t)),Function.apply(void 0,r)};var n=\"for(var j=2*a,k=j*c,l=k,m=c,n=b,o=a+b,p=c;d>p;++p,k+=j){var _;if($)if(m===p)m+=1,l+=j;else{for(var s=0;j>s;++s){var t=e[k+s];e[k+s]=e[l],e[l++]=t}var u=f[p];f[p]=f[m],f[m++]=u}}return m\"},{}],101:[function(t,e,r){\"use strict\";e.exports=function(t,e){e<=4*n?i(0,e-1,t):function t(e,r,h){var f=(r-e+1)/6|0,p=e+f,d=r-f,g=e+r>>1,v=g-f,m=g+f,y=p,x=v,b=g,_=m,w=d,k=e+1,T=r-1,A=0;c(y,x,h)&&(A=y,y=x,x=A);c(_,w,h)&&(A=_,_=w,w=A);c(y,b,h)&&(A=y,y=b,b=A);c(x,b,h)&&(A=x,x=b,b=A);c(y,_,h)&&(A=y,y=_,_=A);c(b,_,h)&&(A=b,b=_,_=A);c(x,w,h)&&(A=x,x=w,w=A);c(x,b,h)&&(A=x,x=b,b=A);c(_,w,h)&&(A=_,_=w,w=A);var M=h[2*x];var S=h[2*x+1];var E=h[2*_];var C=h[2*_+1];var L=2*y;var P=2*b;var O=2*w;var z=2*p;var I=2*g;var D=2*d;for(var R=0;R<2;++R){var F=h[L+R],B=h[P+R],N=h[O+R];h[z+R]=F,h[I+R]=B,h[D+R]=N}o(v,e,h);o(m,r,h);for(var j=k;j<=T;++j)if(u(j,M,S,h))j!==k&&a(j,k,h),++k;else if(!u(j,E,C,h))for(;;){if(u(T,E,C,h)){u(T,M,S,h)?(s(j,k,T,h),++k,--T):(a(j,T,h),--T);break}if(--T<j)break}l(e,k-1,M,S,h);l(r,T+1,E,C,h);k-2-e<=n?i(e,k-2,h):t(e,k-2,h);r-(T+2)<=n?i(T+2,r,h):t(T+2,r,h);T-k<=n?i(k,T,h):t(k,T,h)}(0,e-1,t)};var n=32;function i(t,e,r){for(var n=2*(t+1),i=t+1;i<=e;++i){for(var a=r[n++],o=r[n++],s=i,l=n-2;s-- >t;){var c=r[l-2],u=r[l-1];if(c<a)break;if(c===a&&u<o)break;r[l]=c,r[l+1]=u,l-=2}r[l]=a,r[l+1]=o}}function a(t,e,r){e*=2;var n=r[t*=2],i=r[t+1];r[t]=r[e],r[t+1]=r[e+1],r[e]=n,r[e+1]=i}function o(t,e,r){e*=2,r[t*=2]=r[e],r[t+1]=r[e+1]}function s(t,e,r,n){e*=2,r*=2;var i=n[t*=2],a=n[t+1];n[t]=n[e],n[t+1]=n[e+1],n[e]=n[r],n[e+1]=n[r+1],n[r]=i,n[r+1]=a}function l(t,e,r,n,i){e*=2,i[t*=2]=i[e],i[e]=r,i[t+1]=i[e+1],i[e+1]=n}function c(t,e,r){e*=2;var n=r[t*=2],i=r[e];return!(n<i)&&(n!==i||r[t+1]>r[e+1])}function u(t,e,r,n){var i=n[t*=2];return i<e||i===e&&n[t+1]<r}},{}],102:[function(t,e,r){\"use strict\";e.exports={init:function(t){var e=i.nextPow2(t);s.length<e&&(n.free(s),s=n.mallocInt32(e));l.length<e&&(n.free(l),l=n.mallocInt32(e));c.length<e&&(n.free(c),c=n.mallocInt32(e));u.length<e&&(n.free(u),u=n.mallocInt32(e));h.length<e&&(n.free(h),h=n.mallocInt32(e));f.length<e&&(n.free(f),f=n.mallocInt32(e));var r=8*e;p.length<r&&(n.free(p),p=n.mallocDouble(r))},sweepBipartite:function(t,e,r,n,i,h,f,v,m,y){for(var x=0,b=2*t,_=t-1,w=b-1,k=r;k<n;++k){var T=h[k],A=b*k;p[x++]=i[A+_],p[x++]=-(T+1),p[x++]=i[A+w],p[x++]=T}for(var k=f;k<v;++k){var T=y[k]+o,M=b*k;p[x++]=m[M+_],p[x++]=-T,p[x++]=m[M+w],p[x++]=T}var S=x>>>1;a(p,S);for(var E=0,C=0,k=0;k<S;++k){var L=0|p[2*k+1];if(L>=o)d(c,u,C--,L=L-o|0);else if(L>=0)d(s,l,E--,L);else if(L<=-o){L=-L-o|0;for(var P=0;P<E;++P){var O=e(s[P],L);if(void 0!==O)return O}g(c,u,C++,L)}else{L=-L-1|0;for(var P=0;P<C;++P){var O=e(L,c[P]);if(void 0!==O)return O}g(s,l,E++,L)}}},sweepComplete:function(t,e,r,n,i,o,v,m,y,x){for(var b=0,_=2*t,w=t-1,k=_-1,T=r;T<n;++T){var A=o[T]+1<<1,M=_*T;p[b++]=i[M+w],p[b++]=-A,p[b++]=i[M+k],p[b++]=A}for(var T=v;T<m;++T){var A=x[T]+1<<1,S=_*T;p[b++]=y[S+w],p[b++]=1|-A,p[b++]=y[S+k],p[b++]=1|A}var E=b>>>1;a(p,E);for(var C=0,L=0,P=0,T=0;T<E;++T){var O=0|p[2*T+1],z=1&O;if(T<E-1&&O>>1==p[2*T+3]>>1&&(z=2,T+=1),O<0){for(var I=-(O>>1)-1,D=0;D<P;++D){var R=e(h[D],I);if(void 0!==R)return R}if(0!==z)for(var D=0;D<C;++D){var R=e(s[D],I);if(void 0!==R)return R}if(1!==z)for(var D=0;D<L;++D){var R=e(c[D],I);if(void 0!==R)return R}0===z?g(s,l,C++,I):1===z?g(c,u,L++,I):2===z&&g(h,f,P++,I)}else{var I=(O>>1)-1;0===z?d(s,l,C--,I):1===z?d(c,u,L--,I):2===z&&d(h,f,P--,I)}}},scanBipartite:function(t,e,r,n,i,c,u,h,f,v,m,y){var x=0,b=2*t,_=e,w=e+t,k=1,T=1;n?T=o:k=o;for(var A=i;A<c;++A){var M=A+k,S=b*A;p[x++]=u[S+_],p[x++]=-M,p[x++]=u[S+w],p[x++]=M}for(var A=f;A<v;++A){var M=A+T,E=b*A;p[x++]=m[E+_],p[x++]=-M}var C=x>>>1;a(p,C);for(var L=0,A=0;A<C;++A){var P=0|p[2*A+1];if(P<0){var M=-P,O=!1;if(M>=o?(O=!n,M-=o):(O=!!n,M-=1),O)g(s,l,L++,M);else{var z=y[M],I=b*M,D=m[I+e+1],R=m[I+e+1+t];t:for(var F=0;F<L;++F){var B=s[F],N=b*B;if(!(R<u[N+e+1]||u[N+e+1+t]<D)){for(var j=e+2;j<t;++j)if(m[I+j+t]<u[N+j]||u[N+j+t]<m[I+j])continue t;var U,V=h[B];if(void 0!==(U=n?r(z,V):r(V,z)))return U}}}}else d(s,l,L--,P-k)}},scanComplete:function(t,e,r,n,i,l,c,u,h,f,d){for(var g=0,v=2*t,m=e,y=e+t,x=n;x<i;++x){var b=x+o,_=v*x;p[g++]=l[_+m],p[g++]=-b,p[g++]=l[_+y],p[g++]=b}for(var x=u;x<h;++x){var b=x+1,w=v*x;p[g++]=f[w+m],p[g++]=-b}var k=g>>>1;a(p,k);for(var T=0,x=0;x<k;++x){var A=0|p[2*x+1];if(A<0){var b=-A;if(b>=o)s[T++]=b-o;else{var M=d[b-=1],S=v*b,E=f[S+e+1],C=f[S+e+1+t];t:for(var L=0;L<T;++L){var P=s[L],O=c[P];if(O===M)break;var z=v*P;if(!(C<l[z+e+1]||l[z+e+1+t]<E)){for(var I=e+2;I<t;++I)if(f[S+I+t]<l[z+I]||l[z+I+t]<f[S+I])continue t;var D=r(O,M);if(void 0!==D)return D}}}}else{for(var b=A-o,L=T-1;L>=0;--L)if(s[L]===b){for(var I=L+1;I<T;++I)s[I-1]=s[I];break}--T}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./sort\"),o=1<<28,s=n.mallocInt32(1024),l=n.mallocInt32(1024),c=n.mallocInt32(1024),u=n.mallocInt32(1024),h=n.mallocInt32(1024),f=n.mallocInt32(1024),p=n.mallocDouble(8192);function d(t,e,r,n){var i=e[n],a=t[r-1];t[i]=a,e[a]=i}function g(t,e,r,n){t[r]=n,e[n]=r}},{\"./sort\":101,\"bit-twiddle\":92,\"typedarray-pool\":545}],103:[function(t,e,r){},{}],104:[function(t,e,r){var n=Object.create||function(t){var e=function(){};return e.prototype=t,new e},i=Object.keys||function(t){var e=[];for(var r in t)Object.prototype.hasOwnProperty.call(t,r)&&e.push(r);return r},a=Function.prototype.bind||function(t){var e=this;return function(){return e.apply(t,arguments)}};function o(){this._events&&Object.prototype.hasOwnProperty.call(this,\"_events\")||(this._events=n(null),this._eventsCount=0),this._maxListeners=this._maxListeners||void 0}e.exports=o,o.EventEmitter=o,o.prototype._events=void 0,o.prototype._maxListeners=void 0;var s,l=10;try{var c={};Object.defineProperty&&Object.defineProperty(c,\"x\",{value:0}),s=0===c.x}catch(t){s=!1}function u(t){return void 0===t._maxListeners?o.defaultMaxListeners:t._maxListeners}function h(t,e,r,i){var a,o,s;if(\"function\"!=typeof r)throw new TypeError('\"listener\" argument must be a function');if((o=t._events)?(o.newListener&&(t.emit(\"newListener\",e,r.listener?r.listener:r),o=t._events),s=o[e]):(o=t._events=n(null),t._eventsCount=0),s){if(\"function\"==typeof s?s=o[e]=i?[r,s]:[s,r]:i?s.unshift(r):s.push(r),!s.warned&&(a=u(t))&&a>0&&s.length>a){s.warned=!0;var l=new Error(\"Possible EventEmitter memory leak detected. \"+s.length+' \"'+String(e)+'\" listeners added. Use emitter.setMaxListeners() to increase limit.');l.name=\"MaxListenersExceededWarning\",l.emitter=t,l.type=e,l.count=s.length,\"object\"==typeof console&&console.warn&&console.warn(\"%s: %s\",l.name,l.message)}}else s=o[e]=r,++t._eventsCount;return t}function f(){if(!this.fired)switch(this.target.removeListener(this.type,this.wrapFn),this.fired=!0,arguments.length){case 0:return this.listener.call(this.target);case 1:return this.listener.call(this.target,arguments[0]);case 2:return this.listener.call(this.target,arguments[0],arguments[1]);case 3:return this.listener.call(this.target,arguments[0],arguments[1],arguments[2]);default:for(var t=new Array(arguments.length),e=0;e<t.length;++e)t[e]=arguments[e];this.listener.apply(this.target,t)}}function p(t,e,r){var n={fired:!1,wrapFn:void 0,target:t,type:e,listener:r},i=a.call(f,n);return i.listener=r,n.wrapFn=i,i}function d(t,e,r){var n=t._events;if(!n)return[];var i=n[e];return i?\"function\"==typeof i?r?[i.listener||i]:[i]:r?function(t){for(var e=new Array(t.length),r=0;r<e.length;++r)e[r]=t[r].listener||t[r];return e}(i):v(i,i.length):[]}function g(t){var e=this._events;if(e){var r=e[t];if(\"function\"==typeof r)return 1;if(r)return r.length}return 0}function v(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t[n];return r}s?Object.defineProperty(o,\"defaultMaxListeners\",{enumerable:!0,get:function(){return l},set:function(t){if(\"number\"!=typeof t||t<0||t!=t)throw new TypeError('\"defaultMaxListeners\" must be a positive number');l=t}}):o.defaultMaxListeners=l,o.prototype.setMaxListeners=function(t){if(\"number\"!=typeof t||t<0||isNaN(t))throw new TypeError('\"n\" argument must be a positive number');return this._maxListeners=t,this},o.prototype.getMaxListeners=function(){return u(this)},o.prototype.emit=function(t){var e,r,n,i,a,o,s=\"error\"===t;if(o=this._events)s=s&&null==o.error;else if(!s)return!1;if(s){if(arguments.length>1&&(e=arguments[1]),e instanceof Error)throw e;var l=new Error('Unhandled \"error\" event. ('+e+\")\");throw l.context=e,l}if(!(r=o[t]))return!1;var c=\"function\"==typeof r;switch(n=arguments.length){case 1:!function(t,e,r){if(e)t.call(r);else for(var n=t.length,i=v(t,n),a=0;a<n;++a)i[a].call(r)}(r,c,this);break;case 2:!function(t,e,r,n){if(e)t.call(r,n);else for(var i=t.length,a=v(t,i),o=0;o<i;++o)a[o].call(r,n)}(r,c,this,arguments[1]);break;case 3:!function(t,e,r,n,i){if(e)t.call(r,n,i);else for(var a=t.length,o=v(t,a),s=0;s<a;++s)o[s].call(r,n,i)}(r,c,this,arguments[1],arguments[2]);break;case 4:!function(t,e,r,n,i,a){if(e)t.call(r,n,i,a);else for(var o=t.length,s=v(t,o),l=0;l<o;++l)s[l].call(r,n,i,a)}(r,c,this,arguments[1],arguments[2],arguments[3]);break;default:for(i=new Array(n-1),a=1;a<n;a++)i[a-1]=arguments[a];!function(t,e,r,n){if(e)t.apply(r,n);else for(var i=t.length,a=v(t,i),o=0;o<i;++o)a[o].apply(r,n)}(r,c,this,i)}return!0},o.prototype.addListener=function(t,e){return h(this,t,e,!1)},o.prototype.on=o.prototype.addListener,o.prototype.prependListener=function(t,e){return h(this,t,e,!0)},o.prototype.once=function(t,e){if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');return this.on(t,p(this,t,e)),this},o.prototype.prependOnceListener=function(t,e){if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');return this.prependListener(t,p(this,t,e)),this},o.prototype.removeListener=function(t,e){var r,i,a,o,s;if(\"function\"!=typeof e)throw new TypeError('\"listener\" argument must be a function');if(!(i=this._events))return this;if(!(r=i[t]))return this;if(r===e||r.listener===e)0==--this._eventsCount?this._events=n(null):(delete i[t],i.removeListener&&this.emit(\"removeListener\",t,r.listener||e));else if(\"function\"!=typeof r){for(a=-1,o=r.length-1;o>=0;o--)if(r[o]===e||r[o].listener===e){s=r[o].listener,a=o;break}if(a<0)return this;0===a?r.shift():function(t,e){for(var r=e,n=r+1,i=t.length;n<i;r+=1,n+=1)t[r]=t[n];t.pop()}(r,a),1===r.length&&(i[t]=r[0]),i.removeListener&&this.emit(\"removeListener\",t,s||e)}return this},o.prototype.removeAllListeners=function(t){var e,r,a;if(!(r=this._events))return this;if(!r.removeListener)return 0===arguments.length?(this._events=n(null),this._eventsCount=0):r[t]&&(0==--this._eventsCount?this._events=n(null):delete r[t]),this;if(0===arguments.length){var o,s=i(r);for(a=0;a<s.length;++a)\"removeListener\"!==(o=s[a])&&this.removeAllListeners(o);return this.removeAllListeners(\"removeListener\"),this._events=n(null),this._eventsCount=0,this}if(\"function\"==typeof(e=r[t]))this.removeListener(t,e);else if(e)for(a=e.length-1;a>=0;a--)this.removeListener(t,e[a]);return this},o.prototype.listeners=function(t){return d(this,t,!0)},o.prototype.rawListeners=function(t){return d(this,t,!1)},o.listenerCount=function(t,e){return\"function\"==typeof t.listenerCount?t.listenerCount(e):g.call(t,e)},o.prototype.listenerCount=g,o.prototype.eventNames=function(){return this._eventsCount>0?Reflect.ownKeys(this._events):[]}},{}],105:[function(t,e,r){(function(e){\"use strict\";var n=t(\"base64-js\"),i=t(\"ieee754\");r.Buffer=e,r.SlowBuffer=function(t){+t!=t&&(t=0);return e.alloc(+t)},r.INSPECT_MAX_BYTES=50;var a=2147483647;function o(t){if(t>a)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"');var r=new Uint8Array(t);return r.__proto__=e.prototype,r}function e(t,e,r){if(\"number\"==typeof t){if(\"string\"==typeof e)throw new TypeError('The \"string\" argument must be of type string. Received type number');return c(t)}return s(t,e,r)}function s(t,r,n){if(\"string\"==typeof t)return function(t,r){\"string\"==typeof r&&\"\"!==r||(r=\"utf8\");if(!e.isEncoding(r))throw new TypeError(\"Unknown encoding: \"+r);var n=0|f(t,r),i=o(n),a=i.write(t,r);a!==n&&(i=i.slice(0,a));return i}(t,r);if(ArrayBuffer.isView(t))return u(t);if(null==t)throw TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t);if(N(t,ArrayBuffer)||t&&N(t.buffer,ArrayBuffer))return function(t,r,n){if(r<0||t.byteLength<r)throw new RangeError('\"offset\" is outside of buffer bounds');if(t.byteLength<r+(n||0))throw new RangeError('\"length\" is outside of buffer bounds');var i;i=void 0===r&&void 0===n?new Uint8Array(t):void 0===n?new Uint8Array(t,r):new Uint8Array(t,r,n);return i.__proto__=e.prototype,i}(t,r,n);if(\"number\"==typeof t)throw new TypeError('The \"value\" argument must not be of type number. Received type number');var i=t.valueOf&&t.valueOf();if(null!=i&&i!==t)return e.from(i,r,n);var a=function(t){if(e.isBuffer(t)){var r=0|h(t.length),n=o(r);return 0===n.length?n:(t.copy(n,0,0,r),n)}if(void 0!==t.length)return\"number\"!=typeof t.length||j(t.length)?o(0):u(t);if(\"Buffer\"===t.type&&Array.isArray(t.data))return u(t.data)}(t);if(a)return a;if(\"undefined\"!=typeof Symbol&&null!=Symbol.toPrimitive&&\"function\"==typeof t[Symbol.toPrimitive])return e.from(t[Symbol.toPrimitive](\"string\"),r,n);throw new TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t)}function l(t){if(\"number\"!=typeof t)throw new TypeError('\"size\" argument must be of type number');if(t<0)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"')}function c(t){return l(t),o(t<0?0:0|h(t))}function u(t){for(var e=t.length<0?0:0|h(t.length),r=o(e),n=0;n<e;n+=1)r[n]=255&t[n];return r}function h(t){if(t>=a)throw new RangeError(\"Attempt to allocate Buffer larger than maximum size: 0x\"+a.toString(16)+\" bytes\");return 0|t}function f(t,r){if(e.isBuffer(t))return t.length;if(ArrayBuffer.isView(t)||N(t,ArrayBuffer))return t.byteLength;if(\"string\"!=typeof t)throw new TypeError('The \"string\" argument must be one of type string, Buffer, or ArrayBuffer. Received type '+typeof t);var n=t.length,i=arguments.length>2&&!0===arguments[2];if(!i&&0===n)return 0;for(var a=!1;;)switch(r){case\"ascii\":case\"latin1\":case\"binary\":return n;case\"utf8\":case\"utf-8\":return R(t).length;case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return 2*n;case\"hex\":return n>>>1;case\"base64\":return F(t).length;default:if(a)return i?-1:R(t).length;r=(\"\"+r).toLowerCase(),a=!0}}function p(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function d(t,r,n,i,a){if(0===t.length)return-1;if(\"string\"==typeof n?(i=n,n=0):n>2147483647?n=2147483647:n<-2147483648&&(n=-2147483648),j(n=+n)&&(n=a?0:t.length-1),n<0&&(n=t.length+n),n>=t.length){if(a)return-1;n=t.length-1}else if(n<0){if(!a)return-1;n=0}if(\"string\"==typeof r&&(r=e.from(r,i)),e.isBuffer(r))return 0===r.length?-1:g(t,r,n,i,a);if(\"number\"==typeof r)return r&=255,\"function\"==typeof Uint8Array.prototype.indexOf?a?Uint8Array.prototype.indexOf.call(t,r,n):Uint8Array.prototype.lastIndexOf.call(t,r,n):g(t,[r],n,i,a);throw new TypeError(\"val must be string, number or Buffer\")}function g(t,e,r,n,i){var a,o=1,s=t.length,l=e.length;if(void 0!==n&&(\"ucs2\"===(n=String(n).toLowerCase())||\"ucs-2\"===n||\"utf16le\"===n||\"utf-16le\"===n)){if(t.length<2||e.length<2)return-1;o=2,s/=2,l/=2,r/=2}function c(t,e){return 1===o?t[e]:t.readUInt16BE(e*o)}if(i){var u=-1;for(a=r;a<s;a++)if(c(t,a)===c(e,-1===u?0:a-u)){if(-1===u&&(u=a),a-u+1===l)return u*o}else-1!==u&&(a-=a-u),u=-1}else for(r+l>s&&(r=s-l),a=r;a>=0;a--){for(var h=!0,f=0;f<l;f++)if(c(t,a+f)!==c(e,f)){h=!1;break}if(h)return a}return-1}function v(t,e,r,n){r=Number(r)||0;var i=t.length-r;n?(n=Number(n))>i&&(n=i):n=i;var a=e.length;n>a/2&&(n=a/2);for(var o=0;o<n;++o){var s=parseInt(e.substr(2*o,2),16);if(j(s))return o;t[r+o]=s}return o}function m(t,e,r,n){return B(R(e,t.length-r),t,r,n)}function y(t,e,r,n){return B(function(t){for(var e=[],r=0;r<t.length;++r)e.push(255&t.charCodeAt(r));return e}(e),t,r,n)}function x(t,e,r,n){return y(t,e,r,n)}function b(t,e,r,n){return B(F(e),t,r,n)}function _(t,e,r,n){return B(function(t,e){for(var r,n,i,a=[],o=0;o<t.length&&!((e-=2)<0);++o)r=t.charCodeAt(o),n=r>>8,i=r%256,a.push(i),a.push(n);return a}(e,t.length-r),t,r,n)}function w(t,e,r){return 0===e&&r===t.length?n.fromByteArray(t):n.fromByteArray(t.slice(e,r))}function k(t,e,r){r=Math.min(t.length,r);for(var n=[],i=e;i<r;){var a,o,s,l,c=t[i],u=null,h=c>239?4:c>223?3:c>191?2:1;if(i+h<=r)switch(h){case 1:c<128&&(u=c);break;case 2:128==(192&(a=t[i+1]))&&(l=(31&c)<<6|63&a)>127&&(u=l);break;case 3:a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&(l=(15&c)<<12|(63&a)<<6|63&o)>2047&&(l<55296||l>57343)&&(u=l);break;case 4:a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&(l=(15&c)<<18|(63&a)<<12|(63&o)<<6|63&s)>65535&&l<1114112&&(u=l)}null===u?(u=65533,h=1):u>65535&&(u-=65536,n.push(u>>>10&1023|55296),u=56320|1023&u),n.push(u),i+=h}return function(t){var e=t.length;if(e<=T)return String.fromCharCode.apply(String,t);var r=\"\",n=0;for(;n<e;)r+=String.fromCharCode.apply(String,t.slice(n,n+=T));return r}(n)}r.kMaxLength=a,e.TYPED_ARRAY_SUPPORT=function(){try{var t=new Uint8Array(1);return t.__proto__={__proto__:Uint8Array.prototype,foo:function(){return 42}},42===t.foo()}catch(t){return!1}}(),e.TYPED_ARRAY_SUPPORT||\"undefined\"==typeof console||\"function\"!=typeof console.error||console.error(\"This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support.\"),Object.defineProperty(e.prototype,\"parent\",{enumerable:!0,get:function(){if(e.isBuffer(this))return this.buffer}}),Object.defineProperty(e.prototype,\"offset\",{enumerable:!0,get:function(){if(e.isBuffer(this))return this.byteOffset}}),\"undefined\"!=typeof Symbol&&null!=Symbol.species&&e[Symbol.species]===e&&Object.defineProperty(e,Symbol.species,{value:null,configurable:!0,enumerable:!1,writable:!1}),e.poolSize=8192,e.from=function(t,e,r){return s(t,e,r)},e.prototype.__proto__=Uint8Array.prototype,e.__proto__=Uint8Array,e.alloc=function(t,e,r){return function(t,e,r){return l(t),t<=0?o(t):void 0!==e?\"string\"==typeof r?o(t).fill(e,r):o(t).fill(e):o(t)}(t,e,r)},e.allocUnsafe=function(t){return c(t)},e.allocUnsafeSlow=function(t){return c(t)},e.isBuffer=function(t){return null!=t&&!0===t._isBuffer&&t!==e.prototype},e.compare=function(t,r){if(N(t,Uint8Array)&&(t=e.from(t,t.offset,t.byteLength)),N(r,Uint8Array)&&(r=e.from(r,r.offset,r.byteLength)),!e.isBuffer(t)||!e.isBuffer(r))throw new TypeError('The \"buf1\", \"buf2\" arguments must be one of type Buffer or Uint8Array');if(t===r)return 0;for(var n=t.length,i=r.length,a=0,o=Math.min(n,i);a<o;++a)if(t[a]!==r[a]){n=t[a],i=r[a];break}return n<i?-1:i<n?1:0},e.isEncoding=function(t){switch(String(t).toLowerCase()){case\"hex\":case\"utf8\":case\"utf-8\":case\"ascii\":case\"latin1\":case\"binary\":case\"base64\":case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return!0;default:return!1}},e.concat=function(t,r){if(!Array.isArray(t))throw new TypeError('\"list\" argument must be an Array of Buffers');if(0===t.length)return e.alloc(0);var n;if(void 0===r)for(r=0,n=0;n<t.length;++n)r+=t[n].length;var i=e.allocUnsafe(r),a=0;for(n=0;n<t.length;++n){var o=t[n];if(N(o,Uint8Array)&&(o=e.from(o)),!e.isBuffer(o))throw new TypeError('\"list\" argument must be an Array of Buffers');o.copy(i,a),a+=o.length}return i},e.byteLength=f,e.prototype._isBuffer=!0,e.prototype.swap16=function(){var t=this.length;if(t%2!=0)throw new RangeError(\"Buffer size must be a multiple of 16-bits\");for(var e=0;e<t;e+=2)p(this,e,e+1);return this},e.prototype.swap32=function(){var t=this.length;if(t%4!=0)throw new RangeError(\"Buffer size must be a multiple of 32-bits\");for(var e=0;e<t;e+=4)p(this,e,e+3),p(this,e+1,e+2);return this},e.prototype.swap64=function(){var t=this.length;if(t%8!=0)throw new RangeError(\"Buffer size must be a multiple of 64-bits\");for(var e=0;e<t;e+=8)p(this,e,e+7),p(this,e+1,e+6),p(this,e+2,e+5),p(this,e+3,e+4);return this},e.prototype.toString=function(){var t=this.length;return 0===t?\"\":0===arguments.length?k(this,0,t):function(t,e,r){var n=!1;if((void 0===e||e<0)&&(e=0),e>this.length)return\"\";if((void 0===r||r>this.length)&&(r=this.length),r<=0)return\"\";if((r>>>=0)<=(e>>>=0))return\"\";for(t||(t=\"utf8\");;)switch(t){case\"hex\":return S(this,e,r);case\"utf8\":case\"utf-8\":return k(this,e,r);case\"ascii\":return A(this,e,r);case\"latin1\":case\"binary\":return M(this,e,r);case\"base64\":return w(this,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return E(this,e,r);default:if(n)throw new TypeError(\"Unknown encoding: \"+t);t=(t+\"\").toLowerCase(),n=!0}}.apply(this,arguments)},e.prototype.toLocaleString=e.prototype.toString,e.prototype.equals=function(t){if(!e.isBuffer(t))throw new TypeError(\"Argument must be a Buffer\");return this===t||0===e.compare(this,t)},e.prototype.inspect=function(){var t=\"\",e=r.INSPECT_MAX_BYTES;return t=this.toString(\"hex\",0,e).replace(/(.{2})/g,\"$1 \").trim(),this.length>e&&(t+=\" ... \"),\"<Buffer \"+t+\">\"},e.prototype.compare=function(t,r,n,i,a){if(N(t,Uint8Array)&&(t=e.from(t,t.offset,t.byteLength)),!e.isBuffer(t))throw new TypeError('The \"target\" argument must be one of type Buffer or Uint8Array. Received type '+typeof t);if(void 0===r&&(r=0),void 0===n&&(n=t?t.length:0),void 0===i&&(i=0),void 0===a&&(a=this.length),r<0||n>t.length||i<0||a>this.length)throw new RangeError(\"out of range index\");if(i>=a&&r>=n)return 0;if(i>=a)return-1;if(r>=n)return 1;if(this===t)return 0;for(var o=(a>>>=0)-(i>>>=0),s=(n>>>=0)-(r>>>=0),l=Math.min(o,s),c=this.slice(i,a),u=t.slice(r,n),h=0;h<l;++h)if(c[h]!==u[h]){o=c[h],s=u[h];break}return o<s?-1:s<o?1:0},e.prototype.includes=function(t,e,r){return-1!==this.indexOf(t,e,r)},e.prototype.indexOf=function(t,e,r){return d(this,t,e,r,!0)},e.prototype.lastIndexOf=function(t,e,r){return d(this,t,e,r,!1)},e.prototype.write=function(t,e,r,n){if(void 0===e)n=\"utf8\",r=this.length,e=0;else if(void 0===r&&\"string\"==typeof e)n=e,r=this.length,e=0;else{if(!isFinite(e))throw new Error(\"Buffer.write(string, encoding, offset[, length]) is no longer supported\");e>>>=0,isFinite(r)?(r>>>=0,void 0===n&&(n=\"utf8\")):(n=r,r=void 0)}var i=this.length-e;if((void 0===r||r>i)&&(r=i),t.length>0&&(r<0||e<0)||e>this.length)throw new RangeError(\"Attempt to write outside buffer bounds\");n||(n=\"utf8\");for(var a=!1;;)switch(n){case\"hex\":return v(this,t,e,r);case\"utf8\":case\"utf-8\":return m(this,t,e,r);case\"ascii\":return y(this,t,e,r);case\"latin1\":case\"binary\":return x(this,t,e,r);case\"base64\":return b(this,t,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return _(this,t,e,r);default:if(a)throw new TypeError(\"Unknown encoding: \"+n);n=(\"\"+n).toLowerCase(),a=!0}},e.prototype.toJSON=function(){return{type:\"Buffer\",data:Array.prototype.slice.call(this._arr||this,0)}};var T=4096;function A(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(127&t[i]);return n}function M(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(t[i]);return n}function S(t,e,r){var n=t.length;(!e||e<0)&&(e=0),(!r||r<0||r>n)&&(r=n);for(var i=\"\",a=e;a<r;++a)i+=D(t[a]);return i}function E(t,e,r){for(var n=t.slice(e,r),i=\"\",a=0;a<n.length;a+=2)i+=String.fromCharCode(n[a]+256*n[a+1]);return i}function C(t,e,r){if(t%1!=0||t<0)throw new RangeError(\"offset is not uint\");if(t+e>r)throw new RangeError(\"Trying to access beyond buffer length\")}function L(t,r,n,i,a,o){if(!e.isBuffer(t))throw new TypeError('\"buffer\" argument must be a Buffer instance');if(r>a||r<o)throw new RangeError('\"value\" argument is out of bounds');if(n+i>t.length)throw new RangeError(\"Index out of range\")}function P(t,e,r,n,i,a){if(r+n>t.length)throw new RangeError(\"Index out of range\");if(r<0)throw new RangeError(\"Index out of range\")}function O(t,e,r,n,a){return e=+e,r>>>=0,a||P(t,0,r,4),i.write(t,e,r,n,23,4),r+4}function z(t,e,r,n,a){return e=+e,r>>>=0,a||P(t,0,r,8),i.write(t,e,r,n,52,8),r+8}e.prototype.slice=function(t,r){var n=this.length;(t=~~t)<0?(t+=n)<0&&(t=0):t>n&&(t=n),(r=void 0===r?n:~~r)<0?(r+=n)<0&&(r=0):r>n&&(r=n),r<t&&(r=t);var i=this.subarray(t,r);return i.__proto__=e.prototype,i},e.prototype.readUIntLE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n},e.prototype.readUIntBE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t+--e],i=1;e>0&&(i*=256);)n+=this[t+--e]*i;return n},e.prototype.readUInt8=function(t,e){return t>>>=0,e||C(t,1,this.length),this[t]},e.prototype.readUInt16LE=function(t,e){return t>>>=0,e||C(t,2,this.length),this[t]|this[t+1]<<8},e.prototype.readUInt16BE=function(t,e){return t>>>=0,e||C(t,2,this.length),this[t]<<8|this[t+1]},e.prototype.readUInt32LE=function(t,e){return t>>>=0,e||C(t,4,this.length),(this[t]|this[t+1]<<8|this[t+2]<<16)+16777216*this[t+3]},e.prototype.readUInt32BE=function(t,e){return t>>>=0,e||C(t,4,this.length),16777216*this[t]+(this[t+1]<<16|this[t+2]<<8|this[t+3])},e.prototype.readIntLE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n>=(i*=128)&&(n-=Math.pow(2,8*e)),n},e.prototype.readIntBE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=e,i=1,a=this[t+--n];n>0&&(i*=256);)a+=this[t+--n]*i;return a>=(i*=128)&&(a-=Math.pow(2,8*e)),a},e.prototype.readInt8=function(t,e){return t>>>=0,e||C(t,1,this.length),128&this[t]?-1*(255-this[t]+1):this[t]},e.prototype.readInt16LE=function(t,e){t>>>=0,e||C(t,2,this.length);var r=this[t]|this[t+1]<<8;return 32768&r?4294901760|r:r},e.prototype.readInt16BE=function(t,e){t>>>=0,e||C(t,2,this.length);var r=this[t+1]|this[t]<<8;return 32768&r?4294901760|r:r},e.prototype.readInt32LE=function(t,e){return t>>>=0,e||C(t,4,this.length),this[t]|this[t+1]<<8|this[t+2]<<16|this[t+3]<<24},e.prototype.readInt32BE=function(t,e){return t>>>=0,e||C(t,4,this.length),this[t]<<24|this[t+1]<<16|this[t+2]<<8|this[t+3]},e.prototype.readFloatLE=function(t,e){return t>>>=0,e||C(t,4,this.length),i.read(this,t,!0,23,4)},e.prototype.readFloatBE=function(t,e){return t>>>=0,e||C(t,4,this.length),i.read(this,t,!1,23,4)},e.prototype.readDoubleLE=function(t,e){return t>>>=0,e||C(t,8,this.length),i.read(this,t,!0,52,8)},e.prototype.readDoubleBE=function(t,e){return t>>>=0,e||C(t,8,this.length),i.read(this,t,!1,52,8)},e.prototype.writeUIntLE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||L(this,t,e,r,Math.pow(2,8*r)-1,0);var i=1,a=0;for(this[e]=255&t;++a<r&&(i*=256);)this[e+a]=t/i&255;return e+r},e.prototype.writeUIntBE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||L(this,t,e,r,Math.pow(2,8*r)-1,0);var i=r-1,a=1;for(this[e+i]=255&t;--i>=0&&(a*=256);)this[e+i]=t/a&255;return e+r},e.prototype.writeUInt8=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,1,255,0),this[e]=255&t,e+1},e.prototype.writeUInt16LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,65535,0),this[e]=255&t,this[e+1]=t>>>8,e+2},e.prototype.writeUInt16BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,65535,0),this[e]=t>>>8,this[e+1]=255&t,e+2},e.prototype.writeUInt32LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,4294967295,0),this[e+3]=t>>>24,this[e+2]=t>>>16,this[e+1]=t>>>8,this[e]=255&t,e+4},e.prototype.writeUInt32BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,4294967295,0),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},e.prototype.writeIntLE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);L(this,t,e,r,i-1,-i)}var a=0,o=1,s=0;for(this[e]=255&t;++a<r&&(o*=256);)t<0&&0===s&&0!==this[e+a-1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},e.prototype.writeIntBE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);L(this,t,e,r,i-1,-i)}var a=r-1,o=1,s=0;for(this[e+a]=255&t;--a>=0&&(o*=256);)t<0&&0===s&&0!==this[e+a+1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},e.prototype.writeInt8=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,1,127,-128),t<0&&(t=255+t+1),this[e]=255&t,e+1},e.prototype.writeInt16LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,32767,-32768),this[e]=255&t,this[e+1]=t>>>8,e+2},e.prototype.writeInt16BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,32767,-32768),this[e]=t>>>8,this[e+1]=255&t,e+2},e.prototype.writeInt32LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,2147483647,-2147483648),this[e]=255&t,this[e+1]=t>>>8,this[e+2]=t>>>16,this[e+3]=t>>>24,e+4},e.prototype.writeInt32BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,2147483647,-2147483648),t<0&&(t=4294967295+t+1),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},e.prototype.writeFloatLE=function(t,e,r){return O(this,t,e,!0,r)},e.prototype.writeFloatBE=function(t,e,r){return O(this,t,e,!1,r)},e.prototype.writeDoubleLE=function(t,e,r){return z(this,t,e,!0,r)},e.prototype.writeDoubleBE=function(t,e,r){return z(this,t,e,!1,r)},e.prototype.copy=function(t,r,n,i){if(!e.isBuffer(t))throw new TypeError(\"argument should be a Buffer\");if(n||(n=0),i||0===i||(i=this.length),r>=t.length&&(r=t.length),r||(r=0),i>0&&i<n&&(i=n),i===n)return 0;if(0===t.length||0===this.length)return 0;if(r<0)throw new RangeError(\"targetStart out of bounds\");if(n<0||n>=this.length)throw new RangeError(\"Index out of range\");if(i<0)throw new RangeError(\"sourceEnd out of bounds\");i>this.length&&(i=this.length),t.length-r<i-n&&(i=t.length-r+n);var a=i-n;if(this===t&&\"function\"==typeof Uint8Array.prototype.copyWithin)this.copyWithin(r,n,i);else if(this===t&&n<r&&r<i)for(var o=a-1;o>=0;--o)t[o+r]=this[o+n];else Uint8Array.prototype.set.call(t,this.subarray(n,i),r);return a},e.prototype.fill=function(t,r,n,i){if(\"string\"==typeof t){if(\"string\"==typeof r?(i=r,r=0,n=this.length):\"string\"==typeof n&&(i=n,n=this.length),void 0!==i&&\"string\"!=typeof i)throw new TypeError(\"encoding must be a string\");if(\"string\"==typeof i&&!e.isEncoding(i))throw new TypeError(\"Unknown encoding: \"+i);if(1===t.length){var a=t.charCodeAt(0);(\"utf8\"===i&&a<128||\"latin1\"===i)&&(t=a)}}else\"number\"==typeof t&&(t&=255);if(r<0||this.length<r||this.length<n)throw new RangeError(\"Out of range index\");if(n<=r)return this;var o;if(r>>>=0,n=void 0===n?this.length:n>>>0,t||(t=0),\"number\"==typeof t)for(o=r;o<n;++o)this[o]=t;else{var s=e.isBuffer(t)?t:e.from(t,i),l=s.length;if(0===l)throw new TypeError('The value \"'+t+'\" is invalid for argument \"value\"');for(o=0;o<n-r;++o)this[o+r]=s[o%l]}return this};var I=/[^+\\/0-9A-Za-z-_]/g;function D(t){return t<16?\"0\"+t.toString(16):t.toString(16)}function R(t,e){var r;e=e||1/0;for(var n=t.length,i=null,a=[],o=0;o<n;++o){if((r=t.charCodeAt(o))>55295&&r<57344){if(!i){if(r>56319){(e-=3)>-1&&a.push(239,191,189);continue}if(o+1===n){(e-=3)>-1&&a.push(239,191,189);continue}i=r;continue}if(r<56320){(e-=3)>-1&&a.push(239,191,189),i=r;continue}r=65536+(i-55296<<10|r-56320)}else i&&(e-=3)>-1&&a.push(239,191,189);if(i=null,r<128){if((e-=1)<0)break;a.push(r)}else if(r<2048){if((e-=2)<0)break;a.push(r>>6|192,63&r|128)}else if(r<65536){if((e-=3)<0)break;a.push(r>>12|224,r>>6&63|128,63&r|128)}else{if(!(r<1114112))throw new Error(\"Invalid code point\");if((e-=4)<0)break;a.push(r>>18|240,r>>12&63|128,r>>6&63|128,63&r|128)}}return a}function F(t){return n.toByteArray(function(t){if((t=(t=t.split(\"=\")[0]).trim().replace(I,\"\")).length<2)return\"\";for(;t.length%4!=0;)t+=\"=\";return t}(t))}function B(t,e,r,n){for(var i=0;i<n&&!(i+r>=e.length||i>=t.length);++i)e[i+r]=t[i];return i}function N(t,e){return t instanceof e||null!=t&&null!=t.constructor&&null!=t.constructor.name&&t.constructor.name===e.name}function j(t){return t!=t}}).call(this,t(\"buffer\").Buffer)},{\"base64-js\":74,buffer:105,ieee754:412}],106:[function(t,e,r){\"use strict\";var n=t(\"./lib/monotone\"),i=t(\"./lib/triangulation\"),a=t(\"./lib/delaunay\"),o=t(\"./lib/filter\");function s(t){return[Math.min(t[0],t[1]),Math.max(t[0],t[1])]}function l(t,e){return t[0]-e[0]||t[1]-e[1]}function c(t,e,r){return e in t?t[e]:r}e.exports=function(t,e,r){Array.isArray(e)?(r=r||{},e=e||[]):(r=e||{},e=[]);var u=!!c(r,\"delaunay\",!0),h=!!c(r,\"interior\",!0),f=!!c(r,\"exterior\",!0),p=!!c(r,\"infinity\",!1);if(!h&&!f||0===t.length)return[];var d=n(t,e);if(u||h!==f||p){for(var g=i(t.length,function(t){return t.map(s).sort(l)}(e)),v=0;v<d.length;++v){var m=d[v];g.addTriangle(m[0],m[1],m[2])}return u&&a(t,g),f?h?p?o(g,0,p):g.cells():o(g,1,p):o(g,-1)}return d}},{\"./lib/delaunay\":107,\"./lib/filter\":108,\"./lib/monotone\":109,\"./lib/triangulation\":110}],107:[function(t,e,r){\"use strict\";var n=t(\"robust-in-sphere\")[4];t(\"binary-search-bounds\");function i(t,e,r,i,a,o){var s=e.opposite(i,a);if(!(s<0)){if(a<i){var l=i;i=a,a=l,l=o,o=s,s=l}e.isConstraint(i,a)||n(t[i],t[a],t[o],t[s])<0&&r.push(i,a)}}e.exports=function(t,e){for(var r=[],a=t.length,o=e.stars,s=0;s<a;++s)for(var l=o[s],c=1;c<l.length;c+=2){var u=l[c];if(!(u<s)&&!e.isConstraint(s,u)){for(var h=l[c-1],f=-1,p=1;p<l.length;p+=2)if(l[p-1]===u){f=l[p];break}f<0||n(t[s],t[u],t[h],t[f])<0&&r.push(s,u)}}for(;r.length>0;){for(var u=r.pop(),s=r.pop(),h=-1,f=-1,l=o[s],d=1;d<l.length;d+=2){var g=l[d-1],v=l[d];g===u?f=v:v===u&&(h=g)}h<0||f<0||(n(t[s],t[u],t[h],t[f])>=0||(e.flip(s,u),i(t,e,r,h,s,f),i(t,e,r,s,f,h),i(t,e,r,f,u,h),i(t,e,r,u,h,f)))}}},{\"binary-search-bounds\":111,\"robust-in-sphere\":508}],108:[function(t,e,r){\"use strict\";var n,i=t(\"binary-search-bounds\");function a(t,e,r,n,i,a,o){this.cells=t,this.neighbor=e,this.flags=n,this.constraint=r,this.active=i,this.next=a,this.boundary=o}function o(t,e){return t[0]-e[0]||t[1]-e[1]||t[2]-e[2]}e.exports=function(t,e,r){var n=function(t,e){for(var r=t.cells(),n=r.length,i=0;i<n;++i){var s=r[i],l=s[0],c=s[1],u=s[2];c<u?c<l&&(s[0]=c,s[1]=u,s[2]=l):u<l&&(s[0]=u,s[1]=l,s[2]=c)}r.sort(o);for(var h=new Array(n),i=0;i<h.length;++i)h[i]=0;var f=[],p=[],d=new Array(3*n),g=new Array(3*n),v=null;e&&(v=[]);for(var m=new a(r,d,g,h,f,p,v),i=0;i<n;++i)for(var s=r[i],y=0;y<3;++y){var l=s[y],c=s[(y+1)%3],x=d[3*i+y]=m.locate(c,l,t.opposite(c,l)),b=g[3*i+y]=t.isConstraint(l,c);x<0&&(b?p.push(i):(f.push(i),h[i]=1),e&&v.push([c,l,-1]))}return m}(t,r);if(0===e)return r?n.cells.concat(n.boundary):n.cells;var i=1,s=n.active,l=n.next,c=n.flags,u=n.cells,h=n.constraint,f=n.neighbor;for(;s.length>0||l.length>0;){for(;s.length>0;){var p=s.pop();if(c[p]!==-i){c[p]=i;u[p];for(var d=0;d<3;++d){var g=f[3*p+d];g>=0&&0===c[g]&&(h[3*p+d]?l.push(g):(s.push(g),c[g]=i))}}}var v=l;l=s,s=v,l.length=0,i=-i}var m=function(t,e,r){for(var n=0,i=0;i<t.length;++i)e[i]===r&&(t[n++]=t[i]);return t.length=n,t}(u,c,e);if(r)return m.concat(n.boundary);return m},a.prototype.locate=(n=[0,0,0],function(t,e,r){var a=t,s=e,l=r;return e<r?e<t&&(a=e,s=r,l=t):r<t&&(a=r,s=t,l=e),a<0?-1:(n[0]=a,n[1]=s,n[2]=l,i.eq(this.cells,n,o))})},{\"binary-search-bounds\":111}],109:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"robust-orientation\")[3],a=0,o=1,s=2;function l(t,e,r,n,i){this.a=t,this.b=e,this.idx=r,this.lowerIds=n,this.upperIds=i}function c(t,e,r,n){this.a=t,this.b=e,this.type=r,this.idx=n}function u(t,e){var r=t.a[0]-e.a[0]||t.a[1]-e.a[1]||t.type-e.type;return r||(t.type!==a&&(r=i(t.a,t.b,e.b))?r:t.idx-e.idx)}function h(t,e){return i(t.a,t.b,e)}function f(t,e,r,a,o){for(var s=n.lt(e,a,h),l=n.gt(e,a,h),c=s;c<l;++c){for(var u=e[c],f=u.lowerIds,p=f.length;p>1&&i(r[f[p-2]],r[f[p-1]],a)>0;)t.push([f[p-1],f[p-2],o]),p-=1;f.length=p,f.push(o);var d=u.upperIds;for(p=d.length;p>1&&i(r[d[p-2]],r[d[p-1]],a)<0;)t.push([d[p-2],d[p-1],o]),p-=1;d.length=p,d.push(o)}}function p(t,e){var r;return(r=t.a[0]<e.a[0]?i(t.a,t.b,e.a):i(e.b,e.a,t.a))?r:(r=e.b[0]<t.b[0]?i(t.a,t.b,e.b):i(e.b,e.a,t.b))||t.idx-e.idx}function d(t,e,r){var i=n.le(t,r,p),a=t[i],o=a.upperIds,s=o[o.length-1];a.upperIds=[s],t.splice(i+1,0,new l(r.a,r.b,r.idx,[s],o))}function g(t,e,r){var i=r.a;r.a=r.b,r.b=i;var a=n.eq(t,r,p),o=t[a];t[a-1].upperIds=o.upperIds,t.splice(a,1)}e.exports=function(t,e){for(var r=t.length,n=e.length,i=[],h=0;h<r;++h)i.push(new c(t[h],null,a,h));for(var h=0;h<n;++h){var p=e[h],v=t[p[0]],m=t[p[1]];v[0]<m[0]?i.push(new c(v,m,s,h),new c(m,v,o,h)):v[0]>m[0]&&i.push(new c(m,v,s,h),new c(v,m,o,h))}i.sort(u);for(var y=i[0].a[0]-(1+Math.abs(i[0].a[0]))*Math.pow(2,-52),x=[new l([y,1],[y,0],-1,[],[],[],[])],b=[],h=0,_=i.length;h<_;++h){var w=i[h],k=w.type;k===a?f(b,x,t,w.a,w.idx):k===s?d(x,t,w):g(x,t,w)}return b}},{\"binary-search-bounds\":111,\"robust-orientation\":510}],110:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\");function i(t,e){this.stars=t,this.edges=e}e.exports=function(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=[];return new i(r,e)};var a=i.prototype;function o(t,e,r){for(var n=1,i=t.length;n<i;n+=2)if(t[n-1]===e&&t[n]===r)return t[n-1]=t[i-2],t[n]=t[i-1],void(t.length=i-2)}a.isConstraint=function(){var t=[0,0];function e(t,e){return t[0]-e[0]||t[1]-e[1]}return function(r,i){return t[0]=Math.min(r,i),t[1]=Math.max(r,i),n.eq(this.edges,t,e)>=0}}(),a.removeTriangle=function(t,e,r){var n=this.stars;o(n[t],e,r),o(n[e],r,t),o(n[r],t,e)},a.addTriangle=function(t,e,r){var n=this.stars;n[t].push(e,r),n[e].push(r,t),n[r].push(t,e)},a.opposite=function(t,e){for(var r=this.stars[e],n=1,i=r.length;n<i;n+=2)if(r[n]===t)return r[n-1];return-1},a.flip=function(t,e){var r=this.opposite(t,e),n=this.opposite(e,t);this.removeTriangle(t,e,r),this.removeTriangle(e,t,n),this.addTriangle(t,n,r),this.addTriangle(e,r,n)},a.edges=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2)e.push([i[a],i[a+1]]);return e},a.cells=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2){var s=i[a],l=i[a+1];r<Math.min(s,l)&&e.push([r,s,l])}return e}},{\"binary-search-bounds\":111}],111:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",i?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a[m]\"];return i?e.indexOf(\"c\")<0?a.push(\";if(x===y){return m}else if(x<=y){\"):a.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):a.push(\";if(\",e,\"){i=m;\"),r?a.push(\"l=m+1}else{h=m-1}\"):a.push(\"h=m-1}else{l=m+1}\"),a.push(\"}\"),i?a.push(\"return -1};\"):a.push(\"return i};\"),a.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(typeof(c)==='function'){return P(a,(l===void 0)?0:l|0,(h===void 0)?a.length-1:h|0,y,c)}else{return A(a,(c===void 0)?0:c|0,(l===void 0)?a.length-1:l|0,y)}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],112:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1,r=1;r<t.length;++r)for(var n=0;n<r;++n)if(t[r]<t[n])e=-e;else if(t[n]===t[r])return 0;return e}},{}],113:[function(t,e,r){\"use strict\";var n=t(\"dup\"),i=t(\"robust-linear-solve\");function a(t,e){for(var r=0,n=t.length,i=0;i<n;++i)r+=t[i]*e[i];return r}function o(t){var e=t.length;if(0===e)return[];t[0].length;var r=n([t.length+1,t.length+1],1),o=n([t.length+1],1);r[e][e]=0;for(var s=0;s<e;++s){for(var l=0;l<=s;++l)r[l][s]=r[s][l]=2*a(t[s],t[l]);o[s]=a(t[s],t[s])}var c=i(r,o),u=0,h=c[e+1];for(s=0;s<h.length;++s)u+=h[s];var f=new Array(e);for(s=0;s<e;++s){h=c[s];var p=0;for(l=0;l<h.length;++l)p+=h[l];f[s]=p/u}return f}function s(t){if(0===t.length)return[];for(var e=t[0].length,r=n([e]),i=o(t),a=0;a<t.length;++a)for(var s=0;s<e;++s)r[s]+=t[a][s]*i[a];return r}s.barycenetric=o,e.exports=s},{dup:170,\"robust-linear-solve\":509}],114:[function(t,e,r){e.exports=function(t){for(var e=n(t),r=0,i=0;i<t.length;++i)for(var a=t[i],o=0;o<e.length;++o)r+=Math.pow(a[o]-e[o],2);return Math.sqrt(r/t.length)};var n=t(\"circumcenter\")},{circumcenter:113}],115:[function(t,e,r){e.exports=function(t,e,r){return e<r?t<e?e:t>r?r:t:t<r?r:t>e?e:t}},{}],116:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n;if(r){n=e;for(var i=new Array(e.length),a=0;a<e.length;++a){var o=e[a];i[a]=[o[0],o[1],r[a]]}e=i}var s=function(t,e,r){var n=d(t,[],p(t));return m(e,n,r),!!n}(t,e,!!r);for(;y(t,e,!!r);)s=!0;if(r&&s){n.length=0,r.length=0;for(var a=0;a<e.length;++a){var o=e[a];n.push([o[0],o[1]]),r.push(o[2])}}return s};var n=t(\"union-find\"),i=t(\"box-intersect\"),a=t(\"robust-segment-intersect\"),o=t(\"big-rat\"),s=t(\"big-rat/cmp\"),l=t(\"big-rat/to-float\"),c=t(\"rat-vec\"),u=t(\"nextafter\"),h=t(\"./lib/rat-seg-intersect\");function f(t){var e=l(t);return[u(e,-1/0),u(e,1/0)]}function p(t){for(var e=new Array(t.length),r=0;r<t.length;++r){var n=t[r];e[r]=[u(n[0],-1/0),u(n[1],-1/0),u(n[0],1/0),u(n[1],1/0)]}return e}function d(t,e,r){for(var a=e.length,o=new n(a),s=[],l=0;l<e.length;++l){var c=e[l],h=f(c[0]),p=f(c[1]);s.push([u(h[0],-1/0),u(p[0],-1/0),u(h[1],1/0),u(p[1],1/0)])}i(s,function(t,e){o.link(t,e)});var d=!0,g=new Array(a);for(l=0;l<a;++l){(m=o.find(l))!==l&&(d=!1,t[m]=[Math.min(t[l][0],t[m][0]),Math.min(t[l][1],t[m][1])])}if(d)return null;var v=0;for(l=0;l<a;++l){var m;(m=o.find(l))===l?(g[l]=v,t[v++]=t[l]):g[l]=-1}t.length=v;for(l=0;l<a;++l)g[l]<0&&(g[l]=g[o.find(l)]);return g}function g(t,e){return t[0]-e[0]||t[1]-e[1]}function v(t,e){var r=t[0]-e[0]||t[1]-e[1];return r||(t[2]<e[2]?-1:t[2]>e[2]?1:0)}function m(t,e,r){if(0!==t.length){if(e)for(var n=0;n<t.length;++n){var i=e[(o=t[n])[0]],a=e[o[1]];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}else for(n=0;n<t.length;++n){var o;i=(o=t[n])[0],a=o[1];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}r?t.sort(v):t.sort(g);var s=1;for(n=1;n<t.length;++n){var l=t[n-1],c=t[n];(c[0]!==l[0]||c[1]!==l[1]||r&&c[2]!==l[2])&&(t[s++]=c)}t.length=s}}function y(t,e,r){var n=function(t,e){for(var r=new Array(e.length),n=0;n<e.length;++n){var i=e[n],a=t[i[0]],o=t[i[1]];r[n]=[u(Math.min(a[0],o[0]),-1/0),u(Math.min(a[1],o[1]),-1/0),u(Math.max(a[0],o[0]),1/0),u(Math.max(a[1],o[1]),1/0)]}return r}(t,e),f=function(t,e,r){var n=[];return i(r,function(r,i){var o=e[r],s=e[i];if(o[0]!==s[0]&&o[0]!==s[1]&&o[1]!==s[0]&&o[1]!==s[1]){var l=t[o[0]],c=t[o[1]],u=t[s[0]],h=t[s[1]];a(l,c,u,h)&&n.push([r,i])}}),n}(t,e,n),g=p(t),v=function(t,e,r,n){var o=[];return i(r,n,function(r,n){var i=e[r];if(i[0]!==n&&i[1]!==n){var s=t[n],l=t[i[0]],c=t[i[1]];a(l,c,s,s)&&o.push([r,n])}}),o}(t,e,n,g),y=d(t,function(t,e,r,n,i){var a,u,f=t.map(function(t){return[o(t[0]),o(t[1])]});for(a=0;a<r.length;++a){var p=r[a];u=p[0];var d=p[1],g=e[u],v=e[d],m=h(c(t[g[0]]),c(t[g[1]]),c(t[v[0]]),c(t[v[1]]));if(m){var y=t.length;t.push([l(m[0]),l(m[1])]),f.push(m),n.push([u,y],[d,y])}}for(n.sort(function(t,e){if(t[0]!==e[0])return t[0]-e[0];var r=f[t[1]],n=f[e[1]];return s(r[0],n[0])||s(r[1],n[1])}),a=n.length-1;a>=0;--a){var x=e[u=(S=n[a])[0]],b=x[0],_=x[1],w=t[b],k=t[_];if((w[0]-k[0]||w[1]-k[1])<0){var T=b;b=_,_=T}x[0]=b;var A,M=x[1]=S[1];for(i&&(A=x[2]);a>0&&n[a-1][0]===u;){var S,E=(S=n[--a])[1];i?e.push([M,E,A]):e.push([M,E]),M=E}i?e.push([M,_,A]):e.push([M,_])}return f}(t,e,f,v,r));return m(e,y,r),!!y||(f.length>0||v.length>0)}},{\"./lib/rat-seg-intersect\":117,\"big-rat\":78,\"big-rat/cmp\":76,\"big-rat/to-float\":90,\"box-intersect\":96,nextafter:451,\"rat-vec\":486,\"robust-segment-intersect\":513,\"union-find\":546}],117:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var a=s(e,t),h=s(n,r),f=u(a,h);if(0===o(f))return null;var p=s(t,r),d=u(h,p),g=i(d,f),v=c(a,g);return l(t,v)};var n=t(\"big-rat/mul\"),i=t(\"big-rat/div\"),a=t(\"big-rat/sub\"),o=t(\"big-rat/sign\"),s=t(\"rat-vec/sub\"),l=t(\"rat-vec/add\"),c=t(\"rat-vec/muls\");function u(t,e){return a(n(t[0],e[1]),n(t[1],e[0]))}},{\"big-rat/div\":77,\"big-rat/mul\":87,\"big-rat/sign\":88,\"big-rat/sub\":89,\"rat-vec/add\":485,\"rat-vec/muls\":487,\"rat-vec/sub\":488}],118:[function(t,e,r){\"use strict\";var n=t(\"clamp\");function i(t,e){null==e&&(e=!0);var r=t[0],i=t[1],a=t[2],o=t[3];return null==o&&(o=e?1:255),e&&(r*=255,i*=255,a*=255,o*=255),16777216*(r=255&n(r,0,255))+((i=255&n(i,0,255))<<16)+((a=255&n(a,0,255))<<8)+(o=255&n(o,0,255))}e.exports=i,e.exports.to=i,e.exports.from=function(t,e){var r=(t=+t)>>>24,n=(16711680&t)>>>16,i=(65280&t)>>>8,a=255&t;return!1===e?[r,n,i,a]:[r/255,n/255,i/255,a/255]}},{clamp:115}],119:[function(t,e,r){\"use strict\";e.exports={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]}},{}],120:[function(t,e,r){\"use strict\";var n=t(\"color-rgba\"),i=t(\"clamp\"),a=t(\"dtype\");e.exports=function(t,e){\"float\"!==e&&e||(e=\"array\"),\"uint\"===e&&(e=\"uint8\"),\"uint_clamped\"===e&&(e=\"uint8_clamped\");var r=new(a(e))(4),o=\"uint8\"!==e&&\"uint8_clamped\"!==e;return t.length&&\"string\"!=typeof t||((t=n(t))[0]/=255,t[1]/=255,t[2]/=255),function(t){return t instanceof Uint8Array||t instanceof Uint8ClampedArray||!!(Array.isArray(t)&&(t[0]>1||0===t[0])&&(t[1]>1||0===t[1])&&(t[2]>1||0===t[2])&&(!t[3]||t[3]>1))}(t)?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:255,o&&(r[0]/=255,r[1]/=255,r[2]/=255,r[3]/=255),r):(o?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:1):(r[0]=i(Math.floor(255*t[0]),0,255),r[1]=i(Math.floor(255*t[1]),0,255),r[2]=i(Math.floor(255*t[2]),0,255),r[3]=null==t[3]?255:i(Math.floor(255*t[3]),0,255)),r)}},{clamp:115,\"color-rgba\":122,dtype:169}],121:[function(t,e,r){(function(r){\"use strict\";var n=t(\"color-name\"),i=t(\"is-plain-obj\"),a=t(\"defined\");e.exports=function(t){var e,s,l=[],c=1;if(\"string\"==typeof t)if(n[t])l=n[t].slice(),s=\"rgb\";else if(\"transparent\"===t)c=0,s=\"rgb\",l=[0,0,0];else if(/^#[A-Fa-f0-9]+$/.test(t)){var u=t.slice(1),h=u.length,f=h<=4;c=1,f?(l=[parseInt(u[0]+u[0],16),parseInt(u[1]+u[1],16),parseInt(u[2]+u[2],16)],4===h&&(c=parseInt(u[3]+u[3],16)/255)):(l=[parseInt(u[0]+u[1],16),parseInt(u[2]+u[3],16),parseInt(u[4]+u[5],16)],8===h&&(c=parseInt(u[6]+u[7],16)/255)),l[0]||(l[0]=0),l[1]||(l[1]=0),l[2]||(l[2]=0),s=\"rgb\"}else if(e=/^((?:rgb|hs[lvb]|hwb|cmyk?|xy[zy]|gray|lab|lchu?v?|[ly]uv|lms)a?)\\s*\\(([^\\)]*)\\)/.exec(t)){var p=e[1],d=\"rgb\"===p,u=p.replace(/a$/,\"\");s=u;var h=\"cmyk\"===u?4:\"gray\"===u?1:3;l=e[2].trim().split(/\\s*,\\s*/).map(function(t,e){if(/%$/.test(t))return e===h?parseFloat(t)/100:\"rgb\"===u?255*parseFloat(t)/100:parseFloat(t);if(\"h\"===u[e]){if(/deg$/.test(t))return parseFloat(t);if(void 0!==o[t])return o[t]}return parseFloat(t)}),p===u&&l.push(1),c=d?1:void 0===l[h]?1:l[h],l=l.slice(0,h)}else t.length>10&&/[0-9](?:\\s|\\/)/.test(t)&&(l=t.match(/([0-9]+)/g).map(function(t){return parseFloat(t)}),s=t.match(/([a-z])/gi).join(\"\").toLowerCase());else if(isNaN(t))if(i(t)){var g=a(t.r,t.red,t.R,null);null!==g?(s=\"rgb\",l=[g,a(t.g,t.green,t.G),a(t.b,t.blue,t.B)]):(s=\"hsl\",l=[a(t.h,t.hue,t.H),a(t.s,t.saturation,t.S),a(t.l,t.lightness,t.L,t.b,t.brightness)]),c=a(t.a,t.alpha,t.opacity,1),null!=t.opacity&&(c/=100)}else(Array.isArray(t)||r.ArrayBuffer&&ArrayBuffer.isView&&ArrayBuffer.isView(t))&&(l=[t[0],t[1],t[2]],s=\"rgb\",c=4===t.length?t[3]:1);else s=\"rgb\",l=[t>>>16,(65280&t)>>>8,255&t];return{space:s,values:l,alpha:c}};var o={red:0,orange:60,yellow:120,green:180,blue:240,purple:300}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"color-name\":119,defined:164,\"is-plain-obj\":422}],122:[function(t,e,r){\"use strict\";var n=t(\"color-parse\"),i=t(\"color-space/hsl\"),a=t(\"clamp\");e.exports=function(t){var e,r=n(t);return r.space?((e=Array(3))[0]=a(r.values[0],0,255),e[1]=a(r.values[1],0,255),e[2]=a(r.values[2],0,255),\"h\"===r.space[0]&&(e=i.rgb(e)),e.push(a(r.alpha,0,1)),e):[]}},{clamp:115,\"color-parse\":121,\"color-space/hsl\":123}],123:[function(t,e,r){\"use strict\";var n=t(\"./rgb\");e.exports={name:\"hsl\",min:[0,0,0],max:[360,100,100],channel:[\"hue\",\"saturation\",\"lightness\"],alias:[\"HSL\"],rgb:function(t){var e,r,n,i,a,o=t[0]/360,s=t[1]/100,l=t[2]/100;if(0===s)return[a=255*l,a,a];e=2*l-(r=l<.5?l*(1+s):l+s-l*s),i=[0,0,0];for(var c=0;c<3;c++)(n=o+1/3*-(c-1))<0?n++:n>1&&n--,a=6*n<1?e+6*(r-e)*n:2*n<1?r:3*n<2?e+(r-e)*(2/3-n)*6:e,i[c]=255*a;return i}},n.hsl=function(t){var e,r,n=t[0]/255,i=t[1]/255,a=t[2]/255,o=Math.min(n,i,a),s=Math.max(n,i,a),l=s-o;return s===o?e=0:n===s?e=(i-a)/l:i===s?e=2+(a-n)/l:a===s&&(e=4+(n-i)/l),(e=Math.min(60*e,360))<0&&(e+=360),r=(o+s)/2,[e,100*(s===o?0:r<=.5?l/(s+o):l/(2-s-o)),100*r]}},{\"./rgb\":124}],124:[function(t,e,r){\"use strict\";e.exports={name:\"rgb\",min:[0,0,0],max:[255,255,255],channel:[\"red\",\"green\",\"blue\"],alias:[\"RGB\"]}},{}],125:[function(t,e,r){e.exports={jet:[{index:0,rgb:[0,0,131]},{index:.125,rgb:[0,60,170]},{index:.375,rgb:[5,255,255]},{index:.625,rgb:[255,255,0]},{index:.875,rgb:[250,0,0]},{index:1,rgb:[128,0,0]}],hsv:[{index:0,rgb:[255,0,0]},{index:.169,rgb:[253,255,2]},{index:.173,rgb:[247,255,2]},{index:.337,rgb:[0,252,4]},{index:.341,rgb:[0,252,10]},{index:.506,rgb:[1,249,255]},{index:.671,rgb:[2,0,253]},{index:.675,rgb:[8,0,253]},{index:.839,rgb:[255,0,251]},{index:.843,rgb:[255,0,245]},{index:1,rgb:[255,0,6]}],hot:[{index:0,rgb:[0,0,0]},{index:.3,rgb:[230,0,0]},{index:.6,rgb:[255,210,0]},{index:1,rgb:[255,255,255]}],cool:[{index:0,rgb:[0,255,255]},{index:1,rgb:[255,0,255]}],spring:[{index:0,rgb:[255,0,255]},{index:1,rgb:[255,255,0]}],summer:[{index:0,rgb:[0,128,102]},{index:1,rgb:[255,255,102]}],autumn:[{index:0,rgb:[255,0,0]},{index:1,rgb:[255,255,0]}],winter:[{index:0,rgb:[0,0,255]},{index:1,rgb:[0,255,128]}],bone:[{index:0,rgb:[0,0,0]},{index:.376,rgb:[84,84,116]},{index:.753,rgb:[169,200,200]},{index:1,rgb:[255,255,255]}],copper:[{index:0,rgb:[0,0,0]},{index:.804,rgb:[255,160,102]},{index:1,rgb:[255,199,127]}],greys:[{index:0,rgb:[0,0,0]},{index:1,rgb:[255,255,255]}],yignbu:[{index:0,rgb:[8,29,88]},{index:.125,rgb:[37,52,148]},{index:.25,rgb:[34,94,168]},{index:.375,rgb:[29,145,192]},{index:.5,rgb:[65,182,196]},{index:.625,rgb:[127,205,187]},{index:.75,rgb:[199,233,180]},{index:.875,rgb:[237,248,217]},{index:1,rgb:[255,255,217]}],greens:[{index:0,rgb:[0,68,27]},{index:.125,rgb:[0,109,44]},{index:.25,rgb:[35,139,69]},{index:.375,rgb:[65,171,93]},{index:.5,rgb:[116,196,118]},{index:.625,rgb:[161,217,155]},{index:.75,rgb:[199,233,192]},{index:.875,rgb:[229,245,224]},{index:1,rgb:[247,252,245]}],yiorrd:[{index:0,rgb:[128,0,38]},{index:.125,rgb:[189,0,38]},{index:.25,rgb:[227,26,28]},{index:.375,rgb:[252,78,42]},{index:.5,rgb:[253,141,60]},{index:.625,rgb:[254,178,76]},{index:.75,rgb:[254,217,118]},{index:.875,rgb:[255,237,160]},{index:1,rgb:[255,255,204]}],bluered:[{index:0,rgb:[0,0,255]},{index:1,rgb:[255,0,0]}],rdbu:[{index:0,rgb:[5,10,172]},{index:.35,rgb:[106,137,247]},{index:.5,rgb:[190,190,190]},{index:.6,rgb:[220,170,132]},{index:.7,rgb:[230,145,90]},{index:1,rgb:[178,10,28]}],picnic:[{index:0,rgb:[0,0,255]},{index:.1,rgb:[51,153,255]},{index:.2,rgb:[102,204,255]},{index:.3,rgb:[153,204,255]},{index:.4,rgb:[204,204,255]},{index:.5,rgb:[255,255,255]},{index:.6,rgb:[255,204,255]},{index:.7,rgb:[255,153,255]},{index:.8,rgb:[255,102,204]},{index:.9,rgb:[255,102,102]},{index:1,rgb:[255,0,0]}],rainbow:[{index:0,rgb:[150,0,90]},{index:.125,rgb:[0,0,200]},{index:.25,rgb:[0,25,255]},{index:.375,rgb:[0,152,255]},{index:.5,rgb:[44,255,150]},{index:.625,rgb:[151,255,0]},{index:.75,rgb:[255,234,0]},{index:.875,rgb:[255,111,0]},{index:1,rgb:[255,0,0]}],portland:[{index:0,rgb:[12,51,131]},{index:.25,rgb:[10,136,186]},{index:.5,rgb:[242,211,56]},{index:.75,rgb:[242,143,56]},{index:1,rgb:[217,30,30]}],blackbody:[{index:0,rgb:[0,0,0]},{index:.2,rgb:[230,0,0]},{index:.4,rgb:[230,210,0]},{index:.7,rgb:[255,255,255]},{index:1,rgb:[160,200,255]}],earth:[{index:0,rgb:[0,0,130]},{index:.1,rgb:[0,180,180]},{index:.2,rgb:[40,210,40]},{index:.4,rgb:[230,230,50]},{index:.6,rgb:[120,70,20]},{index:1,rgb:[255,255,255]}],electric:[{index:0,rgb:[0,0,0]},{index:.15,rgb:[30,0,100]},{index:.4,rgb:[120,0,100]},{index:.6,rgb:[160,90,0]},{index:.8,rgb:[230,200,0]},{index:1,rgb:[255,250,220]}],alpha:[{index:0,rgb:[255,255,255,0]},{index:1,rgb:[255,255,255,1]}],viridis:[{index:0,rgb:[68,1,84]},{index:.13,rgb:[71,44,122]},{index:.25,rgb:[59,81,139]},{index:.38,rgb:[44,113,142]},{index:.5,rgb:[33,144,141]},{index:.63,rgb:[39,173,129]},{index:.75,rgb:[92,200,99]},{index:.88,rgb:[170,220,50]},{index:1,rgb:[253,231,37]}],inferno:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[31,12,72]},{index:.25,rgb:[85,15,109]},{index:.38,rgb:[136,34,106]},{index:.5,rgb:[186,54,85]},{index:.63,rgb:[227,89,51]},{index:.75,rgb:[249,140,10]},{index:.88,rgb:[249,201,50]},{index:1,rgb:[252,255,164]}],magma:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[28,16,68]},{index:.25,rgb:[79,18,123]},{index:.38,rgb:[129,37,129]},{index:.5,rgb:[181,54,122]},{index:.63,rgb:[229,80,100]},{index:.75,rgb:[251,135,97]},{index:.88,rgb:[254,194,135]},{index:1,rgb:[252,253,191]}],plasma:[{index:0,rgb:[13,8,135]},{index:.13,rgb:[75,3,161]},{index:.25,rgb:[125,3,168]},{index:.38,rgb:[168,34,150]},{index:.5,rgb:[203,70,121]},{index:.63,rgb:[229,107,93]},{index:.75,rgb:[248,148,65]},{index:.88,rgb:[253,195,40]},{index:1,rgb:[240,249,33]}],warm:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[172,0,187]},{index:.25,rgb:[219,0,170]},{index:.38,rgb:[255,0,130]},{index:.5,rgb:[255,63,74]},{index:.63,rgb:[255,123,0]},{index:.75,rgb:[234,176,0]},{index:.88,rgb:[190,228,0]},{index:1,rgb:[147,255,0]}],cool:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[116,0,218]},{index:.25,rgb:[98,74,237]},{index:.38,rgb:[68,146,231]},{index:.5,rgb:[0,204,197]},{index:.63,rgb:[0,247,146]},{index:.75,rgb:[0,255,88]},{index:.88,rgb:[40,255,8]},{index:1,rgb:[147,255,0]}],\"rainbow-soft\":[{index:0,rgb:[125,0,179]},{index:.1,rgb:[199,0,180]},{index:.2,rgb:[255,0,121]},{index:.3,rgb:[255,108,0]},{index:.4,rgb:[222,194,0]},{index:.5,rgb:[150,255,0]},{index:.6,rgb:[0,255,55]},{index:.7,rgb:[0,246,150]},{index:.8,rgb:[50,167,222]},{index:.9,rgb:[103,51,235]},{index:1,rgb:[124,0,186]}],bathymetry:[{index:0,rgb:[40,26,44]},{index:.13,rgb:[59,49,90]},{index:.25,rgb:[64,76,139]},{index:.38,rgb:[63,110,151]},{index:.5,rgb:[72,142,158]},{index:.63,rgb:[85,174,163]},{index:.75,rgb:[120,206,163]},{index:.88,rgb:[187,230,172]},{index:1,rgb:[253,254,204]}],cdom:[{index:0,rgb:[47,15,62]},{index:.13,rgb:[87,23,86]},{index:.25,rgb:[130,28,99]},{index:.38,rgb:[171,41,96]},{index:.5,rgb:[206,67,86]},{index:.63,rgb:[230,106,84]},{index:.75,rgb:[242,149,103]},{index:.88,rgb:[249,193,135]},{index:1,rgb:[254,237,176]}],chlorophyll:[{index:0,rgb:[18,36,20]},{index:.13,rgb:[25,63,41]},{index:.25,rgb:[24,91,59]},{index:.38,rgb:[13,119,72]},{index:.5,rgb:[18,148,80]},{index:.63,rgb:[80,173,89]},{index:.75,rgb:[132,196,122]},{index:.88,rgb:[175,221,162]},{index:1,rgb:[215,249,208]}],density:[{index:0,rgb:[54,14,36]},{index:.13,rgb:[89,23,80]},{index:.25,rgb:[110,45,132]},{index:.38,rgb:[120,77,178]},{index:.5,rgb:[120,113,213]},{index:.63,rgb:[115,151,228]},{index:.75,rgb:[134,185,227]},{index:.88,rgb:[177,214,227]},{index:1,rgb:[230,241,241]}],\"freesurface-blue\":[{index:0,rgb:[30,4,110]},{index:.13,rgb:[47,14,176]},{index:.25,rgb:[41,45,236]},{index:.38,rgb:[25,99,212]},{index:.5,rgb:[68,131,200]},{index:.63,rgb:[114,156,197]},{index:.75,rgb:[157,181,203]},{index:.88,rgb:[200,208,216]},{index:1,rgb:[241,237,236]}],\"freesurface-red\":[{index:0,rgb:[60,9,18]},{index:.13,rgb:[100,17,27]},{index:.25,rgb:[142,20,29]},{index:.38,rgb:[177,43,27]},{index:.5,rgb:[192,87,63]},{index:.63,rgb:[205,125,105]},{index:.75,rgb:[216,162,148]},{index:.88,rgb:[227,199,193]},{index:1,rgb:[241,237,236]}],oxygen:[{index:0,rgb:[64,5,5]},{index:.13,rgb:[106,6,15]},{index:.25,rgb:[144,26,7]},{index:.38,rgb:[168,64,3]},{index:.5,rgb:[188,100,4]},{index:.63,rgb:[206,136,11]},{index:.75,rgb:[220,174,25]},{index:.88,rgb:[231,215,44]},{index:1,rgb:[248,254,105]}],par:[{index:0,rgb:[51,20,24]},{index:.13,rgb:[90,32,35]},{index:.25,rgb:[129,44,34]},{index:.38,rgb:[159,68,25]},{index:.5,rgb:[182,99,19]},{index:.63,rgb:[199,134,22]},{index:.75,rgb:[212,171,35]},{index:.88,rgb:[221,210,54]},{index:1,rgb:[225,253,75]}],phase:[{index:0,rgb:[145,105,18]},{index:.13,rgb:[184,71,38]},{index:.25,rgb:[186,58,115]},{index:.38,rgb:[160,71,185]},{index:.5,rgb:[110,97,218]},{index:.63,rgb:[50,123,164]},{index:.75,rgb:[31,131,110]},{index:.88,rgb:[77,129,34]},{index:1,rgb:[145,105,18]}],salinity:[{index:0,rgb:[42,24,108]},{index:.13,rgb:[33,50,162]},{index:.25,rgb:[15,90,145]},{index:.38,rgb:[40,118,137]},{index:.5,rgb:[59,146,135]},{index:.63,rgb:[79,175,126]},{index:.75,rgb:[120,203,104]},{index:.88,rgb:[193,221,100]},{index:1,rgb:[253,239,154]}],temperature:[{index:0,rgb:[4,35,51]},{index:.13,rgb:[23,51,122]},{index:.25,rgb:[85,59,157]},{index:.38,rgb:[129,79,143]},{index:.5,rgb:[175,95,130]},{index:.63,rgb:[222,112,101]},{index:.75,rgb:[249,146,66]},{index:.88,rgb:[249,196,65]},{index:1,rgb:[232,250,91]}],turbidity:[{index:0,rgb:[34,31,27]},{index:.13,rgb:[65,50,41]},{index:.25,rgb:[98,69,52]},{index:.38,rgb:[131,89,57]},{index:.5,rgb:[161,112,59]},{index:.63,rgb:[185,140,66]},{index:.75,rgb:[202,174,88]},{index:.88,rgb:[216,209,126]},{index:1,rgb:[233,246,171]}],\"velocity-blue\":[{index:0,rgb:[17,32,64]},{index:.13,rgb:[35,52,116]},{index:.25,rgb:[29,81,156]},{index:.38,rgb:[31,113,162]},{index:.5,rgb:[50,144,169]},{index:.63,rgb:[87,173,176]},{index:.75,rgb:[149,196,189]},{index:.88,rgb:[203,221,211]},{index:1,rgb:[254,251,230]}],\"velocity-green\":[{index:0,rgb:[23,35,19]},{index:.13,rgb:[24,64,38]},{index:.25,rgb:[11,95,45]},{index:.38,rgb:[39,123,35]},{index:.5,rgb:[95,146,12]},{index:.63,rgb:[152,165,18]},{index:.75,rgb:[201,186,69]},{index:.88,rgb:[233,216,137]},{index:1,rgb:[255,253,205]}],cubehelix:[{index:0,rgb:[0,0,0]},{index:.07,rgb:[22,5,59]},{index:.13,rgb:[60,4,105]},{index:.2,rgb:[109,1,135]},{index:.27,rgb:[161,0,147]},{index:.33,rgb:[210,2,142]},{index:.4,rgb:[251,11,123]},{index:.47,rgb:[255,29,97]},{index:.53,rgb:[255,54,69]},{index:.6,rgb:[255,85,46]},{index:.67,rgb:[255,120,34]},{index:.73,rgb:[255,157,37]},{index:.8,rgb:[241,191,57]},{index:.87,rgb:[224,220,93]},{index:.93,rgb:[218,241,142]},{index:1,rgb:[227,253,198]}]}},{}],126:[function(t,e,r){\"use strict\";var n=t(\"./colorScale\"),i=t(\"lerp\");function a(t){return[t[0]/255,t[1]/255,t[2]/255,t[3]]}function o(t){for(var e,r=\"#\",n=0;n<3;++n)r+=(\"00\"+(e=(e=t[n]).toString(16))).substr(e.length);return r}function s(t){return\"rgba(\"+t.join(\",\")+\")\"}e.exports=function(t){var e,r,l,c,u,h,f,p,d,g;t||(t={});p=(t.nshades||72)-1,f=t.format||\"hex\",(h=t.colormap)||(h=\"jet\");if(\"string\"==typeof h){if(h=h.toLowerCase(),!n[h])throw Error(h+\" not a supported colorscale\");u=n[h]}else{if(!Array.isArray(h))throw Error(\"unsupported colormap option\",h);u=h.slice()}if(u.length>p+1)throw new Error(h+\" map requires nshades to be at least size \"+u.length);d=Array.isArray(t.alpha)?2!==t.alpha.length?[1,1]:t.alpha.slice():\"number\"==typeof t.alpha?[t.alpha,t.alpha]:[1,1];e=u.map(function(t){return Math.round(t.index*p)}),d[0]=Math.min(Math.max(d[0],0),1),d[1]=Math.min(Math.max(d[1],0),1);var v=u.map(function(t,e){var r=u[e].index,n=u[e].rgb.slice();return 4===n.length&&n[3]>=0&&n[3]<=1?n:(n[3]=d[0]+(d[1]-d[0])*r,n)}),m=[];for(g=0;g<e.length-1;++g){c=e[g+1]-e[g],r=v[g],l=v[g+1];for(var y=0;y<c;y++){var x=y/c;m.push([Math.round(i(r[0],l[0],x)),Math.round(i(r[1],l[1],x)),Math.round(i(r[2],l[2],x)),i(r[3],l[3],x)])}}m.push(u[u.length-1].rgb.concat(d[1])),\"hex\"===f?m=m.map(o):\"rgbaString\"===f?m=m.map(s):\"float\"===f&&(m=m.map(a));return m}},{\"./colorScale\":125,lerp:425}],127:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a){var o=n(e,r,a);if(0===o){var s=i(n(t,e,r)),c=i(n(t,e,a));if(s===c){if(0===s){var u=l(t,e,r),h=l(t,e,a);return u===h?0:u?1:-1}return 0}return 0===c?s>0?-1:l(t,e,a)?-1:1:0===s?c>0?1:l(t,e,r)?1:-1:i(c-s)}var f=n(t,e,r);if(f>0)return o>0&&n(t,e,a)>0?1:-1;if(f<0)return o>0||n(t,e,a)>0?1:-1;var p=n(t,e,a);return p>0?1:l(t,e,r)?1:-1};var n=t(\"robust-orientation\"),i=t(\"signum\"),a=t(\"two-sum\"),o=t(\"robust-product\"),s=t(\"robust-sum\");function l(t,e,r){var n=a(t[0],-e[0]),i=a(t[1],-e[1]),l=a(r[0],-e[0]),c=a(r[1],-e[1]),u=s(o(n,l),o(i,c));return u[u.length-1]>=0}},{\"robust-orientation\":510,\"robust-product\":511,\"robust-sum\":515,signum:516,\"two-sum\":544}],128:[function(t,e,r){e.exports=function(t,e){var r=t.length,a=t.length-e.length;if(a)return a;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return t[0]+t[1]-e[0]-e[1]||n(t[0],t[1])-n(e[0],e[1]);case 3:var o=t[0]+t[1],s=e[0]+e[1];if(a=o+t[2]-(s+e[2]))return a;var l=n(t[0],t[1]),c=n(e[0],e[1]);return n(l,t[2])-n(c,e[2])||n(l+t[2],o)-n(c+e[2],s);case 4:var u=t[0],h=t[1],f=t[2],p=t[3],d=e[0],g=e[1],v=e[2],m=e[3];return u+h+f+p-(d+g+v+m)||n(u,h,f,p)-n(d,g,v,m,d)||n(u+h,u+f,u+p,h+f,h+p,f+p)-n(d+g,d+v,d+m,g+v,g+m,v+m)||n(u+h+f,u+h+p,u+f+p,h+f+p)-n(d+g+v,d+g+m,d+v+m,g+v+m);default:for(var y=t.slice().sort(i),x=e.slice().sort(i),b=0;b<r;++b)if(a=y[b]-x[b])return a;return 0}};var n=Math.min;function i(t,e){return t-e}},{}],129:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"cell-orientation\");e.exports=function(t,e){return n(t,e)||i(t)-i(e)}},{\"cell-orientation\":112,\"compare-cell\":128}],130:[function(t,e,r){\"use strict\";var n=t(\"./lib/ch1d\"),i=t(\"./lib/ch2d\"),a=t(\"./lib/chnd\");e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[[0]];var r=t[0].length;if(0===r)return[];if(1===r)return n(t);if(2===r)return i(t);return a(t,r)}},{\"./lib/ch1d\":131,\"./lib/ch2d\":132,\"./lib/chnd\":133}],131:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0,r=0,n=1;n<t.length;++n)t[n][0]<t[e][0]&&(e=n),t[n][0]>t[r][0]&&(r=n);return e<r?[[e],[r]]:e>r?[[r],[e]]:[[e]]}},{}],132:[function(t,e,r){\"use strict\";e.exports=function(t){var e=n(t),r=e.length;if(r<=2)return[];for(var i=new Array(r),a=e[r-1],o=0;o<r;++o){var s=e[o];i[o]=[a,s],a=s}return i};var n=t(\"monotone-convex-hull-2d\")},{\"monotone-convex-hull-2d\":434}],133:[function(t,e,r){\"use strict\";e.exports=function(t,e){try{return n(t,!0)}catch(s){var r=i(t);if(r.length<=e)return[];var a=function(t,e){for(var r=t.length,n=new Array(r),i=0;i<e.length;++i)n[i]=t[e[i]];for(var a=e.length,i=0;i<r;++i)e.indexOf(i)<0&&(n[a++]=t[i]);return n}(t,r),o=n(a,!0);return function(t,e){for(var r=t.length,n=e.length,i=0;i<r;++i)for(var a=t[i],o=0;o<a.length;++o){var s=a[o];if(s<n)a[o]=e[s];else{s-=n;for(var l=0;l<n;++l)s>=e[l]&&(s+=1);a[o]=s}}return t}(o,r)}};var n=t(\"incremental-convex-hull\"),i=t(\"affine-hull\")},{\"affine-hull\":62,\"incremental-convex-hull\":413}],134:[function(t,e,r){e.exports={AFG:\"afghan\",ALA:\"\\\\b\\\\wland\",ALB:\"albania\",DZA:\"algeria\",ASM:\"^(?=.*americ).*samoa\",AND:\"andorra\",AGO:\"angola\",AIA:\"anguill?a\",ATA:\"antarctica\",ATG:\"antigua\",ARG:\"argentin\",ARM:\"armenia\",ABW:\"^(?!.*bonaire).*\\\\baruba\",AUS:\"australia\",AUT:\"^(?!.*hungary).*austria|\\\\baustri.*\\\\bemp\",AZE:\"azerbaijan\",BHS:\"bahamas\",BHR:\"bahrain\",BGD:\"bangladesh|^(?=.*east).*paki?stan\",BRB:\"barbados\",BLR:\"belarus|byelo\",BEL:\"^(?!.*luxem).*belgium\",BLZ:\"belize|^(?=.*british).*honduras\",BEN:\"benin|dahome\",BMU:\"bermuda\",BTN:\"bhutan\",BOL:\"bolivia\",BES:\"^(?=.*bonaire).*eustatius|^(?=.*carib).*netherlands|\\\\bbes.?islands\",BIH:\"herzegovina|bosnia\",BWA:\"botswana|bechuana\",BVT:\"bouvet\",BRA:\"brazil\",IOT:\"british.?indian.?ocean\",BRN:\"brunei\",BGR:\"bulgaria\",BFA:\"burkina|\\\\bfaso|upper.?volta\",BDI:\"burundi\",CPV:\"verde\",KHM:\"cambodia|kampuchea|khmer\",CMR:\"cameroon\",CAN:\"canada\",CYM:\"cayman\",CAF:\"\\\\bcentral.african.republic\",TCD:\"\\\\bchad\",CHL:\"\\\\bchile\",CHN:\"^(?!.*\\\\bmac)(?!.*\\\\bhong)(?!.*\\\\btai)(?!.*\\\\brep).*china|^(?=.*peo)(?=.*rep).*china\",CXR:\"christmas\",CCK:\"\\\\bcocos|keeling\",COL:\"colombia\",COM:\"comoro\",COG:\"^(?!.*\\\\bdem)(?!.*\\\\bd[\\\\.]?r)(?!.*kinshasa)(?!.*zaire)(?!.*belg)(?!.*l.opoldville)(?!.*free).*\\\\bcongo\",COK:\"\\\\bcook\",CRI:\"costa.?rica\",CIV:\"ivoire|ivory\",HRV:\"croatia\",CUB:\"\\\\bcuba\",CUW:\"^(?!.*bonaire).*\\\\bcura(c|\\xe7)ao\",CYP:\"cyprus\",CSK:\"czechoslovakia\",CZE:\"^(?=.*rep).*czech|czechia|bohemia\",COD:\"\\\\bdem.*congo|congo.*\\\\bdem|congo.*\\\\bd[\\\\.]?r|\\\\bd[\\\\.]?r.*congo|belgian.?congo|congo.?free.?state|kinshasa|zaire|l.opoldville|drc|droc|rdc\",DNK:\"denmark\",DJI:\"djibouti\",DMA:\"dominica(?!n)\",DOM:\"dominican.rep\",ECU:\"ecuador\",EGY:\"egypt\",SLV:\"el.?salvador\",GNQ:\"guine.*eq|eq.*guine|^(?=.*span).*guinea\",ERI:\"eritrea\",EST:\"estonia\",ETH:\"ethiopia|abyssinia\",FLK:\"falkland|malvinas\",FRO:\"faroe|faeroe\",FJI:\"fiji\",FIN:\"finland\",FRA:\"^(?!.*\\\\bdep)(?!.*martinique).*france|french.?republic|\\\\bgaul\",GUF:\"^(?=.*french).*guiana\",PYF:\"french.?polynesia|tahiti\",ATF:\"french.?southern\",GAB:\"gabon\",GMB:\"gambia\",GEO:\"^(?!.*south).*georgia\",DDR:\"german.?democratic.?republic|democratic.?republic.*germany|east.germany\",DEU:\"^(?!.*east).*germany|^(?=.*\\\\bfed.*\\\\brep).*german\",GHA:\"ghana|gold.?coast\",GIB:\"gibraltar\",GRC:\"greece|hellenic|hellas\",GRL:\"greenland\",GRD:\"grenada\",GLP:\"guadeloupe\",GUM:\"\\\\bguam\",GTM:\"guatemala\",GGY:\"guernsey\",GIN:\"^(?!.*eq)(?!.*span)(?!.*bissau)(?!.*portu)(?!.*new).*guinea\",GNB:\"bissau|^(?=.*portu).*guinea\",GUY:\"guyana|british.?guiana\",HTI:\"haiti\",HMD:\"heard.*mcdonald\",VAT:\"holy.?see|vatican|papal.?st\",HND:\"^(?!.*brit).*honduras\",HKG:\"hong.?kong\",HUN:\"^(?!.*austr).*hungary\",ISL:\"iceland\",IND:\"india(?!.*ocea)\",IDN:\"indonesia\",IRN:\"\\\\biran|persia\",IRQ:\"\\\\biraq|mesopotamia\",IRL:\"(^ireland)|(^republic.*ireland)\",IMN:\"^(?=.*isle).*\\\\bman\",ISR:\"israel\",ITA:\"italy\",JAM:\"jamaica\",JPN:\"japan\",JEY:\"jersey\",JOR:\"jordan\",KAZ:\"kazak\",KEN:\"kenya|british.?east.?africa|east.?africa.?prot\",KIR:\"kiribati\",PRK:\"^(?=.*democrat|people|north|d.*p.*.r).*\\\\bkorea|dprk|korea.*(d.*p.*r)\",KWT:\"kuwait\",KGZ:\"kyrgyz|kirghiz\",LAO:\"\\\\blaos?\\\\b\",LVA:\"latvia\",LBN:\"lebanon\",LSO:\"lesotho|basuto\",LBR:\"liberia\",LBY:\"libya\",LIE:\"liechtenstein\",LTU:\"lithuania\",LUX:\"^(?!.*belg).*luxem\",MAC:\"maca(o|u)\",MDG:\"madagascar|malagasy\",MWI:\"malawi|nyasa\",MYS:\"malaysia\",MDV:\"maldive\",MLI:\"\\\\bmali\\\\b\",MLT:\"\\\\bmalta\",MHL:\"marshall\",MTQ:\"martinique\",MRT:\"mauritania\",MUS:\"mauritius\",MYT:\"\\\\bmayotte\",MEX:\"\\\\bmexic\",FSM:\"fed.*micronesia|micronesia.*fed\",MCO:\"monaco\",MNG:\"mongolia\",MNE:\"^(?!.*serbia).*montenegro\",MSR:\"montserrat\",MAR:\"morocco|\\\\bmaroc\",MOZ:\"mozambique\",MMR:\"myanmar|burma\",NAM:\"namibia\",NRU:\"nauru\",NPL:\"nepal\",NLD:\"^(?!.*\\\\bant)(?!.*\\\\bcarib).*netherlands\",ANT:\"^(?=.*\\\\bant).*(nether|dutch)\",NCL:\"new.?caledonia\",NZL:\"new.?zealand\",NIC:\"nicaragua\",NER:\"\\\\bniger(?!ia)\",NGA:\"nigeria\",NIU:\"niue\",NFK:\"norfolk\",MNP:\"mariana\",NOR:\"norway\",OMN:\"\\\\boman|trucial\",PAK:\"^(?!.*east).*paki?stan\",PLW:\"palau\",PSE:\"palestin|\\\\bgaza|west.?bank\",PAN:\"panama\",PNG:\"papua|new.?guinea\",PRY:\"paraguay\",PER:\"peru\",PHL:\"philippines\",PCN:\"pitcairn\",POL:\"poland\",PRT:\"portugal\",PRI:\"puerto.?rico\",QAT:\"qatar\",KOR:\"^(?!.*d.*p.*r)(?!.*democrat)(?!.*people)(?!.*north).*\\\\bkorea(?!.*d.*p.*r)\",MDA:\"moldov|b(a|e)ssarabia\",REU:\"r(e|\\xe9)union\",ROU:\"r(o|u|ou)mania\",RUS:\"\\\\brussia|soviet.?union|u\\\\.?s\\\\.?s\\\\.?r|socialist.?republics\",RWA:\"rwanda\",BLM:\"barth(e|\\xe9)lemy\",SHN:\"helena\",KNA:\"kitts|\\\\bnevis\",LCA:\"\\\\blucia\",MAF:\"^(?=.*collectivity).*martin|^(?=.*france).*martin(?!ique)|^(?=.*french).*martin(?!ique)\",SPM:\"miquelon\",VCT:\"vincent\",WSM:\"^(?!.*amer).*samoa\",SMR:\"san.?marino\",STP:\"\\\\bs(a|\\xe3)o.?tom(e|\\xe9)\",SAU:\"\\\\bsa\\\\w*.?arabia\",SEN:\"senegal\",SRB:\"^(?!.*monte).*serbia\",SYC:\"seychell\",SLE:\"sierra\",SGP:\"singapore\",SXM:\"^(?!.*martin)(?!.*saba).*maarten\",SVK:\"^(?!.*cze).*slovak\",SVN:\"slovenia\",SLB:\"solomon\",SOM:\"somali\",ZAF:\"south.africa|s\\\\\\\\..?africa\",SGS:\"south.?georgia|sandwich\",SSD:\"\\\\bs\\\\w*.?sudan\",ESP:\"spain\",LKA:\"sri.?lanka|ceylon\",SDN:\"^(?!.*\\\\bs(?!u)).*sudan\",SUR:\"surinam|dutch.?guiana\",SJM:\"svalbard\",SWZ:\"swaziland\",SWE:\"sweden\",CHE:\"switz|swiss\",SYR:\"syria\",TWN:\"taiwan|taipei|formosa|^(?!.*peo)(?=.*rep).*china\",TJK:\"tajik\",THA:\"thailand|\\\\bsiam\",MKD:\"macedonia|fyrom\",TLS:\"^(?=.*leste).*timor|^(?=.*east).*timor\",TGO:\"togo\",TKL:\"tokelau\",TON:\"tonga\",TTO:\"trinidad|tobago\",TUN:\"tunisia\",TUR:\"turkey\",TKM:\"turkmen\",TCA:\"turks\",TUV:\"tuvalu\",UGA:\"uganda\",UKR:\"ukrain\",ARE:\"emirates|^u\\\\.?a\\\\.?e\\\\.?$|united.?arab.?em\",GBR:\"united.?kingdom|britain|^u\\\\.?k\\\\.?$\",TZA:\"tanzania\",USA:\"united.?states\\\\b(?!.*islands)|\\\\bu\\\\.?s\\\\.?a\\\\.?\\\\b|^\\\\s*u\\\\.?s\\\\.?\\\\b(?!.*islands)\",UMI:\"minor.?outlying.?is\",URY:\"uruguay\",UZB:\"uzbek\",VUT:\"vanuatu|new.?hebrides\",VEN:\"venezuela\",VNM:\"^(?!.*republic).*viet.?nam|^(?=.*socialist).*viet.?nam\",VGB:\"^(?=.*\\\\bu\\\\.?\\\\s?k).*virgin|^(?=.*brit).*virgin|^(?=.*kingdom).*virgin\",VIR:\"^(?=.*\\\\bu\\\\.?\\\\s?s).*virgin|^(?=.*states).*virgin\",WLF:\"futuna|wallis\",ESH:\"western.sahara\",YEM:\"^(?!.*arab)(?!.*north)(?!.*sana)(?!.*peo)(?!.*dem)(?!.*south)(?!.*aden)(?!.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YMD:\"^(?=.*peo).*yemen|^(?!.*rep)(?=.*dem).*yemen|^(?=.*south).*yemen|^(?=.*aden).*yemen|^(?=.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YUG:\"yugoslavia\",ZMB:\"zambia|northern.?rhodesia\",EAZ:\"zanzibar\",ZWE:\"zimbabwe|^(?!.*northern).*rhodesia\"}},{}],135:[function(t,e,r){e.exports=[\"xx-small\",\"x-small\",\"small\",\"medium\",\"large\",\"x-large\",\"xx-large\",\"larger\",\"smaller\"]},{}],136:[function(t,e,r){e.exports=[\"normal\",\"condensed\",\"semi-condensed\",\"extra-condensed\",\"ultra-condensed\",\"expanded\",\"semi-expanded\",\"extra-expanded\",\"ultra-expanded\"]},{}],137:[function(t,e,r){e.exports=[\"normal\",\"italic\",\"oblique\"]},{}],138:[function(t,e,r){e.exports=[\"normal\",\"bold\",\"bolder\",\"lighter\",\"100\",\"200\",\"300\",\"400\",\"500\",\"600\",\"700\",\"800\",\"900\"]},{}],139:[function(t,e,r){\"use strict\";e.exports={parse:t(\"./parse\"),stringify:t(\"./stringify\")}},{\"./parse\":141,\"./stringify\":142}],140:[function(t,e,r){\"use strict\";var n=t(\"css-font-size-keywords\");e.exports={isSize:function(t){return/^[\\d\\.]/.test(t)||-1!==t.indexOf(\"/\")||-1!==n.indexOf(t)}}},{\"css-font-size-keywords\":135}],141:[function(t,e,r){\"use strict\";var n=t(\"unquote\"),i=t(\"css-global-keywords\"),a=t(\"css-system-font-keywords\"),o=t(\"css-font-weight-keywords\"),s=t(\"css-font-style-keywords\"),l=t(\"css-font-stretch-keywords\"),c=t(\"string-split-by\"),u=t(\"./lib/util\").isSize;e.exports=f;var h=f.cache={};function f(t){if(\"string\"!=typeof t)throw new Error(\"Font argument must be a string.\");if(h[t])return h[t];if(\"\"===t)throw new Error(\"Cannot parse an empty string.\");if(-1!==a.indexOf(t))return h[t]={system:t};for(var e,r={style:\"normal\",variant:\"normal\",weight:\"normal\",stretch:\"normal\",lineHeight:\"normal\",size:\"1rem\",family:[\"serif\"]},f=c(t,/\\s+/);e=f.shift();){if(-1!==i.indexOf(e))return[\"style\",\"variant\",\"weight\",\"stretch\"].forEach(function(t){r[t]=e}),h[t]=r;if(-1===s.indexOf(e))if(\"normal\"!==e&&\"small-caps\"!==e)if(-1===l.indexOf(e)){if(-1===o.indexOf(e)){if(u(e)){var d=c(e,\"/\");if(r.size=d[0],null!=d[1]?r.lineHeight=p(d[1]):\"/\"===f[0]&&(f.shift(),r.lineHeight=p(f.shift())),!f.length)throw new Error(\"Missing required font-family.\");return r.family=c(f.join(\" \"),/\\s*,\\s*/).map(n),h[t]=r}throw new Error(\"Unknown or unsupported font token: \"+e)}r.weight=e}else r.stretch=e;else r.variant=e;else r.style=e}throw new Error(\"Missing required font-size.\")}function p(t){var e=parseFloat(t);return e.toString()===t?e:t}},{\"./lib/util\":140,\"css-font-stretch-keywords\":136,\"css-font-style-keywords\":137,\"css-font-weight-keywords\":138,\"css-global-keywords\":143,\"css-system-font-keywords\":144,\"string-split-by\":529,unquote:548}],142:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\"),i=t(\"./lib/util\").isSize,a=g(t(\"css-global-keywords\")),o=g(t(\"css-system-font-keywords\")),s=g(t(\"css-font-weight-keywords\")),l=g(t(\"css-font-style-keywords\")),c=g(t(\"css-font-stretch-keywords\")),u={normal:1,\"small-caps\":1},h={serif:1,\"sans-serif\":1,monospace:1,cursive:1,fantasy:1,\"system-ui\":1},f=\"1rem\",p=\"serif\";function d(t,e){if(t&&!e[t]&&!a[t])throw Error(\"Unknown keyword `\"+t+\"`\");return t}function g(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=1;return e}e.exports=function(t){if((t=n(t,{style:\"style fontstyle fontStyle font-style slope distinction\",variant:\"variant font-variant fontVariant fontvariant var capitalization\",weight:\"weight w font-weight fontWeight fontweight\",stretch:\"stretch font-stretch fontStretch fontstretch width\",size:\"size s font-size fontSize fontsize height em emSize\",lineHeight:\"lh line-height lineHeight lineheight leading\",family:\"font family fontFamily font-family fontfamily type typeface face\",system:\"system reserved default global\"})).system)return t.system&&d(t.system,o),t.system;if(d(t.style,l),d(t.variant,u),d(t.weight,s),d(t.stretch,c),null==t.size&&(t.size=f),\"number\"==typeof t.size&&(t.size+=\"px\"),!i)throw Error(\"Bad size value `\"+t.size+\"`\");t.family||(t.family=p),Array.isArray(t.family)&&(t.family.length||(t.family=[p]),t.family=t.family.map(function(t){return h[t]?t:'\"'+t+'\"'}).join(\", \"));var e=[];return e.push(t.style),t.variant!==t.style&&e.push(t.variant),t.weight!==t.variant&&t.weight!==t.style&&e.push(t.weight),t.stretch!==t.weight&&t.stretch!==t.variant&&t.stretch!==t.style&&e.push(t.stretch),e.push(t.size+(null==t.lineHeight||\"normal\"===t.lineHeight||t.lineHeight+\"\"==\"1\"?\"\":\"/\"+t.lineHeight)),e.push(t.family),e.filter(Boolean).join(\" \")}},{\"./lib/util\":140,\"css-font-stretch-keywords\":136,\"css-font-style-keywords\":137,\"css-font-weight-keywords\":138,\"css-global-keywords\":143,\"css-system-font-keywords\":144,\"pick-by-alias\":465}],143:[function(t,e,r){e.exports=[\"inherit\",\"initial\",\"unset\"]},{}],144:[function(t,e,r){e.exports=[\"caption\",\"icon\",\"menu\",\"message-box\",\"small-caption\",\"status-bar\"]},{}],145:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i-1,s=i*i,l=o*o,c=(1+2*i)*l,u=i*l,h=s*(3-2*i),f=s*o;if(t.length){a||(a=new Array(t.length));for(var p=t.length-1;p>=0;--p)a[p]=c*t[p]+u*e[p]+h*r[p]+f*n[p];return a}return c*t+u*e+h*r+f*n},e.exports.derivative=function(t,e,r,n,i,a){var o=6*i*i-6*i,s=3*i*i-4*i+1,l=-6*i*i+6*i,c=3*i*i-2*i;if(t.length){a||(a=new Array(t.length));for(var u=t.length-1;u>=0;--u)a[u]=o*t[u]+s*e[u]+l*r[u]+c*n[u];return a}return o*t+s*e+l*r[u]+c*n}},{}],146:[function(t,e,r){\"use strict\";var n=t(\"./lib/thunk.js\");function i(){this.argTypes=[],this.shimArgs=[],this.arrayArgs=[],this.arrayBlockIndices=[],this.scalarArgs=[],this.offsetArgs=[],this.offsetArgIndex=[],this.indexArgs=[],this.shapeArgs=[],this.funcName=\"\",this.pre=null,this.body=null,this.post=null,this.debug=!1}e.exports=function(t){var e=new i;e.pre=t.pre,e.body=t.body,e.post=t.post;var r=t.args.slice(0);e.argTypes=r;for(var a=0;a<r.length;++a){var o=r[a];if(\"array\"===o||\"object\"==typeof o&&o.blockIndices){if(e.argTypes[a]=\"array\",e.arrayArgs.push(a),e.arrayBlockIndices.push(o.blockIndices?o.blockIndices:0),e.shimArgs.push(\"array\"+a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array args\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array args\")}else if(\"scalar\"===o)e.scalarArgs.push(a),e.shimArgs.push(\"scalar\"+a);else if(\"index\"===o){if(e.indexArgs.push(a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array index\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array index\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array index\")}else if(\"shape\"===o){if(e.shapeArgs.push(a),a<e.pre.args.length&&e.pre.args[a].lvalue)throw new Error(\"cwise: pre() block may not write to array shape\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array shape\");if(a<e.post.args.length&&e.post.args[a].lvalue)throw new Error(\"cwise: post() block may not write to array shape\")}else{if(\"object\"!=typeof o||!o.offset)throw new Error(\"cwise: Unknown argument type \"+r[a]);e.argTypes[a]=\"offset\",e.offsetArgs.push({array:o.array,offset:o.offset}),e.offsetArgIndex.push(a)}}if(e.arrayArgs.length<=0)throw new Error(\"cwise: No array arguments specified\");if(e.pre.args.length>r.length)throw new Error(\"cwise: Too many arguments in pre() block\");if(e.body.args.length>r.length)throw new Error(\"cwise: Too many arguments in body() block\");if(e.post.args.length>r.length)throw new Error(\"cwise: Too many arguments in post() block\");return e.debug=!!t.printCode||!!t.debug,e.funcName=t.funcName||\"cwise\",e.blockSize=t.blockSize||64,n(e)}},{\"./lib/thunk.js\":148}],147:[function(t,e,r){\"use strict\";var n=t(\"uniq\");function i(t,e,r){var n,i,a=t.length,o=e.arrayArgs.length,s=e.indexArgs.length>0,l=[],c=[],u=0,h=0;for(n=0;n<a;++n)c.push([\"i\",n,\"=0\"].join(\"\"));for(i=0;i<o;++i)for(n=0;n<a;++n)h=u,u=t[n],0===n?c.push([\"d\",i,\"s\",n,\"=t\",i,\"p\",u].join(\"\")):c.push([\"d\",i,\"s\",n,\"=(t\",i,\"p\",u,\"-s\",h,\"*t\",i,\"p\",h,\")\"].join(\"\"));for(c.length>0&&l.push(\"var \"+c.join(\",\")),n=a-1;n>=0;--n)u=t[n],l.push([\"for(i\",n,\"=0;i\",n,\"<s\",u,\";++i\",n,\"){\"].join(\"\"));for(l.push(r),n=0;n<a;++n){for(h=u,u=t[n],i=0;i<o;++i)l.push([\"p\",i,\"+=d\",i,\"s\",n].join(\"\"));s&&(n>0&&l.push([\"index[\",h,\"]-=s\",h].join(\"\")),l.push([\"++index[\",u,\"]\"].join(\"\"))),l.push(\"}\")}return l.join(\"\\n\")}function a(t,e,r){for(var n=t.body,i=[],a=[],o=0;o<t.args.length;++o){var s=t.args[o];if(!(s.count<=0)){var l=new RegExp(s.name,\"g\"),c=\"\",u=e.arrayArgs.indexOf(o);switch(e.argTypes[o]){case\"offset\":var h=e.offsetArgIndex.indexOf(o);u=e.offsetArgs[h].array,c=\"+q\"+h;case\"array\":c=\"p\"+u+c;var f=\"l\"+o,p=\"a\"+u;if(0===e.arrayBlockIndices[u])1===s.count?\"generic\"===r[u]?s.lvalue?(i.push([\"var \",f,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,f),a.push([p,\".set(\",c,\",\",f,\")\"].join(\"\"))):n=n.replace(l,[p,\".get(\",c,\")\"].join(\"\")):n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\")):\"generic\"===r[u]?(i.push([\"var \",f,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,f),s.lvalue&&a.push([p,\".set(\",c,\",\",f,\")\"].join(\"\"))):(i.push([\"var \",f,\"=\",p,\"[\",c,\"]\"].join(\"\")),n=n.replace(l,f),s.lvalue&&a.push([p,\"[\",c,\"]=\",f].join(\"\")));else{for(var d=[s.name],g=[c],v=0;v<Math.abs(e.arrayBlockIndices[u]);v++)d.push(\"\\\\s*\\\\[([^\\\\]]+)\\\\]\"),g.push(\"$\"+(v+1)+\"*t\"+u+\"b\"+v);if(l=new RegExp(d.join(\"\"),\"g\"),c=g.join(\"+\"),\"generic\"===r[u])throw new Error(\"cwise: Generic arrays not supported in combination with blocks!\");n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\"))}break;case\"scalar\":n=n.replace(l,\"Y\"+e.scalarArgs.indexOf(o));break;case\"index\":n=n.replace(l,\"index\");break;case\"shape\":n=n.replace(l,\"shape\")}}}return[i.join(\"\\n\"),n,a.join(\"\\n\")].join(\"\\n\").trim()}e.exports=function(t,e){for(var r=e[1].length-Math.abs(t.arrayBlockIndices[0])|0,o=new Array(t.arrayArgs.length),s=new Array(t.arrayArgs.length),l=0;l<t.arrayArgs.length;++l)s[l]=e[2*l],o[l]=e[2*l+1];var c=[],u=[],h=[],f=[],p=[];for(l=0;l<t.arrayArgs.length;++l){t.arrayBlockIndices[l]<0?(h.push(0),f.push(r),c.push(r),u.push(r+t.arrayBlockIndices[l])):(h.push(t.arrayBlockIndices[l]),f.push(t.arrayBlockIndices[l]+r),c.push(0),u.push(t.arrayBlockIndices[l]));for(var d=[],g=0;g<o[l].length;g++)h[l]<=o[l][g]&&o[l][g]<f[l]&&d.push(o[l][g]-h[l]);p.push(d)}var v=[\"SS\"],m=[\"'use strict'\"],y=[];for(g=0;g<r;++g)y.push([\"s\",g,\"=SS[\",g,\"]\"].join(\"\"));for(l=0;l<t.arrayArgs.length;++l){for(v.push(\"a\"+l),v.push(\"t\"+l),v.push(\"p\"+l),g=0;g<r;++g)y.push([\"t\",l,\"p\",g,\"=t\",l,\"[\",h[l]+g,\"]\"].join(\"\"));for(g=0;g<Math.abs(t.arrayBlockIndices[l]);++g)y.push([\"t\",l,\"b\",g,\"=t\",l,\"[\",c[l]+g,\"]\"].join(\"\"))}for(l=0;l<t.scalarArgs.length;++l)v.push(\"Y\"+l);if(t.shapeArgs.length>0&&y.push(\"shape=SS.slice(0)\"),t.indexArgs.length>0){var x=new Array(r);for(l=0;l<r;++l)x[l]=\"0\";y.push([\"index=[\",x.join(\",\"),\"]\"].join(\"\"))}for(l=0;l<t.offsetArgs.length;++l){var b=t.offsetArgs[l],_=[];for(g=0;g<b.offset.length;++g)0!==b.offset[g]&&(1===b.offset[g]?_.push([\"t\",b.array,\"p\",g].join(\"\")):_.push([b.offset[g],\"*t\",b.array,\"p\",g].join(\"\")));0===_.length?y.push(\"q\"+l+\"=0\"):y.push([\"q\",l,\"=\",_.join(\"+\")].join(\"\"))}var w=n([].concat(t.pre.thisVars).concat(t.body.thisVars).concat(t.post.thisVars));for((y=y.concat(w)).length>0&&m.push(\"var \"+y.join(\",\")),l=0;l<t.arrayArgs.length;++l)m.push(\"p\"+l+\"|=0\");t.pre.body.length>3&&m.push(a(t.pre,t,s));var k=a(t.body,t,s),T=function(t){for(var e=0,r=t[0].length;e<r;){for(var n=1;n<t.length;++n)if(t[n][e]!==t[0][e])return e;++e}return e}(p);T<r?m.push(function(t,e,r,n){for(var a=e.length,o=r.arrayArgs.length,s=r.blockSize,l=r.indexArgs.length>0,c=[],u=0;u<o;++u)c.push([\"var offset\",u,\"=p\",u].join(\"\"));for(u=t;u<a;++u)c.push([\"for(var j\"+u+\"=SS[\",e[u],\"]|0;j\",u,\">0;){\"].join(\"\")),c.push([\"if(j\",u,\"<\",s,\"){\"].join(\"\")),c.push([\"s\",e[u],\"=j\",u].join(\"\")),c.push([\"j\",u,\"=0\"].join(\"\")),c.push([\"}else{s\",e[u],\"=\",s].join(\"\")),c.push([\"j\",u,\"-=\",s,\"}\"].join(\"\")),l&&c.push([\"index[\",e[u],\"]=j\",u].join(\"\"));for(u=0;u<o;++u){for(var h=[\"offset\"+u],f=t;f<a;++f)h.push([\"j\",f,\"*t\",u,\"p\",e[f]].join(\"\"));c.push([\"p\",u,\"=(\",h.join(\"+\"),\")\"].join(\"\"))}for(c.push(i(e,r,n)),u=t;u<a;++u)c.push(\"}\");return c.join(\"\\n\")}(T,p[0],t,k)):m.push(i(p[0],t,k)),t.post.body.length>3&&m.push(a(t.post,t,s)),t.debug&&console.log(\"-----Generated cwise routine for \",e,\":\\n\"+m.join(\"\\n\")+\"\\n----------\");var A=[t.funcName||\"unnamed\",\"_cwise_loop_\",o[0].join(\"s\"),\"m\",T,function(t){for(var e=new Array(t.length),r=!0,n=0;n<t.length;++n){var i=t[n],a=i.match(/\\d+/);a=a?a[0]:\"\",0===i.charAt(0)?e[n]=\"u\"+i.charAt(1)+a:e[n]=i.charAt(0)+a,n>0&&(r=r&&e[n]===e[n-1])}return r?e[0]:e.join(\"\")}(s)].join(\"\");return new Function([\"function \",A,\"(\",v.join(\",\"),\"){\",m.join(\"\\n\"),\"} return \",A].join(\"\"))()}},{uniq:547}],148:[function(t,e,r){\"use strict\";var n=t(\"./compile.js\");e.exports=function(t){var e=[\"'use strict'\",\"var CACHED={}\"],r=[],i=t.funcName+\"_cwise_thunk\";e.push([\"return function \",i,\"(\",t.shimArgs.join(\",\"),\"){\"].join(\"\"));for(var a=[],o=[],s=[[\"array\",t.arrayArgs[0],\".shape.slice(\",Math.max(0,t.arrayBlockIndices[0]),t.arrayBlockIndices[0]<0?\",\"+t.arrayBlockIndices[0]+\")\":\")\"].join(\"\")],l=[],c=[],u=0;u<t.arrayArgs.length;++u){var h=t.arrayArgs[u];r.push([\"t\",h,\"=array\",h,\".dtype,\",\"r\",h,\"=array\",h,\".order\"].join(\"\")),a.push(\"t\"+h),a.push(\"r\"+h),o.push(\"t\"+h),o.push(\"r\"+h+\".join()\"),s.push(\"array\"+h+\".data\"),s.push(\"array\"+h+\".stride\"),s.push(\"array\"+h+\".offset|0\"),u>0&&(l.push(\"array\"+t.arrayArgs[0]+\".shape.length===array\"+h+\".shape.length+\"+(Math.abs(t.arrayBlockIndices[0])-Math.abs(t.arrayBlockIndices[u]))),c.push(\"array\"+t.arrayArgs[0]+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[0])+\"]===array\"+h+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[u])+\"]\"))}for(t.arrayArgs.length>1&&(e.push(\"if (!(\"+l.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same dimensionality!')\"),e.push(\"for(var shapeIndex=array\"+t.arrayArgs[0]+\".shape.length-\"+Math.abs(t.arrayBlockIndices[0])+\"; shapeIndex--\\x3e0;) {\"),e.push(\"if (!(\"+c.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same shape!')\"),e.push(\"}\")),u=0;u<t.scalarArgs.length;++u)s.push(\"scalar\"+t.scalarArgs[u]);return r.push([\"type=[\",o.join(\",\"),\"].join()\"].join(\"\")),r.push(\"proc=CACHED[type]\"),e.push(\"var \"+r.join(\",\")),e.push([\"if(!proc){\",\"CACHED[type]=proc=compile([\",a.join(\",\"),\"])}\",\"return proc(\",s.join(\",\"),\")}\"].join(\"\")),t.debug&&console.log(\"-----Generated thunk:\\n\"+e.join(\"\\n\")+\"\\n----------\"),new Function(\"compile\",e.join(\"\\n\"))(n.bind(void 0,t))}},{\"./compile.js\":147}],149:[function(t,e,r){e.exports=t(\"cwise-compiler\")},{\"cwise-compiler\":146}],150:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/copy\"),a=t(\"es5-ext/object/normalize-options\"),o=t(\"es5-ext/object/valid-callable\"),s=t(\"es5-ext/object/map\"),l=t(\"es5-ext/object/valid-callable\"),c=t(\"es5-ext/object/valid-value\"),u=Function.prototype.bind,h=Object.defineProperty,f=Object.prototype.hasOwnProperty;n=function(t,e,r){var n,a=c(e)&&l(e.value);return delete(n=i(e)).writable,delete n.value,n.get=function(){return!r.overwriteDefinition&&f.call(this,t)?a:(e.value=u.call(a,r.resolveContext?r.resolveContext(this):this),h(this,t,e),this[t])},n},e.exports=function(t){var e=a(arguments[1]);return null!=e.resolveContext&&o(e.resolveContext),s(t,function(t,r){return n(r,t,e)})}},{\"es5-ext/object/copy\":189,\"es5-ext/object/map\":198,\"es5-ext/object/normalize-options\":199,\"es5-ext/object/valid-callable\":203,\"es5-ext/object/valid-value\":205}],151:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/object/assign\"),i=t(\"es5-ext/object/normalize-options\"),a=t(\"es5-ext/object/is-callable\"),o=t(\"es5-ext/string/#/contains\");(e.exports=function(t,e){var r,a,s,l,c;return arguments.length<2||\"string\"!=typeof t?(l=e,e=t,t=null):l=arguments[2],null==t?(r=s=!0,a=!1):(r=o.call(t,\"c\"),a=o.call(t,\"e\"),s=o.call(t,\"w\")),c={value:e,configurable:r,enumerable:a,writable:s},l?n(i(l),c):c}).gs=function(t,e,r){var s,l,c,u;return\"string\"!=typeof t?(c=r,r=e,e=t,t=null):c=arguments[3],null==e?e=void 0:a(e)?null==r?r=void 0:a(r)||(c=r,r=void 0):(c=e,e=r=void 0),null==t?(s=!0,l=!1):(s=o.call(t,\"c\"),l=o.call(t,\"e\")),u={get:e,set:r,configurable:s,enumerable:l},c?n(i(c),u):u}},{\"es5-ext/object/assign\":186,\"es5-ext/object/is-callable\":192,\"es5-ext/object/normalize-options\":199,\"es5-ext/string/#/contains\":206}],152:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function r(t){var r;return 1===t.length&&(r=t,t=function(t,n){return e(r(t),n)}),{left:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}var n=r(e),i=n.right,a=n.left;function o(t,e){return[t,e]}function s(t){return null===t?NaN:+t}function l(t,e){var r,n,i=t.length,a=0,o=-1,l=0,c=0;if(null==e)for(;++o<i;)isNaN(r=s(t[o]))||(c+=(n=r-l)*(r-(l+=n/++a)));else for(;++o<i;)isNaN(r=s(e(t[o],o,t)))||(c+=(n=r-l)*(r-(l+=n/++a)));if(a>1)return c/(a-1)}function c(t,e){var r=l(t,e);return r?Math.sqrt(r):r}function u(t,e){var r,n,i,a=t.length,o=-1;if(null==e){for(;++o<a;)if(null!=(r=t[o])&&r>=r)for(n=i=r;++o<a;)null!=(r=t[o])&&(n>r&&(n=r),i<r&&(i=r))}else for(;++o<a;)if(null!=(r=e(t[o],o,t))&&r>=r)for(n=i=r;++o<a;)null!=(r=e(t[o],o,t))&&(n>r&&(n=r),i<r&&(i=r));return[n,i]}var h=Array.prototype,f=h.slice,p=h.map;function d(t){return function(){return t}}function g(t){return t}function v(t,e,r){t=+t,e=+e,r=(i=arguments.length)<2?(e=t,t=0,1):i<3?1:+r;for(var n=-1,i=0|Math.max(0,Math.ceil((e-t)/r)),a=new Array(i);++n<i;)a[n]=t+n*r;return a}var m=Math.sqrt(50),y=Math.sqrt(10),x=Math.sqrt(2);function b(t,e,r){var n=(e-t)/Math.max(0,r),i=Math.floor(Math.log(n)/Math.LN10),a=n/Math.pow(10,i);return i>=0?(a>=m?10:a>=y?5:a>=x?2:1)*Math.pow(10,i):-Math.pow(10,-i)/(a>=m?10:a>=y?5:a>=x?2:1)}function _(t,e,r){var n=Math.abs(e-t)/Math.max(0,r),i=Math.pow(10,Math.floor(Math.log(n)/Math.LN10)),a=n/i;return a>=m?i*=10:a>=y?i*=5:a>=x&&(i*=2),e<t?-i:i}function w(t){return Math.ceil(Math.log(t.length)/Math.LN2)+1}function k(t,e,r){if(null==r&&(r=s),n=t.length){if((e=+e)<=0||n<2)return+r(t[0],0,t);if(e>=1)return+r(t[n-1],n-1,t);var n,i=(n-1)*e,a=Math.floor(i),o=+r(t[a],a,t);return o+(+r(t[a+1],a+1,t)-o)*(i-a)}}function T(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&n>r&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&n>r&&(n=r);return n}function A(t){if(!(i=t.length))return[];for(var e=-1,r=T(t,M),n=new Array(r);++e<r;)for(var i,a=-1,o=n[e]=new Array(i);++a<i;)o[a]=t[a][e];return n}function M(t){return t.length}t.bisect=i,t.bisectRight=i,t.bisectLeft=a,t.ascending=e,t.bisector=r,t.cross=function(t,e,r){var n,i,a,s,l=t.length,c=e.length,u=new Array(l*c);for(null==r&&(r=o),n=a=0;n<l;++n)for(s=t[n],i=0;i<c;++i,++a)u[a]=r(s,e[i]);return u},t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.deviation=c,t.extent=u,t.histogram=function(){var t=g,e=u,r=w;function n(n){var a,o,s=n.length,l=new Array(s);for(a=0;a<s;++a)l[a]=t(n[a],a,n);var c=e(l),u=c[0],h=c[1],f=r(l,u,h);Array.isArray(f)||(f=_(u,h,f),f=v(Math.ceil(u/f)*f,h,f));for(var p=f.length;f[0]<=u;)f.shift(),--p;for(;f[p-1]>h;)f.pop(),--p;var d,g=new Array(p+1);for(a=0;a<=p;++a)(d=g[a]=[]).x0=a>0?f[a-1]:u,d.x1=a<p?f[a]:h;for(a=0;a<s;++a)u<=(o=l[a])&&o<=h&&g[i(f,o,0,p)].push(n[a]);return g}return n.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:d(e),n):t},n.domain=function(t){return arguments.length?(e=\"function\"==typeof t?t:d([t[0],t[1]]),n):e},n.thresholds=function(t){return arguments.length?(r=\"function\"==typeof t?t:Array.isArray(t)?d(f.call(t)):d(t),n):r},n},t.thresholdFreedmanDiaconis=function(t,r,n){return t=p.call(t,s).sort(e),Math.ceil((n-r)/(2*(k(t,.75)-k(t,.25))*Math.pow(t.length,-1/3)))},t.thresholdScott=function(t,e,r){return Math.ceil((r-e)/(3.5*c(t)*Math.pow(t.length,-1/3)))},t.thresholdSturges=w,t.max=function(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&r>n&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&r>n&&(n=r);return n},t.mean=function(t,e){var r,n=t.length,i=n,a=-1,o=0;if(null==e)for(;++a<n;)isNaN(r=s(t[a]))?--i:o+=r;else for(;++a<n;)isNaN(r=s(e(t[a],a,t)))?--i:o+=r;if(i)return o/i},t.median=function(t,r){var n,i=t.length,a=-1,o=[];if(null==r)for(;++a<i;)isNaN(n=s(t[a]))||o.push(n);else for(;++a<i;)isNaN(n=s(r(t[a],a,t)))||o.push(n);return k(o.sort(e),.5)},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r},t.min=T,t.pairs=function(t,e){null==e&&(e=o);for(var r=0,n=t.length-1,i=t[0],a=new Array(n<0?0:n);r<n;)a[r]=e(i,i=t[++r]);return a},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.quantile=k,t.range=v,t.scan=function(t,r){if(n=t.length){var n,i,a=0,o=0,s=t[o];for(null==r&&(r=e);++a<n;)(r(i=t[a],s)<0||0!==r(s,s))&&(s=i,o=a);return 0===r(s,s)?o:void 0}},t.shuffle=function(t,e,r){for(var n,i,a=(null==r?t.length:r)-(e=null==e?0:+e);a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.sum=function(t,e){var r,n=t.length,i=-1,a=0;if(null==e)for(;++i<n;)(r=+t[i])&&(a+=r);else for(;++i<n;)(r=+e(t[i],i,t))&&(a+=r);return a},t.ticks=function(t,e,r){var n,i,a,o,s=-1;if(r=+r,(t=+t)==(e=+e)&&r>0)return[t];if((n=e<t)&&(i=t,t=e,e=i),0===(o=b(t,e,r))||!isFinite(o))return[];if(o>0)for(t=Math.ceil(t/o),e=Math.floor(e/o),a=new Array(i=Math.ceil(e-t+1));++s<i;)a[s]=(t+s)*o;else for(t=Math.floor(t*o),e=Math.ceil(e*o),a=new Array(i=Math.ceil(t-e+1));++s<i;)a[s]=(t-s)/o;return n&&a.reverse(),a},t.tickIncrement=b,t.tickStep=_,t.transpose=A,t.variance=l,t.zip=function(){return A(arguments)},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],153:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(){}function r(t,r){var n=new e;if(t instanceof e)t.each(function(t,e){n.set(e,t)});else if(Array.isArray(t)){var i,a=-1,o=t.length;if(null==r)for(;++a<o;)n.set(a,t[a]);else for(;++a<o;)n.set(r(i=t[a],a,t),i)}else if(t)for(var s in t)n.set(s,t[s]);return n}e.prototype=r.prototype={constructor:e,has:function(t){return\"$\"+t in this},get:function(t){return this[\"$\"+t]},set:function(t,e){return this[\"$\"+t]=e,this},remove:function(t){var e=\"$\"+t;return e in this&&delete this[e]},clear:function(){for(var t in this)\"$\"===t[0]&&delete this[t]},keys:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(e.slice(1));return t},values:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(this[e]);return t},entries:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push({key:e.slice(1),value:this[e]});return t},size:function(){var t=0;for(var e in this)\"$\"===e[0]&&++t;return t},empty:function(){for(var t in this)if(\"$\"===t[0])return!1;return!0},each:function(t){for(var e in this)\"$\"===e[0]&&t(this[e],e.slice(1),this)}};function n(){return{}}function i(t,e,r){t[e]=r}function a(){return r()}function o(t,e,r){t.set(e,r)}function s(){}var l=r.prototype;function c(t,e){var r=new s;if(t instanceof s)t.each(function(t){r.add(t)});else if(t){var n=-1,i=t.length;if(null==e)for(;++n<i;)r.add(t[n]);else for(;++n<i;)r.add(e(t[n],n,t))}return r}s.prototype=c.prototype={constructor:s,has:l.has,add:function(t){return this[\"$\"+(t+=\"\")]=t,this},remove:l.remove,clear:l.clear,values:l.keys,size:l.size,empty:l.empty,each:l.each};t.nest=function(){var t,e,s,l=[],c=[];function u(n,i,a,o){if(i>=l.length)return null!=t&&n.sort(t),null!=e?e(n):n;for(var s,c,h,f=-1,p=n.length,d=l[i++],g=r(),v=a();++f<p;)(h=g.get(s=d(c=n[f])+\"\"))?h.push(c):g.set(s,[c]);return g.each(function(t,e){o(v,e,u(t,i,a,o))}),v}return s={object:function(t){return u(t,0,n,i)},map:function(t){return u(t,0,a,o)},entries:function(t){return function t(r,n){if(++n>l.length)return r;var i,a=c[n-1];return null!=e&&n>=l.length?i=r.entries():(i=[],r.each(function(e,r){i.push({key:r,values:t(e,n)})})),null!=a?i.sort(function(t,e){return a(t.key,e.key)}):i}(u(t,0,a,o),0)},key:function(t){return l.push(t),s},sortKeys:function(t){return c[l.length-1]=t,s},sortValues:function(e){return t=e,s},rollup:function(t){return e=t,s}}},t.set=c,t.map=r,t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],154:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e,r){t.prototype=e.prototype=r,r.constructor=t}function r(t,e){var r=Object.create(t.prototype);for(var n in e)r[n]=e[n];return r}function n(){}var i=\"\\\\s*([+-]?\\\\d+)\\\\s*\",a=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)\\\\s*\",o=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)%\\\\s*\",s=/^#([0-9a-f]{3})$/,l=/^#([0-9a-f]{6})$/,c=new RegExp(\"^rgb\\\\(\"+[i,i,i]+\"\\\\)$\"),u=new RegExp(\"^rgb\\\\(\"+[o,o,o]+\"\\\\)$\"),h=new RegExp(\"^rgba\\\\(\"+[i,i,i,a]+\"\\\\)$\"),f=new RegExp(\"^rgba\\\\(\"+[o,o,o,a]+\"\\\\)$\"),p=new RegExp(\"^hsl\\\\(\"+[a,o,o]+\"\\\\)$\"),d=new RegExp(\"^hsla\\\\(\"+[a,o,o,a]+\"\\\\)$\"),g={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};function v(t){var e;return t=(t+\"\").trim().toLowerCase(),(e=s.exec(t))?new _((e=parseInt(e[1],16))>>8&15|e>>4&240,e>>4&15|240&e,(15&e)<<4|15&e,1):(e=l.exec(t))?m(parseInt(e[1],16)):(e=c.exec(t))?new _(e[1],e[2],e[3],1):(e=u.exec(t))?new _(255*e[1]/100,255*e[2]/100,255*e[3]/100,1):(e=h.exec(t))?y(e[1],e[2],e[3],e[4]):(e=f.exec(t))?y(255*e[1]/100,255*e[2]/100,255*e[3]/100,e[4]):(e=p.exec(t))?k(e[1],e[2]/100,e[3]/100,1):(e=d.exec(t))?k(e[1],e[2]/100,e[3]/100,e[4]):g.hasOwnProperty(t)?m(g[t]):\"transparent\"===t?new _(NaN,NaN,NaN,0):null}function m(t){return new _(t>>16&255,t>>8&255,255&t,1)}function y(t,e,r,n){return n<=0&&(t=e=r=NaN),new _(t,e,r,n)}function x(t){return t instanceof n||(t=v(t)),t?new _((t=t.rgb()).r,t.g,t.b,t.opacity):new _}function b(t,e,r,n){return 1===arguments.length?x(t):new _(t,e,r,null==n?1:n)}function _(t,e,r,n){this.r=+t,this.g=+e,this.b=+r,this.opacity=+n}function w(t){return((t=Math.max(0,Math.min(255,Math.round(t)||0)))<16?\"0\":\"\")+t.toString(16)}function k(t,e,r,n){return n<=0?t=e=r=NaN:r<=0||r>=1?t=e=NaN:e<=0&&(t=NaN),new A(t,e,r,n)}function T(t,e,r,i){return 1===arguments.length?function(t){if(t instanceof A)return new A(t.h,t.s,t.l,t.opacity);if(t instanceof n||(t=v(t)),!t)return new A;if(t instanceof A)return t;var e=(t=t.rgb()).r/255,r=t.g/255,i=t.b/255,a=Math.min(e,r,i),o=Math.max(e,r,i),s=NaN,l=o-a,c=(o+a)/2;return l?(s=e===o?(r-i)/l+6*(r<i):r===o?(i-e)/l+2:(e-r)/l+4,l/=c<.5?o+a:2-o-a,s*=60):l=c>0&&c<1?0:s,new A(s,l,c,t.opacity)}(t):new A(t,e,r,null==i?1:i)}function A(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}function M(t,e,r){return 255*(t<60?e+(r-e)*t/60:t<180?r:t<240?e+(r-e)*(240-t)/60:e)}e(n,v,{displayable:function(){return this.rgb().displayable()},hex:function(){return this.rgb().hex()},toString:function(){return this.rgb()+\"\"}}),e(_,b,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new _(this.r*t,this.g*t,this.b*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new _(this.r*t,this.g*t,this.b*t,this.opacity)},rgb:function(){return this},displayable:function(){return 0<=this.r&&this.r<=255&&0<=this.g&&this.g<=255&&0<=this.b&&this.b<=255&&0<=this.opacity&&this.opacity<=1},hex:function(){return\"#\"+w(this.r)+w(this.g)+w(this.b)},toString:function(){var t=this.opacity;return(1===(t=isNaN(t)?1:Math.max(0,Math.min(1,t)))?\"rgb(\":\"rgba(\")+Math.max(0,Math.min(255,Math.round(this.r)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.g)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.b)||0))+(1===t?\")\":\", \"+t+\")\")}})),e(A,T,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new A(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new A(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=this.h%360+360*(this.h<0),e=isNaN(t)||isNaN(this.s)?0:this.s,r=this.l,n=r+(r<.5?r:1-r)*e,i=2*r-n;return new _(M(t>=240?t-240:t+120,i,n),M(t,i,n),M(t<120?t+240:t-120,i,n),this.opacity)},displayable:function(){return(0<=this.s&&this.s<=1||isNaN(this.s))&&0<=this.l&&this.l<=1&&0<=this.opacity&&this.opacity<=1}}));var S=Math.PI/180,E=180/Math.PI,C=.96422,L=1,P=.82521,O=4/29,z=6/29,I=3*z*z,D=z*z*z;function R(t){if(t instanceof B)return new B(t.l,t.a,t.b,t.opacity);if(t instanceof G){if(isNaN(t.h))return new B(t.l,0,0,t.opacity);var e=t.h*S;return new B(t.l,Math.cos(e)*t.c,Math.sin(e)*t.c,t.opacity)}t instanceof _||(t=x(t));var r,n,i=V(t.r),a=V(t.g),o=V(t.b),s=N((.2225045*i+.7168786*a+.0606169*o)/L);return i===a&&a===o?r=n=s:(r=N((.4360747*i+.3850649*a+.1430804*o)/C),n=N((.0139322*i+.0971045*a+.7141733*o)/P)),new B(116*s-16,500*(r-s),200*(s-n),t.opacity)}function F(t,e,r,n){return 1===arguments.length?R(t):new B(t,e,r,null==n?1:n)}function B(t,e,r,n){this.l=+t,this.a=+e,this.b=+r,this.opacity=+n}function N(t){return t>D?Math.pow(t,1/3):t/I+O}function j(t){return t>z?t*t*t:I*(t-O)}function U(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function V(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function q(t){if(t instanceof G)return new G(t.h,t.c,t.l,t.opacity);if(t instanceof B||(t=R(t)),0===t.a&&0===t.b)return new G(NaN,0,t.l,t.opacity);var e=Math.atan2(t.b,t.a)*E;return new G(e<0?e+360:e,Math.sqrt(t.a*t.a+t.b*t.b),t.l,t.opacity)}function H(t,e,r,n){return 1===arguments.length?q(t):new G(t,e,r,null==n?1:n)}function G(t,e,r,n){this.h=+t,this.c=+e,this.l=+r,this.opacity=+n}e(B,F,r(n,{brighter:function(t){return new B(this.l+18*(null==t?1:t),this.a,this.b,this.opacity)},darker:function(t){return new B(this.l-18*(null==t?1:t),this.a,this.b,this.opacity)},rgb:function(){var t=(this.l+16)/116,e=isNaN(this.a)?t:t+this.a/500,r=isNaN(this.b)?t:t-this.b/200;return new _(U(3.1338561*(e=C*j(e))-1.6168667*(t=L*j(t))-.4906146*(r=P*j(r))),U(-.9787684*e+1.9161415*t+.033454*r),U(.0719453*e-.2289914*t+1.4052427*r),this.opacity)}})),e(G,H,r(n,{brighter:function(t){return new G(this.h,this.c,this.l+18*(null==t?1:t),this.opacity)},darker:function(t){return new G(this.h,this.c,this.l-18*(null==t?1:t),this.opacity)},rgb:function(){return R(this).rgb()}}));var Y=-.14861,W=1.78277,X=-.29227,Z=-.90649,J=1.97294,K=J*Z,$=J*W,Q=W*X-Z*Y;function tt(t,e,r,n){return 1===arguments.length?function(t){if(t instanceof et)return new et(t.h,t.s,t.l,t.opacity);t instanceof _||(t=x(t));var e=t.r/255,r=t.g/255,n=t.b/255,i=(Q*n+K*e-$*r)/(Q+K-$),a=n-i,o=(J*(r-i)-X*a)/Z,s=Math.sqrt(o*o+a*a)/(J*i*(1-i)),l=s?Math.atan2(o,a)*E-120:NaN;return new et(l<0?l+360:l,s,i,t.opacity)}(t):new et(t,e,r,null==n?1:n)}function et(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}e(et,tt,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new et(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new et(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=isNaN(this.h)?0:(this.h+120)*S,e=+this.l,r=isNaN(this.s)?0:this.s*e*(1-e),n=Math.cos(t),i=Math.sin(t);return new _(255*(e+r*(Y*n+W*i)),255*(e+r*(X*n+Z*i)),255*(e+r*(J*n)),this.opacity)}})),t.color=v,t.rgb=b,t.hsl=T,t.lab=F,t.hcl=H,t.lch=function(t,e,r,n){return 1===arguments.length?q(t):new G(r,e,t,null==n?1:n)},t.gray=function(t,e){return new B(t,0,0,null==e?1:e)},t.cubehelix=tt,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],155:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e={value:function(){}};function r(){for(var t,e=0,r=arguments.length,i={};e<r;++e){if(!(t=arguments[e]+\"\")||t in i)throw new Error(\"illegal type: \"+t);i[t]=[]}return new n(i)}function n(t){this._=t}function i(t,e){for(var r,n=0,i=t.length;n<i;++n)if((r=t[n]).name===e)return r.value}function a(t,r,n){for(var i=0,a=t.length;i<a;++i)if(t[i].name===r){t[i]=e,t=t.slice(0,i).concat(t.slice(i+1));break}return null!=n&&t.push({name:r,value:n}),t}n.prototype=r.prototype={constructor:n,on:function(t,e){var r,n,o=this._,s=(n=o,(t+\"\").trim().split(/^|\\s+/).map(function(t){var e=\"\",r=t.indexOf(\".\");if(r>=0&&(e=t.slice(r+1),t=t.slice(0,r)),t&&!n.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);return{type:t,name:e}})),l=-1,c=s.length;if(!(arguments.length<2)){if(null!=e&&\"function\"!=typeof e)throw new Error(\"invalid callback: \"+e);for(;++l<c;)if(r=(t=s[l]).type)o[r]=a(o[r],t.name,e);else if(null==e)for(r in o)o[r]=a(o[r],t.name,null);return this}for(;++l<c;)if((r=(t=s[l]).type)&&(r=i(o[r],t.name)))return r},copy:function(){var t={},e=this._;for(var r in e)t[r]=e[r].slice();return new n(t)},call:function(t,e){if((r=arguments.length-2)>0)for(var r,n,i=new Array(r),a=0;a<r;++a)i[a]=arguments[a+2];if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(a=0,r=(n=this._[t]).length;a<r;++a)n[a].value.apply(e,i)},apply:function(t,e,r){if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(var n=this._[t],i=0,a=n.length;i<a;++i)n[i].value.apply(e,r)}},t.dispatch=r,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],156:[function(t,e,r){var n,i;n=this,i=function(t,e,r,n,i){\"use strict\";var a=function(t){return function(){return t}},o=function(){return 1e-6*(Math.random()-.5)};function s(t){return t.x+t.vx}function l(t){return t.y+t.vy}function c(t){return t.index}function u(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function h(t){return t.x}function f(t){return t.y}var p=10,d=Math.PI*(3-Math.sqrt(5));t.forceCenter=function(t,e){var r;function n(){var n,i,a=r.length,o=0,s=0;for(n=0;n<a;++n)o+=(i=r[n]).x,s+=i.y;for(o=o/a-t,s=s/a-e,n=0;n<a;++n)(i=r[n]).x-=o,i.y-=s}return null==t&&(t=0),null==e&&(e=0),n.initialize=function(t){r=t},n.x=function(e){return arguments.length?(t=+e,n):t},n.y=function(t){return arguments.length?(e=+t,n):e},n},t.forceCollide=function(t){var r,n,i=1,c=1;function u(){for(var t,a,u,f,p,d,g,v=r.length,m=0;m<c;++m)for(a=e.quadtree(r,s,l).visitAfter(h),t=0;t<v;++t)u=r[t],d=n[u.index],g=d*d,f=u.x+u.vx,p=u.y+u.vy,a.visit(y);function y(t,e,r,n,a){var s=t.data,l=t.r,c=d+l;if(!s)return e>f+c||n<f-c||r>p+c||a<p-c;if(s.index>u.index){var h=f-s.x-s.vx,v=p-s.y-s.vy,m=h*h+v*v;m<c*c&&(0===h&&(m+=(h=o())*h),0===v&&(m+=(v=o())*v),m=(c-(m=Math.sqrt(m)))/m*i,u.vx+=(h*=m)*(c=(l*=l)/(g+l)),u.vy+=(v*=m)*c,s.vx-=h*(c=1-c),s.vy-=v*c)}}}function h(t){if(t.data)return t.r=n[t.data.index];for(var e=t.r=0;e<4;++e)t[e]&&t[e].r>t.r&&(t.r=t[e].r)}function f(){if(r){var e,i,a=r.length;for(n=new Array(a),e=0;e<a;++e)i=r[e],n[i.index]=+t(i,e,r)}}return\"function\"!=typeof t&&(t=a(null==t?1:+t)),u.initialize=function(t){r=t,f()},u.iterations=function(t){return arguments.length?(c=+t,u):c},u.strength=function(t){return arguments.length?(i=+t,u):i},u.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),f(),u):t},u},t.forceLink=function(t){var e,n,i,s,l,h=c,f=function(t){return 1/Math.min(s[t.source.index],s[t.target.index])},p=a(30),d=1;function g(r){for(var i=0,a=t.length;i<d;++i)for(var s,c,u,h,f,p,g,v=0;v<a;++v)c=(s=t[v]).source,h=(u=s.target).x+u.vx-c.x-c.vx||o(),f=u.y+u.vy-c.y-c.vy||o(),h*=p=((p=Math.sqrt(h*h+f*f))-n[v])/p*r*e[v],f*=p,u.vx-=h*(g=l[v]),u.vy-=f*g,c.vx+=h*(g=1-g),c.vy+=f*g}function v(){if(i){var a,o,c=i.length,f=t.length,p=r.map(i,h);for(a=0,s=new Array(c);a<f;++a)(o=t[a]).index=a,\"object\"!=typeof o.source&&(o.source=u(p,o.source)),\"object\"!=typeof o.target&&(o.target=u(p,o.target)),s[o.source.index]=(s[o.source.index]||0)+1,s[o.target.index]=(s[o.target.index]||0)+1;for(a=0,l=new Array(f);a<f;++a)o=t[a],l[a]=s[o.source.index]/(s[o.source.index]+s[o.target.index]);e=new Array(f),m(),n=new Array(f),y()}}function m(){if(i)for(var r=0,n=t.length;r<n;++r)e[r]=+f(t[r],r,t)}function y(){if(i)for(var e=0,r=t.length;e<r;++e)n[e]=+p(t[e],e,t)}return null==t&&(t=[]),g.initialize=function(t){i=t,v()},g.links=function(e){return arguments.length?(t=e,v(),g):t},g.id=function(t){return arguments.length?(h=t,g):h},g.iterations=function(t){return arguments.length?(d=+t,g):d},g.strength=function(t){return arguments.length?(f=\"function\"==typeof t?t:a(+t),m(),g):f},g.distance=function(t){return arguments.length?(p=\"function\"==typeof t?t:a(+t),y(),g):p},g},t.forceManyBody=function(){var t,r,n,i,s=a(-30),l=1,c=1/0,u=.81;function p(i){var a,o=t.length,s=e.quadtree(t,h,f).visitAfter(g);for(n=i,a=0;a<o;++a)r=t[a],s.visit(v)}function d(){if(t){var e,r,n=t.length;for(i=new Array(n),e=0;e<n;++e)r=t[e],i[r.index]=+s(r,e,t)}}function g(t){var e,r,n,a,o,s=0,l=0;if(t.length){for(n=a=o=0;o<4;++o)(e=t[o])&&(r=Math.abs(e.value))&&(s+=e.value,l+=r,n+=r*e.x,a+=r*e.y);t.x=n/l,t.y=a/l}else{(e=t).x=e.data.x,e.y=e.data.y;do{s+=i[e.data.index]}while(e=e.next)}t.value=s}function v(t,e,a,s){if(!t.value)return!0;var h=t.x-r.x,f=t.y-r.y,p=s-e,d=h*h+f*f;if(p*p/u<d)return d<c&&(0===h&&(d+=(h=o())*h),0===f&&(d+=(f=o())*f),d<l&&(d=Math.sqrt(l*d)),r.vx+=h*t.value*n/d,r.vy+=f*t.value*n/d),!0;if(!(t.length||d>=c)){(t.data!==r||t.next)&&(0===h&&(d+=(h=o())*h),0===f&&(d+=(f=o())*f),d<l&&(d=Math.sqrt(l*d)));do{t.data!==r&&(p=i[t.data.index]*n/d,r.vx+=h*p,r.vy+=f*p)}while(t=t.next)}}return p.initialize=function(e){t=e,d()},p.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),d(),p):s},p.distanceMin=function(t){return arguments.length?(l=t*t,p):Math.sqrt(l)},p.distanceMax=function(t){return arguments.length?(c=t*t,p):Math.sqrt(c)},p.theta=function(t){return arguments.length?(u=t*t,p):Math.sqrt(u)},p},t.forceRadial=function(t,e,r){var n,i,o,s=a(.1);function l(t){for(var a=0,s=n.length;a<s;++a){var l=n[a],c=l.x-e||1e-6,u=l.y-r||1e-6,h=Math.sqrt(c*c+u*u),f=(o[a]-h)*i[a]*t/h;l.vx+=c*f,l.vy+=u*f}}function c(){if(n){var e,r=n.length;for(i=new Array(r),o=new Array(r),e=0;e<r;++e)o[e]=+t(n[e],e,n),i[e]=isNaN(o[e])?0:+s(n[e],e,n)}}return\"function\"!=typeof t&&(t=a(+t)),null==e&&(e=0),null==r&&(r=0),l.initialize=function(t){n=t,c()},l.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),c(),l):s},l.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),c(),l):t},l.x=function(t){return arguments.length?(e=+t,l):e},l.y=function(t){return arguments.length?(r=+t,l):r},l},t.forceSimulation=function(t){var e,a=1,o=.001,s=1-Math.pow(o,1/300),l=0,c=.6,u=r.map(),h=i.timer(g),f=n.dispatch(\"tick\",\"end\");function g(){v(),f.call(\"tick\",e),a<o&&(h.stop(),f.call(\"end\",e))}function v(){var e,r,n=t.length;for(a+=(l-a)*s,u.each(function(t){t(a)}),e=0;e<n;++e)null==(r=t[e]).fx?r.x+=r.vx*=c:(r.x=r.fx,r.vx=0),null==r.fy?r.y+=r.vy*=c:(r.y=r.fy,r.vy=0)}function m(){for(var e,r=0,n=t.length;r<n;++r){if((e=t[r]).index=r,isNaN(e.x)||isNaN(e.y)){var i=p*Math.sqrt(r),a=r*d;e.x=i*Math.cos(a),e.y=i*Math.sin(a)}(isNaN(e.vx)||isNaN(e.vy))&&(e.vx=e.vy=0)}}function y(e){return e.initialize&&e.initialize(t),e}return null==t&&(t=[]),m(),e={tick:v,restart:function(){return h.restart(g),e},stop:function(){return h.stop(),e},nodes:function(r){return arguments.length?(t=r,m(),u.each(y),e):t},alpha:function(t){return arguments.length?(a=+t,e):a},alphaMin:function(t){return arguments.length?(o=+t,e):o},alphaDecay:function(t){return arguments.length?(s=+t,e):+s},alphaTarget:function(t){return arguments.length?(l=+t,e):l},velocityDecay:function(t){return arguments.length?(c=1-t,e):1-c},force:function(t,r){return arguments.length>1?(null==r?u.remove(t):u.set(t,y(r)),e):u.get(t)},find:function(e,r,n){var i,a,o,s,l,c=0,u=t.length;for(null==n?n=1/0:n*=n,c=0;c<u;++c)(o=(i=e-(s=t[c]).x)*i+(a=r-s.y)*a)<n&&(l=s,n=o);return l},on:function(t,r){return arguments.length>1?(f.on(t,r),e):f.on(t)}}},t.forceX=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vx+=(n[a]-i.x)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},t.forceY=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vy+=(n[a]-i.y)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.y=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-quadtree\"),t(\"d3-collection\"),t(\"d3-dispatch\"),t(\"d3-timer\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,n.d3)},{\"d3-collection\":153,\"d3-dispatch\":155,\"d3-quadtree\":160,\"d3-timer\":162}],157:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e){return t.parent===e.parent?1:2}function r(t,e){return t+e.x}function n(t,e){return Math.max(t,e.y)}function i(t){var e=0,r=t.children,n=r&&r.length;if(n)for(;--n>=0;)e+=r[n].value;else e=1;t.value=e}function a(t,e){var r,n,i,a,s,u=new c(t),h=+t.value&&(u.value=t.value),f=[u];for(null==e&&(e=o);r=f.pop();)if(h&&(r.value=+r.data.value),(i=e(r.data))&&(s=i.length))for(r.children=new Array(s),a=s-1;a>=0;--a)f.push(n=r.children[a]=new c(i[a])),n.parent=r,n.depth=r.depth+1;return u.eachBefore(l)}function o(t){return t.children}function s(t){t.data=t.data.data}function l(t){var e=0;do{t.height=e}while((t=t.parent)&&t.height<++e)}function c(t){this.data=t,this.depth=this.height=0,this.parent=null}c.prototype=a.prototype={constructor:c,count:function(){return this.eachAfter(i)},each:function(t){var e,r,n,i,a=this,o=[a];do{for(e=o.reverse(),o=[];a=e.pop();)if(t(a),r=a.children)for(n=0,i=r.length;n<i;++n)o.push(r[n])}while(o.length);return this},eachAfter:function(t){for(var e,r,n,i=this,a=[i],o=[];i=a.pop();)if(o.push(i),e=i.children)for(r=0,n=e.length;r<n;++r)a.push(e[r]);for(;i=o.pop();)t(i);return this},eachBefore:function(t){for(var e,r,n=this,i=[n];n=i.pop();)if(t(n),e=n.children)for(r=e.length-1;r>=0;--r)i.push(e[r]);return this},sum:function(t){return this.eachAfter(function(e){for(var r=+t(e.data)||0,n=e.children,i=n&&n.length;--i>=0;)r+=n[i].value;e.value=r})},sort:function(t){return this.eachBefore(function(e){e.children&&e.children.sort(t)})},path:function(t){for(var e=this,r=function(t,e){if(t===e)return t;var r=t.ancestors(),n=e.ancestors(),i=null;for(t=r.pop(),e=n.pop();t===e;)i=t,t=r.pop(),e=n.pop();return i}(e,t),n=[e];e!==r;)e=e.parent,n.push(e);for(var i=n.length;t!==r;)n.splice(i,0,t),t=t.parent;return n},ancestors:function(){for(var t=this,e=[t];t=t.parent;)e.push(t);return e},descendants:function(){var t=[];return this.each(function(e){t.push(e)}),t},leaves:function(){var t=[];return this.eachBefore(function(e){e.children||t.push(e)}),t},links:function(){var t=this,e=[];return t.each(function(r){r!==t&&e.push({source:r.parent,target:r})}),e},copy:function(){return a(this).eachBefore(s)}};var u=Array.prototype.slice;function h(t){for(var e,r,n=0,i=(t=function(t){for(var e,r,n=t.length;n;)r=Math.random()*n--|0,e=t[n],t[n]=t[r],t[r]=e;return t}(u.call(t))).length,a=[];n<i;)e=t[n],r&&d(r,e)?++n:(r=v(a=f(a,e)),n=0);return r}function f(t,e){var r,n;if(g(e,t))return[e];for(r=0;r<t.length;++r)if(p(e,t[r])&&g(m(t[r],e),t))return[t[r],e];for(r=0;r<t.length-1;++r)for(n=r+1;n<t.length;++n)if(p(m(t[r],t[n]),e)&&p(m(t[r],e),t[n])&&p(m(t[n],e),t[r])&&g(y(t[r],t[n],e),t))return[t[r],t[n],e];throw new Error}function p(t,e){var r=t.r-e.r,n=e.x-t.x,i=e.y-t.y;return r<0||r*r<n*n+i*i}function d(t,e){var r=t.r-e.r+1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function g(t,e){for(var r=0;r<e.length;++r)if(!d(t,e[r]))return!1;return!0}function v(t){switch(t.length){case 1:return{x:(e=t[0]).x,y:e.y,r:e.r};case 2:return m(t[0],t[1]);case 3:return y(t[0],t[1],t[2])}var e}function m(t,e){var r=t.x,n=t.y,i=t.r,a=e.x,o=e.y,s=e.r,l=a-r,c=o-n,u=s-i,h=Math.sqrt(l*l+c*c);return{x:(r+a+l/h*u)/2,y:(n+o+c/h*u)/2,r:(h+i+s)/2}}function y(t,e,r){var n=t.x,i=t.y,a=t.r,o=e.x,s=e.y,l=e.r,c=r.x,u=r.y,h=r.r,f=n-o,p=n-c,d=i-s,g=i-u,v=l-a,m=h-a,y=n*n+i*i-a*a,x=y-o*o-s*s+l*l,b=y-c*c-u*u+h*h,_=p*d-f*g,w=(d*b-g*x)/(2*_)-n,k=(g*v-d*m)/_,T=(p*x-f*b)/(2*_)-i,A=(f*m-p*v)/_,M=k*k+A*A-1,S=2*(a+w*k+T*A),E=w*w+T*T-a*a,C=-(M?(S+Math.sqrt(S*S-4*M*E))/(2*M):E/S);return{x:n+w+k*C,y:i+T+A*C,r:C}}function x(t,e,r){var n,i,a,o,s=t.x-e.x,l=t.y-e.y,c=s*s+l*l;c?(i=e.r+r.r,i*=i,o=t.r+r.r,i>(o*=o)?(n=(c+o-i)/(2*c),a=Math.sqrt(Math.max(0,o/c-n*n)),r.x=t.x-n*s-a*l,r.y=t.y-n*l+a*s):(n=(c+i-o)/(2*c),a=Math.sqrt(Math.max(0,i/c-n*n)),r.x=e.x+n*s-a*l,r.y=e.y+n*l+a*s)):(r.x=e.x+r.r,r.y=e.y)}function b(t,e){var r=t.r+e.r-1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function _(t){var e=t._,r=t.next._,n=e.r+r.r,i=(e.x*r.r+r.x*e.r)/n,a=(e.y*r.r+r.y*e.r)/n;return i*i+a*a}function w(t){this._=t,this.next=null,this.previous=null}function k(t){if(!(i=t.length))return 0;var e,r,n,i,a,o,s,l,c,u,f;if((e=t[0]).x=0,e.y=0,!(i>1))return e.r;if(r=t[1],e.x=-r.r,r.x=e.r,r.y=0,!(i>2))return e.r+r.r;x(r,e,n=t[2]),e=new w(e),r=new w(r),n=new w(n),e.next=n.previous=r,r.next=e.previous=n,n.next=r.previous=e;t:for(s=3;s<i;++s){x(e._,r._,n=t[s]),n=new w(n),l=r.next,c=e.previous,u=r._.r,f=e._.r;do{if(u<=f){if(b(l._,n._)){r=l,e.next=r,r.previous=e,--s;continue t}u+=l._.r,l=l.next}else{if(b(c._,n._)){(e=c).next=r,r.previous=e,--s;continue t}f+=c._.r,c=c.previous}}while(l!==c.next);for(n.previous=e,n.next=r,e.next=r.previous=r=n,a=_(e);(n=n.next)!==r;)(o=_(n))<a&&(e=n,a=o);r=e.next}for(e=[r._],n=r;(n=n.next)!==r;)e.push(n._);for(n=h(e),s=0;s<i;++s)(e=t[s]).x-=n.x,e.y-=n.y;return n.r}function T(t){if(\"function\"!=typeof t)throw new Error;return t}function A(){return 0}function M(t){return function(){return t}}function S(t){return Math.sqrt(t.value)}function E(t){return function(e){e.children||(e.r=Math.max(0,+t(e)||0))}}function C(t,e){return function(r){if(n=r.children){var n,i,a,o=n.length,s=t(r)*e||0;if(s)for(i=0;i<o;++i)n[i].r+=s;if(a=k(n),s)for(i=0;i<o;++i)n[i].r-=s;r.r=a+s}}}function L(t){return function(e){var r=e.parent;e.r*=t,r&&(e.x=r.x+t*e.x,e.y=r.y+t*e.y)}}function P(t){t.x0=Math.round(t.x0),t.y0=Math.round(t.y0),t.x1=Math.round(t.x1),t.y1=Math.round(t.y1)}function O(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(n-e)/t.value;++s<l;)(a=o[s]).y0=r,a.y1=i,a.x0=e,a.x1=e+=a.value*c}var z=\"$\",I={depth:-1},D={};function R(t){return t.id}function F(t){return t.parentId}function B(t,e){return t.parent===e.parent?1:2}function N(t){var e=t.children;return e?e[0]:t.t}function j(t){var e=t.children;return e?e[e.length-1]:t.t}function U(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function V(t,e,r){return t.a.parent===e.parent?t.a:r}function q(t,e){this._=t,this.parent=null,this.children=null,this.A=null,this.a=this,this.z=0,this.m=0,this.c=0,this.s=0,this.t=null,this.i=e}function H(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(i-r)/t.value;++s<l;)(a=o[s]).x0=e,a.x1=n,a.y0=r,a.y1=r+=a.value*c}q.prototype=Object.create(c.prototype);var G=(1+Math.sqrt(5))/2;function Y(t,e,r,n,i,a){for(var o,s,l,c,u,h,f,p,d,g,v,m=[],y=e.children,x=0,b=0,_=y.length,w=e.value;x<_;){l=i-r,c=a-n;do{u=y[b++].value}while(!u&&b<_);for(h=f=u,v=u*u*(g=Math.max(c/l,l/c)/(w*t)),d=Math.max(f/v,v/h);b<_;++b){if(u+=s=y[b].value,s<h&&(h=s),s>f&&(f=s),v=u*u*g,(p=Math.max(f/v,v/h))>d){u-=s;break}d=p}m.push(o={value:u,dice:l<c,children:y.slice(x,b)}),o.dice?O(o,r,n,i,w?n+=c*u/w:a):H(o,r,n,w?r+=l*u/w:i,a),w-=u,x=b}return m}var W=function t(e){function r(t,r,n,i,a){Y(e,t,r,n,i,a)}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);var X=function t(e){function r(t,r,n,i,a){if((o=t._squarify)&&o.ratio===e)for(var o,s,l,c,u,h=-1,f=o.length,p=t.value;++h<f;){for(l=(s=o[h]).children,c=s.value=0,u=l.length;c<u;++c)s.value+=l[c].value;s.dice?O(s,r,n,i,n+=(a-n)*s.value/p):H(s,r,n,r+=(i-r)*s.value/p,a),p-=s.value}else t._squarify=o=Y(e,t,r,n,i,a),o.ratio=e}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);t.cluster=function(){var t=e,i=1,a=1,o=!1;function s(e){var s,l=0;e.eachAfter(function(e){var i=e.children;i?(e.x=function(t){return t.reduce(r,0)/t.length}(i),e.y=function(t){return 1+t.reduce(n,0)}(i)):(e.x=s?l+=t(e,s):0,e.y=0,s=e)});var c=function(t){for(var e;e=t.children;)t=e[0];return t}(e),u=function(t){for(var e;e=t.children;)t=e[e.length-1];return t}(e),h=c.x-t(c,u)/2,f=u.x+t(u,c)/2;return e.eachAfter(o?function(t){t.x=(t.x-e.x)*i,t.y=(e.y-t.y)*a}:function(t){t.x=(t.x-h)/(f-h)*i,t.y=(1-(e.y?t.y/e.y:1))*a})}return s.separation=function(e){return arguments.length?(t=e,s):t},s.size=function(t){return arguments.length?(o=!1,i=+t[0],a=+t[1],s):o?null:[i,a]},s.nodeSize=function(t){return arguments.length?(o=!0,i=+t[0],a=+t[1],s):o?[i,a]:null},s},t.hierarchy=a,t.pack=function(){var t=null,e=1,r=1,n=A;function i(i){return i.x=e/2,i.y=r/2,t?i.eachBefore(E(t)).eachAfter(C(n,.5)).eachBefore(L(1)):i.eachBefore(E(S)).eachAfter(C(A,1)).eachAfter(C(n,i.r/Math.min(e,r))).eachBefore(L(Math.min(e,r)/(2*i.r))),i}return i.radius=function(e){return arguments.length?(t=null==(r=e)?null:T(r),i):t;var r},i.size=function(t){return arguments.length?(e=+t[0],r=+t[1],i):[e,r]},i.padding=function(t){return arguments.length?(n=\"function\"==typeof t?t:M(+t),i):n},i},t.packSiblings=function(t){return k(t),t},t.packEnclose=h,t.partition=function(){var t=1,e=1,r=0,n=!1;function i(i){var a=i.height+1;return i.x0=i.y0=r,i.x1=t,i.y1=e/a,i.eachBefore(function(t,e){return function(n){n.children&&O(n,n.x0,t*(n.depth+1)/e,n.x1,t*(n.depth+2)/e);var i=n.x0,a=n.y0,o=n.x1-r,s=n.y1-r;o<i&&(i=o=(i+o)/2),s<a&&(a=s=(a+s)/2),n.x0=i,n.y0=a,n.x1=o,n.y1=s}}(e,a)),n&&i.eachBefore(P),i}return i.round=function(t){return arguments.length?(n=!!t,i):n},i.size=function(r){return arguments.length?(t=+r[0],e=+r[1],i):[t,e]},i.padding=function(t){return arguments.length?(r=+t,i):r},i},t.stratify=function(){var t=R,e=F;function r(r){var n,i,a,o,s,u,h,f=r.length,p=new Array(f),d={};for(i=0;i<f;++i)n=r[i],s=p[i]=new c(n),null!=(u=t(n,i,r))&&(u+=\"\")&&(d[h=z+(s.id=u)]=h in d?D:s);for(i=0;i<f;++i)if(s=p[i],null!=(u=e(r[i],i,r))&&(u+=\"\")){if(!(o=d[z+u]))throw new Error(\"missing: \"+u);if(o===D)throw new Error(\"ambiguous: \"+u);o.children?o.children.push(s):o.children=[s],s.parent=o}else{if(a)throw new Error(\"multiple roots\");a=s}if(!a)throw new Error(\"no root\");if(a.parent=I,a.eachBefore(function(t){t.depth=t.parent.depth+1,--f}).eachBefore(l),a.parent=null,f>0)throw new Error(\"cycle\");return a}return r.id=function(e){return arguments.length?(t=T(e),r):t},r.parentId=function(t){return arguments.length?(e=T(t),r):e},r},t.tree=function(){var t=B,e=1,r=1,n=null;function i(i){var l=function(t){for(var e,r,n,i,a,o=new q(t,0),s=[o];e=s.pop();)if(n=e._.children)for(e.children=new Array(a=n.length),i=a-1;i>=0;--i)s.push(r=e.children[i]=new q(n[i],i)),r.parent=e;return(o.parent=new q(null,0)).children=[o],o}(i);if(l.eachAfter(a),l.parent.m=-l.z,l.eachBefore(o),n)i.eachBefore(s);else{var c=i,u=i,h=i;i.eachBefore(function(t){t.x<c.x&&(c=t),t.x>u.x&&(u=t),t.depth>h.depth&&(h=t)});var f=c===u?1:t(c,u)/2,p=f-c.x,d=e/(u.x+f+p),g=r/(h.depth||1);i.eachBefore(function(t){t.x=(t.x+p)*d,t.y=t.depth*g})}return i}function a(e){var r=e.children,n=e.parent.children,i=e.i?n[e.i-1]:null;if(r){!function(t){for(var e,r=0,n=0,i=t.children,a=i.length;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(e);var a=(r[0].z+r[r.length-1].z)/2;i?(e.z=i.z+t(e._,i._),e.m=e.z-a):e.z=a}else i&&(e.z=i.z+t(e._,i._));e.parent.A=function(e,r,n){if(r){for(var i,a=e,o=e,s=r,l=a.parent.children[0],c=a.m,u=o.m,h=s.m,f=l.m;s=j(s),a=N(a),s&&a;)l=N(l),(o=j(o)).a=e,(i=s.z+h-a.z-c+t(s._,a._))>0&&(U(V(s,e,n),e,i),c+=i,u+=i),h+=s.m,c+=a.m,f+=l.m,u+=o.m;s&&!j(o)&&(o.t=s,o.m+=h-u),a&&!N(l)&&(l.t=a,l.m+=c-f,n=e)}return n}(e,i,e.parent.A||n[0])}function o(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function s(t){t.x*=e,t.y=t.depth*r}return i.separation=function(e){return arguments.length?(t=e,i):t},i.size=function(t){return arguments.length?(n=!1,e=+t[0],r=+t[1],i):n?null:[e,r]},i.nodeSize=function(t){return arguments.length?(n=!0,e=+t[0],r=+t[1],i):n?[e,r]:null},i},t.treemap=function(){var t=W,e=!1,r=1,n=1,i=[0],a=A,o=A,s=A,l=A,c=A;function u(t){return t.x0=t.y0=0,t.x1=r,t.y1=n,t.eachBefore(h),i=[0],e&&t.eachBefore(P),t}function h(e){var r=i[e.depth],n=e.x0+r,u=e.y0+r,h=e.x1-r,f=e.y1-r;h<n&&(n=h=(n+h)/2),f<u&&(u=f=(u+f)/2),e.x0=n,e.y0=u,e.x1=h,e.y1=f,e.children&&(r=i[e.depth+1]=a(e)/2,n+=c(e)-r,u+=o(e)-r,(h-=s(e)-r)<n&&(n=h=(n+h)/2),(f-=l(e)-r)<u&&(u=f=(u+f)/2),t(e,n,u,h,f))}return u.round=function(t){return arguments.length?(e=!!t,u):e},u.size=function(t){return arguments.length?(r=+t[0],n=+t[1],u):[r,n]},u.tile=function(e){return arguments.length?(t=T(e),u):t},u.padding=function(t){return arguments.length?u.paddingInner(t).paddingOuter(t):u.paddingInner()},u.paddingInner=function(t){return arguments.length?(a=\"function\"==typeof t?t:M(+t),u):a},u.paddingOuter=function(t){return arguments.length?u.paddingTop(t).paddingRight(t).paddingBottom(t).paddingLeft(t):u.paddingTop()},u.paddingTop=function(t){return arguments.length?(o=\"function\"==typeof t?t:M(+t),u):o},u.paddingRight=function(t){return arguments.length?(s=\"function\"==typeof t?t:M(+t),u):s},u.paddingBottom=function(t){return arguments.length?(l=\"function\"==typeof t?t:M(+t),u):l},u.paddingLeft=function(t){return arguments.length?(c=\"function\"==typeof t?t:M(+t),u):c},u},t.treemapBinary=function(t,e,r,n,i){var a,o,s=t.children,l=s.length,c=new Array(l+1);for(c[0]=o=a=0;a<l;++a)c[a+1]=o+=s[a].value;!function t(e,r,n,i,a,o,l){if(e>=r-1){var u=s[e];return u.x0=i,u.y0=a,u.x1=o,void(u.y1=l)}for(var h=c[e],f=n/2+h,p=e+1,d=r-1;p<d;){var g=p+d>>>1;c[g]<f?p=g+1:d=g}f-c[p-1]<c[p]-f&&e+1<p&&--p;var v=c[p]-h,m=n-v;if(o-i>l-a){var y=(i*m+o*v)/n;t(e,p,v,i,a,y,l),t(p,r,m,y,a,o,l)}else{var x=(a*m+l*v)/n;t(e,p,v,i,a,o,x),t(p,r,m,i,x,o,l)}}(0,l,t.value,e,r,n,i)},t.treemapDice=O,t.treemapSlice=H,t.treemapSliceDice=function(t,e,r,n,i){(1&t.depth?H:O)(t,e,r,n,i)},t.treemapSquarify=W,t.treemapResquarify=X,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],158:[function(t,e,r){var n,i;n=this,i=function(t,e){\"use strict\";function r(t,e,r,n,i){var a=t*t,o=a*t;return((1-3*t+3*a-o)*e+(4-6*a+3*o)*r+(1+3*t+3*a-3*o)*n+o*i)/6}function n(t){var e=t.length-1;return function(n){var i=n<=0?n=0:n>=1?(n=1,e-1):Math.floor(n*e),a=t[i],o=t[i+1],s=i>0?t[i-1]:2*a-o,l=i<e-1?t[i+2]:2*o-a;return r((n-i/e)*e,s,a,o,l)}}function i(t){var e=t.length;return function(n){var i=Math.floor(((n%=1)<0?++n:n)*e),a=t[(i+e-1)%e],o=t[i%e],s=t[(i+1)%e],l=t[(i+2)%e];return r((n-i/e)*e,a,o,s,l)}}function a(t){return function(){return t}}function o(t,e){return function(r){return t+r*e}}function s(t,e){var r=e-t;return r?o(t,r>180||r<-180?r-360*Math.round(r/360):r):a(isNaN(t)?e:t)}function l(t){return 1==(t=+t)?c:function(e,r){return r-e?function(t,e,r){return t=Math.pow(t,r),e=Math.pow(e,r)-t,r=1/r,function(n){return Math.pow(t+n*e,r)}}(e,r,t):a(isNaN(e)?r:e)}}function c(t,e){var r=e-t;return r?o(t,r):a(isNaN(t)?e:t)}var u=function t(r){var n=l(r);function i(t,r){var i=n((t=e.rgb(t)).r,(r=e.rgb(r)).r),a=n(t.g,r.g),o=n(t.b,r.b),s=c(t.opacity,r.opacity);return function(e){return t.r=i(e),t.g=a(e),t.b=o(e),t.opacity=s(e),t+\"\"}}return i.gamma=t,i}(1);function h(t){return function(r){var n,i,a=r.length,o=new Array(a),s=new Array(a),l=new Array(a);for(n=0;n<a;++n)i=e.rgb(r[n]),o[n]=i.r||0,s[n]=i.g||0,l[n]=i.b||0;return o=t(o),s=t(s),l=t(l),i.opacity=1,function(t){return i.r=o(t),i.g=s(t),i.b=l(t),i+\"\"}}}var f=h(n),p=h(i);function d(t,e){var r,n=e?e.length:0,i=t?Math.min(n,t.length):0,a=new Array(i),o=new Array(n);for(r=0;r<i;++r)a[r]=_(t[r],e[r]);for(;r<n;++r)o[r]=e[r];return function(t){for(r=0;r<i;++r)o[r]=a[r](t);return o}}function g(t,e){var r=new Date;return e-=t=+t,function(n){return r.setTime(t+e*n),r}}function v(t,e){return e-=t=+t,function(r){return t+e*r}}function m(t,e){var r,n={},i={};for(r in null!==t&&\"object\"==typeof t||(t={}),null!==e&&\"object\"==typeof e||(e={}),e)r in t?n[r]=_(t[r],e[r]):i[r]=e[r];return function(t){for(r in n)i[r]=n[r](t);return i}}var y=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,x=new RegExp(y.source,\"g\");function b(t,e){var r,n,i,a=y.lastIndex=x.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=y.exec(t))&&(n=x.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:v(r,n)})),a=x.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?function(t){return function(e){return t(e)+\"\"}}(l[0].x):function(t){return function(){return t}}(e):(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}function _(t,r){var n,i=typeof r;return null==r||\"boolean\"===i?a(r):(\"number\"===i?v:\"string\"===i?(n=e.color(r))?(r=n,u):b:r instanceof e.color?u:r instanceof Date?g:Array.isArray(r)?d:\"function\"!=typeof r.valueOf&&\"function\"!=typeof r.toString||isNaN(r)?m:v)(t,r)}var w,k,T,A,M=180/Math.PI,S={translateX:0,translateY:0,rotate:0,skewX:0,scaleX:1,scaleY:1};function E(t,e,r,n,i,a){var o,s,l;return(o=Math.sqrt(t*t+e*e))&&(t/=o,e/=o),(l=t*r+e*n)&&(r-=t*l,n-=e*l),(s=Math.sqrt(r*r+n*n))&&(r/=s,n/=s,l/=s),t*n<e*r&&(t=-t,e=-e,l=-l,o=-o),{translateX:i,translateY:a,rotate:Math.atan2(e,t)*M,skewX:Math.atan(l)*M,scaleX:o,scaleY:s}}function C(t,e,r,n){function i(t){return t.length?t.pop()+\" \":\"\"}return function(a,o){var s=[],l=[];return a=t(a),o=t(o),function(t,n,i,a,o,s){if(t!==i||n!==a){var l=o.push(\"translate(\",null,e,null,r);s.push({i:l-4,x:v(t,i)},{i:l-2,x:v(n,a)})}else(i||a)&&o.push(\"translate(\"+i+e+a+r)}(a.translateX,a.translateY,o.translateX,o.translateY,s,l),function(t,e,r,a){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),a.push({i:r.push(i(r)+\"rotate(\",null,n)-2,x:v(t,e)})):e&&r.push(i(r)+\"rotate(\"+e+n)}(a.rotate,o.rotate,s,l),function(t,e,r,a){t!==e?a.push({i:r.push(i(r)+\"skewX(\",null,n)-2,x:v(t,e)}):e&&r.push(i(r)+\"skewX(\"+e+n)}(a.skewX,o.skewX,s,l),function(t,e,r,n,a,o){if(t!==r||e!==n){var s=a.push(i(a)+\"scale(\",null,\",\",null,\")\");o.push({i:s-4,x:v(t,r)},{i:s-2,x:v(e,n)})}else 1===r&&1===n||a.push(i(a)+\"scale(\"+r+\",\"+n+\")\")}(a.scaleX,a.scaleY,o.scaleX,o.scaleY,s,l),a=o=null,function(t){for(var e,r=-1,n=l.length;++r<n;)s[(e=l[r]).i]=e.x(t);return s.join(\"\")}}}var L=C(function(t){return\"none\"===t?S:(w||(w=document.createElement(\"DIV\"),k=document.documentElement,T=document.defaultView),w.style.transform=t,t=T.getComputedStyle(k.appendChild(w),null).getPropertyValue(\"transform\"),k.removeChild(w),E(+(t=t.slice(7,-1).split(\",\"))[0],+t[1],+t[2],+t[3],+t[4],+t[5]))},\"px, \",\"px)\",\"deg)\"),P=C(function(t){return null==t?S:(A||(A=document.createElementNS(\"http://www.w3.org/2000/svg\",\"g\")),A.setAttribute(\"transform\",t),(t=A.transform.baseVal.consolidate())?E((t=t.matrix).a,t.b,t.c,t.d,t.e,t.f):S)},\", \",\")\",\")\"),O=Math.SQRT2,z=2,I=4,D=1e-12;function R(t){return((t=Math.exp(t))+1/t)/2}function F(t){return function(r,n){var i=t((r=e.hsl(r)).h,(n=e.hsl(n)).h),a=c(r.s,n.s),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.s=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var B=F(s),N=F(c);function j(t){return function(r,n){var i=t((r=e.hcl(r)).h,(n=e.hcl(n)).h),a=c(r.c,n.c),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.c=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var U=j(s),V=j(c);function q(t){return function r(n){function i(r,i){var a=t((r=e.cubehelix(r)).h,(i=e.cubehelix(i)).h),o=c(r.s,i.s),s=c(r.l,i.l),l=c(r.opacity,i.opacity);return function(t){return r.h=a(t),r.s=o(t),r.l=s(Math.pow(t,n)),r.opacity=l(t),r+\"\"}}return n=+n,i.gamma=r,i}(1)}var H=q(s),G=q(c);t.interpolate=_,t.interpolateArray=d,t.interpolateBasis=n,t.interpolateBasisClosed=i,t.interpolateDate=g,t.interpolateDiscrete=function(t){var e=t.length;return function(r){return t[Math.max(0,Math.min(e-1,Math.floor(r*e)))]}},t.interpolateHue=function(t,e){var r=s(+t,+e);return function(t){var e=r(t);return e-360*Math.floor(e/360)}},t.interpolateNumber=v,t.interpolateObject=m,t.interpolateRound=function(t,e){return e-=t=+t,function(r){return Math.round(t+e*r)}},t.interpolateString=b,t.interpolateTransformCss=L,t.interpolateTransformSvg=P,t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,h=l-a,f=u*u+h*h;if(f<D)n=Math.log(c/o)/O,r=function(t){return[i+t*u,a+t*h,o*Math.exp(O*t*n)]};else{var p=Math.sqrt(f),d=(c*c-o*o+I*f)/(2*o*z*p),g=(c*c-o*o-I*f)/(2*c*z*p),v=Math.log(Math.sqrt(d*d+1)-d),m=Math.log(Math.sqrt(g*g+1)-g);n=(m-v)/O,r=function(t){var e,r=t*n,s=R(v),l=o/(z*p)*(s*(e=O*r+v,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(v));return[i+l*u,a+l*h,o*s/R(O*r+v)]}}return r.duration=1e3*n,r},t.interpolateRgb=u,t.interpolateRgbBasis=f,t.interpolateRgbBasisClosed=p,t.interpolateHsl=B,t.interpolateHslLong=N,t.interpolateLab=function(t,r){var n=c((t=e.lab(t)).l,(r=e.lab(r)).l),i=c(t.a,r.a),a=c(t.b,r.b),o=c(t.opacity,r.opacity);return function(e){return t.l=n(e),t.a=i(e),t.b=a(e),t.opacity=o(e),t+\"\"}},t.interpolateHcl=U,t.interpolateHclLong=V,t.interpolateCubehelix=H,t.interpolateCubehelixLong=G,t.piecewise=function(t,e){for(var r=0,n=e.length-1,i=e[0],a=new Array(n<0?0:n);r<n;)a[r]=t(i,i=e[++r]);return function(t){var e=Math.max(0,Math.min(n-1,Math.floor(t*=n)));return a[e](t-e)}},t.quantize=function(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t(n/(e-1));return r},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-color\")):i(n.d3=n.d3||{},n.d3)},{\"d3-color\":154}],159:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e=Math.PI,r=2*e,n=r-1e-6;function i(){this._x0=this._y0=this._x1=this._y1=null,this._=\"\"}function a(){return new i}i.prototype=a.prototype={constructor:i,moveTo:function(t,e){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)},closePath:function(){null!==this._x1&&(this._x1=this._x0,this._y1=this._y0,this._+=\"Z\")},lineTo:function(t,e){this._+=\"L\"+(this._x1=+t)+\",\"+(this._y1=+e)},quadraticCurveTo:function(t,e,r,n){this._+=\"Q\"+ +t+\",\"+ +e+\",\"+(this._x1=+r)+\",\"+(this._y1=+n)},bezierCurveTo:function(t,e,r,n,i,a){this._+=\"C\"+ +t+\",\"+ +e+\",\"+ +r+\",\"+ +n+\",\"+(this._x1=+i)+\",\"+(this._y1=+a)},arcTo:function(t,r,n,i,a){t=+t,r=+r,n=+n,i=+i,a=+a;var o=this._x1,s=this._y1,l=n-t,c=i-r,u=o-t,h=s-r,f=u*u+h*h;if(a<0)throw new Error(\"negative radius: \"+a);if(null===this._x1)this._+=\"M\"+(this._x1=t)+\",\"+(this._y1=r);else if(f>1e-6)if(Math.abs(h*l-c*u)>1e-6&&a){var p=n-o,d=i-s,g=l*l+c*c,v=p*p+d*d,m=Math.sqrt(g),y=Math.sqrt(f),x=a*Math.tan((e-Math.acos((g+f-v)/(2*m*y)))/2),b=x/y,_=x/m;Math.abs(b-1)>1e-6&&(this._+=\"L\"+(t+b*u)+\",\"+(r+b*h)),this._+=\"A\"+a+\",\"+a+\",0,0,\"+ +(h*p>u*d)+\",\"+(this._x1=t+_*l)+\",\"+(this._y1=r+_*c)}else this._+=\"L\"+(this._x1=t)+\",\"+(this._y1=r);else;},arc:function(t,i,a,o,s,l){t=+t,i=+i;var c=(a=+a)*Math.cos(o),u=a*Math.sin(o),h=t+c,f=i+u,p=1^l,d=l?o-s:s-o;if(a<0)throw new Error(\"negative radius: \"+a);null===this._x1?this._+=\"M\"+h+\",\"+f:(Math.abs(this._x1-h)>1e-6||Math.abs(this._y1-f)>1e-6)&&(this._+=\"L\"+h+\",\"+f),a&&(d<0&&(d=d%r+r),d>n?this._+=\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(t-c)+\",\"+(i-u)+\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(this._x1=h)+\",\"+(this._y1=f):d>1e-6&&(this._+=\"A\"+a+\",\"+a+\",0,\"+ +(d>=e)+\",\"+p+\",\"+(this._x1=t+a*Math.cos(s))+\",\"+(this._y1=i+a*Math.sin(s))))},rect:function(t,e,r,n){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)+\"h\"+ +r+\"v\"+ +n+\"h\"+-r+\"Z\"},toString:function(){return this._}},t.path=a,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],160:[function(t,e,r){var n;n=this,function(t){\"use strict\";function e(t,e,r,n){if(isNaN(e)||isNaN(r))return t;var i,a,o,s,l,c,u,h,f,p=t._root,d={data:n},g=t._x0,v=t._y0,m=t._x1,y=t._y1;if(!p)return t._root=d,t;for(;p.length;)if((c=e>=(a=(g+m)/2))?g=a:m=a,(u=r>=(o=(v+y)/2))?v=o:y=o,i=p,!(p=p[h=u<<1|c]))return i[h]=d,t;if(s=+t._x.call(null,p.data),l=+t._y.call(null,p.data),e===s&&r===l)return d.next=p,i?i[h]=d:t._root=d,t;do{i=i?i[h]=new Array(4):t._root=new Array(4),(c=e>=(a=(g+m)/2))?g=a:m=a,(u=r>=(o=(v+y)/2))?v=o:y=o}while((h=u<<1|c)==(f=(l>=o)<<1|s>=a));return i[f]=p,i[h]=d,t}var r=function(t,e,r,n,i){this.node=t,this.x0=e,this.y0=r,this.x1=n,this.y1=i};function n(t){return t[0]}function i(t){return t[1]}function a(t,e,r){var a=new o(null==e?n:e,null==r?i:r,NaN,NaN,NaN,NaN);return null==t?a:a.addAll(t)}function o(t,e,r,n,i,a){this._x=t,this._y=e,this._x0=r,this._y0=n,this._x1=i,this._y1=a,this._root=void 0}function s(t){for(var e={data:t.data},r=e;t=t.next;)r=r.next={data:t.data};return e}var l=a.prototype=o.prototype;l.copy=function(){var t,e,r=new o(this._x,this._y,this._x0,this._y0,this._x1,this._y1),n=this._root;if(!n)return r;if(!n.length)return r._root=s(n),r;for(t=[{source:n,target:r._root=new Array(4)}];n=t.pop();)for(var i=0;i<4;++i)(e=n.source[i])&&(e.length?t.push({source:e,target:n.target[i]=new Array(4)}):n.target[i]=s(e));return r},l.add=function(t){var r=+this._x.call(null,t),n=+this._y.call(null,t);return e(this.cover(r,n),r,n,t)},l.addAll=function(t){var r,n,i,a,o=t.length,s=new Array(o),l=new Array(o),c=1/0,u=1/0,h=-1/0,f=-1/0;for(n=0;n<o;++n)isNaN(i=+this._x.call(null,r=t[n]))||isNaN(a=+this._y.call(null,r))||(s[n]=i,l[n]=a,i<c&&(c=i),i>h&&(h=i),a<u&&(u=a),a>f&&(f=a));for(h<c&&(c=this._x0,h=this._x1),f<u&&(u=this._y0,f=this._y1),this.cover(c,u).cover(h,f),n=0;n<o;++n)e(this,s[n],l[n],t[n]);return this},l.cover=function(t,e){if(isNaN(t=+t)||isNaN(e=+e))return this;var r=this._x0,n=this._y0,i=this._x1,a=this._y1;if(isNaN(r))i=(r=Math.floor(t))+1,a=(n=Math.floor(e))+1;else{if(!(r>t||t>i||n>e||e>a))return this;var o,s,l=i-r,c=this._root;switch(s=(e<(n+a)/2)<<1|t<(r+i)/2){case 0:do{(o=new Array(4))[s]=c,c=o}while(a=n+(l*=2),t>(i=r+l)||e>a);break;case 1:do{(o=new Array(4))[s]=c,c=o}while(a=n+(l*=2),(r=i-l)>t||e>a);break;case 2:do{(o=new Array(4))[s]=c,c=o}while(n=a-(l*=2),t>(i=r+l)||n>e);break;case 3:do{(o=new Array(4))[s]=c,c=o}while(n=a-(l*=2),(r=i-l)>t||n>e)}this._root&&this._root.length&&(this._root=c)}return this._x0=r,this._y0=n,this._x1=i,this._y1=a,this},l.data=function(){var t=[];return this.visit(function(e){if(!e.length)do{t.push(e.data)}while(e=e.next)}),t},l.extent=function(t){return arguments.length?this.cover(+t[0][0],+t[0][1]).cover(+t[1][0],+t[1][1]):isNaN(this._x0)?void 0:[[this._x0,this._y0],[this._x1,this._y1]]},l.find=function(t,e,n){var i,a,o,s,l,c,u,h=this._x0,f=this._y0,p=this._x1,d=this._y1,g=[],v=this._root;for(v&&g.push(new r(v,h,f,p,d)),null==n?n=1/0:(h=t-n,f=e-n,p=t+n,d=e+n,n*=n);c=g.pop();)if(!(!(v=c.node)||(a=c.x0)>p||(o=c.y0)>d||(s=c.x1)<h||(l=c.y1)<f))if(v.length){var m=(a+s)/2,y=(o+l)/2;g.push(new r(v[3],m,y,s,l),new r(v[2],a,y,m,l),new r(v[1],m,o,s,y),new r(v[0],a,o,m,y)),(u=(e>=y)<<1|t>=m)&&(c=g[g.length-1],g[g.length-1]=g[g.length-1-u],g[g.length-1-u]=c)}else{var x=t-+this._x.call(null,v.data),b=e-+this._y.call(null,v.data),_=x*x+b*b;if(_<n){var w=Math.sqrt(n=_);h=t-w,f=e-w,p=t+w,d=e+w,i=v.data}}return i},l.remove=function(t){if(isNaN(a=+this._x.call(null,t))||isNaN(o=+this._y.call(null,t)))return this;var e,r,n,i,a,o,s,l,c,u,h,f,p=this._root,d=this._x0,g=this._y0,v=this._x1,m=this._y1;if(!p)return this;if(p.length)for(;;){if((c=a>=(s=(d+v)/2))?d=s:v=s,(u=o>=(l=(g+m)/2))?g=l:m=l,e=p,!(p=p[h=u<<1|c]))return this;if(!p.length)break;(e[h+1&3]||e[h+2&3]||e[h+3&3])&&(r=e,f=h)}for(;p.data!==t;)if(n=p,!(p=p.next))return this;return(i=p.next)&&delete p.next,n?(i?n.next=i:delete n.next,this):e?(i?e[h]=i:delete e[h],(p=e[0]||e[1]||e[2]||e[3])&&p===(e[3]||e[2]||e[1]||e[0])&&!p.length&&(r?r[f]=p:this._root=p),this):(this._root=i,this)},l.removeAll=function(t){for(var e=0,r=t.length;e<r;++e)this.remove(t[e]);return this},l.root=function(){return this._root},l.size=function(){var t=0;return this.visit(function(e){if(!e.length)do{++t}while(e=e.next)}),t},l.visit=function(t){var e,n,i,a,o,s,l=[],c=this._root;for(c&&l.push(new r(c,this._x0,this._y0,this._x1,this._y1));e=l.pop();)if(!t(c=e.node,i=e.x0,a=e.y0,o=e.x1,s=e.y1)&&c.length){var u=(i+o)/2,h=(a+s)/2;(n=c[3])&&l.push(new r(n,u,h,o,s)),(n=c[2])&&l.push(new r(n,i,h,u,s)),(n=c[1])&&l.push(new r(n,u,a,o,h)),(n=c[0])&&l.push(new r(n,i,a,u,h))}return this},l.visitAfter=function(t){var e,n=[],i=[];for(this._root&&n.push(new r(this._root,this._x0,this._y0,this._x1,this._y1));e=n.pop();){var a=e.node;if(a.length){var o,s=e.x0,l=e.y0,c=e.x1,u=e.y1,h=(s+c)/2,f=(l+u)/2;(o=a[0])&&n.push(new r(o,s,l,h,f)),(o=a[1])&&n.push(new r(o,h,l,c,f)),(o=a[2])&&n.push(new r(o,s,f,h,u)),(o=a[3])&&n.push(new r(o,h,f,c,u))}i.push(e)}for(;e=i.pop();)t(e.node,e.x0,e.y0,e.x1,e.y1);return this},l.x=function(t){return arguments.length?(this._x=t,this):this._x},l.y=function(t){return arguments.length?(this._y=t,this):this._y},t.quadtree=a,Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],161:[function(t,e,r){var n,i;n=this,i=function(t,e){\"use strict\";function r(t){return function(){return t}}var n=Math.abs,i=Math.atan2,a=Math.cos,o=Math.max,s=Math.min,l=Math.sin,c=Math.sqrt,u=1e-12,h=Math.PI,f=h/2,p=2*h;function d(t){return t>=1?f:t<=-1?-f:Math.asin(t)}function g(t){return t.innerRadius}function v(t){return t.outerRadius}function m(t){return t.startAngle}function y(t){return t.endAngle}function x(t){return t&&t.padAngle}function b(t,e,r,n,i,a,s){var l=t-r,u=e-n,h=(s?a:-a)/c(l*l+u*u),f=h*u,p=-h*l,d=t+f,g=e+p,v=r+f,m=n+p,y=(d+v)/2,x=(g+m)/2,b=v-d,_=m-g,w=b*b+_*_,k=i-a,T=d*m-v*g,A=(_<0?-1:1)*c(o(0,k*k*w-T*T)),M=(T*_-b*A)/w,S=(-T*b-_*A)/w,E=(T*_+b*A)/w,C=(-T*b+_*A)/w,L=M-y,P=S-x,O=E-y,z=C-x;return L*L+P*P>O*O+z*z&&(M=E,S=C),{cx:M,cy:S,x01:-f,y01:-p,x11:M*(i/k-1),y11:S*(i/k-1)}}function _(t){this._context=t}function w(t){return new _(t)}function k(t){return t[0]}function T(t){return t[1]}function A(){var t=k,n=T,i=r(!0),a=null,o=w,s=null;function l(r){var l,c,u,h=r.length,f=!1;for(null==a&&(s=o(u=e.path())),l=0;l<=h;++l)!(l<h&&i(c=r[l],l,r))===f&&((f=!f)?s.lineStart():s.lineEnd()),f&&s.point(+t(c,l,r),+n(c,l,r));if(u)return s=null,u+\"\"||null}return l.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),l):t},l.y=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),l):n},l.defined=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(!!t),l):i},l.curve=function(t){return arguments.length?(o=t,null!=a&&(s=o(a)),l):o},l.context=function(t){return arguments.length?(null==t?a=s=null:s=o(a=t),l):a},l}function M(){var t=k,n=null,i=r(0),a=T,o=r(!0),s=null,l=w,c=null;function u(r){var u,h,f,p,d,g=r.length,v=!1,m=new Array(g),y=new Array(g);for(null==s&&(c=l(d=e.path())),u=0;u<=g;++u){if(!(u<g&&o(p=r[u],u,r))===v)if(v=!v)h=u,c.areaStart(),c.lineStart();else{for(c.lineEnd(),c.lineStart(),f=u-1;f>=h;--f)c.point(m[f],y[f]);c.lineEnd(),c.areaEnd()}v&&(m[u]=+t(p,u,r),y[u]=+i(p,u,r),c.point(n?+n(p,u,r):m[u],a?+a(p,u,r):y[u]))}if(d)return c=null,d+\"\"||null}function h(){return A().defined(o).curve(l).context(s)}return u.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),n=null,u):t},u.x0=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),u):t},u.x1=function(t){return arguments.length?(n=null==t?null:\"function\"==typeof t?t:r(+t),u):n},u.y=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a=null,u):i},u.y0=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),u):i},u.y1=function(t){return arguments.length?(a=null==t?null:\"function\"==typeof t?t:r(+t),u):a},u.lineX0=u.lineY0=function(){return h().x(t).y(i)},u.lineY1=function(){return h().x(t).y(a)},u.lineX1=function(){return h().x(n).y(i)},u.defined=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(!!t),u):o},u.curve=function(t){return arguments.length?(l=t,null!=s&&(c=l(s)),u):l},u.context=function(t){return arguments.length?(null==t?s=c=null:c=l(s=t),u):s},u}function S(t,e){return e<t?-1:e>t?1:e>=t?0:NaN}function E(t){return t}_.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._point=0},lineEnd:function(){(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:this._context.lineTo(t,e)}}};var C=P(w);function L(t){this._curve=t}function P(t){function e(e){return new L(t(e))}return e._curve=t,e}function O(t){var e=t.curve;return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function z(){return O(A().curve(C))}function I(){var t=M().curve(C),e=t.curve,r=t.lineX0,n=t.lineX1,i=t.lineY0,a=t.lineY1;return t.angle=t.x,delete t.x,t.startAngle=t.x0,delete t.x0,t.endAngle=t.x1,delete t.x1,t.radius=t.y,delete t.y,t.innerRadius=t.y0,delete t.y0,t.outerRadius=t.y1,delete t.y1,t.lineStartAngle=function(){return O(r())},delete t.lineX0,t.lineEndAngle=function(){return O(n())},delete t.lineX1,t.lineInnerRadius=function(){return O(i())},delete t.lineY0,t.lineOuterRadius=function(){return O(a())},delete t.lineY1,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function D(t,e){return[(e=+e)*Math.cos(t-=Math.PI/2),e*Math.sin(t)]}L.prototype={areaStart:function(){this._curve.areaStart()},areaEnd:function(){this._curve.areaEnd()},lineStart:function(){this._curve.lineStart()},lineEnd:function(){this._curve.lineEnd()},point:function(t,e){this._curve.point(e*Math.sin(t),e*-Math.cos(t))}};var R=Array.prototype.slice;function F(t){return t.source}function B(t){return t.target}function N(t){var n=F,i=B,a=k,o=T,s=null;function l(){var r,l=R.call(arguments),c=n.apply(this,l),u=i.apply(this,l);if(s||(s=r=e.path()),t(s,+a.apply(this,(l[0]=c,l)),+o.apply(this,l),+a.apply(this,(l[0]=u,l)),+o.apply(this,l)),r)return s=null,r+\"\"||null}return l.source=function(t){return arguments.length?(n=t,l):n},l.target=function(t){return arguments.length?(i=t,l):i},l.x=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),l):a},l.y=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),l):o},l.context=function(t){return arguments.length?(s=null==t?null:t,l):s},l}function j(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e=(e+n)/2,r,e,i,n,i)}function U(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e,r=(r+i)/2,n,r,n,i)}function V(t,e,r,n,i){var a=D(e,r),o=D(e,r=(r+i)/2),s=D(n,r),l=D(n,i);t.moveTo(a[0],a[1]),t.bezierCurveTo(o[0],o[1],s[0],s[1],l[0],l[1])}var q={draw:function(t,e){var r=Math.sqrt(e/h);t.moveTo(r,0),t.arc(0,0,r,0,p)}},H={draw:function(t,e){var r=Math.sqrt(e/5)/2;t.moveTo(-3*r,-r),t.lineTo(-r,-r),t.lineTo(-r,-3*r),t.lineTo(r,-3*r),t.lineTo(r,-r),t.lineTo(3*r,-r),t.lineTo(3*r,r),t.lineTo(r,r),t.lineTo(r,3*r),t.lineTo(-r,3*r),t.lineTo(-r,r),t.lineTo(-3*r,r),t.closePath()}},G=Math.sqrt(1/3),Y=2*G,W={draw:function(t,e){var r=Math.sqrt(e/Y),n=r*G;t.moveTo(0,-r),t.lineTo(n,0),t.lineTo(0,r),t.lineTo(-n,0),t.closePath()}},X=Math.sin(h/10)/Math.sin(7*h/10),Z=Math.sin(p/10)*X,J=-Math.cos(p/10)*X,K={draw:function(t,e){var r=Math.sqrt(.8908130915292852*e),n=Z*r,i=J*r;t.moveTo(0,-r),t.lineTo(n,i);for(var a=1;a<5;++a){var o=p*a/5,s=Math.cos(o),l=Math.sin(o);t.lineTo(l*r,-s*r),t.lineTo(s*n-l*i,l*n+s*i)}t.closePath()}},$={draw:function(t,e){var r=Math.sqrt(e),n=-r/2;t.rect(n,n,r,r)}},Q=Math.sqrt(3),tt={draw:function(t,e){var r=-Math.sqrt(e/(3*Q));t.moveTo(0,2*r),t.lineTo(-Q*r,-r),t.lineTo(Q*r,-r),t.closePath()}},et=-.5,rt=Math.sqrt(3)/2,nt=1/Math.sqrt(12),it=3*(nt/2+1),at={draw:function(t,e){var r=Math.sqrt(e/it),n=r/2,i=r*nt,a=n,o=r*nt+r,s=-a,l=o;t.moveTo(n,i),t.lineTo(a,o),t.lineTo(s,l),t.lineTo(et*n-rt*i,rt*n+et*i),t.lineTo(et*a-rt*o,rt*a+et*o),t.lineTo(et*s-rt*l,rt*s+et*l),t.lineTo(et*n+rt*i,et*i-rt*n),t.lineTo(et*a+rt*o,et*o-rt*a),t.lineTo(et*s+rt*l,et*l-rt*s),t.closePath()}},ot=[q,H,W,$,K,tt,at];function st(){}function lt(t,e,r){t._context.bezierCurveTo((2*t._x0+t._x1)/3,(2*t._y0+t._y1)/3,(t._x0+2*t._x1)/3,(t._y0+2*t._y1)/3,(t._x0+4*t._x1+e)/6,(t._y0+4*t._y1+r)/6)}function ct(t){this._context=t}function ut(t){this._context=t}function ht(t){this._context=t}function ft(t,e){this._basis=new ct(t),this._beta=e}ct.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){switch(this._point){case 3:lt(this,this._x1,this._y1);case 2:this._context.lineTo(this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,this._context.lineTo((5*this._x0+this._x1)/6,(5*this._y0+this._y1)/6);default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ut.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._y0=this._y1=this._y2=this._y3=this._y4=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x2,this._y2),this._context.closePath();break;case 2:this._context.moveTo((this._x2+2*this._x3)/3,(this._y2+2*this._y3)/3),this._context.lineTo((this._x3+2*this._x2)/3,(this._y3+2*this._y2)/3),this._context.closePath();break;case 3:this.point(this._x2,this._y2),this.point(this._x3,this._y3),this.point(this._x4,this._y4)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x2=t,this._y2=e;break;case 1:this._point=2,this._x3=t,this._y3=e;break;case 2:this._point=3,this._x4=t,this._y4=e,this._context.moveTo((this._x0+4*this._x1+t)/6,(this._y0+4*this._y1+e)/6);break;default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ht.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3;var r=(this._x0+4*this._x1+t)/6,n=(this._y0+4*this._y1+e)/6;this._line?this._context.lineTo(r,n):this._context.moveTo(r,n);break;case 3:this._point=4;default:lt(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ft.prototype={lineStart:function(){this._x=[],this._y=[],this._basis.lineStart()},lineEnd:function(){var t=this._x,e=this._y,r=t.length-1;if(r>0)for(var n,i=t[0],a=e[0],o=t[r]-i,s=e[r]-a,l=-1;++l<=r;)n=l/r,this._basis.point(this._beta*t[l]+(1-this._beta)*(i+n*o),this._beta*e[l]+(1-this._beta)*(a+n*s));this._x=this._y=null,this._basis.lineEnd()},point:function(t,e){this._x.push(+t),this._y.push(+e)}};var pt=function t(e){function r(t){return 1===e?new ct(t):new ft(t,e)}return r.beta=function(e){return t(+e)},r}(.85);function dt(t,e,r){t._context.bezierCurveTo(t._x1+t._k*(t._x2-t._x0),t._y1+t._k*(t._y2-t._y0),t._x2+t._k*(t._x1-e),t._y2+t._k*(t._y1-r),t._x2,t._y2)}function gt(t,e){this._context=t,this._k=(1-e)/6}gt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:dt(this,this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2,this._x1=t,this._y1=e;break;case 2:this._point=3;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var vt=function t(e){function r(t){return new gt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function mt(t,e){this._context=t,this._k=(1-e)/6}mt.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var yt=function t(e){function r(t){return new mt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function xt(t,e){this._context=t,this._k=(1-e)/6}xt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:dt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var bt=function t(e){function r(t){return new xt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function _t(t,e,r){var n=t._x1,i=t._y1,a=t._x2,o=t._y2;if(t._l01_a>u){var s=2*t._l01_2a+3*t._l01_a*t._l12_a+t._l12_2a,l=3*t._l01_a*(t._l01_a+t._l12_a);n=(n*s-t._x0*t._l12_2a+t._x2*t._l01_2a)/l,i=(i*s-t._y0*t._l12_2a+t._y2*t._l01_2a)/l}if(t._l23_a>u){var c=2*t._l23_2a+3*t._l23_a*t._l12_a+t._l12_2a,h=3*t._l23_a*(t._l23_a+t._l12_a);a=(a*c+t._x1*t._l23_2a-e*t._l12_2a)/h,o=(o*c+t._y1*t._l23_2a-r*t._l12_2a)/h}t._context.bezierCurveTo(n,i,a,o,t._x2,t._y2)}function wt(t,e){this._context=t,this._alpha=e}wt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:this.point(this._x2,this._y2)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var kt=function t(e){function r(t){return e?new wt(t,e):new gt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Tt(t,e){this._context=t,this._alpha=e}Tt.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var At=function t(e){function r(t){return e?new Tt(t,e):new mt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Mt(t,e){this._context=t,this._alpha=e}Mt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:_t(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var St=function t(e){function r(t){return e?new Mt(t,e):new xt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Et(t){this._context=t}function Ct(t){return t<0?-1:1}function Lt(t,e,r){var n=t._x1-t._x0,i=e-t._x1,a=(t._y1-t._y0)/(n||i<0&&-0),o=(r-t._y1)/(i||n<0&&-0),s=(a*i+o*n)/(n+i);return(Ct(a)+Ct(o))*Math.min(Math.abs(a),Math.abs(o),.5*Math.abs(s))||0}function Pt(t,e){var r=t._x1-t._x0;return r?(3*(t._y1-t._y0)/r-e)/2:e}function Ot(t,e,r){var n=t._x0,i=t._y0,a=t._x1,o=t._y1,s=(a-n)/3;t._context.bezierCurveTo(n+s,i+s*e,a-s,o-s*r,a,o)}function zt(t){this._context=t}function It(t){this._context=new Dt(t)}function Dt(t){this._context=t}function Rt(t){this._context=t}function Ft(t){var e,r,n=t.length-1,i=new Array(n),a=new Array(n),o=new Array(n);for(i[0]=0,a[0]=2,o[0]=t[0]+2*t[1],e=1;e<n-1;++e)i[e]=1,a[e]=4,o[e]=4*t[e]+2*t[e+1];for(i[n-1]=2,a[n-1]=7,o[n-1]=8*t[n-1]+t[n],e=1;e<n;++e)r=i[e]/a[e-1],a[e]-=r,o[e]-=r*o[e-1];for(i[n-1]=o[n-1]/a[n-1],e=n-2;e>=0;--e)i[e]=(o[e]-i[e+1])/a[e];for(a[n-1]=(t[n]+i[n-1])/2,e=0;e<n-1;++e)a[e]=2*t[e+1]-i[e+1];return[i,a]}function Bt(t,e){this._context=t,this._t=e}function Nt(t,e){if((i=t.length)>1)for(var r,n,i,a=1,o=t[e[0]],s=o.length;a<i;++a)for(n=o,o=t[e[a]],r=0;r<s;++r)o[r][1]+=o[r][0]=isNaN(n[r][1])?n[r][0]:n[r][1]}function jt(t){for(var e=t.length,r=new Array(e);--e>=0;)r[e]=e;return r}function Ut(t,e){return t[e]}function Vt(t){var e=t.map(qt);return jt(t).sort(function(t,r){return e[t]-e[r]})}function qt(t){for(var e,r=-1,n=0,i=t.length,a=-1/0;++r<i;)(e=+t[r][1])>a&&(a=e,n=r);return n}function Ht(t){var e=t.map(Gt);return jt(t).sort(function(t,r){return e[t]-e[r]})}function Gt(t){for(var e,r=0,n=-1,i=t.length;++n<i;)(e=+t[n][1])&&(r+=e);return r}Et.prototype={areaStart:st,areaEnd:st,lineStart:function(){this._point=0},lineEnd:function(){this._point&&this._context.closePath()},point:function(t,e){t=+t,e=+e,this._point?this._context.lineTo(t,e):(this._point=1,this._context.moveTo(t,e))}},zt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=this._t0=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x1,this._y1);break;case 3:Ot(this,this._t0,Pt(this,this._t0))}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){var r=NaN;if(e=+e,(t=+t)!==this._x1||e!==this._y1){switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,Ot(this,Pt(this,r=Lt(this,t,e)),r);break;default:Ot(this,this._t0,r=Lt(this,t,e))}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e,this._t0=r}}},(It.prototype=Object.create(zt.prototype)).point=function(t,e){zt.prototype.point.call(this,e,t)},Dt.prototype={moveTo:function(t,e){this._context.moveTo(e,t)},closePath:function(){this._context.closePath()},lineTo:function(t,e){this._context.lineTo(e,t)},bezierCurveTo:function(t,e,r,n,i,a){this._context.bezierCurveTo(e,t,n,r,a,i)}},Rt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=[],this._y=[]},lineEnd:function(){var t=this._x,e=this._y,r=t.length;if(r)if(this._line?this._context.lineTo(t[0],e[0]):this._context.moveTo(t[0],e[0]),2===r)this._context.lineTo(t[1],e[1]);else for(var n=Ft(t),i=Ft(e),a=0,o=1;o<r;++a,++o)this._context.bezierCurveTo(n[0][a],i[0][a],n[1][a],i[1][a],t[o],e[o]);(this._line||0!==this._line&&1===r)&&this._context.closePath(),this._line=1-this._line,this._x=this._y=null},point:function(t,e){this._x.push(+t),this._y.push(+e)}},Bt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=this._y=NaN,this._point=0},lineEnd:function(){0<this._t&&this._t<1&&2===this._point&&this._context.lineTo(this._x,this._y),(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line>=0&&(this._t=1-this._t,this._line=1-this._line)},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:if(this._t<=0)this._context.lineTo(this._x,e),this._context.lineTo(t,e);else{var r=this._x*(1-this._t)+t*this._t;this._context.lineTo(r,this._y),this._context.lineTo(r,e)}}this._x=t,this._y=e}},t.arc=function(){var t=g,o=v,_=r(0),w=null,k=m,T=y,A=x,M=null;function S(){var r,g,v,m=+t.apply(this,arguments),y=+o.apply(this,arguments),x=k.apply(this,arguments)-f,S=T.apply(this,arguments)-f,E=n(S-x),C=S>x;if(M||(M=r=e.path()),y<m&&(g=y,y=m,m=g),y>u)if(E>p-u)M.moveTo(y*a(x),y*l(x)),M.arc(0,0,y,x,S,!C),m>u&&(M.moveTo(m*a(S),m*l(S)),M.arc(0,0,m,S,x,C));else{var L,P,O=x,z=S,I=x,D=S,R=E,F=E,B=A.apply(this,arguments)/2,N=B>u&&(w?+w.apply(this,arguments):c(m*m+y*y)),j=s(n(y-m)/2,+_.apply(this,arguments)),U=j,V=j;if(N>u){var q=d(N/m*l(B)),H=d(N/y*l(B));(R-=2*q)>u?(I+=q*=C?1:-1,D-=q):(R=0,I=D=(x+S)/2),(F-=2*H)>u?(O+=H*=C?1:-1,z-=H):(F=0,O=z=(x+S)/2)}var G=y*a(O),Y=y*l(O),W=m*a(D),X=m*l(D);if(j>u){var Z,J=y*a(z),K=y*l(z),$=m*a(I),Q=m*l(I);if(E<h&&(Z=function(t,e,r,n,i,a,o,s){var l=r-t,c=n-e,h=o-i,f=s-a,p=f*l-h*c;if(!(p*p<u))return[t+(p=(h*(e-a)-f*(t-i))/p)*l,e+p*c]}(G,Y,$,Q,J,K,W,X))){var tt=G-Z[0],et=Y-Z[1],rt=J-Z[0],nt=K-Z[1],it=1/l(((v=(tt*rt+et*nt)/(c(tt*tt+et*et)*c(rt*rt+nt*nt)))>1?0:v<-1?h:Math.acos(v))/2),at=c(Z[0]*Z[0]+Z[1]*Z[1]);U=s(j,(m-at)/(it-1)),V=s(j,(y-at)/(it+1))}}F>u?V>u?(L=b($,Q,G,Y,y,V,C),P=b(J,K,W,X,y,V,C),M.moveTo(L.cx+L.x01,L.cy+L.y01),V<j?M.arc(L.cx,L.cy,V,i(L.y01,L.x01),i(P.y01,P.x01),!C):(M.arc(L.cx,L.cy,V,i(L.y01,L.x01),i(L.y11,L.x11),!C),M.arc(0,0,y,i(L.cy+L.y11,L.cx+L.x11),i(P.cy+P.y11,P.cx+P.x11),!C),M.arc(P.cx,P.cy,V,i(P.y11,P.x11),i(P.y01,P.x01),!C))):(M.moveTo(G,Y),M.arc(0,0,y,O,z,!C)):M.moveTo(G,Y),m>u&&R>u?U>u?(L=b(W,X,J,K,m,-U,C),P=b(G,Y,$,Q,m,-U,C),M.lineTo(L.cx+L.x01,L.cy+L.y01),U<j?M.arc(L.cx,L.cy,U,i(L.y01,L.x01),i(P.y01,P.x01),!C):(M.arc(L.cx,L.cy,U,i(L.y01,L.x01),i(L.y11,L.x11),!C),M.arc(0,0,m,i(L.cy+L.y11,L.cx+L.x11),i(P.cy+P.y11,P.cx+P.x11),C),M.arc(P.cx,P.cy,U,i(P.y11,P.x11),i(P.y01,P.x01),!C))):M.arc(0,0,m,D,I,C):M.lineTo(W,X)}else M.moveTo(0,0);if(M.closePath(),r)return M=null,r+\"\"||null}return S.centroid=function(){var e=(+t.apply(this,arguments)+ +o.apply(this,arguments))/2,r=(+k.apply(this,arguments)+ +T.apply(this,arguments))/2-h/2;return[a(r)*e,l(r)*e]},S.innerRadius=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),S):t},S.outerRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),S):o},S.cornerRadius=function(t){return arguments.length?(_=\"function\"==typeof t?t:r(+t),S):_},S.padRadius=function(t){return arguments.length?(w=null==t?null:\"function\"==typeof t?t:r(+t),S):w},S.startAngle=function(t){return arguments.length?(k=\"function\"==typeof t?t:r(+t),S):k},S.endAngle=function(t){return arguments.length?(T=\"function\"==typeof t?t:r(+t),S):T},S.padAngle=function(t){return arguments.length?(A=\"function\"==typeof t?t:r(+t),S):A},S.context=function(t){return arguments.length?(M=null==t?null:t,S):M},S},t.area=M,t.line=A,t.pie=function(){var t=E,e=S,n=null,i=r(0),a=r(p),o=r(0);function s(r){var s,l,c,u,h,f=r.length,d=0,g=new Array(f),v=new Array(f),m=+i.apply(this,arguments),y=Math.min(p,Math.max(-p,a.apply(this,arguments)-m)),x=Math.min(Math.abs(y)/f,o.apply(this,arguments)),b=x*(y<0?-1:1);for(s=0;s<f;++s)(h=v[g[s]=s]=+t(r[s],s,r))>0&&(d+=h);for(null!=e?g.sort(function(t,r){return e(v[t],v[r])}):null!=n&&g.sort(function(t,e){return n(r[t],r[e])}),s=0,c=d?(y-f*b)/d:0;s<f;++s,m=u)l=g[s],u=m+((h=v[l])>0?h*c:0)+b,v[l]={data:r[l],index:s,value:h,startAngle:m,endAngle:u,padAngle:x};return v}return s.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),s):t},s.sortValues=function(t){return arguments.length?(e=t,n=null,s):e},s.sort=function(t){return arguments.length?(n=t,e=null,s):n},s.startAngle=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),s):i},s.endAngle=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),s):a},s.padAngle=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),s):o},s},t.areaRadial=I,t.radialArea=I,t.lineRadial=z,t.radialLine=z,t.pointRadial=D,t.linkHorizontal=function(){return N(j)},t.linkVertical=function(){return N(U)},t.linkRadial=function(){var t=N(V);return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t},t.symbol=function(){var t=r(q),n=r(64),i=null;function a(){var r;if(i||(i=r=e.path()),t.apply(this,arguments).draw(i,+n.apply(this,arguments)),r)return i=null,r+\"\"||null}return a.type=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(e),a):t},a.size=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),a):n},a.context=function(t){return arguments.length?(i=null==t?null:t,a):i},a},t.symbols=ot,t.symbolCircle=q,t.symbolCross=H,t.symbolDiamond=W,t.symbolSquare=$,t.symbolStar=K,t.symbolTriangle=tt,t.symbolWye=at,t.curveBasisClosed=function(t){return new ut(t)},t.curveBasisOpen=function(t){return new ht(t)},t.curveBasis=function(t){return new ct(t)},t.curveBundle=pt,t.curveCardinalClosed=yt,t.curveCardinalOpen=bt,t.curveCardinal=vt,t.curveCatmullRomClosed=At,t.curveCatmullRomOpen=St,t.curveCatmullRom=kt,t.curveLinearClosed=function(t){return new Et(t)},t.curveLinear=w,t.curveMonotoneX=function(t){return new zt(t)},t.curveMonotoneY=function(t){return new It(t)},t.curveNatural=function(t){return new Rt(t)},t.curveStep=function(t){return new Bt(t,.5)},t.curveStepAfter=function(t){return new Bt(t,1)},t.curveStepBefore=function(t){return new Bt(t,0)},t.stack=function(){var t=r([]),e=jt,n=Nt,i=Ut;function a(r){var a,o,s=t.apply(this,arguments),l=r.length,c=s.length,u=new Array(c);for(a=0;a<c;++a){for(var h,f=s[a],p=u[a]=new Array(l),d=0;d<l;++d)p[d]=h=[0,+i(r[d],f,d,r)],h.data=r[d];p.key=f}for(a=0,o=e(u);a<c;++a)u[o[a]].index=a;return n(u,o),u}return a.keys=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(R.call(e)),a):t},a.value=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a):i},a.order=function(t){return arguments.length?(e=null==t?jt:\"function\"==typeof t?t:r(R.call(t)),a):e},a.offset=function(t){return arguments.length?(n=null==t?Nt:t,a):n},a},t.stackOffsetExpand=function(t,e){if((n=t.length)>0){for(var r,n,i,a=0,o=t[0].length;a<o;++a){for(i=r=0;r<n;++r)i+=t[r][a][1]||0;if(i)for(r=0;r<n;++r)t[r][a][1]/=i}Nt(t,e)}},t.stackOffsetDiverging=function(t,e){if((s=t.length)>1)for(var r,n,i,a,o,s,l=0,c=t[e[0]].length;l<c;++l)for(a=o=0,r=0;r<s;++r)(i=(n=t[e[r]][l])[1]-n[0])>=0?(n[0]=a,n[1]=a+=i):i<0?(n[1]=o,n[0]=o+=i):n[0]=a},t.stackOffsetNone=Nt,t.stackOffsetSilhouette=function(t,e){if((r=t.length)>0){for(var r,n=0,i=t[e[0]],a=i.length;n<a;++n){for(var o=0,s=0;o<r;++o)s+=t[o][n][1]||0;i[n][1]+=i[n][0]=-s/2}Nt(t,e)}},t.stackOffsetWiggle=function(t,e){if((i=t.length)>0&&(n=(r=t[e[0]]).length)>0){for(var r,n,i,a=0,o=1;o<n;++o){for(var s=0,l=0,c=0;s<i;++s){for(var u=t[e[s]],h=u[o][1]||0,f=(h-(u[o-1][1]||0))/2,p=0;p<s;++p){var d=t[e[p]];f+=(d[o][1]||0)-(d[o-1][1]||0)}l+=h,c+=f*h}r[o-1][1]+=r[o-1][0]=a,l&&(a-=c/l)}r[o-1][1]+=r[o-1][0]=a,Nt(t,e)}},t.stackOrderAppearance=Vt,t.stackOrderAscending=Ht,t.stackOrderDescending=function(t){return Ht(t).reverse()},t.stackOrderInsideOut=function(t){var e,r,n=t.length,i=t.map(Gt),a=Vt(t),o=0,s=0,l=[],c=[];for(e=0;e<n;++e)r=a[e],o<s?(o+=i[r],l.push(r)):(s+=i[r],c.push(r));return c.reverse().concat(l)},t.stackOrderNone=jt,t.stackOrderReverse=function(t){return jt(t).reverse()},Object.defineProperty(t,\"__esModule\",{value:!0})},\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-path\")):i(n.d3=n.d3||{},n.d3)},{\"d3-path\":159}],162:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e,r,n=0,i=0,a=0,o=1e3,s=0,l=0,c=0,u=\"object\"==typeof performance&&performance.now?performance:Date,h=\"object\"==typeof window&&window.requestAnimationFrame?window.requestAnimationFrame.bind(window):function(t){setTimeout(t,17)};function f(){return l||(h(p),l=u.now()+c)}function p(){l=0}function d(){this._call=this._time=this._next=null}function g(t,e,r){var n=new d;return n.restart(t,e,r),n}function v(){f(),++n;for(var t,r=e;r;)(t=l-r._time)>=0&&r._call.call(null,t),r=r._next;--n}function m(){l=(s=u.now())+c,n=i=0;try{v()}finally{n=0,function(){var t,n,i=e,a=1/0;for(;i;)i._call?(a>i._time&&(a=i._time),t=i,i=i._next):(n=i._next,i._next=null,i=t?t._next=n:e=n);r=t,x(a)}(),l=0}}function y(){var t=u.now(),e=t-s;e>o&&(c-=e,s=t)}function x(t){n||(i&&(i=clearTimeout(i)),t-l>24?(t<1/0&&(i=setTimeout(m,t-u.now()-c)),a&&(a=clearInterval(a))):(a||(s=u.now(),a=setInterval(y,o)),n=1,h(m)))}d.prototype=g.prototype={constructor:d,restart:function(t,n,i){if(\"function\"!=typeof t)throw new TypeError(\"callback is not a function\");i=(null==i?f():+i)+(null==n?0:+n),this._next||r===this||(r?r._next=this:e=this,r=this),this._call=t,this._time=i,x()},stop:function(){this._call&&(this._call=null,this._time=1/0,x())}};t.now=f,t.timer=g,t.timerFlush=v,t.timeout=function(t,e,r){var n=new d;return e=null==e?0:+e,n.restart(function(r){n.stop(),t(r+e)},e,r),n},t.interval=function(t,e,r){var n=new d,i=e;return null==e?(n.restart(t,e,r),n):(e=+e,r=null==r?f():+r,n.restart(function a(o){o+=i,n.restart(a,i+=e,r),t(o)},e,r),n)},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.d3=n.d3||{})},{}],163:[function(t,e,r){!function(){var t={version:\"3.5.17\"},r=[].slice,n=function(t){return r.call(t)},i=this.document;function a(t){return t&&(t.ownerDocument||t.document||t).documentElement}function o(t){return t&&(t.ownerDocument&&t.ownerDocument.defaultView||t.document&&t||t.defaultView)}if(i)try{n(i.documentElement.childNodes)[0].nodeType}catch(t){n=function(t){for(var e=t.length,r=new Array(e);e--;)r[e]=t[e];return r}}if(Date.now||(Date.now=function(){return+new Date}),i)try{i.createElement(\"DIV\").style.setProperty(\"opacity\",0,\"\")}catch(t){var s=this.Element.prototype,l=s.setAttribute,c=s.setAttributeNS,u=this.CSSStyleDeclaration.prototype,h=u.setProperty;s.setAttribute=function(t,e){l.call(this,t,e+\"\")},s.setAttributeNS=function(t,e,r){c.call(this,t,e,r+\"\")},u.setProperty=function(t,e,r){h.call(this,t,e+\"\",r)}}function f(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function p(t){return null===t?NaN:+t}function d(t){return!isNaN(t)}function g(t){return{left:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}t.ascending=f,t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.min=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&r>n&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&r>n&&(r=n)}return r},t.max=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&n>r&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&n>r&&(r=n)}return r},t.extent=function(t,e){var r,n,i,a=-1,o=t.length;if(1===arguments.length){for(;++a<o;)if(null!=(n=t[a])&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=t[a])&&(r>n&&(r=n),i<n&&(i=n))}else{for(;++a<o;)if(null!=(n=e.call(t,t[a],a))&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=e.call(t,t[a],a))&&(r>n&&(r=n),i<n&&(i=n))}return[r,i]},t.sum=function(t,e){var r,n=0,i=t.length,a=-1;if(1===arguments.length)for(;++a<i;)d(r=+t[a])&&(n+=r);else for(;++a<i;)d(r=+e.call(t,t[a],a))&&(n+=r);return n},t.mean=function(t,e){var r,n=0,i=t.length,a=-1,o=i;if(1===arguments.length)for(;++a<i;)d(r=p(t[a]))?n+=r:--o;else for(;++a<i;)d(r=p(e.call(t,t[a],a)))?n+=r:--o;if(o)return n/o},t.quantile=function(t,e){var r=(t.length-1)*e+1,n=Math.floor(r),i=+t[n-1],a=r-n;return a?i+a*(t[n]-i):i},t.median=function(e,r){var n,i=[],a=e.length,o=-1;if(1===arguments.length)for(;++o<a;)d(n=p(e[o]))&&i.push(n);else for(;++o<a;)d(n=p(r.call(e,e[o],o)))&&i.push(n);if(i.length)return t.quantile(i.sort(f),.5)},t.variance=function(t,e){var r,n,i=t.length,a=0,o=0,s=-1,l=0;if(1===arguments.length)for(;++s<i;)d(r=p(t[s]))&&(o+=(n=r-a)*(r-(a+=n/++l)));else for(;++s<i;)d(r=p(e.call(t,t[s],s)))&&(o+=(n=r-a)*(r-(a+=n/++l)));if(l>1)return o/(l-1)},t.deviation=function(){var e=t.variance.apply(this,arguments);return e?Math.sqrt(e):e};var v=g(f);function m(t){return t.length}t.bisectLeft=v.left,t.bisect=t.bisectRight=v.right,t.bisector=function(t){return g(1===t.length?function(e,r){return f(t(e),r)}:t)},t.shuffle=function(t,e,r){(a=arguments.length)<3&&(r=t.length,a<2&&(e=0));for(var n,i,a=r-e;a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.pairs=function(t){for(var e=0,r=t.length-1,n=t[0],i=new Array(r<0?0:r);e<r;)i[e]=[n,n=t[++e]];return i},t.transpose=function(e){if(!(a=e.length))return[];for(var r=-1,n=t.min(e,m),i=new Array(n);++r<n;)for(var a,o=-1,s=i[r]=new Array(a);++o<a;)s[o]=e[o][r];return i},t.zip=function(){return t.transpose(arguments)},t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r};var y=Math.abs;function x(t,e){for(var r in e)Object.defineProperty(t.prototype,r,{value:e[r],enumerable:!1})}function b(){this._=Object.create(null)}t.range=function(t,e,r){if(arguments.length<3&&(r=1,arguments.length<2&&(e=t,t=0)),(e-t)/r==1/0)throw new Error(\"infinite range\");var n,i=[],a=function(t){var e=1;for(;t*e%1;)e*=10;return e}(y(r)),o=-1;if(t*=a,e*=a,(r*=a)<0)for(;(n=t+r*++o)>e;)i.push(n/a);else for(;(n=t+r*++o)<e;)i.push(n/a);return i},t.map=function(t,e){var r=new b;if(t instanceof b)t.forEach(function(t,e){r.set(t,e)});else if(Array.isArray(t)){var n,i=-1,a=t.length;if(1===arguments.length)for(;++i<a;)r.set(i,t[i]);else for(;++i<a;)r.set(e.call(t,n=t[i],i),n)}else for(var o in t)r.set(o,t[o]);return r};var _=\"__proto__\",w=\"\\0\";function k(t){return(t+=\"\")===_||t[0]===w?w+t:t}function T(t){return(t+=\"\")[0]===w?t.slice(1):t}function A(t){return k(t)in this._}function M(t){return(t=k(t))in this._&&delete this._[t]}function S(){var t=[];for(var e in this._)t.push(T(e));return t}function E(){var t=0;for(var e in this._)++t;return t}function C(){for(var t in this._)return!1;return!0}function L(){this._=Object.create(null)}function P(t){return t}function O(t,e,r){return function(){var n=r.apply(e,arguments);return n===e?t:n}}function z(t,e){if(e in t)return e;e=e.charAt(0).toUpperCase()+e.slice(1);for(var r=0,n=I.length;r<n;++r){var i=I[r]+e;if(i in t)return i}}x(b,{has:A,get:function(t){return this._[k(t)]},set:function(t,e){return this._[k(t)]=e},remove:M,keys:S,values:function(){var t=[];for(var e in this._)t.push(this._[e]);return t},entries:function(){var t=[];for(var e in this._)t.push({key:T(e),value:this._[e]});return t},size:E,empty:C,forEach:function(t){for(var e in this._)t.call(this,T(e),this._[e])}}),t.nest=function(){var e,r,n={},i=[],a=[];function o(t,a,s){if(s>=i.length)return r?r.call(n,a):e?a.sort(e):a;for(var l,c,u,h,f=-1,p=a.length,d=i[s++],g=new b;++f<p;)(h=g.get(l=d(c=a[f])))?h.push(c):g.set(l,[c]);return t?(c=t(),u=function(e,r){c.set(e,o(t,r,s))}):(c={},u=function(e,r){c[e]=o(t,r,s)}),g.forEach(u),c}return n.map=function(t,e){return o(e,t,0)},n.entries=function(e){return function t(e,r){if(r>=i.length)return e;var n=[],o=a[r++];return e.forEach(function(e,i){n.push({key:e,values:t(i,r)})}),o?n.sort(function(t,e){return o(t.key,e.key)}):n}(o(t.map,e,0),0)},n.key=function(t){return i.push(t),n},n.sortKeys=function(t){return a[i.length-1]=t,n},n.sortValues=function(t){return e=t,n},n.rollup=function(t){return r=t,n},n},t.set=function(t){var e=new L;if(t)for(var r=0,n=t.length;r<n;++r)e.add(t[r]);return e},x(L,{has:A,add:function(t){return this._[k(t+=\"\")]=!0,t},remove:M,values:S,size:E,empty:C,forEach:function(t){for(var e in this._)t.call(this,T(e))}}),t.behavior={},t.rebind=function(t,e){for(var r,n=1,i=arguments.length;++n<i;)t[r=arguments[n]]=O(t,e,e[r]);return t};var I=[\"webkit\",\"ms\",\"moz\",\"Moz\",\"o\",\"O\"];function D(){}function R(){}function F(t){var e=[],r=new b;function n(){for(var r,n=e,i=-1,a=n.length;++i<a;)(r=n[i].on)&&r.apply(this,arguments);return t}return n.on=function(n,i){var a,o=r.get(n);return arguments.length<2?o&&o.on:(o&&(o.on=null,e=e.slice(0,a=e.indexOf(o)).concat(e.slice(a+1)),r.remove(n)),i&&e.push(r.set(n,{on:i})),t)},n}function B(){t.event.preventDefault()}function N(){for(var e,r=t.event;e=r.sourceEvent;)r=e;return r}function j(e){for(var r=new R,n=0,i=arguments.length;++n<i;)r[arguments[n]]=F(r);return r.of=function(n,i){return function(a){try{var o=a.sourceEvent=t.event;a.target=e,t.event=a,r[a.type].apply(n,i)}finally{t.event=o}}},r}t.dispatch=function(){for(var t=new R,e=-1,r=arguments.length;++e<r;)t[arguments[e]]=F(t);return t},R.prototype.on=function(t,e){var r=t.indexOf(\".\"),n=\"\";if(r>=0&&(n=t.slice(r+1),t=t.slice(0,r)),t)return arguments.length<2?this[t].on(n):this[t].on(n,e);if(2===arguments.length){if(null==e)for(t in this)this.hasOwnProperty(t)&&this[t].on(n,null);return this}},t.event=null,t.requote=function(t){return t.replace(U,\"\\\\$&\")};var U=/[\\\\\\^\\$\\*\\+\\?\\|\\[\\]\\(\\)\\.\\{\\}]/g,V={}.__proto__?function(t,e){t.__proto__=e}:function(t,e){for(var r in e)t[r]=e[r]};function q(t){return V(t,W),t}var H=function(t,e){return e.querySelector(t)},G=function(t,e){return e.querySelectorAll(t)},Y=function(t,e){var r=t.matches||t[z(t,\"matchesSelector\")];return(Y=function(t,e){return r.call(t,e)})(t,e)};\"function\"==typeof Sizzle&&(H=function(t,e){return Sizzle(t,e)[0]||null},G=Sizzle,Y=Sizzle.matchesSelector),t.selection=function(){return t.select(i.documentElement)};var W=t.selection.prototype=[];function X(t){return\"function\"==typeof t?t:function(){return H(t,this)}}function Z(t){return\"function\"==typeof t?t:function(){return G(t,this)}}W.select=function(t){var e,r,n,i,a=[];t=X(t);for(var o=-1,s=this.length;++o<s;){a.push(e=[]),e.parentNode=(n=this[o]).parentNode;for(var l=-1,c=n.length;++l<c;)(i=n[l])?(e.push(r=t.call(i,i.__data__,l,o)),r&&\"__data__\"in i&&(r.__data__=i.__data__)):e.push(null)}return q(a)},W.selectAll=function(t){var e,r,i=[];t=Z(t);for(var a=-1,o=this.length;++a<o;)for(var s=this[a],l=-1,c=s.length;++l<c;)(r=s[l])&&(i.push(e=n(t.call(r,r.__data__,l,a))),e.parentNode=r);return q(i)};var J=\"http://www.w3.org/1999/xhtml\",K={svg:\"http://www.w3.org/2000/svg\",xhtml:J,xlink:\"http://www.w3.org/1999/xlink\",xml:\"http://www.w3.org/XML/1998/namespace\",xmlns:\"http://www.w3.org/2000/xmlns/\"};function $(e,r){return e=t.ns.qualify(e),null==r?e.local?function(){this.removeAttributeNS(e.space,e.local)}:function(){this.removeAttribute(e)}:\"function\"==typeof r?e.local?function(){var t=r.apply(this,arguments);null==t?this.removeAttributeNS(e.space,e.local):this.setAttributeNS(e.space,e.local,t)}:function(){var t=r.apply(this,arguments);null==t?this.removeAttribute(e):this.setAttribute(e,t)}:e.local?function(){this.setAttributeNS(e.space,e.local,r)}:function(){this.setAttribute(e,r)}}function Q(t){return t.trim().replace(/\\s+/g,\" \")}function tt(e){return new RegExp(\"(?:^|\\\\s+)\"+t.requote(e)+\"(?:\\\\s+|$)\",\"g\")}function et(t){return(t+\"\").trim().split(/^|\\s+/)}function rt(t,e){var r=(t=et(t).map(nt)).length;return\"function\"==typeof e?function(){for(var n=-1,i=e.apply(this,arguments);++n<r;)t[n](this,i)}:function(){for(var n=-1;++n<r;)t[n](this,e)}}function nt(t){var e=tt(t);return function(r,n){if(i=r.classList)return n?i.add(t):i.remove(t);var i=r.getAttribute(\"class\")||\"\";n?(e.lastIndex=0,e.test(i)||r.setAttribute(\"class\",Q(i+\" \"+t))):r.setAttribute(\"class\",Q(i.replace(e,\" \")))}}function it(t,e,r){return null==e?function(){this.style.removeProperty(t)}:\"function\"==typeof e?function(){var n=e.apply(this,arguments);null==n?this.style.removeProperty(t):this.style.setProperty(t,n,r)}:function(){this.style.setProperty(t,e,r)}}function at(t,e){return null==e?function(){delete this[t]}:\"function\"==typeof e?function(){var r=e.apply(this,arguments);null==r?delete this[t]:this[t]=r}:function(){this[t]=e}}function ot(e){return\"function\"==typeof e?e:(e=t.ns.qualify(e)).local?function(){return this.ownerDocument.createElementNS(e.space,e.local)}:function(){var t=this.ownerDocument,r=this.namespaceURI;return r===J&&t.documentElement.namespaceURI===J?t.createElement(e):t.createElementNS(r,e)}}function st(){var t=this.parentNode;t&&t.removeChild(this)}function lt(t){return{__data__:t}}function ct(t){return function(){return Y(this,t)}}function ut(t,e){for(var r=0,n=t.length;r<n;r++)for(var i,a=t[r],o=0,s=a.length;o<s;o++)(i=a[o])&&e(i,o,r);return t}function ht(t){return V(t,ft),t}t.ns={prefix:K,qualify:function(t){var e=t.indexOf(\":\"),r=t;return e>=0&&\"xmlns\"!==(r=t.slice(0,e))&&(t=t.slice(e+1)),K.hasOwnProperty(r)?{space:K[r],local:t}:t}},W.attr=function(e,r){if(arguments.length<2){if(\"string\"==typeof e){var n=this.node();return(e=t.ns.qualify(e)).local?n.getAttributeNS(e.space,e.local):n.getAttribute(e)}for(r in e)this.each($(r,e[r]));return this}return this.each($(e,r))},W.classed=function(t,e){if(arguments.length<2){if(\"string\"==typeof t){var r=this.node(),n=(t=et(t)).length,i=-1;if(e=r.classList){for(;++i<n;)if(!e.contains(t[i]))return!1}else for(e=r.getAttribute(\"class\");++i<n;)if(!tt(t[i]).test(e))return!1;return!0}for(e in t)this.each(rt(e,t[e]));return this}return this.each(rt(t,e))},W.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.each(it(r,t[r],e));return this}if(n<2){var i=this.node();return o(i).getComputedStyle(i,null).getPropertyValue(t)}r=\"\"}return this.each(it(t,e,r))},W.property=function(t,e){if(arguments.length<2){if(\"string\"==typeof t)return this.node()[t];for(e in t)this.each(at(e,t[e]));return this}return this.each(at(t,e))},W.text=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.textContent=null==e?\"\":e}:null==t?function(){this.textContent=\"\"}:function(){this.textContent=t}):this.node().textContent},W.html=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.innerHTML=null==e?\"\":e}:null==t?function(){this.innerHTML=\"\"}:function(){this.innerHTML=t}):this.node().innerHTML},W.append=function(t){return t=ot(t),this.select(function(){return this.appendChild(t.apply(this,arguments))})},W.insert=function(t,e){return t=ot(t),e=X(e),this.select(function(){return this.insertBefore(t.apply(this,arguments),e.apply(this,arguments)||null)})},W.remove=function(){return this.each(st)},W.data=function(t,e){var r,n,i=-1,a=this.length;if(!arguments.length){for(t=new Array(a=(r=this[0]).length);++i<a;)(n=r[i])&&(t[i]=n.__data__);return t}function o(t,r){var n,i,a,o=t.length,u=r.length,h=Math.min(o,u),f=new Array(u),p=new Array(u),d=new Array(o);if(e){var g,v=new b,m=new Array(o);for(n=-1;++n<o;)(i=t[n])&&(v.has(g=e.call(i,i.__data__,n))?d[n]=i:v.set(g,i),m[n]=g);for(n=-1;++n<u;)(i=v.get(g=e.call(r,a=r[n],n)))?!0!==i&&(f[n]=i,i.__data__=a):p[n]=lt(a),v.set(g,!0);for(n=-1;++n<o;)n in m&&!0!==v.get(m[n])&&(d[n]=t[n])}else{for(n=-1;++n<h;)i=t[n],a=r[n],i?(i.__data__=a,f[n]=i):p[n]=lt(a);for(;n<u;++n)p[n]=lt(r[n]);for(;n<o;++n)d[n]=t[n]}p.update=f,p.parentNode=f.parentNode=d.parentNode=t.parentNode,s.push(p),l.push(f),c.push(d)}var s=ht([]),l=q([]),c=q([]);if(\"function\"==typeof t)for(;++i<a;)o(r=this[i],t.call(r,r.parentNode.__data__,i));else for(;++i<a;)o(r=this[i],t);return l.enter=function(){return s},l.exit=function(){return c},l},W.datum=function(t){return arguments.length?this.property(\"__data__\",t):this.property(\"__data__\")},W.filter=function(t){var e,r,n,i=[];\"function\"!=typeof t&&(t=ct(t));for(var a=0,o=this.length;a<o;a++){i.push(e=[]),e.parentNode=(r=this[a]).parentNode;for(var s=0,l=r.length;s<l;s++)(n=r[s])&&t.call(n,n.__data__,s,a)&&e.push(n)}return q(i)},W.order=function(){for(var t=-1,e=this.length;++t<e;)for(var r,n=this[t],i=n.length-1,a=n[i];--i>=0;)(r=n[i])&&(a&&a!==r.nextSibling&&a.parentNode.insertBefore(r,a),a=r);return this},W.sort=function(t){t=function(t){arguments.length||(t=f);return function(e,r){return e&&r?t(e.__data__,r.__data__):!e-!r}}.apply(this,arguments);for(var e=-1,r=this.length;++e<r;)this[e].sort(t);return this.order()},W.each=function(t){return ut(this,function(e,r,n){t.call(e,e.__data__,r,n)})},W.call=function(t){var e=n(arguments);return t.apply(e[0]=this,e),this},W.empty=function(){return!this.node()},W.node=function(){for(var t=0,e=this.length;t<e;t++)for(var r=this[t],n=0,i=r.length;n<i;n++){var a=r[n];if(a)return a}return null},W.size=function(){var t=0;return ut(this,function(){++t}),t};var ft=[];function pt(e,r,i){var a=\"__on\"+e,o=e.indexOf(\".\"),s=gt;o>0&&(e=e.slice(0,o));var l=dt.get(e);function c(){var t=this[a];t&&(this.removeEventListener(e,t,t.$),delete this[a])}return l&&(e=l,s=vt),o?r?function(){var t=s(r,n(arguments));c.call(this),this.addEventListener(e,this[a]=t,t.$=i),t._=r}:c:r?D:function(){var r,n=new RegExp(\"^__on([^.]+)\"+t.requote(e)+\"$\");for(var i in this)if(r=i.match(n)){var a=this[i];this.removeEventListener(r[1],a,a.$),delete this[i]}}}t.selection.enter=ht,t.selection.enter.prototype=ft,ft.append=W.append,ft.empty=W.empty,ft.node=W.node,ft.call=W.call,ft.size=W.size,ft.select=function(t){for(var e,r,n,i,a,o=[],s=-1,l=this.length;++s<l;){n=(i=this[s]).update,o.push(e=[]),e.parentNode=i.parentNode;for(var c=-1,u=i.length;++c<u;)(a=i[c])?(e.push(n[c]=r=t.call(i.parentNode,a.__data__,c,s)),r.__data__=a.__data__):e.push(null)}return q(o)},ft.insert=function(t,e){var r,n,i;return arguments.length<2&&(r=this,e=function(t,e,a){var o,s=r[a].update,l=s.length;for(a!=i&&(i=a,n=0),e>=n&&(n=e+1);!(o=s[n])&&++n<l;);return o}),W.insert.call(this,t,e)},t.select=function(t){var e;return\"string\"==typeof t?(e=[H(t,i)]).parentNode=i.documentElement:(e=[t]).parentNode=a(t),q([e])},t.selectAll=function(t){var e;return\"string\"==typeof t?(e=n(G(t,i))).parentNode=i.documentElement:(e=n(t)).parentNode=null,q([e])},W.on=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=!1),t)this.each(pt(r,t[r],e));return this}if(n<2)return(n=this.node()[\"__on\"+t])&&n._;r=!1}return this.each(pt(t,e,r))};var dt=t.map({mouseenter:\"mouseover\",mouseleave:\"mouseout\"});function gt(e,r){return function(n){var i=t.event;t.event=n,r[0]=this.__data__;try{e.apply(this,r)}finally{t.event=i}}}function vt(t,e){var r=gt(t,e);return function(t){var e=t.relatedTarget;e&&(e===this||8&e.compareDocumentPosition(this))||r.call(this,t)}}i&&dt.forEach(function(t){\"on\"+t in i&&dt.remove(t)});var mt,yt=0;function xt(e){var r=\".dragsuppress-\"+ ++yt,n=\"click\"+r,i=t.select(o(e)).on(\"touchmove\"+r,B).on(\"dragstart\"+r,B).on(\"selectstart\"+r,B);if(null==mt&&(mt=!(\"onselectstart\"in e)&&z(e.style,\"userSelect\")),mt){var s=a(e).style,l=s[mt];s[mt]=\"none\"}return function(t){if(i.on(r,null),mt&&(s[mt]=l),t){var e=function(){i.on(n,null)};i.on(n,function(){B(),e()},!0),setTimeout(e,0)}}}t.mouse=function(t){return _t(t,N())};var bt=this.navigator&&/WebKit/.test(this.navigator.userAgent)?-1:0;function _t(e,r){r.changedTouches&&(r=r.changedTouches[0]);var n=e.ownerSVGElement||e;if(n.createSVGPoint){var i=n.createSVGPoint();if(bt<0){var a=o(e);if(a.scrollX||a.scrollY){var s=(n=t.select(\"body\").append(\"svg\").style({position:\"absolute\",top:0,left:0,margin:0,padding:0,border:\"none\"},\"important\"))[0][0].getScreenCTM();bt=!(s.f||s.e),n.remove()}}return bt?(i.x=r.pageX,i.y=r.pageY):(i.x=r.clientX,i.y=r.clientY),[(i=i.matrixTransform(e.getScreenCTM().inverse())).x,i.y]}var l=e.getBoundingClientRect();return[r.clientX-l.left-e.clientLeft,r.clientY-l.top-e.clientTop]}function wt(){return t.event.changedTouches[0].identifier}t.touch=function(t,e,r){if(arguments.length<3&&(r=e,e=N().changedTouches),e)for(var n,i=0,a=e.length;i<a;++i)if((n=e[i]).identifier===r)return _t(t,n)},t.behavior.drag=function(){var e=j(a,\"drag\",\"dragstart\",\"dragend\"),r=null,n=s(D,t.mouse,o,\"mousemove\",\"mouseup\"),i=s(wt,t.touch,P,\"touchmove\",\"touchend\");function a(){this.on(\"mousedown.drag\",n).on(\"touchstart.drag\",i)}function s(n,i,a,o,s){return function(){var l,c=t.event.target.correspondingElement||t.event.target,u=this.parentNode,h=e.of(this,arguments),f=0,p=n(),d=\".drag\"+(null==p?\"\":\"-\"+p),g=t.select(a(c)).on(o+d,function(){var t,e,r=i(u,p);if(!r)return;t=r[0]-m[0],e=r[1]-m[1],f|=t|e,m=r,h({type:\"drag\",x:r[0]+l[0],y:r[1]+l[1],dx:t,dy:e})}).on(s+d,function(){if(!i(u,p))return;g.on(o+d,null).on(s+d,null),v(f),h({type:\"dragend\"})}),v=xt(c),m=i(u,p);l=r?[(l=r.apply(this,arguments)).x-m[0],l.y-m[1]]:[0,0],h({type:\"dragstart\"})}}return a.origin=function(t){return arguments.length?(r=t,a):r},t.rebind(a,e,\"on\")},t.touches=function(t,e){return arguments.length<2&&(e=N().touches),e?n(e).map(function(e){var r=_t(t,e);return r.identifier=e.identifier,r}):[]};var kt=1e-6,Tt=kt*kt,At=Math.PI,Mt=2*At,St=Mt-kt,Et=At/2,Ct=At/180,Lt=180/At;function Pt(t){return t>0?1:t<0?-1:0}function Ot(t,e,r){return(e[0]-t[0])*(r[1]-t[1])-(e[1]-t[1])*(r[0]-t[0])}function zt(t){return t>1?0:t<-1?At:Math.acos(t)}function It(t){return t>1?Et:t<-1?-Et:Math.asin(t)}function Dt(t){return((t=Math.exp(t))+1/t)/2}function Rt(t){return(t=Math.sin(t/2))*t}var Ft=Math.SQRT2;t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,h=l-a,f=u*u+h*h;if(f<Tt)n=Math.log(c/o)/Ft,r=function(t){return[i+t*u,a+t*h,o*Math.exp(Ft*t*n)]};else{var p=Math.sqrt(f),d=(c*c-o*o+4*f)/(2*o*2*p),g=(c*c-o*o-4*f)/(2*c*2*p),v=Math.log(Math.sqrt(d*d+1)-d),m=Math.log(Math.sqrt(g*g+1)-g);n=(m-v)/Ft,r=function(t){var e,r=t*n,s=Dt(v),l=o/(2*p)*(s*(e=Ft*r+v,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(v));return[i+l*u,a+l*h,o*s/Dt(Ft*r+v)]}}return r.duration=1e3*n,r},t.behavior.zoom=function(){var e,r,n,a,s,l,c,u,h,f={x:0,y:0,k:1},p=[960,500],d=jt,g=250,v=0,m=\"mousedown.zoom\",y=\"mousemove.zoom\",x=\"mouseup.zoom\",b=\"touchstart.zoom\",_=j(w,\"zoomstart\",\"zoom\",\"zoomend\");function w(t){t.on(m,P).on(Nt+\".zoom\",z).on(\"dblclick.zoom\",I).on(b,O)}function k(t){return[(t[0]-f.x)/f.k,(t[1]-f.y)/f.k]}function T(t){f.k=Math.max(d[0],Math.min(d[1],t))}function A(t,e){e=function(t){return[t[0]*f.k+f.x,t[1]*f.k+f.y]}(e),f.x+=t[0]-e[0],f.y+=t[1]-e[1]}function M(e,n,i,a){e.__chart__={x:f.x,y:f.y,k:f.k},T(Math.pow(2,a)),A(r=n,i),e=t.select(e),g>0&&(e=e.transition().duration(g)),e.call(w.event)}function S(){c&&c.domain(l.range().map(function(t){return(t-f.x)/f.k}).map(l.invert)),h&&h.domain(u.range().map(function(t){return(t-f.y)/f.k}).map(u.invert))}function E(t){v++||t({type:\"zoomstart\"})}function C(t){S(),t({type:\"zoom\",scale:f.k,translate:[f.x,f.y]})}function L(t){--v||(t({type:\"zoomend\"}),r=null)}function P(){var e=this,r=_.of(e,arguments),n=0,i=t.select(o(e)).on(y,function(){n=1,A(t.mouse(e),a),C(r)}).on(x,function(){i.on(y,null).on(x,null),s(n),L(r)}),a=k(t.mouse(e)),s=xt(e);hs.call(e),E(r)}function O(){var e,r=this,n=_.of(r,arguments),i={},a=0,o=\".zoom-\"+t.event.changedTouches[0].identifier,l=\"touchmove\"+o,c=\"touchend\"+o,u=[],h=t.select(r),p=xt(r);function d(){var n=t.touches(r);return e=f.k,n.forEach(function(t){t.identifier in i&&(i[t.identifier]=k(t))}),n}function g(){var e=t.event.target;t.select(e).on(l,v).on(c,y),u.push(e);for(var n=t.event.changedTouches,o=0,h=n.length;o<h;++o)i[n[o].identifier]=null;var p=d(),g=Date.now();if(1===p.length){if(g-s<500){var m=p[0];M(r,m,i[m.identifier],Math.floor(Math.log(f.k)/Math.LN2)+1),B()}s=g}else if(p.length>1){m=p[0];var x=p[1],b=m[0]-x[0],_=m[1]-x[1];a=b*b+_*_}}function v(){var o,l,c,u,h=t.touches(r);hs.call(r);for(var f=0,p=h.length;f<p;++f,u=null)if(c=h[f],u=i[c.identifier]){if(l)break;o=c,l=u}if(u){var d=(d=c[0]-o[0])*d+(d=c[1]-o[1])*d,g=a&&Math.sqrt(d/a);o=[(o[0]+c[0])/2,(o[1]+c[1])/2],l=[(l[0]+u[0])/2,(l[1]+u[1])/2],T(g*e)}s=null,A(o,l),C(n)}function y(){if(t.event.touches.length){for(var e=t.event.changedTouches,r=0,a=e.length;r<a;++r)delete i[e[r].identifier];for(var s in i)return void d()}t.selectAll(u).on(o,null),h.on(m,P).on(b,O),p(),L(n)}g(),E(n),h.on(m,null).on(b,g)}function z(){var i=_.of(this,arguments);a?clearTimeout(a):(hs.call(this),e=k(r=n||t.mouse(this)),E(i)),a=setTimeout(function(){a=null,L(i)},50),B(),T(Math.pow(2,.002*Bt())*f.k),A(r,e),C(i)}function I(){var e=t.mouse(this),r=Math.log(f.k)/Math.LN2;M(this,e,k(e),t.event.shiftKey?Math.ceil(r)-1:Math.floor(r)+1)}return Nt||(Nt=\"onwheel\"in i?(Bt=function(){return-t.event.deltaY*(t.event.deltaMode?120:1)},\"wheel\"):\"onmousewheel\"in i?(Bt=function(){return t.event.wheelDelta},\"mousewheel\"):(Bt=function(){return-t.event.detail},\"MozMousePixelScroll\")),w.event=function(e){e.each(function(){var e=_.of(this,arguments),n=f;ds?t.select(this).transition().each(\"start.zoom\",function(){f=this.__chart__||{x:0,y:0,k:1},E(e)}).tween(\"zoom:zoom\",function(){var i=p[0],a=p[1],o=r?r[0]:i/2,s=r?r[1]:a/2,l=t.interpolateZoom([(o-f.x)/f.k,(s-f.y)/f.k,i/f.k],[(o-n.x)/n.k,(s-n.y)/n.k,i/n.k]);return function(t){var r=l(t),n=i/r[2];this.__chart__=f={x:o-r[0]*n,y:s-r[1]*n,k:n},C(e)}}).each(\"interrupt.zoom\",function(){L(e)}).each(\"end.zoom\",function(){L(e)}):(this.__chart__=f,E(e),C(e),L(e))})},w.translate=function(t){return arguments.length?(f={x:+t[0],y:+t[1],k:f.k},S(),w):[f.x,f.y]},w.scale=function(t){return arguments.length?(f={x:f.x,y:f.y,k:null},T(+t),S(),w):f.k},w.scaleExtent=function(t){return arguments.length?(d=null==t?jt:[+t[0],+t[1]],w):d},w.center=function(t){return arguments.length?(n=t&&[+t[0],+t[1]],w):n},w.size=function(t){return arguments.length?(p=t&&[+t[0],+t[1]],w):p},w.duration=function(t){return arguments.length?(g=+t,w):g},w.x=function(t){return arguments.length?(c=t,l=t.copy(),f={x:0,y:0,k:1},w):c},w.y=function(t){return arguments.length?(h=t,u=t.copy(),f={x:0,y:0,k:1},w):h},t.rebind(w,_,\"on\")};var Bt,Nt,jt=[0,1/0];function Ut(){}function Vt(t,e,r){return this instanceof Vt?(this.h=+t,this.s=+e,void(this.l=+r)):arguments.length<2?t instanceof Vt?new Vt(t.h,t.s,t.l):ue(\"\"+t,he,Vt):new Vt(t,e,r)}t.color=Ut,Ut.prototype.toString=function(){return this.rgb()+\"\"},t.hsl=Vt;var qt=Vt.prototype=new Ut;function Ht(t,e,r){var n,i;function a(t){return Math.round(255*function(t){return t>360?t-=360:t<0&&(t+=360),t<60?n+(i-n)*t/60:t<180?i:t<240?n+(i-n)*(240-t)/60:n}(t))}return t=isNaN(t)?0:(t%=360)<0?t+360:t,e=isNaN(e)?0:e<0?0:e>1?1:e,n=2*(r=r<0?0:r>1?1:r)-(i=r<=.5?r*(1+e):r+e-r*e),new ae(a(t+120),a(t),a(t-120))}function Gt(e,r,n){return this instanceof Gt?(this.h=+e,this.c=+r,void(this.l=+n)):arguments.length<2?e instanceof Gt?new Gt(e.h,e.c,e.l):ee(e instanceof Xt?e.l:(e=fe((e=t.rgb(e)).r,e.g,e.b)).l,e.a,e.b):new Gt(e,r,n)}qt.brighter=function(t){return t=Math.pow(.7,arguments.length?t:1),new Vt(this.h,this.s,this.l/t)},qt.darker=function(t){return t=Math.pow(.7,arguments.length?t:1),new Vt(this.h,this.s,t*this.l)},qt.rgb=function(){return Ht(this.h,this.s,this.l)},t.hcl=Gt;var Yt=Gt.prototype=new Ut;function Wt(t,e,r){return isNaN(t)&&(t=0),isNaN(e)&&(e=0),new Xt(r,Math.cos(t*=Ct)*e,Math.sin(t)*e)}function Xt(t,e,r){return this instanceof Xt?(this.l=+t,this.a=+e,void(this.b=+r)):arguments.length<2?t instanceof Xt?new Xt(t.l,t.a,t.b):t instanceof Gt?Wt(t.h,t.c,t.l):fe((t=ae(t)).r,t.g,t.b):new Xt(t,e,r)}Yt.brighter=function(t){return new Gt(this.h,this.c,Math.min(100,this.l+Zt*(arguments.length?t:1)))},Yt.darker=function(t){return new Gt(this.h,this.c,Math.max(0,this.l-Zt*(arguments.length?t:1)))},Yt.rgb=function(){return Wt(this.h,this.c,this.l).rgb()},t.lab=Xt;var Zt=18,Jt=.95047,Kt=1,$t=1.08883,Qt=Xt.prototype=new Ut;function te(t,e,r){var n=(t+16)/116,i=n+e/500,a=n-r/200;return new ae(ie(3.2404542*(i=re(i)*Jt)-1.5371385*(n=re(n)*Kt)-.4985314*(a=re(a)*$t)),ie(-.969266*i+1.8760108*n+.041556*a),ie(.0556434*i-.2040259*n+1.0572252*a))}function ee(t,e,r){return t>0?new Gt(Math.atan2(r,e)*Lt,Math.sqrt(e*e+r*r),t):new Gt(NaN,NaN,t)}function re(t){return t>.206893034?t*t*t:(t-4/29)/7.787037}function ne(t){return t>.008856?Math.pow(t,1/3):7.787037*t+4/29}function ie(t){return Math.round(255*(t<=.00304?12.92*t:1.055*Math.pow(t,1/2.4)-.055))}function ae(t,e,r){return this instanceof ae?(this.r=~~t,this.g=~~e,void(this.b=~~r)):arguments.length<2?t instanceof ae?new ae(t.r,t.g,t.b):ue(\"\"+t,ae,Ht):new ae(t,e,r)}function oe(t){return new ae(t>>16,t>>8&255,255&t)}function se(t){return oe(t)+\"\"}Qt.brighter=function(t){return new Xt(Math.min(100,this.l+Zt*(arguments.length?t:1)),this.a,this.b)},Qt.darker=function(t){return new Xt(Math.max(0,this.l-Zt*(arguments.length?t:1)),this.a,this.b)},Qt.rgb=function(){return te(this.l,this.a,this.b)},t.rgb=ae;var le=ae.prototype=new Ut;function ce(t){return t<16?\"0\"+Math.max(0,t).toString(16):Math.min(255,t).toString(16)}function ue(t,e,r){var n,i,a,o=0,s=0,l=0;if(n=/([a-z]+)\\((.*)\\)/.exec(t=t.toLowerCase()))switch(i=n[2].split(\",\"),n[1]){case\"hsl\":return r(parseFloat(i[0]),parseFloat(i[1])/100,parseFloat(i[2])/100);case\"rgb\":return e(de(i[0]),de(i[1]),de(i[2]))}return(a=ge.get(t))?e(a.r,a.g,a.b):(null==t||\"#\"!==t.charAt(0)||isNaN(a=parseInt(t.slice(1),16))||(4===t.length?(o=(3840&a)>>4,o|=o>>4,s=240&a,s|=s>>4,l=15&a,l|=l<<4):7===t.length&&(o=(16711680&a)>>16,s=(65280&a)>>8,l=255&a)),e(o,s,l))}function he(t,e,r){var n,i,a=Math.min(t/=255,e/=255,r/=255),o=Math.max(t,e,r),s=o-a,l=(o+a)/2;return s?(i=l<.5?s/(o+a):s/(2-o-a),n=t==o?(e-r)/s+(e<r?6:0):e==o?(r-t)/s+2:(t-e)/s+4,n*=60):(n=NaN,i=l>0&&l<1?0:n),new Vt(n,i,l)}function fe(t,e,r){var n=ne((.4124564*(t=pe(t))+.3575761*(e=pe(e))+.1804375*(r=pe(r)))/Jt),i=ne((.2126729*t+.7151522*e+.072175*r)/Kt);return Xt(116*i-16,500*(n-i),200*(i-ne((.0193339*t+.119192*e+.9503041*r)/$t)))}function pe(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function de(t){var e=parseFloat(t);return\"%\"===t.charAt(t.length-1)?Math.round(2.55*e):e}le.brighter=function(t){t=Math.pow(.7,arguments.length?t:1);var e=this.r,r=this.g,n=this.b,i=30;return e||r||n?(e&&e<i&&(e=i),r&&r<i&&(r=i),n&&n<i&&(n=i),new ae(Math.min(255,e/t),Math.min(255,r/t),Math.min(255,n/t))):new ae(i,i,i)},le.darker=function(t){return new ae((t=Math.pow(.7,arguments.length?t:1))*this.r,t*this.g,t*this.b)},le.hsl=function(){return he(this.r,this.g,this.b)},le.toString=function(){return\"#\"+ce(this.r)+ce(this.g)+ce(this.b)};var ge=t.map({aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074});function ve(t){return\"function\"==typeof t?t:function(){return t}}function me(t){return function(e,r,n){return 2===arguments.length&&\"function\"==typeof r&&(n=r,r=null),ye(e,r,t,n)}}function ye(e,r,i,a){var o={},s=t.dispatch(\"beforesend\",\"progress\",\"load\",\"error\"),l={},c=new XMLHttpRequest,u=null;function h(){var t,e=c.status;if(!e&&function(t){var e=t.responseType;return e&&\"text\"!==e?t.response:t.responseText}(c)||e>=200&&e<300||304===e){try{t=i.call(o,c)}catch(t){return void s.error.call(o,t)}s.load.call(o,t)}else s.error.call(o,c)}return!this.XDomainRequest||\"withCredentials\"in c||!/^(http(s)?:)?\\/\\//.test(e)||(c=new XDomainRequest),\"onload\"in c?c.onload=c.onerror=h:c.onreadystatechange=function(){c.readyState>3&&h()},c.onprogress=function(e){var r=t.event;t.event=e;try{s.progress.call(o,c)}finally{t.event=r}},o.header=function(t,e){return t=(t+\"\").toLowerCase(),arguments.length<2?l[t]:(null==e?delete l[t]:l[t]=e+\"\",o)},o.mimeType=function(t){return arguments.length?(r=null==t?null:t+\"\",o):r},o.responseType=function(t){return arguments.length?(u=t,o):u},o.response=function(t){return i=t,o},[\"get\",\"post\"].forEach(function(t){o[t]=function(){return o.send.apply(o,[t].concat(n(arguments)))}}),o.send=function(t,n,i){if(2===arguments.length&&\"function\"==typeof n&&(i=n,n=null),c.open(t,e,!0),null==r||\"accept\"in l||(l.accept=r+\",*/*\"),c.setRequestHeader)for(var a in l)c.setRequestHeader(a,l[a]);return null!=r&&c.overrideMimeType&&c.overrideMimeType(r),null!=u&&(c.responseType=u),null!=i&&o.on(\"error\",i).on(\"load\",function(t){i(null,t)}),s.beforesend.call(o,c),c.send(null==n?null:n),o},o.abort=function(){return c.abort(),o},t.rebind(o,s,\"on\"),null==a?o:o.get(function(t){return 1===t.length?function(e,r){t(null==e?r:null)}:t}(a))}ge.forEach(function(t,e){ge.set(t,oe(e))}),t.functor=ve,t.xhr=me(P),t.dsv=function(t,e){var r=new RegExp('[\"'+t+\"\\n]\"),n=t.charCodeAt(0);function i(t,r,n){arguments.length<3&&(n=r,r=null);var i=ye(t,e,null==r?a:o(r),n);return i.row=function(t){return arguments.length?i.response(null==(r=t)?a:o(t)):r},i}function a(t){return i.parse(t.responseText)}function o(t){return function(e){return i.parse(e.responseText,t)}}function s(e){return e.map(l).join(t)}function l(t){return r.test(t)?'\"'+t.replace(/\\\"/g,'\"\"')+'\"':t}return i.parse=function(t,e){var r;return i.parseRows(t,function(t,n){if(r)return r(t,n-1);var i=new Function(\"d\",\"return {\"+t.map(function(t,e){return JSON.stringify(t)+\": d[\"+e+\"]\"}).join(\",\")+\"}\");r=e?function(t,r){return e(i(t),r)}:i})},i.parseRows=function(t,e){var r,i,a={},o={},s=[],l=t.length,c=0,u=0;function h(){if(c>=l)return o;if(i)return i=!1,a;var e=c;if(34===t.charCodeAt(e)){for(var r=e;r++<l;)if(34===t.charCodeAt(r)){if(34!==t.charCodeAt(r+1))break;++r}return c=r+2,13===(s=t.charCodeAt(r+1))?(i=!0,10===t.charCodeAt(r+2)&&++c):10===s&&(i=!0),t.slice(e+1,r).replace(/\"\"/g,'\"')}for(;c<l;){var s,u=1;if(10===(s=t.charCodeAt(c++)))i=!0;else if(13===s)i=!0,10===t.charCodeAt(c)&&(++c,++u);else if(s!==n)continue;return t.slice(e,c-u)}return t.slice(e)}for(;(r=h())!==o;){for(var f=[];r!==a&&r!==o;)f.push(r),r=h();e&&null==(f=e(f,u++))||s.push(f)}return s},i.format=function(e){if(Array.isArray(e[0]))return i.formatRows(e);var r=new L,n=[];return e.forEach(function(t){for(var e in t)r.has(e)||n.push(r.add(e))}),[n.map(l).join(t)].concat(e.map(function(e){return n.map(function(t){return l(e[t])}).join(t)})).join(\"\\n\")},i.formatRows=function(t){return t.map(s).join(\"\\n\")},i},t.csv=t.dsv(\",\",\"text/csv\"),t.tsv=t.dsv(\"\\t\",\"text/tab-separated-values\");var xe,be,_e,we,ke=this[z(this,\"requestAnimationFrame\")]||function(t){setTimeout(t,17)};function Te(t,e,r){var n=arguments.length;n<2&&(e=0),n<3&&(r=Date.now());var i={c:t,t:r+e,n:null};return be?be.n=i:xe=i,be=i,_e||(we=clearTimeout(we),_e=1,ke(Ae)),i}function Ae(){var t=Me(),e=Se()-t;e>24?(isFinite(e)&&(clearTimeout(we),we=setTimeout(Ae,e)),_e=0):(_e=1,ke(Ae))}function Me(){for(var t=Date.now(),e=xe;e;)t>=e.t&&e.c(t-e.t)&&(e.c=null),e=e.n;return t}function Se(){for(var t,e=xe,r=1/0;e;)e.c?(e.t<r&&(r=e.t),e=(t=e).n):e=t?t.n=e.n:xe=e.n;return be=t,r}function Ee(t,e){return e-(t?Math.ceil(Math.log(t)/Math.LN10):1)}t.timer=function(){Te.apply(this,arguments)},t.timer.flush=function(){Me(),Se()},t.round=function(t,e){return e?Math.round(t*(e=Math.pow(10,e)))/e:Math.round(t)};var Ce=[\"y\",\"z\",\"a\",\"f\",\"p\",\"n\",\"\\xb5\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\",\"P\",\"E\",\"Z\",\"Y\"].map(function(t,e){var r=Math.pow(10,3*y(8-e));return{scale:e>8?function(t){return t/r}:function(t){return t*r},symbol:t}});t.formatPrefix=function(e,r){var n=0;return(e=+e)&&(e<0&&(e*=-1),r&&(e=t.round(e,Ee(e,r))),n=1+Math.floor(1e-12+Math.log(e)/Math.LN10),n=Math.max(-24,Math.min(24,3*Math.floor((n-1)/3)))),Ce[8+n/3]};var Le=/(?:([^{])?([<>=^]))?([+\\- ])?([$#])?(0)?(\\d+)?(,)?(\\.-?\\d+)?([a-z%])?/i,Pe=t.map({b:function(t){return t.toString(2)},c:function(t){return String.fromCharCode(t)},o:function(t){return t.toString(8)},x:function(t){return t.toString(16)},X:function(t){return t.toString(16).toUpperCase()},g:function(t,e){return t.toPrecision(e)},e:function(t,e){return t.toExponential(e)},f:function(t,e){return t.toFixed(e)},r:function(e,r){return(e=t.round(e,Ee(e,r))).toFixed(Math.max(0,Math.min(20,Ee(e*(1+1e-15),r))))}});function Oe(t){return t+\"\"}var ze=t.time={},Ie=Date;function De(){this._=new Date(arguments.length>1?Date.UTC.apply(this,arguments):arguments[0])}De.prototype={getDate:function(){return this._.getUTCDate()},getDay:function(){return this._.getUTCDay()},getFullYear:function(){return this._.getUTCFullYear()},getHours:function(){return this._.getUTCHours()},getMilliseconds:function(){return this._.getUTCMilliseconds()},getMinutes:function(){return this._.getUTCMinutes()},getMonth:function(){return this._.getUTCMonth()},getSeconds:function(){return this._.getUTCSeconds()},getTime:function(){return this._.getTime()},getTimezoneOffset:function(){return 0},valueOf:function(){return this._.valueOf()},setDate:function(){Re.setUTCDate.apply(this._,arguments)},setDay:function(){Re.setUTCDay.apply(this._,arguments)},setFullYear:function(){Re.setUTCFullYear.apply(this._,arguments)},setHours:function(){Re.setUTCHours.apply(this._,arguments)},setMilliseconds:function(){Re.setUTCMilliseconds.apply(this._,arguments)},setMinutes:function(){Re.setUTCMinutes.apply(this._,arguments)},setMonth:function(){Re.setUTCMonth.apply(this._,arguments)},setSeconds:function(){Re.setUTCSeconds.apply(this._,arguments)},setTime:function(){Re.setTime.apply(this._,arguments)}};var Re=Date.prototype;function Fe(t,e,r){function n(e){var r=t(e),n=a(r,1);return e-r<n-e?r:n}function i(r){return e(r=t(new Ie(r-1)),1),r}function a(t,r){return e(t=new Ie(+t),r),t}function o(t,n,a){var o=i(t),s=[];if(a>1)for(;o<n;)r(o)%a||s.push(new Date(+o)),e(o,1);else for(;o<n;)s.push(new Date(+o)),e(o,1);return s}t.floor=t,t.round=n,t.ceil=i,t.offset=a,t.range=o;var s=t.utc=Be(t);return s.floor=s,s.round=Be(n),s.ceil=Be(i),s.offset=Be(a),s.range=function(t,e,r){try{Ie=De;var n=new De;return n._=t,o(n,e,r)}finally{Ie=Date}},t}function Be(t){return function(e,r){try{Ie=De;var n=new De;return n._=e,t(n,r)._}finally{Ie=Date}}}ze.year=Fe(function(t){return(t=ze.day(t)).setMonth(0,1),t},function(t,e){t.setFullYear(t.getFullYear()+e)},function(t){return t.getFullYear()}),ze.years=ze.year.range,ze.years.utc=ze.year.utc.range,ze.day=Fe(function(t){var e=new Ie(2e3,0);return e.setFullYear(t.getFullYear(),t.getMonth(),t.getDate()),e},function(t,e){t.setDate(t.getDate()+e)},function(t){return t.getDate()-1}),ze.days=ze.day.range,ze.days.utc=ze.day.utc.range,ze.dayOfYear=function(t){var e=ze.year(t);return Math.floor((t-e-6e4*(t.getTimezoneOffset()-e.getTimezoneOffset()))/864e5)},[\"sunday\",\"monday\",\"tuesday\",\"wednesday\",\"thursday\",\"friday\",\"saturday\"].forEach(function(t,e){e=7-e;var r=ze[t]=Fe(function(t){return(t=ze.day(t)).setDate(t.getDate()-(t.getDay()+e)%7),t},function(t,e){t.setDate(t.getDate()+7*Math.floor(e))},function(t){var r=ze.year(t).getDay();return Math.floor((ze.dayOfYear(t)+(r+e)%7)/7)-(r!==e)});ze[t+\"s\"]=r.range,ze[t+\"s\"].utc=r.utc.range,ze[t+\"OfYear\"]=function(t){var r=ze.year(t).getDay();return Math.floor((ze.dayOfYear(t)+(r+e)%7)/7)}}),ze.week=ze.sunday,ze.weeks=ze.sunday.range,ze.weeks.utc=ze.sunday.utc.range,ze.weekOfYear=ze.sundayOfYear;var Ne={\"-\":\"\",_:\" \",0:\"0\"},je=/^\\s*\\d+/,Ue=/^%/;function Ve(t,e,r){var n=t<0?\"-\":\"\",i=(n?-t:t)+\"\",a=i.length;return n+(a<r?new Array(r-a+1).join(e)+i:i)}function qe(e){return new RegExp(\"^(?:\"+e.map(t.requote).join(\"|\")+\")\",\"i\")}function He(t){for(var e=new b,r=-1,n=t.length;++r<n;)e.set(t[r].toLowerCase(),r);return e}function Ge(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+1));return n?(t.w=+n[0],r+n[0].length):-1}function Ye(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.U=+n[0],r+n[0].length):-1}function We(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.W=+n[0],r+n[0].length):-1}function Xe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+4));return n?(t.y=+n[0],r+n[0].length):-1}function Ze(t,e,r){je.lastIndex=0;var n,i=je.exec(e.slice(r,r+2));return i?(t.y=(n=+i[0])+(n>68?1900:2e3),r+i[0].length):-1}function Je(t,e,r){return/^[+-]\\d{4}$/.test(e=e.slice(r,r+5))?(t.Z=-e,r+5):-1}function Ke(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.m=n[0]-1,r+n[0].length):-1}function $e(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.d=+n[0],r+n[0].length):-1}function Qe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.j=+n[0],r+n[0].length):-1}function tr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.H=+n[0],r+n[0].length):-1}function er(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.M=+n[0],r+n[0].length):-1}function rr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.S=+n[0],r+n[0].length):-1}function nr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.L=+n[0],r+n[0].length):-1}function ir(t){var e=t.getTimezoneOffset(),r=e>0?\"-\":\"+\",n=y(e)/60|0,i=y(e)%60;return r+Ve(n,\"0\",2)+Ve(i,\"0\",2)}function ar(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r,r+1));return n?r+n[0].length:-1}function or(t){for(var e=t.length,r=-1;++r<e;)t[r][0]=this(t[r][0]);return function(e){for(var r=0,n=t[r];!n[1](e);)n=t[++r];return n[0](e)}}t.locale=function(e){return{numberFormat:function(e){var r=e.decimal,n=e.thousands,i=e.grouping,a=e.currency,o=i&&n?function(t,e){for(var r=t.length,a=[],o=0,s=i[0],l=0;r>0&&s>0&&(l+s+1>e&&(s=Math.max(1,e-l)),a.push(t.substring(r-=s,r+s)),!((l+=s+1)>e));)s=i[o=(o+1)%i.length];return a.reverse().join(n)}:P;return function(e){var n=Le.exec(e),i=n[1]||\" \",s=n[2]||\">\",l=n[3]||\"-\",c=n[4]||\"\",u=n[5],h=+n[6],f=n[7],p=n[8],d=n[9],g=1,v=\"\",m=\"\",y=!1,x=!0;switch(p&&(p=+p.substring(1)),(u||\"0\"===i&&\"=\"===s)&&(u=i=\"0\",s=\"=\"),d){case\"n\":f=!0,d=\"g\";break;case\"%\":g=100,m=\"%\",d=\"f\";break;case\"p\":g=100,m=\"%\",d=\"r\";break;case\"b\":case\"o\":case\"x\":case\"X\":\"#\"===c&&(v=\"0\"+d.toLowerCase());case\"c\":x=!1;case\"d\":y=!0,p=0;break;case\"s\":g=-1,d=\"r\"}\"$\"===c&&(v=a[0],m=a[1]),\"r\"!=d||p||(d=\"g\"),null!=p&&(\"g\"==d?p=Math.max(1,Math.min(21,p)):\"e\"!=d&&\"f\"!=d||(p=Math.max(0,Math.min(20,p)))),d=Pe.get(d)||Oe;var b=u&&f;return function(e){var n=m;if(y&&e%1)return\"\";var a=e<0||0===e&&1/e<0?(e=-e,\"-\"):\"-\"===l?\"\":l;if(g<0){var c=t.formatPrefix(e,p);e=c.scale(e),n=c.symbol+m}else e*=g;var _,w,k=(e=d(e,p)).lastIndexOf(\".\");if(k<0){var T=x?e.lastIndexOf(\"e\"):-1;T<0?(_=e,w=\"\"):(_=e.substring(0,T),w=e.substring(T))}else _=e.substring(0,k),w=r+e.substring(k+1);!u&&f&&(_=o(_,1/0));var A=v.length+_.length+w.length+(b?0:a.length),M=A<h?new Array(A=h-A+1).join(i):\"\";return b&&(_=o(M+_,M.length?h-w.length:1/0)),a+=v,e=_+w,(\"<\"===s?a+e+M:\">\"===s?M+a+e:\"^\"===s?M.substring(0,A>>=1)+a+e+M.substring(A):a+(b?e:M+e))+n}}}(e),timeFormat:function(e){var r=e.dateTime,n=e.date,i=e.time,a=e.periods,o=e.days,s=e.shortDays,l=e.months,c=e.shortMonths;function u(t){var e=t.length;function r(r){for(var n,i,a,o=[],s=-1,l=0;++s<e;)37===t.charCodeAt(s)&&(o.push(t.slice(l,s)),null!=(i=Ne[n=t.charAt(++s)])&&(n=t.charAt(++s)),(a=_[n])&&(n=a(r,null==i?\"e\"===n?\" \":\"0\":i)),o.push(n),l=s+1);return o.push(t.slice(l,s)),o.join(\"\")}return r.parse=function(e){var r={y:1900,m:0,d:1,H:0,M:0,S:0,L:0,Z:null};if(h(r,t,e,0)!=e.length)return null;\"p\"in r&&(r.H=r.H%12+12*r.p);var n=null!=r.Z&&Ie!==De,i=new(n?De:Ie);return\"j\"in r?i.setFullYear(r.y,0,r.j):\"W\"in r||\"U\"in r?(\"w\"in r||(r.w=\"W\"in r?1:0),i.setFullYear(r.y,0,1),i.setFullYear(r.y,0,\"W\"in r?(r.w+6)%7+7*r.W-(i.getDay()+5)%7:r.w+7*r.U-(i.getDay()+6)%7)):i.setFullYear(r.y,r.m,r.d),i.setHours(r.H+(r.Z/100|0),r.M+r.Z%100,r.S,r.L),n?i._:i},r.toString=function(){return t},r}function h(t,e,r,n){for(var i,a,o,s=0,l=e.length,c=r.length;s<l;){if(n>=c)return-1;if(37===(i=e.charCodeAt(s++))){if(o=e.charAt(s++),!(a=w[o in Ne?e.charAt(s++):o])||(n=a(t,r,n))<0)return-1}else if(i!=r.charCodeAt(n++))return-1}return n}u.utc=function(t){var e=u(t);function r(t){try{var r=new(Ie=De);return r._=t,e(r)}finally{Ie=Date}}return r.parse=function(t){try{Ie=De;var r=e.parse(t);return r&&r._}finally{Ie=Date}},r.toString=e.toString,r},u.multi=u.utc.multi=or;var f=t.map(),p=qe(o),d=He(o),g=qe(s),v=He(s),m=qe(l),y=He(l),x=qe(c),b=He(c);a.forEach(function(t,e){f.set(t.toLowerCase(),e)});var _={a:function(t){return s[t.getDay()]},A:function(t){return o[t.getDay()]},b:function(t){return c[t.getMonth()]},B:function(t){return l[t.getMonth()]},c:u(r),d:function(t,e){return Ve(t.getDate(),e,2)},e:function(t,e){return Ve(t.getDate(),e,2)},H:function(t,e){return Ve(t.getHours(),e,2)},I:function(t,e){return Ve(t.getHours()%12||12,e,2)},j:function(t,e){return Ve(1+ze.dayOfYear(t),e,3)},L:function(t,e){return Ve(t.getMilliseconds(),e,3)},m:function(t,e){return Ve(t.getMonth()+1,e,2)},M:function(t,e){return Ve(t.getMinutes(),e,2)},p:function(t){return a[+(t.getHours()>=12)]},S:function(t,e){return Ve(t.getSeconds(),e,2)},U:function(t,e){return Ve(ze.sundayOfYear(t),e,2)},w:function(t){return t.getDay()},W:function(t,e){return Ve(ze.mondayOfYear(t),e,2)},x:u(n),X:u(i),y:function(t,e){return Ve(t.getFullYear()%100,e,2)},Y:function(t,e){return Ve(t.getFullYear()%1e4,e,4)},Z:ir,\"%\":function(){return\"%\"}},w={a:function(t,e,r){g.lastIndex=0;var n=g.exec(e.slice(r));return n?(t.w=v.get(n[0].toLowerCase()),r+n[0].length):-1},A:function(t,e,r){p.lastIndex=0;var n=p.exec(e.slice(r));return n?(t.w=d.get(n[0].toLowerCase()),r+n[0].length):-1},b:function(t,e,r){x.lastIndex=0;var n=x.exec(e.slice(r));return n?(t.m=b.get(n[0].toLowerCase()),r+n[0].length):-1},B:function(t,e,r){m.lastIndex=0;var n=m.exec(e.slice(r));return n?(t.m=y.get(n[0].toLowerCase()),r+n[0].length):-1},c:function(t,e,r){return h(t,_.c.toString(),e,r)},d:$e,e:$e,H:tr,I:tr,j:Qe,L:nr,m:Ke,M:er,p:function(t,e,r){var n=f.get(e.slice(r,r+=2).toLowerCase());return null==n?-1:(t.p=n,r)},S:rr,U:Ye,w:Ge,W:We,x:function(t,e,r){return h(t,_.x.toString(),e,r)},X:function(t,e,r){return h(t,_.X.toString(),e,r)},y:Ze,Y:Xe,Z:Je,\"%\":ar};return u}(e)}};var sr=t.locale({decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],dateTime:\"%a %b %e %X %Y\",date:\"%m/%d/%Y\",time:\"%H:%M:%S\",periods:[\"AM\",\"PM\"],days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"]});function lr(){}t.format=sr.numberFormat,t.geo={},lr.prototype={s:0,t:0,add:function(t){ur(t,this.t,cr),ur(cr.s,this.s,this),this.s?this.t+=cr.t:this.s=cr.t},reset:function(){this.s=this.t=0},valueOf:function(){return this.s}};var cr=new lr;function ur(t,e,r){var n=r.s=t+e,i=n-t,a=n-i;r.t=t-a+(e-i)}function hr(t,e){t&&pr.hasOwnProperty(t.type)&&pr[t.type](t,e)}t.geo.stream=function(t,e){t&&fr.hasOwnProperty(t.type)?fr[t.type](t,e):hr(t,e)};var fr={Feature:function(t,e){hr(t.geometry,e)},FeatureCollection:function(t,e){for(var r=t.features,n=-1,i=r.length;++n<i;)hr(r[n].geometry,e)}},pr={Sphere:function(t,e){e.sphere()},Point:function(t,e){t=t.coordinates,e.point(t[0],t[1],t[2])},MultiPoint:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)t=r[n],e.point(t[0],t[1],t[2])},LineString:function(t,e){dr(t.coordinates,e,0)},MultiLineString:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)dr(r[n],e,0)},Polygon:function(t,e){gr(t.coordinates,e)},MultiPolygon:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)gr(r[n],e)},GeometryCollection:function(t,e){for(var r=t.geometries,n=-1,i=r.length;++n<i;)hr(r[n],e)}};function dr(t,e,r){var n,i=-1,a=t.length-r;for(e.lineStart();++i<a;)n=t[i],e.point(n[0],n[1],n[2]);e.lineEnd()}function gr(t,e){var r=-1,n=t.length;for(e.polygonStart();++r<n;)dr(t[r],e,1);e.polygonEnd()}t.geo.area=function(e){return vr=0,t.geo.stream(e,Cr),vr};var vr,mr,yr,xr,br,_r,wr,kr,Tr,Ar,Mr,Sr,Er=new lr,Cr={sphere:function(){vr+=4*At},point:D,lineStart:D,lineEnd:D,polygonStart:function(){Er.reset(),Cr.lineStart=Lr},polygonEnd:function(){var t=2*Er;vr+=t<0?4*At+t:t,Cr.lineStart=Cr.lineEnd=Cr.point=D}};function Lr(){var t,e,r,n,i;function a(t,e){e=e*Ct/2+At/4;var a=(t*=Ct)-r,o=a>=0?1:-1,s=o*a,l=Math.cos(e),c=Math.sin(e),u=i*c,h=n*l+u*Math.cos(s),f=u*o*Math.sin(s);Er.add(Math.atan2(f,h)),r=t,n=l,i=c}Cr.point=function(o,s){Cr.point=a,r=(t=o)*Ct,n=Math.cos(s=(e=s)*Ct/2+At/4),i=Math.sin(s)},Cr.lineEnd=function(){a(t,e)}}function Pr(t){var e=t[0],r=t[1],n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}function Or(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}function zr(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}function Ir(t,e){t[0]+=e[0],t[1]+=e[1],t[2]+=e[2]}function Dr(t,e){return[t[0]*e,t[1]*e,t[2]*e]}function Rr(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]+t[2]*t[2]);t[0]/=e,t[1]/=e,t[2]/=e}function Fr(t){return[Math.atan2(t[1],t[0]),It(t[2])]}function Br(t,e){return y(t[0]-e[0])<kt&&y(t[1]-e[1])<kt}t.geo.bounds=function(){var e,r,n,i,a,o,s,l,c,u,h,f={point:p,lineStart:g,lineEnd:v,polygonStart:function(){f.point=m,f.lineStart=x,f.lineEnd=b,c=0,Cr.polygonStart()},polygonEnd:function(){Cr.polygonEnd(),f.point=p,f.lineStart=g,f.lineEnd=v,Er<0?(e=-(n=180),r=-(i=90)):c>kt?i=90:c<-kt&&(r=-90),h[0]=e,h[1]=n}};function p(t,a){u.push(h=[e=t,n=t]),a<r&&(r=a),a>i&&(i=a)}function d(t,o){var s=Pr([t*Ct,o*Ct]);if(l){var c=zr(l,s),u=zr([c[1],-c[0],0],c);Rr(u),u=Fr(u);var h=t-a,f=h>0?1:-1,d=u[0]*Lt*f,g=y(h)>180;if(g^(f*a<d&&d<f*t))(v=u[1]*Lt)>i&&(i=v);else if(g^(f*a<(d=(d+360)%360-180)&&d<f*t)){var v;(v=-u[1]*Lt)<r&&(r=v)}else o<r&&(r=o),o>i&&(i=o);g?t<a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t):n>=e?(t<e&&(e=t),t>n&&(n=t)):t>a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t)}else p(t,o);l=s,a=t}function g(){f.point=d}function v(){h[0]=e,h[1]=n,f.point=p,l=null}function m(t,e){if(l){var r=t-a;c+=y(r)>180?r+(r>0?360:-360):r}else o=t,s=e;Cr.point(t,e),d(t,e)}function x(){Cr.lineStart()}function b(){m(o,s),Cr.lineEnd(),y(c)>kt&&(e=-(n=180)),h[0]=e,h[1]=n,l=null}function _(t,e){return(e-=t)<0?e+360:e}function w(t,e){return t[0]-e[0]}function k(t,e){return e[0]<=e[1]?e[0]<=t&&t<=e[1]:t<e[0]||e[1]<t}return function(a){if(i=n=-(e=r=1/0),u=[],t.geo.stream(a,f),c=u.length){u.sort(w);for(var o=1,s=[g=u[0]];o<c;++o)k((p=u[o])[0],g)||k(p[1],g)?(_(g[0],p[1])>_(g[0],g[1])&&(g[1]=p[1]),_(p[0],g[1])>_(g[0],g[1])&&(g[0]=p[0])):s.push(g=p);for(var l,c,p,d=-1/0,g=(o=0,s[c=s.length-1]);o<=c;g=p,++o)p=s[o],(l=_(g[1],p[0]))>d&&(d=l,e=p[0],n=g[1])}return u=h=null,e===1/0||r===1/0?[[NaN,NaN],[NaN,NaN]]:[[e,r],[n,i]]}}(),t.geo.centroid=function(e){mr=yr=xr=br=_r=wr=kr=Tr=Ar=Mr=Sr=0,t.geo.stream(e,Nr);var r=Ar,n=Mr,i=Sr,a=r*r+n*n+i*i;return a<Tt&&(r=wr,n=kr,i=Tr,yr<kt&&(r=xr,n=br,i=_r),(a=r*r+n*n+i*i)<Tt)?[NaN,NaN]:[Math.atan2(n,r)*Lt,It(i/Math.sqrt(a))*Lt]};var Nr={sphere:D,point:jr,lineStart:Vr,lineEnd:qr,polygonStart:function(){Nr.lineStart=Hr},polygonEnd:function(){Nr.lineStart=Vr}};function jr(t,e){t*=Ct;var r=Math.cos(e*=Ct);Ur(r*Math.cos(t),r*Math.sin(t),Math.sin(e))}function Ur(t,e,r){xr+=(t-xr)/++mr,br+=(e-br)/mr,_r+=(r-_r)/mr}function Vr(){var t,e,r;function n(n,i){n*=Ct;var a=Math.cos(i*=Ct),o=a*Math.cos(n),s=a*Math.sin(n),l=Math.sin(i),c=Math.atan2(Math.sqrt((c=e*l-r*s)*c+(c=r*o-t*l)*c+(c=t*s-e*o)*c),t*o+e*s+r*l);yr+=c,wr+=c*(t+(t=o)),kr+=c*(e+(e=s)),Tr+=c*(r+(r=l)),Ur(t,e,r)}Nr.point=function(i,a){i*=Ct;var o=Math.cos(a*=Ct);t=o*Math.cos(i),e=o*Math.sin(i),r=Math.sin(a),Nr.point=n,Ur(t,e,r)}}function qr(){Nr.point=jr}function Hr(){var t,e,r,n,i;function a(t,e){t*=Ct;var a=Math.cos(e*=Ct),o=a*Math.cos(t),s=a*Math.sin(t),l=Math.sin(e),c=n*l-i*s,u=i*o-r*l,h=r*s-n*o,f=Math.sqrt(c*c+u*u+h*h),p=r*o+n*s+i*l,d=f&&-zt(p)/f,g=Math.atan2(f,p);Ar+=d*c,Mr+=d*u,Sr+=d*h,yr+=g,wr+=g*(r+(r=o)),kr+=g*(n+(n=s)),Tr+=g*(i+(i=l)),Ur(r,n,i)}Nr.point=function(o,s){t=o,e=s,Nr.point=a,o*=Ct;var l=Math.cos(s*=Ct);r=l*Math.cos(o),n=l*Math.sin(o),i=Math.sin(s),Ur(r,n,i)},Nr.lineEnd=function(){a(t,e),Nr.lineEnd=qr,Nr.point=jr}}function Gr(t,e){function r(r,n){return r=t(r,n),e(r[0],r[1])}return t.invert&&e.invert&&(r.invert=function(r,n){return(r=e.invert(r,n))&&t.invert(r[0],r[1])}),r}function Yr(){return!0}function Wr(t,e,r,n,i){var a=[],o=[];if(t.forEach(function(t){if(!((e=t.length-1)<=0)){var e,r=t[0],n=t[e];if(Br(r,n)){i.lineStart();for(var s=0;s<e;++s)i.point((r=t[s])[0],r[1]);i.lineEnd()}else{var l=new Zr(r,t,null,!0),c=new Zr(r,null,l,!1);l.o=c,a.push(l),o.push(c),l=new Zr(n,t,null,!1),c=new Zr(n,null,l,!0),l.o=c,a.push(l),o.push(c)}}}),o.sort(e),Xr(a),Xr(o),a.length){for(var s=0,l=r,c=o.length;s<c;++s)o[s].e=l=!l;for(var u,h,f=a[0];;){for(var p=f,d=!0;p.v;)if((p=p.n)===f)return;u=p.z,i.lineStart();do{if(p.v=p.o.v=!0,p.e){if(d)for(s=0,c=u.length;s<c;++s)i.point((h=u[s])[0],h[1]);else n(p.x,p.n.x,1,i);p=p.n}else{if(d)for(s=(u=p.p.z).length-1;s>=0;--s)i.point((h=u[s])[0],h[1]);else n(p.x,p.p.x,-1,i);p=p.p}u=(p=p.o).z,d=!d}while(!p.v);i.lineEnd()}}}function Xr(t){if(e=t.length){for(var e,r,n=0,i=t[0];++n<e;)i.n=r=t[n],r.p=i,i=r;i.n=r=t[0],r.p=i}}function Zr(t,e,r,n){this.x=t,this.z=e,this.o=r,this.e=n,this.v=!1,this.n=this.p=null}function Jr(e,r,n,i){return function(a,o){var s,l=r(o),c=a.invert(i[0],i[1]),u={point:h,lineStart:p,lineEnd:d,polygonStart:function(){u.point=b,u.lineStart=_,u.lineEnd=w,s=[],g=[]},polygonEnd:function(){u.point=h,u.lineStart=p,u.lineEnd=d,s=t.merge(s);var e=function(t,e){var r=t[0],n=t[1],i=[Math.sin(r),-Math.cos(r),0],a=0,o=0;Er.reset();for(var s=0,l=e.length;s<l;++s){var c=e[s],u=c.length;if(u)for(var h=c[0],f=h[0],p=h[1]/2+At/4,d=Math.sin(p),g=Math.cos(p),v=1;;){v===u&&(v=0);var m=(t=c[v])[0],y=t[1]/2+At/4,x=Math.sin(y),b=Math.cos(y),_=m-f,w=_>=0?1:-1,k=w*_,T=k>At,A=d*x;if(Er.add(Math.atan2(A*w*Math.sin(k),g*b+A*Math.cos(k))),a+=T?_+w*Mt:_,T^f>=r^m>=r){var M=zr(Pr(h),Pr(t));Rr(M);var S=zr(i,M);Rr(S);var E=(T^_>=0?-1:1)*It(S[2]);(n>E||n===E&&(M[0]||M[1]))&&(o+=T^_>=0?1:-1)}if(!v++)break;f=m,d=x,g=b,h=t}}return(a<-kt||a<kt&&Er<-kt)^1&o}(c,g);s.length?(x||(o.polygonStart(),x=!0),Wr(s,Qr,e,n,o)):e&&(x||(o.polygonStart(),x=!0),o.lineStart(),n(null,null,1,o),o.lineEnd()),x&&(o.polygonEnd(),x=!1),s=g=null},sphere:function(){o.polygonStart(),o.lineStart(),n(null,null,1,o),o.lineEnd(),o.polygonEnd()}};function h(t,r){var n=a(t,r);e(t=n[0],r=n[1])&&o.point(t,r)}function f(t,e){var r=a(t,e);l.point(r[0],r[1])}function p(){u.point=f,l.lineStart()}function d(){u.point=h,l.lineEnd()}var g,v,m=$r(),y=r(m),x=!1;function b(t,e){v.push([t,e]);var r=a(t,e);y.point(r[0],r[1])}function _(){y.lineStart(),v=[]}function w(){b(v[0][0],v[0][1]),y.lineEnd();var t,e=y.clean(),r=m.buffer(),n=r.length;if(v.pop(),g.push(v),v=null,n)if(1&e){var i,a=-1;if((n=(t=r[0]).length-1)>0){for(x||(o.polygonStart(),x=!0),o.lineStart();++a<n;)o.point((i=t[a])[0],i[1]);o.lineEnd()}}else n>1&&2&e&&r.push(r.pop().concat(r.shift())),s.push(r.filter(Kr))}return u}}function Kr(t){return t.length>1}function $r(){var t,e=[];return{lineStart:function(){e.push(t=[])},point:function(e,r){t.push([e,r])},lineEnd:D,buffer:function(){var r=e;return e=[],t=null,r},rejoin:function(){e.length>1&&e.push(e.pop().concat(e.shift()))}}}function Qr(t,e){return((t=t.x)[0]<0?t[1]-Et-kt:Et-t[1])-((e=e.x)[0]<0?e[1]-Et-kt:Et-e[1])}var tn=Jr(Yr,function(t){var e,r=NaN,n=NaN,i=NaN;return{lineStart:function(){t.lineStart(),e=1},point:function(a,o){var s=a>0?At:-At,l=y(a-r);y(l-At)<kt?(t.point(r,n=(n+o)/2>0?Et:-Et),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),t.point(a,n),e=0):i!==s&&l>=At&&(y(r-i)<kt&&(r-=i*kt),y(a-s)<kt&&(a-=s*kt),n=function(t,e,r,n){var i,a,o=Math.sin(t-r);return y(o)>kt?Math.atan((Math.sin(e)*(a=Math.cos(n))*Math.sin(r)-Math.sin(n)*(i=Math.cos(e))*Math.sin(t))/(i*a*o)):(e+n)/2}(r,n,a,o),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),e=0),t.point(r=a,n=o),i=s},lineEnd:function(){t.lineEnd(),r=n=NaN},clean:function(){return 2-e}}},function(t,e,r,n){var i;if(null==t)i=r*Et,n.point(-At,i),n.point(0,i),n.point(At,i),n.point(At,0),n.point(At,-i),n.point(0,-i),n.point(-At,-i),n.point(-At,0),n.point(-At,i);else if(y(t[0]-e[0])>kt){var a=t[0]<e[0]?At:-At;i=r*a/2,n.point(-a,i),n.point(0,i),n.point(a,i)}else n.point(e[0],e[1])},[-At,-At/2]);function en(t,e,r,n){return function(i){var a,o=i.a,s=i.b,l=o.x,c=o.y,u=0,h=1,f=s.x-l,p=s.y-c;if(a=t-l,f||!(a>0)){if(a/=f,f<0){if(a<u)return;a<h&&(h=a)}else if(f>0){if(a>h)return;a>u&&(u=a)}if(a=r-l,f||!(a<0)){if(a/=f,f<0){if(a>h)return;a>u&&(u=a)}else if(f>0){if(a<u)return;a<h&&(h=a)}if(a=e-c,p||!(a>0)){if(a/=p,p<0){if(a<u)return;a<h&&(h=a)}else if(p>0){if(a>h)return;a>u&&(u=a)}if(a=n-c,p||!(a<0)){if(a/=p,p<0){if(a>h)return;a>u&&(u=a)}else if(p>0){if(a<u)return;a<h&&(h=a)}return u>0&&(i.a={x:l+u*f,y:c+u*p}),h<1&&(i.b={x:l+h*f,y:c+h*p}),i}}}}}}var rn=1e9;function nn(e,r,n,i){return function(l){var c,u,h,f,p,d,g,v,m,y,x,b=l,_=$r(),w=en(e,r,n,i),k={point:M,lineStart:function(){k.point=S,u&&u.push(h=[]);y=!0,m=!1,g=v=NaN},lineEnd:function(){c&&(S(f,p),d&&m&&_.rejoin(),c.push(_.buffer()));k.point=M,m&&l.lineEnd()},polygonStart:function(){l=_,c=[],u=[],x=!0},polygonEnd:function(){l=b,c=t.merge(c);var r=function(t){for(var e=0,r=u.length,n=t[1],i=0;i<r;++i)for(var a,o=1,s=u[i],l=s.length,c=s[0];o<l;++o)a=s[o],c[1]<=n?a[1]>n&&Ot(c,a,t)>0&&++e:a[1]<=n&&Ot(c,a,t)<0&&--e,c=a;return 0!==e}([e,i]),n=x&&r,a=c.length;(n||a)&&(l.polygonStart(),n&&(l.lineStart(),T(null,null,1,l),l.lineEnd()),a&&Wr(c,o,r,T,l),l.polygonEnd()),c=u=h=null}};function T(t,o,l,c){var u=0,h=0;if(null==t||(u=a(t,l))!==(h=a(o,l))||s(t,o)<0^l>0)do{c.point(0===u||3===u?e:n,u>1?i:r)}while((u=(u+l+4)%4)!==h);else c.point(o[0],o[1])}function A(t,a){return e<=t&&t<=n&&r<=a&&a<=i}function M(t,e){A(t,e)&&l.point(t,e)}function S(t,e){var r=A(t=Math.max(-rn,Math.min(rn,t)),e=Math.max(-rn,Math.min(rn,e)));if(u&&h.push([t,e]),y)f=t,p=e,d=r,y=!1,r&&(l.lineStart(),l.point(t,e));else if(r&&m)l.point(t,e);else{var n={a:{x:g,y:v},b:{x:t,y:e}};w(n)?(m||(l.lineStart(),l.point(n.a.x,n.a.y)),l.point(n.b.x,n.b.y),r||l.lineEnd(),x=!1):r&&(l.lineStart(),l.point(t,e),x=!1)}g=t,v=e,m=r}return k};function a(t,i){return y(t[0]-e)<kt?i>0?0:3:y(t[0]-n)<kt?i>0?2:1:y(t[1]-r)<kt?i>0?1:0:i>0?3:2}function o(t,e){return s(t.x,e.x)}function s(t,e){var r=a(t,1),n=a(e,1);return r!==n?r-n:0===r?e[1]-t[1]:1===r?t[0]-e[0]:2===r?t[1]-e[1]:e[0]-t[0]}}function an(t){var e=0,r=At/3,n=Cn(t),i=n(e,r);return i.parallels=function(t){return arguments.length?n(e=t[0]*At/180,r=t[1]*At/180):[e/At*180,r/At*180]},i}function on(t,e){var r=Math.sin(t),n=(r+Math.sin(e))/2,i=1+r*(2*n-r),a=Math.sqrt(i)/n;function o(t,e){var r=Math.sqrt(i-2*n*Math.sin(e))/n;return[r*Math.sin(t*=n),a-r*Math.cos(t)]}return o.invert=function(t,e){var r=a-e;return[Math.atan2(t,r)/n,It((i-(t*t+r*r)*n*n)/(2*n))]},o}t.geo.clipExtent=function(){var t,e,r,n,i,a,o={stream:function(t){return i&&(i.valid=!1),(i=a(t)).valid=!0,i},extent:function(s){return arguments.length?(a=nn(t=+s[0][0],e=+s[0][1],r=+s[1][0],n=+s[1][1]),i&&(i.valid=!1,i=null),o):[[t,e],[r,n]]}};return o.extent([[0,0],[960,500]])},(t.geo.conicEqualArea=function(){return an(on)}).raw=on,t.geo.albers=function(){return t.geo.conicEqualArea().rotate([96,0]).center([-.6,38.7]).parallels([29.5,45.5]).scale(1070)},t.geo.albersUsa=function(){var e,r,n,i,a=t.geo.albers(),o=t.geo.conicEqualArea().rotate([154,0]).center([-2,58.5]).parallels([55,65]),s=t.geo.conicEqualArea().rotate([157,0]).center([-3,19.9]).parallels([8,18]),l={point:function(t,r){e=[t,r]}};function c(t){var a=t[0],o=t[1];return e=null,r(a,o),e||(n(a,o),e)||i(a,o),e}return c.invert=function(t){var e=a.scale(),r=a.translate(),n=(t[0]-r[0])/e,i=(t[1]-r[1])/e;return(i>=.12&&i<.234&&n>=-.425&&n<-.214?o:i>=.166&&i<.234&&n>=-.214&&n<-.115?s:a).invert(t)},c.stream=function(t){var e=a.stream(t),r=o.stream(t),n=s.stream(t);return{point:function(t,i){e.point(t,i),r.point(t,i),n.point(t,i)},sphere:function(){e.sphere(),r.sphere(),n.sphere()},lineStart:function(){e.lineStart(),r.lineStart(),n.lineStart()},lineEnd:function(){e.lineEnd(),r.lineEnd(),n.lineEnd()},polygonStart:function(){e.polygonStart(),r.polygonStart(),n.polygonStart()},polygonEnd:function(){e.polygonEnd(),r.polygonEnd(),n.polygonEnd()}}},c.precision=function(t){return arguments.length?(a.precision(t),o.precision(t),s.precision(t),c):a.precision()},c.scale=function(t){return arguments.length?(a.scale(t),o.scale(.35*t),s.scale(t),c.translate(a.translate())):a.scale()},c.translate=function(t){if(!arguments.length)return a.translate();var e=a.scale(),u=+t[0],h=+t[1];return r=a.translate(t).clipExtent([[u-.455*e,h-.238*e],[u+.455*e,h+.238*e]]).stream(l).point,n=o.translate([u-.307*e,h+.201*e]).clipExtent([[u-.425*e+kt,h+.12*e+kt],[u-.214*e-kt,h+.234*e-kt]]).stream(l).point,i=s.translate([u-.205*e,h+.212*e]).clipExtent([[u-.214*e+kt,h+.166*e+kt],[u-.115*e-kt,h+.234*e-kt]]).stream(l).point,c},c.scale(1070)};var sn,ln,cn,un,hn,fn,pn={point:D,lineStart:D,lineEnd:D,polygonStart:function(){ln=0,pn.lineStart=dn},polygonEnd:function(){pn.lineStart=pn.lineEnd=pn.point=D,sn+=y(ln/2)}};function dn(){var t,e,r,n;function i(t,e){ln+=n*t-r*e,r=t,n=e}pn.point=function(a,o){pn.point=i,t=r=a,e=n=o},pn.lineEnd=function(){i(t,e)}}var gn={point:function(t,e){t<cn&&(cn=t);t>hn&&(hn=t);e<un&&(un=e);e>fn&&(fn=e)},lineStart:D,lineEnd:D,polygonStart:D,polygonEnd:D};function vn(){var t=mn(4.5),e=[],r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(e){return t=mn(e),r},result:function(){if(e.length){var t=e.join(\"\");return e=[],t}}};function n(r,n){e.push(\"M\",r,\",\",n,t)}function i(t,n){e.push(\"M\",t,\",\",n),r.point=a}function a(t,r){e.push(\"L\",t,\",\",r)}function o(){r.point=n}function s(){e.push(\"Z\")}return r}function mn(t){return\"m0,\"+t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+-2*t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+2*t+\"z\"}var yn,xn={point:bn,lineStart:_n,lineEnd:wn,polygonStart:function(){xn.lineStart=kn},polygonEnd:function(){xn.point=bn,xn.lineStart=_n,xn.lineEnd=wn}};function bn(t,e){xr+=t,br+=e,++_r}function _n(){var t,e;function r(r,n){var i=r-t,a=n-e,o=Math.sqrt(i*i+a*a);wr+=o*(t+r)/2,kr+=o*(e+n)/2,Tr+=o,bn(t=r,e=n)}xn.point=function(n,i){xn.point=r,bn(t=n,e=i)}}function wn(){xn.point=bn}function kn(){var t,e,r,n;function i(t,e){var i=t-r,a=e-n,o=Math.sqrt(i*i+a*a);wr+=o*(r+t)/2,kr+=o*(n+e)/2,Tr+=o,Ar+=(o=n*t-r*e)*(r+t),Mr+=o*(n+e),Sr+=3*o,bn(r=t,n=e)}xn.point=function(a,o){xn.point=i,bn(t=r=a,e=n=o)},xn.lineEnd=function(){i(t,e)}}function Tn(t){var e=4.5,r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(t){return e=t,r},result:D};function n(r,n){t.moveTo(r+e,n),t.arc(r,n,e,0,Mt)}function i(e,n){t.moveTo(e,n),r.point=a}function a(e,r){t.lineTo(e,r)}function o(){r.point=n}function s(){t.closePath()}return r}function An(t){var e=.5,r=Math.cos(30*Ct),n=16;function i(e){return(n?function(e){var r,i,o,s,l,c,u,h,f,p,d,g,v={point:m,lineStart:y,lineEnd:b,polygonStart:function(){e.polygonStart(),v.lineStart=_},polygonEnd:function(){e.polygonEnd(),v.lineStart=y}};function m(r,n){r=t(r,n),e.point(r[0],r[1])}function y(){h=NaN,v.point=x,e.lineStart()}function x(r,i){var o=Pr([r,i]),s=t(r,i);a(h,f,u,p,d,g,h=s[0],f=s[1],u=r,p=o[0],d=o[1],g=o[2],n,e),e.point(h,f)}function b(){v.point=m,e.lineEnd()}function _(){y(),v.point=w,v.lineEnd=k}function w(t,e){x(r=t,e),i=h,o=f,s=p,l=d,c=g,v.point=x}function k(){a(h,f,u,p,d,g,i,o,r,s,l,c,n,e),v.lineEnd=b,b()}return v}:function(e){return Sn(e,function(r,n){r=t(r,n),e.point(r[0],r[1])})})(e)}function a(n,i,o,s,l,c,u,h,f,p,d,g,v,m){var x=u-n,b=h-i,_=x*x+b*b;if(_>4*e&&v--){var w=s+p,k=l+d,T=c+g,A=Math.sqrt(w*w+k*k+T*T),M=Math.asin(T/=A),S=y(y(T)-1)<kt||y(o-f)<kt?(o+f)/2:Math.atan2(k,w),E=t(S,M),C=E[0],L=E[1],P=C-n,O=L-i,z=b*P-x*O;(z*z/_>e||y((x*P+b*O)/_-.5)>.3||s*p+l*d+c*g<r)&&(a(n,i,o,s,l,c,C,L,S,w/=A,k/=A,T,v,m),m.point(C,L),a(C,L,S,w,k,T,u,h,f,p,d,g,v,m))}}return i.precision=function(t){return arguments.length?(n=(e=t*t)>0&&16,i):Math.sqrt(e)},i}function Mn(t){this.stream=t}function Sn(t,e){return{point:e,sphere:function(){t.sphere()},lineStart:function(){t.lineStart()},lineEnd:function(){t.lineEnd()},polygonStart:function(){t.polygonStart()},polygonEnd:function(){t.polygonEnd()}}}function En(t){return Cn(function(){return t})()}function Cn(e){var r,n,i,a,o,s,l=An(function(t,e){return[(t=r(t,e))[0]*c+a,o-t[1]*c]}),c=150,u=480,h=250,f=0,p=0,d=0,g=0,v=0,m=tn,x=P,b=null,_=null;function w(t){return[(t=i(t[0]*Ct,t[1]*Ct))[0]*c+a,o-t[1]*c]}function k(t){return(t=i.invert((t[0]-a)/c,(o-t[1])/c))&&[t[0]*Lt,t[1]*Lt]}function T(){i=Gr(n=zn(d,g,v),r);var t=r(f,p);return a=u-t[0]*c,o=h+t[1]*c,A()}function A(){return s&&(s.valid=!1,s=null),w}return w.stream=function(t){return s&&(s.valid=!1),(s=Ln(m(n,l(x(t))))).valid=!0,s},w.clipAngle=function(t){return arguments.length?(m=null==t?(b=t,tn):function(t){var e=Math.cos(t),r=e>0,n=y(e)>kt;return Jr(i,function(t){var e,s,l,c,u;return{lineStart:function(){c=l=!1,u=1},point:function(h,f){var p,d=[h,f],g=i(h,f),v=r?g?0:o(h,f):g?o(h+(h<0?At:-At),f):0;if(!e&&(c=l=g)&&t.lineStart(),g!==l&&(p=a(e,d),(Br(e,p)||Br(d,p))&&(d[0]+=kt,d[1]+=kt,g=i(d[0],d[1]))),g!==l)u=0,g?(t.lineStart(),p=a(d,e),t.point(p[0],p[1])):(p=a(e,d),t.point(p[0],p[1]),t.lineEnd()),e=p;else if(n&&e&&r^g){var m;v&s||!(m=a(d,e,!0))||(u=0,r?(t.lineStart(),t.point(m[0][0],m[0][1]),t.point(m[1][0],m[1][1]),t.lineEnd()):(t.point(m[1][0],m[1][1]),t.lineEnd(),t.lineStart(),t.point(m[0][0],m[0][1])))}!g||e&&Br(e,d)||t.point(d[0],d[1]),e=d,l=g,s=v},lineEnd:function(){l&&t.lineEnd(),e=null},clean:function(){return u|(c&&l)<<1}}},Fn(t,6*Ct),r?[0,-t]:[-At,t-At]);function i(t,r){return Math.cos(t)*Math.cos(r)>e}function a(t,r,n){var i=[1,0,0],a=zr(Pr(t),Pr(r)),o=Or(a,a),s=a[0],l=o-s*s;if(!l)return!n&&t;var c=e*o/l,u=-e*s/l,h=zr(i,a),f=Dr(i,c);Ir(f,Dr(a,u));var p=h,d=Or(f,p),g=Or(p,p),v=d*d-g*(Or(f,f)-1);if(!(v<0)){var m=Math.sqrt(v),x=Dr(p,(-d-m)/g);if(Ir(x,f),x=Fr(x),!n)return x;var b,_=t[0],w=r[0],k=t[1],T=r[1];w<_&&(b=_,_=w,w=b);var A=w-_,M=y(A-At)<kt;if(!M&&T<k&&(b=k,k=T,T=b),M||A<kt?M?k+T>0^x[1]<(y(x[0]-_)<kt?k:T):k<=x[1]&&x[1]<=T:A>At^(_<=x[0]&&x[0]<=w)){var S=Dr(p,(-d+m)/g);return Ir(S,f),[x,Fr(S)]}}}function o(e,n){var i=r?t:At-t,a=0;return e<-i?a|=1:e>i&&(a|=2),n<-i?a|=4:n>i&&(a|=8),a}}((b=+t)*Ct),A()):b},w.clipExtent=function(t){return arguments.length?(_=t,x=t?nn(t[0][0],t[0][1],t[1][0],t[1][1]):P,A()):_},w.scale=function(t){return arguments.length?(c=+t,T()):c},w.translate=function(t){return arguments.length?(u=+t[0],h=+t[1],T()):[u,h]},w.center=function(t){return arguments.length?(f=t[0]%360*Ct,p=t[1]%360*Ct,T()):[f*Lt,p*Lt]},w.rotate=function(t){return arguments.length?(d=t[0]%360*Ct,g=t[1]%360*Ct,v=t.length>2?t[2]%360*Ct:0,T()):[d*Lt,g*Lt,v*Lt]},t.rebind(w,l,\"precision\"),function(){return r=e.apply(this,arguments),w.invert=r.invert&&k,T()}}function Ln(t){return Sn(t,function(e,r){t.point(e*Ct,r*Ct)})}function Pn(t,e){return[t,e]}function On(t,e){return[t>At?t-Mt:t<-At?t+Mt:t,e]}function zn(t,e,r){return t?e||r?Gr(Dn(t),Rn(e,r)):Dn(t):e||r?Rn(e,r):On}function In(t){return function(e,r){return[(e+=t)>At?e-Mt:e<-At?e+Mt:e,r]}}function Dn(t){var e=In(t);return e.invert=In(-t),e}function Rn(t,e){var r=Math.cos(t),n=Math.sin(t),i=Math.cos(e),a=Math.sin(e);function o(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*r+s*n;return[Math.atan2(l*i-u*a,s*r-c*n),It(u*i+l*a)]}return o.invert=function(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*i-l*a;return[Math.atan2(l*i+c*a,s*r+u*n),It(u*r-s*n)]},o}function Fn(t,e){var r=Math.cos(t),n=Math.sin(t);return function(i,a,o,s){var l=o*e;null!=i?(i=Bn(r,i),a=Bn(r,a),(o>0?i<a:i>a)&&(i+=o*Mt)):(i=t+o*Mt,a=t-.5*l);for(var c,u=i;o>0?u>a:u<a;u-=l)s.point((c=Fr([r,-n*Math.cos(u),-n*Math.sin(u)]))[0],c[1])}}function Bn(t,e){var r=Pr(e);r[0]-=t,Rr(r);var n=zt(-r[1]);return((-r[2]<0?-n:n)+2*Math.PI-kt)%(2*Math.PI)}function Nn(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map(function(e){return[t,e]})}}function jn(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map(function(e){return[e,t]})}}function Un(t){return t.source}function Vn(t){return t.target}t.geo.path=function(){var e,r,n,i,a,o=4.5;function s(e){return e&&(\"function\"==typeof o&&i.pointRadius(+o.apply(this,arguments)),a&&a.valid||(a=n(i)),t.geo.stream(e,a)),i.result()}function l(){return a=null,s}return s.area=function(e){return sn=0,t.geo.stream(e,n(pn)),sn},s.centroid=function(e){return xr=br=_r=wr=kr=Tr=Ar=Mr=Sr=0,t.geo.stream(e,n(xn)),Sr?[Ar/Sr,Mr/Sr]:Tr?[wr/Tr,kr/Tr]:_r?[xr/_r,br/_r]:[NaN,NaN]},s.bounds=function(e){return hn=fn=-(cn=un=1/0),t.geo.stream(e,n(gn)),[[cn,un],[hn,fn]]},s.projection=function(t){return arguments.length?(n=(e=t)?t.stream||(r=t,i=An(function(t,e){return r([t*Lt,e*Lt])}),function(t){return Ln(i(t))}):P,l()):e;var r,i},s.context=function(t){return arguments.length?(i=null==(r=t)?new vn:new Tn(t),\"function\"!=typeof o&&i.pointRadius(o),l()):r},s.pointRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:(i.pointRadius(+t),+t),s):o},s.projection(t.geo.albersUsa()).context(null)},t.geo.transform=function(t){return{stream:function(e){var r=new Mn(e);for(var n in t)r[n]=t[n];return r}}},Mn.prototype={point:function(t,e){this.stream.point(t,e)},sphere:function(){this.stream.sphere()},lineStart:function(){this.stream.lineStart()},lineEnd:function(){this.stream.lineEnd()},polygonStart:function(){this.stream.polygonStart()},polygonEnd:function(){this.stream.polygonEnd()}},t.geo.projection=En,t.geo.projectionMutator=Cn,(t.geo.equirectangular=function(){return En(Pn)}).raw=Pn.invert=Pn,t.geo.rotation=function(t){function e(e){return(e=t(e[0]*Ct,e[1]*Ct))[0]*=Lt,e[1]*=Lt,e}return t=zn(t[0]%360*Ct,t[1]*Ct,t.length>2?t[2]*Ct:0),e.invert=function(e){return(e=t.invert(e[0]*Ct,e[1]*Ct))[0]*=Lt,e[1]*=Lt,e},e},On.invert=Pn,t.geo.circle=function(){var t,e,r=[0,0],n=6;function i(){var t=\"function\"==typeof r?r.apply(this,arguments):r,n=zn(-t[0]*Ct,-t[1]*Ct,0).invert,i=[];return e(null,null,1,{point:function(t,e){i.push(t=n(t,e)),t[0]*=Lt,t[1]*=Lt}}),{type:\"Polygon\",coordinates:[i]}}return i.origin=function(t){return arguments.length?(r=t,i):r},i.angle=function(r){return arguments.length?(e=Fn((t=+r)*Ct,n*Ct),i):t},i.precision=function(r){return arguments.length?(e=Fn(t*Ct,(n=+r)*Ct),i):n},i.angle(90)},t.geo.distance=function(t,e){var r,n=(e[0]-t[0])*Ct,i=t[1]*Ct,a=e[1]*Ct,o=Math.sin(n),s=Math.cos(n),l=Math.sin(i),c=Math.cos(i),u=Math.sin(a),h=Math.cos(a);return Math.atan2(Math.sqrt((r=h*o)*r+(r=c*u-l*h*s)*r),l*u+c*h*s)},t.geo.graticule=function(){var e,r,n,i,a,o,s,l,c,u,h,f,p=10,d=p,g=90,v=360,m=2.5;function x(){return{type:\"MultiLineString\",coordinates:b()}}function b(){return t.range(Math.ceil(i/g)*g,n,g).map(h).concat(t.range(Math.ceil(l/v)*v,s,v).map(f)).concat(t.range(Math.ceil(r/p)*p,e,p).filter(function(t){return y(t%g)>kt}).map(c)).concat(t.range(Math.ceil(o/d)*d,a,d).filter(function(t){return y(t%v)>kt}).map(u))}return x.lines=function(){return b().map(function(t){return{type:\"LineString\",coordinates:t}})},x.outline=function(){return{type:\"Polygon\",coordinates:[h(i).concat(f(s).slice(1),h(n).reverse().slice(1),f(l).reverse().slice(1))]}},x.extent=function(t){return arguments.length?x.majorExtent(t).minorExtent(t):x.minorExtent()},x.majorExtent=function(t){return arguments.length?(i=+t[0][0],n=+t[1][0],l=+t[0][1],s=+t[1][1],i>n&&(t=i,i=n,n=t),l>s&&(t=l,l=s,s=t),x.precision(m)):[[i,l],[n,s]]},x.minorExtent=function(t){return arguments.length?(r=+t[0][0],e=+t[1][0],o=+t[0][1],a=+t[1][1],r>e&&(t=r,r=e,e=t),o>a&&(t=o,o=a,a=t),x.precision(m)):[[r,o],[e,a]]},x.step=function(t){return arguments.length?x.majorStep(t).minorStep(t):x.minorStep()},x.majorStep=function(t){return arguments.length?(g=+t[0],v=+t[1],x):[g,v]},x.minorStep=function(t){return arguments.length?(p=+t[0],d=+t[1],x):[p,d]},x.precision=function(t){return arguments.length?(m=+t,c=Nn(o,a,90),u=jn(r,e,m),h=Nn(l,s,90),f=jn(i,n,m),x):m},x.majorExtent([[-180,-90+kt],[180,90-kt]]).minorExtent([[-180,-80-kt],[180,80+kt]])},t.geo.greatArc=function(){var e,r,n=Un,i=Vn;function a(){return{type:\"LineString\",coordinates:[e||n.apply(this,arguments),r||i.apply(this,arguments)]}}return a.distance=function(){return t.geo.distance(e||n.apply(this,arguments),r||i.apply(this,arguments))},a.source=function(t){return arguments.length?(n=t,e=\"function\"==typeof t?null:t,a):n},a.target=function(t){return arguments.length?(i=t,r=\"function\"==typeof t?null:t,a):i},a.precision=function(){return arguments.length?a:0},a},t.geo.interpolate=function(t,e){return r=t[0]*Ct,n=t[1]*Ct,i=e[0]*Ct,a=e[1]*Ct,o=Math.cos(n),s=Math.sin(n),l=Math.cos(a),c=Math.sin(a),u=o*Math.cos(r),h=o*Math.sin(r),f=l*Math.cos(i),p=l*Math.sin(i),d=2*Math.asin(Math.sqrt(Rt(a-n)+o*l*Rt(i-r))),g=1/Math.sin(d),(v=d?function(t){var e=Math.sin(t*=d)*g,r=Math.sin(d-t)*g,n=r*u+e*f,i=r*h+e*p,a=r*s+e*c;return[Math.atan2(i,n)*Lt,Math.atan2(a,Math.sqrt(n*n+i*i))*Lt]}:function(){return[r*Lt,n*Lt]}).distance=d,v;var r,n,i,a,o,s,l,c,u,h,f,p,d,g,v},t.geo.length=function(e){return yn=0,t.geo.stream(e,qn),yn};var qn={sphere:D,point:D,lineStart:function(){var t,e,r;function n(n,i){var a=Math.sin(i*=Ct),o=Math.cos(i),s=y((n*=Ct)-t),l=Math.cos(s);yn+=Math.atan2(Math.sqrt((s=o*Math.sin(s))*s+(s=r*a-e*o*l)*s),e*a+r*o*l),t=n,e=a,r=o}qn.point=function(i,a){t=i*Ct,e=Math.sin(a*=Ct),r=Math.cos(a),qn.point=n},qn.lineEnd=function(){qn.point=qn.lineEnd=D}},lineEnd:D,polygonStart:D,polygonEnd:D};function Hn(t,e){function r(e,r){var n=Math.cos(e),i=Math.cos(r),a=t(n*i);return[a*i*Math.sin(e),a*Math.sin(r)]}return r.invert=function(t,r){var n=Math.sqrt(t*t+r*r),i=e(n),a=Math.sin(i),o=Math.cos(i);return[Math.atan2(t*a,n*o),Math.asin(n&&r*a/n)]},r}var Gn=Hn(function(t){return Math.sqrt(2/(1+t))},function(t){return 2*Math.asin(t/2)});(t.geo.azimuthalEqualArea=function(){return En(Gn)}).raw=Gn;var Yn=Hn(function(t){var e=Math.acos(t);return e&&e/Math.sin(e)},P);function Wn(t,e){var r=Math.cos(t),n=function(t){return Math.tan(At/4+t/2)},i=t===e?Math.sin(t):Math.log(r/Math.cos(e))/Math.log(n(e)/n(t)),a=r*Math.pow(n(t),i)/i;if(!i)return Jn;function o(t,e){a>0?e<-Et+kt&&(e=-Et+kt):e>Et-kt&&(e=Et-kt);var r=a/Math.pow(n(e),i);return[r*Math.sin(i*t),a-r*Math.cos(i*t)]}return o.invert=function(t,e){var r=a-e,n=Pt(i)*Math.sqrt(t*t+r*r);return[Math.atan2(t,r)/i,2*Math.atan(Math.pow(a/n,1/i))-Et]},o}function Xn(t,e){var r=Math.cos(t),n=t===e?Math.sin(t):(r-Math.cos(e))/(e-t),i=r/n+t;if(y(n)<kt)return Pn;function a(t,e){var r=i-e;return[r*Math.sin(n*t),i-r*Math.cos(n*t)]}return a.invert=function(t,e){var r=i-e;return[Math.atan2(t,r)/n,i-Pt(n)*Math.sqrt(t*t+r*r)]},a}(t.geo.azimuthalEquidistant=function(){return En(Yn)}).raw=Yn,(t.geo.conicConformal=function(){return an(Wn)}).raw=Wn,(t.geo.conicEquidistant=function(){return an(Xn)}).raw=Xn;var Zn=Hn(function(t){return 1/t},Math.atan);function Jn(t,e){return[t,Math.log(Math.tan(At/4+e/2))]}function Kn(t){var e,r=En(t),n=r.scale,i=r.translate,a=r.clipExtent;return r.scale=function(){var t=n.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.translate=function(){var t=i.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.clipExtent=function(t){var o=a.apply(r,arguments);if(o===r){if(e=null==t){var s=At*n(),l=i();a([[l[0]-s,l[1]-s],[l[0]+s,l[1]+s]])}}else e&&(o=null);return o},r.clipExtent(null)}(t.geo.gnomonic=function(){return En(Zn)}).raw=Zn,Jn.invert=function(t,e){return[t,2*Math.atan(Math.exp(e))-Et]},(t.geo.mercator=function(){return Kn(Jn)}).raw=Jn;var $n=Hn(function(){return 1},Math.asin);(t.geo.orthographic=function(){return En($n)}).raw=$n;var Qn=Hn(function(t){return 1/(1+t)},function(t){return 2*Math.atan(t)});function ti(t,e){return[Math.log(Math.tan(At/4+e/2)),-t]}function ei(t){return t[0]}function ri(t){return t[1]}function ni(t){for(var e=t.length,r=[0,1],n=2,i=2;i<e;i++){for(;n>1&&Ot(t[r[n-2]],t[r[n-1]],t[i])<=0;)--n;r[n++]=i}return r.slice(0,n)}function ii(t,e){return t[0]-e[0]||t[1]-e[1]}(t.geo.stereographic=function(){return En(Qn)}).raw=Qn,ti.invert=function(t,e){return[-e,2*Math.atan(Math.exp(t))-Et]},(t.geo.transverseMercator=function(){var t=Kn(ti),e=t.center,r=t.rotate;return t.center=function(t){return t?e([-t[1],t[0]]):[(t=e())[1],-t[0]]},t.rotate=function(t){return t?r([t[0],t[1],t.length>2?t[2]+90:90]):[(t=r())[0],t[1],t[2]-90]},r([0,0,90])}).raw=ti,t.geom={},t.geom.hull=function(t){var e=ei,r=ri;if(arguments.length)return n(t);function n(t){if(t.length<3)return[];var n,i=ve(e),a=ve(r),o=t.length,s=[],l=[];for(n=0;n<o;n++)s.push([+i.call(this,t[n],n),+a.call(this,t[n],n),n]);for(s.sort(ii),n=0;n<o;n++)l.push([s[n][0],-s[n][1]]);var c=ni(s),u=ni(l),h=u[0]===c[0],f=u[u.length-1]===c[c.length-1],p=[];for(n=c.length-1;n>=0;--n)p.push(t[s[c[n]][2]]);for(n=+h;n<u.length-f;++n)p.push(t[s[u[n]][2]]);return p}return n.x=function(t){return arguments.length?(e=t,n):e},n.y=function(t){return arguments.length?(r=t,n):r},n},t.geom.polygon=function(t){return V(t,ai),t};var ai=t.geom.polygon.prototype=[];function oi(t,e,r){return(r[0]-e[0])*(t[1]-e[1])<(r[1]-e[1])*(t[0]-e[0])}function si(t,e,r,n){var i=t[0],a=r[0],o=e[0]-i,s=n[0]-a,l=t[1],c=r[1],u=e[1]-l,h=n[1]-c,f=(s*(l-c)-h*(i-a))/(h*o-s*u);return[i+f*o,l+f*u]}function li(t){var e=t[0],r=t[t.length-1];return!(e[0]-r[0]||e[1]-r[1])}ai.area=function(){for(var t,e=-1,r=this.length,n=this[r-1],i=0;++e<r;)t=n,n=this[e],i+=t[1]*n[0]-t[0]*n[1];return.5*i},ai.centroid=function(t){var e,r,n=-1,i=this.length,a=0,o=0,s=this[i-1];for(arguments.length||(t=-1/(6*this.area()));++n<i;)e=s,s=this[n],r=e[0]*s[1]-s[0]*e[1],a+=(e[0]+s[0])*r,o+=(e[1]+s[1])*r;return[a*t,o*t]},ai.clip=function(t){for(var e,r,n,i,a,o,s=li(t),l=-1,c=this.length-li(this),u=this[c-1];++l<c;){for(e=t.slice(),t.length=0,i=this[l],a=e[(n=e.length-s)-1],r=-1;++r<n;)oi(o=e[r],u,i)?(oi(a,u,i)||t.push(si(a,o,u,i)),t.push(o)):oi(a,u,i)&&t.push(si(a,o,u,i)),a=o;s&&t.push(t[0]),u=i}return t};var ci,ui,hi,fi,pi,di=[],gi=[];function vi(){Ii(this),this.edge=this.site=this.circle=null}function mi(t){var e=di.pop()||new vi;return e.site=t,e}function yi(t){Si(t),hi.remove(t),di.push(t),Ii(t)}function xi(t){var e=t.circle,r=e.x,n=e.cy,i={x:r,y:n},a=t.P,o=t.N,s=[t];yi(t);for(var l=a;l.circle&&y(r-l.circle.x)<kt&&y(n-l.circle.cy)<kt;)a=l.P,s.unshift(l),yi(l),l=a;s.unshift(l),Si(l);for(var c=o;c.circle&&y(r-c.circle.x)<kt&&y(n-c.circle.cy)<kt;)o=c.N,s.push(c),yi(c),c=o;s.push(c),Si(c);var u,h=s.length;for(u=1;u<h;++u)c=s[u],l=s[u-1],Pi(c.edge,l.site,c.site,i);l=s[0],(c=s[h-1]).edge=Li(l.site,c.site,null,i),Mi(l),Mi(c)}function bi(t){for(var e,r,n,i,a=t.x,o=t.y,s=hi._;s;)if((n=_i(s,o)-a)>kt)s=s.L;else{if(!((i=a-wi(s,o))>kt)){n>-kt?(e=s.P,r=s):i>-kt?(e=s,r=s.N):e=r=s;break}if(!s.R){e=s;break}s=s.R}var l=mi(t);if(hi.insert(e,l),e||r){if(e===r)return Si(e),r=mi(e.site),hi.insert(l,r),l.edge=r.edge=Li(e.site,l.site),Mi(e),void Mi(r);if(r){Si(e),Si(r);var c=e.site,u=c.x,h=c.y,f=t.x-u,p=t.y-h,d=r.site,g=d.x-u,v=d.y-h,m=2*(f*v-p*g),y=f*f+p*p,x=g*g+v*v,b={x:(v*y-p*x)/m+u,y:(f*x-g*y)/m+h};Pi(r.edge,c,d,b),l.edge=Li(c,t,null,b),r.edge=Li(t,d,null,b),Mi(e),Mi(r)}else l.edge=Li(e.site,l.site)}}function _i(t,e){var r=t.site,n=r.x,i=r.y,a=i-e;if(!a)return n;var o=t.P;if(!o)return-1/0;var s=(r=o.site).x,l=r.y,c=l-e;if(!c)return s;var u=s-n,h=1/a-1/c,f=u/c;return h?(-f+Math.sqrt(f*f-2*h*(u*u/(-2*c)-l+c/2+i-a/2)))/h+n:(n+s)/2}function wi(t,e){var r=t.N;if(r)return _i(r,e);var n=t.site;return n.y===e?n.x:1/0}function ki(t){this.site=t,this.edges=[]}function Ti(t,e){return e.angle-t.angle}function Ai(){Ii(this),this.x=this.y=this.arc=this.site=this.cy=null}function Mi(t){var e=t.P,r=t.N;if(e&&r){var n=e.site,i=t.site,a=r.site;if(n!==a){var o=i.x,s=i.y,l=n.x-o,c=n.y-s,u=a.x-o,h=2*(l*(v=a.y-s)-c*u);if(!(h>=-Tt)){var f=l*l+c*c,p=u*u+v*v,d=(v*f-c*p)/h,g=(l*p-u*f)/h,v=g+s,m=gi.pop()||new Ai;m.arc=t,m.site=i,m.x=d+o,m.y=v+Math.sqrt(d*d+g*g),m.cy=v,t.circle=m;for(var y=null,x=pi._;x;)if(m.y<x.y||m.y===x.y&&m.x<=x.x){if(!x.L){y=x.P;break}x=x.L}else{if(!x.R){y=x;break}x=x.R}pi.insert(y,m),y||(fi=m)}}}}function Si(t){var e=t.circle;e&&(e.P||(fi=e.N),pi.remove(e),gi.push(e),Ii(e),t.circle=null)}function Ei(t,e){var r=t.b;if(r)return!0;var n,i,a=t.a,o=e[0][0],s=e[1][0],l=e[0][1],c=e[1][1],u=t.l,h=t.r,f=u.x,p=u.y,d=h.x,g=h.y,v=(f+d)/2,m=(p+g)/2;if(g===p){if(v<o||v>=s)return;if(f>d){if(a){if(a.y>=c)return}else a={x:v,y:l};r={x:v,y:c}}else{if(a){if(a.y<l)return}else a={x:v,y:c};r={x:v,y:l}}}else if(i=m-(n=(f-d)/(g-p))*v,n<-1||n>1)if(f>d){if(a){if(a.y>=c)return}else a={x:(l-i)/n,y:l};r={x:(c-i)/n,y:c}}else{if(a){if(a.y<l)return}else a={x:(c-i)/n,y:c};r={x:(l-i)/n,y:l}}else if(p<g){if(a){if(a.x>=s)return}else a={x:o,y:n*o+i};r={x:s,y:n*s+i}}else{if(a){if(a.x<o)return}else a={x:s,y:n*s+i};r={x:o,y:n*o+i}}return t.a=a,t.b=r,!0}function Ci(t,e){this.l=t,this.r=e,this.a=this.b=null}function Li(t,e,r,n){var i=new Ci(t,e);return ci.push(i),r&&Pi(i,t,e,r),n&&Pi(i,e,t,n),ui[t.i].edges.push(new Oi(i,t,e)),ui[e.i].edges.push(new Oi(i,e,t)),i}function Pi(t,e,r,n){t.a||t.b?t.l===r?t.b=n:t.a=n:(t.a=n,t.l=e,t.r=r)}function Oi(t,e,r){var n=t.a,i=t.b;this.edge=t,this.site=e,this.angle=r?Math.atan2(r.y-e.y,r.x-e.x):t.l===e?Math.atan2(i.x-n.x,n.y-i.y):Math.atan2(n.x-i.x,i.y-n.y)}function zi(){this._=null}function Ii(t){t.U=t.C=t.L=t.R=t.P=t.N=null}function Di(t,e){var r=e,n=e.R,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.R=n.L,r.R&&(r.R.U=r),n.L=r}function Ri(t,e){var r=e,n=e.L,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.L=n.R,r.L&&(r.L.U=r),n.R=r}function Fi(t){for(;t.L;)t=t.L;return t}function Bi(t,e){var r,n,i,a=t.sort(Ni).pop();for(ci=[],ui=new Array(t.length),hi=new zi,pi=new zi;;)if(i=fi,a&&(!i||a.y<i.y||a.y===i.y&&a.x<i.x))a.x===r&&a.y===n||(ui[a.i]=new ki(a),bi(a),r=a.x,n=a.y),a=t.pop();else{if(!i)break;xi(i.arc)}e&&(function(t){for(var e,r=ci,n=en(t[0][0],t[0][1],t[1][0],t[1][1]),i=r.length;i--;)(!Ei(e=r[i],t)||!n(e)||y(e.a.x-e.b.x)<kt&&y(e.a.y-e.b.y)<kt)&&(e.a=e.b=null,r.splice(i,1))}(e),function(t){for(var e,r,n,i,a,o,s,l,c,u,h=t[0][0],f=t[1][0],p=t[0][1],d=t[1][1],g=ui,v=g.length;v--;)if((a=g[v])&&a.prepare())for(l=(s=a.edges).length,o=0;o<l;)n=(u=s[o].end()).x,i=u.y,e=(c=s[++o%l].start()).x,r=c.y,(y(n-e)>kt||y(i-r)>kt)&&(s.splice(o,0,new Oi((m=a.site,x=u,b=y(n-h)<kt&&d-i>kt?{x:h,y:y(e-h)<kt?r:d}:y(i-d)<kt&&f-n>kt?{x:y(r-d)<kt?e:f,y:d}:y(n-f)<kt&&i-p>kt?{x:f,y:y(e-f)<kt?r:p}:y(i-p)<kt&&n-h>kt?{x:y(r-p)<kt?e:h,y:p}:null,_=void 0,_=new Ci(m,null),_.a=x,_.b=b,ci.push(_),_),a.site,null)),++l);var m,x,b,_}(e));var o={cells:ui,edges:ci};return hi=pi=ci=ui=null,o}function Ni(t,e){return e.y-t.y||e.x-t.x}ki.prototype.prepare=function(){for(var t,e=this.edges,r=e.length;r--;)(t=e[r].edge).b&&t.a||e.splice(r,1);return e.sort(Ti),e.length},Oi.prototype={start:function(){return this.edge.l===this.site?this.edge.a:this.edge.b},end:function(){return this.edge.l===this.site?this.edge.b:this.edge.a}},zi.prototype={insert:function(t,e){var r,n,i;if(t){if(e.P=t,e.N=t.N,t.N&&(t.N.P=e),t.N=e,t.R){for(t=t.R;t.L;)t=t.L;t.L=e}else t.R=e;r=t}else this._?(t=Fi(this._),e.P=null,e.N=t,t.P=t.L=e,r=t):(e.P=e.N=null,this._=e,r=null);for(e.L=e.R=null,e.U=r,e.C=!0,t=e;r&&r.C;)r===(n=r.U).L?(i=n.R)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.R&&(Di(this,r),r=(t=r).U),r.C=!1,n.C=!0,Ri(this,n)):(i=n.L)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.L&&(Ri(this,r),r=(t=r).U),r.C=!1,n.C=!0,Di(this,n)),r=t.U;this._.C=!1},remove:function(t){t.N&&(t.N.P=t.P),t.P&&(t.P.N=t.N),t.N=t.P=null;var e,r,n,i=t.U,a=t.L,o=t.R;if(r=a?o?Fi(o):a:o,i?i.L===t?i.L=r:i.R=r:this._=r,a&&o?(n=r.C,r.C=t.C,r.L=a,a.U=r,r!==o?(i=r.U,r.U=t.U,t=r.R,i.L=t,r.R=o,o.U=r):(r.U=i,i=r,t=r.R)):(n=t.C,t=r),t&&(t.U=i),!n)if(t&&t.C)t.C=!1;else{do{if(t===this._)break;if(t===i.L){if((e=i.R).C&&(e.C=!1,i.C=!0,Di(this,i),e=i.R),e.L&&e.L.C||e.R&&e.R.C){e.R&&e.R.C||(e.L.C=!1,e.C=!0,Ri(this,e),e=i.R),e.C=i.C,i.C=e.R.C=!1,Di(this,i),t=this._;break}}else if((e=i.L).C&&(e.C=!1,i.C=!0,Ri(this,i),e=i.L),e.L&&e.L.C||e.R&&e.R.C){e.L&&e.L.C||(e.R.C=!1,e.C=!0,Di(this,e),e=i.L),e.C=i.C,i.C=e.L.C=!1,Ri(this,i),t=this._;break}e.C=!0,t=i,i=i.U}while(!t.C);t&&(t.C=!1)}}},t.geom.voronoi=function(t){var e=ei,r=ri,n=e,i=r,a=ji;if(t)return o(t);function o(t){var e=new Array(t.length),r=a[0][0],n=a[0][1],i=a[1][0],o=a[1][1];return Bi(s(t),a).cells.forEach(function(a,s){var l=a.edges,c=a.site;(e[s]=l.length?l.map(function(t){var e=t.start();return[e.x,e.y]}):c.x>=r&&c.x<=i&&c.y>=n&&c.y<=o?[[r,o],[i,o],[i,n],[r,n]]:[]).point=t[s]}),e}function s(t){return t.map(function(t,e){return{x:Math.round(n(t,e)/kt)*kt,y:Math.round(i(t,e)/kt)*kt,i:e}})}return o.links=function(t){return Bi(s(t)).edges.filter(function(t){return t.l&&t.r}).map(function(e){return{source:t[e.l.i],target:t[e.r.i]}})},o.triangles=function(t){var e=[];return Bi(s(t)).cells.forEach(function(r,n){for(var i,a,o,s,l=r.site,c=r.edges.sort(Ti),u=-1,h=c.length,f=c[h-1].edge,p=f.l===l?f.r:f.l;++u<h;)f,i=p,p=(f=c[u].edge).l===l?f.r:f.l,n<i.i&&n<p.i&&(o=i,s=p,((a=l).x-s.x)*(o.y-a.y)-(a.x-o.x)*(s.y-a.y)<0)&&e.push([t[n],t[i.i],t[p.i]])}),e},o.x=function(t){return arguments.length?(n=ve(e=t),o):e},o.y=function(t){return arguments.length?(i=ve(r=t),o):r},o.clipExtent=function(t){return arguments.length?(a=null==t?ji:t,o):a===ji?null:a},o.size=function(t){return arguments.length?o.clipExtent(t&&[[0,0],t]):a===ji?null:a&&a[1]},o};var ji=[[-1e6,-1e6],[1e6,1e6]];function Ui(t){return t.x}function Vi(t){return t.y}function qi(e,r){e=t.rgb(e),r=t.rgb(r);var n=e.r,i=e.g,a=e.b,o=r.r-n,s=r.g-i,l=r.b-a;return function(t){return\"#\"+ce(Math.round(n+o*t))+ce(Math.round(i+s*t))+ce(Math.round(a+l*t))}}function Hi(t,e){var r,n={},i={};for(r in t)r in e?n[r]=Zi(t[r],e[r]):i[r]=t[r];for(r in e)r in t||(i[r]=e[r]);return function(t){for(r in n)i[r]=n[r](t);return i}}function Gi(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function Yi(t,e){var r,n,i,a=Wi.lastIndex=Xi.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=Wi.exec(t))&&(n=Xi.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:Gi(r,n)})),a=Xi.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?(e=l[0].x,function(t){return e(t)+\"\"}):function(){return e}:(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}t.geom.delaunay=function(e){return t.geom.voronoi().triangles(e)},t.geom.quadtree=function(t,e,r,n,i){var a,o=ei,s=ri;if(a=arguments.length)return o=Ui,s=Vi,3===a&&(i=r,n=e,r=e=0),l(t);function l(t){var l,c,u,h,f,p,d,g,v,m=ve(o),x=ve(s);if(null!=e)p=e,d=r,g=n,v=i;else if(g=v=-(p=d=1/0),c=[],u=[],f=t.length,a)for(h=0;h<f;++h)(l=t[h]).x<p&&(p=l.x),l.y<d&&(d=l.y),l.x>g&&(g=l.x),l.y>v&&(v=l.y),c.push(l.x),u.push(l.y);else for(h=0;h<f;++h){var b=+m(l=t[h],h),_=+x(l,h);b<p&&(p=b),_<d&&(d=_),b>g&&(g=b),_>v&&(v=_),c.push(b),u.push(_)}var w=g-p,k=v-d;function T(t,e,r,n,i,a,o,s){if(!isNaN(r)&&!isNaN(n))if(t.leaf){var l=t.x,c=t.y;if(null!=l)if(y(l-r)+y(c-n)<.01)A(t,e,r,n,i,a,o,s);else{var u=t.point;t.x=t.y=t.point=null,A(t,u,l,c,i,a,o,s),A(t,e,r,n,i,a,o,s)}else t.x=r,t.y=n,t.point=e}else A(t,e,r,n,i,a,o,s)}function A(t,e,r,n,i,a,o,s){var l=.5*(i+o),c=.5*(a+s),u=r>=l,h=n>=c,f=h<<1|u;t.leaf=!1,u?i=l:o=l,h?a=c:s=c,T(t=t.nodes[f]||(t.nodes[f]={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){T(M,t,+m(t,++h),+x(t,h),p,d,g,v)}}),e,r,n,i,a,o,s)}w>k?v=d+w:g=p+k;var M={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){T(M,t,+m(t,++h),+x(t,h),p,d,g,v)}};if(M.visit=function(t){!function t(e,r,n,i,a,o){if(!e(r,n,i,a,o)){var s=.5*(n+a),l=.5*(i+o),c=r.nodes;c[0]&&t(e,c[0],n,i,s,l),c[1]&&t(e,c[1],s,i,a,l),c[2]&&t(e,c[2],n,l,s,o),c[3]&&t(e,c[3],s,l,a,o)}}(t,M,p,d,g,v)},M.find=function(t){return function(t,e,r,n,i,a,o){var s,l=1/0;return function t(c,u,h,f,p){if(!(u>a||h>o||f<n||p<i)){if(d=c.point){var d,g=e-c.x,v=r-c.y,m=g*g+v*v;if(m<l){var y=Math.sqrt(l=m);n=e-y,i=r-y,a=e+y,o=r+y,s=d}}for(var x=c.nodes,b=.5*(u+f),_=.5*(h+p),w=(r>=_)<<1|e>=b,k=w+4;w<k;++w)if(c=x[3&w])switch(3&w){case 0:t(c,u,h,b,_);break;case 1:t(c,b,h,f,_);break;case 2:t(c,u,_,b,p);break;case 3:t(c,b,_,f,p)}}}(t,n,i,a,o),s}(M,t[0],t[1],p,d,g,v)},h=-1,null==e){for(;++h<f;)T(M,t[h],c[h],u[h],p,d,g,v);--h}else t.forEach(M.add);return c=u=t=l=null,M}return l.x=function(t){return arguments.length?(o=t,l):o},l.y=function(t){return arguments.length?(s=t,l):s},l.extent=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=+t[0][0],r=+t[0][1],n=+t[1][0],i=+t[1][1]),l):null==e?null:[[e,r],[n,i]]},l.size=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=r=0,n=+t[0],i=+t[1]),l):null==e?null:[n-e,i-r]},l},t.interpolateRgb=qi,t.interpolateObject=Hi,t.interpolateNumber=Gi,t.interpolateString=Yi;var Wi=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,Xi=new RegExp(Wi.source,\"g\");function Zi(e,r){for(var n,i=t.interpolators.length;--i>=0&&!(n=t.interpolators[i](e,r)););return n}function Ji(t,e){var r,n=[],i=[],a=t.length,o=e.length,s=Math.min(t.length,e.length);for(r=0;r<s;++r)n.push(Zi(t[r],e[r]));for(;r<a;++r)i[r]=t[r];for(;r<o;++r)i[r]=e[r];return function(t){for(r=0;r<s;++r)i[r]=n[r](t);return i}}t.interpolate=Zi,t.interpolators=[function(t,e){var r=typeof e;return(\"string\"===r?ge.has(e.toLowerCase())||/^(#|rgb\\(|hsl\\()/i.test(e)?qi:Yi:e instanceof Ut?qi:Array.isArray(e)?Ji:\"object\"===r&&isNaN(e)?Hi:Gi)(t,e)}],t.interpolateArray=Ji;var Ki=function(){return P},$i=t.map({linear:Ki,poly:function(t){return function(e){return Math.pow(e,t)}},quad:function(){return ra},cubic:function(){return na},sin:function(){return aa},exp:function(){return oa},circle:function(){return sa},elastic:function(t,e){var r;arguments.length<2&&(e=.45);arguments.length?r=e/Mt*Math.asin(1/t):(t=1,r=e/4);return function(n){return 1+t*Math.pow(2,-10*n)*Math.sin((n-r)*Mt/e)}},back:function(t){t||(t=1.70158);return function(e){return e*e*((t+1)*e-t)}},bounce:function(){return la}}),Qi=t.map({in:P,out:ta,\"in-out\":ea,\"out-in\":function(t){return ea(ta(t))}});function ta(t){return function(e){return 1-t(1-e)}}function ea(t){return function(e){return.5*(e<.5?t(2*e):2-t(2-2*e))}}function ra(t){return t*t}function na(t){return t*t*t}function ia(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}function aa(t){return 1-Math.cos(t*Et)}function oa(t){return Math.pow(2,10*(t-1))}function sa(t){return 1-Math.sqrt(1-t*t)}function la(t){return t<1/2.75?7.5625*t*t:t<2/2.75?7.5625*(t-=1.5/2.75)*t+.75:t<2.5/2.75?7.5625*(t-=2.25/2.75)*t+.9375:7.5625*(t-=2.625/2.75)*t+.984375}function ca(t,e){return e-=t,function(r){return Math.round(t+e*r)}}function ua(t){var e,r,n,i=[t.a,t.b],a=[t.c,t.d],o=fa(i),s=ha(i,a),l=fa(((e=a)[0]+=(n=-s)*(r=i)[0],e[1]+=n*r[1],e))||0;i[0]*a[1]<a[0]*i[1]&&(i[0]*=-1,i[1]*=-1,o*=-1,s*=-1),this.rotate=(o?Math.atan2(i[1],i[0]):Math.atan2(-a[0],a[1]))*Lt,this.translate=[t.e,t.f],this.scale=[o,l],this.skew=l?Math.atan2(s,l)*Lt:0}function ha(t,e){return t[0]*e[0]+t[1]*e[1]}function fa(t){var e=Math.sqrt(ha(t,t));return e&&(t[0]/=e,t[1]/=e),e}t.ease=function(t){var e,n=t.indexOf(\"-\"),i=n>=0?t.slice(0,n):t,a=n>=0?t.slice(n+1):\"in\";return i=$i.get(i)||Ki,a=Qi.get(a)||P,e=a(i.apply(null,r.call(arguments,1))),function(t){return t<=0?0:t>=1?1:e(t)}},t.interpolateHcl=function(e,r){e=t.hcl(e),r=t.hcl(r);var n=e.h,i=e.c,a=e.l,o=r.h-n,s=r.c-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.c:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Wt(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateHsl=function(e,r){e=t.hsl(e),r=t.hsl(r);var n=e.h,i=e.s,a=e.l,o=r.h-n,s=r.s-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.s:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Ht(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateLab=function(e,r){e=t.lab(e),r=t.lab(r);var n=e.l,i=e.a,a=e.b,o=r.l-n,s=r.a-i,l=r.b-a;return function(t){return te(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateRound=ca,t.transform=function(e){var r=i.createElementNS(t.ns.prefix.svg,\"g\");return(t.transform=function(t){if(null!=t){r.setAttribute(\"transform\",t);var e=r.transform.baseVal.consolidate()}return new ua(e?e.matrix:pa)})(e)},ua.prototype.toString=function(){return\"translate(\"+this.translate+\")rotate(\"+this.rotate+\")skewX(\"+this.skew+\")scale(\"+this.scale+\")\"};var pa={a:1,b:0,c:0,d:1,e:0,f:0};function da(t){return t.length?t.pop()+\",\":\"\"}function ga(e,r){var n=[],i=[];return e=t.transform(e),r=t.transform(r),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(\"translate(\",null,\",\",null,\")\");n.push({i:i-4,x:Gi(t[0],e[0])},{i:i-2,x:Gi(t[1],e[1])})}else(e[0]||e[1])&&r.push(\"translate(\"+e+\")\")}(e.translate,r.translate,n,i),function(t,e,r,n){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),n.push({i:r.push(da(r)+\"rotate(\",null,\")\")-2,x:Gi(t,e)})):e&&r.push(da(r)+\"rotate(\"+e+\")\")}(e.rotate,r.rotate,n,i),function(t,e,r,n){t!==e?n.push({i:r.push(da(r)+\"skewX(\",null,\")\")-2,x:Gi(t,e)}):e&&r.push(da(r)+\"skewX(\"+e+\")\")}(e.skew,r.skew,n,i),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(da(r)+\"scale(\",null,\",\",null,\")\");n.push({i:i-4,x:Gi(t[0],e[0])},{i:i-2,x:Gi(t[1],e[1])})}else 1===e[0]&&1===e[1]||r.push(da(r)+\"scale(\"+e+\")\")}(e.scale,r.scale,n,i),e=r=null,function(t){for(var e,r=-1,a=i.length;++r<a;)n[(e=i[r]).i]=e.x(t);return n.join(\"\")}}function va(t,e){return e=(e-=t=+t)||1/e,function(r){return(r-t)/e}}function ma(t,e){return e=(e-=t=+t)||1/e,function(r){return Math.max(0,Math.min(1,(r-t)/e))}}function ya(t){for(var e=t.source,r=t.target,n=function(t,e){if(t===e)return t;var r=xa(t),n=xa(e),i=r.pop(),a=n.pop(),o=null;for(;i===a;)o=i,i=r.pop(),a=n.pop();return o}(e,r),i=[e];e!==n;)e=e.parent,i.push(e);for(var a=i.length;r!==n;)i.splice(a,0,r),r=r.parent;return i}function xa(t){for(var e=[],r=t.parent;null!=r;)e.push(t),t=r,r=r.parent;return e.push(t),e}function ba(t){t.fixed|=2}function _a(t){t.fixed&=-7}function wa(t){t.fixed|=4,t.px=t.x,t.py=t.y}function ka(t){t.fixed&=-5}t.interpolateTransform=ga,t.layout={},t.layout.bundle=function(){return function(t){for(var e=[],r=-1,n=t.length;++r<n;)e.push(ya(t[r]));return e}},t.layout.chord=function(){var e,r,n,i,a,o,s,l={},c=0;function u(){var l,u,f,p,d,g={},v=[],m=t.range(i),y=[];for(e=[],r=[],l=0,p=-1;++p<i;){for(u=0,d=-1;++d<i;)u+=n[p][d];v.push(u),y.push(t.range(i)),l+=u}for(a&&m.sort(function(t,e){return a(v[t],v[e])}),o&&y.forEach(function(t,e){t.sort(function(t,r){return o(n[e][t],n[e][r])})}),l=(Mt-c*i)/l,u=0,p=-1;++p<i;){for(f=u,d=-1;++d<i;){var x=m[p],b=y[x][d],_=n[x][b],w=u,k=u+=_*l;g[x+\"-\"+b]={index:x,subindex:b,startAngle:w,endAngle:k,value:_}}r[x]={index:x,startAngle:f,endAngle:u,value:v[x]},u+=c}for(p=-1;++p<i;)for(d=p-1;++d<i;){var T=g[p+\"-\"+d],A=g[d+\"-\"+p];(T.value||A.value)&&e.push(T.value<A.value?{source:A,target:T}:{source:T,target:A})}s&&h()}function h(){e.sort(function(t,e){return s((t.source.value+t.target.value)/2,(e.source.value+e.target.value)/2)})}return l.matrix=function(t){return arguments.length?(i=(n=t)&&n.length,e=r=null,l):n},l.padding=function(t){return arguments.length?(c=t,e=r=null,l):c},l.sortGroups=function(t){return arguments.length?(a=t,e=r=null,l):a},l.sortSubgroups=function(t){return arguments.length?(o=t,e=null,l):o},l.sortChords=function(t){return arguments.length?(s=t,e&&h(),l):s},l.chords=function(){return e||u(),e},l.groups=function(){return r||u(),r},l},t.layout.force=function(){var e,r,n,i,a,o,s={},l=t.dispatch(\"start\",\"tick\",\"end\"),c=[1,1],u=.9,h=Ta,f=Aa,p=-30,d=Ma,g=.1,v=.64,m=[],y=[];function x(t){return function(e,r,n,i){if(e.point!==t){var a=e.cx-t.x,o=e.cy-t.y,s=i-r,l=a*a+o*o;if(s*s/v<l){if(l<d){var c=e.charge/l;t.px-=a*c,t.py-=o*c}return!0}if(e.point&&l&&l<d){c=e.pointCharge/l;t.px-=a*c,t.py-=o*c}}return!e.charge}}function b(e){e.px=t.event.x,e.py=t.event.y,s.resume()}return s.tick=function(){if((n*=.99)<.005)return e=null,l.end({type:\"end\",alpha:n=0}),!0;var r,s,h,f,d,v,b,_,w,k=m.length,T=y.length;for(s=0;s<T;++s)f=(h=y[s]).source,(v=(_=(d=h.target).x-f.x)*_+(w=d.y-f.y)*w)&&(_*=v=n*a[s]*((v=Math.sqrt(v))-i[s])/v,w*=v,d.x-=_*(b=f.weight+d.weight?f.weight/(f.weight+d.weight):.5),d.y-=w*b,f.x+=_*(b=1-b),f.y+=w*b);if((b=n*g)&&(_=c[0]/2,w=c[1]/2,s=-1,b))for(;++s<k;)(h=m[s]).x+=(_-h.x)*b,h.y+=(w-h.y)*b;if(p)for(!function t(e,r,n){var i=0,a=0;e.charge=0;if(!e.leaf)for(var o,s=e.nodes,l=s.length,c=-1;++c<l;)null!=(o=s[c])&&(t(o,r,n),e.charge+=o.charge,i+=o.charge*o.cx,a+=o.charge*o.cy);if(e.point){e.leaf||(e.point.x+=Math.random()-.5,e.point.y+=Math.random()-.5);var u=r*n[e.point.index];e.charge+=e.pointCharge=u,i+=u*e.point.x,a+=u*e.point.y}e.cx=i/e.charge;e.cy=a/e.charge}(r=t.geom.quadtree(m),n,o),s=-1;++s<k;)(h=m[s]).fixed||r.visit(x(h));for(s=-1;++s<k;)(h=m[s]).fixed?(h.x=h.px,h.y=h.py):(h.x-=(h.px-(h.px=h.x))*u,h.y-=(h.py-(h.py=h.y))*u);l.tick({type:\"tick\",alpha:n})},s.nodes=function(t){return arguments.length?(m=t,s):m},s.links=function(t){return arguments.length?(y=t,s):y},s.size=function(t){return arguments.length?(c=t,s):c},s.linkDistance=function(t){return arguments.length?(h=\"function\"==typeof t?t:+t,s):h},s.distance=s.linkDistance,s.linkStrength=function(t){return arguments.length?(f=\"function\"==typeof t?t:+t,s):f},s.friction=function(t){return arguments.length?(u=+t,s):u},s.charge=function(t){return arguments.length?(p=\"function\"==typeof t?t:+t,s):p},s.chargeDistance=function(t){return arguments.length?(d=t*t,s):Math.sqrt(d)},s.gravity=function(t){return arguments.length?(g=+t,s):g},s.theta=function(t){return arguments.length?(v=t*t,s):Math.sqrt(v)},s.alpha=function(t){return arguments.length?(t=+t,n?t>0?n=t:(e.c=null,e.t=NaN,e=null,l.end({type:\"end\",alpha:n=0})):t>0&&(l.start({type:\"start\",alpha:n=t}),e=Te(s.tick)),s):n},s.start=function(){var t,e,r,n=m.length,l=y.length,u=c[0],d=c[1];for(t=0;t<n;++t)(r=m[t]).index=t,r.weight=0;for(t=0;t<l;++t)\"number\"==typeof(r=y[t]).source&&(r.source=m[r.source]),\"number\"==typeof r.target&&(r.target=m[r.target]),++r.source.weight,++r.target.weight;for(t=0;t<n;++t)r=m[t],isNaN(r.x)&&(r.x=g(\"x\",u)),isNaN(r.y)&&(r.y=g(\"y\",d)),isNaN(r.px)&&(r.px=r.x),isNaN(r.py)&&(r.py=r.y);if(i=[],\"function\"==typeof h)for(t=0;t<l;++t)i[t]=+h.call(this,y[t],t);else for(t=0;t<l;++t)i[t]=h;if(a=[],\"function\"==typeof f)for(t=0;t<l;++t)a[t]=+f.call(this,y[t],t);else for(t=0;t<l;++t)a[t]=f;if(o=[],\"function\"==typeof p)for(t=0;t<n;++t)o[t]=+p.call(this,m[t],t);else for(t=0;t<n;++t)o[t]=p;function g(r,i){if(!e){for(e=new Array(n),c=0;c<n;++c)e[c]=[];for(c=0;c<l;++c){var a=y[c];e[a.source.index].push(a.target),e[a.target.index].push(a.source)}}for(var o,s=e[t],c=-1,u=s.length;++c<u;)if(!isNaN(o=s[c][r]))return o;return Math.random()*i}return s.resume()},s.resume=function(){return s.alpha(.1)},s.stop=function(){return s.alpha(0)},s.drag=function(){if(r||(r=t.behavior.drag().origin(P).on(\"dragstart.force\",ba).on(\"drag.force\",b).on(\"dragend.force\",_a)),!arguments.length)return r;this.on(\"mouseover.force\",wa).on(\"mouseout.force\",ka).call(r)},t.rebind(s,l,\"on\")};var Ta=20,Aa=1,Ma=1/0;function Sa(e,r){return t.rebind(e,r,\"sort\",\"children\",\"value\"),e.nodes=e,e.links=za,e}function Ea(t,e){for(var r=[t];null!=(t=r.pop());)if(e(t),(i=t.children)&&(n=i.length))for(var n,i;--n>=0;)r.push(i[n])}function Ca(t,e){for(var r=[t],n=[];null!=(t=r.pop());)if(n.push(t),(a=t.children)&&(i=a.length))for(var i,a,o=-1;++o<i;)r.push(a[o]);for(;null!=(t=n.pop());)e(t)}function La(t){return t.children}function Pa(t){return t.value}function Oa(t,e){return e.value-t.value}function za(e){return t.merge(e.map(function(t){return(t.children||[]).map(function(e){return{source:t,target:e}})}))}t.layout.hierarchy=function(){var t=Oa,e=La,r=Pa;function n(i){var a,o=[i],s=[];for(i.depth=0;null!=(a=o.pop());)if(s.push(a),(c=e.call(n,a,a.depth))&&(l=c.length)){for(var l,c,u;--l>=0;)o.push(u=c[l]),u.parent=a,u.depth=a.depth+1;r&&(a.value=0),a.children=c}else r&&(a.value=+r.call(n,a,a.depth)||0),delete a.children;return Ca(i,function(e){var n,i;t&&(n=e.children)&&n.sort(t),r&&(i=e.parent)&&(i.value+=e.value)}),s}return n.sort=function(e){return arguments.length?(t=e,n):t},n.children=function(t){return arguments.length?(e=t,n):e},n.value=function(t){return arguments.length?(r=t,n):r},n.revalue=function(t){return r&&(Ea(t,function(t){t.children&&(t.value=0)}),Ca(t,function(t){var e;t.children||(t.value=+r.call(n,t,t.depth)||0),(e=t.parent)&&(e.value+=t.value)})),t},n},t.layout.partition=function(){var e=t.layout.hierarchy(),r=[1,1];function n(t,n){var i=e.call(this,t,n);return function t(e,r,n,i){var a=e.children;if(e.x=r,e.y=e.depth*i,e.dx=n,e.dy=i,a&&(o=a.length)){var o,s,l,c=-1;for(n=e.value?n/e.value:0;++c<o;)t(s=a[c],r,l=s.value*n,i),r+=l}}(i[0],0,r[0],r[1]/function t(e){var r=e.children,n=0;if(r&&(i=r.length))for(var i,a=-1;++a<i;)n=Math.max(n,t(r[a]));return 1+n}(i[0])),i}return n.size=function(t){return arguments.length?(r=t,n):r},Sa(n,e)},t.layout.pie=function(){var e=Number,r=Ia,n=0,i=Mt,a=0;function o(s){var l,c=s.length,u=s.map(function(t,r){return+e.call(o,t,r)}),h=+(\"function\"==typeof n?n.apply(this,arguments):n),f=(\"function\"==typeof i?i.apply(this,arguments):i)-h,p=Math.min(Math.abs(f)/c,+(\"function\"==typeof a?a.apply(this,arguments):a)),d=p*(f<0?-1:1),g=t.sum(u),v=g?(f-c*d)/g:0,m=t.range(c),y=[];return null!=r&&m.sort(r===Ia?function(t,e){return u[e]-u[t]}:function(t,e){return r(s[t],s[e])}),m.forEach(function(t){y[t]={data:s[t],value:l=u[t],startAngle:h,endAngle:h+=l*v+d,padAngle:p}}),y}return o.value=function(t){return arguments.length?(e=t,o):e},o.sort=function(t){return arguments.length?(r=t,o):r},o.startAngle=function(t){return arguments.length?(n=t,o):n},o.endAngle=function(t){return arguments.length?(i=t,o):i},o.padAngle=function(t){return arguments.length?(a=t,o):a},o};var Ia={};function Da(t){return t.x}function Ra(t){return t.y}function Fa(t,e,r){t.y0=e,t.y=r}t.layout.stack=function(){var e=P,r=ja,n=Ua,i=Fa,a=Da,o=Ra;function s(l,c){if(!(p=l.length))return l;var u=l.map(function(t,r){return e.call(s,t,r)}),h=u.map(function(t){return t.map(function(t,e){return[a.call(s,t,e),o.call(s,t,e)]})}),f=r.call(s,h,c);u=t.permute(u,f),h=t.permute(h,f);var p,d,g,v,m=n.call(s,h,c),y=u[0].length;for(g=0;g<y;++g)for(i.call(s,u[0][g],v=m[g],h[0][g][1]),d=1;d<p;++d)i.call(s,u[d][g],v+=h[d-1][g][1],h[d][g][1]);return l}return s.values=function(t){return arguments.length?(e=t,s):e},s.order=function(t){return arguments.length?(r=\"function\"==typeof t?t:Ba.get(t)||ja,s):r},s.offset=function(t){return arguments.length?(n=\"function\"==typeof t?t:Na.get(t)||Ua,s):n},s.x=function(t){return arguments.length?(a=t,s):a},s.y=function(t){return arguments.length?(o=t,s):o},s.out=function(t){return arguments.length?(i=t,s):i},s};var Ba=t.map({\"inside-out\":function(e){var r,n,i=e.length,a=e.map(Va),o=e.map(qa),s=t.range(i).sort(function(t,e){return a[t]-a[e]}),l=0,c=0,u=[],h=[];for(r=0;r<i;++r)n=s[r],l<c?(l+=o[n],u.push(n)):(c+=o[n],h.push(n));return h.reverse().concat(u)},reverse:function(e){return t.range(e.length).reverse()},default:ja}),Na=t.map({silhouette:function(t){var e,r,n,i=t.length,a=t[0].length,o=[],s=0,l=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];n>s&&(s=n),o.push(n)}for(r=0;r<a;++r)l[r]=(s-o[r])/2;return l},wiggle:function(t){var e,r,n,i,a,o,s,l,c,u=t.length,h=t[0],f=h.length,p=[];for(p[0]=l=c=0,r=1;r<f;++r){for(e=0,i=0;e<u;++e)i+=t[e][r][1];for(e=0,a=0,s=h[r][0]-h[r-1][0];e<u;++e){for(n=0,o=(t[e][r][1]-t[e][r-1][1])/(2*s);n<e;++n)o+=(t[n][r][1]-t[n][r-1][1])/s;a+=o*t[e][r][1]}p[r]=l-=i?a/i*s:0,l<c&&(c=l)}for(r=0;r<f;++r)p[r]-=c;return p},expand:function(t){var e,r,n,i=t.length,a=t[0].length,o=1/i,s=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];if(n)for(e=0;e<i;e++)t[e][r][1]/=n;else for(e=0;e<i;e++)t[e][r][1]=o}for(r=0;r<a;++r)s[r]=0;return s},zero:Ua});function ja(e){return t.range(e.length)}function Ua(t){for(var e=-1,r=t[0].length,n=[];++e<r;)n[e]=0;return n}function Va(t){for(var e,r=1,n=0,i=t[0][1],a=t.length;r<a;++r)(e=t[r][1])>i&&(n=r,i=e);return n}function qa(t){return t.reduce(Ha,0)}function Ha(t,e){return t+e[1]}function Ga(t,e){return Ya(t,Math.ceil(Math.log(e.length)/Math.LN2+1))}function Ya(t,e){for(var r=-1,n=+t[0],i=(t[1]-n)/e,a=[];++r<=e;)a[r]=i*r+n;return a}function Wa(e){return[t.min(e),t.max(e)]}function Xa(t,e){return t.value-e.value}function Za(t,e){var r=t._pack_next;t._pack_next=e,e._pack_prev=t,e._pack_next=r,r._pack_prev=e}function Ja(t,e){t._pack_next=e,e._pack_prev=t}function Ka(t,e){var r=e.x-t.x,n=e.y-t.y,i=t.r+e.r;return.999*i*i>r*r+n*n}function $a(t){if((e=t.children)&&(l=e.length)){var e,r,n,i,a,o,s,l,c=1/0,u=-1/0,h=1/0,f=-1/0;if(e.forEach(Qa),(r=e[0]).x=-r.r,r.y=0,x(r),l>1&&((n=e[1]).x=n.r,n.y=0,x(n),l>2))for(eo(r,n,i=e[2]),x(i),Za(r,i),r._pack_prev=i,Za(i,n),n=r._pack_next,a=3;a<l;a++){eo(r,n,i=e[a]);var p=0,d=1,g=1;for(o=n._pack_next;o!==n;o=o._pack_next,d++)if(Ka(o,i)){p=1;break}if(1==p)for(s=r._pack_prev;s!==o._pack_prev&&!Ka(s,i);s=s._pack_prev,g++);p?(d<g||d==g&&n.r<r.r?Ja(r,n=o):Ja(r=s,n),a--):(Za(r,i),n=i,x(i))}var v=(c+u)/2,m=(h+f)/2,y=0;for(a=0;a<l;a++)(i=e[a]).x-=v,i.y-=m,y=Math.max(y,i.r+Math.sqrt(i.x*i.x+i.y*i.y));t.r=y,e.forEach(to)}function x(t){c=Math.min(t.x-t.r,c),u=Math.max(t.x+t.r,u),h=Math.min(t.y-t.r,h),f=Math.max(t.y+t.r,f)}}function Qa(t){t._pack_next=t._pack_prev=t}function to(t){delete t._pack_next,delete t._pack_prev}function eo(t,e,r){var n=t.r+r.r,i=e.x-t.x,a=e.y-t.y;if(n&&(i||a)){var o=e.r+r.r,s=i*i+a*a,l=.5+((n*=n)-(o*=o))/(2*s),c=Math.sqrt(Math.max(0,2*o*(n+s)-(n-=s)*n-o*o))/(2*s);r.x=t.x+l*i+c*a,r.y=t.y+l*a-c*i}else r.x=t.x+n,r.y=t.y}function ro(t,e){return t.parent==e.parent?1:2}function no(t){var e=t.children;return e.length?e[0]:t.t}function io(t){var e,r=t.children;return(e=r.length)?r[e-1]:t.t}function ao(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function oo(t,e,r){return t.a.parent===e.parent?t.a:r}function so(t){return{x:t.x,y:t.y,dx:t.dx,dy:t.dy}}function lo(t,e){var r=t.x+e[3],n=t.y+e[0],i=t.dx-e[1]-e[3],a=t.dy-e[0]-e[2];return i<0&&(r+=i/2,i=0),a<0&&(n+=a/2,a=0),{x:r,y:n,dx:i,dy:a}}function co(t){var e=t[0],r=t[t.length-1];return e<r?[e,r]:[r,e]}function uo(t){return t.rangeExtent?t.rangeExtent():co(t.range())}function ho(t,e,r,n){var i=r(t[0],t[1]),a=n(e[0],e[1]);return function(t){return a(i(t))}}function fo(t,e){var r,n=0,i=t.length-1,a=t[n],o=t[i];return o<a&&(r=n,n=i,i=r,r=a,a=o,o=r),t[n]=e.floor(a),t[i]=e.ceil(o),t}function po(t){return t?{floor:function(e){return Math.floor(e/t)*t},ceil:function(e){return Math.ceil(e/t)*t}}:go}t.layout.histogram=function(){var e=!0,r=Number,n=Wa,i=Ga;function a(a,o){for(var s,l,c=[],u=a.map(r,this),h=n.call(this,u,o),f=i.call(this,h,u,o),p=(o=-1,u.length),d=f.length-1,g=e?1:1/p;++o<d;)(s=c[o]=[]).dx=f[o+1]-(s.x=f[o]),s.y=0;if(d>0)for(o=-1;++o<p;)(l=u[o])>=h[0]&&l<=h[1]&&((s=c[t.bisect(f,l,1,d)-1]).y+=g,s.push(a[o]));return c}return a.value=function(t){return arguments.length?(r=t,a):r},a.range=function(t){return arguments.length?(n=ve(t),a):n},a.bins=function(t){return arguments.length?(i=\"number\"==typeof t?function(e){return Ya(e,t)}:ve(t),a):i},a.frequency=function(t){return arguments.length?(e=!!t,a):e},a},t.layout.pack=function(){var e,r=t.layout.hierarchy().sort(Xa),n=0,i=[1,1];function a(t,a){var o=r.call(this,t,a),s=o[0],l=i[0],c=i[1],u=null==e?Math.sqrt:\"function\"==typeof e?e:function(){return e};if(s.x=s.y=0,Ca(s,function(t){t.r=+u(t.value)}),Ca(s,$a),n){var h=n*(e?1:Math.max(2*s.r/l,2*s.r/c))/2;Ca(s,function(t){t.r+=h}),Ca(s,$a),Ca(s,function(t){t.r-=h})}return function t(e,r,n,i){var a=e.children;e.x=r+=i*e.x;e.y=n+=i*e.y;e.r*=i;if(a)for(var o=-1,s=a.length;++o<s;)t(a[o],r,n,i)}(s,l/2,c/2,e?1:1/Math.max(2*s.r/l,2*s.r/c)),o}return a.size=function(t){return arguments.length?(i=t,a):i},a.radius=function(t){return arguments.length?(e=null==t||\"function\"==typeof t?t:+t,a):e},a.padding=function(t){return arguments.length?(n=+t,a):n},Sa(a,r)},t.layout.tree=function(){var e=t.layout.hierarchy().sort(null).value(null),r=ro,n=[1,1],i=null;function a(t,a){var c=e.call(this,t,a),u=c[0],h=function(t){var e,r={A:null,children:[t]},n=[r];for(;null!=(e=n.pop());)for(var i,a=e.children,o=0,s=a.length;o<s;++o)n.push((a[o]=i={_:a[o],parent:e,children:(i=a[o].children)&&i.slice()||[],A:null,a:null,z:0,m:0,c:0,s:0,t:null,i:o}).a=i);return r.children[0]}(u);if(Ca(h,o),h.parent.m=-h.z,Ea(h,s),i)Ea(u,l);else{var f=u,p=u,d=u;Ea(u,function(t){t.x<f.x&&(f=t),t.x>p.x&&(p=t),t.depth>d.depth&&(d=t)});var g=r(f,p)/2-f.x,v=n[0]/(p.x+r(p,f)/2+g),m=n[1]/(d.depth||1);Ea(u,function(t){t.x=(t.x+g)*v,t.y=t.depth*m})}return c}function o(t){var e=t.children,n=t.parent.children,i=t.i?n[t.i-1]:null;if(e.length){!function(t){var e,r=0,n=0,i=t.children,a=i.length;for(;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(t);var a=(e[0].z+e[e.length-1].z)/2;i?(t.z=i.z+r(t._,i._),t.m=t.z-a):t.z=a}else i&&(t.z=i.z+r(t._,i._));t.parent.A=function(t,e,n){if(e){for(var i,a=t,o=t,s=e,l=a.parent.children[0],c=a.m,u=o.m,h=s.m,f=l.m;s=io(s),a=no(a),s&&a;)l=no(l),(o=io(o)).a=t,(i=s.z+h-a.z-c+r(s._,a._))>0&&(ao(oo(s,t,n),t,i),c+=i,u+=i),h+=s.m,c+=a.m,f+=l.m,u+=o.m;s&&!io(o)&&(o.t=s,o.m+=h-u),a&&!no(l)&&(l.t=a,l.m+=c-f,n=t)}return n}(t,i,t.parent.A||n[0])}function s(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function l(t){t.x*=n[0],t.y=t.depth*n[1]}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t)?l:null,a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null==(n=t)?null:l,a):i?n:null},Sa(a,e)},t.layout.cluster=function(){var e=t.layout.hierarchy().sort(null).value(null),r=ro,n=[1,1],i=!1;function a(a,o){var s,l=e.call(this,a,o),c=l[0],u=0;Ca(c,function(e){var n=e.children;n&&n.length?(e.x=function(t){return t.reduce(function(t,e){return t+e.x},0)/t.length}(n),e.y=function(e){return 1+t.max(e,function(t){return t.y})}(n)):(e.x=s?u+=r(e,s):0,e.y=0,s=e)});var h=function t(e){var r=e.children;return r&&r.length?t(r[0]):e}(c),f=function t(e){var r,n=e.children;return n&&(r=n.length)?t(n[r-1]):e}(c),p=h.x-r(h,f)/2,d=f.x+r(f,h)/2;return Ca(c,i?function(t){t.x=(t.x-c.x)*n[0],t.y=(c.y-t.y)*n[1]}:function(t){t.x=(t.x-p)/(d-p)*n[0],t.y=(1-(c.y?t.y/c.y:1))*n[1]}),l}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t),a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null!=(n=t),a):i?n:null},Sa(a,e)},t.layout.treemap=function(){var e,r=t.layout.hierarchy(),n=Math.round,i=[1,1],a=null,o=so,s=!1,l=\"squarify\",c=.5*(1+Math.sqrt(5));function u(t,e){for(var r,n,i=-1,a=t.length;++i<a;)n=(r=t[i]).value*(e<0?0:e),r.area=isNaN(n)||n<=0?0:n}function h(t){var e=t.children;if(e&&e.length){var r,n,i,a=o(t),s=[],c=e.slice(),f=1/0,g=\"slice\"===l?a.dx:\"dice\"===l?a.dy:\"slice-dice\"===l?1&t.depth?a.dy:a.dx:Math.min(a.dx,a.dy);for(u(c,a.dx*a.dy/t.value),s.area=0;(i=c.length)>0;)s.push(r=c[i-1]),s.area+=r.area,\"squarify\"!==l||(n=p(s,g))<=f?(c.pop(),f=n):(s.area-=s.pop().area,d(s,g,a,!1),g=Math.min(a.dx,a.dy),s.length=s.area=0,f=1/0);s.length&&(d(s,g,a,!0),s.length=s.area=0),e.forEach(h)}}function f(t){var e=t.children;if(e&&e.length){var r,n=o(t),i=e.slice(),a=[];for(u(i,n.dx*n.dy/t.value),a.area=0;r=i.pop();)a.push(r),a.area+=r.area,null!=r.z&&(d(a,r.z?n.dx:n.dy,n,!i.length),a.length=a.area=0);e.forEach(f)}}function p(t,e){for(var r,n=t.area,i=0,a=1/0,o=-1,s=t.length;++o<s;)(r=t[o].area)&&(r<a&&(a=r),r>i&&(i=r));return e*=e,(n*=n)?Math.max(e*i*c/n,n/(e*a*c)):1/0}function d(t,e,r,i){var a,o=-1,s=t.length,l=r.x,c=r.y,u=e?n(t.area/e):0;if(e==r.dx){for((i||u>r.dy)&&(u=r.dy);++o<s;)(a=t[o]).x=l,a.y=c,a.dy=u,l+=a.dx=Math.min(r.x+r.dx-l,u?n(a.area/u):0);a.z=!0,a.dx+=r.x+r.dx-l,r.y+=u,r.dy-=u}else{for((i||u>r.dx)&&(u=r.dx);++o<s;)(a=t[o]).x=l,a.y=c,a.dx=u,c+=a.dy=Math.min(r.y+r.dy-c,u?n(a.area/u):0);a.z=!1,a.dy+=r.y+r.dy-c,r.x+=u,r.dx-=u}}function g(t){var n=e||r(t),a=n[0];return a.x=a.y=0,a.value?(a.dx=i[0],a.dy=i[1]):a.dx=a.dy=0,e&&r.revalue(a),u([a],a.dx*a.dy/a.value),(e?f:h)(a),s&&(e=n),n}return g.size=function(t){return arguments.length?(i=t,g):i},g.padding=function(t){if(!arguments.length)return a;function e(e){return lo(e,t)}var r;return o=null==(a=t)?so:\"function\"==(r=typeof t)?function(e){var r=t.call(g,e,e.depth);return null==r?so(e):lo(e,\"number\"==typeof r?[r,r,r,r]:r)}:\"number\"===r?(t=[t,t,t,t],e):e,g},g.round=function(t){return arguments.length?(n=t?Math.round:Number,g):n!=Number},g.sticky=function(t){return arguments.length?(s=t,e=null,g):s},g.ratio=function(t){return arguments.length?(c=t,g):c},g.mode=function(t){return arguments.length?(l=t+\"\",g):l},Sa(g,r)},t.random={normal:function(t,e){var r=arguments.length;return r<2&&(e=1),r<1&&(t=0),function(){var r,n,i;do{i=(r=2*Math.random()-1)*r+(n=2*Math.random()-1)*n}while(!i||i>1);return t+e*r*Math.sqrt(-2*Math.log(i)/i)}},logNormal:function(){var e=t.random.normal.apply(t,arguments);return function(){return Math.exp(e())}},bates:function(e){var r=t.random.irwinHall(e);return function(){return r()/e}},irwinHall:function(t){return function(){for(var e=0,r=0;r<t;r++)e+=Math.random();return e}}},t.scale={};var go={floor:P,ceil:P};function vo(e,r,n,i){var a=[],o=[],s=0,l=Math.min(e.length,r.length)-1;for(e[l]<e[0]&&(e=e.slice().reverse(),r=r.slice().reverse());++s<=l;)a.push(n(e[s-1],e[s])),o.push(i(r[s-1],r[s]));return function(r){var n=t.bisect(e,r,1,l)-1;return o[n](a[n](r))}}function mo(e,r){return t.rebind(e,r,\"range\",\"rangeRound\",\"interpolate\",\"clamp\")}function yo(t,e){return fo(t,po(xo(t,e)[2])),fo(t,po(xo(t,e)[2])),t}function xo(t,e){null==e&&(e=10);var r=co(t),n=r[1]-r[0],i=Math.pow(10,Math.floor(Math.log(n/e)/Math.LN10)),a=e/n*i;return a<=.15?i*=10:a<=.35?i*=5:a<=.75&&(i*=2),r[0]=Math.ceil(r[0]/i)*i,r[1]=Math.floor(r[1]/i)*i+.5*i,r[2]=i,r}function bo(e,r){return t.range.apply(t,xo(e,r))}function _o(e,r,n){var i=xo(e,r);if(n){var a=Le.exec(n);if(a.shift(),\"s\"===a[8]){var o=t.formatPrefix(Math.max(y(i[0]),y(i[1])));return a[7]||(a[7]=\".\"+ko(o.scale(i[2]))),a[8]=\"f\",n=t.format(a.join(\"\")),function(t){return n(o.scale(t))+o.symbol}}a[7]||(a[7]=\".\"+function(t,e){var r=ko(e[2]);return t in wo?Math.abs(r-ko(Math.max(y(e[0]),y(e[1]))))+ +(\"e\"!==t):r-2*(\"%\"===t)}(a[8],i)),n=a.join(\"\")}else n=\",.\"+ko(i[2])+\"f\";return t.format(n)}t.scale.linear=function(){return function t(e,r,n,i){var a,o;function s(){var t=Math.min(e.length,r.length)>2?vo:ho,s=i?ma:va;return a=t(e,r,s,n),o=t(r,e,s,Zi),l}function l(t){return a(t)}l.invert=function(t){return o(t)};l.domain=function(t){return arguments.length?(e=t.map(Number),s()):e};l.range=function(t){return arguments.length?(r=t,s()):r};l.rangeRound=function(t){return l.range(t).interpolate(ca)};l.clamp=function(t){return arguments.length?(i=t,s()):i};l.interpolate=function(t){return arguments.length?(n=t,s()):n};l.ticks=function(t){return bo(e,t)};l.tickFormat=function(t,r){return _o(e,t,r)};l.nice=function(t){return yo(e,t),s()};l.copy=function(){return t(e,r,n,i)};return s()}([0,1],[0,1],Zi,!1)};var wo={s:1,g:1,p:1,r:1,e:1};function ko(t){return-Math.floor(Math.log(t)/Math.LN10+.01)}t.scale.log=function(){return function e(r,n,i,a){function o(t){return(i?Math.log(t<0?0:t):-Math.log(t>0?0:-t))/Math.log(n)}function s(t){return i?Math.pow(n,t):-Math.pow(n,-t)}function l(t){return r(o(t))}l.invert=function(t){return s(r.invert(t))};l.domain=function(t){return arguments.length?(i=t[0]>=0,r.domain((a=t.map(Number)).map(o)),l):a};l.base=function(t){return arguments.length?(n=+t,r.domain(a.map(o)),l):n};l.nice=function(){var t=fo(a.map(o),i?Math:Ao);return r.domain(t),a=t.map(s),l};l.ticks=function(){var t=co(a),e=[],r=t[0],l=t[1],c=Math.floor(o(r)),u=Math.ceil(o(l)),h=n%1?2:n;if(isFinite(u-c)){if(i){for(;c<u;c++)for(var f=1;f<h;f++)e.push(s(c)*f);e.push(s(c))}else for(e.push(s(c));c++<u;)for(var f=h-1;f>0;f--)e.push(s(c)*f);for(c=0;e[c]<r;c++);for(u=e.length;e[u-1]>l;u--);e=e.slice(c,u)}return e};l.tickFormat=function(e,r){if(!arguments.length)return To;arguments.length<2?r=To:\"function\"!=typeof r&&(r=t.format(r));var i=Math.max(1,n*e/l.ticks().length);return function(t){var e=t/s(Math.round(o(t)));return e*n<n-.5&&(e*=n),e<=i?r(t):\"\"}};l.copy=function(){return e(r.copy(),n,i,a)};return mo(l,r)}(t.scale.linear().domain([0,1]),10,!0,[1,10])};var To=t.format(\".0e\"),Ao={floor:function(t){return-Math.ceil(-t)},ceil:function(t){return-Math.floor(-t)}};function Mo(t){return function(e){return e<0?-Math.pow(-e,t):Math.pow(e,t)}}t.scale.pow=function(){return function t(e,r,n){var i=Mo(r),a=Mo(1/r);function o(t){return e(i(t))}o.invert=function(t){return a(e.invert(t))};o.domain=function(t){return arguments.length?(e.domain((n=t.map(Number)).map(i)),o):n};o.ticks=function(t){return bo(n,t)};o.tickFormat=function(t,e){return _o(n,t,e)};o.nice=function(t){return o.domain(yo(n,t))};o.exponent=function(t){return arguments.length?(i=Mo(r=t),a=Mo(1/r),e.domain(n.map(i)),o):r};o.copy=function(){return t(e.copy(),r,n)};return mo(o,e)}(t.scale.linear(),1,[0,1])},t.scale.sqrt=function(){return t.scale.pow().exponent(.5)},t.scale.ordinal=function(){return function e(r,n){var i,a,o;function s(t){return a[((i.get(t)||(\"range\"===n.t?i.set(t,r.push(t)):NaN))-1)%a.length]}function l(e,n){return t.range(r.length).map(function(t){return e+n*t})}s.domain=function(t){if(!arguments.length)return r;r=[],i=new b;for(var e,a=-1,o=t.length;++a<o;)i.has(e=t[a])||i.set(e,r.push(e));return s[n.t].apply(s,n.a)};s.range=function(t){return arguments.length?(a=t,o=0,n={t:\"range\",a:arguments},s):a};s.rangePoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=(i+c)/2,0):(c-i)/(r.length-1+e);return a=l(i+u*e/2,u),o=0,n={t:\"rangePoints\",a:arguments},s};s.rangeRoundPoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=c=Math.round((i+c)/2),0):(c-i)/(r.length-1+e)|0;return a=l(i+Math.round(u*e/2+(c-i-(r.length-1+e)*u)/2),u),o=0,n={t:\"rangeRoundPoints\",a:arguments},s};s.rangeBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],h=t[1-c],f=(h-u)/(r.length-e+2*i);return a=l(u+f*i,f),c&&a.reverse(),o=f*(1-e),n={t:\"rangeBands\",a:arguments},s};s.rangeRoundBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],h=t[1-c],f=Math.floor((h-u)/(r.length-e+2*i));return a=l(u+Math.round((h-u-(r.length-e)*f)/2),f),c&&a.reverse(),o=Math.round(f*(1-e)),n={t:\"rangeRoundBands\",a:arguments},s};s.rangeBand=function(){return o};s.rangeExtent=function(){return co(n.a[0])};s.copy=function(){return e(r,n)};return s.domain(r)}([],{t:\"range\",a:[[]]})},t.scale.category10=function(){return t.scale.ordinal().range(So)},t.scale.category20=function(){return t.scale.ordinal().range(Eo)},t.scale.category20b=function(){return t.scale.ordinal().range(Co)},t.scale.category20c=function(){return t.scale.ordinal().range(Lo)};var So=[2062260,16744206,2924588,14034728,9725885,9197131,14907330,8355711,12369186,1556175].map(se),Eo=[2062260,11454440,16744206,16759672,2924588,10018698,14034728,16750742,9725885,12955861,9197131,12885140,14907330,16234194,8355711,13092807,12369186,14408589,1556175,10410725].map(se),Co=[3750777,5395619,7040719,10264286,6519097,9216594,11915115,13556636,9202993,12426809,15186514,15190932,8666169,11356490,14049643,15177372,8077683,10834324,13528509,14589654].map(se),Lo=[3244733,7057110,10406625,13032431,15095053,16616764,16625259,16634018,3253076,7652470,10607003,13101504,7695281,10394312,12369372,14342891,6513507,9868950,12434877,14277081].map(se);function Po(){return 0}t.scale.quantile=function(){return function e(r,n){var i;function a(){var e=0,a=n.length;for(i=[];++e<a;)i[e-1]=t.quantile(r,e/a);return o}function o(e){if(!isNaN(e=+e))return n[t.bisect(i,e)]}o.domain=function(t){return arguments.length?(r=t.map(p).filter(d).sort(f),a()):r};o.range=function(t){return arguments.length?(n=t,a()):n};o.quantiles=function(){return i};o.invertExtent=function(t){return(t=n.indexOf(t))<0?[NaN,NaN]:[t>0?i[t-1]:r[0],t<i.length?i[t]:r[r.length-1]]};o.copy=function(){return e(r,n)};return a()}([],[])},t.scale.quantize=function(){return function t(e,r,n){var i,a;function o(t){return n[Math.max(0,Math.min(a,Math.floor(i*(t-e))))]}function s(){return i=n.length/(r-e),a=n.length-1,o}o.domain=function(t){return arguments.length?(e=+t[0],r=+t[t.length-1],s()):[e,r]};o.range=function(t){return arguments.length?(n=t,s()):n};o.invertExtent=function(t){return[t=(t=n.indexOf(t))<0?NaN:t/i+e,t+1/i]};o.copy=function(){return t(e,r,n)};return s()}(0,1,[0,1])},t.scale.threshold=function(){return function e(r,n){function i(e){if(e<=e)return n[t.bisect(r,e)]}i.domain=function(t){return arguments.length?(r=t,i):r};i.range=function(t){return arguments.length?(n=t,i):n};i.invertExtent=function(t){return t=n.indexOf(t),[r[t-1],r[t]]};i.copy=function(){return e(r,n)};return i}([.5],[0,1])},t.scale.identity=function(){return function t(e){function r(t){return+t}r.invert=r;r.domain=r.range=function(t){return arguments.length?(e=t.map(r),r):e};r.ticks=function(t){return bo(e,t)};r.tickFormat=function(t,r){return _o(e,t,r)};r.copy=function(){return t(e)};return r}([0,1])},t.svg={},t.svg.arc=function(){var t=zo,e=Io,r=Po,n=Oo,i=Do,a=Ro,o=Fo;function s(){var s=Math.max(0,+t.apply(this,arguments)),c=Math.max(0,+e.apply(this,arguments)),u=i.apply(this,arguments)-Et,h=a.apply(this,arguments)-Et,f=Math.abs(h-u),p=u>h?0:1;if(c<s&&(d=c,c=s,s=d),f>=St)return l(c,p)+(s?l(s,1-p):\"\")+\"Z\";var d,g,v,m,y,x,b,_,w,k,T,A,M=0,S=0,E=[];if((m=(+o.apply(this,arguments)||0)/2)&&(v=n===Oo?Math.sqrt(s*s+c*c):+n.apply(this,arguments),p||(S*=-1),c&&(S=It(v/c*Math.sin(m))),s&&(M=It(v/s*Math.sin(m)))),c){y=c*Math.cos(u+S),x=c*Math.sin(u+S),b=c*Math.cos(h-S),_=c*Math.sin(h-S);var C=Math.abs(h-u-2*S)<=At?0:1;if(S&&Bo(y,x,b,_)===p^C){var L=(u+h)/2;y=c*Math.cos(L),x=c*Math.sin(L),b=_=null}}else y=x=0;if(s){w=s*Math.cos(h-M),k=s*Math.sin(h-M),T=s*Math.cos(u+M),A=s*Math.sin(u+M);var P=Math.abs(u-h+2*M)<=At?0:1;if(M&&Bo(w,k,T,A)===1-p^P){var O=(u+h)/2;w=s*Math.cos(O),k=s*Math.sin(O),T=A=null}}else w=k=0;if(f>kt&&(d=Math.min(Math.abs(c-s)/2,+r.apply(this,arguments)))>.001){g=s<c^p?0:1;var z=d,I=d;if(f<At){var D=null==T?[w,k]:null==b?[y,x]:si([y,x],[T,A],[b,_],[w,k]),R=y-D[0],F=x-D[1],B=b-D[0],N=_-D[1],j=1/Math.sin(Math.acos((R*B+F*N)/(Math.sqrt(R*R+F*F)*Math.sqrt(B*B+N*N)))/2),U=Math.sqrt(D[0]*D[0]+D[1]*D[1]);I=Math.min(d,(s-U)/(j-1)),z=Math.min(d,(c-U)/(j+1))}if(null!=b){var V=No(null==T?[w,k]:[T,A],[y,x],c,z,p),q=No([b,_],[w,k],c,z,p);d===z?E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 0,\",g,\" \",V[1],\"A\",c,\",\",c,\" 0 \",1-p^Bo(V[1][0],V[1][1],q[1][0],q[1][1]),\",\",p,\" \",q[1],\"A\",z,\",\",z,\" 0 0,\",g,\" \",q[0]):E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 1,\",g,\" \",q[0])}else E.push(\"M\",y,\",\",x);if(null!=T){var H=No([y,x],[T,A],s,-I,p),G=No([w,k],null==b?[y,x]:[b,_],s,-I,p);d===I?E.push(\"L\",G[0],\"A\",I,\",\",I,\" 0 0,\",g,\" \",G[1],\"A\",s,\",\",s,\" 0 \",p^Bo(G[1][0],G[1][1],H[1][0],H[1][1]),\",\",1-p,\" \",H[1],\"A\",I,\",\",I,\" 0 0,\",g,\" \",H[0]):E.push(\"L\",G[0],\"A\",I,\",\",I,\" 0 0,\",g,\" \",H[0])}else E.push(\"L\",w,\",\",k)}else E.push(\"M\",y,\",\",x),null!=b&&E.push(\"A\",c,\",\",c,\" 0 \",C,\",\",p,\" \",b,\",\",_),E.push(\"L\",w,\",\",k),null!=T&&E.push(\"A\",s,\",\",s,\" 0 \",P,\",\",1-p,\" \",T,\",\",A);return E.push(\"Z\"),E.join(\"\")}function l(t,e){return\"M0,\"+t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+-t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+t}return s.innerRadius=function(e){return arguments.length?(t=ve(e),s):t},s.outerRadius=function(t){return arguments.length?(e=ve(t),s):e},s.cornerRadius=function(t){return arguments.length?(r=ve(t),s):r},s.padRadius=function(t){return arguments.length?(n=t==Oo?Oo:ve(t),s):n},s.startAngle=function(t){return arguments.length?(i=ve(t),s):i},s.endAngle=function(t){return arguments.length?(a=ve(t),s):a},s.padAngle=function(t){return arguments.length?(o=ve(t),s):o},s.centroid=function(){var r=(+t.apply(this,arguments)+ +e.apply(this,arguments))/2,n=(+i.apply(this,arguments)+ +a.apply(this,arguments))/2-Et;return[Math.cos(n)*r,Math.sin(n)*r]},s};var Oo=\"auto\";function zo(t){return t.innerRadius}function Io(t){return t.outerRadius}function Do(t){return t.startAngle}function Ro(t){return t.endAngle}function Fo(t){return t&&t.padAngle}function Bo(t,e,r,n){return(t-r)*e-(e-n)*t>0?0:1}function No(t,e,r,n,i){var a=t[0]-e[0],o=t[1]-e[1],s=(i?n:-n)/Math.sqrt(a*a+o*o),l=s*o,c=-s*a,u=t[0]+l,h=t[1]+c,f=e[0]+l,p=e[1]+c,d=(u+f)/2,g=(h+p)/2,v=f-u,m=p-h,y=v*v+m*m,x=r-n,b=u*p-f*h,_=(m<0?-1:1)*Math.sqrt(Math.max(0,x*x*y-b*b)),w=(b*m-v*_)/y,k=(-b*v-m*_)/y,T=(b*m+v*_)/y,A=(-b*v+m*_)/y,M=w-d,S=k-g,E=T-d,C=A-g;return M*M+S*S>E*E+C*C&&(w=T,k=A),[[w-l,k-c],[w*r/x,k*r/x]]}function jo(t){var e=ei,r=ri,n=Yr,i=Vo,a=i.key,o=.7;function s(a){var s,l=[],c=[],u=-1,h=a.length,f=ve(e),p=ve(r);function d(){l.push(\"M\",i(t(c),o))}for(;++u<h;)n.call(this,s=a[u],u)?c.push([+f.call(this,s,u),+p.call(this,s,u)]):c.length&&(d(),c=[]);return c.length&&d(),l.length?l.join(\"\"):null}return s.x=function(t){return arguments.length?(e=t,s):e},s.y=function(t){return arguments.length?(r=t,s):r},s.defined=function(t){return arguments.length?(n=t,s):n},s.interpolate=function(t){return arguments.length?(a=\"function\"==typeof t?i=t:(i=Uo.get(t)||Vo).key,s):a},s.tension=function(t){return arguments.length?(o=t,s):o},s}t.svg.line=function(){return jo(P)};var Uo=t.map({linear:Vo,\"linear-closed\":qo,step:function(t){var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];for(;++e<r;)i.push(\"H\",(n[0]+(n=t[e])[0])/2,\"V\",n[1]);r>1&&i.push(\"H\",n[0]);return i.join(\"\")},\"step-before\":Ho,\"step-after\":Go,basis:Xo,\"basis-open\":function(t){if(t.length<4)return Vo(t);var e,r=[],n=-1,i=t.length,a=[0],o=[0];for(;++n<3;)e=t[n],a.push(e[0]),o.push(e[1]);r.push(Zo($o,a)+\",\"+Zo($o,o)),--n;for(;++n<i;)e=t[n],a.shift(),a.push(e[0]),o.shift(),o.push(e[1]),Qo(r,a,o);return r.join(\"\")},\"basis-closed\":function(t){var e,r,n=-1,i=t.length,a=i+4,o=[],s=[];for(;++n<4;)r=t[n%i],o.push(r[0]),s.push(r[1]);e=[Zo($o,o),\",\",Zo($o,s)],--n;for(;++n<a;)r=t[n%i],o.shift(),o.push(r[0]),s.shift(),s.push(r[1]),Qo(e,o,s);return e.join(\"\")},bundle:function(t,e){var r=t.length-1;if(r)for(var n,i,a=t[0][0],o=t[0][1],s=t[r][0]-a,l=t[r][1]-o,c=-1;++c<=r;)n=t[c],i=c/r,n[0]=e*n[0]+(1-e)*(a+i*s),n[1]=e*n[1]+(1-e)*(o+i*l);return Xo(t)},cardinal:function(t,e){return t.length<3?Vo(t):t[0]+Yo(t,Wo(t,e))},\"cardinal-open\":function(t,e){return t.length<4?Vo(t):t[1]+Yo(t.slice(1,-1),Wo(t,e))},\"cardinal-closed\":function(t,e){return t.length<3?qo(t):t[0]+Yo((t.push(t[0]),t),Wo([t[t.length-2]].concat(t,[t[1]]),e))},monotone:function(t){return t.length<3?Vo(t):t[0]+Yo(t,function(t){var e,r,n,i,a=[],o=function(t){var e=0,r=t.length-1,n=[],i=t[0],a=t[1],o=n[0]=ts(i,a);for(;++e<r;)n[e]=(o+(o=ts(i=a,a=t[e+1])))/2;return n[e]=o,n}(t),s=-1,l=t.length-1;for(;++s<l;)e=ts(t[s],t[s+1]),y(e)<kt?o[s]=o[s+1]=0:(r=o[s]/e,n=o[s+1]/e,(i=r*r+n*n)>9&&(i=3*e/Math.sqrt(i),o[s]=i*r,o[s+1]=i*n));s=-1;for(;++s<=l;)i=(t[Math.min(l,s+1)][0]-t[Math.max(0,s-1)][0])/(6*(1+o[s]*o[s])),a.push([i||0,o[s]*i||0]);return a}(t))}});function Vo(t){return t.length>1?t.join(\"L\"):t+\"Z\"}function qo(t){return t.join(\"L\")+\"Z\"}function Ho(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"V\",(n=t[e])[1],\"H\",n[0]);return i.join(\"\")}function Go(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"H\",(n=t[e])[0],\"V\",n[1]);return i.join(\"\")}function Yo(t,e){if(e.length<1||t.length!=e.length&&t.length!=e.length+2)return Vo(t);var r=t.length!=e.length,n=\"\",i=t[0],a=t[1],o=e[0],s=o,l=1;if(r&&(n+=\"Q\"+(a[0]-2*o[0]/3)+\",\"+(a[1]-2*o[1]/3)+\",\"+a[0]+\",\"+a[1],i=t[1],l=2),e.length>1){s=e[1],a=t[l],l++,n+=\"C\"+(i[0]+o[0])+\",\"+(i[1]+o[1])+\",\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1];for(var c=2;c<e.length;c++,l++)a=t[l],s=e[c],n+=\"S\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1]}if(r){var u=t[l];n+=\"Q\"+(a[0]+2*s[0]/3)+\",\"+(a[1]+2*s[1]/3)+\",\"+u[0]+\",\"+u[1]}return n}function Wo(t,e){for(var r,n=[],i=(1-e)/2,a=t[0],o=t[1],s=1,l=t.length;++s<l;)r=a,a=o,o=t[s],n.push([i*(o[0]-r[0]),i*(o[1]-r[1])]);return n}function Xo(t){if(t.length<3)return Vo(t);var e=1,r=t.length,n=t[0],i=n[0],a=n[1],o=[i,i,i,(n=t[1])[0]],s=[a,a,a,n[1]],l=[i,\",\",a,\"L\",Zo($o,o),\",\",Zo($o,s)];for(t.push(t[r-1]);++e<=r;)n=t[e],o.shift(),o.push(n[0]),s.shift(),s.push(n[1]),Qo(l,o,s);return t.pop(),l.push(\"L\",n),l.join(\"\")}function Zo(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}Uo.forEach(function(t,e){e.key=t,e.closed=/-closed$/.test(t)});var Jo=[0,2/3,1/3,0],Ko=[0,1/3,2/3,0],$o=[0,1/6,2/3,1/6];function Qo(t,e,r){t.push(\"C\",Zo(Jo,e),\",\",Zo(Jo,r),\",\",Zo(Ko,e),\",\",Zo(Ko,r),\",\",Zo($o,e),\",\",Zo($o,r))}function ts(t,e){return(e[1]-t[1])/(e[0]-t[0])}function es(t){for(var e,r,n,i=-1,a=t.length;++i<a;)r=(e=t[i])[0],n=e[1]-Et,e[0]=r*Math.cos(n),e[1]=r*Math.sin(n);return t}function rs(t){var e=ei,r=ei,n=0,i=ri,a=Yr,o=Vo,s=o.key,l=o,c=\"L\",u=.7;function h(s){var h,f,p,d=[],g=[],v=[],m=-1,y=s.length,x=ve(e),b=ve(n),_=e===r?function(){return f}:ve(r),w=n===i?function(){return p}:ve(i);function k(){d.push(\"M\",o(t(v),u),c,l(t(g.reverse()),u),\"Z\")}for(;++m<y;)a.call(this,h=s[m],m)?(g.push([f=+x.call(this,h,m),p=+b.call(this,h,m)]),v.push([+_.call(this,h,m),+w.call(this,h,m)])):g.length&&(k(),g=[],v=[]);return g.length&&k(),d.length?d.join(\"\"):null}return h.x=function(t){return arguments.length?(e=r=t,h):r},h.x0=function(t){return arguments.length?(e=t,h):e},h.x1=function(t){return arguments.length?(r=t,h):r},h.y=function(t){return arguments.length?(n=i=t,h):i},h.y0=function(t){return arguments.length?(n=t,h):n},h.y1=function(t){return arguments.length?(i=t,h):i},h.defined=function(t){return arguments.length?(a=t,h):a},h.interpolate=function(t){return arguments.length?(s=\"function\"==typeof t?o=t:(o=Uo.get(t)||Vo).key,l=o.reverse||o,c=o.closed?\"M\":\"L\",h):s},h.tension=function(t){return arguments.length?(u=t,h):u},h}function ns(t){return t.radius}function is(t){return[t.x,t.y]}function as(){return 64}function os(){return\"circle\"}function ss(t){var e=Math.sqrt(t/At);return\"M0,\"+e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+-e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+e+\"Z\"}t.svg.line.radial=function(){var t=jo(es);return t.radius=t.x,delete t.x,t.angle=t.y,delete t.y,t},Ho.reverse=Go,Go.reverse=Ho,t.svg.area=function(){return rs(P)},t.svg.area.radial=function(){var t=rs(es);return t.radius=t.x,delete t.x,t.innerRadius=t.x0,delete t.x0,t.outerRadius=t.x1,delete t.x1,t.angle=t.y,delete t.y,t.startAngle=t.y0,delete t.y0,t.endAngle=t.y1,delete t.y1,t},t.svg.chord=function(){var t=Un,e=Vn,r=ns,n=Do,i=Ro;function a(r,n){var i,a,c=o(this,t,r,n),u=o(this,e,r,n);return\"M\"+c.p0+s(c.r,c.p1,c.a1-c.a0)+(a=u,(i=c).a0==a.a0&&i.a1==a.a1?l(c.r,c.p1,c.r,c.p0):l(c.r,c.p1,u.r,u.p0)+s(u.r,u.p1,u.a1-u.a0)+l(u.r,u.p1,c.r,c.p0))+\"Z\"}function o(t,e,a,o){var s=e.call(t,a,o),l=r.call(t,s,o),c=n.call(t,s,o)-Et,u=i.call(t,s,o)-Et;return{r:l,a0:c,a1:u,p0:[l*Math.cos(c),l*Math.sin(c)],p1:[l*Math.cos(u),l*Math.sin(u)]}}function s(t,e,r){return\"A\"+t+\",\"+t+\" 0 \"+ +(r>At)+\",1 \"+e}function l(t,e,r,n){return\"Q 0,0 \"+n}return a.radius=function(t){return arguments.length?(r=ve(t),a):r},a.source=function(e){return arguments.length?(t=ve(e),a):t},a.target=function(t){return arguments.length?(e=ve(t),a):e},a.startAngle=function(t){return arguments.length?(n=ve(t),a):n},a.endAngle=function(t){return arguments.length?(i=ve(t),a):i},a},t.svg.diagonal=function(){var t=Un,e=Vn,r=is;function n(n,i){var a=t.call(this,n,i),o=e.call(this,n,i),s=(a.y+o.y)/2,l=[a,{x:a.x,y:s},{x:o.x,y:s},o];return\"M\"+(l=l.map(r))[0]+\"C\"+l[1]+\" \"+l[2]+\" \"+l[3]}return n.source=function(e){return arguments.length?(t=ve(e),n):t},n.target=function(t){return arguments.length?(e=ve(t),n):e},n.projection=function(t){return arguments.length?(r=t,n):r},n},t.svg.diagonal.radial=function(){var e=t.svg.diagonal(),r=is,n=e.projection;return e.projection=function(t){return arguments.length?n(function(t){return function(){var e=t.apply(this,arguments),r=e[0],n=e[1]-Et;return[r*Math.cos(n),r*Math.sin(n)]}}(r=t)):r},e},t.svg.symbol=function(){var t=os,e=as;function r(r,n){return(ls.get(t.call(this,r,n))||ss)(e.call(this,r,n))}return r.type=function(e){return arguments.length?(t=ve(e),r):t},r.size=function(t){return arguments.length?(e=ve(t),r):e},r};var ls=t.map({circle:ss,cross:function(t){var e=Math.sqrt(t/5)/2;return\"M\"+-3*e+\",\"+-e+\"H\"+-e+\"V\"+-3*e+\"H\"+e+\"V\"+-e+\"H\"+3*e+\"V\"+e+\"H\"+e+\"V\"+3*e+\"H\"+-e+\"V\"+e+\"H\"+-3*e+\"Z\"},diamond:function(t){var e=Math.sqrt(t/(2*us)),r=e*us;return\"M0,\"+-e+\"L\"+r+\",0 0,\"+e+\" \"+-r+\",0Z\"},square:function(t){var e=Math.sqrt(t)/2;return\"M\"+-e+\",\"+-e+\"L\"+e+\",\"+-e+\" \"+e+\",\"+e+\" \"+-e+\",\"+e+\"Z\"},\"triangle-down\":function(t){var e=Math.sqrt(t/cs),r=e*cs/2;return\"M0,\"+r+\"L\"+e+\",\"+-r+\" \"+-e+\",\"+-r+\"Z\"},\"triangle-up\":function(t){var e=Math.sqrt(t/cs),r=e*cs/2;return\"M0,\"+-r+\"L\"+e+\",\"+r+\" \"+-e+\",\"+r+\"Z\"}});t.svg.symbolTypes=ls.keys();var cs=Math.sqrt(3),us=Math.tan(30*Ct);W.transition=function(t){for(var e,r,n=ds||++ms,i=bs(t),a=[],o=gs||{time:Date.now(),ease:ia,delay:0,duration:250},s=-1,l=this.length;++s<l;){a.push(e=[]);for(var c=this[s],u=-1,h=c.length;++u<h;)(r=c[u])&&_s(r,u,i,n,o),e.push(r)}return ps(a,i,n)},W.interrupt=function(t){return this.each(null==t?hs:fs(bs(t)))};var hs=fs(bs());function fs(t){return function(){var e,r,n;(e=this[t])&&(n=e[r=e.active])&&(n.timer.c=null,n.timer.t=NaN,--e.count?delete e[r]:delete this[t],e.active+=.5,n.event&&n.event.interrupt.call(this,this.__data__,n.index))}}function ps(t,e,r){return V(t,vs),t.namespace=e,t.id=r,t}var ds,gs,vs=[],ms=0;function ys(t,e,r,n){var i=t.id,a=t.namespace;return ut(t,\"function\"==typeof r?function(t,o,s){t[a][i].tween.set(e,n(r.call(t,t.__data__,o,s)))}:(r=n(r),function(t){t[a][i].tween.set(e,r)}))}function xs(t){return null==t&&(t=\"\"),function(){this.textContent=t}}function bs(t){return null==t?\"__transition__\":\"__transition_\"+t+\"__\"}function _s(t,e,r,n,i){var a,o,s,l,c,u=t[r]||(t[r]={active:0,count:0}),h=u[n];function f(r){var i=u.active,f=u[i];for(var d in f&&(f.timer.c=null,f.timer.t=NaN,--u.count,delete u[i],f.event&&f.event.interrupt.call(t,t.__data__,f.index)),u)if(+d<n){var g=u[d];g.timer.c=null,g.timer.t=NaN,--u.count,delete u[d]}o.c=p,Te(function(){return o.c&&p(r||1)&&(o.c=null,o.t=NaN),1},0,a),u.active=n,h.event&&h.event.start.call(t,t.__data__,e),c=[],h.tween.forEach(function(r,n){(n=n.call(t,t.__data__,e))&&c.push(n)}),l=h.ease,s=h.duration}function p(i){for(var a=i/s,o=l(a),f=c.length;f>0;)c[--f].call(t,o);if(a>=1)return h.event&&h.event.end.call(t,t.__data__,e),--u.count?delete u[n]:delete t[r],1}h||(a=i.time,o=Te(function(t){var e=h.delay;if(o.t=e+a,e<=t)return f(t-e);o.c=f},0,a),h=u[n]={tween:new b,time:a,timer:o,delay:i.delay,duration:i.duration,ease:i.ease,index:e},i=null,++u.count)}vs.call=W.call,vs.empty=W.empty,vs.node=W.node,vs.size=W.size,t.transition=function(e,r){return e&&e.transition?ds?e.transition(r):e:t.selection().transition(e)},t.transition.prototype=vs,vs.select=function(t){var e,r,n,i=this.id,a=this.namespace,o=[];t=X(t);for(var s=-1,l=this.length;++s<l;){o.push(e=[]);for(var c=this[s],u=-1,h=c.length;++u<h;)(n=c[u])&&(r=t.call(n,n.__data__,u,s))?(\"__data__\"in n&&(r.__data__=n.__data__),_s(r,u,a,i,n[a][i]),e.push(r)):e.push(null)}return ps(o,a,i)},vs.selectAll=function(t){var e,r,n,i,a,o=this.id,s=this.namespace,l=[];t=Z(t);for(var c=-1,u=this.length;++c<u;)for(var h=this[c],f=-1,p=h.length;++f<p;)if(n=h[f]){a=n[s][o],r=t.call(n,n.__data__,f,c),l.push(e=[]);for(var d=-1,g=r.length;++d<g;)(i=r[d])&&_s(i,d,s,o,a),e.push(i)}return ps(l,s,o)},vs.filter=function(t){var e,r,n=[];\"function\"!=typeof t&&(t=ct(t));for(var i=0,a=this.length;i<a;i++){n.push(e=[]);for(var o,s=0,l=(o=this[i]).length;s<l;s++)(r=o[s])&&t.call(r,r.__data__,s,i)&&e.push(r)}return ps(n,this.namespace,this.id)},vs.tween=function(t,e){var r=this.id,n=this.namespace;return arguments.length<2?this.node()[n][r].tween.get(t):ut(this,null==e?function(e){e[n][r].tween.remove(t)}:function(i){i[n][r].tween.set(t,e)})},vs.attr=function(e,r){if(arguments.length<2){for(r in e)this.attr(r,e[r]);return this}var n=\"transform\"==e?ga:Zi,i=t.ns.qualify(e);function a(){this.removeAttribute(i)}function o(){this.removeAttributeNS(i.space,i.local)}return ys(this,\"attr.\"+e,r,i.local?function(t){return null==t?o:(t+=\"\",function(){var e,r=this.getAttributeNS(i.space,i.local);return r!==t&&(e=n(r,t),function(t){this.setAttributeNS(i.space,i.local,e(t))})})}:function(t){return null==t?a:(t+=\"\",function(){var e,r=this.getAttribute(i);return r!==t&&(e=n(r,t),function(t){this.setAttribute(i,e(t))})})})},vs.attrTween=function(e,r){var n=t.ns.qualify(e);return this.tween(\"attr.\"+e,n.local?function(t,e){var i=r.call(this,t,e,this.getAttributeNS(n.space,n.local));return i&&function(t){this.setAttributeNS(n.space,n.local,i(t))}}:function(t,e){var i=r.call(this,t,e,this.getAttribute(n));return i&&function(t){this.setAttribute(n,i(t))}})},vs.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.style(r,t[r],e);return this}r=\"\"}function i(){this.style.removeProperty(t)}return ys(this,\"style.\"+t,e,function(e){return null==e?i:(e+=\"\",function(){var n,i=o(this).getComputedStyle(this,null).getPropertyValue(t);return i!==e&&(n=Zi(i,e),function(e){this.style.setProperty(t,n(e),r)})})})},vs.styleTween=function(t,e,r){return arguments.length<3&&(r=\"\"),this.tween(\"style.\"+t,function(n,i){var a=e.call(this,n,i,o(this).getComputedStyle(this,null).getPropertyValue(t));return a&&function(e){this.style.setProperty(t,a(e),r)}})},vs.text=function(t){return ys(this,\"text\",t,xs)},vs.remove=function(){var t=this.namespace;return this.each(\"end.transition\",function(){var e;this[t].count<2&&(e=this.parentNode)&&e.removeChild(this)})},vs.ease=function(e){var r=this.id,n=this.namespace;return arguments.length<1?this.node()[n][r].ease:(\"function\"!=typeof e&&(e=t.ease.apply(t,arguments)),ut(this,function(t){t[n][r].ease=e}))},vs.delay=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].delay:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].delay=+t.call(n,n.__data__,i,a)}:(t=+t,function(n){n[r][e].delay=t}))},vs.duration=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].duration:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].duration=Math.max(1,t.call(n,n.__data__,i,a))}:(t=Math.max(1,t),function(n){n[r][e].duration=t}))},vs.each=function(e,r){var n=this.id,i=this.namespace;if(arguments.length<2){var a=gs,o=ds;try{ds=n,ut(this,function(t,r,a){gs=t[i][n],e.call(t,t.__data__,r,a)})}finally{gs=a,ds=o}}else ut(this,function(a){var o=a[i][n];(o.event||(o.event=t.dispatch(\"start\",\"end\",\"interrupt\"))).on(e,r)});return this},vs.transition=function(){for(var t,e,r,n=this.id,i=++ms,a=this.namespace,o=[],s=0,l=this.length;s<l;s++){o.push(t=[]);for(var c,u=0,h=(c=this[s]).length;u<h;u++)(e=c[u])&&_s(e,u,a,i,{time:(r=e[a][n]).time,ease:r.ease,delay:r.delay+r.duration,duration:r.duration}),t.push(e)}return ps(o,a,i)},t.svg.axis=function(){var e,r=t.scale.linear(),i=ws,a=6,o=6,s=3,l=[10],c=null;function u(n){n.each(function(){var n,u=t.select(this),h=this.__chart__||r,f=this.__chart__=r.copy(),p=null==c?f.ticks?f.ticks.apply(f,l):f.domain():c,d=null==e?f.tickFormat?f.tickFormat.apply(f,l):P:e,g=u.selectAll(\".tick\").data(p,f),v=g.enter().insert(\"g\",\".domain\").attr(\"class\",\"tick\").style(\"opacity\",kt),m=t.transition(g.exit()).style(\"opacity\",kt).remove(),y=t.transition(g.order()).style(\"opacity\",1),x=Math.max(a,0)+s,b=uo(f),_=u.selectAll(\".domain\").data([0]),w=(_.enter().append(\"path\").attr(\"class\",\"domain\"),t.transition(_));v.append(\"line\"),v.append(\"text\");var k,T,A,M,S=v.select(\"line\"),E=y.select(\"line\"),C=g.select(\"text\").text(d),L=v.select(\"text\"),O=y.select(\"text\"),z=\"top\"===i||\"left\"===i?-1:1;if(\"bottom\"===i||\"top\"===i?(n=Ts,k=\"x\",A=\"y\",T=\"x2\",M=\"y2\",C.attr(\"dy\",z<0?\"0em\":\".71em\").style(\"text-anchor\",\"middle\"),w.attr(\"d\",\"M\"+b[0]+\",\"+z*o+\"V0H\"+b[1]+\"V\"+z*o)):(n=As,k=\"y\",A=\"x\",T=\"y2\",M=\"x2\",C.attr(\"dy\",\".32em\").style(\"text-anchor\",z<0?\"end\":\"start\"),w.attr(\"d\",\"M\"+z*o+\",\"+b[0]+\"H0V\"+b[1]+\"H\"+z*o)),S.attr(M,z*a),L.attr(A,z*x),E.attr(T,0).attr(M,z*a),O.attr(k,0).attr(A,z*x),f.rangeBand){var I=f,D=I.rangeBand()/2;h=f=function(t){return I(t)+D}}else h.rangeBand?h=f:m.call(n,f,h);v.call(n,h,f),y.call(n,f,f)})}return u.scale=function(t){return arguments.length?(r=t,u):r},u.orient=function(t){return arguments.length?(i=t in ks?t+\"\":ws,u):i},u.ticks=function(){return arguments.length?(l=n(arguments),u):l},u.tickValues=function(t){return arguments.length?(c=t,u):c},u.tickFormat=function(t){return arguments.length?(e=t,u):e},u.tickSize=function(t){var e=arguments.length;return e?(a=+t,o=+arguments[e-1],u):a},u.innerTickSize=function(t){return arguments.length?(a=+t,u):a},u.outerTickSize=function(t){return arguments.length?(o=+t,u):o},u.tickPadding=function(t){return arguments.length?(s=+t,u):s},u.tickSubdivide=function(){return arguments.length&&u},u};var ws=\"bottom\",ks={top:1,right:1,bottom:1,left:1};function Ts(t,e,r){t.attr(\"transform\",function(t){var n=e(t);return\"translate(\"+(isFinite(n)?n:r(t))+\",0)\"})}function As(t,e,r){t.attr(\"transform\",function(t){var n=e(t);return\"translate(0,\"+(isFinite(n)?n:r(t))+\")\"})}t.svg.brush=function(){var e,r,n=j(f,\"brushstart\",\"brush\",\"brushend\"),i=null,a=null,s=[0,0],l=[0,0],c=!0,u=!0,h=Ss[0];function f(e){e.each(function(){var e=t.select(this).style(\"pointer-events\",\"all\").style(\"-webkit-tap-highlight-color\",\"rgba(0,0,0,0)\").on(\"mousedown.brush\",v).on(\"touchstart.brush\",v),r=e.selectAll(\".background\").data([0]);r.enter().append(\"rect\").attr(\"class\",\"background\").style(\"visibility\",\"hidden\").style(\"cursor\",\"crosshair\"),e.selectAll(\".extent\").data([0]).enter().append(\"rect\").attr(\"class\",\"extent\").style(\"cursor\",\"move\");var n=e.selectAll(\".resize\").data(h,P);n.exit().remove(),n.enter().append(\"g\").attr(\"class\",function(t){return\"resize \"+t}).style(\"cursor\",function(t){return Ms[t]}).append(\"rect\").attr(\"x\",function(t){return/[ew]$/.test(t)?-3:null}).attr(\"y\",function(t){return/^[ns]/.test(t)?-3:null}).attr(\"width\",6).attr(\"height\",6).style(\"visibility\",\"hidden\"),n.style(\"display\",f.empty()?\"none\":null);var o,s=t.transition(e),l=t.transition(r);i&&(o=uo(i),l.attr(\"x\",o[0]).attr(\"width\",o[1]-o[0]),d(s)),a&&(o=uo(a),l.attr(\"y\",o[0]).attr(\"height\",o[1]-o[0]),g(s)),p(s)})}function p(t){t.selectAll(\".resize\").attr(\"transform\",function(t){return\"translate(\"+s[+/e$/.test(t)]+\",\"+l[+/^s/.test(t)]+\")\"})}function d(t){t.select(\".extent\").attr(\"x\",s[0]),t.selectAll(\".extent,.n>rect,.s>rect\").attr(\"width\",s[1]-s[0])}function g(t){t.select(\".extent\").attr(\"y\",l[0]),t.selectAll(\".extent,.e>rect,.w>rect\").attr(\"height\",l[1]-l[0])}function v(){var h,v,m=this,y=t.select(t.event.target),x=n.of(m,arguments),b=t.select(m),_=y.datum(),w=!/^(n|s)$/.test(_)&&i,k=!/^(e|w)$/.test(_)&&a,T=y.classed(\"extent\"),A=xt(m),M=t.mouse(m),S=t.select(o(m)).on(\"keydown.brush\",function(){32==t.event.keyCode&&(T||(h=null,M[0]-=s[1],M[1]-=l[1],T=2),B())}).on(\"keyup.brush\",function(){32==t.event.keyCode&&2==T&&(M[0]+=s[1],M[1]+=l[1],T=0,B())});if(t.event.changedTouches?S.on(\"touchmove.brush\",L).on(\"touchend.brush\",O):S.on(\"mousemove.brush\",L).on(\"mouseup.brush\",O),b.interrupt().selectAll(\"*\").interrupt(),T)M[0]=s[0]-M[0],M[1]=l[0]-M[1];else if(_){var E=+/w$/.test(_),C=+/^n/.test(_);v=[s[1-E]-M[0],l[1-C]-M[1]],M[0]=s[E],M[1]=l[C]}else t.event.altKey&&(h=M.slice());function L(){var e=t.mouse(m),r=!1;v&&(e[0]+=v[0],e[1]+=v[1]),T||(t.event.altKey?(h||(h=[(s[0]+s[1])/2,(l[0]+l[1])/2]),M[0]=s[+(e[0]<h[0])],M[1]=l[+(e[1]<h[1])]):h=null),w&&P(e,i,0)&&(d(b),r=!0),k&&P(e,a,1)&&(g(b),r=!0),r&&(p(b),x({type:\"brush\",mode:T?\"move\":\"resize\"}))}function P(t,n,i){var a,o,f=uo(n),p=f[0],d=f[1],g=M[i],v=i?l:s,m=v[1]-v[0];if(T&&(p-=g,d-=m+g),a=(i?u:c)?Math.max(p,Math.min(d,t[i])):t[i],T?o=(a+=g)+m:(h&&(g=Math.max(p,Math.min(d,2*h[i]-a))),g<a?(o=a,a=g):o=g),v[0]!=a||v[1]!=o)return i?r=null:e=null,v[0]=a,v[1]=o,!0}function O(){L(),b.style(\"pointer-events\",\"all\").selectAll(\".resize\").style(\"display\",f.empty()?\"none\":null),t.select(\"body\").style(\"cursor\",null),S.on(\"mousemove.brush\",null).on(\"mouseup.brush\",null).on(\"touchmove.brush\",null).on(\"touchend.brush\",null).on(\"keydown.brush\",null).on(\"keyup.brush\",null),A(),x({type:\"brushend\"})}b.style(\"pointer-events\",\"none\").selectAll(\".resize\").style(\"display\",null),t.select(\"body\").style(\"cursor\",y.style(\"cursor\")),x({type:\"brushstart\"}),L()}return f.event=function(i){i.each(function(){var i=n.of(this,arguments),a={x:s,y:l,i:e,j:r},o=this.__chart__||a;this.__chart__=a,ds?t.select(this).transition().each(\"start.brush\",function(){e=o.i,r=o.j,s=o.x,l=o.y,i({type:\"brushstart\"})}).tween(\"brush:brush\",function(){var t=Ji(s,a.x),n=Ji(l,a.y);return e=r=null,function(e){s=a.x=t(e),l=a.y=n(e),i({type:\"brush\",mode:\"resize\"})}}).each(\"end.brush\",function(){e=a.i,r=a.j,i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"})}):(i({type:\"brushstart\"}),i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"}))})},f.x=function(t){return arguments.length?(h=Ss[!(i=t)<<1|!a],f):i},f.y=function(t){return arguments.length?(h=Ss[!i<<1|!(a=t)],f):a},f.clamp=function(t){return arguments.length?(i&&a?(c=!!t[0],u=!!t[1]):i?c=!!t:a&&(u=!!t),f):i&&a?[c,u]:i?c:a?u:null},f.extent=function(t){var n,o,c,u,h;return arguments.length?(i&&(n=t[0],o=t[1],a&&(n=n[0],o=o[0]),e=[n,o],i.invert&&(n=i(n),o=i(o)),o<n&&(h=n,n=o,o=h),n==s[0]&&o==s[1]||(s=[n,o])),a&&(c=t[0],u=t[1],i&&(c=c[1],u=u[1]),r=[c,u],a.invert&&(c=a(c),u=a(u)),u<c&&(h=c,c=u,u=h),c==l[0]&&u==l[1]||(l=[c,u])),f):(i&&(e?(n=e[0],o=e[1]):(n=s[0],o=s[1],i.invert&&(n=i.invert(n),o=i.invert(o)),o<n&&(h=n,n=o,o=h))),a&&(r?(c=r[0],u=r[1]):(c=l[0],u=l[1],a.invert&&(c=a.invert(c),u=a.invert(u)),u<c&&(h=c,c=u,u=h))),i&&a?[[n,c],[o,u]]:i?[n,o]:a&&[c,u])},f.clear=function(){return f.empty()||(s=[0,0],l=[0,0],e=r=null),f},f.empty=function(){return!!i&&s[0]==s[1]||!!a&&l[0]==l[1]},t.rebind(f,n,\"on\")};var Ms={n:\"ns-resize\",e:\"ew-resize\",s:\"ns-resize\",w:\"ew-resize\",nw:\"nwse-resize\",ne:\"nesw-resize\",se:\"nwse-resize\",sw:\"nesw-resize\"},Ss=[[\"n\",\"e\",\"s\",\"w\",\"nw\",\"ne\",\"se\",\"sw\"],[\"e\",\"w\"],[\"n\",\"s\"],[]],Es=ze.format=sr.timeFormat,Cs=Es.utc,Ls=Cs(\"%Y-%m-%dT%H:%M:%S.%LZ\");function Ps(t){return t.toISOString()}function Os(e,r,n){function i(t){return e(t)}function a(e,n){var i=(e[1]-e[0])/n,a=t.bisect(Is,i);return a==Is.length?[r.year,xo(e.map(function(t){return t/31536e6}),n)[2]]:a?r[i/Is[a-1]<Is[a]/i?a-1:a]:[Fs,xo(e,n)[2]]}return i.invert=function(t){return zs(e.invert(t))},i.domain=function(t){return arguments.length?(e.domain(t),i):e.domain().map(zs)},i.nice=function(t,e){var r=i.domain(),n=co(r),o=null==t?a(n,10):\"number\"==typeof t&&a(n,t);function s(r){return!isNaN(r)&&!t.range(r,zs(+r+1),e).length}return o&&(t=o[0],e=o[1]),i.domain(fo(r,e>1?{floor:function(e){for(;s(e=t.floor(e));)e=zs(e-1);return e},ceil:function(e){for(;s(e=t.ceil(e));)e=zs(+e+1);return e}}:t))},i.ticks=function(t,e){var r=co(i.domain()),n=null==t?a(r,10):\"number\"==typeof t?a(r,t):!t.range&&[{range:t},e];return n&&(t=n[0],e=n[1]),t.range(r[0],zs(+r[1]+1),e<1?1:e)},i.tickFormat=function(){return n},i.copy=function(){return Os(e.copy(),r,n)},mo(i,e)}function zs(t){return new Date(t)}Es.iso=Date.prototype.toISOString&&+new Date(\"2000-01-01T00:00:00.000Z\")?Ps:Ls,Ps.parse=function(t){var e=new Date(t);return isNaN(e)?null:e},Ps.toString=Ls.toString,ze.second=Fe(function(t){return new Ie(1e3*Math.floor(t/1e3))},function(t,e){t.setTime(t.getTime()+1e3*Math.floor(e))},function(t){return t.getSeconds()}),ze.seconds=ze.second.range,ze.seconds.utc=ze.second.utc.range,ze.minute=Fe(function(t){return new Ie(6e4*Math.floor(t/6e4))},function(t,e){t.setTime(t.getTime()+6e4*Math.floor(e))},function(t){return t.getMinutes()}),ze.minutes=ze.minute.range,ze.minutes.utc=ze.minute.utc.range,ze.hour=Fe(function(t){var e=t.getTimezoneOffset()/60;return new Ie(36e5*(Math.floor(t/36e5-e)+e))},function(t,e){t.setTime(t.getTime()+36e5*Math.floor(e))},function(t){return t.getHours()}),ze.hours=ze.hour.range,ze.hours.utc=ze.hour.utc.range,ze.month=Fe(function(t){return(t=ze.day(t)).setDate(1),t},function(t,e){t.setMonth(t.getMonth()+e)},function(t){return t.getMonth()}),ze.months=ze.month.range,ze.months.utc=ze.month.utc.range;var Is=[1e3,5e3,15e3,3e4,6e4,3e5,9e5,18e5,36e5,108e5,216e5,432e5,864e5,1728e5,6048e5,2592e6,7776e6,31536e6],Ds=[[ze.second,1],[ze.second,5],[ze.second,15],[ze.second,30],[ze.minute,1],[ze.minute,5],[ze.minute,15],[ze.minute,30],[ze.hour,1],[ze.hour,3],[ze.hour,6],[ze.hour,12],[ze.day,1],[ze.day,2],[ze.week,1],[ze.month,1],[ze.month,3],[ze.year,1]],Rs=Es.multi([[\".%L\",function(t){return t.getMilliseconds()}],[\":%S\",function(t){return t.getSeconds()}],[\"%I:%M\",function(t){return t.getMinutes()}],[\"%I %p\",function(t){return t.getHours()}],[\"%a %d\",function(t){return t.getDay()&&1!=t.getDate()}],[\"%b %d\",function(t){return 1!=t.getDate()}],[\"%B\",function(t){return t.getMonth()}],[\"%Y\",Yr]]),Fs={range:function(e,r,n){return t.range(Math.ceil(e/n)*n,+r,n).map(zs)},floor:P,ceil:P};Ds.year=ze.year,ze.scale=function(){return Os(t.scale.linear(),Ds,Rs)};var Bs=Ds.map(function(t){return[t[0].utc,t[1]]}),Ns=Cs.multi([[\".%L\",function(t){return t.getUTCMilliseconds()}],[\":%S\",function(t){return t.getUTCSeconds()}],[\"%I:%M\",function(t){return t.getUTCMinutes()}],[\"%I %p\",function(t){return t.getUTCHours()}],[\"%a %d\",function(t){return t.getUTCDay()&&1!=t.getUTCDate()}],[\"%b %d\",function(t){return 1!=t.getUTCDate()}],[\"%B\",function(t){return t.getUTCMonth()}],[\"%Y\",Yr]]);function js(t){return JSON.parse(t.responseText)}function Us(t){var e=i.createRange();return e.selectNode(i.body),e.createContextualFragment(t.responseText)}Bs.year=ze.year.utc,ze.scale.utc=function(){return Os(t.scale.linear(),Bs,Ns)},t.text=me(function(t){return t.responseText}),t.json=function(t,e){return ye(t,\"application/json\",js,e)},t.html=function(t,e){return ye(t,\"text/html\",Us,e)},t.xml=me(function(t){return t.responseXML}),\"object\"==typeof e&&e.exports?e.exports=t:this.d3=t}()},{}],164:[function(t,e,r){e.exports=function(){for(var t=0;t<arguments.length;t++)if(void 0!==arguments[t])return arguments[t]}},{}],165:[function(t,e,r){\"use strict\";var n=t(\"incremental-convex-hull\"),i=t(\"uniq\");function a(t,e){this.point=t,this.index=e}function o(t,e){for(var r=t.point,n=e.point,i=r.length,a=0;a<i;++a){var o=n[a]-r[a];if(o)return o}return 0}e.exports=function(t,e){var r=t.length;if(0===r)return[];var s=t[0].length;if(s<1)return[];if(1===s)return function(t,e,r){if(1===t)return r?[[-1,0]]:[];var n=e.map(function(t,e){return[t[0],e]});n.sort(function(t,e){return t[0]-e[0]});for(var i=new Array(t-1),a=1;a<t;++a){var o=n[a-1],s=n[a];i[a-1]=[o[1],s[1]]}r&&i.push([-1,i[0][1]],[i[t-1][1],-1]);return i}(r,t,e);for(var l=new Array(r),c=1,u=0;u<r;++u){for(var h=t[u],f=new Array(s+1),p=0,d=0;d<s;++d){var g=h[d];f[d]=g,p+=g*g}f[s]=p,l[u]=new a(f,u),c=Math.max(p,c)}i(l,o),r=l.length;for(var v=new Array(r+s+1),m=new Array(r+s+1),y=(s+1)*(s+1)*c,x=new Array(s+1),u=0;u<=s;++u)x[u]=0;x[s]=y,v[0]=x.slice(),m[0]=-1;for(var u=0;u<=s;++u){var f=x.slice();f[u]=1,v[u+1]=f,m[u+1]=-1}for(var u=0;u<r;++u){var b=l[u];v[u+s+1]=b.point,m[u+s+1]=b.index}var _=n(v,!1);_=e?_.filter(function(t){for(var e=0,r=0;r<=s;++r){var n=m[t[r]];if(n<0&&++e>=2)return!1;t[r]=n}return!0}):_.filter(function(t){for(var e=0;e<=s;++e){var r=m[t[e]];if(r<0)return!1;t[e]=r}return!0});if(1&s)for(var u=0;u<_.length;++u){var b=_[u],f=b[0];b[0]=b[1],b[1]=f}return _}},{\"incremental-convex-hull\":413,uniq:547}],166:[function(t,e,r){\"use strict\";e.exports=a;var n=(a.canvas=document.createElement(\"canvas\")).getContext(\"2d\"),i=o([32,126]);function a(t,e){Array.isArray(t)&&(t=t.join(\", \"));var r,a={},s=16,l=.05;e&&(2===e.length&&\"number\"==typeof e[0]?r=o(e):Array.isArray(e)?r=e:(e.o?r=o(e.o):e.pairs&&(r=e.pairs),e.fontSize&&(s=e.fontSize),null!=e.threshold&&(l=e.threshold))),r||(r=i),n.font=s+\"px \"+t;for(var c=0;c<r.length;c++){var u=r[c],h=n.measureText(u[0]).width+n.measureText(u[1]).width,f=n.measureText(u).width;if(Math.abs(h-f)>s*l){var p=(f-h)/s;a[u]=1e3*p}}return a}function o(t){for(var e=[],r=t[0];r<=t[1];r++)for(var n=String.fromCharCode(r),i=t[0];i<t[1];i++){var a=n+String.fromCharCode(i);e.push(a)}return e}a.createPairs=o,a.ascii=i},{}],167:[function(t,e,r){(function(t){var r=!1;if(\"undefined\"!=typeof Float64Array){var n=new Float64Array(1),i=new Uint32Array(n.buffer);if(n[0]=1,r=!0,1072693248===i[1]){e.exports=function(t){return n[0]=t,[i[0],i[1]]},e.exports.pack=function(t,e){return i[0]=t,i[1]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[0]},e.exports.hi=function(t){return n[0]=t,i[1]}}else if(1072693248===i[0]){e.exports=function(t){return n[0]=t,[i[1],i[0]]},e.exports.pack=function(t,e){return i[1]=t,i[0]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[1]},e.exports.hi=function(t){return n[0]=t,i[0]}}else r=!1}if(!r){var a=new t(8);e.exports=function(t){return a.writeDoubleLE(t,0,!0),[a.readUInt32LE(0,!0),a.readUInt32LE(4,!0)]},e.exports.pack=function(t,e){return a.writeUInt32LE(t,0,!0),a.writeUInt32LE(e,4,!0),a.readDoubleLE(0,!0)},e.exports.lo=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(0,!0)},e.exports.hi=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(4,!0)}}e.exports.sign=function(t){return e.exports.hi(t)>>>31},e.exports.exponent=function(t){return(e.exports.hi(t)<<1>>>21)-1023},e.exports.fraction=function(t){var r=e.exports.lo(t),n=e.exports.hi(t),i=1048575&n;return 2146435072&n&&(i+=1<<20),[r,i]},e.exports.denormalized=function(t){return!(2146435072&e.exports.hi(t))}}).call(this,t(\"buffer\").Buffer)},{buffer:105}],168:[function(t,e,r){var n=t(\"abs-svg-path\"),i=t(\"normalize-svg-path\"),a={M:\"moveTo\",C:\"bezierCurveTo\"};e.exports=function(t,e){t.beginPath(),i(n(e)).forEach(function(e){var r=e[0],n=e.slice(1);t[a[r]].apply(t,n)}),t.closePath()}},{\"abs-svg-path\":60,\"normalize-svg-path\":452}],169:[function(t,e,r){e.exports=function(t){switch(t){case\"int8\":return Int8Array;case\"int16\":return Int16Array;case\"int32\":return Int32Array;case\"uint8\":return Uint8Array;case\"uint16\":return Uint16Array;case\"uint32\":return Uint32Array;case\"float32\":return Float32Array;case\"float64\":return Float64Array;case\"array\":return Array;case\"uint8_clamped\":return Uint8ClampedArray}}},{}],170:[function(t,e,r){\"use strict\";e.exports=function(t,e){switch(\"undefined\"==typeof e&&(e=0),typeof t){case\"number\":if(t>0)return function(t,e){var r,n;for(r=new Array(t),n=0;n<t;++n)r[n]=e;return r}(0|t,e);break;case\"object\":if(\"number\"==typeof t.length)return function t(e,r,n){var i=0|e[n];if(i<=0)return[];var a,o=new Array(i);if(n===e.length-1)for(a=0;a<i;++a)o[a]=r;else for(a=0;a<i;++a)o[a]=t(e,r,n+1);return o}(t,e,0)}return[]}},{}],171:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(\"number\"!=typeof e){e=0;for(var i=0;i<r;++i){var a=t[i];e=Math.max(e,a[0],a[1])}e=1+(0|e)}e|=0;for(var o=new Array(e),i=0;i<e;++i)o[i]=[];for(var i=0;i<r;++i){var a=t[i];o[a[0]].push(a[1]),o[a[1]].push(a[0])}for(var s=0;s<e;++s)n(o[s],function(t,e){return t-e});return o};var n=t(\"uniq\")},{uniq:547}],172:[function(t,e,r){var n=t(\"strongly-connected-components\");e.exports=function(t){var e,r=[],i=[],a=[],o={},s=[];function l(t){var r,n,u=!1;for(i.push(t),a[t]=!0,r=0;r<s[t].length;r++)(n=s[t][r])===e?(c(e,i),u=!0):a[n]||(u=l(n));if(u)!function t(e){a[e]=!1,o.hasOwnProperty(e)&&Object.keys(o[e]).forEach(function(r){delete o[e][r],a[r]&&t(r)})}(t);else for(r=0;r<s[t].length;r++){n=s[t][r];var h=o[n];h||(h={},o[n]=h),h[n]=!0}return i.pop(),u}function c(t,e){var n=[].concat(e).concat(t);r.push(n)}function u(e){!function(e){for(var r=0;r<t.length;r++)r<e&&(t[r]=[]),t[r]=t[r].filter(function(t){return t>=e})}(e);for(var r,i=n(t).components.filter(function(t){return t.length>1}),a=1/0,o=0;o<i.length;o++)for(var s=0;s<i[o].length;s++)i[o][s]<a&&(a=i[o][s],r=o);var l=i[r];return!!l&&{leastVertex:a,adjList:t.map(function(t,e){return-1===l.indexOf(e)?[]:t.filter(function(t){return-1!==l.indexOf(t)})})}}e=0;for(var h=t.length;e<h;){var f=u(e);if(e=f.leastVertex,s=f.adjList){for(var p=0;p<s.length;p++)for(var d=0;d<s[p].length;d++){var g=s[p][d];a[+g]=!1,o[g]={}}l(e),e+=1}else e=h}return r}},{\"strongly-connected-components\":530}],173:[function(t,e,r){\"use strict\";var n=t(\"../../object/valid-value\");e.exports=function(){return n(this).length=0,this}},{\"../../object/valid-value\":205}],174:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Array.from:t(\"./shim\")},{\"./is-implemented\":175,\"./shim\":176}],175:[function(t,e,r){\"use strict\";e.exports=function(){var t,e,r=Array.from;return\"function\"==typeof r&&(e=r(t=[\"raz\",\"dwa\"]),Boolean(e&&e!==t&&\"dwa\"===e[1]))}},{}],176:[function(t,e,r){\"use strict\";var n=t(\"es6-symbol\").iterator,i=t(\"../../function/is-arguments\"),a=t(\"../../function/is-function\"),o=t(\"../../number/to-pos-integer\"),s=t(\"../../object/valid-callable\"),l=t(\"../../object/valid-value\"),c=t(\"../../object/is-value\"),u=t(\"../../string/is-string\"),h=Array.isArray,f=Function.prototype.call,p={configurable:!0,enumerable:!0,writable:!0,value:null},d=Object.defineProperty;e.exports=function(t){var e,r,g,v,m,y,x,b,_,w,k=arguments[1],T=arguments[2];if(t=Object(l(t)),c(k)&&s(k),this&&this!==Array&&a(this))e=this;else{if(!k){if(i(t))return 1!==(m=t.length)?Array.apply(null,t):((v=new Array(1))[0]=t[0],v);if(h(t)){for(v=new Array(m=t.length),r=0;r<m;++r)v[r]=t[r];return v}}v=[]}if(!h(t))if(void 0!==(_=t[n])){for(x=s(_).call(t),e&&(v=new e),b=x.next(),r=0;!b.done;)w=k?f.call(k,T,b.value,r):b.value,e?(p.value=w,d(v,r,p)):v[r]=w,b=x.next(),++r;m=r}else if(u(t)){for(m=t.length,e&&(v=new e),r=0,g=0;r<m;++r)w=t[r],r+1<m&&(y=w.charCodeAt(0))>=55296&&y<=56319&&(w+=t[++r]),w=k?f.call(k,T,w,g):w,e?(p.value=w,d(v,g,p)):v[g]=w,++g;m=g}if(void 0===m)for(m=o(t.length),e&&(v=new e(m)),r=0;r<m;++r)w=k?f.call(k,T,t[r],r):t[r],e?(p.value=w,d(v,r,p)):v[r]=w;return e&&(p.value=null,v.length=m),v}},{\"../../function/is-arguments\":177,\"../../function/is-function\":178,\"../../number/to-pos-integer\":184,\"../../object/is-value\":194,\"../../object/valid-callable\":203,\"../../object/valid-value\":205,\"../../string/is-string\":209,\"es6-symbol\":219}],177:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(function(){return arguments}());e.exports=function(t){return n.call(t)===i}},{}],178:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(t(\"./noop\"));e.exports=function(t){return\"function\"==typeof t&&n.call(t)===i}},{\"./noop\":179}],179:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],180:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Math.sign:t(\"./shim\")},{\"./is-implemented\":181,\"./shim\":182}],181:[function(t,e,r){\"use strict\";e.exports=function(){var t=Math.sign;return\"function\"==typeof t&&(1===t(10)&&-1===t(-20))}},{}],182:[function(t,e,r){\"use strict\";e.exports=function(t){return t=Number(t),isNaN(t)||0===t?t:t>0?1:-1}},{}],183:[function(t,e,r){\"use strict\";var n=t(\"../math/sign\"),i=Math.abs,a=Math.floor;e.exports=function(t){return isNaN(t)?0:0!==(t=Number(t))&&isFinite(t)?n(t)*a(i(t)):t}},{\"../math/sign\":180}],184:[function(t,e,r){\"use strict\";var n=t(\"./to-integer\"),i=Math.max;e.exports=function(t){return i(0,n(t))}},{\"./to-integer\":183}],185:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./valid-value\"),a=Function.prototype.bind,o=Function.prototype.call,s=Object.keys,l=Object.prototype.propertyIsEnumerable;e.exports=function(t,e){return function(r,c){var u,h=arguments[2],f=arguments[3];return r=Object(i(r)),n(c),u=s(r),f&&u.sort(\"function\"==typeof f?a.call(f,r):void 0),\"function\"!=typeof t&&(t=u[t]),o.call(t,u,function(t,n){return l.call(r,t)?o.call(c,h,r[t],t,r,n):e})}}},{\"./valid-callable\":203,\"./valid-value\":205}],186:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.assign:t(\"./shim\")},{\"./is-implemented\":187,\"./shim\":188}],187:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=Object.assign;return\"function\"==typeof e&&(e(t={foo:\"raz\"},{bar:\"dwa\"},{trzy:\"trzy\"}),t.foo+t.bar+t.trzy===\"razdwatrzy\")}},{}],188:[function(t,e,r){\"use strict\";var n=t(\"../keys\"),i=t(\"../valid-value\"),a=Math.max;e.exports=function(t,e){var r,o,s,l=a(arguments.length,2);for(t=Object(i(t)),s=function(n){try{t[n]=e[n]}catch(t){r||(r=t)}},o=1;o<l;++o)e=arguments[o],n(e).forEach(s);if(void 0!==r)throw r;return t}},{\"../keys\":195,\"../valid-value\":205}],189:[function(t,e,r){\"use strict\";var n=t(\"../array/from\"),i=t(\"./assign\"),a=t(\"./valid-value\");e.exports=function(t){var e=Object(a(t)),r=arguments[1],o=Object(arguments[2]);if(e!==t&&!r)return e;var s={};return r?n(r,function(e){(o.ensure||e in t)&&(s[e]=t[e])}):i(s,t),s}},{\"../array/from\":174,\"./assign\":186,\"./valid-value\":205}],190:[function(t,e,r){\"use strict\";var n,i,a,o,s=Object.create;t(\"./set-prototype-of/is-implemented\")()||(n=t(\"./set-prototype-of/shim\")),e.exports=n?1!==n.level?s:(i={},a={},o={configurable:!1,enumerable:!1,writable:!0,value:void 0},Object.getOwnPropertyNames(Object.prototype).forEach(function(t){a[t]=\"__proto__\"!==t?o:{configurable:!0,enumerable:!1,writable:!0,value:void 0}}),Object.defineProperties(i,a),Object.defineProperty(n,\"nullPolyfill\",{configurable:!1,enumerable:!1,writable:!1,value:i}),function(t,e){return s(null===t?i:t,e)}):s},{\"./set-prototype-of/is-implemented\":201,\"./set-prototype-of/shim\":202}],191:[function(t,e,r){\"use strict\";e.exports=t(\"./_iterate\")(\"forEach\")},{\"./_iterate\":185}],192:[function(t,e,r){\"use strict\";e.exports=function(t){return\"function\"==typeof t}},{}],193:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i={function:!0,object:!0};e.exports=function(t){return n(t)&&i[typeof t]||!1}},{\"./is-value\":194}],194:[function(t,e,r){\"use strict\";var n=t(\"../function/noop\")();e.exports=function(t){return t!==n&&null!==t}},{\"../function/noop\":179}],195:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.keys:t(\"./shim\")},{\"./is-implemented\":196,\"./shim\":197}],196:[function(t,e,r){\"use strict\";e.exports=function(){try{return Object.keys(\"primitive\"),!0}catch(t){return!1}}},{}],197:[function(t,e,r){\"use strict\";var n=t(\"../is-value\"),i=Object.keys;e.exports=function(t){return i(n(t)?Object(t):t)}},{\"../is-value\":194}],198:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./for-each\"),a=Function.prototype.call;e.exports=function(t,e){var r={},o=arguments[2];return n(e),i(t,function(t,n,i,s){r[n]=a.call(e,o,t,n,i,s)}),r}},{\"./for-each\":191,\"./valid-callable\":203}],199:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i=Array.prototype.forEach,a=Object.create;e.exports=function(t){var e=a(null);return i.call(arguments,function(t){n(t)&&function(t,e){var r;for(r in t)e[r]=t[r]}(Object(t),e)}),e}},{\"./is-value\":194}],200:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.setPrototypeOf:t(\"./shim\")},{\"./is-implemented\":201,\"./shim\":202}],201:[function(t,e,r){\"use strict\";var n=Object.create,i=Object.getPrototypeOf,a={};e.exports=function(){var t=Object.setPrototypeOf,e=arguments[0]||n;return\"function\"==typeof t&&i(t(e(null),a))===a}},{}],202:[function(t,e,r){\"use strict\";var n,i,a,o,s=t(\"../is-object\"),l=t(\"../valid-value\"),c=Object.prototype.isPrototypeOf,u=Object.defineProperty,h={configurable:!0,enumerable:!1,writable:!0,value:void 0};n=function(t,e){if(l(t),null===e||s(e))return t;throw new TypeError(\"Prototype must be null or an object\")},e.exports=(i=function(){var t,e=Object.create(null),r={},n=Object.getOwnPropertyDescriptor(Object.prototype,\"__proto__\");if(n){try{(t=n.set).call(e,r)}catch(t){}if(Object.getPrototypeOf(e)===r)return{set:t,level:2}}return e.__proto__=r,Object.getPrototypeOf(e)===r?{level:2}:((e={}).__proto__=r,Object.getPrototypeOf(e)===r&&{level:1})}())?(2===i.level?i.set?(o=i.set,a=function(t,e){return o.call(n(t,e),e),t}):a=function(t,e){return n(t,e).__proto__=e,t}:a=function t(e,r){var i;return n(e,r),(i=c.call(t.nullPolyfill,e))&&delete t.nullPolyfill.__proto__,null===r&&(r=t.nullPolyfill),e.__proto__=r,i&&u(t.nullPolyfill,\"__proto__\",h),e},Object.defineProperty(a,\"level\",{configurable:!1,enumerable:!1,writable:!1,value:i.level})):null,t(\"../create\")},{\"../create\":190,\"../is-object\":193,\"../valid-value\":205}],203:[function(t,e,r){\"use strict\";e.exports=function(t){if(\"function\"!=typeof t)throw new TypeError(t+\" is not a function\");return t}},{}],204:[function(t,e,r){\"use strict\";var n=t(\"./is-object\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not an Object\");return t}},{\"./is-object\":193}],205:[function(t,e,r){\"use strict\";var n=t(\"./is-value\");e.exports=function(t){if(!n(t))throw new TypeError(\"Cannot use null or undefined\");return t}},{\"./is-value\":194}],206:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?String.prototype.contains:t(\"./shim\")},{\"./is-implemented\":207,\"./shim\":208}],207:[function(t,e,r){\"use strict\";var n=\"razdwatrzy\";e.exports=function(){return\"function\"==typeof n.contains&&(!0===n.contains(\"dwa\")&&!1===n.contains(\"foo\"))}},{}],208:[function(t,e,r){\"use strict\";var n=String.prototype.indexOf;e.exports=function(t){return n.call(this,t,arguments[1])>-1}},{}],209:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(\"\");e.exports=function(t){return\"string\"==typeof t||t&&\"object\"==typeof t&&(t instanceof String||n.call(t)===i)||!1}},{}],210:[function(t,e,r){\"use strict\";var n=Object.create(null),i=Math.random;e.exports=function(){var t;do{t=i().toString(36).slice(2)}while(n[t]);return t}},{}],211:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"es5-ext/string/#/contains\"),o=t(\"d\"),s=t(\"es6-symbol\"),l=t(\"./\"),c=Object.defineProperty;n=e.exports=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");l.call(this,t),e=e?a.call(e,\"key+value\")?\"key+value\":a.call(e,\"key\")?\"key\":\"value\":\"value\",c(this,\"__kind__\",o(\"\",e))},i&&i(n,l),delete n.prototype.constructor,n.prototype=Object.create(l.prototype,{_resolve:o(function(t){return\"value\"===this.__kind__?this.__list__[t]:\"key+value\"===this.__kind__?[t,this.__list__[t]]:t})}),c(n.prototype,s.toStringTag,o(\"c\",\"Array Iterator\"))},{\"./\":214,d:151,\"es5-ext/object/set-prototype-of\":200,\"es5-ext/string/#/contains\":206,\"es6-symbol\":219}],212:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/valid-callable\"),a=t(\"es5-ext/string/is-string\"),o=t(\"./get\"),s=Array.isArray,l=Function.prototype.call,c=Array.prototype.some;e.exports=function(t,e){var r,u,h,f,p,d,g,v,m=arguments[2];if(s(t)||n(t)?r=\"array\":a(t)?r=\"string\":t=o(t),i(e),h=function(){f=!0},\"array\"!==r)if(\"string\"!==r)for(u=t.next();!u.done;){if(l.call(e,m,u.value,h),f)return;u=t.next()}else for(d=t.length,p=0;p<d&&(g=t[p],p+1<d&&(v=g.charCodeAt(0))>=55296&&v<=56319&&(g+=t[++p]),l.call(e,m,g,h),!f);++p);else c.call(t,function(t){return l.call(e,m,t,h),f})}},{\"./get\":213,\"es5-ext/function/is-arguments\":177,\"es5-ext/object/valid-callable\":203,\"es5-ext/string/is-string\":209}],213:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/string/is-string\"),a=t(\"./array\"),o=t(\"./string\"),s=t(\"./valid-iterable\"),l=t(\"es6-symbol\").iterator;e.exports=function(t){return\"function\"==typeof s(t)[l]?t[l]():n(t)?new a(t):i(t)?new o(t):new a(t)}},{\"./array\":211,\"./string\":216,\"./valid-iterable\":217,\"es5-ext/function/is-arguments\":177,\"es5-ext/string/is-string\":209,\"es6-symbol\":219}],214:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/array/#/clear\"),a=t(\"es5-ext/object/assign\"),o=t(\"es5-ext/object/valid-callable\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"d\"),c=t(\"d/auto-bind\"),u=t(\"es6-symbol\"),h=Object.defineProperty,f=Object.defineProperties;e.exports=n=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");f(this,{__list__:l(\"w\",s(t)),__context__:l(\"w\",e),__nextIndex__:l(\"w\",0)}),e&&(o(e.on),e.on(\"_add\",this._onAdd),e.on(\"_delete\",this._onDelete),e.on(\"_clear\",this._onClear))},delete n.prototype.constructor,f(n.prototype,a({_next:l(function(){var t;if(this.__list__)return this.__redo__&&void 0!==(t=this.__redo__.shift())?t:this.__nextIndex__<this.__list__.length?this.__nextIndex__++:void this._unBind()}),next:l(function(){return this._createResult(this._next())}),_createResult:l(function(t){return void 0===t?{done:!0,value:void 0}:{done:!1,value:this._resolve(t)}}),_resolve:l(function(t){return this.__list__[t]}),_unBind:l(function(){this.__list__=null,delete this.__redo__,this.__context__&&(this.__context__.off(\"_add\",this._onAdd),this.__context__.off(\"_delete\",this._onDelete),this.__context__.off(\"_clear\",this._onClear),this.__context__=null)}),toString:l(function(){return\"[object \"+(this[u.toStringTag]||\"Object\")+\"]\"})},c({_onAdd:l(function(t){t>=this.__nextIndex__||(++this.__nextIndex__,this.__redo__?(this.__redo__.forEach(function(e,r){e>=t&&(this.__redo__[r]=++e)},this),this.__redo__.push(t)):h(this,\"__redo__\",l(\"c\",[t])))}),_onDelete:l(function(t){var e;t>=this.__nextIndex__||(--this.__nextIndex__,this.__redo__&&(-1!==(e=this.__redo__.indexOf(t))&&this.__redo__.splice(e,1),this.__redo__.forEach(function(e,r){e>t&&(this.__redo__[r]=--e)},this)))}),_onClear:l(function(){this.__redo__&&i.call(this.__redo__),this.__nextIndex__=0})}))),h(n.prototype,u.iterator,l(function(){return this}))},{d:151,\"d/auto-bind\":150,\"es5-ext/array/#/clear\":173,\"es5-ext/object/assign\":186,\"es5-ext/object/valid-callable\":203,\"es5-ext/object/valid-value\":205,\"es6-symbol\":219}],215:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/string/is-string\"),o=t(\"es6-symbol\").iterator,s=Array.isArray;e.exports=function(t){return!!i(t)&&(!!s(t)||(!!a(t)||(!!n(t)||\"function\"==typeof t[o])))}},{\"es5-ext/function/is-arguments\":177,\"es5-ext/object/is-value\":194,\"es5-ext/string/is-string\":209,\"es6-symbol\":219}],216:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"d\"),o=t(\"es6-symbol\"),s=t(\"./\"),l=Object.defineProperty;n=e.exports=function(t){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");t=String(t),s.call(this,t),l(this,\"__length__\",a(\"\",t.length))},i&&i(n,s),delete n.prototype.constructor,n.prototype=Object.create(s.prototype,{_next:a(function(){if(this.__list__)return this.__nextIndex__<this.__length__?this.__nextIndex__++:void this._unBind()}),_resolve:a(function(t){var e,r=this.__list__[t];return this.__nextIndex__===this.__length__?r:(e=r.charCodeAt(0))>=55296&&e<=56319?r+this.__list__[this.__nextIndex__++]:r})}),l(n.prototype,o.toStringTag,a(\"c\",\"String Iterator\"))},{\"./\":214,d:151,\"es5-ext/object/set-prototype-of\":200,\"es6-symbol\":219}],217:[function(t,e,r){\"use strict\";var n=t(\"./is-iterable\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not iterable\");return t}},{\"./is-iterable\":215}],218:[function(t,e,r){(function(n,i){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():t.ES6Promise=n()}(this,function(){\"use strict\";function e(t){return\"function\"==typeof t}var r=Array.isArray?Array.isArray:function(t){return\"[object Array]\"===Object.prototype.toString.call(t)},a=0,o=void 0,s=void 0,l=function(t,e){g[a]=t,g[a+1]=e,2===(a+=2)&&(s?s(v):_())};var c=\"undefined\"!=typeof window?window:void 0,u=c||{},h=u.MutationObserver||u.WebKitMutationObserver,f=\"undefined\"==typeof self&&\"undefined\"!=typeof n&&\"[object process]\"==={}.toString.call(n),p=\"undefined\"!=typeof Uint8ClampedArray&&\"undefined\"!=typeof importScripts&&\"undefined\"!=typeof MessageChannel;function d(){var t=setTimeout;return function(){return t(v,1)}}var g=new Array(1e3);function v(){for(var t=0;t<a;t+=2){(0,g[t])(g[t+1]),g[t]=void 0,g[t+1]=void 0}a=0}var m,y,x,b,_=void 0;function w(t,e){var r=arguments,n=this,i=new this.constructor(A);void 0===i[T]&&V(i);var a,o=n._state;return o?(a=r[o-1],l(function(){return j(o,i,a,n._result)})):R(n,i,t,e),i}function k(t){if(t&&\"object\"==typeof t&&t.constructor===this)return t;var e=new this(A);return O(e,t),e}f?_=function(){return n.nextTick(v)}:h?(y=0,x=new h(v),b=document.createTextNode(\"\"),x.observe(b,{characterData:!0}),_=function(){b.data=y=++y%2}):p?((m=new MessageChannel).port1.onmessage=v,_=function(){return m.port2.postMessage(0)}):_=void 0===c&&\"function\"==typeof t?function(){try{var e=t(\"vertx\");return o=e.runOnLoop||e.runOnContext,function(){o(v)}}catch(t){return d()}}():d();var T=Math.random().toString(36).substring(16);function A(){}var M=void 0,S=1,E=2,C=new B;function L(t){try{return t.then}catch(t){return C.error=t,C}}function P(t,r,n){r.constructor===t.constructor&&n===w&&r.constructor.resolve===k?function(t,e){e._state===S?I(t,e._result):e._state===E?D(t,e._result):R(e,void 0,function(e){return O(t,e)},function(e){return D(t,e)})}(t,r):n===C?D(t,C.error):void 0===n?I(t,r):e(n)?function(t,e,r){l(function(t){var n=!1,i=function(t,e,r,n){try{t.call(e,r,n)}catch(t){return t}}(r,e,function(r){n||(n=!0,e!==r?O(t,r):I(t,r))},function(e){n||(n=!0,D(t,e))},t._label);!n&&i&&(n=!0,D(t,i))},t)}(t,r,n):I(t,r)}function O(t,e){var r;t===e?D(t,new TypeError(\"You cannot resolve a promise with itself\")):\"function\"==typeof(r=e)||\"object\"==typeof r&&null!==r?P(t,e,L(e)):I(t,e)}function z(t){t._onerror&&t._onerror(t._result),F(t)}function I(t,e){t._state===M&&(t._result=e,t._state=S,0!==t._subscribers.length&&l(F,t))}function D(t,e){t._state===M&&(t._state=E,t._result=e,l(z,t))}function R(t,e,r,n){var i=t._subscribers,a=i.length;t._onerror=null,i[a]=e,i[a+S]=r,i[a+E]=n,0===a&&t._state&&l(F,t)}function F(t){var e=t._subscribers,r=t._state;if(0!==e.length){for(var n=void 0,i=void 0,a=t._result,o=0;o<e.length;o+=3)n=e[o],i=e[o+r],n?j(r,n,i,a):i(a);t._subscribers.length=0}}function B(){this.error=null}var N=new B;function j(t,r,n,i){var a=e(n),o=void 0,s=void 0,l=void 0,c=void 0;if(a){if((o=function(t,e){try{return t(e)}catch(t){return N.error=t,N}}(n,i))===N?(c=!0,s=o.error,o=null):l=!0,r===o)return void D(r,new TypeError(\"A promises callback cannot return that same promise.\"))}else o=i,l=!0;r._state!==M||(a&&l?O(r,o):c?D(r,s):t===S?I(r,o):t===E&&D(r,o))}var U=0;function V(t){t[T]=U++,t._state=void 0,t._result=void 0,t._subscribers=[]}function q(t,e){this._instanceConstructor=t,this.promise=new t(A),this.promise[T]||V(this.promise),r(e)?(this._input=e,this.length=e.length,this._remaining=e.length,this._result=new Array(this.length),0===this.length?I(this.promise,this._result):(this.length=this.length||0,this._enumerate(),0===this._remaining&&I(this.promise,this._result))):D(this.promise,new Error(\"Array Methods must be provided an Array\"))}function H(t){this[T]=U++,this._result=this._state=void 0,this._subscribers=[],A!==t&&(\"function\"!=typeof t&&function(){throw new TypeError(\"You must pass a resolver function as the first argument to the promise constructor\")}(),this instanceof H?function(t,e){try{e(function(e){O(t,e)},function(e){D(t,e)})}catch(e){D(t,e)}}(this,t):function(){throw new TypeError(\"Failed to construct 'Promise': Please use the 'new' operator, this object constructor cannot be called as a function.\")}())}function G(){var t=void 0;if(\"undefined\"!=typeof i)t=i;else if(\"undefined\"!=typeof self)t=self;else try{t=Function(\"return this\")()}catch(t){throw new Error(\"polyfill failed because global object is unavailable in this environment\")}var e=t.Promise;if(e){var r=null;try{r=Object.prototype.toString.call(e.resolve())}catch(t){}if(\"[object Promise]\"===r&&!e.cast)return}t.Promise=H}return q.prototype._enumerate=function(){for(var t=this.length,e=this._input,r=0;this._state===M&&r<t;r++)this._eachEntry(e[r],r)},q.prototype._eachEntry=function(t,e){var r=this._instanceConstructor,n=r.resolve;if(n===k){var i=L(t);if(i===w&&t._state!==M)this._settledAt(t._state,e,t._result);else if(\"function\"!=typeof i)this._remaining--,this._result[e]=t;else if(r===H){var a=new r(A);P(a,t,i),this._willSettleAt(a,e)}else this._willSettleAt(new r(function(e){return e(t)}),e)}else this._willSettleAt(n(t),e)},q.prototype._settledAt=function(t,e,r){var n=this.promise;n._state===M&&(this._remaining--,t===E?D(n,r):this._result[e]=r),0===this._remaining&&I(n,this._result)},q.prototype._willSettleAt=function(t,e){var r=this;R(t,void 0,function(t){return r._settledAt(S,e,t)},function(t){return r._settledAt(E,e,t)})},H.all=function(t){return new q(this,t).promise},H.race=function(t){var e=this;return r(t)?new e(function(r,n){for(var i=t.length,a=0;a<i;a++)e.resolve(t[a]).then(r,n)}):new e(function(t,e){return e(new TypeError(\"You must pass an array to race.\"))})},H.resolve=k,H.reject=function(t){var e=new this(A);return D(e,t),e},H._setScheduler=function(t){s=t},H._setAsap=function(t){l=t},H._asap=l,H.prototype={constructor:H,then:w,catch:function(t){return this.then(null,t)}},G(),H.polyfill=G,H.Promise=H,H})}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{_process:482}],219:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Symbol:t(\"./polyfill\")},{\"./is-implemented\":220,\"./polyfill\":222}],220:[function(t,e,r){\"use strict\";var n={object:!0,symbol:!0};e.exports=function(){var t;if(\"function\"!=typeof Symbol)return!1;t=Symbol(\"test symbol\");try{String(t)}catch(t){return!1}return!!n[typeof Symbol.iterator]&&(!!n[typeof Symbol.toPrimitive]&&!!n[typeof Symbol.toStringTag])}},{}],221:[function(t,e,r){\"use strict\";e.exports=function(t){return!!t&&(\"symbol\"==typeof t||!!t.constructor&&(\"Symbol\"===t.constructor.name&&\"Symbol\"===t[t.constructor.toStringTag]))}},{}],222:[function(t,e,r){\"use strict\";var n,i,a,o,s=t(\"d\"),l=t(\"./validate-symbol\"),c=Object.create,u=Object.defineProperties,h=Object.defineProperty,f=Object.prototype,p=c(null);if(\"function\"==typeof Symbol){n=Symbol;try{String(n()),o=!0}catch(t){}}var d,g=(d=c(null),function(t){for(var e,r,n=0;d[t+(n||\"\")];)++n;return d[t+=n||\"\"]=!0,h(f,e=\"@@\"+t,s.gs(null,function(t){r||(r=!0,h(this,e,s(t)),r=!1)})),e});a=function(t){if(this instanceof a)throw new TypeError(\"Symbol is not a constructor\");return i(t)},e.exports=i=function t(e){var r;if(this instanceof t)throw new TypeError(\"Symbol is not a constructor\");return o?n(e):(r=c(a.prototype),e=void 0===e?\"\":String(e),u(r,{__description__:s(\"\",e),__name__:s(\"\",g(e))}))},u(i,{for:s(function(t){return p[t]?p[t]:p[t]=i(String(t))}),keyFor:s(function(t){var e;for(e in l(t),p)if(p[e]===t)return e}),hasInstance:s(\"\",n&&n.hasInstance||i(\"hasInstance\")),isConcatSpreadable:s(\"\",n&&n.isConcatSpreadable||i(\"isConcatSpreadable\")),iterator:s(\"\",n&&n.iterator||i(\"iterator\")),match:s(\"\",n&&n.match||i(\"match\")),replace:s(\"\",n&&n.replace||i(\"replace\")),search:s(\"\",n&&n.search||i(\"search\")),species:s(\"\",n&&n.species||i(\"species\")),split:s(\"\",n&&n.split||i(\"split\")),toPrimitive:s(\"\",n&&n.toPrimitive||i(\"toPrimitive\")),toStringTag:s(\"\",n&&n.toStringTag||i(\"toStringTag\")),unscopables:s(\"\",n&&n.unscopables||i(\"unscopables\"))}),u(a.prototype,{constructor:s(i),toString:s(\"\",function(){return this.__name__})}),u(i.prototype,{toString:s(function(){return\"Symbol (\"+l(this).__description__+\")\"}),valueOf:s(function(){return l(this)})}),h(i.prototype,i.toPrimitive,s(\"\",function(){var t=l(this);return\"symbol\"==typeof t?t:t.toString()})),h(i.prototype,i.toStringTag,s(\"c\",\"Symbol\")),h(a.prototype,i.toStringTag,s(\"c\",i.prototype[i.toStringTag])),h(a.prototype,i.toPrimitive,s(\"c\",i.prototype[i.toPrimitive]))},{\"./validate-symbol\":223,d:151}],223:[function(t,e,r){\"use strict\";var n=t(\"./is-symbol\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not a symbol\");return t}},{\"./is-symbol\":221}],224:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=e||0,i=r||1;return[[t[12]+t[0],t[13]+t[1],t[14]+t[2],t[15]+t[3]],[t[12]-t[0],t[13]-t[1],t[14]-t[2],t[15]-t[3]],[t[12]+t[4],t[13]+t[5],t[14]+t[6],t[15]+t[7]],[t[12]-t[4],t[13]-t[5],t[14]-t[6],t[15]-t[7]],[n*t[12]+t[8],n*t[13]+t[9],n*t[14]+t[10],n*t[15]+t[11]],[i*t[12]-t[8],i*t[13]-t[9],i*t[14]-t[10],i*t[15]-t[11]]]}},{}],225:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\");e.exports=function(t){var e=typeof t;if(\"string\"===e){var r=t;if(0===(t=+t)&&n(r))return!1}else if(\"number\"!==e)return!1;return t-t<1}},{\"is-string-blank\":423}],226:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 0:return new o([0],[0],0);case 1:if(\"number\"==typeof t){var n=l(t);return new o(n,n,0)}return new o(t,l(t.length),0);case 2:if(\"number\"==typeof e){var n=l(t.length);return new o(t,n,+e)}r=0;case 3:if(t.length!==e.length)throw new Error(\"state and velocity lengths must match\");return new o(t,e,r)}};var n=t(\"cubic-hermite\"),i=t(\"binary-search-bounds\");function a(t,e,r){return Math.min(e,Math.max(t,r))}function o(t,e,r){this.dimension=t.length,this.bounds=[new Array(this.dimension),new Array(this.dimension)];for(var n=0;n<this.dimension;++n)this.bounds[0][n]=-1/0,this.bounds[1][n]=1/0;this._state=t.slice().reverse(),this._velocity=e.slice().reverse(),this._time=[r],this._scratch=[t.slice(),t.slice(),t.slice(),t.slice(),t.slice()]}var s=o.prototype;function l(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=0;return e}s.flush=function(t){var e=i.gt(this._time,t)-1;e<=0||(this._time.splice(0,e),this._state.splice(0,e*this.dimension),this._velocity.splice(0,e*this.dimension))},s.curve=function(t){var e=this._time,r=e.length,o=i.le(e,t),s=this._scratch[0],l=this._state,c=this._velocity,u=this.dimension,h=this.bounds;if(o<0)for(var f=u-1,p=0;p<u;++p,--f)s[p]=l[f];else if(o>=r-1){f=l.length-1;var d=t-e[r-1];for(p=0;p<u;++p,--f)s[p]=l[f]+d*c[f]}else{f=u*(o+1)-1;var g=e[o],v=e[o+1]-g||1,m=this._scratch[1],y=this._scratch[2],x=this._scratch[3],b=this._scratch[4],_=!0;for(p=0;p<u;++p,--f)m[p]=l[f],x[p]=c[f]*v,y[p]=l[f+u],b[p]=c[f+u]*v,_=_&&m[p]===y[p]&&x[p]===b[p]&&0===x[p];if(_)for(p=0;p<u;++p)s[p]=m[p];else n(m,x,y,b,(t-g)/v,s)}var w=h[0],k=h[1];for(p=0;p<u;++p)s[p]=a(w[p],k[p],s[p]);return s},s.dcurve=function(t){var e=this._time,r=e.length,a=i.le(e,t),o=this._scratch[0],s=this._state,l=this._velocity,c=this.dimension;if(a>=r-1)for(var u=s.length-1,h=(e[r-1],0);h<c;++h,--u)o[h]=l[u];else{u=c*(a+1)-1;var f=e[a],p=e[a+1]-f||1,d=this._scratch[1],g=this._scratch[2],v=this._scratch[3],m=this._scratch[4],y=!0;for(h=0;h<c;++h,--u)d[h]=s[u],v[h]=l[u]*p,g[h]=s[u+c],m[h]=l[u+c]*p,y=y&&d[h]===g[h]&&v[h]===m[h]&&0===v[h];if(y)for(h=0;h<c;++h)o[h]=0;else{n.derivative(d,v,g,m,(t-f)/p,o);for(h=0;h<c;++h)o[h]/=p}}return o},s.lastT=function(){var t=this._time;return t[t.length-1]},s.stable=function(){for(var t=this._velocity,e=t.length,r=this.dimension-1;r>=0;--r)if(t[--e])return!1;return!0},s.jump=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1];this._time.push(e,t);for(var u=0;u<2;++u)for(var h=0;h<r;++h)n.push(n[o++]),i.push(0);this._time.push(t);for(h=r;h>0;--h)n.push(a(l[h-1],c[h-1],arguments[h])),i.push(0)}},s.push=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=t-e,l=this.bounds,c=l[0],u=l[1],h=s>1e-6?1/s:0;this._time.push(t);for(var f=r;f>0;--f){var p=a(c[f-1],u[f-1],arguments[f]);n.push(p),i.push((p-n[o++])*h)}}},s.set=function(t){var e=this.dimension;if(!(t<this.lastT()||arguments.length!==e+1)){var r=this._state,n=this._velocity,i=this.bounds,o=i[0],s=i[1];this._time.push(t);for(var l=e;l>0;--l)r.push(a(o[l-1],s[l-1],arguments[l])),n.push(0)}},s.move=function(t){var e=this.lastT(),r=this.dimension;if(!(t<=e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1],u=t-e,h=u>1e-6?1/u:0;this._time.push(t);for(var f=r;f>0;--f){var p=arguments[f];n.push(a(l[f-1],c[f-1],n[o++]+p)),i.push(p*h)}}},s.idle=function(t){var e=this.lastT();if(!(t<e)){var r=this.dimension,n=this._state,i=this._velocity,o=n.length-r,s=this.bounds,l=s[0],c=s[1],u=t-e;this._time.push(t);for(var h=r-1;h>=0;--h)n.push(a(l[h],c[h],n[o]+u*i[o])),i.push(0),o+=1}}},{\"binary-search-bounds\":91,\"cubic-hermite\":145}],227:[function(t,e,r){var n=t(\"dtype\");e.exports=function(t,e,r){if(!t)throw new TypeError(\"must specify data as first parameter\");if(r=0|+(r||0),Array.isArray(t)&&t[0]&&\"number\"==typeof t[0][0]){var i,a,o,s,l=t[0].length,c=t.length*l;e&&\"string\"!=typeof e||(e=new(n(e||\"float32\"))(c+r));var u=e.length-r;if(c!==u)throw new Error(\"source length \"+c+\" (\"+l+\"x\"+t.length+\") does not match destination length \"+u);for(i=0,o=r;i<t.length;i++)for(a=0;a<l;a++)e[o++]=null===t[i][a]?NaN:t[i][a]}else if(e&&\"string\"!=typeof e)e.set(t,r);else{var h=n(e||\"float32\");if(Array.isArray(t)||\"array\"===e)for(e=new h(t.length+r),i=0,o=r,s=e.length;o<s;o++,i++)e[o]=null===t[i]?NaN:t[i];else 0===r?e=new h(t):(e=new h(t.length+r)).set(t,r)}return e}},{dtype:169}],228:[function(t,e,r){\"use strict\";var n=t(\"css-font/stringify\"),i=[32,126];e.exports=function(t){var e=(t=t||{}).shape?t.shape:t.canvas?[t.canvas.width,t.canvas.height]:[512,512],r=t.canvas||document.createElement(\"canvas\"),a=t.font,o=\"number\"==typeof t.step?[t.step,t.step]:t.step||[32,32],s=t.chars||i;a&&\"string\"!=typeof a&&(a=n(a));if(Array.isArray(s)){if(2===s.length&&\"number\"==typeof s[0]&&\"number\"==typeof s[1]){for(var l=[],c=s[0],u=0;c<=s[1];c++)l[u++]=String.fromCharCode(c);s=l}}else s=String(s).split(\"\");e=e.slice(),r.width=e[0],r.height=e[1];var h=r.getContext(\"2d\");h.fillStyle=\"#000\",h.fillRect(0,0,r.width,r.height),h.font=a,h.textAlign=\"center\",h.textBaseline=\"middle\",h.fillStyle=\"#fff\";for(var f=o[0]/2,p=o[1]/2,c=0;c<s.length;c++)h.fillText(s[c],f,p),(f+=o[0])>e[0]-o[0]/2&&(f=o[0]/2,p+=o[1]);return r}},{\"css-font/stringify\":142}],229:[function(t,e,r){\"use strict\";function n(t,e){e||(e={}),(\"string\"==typeof t||Array.isArray(t))&&(e.family=t);var r=Array.isArray(e.family)?e.family.join(\", \"):e.family;if(!r)throw Error(\"`family` must be defined\");var s=e.size||e.fontSize||e.em||48,l=e.weight||e.fontWeight||\"\",c=(t=[e.style||e.fontStyle||\"\",l,s].join(\" \")+\"px \"+r,e.origin||\"top\");if(n.cache[r]&&s<=n.cache[r].em)return i(n.cache[r],c);var u=e.canvas||n.canvas,h=u.getContext(\"2d\"),f={upper:void 0!==e.upper?e.upper:\"H\",lower:void 0!==e.lower?e.lower:\"x\",descent:void 0!==e.descent?e.descent:\"p\",ascent:void 0!==e.ascent?e.ascent:\"h\",tittle:void 0!==e.tittle?e.tittle:\"i\",overshoot:void 0!==e.overshoot?e.overshoot:\"O\"},p=Math.ceil(1.5*s);u.height=p,u.width=.5*p,h.font=t;var d={top:0};h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillStyle=\"black\",h.fillText(\"H\",0,0);var g=a(h.getImageData(0,0,p,p));h.clearRect(0,0,p,p),h.textBaseline=\"bottom\",h.fillText(\"H\",0,p);var v=a(h.getImageData(0,0,p,p));d.lineHeight=d.bottom=p-v+g,h.clearRect(0,0,p,p),h.textBaseline=\"alphabetic\",h.fillText(\"H\",0,p);var m=p-a(h.getImageData(0,0,p,p))-1+g;d.baseline=d.alphabetic=m,h.clearRect(0,0,p,p),h.textBaseline=\"middle\",h.fillText(\"H\",0,.5*p);var y=a(h.getImageData(0,0,p,p));d.median=d.middle=p-y-1+g-.5*p,h.clearRect(0,0,p,p),h.textBaseline=\"hanging\",h.fillText(\"H\",0,.5*p);var x=a(h.getImageData(0,0,p,p));d.hanging=p-x-1+g-.5*p,h.clearRect(0,0,p,p),h.textBaseline=\"ideographic\",h.fillText(\"H\",0,p);var b=a(h.getImageData(0,0,p,p));if(d.ideographic=p-b-1+g,f.upper&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.upper,0,0),d.upper=a(h.getImageData(0,0,p,p)),d.capHeight=d.baseline-d.upper),f.lower&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.lower,0,0),d.lower=a(h.getImageData(0,0,p,p)),d.xHeight=d.baseline-d.lower),f.tittle&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.tittle,0,0),d.tittle=a(h.getImageData(0,0,p,p))),f.ascent&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.ascent,0,0),d.ascent=a(h.getImageData(0,0,p,p))),f.descent&&(h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.descent,0,0),d.descent=o(h.getImageData(0,0,p,p))),f.overshoot){h.clearRect(0,0,p,p),h.textBaseline=\"top\",h.fillText(f.overshoot,0,0);var _=o(h.getImageData(0,0,p,p));d.overshoot=_-m}for(var w in d)d[w]/=s;return d.em=s,n.cache[r]=d,i(d,c)}function i(t,e){var r={};for(var n in\"string\"==typeof e&&(e=t[e]),t)\"em\"!==n&&(r[n]=t[n]-e);return r}function a(t){for(var e=t.height,r=t.data,n=3;n<r.length;n+=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}function o(t){for(var e=t.height,r=t.data,n=r.length-1;n>0;n-=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}e.exports=n,n.canvas=document.createElement(\"canvas\"),n.cache={}},{}],230:[function(t,e,r){\"use strict\";e.exports=function(t){return new c(t||d,null)};var n=0,i=1;function a(t,e,r,n,i,a){this._color=t,this.key=e,this.value=r,this.left=n,this.right=i,this._count=a}function o(t){return new a(t._color,t.key,t.value,t.left,t.right,t._count)}function s(t,e){return new a(t,e.key,e.value,e.left,e.right,e._count)}function l(t){t._count=1+(t.left?t.left._count:0)+(t.right?t.right._count:0)}function c(t,e){this._compare=t,this.root=e}var u=c.prototype;function h(t,e){this.tree=t,this._stack=e}Object.defineProperty(u,\"keys\",{get:function(){var t=[];return this.forEach(function(e,r){t.push(e)}),t}}),Object.defineProperty(u,\"values\",{get:function(){var t=[];return this.forEach(function(e,r){t.push(r)}),t}}),Object.defineProperty(u,\"length\",{get:function(){return this.root?this.root._count:0}}),u.insert=function(t,e){for(var r=this._compare,o=this.root,u=[],h=[];o;){var f=r(t,o.key);u.push(o),h.push(f),o=f<=0?o.left:o.right}u.push(new a(n,t,e,null,null,1));for(var p=u.length-2;p>=0;--p){o=u[p];h[p]<=0?u[p]=new a(o._color,o.key,o.value,u[p+1],o.right,o._count+1):u[p]=new a(o._color,o.key,o.value,o.left,u[p+1],o._count+1)}for(p=u.length-1;p>1;--p){var d=u[p-1];o=u[p];if(d._color===i||o._color===i)break;var g=u[p-2];if(g.left===d)if(d.left===o){if(!(v=g.right)||v._color!==n){if(g._color=n,g.left=d.right,d._color=i,d.right=g,u[p-2]=d,u[p-1]=o,l(g),l(d),p>=3)(m=u[p-3]).left===g?m.left=d:m.right=d;break}d._color=i,g.right=s(i,v),g._color=n,p-=1}else{if(!(v=g.right)||v._color!==n){if(d.right=o.left,g._color=n,g.left=o.right,o._color=i,o.left=d,o.right=g,u[p-2]=o,u[p-1]=d,l(g),l(d),l(o),p>=3)(m=u[p-3]).left===g?m.left=o:m.right=o;break}d._color=i,g.right=s(i,v),g._color=n,p-=1}else if(d.right===o){if(!(v=g.left)||v._color!==n){if(g._color=n,g.right=d.left,d._color=i,d.left=g,u[p-2]=d,u[p-1]=o,l(g),l(d),p>=3)(m=u[p-3]).right===g?m.right=d:m.left=d;break}d._color=i,g.left=s(i,v),g._color=n,p-=1}else{var v;if(!(v=g.left)||v._color!==n){var m;if(d.left=o.right,g._color=n,g.right=o.left,o._color=i,o.right=d,o.left=g,u[p-2]=o,u[p-1]=d,l(g),l(d),l(o),p>=3)(m=u[p-3]).right===g?m.right=o:m.left=o;break}d._color=i,g.left=s(i,v),g._color=n,p-=1}}return u[0]._color=i,new c(r,u[0])},u.forEach=function(t,e,r){if(this.root)switch(arguments.length){case 1:return function t(e,r){var n;if(r.left&&(n=t(e,r.left)))return n;return(n=e(r.key,r.value))||(r.right?t(e,r.right):void 0)}(t,this.root);case 2:return function t(e,r,n,i){if(r(e,i.key)<=0){var a;if(i.left&&(a=t(e,r,n,i.left)))return a;if(a=n(i.key,i.value))return a}if(i.right)return t(e,r,n,i.right)}(e,this._compare,t,this.root);case 3:if(this._compare(e,r)>=0)return;return function t(e,r,n,i,a){var o,s=n(e,a.key),l=n(r,a.key);if(s<=0){if(a.left&&(o=t(e,r,n,i,a.left)))return o;if(l>0&&(o=i(a.key,a.value)))return o}if(l>0&&a.right)return t(e,r,n,i,a.right)}(e,r,this._compare,t,this.root)}},Object.defineProperty(u,\"begin\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.left;return new h(this,t)}}),Object.defineProperty(u,\"end\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.right;return new h(this,t)}}),u.at=function(t){if(t<0)return new h(this,[]);for(var e=this.root,r=[];;){if(r.push(e),e.left){if(t<e.left._count){e=e.left;continue}t-=e.left._count}if(!t)return new h(this,r);if(t-=1,!e.right)break;if(t>=e.right._count)break;e=e.right}return new h(this,[])},u.ge=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<=0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},u.gt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},u.lt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},u.le=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>=0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},u.find=function(t){for(var e=this._compare,r=this.root,n=[];r;){var i=e(t,r.key);if(n.push(r),0===i)return new h(this,n);r=i<=0?r.left:r.right}return new h(this,[])},u.remove=function(t){var e=this.find(t);return e?e.remove():this},u.get=function(t){for(var e=this._compare,r=this.root;r;){var n=e(t,r.key);if(0===n)return r.value;r=n<=0?r.left:r.right}};var f=h.prototype;function p(t,e){t.key=e.key,t.value=e.value,t.left=e.left,t.right=e.right,t._color=e._color,t._count=e._count}function d(t,e){return t<e?-1:t>e?1:0}Object.defineProperty(f,\"valid\",{get:function(){return this._stack.length>0}}),Object.defineProperty(f,\"node\",{get:function(){return this._stack.length>0?this._stack[this._stack.length-1]:null},enumerable:!0}),f.clone=function(){return new h(this.tree,this._stack.slice())},f.remove=function(){var t=this._stack;if(0===t.length)return this.tree;var e=new Array(t.length),r=t[t.length-1];e[e.length-1]=new a(r._color,r.key,r.value,r.left,r.right,r._count);for(var u=t.length-2;u>=0;--u){(r=t[u]).left===t[u+1]?e[u]=new a(r._color,r.key,r.value,e[u+1],r.right,r._count):e[u]=new a(r._color,r.key,r.value,r.left,e[u+1],r._count)}if((r=e[e.length-1]).left&&r.right){var h=e.length;for(r=r.left;r.right;)e.push(r),r=r.right;var f=e[h-1];e.push(new a(r._color,f.key,f.value,r.left,r.right,r._count)),e[h-1].key=r.key,e[h-1].value=r.value;for(u=e.length-2;u>=h;--u)r=e[u],e[u]=new a(r._color,r.key,r.value,r.left,e[u+1],r._count);e[h-1].left=e[h]}if((r=e[e.length-1])._color===n){var d=e[e.length-2];d.left===r?d.left=null:d.right===r&&(d.right=null),e.pop();for(u=0;u<e.length;++u)e[u]._count--;return new c(this.tree._compare,e[0])}if(r.left||r.right){r.left?p(r,r.left):r.right&&p(r,r.right),r._color=i;for(u=0;u<e.length-1;++u)e[u]._count--;return new c(this.tree._compare,e[0])}if(1===e.length)return new c(this.tree._compare,null);for(u=0;u<e.length;++u)e[u]._count--;var g=e[e.length-2];return function(t){for(var e,r,a,c,u=t.length-1;u>=0;--u){if(e=t[u],0===u)return void(e._color=i);if((r=t[u-1]).left===e){if((a=r.right).right&&a.right._color===n)return c=(a=r.right=o(a)).right=o(a.right),r.right=a.left,a.left=r,a.right=c,a._color=r._color,e._color=i,r._color=i,c._color=i,l(r),l(a),u>1&&((h=t[u-2]).left===r?h.left=a:h.right=a),void(t[u-1]=a);if(a.left&&a.left._color===n)return c=(a=r.right=o(a)).left=o(a.left),r.right=c.left,a.left=c.right,c.left=r,c.right=a,c._color=r._color,r._color=i,a._color=i,e._color=i,l(r),l(a),l(c),u>1&&((h=t[u-2]).left===r?h.left=c:h.right=c),void(t[u-1]=c);if(a._color===i){if(r._color===n)return r._color=i,void(r.right=s(n,a));r.right=s(n,a);continue}a=o(a),r.right=a.left,a.left=r,a._color=r._color,r._color=n,l(r),l(a),u>1&&((h=t[u-2]).left===r?h.left=a:h.right=a),t[u-1]=a,t[u]=r,u+1<t.length?t[u+1]=e:t.push(e),u+=2}else{if((a=r.left).left&&a.left._color===n)return c=(a=r.left=o(a)).left=o(a.left),r.left=a.right,a.right=r,a.left=c,a._color=r._color,e._color=i,r._color=i,c._color=i,l(r),l(a),u>1&&((h=t[u-2]).right===r?h.right=a:h.left=a),void(t[u-1]=a);if(a.right&&a.right._color===n)return c=(a=r.left=o(a)).right=o(a.right),r.left=c.right,a.right=c.left,c.right=r,c.left=a,c._color=r._color,r._color=i,a._color=i,e._color=i,l(r),l(a),l(c),u>1&&((h=t[u-2]).right===r?h.right=c:h.left=c),void(t[u-1]=c);if(a._color===i){if(r._color===n)return r._color=i,void(r.left=s(n,a));r.left=s(n,a);continue}var h;a=o(a),r.left=a.right,a.right=r,a._color=r._color,r._color=n,l(r),l(a),u>1&&((h=t[u-2]).right===r?h.right=a:h.left=a),t[u-1]=a,t[u]=r,u+1<t.length?t[u+1]=e:t.push(e),u+=2}}}(e),g.left===r?g.left=null:g.right=null,new c(this.tree._compare,e[0])},Object.defineProperty(f,\"key\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].key},enumerable:!0}),Object.defineProperty(f,\"value\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].value},enumerable:!0}),Object.defineProperty(f,\"index\",{get:function(){var t=0,e=this._stack;if(0===e.length){var r=this.tree.root;return r?r._count:0}e[e.length-1].left&&(t=e[e.length-1].left._count);for(var n=e.length-2;n>=0;--n)e[n+1]===e[n].right&&(++t,e[n].left&&(t+=e[n].left._count));return t},enumerable:!0}),f.next=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.right)for(e=e.right;e;)t.push(e),e=e.left;else for(t.pop();t.length>0&&t[t.length-1].right===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(f,\"hasNext\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].right)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].left===t[e])return!0;return!1}}),f.update=function(t){var e=this._stack;if(0===e.length)throw new Error(\"Can't update empty node!\");var r=new Array(e.length),n=e[e.length-1];r[r.length-1]=new a(n._color,n.key,t,n.left,n.right,n._count);for(var i=e.length-2;i>=0;--i)(n=e[i]).left===e[i+1]?r[i]=new a(n._color,n.key,n.value,r[i+1],n.right,n._count):r[i]=new a(n._color,n.key,n.value,n.left,r[i+1],n._count);return new c(this.tree._compare,r[0])},f.prev=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.left)for(e=e.left;e;)t.push(e),e=e.right;else for(t.pop();t.length>0&&t[t.length-1].left===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(f,\"hasPrev\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].left)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].right===t[e])return!0;return!1}})},{}],231:[function(t,e,r){var n=[.9999999999998099,676.5203681218851,-1259.1392167224028,771.3234287776531,-176.6150291621406,12.507343278686905,-.13857109526572012,9984369578019572e-21,1.5056327351493116e-7],i=607/128,a=[.9999999999999971,57.15623566586292,-59.59796035547549,14.136097974741746,-.4919138160976202,3399464998481189e-20,4652362892704858e-20,-9837447530487956e-20,.0001580887032249125,-.00021026444172410488,.00021743961811521265,-.0001643181065367639,8441822398385275e-20,-26190838401581408e-21,36899182659531625e-22];function o(t){if(t<0)return Number(\"0/0\");for(var e=a[0],r=a.length-1;r>0;--r)e+=a[r]/(t+r);var n=t+i+.5;return.5*Math.log(2*Math.PI)+(t+.5)*Math.log(n)-n+Math.log(e)-Math.log(t)}e.exports=function t(e){if(e<.5)return Math.PI/(Math.sin(Math.PI*e)*t(1-e));if(e>100)return Math.exp(o(e));e-=1;for(var r=n[0],i=1;i<9;i++)r+=n[i]/(e+i);var a=e+7+.5;return Math.sqrt(2*Math.PI)*Math.pow(a,e+.5)*Math.exp(-a)*r},e.exports.log=o},{}],232:[function(t,e,r){e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"must specify type string\");if(e=e||{},\"undefined\"==typeof document&&!e.canvas)return null;var r=e.canvas||document.createElement(\"canvas\");\"number\"==typeof e.width&&(r.width=e.width);\"number\"==typeof e.height&&(r.height=e.height);var n,i=e;try{var a=[t];0===t.indexOf(\"webgl\")&&a.push(\"experimental-\"+t);for(var o=0;o<a.length;o++)if(n=r.getContext(a[o],i))return n}catch(t){n=null}return n||null}},{}],233:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=new u(t);return r.update(e),r};var n=t(\"./lib/text.js\"),i=t(\"./lib/lines.js\"),a=t(\"./lib/background.js\"),o=t(\"./lib/cube.js\"),s=t(\"./lib/ticks.js\"),l=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]);function c(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function u(t){this.gl=t,this.pixelRatio=1,this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.autoTicks=!0,this.tickSpacing=[1,1,1],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickAlign=[\"auto\",\"auto\",\"auto\"],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[10,10,10],this.lastCubeProps={cubeEdges:[0,0,0],axis:[0,0,0]},this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=\"sans-serif\",this.labelSize=[20,20,20],this.labelAngle=[0,0,0],this.labelAlign=[\"auto\",\"auto\",\"auto\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[10,10,10],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[0,0,0],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!1,!1,!1],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._firstInit=!0,this._text=null,this._lines=null,this._background=a(t)}var h=u.prototype;function f(){this.primalOffset=[0,0,0],this.primalMinor=[0,0,0],this.mirrorOffset=[0,0,0],this.mirrorMinor=[0,0,0]}h.update=function(t){function e(e,r,n){if(n in t){var i,a=t[n],o=this[n];(e?Array.isArray(a)&&Array.isArray(a[0]):Array.isArray(a))?this[n]=i=[r(a[0]),r(a[1]),r(a[2])]:this[n]=i=[r(a),r(a),r(a)];for(var s=0;s<3;++s)if(i[s]!==o[s])return!0}return!1}t=t||{};var r,a=e.bind(this,!1,Number),o=e.bind(this,!1,Boolean),l=e.bind(this,!1,String),c=e.bind(this,!0,function(t){if(Array.isArray(t)){if(3===t.length)return[+t[0],+t[1],+t[2],1];if(4===t.length)return[+t[0],+t[1],+t[2],+t[3]]}return[0,0,0,1]}),u=!1,h=!1;if(\"bounds\"in t)for(var f=t.bounds,p=0;p<2;++p)for(var d=0;d<3;++d)f[p][d]!==this.bounds[p][d]&&(h=!0),this.bounds[p][d]=f[p][d];if(\"ticks\"in t){r=t.ticks,u=!0,this.autoTicks=!1;for(p=0;p<3;++p)this.tickSpacing[p]=0}else a(\"tickSpacing\")&&(this.autoTicks=!0,h=!0);if(this._firstInit&&(\"ticks\"in t||\"tickSpacing\"in t||(this.autoTicks=!0),h=!0,u=!0,this._firstInit=!1),h&&this.autoTicks&&(r=s.create(this.bounds,this.tickSpacing),u=!0),u){for(p=0;p<3;++p)r[p].sort(function(t,e){return t.x-e.x});s.equal(r,this.ticks)?u=!1:this.ticks=r}o(\"tickEnable\"),l(\"tickFont\")&&(u=!0),a(\"tickSize\"),a(\"tickAngle\"),a(\"tickPad\"),c(\"tickColor\");var g=l(\"labels\");l(\"labelFont\")&&(g=!0),o(\"labelEnable\"),a(\"labelSize\"),a(\"labelPad\"),c(\"labelColor\"),o(\"lineEnable\"),o(\"lineMirror\"),a(\"lineWidth\"),c(\"lineColor\"),o(\"lineTickEnable\"),o(\"lineTickMirror\"),a(\"lineTickLength\"),a(\"lineTickWidth\"),c(\"lineTickColor\"),o(\"gridEnable\"),a(\"gridWidth\"),c(\"gridColor\"),o(\"zeroEnable\"),c(\"zeroLineColor\"),a(\"zeroLineWidth\"),o(\"backgroundEnable\"),c(\"backgroundColor\"),this._text?this._text&&(g||u)&&this._text.update(this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont):this._text=n(this.gl,this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont),this._lines&&u&&(this._lines.dispose(),this._lines=null),this._lines||(this._lines=i(this.gl,this.bounds,this.ticks))};var p=[new f,new f,new f];function d(t,e,r,n,i){for(var a=t.primalOffset,o=t.primalMinor,s=t.mirrorOffset,l=t.mirrorMinor,c=n[e],u=0;u<3;++u)if(e!==u){var h=a,f=s,p=o,d=l;c&1<<u&&(h=s,f=a,p=l,d=o),h[u]=r[0][u],f[u]=r[1][u],i[u]>0?(p[u]=-1,d[u]=0):(p[u]=0,d[u]=1)}}var g=[0,0,0],v={model:l,view:l,projection:l,_ortho:!1};h.isOpaque=function(){return!0},h.isTransparent=function(){return!1},h.drawTransparent=function(t){};var m=[0,0,0],y=[0,0,0],x=[0,0,0];h.draw=function(t){t=t||v;for(var e=this.gl,r=t.model||l,n=t.view||l,i=t.projection||l,a=this.bounds,s=t._ortho||!1,u=o(r,n,i,a,s),h=u.cubeEdges,f=u.axis,b=n[12],_=n[13],w=n[14],k=n[15],T=(s?2:1)*this.pixelRatio*(i[3]*b+i[7]*_+i[11]*w+i[15]*k)/e.drawingBufferHeight,A=0;A<3;++A)this.lastCubeProps.cubeEdges[A]=h[A],this.lastCubeProps.axis[A]=f[A];var M=p;for(A=0;A<3;++A)d(p[A],A,this.bounds,h,f);e=this.gl;var S,E=g;for(A=0;A<3;++A)this.backgroundEnable[A]?E[A]=f[A]:E[A]=0;this._background.draw(r,n,i,a,E,this.backgroundColor),this._lines.bind(r,n,i,this);for(A=0;A<3;++A){var C=[0,0,0];f[A]>0?C[A]=a[1][A]:C[A]=a[0][A];for(var L=0;L<2;++L){var P=(A+1+L)%3,O=(A+1+(1^L))%3;this.gridEnable[P]&&this._lines.drawGrid(P,O,this.bounds,C,this.gridColor[P],this.gridWidth[P]*this.pixelRatio)}for(L=0;L<2;++L){P=(A+1+L)%3,O=(A+1+(1^L))%3;this.zeroEnable[O]&&Math.min(a[0][O],a[1][O])<=0&&Math.max(a[0][O],a[1][O])>=0&&this._lines.drawZero(P,O,this.bounds,C,this.zeroLineColor[O],this.zeroLineWidth[O]*this.pixelRatio)}}for(A=0;A<3;++A){this.lineEnable[A]&&this._lines.drawAxisLine(A,this.bounds,M[A].primalOffset,this.lineColor[A],this.lineWidth[A]*this.pixelRatio),this.lineMirror[A]&&this._lines.drawAxisLine(A,this.bounds,M[A].mirrorOffset,this.lineColor[A],this.lineWidth[A]*this.pixelRatio);var z=c(m,M[A].primalMinor),I=c(y,M[A].mirrorMinor),D=this.lineTickLength;for(L=0;L<3;++L){var R=T/r[5*L];z[L]*=D[L]*R,I[L]*=D[L]*R}this.lineTickEnable[A]&&this._lines.drawAxisTicks(A,M[A].primalOffset,z,this.lineTickColor[A],this.lineTickWidth[A]*this.pixelRatio),this.lineTickMirror[A]&&this._lines.drawAxisTicks(A,M[A].mirrorOffset,I,this.lineTickColor[A],this.lineTickWidth[A]*this.pixelRatio)}this._lines.unbind(),this._text.bind(r,n,i,this.pixelRatio);var F,B;function N(t){(B=[0,0,0])[t]=1}function j(t,e,r){var n=(t+1)%3,i=(t+2)%3,a=e[n],o=e[i],s=r[n],l=r[i];a>0&&l>0?N(n):a>0&&l<0?N(n):a<0&&l>0?N(n):a<0&&l<0?N(n):o>0&&s>0?N(i):o>0&&s<0?N(i):o<0&&s>0?N(i):o<0&&s<0&&N(i)}for(A=0;A<3;++A){var U=M[A].primalMinor,V=M[A].mirrorMinor,q=c(x,M[A].primalOffset);for(L=0;L<3;++L)this.lineTickEnable[A]&&(q[L]+=T*U[L]*Math.max(this.lineTickLength[L],0)/r[5*L]);var H=[0,0,0];if(H[A]=1,this.tickEnable[A]){-3600===this.tickAngle[A]?(this.tickAngle[A]=0,this.tickAlign[A]=\"auto\"):this.tickAlign[A]=-1,F=1,\"auto\"===(S=[this.tickAlign[A],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]),B=[0,0,0],j(A,U,V);for(L=0;L<3;++L)q[L]+=T*U[L]*this.tickPad[L]/r[5*L];this._text.drawTicks(A,this.tickSize[A],this.tickAngle[A],q,this.tickColor[A],H,B,S)}if(this.labelEnable[A]){F=0,B=[0,0,0],this.labels[A].length>4&&(N(A),F=1),\"auto\"===(S=[this.labelAlign[A],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]);for(L=0;L<3;++L)q[L]+=T*U[L]*this.labelPad[L]/r[5*L];q[A]+=.5*(a[0][A]+a[1][A]),this._text.drawLabel(A,this.labelSize[A],this.labelAngle[A],q,this.labelColor[A],[0,0,0],B,S)}}this._text.unbind()},h.dispose=function(){this._text.dispose(),this._lines.dispose(),this._background.dispose(),this._lines=null,this._text=null,this._background=null,this.gl=null}},{\"./lib/background.js\":234,\"./lib/cube.js\":235,\"./lib/lines.js\":236,\"./lib/text.js\":238,\"./lib/ticks.js\":239}],234:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=[],r=[],s=0,l=0;l<3;++l)for(var c=(l+1)%3,u=(l+2)%3,h=[0,0,0],f=[0,0,0],p=-1;p<=1;p+=2){r.push(s,s+2,s+1,s+1,s+2,s+3),h[l]=p,f[l]=p;for(var d=-1;d<=1;d+=2){h[c]=d;for(var g=-1;g<=1;g+=2)h[u]=g,e.push(h[0],h[1],h[2],f[0],f[1],f[2]),s+=1}var v=c;c=u,u=v}var m=n(t,new Float32Array(e)),y=n(t,new Uint16Array(r),t.ELEMENT_ARRAY_BUFFER),x=i(t,[{buffer:m,type:t.FLOAT,size:3,offset:0,stride:24},{buffer:m,type:t.FLOAT,size:3,offset:12,stride:24}],y),b=a(t);return b.attributes.position.location=0,b.attributes.normal.location=1,new o(t,m,x,b)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").bg;function o(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n}var s=o.prototype;s.draw=function(t,e,r,n,i,a){for(var o=!1,s=0;s<3;++s)o=o||i[s];if(o){var l=this.gl;l.enable(l.POLYGON_OFFSET_FILL),l.polygonOffset(1,2),this.shader.bind(),this.shader.uniforms={model:t,view:e,projection:r,bounds:n,enable:i,colors:a},this.vao.bind(),this.vao.draw(this.gl.TRIANGLES,36),this.vao.unbind(),l.disable(l.POLYGON_OFFSET_FILL)}},s.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders\":237,\"gl-buffer\":241,\"gl-vao\":327}],235:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,p){i(s,e,t),i(s,r,s);for(var y=0,x=0;x<2;++x){u[2]=a[x][2];for(var b=0;b<2;++b){u[1]=a[b][1];for(var _=0;_<2;++_)u[0]=a[_][0],f(l[y],u,s),y+=1}}for(var w=-1,x=0;x<8;++x){for(var k=l[x][3],T=0;T<3;++T)c[x][T]=l[x][T]/k;p&&(c[x][2]*=-1),k<0&&(w<0?w=x:c[x][2]<c[w][2]&&(w=x))}if(w<0){w=0;for(var A=0;A<3;++A){for(var M=(A+2)%3,S=(A+1)%3,E=-1,C=-1,L=0;L<2;++L){var P=L<<A,O=P+(L<<M)+(1-L<<S),z=P+(1-L<<M)+(L<<S);o(c[P],c[O],c[z],h)<0||(L?E=1:C=1)}if(E<0||C<0)C>E&&(w|=1<<A);else{for(var L=0;L<2;++L){var P=L<<A,O=P+(L<<M)+(1-L<<S),z=P+(1-L<<M)+(L<<S),I=d([l[P],l[O],l[z],l[P+(1<<M)+(1<<S)]]);L?E=I:C=I}C>E&&(w|=1<<A)}}}for(var D=7^w,R=-1,x=0;x<8;++x)x!==w&&x!==D&&(R<0?R=x:c[R][1]>c[x][1]&&(R=x));for(var F=-1,x=0;x<3;++x){var B=R^1<<x;if(B!==w&&B!==D){F<0&&(F=B);var S=c[B];S[0]<c[F][0]&&(F=B)}}for(var N=-1,x=0;x<3;++x){var B=R^1<<x;if(B!==w&&B!==D&&B!==F){N<0&&(N=B);var S=c[B];S[0]>c[N][0]&&(N=B)}}var j=g;j[0]=j[1]=j[2]=0,j[n.log2(F^R)]=R&F,j[n.log2(R^N)]=R&N;var U=7^N;U===w||U===D?(U=7^F,j[n.log2(N^U)]=U&N):j[n.log2(F^U)]=U&F;for(var V=v,q=w,A=0;A<3;++A)V[A]=q&1<<A?-1:1;return m};var n=t(\"bit-twiddle\"),i=t(\"gl-mat4/multiply\"),a=t(\"split-polygon\"),o=t(\"robust-orientation\"),s=new Array(16),l=new Array(8),c=new Array(8),u=new Array(3),h=[0,0,0];function f(t,e,r){for(var n=0;n<4;++n){t[n]=r[12+n];for(var i=0;i<3;++i)t[n]+=e[i]*r[4*i+n]}}!function(){for(var t=0;t<8;++t)l[t]=[1,1,1,1],c[t]=[1,1,1]}();var p=[[0,0,1,0,0],[0,0,-1,1,0],[0,-1,0,1,0],[0,1,0,1,0],[-1,0,0,1,0],[1,0,0,1,0]];function d(t){for(var e=0;e<p.length;++e)if((t=a.positive(t,p[e])).length<3)return 0;var r=t[0],n=r[0]/r[3],i=r[1]/r[3],o=0;for(e=1;e+1<t.length;++e){var s=t[e],l=t[e+1],c=s[0]/s[3]-n,u=s[1]/s[3]-i,h=l[0]/l[3]-n,f=l[1]/l[3]-i;o+=Math.abs(c*f-u*h)}return o}var g=[1,1,1],v=[0,0,0],m={cubeEdges:g,axis:v}},{\"bit-twiddle\":92,\"gl-mat4/multiply\":267,\"robust-orientation\":510,\"split-polygon\":527}],236:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var o=[],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[0,0,0];o.push(0,0,1,0,1,1,0,0,-1,0,0,-1,0,1,1,0,1,-1);for(var h=0;h<3;++h){for(var f=o.length/3|0,d=0;d<r[h].length;++d){var g=+r[h][d].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var v=o.length/3|0;s[h]=f,l[h]=v-f;for(var f=o.length/3|0,m=0;m<r[h].length;++m){var g=+r[h][m].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var v=o.length/3|0;c[h]=f,u[h]=v-f}var y=n(t,new Float32Array(o)),x=i(t,[{buffer:y,type:t.FLOAT,size:3,stride:0,offset:0}]),b=a(t);return b.attributes.position.location=0,new p(t,y,x,b,l,s,u,c)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").line,o=[0,0,0],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[1,1];function h(t){return t[0]=t[1]=t[2]=0,t}function f(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function p(t,e,r,n,i,a,o,s){this.gl=t,this.vertBuffer=e,this.vao=r,this.shader=n,this.tickCount=i,this.tickOffset=a,this.gridCount=o,this.gridOffset=s}var d=p.prototype;d.bind=function(t,e,r){this.shader.bind(),this.shader.uniforms.model=t,this.shader.uniforms.view=e,this.shader.uniforms.projection=r,u[0]=this.gl.drawingBufferWidth,u[1]=this.gl.drawingBufferHeight,this.shader.uniforms.screenShape=u,this.vao.bind()},d.unbind=function(){this.vao.unbind()},d.drawAxisLine=function(t,e,r,n,i){var a=h(s);this.shader.uniforms.majorAxis=s,a[t]=e[1][t]-e[0][t],this.shader.uniforms.minorAxis=a;var o,u=f(c,r);u[t]+=e[0][t],this.shader.uniforms.offset=u,this.shader.uniforms.lineWidth=i,this.shader.uniforms.color=n,(o=h(l))[(t+2)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6),(o=h(l))[(t+1)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6)},d.drawAxisTicks=function(t,e,r,n,i){if(this.tickCount[t]){var a=h(o);a[t]=1,this.shader.uniforms.majorAxis=a,this.shader.uniforms.offset=e,this.shader.uniforms.minorAxis=r,this.shader.uniforms.color=n,this.shader.uniforms.lineWidth=i;var s=h(l);s[t]=1,this.shader.uniforms.screenAxis=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t])}},d.drawGrid=function(t,e,r,n,i,a){if(this.gridCount[t]){var u=h(s);u[e]=r[1][e]-r[0][e],this.shader.uniforms.minorAxis=u;var p=f(c,n);p[e]+=r[0][e],this.shader.uniforms.offset=p;var d=h(o);d[t]=1,this.shader.uniforms.majorAxis=d;var g=h(l);g[t]=1,this.shader.uniforms.screenAxis=g,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,this.gridCount[t],this.gridOffset[t])}},d.drawZero=function(t,e,r,n,i,a){var o=h(s);this.shader.uniforms.majorAxis=o,o[t]=r[1][t]-r[0][t],this.shader.uniforms.minorAxis=o;var u=f(c,n);u[t]+=r[0][t],this.shader.uniforms.offset=u;var p=h(l);p[e]=1,this.shader.uniforms.screenAxis=p,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,6)},d.dispose=function(){this.vao.dispose(),this.vertBuffer.dispose(),this.shader.dispose()}},{\"./shaders\":237,\"gl-buffer\":241,\"gl-vao\":327}],237:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, majorAxis, minorAxis, screenAxis;\\nuniform float lineWidth;\\nuniform vec2 screenShape;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nvoid main() {\\n  vec3 major = position.x * majorAxis;\\n  vec3 minor = position.y * minorAxis;\\n\\n  vec3 vPosition = major + minor + offset;\\n  vec3 pPosition = project(vPosition);\\n  vec3 offset = project(vPosition + screenAxis * position.z);\\n\\n  vec2 screen = normalize((offset - pPosition).xy * screenShape) / screenShape;\\n\\n  gl_Position = vec4(pPosition + vec3(0.5 * screen * lineWidth, 0), 1.0);\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.line=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"}])};var s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, axis, alignDir, alignOpt;\\nuniform float scale, angle, pixelScale;\\nuniform vec2 resolution;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nfloat computeViewAngle(vec3 a, vec3 b) {\\n  vec3 A = project(a);\\n  vec3 B = project(b);\\n\\n  return atan(\\n    (B.y - A.y) * resolution.y,\\n    (B.x - A.x) * resolution.x\\n  );\\n}\\n\\nconst float PI = 3.141592;\\nconst float TWO_PI = 2.0 * PI;\\nconst float HALF_PI = 0.5 * PI;\\nconst float ONE_AND_HALF_PI = 1.5 * PI;\\n\\nint option = int(floor(alignOpt.x + 0.001));\\nfloat hv_ratio =       alignOpt.y;\\nbool enableAlign =    (alignOpt.z != 0.0);\\n\\nfloat mod_angle(float a) {\\n  return mod(a, PI);\\n}\\n\\nfloat positive_angle(float a) {\\n  return mod_angle((a < 0.0) ?\\n    a + TWO_PI :\\n    a\\n  );\\n}\\n\\nfloat look_upwards(float a) {\\n  float b = positive_angle(a);\\n  return ((b > HALF_PI) && (b <= ONE_AND_HALF_PI)) ?\\n    b - PI :\\n    b;\\n}\\n\\nfloat look_horizontal_or_vertical(float a, float ratio) {\\n  // ratio controls the ratio between being horizontal to (vertical + horizontal)\\n  // if ratio is set to 0.5 then it is 50%, 50%.\\n  // when using a higher ratio e.g. 0.75 the result would\\n  // likely be more horizontal than vertical.\\n\\n  float b = positive_angle(a);\\n\\n  return\\n    (b < (      ratio) * HALF_PI) ? 0.0 :\\n    (b < (2.0 - ratio) * HALF_PI) ? -HALF_PI :\\n    (b < (2.0 + ratio) * HALF_PI) ? 0.0 :\\n    (b < (4.0 - ratio) * HALF_PI) ? HALF_PI :\\n                                    0.0;\\n}\\n\\nfloat roundTo(float a, float b) {\\n  return float(b * floor((a + 0.5 * b) / b));\\n}\\n\\nfloat look_round_n_directions(float a, int n) {\\n  float b = positive_angle(a);\\n  float div = TWO_PI / float(n);\\n  float c = roundTo(b, div);\\n  return look_upwards(c);\\n}\\n\\nfloat applyAlignOption(float rawAngle, float delta) {\\n  return\\n    (option >  2) ? look_round_n_directions(rawAngle + delta, option) :       // option 3-n: round to n directions\\n    (option == 2) ? look_horizontal_or_vertical(rawAngle + delta, hv_ratio) : // horizontal or vertical\\n    (option == 1) ? rawAngle + delta :       // use free angle, and flip to align with one direction of the axis\\n    (option == 0) ? look_upwards(rawAngle) : // use free angle, and stay upwards\\n    (option ==-1) ? 0.0 :                    // useful for backward compatibility, all texts remains horizontal\\n                    rawAngle;                // otherwise return back raw input angle\\n}\\n\\nbool isAxisTitle = (axis.x == 0.0) &&\\n                   (axis.y == 0.0) &&\\n                   (axis.z == 0.0);\\n\\nvoid main() {\\n  //Compute world offset\\n  float axisDistance = position.z;\\n  vec3 dataPosition = axisDistance * axis + offset;\\n\\n  float beta = angle; // i.e. user defined attributes for each tick\\n\\n  float axisAngle;\\n  float clipAngle;\\n  float flip;\\n\\n  if (enableAlign) {\\n    axisAngle = (isAxisTitle) ? HALF_PI :\\n                      computeViewAngle(dataPosition, dataPosition + axis);\\n    clipAngle = computeViewAngle(dataPosition, dataPosition + alignDir);\\n\\n    axisAngle += (sin(axisAngle) < 0.0) ? PI : 0.0;\\n    clipAngle += (sin(clipAngle) < 0.0) ? PI : 0.0;\\n\\n    flip = (dot(vec2(cos(axisAngle), sin(axisAngle)),\\n                vec2(sin(clipAngle),-cos(clipAngle))) > 0.0) ? 1.0 : 0.0;\\n\\n    beta += applyAlignOption(clipAngle, flip * PI);\\n  }\\n\\n  //Compute plane offset\\n  vec2 planeCoord = position.xy * pixelScale;\\n\\n  mat2 planeXform = scale * mat2(\\n     cos(beta), sin(beta),\\n    -sin(beta), cos(beta)\\n  );\\n\\n  vec2 viewOffset = 2.0 * planeXform * planeCoord / resolution;\\n\\n  //Compute clip position\\n  vec3 clipPosition = project(dataPosition);\\n\\n  //Apply text offset in clip coordinates\\n  clipPosition += vec3(viewOffset, 0.0);\\n\\n  //Done\\n  gl_Position = vec4(clipPosition, 1.0);\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.text=function(t){return i(t,s,l,null,[{name:\"position\",type:\"vec3\"}])};var c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec3 normal;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 enable;\\nuniform vec3 bounds[2];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n\\n  vec3 signAxis = sign(bounds[1] - bounds[0]);\\n\\n  vec3 realNormal = signAxis * normal;\\n\\n  if(dot(realNormal, enable) > 0.0) {\\n    vec3 minRange = min(bounds[0], bounds[1]);\\n    vec3 maxRange = max(bounds[0], bounds[1]);\\n    vec3 nPosition = mix(minRange, maxRange, 0.5 * (position + 1.0));\\n    gl_Position = projection * view * model * vec4(nPosition, 1.0);\\n  } else {\\n    gl_Position = vec4(0,0,0,0);\\n  }\\n\\n  colorChannel = abs(realNormal);\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 colors[3];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n  gl_FragColor = colorChannel.x * colors[0] +\\n                 colorChannel.y * colors[1] +\\n                 colorChannel.z * colors[2];\\n}\"]);r.bg=function(t){return i(t,c,u,null,[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}])}},{\"gl-shader\":301,glslify:409}],238:[function(t,e,r){(function(r){\"use strict\";e.exports=function(t,e,r,a,s,l){var u=n(t),h=i(t,[{buffer:u,size:3}]),f=o(t);f.attributes.position.location=0;var p=new c(t,f,u,h);return p.update(e,r,a,s,l),p};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"vectorize-text\"),o=t(\"./shaders\").text,s=window||r.global||{},l=s.__TEXT_CACHE||{};s.__TEXT_CACHE={};function c(t,e,r,n){this.gl=t,this.shader=e,this.buffer=r,this.vao=n,this.tickOffset=this.tickCount=this.labelOffset=this.labelCount=null}var u=c.prototype,h=[0,0];u.bind=function(t,e,r,n){this.vao.bind(),this.shader.bind();var i=this.shader.uniforms;i.model=t,i.view=e,i.projection=r,i.pixelScale=n,h[0]=this.gl.drawingBufferWidth,h[1]=this.gl.drawingBufferHeight,this.shader.uniforms.resolution=h},u.unbind=function(){this.vao.unbind()},u.update=function(t,e,r,n,i){var o=[];function s(t,e,r,n,i,s){var c=l[r];c||(c=l[r]={});var u=c[e];u||(u=c[e]=function(t,e){try{return a(t,e)}catch(e){return console.warn('error vectorizing text:\"'+t+'\" error:',e),{cells:[],positions:[]}}}(e,{triangles:!0,font:r,textAlign:\"center\",textBaseline:\"middle\",lineSpacing:i,styletags:s}));for(var h=(n||12)/12,f=u.positions,p=u.cells,d=0,g=p.length;d<g;++d)for(var v=p[d],m=2;m>=0;--m){var y=f[v[m]];o.push(h*y[0],-h*y[1],t)}}for(var c=[0,0,0],u=[0,0,0],h=[0,0,0],f=[0,0,0],p={breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},d=0;d<3;++d){h[d]=o.length/3|0,s(.5*(t[0][d]+t[1][d]),e[d],r[d],12,1.25,p),f[d]=(o.length/3|0)-h[d],c[d]=o.length/3|0;for(var g=0;g<n[d].length;++g)n[d][g].text&&s(n[d][g].x,n[d][g].text,n[d][g].font||i,n[d][g].fontSize||12,1.25,p);u[d]=(o.length/3|0)-c[d]}this.buffer.update(o),this.tickOffset=c,this.tickCount=u,this.labelOffset=h,this.labelCount=f},u.drawTicks=function(t,e,r,n,i,a,o,s){this.tickCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t]))},u.drawLabel=function(t,e,r,n,i,a,o,s){this.labelCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.labelCount[t],this.labelOffset[t]))},u.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()}}).call(this,t(\"_process\"))},{\"./shaders\":237,_process:482,\"gl-buffer\":241,\"gl-vao\":327,\"vectorize-text\":550}],239:[function(t,e,r){\"use strict\";function n(t,e){var r=t+\"\",n=r.indexOf(\".\"),i=0;n>=0&&(i=r.length-n-1);var a=Math.pow(10,i),o=Math.round(t*e*a),s=o+\"\";if(s.indexOf(\"e\")>=0)return s;var l=o/a,c=o%a;o<0?(l=0|-Math.ceil(l),c=0|-c):(l=0|Math.floor(l),c|=0);var u=\"\"+l;if(o<0&&(u=\"-\"+u),i){for(var h=\"\"+c;h.length<i;)h=\"0\"+h;return u+\".\"+h}return u}r.create=function(t,e){for(var r=[],i=0;i<3;++i){for(var a=[],o=(t[0][i],t[1][i],0);o*e[i]<=t[1][i];++o)a.push({x:o*e[i],text:n(e[i],o)});for(var o=-1;o*e[i]>=t[0][i];--o)a.push({x:o*e[i],text:n(e[i],o)});r.push(a)}return r},r.equal=function(t,e){for(var r=0;r<3;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;++n){var i=t[r][n],a=e[r][n];if(i.x!==a.x||i.text!==a.text||i.font!==a.font||i.fontColor!==a.fontColor||i.fontSize!==a.fontSize||i.dx!==a.dx||i.dy!==a.dy)return!1}}return!0}},{}],240:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,l,h){var f=e.model||c,p=e.view||c,m=e.projection||c,y=e._ortho||!1,x=t.bounds,b=(h=h||a(f,p,m,x,y)).axis;o(u,p,f),o(u,m,u);for(var _=g,w=0;w<3;++w)_[w].lo=1/0,_[w].hi=-1/0,_[w].pixelsPerDataUnit=1/0;var k=n(s(u,u));s(u,u);for(var T=0;T<3;++T){var A=(T+1)%3,M=(T+2)%3,S=v;t:for(var w=0;w<2;++w){var E=[];if(b[T]<0!=!!w){S[T]=x[w][T];for(var C=0;C<2;++C){S[A]=x[C^w][A];for(var L=0;L<2;++L)S[M]=x[L^C^w][M],E.push(S.slice())}for(var P=y?5:4,C=P;C===P;++C){if(0===E.length)continue t;E=i.positive(E,k[C])}for(var C=0;C<E.length;++C)for(var M=E[C],O=d(v,u,M,r,l),L=0;L<3;++L)_[L].lo=Math.min(_[L].lo,M[L]),_[L].hi=Math.max(_[L].hi,M[L]),L!==T&&(_[L].pixelsPerDataUnit=Math.min(_[L].pixelsPerDataUnit,Math.abs(O[L])))}}}return _};var n=t(\"extract-frustum-planes\"),i=t(\"split-polygon\"),a=t(\"./lib/cube.js\"),o=t(\"gl-mat4/multiply\"),s=t(\"gl-mat4/transpose\"),l=t(\"gl-vec4/transformMat4\"),c=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]),u=new Float32Array(16);function h(t,e,r){this.lo=t,this.hi=e,this.pixelsPerDataUnit=r}var f=[0,0,0,1],p=[0,0,0,1];function d(t,e,r,n,i){for(var a=0;a<3;++a){for(var o=f,s=p,c=0;c<3;++c)s[c]=o[c]=r[c];s[3]=o[3]=1,s[a]+=1,l(s,s,e),s[3]<0&&(t[a]=1/0),o[a]-=1,l(o,o,e),o[3]<0&&(t[a]=1/0);var u=(o[0]/o[3]-s[0]/s[3])*n,h=(o[1]/o[3]-s[1]/s[3])*i;t[a]=.25*Math.sqrt(u*u+h*h)}return t}var g=[new h(1/0,-1/0,1/0),new h(1/0,-1/0,1/0),new h(1/0,-1/0,1/0)],v=[0,0,0]},{\"./lib/cube.js\":235,\"extract-frustum-planes\":224,\"gl-mat4/multiply\":267,\"gl-mat4/transpose\":276,\"gl-vec4/transformMat4\":398,\"split-polygon\":527}],241:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"ndarray-ops\"),a=t(\"ndarray\"),o=[\"uint8\",\"uint8_clamped\",\"uint16\",\"uint32\",\"int8\",\"int16\",\"int32\",\"float32\"];function s(t,e,r,n,i){this.gl=t,this.type=e,this.handle=r,this.length=n,this.usage=i}var l=s.prototype;function c(t,e,r,n,i,a){var o=i.length*i.BYTES_PER_ELEMENT;if(a<0)return t.bufferData(e,i,n),o;if(o+a>r)throw new Error(\"gl-buffer: If resizing buffer, must not specify offset\");return t.bufferSubData(e,a,i),r}function u(t,e){for(var r=n.malloc(t.length,e),i=t.length,a=0;a<i;++a)r[a]=t[a];return r}l.bind=function(){this.gl.bindBuffer(this.type,this.handle)},l.unbind=function(){this.gl.bindBuffer(this.type,null)},l.dispose=function(){this.gl.deleteBuffer(this.handle)},l.update=function(t,e){if(\"number\"!=typeof e&&(e=-1),this.bind(),\"object\"==typeof t&&\"undefined\"!=typeof t.shape){var r=t.dtype;if(o.indexOf(r)<0&&(r=\"float32\"),this.type===this.gl.ELEMENT_ARRAY_BUFFER)r=gl.getExtension(\"OES_element_index_uint\")&&\"uint16\"!==r?\"uint32\":\"uint16\";if(r===t.dtype&&function(t,e){for(var r=1,n=e.length-1;n>=0;--n){if(e[n]!==r)return!1;r*=t[n]}return!0}(t.shape,t.stride))0===t.offset&&t.data.length===t.shape[0]?this.length=c(this.gl,this.type,this.length,this.usage,t.data,e):this.length=c(this.gl,this.type,this.length,this.usage,t.data.subarray(t.offset,t.shape[0]),e);else{var s=n.malloc(t.size,r),l=a(s,t.shape);i.assign(l,t),this.length=c(this.gl,this.type,this.length,this.usage,e<0?s:s.subarray(0,t.size),e),n.free(s)}}else if(Array.isArray(t)){var h;h=this.type===this.gl.ELEMENT_ARRAY_BUFFER?u(t,\"uint16\"):u(t,\"float32\"),this.length=c(this.gl,this.type,this.length,this.usage,e<0?h:h.subarray(0,t.length),e),n.free(h)}else if(\"object\"==typeof t&&\"number\"==typeof t.length)this.length=c(this.gl,this.type,this.length,this.usage,t,e);else{if(\"number\"!=typeof t&&void 0!==t)throw new Error(\"gl-buffer: Invalid data type\");if(e>=0)throw new Error(\"gl-buffer: Cannot specify offset when resizing buffer\");(t|=0)<=0&&(t=1),this.gl.bufferData(this.type,0|t,this.usage),this.length=t}},e.exports=function(t,e,r,n){if(r=r||t.ARRAY_BUFFER,n=n||t.DYNAMIC_DRAW,r!==t.ARRAY_BUFFER&&r!==t.ELEMENT_ARRAY_BUFFER)throw new Error(\"gl-buffer: Invalid type for webgl buffer, must be either gl.ARRAY_BUFFER or gl.ELEMENT_ARRAY_BUFFER\");if(n!==t.DYNAMIC_DRAW&&n!==t.STATIC_DRAW&&n!==t.STREAM_DRAW)throw new Error(\"gl-buffer: Invalid usage for buffer, must be either gl.DYNAMIC_DRAW, gl.STATIC_DRAW or gl.STREAM_DRAW\");var i=t.createBuffer(),a=new s(t,r,i,0,n);return a.update(e),a}},{ndarray:450,\"ndarray-ops\":444,\"typedarray-pool\":545}],242:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\"),i=function(t,e){for(var r=0;r<t.length;r++)if(t[r]>=e)return r-1;return r},a=n.create(),o=n.create(),s=function(t,e,r){return t<e?e:t>r?r:t},l=function(t,e,r,l){var c=t[0],u=t[1],h=t[2],f=r[0].length,p=r[1].length,d=r[2].length,g=i(r[0],c),v=i(r[1],u),m=i(r[2],h),y=g+1,x=v+1,b=m+1;if(l&&(g=s(g,0,f-1),y=s(y,0,f-1),v=s(v,0,p-1),x=s(x,0,p-1),m=s(m,0,d-1),b=s(b,0,d-1)),g<0||v<0||m<0||y>=f||x>=p||b>=d)return n.create();var _=(c-r[0][g])/(r[0][y]-r[0][g]),w=(u-r[1][v])/(r[1][x]-r[1][v]),k=(h-r[2][m])/(r[2][b]-r[2][m]);(_<0||_>1||isNaN(_))&&(_=0),(w<0||w>1||isNaN(w))&&(w=0),(k<0||k>1||isNaN(k))&&(k=0);var T=m*f*p,A=b*f*p,M=v*f,S=x*f,E=g,C=y,L=e[M+T+E],P=e[M+T+C],O=e[S+T+E],z=e[S+T+C],I=e[M+A+E],D=e[M+A+C],R=e[S+A+E],F=e[S+A+C],B=n.create();return n.lerp(B,L,P,_),n.lerp(a,O,z,_),n.lerp(B,B,a,w),n.lerp(a,I,D,_),n.lerp(o,R,F,_),n.lerp(a,a,o,w),n.lerp(B,B,a,k),B};e.exports=function(t,e){var r;r=t.positions?t.positions:function(t){for(var e=t[0],r=t[1],n=t[2],i=[],a=0;a<n.length;a++)for(var o=0;o<r.length;o++)for(var s=0;s<e.length;s++)i.push([n[a],r[o],e[s]]);return i}(t.meshgrid);var i=t.meshgrid,a=t.vectors,o={positions:[],vertexIntensity:[],vertexIntensityBounds:t.vertexIntensityBounds,vertexNormals:[],vectors:[],cells:[],coneOffset:t.coneOffset,colormap:t.colormap};if(0===t.positions.length)return e&&(e[0]=[0,0,0],e[1]=[0,0,0]),o;for(var s=0,c=1/0,u=-1/0,h=1/0,f=-1/0,p=1/0,d=-1/0,g=null,v=null,m=[],y=1/0,x=0;x<r.length;x++){var b,_=r[x];c=Math.min(_[0],c),u=Math.max(_[0],u),h=Math.min(_[1],h),f=Math.max(_[1],f),p=Math.min(_[2],p),d=Math.max(_[2],d),b=i?l(_,a,i,!0):a[x],n.length(b)>s&&(s=n.length(b)),x&&(y=Math.min(y,2*n.distance(g,_)/(n.length(v)+n.length(b)))),g=_,v=b,m.push(b)}var w=[c,h,p],k=[u,f,d];e&&(e[0]=w,e[1]=k),0===s&&(s=1);var T=1/s;isFinite(y)&&!isNaN(y)||(y=1),o.vectorScale=y;var A=function(t,e,r){var i=n.create();return void 0!==t&&n.set(i,t,e,r),i}(0,1,0),M=t.coneSize||.5;t.absoluteConeSize&&(M=t.absoluteConeSize*T),o.coneScale=M;x=0;for(var S=0;x<r.length;x++)for(var E=(_=r[x])[0],C=_[1],L=_[2],P=m[x],O=n.length(P)*T,z=0;z<8;z++){o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.positions.push([E,C,L,S++]),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vectors.push(P),o.vertexIntensity.push(O,O,O),o.vertexIntensity.push(O,O,O),o.vertexNormals.push(A,A,A),o.vertexNormals.push(A,A,A);var I=o.positions.length;o.cells.push([I-6,I-5,I-4],[I-3,I-2,I-1])}return o},e.exports.createConeMesh=t(\"./lib/conemesh\")},{\"./lib/conemesh\":243,\"gl-vec3\":346}],243:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./shaders\"),g=d.meshShader,v=d.pickShader,m=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function y(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,y,x,b,_,w,k,T){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=i,this.triangleVectors=a,this.triangleColors=s,this.triangleNormals=c,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=u,this.triangleCount=0,this.lineWidth=1,this.edgePositions=h,this.edgeColors=p,this.edgeUVs=d,this.edgeIds=f,this.edgeVAO=g,this.edgeCount=0,this.pointPositions=v,this.pointColors=x,this.pointUVs=b,this.pointSizes=_,this.pointIds=y,this.pointVAO=w,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=k,this.contourVAO=T,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.coneScale=2,this.vectorScale=1,this.coneOffset=.25,this._model=m,this._view=m,this._projection=m,this._resolution=[1,1]}var x=y.prototype;function b(t){var e=n(t,v.vertex,v.fragment,null,v.attributes);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.vector.location=5,e}x.isOpaque=function(){return this.opacity>=1},x.isTransparent=function(){return this.opacity<1},x.pickSlots=1,x.setPickBase=function(t){this.pickId=t},x.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=i[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},x.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),void 0!==t.vectorScale&&(this.vectorScale=t.vectorScale),void 0!==t.coneScale&&(this.coneScale=t.coneScale),void 0!==t.coneOffset&&(this.coneOffset=t.coneOffset),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=h({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return u(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,i=t.vectors;if(n&&r&&i){var a=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[],w=[],k=[];this.cells=r,this.positions=n;var T=t.vertexNormals,A=t.cellNormals,M=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,S=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!A&&(A=s.faceNormals(r,n,S)),A||T||(T=s.vertexNormals(r,n,M));var E=t.vertexColors,C=t.cellColors,L=t.meshColor||[1,1,1,1],P=t.vertexUVs,O=t.vertexIntensity,z=t.cellUVs,I=t.cellIntensity,D=1/0,R=-1/0;if(!P&&!z)if(O)if(t.vertexIntensityBounds)D=+t.vertexIntensityBounds[0],R=+t.vertexIntensityBounds[1];else for(var F=0;F<O.length;++F){var B=O[F];D=Math.min(D,B),R=Math.max(R,B)}else if(I)for(F=0;F<I.length;++F){B=I[F];D=Math.min(D,B),R=Math.max(R,B)}else for(F=0;F<n.length;++F){B=n[F][2];D=Math.min(D,B),R=Math.max(R,B)}this.intensity=O||(I?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,I):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var N=t.pointSizes,j=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(F=0;F<n.length;++F)for(var U=n[F],V=0;V<3;++V)!isNaN(U[V])&&isFinite(U[V])&&(this.bounds[0][V]=Math.min(this.bounds[0][V],U[V]),this.bounds[1][V]=Math.max(this.bounds[1][V],U[V]));var q=0,H=0,G=0;t:for(F=0;F<r.length;++F){var Y=r[F];switch(Y.length){case 1:for(U=n[X=Y[0]],V=0;V<3;++V)if(isNaN(U[V])||!isFinite(U[V]))continue t;x.push(U[0],U[1],U[2],U[3]),3===(Z=E?E[X]:C?C[F]:L).length?b.push(Z[0],Z[1],Z[2],1):b.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],_.push(J[0],J[1]),N?w.push(N[X]):w.push(j),k.push(F),G+=1;break;case 2:for(V=0;V<2;++V){U=n[X=Y[V]];for(var W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t}for(V=0;V<2;++V){U=n[X=Y[V]];g.push(U[0],U[1],U[2]),3===(Z=E?E[X]:C?C[F]:L).length?v.push(Z[0],Z[1],Z[2],1):v.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],m.push(J[0],J[1]),y.push(F)}H+=1;break;case 3:for(V=0;V<3;++V)for(U=n[X=Y[V]],W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t;for(V=0;V<3;++V){var X;U=n[X=Y[2-V]];a.push(U[0],U[1],U[2],U[3]);var Z,J,K,$=i[X];l.push($[0],$[1],$[2]),3===(Z=E?E[X]:C?C[F]:L).length?c.push(Z[0],Z[1],Z[2],1):c.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],p.push(J[0],J[1]),K=T?T[X]:A[F],f.push(K[0],K[1],K[2]),d.push(F)}q+=1}}this.pointCount=G,this.edgeCount=H,this.triangleCount=q,this.pointPositions.update(x),this.pointColors.update(b),this.pointUVs.update(_),this.pointSizes.update(w),this.pointIds.update(new Uint32Array(k)),this.edgePositions.update(g),this.edgeColors.update(v),this.edgeUVs.update(m),this.edgeIds.update(new Uint32Array(y)),this.trianglePositions.update(a),this.triangleVectors.update(l),this.triangleColors.update(c),this.triangleUVs.update(p),this.triangleNormals.update(f),this.triangleIds.update(new Uint32Array(d))}},x.drawTransparent=x.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:m.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var f=u[12+o],p=0;p<3;++p)f+=u[4*p+o]*this.lightPosition[p];s.lightPosition[o]=f/h}if(this.triangleCount>0){var d=this.triShader;d.bind(),d.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},x.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:i,clipBounds:a,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind())},x.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3);return{index:Math.floor(r[1]/48),position:n,dataCoordinate:n}},x.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose()},e.exports=function(t,e){1===arguments.length&&(t=(e=t).gl);var r=e.triShader||function(t){var e=n(t,g.vertex,g.fragment,null,g.attributes);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.vector.location=5,e}(t),s=b(t),l=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));l.generateMipmap(),l.minFilter=t.LINEAR_MIPMAP_LINEAR,l.magFilter=t.LINEAR;var c=i(t),h=i(t),f=i(t),p=i(t),d=i(t),v=i(t),m=a(t,[{buffer:c,type:t.FLOAT,size:4},{buffer:v,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:f,type:t.FLOAT,size:4},{buffer:p,type:t.FLOAT,size:2},{buffer:d,type:t.FLOAT,size:3},{buffer:h,type:t.FLOAT,size:3}]),x=i(t),_=i(t),w=i(t),k=i(t),T=a(t,[{buffer:x,type:t.FLOAT,size:3},{buffer:k,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:_,type:t.FLOAT,size:4},{buffer:w,type:t.FLOAT,size:2}]),A=i(t),M=i(t),S=i(t),E=i(t),C=i(t),L=a(t,[{buffer:A,type:t.FLOAT,size:3},{buffer:C,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:M,type:t.FLOAT,size:4},{buffer:S,type:t.FLOAT,size:2},{buffer:E,type:t.FLOAT,size:1}]),P=i(t),O=new y(t,l,r,s,c,h,v,f,p,d,m,x,k,_,w,T,A,C,M,S,E,L,P,a(t,[{buffer:P,type:t.FLOAT,size:3}]));return O.update(e),O}},{\"./shaders\":244,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-shader\":301,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,normals:453,\"simplicial-complex-contour\":518,\"typedarray-pool\":545}],244:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\nuniform float vectorScale;\\nuniform float coneScale;\\n\\nuniform float coneOffset;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * conePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal,0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(conePosition, 1.0);\\n  vec4 t_position  = view * conePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = conePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular\\n            , opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nuniform float vectorScale;\\nuniform float coneScale;\\nuniform float coneOffset;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n  gl_Position = projection * view * conePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec3\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec3\"}]}},{glslify:409}],245:[function(t,e,r){e.exports={0:\"NONE\",1:\"ONE\",2:\"LINE_LOOP\",3:\"LINE_STRIP\",4:\"TRIANGLES\",5:\"TRIANGLE_STRIP\",6:\"TRIANGLE_FAN\",256:\"DEPTH_BUFFER_BIT\",512:\"NEVER\",513:\"LESS\",514:\"EQUAL\",515:\"LEQUAL\",516:\"GREATER\",517:\"NOTEQUAL\",518:\"GEQUAL\",519:\"ALWAYS\",768:\"SRC_COLOR\",769:\"ONE_MINUS_SRC_COLOR\",770:\"SRC_ALPHA\",771:\"ONE_MINUS_SRC_ALPHA\",772:\"DST_ALPHA\",773:\"ONE_MINUS_DST_ALPHA\",774:\"DST_COLOR\",775:\"ONE_MINUS_DST_COLOR\",776:\"SRC_ALPHA_SATURATE\",1024:\"STENCIL_BUFFER_BIT\",1028:\"FRONT\",1029:\"BACK\",1032:\"FRONT_AND_BACK\",1280:\"INVALID_ENUM\",1281:\"INVALID_VALUE\",1282:\"INVALID_OPERATION\",1285:\"OUT_OF_MEMORY\",1286:\"INVALID_FRAMEBUFFER_OPERATION\",2304:\"CW\",2305:\"CCW\",2849:\"LINE_WIDTH\",2884:\"CULL_FACE\",2885:\"CULL_FACE_MODE\",2886:\"FRONT_FACE\",2928:\"DEPTH_RANGE\",2929:\"DEPTH_TEST\",2930:\"DEPTH_WRITEMASK\",2931:\"DEPTH_CLEAR_VALUE\",2932:\"DEPTH_FUNC\",2960:\"STENCIL_TEST\",2961:\"STENCIL_CLEAR_VALUE\",2962:\"STENCIL_FUNC\",2963:\"STENCIL_VALUE_MASK\",2964:\"STENCIL_FAIL\",2965:\"STENCIL_PASS_DEPTH_FAIL\",2966:\"STENCIL_PASS_DEPTH_PASS\",2967:\"STENCIL_REF\",2968:\"STENCIL_WRITEMASK\",2978:\"VIEWPORT\",3024:\"DITHER\",3042:\"BLEND\",3088:\"SCISSOR_BOX\",3089:\"SCISSOR_TEST\",3106:\"COLOR_CLEAR_VALUE\",3107:\"COLOR_WRITEMASK\",3317:\"UNPACK_ALIGNMENT\",3333:\"PACK_ALIGNMENT\",3379:\"MAX_TEXTURE_SIZE\",3386:\"MAX_VIEWPORT_DIMS\",3408:\"SUBPIXEL_BITS\",3410:\"RED_BITS\",3411:\"GREEN_BITS\",3412:\"BLUE_BITS\",3413:\"ALPHA_BITS\",3414:\"DEPTH_BITS\",3415:\"STENCIL_BITS\",3553:\"TEXTURE_2D\",4352:\"DONT_CARE\",4353:\"FASTEST\",4354:\"NICEST\",5120:\"BYTE\",5121:\"UNSIGNED_BYTE\",5122:\"SHORT\",5123:\"UNSIGNED_SHORT\",5124:\"INT\",5125:\"UNSIGNED_INT\",5126:\"FLOAT\",5386:\"INVERT\",5890:\"TEXTURE\",6401:\"STENCIL_INDEX\",6402:\"DEPTH_COMPONENT\",6406:\"ALPHA\",6407:\"RGB\",6408:\"RGBA\",6409:\"LUMINANCE\",6410:\"LUMINANCE_ALPHA\",7680:\"KEEP\",7681:\"REPLACE\",7682:\"INCR\",7683:\"DECR\",7936:\"VENDOR\",7937:\"RENDERER\",7938:\"VERSION\",9728:\"NEAREST\",9729:\"LINEAR\",9984:\"NEAREST_MIPMAP_NEAREST\",9985:\"LINEAR_MIPMAP_NEAREST\",9986:\"NEAREST_MIPMAP_LINEAR\",9987:\"LINEAR_MIPMAP_LINEAR\",10240:\"TEXTURE_MAG_FILTER\",10241:\"TEXTURE_MIN_FILTER\",10242:\"TEXTURE_WRAP_S\",10243:\"TEXTURE_WRAP_T\",10497:\"REPEAT\",10752:\"POLYGON_OFFSET_UNITS\",16384:\"COLOR_BUFFER_BIT\",32769:\"CONSTANT_COLOR\",32770:\"ONE_MINUS_CONSTANT_COLOR\",32771:\"CONSTANT_ALPHA\",32772:\"ONE_MINUS_CONSTANT_ALPHA\",32773:\"BLEND_COLOR\",32774:\"FUNC_ADD\",32777:\"BLEND_EQUATION_RGB\",32778:\"FUNC_SUBTRACT\",32779:\"FUNC_REVERSE_SUBTRACT\",32819:\"UNSIGNED_SHORT_4_4_4_4\",32820:\"UNSIGNED_SHORT_5_5_5_1\",32823:\"POLYGON_OFFSET_FILL\",32824:\"POLYGON_OFFSET_FACTOR\",32854:\"RGBA4\",32855:\"RGB5_A1\",32873:\"TEXTURE_BINDING_2D\",32926:\"SAMPLE_ALPHA_TO_COVERAGE\",32928:\"SAMPLE_COVERAGE\",32936:\"SAMPLE_BUFFERS\",32937:\"SAMPLES\",32938:\"SAMPLE_COVERAGE_VALUE\",32939:\"SAMPLE_COVERAGE_INVERT\",32968:\"BLEND_DST_RGB\",32969:\"BLEND_SRC_RGB\",32970:\"BLEND_DST_ALPHA\",32971:\"BLEND_SRC_ALPHA\",33071:\"CLAMP_TO_EDGE\",33170:\"GENERATE_MIPMAP_HINT\",33189:\"DEPTH_COMPONENT16\",33306:\"DEPTH_STENCIL_ATTACHMENT\",33635:\"UNSIGNED_SHORT_5_6_5\",33648:\"MIRRORED_REPEAT\",33901:\"ALIASED_POINT_SIZE_RANGE\",33902:\"ALIASED_LINE_WIDTH_RANGE\",33984:\"TEXTURE0\",33985:\"TEXTURE1\",33986:\"TEXTURE2\",33987:\"TEXTURE3\",33988:\"TEXTURE4\",33989:\"TEXTURE5\",33990:\"TEXTURE6\",33991:\"TEXTURE7\",33992:\"TEXTURE8\",33993:\"TEXTURE9\",33994:\"TEXTURE10\",33995:\"TEXTURE11\",33996:\"TEXTURE12\",33997:\"TEXTURE13\",33998:\"TEXTURE14\",33999:\"TEXTURE15\",34000:\"TEXTURE16\",34001:\"TEXTURE17\",34002:\"TEXTURE18\",34003:\"TEXTURE19\",34004:\"TEXTURE20\",34005:\"TEXTURE21\",34006:\"TEXTURE22\",34007:\"TEXTURE23\",34008:\"TEXTURE24\",34009:\"TEXTURE25\",34010:\"TEXTURE26\",34011:\"TEXTURE27\",34012:\"TEXTURE28\",34013:\"TEXTURE29\",34014:\"TEXTURE30\",34015:\"TEXTURE31\",34016:\"ACTIVE_TEXTURE\",34024:\"MAX_RENDERBUFFER_SIZE\",34041:\"DEPTH_STENCIL\",34055:\"INCR_WRAP\",34056:\"DECR_WRAP\",34067:\"TEXTURE_CUBE_MAP\",34068:\"TEXTURE_BINDING_CUBE_MAP\",34069:\"TEXTURE_CUBE_MAP_POSITIVE_X\",34070:\"TEXTURE_CUBE_MAP_NEGATIVE_X\",34071:\"TEXTURE_CUBE_MAP_POSITIVE_Y\",34072:\"TEXTURE_CUBE_MAP_NEGATIVE_Y\",34073:\"TEXTURE_CUBE_MAP_POSITIVE_Z\",34074:\"TEXTURE_CUBE_MAP_NEGATIVE_Z\",34076:\"MAX_CUBE_MAP_TEXTURE_SIZE\",34338:\"VERTEX_ATTRIB_ARRAY_ENABLED\",34339:\"VERTEX_ATTRIB_ARRAY_SIZE\",34340:\"VERTEX_ATTRIB_ARRAY_STRIDE\",34341:\"VERTEX_ATTRIB_ARRAY_TYPE\",34342:\"CURRENT_VERTEX_ATTRIB\",34373:\"VERTEX_ATTRIB_ARRAY_POINTER\",34466:\"NUM_COMPRESSED_TEXTURE_FORMATS\",34467:\"COMPRESSED_TEXTURE_FORMATS\",34660:\"BUFFER_SIZE\",34661:\"BUFFER_USAGE\",34816:\"STENCIL_BACK_FUNC\",34817:\"STENCIL_BACK_FAIL\",34818:\"STENCIL_BACK_PASS_DEPTH_FAIL\",34819:\"STENCIL_BACK_PASS_DEPTH_PASS\",34877:\"BLEND_EQUATION_ALPHA\",34921:\"MAX_VERTEX_ATTRIBS\",34922:\"VERTEX_ATTRIB_ARRAY_NORMALIZED\",34930:\"MAX_TEXTURE_IMAGE_UNITS\",34962:\"ARRAY_BUFFER\",34963:\"ELEMENT_ARRAY_BUFFER\",34964:\"ARRAY_BUFFER_BINDING\",34965:\"ELEMENT_ARRAY_BUFFER_BINDING\",34975:\"VERTEX_ATTRIB_ARRAY_BUFFER_BINDING\",35040:\"STREAM_DRAW\",35044:\"STATIC_DRAW\",35048:\"DYNAMIC_DRAW\",35632:\"FRAGMENT_SHADER\",35633:\"VERTEX_SHADER\",35660:\"MAX_VERTEX_TEXTURE_IMAGE_UNITS\",35661:\"MAX_COMBINED_TEXTURE_IMAGE_UNITS\",35663:\"SHADER_TYPE\",35664:\"FLOAT_VEC2\",35665:\"FLOAT_VEC3\",35666:\"FLOAT_VEC4\",35667:\"INT_VEC2\",35668:\"INT_VEC3\",35669:\"INT_VEC4\",35670:\"BOOL\",35671:\"BOOL_VEC2\",35672:\"BOOL_VEC3\",35673:\"BOOL_VEC4\",35674:\"FLOAT_MAT2\",35675:\"FLOAT_MAT3\",35676:\"FLOAT_MAT4\",35678:\"SAMPLER_2D\",35680:\"SAMPLER_CUBE\",35712:\"DELETE_STATUS\",35713:\"COMPILE_STATUS\",35714:\"LINK_STATUS\",35715:\"VALIDATE_STATUS\",35716:\"INFO_LOG_LENGTH\",35717:\"ATTACHED_SHADERS\",35718:\"ACTIVE_UNIFORMS\",35719:\"ACTIVE_UNIFORM_MAX_LENGTH\",35720:\"SHADER_SOURCE_LENGTH\",35721:\"ACTIVE_ATTRIBUTES\",35722:\"ACTIVE_ATTRIBUTE_MAX_LENGTH\",35724:\"SHADING_LANGUAGE_VERSION\",35725:\"CURRENT_PROGRAM\",36003:\"STENCIL_BACK_REF\",36004:\"STENCIL_BACK_VALUE_MASK\",36005:\"STENCIL_BACK_WRITEMASK\",36006:\"FRAMEBUFFER_BINDING\",36007:\"RENDERBUFFER_BINDING\",36048:\"FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE\",36049:\"FRAMEBUFFER_ATTACHMENT_OBJECT_NAME\",36050:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL\",36051:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE\",36053:\"FRAMEBUFFER_COMPLETE\",36054:\"FRAMEBUFFER_INCOMPLETE_ATTACHMENT\",36055:\"FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT\",36057:\"FRAMEBUFFER_INCOMPLETE_DIMENSIONS\",36061:\"FRAMEBUFFER_UNSUPPORTED\",36064:\"COLOR_ATTACHMENT0\",36096:\"DEPTH_ATTACHMENT\",36128:\"STENCIL_ATTACHMENT\",36160:\"FRAMEBUFFER\",36161:\"RENDERBUFFER\",36162:\"RENDERBUFFER_WIDTH\",36163:\"RENDERBUFFER_HEIGHT\",36164:\"RENDERBUFFER_INTERNAL_FORMAT\",36168:\"STENCIL_INDEX8\",36176:\"RENDERBUFFER_RED_SIZE\",36177:\"RENDERBUFFER_GREEN_SIZE\",36178:\"RENDERBUFFER_BLUE_SIZE\",36179:\"RENDERBUFFER_ALPHA_SIZE\",36180:\"RENDERBUFFER_DEPTH_SIZE\",36181:\"RENDERBUFFER_STENCIL_SIZE\",36194:\"RGB565\",36336:\"LOW_FLOAT\",36337:\"MEDIUM_FLOAT\",36338:\"HIGH_FLOAT\",36339:\"LOW_INT\",36340:\"MEDIUM_INT\",36341:\"HIGH_INT\",36346:\"SHADER_COMPILER\",36347:\"MAX_VERTEX_UNIFORM_VECTORS\",36348:\"MAX_VARYING_VECTORS\",36349:\"MAX_FRAGMENT_UNIFORM_VECTORS\",37440:\"UNPACK_FLIP_Y_WEBGL\",37441:\"UNPACK_PREMULTIPLY_ALPHA_WEBGL\",37442:\"CONTEXT_LOST_WEBGL\",37443:\"UNPACK_COLORSPACE_CONVERSION_WEBGL\",37444:\"BROWSER_DEFAULT_WEBGL\"}},{}],246:[function(t,e,r){var n=t(\"./1.0/numbers\");e.exports=function(t){return n[t]}},{\"./1.0/numbers\":245}],247:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),o=i(e,[{buffer:r,type:e.FLOAT,size:3,offset:0,stride:40},{buffer:r,type:e.FLOAT,size:4,offset:12,stride:40},{buffer:r,type:e.FLOAT,size:3,offset:28,stride:40}]),l=a(e);l.attributes.position.location=0,l.attributes.color.location=1,l.attributes.offset.location=2;var c=new s(e,r,o,l);return c.update(t),c};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\"),o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.shader=n,this.buffer=e,this.vao=r,this.pixelRatio=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lineWidth=[1,1,1],this.capSize=[10,10,10],this.lineCount=[0,0,0],this.lineOffset=[0,0,0],this.opacity=1,this.hasAlpha=!1}var l=s.prototype;function c(t,e){for(var r=0;r<3;++r)t[0][r]=Math.min(t[0][r],e[r]),t[1][r]=Math.max(t[1][r],e[r])}l.isOpaque=function(){return!this.hasAlpha},l.isTransparent=function(){return this.hasAlpha},l.drawTransparent=l.draw=function(t){var e=this.gl,r=this.shader.uniforms;this.shader.bind();var n=r.view=t.view||o,i=r.projection=t.projection||o;r.model=t.model||o,r.clipBounds=this.clipBounds,r.opacity=this.opacity;var a=n[12],s=n[13],l=n[14],c=n[15],u=(t._ortho||!1?2:1)*this.pixelRatio*(i[3]*a+i[7]*s+i[11]*l+i[15]*c)/e.drawingBufferHeight;this.vao.bind();for(var h=0;h<3;++h)e.lineWidth(this.lineWidth[h]*this.pixelRatio),r.capSize=this.capSize[h]*u,this.lineCount[h]&&e.drawArrays(e.LINES,this.lineOffset[h],this.lineCount[h]);this.vao.unbind()};var u=function(){for(var t=new Array(3),e=0;e<3;++e){for(var r=[],n=1;n<=2;++n)for(var i=-1;i<=1;i+=2){var a=[0,0,0];a[(n+e)%3]=i,r.push(a)}t[e]=r}return t}();function h(t,e,r,n){for(var i=u[n],a=0;a<i.length;++a){var o=i[a];t.push(e[0],e[1],e[2],r[0],r[1],r[2],r[3],o[0],o[1],o[2])}return i.length}l.update=function(t){\"lineWidth\"in(t=t||{})&&(this.lineWidth=t.lineWidth,Array.isArray(this.lineWidth)||(this.lineWidth=[this.lineWidth,this.lineWidth,this.lineWidth])),\"capSize\"in t&&(this.capSize=t.capSize,Array.isArray(this.capSize)||(this.capSize=[this.capSize,this.capSize,this.capSize])),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var e=t.color||[[0,0,0],[0,0,0],[0,0,0]],r=t.position,n=t.error;if(Array.isArray(e[0])||(e=[e,e,e]),r&&n){var i=[],a=r.length,o=0;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.lineCount=[0,0,0];for(var s=0;s<3;++s){this.lineOffset[s]=o;t:for(var l=0;l<a;++l){for(var u=r[l],f=0;f<3;++f)if(isNaN(u[f])||!isFinite(u[f]))continue t;var p=n[l],d=e[s];if(Array.isArray(d[0])&&(d=e[l]),3===d.length?d=[d[0],d[1],d[2],1]:4===d.length&&(d=[d[0],d[1],d[2],d[3]],!this.hasAlpha&&d[3]<1&&(this.hasAlpha=!0)),!isNaN(p[0][s])&&!isNaN(p[1][s])){var g;if(p[0][s]<0)(g=u.slice())[s]+=p[0][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+h(i,g,d,s);if(p[1][s]>0)(g=u.slice())[s]+=p[1][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+h(i,g,d,s)}}this.lineCount[s]=o-this.lineOffset[s]}this.buffer.update(i)}},l.dispose=function(){this.shader.dispose(),this.buffer.dispose(),this.vao.dispose()}},{\"./shaders/index\":248,\"gl-buffer\":241,\"gl-vao\":327}],248:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, offset;\\nattribute vec4 color;\\nuniform mat4 model, view, projection;\\nuniform float capSize;\\nvarying vec4 fragColor;\\nvarying vec3 fragPosition;\\n\\nvoid main() {\\n  vec4 worldPosition  = model * vec4(position, 1.0);\\n  worldPosition       = (worldPosition / worldPosition.w) + vec4(capSize * offset, 0.0);\\n  gl_Position         = projection * view * worldPosition;\\n  fragColor           = color;\\n  fragPosition        = position;\\n}\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float opacity;\\nvarying vec3 fragPosition;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], fragPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  gl_FragColor = opacity * fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"offset\",type:\"vec3\"}])}},{\"gl-shader\":301,glslify:409}],249:[function(t,e,r){\"use strict\";var n=t(\"gl-texture2d\");e.exports=function(t,e,r,n){i||(i=t.FRAMEBUFFER_UNSUPPORTED,a=t.FRAMEBUFFER_INCOMPLETE_ATTACHMENT,o=t.FRAMEBUFFER_INCOMPLETE_DIMENSIONS,s=t.FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT);var c=t.getExtension(\"WEBGL_draw_buffers\");!l&&c&&function(t,e){var r=t.getParameter(e.MAX_COLOR_ATTACHMENTS_WEBGL);l=new Array(r+1);for(var n=0;n<=r;++n){for(var i=new Array(r),a=0;a<n;++a)i[a]=t.COLOR_ATTACHMENT0+a;for(var a=n;a<r;++a)i[a]=t.NONE;l[n]=i}}(t,c);Array.isArray(e)&&(n=r,r=0|e[1],e=0|e[0]);if(\"number\"!=typeof e)throw new Error(\"gl-fbo: Missing shape parameter\");var u=t.getParameter(t.MAX_RENDERBUFFER_SIZE);if(e<0||e>u||r<0||r>u)throw new Error(\"gl-fbo: Parameters are too large for FBO\");var h=1;if(\"color\"in(n=n||{})){if((h=Math.max(0|n.color,0))<0)throw new Error(\"gl-fbo: Must specify a nonnegative number of colors\");if(h>1){if(!c)throw new Error(\"gl-fbo: Multiple draw buffer extension not supported\");if(h>t.getParameter(c.MAX_COLOR_ATTACHMENTS_WEBGL))throw new Error(\"gl-fbo: Context does not support \"+h+\" draw buffers\")}}var f=t.UNSIGNED_BYTE,p=t.getExtension(\"OES_texture_float\");if(n.float&&h>0){if(!p)throw new Error(\"gl-fbo: Context does not support floating point textures\");f=t.FLOAT}else n.preferFloat&&h>0&&p&&(f=t.FLOAT);var g=!0;\"depth\"in n&&(g=!!n.depth);var v=!1;\"stencil\"in n&&(v=!!n.stencil);return new d(t,e,r,f,h,g,v,c)};var i,a,o,s,l=null;function c(t){return[t.getParameter(t.FRAMEBUFFER_BINDING),t.getParameter(t.RENDERBUFFER_BINDING),t.getParameter(t.TEXTURE_BINDING_2D)]}function u(t,e){t.bindFramebuffer(t.FRAMEBUFFER,e[0]),t.bindRenderbuffer(t.RENDERBUFFER,e[1]),t.bindTexture(t.TEXTURE_2D,e[2])}function h(t){switch(t){case i:throw new Error(\"gl-fbo: Framebuffer unsupported\");case a:throw new Error(\"gl-fbo: Framebuffer incomplete attachment\");case o:throw new Error(\"gl-fbo: Framebuffer incomplete dimensions\");case s:throw new Error(\"gl-fbo: Framebuffer incomplete missing attachment\");default:throw new Error(\"gl-fbo: Framebuffer failed for unspecified reason\")}}function f(t,e,r,i,a,o){if(!i)return null;var s=n(t,e,r,a,i);return s.magFilter=t.NEAREST,s.minFilter=t.NEAREST,s.mipSamples=1,s.bind(),t.framebufferTexture2D(t.FRAMEBUFFER,o,t.TEXTURE_2D,s.handle,0),s}function p(t,e,r,n,i){var a=t.createRenderbuffer();return t.bindRenderbuffer(t.RENDERBUFFER,a),t.renderbufferStorage(t.RENDERBUFFER,n,e,r),t.framebufferRenderbuffer(t.FRAMEBUFFER,i,t.RENDERBUFFER,a),a}function d(t,e,r,n,i,a,o,s){this.gl=t,this._shape=[0|e,0|r],this._destroyed=!1,this._ext=s,this.color=new Array(i);for(var d=0;d<i;++d)this.color[d]=null;this._color_rb=null,this.depth=null,this._depth_rb=null,this._colorType=n,this._useDepth=a,this._useStencil=o;var g=this,v=[0|e,0|r];Object.defineProperties(v,{0:{get:function(){return g._shape[0]},set:function(t){return g.width=t}},1:{get:function(){return g._shape[1]},set:function(t){return g.height=t}}}),this._shapeVector=v,function(t){var e=c(t.gl),r=t.gl,n=t.handle=r.createFramebuffer(),i=t._shape[0],a=t._shape[1],o=t.color.length,s=t._ext,d=t._useStencil,g=t._useDepth,v=t._colorType;r.bindFramebuffer(r.FRAMEBUFFER,n);for(var m=0;m<o;++m)t.color[m]=f(r,i,a,v,r.RGBA,r.COLOR_ATTACHMENT0+m);0===o?(t._color_rb=p(r,i,a,r.RGBA4,r.COLOR_ATTACHMENT0),s&&s.drawBuffersWEBGL(l[0])):o>1&&s.drawBuffersWEBGL(l[o]);var y=r.getExtension(\"WEBGL_depth_texture\");y?d?t.depth=f(r,i,a,y.UNSIGNED_INT_24_8_WEBGL,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g&&(t.depth=f(r,i,a,r.UNSIGNED_SHORT,r.DEPTH_COMPONENT,r.DEPTH_ATTACHMENT)):g&&d?t._depth_rb=p(r,i,a,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g?t._depth_rb=p(r,i,a,r.DEPTH_COMPONENT16,r.DEPTH_ATTACHMENT):d&&(t._depth_rb=p(r,i,a,r.STENCIL_INDEX,r.STENCIL_ATTACHMENT));var x=r.checkFramebufferStatus(r.FRAMEBUFFER);if(x!==r.FRAMEBUFFER_COMPLETE){for(t._destroyed=!0,r.bindFramebuffer(r.FRAMEBUFFER,null),r.deleteFramebuffer(t.handle),t.handle=null,t.depth&&(t.depth.dispose(),t.depth=null),t._depth_rb&&(r.deleteRenderbuffer(t._depth_rb),t._depth_rb=null),m=0;m<t.color.length;++m)t.color[m].dispose(),t.color[m]=null;t._color_rb&&(r.deleteRenderbuffer(t._color_rb),t._color_rb=null),u(r,e),h(x)}u(r,e)}(this)}var g=d.prototype;function v(t,e,r){if(t._destroyed)throw new Error(\"gl-fbo: Can't resize destroyed FBO\");if(t._shape[0]!==e||t._shape[1]!==r){var n=t.gl,i=n.getParameter(n.MAX_RENDERBUFFER_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-fbo: Can't resize FBO, invalid dimensions\");t._shape[0]=e,t._shape[1]=r;for(var a=c(n),o=0;o<t.color.length;++o)t.color[o].shape=t._shape;t._color_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._color_rb),n.renderbufferStorage(n.RENDERBUFFER,n.RGBA4,t._shape[0],t._shape[1])),t.depth&&(t.depth.shape=t._shape),t._depth_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._depth_rb),t._useDepth&&t._useStencil?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_STENCIL,t._shape[0],t._shape[1]):t._useDepth?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_COMPONENT16,t._shape[0],t._shape[1]):t._useStencil&&n.renderbufferStorage(n.RENDERBUFFER,n.STENCIL_INDEX,t._shape[0],t._shape[1])),n.bindFramebuffer(n.FRAMEBUFFER,t.handle);var s=n.checkFramebufferStatus(n.FRAMEBUFFER);s!==n.FRAMEBUFFER_COMPLETE&&(t.dispose(),u(n,a),h(s)),u(n,a)}}Object.defineProperties(g,{shape:{get:function(){return this._destroyed?[0,0]:this._shapeVector},set:function(t){if(Array.isArray(t)||(t=[0|t,0|t]),2!==t.length)throw new Error(\"gl-fbo: Shape vector must be length 2\");var e=0|t[0],r=0|t[1];return v(this,e,r),[e,r]},enumerable:!1},width:{get:function(){return this._destroyed?0:this._shape[0]},set:function(t){return v(this,t|=0,this._shape[1]),t},enumerable:!1},height:{get:function(){return this._destroyed?0:this._shape[1]},set:function(t){return t|=0,v(this,this._shape[0],t),t},enumerable:!1}}),g.bind=function(){if(!this._destroyed){var t=this.gl;t.bindFramebuffer(t.FRAMEBUFFER,this.handle),t.viewport(0,0,this._shape[0],this._shape[1])}},g.dispose=function(){if(!this._destroyed){this._destroyed=!0;var t=this.gl;t.deleteFramebuffer(this.handle),this.handle=null,this.depth&&(this.depth.dispose(),this.depth=null),this._depth_rb&&(t.deleteRenderbuffer(this._depth_rb),this._depth_rb=null);for(var e=0;e<this.color.length;++e)this.color[e].dispose(),this.color[e]=null;this._color_rb&&(t.deleteRenderbuffer(this._color_rb),this._color_rb=null)}}},{\"gl-texture2d\":322}],250:[function(t,e,r){var n=t(\"sprintf-js\").sprintf,i=t(\"gl-constants/lookup\"),a=t(\"glsl-shader-name\"),o=t(\"add-line-numbers\");e.exports=function(t,e,r){\"use strict\";var s=a(e)||\"of unknown name (see npm glsl-shader-name)\",l=\"unknown type\";void 0!==r&&(l=r===i.FRAGMENT_SHADER?\"fragment\":\"vertex\");for(var c=n(\"Error compiling %s shader %s:\\n\",l,s),u=n(\"%s%s\",c,t),h=t.split(\"\\n\"),f={},p=0;p<h.length;p++){var d=h[p];if(\"\"!==d&&\"\\0\"!==d){var g=parseInt(d.split(\":\")[2]);if(isNaN(g))throw new Error(n(\"Could not parse error: %s\",d));f[g]=d}}for(var v=o(e).split(\"\\n\"),p=0;p<v.length;p++)if(f[p+3]||f[p+2]||f[p+1]){var m=v[p];if(c+=m+\"\\n\",f[p+1]){var y=f[p+1];y=y.substr(y.split(\":\",3).join(\":\").length+1).trim(),c+=n(\"^^^ %s\\n\\n\",y)}}return{long:c.trim(),short:u.trim()}}},{\"add-line-numbers\":61,\"gl-constants/lookup\":246,\"glsl-shader-name\":401,\"sprintf-js\":528}],251:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.gl,n=o(r,l.vertex,l.fragment),i=o(r,l.pickVertex,l.pickFragment),a=s(r),u=s(r),h=s(r),f=s(r),p=new c(t,n,i,a,u,h,f);return p.update(e),t.addObject(p),p};var n=t(\"binary-search-bounds\"),i=t(\"iota-array\"),a=t(\"typedarray-pool\"),o=t(\"gl-shader\"),s=t(\"gl-buffer\"),l=t(\"./lib/shaders\");function c(t,e,r,n,i,a,o){this.plot=t,this.shader=e,this.pickShader=r,this.positionBuffer=n,this.weightBuffer=i,this.colorBuffer=a,this.idBuffer=o,this.xData=[],this.yData=[],this.shape=[0,0],this.bounds=[1/0,1/0,-1/0,-1/0],this.pickOffset=0}var u,h=c.prototype,f=[0,0,1,0,0,1,1,0,1,1,0,1];h.draw=(u=[1,0,0,0,1,0,0,0,1],function(){var t=this.plot,e=this.shader,r=this.bounds,n=this.numVertices;if(!(n<=0)){var i=t.gl,a=t.dataBox,o=r[2]-r[0],s=r[3]-r[1],l=a[2]-a[0],c=a[3]-a[1];u[0]=2*o/l,u[4]=2*s/c,u[6]=2*(r[0]-a[0])/l-1,u[7]=2*(r[1]-a[1])/c-1,e.bind();var h=e.uniforms;h.viewTransform=u,h.shape=this.shape;var f=e.attributes;this.positionBuffer.bind(),f.position.pointer(),this.weightBuffer.bind(),f.weight.pointer(i.UNSIGNED_BYTE,!1),this.colorBuffer.bind(),f.color.pointer(i.UNSIGNED_BYTE,!0),i.drawArrays(i.TRIANGLES,0,n)}}),h.drawPick=function(){var t=[1,0,0,0,1,0,0,0,1],e=[0,0,0,0];return function(r){var n=this.plot,i=this.pickShader,a=this.bounds,o=this.numVertices;if(!(o<=0)){var s=n.gl,l=n.dataBox,c=a[2]-a[0],u=a[3]-a[1],h=l[2]-l[0],f=l[3]-l[1];t[0]=2*c/h,t[4]=2*u/f,t[6]=2*(a[0]-l[0])/h-1,t[7]=2*(a[1]-l[1])/f-1;for(var p=0;p<4;++p)e[p]=r>>8*p&255;this.pickOffset=r,i.bind();var d=i.uniforms;d.viewTransform=t,d.pickOffset=e,d.shape=this.shape;var g=i.attributes;return this.positionBuffer.bind(),g.position.pointer(),this.weightBuffer.bind(),g.weight.pointer(s.UNSIGNED_BYTE,!1),this.idBuffer.bind(),g.pickId.pointer(s.UNSIGNED_BYTE,!1),s.drawArrays(s.TRIANGLES,0,o),r+this.shape[0]*this.shape[1]}}}(),h.pick=function(t,e,r){var n=this.pickOffset,i=this.shape[0]*this.shape[1];if(r<n||r>=n+i)return null;var a=r-n,o=this.xData,s=this.yData;return{object:this,pointId:a,dataCoord:[o[a%this.shape[0]],s[a/this.shape[0]|0]]}},h.update=function(t){var e=(t=t||{}).shape||[0,0],r=t.x||i(e[0]),o=t.y||i(e[1]),s=t.z||new Float32Array(e[0]*e[1]);this.xData=r,this.yData=o;var l=t.colorLevels||[0],c=t.colorValues||[0,0,0,1],u=l.length,h=this.bounds,p=h[0]=r[0],d=h[1]=o[0],g=1/((h[2]=r[r.length-1])-p),v=1/((h[3]=o[o.length-1])-d),m=e[0],y=e[1];this.shape=[m,y];var x=(m-1)*(y-1)*(f.length>>>1);this.numVertices=x;for(var b=a.mallocUint8(4*x),_=a.mallocFloat32(2*x),w=a.mallocUint8(2*x),k=a.mallocUint32(x),T=0,A=0;A<y-1;++A)for(var M=v*(o[A]-d),S=v*(o[A+1]-d),E=0;E<m-1;++E)for(var C=g*(r[E]-p),L=g*(r[E+1]-p),P=0;P<f.length;P+=2){var O,z,I,D,R=f[P],F=f[P+1],B=s[(A+F)*m+(E+R)],N=n.le(l,B);if(N<0)O=c[0],z=c[1],I=c[2],D=c[3];else if(N===u-1)O=c[4*u-4],z=c[4*u-3],I=c[4*u-2],D=c[4*u-1];else{var j=(B-l[N])/(l[N+1]-l[N]),U=1-j,V=4*N,q=4*(N+1);O=U*c[V]+j*c[q],z=U*c[V+1]+j*c[q+1],I=U*c[V+2]+j*c[q+2],D=U*c[V+3]+j*c[q+3]}b[4*T]=255*O,b[4*T+1]=255*z,b[4*T+2]=255*I,b[4*T+3]=255*D,_[2*T]=.5*C+.5*L,_[2*T+1]=.5*M+.5*S,w[2*T]=R,w[2*T+1]=F,k[T]=A*m+E,T+=1}this.positionBuffer.update(_),this.weightBuffer.update(w),this.colorBuffer.update(b),this.idBuffer.update(k),a.free(_),a.free(b),a.free(w),a.free(k)},h.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.positionBuffer.dispose(),this.weightBuffer.dispose(),this.colorBuffer.dispose(),this.idBuffer.dispose(),this.plot.removeObject(this)}},{\"./lib/shaders\":252,\"binary-search-bounds\":253,\"gl-buffer\":241,\"gl-shader\":301,\"iota-array\":416,\"typedarray-pool\":545}],252:[function(t,e,r){\"use strict\";var n=t(\"glslify\");e.exports={fragment:n([\"precision lowp float;\\n#define GLSLIFY 1\\nvarying vec4 fragColor;\\nvoid main() {\\n  gl_FragColor = vec4(fragColor.rgb * fragColor.a, fragColor.a);\\n}\\n\"]),vertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 color;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  fragColor = color;\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"]),pickFragment:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nuniform vec2 shape;\\nuniform vec4 pickOffset;\\n\\nvoid main() {\\n  vec2 d = step(.5, vWeight);\\n  vec4 id = fragId + pickOffset;\\n  id.x += d.x + d.y*shape.x;\\n\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  gl_FragColor = id/255.;\\n}\\n\"]),pickVertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nvoid main() {\\n  vWeight = weight;\\n\\n  fragId = pickId;\\n\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"])}},{glslify:409}],253:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],254:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, nextPosition;\\nattribute float arcLength, lineWidth;\\nattribute vec4 color;\\n\\nuniform vec2 screenShape;\\nuniform float pixelRatio;\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 fragColor;\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  vec4 startPoint = project(position);\\n  vec4 endPoint   = project(nextPosition);\\n\\n  vec2 A = startPoint.xy / startPoint.w;\\n  vec2 B =   endPoint.xy /   endPoint.w;\\n\\n  float clipAngle = atan(\\n    (B.y - A.y) * screenShape.y,\\n    (B.x - A.x) * screenShape.x\\n  );\\n\\n  vec2 offset = 0.5 * pixelRatio * lineWidth * vec2(\\n    sin(clipAngle),\\n    -cos(clipAngle)\\n  ) / screenShape;\\n\\n  gl_Position = vec4(startPoint.xy + startPoint.w * offset, startPoint.zw);\\n\\n  worldPosition = position;\\n  pixelArcLength = arcLength;\\n  fragColor = color;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3      clipBounds[2];\\nuniform sampler2D dashTexture;\\nuniform float     dashScale;\\nuniform float     opacity;\\n\\nvarying vec3    worldPosition;\\nvarying float   pixelArcLength;\\nvarying vec4    fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], worldPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  float dashWeight = texture2D(dashTexture, vec2(dashScale * pixelArcLength, 0)).r;\\n  if(dashWeight < 0.5) {\\n    discard;\\n  }\\n  gl_FragColor = fragColor * opacity;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\n#define FLOAT_MAX  1.70141184e38\\n#define FLOAT_MIN  1.17549435e-38\\n\\nlowp vec4 encode_float_1540259130(highp float v) {\\n  highp float av = abs(v);\\n\\n  //Handle special cases\\n  if(av < FLOAT_MIN) {\\n    return vec4(0.0, 0.0, 0.0, 0.0);\\n  } else if(v > FLOAT_MAX) {\\n    return vec4(127.0, 128.0, 0.0, 0.0) / 255.0;\\n  } else if(v < -FLOAT_MAX) {\\n    return vec4(255.0, 128.0, 0.0, 0.0) / 255.0;\\n  }\\n\\n  highp vec4 c = vec4(0,0,0,0);\\n\\n  //Compute exponent and mantissa\\n  highp float e = floor(log2(av));\\n  highp float m = av * pow(2.0, -e) - 1.0;\\n  \\n  //Unpack mantissa\\n  c[1] = floor(128.0 * m);\\n  m -= c[1] / 128.0;\\n  c[2] = floor(32768.0 * m);\\n  m -= c[2] / 32768.0;\\n  c[3] = floor(8388608.0 * m);\\n  \\n  //Unpack exponent\\n  highp float ebias = e + 127.0;\\n  c[0] = floor(ebias / 2.0);\\n  ebias -= c[0] * 2.0;\\n  c[1] += floor(ebias) * 128.0; \\n\\n  //Unpack sign bit\\n  c[0] += 128.0 * step(0.0, -v);\\n\\n  //Scale back to range\\n  return c / 255.0;\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform float pickId;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], worldPosition)) discard;\\n\\n  gl_FragColor = vec4(pickId/255.0, encode_float_1540259130(pixelArcLength).xyz);\\n}\"]),l=[{name:\"position\",type:\"vec3\"},{name:\"nextPosition\",type:\"vec3\"},{name:\"arcLength\",type:\"float\"},{name:\"lineWidth\",type:\"float\"},{name:\"color\",type:\"vec4\"}];r.createShader=function(t){return i(t,a,o,null,l)},r.createPickShader=function(t){return i(t,a,s,null,l)}},{\"gl-shader\":301,glslify:409}],255:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl||t.scene&&t.scene.gl,r=u(e);r.attributes.position.location=0,r.attributes.nextPosition.location=1,r.attributes.arcLength.location=2,r.attributes.lineWidth.location=3,r.attributes.color.location=4;var o=h(e);o.attributes.position.location=0,o.attributes.nextPosition.location=1,o.attributes.arcLength.location=2,o.attributes.lineWidth.location=3,o.attributes.color.location=4;for(var s=n(e),c=i(e,[{buffer:s,size:3,offset:0,stride:48},{buffer:s,size:3,offset:12,stride:48},{buffer:s,size:1,offset:24,stride:48},{buffer:s,size:1,offset:28,stride:48},{buffer:s,size:4,offset:32,stride:48}]),f=l(new Array(1024),[256,1,4]),p=0;p<1024;++p)f.data[p]=255;var d=a(e,f);d.wrap=e.REPEAT;var g=new v(e,r,o,s,c,d);return g.update(t),g};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"gl-texture2d\"),o=t(\"glsl-read-float\"),s=t(\"binary-search-bounds\"),l=t(\"ndarray\"),c=t(\"./lib/shaders\"),u=c.createShader,h=c.createPickShader,f=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function p(t,e){for(var r=0,n=0;n<3;++n){var i=t[n]-e[n];r+=i*i}return Math.sqrt(r)}function d(t){for(var e=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],r=0;r<3;++r)e[0][r]=Math.max(t[0][r],e[0][r]),e[1][r]=Math.min(t[1][r],e[1][r]);return e}function g(t,e,r,n){this.arcLength=t,this.position=e,this.index=r,this.dataCoordinate=n}function v(t,e,r,n,i,a){this.gl=t,this.shader=e,this.pickShader=r,this.buffer=n,this.vao=i,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.points=[],this.arcLength=[],this.vertexCount=0,this.bounds=[[0,0,0],[0,0,0]],this.pickId=0,this.lineWidth=1,this.texture=a,this.dashScale=1,this.opacity=1,this.hasAlpha=!1,this.dirty=!0,this.pixelRatio=1}var m=v.prototype;m.isTransparent=function(){return this.hasAlpha},m.isOpaque=function(){return!this.hasAlpha},m.pickSlots=1,m.setPickBase=function(t){this.pickId=t},m.drawTransparent=m.draw=function(t){if(this.vertexCount){var e=this.gl,r=this.shader,n=this.vao;r.bind(),r.uniforms={model:t.model||f,view:t.view||f,projection:t.projection||f,clipBounds:d(this.clipBounds),dashTexture:this.texture.bind(),dashScale:this.dashScale/this.arcLength[this.arcLength.length-1],opacity:this.opacity,screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},m.drawPick=function(t){if(this.vertexCount){var e=this.gl,r=this.pickShader,n=this.vao;r.bind(),r.uniforms={model:t.model||f,view:t.view||f,projection:t.projection||f,pickId:this.pickId,clipBounds:d(this.clipBounds),screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},m.update=function(t){var e,r;this.dirty=!0;var n=!!t.connectGaps;\"dashScale\"in t&&(this.dashScale=t.dashScale),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var i=[],a=[],o=[],c=0,u=0,h=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],f=t.position||t.positions;if(f){var d=t.color||t.colors||[0,0,0,1],g=t.lineWidth||1,v=!1;t:for(e=1;e<f.length;++e){var m,y,x,b=f[e-1],_=f[e];for(a.push(c),o.push(b.slice()),r=0;r<3;++r){if(isNaN(b[r])||isNaN(_[r])||!isFinite(b[r])||!isFinite(_[r])){if(!n&&i.length>0){for(var w=0;w<24;++w)i.push(i[i.length-12]);u+=2,v=!0}continue t}h[0][r]=Math.min(h[0][r],b[r],_[r]),h[1][r]=Math.max(h[1][r],b[r],_[r])}Array.isArray(d[0])?(m=d.length>e-1?d[e-1]:d.length>0?d[d.length-1]:[0,0,0,1],y=d.length>e?d[e]:d.length>0?d[d.length-1]:[0,0,0,1]):m=y=d,3===m.length&&(m=[m[0],m[1],m[2],1]),3===y.length&&(y=[y[0],y[1],y[2],1]),!this.hasAlpha&&m[3]<1&&(this.hasAlpha=!0),x=Array.isArray(g)?g.length>e-1?g[e-1]:g.length>0?g[g.length-1]:[0,0,0,1]:g;var k=c;if(c+=p(b,_),v){for(r=0;r<2;++r)i.push(b[0],b[1],b[2],_[0],_[1],_[2],k,x,m[0],m[1],m[2],m[3]);u+=2,v=!1}i.push(b[0],b[1],b[2],_[0],_[1],_[2],k,x,m[0],m[1],m[2],m[3],b[0],b[1],b[2],_[0],_[1],_[2],k,-x,m[0],m[1],m[2],m[3],_[0],_[1],_[2],b[0],b[1],b[2],c,-x,y[0],y[1],y[2],y[3],_[0],_[1],_[2],b[0],b[1],b[2],c,x,y[0],y[1],y[2],y[3]),u+=4}}if(this.buffer.update(i),a.push(c),o.push(f[f.length-1].slice()),this.bounds=h,this.vertexCount=u,this.points=o,this.arcLength=a,\"dashes\"in t){var T=t.dashes.slice();for(T.unshift(0),e=1;e<T.length;++e)T[e]=T[e-1]+T[e];var A=l(new Array(1024),[256,1,4]);for(e=0;e<256;++e){for(r=0;r<4;++r)A.set(e,0,r,0);1&s.le(T,T[T.length-1]*e/255)?A.set(e,0,0,0):A.set(e,0,0,255)}this.texture.setPixels(A)}},m.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()},m.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=o(t.value[0],t.value[1],t.value[2],0),r=s.le(this.arcLength,e);if(r<0)return null;if(r===this.arcLength.length-1)return new g(this.arcLength[this.arcLength.length-1],this.points[this.points.length-1].slice(),r);for(var n=this.points[r],i=this.points[Math.min(r+1,this.points.length-1)],a=(e-this.arcLength[r])/(this.arcLength[r+1]-this.arcLength[r]),l=1-a,c=[0,0,0],u=0;u<3;++u)c[u]=l*n[u]+a*i[u];var h=Math.min(a<.5?r:r+1,this.points.length-1);return new g(e,c,h,this.points[h])}},{\"./lib/shaders\":254,\"binary-search-bounds\":256,\"gl-buffer\":241,\"gl-texture2d\":322,\"gl-vao\":327,\"glsl-read-float\":400,ndarray:450}],256:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],257:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r*a-i*n;return o?(o=1/o,t[0]=a*o,t[1]=-n*o,t[2]=-i*o,t[3]=r*o,t):null}},{}],258:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=u*o-s*c,f=-u*a+s*l,p=c*a-o*l,d=r*h+n*f+i*p;return d?(d=1/d,t[0]=h*d,t[1]=(-u*n+i*c)*d,t[2]=(s*n-i*o)*d,t[3]=f*d,t[4]=(u*r-i*l)*d,t[5]=(-s*r+i*a)*d,t[6]=p*d,t[7]=(-c*r+n*l)*d,t[8]=(o*r-n*a)*d,t):null}},{}],259:[function(t,e,r){e.exports=function(t){var e=new Float32Array(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e}},{}],260:[function(t,e,r){e.exports=function(){var t=new Float32Array(16);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],261:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3],a=t[4],o=t[5],s=t[6],l=t[7],c=t[8],u=t[9],h=t[10],f=t[11],p=t[12],d=t[13],g=t[14],v=t[15];return(e*o-r*a)*(h*v-f*g)-(e*s-n*a)*(u*v-f*d)+(e*l-i*a)*(u*g-h*d)+(r*s-n*o)*(c*v-f*p)-(r*l-i*o)*(c*g-h*p)+(n*l-i*s)*(c*d-u*p)}},{}],262:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r+r,s=n+n,l=i+i,c=r*o,u=n*o,h=n*s,f=i*o,p=i*s,d=i*l,g=a*o,v=a*s,m=a*l;return t[0]=1-h-d,t[1]=u+m,t[2]=f-v,t[3]=0,t[4]=u-m,t[5]=1-c-d,t[6]=p+g,t[7]=0,t[8]=f+v,t[9]=p-g,t[10]=1-c-h,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],263:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=n+n,l=i+i,c=a+a,u=n*s,h=n*l,f=n*c,p=i*l,d=i*c,g=a*c,v=o*s,m=o*l,y=o*c;return t[0]=1-(p+g),t[1]=h+y,t[2]=f-m,t[3]=0,t[4]=h-y,t[5]=1-(u+g),t[6]=d+v,t[7]=0,t[8]=f+m,t[9]=d-v,t[10]=1-(u+p),t[11]=0,t[12]=r[0],t[13]=r[1],t[14]=r[2],t[15]=1,t}},{}],264:[function(t,e,r){e.exports=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],265:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],g=e[13],v=e[14],m=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,k=i*c-a*l,T=u*g-h*d,A=u*v-f*d,M=u*m-p*d,S=h*v-f*g,E=h*m-p*g,C=f*m-p*v,L=y*C-x*E+b*S+_*M-w*A+k*T;if(!L)return null;return L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(i*E-n*C-a*S)*L,t[2]=(g*k-v*w+m*_)*L,t[3]=(f*w-h*k-p*_)*L,t[4]=(l*M-o*C-c*A)*L,t[5]=(r*C-i*M+a*A)*L,t[6]=(v*b-d*k-m*x)*L,t[7]=(u*k-f*b+p*x)*L,t[8]=(o*E-s*M+c*T)*L,t[9]=(n*M-r*E-a*T)*L,t[10]=(d*w-g*b+m*y)*L,t[11]=(h*b-u*w-p*y)*L,t[12]=(s*A-o*S-l*T)*L,t[13]=(r*S-n*A+i*T)*L,t[14]=(g*x-d*_-v*y)*L,t[15]=(u*_-h*x+f*y)*L,t}},{}],266:[function(t,e,r){var n=t(\"./identity\");e.exports=function(t,e,r,i){var a,o,s,l,c,u,h,f,p,d,g=e[0],v=e[1],m=e[2],y=i[0],x=i[1],b=i[2],_=r[0],w=r[1],k=r[2];if(Math.abs(g-_)<1e-6&&Math.abs(v-w)<1e-6&&Math.abs(m-k)<1e-6)return n(t);h=g-_,f=v-w,p=m-k,d=1/Math.sqrt(h*h+f*f+p*p),a=x*(p*=d)-b*(f*=d),o=b*(h*=d)-y*p,s=y*f-x*h,(d=Math.sqrt(a*a+o*o+s*s))?(a*=d=1/d,o*=d,s*=d):(a=0,o=0,s=0);l=f*s-p*o,c=p*a-h*s,u=h*o-f*a,(d=Math.sqrt(l*l+c*c+u*u))?(l*=d=1/d,c*=d,u*=d):(l=0,c=0,u=0);return t[0]=a,t[1]=l,t[2]=h,t[3]=0,t[4]=o,t[5]=c,t[6]=f,t[7]=0,t[8]=s,t[9]=u,t[10]=p,t[11]=0,t[12]=-(a*g+o*v+s*m),t[13]=-(l*g+c*v+u*m),t[14]=-(h*g+f*v+p*m),t[15]=1,t}},{\"./identity\":264}],267:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],g=e[12],v=e[13],m=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*h+w*g,t[1]=x*i+b*l+_*f+w*v,t[2]=x*a+b*c+_*p+w*m,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*h+w*g,t[5]=x*i+b*l+_*f+w*v,t[6]=x*a+b*c+_*p+w*m,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*h+w*g,t[9]=x*i+b*l+_*f+w*v,t[10]=x*a+b*c+_*p+w*m,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*h+w*g,t[13]=x*i+b*l+_*f+w*v,t[14]=x*a+b*c+_*p+w*m,t[15]=x*o+b*u+_*d+w*y,t}},{}],268:[function(t,e,r){e.exports=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t}},{}],269:[function(t,e,r){e.exports=function(t,e,r,n,i){var a=1/Math.tan(e/2),o=1/(n-i);return t[0]=a/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=a,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=(i+n)*o,t[11]=-1,t[12]=0,t[13]=0,t[14]=2*i*n*o,t[15]=0,t}},{}],270:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_,w,k,T,A,M,S,E=n[0],C=n[1],L=n[2],P=Math.sqrt(E*E+C*C+L*L);if(Math.abs(P)<1e-6)return null;E*=P=1/P,C*=P,L*=P,i=Math.sin(r),a=Math.cos(r),o=1-a,s=e[0],l=e[1],c=e[2],u=e[3],h=e[4],f=e[5],p=e[6],d=e[7],g=e[8],v=e[9],m=e[10],y=e[11],x=E*E*o+a,b=C*E*o+L*i,_=L*E*o-C*i,w=E*C*o-L*i,k=C*C*o+a,T=L*C*o+E*i,A=E*L*o+C*i,M=C*L*o-E*i,S=L*L*o+a,t[0]=s*x+h*b+g*_,t[1]=l*x+f*b+v*_,t[2]=c*x+p*b+m*_,t[3]=u*x+d*b+y*_,t[4]=s*w+h*k+g*T,t[5]=l*w+f*k+v*T,t[6]=c*w+p*k+m*T,t[7]=u*w+d*k+y*T,t[8]=s*A+h*M+g*S,t[9]=l*A+f*M+v*S,t[10]=c*A+p*M+m*S,t[11]=u*A+d*M+y*S,e!==t&&(t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t}},{}],271:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+h*n,t[7]=l*i+f*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=h*i-s*n,t[11]=f*i-l*n,t}},{}],272:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[8],u=e[9],h=e[10],f=e[11];e!==t&&(t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i-c*n,t[1]=o*i-u*n,t[2]=s*i-h*n,t[3]=l*i-f*n,t[8]=a*n+c*i,t[9]=o*n+u*i,t[10]=s*n+h*i,t[11]=l*n+f*i,t}},{}],273:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+h*n,t[3]=l*i+f*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=h*i-s*n,t[7]=f*i-l*n,t}},{}],274:[function(t,e,r){e.exports=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},{}],275:[function(t,e,r){e.exports=function(t,e,r){var n,i,a,o,s,l,c,u,h,f,p,d,g=r[0],v=r[1],m=r[2];e===t?(t[12]=e[0]*g+e[4]*v+e[8]*m+e[12],t[13]=e[1]*g+e[5]*v+e[9]*m+e[13],t[14]=e[2]*g+e[6]*v+e[10]*m+e[14],t[15]=e[3]*g+e[7]*v+e[11]*m+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*g+s*v+h*m+e[12],t[13]=i*g+l*v+f*m+e[13],t[14]=a*g+c*v+p*m+e[14],t[15]=o*g+u*v+d*m+e[15]);return t}},{}],276:[function(t,e,r){e.exports=function(t,e){if(t===e){var r=e[1],n=e[2],i=e[3],a=e[6],o=e[7],s=e[11];t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=r,t[6]=e[9],t[7]=e[13],t[8]=n,t[9]=a,t[11]=e[14],t[12]=i,t[13]=o,t[14]=s}else t[0]=e[0],t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=e[1],t[5]=e[5],t[6]=e[9],t[7]=e[13],t[8]=e[2],t[9]=e[6],t[10]=e[10],t[11]=e[14],t[12]=e[3],t[13]=e[7],t[14]=e[11],t[15]=e[15];return t}},{}],277:[function(t,e,r){\"use strict\";e.exports=function(t,e){switch(e.length){case 0:break;case 1:t[0]=1/e[0];break;case 4:n(t,e);break;case 9:i(t,e);break;case 16:a(t,e);break;default:throw new Error(\"currently supports matrices up to 4x4\")}return t};var n=t(\"gl-mat2/invert\"),i=t(\"gl-mat3/invert\"),a=t(\"gl-mat4/invert\")},{\"gl-mat2/invert\":257,\"gl-mat3/invert\":258,\"gl-mat4/invert\":265}],278:[function(t,e,r){\"use strict\";var n=t(\"barycentric\"),i=t(\"polytope-closest-point/lib/closest_point_2d.js\");function a(t,e){for(var r=[0,0,0,0],n=0;n<4;++n)for(var i=0;i<4;++i)r[i]+=t[4*n+i]*e[n];return r}function o(t,e,r,n,i){for(var o=a(n,a(r,a(e,[t[0],t[1],t[2],1]))),s=0;s<3;++s)o[s]/=o[3];return[.5*i[0]*(1+o[0]),.5*i[1]*(1-o[1])]}e.exports=function(t,e,r,a,s,l){if(1===t.length)return[0,t[0].slice()];for(var c=new Array(t.length),u=0;u<t.length;++u)c[u]=o(t[u],r,a,s,l);for(var h=0,f=1/0,u=0;u<c.length;++u){for(var p=0,d=0;d<2;++d)p+=Math.pow(c[u][d]-e[d],2);p<f&&(f=p,h=u)}for(var g=function(t,e){if(2===t.length){for(var r=0,a=0,o=0;o<2;++o)r+=Math.pow(e[o]-t[0][o],2),a+=Math.pow(e[o]-t[1][o],2);return r=Math.sqrt(r),a=Math.sqrt(a),r+a<1e-6?[1,0]:[a/(r+a),r/(a+r)]}if(3===t.length){var s=[0,0];return i(t[0],t[1],t[2],e,s),n(t,s)}return[]}(c,e),v=0,u=0;u<3;++u){if(g[u]<-.001||g[u]>1.0001)return null;v+=g[u]}if(Math.abs(v-1)>.001)return null;return[h,function(t,e){for(var r=[0,0,0],n=0;n<t.length;++n)for(var i=t[n],a=e[n],o=0;o<3;++o)r[o]+=a*i[o];return r}(t,g),g]}},{barycentric:73,\"polytope-closest-point/lib/closest_point_2d.js\":481}],279:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, normal;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  gl_Position      = project(position);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * vec4(position , 1.0);\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal  = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  f_color          = color;\\n  f_data           = position;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\n//#pragma glslify: beckmann = require(glsl-specular-beckmann) // used in gl-surface3d\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (f_color.a == 0.0 ||\\n    outOfRange(clipBounds[0], clipBounds[1], f_data)\\n  ) discard;\\n\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  //float specular = max(0.0, beckmann(L, V, N, roughness)); // used in gl-surface3d\\n\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = vec4(f_color.rgb, 1.0) * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * f_color.a;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_color = color;\\n  f_data  = position;\\n  f_uv    = uv;\\n}\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_data)) discard;\\n\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\nattribute float pointSize;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0 ,0.0 ,0.0);\\n  } else {\\n    gl_Position = projection * view * model * vec4(position, 1.0);\\n  }\\n  gl_PointSize = pointSize;\\n  f_color = color;\\n  f_uv = uv;\\n}\"]),c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  vec2 pointR = gl_PointCoord.xy - vec2(0.5, 0.5);\\n  if(dot(pointR, pointR) > 0.25) {\\n    discard;\\n  }\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_id        = id;\\n  f_position  = position;\\n}\"]),h=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]),f=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3  position;\\nattribute float pointSize;\\nattribute vec4  id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0, 0.0, 0.0);\\n  } else {\\n    gl_Position  = projection * view * model * vec4(position, 1.0);\\n    gl_PointSize = pointSize;\\n  }\\n  f_id         = id;\\n  f_position   = position;\\n}\"]),p=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n}\"]),d=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec3 contourColor;\\n\\nvoid main() {\\n  gl_FragColor = vec4(contourColor, 1.0);\\n}\\n\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.wireShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.pointShader={vertex:l,fragment:c,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"pointSize\",type:\"float\"}]},r.pickShader={vertex:u,fragment:h,attributes:[{name:\"position\",type:\"vec3\"},{name:\"id\",type:\"vec4\"}]},r.pointPickShader={vertex:f,fragment:h,attributes:[{name:\"position\",type:\"vec3\"},{name:\"pointSize\",type:\"float\"},{name:\"id\",type:\"vec4\"}]},r.contourShader={vertex:p,fragment:d,attributes:[{name:\"position\",type:\"vec3\"}]}},{glslify:409}],280:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./lib/shaders\"),g=t(\"./lib/closest-point\"),v=d.meshShader,m=d.wireShader,y=d.pointShader,x=d.pickShader,b=d.pointPickShader,_=d.contourShader,w=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function k(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_,k,T,A,M,S){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.lineShader=n,this.pointShader=i,this.pickShader=a,this.pointPickShader=o,this.contourShader=s,this.trianglePositions=l,this.triangleColors=u,this.triangleNormals=f,this.triangleUVs=h,this.triangleIds=c,this.triangleVAO=p,this.triangleCount=0,this.lineWidth=1,this.edgePositions=d,this.edgeColors=v,this.edgeUVs=m,this.edgeIds=g,this.edgeVAO=y,this.edgeCount=0,this.pointPositions=x,this.pointColors=_,this.pointUVs=k,this.pointSizes=T,this.pointIds=b,this.pointVAO=A,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=M,this.contourVAO=S,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.hasAlpha=!1,this.opacityscale=!1,this._model=w,this._view=w,this._projection=w,this._resolution=[1,1]}var T=k.prototype;function A(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}function M(t){var e=n(t,y.vertex,y.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.pointSize.location=4,e}function S(t){var e=n(t,x.vertex,x.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e}function E(t){var e=n(t,b.vertex,b.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.pointSize.location=4,e}function C(t){var e=n(t,_.vertex,_.fragment);return e.attributes.position.location=0,e}T.isOpaque=function(){return!this.hasAlpha},T.isTransparent=function(){return this.hasAlpha},T.pickSlots=1,T.setPickBase=function(t){this.pickId=t},T.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=i[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},T.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=t.opacity,this.opacity<1&&(this.hasAlpha=!0)),\"opacityscale\"in t&&(this.opacityscale=t.opacityscale,this.hasAlpha=!0),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t,e){for(var r=h({colormap:t,nshades:256,format:\"rgba\"}),n=new Uint8Array(1024),i=0;i<256;++i){for(var a=r[i],o=0;o<3;++o)n[4*i+o]=a[o];n[4*i+3]=e?255*A(i/255,e):255*a[3]}return u(n,[256,256,4],[4,0,1])}(t.colormap,this.opacityscale)),this.texture.generateMipmap());var r=t.cells,n=t.positions;if(n&&r){var i=[],a=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[];this.cells=r,this.positions=n;var w=t.vertexNormals,k=t.cellNormals,T=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,M=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!k&&(k=s.faceNormals(r,n,M)),k||w||(w=s.vertexNormals(r,n,T));var S=t.vertexColors,E=t.cellColors,C=t.meshColor||[1,1,1,1],L=t.vertexUVs,P=t.vertexIntensity,O=t.cellUVs,z=t.cellIntensity,I=1/0,D=-1/0;if(!L&&!O)if(P)if(t.vertexIntensityBounds)I=+t.vertexIntensityBounds[0],D=+t.vertexIntensityBounds[1];else for(var R=0;R<P.length;++R){var F=P[R];I=Math.min(I,F),D=Math.max(D,F)}else if(z)for(R=0;R<z.length;++R){F=z[R];I=Math.min(I,F),D=Math.max(D,F)}else for(R=0;R<n.length;++R){F=n[R][2];I=Math.min(I,F),D=Math.max(D,F)}this.intensity=P||(z?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,z):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var B=t.pointSizes,N=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(R=0;R<n.length;++R)for(var j=n[R],U=0;U<3;++U)!isNaN(j[U])&&isFinite(j[U])&&(this.bounds[0][U]=Math.min(this.bounds[0][U],j[U]),this.bounds[1][U]=Math.max(this.bounds[1][U],j[U]));var V=0,q=0,H=0;t:for(R=0;R<r.length;++R){var G=r[R];switch(G.length){case 1:for(j=n[W=G[0]],U=0;U<3;++U)if(isNaN(j[U])||!isFinite(j[U]))continue t;m.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?y.push(X[0],X[1],X[2],this.opacity):(y.push(X[0],X[1],X[2],X[3]*this.opacity),!this.hasAlpha&&X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],x.push(Z[0],Z[1]),B?b.push(B[W]):b.push(N),_.push(R),H+=1;break;case 2:for(U=0;U<2;++U){j=n[W=G[U]];for(var Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t}for(U=0;U<2;++U){j=n[W=G[U]];p.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?d.push(X[0],X[1],X[2],this.opacity):(d.push(X[0],X[1],X[2],X[3]*this.opacity),!this.hasAlpha&&X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],g.push(Z[0],Z[1]),v.push(R)}q+=1;break;case 3:for(U=0;U<3;++U)for(j=n[W=G[U]],Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t;for(U=0;U<3;++U){var W,X,Z,J;j=n[W=G[2-U]];i.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*A((P[W]-I)/(D-I),this.opacityscale)):3===X.length?a.push(X[0],X[1],X[2],this.opacity):(a.push(X[0],X[1],X[2],X[3]*this.opacity),!this.hasAlpha&&X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:P?[(P[W]-I)/(D-I),0]:O?O[R]:z?[(z[R]-I)/(D-I),0]:[(j[2]-I)/(D-I),0],c.push(Z[0],Z[1]),J=w?w[W]:k[R],l.push(J[0],J[1],J[2]),f.push(R)}V+=1}}this.pointCount=H,this.edgeCount=q,this.triangleCount=V,this.pointPositions.update(m),this.pointColors.update(y),this.pointUVs.update(x),this.pointSizes.update(b),this.pointIds.update(new Uint32Array(_)),this.edgePositions.update(p),this.edgeColors.update(d),this.edgeUVs.update(g),this.edgeIds.update(new Uint32Array(v)),this.trianglePositions.update(i),this.triangleColors.update(a),this.triangleUVs.update(c),this.triangleNormals.update(l),this.triangleIds.update(new Uint32Array(f))}},T.drawTransparent=T.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:w.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h,f=u[15];for(o=0;o<3;++o)f+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];s.lightPosition[o]=p/f}this.triangleCount>0&&((h=this.triShader).bind(),h.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind());this.edgeCount>0&&this.lineWidth>0&&((h=this.lineShader).bind(),h.uniforms=s,this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind());this.pointCount>0&&((h=this.pointShader).bind(),h.uniforms=s,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind());this.contourEnable&&this.contourCount>0&&this.contourLineWidth>0&&((h=this.contourShader).bind(),h.uniforms=s,this.contourVAO.bind(),e.drawArrays(e.LINES,0,this.contourCount),this.contourVAO.unbind())},T.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s,l={model:r,view:n,projection:i,clipBounds:a,pickId:this.pickId/255};((s=this.pickShader).bind(),s.uniforms=l,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind()),this.pointCount>0)&&((s=this.pointPickShader).bind(),s.uniforms=l,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind())},T.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;for(var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions,i=new Array(r.length),a=0;a<r.length;++a)i[a]=n[r[a]];var o=g(i,[t.coord[0],this._resolution[1]-t.coord[1]],this._model,this._view,this._projection,this._resolution);if(!o)return null;var s=o[2],l=0;for(a=0;a<r.length;++a)l+=s[a]*this.intensity[r[a]];return{position:o[1],index:r[o[0]],cell:r,cellId:e,intensity:l,dataCoordinate:this.positions[r[o[0]]]}},T.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.lineShader.dispose(),this.pointShader.dispose(),this.pickShader.dispose(),this.pointPickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose(),this.contourShader.dispose()},e.exports=function(t,e){if(1===arguments.length&&(t=(e=t).gl),!(t.getExtension(\"OES_standard_derivatives\")||t.getExtension(\"MOZ_OES_standard_derivatives\")||t.getExtension(\"WEBKIT_OES_standard_derivatives\")))throw new Error(\"derivatives not supported\");var r=function(t){var e=n(t,v.vertex,v.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.normal.location=4,e}(t),s=function(t){var e=n(t,m.vertex,m.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e}(t),l=M(t),c=S(t),h=E(t),f=C(t),p=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));p.generateMipmap(),p.minFilter=t.LINEAR_MIPMAP_LINEAR,p.magFilter=t.LINEAR;var d=i(t),g=i(t),y=i(t),x=i(t),b=i(t),_=a(t,[{buffer:d,type:t.FLOAT,size:3},{buffer:b,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:g,type:t.FLOAT,size:4},{buffer:y,type:t.FLOAT,size:2},{buffer:x,type:t.FLOAT,size:3}]),w=i(t),T=i(t),A=i(t),L=i(t),P=a(t,[{buffer:w,type:t.FLOAT,size:3},{buffer:L,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:T,type:t.FLOAT,size:4},{buffer:A,type:t.FLOAT,size:2}]),O=i(t),z=i(t),I=i(t),D=i(t),R=i(t),F=a(t,[{buffer:O,type:t.FLOAT,size:3},{buffer:R,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:z,type:t.FLOAT,size:4},{buffer:I,type:t.FLOAT,size:2},{buffer:D,type:t.FLOAT,size:1}]),B=i(t),N=new k(t,p,r,s,l,c,h,f,d,b,g,y,x,_,w,L,T,A,P,O,R,z,I,D,F,B,a(t,[{buffer:B,type:t.FLOAT,size:3}]));return N.update(e),N}},{\"./lib/closest-point\":278,\"./lib/shaders\":279,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-shader\":301,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,normals:453,\"simplicial-complex-contour\":518,\"typedarray-pool\":545}],281:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[0,0,0,1,1,0,1,1]),s=i(e,a.boxVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawBox=(s=[0,0],l=[0,0],function(t,e,r,n,i){var a=this.plot,o=this.shader,c=a.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,o.uniforms.lo=s,o.uniforms.hi=l,o.uniforms.color=i,c.drawArrays(c.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":284,\"gl-buffer\":241,\"gl-shader\":301}],282:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,o.gridVert,o.gridFrag),l=i(e,o.tickVert,o.gridFrag);return new s(t,r,a,l)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"binary-search-bounds\"),o=t(\"./shaders\");function s(t,e,r,n){this.plot=t,this.vbo=e,this.shader=r,this.tickShader=n,this.ticks=[[],[]]}function l(t,e){return t-e}var c,u,h,f,p,d=s.prototype;d.draw=(c=[0,0],u=[0,0],h=[0,0],function(){for(var t=this.plot,e=this.vbo,r=this.shader,n=this.ticks,i=t.gl,a=t._tickBounds,o=t.dataBox,s=t.viewBox,l=t.gridLineWidth,f=t.gridLineColor,p=t.gridLineEnable,d=t.pixelRatio,g=0;g<2;++g){var v=a[g],m=a[g+2]-v,y=.5*(o[g+2]+o[g]),x=o[g+2]-o[g];u[g]=2*m/x,c[g]=2*(v-y)/x}r.bind(),e.bind(),r.attributes.dataCoord.pointer(),r.uniforms.dataShift=c,r.uniforms.dataScale=u;var b=0;for(g=0;g<2;++g){h[0]=h[1]=0,h[g]=1,r.uniforms.dataAxis=h,r.uniforms.lineWidth=l[g]/(s[g+2]-s[g])*d,r.uniforms.color=f[g];var _=6*n[g].length;p[g]&&_&&i.drawArrays(i.TRIANGLES,b,_),b+=_}}),d.drawTickMarks=function(){var t=[0,0],e=[0,0],r=[1,0],n=[0,1],i=[0,0],o=[0,0];return function(){for(var s=this.plot,c=this.vbo,u=this.tickShader,h=this.ticks,f=s.gl,p=s._tickBounds,d=s.dataBox,g=s.viewBox,v=s.pixelRatio,m=s.screenBox,y=m[2]-m[0],x=m[3]-m[1],b=g[2]-g[0],_=g[3]-g[1],w=0;w<2;++w){var k=p[w],T=p[w+2]-k,A=.5*(d[w+2]+d[w]),M=d[w+2]-d[w];e[w]=2*T/M,t[w]=2*(k-A)/M}e[0]*=b/y,t[0]*=b/y,e[1]*=_/x,t[1]*=_/x,u.bind(),c.bind(),u.attributes.dataCoord.pointer();var S=u.uniforms;S.dataShift=t,S.dataScale=e;var E=s.tickMarkLength,C=s.tickMarkWidth,L=s.tickMarkColor,P=6*h[0].length,O=Math.min(a.ge(h[0],(d[0]-p[0])/(p[2]-p[0]),l),h[0].length),z=Math.min(a.gt(h[0],(d[2]-p[0])/(p[2]-p[0]),l),h[0].length),I=0+6*O,D=6*Math.max(0,z-O),R=Math.min(a.ge(h[1],(d[1]-p[1])/(p[3]-p[1]),l),h[1].length),F=Math.min(a.gt(h[1],(d[3]-p[1])/(p[3]-p[1]),l),h[1].length),B=P+6*R,N=6*Math.max(0,F-R);i[0]=2*(g[0]-E[1])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=E[1]*v/y,o[1]=C[1]*v/x,N&&(S.color=L[1],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,f.drawArrays(f.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[1]-E[0])/x-1,o[0]=C[0]*v/y,o[1]=E[0]*v/x,D&&(S.color=L[0],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,f.drawArrays(f.TRIANGLES,I,D)),i[0]=2*(g[2]+E[3])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=E[3]*v/y,o[1]=C[3]*v/x,N&&(S.color=L[3],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,f.drawArrays(f.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[3]+E[2])/x-1,o[0]=C[2]*v/y,o[1]=E[2]*v/x,D&&(S.color=L[2],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,f.drawArrays(f.TRIANGLES,I,D))}}(),d.update=(f=[1,1,-1,-1,1,-1],p=[1,-1,1,1,-1,-1],function(t){for(var e=t.ticks,r=t.bounds,n=new Float32Array(18*(e[0].length+e[1].length)),i=(this.plot.zeroLineEnable,0),a=[[],[]],o=0;o<2;++o)for(var s=a[o],l=e[o],c=r[o],u=r[o+2],h=0;h<l.length;++h){var d=(l[h].x-c)/(u-c);s.push(d);for(var g=0;g<6;++g)n[i++]=d,n[i++]=f[g],n[i++]=p[g]}this.ticks=a,this.vbo.update(n)}),d.dispose=function(){this.vbo.dispose(),this.shader.dispose(),this.tickShader.dispose()}},{\"./shaders\":284,\"binary-search-bounds\":286,\"gl-buffer\":241,\"gl-shader\":301}],283:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[-1,-1,-1,1,1,-1,1,1]),s=i(e,a.lineVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawLine=(s=[0,0],l=[0,0],function(t,e,r,n,i,a){var o=this.plot,c=this.shader,u=o.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,c.uniforms.start=s,c.uniforms.end=l,c.uniforms.width=i*o.pixelRatio,c.uniforms.color=a,u.drawArrays(u.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":284,\"gl-buffer\":241,\"gl-shader\":301}],284:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision lowp float;\\n#define GLSLIFY 1\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = vec4(color.xyz * color.w, color.w);\\n}\\n\"]);e.exports={lineVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 start, end;\\nuniform float width;\\n\\nvec2 perp(vec2 v) {\\n  return vec2(v.y, -v.x);\\n}\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  vec2 delta = normalize(perp(start - end));\\n  vec2 offset = mix(start, end, 0.5 * (coord.y+1.0));\\n  gl_Position = vec4(screen(offset + 0.5 * width * delta * coord.x), 0, 1);\\n}\\n\"]),lineFrag:i,textVert:n([\"#define GLSLIFY 1\\nattribute vec3 textCoordinate;\\n\\nuniform vec2 dataScale, dataShift, dataAxis, screenOffset, textScale;\\nuniform float angle;\\n\\nvoid main() {\\n  float dataOffset  = textCoordinate.z;\\n  vec2 glyphOffset  = textCoordinate.xy;\\n  mat2 glyphMatrix = mat2(cos(angle), sin(angle), -sin(angle), cos(angle));\\n  vec2 screenCoordinate = dataAxis * (dataScale * dataOffset + dataShift) +\\n    glyphMatrix * glyphOffset * textScale + screenOffset;\\n  gl_Position = vec4(screenCoordinate, 0, 1);\\n}\\n\"]),textFrag:i,gridVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale;\\nuniform float lineWidth;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  pos += 10.0 * dataCoord.y * vec2(dataAxis.y, -dataAxis.x) + dataCoord.z * lineWidth;\\n  gl_Position = vec4(pos, 0, 1);\\n}\\n\"]),gridFrag:i,boxVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 lo, hi;\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  gl_Position = vec4(screen(mix(lo, hi, coord)), 0, 1);\\n}\\n\"]),tickVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale, screenOffset, tickScale;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  gl_Position = vec4(pos + tickScale*dataCoord.yz + screenOffset, 0, 1);\\n}\\n\"])}},{glslify:409}],285:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,s.textVert,s.textFrag);return new l(t,r,a)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"text-cache\"),o=t(\"binary-search-bounds\"),s=t(\"./shaders\");function l(t,e,r){this.plot=t,this.vbo=e,this.shader=r,this.tickOffset=[[],[]],this.tickX=[[],[]],this.labelOffset=[0,0],this.labelCount=[0,0]}var c,u,h,f,p,d,g=l.prototype;g.drawTicks=(c=[0,0],u=[0,0],h=[0,0],function(t){var e=this.plot,r=this.shader,n=this.tickX[t],i=this.tickOffset[t],a=e.gl,s=e.viewBox,l=e.dataBox,f=e.screenBox,p=e.pixelRatio,d=e.tickEnable,g=e.tickPad,v=e.tickColor,m=e.tickAngle,y=e.labelEnable,x=e.labelPad,b=e.labelColor,_=e.labelAngle,w=this.labelOffset[t],k=this.labelCount[t],T=o.lt(n,l[t]),A=o.le(n,l[t+2]);c[0]=c[1]=0,c[t]=1,u[t]=(s[2+t]+s[t])/(f[2+t]-f[t])-1;var M=2/f[2+(1^t)]-f[1^t];u[1^t]=M*s[1^t]-1,d[t]&&(u[1^t]-=M*p*g[t],T<A&&i[A]>i[T]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=v[t],r.uniforms.angle=m[t],a.drawArrays(a.TRIANGLES,i[T],i[A]-i[T]))),y[t]&&k&&(u[1^t]-=M*p*x[t],r.uniforms.dataAxis=h,r.uniforms.screenOffset=u,r.uniforms.color=b[t],r.uniforms.angle=_[t],a.drawArrays(a.TRIANGLES,w,k)),u[1^t]=M*s[2+(1^t)]-1,d[t+2]&&(u[1^t]+=M*p*g[t+2],T<A&&i[A]>i[T]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=v[t+2],r.uniforms.angle=m[t+2],a.drawArrays(a.TRIANGLES,i[T],i[A]-i[T]))),y[t+2]&&k&&(u[1^t]+=M*p*x[t+2],r.uniforms.dataAxis=h,r.uniforms.screenOffset=u,r.uniforms.color=b[t+2],r.uniforms.angle=_[t+2],a.drawArrays(a.TRIANGLES,w,k))}),g.drawTitle=function(){var t=[0,0],e=[0,0];return function(){var r=this.plot,n=this.shader,i=r.gl,a=r.screenBox,o=r.titleCenter,s=r.titleAngle,l=r.titleColor,c=r.pixelRatio;if(this.titleCount){for(var u=0;u<2;++u)e[u]=2*(o[u]*c-a[u])/(a[2+u]-a[u])-1;n.bind(),n.uniforms.dataAxis=t,n.uniforms.screenOffset=e,n.uniforms.angle=s,n.uniforms.color=l,i.drawArrays(i.TRIANGLES,this.titleOffset,this.titleCount)}}}(),g.bind=(f=[0,0],p=[0,0],d=[0,0],function(){var t=this.plot,e=this.shader,r=t._tickBounds,n=t.dataBox,i=t.screenBox,a=t.viewBox;e.bind();for(var o=0;o<2;++o){var s=r[o],l=r[o+2]-s,c=.5*(n[o+2]+n[o]),u=n[o+2]-n[o],h=a[o],g=a[o+2]-h,v=i[o],m=i[o+2]-v;p[o]=2*l/u*g/m,f[o]=2*(s-c)/u*g/m}d[1]=2*t.pixelRatio/(i[3]-i[1]),d[0]=d[1]*(i[3]-i[1])/(i[2]-i[0]),e.uniforms.dataScale=p,e.uniforms.dataShift=f,e.uniforms.textScale=d,this.vbo.bind(),e.attributes.textCoordinate.pointer()}),g.update=function(t){var e,r,n,i,o,s=[],l=t.ticks,c=t.bounds;for(o=0;o<2;++o){var u=[Math.floor(s.length/3)],h=[-1/0],f=l[o];for(e=0;e<f.length;++e){var p=f[e],d=p.x,g=p.text,v=p.font||\"sans-serif\";i=p.fontSize||12;for(var m=1/(c[o+2]-c[o]),y=c[o],x=g.split(\"\\n\"),b=0;b<x.length;b++)for(n=a(v,x[b]).data,r=0;r<n.length;r+=2)s.push(n[r]*i,-n[r+1]*i-b*i*1.2,(d-y)*m);u.push(Math.floor(s.length/3)),h.push(d)}this.tickOffset[o]=u,this.tickX[o]=h}for(o=0;o<2;++o){for(this.labelOffset[o]=Math.floor(s.length/3),n=a(t.labelFont[o],t.labels[o],{textAlign:\"center\"}).data,i=t.labelSize[o],e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.labelCount[o]=Math.floor(s.length/3)-this.labelOffset[o]}for(this.titleOffset=Math.floor(s.length/3),n=a(t.titleFont,t.title).data,i=t.titleSize,e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.titleCount=Math.floor(s.length/3)-this.titleOffset,this.vbo.update(s)},g.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":284,\"binary-search-bounds\":286,\"gl-buffer\":241,\"gl-shader\":301,\"text-cache\":536}],286:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],287:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[e.drawingBufferWidth,e.drawingBufferHeight]),c=new l(e,r);return c.grid=i(c),c.text=a(c),c.line=o(c),c.box=s(c),c.update(t),c};var n=t(\"gl-select-static\"),i=t(\"./lib/grid\"),a=t(\"./lib/text\"),o=t(\"./lib/line\"),s=t(\"./lib/box\");function l(t,e){this.gl=t,this.pickBuffer=e,this.screenBox=[0,0,t.drawingBufferWidth,t.drawingBufferHeight],this.viewBox=[0,0,0,0],this.dataBox=[-10,-10,10,10],this.gridLineEnable=[!0,!0],this.gridLineWidth=[1,1],this.gridLineColor=[[0,0,0,1],[0,0,0,1]],this.pixelRatio=1,this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickEnable=[!0,!0,!0,!0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[15,15,15,15],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelEnable=[!0,!0,!0,!0],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.titleCenter=[0,0],this.titleEnable=!0,this.titleAngle=0,this.titleColor=[0,0,0,1],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[4,4],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderLineEnable=[!0,!0,!0,!0],this.borderLineWidth=[2,2,2,2],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.grid=null,this.text=null,this.line=null,this.box=null,this.objects=[],this.overlays=[],this._tickBounds=[1/0,1/0,-1/0,-1/0],this.static=!1,this.dirty=!1,this.pickDirty=!1,this.pickDelay=120,this.pickRadius=10,this._pickTimeout=null,this._drawPick=this.drawPick.bind(this),this._depthCounter=0}var c=l.prototype;function u(t){for(var e=t.slice(),r=0;r<e.length;++r)e[r]=e[r].slice();return e}function h(t,e){return t.x-e.x}c.setDirty=function(){this.dirty=this.pickDirty=!0},c.setOverlayDirty=function(){this.dirty=!0},c.nextDepthValue=function(){return this._depthCounter++/65536},c.draw=function(){var t=this.gl,e=this.screenBox,r=this.viewBox,n=this.dataBox,i=this.pixelRatio,a=this.grid,o=this.line,s=this.text,l=this.objects;if(this._depthCounter=0,this.pickDirty&&(this._pickTimeout&&clearTimeout(this._pickTimeout),this.pickDirty=!1,this._pickTimeout=setTimeout(this._drawPick,this.pickDelay)),this.dirty){if(this.dirty=!1,t.bindFramebuffer(t.FRAMEBUFFER,null),t.enable(t.SCISSOR_TEST),t.disable(t.DEPTH_TEST),t.depthFunc(t.LESS),t.depthMask(!1),t.enable(t.BLEND),t.blendEquation(t.FUNC_ADD,t.FUNC_ADD),t.blendFunc(t.ONE,t.ONE_MINUS_SRC_ALPHA),this.borderColor){t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]);var c=this.borderColor;t.clearColor(c[0]*c[3],c[1]*c[3],c[2]*c[3],c[3]),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT)}t.scissor(r[0],r[1],r[2]-r[0],r[3]-r[1]),t.viewport(r[0],r[1],r[2]-r[0],r[3]-r[1]);var u=this.backgroundColor;t.clearColor(u[0]*u[3],u[1]*u[3],u[2]*u[3],u[3]),t.clear(t.COLOR_BUFFER_BIT),a.draw();var h=this.zeroLineEnable,f=this.zeroLineColor,p=this.zeroLineWidth;if(h[0]||h[1]){o.bind();for(var d=0;d<2;++d)if(h[d]&&n[d]<=0&&n[d+2]>=0){var g=e[d]-n[d]*(e[d+2]-e[d])/(n[d+2]-n[d]);0===d?o.drawLine(g,e[1],g,e[3],p[d],f[d]):o.drawLine(e[0],g,e[2],g,p[d],f[d])}}for(d=0;d<l.length;++d)l[d].draw();t.viewport(e[0],e[1],e[2]-e[0],e[3]-e[1]),t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]),this.grid.drawTickMarks(),o.bind();var v=this.borderLineEnable,m=this.borderLineWidth,y=this.borderLineColor;for(v[1]&&o.drawLine(r[0],r[1]-.5*m[1]*i,r[0],r[3]+.5*m[3]*i,m[1],y[1]),v[0]&&o.drawLine(r[0]-.5*m[0]*i,r[1],r[2]+.5*m[2]*i,r[1],m[0],y[0]),v[3]&&o.drawLine(r[2],r[1]-.5*m[1]*i,r[2],r[3]+.5*m[3]*i,m[3],y[3]),v[2]&&o.drawLine(r[0]-.5*m[0]*i,r[3],r[2]+.5*m[2]*i,r[3],m[2],y[2]),s.bind(),d=0;d<2;++d)s.drawTicks(d);this.titleEnable&&s.drawTitle();var x=this.overlays;for(d=0;d<x.length;++d)x[d].draw();t.disable(t.SCISSOR_TEST),t.disable(t.BLEND),t.depthMask(!0)}},c.drawPick=function(){if(!this.static){var t=this.pickBuffer;this.gl;this._pickTimeout=null,t.begin();for(var e=1,r=this.objects,n=0;n<r.length;++n)e=r[n].drawPick(e);t.end()}},c.pick=function(t,e){if(!this.static){var r=this.pixelRatio,n=this.pickPixelRatio,i=this.viewBox,a=0|Math.round((t-i[0]/r)*n),o=0|Math.round((e-i[1]/r)*n),s=this.pickBuffer.query(a,o,this.pickRadius);if(!s)return null;for(var l=s.id+(s.value[0]<<8)+(s.value[1]<<16)+(s.value[2]<<24),c=this.objects,u=0;u<c.length;++u){var h=c[u].pick(a,o,l);if(h)return h}return null}},c.setScreenBox=function(t){var e=this.screenBox,r=this.pixelRatio;e[0]=0|Math.round(t[0]*r),e[1]=0|Math.round(t[1]*r),e[2]=0|Math.round(t[2]*r),e[3]=0|Math.round(t[3]*r),this.setDirty()},c.setDataBox=function(t){var e=this.dataBox;(e[0]!==t[0]||e[1]!==t[1]||e[2]!==t[2]||e[3]!==t[3])&&(e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],this.setDirty())},c.setViewBox=function(t){var e=this.pixelRatio,r=this.viewBox;r[0]=0|Math.round(t[0]*e),r[1]=0|Math.round(t[1]*e),r[2]=0|Math.round(t[2]*e),r[3]=0|Math.round(t[3]*e);var n=this.pickPixelRatio;this.pickBuffer.shape=[0|Math.round((t[2]-t[0])*n),0|Math.round((t[3]-t[1])*n)],this.setDirty()},c.update=function(t){t=t||{};var e=this.gl;this.pixelRatio=t.pixelRatio||1;var r=this.pixelRatio;this.pickPixelRatio=Math.max(r,1),this.setScreenBox(t.screenBox||[0,0,e.drawingBufferWidth/r,e.drawingBufferHeight/r]);this.screenBox;this.setViewBox(t.viewBox||[.125*(this.screenBox[2]-this.screenBox[0])/r,.125*(this.screenBox[3]-this.screenBox[1])/r,.875*(this.screenBox[2]-this.screenBox[0])/r,.875*(this.screenBox[3]-this.screenBox[1])/r]);var n=this.viewBox,i=(n[2]-n[0])/(n[3]-n[1]);this.setDataBox(t.dataBox||[-10,-10/i,10,10/i]),this.borderColor=!1!==t.borderColor&&(t.borderColor||[0,0,0,0]).slice(),this.backgroundColor=(t.backgroundColor||[0,0,0,0]).slice(),this.gridLineEnable=(t.gridLineEnable||[!0,!0]).slice(),this.gridLineWidth=(t.gridLineWidth||[1,1]).slice(),this.gridLineColor=u(t.gridLineColor||[[.5,.5,.5,1],[.5,.5,.5,1]]),this.zeroLineEnable=(t.zeroLineEnable||[!0,!0]).slice(),this.zeroLineWidth=(t.zeroLineWidth||[4,4]).slice(),this.zeroLineColor=u(t.zeroLineColor||[[0,0,0,1],[0,0,0,1]]),this.tickMarkLength=(t.tickMarkLength||[0,0,0,0]).slice(),this.tickMarkWidth=(t.tickMarkWidth||[0,0,0,0]).slice(),this.tickMarkColor=u(t.tickMarkColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.titleCenter=(t.titleCenter||[.5*(n[0]+n[2])/r,(n[3]+120)/r]).slice(),this.titleEnable=!(\"titleEnable\"in t&&!t.titleEnable),this.titleAngle=t.titleAngle||0,this.titleColor=(t.titleColor||[0,0,0,1]).slice(),this.labelPad=(t.labelPad||[15,15,15,15]).slice(),this.labelAngle=(t.labelAngle||[0,Math.PI/2,0,3*Math.PI/2]).slice(),this.labelEnable=(t.labelEnable||[!0,!0,!0,!0]).slice(),this.labelColor=u(t.labelColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.tickPad=(t.tickPad||[15,15,15,15]).slice(),this.tickAngle=(t.tickAngle||[0,0,0,0]).slice(),this.tickEnable=(t.tickEnable||[!0,!0,!0,!0]).slice(),this.tickColor=u(t.tickColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.borderLineEnable=(t.borderLineEnable||[!0,!0,!0,!0]).slice(),this.borderLineWidth=(t.borderLineWidth||[2,2,2,2]).slice(),this.borderLineColor=u(t.borderLineColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]);var a=t.ticks||[[],[]],o=this._tickBounds;o[0]=o[1]=1/0,o[2]=o[3]=-1/0;for(var s=0;s<2;++s){var l=a[s].slice(0);0!==l.length&&(l.sort(h),o[s]=Math.min(o[s],l[0].x),o[s+2]=Math.max(o[s+2],l[l.length-1].x))}this.grid.update({bounds:o,ticks:a}),this.text.update({bounds:o,ticks:a,labels:t.labels||[\"x\",\"y\"],labelSize:t.labelSize||[12,12],labelFont:t.labelFont||[\"sans-serif\",\"sans-serif\"],title:t.title||\"\",titleSize:t.titleSize||18,titleFont:t.titleFont||\"sans-serif\"}),this.static=!!t.static,this.setDirty()},c.dispose=function(){this.box.dispose(),this.grid.dispose(),this.text.dispose(),this.line.dispose();for(var t=this.objects.length-1;t>=0;--t)this.objects[t].dispose();this.objects.length=0;for(t=this.overlays.length-1;t>=0;--t)this.overlays[t].dispose();this.overlays.length=0,this.gl=null},c.addObject=function(t){this.objects.indexOf(t)<0&&(this.objects.push(t),this.setDirty())},c.removeObject=function(t){for(var e=this.objects,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setDirty();break}},c.addOverlay=function(t){this.overlays.indexOf(t)<0&&(this.overlays.push(t),this.setOverlayDirty())},c.removeOverlay=function(t){for(var e=this.overlays,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setOverlayDirty();break}}},{\"./lib/box\":281,\"./lib/grid\":282,\"./lib/line\":283,\"./lib/text\":285,\"gl-select-static\":300}],288:[function(t,e,r){\"use strict\";e.exports=function(t,e){t=t||document.body,e=e||{};var r=[.01,1/0];\"distanceLimits\"in e&&(r[0]=e.distanceLimits[0],r[1]=e.distanceLimits[1]);\"zoomMin\"in e&&(r[0]=e.zoomMin);\"zoomMax\"in e&&(r[1]=e.zoomMax);var c=i({center:e.center||[0,0,0],up:e.up||[0,1,0],eye:e.eye||[0,0,10],mode:e.mode||\"orbit\",distanceLimits:r}),u=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],h=0,f=t.clientWidth,p=t.clientHeight,d={keyBindingMode:\"rotate\",enableWheel:!0,view:c,element:t,delay:e.delay||16,rotateSpeed:e.rotateSpeed||1,zoomSpeed:e.zoomSpeed||1,translateSpeed:e.translateSpeed||1,flipX:!!e.flipX,flipY:!!e.flipY,modes:c.modes,_ortho:e._ortho||e.projection&&\"orthographic\"===e.projection.type||!1,tick:function(){var e=n(),r=this.delay,i=e-2*r;c.idle(e-r),c.recalcMatrix(i),c.flush(e-(100+2*r));for(var a=!0,o=c.computedMatrix,s=0;s<16;++s)a=a&&u[s]===o[s],u[s]=o[s];var l=t.clientWidth===f&&t.clientHeight===p;return f=t.clientWidth,p=t.clientHeight,a?!l:(h=Math.exp(c.computedRadius[0]),!0)},lookAt:function(t,e,r){c.lookAt(c.lastT(),t,e,r)},rotate:function(t,e,r){c.rotate(c.lastT(),t,e,r)},pan:function(t,e,r){c.pan(c.lastT(),t,e,r)},translate:function(t,e,r){c.translate(c.lastT(),t,e,r)}};return Object.defineProperties(d,{matrix:{get:function(){return c.computedMatrix},set:function(t){return c.setMatrix(c.lastT(),t),c.computedMatrix},enumerable:!0},mode:{get:function(){return c.getMode()},set:function(t){var e=c.computedUp.slice(),r=c.computedEye.slice(),i=c.computedCenter.slice();if(c.setMode(t),\"turntable\"===t){var a=n();c._active.lookAt(a,r,i,e),c._active.lookAt(a+500,r,i,[0,0,1]),c._active.flush(a)}return c.getMode()},enumerable:!0},center:{get:function(){return c.computedCenter},set:function(t){return c.lookAt(c.lastT(),null,t),c.computedCenter},enumerable:!0},eye:{get:function(){return c.computedEye},set:function(t){return c.lookAt(c.lastT(),t),c.computedEye},enumerable:!0},up:{get:function(){return c.computedUp},set:function(t){return c.lookAt(c.lastT(),null,null,t),c.computedUp},enumerable:!0},distance:{get:function(){return h},set:function(t){return c.setDistance(c.lastT(),t),t},enumerable:!0},distanceLimits:{get:function(){return c.getDistanceLimits(r)},set:function(t){return c.setDistanceLimits(t),t},enumerable:!0}}),t.addEventListener(\"contextmenu\",function(t){return t.preventDefault(),!1}),d._lastX=-1,d._lastY=-1,d._lastMods={shift:!1,control:!1,alt:!1,meta:!1},d.enableMouseListeners=function(){function e(e,r,i,a){var o=d.keyBindingMode;if(!1!==o){var s=\"rotate\"===o,l=\"pan\"===o,u=\"zoom\"===o,f=!!a.control,p=!!a.alt,g=!!a.shift,v=!!(1&e),m=!!(2&e),y=!!(4&e),x=1/t.clientHeight,b=x*(r-d._lastX),_=x*(i-d._lastY),w=d.flipX?1:-1,k=d.flipY?1:-1,T=Math.PI*d.rotateSpeed,A=n();if(-1!==d._lastX&&-1!==d._lastY&&((s&&v&&!f&&!p&&!g||v&&!f&&!p&&g)&&c.rotate(A,w*T*b,-k*T*_,0),(l&&v&&!f&&!p&&!g||m||v&&f&&!p&&!g)&&c.pan(A,-d.translateSpeed*b*h,d.translateSpeed*_*h,0),u&&v&&!f&&!p&&!g||y||v&&!f&&p&&!g)){var M=-d.zoomSpeed*_/window.innerHeight*(A-c.lastT())*100;c.pan(A,0,0,h*(Math.exp(M)-1))}return d._lastX=r,d._lastY=i,d._lastMods=a,!0}}d.mouseListener=a(t,e),t.addEventListener(\"touchstart\",function(r){var n=s(r.changedTouches[0],t);e(0,n[0],n[1],d._lastMods),e(1,n[0],n[1],d._lastMods),r.preventDefault()},!!l&&{passive:!1}),t.addEventListener(\"touchmove\",function(r){var n=s(r.changedTouches[0],t);e(1,n[0],n[1],d._lastMods),r.preventDefault()},!!l&&{passive:!1}),t.addEventListener(\"touchend\",function(t){e(0,d._lastX,d._lastY,d._lastMods),t.preventDefault()},!!l&&{passive:!1}),d.wheelListener=o(t,function(t,e){if(!1!==d.keyBindingMode&&d.enableWheel){var r=d.flipX?1:-1,i=d.flipY?1:-1,a=n();if(Math.abs(t)>Math.abs(e))c.rotate(a,0,0,-t*r*Math.PI*d.rotateSpeed/window.innerWidth);else if(!d._ortho){var o=-d.zoomSpeed*i*e/window.innerHeight*(a-c.lastT())/20;c.pan(a,0,0,h*(Math.exp(o)-1))}}},!0)},d.enableMouseListeners(),d};var n=t(\"right-now\"),i=t(\"3d-view\"),a=t(\"mouse-change\"),o=t(\"mouse-wheel\"),s=t(\"mouse-event-offset\"),l=t(\"has-passive-events\")},{\"3d-view\":52,\"has-passive-events\":411,\"mouse-change\":435,\"mouse-event-offset\":436,\"mouse-wheel\":438,\"right-now\":504}],289:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\nattribute vec2 position;\\nvarying vec2 uv;\\nvoid main() {\\n  uv = position;\\n  gl_Position = vec4(position, 0, 1);\\n}\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D accumBuffer;\\nvarying vec2 uv;\\n\\nvoid main() {\\n  vec4 accum = texture2D(accumBuffer, 0.5 * (uv + 1.0));\\n  gl_FragColor = min(vec4(1,1,1,1), accum);\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec2\"}])}},{\"gl-shader\":301,glslify:409}],290:[function(t,e,r){\"use strict\";var n=t(\"./camera.js\"),i=t(\"gl-axes3d\"),a=t(\"gl-axes3d/properties\"),o=t(\"gl-spikes3d\"),s=t(\"gl-select-static\"),l=t(\"gl-fbo\"),c=t(\"a-big-triangle\"),u=t(\"mouse-change\"),h=t(\"mouse-wheel\"),f=t(\"gl-mat4/perspective\"),p=t(\"gl-mat4/ortho\"),d=t(\"./lib/shader\"),g=t(\"is-mobile\")({tablet:!0});function v(){this.mouse=[-1,-1],this.screen=null,this.distance=1/0,this.index=null,this.dataCoordinate=null,this.dataPosition=null,this.object=null,this.data=null}function m(t){var e=Math.round(Math.log(Math.abs(t))/Math.log(10));if(e<0){var r=Math.round(Math.pow(10,-e));return Math.ceil(t*r)/r}if(e>0){r=Math.round(Math.pow(10,e));return Math.ceil(t/r)*r}return Math.ceil(t)}function y(t){return\"boolean\"!=typeof t||t}e.exports={createScene:function(t){(t=t||{}).camera=t.camera||{};var e=t.canvas;if(!e)if(e=document.createElement(\"canvas\"),t.container){var r=t.container;r.appendChild(e)}else document.body.appendChild(e);var x=t.gl;x||(x=function(t,e){var r=null;try{(r=t.getContext(\"webgl\",e))||(r=t.getContext(\"experimental-webgl\",e))}catch(t){return null}return r}(e,t.glOptions||{premultipliedAlpha:!0,antialias:!0,preserveDrawingBuffer:g}));if(!x)throw new Error(\"webgl not supported\");var b=t.bounds||[[-10,-10,-10],[10,10,10]],_=new v,w=l(x,[x.drawingBufferWidth,x.drawingBufferHeight],{preferFloat:!g}),k=d(x),T=t.cameraObject&&!0===t.cameraObject._ortho||t.camera.projection&&\"orthographic\"===t.camera.projection.type||!1,A={eye:t.camera.eye||[2,0,0],center:t.camera.center||[0,0,0],up:t.camera.up||[0,1,0],zoomMin:t.camera.zoomMax||.1,zoomMax:t.camera.zoomMin||100,mode:t.camera.mode||\"turntable\",_ortho:T},M=t.axes||{},S=i(x,M);S.enable=!M.disable;var E=t.spikes||{},C=o(x,E),L=[],P=[],O=[],z=[],I=!0,D=!0,R=new Array(16),F=new Array(16),B={view:null,projection:R,model:F,_ortho:!1},D=!0,N=[x.drawingBufferWidth,x.drawingBufferHeight],j=t.cameraObject||n(e,A),U={gl:x,contextLost:!1,pixelRatio:t.pixelRatio||1,canvas:e,selection:_,camera:j,axes:S,axesPixels:null,spikes:C,bounds:b,objects:L,shape:N,aspect:t.aspectRatio||[1,1,1],pickRadius:t.pickRadius||10,zNear:t.zNear||.01,zFar:t.zFar||1e3,fovy:t.fovy||Math.PI/4,clearColor:t.clearColor||[0,0,0,0],autoResize:y(t.autoResize),autoBounds:y(t.autoBounds),autoScale:!!t.autoScale,autoCenter:y(t.autoCenter),clipToBounds:y(t.clipToBounds),snapToData:!!t.snapToData,onselect:t.onselect||null,onrender:t.onrender||null,onclick:t.onclick||null,cameraParams:B,oncontextloss:null,mouseListener:null,_stopped:!1},V=[x.drawingBufferWidth/U.pixelRatio|0,x.drawingBufferHeight/U.pixelRatio|0];function q(){if(!U._stopped&&U.autoResize){var t=e.parentNode,r=1,n=1;t&&t!==document.body?(r=t.clientWidth,n=t.clientHeight):(r=window.innerWidth,n=window.innerHeight);var i=0|Math.ceil(r*U.pixelRatio),a=0|Math.ceil(n*U.pixelRatio);if(i!==e.width||a!==e.height){e.width=i,e.height=a;var o=e.style;o.position=o.position||\"absolute\",o.left=\"0px\",o.top=\"0px\",o.width=r+\"px\",o.height=n+\"px\",I=!0}}}U.autoResize&&q();function H(){for(var t=L.length,e=z.length,r=0;r<e;++r)O[r]=0;t:for(var r=0;r<t;++r){var n=L[r],i=n.pickSlots;if(i){for(var a=0;a<e;++a)if(O[a]+i<255){P[r]=a,n.setPickBase(O[a]+1),O[a]+=i;continue t}var o=s(x,N);P[r]=e,z.push(o),O.push(i),n.setPickBase(1),e+=1}else P[r]=-1}for(;e>0&&0===O[e-1];)O.pop(),z.pop().dispose()}function G(){if(U.contextLost)return!0;x.isContextLost()&&(U.contextLost=!0,U.mouseListener.enabled=!1,U.selection.object=null,U.oncontextloss&&U.oncontextloss())}window.addEventListener(\"resize\",q),U.update=function(t){U._stopped||(t=t||{},I=!0,D=!0)},U.add=function(t){U._stopped||(t.axes=S,L.push(t),P.push(-1),I=!0,D=!0,H())},U.remove=function(t){if(!U._stopped){var e=L.indexOf(t);e<0||(L.splice(e,1),P.pop(),I=!0,D=!0,H())}},U.dispose=function(){if(!U._stopped&&(U._stopped=!0,window.removeEventListener(\"resize\",q),e.removeEventListener(\"webglcontextlost\",G),U.mouseListener.enabled=!1,!U.contextLost)){S.dispose(),C.dispose();for(var t=0;t<L.length;++t)L[t].dispose();w.dispose();for(var t=0;t<z.length;++t)z[t].dispose();k.dispose(),x=null,S=null,C=null,L=[]}},U.wheelListener=h(e,function(t,e){if(!1!==j.keyBindingMode&&j.enableWheel&&j._ortho){var r=t>e?1.1:1/1.1;U.aspect[0]*=r,U.aspect[1]*=r,U.aspect[2]*=r,U.redraw()}},!0),U._mouseRotating=!1,U._prevButtons=0,U.enableMouseListeners=function(){U.mouseListener=u(e,function(t,e,r){if(!U._stopped){var n=z.length,i=L.length,a=_.object;_.distance=1/0,_.mouse[0]=e,_.mouse[1]=r,_.object=null,_.screen=null,_.dataCoordinate=_.dataPosition=null;var o=!1;if(t&&U._prevButtons)U._mouseRotating=!0;else{U._mouseRotating&&(D=!0),U._mouseRotating=!1;for(var s=0;s<n;++s){var l=z[s].query(e,V[1]-r-1,U.pickRadius);if(l){if(l.distance>_.distance)continue;for(var c=0;c<i;++c){var u=L[c];if(P[c]===s){var h=u.pick(l);h&&(_.buttons=t,_.screen=l.coord,_.distance=l.distance,_.object=u,_.index=h.distance,_.dataPosition=h.position,_.dataCoordinate=h.dataCoordinate,_.data=h,o=!0)}}}}}a&&a!==_.object&&(a.highlight&&a.highlight(null),I=!0),_.object&&(_.object.highlight&&_.object.highlight(_.data),I=!0),(o=o||_.object!==a)&&U.onselect&&U.onselect(_),1&t&&!(1&U._prevButtons)&&U.onclick&&U.onclick(_),U._prevButtons=t}})},e.addEventListener(\"webglcontextlost\",G);var Y=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],W=[Y[0].slice(),Y[1].slice()];function X(){if(!G()){q();var t=U.camera.tick();B.view=U.camera.matrix,I=I||t,D=D||t,S.pixelRatio=U.pixelRatio,C.pixelRatio=U.pixelRatio;var e=L.length,r=Y[0],n=Y[1];r[0]=r[1]=r[2]=1/0,n[0]=n[1]=n[2]=-1/0;for(var i=0;i<e;++i){var o=L[i];o.pixelRatio=U.pixelRatio,o.axes=U.axes,I=I||!!o.dirty,D=D||!!o.dirty;var s=o.bounds;if(s)for(var l=s[0],u=s[1],h=0;h<3;++h)r[h]=Math.min(r[h],l[h]),n[h]=Math.max(n[h],u[h])}var d=U.bounds;if(U.autoBounds)for(var h=0;h<3;++h){if(n[h]<r[h])r[h]=-1,n[h]=1;else{r[h]===n[h]&&(r[h]-=1,n[h]+=1);var g=.05*(n[h]-r[h]);r[h]=r[h]-g,n[h]=n[h]+g}d[0][h]=r[h],d[1][h]=n[h]}for(var v=!1,h=0;h<3;++h)v=v||W[0][h]!==d[0][h]||W[1][h]!==d[1][h],W[0][h]=d[0][h],W[1][h]=d[1][h];if(D=D||v,I=I||v){if(v){for(var y=[0,0,0],i=0;i<3;++i)y[i]=m((d[1][i]-d[0][i])/10);S.autoTicks?S.update({bounds:d,tickSpacing:y}):S.update({bounds:d})}var b=x.drawingBufferWidth,A=x.drawingBufferHeight;N[0]=b,N[1]=A,V[0]=0|Math.max(b/U.pixelRatio,1),V[1]=0|Math.max(A/U.pixelRatio,1),T?(p(R,-b/A,b/A,-1,1,U.zNear,U.zFar),B._ortho=!0):(f(R,U.fovy,b/A,U.zNear,U.zFar),B._ortho=!1);for(var i=0;i<16;++i)F[i]=0;F[15]=1;for(var M=0,i=0;i<3;++i)M=Math.max(M,d[1][i]-d[0][i]);for(var i=0;i<3;++i)U.autoScale?F[5*i]=U.aspect[i]/(d[1][i]-d[0][i]):F[5*i]=1/M,U.autoCenter&&(F[12+i]=.5*-F[5*i]*(d[0][i]+d[1][i]));for(var i=0;i<e;++i){var o=L[i];o.axesBounds=d,U.clipToBounds&&(o.clipBounds=d)}_.object&&(U.snapToData?C.position=_.dataCoordinate:C.position=_.dataPosition,C.bounds=d),D&&(D=!1,function(){if(G())return;x.colorMask(!0,!0,!0,!0),x.depthMask(!0),x.disable(x.BLEND),x.enable(x.DEPTH_TEST);for(var t=L.length,e=z.length,r=0;r<e;++r){var n=z[r];n.shape=V,n.begin();for(var i=0;i<t;++i)if(P[i]===r){var a=L[i];a.drawPick&&(a.pixelRatio=1,a.drawPick(B))}n.end()}}()),U.axesPixels=a(U.axes,B,b,A),U.onrender&&U.onrender(),x.bindFramebuffer(x.FRAMEBUFFER,null),x.viewport(0,0,b,A);var E=U.clearColor;x.clearColor(E[0],E[1],E[2],E[3]),x.clear(x.COLOR_BUFFER_BIT|x.DEPTH_BUFFER_BIT),x.depthMask(!0),x.colorMask(!0,!0,!0,!0),x.enable(x.DEPTH_TEST),x.depthFunc(x.LEQUAL),x.disable(x.BLEND),x.disable(x.CULL_FACE);var O=!1;S.enable&&(O=O||S.isTransparent(),S.draw(B)),C.axes=S,_.object&&C.draw(B),x.disable(x.CULL_FACE);for(var i=0;i<e;++i){var o=L[i];o.axes=S,o.pixelRatio=U.pixelRatio,o.isOpaque&&o.isOpaque()&&o.draw(B),o.isTransparent&&o.isTransparent()&&(O=!0)}if(O){w.shape=N,w.bind(),x.clear(x.DEPTH_BUFFER_BIT),x.colorMask(!1,!1,!1,!1),x.depthMask(!0),x.depthFunc(x.LESS),S.enable&&S.isTransparent()&&S.drawTransparent(B);for(var i=0;i<e;++i){var o=L[i];o.isOpaque&&o.isOpaque()&&o.draw(B)}x.enable(x.BLEND),x.blendEquation(x.FUNC_ADD),x.blendFunc(x.ONE,x.ONE_MINUS_SRC_ALPHA),x.colorMask(!0,!0,!0,!0),x.depthMask(!1),x.clearColor(0,0,0,0),x.clear(x.COLOR_BUFFER_BIT),S.isTransparent()&&S.drawTransparent(B);for(var i=0;i<e;++i){var o=L[i];o.isTransparent&&o.isTransparent()&&o.drawTransparent(B)}x.bindFramebuffer(x.FRAMEBUFFER,null),x.blendFunc(x.ONE,x.ONE_MINUS_SRC_ALPHA),x.disable(x.DEPTH_TEST),k.bind(),w.color[0].bind(0),k.uniforms.accumBuffer=0,c(x),x.disable(x.BLEND)}I=!1;for(var i=0;i<e;++i)L[i].dirty=!1}}}return U.enableMouseListeners(),function t(){U._stopped||U.contextLost||(X(),requestAnimationFrame(t))}(),U.redraw=function(){U._stopped||(I=!0,X())},U},createCamera:n}},{\"./camera.js\":288,\"./lib/shader\":289,\"a-big-triangle\":59,\"gl-axes3d\":233,\"gl-axes3d/properties\":240,\"gl-fbo\":249,\"gl-mat4/ortho\":268,\"gl-mat4/perspective\":269,\"gl-select-static\":300,\"gl-spikes3d\":310,\"is-mobile\":420,\"mouse-change\":435,\"mouse-wheel\":438}],291:[function(t,e,r){var n=t(\"glslify\");r.pointVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform float pointCloud;\\n\\nhighp float rand(vec2 co) {\\n  highp float a = 12.9898;\\n  highp float b = 78.233;\\n  highp float c = 43758.5453;\\n  highp float d = dot(co.xy, vec2(a, b));\\n  highp float e = mod(d, 3.14);\\n  return fract(sin(e) * c);\\n}\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n    // if we don't jitter the point size a bit, overall point cloud\\n    // saturation 'jumps' on zooming, which is disturbing and confusing\\n  gl_PointSize = pointSize * ((19.5 + rand(position)) / 20.0);\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    // get the same square surface as circle would be\\n    gl_PointSize *= 0.886;\\n  }\\n}\"]),r.pointFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color, borderColor;\\nuniform float centerFraction;\\nuniform float pointCloud;\\n\\nvoid main() {\\n  float radius;\\n  vec4 baseColor;\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    if(centerFraction == 1.0) {\\n      gl_FragColor = color;\\n    } else {\\n      gl_FragColor = mix(borderColor, color, centerFraction);\\n    }\\n  } else {\\n    radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n    if(radius > 1.0) {\\n      discard;\\n    }\\n    baseColor = mix(borderColor, color, step(radius, centerFraction));\\n    gl_FragColor = vec4(baseColor.rgb * baseColor.a, baseColor.a);\\n  }\\n}\\n\"]),r.pickVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform vec4 pickOffset;\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n  gl_PointSize = pointSize;\\n\\n  vec4 id = pickId + pickOffset;\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  fragId = id;\\n}\\n\"]),r.pickFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  float radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n  if(radius > 1.0) {\\n    discard;\\n  }\\n  gl_FragColor = fragId / 255.0;\\n}\\n\"])},{glslify:409}],292:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"typedarray-pool\"),o=t(\"./lib/shader\");function s(t,e,r,n,i){this.plot=t,this.offsetBuffer=e,this.pickBuffer=r,this.shader=n,this.pickShader=i,this.sizeMin=.5,this.sizeMinCap=2,this.sizeMax=20,this.areaRatio=1,this.pointCount=0,this.color=[1,0,0,1],this.borderColor=[0,0,0,1],this.blend=!1,this.pickOffset=0,this.points=null}e.exports=function(t,e){var r=t.gl,a=i(r),l=i(r),c=n(r,o.pointVertex,o.pointFragment),u=n(r,o.pickVertex,o.pickFragment),h=new s(t,a,l,c,u);return h.update(e),t.addObject(h),h};var l,c,u=s.prototype;u.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.offsetBuffer.dispose(),this.pickBuffer.dispose(),this.plot.removeObject(this)},u.update=function(t){var e;function r(e,r){return e in t?t[e]:r}t=t||{},this.sizeMin=r(\"sizeMin\",.5),this.sizeMax=r(\"sizeMax\",20),this.color=r(\"color\",[1,0,0,1]).slice(),this.areaRatio=r(\"areaRatio\",1),this.borderColor=r(\"borderColor\",[0,0,0,1]).slice(),this.blend=r(\"blend\",!1);var n=t.positions.length>>>1,i=t.positions instanceof Float32Array,o=t.idToIndex instanceof Int32Array&&t.idToIndex.length>=n,s=t.positions,l=i?s:a.mallocFloat32(s.length),c=o?t.idToIndex:a.mallocInt32(n);if(i||l.set(s),!o)for(l.set(s),e=0;e<n;e++)c[e]=e;this.points=s,this.offsetBuffer.update(l),this.pickBuffer.update(c),i||a.free(l),o||a.free(c),this.pointCount=n,this.pickOffset=0},u.unifiedDraw=(l=[1,0,0,0,1,0,0,0,1],c=[0,0,0,0],function(t){var e=void 0!==t,r=e?this.pickShader:this.shader,n=this.plot.gl,i=this.plot.dataBox;if(0===this.pointCount)return t;var a=i[2]-i[0],o=i[3]-i[1],s=function(t,e){var r,n=0,i=t.length>>>1;for(r=0;r<i;r++){var a=t[2*r],o=t[2*r+1];a>=e[0]&&a<=e[2]&&o>=e[1]&&o<=e[3]&&n++}return n}(this.points,i),u=this.plot.pickPixelRatio*Math.max(Math.min(this.sizeMinCap,this.sizeMin),Math.min(this.sizeMax,this.sizeMax/Math.pow(s,.33333)));l[0]=2/a,l[4]=2/o,l[6]=-2*i[0]/a-1,l[7]=-2*i[1]/o-1,this.offsetBuffer.bind(),r.bind(),r.attributes.position.pointer(),r.uniforms.matrix=l,r.uniforms.color=this.color,r.uniforms.borderColor=this.borderColor,r.uniforms.pointCloud=u<5,r.uniforms.pointSize=u,r.uniforms.centerFraction=Math.min(1,Math.max(0,Math.sqrt(1-this.areaRatio))),e&&(c[0]=255&t,c[1]=t>>8&255,c[2]=t>>16&255,c[3]=t>>24&255,this.pickBuffer.bind(),r.attributes.pickId.pointer(n.UNSIGNED_BYTE),r.uniforms.pickOffset=c,this.pickOffset=t);var h=n.getParameter(n.BLEND),f=n.getParameter(n.DITHER);return h&&!this.blend&&n.disable(n.BLEND),f&&n.disable(n.DITHER),n.drawArrays(n.POINTS,0,this.pointCount),h&&!this.blend&&n.enable(n.BLEND),f&&n.enable(n.DITHER),t+this.pointCount}),u.draw=u.unifiedDraw,u.drawPick=u.unifiedDraw,u.pick=function(t,e,r){var n=this.pickOffset,i=this.pointCount;if(r<n||r>=n+i)return null;var a=r-n,o=this.points;return{object:this,pointId:a,dataCoord:[o[2*a],o[2*a+1]]}}},{\"./lib/shader\":291,\"gl-buffer\":241,\"gl-shader\":301,\"typedarray-pool\":545}],293:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c=e[0],u=e[1],h=e[2],f=e[3],p=r[0],d=r[1],g=r[2],v=r[3];(a=c*p+u*d+h*g+f*v)<0&&(a=-a,p=-p,d=-d,g=-g,v=-v);1-a>1e-6?(i=Math.acos(a),o=Math.sin(i),s=Math.sin((1-n)*i)/o,l=Math.sin(n*i)/o):(s=1-n,l=n);return t[0]=s*c+l*p,t[1]=s*u+l*d,t[2]=s*h+l*g,t[3]=s*f+l*v,t}},{}],294:[function(t,e,r){\"use strict\";e.exports=function(t){return t||0===t?t.toString():\"\"}},{}],295:[function(t,e,r){\"use strict\";var n=t(\"vectorize-text\");e.exports=function(t,e,r){var a=i[e];a||(a=i[e]={});if(t in a)return a[t];var o={textAlign:\"center\",textBaseline:\"middle\",lineHeight:1,font:e,lineSpacing:1.25,styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},triangles:!0},s=n(t,o);o.triangles=!1;var l,c,u=n(t,o);if(r&&1!==r){for(l=0;l<s.positions.length;++l)for(c=0;c<s.positions[l].length;++c)s.positions[l][c]/=r;for(l=0;l<u.positions.length;++l)for(c=0;c<u.positions[l].length;++c)u.positions[l][c]/=r}var h=[[1/0,1/0],[-1/0,-1/0]],f=u.positions.length;for(l=0;l<f;++l){var p=u.positions[l];for(c=0;c<2;++c)h[0][c]=Math.min(h[0][c],p[c]),h[1][c]=Math.max(h[1][c],p[c])}return a[t]=[s,u,h]};var i={}},{\"vectorize-text\":550}],296:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform vec4 highlightId;\\nuniform float highlightScale;\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = 1.0;\\n    if(distance(highlightId, id) < 0.0001) {\\n      scale = highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1);\\n    vec4 viewPosition = view * worldPosition;\\n    viewPosition = viewPosition / viewPosition.w;\\n    vec4 clipPosition = projection * (viewPosition + scale * vec4(glyph.x, -glyph.y, 0, 0));\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float highlightScale, pixelRatio;\\nuniform vec4 highlightId;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = pixelRatio;\\n    if(distance(highlightId.bgr, id.bgr) < 0.001) {\\n      scale *= highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1.0);\\n    vec4 viewPosition = view * worldPosition;\\n    vec4 clipPosition = projection * viewPosition;\\n    clipPosition /= clipPosition.w;\\n\\n    gl_Position = clipPosition + vec4(screenSize * scale * vec2(glyph.x, -glyph.y), 0.0, 0.0);\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform float highlightScale;\\nuniform vec4 highlightId;\\nuniform vec3 axes[2];\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float scale, pixelRatio;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float lscale = pixelRatio * scale;\\n    if(distance(highlightId, id) < 0.0001) {\\n      lscale *= highlightScale;\\n    }\\n\\n    vec4 clipCenter   = projection * view * model * vec4(position, 1);\\n    vec3 dataPosition = position + 0.5*lscale*(axes[0] * glyph.x + axes[1] * glyph.y) * clipCenter.w * screenSize.y;\\n    vec4 clipPosition = projection * view * model * vec4(dataPosition, 1);\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = dataPosition;\\n  }\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float opacity;\\n\\nvarying vec4 interpColor;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (\\n    outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate) ||\\n    interpColor.a * opacity == 0.\\n  ) discard;\\n  gl_FragColor = interpColor * opacity;\\n}\\n\"]),c=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float pickGroup;\\n\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate)) discard;\\n\\n  gl_FragColor = vec4(pickGroup, pickId.bgr);\\n}\"]),u=[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"glyph\",type:\"vec2\"},{name:\"id\",type:\"vec4\"}],h={vertex:a,fragment:l,attributes:u},f={vertex:o,fragment:l,attributes:u},p={vertex:s,fragment:l,attributes:u},d={vertex:a,fragment:c,attributes:u},g={vertex:o,fragment:c,attributes:u},v={vertex:s,fragment:c,attributes:u};function m(t,e){var r=n(t,e),i=r.attributes;return i.position.location=0,i.color.location=1,i.glyph.location=2,i.id.location=3,r}r.createPerspective=function(t){return m(t,h)},r.createOrtho=function(t){return m(t,f)},r.createProject=function(t){return m(t,p)},r.createPickPerspective=function(t){return m(t,d)},r.createPickOrtho=function(t){return m(t,g)},r.createPickProject=function(t){return m(t,v)}},{\"gl-shader\":301,glslify:409}],297:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"typedarray-pool\"),s=t(\"gl-mat4/multiply\"),l=t(\"./lib/shaders\"),c=t(\"./lib/glyphs\"),u=t(\"./lib/get-simple-string\"),h=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function f(t,e){var r=t[0],n=t[1],i=t[2],a=t[3];return t[0]=e[0]*r+e[4]*n+e[8]*i+e[12]*a,t[1]=e[1]*r+e[5]*n+e[9]*i+e[13]*a,t[2]=e[2]*r+e[6]*n+e[10]*i+e[14]*a,t[3]=e[3]*r+e[7]*n+e[11]*i+e[15]*a,t}function p(t,e,r,n){return f(n,n),f(n,n),f(n,n)}function d(t,e){this.index=t,this.dataCoordinate=this.position=e}function g(t){return!0===t?1:t>1?1:t}function v(t,e,r,n,i,a,o,s,l,c,u,h){this.gl=t,this.pixelRatio=1,this.shader=e,this.orthoShader=r,this.projectShader=n,this.pointBuffer=i,this.colorBuffer=a,this.glyphBuffer=o,this.idBuffer=s,this.vao=l,this.vertexCount=0,this.lineVertexCount=0,this.opacity=1,this.hasAlpha=!1,this.lineWidth=0,this.projectScale=[2/3,2/3,2/3],this.projectOpacity=[1,1,1],this.projectHasAlpha=!1,this.pickId=0,this.pickPerspectiveShader=c,this.pickOrthoShader=u,this.pickProjectShader=h,this.points=[],this._selectResult=new d(0,[0,0,0]),this.useOrtho=!0,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.axesProject=[!0,!0,!0],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.highlightId=[1,1,1,1],this.highlightScale=2,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.dirty=!0}e.exports=function(t){var e=t.gl,r=l.createPerspective(e),n=l.createOrtho(e),o=l.createProject(e),s=l.createPickPerspective(e),c=l.createPickOrtho(e),u=l.createPickProject(e),h=i(e),f=i(e),p=i(e),d=i(e),g=a(e,[{buffer:h,size:3,type:e.FLOAT},{buffer:f,size:4,type:e.FLOAT},{buffer:p,size:2,type:e.FLOAT},{buffer:d,size:4,type:e.UNSIGNED_BYTE,normalized:!0}]),m=new v(e,r,n,o,h,f,p,d,g,s,c,u);return m.update(t),m};var m=v.prototype;m.pickSlots=1,m.setPickBase=function(t){this.pickId=t},m.isTransparent=function(){if(this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&this.projectHasAlpha)return!0;return!1},m.isOpaque=function(){if(!this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&!this.projectHasAlpha)return!0;return!1};var y=[0,0],x=[0,0,0],b=[0,0,0],_=[0,0,0,1],w=[0,0,0,1],k=h.slice(),T=[0,0,0],A=[[0,0,0],[0,0,0]];function M(t){return t[0]=t[1]=t[2]=0,t}function S(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=1,t}function E(t,e,r,n){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[r]=n,t}function C(t,e,r,n){var i,a=e.axesProject,o=e.gl,l=t.uniforms,c=r.model||h,u=r.view||h,f=r.projection||h,d=e.axesBounds,g=function(t){for(var e=A,r=0;r<2;++r)for(var n=0;n<3;++n)e[r][n]=Math.max(Math.min(t[r][n],1e8),-1e8);return e}(e.clipBounds);i=e.axes&&e.axes.lastCubeProps?e.axes.lastCubeProps.axis:[1,1,1],y[0]=2/o.drawingBufferWidth,y[1]=2/o.drawingBufferHeight,t.bind(),l.view=u,l.projection=f,l.screenSize=y,l.highlightId=e.highlightId,l.highlightScale=e.highlightScale,l.clipBounds=g,l.pickGroup=e.pickId/255,l.pixelRatio=n;for(var v=0;v<3;++v)if(a[v]){l.scale=e.projectScale[v],l.opacity=e.projectOpacity[v];for(var m=k,C=0;C<16;++C)m[C]=0;for(C=0;C<4;++C)m[5*C]=1;m[5*v]=0,i[v]<0?m[12+v]=d[0][v]:m[12+v]=d[1][v],s(m,c,m),l.model=m;var L=(v+1)%3,P=(v+2)%3,O=M(x),z=M(b);O[L]=1,z[P]=1;var I=p(0,0,0,S(_,O)),D=p(0,0,0,S(w,z));if(Math.abs(I[1])>Math.abs(D[1])){var R=I;I=D,D=R,R=O,O=z,z=R;var F=L;L=P,P=F}I[0]<0&&(O[L]=-1),D[1]>0&&(z[P]=-1);var B=0,N=0;for(C=0;C<4;++C)B+=Math.pow(c[4*L+C],2),N+=Math.pow(c[4*P+C],2);O[L]/=Math.sqrt(B),z[P]/=Math.sqrt(N),l.axes[0]=O,l.axes[1]=z,l.fragClipBounds[0]=E(T,g[0],v,-1e8),l.fragClipBounds[1]=E(T,g[1],v,1e8),e.vao.bind(),e.vao.draw(o.TRIANGLES,e.vertexCount),e.lineWidth>0&&(o.lineWidth(e.lineWidth*n),e.vao.draw(o.LINES,e.lineVertexCount,e.vertexCount)),e.vao.unbind()}}var L=[[-1e8,-1e8,-1e8],[1e8,1e8,1e8]];function P(t,e,r,n,i,a,o){var s=r.gl;if((a===r.projectHasAlpha||o)&&C(e,r,n,i),a===r.hasAlpha||o){t.bind();var l=t.uniforms;l.model=n.model||h,l.view=n.view||h,l.projection=n.projection||h,y[0]=2/s.drawingBufferWidth,y[1]=2/s.drawingBufferHeight,l.screenSize=y,l.highlightId=r.highlightId,l.highlightScale=r.highlightScale,l.fragClipBounds=L,l.clipBounds=r.axes.bounds,l.opacity=r.opacity,l.pickGroup=r.pickId/255,l.pixelRatio=i,r.vao.bind(),r.vao.draw(s.TRIANGLES,r.vertexCount),r.lineWidth>0&&(s.lineWidth(r.lineWidth*i),r.vao.draw(s.LINES,r.lineVertexCount,r.vertexCount)),r.vao.unbind()}}function O(t,e,r,i){var a;a=Array.isArray(t)?e<t.length?t[e]:void 0:t,a=u(a);var o=!0;n(a)&&(a=\"\\u25bc\",o=!1);var s=c(a,r,i);return{mesh:s[0],lines:s[1],bounds:s[2],visible:o}}m.draw=function(t){P(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!1,!1)},m.drawTransparent=function(t){P(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!0,!1)},m.drawPick=function(t){P(this.useOrtho?this.pickOrthoShader:this.pickPerspectiveShader,this.pickProjectShader,this,t,1,!0,!0)},m.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[2]+(t.value[1]<<8)+(t.value[0]<<16);if(e>=this.pointCount||e<0)return null;var r=this.points[e],n=this._selectResult;n.index=e;for(var i=0;i<3;++i)n.position[i]=n.dataCoordinate[i]=r[i];return n},m.highlight=function(t){if(t){var e=t.index,r=255&e,n=e>>8&255,i=e>>16&255;this.highlightId=[r/255,n/255,i/255,0]}else this.highlightId=[1,1,1,1]},m.update=function(t){if(\"perspective\"in(t=t||{})&&(this.useOrtho=!t.perspective),\"orthographic\"in t&&(this.useOrtho=!!t.orthographic),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"project\"in t)if(Array.isArray(t.project))this.axesProject=t.project;else{var e=!!t.project;this.axesProject=[e,e,e]}if(\"projectScale\"in t)if(Array.isArray(t.projectScale))this.projectScale=t.projectScale.slice();else{var r=+t.projectScale;this.projectScale=[r,r,r]}if(this.projectHasAlpha=!1,\"projectOpacity\"in t){if(Array.isArray(t.projectOpacity))this.projectOpacity=t.projectOpacity.slice();else{r=+t.projectOpacity;this.projectOpacity=[r,r,r]}for(var n=0;n<3;++n)this.projectOpacity[n]=g(this.projectOpacity[n]),this.projectOpacity[n]<1&&(this.projectHasAlpha=!0)}this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=g(t.opacity),this.opacity<1&&(this.hasAlpha=!0)),this.dirty=!0;var i,a,s=t.position,l=t.font||\"normal\",c=t.alignment||[0,0];if(2===c.length)i=c[0],a=c[1];else{i=[],a=[];for(n=0;n<c.length;++n)i[n]=c[n][0],a[n]=c[n][1]}var u=[1/0,1/0,1/0],h=[-1/0,-1/0,-1/0],f=t.glyph,p=t.color,d=t.size,v=t.angle,m=t.lineColor,y=-1,x=0,b=0,_=0;if(s.length){_=s.length;t:for(n=0;n<_;++n){for(var w=s[n],k=0;k<3;++k)if(isNaN(w[k])||!isFinite(w[k]))continue t;var T=(N=O(f,n,l,this.pixelRatio)).mesh,A=N.lines,M=N.bounds;x+=3*T.cells.length,b+=2*A.edges.length}}var S=x+b,E=o.mallocFloat(3*S),C=o.mallocFloat(4*S),L=o.mallocFloat(2*S),P=o.mallocUint32(S);if(S>0){var z=0,I=x,D=[0,0,0,1],R=[0,0,0,1],F=Array.isArray(p)&&Array.isArray(p[0]),B=Array.isArray(m)&&Array.isArray(m[0]);t:for(n=0;n<_;++n){y+=1;for(w=s[n],k=0;k<3;++k){if(isNaN(w[k])||!isFinite(w[k]))continue t;h[k]=Math.max(h[k],w[k]),u[k]=Math.min(u[k],w[k])}T=(N=O(f,n,l,this.pixelRatio)).mesh,A=N.lines,M=N.bounds;var N,j=N.visible;if(j)if(Array.isArray(p)){if(3===(U=F?n<p.length?p[n]:[0,0,0,0]:p).length){for(k=0;k<3;++k)D[k]=U[k];D[3]=1}else if(4===U.length){for(k=0;k<4;++k)D[k]=U[k];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else D[0]=D[1]=D[2]=0,D[3]=1;else D=[1,1,1,0];if(j)if(Array.isArray(m)){var U;if(3===(U=B?n<m.length?m[n]:[0,0,0,0]:m).length){for(k=0;k<3;++k)R[k]=U[k];R[k]=1}else if(4===U.length){for(k=0;k<4;++k)R[k]=U[k];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else R[0]=R[1]=R[2]=0,R[3]=1;else R=[1,1,1,0];var V=.5;j?Array.isArray(d)?V=n<d.length?+d[n]:12:d?V=+d:this.useOrtho&&(V=12):V=0;var q=0;Array.isArray(v)?q=n<v.length?+v[n]:0:v&&(q=+v);var H=Math.cos(q),G=Math.sin(q);for(w=s[n],k=0;k<3;++k)h[k]=Math.max(h[k],w[k]),u[k]=Math.min(u[k],w[k]);var Y=i,W=a;Y=0;Array.isArray(i)?Y=n<i.length?i[n]:0:i&&(Y=i);W=0;Array.isArray(a)?W=n<a.length?a[n]:0:a&&(W=a);var X=[Y*=Y>0?1-M[0][0]:Y<0?1+M[1][0]:1,W*=W>0?1-M[0][1]:W<0?1+M[1][1]:1],Z=T.cells||[],J=T.positions||[];for(k=0;k<Z.length;++k)for(var K=Z[k],$=0;$<3;++$){for(var Q=0;Q<3;++Q)E[3*z+Q]=w[Q];for(Q=0;Q<4;++Q)C[4*z+Q]=D[Q];P[z]=y;var tt=J[K[$]];L[2*z]=V*(H*tt[0]-G*tt[1]+X[0]),L[2*z+1]=V*(G*tt[0]+H*tt[1]+X[1]),z+=1}for(Z=A.edges,J=A.positions,k=0;k<Z.length;++k)for(K=Z[k],$=0;$<2;++$){for(Q=0;Q<3;++Q)E[3*I+Q]=w[Q];for(Q=0;Q<4;++Q)C[4*I+Q]=R[Q];P[I]=y;tt=J[K[$]];L[2*I]=V*(H*tt[0]-G*tt[1]+X[0]),L[2*I+1]=V*(G*tt[0]+H*tt[1]+X[1]),I+=1}}}this.bounds=[u,h],this.points=s,this.pointCount=s.length,this.vertexCount=x,this.lineVertexCount=b,this.pointBuffer.update(E),this.colorBuffer.update(C),this.glyphBuffer.update(L),this.idBuffer.update(P),o.free(E),o.free(C),o.free(L),o.free(P)},m.dispose=function(){this.shader.dispose(),this.orthoShader.dispose(),this.pickPerspectiveShader.dispose(),this.pickOrthoShader.dispose(),this.vao.dispose(),this.pointBuffer.dispose(),this.colorBuffer.dispose(),this.glyphBuffer.dispose(),this.idBuffer.dispose()}},{\"./lib/get-simple-string\":294,\"./lib/glyphs\":295,\"./lib/shaders\":296,\"gl-buffer\":241,\"gl-mat4/multiply\":267,\"gl-vao\":327,\"is-string-blank\":423,\"typedarray-pool\":545}],298:[function(t,e,r){\"use strict\";var n=t(\"glslify\");r.boxVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 vertex;\\n\\nuniform vec2 cornerA, cornerB;\\n\\nvoid main() {\\n  gl_Position = vec4(mix(cornerA, cornerB, vertex), 0, 1);\\n}\\n\"]),r.boxFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\n\\nvoid main() {\\n  gl_FragColor = color;\\n}\\n\"])},{glslify:409}],299:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"./lib/shaders\");function o(t,e,r){this.plot=t,this.boxBuffer=e,this.boxShader=r,this.enabled=!0,this.selectBox=[1/0,1/0,-1/0,-1/0],this.borderColor=[0,0,0,1],this.innerFill=!1,this.innerColor=[0,0,0,.25],this.outerFill=!0,this.outerColor=[0,0,0,.5],this.borderWidth=10}e.exports=function(t,e){var r=t.gl,s=i(r,[0,0,0,1,1,0,1,1]),l=n(r,a.boxVertex,a.boxFragment),c=new o(t,s,l);return c.update(e),t.addOverlay(c),c};var s=o.prototype;s.draw=function(){if(this.enabled){var t=this.plot,e=this.selectBox,r=this.borderWidth,n=(this.innerFill,this.innerColor),i=(this.outerFill,this.outerColor),a=this.borderColor,o=t.box,s=t.screenBox,l=t.dataBox,c=t.viewBox,u=t.pixelRatio,h=(e[0]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],f=(e[1]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1],p=(e[2]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],d=(e[3]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1];if(h=Math.max(h,c[0]),f=Math.max(f,c[1]),p=Math.min(p,c[2]),d=Math.min(d,c[3]),!(p<h||d<f)){o.bind();var g=s[2]-s[0],v=s[3]-s[1];if(this.outerFill&&(o.drawBox(0,0,g,f,i),o.drawBox(0,f,h,d,i),o.drawBox(0,d,g,v,i),o.drawBox(p,f,g,d,i)),this.innerFill&&o.drawBox(h,f,p,d,n),r>0){var m=r*u;o.drawBox(h-m,f-m,p+m,f+m,a),o.drawBox(h-m,d-m,p+m,d+m,a),o.drawBox(h-m,f-m,h+m,d+m,a),o.drawBox(p-m,f-m,p+m,d+m,a)}}}},s.update=function(t){t=t||{},this.innerFill=!!t.innerFill,this.outerFill=!!t.outerFill,this.innerColor=(t.innerColor||[0,0,0,.5]).slice(),this.outerColor=(t.outerColor||[0,0,0,.5]).slice(),this.borderColor=(t.borderColor||[0,0,0,1]).slice(),this.borderWidth=t.borderWidth||0,this.selectBox=(t.selectBox||this.selectBox).slice()},s.dispose=function(){this.boxBuffer.dispose(),this.boxShader.dispose(),this.plot.removeOverlay(this)}},{\"./lib/shaders\":298,\"gl-buffer\":241,\"gl-shader\":301}],300:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=n(t,e),a=i.mallocUint8(e[0]*e[1]*4);return new c(t,r,a)};var n=t(\"gl-fbo\"),i=t(\"typedarray-pool\"),a=t(\"ndarray\"),o=t(\"bit-twiddle\").nextPow2,s=t(\"cwise/lib/wrapper\")({args:[\"array\",{offset:[0,0,1],array:0},{offset:[0,0,2],array:0},{offset:[0,0,3],array:0},\"scalar\",\"scalar\",\"index\"],pre:{body:\"{this_closestD2=1e8,this_closestX=-1,this_closestY=-1}\",args:[],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[]},body:{body:\"{if(_inline_16_arg0_<255||_inline_16_arg1_<255||_inline_16_arg2_<255||_inline_16_arg3_<255){var _inline_16_l=_inline_16_arg4_-_inline_16_arg6_[0],_inline_16_a=_inline_16_arg5_-_inline_16_arg6_[1],_inline_16_f=_inline_16_l*_inline_16_l+_inline_16_a*_inline_16_a;_inline_16_f<this_closestD2&&(this_closestD2=_inline_16_f,this_closestX=_inline_16_arg6_[0],this_closestY=_inline_16_arg6_[1])}}\",args:[{name:\"_inline_16_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg4_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg5_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_16_arg6_\",lvalue:!1,rvalue:!0,count:4}],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[\"_inline_16_a\",\"_inline_16_f\",\"_inline_16_l\"]},post:{body:\"{return[this_closestX,this_closestY,this_closestD2]}\",args:[],thisVars:[\"this_closestD2\",\"this_closestX\",\"this_closestY\"],localVars:[]},debug:!1,funcName:\"cwise\",blockSize:64});function l(t,e,r,n,i){this.coord=[t,e],this.id=r,this.value=n,this.distance=i}function c(t,e,r){this.gl=t,this.fbo=e,this.buffer=r,this._readTimeout=null;var n=this;this._readCallback=function(){n.gl&&(e.bind(),t.readPixels(0,0,e.shape[0],e.shape[1],t.RGBA,t.UNSIGNED_BYTE,n.buffer),n._readTimeout=null)}}var u=c.prototype;Object.defineProperty(u,\"shape\",{get:function(){return this.gl?this.fbo.shape.slice():[0,0]},set:function(t){if(this.gl){this.fbo.shape=t;var e=this.fbo.shape[0],r=this.fbo.shape[1];if(r*e*4>this.buffer.length){i.free(this.buffer);for(var n=this.buffer=i.mallocUint8(o(r*e*4)),a=0;a<r*e*4;++a)n[a]=255}return t}}}),u.begin=function(){var t=this.gl;this.shape;t&&(this.fbo.bind(),t.clearColor(1,1,1,1),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT))},u.end=function(){var t=this.gl;t&&(t.bindFramebuffer(t.FRAMEBUFFER,null),this._readTimeout||clearTimeout(this._readTimeout),this._readTimeout=setTimeout(this._readCallback,1))},u.query=function(t,e,r){if(!this.gl)return null;var n=this.fbo.shape.slice();t|=0,e|=0,\"number\"!=typeof r&&(r=1);var i=0|Math.min(Math.max(t-r,0),n[0]),o=0|Math.min(Math.max(t+r,0),n[0]),c=0|Math.min(Math.max(e-r,0),n[1]),u=0|Math.min(Math.max(e+r,0),n[1]);if(o<=i||u<=c)return null;var h=[o-i,u-c],f=a(this.buffer,[h[0],h[1],4],[4,4*n[0],1],4*(i+n[0]*c)),p=s(f.hi(h[0],h[1],1),r,r),d=p[0],g=p[1];return d<0||Math.pow(this.radius,2)<p[2]?null:new l(d+i|0,g+c|0,f.get(d,g,0),[f.get(d,g,1),f.get(d,g,2),f.get(d,g,3)],Math.sqrt(p[2]))},u.dispose=function(){this.gl&&(this.fbo.dispose(),i.free(this.buffer),this.gl=null,this._readTimeout&&clearTimeout(this._readTimeout))}},{\"bit-twiddle\":92,\"cwise/lib/wrapper\":149,\"gl-fbo\":249,ndarray:450,\"typedarray-pool\":545}],301:[function(t,e,r){\"use strict\";var n=t(\"./lib/create-uniforms\"),i=t(\"./lib/create-attributes\"),a=t(\"./lib/reflect\"),o=t(\"./lib/shader-cache\"),s=t(\"./lib/runtime-reflect\"),l=t(\"./lib/GLError\");function c(t){this.gl=t,this.gl.lastAttribCount=0,this._vref=this._fref=this._relink=this.vertShader=this.fragShader=this.program=this.attributes=this.uniforms=this.types=null}var u=c.prototype;function h(t,e){return t.name<e.name?-1:1}u.bind=function(){var t;this.program||this._relink();var e=this.gl.getProgramParameter(this.program,this.gl.ACTIVE_ATTRIBUTES),r=this.gl.lastAttribCount;if(e>r)for(t=r;t<e;t++)this.gl.enableVertexAttribArray(t);else if(r>e)for(t=e;t<r;t++)this.gl.disableVertexAttribArray(t);this.gl.lastAttribCount=e,this.gl.useProgram(this.program)},u.dispose=function(){for(var t=this.gl.lastAttribCount,e=0;e<t;e++)this.gl.disableVertexAttribArray(e);this.gl.lastAttribCount=0,this._fref&&this._fref.dispose(),this._vref&&this._vref.dispose(),this.attributes=this.types=this.vertShader=this.fragShader=this.program=this._relink=this._fref=this._vref=null},u.update=function(t,e,r,c){if(!e||1===arguments.length){var u=t;t=u.vertex,e=u.fragment,r=u.uniforms,c=u.attributes}var f=this,p=f.gl,d=f._vref;f._vref=o.shader(p,p.VERTEX_SHADER,t),d&&d.dispose(),f.vertShader=f._vref.shader;var g=this._fref;if(f._fref=o.shader(p,p.FRAGMENT_SHADER,e),g&&g.dispose(),f.fragShader=f._fref.shader,!r||!c){var v=p.createProgram();if(p.attachShader(v,f.fragShader),p.attachShader(v,f.vertShader),p.linkProgram(v),!p.getProgramParameter(v,p.LINK_STATUS)){var m=p.getProgramInfoLog(v);throw new l(m,\"Error linking program:\"+m)}r=r||s.uniforms(p,v),c=c||s.attributes(p,v),p.deleteProgram(v)}(c=c.slice()).sort(h);var y,x=[],b=[],_=[];for(y=0;y<c.length;++y){var w=c[y];if(w.type.indexOf(\"mat\")>=0){for(var k=0|w.type.charAt(w.type.length-1),T=new Array(k),A=0;A<k;++A)T[A]=_.length,b.push(w.name+\"[\"+A+\"]\"),\"number\"==typeof w.location?_.push(w.location+A):Array.isArray(w.location)&&w.location.length===k&&\"number\"==typeof w.location[A]?_.push(0|w.location[A]):_.push(-1);x.push({name:w.name,type:w.type,locations:T})}else x.push({name:w.name,type:w.type,locations:[_.length]}),b.push(w.name),\"number\"==typeof w.location?_.push(0|w.location):_.push(-1)}var M=0;for(y=0;y<_.length;++y)if(_[y]<0){for(;_.indexOf(M)>=0;)M+=1;_[y]=M}var S=new Array(r.length);function E(){f.program=o.program(p,f._vref,f._fref,b,_);for(var t=0;t<r.length;++t)S[t]=p.getUniformLocation(f.program,r[t].name)}E(),f._relink=E,f.types={uniforms:a(r),attributes:a(c)},f.attributes=i(p,f,x,_),Object.defineProperty(f,\"uniforms\",n(p,f,r,S))},e.exports=function(t,e,r,n,i){var a=new c(t);return a.update(e,r,n,i),a}},{\"./lib/GLError\":302,\"./lib/create-attributes\":303,\"./lib/create-uniforms\":304,\"./lib/reflect\":305,\"./lib/runtime-reflect\":306,\"./lib/shader-cache\":307}],302:[function(t,e,r){function n(t,e,r){this.shortMessage=e||\"\",this.longMessage=r||\"\",this.rawError=t||\"\",this.message=\"gl-shader: \"+(e||t||\"\")+(r?\"\\n\"+r:\"\"),this.stack=(new Error).stack}n.prototype=new Error,n.prototype.name=\"GLError\",n.prototype.constructor=n,e.exports=n},{}],303:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){for(var a={},l=0,c=r.length;l<c;++l){var u=r[l],h=u.name,f=u.type,p=u.locations;switch(f){case\"bool\":case\"int\":case\"float\":o(t,e,p[0],i,1,a,h);break;default:if(f.indexOf(\"vec\")>=0){var d=f.charCodeAt(f.length-1)-48;if(d<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+h+\": \"+f);o(t,e,p[0],i,d,a,h)}else{if(!(f.indexOf(\"mat\")>=0))throw new n(\"\",\"Unknown data type for attribute \"+h+\": \"+f);var d=f.charCodeAt(f.length-1)-48;if(d<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+h+\": \"+f);s(t,e,p,i,d,a,h)}}}return a};var n=t(\"./GLError\");function i(t,e,r,n,i,a){this._gl=t,this._wrapper=e,this._index=r,this._locations=n,this._dimension=i,this._constFunc=a}var a=i.prototype;function o(t,e,r,n,a,o,s){for(var l=[\"gl\",\"v\"],c=[],u=0;u<a;++u)l.push(\"x\"+u),c.push(\"x\"+u);l.push(\"if(x0.length===void 0){return gl.vertexAttrib\"+a+\"f(v,\"+c.join()+\")}else{return gl.vertexAttrib\"+a+\"fv(v,x0)}\");var h=Function.apply(null,l),f=new i(t,e,r,n,a,h);Object.defineProperty(o,s,{set:function(e){return t.disableVertexAttribArray(n[r]),h(t,n[r],e),e},get:function(){return f},enumerable:!0})}function s(t,e,r,n,i,a,s){for(var l=new Array(i),c=new Array(i),u=0;u<i;++u)o(t,e,r[u],n,i,l,u),c[u]=l[u];Object.defineProperty(l,\"location\",{set:function(t){if(Array.isArray(t))for(var e=0;e<i;++e)c[e].location=t[e];else for(e=0;e<i;++e)c[e].location=t+e;return t},get:function(){for(var t=new Array(i),e=0;e<i;++e)t[e]=n[r[e]];return t},enumerable:!0}),l.pointer=function(e,a,o,s){e=e||t.FLOAT,a=!!a,o=o||i*i,s=s||0;for(var l=0;l<i;++l){var c=n[r[l]];t.vertexAttribPointer(c,i,e,a,o,s+l*i),t.enableVertexAttribArray(c)}};var h=new Array(i),f=t[\"vertexAttrib\"+i+\"fv\"];Object.defineProperty(a,s,{set:function(e){for(var a=0;a<i;++a){var o=n[r[a]];if(t.disableVertexAttribArray(o),Array.isArray(e[0]))f.call(t,o,e[a]);else{for(var s=0;s<i;++s)h[s]=e[i*a+s];f.call(t,o,h)}}return e},get:function(){return l},enumerable:!0})}a.pointer=function(t,e,r,n){var i=this._gl,a=this._locations[this._index];i.vertexAttribPointer(a,this._dimension,t||i.FLOAT,!!e,r||0,n||0),i.enableVertexAttribArray(a)},a.set=function(t,e,r,n){return this._constFunc(this._locations[this._index],t,e,r,n)},Object.defineProperty(a,\"location\",{get:function(){return this._locations[this._index]},set:function(t){return t!==this._locations[this._index]&&(this._locations[this._index]=0|t,this._wrapper.program=null),0|t}})},{\"./GLError\":302}],304:[function(t,e,r){\"use strict\";var n=t(\"./reflect\"),i=t(\"./GLError\");function a(t){return new Function(\"y\",\"return function(){return y}\")(t)}function o(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}e.exports=function(t,e,r,s){function l(t,e,r){switch(r){case\"bool\":case\"int\":case\"sampler2D\":case\"samplerCube\":return\"gl.uniform1i(locations[\"+e+\"],obj\"+t+\")\";case\"float\":return\"gl.uniform1f(locations[\"+e+\"],obj\"+t+\")\";default:var n=r.indexOf(\"vec\");if(!(0<=n&&n<=1&&r.length===4+n)){if(0===r.indexOf(\"mat\")&&4===r.length){var a=r.charCodeAt(r.length-1)-48;if(a<2||a>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+r);return\"gl.uniformMatrix\"+a+\"fv(locations[\"+e+\"],false,obj\"+t+\")\"}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+r)}var a=r.charCodeAt(r.length-1)-48;if(a<2||a>4)throw new i(\"\",\"Invalid data type\");switch(r.charAt(0)){case\"b\":case\"i\":return\"gl.uniform\"+a+\"iv(locations[\"+e+\"],obj\"+t+\")\";case\"v\":return\"gl.uniform\"+a+\"fv(locations[\"+e+\"],obj\"+t+\")\";default:throw new i(\"\",\"Unrecognized data type for vector \"+name+\": \"+r)}}}function c(e){for(var n=[\"return function updateProperty(obj){\"],i=function t(e,r){if(\"object\"!=typeof r)return[[e,r]];var n=[];for(var i in r){var a=r[i],o=e;parseInt(i)+\"\"===i?o+=\"[\"+i+\"]\":o+=\".\"+i,\"object\"==typeof a?n.push.apply(n,t(o,a)):n.push([o,a])}return n}(\"\",e),a=0;a<i.length;++a){var o=i[a],c=o[0],u=o[1];s[u]&&n.push(l(c,u,r[u].type))}n.push(\"return obj}\");var h=new Function(\"gl\",\"locations\",n.join(\"\\n\"));return h(t,s)}function u(n,l,u){if(\"object\"==typeof u){var f=h(u);Object.defineProperty(n,l,{get:a(f),set:c(u),enumerable:!0,configurable:!1})}else s[u]?Object.defineProperty(n,l,{get:(p=u,new Function(\"gl\",\"wrapper\",\"locations\",\"return function(){return gl.getUniform(wrapper.program,locations[\"+p+\"])}\")(t,e,s)),set:c(u),enumerable:!0,configurable:!1}):n[l]=function(t){switch(t){case\"bool\":return!1;case\"int\":case\"sampler2D\":case\"samplerCube\":case\"float\":return 0;default:var e=t.indexOf(\"vec\");if(0<=e&&e<=1&&t.length===4+e){var r=t.charCodeAt(t.length-1)-48;if(r<2||r>4)throw new i(\"\",\"Invalid data type\");return\"b\"===t.charAt(0)?o(r,!1):o(r,0)}if(0===t.indexOf(\"mat\")&&4===t.length){var r=t.charCodeAt(t.length-1)-48;if(r<2||r>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+t);return o(r*r,0)}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+t)}}(r[u].type);var p}function h(t){var e;if(Array.isArray(t)){e=new Array(t.length);for(var r=0;r<t.length;++r)u(e,r,t[r])}else for(var n in e={},t)u(e,n,t[n]);return e}var f=n(r,!0);return{get:a(h(f)),set:c(f),enumerable:!0,configurable:!0}}},{\"./GLError\":302,\"./reflect\":305}],305:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r={},n=0;n<t.length;++n)for(var i=t[n].name,a=i.split(\".\"),o=r,s=0;s<a.length;++s){var l=a[s].split(\"[\");if(l.length>1){l[0]in o||(o[l[0]]=[]),o=o[l[0]];for(var c=1;c<l.length;++c){var u=parseInt(l[c]);c<l.length-1||s<a.length-1?(u in o||(c<l.length-1?o[u]=[]:o[u]={}),o=o[u]):o[u]=e?n:t[n].type}}else s<a.length-1?(l[0]in o||(o[l[0]]={}),o=o[l[0]]):o[l[0]]=e?n:t[n].type}return r}},{}],306:[function(t,e,r){\"use strict\";r.uniforms=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_UNIFORMS),n=[],i=0;i<r;++i){var o=t.getActiveUniform(e,i);if(o){var s=a(t,o.type);if(o.size>1)for(var l=0;l<o.size;++l)n.push({name:o.name.replace(\"[0]\",\"[\"+l+\"]\"),type:s});else n.push({name:o.name,type:s})}}return n},r.attributes=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_ATTRIBUTES),n=[],i=0;i<r;++i){var o=t.getActiveAttrib(e,i);o&&n.push({name:o.name,type:a(t,o.type)})}return n};var n={FLOAT:\"float\",FLOAT_VEC2:\"vec2\",FLOAT_VEC3:\"vec3\",FLOAT_VEC4:\"vec4\",INT:\"int\",INT_VEC2:\"ivec2\",INT_VEC3:\"ivec3\",INT_VEC4:\"ivec4\",BOOL:\"bool\",BOOL_VEC2:\"bvec2\",BOOL_VEC3:\"bvec3\",BOOL_VEC4:\"bvec4\",FLOAT_MAT2:\"mat2\",FLOAT_MAT3:\"mat3\",FLOAT_MAT4:\"mat4\",SAMPLER_2D:\"sampler2D\",SAMPLER_CUBE:\"samplerCube\"},i=null;function a(t,e){if(!i){var r=Object.keys(n);i={};for(var a=0;a<r.length;++a){var o=r[a];i[t[o]]=n[o]}}return i[e]}},{}],307:[function(t,e,r){\"use strict\";r.shader=function(t,e,r){return u(t).getShaderReference(e,r)},r.program=function(t,e,r,n,i){return u(t).getProgram(e,r,n,i)};var n=t(\"./GLError\"),i=t(\"gl-format-compiler-error\"),a=new(\"undefined\"==typeof WeakMap?t(\"weakmap-shim\"):WeakMap),o=0;function s(t,e,r,n,i,a,o){this.id=t,this.src=e,this.type=r,this.shader=n,this.count=a,this.programs=[],this.cache=o}function l(t){this.gl=t,this.shaders=[{},{}],this.programs={}}s.prototype.dispose=function(){if(0==--this.count){for(var t=this.cache,e=t.gl,r=this.programs,n=0,i=r.length;n<i;++n){var a=t.programs[r[n]];a&&(delete t.programs[n],e.deleteProgram(a))}e.deleteShader(this.shader),delete t.shaders[this.type===e.FRAGMENT_SHADER|0][this.src]}};var c=l.prototype;function u(t){var e=a.get(t);return e||(e=new l(t),a.set(t,e)),e}c.getShaderReference=function(t,e){var r=this.gl,a=this.shaders[t===r.FRAGMENT_SHADER|0],l=a[e];if(l&&r.isShader(l.shader))l.count+=1;else{var c=function(t,e,r){var a=t.createShader(e);if(t.shaderSource(a,r),t.compileShader(a),!t.getShaderParameter(a,t.COMPILE_STATUS)){var o=t.getShaderInfoLog(a);try{var s=i(o,r,e)}catch(t){throw console.warn(\"Failed to format compiler error: \"+t),new n(o,\"Error compiling shader:\\n\"+o)}throw new n(o,s.short,s.long)}return a}(r,t,e);l=a[e]=new s(o++,e,t,c,[],1,this)}return l},c.getProgram=function(t,e,r,i){var a=[t.id,e.id,r.join(\":\"),i.join(\":\")].join(\"@\"),o=this.programs[a];return o&&this.gl.isProgram(o)||(this.programs[a]=o=function(t,e,r,i,a){var o=t.createProgram();t.attachShader(o,e),t.attachShader(o,r);for(var s=0;s<i.length;++s)t.bindAttribLocation(o,a[s],i[s]);if(t.linkProgram(o),!t.getProgramParameter(o,t.LINK_STATUS)){var l=t.getProgramInfoLog(o);throw new n(l,\"Error linking program: \"+l)}return o}(this.gl,t.shader,e.shader,r,i),t.programs.push(a),e.programs.push(a)),o}},{\"./GLError\":302,\"gl-format-compiler-error\":250,\"weakmap-shim\":555}],308:[function(t,e,r){\"use strict\";function n(t){this.plot=t,this.enable=[!0,!0,!1,!1],this.width=[1,1,1,1],this.color=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.center=[1/0,1/0]}e.exports=function(t,e){var r=new n(t);return r.update(e),t.addOverlay(r),r};var i=n.prototype;i.update=function(t){t=t||{},this.enable=(t.enable||[!0,!0,!1,!1]).slice(),this.width=(t.width||[1,1,1,1]).slice(),this.color=(t.color||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]).map(function(t){return t.slice()}),this.center=(t.center||[1/0,1/0]).slice(),this.plot.setOverlayDirty()},i.draw=function(){var t=this.enable,e=this.width,r=this.color,n=this.center,i=this.plot,a=i.line,o=i.dataBox,s=i.viewBox;if(a.bind(),o[0]<=n[0]&&n[0]<=o[2]&&o[1]<=n[1]&&n[1]<=o[3]){var l=s[0]+(n[0]-o[0])/(o[2]-o[0])*(s[2]-s[0]),c=s[1]+(n[1]-o[1])/(o[3]-o[1])*(s[3]-s[1]);t[0]&&a.drawLine(l,c,s[0],c,e[0],r[0]),t[1]&&a.drawLine(l,c,l,s[1],e[1],r[1]),t[2]&&a.drawLine(l,c,s[2],c,e[2],r[2]),t[3]&&a.drawLine(l,c,l,s[3],e[3],r[3])}},i.dispose=function(){this.plot.removeOverlay(this)}},{}],309:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, color;\\nattribute float weight;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 coordinates[3];\\nuniform vec4 colors[3];\\nuniform vec2 screenShape;\\nuniform float lineWidth;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vertexPosition = mix(coordinates[0],\\n    mix(coordinates[2], coordinates[1], 0.5 * (position + 1.0)), abs(position));\\n\\n  vec4 clipPos = projection * view * model * vec4(vertexPosition, 1.0);\\n  vec2 clipOffset = (projection * view * model * vec4(color, 0.0)).xy;\\n  vec2 delta = weight * clipOffset * screenShape;\\n  vec2 lineOffset = normalize(vec2(delta.y, -delta.x)) / screenShape;\\n\\n  gl_Position   = vec4(clipPos.xy + clipPos.w * 0.5 * lineWidth * lineOffset, clipPos.z, clipPos.w);\\n  fragColor     = color.x * colors[0] + color.y * colors[1] + color.z * colors[2];\\n}\\n\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  gl_FragColor = fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec3\"},{name:\"weight\",type:\"float\"}])}},{\"gl-shader\":301,glslify:409}],310:[function(t,e,r){\"use strict\";var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\");e.exports=function(t,e){var r=[];function o(t,e,n,i,a,o){var s=[t,e,n,0,0,0,1];s[i+3]=1,s[i]=a,r.push.apply(r,s),s[6]=-1,r.push.apply(r,s),s[i]=o,r.push.apply(r,s),r.push.apply(r,s),s[6]=1,r.push.apply(r,s),s[i]=a,r.push.apply(r,s)}o(0,0,0,0,0,1),o(0,0,0,1,0,1),o(0,0,0,2,0,1),o(1,0,0,1,-1,1),o(1,0,0,2,-1,1),o(0,1,0,0,-1,1),o(0,1,0,2,-1,1),o(0,0,1,0,-1,1),o(0,0,1,1,-1,1);var l=n(t,r),c=i(t,[{type:t.FLOAT,buffer:l,size:3,offset:0,stride:28},{type:t.FLOAT,buffer:l,size:3,offset:12,stride:28},{type:t.FLOAT,buffer:l,size:1,offset:24,stride:28}]),u=a(t);u.attributes.position.location=0,u.attributes.color.location=1,u.attributes.weight.location=2;var h=new s(t,l,c,u);return h.update(e),h};var o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n,this.pixelRatio=1,this.bounds=[[-1e3,-1e3,-1e3],[1e3,1e3,1e3]],this.position=[0,0,0],this.lineWidth=[2,2,2],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.enabled=[!0,!0,!0],this.drawSides=[!0,!0,!0],this.axes=null}var l=s.prototype,c=[0,0,0],u=[0,0,0],h=[0,0];l.isTransparent=function(){return!1},l.drawTransparent=function(t){},l.draw=function(t){var e=this.gl,r=this.vao,n=this.shader;r.bind(),n.bind();var i,a=t.model||o,s=t.view||o,l=t.projection||o;this.axes&&(i=this.axes.lastCubeProps.axis);for(var f=c,p=u,d=0;d<3;++d)i&&i[d]<0?(f[d]=this.bounds[0][d],p[d]=this.bounds[1][d]):(f[d]=this.bounds[1][d],p[d]=this.bounds[0][d]);h[0]=e.drawingBufferWidth,h[1]=e.drawingBufferHeight,n.uniforms.model=a,n.uniforms.view=s,n.uniforms.projection=l,n.uniforms.coordinates=[this.position,f,p],n.uniforms.colors=this.colors,n.uniforms.screenShape=h;for(d=0;d<3;++d)n.uniforms.lineWidth=this.lineWidth[d]*this.pixelRatio,this.enabled[d]&&(r.draw(e.TRIANGLES,6,6*d),this.drawSides[d]&&r.draw(e.TRIANGLES,12,18+12*d));r.unbind()},l.update=function(t){t&&(\"bounds\"in t&&(this.bounds=t.bounds),\"position\"in t&&(this.position=t.position),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"colors\"in t&&(this.colors=t.colors),\"enabled\"in t&&(this.enabled=t.enabled),\"drawSides\"in t&&(this.drawSides=t.drawSides))},l.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders/index\":309,\"gl-buffer\":241,\"gl-vao\":327}],311:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\nuniform float vectorScale;\\nuniform float tubeScale;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * tubePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal,0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(tubePosition, 1.0);\\n  vec4 t_position  = view * tubePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = tubePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular\\n            , opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data\\n           , f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform float tubeScale;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  gl_Position = projection * view * tubePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec4\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec4\"}]}},{glslify:409}],312:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),h=t(\"colormap\"),f=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./shaders\"),g=d.meshShader,v=d.pickShader,m=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function y(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,y,x,b,_,w,k,T){this.gl=t,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=i,this.triangleVectors=a,this.triangleColors=s,this.triangleNormals=c,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=u,this.triangleCount=0,this.lineWidth=1,this.edgePositions=h,this.edgeColors=p,this.edgeUVs=d,this.edgeIds=f,this.edgeVAO=g,this.edgeCount=0,this.pointPositions=v,this.pointColors=x,this.pointUVs=b,this.pointSizes=_,this.pointIds=y,this.pointVAO=w,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=k,this.contourVAO=T,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!1,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.tubeScale=1,this._model=m,this._view=m,this._projection=m,this._resolution=[1,1],this.pixelRatio=1}var x=y.prototype;function b(t){var e=n(t,v.vertex,v.fragment,null,v.attributes);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.vector.location=5,e}x.isOpaque=function(){return this.opacity>=1},x.isTransparent=function(){return this.opacity<1},x.pickSlots=1,x.setPickBase=function(t){this.pickId=t},x.highlight=function(t){if(t&&this.contourEnable){for(var e=f(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var h=c[0];2===c.length&&(h=c[u]);for(var d=n[h][0],g=n[h][1],v=i[h],m=1-v,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=v*y[b]+m*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},x.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=h({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return u(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,i=t.vectors;if(n&&r&&i){void 0!==t.tubeScale&&(this.tubeScale=t.tubeScale);var a=[],l=[],c=[],f=[],p=[],d=[],g=[],v=[],m=[],y=[],x=[],b=[],_=[],w=[],k=[];this.cells=r,this.positions=n,this.vectors=i;var T=t.vertexNormals,A=t.cellNormals,M=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,S=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!A&&(A=s.faceNormals(r,n,S)),A||T||(T=s.vertexNormals(r,n,M));var E=t.vertexColors,C=t.cellColors,L=t.meshColor||[1,1,1,1],P=t.vertexUVs,O=t.vertexIntensity,z=t.cellUVs,I=t.cellIntensity,D=1/0,R=-1/0;if(!P&&!z)if(O)if(t.vertexIntensityBounds)D=+t.vertexIntensityBounds[0],R=+t.vertexIntensityBounds[1];else for(var F=0;F<O.length;++F){var B=O[F];D=Math.min(D,B),R=Math.max(R,B)}else if(I)for(F=0;F<I.length;++F){B=I[F];D=Math.min(D,B),R=Math.max(R,B)}else for(F=0;F<n.length;++F){B=n[F][2];D=Math.min(D,B),R=Math.max(R,B)}this.intensity=O||(I?function(t,e,r){for(var n=new Array(e),i=0;i<e;++i)n[i]=0;var a=t.length;for(i=0;i<a;++i)for(var o=t[i],s=0;s<o.length;++s)n[o[s]]=r[i];return n}(r,n.length,I):function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n));var N=t.pointSizes,j=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(F=0;F<n.length;++F)for(var U=n[F],V=0;V<3;++V)!isNaN(U[V])&&isFinite(U[V])&&(this.bounds[0][V]=Math.min(this.bounds[0][V],U[V]),this.bounds[1][V]=Math.max(this.bounds[1][V],U[V]));var q=0,H=0,G=0;t:for(F=0;F<r.length;++F){var Y=r[F];switch(Y.length){case 1:for(U=n[X=Y[0]],V=0;V<3;++V)if(isNaN(U[V])||!isFinite(U[V]))continue t;x.push(U[0],U[1],U[2],U[3]),3===(Z=E?E[X]:C?C[F]:L).length?b.push(Z[0],Z[1],Z[2],1):b.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],_.push(J[0],J[1]),N?w.push(N[X]):w.push(j),k.push(F),G+=1;break;case 2:for(V=0;V<2;++V){U=n[X=Y[V]];for(var W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t}for(V=0;V<2;++V){U=n[X=Y[V]];g.push(U[0],U[1],U[2]),3===(Z=E?E[X]:C?C[F]:L).length?v.push(Z[0],Z[1],Z[2],1):v.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],m.push(J[0],J[1]),y.push(F)}H+=1;break;case 3:for(V=0;V<3;++V)for(U=n[X=Y[V]],W=0;W<3;++W)if(isNaN(U[W])||!isFinite(U[W]))continue t;for(V=0;V<3;++V){var X;U=n[X=Y[2-V]];a.push(U[0],U[1],U[2],U[3]);var Z,J,K,$=i[X];l.push($[0],$[1],$[2],$[3]),3===(Z=E?E[X]:C?C[F]:L).length?c.push(Z[0],Z[1],Z[2],1):c.push(Z[0],Z[1],Z[2],Z[3]),J=P?P[X]:O?[(O[X]-D)/(R-D),0]:z?z[F]:I?[(I[F]-D)/(R-D),0]:[(U[2]-D)/(R-D),0],p.push(J[0],J[1]),K=T?T[X]:A[F],f.push(K[0],K[1],K[2]),d.push(F)}q+=1}}this.pointCount=G,this.edgeCount=H,this.triangleCount=q,this.pointPositions.update(x),this.pointColors.update(b),this.pointUVs.update(_),this.pointSizes.update(w),this.pointIds.update(new Uint32Array(k)),this.edgePositions.update(g),this.edgeColors.update(v),this.edgeUVs.update(m),this.edgeIds.update(new Uint32Array(y)),this.trianglePositions.update(a),this.triangleVectors.update(l),this.triangleColors.update(c),this.triangleUVs.update(p),this.triangleNormals.update(f),this.triangleIds.update(new Uint32Array(d))}},x.drawTransparent=x.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:m.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,tubeScale:this.tubeScale,contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var f=u[12+o],p=0;p<3;++p)f+=u[4*p+o]*this.lightPosition[p];s.lightPosition[o]=f/h}if(this.triangleCount>0){var d=this.triShader;d.bind(),d.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},x.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||m,n=t.view||m,i=t.projection||m,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:i,clipBounds:a,tubeScale:this.tubeScale,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind())},x.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3);return{index:e,position:n,intensity:this.intensity[r[1]],velocity:this.vectors[r[1]].slice(0,3),divergence:this.vectors[r[1]][3],dataCoordinate:n}},x.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose()},e.exports=function(t,e){1===arguments.length&&(t=(e=t).gl);var r=e.triShader||function(t){var e=n(t,g.vertex,g.fragment,null,g.attributes);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.vector.location=5,e}(t),s=b(t),l=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));l.generateMipmap(),l.minFilter=t.LINEAR_MIPMAP_LINEAR,l.magFilter=t.LINEAR;var c=i(t),h=i(t),f=i(t),p=i(t),d=i(t),v=i(t),m=a(t,[{buffer:c,type:t.FLOAT,size:4},{buffer:v,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:f,type:t.FLOAT,size:4},{buffer:p,type:t.FLOAT,size:2},{buffer:d,type:t.FLOAT,size:3},{buffer:h,type:t.FLOAT,size:4}]),x=i(t),_=i(t),w=i(t),k=i(t),T=a(t,[{buffer:x,type:t.FLOAT,size:3},{buffer:k,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:_,type:t.FLOAT,size:4},{buffer:w,type:t.FLOAT,size:2}]),A=i(t),M=i(t),S=i(t),E=i(t),C=i(t),L=a(t,[{buffer:A,type:t.FLOAT,size:3},{buffer:C,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:M,type:t.FLOAT,size:4},{buffer:S,type:t.FLOAT,size:2},{buffer:E,type:t.FLOAT,size:1}]),P=i(t),O=new y(t,l,r,s,c,h,v,f,p,d,m,x,k,_,w,T,A,C,M,S,E,L,P,a(t,[{buffer:P,type:t.FLOAT,size:3}]));return O.update(e),O}},{\"./shaders\":311,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-shader\":301,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,normals:453,\"simplicial-complex-contour\":518,\"typedarray-pool\":545}],313:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\"),i=t(\"gl-vec4\"),a=function(t,e,r,a){for(var o=0,s=0;s<t.length;s++)for(var l=t[s].velocities,c=0;c<l.length;c++){var u=n.length(l[c]);u>o&&(o=u)}var h=t.map(function(t){return function(t,e,r,a){var o,s,l,c=t.points,u=t.velocities,h=t.divergences;n.set(n.create(),0,1,0),n.create(),n.create();n.create();for(var f=[],p=[],d=[],g=[],v=[],m=[],y=0,x=0,b=i.create(),_=i.create(),w=0;w<c.length;w++){o=c[w],s=u[w],l=h[w],0===e&&(l=.05*r),x=n.length(s)/a,b=i.create(),n.copy(b,s),b[3]=l;for(var k=0;k<8;k++)v[k]=[o[0],o[1],o[2],k];if(g.length>0)for(k=0;k<8;k++){var T=(k+1)%8;f.push(g[k],v[k],v[T],v[T],g[T],g[k]),d.push(_,b,b,b,_,_),m.push(y,x,x,x,y,y),p.push([f.length-6,f.length-5,f.length-4],[f.length-3,f.length-2,f.length-1])}var A=g;g=v,v=A,A=_,_=b,b=A,A=y,y=x,x=A}return{positions:f,cells:p,vectors:d,vertexIntensity:m}}(t,r,a,o)}),f=[],p=[],d=[],g=[];for(s=0;s<h.length;s++){var v=h[s],m=f.length;f=f.concat(v.positions),d=d.concat(v.vectors),g=g.concat(v.vertexIntensity);for(c=0;c<v.cells.length;c++){var y=v.cells[c],x=[];p.push(x);for(var b=0;b<y.length;b++)x.push(y[b]+m)}}return{positions:f,cells:p,vectors:d,vertexIntensity:g,colormap:e}},o=function(t,e){var r=n.create(),i=1e-4;n.add(r,t,[i,0,0]);var a=this.getVelocity(r);n.subtract(a,a,e),n.scale(a,a,1e4),n.add(r,t,[0,i,0]);var o=this.getVelocity(r);n.subtract(o,o,e),n.scale(o,o,1e4),n.add(r,t,[0,0,i]);var s=this.getVelocity(r);return n.subtract(s,s,e),n.scale(s,s,1e4),n.add(r,a,o),n.add(r,r,s),r},s=function(t){return f(t,this.vectors,this.meshgrid,this.clampBorders)},l=function(t,e){for(var r=0;r<t.length;r++){var n=t[r];if(n===e)return r;if(n>e)return r-1}return r},c=n.create(),u=n.create(),h=function(t,e,r){return t<e?e:t>r?r:t},f=function(t,e,r,i){var a=t[0],o=t[1],s=t[2],f=r[0].length,p=r[1].length,d=r[2].length,g=l(r[0],a),v=l(r[1],o),m=l(r[2],s),y=g+1,x=v+1,b=m+1;if(r[0][g]===a&&(y=g),r[1][v]===o&&(x=v),r[2][m]===s&&(b=m),i&&(g=h(g,0,f-1),y=h(y,0,f-1),v=h(v,0,p-1),x=h(x,0,p-1),m=h(m,0,d-1),b=h(b,0,d-1)),g<0||v<0||m<0||y>=f||x>=p||b>=d)return n.create();var _=(a-r[0][g])/(r[0][y]-r[0][g]),w=(o-r[1][v])/(r[1][x]-r[1][v]),k=(s-r[2][m])/(r[2][b]-r[2][m]);(_<0||_>1||isNaN(_))&&(_=0),(w<0||w>1||isNaN(w))&&(w=0),(k<0||k>1||isNaN(k))&&(k=0);var T=m*f*p,A=b*f*p,M=v*f,S=x*f,E=g,C=y,L=e[M+T+E],P=e[M+T+C],O=e[S+T+E],z=e[S+T+C],I=e[M+A+E],D=e[M+A+C],R=e[S+A+E],F=e[S+A+C],B=n.create();return n.lerp(B,L,P,_),n.lerp(c,O,z,_),n.lerp(B,B,c,w),n.lerp(c,I,D,_),n.lerp(u,R,F,_),n.lerp(c,c,u,w),n.lerp(B,B,c,k),B},p=function(t){var e=1/0;t.sort(function(t,e){return t-e});for(var r=1;r<t.length;r++){var n=Math.abs(t[r]-t[r-1]);n<e&&(e=n)}return e};e.exports=function(t,e){var r=t.startingPositions,i=t.maxLength||1e3,l=t.tubeSize||1,c=t.absoluteTubeSize;t.getDivergence||(t.getDivergence=o),t.getVelocity||(t.getVelocity=s),void 0===t.clampBorders&&(t.clampBorders=!0);var u=[],h=e[0][0],f=e[0][1],d=e[0][2],g=e[1][0],v=e[1][1],m=e[1][2],y=function(t,e){var r=e[0],n=e[1],i=e[2];return r>=h&&r<=g&&n>=f&&n<=v&&i>=d&&i<=m},x=10*n.distance(e[0],e[1])/i,b=x*x,_=1,w=0;n.create();r.length>=2&&(_=function(t){for(var e=[],r=[],n=[],i={},a={},o={},s=0;s<t.length;s++){var l=t[s],c=l[0],u=l[1],h=l[2];i[c]||(e.push(c),i[c]=!0),a[u]||(r.push(u),a[u]=!0),o[h]||(n.push(h),o[h]=!0)}var f=p(e),d=p(r),g=p(n),v=Math.min(f,d,g);return isFinite(v)?v:1}(r));for(var k=0;k<r.length;k++){var T=n.create();n.copy(T,r[k]);var A=[T],M=[],S=t.getVelocity(T),E=T;M.push(S);var C=[],L=t.getDivergence(T,S);(I=n.length(L))>w&&!isNaN(I)&&isFinite(I)&&(w=I),C.push(I),u.push({points:A,velocities:M,divergences:C});for(var P=0;P<100*i&&A.length<i&&y(0,T);){P++;var O=n.clone(S),z=n.squaredLength(O);if(0===z)break;if(z>b&&n.scale(O,O,x/Math.sqrt(z)),n.add(O,O,T),S=t.getVelocity(O),n.squaredDistance(E,O)-b>-1e-4*b){A.push(O),E=O,M.push(S);L=t.getDivergence(O,S);(I=n.length(L))>w&&!isNaN(I)&&isFinite(I)&&(w=I),C.push(I)}T=O}}for(k=0;k<C.length;k++){var I=C[k];!isNaN(I)&&isFinite(I)||(C[k]=w)}var D=a(u,t.colormap,w,_);return c?D.tubeScale=c:(0===w&&(w=1),D.tubeScale=.5*l*_/w),D},e.exports.createTubeMesh=t(\"./lib/tubemesh\")},{\"./lib/tubemesh\":312,\"gl-vec3\":346,\"gl-vec4\":382}],314:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute vec3 f;\\nattribute vec3 normal;\\n\\nuniform vec3 objectOffset;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 lightPosition, eyePosition;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 localCoordinate = vec3(uv.zw, f.x);\\n  worldCoordinate = objectOffset + localCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n  vec4 clipPosition = projection * view * worldPosition;\\n  gl_Position = clipPosition;\\n  kill = f.y;\\n  value = f.z;\\n  planeCoordinate = uv.xy;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * worldPosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  lightDirection = lightPosition - cameraCoordinate.xyz;\\n  eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  surfaceNormal  = normalize((vec4(normal,0) * inverseModel).xyz);\\n}\\n\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat beckmannSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness) {\\n  return beckmannDistribution(dot(surfaceNormal, normalize(lightDirection + viewDirection)), roughness);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 lowerBound, upperBound;\\nuniform float contourTint;\\nuniform vec4 contourColor;\\nuniform sampler2D colormap;\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform float vertexColor;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec3 N = normalize(surfaceNormal);\\n  vec3 V = normalize(eyeDirection);\\n  vec3 L = normalize(lightDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = max(beckmannSpecular(L, V, N, roughness), 0.);\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  //decide how to interpolate color \\u2014 in vertex or in fragment\\n  vec4 surfaceColor =\\n    step(vertexColor, .5) * texture2D(colormap, vec2(value, value)) +\\n    step(.5, vertexColor) * vColor;\\n\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = mix(litColor, contourColor, contourTint) * opacity;\\n}\\n\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute float f;\\n\\nuniform vec3 objectOffset;\\nuniform mat3 permutation;\\nuniform mat4 model, view, projection;\\nuniform float height, zOffset;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 dataCoordinate = permutation * vec3(uv.xy, height);\\n  worldCoordinate = objectOffset + dataCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n\\n  vec4 clipPosition = projection * view * worldPosition;\\n  clipPosition.z += zOffset;\\n\\n  gl_Position = clipPosition;\\n  value = f + objectOffset.z;\\n  kill = -1.0;\\n  planeCoordinate = uv.zw;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Don't do lighting for contours\\n  surfaceNormal   = vec3(1,0,0);\\n  eyeDirection    = vec3(0,1,0);\\n  lightDirection  = vec3(0,0,1);\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec2 shape;\\nuniform vec3 clipBounds[2];\\nuniform float pickId;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 surfaceNormal;\\n\\nvec2 splitFloat(float v) {\\n  float vh = 255.0 * v;\\n  float upper = floor(vh);\\n  float lower = fract(vh);\\n  return vec2(upper / 255.0, floor(lower * 16.0) / 16.0);\\n}\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec2 ux = splitFloat(planeCoordinate.x / shape.x);\\n  vec2 uy = splitFloat(planeCoordinate.y / shape.y);\\n  gl_FragColor = vec4(pickId, ux.x, uy.x, ux.y + (uy.y/16.0));\\n}\\n\"]);r.createShader=function(t){var e=n(t,a,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createPickShader=function(t){var e=n(t,a,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createContourShader=function(t){var e=n(t,s,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e},r.createPickContourShader=function(t){var e=n(t,s,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e}},{\"gl-shader\":301,glslify:409}],315:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],316:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=y(e),n=b(e),s=x(e),l=_(e),c=i(e),u=a(e,[{buffer:c,size:4,stride:w,offset:0},{buffer:c,size:3,stride:w,offset:16},{buffer:c,size:3,stride:w,offset:28}]),h=i(e),f=a(e,[{buffer:h,size:4,stride:20,offset:0},{buffer:h,size:1,stride:20,offset:16}]),p=i(e),d=a(e,[{buffer:p,size:2,type:e.FLOAT}]),g=o(e,1,S,e.RGBA,e.UNSIGNED_BYTE);g.minFilter=e.LINEAR,g.magFilter=e.LINEAR;var v=new E(e,[0,0],[[0,0,0],[0,0,0]],r,n,c,u,g,s,l,h,f,p,d,[0,0,0]),m={levels:[[],[],[]]};for(var k in t)m[k]=t[k];return m.colormap=m.colormap||\"jet\",v.update(m),v};var n=t(\"bit-twiddle\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"typedarray-pool\"),l=t(\"colormap\"),c=t(\"ndarray-ops\"),u=t(\"ndarray-pack\"),h=t(\"ndarray\"),f=t(\"surface-nets\"),p=t(\"gl-mat4/multiply\"),d=t(\"gl-mat4/invert\"),g=t(\"binary-search-bounds\"),v=t(\"ndarray-gradient\"),m=t(\"./lib/shaders\"),y=m.createShader,x=m.createContourShader,b=m.createPickShader,_=m.createPickContourShader,w=40,k=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1],T=[[0,0],[0,1],[1,0],[1,1],[1,0],[0,1]],A=[[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0]];function M(t,e,r,n,i){this.position=t,this.index=e,this.uv=r,this.level=n,this.dataCoordinate=i}!function(){for(var t=0;t<3;++t){var e=A[t],r=(t+2)%3;e[(t+1)%3+0]=1,e[r+3]=1,e[t+6]=1}}();var S=256;function E(t,e,r,n,i,a,o,l,c,u,f,p,d,g,v){this.gl=t,this.shape=e,this.bounds=r,this.objectOffset=v,this.intensityBounds=[],this._shader=n,this._pickShader=i,this._coordinateBuffer=a,this._vao=o,this._colorMap=l,this._contourShader=c,this._contourPickShader=u,this._contourBuffer=f,this._contourVAO=p,this._contourOffsets=[[],[],[]],this._contourCounts=[[],[],[]],this._vertexCount=0,this._pickResult=new M([0,0,0],[0,0],[0,0],[0,0,0],[0,0,0]),this._dynamicBuffer=d,this._dynamicVAO=g,this._dynamicOffsets=[0,0,0],this._dynamicCounts=[0,0,0],this.contourWidth=[1,1,1],this.contourLevels=[[1],[1],[1]],this.contourTint=[0,0,0],this.contourColor=[[.5,.5,.5,1],[.5,.5,.5,1],[.5,.5,.5,1]],this.showContour=!0,this.showSurface=!0,this.enableHighlight=[!0,!0,!0],this.highlightColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.highlightTint=[1,1,1],this.highlightLevel=[-1,-1,-1],this.enableDynamic=[!0,!0,!0],this.dynamicLevel=[NaN,NaN,NaN],this.dynamicColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.dynamicTint=[1,1,1],this.dynamicWidth=[1,1,1],this.axesBounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.surfaceProject=[!1,!1,!1],this.contourProject=[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],this.colorBounds=[!1,!1],this._field=[h(s.mallocFloat(1024),[0,0]),h(s.mallocFloat(1024),[0,0]),h(s.mallocFloat(1024),[0,0])],this.pickId=1,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.snapToData=!1,this.pixelRatio=1,this.opacity=1,this.lightPosition=[10,1e4,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.vertexColor=0,this.dirty=!0}var C=E.prototype;C.isTransparent=function(){return this.opacity<1},C.isOpaque=function(){if(this.opacity>=1)return!0;for(var t=0;t<3;++t)if(this._contourCounts[t].length>0||this._dynamicCounts[t]>0)return!0;return!1},C.pickSlots=1,C.setPickBase=function(t){this.pickId=t};var L=[0,0,0],P={showSurface:!1,showContour:!1,projections:[k.slice(),k.slice(),k.slice()],clipBounds:[[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]]]};function O(t,e){var r,n,i,a=e.axes&&e.axes.lastCubeProps.axis||L,o=e.showSurface,s=e.showContour;for(r=0;r<3;++r)for(o=o||e.surfaceProject[r],n=0;n<3;++n)s=s||e.contourProject[r][n];for(r=0;r<3;++r){var l=P.projections[r];for(n=0;n<16;++n)l[n]=0;for(n=0;n<4;++n)l[5*n]=1;l[5*r]=0,l[12+r]=e.axesBounds[+(a[r]>0)][r],p(l,t.model,l);var c=P.clipBounds[r];for(i=0;i<2;++i)for(n=0;n<3;++n)c[i][n]=t.clipBounds[i][n];c[0][r]=-1e8,c[1][r]=1e8}return P.showSurface=o,P.showContour=s,P}var z={model:k,view:k,projection:k,inverseModel:k.slice(),lowerBound:[0,0,0],upperBound:[0,0,0],colorMap:0,clipBounds:[[0,0,0],[0,0,0]],height:0,contourTint:0,contourColor:[0,0,0,1],permutation:[1,0,0,0,1,0,0,0,1],zOffset:-1e-4,objectOffset:[0,0,0],kambient:1,kdiffuse:1,kspecular:1,lightPosition:[1e3,1e3,1e3],eyePosition:[0,0,0],roughness:1,fresnel:1,opacity:1,vertexColor:0},I=k.slice(),D=[1,0,0,0,1,0,0,0,1];function R(t,e){t=t||{};var r=this.gl;r.disable(r.CULL_FACE),this._colorMap.bind(0);var n=z;n.model=t.model||k,n.view=t.view||k,n.projection=t.projection||k,n.lowerBound=[this.bounds[0][0],this.bounds[0][1],this.colorBounds[0]||this.bounds[0][2]],n.upperBound=[this.bounds[1][0],this.bounds[1][1],this.colorBounds[1]||this.bounds[1][2]],n.objectOffset=this.objectOffset,n.contourColor=this.contourColor[0],n.inverseModel=d(n.inverseModel,n.model);for(var i=0;i<2;++i)for(var a=n.clipBounds[i],o=0;o<3;++o)a[o]=Math.min(Math.max(this.clipBounds[i][o],-1e8),1e8);n.kambient=this.ambientLight,n.kdiffuse=this.diffuseLight,n.kspecular=this.specularLight,n.roughness=this.roughness,n.fresnel=this.fresnel,n.opacity=this.opacity,n.height=0,n.permutation=D,n.vertexColor=this.vertexColor;var s=I;for(p(s,n.view,n.model),p(s,n.projection,s),d(s,s),i=0;i<3;++i)n.eyePosition[i]=s[12+i]/s[15];var l=s[15];for(i=0;i<3;++i)l+=this.lightPosition[i]*s[4*i+3];for(i=0;i<3;++i){var c=s[12+i];for(o=0;o<3;++o)c+=s[4*o+i]*this.lightPosition[o];n.lightPosition[i]=c/l}var u=O(n,this);if(u.showSurface&&e===this.opacity<1){for(this._shader.bind(),this._shader.uniforms=n,this._vao.bind(),this.showSurface&&this._vertexCount&&this._vao.draw(r.TRIANGLES,this._vertexCount),i=0;i<3;++i)this.surfaceProject[i]&&this.vertexCount&&(this._shader.uniforms.model=u.projections[i],this._shader.uniforms.clipBounds=u.clipBounds[i],this._vao.draw(r.TRIANGLES,this._vertexCount));this._vao.unbind()}if(u.showContour&&!e){var h=this._contourShader;n.kambient=1,n.kdiffuse=0,n.kspecular=0,n.opacity=1,h.bind(),h.uniforms=n;var f=this._contourVAO;for(f.bind(),i=0;i<3;++i)for(h.uniforms.permutation=A[i],r.lineWidth(this.contourWidth[i]*this.pixelRatio),o=0;o<this.contourLevels[i].length;++o)o===this.highlightLevel[i]?(h.uniforms.contourColor=this.highlightColor[i],h.uniforms.contourTint=this.highlightTint[i]):0!==o&&o-1!==this.highlightLevel[i]||(h.uniforms.contourColor=this.contourColor[i],h.uniforms.contourTint=this.contourTint[i]),this._contourCounts[i][o]&&(h.uniforms.height=this.contourLevels[i][o],f.draw(r.LINES,this._contourCounts[i][o],this._contourOffsets[i][o]));for(i=0;i<3;++i)for(h.uniforms.model=u.projections[i],h.uniforms.clipBounds=u.clipBounds[i],o=0;o<3;++o)if(this.contourProject[i][o]){h.uniforms.permutation=A[o],r.lineWidth(this.contourWidth[o]*this.pixelRatio);for(var g=0;g<this.contourLevels[o].length;++g)g===this.highlightLevel[o]?(h.uniforms.contourColor=this.highlightColor[o],h.uniforms.contourTint=this.highlightTint[o]):0!==g&&g-1!==this.highlightLevel[o]||(h.uniforms.contourColor=this.contourColor[o],h.uniforms.contourTint=this.contourTint[o]),this._contourCounts[o][g]&&(h.uniforms.height=this.contourLevels[o][g],f.draw(r.LINES,this._contourCounts[o][g],this._contourOffsets[o][g]))}for(f.unbind(),(f=this._dynamicVAO).bind(),i=0;i<3;++i)if(0!==this._dynamicCounts[i])for(h.uniforms.model=n.model,h.uniforms.clipBounds=n.clipBounds,h.uniforms.permutation=A[i],r.lineWidth(this.dynamicWidth[i]*this.pixelRatio),h.uniforms.contourColor=this.dynamicColor[i],h.uniforms.contourTint=this.dynamicTint[i],h.uniforms.height=this.dynamicLevel[i],f.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]),o=0;o<3;++o)this.contourProject[o][i]&&(h.uniforms.model=u.projections[o],h.uniforms.clipBounds=u.clipBounds[o],f.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]));f.unbind()}}C.draw=function(t){return R.call(this,t,!1)},C.drawTransparent=function(t){return R.call(this,t,!0)};var F={model:k,view:k,projection:k,inverseModel:k,clipBounds:[[0,0,0],[0,0,0]],height:0,shape:[0,0],pickId:0,lowerBound:[0,0,0],upperBound:[0,0,0],zOffset:0,objectOffset:[0,0,0],permutation:[1,0,0,0,1,0,0,0,1],lightPosition:[0,0,0],eyePosition:[0,0,0]};function B(t,e){return Array.isArray(t)?[e(t[0]),e(t[1]),e(t[2])]:[e(t),e(t),e(t)]}function N(t){return Array.isArray(t)?3===t.length?[t[0],t[1],t[2],1]:[t[0],t[1],t[2],t[3]]:[0,0,0,1]}function j(t){if(Array.isArray(t)){if(Array.isArray(t))return[N(t[0]),N(t[1]),N(t[2])];var e=N(t);return[e.slice(),e.slice(),e.slice()]}}C.drawPick=function(t){t=t||{};var e=this.gl;e.disable(e.CULL_FACE);var r=F;r.model=t.model||k,r.view=t.view||k,r.projection=t.projection||k,r.shape=this._field[2].shape,r.pickId=this.pickId/255,r.lowerBound=this.bounds[0],r.upperBound=this.bounds[1],r.objectOffset=this.objectOffset,r.permutation=D;for(var n=0;n<2;++n)for(var i=r.clipBounds[n],a=0;a<3;++a)i[a]=Math.min(Math.max(this.clipBounds[n][a],-1e8),1e8);var o=O(r,this);if(o.showSurface){for(this._pickShader.bind(),this._pickShader.uniforms=r,this._vao.bind(),this._vao.draw(e.TRIANGLES,this._vertexCount),n=0;n<3;++n)this.surfaceProject[n]&&(this._pickShader.uniforms.model=o.projections[n],this._pickShader.uniforms.clipBounds=o.clipBounds[n],this._vao.draw(e.TRIANGLES,this._vertexCount));this._vao.unbind()}if(o.showContour){var s=this._contourPickShader;s.bind(),s.uniforms=r;var l=this._contourVAO;for(l.bind(),a=0;a<3;++a)for(e.lineWidth(this.contourWidth[a]*this.pixelRatio),s.uniforms.permutation=A[a],n=0;n<this.contourLevels[a].length;++n)this._contourCounts[a][n]&&(s.uniforms.height=this.contourLevels[a][n],l.draw(e.LINES,this._contourCounts[a][n],this._contourOffsets[a][n]));for(n=0;n<3;++n)for(s.uniforms.model=o.projections[n],s.uniforms.clipBounds=o.clipBounds[n],a=0;a<3;++a)if(this.contourProject[n][a]){s.uniforms.permutation=A[a],e.lineWidth(this.contourWidth[a]*this.pixelRatio);for(var c=0;c<this.contourLevels[a].length;++c)this._contourCounts[a][c]&&(s.uniforms.height=this.contourLevels[a][c],l.draw(e.LINES,this._contourCounts[a][c],this._contourOffsets[a][c]))}l.unbind()}},C.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=this._field[2].shape,r=this._pickResult,n=e[0]*(t.value[0]+(t.value[2]>>4)/16)/255,i=Math.floor(n),a=n-i,o=e[1]*(t.value[1]+(15&t.value[2])/16)/255,s=Math.floor(o),l=o-s;i+=1,s+=1;var c=r.position;c[0]=c[1]=c[2]=0;for(var u=0;u<2;++u)for(var h=u?a:1-a,f=0;f<2;++f)for(var p=i+u,d=s+f,v=h*(f?l:1-l),m=0;m<3;++m)c[m]+=this._field[m].get(p,d)*v;for(var y=this._pickResult.level,x=0;x<3;++x)if(y[x]=g.le(this.contourLevels[x],c[x]),y[x]<0)this.contourLevels[x].length>0&&(y[x]=0);else if(y[x]<this.contourLevels[x].length-1){var b=this.contourLevels[x][y[x]],_=this.contourLevels[x][y[x]+1];Math.abs(b-c[x])>Math.abs(_-c[x])&&(y[x]+=1)}for(r.index[0]=a<.5?i:i+1,r.index[1]=l<.5?s:s+1,r.uv[0]=n/e[0],r.uv[1]=o/e[1],m=0;m<3;++m)r.dataCoordinate[m]=this._field[m].get(r.index[0],r.index[1]);return r},C.padField=function(t,e){var r=e.shape.slice(),n=t.shape.slice();c.assign(t.lo(1,1).hi(r[0],r[1]),e),c.assign(t.lo(1).hi(r[0],1),e.hi(r[0],1)),c.assign(t.lo(1,n[1]-1).hi(r[0],1),e.lo(0,r[1]-1).hi(r[0],1)),c.assign(t.lo(0,1).hi(1,r[1]),e.hi(1)),c.assign(t.lo(n[0]-1,1).hi(1,r[1]),e.lo(r[0]-1)),t.set(0,0,e.get(0,0)),t.set(0,n[1]-1,e.get(0,r[1]-1)),t.set(n[0]-1,0,e.get(r[0]-1,0)),t.set(n[0]-1,n[1]-1,e.get(r[0]-1,r[1]-1))},C.update=function(t){t=t||{},this.objectOffset=t.objectOffset||this.objectOffset,this.dirty=!0,\"contourWidth\"in t&&(this.contourWidth=B(t.contourWidth,Number)),\"showContour\"in t&&(this.showContour=B(t.showContour,Boolean)),\"showSurface\"in t&&(this.showSurface=!!t.showSurface),\"contourTint\"in t&&(this.contourTint=B(t.contourTint,Boolean)),\"contourColor\"in t&&(this.contourColor=j(t.contourColor)),\"contourProject\"in t&&(this.contourProject=B(t.contourProject,function(t){return B(t,Boolean)})),\"surfaceProject\"in t&&(this.surfaceProject=t.surfaceProject),\"dynamicColor\"in t&&(this.dynamicColor=j(t.dynamicColor)),\"dynamicTint\"in t&&(this.dynamicTint=B(t.dynamicTint,Number)),\"dynamicWidth\"in t&&(this.dynamicWidth=B(t.dynamicWidth,Number)),\"opacity\"in t&&(this.opacity=t.opacity),\"colorBounds\"in t&&(this.colorBounds=t.colorBounds),\"vertexColor\"in t&&(this.vertexColor=t.vertexColor?1:0);var e=t.field||t.coords&&t.coords[2]||null,r=!1;if(e||(e=this._field[2].shape[0]||this._field[2].shape[2]?this._field[2].lo(1,1).hi(this._field[2].shape[0]-2,this._field[2].shape[1]-2):this._field[2].hi(0,0)),\"field\"in t||\"coords\"in t){var i=(e.shape[0]+2)*(e.shape[1]+2);i>this._field[2].data.length&&(s.freeFloat(this._field[2].data),this._field[2].data=s.mallocFloat(n.nextPow2(i))),this._field[2]=h(this._field[2].data,[e.shape[0]+2,e.shape[1]+2]),this.padField(this._field[2],e),this.shape=e.shape.slice();for(var a=this.shape,o=0;o<2;++o)this._field[2].size>this._field[o].data.length&&(s.freeFloat(this._field[o].data),this._field[o].data=s.mallocFloat(this._field[2].size)),this._field[o]=h(this._field[o].data,[a[0]+2,a[1]+2]);if(t.coords){var p=t.coords;if(!Array.isArray(p)||3!==p.length)throw new Error(\"gl-surface: invalid coordinates for x/y\");for(o=0;o<2;++o){var d=p[o];for(b=0;b<2;++b)if(d.shape[b]!==a[b])throw new Error(\"gl-surface: coords have incorrect shape\");this.padField(this._field[o],d)}}else if(t.ticks){var g=t.ticks;if(!Array.isArray(g)||2!==g.length)throw new Error(\"gl-surface: invalid ticks\");for(o=0;o<2;++o){var m=g[o];if((Array.isArray(m)||m.length)&&(m=h(m)),m.shape[0]!==a[o])throw new Error(\"gl-surface: invalid tick length\");var y=h(m.data,a);y.stride[o]=m.stride[0],y.stride[1^o]=0,this.padField(this._field[o],y)}}else{for(o=0;o<2;++o){var x=[0,0];x[o]=1,this._field[o]=h(this._field[o].data,[a[0]+2,a[1]+2],x,0)}this._field[0].set(0,0,0);for(var b=0;b<a[0];++b)this._field[0].set(b+1,0,b);for(this._field[0].set(a[0]+1,0,a[0]-1),this._field[1].set(0,0,0),b=0;b<a[1];++b)this._field[1].set(0,b+1,b);this._field[1].set(0,a[1]+1,a[1]-1)}var _=this._field,w=h(s.mallocFloat(3*_[2].size*2),[3,a[0]+2,a[1]+2,2]);for(o=0;o<3;++o)v(w.pick(o),_[o],\"mirror\");var k=h(s.mallocFloat(3*_[2].size),[a[0]+2,a[1]+2,3]);for(o=0;o<a[0]+2;++o)for(b=0;b<a[1]+2;++b){var A=w.get(0,o,b,0),M=w.get(0,o,b,1),E=w.get(1,o,b,0),C=w.get(1,o,b,1),L=w.get(2,o,b,0),P=w.get(2,o,b,1),O=E*P-C*L,z=L*M-P*A,I=A*C-M*E,D=Math.sqrt(O*O+z*z+I*I);D<1e-8?(D=Math.max(Math.abs(O),Math.abs(z),Math.abs(I)))<1e-8?(I=1,z=O=0,D=1):D=1/D:D=1/Math.sqrt(D),k.set(o,b,0,O*D),k.set(o,b,1,z*D),k.set(o,b,2,I*D)}s.free(w.data);var R=[1/0,1/0,1/0],F=[-1/0,-1/0,-1/0],N=1/0,U=-1/0,V=(a[0]-1)*(a[1]-1)*6,q=s.mallocFloat(n.nextPow2(10*V)),H=0,G=0;for(o=0;o<a[0]-1;++o)t:for(b=0;b<a[1]-1;++b){for(var Y=0;Y<2;++Y)for(var W=0;W<2;++W)for(var X=0;X<3;++X){var Z=this._field[X].get(1+o+Y,1+b+W);if(isNaN(Z)||!isFinite(Z))continue t}for(X=0;X<6;++X){var J=o+T[X][0],K=b+T[X][1],$=this._field[0].get(J+1,K+1),Q=this._field[1].get(J+1,K+1);Z=this._field[2].get(J+1,K+1),O=k.get(J+1,K+1,0),z=k.get(J+1,K+1,1),I=k.get(J+1,K+1,2),t.intensity&&(tt=t.intensity.get(J,K));var tt=t.intensity?t.intensity.get(J,K):Z+this.objectOffset[2];q[H++]=J,q[H++]=K,q[H++]=$,q[H++]=Q,q[H++]=Z,q[H++]=0,q[H++]=tt,q[H++]=O,q[H++]=z,q[H++]=I,R[0]=Math.min(R[0],$+this.objectOffset[0]),R[1]=Math.min(R[1],Q+this.objectOffset[1]),R[2]=Math.min(R[2],Z+this.objectOffset[2]),N=Math.min(N,tt),F[0]=Math.max(F[0],$+this.objectOffset[0]),F[1]=Math.max(F[1],Q+this.objectOffset[1]),F[2]=Math.max(F[2],Z+this.objectOffset[2]),U=Math.max(U,tt),G+=1}}for(t.intensityBounds&&(N=+t.intensityBounds[0],U=+t.intensityBounds[1]),o=6;o<H;o+=10)q[o]=(q[o]-N)/(U-N);this._vertexCount=G,this._coordinateBuffer.update(q.subarray(0,H)),s.freeFloat(q),s.free(k.data),this.bounds=[R,F],this.intensity=t.intensity||this._field[2],this.intensityBounds[0]===N&&this.intensityBounds[1]===U||(r=!0),this.intensityBounds=[N,U]}if(\"levels\"in t){var et=t.levels;for(et=Array.isArray(et[0])?et.slice():[[],[],et],o=0;o<3;++o)et[o]=et[o].slice(),et[o].sort(function(t,e){return t-e});for(o=0;o<3;++o)for(b=0;b<et[o].length;++b)et[o][b]-=this.objectOffset[o];t:for(o=0;o<3;++o){if(et[o].length!==this.contourLevels[o].length){r=!0;break}for(b=0;b<et[o].length;++b)if(et[o][b]!==this.contourLevels[o][b]){r=!0;break t}}this.contourLevels=et}if(r){_=this._field,a=this.shape;for(var rt=[],nt=0;nt<3;++nt){var it=this.contourLevels[nt],at=[],ot=[],st=[0,0,0];for(o=0;o<it.length;++o){var lt=f(this._field[nt],it[o]);at.push(rt.length/5|0),G=0;t:for(b=0;b<lt.cells.length;++b){var ct=lt.cells[b];for(X=0;X<2;++X){var ut=lt.positions[ct[X]],ht=ut[0],ft=0|Math.floor(ht),pt=ht-ft,dt=ut[1],gt=0|Math.floor(dt),vt=dt-gt,mt=!1;e:for(var yt=0;yt<3;++yt){st[yt]=0;var xt=(nt+yt+1)%3;for(Y=0;Y<2;++Y){var bt=Y?pt:1-pt;for(J=0|Math.min(Math.max(ft+Y,0),a[0]),W=0;W<2;++W){var _t=W?vt:1-vt;if(K=0|Math.min(Math.max(gt+W,0),a[1]),Z=yt<2?this._field[xt].get(J,K):(this.intensity.get(J,K)-this.intensityBounds[0])/(this.intensityBounds[1]-this.intensityBounds[0]),!isFinite(Z)||isNaN(Z)){mt=!0;break e}var wt=bt*_t;st[yt]+=wt*Z}}}if(mt){if(X>0){for(var kt=0;kt<5;++kt)rt.pop();G-=1}continue t}rt.push(st[0],st[1],ut[0],ut[1],st[2]),G+=1}}ot.push(G)}this._contourOffsets[nt]=at,this._contourCounts[nt]=ot}var Tt=s.mallocFloat(rt.length);for(o=0;o<rt.length;++o)Tt[o]=rt[o];this._contourBuffer.update(Tt),s.freeFloat(Tt)}t.colormap&&this._colorMap.setPixels(function(t){var e=u([l({colormap:t,nshades:S,format:\"rgba\"}).map(function(t){return[t[0],t[1],t[2],255*t[3]]})]);return c.divseq(e,255),e}(t.colormap))},C.dispose=function(){this._shader.dispose(),this._vao.dispose(),this._coordinateBuffer.dispose(),this._colorMap.dispose(),this._contourBuffer.dispose(),this._contourVAO.dispose(),this._contourShader.dispose(),this._contourPickShader.dispose(),this._dynamicBuffer.dispose(),this._dynamicVAO.dispose();for(var t=0;t<3;++t)s.freeFloat(this._field[t].data)},C.highlight=function(t){var e,r;if(!t)return this._dynamicCounts=[0,0,0],this.dyanamicLevel=[NaN,NaN,NaN],void(this.highlightLevel=[-1,-1,-1]);for(e=0;e<3;++e)this.enableHighlight[e]?this.highlightLevel[e]=t.level[e]:this.highlightLevel[e]=-1;for(r=this.snapToData?t.dataCoordinate:t.position,e=0;e<3;++e)r[e]-=this.objectOffset[e];if(this.enableDynamic[0]&&r[0]!==this.dynamicLevel[0]||this.enableDynamic[1]&&r[1]!==this.dynamicLevel[1]||this.enableDynamic[2]&&r[2]!==this.dynamicLevel[2]){for(var n=0,i=this.shape,a=s.mallocFloat(12*i[0]*i[1]),o=0;o<3;++o)if(this.enableDynamic[o]){this.dynamicLevel[o]=r[o];var l=(o+1)%3,c=(o+2)%3,u=this._field[o],h=this._field[l],p=this._field[c],d=f(u,r[o]),g=d.cells,v=d.positions;for(this._dynamicOffsets[o]=n,e=0;e<g.length;++e)for(var m=g[e],y=0;y<2;++y){var x=v[m[y]],b=+x[0],_=0|b,w=0|Math.min(_+1,i[0]),k=b-_,T=1-k,A=+x[1],M=0|A,S=0|Math.min(M+1,i[1]),E=A-M,C=1-E,L=T*C,P=T*E,O=k*C,z=k*E,I=L*h.get(_,M)+P*h.get(_,S)+O*h.get(w,M)+z*h.get(w,S),D=L*p.get(_,M)+P*p.get(_,S)+O*p.get(w,M)+z*p.get(w,S);if(isNaN(I)||isNaN(D)){y&&(n-=1);break}a[2*n+0]=I,a[2*n+1]=D,n+=1}this._dynamicCounts[o]=n-this._dynamicOffsets[o]}else this.dynamicLevel[o]=NaN,this._dynamicCounts[o]=0;this._dynamicBuffer.update(a.subarray(0,2*n)),s.freeFloat(a)}}},{\"./lib/shaders\":314,\"binary-search-bounds\":315,\"bit-twiddle\":92,colormap:126,\"gl-buffer\":241,\"gl-mat4/invert\":265,\"gl-mat4/multiply\":267,\"gl-texture2d\":322,\"gl-vao\":327,ndarray:450,\"ndarray-gradient\":441,\"ndarray-ops\":444,\"ndarray-pack\":445,\"surface-nets\":531,\"typedarray-pool\":545}],317:[function(t,e,r){\"use strict\";var n=t(\"css-font\"),i=t(\"pick-by-alias\"),a=t(\"regl\"),o=t(\"gl-util/context\"),s=t(\"es6-weak-map\"),l=t(\"color-normalize\"),c=t(\"font-atlas\"),u=t(\"typedarray-pool\"),h=t(\"parse-rect\"),f=t(\"is-plain-obj\"),p=t(\"parse-unit\"),d=t(\"to-px\"),g=t(\"detect-kerning\"),v=t(\"object-assign\"),m=t(\"font-measure\"),y=t(\"flatten-vertex-data\"),x=t(\"bit-twiddle\").nextPow2,b=new s,_=!1;if(document.body){var w=document.body.appendChild(document.createElement(\"div\"));w.style.font=\"italic small-caps bold condensed 16px/2 cursive\",getComputedStyle(w).fontStretch&&(_=!0),document.body.removeChild(w)}var k=function(t){!function(t){return\"function\"==typeof t&&t._gl&&t.prop&&t.texture&&t.buffer}(t)?this.gl=o(t):(t={regl:t},this.gl=t.regl._gl),this.shader=b.get(this.gl),this.shader?this.regl=this.shader.regl:this.regl=t.regl||a({gl:this.gl}),this.charBuffer=this.regl.buffer({type:\"uint8\",usage:\"stream\"}),this.sizeBuffer=this.regl.buffer({type:\"float\",usage:\"stream\"}),this.shader||(this.shader=this.createShader(),b.set(this.gl,this.shader)),this.batch=[],this.fontSize=[],this.font=[],this.fontAtlas=[],this.draw=this.shader.draw.bind(this),this.render=function(){this.regl._refresh(),this.draw(this.batch)},this.canvas=this.gl.canvas,this.update(f(t)?t:{})};k.prototype.createShader=function(){var t=this.regl,e=t({blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},stencil:{enable:!1},depth:{enable:!1},count:t.prop(\"count\"),offset:t.prop(\"offset\"),attributes:{charOffset:{offset:4,stride:8,buffer:t.this(\"sizeBuffer\")},width:{offset:0,stride:8,buffer:t.this(\"sizeBuffer\")},char:t.this(\"charBuffer\"),position:t.this(\"position\")},uniforms:{atlasSize:function(t,e){return[e.atlas.width,e.atlas.height]},atlasDim:function(t,e){return[e.atlas.cols,e.atlas.rows]},atlas:function(t,e){return e.atlas.texture},charStep:function(t,e){return e.atlas.step},em:function(t,e){return e.atlas.em},color:t.prop(\"color\"),opacity:t.prop(\"opacity\"),viewport:t.this(\"viewportArray\"),scale:t.this(\"scale\"),align:t.prop(\"align\"),baseline:t.prop(\"baseline\"),translate:t.this(\"translate\"),positionOffset:t.prop(\"positionOffset\")},primitive:\"points\",viewport:t.this(\"viewport\"),vert:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tattribute float width, charOffset, char;\\n\\t\\t\\tattribute vec2 position;\\n\\t\\t\\tuniform float fontSize, charStep, em, align, baseline;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tuniform vec4 color;\\n\\t\\t\\tuniform vec2 atlasSize, atlasDim, scale, translate, positionOffset;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\t\"+(k.normalViewport?\"\":\"vec2 positionOffset = vec2(positionOffset.x,- positionOffset.y);\")+\"\\n\\n\\t\\t\\t\\tvec2 offset = floor(em * (vec2(align + charOffset, baseline)\\n\\t\\t\\t\\t\\t+ positionOffset))\\n\\t\\t\\t\\t\\t/ (viewport.zw * scale.xy);\\n\\n\\t\\t\\t\\tvec2 position = (position + translate) * scale;\\n\\t\\t\\t\\tposition += offset * scale;\\n\\n\\t\\t\\t\\t\"+(k.normalViewport?\"position.y = 1. - position.y;\":\"\")+\"\\n\\n\\t\\t\\t\\tcharCoord = position * viewport.zw + viewport.xy;\\n\\n\\t\\t\\t\\tgl_Position = vec4(position * 2. - 1., 0, 1);\\n\\n\\t\\t\\t\\tgl_PointSize = charStep;\\n\\n\\t\\t\\t\\tcharId.x = mod(char, atlasDim.x);\\n\\t\\t\\t\\tcharId.y = floor(char / atlasDim.x);\\n\\n\\t\\t\\t\\tcharWidth = width * em;\\n\\n\\t\\t\\t\\tfontColor = color / 255.;\\n\\t\\t\\t}\",frag:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tuniform sampler2D atlas;\\n\\t\\t\\tuniform float fontSize, charStep, opacity;\\n\\t\\t\\tuniform vec2 atlasSize;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\n\\t\\t\\tfloat lightness(vec4 color) {\\n\\t\\t\\t\\treturn color.r * 0.299 + color.g * 0.587 + color.b * 0.114;\\n\\t\\t\\t}\\n\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\tvec2 uv = gl_FragCoord.xy - charCoord + charStep * .5;\\n\\t\\t\\t\\tfloat halfCharStep = floor(charStep * .5 + .5);\\n\\n\\t\\t\\t\\t// invert y and shift by 1px (FF expecially needs that)\\n\\t\\t\\t\\tuv.y = charStep - uv.y;\\n\\n\\t\\t\\t\\t// ignore points outside of character bounding box\\n\\t\\t\\t\\tfloat halfCharWidth = ceil(charWidth * .5);\\n\\t\\t\\t\\tif (floor(uv.x) > halfCharStep + halfCharWidth ||\\n\\t\\t\\t\\t\\tfloor(uv.x) < halfCharStep - halfCharWidth) return;\\n\\n\\t\\t\\t\\tuv += charId * charStep;\\n\\t\\t\\t\\tuv = uv / atlasSize;\\n\\n\\t\\t\\t\\tvec4 color = fontColor;\\n\\t\\t\\t\\tvec4 mask = texture2D(atlas, uv);\\n\\n\\t\\t\\t\\tfloat maskY = lightness(mask);\\n\\t\\t\\t\\t// float colorY = lightness(color);\\n\\t\\t\\t\\tcolor.a *= maskY;\\n\\t\\t\\t\\tcolor.a *= opacity;\\n\\n\\t\\t\\t\\t// color.a += .1;\\n\\n\\t\\t\\t\\t// antialiasing, see yiq color space y-channel formula\\n\\t\\t\\t\\t// color.rgb += (1. - color.rgb) * (1. - mask.rgb);\\n\\n\\t\\t\\t\\tgl_FragColor = color;\\n\\t\\t\\t}\"});return{regl:t,draw:e,atlas:{}}},k.prototype.update=function(t){var e=this;if(\"string\"==typeof t)t={text:t};else if(!t)return;null!=(t=i(t,{position:\"position positions coord coords coordinates\",font:\"font fontFace fontface typeface cssFont css-font family fontFamily\",fontSize:\"fontSize fontsize size font-size\",text:\"text texts chars characters value values symbols\",align:\"align alignment textAlign textbaseline\",baseline:\"baseline textBaseline textbaseline\",direction:\"dir direction textDirection\",color:\"color colour fill fill-color fillColor textColor textcolor\",kerning:\"kerning kern\",range:\"range dataBox\",viewport:\"vp viewport viewBox viewbox viewPort\",opacity:\"opacity alpha transparency visible visibility opaque\",offset:\"offset positionOffset padding shift indent indentation\"},!0)).opacity&&(Array.isArray(t.opacity)?this.opacity=t.opacity.map(function(t){return parseFloat(t)}):this.opacity=parseFloat(t.opacity)),null!=t.viewport&&(this.viewport=h(t.viewport),k.normalViewport&&(this.viewport.y=this.canvas.height-this.viewport.y-this.viewport.height),this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null==this.viewport&&(this.viewport={x:0,y:0,width:this.gl.drawingBufferWidth,height:this.gl.drawingBufferHeight},this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null!=t.kerning&&(this.kerning=t.kerning),null!=t.offset&&(\"number\"==typeof t.offset&&(t.offset=[t.offset,0]),this.positionOffset=y(t.offset)),t.direction&&(this.direction=t.direction),t.range&&(this.range=t.range,this.scale=[1/(t.range[2]-t.range[0]),1/(t.range[3]-t.range[1])],this.translate=[-t.range[0],-t.range[1]]),t.scale&&(this.scale=t.scale),t.translate&&(this.translate=t.translate),this.scale||(this.scale=[1/this.viewport.width,1/this.viewport.height]),this.translate||(this.translate=[0,0]),this.font.length||t.font||(t.font=k.baseFontSize+\"px sans-serif\");var r,a=!1,o=!1;if(t.font&&(Array.isArray(t.font)?t.font:[t.font]).forEach(function(t,r){if(\"string\"==typeof t)try{t=n.parse(t)}catch(e){t=n.parse(k.baseFontSize+\"px \"+t)}else t=n.parse(n.stringify(t));var i=n.stringify({size:k.baseFontSize,family:t.family,stretch:_?t.stretch:void 0,variant:t.variant,weight:t.weight,style:t.style}),s=p(t.size),l=Math.round(s[0]*d(s[1]));if(l!==e.fontSize[r]&&(o=!0,e.fontSize[r]=l),!(e.font[r]&&i==e.font[r].baseString||(a=!0,e.font[r]=k.fonts[i],e.font[r]))){var c=t.family.join(\", \"),u=[t.style];t.style!=t.variant&&u.push(t.variant),t.variant!=t.weight&&u.push(t.weight),_&&t.weight!=t.stretch&&u.push(t.stretch),e.font[r]={baseString:i,family:c,weight:t.weight,stretch:t.stretch,style:t.style,variant:t.variant,width:{},kerning:{},metrics:m(c,{origin:\"top\",fontSize:k.baseFontSize,fontStyle:u.join(\" \")})},k.fonts[i]=e.font[r]}}),(a||o)&&this.font.forEach(function(r,i){var a=n.stringify({size:e.fontSize[i],family:r.family,stretch:_?r.stretch:void 0,variant:r.variant,weight:r.weight,style:r.style});if(e.fontAtlas[i]=e.shader.atlas[a],!e.fontAtlas[i]){var o=r.metrics;e.shader.atlas[a]=e.fontAtlas[i]={fontString:a,step:2*Math.ceil(e.fontSize[i]*o.bottom*.5),em:e.fontSize[i],cols:0,rows:0,height:0,width:0,chars:[],ids:{},texture:e.regl.texture()}}null==t.text&&(t.text=e.text)}),\"string\"==typeof t.text&&t.position&&t.position.length>2){for(var s=Array(.5*t.position.length),f=0;f<s.length;f++)s[f]=t.text;t.text=s}if(null!=t.text||a){if(this.textOffsets=[0],Array.isArray(t.text)){this.count=t.text[0].length,this.counts=[this.count];for(var b=1;b<t.text.length;b++)this.textOffsets[b]=this.textOffsets[b-1]+t.text[b-1].length,this.count+=t.text[b].length,this.counts.push(t.text[b].length);this.text=t.text.join(\"\")}else this.text=t.text,this.count=this.text.length,this.counts=[this.count];r=[],this.font.forEach(function(t,n){k.atlasContext.font=t.baseString;for(var i=e.fontAtlas[n],a=0;a<e.text.length;a++){var o=e.text.charAt(a);if(null==i.ids[o]&&(i.ids[o]=i.chars.length,i.chars.push(o),r.push(o)),null==t.width[o]&&(t.width[o]=k.atlasContext.measureText(o).width/k.baseFontSize,e.kerning)){var s=[];for(var l in t.width)s.push(l+o,o+l);v(t.kerning,g(t.family,{pairs:s}))}}})}if(t.position)if(t.position.length>2){for(var w=!t.position[0].length,T=u.mallocFloat(2*this.count),A=0,M=0;A<this.counts.length;A++){var S=this.counts[A];if(w)for(var E=0;E<S;E++)T[M++]=t.position[2*A],T[M++]=t.position[2*A+1];else for(var C=0;C<S;C++)T[M++]=t.position[A][0],T[M++]=t.position[A][1]}this.position.call?this.position({type:\"float\",data:T}):this.position=this.regl.buffer({type:\"float\",data:T}),u.freeFloat(T)}else this.position.destroy&&this.position.destroy(),this.position={constant:t.position};if(t.text||a){var L=u.mallocUint8(this.count),P=u.mallocFloat(2*this.count);this.textWidth=[];for(var O=0,z=0;O<this.counts.length;O++){for(var I=this.counts[O],D=this.font[O]||this.font[0],R=this.fontAtlas[O]||this.fontAtlas[0],F=0;F<I;F++){var B=this.text.charAt(z),N=this.text.charAt(z-1);if(L[z]=R.ids[B],P[2*z]=D.width[B],F){var j=P[2*z-2],U=P[2*z],V=P[2*z-1]+.5*j+.5*U;if(this.kerning){var q=D.kerning[N+B];q&&(V+=.001*q)}P[2*z+1]=V}else P[2*z+1]=.5*P[2*z];z++}this.textWidth.push(P.length?.5*P[2*z-2]+P[2*z-1]:0)}t.align||(t.align=this.align),this.charBuffer({data:L,type:\"uint8\",usage:\"stream\"}),this.sizeBuffer({data:P,type:\"float\",usage:\"stream\"}),u.freeUint8(L),u.freeFloat(P),r.length&&this.font.forEach(function(t,r){var n=e.fontAtlas[r],i=n.step,a=Math.floor(k.maxAtlasSize/i),o=Math.min(a,n.chars.length),s=Math.ceil(n.chars.length/o),l=x(o*i),u=x(s*i);n.width=l,n.height=u,n.rows=s,n.cols=o,n.em&&n.texture({data:c({canvas:k.atlasCanvas,font:n.fontString,chars:n.chars,shape:[l,u],step:[i,i]})})})}if(t.align&&(this.align=t.align,this.alignOffset=this.textWidth.map(function(t,r){var n=Array.isArray(e.align)?e.align.length>1?e.align[r]:e.align[0]:e.align;if(\"number\"==typeof n)return n;switch(n){case\"right\":case\"end\":return-t;case\"center\":case\"centre\":case\"middle\":return.5*-t}return 0})),null==this.baseline&&null==t.baseline&&(t.baseline=0),null!=t.baseline&&(this.baseline=t.baseline,Array.isArray(this.baseline)||(this.baseline=[this.baseline]),this.baselineOffset=this.baseline.map(function(t,r){var n=(e.font[r]||e.font[0]).metrics,i=0;return i+=.5*n.bottom,i+=\"number\"==typeof t?t-n.baseline:-n[t],k.normalViewport||(i*=-1),i})),null!=t.color)if(t.color||(t.color=\"transparent\"),\"string\"!=typeof t.color&&isNaN(t.color)){var H;if(\"number\"==typeof t.color[0]&&t.color.length>this.counts.length){var G=t.color.length;H=u.mallocUint8(G);for(var Y=(t.color.subarray||t.color.slice).bind(t.color),W=0;W<G;W+=4)H.set(l(Y(W,W+4),\"uint8\"),W)}else{var X=t.color.length;H=u.mallocUint8(4*X);for(var Z=0;Z<X;Z++)H.set(l(t.color[Z]||0,\"uint8\"),4*Z)}this.color=H}else this.color=l(t.color,\"uint8\");if(t.position||t.text||t.color||t.baseline||t.align||t.font||t.offset||t.opacity)if(this.color.length>4||this.baselineOffset.length>1||this.align&&this.align.length>1||this.fontAtlas.length>1||this.positionOffset.length>2){var J=Math.max(.5*this.position.length||0,.25*this.color.length||0,this.baselineOffset.length||0,this.alignOffset.length||0,this.font.length||0,this.opacity.length||0,.5*this.positionOffset.length||0);this.batch=Array(J);for(var K=0;K<this.batch.length;K++)this.batch[K]={count:this.counts.length>1?this.counts[K]:this.counts[0],offset:this.textOffsets.length>1?this.textOffsets[K]:this.textOffsets[0],color:this.color?this.color.length<=4?this.color:this.color.subarray(4*K,4*K+4):[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[K]:this.opacity,baseline:null!=this.baselineOffset[K]?this.baselineOffset[K]:this.baselineOffset[0],align:this.align?null!=this.alignOffset[K]?this.alignOffset[K]:this.alignOffset[0]:0,atlas:this.fontAtlas[K]||this.fontAtlas[0],positionOffset:this.positionOffset.length>2?this.positionOffset.subarray(2*K,2*K+2):this.positionOffset}}else this.count?this.batch=[{count:this.count,offset:0,color:this.color||[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[0]:this.opacity,baseline:this.baselineOffset[0],align:this.alignOffset?this.alignOffset[0]:0,atlas:this.fontAtlas[0],positionOffset:this.positionOffset}]:this.batch=[]},k.prototype.destroy=function(){},k.prototype.kerning=!0,k.prototype.position={constant:new Float32Array(2)},k.prototype.translate=null,k.prototype.scale=null,k.prototype.font=null,k.prototype.text=\"\",k.prototype.positionOffset=[0,0],k.prototype.opacity=1,k.prototype.color=new Uint8Array([0,0,0,255]),k.prototype.alignOffset=[0,0],k.normalViewport=!1,k.maxAtlasSize=1024,k.atlasCanvas=document.createElement(\"canvas\"),k.atlasContext=k.atlasCanvas.getContext(\"2d\",{alpha:!1}),k.baseFontSize=64,k.fonts={},e.exports=k},{\"bit-twiddle\":92,\"color-normalize\":120,\"css-font\":139,\"detect-kerning\":166,\"es6-weak-map\":318,\"flatten-vertex-data\":227,\"font-atlas\":228,\"font-measure\":229,\"gl-util/context\":323,\"is-plain-obj\":422,\"object-assign\":454,\"parse-rect\":459,\"parse-unit\":461,\"pick-by-alias\":465,regl:502,\"to-px\":539,\"typedarray-pool\":545}],318:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?WeakMap:t(\"./polyfill\")},{\"./is-implemented\":319,\"./polyfill\":321}],319:[function(t,e,r){\"use strict\";e.exports=function(){var t,e;if(\"function\"!=typeof WeakMap)return!1;try{t=new WeakMap([[e={},\"one\"],[{},\"two\"],[{},\"three\"]])}catch(t){return!1}return\"[object WeakMap]\"===String(t)&&(\"function\"==typeof t.set&&(t.set({},1)===t&&(\"function\"==typeof t.delete&&(\"function\"==typeof t.has&&\"one\"===t.get(e)))))}},{}],320:[function(t,e,r){\"use strict\";e.exports=\"function\"==typeof WeakMap&&\"[object WeakMap]\"===Object.prototype.toString.call(new WeakMap)},{}],321:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/object/set-prototype-of\"),o=t(\"es5-ext/object/valid-object\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"es5-ext/string/random-uniq\"),c=t(\"d\"),u=t(\"es6-iterator/get\"),h=t(\"es6-iterator/for-of\"),f=t(\"es6-symbol\").toStringTag,p=t(\"./is-native-implemented\"),d=Array.isArray,g=Object.defineProperty,v=Object.prototype.hasOwnProperty,m=Object.getPrototypeOf;e.exports=n=function(){var t,e=arguments[0];if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");return t=p&&a&&WeakMap!==n?a(new WeakMap,m(this)):this,i(e)&&(d(e)||(e=u(e))),g(t,\"__weakMapData__\",c(\"c\",\"$weakMap$\"+l())),e?(h(e,function(e){s(e),t.set(e[0],e[1])}),t):t},p&&(a&&a(n,WeakMap),n.prototype=Object.create(WeakMap.prototype,{constructor:c(n)})),Object.defineProperties(n.prototype,{delete:c(function(t){return!!v.call(o(t),this.__weakMapData__)&&(delete t[this.__weakMapData__],!0)}),get:c(function(t){if(v.call(o(t),this.__weakMapData__))return t[this.__weakMapData__]}),has:c(function(t){return v.call(o(t),this.__weakMapData__)}),set:c(function(t,e){return g(o(t),this.__weakMapData__,c(\"c\",e)),this}),toString:c(function(){return\"[object WeakMap]\"})}),g(n.prototype,f,c(\"c\",\"WeakMap\"))},{\"./is-native-implemented\":320,d:151,\"es5-ext/object/is-value\":194,\"es5-ext/object/set-prototype-of\":200,\"es5-ext/object/valid-object\":204,\"es5-ext/object/valid-value\":205,\"es5-ext/string/random-uniq\":210,\"es6-iterator/for-of\":212,\"es6-iterator/get\":213,\"es6-symbol\":219}],322:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"ndarray-ops\"),a=t(\"typedarray-pool\");e.exports=function(t){if(arguments.length<=1)throw new Error(\"gl-texture2d: Missing arguments for texture2d constructor\");o||function(t){o=[t.LINEAR,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_NEAREST],s=[t.NEAREST,t.LINEAR,t.NEAREST_MIPMAP_NEAREST,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_LINEAR],l=[t.REPEAT,t.CLAMP_TO_EDGE,t.MIRRORED_REPEAT]}(t);if(\"number\"==typeof arguments[1])return v(t,arguments[1],arguments[2],arguments[3]||t.RGBA,arguments[4]||t.UNSIGNED_BYTE);if(Array.isArray(arguments[1]))return v(t,0|arguments[1][0],0|arguments[1][1],arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(\"object\"==typeof arguments[1]){var e=arguments[1],r=c(e)?e:e.raw;if(r)return function(t,e,r,n,i,a){var o=g(t);return t.texImage2D(t.TEXTURE_2D,0,i,i,a,e),new f(t,o,r,n,i,a)}(t,r,0|e.width,0|e.height,arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(e.shape&&e.data&&e.stride)return function(t,e){var r=e.dtype,o=e.shape.slice(),s=t.getParameter(t.MAX_TEXTURE_SIZE);if(o[0]<0||o[0]>s||o[1]<0||o[1]>s)throw new Error(\"gl-texture2d: Invalid texture size\");var l=d(o,e.stride.slice()),c=0;\"float32\"===r?c=t.FLOAT:\"float64\"===r?(c=t.FLOAT,l=!1,r=\"float32\"):\"uint8\"===r?c=t.UNSIGNED_BYTE:(c=t.UNSIGNED_BYTE,l=!1,r=\"uint8\");var h,p,v=0;if(2===o.length)v=t.LUMINANCE,o=[o[0],o[1],1],e=n(e.data,o,[e.stride[0],e.stride[1],1],e.offset);else{if(3!==o.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===o[2])v=t.ALPHA;else if(2===o[2])v=t.LUMINANCE_ALPHA;else if(3===o[2])v=t.RGB;else{if(4!==o[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");v=t.RGBA}}c!==t.FLOAT||t.getExtension(\"OES_texture_float\")||(c=t.UNSIGNED_BYTE,l=!1);var m=e.size;if(l)h=0===e.offset&&e.data.length===m?e.data:e.data.subarray(e.offset,e.offset+m);else{var y=[o[2],o[2]*o[0],1];p=a.malloc(m,r);var x=n(p,o,y,0);\"float32\"!==r&&\"float64\"!==r||c!==t.UNSIGNED_BYTE?i.assign(x,e):u(x,e),h=p.subarray(0,m)}var b=g(t);t.texImage2D(t.TEXTURE_2D,0,v,o[0],o[1],0,v,c,h),l||a.free(p);return new f(t,b,o[0],o[1],v,c)}(t,e)}throw new Error(\"gl-texture2d: Invalid arguments for texture2d constructor\")};var o=null,s=null,l=null;function c(t){return\"undefined\"!=typeof HTMLCanvasElement&&t instanceof HTMLCanvasElement||\"undefined\"!=typeof HTMLImageElement&&t instanceof HTMLImageElement||\"undefined\"!=typeof HTMLVideoElement&&t instanceof HTMLVideoElement||\"undefined\"!=typeof ImageData&&t instanceof ImageData}var u=function(t,e){i.muls(t,e,255)};function h(t,e,r){var n=t.gl,i=n.getParameter(n.MAX_TEXTURE_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-texture2d: Invalid texture size\");return t._shape=[e,r],t.bind(),n.texImage2D(n.TEXTURE_2D,0,t.format,e,r,0,t.format,t.type,null),t._mipLevels=[0],t}function f(t,e,r,n,i,a){this.gl=t,this.handle=e,this.format=i,this.type=a,this._shape=[r,n],this._mipLevels=[0],this._magFilter=t.NEAREST,this._minFilter=t.NEAREST,this._wrapS=t.CLAMP_TO_EDGE,this._wrapT=t.CLAMP_TO_EDGE,this._anisoSamples=1;var o=this,s=[this._wrapS,this._wrapT];Object.defineProperties(s,[{get:function(){return o._wrapS},set:function(t){return o.wrapS=t}},{get:function(){return o._wrapT},set:function(t){return o.wrapT=t}}]),this._wrapVector=s;var l=[this._shape[0],this._shape[1]];Object.defineProperties(l,[{get:function(){return o._shape[0]},set:function(t){return o.width=t}},{get:function(){return o._shape[1]},set:function(t){return o.height=t}}]),this._shapeVector=l}var p=f.prototype;function d(t,e){return 3===t.length?1===e[2]&&e[1]===t[0]*t[2]&&e[0]===t[2]:1===e[0]&&e[1]===t[0]}function g(t){var e=t.createTexture();return t.bindTexture(t.TEXTURE_2D,e),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MIN_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MAG_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_S,t.CLAMP_TO_EDGE),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_T,t.CLAMP_TO_EDGE),e}function v(t,e,r,n,i){var a=t.getParameter(t.MAX_TEXTURE_SIZE);if(e<0||e>a||r<0||r>a)throw new Error(\"gl-texture2d: Invalid texture shape\");if(i===t.FLOAT&&!t.getExtension(\"OES_texture_float\"))throw new Error(\"gl-texture2d: Floating point textures not supported on this platform\");var o=g(t);return t.texImage2D(t.TEXTURE_2D,0,n,e,r,0,n,i,null),new f(t,o,e,r,n,i)}Object.defineProperties(p,{minFilter:{get:function(){return this._minFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,t),this._minFilter=t}},magFilter:{get:function(){return this._magFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,t),this._magFilter=t}},mipSamples:{get:function(){return this._anisoSamples},set:function(t){var e=this._anisoSamples;if(this._anisoSamples=0|Math.max(t,1),e!==this._anisoSamples){var r=this.gl.getExtension(\"EXT_texture_filter_anisotropic\");r&&this.gl.texParameterf(this.gl.TEXTURE_2D,r.TEXTURE_MAX_ANISOTROPY_EXT,this._anisoSamples)}return this._anisoSamples}},wrapS:{get:function(){return this._wrapS},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_S,t),this._wrapS=t}},wrapT:{get:function(){return this._wrapT},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_T,t),this._wrapT=t}},wrap:{get:function(){return this._wrapVector},set:function(t){if(Array.isArray(t)||(t=[t,t]),2!==t.length)throw new Error(\"gl-texture2d: Must specify wrap mode for rows and columns\");for(var e=0;e<2;++e)if(l.indexOf(t[e])<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);this._wrapS=t[0],this._wrapT=t[1];var r=this.gl;return this.bind(),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_S,this._wrapS),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_T,this._wrapT),t}},shape:{get:function(){return this._shapeVector},set:function(t){if(Array.isArray(t)){if(2!==t.length)throw new Error(\"gl-texture2d: Invalid texture shape\")}else t=[0|t,0|t];return h(this,0|t[0],0|t[1]),[0|t[0],0|t[1]]}},width:{get:function(){return this._shape[0]},set:function(t){return h(this,t|=0,this._shape[1]),t}},height:{get:function(){return this._shape[1]},set:function(t){return t|=0,h(this,this._shape[0],t),t}}}),p.bind=function(t){var e=this.gl;return void 0!==t&&e.activeTexture(e.TEXTURE0+(0|t)),e.bindTexture(e.TEXTURE_2D,this.handle),void 0!==t?0|t:e.getParameter(e.ACTIVE_TEXTURE)-e.TEXTURE0},p.dispose=function(){this.gl.deleteTexture(this.handle)},p.generateMipmap=function(){this.bind(),this.gl.generateMipmap(this.gl.TEXTURE_2D);for(var t=Math.min(this._shape[0],this._shape[1]),e=0;t>0;++e,t>>>=1)this._mipLevels.indexOf(e)<0&&this._mipLevels.push(e)},p.setPixels=function(t,e,r,o){var s=this.gl;this.bind(),Array.isArray(e)?(o=r,r=0|e[1],e=0|e[0]):(e=e||0,r=r||0),o=o||0;var l=c(t)?t:t.raw;if(l){this._mipLevels.indexOf(o)<0?(s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,this.type,l),this._mipLevels.push(o)):s.texSubImage2D(s.TEXTURE_2D,o,e,r,this.format,this.type,l)}else{if(!(t.shape&&t.stride&&t.data))throw new Error(\"gl-texture2d: Unsupported data type\");if(t.shape.length<2||e+t.shape[1]>this._shape[1]>>>o||r+t.shape[0]>this._shape[0]>>>o||e<0||r<0)throw new Error(\"gl-texture2d: Texture dimensions are out of bounds\");!function(t,e,r,o,s,l,c,h){var f=h.dtype,p=h.shape.slice();if(p.length<2||p.length>3)throw new Error(\"gl-texture2d: Invalid ndarray, must be 2d or 3d\");var g=0,v=0,m=d(p,h.stride.slice());\"float32\"===f?g=t.FLOAT:\"float64\"===f?(g=t.FLOAT,m=!1,f=\"float32\"):\"uint8\"===f?g=t.UNSIGNED_BYTE:(g=t.UNSIGNED_BYTE,m=!1,f=\"uint8\");if(2===p.length)v=t.LUMINANCE,p=[p[0],p[1],1],h=n(h.data,p,[h.stride[0],h.stride[1],1],h.offset);else{if(3!==p.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===p[2])v=t.ALPHA;else if(2===p[2])v=t.LUMINANCE_ALPHA;else if(3===p[2])v=t.RGB;else{if(4!==p[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");v=t.RGBA}p[2]}v!==t.LUMINANCE&&v!==t.ALPHA||s!==t.LUMINANCE&&s!==t.ALPHA||(v=s);if(v!==s)throw new Error(\"gl-texture2d: Incompatible texture format for setPixels\");var y=h.size,x=c.indexOf(o)<0;x&&c.push(o);if(g===l&&m)0===h.offset&&h.data.length===y?x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,h.data):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,h.data):x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,h.data.subarray(h.offset,h.offset+y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,h.data.subarray(h.offset,h.offset+y));else{var b;b=l===t.FLOAT?a.mallocFloat32(y):a.mallocUint8(y);var _=n(b,p,[p[2],p[2]*p[0],1]);g===t.FLOAT&&l===t.UNSIGNED_BYTE?u(_,h):i.assign(_,h),x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,b.subarray(0,y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,b.subarray(0,y)),l===t.FLOAT?a.freeFloat32(b):a.freeUint8(b)}}(s,e,r,o,this.format,this.type,this._mipLevels,t)}}},{ndarray:450,\"ndarray-ops\":444,\"typedarray-pool\":545}],323:[function(t,e,r){(function(r){\"use strict\";var n=t(\"pick-by-alias\");function i(t){if(t.container)if(t.container==document.body)document.body.style.width||(t.canvas.width=t.width||t.pixelRatio*r.innerWidth),document.body.style.height||(t.canvas.height=t.height||t.pixelRatio*r.innerHeight);else{var e=t.container.getBoundingClientRect();t.canvas.width=t.width||e.right-e.left,t.canvas.height=t.height||e.bottom-e.top}}function a(t){return\"function\"==typeof t.getContext&&\"width\"in t&&\"height\"in t}function o(){var t=document.createElement(\"canvas\");return t.style.position=\"absolute\",t.style.top=0,t.style.left=0,t}e.exports=function(t){var e;if(t?\"string\"==typeof t&&(t={container:t}):t={},a(t)?t={container:t}:t=\"string\"==typeof(e=t).nodeName&&\"function\"==typeof e.appendChild&&\"function\"==typeof e.getBoundingClientRect?{container:t}:function(t){return\"function\"==typeof t.drawArrays||\"function\"==typeof t.drawElements}(t)?{gl:t}:n(t,{container:\"container target element el canvas holder parent parentNode wrapper use ref root node\",gl:\"gl context webgl glContext\",attrs:\"attributes attrs contextAttributes\",pixelRatio:\"pixelRatio pxRatio px ratio pxratio pixelratio\",width:\"w width\",height:\"h height\"},!0),t.pixelRatio||(t.pixelRatio=r.pixelRatio||1),t.gl)return t.gl;if(t.canvas&&(t.container=t.canvas.parentNode),t.container){if(\"string\"==typeof t.container){var s=document.querySelector(t.container);if(!s)throw Error(\"Element \"+t.container+\" is not found\");t.container=s}a(t.container)?(t.canvas=t.container,t.container=t.canvas.parentNode):t.canvas||(t.canvas=o(),t.container.appendChild(t.canvas),i(t))}else if(!t.canvas){if(\"undefined\"==typeof document)throw Error(\"Not DOM environment. Use headless-gl.\");t.container=document.body||document.documentElement,t.canvas=o(),t.container.appendChild(t.canvas),i(t)}if(!t.gl)try{t.gl=t.canvas.getContext(\"webgl\",t.attrs)}catch(e){try{t.gl=t.canvas.getContext(\"experimental-webgl\",t.attrs)}catch(e){t.gl=t.canvas.getContext(\"webgl-experimental\",t.attrs)}}return t.gl}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"pick-by-alias\":465}],324:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){e?e.bind():t.bindBuffer(t.ELEMENT_ARRAY_BUFFER,null);var n=0|t.getParameter(t.MAX_VERTEX_ATTRIBS);if(r){if(r.length>n)throw new Error(\"gl-vao: Too many vertex attributes\");for(var i=0;i<r.length;++i){var a=r[i];if(a.buffer){var o=a.buffer,s=a.size||4,l=a.type||t.FLOAT,c=!!a.normalized,u=a.stride||0,h=a.offset||0;o.bind(),t.enableVertexAttribArray(i),t.vertexAttribPointer(i,s,l,c,u,h)}else{if(\"number\"==typeof a)t.vertexAttrib1f(i,a);else if(1===a.length)t.vertexAttrib1f(i,a[0]);else if(2===a.length)t.vertexAttrib2f(i,a[0],a[1]);else if(3===a.length)t.vertexAttrib3f(i,a[0],a[1],a[2]);else{if(4!==a.length)throw new Error(\"gl-vao: Invalid vertex attribute\");t.vertexAttrib4f(i,a[0],a[1],a[2],a[3])}t.disableVertexAttribArray(i)}}for(;i<n;++i)t.disableVertexAttribArray(i)}else for(t.bindBuffer(t.ARRAY_BUFFER,null),i=0;i<n;++i)t.disableVertexAttribArray(i)}},{}],325:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t){this.gl=t,this._elements=null,this._attributes=null,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(){n(this.gl,this._elements,this._attributes)},i.prototype.update=function(t,e,r){this._elements=e,this._attributes=t,this._elementsType=r||this.gl.UNSIGNED_SHORT},i.prototype.dispose=function(){},i.prototype.unbind=function(){},i.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._elements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t){return new i(t)}},{\"./do-bind.js\":324}],326:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t,e,r,n,i,a){this.location=t,this.dimension=e,this.a=r,this.b=n,this.c=i,this.d=a}function a(t,e,r){this.gl=t,this._ext=e,this.handle=r,this._attribs=[],this._useElements=!1,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(t){switch(this.dimension){case 1:t.vertexAttrib1f(this.location,this.a);break;case 2:t.vertexAttrib2f(this.location,this.a,this.b);break;case 3:t.vertexAttrib3f(this.location,this.a,this.b,this.c);break;case 4:t.vertexAttrib4f(this.location,this.a,this.b,this.c,this.d)}},a.prototype.bind=function(){this._ext.bindVertexArrayOES(this.handle);for(var t=0;t<this._attribs.length;++t)this._attribs[t].bind(this.gl)},a.prototype.unbind=function(){this._ext.bindVertexArrayOES(null)},a.prototype.dispose=function(){this._ext.deleteVertexArrayOES(this.handle)},a.prototype.update=function(t,e,r){if(this.bind(),n(this.gl,e,t),this.unbind(),this._attribs.length=0,t)for(var a=0;a<t.length;++a){var o=t[a];\"number\"==typeof o?this._attribs.push(new i(a,1,o)):Array.isArray(o)&&this._attribs.push(new i(a,o.length,o[0],o[1],o[2],o[3]))}this._useElements=!!e,this._elementsType=r||this.gl.UNSIGNED_SHORT},a.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._useElements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t,e){return new a(t,e,e.createVertexArrayOES())}},{\"./do-bind.js\":324}],327:[function(t,e,r){\"use strict\";var n=t(\"./lib/vao-native.js\"),i=t(\"./lib/vao-emulated.js\");function a(t){this.bindVertexArrayOES=t.bindVertexArray.bind(t),this.createVertexArrayOES=t.createVertexArray.bind(t),this.deleteVertexArrayOES=t.deleteVertexArray.bind(t)}e.exports=function(t,e,r,o){var s,l=t.createVertexArray?new a(t):t.getExtension(\"OES_vertex_array_object\");return(s=l?n(t,l):i(t)).update(e,r,o),s}},{\"./lib/vao-emulated.js\":325,\"./lib/vao-native.js\":326}],328:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t}},{}],329:[function(t,e,r){e.exports=function(t,e){var r=n(t[0],t[1],t[2]),o=n(e[0],e[1],e[2]);i(r,r),i(o,o);var s=a(r,o);return s>1?0:Math.acos(s)};var n=t(\"./fromValues\"),i=t(\"./normalize\"),a=t(\"./dot\")},{\"./dot\":339,\"./fromValues\":345,\"./normalize\":356}],330:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.ceil(e[0]),t[1]=Math.ceil(e[1]),t[2]=Math.ceil(e[2]),t}},{}],331:[function(t,e,r){e.exports=function(t){var e=new Float32Array(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e}},{}],332:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}},{}],333:[function(t,e,r){e.exports=function(){var t=new Float32Array(3);return t[0]=0,t[1]=0,t[2]=0,t}},{}],334:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2];return t[0]=i*l-a*s,t[1]=a*o-n*l,t[2]=n*s-i*o,t}},{}],335:[function(t,e,r){e.exports=t(\"./distance\")},{\"./distance\":336}],336:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return Math.sqrt(r*r+n*n+i*i)}},{}],337:[function(t,e,r){e.exports=t(\"./divide\")},{\"./divide\":338}],338:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t}},{}],339:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}},{}],340:[function(t,e,r){e.exports=1e-6},{}],341:[function(t,e,r){e.exports=function(t,e){var r=t[0],i=t[1],a=t[2],o=e[0],s=e[1],l=e[2];return Math.abs(r-o)<=n*Math.max(1,Math.abs(r),Math.abs(o))&&Math.abs(i-s)<=n*Math.max(1,Math.abs(i),Math.abs(s))&&Math.abs(a-l)<=n*Math.max(1,Math.abs(a),Math.abs(l))};var n=t(\"./epsilon\")},{\"./epsilon\":340}],342:[function(t,e,r){e.exports=function(t,e){return t[0]===e[0]&&t[1]===e[1]&&t[2]===e[2]}},{}],343:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.floor(e[0]),t[1]=Math.floor(e[1]),t[2]=Math.floor(e[2]),t}},{}],344:[function(t,e,r){e.exports=function(t,e,r,i,a,o){var s,l;e||(e=3);r||(r=0);l=i?Math.min(i*e+r,t.length):t.length;for(s=r;s<l;s+=e)n[0]=t[s],n[1]=t[s+1],n[2]=t[s+2],a(n,n,o),t[s]=n[0],t[s+1]=n[1],t[s+2]=n[2];return t};var n=t(\"./create\")()},{\"./create\":333}],345:[function(t,e,r){e.exports=function(t,e,r){var n=new Float32Array(3);return n[0]=t,n[1]=e,n[2]=r,n}},{}],346:[function(t,e,r){e.exports={EPSILON:t(\"./epsilon\"),create:t(\"./create\"),clone:t(\"./clone\"),angle:t(\"./angle\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),equals:t(\"./equals\"),exactEquals:t(\"./exactEquals\"),add:t(\"./add\"),subtract:t(\"./subtract\"),sub:t(\"./sub\"),multiply:t(\"./multiply\"),mul:t(\"./mul\"),divide:t(\"./divide\"),div:t(\"./div\"),min:t(\"./min\"),max:t(\"./max\"),floor:t(\"./floor\"),ceil:t(\"./ceil\"),round:t(\"./round\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),dist:t(\"./dist\"),squaredDistance:t(\"./squaredDistance\"),sqrDist:t(\"./sqrDist\"),length:t(\"./length\"),len:t(\"./len\"),squaredLength:t(\"./squaredLength\"),sqrLen:t(\"./sqrLen\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),cross:t(\"./cross\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformMat3:t(\"./transformMat3\"),transformQuat:t(\"./transformQuat\"),rotateX:t(\"./rotateX\"),rotateY:t(\"./rotateY\"),rotateZ:t(\"./rotateZ\"),forEach:t(\"./forEach\")}},{\"./add\":328,\"./angle\":329,\"./ceil\":330,\"./clone\":331,\"./copy\":332,\"./create\":333,\"./cross\":334,\"./dist\":335,\"./distance\":336,\"./div\":337,\"./divide\":338,\"./dot\":339,\"./epsilon\":340,\"./equals\":341,\"./exactEquals\":342,\"./floor\":343,\"./forEach\":344,\"./fromValues\":345,\"./inverse\":347,\"./len\":348,\"./length\":349,\"./lerp\":350,\"./max\":351,\"./min\":352,\"./mul\":353,\"./multiply\":354,\"./negate\":355,\"./normalize\":356,\"./random\":357,\"./rotateX\":358,\"./rotateY\":359,\"./rotateZ\":360,\"./round\":361,\"./scale\":362,\"./scaleAndAdd\":363,\"./set\":364,\"./sqrDist\":365,\"./sqrLen\":366,\"./squaredDistance\":367,\"./squaredLength\":368,\"./sub\":369,\"./subtract\":370,\"./transformMat3\":371,\"./transformMat4\":372,\"./transformQuat\":373}],347:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t}},{}],348:[function(t,e,r){e.exports=t(\"./length\")},{\"./length\":349}],349:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return Math.sqrt(e*e+r*r+n*n)}},{}],350:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t}},{}],351:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t}},{}],352:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t}},{}],353:[function(t,e,r){e.exports=t(\"./multiply\")},{\"./multiply\":354}],354:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t}},{}],355:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t}},{}],356:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=r*r+n*n+i*i;a>0&&(a=1/Math.sqrt(a),t[0]=e[0]*a,t[1]=e[1]*a,t[2]=e[2]*a);return t}},{}],357:[function(t,e,r){e.exports=function(t,e){e=e||1;var r=2*Math.random()*Math.PI,n=2*Math.random()-1,i=Math.sqrt(1-n*n)*e;return t[0]=Math.cos(r)*i,t[1]=Math.sin(r)*i,t[2]=n*e,t}},{}],358:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[1],a=r[2],o=e[1]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=e[0],t[1]=i+o*c-s*l,t[2]=a+o*l+s*c,t}},{}],359:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[2],o=e[0]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+s*l+o*c,t[1]=e[1],t[2]=a+s*c-o*l,t}},{}],360:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[1],o=e[0]-i,s=e[1]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+o*c-s*l,t[1]=a+o*l+s*c,t[2]=e[2],t}},{}],361:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.round(e[0]),t[1]=Math.round(e[1]),t[2]=Math.round(e[2]),t}},{}],362:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t}},{}],363:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t}},{}],364:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e,t[1]=r,t[2]=n,t}},{}],365:[function(t,e,r){e.exports=t(\"./squaredDistance\")},{\"./squaredDistance\":367}],366:[function(t,e,r){e.exports=t(\"./squaredLength\")},{\"./squaredLength\":368}],367:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return r*r+n*n+i*i}},{}],368:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return e*e+r*r+n*n}},{}],369:[function(t,e,r){e.exports=t(\"./subtract\")},{\"./subtract\":370}],370:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t}},{}],371:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t}},{}],372:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[3]*n+r[7]*i+r[11]*a+r[15];return o=o||1,t[0]=(r[0]*n+r[4]*i+r[8]*a+r[12])/o,t[1]=(r[1]*n+r[5]*i+r[9]*a+r[13])/o,t[2]=(r[2]*n+r[6]*i+r[10]*a+r[14])/o,t}},{}],373:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,h=c*i+l*n-o*a,f=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+h*-l-f*-s,t[1]=h*c+p*-s+f*-o-u*-l,t[2]=f*c+p*-l+u*-s-h*-o,t}},{}],374:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t[3]=e[3]+r[3],t}},{}],375:[function(t,e,r){e.exports=function(t){var e=new Float32Array(4);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e}},{}],376:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t}},{}],377:[function(t,e,r){e.exports=function(){var t=new Float32Array(4);return t[0]=0,t[1]=0,t[2]=0,t[3]=0,t}},{}],378:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return Math.sqrt(r*r+n*n+i*i+a*a)}},{}],379:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t[3]=e[3]/r[3],t}},{}],380:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}},{}],381:[function(t,e,r){e.exports=function(t,e,r,n){var i=new Float32Array(4);return i[0]=t,i[1]=e,i[2]=r,i[3]=n,i}},{}],382:[function(t,e,r){e.exports={create:t(\"./create\"),clone:t(\"./clone\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),add:t(\"./add\"),subtract:t(\"./subtract\"),multiply:t(\"./multiply\"),divide:t(\"./divide\"),min:t(\"./min\"),max:t(\"./max\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),squaredDistance:t(\"./squaredDistance\"),length:t(\"./length\"),squaredLength:t(\"./squaredLength\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformQuat:t(\"./transformQuat\")}},{\"./add\":374,\"./clone\":375,\"./copy\":376,\"./create\":377,\"./distance\":378,\"./divide\":379,\"./dot\":380,\"./fromValues\":381,\"./inverse\":383,\"./length\":384,\"./lerp\":385,\"./max\":386,\"./min\":387,\"./multiply\":388,\"./negate\":389,\"./normalize\":390,\"./random\":391,\"./scale\":392,\"./scaleAndAdd\":393,\"./set\":394,\"./squaredDistance\":395,\"./squaredLength\":396,\"./subtract\":397,\"./transformMat4\":398,\"./transformQuat\":399}],383:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t[3]=1/e[3],t}},{}],384:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return Math.sqrt(e*e+r*r+n*n+i*i)}},{}],385:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2],s=e[3];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t[3]=s+n*(r[3]-s),t}},{}],386:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t[3]=Math.max(e[3],r[3]),t}},{}],387:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t[3]=Math.min(e[3],r[3]),t}},{}],388:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t[3]=e[3]*r[3],t}},{}],389:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t[3]=-e[3],t}},{}],390:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r*r+n*n+i*i+a*a;o>0&&(o=1/Math.sqrt(o),t[0]=r*o,t[1]=n*o,t[2]=i*o,t[3]=a*o);return t}},{}],391:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"./scale\");e.exports=function(t,e){return e=e||1,t[0]=Math.random(),t[1]=Math.random(),t[2]=Math.random(),t[3]=Math.random(),n(t,t),i(t,t,e),t}},{\"./normalize\":390,\"./scale\":392}],392:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t}},{}],393:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t[3]=e[3]+r[3]*n,t}},{}],394:[function(t,e,r){e.exports=function(t,e,r,n,i){return t[0]=e,t[1]=r,t[2]=n,t[3]=i,t}},{}],395:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return r*r+n*n+i*i+a*a}},{}],396:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return e*e+r*r+n*n+i*i}},{}],397:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t[3]=e[3]-r[3],t}},{}],398:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}},{}],399:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,h=c*i+l*n-o*a,f=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+h*-l-f*-s,t[1]=h*c+p*-s+f*-o-u*-l,t[2]=f*c+p*-l+u*-s-h*-o,t[3]=e[3],t}},{}],400:[function(t,e,r){e.exports=function(t,e,r,a){return n[0]=a,n[1]=r,n[2]=e,n[3]=t,i[0]};var n=new Uint8Array(4),i=new Float32Array(n.buffer)},{}],401:[function(t,e,r){var n=t(\"glsl-tokenizer\"),i=t(\"atob-lite\");e.exports=function(t){for(var e=Array.isArray(t)?t:n(t),r=0;r<e.length;r++){var a=e[r];if(\"preprocessor\"===a.type){var o=a.data.match(/\\#define\\s+SHADER_NAME(_B64)?\\s+(.+)$/);if(o&&o[2]){var s=o[1],l=o[2];return(s?i(l):l).trim()}}}}},{\"atob-lite\":72,\"glsl-tokenizer\":408}],402:[function(t,e,r){e.exports=function(t){var e,r,k,T=0,A=0,M=l,S=[],E=[],C=1,L=0,P=0,O=!1,z=!1,I=\"\",D=a,R=n;\"300 es\"===(t=t||{}).version&&(D=s,R=o);return function(t){return E=[],null!==t?function(t){var r;T=0,k=(I+=t).length;for(;e=I[T],T<k;){switch(r=T,M){case u:T=U();break;case h:case f:T=j();break;case p:T=V();break;case d:T=G();break;case _:T=H();break;case g:T=Y();break;case c:T=W();break;case x:T=N();break;case l:T=B()}if(r!==T)switch(I[r]){case\"\\n\":L=0,++C;break;default:++L}}return A+=T,I=I.slice(T),E}(t.replace?t.replace(/\\r\\n/g,\"\\n\"):t):function(t){S.length&&F(S.join(\"\"));return M=b,F(\"(eof)\"),E}()};function F(t){t.length&&E.push({type:w[M],data:t,position:P,line:C,column:L})}function B(){return S=S.length?[]:S,\"/\"===r&&\"*\"===e?(P=A+T-1,M=u,r=e,T+1):\"/\"===r&&\"/\"===e?(P=A+T-1,M=h,r=e,T+1):\"#\"===e?(M=f,P=A+T,T):/\\s/.test(e)?(M=x,P=A+T,T):(O=/\\d/.test(e),z=/[^\\w_]/.test(e),P=A+T,M=O?d:z?p:c,T)}function N(){return/[^\\s]/g.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function j(){return\"\\r\"!==e&&\"\\n\"!==e||\"\\\\\"===r?(S.push(e),r=e,T+1):(F(S.join(\"\")),M=l,T)}function U(){return\"/\"===e&&\"*\"===r?(S.push(e),F(S.join(\"\")),M=l,T+1):(S.push(e),r=e,T+1)}function V(){if(\".\"===r&&/\\d/.test(e))return M=g,T;if(\"/\"===r&&\"*\"===e)return M=u,T;if(\"/\"===r&&\"/\"===e)return M=h,T;if(\".\"===e&&S.length){for(;q(S););return M=g,T}if(\";\"===e||\")\"===e||\"(\"===e){if(S.length)for(;q(S););return F(e),M=l,T+1}var t=2===S.length&&\"=\"!==e;if(/[\\w_\\d\\s]/.test(e)||t){for(;q(S););return M=l,T}return S.push(e),r=e,T+1}function q(t){for(var e,r,n=0;;){if(e=i.indexOf(t.slice(0,t.length+n).join(\"\")),r=i[e],-1===e){if(n--+t.length>0)continue;r=t.slice(0,1).join(\"\")}return F(r),P+=r.length,(S=S.slice(r.length)).length}}function H(){return/[^a-fA-F0-9]/.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function G(){return\".\"===e?(S.push(e),M=g,r=e,T+1):/[eE]/.test(e)?(S.push(e),M=g,r=e,T+1):\"x\"===e&&1===S.length&&\"0\"===S[0]?(M=_,S.push(e),r=e,T+1):/[^\\d]/.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function Y(){return\"f\"===e&&(S.push(e),r=e,T+=1),/[eE]/.test(e)?(S.push(e),r=e,T+1):\"-\"===e&&/[eE]/.test(r)?(S.push(e),r=e,T+1):/[^\\d]/.test(e)?(F(S.join(\"\")),M=l,T):(S.push(e),r=e,T+1)}function W(){if(/[^\\d\\w_]/.test(e)){var t=S.join(\"\");return M=R.indexOf(t)>-1?y:D.indexOf(t)>-1?m:v,F(S.join(\"\")),M=l,T}return S.push(e),r=e,T+1}};var n=t(\"./lib/literals\"),i=t(\"./lib/operators\"),a=t(\"./lib/builtins\"),o=t(\"./lib/literals-300es\"),s=t(\"./lib/builtins-300es\"),l=999,c=9999,u=0,h=1,f=2,p=3,d=4,g=5,v=6,m=7,y=8,x=9,b=10,_=11,w=[\"block-comment\",\"line-comment\",\"preprocessor\",\"operator\",\"integer\",\"float\",\"ident\",\"builtin\",\"keyword\",\"whitespace\",\"eof\",\"integer\"]},{\"./lib/builtins\":404,\"./lib/builtins-300es\":403,\"./lib/literals\":406,\"./lib/literals-300es\":405,\"./lib/operators\":407}],403:[function(t,e,r){var n=t(\"./builtins\");n=n.slice().filter(function(t){return!/^(gl\\_|texture)/.test(t)}),e.exports=n.concat([\"gl_VertexID\",\"gl_InstanceID\",\"gl_Position\",\"gl_PointSize\",\"gl_FragCoord\",\"gl_FrontFacing\",\"gl_FragDepth\",\"gl_PointCoord\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexUniformVectors\",\"gl_MaxVertexOutputVectors\",\"gl_MaxFragmentInputVectors\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxTextureImageUnits\",\"gl_MaxFragmentUniformVectors\",\"gl_MaxDrawBuffers\",\"gl_MinProgramTexelOffset\",\"gl_MaxProgramTexelOffset\",\"gl_DepthRangeParameters\",\"gl_DepthRange\",\"trunc\",\"round\",\"roundEven\",\"isnan\",\"isinf\",\"floatBitsToInt\",\"floatBitsToUint\",\"intBitsToFloat\",\"uintBitsToFloat\",\"packSnorm2x16\",\"unpackSnorm2x16\",\"packUnorm2x16\",\"unpackUnorm2x16\",\"packHalf2x16\",\"unpackHalf2x16\",\"outerProduct\",\"transpose\",\"determinant\",\"inverse\",\"texture\",\"textureSize\",\"textureProj\",\"textureLod\",\"textureOffset\",\"texelFetch\",\"texelFetchOffset\",\"textureProjOffset\",\"textureLodOffset\",\"textureProjLod\",\"textureProjLodOffset\",\"textureGrad\",\"textureGradOffset\",\"textureProjGrad\",\"textureProjGradOffset\"])},{\"./builtins\":404}],404:[function(t,e,r){e.exports=[\"abs\",\"acos\",\"all\",\"any\",\"asin\",\"atan\",\"ceil\",\"clamp\",\"cos\",\"cross\",\"dFdx\",\"dFdy\",\"degrees\",\"distance\",\"dot\",\"equal\",\"exp\",\"exp2\",\"faceforward\",\"floor\",\"fract\",\"gl_BackColor\",\"gl_BackLightModelProduct\",\"gl_BackLightProduct\",\"gl_BackMaterial\",\"gl_BackSecondaryColor\",\"gl_ClipPlane\",\"gl_ClipVertex\",\"gl_Color\",\"gl_DepthRange\",\"gl_DepthRangeParameters\",\"gl_EyePlaneQ\",\"gl_EyePlaneR\",\"gl_EyePlaneS\",\"gl_EyePlaneT\",\"gl_Fog\",\"gl_FogCoord\",\"gl_FogFragCoord\",\"gl_FogParameters\",\"gl_FragColor\",\"gl_FragCoord\",\"gl_FragData\",\"gl_FragDepth\",\"gl_FragDepthEXT\",\"gl_FrontColor\",\"gl_FrontFacing\",\"gl_FrontLightModelProduct\",\"gl_FrontLightProduct\",\"gl_FrontMaterial\",\"gl_FrontSecondaryColor\",\"gl_LightModel\",\"gl_LightModelParameters\",\"gl_LightModelProducts\",\"gl_LightProducts\",\"gl_LightSource\",\"gl_LightSourceParameters\",\"gl_MaterialParameters\",\"gl_MaxClipPlanes\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxDrawBuffers\",\"gl_MaxFragmentUniformComponents\",\"gl_MaxLights\",\"gl_MaxTextureCoords\",\"gl_MaxTextureImageUnits\",\"gl_MaxTextureUnits\",\"gl_MaxVaryingFloats\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxVertexUniformComponents\",\"gl_ModelViewMatrix\",\"gl_ModelViewMatrixInverse\",\"gl_ModelViewMatrixInverseTranspose\",\"gl_ModelViewMatrixTranspose\",\"gl_ModelViewProjectionMatrix\",\"gl_ModelViewProjectionMatrixInverse\",\"gl_ModelViewProjectionMatrixInverseTranspose\",\"gl_ModelViewProjectionMatrixTranspose\",\"gl_MultiTexCoord0\",\"gl_MultiTexCoord1\",\"gl_MultiTexCoord2\",\"gl_MultiTexCoord3\",\"gl_MultiTexCoord4\",\"gl_MultiTexCoord5\",\"gl_MultiTexCoord6\",\"gl_MultiTexCoord7\",\"gl_Normal\",\"gl_NormalMatrix\",\"gl_NormalScale\",\"gl_ObjectPlaneQ\",\"gl_ObjectPlaneR\",\"gl_ObjectPlaneS\",\"gl_ObjectPlaneT\",\"gl_Point\",\"gl_PointCoord\",\"gl_PointParameters\",\"gl_PointSize\",\"gl_Position\",\"gl_ProjectionMatrix\",\"gl_ProjectionMatrixInverse\",\"gl_ProjectionMatrixInverseTranspose\",\"gl_ProjectionMatrixTranspose\",\"gl_SecondaryColor\",\"gl_TexCoord\",\"gl_TextureEnvColor\",\"gl_TextureMatrix\",\"gl_TextureMatrixInverse\",\"gl_TextureMatrixInverseTranspose\",\"gl_TextureMatrixTranspose\",\"gl_Vertex\",\"greaterThan\",\"greaterThanEqual\",\"inversesqrt\",\"length\",\"lessThan\",\"lessThanEqual\",\"log\",\"log2\",\"matrixCompMult\",\"max\",\"min\",\"mix\",\"mod\",\"normalize\",\"not\",\"notEqual\",\"pow\",\"radians\",\"reflect\",\"refract\",\"sign\",\"sin\",\"smoothstep\",\"sqrt\",\"step\",\"tan\",\"texture2D\",\"texture2DLod\",\"texture2DProj\",\"texture2DProjLod\",\"textureCube\",\"textureCubeLod\",\"texture2DLodEXT\",\"texture2DProjLodEXT\",\"textureCubeLodEXT\",\"texture2DGradEXT\",\"texture2DProjGradEXT\",\"textureCubeGradEXT\"]},{}],405:[function(t,e,r){var n=t(\"./literals\");e.exports=n.slice().concat([\"layout\",\"centroid\",\"smooth\",\"case\",\"mat2x2\",\"mat2x3\",\"mat2x4\",\"mat3x2\",\"mat3x3\",\"mat3x4\",\"mat4x2\",\"mat4x3\",\"mat4x4\",\"uint\",\"uvec2\",\"uvec3\",\"uvec4\",\"samplerCubeShadow\",\"sampler2DArray\",\"sampler2DArrayShadow\",\"isampler2D\",\"isampler3D\",\"isamplerCube\",\"isampler2DArray\",\"usampler2D\",\"usampler3D\",\"usamplerCube\",\"usampler2DArray\",\"coherent\",\"restrict\",\"readonly\",\"writeonly\",\"resource\",\"atomic_uint\",\"noperspective\",\"patch\",\"sample\",\"subroutine\",\"common\",\"partition\",\"active\",\"filter\",\"image1D\",\"image2D\",\"image3D\",\"imageCube\",\"iimage1D\",\"iimage2D\",\"iimage3D\",\"iimageCube\",\"uimage1D\",\"uimage2D\",\"uimage3D\",\"uimageCube\",\"image1DArray\",\"image2DArray\",\"iimage1DArray\",\"iimage2DArray\",\"uimage1DArray\",\"uimage2DArray\",\"image1DShadow\",\"image2DShadow\",\"image1DArrayShadow\",\"image2DArrayShadow\",\"imageBuffer\",\"iimageBuffer\",\"uimageBuffer\",\"sampler1DArray\",\"sampler1DArrayShadow\",\"isampler1D\",\"isampler1DArray\",\"usampler1D\",\"usampler1DArray\",\"isampler2DRect\",\"usampler2DRect\",\"samplerBuffer\",\"isamplerBuffer\",\"usamplerBuffer\",\"sampler2DMS\",\"isampler2DMS\",\"usampler2DMS\",\"sampler2DMSArray\",\"isampler2DMSArray\",\"usampler2DMSArray\"])},{\"./literals\":406}],406:[function(t,e,r){e.exports=[\"precision\",\"highp\",\"mediump\",\"lowp\",\"attribute\",\"const\",\"uniform\",\"varying\",\"break\",\"continue\",\"do\",\"for\",\"while\",\"if\",\"else\",\"in\",\"out\",\"inout\",\"float\",\"int\",\"void\",\"bool\",\"true\",\"false\",\"discard\",\"return\",\"mat2\",\"mat3\",\"mat4\",\"vec2\",\"vec3\",\"vec4\",\"ivec2\",\"ivec3\",\"ivec4\",\"bvec2\",\"bvec3\",\"bvec4\",\"sampler1D\",\"sampler2D\",\"sampler3D\",\"samplerCube\",\"sampler1DShadow\",\"sampler2DShadow\",\"struct\",\"asm\",\"class\",\"union\",\"enum\",\"typedef\",\"template\",\"this\",\"packed\",\"goto\",\"switch\",\"default\",\"inline\",\"noinline\",\"volatile\",\"public\",\"static\",\"extern\",\"external\",\"interface\",\"long\",\"short\",\"double\",\"half\",\"fixed\",\"unsigned\",\"input\",\"output\",\"hvec2\",\"hvec3\",\"hvec4\",\"dvec2\",\"dvec3\",\"dvec4\",\"fvec2\",\"fvec3\",\"fvec4\",\"sampler2DRect\",\"sampler3DRect\",\"sampler2DRectShadow\",\"sizeof\",\"cast\",\"namespace\",\"using\"]},{}],407:[function(t,e,r){e.exports=[\"<<=\",\">>=\",\"++\",\"--\",\"<<\",\">>\",\"<=\",\">=\",\"==\",\"!=\",\"&&\",\"||\",\"+=\",\"-=\",\"*=\",\"/=\",\"%=\",\"&=\",\"^^\",\"^=\",\"|=\",\"(\",\")\",\"[\",\"]\",\".\",\"!\",\"~\",\"*\",\"/\",\"%\",\"+\",\"-\",\"<\",\">\",\"&\",\"^\",\"|\",\"?\",\":\",\"=\",\",\",\";\",\"{\",\"}\"]},{}],408:[function(t,e,r){var n=t(\"./index\");e.exports=function(t,e){var r=n(e),i=[];return i=(i=i.concat(r(t))).concat(r(null))}},{\"./index\":402}],409:[function(t,e,r){e.exports=function(t){\"string\"==typeof t&&(t=[t]);for(var e=[].slice.call(arguments,1),r=[],n=0;n<t.length-1;n++)r.push(t[n],e[n]||\"\");return r.push(t[n]),r.join(\"\")}},{}],410:[function(t,e,r){(function(r){\"use strict\";var n,i=t(\"is-browser\");n=\"function\"==typeof r.matchMedia?!r.matchMedia(\"(hover: none)\").matches:i,e.exports=n}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"is-browser\":417}],411:[function(t,e,r){\"use strict\";var n=t(\"is-browser\");e.exports=n&&function(){var t=!1;try{var e=Object.defineProperty({},\"passive\",{get:function(){t=!0}});window.addEventListener(\"test\",null,e),window.removeEventListener(\"test\",null,e)}catch(e){t=!1}return t}()},{\"is-browser\":417}],412:[function(t,e,r){r.read=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?i-1:0,f=r?-1:1,p=t[e+h];for(h+=f,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+h],h+=f,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},r.write=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,h=u>>1,f=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,i),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g}},{}],413:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(0===r)throw new Error(\"Must have at least d+1 points\");var i=t[0].length;if(r<=i)throw new Error(\"Must input at least d+1 points\");var o=t.slice(0,i+1),s=n.apply(void 0,o);if(0===s)throw new Error(\"Input not in general position\");for(var l=new Array(i+1),u=0;u<=i;++u)l[u]=u;s<0&&(l[0]=1,l[1]=0);for(var h=new a(l,new Array(i+1),!1),f=h.adjacent,p=new Array(i+2),u=0;u<=i;++u){for(var d=l.slice(),g=0;g<=i;++g)g===u&&(d[g]=-1);var v=d[0];d[0]=d[1],d[1]=v;var m=new a(d,new Array(i+1),!0);f[u]=m,p[u]=m}p[i+1]=h;for(var u=0;u<=i;++u)for(var d=f[u].vertices,y=f[u].adjacent,g=0;g<=i;++g){var x=d[g];if(x<0)y[g]=h;else for(var b=0;b<=i;++b)f[b].vertices.indexOf(x)<0&&(y[g]=f[b])}for(var _=new c(i,o,p),w=!!e,u=i+1;u<r;++u)_.insert(t[u],w);return _.boundary()};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\").compareCells;function a(t,e,r){this.vertices=t,this.adjacent=e,this.boundary=r,this.lastVisited=-1}function o(t,e,r){this.vertices=t,this.cell=e,this.index=r}function s(t,e){return i(t.vertices,e.vertices)}a.prototype.flip=function(){var t=this.vertices[0];this.vertices[0]=this.vertices[1],this.vertices[1]=t;var e=this.adjacent[0];this.adjacent[0]=this.adjacent[1],this.adjacent[1]=e};var l=[];function c(t,e,r){this.dimension=t,this.vertices=e,this.simplices=r,this.interior=r.filter(function(t){return!t.boundary}),this.tuple=new Array(t+1);for(var i=0;i<=t;++i)this.tuple[i]=this.vertices[i];var a=l[t];a||(a=l[t]=function(t){for(var e=[\"function orient(){var tuple=this.tuple;return test(\"],r=0;r<=t;++r)r>0&&e.push(\",\"),e.push(\"tuple[\",r,\"]\");e.push(\")}return orient\");var i=new Function(\"test\",e.join(\"\")),a=n[t+1];return a||(a=n),i(a)}(t)),this.orient=a}var u=c.prototype;u.handleBoundaryDegeneracy=function(t,e){var r=this.dimension,n=this.vertices.length-1,i=this.tuple,a=this.vertices,o=[t];for(t.lastVisited=-n;o.length>0;){(t=o.pop()).vertices;for(var s=t.adjacent,l=0;l<=r;++l){var c=s[l];if(c.boundary&&!(c.lastVisited<=-n)){for(var u=c.vertices,h=0;h<=r;++h){var f=u[h];i[h]=f<0?e:a[f]}var p=this.orient();if(p>0)return c;c.lastVisited=-n,0===p&&o.push(c)}}}return null},u.walk=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,a=this.tuple,o=e?this.interior.length*Math.random()|0:this.interior.length-1,s=this.interior[o];t:for(;!s.boundary;){for(var l=s.vertices,c=s.adjacent,u=0;u<=n;++u)a[u]=i[l[u]];s.lastVisited=r;for(u=0;u<=n;++u){var h=c[u];if(!(h.lastVisited>=r)){var f=a[u];a[u]=t;var p=this.orient();if(a[u]=f,p<0){s=h;continue t}h.boundary?h.lastVisited=-r:h.lastVisited=r}}return}return s},u.addPeaks=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,l=this.tuple,c=this.interior,u=this.simplices,h=[e];e.lastVisited=r,e.vertices[e.vertices.indexOf(-1)]=r,e.boundary=!1,c.push(e);for(var f=[];h.length>0;){var p=(e=h.pop()).vertices,d=e.adjacent,g=p.indexOf(r);if(!(g<0))for(var v=0;v<=n;++v)if(v!==g){var m=d[v];if(m.boundary&&!(m.lastVisited>=r)){var y=m.vertices;if(m.lastVisited!==-r){for(var x=0,b=0;b<=n;++b)y[b]<0?(x=b,l[b]=t):l[b]=i[y[b]];if(this.orient()>0){y[x]=r,m.boundary=!1,c.push(m),h.push(m),m.lastVisited=r;continue}m.lastVisited=-r}var _=m.adjacent,w=p.slice(),k=d.slice(),T=new a(w,k,!0);u.push(T);var A=_.indexOf(e);if(!(A<0)){_[A]=T,k[g]=m,w[v]=-1,k[v]=e,d[v]=T,T.flip();for(b=0;b<=n;++b){var M=w[b];if(!(M<0||M===r)){for(var S=new Array(n-1),E=0,C=0;C<=n;++C){var L=w[C];L<0||C===b||(S[E++]=L)}f.push(new o(S,T,b))}}}}}}f.sort(s);for(v=0;v+1<f.length;v+=2){var P=f[v],O=f[v+1],z=P.index,I=O.index;z<0||I<0||(P.cell.adjacent[P.index]=O.cell,O.cell.adjacent[O.index]=P.cell)}},u.insert=function(t,e){var r=this.vertices;r.push(t);var n=this.walk(t,e);if(n){for(var i=this.dimension,a=this.tuple,o=0;o<=i;++o){var s=n.vertices[o];a[o]=s<0?t:r[s]}var l=this.orient(a);l<0||(0!==l||(n=this.handleBoundaryDegeneracy(n,t)))&&this.addPeaks(t,n)}},u.boundary=function(){for(var t=this.dimension,e=[],r=this.simplices,n=r.length,i=0;i<n;++i){var a=r[i];if(a.boundary){for(var o=new Array(t),s=a.vertices,l=0,c=0,u=0;u<=t;++u)s[u]>=0?o[l++]=s[u]:c=1&u;if(c===(1&t)){var h=o[0];o[0]=o[1],o[1]=h}e.push(o)}}return e}},{\"robust-orientation\":510,\"simplicial-complex\":520}],414:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=0,a=1;function o(t,e,r,n,i){this.mid=t,this.left=e,this.right=r,this.leftPoints=n,this.rightPoints=i,this.count=(e?e.count:0)+(r?r.count:0)+n.length}e.exports=function(t){if(!t||0===t.length)return new x(null);return new x(y(t))};var s=o.prototype;function l(t,e){t.mid=e.mid,t.left=e.left,t.right=e.right,t.leftPoints=e.leftPoints,t.rightPoints=e.rightPoints,t.count=e.count}function c(t,e){var r=y(e);t.mid=r.mid,t.left=r.left,t.right=r.right,t.leftPoints=r.leftPoints,t.rightPoints=r.rightPoints,t.count=r.count}function u(t,e){var r=t.intervals([]);r.push(e),c(t,r)}function h(t,e){var r=t.intervals([]),n=r.indexOf(e);return n<0?i:(r.splice(n,1),c(t,r),a)}function f(t,e,r){for(var n=0;n<t.length&&t[n][0]<=e;++n){var i=r(t[n]);if(i)return i}}function p(t,e,r){for(var n=t.length-1;n>=0&&t[n][1]>=e;--n){var i=r(t[n]);if(i)return i}}function d(t,e){for(var r=0;r<t.length;++r){var n=e(t[r]);if(n)return n}}function g(t,e){return t-e}function v(t,e){var r=t[0]-e[0];return r||t[1]-e[1]}function m(t,e){var r=t[1]-e[1];return r||t[0]-e[0]}function y(t){if(0===t.length)return null;for(var e=[],r=0;r<t.length;++r)e.push(t[r][0],t[r][1]);e.sort(g);var n=e[e.length>>1],i=[],a=[],s=[];for(r=0;r<t.length;++r){var l=t[r];l[1]<n?i.push(l):n<l[0]?a.push(l):s.push(l)}var c=s,u=s.slice();return c.sort(v),u.sort(m),new o(n,y(i),y(a),c,u)}function x(t){this.root=t}s.intervals=function(t){return t.push.apply(t,this.leftPoints),this.left&&this.left.intervals(t),this.right&&this.right.intervals(t),t},s.insert=function(t){var e=this.count-this.leftPoints.length;if(this.count+=1,t[1]<this.mid)this.left?4*(this.left.count+1)>3*(e+1)?u(this,t):this.left.insert(t):this.left=y([t]);else if(t[0]>this.mid)this.right?4*(this.right.count+1)>3*(e+1)?u(this,t):this.right.insert(t):this.right=y([t]);else{var r=n.ge(this.leftPoints,t,v),i=n.ge(this.rightPoints,t,m);this.leftPoints.splice(r,0,t),this.rightPoints.splice(i,0,t)}},s.remove=function(t){var e=this.count-this.leftPoints;if(t[1]<this.mid)return this.left?4*(this.right?this.right.count:0)>3*(e-1)?h(this,t):2===(c=this.left.remove(t))?(this.left=null,this.count-=1,a):(c===a&&(this.count-=1),c):i;if(t[0]>this.mid)return this.right?4*(this.left?this.left.count:0)>3*(e-1)?h(this,t):2===(c=this.right.remove(t))?(this.right=null,this.count-=1,a):(c===a&&(this.count-=1),c):i;if(1===this.count)return this.leftPoints[0]===t?2:i;if(1===this.leftPoints.length&&this.leftPoints[0]===t){if(this.left&&this.right){for(var r=this,o=this.left;o.right;)r=o,o=o.right;if(r===this)o.right=this.right;else{var s=this.left,c=this.right;r.count-=o.count,r.right=o.left,o.left=s,o.right=c}l(this,o),this.count=(this.left?this.left.count:0)+(this.right?this.right.count:0)+this.leftPoints.length}else this.left?l(this,this.left):l(this,this.right);return a}for(s=n.ge(this.leftPoints,t,v);s<this.leftPoints.length&&this.leftPoints[s][0]===t[0];++s)if(this.leftPoints[s]===t){this.count-=1,this.leftPoints.splice(s,1);for(c=n.ge(this.rightPoints,t,m);c<this.rightPoints.length&&this.rightPoints[c][1]===t[1];++c)if(this.rightPoints[c]===t)return this.rightPoints.splice(c,1),a}return i},s.queryPoint=function(t,e){if(t<this.mid){if(this.left)if(r=this.left.queryPoint(t,e))return r;return f(this.leftPoints,t,e)}if(t>this.mid){var r;if(this.right)if(r=this.right.queryPoint(t,e))return r;return p(this.rightPoints,t,e)}return d(this.leftPoints,e)},s.queryInterval=function(t,e,r){var n;if(t<this.mid&&this.left&&(n=this.left.queryInterval(t,e,r)))return n;if(e>this.mid&&this.right&&(n=this.right.queryInterval(t,e,r)))return n;return e<this.mid?f(this.leftPoints,e,r):t>this.mid?p(this.rightPoints,t,r):d(this.leftPoints,r)};var b=x.prototype;b.insert=function(t){this.root?this.root.insert(t):this.root=new o(t[0],null,null,[t],[t])},b.remove=function(t){if(this.root){var e=this.root.remove(t);return 2===e&&(this.root=null),e!==i}return!1},b.queryPoint=function(t,e){if(this.root)return this.root.queryPoint(t,e)},b.queryInterval=function(t,e,r){if(t<=e&&this.root)return this.root.queryInterval(t,e,r)},Object.defineProperty(b,\"count\",{get:function(){return this.root?this.root.count:0}}),Object.defineProperty(b,\"intervals\",{get:function(){return this.root?this.root.intervals([]):[]}})},{\"binary-search-bounds\":91}],415:[function(t,e,r){\"use strict\";e.exports=function(t,e){e=e||new Array(t.length);for(var r=0;r<t.length;++r)e[t[r]]=r;return e}},{}],416:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=r;return e}},{}],417:[function(t,e,r){e.exports=!0},{}],418:[function(t,e,r){function n(t){return!!t.constructor&&\"function\"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}e.exports=function(t){return null!=t&&(n(t)||function(t){return\"function\"==typeof t.readFloatLE&&\"function\"==typeof t.slice&&n(t.slice(0,0))}(t)||!!t._isBuffer)}},{}],419:[function(t,e,r){\"use strict\";e.exports=\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion))},{}],420:[function(t,e,r){\"use strict\";e.exports=a,e.exports.isMobile=a;var n=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i,i=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino|android|ipad|playbook|silk/i;function a(t){t||(t={});var e=t.ua;return e||\"undefined\"==typeof navigator||(e=navigator.userAgent),e&&e.headers&&\"string\"==typeof e.headers[\"user-agent\"]&&(e=e.headers[\"user-agent\"]),\"string\"==typeof e&&(t.tablet?i.test(e):n.test(e))}},{}],421:[function(t,e,r){\"use strict\";e.exports=function(t){var e=typeof t;return null!==t&&(\"object\"===e||\"function\"===e)}},{}],422:[function(t,e,r){\"use strict\";var n=Object.prototype.toString;e.exports=function(t){var e;return\"[object Object]\"===n.call(t)&&(null===(e=Object.getPrototypeOf(t))||e===Object.getPrototypeOf({}))}},{}],423:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=t.length,n=0;n<r;n++)if(((e=t.charCodeAt(n))<9||e>13)&&32!==e&&133!==e&&160!==e&&5760!==e&&6158!==e&&(e<8192||e>8205)&&8232!==e&&8233!==e&&8239!==e&&8287!==e&&8288!==e&&12288!==e&&65279!==e)return!1;return!0}},{}],424:[function(t,e,r){\"use strict\";e.exports=function(t){return\"string\"==typeof t&&(t=t.trim(),!!(/^[mzlhvcsqta]\\s*[-+.0-9][^mlhvzcsqta]+/i.test(t)&&/[\\dz]$/i.test(t)&&t.length>4))}},{}],425:[function(t,e,r){e.exports=function(t,e,r){return t*(1-r)+e*r}},{}],426:[function(t,e,r){var n,i;n=this,i=function(){\"use strict\";var t,e,r;function n(n,i){if(t)if(e){var a=\"var sharedChunk = {}; (\"+t+\")(sharedChunk); (\"+e+\")(sharedChunk);\",o={};t(o),(r=i(o)).workerUrl=window.URL.createObjectURL(new Blob([a],{type:\"text/javascript\"}))}else e=i;else t=i}return n(0,function(t){function e(t,e){return t(e={exports:{}},e.exports),e.exports}var r=n;function n(t,e,r,n){this.cx=3*t,this.bx=3*(r-t)-this.cx,this.ax=1-this.cx-this.bx,this.cy=3*e,this.by=3*(n-e)-this.cy,this.ay=1-this.cy-this.by,this.p1x=t,this.p1y=n,this.p2x=r,this.p2y=n}n.prototype.sampleCurveX=function(t){return((this.ax*t+this.bx)*t+this.cx)*t},n.prototype.sampleCurveY=function(t){return((this.ay*t+this.by)*t+this.cy)*t},n.prototype.sampleCurveDerivativeX=function(t){return(3*this.ax*t+2*this.bx)*t+this.cx},n.prototype.solveCurveX=function(t,e){var r,n,i,a,o;for(void 0===e&&(e=1e-6),i=t,o=0;o<8;o++){if(a=this.sampleCurveX(i)-t,Math.abs(a)<e)return i;var s=this.sampleCurveDerivativeX(i);if(Math.abs(s)<1e-6)break;i-=a/s}if((i=t)<(r=0))return r;if(i>(n=1))return n;for(;r<n;){if(a=this.sampleCurveX(i),Math.abs(a-t)<e)return i;t>a?r=i:n=i,i=.5*(n-r)+r}return i},n.prototype.solve=function(t,e){return this.sampleCurveY(this.solveCurveX(t,e))};var i=a;function a(t,e){this.x=t,this.y=e}function o(t,e){if(Array.isArray(t)){if(!Array.isArray(e)||t.length!==e.length)return!1;for(var r=0;r<t.length;r++)if(!o(t[r],e[r]))return!1;return!0}if(\"object\"==typeof t&&null!==t&&null!==e){if(\"object\"!=typeof e)return!1;if(Object.keys(t).length!==Object.keys(e).length)return!1;for(var n in t)if(!o(t[n],e[n]))return!1;return!0}return t===e}function s(t,e,n,i){var a=new r(t,e,n,i);return function(t){return a.solve(t)}}a.prototype={clone:function(){return new a(this.x,this.y)},add:function(t){return this.clone()._add(t)},sub:function(t){return this.clone()._sub(t)},multByPoint:function(t){return this.clone()._multByPoint(t)},divByPoint:function(t){return this.clone()._divByPoint(t)},mult:function(t){return this.clone()._mult(t)},div:function(t){return this.clone()._div(t)},rotate:function(t){return this.clone()._rotate(t)},rotateAround:function(t,e){return this.clone()._rotateAround(t,e)},matMult:function(t){return this.clone()._matMult(t)},unit:function(){return this.clone()._unit()},perp:function(){return this.clone()._perp()},round:function(){return this.clone()._round()},mag:function(){return Math.sqrt(this.x*this.x+this.y*this.y)},equals:function(t){return this.x===t.x&&this.y===t.y},dist:function(t){return Math.sqrt(this.distSqr(t))},distSqr:function(t){var e=t.x-this.x,r=t.y-this.y;return e*e+r*r},angle:function(){return Math.atan2(this.y,this.x)},angleTo:function(t){return Math.atan2(this.y-t.y,this.x-t.x)},angleWith:function(t){return this.angleWithSep(t.x,t.y)},angleWithSep:function(t,e){return Math.atan2(this.x*e-this.y*t,this.x*t+this.y*e)},_matMult:function(t){var e=t[0]*this.x+t[1]*this.y,r=t[2]*this.x+t[3]*this.y;return this.x=e,this.y=r,this},_add:function(t){return this.x+=t.x,this.y+=t.y,this},_sub:function(t){return this.x-=t.x,this.y-=t.y,this},_mult:function(t){return this.x*=t,this.y*=t,this},_div:function(t){return this.x/=t,this.y/=t,this},_multByPoint:function(t){return this.x*=t.x,this.y*=t.y,this},_divByPoint:function(t){return this.x/=t.x,this.y/=t.y,this},_unit:function(){return this._div(this.mag()),this},_perp:function(){var t=this.y;return this.y=this.x,this.x=-t,this},_rotate:function(t){var e=Math.cos(t),r=Math.sin(t),n=e*this.x-r*this.y,i=r*this.x+e*this.y;return this.x=n,this.y=i,this},_rotateAround:function(t,e){var r=Math.cos(t),n=Math.sin(t),i=e.x+r*(this.x-e.x)-n*(this.y-e.y),a=e.y+n*(this.x-e.x)+r*(this.y-e.y);return this.x=i,this.y=a,this},_round:function(){return this.x=Math.round(this.x),this.y=Math.round(this.y),this}},a.convert=function(t){return t instanceof a?t:Array.isArray(t)?new a(t[0],t[1]):t};var l=s(.25,.1,.25,1);function c(t,e,r){return Math.min(r,Math.max(e,t))}function u(t,e,r){var n=r-e,i=((t-e)%n+n)%n+e;return i===e?r:i}function h(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}var f=1;function p(){return f++}function d(){return function t(e){return e?(e^16*Math.random()>>e/4).toString(16):([1e7]+-[1e3]+-4e3+-8e3+-1e11).replace(/[018]/g,t)}()}function g(t){return!!t&&/^[0-9a-f]{8}-[0-9a-f]{4}-[4][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$/i.test(t)}function v(t,e){t.forEach(function(t){e[t]&&(e[t]=e[t].bind(e))})}function m(t,e){return-1!==t.indexOf(e,t.length-e.length)}function y(t,e,r){var n={};for(var i in t)n[i]=e.call(r||this,t[i],i,t);return n}function x(t,e,r){var n={};for(var i in t)e.call(r||this,t[i],i,t)&&(n[i]=t[i]);return n}function b(t){return Array.isArray(t)?t.map(b):\"object\"==typeof t&&t?y(t,b):t}var _={};function w(t){_[t]||(\"undefined\"!=typeof console&&console.warn(t),_[t]=!0)}function k(t,e,r){return(r.y-t.y)*(e.x-t.x)>(e.y-t.y)*(r.x-t.x)}function T(t){for(var e=0,r=0,n=t.length,i=n-1,a=void 0,o=void 0;r<n;i=r++)a=t[r],e+=((o=t[i]).x-a.x)*(a.y+o.y);return e}function A(t){var e={};if(t.replace(/(?:^|(?:\\s*\\,\\s*))([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)(?:\\=(?:([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)|(?:\\\"((?:[^\"\\\\]|\\\\.)*)\\\")))?/g,function(t,r,n,i){var a=n||i;return e[r]=!a||a.toLowerCase(),\"\"}),e[\"max-age\"]){var r=parseInt(e[\"max-age\"],10);isNaN(r)?delete e[\"max-age\"]:e[\"max-age\"]=r}return e}function M(t){try{var e=self[t];return e.setItem(\"_mapbox_test_\",1),e.removeItem(\"_mapbox_test_\"),!0}catch(t){return!1}}var S,E,C,L=self.performance&&self.performance.now?self.performance.now.bind(self.performance):Date.now.bind(Date),P=self.requestAnimationFrame||self.mozRequestAnimationFrame||self.webkitRequestAnimationFrame||self.msRequestAnimationFrame,O=self.cancelAnimationFrame||self.mozCancelAnimationFrame||self.webkitCancelAnimationFrame||self.msCancelAnimationFrame,z={now:L,frame:function(t){var e=P(t);return{cancel:function(){return O(e)}}},getImageData:function(t){var e=self.document.createElement(\"canvas\"),r=e.getContext(\"2d\");if(!r)throw new Error(\"failed to create canvas 2d context\");return e.width=t.width,e.height=t.height,r.drawImage(t,0,0,t.width,t.height),r.getImageData(0,0,t.width,t.height)},resolveURL:function(t){return S||(S=self.document.createElement(\"a\")),S.href=t,S.href},hardwareConcurrency:self.navigator.hardwareConcurrency||4,get devicePixelRatio(){return self.devicePixelRatio}},I={API_URL:\"https://api.mapbox.com\",get EVENTS_URL(){return this.API_URL?0===this.API_URL.indexOf(\"https://api.mapbox.cn\")?\"https://events.mapbox.cn/events/v2\":0===this.API_URL.indexOf(\"https://api.mapbox.com\")?\"https://events.mapbox.com/events/v2\":null:null},FEEDBACK_URL:\"https://apps.mapbox.com/feedback\",REQUIRE_ACCESS_TOKEN:!0,ACCESS_TOKEN:null,MAX_PARALLEL_IMAGE_REQUESTS:16},D={supported:!1,testSupport:function(t){!R&&C&&(F?B(t):E=t)}},R=!1,F=!1;function B(t){var e=t.createTexture();t.bindTexture(t.TEXTURE_2D,e);try{if(t.texImage2D(t.TEXTURE_2D,0,t.RGBA,t.RGBA,t.UNSIGNED_BYTE,C),t.isContextLost())return;D.supported=!0}catch(t){}t.deleteTexture(e),R=!0}self.document&&((C=self.document.createElement(\"img\")).onload=function(){E&&B(E),E=null,F=!0},C.onerror=function(){R=!0,E=null},C.src=\"data:image/webp;base64,UklGRh4AAABXRUJQVlA4TBEAAAAvAQAAAAfQ//73v/+BiOh/AAA=\");var N=\"01\",j=function(t){this._transformRequestFn=t,this._createSkuToken()};j.prototype._createSkuToken=function(){var t=function(){for(var t=\"\",e=0;e<10;e++)t+=\"0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ\"[Math.floor(62*Math.random())];return{token:[\"1\",N,t].join(\"\"),tokenExpiresAt:Date.now()+432e5}}();this._skuToken=t.token,this._skuTokenExpiresAt=t.tokenExpiresAt},j.prototype._isSkuTokenExpired=function(){return Date.now()>this._skuTokenExpiresAt},j.prototype.transformRequest=function(t,e){return this._transformRequestFn&&this._transformRequestFn(t,e)||{url:t}},j.prototype.normalizeStyleURL=function(t,e){return Y(t,e)},j.prototype.normalizeGlyphsURL=function(t,e){return W(t,e)},j.prototype.normalizeSourceURL=function(t,e){return X(t,e)},j.prototype.normalizeSpriteURL=function(t,e,r,n){return Z(t,e,r,n)},j.prototype.normalizeTileURL=function(t,e,r){return this._isSkuTokenExpired()&&this._createSkuToken(),K(t,e,r,this._skuToken)},j.prototype.canonicalizeTileURL=function(t){return Q(t)},j.prototype.canonicalizeTileset=function(t,e){return tt(t,e)};var U=\"See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\";function V(t,e){var r=rt(I.API_URL);if(t.protocol=r.protocol,t.authority=r.authority,\"/\"!==r.path&&(t.path=\"\"+r.path+t.path),!I.REQUIRE_ACCESS_TOKEN)return nt(t);if(!(e=e||I.ACCESS_TOKEN))throw new Error(\"An API access token is required to use Mapbox GL. \"+U);if(\"s\"===e[0])throw new Error(\"Use a public access token (pk.*) with Mapbox GL, not a secret access token (sk.*). \"+U);return t.params.push(\"access_token=\"+e),nt(t)}function q(t){return 0===t.indexOf(\"mapbox:\")}var H=/^((https?:)?\\/\\/)?([^\\/]+\\.)?mapbox\\.c(n|om)(\\/|\\?|$)/i;function G(t){return H.test(t)}var Y=function(t,e){if(!q(t))return t;var r=rt(t);return r.path=\"/styles/v1\"+r.path,V(r,e)},W=function(t,e){if(!q(t))return t;var r=rt(t);return r.path=\"/fonts/v1\"+r.path,V(r,e)},X=function(t,e){if(!q(t))return t;var r=rt(t);return r.path=\"/v4/\"+r.authority+\".json\",r.params.push(\"secure\"),V(r,e)},Z=function(t,e,r,n){var i=rt(t);return q(t)?(i.path=\"/styles/v1\"+i.path+\"/sprite\"+e+r,V(i,n)):(i.path+=\"\"+e+r,nt(i))},J=/(\\.(png|jpg)\\d*)(?=$)/,K=function(t,e,r,n){if(!e||!q(e))return t;var i=rt(t),a=z.devicePixelRatio>=2||512===r?\"@2x\":\"\",o=D.supported?\".webp\":\"$1\";return i.path=i.path.replace(J,\"\"+a+o),i.path=\"/v4\"+i.path,I.REQUIRE_ACCESS_TOKEN&&I.ACCESS_TOKEN&&n&&i.params.push(\"sku=\"+n),V(i)},$=/\\.[\\w]+$/,Q=function(t){var e=rt(t);if(!e.path.match(/(^\\/v4\\/)/)||!e.path.match($))return t;var r=\"mapbox://tiles/\";r+=e.path.replace(\"/v4/\",\"\");var n=e.params.filter(function(t){return!t.match(/^access_token=/)});return n.length&&(r+=\"?\"+n.join(\"&\")),r},tt=function(t,e){if(!q(e))return t.tiles||[];for(var r=[],n=0,i=t.tiles;n<i.length;n+=1){var a=i[n],o=Q(a);r.push(o)}return r},et=/^(\\w+):\\/\\/([^\\/?]*)(\\/[^?]+)?\\??(.+)?/;function rt(t){var e=t.match(et);if(!e)throw new Error(\"Unable to parse URL object\");return{protocol:e[1],authority:e[2],path:e[3]||\"/\",params:e[4]?e[4].split(\"&\"):[]}}function nt(t){var e=t.params.length?\"?\"+t.params.join(\"&\"):\"\";return t.protocol+\"://\"+t.authority+t.path+e}function it(t){if(!t)return null;var e,r=t.split(\".\");if(!r||3!==r.length)return null;try{return JSON.parse((e=r[1],decodeURIComponent(self.atob(e).split(\"\").map(function(t){return\"%\"+(\"00\"+t.charCodeAt(0).toString(16)).slice(-2)}).join(\"\"))))}catch(t){return null}}var at=function(t){this.type=t,this.anonId=null,this.eventData={},this.queue=[],this.pendingRequest=null};at.prototype.getStorageKey=function(t){var e,r=it(I.ACCESS_TOKEN),n=\"\";return r&&r.u?(e=r.u,n=self.btoa(encodeURIComponent(e).replace(/%([0-9A-F]{2})/g,function(t,e){return String.fromCharCode(Number(\"0x\"+e))}))):n=I.ACCESS_TOKEN||\"\",t?\"mapbox.eventData.\"+t+\":\"+n:\"mapbox.eventData:\"+n},at.prototype.fetchEventData=function(){var t=M(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{var n=self.localStorage.getItem(e);n&&(this.eventData=JSON.parse(n));var i=self.localStorage.getItem(r);i&&(this.anonId=i)}catch(t){w(\"Unable to read from LocalStorage\")}},at.prototype.saveEventData=function(){var t=M(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{self.localStorage.setItem(r,this.anonId),Object.keys(this.eventData).length>=1&&self.localStorage.setItem(e,JSON.stringify(this.eventData))}catch(t){w(\"Unable to write to LocalStorage\")}},at.prototype.processRequests=function(){},at.prototype.postEvent=function(t,e,r){var n=this;if(I.EVENTS_URL){var i=rt(I.EVENTS_URL);i.params.push(\"access_token=\"+(I.ACCESS_TOKEN||\"\"));var a={event:this.type,created:new Date(t).toISOString(),sdkIdentifier:\"mapbox-gl-js\",sdkVersion:\"1.1.1\",skuId:N,userId:this.anonId},o=e?h(a,e):a,s={url:nt(i),headers:{\"Content-Type\":\"text/plain\"},body:JSON.stringify([o])};this.pendingRequest=St(s,function(t){n.pendingRequest=null,r(t),n.saveEventData(),n.processRequests()})}},at.prototype.queueRequest=function(t){this.queue.push(t),this.processRequests()};var ot,st=function(t){function e(){t.call(this,\"map.load\"),this.success={},this.skuToken=\"\"}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.postMapLoadEvent=function(t,e,r){this.skuToken=r,I.EVENTS_URL&&I.ACCESS_TOKEN&&Array.isArray(t)&&t.some(function(t){return q(t)||G(t)})&&this.queueRequest({id:e,timestamp:Date.now()})},e.prototype.processRequests=function(){var t=this;if(!this.pendingRequest&&0!==this.queue.length){var e=this.queue.shift(),r=e.id,n=e.timestamp;r&&this.success[r]||(this.anonId||this.fetchEventData(),g(this.anonId)||(this.anonId=d()),this.postEvent(n,{skuToken:this.skuToken},function(e){e||r&&(t.success[r]=!0)}))}},e}(at),lt=new(function(t){function e(){t.call(this,\"appUserTurnstile\")}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.postTurnstileEvent=function(t){I.EVENTS_URL&&I.ACCESS_TOKEN&&Array.isArray(t)&&t.some(function(t){return q(t)||G(t)})&&this.queueRequest(Date.now())},e.prototype.processRequests=function(){var t=this;if(!this.pendingRequest&&0!==this.queue.length){this.anonId&&this.eventData.lastSuccess&&this.eventData.tokenU||this.fetchEventData();var e=it(I.ACCESS_TOKEN),r=e?e.u:I.ACCESS_TOKEN,n=r!==this.eventData.tokenU;g(this.anonId)||(this.anonId=d(),n=!0);var i=this.queue.shift();if(this.eventData.lastSuccess){var a=new Date(this.eventData.lastSuccess),o=new Date(i),s=(i-this.eventData.lastSuccess)/864e5;n=n||s>=1||s<-1||a.getDate()!==o.getDate()}else n=!0;if(!n)return this.processRequests();this.postEvent(i,{\"enabled.telemetry\":!1},function(e){e||(t.eventData.lastSuccess=i,t.eventData.tokenU=r)})}},e}(at)),ct=lt.postTurnstileEvent.bind(lt),ut=new st,ht=ut.postMapLoadEvent.bind(ut),ft=\"mapbox-tiles\",pt=500,dt=50,gt=42e4;function vt(t){var e=t.indexOf(\"?\");return e<0?t:t.slice(0,e)}var mt=1/0,yt={Unknown:\"Unknown\",Style:\"Style\",Source:\"Source\",Tile:\"Tile\",Glyphs:\"Glyphs\",SpriteImage:\"SpriteImage\",SpriteJSON:\"SpriteJSON\",Image:\"Image\"};\"function\"==typeof Object.freeze&&Object.freeze(yt);var xt=function(t){function e(e,r,n){401===r&&G(n)&&(e+=\": you may have provided an invalid Mapbox access token. See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\"),t.call(this,e),this.status=r,this.url=n,this.name=this.constructor.name,this.message=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.toString=function(){return this.name+\": \"+this.message+\" (\"+this.status+\"): \"+this.url},e}(Error);function bt(){return\"undefined\"!=typeof WorkerGlobalScope&&\"undefined\"!=typeof self&&self instanceof WorkerGlobalScope}var _t=bt()?function(){return self.worker&&self.worker.referrer}:function(){var t=self.location.origin;if(t&&\"null\"!==t&&\"file://\"!==t)return t+self.location.pathname};function wt(t,e){var r,n=new self.AbortController,i=new self.Request(t.url,{method:t.method||\"GET\",body:t.body,credentials:t.credentials,headers:t.headers,referrer:_t(),signal:n.signal}),a=!1,o=!1,s=(r=i.url).indexOf(\"sku=\")>0&&G(r);\"json\"===t.type&&i.headers.set(\"Accept\",\"application/json\");var l=function(r,n,a){if(!o){if(r&&\"SecurityError\"!==r.message&&w(r),n&&a)return c(n);var l=Date.now();self.fetch(i).then(function(r){if(r.ok){var n=s?r.clone():null;return c(r,n,l)}return e(new xt(r.statusText,r.status,t.url))}).catch(function(t){20!==t.code&&e(new Error(t.message))})}},c=function(r,n,s){(\"arrayBuffer\"===t.type?r.arrayBuffer():\"json\"===t.type?r.json():r.text()).then(function(t){o||(n&&s&&function(t,e,r){if(self.caches){var n={status:e.status,statusText:e.statusText,headers:new self.Headers};e.headers.forEach(function(t,e){return n.headers.set(e,t)});var i=A(e.headers.get(\"Cache-Control\")||\"\");i[\"no-store\"]||(i[\"max-age\"]&&n.headers.set(\"Expires\",new Date(r+1e3*i[\"max-age\"]).toUTCString()),new Date(n.headers.get(\"Expires\")).getTime()-r<gt||function(t,e){if(void 0===ot)try{new Response(new ReadableStream),ot=!0}catch(t){ot=!1}ot?e(t.body):t.blob().then(e)}(e,function(e){var r=new self.Response(e,n);self.caches.open(ft).then(function(e){return e.put(vt(t.url),r)})}))}}(i,n,s),a=!0,e(null,t,r.headers.get(\"Cache-Control\"),r.headers.get(\"Expires\")))}).catch(function(t){return e(new Error(t.message))})};return s?function(t,e){if(!self.caches)return e(null);var r=vt(t.url);self.caches.open(ft).catch(e).then(function(t){t.match(r).catch(e).then(function(n){var i=function(t){if(!t)return!1;var e=new Date(t.headers.get(\"Expires\")),r=A(t.headers.get(\"Cache-Control\")||\"\");return e>Date.now()&&!r[\"no-cache\"]}(n);t.delete(r),i&&t.put(r,n.clone()),e(null,n,i)})})}(i,l):l(null,null),{cancel:function(){o=!0,a||n.abort()}}}var kt,Tt,At=function(t,e){if(!/^file:/.test(t.url)){if(self.fetch&&self.Request&&self.AbortController&&self.Request.prototype.hasOwnProperty(\"signal\"))return wt(t,e);if(bt()&&self.worker&&self.worker.actor)return self.worker.actor.send(\"getResource\",t,e)}return function(t,e){var r=new self.XMLHttpRequest;for(var n in r.open(t.method||\"GET\",t.url,!0),\"arrayBuffer\"===t.type&&(r.responseType=\"arraybuffer\"),t.headers)r.setRequestHeader(n,t.headers[n]);return\"json\"===t.type&&r.setRequestHeader(\"Accept\",\"application/json\"),r.withCredentials=\"include\"===t.credentials,r.onerror=function(){e(new Error(r.statusText))},r.onload=function(){if((r.status>=200&&r.status<300||0===r.status)&&null!==r.response){var n=r.response;if(\"json\"===t.type)try{n=JSON.parse(r.response)}catch(t){return e(t)}e(null,n,r.getResponseHeader(\"Cache-Control\"),r.getResponseHeader(\"Expires\"))}else e(new xt(r.statusText,r.status,t.url))},r.send(t.body),{cancel:function(){return r.abort()}}}(t,e)},Mt=function(t,e){return At(h(t,{type:\"arrayBuffer\"}),e)},St=function(t,e){return At(h(t,{method:\"POST\"}),e)};kt=[],Tt=0;var Et=function(t,e){if(Tt>=I.MAX_PARALLEL_IMAGE_REQUESTS){var r={requestParameters:t,callback:e,cancelled:!1,cancel:function(){this.cancelled=!0}};return kt.push(r),r}Tt++;var n=!1,i=function(){if(!n)for(n=!0,Tt--;kt.length&&Tt<I.MAX_PARALLEL_IMAGE_REQUESTS;){var t=kt.shift(),e=t.requestParameters,r=t.callback;t.cancelled||(t.cancel=Et(e,r).cancel)}},a=Mt(t,function(t,r,n,a){if(i(),t)e(t);else if(r){var o=new self.Image,s=self.URL||self.webkitURL;o.onload=function(){e(null,o),s.revokeObjectURL(o.src)},o.onerror=function(){return e(new Error(\"Could not load image. Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.\"))};var l=new self.Blob([new Uint8Array(r)],{type:\"image/png\"});o.cacheControl=n,o.expires=a,o.src=r.byteLength?s.createObjectURL(l):\"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAC0lEQVQYV2NgAAIAAAUAAarVyFEAAAAASUVORK5CYII=\"}});return{cancel:function(){a.cancel(),i()}}};function Ct(t,e,r){r[t]&&-1!==r[t].indexOf(e)||(r[t]=r[t]||[],r[t].push(e))}function Lt(t,e,r){if(r&&r[t]){var n=r[t].indexOf(e);-1!==n&&r[t].splice(n,1)}}var Pt=function(t,e){void 0===e&&(e={}),h(this,e),this.type=t},Ot=function(t){function e(e,r){void 0===r&&(r={}),t.call(this,\"error\",h({error:e},r))}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Pt),zt=function(){};zt.prototype.on=function(t,e){return this._listeners=this._listeners||{},Ct(t,e,this._listeners),this},zt.prototype.off=function(t,e){return Lt(t,e,this._listeners),Lt(t,e,this._oneTimeListeners),this},zt.prototype.once=function(t,e){return this._oneTimeListeners=this._oneTimeListeners||{},Ct(t,e,this._oneTimeListeners),this},zt.prototype.fire=function(t,e){\"string\"==typeof t&&(t=new Pt(t,e||{}));var r=t.type;if(this.listens(r)){t.target=this;for(var n=0,i=this._listeners&&this._listeners[r]?this._listeners[r].slice():[];n<i.length;n+=1)i[n].call(this,t);for(var a=0,o=this._oneTimeListeners&&this._oneTimeListeners[r]?this._oneTimeListeners[r].slice():[];a<o.length;a+=1){var s=o[a];Lt(r,s,this._oneTimeListeners),s.call(this,t)}var l=this._eventedParent;l&&(h(t,\"function\"==typeof this._eventedParentData?this._eventedParentData():this._eventedParentData),l.fire(t))}else t instanceof Ot&&console.error(t.error);return this},zt.prototype.listens=function(t){return this._listeners&&this._listeners[t]&&this._listeners[t].length>0||this._oneTimeListeners&&this._oneTimeListeners[t]&&this._oneTimeListeners[t].length>0||this._eventedParent&&this._eventedParent.listens(t)},zt.prototype.setEventedParent=function(t,e){return this._eventedParent=t,this._eventedParentData=e,this};var It={$version:8,$root:{version:{required:!0,type:\"enum\",values:[8]},name:{type:\"string\"},metadata:{type:\"*\"},center:{type:\"array\",value:\"number\"},zoom:{type:\"number\"},bearing:{type:\"number\",default:0,period:360,units:\"degrees\"},pitch:{type:\"number\",default:0,units:\"degrees\"},light:{type:\"light\"},sources:{required:!0,type:\"sources\"},sprite:{type:\"string\"},glyphs:{type:\"string\"},transition:{type:\"transition\"},layers:{required:!0,type:\"array\",value:\"layer\"}},sources:{\"*\":{type:\"source\"}},source:[\"source_vector\",\"source_raster\",\"source_raster_dem\",\"source_geojson\",\"source_video\",\"source_image\"],source_vector:{type:{required:!0,type:\"enum\",values:{vector:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},attribution:{type:\"string\"},\"*\":{type:\"*\"}},source_raster:{type:{required:!0,type:\"enum\",values:{raster:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},attribution:{type:\"string\"},\"*\":{type:\"*\"}},source_raster_dem:{type:{required:!0,type:\"enum\",values:{\"raster-dem\":{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},attribution:{type:\"string\"},encoding:{type:\"enum\",values:{terrarium:{},mapbox:{}},default:\"mapbox\"},\"*\":{type:\"*\"}},source_geojson:{type:{required:!0,type:\"enum\",values:{geojson:{}}},data:{type:\"*\"},maxzoom:{type:\"number\",default:18},attribution:{type:\"string\"},buffer:{type:\"number\",default:128,maximum:512,minimum:0},tolerance:{type:\"number\",default:.375},cluster:{type:\"boolean\",default:!1},clusterRadius:{type:\"number\",default:50,minimum:0},clusterMaxZoom:{type:\"number\"},clusterProperties:{type:\"*\"},lineMetrics:{type:\"boolean\",default:!1},generateId:{type:\"boolean\",default:!1}},source_video:{type:{required:!0,type:\"enum\",values:{video:{}}},urls:{required:!0,type:\"array\",value:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},source_image:{type:{required:!0,type:\"enum\",values:{image:{}}},url:{required:!0,type:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},layer:{id:{type:\"string\",required:!0},type:{type:\"enum\",values:{fill:{},line:{},symbol:{},circle:{},heatmap:{},\"fill-extrusion\":{},raster:{},hillshade:{},background:{}},required:!0},metadata:{type:\"*\"},source:{type:\"string\"},\"source-layer\":{type:\"string\"},minzoom:{type:\"number\",minimum:0,maximum:24},maxzoom:{type:\"number\",minimum:0,maximum:24},filter:{type:\"filter\"},layout:{type:\"layout\"},paint:{type:\"paint\"}},layout:[\"layout_fill\",\"layout_line\",\"layout_circle\",\"layout_heatmap\",\"layout_fill-extrusion\",\"layout_symbol\",\"layout_raster\",\"layout_hillshade\",\"layout_background\"],layout_background:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_fill:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_circle:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_heatmap:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},\"layout_fill-extrusion\":{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_line:{\"line-cap\":{type:\"enum\",values:{butt:{},round:{},square:{}},default:\"butt\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-join\":{type:\"enum\",values:{bevel:{},round:{},miter:{}},default:\"miter\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"line-miter-limit\":{type:\"number\",default:2,requires:[{\"line-join\":\"miter\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-round-limit\":{type:\"number\",default:1.05,requires:[{\"line-join\":\"round\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_symbol:{\"symbol-placement\":{type:\"enum\",values:{point:{},line:{},\"line-center\":{}},default:\"point\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-spacing\":{type:\"number\",default:250,minimum:1,units:\"pixels\",requires:[{\"symbol-placement\":\"line\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-avoid-edges\":{type:\"boolean\",default:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"symbol-z-order\":{type:\"enum\",values:{auto:{},\"viewport-y\":{},source:{}},default:\"auto\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-optional\":{type:\"boolean\",default:!1,requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-size\":{type:\"number\",default:1,minimum:0,units:\"factor of the original icon size\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-text-fit\":{type:\"enum\",values:{none:{},width:{},height:{},both:{}},default:\"none\",requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-text-fit-padding\":{type:\"array\",value:\"number\",length:4,default:[0,0,0,0],units:\"pixels\",requires:[\"icon-image\",\"text-field\",{\"icon-text-fit\":[\"both\",\"width\",\"height\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-image\":{type:\"string\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-keep-upright\":{type:\"boolean\",default:!1,requires:[\"icon-image\",{\"icon-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-offset\":{type:\"array\",value:\"number\",length:2,default:[0,0],requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-anchor\":{type:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-field\":{type:\"formatted\",default:\"\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-font\":{type:\"array\",value:\"string\",default:[\"Open Sans Regular\",\"Arial Unicode MS Regular\"],requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-size\":{type:\"number\",default:16,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-width\":{type:\"number\",default:10,minimum:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-line-height\":{type:\"number\",default:1.2,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-letter-spacing\":{type:\"number\",default:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-justify\":{type:\"enum\",values:{auto:{},left:{},center:{},right:{}},default:\"center\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-radial-offset\":{type:\"number\",units:\"ems\",default:0,requires:[{\"!\":\"text-offset\"}],\"property-type\":\"data-driven\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]}},\"text-variable-anchor\":{type:\"array\",value:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},requires:[{\"!\":\"text-anchor\"},{\"!\":\"text-offset\"},{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-anchor\":{type:\"enum\",requires:[\"text-field\"],values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-angle\":{type:\"number\",default:45,units:\"degrees\",requires:[\"text-field\",{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-keep-upright\":{type:\"boolean\",default:!0,requires:[\"text-field\",{\"text-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-transform\":{type:\"enum\",values:{none:{},uppercase:{},lowercase:{}},default:\"none\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-offset\":{type:\"array\",value:\"number\",units:\"ems\",length:2,default:[0,0],requires:[\"text-field\",{\"!\":\"text-radial-offset\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-optional\":{type:\"boolean\",default:!1,requires:[\"text-field\",\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_raster:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_hillshade:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},filter:{type:\"array\",value:\"*\"},filter_operator:{type:\"enum\",values:{\"==\":{},\"!=\":{},\">\":{},\">=\":{},\"<\":{},\"<=\":{},in:{},\"!in\":{},all:{},any:{},none:{},has:{},\"!has\":{}}},geometry_type:{type:\"enum\",values:{Point:{},LineString:{},Polygon:{}}},function:{expression:{type:\"expression\"},stops:{type:\"array\",value:\"function_stop\"},base:{type:\"number\",default:1,minimum:0},property:{type:\"string\",default:\"$zoom\"},type:{type:\"enum\",values:{identity:{},exponential:{},interval:{},categorical:{}},default:\"exponential\"},colorSpace:{type:\"enum\",values:{rgb:{},lab:{},hcl:{}},default:\"rgb\"},default:{type:\"*\",required:!1}},function_stop:{type:\"array\",minimum:0,maximum:22,value:[\"number\",\"color\"],length:2},expression:{type:\"array\",value:\"*\",minimum:1},expression_name:{type:\"enum\",values:{let:{group:\"Variable binding\"},var:{group:\"Variable binding\"},literal:{group:\"Types\"},array:{group:\"Types\"},at:{group:\"Lookup\"},case:{group:\"Decision\"},match:{group:\"Decision\"},coalesce:{group:\"Decision\"},step:{group:\"Ramps, scales, curves\"},interpolate:{group:\"Ramps, scales, curves\"},\"interpolate-hcl\":{group:\"Ramps, scales, curves\"},\"interpolate-lab\":{group:\"Ramps, scales, curves\"},ln2:{group:\"Math\"},pi:{group:\"Math\"},e:{group:\"Math\"},typeof:{group:\"Types\"},string:{group:\"Types\"},number:{group:\"Types\"},boolean:{group:\"Types\"},object:{group:\"Types\"},collator:{group:\"Types\"},format:{group:\"Types\"},\"number-format\":{group:\"Types\"},\"to-string\":{group:\"Types\"},\"to-number\":{group:\"Types\"},\"to-boolean\":{group:\"Types\"},\"to-rgba\":{group:\"Color\"},\"to-color\":{group:\"Types\"},rgb:{group:\"Color\"},rgba:{group:\"Color\"},get:{group:\"Lookup\"},has:{group:\"Lookup\"},length:{group:\"Lookup\"},properties:{group:\"Feature data\"},\"feature-state\":{group:\"Feature data\"},\"geometry-type\":{group:\"Feature data\"},id:{group:\"Feature data\"},zoom:{group:\"Zoom\"},\"heatmap-density\":{group:\"Heatmap\"},\"line-progress\":{group:\"Feature data\"},accumulated:{group:\"Feature data\"},\"+\":{group:\"Math\"},\"*\":{group:\"Math\"},\"-\":{group:\"Math\"},\"/\":{group:\"Math\"},\"%\":{group:\"Math\"},\"^\":{group:\"Math\"},sqrt:{group:\"Math\"},log10:{group:\"Math\"},ln:{group:\"Math\"},log2:{group:\"Math\"},sin:{group:\"Math\"},cos:{group:\"Math\"},tan:{group:\"Math\"},asin:{group:\"Math\"},acos:{group:\"Math\"},atan:{group:\"Math\"},min:{group:\"Math\"},max:{group:\"Math\"},round:{group:\"Math\"},abs:{group:\"Math\"},ceil:{group:\"Math\"},floor:{group:\"Math\"},\"==\":{group:\"Decision\"},\"!=\":{group:\"Decision\"},\">\":{group:\"Decision\"},\"<\":{group:\"Decision\"},\">=\":{group:\"Decision\"},\"<=\":{group:\"Decision\"},all:{group:\"Decision\"},any:{group:\"Decision\"},\"!\":{group:\"Decision\"},\"is-supported-script\":{group:\"String\"},upcase:{group:\"String\"},downcase:{group:\"String\"},concat:{group:\"String\"},\"resolved-locale\":{group:\"String\"}}},light:{anchor:{type:\"enum\",default:\"viewport\",values:{map:{},viewport:{}},\"property-type\":\"data-constant\",transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]}},position:{type:\"array\",default:[1.15,210,30],length:3,value:\"number\",\"property-type\":\"data-constant\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]}},color:{type:\"color\",\"property-type\":\"data-constant\",default:\"#ffffff\",expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0},intensity:{type:\"number\",\"property-type\":\"data-constant\",default:.5,minimum:0,maximum:1,expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0}},paint:[\"paint_fill\",\"paint_line\",\"paint_circle\",\"paint_heatmap\",\"paint_fill-extrusion\",\"paint_symbol\",\"paint_raster\",\"paint_hillshade\",\"paint_background\"],paint_fill:{\"fill-antialias\":{type:\"boolean\",default:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-outline-color\":{type:\"color\",transition:!0,requires:[{\"!\":\"fill-pattern\"},{\"fill-antialias\":!0}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"}},\"paint_fill-extrusion\":{\"fill-extrusion-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-extrusion-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-extrusion-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"fill-extrusion-height\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-base\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,requires:[\"fill-extrusion-height\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-vertical-gradient\":{type:\"boolean\",default:!0,transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_line:{\"line-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"line-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-width\":{type:\"number\",default:1,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-gap-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-offset\":{type:\"number\",default:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-dasharray\":{type:\"array\",value:\"number\",minimum:0,transition:!0,units:\"line widths\",requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"line-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"line-gradient\":{type:\"color\",transition:!1,requires:[{\"!\":\"line-dasharray\"},{\"!\":\"line-pattern\"},{source:\"geojson\",has:{lineMetrics:!0}}],expression:{interpolated:!0,parameters:[\"line-progress\"]},\"property-type\":\"color-ramp\"}},paint_circle:{\"circle-radius\":{type:\"number\",default:5,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-blur\":{type:\"number\",default:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"circle-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-scale\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-stroke-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"}},paint_heatmap:{\"heatmap-radius\":{type:\"number\",default:30,minimum:1,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-weight\":{type:\"number\",default:1,minimum:0,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-intensity\":{type:\"number\",default:1,minimum:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"heatmap-color\":{type:\"color\",default:[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,\"rgba(0, 0, 255, 0)\",.1,\"royalblue\",.3,\"cyan\",.5,\"lime\",.7,\"yellow\",1,\"red\"],transition:!1,expression:{interpolated:!0,parameters:[\"heatmap-density\"]},\"property-type\":\"color-ramp\"},\"heatmap-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_symbol:{\"icon-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"icon-image\",\"icon-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"text-field\",\"text-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_raster:{\"raster-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-hue-rotate\":{type:\"number\",default:0,period:360,transition:!0,units:\"degrees\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-min\":{type:\"number\",default:0,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-max\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-saturation\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-contrast\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-resampling\":{type:\"enum\",values:{linear:{},nearest:{}},default:\"linear\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-fade-duration\":{type:\"number\",default:300,minimum:0,transition:!1,units:\"milliseconds\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_hillshade:{\"hillshade-illumination-direction\":{type:\"number\",default:335,minimum:0,maximum:359,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-illumination-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-exaggeration\":{type:\"number\",default:.5,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-shadow-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-highlight-color\":{type:\"color\",default:\"#FFFFFF\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-accent-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_background:{\"background-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"background-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"background-pattern\":{type:\"string\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"background-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},transition:{duration:{type:\"number\",default:300,minimum:0,units:\"milliseconds\"},delay:{type:\"number\",default:0,minimum:0,units:\"milliseconds\"}},\"property-type\":{\"data-driven\":{type:\"property-type\"},\"cross-faded\":{type:\"property-type\"},\"cross-faded-data-driven\":{type:\"property-type\"},\"color-ramp\":{type:\"property-type\"},\"data-constant\":{type:\"property-type\"},constant:{type:\"property-type\"}}},Dt=function(t,e,r,n){this.message=(t?t+\": \":\"\")+r,n&&(this.identifier=n),null!=e&&e.__line__&&(this.line=e.__line__)};function Rt(t){var e=t.key,r=t.value;return r?[new Dt(e,r,\"constants have been deprecated as of v8\")]:[]}function Ft(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}function Bt(t){return t instanceof Number||t instanceof String||t instanceof Boolean}function Nt(t){return Bt(t)?t.valueOf():t}function jt(t){if(Array.isArray(t))return t.map(jt);if(t instanceof Object&&!Bt(t)){var e={};for(var r in t)e[r]=jt(t[r]);return e}return Nt(t)}var Ut=function(t){function e(e,r){t.call(this,r),this.message=r,this.key=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Error),Vt=function(t,e){void 0===e&&(e=[]),this.parent=t,this.bindings={};for(var r=0,n=e;r<n.length;r+=1){var i=n[r],a=i[0],o=i[1];this.bindings[a]=o}};Vt.prototype.concat=function(t){return new Vt(this,t)},Vt.prototype.get=function(t){if(this.bindings[t])return this.bindings[t];if(this.parent)return this.parent.get(t);throw new Error(t+\" not found in scope.\")},Vt.prototype.has=function(t){return!!this.bindings[t]||!!this.parent&&this.parent.has(t)};var qt={kind:\"null\"},Ht={kind:\"number\"},Gt={kind:\"string\"},Yt={kind:\"boolean\"},Wt={kind:\"color\"},Xt={kind:\"object\"},Zt={kind:\"value\"},Jt={kind:\"collator\"},Kt={kind:\"formatted\"};function $t(t,e){return{kind:\"array\",itemType:t,N:e}}function Qt(t){if(\"array\"===t.kind){var e=Qt(t.itemType);return\"number\"==typeof t.N?\"array<\"+e+\", \"+t.N+\">\":\"value\"===t.itemType.kind?\"array\":\"array<\"+e+\">\"}return t.kind}var te=[qt,Ht,Gt,Yt,Wt,Kt,Xt,$t(Zt)];function ee(t,e){if(\"error\"===e.kind)return null;if(\"array\"===t.kind){if(\"array\"===e.kind&&(0===e.N&&\"value\"===e.itemType.kind||!ee(t.itemType,e.itemType))&&(\"number\"!=typeof t.N||t.N===e.N))return null}else{if(t.kind===e.kind)return null;if(\"value\"===t.kind)for(var r=0,n=te;r<n.length;r+=1)if(!ee(n[r],e))return null}return\"Expected \"+Qt(t)+\" but found \"+Qt(e)+\" instead.\"}var re=e(function(t,e){var r={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],rebeccapurple:[102,51,153,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function n(t){return(t=Math.round(t))<0?0:t>255?255:t}function i(t){return t<0?0:t>1?1:t}function a(t){return\"%\"===t[t.length-1]?n(parseFloat(t)/100*255):n(parseInt(t))}function o(t){return\"%\"===t[t.length-1]?i(parseFloat(t)/100):i(parseFloat(t))}function s(t,e,r){return r<0?r+=1:r>1&&(r-=1),6*r<1?t+(e-t)*r*6:2*r<1?e:3*r<2?t+(e-t)*(2/3-r)*6:t}try{e.parseCSSColor=function(t){var e,i=t.replace(/ /g,\"\").toLowerCase();if(i in r)return r[i].slice();if(\"#\"===i[0])return 4===i.length?(e=parseInt(i.substr(1),16))>=0&&e<=4095?[(3840&e)>>4|(3840&e)>>8,240&e|(240&e)>>4,15&e|(15&e)<<4,1]:null:7===i.length&&(e=parseInt(i.substr(1),16))>=0&&e<=16777215?[(16711680&e)>>16,(65280&e)>>8,255&e,1]:null;var l=i.indexOf(\"(\"),c=i.indexOf(\")\");if(-1!==l&&c+1===i.length){var u=i.substr(0,l),h=i.substr(l+1,c-(l+1)).split(\",\"),f=1;switch(u){case\"rgba\":if(4!==h.length)return null;f=o(h.pop());case\"rgb\":return 3!==h.length?null:[a(h[0]),a(h[1]),a(h[2]),f];case\"hsla\":if(4!==h.length)return null;f=o(h.pop());case\"hsl\":if(3!==h.length)return null;var p=(parseFloat(h[0])%360+360)%360/360,d=o(h[1]),g=o(h[2]),v=g<=.5?g*(d+1):g+d-g*d,m=2*g-v;return[n(255*s(m,v,p+1/3)),n(255*s(m,v,p)),n(255*s(m,v,p-1/3)),f];default:return null}}return null}}catch(t){}}).parseCSSColor,ne=function(t,e,r,n){void 0===n&&(n=1),this.r=t,this.g=e,this.b=r,this.a=n};ne.parse=function(t){if(t){if(t instanceof ne)return t;if(\"string\"==typeof t){var e=re(t);if(e)return new ne(e[0]/255*e[3],e[1]/255*e[3],e[2]/255*e[3],e[3])}}},ne.prototype.toString=function(){var t=this.toArray(),e=t[0],r=t[1],n=t[2],i=t[3];return\"rgba(\"+Math.round(e)+\",\"+Math.round(r)+\",\"+Math.round(n)+\",\"+i+\")\"},ne.prototype.toArray=function(){var t=this.r,e=this.g,r=this.b,n=this.a;return 0===n?[0,0,0,0]:[255*t/n,255*e/n,255*r/n,n]},ne.black=new ne(0,0,0,1),ne.white=new ne(1,1,1,1),ne.transparent=new ne(0,0,0,0),ne.red=new ne(1,0,0,1);var ie=function(t,e,r){this.sensitivity=t?e?\"variant\":\"case\":e?\"accent\":\"base\",this.locale=r,this.collator=new Intl.Collator(this.locale?this.locale:[],{sensitivity:this.sensitivity,usage:\"search\"})};ie.prototype.compare=function(t,e){return this.collator.compare(t,e)},ie.prototype.resolvedLocale=function(){return new Intl.Collator(this.locale?this.locale:[]).resolvedOptions().locale};var ae=function(t,e,r){this.text=t,this.scale=e,this.fontStack=r},oe=function(t){this.sections=t};function se(t,e,r,n){return\"number\"==typeof t&&t>=0&&t<=255&&\"number\"==typeof e&&e>=0&&e<=255&&\"number\"==typeof r&&r>=0&&r<=255?void 0===n||\"number\"==typeof n&&n>=0&&n<=1?null:\"Invalid rgba value [\"+[t,e,r,n].join(\", \")+\"]: 'a' must be between 0 and 1.\":\"Invalid rgba value [\"+(\"number\"==typeof n?[t,e,r,n]:[t,e,r]).join(\", \")+\"]: 'r', 'g', and 'b' must be between 0 and 255.\"}function le(t){if(null===t)return qt;if(\"string\"==typeof t)return Gt;if(\"boolean\"==typeof t)return Yt;if(\"number\"==typeof t)return Ht;if(t instanceof ne)return Wt;if(t instanceof ie)return Jt;if(t instanceof oe)return Kt;if(Array.isArray(t)){for(var e,r=t.length,n=0,i=t;n<i.length;n+=1){var a=le(i[n]);if(e){if(e===a)continue;e=Zt;break}e=a}return $t(e||Zt,r)}return Xt}function ce(t){var e=typeof t;return null===t?\"\":\"string\"===e||\"number\"===e||\"boolean\"===e?String(t):t instanceof ne||t instanceof oe?t.toString():JSON.stringify(t)}oe.fromString=function(t){return new oe([new ae(t,null,null)])},oe.prototype.toString=function(){return this.sections.map(function(t){return t.text}).join(\"\")},oe.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.text);var i={};n.fontStack&&(i[\"text-font\"]=[\"literal\",n.fontStack.split(\",\")]),n.scale&&(i[\"font-scale\"]=n.scale),t.push(i)}return t};var ue=function(t,e){this.type=t,this.value=e};ue.parse=function(t,e){if(2!==t.length)return e.error(\"'literal' expression requires exactly one argument, but found \"+(t.length-1)+\" instead.\");if(!function t(e){if(null===e)return!0;if(\"string\"==typeof e)return!0;if(\"boolean\"==typeof e)return!0;if(\"number\"==typeof e)return!0;if(e instanceof ne)return!0;if(e instanceof ie)return!0;if(e instanceof oe)return!0;if(Array.isArray(e)){for(var r=0,n=e;r<n.length;r+=1)if(!t(n[r]))return!1;return!0}if(\"object\"==typeof e){for(var i in e)if(!t(e[i]))return!1;return!0}return!1}(t[1]))return e.error(\"invalid value\");var r=t[1],n=le(r),i=e.expectedType;return\"array\"!==n.kind||0!==n.N||!i||\"array\"!==i.kind||\"number\"==typeof i.N&&0!==i.N||(n=i),new ue(n,r)},ue.prototype.evaluate=function(){return this.value},ue.prototype.eachChild=function(){},ue.prototype.possibleOutputs=function(){return[this.value]},ue.prototype.serialize=function(){return\"array\"===this.type.kind||\"object\"===this.type.kind?[\"literal\",this.value]:this.value instanceof ne?[\"rgba\"].concat(this.value.toArray()):this.value instanceof oe?this.value.serialize():this.value};var he=function(t){this.name=\"ExpressionEvaluationError\",this.message=t};he.prototype.toJSON=function(){return this.message};var fe={string:Gt,number:Ht,boolean:Yt,object:Xt},pe=function(t,e){this.type=t,this.args=e};pe.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r,n=1,i=t[0];if(\"array\"===i){var a,o;if(t.length>2){var s=t[1];if(\"string\"!=typeof s||!(s in fe)||\"object\"===s)return e.error('The item type argument of \"array\" must be one of string, number, boolean',1);a=fe[s],n++}else a=Zt;if(t.length>3){if(null!==t[2]&&(\"number\"!=typeof t[2]||t[2]<0||t[2]!==Math.floor(t[2])))return e.error('The length argument to \"array\" must be a positive integer literal',2);o=t[2],n++}r=$t(a,o)}else r=fe[i];for(var l=[];n<t.length;n++){var c=e.parse(t[n],n,Zt);if(!c)return null;l.push(c)}return new pe(r,l)},pe.prototype.evaluate=function(t){for(var e=0;e<this.args.length;e++){var r=this.args[e].evaluate(t);if(!ee(this.type,le(r)))return r;if(e===this.args.length-1)throw new he(\"Expected value to be of type \"+Qt(this.type)+\", but found \"+Qt(le(r))+\" instead.\")}return null},pe.prototype.eachChild=function(t){this.args.forEach(t)},pe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},pe.prototype.serialize=function(){var t=this.type,e=[t.kind];if(\"array\"===t.kind){var r=t.itemType;if(\"string\"===r.kind||\"number\"===r.kind||\"boolean\"===r.kind){e.push(r.kind);var n=t.N;(\"number\"==typeof n||this.args.length>1)&&e.push(n)}}return e.concat(this.args.map(function(t){return t.serialize()}))};var de=function(t){this.type=Kt,this.sections=t};de.parse=function(t,e){if(t.length<3)return e.error(\"Expected at least two arguments.\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");for(var r=[],n=1;n<t.length-1;n+=2){var i=e.parse(t[n],1,Zt);if(!i)return null;var a=i.type.kind;if(\"string\"!==a&&\"value\"!==a&&\"null\"!==a)return e.error(\"Formatted text type must be 'string', 'value', or 'null'.\");var o=t[n+1];if(\"object\"!=typeof o||Array.isArray(o))return e.error(\"Format options argument must be an object.\");var s=null;if(o[\"font-scale\"]&&!(s=e.parse(o[\"font-scale\"],1,Ht)))return null;var l=null;if(o[\"text-font\"]&&!(l=e.parse(o[\"text-font\"],1,$t(Gt))))return null;r.push({text:i,scale:s,font:l})}return new de(r)},de.prototype.evaluate=function(t){return new oe(this.sections.map(function(e){return new ae(ce(e.text.evaluate(t)),e.scale?e.scale.evaluate(t):null,e.font?e.font.evaluate(t).join(\",\"):null)}))},de.prototype.eachChild=function(t){for(var e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t(n.text),n.scale&&t(n.scale),n.font&&t(n.font)}},de.prototype.possibleOutputs=function(){return[void 0]},de.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.text.serialize());var i={};n.scale&&(i[\"font-scale\"]=n.scale.serialize()),n.font&&(i[\"text-font\"]=n.font.serialize()),t.push(i)}return t};var ge={\"to-boolean\":Yt,\"to-color\":Wt,\"to-number\":Ht,\"to-string\":Gt},ve=function(t,e){this.type=t,this.args=e};ve.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r=t[0];if((\"to-boolean\"===r||\"to-string\"===r)&&2!==t.length)return e.error(\"Expected one argument.\");for(var n=ge[r],i=[],a=1;a<t.length;a++){var o=e.parse(t[a],a,Zt);if(!o)return null;i.push(o)}return new ve(n,i)},ve.prototype.evaluate=function(t){if(\"boolean\"===this.type.kind)return Boolean(this.args[0].evaluate(t));if(\"color\"===this.type.kind){for(var e,r,n=0,i=this.args;n<i.length;n+=1){if(r=null,(e=i[n].evaluate(t))instanceof ne)return e;if(\"string\"==typeof e){var a=t.parseColor(e);if(a)return a}else if(Array.isArray(e)&&!(r=e.length<3||e.length>4?\"Invalid rbga value \"+JSON.stringify(e)+\": expected an array containing either three or four numeric values.\":se(e[0],e[1],e[2],e[3])))return new ne(e[0]/255,e[1]/255,e[2]/255,e[3])}throw new he(r||\"Could not parse color from value '\"+(\"string\"==typeof e?e:String(JSON.stringify(e)))+\"'\")}if(\"number\"===this.type.kind){for(var o=null,s=0,l=this.args;s<l.length;s+=1){if(null===(o=l[s].evaluate(t)))return 0;var c=Number(o);if(!isNaN(c))return c}throw new he(\"Could not convert \"+JSON.stringify(o)+\" to number.\")}return\"formatted\"===this.type.kind?oe.fromString(ce(this.args[0].evaluate(t))):ce(this.args[0].evaluate(t))},ve.prototype.eachChild=function(t){this.args.forEach(t)},ve.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},ve.prototype.serialize=function(){if(\"formatted\"===this.type.kind)return new de([{text:this.args[0],scale:null,font:null}]).serialize();var t=[\"to-\"+this.type.kind];return this.eachChild(function(e){t.push(e.serialize())}),t};var me=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],ye=function(){this.globals=null,this.feature=null,this.featureState=null,this._parseColorCache={}};ye.prototype.id=function(){return this.feature&&\"id\"in this.feature?this.feature.id:null},ye.prototype.geometryType=function(){return this.feature?\"number\"==typeof this.feature.type?me[this.feature.type]:this.feature.type:null},ye.prototype.properties=function(){return this.feature&&this.feature.properties||{}},ye.prototype.parseColor=function(t){var e=this._parseColorCache[t];return e||(e=this._parseColorCache[t]=ne.parse(t)),e};var xe=function(t,e,r,n){this.name=t,this.type=e,this._evaluate=r,this.args=n};xe.prototype.evaluate=function(t){return this._evaluate(t,this.args)},xe.prototype.eachChild=function(t){this.args.forEach(t)},xe.prototype.possibleOutputs=function(){return[void 0]},xe.prototype.serialize=function(){return[this.name].concat(this.args.map(function(t){return t.serialize()}))},xe.parse=function(t,e){var r,n=t[0],i=xe.definitions[n];if(!i)return e.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0);for(var a=Array.isArray(i)?i[0]:i.type,o=Array.isArray(i)?[[i[1],i[2]]]:i.overloads,s=o.filter(function(e){var r=e[0];return!Array.isArray(r)||r.length===t.length-1}),l=null,c=0,u=s;c<u.length;c+=1){var h=u[c],f=h[0],p=h[1];l=new Ae(e.registry,e.path,null,e.scope);for(var d=[],g=!1,v=1;v<t.length;v++){var m=t[v],y=Array.isArray(f)?f[v-1]:f.type,x=l.parse(m,1+d.length,y);if(!x){g=!0;break}d.push(x)}if(!g)if(Array.isArray(f)&&f.length!==d.length)l.error(\"Expected \"+f.length+\" arguments, but found \"+d.length+\" instead.\");else{for(var b=0;b<d.length;b++){var _=Array.isArray(f)?f[b]:f.type,w=d[b];l.concat(b+1).checkSubtype(_,w.type)}if(0===l.errors.length)return new xe(n,a,p,d)}}if(1===s.length)(r=e.errors).push.apply(r,l.errors);else{for(var k=(s.length?s:o).map(function(t){var e;return e=t[0],Array.isArray(e)?\"(\"+e.map(Qt).join(\", \")+\")\":\"(\"+Qt(e.type)+\"...)\"}).join(\" | \"),T=[],A=1;A<t.length;A++){var M=e.parse(t[A],1+T.length);if(!M)return null;T.push(Qt(M.type))}e.error(\"Expected arguments of type \"+k+\", but found (\"+T.join(\", \")+\") instead.\")}return null},xe.register=function(t,e){for(var r in xe.definitions=e,e)t[r]=xe};var be=function(t,e,r){this.type=Jt,this.locale=r,this.caseSensitive=t,this.diacriticSensitive=e};function _e(t){if(t instanceof xe){if(\"get\"===t.name&&1===t.args.length)return!1;if(\"feature-state\"===t.name)return!1;if(\"has\"===t.name&&1===t.args.length)return!1;if(\"properties\"===t.name||\"geometry-type\"===t.name||\"id\"===t.name)return!1;if(/^filter-/.test(t.name))return!1}var e=!0;return t.eachChild(function(t){e&&!_e(t)&&(e=!1)}),e}function we(t){if(t instanceof xe&&\"feature-state\"===t.name)return!1;var e=!0;return t.eachChild(function(t){e&&!we(t)&&(e=!1)}),e}function ke(t,e){if(t instanceof xe&&e.indexOf(t.name)>=0)return!1;var r=!0;return t.eachChild(function(t){r&&!ke(t,e)&&(r=!1)}),r}be.parse=function(t,e){if(2!==t.length)return e.error(\"Expected one argument.\");var r=t[1];if(\"object\"!=typeof r||Array.isArray(r))return e.error(\"Collator options argument must be an object.\");var n=e.parse(void 0!==r[\"case-sensitive\"]&&r[\"case-sensitive\"],1,Yt);if(!n)return null;var i=e.parse(void 0!==r[\"diacritic-sensitive\"]&&r[\"diacritic-sensitive\"],1,Yt);if(!i)return null;var a=null;return r.locale&&!(a=e.parse(r.locale,1,Gt))?null:new be(n,i,a)},be.prototype.evaluate=function(t){return new ie(this.caseSensitive.evaluate(t),this.diacriticSensitive.evaluate(t),this.locale?this.locale.evaluate(t):null)},be.prototype.eachChild=function(t){t(this.caseSensitive),t(this.diacriticSensitive),this.locale&&t(this.locale)},be.prototype.possibleOutputs=function(){return[void 0]},be.prototype.serialize=function(){var t={};return t[\"case-sensitive\"]=this.caseSensitive.serialize(),t[\"diacritic-sensitive\"]=this.diacriticSensitive.serialize(),this.locale&&(t.locale=this.locale.serialize()),[\"collator\",t]};var Te=function(t,e){this.type=e.type,this.name=t,this.boundExpression=e};Te.parse=function(t,e){if(2!==t.length||\"string\"!=typeof t[1])return e.error(\"'var' expression requires exactly one string literal argument.\");var r=t[1];return e.scope.has(r)?new Te(r,e.scope.get(r)):e.error('Unknown variable \"'+r+'\". Make sure \"'+r+'\" has been bound in an enclosing \"let\" expression before using it.',1)},Te.prototype.evaluate=function(t){return this.boundExpression.evaluate(t)},Te.prototype.eachChild=function(){},Te.prototype.possibleOutputs=function(){return[void 0]},Te.prototype.serialize=function(){return[\"var\",this.name]};var Ae=function(t,e,r,n,i){void 0===e&&(e=[]),void 0===n&&(n=new Vt),void 0===i&&(i=[]),this.registry=t,this.path=e,this.key=e.map(function(t){return\"[\"+t+\"]\"}).join(\"\"),this.scope=n,this.errors=i,this.expectedType=r};function Me(t,e){for(var r,n,i=t.length-1,a=0,o=i,s=0;a<=o;)if(r=t[s=Math.floor((a+o)/2)],n=t[s+1],r<=e){if(s===i||e<n)return s;a=s+1}else{if(!(r>e))throw new he(\"Input is not a number.\");o=s-1}return 0}Ae.prototype.parse=function(t,e,r,n,i){return void 0===i&&(i={}),e?this.concat(e,r,n)._parse(t,i):this._parse(t,i)},Ae.prototype._parse=function(t,e){function r(t,e,r){return\"assert\"===r?new pe(e,[t]):\"coerce\"===r?new ve(e,[t]):t}if(null!==t&&\"string\"!=typeof t&&\"boolean\"!=typeof t&&\"number\"!=typeof t||(t=[\"literal\",t]),Array.isArray(t)){if(0===t.length)return this.error('Expected an array with at least one element. If you wanted a literal array, use [\"literal\", []].');var n=t[0];if(\"string\"!=typeof n)return this.error(\"Expression name must be a string, but found \"+typeof n+' instead. If you wanted a literal array, use [\"literal\", [...]].',0),null;var i=this.registry[n];if(i){var a=i.parse(t,this);if(!a)return null;if(this.expectedType){var o=this.expectedType,s=a.type;if(\"string\"!==o.kind&&\"number\"!==o.kind&&\"boolean\"!==o.kind&&\"object\"!==o.kind&&\"array\"!==o.kind||\"value\"!==s.kind)if(\"color\"!==o.kind&&\"formatted\"!==o.kind||\"value\"!==s.kind&&\"string\"!==s.kind){if(this.checkSubtype(o,s))return null}else a=r(a,o,e.typeAnnotation||\"coerce\");else a=r(a,o,e.typeAnnotation||\"assert\")}if(!(a instanceof ue)&&function t(e){if(e instanceof Te)return t(e.boundExpression);if(e instanceof xe&&\"error\"===e.name)return!1;if(e instanceof be)return!1;var r=e instanceof ve||e instanceof pe,n=!0;return e.eachChild(function(e){n=r?n&&t(e):n&&e instanceof ue}),!!n&&(_e(e)&&ke(e,[\"zoom\",\"heatmap-density\",\"line-progress\",\"accumulated\",\"is-supported-script\"]))}(a)){var l=new ye;try{a=new ue(a.type,a.evaluate(l))}catch(t){return this.error(t.message),null}}return a}return this.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0)}return void 0===t?this.error(\"'undefined' value invalid. Use null instead.\"):\"object\"==typeof t?this.error('Bare objects invalid. Use [\"literal\", {...}] instead.'):this.error(\"Expected an array, but found \"+typeof t+\" instead.\")},Ae.prototype.concat=function(t,e,r){var n=\"number\"==typeof t?this.path.concat(t):this.path,i=r?this.scope.concat(r):this.scope;return new Ae(this.registry,n,e||null,i,this.errors)},Ae.prototype.error=function(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];var n=\"\"+this.key+e.map(function(t){return\"[\"+t+\"]\"}).join(\"\");this.errors.push(new Ut(n,t))},Ae.prototype.checkSubtype=function(t,e){var r=ee(t,e);return r&&this.error(r),r};var Se=function(t,e,r){this.type=t,this.input=e,this.labels=[],this.outputs=[];for(var n=0,i=r;n<i.length;n+=1){var a=i[n],o=a[0],s=a[1];this.labels.push(o),this.outputs.push(s)}};function Ee(t,e,r){return t*(1-r)+e*r}Se.parse=function(t,e){if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");var r=e.parse(t[1],1,Ht);if(!r)return null;var n=[],i=null;e.expectedType&&\"value\"!==e.expectedType.kind&&(i=e.expectedType);for(var a=1;a<t.length;a+=2){var o=1===a?-1/0:t[a],s=t[a+1],l=a,c=a+1;if(\"number\"!=typeof o)return e.error('Input/output pairs for \"step\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',l);if(n.length&&n[n.length-1][0]>=o)return e.error('Input/output pairs for \"step\" expressions must be arranged with input values in strictly ascending order.',l);var u=e.parse(s,c,i);if(!u)return null;i=i||u.type,n.push([o,u])}return new Se(i,r,n)},Se.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;return n>=e[i-1]?r[i-1].evaluate(t):r[Me(e,n)].evaluate(t)},Se.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},Se.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()}))},Se.prototype.serialize=function(){for(var t=[\"step\",this.input.serialize()],e=0;e<this.labels.length;e++)e>0&&t.push(this.labels[e]),t.push(this.outputs[e].serialize());return t};var Ce=Object.freeze({number:Ee,color:function(t,e,r){return new ne(Ee(t.r,e.r,r),Ee(t.g,e.g,r),Ee(t.b,e.b,r),Ee(t.a,e.a,r))},array:function(t,e,r){return t.map(function(t,n){return Ee(t,e[n],r)})}}),Le=.95047,Pe=1,Oe=1.08883,ze=4/29,Ie=6/29,De=3*Ie*Ie,Re=Ie*Ie*Ie,Fe=Math.PI/180,Be=180/Math.PI;function Ne(t){return t>Re?Math.pow(t,1/3):t/De+ze}function je(t){return t>Ie?t*t*t:De*(t-ze)}function Ue(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function Ve(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function qe(t){var e=Ve(t.r),r=Ve(t.g),n=Ve(t.b),i=Ne((.4124564*e+.3575761*r+.1804375*n)/Le),a=Ne((.2126729*e+.7151522*r+.072175*n)/Pe);return{l:116*a-16,a:500*(i-a),b:200*(a-Ne((.0193339*e+.119192*r+.9503041*n)/Oe)),alpha:t.a}}function He(t){var e=(t.l+16)/116,r=isNaN(t.a)?e:e+t.a/500,n=isNaN(t.b)?e:e-t.b/200;return e=Pe*je(e),r=Le*je(r),n=Oe*je(n),new ne(Ue(3.2404542*r-1.5371385*e-.4985314*n),Ue(-.969266*r+1.8760108*e+.041556*n),Ue(.0556434*r-.2040259*e+1.0572252*n),t.alpha)}var Ge={forward:qe,reverse:He,interpolate:function(t,e,r){return{l:Ee(t.l,e.l,r),a:Ee(t.a,e.a,r),b:Ee(t.b,e.b,r),alpha:Ee(t.alpha,e.alpha,r)}}},Ye={forward:function(t){var e=qe(t),r=e.l,n=e.a,i=e.b,a=Math.atan2(i,n)*Be;return{h:a<0?a+360:a,c:Math.sqrt(n*n+i*i),l:r,alpha:t.a}},reverse:function(t){var e=t.h*Fe,r=t.c;return He({l:t.l,a:Math.cos(e)*r,b:Math.sin(e)*r,alpha:t.alpha})},interpolate:function(t,e,r){return{h:function(t,e,r){var n=e-t;return t+r*(n>180||n<-180?n-360*Math.round(n/360):n)}(t.h,e.h,r),c:Ee(t.c,e.c,r),l:Ee(t.l,e.l,r),alpha:Ee(t.alpha,e.alpha,r)}}},We=Object.freeze({lab:Ge,hcl:Ye}),Xe=function(t,e,r,n,i){this.type=t,this.operator=e,this.interpolation=r,this.input=n,this.labels=[],this.outputs=[];for(var a=0,o=i;a<o.length;a+=1){var s=o[a],l=s[0],c=s[1];this.labels.push(l),this.outputs.push(c)}};function Ze(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}Xe.interpolationFactor=function(t,e,n,i){var a=0;if(\"exponential\"===t.name)a=Ze(e,t.base,n,i);else if(\"linear\"===t.name)a=Ze(e,1,n,i);else if(\"cubic-bezier\"===t.name){var o=t.controlPoints;a=new r(o[0],o[1],o[2],o[3]).solve(Ze(e,1,n,i))}return a},Xe.parse=function(t,e){var r=t[0],n=t[1],i=t[2],a=t.slice(3);if(!Array.isArray(n)||0===n.length)return e.error(\"Expected an interpolation type expression.\",1);if(\"linear\"===n[0])n={name:\"linear\"};else if(\"exponential\"===n[0]){var o=n[1];if(\"number\"!=typeof o)return e.error(\"Exponential interpolation requires a numeric base.\",1,1);n={name:\"exponential\",base:o}}else{if(\"cubic-bezier\"!==n[0])return e.error(\"Unknown interpolation type \"+String(n[0]),1,0);var s=n.slice(1);if(4!==s.length||s.some(function(t){return\"number\"!=typeof t||t<0||t>1}))return e.error(\"Cubic bezier interpolation requires four numeric arguments with values between 0 and 1.\",1);n={name:\"cubic-bezier\",controlPoints:s}}if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");if(!(i=e.parse(i,2,Ht)))return null;var l=[],c=null;\"interpolate-hcl\"===r||\"interpolate-lab\"===r?c=Wt:e.expectedType&&\"value\"!==e.expectedType.kind&&(c=e.expectedType);for(var u=0;u<a.length;u+=2){var h=a[u],f=a[u+1],p=u+3,d=u+4;if(\"number\"!=typeof h)return e.error('Input/output pairs for \"interpolate\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',p);if(l.length&&l[l.length-1][0]>=h)return e.error('Input/output pairs for \"interpolate\" expressions must be arranged with input values in strictly ascending order.',p);var g=e.parse(f,d,c);if(!g)return null;c=c||g.type,l.push([h,g])}return\"number\"===c.kind||\"color\"===c.kind||\"array\"===c.kind&&\"number\"===c.itemType.kind&&\"number\"==typeof c.N?new Xe(c,r,n,i,l):e.error(\"Type \"+Qt(c)+\" is not interpolatable.\")},Xe.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;if(n>=e[i-1])return r[i-1].evaluate(t);var a=Me(e,n),o=e[a],s=e[a+1],l=Xe.interpolationFactor(this.interpolation,n,o,s),c=r[a].evaluate(t),u=r[a+1].evaluate(t);return\"interpolate\"===this.operator?Ce[this.type.kind.toLowerCase()](c,u,l):\"interpolate-hcl\"===this.operator?Ye.reverse(Ye.interpolate(Ye.forward(c),Ye.forward(u),l)):Ge.reverse(Ge.interpolate(Ge.forward(c),Ge.forward(u),l))},Xe.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},Xe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()}))},Xe.prototype.serialize=function(){var t;t=\"linear\"===this.interpolation.name?[\"linear\"]:\"exponential\"===this.interpolation.name?1===this.interpolation.base?[\"linear\"]:[\"exponential\",this.interpolation.base]:[\"cubic-bezier\"].concat(this.interpolation.controlPoints);for(var e=[this.operator,t,this.input.serialize()],r=0;r<this.labels.length;r++)e.push(this.labels[r],this.outputs[r].serialize());return e};var Je=function(t,e){this.type=t,this.args=e};Je.parse=function(t,e){if(t.length<2)return e.error(\"Expectected at least one argument.\");var r=null,n=e.expectedType;n&&\"value\"!==n.kind&&(r=n);for(var i=[],a=0,o=t.slice(1);a<o.length;a+=1){var s=o[a],l=e.parse(s,1+i.length,r,void 0,{typeAnnotation:\"omit\"});if(!l)return null;r=r||l.type,i.push(l)}var c=n&&i.some(function(t){return ee(n,t.type)});return new Je(c?Zt:r,i)},Je.prototype.evaluate=function(t){for(var e=null,r=0,n=this.args;r<n.length&&null===(e=n[r].evaluate(t));r+=1);return e},Je.prototype.eachChild=function(t){this.args.forEach(t)},Je.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.args.map(function(t){return t.possibleOutputs()}))},Je.prototype.serialize=function(){var t=[\"coalesce\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var Ke=function(t,e){this.type=e.type,this.bindings=[].concat(t),this.result=e};Ke.prototype.evaluate=function(t){return this.result.evaluate(t)},Ke.prototype.eachChild=function(t){for(var e=0,r=this.bindings;e<r.length;e+=1)t(r[e][1]);t(this.result)},Ke.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found \"+(t.length-1)+\" instead.\");for(var r=[],n=1;n<t.length-1;n+=2){var i=t[n];if(\"string\"!=typeof i)return e.error(\"Expected string, but found \"+typeof i+\" instead.\",n);if(/[^a-zA-Z0-9_]/.test(i))return e.error(\"Variable names must contain only alphanumeric characters or '_'.\",n);var a=e.parse(t[n+1],n+1);if(!a)return null;r.push([i,a])}var o=e.parse(t[t.length-1],t.length-1,e.expectedType,r);return o?new Ke(r,o):null},Ke.prototype.possibleOutputs=function(){return this.result.possibleOutputs()},Ke.prototype.serialize=function(){for(var t=[\"let\"],e=0,r=this.bindings;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];t.push(i,a.serialize())}return t.push(this.result.serialize()),t};var $e=function(t,e,r){this.type=t,this.index=e,this.input=r};$e.parse=function(t,e){if(3!==t.length)return e.error(\"Expected 2 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,Ht),n=e.parse(t[2],2,$t(e.expectedType||Zt));if(!r||!n)return null;var i=n.type;return new $e(i.itemType,r,n)},$e.prototype.evaluate=function(t){var e=this.index.evaluate(t),r=this.input.evaluate(t);if(e<0)throw new he(\"Array index out of bounds: \"+e+\" < 0.\");if(e>=r.length)throw new he(\"Array index out of bounds: \"+e+\" > \"+(r.length-1)+\".\");if(e!==Math.floor(e))throw new he(\"Array index must be an integer, but found \"+e+\" instead.\");return r[e]},$e.prototype.eachChild=function(t){t(this.index),t(this.input)},$e.prototype.possibleOutputs=function(){return[void 0]},$e.prototype.serialize=function(){return[\"at\",this.index.serialize(),this.input.serialize()]};var Qe=function(t,e,r,n,i,a){this.inputType=t,this.type=e,this.input=r,this.cases=n,this.outputs=i,this.otherwise=a};Qe.parse=function(t,e){if(t.length<5)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=1)return e.error(\"Expected an even number of arguments.\");var r,n;e.expectedType&&\"value\"!==e.expectedType.kind&&(n=e.expectedType);for(var i={},a=[],o=2;o<t.length-1;o+=2){var s=t[o],l=t[o+1];Array.isArray(s)||(s=[s]);var c=e.concat(o);if(0===s.length)return c.error(\"Expected at least one branch label.\");for(var u=0,h=s;u<h.length;u+=1){var f=h[u];if(\"number\"!=typeof f&&\"string\"!=typeof f)return c.error(\"Branch labels must be numbers or strings.\");if(\"number\"==typeof f&&Math.abs(f)>Number.MAX_SAFE_INTEGER)return c.error(\"Branch labels must be integers no larger than \"+Number.MAX_SAFE_INTEGER+\".\");if(\"number\"==typeof f&&Math.floor(f)!==f)return c.error(\"Numeric branch labels must be integer values.\");if(r){if(c.checkSubtype(r,le(f)))return null}else r=le(f);if(void 0!==i[String(f)])return c.error(\"Branch labels must be unique.\");i[String(f)]=a.length}var p=e.parse(l,o,n);if(!p)return null;n=n||p.type,a.push(p)}var d=e.parse(t[1],1,Zt);if(!d)return null;var g=e.parse(t[t.length-1],t.length-1,n);return g?\"value\"!==d.type.kind&&e.concat(1).checkSubtype(r,d.type)?null:new Qe(r,n,d,i,a,g):null},Qe.prototype.evaluate=function(t){var e=this.input.evaluate(t);return(le(e)===this.inputType&&this.outputs[this.cases[e]]||this.otherwise).evaluate(t)},Qe.prototype.eachChild=function(t){t(this.input),this.outputs.forEach(t),t(this.otherwise)},Qe.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.outputs.map(function(t){return t.possibleOutputs()})).concat(this.otherwise.possibleOutputs())},Qe.prototype.serialize=function(){for(var t=this,e=[\"match\",this.input.serialize()],r=[],n={},i=0,a=Object.keys(this.cases).sort();i<a.length;i+=1){var o=a[i];void 0===(h=n[this.cases[o]])?(n[this.cases[o]]=r.length,r.push([this.cases[o],[o]])):r[h][1].push(o)}for(var s=function(e){return\"number\"===t.inputType.kind?Number(e):e},l=0,c=r;l<c.length;l+=1){var u=c[l],h=u[0],f=u[1];1===f.length?e.push(s(f[0])):e.push(f.map(s)),e.push(this.outputs[outputIndex$1].serialize())}return e.push(this.otherwise.serialize()),e};var tr=function(t,e,r){this.type=t,this.branches=e,this.otherwise=r};function er(t,e){return\"==\"===t||\"!=\"===t?\"boolean\"===e.kind||\"string\"===e.kind||\"number\"===e.kind||\"null\"===e.kind||\"value\"===e.kind:\"string\"===e.kind||\"number\"===e.kind||\"value\"===e.kind}function rr(t,e,r,n){return 0===n.compare(e,r)}function nr(t,e,r){var n=\"==\"!==t&&\"!=\"!==t;return function(){function i(t,e,r){this.type=Yt,this.lhs=t,this.rhs=e,this.collator=r,this.hasUntypedArgument=\"value\"===t.type.kind||\"value\"===e.type.kind}return i.parse=function(t,e){if(3!==t.length&&4!==t.length)return e.error(\"Expected two or three arguments.\");var r=t[0],a=e.parse(t[1],1,Zt);if(!a)return null;if(!er(r,a.type))return e.concat(1).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Qt(a.type)+\"'.\");var o=e.parse(t[2],2,Zt);if(!o)return null;if(!er(r,o.type))return e.concat(2).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Qt(o.type)+\"'.\");if(a.type.kind!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot compare types '\"+Qt(a.type)+\"' and '\"+Qt(o.type)+\"'.\");n&&(\"value\"===a.type.kind&&\"value\"!==o.type.kind?a=new pe(o.type,[a]):\"value\"!==a.type.kind&&\"value\"===o.type.kind&&(o=new pe(a.type,[o])));var s=null;if(4===t.length){if(\"string\"!==a.type.kind&&\"string\"!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot use collator to compare non-string types.\");if(!(s=e.parse(t[3],3,Jt)))return null}return new i(a,o,s)},i.prototype.evaluate=function(i){var a=this.lhs.evaluate(i),o=this.rhs.evaluate(i);if(n&&this.hasUntypedArgument){var s=le(a),l=le(o);if(s.kind!==l.kind||\"string\"!==s.kind&&\"number\"!==s.kind)throw new he('Expected arguments for \"'+t+'\" to be (string, string) or (number, number), but found ('+s.kind+\", \"+l.kind+\") instead.\")}if(this.collator&&!n&&this.hasUntypedArgument){var c=le(a),u=le(o);if(\"string\"!==c.kind||\"string\"!==u.kind)return e(i,a,o)}return this.collator?r(i,a,o,this.collator.evaluate(i)):e(i,a,o)},i.prototype.eachChild=function(t){t(this.lhs),t(this.rhs),this.collator&&t(this.collator)},i.prototype.possibleOutputs=function(){return[!0,!1]},i.prototype.serialize=function(){var e=[t];return this.eachChild(function(t){e.push(t.serialize())}),e},i}()}tr.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=0)return e.error(\"Expected an odd number of arguments.\");var r;e.expectedType&&\"value\"!==e.expectedType.kind&&(r=e.expectedType);for(var n=[],i=1;i<t.length-1;i+=2){var a=e.parse(t[i],i,Yt);if(!a)return null;var o=e.parse(t[i+1],i+1,r);if(!o)return null;n.push([a,o]),r=r||o.type}var s=e.parse(t[t.length-1],t.length-1,r);return s?new tr(r,n,s):null},tr.prototype.evaluate=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];if(i.evaluate(t))return a.evaluate(t)}return this.otherwise.evaluate(t)},tr.prototype.eachChild=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];t(i),t(a)}t(this.otherwise)},tr.prototype.possibleOutputs=function(){var t;return(t=[]).concat.apply(t,this.branches.map(function(t){return t[0],t[1].possibleOutputs()})).concat(this.otherwise.possibleOutputs())},tr.prototype.serialize=function(){var t=[\"case\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var ir=nr(\"==\",function(t,e,r){return e===r},rr),ar=nr(\"!=\",function(t,e,r){return e!==r},function(t,e,r,n){return!rr(0,e,r,n)}),or=nr(\"<\",function(t,e,r){return e<r},function(t,e,r,n){return n.compare(e,r)<0}),sr=nr(\">\",function(t,e,r){return e>r},function(t,e,r,n){return n.compare(e,r)>0}),lr=nr(\"<=\",function(t,e,r){return e<=r},function(t,e,r,n){return n.compare(e,r)<=0}),cr=nr(\">=\",function(t,e,r){return e>=r},function(t,e,r,n){return n.compare(e,r)>=0}),ur=function(t,e,r,n,i){this.type=Gt,this.number=t,this.locale=e,this.currency=r,this.minFractionDigits=n,this.maxFractionDigits=i};ur.parse=function(t,e){if(3!==t.length)return e.error(\"Expected two arguments.\");var r=e.parse(t[1],1,Ht);if(!r)return null;var n=t[2];if(\"object\"!=typeof n||Array.isArray(n))return e.error(\"NumberFormat options argument must be an object.\");var i=null;if(n.locale&&!(i=e.parse(n.locale,1,Gt)))return null;var a=null;if(n.currency&&!(a=e.parse(n.currency,1,Gt)))return null;var o=null;if(n[\"min-fraction-digits\"]&&!(o=e.parse(n[\"min-fraction-digits\"],1,Ht)))return null;var s=null;return n[\"max-fraction-digits\"]&&!(s=e.parse(n[\"max-fraction-digits\"],1,Ht))?null:new ur(r,i,a,o,s)},ur.prototype.evaluate=function(t){return new Intl.NumberFormat(this.locale?this.locale.evaluate(t):[],{style:this.currency?\"currency\":\"decimal\",currency:this.currency?this.currency.evaluate(t):void 0,minimumFractionDigits:this.minFractionDigits?this.minFractionDigits.evaluate(t):void 0,maximumFractionDigits:this.maxFractionDigits?this.maxFractionDigits.evaluate(t):void 0}).format(this.number.evaluate(t))},ur.prototype.eachChild=function(t){t(this.number),this.locale&&t(this.locale),this.currency&&t(this.currency),this.minFractionDigits&&t(this.minFractionDigits),this.maxFractionDigits&&t(this.maxFractionDigits)},ur.prototype.possibleOutputs=function(){return[void 0]},ur.prototype.serialize=function(){var t={};return this.locale&&(t.locale=this.locale.serialize()),this.currency&&(t.currency=this.currency.serialize()),this.minFractionDigits&&(t[\"min-fraction-digits\"]=this.minFractionDigits.serialize()),this.maxFractionDigits&&(t[\"max-fraction-digits\"]=this.maxFractionDigits.serialize()),[\"number-format\",this.number.serialize(),t]};var hr=function(t){this.type=Ht,this.input=t};hr.parse=function(t,e){if(2!==t.length)return e.error(\"Expected 1 argument, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1);return r?\"array\"!==r.type.kind&&\"string\"!==r.type.kind&&\"value\"!==r.type.kind?e.error(\"Expected argument of type string or array, but found \"+Qt(r.type)+\" instead.\"):new hr(r):null},hr.prototype.evaluate=function(t){var e=this.input.evaluate(t);if(\"string\"==typeof e)return e.length;if(Array.isArray(e))return e.length;throw new he(\"Expected value to be of type string or array, but found \"+Qt(le(e))+\" instead.\")},hr.prototype.eachChild=function(t){t(this.input)},hr.prototype.possibleOutputs=function(){return[void 0]},hr.prototype.serialize=function(){var t=[\"length\"];return this.eachChild(function(e){t.push(e.serialize())}),t};var fr={\"==\":ir,\"!=\":ar,\">\":sr,\"<\":or,\">=\":cr,\"<=\":lr,array:pe,at:$e,boolean:pe,case:tr,coalesce:Je,collator:be,format:de,interpolate:Xe,\"interpolate-hcl\":Xe,\"interpolate-lab\":Xe,length:hr,let:Ke,literal:ue,match:Qe,number:pe,\"number-format\":ur,object:pe,step:Se,string:pe,\"to-boolean\":ve,\"to-color\":ve,\"to-number\":ve,\"to-string\":ve,var:Te};function pr(t,e){var r=e[0],n=e[1],i=e[2],a=e[3];r=r.evaluate(t),n=n.evaluate(t),i=i.evaluate(t);var o=a?a.evaluate(t):1,s=se(r,n,i,o);if(s)throw new he(s);return new ne(r/255*o,n/255*o,i/255*o,o)}function dr(t,e){return t in e}function gr(t,e){var r=e[t];return void 0===r?null:r}function vr(t){return{type:t}}function mr(t){return{result:\"success\",value:t}}function yr(t){return{result:\"error\",value:t}}function xr(t){return\"data-driven\"===t[\"property-type\"]||\"cross-faded-data-driven\"===t[\"property-type\"]}function br(t){return!!t.expression&&t.expression.parameters.indexOf(\"zoom\")>-1}function _r(t){return!!t.expression&&t.expression.interpolated}function wr(t){return t instanceof Number?\"number\":t instanceof String?\"string\":t instanceof Boolean?\"boolean\":Array.isArray(t)?\"array\":null===t?\"null\":typeof t}function kr(t){return\"object\"==typeof t&&null!==t&&!Array.isArray(t)}function Tr(t){return t}function Ar(t,e,r){return void 0!==t?t:void 0!==e?e:void 0!==r?r:void 0}function Mr(t,e,r,n,i){return Ar(typeof r===i?n[r]:void 0,t.default,e.default)}function Sr(t,e,r){if(\"number\"!==wr(r))return Ar(t.default,e.default);var n=t.stops.length;if(1===n)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[n-1][0])return t.stops[n-1][1];var i=Me(t.stops.map(function(t){return t[0]}),r);return t.stops[i][1]}function Er(t,e,r){var n=void 0!==t.base?t.base:1;if(\"number\"!==wr(r))return Ar(t.default,e.default);var i=t.stops.length;if(1===i)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[i-1][0])return t.stops[i-1][1];var a=Me(t.stops.map(function(t){return t[0]}),r),o=function(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}(r,n,t.stops[a][0],t.stops[a+1][0]),s=t.stops[a][1],l=t.stops[a+1][1],c=Ce[e.type]||Tr;if(t.colorSpace&&\"rgb\"!==t.colorSpace){var u=We[t.colorSpace];c=function(t,e){return u.reverse(u.interpolate(u.forward(t),u.forward(e),o))}}return\"function\"==typeof s.evaluate?{evaluate:function(){for(var t=[],e=arguments.length;e--;)t[e]=arguments[e];var r=s.evaluate.apply(void 0,t),n=l.evaluate.apply(void 0,t);if(void 0!==r&&void 0!==n)return c(r,n,o)}}:c(s,l,o)}function Cr(t,e,r){return\"color\"===e.type?r=ne.parse(r):\"formatted\"===e.type?r=oe.fromString(r.toString()):wr(r)===e.type||\"enum\"===e.type&&e.values[r]||(r=void 0),Ar(r,t.default,e.default)}xe.register(fr,{error:[{kind:\"error\"},[Gt],function(t,e){var r=e[0];throw new he(r.evaluate(t))}],typeof:[Gt,[Zt],function(t,e){return Qt(le(e[0].evaluate(t)))}],\"to-rgba\":[$t(Ht,4),[Wt],function(t,e){return e[0].evaluate(t).toArray()}],rgb:[Wt,[Ht,Ht,Ht],pr],rgba:[Wt,[Ht,Ht,Ht,Ht],pr],has:{type:Yt,overloads:[[[Gt],function(t,e){return dr(e[0].evaluate(t),t.properties())}],[[Gt,Xt],function(t,e){var r=e[0],n=e[1];return dr(r.evaluate(t),n.evaluate(t))}]]},get:{type:Zt,overloads:[[[Gt],function(t,e){return gr(e[0].evaluate(t),t.properties())}],[[Gt,Xt],function(t,e){var r=e[0],n=e[1];return gr(r.evaluate(t),n.evaluate(t))}]]},\"feature-state\":[Zt,[Gt],function(t,e){return gr(e[0].evaluate(t),t.featureState||{})}],properties:[Xt,[],function(t){return t.properties()}],\"geometry-type\":[Gt,[],function(t){return t.geometryType()}],id:[Zt,[],function(t){return t.id()}],zoom:[Ht,[],function(t){return t.globals.zoom}],\"heatmap-density\":[Ht,[],function(t){return t.globals.heatmapDensity||0}],\"line-progress\":[Ht,[],function(t){return t.globals.lineProgress||0}],accumulated:[Zt,[],function(t){return void 0===t.globals.accumulated?null:t.globals.accumulated}],\"+\":[Ht,vr(Ht),function(t,e){for(var r=0,n=0,i=e;n<i.length;n+=1)r+=i[n].evaluate(t);return r}],\"*\":[Ht,vr(Ht),function(t,e){for(var r=1,n=0,i=e;n<i.length;n+=1)r*=i[n].evaluate(t);return r}],\"-\":{type:Ht,overloads:[[[Ht,Ht],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)-n.evaluate(t)}],[[Ht],function(t,e){return-e[0].evaluate(t)}]]},\"/\":[Ht,[Ht,Ht],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)/n.evaluate(t)}],\"%\":[Ht,[Ht,Ht],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)%n.evaluate(t)}],ln2:[Ht,[],function(){return Math.LN2}],pi:[Ht,[],function(){return Math.PI}],e:[Ht,[],function(){return Math.E}],\"^\":[Ht,[Ht,Ht],function(t,e){var r=e[0],n=e[1];return Math.pow(r.evaluate(t),n.evaluate(t))}],sqrt:[Ht,[Ht],function(t,e){var r=e[0];return Math.sqrt(r.evaluate(t))}],log10:[Ht,[Ht],function(t,e){var r=e[0];return Math.log(r.evaluate(t))/Math.LN10}],ln:[Ht,[Ht],function(t,e){var r=e[0];return Math.log(r.evaluate(t))}],log2:[Ht,[Ht],function(t,e){var r=e[0];return Math.log(r.evaluate(t))/Math.LN2}],sin:[Ht,[Ht],function(t,e){var r=e[0];return Math.sin(r.evaluate(t))}],cos:[Ht,[Ht],function(t,e){var r=e[0];return Math.cos(r.evaluate(t))}],tan:[Ht,[Ht],function(t,e){var r=e[0];return Math.tan(r.evaluate(t))}],asin:[Ht,[Ht],function(t,e){var r=e[0];return Math.asin(r.evaluate(t))}],acos:[Ht,[Ht],function(t,e){var r=e[0];return Math.acos(r.evaluate(t))}],atan:[Ht,[Ht],function(t,e){var r=e[0];return Math.atan(r.evaluate(t))}],min:[Ht,vr(Ht),function(t,e){return Math.min.apply(Math,e.map(function(e){return e.evaluate(t)}))}],max:[Ht,vr(Ht),function(t,e){return Math.max.apply(Math,e.map(function(e){return e.evaluate(t)}))}],abs:[Ht,[Ht],function(t,e){var r=e[0];return Math.abs(r.evaluate(t))}],round:[Ht,[Ht],function(t,e){var r=e[0].evaluate(t);return r<0?-Math.round(-r):Math.round(r)}],floor:[Ht,[Ht],function(t,e){var r=e[0];return Math.floor(r.evaluate(t))}],ceil:[Ht,[Ht],function(t,e){var r=e[0];return Math.ceil(r.evaluate(t))}],\"filter-==\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1];return t.properties()[r.value]===n.value}],\"filter-id-==\":[Yt,[Zt],function(t,e){var r=e[0];return t.id()===r.value}],\"filter-type-==\":[Yt,[Gt],function(t,e){var r=e[0];return t.geometryType()===r.value}],\"filter-<\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<a}],\"filter-id-<\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<i}],\"filter->\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>a}],\"filter-id->\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>i}],\"filter-<=\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<=a}],\"filter-id-<=\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<=i}],\"filter->=\":[Yt,[Gt,Zt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>=a}],\"filter-id->=\":[Yt,[Zt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>=i}],\"filter-has\":[Yt,[Zt],function(t,e){return e[0].value in t.properties()}],\"filter-has-id\":[Yt,[],function(t){return null!==t.id()}],\"filter-type-in\":[Yt,[$t(Gt)],function(t,e){return e[0].value.indexOf(t.geometryType())>=0}],\"filter-id-in\":[Yt,[$t(Zt)],function(t,e){return e[0].value.indexOf(t.id())>=0}],\"filter-in-small\":[Yt,[Gt,$t(Zt)],function(t,e){var r=e[0];return e[1].value.indexOf(t.properties()[r.value])>=0}],\"filter-in-large\":[Yt,[Gt,$t(Zt)],function(t,e){var r=e[0],n=e[1];return function(t,e,r,n){for(;r<=n;){var i=r+n>>1;if(e[i]===t)return!0;e[i]>t?n=i-1:r=i+1}return!1}(t.properties()[r.value],n.value,0,n.value.length-1)}],all:{type:Yt,overloads:[[[Yt,Yt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)&&n.evaluate(t)}],[vr(Yt),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(!n[r].evaluate(t))return!1;return!0}]]},any:{type:Yt,overloads:[[[Yt,Yt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)||n.evaluate(t)}],[vr(Yt),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(n[r].evaluate(t))return!0;return!1}]]},\"!\":[Yt,[Yt],function(t,e){return!e[0].evaluate(t)}],\"is-supported-script\":[Yt,[Gt],function(t,e){var r=e[0],n=t.globals&&t.globals.isSupportedScript;return!n||n(r.evaluate(t))}],upcase:[Gt,[Gt],function(t,e){return e[0].evaluate(t).toUpperCase()}],downcase:[Gt,[Gt],function(t,e){return e[0].evaluate(t).toLowerCase()}],concat:[Gt,vr(Zt),function(t,e){return e.map(function(e){return ce(e.evaluate(t))}).join(\"\")}],\"resolved-locale\":[Gt,[Jt],function(t,e){return e[0].evaluate(t).resolvedLocale()}]});var Lr=function(t,e){var r;this.expression=t,this._warningHistory={},this._evaluator=new ye,this._defaultValue=e?\"color\"===(r=e).type&&kr(r.default)?new ne(0,0,0,0):\"color\"===r.type?ne.parse(r.default)||null:void 0===r.default?null:r.default:null,this._enumValues=e&&\"enum\"===e.type?e.values:null};function Pr(t){return Array.isArray(t)&&t.length>0&&\"string\"==typeof t[0]&&t[0]in fr}function Or(t,e){var r=new Ae(fr,[],e?function(t){var e={color:Wt,string:Gt,number:Ht,enum:Gt,boolean:Yt,formatted:Kt};return\"array\"===t.type?$t(e[t.value]||Zt,t.length):e[t.type]}(e):void 0),n=r.parse(t,void 0,void 0,void 0,e&&\"string\"===e.type?{typeAnnotation:\"coerce\"}:void 0);return n?mr(new Lr(n,e)):yr(r.errors)}Lr.prototype.evaluateWithoutErrorHandling=function(t,e,r){return this._evaluator.globals=t,this._evaluator.feature=e,this._evaluator.featureState=r,this.expression.evaluate(this._evaluator)},Lr.prototype.evaluate=function(t,e,r){this._evaluator.globals=t,this._evaluator.feature=e||null,this._evaluator.featureState=r||null;try{var n=this.expression.evaluate(this._evaluator);if(null==n)return this._defaultValue;if(this._enumValues&&!(n in this._enumValues))throw new he(\"Expected value to be one of \"+Object.keys(this._enumValues).map(function(t){return JSON.stringify(t)}).join(\", \")+\", but found \"+JSON.stringify(n)+\" instead.\");return n}catch(t){return this._warningHistory[t.message]||(this._warningHistory[t.message]=!0,\"undefined\"!=typeof console&&console.warn(t.message)),this._defaultValue}};var zr=function(t,e){this.kind=t,this._styleExpression=e,this.isStateDependent=\"constant\"!==t&&!we(e.expression)};zr.prototype.evaluateWithoutErrorHandling=function(t,e,r){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r)},zr.prototype.evaluate=function(t,e,r){return this._styleExpression.evaluate(t,e,r)};var Ir=function(t,e,r){this.kind=t,this.zoomStops=r.labels,this._styleExpression=e,this.isStateDependent=\"camera\"!==t&&!we(e.expression),r instanceof Xe&&(this.interpolationType=r.interpolation)};function Dr(t,e){if(\"error\"===(t=Or(t,e)).result)return t;var r=t.value.expression,n=_e(r);if(!n&&!xr(e))return yr([new Ut(\"\",\"data expressions not supported\")]);var i=ke(r,[\"zoom\"]);if(!i&&!br(e))return yr([new Ut(\"\",\"zoom expressions not supported\")]);var a=function t(e){var r=null;if(e instanceof Ke)r=t(e.result);else if(e instanceof Je)for(var n=0,i=e.args;n<i.length;n+=1){var a=i[n];if(r=t(a))break}else(e instanceof Se||e instanceof Xe)&&e.input instanceof xe&&\"zoom\"===e.input.name&&(r=e);return r instanceof Ut?r:(e.eachChild(function(e){var n=t(e);n instanceof Ut?r=n:!r&&n?r=new Ut(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.'):r&&n&&r!==n&&(r=new Ut(\"\",'Only one zoom-based \"step\" or \"interpolate\" subexpression may be used in an expression.'))}),r)}(r);return a||i?a instanceof Ut?yr([a]):a instanceof Xe&&!_r(e)?yr([new Ut(\"\",'\"interpolate\" expressions cannot be used with this property')]):mr(a?new Ir(n?\"camera\":\"composite\",t.value,a):new zr(n?\"constant\":\"source\",t.value)):yr([new Ut(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.')])}Ir.prototype.evaluateWithoutErrorHandling=function(t,e,r){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r)},Ir.prototype.evaluate=function(t,e,r){return this._styleExpression.evaluate(t,e,r)},Ir.prototype.interpolationFactor=function(t,e,r){return this.interpolationType?Xe.interpolationFactor(this.interpolationType,t,e,r):0};var Rr=function(t,e){this._parameters=t,this._specification=e,Ft(this,function t(e,r){var n,i,a,o=\"color\"===r.type,s=e.stops&&\"object\"==typeof e.stops[0][0],l=s||void 0!==e.property,c=s||!l,u=e.type||(_r(r)?\"exponential\":\"interval\");if(o&&((e=Ft({},e)).stops&&(e.stops=e.stops.map(function(t){return[t[0],ne.parse(t[1])]})),e.default?e.default=ne.parse(e.default):e.default=ne.parse(r.default)),e.colorSpace&&\"rgb\"!==e.colorSpace&&!We[e.colorSpace])throw new Error(\"Unknown color space: \"+e.colorSpace);if(\"exponential\"===u)n=Er;else if(\"interval\"===u)n=Sr;else if(\"categorical\"===u){n=Mr,i=Object.create(null);for(var h=0,f=e.stops;h<f.length;h+=1){var p=f[h];i[p[0]]=p[1]}a=typeof e.stops[0][0]}else{if(\"identity\"!==u)throw new Error('Unknown function type \"'+u+'\"');n=Cr}if(s){for(var d={},g=[],v=0;v<e.stops.length;v++){var m=e.stops[v],y=m[0].zoom;void 0===d[y]&&(d[y]={zoom:y,type:e.type,property:e.property,default:e.default,stops:[]},g.push(y)),d[y].stops.push([m[0].value,m[1]])}for(var x=[],b=0,_=g;b<_.length;b+=1){var w=_[b];x.push([d[w].zoom,t(d[w],r)])}var k={name:\"linear\"};return{kind:\"composite\",interpolationType:k,interpolationFactor:Xe.interpolationFactor.bind(void 0,k),zoomStops:x.map(function(t){return t[0]}),evaluate:function(t,n){var i=t.zoom;return Er({stops:x,base:e.base},r,i).evaluate(i,n)}}}if(c){var T=\"exponential\"===u?{name:\"exponential\",base:void 0!==e.base?e.base:1}:null;return{kind:\"camera\",interpolationType:T,interpolationFactor:Xe.interpolationFactor.bind(void 0,T),zoomStops:e.stops.map(function(t){return t[0]}),evaluate:function(t){var o=t.zoom;return n(e,r,o,i,a)}}}return{kind:\"source\",evaluate:function(t,o){var s=o&&o.properties?o.properties[e.property]:void 0;return void 0===s?Ar(e.default,r.default):n(e,r,s,i,a)}}}(this._parameters,this._specification))};function Fr(t){var e=t.key,r=t.value,n=t.valueSpec||{},i=t.objectElementValidators||{},a=t.style,o=t.styleSpec,s=[],l=wr(r);if(\"object\"!==l)return[new Dt(e,r,\"object expected, \"+l+\" found\")];for(var c in r){var u=c.split(\".\")[0],h=n[u]||n[\"*\"],f=void 0;if(i[u])f=i[u];else if(n[u])f=ln;else if(i[\"*\"])f=i[\"*\"];else{if(!n[\"*\"]){s.push(new Dt(e,r[c],'unknown property \"'+c+'\"'));continue}f=ln}s=s.concat(f({key:(e?e+\".\":e)+c,value:r[c],valueSpec:h,style:a,styleSpec:o,object:r,objectKey:c},r))}for(var p in n)i[p]||n[p].required&&void 0===n[p].default&&void 0===r[p]&&s.push(new Dt(e,r,'missing required property \"'+p+'\"'));return s}function Br(t){var e=t.value,r=t.valueSpec,n=t.style,i=t.styleSpec,a=t.key,o=t.arrayElementValidator||ln;if(\"array\"!==wr(e))return[new Dt(a,e,\"array expected, \"+wr(e)+\" found\")];if(r.length&&e.length!==r.length)return[new Dt(a,e,\"array length \"+r.length+\" expected, length \"+e.length+\" found\")];if(r[\"min-length\"]&&e.length<r[\"min-length\"])return[new Dt(a,e,\"array length at least \"+r[\"min-length\"]+\" expected, length \"+e.length+\" found\")];var s={type:r.value,values:r.values};i.$version<7&&(s.function=r.function),\"object\"===wr(r.value)&&(s=r.value);for(var l=[],c=0;c<e.length;c++)l=l.concat(o({array:e,arrayIndex:c,value:e[c],valueSpec:s,style:n,styleSpec:i,key:a+\"[\"+c+\"]\"}));return l}function Nr(t){var e=t.key,r=t.value,n=t.valueSpec,i=wr(r);return\"number\"!==i?[new Dt(e,r,\"number expected, \"+i+\" found\")]:\"minimum\"in n&&r<n.minimum?[new Dt(e,r,r+\" is less than the minimum value \"+n.minimum)]:\"maximum\"in n&&r>n.maximum?[new Dt(e,r,r+\" is greater than the maximum value \"+n.maximum)]:[]}function jr(t){var e,r,n,i=t.valueSpec,a=Nt(t.value.type),o={},s=\"categorical\"!==a&&void 0===t.value.property,l=!s,c=\"array\"===wr(t.value.stops)&&\"array\"===wr(t.value.stops[0])&&\"object\"===wr(t.value.stops[0][0]),u=Fr({key:t.key,value:t.value,valueSpec:t.styleSpec.function,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{stops:function(t){if(\"identity\"===a)return[new Dt(t.key,t.value,'identity function may not have a \"stops\" property')];var e=[],r=t.value;return e=e.concat(Br({key:t.key,value:r,valueSpec:t.valueSpec,style:t.style,styleSpec:t.styleSpec,arrayElementValidator:h})),\"array\"===wr(r)&&0===r.length&&e.push(new Dt(t.key,r,\"array must have at least one stop\")),e},default:function(t){return ln({key:t.key,value:t.value,valueSpec:i,style:t.style,styleSpec:t.styleSpec})}}});return\"identity\"===a&&s&&u.push(new Dt(t.key,t.value,'missing required property \"property\"')),\"identity\"===a||t.value.stops||u.push(new Dt(t.key,t.value,'missing required property \"stops\"')),\"exponential\"===a&&t.valueSpec.expression&&!_r(t.valueSpec)&&u.push(new Dt(t.key,t.value,\"exponential functions not supported\")),t.styleSpec.$version>=8&&(l&&!xr(t.valueSpec)?u.push(new Dt(t.key,t.value,\"property functions not supported\")):s&&!br(t.valueSpec)&&u.push(new Dt(t.key,t.value,\"zoom functions not supported\"))),\"categorical\"!==a&&!c||void 0!==t.value.property||u.push(new Dt(t.key,t.value,'\"property\" property is required')),u;function h(t){var e=[],a=t.value,s=t.key;if(\"array\"!==wr(a))return[new Dt(s,a,\"array expected, \"+wr(a)+\" found\")];if(2!==a.length)return[new Dt(s,a,\"array length 2 expected, length \"+a.length+\" found\")];if(c){if(\"object\"!==wr(a[0]))return[new Dt(s,a,\"object expected, \"+wr(a[0])+\" found\")];if(void 0===a[0].zoom)return[new Dt(s,a,\"object stop key must have zoom\")];if(void 0===a[0].value)return[new Dt(s,a,\"object stop key must have value\")];if(n&&n>Nt(a[0].zoom))return[new Dt(s,a[0].zoom,\"stop zoom values must appear in ascending order\")];Nt(a[0].zoom)!==n&&(n=Nt(a[0].zoom),r=void 0,o={}),e=e.concat(Fr({key:s+\"[0]\",value:a[0],valueSpec:{zoom:{}},style:t.style,styleSpec:t.styleSpec,objectElementValidators:{zoom:Nr,value:f}}))}else e=e.concat(f({key:s+\"[0]\",value:a[0],valueSpec:{},style:t.style,styleSpec:t.styleSpec},a));return Pr(jt(a[1]))?e.concat([new Dt(s+\"[1]\",a[1],\"expressions are not allowed in function stops.\")]):e.concat(ln({key:s+\"[1]\",value:a[1],valueSpec:i,style:t.style,styleSpec:t.styleSpec}))}function f(t,n){var s=wr(t.value),l=Nt(t.value),c=null!==t.value?t.value:n;if(e){if(s!==e)return[new Dt(t.key,c,s+\" stop domain type must match previous stop domain type \"+e)]}else e=s;if(\"number\"!==s&&\"string\"!==s&&\"boolean\"!==s)return[new Dt(t.key,c,\"stop domain value must be a number, string, or boolean\")];if(\"number\"!==s&&\"categorical\"!==a){var u=\"number expected, \"+s+\" found\";return xr(i)&&void 0===a&&(u+='\\nIf you intended to use a categorical function, specify `\"type\": \"categorical\"`.'),[new Dt(t.key,c,u)]}return\"categorical\"!==a||\"number\"!==s||isFinite(l)&&Math.floor(l)===l?\"categorical\"!==a&&\"number\"===s&&void 0!==r&&l<r?[new Dt(t.key,c,\"stop domain values must appear in ascending order\")]:(r=l,\"categorical\"===a&&l in o?[new Dt(t.key,c,\"stop domain values must be unique\")]:(o[l]=!0,[])):[new Dt(t.key,c,\"integer expected, found \"+l)]}}function Ur(t){var e=(\"property\"===t.expressionContext?Dr:Or)(jt(t.value),t.valueSpec);if(\"error\"===e.result)return e.value.map(function(e){return new Dt(\"\"+t.key+e.key,t.value,e.message)});var r=e.value.expression||e.value._styleExpression.expression;if(\"property\"===t.expressionContext&&\"text-font\"===t.propertyKey&&-1!==r.possibleOutputs().indexOf(void 0))return[new Dt(t.key,t.value,'Invalid data expression for \"'+t.propertyKey+'\". Output values must be contained as literals within the expression.')];if(\"property\"===t.expressionContext&&\"layout\"===t.propertyType&&!we(r))return[new Dt(t.key,t.value,'\"feature-state\" data expressions are not supported with layout properties.')];if(\"filter\"===t.expressionContext&&!we(r))return[new Dt(t.key,t.value,'\"feature-state\" data expressions are not supported with filters.')];if(t.expressionContext&&0===t.expressionContext.indexOf(\"cluster\")){if(!ke(r,[\"zoom\",\"feature-state\"]))return[new Dt(t.key,t.value,'\"zoom\" and \"feature-state\" expressions are not supported with cluster properties.')];if(\"cluster-initial\"===t.expressionContext&&!_e(r))return[new Dt(t.key,t.value,\"Feature data expressions are not supported with initial expression part of cluster properties.\")]}return[]}function Vr(t){var e=t.key,r=t.value,n=t.valueSpec,i=[];return Array.isArray(n.values)?-1===n.values.indexOf(Nt(r))&&i.push(new Dt(e,r,\"expected one of [\"+n.values.join(\", \")+\"], \"+JSON.stringify(r)+\" found\")):-1===Object.keys(n.values).indexOf(Nt(r))&&i.push(new Dt(e,r,\"expected one of [\"+Object.keys(n.values).join(\", \")+\"], \"+JSON.stringify(r)+\" found\")),i}function qr(t){if(!0===t||!1===t)return!0;if(!Array.isArray(t)||0===t.length)return!1;switch(t[0]){case\"has\":return t.length>=2&&\"$id\"!==t[1]&&\"$type\"!==t[1];case\"in\":case\"!in\":case\"!has\":case\"none\":return!1;case\"==\":case\"!=\":case\">\":case\">=\":case\"<\":case\"<=\":return 3!==t.length||Array.isArray(t[1])||Array.isArray(t[2]);case\"any\":case\"all\":for(var e=0,r=t.slice(1);e<r.length;e+=1){var n=r[e];if(!qr(n)&&\"boolean\"!=typeof n)return!1}return!0;default:return!0}}Rr.deserialize=function(t){return new Rr(t._parameters,t._specification)},Rr.serialize=function(t){return{_parameters:t._parameters,_specification:t._specification}};var Hr={type:\"boolean\",default:!1,transition:!1,\"property-type\":\"data-driven\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]}};function Gr(t){if(null==t)return function(){return!0};qr(t)||(t=Wr(t));var e=Or(t,Hr);if(\"error\"===e.result)throw new Error(e.value.map(function(t){return t.key+\": \"+t.message}).join(\", \"));return function(t,r){return e.value.evaluate(t,r)}}function Yr(t,e){return t<e?-1:t>e?1:0}function Wr(t){if(!t)return!0;var e,r=t[0];return t.length<=1?\"any\"!==r:\"==\"===r?Xr(t[1],t[2],\"==\"):\"!=\"===r?Kr(Xr(t[1],t[2],\"==\")):\"<\"===r||\">\"===r||\"<=\"===r||\">=\"===r?Xr(t[1],t[2],r):\"any\"===r?(e=t.slice(1),[\"any\"].concat(e.map(Wr))):\"all\"===r?[\"all\"].concat(t.slice(1).map(Wr)):\"none\"===r?[\"all\"].concat(t.slice(1).map(Wr).map(Kr)):\"in\"===r?Zr(t[1],t.slice(2)):\"!in\"===r?Kr(Zr(t[1],t.slice(2))):\"has\"===r?Jr(t[1]):\"!has\"!==r||Kr(Jr(t[1]))}function Xr(t,e,r){switch(t){case\"$type\":return[\"filter-type-\"+r,e];case\"$id\":return[\"filter-id-\"+r,e];default:return[\"filter-\"+r,t,e]}}function Zr(t,e){if(0===e.length)return!1;switch(t){case\"$type\":return[\"filter-type-in\",[\"literal\",e]];case\"$id\":return[\"filter-id-in\",[\"literal\",e]];default:return e.length>200&&!e.some(function(t){return typeof t!=typeof e[0]})?[\"filter-in-large\",t,[\"literal\",e.sort(Yr)]]:[\"filter-in-small\",t,[\"literal\",e]]}}function Jr(t){switch(t){case\"$type\":return!0;case\"$id\":return[\"filter-has-id\"];default:return[\"filter-has\",t]}}function Kr(t){return[\"!\",t]}function $r(t){return qr(jt(t.value))?Ur(Ft({},t,{expressionContext:\"filter\",valueSpec:{value:\"boolean\"}})):function t(e){var r=e.value,n=e.key;if(\"array\"!==wr(r))return[new Dt(n,r,\"array expected, \"+wr(r)+\" found\")];var i,a=e.styleSpec,o=[];if(r.length<1)return[new Dt(n,r,\"filter array must have at least 1 element\")];switch(o=o.concat(Vr({key:n+\"[0]\",value:r[0],valueSpec:a.filter_operator,style:e.style,styleSpec:e.styleSpec})),Nt(r[0])){case\"<\":case\"<=\":case\">\":case\">=\":r.length>=2&&\"$type\"===Nt(r[1])&&o.push(new Dt(n,r,'\"$type\" cannot be use with operator \"'+r[0]+'\"'));case\"==\":case\"!=\":3!==r.length&&o.push(new Dt(n,r,'filter array for operator \"'+r[0]+'\" must have 3 elements'));case\"in\":case\"!in\":r.length>=2&&\"string\"!==(i=wr(r[1]))&&o.push(new Dt(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"));for(var s=2;s<r.length;s++)i=wr(r[s]),\"$type\"===Nt(r[1])?o=o.concat(Vr({key:n+\"[\"+s+\"]\",value:r[s],valueSpec:a.geometry_type,style:e.style,styleSpec:e.styleSpec})):\"string\"!==i&&\"number\"!==i&&\"boolean\"!==i&&o.push(new Dt(n+\"[\"+s+\"]\",r[s],\"string, number, or boolean expected, \"+i+\" found\"));break;case\"any\":case\"all\":case\"none\":for(var l=1;l<r.length;l++)o=o.concat(t({key:n+\"[\"+l+\"]\",value:r[l],style:e.style,styleSpec:e.styleSpec}));break;case\"has\":case\"!has\":i=wr(r[1]),2!==r.length?o.push(new Dt(n,r,'filter array for \"'+r[0]+'\" operator must have 2 elements')):\"string\"!==i&&o.push(new Dt(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"))}return o}(t)}function Qr(t,e){var r=t.key,n=t.style,i=t.styleSpec,a=t.value,o=t.objectKey,s=i[e+\"_\"+t.layerType];if(!s)return[];var l=o.match(/^(.*)-transition$/);if(\"paint\"===e&&l&&s[l[1]]&&s[l[1]].transition)return ln({key:r,value:a,valueSpec:i.transition,style:n,styleSpec:i});var c,u=t.valueSpec||s[o];if(!u)return[new Dt(r,a,'unknown property \"'+o+'\"')];if(\"string\"===wr(a)&&xr(u)&&!u.tokens&&(c=/^{([^}]+)}$/.exec(a)))return[new Dt(r,a,'\"'+o+'\" does not support interpolation syntax\\nUse an identity property function instead: `{ \"type\": \"identity\", \"property\": '+JSON.stringify(c[1])+\" }`.\")];var h=[];return\"symbol\"===t.layerType&&(\"text-field\"===o&&n&&!n.glyphs&&h.push(new Dt(r,a,'use of \"text-field\" requires a style \"glyphs\" property')),\"text-font\"===o&&kr(jt(a))&&\"identity\"===Nt(a.type)&&h.push(new Dt(r,a,'\"text-font\" does not support identity functions'))),h.concat(ln({key:t.key,value:a,valueSpec:u,style:n,styleSpec:i,expressionContext:\"property\",propertyType:e,propertyKey:o}))}function tn(t){return Qr(t,\"paint\")}function en(t){return Qr(t,\"layout\")}function rn(t){var e=[],r=t.value,n=t.key,i=t.style,a=t.styleSpec;r.type||r.ref||e.push(new Dt(n,r,'either \"type\" or \"ref\" is required'));var o,s=Nt(r.type),l=Nt(r.ref);if(r.id)for(var c=Nt(r.id),u=0;u<t.arrayIndex;u++){var h=i.layers[u];Nt(h.id)===c&&e.push(new Dt(n,r.id,'duplicate layer id \"'+r.id+'\", previously used at line '+h.id.__line__))}if(\"ref\"in r)[\"type\",\"source\",\"source-layer\",\"filter\",\"layout\"].forEach(function(t){t in r&&e.push(new Dt(n,r[t],'\"'+t+'\" is prohibited for ref layers'))}),i.layers.forEach(function(t){Nt(t.id)===l&&(o=t)}),o?o.ref?e.push(new Dt(n,r.ref,\"ref cannot reference another ref layer\")):s=Nt(o.type):e.push(new Dt(n,r.ref,'ref layer \"'+l+'\" not found'));else if(\"background\"!==s)if(r.source){var f=i.sources&&i.sources[r.source],p=f&&Nt(f.type);f?\"vector\"===p&&\"raster\"===s?e.push(new Dt(n,r.source,'layer \"'+r.id+'\" requires a raster source')):\"raster\"===p&&\"raster\"!==s?e.push(new Dt(n,r.source,'layer \"'+r.id+'\" requires a vector source')):\"vector\"!==p||r[\"source-layer\"]?\"raster-dem\"===p&&\"hillshade\"!==s?e.push(new Dt(n,r.source,\"raster-dem source can only be used with layer type 'hillshade'.\")):\"line\"!==s||!r.paint||!r.paint[\"line-gradient\"]||\"geojson\"===p&&f.lineMetrics||e.push(new Dt(n,r,'layer \"'+r.id+'\" specifies a line-gradient, which requires a GeoJSON source with `lineMetrics` enabled.')):e.push(new Dt(n,r,'layer \"'+r.id+'\" must specify a \"source-layer\"')):e.push(new Dt(n,r.source,'source \"'+r.source+'\" not found'))}else e.push(new Dt(n,r,'missing required property \"source\"'));return e=e.concat(Fr({key:n,value:r,valueSpec:a.layer,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(){return[]},type:function(){return ln({key:n+\".type\",value:r.type,valueSpec:a.layer.type,style:t.style,styleSpec:t.styleSpec,object:r,objectKey:\"type\"})},filter:$r,layout:function(t){return Fr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return en(Ft({layerType:s},t))}}})},paint:function(t){return Fr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return tn(Ft({layerType:s},t))}}})}}}))}function nn(t){var e=t.value,r=t.key,n=t.styleSpec,i=t.style;if(!e.type)return[new Dt(r,e,'\"type\" is required')];var a,o=Nt(e.type);switch(o){case\"vector\":case\"raster\":case\"raster-dem\":if(a=Fr({key:r,value:e,valueSpec:n[\"source_\"+o.replace(\"-\",\"_\")],style:t.style,styleSpec:n}),\"url\"in e)for(var s in e)[\"type\",\"url\",\"tileSize\"].indexOf(s)<0&&a.push(new Dt(r+\".\"+s,e[s],'a source with a \"url\" property may not include a \"'+s+'\" property'));return a;case\"geojson\":if(a=Fr({key:r,value:e,valueSpec:n.source_geojson,style:i,styleSpec:n}),e.cluster)for(var l in e.clusterProperties){var c=e.clusterProperties[l],u=c[0],h=c[1],f=\"string\"==typeof u?[u,[\"accumulated\"],[\"get\",l]]:u;a.push.apply(a,Ur({key:r+\".\"+l+\".map\",value:h,expressionContext:\"cluster-map\"})),a.push.apply(a,Ur({key:r+\".\"+l+\".reduce\",value:f,expressionContext:\"cluster-reduce\"}))}return a;case\"video\":return Fr({key:r,value:e,valueSpec:n.source_video,style:i,styleSpec:n});case\"image\":return Fr({key:r,value:e,valueSpec:n.source_image,style:i,styleSpec:n});case\"canvas\":return[new Dt(r,null,\"Please use runtime APIs to add canvas sources, rather than including them in stylesheets.\",\"source.canvas\")];default:return Vr({key:r+\".type\",value:e.type,valueSpec:{values:[\"vector\",\"raster\",\"raster-dem\",\"geojson\",\"video\",\"image\"]},style:i,styleSpec:n})}}function an(t){var e=t.value,r=t.styleSpec,n=r.light,i=t.style,a=[],o=wr(e);if(void 0===e)return a;if(\"object\"!==o)return a.concat([new Dt(\"light\",e,\"object expected, \"+o+\" found\")]);for(var s in e){var l=s.match(/^(.*)-transition$/);a=l&&n[l[1]]&&n[l[1]].transition?a.concat(ln({key:s,value:e[s],valueSpec:r.transition,style:i,styleSpec:r})):n[s]?a.concat(ln({key:s,value:e[s],valueSpec:n[s],style:i,styleSpec:r})):a.concat([new Dt(s,e[s],'unknown property \"'+s+'\"')])}return a}function on(t){var e=t.value,r=t.key,n=wr(e);return\"string\"!==n?[new Dt(r,e,\"string expected, \"+n+\" found\")]:[]}var sn={\"*\":function(){return[]},array:Br,boolean:function(t){var e=t.value,r=t.key,n=wr(e);return\"boolean\"!==n?[new Dt(r,e,\"boolean expected, \"+n+\" found\")]:[]},number:Nr,color:function(t){var e=t.key,r=t.value,n=wr(r);return\"string\"!==n?[new Dt(e,r,\"color expected, \"+n+\" found\")]:null===re(r)?[new Dt(e,r,'color expected, \"'+r+'\" found')]:[]},constants:Rt,enum:Vr,filter:$r,function:jr,layer:rn,object:Fr,source:nn,light:an,string:on,formatted:function(t){return 0===on(t).length?[]:Ur(t)}};function ln(t){var e=t.value,r=t.valueSpec,n=t.styleSpec;return r.expression&&kr(Nt(e))?jr(t):r.expression&&Pr(jt(e))?Ur(t):r.type&&sn[r.type]?sn[r.type](t):Fr(Ft({},t,{valueSpec:r.type?n[r.type]:r}))}function cn(t){var e=t.value,r=t.key,n=on(t);return n.length?n:(-1===e.indexOf(\"{fontstack}\")&&n.push(new Dt(r,e,'\"glyphs\" url must include a \"{fontstack}\" token')),-1===e.indexOf(\"{range}\")&&n.push(new Dt(r,e,'\"glyphs\" url must include a \"{range}\" token')),n)}function un(t,e){e=e||It;var r=[];return r=r.concat(ln({key:\"\",value:t,valueSpec:e.$root,styleSpec:e,style:t,objectElementValidators:{glyphs:cn,\"*\":function(){return[]}}})),t.constants&&(r=r.concat(Rt({key:\"constants\",value:t.constants,style:t,styleSpec:e}))),hn(r)}function hn(t){return[].concat(t).sort(function(t,e){return t.line-e.line})}function fn(t){return function(){for(var e=[],r=arguments.length;r--;)e[r]=arguments[r];return hn(t.apply(this,e))}}un.source=fn(nn),un.light=fn(an),un.layer=fn(rn),un.filter=fn($r),un.paintProperty=fn(tn),un.layoutProperty=fn(en);var pn=un,dn=pn.light,gn=pn.paintProperty,vn=pn.layoutProperty;function mn(t,e){var r=!1;if(e&&e.length)for(var n=0,i=e;n<i.length;n+=1){var a=i[n];t.fire(new Ot(new Error(a.message))),r=!0}return r}var yn=bn,xn=3;function bn(t,e,r){var n=this.cells=[];if(t instanceof ArrayBuffer){this.arrayBuffer=t;var i=new Int32Array(this.arrayBuffer);t=i[0],e=i[1],r=i[2],this.d=e+2*r;for(var a=0;a<this.d*this.d;a++){var o=i[xn+a],s=i[xn+a+1];n.push(o===s?null:i.subarray(o,s))}var l=i[xn+n.length],c=i[xn+n.length+1];this.keys=i.subarray(l,c),this.bboxes=i.subarray(c),this.insert=this._insertReadonly}else{this.d=e+2*r;for(var u=0;u<this.d*this.d;u++)n.push([]);this.keys=[],this.bboxes=[]}this.n=e,this.extent=t,this.padding=r,this.scale=e/t,this.uid=0;var h=r/e*t;this.min=-h,this.max=t+h}bn.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertCell,this.uid++),this.keys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},bn.prototype._insertReadonly=function(){throw\"Cannot insert into a GridIndex created from an ArrayBuffer.\"},bn.prototype._insertCell=function(t,e,r,n,i,a){this.cells[i].push(a)},bn.prototype.query=function(t,e,r,n,i){var a=this.min,o=this.max;if(t<=a&&e<=a&&o<=r&&o<=n&&!i)return Array.prototype.slice.call(this.keys);var s=[];return this._forEachCell(t,e,r,n,this._queryCell,s,{},i),s},bn.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=this.cells[i];if(null!==l)for(var c=this.keys,u=this.bboxes,h=0;h<l.length;h++){var f=l[h];if(void 0===o[f]){var p=4*f;(s?s(u[p+0],u[p+1],u[p+2],u[p+3]):t<=u[p+2]&&e<=u[p+3]&&r>=u[p+0]&&n>=u[p+1])?(o[f]=!0,a.push(c[f])):o[f]=!1}}},bn.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToCellCoord(t),c=this._convertToCellCoord(e),u=this._convertToCellCoord(r),h=this._convertToCellCoord(n),f=l;f<=u;f++)for(var p=c;p<=h;p++){var d=this.d*p+f;if((!s||s(this._convertFromCellCoord(f),this._convertFromCellCoord(p),this._convertFromCellCoord(f+1),this._convertFromCellCoord(p+1)))&&i.call(this,t,e,r,n,d,a,o,s))return}},bn.prototype._convertFromCellCoord=function(t){return(t-this.padding)/this.scale},bn.prototype._convertToCellCoord=function(t){return Math.max(0,Math.min(this.d-1,Math.floor(t*this.scale)+this.padding))},bn.prototype.toArrayBuffer=function(){if(this.arrayBuffer)return this.arrayBuffer;for(var t=this.cells,e=xn+this.cells.length+1+1,r=0,n=0;n<this.cells.length;n++)r+=this.cells[n].length;var i=new Int32Array(e+r+this.keys.length+this.bboxes.length);i[0]=this.extent,i[1]=this.n,i[2]=this.padding;for(var a=e,o=0;o<t.length;o++){var s=t[o];i[xn+o]=a,i.set(s,a),a+=s.length}return i[xn+t.length]=a,i.set(this.keys,a),a+=this.keys.length,i[xn+t.length+1]=a,i.set(this.bboxes,a),a+=this.bboxes.length,i.buffer};var _n=self.ImageData,wn={};function kn(t,e,r){void 0===r&&(r={}),Object.defineProperty(e,\"_classRegistryKey\",{value:t,writeable:!1}),wn[t]={klass:e,omit:r.omit||[],shallow:r.shallow||[]}}for(var Tn in kn(\"Object\",Object),yn.serialize=function(t,e){var r=t.toArrayBuffer();return e&&e.push(r),{buffer:r}},yn.deserialize=function(t){return new yn(t.buffer)},kn(\"Grid\",yn),kn(\"Color\",ne),kn(\"Error\",Error),kn(\"StylePropertyFunction\",Rr),kn(\"StyleExpression\",Lr,{omit:[\"_evaluator\"]}),kn(\"ZoomDependentExpression\",Ir),kn(\"ZoomConstantExpression\",zr),kn(\"CompoundExpression\",xe,{omit:[\"_evaluate\"]}),fr)fr[Tn]._classRegistryKey||kn(\"Expression_\"+Tn,fr[Tn]);function An(t,e){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp)return t;if(t instanceof ArrayBuffer)return e&&e.push(t),t;if(ArrayBuffer.isView(t)){var r=t;return e&&e.push(r.buffer),r}if(t instanceof _n)return e&&e.push(t.data.buffer),t;if(Array.isArray(t)){for(var n=[],i=0,a=t;i<a.length;i+=1){var o=a[i];n.push(An(o,e))}return n}if(\"object\"==typeof t){var s=t.constructor,l=s._classRegistryKey;if(!l)throw new Error(\"can't serialize object of unregistered class\");var c=s.serialize?s.serialize(t,e):{};if(!s.serialize){for(var u in t)if(t.hasOwnProperty(u)&&!(wn[l].omit.indexOf(u)>=0)){var h=t[u];c[u]=wn[l].shallow.indexOf(u)>=0?h:An(h,e)}t instanceof Error&&(c.message=t.message)}if(c.$name)throw new Error(\"$name property is reserved for worker serialization logic.\");return\"Object\"!==l&&(c.$name=l),c}throw new Error(\"can't serialize object of type \"+typeof t)}function Mn(t){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp||t instanceof ArrayBuffer||ArrayBuffer.isView(t)||t instanceof _n)return t;if(Array.isArray(t))return t.map(Mn);if(\"object\"==typeof t){var e=t.$name||\"Object\",r=wn[e].klass;if(!r)throw new Error(\"can't deserialize unregistered class \"+e);if(r.deserialize)return r.deserialize(t);for(var n=Object.create(r.prototype),i=0,a=Object.keys(t);i<a.length;i+=1){var o=a[i];if(\"$name\"!==o){var s=t[o];n[o]=wn[e].shallow.indexOf(o)>=0?s:Mn(s)}}return n}throw new Error(\"can't deserialize object of type \"+typeof t)}var Sn=function(){this.first=!0};Sn.prototype.update=function(t,e){var r=Math.floor(t);return this.first?(this.first=!1,this.lastIntegerZoom=r,this.lastIntegerZoomTime=0,this.lastZoom=t,this.lastFloorZoom=r,!0):(this.lastFloorZoom>r?(this.lastIntegerZoom=r+1,this.lastIntegerZoomTime=e):this.lastFloorZoom<r&&(this.lastIntegerZoom=r,this.lastIntegerZoomTime=e),t!==this.lastZoom&&(this.lastZoom=t,this.lastFloorZoom=r,!0))};var En={\"Latin-1 Supplement\":function(t){return t>=128&&t<=255},Arabic:function(t){return t>=1536&&t<=1791},\"Arabic Supplement\":function(t){return t>=1872&&t<=1919},\"Arabic Extended-A\":function(t){return t>=2208&&t<=2303},\"Hangul Jamo\":function(t){return t>=4352&&t<=4607},\"Unified Canadian Aboriginal Syllabics\":function(t){return t>=5120&&t<=5759},Khmer:function(t){return t>=6016&&t<=6143},\"Unified Canadian Aboriginal Syllabics Extended\":function(t){return t>=6320&&t<=6399},\"General Punctuation\":function(t){return t>=8192&&t<=8303},\"Letterlike Symbols\":function(t){return t>=8448&&t<=8527},\"Number Forms\":function(t){return t>=8528&&t<=8591},\"Miscellaneous Technical\":function(t){return t>=8960&&t<=9215},\"Control Pictures\":function(t){return t>=9216&&t<=9279},\"Optical Character Recognition\":function(t){return t>=9280&&t<=9311},\"Enclosed Alphanumerics\":function(t){return t>=9312&&t<=9471},\"Geometric Shapes\":function(t){return t>=9632&&t<=9727},\"Miscellaneous Symbols\":function(t){return t>=9728&&t<=9983},\"Miscellaneous Symbols and Arrows\":function(t){return t>=11008&&t<=11263},\"CJK Radicals Supplement\":function(t){return t>=11904&&t<=12031},\"Kangxi Radicals\":function(t){return t>=12032&&t<=12255},\"Ideographic Description Characters\":function(t){return t>=12272&&t<=12287},\"CJK Symbols and Punctuation\":function(t){return t>=12288&&t<=12351},Hiragana:function(t){return t>=12352&&t<=12447},Katakana:function(t){return t>=12448&&t<=12543},Bopomofo:function(t){return t>=12544&&t<=12591},\"Hangul Compatibility Jamo\":function(t){return t>=12592&&t<=12687},Kanbun:function(t){return t>=12688&&t<=12703},\"Bopomofo Extended\":function(t){return t>=12704&&t<=12735},\"CJK Strokes\":function(t){return t>=12736&&t<=12783},\"Katakana Phonetic Extensions\":function(t){return t>=12784&&t<=12799},\"Enclosed CJK Letters and Months\":function(t){return t>=12800&&t<=13055},\"CJK Compatibility\":function(t){return t>=13056&&t<=13311},\"CJK Unified Ideographs Extension A\":function(t){return t>=13312&&t<=19903},\"Yijing Hexagram Symbols\":function(t){return t>=19904&&t<=19967},\"CJK Unified Ideographs\":function(t){return t>=19968&&t<=40959},\"Yi Syllables\":function(t){return t>=40960&&t<=42127},\"Yi Radicals\":function(t){return t>=42128&&t<=42191},\"Hangul Jamo Extended-A\":function(t){return t>=43360&&t<=43391},\"Hangul Syllables\":function(t){return t>=44032&&t<=55215},\"Hangul Jamo Extended-B\":function(t){return t>=55216&&t<=55295},\"Private Use Area\":function(t){return t>=57344&&t<=63743},\"CJK Compatibility Ideographs\":function(t){return t>=63744&&t<=64255},\"Arabic Presentation Forms-A\":function(t){return t>=64336&&t<=65023},\"Vertical Forms\":function(t){return t>=65040&&t<=65055},\"CJK Compatibility Forms\":function(t){return t>=65072&&t<=65103},\"Small Form Variants\":function(t){return t>=65104&&t<=65135},\"Arabic Presentation Forms-B\":function(t){return t>=65136&&t<=65279},\"Halfwidth and Fullwidth Forms\":function(t){return t>=65280&&t<=65519}};function Cn(t){for(var e=0,r=t;e<r.length;e+=1)if(On(r[e].charCodeAt(0)))return!0;return!1}function Ln(t){for(var e=0,r=t;e<r.length;e+=1)if(!Pn(r[e].charCodeAt(0)))return!1;return!0}function Pn(t){return!(En.Arabic(t)||En[\"Arabic Supplement\"](t)||En[\"Arabic Extended-A\"](t)||En[\"Arabic Presentation Forms-A\"](t)||En[\"Arabic Presentation Forms-B\"](t))}function On(t){return!!(746===t||747===t||!(t<4352)&&(En[\"Bopomofo Extended\"](t)||En.Bopomofo(t)||En[\"CJK Compatibility Forms\"](t)&&!(t>=65097&&t<=65103)||En[\"CJK Compatibility Ideographs\"](t)||En[\"CJK Compatibility\"](t)||En[\"CJK Radicals Supplement\"](t)||En[\"CJK Strokes\"](t)||!(!En[\"CJK Symbols and Punctuation\"](t)||t>=12296&&t<=12305||t>=12308&&t<=12319||12336===t)||En[\"CJK Unified Ideographs Extension A\"](t)||En[\"CJK Unified Ideographs\"](t)||En[\"Enclosed CJK Letters and Months\"](t)||En[\"Hangul Compatibility Jamo\"](t)||En[\"Hangul Jamo Extended-A\"](t)||En[\"Hangul Jamo Extended-B\"](t)||En[\"Hangul Jamo\"](t)||En[\"Hangul Syllables\"](t)||En.Hiragana(t)||En[\"Ideographic Description Characters\"](t)||En.Kanbun(t)||En[\"Kangxi Radicals\"](t)||En[\"Katakana Phonetic Extensions\"](t)||En.Katakana(t)&&12540!==t||!(!En[\"Halfwidth and Fullwidth Forms\"](t)||65288===t||65289===t||65293===t||t>=65306&&t<=65310||65339===t||65341===t||65343===t||t>=65371&&t<=65503||65507===t||t>=65512&&t<=65519)||!(!En[\"Small Form Variants\"](t)||t>=65112&&t<=65118||t>=65123&&t<=65126)||En[\"Unified Canadian Aboriginal Syllabics\"](t)||En[\"Unified Canadian Aboriginal Syllabics Extended\"](t)||En[\"Vertical Forms\"](t)||En[\"Yijing Hexagram Symbols\"](t)||En[\"Yi Syllables\"](t)||En[\"Yi Radicals\"](t)))}function zn(t){return!(On(t)||function(t){return!!(En[\"Latin-1 Supplement\"](t)&&(167===t||169===t||174===t||177===t||188===t||189===t||190===t||215===t||247===t)||En[\"General Punctuation\"](t)&&(8214===t||8224===t||8225===t||8240===t||8241===t||8251===t||8252===t||8258===t||8263===t||8264===t||8265===t||8273===t)||En[\"Letterlike Symbols\"](t)||En[\"Number Forms\"](t)||En[\"Miscellaneous Technical\"](t)&&(t>=8960&&t<=8967||t>=8972&&t<=8991||t>=8996&&t<=9e3||9003===t||t>=9085&&t<=9114||t>=9150&&t<=9165||9167===t||t>=9169&&t<=9179||t>=9186&&t<=9215)||En[\"Control Pictures\"](t)&&9251!==t||En[\"Optical Character Recognition\"](t)||En[\"Enclosed Alphanumerics\"](t)||En[\"Geometric Shapes\"](t)||En[\"Miscellaneous Symbols\"](t)&&!(t>=9754&&t<=9759)||En[\"Miscellaneous Symbols and Arrows\"](t)&&(t>=11026&&t<=11055||t>=11088&&t<=11097||t>=11192&&t<=11243)||En[\"CJK Symbols and Punctuation\"](t)||En.Katakana(t)||En[\"Private Use Area\"](t)||En[\"CJK Compatibility Forms\"](t)||En[\"Small Form Variants\"](t)||En[\"Halfwidth and Fullwidth Forms\"](t)||8734===t||8756===t||8757===t||t>=9984&&t<=10087||t>=10102&&t<=10131||65532===t||65533===t)}(t))}function In(t,e){return!(!e&&(t>=1424&&t<=2303||En[\"Arabic Presentation Forms-A\"](t)||En[\"Arabic Presentation Forms-B\"](t))||t>=2304&&t<=3583||t>=3840&&t<=4255||En.Khmer(t))}var Dn,Rn=!1,Fn=null,Bn=!1,Nn=new zt,jn={applyArabicShaping:null,processBidirectionalText:null,processStyledBidirectionalText:null,isLoaded:function(){return Bn||null!=jn.applyArabicShaping}},Un=function(t,e){this.zoom=t,e?(this.now=e.now,this.fadeDuration=e.fadeDuration,this.zoomHistory=e.zoomHistory,this.transition=e.transition):(this.now=0,this.fadeDuration=0,this.zoomHistory=new Sn,this.transition={})};Un.prototype.isSupportedScript=function(t){return function(t,e){for(var r=0,n=t;r<n.length;r+=1)if(!In(n[r].charCodeAt(0),e))return!1;return!0}(t,jn.isLoaded())},Un.prototype.crossFadingFactor=function(){return 0===this.fadeDuration?1:Math.min((this.now-this.zoomHistory.lastIntegerZoomTime)/this.fadeDuration,1)},Un.prototype.getCrossfadeParameters=function(){var t=this.zoom,e=t-Math.floor(t),r=this.crossFadingFactor();return t>this.zoomHistory.lastIntegerZoom?{fromScale:2,toScale:1,t:e+(1-e)*r}:{fromScale:.5,toScale:1,t:1-(1-r)*e}};var Vn=function(t,e){this.property=t,this.value=e,this.expression=function(t,e){if(kr(t))return new Rr(t,e);if(Pr(t)){var r=Dr(t,e);if(\"error\"===r.result)throw new Error(r.value.map(function(t){return t.key+\": \"+t.message}).join(\", \"));return r.value}var n=t;return\"string\"==typeof t&&\"color\"===e.type&&(n=ne.parse(t)),{kind:\"constant\",evaluate:function(){return n}}}(void 0===e?t.specification.default:e,t.specification)};Vn.prototype.isDataDriven=function(){return\"source\"===this.expression.kind||\"composite\"===this.expression.kind},Vn.prototype.possiblyEvaluate=function(t){return this.property.possiblyEvaluate(this,t)};var qn=function(t){this.property=t,this.value=new Vn(t,void 0)};qn.prototype.transitioned=function(t,e){return new Gn(this.property,this.value,e,h({},t.transition,this.transition),t.now)},qn.prototype.untransitioned=function(){return new Gn(this.property,this.value,null,{},0)};var Hn=function(t){this._properties=t,this._values=Object.create(t.defaultTransitionablePropertyValues)};Hn.prototype.getValue=function(t){return b(this._values[t].value.value)},Hn.prototype.setValue=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new qn(this._values[t].property)),this._values[t].value=new Vn(this._values[t].property,null===e?void 0:b(e))},Hn.prototype.getTransition=function(t){return b(this._values[t].transition)},Hn.prototype.setTransition=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new qn(this._values[t].property)),this._values[t].transition=b(e)||void 0},Hn.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i);var a=this.getTransition(n);void 0!==a&&(t[n+\"-transition\"]=a)}return t},Hn.prototype.transitioned=function(t,e){for(var r=new Yn(this._properties),n=0,i=Object.keys(this._values);n<i.length;n+=1){var a=i[n];r._values[a]=this._values[a].transitioned(t,e._values[a])}return r},Hn.prototype.untransitioned=function(){for(var t=new Yn(this._properties),e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e];t._values[n]=this._values[n].untransitioned()}return t};var Gn=function(t,e,r,n,i){this.property=t,this.value=e,this.begin=i+n.delay||0,this.end=this.begin+n.duration||0,t.specification.transition&&(n.delay||n.duration)&&(this.prior=r)};Gn.prototype.possiblyEvaluate=function(t){var e=t.now||0,r=this.value.possiblyEvaluate(t),n=this.prior;if(n){if(e>this.end)return this.prior=null,r;if(this.value.isDataDriven())return this.prior=null,r;if(e<this.begin)return n.possiblyEvaluate(t);var i=(e-this.begin)/(this.end-this.begin);return this.property.interpolate(n.possiblyEvaluate(t),r,function(t){if(i<=0)return 0;if(i>=1)return 1;var e=i*i,r=e*i;return 4*(i<.5?r:3*(i-e)+r-.75)}())}return r};var Yn=function(t){this._properties=t,this._values=Object.create(t.defaultTransitioningPropertyValues)};Yn.prototype.possiblyEvaluate=function(t){for(var e=new Zn(this._properties),r=0,n=Object.keys(this._values);r<n.length;r+=1){var i=n[r];e._values[i]=this._values[i].possiblyEvaluate(t)}return e},Yn.prototype.hasTransition=function(){for(var t=0,e=Object.keys(this._values);t<e.length;t+=1){var r=e[t];if(this._values[r].prior)return!0}return!1};var Wn=function(t){this._properties=t,this._values=Object.create(t.defaultPropertyValues)};Wn.prototype.getValue=function(t){return b(this._values[t].value)},Wn.prototype.setValue=function(t,e){this._values[t]=new Vn(this._values[t].property,null===e?void 0:b(e))},Wn.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i)}return t},Wn.prototype.possiblyEvaluate=function(t){for(var e=new Zn(this._properties),r=0,n=Object.keys(this._values);r<n.length;r+=1){var i=n[r];e._values[i]=this._values[i].possiblyEvaluate(t)}return e};var Xn=function(t,e,r){this.property=t,this.value=e,this.parameters=r};Xn.prototype.isConstant=function(){return\"constant\"===this.value.kind},Xn.prototype.constantOr=function(t){return\"constant\"===this.value.kind?this.value.value:t},Xn.prototype.evaluate=function(t,e){return this.property.evaluate(this.value,this.parameters,t,e)};var Zn=function(t){this._properties=t,this._values=Object.create(t.defaultPossiblyEvaluatedValues)};Zn.prototype.get=function(t){return this._values[t]};var Jn=function(t){this.specification=t};Jn.prototype.possiblyEvaluate=function(t,e){return t.expression.evaluate(e)},Jn.prototype.interpolate=function(t,e,r){var n=Ce[this.specification.type];return n?n(t,e,r):t};var Kn=function(t){this.specification=t};Kn.prototype.possiblyEvaluate=function(t,e){return\"constant\"===t.expression.kind||\"camera\"===t.expression.kind?new Xn(this,{kind:\"constant\",value:t.expression.evaluate(e)},e):new Xn(this,t.expression,e)},Kn.prototype.interpolate=function(t,e,r){if(\"constant\"!==t.value.kind||\"constant\"!==e.value.kind)return t;if(void 0===t.value.value||void 0===e.value.value)return new Xn(this,{kind:\"constant\",value:void 0},t.parameters);var n=Ce[this.specification.type];return n?new Xn(this,{kind:\"constant\",value:n(t.value.value,e.value.value,r)},t.parameters):t},Kn.prototype.evaluate=function(t,e,r,n){return\"constant\"===t.kind?t.value:t.evaluate(e,r,n)};var $n=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(t,e){if(void 0===t.value)return new Xn(this,{kind:\"constant\",value:void 0},e);if(\"constant\"===t.expression.kind){var r=t.expression.evaluate(e),n=this._calculate(r,r,r,e);return new Xn(this,{kind:\"constant\",value:n},e)}if(\"camera\"===t.expression.kind){var i=this._calculate(t.expression.evaluate({zoom:e.zoom-1}),t.expression.evaluate({zoom:e.zoom}),t.expression.evaluate({zoom:e.zoom+1}),e);return new Xn(this,{kind:\"constant\",value:i},e)}return new Xn(this,t.expression,e)},e.prototype.evaluate=function(t,e,r,n){if(\"source\"===t.kind){var i=t.evaluate(e,r,n);return this._calculate(i,i,i,e)}return\"composite\"===t.kind?this._calculate(t.evaluate({zoom:Math.floor(e.zoom)-1},r,n),t.evaluate({zoom:Math.floor(e.zoom)},r,n),t.evaluate({zoom:Math.floor(e.zoom)+1},r,n),e):t.value},e.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},e.prototype.interpolate=function(t){return t},e}(Kn),Qn=function(t){this.specification=t};Qn.prototype.possiblyEvaluate=function(t,e){if(void 0!==t.value){if(\"constant\"===t.expression.kind){var r=t.expression.evaluate(e);return this._calculate(r,r,r,e)}return this._calculate(t.expression.evaluate(new Un(Math.floor(e.zoom-1),e)),t.expression.evaluate(new Un(Math.floor(e.zoom),e)),t.expression.evaluate(new Un(Math.floor(e.zoom+1),e)),e)}},Qn.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},Qn.prototype.interpolate=function(t){return t};var ti=function(t){this.specification=t};ti.prototype.possiblyEvaluate=function(t,e){return!!t.expression.evaluate(e)},ti.prototype.interpolate=function(){return!1};var ei=function(t){for(var e in this.properties=t,this.defaultPropertyValues={},this.defaultTransitionablePropertyValues={},this.defaultTransitioningPropertyValues={},this.defaultPossiblyEvaluatedValues={},t){var r=t[e],n=this.defaultPropertyValues[e]=new Vn(r,void 0),i=this.defaultTransitionablePropertyValues[e]=new qn(r);this.defaultTransitioningPropertyValues[e]=i.untransitioned(),this.defaultPossiblyEvaluatedValues[e]=n.possiblyEvaluate({})}};kn(\"DataDrivenProperty\",Kn),kn(\"DataConstantProperty\",Jn),kn(\"CrossFadedDataDrivenProperty\",$n),kn(\"CrossFadedProperty\",Qn),kn(\"ColorRampProperty\",ti);var ri=function(t){function e(e,r){if(t.call(this),this.id=e.id,this.type=e.type,this._featureFilter=function(){return!0},\"custom\"!==e.type&&(e=e,this.metadata=e.metadata,this.minzoom=e.minzoom,this.maxzoom=e.maxzoom,\"background\"!==e.type&&(this.source=e.source,this.sourceLayer=e[\"source-layer\"],this.filter=e.filter),r.layout&&(this._unevaluatedLayout=new Wn(r.layout)),r.paint)){for(var n in this._transitionablePaint=new Hn(r.paint),e.paint)this.setPaintProperty(n,e.paint[n],{validate:!1});for(var i in e.layout)this.setLayoutProperty(i,e.layout[i],{validate:!1});this._transitioningPaint=this._transitionablePaint.untransitioned()}}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getCrossfadeParameters=function(){return this._crossfadeParameters},e.prototype.getLayoutProperty=function(t){return\"visibility\"===t?this.visibility:this._unevaluatedLayout.getValue(t)},e.prototype.setLayoutProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e){var n=\"layers.\"+this.id+\".layout.\"+t;if(this._validate(vn,n,t,e,r))return}\"visibility\"!==t?this._unevaluatedLayout.setValue(t,e):this.visibility=e},e.prototype.getPaintProperty=function(t){return m(t,\"-transition\")?this._transitionablePaint.getTransition(t.slice(0,-\"-transition\".length)):this._transitionablePaint.getValue(t)},e.prototype.setPaintProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e){var n=\"layers.\"+this.id+\".paint.\"+t;if(this._validate(gn,n,t,e,r))return!1}if(m(t,\"-transition\"))return this._transitionablePaint.setTransition(t.slice(0,-\"-transition\".length),e||void 0),!1;var i=this._transitionablePaint._values[t],a=\"cross-faded-data-driven\"===i.property.specification[\"property-type\"],o=i.value.isDataDriven();return this._transitionablePaint.setValue(t,e),this._handleSpecialPaintPropertyUpdate(t),this._transitionablePaint._values[t].value.isDataDriven()||o||a},e.prototype._handleSpecialPaintPropertyUpdate=function(t){},e.prototype.isHidden=function(t){return!!(this.minzoom&&t<this.minzoom)||!!(this.maxzoom&&t>=this.maxzoom)||\"none\"===this.visibility},e.prototype.updateTransitions=function(t){this._transitioningPaint=this._transitionablePaint.transitioned(t,this._transitioningPaint)},e.prototype.hasTransition=function(){return this._transitioningPaint.hasTransition()},e.prototype.recalculate=function(t){t.getCrossfadeParameters&&(this._crossfadeParameters=t.getCrossfadeParameters()),this._unevaluatedLayout&&(this.layout=this._unevaluatedLayout.possiblyEvaluate(t)),this.paint=this._transitioningPaint.possiblyEvaluate(t)},e.prototype.serialize=function(){var t={id:this.id,type:this.type,source:this.source,\"source-layer\":this.sourceLayer,metadata:this.metadata,minzoom:this.minzoom,maxzoom:this.maxzoom,filter:this.filter,layout:this._unevaluatedLayout&&this._unevaluatedLayout.serialize(),paint:this._transitionablePaint&&this._transitionablePaint.serialize()};return this.visibility&&(t.layout=t.layout||{},t.layout.visibility=this.visibility),x(t,function(t,e){return!(void 0===t||\"layout\"===e&&!Object.keys(t).length||\"paint\"===e&&!Object.keys(t).length)})},e.prototype._validate=function(t,e,r,n,i){return void 0===i&&(i={}),(!i||!1!==i.validate)&&mn(this,t.call(pn,{key:e,layerType:this.type,objectKey:r,value:n,styleSpec:It,style:{glyphs:!0,sprite:!0}}))},e.prototype.is3D=function(){return!1},e.prototype.isTileClipped=function(){return!1},e.prototype.hasOffscreenPass=function(){return!1},e.prototype.resize=function(){},e.prototype.isStateDependent=function(){for(var t in this.paint._values){var e=this.paint.get(t);if(e instanceof Xn&&xr(e.property.specification)&&(\"source\"===e.value.kind||\"composite\"===e.value.kind)&&e.value.isStateDependent)return!0}return!1},e}(zt),ni={Int8:Int8Array,Uint8:Uint8Array,Int16:Int16Array,Uint16:Uint16Array,Int32:Int32Array,Uint32:Uint32Array,Float32:Float32Array},ii=function(t,e){this._structArray=t,this._pos1=e*this.size,this._pos2=this._pos1/2,this._pos4=this._pos1/4,this._pos8=this._pos1/8},ai=function(){this.isTransferred=!1,this.capacity=-1,this.resize(0)};function oi(t,e){void 0===e&&(e=1);var r=0,n=0;return{members:t.map(function(t){var i,a=(i=t.type,ni[i].BYTES_PER_ELEMENT),o=r=si(r,Math.max(e,a)),s=t.components||1;return n=Math.max(n,a),r+=a*s,{name:t.name,type:t.type,components:s,offset:o}}),size:si(r,Math.max(n,e)),alignment:e}}function si(t,e){return Math.ceil(t/e)*e}ai.serialize=function(t,e){return t._trim(),e&&(t.isTransferred=!0,e.push(t.arrayBuffer)),{length:t.length,arrayBuffer:t.arrayBuffer}},ai.deserialize=function(t){var e=Object.create(this.prototype);return e.arrayBuffer=t.arrayBuffer,e.length=t.length,e.capacity=t.arrayBuffer.byteLength/e.bytesPerElement,e._refreshViews(),e},ai.prototype._trim=function(){this.length!==this.capacity&&(this.capacity=this.length,this.arrayBuffer=this.arrayBuffer.slice(0,this.length*this.bytesPerElement),this._refreshViews())},ai.prototype.clear=function(){this.length=0},ai.prototype.resize=function(t){this.reserve(t),this.length=t},ai.prototype.reserve=function(t){if(t>this.capacity){this.capacity=Math.max(t,Math.floor(5*this.capacity),128),this.arrayBuffer=new ArrayBuffer(this.capacity*this.bytesPerElement);var e=this.uint8;this._refreshViews(),e&&this.uint8.set(e)}},ai.prototype._refreshViews=function(){throw new Error(\"_refreshViews() must be implemented by each concrete StructArray layout\")};var li=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.int16[n+0]=e,this.int16[n+1]=r,t},e}(ai);li.prototype.bytesPerElement=4,kn(\"StructArrayLayout2i4\",li);var ci=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.int16[a+0]=e,this.int16[a+1]=r,this.int16[a+2]=n,this.int16[a+3]=i,t},e}(ai);ci.prototype.bytesPerElement=8,kn(\"StructArrayLayout4i8\",ci);var ui=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(ai);ui.prototype.bytesPerElement=12,kn(\"StructArrayLayout2i4i12\",ui);var hi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=4*t,l=8*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.uint8[l+4]=n,this.uint8[l+5]=i,this.uint8[l+6]=a,this.uint8[l+7]=o,t},e}(ai);hi.prototype.bytesPerElement=8,kn(\"StructArrayLayout2i4ub8\",hi);var fi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s){var l=this.length;return this.resize(l+1),this.emplace(l,t,e,r,n,i,a,o,s)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l){var c=8*t;return this.uint16[c+0]=e,this.uint16[c+1]=r,this.uint16[c+2]=n,this.uint16[c+3]=i,this.uint16[c+4]=a,this.uint16[c+5]=o,this.uint16[c+6]=s,this.uint16[c+7]=l,t},e}(ai);fi.prototype.bytesPerElement=16,kn(\"StructArrayLayout8ui16\",fi);var pi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s){var l=this.length;return this.resize(l+1),this.emplace(l,t,e,r,n,i,a,o,s)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l){var c=8*t;return this.int16[c+0]=e,this.int16[c+1]=r,this.int16[c+2]=n,this.int16[c+3]=i,this.uint16[c+4]=a,this.uint16[c+5]=o,this.uint16[c+6]=s,this.uint16[c+7]=l,t},e}(ai);pi.prototype.bytesPerElement=16,kn(\"StructArrayLayout4i4ui16\",pi);var di=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.float32[i+0]=e,this.float32[i+1]=r,this.float32[i+2]=n,t},e}(ai);di.prototype.bytesPerElement=12,kn(\"StructArrayLayout3f12\",di);var gi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.uint32[r+0]=e,t},e}(ai);gi.prototype.bytesPerElement=4,kn(\"StructArrayLayout1ul4\",gi);var vi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u){var h=this.length;return this.resize(h+1),this.emplace(h,t,e,r,n,i,a,o,s,l,c,u)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h){var f=12*t,p=6*t;return this.int16[f+0]=e,this.int16[f+1]=r,this.int16[f+2]=n,this.int16[f+3]=i,this.int16[f+4]=a,this.int16[f+5]=o,this.uint32[p+3]=s,this.uint16[f+8]=l,this.uint16[f+9]=c,this.int16[f+10]=u,this.int16[f+11]=h,t},e}(ai);vi.prototype.bytesPerElement=24,kn(\"StructArrayLayout6i1ul2ui2i24\",vi);var mi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(ai);mi.prototype.bytesPerElement=12,kn(\"StructArrayLayout2i2i2i12\",mi);var yi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=12*t,o=3*t;return this.uint8[a+0]=e,this.uint8[a+1]=r,this.float32[o+1]=n,this.float32[o+2]=i,t},e}(ai);yi.prototype.bytesPerElement=12,kn(\"StructArrayLayout2ub2f12\",yi);var xi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d){var g=this.length;return this.resize(g+1),this.emplace(g,t,e,r,n,i,a,o,s,l,c,u,h,f,p,d)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g){var v=22*t,m=11*t,y=44*t;return this.int16[v+0]=e,this.int16[v+1]=r,this.uint16[v+2]=n,this.uint16[v+3]=i,this.uint32[m+2]=a,this.uint32[m+3]=o,this.uint32[m+4]=s,this.uint16[v+10]=l,this.uint16[v+11]=c,this.uint16[v+12]=u,this.float32[m+7]=h,this.float32[m+8]=f,this.uint8[y+36]=p,this.uint8[y+37]=d,this.uint32[m+10]=g,t},e}(ai);xi.prototype.bytesPerElement=44,kn(\"StructArrayLayout2i2ui3ul3ui2f2ub1ul44\",xi);var bi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m){var y=this.length;return this.resize(y+1),this.emplace(y,t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g,v,m,y){var x=22*t,b=11*t;return this.int16[x+0]=e,this.int16[x+1]=r,this.int16[x+2]=n,this.int16[x+3]=i,this.int16[x+4]=a,this.int16[x+5]=o,this.uint16[x+6]=s,this.uint16[x+7]=l,this.uint16[x+8]=c,this.uint16[x+9]=u,this.uint16[x+10]=h,this.uint16[x+11]=f,this.uint16[x+12]=p,this.uint16[x+13]=d,this.uint16[x+14]=g,this.uint32[b+8]=v,this.float32[b+9]=m,this.float32[b+10]=y,t},e}(ai);bi.prototype.bytesPerElement=44,kn(\"StructArrayLayout6i9ui1ul2f44\",bi);var _i=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.float32[r+0]=e,t},e}(ai);_i.prototype.bytesPerElement=4,kn(\"StructArrayLayout1f4\",_i);var wi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.int16[i+0]=e,this.int16[i+1]=r,this.int16[i+2]=n,t},e}(ai);wi.prototype.bytesPerElement=6,kn(\"StructArrayLayout3i6\",wi);var ki=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=2*t,a=4*t;return this.uint32[i+0]=e,this.uint16[a+2]=r,this.uint16[a+3]=n,t},e}(ai);ki.prototype.bytesPerElement=8,kn(\"StructArrayLayout1ul2ui8\",ki);var Ti=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.uint16[i+0]=e,this.uint16[i+1]=r,this.uint16[i+2]=n,t},e}(ai);Ti.prototype.bytesPerElement=6,kn(\"StructArrayLayout3ui6\",Ti);var Ai=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.uint16[n+0]=e,this.uint16[n+1]=r,t},e}(ai);Ai.prototype.bytesPerElement=4,kn(\"StructArrayLayout2ui4\",Ai);var Mi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.uint16[r+0]=e,t},e}(ai);Mi.prototype.bytesPerElement=2,kn(\"StructArrayLayout1ui2\",Mi);var Si=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.float32[n+0]=e,this.float32[n+1]=r,t},e}(ai);Si.prototype.bytesPerElement=8,kn(\"StructArrayLayout2f8\",Si);var Ei=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.float32[a+0]=e,this.float32[a+1]=r,this.float32[a+2]=n,this.float32[a+3]=i,t},e}(ai);Ei.prototype.bytesPerElement=16,kn(\"StructArrayLayout4f16\",Ei);var Ci=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorPointX:{configurable:!0},anchorPointY:{configurable:!0},x1:{configurable:!0},y1:{configurable:!0},x2:{configurable:!0},y2:{configurable:!0},featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0},radius:{configurable:!0},signedDistanceFromAnchor:{configurable:!0},anchorPoint:{configurable:!0}};return r.anchorPointX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorPointX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorPointY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorPointY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.x1.get=function(){return this._structArray.int16[this._pos2+2]},r.x1.set=function(t){this._structArray.int16[this._pos2+2]=t},r.y1.get=function(){return this._structArray.int16[this._pos2+3]},r.y1.set=function(t){this._structArray.int16[this._pos2+3]=t},r.x2.get=function(){return this._structArray.int16[this._pos2+4]},r.x2.set=function(t){this._structArray.int16[this._pos2+4]=t},r.y2.get=function(){return this._structArray.int16[this._pos2+5]},r.y2.set=function(t){this._structArray.int16[this._pos2+5]=t},r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.featureIndex.set=function(t){this._structArray.uint32[this._pos4+3]=t},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.sourceLayerIndex.set=function(t){this._structArray.uint16[this._pos2+8]=t},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.bucketIndex.set=function(t){this._structArray.uint16[this._pos2+9]=t},r.radius.get=function(){return this._structArray.int16[this._pos2+10]},r.radius.set=function(t){this._structArray.int16[this._pos2+10]=t},r.signedDistanceFromAnchor.get=function(){return this._structArray.int16[this._pos2+11]},r.signedDistanceFromAnchor.set=function(t){this._structArray.int16[this._pos2+11]=t},r.anchorPoint.get=function(){return new i(this.anchorPointX,this.anchorPointY)},Object.defineProperties(e.prototype,r),e}(ii);Ci.prototype.size=24;var Li=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Ci(this,t)},e}(vi);kn(\"CollisionBoxArray\",Li);var Pi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},glyphStartIndex:{configurable:!0},numGlyphs:{configurable:!0},vertexStartIndex:{configurable:!0},lineStartIndex:{configurable:!0},lineLength:{configurable:!0},segment:{configurable:!0},lowerSize:{configurable:!0},upperSize:{configurable:!0},lineOffsetX:{configurable:!0},lineOffsetY:{configurable:!0},writingMode:{configurable:!0},hidden:{configurable:!0},crossTileID:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.glyphStartIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.glyphStartIndex.set=function(t){this._structArray.uint16[this._pos2+2]=t},r.numGlyphs.get=function(){return this._structArray.uint16[this._pos2+3]},r.numGlyphs.set=function(t){this._structArray.uint16[this._pos2+3]=t},r.vertexStartIndex.get=function(){return this._structArray.uint32[this._pos4+2]},r.vertexStartIndex.set=function(t){this._structArray.uint32[this._pos4+2]=t},r.lineStartIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.lineStartIndex.set=function(t){this._structArray.uint32[this._pos4+3]=t},r.lineLength.get=function(){return this._structArray.uint32[this._pos4+4]},r.lineLength.set=function(t){this._structArray.uint32[this._pos4+4]=t},r.segment.get=function(){return this._structArray.uint16[this._pos2+10]},r.segment.set=function(t){this._structArray.uint16[this._pos2+10]=t},r.lowerSize.get=function(){return this._structArray.uint16[this._pos2+11]},r.lowerSize.set=function(t){this._structArray.uint16[this._pos2+11]=t},r.upperSize.get=function(){return this._structArray.uint16[this._pos2+12]},r.upperSize.set=function(t){this._structArray.uint16[this._pos2+12]=t},r.lineOffsetX.get=function(){return this._structArray.float32[this._pos4+7]},r.lineOffsetX.set=function(t){this._structArray.float32[this._pos4+7]=t},r.lineOffsetY.get=function(){return this._structArray.float32[this._pos4+8]},r.lineOffsetY.set=function(t){this._structArray.float32[this._pos4+8]=t},r.writingMode.get=function(){return this._structArray.uint8[this._pos1+36]},r.writingMode.set=function(t){this._structArray.uint8[this._pos1+36]=t},r.hidden.get=function(){return this._structArray.uint8[this._pos1+37]},r.hidden.set=function(t){this._structArray.uint8[this._pos1+37]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+10]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+10]=t},Object.defineProperties(e.prototype,r),e}(ii);Pi.prototype.size=44;var Oi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Pi(this,t)},e}(xi);kn(\"PlacedSymbolArray\",Oi);var zi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},rightJustifiedTextSymbolIndex:{configurable:!0},centerJustifiedTextSymbolIndex:{configurable:!0},leftJustifiedTextSymbolIndex:{configurable:!0},verticalPlacedTextSymbolIndex:{configurable:!0},key:{configurable:!0},textBoxStartIndex:{configurable:!0},textBoxEndIndex:{configurable:!0},iconBoxStartIndex:{configurable:!0},iconBoxEndIndex:{configurable:!0},featureIndex:{configurable:!0},numHorizontalGlyphVertices:{configurable:!0},numVerticalGlyphVertices:{configurable:!0},numIconVertices:{configurable:!0},crossTileID:{configurable:!0},textBoxScale:{configurable:!0},radialTextOffset:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorX.set=function(t){this._structArray.int16[this._pos2+0]=t},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.anchorY.set=function(t){this._structArray.int16[this._pos2+1]=t},r.rightJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+2]},r.rightJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+2]=t},r.centerJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+3]},r.centerJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+3]=t},r.leftJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+4]},r.leftJustifiedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+4]=t},r.verticalPlacedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+5]},r.verticalPlacedTextSymbolIndex.set=function(t){this._structArray.int16[this._pos2+5]=t},r.key.get=function(){return this._structArray.uint16[this._pos2+6]},r.key.set=function(t){this._structArray.uint16[this._pos2+6]=t},r.textBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+7]},r.textBoxStartIndex.set=function(t){this._structArray.uint16[this._pos2+7]=t},r.textBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.textBoxEndIndex.set=function(t){this._structArray.uint16[this._pos2+8]=t},r.iconBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.iconBoxStartIndex.set=function(t){this._structArray.uint16[this._pos2+9]=t},r.iconBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+10]},r.iconBoxEndIndex.set=function(t){this._structArray.uint16[this._pos2+10]=t},r.featureIndex.get=function(){return this._structArray.uint16[this._pos2+11]},r.featureIndex.set=function(t){this._structArray.uint16[this._pos2+11]=t},r.numHorizontalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+12]},r.numHorizontalGlyphVertices.set=function(t){this._structArray.uint16[this._pos2+12]=t},r.numVerticalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+13]},r.numVerticalGlyphVertices.set=function(t){this._structArray.uint16[this._pos2+13]=t},r.numIconVertices.get=function(){return this._structArray.uint16[this._pos2+14]},r.numIconVertices.set=function(t){this._structArray.uint16[this._pos2+14]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+8]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+8]=t},r.textBoxScale.get=function(){return this._structArray.float32[this._pos4+9]},r.textBoxScale.set=function(t){this._structArray.float32[this._pos4+9]=t},r.radialTextOffset.get=function(){return this._structArray.float32[this._pos4+10]},r.radialTextOffset.set=function(t){this._structArray.float32[this._pos4+10]=t},Object.defineProperties(e.prototype,r),e}(ii);zi.prototype.size=44;var Ii=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new zi(this,t)},e}(bi);kn(\"SymbolInstanceArray\",Ii);var Di=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={offsetX:{configurable:!0}};return r.offsetX.get=function(){return this._structArray.float32[this._pos4+0]},r.offsetX.set=function(t){this._structArray.float32[this._pos4+0]=t},Object.defineProperties(e.prototype,r),e}(ii);Di.prototype.size=4;var Ri=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getoffsetX=function(t){return this.float32[1*t+0]},e.prototype.get=function(t){return new Di(this,t)},e}(_i);kn(\"GlyphOffsetArray\",Ri);var Fi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={x:{configurable:!0},y:{configurable:!0},tileUnitDistanceFromAnchor:{configurable:!0}};return r.x.get=function(){return this._structArray.int16[this._pos2+0]},r.x.set=function(t){this._structArray.int16[this._pos2+0]=t},r.y.get=function(){return this._structArray.int16[this._pos2+1]},r.y.set=function(t){this._structArray.int16[this._pos2+1]=t},r.tileUnitDistanceFromAnchor.get=function(){return this._structArray.int16[this._pos2+2]},r.tileUnitDistanceFromAnchor.set=function(t){this._structArray.int16[this._pos2+2]=t},Object.defineProperties(e.prototype,r),e}(ii);Fi.prototype.size=6;var Bi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getx=function(t){return this.int16[3*t+0]},e.prototype.gety=function(t){return this.int16[3*t+1]},e.prototype.gettileUnitDistanceFromAnchor=function(t){return this.int16[3*t+2]},e.prototype.get=function(t){return new Fi(this,t)},e}(wi);kn(\"SymbolLineVertexArray\",Bi);var Ni=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0}};return r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+0]},r.featureIndex.set=function(t){this._structArray.uint32[this._pos4+0]=t},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.sourceLayerIndex.set=function(t){this._structArray.uint16[this._pos2+2]=t},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+3]},r.bucketIndex.set=function(t){this._structArray.uint16[this._pos2+3]=t},Object.defineProperties(e.prototype,r),e}(ii);Ni.prototype.size=8;var ji=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new Ni(this,t)},e}(ki);kn(\"FeatureIndexArray\",ji);var Ui=oi([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,Vi=function(t){void 0===t&&(t=[]),this.segments=t};function qi(t,e){return 256*(t=c(Math.floor(t),0,255))+c(Math.floor(e),0,255)}Vi.prototype.prepareSegment=function(t,e,r,n){var i=this.segments[this.segments.length-1];return t>Vi.MAX_VERTEX_ARRAY_LENGTH&&w(\"Max vertices per segment is \"+Vi.MAX_VERTEX_ARRAY_LENGTH+\": bucket requested \"+t),(!i||i.vertexLength+t>Vi.MAX_VERTEX_ARRAY_LENGTH||i.sortKey!==n)&&(i={vertexOffset:e.length,primitiveOffset:r.length,vertexLength:0,primitiveLength:0},void 0!==n&&(i.sortKey=n),this.segments.push(i)),i},Vi.prototype.get=function(){return this.segments},Vi.prototype.destroy=function(){for(var t=0,e=this.segments;t<e.length;t+=1){var r=e[t];for(var n in r.vaos)r.vaos[n].destroy()}},Vi.simpleSegment=function(t,e,r,n){return new Vi([{vertexOffset:t,primitiveOffset:e,vertexLength:r,primitiveLength:n,vaos:{},sortKey:0}])},Vi.MAX_VERTEX_ARRAY_LENGTH=Math.pow(2,16)-1,kn(\"SegmentVector\",Vi);var Hi=function(){this.ids=[],this.positions=[],this.indexed=!1};function Gi(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}Hi.prototype.add=function(t,e,r,n){this.ids.push(t),this.positions.push(e,r,n)},Hi.prototype.getPositions=function(t){for(var e=0,r=this.ids.length-1;e<r;){var n=e+r>>1;this.ids[n]>=t?r=n:e=n+1}for(var i=[];this.ids[e]===t;){var a=this.positions[3*e],o=this.positions[3*e+1],s=this.positions[3*e+2];i.push({index:a,start:o,end:s}),e++}return i},Hi.serialize=function(t,e){var r=new Float64Array(t.ids),n=new Uint32Array(t.positions);return function t(e,r,n,i){if(!(n>=i)){for(var a=e[n+i>>1],o=n-1,s=i+1;;){do{o++}while(e[o]<a);do{s--}while(e[s]>a);if(o>=s)break;Gi(e,o,s),Gi(r,3*o,3*s),Gi(r,3*o+1,3*s+1),Gi(r,3*o+2,3*s+2)}t(e,r,n,s),t(e,r,s+1,i)}}(r,n,0,r.length-1),e.push(r.buffer,n.buffer),{ids:r,positions:n}},Hi.deserialize=function(t){var e=new Hi;return e.ids=t.ids,e.positions=t.positions,e.indexed=!0,e},kn(\"FeaturePositionMap\",Hi);var Yi=function(t,e){this.gl=t.gl,this.location=e},Wi=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1i(this.location,t))},e}(Yi),Xi=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1f(this.location,t))},e}(Yi),Zi=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]||(this.current=t,this.gl.uniform2f(this.location,t[0],t[1]))},e}(Yi),Ji=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]||(this.current=t,this.gl.uniform3f(this.location,t[0],t[1],t[2]))},e}(Yi),Ki=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]&&t[3]===this.current[3]||(this.current=t,this.gl.uniform4f(this.location,t[0],t[1],t[2],t[3]))},e}(Yi),$i=function(t){function e(e,r){t.call(this,e,r),this.current=ne.transparent}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t.r===this.current.r&&t.g===this.current.g&&t.b===this.current.b&&t.a===this.current.a||(this.current=t,this.gl.uniform4f(this.location,t.r,t.g,t.b,t.a))},e}(Yi),Qi=new Float32Array(16),ta=function(t){function e(e,r){t.call(this,e,r),this.current=Qi}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(t[12]!==this.current[12]||t[0]!==this.current[0])return this.current=t,void this.gl.uniformMatrix4fv(this.location,!1,t);for(var e=1;e<16;e++)if(t[e]!==this.current[e]){this.current=t,this.gl.uniformMatrix4fv(this.location,!1,t);break}},e}(Yi);function ea(t){return[qi(255*t.r,255*t.g),qi(255*t.b,255*t.a)]}var ra=function(t,e,r){this.value=t,this.names=e,this.uniformNames=this.names.map(function(t){return\"u_\"+t}),this.type=r,this.maxValue=-1/0};ra.prototype.defines=function(){return this.names.map(function(t){return\"#define HAS_UNIFORM_u_\"+t})},ra.prototype.setConstantPatternPositions=function(){},ra.prototype.populatePaintArray=function(){},ra.prototype.updatePaintArray=function(){},ra.prototype.upload=function(){},ra.prototype.destroy=function(){},ra.prototype.setUniforms=function(t,e,r,n){e.set(n.constantOr(this.value))},ra.prototype.getBinding=function(t,e){return\"color\"===this.type?new $i(t,e):new Xi(t,e)},ra.serialize=function(t){var e=t.value,r=t.names,n=t.type;return{value:An(e),names:r,type:n}},ra.deserialize=function(t){var e=t.value,r=t.names,n=t.type;return new ra(Mn(e),r,n)};var na=function(t,e,r){this.value=t,this.names=e,this.uniformNames=this.names.map(function(t){return\"u_\"+t}),this.type=r,this.maxValue=-1/0,this.patternPositions={patternTo:null,patternFrom:null}};na.prototype.defines=function(){return this.names.map(function(t){return\"#define HAS_UNIFORM_u_\"+t})},na.prototype.populatePaintArray=function(){},na.prototype.updatePaintArray=function(){},na.prototype.upload=function(){},na.prototype.destroy=function(){},na.prototype.setConstantPatternPositions=function(t,e){this.patternPositions.patternTo=t.tlbr,this.patternPositions.patternFrom=e.tlbr},na.prototype.setUniforms=function(t,e,r,n,i){var a=this.patternPositions;\"u_pattern_to\"===i&&a.patternTo&&e.set(a.patternTo),\"u_pattern_from\"===i&&a.patternFrom&&e.set(a.patternFrom)},na.prototype.getBinding=function(t,e){return new Ki(t,e)};var ia=function(t,e,r,n){this.expression=t,this.names=e,this.type=r,this.uniformNames=this.names.map(function(t){return\"a_\"+t}),this.maxValue=-1/0,this.paintVertexAttributes=e.map(function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?2:1,offset:0}}),this.paintVertexArray=new n};ia.prototype.defines=function(){return[]},ia.prototype.setConstantPatternPositions=function(){},ia.prototype.populatePaintArray=function(t,e){var r=this.paintVertexArray,n=r.length;r.reserve(t);var i=this.expression.evaluate(new Un(0),e,{});if(\"color\"===this.type)for(var a=ea(i),o=n;o<t;o++)r.emplaceBack(a[0],a[1]);else{for(var s=n;s<t;s++)r.emplaceBack(i);this.maxValue=Math.max(this.maxValue,i)}},ia.prototype.updatePaintArray=function(t,e,r,n){var i=this.paintVertexArray,a=this.expression.evaluate({zoom:0},r,n);if(\"color\"===this.type)for(var o=ea(a),s=t;s<e;s++)i.emplace(s,o[0],o[1]);else{for(var l=t;l<e;l++)i.emplace(l,a);this.maxValue=Math.max(this.maxValue,a)}},ia.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},ia.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},ia.prototype.setUniforms=function(t,e){e.set(0)},ia.prototype.getBinding=function(t,e){return new Xi(t,e)};var aa=function(t,e,r,n,i,a){this.expression=t,this.names=e,this.uniformNames=this.names.map(function(t){return\"u_\"+t+\"_t\"}),this.type=r,this.useIntegerZoom=n,this.zoom=i,this.maxValue=-1/0;var o=a;this.paintVertexAttributes=e.map(function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?4:2,offset:0}}),this.paintVertexArray=new o};aa.prototype.defines=function(){return[]},aa.prototype.setConstantPatternPositions=function(){},aa.prototype.populatePaintArray=function(t,e){var r=this.paintVertexArray,n=r.length;r.reserve(t);var i=this.expression.evaluate(new Un(this.zoom),e,{}),a=this.expression.evaluate(new Un(this.zoom+1),e,{});if(\"color\"===this.type)for(var o=ea(i),s=ea(a),l=n;l<t;l++)r.emplaceBack(o[0],o[1],s[0],s[1]);else{for(var c=n;c<t;c++)r.emplaceBack(i,a);this.maxValue=Math.max(this.maxValue,i,a)}},aa.prototype.updatePaintArray=function(t,e,r,n){var i=this.paintVertexArray,a=this.expression.evaluate({zoom:this.zoom},r,n),o=this.expression.evaluate({zoom:this.zoom+1},r,n);if(\"color\"===this.type)for(var s=ea(a),l=ea(o),c=t;c<e;c++)i.emplace(c,s[0],s[1],l[0],l[1]);else{for(var u=t;u<e;u++)i.emplace(u,a,o);this.maxValue=Math.max(this.maxValue,a,o)}},aa.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},aa.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},aa.prototype.interpolationFactor=function(t){return this.useIntegerZoom?this.expression.interpolationFactor(Math.floor(t),this.zoom,this.zoom+1):this.expression.interpolationFactor(t,this.zoom,this.zoom+1)},aa.prototype.setUniforms=function(t,e,r){e.set(this.interpolationFactor(r.zoom))},aa.prototype.getBinding=function(t,e){return new Xi(t,e)};var oa=function(t,e,r,n,i,a,o){this.expression=t,this.names=e,this.type=r,this.uniformNames=this.names.map(function(t){return\"u_\"+t+\"_t\"}),this.useIntegerZoom=n,this.zoom=i,this.maxValue=-1/0,this.layerId=o,this.paintVertexAttributes=e.map(function(t){return{name:\"a_\"+t,type:\"Uint16\",components:4,offset:0}}),this.zoomInPaintVertexArray=new a,this.zoomOutPaintVertexArray=new a};oa.prototype.defines=function(){return[]},oa.prototype.setConstantPatternPositions=function(){},oa.prototype.populatePaintArray=function(t,e,r){var n=this.zoomInPaintVertexArray,i=this.zoomOutPaintVertexArray,a=this.layerId,o=n.length;if(n.reserve(t),i.reserve(t),r&&e.patterns&&e.patterns[a]){var s=e.patterns[a],l=s.min,c=s.mid,u=s.max,h=r[l],f=r[c],p=r[u];if(!h||!f||!p)return;for(var d=o;d<t;d++)n.emplaceBack(f.tl[0],f.tl[1],f.br[0],f.br[1],h.tl[0],h.tl[1],h.br[0],h.br[1]),i.emplaceBack(f.tl[0],f.tl[1],f.br[0],f.br[1],p.tl[0],p.tl[1],p.br[0],p.br[1])}},oa.prototype.updatePaintArray=function(t,e,r,n,i){var a=this.zoomInPaintVertexArray,o=this.zoomOutPaintVertexArray,s=this.layerId;if(i&&r.patterns&&r.patterns[s]){var l=r.patterns[s],c=l.min,u=l.mid,h=l.max,f=i[c],p=i[u],d=i[h];if(!f||!p||!d)return;for(var g=t;g<e;g++)a.emplace(g,p.tl[0],p.tl[1],p.br[0],p.br[1],f.tl[0],f.tl[1],f.br[0],f.br[1]),o.emplace(g,p.tl[0],p.tl[1],p.br[0],p.br[1],d.tl[0],d.tl[1],d.br[0],d.br[1])}},oa.prototype.upload=function(t){this.zoomInPaintVertexArray&&this.zoomInPaintVertexArray.arrayBuffer&&this.zoomOutPaintVertexArray&&this.zoomOutPaintVertexArray.arrayBuffer&&(this.zoomInPaintVertexBuffer=t.createVertexBuffer(this.zoomInPaintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent),this.zoomOutPaintVertexBuffer=t.createVertexBuffer(this.zoomOutPaintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},oa.prototype.destroy=function(){this.zoomOutPaintVertexBuffer&&this.zoomOutPaintVertexBuffer.destroy(),this.zoomInPaintVertexBuffer&&this.zoomInPaintVertexBuffer.destroy()},oa.prototype.setUniforms=function(t,e){e.set(0)},oa.prototype.getBinding=function(t,e){return new Xi(t,e)};var sa=function(){this.binders={},this.cacheKey=\"\",this._buffers=[],this._featureMap=new Hi,this._bufferOffset=0};sa.createDynamic=function(t,e,r){var n=new sa,i=[];for(var a in t.paint._values)if(r(a)){var o=t.paint.get(a);if(o instanceof Xn&&xr(o.property.specification)){var s=ca(a,t.type),l=o.property.specification.type,c=o.property.useIntegerZoom;if(\"cross-faded\"===o.property.specification[\"property-type\"]||\"cross-faded-data-driven\"===o.property.specification[\"property-type\"])if(\"constant\"===o.value.kind)n.binders[a]=new na(o.value.value,s,l),i.push(\"/u_\"+a);else{var u=ua(a,l,\"source\");n.binders[a]=new oa(o.value,s,l,c,e,u,t.id),i.push(\"/a_\"+a)}else if(\"constant\"===o.value.kind)n.binders[a]=new ra(o.value.value,s,l),i.push(\"/u_\"+a);else if(\"source\"===o.value.kind){var h=ua(a,l,\"source\");n.binders[a]=new ia(o.value,s,l,h),i.push(\"/a_\"+a)}else{var f=ua(a,l,\"composite\");n.binders[a]=new aa(o.value,s,l,c,e,f),i.push(\"/z_\"+a)}}}return n.cacheKey=i.sort().join(\"\"),n},sa.prototype.populatePaintArrays=function(t,e,r,n){for(var i in this.binders)this.binders[i].populatePaintArray(t,e,n);void 0!==e.id&&this._featureMap.add(+e.id,r,this._bufferOffset,t),this._bufferOffset=t},sa.prototype.setConstantPatternPositions=function(t,e){for(var r in this.binders)this.binders[r].setConstantPatternPositions(t,e)},sa.prototype.updatePaintArrays=function(t,e,r,n){var i=!1;for(var a in t)for(var o=0,s=this._featureMap.getPositions(+a);o<s.length;o+=1){var l=s[o],c=e.feature(l.index);for(var u in this.binders){var h=this.binders[u];if(!(h instanceof ra||h instanceof na)&&!0===h.expression.isStateDependent){var f=r.paint.get(u);h.expression=f.value,h.updatePaintArray(l.start,l.end,c,t[a],n),i=!0}}}return i},sa.prototype.defines=function(){var t=[];for(var e in this.binders)t.push.apply(t,this.binders[e].defines());return t},sa.prototype.getPaintVertexBuffers=function(){return this._buffers},sa.prototype.getUniforms=function(t,e){var r=[];for(var n in this.binders)for(var i=this.binders[n],a=0,o=i.uniformNames;a<o.length;a+=1){var s=o[a];if(e[s]){var l=i.getBinding(t,e[s]);r.push({name:s,property:n,binding:l})}}return r},sa.prototype.setUniforms=function(t,e,r,n){for(var i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.name,l=o.property,c=o.binding;this.binders[l].setUniforms(t,c,n,r.get(l),s)}},sa.prototype.updatePatternPaintBuffers=function(t){var e=[];for(var r in this.binders){var n=this.binders[r];if(n instanceof oa){var i=2===t.fromScale?n.zoomInPaintVertexBuffer:n.zoomOutPaintVertexBuffer;i&&e.push(i)}else(n instanceof ia||n instanceof aa)&&n.paintVertexBuffer&&e.push(n.paintVertexBuffer)}this._buffers=e},sa.prototype.upload=function(t){for(var e in this.binders)this.binders[e].upload(t);var r=[];for(var n in this.binders){var i=this.binders[n];(i instanceof ia||i instanceof aa)&&i.paintVertexBuffer&&r.push(i.paintVertexBuffer)}this._buffers=r},sa.prototype.destroy=function(){for(var t in this.binders)this.binders[t].destroy()};var la=function(t,e,r,n){void 0===n&&(n=function(){return!0}),this.programConfigurations={};for(var i=0,a=e;i<a.length;i+=1){var o=a[i];this.programConfigurations[o.id]=sa.createDynamic(o,r,n),this.programConfigurations[o.id].layoutAttributes=t}this.needsUpload=!1};function ca(t,e){return{\"text-opacity\":[\"opacity\"],\"icon-opacity\":[\"opacity\"],\"text-color\":[\"fill_color\"],\"icon-color\":[\"fill_color\"],\"text-halo-color\":[\"halo_color\"],\"icon-halo-color\":[\"halo_color\"],\"text-halo-blur\":[\"halo_blur\"],\"icon-halo-blur\":[\"halo_blur\"],\"text-halo-width\":[\"halo_width\"],\"icon-halo-width\":[\"halo_width\"],\"line-gap-width\":[\"gapwidth\"],\"line-pattern\":[\"pattern_to\",\"pattern_from\"],\"fill-pattern\":[\"pattern_to\",\"pattern_from\"],\"fill-extrusion-pattern\":[\"pattern_to\",\"pattern_from\"]}[t]||[t.replace(e+\"-\",\"\").replace(/-/g,\"_\")]}function ua(t,e,r){var n={color:{source:Si,composite:Ei},number:{source:_i,composite:Si}},i=function(t){return{\"line-pattern\":{source:fi,composite:fi},\"fill-pattern\":{source:fi,composite:fi},\"fill-extrusion-pattern\":{source:fi,composite:fi}}[t]}(t);return i&&i[r]||n[e][r]}la.prototype.populatePaintArrays=function(t,e,r,n){for(var i in this.programConfigurations)this.programConfigurations[i].populatePaintArrays(t,e,r,n);this.needsUpload=!0},la.prototype.updatePaintArrays=function(t,e,r,n){for(var i=0,a=r;i<a.length;i+=1){var o=a[i];this.needsUpload=this.programConfigurations[o.id].updatePaintArrays(t,e,o,n)||this.needsUpload}},la.prototype.get=function(t){return this.programConfigurations[t]},la.prototype.upload=function(t){if(this.needsUpload){for(var e in this.programConfigurations)this.programConfigurations[e].upload(t);this.needsUpload=!1}},la.prototype.destroy=function(){for(var t in this.programConfigurations)this.programConfigurations[t].destroy()},kn(\"ConstantBinder\",ra),kn(\"CrossFadedConstantBinder\",na),kn(\"SourceExpressionBinder\",ia),kn(\"CrossFadedCompositeBinder\",oa),kn(\"CompositeExpressionBinder\",aa),kn(\"ProgramConfiguration\",sa,{omit:[\"_buffers\"]}),kn(\"ProgramConfigurationSet\",la);var ha=8192,fa=(16,{min:-1*Math.pow(2,15),max:Math.pow(2,15)-1});function pa(t){for(var e=ha/t.extent,r=t.loadGeometry(),n=0;n<r.length;n++)for(var i=r[n],a=0;a<i.length;a++){var o=i[a];o.x=Math.round(o.x*e),o.y=Math.round(o.y*e),(o.x<fa.min||o.x>fa.max||o.y<fa.min||o.y>fa.max)&&w(\"Geometry exceeds allowed extent, reduce your vector tile buffer size\")}return r}function da(t,e,r,n,i){t.emplaceBack(2*e+(n+1)/2,2*r+(i+1)/2)}var ga=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new li,this.indexArray=new Ti,this.segments=new Vi,this.programConfigurations=new la(Ui,t.layers,t.zoom),this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function va(t,e){for(var r=0;r<t.length;r++)if(Aa(e,t[r]))return!0;for(var n=0;n<e.length;n++)if(Aa(t,e[n]))return!0;return!!ba(t,e)}function ma(t,e,r){return!!Aa(t,e)||!!wa(e,t,r)}function ya(t,e){if(1===t.length)return Ta(e,t[0]);for(var r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++)if(Aa(t,n[i]))return!0;for(var a=0;a<t.length;a++)if(Ta(e,t[a]))return!0;for(var o=0;o<e.length;o++)if(ba(t,e[o]))return!0;return!1}function xa(t,e,r){if(t.length>1){if(ba(t,e))return!0;for(var n=0;n<e.length;n++)if(wa(e[n],t,r))return!0}for(var i=0;i<t.length;i++)if(wa(t[i],e,r))return!0;return!1}function ba(t,e){if(0===t.length||0===e.length)return!1;for(var r=0;r<t.length-1;r++)for(var n=t[r],i=t[r+1],a=0;a<e.length-1;a++)if(_a(n,i,e[a],e[a+1]))return!0;return!1}function _a(t,e,r,n){return k(t,r,n)!==k(e,r,n)&&k(t,e,r)!==k(t,e,n)}function wa(t,e,r){var n=r*r;if(1===e.length)return t.distSqr(e[0])<n;for(var i=1;i<e.length;i++)if(ka(t,e[i-1],e[i])<n)return!0;return!1}function ka(t,e,r){var n=e.distSqr(r);if(0===n)return t.distSqr(e);var i=((t.x-e.x)*(r.x-e.x)+(t.y-e.y)*(r.y-e.y))/n;return i<0?t.distSqr(e):i>1?t.distSqr(r):t.distSqr(r.sub(e)._mult(i)._add(e))}function Ta(t,e){for(var r,n,i,a=!1,o=0;o<t.length;o++)for(var s=0,l=(r=t[o]).length-1;s<r.length;l=s++)n=r[s],i=r[l],n.y>e.y!=i.y>e.y&&e.x<(i.x-n.x)*(e.y-n.y)/(i.y-n.y)+n.x&&(a=!a);return a}function Aa(t,e){for(var r=!1,n=0,i=t.length-1;n<t.length;i=n++){var a=t[n],o=t[i];a.y>e.y!=o.y>e.y&&e.x<(o.x-a.x)*(e.y-a.y)/(o.y-a.y)+a.x&&(r=!r)}return r}function Ma(t,e,r){var n=r[0],i=r[2];if(t.x<n.x&&e.x<n.x||t.x>i.x&&e.x>i.x||t.y<n.y&&e.y<n.y||t.y>i.y&&e.y>i.y)return!1;var a=k(t,e,r[0]);return a!==k(t,e,r[1])||a!==k(t,e,r[2])||a!==k(t,e,r[3])}function Sa(t,e,r){var n=e.paint.get(t).value;return\"constant\"===n.kind?n.value:r.programConfigurations.get(e.id).binders[t].maxValue}function Ea(t){return Math.sqrt(t[0]*t[0]+t[1]*t[1])}function Ca(t,e,r,n,a){if(!e[0]&&!e[1])return t;var o=i.convert(e)._mult(a);\"viewport\"===r&&o._rotate(-n);for(var s=[],l=0;l<t.length;l++){var c=t[l];s.push(c.sub(o))}return s}ga.prototype.populate=function(t,e){for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a);this.addFeature(a,l,o),e.featureIndex.insert(a,l,o,s,this.index)}}},ga.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},ga.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},ga.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},ga.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ui),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},ga.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},ga.prototype.addFeature=function(t,e,r){for(var n=0,i=e;n<i.length;n+=1)for(var a=0,o=i[n];a<o.length;a+=1){var s=o[a],l=s.x,c=s.y;if(!(l<0||l>=ha||c<0||c>=ha)){var u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),h=u.vertexLength;da(this.layoutVertexArray,l,c,-1,-1),da(this.layoutVertexArray,l,c,1,-1),da(this.layoutVertexArray,l,c,1,1),da(this.layoutVertexArray,l,c,-1,1),this.indexArray.emplaceBack(h,h+1,h+2),this.indexArray.emplaceBack(h,h+3,h+2),u.vertexLength+=4,u.primitiveLength+=2}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,{})},kn(\"CircleBucket\",ga,{omit:[\"layers\"]});var La={paint:new ei({\"circle-radius\":new Kn(It.paint_circle[\"circle-radius\"]),\"circle-color\":new Kn(It.paint_circle[\"circle-color\"]),\"circle-blur\":new Kn(It.paint_circle[\"circle-blur\"]),\"circle-opacity\":new Kn(It.paint_circle[\"circle-opacity\"]),\"circle-translate\":new Jn(It.paint_circle[\"circle-translate\"]),\"circle-translate-anchor\":new Jn(It.paint_circle[\"circle-translate-anchor\"]),\"circle-pitch-scale\":new Jn(It.paint_circle[\"circle-pitch-scale\"]),\"circle-pitch-alignment\":new Jn(It.paint_circle[\"circle-pitch-alignment\"]),\"circle-stroke-width\":new Kn(It.paint_circle[\"circle-stroke-width\"]),\"circle-stroke-color\":new Kn(It.paint_circle[\"circle-stroke-color\"]),\"circle-stroke-opacity\":new Kn(It.paint_circle[\"circle-stroke-opacity\"])})},Pa=\"undefined\"!=typeof Float32Array?Float32Array:Array;function Oa(){var t=new Pa(9);return Pa!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[5]=0,t[6]=0,t[7]=0),t[0]=1,t[4]=1,t[8]=1,t}function za(){var t=new Pa(3);return Pa!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0),t}function Ia(t,e,r){var n=new Pa(3);return n[0]=t,n[1]=e,n[2]=r,n}Math.PI;function Da(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}function Ra(){var t=new Pa(4);return Pa!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0),t[3]=1,t}za(),function(){var t;t=new Pa(4),Pa!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0,t[3]=0)}();za(),Ia(1,0,0),Ia(0,1,0),Ra(),Ra(),Oa(),function(){var t;t=new Pa(2),Pa!=Float32Array&&(t[0]=0,t[1]=0)}();var Fa=function(t){function e(e){t.call(this,e,La)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new ga(t)},e.prototype.queryRadius=function(t){var e=t;return Sa(\"circle-radius\",this,e)+Sa(\"circle-stroke-width\",this,e)+Ea(this.paint.get(\"circle-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o,s){for(var l=Ca(t,this.paint.get(\"circle-translate\"),this.paint.get(\"circle-translate-anchor\"),a.angle,o),c=this.paint.get(\"circle-radius\").evaluate(e,r)+this.paint.get(\"circle-stroke-width\").evaluate(e,r),u=\"map\"===this.paint.get(\"circle-pitch-alignment\"),h=u?l:function(t,e){return l.map(function(t){return Ba(t,e)})}(0,s),f=u?c*o:c,p=0,d=n;p<d.length;p+=1)for(var g=0,v=d[p];g<v.length;g+=1){var m=v[g],y=u?m:Ba(m,s),x=f,b=Da([],[m.x,m.y,0,1],s);if(\"viewport\"===this.paint.get(\"circle-pitch-scale\")&&\"map\"===this.paint.get(\"circle-pitch-alignment\")?x*=b[3]/a.cameraToCenterDistance:\"map\"===this.paint.get(\"circle-pitch-scale\")&&\"viewport\"===this.paint.get(\"circle-pitch-alignment\")&&(x*=a.cameraToCenterDistance/b[3]),ma(h,y,x))return!0}return!1},e}(ri);function Ba(t,e){var r=Da([],[t.x,t.y,0,1],e);return new i(r[0]/r[3],r[1]/r[3])}var Na=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ga);function ja(t,e,r,n){var i=e.width,a=e.height;if(n){if(n instanceof Uint8ClampedArray)n=new Uint8Array(n.buffer);else if(n.length!==i*a*r)throw new RangeError(\"mismatched image size\")}else n=new Uint8Array(i*a*r);return t.width=i,t.height=a,t.data=n,t}function Ua(t,e,r){var n=e.width,i=e.height;if(n!==t.width||i!==t.height){var a=ja({},{width:n,height:i},r);Va(t,a,{x:0,y:0},{x:0,y:0},{width:Math.min(t.width,n),height:Math.min(t.height,i)},r),t.width=n,t.height=i,t.data=a.data}}function Va(t,e,r,n,i,a){if(0===i.width||0===i.height)return e;if(i.width>t.width||i.height>t.height||r.x>t.width-i.width||r.y>t.height-i.height)throw new RangeError(\"out of range source coordinates for image copy\");if(i.width>e.width||i.height>e.height||n.x>e.width-i.width||n.y>e.height-i.height)throw new RangeError(\"out of range destination coordinates for image copy\");for(var o=t.data,s=e.data,l=0;l<i.height;l++)for(var c=((r.y+l)*t.width+r.x)*a,u=((n.y+l)*e.width+n.x)*a,h=0;h<i.width*a;h++)s[u+h]=o[c+h];return e}kn(\"HeatmapBucket\",Na,{omit:[\"layers\"]});var qa=function(t,e){ja(this,t,1,e)};qa.prototype.resize=function(t){Ua(this,t,1)},qa.prototype.clone=function(){return new qa({width:this.width,height:this.height},new Uint8Array(this.data))},qa.copy=function(t,e,r,n,i){Va(t,e,r,n,i,1)};var Ha=function(t,e){ja(this,t,4,e)};Ha.prototype.resize=function(t){Ua(this,t,4)},Ha.prototype.replace=function(t,e){e?this.data.set(t):t instanceof Uint8ClampedArray?this.data=new Uint8Array(t.buffer):this.data=t},Ha.prototype.clone=function(){return new Ha({width:this.width,height:this.height},new Uint8Array(this.data))},Ha.copy=function(t,e,r,n,i){Va(t,e,r,n,i,4)},kn(\"AlphaImage\",qa),kn(\"RGBAImage\",Ha);var Ga={paint:new ei({\"heatmap-radius\":new Kn(It.paint_heatmap[\"heatmap-radius\"]),\"heatmap-weight\":new Kn(It.paint_heatmap[\"heatmap-weight\"]),\"heatmap-intensity\":new Jn(It.paint_heatmap[\"heatmap-intensity\"]),\"heatmap-color\":new ti(It.paint_heatmap[\"heatmap-color\"]),\"heatmap-opacity\":new Jn(It.paint_heatmap[\"heatmap-opacity\"])})};function Ya(t,e){for(var r=new Uint8Array(1024),n={},i=0,a=0;i<256;i++,a+=4){n[e]=i/255;var o=t.evaluate(n);r[a+0]=Math.floor(255*o.r/o.a),r[a+1]=Math.floor(255*o.g/o.a),r[a+2]=Math.floor(255*o.b/o.a),r[a+3]=Math.floor(255*o.a)}return new Ha({width:256,height:1},r)}var Wa=function(t){function e(e){t.call(this,e,Ga),this._updateColorRamp()}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new Na(t)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"heatmap-color\"===t&&this._updateColorRamp()},e.prototype._updateColorRamp=function(){var t=this._transitionablePaint._values[\"heatmap-color\"].value.expression;this.colorRamp=Ya(t,\"heatmapDensity\"),this.colorRampTexture=null},e.prototype.resize=function(){this.heatmapFbo&&(this.heatmapFbo.destroy(),this.heatmapFbo=null)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"heatmap-opacity\")&&\"none\"!==this.visibility},e}(ri),Xa={paint:new ei({\"hillshade-illumination-direction\":new Jn(It.paint_hillshade[\"hillshade-illumination-direction\"]),\"hillshade-illumination-anchor\":new Jn(It.paint_hillshade[\"hillshade-illumination-anchor\"]),\"hillshade-exaggeration\":new Jn(It.paint_hillshade[\"hillshade-exaggeration\"]),\"hillshade-shadow-color\":new Jn(It.paint_hillshade[\"hillshade-shadow-color\"]),\"hillshade-highlight-color\":new Jn(It.paint_hillshade[\"hillshade-highlight-color\"]),\"hillshade-accent-color\":new Jn(It.paint_hillshade[\"hillshade-accent-color\"])})},Za=function(t){function e(e){t.call(this,e,Xa)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"hillshade-exaggeration\")&&\"none\"!==this.visibility},e}(ri),Ja=oi([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,Ka=Qa,$a=Qa;function Qa(t,e,r){r=r||2;var n,i,a,o,s,l,c,u=e&&e.length,h=u?e[0]*r:t.length,f=to(t,0,h,r,!0),p=[];if(!f||f.next===f.prev)return p;if(u&&(f=function(t,e,r,n){var i,a,o,s=[];for(i=0,a=e.length;i<a;i++)(o=to(t,e[i]*n,i<a-1?e[i+1]*n:t.length,n,!1))===o.next&&(o.steiner=!0),s.push(uo(o));for(s.sort(so),i=0;i<s.length;i++)lo(s[i],r),r=eo(r,r.next);return r}(t,e,f,r)),t.length>80*r){n=a=t[0],i=o=t[1];for(var d=r;d<h;d+=r)(s=t[d])<n&&(n=s),(l=t[d+1])<i&&(i=l),s>a&&(a=s),l>o&&(o=l);c=0!==(c=Math.max(a-n,o-i))?1/c:0}return ro(f,p,r,n,i,c),p}function to(t,e,r,n,i){var a,o;if(i===wo(t,e,r,n)>0)for(a=e;a<r;a+=n)o=xo(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=xo(a,t[a],t[a+1],o);return o&&go(o,o.next)&&(bo(o),o=o.next),o}function eo(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!go(n,n.next)&&0!==po(n.prev,n,n.next))n=n.next;else{if(bo(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function ro(t,e,r,n,i,a,o){if(t){!o&&a&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=co(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,a);for(var s,l,c=t;t.prev!==t.next;)if(s=t.prev,l=t.next,a?io(t,n,i,a):no(t))e.push(s.i/r),e.push(t.i/r),e.push(l.i/r),bo(t),t=l.next,c=l.next;else if((t=l)===c){o?1===o?ro(t=ao(t,e,r),e,r,n,i,a,2):2===o&&oo(t,e,r,n,i,a):ro(eo(t),e,r,n,i,a,1);break}}}function no(t){var e=t.prev,r=t,n=t.next;if(po(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(ho(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&po(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function io(t,e,r,n){var i=t.prev,a=t,o=t.next;if(po(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,h=co(s,l,e,r,n),f=co(c,u,e,r,n),p=t.prevZ,d=t.nextZ;p&&p.z>=h&&d&&d.z<=f;){if(p!==t.prev&&p!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&po(p.prev,p,p.next)>=0)return!1;if(p=p.prevZ,d!==t.prev&&d!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&po(d.prev,d,d.next)>=0)return!1;d=d.nextZ}for(;p&&p.z>=h;){if(p!==t.prev&&p!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&po(p.prev,p,p.next)>=0)return!1;p=p.prevZ}for(;d&&d.z<=f;){if(d!==t.prev&&d!==t.next&&ho(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&po(d.prev,d,d.next)>=0)return!1;d=d.nextZ}return!0}function ao(t,e,r){var n=t;do{var i=n.prev,a=n.next.next;!go(i,a)&&vo(i,n,n.next,a)&&mo(i,a)&&mo(a,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(a.i/r),bo(n),bo(n.next),n=t=a),n=n.next}while(n!==t);return n}function oo(t,e,r,n,i,a){var o=t;do{for(var s=o.next.next;s!==o.prev;){if(o.i!==s.i&&fo(o,s)){var l=yo(o,s);return o=eo(o,o.next),l=eo(l,l.next),ro(o,e,r,n,i,a),void ro(l,e,r,n,i,a)}s=s.next}o=o.next}while(o!==t)}function so(t,e){return t.x-e.x}function lo(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r.prev;var l,c=r,u=r.x,h=r.y,f=1/0;for(n=r.next;n!==c;)i>=n.x&&n.x>=u&&i!==n.x&&ho(a<h?i:o,a,u,h,a<h?o:i,a,n.x,n.y)&&((l=Math.abs(a-n.y)/(i-n.x))<f||l===f&&n.x>r.x)&&mo(n,t)&&(r=n,f=l),n=n.next;return r}(t,e)){var r=yo(e,t);eo(r,r.next)}}function co(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function uo(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function ho(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function fo(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&vo(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&mo(t,e)&&mo(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)}function po(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function go(t,e){return t.x===e.x&&t.y===e.y}function vo(t,e,r,n){return!!(go(t,e)&&go(r,n)||go(t,n)&&go(r,e))||po(t,e,r)>0!=po(t,e,n)>0&&po(r,n,t)>0!=po(r,n,e)>0}function mo(t,e){return po(t.prev,t,t.next)<0?po(t,e,t.next)>=0&&po(t,t.prev,e)>=0:po(t,e,t.prev)<0||po(t,t.next,e)<0}function yo(t,e){var r=new _o(t.i,t.x,t.y),n=new _o(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function xo(t,e,r,n){var i=new _o(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function bo(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function _o(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function wo(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}function ko(t,e,r,n,i){!function t(e,r,n,i,a){for(;i>n;){if(i-n>600){var o=i-n+1,s=r-n+1,l=Math.log(o),c=.5*Math.exp(2*l/3),u=.5*Math.sqrt(l*c*(o-c)/o)*(s-o/2<0?-1:1);t(e,r,Math.max(n,Math.floor(r-s*c/o+u)),Math.min(i,Math.floor(r+(o-s)*c/o+u)),a)}var h=e[r],f=n,p=i;for(To(e,n,r),a(e[i],h)>0&&To(e,n,i);f<p;){for(To(e,f,p),f++,p--;a(e[f],h)<0;)f++;for(;a(e[p],h)>0;)p--}0===a(e[n],h)?To(e,n,p):To(e,++p,i),p<=r&&(n=p+1),r<=p&&(i=p-1)}}(t,e,r||0,n||t.length-1,i||Ao)}function To(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function Ao(t,e){return t<e?-1:t>e?1:0}function Mo(t,e){var r=t.length;if(r<=1)return[t];for(var n,i,a=[],o=0;o<r;o++){var s=T(t[o]);0!==s&&(t[o].area=Math.abs(s),void 0===i&&(i=s<0),i===s<0?(n&&a.push(n),n=[t[o]]):n.push(t[o]))}if(n&&a.push(n),e>1)for(var l=0;l<a.length;l++)a[l].length<=e||(ko(a[l],e,1,a[l].length-1,So),a[l]=a[l].slice(0,e));return a}function So(t,e){return e.area-t.area}function Eo(t,e,r){for(var n=r.patternDependencies,i=!1,a=0,o=e;a<o.length;a+=1){var s=o[a].paint.get(t+\"-pattern\");s.isConstant()||(i=!0);var l=s.constantOr(null);l&&(i=!0,n[l.to]=!0,n[l.from]=!0)}return i}function Co(t,e,r,n,i){for(var a=i.patternDependencies,o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.paint.get(t+\"-pattern\").value;if(\"constant\"!==c.kind){var u=c.evaluate({zoom:n-1},r,{}),h=c.evaluate({zoom:n},r,{}),f=c.evaluate({zoom:n+1},r,{});a[u]=!0,a[h]=!0,a[f]=!0,r.patterns[l.id]={min:u,mid:h,max:f}}}return r}Qa.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(wo(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(wo(t,c,u,r))}var h=0;for(s=0;s<n.length;s+=3){var f=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;h+=Math.abs((t[f]-t[d])*(t[p+1]-t[f+1])-(t[f]-t[p])*(t[d+1]-t[f+1]))}return 0===o&&0===h?0:Math.abs((h-o)/o)},Qa.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r},Ka.default=$a;var Lo=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new li,this.indexArray=new Ti,this.indexArray2=new Ai,this.programConfigurations=new la(Ja,t.layers,t.zoom),this.segments=new Vi,this.segments2=new Vi,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};Lo.prototype.populate=function(t,e){this.features=[],this.hasPattern=Eo(\"fill\",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a),c={sourceLayerIndex:s,index:o,geometry:l,properties:a.properties,type:a.type,patterns:{}};void 0!==a.id&&(c.id=a.id),this.hasPattern?this.features.push(Co(\"fill\",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(a,l,o,s,this.index)}}},Lo.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Lo.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var i=n[r],a=i.geometry;this.addFeature(i,a,i.index,e)}},Lo.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Lo.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Lo.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ja),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.indexBuffer2=t.createIndexBuffer(this.indexArray2)),this.programConfigurations.upload(t),this.uploaded=!0},Lo.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.indexBuffer2.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.segments2.destroy())},Lo.prototype.addFeature=function(t,e,r,n){for(var i=0,a=Mo(e,500);i<a.length;i+=1){for(var o=a[i],s=0,l=0,c=o;l<c.length;l+=1)s+=c[l].length;for(var u=this.segments.prepareSegment(s,this.layoutVertexArray,this.indexArray),h=u.vertexLength,f=[],p=[],d=0,g=o;d<g.length;d+=1){var v=g[d];if(0!==v.length){v!==o[0]&&p.push(f.length/2);var m=this.segments2.prepareSegment(v.length,this.layoutVertexArray,this.indexArray2),y=m.vertexLength;this.layoutVertexArray.emplaceBack(v[0].x,v[0].y),this.indexArray2.emplaceBack(y+v.length-1,y),f.push(v[0].x),f.push(v[0].y);for(var x=1;x<v.length;x++)this.layoutVertexArray.emplaceBack(v[x].x,v[x].y),this.indexArray2.emplaceBack(y+x-1,y+x),f.push(v[x].x),f.push(v[x].y);m.vertexLength+=v.length,m.primitiveLength+=v.length}}for(var b=Ka(f,p),_=0;_<b.length;_+=3)this.indexArray.emplaceBack(h+b[_],h+b[_+1],h+b[_+2]);u.vertexLength+=s,u.primitiveLength+=b.length/3}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,n)},kn(\"FillBucket\",Lo,{omit:[\"layers\",\"features\"]});var Po={paint:new ei({\"fill-antialias\":new Jn(It.paint_fill[\"fill-antialias\"]),\"fill-opacity\":new Kn(It.paint_fill[\"fill-opacity\"]),\"fill-color\":new Kn(It.paint_fill[\"fill-color\"]),\"fill-outline-color\":new Kn(It.paint_fill[\"fill-outline-color\"]),\"fill-translate\":new Jn(It.paint_fill[\"fill-translate\"]),\"fill-translate-anchor\":new Jn(It.paint_fill[\"fill-translate-anchor\"]),\"fill-pattern\":new $n(It.paint_fill[\"fill-pattern\"])})},Oo=function(t){function e(e){t.call(this,e,Po)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e);var r=this.paint._values[\"fill-outline-color\"];\"constant\"===r.value.kind&&void 0===r.value.value&&(this.paint._values[\"fill-outline-color\"]=this.paint._values[\"fill-color\"])},e.prototype.createBucket=function(t){return new Lo(t)},e.prototype.queryRadius=function(){return Ea(this.paint.get(\"fill-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o){return ya(Ca(t,this.paint.get(\"fill-translate\"),this.paint.get(\"fill-translate-anchor\"),a.angle,o),n)},e.prototype.isTileClipped=function(){return!0},e}(ri),zo=oi([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_normal_ed\",components:4,type:\"Int16\"}],4).members,Io=Do;function Do(t,e,r,n,i){this.properties={},this.extent=r,this.type=0,this._pbf=t,this._geometry=-1,this._keys=n,this._values=i,t.readFields(Ro,this,e)}function Ro(t,e,r){1==t?e.id=r.readVarint():2==t?function(t,e){for(var r=t.readVarint()+t.pos;t.pos<r;){var n=e._keys[t.readVarint()],i=e._values[t.readVarint()];e.properties[n]=i}}(r,e):3==t?e.type=r.readVarint():4==t&&(e._geometry=r.pos)}function Fo(t){for(var e,r,n=0,i=0,a=t.length,o=a-1;i<a;o=i++)e=t[i],n+=((r=t[o]).x-e.x)*(e.y+r.y);return n}Do.types=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],Do.prototype.loadGeometry=function(){var t=this._pbf;t.pos=this._geometry;for(var e,r=t.readVarint()+t.pos,n=1,a=0,o=0,s=0,l=[];t.pos<r;){if(a<=0){var c=t.readVarint();n=7&c,a=c>>3}if(a--,1===n||2===n)o+=t.readSVarint(),s+=t.readSVarint(),1===n&&(e&&l.push(e),e=[]),e.push(new i(o,s));else{if(7!==n)throw new Error(\"unknown command \"+n);e&&e.push(e[0].clone())}}return e&&l.push(e),l},Do.prototype.bbox=function(){var t=this._pbf;t.pos=this._geometry;for(var e=t.readVarint()+t.pos,r=1,n=0,i=0,a=0,o=1/0,s=-1/0,l=1/0,c=-1/0;t.pos<e;){if(n<=0){var u=t.readVarint();r=7&u,n=u>>3}if(n--,1===r||2===r)(i+=t.readSVarint())<o&&(o=i),i>s&&(s=i),(a+=t.readSVarint())<l&&(l=a),a>c&&(c=a);else if(7!==r)throw new Error(\"unknown command \"+r)}return[o,l,s,c]},Do.prototype.toGeoJSON=function(t,e,r){var n,i,a=this.extent*Math.pow(2,r),o=this.extent*t,s=this.extent*e,l=this.loadGeometry(),c=Do.types[this.type];function u(t){for(var e=0;e<t.length;e++){var r=t[e],n=180-360*(r.y+s)/a;t[e]=[360*(r.x+o)/a-180,360/Math.PI*Math.atan(Math.exp(n*Math.PI/180))-90]}}switch(this.type){case 1:var h=[];for(n=0;n<l.length;n++)h[n]=l[n][0];u(l=h);break;case 2:for(n=0;n<l.length;n++)u(l[n]);break;case 3:for(l=function(t){var e=t.length;if(e<=1)return[t];for(var r,n,i=[],a=0;a<e;a++){var o=Fo(t[a]);0!==o&&(void 0===n&&(n=o<0),n===o<0?(r&&i.push(r),r=[t[a]]):r.push(t[a]))}return r&&i.push(r),i}(l),n=0;n<l.length;n++)for(i=0;i<l[n].length;i++)u(l[n][i])}1===l.length?l=l[0]:c=\"Multi\"+c;var f={type:\"Feature\",geometry:{type:c,coordinates:l},properties:this.properties};return\"id\"in this&&(f.id=this.id),f};var Bo=No;function No(t,e){this.version=1,this.name=null,this.extent=4096,this.length=0,this._pbf=t,this._keys=[],this._values=[],this._features=[],t.readFields(jo,this,e),this.length=this._features.length}function jo(t,e,r){15===t?e.version=r.readVarint():1===t?e.name=r.readString():5===t?e.extent=r.readVarint():2===t?e._features.push(r.pos):3===t?e._keys.push(r.readString()):4===t&&e._values.push(function(t){for(var e=null,r=t.readVarint()+t.pos;t.pos<r;){var n=t.readVarint()>>3;e=1===n?t.readString():2===n?t.readFloat():3===n?t.readDouble():4===n?t.readVarint64():5===n?t.readVarint():6===n?t.readSVarint():7===n?t.readBoolean():null}return e}(r))}function Uo(t,e,r){if(3===t){var n=new Bo(r,r.readVarint()+r.pos);n.length&&(e[n.name]=n)}}No.prototype.feature=function(t){if(t<0||t>=this._features.length)throw new Error(\"feature index out of bounds\");this._pbf.pos=this._features[t];var e=this._pbf.readVarint()+this._pbf.pos;return new Io(this._pbf,e,this.extent,this._keys,this._values)};var Vo={VectorTile:function(t,e){this.layers=t.readFields(Uo,{},e)},VectorTileFeature:Io,VectorTileLayer:Bo},qo=Vo.VectorTileFeature.types,Ho=Math.pow(2,13);function Go(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,2*Math.floor(n*Ho)+o,i*Ho*2,a*Ho*2,Math.round(s))}var Yo=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new ui,this.indexArray=new Ti,this.programConfigurations=new la(zo,t.layers,t.zoom),this.segments=new Vi,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function Wo(t,e){return t.x===e.x&&(t.x<0||t.x>ha)||t.y===e.y&&(t.y<0||t.y>ha)}function Xo(t){return t.every(function(t){return t.x<0})||t.every(function(t){return t.x>ha})||t.every(function(t){return t.y<0})||t.every(function(t){return t.y>ha})}Yo.prototype.populate=function(t,e){this.features=[],this.hasPattern=Eo(\"fill-extrusion\",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a),c={sourceLayerIndex:s,index:o,geometry:l,properties:a.properties,type:a.type,patterns:{}};void 0!==a.id&&(c.id=a.id),this.hasPattern?this.features.push(Co(\"fill-extrusion\",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(a,l,o,s,this.index,!0)}}},Yo.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var i=n[r],a=i.geometry;this.addFeature(i,a,i.index,e)}},Yo.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Yo.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Yo.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Yo.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,zo),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Yo.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Yo.prototype.addFeature=function(t,e,r,n){for(var i=0,a=Mo(e,500);i<a.length;i+=1){for(var o=a[i],s=0,l=0,c=o;l<c.length;l+=1)s+=c[l].length;for(var u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),h=0,f=o;h<f.length;h+=1){var p=f[h];if(0!==p.length&&!Xo(p))for(var d=0,g=0;g<p.length;g++){var v=p[g];if(g>=1){var m=p[g-1];if(!Wo(v,m)){u.vertexLength+4>Vi.MAX_VERTEX_ARRAY_LENGTH&&(u=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray));var y=v.sub(m)._perp()._unit(),x=m.dist(v);d+x>32768&&(d=0),Go(this.layoutVertexArray,v.x,v.y,y.x,y.y,0,0,d),Go(this.layoutVertexArray,v.x,v.y,y.x,y.y,0,1,d),d+=x,Go(this.layoutVertexArray,m.x,m.y,y.x,y.y,0,0,d),Go(this.layoutVertexArray,m.x,m.y,y.x,y.y,0,1,d);var b=u.vertexLength;this.indexArray.emplaceBack(b,b+2,b+1),this.indexArray.emplaceBack(b+1,b+2,b+3),u.vertexLength+=4,u.primitiveLength+=2}}}}if(u.vertexLength+s>Vi.MAX_VERTEX_ARRAY_LENGTH&&(u=this.segments.prepareSegment(s,this.layoutVertexArray,this.indexArray)),\"Polygon\"===qo[t.type]){for(var _=[],w=[],k=u.vertexLength,T=0,A=o;T<A.length;T+=1){var M=A[T];if(0!==M.length){M!==o[0]&&w.push(_.length/2);for(var S=0;S<M.length;S++){var E=M[S];Go(this.layoutVertexArray,E.x,E.y,0,0,1,1,0),_.push(E.x),_.push(E.y)}}}for(var C=Ka(_,w),L=0;L<C.length;L+=3)this.indexArray.emplaceBack(k+C[L],k+C[L+2],k+C[L+1]);u.primitiveLength+=C.length/3,u.vertexLength+=s}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,n)},kn(\"FillExtrusionBucket\",Yo,{omit:[\"layers\",\"features\"]});var Zo={paint:new ei({\"fill-extrusion-opacity\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-opacity\"]),\"fill-extrusion-color\":new Kn(It[\"paint_fill-extrusion\"][\"fill-extrusion-color\"]),\"fill-extrusion-translate\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-translate\"]),\"fill-extrusion-translate-anchor\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-translate-anchor\"]),\"fill-extrusion-pattern\":new $n(It[\"paint_fill-extrusion\"][\"fill-extrusion-pattern\"]),\"fill-extrusion-height\":new Kn(It[\"paint_fill-extrusion\"][\"fill-extrusion-height\"]),\"fill-extrusion-base\":new Kn(It[\"paint_fill-extrusion\"][\"fill-extrusion-base\"]),\"fill-extrusion-vertical-gradient\":new Jn(It[\"paint_fill-extrusion\"][\"fill-extrusion-vertical-gradient\"])})},Jo=function(t){function e(e){t.call(this,e,Zo)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new Yo(t)},e.prototype.queryRadius=function(){return Ea(this.paint.get(\"fill-extrusion-translate\"))},e.prototype.is3D=function(){return!0},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s,l){var c=Ca(t,this.paint.get(\"fill-extrusion-translate\"),this.paint.get(\"fill-extrusion-translate-anchor\"),o.angle,s),u=this.paint.get(\"fill-extrusion-height\").evaluate(e,r),h=this.paint.get(\"fill-extrusion-base\").evaluate(e,r),f=function(t,e,r,n){for(var a=[],o=0,s=t;o<s.length;o+=1){var l=s[o],c=[l.x,l.y,0,1];Da(c,c,e),a.push(new i(c[0]/c[3],c[1]/c[3]))}return a}(c,l),p=function(t,e,r,n){for(var a=[],o=[],s=n[8]*e,l=n[9]*e,c=n[10]*e,u=n[11]*e,h=n[8]*r,f=n[9]*r,p=n[10]*r,d=n[11]*r,g=0,v=t;g<v.length;g+=1){for(var m=[],y=[],x=0,b=v[g];x<b.length;x+=1){var _=b[x],w=_.x,k=_.y,T=n[0]*w+n[4]*k+n[12],A=n[1]*w+n[5]*k+n[13],M=n[2]*w+n[6]*k+n[14],S=n[3]*w+n[7]*k+n[15],E=M+c,C=S+u,L=T+h,P=A+f,O=M+p,z=S+d,I=new i((T+s)/C,(A+l)/C);I.z=E/C,m.push(I);var D=new i(L/z,P/z);D.z=O/z,y.push(D)}a.push(m),o.push(y)}return[a,o]}(n,h,u,l);return function(t,e,r){var n=1/0;ya(r,e)&&(n=$o(r,e[0]));for(var i=0;i<e.length;i++)for(var a=e[i],o=t[i],s=0;s<a.length-1;s++){var l=a[s],c=a[s+1],u=o[s],h=[l,c,o[s+1],u,l];va(r,h)&&(n=Math.min(n,$o(r,h)))}return n!==1/0&&n}(p[0],p[1],f)},e}(ri);function Ko(t,e){return t.x*e.x+t.y*e.y}function $o(t,e){if(1===t.length){var r=e[0],n=e[1],i=e[3],a=t[0],o=n.sub(r),s=i.sub(r),l=a.sub(r),c=Ko(o,o),u=Ko(o,s),h=Ko(s,s),f=Ko(l,o),p=Ko(l,s),d=c*h-u*u,g=(h*f-u*p)/d,v=(c*p-u*f)/d,m=1-g-v;return r.z*m+n.z*g+i.z*v}for(var y=1/0,x=0,b=e;x<b.length;x+=1){var _=b[x];y=Math.min(y,_.z)}return y}var Qo=oi([{name:\"a_pos_normal\",components:2,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint8\"}],4).members,ts=Vo.VectorTileFeature.types,es=63,rs=Math.cos(Math.PI/180*37.5),ns=.5,is=Math.pow(2,14)/ns;function as(t,e,r,n,i,a,o){t.emplaceBack((e.x<<1)+(n?1:0),(e.y<<1)+(i?1:0),Math.round(es*r.x)+128,Math.round(es*r.y)+128,1+(0===a?0:a<0?-1:1)|(o*ns&63)<<2,o*ns>>6)}var os=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.features=[],this.hasPattern=!1,this.layoutVertexArray=new hi,this.indexArray=new Ti,this.programConfigurations=new la(Qo,t.layers,t.zoom),this.segments=new Vi,this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id})};function ss(t,e){return(t/e.tileTotal*(e.end-e.start)+e.start)*(is-1)}os.prototype.populate=function(t,e){this.features=[],this.hasPattern=Eo(\"line\",this.layers,e);for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.feature,o=i.index,s=i.sourceLayerIndex;if(this.layers[0]._featureFilter(new Un(this.zoom),a)){var l=pa(a),c={sourceLayerIndex:s,index:o,geometry:l,properties:a.properties,type:a.type,patterns:{}};void 0!==a.id&&(c.id=a.id),this.hasPattern?this.features.push(Co(\"line\",this.layers,c,this.zoom,e)):this.addFeature(c,l,o,{}),e.featureIndex.insert(a,l,o,s,this.index)}}},os.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},os.prototype.addFeatures=function(t,e){for(var r=0,n=this.features;r<n.length;r+=1){var i=n[r],a=i.geometry;this.addFeature(i,a,i.index,e)}},os.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},os.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},os.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Qo),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},os.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},os.prototype.addFeature=function(t,e,r,n){for(var i=this.layers[0].layout,a=i.get(\"line-join\").evaluate(t,{}),o=i.get(\"line-cap\"),s=i.get(\"line-miter-limit\"),l=i.get(\"line-round-limit\"),c=0,u=e;c<u.length;c+=1){var h=u[c];this.addLine(h,t,a,o,s,l,r,n)}},os.prototype.addLine=function(t,e,r,n,i,a,o,s){var l=null;e.properties&&e.properties.hasOwnProperty(\"mapbox_clip_start\")&&e.properties.hasOwnProperty(\"mapbox_clip_end\")&&(l={start:e.properties.mapbox_clip_start,end:e.properties.mapbox_clip_end,tileTotal:void 0});for(var c=\"Polygon\"===ts[e.type],u=t.length;u>=2&&t[u-1].equals(t[u-2]);)u--;for(var h=0;h<u-1&&t[h].equals(t[h+1]);)h++;if(!(u<(c?3:2))){l&&(l.tileTotal=function(t,e,r){for(var n,i,a=0,o=h;o<r-1;o++)n=t[o],i=t[o+1],a+=n.dist(i);return a}(t,0,u)),\"bevel\"===r&&(i=1.05);var f=ha/(512*this.overscaling)*15,p=t[h],d=this.segments.prepareSegment(10*u,this.layoutVertexArray,this.indexArray);this.distance=0;var g,v,m,y=n,x=c?\"butt\":n,b=!0,_=void 0,w=void 0,k=void 0,T=void 0;this.e1=this.e2=this.e3=-1,c&&(g=t[u-2],T=p.sub(g)._unit()._perp());for(var A=h;A<u;A++)if(!(w=c&&A===u-1?t[h+1]:t[A+1])||!t[A].equals(w)){T&&(k=T),g&&(_=g),g=t[A],T=w?w.sub(g)._unit()._perp():k;var M=(k=k||T).add(T);0===M.x&&0===M.y||M._unit();var S=M.x*T.x+M.y*T.y,E=0!==S?1/S:1/0,C=S<rs&&_&&w;if(C&&A>h){var L=g.dist(_);if(L>2*f){var P=g.sub(g.sub(_)._mult(f/L)._round());this.distance+=P.dist(_),this.addCurrentVertex(P,this.distance,k.mult(1),0,0,!1,d,l),_=P}}var O=_&&w,z=O?r:w?y:x;if(O&&\"round\"===z&&(E<a?z=\"miter\":E<=2&&(z=\"fakeround\")),\"miter\"===z&&E>i&&(z=\"bevel\"),\"bevel\"===z&&(E>2&&(z=\"flipbevel\"),E<i&&(z=\"miter\")),_&&(this.distance+=g.dist(_)),\"miter\"===z)M._mult(E),this.addCurrentVertex(g,this.distance,M,0,0,!1,d,l);else if(\"flipbevel\"===z){if(E>100)M=T.clone().mult(-1);else{var I=k.x*T.y-k.y*T.x>0?-1:1,D=E*k.add(T).mag()/k.sub(T).mag();M._perp()._mult(D*I)}this.addCurrentVertex(g,this.distance,M,0,0,!1,d,l),this.addCurrentVertex(g,this.distance,M.mult(-1),0,0,!1,d,l)}else if(\"bevel\"===z||\"fakeround\"===z){var R=k.x*T.y-k.y*T.x>0,F=-Math.sqrt(E*E-1);if(R?(m=0,v=F):(v=0,m=F),b||this.addCurrentVertex(g,this.distance,k,v,m,!1,d,l),\"fakeround\"===z){for(var B=Math.floor(8*(.5-(S-.5))),N=void 0,j=0;j<B;j++)N=T.mult((j+1)/(B+1))._add(k)._unit(),this.addPieSliceVertex(g,this.distance,N,R,d,l);this.addPieSliceVertex(g,this.distance,M,R,d,l);for(var U=B-1;U>=0;U--)N=k.mult((U+1)/(B+1))._add(T)._unit(),this.addPieSliceVertex(g,this.distance,N,R,d,l)}w&&this.addCurrentVertex(g,this.distance,T,-v,-m,!1,d,l)}else\"butt\"===z?(b||this.addCurrentVertex(g,this.distance,k,0,0,!1,d,l),w&&this.addCurrentVertex(g,this.distance,T,0,0,!1,d,l)):\"square\"===z?(b||(this.addCurrentVertex(g,this.distance,k,1,1,!1,d,l),this.e1=this.e2=-1),w&&this.addCurrentVertex(g,this.distance,T,-1,-1,!1,d,l)):\"round\"===z&&(b||(this.addCurrentVertex(g,this.distance,k,0,0,!1,d,l),this.addCurrentVertex(g,this.distance,k,1,1,!0,d,l),this.e1=this.e2=-1),w&&(this.addCurrentVertex(g,this.distance,T,-1,-1,!0,d,l),this.addCurrentVertex(g,this.distance,T,0,0,!1,d,l)));if(C&&A<u-1){var V=g.dist(w);if(V>2*f){var q=g.add(w.sub(g)._mult(f/V)._round());this.distance+=q.dist(g),this.addCurrentVertex(q,this.distance,T.mult(1),0,0,!1,d,l),g=q}}b=!1}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,e,o,s)}},os.prototype.addCurrentVertex=function(t,e,r,n,i,a,o,s){var l,c=this.layoutVertexArray,u=this.indexArray;s&&(e=ss(e,s)),l=r.clone(),n&&l._sub(r.perp()._mult(n)),as(c,t,l,a,!1,n,e),this.e3=o.vertexLength++,this.e1>=0&&this.e2>=0&&(u.emplaceBack(this.e1,this.e2,this.e3),o.primitiveLength++),this.e1=this.e2,this.e2=this.e3,l=r.mult(-1),i&&l._sub(r.perp()._mult(i)),as(c,t,l,a,!0,-i,e),this.e3=o.vertexLength++,this.e1>=0&&this.e2>=0&&(u.emplaceBack(this.e1,this.e2,this.e3),o.primitiveLength++),this.e1=this.e2,this.e2=this.e3,e>is/2&&!s&&(this.distance=0,this.addCurrentVertex(t,this.distance,r,n,i,a,o))},os.prototype.addPieSliceVertex=function(t,e,r,n,i,a){r=r.mult(n?-1:1);var o=this.layoutVertexArray,s=this.indexArray;a&&(e=ss(e,a)),as(o,t,r,!1,n,0,e),this.e3=i.vertexLength++,this.e1>=0&&this.e2>=0&&(s.emplaceBack(this.e1,this.e2,this.e3),i.primitiveLength++),n?this.e2=this.e3:this.e1=this.e3},kn(\"LineBucket\",os,{omit:[\"layers\",\"features\"]});var ls=new ei({\"line-cap\":new Jn(It.layout_line[\"line-cap\"]),\"line-join\":new Kn(It.layout_line[\"line-join\"]),\"line-miter-limit\":new Jn(It.layout_line[\"line-miter-limit\"]),\"line-round-limit\":new Jn(It.layout_line[\"line-round-limit\"])}),cs={paint:new ei({\"line-opacity\":new Kn(It.paint_line[\"line-opacity\"]),\"line-color\":new Kn(It.paint_line[\"line-color\"]),\"line-translate\":new Jn(It.paint_line[\"line-translate\"]),\"line-translate-anchor\":new Jn(It.paint_line[\"line-translate-anchor\"]),\"line-width\":new Kn(It.paint_line[\"line-width\"]),\"line-gap-width\":new Kn(It.paint_line[\"line-gap-width\"]),\"line-offset\":new Kn(It.paint_line[\"line-offset\"]),\"line-blur\":new Kn(It.paint_line[\"line-blur\"]),\"line-dasharray\":new Qn(It.paint_line[\"line-dasharray\"]),\"line-pattern\":new $n(It.paint_line[\"line-pattern\"]),\"line-gradient\":new ti(It.paint_line[\"line-gradient\"])}),layout:ls},us=new(function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(e,r){return r=new Un(Math.floor(r.zoom),{now:r.now,fadeDuration:r.fadeDuration,zoomHistory:r.zoomHistory,transition:r.transition}),t.prototype.possiblyEvaluate.call(this,e,r)},e.prototype.evaluate=function(e,r,n,i){return r=h({},r,{zoom:Math.floor(r.zoom)}),t.prototype.evaluate.call(this,e,r,n,i)},e}(Kn))(cs.paint.properties[\"line-width\"].specification);us.useIntegerZoom=!0;var hs=function(t){function e(e){t.call(this,e,cs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"line-gradient\"===t&&this._updateGradient()},e.prototype._updateGradient=function(){var t=this._transitionablePaint._values[\"line-gradient\"].value.expression;this.gradient=Ya(t,\"lineProgress\"),this.gradientTexture=null},e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e),this.paint._values[\"line-floorwidth\"]=us.possiblyEvaluate(this._transitioningPaint._values[\"line-width\"].value,e)},e.prototype.createBucket=function(t){return new os(t)},e.prototype.queryRadius=function(t){var e=t,r=fs(Sa(\"line-width\",this,e),Sa(\"line-gap-width\",this,e)),n=Sa(\"line-offset\",this,e);return r/2+Math.abs(n)+Ea(this.paint.get(\"line-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s){var l=Ca(t,this.paint.get(\"line-translate\"),this.paint.get(\"line-translate-anchor\"),o.angle,s),c=s/2*fs(this.paint.get(\"line-width\").evaluate(e,r),this.paint.get(\"line-gap-width\").evaluate(e,r)),u=this.paint.get(\"line-offset\").evaluate(e,r);return u&&(n=function(t,e){for(var r=[],n=new i(0,0),a=0;a<t.length;a++){for(var o=t[a],s=[],l=0;l<o.length;l++){var c=o[l-1],u=o[l],h=o[l+1],f=0===l?n:u.sub(c)._unit()._perp(),p=l===o.length-1?n:h.sub(u)._unit()._perp(),d=f._add(p)._unit(),g=d.x*p.x+d.y*p.y;d._mult(1/g),s.push(d._mult(e)._add(u))}r.push(s)}return r}(n,u*s)),function(t,e,r){for(var n=0;n<e.length;n++){var i=e[n];if(t.length>=3)for(var a=0;a<i.length;a++)if(Aa(t,i[a]))return!0;if(xa(t,i,r))return!0}return!1}(l,n,c)},e.prototype.isTileClipped=function(){return!0},e}(ri);function fs(t,e){return e>0?e+2*t:t}var ps=oi([{name:\"a_pos_offset\",components:4,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint16\"}]),ds=oi([{name:\"a_projected_pos\",components:3,type:\"Float32\"}],4),gs=(oi([{name:\"a_fade_opacity\",components:1,type:\"Uint32\"}],4),oi([{name:\"a_placed\",components:2,type:\"Uint8\"},{name:\"a_shift\",components:2,type:\"Float32\"}])),vs=(oi([{type:\"Int16\",name:\"anchorPointX\"},{type:\"Int16\",name:\"anchorPointY\"},{type:\"Int16\",name:\"x1\"},{type:\"Int16\",name:\"y1\"},{type:\"Int16\",name:\"x2\"},{type:\"Int16\",name:\"y2\"},{type:\"Uint32\",name:\"featureIndex\"},{type:\"Uint16\",name:\"sourceLayerIndex\"},{type:\"Uint16\",name:\"bucketIndex\"},{type:\"Int16\",name:\"radius\"},{type:\"Int16\",name:\"signedDistanceFromAnchor\"}]),oi([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4)),ms=oi([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4);function ys(t,e,r){return t.sections.forEach(function(t){t.text=function(t,e,r){var n=e.layout.get(\"text-transform\").evaluate(r,{});return\"uppercase\"===n?t=t.toLocaleUpperCase():\"lowercase\"===n&&(t=t.toLocaleLowerCase()),jn.applyArabicShaping&&(t=jn.applyArabicShaping(t)),t}(t.text,e,r)}),t}oi([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Uint16\",name:\"glyphStartIndex\"},{type:\"Uint16\",name:\"numGlyphs\"},{type:\"Uint32\",name:\"vertexStartIndex\"},{type:\"Uint32\",name:\"lineStartIndex\"},{type:\"Uint32\",name:\"lineLength\"},{type:\"Uint16\",name:\"segment\"},{type:\"Uint16\",name:\"lowerSize\"},{type:\"Uint16\",name:\"upperSize\"},{type:\"Float32\",name:\"lineOffsetX\"},{type:\"Float32\",name:\"lineOffsetY\"},{type:\"Uint8\",name:\"writingMode\"},{type:\"Uint8\",name:\"hidden\"},{type:\"Uint32\",name:\"crossTileID\"}]),oi([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Int16\",name:\"rightJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"centerJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"leftJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"verticalPlacedTextSymbolIndex\"},{type:\"Uint16\",name:\"key\"},{type:\"Uint16\",name:\"textBoxStartIndex\"},{type:\"Uint16\",name:\"textBoxEndIndex\"},{type:\"Uint16\",name:\"iconBoxStartIndex\"},{type:\"Uint16\",name:\"iconBoxEndIndex\"},{type:\"Uint16\",name:\"featureIndex\"},{type:\"Uint16\",name:\"numHorizontalGlyphVertices\"},{type:\"Uint16\",name:\"numVerticalGlyphVertices\"},{type:\"Uint16\",name:\"numIconVertices\"},{type:\"Uint32\",name:\"crossTileID\"},{type:\"Float32\",name:\"textBoxScale\"},{type:\"Float32\",name:\"radialTextOffset\"}]),oi([{type:\"Float32\",name:\"offsetX\"}]),oi([{type:\"Int16\",name:\"x\"},{type:\"Int16\",name:\"y\"},{type:\"Int16\",name:\"tileUnitDistanceFromAnchor\"}]);var xs={\"!\":\"\\ufe15\",\"#\":\"\\uff03\",$:\"\\uff04\",\"%\":\"\\uff05\",\"&\":\"\\uff06\",\"(\":\"\\ufe35\",\")\":\"\\ufe36\",\"*\":\"\\uff0a\",\"+\":\"\\uff0b\",\",\":\"\\ufe10\",\"-\":\"\\ufe32\",\".\":\"\\u30fb\",\"/\":\"\\uff0f\",\":\":\"\\ufe13\",\";\":\"\\ufe14\",\"<\":\"\\ufe3f\",\"=\":\"\\uff1d\",\">\":\"\\ufe40\",\"?\":\"\\ufe16\",\"@\":\"\\uff20\",\"[\":\"\\ufe47\",\"\\\\\":\"\\uff3c\",\"]\":\"\\ufe48\",\"^\":\"\\uff3e\",_:\"\\ufe33\",\"`\":\"\\uff40\",\"{\":\"\\ufe37\",\"|\":\"\\u2015\",\"}\":\"\\ufe38\",\"~\":\"\\uff5e\",\"\\xa2\":\"\\uffe0\",\"\\xa3\":\"\\uffe1\",\"\\xa5\":\"\\uffe5\",\"\\xa6\":\"\\uffe4\",\"\\xac\":\"\\uffe2\",\"\\xaf\":\"\\uffe3\",\"\\u2013\":\"\\ufe32\",\"\\u2014\":\"\\ufe31\",\"\\u2018\":\"\\ufe43\",\"\\u2019\":\"\\ufe44\",\"\\u201c\":\"\\ufe41\",\"\\u201d\":\"\\ufe42\",\"\\u2026\":\"\\ufe19\",\"\\u2027\":\"\\u30fb\",\"\\u20a9\":\"\\uffe6\",\"\\u3001\":\"\\ufe11\",\"\\u3002\":\"\\ufe12\",\"\\u3008\":\"\\ufe3f\",\"\\u3009\":\"\\ufe40\",\"\\u300a\":\"\\ufe3d\",\"\\u300b\":\"\\ufe3e\",\"\\u300c\":\"\\ufe41\",\"\\u300d\":\"\\ufe42\",\"\\u300e\":\"\\ufe43\",\"\\u300f\":\"\\ufe44\",\"\\u3010\":\"\\ufe3b\",\"\\u3011\":\"\\ufe3c\",\"\\u3014\":\"\\ufe39\",\"\\u3015\":\"\\ufe3a\",\"\\u3016\":\"\\ufe17\",\"\\u3017\":\"\\ufe18\",\"\\uff01\":\"\\ufe15\",\"\\uff08\":\"\\ufe35\",\"\\uff09\":\"\\ufe36\",\"\\uff0c\":\"\\ufe10\",\"\\uff0d\":\"\\ufe32\",\"\\uff0e\":\"\\u30fb\",\"\\uff1a\":\"\\ufe13\",\"\\uff1b\":\"\\ufe14\",\"\\uff1c\":\"\\ufe3f\",\"\\uff1e\":\"\\ufe40\",\"\\uff1f\":\"\\ufe16\",\"\\uff3b\":\"\\ufe47\",\"\\uff3d\":\"\\ufe48\",\"\\uff3f\":\"\\ufe33\",\"\\uff5b\":\"\\ufe37\",\"\\uff5c\":\"\\u2015\",\"\\uff5d\":\"\\ufe38\",\"\\uff5f\":\"\\ufe35\",\"\\uff60\":\"\\ufe36\",\"\\uff61\":\"\\ufe12\",\"\\uff62\":\"\\ufe41\",\"\\uff63\":\"\\ufe42\"},bs=function(t){function e(e,r,n,i){t.call(this,e,r),this.angle=n,void 0!==i&&(this.segment=i)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.clone=function(){return new e(this.x,this.y,this.angle,this.segment)},e}(i);kn(\"Anchor\",bs);var _s=256;function ws(t,e){var r=e.expression;if(\"constant\"===r.kind)return{kind:\"constant\",layoutSize:r.evaluate(new Un(t+1))};if(\"source\"===r.kind)return{kind:\"source\"};for(var n=r.zoomStops,i=r.interpolationType,a=0;a<n.length&&n[a]<=t;)a++;for(var o=a=Math.max(0,a-1);o<n.length&&n[o]<t+1;)o++;o=Math.min(n.length-1,o);var s=n[a],l=n[o];return\"composite\"===r.kind?{kind:\"composite\",minZoom:s,maxZoom:l,interpolationType:i}:{kind:\"camera\",minZoom:s,maxZoom:l,minSize:r.evaluate(new Un(s)),maxSize:r.evaluate(new Un(l)),interpolationType:i}}function ks(t,e,r){var n=e.uSize,i=e.uSizeT,a=r.lowerSize,o=r.upperSize;return\"source\"===t.kind?a/_s:\"composite\"===t.kind?Ee(a/_s,o/_s,i):n}function Ts(t,e){var r=0,n=0;if(\"constant\"===t.kind)n=t.layoutSize;else if(\"source\"!==t.kind){var i=t.interpolationType,a=t.minZoom,o=t.maxZoom,s=i?c(Xe.interpolationFactor(i,e,a,o),0,1):0;\"camera\"===t.kind?n=Ee(t.minSize,t.maxSize,s):r=s}return{uSizeT:r,uSize:n}}var As=Object.freeze({getSizeData:ws,evaluateSizeForFeature:ks,evaluateSizeForZoom:Ts,SIZE_PACK_FACTOR:_s}),Ms=Vo.VectorTileFeature.types,Ss=[{name:\"a_fade_opacity\",components:1,type:\"Uint8\",offset:0}];function Es(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,Math.round(32*n),Math.round(32*i),a,o,s?s[0]:0,s?s[1]:0)}function Cs(t,e,r){t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r)}var Ls=function(t){this.layoutVertexArray=new pi,this.indexArray=new Ti,this.programConfigurations=t,this.segments=new Vi,this.dynamicLayoutVertexArray=new di,this.opacityVertexArray=new gi,this.placedSymbolArray=new Oi};Ls.prototype.upload=function(t,e,r,n){r&&(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,ps.members),this.indexBuffer=t.createIndexBuffer(this.indexArray,e),this.dynamicLayoutVertexBuffer=t.createVertexBuffer(this.dynamicLayoutVertexArray,ds.members,!0),this.opacityVertexBuffer=t.createVertexBuffer(this.opacityVertexArray,Ss,!0),this.opacityVertexBuffer.itemSize=1),(r||n)&&this.programConfigurations.upload(t)},Ls.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.dynamicLayoutVertexBuffer.destroy(),this.opacityVertexBuffer.destroy())},kn(\"SymbolBuffers\",Ls);var Ps=function(t,e,r){this.layoutVertexArray=new t,this.layoutAttributes=e,this.indexArray=new r,this.segments=new Vi,this.collisionVertexArray=new yi};Ps.prototype.upload=function(t){this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,this.layoutAttributes),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.collisionVertexBuffer=t.createVertexBuffer(this.collisionVertexArray,gs.members,!0)},Ps.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.segments.destroy(),this.collisionVertexBuffer.destroy())},kn(\"CollisionBuffers\",Ps);var Os=function(t){this.collisionBoxArray=t.collisionBoxArray,this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map(function(t){return t.id}),this.index=t.index,this.pixelRatio=t.pixelRatio,this.sourceLayerIndex=t.sourceLayerIndex,this.hasPattern=!1;var e=this.layers[0]._unevaluatedLayout._values;this.textSizeData=ws(this.zoom,e[\"text-size\"]),this.iconSizeData=ws(this.zoom,e[\"icon-size\"]);var r=this.layers[0].layout,n=r.get(\"symbol-sort-key\"),i=r.get(\"symbol-z-order\");this.sortFeaturesByKey=\"viewport-y\"!==i&&void 0!==n.constantOr(1);var a=\"viewport-y\"===i||\"auto\"===i&&!this.sortFeaturesByKey;this.sortFeaturesByY=a&&(r.get(\"text-allow-overlap\")||r.get(\"icon-allow-overlap\")||r.get(\"text-ignore-placement\")||r.get(\"icon-ignore-placement\")),this.stateDependentLayerIds=this.layers.filter(function(t){return t.isStateDependent()}).map(function(t){return t.id}),this.sourceID=t.sourceID};Os.prototype.createArrays=function(){this.text=new Ls(new la(ps.members,this.layers,this.zoom,function(t){return/^text/.test(t)})),this.icon=new Ls(new la(ps.members,this.layers,this.zoom,function(t){return/^icon/.test(t)})),this.collisionBox=new Ps(mi,vs.members,Ai),this.collisionCircle=new Ps(mi,ms.members,Ti),this.glyphOffsetArray=new Ri,this.lineVertexArray=new Bi,this.symbolInstances=new Ii},Os.prototype.calculateGlyphDependencies=function(t,e,r,n){for(var i=0;i<t.length;i++)if(e[t.charCodeAt(i)]=!0,r&&n){var a=xs[t.charAt(i)];a&&(e[a.charCodeAt(0)]=!0)}},Os.prototype.populate=function(t,e){var r=this.layers[0],n=r.layout,i=n.get(\"text-font\"),a=n.get(\"text-field\"),o=n.get(\"icon-image\"),s=(\"constant\"!==a.value.kind||a.value.value.toString().length>0)&&(\"constant\"!==i.value.kind||i.value.value.length>0),l=\"constant\"!==o.value.kind||o.value.value&&o.value.value.length>0,c=n.get(\"symbol-sort-key\");if(this.features=[],s||l){for(var u=e.iconDependencies,h=e.glyphDependencies,f=new Un(this.zoom),p=0,d=t;p<d.length;p+=1){var g=d[p],v=g.feature,m=g.index,y=g.sourceLayerIndex;if(r._featureFilter(f,v)){var x=void 0;if(s){var b=r.getValueAndResolveTokens(\"text-field\",v);x=ys(b instanceof oe?b:oe.fromString(b),r,v)}var _=void 0;if(l&&(_=r.getValueAndResolveTokens(\"icon-image\",v)),x||_){var w=this.sortFeaturesByKey?c.evaluate(v,{}):void 0,k={text:x,icon:_,index:m,sourceLayerIndex:y,geometry:pa(v),properties:v.properties,type:Ms[v.type],sortKey:w};if(void 0!==v.id&&(k.id=v.id),this.features.push(k),_&&(u[_]=!0),x)for(var T=i.evaluate(v,{}).join(\",\"),A=\"map\"===n.get(\"text-rotation-alignment\")&&\"point\"!==n.get(\"symbol-placement\"),M=0,S=x.sections;M<S.length;M+=1){var E=S[M],C=Cn(x.toString()),L=E.fontStack||T,P=h[L]=h[L]||{};this.calculateGlyphDependencies(E.text,P,A,C)}}}}\"line\"===n.get(\"symbol-placement\")&&(this.features=function(t){var e={},r={},n=[],i=0;function a(e){n.push(t[e]),i++}function o(t,e,i){var a=r[t];return delete r[t],r[e]=a,n[a].geometry[0].pop(),n[a].geometry[0]=n[a].geometry[0].concat(i[0]),a}function s(t,r,i){var a=e[r];return delete e[r],e[t]=a,n[a].geometry[0].shift(),n[a].geometry[0]=i[0].concat(n[a].geometry[0]),a}function l(t,e,r){var n=r?e[0][e[0].length-1]:e[0][0];return t+\":\"+n.x+\":\"+n.y}for(var c=0;c<t.length;c++){var u=t[c],h=u.geometry,f=u.text?u.text.toString():null;if(f){var p=l(f,h),d=l(f,h,!0);if(p in r&&d in e&&r[p]!==e[d]){var g=s(p,d,h),v=o(p,d,n[g].geometry);delete e[p],delete r[d],r[l(f,n[v].geometry,!0)]=v,n[g].geometry=null}else p in r?o(p,d,h):d in e?s(p,d,h):(a(c),e[p]=i-1,r[d]=i-1)}else a(c)}return n.filter(function(t){return t.geometry})}(this.features)),this.sortFeaturesByKey&&this.features.sort(function(t,e){return t.sortKey-e.sortKey})}},Os.prototype.update=function(t,e,r){this.stateDependentLayers.length&&(this.text.programConfigurations.updatePaintArrays(t,e,this.layers,r),this.icon.programConfigurations.updatePaintArrays(t,e,this.layers,r))},Os.prototype.isEmpty=function(){return 0===this.symbolInstances.length},Os.prototype.uploadPending=function(){return!this.uploaded||this.text.programConfigurations.needsUpload||this.icon.programConfigurations.needsUpload},Os.prototype.upload=function(t){this.uploaded||(this.collisionBox.upload(t),this.collisionCircle.upload(t)),this.text.upload(t,this.sortFeaturesByY,!this.uploaded,this.text.programConfigurations.needsUpload),this.icon.upload(t,this.sortFeaturesByY,!this.uploaded,this.icon.programConfigurations.needsUpload),this.uploaded=!0},Os.prototype.destroy=function(){this.text.destroy(),this.icon.destroy(),this.collisionBox.destroy(),this.collisionCircle.destroy()},Os.prototype.addToLineVertexArray=function(t,e){var r=this.lineVertexArray.length;if(void 0!==t.segment){for(var n=t.dist(e[t.segment+1]),i=t.dist(e[t.segment]),a={},o=t.segment+1;o<e.length;o++)a[o]={x:e[o].x,y:e[o].y,tileUnitDistanceFromAnchor:n},o<e.length-1&&(n+=e[o+1].dist(e[o]));for(var s=t.segment||0;s>=0;s--)a[s]={x:e[s].x,y:e[s].y,tileUnitDistanceFromAnchor:i},s>0&&(i+=e[s-1].dist(e[s]));for(var l=0;l<e.length;l++){var c=a[l];this.lineVertexArray.emplaceBack(c.x,c.y,c.tileUnitDistanceFromAnchor)}}return{lineStartIndex:r,lineLength:this.lineVertexArray.length-r}},Os.prototype.addSymbols=function(t,e,r,n,i,a,o,s,l,c){for(var u=t.indexArray,h=t.layoutVertexArray,f=t.dynamicLayoutVertexArray,p=t.segments.prepareSegment(4*e.length,t.layoutVertexArray,t.indexArray,a.sortKey),d=this.glyphOffsetArray.length,g=p.vertexLength,v=0,m=e;v<m.length;v+=1){var y=m[v],x=y.tl,b=y.tr,_=y.bl,w=y.br,k=y.tex,T=p.vertexLength,A=y.glyphOffset[1];Es(h,s.x,s.y,x.x,A+x.y,k.x,k.y,r),Es(h,s.x,s.y,b.x,A+b.y,k.x+k.w,k.y,r),Es(h,s.x,s.y,_.x,A+_.y,k.x,k.y+k.h,r),Es(h,s.x,s.y,w.x,A+w.y,k.x+k.w,k.y+k.h,r),Cs(f,s,0),u.emplaceBack(T,T+1,T+2),u.emplaceBack(T+1,T+2,T+3),p.vertexLength+=4,p.primitiveLength+=2,this.glyphOffsetArray.emplaceBack(y.glyphOffset[0])}t.placedSymbolArray.emplaceBack(s.x,s.y,d,this.glyphOffsetArray.length-d,g,l,c,s.segment,r?r[0]:0,r?r[1]:0,n[0],n[1],o,!1,0),t.programConfigurations.populatePaintArrays(t.layoutVertexArray.length,a,a.index,{})},Os.prototype._addCollisionDebugVertex=function(t,e,r,n,i,a){return e.emplaceBack(0,0),t.emplaceBack(r.x,r.y,n,i,Math.round(a.x),Math.round(a.y))},Os.prototype.addCollisionDebugVertices=function(t,e,r,n,a,o,s,l){var c=a.segments.prepareSegment(4,a.layoutVertexArray,a.indexArray),u=c.vertexLength,h=a.layoutVertexArray,f=a.collisionVertexArray,p=s.anchorX,d=s.anchorY;if(this._addCollisionDebugVertex(h,f,o,p,d,new i(t,e)),this._addCollisionDebugVertex(h,f,o,p,d,new i(r,e)),this._addCollisionDebugVertex(h,f,o,p,d,new i(r,n)),this._addCollisionDebugVertex(h,f,o,p,d,new i(t,n)),c.vertexLength+=4,l){var g=a.indexArray;g.emplaceBack(u,u+1,u+2),g.emplaceBack(u,u+2,u+3),c.primitiveLength+=2}else{var v=a.indexArray;v.emplaceBack(u,u+1),v.emplaceBack(u+1,u+2),v.emplaceBack(u+2,u+3),v.emplaceBack(u+3,u),c.primitiveLength+=4}},Os.prototype.addDebugCollisionBoxes=function(t,e,r){for(var n=t;n<e;n++){var i=this.collisionBoxArray.get(n),a=i.x1,o=i.y1,s=i.x2,l=i.y2,c=i.radius>0;this.addCollisionDebugVertices(a,o,s,l,c?this.collisionCircle:this.collisionBox,i.anchorPoint,r,c)}},Os.prototype.generateCollisionDebugBuffers=function(){for(var t=0;t<this.symbolInstances.length;t++){var e=this.symbolInstances.get(t);this.addDebugCollisionBoxes(e.textBoxStartIndex,e.textBoxEndIndex,e),this.addDebugCollisionBoxes(e.iconBoxStartIndex,e.iconBoxEndIndex,e)}},Os.prototype._deserializeCollisionBoxesForSymbol=function(t,e,r,n,i){for(var a={},o=e;o<r;o++){var s=t.get(o);if(0===s.radius){a.textBox={x1:s.x1,y1:s.y1,x2:s.x2,y2:s.y2,anchorPointX:s.anchorPointX,anchorPointY:s.anchorPointY},a.textFeatureIndex=s.featureIndex;break}a.textCircles||(a.textCircles=[],a.textFeatureIndex=s.featureIndex),a.textCircles.push(s.anchorPointX,s.anchorPointY,s.radius,s.signedDistanceFromAnchor,1)}for(var l=n;l<i;l++){var c=t.get(l);if(0===c.radius){a.iconBox={x1:c.x1,y1:c.y1,x2:c.x2,y2:c.y2,anchorPointX:c.anchorPointX,anchorPointY:c.anchorPointY},a.iconFeatureIndex=c.featureIndex;break}}return a},Os.prototype.deserializeCollisionBoxes=function(t){this.collisionArrays=[];for(var e=0;e<this.symbolInstances.length;e++){var r=this.symbolInstances.get(e);this.collisionArrays.push(this._deserializeCollisionBoxesForSymbol(t,r.textBoxStartIndex,r.textBoxEndIndex,r.iconBoxStartIndex,r.iconBoxEndIndex))}},Os.prototype.hasTextData=function(){return this.text.segments.get().length>0},Os.prototype.hasIconData=function(){return this.icon.segments.get().length>0},Os.prototype.hasCollisionBoxData=function(){return this.collisionBox.segments.get().length>0},Os.prototype.hasCollisionCircleData=function(){return this.collisionCircle.segments.get().length>0},Os.prototype.addIndicesForPlacedTextSymbol=function(t){for(var e=this.text.placedSymbolArray.get(t),r=e.vertexStartIndex+4*e.numGlyphs,n=e.vertexStartIndex;n<r;n+=4)this.text.indexArray.emplaceBack(n,n+1,n+2),this.text.indexArray.emplaceBack(n+1,n+2,n+3)},Os.prototype.getSortedSymbolIndexes=function(t){if(this.sortedAngle===t&&void 0!==this.symbolInstanceIndexes)return this.symbolInstanceIndexes;for(var e=Math.sin(t),r=Math.cos(t),n=[],i=[],a=[],o=0;o<this.symbolInstances.length;++o){a.push(o);var s=this.symbolInstances.get(o);n.push(0|Math.round(e*s.anchorX+r*s.anchorY)),i.push(s.featureIndex)}return a.sort(function(t,e){return n[t]-n[e]||i[e]-i[t]}),a},Os.prototype.sortFeatures=function(t){var e=this;if(this.sortFeaturesByY&&this.sortedAngle!==t&&!(this.text.segments.get().length>1||this.icon.segments.get().length>1)){this.symbolInstanceIndexes=this.getSortedSymbolIndexes(t),this.sortedAngle=t,this.text.indexArray.clear(),this.icon.indexArray.clear(),this.featureSortOrder=[];for(var r=0,n=this.symbolInstanceIndexes;r<n.length;r+=1){var i=n[r],a=this.symbolInstances.get(i);this.featureSortOrder.push(a.featureIndex),[a.rightJustifiedTextSymbolIndex,a.centerJustifiedTextSymbolIndex,a.leftJustifiedTextSymbolIndex].forEach(function(t,r,n){t>=0&&n.indexOf(t)===r&&e.addIndicesForPlacedTextSymbol(t)}),a.verticalPlacedTextSymbolIndex>=0&&this.addIndicesForPlacedTextSymbol(a.verticalPlacedTextSymbolIndex);var o=this.icon.placedSymbolArray.get(i);if(o.numGlyphs){var s=o.vertexStartIndex;this.icon.indexArray.emplaceBack(s,s+1,s+2),this.icon.indexArray.emplaceBack(s+1,s+2,s+3)}}this.text.indexBuffer&&this.text.indexBuffer.updateData(this.text.indexArray),this.icon.indexBuffer&&this.icon.indexBuffer.updateData(this.icon.indexArray)}},kn(\"SymbolBucket\",Os,{omit:[\"layers\",\"collisionBoxArray\",\"features\",\"compareText\"]}),Os.MAX_GLYPHS=65535,Os.addDynamicAttributes=Cs;var zs=new ei({\"symbol-placement\":new Jn(It.layout_symbol[\"symbol-placement\"]),\"symbol-spacing\":new Jn(It.layout_symbol[\"symbol-spacing\"]),\"symbol-avoid-edges\":new Jn(It.layout_symbol[\"symbol-avoid-edges\"]),\"symbol-sort-key\":new Kn(It.layout_symbol[\"symbol-sort-key\"]),\"symbol-z-order\":new Jn(It.layout_symbol[\"symbol-z-order\"]),\"icon-allow-overlap\":new Jn(It.layout_symbol[\"icon-allow-overlap\"]),\"icon-ignore-placement\":new Jn(It.layout_symbol[\"icon-ignore-placement\"]),\"icon-optional\":new Jn(It.layout_symbol[\"icon-optional\"]),\"icon-rotation-alignment\":new Jn(It.layout_symbol[\"icon-rotation-alignment\"]),\"icon-size\":new Kn(It.layout_symbol[\"icon-size\"]),\"icon-text-fit\":new Jn(It.layout_symbol[\"icon-text-fit\"]),\"icon-text-fit-padding\":new Jn(It.layout_symbol[\"icon-text-fit-padding\"]),\"icon-image\":new Kn(It.layout_symbol[\"icon-image\"]),\"icon-rotate\":new Kn(It.layout_symbol[\"icon-rotate\"]),\"icon-padding\":new Jn(It.layout_symbol[\"icon-padding\"]),\"icon-keep-upright\":new Jn(It.layout_symbol[\"icon-keep-upright\"]),\"icon-offset\":new Kn(It.layout_symbol[\"icon-offset\"]),\"icon-anchor\":new Kn(It.layout_symbol[\"icon-anchor\"]),\"icon-pitch-alignment\":new Jn(It.layout_symbol[\"icon-pitch-alignment\"]),\"text-pitch-alignment\":new Jn(It.layout_symbol[\"text-pitch-alignment\"]),\"text-rotation-alignment\":new Jn(It.layout_symbol[\"text-rotation-alignment\"]),\"text-field\":new Kn(It.layout_symbol[\"text-field\"]),\"text-font\":new Kn(It.layout_symbol[\"text-font\"]),\"text-size\":new Kn(It.layout_symbol[\"text-size\"]),\"text-max-width\":new Kn(It.layout_symbol[\"text-max-width\"]),\"text-line-height\":new Jn(It.layout_symbol[\"text-line-height\"]),\"text-letter-spacing\":new Kn(It.layout_symbol[\"text-letter-spacing\"]),\"text-justify\":new Kn(It.layout_symbol[\"text-justify\"]),\"text-radial-offset\":new Kn(It.layout_symbol[\"text-radial-offset\"]),\"text-variable-anchor\":new Jn(It.layout_symbol[\"text-variable-anchor\"]),\"text-anchor\":new Kn(It.layout_symbol[\"text-anchor\"]),\"text-max-angle\":new Jn(It.layout_symbol[\"text-max-angle\"]),\"text-rotate\":new Kn(It.layout_symbol[\"text-rotate\"]),\"text-padding\":new Jn(It.layout_symbol[\"text-padding\"]),\"text-keep-upright\":new Jn(It.layout_symbol[\"text-keep-upright\"]),\"text-transform\":new Kn(It.layout_symbol[\"text-transform\"]),\"text-offset\":new Kn(It.layout_symbol[\"text-offset\"]),\"text-allow-overlap\":new Jn(It.layout_symbol[\"text-allow-overlap\"]),\"text-ignore-placement\":new Jn(It.layout_symbol[\"text-ignore-placement\"]),\"text-optional\":new Jn(It.layout_symbol[\"text-optional\"])}),Is={paint:new ei({\"icon-opacity\":new Kn(It.paint_symbol[\"icon-opacity\"]),\"icon-color\":new Kn(It.paint_symbol[\"icon-color\"]),\"icon-halo-color\":new Kn(It.paint_symbol[\"icon-halo-color\"]),\"icon-halo-width\":new Kn(It.paint_symbol[\"icon-halo-width\"]),\"icon-halo-blur\":new Kn(It.paint_symbol[\"icon-halo-blur\"]),\"icon-translate\":new Jn(It.paint_symbol[\"icon-translate\"]),\"icon-translate-anchor\":new Jn(It.paint_symbol[\"icon-translate-anchor\"]),\"text-opacity\":new Kn(It.paint_symbol[\"text-opacity\"]),\"text-color\":new Kn(It.paint_symbol[\"text-color\"]),\"text-halo-color\":new Kn(It.paint_symbol[\"text-halo-color\"]),\"text-halo-width\":new Kn(It.paint_symbol[\"text-halo-width\"]),\"text-halo-blur\":new Kn(It.paint_symbol[\"text-halo-blur\"]),\"text-translate\":new Jn(It.paint_symbol[\"text-translate\"]),\"text-translate-anchor\":new Jn(It.paint_symbol[\"text-translate-anchor\"])}),layout:zs},Ds=function(t){function e(e){t.call(this,e,Is)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e){t.prototype.recalculate.call(this,e),\"auto\"===this.layout.get(\"icon-rotation-alignment\")&&(\"point\"!==this.layout.get(\"symbol-placement\")?this.layout._values[\"icon-rotation-alignment\"]=\"map\":this.layout._values[\"icon-rotation-alignment\"]=\"viewport\"),\"auto\"===this.layout.get(\"text-rotation-alignment\")&&(\"point\"!==this.layout.get(\"symbol-placement\")?this.layout._values[\"text-rotation-alignment\"]=\"map\":this.layout._values[\"text-rotation-alignment\"]=\"viewport\"),\"auto\"===this.layout.get(\"text-pitch-alignment\")&&(this.layout._values[\"text-pitch-alignment\"]=this.layout.get(\"text-rotation-alignment\")),\"auto\"===this.layout.get(\"icon-pitch-alignment\")&&(this.layout._values[\"icon-pitch-alignment\"]=this.layout.get(\"icon-rotation-alignment\"))},e.prototype.getValueAndResolveTokens=function(t,e){var r,n=this.layout.get(t).evaluate(e,{}),i=this._unevaluatedLayout._values[t];return i.isDataDriven()||Pr(i.value)?n:(r=e.properties,n.replace(/{([^{}]+)}/g,function(t,e){return e in r?String(r[e]):\"\"}))},e.prototype.createBucket=function(t){return new Os(t)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e}(ri),Rs={paint:new ei({\"background-color\":new Jn(It.paint_background[\"background-color\"]),\"background-pattern\":new Qn(It.paint_background[\"background-pattern\"]),\"background-opacity\":new Jn(It.paint_background[\"background-opacity\"])})},Fs=function(t){function e(e){t.call(this,e,Rs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ri),Bs={paint:new ei({\"raster-opacity\":new Jn(It.paint_raster[\"raster-opacity\"]),\"raster-hue-rotate\":new Jn(It.paint_raster[\"raster-hue-rotate\"]),\"raster-brightness-min\":new Jn(It.paint_raster[\"raster-brightness-min\"]),\"raster-brightness-max\":new Jn(It.paint_raster[\"raster-brightness-max\"]),\"raster-saturation\":new Jn(It.paint_raster[\"raster-saturation\"]),\"raster-contrast\":new Jn(It.paint_raster[\"raster-contrast\"]),\"raster-resampling\":new Jn(It.paint_raster[\"raster-resampling\"]),\"raster-fade-duration\":new Jn(It.paint_raster[\"raster-fade-duration\"])})},Ns=function(t){function e(e){t.call(this,e,Bs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(ri),js=function(t){function e(e){t.call(this,e,{}),this.implementation=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.is3D=function(){return\"3d\"===this.implementation.renderingMode},e.prototype.hasOffscreenPass=function(){return void 0!==this.implementation.prerender},e.prototype.recalculate=function(){},e.prototype.updateTransitions=function(){},e.prototype.hasTransition=function(){},e.prototype.serialize=function(){},e.prototype.onAdd=function(t){this.implementation.onAdd&&this.implementation.onAdd(t,t.painter.context.gl)},e.prototype.onRemove=function(t){this.implementation.onRemove&&this.implementation.onRemove(t,t.painter.context.gl)},e}(ri),Us={circle:Fa,heatmap:Wa,hillshade:Za,fill:Oo,\"fill-extrusion\":Jo,line:hs,symbol:Ds,background:Fs,raster:Ns};function Vs(t){for(var e=0,r=0,n=0,i=t;n<i.length;n+=1){var a=i[n];e+=a.w*a.h,r=Math.max(r,a.w)}t.sort(function(t,e){return e.h-t.h});for(var o=[{x:0,y:0,w:Math.max(Math.ceil(Math.sqrt(e/.95)),r),h:1/0}],s=0,l=0,c=0,u=t;c<u.length;c+=1)for(var h=u[c],f=o.length-1;f>=0;f--){var p=o[f];if(!(h.w>p.w||h.h>p.h)){if(h.x=p.x,h.y=p.y,l=Math.max(l,h.y+h.h),s=Math.max(s,h.x+h.w),h.w===p.w&&h.h===p.h){var d=o.pop();f<o.length&&(o[f]=d)}else h.h===p.h?(p.x+=h.w,p.w-=h.w):h.w===p.w?(p.y+=h.h,p.h-=h.h):(o.push({x:p.x+h.w,y:p.y,w:p.w-h.w,h:h.h}),p.y+=h.h,p.h-=h.h);break}}return{w:s,h:l,fill:e/(s*l)||0}}var qs=function(t,e){var r=e.pixelRatio,n=e.version;this.paddedRect=t,this.pixelRatio=r,this.version=n},Hs={tl:{configurable:!0},br:{configurable:!0},tlbr:{configurable:!0},displaySize:{configurable:!0}};Hs.tl.get=function(){return[this.paddedRect.x+1,this.paddedRect.y+1]},Hs.br.get=function(){return[this.paddedRect.x+this.paddedRect.w-1,this.paddedRect.y+this.paddedRect.h-1]},Hs.tlbr.get=function(){return this.tl.concat(this.br)},Hs.displaySize.get=function(){return[(this.paddedRect.w-2)/this.pixelRatio,(this.paddedRect.h-2)/this.pixelRatio]},Object.defineProperties(qs.prototype,Hs);var Gs=function(t,e){var r={},n={};this.haveRenderCallbacks=[];var i=[];this.addImages(t,r,i),this.addImages(e,n,i);var a=Vs(i),o=a.w,s=a.h,l=new Ha({width:o||1,height:s||1});for(var c in t){var u=t[c],h=r[c].paddedRect;Ha.copy(u.data,l,{x:0,y:0},{x:h.x+1,y:h.y+1},u.data)}for(var f in e){var p=e[f],d=n[f].paddedRect,g=d.x+1,v=d.y+1,m=p.data.width,y=p.data.height;Ha.copy(p.data,l,{x:0,y:0},{x:g,y:v},p.data),Ha.copy(p.data,l,{x:0,y:y-1},{x:g,y:v-1},{width:m,height:1}),Ha.copy(p.data,l,{x:0,y:0},{x:g,y:v+y},{width:m,height:1}),Ha.copy(p.data,l,{x:m-1,y:0},{x:g-1,y:v},{width:1,height:y}),Ha.copy(p.data,l,{x:0,y:0},{x:g+m,y:v},{width:1,height:y})}this.image=l,this.iconPositions=r,this.patternPositions=n};Gs.prototype.addImages=function(t,e,r){for(var n in t){var i=t[n],a={x:0,y:0,w:i.data.width+2,h:i.data.height+2};r.push(a),e[n]=new qs(a,i),i.hasRenderCallback&&this.haveRenderCallbacks.push(n)}},Gs.prototype.patchUpdatedImages=function(t,e){for(var r in t.dispatchRenderCallbacks(this.haveRenderCallbacks),t.updatedImages)this.patchUpdatedImage(this.iconPositions[r],t.getImage(r),e),this.patchUpdatedImage(this.patternPositions[r],t.getImage(r),e)},Gs.prototype.patchUpdatedImage=function(t,e,r){if(t&&e&&t.version!==e.version){t.version=e.version;var n=t.tl,i=n[0],a=n[1];r.update(e.data,void 0,{x:i,y:a})}},kn(\"ImagePosition\",qs),kn(\"ImageAtlas\",Gs);var Ys=self.HTMLImageElement,Ws=self.HTMLCanvasElement,Xs=self.HTMLVideoElement,Zs=self.ImageData,Js=function(t,e,r,n){this.context=t,this.format=r,this.texture=t.gl.createTexture(),this.update(e,n)};Js.prototype.update=function(t,e,r){var n=t.width,i=t.height,a=!(this.size&&this.size[0]===n&&this.size[1]===i||r),o=this.context,s=o.gl;if(this.useMipmap=Boolean(e&&e.useMipmap),s.bindTexture(s.TEXTURE_2D,this.texture),o.pixelStoreUnpackFlipY.set(!1),o.pixelStoreUnpack.set(1),o.pixelStoreUnpackPremultiplyAlpha.set(this.format===s.RGBA&&(!e||!1!==e.premultiply)),a)this.size=[n,i],t instanceof Ys||t instanceof Ws||t instanceof Xs||t instanceof Zs?s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,s.UNSIGNED_BYTE,t):s.texImage2D(s.TEXTURE_2D,0,this.format,n,i,0,this.format,s.UNSIGNED_BYTE,t.data);else{var l=r||{x:0,y:0},c=l.x,u=l.y;t instanceof Ys||t instanceof Ws||t instanceof Xs||t instanceof Zs?s.texSubImage2D(s.TEXTURE_2D,0,c,u,s.RGBA,s.UNSIGNED_BYTE,t):s.texSubImage2D(s.TEXTURE_2D,0,c,u,n,i,s.RGBA,s.UNSIGNED_BYTE,t.data)}this.useMipmap&&this.isSizePowerOfTwo()&&s.generateMipmap(s.TEXTURE_2D)},Js.prototype.bind=function(t,e,r){var n=this.context.gl;n.bindTexture(n.TEXTURE_2D,this.texture),r!==n.LINEAR_MIPMAP_NEAREST||this.isSizePowerOfTwo()||(r=n.LINEAR),t!==this.filter&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,t),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,r||t),this.filter=t),e!==this.wrap&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,e),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,e),this.wrap=e)},Js.prototype.isSizePowerOfTwo=function(){return this.size[0]===this.size[1]&&Math.log(this.size[0])/Math.LN2%1==0},Js.prototype.destroy=function(){this.context.gl.deleteTexture(this.texture),this.texture=null};var Ks=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,h=r?i-1:0,f=r?-1:1,p=t[e+h];for(h+=f,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+h],h+=f,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+h],h+=f,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},$s=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,h=u>>1,f=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+h>=1?f/l:f*Math.pow(2,1-h))*l>=2&&(o++,l/=2),o+h>=u?(s=0,o=u):o+h>=1?(s=(e*l-1)*Math.pow(2,i),o+=h):(s=e*Math.pow(2,h-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g},Qs=tl;function tl(t){this.buf=ArrayBuffer.isView&&ArrayBuffer.isView(t)?t:new Uint8Array(t||0),this.pos=0,this.type=0,this.length=this.buf.length}function el(t){return t.type===tl.Bytes?t.readVarint()+t.pos:t.pos+1}function rl(t,e,r){return r?4294967296*e+(t>>>0):4294967296*(e>>>0)+(t>>>0)}function nl(t,e,r){var n=e<=16383?1:e<=2097151?2:e<=268435455?3:Math.floor(Math.log(e)/(7*Math.LN2));r.realloc(n);for(var i=r.pos-1;i>=t;i--)r.buf[i+n]=r.buf[i]}function il(t,e){for(var r=0;r<t.length;r++)e.writeVarint(t[r])}function al(t,e){for(var r=0;r<t.length;r++)e.writeSVarint(t[r])}function ol(t,e){for(var r=0;r<t.length;r++)e.writeFloat(t[r])}function sl(t,e){for(var r=0;r<t.length;r++)e.writeDouble(t[r])}function ll(t,e){for(var r=0;r<t.length;r++)e.writeBoolean(t[r])}function cl(t,e){for(var r=0;r<t.length;r++)e.writeFixed32(t[r])}function ul(t,e){for(var r=0;r<t.length;r++)e.writeSFixed32(t[r])}function hl(t,e){for(var r=0;r<t.length;r++)e.writeFixed64(t[r])}function fl(t,e){for(var r=0;r<t.length;r++)e.writeSFixed64(t[r])}function pl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+16777216*t[e+3]}function dl(t,e,r){t[r]=e,t[r+1]=e>>>8,t[r+2]=e>>>16,t[r+3]=e>>>24}function gl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+(t[e+3]<<24)}tl.Varint=0,tl.Fixed64=1,tl.Bytes=2,tl.Fixed32=5,tl.prototype={destroy:function(){this.buf=null},readFields:function(t,e,r){for(r=r||this.length;this.pos<r;){var n=this.readVarint(),i=n>>3,a=this.pos;this.type=7&n,t(i,e,this),this.pos===a&&this.skip(n)}return e},readMessage:function(t,e){return this.readFields(t,e,this.readVarint()+this.pos)},readFixed32:function(){var t=pl(this.buf,this.pos);return this.pos+=4,t},readSFixed32:function(){var t=gl(this.buf,this.pos);return this.pos+=4,t},readFixed64:function(){var t=pl(this.buf,this.pos)+4294967296*pl(this.buf,this.pos+4);return this.pos+=8,t},readSFixed64:function(){var t=pl(this.buf,this.pos)+4294967296*gl(this.buf,this.pos+4);return this.pos+=8,t},readFloat:function(){var t=Ks(this.buf,this.pos,!0,23,4);return this.pos+=4,t},readDouble:function(){var t=Ks(this.buf,this.pos,!0,52,8);return this.pos+=8,t},readVarint:function(t){var e,r,n=this.buf;return e=127&(r=n[this.pos++]),r<128?e:(e|=(127&(r=n[this.pos++]))<<7,r<128?e:(e|=(127&(r=n[this.pos++]))<<14,r<128?e:(e|=(127&(r=n[this.pos++]))<<21,r<128?e:function(t,e,r){var n,i,a=r.buf;if(n=(112&(i=a[r.pos++]))>>4,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<3,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<10,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<17,i<128)return rl(t,n,e);if(n|=(127&(i=a[r.pos++]))<<24,i<128)return rl(t,n,e);if(n|=(1&(i=a[r.pos++]))<<31,i<128)return rl(t,n,e);throw new Error(\"Expected varint not more than 10 bytes\")}(e|=(15&(r=n[this.pos]))<<28,t,this))))},readVarint64:function(){return this.readVarint(!0)},readSVarint:function(){var t=this.readVarint();return t%2==1?(t+1)/-2:t/2},readBoolean:function(){return Boolean(this.readVarint())},readString:function(){var t=this.readVarint()+this.pos,e=function(t,e,r){for(var n=\"\",i=e;i<r;){var a,o,s,l=t[i],c=null,u=l>239?4:l>223?3:l>191?2:1;if(i+u>r)break;1===u?l<128&&(c=l):2===u?128==(192&(a=t[i+1]))&&(c=(31&l)<<6|63&a)<=127&&(c=null):3===u?(a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&((c=(15&l)<<12|(63&a)<<6|63&o)<=2047||c>=55296&&c<=57343)&&(c=null)):4===u&&(a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&((c=(15&l)<<18|(63&a)<<12|(63&o)<<6|63&s)<=65535||c>=1114112)&&(c=null)),null===c?(c=65533,u=1):c>65535&&(c-=65536,n+=String.fromCharCode(c>>>10&1023|55296),c=56320|1023&c),n+=String.fromCharCode(c),i+=u}return n}(this.buf,this.pos,t);return this.pos=t,e},readBytes:function(){var t=this.readVarint()+this.pos,e=this.buf.subarray(this.pos,t);return this.pos=t,e},readPackedVarint:function(t,e){if(this.type!==tl.Bytes)return t.push(this.readVarint(e));var r=el(this);for(t=t||[];this.pos<r;)t.push(this.readVarint(e));return t},readPackedSVarint:function(t){if(this.type!==tl.Bytes)return t.push(this.readSVarint());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSVarint());return t},readPackedBoolean:function(t){if(this.type!==tl.Bytes)return t.push(this.readBoolean());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readBoolean());return t},readPackedFloat:function(t){if(this.type!==tl.Bytes)return t.push(this.readFloat());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFloat());return t},readPackedDouble:function(t){if(this.type!==tl.Bytes)return t.push(this.readDouble());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readDouble());return t},readPackedFixed32:function(t){if(this.type!==tl.Bytes)return t.push(this.readFixed32());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFixed32());return t},readPackedSFixed32:function(t){if(this.type!==tl.Bytes)return t.push(this.readSFixed32());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed32());return t},readPackedFixed64:function(t){if(this.type!==tl.Bytes)return t.push(this.readFixed64());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readFixed64());return t},readPackedSFixed64:function(t){if(this.type!==tl.Bytes)return t.push(this.readSFixed64());var e=el(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed64());return t},skip:function(t){var e=7&t;if(e===tl.Varint)for(;this.buf[this.pos++]>127;);else if(e===tl.Bytes)this.pos=this.readVarint()+this.pos;else if(e===tl.Fixed32)this.pos+=4;else{if(e!==tl.Fixed64)throw new Error(\"Unimplemented type: \"+e);this.pos+=8}},writeTag:function(t,e){this.writeVarint(t<<3|e)},realloc:function(t){for(var e=this.length||16;e<this.pos+t;)e*=2;if(e!==this.length){var r=new Uint8Array(e);r.set(this.buf),this.buf=r,this.length=e}},finish:function(){return this.length=this.pos,this.pos=0,this.buf.subarray(0,this.length)},writeFixed32:function(t){this.realloc(4),dl(this.buf,t,this.pos),this.pos+=4},writeSFixed32:function(t){this.realloc(4),dl(this.buf,t,this.pos),this.pos+=4},writeFixed64:function(t){this.realloc(8),dl(this.buf,-1&t,this.pos),dl(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeSFixed64:function(t){this.realloc(8),dl(this.buf,-1&t,this.pos),dl(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeVarint:function(t){(t=+t||0)>268435455||t<0?function(t,e){var r,n;if(t>=0?(r=t%4294967296|0,n=t/4294967296|0):(n=~(-t/4294967296),4294967295^(r=~(-t%4294967296))?r=r+1|0:(r=0,n=n+1|0)),t>=0x10000000000000000||t<-0x10000000000000000)throw new Error(\"Given varint doesn't fit into 10 bytes\");e.realloc(10),function(t,e,r){r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos]=127&t}(r,0,e),function(t,e){var r=(7&t)<<4;e.buf[e.pos++]|=r|((t>>>=3)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t)))))}(n,e)}(t,this):(this.realloc(4),this.buf[this.pos++]=127&t|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=t>>>7&127))))},writeSVarint:function(t){this.writeVarint(t<0?2*-t-1:2*t)},writeBoolean:function(t){this.writeVarint(Boolean(t))},writeString:function(t){t=String(t),this.realloc(4*t.length),this.pos++;var e=this.pos;this.pos=function(t,e,r){for(var n,i,a=0;a<e.length;a++){if((n=e.charCodeAt(a))>55295&&n<57344){if(!i){n>56319||a+1===e.length?(t[r++]=239,t[r++]=191,t[r++]=189):i=n;continue}if(n<56320){t[r++]=239,t[r++]=191,t[r++]=189,i=n;continue}n=i-55296<<10|n-56320|65536,i=null}else i&&(t[r++]=239,t[r++]=191,t[r++]=189,i=null);n<128?t[r++]=n:(n<2048?t[r++]=n>>6|192:(n<65536?t[r++]=n>>12|224:(t[r++]=n>>18|240,t[r++]=n>>12&63|128),t[r++]=n>>6&63|128),t[r++]=63&n|128)}return r}(this.buf,t,this.pos);var r=this.pos-e;r>=128&&nl(e,r,this),this.pos=e-1,this.writeVarint(r),this.pos+=r},writeFloat:function(t){this.realloc(4),$s(this.buf,t,this.pos,!0,23,4),this.pos+=4},writeDouble:function(t){this.realloc(8),$s(this.buf,t,this.pos,!0,52,8),this.pos+=8},writeBytes:function(t){var e=t.length;this.writeVarint(e),this.realloc(e);for(var r=0;r<e;r++)this.buf[this.pos++]=t[r]},writeRawMessage:function(t,e){this.pos++;var r=this.pos;t(e,this);var n=this.pos-r;n>=128&&nl(r,n,this),this.pos=r-1,this.writeVarint(n),this.pos+=n},writeMessage:function(t,e,r){this.writeTag(t,tl.Bytes),this.writeRawMessage(e,r)},writePackedVarint:function(t,e){e.length&&this.writeMessage(t,il,e)},writePackedSVarint:function(t,e){e.length&&this.writeMessage(t,al,e)},writePackedBoolean:function(t,e){e.length&&this.writeMessage(t,ll,e)},writePackedFloat:function(t,e){e.length&&this.writeMessage(t,ol,e)},writePackedDouble:function(t,e){e.length&&this.writeMessage(t,sl,e)},writePackedFixed32:function(t,e){e.length&&this.writeMessage(t,cl,e)},writePackedSFixed32:function(t,e){e.length&&this.writeMessage(t,ul,e)},writePackedFixed64:function(t,e){e.length&&this.writeMessage(t,hl,e)},writePackedSFixed64:function(t,e){e.length&&this.writeMessage(t,fl,e)},writeBytesField:function(t,e){this.writeTag(t,tl.Bytes),this.writeBytes(e)},writeFixed32Field:function(t,e){this.writeTag(t,tl.Fixed32),this.writeFixed32(e)},writeSFixed32Field:function(t,e){this.writeTag(t,tl.Fixed32),this.writeSFixed32(e)},writeFixed64Field:function(t,e){this.writeTag(t,tl.Fixed64),this.writeFixed64(e)},writeSFixed64Field:function(t,e){this.writeTag(t,tl.Fixed64),this.writeSFixed64(e)},writeVarintField:function(t,e){this.writeTag(t,tl.Varint),this.writeVarint(e)},writeSVarintField:function(t,e){this.writeTag(t,tl.Varint),this.writeSVarint(e)},writeStringField:function(t,e){this.writeTag(t,tl.Bytes),this.writeString(e)},writeFloatField:function(t,e){this.writeTag(t,tl.Fixed32),this.writeFloat(e)},writeDoubleField:function(t,e){this.writeTag(t,tl.Fixed64),this.writeDouble(e)},writeBooleanField:function(t,e){this.writeVarintField(t,Boolean(e))}};var vl=3;function ml(t,e,r){1===t&&r.readMessage(yl,e)}function yl(t,e,r){if(3===t){var n=r.readMessage(xl,{}),i=n.id,a=n.bitmap,o=n.width,s=n.height,l=n.left,c=n.top,u=n.advance;e.push({id:i,bitmap:new qa({width:o+2*vl,height:s+2*vl},a),metrics:{width:o,height:s,left:l,top:c,advance:u}})}}function xl(t,e,r){1===t?e.id=r.readVarint():2===t?e.bitmap=r.readBytes():3===t?e.width=r.readVarint():4===t?e.height=r.readVarint():5===t?e.left=r.readSVarint():6===t?e.top=r.readSVarint():7===t&&(e.advance=r.readVarint())}var bl=vl,_l=function(t,e,r){this.target=t,this.parent=e,this.mapId=r,this.callbacks={},this.callbackID=0,v([\"receive\"],this),this.target.addEventListener(\"message\",this.receive,!1)};function wl(t,e,r){var n=2*Math.PI*6378137/256/Math.pow(2,r);return[t*n-2*Math.PI*6378137/2,e*n-2*Math.PI*6378137/2]}_l.prototype.send=function(t,e,r,n){var i=this,a=r?this.mapId+\":\"+this.callbackID++:null;r&&(this.callbacks[a]=r);var o=[];if(this.target.postMessage({targetMapId:n,sourceMapId:this.mapId,type:t,id:String(a),data:An(e,o)},o),r)return{cancel:function(){i.callbacks[a]=null,i.target.postMessage({targetMapId:n,sourceMapId:i.mapId,type:\"<cancel>\",id:String(a)})}}},_l.prototype.receive=function(t){var e,r=this,n=t.data,i=n.id;if(!n.targetMapId||this.mapId===n.targetMapId){var a=function(t,e){delete r.callbacks[i];var n=[];r.target.postMessage({sourceMapId:r.mapId,type:\"<response>\",id:String(i),error:t?An(t):null,data:An(e,n)},n)};if(\"<response>\"===n.type||\"<cancel>\"===n.type)e=this.callbacks[n.id],delete this.callbacks[n.id],e&&n.error?e(Mn(n.error)):e&&e(null,Mn(n.data));else if(void 0!==n.id&&this.parent[n.type]){this.callbacks[n.id]=null;var o=this.parent[n.type](n.sourceMapId,Mn(n.data),a);o&&null===this.callbacks[n.id]&&(this.callbacks[n.id]=o.cancel)}else if(void 0!==n.id&&this.parent.getWorkerSource){var s=n.type.split(\".\"),l=Mn(n.data);this.parent.getWorkerSource(n.sourceMapId,s[0],l.source)[s[1]](l,a)}else this.parent[n.type](Mn(n.data))}},_l.prototype.remove=function(){this.target.removeEventListener(\"message\",this.receive,!1)};var kl=function(t,e){t&&(e?this.setSouthWest(t).setNorthEast(e):4===t.length?this.setSouthWest([t[0],t[1]]).setNorthEast([t[2],t[3]]):this.setSouthWest(t[0]).setNorthEast(t[1]))};kl.prototype.setNorthEast=function(t){return this._ne=t instanceof Tl?new Tl(t.lng,t.lat):Tl.convert(t),this},kl.prototype.setSouthWest=function(t){return this._sw=t instanceof Tl?new Tl(t.lng,t.lat):Tl.convert(t),this},kl.prototype.extend=function(t){var e,r,n=this._sw,i=this._ne;if(t instanceof Tl)e=t,r=t;else{if(!(t instanceof kl))return Array.isArray(t)?t.every(Array.isArray)?this.extend(kl.convert(t)):this.extend(Tl.convert(t)):this;if(e=t._sw,r=t._ne,!e||!r)return this}return n||i?(n.lng=Math.min(e.lng,n.lng),n.lat=Math.min(e.lat,n.lat),i.lng=Math.max(r.lng,i.lng),i.lat=Math.max(r.lat,i.lat)):(this._sw=new Tl(e.lng,e.lat),this._ne=new Tl(r.lng,r.lat)),this},kl.prototype.getCenter=function(){return new Tl((this._sw.lng+this._ne.lng)/2,(this._sw.lat+this._ne.lat)/2)},kl.prototype.getSouthWest=function(){return this._sw},kl.prototype.getNorthEast=function(){return this._ne},kl.prototype.getNorthWest=function(){return new Tl(this.getWest(),this.getNorth())},kl.prototype.getSouthEast=function(){return new Tl(this.getEast(),this.getSouth())},kl.prototype.getWest=function(){return this._sw.lng},kl.prototype.getSouth=function(){return this._sw.lat},kl.prototype.getEast=function(){return this._ne.lng},kl.prototype.getNorth=function(){return this._ne.lat},kl.prototype.toArray=function(){return[this._sw.toArray(),this._ne.toArray()]},kl.prototype.toString=function(){return\"LngLatBounds(\"+this._sw.toString()+\", \"+this._ne.toString()+\")\"},kl.prototype.isEmpty=function(){return!(this._sw&&this._ne)},kl.convert=function(t){return!t||t instanceof kl?t:new kl(t)};var Tl=function(t,e){if(isNaN(t)||isNaN(e))throw new Error(\"Invalid LngLat object: (\"+t+\", \"+e+\")\");if(this.lng=+t,this.lat=+e,this.lat>90||this.lat<-90)throw new Error(\"Invalid LngLat latitude value: must be between -90 and 90\")};function Al(t){return 2*Math.PI*6378137*Math.cos(t*Math.PI/180)}function Ml(t){return(180+t)/360}function Sl(t){return(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+t*Math.PI/360)))/360}function El(t,e){return t/Al(e)}function Cl(t){var e=180-360*t;return 360/Math.PI*Math.atan(Math.exp(e*Math.PI/180))-90}Tl.prototype.wrap=function(){return new Tl(u(this.lng,-180,180),this.lat)},Tl.prototype.toArray=function(){return[this.lng,this.lat]},Tl.prototype.toString=function(){return\"LngLat(\"+this.lng+\", \"+this.lat+\")\"},Tl.prototype.toBounds=function(t){void 0===t&&(t=0);var e=360*t/40075017,r=e/Math.cos(Math.PI/180*this.lat);return new kl(new Tl(this.lng-r,this.lat-e),new Tl(this.lng+r,this.lat+e))},Tl.convert=function(t){if(t instanceof Tl)return t;if(Array.isArray(t)&&(2===t.length||3===t.length))return new Tl(Number(t[0]),Number(t[1]));if(!Array.isArray(t)&&\"object\"==typeof t&&null!==t)return new Tl(Number(\"lng\"in t?t.lng:t.lon),Number(t.lat));throw new Error(\"`LngLatLike` argument must be specified as a LngLat instance, an object {lng: <lng>, lat: <lat>}, an object {lon: <lng>, lat: <lat>}, or an array of [<lng>, <lat>]\")};var Ll=function(t,e,r){void 0===r&&(r=0),this.x=+t,this.y=+e,this.z=+r};Ll.fromLngLat=function(t,e){void 0===e&&(e=0);var r=Tl.convert(t);return new Ll(Ml(r.lng),Sl(r.lat),El(e,r.lat))},Ll.prototype.toLngLat=function(){return new Tl(360*this.x-180,Cl(this.y))},Ll.prototype.toAltitude=function(){return this.z*Al(Cl(this.y))};var Pl=function(t,e,r){this.z=t,this.x=e,this.y=r,this.key=Il(0,t,e,r)};Pl.prototype.equals=function(t){return this.z===t.z&&this.x===t.x&&this.y===t.y},Pl.prototype.url=function(t,e){var r,n,i,a,o,s=(r=this.x,n=this.y,i=this.z,a=wl(256*r,256*(n=Math.pow(2,i)-n-1),i),o=wl(256*(r+1),256*(n+1),i),a[0]+\",\"+a[1]+\",\"+o[0]+\",\"+o[1]),l=function(t,e,r){for(var n,i=\"\",a=t;a>0;a--)i+=(e&(n=1<<a-1)?1:0)+(r&n?2:0);return i}(this.z,this.x,this.y);return t[(this.x+this.y)%t.length].replace(\"{prefix}\",(this.x%16).toString(16)+(this.y%16).toString(16)).replace(\"{z}\",String(this.z)).replace(\"{x}\",String(this.x)).replace(\"{y}\",String(\"tms\"===e?Math.pow(2,this.z)-this.y-1:this.y)).replace(\"{quadkey}\",l).replace(\"{bbox-epsg-3857}\",s)},Pl.prototype.getTilePoint=function(t){var e=Math.pow(2,this.z);return new i((t.x*e-this.x)*ha,(t.y*e-this.y)*ha)};var Ol=function(t,e){this.wrap=t,this.canonical=e,this.key=Il(t,e.z,e.x,e.y)},zl=function(t,e,r,n,i){this.overscaledZ=t,this.wrap=e,this.canonical=new Pl(r,+n,+i),this.key=Il(e,t,n,i)};function Il(t,e,r,n){(t*=2)<0&&(t=-1*t-1);var i=1<<e;return 32*(i*i*t+i*n+r)+e}zl.prototype.equals=function(t){return this.overscaledZ===t.overscaledZ&&this.wrap===t.wrap&&this.canonical.equals(t.canonical)},zl.prototype.scaledTo=function(t){var e=this.canonical.z-t;return t>this.canonical.z?new zl(t,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y):new zl(t,this.wrap,t,this.canonical.x>>e,this.canonical.y>>e)},zl.prototype.isChildOf=function(t){if(t.wrap!==this.wrap)return!1;var e=this.canonical.z-t.canonical.z;return 0===t.overscaledZ||t.overscaledZ<this.overscaledZ&&t.canonical.x===this.canonical.x>>e&&t.canonical.y===this.canonical.y>>e},zl.prototype.children=function(t){if(this.overscaledZ>=t)return[new zl(this.overscaledZ+1,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y)];var e=this.canonical.z+1,r=2*this.canonical.x,n=2*this.canonical.y;return[new zl(e,this.wrap,e,r,n),new zl(e,this.wrap,e,r+1,n),new zl(e,this.wrap,e,r,n+1),new zl(e,this.wrap,e,r+1,n+1)]},zl.prototype.isLessThan=function(t){return this.wrap<t.wrap||!(this.wrap>t.wrap)&&(this.overscaledZ<t.overscaledZ||!(this.overscaledZ>t.overscaledZ)&&(this.canonical.x<t.canonical.x||!(this.canonical.x>t.canonical.x)&&this.canonical.y<t.canonical.y))},zl.prototype.wrapped=function(){return new zl(this.overscaledZ,0,this.canonical.z,this.canonical.x,this.canonical.y)},zl.prototype.unwrapTo=function(t){return new zl(this.overscaledZ,t,this.canonical.z,this.canonical.x,this.canonical.y)},zl.prototype.overscaleFactor=function(){return Math.pow(2,this.overscaledZ-this.canonical.z)},zl.prototype.toUnwrapped=function(){return new Ol(this.wrap,this.canonical)},zl.prototype.toString=function(){return this.overscaledZ+\"/\"+this.canonical.x+\"/\"+this.canonical.y},zl.prototype.getTilePoint=function(t){return this.canonical.getTilePoint(new Ll(t.x-this.wrap,t.y))},kn(\"CanonicalTileID\",Pl),kn(\"OverscaledTileID\",zl,{omit:[\"posMatrix\"]});var Dl=function(t,e,r){if(this.uid=t,e.height!==e.width)throw new RangeError(\"DEM tiles must be square\");if(r&&\"mapbox\"!==r&&\"terrarium\"!==r)return w('\"'+r+'\" is not a valid encoding type. Valid types include \"mapbox\" and \"terrarium\".');var n=this.dim=e.height;this.stride=this.dim+2,this.data=new Int32Array(this.stride*this.stride);for(var i=e.data,a=\"terrarium\"===r?this._unpackTerrarium:this._unpackMapbox,o=0;o<n;o++)for(var s=0;s<n;s++){var l=4*(o*n+s);this.set(s,o,a(i[l],i[l+1],i[l+2]))}for(var c=0;c<n;c++)this.set(-1,c,this.get(0,c)),this.set(n,c,this.get(n-1,c)),this.set(c,-1,this.get(c,0)),this.set(c,n,this.get(c,n-1));this.set(-1,-1,this.get(0,0)),this.set(n,-1,this.get(n-1,0)),this.set(-1,n,this.get(0,n-1)),this.set(n,n,this.get(n-1,n-1))};Dl.prototype.set=function(t,e,r){this.data[this._idx(t,e)]=r+65536},Dl.prototype.get=function(t,e){return this.data[this._idx(t,e)]-65536},Dl.prototype._idx=function(t,e){if(t<-1||t>=this.dim+1||e<-1||e>=this.dim+1)throw new RangeError(\"out of range source coordinates for DEM data\");return(e+1)*this.stride+(t+1)},Dl.prototype._unpackMapbox=function(t,e,r){return(256*t*256+256*e+r)/10-1e4},Dl.prototype._unpackTerrarium=function(t,e,r){return 256*t+e+r/256-32768},Dl.prototype.getPixels=function(){return new Ha({width:this.stride,height:this.stride},new Uint8Array(this.data.buffer))},Dl.prototype.backfillBorder=function(t,e,r){if(this.dim!==t.dim)throw new Error(\"dem dimension mismatch\");var n=e*this.dim,i=e*this.dim+this.dim,a=r*this.dim,o=r*this.dim+this.dim;switch(e){case-1:n=i-1;break;case 1:i=n+1}switch(r){case-1:a=o-1;break;case 1:o=a+1}for(var s=-e*this.dim,l=-r*this.dim,c=a;c<o;c++)for(var u=n;u<i;u++)this.set(u,c,t.get(u+s,c+l))},kn(\"DEMData\",Dl);var Rl=oi([{name:\"a_pos\",type:\"Int16\",components:2},{name:\"a_texture_pos\",type:\"Int16\",components:2}]),Fl=function(t){this._stringToNumber={},this._numberToString=[];for(var e=0;e<t.length;e++){var r=t[e];this._stringToNumber[r]=e,this._numberToString[e]=r}};Fl.prototype.encode=function(t){return this._stringToNumber[t]},Fl.prototype.decode=function(t){return this._numberToString[t]};var Bl=function(t,e,r,n){this.type=\"Feature\",this._vectorTileFeature=t,t._z=e,t._x=r,t._y=n,this.properties=t.properties,null!=t.id&&(this.id=t.id)},Nl={geometry:{configurable:!0}};Nl.geometry.get=function(){return void 0===this._geometry&&(this._geometry=this._vectorTileFeature.toGeoJSON(this._vectorTileFeature._x,this._vectorTileFeature._y,this._vectorTileFeature._z).geometry),this._geometry},Nl.geometry.set=function(t){this._geometry=t},Bl.prototype.toJSON=function(){var t={geometry:this.geometry};for(var e in this)\"_geometry\"!==e&&\"_vectorTileFeature\"!==e&&(t[e]=this[e]);return t},Object.defineProperties(Bl.prototype,Nl);var jl=function(){this.state={},this.stateChanges={},this.deletedStates={}};jl.prototype.updateState=function(t,e,r){var n=String(e);if(this.stateChanges[t]=this.stateChanges[t]||{},this.stateChanges[t][n]=this.stateChanges[t][n]||{},h(this.stateChanges[t][n],r),null===this.deletedStates[t])for(var i in this.deletedStates[t]={},this.state[t])i!==n&&(this.deletedStates[t][i]=null);else if(this.deletedStates[t]&&null===this.deletedStates[t][n])for(var a in this.deletedStates[t][n]={},this.state[t][n])r[a]||(this.deletedStates[t][n][a]=null);else for(var o in r)this.deletedStates[t]&&this.deletedStates[t][n]&&null===this.deletedStates[t][n][o]&&delete this.deletedStates[t][n][o]},jl.prototype.removeFeatureState=function(t,e,r){if(null!==this.deletedStates[t]){var n=String(e);if(this.deletedStates[t]=this.deletedStates[t]||{},r&&void 0!==e&&e>=0)null!==this.deletedStates[t][n]&&(this.deletedStates[t][n]=this.deletedStates[t][n]||{},this.deletedStates[t][n][r]=null);else if(void 0!==e&&e>=0)if(this.stateChanges[t]&&this.stateChanges[t][n])for(r in this.deletedStates[t][n]={},this.stateChanges[t][n])this.deletedStates[t][n][r]=null;else this.deletedStates[t][n]=null;else this.deletedStates[t]=null}},jl.prototype.getState=function(t,e){var r=String(e),n=this.state[t]||{},i=this.stateChanges[t]||{},a=h({},n[r],i[r]);if(null===this.deletedStates[t])return{};if(this.deletedStates[t]){var o=this.deletedStates[t][e];if(null===o)return{};for(var s in o)delete a[s]}return a},jl.prototype.initializeTileState=function(t,e){t.setFeatureState(this.state,e)},jl.prototype.coalesceChanges=function(t,e){var r={};for(var n in this.stateChanges){this.state[n]=this.state[n]||{};var i={};for(var a in this.stateChanges[n])this.state[n][a]||(this.state[n][a]={}),h(this.state[n][a],this.stateChanges[n][a]),i[a]=this.state[n][a];r[n]=i}for(var o in this.deletedStates){this.state[o]=this.state[o]||{};var s={};if(null===this.deletedStates[o])for(var l in this.state[o])s[l]={},this.state[o][l]={};else for(var c in this.deletedStates[o]){if(null===this.deletedStates[o][c])this.state[o][c]={};else for(var u=0,f=Object.keys(this.deletedStates[o][c]);u<f.length;u+=1){var p=f[u];delete this.state[o][c][p]}s[c]=this.state[o][c]}r[o]=r[o]||{},h(r[o],s)}if(this.stateChanges={},this.deletedStates={},0!==Object.keys(r).length)for(var d in t)t[d].setFeatureState(r,e)};var Ul=function(t,e,r){this.tileID=t,this.x=t.canonical.x,this.y=t.canonical.y,this.z=t.canonical.z,this.grid=e||new yn(ha,16,0),this.grid3D=new yn(ha,16,0),this.featureIndexArray=r||new ji};function Vl(t){for(var e=1/0,r=1/0,n=-1/0,i=-1/0,a=0,o=t;a<o.length;a+=1){var s=o[a];e=Math.min(e,s.x),r=Math.min(r,s.y),n=Math.max(n,s.x),i=Math.max(i,s.y)}return{minX:e,minY:r,maxX:n,maxY:i}}function ql(t,e){return e-t}Ul.prototype.insert=function(t,e,r,n,i,a){var o=this.featureIndexArray.length;this.featureIndexArray.emplaceBack(r,n,i);for(var s=a?this.grid3D:this.grid,l=0;l<e.length;l++){for(var c=e[l],u=[1/0,1/0,-1/0,-1/0],h=0;h<c.length;h++){var f=c[h];u[0]=Math.min(u[0],f.x),u[1]=Math.min(u[1],f.y),u[2]=Math.max(u[2],f.x),u[3]=Math.max(u[3],f.y)}u[0]<ha&&u[1]<ha&&u[2]>=0&&u[3]>=0&&s.insert(o,u[0],u[1],u[2],u[3])}},Ul.prototype.loadVTLayers=function(){return this.vtLayers||(this.vtLayers=new Vo.VectorTile(new Qs(this.rawTileData)).layers,this.sourceLayerCoder=new Fl(this.vtLayers?Object.keys(this.vtLayers).sort():[\"_geojsonTileLayer\"])),this.vtLayers},Ul.prototype.query=function(t,e,r){var n=this;this.loadVTLayers();for(var a=t.params||{},o=ha/t.tileSize/t.scale,s=Gr(a.filter),l=t.queryGeometry,c=t.queryPadding*o,u=Vl(l),h=this.grid.query(u.minX-c,u.minY-c,u.maxX+c,u.maxY+c),f=Vl(t.cameraQueryGeometry),p=0,d=this.grid3D.query(f.minX-c,f.minY-c,f.maxX+c,f.maxY+c,function(e,r,n,a){return function(t,e,r,n,a){for(var o=0,s=t;o<s.length;o+=1){var l=s[o];if(e<=l.x&&r<=l.y&&n>=l.x&&a>=l.y)return!0}var c=[new i(e,r),new i(e,a),new i(n,a),new i(n,r)];if(t.length>2)for(var u=0,h=c;u<h.length;u+=1)if(Aa(t,h[u]))return!0;for(var f=0;f<t.length-1;f++)if(Ma(t[f],t[f+1],c))return!0;return!1}(t.cameraQueryGeometry,e-c,r-c,n+c,a+c)});p<d.length;p+=1){var g=d[p];h.push(g)}h.sort(ql);for(var v,m={},y=function(i){var c=h[i];if(c!==v){v=c;var u=n.featureIndexArray.get(c),f=null;n.loadMatchingFeature(m,u.bucketIndex,u.sourceLayerIndex,u.featureIndex,s,a.layers,e,function(e,i){f||(f=pa(e));var a={};return e.id&&(a=r.getState(i.sourceLayer||\"_geojsonTileLayer\",e.id)),i.queryIntersectsFeature(l,e,a,f,n.z,t.transform,o,t.pixelPosMatrix)})}},x=0;x<h.length;x++)y(x);return m},Ul.prototype.loadMatchingFeature=function(t,e,r,n,i,a,o,s){var l=this.bucketLayerIDs[e];if(!a||function(t,e){for(var r=0;r<t.length;r++)if(e.indexOf(t[r])>=0)return!0;return!1}(a,l)){var c=this.sourceLayerCoder.decode(r),u=this.vtLayers[c].feature(n);if(i(new Un(this.tileID.overscaledZ),u))for(var h=0;h<l.length;h++){var f=l[h];if(!(a&&a.indexOf(f)<0)){var p=o[f];if(p){var d=!s||s(u,p);if(d){var g=new Bl(u,this.z,this.x,this.y);g.layer=p.serialize();var v=t[f];void 0===v&&(v=t[f]=[]),v.push({featureIndex:n,feature:g,intersectionZ:d})}}}}}},Ul.prototype.lookupSymbolFeatures=function(t,e,r,n,i,a){var o={};this.loadVTLayers();for(var s=Gr(n),l=0,c=t;l<c.length;l+=1){var u=c[l];this.loadMatchingFeature(o,e,r,u,s,i,a)}return o},Ul.prototype.hasLayer=function(t){for(var e=0,r=this.bucketLayerIDs;e<r.length;e+=1)for(var n=0,i=r[e];n<i.length;n+=1)if(t===i[n])return!0;return!1},kn(\"FeatureIndex\",Ul,{omit:[\"rawTileData\",\"sourceLayerCoder\"]});var Hl=function(t,e){this.tileID=t,this.uid=p(),this.uses=0,this.tileSize=e,this.buckets={},this.expirationTime=null,this.queryPadding=0,this.hasSymbolBuckets=!1,this.expiredRequestCount=0,this.state=\"loading\"};Hl.prototype.registerFadeDuration=function(t){var e=t+this.timeAdded;e<z.now()||this.fadeEndTime&&e<this.fadeEndTime||(this.fadeEndTime=e)},Hl.prototype.wasRequested=function(){return\"errored\"===this.state||\"loaded\"===this.state||\"reloading\"===this.state},Hl.prototype.loadVectorData=function(t,e,r){if(this.hasData()&&this.unloadVectorData(),this.state=\"loaded\",t){for(var n in t.featureIndex&&(this.latestFeatureIndex=t.featureIndex,t.rawTileData?(this.latestRawTileData=t.rawTileData,this.latestFeatureIndex.rawTileData=t.rawTileData):this.latestRawTileData&&(this.latestFeatureIndex.rawTileData=this.latestRawTileData)),this.collisionBoxArray=t.collisionBoxArray,this.buckets=function(t,e){var r={};if(!e)return r;for(var n=function(){var t=a[i],n=t.layerIds.map(function(t){return e.getLayer(t)}).filter(Boolean);if(0!==n.length){t.layers=n,t.stateDependentLayerIds&&(t.stateDependentLayers=t.stateDependentLayerIds.map(function(t){return n.filter(function(e){return e.id===t})[0]}));for(var o=0,s=n;o<s.length;o+=1){var l=s[o];r[l.id]=t}}},i=0,a=t;i<a.length;i+=1)n();return r}(t.buckets,e.style),this.hasSymbolBuckets=!1,this.buckets){var i=this.buckets[n];if(i instanceof Os){if(this.hasSymbolBuckets=!0,!r)break;i.justReloaded=!0}}for(var a in this.queryPadding=0,this.buckets){var o=this.buckets[a];this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(a).queryRadius(o))}t.imageAtlas&&(this.imageAtlas=t.imageAtlas),t.glyphAtlasImage&&(this.glyphAtlasImage=t.glyphAtlasImage)}else this.collisionBoxArray=new Li},Hl.prototype.unloadVectorData=function(){for(var t in this.buckets)this.buckets[t].destroy();this.buckets={},this.imageAtlasTexture&&this.imageAtlasTexture.destroy(),this.imageAtlas&&(this.imageAtlas=null),this.glyphAtlasTexture&&this.glyphAtlasTexture.destroy(),this.latestFeatureIndex=null,this.state=\"unloaded\"},Hl.prototype.unloadDEMData=function(){this.dem=null,this.neighboringTiles=null,this.state=\"unloaded\"},Hl.prototype.getBucket=function(t){return this.buckets[t.id]},Hl.prototype.upload=function(t){for(var e in this.buckets){var r=this.buckets[e];r.uploadPending()&&r.upload(t)}var n=t.gl;this.imageAtlas&&!this.imageAtlas.uploaded&&(this.imageAtlasTexture=new Js(t,this.imageAtlas.image,n.RGBA),this.imageAtlas.uploaded=!0),this.glyphAtlasImage&&(this.glyphAtlasTexture=new Js(t,this.glyphAtlasImage,n.ALPHA),this.glyphAtlasImage=null)},Hl.prototype.prepare=function(t){this.imageAtlas&&this.imageAtlas.patchUpdatedImages(t,this.imageAtlasTexture)},Hl.prototype.queryRenderedFeatures=function(t,e,r,n,i,a,o,s,l){return this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData?this.latestFeatureIndex.query({queryGeometry:r,cameraQueryGeometry:n,scale:i,tileSize:this.tileSize,pixelPosMatrix:l,transform:o,params:a,queryPadding:this.queryPadding*s},t,e):{}},Hl.prototype.querySourceFeatures=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData){var r=this.latestFeatureIndex.loadVTLayers(),n=e?e.sourceLayer:\"\",i=r._geojsonTileLayer||r[n];if(i)for(var a=Gr(e&&e.filter),o=this.tileID.canonical,s=o.z,l=o.x,c=o.y,u={z:s,x:l,y:c},h=0;h<i.length;h++){var f=i.feature(h);if(a(new Un(this.tileID.overscaledZ),f)){var p=new Bl(f,s,l,c);p.tile=u,t.push(p)}}}},Hl.prototype.clearMask=function(){this.segments&&(this.segments.destroy(),delete this.segments),this.maskedBoundsBuffer&&(this.maskedBoundsBuffer.destroy(),delete this.maskedBoundsBuffer),this.maskedIndexBuffer&&(this.maskedIndexBuffer.destroy(),delete this.maskedIndexBuffer)},Hl.prototype.setMask=function(t,e){if(!o(this.mask,t)&&(this.mask=t,this.clearMask(),!o(t,{0:!0}))){var r=new ci,n=new Ti;this.segments=new Vi,this.segments.prepareSegment(0,r,n);for(var a=Object.keys(t),s=0;s<a.length;s++){var l=t[+a[s]],c=ha>>l.z,u=new i(l.x*c,l.y*c),h=new i(u.x+c,u.y+c),f=this.segments.prepareSegment(4,r,n);r.emplaceBack(u.x,u.y,u.x,u.y),r.emplaceBack(h.x,u.y,h.x,u.y),r.emplaceBack(u.x,h.y,u.x,h.y),r.emplaceBack(h.x,h.y,h.x,h.y);var p=f.vertexLength;n.emplaceBack(p,p+1,p+2),n.emplaceBack(p+1,p+2,p+3),f.vertexLength+=4,f.primitiveLength+=2}this.maskedBoundsBuffer=e.createVertexBuffer(r,Rl.members),this.maskedIndexBuffer=e.createIndexBuffer(n)}},Hl.prototype.hasData=function(){return\"loaded\"===this.state||\"reloading\"===this.state||\"expired\"===this.state},Hl.prototype.patternsLoaded=function(){return this.imageAtlas&&!!Object.keys(this.imageAtlas.patternPositions).length},Hl.prototype.setExpiryData=function(t){var e=this.expirationTime;if(t.cacheControl){var r=A(t.cacheControl);r[\"max-age\"]&&(this.expirationTime=Date.now()+1e3*r[\"max-age\"])}else t.expires&&(this.expirationTime=new Date(t.expires).getTime());if(this.expirationTime){var n=Date.now(),i=!1;if(this.expirationTime>n)i=!1;else if(e)if(this.expirationTime<e)i=!0;else{var a=this.expirationTime-e;a?this.expirationTime=n+Math.max(a,3e4):i=!0}else i=!0;i?(this.expiredRequestCount++,this.state=\"expired\"):this.expiredRequestCount=0}},Hl.prototype.getExpiryTimeout=function(){if(this.expirationTime)return this.expiredRequestCount?1e3*(1<<Math.min(this.expiredRequestCount-1,31)):Math.min(this.expirationTime-(new Date).getTime(),Math.pow(2,31)-1)},Hl.prototype.setFeatureState=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData&&0!==Object.keys(t).length){var r=this.latestFeatureIndex.loadVTLayers();for(var n in this.buckets){var i=this.buckets[n],a=i.layers[0].sourceLayer||\"_geojsonTileLayer\",o=r[a],s=t[a];o&&s&&0!==Object.keys(s).length&&(i.update(s,o,this.imageAtlas&&this.imageAtlas.patternPositions||{}),e&&e.style&&(this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(n).queryRadius(i))))}}},Hl.prototype.holdingForFade=function(){return void 0!==this.symbolFadeHoldUntil},Hl.prototype.symbolFadeFinished=function(){return!this.symbolFadeHoldUntil||this.symbolFadeHoldUntil<z.now()},Hl.prototype.clearFadeHold=function(){this.symbolFadeHoldUntil=void 0},Hl.prototype.setHoldDuration=function(t){this.symbolFadeHoldUntil=z.now()+t};var Gl=24,Yl={horizontal:1,vertical:2,horizontalOnly:3},Wl=function(){this.text=\"\",this.sectionIndex=[],this.sections=[]};function Xl(t,e,r,n,i,a,o,s,l,c){var u,h=Wl.fromFeature(t,r);c===Yl.vertical&&h.verticalizePunctuation();var f=jn.processBidirectionalText,p=jn.processStyledBidirectionalText;if(f&&1===h.sections.length){u=[];for(var d=0,g=f(h.toString(),tc(h,s,n,e));d<g.length;d+=1){var v=g[d],m=new Wl;m.text=v,m.sections=h.sections;for(var y=0;y<v.length;y++)m.sectionIndex.push(0);u.push(m)}}else if(p){u=[];for(var x=0,b=p(h.text,h.sectionIndex,tc(h,s,n,e));x<b.length;x+=1){var _=b[x],w=new Wl;w.text=_[0],w.sectionIndex=_[1],w.sections=h.sections,u.push(w)}}else u=function(t,e){for(var r=[],n=t.text,i=0,a=0,o=e;a<o.length;a+=1){var s=o[a];r.push(t.substring(i,s)),i=s}return i<n.length&&r.push(t.substring(i,n.length)),r}(h,tc(h,s,n,e));var k=[],T={positionedGlyphs:k,text:h.toString(),top:l[1],bottom:l[1],left:l[0],right:l[0],writingMode:c,lineCount:u.length};return function(t,e,r,n,i,a,o,s){for(var l=0,c=-17,u=0,h=t.positionedGlyphs,f=\"right\"===a?1:\"left\"===a?0:.5,p=0,d=r;p<d.length;p+=1){var g=d[p];g.trim();var v=g.getMaxScale();if(g.length()){for(var m=h.length,y=0;y<g.length();y++){var x=g.getSection(y),b=g.getCharCode(y),_=24*(v-x.scale),w=e[x.fontStack],k=w&&w[b];k&&(On(b)&&o!==Yl.horizontal?(h.push({glyph:b,x:l,y:_,vertical:!0,scale:x.scale,fontStack:x.fontStack}),l+=Gl*x.scale+s):(h.push({glyph:b,x:l,y:c+_,vertical:!1,scale:x.scale,fontStack:x.fontStack}),l+=k.metrics.advance*x.scale+s))}if(h.length!==m){var T=l-s;u=Math.max(T,u),rc(h,e,m,h.length-1,f)}l=0,c+=n*v}else c+=n}var A=ec(i),M=A.horizontalAlign,S=A.verticalAlign;!function(t,e,r,n,i,a,o){for(var s=(e-r)*i,l=(-n*o+.5)*a,c=0;c<t.length;c++)t[c].x+=s,t[c].y+=l}(h,f,M,S,u,n,r.length);var E=c- -17;t.top+=-S*E,t.bottom=t.top+E,t.left+=-M*u,t.right=t.left+u}(T,e,u,i,a,o,c,s),!!k.length&&T}Wl.fromFeature=function(t,e){for(var r=new Wl,n=0;n<t.sections.length;n++){var i=t.sections[n];r.sections.push({scale:i.scale||1,fontStack:i.fontStack||e}),r.text+=i.text;for(var a=0;a<i.text.length;a++)r.sectionIndex.push(n)}return r},Wl.prototype.length=function(){return this.text.length},Wl.prototype.getSection=function(t){return this.sections[this.sectionIndex[t]]},Wl.prototype.getCharCode=function(t){return this.text.charCodeAt(t)},Wl.prototype.verticalizePunctuation=function(){this.text=function(t){for(var e=\"\",r=0;r<t.length;r++){var n=t.charCodeAt(r+1)||null,i=t.charCodeAt(r-1)||null;n&&zn(n)&&!xs[t[r+1]]||i&&zn(i)&&!xs[t[r-1]]||!xs[t[r]]?e+=t[r]:e+=xs[t[r]]}return e}(this.text)},Wl.prototype.trim=function(){for(var t=0,e=0;e<this.text.length&&Zl[this.text.charCodeAt(e)];e++)t++;for(var r=this.text.length,n=this.text.length-1;n>=0&&n>=t&&Zl[this.text.charCodeAt(n)];n--)r--;this.text=this.text.substring(t,r),this.sectionIndex=this.sectionIndex.slice(t,r)},Wl.prototype.substring=function(t,e){var r=new Wl;return r.text=this.text.substring(t,e),r.sectionIndex=this.sectionIndex.slice(t,e),r.sections=this.sections,r},Wl.prototype.toString=function(){return this.text},Wl.prototype.getMaxScale=function(){var t=this;return this.sectionIndex.reduce(function(e,r){return Math.max(e,t.sections[r].scale)},0)};var Zl={9:!0,10:!0,11:!0,12:!0,13:!0,32:!0},Jl={};function Kl(t,e,r,n){var i=Math.pow(t-e,2);return n?t<e?i/2:2*i:i+Math.abs(r)*r}function $l(t,e,r){var n=0;return 10===t&&(n-=1e4),r&&(n+=150),40!==t&&65288!==t||(n+=50),41!==e&&65289!==e||(n+=50),n}function Ql(t,e,r,n,i,a){for(var o=null,s=Kl(e,r,i,a),l=0,c=n;l<c.length;l+=1){var u=c[l],h=Kl(e-u.x,r,i,a)+u.badness;h<=s&&(o=u,s=h)}return{index:t,x:e,priorBreak:o,badness:s}}function tc(t,e,r,n){if(!r)return[];if(!t)return[];for(var i,a=[],o=function(t,e,r,n){for(var i=0,a=0;a<t.length();a++){var o=t.getSection(a),s=n[o.fontStack],l=s&&s[t.getCharCode(a)];l&&(i+=l.metrics.advance*o.scale+e)}return i/Math.max(1,Math.ceil(i/r))}(t,e,r,n),s=t.text.indexOf(\"\\u200b\")>=0,l=0,c=0;c<t.length();c++){var u=t.getSection(c),h=t.getCharCode(c),f=n[u.fontStack],p=f&&f[h];if(p&&!Zl[h]&&(l+=p.metrics.advance*u.scale+e),c<t.length()-1){var d=!((i=h)<11904||!(En[\"Bopomofo Extended\"](i)||En.Bopomofo(i)||En[\"CJK Compatibility Forms\"](i)||En[\"CJK Compatibility Ideographs\"](i)||En[\"CJK Compatibility\"](i)||En[\"CJK Radicals Supplement\"](i)||En[\"CJK Strokes\"](i)||En[\"CJK Symbols and Punctuation\"](i)||En[\"CJK Unified Ideographs Extension A\"](i)||En[\"CJK Unified Ideographs\"](i)||En[\"Enclosed CJK Letters and Months\"](i)||En[\"Halfwidth and Fullwidth Forms\"](i)||En.Hiragana(i)||En[\"Ideographic Description Characters\"](i)||En[\"Kangxi Radicals\"](i)||En[\"Katakana Phonetic Extensions\"](i)||En.Katakana(i)||En[\"Vertical Forms\"](i)||En[\"Yi Radicals\"](i)||En[\"Yi Syllables\"](i)));(Jl[h]||d)&&a.push(Ql(c+1,l,o,a,$l(h,t.getCharCode(c+1),d&&s),!1))}}return function t(e){return e?t(e.priorBreak).concat(e.index):[]}(Ql(t.length(),l,o,a,0,!0))}function ec(t){var e=.5,r=.5;switch(t){case\"right\":case\"top-right\":case\"bottom-right\":e=1;break;case\"left\":case\"top-left\":case\"bottom-left\":e=0}switch(t){case\"bottom\":case\"bottom-right\":case\"bottom-left\":r=1;break;case\"top\":case\"top-right\":case\"top-left\":r=0}return{horizontalAlign:e,verticalAlign:r}}function rc(t,e,r,n,i){if(i){var a=t[n],o=e[a.fontStack],s=o&&o[a.glyph];if(s)for(var l=s.metrics.advance*a.scale,c=(t[n].x+l)*i,u=r;u<=n;u++)t[u].x-=c}}function nc(t,e,r){var n=ec(r),i=n.horizontalAlign,a=n.verticalAlign,o=e[0],s=e[1],l=o-t.displaySize[0]*i,c=l+t.displaySize[0],u=s-t.displaySize[1]*a;return{image:t,top:u,bottom:u+t.displaySize[1],left:l,right:c}}function ic(t,e,r,n,i){if(void 0===e.segment)return!0;for(var a=e,o=e.segment+1,s=0;s>-r/2;){if(--o<0)return!1;s-=t[o].dist(a),a=t[o]}s+=t[o].dist(t[o+1]),o++;for(var l=[],c=0;s<r/2;){var u=t[o-1],h=t[o],f=t[o+1];if(!f)return!1;var p=u.angleTo(h)-h.angleTo(f);for(p=Math.abs((p+3*Math.PI)%(2*Math.PI)-Math.PI),l.push({distance:s,angleDelta:p}),c+=p;s-l[0].distance>n;)c-=l.shift().angleDelta;if(c>i)return!1;o++,s+=h.dist(f)}return!0}function ac(t){for(var e=0,r=0;r<t.length-1;r++)e+=t[r].dist(t[r+1]);return e}function oc(t,e,r){return t?.6*e*r:0}function sc(t,e){return Math.max(t?t.right-t.left:0,e?e.right-e.left:0)}function lc(t,e,r,n,i,a){for(var o=oc(r,i,a),s=sc(r,n)*a,l=0,c=ac(t)/2,u=0;u<t.length-1;u++){var h=t[u],f=t[u+1],p=h.dist(f);if(l+p>c){var d=(c-l)/p,g=Ee(h.x,f.x,d),v=Ee(h.y,f.y,d),m=new bs(g,v,f.angleTo(h),u);return m._round(),!o||ic(t,m,s,o,e)?m:void 0}l+=p}}function cc(t,e,r,n,i,a,o,s,l){var c=oc(n,a,o),u=sc(n,i),h=u*o,f=0===t[0].x||t[0].x===l||0===t[0].y||t[0].y===l;return e-h<e/4&&(e=h+e/4),function t(e,r,n,i,a,o,s,l,c){for(var u=o/2,h=ac(e),f=0,p=r-n,d=[],g=0;g<e.length-1;g++){for(var v=e[g],m=e[g+1],y=v.dist(m),x=m.angleTo(v);p+n<f+y;){var b=((p+=n)-f)/y,_=Ee(v.x,m.x,b),w=Ee(v.y,m.y,b);if(_>=0&&_<c&&w>=0&&w<c&&p-u>=0&&p+u<=h){var k=new bs(_,w,x,g);k._round(),i&&!ic(e,k,o,i,a)||d.push(k)}}f+=y}return l||d.length||s||(d=t(e,f/2,n,i,a,o,s,!0,c)),d}(t,f?e/2*s%e:(u/2+2*a)*o*s%e,e,c,r,h,f,!1,l)}Jl[10]=!0,Jl[32]=!0,Jl[38]=!0,Jl[40]=!0,Jl[41]=!0,Jl[43]=!0,Jl[45]=!0,Jl[47]=!0,Jl[173]=!0,Jl[183]=!0,Jl[8203]=!0,Jl[8208]=!0,Jl[8211]=!0,Jl[8231]=!0;var uc=function(t,e,r,n,a,o,s,l,c,u,h,f){var p=s.top*l-c,d=s.bottom*l+c,g=s.left*l-c,v=s.right*l+c;if(this.boxStartIndex=t.length,u){var m=d-p,y=v-g;m>0&&(m=Math.max(10*l,m),this._addLineCollisionCircles(t,e,r,r.segment,y,m,n,a,o,h))}else{if(f){var x=new i(g,p),b=new i(v,p),_=new i(g,d),w=new i(v,d),k=f*Math.PI/180;x._rotate(k),b._rotate(k),_._rotate(k),w._rotate(k),g=Math.min(x.x,b.x,_.x,w.x),v=Math.max(x.x,b.x,_.x,w.x),p=Math.min(x.y,b.y,_.y,w.y),d=Math.max(x.y,b.y,_.y,w.y)}t.emplaceBack(r.x,r.y,g,p,v,d,n,a,o,0,0)}this.boxEndIndex=t.length};uc.prototype._addLineCollisionCircles=function(t,e,r,n,i,a,o,s,l,c){var u=a/2,h=Math.floor(i/u)||1,f=1+.4*Math.log(c)/Math.LN2,p=Math.floor(h*f/2),d=-a/2,g=r,v=n+1,m=d,y=-i/2,x=y-i/4;do{if(--v<0){if(m>y)return;v=0;break}m-=e[v].dist(g),g=e[v]}while(m>x);for(var b=e[v].dist(e[v+1]),_=-p;_<h+p;_++){var w=_*u,k=y+w;if(w<0&&(k+=w),w>i&&(k+=w-i),!(k<m)){for(;m+b<k;){if(m+=b,++v+1>=e.length)return;b=e[v].dist(e[v+1])}var T=k-m,A=e[v],M=e[v+1].sub(A)._unit()._mult(T)._add(A)._round(),S=Math.abs(k-d)<u?0:.8*(k-d);t.emplaceBack(M.x,M.y,-a/2,-a/2,a/2,a/2,o,s,l,a/2,S)}}};var hc=function(t,e){if(void 0===t&&(t=[]),void 0===e&&(e=fc),this.data=t,this.length=this.data.length,this.compare=e,this.length>0)for(var r=(this.length>>1)-1;r>=0;r--)this._down(r)};function fc(t,e){return t<e?-1:t>e?1:0}function pc(t,e,r){void 0===e&&(e=1),void 0===r&&(r=!1);for(var n=1/0,a=1/0,o=-1/0,s=-1/0,l=t[0],c=0;c<l.length;c++){var u=l[c];(!c||u.x<n)&&(n=u.x),(!c||u.y<a)&&(a=u.y),(!c||u.x>o)&&(o=u.x),(!c||u.y>s)&&(s=u.y)}var h=o-n,f=s-a,p=Math.min(h,f),d=p/2,g=new hc([],dc);if(0===p)return new i(n,a);for(var v=n;v<o;v+=p)for(var m=a;m<s;m+=p)g.push(new gc(v+d,m+d,d,t));for(var y=function(t){for(var e=0,r=0,n=0,i=t[0],a=0,o=i.length,s=o-1;a<o;s=a++){var l=i[a],c=i[s],u=l.x*c.y-c.x*l.y;r+=(l.x+c.x)*u,n+=(l.y+c.y)*u,e+=3*u}return new gc(r/e,n/e,0,t)}(t),x=g.length;g.length;){var b=g.pop();(b.d>y.d||!y.d)&&(y=b,r&&console.log(\"found best %d after %d probes\",Math.round(1e4*b.d)/1e4,x)),b.max-y.d<=e||(d=b.h/2,g.push(new gc(b.p.x-d,b.p.y-d,d,t)),g.push(new gc(b.p.x+d,b.p.y-d,d,t)),g.push(new gc(b.p.x-d,b.p.y+d,d,t)),g.push(new gc(b.p.x+d,b.p.y+d,d,t)),x+=4)}return r&&(console.log(\"num probes: \"+x),console.log(\"best distance: \"+y.d)),y.p}function dc(t,e){return e.max-t.max}function gc(t,e,r,n){this.p=new i(t,e),this.h=r,this.d=function(t,e){for(var r=!1,n=1/0,i=0;i<e.length;i++)for(var a=e[i],o=0,s=a.length,l=s-1;o<s;l=o++){var c=a[o],u=a[l];c.y>t.y!=u.y>t.y&&t.x<(u.x-c.x)*(t.y-c.y)/(u.y-c.y)+c.x&&(r=!r),n=Math.min(n,ka(t,c,u))}return(r?1:-1)*Math.sqrt(n)}(this.p,n),this.max=this.d+this.h*Math.SQRT2}hc.prototype.push=function(t){this.data.push(t),this.length++,this._up(this.length-1)},hc.prototype.pop=function(){if(0!==this.length){var t=this.data[0];return this.length--,this.length>0&&(this.data[0]=this.data[this.length],this._down(0)),this.data.pop(),t}},hc.prototype.peek=function(){return this.data[0]},hc.prototype._up=function(t){for(var e=this.data,r=this.compare,n=e[t];t>0;){var i=t-1>>1,a=e[i];if(r(n,a)>=0)break;e[t]=a,t=i}e[t]=n},hc.prototype._down=function(t){for(var e=this.data,r=this.compare,n=this.length>>1,i=e[t];t<n;){var a=1+(t<<1),o=e[a],s=a+1;if(s<this.length&&r(e[s],o)<0&&(a=s,o=e[s]),r(o,i)>=0)break;e[t]=o,t=a}e[t]=i};var vc=e(function(t){t.exports=function(t,e){var r,n,i,a,o,s,l,c;for(r=3&t.length,n=t.length-r,i=e,o=3432918353,s=461845907,c=0;c<n;)l=255&t.charCodeAt(c)|(255&t.charCodeAt(++c))<<8|(255&t.charCodeAt(++c))<<16|(255&t.charCodeAt(++c))<<24,++c,i=27492+(65535&(a=5*(65535&(i=(i^=l=(65535&(l=(l=(65535&l)*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295)<<13|i>>>19))+((5*(i>>>16)&65535)<<16)&4294967295))+((58964+(a>>>16)&65535)<<16);switch(l=0,r){case 3:l^=(255&t.charCodeAt(c+2))<<16;case 2:l^=(255&t.charCodeAt(c+1))<<8;case 1:i^=l=(65535&(l=(l=(65535&(l^=255&t.charCodeAt(c)))*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295}return i^=t.length,i=2246822507*(65535&(i^=i>>>16))+((2246822507*(i>>>16)&65535)<<16)&4294967295,i=3266489909*(65535&(i^=i>>>13))+((3266489909*(i>>>16)&65535)<<16)&4294967295,(i^=i>>>16)>>>0}}),mc=e(function(t){t.exports=function(t,e){for(var r,n=t.length,i=e^n,a=0;n>=4;)r=1540483477*(65535&(r=255&t.charCodeAt(a)|(255&t.charCodeAt(++a))<<8|(255&t.charCodeAt(++a))<<16|(255&t.charCodeAt(++a))<<24))+((1540483477*(r>>>16)&65535)<<16),i=1540483477*(65535&i)+((1540483477*(i>>>16)&65535)<<16)^(r=1540483477*(65535&(r^=r>>>24))+((1540483477*(r>>>16)&65535)<<16)),n-=4,++a;switch(n){case 3:i^=(255&t.charCodeAt(a+2))<<16;case 2:i^=(255&t.charCodeAt(a+1))<<8;case 1:i=1540483477*(65535&(i^=255&t.charCodeAt(a)))+((1540483477*(i>>>16)&65535)<<16)}return i=1540483477*(65535&(i^=i>>>13))+((1540483477*(i>>>16)&65535)<<16),(i^=i>>>15)>>>0}}),yc=vc,xc=vc,bc=mc;yc.murmur3=xc,yc.murmur2=bc;var _c=7;function wc(t,e){var r=0,n=0,i=e/Math.sqrt(2);switch(t){case\"top-right\":case\"top-left\":n=i-_c;break;case\"bottom-right\":case\"bottom-left\":n=-i+_c;break;case\"bottom\":n=-e+_c;break;case\"top\":n=e-_c}switch(t){case\"top-right\":case\"bottom-right\":r=-i;break;case\"top-left\":case\"bottom-left\":r=i;break;case\"left\":r=e;break;case\"right\":r=-e}return[r,n]}function kc(t){switch(t){case\"right\":case\"top-right\":case\"bottom-right\":return\"right\";case\"left\":case\"top-left\":case\"bottom-left\":return\"left\"}return\"center\"}function Tc(t,e,r,n,a,o,s){var l=o.layoutTextSize.evaluate(e,{}),c=o.layoutIconSize.evaluate(e,{}),u=o.textMaxSize.evaluate(e,{});void 0===u&&(u=l);var h=t.layers[0].layout,f=h.get(\"icon-offset\").evaluate(e,{}),p=Sc(r.horizontal),d=l/24,g=t.tilePixelRatio*d,v=t.tilePixelRatio*u/24,m=t.tilePixelRatio*c,y=t.tilePixelRatio*h.get(\"symbol-spacing\"),x=h.get(\"text-padding\")*t.tilePixelRatio,b=h.get(\"icon-padding\")*t.tilePixelRatio,_=h.get(\"text-max-angle\")/180*Math.PI,k=\"map\"===h.get(\"text-rotation-alignment\")&&\"point\"!==h.get(\"symbol-placement\"),T=\"map\"===h.get(\"icon-rotation-alignment\")&&\"point\"!==h.get(\"symbol-placement\"),A=h.get(\"symbol-placement\"),M=y/2,S=function(l,c){c.x<0||c.x>=ha||c.y<0||c.y>=ha||function(t,e,r,n,a,o,s,l,c,u,h,f,p,d,g,v,m,y,x,b,_){var k,T,A=t.addToLineVertexArray(e,r),M=0,S=0,E=0,C={},L=yc(\"\"),P=(o.layout.get(\"text-radial-offset\").evaluate(x,{})||0)*Gl;for(var O in n.horizontal){var z=n.horizontal[O];if(!k){L=yc(z.text);var I=o.layout.get(\"text-rotate\").evaluate(x,{});k=new uc(s,r,e,l,c,u,z,h,f,p,t.overscaling,I)}var D=1===z.lineCount;if(S+=Mc(t,e,z,o,p,x,d,A,n.vertical?Yl.horizontal:Yl.horizontalOnly,D?Object.keys(n.horizontal):[O],C,b,_),D)break}n.vertical&&(E+=Mc(t,e,n.vertical,o,p,x,d,A,Yl.vertical,[\"vertical\"],C,b,_));var R=k?k.boxStartIndex:t.collisionBoxArray.length,F=k?k.boxEndIndex:t.collisionBoxArray.length;if(a){var B=function(t,e,r,n,a,o){var s,l,c,u,h=e.image,f=r.layout,p=e.top-1/h.pixelRatio,d=e.left-1/h.pixelRatio,g=e.bottom+1/h.pixelRatio,v=e.right+1/h.pixelRatio;if(\"none\"!==f.get(\"icon-text-fit\")&&a){var m=v-d,y=g-p,x=f.get(\"text-size\").evaluate(o,{})/24,b=a.left*x,_=a.right*x,w=a.top*x,k=_-b,T=a.bottom*x-w,A=f.get(\"icon-text-fit-padding\")[0],M=f.get(\"icon-text-fit-padding\")[1],S=f.get(\"icon-text-fit-padding\")[2],E=f.get(\"icon-text-fit-padding\")[3],C=\"width\"===f.get(\"icon-text-fit\")?.5*(T-y):0,L=\"height\"===f.get(\"icon-text-fit\")?.5*(k-m):0,P=\"width\"===f.get(\"icon-text-fit\")||\"both\"===f.get(\"icon-text-fit\")?k:m,O=\"height\"===f.get(\"icon-text-fit\")||\"both\"===f.get(\"icon-text-fit\")?T:y;s=new i(b+L-E,w+C-A),l=new i(b+L+M+P,w+C-A),c=new i(b+L+M+P,w+C+S+O),u=new i(b+L-E,w+C+S+O)}else s=new i(d,p),l=new i(v,p),c=new i(v,g),u=new i(d,g);var z=r.layout.get(\"icon-rotate\").evaluate(o,{})*Math.PI/180;if(z){var I=Math.sin(z),D=Math.cos(z),R=[D,-I,I,D];s._matMult(R),l._matMult(R),u._matMult(R),c._matMult(R)}return[{tl:s,tr:l,bl:u,br:c,tex:h.paddedRect,writingMode:void 0,glyphOffset:[0,0]}]}(0,a,o,0,Sc(n.horizontal),x),N=o.layout.get(\"icon-rotate\").evaluate(x,{});T=new uc(s,r,e,l,c,u,a,g,v,!1,t.overscaling,N),M=4*B.length;var j=t.iconSizeData,U=null;\"source\"===j.kind?(U=[_s*o.layout.get(\"icon-size\").evaluate(x,{})])[0]>Ac&&w(t.layerIds[0]+': Value for \"icon-size\" is >= 256. Reduce your \"icon-size\".'):\"composite\"===j.kind&&((U=[_s*_.compositeIconSizes[0].evaluate(x,{}),_s*_.compositeIconSizes[1].evaluate(x,{})])[0]>Ac||U[1]>Ac)&&w(t.layerIds[0]+': Value for \"icon-size\" is >= 256. Reduce your \"icon-size\".'),t.addSymbols(t.icon,B,U,y,m,x,!1,e,A.lineStartIndex,A.lineLength)}var V=T?T.boxStartIndex:t.collisionBoxArray.length,q=T?T.boxEndIndex:t.collisionBoxArray.length;t.glyphOffsetArray.length>=Os.MAX_GLYPHS&&w(\"Too many glyphs being rendered in a tile. See https://github.com/mapbox/mapbox-gl-js/issues/2907\"),t.symbolInstances.emplaceBack(e.x,e.y,C.right>=0?C.right:-1,C.center>=0?C.center:-1,C.left>=0?C.left:-1,C.vertical||-1,L,R,F,V,q,l,S,E,M,0,h,P)}(t,c,l,r,n,t.layers[0],t.collisionBoxArray,e.index,e.sourceLayerIndex,t.index,g,x,k,s,m,b,T,f,e,a,o)};if(\"line\"===A)for(var E=0,C=function(t,e,r,n,a){for(var o=[],s=0;s<t.length;s++)for(var l=t[s],c=void 0,u=0;u<l.length-1;u++){var h=l[u],f=l[u+1];h.x<0&&f.x<0||(h.x<0?h=new i(0,h.y+(f.y-h.y)*((0-h.x)/(f.x-h.x)))._round():f.x<0&&(f=new i(0,h.y+(f.y-h.y)*((0-h.x)/(f.x-h.x)))._round()),h.y<0&&f.y<0||(h.y<0?h=new i(h.x+(f.x-h.x)*((0-h.y)/(f.y-h.y)),0)._round():f.y<0&&(f=new i(h.x+(f.x-h.x)*((0-h.y)/(f.y-h.y)),0)._round()),h.x>=n&&f.x>=n||(h.x>=n?h=new i(n,h.y+(f.y-h.y)*((n-h.x)/(f.x-h.x)))._round():f.x>=n&&(f=new i(n,h.y+(f.y-h.y)*((n-h.x)/(f.x-h.x)))._round()),h.y>=a&&f.y>=a||(h.y>=a?h=new i(h.x+(f.x-h.x)*((a-h.y)/(f.y-h.y)),a)._round():f.y>=a&&(f=new i(h.x+(f.x-h.x)*((a-h.y)/(f.y-h.y)),a)._round()),c&&h.equals(c[c.length-1])||(c=[h],o.push(c)),c.push(f)))))}return o}(e.geometry,0,0,ha,ha);E<C.length;E+=1)for(var L=C[E],P=0,O=cc(L,y,_,r.vertical||p,n,24,v,t.overscaling,ha);P<O.length;P+=1){var z=O[P];p&&Ec(t,p.text,M,z)||S(L,z)}else if(\"line-center\"===A)for(var I=0,D=e.geometry;I<D.length;I+=1){var R=D[I];if(R.length>1){var F=lc(R,_,r.vertical||p,n,24,v);F&&S(R,F)}}else if(\"Polygon\"===e.type)for(var B=0,N=Mo(e.geometry,0);B<N.length;B+=1){var j=N[B],U=pc(j,16);S(j[0],new bs(U.x,U.y,0))}else if(\"LineString\"===e.type)for(var V=0,q=e.geometry;V<q.length;V+=1){var H=q[V];S(H,new bs(H[0].x,H[0].y,0))}else if(\"Point\"===e.type)for(var G=0,Y=e.geometry;G<Y.length;G+=1)for(var W=0,X=Y[G];W<X.length;W+=1){var Z=X[W];S([Z],new bs(Z.x,Z.y,0))}}var Ac=65535;function Mc(t,e,r,n,a,o,s,l,c,u,h,f,p){var d=function(t,e,r,n,a,o,s){for(var l=n.layout.get(\"text-rotate\").evaluate(o,{})*Math.PI/180,c=e.positionedGlyphs,u=[],h=0;h<c.length;h++){var f=c[h],p=s[f.fontStack],d=p&&p[f.glyph];if(d){var g=d.rect;if(g){var v=bl+1,m=d.metrics.advance*f.scale/2,y=a?[f.x+m,f.y]:[0,0],x=a?[0,0]:[f.x+m+r[0],f.y+r[1]],b=(d.metrics.left-v)*f.scale-m+x[0],_=(-d.metrics.top-v)*f.scale+x[1],w=b+g.w*f.scale,k=_+g.h*f.scale,T=new i(b,_),A=new i(w,_),M=new i(b,k),S=new i(w,k);if(a&&f.vertical){var E=new i(-m,m),C=-Math.PI/2,L=new i(5,0);T._rotateAround(C,E)._add(L),A._rotateAround(C,E)._add(L),M._rotateAround(C,E)._add(L),S._rotateAround(C,E)._add(L)}if(l){var P=Math.sin(l),O=Math.cos(l),z=[O,-P,P,O];T._matMult(z),A._matMult(z),M._matMult(z),S._matMult(z)}u.push({tl:T,tr:A,bl:M,br:S,tex:g,writingMode:e.writingMode,glyphOffset:y})}}}return u}(0,r,s,n,a,o,f),g=t.textSizeData,v=null;\"source\"===g.kind?(v=[_s*n.layout.get(\"text-size\").evaluate(o,{})])[0]>Ac&&w(t.layerIds[0]+': Value for \"text-size\" is >= 256. Reduce your \"text-size\".'):\"composite\"===g.kind&&((v=[_s*p.compositeTextSizes[0].evaluate(o,{}),_s*p.compositeTextSizes[1].evaluate(o,{})])[0]>Ac||v[1]>Ac)&&w(t.layerIds[0]+': Value for \"text-size\" is >= 256. Reduce your \"text-size\".'),t.addSymbols(t.text,d,v,s,a,o,c,e,l.lineStartIndex,l.lineLength);for(var m=0,y=u;m<y.length;m+=1)h[y[m]]=t.text.placedSymbolArray.length-1;return 4*d.length}function Sc(t){for(var e in t)return t[e];return null}function Ec(t,e,r,n){var i=t.compareText;if(e in i){for(var a=i[e],o=a.length-1;o>=0;o--)if(n.dist(a[o])<r)return!0}else i[e]=[];return i[e].push(n),!1}t.Actor=_l,t.AlphaImage=qa,t.CanonicalTileID=Pl,t.CollisionBoxArray=Li,t.Color=ne,t.DEMData=Dl,t.DataConstantProperty=Jn,t.DictionaryCoder=Fl,t.EXTENT=ha,t.ErrorEvent=Ot,t.EvaluationParameters=Un,t.Event=Pt,t.Evented=zt,t.FeatureIndex=Ul,t.FillBucket=Lo,t.FillExtrusionBucket=Yo,t.ImageAtlas=Gs,t.ImagePosition=qs,t.LineBucket=os,t.LngLat=Tl,t.LngLatBounds=kl,t.MercatorCoordinate=Ll,t.ONE_EM=Gl,t.OverscaledTileID=zl,t.Point=i,t.Point$1=i,t.ProgramConfiguration=sa,t.Properties=ei,t.Protobuf=Qs,t.RGBAImage=Ha,t.RequestManager=j,t.ResourceType=yt,t.SegmentVector=Vi,t.SourceFeatureState=jl,t.StructArrayLayout1ui2=Mi,t.StructArrayLayout2i4=li,t.StructArrayLayout2ui4=Ai,t.StructArrayLayout3ui6=Ti,t.StructArrayLayout4i8=ci,t.SymbolBucket=Os,t.Texture=Js,t.Tile=Hl,t.Transitionable=Hn,t.Uniform1f=Xi,t.Uniform1i=Wi,t.Uniform2f=Zi,t.Uniform3f=Ji,t.Uniform4f=Ki,t.UniformColor=$i,t.UniformMatrix4f=ta,t.UnwrappedTileID=Ol,t.ValidationError=Dt,t.WritingMode=Yl,t.ZoomHistory=Sn,t.addDynamicAttributes=Cs,t.asyncAll=function(t,e,r){if(!t.length)return r(null,[]);var n=t.length,i=new Array(t.length),a=null;t.forEach(function(t,o){e(t,function(t,e){t&&(a=t),i[o]=e,0==--n&&r(a,i)})})},t.bezier=s,t.bindAll=v,t.browser=z,t.cacheEntryPossiblyAdded=function(t){++mt>dt&&(t.send(\"enforceCacheSizeLimit\",pt),mt=0)},t.clamp=c,t.clearTileCache=function(t){var e=self.caches.delete(ft);t&&e.catch(t).then(function(){return t()})},t.clone=function(t){var e=new Pa(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e},t.clone$1=b,t.config=I,t.create=function(){var t=new Pa(16);return Pa!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=0,t[12]=0,t[13]=0,t[14]=0),t[0]=1,t[5]=1,t[10]=1,t[15]=1,t},t.create$1=Oa,t.create$2=function(){var t=new Pa(4);return Pa!=Float32Array&&(t[1]=0,t[2]=0),t[0]=1,t[3]=1,t},t.createCommonjsModule=e,t.createExpression=Or,t.createLayout=oi,t.createStyleLayer=function(t){return\"custom\"===t.type?new js(t):new Us[t.type](t)},t.deepEqual=o,t.ease=l,t.emitValidationErrors=mn,t.endsWith=m,t.enforceCacheSizeLimit=function(t){self.caches&&self.caches.open(ft).then(function(e){e.keys().then(function(r){for(var n=0;n<r.length-t;n++)e.delete(r[n])})})},t.evaluateRadialOffset=wc,t.evaluateSizeForFeature=ks,t.evaluateSizeForZoom=Ts,t.evented=Nn,t.extend=h,t.featureFilter=Gr,t.filterObject=x,t.fromRotation=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=r,t[2]=0,t[3]=-r,t[4]=n,t[5]=0,t[6]=0,t[7]=0,t[8]=1,t},t.getAnchorAlignment=ec,t.getAnchorJustification=kc,t.getArrayBuffer=Mt,t.getImage=Et,t.getJSON=function(t,e){return At(h(t,{type:\"json\"}),e)},t.getReferrer=_t,t.getVideo=function(t,e){var r,n,i=self.document.createElement(\"video\");i.muted=!0,i.onloadstart=function(){e(null,i)};for(var a=0;a<t.length;a++){var o=self.document.createElement(\"source\");r=t[a],n=void 0,(n=self.document.createElement(\"a\")).href=r,(n.protocol!==self.document.location.protocol||n.host!==self.document.location.host)&&(i.crossOrigin=\"Anonymous\"),o.src=t[a],i.appendChild(o)}return{cancel:function(){}}},t.identity=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t},t.invert=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],h=e[9],f=e[10],p=e[11],d=e[12],g=e[13],v=e[14],m=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,k=i*c-a*l,T=u*g-h*d,A=u*v-f*d,M=u*m-p*d,S=h*v-f*g,E=h*m-p*g,C=f*m-p*v,L=y*C-x*E+b*S+_*M-w*A+k*T;return L?(L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(i*E-n*C-a*S)*L,t[2]=(g*k-v*w+m*_)*L,t[3]=(f*w-h*k-p*_)*L,t[4]=(l*M-o*C-c*A)*L,t[5]=(r*C-i*M+a*A)*L,t[6]=(v*b-d*k-m*x)*L,t[7]=(u*k-f*b+p*x)*L,t[8]=(o*E-s*M+c*T)*L,t[9]=(n*M-r*E-a*T)*L,t[10]=(d*w-g*b+m*y)*L,t[11]=(h*b-u*w-p*y)*L,t[12]=(s*A-o*S-l*T)*L,t[13]=(r*S-n*A+i*T)*L,t[14]=(g*x-d*_-v*y)*L,t[15]=(u*_-h*x+f*y)*L,t):null},t.isChar=En,t.isMapboxURL=q,t.keysDifference=function(t,e){var r=[];for(var n in t)n in e||r.push(n);return r},t.makeRequest=At,t.mapObject=y,t.mercatorXfromLng=Ml,t.mercatorYfromLat=Sl,t.mercatorZfromAltitude=El,t.multiply=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],g=e[12],v=e[13],m=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*h+w*g,t[1]=x*i+b*l+_*f+w*v,t[2]=x*a+b*c+_*p+w*m,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*h+w*g,t[5]=x*i+b*l+_*f+w*v,t[6]=x*a+b*c+_*p+w*m,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*h+w*g,t[9]=x*i+b*l+_*f+w*v,t[10]=x*a+b*c+_*p+w*m,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*h+w*g,t[13]=x*i+b*l+_*f+w*v,t[14]=x*a+b*c+_*p+w*m,t[15]=x*o+b*u+_*d+w*y,t},t.mvt=Vo,t.number=Ee,t.ortho=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t},t.parseGlyphPBF=function(t){return new Qs(t).readFields(ml,[])},t.pbf=Qs,t.performSymbolLayout=function(t,e,r,n,i,a){t.createArrays();var o=512*t.overscaling;t.tilePixelRatio=ha/o,t.compareText={},t.iconsNeedLinear=!1;var s=t.layers[0].layout,l=t.layers[0]._unevaluatedLayout._values,c={};if(\"composite\"===t.textSizeData.kind){var u=t.textSizeData,h=u.minZoom,f=u.maxZoom;c.compositeTextSizes=[l[\"text-size\"].possiblyEvaluate(new Un(h)),l[\"text-size\"].possiblyEvaluate(new Un(f))]}if(\"composite\"===t.iconSizeData.kind){var p=t.iconSizeData,d=p.minZoom,g=p.maxZoom;c.compositeIconSizes=[l[\"icon-size\"].possiblyEvaluate(new Un(d)),l[\"icon-size\"].possiblyEvaluate(new Un(g))]}c.layoutTextSize=l[\"text-size\"].possiblyEvaluate(new Un(t.zoom+1)),c.layoutIconSize=l[\"icon-size\"].possiblyEvaluate(new Un(t.zoom+1)),c.textMaxSize=l[\"text-size\"].possiblyEvaluate(new Un(18));for(var v=s.get(\"text-line-height\")*Gl,m=\"map\"===s.get(\"text-rotation-alignment\")&&\"point\"!==s.get(\"symbol-placement\"),y=s.get(\"text-keep-upright\"),x=0,b=t.features;x<b.length;x+=1){var _=b[x],k=s.get(\"text-font\").evaluate(_,{}).join(\",\"),T=r,A={horizontal:{},vertical:void 0},M=_.text,S=[0,0];if(M){var E=M.toString(),C=s.get(\"text-letter-spacing\").evaluate(_,{})*Gl,L=Ln(E)?C:0,P=s.get(\"text-anchor\").evaluate(_,{}),O=s.get(\"text-variable-anchor\"),z=s.get(\"text-radial-offset\").evaluate(_,{});O||(S=z?wc(P,z*Gl):s.get(\"text-offset\").evaluate(_,{}).map(function(t){return t*Gl}));var I=m?\"center\":s.get(\"text-justify\").evaluate(_,{}),D=\"point\"===s.get(\"symbol-placement\")?s.get(\"text-max-width\").evaluate(_,{})*Gl:0;if(!m&&O)for(var R=\"auto\"===I?O.map(function(t){return kc(t)}):[I],F=!1,B=0;B<R.length;B++){var N=R[B];if(!A.horizontal[N])if(F)A.horizontal[N]=A.horizontal[0];else{var j=Xl(M,e,k,D,v,\"center\",N,L,S,Yl.horizontal);j&&(A.horizontal[N]=j,F=1===j.lineCount)}}else{\"auto\"===I&&(I=kc(P));var U=Xl(M,e,k,D,v,P,I,L,S,Yl.horizontal);U&&(A.horizontal[I]=U),Cn(E)&&m&&y&&(A.vertical=Xl(M,e,k,D,v,P,I,L,S,Yl.vertical))}}var V=void 0;if(_.icon){var q=n[_.icon];q&&(V=nc(i[_.icon],s.get(\"icon-offset\").evaluate(_,{}),s.get(\"icon-anchor\").evaluate(_,{})),void 0===t.sdfIcons?t.sdfIcons=q.sdf:t.sdfIcons!==q.sdf&&w(\"Style sheet warning: Cannot mix SDF and non-SDF icons in one buffer\"),q.pixelRatio!==t.pixelRatio?t.iconsNeedLinear=!0:0!==s.get(\"icon-rotate\").constantOr(1)&&(t.iconsNeedLinear=!0))}(Object.keys(A.horizontal).length||V)&&Tc(t,_,A,V,T,c,S)}a&&t.generateCollisionDebugBuffers()},t.perspective=function(t,e,r,n,i){var a,o=1/Math.tan(e/2);return t[0]=o/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=o,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=-1,t[12]=0,t[13]=0,t[15]=0,null!=i&&i!==1/0?(a=1/(n-i),t[10]=(i+n)*a,t[14]=2*i*n*a):(t[10]=-1,t[14]=-2*n),t},t.pick=function(t,e){for(var r={},n=0;n<e.length;n++){var i=e[n];i in t&&(r[i]=t[i])}return r},t.plugin=jn,t.polygonIntersectsPolygon=va,t.postMapLoadEvent=ht,t.postTurnstileEvent=ct,t.potpack=Vs,t.rasterBoundsAttributes=Rl,t.refProperties=[\"type\",\"source\",\"source-layer\",\"minzoom\",\"maxzoom\",\"filter\",\"layout\"],t.register=kn,t.registerForPluginAvailability=function(t){return Fn?t({pluginURL:Fn,completionCallback:Dn}):Nn.once(\"pluginAvailable\",t),t},t.rotate=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=Math.sin(r),l=Math.cos(r);return t[0]=n*l+a*s,t[1]=i*l+o*s,t[2]=n*-s+a*l,t[3]=i*-s+o*l,t},t.rotateX=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],h=e[10],f=e[11];return e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+h*n,t[7]=l*i+f*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=h*i-s*n,t[11]=f*i-l*n,t},t.rotateZ=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],h=e[6],f=e[7];return e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+h*n,t[3]=l*i+f*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=h*i-s*n,t[7]=f*i-l*n,t},t.scale=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t},t.setCacheLimits=function(t,e){pt=t,dt=e},t.setRTLTextPlugin=function(t,e){if(Rn)throw new Error(\"setRTLTextPlugin cannot be called multiple times.\");Rn=!0,Fn=z.resolveURL(t),Dn=function(t){t?(Rn=!1,Fn=null,e&&e(t)):Bn=!0},Nn.fire(new Pt(\"pluginAvailable\",{pluginURL:Fn,completionCallback:Dn}))},t.sphericalToCartesian=function(t){var e=t[0],r=t[1],n=t[2];return r+=90,r*=Math.PI/180,n*=Math.PI/180,{x:e*Math.cos(r)*Math.sin(n),y:e*Math.sin(r)*Math.sin(n),z:e*Math.cos(n)}},t.styleSpec=It,t.symbolSize=As,t.transformMat3=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t},t.transformMat4=Da,t.translate=function(t,e,r){var n,i,a,o,s,l,c,u,h,f,p,d,g=r[0],v=r[1],m=r[2];return e===t?(t[12]=e[0]*g+e[4]*v+e[8]*m+e[12],t[13]=e[1]*g+e[5]*v+e[9]*m+e[13],t[14]=e[2]*g+e[6]*v+e[10]*m+e[14],t[15]=e[3]*g+e[7]*v+e[11]*m+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],h=e[8],f=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=h,t[9]=f,t[10]=p,t[11]=d,t[12]=n*g+s*v+h*m+e[12],t[13]=i*g+l*v+f*m+e[13],t[14]=a*g+c*v+p*m+e[14],t[15]=o*g+u*v+d*m+e[15]),t},t.uniqueId=p,t.validateCustomStyleLayer=function(t){var e=[],r=t.id;return void 0===r&&e.push({message:\"layers.\"+r+': missing required property \"id\"'}),void 0===t.render&&e.push({message:\"layers.\"+r+': missing required method \"render\"'}),t.renderingMode&&\"2d\"!==t.renderingMode&&\"3d\"!==t.renderingMode&&e.push({message:\"layers.\"+r+': property \"renderingMode\" must be either \"2d\" or \"3d\"'}),e},t.validateLight=dn,t.validateStyle=pn,t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.vectorTile=Vo,t.version=\"1.1.1\",t.warnOnce=w,t.webpSupported=D,t.window=self,t.wrap=u}),n(0,function(t){function e(t){var r=typeof t;if(\"number\"===r||\"boolean\"===r||\"string\"===r||null==t)return JSON.stringify(t);if(Array.isArray(t)){for(var n=\"[\",i=0,a=t;i<a.length;i+=1)n+=e(a[i])+\",\";return n+\"]\"}for(var o=Object.keys(t).sort(),s=\"{\",l=0;l<o.length;l++)s+=JSON.stringify(o[l])+\":\"+e(t[o[l]])+\",\";return s+\"}\"}function r(r){for(var n=\"\",i=0,a=t.refProperties;i<a.length;i+=1)n+=\"/\"+e(r[a[i]]);return n}var n=function(t){this.keyCache={},t&&this.replace(t)};n.prototype.replace=function(t){this._layerConfigs={},this._layers={},this.update(t,[])},n.prototype.update=function(e,n){for(var i=this,a=0,o=e;a<o.length;a+=1){var s=o[a];this._layerConfigs[s.id]=s;var l=this._layers[s.id]=t.createStyleLayer(s);l._featureFilter=t.featureFilter(l.filter),this.keyCache[s.id]&&delete this.keyCache[s.id]}for(var c=0,u=n;c<u.length;c+=1){var h=u[c];delete this.keyCache[h],delete this._layerConfigs[h],delete this._layers[h]}this.familiesBySource={};for(var f=0,p=function(t,e){for(var n={},i=0;i<t.length;i++){var a=e&&e[t[i].id]||r(t[i]);e&&(e[t[i].id]=a);var o=n[a];o||(o=n[a]=[]),o.push(t[i])}var s=[];for(var l in n)s.push(n[l]);return s}(t.values(this._layerConfigs),this.keyCache);f<p.length;f+=1){var d=p[f].map(function(t){return i._layers[t.id]}),g=d[0];if(\"none\"!==g.visibility){var v=g.source||\"\",m=this.familiesBySource[v];m||(m=this.familiesBySource[v]={});var y=g.sourceLayer||\"_geojsonTileLayer\",x=m[y];x||(x=m[y]=[]),x.push(d)}}};var i=function(e){var r={},n=[];for(var i in e){var a=e[i],o=r[i]={};for(var s in a){var l=a[+s];if(l&&0!==l.bitmap.width&&0!==l.bitmap.height){var c={x:0,y:0,w:l.bitmap.width+2,h:l.bitmap.height+2};n.push(c),o[s]={rect:c,metrics:l.metrics}}}}var u=t.potpack(n),h=u.w,f=u.h,p=new t.AlphaImage({width:h||1,height:f||1});for(var d in e){var g=e[d];for(var v in g){var m=g[+v];if(m&&0!==m.bitmap.width&&0!==m.bitmap.height){var y=r[d][v].rect;t.AlphaImage.copy(m.bitmap,p,{x:0,y:0},{x:y.x+1,y:y.y+1},m.bitmap)}}}this.image=p,this.positions=r};t.register(\"GlyphAtlas\",i);var a=function(e){this.tileID=new t.OverscaledTileID(e.tileID.overscaledZ,e.tileID.wrap,e.tileID.canonical.z,e.tileID.canonical.x,e.tileID.canonical.y),this.uid=e.uid,this.zoom=e.zoom,this.pixelRatio=e.pixelRatio,this.tileSize=e.tileSize,this.source=e.source,this.overscaling=this.tileID.overscaleFactor(),this.showCollisionBoxes=e.showCollisionBoxes,this.collectResourceTiming=!!e.collectResourceTiming,this.returnDependencies=!!e.returnDependencies};function o(e,r){for(var n=new t.EvaluationParameters(r),i=0,a=e;i<a.length;i+=1)a[i].recalculate(n)}a.prototype.parse=function(e,r,n,a){var s=this;this.status=\"parsing\",this.data=e,this.collisionBoxArray=new t.CollisionBoxArray;var l=new t.DictionaryCoder(Object.keys(e.layers).sort()),c=new t.FeatureIndex(this.tileID);c.bucketLayerIDs=[];var u,h,f,p,d={},g={featureIndex:c,iconDependencies:{},patternDependencies:{},glyphDependencies:{}},v=r.familiesBySource[this.source];for(var m in v){var y=e.layers[m];if(y){1===y.version&&t.warnOnce('Vector tile source \"'+this.source+'\" layer \"'+m+'\" does not use vector tile spec v2 and therefore may have some rendering errors.');for(var x=l.encode(m),b=[],_=0;_<y.length;_++){var w=y.feature(_);b.push({feature:w,index:_,sourceLayerIndex:x})}for(var k=0,T=v[m];k<T.length;k+=1){var A=T[k],M=A[0];M.minzoom&&this.zoom<Math.floor(M.minzoom)||M.maxzoom&&this.zoom>=M.maxzoom||\"none\"!==M.visibility&&(o(A,this.zoom),(d[M.id]=M.createBucket({index:c.bucketLayerIDs.length,layers:A,zoom:this.zoom,pixelRatio:this.pixelRatio,overscaling:this.overscaling,collisionBoxArray:this.collisionBoxArray,sourceLayerIndex:x,sourceID:this.source})).populate(b,g),c.bucketLayerIDs.push(A.map(function(t){return t.id})))}}}var S=t.mapObject(g.glyphDependencies,function(t){return Object.keys(t).map(Number)});Object.keys(S).length?n.send(\"getGlyphs\",{uid:this.uid,stacks:S},function(t,e){u||(u=t,h=e,L.call(s))}):h={};var E=Object.keys(g.iconDependencies);E.length?n.send(\"getImages\",{icons:E},function(t,e){u||(u=t,f=e,L.call(s))}):f={};var C=Object.keys(g.patternDependencies);function L(){if(u)return a(u);if(h&&f&&p){var e=new i(h),r=new t.ImageAtlas(f,p);for(var n in d){var s=d[n];s instanceof t.SymbolBucket?(o(s.layers,this.zoom),t.performSymbolLayout(s,h,e.positions,f,r.iconPositions,this.showCollisionBoxes)):s.hasPattern&&(s instanceof t.LineBucket||s instanceof t.FillBucket||s instanceof t.FillExtrusionBucket)&&(o(s.layers,this.zoom),s.addFeatures(g,r.patternPositions))}this.status=\"done\",a(null,{buckets:t.values(d).filter(function(t){return!t.isEmpty()}),featureIndex:c,collisionBoxArray:this.collisionBoxArray,glyphAtlasImage:e.image,imageAtlas:r,glyphMap:this.returnDependencies?h:null,iconMap:this.returnDependencies?f:null,glyphPositions:this.returnDependencies?e.positions:null})}}C.length?n.send(\"getImages\",{icons:C},function(t,e){u||(u=t,p=e,L.call(s))}):p={},L.call(this)};var s=\"undefined\"!=typeof performance,l={getEntriesByName:function(t){return!!(s&&performance&&performance.getEntriesByName)&&performance.getEntriesByName(t)},mark:function(t){return!!(s&&performance&&performance.mark)&&performance.mark(t)},measure:function(t,e,r){return!!(s&&performance&&performance.measure)&&performance.measure(t,e,r)},clearMarks:function(t){return!!(s&&performance&&performance.clearMarks)&&performance.clearMarks(t)},clearMeasures:function(t){return!!(s&&performance&&performance.clearMeasures)&&performance.clearMeasures(t)}},c=function(t){this._marks={start:[t.url,\"start\"].join(\"#\"),end:[t.url,\"end\"].join(\"#\"),measure:t.url.toString()},l.mark(this._marks.start)};function u(e,r){var n=t.getArrayBuffer(e.request,function(e,n,i,a){e?r(e):n&&r(null,{vectorTile:new t.vectorTile.VectorTile(new t.pbf(n)),rawData:n,cacheControl:i,expires:a})});return function(){n.cancel(),r()}}c.prototype.finish=function(){l.mark(this._marks.end);var t=l.getEntriesByName(this._marks.measure);return 0===t.length&&(l.measure(this._marks.measure,this._marks.start,this._marks.end),t=l.getEntriesByName(this._marks.measure),l.clearMarks(this._marks.start),l.clearMarks(this._marks.end),l.clearMeasures(this._marks.measure)),t},l.Performance=c;var h=function(t,e,r){this.actor=t,this.layerIndex=e,this.loadVectorData=r||u,this.loading={},this.loaded={}};h.prototype.loadTile=function(e,r){var n=this,i=e.uid;this.loading||(this.loading={});var o=!!(e&&e.request&&e.request.collectResourceTiming)&&new l.Performance(e.request),s=this.loading[i]=new a(e);s.abort=this.loadVectorData(e,function(e,a){if(delete n.loading[i],e||!a)return s.status=\"done\",n.loaded[i]=s,r(e);var l=a.rawData,c={};a.expires&&(c.expires=a.expires),a.cacheControl&&(c.cacheControl=a.cacheControl);var u={};if(o){var h=o.finish();h&&(u.resourceTiming=JSON.parse(JSON.stringify(h)))}s.vectorTile=a.vectorTile,s.parse(a.vectorTile,n.layerIndex,n.actor,function(e,n){if(e||!n)return r(e);r(null,t.extend({rawTileData:l.slice(0)},n,c,u))}),n.loaded=n.loaded||{},n.loaded[i]=s})},h.prototype.reloadTile=function(t,e){var r=this.loaded,n=t.uid,i=this;if(r&&r[n]){var a=r[n];a.showCollisionBoxes=t.showCollisionBoxes;var o=function(t,r){var n=a.reloadCallback;n&&(delete a.reloadCallback,a.parse(a.vectorTile,i.layerIndex,i.actor,n)),e(t,r)};\"parsing\"===a.status?a.reloadCallback=o:\"done\"===a.status&&(a.vectorTile?a.parse(a.vectorTile,this.layerIndex,this.actor,o):o())}},h.prototype.abortTile=function(t,e){var r=this.loading,n=t.uid;r&&r[n]&&r[n].abort&&(r[n].abort(),delete r[n]),e()},h.prototype.removeTile=function(t,e){var r=this.loaded,n=t.uid;r&&r[n]&&delete r[n],e()};var f=function(){this.loaded={}};f.prototype.loadTile=function(e,r){var n=e.uid,i=e.encoding,a=e.rawImageData,o=new t.DEMData(n,a,i);this.loaded=this.loaded||{},this.loaded[n]=o,r(null,o)},f.prototype.removeTile=function(t){var e=this.loaded,r=t.uid;e&&e[r]&&delete e[r]};var p={RADIUS:6378137,FLATTENING:1/298.257223563,POLAR_RADIUS:6356752.3142};function d(t){var e=0;if(t&&t.length>0){e+=Math.abs(g(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(g(t[r]))}return e}function g(t){var e,r,n,i,a,o,s=0,l=t.length;if(l>2){for(o=0;o<l;o++)o===l-2?(n=l-2,i=l-1,a=0):o===l-1?(n=l-1,i=0,a=1):(n=o,i=o+1,a=o+2),e=t[n],r=t[i],s+=(v(t[a][0])-v(e[0]))*Math.sin(v(r[1]));s=s*p.RADIUS*p.RADIUS/2}return s}function v(t){return t*Math.PI/180}var m={geometry:function t(e){var r,n=0;switch(e.type){case\"Polygon\":return d(e.coordinates);case\"MultiPolygon\":for(r=0;r<e.coordinates.length;r++)n+=d(e.coordinates[r]);return n;case\"Point\":case\"MultiPoint\":case\"LineString\":case\"MultiLineString\":return 0;case\"GeometryCollection\":for(r=0;r<e.geometries.length;r++)n+=t(e.geometries[r]);return n}},ring:g};function y(t,e){return function(r){return t(r,e)}}function x(t,e){e=!!e,t[0]=b(t[0],e);for(var r=1;r<t.length;r++)t[r]=b(t[r],!e);return t}function b(t,e){return function(t){return m.ring(t)>=0}(t)===e?t:t.reverse()}var _=t.vectorTile.VectorTileFeature.prototype.toGeoJSON,w=function(e){this._feature=e,this.extent=t.EXTENT,this.type=e.type,this.properties=e.tags,\"id\"in e&&!isNaN(e.id)&&(this.id=parseInt(e.id,10))};w.prototype.loadGeometry=function(){if(1===this._feature.type){for(var e=[],r=0,n=this._feature.geometry;r<n.length;r+=1){var i=n[r];e.push([new t.Point$1(i[0],i[1])])}return e}for(var a=[],o=0,s=this._feature.geometry;o<s.length;o+=1){for(var l=[],c=0,u=s[o];c<u.length;c+=1){var h=u[c];l.push(new t.Point$1(h[0],h[1]))}a.push(l)}return a},w.prototype.toGeoJSON=function(t,e,r){return _.call(this,t,e,r)};var k=function(e){this.layers={_geojsonTileLayer:this},this.name=\"_geojsonTileLayer\",this.extent=t.EXTENT,this.length=e.length,this._features=e};k.prototype.feature=function(t){return new w(this._features[t])};var T=t.vectorTile.VectorTileFeature,A=M;function M(t,e){this.options=e||{},this.features=t,this.length=t.length}function S(t,e){this.id=\"number\"==typeof t.id?t.id:void 0,this.type=t.type,this.rawGeometry=1===t.type?[t.geometry]:t.geometry,this.properties=t.tags,this.extent=e||4096}M.prototype.feature=function(t){return new S(this.features[t],this.options.extent)},S.prototype.loadGeometry=function(){var e=this.rawGeometry;this.geometry=[];for(var r=0;r<e.length;r++){for(var n=e[r],i=[],a=0;a<n.length;a++)i.push(new t.Point$1(n[a][0],n[a][1]));this.geometry.push(i)}return this.geometry},S.prototype.bbox=function(){this.geometry||this.loadGeometry();for(var t=this.geometry,e=1/0,r=-1/0,n=1/0,i=-1/0,a=0;a<t.length;a++)for(var o=t[a],s=0;s<o.length;s++){var l=o[s];e=Math.min(e,l.x),r=Math.max(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.y)}return[e,n,r,i]},S.prototype.toGeoJSON=T.prototype.toGeoJSON;var E=P,C=P,L=A;function P(e){var r=new t.pbf;return function(t,e){for(var r in t.layers)e.writeMessage(3,O,t.layers[r])}(e,r),r.finish()}function O(t,e){var r;e.writeVarintField(15,t.version||1),e.writeStringField(1,t.name||\"\"),e.writeVarintField(5,t.extent||4096);var n={keys:[],values:[],keycache:{},valuecache:{}};for(r=0;r<t.length;r++)n.feature=t.feature(r),e.writeMessage(2,z,n);var i=n.keys;for(r=0;r<i.length;r++)e.writeStringField(3,i[r]);var a=n.values;for(r=0;r<a.length;r++)e.writeMessage(4,B,a[r])}function z(t,e){var r=t.feature;void 0!==r.id&&e.writeVarintField(1,r.id),e.writeMessage(2,I,t),e.writeVarintField(3,r.type),e.writeMessage(4,F,r)}function I(t,e){var r=t.feature,n=t.keys,i=t.values,a=t.keycache,o=t.valuecache;for(var s in r.properties){var l=a[s];void 0===l&&(n.push(s),l=n.length-1,a[s]=l),e.writeVarint(l);var c=r.properties[s],u=typeof c;\"string\"!==u&&\"boolean\"!==u&&\"number\"!==u&&(c=JSON.stringify(c));var h=u+\":\"+c,f=o[h];void 0===f&&(i.push(c),f=i.length-1,o[h]=f),e.writeVarint(f)}}function D(t,e){return(e<<3)+(7&t)}function R(t){return t<<1^t>>31}function F(t,e){for(var r=t.loadGeometry(),n=t.type,i=0,a=0,o=r.length,s=0;s<o;s++){var l=r[s],c=1;1===n&&(c=l.length),e.writeVarint(D(1,c));for(var u=3===n?l.length-1:l.length,h=0;h<u;h++){1===h&&1!==n&&e.writeVarint(D(2,u-1));var f=l[h].x-i,p=l[h].y-a;e.writeVarint(R(f)),e.writeVarint(R(p)),i+=f,a+=p}3===n&&e.writeVarint(D(7,1))}}function B(t,e){var r=typeof t;\"string\"===r?e.writeStringField(1,t):\"boolean\"===r?e.writeBooleanField(7,t):\"number\"===r&&(t%1!=0?e.writeDoubleField(3,t):t<0?e.writeSVarintField(6,t):e.writeVarintField(5,t))}function N(t,e,r,n){j(t,r,n),j(e,2*r,2*n),j(e,2*r+1,2*n+1)}function j(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function U(t,e,r,n){var i=t-r,a=e-n;return i*i+a*a}E.fromVectorTileJs=C,E.fromGeojsonVt=function(t,e){e=e||{};var r={};for(var n in t)r[n]=new A(t[n].features,e),r[n].name=n,r[n].version=e.version,r[n].extent=e.extent;return P({layers:r})},E.GeoJSONWrapper=L;var V=function(t){return t[0]},q=function(t){return t[1]},H=function(t,e,r,n,i){void 0===e&&(e=V),void 0===r&&(r=q),void 0===n&&(n=64),void 0===i&&(i=Float64Array),this.nodeSize=n,this.points=t;for(var a=t.length<65536?Uint16Array:Uint32Array,o=this.ids=new a(t.length),s=this.coords=new i(2*t.length),l=0;l<t.length;l++)o[l]=l,s[2*l]=e(t[l]),s[2*l+1]=r(t[l]);!function t(e,r,n,i,a,o){if(!(a-i<=n)){var s=i+a>>1;!function t(e,r,n,i,a,o){for(;a>i;){if(a-i>600){var s=a-i+1,l=n-i+1,c=Math.log(s),u=.5*Math.exp(2*c/3),h=.5*Math.sqrt(c*u*(s-u)/s)*(l-s/2<0?-1:1);t(e,r,n,Math.max(i,Math.floor(n-l*u/s+h)),Math.min(a,Math.floor(n+(s-l)*u/s+h)),o)}var f=r[2*n+o],p=i,d=a;for(N(e,r,i,n),r[2*a+o]>f&&N(e,r,i,a);p<d;){for(N(e,r,p,d),p++,d--;r[2*p+o]<f;)p++;for(;r[2*d+o]>f;)d--}r[2*i+o]===f?N(e,r,i,d):N(e,r,++d,a),d<=n&&(i=d+1),n<=d&&(a=d-1)}}(e,r,s,i,a,o%2),t(e,r,n,i,s-1,o+1),t(e,r,n,s+1,a,o+1)}}(o,s,n,0,o.length-1,0)};H.prototype.range=function(t,e,r,n){return function(t,e,r,n,i,a,o){for(var s,l,c=[0,t.length-1,0],u=[];c.length;){var h=c.pop(),f=c.pop(),p=c.pop();if(f-p<=o)for(var d=p;d<=f;d++)s=e[2*d],l=e[2*d+1],s>=r&&s<=i&&l>=n&&l<=a&&u.push(t[d]);else{var g=Math.floor((p+f)/2);s=e[2*g],l=e[2*g+1],s>=r&&s<=i&&l>=n&&l<=a&&u.push(t[g]);var v=(h+1)%2;(0===h?r<=s:n<=l)&&(c.push(p),c.push(g-1),c.push(v)),(0===h?i>=s:a>=l)&&(c.push(g+1),c.push(f),c.push(v))}}return u}(this.ids,this.coords,t,e,r,n,this.nodeSize)},H.prototype.within=function(t,e,r){return function(t,e,r,n,i,a){for(var o=[0,t.length-1,0],s=[],l=i*i;o.length;){var c=o.pop(),u=o.pop(),h=o.pop();if(u-h<=a)for(var f=h;f<=u;f++)U(e[2*f],e[2*f+1],r,n)<=l&&s.push(t[f]);else{var p=Math.floor((h+u)/2),d=e[2*p],g=e[2*p+1];U(d,g,r,n)<=l&&s.push(t[p]);var v=(c+1)%2;(0===c?r-i<=d:n-i<=g)&&(o.push(h),o.push(p-1),o.push(v)),(0===c?r+i>=d:n+i>=g)&&(o.push(p+1),o.push(u),o.push(v))}}return s}(this.ids,this.coords,t,e,r,this.nodeSize)};var G={minZoom:0,maxZoom:16,radius:40,extent:512,nodeSize:64,log:!1,reduce:null,map:function(t){return t}},Y=function(t){this.options=Q(Object.create(G),t),this.trees=new Array(this.options.maxZoom+1)};function W(t,e,r,n,i){return{x:t,y:e,zoom:1/0,id:r,parentId:-1,numPoints:n,properties:i}}function X(t,e){var r=t.geometry.coordinates,n=r[0],i=r[1];return{x:K(n),y:$(i),zoom:1/0,index:e,parentId:-1}}function Z(t){return{type:\"Feature\",id:t.id,properties:J(t),geometry:{type:\"Point\",coordinates:[(n=t.x,360*(n-.5)),(e=t.y,r=(180-360*e)*Math.PI/180,360*Math.atan(Math.exp(r))/Math.PI-90)]}};var e,r,n}function J(t){var e=t.numPoints,r=e>=1e4?Math.round(e/1e3)+\"k\":e>=1e3?Math.round(e/100)/10+\"k\":e;return Q(Q({},t.properties),{cluster:!0,cluster_id:t.id,point_count:e,point_count_abbreviated:r})}function K(t){return t/360+.5}function $(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function Q(t,e){for(var r in e)t[r]=e[r];return t}function tt(t){return t.x}function et(t){return t.y}function rt(t,e,r,n,i,a){var o=i-r,s=a-n;if(0!==o||0!==s){var l=((t-r)*o+(e-n)*s)/(o*o+s*s);l>1?(r=i,n=a):l>0&&(r+=o*l,n+=s*l)}return(o=t-r)*o+(s=e-n)*s}function nt(t,e,r,n){var i={id:void 0===t?null:t,type:e,geometry:r,tags:n,minX:1/0,minY:1/0,maxX:-1/0,maxY:-1/0};return function(t){var e=t.geometry,r=t.type;if(\"Point\"===r||\"MultiPoint\"===r||\"LineString\"===r)it(t,e);else if(\"Polygon\"===r||\"MultiLineString\"===r)for(var n=0;n<e.length;n++)it(t,e[n]);else if(\"MultiPolygon\"===r)for(n=0;n<e.length;n++)for(var i=0;i<e[n].length;i++)it(t,e[n][i])}(i),i}function it(t,e){for(var r=0;r<e.length;r+=3)t.minX=Math.min(t.minX,e[r]),t.minY=Math.min(t.minY,e[r+1]),t.maxX=Math.max(t.maxX,e[r]),t.maxY=Math.max(t.maxY,e[r+1])}function at(t,e,r,n){if(e.geometry){var i=e.geometry.coordinates,a=e.geometry.type,o=Math.pow(r.tolerance/((1<<r.maxZoom)*r.extent),2),s=[],l=e.id;if(r.promoteId?l=e.properties[r.promoteId]:r.generateId&&(l=n||0),\"Point\"===a)ot(i,s);else if(\"MultiPoint\"===a)for(var c=0;c<i.length;c++)ot(i[c],s);else if(\"LineString\"===a)st(i,s,o,!1);else if(\"MultiLineString\"===a){if(r.lineMetrics){for(c=0;c<i.length;c++)s=[],st(i[c],s,o,!1),t.push(nt(l,\"LineString\",s,e.properties));return}lt(i,s,o,!1)}else if(\"Polygon\"===a)lt(i,s,o,!0);else{if(\"MultiPolygon\"!==a){if(\"GeometryCollection\"===a){for(c=0;c<e.geometry.geometries.length;c++)at(t,{id:l,geometry:e.geometry.geometries[c],properties:e.properties},r,n);return}throw new Error(\"Input data is not a valid GeoJSON object.\")}for(c=0;c<i.length;c++){var u=[];lt(i[c],u,o,!0),s.push(u)}}t.push(nt(l,a,s,e.properties))}}function ot(t,e){e.push(ct(t[0])),e.push(ut(t[1])),e.push(0)}function st(t,e,r,n){for(var i,a,o=0,s=0;s<t.length;s++){var l=ct(t[s][0]),c=ut(t[s][1]);e.push(l),e.push(c),e.push(0),s>0&&(o+=n?(i*c-l*a)/2:Math.sqrt(Math.pow(l-i,2)+Math.pow(c-a,2))),i=l,a=c}var u=e.length-3;e[2]=1,function t(e,r,n,i){for(var a,o=i,s=n-r>>1,l=n-r,c=e[r],u=e[r+1],h=e[n],f=e[n+1],p=r+3;p<n;p+=3){var d=rt(e[p],e[p+1],c,u,h,f);if(d>o)a=p,o=d;else if(d===o){var g=Math.abs(p-s);g<l&&(a=p,l=g)}}o>i&&(a-r>3&&t(e,r,a,i),e[a+2]=o,n-a>3&&t(e,a,n,i))}(e,0,u,r),e[u+2]=1,e.size=Math.abs(o),e.start=0,e.end=e.size}function lt(t,e,r,n){for(var i=0;i<t.length;i++){var a=[];st(t[i],a,r,n),e.push(a)}}function ct(t){return t/360+.5}function ut(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function ht(t,e,r,n,i,a,o,s){if(n/=e,a>=(r/=e)&&o<n)return t;if(o<r||a>=n)return null;for(var l=[],c=0;c<t.length;c++){var u=t[c],h=u.geometry,f=u.type,p=0===i?u.minX:u.minY,d=0===i?u.maxX:u.maxY;if(p>=r&&d<n)l.push(u);else if(!(d<r||p>=n)){var g=[];if(\"Point\"===f||\"MultiPoint\"===f)ft(h,g,r,n,i);else if(\"LineString\"===f)pt(h,g,r,n,i,!1,s.lineMetrics);else if(\"MultiLineString\"===f)gt(h,g,r,n,i,!1);else if(\"Polygon\"===f)gt(h,g,r,n,i,!0);else if(\"MultiPolygon\"===f)for(var v=0;v<h.length;v++){var m=[];gt(h[v],m,r,n,i,!0),m.length&&g.push(m)}if(g.length){if(s.lineMetrics&&\"LineString\"===f){for(v=0;v<g.length;v++)l.push(nt(u.id,f,g[v],u.tags));continue}\"LineString\"!==f&&\"MultiLineString\"!==f||(1===g.length?(f=\"LineString\",g=g[0]):f=\"MultiLineString\"),\"Point\"!==f&&\"MultiPoint\"!==f||(f=3===g.length?\"Point\":\"MultiPoint\"),l.push(nt(u.id,f,g,u.tags))}}}return l.length?l:null}function ft(t,e,r,n,i){for(var a=0;a<t.length;a+=3){var o=t[a+i];o>=r&&o<=n&&(e.push(t[a]),e.push(t[a+1]),e.push(t[a+2]))}}function pt(t,e,r,n,i,a,o){for(var s,l,c=dt(t),u=0===i?mt:yt,h=t.start,f=0;f<t.length-3;f+=3){var p=t[f],d=t[f+1],g=t[f+2],v=t[f+3],m=t[f+4],y=0===i?p:d,x=0===i?v:m,b=!1;o&&(s=Math.sqrt(Math.pow(p-v,2)+Math.pow(d-m,2))),y<r?x>r&&(l=u(c,p,d,v,m,r),o&&(c.start=h+s*l)):y>n?x<n&&(l=u(c,p,d,v,m,n),o&&(c.start=h+s*l)):vt(c,p,d,g),x<r&&y>=r&&(l=u(c,p,d,v,m,r),b=!0),x>n&&y<=n&&(l=u(c,p,d,v,m,n),b=!0),!a&&b&&(o&&(c.end=h+s*l),e.push(c),c=dt(t)),o&&(h+=s)}var _=t.length-3;p=t[_],d=t[_+1],g=t[_+2],(y=0===i?p:d)>=r&&y<=n&&vt(c,p,d,g),_=c.length-3,a&&_>=3&&(c[_]!==c[0]||c[_+1]!==c[1])&&vt(c,c[0],c[1],c[2]),c.length&&e.push(c)}function dt(t){var e=[];return e.size=t.size,e.start=t.start,e.end=t.end,e}function gt(t,e,r,n,i,a){for(var o=0;o<t.length;o++)pt(t[o],e,r,n,i,a,!1)}function vt(t,e,r,n){t.push(e),t.push(r),t.push(n)}function mt(t,e,r,n,i,a){var o=(a-e)/(n-e);return t.push(a),t.push(r+(i-r)*o),t.push(1),o}function yt(t,e,r,n,i,a){var o=(a-r)/(i-r);return t.push(e+(n-e)*o),t.push(a),t.push(1),o}function xt(t,e){for(var r=[],n=0;n<t.length;n++){var i,a=t[n],o=a.type;if(\"Point\"===o||\"MultiPoint\"===o||\"LineString\"===o)i=bt(a.geometry,e);else if(\"MultiLineString\"===o||\"Polygon\"===o){i=[];for(var s=0;s<a.geometry.length;s++)i.push(bt(a.geometry[s],e))}else if(\"MultiPolygon\"===o)for(i=[],s=0;s<a.geometry.length;s++){for(var l=[],c=0;c<a.geometry[s].length;c++)l.push(bt(a.geometry[s][c],e));i.push(l)}r.push(nt(a.id,o,i,a.tags))}return r}function bt(t,e){var r=[];r.size=t.size,void 0!==t.start&&(r.start=t.start,r.end=t.end);for(var n=0;n<t.length;n+=3)r.push(t[n]+e,t[n+1],t[n+2]);return r}function _t(t,e){if(t.transformed)return t;var r,n,i,a=1<<t.z,o=t.x,s=t.y;for(r=0;r<t.features.length;r++){var l=t.features[r],c=l.geometry,u=l.type;if(l.geometry=[],1===u)for(n=0;n<c.length;n+=2)l.geometry.push(wt(c[n],c[n+1],e,a,o,s));else for(n=0;n<c.length;n++){var h=[];for(i=0;i<c[n].length;i+=2)h.push(wt(c[n][i],c[n][i+1],e,a,o,s));l.geometry.push(h)}}return t.transformed=!0,t}function wt(t,e,r,n,i,a){return[Math.round(r*(t*n-i)),Math.round(r*(e*n-a))]}function kt(t,e,r,n,i){for(var a=e===i.maxZoom?0:i.tolerance/((1<<e)*i.extent),o={features:[],numPoints:0,numSimplified:0,numFeatures:0,source:null,x:r,y:n,z:e,transformed:!1,minX:2,minY:1,maxX:-1,maxY:0},s=0;s<t.length;s++){o.numFeatures++,Tt(o,t[s],a,i);var l=t[s].minX,c=t[s].minY,u=t[s].maxX,h=t[s].maxY;l<o.minX&&(o.minX=l),c<o.minY&&(o.minY=c),u>o.maxX&&(o.maxX=u),h>o.maxY&&(o.maxY=h)}return o}function Tt(t,e,r,n){var i=e.geometry,a=e.type,o=[];if(\"Point\"===a||\"MultiPoint\"===a)for(var s=0;s<i.length;s+=3)o.push(i[s]),o.push(i[s+1]),t.numPoints++,t.numSimplified++;else if(\"LineString\"===a)At(o,i,t,r,!1,!1);else if(\"MultiLineString\"===a||\"Polygon\"===a)for(s=0;s<i.length;s++)At(o,i[s],t,r,\"Polygon\"===a,0===s);else if(\"MultiPolygon\"===a)for(var l=0;l<i.length;l++){var c=i[l];for(s=0;s<c.length;s++)At(o,c[s],t,r,!0,0===s)}if(o.length){var u=e.tags||null;if(\"LineString\"===a&&n.lineMetrics){for(var h in u={},e.tags)u[h]=e.tags[h];u.mapbox_clip_start=i.start/i.size,u.mapbox_clip_end=i.end/i.size}var f={geometry:o,type:\"Polygon\"===a||\"MultiPolygon\"===a?3:\"LineString\"===a||\"MultiLineString\"===a?2:1,tags:u};null!==e.id&&(f.id=e.id),t.features.push(f)}}function At(t,e,r,n,i,a){var o=n*n;if(n>0&&e.size<(i?o:n))r.numPoints+=e.length/3;else{for(var s=[],l=0;l<e.length;l+=3)(0===n||e[l+2]>o)&&(r.numSimplified++,s.push(e[l]),s.push(e[l+1])),r.numPoints++;i&&function(t,e){for(var r=0,n=0,i=t.length,a=i-2;n<i;a=n,n+=2)r+=(t[n]-t[a])*(t[n+1]+t[a+1]);if(r>0===e)for(n=0,i=t.length;n<i/2;n+=2){var o=t[n],s=t[n+1];t[n]=t[i-2-n],t[n+1]=t[i-1-n],t[i-2-n]=o,t[i-1-n]=s}}(s,a),t.push(s)}}function Mt(t,e){var r=(e=this.options=function(t,e){for(var r in e)t[r]=e[r];return t}(Object.create(this.options),e)).debug;if(r&&console.time(\"preprocess data\"),e.maxZoom<0||e.maxZoom>24)throw new Error(\"maxZoom should be in the 0-24 range\");if(e.promoteId&&e.generateId)throw new Error(\"promoteId and generateId cannot be used together.\");var n=function(t,e){var r=[];if(\"FeatureCollection\"===t.type)for(var n=0;n<t.features.length;n++)at(r,t.features[n],e,n);else\"Feature\"===t.type?at(r,t,e):at(r,{geometry:t},e);return r}(t,e);this.tiles={},this.tileCoords=[],r&&(console.timeEnd(\"preprocess data\"),console.log(\"index: maxZoom: %d, maxPoints: %d\",e.indexMaxZoom,e.indexMaxPoints),console.time(\"generate tiles\"),this.stats={},this.total=0),(n=function(t,e){var r=e.buffer/e.extent,n=t,i=ht(t,1,-1-r,r,0,-1,2,e),a=ht(t,1,1-r,2+r,0,-1,2,e);return(i||a)&&(n=ht(t,1,-r,1+r,0,-1,2,e)||[],i&&(n=xt(i,1).concat(n)),a&&(n=n.concat(xt(a,-1)))),n}(n,e)).length&&this.splitTile(n,0,0,0),r&&(n.length&&console.log(\"features: %d, points: %d\",this.tiles[0].numFeatures,this.tiles[0].numPoints),console.timeEnd(\"generate tiles\"),console.log(\"tiles generated:\",this.total,JSON.stringify(this.stats)))}function St(t,e,r){return 32*((1<<t)*r+e)+t}function Et(t,e){var r=t.tileID.canonical;if(!this._geoJSONIndex)return e(null,null);var n=this._geoJSONIndex.getTile(r.z,r.x,r.y);if(!n)return e(null,null);var i=new k(n.features),a=E(i);0===a.byteOffset&&a.byteLength===a.buffer.byteLength||(a=new Uint8Array(a)),e(null,{vectorTile:i,rawData:a.buffer})}Y.prototype.load=function(t){var e=this.options,r=e.log,n=e.minZoom,i=e.maxZoom,a=e.nodeSize;r&&console.time(\"total time\");var o=\"prepare \"+t.length+\" points\";r&&console.time(o),this.points=t;for(var s=[],l=0;l<t.length;l++)t[l].geometry&&s.push(X(t[l],l));this.trees[i+1]=new H(s,tt,et,a,Float32Array),r&&console.timeEnd(o);for(var c=i;c>=n;c--){var u=+Date.now();s=this._cluster(s,c),this.trees[c]=new H(s,tt,et,a,Float32Array),r&&console.log(\"z%d: %d clusters in %dms\",c,s.length,+Date.now()-u)}return r&&console.timeEnd(\"total time\"),this},Y.prototype.getClusters=function(t,e){var r=((t[0]+180)%360+360)%360-180,n=Math.max(-90,Math.min(90,t[1])),i=180===t[2]?180:((t[2]+180)%360+360)%360-180,a=Math.max(-90,Math.min(90,t[3]));if(t[2]-t[0]>=360)r=-180,i=180;else if(r>i){var o=this.getClusters([r,n,180,a],e),s=this.getClusters([-180,n,i,a],e);return o.concat(s)}for(var l=this.trees[this._limitZoom(e)],c=[],u=0,h=l.range(K(r),$(a),K(i),$(n));u<h.length;u+=1){var f=h[u],p=l.points[f];c.push(p.numPoints?Z(p):this.points[p.index])}return c},Y.prototype.getChildren=function(t){var e=t>>5,r=t%32,n=\"No cluster with the specified id.\",i=this.trees[r];if(!i)throw new Error(n);var a=i.points[e];if(!a)throw new Error(n);for(var o=this.options.radius/(this.options.extent*Math.pow(2,r-1)),s=[],l=0,c=i.within(a.x,a.y,o);l<c.length;l+=1){var u=c[l],h=i.points[u];h.parentId===t&&s.push(h.numPoints?Z(h):this.points[h.index])}if(0===s.length)throw new Error(n);return s},Y.prototype.getLeaves=function(t,e,r){e=e||10,r=r||0;var n=[];return this._appendLeaves(n,t,e,r,0),n},Y.prototype.getTile=function(t,e,r){var n=this.trees[this._limitZoom(t)],i=Math.pow(2,t),a=this.options,o=a.extent,s=a.radius/o,l=(r-s)/i,c=(r+1+s)/i,u={features:[]};return this._addTileFeatures(n.range((e-s)/i,l,(e+1+s)/i,c),n.points,e,r,i,u),0===e&&this._addTileFeatures(n.range(1-s/i,l,1,c),n.points,i,r,i,u),e===i-1&&this._addTileFeatures(n.range(0,l,s/i,c),n.points,-1,r,i,u),u.features.length?u:null},Y.prototype.getClusterExpansionZoom=function(t){for(var e=t%32-1;e<=this.options.maxZoom;){var r=this.getChildren(t);if(e++,1!==r.length)break;t=r[0].properties.cluster_id}return e},Y.prototype._appendLeaves=function(t,e,r,n,i){for(var a=0,o=this.getChildren(e);a<o.length;a+=1){var s=o[a],l=s.properties;if(l&&l.cluster?i+l.point_count<=n?i+=l.point_count:i=this._appendLeaves(t,l.cluster_id,r,n,i):i<n?i++:t.push(s),t.length===r)break}return i},Y.prototype._addTileFeatures=function(t,e,r,n,i,a){for(var o=0,s=t;o<s.length;o+=1){var l=e[s[o]],c={type:1,geometry:[[Math.round(this.options.extent*(l.x*i-r)),Math.round(this.options.extent*(l.y*i-n))]],tags:l.numPoints?J(l):this.points[l.index].properties},u=l.numPoints?l.id:this.points[l.index].id;void 0!==u&&(c.id=u),a.features.push(c)}},Y.prototype._limitZoom=function(t){return Math.max(this.options.minZoom,Math.min(t,this.options.maxZoom+1))},Y.prototype._cluster=function(t,e){for(var r=[],n=this.options,i=n.radius,a=n.extent,o=n.reduce,s=i/(a*Math.pow(2,e)),l=0;l<t.length;l++){var c=t[l];if(!(c.zoom<=e)){c.zoom=e;for(var u=this.trees[e+1],h=u.within(c.x,c.y,s),f=c.numPoints||1,p=c.x*f,d=c.y*f,g=o?this._map(c,!0):null,v=(l<<5)+(e+1),m=0,y=h;m<y.length;m+=1){var x=y[m],b=u.points[x];if(!(b.zoom<=e)){b.zoom=e;var _=b.numPoints||1;p+=b.x*_,d+=b.y*_,f+=_,b.parentId=v,o&&o(g,this._map(b))}}1===f?r.push(c):(c.parentId=v,r.push(W(p/f,d/f,v,f,g)))}}return r},Y.prototype._map=function(t,e){if(t.numPoints)return e?Q({},t.properties):t.properties;var r=this.points[t.index].properties,n=this.options.map(r);return e&&n===r?Q({},n):n},Mt.prototype.options={maxZoom:14,indexMaxZoom:5,indexMaxPoints:1e5,tolerance:3,extent:4096,buffer:64,lineMetrics:!1,promoteId:null,generateId:!1,debug:0},Mt.prototype.splitTile=function(t,e,r,n,i,a,o){for(var s=[t,e,r,n],l=this.options,c=l.debug;s.length;){n=s.pop(),r=s.pop(),e=s.pop(),t=s.pop();var u=1<<e,h=St(e,r,n),f=this.tiles[h];if(!f&&(c>1&&console.time(\"creation\"),f=this.tiles[h]=kt(t,e,r,n,l),this.tileCoords.push({z:e,x:r,y:n}),c)){c>1&&(console.log(\"tile z%d-%d-%d (features: %d, points: %d, simplified: %d)\",e,r,n,f.numFeatures,f.numPoints,f.numSimplified),console.timeEnd(\"creation\"));var p=\"z\"+e;this.stats[p]=(this.stats[p]||0)+1,this.total++}if(f.source=t,i){if(e===l.maxZoom||e===i)continue;var d=1<<i-e;if(r!==Math.floor(a/d)||n!==Math.floor(o/d))continue}else if(e===l.indexMaxZoom||f.numPoints<=l.indexMaxPoints)continue;if(f.source=null,0!==t.length){c>1&&console.time(\"clipping\");var g,v,m,y,x,b,_=.5*l.buffer/l.extent,w=.5-_,k=.5+_,T=1+_;g=v=m=y=null,x=ht(t,u,r-_,r+k,0,f.minX,f.maxX,l),b=ht(t,u,r+w,r+T,0,f.minX,f.maxX,l),t=null,x&&(g=ht(x,u,n-_,n+k,1,f.minY,f.maxY,l),v=ht(x,u,n+w,n+T,1,f.minY,f.maxY,l),x=null),b&&(m=ht(b,u,n-_,n+k,1,f.minY,f.maxY,l),y=ht(b,u,n+w,n+T,1,f.minY,f.maxY,l),b=null),c>1&&console.timeEnd(\"clipping\"),s.push(g||[],e+1,2*r,2*n),s.push(v||[],e+1,2*r,2*n+1),s.push(m||[],e+1,2*r+1,2*n),s.push(y||[],e+1,2*r+1,2*n+1)}}},Mt.prototype.getTile=function(t,e,r){var n=this.options,i=n.extent,a=n.debug;if(t<0||t>24)return null;var o=1<<t,s=St(t,e=(e%o+o)%o,r);if(this.tiles[s])return _t(this.tiles[s],i);a>1&&console.log(\"drilling down to z%d-%d-%d\",t,e,r);for(var l,c=t,u=e,h=r;!l&&c>0;)c--,u=Math.floor(u/2),h=Math.floor(h/2),l=this.tiles[St(c,u,h)];return l&&l.source?(a>1&&console.log(\"found parent tile z%d-%d-%d\",c,u,h),a>1&&console.time(\"drilling down\"),this.splitTile(l.source,c,u,h,t,e,r),a>1&&console.timeEnd(\"drilling down\"),this.tiles[s]?_t(this.tiles[s],i):null):null};var Ct=function(e){function r(t,r,n){e.call(this,t,r,Et),n&&(this.loadGeoJSON=n)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadData=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),this._pendingCallback=e,this._pendingLoadDataParams=t,this._state&&\"Idle\"!==this._state?this._state=\"NeedsLoadData\":(this._state=\"Coalescing\",this._loadData())},r.prototype._loadData=function(){var e=this;if(this._pendingCallback&&this._pendingLoadDataParams){var r=this._pendingCallback,n=this._pendingLoadDataParams;delete this._pendingCallback,delete this._pendingLoadDataParams;var i=!!(n&&n.request&&n.request.collectResourceTiming)&&new l.Performance(n.request);this.loadGeoJSON(n,function(a,o){if(a||!o)return r(a);if(\"object\"!=typeof o)return r(new Error(\"Input data given to '\"+n.source+\"' is not a valid GeoJSON object.\"));!function t(e,r){switch(e&&e.type||null){case\"FeatureCollection\":return e.features=e.features.map(y(t,r)),e;case\"GeometryCollection\":return e.geometries=e.geometries.map(y(t,r)),e;case\"Feature\":return e.geometry=t(e.geometry,r),e;case\"Polygon\":case\"MultiPolygon\":return function(t,e){return\"Polygon\"===t.type?t.coordinates=x(t.coordinates,e):\"MultiPolygon\"===t.type&&(t.coordinates=t.coordinates.map(y(x,e))),t}(e,r);default:return e}}(o,!0);try{e._geoJSONIndex=n.cluster?new Y(function(e){var r=e.superclusterOptions,n=e.clusterProperties;if(!n||!r)return r;for(var i={},a={},o={accumulated:null,zoom:0},s={properties:null},l=Object.keys(n),c=0,u=l;c<u.length;c+=1){var h=u[c],f=n[h],p=f[0],d=f[1],g=t.createExpression(d),v=t.createExpression(\"string\"==typeof p?[p,[\"accumulated\"],[\"get\",h]]:p);i[h]=g.value,a[h]=v.value}return r.map=function(t){s.properties=t;for(var e={},r=0,n=l;r<n.length;r+=1){var a=n[r];e[a]=i[a].evaluate(o,s)}return e},r.reduce=function(t,e){s.properties=e;for(var r=0,n=l;r<n.length;r+=1){var i=n[r];o.accumulated=t[i],t[i]=a[i].evaluate(o,s)}},r}(n)).load(o.features):new Mt(o,n.geojsonVtOptions)}catch(a){return r(a)}e.loaded={};var s={};if(i){var l=i.finish();l&&(s.resourceTiming={},s.resourceTiming[n.source]=JSON.parse(JSON.stringify(l)))}r(null,s)})}},r.prototype.coalesce=function(){\"Coalescing\"===this._state?this._state=\"Idle\":\"NeedsLoadData\"===this._state&&(this._state=\"Coalescing\",this._loadData())},r.prototype.reloadTile=function(t,r){var n=this.loaded,i=t.uid;return n&&n[i]?e.prototype.reloadTile.call(this,t,r):this.loadTile(t,r)},r.prototype.loadGeoJSON=function(e,r){if(e.request)t.getJSON(e.request,r);else{if(\"string\"!=typeof e.data)return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"));try{return r(null,JSON.parse(e.data))}catch(t){return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"))}}},r.prototype.removeSource=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),e()},r.prototype.getClusterExpansionZoom=function(t,e){e(null,this._geoJSONIndex.getClusterExpansionZoom(t.clusterId))},r.prototype.getClusterChildren=function(t,e){e(null,this._geoJSONIndex.getChildren(t.clusterId))},r.prototype.getClusterLeaves=function(t,e){e(null,this._geoJSONIndex.getLeaves(t.clusterId,t.limit,t.offset))},r}(h),Lt=function(e){var r=this;this.self=e,this.actor=new t.Actor(e,this),this.layerIndexes={},this.workerSourceTypes={vector:h,geojson:Ct},this.workerSources={},this.demWorkerSources={},this.self.registerWorkerSource=function(t,e){if(r.workerSourceTypes[t])throw new Error('Worker source with name \"'+t+'\" already registered.');r.workerSourceTypes[t]=e},this.self.registerRTLTextPlugin=function(e){if(t.plugin.isLoaded())throw new Error(\"RTL text plugin already registered.\");t.plugin.applyArabicShaping=e.applyArabicShaping,t.plugin.processBidirectionalText=e.processBidirectionalText,t.plugin.processStyledBidirectionalText=e.processStyledBidirectionalText}};return Lt.prototype.setReferrer=function(t,e){this.referrer=e},Lt.prototype.setLayers=function(t,e,r){this.getLayerIndex(t).replace(e),r()},Lt.prototype.updateLayers=function(t,e,r){this.getLayerIndex(t).update(e.layers,e.removedIds),r()},Lt.prototype.loadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).loadTile(e,r)},Lt.prototype.loadDEMTile=function(t,e,r){this.getDEMWorkerSource(t,e.source).loadTile(e,r)},Lt.prototype.reloadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).reloadTile(e,r)},Lt.prototype.abortTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).abortTile(e,r)},Lt.prototype.removeTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).removeTile(e,r)},Lt.prototype.removeDEMTile=function(t,e){this.getDEMWorkerSource(t,e.source).removeTile(e)},Lt.prototype.removeSource=function(t,e,r){if(this.workerSources[t]&&this.workerSources[t][e.type]&&this.workerSources[t][e.type][e.source]){var n=this.workerSources[t][e.type][e.source];delete this.workerSources[t][e.type][e.source],void 0!==n.removeSource?n.removeSource(e,r):r()}},Lt.prototype.loadWorkerSource=function(t,e,r){try{this.self.importScripts(e.url),r()}catch(t){r(t.toString())}},Lt.prototype.loadRTLTextPlugin=function(e,r,n){try{t.plugin.isLoaded()||(this.self.importScripts(r),n(t.plugin.isLoaded()?null:new Error(\"RTL Text Plugin failed to import scripts from \"+r)))}catch(t){n(t.toString())}},Lt.prototype.getLayerIndex=function(t){var e=this.layerIndexes[t];return e||(e=this.layerIndexes[t]=new n),e},Lt.prototype.getWorkerSource=function(t,e,r){var n=this;if(this.workerSources[t]||(this.workerSources[t]={}),this.workerSources[t][e]||(this.workerSources[t][e]={}),!this.workerSources[t][e][r]){var i={send:function(e,r,i){n.actor.send(e,r,i,t)}};this.workerSources[t][e][r]=new this.workerSourceTypes[e](i,this.getLayerIndex(t))}return this.workerSources[t][e][r]},Lt.prototype.getDEMWorkerSource=function(t,e){return this.demWorkerSources[t]||(this.demWorkerSources[t]={}),this.demWorkerSources[t][e]||(this.demWorkerSources[t][e]=new f),this.demWorkerSources[t][e]},Lt.prototype.enforceCacheSizeLimit=function(e,r){t.enforceCacheSizeLimit(r)},\"undefined\"!=typeof WorkerGlobalScope&&void 0!==t.window&&t.window instanceof WorkerGlobalScope&&(t.window.worker=new Lt(t.window)),Lt}),n(0,function(t){var e=t.createCommonjsModule(function(t){function e(t){return!!(\"undefined\"!=typeof window&&\"undefined\"!=typeof document&&Array.prototype&&Array.prototype.every&&Array.prototype.filter&&Array.prototype.forEach&&Array.prototype.indexOf&&Array.prototype.lastIndexOf&&Array.prototype.map&&Array.prototype.some&&Array.prototype.reduce&&Array.prototype.reduceRight&&Array.isArray&&Function.prototype&&Function.prototype.bind&&Object.keys&&Object.create&&Object.getPrototypeOf&&Object.getOwnPropertyNames&&Object.isSealed&&Object.isFrozen&&Object.isExtensible&&Object.getOwnPropertyDescriptor&&Object.defineProperty&&Object.defineProperties&&Object.seal&&Object.freeze&&Object.preventExtensions&&\"JSON\"in window&&\"parse\"in JSON&&\"stringify\"in JSON&&function(){if(!(\"Worker\"in window&&\"Blob\"in window&&\"URL\"in window))return!1;var t,e,r=new Blob([\"\"],{type:\"text/javascript\"}),n=URL.createObjectURL(r);try{e=new Worker(n),t=!0}catch(e){t=!1}return e&&e.terminate(),URL.revokeObjectURL(n),t}()&&\"Uint8ClampedArray\"in window&&ArrayBuffer.isView&&function(t){return void 0===r[t]&&(r[t]=function(t){var r=document.createElement(\"canvas\"),n=Object.create(e.webGLContextAttributes);return n.failIfMajorPerformanceCaveat=t,r.probablySupportsContext?r.probablySupportsContext(\"webgl\",n)||r.probablySupportsContext(\"experimental-webgl\",n):r.supportsContext?r.supportsContext(\"webgl\",n)||r.supportsContext(\"experimental-webgl\",n):r.getContext(\"webgl\",n)||r.getContext(\"experimental-webgl\",n)}(t)),r[t]}(t&&t.failIfMajorPerformanceCaveat))}t.exports?t.exports=e:window&&(window.mapboxgl=window.mapboxgl||{},window.mapboxgl.supported=e);var r={};e.webGLContextAttributes={antialias:!1,alpha:!0,stencil:!0,depth:!0}}),r={create:function(e,r,n){var i=t.window.document.createElement(e);return void 0!==r&&(i.className=r),n&&n.appendChild(i),i},createNS:function(e,r){return t.window.document.createElementNS(e,r)}},n=t.window.document.documentElement.style;function i(t){if(!n)return t[0];for(var e=0;e<t.length;e++)if(t[e]in n)return t[e];return t[0]}var a,o=i([\"userSelect\",\"MozUserSelect\",\"WebkitUserSelect\",\"msUserSelect\"]);r.disableDrag=function(){n&&o&&(a=n[o],n[o]=\"none\")},r.enableDrag=function(){n&&o&&(n[o]=a)};var s=i([\"transform\",\"WebkitTransform\"]);r.setTransform=function(t,e){t.style[s]=e};var l=!1;try{var c=Object.defineProperty({},\"passive\",{get:function(){l=!0}});t.window.addEventListener(\"test\",c,c),t.window.removeEventListener(\"test\",c,c)}catch(t){l=!1}r.addEventListener=function(t,e,r,n){void 0===n&&(n={}),\"passive\"in n&&l?t.addEventListener(e,r,n):t.addEventListener(e,r,n.capture)},r.removeEventListener=function(t,e,r,n){void 0===n&&(n={}),\"passive\"in n&&l?t.removeEventListener(e,r,n):t.removeEventListener(e,r,n.capture)};var u=function(e){e.preventDefault(),e.stopPropagation(),t.window.removeEventListener(\"click\",u,!0)};function h(t){var e=t.userImage;return!!(e&&e.render&&e.render())&&(t.data.replace(new Uint8Array(e.data.buffer)),!0)}r.suppressClick=function(){t.window.addEventListener(\"click\",u,!0),t.window.setTimeout(function(){t.window.removeEventListener(\"click\",u,!0)},0)},r.mousePos=function(e,r){var n=e.getBoundingClientRect(),i=t.window.TouchEvent&&r instanceof t.window.TouchEvent?r.touches[0]:r;return new t.Point(i.clientX-n.left-e.clientLeft,i.clientY-n.top-e.clientTop)},r.touchPos=function(e,r){for(var n=e.getBoundingClientRect(),i=[],a=\"touchend\"===r.type?r.changedTouches:r.touches,o=0;o<a.length;o++)i.push(new t.Point(a[o].clientX-n.left-e.clientLeft,a[o].clientY-n.top-e.clientTop));return i},r.mouseButton=function(e){return void 0!==t.window.InstallTrigger&&2===e.button&&e.ctrlKey&&t.window.navigator.platform.toUpperCase().indexOf(\"MAC\")>=0?0:e.button},r.remove=function(t){t.parentNode&&t.parentNode.removeChild(t)};var f=function(e){function r(){e.call(this),this.images={},this.updatedImages={},this.callbackDispatchedThisFrame={},this.loaded=!1,this.requestors=[],this.patterns={},this.atlasImage=new t.RGBAImage({width:1,height:1}),this.dirty=!0}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.isLoaded=function(){return this.loaded},r.prototype.setLoaded=function(t){if(this.loaded!==t&&(this.loaded=t,t)){for(var e=0,r=this.requestors;e<r.length;e+=1){var n=r[e],i=n.ids,a=n.callback;this._notify(i,a)}this.requestors=[]}},r.prototype.getImage=function(t){return this.images[t]},r.prototype.addImage=function(t,e){this.images[t]=e},r.prototype.updateImage=function(t,e){var r=this.images[t];e.version=r.version+1,this.images[t]=e,this.updatedImages[t]=!0},r.prototype.removeImage=function(t){var e=this.images[t];delete this.images[t],delete this.patterns[t],e.userImage&&e.userImage.onRemove&&e.userImage.onRemove()},r.prototype.listImages=function(){return Object.keys(this.images)},r.prototype.getImages=function(t,e){var r=!0;if(!this.isLoaded())for(var n=0,i=t;n<i.length;n+=1){var a=i[n];this.images[a]||(r=!1)}this.isLoaded()||r?this._notify(t,e):this.requestors.push({ids:t,callback:e})},r.prototype._notify=function(e,r){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i];this.images[o]||this.fire(new t.Event(\"styleimagemissing\",{id:o}));var s=this.images[o];s?n[o]={data:s.data.clone(),pixelRatio:s.pixelRatio,sdf:s.sdf,version:s.version,hasRenderCallback:Boolean(s.userImage&&s.userImage.render)}:t.warnOnce('Image \"'+o+'\" could not be loaded. Please make sure you have added the image with map.addImage() or a \"sprite\" property in your style. You can provide missing images by listening for the \"styleimagemissing\" map event.')}r(null,n)},r.prototype.getPixelSize=function(){var t=this.atlasImage;return{width:t.width,height:t.height}},r.prototype.getPattern=function(e){var r=this.patterns[e],n=this.getImage(e);if(!n)return null;if(r&&r.position.version===n.version)return r.position;if(r)r.position.version=n.version;else{var i={w:n.data.width+2,h:n.data.height+2,x:0,y:0},a=new t.ImagePosition(i,n);this.patterns[e]={bin:i,position:a}}return this._updatePatternAtlas(),this.patterns[e].position},r.prototype.bind=function(e){var r=e.gl;this.atlasTexture?this.dirty&&(this.atlasTexture.update(this.atlasImage),this.dirty=!1):this.atlasTexture=new t.Texture(e,this.atlasImage,r.RGBA),this.atlasTexture.bind(r.LINEAR,r.CLAMP_TO_EDGE)},r.prototype._updatePatternAtlas=function(){var e=[];for(var r in this.patterns)e.push(this.patterns[r].bin);var n=t.potpack(e),i=n.w,a=n.h,o=this.atlasImage;for(var s in o.resize({width:i||1,height:a||1}),this.patterns){var l=this.patterns[s].bin,c=l.x+1,u=l.y+1,h=this.images[s].data,f=h.width,p=h.height;t.RGBAImage.copy(h,o,{x:0,y:0},{x:c,y:u},{width:f,height:p}),t.RGBAImage.copy(h,o,{x:0,y:p-1},{x:c,y:u-1},{width:f,height:1}),t.RGBAImage.copy(h,o,{x:0,y:0},{x:c,y:u+p},{width:f,height:1}),t.RGBAImage.copy(h,o,{x:f-1,y:0},{x:c-1,y:u},{width:1,height:p}),t.RGBAImage.copy(h,o,{x:0,y:0},{x:c+f,y:u},{width:1,height:p})}this.dirty=!0},r.prototype.beginFrame=function(){this.callbackDispatchedThisFrame={}},r.prototype.dispatchRenderCallbacks=function(t){for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!this.callbackDispatchedThisFrame[n]){this.callbackDispatchedThisFrame[n]=!0;var i=this.images[n];h(i)&&this.updateImage(n,i)}}},r}(t.Evented),p=g,d=1e20;function g(t,e,r,n,i,a){this.fontSize=t||24,this.buffer=void 0===e?3:e,this.cutoff=n||.25,this.fontFamily=i||\"sans-serif\",this.fontWeight=a||\"normal\",this.radius=r||8;var o=this.size=this.fontSize+2*this.buffer;this.canvas=document.createElement(\"canvas\"),this.canvas.width=this.canvas.height=o,this.ctx=this.canvas.getContext(\"2d\"),this.ctx.font=this.fontWeight+\" \"+this.fontSize+\"px \"+this.fontFamily,this.ctx.textBaseline=\"middle\",this.ctx.fillStyle=\"black\",this.gridOuter=new Float64Array(o*o),this.gridInner=new Float64Array(o*o),this.f=new Float64Array(o),this.d=new Float64Array(o),this.z=new Float64Array(o+1),this.v=new Int16Array(o),this.middle=Math.round(o/2*(navigator.userAgent.indexOf(\"Gecko/\")>=0?1.2:1))}function v(t,e,r,n,i,a,o){for(var s=0;s<e;s++){for(var l=0;l<r;l++)n[l]=t[l*e+s];for(m(n,i,a,o,r),l=0;l<r;l++)t[l*e+s]=i[l]}for(l=0;l<r;l++){for(s=0;s<e;s++)n[s]=t[l*e+s];for(m(n,i,a,o,e),s=0;s<e;s++)t[l*e+s]=Math.sqrt(i[s])}}function m(t,e,r,n,i){r[0]=0,n[0]=-d,n[1]=+d;for(var a=1,o=0;a<i;a++){for(var s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);s<=n[o];)o--,s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);r[++o]=a,n[o]=s,n[o+1]=+d}for(a=0,o=0;a<i;a++){for(;n[o+1]<a;)o++;e[a]=(a-r[o])*(a-r[o])+t[r[o]]}}g.prototype.draw=function(t){this.ctx.clearRect(0,0,this.size,this.size),this.ctx.fillText(t,this.buffer,this.middle);for(var e=this.ctx.getImageData(0,0,this.size,this.size),r=new Uint8ClampedArray(this.size*this.size),n=0;n<this.size*this.size;n++){var i=e.data[4*n+3]/255;this.gridOuter[n]=1===i?0:0===i?d:Math.pow(Math.max(0,.5-i),2),this.gridInner[n]=1===i?d:0===i?0:Math.pow(Math.max(0,i-.5),2)}for(v(this.gridOuter,this.size,this.size,this.f,this.d,this.v,this.z),v(this.gridInner,this.size,this.size,this.f,this.d,this.v,this.z),n=0;n<this.size*this.size;n++){var a=this.gridOuter[n]-this.gridInner[n];r[n]=Math.max(0,Math.min(255,Math.round(255-255*(a/this.radius+this.cutoff))))}return r};var y=function(t,e){this.requestManager=t,this.localIdeographFontFamily=e,this.entries={}};y.prototype.setURL=function(t){this.url=t},y.prototype.getGlyphs=function(e,r){var n=this,i=[];for(var a in e)for(var o=0,s=e[a];o<s.length;o+=1){var l=s[o];i.push({stack:a,id:l})}t.asyncAll(i,function(t,e){var r=t.stack,i=t.id,a=n.entries[r];a||(a=n.entries[r]={glyphs:{},requests:{}});var o=a.glyphs[i];if(void 0===o)if(o=n._tinySDF(a,r,i))e(null,{stack:r,id:i,glyph:o});else{var s=Math.floor(i/256);if(256*s>65535)e(new Error(\"glyphs > 65535 not supported\"));else{var l=a.requests[s];l||(l=a.requests[s]=[],y.loadGlyphRange(r,s,n.url,n.requestManager,function(t,e){if(e)for(var r in e)a.glyphs[+r]=e[+r];for(var n=0,i=l;n<i.length;n+=1)(0,i[n])(t,e);delete a.requests[s]})),l.push(function(t,n){t?e(t):n&&e(null,{stack:r,id:i,glyph:n[i]||null})})}}else e(null,{stack:r,id:i,glyph:o})},function(t,e){if(t)r(t);else if(e){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.stack,l=o.id,c=o.glyph;(n[s]||(n[s]={}))[l]=c&&{id:c.id,bitmap:c.bitmap.clone(),metrics:c.metrics}}r(null,n)}})},y.prototype._tinySDF=function(e,r,n){var i=this.localIdeographFontFamily;if(i&&(t.isChar[\"CJK Unified Ideographs\"](n)||t.isChar[\"Hangul Syllables\"](n)||t.isChar.Hiragana(n)||t.isChar.Katakana(n))){var a=e.tinySDF;if(!a){var o=\"400\";/bold/i.test(r)?o=\"900\":/medium/i.test(r)?o=\"500\":/light/i.test(r)&&(o=\"200\"),a=e.tinySDF=new y.TinySDF(24,3,8,.25,i,o)}return{id:n,bitmap:new t.AlphaImage({width:30,height:30},a.draw(String.fromCharCode(n))),metrics:{width:24,height:24,left:0,top:-8,advance:24}}}},y.loadGlyphRange=function(e,r,n,i,a){var o=256*r,s=o+255,l=i.transformRequest(i.normalizeGlyphsURL(n).replace(\"{fontstack}\",e).replace(\"{range}\",o+\"-\"+s),t.ResourceType.Glyphs);t.getArrayBuffer(l,function(e,r){if(e)a(e);else if(r){for(var n={},i=0,o=t.parseGlyphPBF(r);i<o.length;i+=1){var s=o[i];n[s.id]=s}a(null,n)}})},y.TinySDF=p;var x=function(){this.specification=t.styleSpec.light.position};x.prototype.possiblyEvaluate=function(e,r){return t.sphericalToCartesian(e.expression.evaluate(r))},x.prototype.interpolate=function(e,r,n){return{x:t.number(e.x,r.x,n),y:t.number(e.y,r.y,n),z:t.number(e.z,r.z,n)}};var b=new t.Properties({anchor:new t.DataConstantProperty(t.styleSpec.light.anchor),position:new x,color:new t.DataConstantProperty(t.styleSpec.light.color),intensity:new t.DataConstantProperty(t.styleSpec.light.intensity)}),_=function(e){function r(r){e.call(this),this._transitionable=new t.Transitionable(b),this.setLight(r),this._transitioning=this._transitionable.untransitioned()}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getLight=function(){return this._transitionable.serialize()},r.prototype.setLight=function(e,r){if(void 0===r&&(r={}),!this._validate(t.validateLight,e,r))for(var n in e){var i=e[n];t.endsWith(n,\"-transition\")?this._transitionable.setTransition(n.slice(0,-\"-transition\".length),i):this._transitionable.setValue(n,i)}},r.prototype.updateTransitions=function(t){this._transitioning=this._transitionable.transitioned(t,this._transitioning)},r.prototype.hasTransition=function(){return this._transitioning.hasTransition()},r.prototype.recalculate=function(t){this.properties=this._transitioning.possiblyEvaluate(t)},r.prototype._validate=function(e,r,n){return(!n||!1!==n.validate)&&t.emitValidationErrors(this,e.call(t.validateStyle,t.extend({value:r,style:{glyphs:!0,sprite:!0},styleSpec:t.styleSpec})))},r}(t.Evented),w=function(t,e){this.width=t,this.height=e,this.nextRow=0,this.bytes=4,this.data=new Uint8Array(this.width*this.height*this.bytes),this.positions={}};w.prototype.getDash=function(t,e){var r=t.join(\",\")+String(e);return this.positions[r]||(this.positions[r]=this.addDash(t,e)),this.positions[r]},w.prototype.addDash=function(e,r){var n=r?7:0,i=2*n+1;if(this.nextRow+i>this.height)return t.warnOnce(\"LineAtlas out of space\"),null;for(var a=0,o=0;o<e.length;o++)a+=e[o];for(var s=this.width/a,l=s/2,c=e.length%2==1,u=-n;u<=n;u++)for(var h=this.nextRow+n+u,f=this.width*h,p=c?-e[e.length-1]:0,d=e[0],g=1,v=0;v<this.width;v++){for(;d<v/s;)p=d,d+=e[g],c&&g===e.length-1&&(d+=e[0]),g++;var m=Math.abs(v-p*s),y=Math.abs(v-d*s),x=Math.min(m,y),b=g%2==1,_=void 0;if(r){var w=n?u/n*(l+1):0;if(b){var k=l-Math.abs(w);_=Math.sqrt(x*x+k*k)}else _=l-Math.sqrt(x*x+w*w)}else _=(b?1:-1)*x;this.data[3+4*(f+v)]=Math.max(0,Math.min(255,_+128))}var T={y:(this.nextRow+n+.5)/this.height,height:2*n/this.height,width:a};return this.nextRow+=i,this.dirty=!0,T},w.prototype.bind=function(t){var e=t.gl;this.texture?(e.bindTexture(e.TEXTURE_2D,this.texture),this.dirty&&(this.dirty=!1,e.texSubImage2D(e.TEXTURE_2D,0,0,0,this.width,this.height,e.RGBA,e.UNSIGNED_BYTE,this.data))):(this.texture=e.createTexture(),e.bindTexture(e.TEXTURE_2D,this.texture),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_S,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_T,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,e.LINEAR),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,e.LINEAR),e.texImage2D(e.TEXTURE_2D,0,e.RGBA,this.width,this.height,0,e.RGBA,e.UNSIGNED_BYTE,this.data))};var k=function e(r,n){this.workerPool=r,this.actors=[],this.currentActor=0,this.id=t.uniqueId();for(var i=this.workerPool.acquire(this.id),a=0;a<i.length;a++){var o=i[a],s=new e.Actor(o,n,this.id);s.name=\"Worker \"+a,this.actors.push(s)}};function T(e,r,n){var i=function(i,a){if(i)return n(i);if(a){var o=t.pick(a,[\"tiles\",\"minzoom\",\"maxzoom\",\"attribution\",\"mapbox_logo\",\"bounds\"]);a.vector_layers&&(o.vectorLayers=a.vector_layers,o.vectorLayerIds=o.vectorLayers.map(function(t){return t.id})),e.url&&(o.tiles=r.canonicalizeTileset(o,e.url)),n(null,o)}};return e.url?t.getJSON(r.transformRequest(r.normalizeSourceURL(e.url),t.ResourceType.Source),i):t.browser.frame(function(){return i(null,e)})}k.prototype.broadcast=function(e,r,n){n=n||function(){},t.asyncAll(this.actors,function(t,n){t.send(e,r,n)},n)},k.prototype.send=function(t,e,r,n){return(\"number\"!=typeof n||isNaN(n))&&(n=this.currentActor=(this.currentActor+1)%this.actors.length),this.actors[n].send(t,e,r),n},k.prototype.remove=function(){this.actors.forEach(function(t){t.remove()}),this.actors=[],this.workerPool.release(this.id)},k.Actor=t.Actor;var A=function(e,r,n){this.bounds=t.LngLatBounds.convert(this.validateBounds(e)),this.minzoom=r||0,this.maxzoom=n||24};A.prototype.validateBounds=function(t){return Array.isArray(t)&&4===t.length?[Math.max(-180,t[0]),Math.max(-90,t[1]),Math.min(180,t[2]),Math.min(90,t[3])]:[-180,-90,180,90]},A.prototype.contains=function(e){var r=Math.pow(2,e.z),n=Math.floor(t.mercatorXfromLng(this.bounds.getWest())*r),i=Math.floor(t.mercatorYfromLat(this.bounds.getNorth())*r),a=Math.ceil(t.mercatorXfromLng(this.bounds.getEast())*r),o=Math.ceil(t.mercatorYfromLat(this.bounds.getSouth())*r);return e.x>=n&&e.x<a&&e.y>=i&&e.y<o};var M=function(e){function r(r,n,i,a){if(e.call(this),this.id=r,this.dispatcher=i,this.type=\"vector\",this.minzoom=0,this.maxzoom=22,this.scheme=\"xyz\",this.tileSize=512,this.reparseOverscaled=!0,this.isTileClipped=!0,t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"])),this._options=t.extend({type:\"vector\"},n),this._collectResourceTiming=n.collectResourceTiming,512!==this.tileSize)throw new Error(\"vector tile sources must have a tileSize of 512\");this.setEventedParent(a)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=T(this._options,this.map._requestManager,function(r,n){e._tileJSONRequest=null,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))})},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,null),i={request:this.map._requestManager.transformRequest(n,t.ResourceType.Tile),uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,tileSize:this.tileSize*e.tileID.overscaleFactor(),type:this.type,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes};function a(n,i){return e.aborted?r(null):n&&404!==n.status?r(n):(i&&i.resourceTiming&&(e.resourceTiming=i.resourceTiming),this.map._refreshExpiredTiles&&i&&e.setExpiryData(i),e.loadVectorData(i,this.map.painter),t.cacheEntryPossiblyAdded(this.dispatcher),r(null),void(e.reloadCallback&&(this.loadTile(e,e.reloadCallback),e.reloadCallback=null)))}i.request.collectResourceTiming=this._collectResourceTiming,void 0===e.workerID||\"expired\"===e.state?e.workerID=this.dispatcher.send(\"loadTile\",i,a.bind(this)):\"loading\"===e.state?e.reloadCallback=r:this.dispatcher.send(\"reloadTile\",i,a.bind(this),e.workerID)},r.prototype.abortTile=function(t){this.dispatcher.send(\"abortTile\",{uid:t.uid,type:this.type,source:this.id},void 0,t.workerID)},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.dispatcher.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},void 0,t.workerID)},r.prototype.hasTransition=function(){return!1},r}(t.Evented),S=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.dispatcher=i,this.setEventedParent(a),this.type=\"raster\",this.minzoom=0,this.maxzoom=22,this.roundZoom=!0,this.scheme=\"xyz\",this.tileSize=512,this._loaded=!1,this._options=t.extend({},n),t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"]))}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=T(this._options,this.map._requestManager,function(r,n){e._tileJSONRequest=null,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))})},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.loadTile=function(e,r){var n=this,i=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(i,t.ResourceType.Tile),function(i,a){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(i)e.state=\"errored\",r(i);else if(a){n.map._refreshExpiredTiles&&e.setExpiryData(a),delete a.cacheControl,delete a.expires;var o=n.map.painter.context,s=o.gl;e.texture=n.map.painter.getTileTexture(a.width),e.texture?e.texture.update(a,{useMipmap:!0}):(e.texture=new t.Texture(o,a,s.RGBA,{useMipmap:!0}),e.texture.bind(s.LINEAR,s.CLAMP_TO_EDGE,s.LINEAR_MIPMAP_NEAREST),o.extTextureFilterAnisotropic&&s.texParameterf(s.TEXTURE_2D,o.extTextureFilterAnisotropic.TEXTURE_MAX_ANISOTROPY_EXT,o.extTextureFilterAnisotropicMax)),e.state=\"loaded\",t.cacheEntryPossiblyAdded(n.dispatcher),r(null)}})},r.prototype.abortTile=function(t,e){t.request&&(t.request.cancel(),delete t.request),e()},r.prototype.unloadTile=function(t,e){t.texture&&this.map.painter.saveTileTexture(t.texture),e()},r.prototype.hasTransition=function(){return!1},r}(t.Evented),E=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),this.type=\"raster-dem\",this.maxzoom=22,this._options=t.extend({},n),this.encoding=n.encoding||\"mapbox\"}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.serialize=function(){return{type:\"raster-dem\",url:this.url,tileSize:this.tileSize,tiles:this.tiles,bounds:this.bounds,encoding:this.encoding}},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.url,this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(n,t.ResourceType.Tile),function(n,i){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(n)e.state=\"errored\",r(n);else if(i){this.map._refreshExpiredTiles&&e.setExpiryData(i),delete i.cacheControl,delete i.expires;var a=t.browser.getImageData(i),o={uid:e.uid,coord:e.tileID,source:this.id,rawImageData:a,encoding:this.encoding};e.workerID&&\"expired\"!==e.state||(e.workerID=this.dispatcher.send(\"loadDEMTile\",o,function(t,n){t&&(e.state=\"errored\",r(t)),n&&(e.dem=n,e.needsHillshadePrepare=!0,e.state=\"loaded\",r(null))}.bind(this)))}}.bind(this)),e.neighboringTiles=this._getNeighboringTiles(e.tileID)},r.prototype._getNeighboringTiles=function(e){var r=e.canonical,n=Math.pow(2,r.z),i=(r.x-1+n)%n,a=0===r.x?e.wrap-1:e.wrap,o=(r.x+1+n)%n,s=r.x+1===n?e.wrap+1:e.wrap,l={};return l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y).key]={backfilled:!1},r.y>0&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y-1).key]={backfilled:!1}),r.y+1<n&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y+1).key]={backfilled:!1}),l},r.prototype.unloadTile=function(t){t.demTexture&&this.map.painter.saveTileTexture(t.demTexture),t.fbo&&(t.fbo.destroy(),delete t.fbo),t.dem&&delete t.dem,delete t.neighboringTiles,t.state=\"unloaded\",this.dispatcher.send(\"removeDEMTile\",{uid:t.uid,source:this.id},void 0,t.workerID)},r}(S),C=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.type=\"geojson\",this.minzoom=0,this.maxzoom=18,this.tileSize=512,this.isTileClipped=!0,this.reparseOverscaled=!0,this._removed=!1,this.dispatcher=i,this.setEventedParent(a),this._data=n.data,this._options=t.extend({},n),this._collectResourceTiming=n.collectResourceTiming,this._resourceTiming=[],void 0!==n.maxzoom&&(this.maxzoom=n.maxzoom),n.type&&(this.type=n.type),n.attribution&&(this.attribution=n.attribution);var o=t.EXTENT/this.tileSize;this.workerOptions=t.extend({source:this.id,cluster:n.cluster||!1,geojsonVtOptions:{buffer:(void 0!==n.buffer?n.buffer:128)*o,tolerance:(void 0!==n.tolerance?n.tolerance:.375)*o,extent:t.EXTENT,maxZoom:this.maxzoom,lineMetrics:n.lineMetrics||!1,generateId:n.generateId||!1},superclusterOptions:{maxZoom:void 0!==n.clusterMaxZoom?Math.min(n.clusterMaxZoom,this.maxzoom-1):this.maxzoom-1,extent:t.EXTENT,radius:(n.clusterRadius||50)*o,log:!1},clusterProperties:n.clusterProperties},n.workerOptions)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData(function(r){if(r)e.fire(new t.ErrorEvent(r));else{var n={dataType:\"source\",sourceDataType:\"metadata\"};e._collectResourceTiming&&e._resourceTiming&&e._resourceTiming.length>0&&(n.resourceTiming=e._resourceTiming,e._resourceTiming=[]),e.fire(new t.Event(\"data\",n))}})},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setData=function(e){var r=this;return this._data=e,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData(function(e){if(e)r.fire(new t.ErrorEvent(e));else{var n={dataType:\"source\",sourceDataType:\"content\"};r._collectResourceTiming&&r._resourceTiming&&r._resourceTiming.length>0&&(n.resourceTiming=r._resourceTiming,r._resourceTiming=[]),r.fire(new t.Event(\"data\",n))}}),this},r.prototype.getClusterExpansionZoom=function(t,e){return this.dispatcher.send(\"geojson.getClusterExpansionZoom\",{clusterId:t,source:this.id},e,this.workerID),this},r.prototype.getClusterChildren=function(t,e){return this.dispatcher.send(\"geojson.getClusterChildren\",{clusterId:t,source:this.id},e,this.workerID),this},r.prototype.getClusterLeaves=function(t,e,r,n){return this.dispatcher.send(\"geojson.getClusterLeaves\",{source:this.id,clusterId:t,limit:e,offset:r},n,this.workerID),this},r.prototype._updateWorkerData=function(e){var r=this,n=t.extend({},this.workerOptions),i=this._data;\"string\"==typeof i?(n.request=this.map._requestManager.transformRequest(t.browser.resolveURL(i),t.ResourceType.Source),n.request.collectResourceTiming=this._collectResourceTiming):n.data=JSON.stringify(i),this.workerID=this.dispatcher.send(this.type+\".loadData\",n,function(t,i){r._removed||i&&i.abandoned||(r._loaded=!0,i&&i.resourceTiming&&i.resourceTiming[r.id]&&(r._resourceTiming=i.resourceTiming[r.id].slice(0)),r.dispatcher.send(r.type+\".coalesce\",{source:n.source},null,r.workerID),e(t))},this.workerID)},r.prototype.loadTile=function(e,r){var n=this,i=void 0===e.workerID?\"loadTile\":\"reloadTile\",a={type:this.type,uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,maxZoom:this.maxzoom,tileSize:this.tileSize,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes};e.workerID=this.dispatcher.send(i,a,function(t,a){return e.unloadVectorData(),e.aborted?r(null):t?r(t):(e.loadVectorData(a,n.map.painter,\"reloadTile\"===i),r(null))},this.workerID)},r.prototype.abortTile=function(t){t.aborted=!0},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.dispatcher.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},null,t.workerID)},r.prototype.onRemove=function(){this._removed=!0,this.dispatcher.send(\"removeSource\",{type:this.type,source:this.id},null,this.workerID)},r.prototype.serialize=function(){return t.extend({},this._options,{type:this.type,data:this._data})},r.prototype.hasTransition=function(){return!1},r}(t.Evented),L=function(e){function r(t,r,n,i){e.call(this),this.id=t,this.dispatcher=n,this.coordinates=r.coordinates,this.type=\"image\",this.minzoom=0,this.maxzoom=22,this.tileSize=512,this.tiles={},this.setEventedParent(i),this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(e,r){var n=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this.url=this.options.url,t.getImage(this.map._requestManager.transformRequest(this.url,t.ResourceType.Image),function(i,a){i?n.fire(new t.ErrorEvent(i)):a&&(n.image=a,e&&(n.coordinates=e),r&&r(),n._finishLoading())})},r.prototype.updateImage=function(t){var e=this;return this.image&&t.url?(this.options.url=t.url,this.load(t.coordinates,function(){e.texture=null}),this):this},r.prototype._finishLoading=function(){this.map&&(this.setCoordinates(this.coordinates),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setCoordinates=function(e){var r=this;this.coordinates=e;var n=e.map(t.MercatorCoordinate.fromLngLat);this.tileID=function(e){for(var r=1/0,n=1/0,i=-1/0,a=-1/0,o=0,s=e;o<s.length;o+=1){var l=s[o];r=Math.min(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.x),a=Math.max(a,l.y)}var c=i-r,u=a-n,h=Math.max(c,u),f=Math.max(0,Math.floor(-Math.log(h)/Math.LN2)),p=Math.pow(2,f);return new t.CanonicalTileID(f,Math.floor((r+i)/2*p),Math.floor((n+a)/2*p))}(n),this.minzoom=this.maxzoom=this.tileID.z;var i=n.map(function(t){return r.tileID.getTilePoint(t)._round()});return this._boundsArray=new t.StructArrayLayout4i8,this._boundsArray.emplaceBack(i[0].x,i[0].y,0,0),this._boundsArray.emplaceBack(i[1].x,i[1].y,t.EXTENT,0),this._boundsArray.emplaceBack(i[3].x,i[3].y,0,t.EXTENT),this._boundsArray.emplaceBack(i[2].x,i[2].y,t.EXTENT,t.EXTENT),this.boundsBuffer&&(this.boundsBuffer.destroy(),delete this.boundsBuffer),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})),this},r.prototype.prepare=function(){if(0!==Object.keys(this.tiles).length&&this.image){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture||(this.texture=new t.Texture(e,this.image,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.loadTile=function(t,e){this.tileID&&this.tileID.equals(t.tileID.canonical)?(this.tiles[String(t.tileID.wrap)]=t,t.buckets={},e(null)):(t.state=\"errored\",e(null))},r.prototype.serialize=function(){return{type:\"image\",url:this.options.url,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return!1},r}(t.Evented),P=function(e){function r(t,r,n,i){e.call(this,t,r,n,i),this.roundZoom=!0,this.type=\"video\",this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this,r=this.options;this.urls=[];for(var n=0,i=r.urls;n<i.length;n+=1){var a=i[n];this.urls.push(this.map._requestManager.transformRequest(a,t.ResourceType.Source).url)}t.getVideo(this.urls,function(r,n){r?e.fire(new t.ErrorEvent(r)):n&&(e.video=n,e.video.loop=!0,e.video.addEventListener(\"playing\",function(){e.map.triggerRepaint()}),e.map&&e.video.play(),e._finishLoading())})},r.prototype.getVideo=function(){return this.video},r.prototype.onAdd=function(t){this.map||(this.map=t,this.load(),this.video&&(this.video.play(),this.setCoordinates(this.coordinates)))},r.prototype.prepare=function(){if(!(0===Object.keys(this.tiles).length||this.video.readyState<2)){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?this.video.paused||(this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE),r.texSubImage2D(r.TEXTURE_2D,0,0,0,r.RGBA,r.UNSIGNED_BYTE,this.video)):(this.texture=new t.Texture(e,this.video,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"video\",urls:this.urls,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this.video&&!this.video.paused},r}(L),O=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),n.coordinates?Array.isArray(n.coordinates)&&4===n.coordinates.length&&!n.coordinates.some(function(t){return!Array.isArray(t)||2!==t.length||t.some(function(t){return\"number\"!=typeof t})})||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"coordinates\" property must be an array of 4 longitude/latitude array pairs'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"coordinates\"'))),n.animate&&\"boolean\"!=typeof n.animate&&this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'optional \"animate\" property must be a boolean value'))),n.canvas?\"string\"==typeof n.canvas||n.canvas instanceof t.window.HTMLCanvasElement||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"canvas\" must be either a string representing the ID of the canvas element from which to read, or an HTMLCanvasElement instance'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"canvas\"'))),this.options=n,this.animate=void 0===n.animate||n.animate}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){this.canvas||(this.canvas=this.options.canvas instanceof t.window.HTMLCanvasElement?this.options.canvas:t.window.document.getElementById(this.options.canvas)),this.width=this.canvas.width,this.height=this.canvas.height,this._hasInvalidDimensions()?this.fire(new t.ErrorEvent(new Error(\"Canvas dimensions cannot be less than or equal to zero.\"))):(this.play=function(){this._playing=!0,this.map.triggerRepaint()},this.pause=function(){this._playing&&(this.prepare(),this._playing=!1)},this._finishLoading())},r.prototype.getCanvas=function(){return this.canvas},r.prototype.onAdd=function(t){this.map=t,this.load(),this.canvas&&this.animate&&this.play()},r.prototype.onRemove=function(){this.pause()},r.prototype.prepare=function(){var e=!1;if(this.canvas.width!==this.width&&(this.width=this.canvas.width,e=!0),this.canvas.height!==this.height&&(this.height=this.canvas.height,e=!0),!this._hasInvalidDimensions()&&0!==Object.keys(this.tiles).length){var r=this.map.painter.context,n=r.gl;for(var i in this.boundsBuffer||(this.boundsBuffer=r.createVertexBuffer(this._boundsArray,t.rasterBoundsAttributes.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?(e||this._playing)&&this.texture.update(this.canvas,{premultiply:!0}):this.texture=new t.Texture(r,this.canvas,n.RGBA,{premultiply:!0}),this.tiles){var a=this.tiles[i];\"loaded\"!==a.state&&(a.state=\"loaded\",a.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"canvas\",coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this._playing},r.prototype._hasInvalidDimensions=function(){for(var t=0,e=[this.canvas.width,this.canvas.height];t<e.length;t+=1){var r=e[t];if(isNaN(r)||r<=0)return!0}return!1},r}(L),z={vector:M,raster:S,\"raster-dem\":E,geojson:C,video:P,image:L,canvas:O},I=function(e,r,n,i){var a=new z[r.type](e,r,n,i);if(a.id!==e)throw new Error(\"Expected Source id to be \"+e+\" instead of \"+a.id);return t.bindAll([\"load\",\"abort\",\"unload\",\"serialize\",\"prepare\"],a),a};function D(e,r){var n=t.identity([]);return t.translate(n,n,[1,1,0]),t.scale(n,n,[.5*e.width,.5*e.height,1]),t.multiply(n,n,e.calculatePosMatrix(r.toUnwrapped()))}function R(t,e,r,n,i){var a=function(t,e,r){if(t)for(var n=0,i=t;n<i.length;n+=1){var a=e[i[n]];if(a&&a.source===r&&\"fill-extrusion\"===a.type)return!0}else for(var o in e){var s=e[o];if(s.source===r&&\"fill-extrusion\"===s.type)return!0}return!1}(n&&n.layers,e,t.id),o=i.maxPitchScaleFactor(),s=t.tilesIn(r,o,a);s.sort(F);for(var l=[],c=0,u=s;c<u.length;c+=1){var h=u[c];l.push({wrappedTileID:h.tileID.wrapped().key,queryResults:h.tile.queryRenderedFeatures(e,t._state,h.queryGeometry,h.cameraQueryGeometry,h.scale,n,i,o,D(t.transform,h.tileID))})}var f=function(t){for(var e={},r={},n=0,i=t;n<i.length;n+=1){var a=i[n],o=a.queryResults,s=a.wrappedTileID,l=r[s]=r[s]||{};for(var c in o)for(var u=o[c],h=l[c]=l[c]||{},f=e[c]=e[c]||[],p=0,d=u;p<d.length;p+=1){var g=d[p];h[g.featureIndex]||(h[g.featureIndex]=!0,f.push(g))}}return e}(l);for(var p in f)f[p].forEach(function(e){var r=e.feature,n=t.getFeatureState(r.layer[\"source-layer\"],r.id);r.source=r.layer.source,r.layer[\"source-layer\"]&&(r.sourceLayer=r.layer[\"source-layer\"]),r.state=n});return f}function F(t,e){var r=t.tileID,n=e.tileID;return r.overscaledZ-n.overscaledZ||r.canonical.y-n.canonical.y||r.wrap-n.wrap||r.canonical.x-n.canonical.x}var B=function(t,e){this.max=t,this.onRemove=e,this.reset()};B.prototype.reset=function(){for(var t in this.data)for(var e=0,r=this.data[t];e<r.length;e+=1){var n=r[e];n.timeout&&clearTimeout(n.timeout),this.onRemove(n.value)}return this.data={},this.order=[],this},B.prototype.add=function(t,e,r){var n=this,i=t.wrapped().key;void 0===this.data[i]&&(this.data[i]=[]);var a={value:e,timeout:void 0};if(void 0!==r&&(a.timeout=setTimeout(function(){n.remove(t,a)},r)),this.data[i].push(a),this.order.push(i),this.order.length>this.max){var o=this._getAndRemoveByKey(this.order[0]);o&&this.onRemove(o)}return this},B.prototype.has=function(t){return t.wrapped().key in this.data},B.prototype.getAndRemove=function(t){return this.has(t)?this._getAndRemoveByKey(t.wrapped().key):null},B.prototype._getAndRemoveByKey=function(t){var e=this.data[t].shift();return e.timeout&&clearTimeout(e.timeout),0===this.data[t].length&&delete this.data[t],this.order.splice(this.order.indexOf(t),1),e.value},B.prototype.get=function(t){return this.has(t)?this.data[t.wrapped().key][0].value:null},B.prototype.remove=function(t,e){if(!this.has(t))return this;var r=t.wrapped().key,n=void 0===e?0:this.data[r].indexOf(e),i=this.data[r][n];return this.data[r].splice(n,1),i.timeout&&clearTimeout(i.timeout),0===this.data[r].length&&delete this.data[r],this.onRemove(i.value),this.order.splice(this.order.indexOf(r),1),this},B.prototype.setMaxSize=function(t){for(this.max=t;this.order.length>this.max;){var e=this._getAndRemoveByKey(this.order[0]);e&&this.onRemove(e)}return this};var N=function(t,e,r){this.context=t;var n=t.gl;this.buffer=n.createBuffer(),this.dynamicDraw=Boolean(r),this.context.unbindVAO(),t.bindElementBuffer.set(this.buffer),n.bufferData(n.ELEMENT_ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?n.DYNAMIC_DRAW:n.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};N.prototype.bind=function(){this.context.bindElementBuffer.set(this.buffer)},N.prototype.updateData=function(t){var e=this.context.gl;this.context.unbindVAO(),this.bind(),e.bufferSubData(e.ELEMENT_ARRAY_BUFFER,0,t.arrayBuffer)},N.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var j={Int8:\"BYTE\",Uint8:\"UNSIGNED_BYTE\",Int16:\"SHORT\",Uint16:\"UNSIGNED_SHORT\",Int32:\"INT\",Uint32:\"UNSIGNED_INT\",Float32:\"FLOAT\"},U=function(t,e,r,n){this.length=e.length,this.attributes=r,this.itemSize=e.bytesPerElement,this.dynamicDraw=n,this.context=t;var i=t.gl;this.buffer=i.createBuffer(),t.bindVertexBuffer.set(this.buffer),i.bufferData(i.ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?i.DYNAMIC_DRAW:i.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};U.prototype.bind=function(){this.context.bindVertexBuffer.set(this.buffer)},U.prototype.updateData=function(t){var e=this.context.gl;this.bind(),e.bufferSubData(e.ARRAY_BUFFER,0,t.arrayBuffer)},U.prototype.enableAttributes=function(t,e){for(var r=0;r<this.attributes.length;r++){var n=this.attributes[r],i=e.attributes[n.name];void 0!==i&&t.enableVertexAttribArray(i)}},U.prototype.setVertexAttribPointers=function(t,e,r){for(var n=0;n<this.attributes.length;n++){var i=this.attributes[n],a=e.attributes[i.name];void 0!==a&&t.vertexAttribPointer(a,i.components,t[j[i.type]],!1,this.itemSize,i.offset+this.itemSize*(r||0))}},U.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var V=function(t){this.gl=t.gl,this.default=this.getDefault(),this.current=this.default,this.dirty=!1};V.prototype.get=function(){return this.current},V.prototype.set=function(t){},V.prototype.getDefault=function(){return this.default},V.prototype.setDefault=function(){this.set(this.default)};var q=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.clearColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(V),H=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 1},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearDepth(t),this.current=t,this.dirty=!1)},e}(V),G=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearStencil(t),this.current=t,this.dirty=!1)},e}(V),Y=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return[!0,!0,!0,!0]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.colorMask(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(V),W=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthMask(t),this.current=t,this.dirty=!1)},e}(V),X=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 255},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.stencilMask(t),this.current=t,this.dirty=!1)},e}(V),Z=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return{func:this.gl.ALWAYS,ref:0,mask:255}},e.prototype.set=function(t){var e=this.current;(t.func!==e.func||t.ref!==e.ref||t.mask!==e.mask||this.dirty)&&(this.gl.stencilFunc(t.func,t.ref,t.mask),this.current=t,this.dirty=!1)},e}(V),J=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.KEEP,t.KEEP,t.KEEP]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||this.dirty)&&(this.gl.stencilOp(t[0],t[1],t[2]),this.current=t,this.dirty=!1)},e}(V),K=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.STENCIL_TEST):e.disable(e.STENCIL_TEST),this.current=t,this.dirty=!1}},e}(V),$=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return[0,1]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.depthRange(t[0],t[1]),this.current=t,this.dirty=!1)},e}(V),Q=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.DEPTH_TEST):e.disable(e.DEPTH_TEST),this.current=t,this.dirty=!1}},e}(V),tt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.LESS},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthFunc(t),this.current=t,this.dirty=!1)},e}(V),et=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.BLEND):e.disable(e.BLEND),this.current=t,this.dirty=!1}},e}(V),rt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.ONE,t.ZERO]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.blendFunc(t[0],t[1]),this.current=t,this.dirty=!1)},e}(V),nt=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.blendColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(V),it=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.FUNC_ADD},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.blendEquation(t),this.current=t,this.dirty=!1)},e}(V),at=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.CULL_FACE):e.disable(e.CULL_FACE),this.current=t,this.dirty=!1}},e}(V),ot=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.BACK},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.cullFace(t),this.current=t,this.dirty=!1)},e}(V),st=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.CCW},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.frontFace(t),this.current=t,this.dirty=!1)},e}(V),lt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.useProgram(t),this.current=t,this.dirty=!1)},e}(V),ct=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.TEXTURE0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.activeTexture(t),this.current=t,this.dirty=!1)},e}(V),ut=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[0,0,t.drawingBufferWidth,t.drawingBufferHeight]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.viewport(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(V),ht=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindFramebuffer(e.FRAMEBUFFER,t),this.current=t,this.dirty=!1}},e}(V),ft=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindRenderbuffer(e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(V),pt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindTexture(e.TEXTURE_2D,t),this.current=t,this.dirty=!1}},e}(V),dt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindBuffer(e.ARRAY_BUFFER,t),this.current=t,this.dirty=!1}},e}(V),gt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){var e=this.gl;e.bindBuffer(e.ELEMENT_ARRAY_BUFFER,t),this.current=t,this.dirty=!1},e}(V),vt=function(t){function e(e){t.call(this,e),this.vao=e.extVertexArrayObject}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){this.vao&&(t!==this.current||this.dirty)&&(this.vao.bindVertexArrayOES(t),this.current=t,this.dirty=!1)},e}(V),mt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 4},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_ALIGNMENT,t),this.current=t,this.dirty=!1}},e}(V),yt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_PREMULTIPLY_ALPHA_WEBGL,t),this.current=t,this.dirty=!1}},e}(V),xt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_FLIP_Y_WEBGL,t),this.current=t,this.dirty=!1}},e}(V),bt=function(t){function e(e,r){t.call(this,e),this.context=e,this.parent=r}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e}(V),_t=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.setDirty=function(){this.dirty=!0},e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferTexture2D(e.FRAMEBUFFER,e.COLOR_ATTACHMENT0,e.TEXTURE_2D,t,0),this.current=t,this.dirty=!1}},e}(bt),wt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferRenderbuffer(e.FRAMEBUFFER,e.DEPTH_ATTACHMENT,e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(bt),kt=function(t,e,r){this.context=t,this.width=e,this.height=r;var n=t.gl,i=this.framebuffer=n.createFramebuffer();this.colorAttachment=new _t(t,i),this.depthAttachment=new wt(t,i)};kt.prototype.destroy=function(){var t=this.context.gl,e=this.colorAttachment.get();e&&t.deleteTexture(e);var r=this.depthAttachment.get();r&&t.deleteRenderbuffer(r),t.deleteFramebuffer(this.framebuffer)};var Tt=function(t,e,r){this.func=t,this.mask=e,this.range=r};Tt.ReadOnly=!1,Tt.ReadWrite=!0,Tt.disabled=new Tt(519,Tt.ReadOnly,[0,1]);var At=function(t,e,r,n,i,a){this.test=t,this.ref=e,this.mask=r,this.fail=n,this.depthFail=i,this.pass=a};At.disabled=new At({func:519,mask:0},0,0,7680,7680,7680);var Mt=function(t,e,r){this.blendFunction=t,this.blendColor=e,this.mask=r};Mt.disabled=new Mt(Mt.Replace=[1,0],t.Color.transparent,[!1,!1,!1,!1]),Mt.unblended=new Mt(Mt.Replace,t.Color.transparent,[!0,!0,!0,!0]),Mt.alphaBlended=new Mt([1,771],t.Color.transparent,[!0,!0,!0,!0]);var St=function(t,e,r){this.enable=t,this.mode=e,this.frontFace=r};St.disabled=new St(!1,1029,2305),St.backCCW=new St(!0,1029,2305);var Et=function(t){this.gl=t,this.extVertexArrayObject=this.gl.getExtension(\"OES_vertex_array_object\"),this.clearColor=new q(this),this.clearDepth=new H(this),this.clearStencil=new G(this),this.colorMask=new Y(this),this.depthMask=new W(this),this.stencilMask=new X(this),this.stencilFunc=new Z(this),this.stencilOp=new J(this),this.stencilTest=new K(this),this.depthRange=new $(this),this.depthTest=new Q(this),this.depthFunc=new tt(this),this.blend=new et(this),this.blendFunc=new rt(this),this.blendColor=new nt(this),this.blendEquation=new it(this),this.cullFace=new at(this),this.cullFaceSide=new ot(this),this.frontFace=new st(this),this.program=new lt(this),this.activeTexture=new ct(this),this.viewport=new ut(this),this.bindFramebuffer=new ht(this),this.bindRenderbuffer=new ft(this),this.bindTexture=new pt(this),this.bindVertexBuffer=new dt(this),this.bindElementBuffer=new gt(this),this.bindVertexArrayOES=this.extVertexArrayObject&&new vt(this),this.pixelStoreUnpack=new mt(this),this.pixelStoreUnpackPremultiplyAlpha=new yt(this),this.pixelStoreUnpackFlipY=new xt(this),this.extTextureFilterAnisotropic=t.getExtension(\"EXT_texture_filter_anisotropic\")||t.getExtension(\"MOZ_EXT_texture_filter_anisotropic\")||t.getExtension(\"WEBKIT_EXT_texture_filter_anisotropic\"),this.extTextureFilterAnisotropic&&(this.extTextureFilterAnisotropicMax=t.getParameter(this.extTextureFilterAnisotropic.MAX_TEXTURE_MAX_ANISOTROPY_EXT)),this.extTextureHalfFloat=t.getExtension(\"OES_texture_half_float\"),this.extTextureHalfFloat&&t.getExtension(\"OES_texture_half_float_linear\")};Et.prototype.setDefault=function(){this.unbindVAO(),this.clearColor.setDefault(),this.clearDepth.setDefault(),this.clearStencil.setDefault(),this.colorMask.setDefault(),this.depthMask.setDefault(),this.stencilMask.setDefault(),this.stencilFunc.setDefault(),this.stencilOp.setDefault(),this.stencilTest.setDefault(),this.depthRange.setDefault(),this.depthTest.setDefault(),this.depthFunc.setDefault(),this.blend.setDefault(),this.blendFunc.setDefault(),this.blendColor.setDefault(),this.blendEquation.setDefault(),this.cullFace.setDefault(),this.cullFaceSide.setDefault(),this.frontFace.setDefault(),this.program.setDefault(),this.activeTexture.setDefault(),this.bindFramebuffer.setDefault(),this.pixelStoreUnpack.setDefault(),this.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.pixelStoreUnpackFlipY.setDefault()},Et.prototype.setDirty=function(){this.clearColor.dirty=!0,this.clearDepth.dirty=!0,this.clearStencil.dirty=!0,this.colorMask.dirty=!0,this.depthMask.dirty=!0,this.stencilMask.dirty=!0,this.stencilFunc.dirty=!0,this.stencilOp.dirty=!0,this.stencilTest.dirty=!0,this.depthRange.dirty=!0,this.depthTest.dirty=!0,this.depthFunc.dirty=!0,this.blend.dirty=!0,this.blendFunc.dirty=!0,this.blendColor.dirty=!0,this.blendEquation.dirty=!0,this.cullFace.dirty=!0,this.cullFaceSide.dirty=!0,this.frontFace.dirty=!0,this.program.dirty=!0,this.activeTexture.dirty=!0,this.viewport.dirty=!0,this.bindFramebuffer.dirty=!0,this.bindRenderbuffer.dirty=!0,this.bindTexture.dirty=!0,this.bindVertexBuffer.dirty=!0,this.bindElementBuffer.dirty=!0,this.extVertexArrayObject&&(this.bindVertexArrayOES.dirty=!0),this.pixelStoreUnpack.dirty=!0,this.pixelStoreUnpackPremultiplyAlpha.dirty=!0,this.pixelStoreUnpackFlipY.dirty=!0},Et.prototype.createIndexBuffer=function(t,e){return new N(this,t,e)},Et.prototype.createVertexBuffer=function(t,e,r){return new U(this,t,e,r)},Et.prototype.createRenderbuffer=function(t,e,r){var n=this.gl,i=n.createRenderbuffer();return this.bindRenderbuffer.set(i),n.renderbufferStorage(n.RENDERBUFFER,t,e,r),this.bindRenderbuffer.set(null),i},Et.prototype.createFramebuffer=function(t,e){return new kt(this,t,e)},Et.prototype.clear=function(t){var e=t.color,r=t.depth,n=this.gl,i=0;e&&(i|=n.COLOR_BUFFER_BIT,this.clearColor.set(e),this.colorMask.set([!0,!0,!0,!0])),void 0!==r&&(i|=n.DEPTH_BUFFER_BIT,this.depthRange.set([0,1]),this.clearDepth.set(r),this.depthMask.set(!0)),n.clear(i)},Et.prototype.setCullFace=function(t){!1===t.enable?this.cullFace.set(!1):(this.cullFace.set(!0),this.cullFaceSide.set(t.mode),this.frontFace.set(t.frontFace))},Et.prototype.setDepthMode=function(t){t.func!==this.gl.ALWAYS||t.mask?(this.depthTest.set(!0),this.depthFunc.set(t.func),this.depthMask.set(t.mask),this.depthRange.set(t.range)):this.depthTest.set(!1)},Et.prototype.setStencilMode=function(t){t.test.func!==this.gl.ALWAYS||t.mask?(this.stencilTest.set(!0),this.stencilMask.set(t.mask),this.stencilOp.set([t.fail,t.depthFail,t.pass]),this.stencilFunc.set({func:t.test.func,ref:t.ref,mask:t.test.mask})):this.stencilTest.set(!1)},Et.prototype.setColorMode=function(e){t.deepEqual(e.blendFunction,Mt.Replace)?this.blend.set(!1):(this.blend.set(!0),this.blendFunc.set(e.blendFunction),this.blendColor.set(e.blendColor)),this.colorMask.set(e.mask)},Et.prototype.unbindVAO=function(){this.extVertexArrayObject&&this.bindVertexArrayOES.set(null)};var Ct=function(e){function r(r,n,i){var a=this;e.call(this),this.id=r,this.dispatcher=i,this.on(\"data\",function(t){\"source\"===t.dataType&&\"metadata\"===t.sourceDataType&&(a._sourceLoaded=!0),a._sourceLoaded&&!a._paused&&\"source\"===t.dataType&&\"content\"===t.sourceDataType&&(a.reload(),a.transform&&a.update(a.transform))}),this.on(\"error\",function(){a._sourceErrored=!0}),this._source=I(r,n,i,this),this._tiles={},this._cache=new B(0,this._unloadTile.bind(this)),this._timers={},this._cacheTimers={},this._maxTileCacheSize=null,this._coveredTiles={},this._state=new t.SourceFeatureState}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.onAdd=function(t){this.map=t,this._maxTileCacheSize=t?t._maxTileCacheSize:null,this._source&&this._source.onAdd&&this._source.onAdd(t)},r.prototype.onRemove=function(t){this._source&&this._source.onRemove&&this._source.onRemove(t)},r.prototype.loaded=function(){if(this._sourceErrored)return!0;if(!this._sourceLoaded)return!1;for(var t in this._tiles){var e=this._tiles[t];if(\"loaded\"!==e.state&&\"errored\"!==e.state)return!1}return!0},r.prototype.getSource=function(){return this._source},r.prototype.pause=function(){this._paused=!0},r.prototype.resume=function(){if(this._paused){var t=this._shouldReloadOnResume;this._paused=!1,this._shouldReloadOnResume=!1,t&&this.reload(),this.transform&&this.update(this.transform)}},r.prototype._loadTile=function(t,e){return this._source.loadTile(t,e)},r.prototype._unloadTile=function(t){if(this._source.unloadTile)return this._source.unloadTile(t,function(){})},r.prototype._abortTile=function(t){if(this._source.abortTile)return this._source.abortTile(t,function(){})},r.prototype.serialize=function(){return this._source.serialize()},r.prototype.prepare=function(t){for(var e in this._source.prepare&&this._source.prepare(),this._state.coalesceChanges(this._tiles,this.map?this.map.painter:null),this._tiles){var r=this._tiles[e];r.upload(t),r.prepare(this.map.style.imageManager)}},r.prototype.getIds=function(){return Object.keys(this._tiles).map(Number).sort(Lt)},r.prototype.getRenderableIds=function(e){var r=this,n=[];for(var i in this._tiles)this._isIdRenderable(+i,e)&&n.push(+i);return e?n.sort(function(e,n){var i=r._tiles[e].tileID,a=r._tiles[n].tileID,o=new t.Point(i.canonical.x,i.canonical.y)._rotate(r.transform.angle),s=new t.Point(a.canonical.x,a.canonical.y)._rotate(r.transform.angle);return i.overscaledZ-a.overscaledZ||s.y-o.y||s.x-o.x}):n.sort(Lt)},r.prototype.hasRenderableParent=function(t){var e=this.findLoadedParent(t,0);return!!e&&this._isIdRenderable(e.tileID.key)},r.prototype._isIdRenderable=function(t,e){return this._tiles[t]&&this._tiles[t].hasData()&&!this._coveredTiles[t]&&(e||!this._tiles[t].holdingForFade())},r.prototype.reload=function(){if(this._paused)this._shouldReloadOnResume=!0;else for(var t in this._cache.reset(),this._tiles)\"errored\"!==this._tiles[t].state&&this._reloadTile(t,\"reloading\")},r.prototype._reloadTile=function(t,e){var r=this._tiles[t];r&&(\"loading\"!==r.state&&(r.state=e),this._loadTile(r,this._tileLoaded.bind(this,r,t,e)))},r.prototype._tileLoaded=function(e,r,n,i){if(i)return e.state=\"errored\",void(404!==i.status?this._source.fire(new t.ErrorEvent(i,{tile:e})):this.update(this.transform));e.timeAdded=t.browser.now(),\"expired\"===n&&(e.refreshedUponExpiration=!0),this._setTileReloadTimer(r,e),\"raster-dem\"===this.getSource().type&&e.dem&&this._backfillDEM(e),this._state.initializeTileState(e,this.map?this.map.painter:null),this._source.fire(new t.Event(\"data\",{dataType:\"source\",tile:e,coord:e.tileID}))},r.prototype._backfillDEM=function(t){for(var e=this.getRenderableIds(),r=0;r<e.length;r++){var n=e[r];if(t.neighboringTiles&&t.neighboringTiles[n]){var i=this.getTileByID(n);a(t,i),a(i,t)}}function a(t,e){t.needsHillshadePrepare=!0;var r=e.tileID.canonical.x-t.tileID.canonical.x,n=e.tileID.canonical.y-t.tileID.canonical.y,i=Math.pow(2,t.tileID.canonical.z),a=e.tileID.key;0===r&&0===n||Math.abs(n)>1||(Math.abs(r)>1&&(1===Math.abs(r+i)?r+=i:1===Math.abs(r-i)&&(r-=i)),e.dem&&t.dem&&(t.dem.backfillBorder(e.dem,r,n),t.neighboringTiles&&t.neighboringTiles[a]&&(t.neighboringTiles[a].backfilled=!0)))}},r.prototype.getTile=function(t){return this.getTileByID(t.key)},r.prototype.getTileByID=function(t){return this._tiles[t]},r.prototype.getZoom=function(t){return t.zoom+t.scaleZoom(t.tileSize/this._source.tileSize)},r.prototype._retainLoadedChildren=function(t,e,r,n){for(var i in this._tiles){var a=this._tiles[i];if(!(n[i]||!a.hasData()||a.tileID.overscaledZ<=e||a.tileID.overscaledZ>r)){for(var o=a.tileID;a&&a.tileID.overscaledZ>e+1;){var s=a.tileID.scaledTo(a.tileID.overscaledZ-1);(a=this._tiles[s.key])&&a.hasData()&&(o=s)}for(var l=o;l.overscaledZ>e;)if(t[(l=l.scaledTo(l.overscaledZ-1)).key]){n[o.key]=o;break}}}},r.prototype.findLoadedParent=function(t,e){for(var r=t.overscaledZ-1;r>=e;r--){var n=t.scaledTo(r);if(!n)return;var i=String(n.key),a=this._tiles[i];if(a&&a.hasData())return a;if(this._cache.has(n))return this._cache.get(n)}},r.prototype.updateCacheSize=function(t){var e=(Math.ceil(t.width/this._source.tileSize)+1)*(Math.ceil(t.height/this._source.tileSize)+1),r=Math.floor(5*e),n=\"number\"==typeof this._maxTileCacheSize?Math.min(this._maxTileCacheSize,r):r;this._cache.setMaxSize(n)},r.prototype.handleWrapJump=function(t){var e=(t-(void 0===this._prevLng?t:this._prevLng))/360,r=Math.round(e);if(this._prevLng=t,r){var n={};for(var i in this._tiles){var a=this._tiles[i];a.tileID=a.tileID.unwrapTo(a.tileID.wrap+r),n[a.tileID.key]=a}for(var o in this._tiles=n,this._timers)clearTimeout(this._timers[o]),delete this._timers[o];for(var s in this._tiles){var l=this._tiles[s];this._setTileReloadTimer(s,l)}}},r.prototype.update=function(e){var n=this;if(this.transform=e,this._sourceLoaded&&!this._paused){var i;this.updateCacheSize(e),this.handleWrapJump(this.transform.center.lng),this._coveredTiles={},this.used?this._source.tileID?i=e.getVisibleUnwrappedCoordinates(this._source.tileID).map(function(e){return new t.OverscaledTileID(e.canonical.z,e.wrap,e.canonical.z,e.canonical.x,e.canonical.y)}):(i=e.coveringTiles({tileSize:this._source.tileSize,minzoom:this._source.minzoom,maxzoom:this._source.maxzoom,roundZoom:this._source.roundZoom,reparseOverscaled:this._source.reparseOverscaled}),this._source.hasTile&&(i=i.filter(function(t){return n._source.hasTile(t)}))):i=[];var a=(this._source.roundZoom?Math.round:Math.floor)(this.getZoom(e)),o=Math.max(a-r.maxOverzooming,this._source.minzoom),s=Math.max(a+r.maxUnderzooming,this._source.minzoom),l=this._updateRetainedTiles(i,a);if(Pt(this._source.type)){for(var c={},u={},h=0,f=Object.keys(l);h<f.length;h+=1){var p=f[h],d=l[p],g=this._tiles[p];if(g&&!(g.fadeEndTime&&g.fadeEndTime<=t.browser.now())){var v=this.findLoadedParent(d,o);v&&(this._addTile(v.tileID),c[v.tileID.key]=v.tileID),u[p]=d}}for(var m in this._retainLoadedChildren(u,a,s,l),c)l[m]||(this._coveredTiles[m]=!0,l[m]=c[m])}for(var y in l)this._tiles[y].clearFadeHold();for(var x=0,b=t.keysDifference(this._tiles,l);x<b.length;x+=1){var _=b[x],w=this._tiles[_];w.hasSymbolBuckets&&!w.holdingForFade()?w.setHoldDuration(this.map._fadeDuration):w.hasSymbolBuckets&&!w.symbolFadeFinished()||this._removeTile(_)}}},r.prototype.releaseSymbolFadeTiles=function(){for(var t in this._tiles)this._tiles[t].holdingForFade()&&this._removeTile(t)},r.prototype._updateRetainedTiles=function(t,e){for(var n={},i={},a=Math.max(e-r.maxOverzooming,this._source.minzoom),o=Math.max(e+r.maxUnderzooming,this._source.minzoom),s={},l=0,c=t;l<c.length;l+=1){var u=c[l],h=this._addTile(u);n[u.key]=u,h.hasData()||e<this._source.maxzoom&&(s[u.key]=u)}this._retainLoadedChildren(s,e,o,n);for(var f=0,p=t;f<p.length;f+=1){var d=p[f],g=this._tiles[d.key];if(!g.hasData()){if(e+1>this._source.maxzoom){var v=d.children(this._source.maxzoom)[0],m=this.getTile(v);if(m&&m.hasData()){n[v.key]=v;continue}}else{var y=d.children(this._source.maxzoom);if(n[y[0].key]&&n[y[1].key]&&n[y[2].key]&&n[y[3].key])continue}for(var x=g.wasRequested(),b=d.overscaledZ-1;b>=a;--b){var _=d.scaledTo(b);if(i[_.key])break;if(i[_.key]=!0,!(g=this.getTile(_))&&x&&(g=this._addTile(_)),g&&(n[_.key]=_,x=g.wasRequested(),g.hasData()))break}}}return n},r.prototype._addTile=function(e){var r=this._tiles[e.key];if(r)return r;(r=this._cache.getAndRemove(e))&&(this._setTileReloadTimer(e.key,r),r.tileID=e,this._state.initializeTileState(r,this.map?this.map.painter:null),this._cacheTimers[e.key]&&(clearTimeout(this._cacheTimers[e.key]),delete this._cacheTimers[e.key],this._setTileReloadTimer(e.key,r)));var n=Boolean(r);return n||(r=new t.Tile(e,this._source.tileSize*e.overscaleFactor()),this._loadTile(r,this._tileLoaded.bind(this,r,e.key,r.state))),r?(r.uses++,this._tiles[e.key]=r,n||this._source.fire(new t.Event(\"dataloading\",{tile:r,coord:r.tileID,dataType:\"source\"})),r):null},r.prototype._setTileReloadTimer=function(t,e){var r=this;t in this._timers&&(clearTimeout(this._timers[t]),delete this._timers[t]);var n=e.getExpiryTimeout();n&&(this._timers[t]=setTimeout(function(){r._reloadTile(t,\"expired\"),delete r._timers[t]},n))},r.prototype._removeTile=function(t){var e=this._tiles[t];e&&(e.uses--,delete this._tiles[t],this._timers[t]&&(clearTimeout(this._timers[t]),delete this._timers[t]),e.uses>0||(e.hasData()?this._cache.add(e.tileID,e,e.getExpiryTimeout()):(e.aborted=!0,this._abortTile(e),this._unloadTile(e))))},r.prototype.clearTiles=function(){for(var t in this._shouldReloadOnResume=!1,this._paused=!1,this._tiles)this._removeTile(t);this._cache.reset()},r.prototype.tilesIn=function(e,r,n){var i=this,a=[],o=this.transform;if(!o)return a;for(var s=n?o.getCameraQueryGeometry(e):e,l=e.map(function(t){return o.pointCoordinate(t)}),c=s.map(function(t){return o.pointCoordinate(t)}),u=this.getIds(),h=1/0,f=1/0,p=-1/0,d=-1/0,g=0,v=c;g<v.length;g+=1){var m=v[g];h=Math.min(h,m.x),f=Math.min(f,m.y),p=Math.max(p,m.x),d=Math.max(d,m.y)}for(var y=function(e){var n=i._tiles[u[e]];if(!n.holdingForFade()){var s=n.tileID,g=Math.pow(2,o.zoom-n.tileID.overscaledZ),v=r*n.queryPadding*t.EXTENT/n.tileSize/g,m=[s.getTilePoint(new t.MercatorCoordinate(h,f)),s.getTilePoint(new t.MercatorCoordinate(p,d))];if(m[0].x-v<t.EXTENT&&m[0].y-v<t.EXTENT&&m[1].x+v>=0&&m[1].y+v>=0){var y=l.map(function(t){return s.getTilePoint(t)}),x=c.map(function(t){return s.getTilePoint(t)});a.push({tile:n,tileID:s,queryGeometry:y,cameraQueryGeometry:x,scale:g})}}},x=0;x<u.length;x++)y(x);return a},r.prototype.getVisibleCoordinates=function(t){for(var e=this,r=this.getRenderableIds(t).map(function(t){return e._tiles[t].tileID}),n=0,i=r;n<i.length;n+=1){var a=i[n];a.posMatrix=this.transform.calculatePosMatrix(a.toUnwrapped())}return r},r.prototype.hasTransition=function(){if(this._source.hasTransition())return!0;if(Pt(this._source.type))for(var e in this._tiles){var r=this._tiles[e];if(void 0!==r.fadeEndTime&&r.fadeEndTime>=t.browser.now())return!0}return!1},r.prototype.setFeatureState=function(t,e,r){t=t||\"_geojsonTileLayer\",this._state.updateState(t,e,r)},r.prototype.removeFeatureState=function(t,e,r){t=t||\"_geojsonTileLayer\",this._state.removeFeatureState(t,e,r)},r.prototype.getFeatureState=function(t,e){return t=t||\"_geojsonTileLayer\",this._state.getState(t,e)},r}(t.Evented);function Lt(t,e){return t%32-e%32||e-t}function Pt(t){return\"raster\"===t||\"image\"===t||\"video\"===t}function Ot(){return new t.window.Worker(Jn.workerUrl)}Ct.maxOverzooming=10,Ct.maxUnderzooming=3;var zt=function(){this.active={}};zt.prototype.acquire=function(t){if(!this.workers)for(this.workers=[];this.workers.length<zt.workerCount;)this.workers.push(new Ot);return this.active[t]=!0,this.workers.slice()},zt.prototype.release=function(t){delete this.active[t],0===Object.keys(this.active).length&&(this.workers.forEach(function(t){t.terminate()}),this.workers=null)};var It,Dt=Math.floor(t.browser.hardwareConcurrency/2);function Rt(e,r){var n={};for(var i in e)\"ref\"!==i&&(n[i]=e[i]);return t.refProperties.forEach(function(t){t in r&&(n[t]=r[t])}),n}function Ft(t){t=t.slice();for(var e=Object.create(null),r=0;r<t.length;r++)e[t[r].id]=t[r];for(var n=0;n<t.length;n++)\"ref\"in t[n]&&(t[n]=Rt(t[n],e[t[n].ref]));return t}zt.workerCount=Math.max(Math.min(Dt,6),1);var Bt={setStyle:\"setStyle\",addLayer:\"addLayer\",removeLayer:\"removeLayer\",setPaintProperty:\"setPaintProperty\",setLayoutProperty:\"setLayoutProperty\",setFilter:\"setFilter\",addSource:\"addSource\",removeSource:\"removeSource\",setGeoJSONSourceData:\"setGeoJSONSourceData\",setLayerZoomRange:\"setLayerZoomRange\",setLayerProperty:\"setLayerProperty\",setCenter:\"setCenter\",setZoom:\"setZoom\",setBearing:\"setBearing\",setPitch:\"setPitch\",setSprite:\"setSprite\",setGlyphs:\"setGlyphs\",setTransition:\"setTransition\",setLight:\"setLight\"};function Nt(t,e,r){r.push({command:Bt.addSource,args:[t,e[t]]})}function jt(t,e,r){e.push({command:Bt.removeSource,args:[t]}),r[t]=!0}function Ut(t,e,r,n){jt(t,r,n),Nt(t,e,r)}function Vt(e,r,n){var i;for(i in e[n])if(e[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;for(i in r[n])if(r[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;return!0}function qt(e,r,n,i,a,o){var s;for(s in r=r||{},e=e||{})e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}));for(s in r)r.hasOwnProperty(s)&&!e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}))}function Ht(t){return t.id}function Gt(t,e){return t[e.id]=e,t}var Yt=function(t,e,r){var n=this.boxCells=[],i=this.circleCells=[];this.xCellCount=Math.ceil(t/r),this.yCellCount=Math.ceil(e/r);for(var a=0;a<this.xCellCount*this.yCellCount;a++)n.push([]),i.push([]);this.circleKeys=[],this.boxKeys=[],this.bboxes=[],this.circles=[],this.width=t,this.height=e,this.xScale=this.xCellCount/t,this.yScale=this.yCellCount/e,this.boxUid=0,this.circleUid=0};function Wt(e,r,n,i,a){var o=t.create();return r?(t.scale(o,o,[1/a,1/a,1]),n||t.rotateZ(o,o,i.angle)):t.multiply(o,i.labelPlaneMatrix,e),o}function Xt(e,r,n,i,a){if(r){var o=t.clone(e);return t.scale(o,o,[a,a,1]),n||t.rotateZ(o,o,-i.angle),o}return i.glCoordMatrix}function Zt(e,r){var n=[e.x,e.y,0,1];ae(n,n,r);var i=n[3];return{point:new t.Point(n[0]/i,n[1]/i),signedDistanceFromCamera:i}}function Jt(t,e){var r=t[0]/t[3],n=t[1]/t[3];return r>=-e[0]&&r<=e[0]&&n>=-e[1]&&n<=e[1]}function Kt(e,r,n,i,a,o,s,l){var c=i?e.textSizeData:e.iconSizeData,u=t.evaluateSizeForZoom(c,n.transform.zoom),h=[256/n.width*2+1,256/n.height*2+1],f=i?e.text.dynamicLayoutVertexArray:e.icon.dynamicLayoutVertexArray;f.clear();for(var p=e.lineVertexArray,d=i?e.text.placedSymbolArray:e.icon.placedSymbolArray,g=n.transform.width/n.transform.height,v=!1,m=0;m<d.length;m++){var y=d.get(m);if(y.hidden||y.writingMode===t.WritingMode.vertical&&!v)ie(y.numGlyphs,f);else{v=!1;var x=[y.anchorX,y.anchorY,0,1];if(t.transformMat4(x,x,r),Jt(x,h)){var b=.5+x[3]/n.transform.cameraToCenterDistance*.5,_=t.evaluateSizeForFeature(c,u,y),w=s?_*b:_/b,k=new t.Point(y.anchorX,y.anchorY),T=Zt(k,a).point,A={},M=te(y,w,!1,l,r,a,o,e.glyphOffsetArray,p,f,T,k,A,g);v=M.useVertical,(M.notEnoughRoom||v||M.needsFlipping&&te(y,w,!0,l,r,a,o,e.glyphOffsetArray,p,f,T,k,A,g).notEnoughRoom)&&ie(y.numGlyphs,f)}else ie(y.numGlyphs,f)}}i?e.text.dynamicLayoutVertexBuffer.updateData(f):e.icon.dynamicLayoutVertexBuffer.updateData(f)}function $t(t,e,r,n,i,a,o,s,l,c,u,h){var f=s.glyphStartIndex+s.numGlyphs,p=s.lineStartIndex,d=s.lineStartIndex+s.lineLength,g=e.getoffsetX(s.glyphStartIndex),v=e.getoffsetX(f-1),m=re(t*g,r,n,i,a,o,s.segment,p,d,l,c,u,h);if(!m)return null;var y=re(t*v,r,n,i,a,o,s.segment,p,d,l,c,u,h);return y?{first:m,last:y}:null}function Qt(e,r,n,i){return e===t.WritingMode.horizontal&&Math.abs(n.y-r.y)>Math.abs(n.x-r.x)*i?{useVertical:!0}:(e===t.WritingMode.vertical?r.y<n.y:r.x>n.x)?{needsFlipping:!0}:null}function te(e,r,n,i,a,o,s,l,c,u,h,f,p,d){var g,v=r/24,m=e.lineOffsetX*v,y=e.lineOffsetY*v;if(e.numGlyphs>1){var x=e.glyphStartIndex+e.numGlyphs,b=e.lineStartIndex,_=e.lineStartIndex+e.lineLength,w=$t(v,l,m,y,n,h,f,e,c,o,p,!1);if(!w)return{notEnoughRoom:!0};var k=Zt(w.first.point,s).point,T=Zt(w.last.point,s).point;if(i&&!n){var A=Qt(e.writingMode,k,T,d);if(A)return A}g=[w.first];for(var M=e.glyphStartIndex+1;M<x-1;M++)g.push(re(v*l.getoffsetX(M),m,y,n,h,f,e.segment,b,_,c,o,p,!1));g.push(w.last)}else{if(i&&!n){var S=Zt(f,a).point,E=e.lineStartIndex+e.segment+1,C=new t.Point(c.getx(E),c.gety(E)),L=Zt(C,a),P=L.signedDistanceFromCamera>0?L.point:ee(f,C,S,1,a),O=Qt(e.writingMode,S,P,d);if(O)return O}var z=re(v*l.getoffsetX(e.glyphStartIndex),m,y,n,h,f,e.segment,e.lineStartIndex,e.lineStartIndex+e.lineLength,c,o,p,!1);if(!z)return{notEnoughRoom:!0};g=[z]}for(var I=0,D=g;I<D.length;I+=1){var R=D[I];t.addDynamicAttributes(u,R.point,R.angle)}return{}}function ee(t,e,r,n,i){var a=Zt(t.add(t.sub(e)._unit()),i).point,o=r.sub(a);return r.add(o._mult(n/o.mag()))}function re(e,r,n,i,a,o,s,l,c,u,h,f,p){var d=i?e-r:e+r,g=d>0?1:-1,v=0;i&&(g*=-1,v=Math.PI),g<0&&(v+=Math.PI);for(var m=g>0?l+s:l+s+1,y=m,x=a,b=a,_=0,w=0,k=Math.abs(d);_+w<=k;){if((m+=g)<l||m>=c)return null;if(b=x,void 0===(x=f[m])){var T=new t.Point(u.getx(m),u.gety(m)),A=Zt(T,h);if(A.signedDistanceFromCamera>0)x=f[m]=A.point;else{var M=m-g;x=ee(0===_?o:new t.Point(u.getx(M),u.gety(M)),T,b,k-_+1,h)}}_+=w,w=b.dist(x)}var S=(k-_)/w,E=x.sub(b),C=E.mult(S)._add(b);return C._add(E._unit()._perp()._mult(n*g)),{point:C,angle:v+Math.atan2(x.y-b.y,x.x-b.x),tileDistance:p?{prevTileDistance:m-g===y?0:u.gettileUnitDistanceFromAnchor(m-g),lastSegmentViewportDistance:k-_}:null}}Yt.prototype.keysLength=function(){return this.boxKeys.length+this.circleKeys.length},Yt.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertBoxCell,this.boxUid++),this.boxKeys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},Yt.prototype.insertCircle=function(t,e,r,n){this._forEachCell(e-n,r-n,e+n,r+n,this._insertCircleCell,this.circleUid++),this.circleKeys.push(t),this.circles.push(e),this.circles.push(r),this.circles.push(n)},Yt.prototype._insertBoxCell=function(t,e,r,n,i,a){this.boxCells[i].push(a)},Yt.prototype._insertCircleCell=function(t,e,r,n,i,a){this.circleCells[i].push(a)},Yt.prototype._query=function(t,e,r,n,i,a){if(r<0||t>this.width||n<0||e>this.height)return!i&&[];var o=[];if(t<=0&&e<=0&&this.width<=r&&this.height<=n){if(i)return!0;for(var s=0;s<this.boxKeys.length;s++)o.push({key:this.boxKeys[s],x1:this.bboxes[4*s],y1:this.bboxes[4*s+1],x2:this.bboxes[4*s+2],y2:this.bboxes[4*s+3]});for(var l=0;l<this.circleKeys.length;l++){var c=this.circles[3*l],u=this.circles[3*l+1],h=this.circles[3*l+2];o.push({key:this.circleKeys[l],x1:c-h,y1:u-h,x2:c+h,y2:u+h})}return a?o.filter(a):o}var f={hitTest:i,seenUids:{box:{},circle:{}}};return this._forEachCell(t,e,r,n,this._queryCell,o,f,a),i?o.length>0:o},Yt.prototype._queryCircle=function(t,e,r,n,i){var a=t-r,o=t+r,s=e-r,l=e+r;if(o<0||a>this.width||l<0||s>this.height)return!n&&[];var c=[],u={hitTest:n,circle:{x:t,y:e,radius:r},seenUids:{box:{},circle:{}}};return this._forEachCell(a,s,o,l,this._queryCellCircle,c,u,i),n?c.length>0:c},Yt.prototype.query=function(t,e,r,n,i){return this._query(t,e,r,n,!1,i)},Yt.prototype.hitTest=function(t,e,r,n,i){return this._query(t,e,r,n,!0,i)},Yt.prototype.hitTestCircle=function(t,e,r,n){return this._queryCircle(t,e,r,!0,n)},Yt.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=o.seenUids,c=this.boxCells[i];if(null!==c)for(var u=this.bboxes,h=0,f=c;h<f.length;h+=1){var p=f[h];if(!l.box[p]){l.box[p]=!0;var d=4*p;if(t<=u[d+2]&&e<=u[d+3]&&r>=u[d+0]&&n>=u[d+1]&&(!s||s(this.boxKeys[p]))){if(o.hitTest)return a.push(!0),!0;a.push({key:this.boxKeys[p],x1:u[d],y1:u[d+1],x2:u[d+2],y2:u[d+3]})}}}var g=this.circleCells[i];if(null!==g)for(var v=this.circles,m=0,y=g;m<y.length;m+=1){var x=y[m];if(!l.circle[x]){l.circle[x]=!0;var b=3*x;if(this._circleAndRectCollide(v[b],v[b+1],v[b+2],t,e,r,n)&&(!s||s(this.circleKeys[x]))){if(o.hitTest)return a.push(!0),!0;var _=v[b],w=v[b+1],k=v[b+2];a.push({key:this.circleKeys[x],x1:_-k,y1:w-k,x2:_+k,y2:w+k})}}}},Yt.prototype._queryCellCircle=function(t,e,r,n,i,a,o,s){var l=o.circle,c=o.seenUids,u=this.boxCells[i];if(null!==u)for(var h=this.bboxes,f=0,p=u;f<p.length;f+=1){var d=p[f];if(!c.box[d]){c.box[d]=!0;var g=4*d;if(this._circleAndRectCollide(l.x,l.y,l.radius,h[g+0],h[g+1],h[g+2],h[g+3])&&(!s||s(this.boxKeys[d])))return a.push(!0),!0}}var v=this.circleCells[i];if(null!==v)for(var m=this.circles,y=0,x=v;y<x.length;y+=1){var b=x[y];if(!c.circle[b]){c.circle[b]=!0;var _=3*b;if(this._circlesCollide(m[_],m[_+1],m[_+2],l.x,l.y,l.radius)&&(!s||s(this.circleKeys[b])))return a.push(!0),!0}}},Yt.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToXCellCoord(t),c=this._convertToYCellCoord(e),u=this._convertToXCellCoord(r),h=this._convertToYCellCoord(n),f=l;f<=u;f++)for(var p=c;p<=h;p++){var d=this.xCellCount*p+f;if(i.call(this,t,e,r,n,d,a,o,s))return}},Yt.prototype._convertToXCellCoord=function(t){return Math.max(0,Math.min(this.xCellCount-1,Math.floor(t*this.xScale)))},Yt.prototype._convertToYCellCoord=function(t){return Math.max(0,Math.min(this.yCellCount-1,Math.floor(t*this.yScale)))},Yt.prototype._circlesCollide=function(t,e,r,n,i,a){var o=n-t,s=i-e,l=r+a;return l*l>o*o+s*s},Yt.prototype._circleAndRectCollide=function(t,e,r,n,i,a,o){var s=(a-n)/2,l=Math.abs(t-(n+s));if(l>s+r)return!1;var c=(o-i)/2,u=Math.abs(e-(i+c));if(u>c+r)return!1;if(l<=s||u<=c)return!0;var h=l-s,f=u-c;return h*h+f*f<=r*r};var ne=new Float32Array([-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0]);function ie(t,e){for(var r=0;r<t;r++){var n=e.length;e.resize(n+4),e.float32.set(ne,3*n)}}function ae(t,e,r){var n=e[0],i=e[1];return t[0]=r[0]*n+r[4]*i+r[12],t[1]=r[1]*n+r[5]*i+r[13],t[3]=r[3]*n+r[7]*i+r[15],t}var oe=function(t,e,r){void 0===e&&(e=new Yt(t.width+200,t.height+200,25)),void 0===r&&(r=new Yt(t.width+200,t.height+200,25)),this.transform=t,this.grid=e,this.ignoredGrid=r,this.pitchfactor=Math.cos(t._pitch)*t.cameraToCenterDistance,this.screenRightBoundary=t.width+100,this.screenBottomBoundary=t.height+100,this.gridRightBoundary=t.width+200,this.gridBottomBoundary=t.height+200};function se(t,e,r){t[e+4]=r?1:0}function le(e,r,n){return r*(t.EXTENT/(e.tileSize*Math.pow(2,n-e.tileID.overscaledZ)))}oe.prototype.placeCollisionBox=function(t,e,r,n,i){var a=this.projectAndGetPerspectiveRatio(n,t.anchorPointX,t.anchorPointY),o=r*a.perspectiveRatio,s=t.x1*o+a.point.x,l=t.y1*o+a.point.y,c=t.x2*o+a.point.x,u=t.y2*o+a.point.y;return!this.isInsideGrid(s,l,c,u)||!e&&this.grid.hitTest(s,l,c,u,i)?{box:[],offscreen:!1}:{box:[s,l,c,u],offscreen:this.isOffscreen(s,l,c,u)}},oe.prototype.approximateTileDistance=function(t,e,r,n,i){var a=i?1:n/this.pitchfactor,o=t.lastSegmentViewportDistance*r;return t.prevTileDistance+o+(a-1)*o*Math.abs(Math.sin(e))},oe.prototype.placeCollisionCircles=function(e,r,n,i,a,o,s,l,c,u,h,f,p){var d=[],g=this.projectAnchor(c,a.anchorX,a.anchorY),v=l/24,m=a.lineOffsetX*l,y=a.lineOffsetY*l,x=new t.Point(a.anchorX,a.anchorY),b=$t(v,s,m,y,!1,Zt(x,u).point,x,a,o,u,{},!0),_=!1,w=!1,k=!0,T=g.perspectiveRatio*i,A=1/(i*n),M=0,S=0;b&&(M=this.approximateTileDistance(b.first.tileDistance,b.first.angle,A,g.cameraDistance,f),S=this.approximateTileDistance(b.last.tileDistance,b.last.angle,A,g.cameraDistance,f));for(var E=0;E<e.length;E+=5){var C=e[E],L=e[E+1],P=e[E+2],O=e[E+3];if(!b||O<-M||O>S)se(e,E,!1);else{var z=this.projectPoint(c,C,L),I=P*T;if(d.length>0){var D=z.x-d[d.length-4],R=z.y-d[d.length-3];if(I*I*2>D*D+R*R&&E+8<e.length){var F=e[E+8];if(F>-M&&F<S){se(e,E,!1);continue}}}var B=E/5;d.push(z.x,z.y,I,B),se(e,E,!0);var N=z.x-I,j=z.y-I,U=z.x+I,V=z.y+I;if(k=k&&this.isOffscreen(N,j,U,V),w=w||this.isInsideGrid(N,j,U,V),!r&&this.grid.hitTestCircle(z.x,z.y,I,p)){if(!h)return{circles:[],offscreen:!1};_=!0}}}return{circles:_||!w?[]:d,offscreen:k}},oe.prototype.queryRenderedSymbols=function(e){if(0===e.length||0===this.grid.keysLength()&&0===this.ignoredGrid.keysLength())return{};for(var r=[],n=1/0,i=1/0,a=-1/0,o=-1/0,s=0,l=e;s<l.length;s+=1){var c=l[s],u=new t.Point(c.x+100,c.y+100);n=Math.min(n,u.x),i=Math.min(i,u.y),a=Math.max(a,u.x),o=Math.max(o,u.y),r.push(u)}for(var h={},f={},p=0,d=this.grid.query(n,i,a,o).concat(this.ignoredGrid.query(n,i,a,o));p<d.length;p+=1){var g=d[p],v=g.key;if(void 0===h[v.bucketInstanceId]&&(h[v.bucketInstanceId]={}),!h[v.bucketInstanceId][v.featureIndex]){var m=[new t.Point(g.x1,g.y1),new t.Point(g.x2,g.y1),new t.Point(g.x2,g.y2),new t.Point(g.x1,g.y2)];t.polygonIntersectsPolygon(r,m)&&(h[v.bucketInstanceId][v.featureIndex]=!0,void 0===f[v.bucketInstanceId]&&(f[v.bucketInstanceId]=[]),f[v.bucketInstanceId].push(v.featureIndex))}}return f},oe.prototype.insertCollisionBox=function(t,e,r,n,i){var a={bucketInstanceId:r,featureIndex:n,collisionGroupID:i};(e?this.ignoredGrid:this.grid).insert(a,t[0],t[1],t[2],t[3])},oe.prototype.insertCollisionCircles=function(t,e,r,n,i){for(var a=e?this.ignoredGrid:this.grid,o={bucketInstanceId:r,featureIndex:n,collisionGroupID:i},s=0;s<t.length;s+=4)a.insertCircle(o,t[s],t[s+1],t[s+2])},oe.prototype.projectAnchor=function(t,e,r){var n=[e,r,0,1];return ae(n,n,t),{perspectiveRatio:.5+this.transform.cameraToCenterDistance/n[3]*.5,cameraDistance:n[3]}},oe.prototype.projectPoint=function(e,r,n){var i=[r,n,0,1];return ae(i,i,e),new t.Point((i[0]/i[3]+1)/2*this.transform.width+100,(-i[1]/i[3]+1)/2*this.transform.height+100)},oe.prototype.projectAndGetPerspectiveRatio=function(e,r,n){var i=[r,n,0,1];return ae(i,i,e),{point:new t.Point((i[0]/i[3]+1)/2*this.transform.width+100,(-i[1]/i[3]+1)/2*this.transform.height+100),perspectiveRatio:.5+this.transform.cameraToCenterDistance/i[3]*.5}},oe.prototype.isOffscreen=function(t,e,r,n){return r<100||t>=this.screenRightBoundary||n<100||e>this.screenBottomBoundary},oe.prototype.isInsideGrid=function(t,e,r,n){return r>=0&&t<this.gridRightBoundary&&n>=0&&e<this.gridBottomBoundary};var ce=function(t,e,r,n){this.opacity=t?Math.max(0,Math.min(1,t.opacity+(t.placed?e:-e))):n&&r?1:0,this.placed=r};ce.prototype.isHidden=function(){return 0===this.opacity&&!this.placed};var ue=function(t,e,r,n,i){this.text=new ce(t?t.text:null,e,r,i),this.icon=new ce(t?t.icon:null,e,n,i)};ue.prototype.isHidden=function(){return this.text.isHidden()&&this.icon.isHidden()};var he=function(t,e,r){this.text=t,this.icon=e,this.skipFade=r},fe=function(t,e,r,n,i){this.bucketInstanceId=t,this.featureIndex=e,this.sourceLayerIndex=r,this.bucketIndex=n,this.tileID=i},pe=function(t){this.crossSourceCollisions=t,this.maxGroupID=0,this.collisionGroups={}};function de(e,r,n,i,a){var o=t.getAnchorAlignment(e),s=-(o.horizontalAlign-.5)*r,l=-(o.verticalAlign-.5)*n,c=t.evaluateRadialOffset(e,i);return new t.Point(s+c[0]*a,l+c[1]*a)}pe.prototype.get=function(t){if(this.crossSourceCollisions)return{ID:0,predicate:null};if(!this.collisionGroups[t]){var e=++this.maxGroupID;this.collisionGroups[t]={ID:e,predicate:function(t){return t.collisionGroupID===e}}}return this.collisionGroups[t]};var ge=function(t,e,r,n){this.transform=t.clone(),this.collisionIndex=new oe(this.transform),this.placements={},this.opacities={},this.variableOffsets={},this.stale=!1,this.commitTime=0,this.fadeDuration=e,this.retainedQueryData={},this.collisionGroups=new pe(r),this.prevPlacement=n,n&&(n.prevPlacement=void 0)};function ve(t,e,r,n,i){t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0)}ge.prototype.placeLayerTile=function(e,r,n,i){var a=r.getBucket(e),o=r.latestFeatureIndex;if(a&&o&&e.id===a.layerIds[0]){var s=r.collisionBoxArray,l=a.layers[0].layout,c=Math.pow(2,this.transform.zoom-r.tileID.overscaledZ),u=r.tileSize/t.EXTENT,h=this.transform.calculatePosMatrix(r.tileID.toUnwrapped()),f=Wt(h,\"map\"===l.get(\"text-pitch-alignment\"),\"map\"===l.get(\"text-rotation-alignment\"),this.transform,le(r,1,this.transform.zoom)),p=Wt(h,\"map\"===l.get(\"icon-pitch-alignment\"),\"map\"===l.get(\"icon-rotation-alignment\"),this.transform,le(r,1,this.transform.zoom));this.retainedQueryData[a.bucketInstanceId]=new fe(a.bucketInstanceId,o,a.sourceLayerIndex,a.index,r.tileID),this.placeLayerBucket(a,h,f,p,c,u,n,r.holdingForFade(),i,s)}},ge.prototype.attemptAnchorPlacement=function(e,r,n,i,a,o,s,l,c,u,h,f,p,d){var g,v=de(e,n,i,a,o),m=this.collisionIndex.placeCollisionBox(function(e,r,n,i,a,o){var s=e.x1,l=e.x2,c=e.y1,u=e.y2,h=e.anchorPointX,f=e.anchorPointY,p=new t.Point(r,n);return i&&p._rotate(a?o:-o),{x1:s+p.x,y1:c+p.y,x2:l+p.x,y2:u+p.y,anchorPointX:h,anchorPointY:f}}(r,v.x,v.y,s,l,this.transform.angle),f,c,u,h.predicate);if(m.box.length>0)return this.prevPlacement&&this.prevPlacement.variableOffsets[p.crossTileID]&&this.prevPlacement.placements[p.crossTileID]&&this.prevPlacement.placements[p.crossTileID].text&&(g=this.prevPlacement.variableOffsets[p.crossTileID].anchor),this.variableOffsets[p.crossTileID]={radialOffset:a,width:n,height:i,anchor:e,textBoxScale:o,prevAnchor:g},this.markUsedJustification(d,e,p),m},ge.prototype.placeLayerBucket=function(e,r,n,i,a,o,s,l,c,u){var h=this,f=e.layers[0].layout,p=t.evaluateSizeForZoom(e.textSizeData,this.transform.zoom),d=f.get(\"text-optional\"),g=f.get(\"icon-optional\"),v=f.get(\"text-allow-overlap\"),m=f.get(\"icon-allow-overlap\"),y=v&&(m||!e.hasIconData()||g),x=m&&(v||!e.hasTextData()||d),b=this.collisionGroups.get(e.sourceID),_=\"map\"===f.get(\"text-rotation-alignment\"),w=\"map\"===f.get(\"text-pitch-alignment\"),k=\"viewport-y\"===f.get(\"symbol-z-order\");!e.collisionArrays&&u&&e.deserializeCollisionBoxes(u);var T=function(i,u){if(!c[i.crossTileID])if(l)h.placements[i.crossTileID]=new he(!1,!1,!1);else{var m=!1,k=!1,T=!0,A=null,M=null,S=null,E=0,C=0;u.textFeatureIndex&&(E=u.textFeatureIndex);var L=u.textBox;if(L)if(f.get(\"text-variable-anchor\")){var P=L.x2-L.x1,O=L.y2-L.y1,z=i.textBoxScale,I=f.get(\"text-variable-anchor\");if(h.prevPlacement&&h.prevPlacement.variableOffsets[i.crossTileID]){var D=h.prevPlacement.variableOffsets[i.crossTileID];I[0]!==D.anchor&&(I=I.filter(function(t){return t!==D.anchor})).unshift(D.anchor)}for(var R=0,F=I;R<F.length;R+=1){var B=F[R];if(A=h.attemptAnchorPlacement(B,L,P,O,i.radialTextOffset,z,_,w,o,r,b,v,i,e)){m=!0;break}}if(!h.variableOffsets[i.crossTileID]&&h.prevPlacement){var N=h.prevPlacement.variableOffsets[i.crossTileID];N&&(h.variableOffsets[i.crossTileID]=N,h.markUsedJustification(e,N.anchor,i))}}else m=(A=h.collisionIndex.placeCollisionBox(L,f.get(\"text-allow-overlap\"),o,r,b.predicate)).box.length>0;T=A&&A.offscreen;var j=u.textCircles;if(j){var U=e.text.placedSymbolArray.get(i.centerJustifiedTextSymbolIndex),V=t.evaluateSizeForFeature(e.textSizeData,p,U);M=h.collisionIndex.placeCollisionCircles(j,f.get(\"text-allow-overlap\"),a,o,U,e.lineVertexArray,e.glyphOffsetArray,V,r,n,s,w,b.predicate),m=f.get(\"text-allow-overlap\")||M.circles.length>0,T=T&&M.offscreen}u.iconFeatureIndex&&(C=u.iconFeatureIndex),u.iconBox&&(k=(S=h.collisionIndex.placeCollisionBox(u.iconBox,f.get(\"icon-allow-overlap\"),o,r,b.predicate)).box.length>0,T=T&&S.offscreen);var q=d||0===i.numHorizontalGlyphVertices&&0===i.numVerticalGlyphVertices,H=g||0===i.numIconVertices;q||H?H?q||(k=k&&m):m=k&&m:k=m=k&&m,m&&A&&h.collisionIndex.insertCollisionBox(A.box,f.get(\"text-ignore-placement\"),e.bucketInstanceId,E,b.ID),k&&S&&h.collisionIndex.insertCollisionBox(S.box,f.get(\"icon-ignore-placement\"),e.bucketInstanceId,C,b.ID),m&&M&&h.collisionIndex.insertCollisionCircles(M.circles,f.get(\"text-ignore-placement\"),e.bucketInstanceId,E,b.ID),h.placements[i.crossTileID]=new he(m||y,k||x,T||e.justReloaded),c[i.crossTileID]=!0}};if(k)for(var A=e.getSortedSymbolIndexes(this.transform.angle),M=A.length-1;M>=0;--M){var S=A[M];T(e.symbolInstances.get(S),e.collisionArrays[S])}else for(var E=0;E<e.symbolInstances.length;++E)T(e.symbolInstances.get(E),e.collisionArrays[E]);e.justReloaded=!1},ge.prototype.markUsedJustification=function(e,r,n){var i={left:n.leftJustifiedTextSymbolIndex,center:n.centerJustifiedTextSymbolIndex,right:n.rightJustifiedTextSymbolIndex},a=i[t.getAnchorJustification(r)];for(var o in i){var s=i[o];s>=0&&(e.text.placedSymbolArray.get(s).crossTileID=a>=0&&s!==a?0:n.crossTileID)}},ge.prototype.commit=function(t){this.commitTime=t;var e=this.prevPlacement,r=!1,n=e&&0!==this.fadeDuration?(this.commitTime-e.commitTime)/this.fadeDuration:1,i=e?e.opacities:{},a=e?e.variableOffsets:{};for(var o in this.placements){var s=this.placements[o],l=i[o];l?(this.opacities[o]=new ue(l,n,s.text,s.icon),r=r||s.text!==l.text.placed||s.icon!==l.icon.placed):(this.opacities[o]=new ue(null,n,s.text,s.icon,s.skipFade),r=r||s.text||s.icon)}for(var c in i){var u=i[c];if(!this.opacities[c]){var h=new ue(u,n,!1,!1);h.isHidden()||(this.opacities[c]=h,r=r||u.text.placed||u.icon.placed)}}for(var f in a)this.variableOffsets[f]||!this.opacities[f]||this.opacities[f].isHidden()||(this.variableOffsets[f]=a[f]);r?this.lastPlacementChangeTime=t:\"number\"!=typeof this.lastPlacementChangeTime&&(this.lastPlacementChangeTime=e?e.lastPlacementChangeTime:t)},ge.prototype.updateLayerOpacities=function(t,e){for(var r={},n=0,i=e;n<i.length;n+=1){var a=i[n],o=a.getBucket(t);o&&a.latestFeatureIndex&&t.id===o.layerIds[0]&&this.updateBucketOpacities(o,r,a.collisionBoxArray)}},ge.prototype.updateBucketOpacities=function(e,r,n){e.hasTextData()&&e.text.opacityVertexArray.clear(),e.hasIconData()&&e.icon.opacityVertexArray.clear(),e.hasCollisionBoxData()&&e.collisionBox.collisionVertexArray.clear(),e.hasCollisionCircleData()&&e.collisionCircle.collisionVertexArray.clear();var i=e.layers[0].layout,a=new ue(null,0,!1,!1,!0),o=i.get(\"text-allow-overlap\"),s=i.get(\"icon-allow-overlap\"),l=i.get(\"text-variable-anchor\"),c=\"map\"===i.get(\"text-rotation-alignment\"),u=\"map\"===i.get(\"text-pitch-alignment\"),h=new ue(null,0,o&&(s||!e.hasIconData()||i.get(\"icon-optional\")),s&&(o||!e.hasTextData()||i.get(\"text-optional\")),!0);!e.collisionArrays&&n&&(e.hasCollisionBoxData()||e.hasCollisionCircleData())&&e.deserializeCollisionBoxes(n);for(var f=0;f<e.symbolInstances.length;f++){var p=e.symbolInstances.get(f),d=p.numHorizontalGlyphVertices,g=p.numVerticalGlyphVertices,v=p.crossTileID,m=r[v],y=this.opacities[v];m?y=a:y||(y=h,this.opacities[v]=y),r[v]=!0;var x=d>0||g>0,b=p.numIconVertices>0;if(x){for(var _=Te(y.text),w=(d+g)/4,k=0;k<w;k++)e.text.opacityVertexArray.emplaceBack(_);var T=y.text.isHidden()?1:0;[p.rightJustifiedTextSymbolIndex,p.centerJustifiedTextSymbolIndex,p.leftJustifiedTextSymbolIndex,p.verticalPlacedTextSymbolIndex].forEach(function(t){t>=0&&(e.text.placedSymbolArray.get(t).hidden=T)});var A=this.variableOffsets[p.crossTileID];A&&this.markUsedJustification(e,A.anchor,p)}if(b){for(var M=Te(y.icon),S=0;S<p.numIconVertices/4;S++)e.icon.opacityVertexArray.emplaceBack(M);e.icon.placedSymbolArray.get(f).hidden=y.icon.isHidden()}if(e.hasCollisionBoxData()||e.hasCollisionCircleData()){var E=e.collisionArrays[f];if(E){if(E.textBox){var C=new t.Point(0,0),L=!0;if(l){var P=this.variableOffsets[v];P?(C=de(P.anchor,P.width,P.height,P.radialOffset,P.textBoxScale),c&&C._rotate(u?this.transform.angle:-this.transform.angle)):L=!1}ve(e.collisionBox.collisionVertexArray,y.text.placed,!L,C.x,C.y)}E.iconBox&&ve(e.collisionBox.collisionVertexArray,y.icon.placed,!1);var O=E.textCircles;if(O&&e.hasCollisionCircleData())for(var z=0;z<O.length;z+=5){var I=m||0===O[z+4];ve(e.collisionCircle.collisionVertexArray,y.text.placed,I)}}}}e.sortFeatures(this.transform.angle),this.retainedQueryData[e.bucketInstanceId]&&(this.retainedQueryData[e.bucketInstanceId].featureSortOrder=e.featureSortOrder),e.hasTextData()&&e.text.opacityVertexBuffer&&e.text.opacityVertexBuffer.updateData(e.text.opacityVertexArray),e.hasIconData()&&e.icon.opacityVertexBuffer&&e.icon.opacityVertexBuffer.updateData(e.icon.opacityVertexArray),e.hasCollisionBoxData()&&e.collisionBox.collisionVertexBuffer&&e.collisionBox.collisionVertexBuffer.updateData(e.collisionBox.collisionVertexArray),e.hasCollisionCircleData()&&e.collisionCircle.collisionVertexBuffer&&e.collisionCircle.collisionVertexBuffer.updateData(e.collisionCircle.collisionVertexArray)},ge.prototype.symbolFadeChange=function(t){return 0===this.fadeDuration?1:(t-this.commitTime)/this.fadeDuration},ge.prototype.hasTransitions=function(t){return this.stale||t-this.lastPlacementChangeTime<this.fadeDuration},ge.prototype.stillRecent=function(t){return this.commitTime+this.fadeDuration>t},ge.prototype.setStale=function(){this.stale=!0};var me=Math.pow(2,25),ye=Math.pow(2,24),xe=Math.pow(2,17),be=Math.pow(2,16),_e=Math.pow(2,9),we=Math.pow(2,8),ke=Math.pow(2,1);function Te(t){if(0===t.opacity&&!t.placed)return 0;if(1===t.opacity&&t.placed)return 4294967295;var e=t.placed?1:0,r=Math.floor(127*t.opacity);return r*me+e*ye+r*xe+e*be+r*_e+e*we+r*ke+e}var Ae=function(){this._currentTileIndex=0,this._seenCrossTileIDs={}};Ae.prototype.continuePlacement=function(t,e,r,n,i){for(;this._currentTileIndex<t.length;){var a=t[this._currentTileIndex];if(e.placeLayerTile(n,a,r,this._seenCrossTileIDs),this._currentTileIndex++,i())return!0}};var Me=function(t,e,r,n,i,a,o){this.placement=new ge(t,i,a,o),this._currentPlacementIndex=e.length-1,this._forceFullPlacement=r,this._showCollisionBoxes=n,this._done=!1};Me.prototype.isDone=function(){return this._done},Me.prototype.continuePlacement=function(e,r,n){for(var i=this,a=t.browser.now(),o=function(){var e=t.browser.now()-a;return!i._forceFullPlacement&&e>2};this._currentPlacementIndex>=0;){var s=r[e[this._currentPlacementIndex]],l=this.placement.collisionIndex.transform.zoom;if(\"symbol\"===s.type&&(!s.minzoom||s.minzoom<=l)&&(!s.maxzoom||s.maxzoom>l)){if(this._inProgressLayer||(this._inProgressLayer=new Ae),this._inProgressLayer.continuePlacement(n[s.source],this.placement,this._showCollisionBoxes,s,o))return;delete this._inProgressLayer}this._currentPlacementIndex--}this._done=!0},Me.prototype.commit=function(t){return this.placement.commit(t),this.placement};var Se=512/t.EXTENT/2,Ee=function(t,e,r){this.tileID=t,this.indexedSymbolInstances={},this.bucketInstanceId=r;for(var n=0;n<e.length;n++){var i=e.get(n),a=i.key;this.indexedSymbolInstances[a]||(this.indexedSymbolInstances[a]=[]),this.indexedSymbolInstances[a].push({crossTileID:i.crossTileID,coord:this.getScaledCoordinates(i,t)})}};Ee.prototype.getScaledCoordinates=function(e,r){var n=r.canonical.z-this.tileID.canonical.z,i=Se/Math.pow(2,n);return{x:Math.floor((r.canonical.x*t.EXTENT+e.anchorX)*i),y:Math.floor((r.canonical.y*t.EXTENT+e.anchorY)*i)}},Ee.prototype.findMatches=function(t,e,r){for(var n=this.tileID.canonical.z<e.canonical.z?1:Math.pow(2,this.tileID.canonical.z-e.canonical.z),i=0;i<t.length;i++){var a=t.get(i);if(!a.crossTileID){var o=this.indexedSymbolInstances[a.key];if(o)for(var s=this.getScaledCoordinates(a,e),l=0,c=o;l<c.length;l+=1){var u=c[l];if(Math.abs(u.coord.x-s.x)<=n&&Math.abs(u.coord.y-s.y)<=n&&!r[u.crossTileID]){r[u.crossTileID]=!0,a.crossTileID=u.crossTileID;break}}}}};var Ce=function(){this.maxCrossTileID=0};Ce.prototype.generate=function(){return++this.maxCrossTileID};var Le=function(){this.indexes={},this.usedCrossTileIDs={},this.lng=0};Le.prototype.handleWrapJump=function(t){var e=Math.round((t-this.lng)/360);if(0!==e)for(var r in this.indexes){var n=this.indexes[r],i={};for(var a in n){var o=n[a];o.tileID=o.tileID.unwrapTo(o.tileID.wrap+e),i[o.tileID.key]=o}this.indexes[r]=i}this.lng=t},Le.prototype.addBucket=function(t,e,r){if(this.indexes[t.overscaledZ]&&this.indexes[t.overscaledZ][t.key]){if(this.indexes[t.overscaledZ][t.key].bucketInstanceId===e.bucketInstanceId)return!1;this.removeBucketCrossTileIDs(t.overscaledZ,this.indexes[t.overscaledZ][t.key])}for(var n=0;n<e.symbolInstances.length;n++)e.symbolInstances.get(n).crossTileID=0;this.usedCrossTileIDs[t.overscaledZ]||(this.usedCrossTileIDs[t.overscaledZ]={});var i=this.usedCrossTileIDs[t.overscaledZ];for(var a in this.indexes){var o=this.indexes[a];if(Number(a)>t.overscaledZ)for(var s in o){var l=o[s];l.tileID.isChildOf(t)&&l.findMatches(e.symbolInstances,t,i)}else{var c=o[t.scaledTo(Number(a)).key];c&&c.findMatches(e.symbolInstances,t,i)}}for(var u=0;u<e.symbolInstances.length;u++){var h=e.symbolInstances.get(u);h.crossTileID||(h.crossTileID=r.generate(),i[h.crossTileID]=!0)}return void 0===this.indexes[t.overscaledZ]&&(this.indexes[t.overscaledZ]={}),this.indexes[t.overscaledZ][t.key]=new Ee(t,e.symbolInstances,e.bucketInstanceId),!0},Le.prototype.removeBucketCrossTileIDs=function(t,e){for(var r in e.indexedSymbolInstances)for(var n=0,i=e.indexedSymbolInstances[r];n<i.length;n+=1){var a=i[n];delete this.usedCrossTileIDs[t][a.crossTileID]}},Le.prototype.removeStaleBuckets=function(t){var e=!1;for(var r in this.indexes){var n=this.indexes[r];for(var i in n)t[n[i].bucketInstanceId]||(this.removeBucketCrossTileIDs(r,n[i]),delete n[i],e=!0)}return e};var Pe=function(){this.layerIndexes={},this.crossTileIDs=new Ce,this.maxBucketInstanceId=0,this.bucketsInCurrentPlacement={}};Pe.prototype.addLayer=function(t,e,r){var n=this.layerIndexes[t.id];void 0===n&&(n=this.layerIndexes[t.id]=new Le);var i=!1,a={};n.handleWrapJump(r);for(var o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.getBucket(t);c&&t.id===c.layerIds[0]&&(c.bucketInstanceId||(c.bucketInstanceId=++this.maxBucketInstanceId),n.addBucket(l.tileID,c,this.crossTileIDs)&&(i=!0),a[c.bucketInstanceId]=!0)}return n.removeStaleBuckets(a)&&(i=!0),i},Pe.prototype.pruneUnusedLayers=function(t){var e={};for(var r in t.forEach(function(t){e[t]=!0}),this.layerIndexes)e[r]||delete this.layerIndexes[r]};var Oe=function(e,r){return t.emitValidationErrors(e,r&&r.filter(function(t){return\"source.canvas\"!==t.identifier}))},ze=t.pick(Bt,[\"addLayer\",\"removeLayer\",\"setPaintProperty\",\"setLayoutProperty\",\"setFilter\",\"addSource\",\"removeSource\",\"setLayerZoomRange\",\"setLight\",\"setTransition\",\"setGeoJSONSourceData\"]),Ie=t.pick(Bt,[\"setCenter\",\"setZoom\",\"setBearing\",\"setPitch\"]),De=function(e){function r(n,i){var a=this;void 0===i&&(i={}),e.call(this),this.map=n,this.dispatcher=new k((It||(It=new zt),It),this),this.imageManager=new f,this.imageManager.setEventedParent(this),this.glyphManager=new y(n._requestManager,i.localIdeographFontFamily),this.lineAtlas=new w(256,512),this.crossTileSymbolIndex=new Pe,this._layers={},this._order=[],this.sourceCaches={},this.zoomHistory=new t.ZoomHistory,this._loaded=!1,this._resetUpdates(),this.dispatcher.broadcast(\"setReferrer\",t.getReferrer());var o=this;this._rtlTextPluginCallback=r.registerForPluginAvailability(function(t){for(var e in o.dispatcher.broadcast(\"loadRTLTextPlugin\",t.pluginURL,t.completionCallback),o.sourceCaches)o.sourceCaches[e].reload()}),this.on(\"data\",function(t){if(\"source\"===t.dataType&&\"metadata\"===t.sourceDataType){var e=a.sourceCaches[t.sourceId];if(e){var r=e.getSource();if(r&&r.vectorLayerIds)for(var n in a._layers){var i=a._layers[n];i.source===r.id&&a._validateLayer(i)}}}})}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadURL=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"}));var i=\"boolean\"==typeof r.validate?r.validate:!t.isMapboxURL(e);e=this.map._requestManager.normalizeStyleURL(e,r.accessToken);var a=this.map._requestManager.transformRequest(e,t.ResourceType.Style);this._request=t.getJSON(a,function(e,r){n._request=null,e?n.fire(new t.ErrorEvent(e)):r&&n._load(r,i)})},r.prototype.loadJSON=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"})),this._request=t.browser.frame(function(){n._request=null,n._load(e,!1!==r.validate)})},r.prototype._load=function(e,r){var n=this;if(!r||!Oe(this,t.validateStyle(e))){for(var i in this._loaded=!0,this.stylesheet=e,e.sources)this.addSource(i,e.sources[i],{validate:!1});e.sprite?this._spriteRequest=function(e,r,n){var i,a,o,s=t.browser.devicePixelRatio>1?\"@2x\":\"\",l=t.getJSON(r.transformRequest(r.normalizeSpriteURL(e,s,\".json\"),t.ResourceType.SpriteJSON),function(t,e){l=null,o||(o=t,i=e,u())}),c=t.getImage(r.transformRequest(r.normalizeSpriteURL(e,s,\".png\"),t.ResourceType.SpriteImage),function(t,e){c=null,o||(o=t,a=e,u())});function u(){if(o)n(o);else if(i&&a){var e=t.browser.getImageData(a),r={};for(var s in i){var l=i[s],c=l.width,u=l.height,h=l.x,f=l.y,p=l.sdf,d=l.pixelRatio,g=new t.RGBAImage({width:c,height:u});t.RGBAImage.copy(e,g,{x:h,y:f},{x:0,y:0},{width:c,height:u}),r[s]={data:g,pixelRatio:d,sdf:p}}n(null,r)}}return{cancel:function(){l&&(l.cancel(),l=null),c&&(c.cancel(),c=null)}}}(e.sprite,this.map._requestManager,function(e,r){if(n._spriteRequest=null,e)n.fire(new t.ErrorEvent(e));else if(r)for(var i in r)n.imageManager.addImage(i,r[i]);n.imageManager.setLoaded(!0),n.fire(new t.Event(\"data\",{dataType:\"style\"}))}):this.imageManager.setLoaded(!0),this.glyphManager.setURL(e.glyphs);var a=Ft(this.stylesheet.layers);this._order=a.map(function(t){return t.id}),this._layers={};for(var o=0,s=a;o<s.length;o+=1){var l=s[o];(l=t.createStyleLayer(l)).setEventedParent(this,{layer:{id:l.id}}),this._layers[l.id]=l}this.dispatcher.broadcast(\"setLayers\",this._serializeLayers(this._order)),this.light=new _(this.stylesheet.light),this.fire(new t.Event(\"data\",{dataType:\"style\"})),this.fire(new t.Event(\"style.load\"))}},r.prototype._validateLayer=function(e){var r=this.sourceCaches[e.source];if(r){var n=e.sourceLayer;if(n){var i=r.getSource();(\"geojson\"===i.type||i.vectorLayerIds&&-1===i.vectorLayerIds.indexOf(n))&&this.fire(new t.ErrorEvent(new Error('Source layer \"'+n+'\" does not exist on source \"'+i.id+'\" as specified by style layer \"'+e.id+'\"')))}}},r.prototype.loaded=function(){if(!this._loaded)return!1;if(Object.keys(this._updatedSources).length)return!1;for(var t in this.sourceCaches)if(!this.sourceCaches[t].loaded())return!1;return!!this.imageManager.isLoaded()},r.prototype._serializeLayers=function(t){for(var e=[],r=0,n=t;r<n.length;r+=1){var i=n[r],a=this._layers[i];\"custom\"!==a.type&&e.push(a.serialize())}return e},r.prototype.hasTransitions=function(){if(this.light&&this.light.hasTransition())return!0;for(var t in this.sourceCaches)if(this.sourceCaches[t].hasTransition())return!0;for(var e in this._layers)if(this._layers[e].hasTransition())return!0;return!1},r.prototype._checkLoaded=function(){if(!this._loaded)throw new Error(\"Style is not done loading\")},r.prototype.update=function(e){if(this._loaded){var r=this._changed;if(this._changed){var n=Object.keys(this._updatedLayers),i=Object.keys(this._removedLayers);for(var a in(n.length||i.length)&&this._updateWorkerLayers(n,i),this._updatedSources){var o=this._updatedSources[a];\"reload\"===o?this._reloadSource(a):\"clear\"===o&&this._clearSource(a)}for(var s in this._updatedPaintProps)this._layers[s].updateTransitions(e);this.light.updateTransitions(e),this._resetUpdates()}for(var l in this.sourceCaches)this.sourceCaches[l].used=!1;for(var c=0,u=this._order;c<u.length;c+=1){var h=u[c],f=this._layers[h];f.recalculate(e),!f.isHidden(e.zoom)&&f.source&&(this.sourceCaches[f.source].used=!0)}this.light.recalculate(e),this.z=e.zoom,r&&this.fire(new t.Event(\"data\",{dataType:\"style\"}))}},r.prototype._updateWorkerLayers=function(t,e){this.dispatcher.broadcast(\"updateLayers\",{layers:this._serializeLayers(t),removedIds:e})},r.prototype._resetUpdates=function(){this._changed=!1,this._updatedLayers={},this._removedLayers={},this._updatedSources={},this._updatedPaintProps={}},r.prototype.setState=function(e){var r=this;if(this._checkLoaded(),Oe(this,t.validateStyle(e)))return!1;(e=t.clone$1(e)).layers=Ft(e.layers);var n=function(e,r){if(!e)return[{command:Bt.setStyle,args:[r]}];var n=[];try{if(!t.deepEqual(e.version,r.version))return[{command:Bt.setStyle,args:[r]}];t.deepEqual(e.center,r.center)||n.push({command:Bt.setCenter,args:[r.center]}),t.deepEqual(e.zoom,r.zoom)||n.push({command:Bt.setZoom,args:[r.zoom]}),t.deepEqual(e.bearing,r.bearing)||n.push({command:Bt.setBearing,args:[r.bearing]}),t.deepEqual(e.pitch,r.pitch)||n.push({command:Bt.setPitch,args:[r.pitch]}),t.deepEqual(e.sprite,r.sprite)||n.push({command:Bt.setSprite,args:[r.sprite]}),t.deepEqual(e.glyphs,r.glyphs)||n.push({command:Bt.setGlyphs,args:[r.glyphs]}),t.deepEqual(e.transition,r.transition)||n.push({command:Bt.setTransition,args:[r.transition]}),t.deepEqual(e.light,r.light)||n.push({command:Bt.setLight,args:[r.light]});var i={},a=[];!function(e,r,n,i){var a;for(a in r=r||{},e=e||{})e.hasOwnProperty(a)&&(r.hasOwnProperty(a)||jt(a,n,i));for(a in r)r.hasOwnProperty(a)&&(e.hasOwnProperty(a)?t.deepEqual(e[a],r[a])||(\"geojson\"===e[a].type&&\"geojson\"===r[a].type&&Vt(e,r,a)?n.push({command:Bt.setGeoJSONSourceData,args:[a,r[a].data]}):Ut(a,r,n,i)):Nt(a,r,n))}(e.sources,r.sources,a,i);var o=[];e.layers&&e.layers.forEach(function(t){i[t.source]?n.push({command:Bt.removeLayer,args:[t.id]}):o.push(t)}),n=n.concat(a),function(e,r,n){r=r||[];var i,a,o,s,l,c,u,h=(e=e||[]).map(Ht),f=r.map(Ht),p=e.reduce(Gt,{}),d=r.reduce(Gt,{}),g=h.slice(),v=Object.create(null);for(i=0,a=0;i<h.length;i++)o=h[i],d.hasOwnProperty(o)?a++:(n.push({command:Bt.removeLayer,args:[o]}),g.splice(g.indexOf(o,a),1));for(i=0,a=0;i<f.length;i++)o=f[f.length-1-i],g[g.length-1-i]!==o&&(p.hasOwnProperty(o)?(n.push({command:Bt.removeLayer,args:[o]}),g.splice(g.lastIndexOf(o,g.length-a),1)):a++,c=g[g.length-i],n.push({command:Bt.addLayer,args:[d[o],c]}),g.splice(g.length-i,0,o),v[o]=!0);for(i=0;i<f.length;i++)if(s=p[o=f[i]],l=d[o],!v[o]&&!t.deepEqual(s,l))if(t.deepEqual(s.source,l.source)&&t.deepEqual(s[\"source-layer\"],l[\"source-layer\"])&&t.deepEqual(s.type,l.type)){for(u in qt(s.layout,l.layout,n,o,null,Bt.setLayoutProperty),qt(s.paint,l.paint,n,o,null,Bt.setPaintProperty),t.deepEqual(s.filter,l.filter)||n.push({command:Bt.setFilter,args:[o,l.filter]}),t.deepEqual(s.minzoom,l.minzoom)&&t.deepEqual(s.maxzoom,l.maxzoom)||n.push({command:Bt.setLayerZoomRange,args:[o,l.minzoom,l.maxzoom]}),s)s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?qt(s[u],l[u],n,o,u.slice(6),Bt.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Bt.setLayerProperty,args:[o,u,l[u]]}));for(u in l)l.hasOwnProperty(u)&&!s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?qt(s[u],l[u],n,o,u.slice(6),Bt.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Bt.setLayerProperty,args:[o,u,l[u]]}))}else n.push({command:Bt.removeLayer,args:[o]}),c=g[g.lastIndexOf(o)+1],n.push({command:Bt.addLayer,args:[l,c]})}(o,r.layers,n)}catch(t){console.warn(\"Unable to compute style diff:\",t),n=[{command:Bt.setStyle,args:[r]}]}return n}(this.serialize(),e).filter(function(t){return!(t.command in Ie)});if(0===n.length)return!1;var i=n.filter(function(t){return!(t.command in ze)});if(i.length>0)throw new Error(\"Unimplemented: \"+i.map(function(t){return t.command}).join(\", \")+\".\");return n.forEach(function(t){\"setTransition\"!==t.command&&r[t.command].apply(r,t.args)}),this.stylesheet=e,!0},r.prototype.addImage=function(e,r){if(this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"An image with this name already exists.\")));this.imageManager.addImage(e,r),this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.updateImage=function(t,e){this.imageManager.updateImage(t,e)},r.prototype.getImage=function(t){return this.imageManager.getImage(t)},r.prototype.removeImage=function(e){if(!this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"No image with this name exists.\")));this.imageManager.removeImage(e),this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.listImages=function(){return this._checkLoaded(),this.imageManager.listImages()},r.prototype.addSource=function(e,r,n){var i=this;if(void 0===n&&(n={}),this._checkLoaded(),void 0!==this.sourceCaches[e])throw new Error(\"There is already a source with this ID\");if(!r.type)throw new Error(\"The type property must be defined, but the only the following properties were given: \"+Object.keys(r).join(\", \")+\".\");if(!([\"vector\",\"raster\",\"geojson\",\"video\",\"image\"].indexOf(r.type)>=0&&this._validate(t.validateStyle.source,\"sources.\"+e,r,null,n))){this.map&&this.map._collectResourceTiming&&(r.collectResourceTiming=!0);var a=this.sourceCaches[e]=new Ct(e,r,this.dispatcher);a.style=this,a.setEventedParent(this,function(){return{isSourceLoaded:i.loaded(),source:a.serialize(),sourceId:e}}),a.onAdd(this.map),this._changed=!0}},r.prototype.removeSource=function(e){if(this._checkLoaded(),void 0===this.sourceCaches[e])throw new Error(\"There is no source with this ID\");for(var r in this._layers)if(this._layers[r].source===e)return this.fire(new t.ErrorEvent(new Error('Source \"'+e+'\" cannot be removed while layer \"'+r+'\" is using it.')));var n=this.sourceCaches[e];delete this.sourceCaches[e],delete this._updatedSources[e],n.fire(new t.Event(\"data\",{sourceDataType:\"metadata\",dataType:\"source\",sourceId:e})),n.setEventedParent(null),n.clearTiles(),n.onRemove&&n.onRemove(this.map),this._changed=!0},r.prototype.setGeoJSONSourceData=function(t,e){this._checkLoaded(),this.sourceCaches[t].getSource().setData(e),this._changed=!0},r.prototype.getSource=function(t){return this.sourceCaches[t]&&this.sourceCaches[t].getSource()},r.prototype.addLayer=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=e.id;if(this.getLayer(i))this.fire(new t.ErrorEvent(new Error('Layer with id \"'+i+'\" already exists on this map')));else{var a;if(\"custom\"===e.type){if(Oe(this,t.validateCustomStyleLayer(e)))return;a=t.createStyleLayer(e)}else{if(\"object\"==typeof e.source&&(this.addSource(i,e.source),e=t.clone$1(e),e=t.extend(e,{source:i})),this._validate(t.validateStyle.layer,\"layers.\"+i,e,{arrayIndex:-1},n))return;a=t.createStyleLayer(e),this._validateLayer(a),a.setEventedParent(this,{layer:{id:i}})}var o=r?this._order.indexOf(r):this._order.length;if(r&&-1===o)this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.')));else{if(this._order.splice(o,0,i),this._layerOrderChanged=!0,this._layers[i]=a,this._removedLayers[i]&&a.source&&\"custom\"!==a.type){var s=this._removedLayers[i];delete this._removedLayers[i],s.type!==a.type?this._updatedSources[a.source]=\"clear\":(this._updatedSources[a.source]=\"reload\",this.sourceCaches[a.source].pause())}this._updateLayer(a),a.onAdd&&a.onAdd(this.map)}}},r.prototype.moveLayer=function(e,r){if(this._checkLoaded(),this._changed=!0,this._layers[e]){if(e!==r){var n=this._order.indexOf(e);this._order.splice(n,1);var i=r?this._order.indexOf(r):this._order.length;r&&-1===i?this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.'))):(this._order.splice(i,0,e),this._layerOrderChanged=!0)}}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be moved.\")))},r.prototype.removeLayer=function(e){this._checkLoaded();var r=this._layers[e];if(r){r.setEventedParent(null);var n=this._order.indexOf(e);this._order.splice(n,1),this._layerOrderChanged=!0,this._changed=!0,this._removedLayers[e]=r,delete this._layers[e],delete this._updatedLayers[e],delete this._updatedPaintProps[e],r.onRemove&&r.onRemove(this.map)}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be removed.\")))},r.prototype.getLayer=function(t){return this._layers[t]},r.prototype.setLayerZoomRange=function(e,r,n){this._checkLoaded();var i=this.getLayer(e);i?i.minzoom===r&&i.maxzoom===n||(null!=r&&(i.minzoom=r),null!=n&&(i.maxzoom=n),this._updateLayer(i)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot have zoom extent.\")))},r.prototype.setFilter=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=this.getLayer(e);if(i){if(!t.deepEqual(i.filter,r))return null==r?(i.filter=void 0,void this._updateLayer(i)):void(this._validate(t.validateStyle.filter,\"layers.\"+i.id+\".filter\",r,null,n)||(i.filter=t.clone$1(r),this._updateLayer(i)))}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be filtered.\")))},r.prototype.getFilter=function(e){return t.clone$1(this.getLayer(e).filter)},r.prototype.setLayoutProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getLayoutProperty(r),n)||(a.setLayoutProperty(r,n,i),this._updateLayer(a)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getLayoutProperty=function(e,r){var n=this.getLayer(e);if(n)return n.getLayoutProperty(r);this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style.\")))},r.prototype.setPaintProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getPaintProperty(r),n)||(a.setPaintProperty(r,n,i)&&this._updateLayer(a),this._changed=!0,this._updatedPaintProps[e]=!0):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getPaintProperty=function(t,e){return this.getLayer(t).getPaintProperty(e)},r.prototype.setFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=e.sourceLayer,a=this.sourceCaches[n],o=parseInt(e.id,10);if(void 0!==a){var s=a.getSource().type;\"geojson\"===s&&i?this.fire(new t.ErrorEvent(new Error(\"GeoJSON sources cannot have a sourceLayer parameter.\"))):\"vector\"!==s||i?isNaN(o)||o<0?this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided and non-negative.\"))):a.setFeatureState(i,o,r):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.removeFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=this.sourceCaches[n];if(void 0!==i){var a=i.getSource().type,o=\"vector\"===a?e.sourceLayer:void 0,s=parseInt(e.id,10);\"vector\"!==a||o?void 0!==e.id&&isNaN(s)||s<0?this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be non-negative.\"))):r&&\"string\"!=typeof e.id&&\"number\"!=typeof e.id?this.fire(new t.ErrorEvent(new Error(\"A feature id is requred to remove its specific state property.\"))):i.removeFeatureState(o,s,r):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.getFeatureState=function(e){this._checkLoaded();var r=e.source,n=e.sourceLayer,i=this.sourceCaches[r],a=parseInt(e.id,10);if(void 0!==i)if(\"vector\"!==i.getSource().type||n){if(!(isNaN(a)||a<0))return i.getFeatureState(n,a);this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided and non-negative.\")))}else this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")));else this.fire(new t.ErrorEvent(new Error(\"The source '\"+r+\"' does not exist in the map's style.\")))},r.prototype.getTransition=function(){return t.extend({duration:300,delay:0},this.stylesheet&&this.stylesheet.transition)},r.prototype.serialize=function(){return t.filterObject({version:this.stylesheet.version,name:this.stylesheet.name,metadata:this.stylesheet.metadata,light:this.stylesheet.light,center:this.stylesheet.center,zoom:this.stylesheet.zoom,bearing:this.stylesheet.bearing,pitch:this.stylesheet.pitch,sprite:this.stylesheet.sprite,glyphs:this.stylesheet.glyphs,transition:this.stylesheet.transition,sources:t.mapObject(this.sourceCaches,function(t){return t.serialize()}),layers:this._serializeLayers(this._order)},function(t){return void 0!==t})},r.prototype._updateLayer=function(t){this._updatedLayers[t.id]=!0,t.source&&!this._updatedSources[t.source]&&(this._updatedSources[t.source]=\"reload\",this.sourceCaches[t.source].pause()),this._changed=!0},r.prototype._flattenAndSortRenderedFeatures=function(t){for(var e=this,r=function(t){return\"fill-extrusion\"===e._layers[t].type},n={},i=[],a=this._order.length-1;a>=0;a--){var o=this._order[a];if(r(o)){n[o]=a;for(var s=0,l=t;s<l.length;s+=1){var c=l[s][o];if(c)for(var u=0,h=c;u<h.length;u+=1){var f=h[u];i.push(f)}}}}i.sort(function(t,e){return e.intersectionZ-t.intersectionZ});for(var p=[],d=this._order.length-1;d>=0;d--){var g=this._order[d];if(r(g))for(var v=i.length-1;v>=0;v--){var m=i[v].feature;if(n[m.layer.id]<d)break;p.push(m),i.pop()}else for(var y=0,x=t;y<x.length;y+=1){var b=x[y][g];if(b)for(var _=0,w=b;_<w.length;_+=1){var k=w[_];p.push(k.feature)}}}return p},r.prototype.queryRenderedFeatures=function(e,r,n){r&&r.filter&&this._validate(t.validateStyle.filter,\"queryRenderedFeatures.filter\",r.filter,null,r);var i={};if(r&&r.layers){if(!Array.isArray(r.layers))return this.fire(new t.ErrorEvent(new Error(\"parameters.layers must be an Array.\"))),[];for(var a=0,o=r.layers;a<o.length;a+=1){var s=o[a],l=this._layers[s];if(!l)return this.fire(new t.ErrorEvent(new Error(\"The layer '\"+s+\"' does not exist in the map's style and cannot be queried for features.\"))),[];i[l.source]=!0}}var c=[];for(var u in this.sourceCaches)r.layers&&!i[u]||c.push(R(this.sourceCaches[u],this._layers,e,r,n));return this.placement&&c.push(function(t,e,r,n,i,a){for(var o={},s=i.queryRenderedSymbols(r),l=[],c=0,u=Object.keys(s).map(Number);c<u.length;c+=1){var h=u[c];l.push(a[h])}l.sort(F);for(var f=function(){var e=d[p],r=e.featureIndex.lookupSymbolFeatures(s[e.bucketInstanceId],e.bucketIndex,e.sourceLayerIndex,n.filter,n.layers,t);for(var i in r){var a=o[i]=o[i]||[],l=r[i];l.sort(function(t,r){var n=e.featureSortOrder;if(n){var i=n.indexOf(t.featureIndex);return n.indexOf(r.featureIndex)-i}return r.featureIndex-t.featureIndex});for(var c=0,u=l;c<u.length;c+=1){var h=u[c];a.push(h)}}},p=0,d=l;p<d.length;p+=1)f();var g=function(r){o[r].forEach(function(n){var i=n.feature,a=t[r],o=e[a.source].getFeatureState(i.layer[\"source-layer\"],i.id);i.source=i.layer.source,i.layer[\"source-layer\"]&&(i.sourceLayer=i.layer[\"source-layer\"]),i.state=o})};for(var v in o)g(v);return o}(this._layers,this.sourceCaches,e,r,this.placement.collisionIndex,this.placement.retainedQueryData)),this._flattenAndSortRenderedFeatures(c)},r.prototype.querySourceFeatures=function(e,r){r&&r.filter&&this._validate(t.validateStyle.filter,\"querySourceFeatures.filter\",r.filter,null,r);var n=this.sourceCaches[e];return n?function(t,e){for(var r=t.getRenderableIds().map(function(e){return t.getTileByID(e)}),n=[],i={},a=0;a<r.length;a++){var o=r[a],s=o.tileID.canonical.key;i[s]||(i[s]=!0,o.querySourceFeatures(n,e))}return n}(n,r):[]},r.prototype.addSourceType=function(t,e,n){return r.getSourceType(t)?n(new Error('A source type called \"'+t+'\" already exists.')):(r.setSourceType(t,e),e.workerSourceURL?void this.dispatcher.broadcast(\"loadWorkerSource\",{name:t,url:e.workerSourceURL},n):n(null,null))},r.prototype.getLight=function(){return this.light.getLight()},r.prototype.setLight=function(e,r){void 0===r&&(r={}),this._checkLoaded();var n=this.light.getLight(),i=!1;for(var a in e)if(!t.deepEqual(e[a],n[a])){i=!0;break}if(i){var o={now:t.browser.now(),transition:t.extend({duration:300,delay:0},this.stylesheet.transition)};this.light.setLight(e,r),this.light.updateTransitions(o)}},r.prototype._validate=function(e,r,n,i,a){return void 0===a&&(a={}),(!a||!1!==a.validate)&&Oe(this,e.call(t.validateStyle,t.extend({key:r,style:this.serialize(),value:n,styleSpec:t.styleSpec},i)))},r.prototype._remove=function(){for(var e in this._request&&(this._request.cancel(),this._request=null),this._spriteRequest&&(this._spriteRequest.cancel(),this._spriteRequest=null),t.evented.off(\"pluginAvailable\",this._rtlTextPluginCallback),this.sourceCaches)this.sourceCaches[e].clearTiles();this.dispatcher.remove()},r.prototype._clearSource=function(t){this.sourceCaches[t].clearTiles()},r.prototype._reloadSource=function(t){this.sourceCaches[t].resume(),this.sourceCaches[t].reload()},r.prototype._updateSources=function(t){for(var e in this.sourceCaches)this.sourceCaches[e].update(t)},r.prototype._generateCollisionBoxes=function(){for(var t in this.sourceCaches)this._reloadSource(t)},r.prototype._updatePlacement=function(e,r,n,i){for(var a=!1,o=!1,s={},l=0,c=this._order;l<c.length;l+=1){var u=c[l],h=this._layers[u];if(\"symbol\"===h.type){if(!s[h.source]){var f=this.sourceCaches[h.source];s[h.source]=f.getRenderableIds(!0).map(function(t){return f.getTileByID(t)}).sort(function(t,e){return e.tileID.overscaledZ-t.tileID.overscaledZ||(t.tileID.isLessThan(e.tileID)?-1:1)})}var p=this.crossTileSymbolIndex.addLayer(h,s[h.source],e.center.lng);a=a||p}}this.crossTileSymbolIndex.pruneUnusedLayers(this._order);var d=this._layerOrderChanged||0===n;if((d||!this.pauseablePlacement||this.pauseablePlacement.isDone()&&!this.placement.stillRecent(t.browser.now()))&&(this.pauseablePlacement=new Me(e,this._order,d,r,n,i,this.placement),this._layerOrderChanged=!1),this.pauseablePlacement.isDone()?this.placement.setStale():(this.pauseablePlacement.continuePlacement(this._order,this._layers,s),this.pauseablePlacement.isDone()&&(this.placement=this.pauseablePlacement.commit(t.browser.now()),o=!0),a&&this.pauseablePlacement.placement.setStale()),o||a)for(var g=0,v=this._order;g<v.length;g+=1){var m=v[g],y=this._layers[m];\"symbol\"===y.type&&this.placement.updateLayerOpacities(y,s[y.source])}return!this.pauseablePlacement.isDone()||this.placement.hasTransitions(t.browser.now())},r.prototype._releaseSymbolFadeTiles=function(){for(var t in this.sourceCaches)this.sourceCaches[t].releaseSymbolFadeTiles()},r.prototype.getImages=function(t,e,r){this.imageManager.getImages(e.icons,r)},r.prototype.getGlyphs=function(t,e,r){this.glyphManager.getGlyphs(e.stacks,r)},r.prototype.getResource=function(e,r,n){return t.makeRequest(r,n)},r}(t.Evented);De.getSourceType=function(t){return z[t]},De.setSourceType=function(t,e){z[t]=e},De.registerForPluginAvailability=t.registerForPluginAvailability;var Re=t.createLayout([{name:\"a_pos\",type:\"Int16\",components:2}]),Fe=lr(\"#ifdef GL_ES\\nprecision mediump float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\",\"#ifdef GL_ES\\nprecision highp float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\\nvec2 unpack_float(const float packedValue) {int packedIntValue=int(packedValue);int v0=packedIntValue/256;return vec2(v0,packedIntValue-v0*256);}vec2 unpack_opacity(const float packedOpacity) {int intOpacity=int(packedOpacity)/2;return vec2(float(intOpacity)/127.0,mod(packedOpacity,2.0));}vec4 decode_color(const vec2 encodedColor) {return vec4(unpack_float(encodedColor[0])/255.0,unpack_float(encodedColor[1])/255.0\\n);}float unpack_mix_vec2(const vec2 packedValue,const float t) {return mix(packedValue[0],packedValue[1],t);}vec4 unpack_mix_color(const vec4 packedColors,const float t) {vec4 minColor=decode_color(vec2(packedColors[0],packedColors[1]));vec4 maxColor=decode_color(vec2(packedColors[2],packedColors[3]));return mix(minColor,maxColor,t);}vec2 get_pattern_pos(const vec2 pixel_coord_upper,const vec2 pixel_coord_lower,const vec2 pattern_size,const float tile_units_to_pixels,const vec2 pos) {vec2 offset=mod(mod(mod(pixel_coord_upper,pattern_size)*256.0,pattern_size)*256.0+pixel_coord_lower,pattern_size);return (tile_units_to_pixels*pos+offset)/pattern_size;}\"),Be=lr(\"uniform vec4 u_color;uniform float u_opacity;void main() {gl_FragColor=u_color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),Ne=lr(\"uniform vec2 u_pattern_tl_a;uniform vec2 u_pattern_br_a;uniform vec2 u_pattern_tl_b;uniform vec2 u_pattern_br_b;uniform vec2 u_texsize;uniform float u_mix;uniform float u_opacity;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(u_pattern_tl_a/u_texsize,u_pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(u_pattern_tl_b/u_texsize,u_pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_mix)*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pattern_size_a;uniform vec2 u_pattern_size_b;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_scale_a;uniform float u_scale_b;uniform float u_tile_units_to_pixels;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_a*u_pattern_size_a,u_tile_units_to_pixels,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_b*u_pattern_size_b,u_tile_units_to_pixels,a_pos);}\"),je=lr(\"varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=v_data.xy;float extrude_length=length(extrude);lowp float antialiasblur=v_data.z;float antialiased_blur=-max(blur,antialiasblur);float opacity_t=smoothstep(0.0,antialiased_blur,extrude_length-1.0);float color_t=stroke_width < 0.01 ? 0.0 : smoothstep(antialiased_blur,0.0,extrude_length-radius/(radius+stroke_width));gl_FragColor=opacity_t*mix(color*opacity,stroke_color*stroke_opacity,color_t);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform bool u_scale_with_map;uniform bool u_pitch_with_map;uniform vec2 u_extrude_scale;uniform lowp float u_device_pixel_ratio;uniform highp float u_camera_to_center_distance;attribute vec2 a_pos;varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main(void) {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=vec2(mod(a_pos,2.0)*2.0-1.0);vec2 circle_center=floor(a_pos*0.5);if (u_pitch_with_map) {vec2 corner_position=circle_center;if (u_scale_with_map) {corner_position+=extrude*(radius+stroke_width)*u_extrude_scale;} else {vec4 projected_center=u_matrix*vec4(circle_center,0,1);corner_position+=extrude*(radius+stroke_width)*u_extrude_scale*(projected_center.w/u_camera_to_center_distance);}gl_Position=u_matrix*vec4(corner_position,0,1);} else {gl_Position=u_matrix*vec4(circle_center,0,1);if (u_scale_with_map) {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*u_camera_to_center_distance;} else {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*gl_Position.w;}}lowp float antialiasblur=1.0/u_device_pixel_ratio/(radius+stroke_width);v_data=vec3(extrude.x,extrude.y,antialiasblur);}\"),Ue=lr(\"void main() {gl_FragColor=vec4(1.0);}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),Ve=lr(\"uniform highp float u_intensity;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main() {\\n#pragma mapbox: initialize highp float weight\\nfloat d=-0.5*3.0*3.0*dot(v_extrude,v_extrude);float val=weight*u_intensity*GAUSS_COEF*exp(d);gl_FragColor=vec4(val,1.0,1.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform float u_extrude_scale;uniform float u_opacity;uniform float u_intensity;attribute vec2 a_pos;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#pragma mapbox: define mediump float radius\\nconst highp float ZERO=1.0/255.0/16.0;\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main(void) {\\n#pragma mapbox: initialize highp float weight\\n#pragma mapbox: initialize mediump float radius\\nvec2 unscaled_extrude=vec2(mod(a_pos,2.0)*2.0-1.0);float S=sqrt(-2.0*log(ZERO/weight/u_intensity/GAUSS_COEF))/3.0;v_extrude=S*unscaled_extrude;vec2 extrude=v_extrude*radius*u_extrude_scale;vec4 pos=vec4(floor(a_pos*0.5)+extrude,0,1);gl_Position=u_matrix*pos;}\"),qe=lr(\"uniform sampler2D u_image;uniform sampler2D u_color_ramp;uniform float u_opacity;varying vec2 v_pos;void main() {float t=texture2D(u_image,v_pos).r;vec4 color=texture2D(u_color_ramp,vec2(t,0.5));gl_FragColor=color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(0.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;attribute vec2 a_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos*u_world,0,1);v_pos.x=a_pos.x;v_pos.y=1.0-a_pos.y;}\"),He=lr(\"varying float v_placed;varying float v_notUsed;void main() {float alpha=0.5;gl_FragColor=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {gl_FragColor=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {gl_FragColor*=.1;}}\",\"attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;attribute vec2 a_shift;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);gl_Position.xy+=(a_extrude+a_shift)*u_extrude_scale*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;}\"),Ge=lr(\"uniform float u_overscale_factor;varying float v_placed;varying float v_notUsed;varying float v_radius;varying vec2 v_extrude;varying vec2 v_extrude_scale;void main() {float alpha=0.5;vec4 color=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {color=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {color*=.2;}float extrude_scale_length=length(v_extrude_scale);float extrude_length=length(v_extrude)*extrude_scale_length;float stroke_width=15.0*extrude_scale_length/u_overscale_factor;float radius=v_radius*extrude_scale_length;float distance_to_edge=abs(extrude_length-radius);float opacity_t=smoothstep(-stroke_width,0.0,-distance_to_edge);gl_FragColor=opacity_t*color;}\",\"attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;varying float v_radius;varying vec2 v_extrude;varying vec2 v_extrude_scale;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);highp float padding_factor=1.2;gl_Position.xy+=a_extrude*u_extrude_scale*padding_factor*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;v_radius=abs(a_extrude.y);v_extrude=a_extrude*padding_factor;v_extrude_scale=u_extrude_scale*u_camera_to_center_distance*collision_perspective_ratio;}\"),Ye=lr(\"uniform highp vec4 u_color;void main() {gl_FragColor=u_color;}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),We=lr(\"#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_FragColor=color*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);}\"),Xe=lr(\"varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=outline_color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;uniform vec2 u_world;varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),Ze=lr(\"uniform vec2 u_texsize;uniform sampler2D u_image;uniform float u_fade;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);float dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=mix(color1,color2,u_fade)*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec4 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;gl_Position=u_matrix*vec4(a_pos,0,1);vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,a_pos);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),Je=lr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_fade)*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec4 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileZoomRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileZoomRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileZoomRatio,a_pos);}\"),Ke=lr(\"varying vec4 v_color;void main() {gl_FragColor=v_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;uniform float u_vertical_gradient;uniform lowp float u_opacity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec4 v_color;\\n#pragma mapbox: define highp float base\\n#pragma mapbox: define highp float height\\n#pragma mapbox: define highp vec4 color\\nvoid main() {\\n#pragma mapbox: initialize highp float base\\n#pragma mapbox: initialize highp float height\\n#pragma mapbox: initialize highp vec4 color\\nvec3 normal=a_normal_ed.xyz;base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);gl_Position=u_matrix*vec4(a_pos,t > 0.0 ? height : base,1);float colorvalue=color.r*0.2126+color.g*0.7152+color.b*0.0722;v_color=vec4(0.0,0.0,0.0,1.0);vec4 ambientlight=vec4(0.03,0.03,0.03,1.0);color+=ambientlight;float directional=clamp(dot(normal/16384.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((1.0-colorvalue+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_color.r+=clamp(color.r*directional*u_lightcolor.r,mix(0.0,0.3,1.0-u_lightcolor.r),1.0);v_color.g+=clamp(color.g*directional*u_lightcolor.g,mix(0.0,0.3,1.0-u_lightcolor.g),1.0);v_color.b+=clamp(color.b*directional*u_lightcolor.b,mix(0.0,0.3,1.0-u_lightcolor.b),1.0);v_color*=u_opacity;}\"),$e=lr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);vec4 mixedColor=mix(color1,color2,u_fade);gl_FragColor=mixedColor*v_lighting;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_height_factor;uniform vec4 u_scale;uniform float u_vertical_gradient;uniform lowp float u_opacity;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec3 normal=a_normal_ed.xyz;float edgedistance=a_normal_ed.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);float z=t > 0.0 ? height : base;gl_Position=u_matrix*vec4(a_pos,z,1);vec2 pos=normal.x==1.0 && normal.y==0.0 && normal.z==16384.0\\n? a_pos\\n: vec2(edgedistance,z*u_height_factor);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,pos);v_lighting=vec4(0.0,0.0,0.0,1.0);float directional=clamp(dot(normal/16383.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((0.5+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_lighting.rgb+=clamp(directional*u_lightcolor,mix(vec3(0.0),vec3(0.3),1.0-u_lightcolor),vec3(1.0));v_lighting*=u_opacity;}\"),Qe=lr(\"#ifdef GL_ES\\nprecision highp float;\\n#endif\\nuniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_dimension;uniform float u_zoom;uniform float u_maxzoom;float getElevation(vec2 coord,float bias) {vec4 data=texture2D(u_image,coord)*255.0;return (data.r+data.g*256.0+data.b*256.0*256.0)/4.0;}void main() {vec2 epsilon=1.0/u_dimension;float a=getElevation(v_pos+vec2(-epsilon.x,-epsilon.y),0.0);float b=getElevation(v_pos+vec2(0,-epsilon.y),0.0);float c=getElevation(v_pos+vec2(epsilon.x,-epsilon.y),0.0);float d=getElevation(v_pos+vec2(-epsilon.x,0),0.0);float e=getElevation(v_pos,0.0);float f=getElevation(v_pos+vec2(epsilon.x,0),0.0);float g=getElevation(v_pos+vec2(-epsilon.x,epsilon.y),0.0);float h=getElevation(v_pos+vec2(0,epsilon.y),0.0);float i=getElevation(v_pos+vec2(epsilon.x,epsilon.y),0.0);float exaggeration=u_zoom < 2.0 ? 0.4 : u_zoom < 4.5 ? 0.35 : 0.3;vec2 deriv=vec2((c+f+f+i)-(a+d+d+g),(g+h+h+i)-(a+b+b+c))/ pow(2.0,(u_zoom-u_maxzoom)*exaggeration+19.2562-u_zoom);gl_FragColor=clamp(vec4(deriv.x/2.0+0.5,deriv.y/2.0+0.5,1.0,1.0),0.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_dimension;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);highp vec2 epsilon=1.0/u_dimension;float scale=(u_dimension.x-2.0)/u_dimension.x;v_pos=(a_texture_pos/8192.0)*scale+epsilon;}\"),tr=lr(\"uniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_latrange;uniform vec2 u_light;uniform vec4 u_shadow;uniform vec4 u_highlight;uniform vec4 u_accent;\\n#define PI 3.141592653589793\\nvoid main() {vec4 pixel=texture2D(u_image,v_pos);vec2 deriv=((pixel.rg*2.0)-1.0);float scaleFactor=cos(radians((u_latrange[0]-u_latrange[1])*(1.0-v_pos.y)+u_latrange[1]));float slope=atan(1.25*length(deriv)/scaleFactor);float aspect=deriv.x !=0.0 ? atan(deriv.y,-deriv.x) : PI/2.0*(deriv.y > 0.0 ? 1.0 :-1.0);float intensity=u_light.x;float azimuth=u_light.y+PI;float base=1.875-intensity*1.75;float maxValue=0.5*PI;float scaledSlope=intensity !=0.5 ? ((pow(base,slope)-1.0)/(pow(base,maxValue)-1.0))*maxValue : slope;float accent=cos(scaledSlope);vec4 accent_color=(1.0-accent)*u_accent*clamp(intensity*2.0,0.0,1.0);float shade=abs(mod((aspect+azimuth)/PI+0.5,2.0)-1.0);vec4 shade_color=mix(u_shadow,u_highlight,shade)*sin(scaledSlope)*clamp(intensity*2.0,0.0,1.0);gl_FragColor=accent_color*(1.0-shade_color.a)+shade_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos=a_texture_pos/8192.0;}\"),er=lr(\"uniform lowp float u_device_pixel_ratio;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform vec2 u_units_to_pixels;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_linesofar;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),rr=lr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);vec4 color=texture2D(u_image,vec2(v_lineprogress,0.5));gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define MAX_LINE_DISTANCE 32767.0\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_lineprogress=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0/MAX_LINE_DISTANCE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),nr=lr(\"uniform lowp float u_device_pixel_ratio;uniform vec2 u_texsize;uniform float u_fade;uniform mediump vec4 u_scale;uniform sampler2D u_image;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float pixelRatio=u_scale.x;float tileZoomRatio=u_scale.y;float fromScale=u_scale.z;float toScale=u_scale.w;vec2 display_size_a=vec2((pattern_br_a.x-pattern_tl_a.x)/pixelRatio,(pattern_br_a.y-pattern_tl_a.y)/pixelRatio);vec2 display_size_b=vec2((pattern_br_b.x-pattern_tl_b.x)/pixelRatio,(pattern_br_b.y-pattern_tl_b.y)/pixelRatio);vec2 pattern_size_a=vec2(display_size_a.x*fromScale/tileZoomRatio,display_size_a.y);vec2 pattern_size_b=vec2(display_size_b.x*toScale/tileZoomRatio,display_size_b.y);float dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float x_a=mod(v_linesofar/pattern_size_a.x,1.0);float x_b=mod(v_linesofar/pattern_size_b.x,1.0);float y_a=0.5+(v_normal.y*clamp(v_width2.s,0.0,(pattern_size_a.y+2.0)/2.0)/pattern_size_a.y);float y_b=0.5+(v_normal.y*clamp(v_width2.s,0.0,(pattern_size_b.y+2.0)/2.0)/pattern_size_b.y);vec2 pos_a=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,vec2(x_a,y_a));vec2 pos_b=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,vec2(x_b,y_b));vec4 color=mix(texture2D(u_image,pos_a),texture2D(u_image,pos_b),u_fade);gl_FragColor=color*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform vec2 u_units_to_pixels;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_linesofar=a_linesofar;v_width2=vec2(outset,inset);}\"),ir=lr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;uniform float u_sdfgamma;uniform float u_mix;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float sdfdist_a=texture2D(u_image,v_tex_a).a;float sdfdist_b=texture2D(u_image,v_tex_b).a;float sdfdist=mix(sdfdist_a,sdfdist_b,u_mix);alpha*=smoothstep(0.5-u_sdfgamma/floorwidth,0.5+u_sdfgamma/floorwidth,sdfdist);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_patternscale_a;uniform float u_tex_y_a;uniform vec2 u_patternscale_b;uniform float u_tex_y_b;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_tex_a=vec2(a_linesofar*u_patternscale_a.x/floorwidth,normal.y*u_patternscale_a.y+u_tex_y_a);v_tex_b=vec2(a_linesofar*u_patternscale_b.x/floorwidth,normal.y*u_patternscale_b.y+u_tex_y_b);v_width2=vec2(outset,inset);}\"),ar=lr(\"uniform float u_fade_t;uniform float u_opacity;uniform sampler2D u_image0;uniform sampler2D u_image1;varying vec2 v_pos0;varying vec2 v_pos1;uniform float u_brightness_low;uniform float u_brightness_high;uniform float u_saturation_factor;uniform float u_contrast_factor;uniform vec3 u_spin_weights;void main() {vec4 color0=texture2D(u_image0,v_pos0);vec4 color1=texture2D(u_image1,v_pos1);if (color0.a > 0.0) {color0.rgb=color0.rgb/color0.a;}if (color1.a > 0.0) {color1.rgb=color1.rgb/color1.a;}vec4 color=mix(color0,color1,u_fade_t);color.a*=u_opacity;vec3 rgb=color.rgb;rgb=vec3(dot(rgb,u_spin_weights.xyz),dot(rgb,u_spin_weights.zxy),dot(rgb,u_spin_weights.yzx));float average=(color.r+color.g+color.b)/3.0;rgb+=(average-rgb)*u_saturation_factor;rgb=(rgb-0.5)*u_contrast_factor+0.5;vec3 u_high_vec=vec3(u_brightness_low,u_brightness_low,u_brightness_low);vec3 u_low_vec=vec3(u_brightness_high,u_brightness_high,u_brightness_high);gl_FragColor=vec4(mix(u_high_vec,u_low_vec,rgb)*color.a,color.a);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_tl_parent;uniform float u_scale_parent;uniform float u_buffer_scale;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos0;varying vec2 v_pos1;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos0=(((a_texture_pos/8192.0)-0.5)/u_buffer_scale )+0.5;v_pos1=(v_pos0*u_scale_parent)+u_tl_parent;}\"),or=lr(\"uniform sampler2D u_texture;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nlowp float alpha=opacity*v_fade_opacity;gl_FragColor=texture2D(u_texture,v_tex)*alpha;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform highp float u_camera_to_center_distance;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform float u_fade_change;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform vec2 u_texsize;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size[0],a_size[1],u_size_t)/256.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size[0]/256.0;} else if (!u_is_size_zoom_constant && u_is_size_feature_constant) {size=u_size;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);v_tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;v_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));}\"),sr=lr(\"#define SDF_PX 8.0\\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;uniform bool u_is_text;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nfloat EDGE_GAMMA=0.105/u_device_pixel_ratio;vec2 tex=v_data0.xy;float gamma_scale=v_data1.x;float size=v_data1.y;float fade_opacity=v_data1[2];float fontScale=u_is_text ? size/24.0 : size;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size[0],a_size[1],u_size_t)/256.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size[0]/256.0;} else if (!u_is_size_zoom_constant && u_is_size_feature_constant) {size=u_size;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);float gamma_scale=gl_Position.w;vec2 tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));v_data0=vec2(tex.x,tex.y);v_data1=vec3(gamma_scale,size,interpolated_fade_opacity);}\");function lr(t,e){var r=/#pragma mapbox: ([\\w]+) ([\\w]+) ([\\w]+) ([\\w]+)/g,n={};return{fragmentSource:t=t.replace(r,function(t,e,r,i,a){return n[a]=!0,\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"\\n#ifdef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"}),vertexSource:e=e.replace(r,function(t,e,r,i,a){var o=\"float\"===i?\"vec2\":\"vec4\",s=a.match(/color/)?\"color\":o;return n[a]?\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"})}}var cr=Object.freeze({prelude:Fe,background:Be,backgroundPattern:Ne,circle:je,clippingMask:Ue,heatmap:Ve,heatmapTexture:qe,collisionBox:He,collisionCircle:Ge,debug:Ye,fill:We,fillOutline:Xe,fillOutlinePattern:Ze,fillPattern:Je,fillExtrusion:Ke,fillExtrusionPattern:$e,hillshadePrepare:Qe,hillshade:tr,line:er,lineGradient:rr,linePattern:nr,lineSDF:ir,raster:ar,symbolIcon:or,symbolSDF:sr}),ur=function(){this.boundProgram=null,this.boundLayoutVertexBuffer=null,this.boundPaintVertexBuffers=[],this.boundIndexBuffer=null,this.boundVertexOffset=null,this.boundDynamicVertexBuffer=null,this.vao=null};ur.prototype.bind=function(t,e,r,n,i,a,o,s){this.context=t;for(var l=this.boundPaintVertexBuffers.length!==n.length,c=0;!l&&c<n.length;c++)this.boundPaintVertexBuffers[c]!==n[c]&&(l=!0);var u=!this.vao||this.boundProgram!==e||this.boundLayoutVertexBuffer!==r||l||this.boundIndexBuffer!==i||this.boundVertexOffset!==a||this.boundDynamicVertexBuffer!==o||this.boundDynamicVertexBuffer2!==s;!t.extVertexArrayObject||u?this.freshBind(e,r,n,i,a,o,s):(t.bindVertexArrayOES.set(this.vao),o&&o.bind(),i&&i.dynamicDraw&&i.bind(),s&&s.bind())},ur.prototype.freshBind=function(t,e,r,n,i,a,o){var s,l=t.numAttributes,c=this.context,u=c.gl;if(c.extVertexArrayObject)this.vao&&this.destroy(),this.vao=c.extVertexArrayObject.createVertexArrayOES(),c.bindVertexArrayOES.set(this.vao),s=0,this.boundProgram=t,this.boundLayoutVertexBuffer=e,this.boundPaintVertexBuffers=r,this.boundIndexBuffer=n,this.boundVertexOffset=i,this.boundDynamicVertexBuffer=a,this.boundDynamicVertexBuffer2=o;else{s=c.currentNumAttributes||0;for(var h=l;h<s;h++)u.disableVertexAttribArray(h)}e.enableAttributes(u,t);for(var f=0,p=r;f<p.length;f+=1)p[f].enableAttributes(u,t);a&&a.enableAttributes(u,t),o&&o.enableAttributes(u,t),e.bind(),e.setVertexAttribPointers(u,t,i);for(var d=0,g=r;d<g.length;d+=1){var v=g[d];v.bind(),v.setVertexAttribPointers(u,t,i)}a&&(a.bind(),a.setVertexAttribPointers(u,t,i)),n&&n.bind(),o&&(o.bind(),o.setVertexAttribPointers(u,t,i)),c.currentNumAttributes=l},ur.prototype.destroy=function(){this.vao&&(this.context.extVertexArrayObject.deleteVertexArrayOES(this.vao),this.vao=null)};var hr=function(t,e,r,n,i){var a=t.gl;this.program=a.createProgram();var o=r.defines();i&&o.push(\"#define OVERDRAW_INSPECTOR;\");var s=o.concat(Fe.fragmentSource,e.fragmentSource).join(\"\\n\"),l=o.concat(Fe.vertexSource,e.vertexSource).join(\"\\n\"),c=a.createShader(a.FRAGMENT_SHADER);a.shaderSource(c,s),a.compileShader(c),a.attachShader(this.program,c);var u=a.createShader(a.VERTEX_SHADER);a.shaderSource(u,l),a.compileShader(u),a.attachShader(this.program,u);for(var h=r.layoutAttributes||[],f=0;f<h.length;f++)a.bindAttribLocation(this.program,f,h[f].name);a.linkProgram(this.program),this.numAttributes=a.getProgramParameter(this.program,a.ACTIVE_ATTRIBUTES),this.attributes={};for(var p={},d=0;d<this.numAttributes;d++){var g=a.getActiveAttrib(this.program,d);g&&(this.attributes[g.name]=a.getAttribLocation(this.program,g.name))}for(var v=a.getProgramParameter(this.program,a.ACTIVE_UNIFORMS),m=0;m<v;m++){var y=a.getActiveUniform(this.program,m);y&&(p[y.name]=a.getUniformLocation(this.program,y.name))}this.fixedUniforms=n(t,p),this.binderUniforms=r.getUniforms(t,p)};function fr(e,r,n){var i=1/le(n,1,r.transform.tileZoom),a=Math.pow(2,n.tileID.overscaledZ),o=n.tileSize*Math.pow(2,r.transform.tileZoom)/a,s=o*(n.tileID.canonical.x+n.tileID.wrap*a),l=o*n.tileID.canonical.y;return{u_image:0,u_texsize:n.imageAtlasTexture.size,u_scale:[t.browser.devicePixelRatio,i,e.fromScale,e.toScale],u_fade:e.t,u_pixel_coord_upper:[s>>16,l>>16],u_pixel_coord_lower:[65535&s,65535&l]}}hr.prototype.draw=function(t,e,r,n,i,a,o,s,l,c,u,h,f,p,d,g){var v,m=t.gl;for(var y in t.program.set(this.program),t.setDepthMode(r),t.setStencilMode(n),t.setColorMode(i),t.setCullFace(a),this.fixedUniforms)this.fixedUniforms[y].set(o[y]);p&&p.setUniforms(t,this.binderUniforms,h,{zoom:f});for(var x=(v={},v[m.LINES]=2,v[m.TRIANGLES]=3,v[m.LINE_STRIP]=1,v)[e],b=0,_=u.get();b<_.length;b+=1){var w=_[b],k=w.vaos||(w.vaos={});(k[s]||(k[s]=new ur)).bind(t,this,l,p?p.getPaintVertexBuffers():[],c,w.vertexOffset,d,g),m.drawElements(e,w.primitiveLength*x,m.UNSIGNED_SHORT,w.primitiveOffset*x*2)}};var pr=function(e,r,n,i){var a=r.style.light,o=a.properties.get(\"position\"),s=[o.x,o.y,o.z],l=t.create$1();\"viewport\"===a.properties.get(\"anchor\")&&t.fromRotation(l,-r.transform.angle),t.transformMat3(s,s,l);var c=a.properties.get(\"color\");return{u_matrix:e,u_lightpos:s,u_lightintensity:a.properties.get(\"intensity\"),u_lightcolor:[c.r,c.g,c.b],u_vertical_gradient:+n,u_opacity:i}},dr=function(e,r,n,i,a,o,s){return t.extend(pr(e,r,n,i),fr(o,r,s),{u_height_factor:-Math.pow(2,a.overscaledZ)/s.tileSize/8})},gr=function(t){return{u_matrix:t}},vr=function(e,r,n,i){return t.extend(gr(e),fr(n,r,i))},mr=function(t,e){return{u_matrix:t,u_world:e}},yr=function(e,r,n,i,a){return t.extend(vr(e,r,n,i),{u_world:a})},xr=function(e,r,n,i){var a,o,s=e.transform;if(\"map\"===i.paint.get(\"circle-pitch-alignment\")){var l=le(n,1,s.zoom);a=!0,o=[l,l]}else a=!1,o=s.pixelsToGLUnits;return{u_camera_to_center_distance:s.cameraToCenterDistance,u_scale_with_map:+(\"map\"===i.paint.get(\"circle-pitch-scale\")),u_matrix:e.translatePosMatrix(r.posMatrix,n,i.paint.get(\"circle-translate\"),i.paint.get(\"circle-translate-anchor\")),u_pitch_with_map:+a,u_device_pixel_ratio:t.browser.devicePixelRatio,u_extrude_scale:o}},br=function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pixels_to_tile_units:new t.Uniform1f(e,r.u_pixels_to_tile_units),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_overscale_factor:new t.Uniform1f(e,r.u_overscale_factor)}},_r=function(t,e,r){var n=le(r,1,e.zoom),i=Math.pow(2,e.zoom-r.tileID.overscaledZ),a=r.tileID.overscaleFactor();return{u_matrix:t,u_camera_to_center_distance:e.cameraToCenterDistance,u_pixels_to_tile_units:n,u_extrude_scale:[e.pixelsToGLUnits[0]/(n*i),e.pixelsToGLUnits[1]/(n*i)],u_overscale_factor:a}},wr=function(t,e){return{u_matrix:t,u_color:e}},kr=function(t){return{u_matrix:t}},Tr=function(t,e,r,n){return{u_matrix:t,u_extrude_scale:le(e,1,r),u_intensity:n}},Ar=function(t,e,r){var n=r.paint.get(\"hillshade-shadow-color\"),i=r.paint.get(\"hillshade-highlight-color\"),a=r.paint.get(\"hillshade-accent-color\"),o=r.paint.get(\"hillshade-illumination-direction\")*(Math.PI/180);\"viewport\"===r.paint.get(\"hillshade-illumination-anchor\")&&(o-=t.transform.angle);var s=!t.options.moving;return{u_matrix:t.transform.calculatePosMatrix(e.tileID.toUnwrapped(),s),u_image:0,u_latrange:Sr(t,e.tileID),u_light:[r.paint.get(\"hillshade-exaggeration\"),o],u_shadow:n,u_highlight:i,u_accent:a}},Mr=function(e,r){var n=e.dem.stride,i=t.create();return t.ortho(i,0,t.EXTENT,-t.EXTENT,0,0,1),t.translate(i,i,[0,-t.EXTENT,0]),{u_matrix:i,u_image:1,u_dimension:[n,n],u_zoom:e.tileID.overscaledZ,u_maxzoom:r}};function Sr(e,r){var n=Math.pow(2,r.canonical.z),i=r.canonical.y;return[new t.MercatorCoordinate(0,i/n).toLngLat().lat,new t.MercatorCoordinate(0,(i+1)/n).toLngLat().lat]}var Er=function(e,r,n){var i=e.transform;return{u_matrix:zr(e,r,n),u_ratio:1/le(r,1,i.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_units_to_pixels:[1/i.pixelsToGLUnits[0],1/i.pixelsToGLUnits[1]]}},Cr=function(e,r,n){return t.extend(Er(e,r,n),{u_image:0})},Lr=function(e,r,n,i){var a=e.transform,o=Or(r,a);return{u_matrix:zr(e,r,n),u_texsize:r.imageAtlasTexture.size,u_ratio:1/le(r,1,a.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_image:0,u_scale:[t.browser.devicePixelRatio,o,i.fromScale,i.toScale],u_fade:i.t,u_units_to_pixels:[1/a.pixelsToGLUnits[0],1/a.pixelsToGLUnits[1]]}},Pr=function(e,r,n,i,a){var o=e.transform,s=e.lineAtlas,l=Or(r,o),c=\"round\"===n.layout.get(\"line-cap\"),u=s.getDash(i.from,c),h=s.getDash(i.to,c),f=u.width*a.fromScale,p=h.width*a.toScale;return t.extend(Er(e,r,n),{u_patternscale_a:[l/f,-u.height/2],u_patternscale_b:[l/p,-h.height/2],u_sdfgamma:s.width/(256*Math.min(f,p)*t.browser.devicePixelRatio)/2,u_image:0,u_tex_y_a:u.y,u_tex_y_b:h.y,u_mix:a.t})};function Or(t,e){return 1/le(t,1,e.tileZoom)}function zr(t,e,r){return t.translatePosMatrix(e.tileID.posMatrix,e,r.paint.get(\"line-translate\"),r.paint.get(\"line-translate-anchor\"))}var Ir=function(t,e,r,n,i){return{u_matrix:t,u_tl_parent:e,u_scale_parent:r,u_buffer_scale:1,u_fade_t:n.mix,u_opacity:n.opacity*i.paint.get(\"raster-opacity\"),u_image0:0,u_image1:1,u_brightness_low:i.paint.get(\"raster-brightness-min\"),u_brightness_high:i.paint.get(\"raster-brightness-max\"),u_saturation_factor:(o=i.paint.get(\"raster-saturation\"),o>0?1-1/(1.001-o):-o),u_contrast_factor:(a=i.paint.get(\"raster-contrast\"),a>0?1/(1-a):1+a),u_spin_weights:function(t){t*=Math.PI/180;var e=Math.sin(t),r=Math.cos(t);return[(2*r+1)/3,(-Math.sqrt(3)*e-r+1)/3,(Math.sqrt(3)*e-r+1)/3]}(i.paint.get(\"raster-hue-rotate\"))};var a,o};var Dr=function(t,e,r,n,i,a,o,s,l,c){var u=i.transform;return{u_is_size_zoom_constant:+(\"constant\"===t||\"source\"===t),u_is_size_feature_constant:+(\"constant\"===t||\"camera\"===t),u_size_t:e?e.uSizeT:0,u_size:e?e.uSize:0,u_camera_to_center_distance:u.cameraToCenterDistance,u_pitch:u.pitch/360*2*Math.PI,u_rotate_symbol:+r,u_aspect_ratio:u.width/u.height,u_fade_change:i.options.fadeDuration?i.symbolFadeChange:1,u_matrix:a,u_label_plane_matrix:o,u_coord_matrix:s,u_is_text:+l,u_pitch_with_map:+n,u_texsize:c,u_texture:0}},Rr=function(e,r,n,i,a,o,s,l,c,u,h){var f=a.transform;return t.extend(Dr(e,r,n,i,a,o,s,l,c,u),{u_gamma_scale:i?Math.cos(f._pitch)*f.cameraToCenterDistance:1,u_device_pixel_ratio:t.browser.devicePixelRatio,u_is_halo:+h})},Fr=function(t,e,r){return{u_matrix:t,u_opacity:e,u_color:r}},Br=function(e,r,n,i,a,o){return t.extend(function(t,e,r,n){var i=r.imageManager.getPattern(t.from),a=r.imageManager.getPattern(t.to),o=r.imageManager.getPixelSize(),s=o.width,l=o.height,c=Math.pow(2,n.tileID.overscaledZ),u=n.tileSize*Math.pow(2,r.transform.tileZoom)/c,h=u*(n.tileID.canonical.x+n.tileID.wrap*c),f=u*n.tileID.canonical.y;return{u_image:0,u_pattern_tl_a:i.tl,u_pattern_br_a:i.br,u_pattern_tl_b:a.tl,u_pattern_br_b:a.br,u_texsize:[s,l],u_mix:e.t,u_pattern_size_a:i.displaySize,u_pattern_size_b:a.displaySize,u_scale_a:e.fromScale,u_scale_b:e.toScale,u_tile_units_to_pixels:1/le(n,1,r.transform.tileZoom),u_pixel_coord_upper:[h>>16,f>>16],u_pixel_coord_lower:[65535&h,65535&f]}}(i,o,n,a),{u_matrix:e,u_opacity:r})},Nr={fillExtrusion:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fillExtrusionPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_height_factor:new t.Uniform1f(e,r.u_height_factor),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fill:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},fillPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},fillOutline:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world)}},fillOutlinePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},circle:function(e,r){return{u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_scale_with_map:new t.Uniform1i(e,r.u_scale_with_map),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},collisionBox:br,collisionCircle:br,debug:function(e,r){return{u_color:new t.UniformColor(e,r.u_color),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},clippingMask:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmap:function(e,r){return{u_extrude_scale:new t.Uniform1f(e,r.u_extrude_scale),u_intensity:new t.Uniform1f(e,r.u_intensity),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmapTexture:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_color_ramp:new t.Uniform1i(e,r.u_color_ramp),u_opacity:new t.Uniform1f(e,r.u_opacity)}},hillshade:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_latrange:new t.Uniform2f(e,r.u_latrange),u_light:new t.Uniform2f(e,r.u_light),u_shadow:new t.UniformColor(e,r.u_shadow),u_highlight:new t.UniformColor(e,r.u_highlight),u_accent:new t.UniformColor(e,r.u_accent)}},hillshadePrepare:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_dimension:new t.Uniform2f(e,r.u_dimension),u_zoom:new t.Uniform1f(e,r.u_zoom),u_maxzoom:new t.Uniform1f(e,r.u_maxzoom)}},line:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels)}},lineGradient:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_image:new t.Uniform1i(e,r.u_image)}},linePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_texsize:new t.Uniform2f(e,r.u_texsize),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_image:new t.Uniform1i(e,r.u_image),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_scale:new t.Uniform4f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},lineSDF:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_patternscale_a:new t.Uniform2f(e,r.u_patternscale_a),u_patternscale_b:new t.Uniform2f(e,r.u_patternscale_b),u_sdfgamma:new t.Uniform1f(e,r.u_sdfgamma),u_image:new t.Uniform1i(e,r.u_image),u_tex_y_a:new t.Uniform1f(e,r.u_tex_y_a),u_tex_y_b:new t.Uniform1f(e,r.u_tex_y_b),u_mix:new t.Uniform1f(e,r.u_mix)}},raster:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_tl_parent:new t.Uniform2f(e,r.u_tl_parent),u_scale_parent:new t.Uniform1f(e,r.u_scale_parent),u_buffer_scale:new t.Uniform1f(e,r.u_buffer_scale),u_fade_t:new t.Uniform1f(e,r.u_fade_t),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image0:new t.Uniform1i(e,r.u_image0),u_image1:new t.Uniform1i(e,r.u_image1),u_brightness_low:new t.Uniform1f(e,r.u_brightness_low),u_brightness_high:new t.Uniform1f(e,r.u_brightness_high),u_saturation_factor:new t.Uniform1f(e,r.u_saturation_factor),u_contrast_factor:new t.Uniform1f(e,r.u_contrast_factor),u_spin_weights:new t.Uniform3f(e,r.u_spin_weights)}},symbolIcon:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1f(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture)}},symbolSDF:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1f(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture),u_gamma_scale:new t.Uniform1f(e,r.u_gamma_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_is_halo:new t.Uniform1f(e,r.u_is_halo)}},background:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_color:new t.UniformColor(e,r.u_color)}},backgroundPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image:new t.Uniform1i(e,r.u_image),u_pattern_tl_a:new t.Uniform2f(e,r.u_pattern_tl_a),u_pattern_br_a:new t.Uniform2f(e,r.u_pattern_br_a),u_pattern_tl_b:new t.Uniform2f(e,r.u_pattern_tl_b),u_pattern_br_b:new t.Uniform2f(e,r.u_pattern_br_b),u_texsize:new t.Uniform2f(e,r.u_texsize),u_mix:new t.Uniform1f(e,r.u_mix),u_pattern_size_a:new t.Uniform2f(e,r.u_pattern_size_a),u_pattern_size_b:new t.Uniform2f(e,r.u_pattern_size_b),u_scale_a:new t.Uniform1f(e,r.u_scale_a),u_scale_b:new t.Uniform1f(e,r.u_scale_b),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_tile_units_to_pixels:new t.Uniform1f(e,r.u_tile_units_to_pixels)}}};function jr(e,r){for(var n=e.sort(function(t,e){return t.tileID.isLessThan(e.tileID)?-1:e.tileID.isLessThan(t.tileID)?1:0}),i=0;i<n.length;i++){var a={},o=n[i],s=n.slice(i+1);Ur(o.tileID.wrapped(),o.tileID,s,new t.OverscaledTileID(0,o.tileID.wrap+1,0,0,0),a),o.setMask(a,r)}}function Ur(e,r,n,i,a){for(var o=0;o<n.length;o++){var s=n[o];if(i.isLessThan(s.tileID))break;if(r.key===s.tileID.key)return;if(s.tileID.isChildOf(r)){for(var l=r.children(1/0),c=0;c<l.length;c++)Ur(e,l[c],n.slice(o),i,a);return}}var u=r.overscaledZ-e.overscaledZ,h=new t.CanonicalTileID(u,r.canonical.x-(e.canonical.x<<u),r.canonical.y-(e.canonical.y<<u));a[h.key]=a[h.key]||h}function Vr(t,e,r,n,i){for(var a=t.context,o=a.gl,s=i?t.useProgram(\"collisionCircle\"):t.useProgram(\"collisionBox\"),l=0;l<n.length;l++){var c=n[l],u=e.getTile(c),h=u.getBucket(r);if(h){var f=i?h.collisionCircle:h.collisionBox;f&&s.draw(a,i?o.TRIANGLES:o.LINES,Tt.disabled,At.disabled,t.colorModeForRenderPass(),St.disabled,_r(c.posMatrix,t.transform,u),r.id,f.layoutVertexBuffer,f.indexBuffer,f.segments,null,t.transform.zoom,null,null,f.collisionVertexBuffer)}}}var qr=t.identity(new Float32Array(16));function Hr(e,r,n,i,a,o){var s=t.getAnchorAlignment(e),l=-(s.horizontalAlign-.5)*r,c=-(s.verticalAlign-.5)*n,u=t.evaluateRadialOffset(e,i);return new t.Point((l/a+u[0])*o,(c/a+u[1])*o)}function Gr(e,r,n,i,a,o,s,l,c,u){var h=e.text.placedSymbolArray,f=e.text.dynamicLayoutVertexArray;f.clear();for(var p=0;p<h.length;p++){var d=h.get(p),g=!d.hidden&&d.crossTileID?i[d.crossTileID]:null;if(g){var v=new t.Point(d.anchorX,d.anchorY),m=Zt(v,n?l:s),y=.5+o.cameraToCenterDistance/m.signedDistanceFromCamera*.5,x=a.evaluateSizeForFeature(e.textSizeData,u,d)*y/t.ONE_EM;n&&(x*=e.tilePixelRatio/c);for(var b=g.width,_=g.height,w=g.radialOffset,k=g.textBoxScale,T=Hr(g.anchor,b,_,w,k,x),A=n?Zt(v.add(T),s).point:m.point.add(r?T.rotate(-o.angle):T),M=0;M<d.numGlyphs;M++)t.addDynamicAttributes(f,A,0)}else ie(d.numGlyphs,f)}e.text.dynamicLayoutVertexBuffer.updateData(f)}function Yr(e,r,n,i,a,o,s,l,c,u,h,f,p){for(var d,g,v=e.context,m=v.gl,y=e.transform,x=\"map\"===l,b=\"map\"===c,_=x&&\"point\"!==n.layout.get(\"symbol-placement\"),w=x&&!b&&!_,k=void 0!==n.layout.get(\"symbol-sort-key\").constantOr(1),T=e.depthModeForSublayer(0,Tt.ReadOnly),A=n.layout.get(\"text-variable-anchor\"),M=[],S=0,E=i;S<E.length;S+=1){var C=E[S],L=r.getTile(C),P=L.getBucket(n);if(P){var O=a?P.text:P.icon;if(O&&O.segments.get().length){var z=O.programConfigurations.get(n.id),I=a||P.sdfIcons,D=a?P.textSizeData:P.iconSizeData;d||(d=e.useProgram(I?\"symbolSDF\":\"symbolIcon\",z),g=t.evaluateSizeForZoom(D,y.zoom)),v.activeTexture.set(m.TEXTURE0);var R=void 0,F=void 0,B=void 0;if(a)F=L.glyphAtlasTexture,B=m.LINEAR,R=L.glyphAtlasTexture.size;else{var N=1!==n.layout.get(\"icon-size\").constantOr(0)||P.iconsNeedLinear,j=b||0!==y.pitch;F=L.imageAtlasTexture,B=I||e.options.rotating||e.options.zooming||N||j?m.LINEAR:m.NEAREST,R=L.imageAtlasTexture.size}var U=le(L,1,e.transform.zoom),V=Wt(C.posMatrix,b,x,e.transform,U),q=Xt(C.posMatrix,b,x,e.transform,U);if(_)Kt(P,C.posMatrix,e,a,V,q,b,u);else if(a&&g&&A){var H=Math.pow(2,y.zoom-L.tileID.overscaledZ);Gr(P,x,b,p,t.symbolSize,y,V,C.posMatrix,H,g)}var G=e.translatePosMatrix(C.posMatrix,L,o,s),Y=_||a&&A?qr:V,W=e.translatePosMatrix(q,L,o,s,!0),X=I&&0!==n.paint.get(a?\"text-halo-width\":\"icon-halo-width\").constantOr(1),Z={program:d,buffers:O,uniformValues:I?Rr(D.kind,g,w,b,e,G,Y,W,a,R,!0):Dr(D.kind,g,w,b,e,G,Y,W,a,R),atlasTexture:F,atlasInterpolation:B,isSDF:I,hasHalo:X};if(k)for(var J=0,K=O.segments.get();J<K.length;J+=1){var $=K[J];M.push({segments:new t.SegmentVector([$]),sortKey:$.sortKey,state:Z})}else M.push({segments:O.segments,sortKey:0,state:Z})}}}k&&M.sort(function(t,e){return t.sortKey-e.sortKey});for(var Q=0,tt=M;Q<tt.length;Q+=1){var et=tt[Q],rt=et.state;if(rt.atlasTexture.bind(rt.atlasInterpolation,m.CLAMP_TO_EDGE),rt.isSDF){var nt=rt.uniformValues;rt.hasHalo&&(nt.u_is_halo=1,Wr(rt.buffers,et.segments,n,e,rt.program,T,h,f,nt)),nt.u_is_halo=0}Wr(rt.buffers,et.segments,n,e,rt.program,T,h,f,rt.uniformValues)}}function Wr(t,e,r,n,i,a,o,s,l){var c=n.context,u=c.gl;i.draw(c,u.TRIANGLES,a,o,s,St.disabled,l,r.id,t.layoutVertexBuffer,t.indexBuffer,e,r.paint,n.transform.zoom,t.programConfigurations.get(r.id),t.dynamicLayoutVertexBuffer,t.opacityVertexBuffer)}function Xr(t,e,r,n,i,a,o){var s,l,c,u,h,f=t.context.gl,p=r.paint.get(\"fill-pattern\"),d=p&&p.constantOr(1),g=r.getCrossfadeParameters();o?(l=d&&!r.getPaintProperty(\"fill-outline-color\")?\"fillOutlinePattern\":\"fillOutline\",s=f.LINES):(l=d?\"fillPattern\":\"fill\",s=f.TRIANGLES);for(var v=0,m=n;v<m.length;v+=1){var y=m[v],x=e.getTile(y);if(!d||x.patternsLoaded()){var b=x.getBucket(r);if(b){var _=b.programConfigurations.get(r.id),w=t.useProgram(l,_);d&&(t.context.activeTexture.set(f.TEXTURE0),x.imageAtlasTexture.bind(f.LINEAR,f.CLAMP_TO_EDGE),_.updatePatternPaintBuffers(g));var k=p.constantOr(null);if(k&&x.imageAtlas){var T=x.imageAtlas.patternPositions[k.to],A=x.imageAtlas.patternPositions[k.from];T&&A&&_.setConstantPatternPositions(T,A)}var M=t.translatePosMatrix(y.posMatrix,x,r.paint.get(\"fill-translate\"),r.paint.get(\"fill-translate-anchor\"));if(o){u=b.indexBuffer2,h=b.segments2;var S=[f.drawingBufferWidth,f.drawingBufferHeight];c=\"fillOutlinePattern\"===l&&d?yr(M,t,g,x,S):mr(M,S)}else u=b.indexBuffer,h=b.segments,c=d?vr(M,t,g,x):gr(M);w.draw(t.context,s,i,t.stencilModeForClipping(y),a,St.disabled,c,r.id,b.layoutVertexBuffer,u,h,r.paint,t.transform.zoom,_)}}}}function Zr(t,e,r,n,i,a,o){for(var s=t.context,l=s.gl,c=r.paint.get(\"fill-extrusion-pattern\"),u=c.constantOr(1),h=r.getCrossfadeParameters(),f=r.paint.get(\"fill-extrusion-opacity\"),p=0,d=n;p<d.length;p+=1){var g=d[p],v=e.getTile(g),m=v.getBucket(r);if(m){var y=m.programConfigurations.get(r.id),x=t.useProgram(u?\"fillExtrusionPattern\":\"fillExtrusion\",y);u&&(t.context.activeTexture.set(l.TEXTURE0),v.imageAtlasTexture.bind(l.LINEAR,l.CLAMP_TO_EDGE),y.updatePatternPaintBuffers(h));var b=c.constantOr(null);if(b&&v.imageAtlas){var _=v.imageAtlas.patternPositions[b.to],w=v.imageAtlas.patternPositions[b.from];_&&w&&y.setConstantPatternPositions(_,w)}var k=t.translatePosMatrix(g.posMatrix,v,r.paint.get(\"fill-extrusion-translate\"),r.paint.get(\"fill-extrusion-translate-anchor\")),T=r.paint.get(\"fill-extrusion-vertical-gradient\"),A=u?dr(k,t,T,f,g,h,v):pr(k,t,T,f);x.draw(s,s.gl.TRIANGLES,i,a,o,St.backCCW,A,r.id,m.layoutVertexBuffer,m.indexBuffer,m.segments,r.paint,t.transform.zoom,y)}}}function Jr(t,e,r,n,i,a){var o=t.context,s=o.gl,l=e.fbo;if(l){var c=t.useProgram(\"hillshade\");o.activeTexture.set(s.TEXTURE0),s.bindTexture(s.TEXTURE_2D,l.colorAttachment.get());var u=Ar(t,e,r);e.maskedBoundsBuffer&&e.maskedIndexBuffer&&e.segments?c.draw(o,s.TRIANGLES,n,i,a,St.disabled,u,r.id,e.maskedBoundsBuffer,e.maskedIndexBuffer,e.segments):c.draw(o,s.TRIANGLES,n,i,a,St.disabled,u,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}}function Kr(e,r,n,i,a,o,s){var l=e.context,c=l.gl;if(r.dem&&r.dem.data){var u=r.dem.dim,h=r.dem.stride,f=r.dem.getPixels();if(l.activeTexture.set(c.TEXTURE1),l.pixelStoreUnpackPremultiplyAlpha.set(!1),r.demTexture=r.demTexture||e.getTileTexture(h),r.demTexture){var p=r.demTexture;p.update(f,{premultiply:!1}),p.bind(c.NEAREST,c.CLAMP_TO_EDGE)}else r.demTexture=new t.Texture(l,f,c.RGBA,{premultiply:!1}),r.demTexture.bind(c.NEAREST,c.CLAMP_TO_EDGE);l.activeTexture.set(c.TEXTURE0);var d=r.fbo;if(!d){var g=new t.Texture(l,{width:u,height:u,data:null},c.RGBA);g.bind(c.LINEAR,c.CLAMP_TO_EDGE),(d=r.fbo=l.createFramebuffer(u,u)).colorAttachment.set(g.texture)}l.bindFramebuffer.set(d.framebuffer),l.viewport.set([0,0,u,u]),e.useProgram(\"hillshadePrepare\").draw(l,c.TRIANGLES,a,o,s,St.disabled,Mr(r,i),n.id,e.rasterBoundsBuffer,e.quadTriangleIndexBuffer,e.rasterBoundsSegments),r.needsHillshadePrepare=!1}}function $r(e,r,n,i,a){var o=i.paint.get(\"raster-fade-duration\");if(o>0){var s=t.browser.now(),l=(s-e.timeAdded)/o,c=r?(s-r.timeAdded)/o:-1,u=n.getSource(),h=a.coveringZoomLevel({tileSize:u.tileSize,roundZoom:u.roundZoom}),f=!r||Math.abs(r.tileID.overscaledZ-h)>Math.abs(e.tileID.overscaledZ-h),p=f&&e.refreshedUponExpiration?1:t.clamp(f?l:1-c,0,1);return e.refreshedUponExpiration&&l>=1&&(e.refreshedUponExpiration=!1),r?{opacity:1,mix:1-p}:{opacity:p,mix:0}}return{opacity:1,mix:0}}function Qr(e,r,n){var i=e.context,a=i.gl,o=n.posMatrix,s=e.useProgram(\"debug\"),l=Tt.disabled,c=At.disabled,u=e.colorModeForRenderPass(),h=\"$debug\";s.draw(i,a.LINE_STRIP,l,c,u,St.disabled,wr(o,t.Color.red),h,e.debugBuffer,e.tileBorderIndexBuffer,e.debugSegments);for(var f=r.getTileByID(n.key).latestRawTileData,p=f&&f.byteLength||0,d=Math.floor(p/1024),g=function(t,e,r,n){n=n||1;var i,a,o,s,l,c,u,h,f=[];for(i=0,a=t.length;i<a;i++)if(l=tn[t[i]]){for(h=null,o=0,s=l[1].length;o<s;o+=2)-1===l[1][o]&&-1===l[1][o+1]?h=null:(c=e+l[1][o]*n,u=200-l[1][o+1]*n,h&&f.push(h.x,h.y,c,u),h={x:c,y:u});e+=l[0]*n}return f}(n.toString()+\" \"+d+\"kb\",50,0,5),v=new t.StructArrayLayout2i4,m=new t.StructArrayLayout2ui4,y=0;y<g.length;y+=2)v.emplaceBack(g[y],g[y+1]),m.emplaceBack(y,y+1);for(var x=i.createVertexBuffer(v,Re.members),b=i.createIndexBuffer(m),_=t.SegmentVector.simpleSegment(0,0,v.length/2,v.length/2),w=r.getTile(n).tileSize,k=t.EXTENT/(Math.pow(2,e.transform.zoom-n.overscaledZ)*w),T=[[-1,-1],[-1,1],[1,-1],[1,1]],A=0;A<T.length;A++){var M=T[A];s.draw(i,a.LINES,l,c,u,St.disabled,wr(t.translate([],o,[k*M[0],k*M[1],0]),t.Color.white),h,x,b,_)}s.draw(i,a.LINES,l,c,u,St.disabled,wr(o,t.Color.black),h,x,b,_)}var tn={\" \":[16,[]],\"!\":[10,[5,21,5,7,-1,-1,5,2,4,1,5,0,6,1,5,2]],'\"':[16,[4,21,4,14,-1,-1,12,21,12,14]],\"#\":[21,[11,25,4,-7,-1,-1,17,25,10,-7,-1,-1,4,12,18,12,-1,-1,3,6,17,6]],$:[20,[8,25,8,-4,-1,-1,12,25,12,-4,-1,-1,17,18,15,20,12,21,8,21,5,20,3,18,3,16,4,14,5,13,7,12,13,10,15,9,16,8,17,6,17,3,15,1,12,0,8,0,5,1,3,3]],\"%\":[24,[21,21,3,0,-1,-1,8,21,10,19,10,17,9,15,7,14,5,14,3,16,3,18,4,20,6,21,8,21,10,20,13,19,16,19,19,20,21,21,-1,-1,17,7,15,6,14,4,14,2,16,0,18,0,20,1,21,3,21,5,19,7,17,7]],\"&\":[26,[23,12,23,13,22,14,21,14,20,13,19,11,17,6,15,3,13,1,11,0,7,0,5,1,4,2,3,4,3,6,4,8,5,9,12,13,13,14,14,16,14,18,13,20,11,21,9,20,8,18,8,16,9,13,11,10,16,3,18,1,20,0,22,0,23,1,23,2]],\"'\":[10,[5,19,4,20,5,21,6,20,6,18,5,16,4,15]],\"(\":[14,[11,25,9,23,7,20,5,16,4,11,4,7,5,2,7,-2,9,-5,11,-7]],\")\":[14,[3,25,5,23,7,20,9,16,10,11,10,7,9,2,7,-2,5,-5,3,-7]],\"*\":[16,[8,21,8,9,-1,-1,3,18,13,12,-1,-1,13,18,3,12]],\"+\":[26,[13,18,13,0,-1,-1,4,9,22,9]],\",\":[10,[6,1,5,0,4,1,5,2,6,1,6,-1,5,-3,4,-4]],\"-\":[26,[4,9,22,9]],\".\":[10,[5,2,4,1,5,0,6,1,5,2]],\"/\":[22,[20,25,2,-7]],0:[20,[9,21,6,20,4,17,3,12,3,9,4,4,6,1,9,0,11,0,14,1,16,4,17,9,17,12,16,17,14,20,11,21,9,21]],1:[20,[6,17,8,18,11,21,11,0]],2:[20,[4,16,4,17,5,19,6,20,8,21,12,21,14,20,15,19,16,17,16,15,15,13,13,10,3,0,17,0]],3:[20,[5,21,16,21,10,13,13,13,15,12,16,11,17,8,17,6,16,3,14,1,11,0,8,0,5,1,4,2,3,4]],4:[20,[13,21,3,7,18,7,-1,-1,13,21,13,0]],5:[20,[15,21,5,21,4,12,5,13,8,14,11,14,14,13,16,11,17,8,17,6,16,3,14,1,11,0,8,0,5,1,4,2,3,4]],6:[20,[16,18,15,20,12,21,10,21,7,20,5,17,4,12,4,7,5,3,7,1,10,0,11,0,14,1,16,3,17,6,17,7,16,10,14,12,11,13,10,13,7,12,5,10,4,7]],7:[20,[17,21,7,0,-1,-1,3,21,17,21]],8:[20,[8,21,5,20,4,18,4,16,5,14,7,13,11,12,14,11,16,9,17,7,17,4,16,2,15,1,12,0,8,0,5,1,4,2,3,4,3,7,4,9,6,11,9,12,13,13,15,14,16,16,16,18,15,20,12,21,8,21]],9:[20,[16,14,15,11,13,9,10,8,9,8,6,9,4,11,3,14,3,15,4,18,6,20,9,21,10,21,13,20,15,18,16,14,16,9,15,4,13,1,10,0,8,0,5,1,4,3]],\":\":[10,[5,14,4,13,5,12,6,13,5,14,-1,-1,5,2,4,1,5,0,6,1,5,2]],\";\":[10,[5,14,4,13,5,12,6,13,5,14,-1,-1,6,1,5,0,4,1,5,2,6,1,6,-1,5,-3,4,-4]],\"<\":[24,[20,18,4,9,20,0]],\"=\":[26,[4,12,22,12,-1,-1,4,6,22,6]],\">\":[24,[4,18,20,9,4,0]],\"?\":[18,[3,16,3,17,4,19,5,20,7,21,11,21,13,20,14,19,15,17,15,15,14,13,13,12,9,10,9,7,-1,-1,9,2,8,1,9,0,10,1,9,2]],\"@\":[27,[18,13,17,15,15,16,12,16,10,15,9,14,8,11,8,8,9,6,11,5,14,5,16,6,17,8,-1,-1,12,16,10,14,9,11,9,8,10,6,11,5,-1,-1,18,16,17,8,17,6,19,5,21,5,23,7,24,10,24,12,23,15,22,17,20,19,18,20,15,21,12,21,9,20,7,19,5,17,4,15,3,12,3,9,4,6,5,4,7,2,9,1,12,0,15,0,18,1,20,2,21,3,-1,-1,19,16,18,8,18,6,19,5]],A:[18,[9,21,1,0,-1,-1,9,21,17,0,-1,-1,4,7,14,7]],B:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,15,17,13,16,12,13,11,-1,-1,4,11,13,11,16,10,17,9,18,7,18,4,17,2,16,1,13,0,4,0]],C:[21,[18,16,17,18,15,20,13,21,9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5]],D:[21,[4,21,4,0,-1,-1,4,21,11,21,14,20,16,18,17,16,18,13,18,8,17,5,16,3,14,1,11,0,4,0]],E:[19,[4,21,4,0,-1,-1,4,21,17,21,-1,-1,4,11,12,11,-1,-1,4,0,17,0]],F:[18,[4,21,4,0,-1,-1,4,21,17,21,-1,-1,4,11,12,11]],G:[21,[18,16,17,18,15,20,13,21,9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,18,8,-1,-1,13,8,18,8]],H:[22,[4,21,4,0,-1,-1,18,21,18,0,-1,-1,4,11,18,11]],I:[8,[4,21,4,0]],J:[16,[12,21,12,5,11,2,10,1,8,0,6,0,4,1,3,2,2,5,2,7]],K:[21,[4,21,4,0,-1,-1,18,21,4,7,-1,-1,9,12,18,0]],L:[17,[4,21,4,0,-1,-1,4,0,16,0]],M:[24,[4,21,4,0,-1,-1,4,21,12,0,-1,-1,20,21,12,0,-1,-1,20,21,20,0]],N:[22,[4,21,4,0,-1,-1,4,21,18,0,-1,-1,18,21,18,0]],O:[22,[9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,19,8,19,13,18,16,17,18,15,20,13,21,9,21]],P:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,14,17,12,16,11,13,10,4,10]],Q:[22,[9,21,7,20,5,18,4,16,3,13,3,8,4,5,5,3,7,1,9,0,13,0,15,1,17,3,18,5,19,8,19,13,18,16,17,18,15,20,13,21,9,21,-1,-1,12,4,18,-2]],R:[21,[4,21,4,0,-1,-1,4,21,13,21,16,20,17,19,18,17,18,15,17,13,16,12,13,11,4,11,-1,-1,11,11,18,0]],S:[20,[17,18,15,20,12,21,8,21,5,20,3,18,3,16,4,14,5,13,7,12,13,10,15,9,16,8,17,6,17,3,15,1,12,0,8,0,5,1,3,3]],T:[16,[8,21,8,0,-1,-1,1,21,15,21]],U:[22,[4,21,4,6,5,3,7,1,10,0,12,0,15,1,17,3,18,6,18,21]],V:[18,[1,21,9,0,-1,-1,17,21,9,0]],W:[24,[2,21,7,0,-1,-1,12,21,7,0,-1,-1,12,21,17,0,-1,-1,22,21,17,0]],X:[20,[3,21,17,0,-1,-1,17,21,3,0]],Y:[18,[1,21,9,11,9,0,-1,-1,17,21,9,11]],Z:[20,[17,21,3,0,-1,-1,3,21,17,21,-1,-1,3,0,17,0]],\"[\":[14,[4,25,4,-7,-1,-1,5,25,5,-7,-1,-1,4,25,11,25,-1,-1,4,-7,11,-7]],\"\\\\\":[14,[0,21,14,-3]],\"]\":[14,[9,25,9,-7,-1,-1,10,25,10,-7,-1,-1,3,25,10,25,-1,-1,3,-7,10,-7]],\"^\":[16,[6,15,8,18,10,15,-1,-1,3,12,8,17,13,12,-1,-1,8,17,8,0]],_:[16,[0,-2,16,-2]],\"`\":[10,[6,21,5,20,4,18,4,16,5,15,6,16,5,17]],a:[19,[15,14,15,0,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],b:[19,[4,21,4,0,-1,-1,4,11,6,13,8,14,11,14,13,13,15,11,16,8,16,6,15,3,13,1,11,0,8,0,6,1,4,3]],c:[18,[15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],d:[19,[15,21,15,0,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],e:[18,[3,8,15,8,15,10,14,12,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],f:[12,[10,21,8,21,6,20,5,17,5,0,-1,-1,2,14,9,14]],g:[19,[15,14,15,-2,14,-5,13,-6,11,-7,8,-7,6,-6,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],h:[19,[4,21,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0]],i:[8,[3,21,4,20,5,21,4,22,3,21,-1,-1,4,14,4,0]],j:[10,[5,21,6,20,7,21,6,22,5,21,-1,-1,6,14,6,-3,5,-6,3,-7,1,-7]],k:[17,[4,21,4,0,-1,-1,14,14,4,4,-1,-1,8,8,15,0]],l:[8,[4,21,4,0]],m:[30,[4,14,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0,-1,-1,15,10,18,13,20,14,23,14,25,13,26,10,26,0]],n:[19,[4,14,4,0,-1,-1,4,10,7,13,9,14,12,14,14,13,15,10,15,0]],o:[19,[8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3,16,6,16,8,15,11,13,13,11,14,8,14]],p:[19,[4,14,4,-7,-1,-1,4,11,6,13,8,14,11,14,13,13,15,11,16,8,16,6,15,3,13,1,11,0,8,0,6,1,4,3]],q:[19,[15,14,15,-7,-1,-1,15,11,13,13,11,14,8,14,6,13,4,11,3,8,3,6,4,3,6,1,8,0,11,0,13,1,15,3]],r:[13,[4,14,4,0,-1,-1,4,8,5,11,7,13,9,14,12,14]],s:[17,[14,11,13,13,10,14,7,14,4,13,3,11,4,9,6,8,11,7,13,6,14,4,14,3,13,1,10,0,7,0,4,1,3,3]],t:[12,[5,21,5,4,6,1,8,0,10,0,-1,-1,2,14,9,14]],u:[19,[4,14,4,4,5,1,7,0,10,0,12,1,15,4,-1,-1,15,14,15,0]],v:[16,[2,14,8,0,-1,-1,14,14,8,0]],w:[22,[3,14,7,0,-1,-1,11,14,7,0,-1,-1,11,14,15,0,-1,-1,19,14,15,0]],x:[17,[3,14,14,0,-1,-1,14,14,3,0]],y:[16,[2,14,8,0,-1,-1,14,14,8,0,6,-4,4,-6,2,-7,1,-7]],z:[17,[14,14,3,0,-1,-1,3,14,14,14,-1,-1,3,0,14,0]],\"{\":[14,[9,25,7,24,6,23,5,21,5,19,6,17,7,16,8,14,8,12,6,10,-1,-1,7,24,6,22,6,20,7,18,8,17,9,15,9,13,8,11,4,9,8,7,9,5,9,3,8,1,7,0,6,-2,6,-4,7,-6,-1,-1,6,8,8,6,8,4,7,2,6,1,5,-1,5,-3,6,-5,7,-6,9,-7]],\"|\":[8,[4,25,4,-7]],\"}\":[14,[5,25,7,24,8,23,9,21,9,19,8,17,7,16,6,14,6,12,8,10,-1,-1,7,24,8,22,8,20,7,18,6,17,5,15,5,13,6,11,10,9,6,7,5,5,5,3,6,1,7,0,8,-2,8,-4,7,-6,-1,-1,8,8,6,6,6,4,7,2,8,1,9,-1,9,-3,8,-5,7,-6,5,-7]],\"~\":[24,[3,6,3,8,4,11,6,12,8,12,10,11,14,8,16,7,18,7,20,8,21,10,-1,-1,3,8,4,10,6,11,8,11,10,10,14,7,16,6,18,6,20,7,21,10,21,12]]},en={symbol:function(t,e,r,n,i){if(\"translucent\"===t.renderPass){var a=At.disabled,o=t.colorModeForRenderPass();0!==r.paint.get(\"icon-opacity\").constantOr(1)&&Yr(t,e,r,n,!1,r.paint.get(\"icon-translate\"),r.paint.get(\"icon-translate-anchor\"),r.layout.get(\"icon-rotation-alignment\"),r.layout.get(\"icon-pitch-alignment\"),r.layout.get(\"icon-keep-upright\"),a,o,i),0!==r.paint.get(\"text-opacity\").constantOr(1)&&Yr(t,e,r,n,!0,r.paint.get(\"text-translate\"),r.paint.get(\"text-translate-anchor\"),r.layout.get(\"text-rotation-alignment\"),r.layout.get(\"text-pitch-alignment\"),r.layout.get(\"text-keep-upright\"),a,o,i),e.map.showCollisionBoxes&&function(t,e,r,n){Vr(t,e,r,n,!1),Vr(t,e,r,n,!0)}(t,e,r,n)}},circle:function(t,e,r,n){if(\"translucent\"===t.renderPass){var i=r.paint.get(\"circle-opacity\"),a=r.paint.get(\"circle-stroke-width\"),o=r.paint.get(\"circle-stroke-opacity\");if(0!==i.constantOr(1)||0!==a.constantOr(1)&&0!==o.constantOr(1))for(var s=t.context,l=s.gl,c=t.depthModeForSublayer(0,Tt.ReadOnly),u=At.disabled,h=t.colorModeForRenderPass(),f=0;f<n.length;f++){var p=n[f],d=e.getTile(p),g=d.getBucket(r);if(g){var v=g.programConfigurations.get(r.id);t.useProgram(\"circle\",v).draw(s,l.TRIANGLES,c,u,h,St.disabled,xr(t,p,d,r),r.id,g.layoutVertexBuffer,g.indexBuffer,g.segments,r.paint,t.transform.zoom,v)}}}},heatmap:function(e,r,n,i){if(0!==n.paint.get(\"heatmap-opacity\"))if(\"offscreen\"===e.renderPass){var a=e.context,o=a.gl,s=e.depthModeForSublayer(0,Tt.ReadOnly),l=At.disabled,c=new Mt([o.ONE,o.ONE],t.Color.transparent,[!0,!0,!0,!0]);!function(t,e,r){var n=t.gl;t.activeTexture.set(n.TEXTURE1),t.viewport.set([0,0,e.width/4,e.height/4]);var i=r.heatmapFbo;if(i)n.bindTexture(n.TEXTURE_2D,i.colorAttachment.get()),t.bindFramebuffer.set(i.framebuffer);else{var a=n.createTexture();n.bindTexture(n.TEXTURE_2D,a),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,n.LINEAR),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,n.LINEAR),i=r.heatmapFbo=t.createFramebuffer(e.width/4,e.height/4),function t(e,r,n,i){var a=e.gl;a.texImage2D(a.TEXTURE_2D,0,a.RGBA,r.width/4,r.height/4,0,a.RGBA,e.extTextureHalfFloat?e.extTextureHalfFloat.HALF_FLOAT_OES:a.UNSIGNED_BYTE,null),i.colorAttachment.set(n),e.extTextureHalfFloat&&a.checkFramebufferStatus(a.FRAMEBUFFER)!==a.FRAMEBUFFER_COMPLETE&&(e.extTextureHalfFloat=null,i.colorAttachment.setDirty(),t(e,r,n,i))}(t,e,a,i)}}(a,e,n),a.clear({color:t.Color.transparent});for(var u=0;u<i.length;u++){var h=i[u];if(!r.hasRenderableParent(h)){var f=r.getTile(h),p=f.getBucket(n);if(p){var d=p.programConfigurations.get(n.id),g=e.useProgram(\"heatmap\",d),v=e.transform.zoom;g.draw(a,o.TRIANGLES,s,l,c,St.disabled,Tr(h.posMatrix,f,v,n.paint.get(\"heatmap-intensity\")),n.id,p.layoutVertexBuffer,p.indexBuffer,p.segments,n.paint,e.transform.zoom,d)}}}a.viewport.set([0,0,e.width,e.height])}else\"translucent\"===e.renderPass&&(e.context.setColorMode(e.colorModeForRenderPass()),function(e,r){var n=e.context,i=n.gl,a=r.heatmapFbo;if(a){n.activeTexture.set(i.TEXTURE0),i.bindTexture(i.TEXTURE_2D,a.colorAttachment.get()),n.activeTexture.set(i.TEXTURE1);var o=r.colorRampTexture;o||(o=r.colorRampTexture=new t.Texture(n,r.colorRamp,i.RGBA)),o.bind(i.LINEAR,i.CLAMP_TO_EDGE),e.useProgram(\"heatmapTexture\").draw(n,i.TRIANGLES,Tt.disabled,At.disabled,e.colorModeForRenderPass(),St.disabled,function(e,r,n,i){var a=t.create();t.ortho(a,0,e.width,e.height,0,0,1);var o=e.context.gl;return{u_matrix:a,u_world:[o.drawingBufferWidth,o.drawingBufferHeight],u_image:n,u_color_ramp:i,u_opacity:r.paint.get(\"heatmap-opacity\")}}(e,r,0,1),r.id,e.viewportBuffer,e.quadTriangleIndexBuffer,e.viewportSegments,r.paint,e.transform.zoom)}}(e,n))},line:function(e,r,n,i){if(\"translucent\"===e.renderPass){var a=n.paint.get(\"line-opacity\"),o=n.paint.get(\"line-width\");if(0!==a.constantOr(1)&&0!==o.constantOr(1)){var s=e.depthModeForSublayer(0,Tt.ReadOnly),l=e.colorModeForRenderPass(),c=n.paint.get(\"line-dasharray\"),u=n.paint.get(\"line-pattern\"),h=u.constantOr(1),f=n.paint.get(\"line-gradient\"),p=n.getCrossfadeParameters(),d=c?\"lineSDF\":h?\"linePattern\":f?\"lineGradient\":\"line\",g=e.context,v=g.gl,m=!0;if(f){g.activeTexture.set(v.TEXTURE0);var y=n.gradientTexture;if(!n.gradient)return;y||(y=n.gradientTexture=new t.Texture(g,n.gradient,v.RGBA)),y.bind(v.LINEAR,v.CLAMP_TO_EDGE)}for(var x=0,b=i;x<b.length;x+=1){var _=b[x],w=r.getTile(_);if(!h||w.patternsLoaded()){var k=w.getBucket(n);if(k){var T=k.programConfigurations.get(n.id),A=e.context.program.get(),M=e.useProgram(d,T),S=m||M.program!==A,E=u.constantOr(null);if(E&&w.imageAtlas){var C=w.imageAtlas.patternPositions[E.to],L=w.imageAtlas.patternPositions[E.from];C&&L&&T.setConstantPatternPositions(C,L)}var P=c?Pr(e,w,n,c,p):h?Lr(e,w,n,p):f?Cr(e,w,n):Er(e,w,n);c&&(S||e.lineAtlas.dirty)?(g.activeTexture.set(v.TEXTURE0),e.lineAtlas.bind(g)):h&&(g.activeTexture.set(v.TEXTURE0),w.imageAtlasTexture.bind(v.LINEAR,v.CLAMP_TO_EDGE),T.updatePatternPaintBuffers(p)),M.draw(g,v.TRIANGLES,s,e.stencilModeForClipping(_),l,St.disabled,P,n.id,k.layoutVertexBuffer,k.indexBuffer,k.segments,n.paint,e.transform.zoom,T),m=!1}}}}}},fill:function(e,r,n,i){var a=n.paint.get(\"fill-color\"),o=n.paint.get(\"fill-opacity\");if(0!==o.constantOr(1)){var s=e.colorModeForRenderPass(),l=n.paint.get(\"fill-pattern\"),c=e.opaquePassEnabledForLayer()&&!l.constantOr(1)&&1===a.constantOr(t.Color.transparent).a&&1===o.constantOr(0)?\"opaque\":\"translucent\";if(e.renderPass===c){var u=e.depthModeForSublayer(1,\"opaque\"===e.renderPass?Tt.ReadWrite:Tt.ReadOnly);Xr(e,r,n,i,u,s,!1)}if(\"translucent\"===e.renderPass&&n.paint.get(\"fill-antialias\")){var h=e.depthModeForSublayer(n.getPaintProperty(\"fill-outline-color\")?2:0,Tt.ReadOnly);Xr(e,r,n,i,h,s,!0)}}},\"fill-extrusion\":function(t,e,r,n){var i=r.paint.get(\"fill-extrusion-opacity\");if(0!==i&&\"translucent\"===t.renderPass){var a=new Tt(t.context.gl.LEQUAL,Tt.ReadWrite,t.depthRangeFor3D);if(1!==i||r.paint.get(\"fill-extrusion-pattern\").constantOr(1))Zr(t,e,r,n,a,At.disabled,Mt.disabled),Zr(t,e,r,n,a,t.stencilModeFor3D(),t.colorModeForRenderPass());else{var o=t.colorModeForRenderPass();Zr(t,e,r,n,a,At.disabled,o)}}},hillshade:function(t,e,r,n){if(\"offscreen\"===t.renderPass||\"translucent\"===t.renderPass){for(var i=t.context,a=e.getSource().maxzoom,o=t.depthModeForSublayer(0,Tt.ReadOnly),s=At.disabled,l=t.colorModeForRenderPass(),c=0,u=n;c<u.length;c+=1){var h=u[c],f=e.getTile(h);f.needsHillshadePrepare&&\"offscreen\"===t.renderPass?Kr(t,f,r,a,o,s,l):\"translucent\"===t.renderPass&&Jr(t,f,r,o,s,l)}i.viewport.set([0,0,t.width,t.height])}},raster:function(t,e,r,n){if(\"translucent\"===t.renderPass&&0!==r.paint.get(\"raster-opacity\"))for(var i=t.context,a=i.gl,o=e.getSource(),s=t.useProgram(\"raster\"),l=At.disabled,c=t.colorModeForRenderPass(),u=n.length&&n[0].overscaledZ,h=!t.options.moving,f=0,p=n;f<p.length;f+=1){var d=p[f],g=t.depthModeForSublayer(d.overscaledZ-u,1===r.paint.get(\"raster-opacity\")?Tt.ReadWrite:Tt.ReadOnly,a.LESS),v=e.getTile(d),m=t.transform.calculatePosMatrix(d.toUnwrapped(),h);v.registerFadeDuration(r.paint.get(\"raster-fade-duration\"));var y=e.findLoadedParent(d,0),x=$r(v,y,e,r,t.transform),b=void 0,_=void 0,w=\"nearest\"===r.paint.get(\"raster-resampling\")?a.NEAREST:a.LINEAR;i.activeTexture.set(a.TEXTURE0),v.texture.bind(w,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),i.activeTexture.set(a.TEXTURE1),y?(y.texture.bind(w,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),b=Math.pow(2,y.tileID.overscaledZ-v.tileID.overscaledZ),_=[v.tileID.canonical.x*b%1,v.tileID.canonical.y*b%1]):v.texture.bind(w,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST);var k=Ir(m,_||[0,0],b||1,x,r);o instanceof L?s.draw(i,a.TRIANGLES,g,l,c,St.disabled,k,r.id,o.boundsBuffer,t.quadTriangleIndexBuffer,o.boundsSegments):v.maskedBoundsBuffer&&v.maskedIndexBuffer&&v.segments?s.draw(i,a.TRIANGLES,g,l,c,St.disabled,k,r.id,v.maskedBoundsBuffer,v.maskedIndexBuffer,v.segments,r.paint,t.transform.zoom):s.draw(i,a.TRIANGLES,g,l,c,St.disabled,k,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}},background:function(t,e,r){var n=r.paint.get(\"background-color\"),i=r.paint.get(\"background-opacity\");if(0!==i){var a=t.context,o=a.gl,s=t.transform,l=s.tileSize,c=r.paint.get(\"background-pattern\");if(!t.isPatternMissing(c)){var u=c||1!==n.a||1!==i?\"translucent\":\"opaque\";if(t.renderPass===u){var h=At.disabled,f=t.depthModeForSublayer(0,\"opaque\"===u?Tt.ReadWrite:Tt.ReadOnly),p=t.colorModeForRenderPass(),d=t.useProgram(c?\"backgroundPattern\":\"background\"),g=s.coveringTiles({tileSize:l});c&&(a.activeTexture.set(o.TEXTURE0),t.imageManager.bind(t.context));for(var v=r.getCrossfadeParameters(),m=0,y=g;m<y.length;m+=1){var x=y[m],b=t.transform.calculatePosMatrix(x.toUnwrapped()),_=c?Br(b,i,t,c,{tileID:x,tileSize:l},v):Fr(b,i,n);d.draw(a,o.TRIANGLES,f,h,p,St.disabled,_,r.id,t.tileExtentBuffer,t.quadTriangleIndexBuffer,t.tileExtentSegments)}}}}},debug:function(t,e,r){for(var n=0;n<r.length;n++)Qr(t,e,r[n])},custom:function(t,e,r){var n=t.context,i=r.implementation;if(\"offscreen\"===t.renderPass){var a=i.prerender;a&&(t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),a.call(i,n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState())}else if(\"translucent\"===t.renderPass){t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),n.setStencilMode(At.disabled);var o=\"3d\"===i.renderingMode?new Tt(t.context.gl.LEQUAL,Tt.ReadWrite,t.depthRangeFor3D):t.depthModeForSublayer(0,Tt.ReadOnly);n.setDepthMode(o),i.render(n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState(),n.bindFramebuffer.set(null)}}},rn=function(e,r){this.context=new Et(e),this.transform=r,this._tileTextures={},this.setup(),this.numSublayers=Ct.maxUnderzooming+Ct.maxOverzooming+1,this.depthEpsilon=1/Math.pow(2,16),this.depthRboNeedsClear=!0,this.emptyProgramConfiguration=new t.ProgramConfiguration,this.crossTileSymbolIndex=new Pe};function nn(t,e){if(t.y>e.y){var r=t;t=e,e=r}return{x0:t.x,y0:t.y,x1:e.x,y1:e.y,dx:e.x-t.x,dy:e.y-t.y}}function an(t,e,r,n,i){var a=Math.max(r,Math.floor(e.y0)),o=Math.min(n,Math.ceil(e.y1));if(t.x0===e.x0&&t.y0===e.y0?t.x0+e.dy/t.dy*t.dx<e.x1:t.x1-e.dy/t.dy*t.dx<e.x0){var s=t;t=e,e=s}for(var l=t.dx/t.dy,c=e.dx/e.dy,u=t.dx>0,h=e.dx<0,f=a;f<o;f++){var p=l*Math.max(0,Math.min(t.dy,f+u-t.y0))+t.x0,d=c*Math.max(0,Math.min(e.dy,f+h-e.y0))+e.x0;i(Math.floor(d),Math.ceil(p),f)}}function on(t,e,r,n,i,a){var o,s=nn(t,e),l=nn(e,r),c=nn(r,t);s.dy>l.dy&&(o=s,s=l,l=o),s.dy>c.dy&&(o=s,s=c,c=o),l.dy>c.dy&&(o=l,l=c,c=o),s.dy&&an(c,s,n,i,a),l.dy&&an(c,l,n,i,a)}rn.prototype.resize=function(e,r){var n=this.context.gl;if(this.width=e*t.browser.devicePixelRatio,this.height=r*t.browser.devicePixelRatio,this.context.viewport.set([0,0,this.width,this.height]),this.style)for(var i=0,a=this.style._order;i<a.length;i+=1){var o=a[i];this.style._layers[o].resize()}this.depthRbo&&(n.deleteRenderbuffer(this.depthRbo),this.depthRbo=null)},rn.prototype.setup=function(){var e=this.context,r=new t.StructArrayLayout2i4;r.emplaceBack(0,0),r.emplaceBack(t.EXTENT,0),r.emplaceBack(0,t.EXTENT),r.emplaceBack(t.EXTENT,t.EXTENT),this.tileExtentBuffer=e.createVertexBuffer(r,Re.members),this.tileExtentSegments=t.SegmentVector.simpleSegment(0,0,4,2);var n=new t.StructArrayLayout2i4;n.emplaceBack(0,0),n.emplaceBack(t.EXTENT,0),n.emplaceBack(0,t.EXTENT),n.emplaceBack(t.EXTENT,t.EXTENT),this.debugBuffer=e.createVertexBuffer(n,Re.members),this.debugSegments=t.SegmentVector.simpleSegment(0,0,4,5);var i=new t.StructArrayLayout4i8;i.emplaceBack(0,0,0,0),i.emplaceBack(t.EXTENT,0,t.EXTENT,0),i.emplaceBack(0,t.EXTENT,0,t.EXTENT),i.emplaceBack(t.EXTENT,t.EXTENT,t.EXTENT,t.EXTENT),this.rasterBoundsBuffer=e.createVertexBuffer(i,t.rasterBoundsAttributes.members),this.rasterBoundsSegments=t.SegmentVector.simpleSegment(0,0,4,2);var a=new t.StructArrayLayout2i4;a.emplaceBack(0,0),a.emplaceBack(1,0),a.emplaceBack(0,1),a.emplaceBack(1,1),this.viewportBuffer=e.createVertexBuffer(a,Re.members),this.viewportSegments=t.SegmentVector.simpleSegment(0,0,4,2);var o=new t.StructArrayLayout1ui2;o.emplaceBack(0),o.emplaceBack(1),o.emplaceBack(3),o.emplaceBack(2),o.emplaceBack(0),this.tileBorderIndexBuffer=e.createIndexBuffer(o);var s=new t.StructArrayLayout3ui6;s.emplaceBack(0,1,2),s.emplaceBack(2,1,3),this.quadTriangleIndexBuffer=e.createIndexBuffer(s);var l=this.context.gl;this.stencilClearMode=new At({func:l.ALWAYS,mask:0},0,255,l.ZERO,l.ZERO,l.ZERO)},rn.prototype.clearStencil=function(){var e=this.context,r=e.gl;this.nextStencilID=1,this.currentStencilSource=void 0;var n=t.create();t.ortho(n,0,this.width,this.height,0,0,1),t.scale(n,n,[r.drawingBufferWidth,r.drawingBufferHeight,0]),this.useProgram(\"clippingMask\").draw(e,r.TRIANGLES,Tt.disabled,this.stencilClearMode,Mt.disabled,St.disabled,kr(n),\"$clipping\",this.viewportBuffer,this.quadTriangleIndexBuffer,this.viewportSegments)},rn.prototype._renderTileClippingMasks=function(t,e){if(this.currentStencilSource!==t.source&&t.isTileClipped()&&e&&e.length){this.currentStencilSource=t.source;var r=this.context,n=r.gl;this.nextStencilID+e.length>256&&this.clearStencil(),r.setColorMode(Mt.disabled),r.setDepthMode(Tt.disabled);var i=this.useProgram(\"clippingMask\");this._tileClippingMaskIDs={};for(var a=0,o=e;a<o.length;a+=1){var s=o[a],l=this._tileClippingMaskIDs[s.key]=this.nextStencilID++;i.draw(r,n.TRIANGLES,Tt.disabled,new At({func:n.ALWAYS,mask:0},l,255,n.KEEP,n.KEEP,n.REPLACE),Mt.disabled,St.disabled,kr(s.posMatrix),\"$clipping\",this.tileExtentBuffer,this.quadTriangleIndexBuffer,this.tileExtentSegments)}}},rn.prototype.stencilModeFor3D=function(){this.nextStencilID+1>256&&this.clearStencil();var t=this.nextStencilID++,e=this.context.gl;return new At({func:e.NOTEQUAL,mask:255},t,255,e.KEEP,e.KEEP,e.REPLACE)},rn.prototype.stencilModeForClipping=function(t){var e=this.context.gl;return new At({func:e.EQUAL,mask:255},this._tileClippingMaskIDs[t.key],0,e.KEEP,e.KEEP,e.REPLACE)},rn.prototype.colorModeForRenderPass=function(){var e=this.context.gl;return this._showOverdrawInspector?new Mt([e.CONSTANT_COLOR,e.ONE],new t.Color(1/8,1/8,1/8,0),[!0,!0,!0,!0]):\"opaque\"===this.renderPass?Mt.unblended:Mt.alphaBlended},rn.prototype.depthModeForSublayer=function(t,e,r){if(!this.opaquePassEnabledForLayer())return Tt.disabled;var n=1-((1+this.currentLayer)*this.numSublayers+t)*this.depthEpsilon;return new Tt(r||this.context.gl.LEQUAL,e,[n,n])},rn.prototype.opaquePassEnabledForLayer=function(){return this.currentLayer<this.opaquePassCutoff},rn.prototype.render=function(e,r){this.style=e,this.options=r,this.lineAtlas=e.lineAtlas,this.imageManager=e.imageManager,this.glyphManager=e.glyphManager,this.symbolFadeChange=e.placement.symbolFadeChange(t.browser.now()),this.imageManager.beginFrame();var n=this.style._order,i=this.style.sourceCaches;for(var a in i){var o=i[a];o.used&&o.prepare(this.context)}var s={},l={},c={};for(var u in i){var h=i[u];s[u]=h.getVisibleCoordinates(),l[u]=s[u].slice().reverse(),c[u]=h.getVisibleCoordinates(!0).reverse()}for(var f in i){var p=i[f],d=p.getSource();if(\"raster\"===d.type||\"raster-dem\"===d.type){for(var g=[],v=0,m=s[f];v<m.length;v+=1){var y=m[v];g.push(p.getTile(y))}jr(g,this.context)}}this.opaquePassCutoff=1/0;for(var x=0;x<n.length;x++){var b=n[x];if(this.style._layers[b].is3D()){this.opaquePassCutoff=x;break}}this.renderPass=\"offscreen\",this.depthRboNeedsClear=!0;for(var _=0,w=n;_<w.length;_+=1){var k=w[_],T=this.style._layers[k];if(T.hasOffscreenPass()&&!T.isHidden(this.transform.zoom)){var A=l[T.source];(\"custom\"===T.type||A.length)&&this.renderLayer(this,i[T.source],T,A)}}for(this.context.bindFramebuffer.set(null),this.context.clear({color:r.showOverdrawInspector?t.Color.black:t.Color.transparent,depth:1}),this.clearStencil(),this._showOverdrawInspector=r.showOverdrawInspector,this.depthRangeFor3D=[0,1-(e._order.length+2)*this.numSublayers*this.depthEpsilon],this.renderPass=\"opaque\",this.currentLayer=n.length-1;this.currentLayer>=0;this.currentLayer--){var M=this.style._layers[n[this.currentLayer]],S=i[M.source],E=s[M.source];this._renderTileClippingMasks(M,E),this.renderLayer(this,S,M,E)}for(this.renderPass=\"translucent\",this.currentLayer=0;this.currentLayer<n.length;this.currentLayer++){var C=this.style._layers[n[this.currentLayer]],L=i[C.source],P=(\"symbol\"===C.type?c:l)[C.source];this._renderTileClippingMasks(C,s[C.source]),this.renderLayer(this,L,C,P)}if(this.options.showTileBoundaries)for(var O in i){en.debug(this,i[O],s[O]);break}this.context.setDefault()},rn.prototype.setupOffscreenDepthRenderbuffer=function(){var t=this.context;this.depthRbo||(this.depthRbo=t.createRenderbuffer(t.gl.DEPTH_COMPONENT16,this.width,this.height))},rn.prototype.renderLayer=function(t,e,r,n){r.isHidden(this.transform.zoom)||(\"background\"===r.type||\"custom\"===r.type||n.length)&&(this.id=r.id,en[r.type](t,e,r,n,this.style.placement.variableOffsets))},rn.prototype.translatePosMatrix=function(e,r,n,i,a){if(!n[0]&&!n[1])return e;var o=a?\"map\"===i?this.transform.angle:0:\"viewport\"===i?-this.transform.angle:0;if(o){var s=Math.sin(o),l=Math.cos(o);n=[n[0]*l-n[1]*s,n[0]*s+n[1]*l]}var c=[a?n[0]:le(r,n[0],this.transform.zoom),a?n[1]:le(r,n[1],this.transform.zoom),0],u=new Float32Array(16);return t.translate(u,e,c),u},rn.prototype.saveTileTexture=function(t){var e=this._tileTextures[t.size[0]];e?e.push(t):this._tileTextures[t.size[0]]=[t]},rn.prototype.getTileTexture=function(t){var e=this._tileTextures[t];return e&&e.length>0?e.pop():null},rn.prototype.isPatternMissing=function(t){if(!t)return!1;var e=this.imageManager.getPattern(t.from),r=this.imageManager.getPattern(t.to);return!e||!r},rn.prototype.useProgram=function(t,e){void 0===e&&(e=this.emptyProgramConfiguration),this.cache=this.cache||{};var r=\"\"+t+(e.cacheKey||\"\")+(this._showOverdrawInspector?\"/overdraw\":\"\");return this.cache[r]||(this.cache[r]=new hr(this.context,cr[t],e,Nr[t],this._showOverdrawInspector)),this.cache[r]},rn.prototype.setCustomLayerDefaults=function(){this.context.unbindVAO(),this.context.cullFace.setDefault(),this.context.activeTexture.setDefault(),this.context.pixelStoreUnpack.setDefault(),this.context.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.context.pixelStoreUnpackFlipY.setDefault()},rn.prototype.setBaseState=function(){var t=this.context.gl;this.context.cullFace.set(!1),this.context.viewport.set([0,0,this.width,this.height]),this.context.blendEquation.set(t.FUNC_ADD)};var sn=function(e,r,n){this.tileSize=512,this.maxValidLatitude=85.051129,this._renderWorldCopies=void 0===n||n,this._minZoom=e||0,this._maxZoom=r||22,this.setMaxBounds(),this.width=0,this.height=0,this._center=new t.LngLat(0,0),this.zoom=0,this.angle=0,this._fov=.6435011087932844,this._pitch=0,this._unmodified=!0,this._posMatrixCache={},this._alignedPosMatrixCache={}},ln={minZoom:{configurable:!0},maxZoom:{configurable:!0},renderWorldCopies:{configurable:!0},worldSize:{configurable:!0},centerPoint:{configurable:!0},size:{configurable:!0},bearing:{configurable:!0},pitch:{configurable:!0},fov:{configurable:!0},zoom:{configurable:!0},center:{configurable:!0},unmodified:{configurable:!0},point:{configurable:!0}};sn.prototype.clone=function(){var t=new sn(this._minZoom,this._maxZoom,this._renderWorldCopies);return t.tileSize=this.tileSize,t.latRange=this.latRange,t.width=this.width,t.height=this.height,t._center=this._center,t.zoom=this.zoom,t.angle=this.angle,t._fov=this._fov,t._pitch=this._pitch,t._unmodified=this._unmodified,t._calcMatrices(),t},ln.minZoom.get=function(){return this._minZoom},ln.minZoom.set=function(t){this._minZoom!==t&&(this._minZoom=t,this.zoom=Math.max(this.zoom,t))},ln.maxZoom.get=function(){return this._maxZoom},ln.maxZoom.set=function(t){this._maxZoom!==t&&(this._maxZoom=t,this.zoom=Math.min(this.zoom,t))},ln.renderWorldCopies.get=function(){return this._renderWorldCopies},ln.renderWorldCopies.set=function(t){void 0===t?t=!0:null===t&&(t=!1),this._renderWorldCopies=t},ln.worldSize.get=function(){return this.tileSize*this.scale},ln.centerPoint.get=function(){return this.size._div(2)},ln.size.get=function(){return new t.Point(this.width,this.height)},ln.bearing.get=function(){return-this.angle/Math.PI*180},ln.bearing.set=function(e){var r=-t.wrap(e,-180,180)*Math.PI/180;this.angle!==r&&(this._unmodified=!1,this.angle=r,this._calcMatrices(),this.rotationMatrix=t.create$2(),t.rotate(this.rotationMatrix,this.rotationMatrix,this.angle))},ln.pitch.get=function(){return this._pitch/Math.PI*180},ln.pitch.set=function(e){var r=t.clamp(e,0,60)/180*Math.PI;this._pitch!==r&&(this._unmodified=!1,this._pitch=r,this._calcMatrices())},ln.fov.get=function(){return this._fov/Math.PI*180},ln.fov.set=function(t){t=Math.max(.01,Math.min(60,t)),this._fov!==t&&(this._unmodified=!1,this._fov=t/180*Math.PI,this._calcMatrices())},ln.zoom.get=function(){return this._zoom},ln.zoom.set=function(t){var e=Math.min(Math.max(t,this.minZoom),this.maxZoom);this._zoom!==e&&(this._unmodified=!1,this._zoom=e,this.scale=this.zoomScale(e),this.tileZoom=Math.floor(e),this.zoomFraction=e-this.tileZoom,this._constrain(),this._calcMatrices())},ln.center.get=function(){return this._center},ln.center.set=function(t){t.lat===this._center.lat&&t.lng===this._center.lng||(this._unmodified=!1,this._center=t,this._constrain(),this._calcMatrices())},sn.prototype.coveringZoomLevel=function(t){return(t.roundZoom?Math.round:Math.floor)(this.zoom+this.scaleZoom(this.tileSize/t.tileSize))},sn.prototype.getVisibleUnwrappedCoordinates=function(e){var r=[new t.UnwrappedTileID(0,e)];if(this._renderWorldCopies)for(var n=this.pointCoordinate(new t.Point(0,0)),i=this.pointCoordinate(new t.Point(this.width,0)),a=this.pointCoordinate(new t.Point(this.width,this.height)),o=this.pointCoordinate(new t.Point(0,this.height)),s=Math.floor(Math.min(n.x,i.x,a.x,o.x)),l=Math.floor(Math.max(n.x,i.x,a.x,o.x)),c=s-1;c<=l+1;c++)0!==c&&r.push(new t.UnwrappedTileID(c,e));return r},sn.prototype.coveringTiles=function(e){var r=this.coveringZoomLevel(e),n=r;if(void 0!==e.minzoom&&r<e.minzoom)return[];void 0!==e.maxzoom&&r>e.maxzoom&&(r=e.maxzoom);var i=t.MercatorCoordinate.fromLngLat(this.center),a=Math.pow(2,r),o=new t.Point(a*i.x-.5,a*i.y-.5);return function(e,r,n,i){void 0===i&&(i=!0);var a=1<<e,o={};function s(r,s,l){var c,u,h,f;if(l>=0&&l<=a)for(c=r;c<s;c++)u=Math.floor(c/a),h=(c%a+a)%a,0!==u&&!0!==i||(f=new t.OverscaledTileID(n,u,e,h,l),o[f.key]=f)}var l=r.map(function(e){return new t.Point(e.x,e.y)._mult(a)});return on(l[0],l[1],l[2],0,a,s),on(l[2],l[3],l[0],0,a,s),Object.keys(o).map(function(t){return o[t]})}(r,[this.pointCoordinate(new t.Point(0,0)),this.pointCoordinate(new t.Point(this.width,0)),this.pointCoordinate(new t.Point(this.width,this.height)),this.pointCoordinate(new t.Point(0,this.height))],e.reparseOverscaled?n:r,this._renderWorldCopies).sort(function(t,e){return o.dist(t.canonical)-o.dist(e.canonical)})},sn.prototype.resize=function(t,e){this.width=t,this.height=e,this.pixelsToGLUnits=[2/t,-2/e],this._constrain(),this._calcMatrices()},ln.unmodified.get=function(){return this._unmodified},sn.prototype.zoomScale=function(t){return Math.pow(2,t)},sn.prototype.scaleZoom=function(t){return Math.log(t)/Math.LN2},sn.prototype.project=function(e){var r=t.clamp(e.lat,-this.maxValidLatitude,this.maxValidLatitude);return new t.Point(t.mercatorXfromLng(e.lng)*this.worldSize,t.mercatorYfromLat(r)*this.worldSize)},sn.prototype.unproject=function(e){return new t.MercatorCoordinate(e.x/this.worldSize,e.y/this.worldSize).toLngLat()},ln.point.get=function(){return this.project(this.center)},sn.prototype.setLocationAtPoint=function(e,r){var n=this.pointCoordinate(r),i=this.pointCoordinate(this.centerPoint),a=this.locationCoordinate(e),o=new t.MercatorCoordinate(a.x-(n.x-i.x),a.y-(n.y-i.y));this.center=this.coordinateLocation(o),this._renderWorldCopies&&(this.center=this.center.wrap())},sn.prototype.locationPoint=function(t){return this.coordinatePoint(this.locationCoordinate(t))},sn.prototype.pointLocation=function(t){return this.coordinateLocation(this.pointCoordinate(t))},sn.prototype.locationCoordinate=function(e){return t.MercatorCoordinate.fromLngLat(e)},sn.prototype.coordinateLocation=function(t){return t.toLngLat()},sn.prototype.pointCoordinate=function(e){var r=[e.x,e.y,0,1],n=[e.x,e.y,1,1];t.transformMat4(r,r,this.pixelMatrixInverse),t.transformMat4(n,n,this.pixelMatrixInverse);var i=r[3],a=n[3],o=r[0]/i,s=n[0]/a,l=r[1]/i,c=n[1]/a,u=r[2]/i,h=n[2]/a,f=u===h?0:(0-u)/(h-u);return new t.MercatorCoordinate(t.number(o,s,f)/this.worldSize,t.number(l,c,f)/this.worldSize)},sn.prototype.coordinatePoint=function(e){var r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix),new t.Point(r[0]/r[3],r[1]/r[3])},sn.prototype.getBounds=function(){return(new t.LngLatBounds).extend(this.pointLocation(new t.Point(0,0))).extend(this.pointLocation(new t.Point(this.width,0))).extend(this.pointLocation(new t.Point(this.width,this.height))).extend(this.pointLocation(new t.Point(0,this.height)))},sn.prototype.getMaxBounds=function(){return this.latRange&&2===this.latRange.length&&this.lngRange&&2===this.lngRange.length?new t.LngLatBounds([this.lngRange[0],this.latRange[0]],[this.lngRange[1],this.latRange[1]]):null},sn.prototype.setMaxBounds=function(t){t?(this.lngRange=[t.getWest(),t.getEast()],this.latRange=[t.getSouth(),t.getNorth()],this._constrain()):(this.lngRange=null,this.latRange=[-this.maxValidLatitude,this.maxValidLatitude])},sn.prototype.calculatePosMatrix=function(e,r){void 0===r&&(r=!1);var n=e.key,i=r?this._alignedPosMatrixCache:this._posMatrixCache;if(i[n])return i[n];var a=e.canonical,o=this.worldSize/this.zoomScale(a.z),s=a.x+Math.pow(2,a.z)*e.wrap,l=t.identity(new Float64Array(16));return t.translate(l,l,[s*o,a.y*o,0]),t.scale(l,l,[o/t.EXTENT,o/t.EXTENT,1]),t.multiply(l,r?this.alignedProjMatrix:this.projMatrix,l),i[n]=new Float32Array(l),i[n]},sn.prototype.customLayerMatrix=function(){return this.mercatorMatrix.slice()},sn.prototype._constrain=function(){if(this.center&&this.width&&this.height&&!this._constraining){this._constraining=!0;var e,r,n,i,a=-90,o=90,s=-180,l=180,c=this.size,u=this._unmodified;if(this.latRange){var h=this.latRange;a=t.mercatorYfromLat(h[1])*this.worldSize,e=(o=t.mercatorYfromLat(h[0])*this.worldSize)-a<c.y?c.y/(o-a):0}if(this.lngRange){var f=this.lngRange;s=t.mercatorXfromLng(f[0])*this.worldSize,r=(l=t.mercatorXfromLng(f[1])*this.worldSize)-s<c.x?c.x/(l-s):0}var p=this.point,d=Math.max(r||0,e||0);if(d)return this.center=this.unproject(new t.Point(r?(l+s)/2:p.x,e?(o+a)/2:p.y)),this.zoom+=this.scaleZoom(d),this._unmodified=u,void(this._constraining=!1);if(this.latRange){var g=p.y,v=c.y/2;g-v<a&&(i=a+v),g+v>o&&(i=o-v)}if(this.lngRange){var m=p.x,y=c.x/2;m-y<s&&(n=s+y),m+y>l&&(n=l-y)}void 0===n&&void 0===i||(this.center=this.unproject(new t.Point(void 0!==n?n:p.x,void 0!==i?i:p.y))),this._unmodified=u,this._constraining=!1}},sn.prototype._calcMatrices=function(){if(this.height){this.cameraToCenterDistance=.5/Math.tan(this._fov/2)*this.height;var e=this._fov/2,r=Math.PI/2+this._pitch,n=Math.sin(e)*this.cameraToCenterDistance/Math.sin(Math.PI-r-e),i=this.point,a=i.x,o=i.y,s=1.01*(Math.cos(Math.PI/2-this._pitch)*n+this.cameraToCenterDistance),l=new Float64Array(16);t.perspective(l,this._fov,this.width/this.height,1,s),t.scale(l,l,[1,-1,1]),t.translate(l,l,[0,0,-this.cameraToCenterDistance]),t.rotateX(l,l,this._pitch),t.rotateZ(l,l,this.angle),t.translate(l,l,[-a,-o,0]),this.mercatorMatrix=t.scale([],l,[this.worldSize,this.worldSize,this.worldSize]),t.scale(l,l,[1,1,t.mercatorZfromAltitude(1,this.center.lat)*this.worldSize,1]),this.projMatrix=l;var c=this.width%2/2,u=this.height%2/2,h=Math.cos(this.angle),f=Math.sin(this.angle),p=a-Math.round(a)+h*c+f*u,d=o-Math.round(o)+h*u+f*c,g=new Float64Array(l);if(t.translate(g,g,[p>.5?p-1:p,d>.5?d-1:d,0]),this.alignedProjMatrix=g,l=t.create(),t.scale(l,l,[this.width/2,-this.height/2,1]),t.translate(l,l,[1,-1,0]),this.labelPlaneMatrix=l,l=t.create(),t.scale(l,l,[1,-1,1]),t.translate(l,l,[-1,-1,0]),t.scale(l,l,[2/this.width,2/this.height,1]),this.glCoordMatrix=l,this.pixelMatrix=t.multiply(new Float64Array(16),this.labelPlaneMatrix,this.projMatrix),!(l=t.invert(new Float64Array(16),this.pixelMatrix)))throw new Error(\"failed to invert matrix\");this.pixelMatrixInverse=l,this._posMatrixCache={},this._alignedPosMatrixCache={}}},sn.prototype.maxPitchScaleFactor=function(){if(!this.pixelMatrixInverse)return 1;var e=this.pointCoordinate(new t.Point(0,0)),r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix)[3]/this.cameraToCenterDistance},sn.prototype.getCameraPoint=function(){var e=this._pitch,r=Math.tan(e)*(this.cameraToCenterDistance||1);return this.centerPoint.add(new t.Point(0,r))},sn.prototype.getCameraQueryGeometry=function(e){var r=this.getCameraPoint();if(1===e.length)return[e[0],r];for(var n=r.x,i=r.y,a=r.x,o=r.y,s=0,l=e;s<l.length;s+=1){var c=l[s];n=Math.min(n,c.x),i=Math.min(i,c.y),a=Math.max(a,c.x),o=Math.max(o,c.y)}return[new t.Point(n,i),new t.Point(a,i),new t.Point(a,o),new t.Point(n,o),new t.Point(n,i)]},Object.defineProperties(sn.prototype,ln);var cn=function(){var e,r,n,i;t.bindAll([\"_onHashChange\",\"_updateHash\"],this),this._updateHash=(e=this._updateHashUnthrottled.bind(this),300,r=!1,n=null,i=function(){n=null,r&&(e(),n=setTimeout(i,300),r=!1)},function(){return r=!0,n||i(),n})};cn.prototype.addTo=function(e){return this._map=e,t.window.addEventListener(\"hashchange\",this._onHashChange,!1),this._map.on(\"moveend\",this._updateHash),this},cn.prototype.remove=function(){return t.window.removeEventListener(\"hashchange\",this._onHashChange,!1),this._map.off(\"moveend\",this._updateHash),clearTimeout(this._updateHash()),delete this._map,this},cn.prototype.getHashString=function(t){var e=this._map.getCenter(),r=Math.round(100*this._map.getZoom())/100,n=Math.ceil((r*Math.LN2+Math.log(512/360/.5))/Math.LN10),i=Math.pow(10,n),a=Math.round(e.lng*i)/i,o=Math.round(e.lat*i)/i,s=this._map.getBearing(),l=this._map.getPitch(),c=\"\";return c+=t?\"#/\"+a+\"/\"+o+\"/\"+r:\"#\"+r+\"/\"+o+\"/\"+a,(s||l)&&(c+=\"/\"+Math.round(10*s)/10),l&&(c+=\"/\"+Math.round(l)),c},cn.prototype._onHashChange=function(){var e=t.window.location.hash.replace(\"#\",\"\").split(\"/\");return e.length>=3&&(this._map.jumpTo({center:[+e[2],+e[1]],zoom:+e[0],bearing:+(e[3]||0),pitch:+(e[4]||0)}),!0)},cn.prototype._updateHashUnthrottled=function(){var e=this.getHashString();try{t.window.history.replaceState(t.window.history.state,\"\",e)}catch(t){}};var un=function(e){function n(n,i,a,o){void 0===o&&(o={});var s=r.mousePos(i.getCanvasContainer(),a),l=i.unproject(s);e.call(this,n,t.extend({point:s,lngLat:l,originalEvent:a},o)),this._defaultPrevented=!1,this.target=i}e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),hn=function(e){function n(n,i,a){var o=r.touchPos(i.getCanvasContainer(),a),s=o.map(function(t){return i.unproject(t)}),l=o.reduce(function(t,e,r,n){return t.add(e.div(n.length))},new t.Point(0,0)),c=i.unproject(l);e.call(this,n,{points:o,point:l,lngLats:s,lngLat:c,originalEvent:a}),this._defaultPrevented=!1}e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),fn=function(t){function e(e,r,n){t.call(this,e,{originalEvent:n}),this._defaultPrevented=!1}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={defaultPrevented:{configurable:!0}};return e.prototype.preventDefault=function(){this._defaultPrevented=!0},r.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(e.prototype,r),e}(t.Event),pn=function(e){this._map=e,this._el=e.getCanvasContainer(),this._delta=0,this._defaultZoomRate=.01,this._wheelZoomRate=1/450,t.bindAll([\"_onWheel\",\"_onTimeout\",\"_onScrollFrame\",\"_onScrollFinished\"],this)};pn.prototype.setZoomRate=function(t){this._defaultZoomRate=t},pn.prototype.setWheelZoomRate=function(t){this._wheelZoomRate=t},pn.prototype.isEnabled=function(){return!!this._enabled},pn.prototype.isActive=function(){return!!this._active},pn.prototype.isZooming=function(){return!!this._zooming},pn.prototype.enable=function(t){this.isEnabled()||(this._enabled=!0,this._aroundCenter=t&&\"center\"===t.around)},pn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},pn.prototype.onWheel=function(e){if(this.isEnabled()){var r=e.deltaMode===t.window.WheelEvent.DOM_DELTA_LINE?40*e.deltaY:e.deltaY,n=t.browser.now(),i=n-(this._lastWheelEventTime||0);this._lastWheelEventTime=n,0!==r&&r%4.000244140625==0?this._type=\"wheel\":0!==r&&Math.abs(r)<4?this._type=\"trackpad\":i>400?(this._type=null,this._lastValue=r,this._timeout=setTimeout(this._onTimeout,40,e)):this._type||(this._type=Math.abs(i*r)<200?\"trackpad\":\"wheel\",this._timeout&&(clearTimeout(this._timeout),this._timeout=null,r+=this._lastValue)),e.shiftKey&&r&&(r/=4),this._type&&(this._lastWheelEvent=e,this._delta-=r,this.isActive()||this._start(e)),e.preventDefault()}},pn.prototype._onTimeout=function(t){this._type=\"wheel\",this._delta-=this._lastValue,this.isActive()||this._start(t)},pn.prototype._start=function(e){if(this._delta){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),this._active=!0,this.isZooming()||(this._zooming=!0,this._map.fire(new t.Event(\"movestart\",{originalEvent:e})),this._map.fire(new t.Event(\"zoomstart\",{originalEvent:e}))),this._finishTimeout&&clearTimeout(this._finishTimeout);var n=r.mousePos(this._el,e);this._around=t.LngLat.convert(this._aroundCenter?this._map.getCenter():this._map.unproject(n)),this._aroundPoint=this._map.transform.locationPoint(this._around),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onScrollFrame))}},pn.prototype._onScrollFrame=function(){var e=this;if(this._frameId=null,this.isActive()){var r=this._map.transform;if(0!==this._delta){var n=\"wheel\"===this._type&&Math.abs(this._delta)>4.000244140625?this._wheelZoomRate:this._defaultZoomRate,i=2/(1+Math.exp(-Math.abs(this._delta*n)));this._delta<0&&0!==i&&(i=1/i);var a=\"number\"==typeof this._targetZoom?r.zoomScale(this._targetZoom):r.scale;this._targetZoom=Math.min(r.maxZoom,Math.max(r.minZoom,r.scaleZoom(a*i))),\"wheel\"===this._type&&(this._startZoom=r.zoom,this._easing=this._smoothOutEasing(200)),this._delta=0}var o=\"number\"==typeof this._targetZoom?this._targetZoom:r.zoom,s=this._startZoom,l=this._easing,c=!1;if(\"wheel\"===this._type&&s&&l){var u=Math.min((t.browser.now()-this._lastWheelEventTime)/200,1),h=l(u);r.zoom=t.number(s,o,h),u<1?this._frameId||(this._frameId=this._map._requestRenderFrame(this._onScrollFrame)):c=!0}else r.zoom=o,c=!0;r.setLocationAtPoint(this._around,this._aroundPoint),this._map.fire(new t.Event(\"move\",{originalEvent:this._lastWheelEvent})),this._map.fire(new t.Event(\"zoom\",{originalEvent:this._lastWheelEvent})),c&&(this._active=!1,this._finishTimeout=setTimeout(function(){e._zooming=!1,e._map.fire(new t.Event(\"zoomend\",{originalEvent:e._lastWheelEvent})),e._map.fire(new t.Event(\"moveend\",{originalEvent:e._lastWheelEvent})),delete e._targetZoom},200))}},pn.prototype._smoothOutEasing=function(e){var r=t.ease;if(this._prevEase){var n=this._prevEase,i=(t.browser.now()-n.start)/n.duration,a=n.easing(i+.01)-n.easing(i),o=.27/Math.sqrt(a*a+1e-4)*.01,s=Math.sqrt(.0729-o*o);r=t.bezier(o,s,.25,1)}return this._prevEase={start:t.browser.now(),duration:e,easing:r},r};var dn=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._container=e.getContainer(),this._clickTolerance=r.clickTolerance||1,t.bindAll([\"_onMouseMove\",\"_onMouseUp\",\"_onKeyDown\"],this)};dn.prototype.isEnabled=function(){return!!this._enabled},dn.prototype.isActive=function(){return!!this._active},dn.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},dn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},dn.prototype.onMouseDown=function(e){this.isEnabled()&&e.shiftKey&&0===e.button&&(t.window.document.addEventListener(\"mousemove\",this._onMouseMove,!1),t.window.document.addEventListener(\"keydown\",this._onKeyDown,!1),t.window.document.addEventListener(\"mouseup\",this._onMouseUp,!1),r.disableDrag(),this._startPos=this._lastPos=r.mousePos(this._el,e),this._active=!0)},dn.prototype._onMouseMove=function(t){var e=r.mousePos(this._el,t);if(!(this._lastPos.equals(e)||!this._box&&e.dist(this._startPos)<this._clickTolerance)){var n=this._startPos;this._lastPos=e,this._box||(this._box=r.create(\"div\",\"mapboxgl-boxzoom\",this._container),this._container.classList.add(\"mapboxgl-crosshair\"),this._fireEvent(\"boxzoomstart\",t));var i=Math.min(n.x,e.x),a=Math.max(n.x,e.x),o=Math.min(n.y,e.y),s=Math.max(n.y,e.y);r.setTransform(this._box,\"translate(\"+i+\"px,\"+o+\"px)\"),this._box.style.width=a-i+\"px\",this._box.style.height=s-o+\"px\"}},dn.prototype._onMouseUp=function(e){if(0===e.button){var n=this._startPos,i=r.mousePos(this._el,e);this._finish(),r.suppressClick(),n.x===i.x&&n.y===i.y?this._fireEvent(\"boxzoomcancel\",e):this._map.fitScreenCoordinates(n,i,this._map.getBearing(),{linear:!0}).fire(new t.Event(\"boxzoomend\",{originalEvent:e}))}},dn.prototype._onKeyDown=function(t){27===t.keyCode&&(this._finish(),this._fireEvent(\"boxzoomcancel\",t))},dn.prototype._finish=function(){this._active=!1,t.window.document.removeEventListener(\"mousemove\",this._onMouseMove,!1),t.window.document.removeEventListener(\"keydown\",this._onKeyDown,!1),t.window.document.removeEventListener(\"mouseup\",this._onMouseUp,!1),this._container.classList.remove(\"mapboxgl-crosshair\"),this._box&&(r.remove(this._box),this._box=null),r.enableDrag(),delete this._startPos,delete this._lastPos},dn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,{originalEvent:r}))};var gn=t.bezier(0,0,.25,1),vn=function(e,r){this._map=e,this._el=r.element||e.getCanvasContainer(),this._state=\"disabled\",this._button=r.button||\"right\",this._bearingSnap=r.bearingSnap||0,this._pitchWithRotate=!1!==r.pitchWithRotate,t.bindAll([\"onMouseDown\",\"_onMouseMove\",\"_onMouseUp\",\"_onBlur\",\"_onDragFrame\"],this)};vn.prototype.isEnabled=function(){return\"disabled\"!==this._state},vn.prototype.isActive=function(){return\"active\"===this._state},vn.prototype.enable=function(){this.isEnabled()||(this._state=\"enabled\")},vn.prototype.disable=function(){if(this.isEnabled())switch(this._state){case\"active\":this._state=\"disabled\",this._unbind(),this._deactivate(),this._fireEvent(\"rotateend\"),this._pitchWithRotate&&this._fireEvent(\"pitchend\"),this._fireEvent(\"moveend\");break;case\"pending\":this._state=\"disabled\",this._unbind();break;default:this._state=\"disabled\"}},vn.prototype.onMouseDown=function(e){if(\"enabled\"===this._state){if(\"right\"===this._button){if(this._eventButton=r.mouseButton(e),this._eventButton!==(e.ctrlKey?0:2))return}else{if(e.ctrlKey||0!==r.mouseButton(e))return;this._eventButton=0}r.disableDrag(),t.window.document.addEventListener(\"mousemove\",this._onMouseMove,{capture:!0}),t.window.document.addEventListener(\"mouseup\",this._onMouseUp),t.window.addEventListener(\"blur\",this._onBlur),this._state=\"pending\",this._inertia=[[t.browser.now(),this._map.getBearing()]],this._startPos=this._lastPos=r.mousePos(this._el,e),this._center=this._map.transform.centerPoint,e.preventDefault()}},vn.prototype._onMouseMove=function(t){var e=r.mousePos(this._el,t);this._lastPos.equals(e)||(this._lastMoveEvent=t,this._lastPos=e,\"pending\"===this._state&&(this._state=\"active\",this._fireEvent(\"rotatestart\",t),this._fireEvent(\"movestart\",t),this._pitchWithRotate&&this._fireEvent(\"pitchstart\",t)),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onDragFrame)))},vn.prototype._onDragFrame=function(){this._frameId=null;var e=this._lastMoveEvent;if(e){var r=this._map.transform,n=this._startPos,i=this._lastPos,a=.8*(n.x-i.x),o=-.5*(n.y-i.y),s=r.bearing-a,l=r.pitch-o,c=this._inertia,u=c[c.length-1];this._drainInertiaBuffer(),c.push([t.browser.now(),this._map._normalizeBearing(s,u[1])]),r.bearing=s,this._pitchWithRotate&&(this._fireEvent(\"pitch\",e),r.pitch=l),this._fireEvent(\"rotate\",e),this._fireEvent(\"move\",e),delete this._lastMoveEvent,this._startPos=this._lastPos}},vn.prototype._onMouseUp=function(t){if(r.mouseButton(t)===this._eventButton)switch(this._state){case\"active\":this._state=\"enabled\",r.suppressClick(),this._unbind(),this._deactivate(),this._inertialRotate(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},vn.prototype._onBlur=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._fireEvent(\"rotateend\",t),this._pitchWithRotate&&this._fireEvent(\"pitchend\",t),this._fireEvent(\"moveend\",t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},vn.prototype._unbind=function(){t.window.document.removeEventListener(\"mousemove\",this._onMouseMove,{capture:!0}),t.window.document.removeEventListener(\"mouseup\",this._onMouseUp),t.window.removeEventListener(\"blur\",this._onBlur),r.enableDrag()},vn.prototype._deactivate=function(){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._lastMoveEvent,delete this._startPos,delete this._lastPos},vn.prototype._inertialRotate=function(t){var e=this;this._fireEvent(\"rotateend\",t),this._drainInertiaBuffer();var r=this._map,n=r.getBearing(),i=this._inertia,a=function(){Math.abs(n)<e._bearingSnap?r.resetNorth({noMoveStart:!0},{originalEvent:t}):e._fireEvent(\"moveend\",t),e._pitchWithRotate&&e._fireEvent(\"pitchend\",t)};if(i.length<2)a();else{var o=i[0],s=i[i.length-1],l=i[i.length-2],c=r._normalizeBearing(n,l[1]),u=s[1]-o[1],h=u<0?-1:1,f=(s[0]-o[0])/1e3;if(0!==u&&0!==f){var p=Math.abs(u*(.25/f));p>180&&(p=180);var d=p/180;c+=h*p*(d/2),Math.abs(r._normalizeBearing(c,0))<this._bearingSnap&&(c=r._normalizeBearing(0,c)),r.rotateTo(c,{duration:1e3*d,easing:gn,noMoveStart:!0},{originalEvent:t})}else a()}},vn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},vn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>0&&r-e[0][0]>160;)e.shift()};var mn=t.bezier(0,0,.3,1),yn=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._state=\"disabled\",this._clickTolerance=r.clickTolerance||1,t.bindAll([\"_onMove\",\"_onMouseUp\",\"_onTouchEnd\",\"_onBlur\",\"_onDragFrame\"],this)};yn.prototype.isEnabled=function(){return\"disabled\"!==this._state},yn.prototype.isActive=function(){return\"active\"===this._state},yn.prototype.enable=function(){this.isEnabled()||(this._el.classList.add(\"mapboxgl-touch-drag-pan\"),this._state=\"enabled\")},yn.prototype.disable=function(){if(this.isEnabled())switch(this._el.classList.remove(\"mapboxgl-touch-drag-pan\"),this._state){case\"active\":this._state=\"disabled\",this._unbind(),this._deactivate(),this._fireEvent(\"dragend\"),this._fireEvent(\"moveend\");break;case\"pending\":this._state=\"disabled\",this._unbind();break;default:this._state=\"disabled\"}},yn.prototype.onMouseDown=function(e){\"enabled\"===this._state&&(e.ctrlKey||0!==r.mouseButton(e)||(r.addEventListener(t.window.document,\"mousemove\",this._onMove,{capture:!0}),r.addEventListener(t.window.document,\"mouseup\",this._onMouseUp),this._start(e)))},yn.prototype.onTouchStart=function(e){\"enabled\"===this._state&&(e.touches.length>1||(r.addEventListener(t.window.document,\"touchmove\",this._onMove,{capture:!0,passive:!1}),r.addEventListener(t.window.document,\"touchend\",this._onTouchEnd),this._start(e)))},yn.prototype._start=function(e){t.window.addEventListener(\"blur\",this._onBlur),this._state=\"pending\",this._startPos=this._mouseDownPos=this._lastPos=r.mousePos(this._el,e),this._inertia=[[t.browser.now(),this._startPos]]},yn.prototype._onMove=function(e){e.preventDefault();var n=r.mousePos(this._el,e);this._lastPos.equals(n)||\"pending\"===this._state&&n.dist(this._mouseDownPos)<this._clickTolerance||(this._lastMoveEvent=e,this._lastPos=n,this._drainInertiaBuffer(),this._inertia.push([t.browser.now(),this._lastPos]),\"pending\"===this._state&&(this._state=\"active\",this._fireEvent(\"dragstart\",e),this._fireEvent(\"movestart\",e)),this._frameId||(this._frameId=this._map._requestRenderFrame(this._onDragFrame)))},yn.prototype._onDragFrame=function(){this._frameId=null;var t=this._lastMoveEvent;if(t){var e=this._map.transform;e.setLocationAtPoint(e.pointLocation(this._startPos),this._lastPos),this._fireEvent(\"drag\",t),this._fireEvent(\"move\",t),this._startPos=this._lastPos,delete this._lastMoveEvent}},yn.prototype._onMouseUp=function(t){if(0===r.mouseButton(t))switch(this._state){case\"active\":this._state=\"enabled\",r.suppressClick(),this._unbind(),this._deactivate(),this._inertialPan(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},yn.prototype._onTouchEnd=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._inertialPan(t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},yn.prototype._onBlur=function(t){switch(this._state){case\"active\":this._state=\"enabled\",this._unbind(),this._deactivate(),this._fireEvent(\"dragend\",t),this._fireEvent(\"moveend\",t);break;case\"pending\":this._state=\"enabled\",this._unbind()}},yn.prototype._unbind=function(){r.removeEventListener(t.window.document,\"touchmove\",this._onMove,{capture:!0,passive:!1}),r.removeEventListener(t.window.document,\"touchend\",this._onTouchEnd),r.removeEventListener(t.window.document,\"mousemove\",this._onMove,{capture:!0}),r.removeEventListener(t.window.document,\"mouseup\",this._onMouseUp),r.removeEventListener(t.window,\"blur\",this._onBlur)},yn.prototype._deactivate=function(){this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._lastMoveEvent,delete this._startPos,delete this._mouseDownPos,delete this._lastPos},yn.prototype._inertialPan=function(t){this._fireEvent(\"dragend\",t),this._drainInertiaBuffer();var e=this._inertia;if(e.length<2)this._fireEvent(\"moveend\",t);else{var r=e[e.length-1],n=e[0],i=r[1].sub(n[1]),a=(r[0]-n[0])/1e3;if(0===a||r[1].equals(n[1]))this._fireEvent(\"moveend\",t);else{var o=i.mult(.3/a),s=o.mag();s>1400&&(s=1400,o._unit()._mult(s));var l=s/750,c=o.mult(-l/2);this._map.panBy(c,{duration:1e3*l,easing:mn,noMoveStart:!0},{originalEvent:t})}}},yn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},yn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>0&&r-e[0][0]>160;)e.shift()};var xn=function(e){this._map=e,this._el=e.getCanvasContainer(),t.bindAll([\"_onKeyDown\"],this)};function bn(t){return t*(2-t)}xn.prototype.isEnabled=function(){return!!this._enabled},xn.prototype.enable=function(){this.isEnabled()||(this._el.addEventListener(\"keydown\",this._onKeyDown,!1),this._enabled=!0)},xn.prototype.disable=function(){this.isEnabled()&&(this._el.removeEventListener(\"keydown\",this._onKeyDown),this._enabled=!1)},xn.prototype._onKeyDown=function(t){if(!(t.altKey||t.ctrlKey||t.metaKey)){var e=0,r=0,n=0,i=0,a=0;switch(t.keyCode){case 61:case 107:case 171:case 187:e=1;break;case 189:case 109:case 173:e=-1;break;case 37:t.shiftKey?r=-1:(t.preventDefault(),i=-1);break;case 39:t.shiftKey?r=1:(t.preventDefault(),i=1);break;case 38:t.shiftKey?n=1:(t.preventDefault(),a=-1);break;case 40:t.shiftKey?n=-1:(a=1,t.preventDefault());break;default:return}var o=this._map,s=o.getZoom(),l={duration:300,delayEndEvents:500,easing:bn,zoom:e?Math.round(s)+e*(t.shiftKey?2:1):s,bearing:o.getBearing()+15*r,pitch:o.getPitch()+10*n,offset:[100*-i,100*-a],center:o.getCenter()};o.easeTo(l,{originalEvent:t})}};var _n=function(e){this._map=e,t.bindAll([\"_onDblClick\",\"_onZoomEnd\"],this)};_n.prototype.isEnabled=function(){return!!this._enabled},_n.prototype.isActive=function(){return!!this._active},_n.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},_n.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},_n.prototype.onTouchStart=function(t){var e=this;if(this.isEnabled()&&!(t.points.length>1))if(this._tapped){var r=t.points[0],n=this._tappedPoint;if(n&&n.dist(r)<=30){t.originalEvent.preventDefault();var i=function(){e._tapped&&e._zoom(t),e._map.off(\"touchcancel\",a),e._resetTapped()},a=function(){e._map.off(\"touchend\",i),e._resetTapped()};this._map.once(\"touchend\",i),this._map.once(\"touchcancel\",a)}else this._resetTapped()}else this._tappedPoint=t.points[0],this._tapped=setTimeout(function(){e._tapped=null,e._tappedPoint=null},300)},_n.prototype._resetTapped=function(){clearTimeout(this._tapped),this._tapped=null,this._tappedPoint=null},_n.prototype.onDblClick=function(t){this.isEnabled()&&(t.originalEvent.preventDefault(),this._zoom(t))},_n.prototype._zoom=function(t){this._active=!0,this._map.on(\"zoomend\",this._onZoomEnd),this._map.zoomTo(this._map.getZoom()+(t.originalEvent.shiftKey?-1:1),{around:t.lngLat},t)},_n.prototype._onZoomEnd=function(){this._active=!1,this._map.off(\"zoomend\",this._onZoomEnd)};var wn=t.bezier(0,0,.15,1),kn=function(e){this._map=e,this._el=e.getCanvasContainer(),t.bindAll([\"_onMove\",\"_onEnd\",\"_onTouchFrame\"],this)};kn.prototype.isEnabled=function(){return!!this._enabled},kn.prototype.enable=function(t){this.isEnabled()||(this._el.classList.add(\"mapboxgl-touch-zoom-rotate\"),this._enabled=!0,this._aroundCenter=!!t&&\"center\"===t.around)},kn.prototype.disable=function(){this.isEnabled()&&(this._el.classList.remove(\"mapboxgl-touch-zoom-rotate\"),this._enabled=!1)},kn.prototype.disableRotation=function(){this._rotationDisabled=!0},kn.prototype.enableRotation=function(){this._rotationDisabled=!1},kn.prototype.onStart=function(e){if(this.isEnabled()&&2===e.touches.length){var n=r.mousePos(this._el,e.touches[0]),i=r.mousePos(this._el,e.touches[1]),a=n.add(i).div(2);this._startVec=n.sub(i),this._startAround=this._map.transform.pointLocation(a),this._gestureIntent=void 0,this._inertia=[],r.addEventListener(t.window.document,\"touchmove\",this._onMove,{passive:!1}),r.addEventListener(t.window.document,\"touchend\",this._onEnd)}},kn.prototype._getTouchEventData=function(t){var e=r.mousePos(this._el,t.touches[0]),n=r.mousePos(this._el,t.touches[1]),i=e.sub(n);return{vec:i,center:e.add(n).div(2),scale:i.mag()/this._startVec.mag(),bearing:this._rotationDisabled?0:180*i.angleWith(this._startVec)/Math.PI}},kn.prototype._onMove=function(e){if(2===e.touches.length){var r=this._getTouchEventData(e),n=r.vec,i=r.scale,a=r.bearing;if(!this._gestureIntent){var o=this._rotationDisabled&&1!==i||Math.abs(1-i)>.15;Math.abs(a)>10?this._gestureIntent=\"rotate\":o&&(this._gestureIntent=\"zoom\"),this._gestureIntent&&(this._map.fire(new t.Event(this._gestureIntent+\"start\",{originalEvent:e})),this._map.fire(new t.Event(\"movestart\",{originalEvent:e})),this._startVec=n)}this._lastTouchEvent=e,this._frameId||(this._frameId=this._map._requestRenderFrame(this._onTouchFrame)),e.preventDefault()}},kn.prototype._onTouchFrame=function(){this._frameId=null;var e=this._gestureIntent;if(e){var r=this._map.transform;this._startScale||(this._startScale=r.scale,this._startBearing=r.bearing);var n=this._getTouchEventData(this._lastTouchEvent),i=n.center,a=n.bearing,o=n.scale,s=r.pointLocation(i),l=r.locationPoint(s);\"rotate\"===e&&(r.bearing=this._startBearing+a),r.zoom=r.scaleZoom(this._startScale*o),r.setLocationAtPoint(this._startAround,l),this._map.fire(new t.Event(e,{originalEvent:this._lastTouchEvent})),this._map.fire(new t.Event(\"move\",{originalEvent:this._lastTouchEvent})),this._drainInertiaBuffer(),this._inertia.push([t.browser.now(),o,i])}},kn.prototype._onEnd=function(e){r.removeEventListener(t.window.document,\"touchmove\",this._onMove,{passive:!1}),r.removeEventListener(t.window.document,\"touchend\",this._onEnd);var n=this._gestureIntent,i=this._startScale;if(this._frameId&&(this._map._cancelRenderFrame(this._frameId),this._frameId=null),delete this._gestureIntent,delete this._startScale,delete this._startBearing,delete this._lastTouchEvent,n){this._map.fire(new t.Event(n+\"end\",{originalEvent:e})),this._drainInertiaBuffer();var a=this._inertia,o=this._map;if(a.length<2)o.snapToNorth({},{originalEvent:e});else{var s=a[a.length-1],l=a[0],c=o.transform.scaleZoom(i*s[1]),u=o.transform.scaleZoom(i*l[1]),h=c-u,f=(s[0]-l[0])/1e3,p=s[2];if(0!==f&&c!==u){var d=.15*h/f;Math.abs(d)>2.5&&(d=d>0?2.5:-2.5);var g=1e3*Math.abs(d/(12*.15)),v=c+d*g/2e3;v<0&&(v=0),o.easeTo({zoom:v,duration:g,easing:wn,around:this._aroundCenter?o.getCenter():o.unproject(p),noMoveStart:!0},{originalEvent:e})}else o.snapToNorth({},{originalEvent:e})}}},kn.prototype._drainInertiaBuffer=function(){for(var e=this._inertia,r=t.browser.now();e.length>2&&r-e[0][0]>160;)e.shift()};var Tn={scrollZoom:pn,boxZoom:dn,dragRotate:vn,dragPan:yn,keyboard:xn,doubleClickZoom:_n,touchZoomRotate:kn},An=function(e){function r(r,n){e.call(this),this._moving=!1,this._zooming=!1,this.transform=r,this._bearingSnap=n.bearingSnap,t.bindAll([\"_renderFrameCallback\"],this)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getCenter=function(){return new t.LngLat(this.transform.center.lng,this.transform.center.lat)},r.prototype.setCenter=function(t,e){return this.jumpTo({center:t},e)},r.prototype.panBy=function(e,r,n){return e=t.Point.convert(e).mult(-1),this.panTo(this.transform.center,t.extend({offset:e},r),n)},r.prototype.panTo=function(e,r,n){return this.easeTo(t.extend({center:e},r),n)},r.prototype.getZoom=function(){return this.transform.zoom},r.prototype.setZoom=function(t,e){return this.jumpTo({zoom:t},e),this},r.prototype.zoomTo=function(e,r,n){return this.easeTo(t.extend({zoom:e},r),n)},r.prototype.zoomIn=function(t,e){return this.zoomTo(this.getZoom()+1,t,e),this},r.prototype.zoomOut=function(t,e){return this.zoomTo(this.getZoom()-1,t,e),this},r.prototype.getBearing=function(){return this.transform.bearing},r.prototype.setBearing=function(t,e){return this.jumpTo({bearing:t},e),this},r.prototype.rotateTo=function(e,r,n){return this.easeTo(t.extend({bearing:e},r),n)},r.prototype.resetNorth=function(e,r){return this.rotateTo(0,t.extend({duration:1e3},e),r),this},r.prototype.snapToNorth=function(t,e){return Math.abs(this.getBearing())<this._bearingSnap?this.resetNorth(t,e):this},r.prototype.getPitch=function(){return this.transform.pitch},r.prototype.setPitch=function(t,e){return this.jumpTo({pitch:t},e),this},r.prototype.cameraForBounds=function(e,r){return e=t.LngLatBounds.convert(e),this._cameraForBoxAndBearing(e.getNorthWest(),e.getSouthEast(),0,r)},r.prototype._cameraForBoxAndBearing=function(e,r,n,i){if(\"number\"==typeof(i=t.extend({padding:{top:0,bottom:0,right:0,left:0},offset:[0,0],maxZoom:this.transform.maxZoom},i)).padding){var a=i.padding;i.padding={top:a,bottom:a,right:a,left:a}}if(t.deepEqual(Object.keys(i.padding).sort(function(t,e){return t<e?-1:t>e?1:0}),[\"bottom\",\"left\",\"right\",\"top\"])){var o=this.transform,s=o.project(t.LngLat.convert(e)),l=o.project(t.LngLat.convert(r)),c=s.rotate(-n*Math.PI/180),u=l.rotate(-n*Math.PI/180),h=new t.Point(Math.max(c.x,u.x),Math.max(c.y,u.y)),f=new t.Point(Math.min(c.x,u.x),Math.min(c.y,u.y)),p=h.sub(f),d=(o.width-i.padding.left-i.padding.right)/p.x,g=(o.height-i.padding.top-i.padding.bottom)/p.y;if(!(g<0||d<0)){var v=Math.min(o.scaleZoom(o.scale*Math.min(d,g)),i.maxZoom),m=t.Point.convert(i.offset),y=(i.padding.left-i.padding.right)/2,x=(i.padding.top-i.padding.bottom)/2,b=new t.Point(m.x+y,m.y+x).mult(o.scale/o.zoomScale(v));return{center:o.unproject(s.add(l).div(2).sub(b)),zoom:v,bearing:n}}t.warnOnce(\"Map cannot fit within canvas with the given bounds, padding, and/or offset.\")}else t.warnOnce(\"options.padding must be a positive number, or an Object with keys 'bottom', 'left', 'right', 'top'\")},r.prototype.fitBounds=function(t,e,r){return this._fitInternal(this.cameraForBounds(t,e),e,r)},r.prototype.fitScreenCoordinates=function(e,r,n,i,a){return this._fitInternal(this._cameraForBoxAndBearing(this.transform.pointLocation(t.Point.convert(e)),this.transform.pointLocation(t.Point.convert(r)),n,i),i,a)},r.prototype._fitInternal=function(e,r,n){return e?(r=t.extend(e,r)).linear?this.easeTo(r,n):this.flyTo(r,n):this},r.prototype.jumpTo=function(e,r){this.stop();var n=this.transform,i=!1,a=!1,o=!1;return\"zoom\"in e&&n.zoom!==+e.zoom&&(i=!0,n.zoom=+e.zoom),void 0!==e.center&&(n.center=t.LngLat.convert(e.center)),\"bearing\"in e&&n.bearing!==+e.bearing&&(a=!0,n.bearing=+e.bearing),\"pitch\"in e&&n.pitch!==+e.pitch&&(o=!0,n.pitch=+e.pitch),this.fire(new t.Event(\"movestart\",r)).fire(new t.Event(\"move\",r)),i&&this.fire(new t.Event(\"zoomstart\",r)).fire(new t.Event(\"zoom\",r)).fire(new t.Event(\"zoomend\",r)),a&&this.fire(new t.Event(\"rotatestart\",r)).fire(new t.Event(\"rotate\",r)).fire(new t.Event(\"rotateend\",r)),o&&this.fire(new t.Event(\"pitchstart\",r)).fire(new t.Event(\"pitch\",r)).fire(new t.Event(\"pitchend\",r)),this.fire(new t.Event(\"moveend\",r))},r.prototype.easeTo=function(e,r){var n=this;this.stop(),!1===(e=t.extend({offset:[0,0],duration:500,easing:t.ease},e)).animate&&(e.duration=0);var i=this.transform,a=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=\"zoom\"in e?+e.zoom:a,c=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,u=\"pitch\"in e?+e.pitch:s,h=i.centerPoint.add(t.Point.convert(e.offset)),f=i.pointLocation(h),p=t.LngLat.convert(e.center||f);this._normalizeCenter(p);var d,g,v=i.project(f),m=i.project(p).sub(v),y=i.zoomScale(l-a);return e.around&&(d=t.LngLat.convert(e.around),g=i.locationPoint(d)),this._zooming=l!==a,this._rotating=o!==c,this._pitching=u!==s,this._prepareEase(r,e.noMoveStart),clearTimeout(this._easeEndTimeoutID),this._ease(function(e){if(n._zooming&&(i.zoom=t.number(a,l,e)),n._rotating&&(i.bearing=t.number(o,c,e)),n._pitching&&(i.pitch=t.number(s,u,e)),d)i.setLocationAtPoint(d,g);else{var f=i.zoomScale(i.zoom-a),p=l>a?Math.min(2,y):Math.max(.5,y),x=Math.pow(p,1-e),b=i.unproject(v.add(m.mult(e*x)).mult(f));i.setLocationAtPoint(i.renderWorldCopies?b.wrap():b,h)}n._fireMoveEvents(r)},function(){e.delayEndEvents?n._easeEndTimeoutID=setTimeout(function(){return n._afterEase(r)},e.delayEndEvents):n._afterEase(r)},e),this},r.prototype._prepareEase=function(e,r){this._moving=!0,r||this.fire(new t.Event(\"movestart\",e)),this._zooming&&this.fire(new t.Event(\"zoomstart\",e)),this._rotating&&this.fire(new t.Event(\"rotatestart\",e)),this._pitching&&this.fire(new t.Event(\"pitchstart\",e))},r.prototype._fireMoveEvents=function(e){this.fire(new t.Event(\"move\",e)),this._zooming&&this.fire(new t.Event(\"zoom\",e)),this._rotating&&this.fire(new t.Event(\"rotate\",e)),this._pitching&&this.fire(new t.Event(\"pitch\",e))},r.prototype._afterEase=function(e){var r=this._zooming,n=this._rotating,i=this._pitching;this._moving=!1,this._zooming=!1,this._rotating=!1,this._pitching=!1,r&&this.fire(new t.Event(\"zoomend\",e)),n&&this.fire(new t.Event(\"rotateend\",e)),i&&this.fire(new t.Event(\"pitchend\",e)),this.fire(new t.Event(\"moveend\",e))},r.prototype.flyTo=function(e,r){var n=this;this.stop(),e=t.extend({offset:[0,0],speed:1.2,curve:1.42,easing:t.ease},e);var i=this.transform,a=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=\"zoom\"in e?t.clamp(+e.zoom,i.minZoom,i.maxZoom):a,c=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,u=\"pitch\"in e?+e.pitch:s,h=i.zoomScale(l-a),f=i.centerPoint.add(t.Point.convert(e.offset)),p=i.pointLocation(f),d=t.LngLat.convert(e.center||p);this._normalizeCenter(d);var g=i.project(p),v=i.project(d).sub(g),m=e.curve,y=Math.max(i.width,i.height),x=y/h,b=v.mag();if(\"minZoom\"in e){var _=t.clamp(Math.min(e.minZoom,a,l),i.minZoom,i.maxZoom),w=y/i.zoomScale(_-a);m=Math.sqrt(w/b*2)}var k=m*m;function T(t){var e=(x*x-y*y+(t?-1:1)*k*k*b*b)/(2*(t?x:y)*k*b);return Math.log(Math.sqrt(e*e+1)-e)}function A(t){return(Math.exp(t)-Math.exp(-t))/2}function M(t){return(Math.exp(t)+Math.exp(-t))/2}var S=T(0),E=function(t){return M(S)/M(S+m*t)},C=function(t){return y*((M(S)*(A(e=S+m*t)/M(e))-A(S))/k)/b;var e},L=(T(1)-S)/m;if(Math.abs(b)<1e-6||!isFinite(L)){if(Math.abs(y-x)<1e-6)return this.easeTo(e,r);var P=x<y?-1:1;L=Math.abs(Math.log(x/y))/m,C=function(){return 0},E=function(t){return Math.exp(P*m*t)}}if(\"duration\"in e)e.duration=+e.duration;else{var O=\"screenSpeed\"in e?+e.screenSpeed/m:+e.speed;e.duration=1e3*L/O}return e.maxDuration&&e.duration>e.maxDuration&&(e.duration=0),this._zooming=!0,this._rotating=o!==c,this._pitching=u!==s,this._prepareEase(r,!1),this._ease(function(e){var h=e*L,p=1/E(h);i.zoom=1===e?l:a+i.scaleZoom(p),n._rotating&&(i.bearing=t.number(o,c,e)),n._pitching&&(i.pitch=t.number(s,u,e));var m=1===e?d:i.unproject(g.add(v.mult(C(h))).mult(p));i.setLocationAtPoint(i.renderWorldCopies?m.wrap():m,f),n._fireMoveEvents(r)},function(){return n._afterEase(r)},e),this},r.prototype.isEasing=function(){return!!this._easeFrameId},r.prototype.stop=function(){if(this._easeFrameId&&(this._cancelRenderFrame(this._easeFrameId),delete this._easeFrameId,delete this._onEaseFrame),this._onEaseEnd){var t=this._onEaseEnd;delete this._onEaseEnd,t.call(this)}return this},r.prototype._ease=function(e,r,n){!1===n.animate||0===n.duration?(e(1),r()):(this._easeStart=t.browser.now(),this._easeOptions=n,this._onEaseFrame=e,this._onEaseEnd=r,this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback))},r.prototype._renderFrameCallback=function(){var e=Math.min((t.browser.now()-this._easeStart)/this._easeOptions.duration,1);this._onEaseFrame(this._easeOptions.easing(e)),e<1?this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback):this.stop()},r.prototype._normalizeBearing=function(e,r){e=t.wrap(e,-180,180);var n=Math.abs(e-r);return Math.abs(e-360-r)<n&&(e-=360),Math.abs(e+360-r)<n&&(e+=360),e},r.prototype._normalizeCenter=function(t){var e=this.transform;if(e.renderWorldCopies&&!e.lngRange){var r=t.lng-e.center.lng;t.lng+=r>180?-360:r<-180?360:0}},r}(t.Evented),Mn=function(e){void 0===e&&(e={}),this.options=e,t.bindAll([\"_updateEditLink\",\"_updateData\",\"_updateCompact\"],this)};Mn.prototype.getDefaultPosition=function(){return\"bottom-right\"},Mn.prototype.onAdd=function(t){var e=this.options&&this.options.compact;return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-attrib\"),this._innerContainer=r.create(\"div\",\"mapboxgl-ctrl-attrib-inner\",this._container),e&&this._container.classList.add(\"mapboxgl-compact\"),this._updateAttributions(),this._updateEditLink(),this._map.on(\"styledata\",this._updateData),this._map.on(\"sourcedata\",this._updateData),this._map.on(\"moveend\",this._updateEditLink),void 0===e&&(this._map.on(\"resize\",this._updateCompact),this._updateCompact()),this._container},Mn.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"styledata\",this._updateData),this._map.off(\"sourcedata\",this._updateData),this._map.off(\"moveend\",this._updateEditLink),this._map.off(\"resize\",this._updateCompact),this._map=void 0},Mn.prototype._updateEditLink=function(){var e=this._editLink;e||(e=this._editLink=this._container.querySelector(\".mapbox-improve-map\"));var r=[{key:\"owner\",value:this.styleOwner},{key:\"id\",value:this.styleId},{key:\"access_token\",value:t.config.ACCESS_TOKEN}];if(e){var n=r.reduce(function(t,e,n){return e.value&&(t+=e.key+\"=\"+e.value+(n<r.length-1?\"&\":\"\")),t},\"?\");e.href=t.config.FEEDBACK_URL+\"/\"+n+(this._map._hash?this._map._hash.getHashString(!0):\"\"),e.rel=\"noopener nofollow\"}},Mn.prototype._updateData=function(t){!t||\"metadata\"!==t.sourceDataType&&\"style\"!==t.dataType||(this._updateAttributions(),this._updateEditLink())},Mn.prototype._updateAttributions=function(){if(this._map.style){var t=[];if(this.options.customAttribution&&(Array.isArray(this.options.customAttribution)?t=t.concat(this.options.customAttribution.map(function(t){return\"string\"!=typeof t?\"\":t})):\"string\"==typeof this.options.customAttribution&&t.push(this.options.customAttribution)),this._map.style.stylesheet){var e=this._map.style.stylesheet;this.styleOwner=e.owner,this.styleId=e.id}var r=this._map.style.sourceCaches;for(var n in r){var i=r[n];if(i.used){var a=i.getSource();a.attribution&&t.indexOf(a.attribution)<0&&t.push(a.attribution)}}t.sort(function(t,e){return t.length-e.length});var o=(t=t.filter(function(e,r){for(var n=r+1;n<t.length;n++)if(t[n].indexOf(e)>=0)return!1;return!0})).join(\" | \");o!==this._attribHTML&&(this._attribHTML=o,t.length?(this._innerContainer.innerHTML=o,this._container.classList.remove(\"mapboxgl-attrib-empty\")):this._container.classList.add(\"mapboxgl-attrib-empty\"),this._editLink=null)}},Mn.prototype._updateCompact=function(){this._map.getCanvasContainer().offsetWidth<=640?this._container.classList.add(\"mapboxgl-compact\"):this._container.classList.remove(\"mapboxgl-compact\")};var Sn=function(){t.bindAll([\"_updateLogo\"],this),t.bindAll([\"_updateCompact\"],this)};Sn.prototype.onAdd=function(t){this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl\");var e=r.create(\"a\",\"mapboxgl-ctrl-logo\");return e.target=\"_blank\",e.rel=\"noopener nofollow\",e.href=\"https://www.mapbox.com/\",e.setAttribute(\"aria-label\",\"Mapbox logo\"),e.setAttribute(\"rel\",\"noopener nofollow\"),this._container.appendChild(e),this._container.style.display=\"none\",this._map.on(\"sourcedata\",this._updateLogo),this._updateLogo(),this._map.on(\"resize\",this._updateCompact),this._updateCompact(),this._container},Sn.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"sourcedata\",this._updateLogo),this._map.off(\"resize\",this._updateCompact)},Sn.prototype.getDefaultPosition=function(){return\"bottom-left\"},Sn.prototype._updateLogo=function(t){t&&\"metadata\"!==t.sourceDataType||(this._container.style.display=this._logoRequired()?\"block\":\"none\")},Sn.prototype._logoRequired=function(){if(this._map.style){var t=this._map.style.sourceCaches;for(var e in t)if(t[e].getSource().mapbox_logo)return!0;return!1}},Sn.prototype._updateCompact=function(){var t=this._container.children;if(t.length){var e=t[0];this._map.getCanvasContainer().offsetWidth<250?e.classList.add(\"mapboxgl-compact\"):e.classList.remove(\"mapboxgl-compact\")}};var En=function(){this._queue=[],this._id=0,this._cleared=!1,this._currentlyRunning=!1};En.prototype.add=function(t){var e=++this._id;return this._queue.push({callback:t,id:e,cancelled:!1}),e},En.prototype.remove=function(t){for(var e=this._currentlyRunning,r=0,n=e?this._queue.concat(e):this._queue;r<n.length;r+=1){var i=n[r];if(i.id===t)return void(i.cancelled=!0)}},En.prototype.run=function(){var t=this._currentlyRunning=this._queue;this._queue=[];for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!n.cancelled&&(n.callback(),this._cleared))break}this._cleared=!1,this._currentlyRunning=!1},En.prototype.clear=function(){this._currentlyRunning&&(this._cleared=!0),this._queue=[]};var Cn=t.window.HTMLImageElement,Ln=t.window.HTMLElement,Pn={center:[0,0],zoom:0,bearing:0,pitch:0,minZoom:0,maxZoom:22,interactive:!0,scrollZoom:!0,boxZoom:!0,dragRotate:!0,dragPan:!0,keyboard:!0,doubleClickZoom:!0,touchZoomRotate:!0,bearingSnap:7,clickTolerance:3,hash:!1,attributionControl:!0,failIfMajorPerformanceCaveat:!1,preserveDrawingBuffer:!1,trackResize:!0,renderWorldCopies:!0,refreshExpiredTiles:!0,maxTileCacheSize:null,localIdeographFontFamily:\"sans-serif\",transformRequest:null,fadeDuration:300,crossSourceCollisions:!0},On=function(n){function i(e){var i=this;if(null!=(e=t.extend({},Pn,e)).minZoom&&null!=e.maxZoom&&e.minZoom>e.maxZoom)throw new Error(\"maxZoom must be greater than minZoom\");var a=new sn(e.minZoom,e.maxZoom,e.renderWorldCopies);if(n.call(this,a,e),this._interactive=e.interactive,this._maxTileCacheSize=e.maxTileCacheSize,this._failIfMajorPerformanceCaveat=e.failIfMajorPerformanceCaveat,this._preserveDrawingBuffer=e.preserveDrawingBuffer,this._antialias=e.antialias,this._trackResize=e.trackResize,this._bearingSnap=e.bearingSnap,this._refreshExpiredTiles=e.refreshExpiredTiles,this._fadeDuration=e.fadeDuration,this._crossSourceCollisions=e.crossSourceCollisions,this._crossFadingFactor=1,this._collectResourceTiming=e.collectResourceTiming,this._renderTaskQueue=new En,this._controls=[],this._mapId=t.uniqueId(),this._requestManager=new t.RequestManager(e.transformRequest),\"string\"==typeof e.container){if(this._container=t.window.document.getElementById(e.container),!this._container)throw new Error(\"Container '\"+e.container+\"' not found.\")}else{if(!(e.container instanceof Ln))throw new Error(\"Invalid type: 'container' must be a String or HTMLElement.\");this._container=e.container}if(e.maxBounds&&this.setMaxBounds(e.maxBounds),t.bindAll([\"_onWindowOnline\",\"_onWindowResize\",\"_contextLost\",\"_contextRestored\"],this),this._setupContainer(),this._setupPainter(),void 0===this.painter)throw new Error(\"Failed to initialize WebGL.\");this.on(\"move\",function(){return i._update(!1)}),this.on(\"moveend\",function(){return i._update(!1)}),this.on(\"zoom\",function(){return i._update(!0)}),void 0!==t.window&&(t.window.addEventListener(\"online\",this._onWindowOnline,!1),t.window.addEventListener(\"resize\",this._onWindowResize,!1)),function(t,e){var n=t.getCanvasContainer(),i=null,a=!1,o=null;for(var s in Tn)t[s]=new Tn[s](t,e),e.interactive&&e[s]&&t[s].enable(e[s]);r.addEventListener(n,\"mouseout\",function(e){t.fire(new un(\"mouseout\",t,e))}),r.addEventListener(n,\"mousedown\",function(i){a=!0,o=r.mousePos(n,i);var s=new un(\"mousedown\",t,i);t.fire(s),s.defaultPrevented||(e.interactive&&!t.doubleClickZoom.isActive()&&t.stop(),t.boxZoom.onMouseDown(i),t.boxZoom.isActive()||t.dragPan.isActive()||t.dragRotate.onMouseDown(i),t.boxZoom.isActive()||t.dragRotate.isActive()||t.dragPan.onMouseDown(i))}),r.addEventListener(n,\"mouseup\",function(e){var r=t.dragRotate.isActive();i&&!r&&t.fire(new un(\"contextmenu\",t,i)),i=null,a=!1,t.fire(new un(\"mouseup\",t,e))}),r.addEventListener(n,\"mousemove\",function(e){if(!t.dragPan.isActive()&&!t.dragRotate.isActive()){for(var r=e.target;r&&r!==n;)r=r.parentNode;r===n&&t.fire(new un(\"mousemove\",t,e))}}),r.addEventListener(n,\"mouseover\",function(e){for(var r=e.target;r&&r!==n;)r=r.parentNode;r===n&&t.fire(new un(\"mouseover\",t,e))}),r.addEventListener(n,\"touchstart\",function(r){var n=new hn(\"touchstart\",t,r);t.fire(n),n.defaultPrevented||(e.interactive&&t.stop(),t.boxZoom.isActive()||t.dragRotate.isActive()||t.dragPan.onTouchStart(r),t.touchZoomRotate.onStart(r),t.doubleClickZoom.onTouchStart(n))},{passive:!1}),r.addEventListener(n,\"touchmove\",function(e){t.fire(new hn(\"touchmove\",t,e))},{passive:!1}),r.addEventListener(n,\"touchend\",function(e){t.fire(new hn(\"touchend\",t,e))}),r.addEventListener(n,\"touchcancel\",function(e){t.fire(new hn(\"touchcancel\",t,e))}),r.addEventListener(n,\"click\",function(i){var a=r.mousePos(n,i);(a.equals(o)||a.dist(o)<e.clickTolerance)&&t.fire(new un(\"click\",t,i))}),r.addEventListener(n,\"dblclick\",function(e){var r=new un(\"dblclick\",t,e);t.fire(r),r.defaultPrevented||t.doubleClickZoom.onDblClick(r)}),r.addEventListener(n,\"contextmenu\",function(e){var r=t.dragRotate.isActive();a||r?a&&(i=e):t.fire(new un(\"contextmenu\",t,e)),(t.dragRotate.isEnabled()||t.listens(\"contextmenu\"))&&e.preventDefault()}),r.addEventListener(n,\"wheel\",function(r){e.interactive&&t.stop();var n=new fn(\"wheel\",t,r);t.fire(n),n.defaultPrevented||t.scrollZoom.onWheel(r)},{passive:!1})}(this,e),this._hash=e.hash&&(new cn).addTo(this),this._hash&&this._hash._onHashChange()||(this.jumpTo({center:e.center,zoom:e.zoom,bearing:e.bearing,pitch:e.pitch}),e.bounds&&(this.resize(),this.fitBounds(e.bounds,t.extend({},e.fitBoundsOptions,{duration:0})))),this.resize(),this._localIdeographFontFamily=e.localIdeographFontFamily,e.style&&this.setStyle(e.style,{localIdeographFontFamily:e.localIdeographFontFamily}),e.attributionControl&&this.addControl(new Mn({customAttribution:e.customAttribution})),this.addControl(new Sn,e.logoPosition),this.on(\"style.load\",function(){i.transform.unmodified&&i.jumpTo(i.style.stylesheet)}),this.on(\"data\",function(e){i._update(\"style\"===e.dataType),i.fire(new t.Event(e.dataType+\"data\",e))}),this.on(\"dataloading\",function(e){i.fire(new t.Event(e.dataType+\"dataloading\",e))})}n&&(i.__proto__=n),i.prototype=Object.create(n&&n.prototype),i.prototype.constructor=i;var a={showTileBoundaries:{configurable:!0},showCollisionBoxes:{configurable:!0},showOverdrawInspector:{configurable:!0},repaint:{configurable:!0},vertices:{configurable:!0}};return i.prototype._getMapId=function(){return this._mapId},i.prototype.addControl=function(e,r){if(void 0===r&&e.getDefaultPosition&&(r=e.getDefaultPosition()),void 0===r&&(r=\"top-right\"),!e||!e.onAdd)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.addControl(). Argument must be a control with onAdd and onRemove methods.\")));var n=e.onAdd(this);this._controls.push(e);var i=this._controlPositions[r];return-1!==r.indexOf(\"bottom\")?i.insertBefore(n,i.firstChild):i.appendChild(n),this},i.prototype.removeControl=function(e){if(!e||!e.onRemove)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.removeControl(). Argument must be a control with onAdd and onRemove methods.\")));var r=this._controls.indexOf(e);return r>-1&&this._controls.splice(r,1),e.onRemove(this),this},i.prototype.resize=function(e){var r=this._containerDimensions(),n=r[0],i=r[1];return this._resizeCanvas(n,i),this.transform.resize(n,i),this.painter.resize(n,i),this.fire(new t.Event(\"movestart\",e)).fire(new t.Event(\"move\",e)).fire(new t.Event(\"resize\",e)).fire(new t.Event(\"moveend\",e)),this},i.prototype.getBounds=function(){return this.transform.getBounds()},i.prototype.getMaxBounds=function(){return this.transform.getMaxBounds()},i.prototype.setMaxBounds=function(e){return this.transform.setMaxBounds(t.LngLatBounds.convert(e)),this._update()},i.prototype.setMinZoom=function(t){if((t=null==t?0:t)>=0&&t<=this.transform.maxZoom)return this.transform.minZoom=t,this._update(),this.getZoom()<t&&this.setZoom(t),this;throw new Error(\"minZoom must be between 0 and the current maxZoom, inclusive\")},i.prototype.getMinZoom=function(){return this.transform.minZoom},i.prototype.setMaxZoom=function(t){if((t=null==t?22:t)>=this.transform.minZoom)return this.transform.maxZoom=t,this._update(),this.getZoom()>t&&this.setZoom(t),this;throw new Error(\"maxZoom must be greater than the current minZoom\")},i.prototype.getRenderWorldCopies=function(){return this.transform.renderWorldCopies},i.prototype.setRenderWorldCopies=function(t){return this.transform.renderWorldCopies=t,this._update()},i.prototype.getMaxZoom=function(){return this.transform.maxZoom},i.prototype.project=function(e){return this.transform.locationPoint(t.LngLat.convert(e))},i.prototype.unproject=function(e){return this.transform.pointLocation(t.Point.convert(e))},i.prototype.isMoving=function(){return this._moving||this.dragPan.isActive()||this.dragRotate.isActive()||this.scrollZoom.isActive()},i.prototype.isZooming=function(){return this._zooming||this.scrollZoom.isZooming()},i.prototype.isRotating=function(){return this._rotating||this.dragRotate.isActive()},i.prototype.on=function(t,e,r){var i=this;if(void 0===r)return n.prototype.on.call(this,t,e);var a=function(){var n;if(\"mouseenter\"===t||\"mouseover\"===t){var a=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){var o=i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[];o.length?a||(a=!0,r.call(i,new un(t,i,n.originalEvent,{features:o}))):a=!1},mouseout:function(){a=!1}}}}if(\"mouseleave\"===t||\"mouseout\"===t){var o=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){(i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[]).length?o=!0:o&&(o=!1,r.call(i,new un(t,i,n.originalEvent)))},mouseout:function(e){o&&(o=!1,r.call(i,new un(t,i,e.originalEvent)))}}}}return{layer:e,listener:r,delegates:(n={},n[t]=function(t){var n=i.getLayer(e)?i.queryRenderedFeatures(t.point,{layers:[e]}):[];n.length&&(t.features=n,r.call(i,t),delete t.features)},n)}}();for(var o in this._delegatedListeners=this._delegatedListeners||{},this._delegatedListeners[t]=this._delegatedListeners[t]||[],this._delegatedListeners[t].push(a),a.delegates)this.on(o,a.delegates[o]);return this},i.prototype.off=function(t,e,r){if(void 0===r)return n.prototype.off.call(this,t,e);if(this._delegatedListeners&&this._delegatedListeners[t])for(var i=this._delegatedListeners[t],a=0;a<i.length;a++){var o=i[a];if(o.layer===e&&o.listener===r){for(var s in o.delegates)this.off(s,o.delegates[s]);return i.splice(a,1),this}}return this},i.prototype.queryRenderedFeatures=function(e,r){if(!this.style)return[];var n;if(void 0!==r||void 0===e||e instanceof t.Point||Array.isArray(e)||(r=e,e=void 0),r=r||{},(e=e||[[0,0],[this.transform.width,this.transform.height]])instanceof t.Point||\"number\"==typeof e[0])n=[t.Point.convert(e)];else{var i=t.Point.convert(e[0]),a=t.Point.convert(e[1]);n=[i,new t.Point(a.x,i.y),a,new t.Point(i.x,a.y),i]}return this.style.queryRenderedFeatures(n,r,this.transform)},i.prototype.querySourceFeatures=function(t,e){return this.style.querySourceFeatures(t,e)},i.prototype.setStyle=function(e,r){return!1!==(r=t.extend({},{localIdeographFontFamily:Pn.localIdeographFontFamily},r)).diff&&r.localIdeographFontFamily===this._localIdeographFontFamily&&this.style&&e?(this._diffStyle(e,r),this):(this._localIdeographFontFamily=r.localIdeographFontFamily,this._updateStyle(e,r))},i.prototype._updateStyle=function(t,e){return this.style&&(this.style.setEventedParent(null),this.style._remove()),t?(this.style=new De(this,e||{}),this.style.setEventedParent(this,{style:this.style}),\"string\"==typeof t?this.style.loadURL(t):this.style.loadJSON(t),this):(delete this.style,this)},i.prototype._diffStyle=function(e,r){var n=this;if(\"string\"==typeof e){var i=this._requestManager.normalizeStyleURL(e),a=this._requestManager.transformRequest(i,t.ResourceType.Style);t.getJSON(a,function(e,i){e?n.fire(new t.ErrorEvent(e)):i&&n._updateDiff(i,r)})}else\"object\"==typeof e&&this._updateDiff(e,r)},i.prototype._updateDiff=function(e,r){try{this.style.setState(e)&&this._update(!0)}catch(n){t.warnOnce(\"Unable to perform style diff: \"+(n.message||n.error||n)+\".  Rebuilding the style from scratch.\"),this._updateStyle(e,r)}},i.prototype.getStyle=function(){if(this.style)return this.style.serialize()},i.prototype.isStyleLoaded=function(){return this.style?this.style.loaded():t.warnOnce(\"There is no style added to the map.\")},i.prototype.addSource=function(t,e){return this.style.addSource(t,e),this._update(!0)},i.prototype.isSourceLoaded=function(e){var r=this.style&&this.style.sourceCaches[e];if(void 0!==r)return r.loaded();this.fire(new t.ErrorEvent(new Error(\"There is no source with ID '\"+e+\"'\")))},i.prototype.areTilesLoaded=function(){var t=this.style&&this.style.sourceCaches;for(var e in t){var r=t[e]._tiles;for(var n in r){var i=r[n];if(\"loaded\"!==i.state&&\"errored\"!==i.state)return!1}}return!0},i.prototype.addSourceType=function(t,e,r){return this.style.addSourceType(t,e,r)},i.prototype.removeSource=function(t){return this.style.removeSource(t),this._update(!0)},i.prototype.getSource=function(t){return this.style.getSource(t)},i.prototype.addImage=function(e,r,n){void 0===n&&(n={});var i=n.pixelRatio;void 0===i&&(i=1);var a=n.sdf;if(void 0===a&&(a=!1),r instanceof Cn){var o=t.browser.getImageData(r),s=o.width,l=o.height,c=o.data;this.style.addImage(e,{data:new t.RGBAImage({width:s,height:l},c),pixelRatio:i,sdf:a,version:0})}else{if(void 0===r.width||void 0===r.height)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.addImage(). The second argument must be an `HTMLImageElement`, `ImageData`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));var u=r.width,h=r.height,f=r.data,p=r;this.style.addImage(e,{data:new t.RGBAImage({width:u,height:h},new Uint8Array(f)),pixelRatio:i,sdf:a,version:0,userImage:p}),p.onAdd&&p.onAdd(this,e)}},i.prototype.updateImage=function(e,r){var n=this.style.getImage(e);if(!n)return this.fire(new t.ErrorEvent(new Error(\"The map has no image with that id. If you are adding a new image use `map.addImage(...)` instead.\")));var i=r instanceof Cn?t.browser.getImageData(r):r,a=i.width,o=i.height,s=i.data;if(void 0===a||void 0===o)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.updateImage(). The second argument must be an `HTMLImageElement`, `ImageData`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));if(a!==n.data.width||o!==n.data.height)return this.fire(new t.ErrorEvent(new Error(\"The width and height of the updated image must be that same as the previous version of the image\")));var l=!(r instanceof Cn);n.data.replace(s,l),this.style.updateImage(e,n)},i.prototype.hasImage=function(e){return e?!!this.style.getImage(e):(this.fire(new t.ErrorEvent(new Error(\"Missing required image id\"))),!1)},i.prototype.removeImage=function(t){this.style.removeImage(t)},i.prototype.loadImage=function(e,r){t.getImage(this._requestManager.transformRequest(e,t.ResourceType.Image),r)},i.prototype.listImages=function(){return this.style.listImages()},i.prototype.addLayer=function(t,e){return this.style.addLayer(t,e),this._update(!0)},i.prototype.moveLayer=function(t,e){return this.style.moveLayer(t,e),this._update(!0)},i.prototype.removeLayer=function(t){return this.style.removeLayer(t),this._update(!0)},i.prototype.getLayer=function(t){return this.style.getLayer(t)},i.prototype.setFilter=function(t,e,r){return void 0===r&&(r={}),this.style.setFilter(t,e,r),this._update(!0)},i.prototype.setLayerZoomRange=function(t,e,r){return this.style.setLayerZoomRange(t,e,r),this._update(!0)},i.prototype.getFilter=function(t){return this.style.getFilter(t)},i.prototype.setPaintProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setPaintProperty(t,e,r,n),this._update(!0)},i.prototype.getPaintProperty=function(t,e){return this.style.getPaintProperty(t,e)},i.prototype.setLayoutProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setLayoutProperty(t,e,r,n),this._update(!0)},i.prototype.getLayoutProperty=function(t,e){return this.style.getLayoutProperty(t,e)},i.prototype.setLight=function(t,e){return void 0===e&&(e={}),this.style.setLight(t,e),this._update(!0)},i.prototype.getLight=function(){return this.style.getLight()},i.prototype.setFeatureState=function(t,e){return this.style.setFeatureState(t,e),this._update()},i.prototype.removeFeatureState=function(t,e){return this.style.removeFeatureState(t,e),this._update()},i.prototype.getFeatureState=function(t){return this.style.getFeatureState(t)},i.prototype.getContainer=function(){return this._container},i.prototype.getCanvasContainer=function(){return this._canvasContainer},i.prototype.getCanvas=function(){return this._canvas},i.prototype._containerDimensions=function(){var t=0,e=0;return this._container&&(t=this._container.clientWidth||400,e=this._container.clientHeight||300),[t,e]},i.prototype._detectMissingCSS=function(){\"rgb(250, 128, 114)\"!==t.window.getComputedStyle(this._missingCSSCanary).getPropertyValue(\"background-color\")&&t.warnOnce(\"This page appears to be missing CSS declarations for Mapbox GL JS, which may cause the map to display incorrectly. Please ensure your page includes mapbox-gl.css, as described in https://www.mapbox.com/mapbox-gl-js/api/.\")},i.prototype._setupContainer=function(){var t=this._container;t.classList.add(\"mapboxgl-map\"),(this._missingCSSCanary=r.create(\"div\",\"mapboxgl-canary\",t)).style.visibility=\"hidden\",this._detectMissingCSS();var e=this._canvasContainer=r.create(\"div\",\"mapboxgl-canvas-container\",t);this._interactive&&e.classList.add(\"mapboxgl-interactive\"),this._canvas=r.create(\"canvas\",\"mapboxgl-canvas\",e),this._canvas.style.position=\"absolute\",this._canvas.addEventListener(\"webglcontextlost\",this._contextLost,!1),this._canvas.addEventListener(\"webglcontextrestored\",this._contextRestored,!1),this._canvas.setAttribute(\"tabindex\",\"0\"),this._canvas.setAttribute(\"aria-label\",\"Map\");var n=this._containerDimensions();this._resizeCanvas(n[0],n[1]);var i=this._controlContainer=r.create(\"div\",\"mapboxgl-control-container\",t),a=this._controlPositions={};[\"top-left\",\"top-right\",\"bottom-left\",\"bottom-right\"].forEach(function(t){a[t]=r.create(\"div\",\"mapboxgl-ctrl-\"+t,i)})},i.prototype._resizeCanvas=function(e,r){var n=t.window.devicePixelRatio||1;this._canvas.width=n*e,this._canvas.height=n*r,this._canvas.style.width=e+\"px\",this._canvas.style.height=r+\"px\"},i.prototype._setupPainter=function(){var r=t.extend({},e.webGLContextAttributes,{failIfMajorPerformanceCaveat:this._failIfMajorPerformanceCaveat,preserveDrawingBuffer:this._preserveDrawingBuffer,antialias:this._antialias||!1}),n=this._canvas.getContext(\"webgl\",r)||this._canvas.getContext(\"experimental-webgl\",r);n?(this.painter=new rn(n,this.transform),t.webpSupported.testSupport(n)):this.fire(new t.ErrorEvent(new Error(\"Failed to initialize WebGL\")))},i.prototype._contextLost=function(e){e.preventDefault(),this._frame&&(this._frame.cancel(),this._frame=null),this.fire(new t.Event(\"webglcontextlost\",{originalEvent:e}))},i.prototype._contextRestored=function(e){this._setupPainter(),this.resize(),this._update(),this.fire(new t.Event(\"webglcontextrestored\",{originalEvent:e}))},i.prototype.loaded=function(){return!this._styleDirty&&!this._sourcesDirty&&!!this.style&&this.style.loaded()},i.prototype._update=function(t){return this.style?(this._styleDirty=this._styleDirty||t,this._sourcesDirty=!0,this.triggerRepaint(),this):this},i.prototype._requestRenderFrame=function(t){return this._update(),this._renderTaskQueue.add(t)},i.prototype._cancelRenderFrame=function(t){this._renderTaskQueue.remove(t)},i.prototype._render=function(){this.painter.context.setDirty(),this.painter.setBaseState(),this._renderTaskQueue.run();var e=!1;if(this.style&&this._styleDirty){this._styleDirty=!1;var r=this.transform.zoom,n=t.browser.now();this.style.zoomHistory.update(r,n);var i=new t.EvaluationParameters(r,{now:n,fadeDuration:this._fadeDuration,zoomHistory:this.style.zoomHistory,transition:this.style.getTransition()}),a=i.crossFadingFactor();1===a&&a===this._crossFadingFactor||(e=!0,this._crossFadingFactor=a),this.style.update(i)}return this.style&&this._sourcesDirty&&(this._sourcesDirty=!1,this.style._updateSources(this.transform)),this._placementDirty=this.style&&this.style._updatePlacement(this.painter.transform,this.showCollisionBoxes,this._fadeDuration,this._crossSourceCollisions),this.painter.render(this.style,{showTileBoundaries:this.showTileBoundaries,showOverdrawInspector:this._showOverdrawInspector,rotating:this.isRotating(),zooming:this.isZooming(),moving:this.isMoving(),fadeDuration:this._fadeDuration}),this.fire(new t.Event(\"render\")),this.loaded()&&!this._loaded&&(this._loaded=!0,this.fire(new t.Event(\"load\"))),this.style&&(this.style.hasTransitions()||e)&&(this._styleDirty=!0),this.style&&!this._placementDirty&&this.style._releaseSymbolFadeTiles(),this._sourcesDirty||this._repaint||this._styleDirty||this._placementDirty?this.triggerRepaint():!this.isMoving()&&this.loaded()&&this.fire(new t.Event(\"idle\")),this},i.prototype.remove=function(){this._hash&&this._hash.remove();for(var e=0,r=this._controls;e<r.length;e+=1)r[e].onRemove(this);this._controls=[],this._frame&&(this._frame.cancel(),this._frame=null),this._renderTaskQueue.clear(),this.setStyle(null),void 0!==t.window&&(t.window.removeEventListener(\"resize\",this._onWindowResize,!1),t.window.removeEventListener(\"online\",this._onWindowOnline,!1));var n=this.painter.context.gl.getExtension(\"WEBGL_lose_context\");n&&n.loseContext(),zn(this._canvasContainer),zn(this._controlContainer),zn(this._missingCSSCanary),this._container.classList.remove(\"mapboxgl-map\"),this.fire(new t.Event(\"remove\"))},i.prototype.triggerRepaint=function(){var e=this;this.style&&!this._frame&&(this._frame=t.browser.frame(function(){e._frame=null,e._render()}))},i.prototype._onWindowOnline=function(){this._update()},i.prototype._onWindowResize=function(){this._trackResize&&this.resize()._update()},a.showTileBoundaries.get=function(){return!!this._showTileBoundaries},a.showTileBoundaries.set=function(t){this._showTileBoundaries!==t&&(this._showTileBoundaries=t,this._update())},a.showCollisionBoxes.get=function(){return!!this._showCollisionBoxes},a.showCollisionBoxes.set=function(t){this._showCollisionBoxes!==t&&(this._showCollisionBoxes=t,t?this.style._generateCollisionBoxes():this._update())},a.showOverdrawInspector.get=function(){return!!this._showOverdrawInspector},a.showOverdrawInspector.set=function(t){this._showOverdrawInspector!==t&&(this._showOverdrawInspector=t,this._update())},a.repaint.get=function(){return!!this._repaint},a.repaint.set=function(t){this._repaint!==t&&(this._repaint=t,this.triggerRepaint())},a.vertices.get=function(){return!!this._vertices},a.vertices.set=function(t){this._vertices=t,this._update()},i.prototype._setCacheLimits=function(e,r){t.setCacheLimits(e,r)},Object.defineProperties(i.prototype,a),i}(An);function zn(t){t.parentNode&&t.parentNode.removeChild(t)}var In={showCompass:!0,showZoom:!0},Dn=function(e){var n=this;this.options=t.extend({},In,e),this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),this._container.addEventListener(\"contextmenu\",function(t){return t.preventDefault()}),this.options.showZoom&&(t.bindAll([\"_updateZoomButtons\"],this),this._zoomInButton=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-zoom-in\",\"Zoom in\",function(){return n._map.zoomIn()}),this._zoomOutButton=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-zoom-out\",\"Zoom out\",function(){return n._map.zoomOut()})),this.options.showCompass&&(t.bindAll([\"_rotateCompassArrow\"],this),this._compass=this._createButton(\"mapboxgl-ctrl-icon mapboxgl-ctrl-compass\",\"Reset bearing to north\",function(){return n._map.resetNorth()}),this._compassArrow=r.create(\"span\",\"mapboxgl-ctrl-compass-arrow\",this._compass))};function Rn(e,r,n){if(e=new t.LngLat(e.lng,e.lat),r){var i=new t.LngLat(e.lng-360,e.lat),a=new t.LngLat(e.lng+360,e.lat),o=n.locationPoint(e).distSqr(r);n.locationPoint(i).distSqr(r)<o?e=i:n.locationPoint(a).distSqr(r)<o&&(e=a)}for(;Math.abs(e.lng-n.center.lng)>180;){var s=n.locationPoint(e);if(s.x>=0&&s.y>=0&&s.x<=n.width&&s.y<=n.height)break;e.lng>n.center.lng?e.lng-=360:e.lng+=360}return e}Dn.prototype._updateZoomButtons=function(){var t=this._map.getZoom();this._zoomInButton.classList.toggle(\"mapboxgl-ctrl-icon-disabled\",t===this._map.getMaxZoom()),this._zoomOutButton.classList.toggle(\"mapboxgl-ctrl-icon-disabled\",t===this._map.getMinZoom())},Dn.prototype._rotateCompassArrow=function(){var t=\"rotate(\"+this._map.transform.angle*(180/Math.PI)+\"deg)\";this._compassArrow.style.transform=t},Dn.prototype.onAdd=function(t){return this._map=t,this.options.showZoom&&(this._map.on(\"zoom\",this._updateZoomButtons),this._updateZoomButtons()),this.options.showCompass&&(this._map.on(\"rotate\",this._rotateCompassArrow),this._rotateCompassArrow(),this._handler=new vn(t,{button:\"left\",element:this._compass}),r.addEventListener(this._compass,\"mousedown\",this._handler.onMouseDown),this._handler.enable()),this._container},Dn.prototype.onRemove=function(){r.remove(this._container),this.options.showZoom&&this._map.off(\"zoom\",this._updateZoomButtons),this.options.showCompass&&(this._map.off(\"rotate\",this._rotateCompassArrow),r.removeEventListener(this._compass,\"mousedown\",this._handler.onMouseDown),this._handler.disable(),delete this._handler),delete this._map},Dn.prototype._createButton=function(t,e,n){var i=r.create(\"button\",t,this._container);return i.type=\"button\",i.title=e,i.setAttribute(\"aria-label\",e),i.addEventListener(\"click\",n),i};var Fn={center:\"translate(-50%,-50%)\",top:\"translate(-50%,0)\",\"top-left\":\"translate(0,0)\",\"top-right\":\"translate(-100%,0)\",bottom:\"translate(-50%,-100%)\",\"bottom-left\":\"translate(0,-100%)\",\"bottom-right\":\"translate(-100%,-100%)\",left:\"translate(0,-50%)\",right:\"translate(-100%,-50%)\"};function Bn(t,e,r){var n=t.classList;for(var i in Fn)n.remove(\"mapboxgl-\"+r+\"-anchor-\"+i);n.add(\"mapboxgl-\"+r+\"-anchor-\"+e)}var Nn,jn=function(e){function n(n,i){if(e.call(this),(n instanceof t.window.HTMLElement||i)&&(n=t.extend({element:n},i)),t.bindAll([\"_update\",\"_onMove\",\"_onUp\",\"_addDragHandler\",\"_onMapClick\"],this),this._anchor=n&&n.anchor||\"center\",this._color=n&&n.color||\"#3FB1CE\",this._draggable=n&&n.draggable||!1,this._state=\"inactive\",n&&n.element)this._element=n.element,this._offset=t.Point.convert(n&&n.offset||[0,0]);else{this._defaultMarker=!0,this._element=r.create(\"div\");var a=r.createNS(\"http://www.w3.org/2000/svg\",\"svg\");a.setAttributeNS(null,\"display\",\"block\"),a.setAttributeNS(null,\"height\",\"41px\"),a.setAttributeNS(null,\"width\",\"27px\"),a.setAttributeNS(null,\"viewBox\",\"0 0 27 41\");var o=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");o.setAttributeNS(null,\"stroke\",\"none\"),o.setAttributeNS(null,\"stroke-width\",\"1\"),o.setAttributeNS(null,\"fill\",\"none\"),o.setAttributeNS(null,\"fill-rule\",\"evenodd\");var s=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");s.setAttributeNS(null,\"fill-rule\",\"nonzero\");var l=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");l.setAttributeNS(null,\"transform\",\"translate(3.0, 29.0)\"),l.setAttributeNS(null,\"fill\",\"#000000\");for(var c=0,u=[{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"9.5\",ry:\"4.77275007\"},{rx:\"8.5\",ry:\"4.29549936\"},{rx:\"7.5\",ry:\"3.81822308\"},{rx:\"6.5\",ry:\"3.34094679\"},{rx:\"5.5\",ry:\"2.86367051\"},{rx:\"4.5\",ry:\"2.38636864\"}];c<u.length;c+=1){var h=u[c],f=r.createNS(\"http://www.w3.org/2000/svg\",\"ellipse\");f.setAttributeNS(null,\"opacity\",\"0.04\"),f.setAttributeNS(null,\"cx\",\"10.5\"),f.setAttributeNS(null,\"cy\",\"5.80029008\"),f.setAttributeNS(null,\"rx\",h.rx),f.setAttributeNS(null,\"ry\",h.ry),l.appendChild(f)}var p=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");p.setAttributeNS(null,\"fill\",this._color);var d=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");d.setAttributeNS(null,\"d\",\"M27,13.5 C27,19.074644 20.250001,27.000002 14.75,34.500002 C14.016665,35.500004 12.983335,35.500004 12.25,34.500002 C6.7499993,27.000002 0,19.222562 0,13.5 C0,6.0441559 6.0441559,0 13.5,0 C20.955844,0 27,6.0441559 27,13.5 Z\"),p.appendChild(d);var g=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");g.setAttributeNS(null,\"opacity\",\"0.25\"),g.setAttributeNS(null,\"fill\",\"#000000\");var v=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");v.setAttributeNS(null,\"d\",\"M13.5,0 C6.0441559,0 0,6.0441559 0,13.5 C0,19.222562 6.7499993,27 12.25,34.5 C13,35.522727 14.016664,35.500004 14.75,34.5 C20.250001,27 27,19.074644 27,13.5 C27,6.0441559 20.955844,0 13.5,0 Z M13.5,1 C20.415404,1 26,6.584596 26,13.5 C26,15.898657 24.495584,19.181431 22.220703,22.738281 C19.945823,26.295132 16.705119,30.142167 13.943359,33.908203 C13.743445,34.180814 13.612715,34.322738 13.5,34.441406 C13.387285,34.322738 13.256555,34.180814 13.056641,33.908203 C10.284481,30.127985 7.4148684,26.314159 5.015625,22.773438 C2.6163816,19.232715 1,15.953538 1,13.5 C1,6.584596 6.584596,1 13.5,1 Z\"),g.appendChild(v);var m=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");m.setAttributeNS(null,\"transform\",\"translate(6.0, 7.0)\"),m.setAttributeNS(null,\"fill\",\"#FFFFFF\");var y=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");y.setAttributeNS(null,\"transform\",\"translate(8.0, 8.0)\");var x=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");x.setAttributeNS(null,\"fill\",\"#000000\"),x.setAttributeNS(null,\"opacity\",\"0.25\"),x.setAttributeNS(null,\"cx\",\"5.5\"),x.setAttributeNS(null,\"cy\",\"5.5\"),x.setAttributeNS(null,\"r\",\"5.4999962\");var b=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");b.setAttributeNS(null,\"fill\",\"#FFFFFF\"),b.setAttributeNS(null,\"cx\",\"5.5\"),b.setAttributeNS(null,\"cy\",\"5.5\"),b.setAttributeNS(null,\"r\",\"5.4999962\"),y.appendChild(x),y.appendChild(b),s.appendChild(l),s.appendChild(p),s.appendChild(g),s.appendChild(m),s.appendChild(y),a.appendChild(s),this._element.appendChild(a),this._offset=t.Point.convert(n&&n.offset||[0,-14])}this._element.classList.add(\"mapboxgl-marker\"),this._element.addEventListener(\"dragstart\",function(t){t.preventDefault()}),Bn(this._element,this._anchor,\"marker\"),this._popup=null}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.addTo=function(t){return this.remove(),this._map=t,t.getCanvasContainer().appendChild(this._element),t.on(\"move\",this._update),t.on(\"moveend\",this._update),this.setDraggable(this._draggable),this._update(),this._map.on(\"click\",this._onMapClick),this},n.prototype.remove=function(){return this._map&&(this._map.off(\"click\",this._onMapClick),this._map.off(\"move\",this._update),this._map.off(\"moveend\",this._update),this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler),this._map.off(\"mouseup\",this._onUp),this._map.off(\"touchend\",this._onUp),delete this._map),r.remove(this._element),this._popup&&this._popup.remove(),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._popup&&this._popup.setLngLat(this._lngLat),this._update(),this},n.prototype.getElement=function(){return this._element},n.prototype.setPopup=function(t){if(this._popup&&(this._popup.remove(),this._popup=null),t){if(!(\"offset\"in t.options)){var e=Math.sqrt(Math.pow(13.5,2)/2);t.options.offset=this._defaultMarker?{top:[0,0],\"top-left\":[0,0],\"top-right\":[0,0],bottom:[0,-38.1],\"bottom-left\":[e,-1*(24.6+e)],\"bottom-right\":[-e,-1*(24.6+e)],left:[13.5,-24.6],right:[-13.5,-24.6]}:this._offset}this._popup=t,this._lngLat&&this._popup.setLngLat(this._lngLat)}return this},n.prototype._onMapClick=function(t){var e=t.originalEvent.target,r=this._element;this._popup&&(e===r||r.contains(e))&&this.togglePopup()},n.prototype.getPopup=function(){return this._popup},n.prototype.togglePopup=function(){var t=this._popup;return t?(t.isOpen()?t.remove():t.addTo(this._map),this):this},n.prototype._update=function(t){this._map&&(this._map.transform.renderWorldCopies&&(this._lngLat=Rn(this._lngLat,this._pos,this._map.transform)),this._pos=this._map.project(this._lngLat)._add(this._offset),t&&\"moveend\"!==t.type||(this._pos=this._pos.round()),r.setTransform(this._element,Fn[this._anchor]+\" translate(\"+this._pos.x+\"px, \"+this._pos.y+\"px)\"))},n.prototype.getOffset=function(){return this._offset},n.prototype.setOffset=function(e){return this._offset=t.Point.convert(e),this._update(),this},n.prototype._onMove=function(e){this._pos=e.point.sub(this._positionDelta),this._lngLat=this._map.unproject(this._pos),this.setLngLat(this._lngLat),this._element.style.pointerEvents=\"none\",\"pending\"===this._state&&(this._state=\"active\",this.fire(new t.Event(\"dragstart\"))),this.fire(new t.Event(\"drag\"))},n.prototype._onUp=function(){this._element.style.pointerEvents=\"auto\",this._positionDelta=null,this._map.off(\"mousemove\",this._onMove),this._map.off(\"touchmove\",this._onMove),\"active\"===this._state&&this.fire(new t.Event(\"dragend\")),this._state=\"inactive\"},n.prototype._addDragHandler=function(t){this._element.contains(t.originalEvent.target)&&(t.preventDefault(),this._positionDelta=t.point.sub(this._pos).add(this._offset),this._state=\"pending\",this._map.on(\"mousemove\",this._onMove),this._map.on(\"touchmove\",this._onMove),this._map.once(\"mouseup\",this._onUp),this._map.once(\"touchend\",this._onUp))},n.prototype.setDraggable=function(t){return this._draggable=!!t,this._map&&(t?(this._map.on(\"mousedown\",this._addDragHandler),this._map.on(\"touchstart\",this._addDragHandler)):(this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler))),this},n.prototype.isDraggable=function(){return this._draggable},n}(t.Evented),Un={positionOptions:{enableHighAccuracy:!1,maximumAge:0,timeout:6e3},fitBoundsOptions:{maxZoom:15},trackUserLocation:!1,showUserLocation:!0},Vn=function(e){function n(r){e.call(this),this.options=t.extend({},Un,r),t.bindAll([\"_onSuccess\",\"_onError\",\"_finish\",\"_setupUI\",\"_updateCamera\",\"_updateMarker\"],this)}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.onAdd=function(e){var n;return this._map=e,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),n=this._setupUI,void 0!==Nn?n(Nn):void 0!==t.window.navigator.permissions?t.window.navigator.permissions.query({name:\"geolocation\"}).then(function(t){Nn=\"denied\"!==t.state,n(Nn)}):(Nn=!!t.window.navigator.geolocation,n(Nn)),this._container},n.prototype.onRemove=function(){void 0!==this._geolocationWatchID&&(t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0),this.options.showUserLocation&&this._userLocationDotMarker&&this._userLocationDotMarker.remove(),r.remove(this._container),this._map=void 0},n.prototype._onSuccess=function(e){if(this.options.trackUserLocation)switch(this._lastKnownPosition=e,this._watchState){case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"BACKGROUND\":case\"BACKGROUND_ERROR\":this._watchState=\"BACKGROUND\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\")}this.options.showUserLocation&&\"OFF\"!==this._watchState&&this._updateMarker(e),this.options.trackUserLocation&&\"ACTIVE_LOCK\"!==this._watchState||this._updateCamera(e),this.options.showUserLocation&&this._dotElement.classList.remove(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"geolocate\",e)),this._finish()},n.prototype._updateCamera=function(e){var r=new t.LngLat(e.coords.longitude,e.coords.latitude),n=e.coords.accuracy,i=this._map.getBearing(),a=t.extend({bearing:i},this.options.fitBoundsOptions);this._map.fitBounds(r.toBounds(n),a,{geolocateSource:!0})},n.prototype._updateMarker=function(t){t?this._userLocationDotMarker.setLngLat([t.coords.longitude,t.coords.latitude]).addTo(this._map):this._userLocationDotMarker.remove()},n.prototype._onError=function(e){if(this.options.trackUserLocation)if(1===e.code)this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),void 0!==this._geolocationWatchID&&this._clearWatch();else switch(this._watchState){case\"WAITING_ACTIVE\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"ACTIVE_LOCK\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\");break;case\"BACKGROUND\":this._watchState=\"BACKGROUND_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\")}\"OFF\"!==this._watchState&&this.options.showUserLocation&&this._dotElement.classList.add(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"error\",e)),this._finish()},n.prototype._finish=function(){this._timeoutId&&clearTimeout(this._timeoutId),this._timeoutId=void 0},n.prototype._setupUI=function(e){var n=this;!1!==e?(this._container.addEventListener(\"contextmenu\",function(t){return t.preventDefault()}),this._geolocateButton=r.create(\"button\",\"mapboxgl-ctrl-icon mapboxgl-ctrl-geolocate\",this._container),this._geolocateButton.type=\"button\",this._geolocateButton.setAttribute(\"aria-label\",\"Geolocate\"),this.options.trackUserLocation&&(this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this._watchState=\"OFF\"),this.options.showUserLocation&&(this._dotElement=r.create(\"div\",\"mapboxgl-user-location-dot\"),this._userLocationDotMarker=new jn(this._dotElement),this.options.trackUserLocation&&(this._watchState=\"OFF\")),this._geolocateButton.addEventListener(\"click\",this.trigger.bind(this)),this._setup=!0,this.options.trackUserLocation&&this._map.on(\"movestart\",function(e){e.geolocateSource||\"ACTIVE_LOCK\"!==n._watchState||(n._watchState=\"BACKGROUND\",n._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\"),n._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),n.fire(new t.Event(\"trackuserlocationend\")))})):t.warnOnce(\"Geolocation support is not available, the GeolocateControl will not be visible.\")},n.prototype.trigger=function(){if(!this._setup)return t.warnOnce(\"Geolocate control triggered before added to a map\"),!1;if(this.options.trackUserLocation){switch(this._watchState){case\"OFF\":this._watchState=\"WAITING_ACTIVE\",this.fire(new t.Event(\"trackuserlocationstart\"));break;case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":case\"BACKGROUND_ERROR\":this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this.fire(new t.Event(\"trackuserlocationend\"));break;case\"BACKGROUND\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._lastKnownPosition&&this._updateCamera(this._lastKnownPosition),this.fire(new t.Event(\"trackuserlocationstart\"))}switch(this._watchState){case\"WAITING_ACTIVE\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_LOCK\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"BACKGROUND\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\");break;case\"BACKGROUND_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\")}\"OFF\"===this._watchState&&void 0!==this._geolocationWatchID?this._clearWatch():void 0===this._geolocationWatchID&&(this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"true\"),this._geolocationWatchID=t.window.navigator.geolocation.watchPosition(this._onSuccess,this._onError,this.options.positionOptions))}else t.window.navigator.geolocation.getCurrentPosition(this._onSuccess,this._onError,this.options.positionOptions),this._timeoutId=setTimeout(this._finish,1e4);return!0},n.prototype._clearWatch=function(){t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0,this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this.options.showUserLocation&&this._updateMarker(null)},n}(t.Evented),qn={maxWidth:100,unit:\"metric\"},Hn=function(e){this.options=t.extend({},qn,e),t.bindAll([\"_onMove\",\"setUnit\"],this)};function Gn(t,e,r){var n,i,a,o,s,l,c=r&&r.maxWidth||100,u=t._container.clientHeight/2,h=(n=t.unproject([0,u]),i=t.unproject([c,u]),a=Math.PI/180,o=n.lat*a,s=i.lat*a,l=Math.sin(o)*Math.sin(s)+Math.cos(o)*Math.cos(s)*Math.cos((i.lng-n.lng)*a),6371e3*Math.acos(Math.min(l,1)));if(r&&\"imperial\"===r.unit){var f=3.2808*h;f>5280?Yn(e,c,f/5280,\"mi\"):Yn(e,c,f,\"ft\")}else r&&\"nautical\"===r.unit?Yn(e,c,h/1852,\"nm\"):Yn(e,c,h,\"m\")}function Yn(t,e,r,n){var i,a,o,s=(i=r,(a=Math.pow(10,(\"\"+Math.floor(i)).length-1))*(o=(o=i/a)>=10?10:o>=5?5:o>=3?3:o>=2?2:o>=1?1:function(t){var e=Math.pow(10,Math.ceil(-Math.log(t)/Math.LN10));return Math.round(t*e)/e}(o))),l=s/r;\"m\"===n&&s>=1e3&&(s/=1e3,n=\"km\"),t.style.width=e*l+\"px\",t.innerHTML=s+n}Hn.prototype.getDefaultPosition=function(){return\"bottom-left\"},Hn.prototype._onMove=function(){Gn(this._map,this._container,this.options)},Hn.prototype.onAdd=function(t){return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-scale\",t.getContainer()),this._map.on(\"move\",this._onMove),this._onMove(),this._container},Hn.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"move\",this._onMove),this._map=void 0},Hn.prototype.setUnit=function(t){this.options.unit=t,Gn(this._map,this._container,this.options)};var Wn=function(e){this._fullscreen=!1,e&&e.container&&(e.container instanceof t.window.HTMLElement?this._container=e.container:t.warnOnce(\"Full screen control 'container' must be a DOM element.\")),t.bindAll([\"_onClickFullscreen\",\"_changeIcon\"],this),\"onfullscreenchange\"in t.window.document?this._fullscreenchange=\"fullscreenchange\":\"onmozfullscreenchange\"in t.window.document?this._fullscreenchange=\"mozfullscreenchange\":\"onwebkitfullscreenchange\"in t.window.document?this._fullscreenchange=\"webkitfullscreenchange\":\"onmsfullscreenchange\"in t.window.document&&(this._fullscreenchange=\"MSFullscreenChange\"),this._className=\"mapboxgl-ctrl\"};Wn.prototype.onAdd=function(e){return this._map=e,this._container||(this._container=this._map.getContainer()),this._controlContainer=r.create(\"div\",this._className+\" mapboxgl-ctrl-group\"),this._checkFullscreenSupport()?this._setupUI():(this._controlContainer.style.display=\"none\",t.warnOnce(\"This device does not support fullscreen mode.\")),this._controlContainer},Wn.prototype.onRemove=function(){r.remove(this._controlContainer),this._map=null,t.window.document.removeEventListener(this._fullscreenchange,this._changeIcon)},Wn.prototype._checkFullscreenSupport=function(){return!!(t.window.document.fullscreenEnabled||t.window.document.mozFullScreenEnabled||t.window.document.msFullscreenEnabled||t.window.document.webkitFullscreenEnabled)},Wn.prototype._setupUI=function(){(this._fullscreenButton=r.create(\"button\",this._className+\"-icon \"+this._className+\"-fullscreen\",this._controlContainer)).type=\"button\",this._updateTitle(),this._fullscreenButton.addEventListener(\"click\",this._onClickFullscreen),t.window.document.addEventListener(this._fullscreenchange,this._changeIcon)},Wn.prototype._updateTitle=function(){var t=this._isFullscreen()?\"Exit fullscreen\":\"Enter fullscreen\";this._fullscreenButton.setAttribute(\"aria-label\",t),this._fullscreenButton.title=t},Wn.prototype._isFullscreen=function(){return this._fullscreen},Wn.prototype._changeIcon=function(){(t.window.document.fullscreenElement||t.window.document.mozFullScreenElement||t.window.document.webkitFullscreenElement||t.window.document.msFullscreenElement)===this._container!==this._fullscreen&&(this._fullscreen=!this._fullscreen,this._fullscreenButton.classList.toggle(this._className+\"-shrink\"),this._fullscreenButton.classList.toggle(this._className+\"-fullscreen\"),this._updateTitle())},Wn.prototype._onClickFullscreen=function(){this._isFullscreen()?t.window.document.exitFullscreen?t.window.document.exitFullscreen():t.window.document.mozCancelFullScreen?t.window.document.mozCancelFullScreen():t.window.document.msExitFullscreen?t.window.document.msExitFullscreen():t.window.document.webkitCancelFullScreen&&t.window.document.webkitCancelFullScreen():this._container.requestFullscreen?this._container.requestFullscreen():this._container.mozRequestFullScreen?this._container.mozRequestFullScreen():this._container.msRequestFullscreen?this._container.msRequestFullscreen():this._container.webkitRequestFullscreen&&this._container.webkitRequestFullscreen()};var Xn={closeButton:!0,closeOnClick:!0,className:\"\",maxWidth:\"240px\"},Zn=function(e){function n(r){e.call(this),this.options=t.extend(Object.create(Xn),r),t.bindAll([\"_update\",\"_onClickClose\",\"remove\"],this)}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.addTo=function(e){var r=this;return this._map=e,this.options.closeOnClick&&this._map.on(\"click\",this._onClickClose),this._map.on(\"remove\",this.remove),this._update(),this._trackPointer?(this._map.on(\"mousemove\",function(t){r._update(t.point)}),this._map.on(\"mouseup\",function(t){r._update(t.point)}),this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")):this._map.on(\"move\",this._update),this.fire(new t.Event(\"open\")),this},n.prototype.isOpen=function(){return!!this._map},n.prototype.remove=function(){return this._content&&r.remove(this._content),this._container&&(r.remove(this._container),delete this._container),this._map&&(this._map.off(\"move\",this._update),this._map.off(\"click\",this._onClickClose),this._map.off(\"remove\",this.remove),this._map.off(\"mousemove\"),delete this._map),this.fire(new t.Event(\"close\")),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._map&&(this._map.on(\"move\",this._update),this._map.off(\"mousemove\"),this._container.classList.remove(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.remove(\"mapboxgl-track-pointer\")),this._trackPointer=!1,this._update(),this},n.prototype.trackPointer=function(){var t=this;return this._trackPointer=!0,this._pos=null,this._map&&(this._map.off(\"move\",this._update),this._map.on(\"mousemove\",function(e){t._update(e.point)}),this._map.on(\"drag\",function(e){t._update(e.point)}),this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")),this},n.prototype.getElement=function(){return this._container},n.prototype.setText=function(e){return this.setDOMContent(t.window.document.createTextNode(e))},n.prototype.setHTML=function(e){var r,n=t.window.document.createDocumentFragment(),i=t.window.document.createElement(\"body\");for(i.innerHTML=e;r=i.firstChild;)n.appendChild(r);return this.setDOMContent(n)},n.prototype.getMaxWidth=function(){return this._container.style.maxWidth},n.prototype.setMaxWidth=function(t){return this.options.maxWidth=t,this._update(),this},n.prototype.setDOMContent=function(t){return this._createContent(),this._content.appendChild(t),this._update(),this},n.prototype._createContent=function(){this._content&&r.remove(this._content),this._content=r.create(\"div\",\"mapboxgl-popup-content\",this._container),this.options.closeButton&&(this._closeButton=r.create(\"button\",\"mapboxgl-popup-close-button\",this._content),this._closeButton.type=\"button\",this._closeButton.setAttribute(\"aria-label\",\"Close popup\"),this._closeButton.innerHTML=\"&#215;\",this._closeButton.addEventListener(\"click\",this._onClickClose))},n.prototype._update=function(e){var n=this,i=this._lngLat||this._trackPointer;if(this._map&&i&&this._content&&(this._container||(this._container=r.create(\"div\",\"mapboxgl-popup\",this._map.getContainer()),this._tip=r.create(\"div\",\"mapboxgl-popup-tip\",this._container),this._container.appendChild(this._content),this.options.className&&this.options.className.split(\" \").forEach(function(t){return n._container.classList.add(t)})),this.options.maxWidth&&this._container.style.maxWidth!==this.options.maxWidth&&(this._container.style.maxWidth=this.options.maxWidth),this._map.transform.renderWorldCopies&&!this._trackPointer&&(this._lngLat=Rn(this._lngLat,this._pos,this._map.transform)),!this._trackPointer||e)){var a=this._pos=this._trackPointer&&e?e:this._map.project(this._lngLat),o=this.options.anchor,s=function e(r){if(r){if(\"number\"==typeof r){var n=Math.round(Math.sqrt(.5*Math.pow(r,2)));return{center:new t.Point(0,0),top:new t.Point(0,r),\"top-left\":new t.Point(n,n),\"top-right\":new t.Point(-n,n),bottom:new t.Point(0,-r),\"bottom-left\":new t.Point(n,-n),\"bottom-right\":new t.Point(-n,-n),left:new t.Point(r,0),right:new t.Point(-r,0)}}if(r instanceof t.Point||Array.isArray(r)){var i=t.Point.convert(r);return{center:i,top:i,\"top-left\":i,\"top-right\":i,bottom:i,\"bottom-left\":i,\"bottom-right\":i,left:i,right:i}}return{center:t.Point.convert(r.center||[0,0]),top:t.Point.convert(r.top||[0,0]),\"top-left\":t.Point.convert(r[\"top-left\"]||[0,0]),\"top-right\":t.Point.convert(r[\"top-right\"]||[0,0]),bottom:t.Point.convert(r.bottom||[0,0]),\"bottom-left\":t.Point.convert(r[\"bottom-left\"]||[0,0]),\"bottom-right\":t.Point.convert(r[\"bottom-right\"]||[0,0]),left:t.Point.convert(r.left||[0,0]),right:t.Point.convert(r.right||[0,0])}}return e(new t.Point(0,0))}(this.options.offset);if(!o){var l,c=this._container.offsetWidth,u=this._container.offsetHeight;l=a.y+s.bottom.y<u?[\"top\"]:a.y>this._map.transform.height-u?[\"bottom\"]:[],a.x<c/2?l.push(\"left\"):a.x>this._map.transform.width-c/2&&l.push(\"right\"),o=0===l.length?\"bottom\":l.join(\"-\")}var h=a.add(s[o]).round();r.setTransform(this._container,Fn[o]+\" translate(\"+h.x+\"px,\"+h.y+\"px)\"),Bn(this._container,o,\"popup\")}},n.prototype._onClickClose=function(){this.remove()},n}(t.Evented),Jn={version:t.version,supported:e,setRTLTextPlugin:t.setRTLTextPlugin,Map:On,NavigationControl:Dn,GeolocateControl:Vn,AttributionControl:Mn,ScaleControl:Hn,FullscreenControl:Wn,Popup:Zn,Marker:jn,Style:De,LngLat:t.LngLat,LngLatBounds:t.LngLatBounds,Point:t.Point,MercatorCoordinate:t.MercatorCoordinate,Evented:t.Evented,config:t.config,get accessToken(){return t.config.ACCESS_TOKEN},set accessToken(e){t.config.ACCESS_TOKEN=e},get baseApiUrl(){return t.config.API_URL},set baseApiUrl(e){t.config.API_URL=e},get workerCount(){return zt.workerCount},set workerCount(t){zt.workerCount=t},get maxParallelImageRequests(){return t.config.MAX_PARALLEL_IMAGE_REQUESTS},set maxParallelImageRequests(e){t.config.MAX_PARALLEL_IMAGE_REQUESTS=e},clearStorage:function(e){t.clearTileCache(e)},workerUrl:\"\"};return Jn}),r},\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=i():(n=n||self).mapboxgl=i()},{}],427:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1<<t+1,r=new Array(e),n=0;n<e;++n)r[n]=a(t,n);return r};var n=t(\"convex-hull\");function i(t,e,r){for(var n=new Array(t),i=0;i<t;++i)n[i]=0,i===e&&(n[i]+=.5),i===r&&(n[i]+=.5);return n}function a(t,e){if(0===e||e===(1<<t+1)-1)return[];for(var r=[],a=[],o=0;o<=t;++o)if(e&1<<o){r.push(i(t,o-1,o-1)),a.push(null);for(var s=0;s<=t;++s)~e&1<<s&&(r.push(i(t,o-1,s-1)),a.push([o,s]))}var l=n(r),c=[];t:for(o=0;o<l.length;++o){var u=l[o],h=[];for(s=0;s<u.length;++s){if(!a[u[s]])continue t;h.push(a[u[s]].slice())}c.push(h)}return c}},{\"convex-hull\":130}],428:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"gl-mat4/create\"),a=t(\"gl-mat4/clone\"),o=t(\"gl-mat4/determinant\"),s=t(\"gl-mat4/invert\"),l=t(\"gl-mat4/transpose\"),c={length:t(\"gl-vec3/length\"),normalize:t(\"gl-vec3/normalize\"),dot:t(\"gl-vec3/dot\"),cross:t(\"gl-vec3/cross\")},u=i(),h=i(),f=[0,0,0,0],p=[[0,0,0],[0,0,0],[0,0,0]],d=[0,0,0];function g(t,e,r,n,i){t[0]=e[0]*n+r[0]*i,t[1]=e[1]*n+r[1]*i,t[2]=e[2]*n+r[2]*i}e.exports=function(t,e,r,i,v,m){if(e||(e=[0,0,0]),r||(r=[0,0,0]),i||(i=[0,0,0]),v||(v=[0,0,0,1]),m||(m=[0,0,0,1]),!n(u,t))return!1;if(a(h,u),h[3]=0,h[7]=0,h[11]=0,h[15]=1,Math.abs(o(h)<1e-8))return!1;var y,x,b,_,w,k,T,A=u[3],M=u[7],S=u[11],E=u[12],C=u[13],L=u[14],P=u[15];if(0!==A||0!==M||0!==S){if(f[0]=A,f[1]=M,f[2]=S,f[3]=P,!s(h,h))return!1;l(h,h),y=v,b=h,_=(x=f)[0],w=x[1],k=x[2],T=x[3],y[0]=b[0]*_+b[4]*w+b[8]*k+b[12]*T,y[1]=b[1]*_+b[5]*w+b[9]*k+b[13]*T,y[2]=b[2]*_+b[6]*w+b[10]*k+b[14]*T,y[3]=b[3]*_+b[7]*w+b[11]*k+b[15]*T}else v[0]=v[1]=v[2]=0,v[3]=1;if(e[0]=E,e[1]=C,e[2]=L,function(t,e){t[0][0]=e[0],t[0][1]=e[1],t[0][2]=e[2],t[1][0]=e[4],t[1][1]=e[5],t[1][2]=e[6],t[2][0]=e[8],t[2][1]=e[9],t[2][2]=e[10]}(p,u),r[0]=c.length(p[0]),c.normalize(p[0],p[0]),i[0]=c.dot(p[0],p[1]),g(p[1],p[1],p[0],1,-i[0]),r[1]=c.length(p[1]),c.normalize(p[1],p[1]),i[0]/=r[1],i[1]=c.dot(p[0],p[2]),g(p[2],p[2],p[0],1,-i[1]),i[2]=c.dot(p[1],p[2]),g(p[2],p[2],p[1],1,-i[2]),r[2]=c.length(p[2]),c.normalize(p[2],p[2]),i[1]/=r[2],i[2]/=r[2],c.cross(d,p[1],p[2]),c.dot(p[0],d)<0)for(var O=0;O<3;O++)r[O]*=-1,p[O][0]*=-1,p[O][1]*=-1,p[O][2]*=-1;return m[0]=.5*Math.sqrt(Math.max(1+p[0][0]-p[1][1]-p[2][2],0)),m[1]=.5*Math.sqrt(Math.max(1-p[0][0]+p[1][1]-p[2][2],0)),m[2]=.5*Math.sqrt(Math.max(1-p[0][0]-p[1][1]+p[2][2],0)),m[3]=.5*Math.sqrt(Math.max(1+p[0][0]+p[1][1]+p[2][2],0)),p[2][1]>p[1][2]&&(m[0]=-m[0]),p[0][2]>p[2][0]&&(m[1]=-m[1]),p[1][0]>p[0][1]&&(m[2]=-m[2]),!0}},{\"./normalize\":429,\"gl-mat4/clone\":259,\"gl-mat4/create\":260,\"gl-mat4/determinant\":261,\"gl-mat4/invert\":265,\"gl-mat4/transpose\":276,\"gl-vec3/cross\":334,\"gl-vec3/dot\":339,\"gl-vec3/length\":349,\"gl-vec3/normalize\":356}],429:[function(t,e,r){e.exports=function(t,e){var r=e[15];if(0===r)return!1;for(var n=1/r,i=0;i<16;i++)t[i]=e[i]*n;return!0}},{}],430:[function(t,e,r){var n=t(\"gl-vec3/lerp\"),i=t(\"mat4-recompose\"),a=t(\"mat4-decompose\"),o=t(\"gl-mat4/determinant\"),s=t(\"quat-slerp\"),l=h(),c=h(),u=h();function h(){return{translate:f(),scale:f(1),skew:f(),perspective:[0,0,0,1],quaternion:[0,0,0,1]}}function f(t){return[t||0,t||0,t||0]}e.exports=function(t,e,r,h){if(0===o(e)||0===o(r))return!1;var f=a(e,l.translate,l.scale,l.skew,l.perspective,l.quaternion),p=a(r,c.translate,c.scale,c.skew,c.perspective,c.quaternion);return!(!f||!p||(n(u.translate,l.translate,c.translate,h),n(u.skew,l.skew,c.skew,h),n(u.scale,l.scale,c.scale,h),n(u.perspective,l.perspective,c.perspective,h),s(u.quaternion,l.quaternion,c.quaternion,h),i(t,u.translate,u.scale,u.skew,u.perspective,u.quaternion),0))}},{\"gl-mat4/determinant\":261,\"gl-vec3/lerp\":350,\"mat4-decompose\":428,\"mat4-recompose\":431,\"quat-slerp\":483}],431:[function(t,e,r){var n={identity:t(\"gl-mat4/identity\"),translate:t(\"gl-mat4/translate\"),multiply:t(\"gl-mat4/multiply\"),create:t(\"gl-mat4/create\"),scale:t(\"gl-mat4/scale\"),fromRotationTranslation:t(\"gl-mat4/fromRotationTranslation\")},i=(n.create(),n.create());e.exports=function(t,e,r,a,o,s){return n.identity(t),n.fromRotationTranslation(t,s,e),t[3]=o[0],t[7]=o[1],t[11]=o[2],t[15]=o[3],n.identity(i),0!==a[2]&&(i[9]=a[2],n.multiply(t,t,i)),0!==a[1]&&(i[9]=0,i[8]=a[1],n.multiply(t,t,i)),0!==a[0]&&(i[8]=0,i[4]=a[0],n.multiply(t,t,i)),n.scale(t,t,r),t}},{\"gl-mat4/create\":260,\"gl-mat4/fromRotationTranslation\":263,\"gl-mat4/identity\":264,\"gl-mat4/multiply\":267,\"gl-mat4/scale\":274,\"gl-mat4/translate\":275}],432:[function(t,e,r){\"use strict\";e.exports=Math.log2||function(t){return Math.log(t)*Math.LOG2E}},{}],433:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"mat4-interpolate\"),a=t(\"gl-mat4/invert\"),o=t(\"gl-mat4/rotateX\"),s=t(\"gl-mat4/rotateY\"),l=t(\"gl-mat4/rotateZ\"),c=t(\"gl-mat4/lookAt\"),u=t(\"gl-mat4/translate\"),h=(t(\"gl-mat4/scale\"),t(\"gl-vec3/normalize\")),f=[0,0,0];function p(t){this._components=t.slice(),this._time=[0],this.prevMatrix=t.slice(),this.nextMatrix=t.slice(),this.computedMatrix=t.slice(),this.computedInverse=t.slice(),this.computedEye=[0,0,0],this.computedUp=[0,0,0],this.computedCenter=[0,0,0],this.computedRadius=[0],this._limits=[-1/0,1/0]}e.exports=function(t){return new p((t=t||{}).matrix||[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1])};var d=p.prototype;d.recalcMatrix=function(t){var e=this._time,r=n.le(e,t),o=this.computedMatrix;if(!(r<0)){var s=this._components;if(r===e.length-1)for(var l=16*r,c=0;c<16;++c)o[c]=s[l++];else{var u=e[r+1]-e[r],f=(l=16*r,this.prevMatrix),p=!0;for(c=0;c<16;++c)f[c]=s[l++];var d=this.nextMatrix;for(c=0;c<16;++c)d[c]=s[l++],p=p&&f[c]===d[c];if(u<1e-6||p)for(c=0;c<16;++c)o[c]=f[c];else i(o,f,d,(t-e[r])/u)}var g=this.computedUp;g[0]=o[1],g[1]=o[5],g[2]=o[9],h(g,g);var v=this.computedInverse;a(v,o);var m=this.computedEye,y=v[15];m[0]=v[12]/y,m[1]=v[13]/y,m[2]=v[14]/y;var x=this.computedCenter,b=Math.exp(this.computedRadius[0]);for(c=0;c<3;++c)x[c]=m[c]-o[2+4*c]*b}},d.idle=function(t){if(!(t<this.lastT())){for(var e=this._components,r=e.length-16,n=0;n<16;++n)e.push(e[r++]);this._time.push(t)}},d.flush=function(t){var e=n.gt(this._time,t)-2;e<0||(this._time.splice(0,e),this._components.splice(0,16*e))},d.lastT=function(){return this._time[this._time.length-1]},d.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||f,n=n||this.computedUp,this.setMatrix(t,c(this.computedMatrix,e,r,n));for(var i=0,a=0;a<3;++a)i+=Math.pow(r[a]-e[a],2);i=Math.log(Math.sqrt(i)),this.computedRadius[0]=i},d.rotate=function(t,e,r,n){this.recalcMatrix(t);var i=this.computedInverse;e&&s(i,i,e),r&&o(i,i,r),n&&l(i,i,n),this.setMatrix(t,a(this.computedMatrix,i))};var g=[0,0,0];d.pan=function(t,e,r,n){g[0]=-(e||0),g[1]=-(r||0),g[2]=-(n||0),this.recalcMatrix(t);var i=this.computedInverse;u(i,i,g),this.setMatrix(t,a(i,i))},d.translate=function(t,e,r,n){g[0]=e||0,g[1]=r||0,g[2]=n||0,this.recalcMatrix(t);var i=this.computedMatrix;u(i,i,g),this.setMatrix(t,i)},d.setMatrix=function(t,e){if(!(t<this.lastT())){this._time.push(t);for(var r=0;r<16;++r)this._components.push(e[r])}},d.setDistance=function(t,e){this.computedRadius[0]=e},d.setDistanceLimits=function(t,e){var r=this._limits;r[0]=t,r[1]=e},d.getDistanceLimits=function(t){var e=this._limits;return t?(t[0]=e[0],t[1]=e[1],t):e}},{\"binary-search-bounds\":91,\"gl-mat4/invert\":265,\"gl-mat4/lookAt\":266,\"gl-mat4/rotateX\":271,\"gl-mat4/rotateY\":272,\"gl-mat4/rotateZ\":273,\"gl-mat4/scale\":274,\"gl-mat4/translate\":275,\"gl-vec3/normalize\":356,\"mat4-interpolate\":430}],434:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<3){for(var r=new Array(e),i=0;i<e;++i)r[i]=i;return 2===e&&t[0][0]===t[1][0]&&t[0][1]===t[1][1]?[0]:r}for(var a=new Array(e),i=0;i<e;++i)a[i]=i;a.sort(function(e,r){var n=t[e][0]-t[r][0];return n||t[e][1]-t[r][1]});for(var o=[a[0],a[1]],s=[a[0],a[1]],i=2;i<e;++i){for(var l=a[i],c=t[l],u=o.length;u>1&&n(t[o[u-2]],t[o[u-1]],c)<=0;)u-=1,o.pop();for(o.push(l),u=s.length;u>1&&n(t[s[u-2]],t[s[u-1]],c)>=0;)u-=1,s.pop();s.push(l)}for(var r=new Array(s.length+o.length-2),h=0,i=0,f=o.length;i<f;++i)r[h++]=o[i];for(var p=s.length-2;p>0;--p)r[h++]=s[p];return r};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":510}],435:[function(t,e,r){\"use strict\";e.exports=function(t,e){e||(e=t,t=window);var r=0,i=0,a=0,o={shift:!1,alt:!1,control:!1,meta:!1},s=!1;function l(t){var e=!1;return\"altKey\"in t&&(e=e||t.altKey!==o.alt,o.alt=!!t.altKey),\"shiftKey\"in t&&(e=e||t.shiftKey!==o.shift,o.shift=!!t.shiftKey),\"ctrlKey\"in t&&(e=e||t.ctrlKey!==o.control,o.control=!!t.ctrlKey),\"metaKey\"in t&&(e=e||t.metaKey!==o.meta,o.meta=!!t.metaKey),e}function c(t,s){var c=n.x(s),u=n.y(s);\"buttons\"in s&&(t=0|s.buttons),(t!==r||c!==i||u!==a||l(s))&&(r=0|t,i=c||0,a=u||0,e&&e(r,i,a,o))}function u(t){c(0,t)}function h(){(r||i||a||o.shift||o.alt||o.meta||o.control)&&(i=a=0,r=0,o.shift=o.alt=o.control=o.meta=!1,e&&e(0,0,0,o))}function f(t){l(t)&&e&&e(r,i,a,o)}function p(t){0===n.buttons(t)?c(0,t):c(r,t)}function d(t){c(r|n.buttons(t),t)}function g(t){c(r&~n.buttons(t),t)}function v(){s||(s=!0,t.addEventListener(\"mousemove\",p),t.addEventListener(\"mousedown\",d),t.addEventListener(\"mouseup\",g),t.addEventListener(\"mouseleave\",u),t.addEventListener(\"mouseenter\",u),t.addEventListener(\"mouseout\",u),t.addEventListener(\"mouseover\",u),t.addEventListener(\"blur\",h),t.addEventListener(\"keyup\",f),t.addEventListener(\"keydown\",f),t.addEventListener(\"keypress\",f),t!==window&&(window.addEventListener(\"blur\",h),window.addEventListener(\"keyup\",f),window.addEventListener(\"keydown\",f),window.addEventListener(\"keypress\",f)))}v();var m={element:t};return Object.defineProperties(m,{enabled:{get:function(){return s},set:function(e){e?v():s&&(s=!1,t.removeEventListener(\"mousemove\",p),t.removeEventListener(\"mousedown\",d),t.removeEventListener(\"mouseup\",g),t.removeEventListener(\"mouseleave\",u),t.removeEventListener(\"mouseenter\",u),t.removeEventListener(\"mouseout\",u),t.removeEventListener(\"mouseover\",u),t.removeEventListener(\"blur\",h),t.removeEventListener(\"keyup\",f),t.removeEventListener(\"keydown\",f),t.removeEventListener(\"keypress\",f),t!==window&&(window.removeEventListener(\"blur\",h),window.removeEventListener(\"keyup\",f),window.removeEventListener(\"keydown\",f),window.removeEventListener(\"keypress\",f)))},enumerable:!0},buttons:{get:function(){return r},enumerable:!0},x:{get:function(){return i},enumerable:!0},y:{get:function(){return a},enumerable:!0},mods:{get:function(){return o},enumerable:!0}}),m};var n=t(\"mouse-event\")},{\"mouse-event\":437}],436:[function(t,e,r){var n={left:0,top:0};e.exports=function(t,e,r){e=e||t.currentTarget||t.srcElement,Array.isArray(r)||(r=[0,0]);var i=t.clientX||0,a=t.clientY||0,o=(s=e,s===window||s===document||s===document.body?n:s.getBoundingClientRect());var s;return r[0]=i-o.left,r[1]=a-o.top,r}},{}],437:[function(t,e,r){\"use strict\";function n(t){return t.target||t.srcElement||window}r.buttons=function(t){if(\"object\"==typeof t){if(\"buttons\"in t)return t.buttons;if(\"which\"in t){if(2===(e=t.which))return 4;if(3===e)return 2;if(e>0)return 1<<e-1}else if(\"button\"in t){var e;if(1===(e=t.button))return 4;if(2===e)return 2;if(e>=0)return 1<<e}}return 0},r.element=n,r.x=function(t){if(\"object\"==typeof t){if(\"offsetX\"in t)return t.offsetX;var e=n(t).getBoundingClientRect();return t.clientX-e.left}return 0},r.y=function(t){if(\"object\"==typeof t){if(\"offsetY\"in t)return t.offsetY;var e=n(t).getBoundingClientRect();return t.clientY-e.top}return 0}},{}],438:[function(t,e,r){\"use strict\";var n=t(\"to-px\");e.exports=function(t,e,r){\"function\"==typeof t&&(r=!!e,e=t,t=window);var i=n(\"ex\",t),a=function(t){r&&t.preventDefault();var n=t.deltaX||0,a=t.deltaY||0,o=t.deltaZ||0,s=t.deltaMode,l=1;switch(s){case 1:l=i;break;case 2:l=window.innerHeight}if(a*=l,o*=l,(n*=l)||a||o)return e(n,a,o,t)};return t.addEventListener(\"wheel\",a),a}},{\"to-px\":539}],439:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\");function i(t){return\"a\"+t}function a(t){return\"d\"+t}function o(t,e){return\"c\"+t+\"_\"+e}function s(t){return\"s\"+t}function l(t,e){return\"t\"+t+\"_\"+e}function c(t){return\"o\"+t}function u(t){return\"x\"+t}function h(t){return\"p\"+t}function f(t,e){return\"d\"+t+\"_\"+e}function p(t){return\"i\"+t}function d(t,e){return\"u\"+t+\"_\"+e}function g(t){return\"b\"+t}function v(t){return\"y\"+t}function m(t){return\"e\"+t}function y(t){return\"v\"+t}e.exports=function(t){function e(t){throw new Error(\"ndarray-extract-contour: \"+t)}\"object\"!=typeof t&&e(\"Must specify arguments\");var r=t.order;Array.isArray(r)||e(\"Must specify order\");var M=t.arrayArguments||1;M<1&&e(\"Must have at least one array argument\");var S=t.scalarArguments||0;S<0&&e(\"Scalar arg count must be > 0\");\"function\"!=typeof t.vertex&&e(\"Must specify vertex creation function\");\"function\"!=typeof t.cell&&e(\"Must specify cell creation function\");\"function\"!=typeof t.phase&&e(\"Must specify phase function\");for(var E=t.getters||[],C=new Array(M),L=0;L<M;++L)E.indexOf(L)>=0?C[L]=!0:C[L]=!1;return function(t,e,r,M,S,E){var C=E.length,L=S.length;if(L<2)throw new Error(\"ndarray-extract-contour: Dimension must be at least 2\");for(var P=\"extractContour\"+S.join(\"_\"),O=[],z=[],I=[],D=0;D<C;++D)I.push(i(D));for(var D=0;D<M;++D)I.push(u(D));for(var D=0;D<L;++D)z.push(s(D)+\"=\"+i(0)+\".shape[\"+D+\"]|0\");for(var D=0;D<C;++D){z.push(a(D)+\"=\"+i(D)+\".data\",c(D)+\"=\"+i(D)+\".offset|0\");for(var R=0;R<L;++R)z.push(l(D,R)+\"=\"+i(D)+\".stride[\"+R+\"]|0\")}for(var D=0;D<C;++D){z.push(h(D)+\"=\"+c(D)),z.push(o(D,0));for(var R=1;R<1<<L;++R){for(var F=[],B=0;B<L;++B)R&1<<B&&F.push(\"-\"+l(D,B));z.push(f(D,R)+\"=(\"+F.join(\"\")+\")|0\"),z.push(o(D,R)+\"=0\")}}for(var D=0;D<C;++D)for(var R=0;R<L;++R){var N=[l(D,S[R])];R>0&&N.push(l(D,S[R-1])+\"*\"+s(S[R-1])),z.push(d(D,S[R])+\"=(\"+N.join(\"-\")+\")|0\")}for(var D=0;D<L;++D)z.push(p(D)+\"=0\");z.push(_+\"=0\");for(var j=[\"2\"],D=L-2;D>=0;--D)j.push(s(S[D]));z.push(w+\"=(\"+j.join(\"*\")+\")|0\",b+\"=mallocUint32(\"+w+\")\",x+\"=mallocUint32(\"+w+\")\",k+\"=0\"),z.push(g(0)+\"=0\");for(var R=1;R<1<<L;++R){for(var U=[],V=[],B=0;B<L;++B)R&1<<B&&(0===V.length?U.push(\"1\"):U.unshift(V.join(\"*\"))),V.push(s(S[B]));var q=\"\";U[0].indexOf(s(S[L-2]))<0&&(q=\"-\");var H=A(L,R,S);z.push(m(H)+\"=(-\"+U.join(\"-\")+\")|0\",v(H)+\"=(\"+q+U.join(\"-\")+\")|0\",g(H)+\"=0\")}function G(t,e){O.push(\"for(\",p(S[t]),\"=\",e,\";\",p(S[t]),\"<\",s(S[t]),\";\",\"++\",p(S[t]),\"){\")}function Y(t){for(var e=0;e<C;++e)O.push(h(e),\"+=\",d(e,S[t]),\";\");O.push(\"}\")}function W(){for(var t=1;t<1<<L;++t)O.push(T,\"=\",m(t),\";\",m(t),\"=\",v(t),\";\",v(t),\"=\",T,\";\")}z.push(y(0)+\"=0\",T+\"=0\"),function t(e,r){if(e<0)return void function(t){for(var e=0;e<C;++e)E[e]?O.push(o(e,0),\"=\",a(e),\".get(\",h(e),\");\"):O.push(o(e,0),\"=\",a(e),\"[\",h(e),\"];\");for(var r=[],e=0;e<C;++e)r.push(o(e,0));for(var e=0;e<M;++e)r.push(u(e));O.push(g(0),\"=\",b,\"[\",k,\"]=phase(\",r.join(),\");\");for(var n=1;n<1<<L;++n)O.push(g(n),\"=\",b,\"[\",k,\"+\",m(n),\"];\");for(var i=[],n=1;n<1<<L;++n)i.push(\"(\"+g(0)+\"!==\"+g(n)+\")\");O.push(\"if(\",i.join(\"||\"),\"){\");for(var s=[],e=0;e<L;++e)s.push(p(e));for(var e=0;e<C;++e){s.push(o(e,0));for(var n=1;n<1<<L;++n)E[e]?O.push(o(e,n),\"=\",a(e),\".get(\",h(e),\"+\",f(e,n),\");\"):O.push(o(e,n),\"=\",a(e),\"[\",h(e),\"+\",f(e,n),\"];\"),s.push(o(e,n))}for(var e=0;e<1<<L;++e)s.push(g(e));for(var e=0;e<M;++e)s.push(u(e));O.push(\"vertex(\",s.join(),\");\",y(0),\"=\",x,\"[\",k,\"]=\",_,\"++;\");for(var l=(1<<L)-1,c=g(l),n=0;n<L;++n)if(0==(t&~(1<<n))){for(var d=l^1<<n,v=g(d),w=[],T=d;T>0;T=T-1&d)w.push(x+\"[\"+k+\"+\"+m(T)+\"]\");w.push(y(0));for(var T=0;T<C;++T)1&n?w.push(o(T,l),o(T,d)):w.push(o(T,d),o(T,l));1&n?w.push(c,v):w.push(v,c);for(var T=0;T<M;++T)w.push(u(T));O.push(\"if(\",c,\"!==\",v,\"){\",\"face(\",w.join(),\")}\")}O.push(\"}\",k,\"+=1;\")}(r);!function(t){for(var e=t-1;e>=0;--e)G(e,0);for(var r=[],e=0;e<C;++e)E[e]?r.push(a(e)+\".get(\"+h(e)+\")\"):r.push(a(e)+\"[\"+h(e)+\"]\");for(var e=0;e<M;++e)r.push(u(e));O.push(b,\"[\",k,\"++]=phase(\",r.join(),\");\");for(var e=0;e<t;++e)Y(e);for(var n=0;n<C;++n)O.push(h(n),\"+=\",d(n,S[t]),\";\")}(e);O.push(\"if(\",s(S[e]),\">0){\",p(S[e]),\"=1;\");t(e-1,r|1<<S[e]);for(var n=0;n<C;++n)O.push(h(n),\"+=\",d(n,S[e]),\";\");e===L-1&&(O.push(k,\"=0;\"),W());G(e,2);t(e-1,r);e===L-1&&(O.push(\"if(\",p(S[L-1]),\"&1){\",k,\"=0;}\"),W());Y(e);O.push(\"}\")}(L-1,0),O.push(\"freeUint32(\",x,\");freeUint32(\",b,\");\");var X=[\"'use strict';\",\"function \",P,\"(\",I.join(),\"){\",\"var \",z.join(),\";\",O.join(\"\"),\"}\",\"return \",P].join(\"\");return new Function(\"vertex\",\"face\",\"phase\",\"mallocUint32\",\"freeUint32\",X)(t,e,r,n.mallocUint32,n.freeUint32)}(t.vertex,t.cell,t.phase,S,r,C)};var x=\"V\",b=\"P\",_=\"N\",w=\"Q\",k=\"X\",T=\"T\";function A(t,e,r){for(var n=0,i=0;i<t;++i)e&1<<i&&(n|=1<<r[i]);return n}},{\"typedarray-pool\":545}],440:[function(t,e,r){\"use strict\";var n=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{_inline_1_arg1_=_inline_1_arg2_.apply(void 0,_inline_1_arg0_)}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"cwise\",blockSize:64});e.exports=function(t,e){return n(t,e),t}},{\"cwise/lib/wrapper\":149}],441:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(Array.isArray(r)){if(r.length!==e.dimension)throw new Error(\"ndarray-gradient: invalid boundary conditions\")}else r=n(e.dimension,\"string\"==typeof r?r:\"clamp\");if(t.dimension!==e.dimension+1)throw new Error(\"ndarray-gradient: output dimension must be +1 input dimension\");if(t.shape[e.dimension]!==e.dimension)throw new Error(\"ndarray-gradient: output shape must match input shape\");for(var i=0;i<e.dimension;++i)if(t.shape[i]!==e.shape[i])throw new Error(\"ndarray-gradient: shape mismatch\");if(0===e.size)return t;if(e.dimension<=0)return t.set(0),t;return function(t){var e=t.join();if(m=o[e])return m;var r=t.length,n=[\"function gradient(dst,src){var s=src.shape.slice();\"];function i(e){for(var i=r-e.length,a=[],o=[],s=[],l=0;l<r;++l)e.indexOf(l+1)>=0?s.push(\"0\"):e.indexOf(-(l+1))>=0?s.push(\"s[\"+l+\"]-1\"):(s.push(\"-1\"),a.push(\"1\"),o.push(\"s[\"+l+\"]-2\"));var c=\".lo(\"+a.join()+\").hi(\"+o.join()+\")\";if(0===a.length&&(c=\"\"),i>0){n.push(\"if(1\");for(var l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\"&&s[\",l,\"]>2\");n.push(\"){grad\",i,\"(src.pick(\",s.join(),\")\",c);for(var l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\",dst.pick(\",s.join(),\",\",l,\")\",c);n.push(\");\")}for(var l=0;l<e.length;++l){var u=Math.abs(e[l])-1,h=\"dst.pick(\"+s.join()+\",\"+u+\")\"+c;switch(t[u]){case\"clamp\":var f=s.slice(),p=s.slice();e[l]<0?f[u]=\"s[\"+u+\"]-2\":p[u]=\"1\",0===i?n.push(\"if(s[\",u,\"]>1){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",f.join(),\")-src.get(\",p.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>1){diff(\",h,\",src.pick(\",f.join(),\")\",c,\",src.pick(\",p.join(),\")\",c,\");}else{zero(\",h,\");};\");break;case\"mirror\":0===i?n.push(\"dst.set(\",s.join(),\",\",u,\",0);\"):n.push(\"zero(\",h,\");\");break;case\"wrap\":var d=s.slice(),g=s.slice();e[l]<0?(d[u]=\"s[\"+u+\"]-2\",g[u]=\"0\"):(d[u]=\"s[\"+u+\"]-1\",g[u]=\"1\"),0===i?n.push(\"if(s[\",u,\"]>2){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",d.join(),\")-src.get(\",g.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>2){diff(\",h,\",src.pick(\",d.join(),\")\",c,\",src.pick(\",g.join(),\")\",c,\");}else{zero(\",h,\");};\");break;default:throw new Error(\"ndarray-gradient: Invalid boundary condition\")}}i>0&&n.push(\"};\")}for(var s=0;s<1<<r;++s){for(var h=[],f=0;f<r;++f)s&1<<f&&h.push(f+1);for(var p=0;p<1<<h.length;++p){for(var d=h.slice(),f=0;f<h.length;++f)p&1<<f&&(d[f]=-d[f]);i(d)}}n.push(\"return dst;};return gradient\");for(var g=[\"diff\",\"zero\"],v=[l,c],s=1;s<=r;++s)g.push(\"grad\"+s),v.push(u(s));g.push(n.join(\"\"));var m=Function.apply(void 0,g).apply(void 0,v);return a[e]=m,m}(r)(t,e)};var n=t(\"dup\"),i=t(\"cwise-compiler\"),a={},o={},s={body:\"\",args:[],thisVars:[],localVars:[]},l=i({args:[\"array\",\"array\",\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1},{name:\"left\",lvalue:!1,rvalue:!0,count:1},{name:\"right\",lvalue:!1,rvalue:!0,count:1}],body:\"out=0.5*(left-right)\",thisVars:[],localVars:[]},funcName:\"cdiff\"}),c=i({args:[\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1}],body:\"out=0\",thisVars:[],localVars:[]},funcName:\"zero\"});function u(t){if(t in a)return a[t];for(var e=[],r=0;r<t;++r)e.push(\"out\",r,\"s=0.5*(inp\",r,\"l-inp\",r,\"r);\");var o=[\"array\"],l=[\"junk\"];for(r=0;r<t;++r){o.push(\"array\"),l.push(\"out\"+r+\"s\");var c=n(t);c[r]=-1,o.push({array:0,offset:c.slice()}),c[r]=1,o.push({array:0,offset:c.slice()}),l.push(\"inp\"+r+\"l\",\"inp\"+r+\"r\")}return a[t]=i({args:o,pre:s,post:s,body:{body:e.join(\"\"),args:l.map(function(t){return{name:t,lvalue:0===t.indexOf(\"out\"),rvalue:0===t.indexOf(\"inp\"),count:\"junk\"!==t|0}}),thisVars:[],localVars:[]},funcName:\"fdTemplate\"+t})}},{\"cwise-compiler\":146,dup:170}],442:[function(t,e,r){\"use strict\";var n=t(\"ndarray-warp\"),i=t(\"gl-matrix-invert\");e.exports=function(t,e,r){var a=e.dimension,o=i([],r);return n(t,e,function(t,e){for(var r=0;r<a;++r){t[r]=o[(a+1)*a+r];for(var n=0;n<a;++n)t[r]+=o[(a+1)*n+r]*e[n]}var i=o[(a+1)*(a+1)-1];for(n=0;n<a;++n)i+=o[(a+1)*n+a]*e[n];var s=1/i;for(r=0;r<a;++r)t[r]*=s;return t}),t}},{\"gl-matrix-invert\":277,\"ndarray-warp\":449}],443:[function(t,e,r){\"use strict\";function n(t,e){var r=Math.floor(e),n=e-r,i=0<=r&&r<t.shape[0],a=0<=r+1&&r+1<t.shape[0];return(1-n)*(i?+t.get(r):0)+n*(a?+t.get(r+1):0)}function i(t,e,r){var n=Math.floor(e),i=e-n,a=0<=n&&n<t.shape[0],o=0<=n+1&&n+1<t.shape[0],s=Math.floor(r),l=r-s,c=0<=s&&s<t.shape[1],u=0<=s+1&&s+1<t.shape[1],h=a&&c?t.get(n,s):0,f=a&&u?t.get(n,s+1):0;return(1-l)*((1-i)*h+i*(o&&c?t.get(n+1,s):0))+l*((1-i)*f+i*(o&&u?t.get(n+1,s+1):0))}function a(t,e,r,n){var i=Math.floor(e),a=e-i,o=0<=i&&i<t.shape[0],s=0<=i+1&&i+1<t.shape[0],l=Math.floor(r),c=r-l,u=0<=l&&l<t.shape[1],h=0<=l+1&&l+1<t.shape[1],f=Math.floor(n),p=n-f,d=0<=f&&f<t.shape[2],g=0<=f+1&&f+1<t.shape[2],v=o&&u&&d?t.get(i,l,f):0,m=o&&h&&d?t.get(i,l+1,f):0,y=s&&u&&d?t.get(i+1,l,f):0,x=s&&h&&d?t.get(i+1,l+1,f):0,b=o&&u&&g?t.get(i,l,f+1):0,_=o&&h&&g?t.get(i,l+1,f+1):0;return(1-p)*((1-c)*((1-a)*v+a*y)+c*((1-a)*m+a*x))+p*((1-c)*((1-a)*b+a*(s&&u&&g?t.get(i+1,l,f+1):0))+c*((1-a)*_+a*(s&&h&&g?t.get(i+1,l+1,f+1):0)))}e.exports=function(t,e,r,o){switch(t.shape.length){case 0:return 0;case 1:return n(t,e);case 2:return i(t,e,r);case 3:return a(t,e,r,o);default:return function(t){var e,r,n=0|t.shape.length,i=new Array(n),a=new Array(n),o=new Array(n),s=new Array(n);for(e=0;e<n;++e)r=+arguments[e+1],i[e]=Math.floor(r),a[e]=r-i[e],o[e]=0<=i[e]&&i[e]<t.shape[e],s[e]=0<=i[e]+1&&i[e]+1<t.shape[e];var l,c,u,h=0;t:for(e=0;e<1<<n;++e){for(c=1,u=t.offset,l=0;l<n;++l)if(e&1<<l){if(!s[l])continue t;c*=a[l],u+=t.stride[l]*(i[l]+1)}else{if(!o[l])continue t;c*=1-a[l],u+=t.stride[l]*i[l]}h+=c*t.data[u]}return h}.apply(void 0,arguments)}},e.exports.d1=n,e.exports.d2=i,e.exports.d3=a},{}],444:[function(t,e,r){\"use strict\";var n=t(\"cwise-compiler\"),i={body:\"\",args:[],thisVars:[],localVars:[]};function a(t){if(!t)return i;for(var e=0;e<t.args.length;++e){var r=t.args[e];t.args[e]=0===e?{name:r,lvalue:!0,rvalue:!!t.rvalue,count:t.count||1}:{name:r,lvalue:!1,rvalue:!0,count:1}}return t.thisVars||(t.thisVars=[]),t.localVars||(t.localVars=[]),t}function o(t){for(var e=[],r=0;r<t.args.length;++r)e.push(\"a\"+r);return new Function(\"P\",[\"return function \",t.funcName,\"_ndarrayops(\",e.join(\",\"),\") {P(\",e.join(\",\"),\");return a0}\"].join(\"\"))(function(t){return n({args:t.args,pre:a(t.pre),body:a(t.body),post:a(t.proc),funcName:t.funcName})}(t))}var s={add:\"+\",sub:\"-\",mul:\"*\",div:\"/\",mod:\"%\",band:\"&\",bor:\"|\",bxor:\"^\",lshift:\"<<\",rshift:\">>\",rrshift:\">>>\"};!function(){for(var t in s){var e=s[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a\"+e+\"=b\"},rvalue:!0,funcName:t+\"eq\"}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a\"+e+\"=s\"},rvalue:!0,funcName:t+\"seq\"})}}();var l={not:\"!\",bnot:\"~\",neg:\"-\",recip:\"1.0/\"};!function(){for(var t in l){var e=l[t];r[t]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=\"+e+\"b\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\"],body:{args:[\"a\"],body:\"a=\"+e+\"a\"},rvalue:!0,count:2,funcName:t+\"eq\"})}}();var c={and:\"&&\",or:\"||\",eq:\"===\",neq:\"!==\",lt:\"<\",gt:\">\",leq:\"<=\",geq:\">=\"};!function(){for(var t in c){var e=c[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=a\"+e+\"b\"},rvalue:!0,count:2,funcName:t+\"eq\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a=a\"+e+\"s\"},rvalue:!0,count:2,funcName:t+\"seq\"})}}();var u=[\"abs\",\"acos\",\"asin\",\"atan\",\"ceil\",\"cos\",\"exp\",\"floor\",\"log\",\"round\",\"sin\",\"sqrt\",\"tan\"];!function(){for(var t=0;t<u.length;++t){var e=u[t];r[e]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"eq\"]=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f(a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"})}}();var h=[\"max\",\"min\",\"atan2\",\"pow\"];!function(){for(var t=0;t<h.length;++t){var e=h[t];r[e]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e+\"s\"}),r[e+\"eq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"}),r[e+\"seq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"seq\"})}}();var f=[\"atan2\",\"pow\"];!function(){for(var t=0;t<f.length;++t){var e=f[t];r[e+\"op\"]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"op\"}),r[e+\"ops\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"ops\"}),r[e+\"opeq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opeq\"}),r[e+\"opseq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opseq\"})}}(),r.any=n({args:[\"array\"],pre:i,body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"if(a){return true}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return false\"},funcName:\"any\"}),r.all=n({args:[\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1}],body:\"if(!x){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"all\"}),r.sum=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s+=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"sum\"}),r.prod=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=1\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s*=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"prod\"}),r.norm2squared=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm2squared\"}),r.norm2=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return Math.sqrt(this_s)\"},funcName:\"norm2\"}),r.norminf=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:4}],body:\"if(-a>this_s){this_s=-a}else if(a>this_s){this_s=a}\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norminf\"}),r.norm1=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:3}],body:\"this_s+=a<0?-a:a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm1\"}),r.sup=n({args:[\"array\"],pre:{body:\"this_h=-Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_>this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.inf=n({args:[\"array\"],pre:{body:\"this_h=Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_<this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.argmin=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_<this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.argmax=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=-Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_>this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.random=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.random\",thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f()\",thisVars:[\"this_f\"]},funcName:\"random\"}),r.assign=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assign\"}),r.assigns=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assigns\"}),r.equals=n({args:[\"array\",\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1},{name:\"y\",lvalue:!1,rvalue:!0,count:1}],body:\"if(x!==y){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"equals\"})},{\"cwise-compiler\":146}],445:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"./doConvert.js\");e.exports=function(t,e){for(var r=[],a=t,o=1;Array.isArray(a);)r.push(a.length),o*=a.length,a=a[0];return 0===r.length?n():(e||(e=n(new Float64Array(o),r)),i(e,t),e)}},{\"./doConvert.js\":446,ndarray:450}],446:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\nvar _inline_1_v=_inline_1_arg1_,_inline_1_i\\nfor(_inline_1_i=0;_inline_1_i<_inline_1_arg2_.length-1;++_inline_1_i) {\\n_inline_1_v=_inline_1_v[_inline_1_arg2_[_inline_1_i]]\\n}\\n_inline_1_arg0_=_inline_1_v[_inline_1_arg2_[_inline_1_arg2_.length-1]]\\n}\",args:[{name:\"_inline_1_arg0_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:4}],thisVars:[],localVars:[\"_inline_1_i\",\"_inline_1_v\"]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},funcName:\"convert\",blockSize:64})},{\"cwise-compiler\":146}],447:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=32;function a(t){switch(t){case\"uint8\":return[n.mallocUint8,n.freeUint8];case\"uint16\":return[n.mallocUint16,n.freeUint16];case\"uint32\":return[n.mallocUint32,n.freeUint32];case\"int8\":return[n.mallocInt8,n.freeInt8];case\"int16\":return[n.mallocInt16,n.freeInt16];case\"int32\":return[n.mallocInt32,n.freeInt32];case\"float32\":return[n.mallocFloat,n.freeFloat];case\"float64\":return[n.mallocDouble,n.freeDouble];default:return null}}function o(t){for(var e=[],r=0;r<t;++r)e.push(\"s\"+r);for(r=0;r<t;++r)e.push(\"n\"+r);for(r=1;r<t;++r)e.push(\"d\"+r);for(r=1;r<t;++r)e.push(\"e\"+r);for(r=1;r<t;++r)e.push(\"f\"+r);return e}e.exports=function(t,e){var r=[\"'use strict'\"],n=[\"ndarraySortWrapper\",t.join(\"d\"),e].join(\"\");r.push([\"function \",n,\"(\",[\"array\"].join(\",\"),\"){\"].join(\"\"));for(var s=[\"data=array.data,offset=array.offset|0,shape=array.shape,stride=array.stride\"],l=0;l<t.length;++l)s.push([\"s\",l,\"=stride[\",l,\"]|0,n\",l,\"=shape[\",l,\"]|0\"].join(\"\"));var c=new Array(t.length),u=[];for(l=0;l<t.length;++l)0!==(p=t[l])&&(0===u.length?c[p]=\"1\":c[p]=u.join(\"*\"),u.push(\"n\"+p));var h=-1,f=-1;for(l=0;l<t.length;++l){var p,d=t[l];0!==d&&(h>0?s.push([\"d\",d,\"=s\",d,\"-d\",h,\"*n\",h].join(\"\")):s.push([\"d\",d,\"=s\",d].join(\"\")),h=d),0!=(p=t.length-1-l)&&(f>0?s.push([\"e\",p,\"=s\",p,\"-e\",f,\"*n\",f,\",f\",p,\"=\",c[p],\"-f\",f,\"*n\",f].join(\"\")):s.push([\"e\",p,\"=s\",p,\",f\",p,\"=\",c[p]].join(\"\")),f=p)}r.push(\"var \"+s.join(\",\"));var g=[\"0\",\"n0-1\",\"data\",\"offset\"].concat(o(t.length));r.push([\"if(n0<=\",i,\"){\",\"insertionSort(\",g.join(\",\"),\")}else{\",\"quickSort(\",g.join(\",\"),\")}\"].join(\"\")),r.push(\"}return \"+n);var v=new Function(\"insertionSort\",\"quickSort\",r.join(\"\\n\")),m=function(t,e){var r=[\"'use strict'\"],n=[\"ndarrayInsertionSort\",t.join(\"d\"),e].join(\"\"),i=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),s=a(e),l=[\"i,j,cptr,ptr=left*s0+offset\"];if(t.length>1){for(var c=[],u=1;u<t.length;++u)l.push(\"i\"+u),c.push(\"n\"+u);s?l.push(\"scratch=malloc(\"+c.join(\"*\")+\")\"):l.push(\"scratch=new Array(\"+c.join(\"*\")+\")\"),l.push(\"dptr\",\"sptr\",\"a\",\"b\")}else l.push(\"scratch\");function h(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function f(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}if(r.push([\"function \",n,\"(\",i.join(\",\"),\"){var \",l.join(\",\")].join(\"\"),\"for(i=left+1;i<=right;++i){\",\"j=i;ptr+=s0\",\"cptr=ptr\"),t.length>1){for(r.push(\"dptr=0;sptr=ptr\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(\"scratch[dptr++]=\",h(\"sptr\")),u=0;u<t.length;++u)0!==(p=t[u])&&r.push(\"sptr+=d\"+p,\"}\");for(r.push(\"__g:while(j--\\x3eleft){\",\"dptr=0\",\"sptr=cptr-s0\"),u=1;u<t.length;++u)1===u&&r.push(\"__l:\"),r.push([\"for(i\",u,\"=0;i\",u,\"<n\",u,\";++i\",u,\"){\"].join(\"\"));for(r.push([\"a=\",h(\"sptr\"),\"\\nb=scratch[dptr]\\nif(a<b){break __g}\\nif(a>b){break __l}\"].join(\"\")),u=t.length-1;u>=1;--u)r.push(\"sptr+=e\"+u,\"dptr+=f\"+u,\"}\");for(r.push(\"dptr=cptr;sptr=cptr-s0\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(f(\"dptr\",h(\"sptr\"))),u=0;u<t.length;++u)0!==(p=t[u])&&r.push([\"dptr+=d\",p,\";sptr+=d\",p].join(\"\"),\"}\");for(r.push(\"cptr-=s0\\n}\"),r.push(\"dptr=cptr;sptr=0\"),u=t.length-1;u>=0;--u)0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"));for(r.push(f(\"dptr\",\"scratch[sptr++]\")),u=0;u<t.length;++u){var p;0!==(p=t[u])&&r.push(\"dptr+=d\"+p,\"}\")}}else r.push(\"scratch=\"+h(\"ptr\"),\"while((j--\\x3eleft)&&(\"+h(\"cptr-s0\")+\">scratch)){\",f(\"cptr\",h(\"cptr-s0\")),\"cptr-=s0\",\"}\",f(\"cptr\",\"scratch\"));return r.push(\"}\"),t.length>1&&s&&r.push(\"free(scratch)\"),r.push(\"} return \"+n),s?new Function(\"malloc\",\"free\",r.join(\"\\n\"))(s[0],s[1]):new Function(r.join(\"\\n\"))()}(t,e),y=function(t,e,r){var n=[\"'use strict'\"],s=[\"ndarrayQuickSort\",t.join(\"d\"),e].join(\"\"),l=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),c=a(e),u=0;n.push([\"function \",s,\"(\",l.join(\",\"),\"){\"].join(\"\"));var h=[\"sixth=((right-left+1)/6)|0\",\"index1=left+sixth\",\"index5=right-sixth\",\"index3=(left+right)>>1\",\"index2=index3-sixth\",\"index4=index3+sixth\",\"el1=index1\",\"el2=index2\",\"el3=index3\",\"el4=index4\",\"el5=index5\",\"less=left+1\",\"great=right-1\",\"pivots_are_equal=true\",\"tmp\",\"tmp0\",\"x\",\"y\",\"z\",\"k\",\"ptr0\",\"ptr1\",\"ptr2\",\"comp_pivot1=0\",\"comp_pivot2=0\",\"comp=0\"];if(t.length>1){for(var f=[],p=1;p<t.length;++p)f.push(\"n\"+p),h.push(\"i\"+p);for(p=0;p<8;++p)h.push(\"b_ptr\"+p);h.push(\"ptr3\",\"ptr4\",\"ptr5\",\"ptr6\",\"ptr7\",\"pivot_ptr\",\"ptr_shift\",\"elementSize=\"+f.join(\"*\")),c?h.push(\"pivot1=malloc(elementSize)\",\"pivot2=malloc(elementSize)\"):h.push(\"pivot1=new Array(elementSize),pivot2=new Array(elementSize)\")}else h.push(\"pivot1\",\"pivot2\");function d(t){return[\"(offset+\",t,\"*s0)\"].join(\"\")}function g(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function v(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}function m(e,r,i){if(1===e.length)n.push(\"ptr0=\"+d(e[0]));else for(var a=0;a<e.length;++a)n.push([\"b_ptr\",a,\"=s0*\",e[a]].join(\"\"));for(r&&n.push(\"pivot_ptr=0\"),n.push(\"ptr_shift=offset\"),a=t.length-1;a>=0;--a)0!==(o=t[a])&&n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"));if(e.length>1)for(a=0;a<e.length;++a)n.push([\"ptr\",a,\"=b_ptr\",a,\"+ptr_shift\"].join(\"\"));for(n.push(i),r&&n.push(\"++pivot_ptr\"),a=0;a<t.length;++a){var o;0!==(o=t[a])&&(e.length>1?n.push(\"ptr_shift+=d\"+o):n.push(\"ptr0+=d\"+o),n.push(\"}\"))}}function y(e,r,i,a){if(1===r.length)n.push(\"ptr0=\"+d(r[0]));else{for(var o=0;o<r.length;++o)n.push([\"b_ptr\",o,\"=s0*\",r[o]].join(\"\"));n.push(\"ptr_shift=offset\")}for(i&&n.push(\"pivot_ptr=0\"),e&&n.push(e+\":\"),o=1;o<t.length;++o)n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"));if(r.length>1)for(o=0;o<r.length;++o)n.push([\"ptr\",o,\"=b_ptr\",o,\"+ptr_shift\"].join(\"\"));for(n.push(a),o=t.length-1;o>=1;--o)i&&n.push(\"pivot_ptr+=f\"+o),r.length>1?n.push(\"ptr_shift+=e\"+o):n.push(\"ptr0+=e\"+o),n.push(\"}\")}function x(){t.length>1&&c&&n.push(\"free(pivot1)\",\"free(pivot2)\")}function b(e,r){var i=\"el\"+e,a=\"el\"+r;if(t.length>1){var o=\"__l\"+ ++u;y(o,[i,a],!1,[\"comp=\",g(\"ptr0\"),\"-\",g(\"ptr1\"),\"\\n\",\"if(comp>0){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0;break \",o,\"}\\n\",\"if(comp<0){break \",o,\"}\"].join(\"\"))}else n.push([\"if(\",g(d(i)),\">\",g(d(a)),\"){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0}\"].join(\"\"))}function _(e,r){t.length>1?m([e,r],!1,v(\"ptr0\",g(\"ptr1\"))):n.push(v(d(e),g(d(r))))}function w(e,r,i){if(t.length>1){var a=\"__l\"+ ++u;y(a,[r],!0,[e,\"=\",g(\"ptr0\"),\"-pivot\",i,\"[pivot_ptr]\\n\",\"if(\",e,\"!==0){break \",a,\"}\"].join(\"\"))}else n.push([e,\"=\",g(d(r)),\"-pivot\",i].join(\"\"))}function k(e,r){t.length>1?m([e,r],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",\"tmp\")].join(\"\")):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",\"tmp\")].join(\"\"))}function T(e,r,i){t.length>1?(m([e,r,i],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",g(\"ptr2\")),\"\\n\",v(\"ptr2\",\"tmp\")].join(\"\")),n.push(\"++\"+r,\"--\"+i)):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"ptr2=\",d(i),\"\\n\",\"++\",r,\"\\n\",\"--\",i,\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",g(\"ptr2\")),\"\\n\",v(\"ptr2\",\"tmp\")].join(\"\"))}function A(t,e){k(t,e),n.push(\"--\"+e)}function M(e,r,i){t.length>1?m([e,r],!0,[v(\"ptr0\",g(\"ptr1\")),\"\\n\",v(\"ptr1\",[\"pivot\",i,\"[pivot_ptr]\"].join(\"\"))].join(\"\")):n.push(v(d(e),g(d(r))),v(d(r),\"pivot\"+i))}function S(e,r){n.push([\"if((\",r,\"-\",e,\")<=\",i,\"){\\n\",\"insertionSort(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}else{\\n\",s,\"(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}\"].join(\"\"))}function E(e,r,i){t.length>1?(n.push([\"__l\",++u,\":while(true){\"].join(\"\")),m([e],!0,[\"if(\",g(\"ptr0\"),\"!==pivot\",r,\"[pivot_ptr]){break __l\",u,\"}\"].join(\"\")),n.push(i,\"}\")):n.push([\"while(\",g(d(e)),\"===pivot\",r,\"){\",i,\"}\"].join(\"\"))}return n.push(\"var \"+h.join(\",\")),b(1,2),b(4,5),b(1,3),b(2,3),b(1,4),b(3,4),b(2,5),b(2,3),b(4,5),t.length>1?m([\"el1\",\"el2\",\"el3\",\"el4\",\"el5\",\"index1\",\"index3\",\"index5\"],!0,[\"pivot1[pivot_ptr]=\",g(\"ptr1\"),\"\\n\",\"pivot2[pivot_ptr]=\",g(\"ptr3\"),\"\\n\",\"pivots_are_equal=pivots_are_equal&&(pivot1[pivot_ptr]===pivot2[pivot_ptr])\\n\",\"x=\",g(\"ptr0\"),\"\\n\",\"y=\",g(\"ptr2\"),\"\\n\",\"z=\",g(\"ptr4\"),\"\\n\",v(\"ptr5\",\"x\"),\"\\n\",v(\"ptr6\",\"y\"),\"\\n\",v(\"ptr7\",\"z\")].join(\"\")):n.push([\"pivot1=\",g(d(\"el2\")),\"\\n\",\"pivot2=\",g(d(\"el4\")),\"\\n\",\"pivots_are_equal=pivot1===pivot2\\n\",\"x=\",g(d(\"el1\")),\"\\n\",\"y=\",g(d(\"el3\")),\"\\n\",\"z=\",g(d(\"el5\")),\"\\n\",v(d(\"index1\"),\"x\"),\"\\n\",v(d(\"index3\"),\"y\"),\"\\n\",v(d(\"index5\"),\"z\")].join(\"\")),_(\"index2\",\"left\"),_(\"index4\",\"right\"),n.push(\"if(pivots_are_equal){\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp\",\"k\",1),n.push(\"if(comp===0){continue}\"),n.push(\"if(comp<0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),n.push(\"while(true){\"),w(\"comp\",\"great\",1),n.push(\"if(comp>0){\"),n.push(\"great--\"),n.push(\"}else if(comp<0){\"),T(\"k\",\"less\",\"great\"),n.push(\"break\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}else{\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1<0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2>0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp>0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),T(\"k\",\"less\",\"great\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),M(\"left\",\"(less-1)\",1),M(\"right\",\"(great+1)\",2),S(\"left\",\"(less-2)\"),S(\"(great+2)\",\"right\"),n.push(\"if(pivots_are_equal){\"),x(),n.push(\"return\"),n.push(\"}\"),n.push(\"if(less<index1&&great>index5){\"),E(\"less\",1,\"++less\"),E(\"great\",2,\"--great\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1===0){\"),n.push(\"if(k!==less){\"),k(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2===0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp===0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),T(\"k\",\"less\",\"great\"),n.push(\"}else{\"),A(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),x(),S(\"less\",\"great\"),n.push(\"}return \"+s),t.length>1&&c?new Function(\"insertionSort\",\"malloc\",\"free\",n.join(\"\\n\"))(r,c[0],c[1]):new Function(\"insertionSort\",n.join(\"\\n\"))(r)}(t,e,m);return v(m,y)}},{\"typedarray-pool\":545}],448:[function(t,e,r){\"use strict\";var n=t(\"./lib/compile_sort.js\"),i={};e.exports=function(t){var e=t.order,r=t.dtype,a=[e,r].join(\":\"),o=i[a];return o||(i[a]=o=n(e,r)),o(t),t}},{\"./lib/compile_sort.js\":447}],449:[function(t,e,r){\"use strict\";var n=t(\"ndarray-linear-interpolate\"),i=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=new Array(_inline_3_arg4_)}\",args:[{name:\"_inline_3_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg2_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg3_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_3_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_4_arg2_(this_warped,_inline_4_arg0_),_inline_4_arg1_=_inline_4_arg3_.apply(void 0,this_warped)}\",args:[{name:\"_inline_4_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_4_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_4_arg4_\",lvalue:!1,rvalue:!1,count:0}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warpND\",blockSize:64}),a=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_7_arg2_(this_warped,_inline_7_arg0_),_inline_7_arg1_=_inline_7_arg3_(_inline_7_arg4_,this_warped[0])}\",args:[{name:\"_inline_7_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_7_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_7_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp1D\",blockSize:64}),o=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0,0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_10_arg2_(this_warped,_inline_10_arg0_),_inline_10_arg1_=_inline_10_arg3_(_inline_10_arg4_,this_warped[0],this_warped[1])}\",args:[{name:\"_inline_10_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_10_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_10_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp2D\",blockSize:64}),s=t(\"cwise/lib/wrapper\")({args:[\"index\",\"array\",\"scalar\",\"scalar\",\"scalar\"],pre:{body:\"{this_warped=[0,0,0]}\",args:[],thisVars:[\"this_warped\"],localVars:[]},body:{body:\"{_inline_13_arg2_(this_warped,_inline_13_arg0_),_inline_13_arg1_=_inline_13_arg3_(_inline_13_arg4_,this_warped[0],this_warped[1],this_warped[2])}\",args:[{name:\"_inline_13_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg1_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_13_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg3_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_13_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_warped\"],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},debug:!1,funcName:\"warp3D\",blockSize:64});e.exports=function(t,e,r){switch(e.shape.length){case 1:a(t,r,n.d1,e);break;case 2:o(t,r,n.d2,e);break;case 3:s(t,r,n.d3,e);break;default:i(t,r,n.bind(void 0,e),e.shape.length)}return t}},{\"cwise/lib/wrapper\":149,\"ndarray-linear-interpolate\":443}],450:[function(t,e,r){var n=t(\"iota-array\"),i=t(\"is-buffer\"),a=\"undefined\"!=typeof Float64Array;function o(t,e){return t[0]-e[0]}function s(){var t,e=this.stride,r=new Array(e.length);for(t=0;t<r.length;++t)r[t]=[Math.abs(e[t]),t];r.sort(o);var n=new Array(r.length);for(t=0;t<n.length;++t)n[t]=r[t][1];return n}function l(t,e){var r=[\"View\",e,\"d\",t].join(\"\");e<0&&(r=\"View_Nil\"+t);var i=\"generic\"===t;if(-1===e){var a=\"function \"+r+\"(a){this.data=a;};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return -1};proto.size=0;proto.dimension=-1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function(){return new \"+r+\"(this.data);};proto.get=proto.set=function(){};proto.pick=function(){return null};return function construct_\"+r+\"(a){return new \"+r+\"(a);}\";return new Function(a)()}if(0===e){a=\"function \"+r+\"(a,d) {this.data = a;this.offset = d};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return this.offset};proto.dimension=0;proto.size=1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function \"+r+\"_copy() {return new \"+r+\"(this.data,this.offset)};proto.pick=function \"+r+\"_pick(){return TrivialArray(this.data);};proto.valueOf=proto.get=function \"+r+\"_get(){return \"+(i?\"this.data.get(this.offset)\":\"this.data[this.offset]\")+\"};proto.set=function \"+r+\"_set(v){return \"+(i?\"this.data.set(this.offset,v)\":\"this.data[this.offset]=v\")+\"};return function construct_\"+r+\"(a,b,c,d){return new \"+r+\"(a,d)}\";return new Function(\"TrivialArray\",a)(c[t][0])}a=[\"'use strict'\"];var o=n(e),l=o.map(function(t){return\"i\"+t}),u=\"this.offset+\"+o.map(function(t){return\"this.stride[\"+t+\"]*i\"+t}).join(\"+\"),h=o.map(function(t){return\"b\"+t}).join(\",\"),f=o.map(function(t){return\"c\"+t}).join(\",\");a.push(\"function \"+r+\"(a,\"+h+\",\"+f+\",d){this.data=a\",\"this.shape=[\"+h+\"]\",\"this.stride=[\"+f+\"]\",\"this.offset=d|0}\",\"var proto=\"+r+\".prototype\",\"proto.dtype='\"+t+\"'\",\"proto.dimension=\"+e),a.push(\"Object.defineProperty(proto,'size',{get:function \"+r+\"_size(){return \"+o.map(function(t){return\"this.shape[\"+t+\"]\"}).join(\"*\"),\"}})\"),1===e?a.push(\"proto.order=[0]\"):(a.push(\"Object.defineProperty(proto,'order',{get:\"),e<4?(a.push(\"function \"+r+\"_order(){\"),2===e?a.push(\"return (Math.abs(this.stride[0])>Math.abs(this.stride[1]))?[1,0]:[0,1]}})\"):3===e&&a.push(\"var s0=Math.abs(this.stride[0]),s1=Math.abs(this.stride[1]),s2=Math.abs(this.stride[2]);if(s0>s1){if(s1>s2){return [2,1,0];}else if(s0>s2){return [1,2,0];}else{return [1,0,2];}}else if(s0>s2){return [2,0,1];}else if(s2>s1){return [0,1,2];}else{return [0,2,1];}}})\")):a.push(\"ORDER})\")),a.push(\"proto.set=function \"+r+\"_set(\"+l.join(\",\")+\",v){\"),i?a.push(\"return this.data.set(\"+u+\",v)}\"):a.push(\"return this.data[\"+u+\"]=v}\"),a.push(\"proto.get=function \"+r+\"_get(\"+l.join(\",\")+\"){\"),i?a.push(\"return this.data.get(\"+u+\")}\"):a.push(\"return this.data[\"+u+\"]}\"),a.push(\"proto.index=function \"+r+\"_index(\",l.join(),\"){return \"+u+\"}\"),a.push(\"proto.hi=function \"+r+\"_hi(\"+l.join(\",\")+\"){return new \"+r+\"(this.data,\"+o.map(function(t){return[\"(typeof i\",t,\"!=='number'||i\",t,\"<0)?this.shape[\",t,\"]:i\",t,\"|0\"].join(\"\")}).join(\",\")+\",\"+o.map(function(t){return\"this.stride[\"+t+\"]\"}).join(\",\")+\",this.offset)}\");var p=o.map(function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"}),d=o.map(function(t){return\"c\"+t+\"=this.stride[\"+t+\"]\"});a.push(\"proto.lo=function \"+r+\"_lo(\"+l.join(\",\")+\"){var b=this.offset,d=0,\"+p.join(\",\")+\",\"+d.join(\",\"));for(var g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){d=i\"+g+\"|0;b+=c\"+g+\"*d;a\"+g+\"-=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map(function(t){return\"a\"+t}).join(\",\")+\",\"+o.map(function(t){return\"c\"+t}).join(\",\")+\",b)}\"),a.push(\"proto.step=function \"+r+\"_step(\"+l.join(\",\")+\"){var \"+o.map(function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"}).join(\",\")+\",\"+o.map(function(t){return\"b\"+t+\"=this.stride[\"+t+\"]\"}).join(\",\")+\",c=this.offset,d=0,ceil=Math.ceil\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'){d=i\"+g+\"|0;if(d<0){c+=b\"+g+\"*(a\"+g+\"-1);a\"+g+\"=ceil(-a\"+g+\"/d)}else{a\"+g+\"=ceil(a\"+g+\"/d)}b\"+g+\"*=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map(function(t){return\"a\"+t}).join(\",\")+\",\"+o.map(function(t){return\"b\"+t}).join(\",\")+\",c)}\");var v=new Array(e),m=new Array(e);for(g=0;g<e;++g)v[g]=\"a[i\"+g+\"]\",m[g]=\"b[i\"+g+\"]\";a.push(\"proto.transpose=function \"+r+\"_transpose(\"+l+\"){\"+l.map(function(t,e){return t+\"=(\"+t+\"===undefined?\"+e+\":\"+t+\"|0)\"}).join(\";\"),\"var a=this.shape,b=this.stride;return new \"+r+\"(this.data,\"+v.join(\",\")+\",\"+m.join(\",\")+\",this.offset)}\"),a.push(\"proto.pick=function \"+r+\"_pick(\"+l+\"){var a=[],b=[],c=this.offset\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){c=(c+this.stride[\"+g+\"]*i\"+g+\")|0}else{a.push(this.shape[\"+g+\"]);b.push(this.stride[\"+g+\"])}\");return a.push(\"var ctor=CTOR_LIST[a.length+1];return ctor(this.data,a,b,c)}\"),a.push(\"return function construct_\"+r+\"(data,shape,stride,offset){return new \"+r+\"(data,\"+o.map(function(t){return\"shape[\"+t+\"]\"}).join(\",\")+\",\"+o.map(function(t){return\"stride[\"+t+\"]\"}).join(\",\")+\",offset)}\"),new Function(\"CTOR_LIST\",\"ORDER\",a.join(\"\\n\"))(c[t],s)}var c={float32:[],float64:[],int8:[],int16:[],int32:[],uint8:[],uint16:[],uint32:[],array:[],uint8_clamped:[],buffer:[],generic:[]};e.exports=function(t,e,r,n){if(void 0===t)return(0,c.array[0])([]);\"number\"==typeof t&&(t=[t]),void 0===e&&(e=[t.length]);var o=e.length;if(void 0===r){r=new Array(o);for(var s=o-1,u=1;s>=0;--s)r[s]=u,u*=e[s]}if(void 0===n)for(n=0,s=0;s<o;++s)r[s]<0&&(n-=(e[s]-1)*r[s]);for(var h=function(t){if(i(t))return\"buffer\";if(a)switch(Object.prototype.toString.call(t)){case\"[object Float64Array]\":return\"float64\";case\"[object Float32Array]\":return\"float32\";case\"[object Int8Array]\":return\"int8\";case\"[object Int16Array]\":return\"int16\";case\"[object Int32Array]\":return\"int32\";case\"[object Uint8Array]\":return\"uint8\";case\"[object Uint16Array]\":return\"uint16\";case\"[object Uint32Array]\":return\"uint32\";case\"[object Uint8ClampedArray]\":return\"uint8_clamped\"}return Array.isArray(t)?\"array\":\"generic\"}(t),f=c[h];f.length<=o+1;)f.push(l(h,f.length-1));return(0,f[o+1])(t,e,r,n)}},{\"iota-array\":416,\"is-buffer\":418}],451:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=Math.pow(2,-1074),a=-1>>>0;e.exports=function(t,e){if(isNaN(t)||isNaN(e))return NaN;if(t===e)return t;if(0===t)return e<0?-i:i;var r=n.hi(t),o=n.lo(t);e>t==t>0?o===a?(r+=1,o=0):o+=1:0===o?(o=a,r-=1):o-=1;return n.pack(o,r)}},{\"double-bits\":167}],452:[function(t,e,r){var n=Math.PI,i=c(120);function a(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function o(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}function s(t,e,r,a,o,c,u,h,f,p){if(p)k=p[0],T=p[1],_=p[2],w=p[3];else{var d=l(t,e,-o);t=d.x,e=d.y;var g=(t-(h=(d=l(h,f,-o)).x))/2,v=(e-(f=d.y))/2,m=g*g/(r*r)+v*v/(a*a);m>1&&(r*=m=Math.sqrt(m),a*=m);var y=r*r,x=a*a,b=(c==u?-1:1)*Math.sqrt(Math.abs((y*x-y*v*v-x*g*g)/(y*v*v+x*g*g)));b==1/0&&(b=1);var _=b*r*v/a+(t+h)/2,w=b*-a*g/r+(e+f)/2,k=Math.asin(((e-w)/a).toFixed(9)),T=Math.asin(((f-w)/a).toFixed(9));(k=t<_?n-k:k)<0&&(k=2*n+k),(T=h<_?n-T:T)<0&&(T=2*n+T),u&&k>T&&(k-=2*n),!u&&T>k&&(T-=2*n)}if(Math.abs(T-k)>i){var A=T,M=h,S=f;T=k+i*(u&&T>k?1:-1);var E=s(h=_+r*Math.cos(T),f=w+a*Math.sin(T),r,a,o,0,u,M,S,[T,A,_,w])}var C=Math.tan((T-k)/4),L=4/3*r*C,P=4/3*a*C,O=[2*t-(t+L*Math.sin(k)),2*e-(e-P*Math.cos(k)),h+L*Math.sin(T),f-P*Math.cos(T),h,f];if(p)return O;E&&(O=O.concat(E));for(var z=0;z<O.length;){var I=l(O[z],O[z+1],o);O[z++]=I.x,O[z++]=I.y}return O}function l(t,e,r){return{x:t*Math.cos(r)-e*Math.sin(r),y:t*Math.sin(r)+e*Math.cos(r)}}function c(t){return t*(n/180)}e.exports=function(t){for(var e,r=[],n=0,i=0,l=0,u=0,h=null,f=null,p=0,d=0,g=0,v=t.length;g<v;g++){var m=t[g],y=m[0];switch(y){case\"M\":l=m[1],u=m[2];break;case\"A\":(m=s(p,d,m[1],m[2],c(m[3]),m[4],m[5],m[6],m[7])).unshift(\"C\"),m.length>7&&(r.push(m.splice(0,7)),m.unshift(\"C\"));break;case\"S\":var x=p,b=d;\"C\"!=e&&\"S\"!=e||(x+=x-n,b+=b-i),m=[\"C\",x,b,m[1],m[2],m[3],m[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(h=2*p-h,f=2*d-f):(h=p,f=d),m=o(p,d,h,f,m[1],m[2]);break;case\"Q\":h=m[1],f=m[2],m=o(p,d,m[1],m[2],m[3],m[4]);break;case\"L\":m=a(p,d,m[1],m[2]);break;case\"H\":m=a(p,d,m[1],d);break;case\"V\":m=a(p,d,p,m[1]);break;case\"Z\":m=a(p,d,l,u)}e=y,p=m[m.length-2],d=m[m.length-1],m.length>4?(n=m[m.length-4],i=m[m.length-3]):(n=p,i=d),r.push(m)}return r}},{}],453:[function(t,e,r){r.vertexNormals=function(t,e,r){for(var n=e.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o)i[o]=[0,0,0];for(o=0;o<t.length;++o)for(var s=t[o],l=0,c=s[s.length-1],u=s[0],h=0;h<s.length;++h){l=c,c=u,u=s[(h+1)%s.length];for(var f=e[l],p=e[c],d=e[u],g=new Array(3),v=0,m=new Array(3),y=0,x=0;x<3;++x)g[x]=f[x]-p[x],v+=g[x]*g[x],m[x]=d[x]-p[x],y+=m[x]*m[x];if(v*y>a){var b=i[c],_=1/Math.sqrt(v*y);for(x=0;x<3;++x){var w=(x+1)%3,k=(x+2)%3;b[x]+=_*(m[w]*g[k]-m[k]*g[w])}}}for(o=0;o<n;++o){b=i[o];var T=0;for(x=0;x<3;++x)T+=b[x]*b[x];if(T>a)for(_=1/Math.sqrt(T),x=0;x<3;++x)b[x]*=_;else for(x=0;x<3;++x)b[x]=0}return i},r.faceNormals=function(t,e,r){for(var n=t.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o){for(var s=t[o],l=new Array(3),c=0;c<3;++c)l[c]=e[s[c]];var u=new Array(3),h=new Array(3);for(c=0;c<3;++c)u[c]=l[1][c]-l[0][c],h[c]=l[2][c]-l[0][c];var f=new Array(3),p=0;for(c=0;c<3;++c){var d=(c+1)%3,g=(c+2)%3;f[c]=u[d]*h[g]-u[g]*h[d],p+=f[c]*f[c]}p=p>a?1/Math.sqrt(p):0;for(c=0;c<3;++c)f[c]*=p;i[o]=f}return i}},{}],454:[function(t,e,r){\"use strict\";var n=Object.getOwnPropertySymbols,i=Object.prototype.hasOwnProperty,a=Object.prototype.propertyIsEnumerable;e.exports=function(){try{if(!Object.assign)return!1;var t=new String(\"abc\");if(t[5]=\"de\",\"5\"===Object.getOwnPropertyNames(t)[0])return!1;for(var e={},r=0;r<10;r++)e[\"_\"+String.fromCharCode(r)]=r;if(\"0123456789\"!==Object.getOwnPropertyNames(e).map(function(t){return e[t]}).join(\"\"))return!1;var n={};return\"abcdefghijklmnopqrst\".split(\"\").forEach(function(t){n[t]=t}),\"abcdefghijklmnopqrst\"===Object.keys(Object.assign({},n)).join(\"\")}catch(t){return!1}}()?Object.assign:function(t,e){for(var r,o,s=function(t){if(null==t)throw new TypeError(\"Object.assign cannot be called with null or undefined\");return Object(t)}(t),l=1;l<arguments.length;l++){for(var c in r=Object(arguments[l]))i.call(r,c)&&(s[c]=r[c]);if(n){o=n(r);for(var u=0;u<o.length;u++)a.call(r,o[u])&&(s[o[u]]=r[o[u]])}}return s}},{}],455:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a,o,s,l,c){var u=e+a+c;if(h>0){var h=Math.sqrt(u+1);t[0]=.5*(o-l)/h,t[1]=.5*(s-n)/h,t[2]=.5*(r-a)/h,t[3]=.5*h}else{var f=Math.max(e,a,c),h=Math.sqrt(2*f-u+1);e>=f?(t[0]=.5*h,t[1]=.5*(i+r)/h,t[2]=.5*(s+n)/h,t[3]=.5*(o-l)/h):a>=f?(t[0]=.5*(r+i)/h,t[1]=.5*h,t[2]=.5*(l+o)/h,t[3]=.5*(s-n)/h):(t[0]=.5*(n+s)/h,t[1]=.5*(o+l)/h,t[2]=.5*h,t[3]=.5*(r-i)/h)}return t}},{}],456:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.rotation||[0,0,0,1],n=t.radius||1;e=[].slice.call(e,0,3),u(r=[].slice.call(r,0,4),r);var i=new h(r,e,Math.log(n));i.setDistanceLimits(t.zoomMin,t.zoomMax),(\"eye\"in t||\"up\"in t)&&i.lookAt(0,t.eye,t.center,t.up);return i};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/lookAt\"),a=t(\"gl-mat4/fromQuat\"),o=t(\"gl-mat4/invert\"),s=t(\"./lib/quatFromFrame\");function l(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function c(t,e,r,n){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2)+Math.pow(n,2))}function u(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=c(r,n,i,a);o>1e-6?(t[0]=r/o,t[1]=n/o,t[2]=i/o,t[3]=a/o):(t[0]=t[1]=t[2]=0,t[3]=1)}function h(t,e,r){this.radius=n([r]),this.center=n(e),this.rotation=n(t),this.computedRadius=this.radius.curve(0),this.computedCenter=this.center.curve(0),this.computedRotation=this.rotation.curve(0),this.computedUp=[.1,0,0],this.computedEye=[.1,0,0],this.computedMatrix=[.1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],this.recalcMatrix(0)}var f=h.prototype;f.lastT=function(){return Math.max(this.radius.lastT(),this.center.lastT(),this.rotation.lastT())},f.recalcMatrix=function(t){this.radius.curve(t),this.center.curve(t),this.rotation.curve(t);var e=this.computedRotation;u(e,e);var r=this.computedMatrix;a(r,e);var n=this.computedCenter,i=this.computedEye,o=this.computedUp,s=Math.exp(this.computedRadius[0]);i[0]=n[0]+s*r[2],i[1]=n[1]+s*r[6],i[2]=n[2]+s*r[10],o[0]=r[1],o[1]=r[5],o[2]=r[9];for(var l=0;l<3;++l){for(var c=0,h=0;h<3;++h)c+=r[l+4*h]*i[h];r[12+l]=-c}},f.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r},f.idle=function(t){this.center.idle(t),this.radius.idle(t),this.rotation.idle(t)},f.flush=function(t){this.center.flush(t),this.radius.flush(t),this.rotation.flush(t)},f.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=i[1],o=i[5],s=i[9],c=l(a,o,s);a/=c,o/=c,s/=c;var u=i[0],h=i[4],f=i[8],p=u*a+h*o+f*s,d=l(u-=a*p,h-=o*p,f-=s*p);u/=d,h/=d,f/=d;var g=i[2],v=i[6],m=i[10],y=g*a+v*o+m*s,x=g*u+v*h+m*f,b=l(g-=y*a+x*u,v-=y*o+x*h,m-=y*s+x*f);g/=b,v/=b,m/=b;var _=u*e+a*r,w=h*e+o*r,k=f*e+s*r;this.center.move(t,_,w,k);var T=Math.exp(this.computedRadius[0]);T=Math.max(1e-4,T+n),this.radius.set(t,Math.log(T))},f.rotate=function(t,e,r,n){this.recalcMatrix(t),e=e||0,r=r||0;var i=this.computedMatrix,a=i[0],o=i[4],s=i[8],u=i[1],h=i[5],f=i[9],p=i[2],d=i[6],g=i[10],v=e*a+r*u,m=e*o+r*h,y=e*s+r*f,x=-(d*y-g*m),b=-(g*v-p*y),_=-(p*m-d*v),w=Math.sqrt(Math.max(0,1-Math.pow(x,2)-Math.pow(b,2)-Math.pow(_,2))),k=c(x,b,_,w);k>1e-6?(x/=k,b/=k,_/=k,w/=k):(x=b=_=0,w=1);var T=this.computedRotation,A=T[0],M=T[1],S=T[2],E=T[3],C=A*w+E*x+M*_-S*b,L=M*w+E*b+S*x-A*_,P=S*w+E*_+A*b-M*x,O=E*w-A*x-M*b-S*_;if(n){x=p,b=d,_=g;var z=Math.sin(n)/l(x,b,_);x*=z,b*=z,_*=z,O=O*(w=Math.cos(e))-(C=C*w+O*x+L*_-P*b)*x-(L=L*w+O*b+P*x-C*_)*b-(P=P*w+O*_+C*b-L*x)*_}var I=c(C,L,P,O);I>1e-6?(C/=I,L/=I,P/=I,O/=I):(C=L=P=0,O=1),this.rotation.set(t,C,L,P,O)},f.lookAt=function(t,e,r,n){this.recalcMatrix(t),r=r||this.computedCenter,e=e||this.computedEye,n=n||this.computedUp;var a=this.computedMatrix;i(a,e,r,n);var o=this.computedRotation;s(o,a[0],a[1],a[2],a[4],a[5],a[6],a[8],a[9],a[10]),u(o,o),this.rotation.set(t,o[0],o[1],o[2],o[3]);for(var l=0,c=0;c<3;++c)l+=Math.pow(r[c]-e[c],2);this.radius.set(t,.5*Math.log(Math.max(l,1e-6))),this.center.set(t,r[0],r[1],r[2])},f.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},f.setMatrix=function(t,e){var r=this.computedRotation;s(r,e[0],e[1],e[2],e[4],e[5],e[6],e[8],e[9],e[10]),u(r,r),this.rotation.set(t,r[0],r[1],r[2],r[3]);var n=this.computedMatrix;o(n,e);var i=n[15];if(Math.abs(i)>1e-6){var a=n[12]/i,l=n[13]/i,c=n[14]/i;this.recalcMatrix(t);var h=Math.exp(this.computedRadius[0]);this.center.set(t,a-n[2]*h,l-n[6]*h,c-n[10]*h),this.radius.idle(t)}else this.center.idle(t),this.radius.idle(t)},f.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},f.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},f.getDistanceLimits=function(t){var e=this.radius.bounds;return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},f.toJSON=function(){return this.recalcMatrix(this.lastT()),{center:this.computedCenter.slice(),rotation:this.computedRotation.slice(),distance:Math.log(this.computedRadius[0]),zoomMin:this.radius.bounds[0][0],zoomMax:this.radius.bounds[1][0]}},f.fromJSON=function(t){var e=this.lastT(),r=t.center;r&&this.center.set(e,r[0],r[1],r[2]);var n=t.rotation;n&&this.rotation.set(e,n[0],n[1],n[2],n[3]);var i=t.distance;i&&i>0&&this.radius.set(e,Math.log(i)),this.setDistanceLimits(t.zoomMin,t.zoomMax)}},{\"./lib/quatFromFrame\":455,\"filtered-vector\":226,\"gl-mat4/fromQuat\":262,\"gl-mat4/invert\":265,\"gl-mat4/lookAt\":266}],457:[function(t,e,r){\"use strict\";var n=t(\"repeat-string\");e.exports=function(t,e,r){return n(r=\"undefined\"!=typeof r?r+\"\":\" \",e)+t}},{\"repeat-string\":503}],458:[function(t,e,r){\"use strict\";function n(t,e){if(\"string\"!=typeof t)return[t];var r=[t];\"string\"==typeof e||Array.isArray(e)?e={brackets:e}:e||(e={});var n=e.brackets?Array.isArray(e.brackets)?e.brackets:[e.brackets]:[\"{}\",\"[]\",\"()\"],i=e.escape||\"___\",a=!!e.flat;n.forEach(function(t){var e=new RegExp([\"\\\\\",t[0],\"[^\\\\\",t[0],\"\\\\\",t[1],\"]*\\\\\",t[1]].join(\"\")),n=[];function a(e,a,o){var s=r.push(e.slice(t[0].length,-t[1].length))-1;return n.push(s),i+s+i}r.forEach(function(t,n){for(var i,o=0;t!=i;)if(i=t,t=t.replace(e,a),o++>1e4)throw Error(\"References have circular dependency. Please, check them.\");r[n]=t}),n=n.reverse(),r=r.map(function(e){return n.forEach(function(r){e=e.replace(new RegExp(\"(\\\\\"+i+r+\"\\\\\"+i+\")\",\"g\"),t[0]+\"$1\"+t[1])}),e})});var o=new RegExp(\"\\\\\"+i+\"([0-9]+)\\\\\"+i);return a?r:function t(e,r,n){for(var i,a=[],s=0;i=o.exec(e);){if(s++>1e4)throw Error(\"Circular references in parenthesis\");a.push(e.slice(0,i.index)),a.push(t(r[i[1]],r)),e=e.slice(i.index+i[0].length)}return a.push(e),a}(r[0],r)}function i(t,e){if(e&&e.flat){var r,n=e&&e.escape||\"___\",i=t[0];if(!i)return\"\";for(var a=new RegExp(\"\\\\\"+n+\"([0-9]+)\\\\\"+n),o=0;i!=r;){if(o++>1e4)throw Error(\"Circular references in \"+t);r=i,i=i.replace(a,s)}return i}return t.reduce(function t(e,r){return Array.isArray(r)&&(r=r.reduce(t,\"\")),e+r},\"\");function s(e,r){if(null==t[r])throw Error(\"Reference \"+r+\"is undefined\");return t[r]}}function a(t,e){return Array.isArray(t)?i(t,e):n(t,e)}a.parse=n,a.stringify=i,e.exports=a},{}],459:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\");e.exports=function(t){var e;arguments.length>1&&(t=arguments);\"string\"==typeof t?t=t.split(/\\s/).map(parseFloat):\"number\"==typeof t&&(t=[t]);t.length&&\"number\"==typeof t[0]?e=1===t.length?{width:t[0],height:t[0],x:0,y:0}:2===t.length?{width:t[0],height:t[1],x:0,y:0}:{x:t[0],y:t[1],width:t[2]-t[0]||0,height:t[3]-t[1]||0}:t&&(t=n(t,{left:\"x l left Left\",top:\"y t top Top\",width:\"w width W Width\",height:\"h height W Width\",bottom:\"b bottom Bottom\",right:\"r right Right\"}),e={x:t.left||0,y:t.top||0},null==t.width?t.right?e.width=t.right-e.x:e.width=0:e.width=t.width,null==t.height?t.bottom?e.height=t.bottom-e.y:e.height=0:e.height=t.height);return e}},{\"pick-by-alias\":465}],460:[function(t,e,r){e.exports=function(t){var e=[];return t.replace(i,function(t,r,i){var o=r.toLowerCase();for(i=function(t){var e=t.match(a);return e?e.map(Number):[]}(i),\"m\"==o&&i.length>2&&(e.push([r].concat(i.splice(0,2))),o=\"l\",r=\"m\"==r?\"l\":\"L\");;){if(i.length==n[o])return i.unshift(r),e.push(i);if(i.length<n[o])throw new Error(\"malformed path data\");e.push([r].concat(i.splice(0,n[o])))}}),e};var n={a:7,c:6,h:1,l:2,m:2,q:4,s:4,t:2,v:1,z:0},i=/([astvzqmhlc])([^astvzqmhlc]*)/gi;var a=/-?[0-9]*\\.?[0-9]+(?:e[-+]?\\d+)?/gi},{}],461:[function(t,e,r){e.exports=function(t,e){e||(e=[0,\"\"]),t=String(t);var r=parseFloat(t,10);return e[0]=r,e[1]=t.match(/[\\d.\\-\\+]*\\s*(.*)/)[1]||\"\",e}},{}],462:[function(t,e,r){(function(t){(function(){var r,n,i,a,o,s;\"undefined\"!=typeof performance&&null!==performance&&performance.now?e.exports=function(){return performance.now()}:\"undefined\"!=typeof t&&null!==t&&t.hrtime?(e.exports=function(){return(r()-o)/1e6},n=t.hrtime,a=(r=function(){var t;return 1e9*(t=n())[0]+t[1]})(),s=1e9*t.uptime(),o=a-s):Date.now?(e.exports=function(){return Date.now()-i},i=Date.now()):(e.exports=function(){return(new Date).getTime()-i},i=(new Date).getTime())}).call(this)}).call(this,t(\"_process\"))},{_process:482}],463:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<n){for(var r=1,a=0;a<e;++a)for(var o=0;o<a;++o)if(t[a]<t[o])r=-r;else if(t[a]===t[o])return 0;return r}for(var s=i.mallocUint8(e),a=0;a<e;++a)s[a]=0;for(var r=1,a=0;a<e;++a)if(!s[a]){var l=1;s[a]=1;for(var o=t[a];o!==a;o=t[o]){if(s[o])return i.freeUint8(s),0;l+=1,s[o]=1}1&l||(r=-r)}return i.freeUint8(s),r};var n=32,i=t(\"typedarray-pool\")},{\"typedarray-pool\":545}],464:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"invert-permutation\");r.rank=function(t){var e=t.length;switch(e){case 0:case 1:return 0;case 2:return t[1]}var r,a,o,s=n.mallocUint32(e),l=n.mallocUint32(e),c=0;for(i(t,l),o=0;o<e;++o)s[o]=t[o];for(o=e-1;o>0;--o)a=l[o],r=s[o],s[o]=s[a],s[a]=r,l[o]=l[r],l[r]=a,c=(c+r)*o;return n.freeUint32(l),n.freeUint32(s),c},r.unrank=function(t,e,r){switch(t){case 0:return r||[];case 1:return r?(r[0]=0,r):[0];case 2:return r?(e?(r[0]=0,r[1]=1):(r[0]=1,r[1]=0),r):e?[0,1]:[1,0]}var n,i,a,o=1;for((r=r||new Array(t))[0]=0,a=1;a<t;++a)r[a]=a,o=o*a|0;for(a=t-1;a>0;--a)e=e-(n=e/o|0)*o|0,o=o/a|0,i=0|r[a],r[a]=0|r[n],r[n]=0|i;return r}},{\"invert-permutation\":415,\"typedarray-pool\":545}],465:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n,a,o={};if(\"string\"==typeof e&&(e=i(e)),Array.isArray(e)){var s={};for(a=0;a<e.length;a++)s[e[a]]=!0;e=s}for(n in e)e[n]=i(e[n]);var l={};for(n in e){var c=e[n];if(Array.isArray(c))for(a=0;a<c.length;a++){var u=c[a];if(r&&(l[u]=!0),u in t){if(o[n]=t[u],r)for(var h=a;h<c.length;h++)l[c[h]]=!0;break}}else n in t&&(e[n]&&(o[n]=t[n]),r&&(l[n]=!0))}if(r)for(n in t)l[n]||(o[n]=t[n]);return o};var n={};function i(t){return n[t]?n[t]:(\"string\"==typeof t&&(t=n[t]=t.split(/\\s*,\\s*|\\s+/)),t)}},{}],466:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=0|e.length,i=t.length,a=[new Array(r),new Array(r)],o=0;o<r;++o)a[0][o]=[],a[1][o]=[];for(var o=0;o<i;++o){var s=t[o];a[0][s[0]].push(s),a[1][s[1]].push(s)}for(var l=[],o=0;o<r;++o)a[0][o].length+a[1][o].length===0&&l.push([o]);function c(t,e){var r=a[e][t[e]];r.splice(r.indexOf(t),1)}function u(t,r,i){for(var o,s,l,u=0;u<2;++u)if(a[u][r].length>0){o=a[u][r][0],l=u;break}s=o[1^l];for(var h=0;h<2;++h)for(var f=a[h][r],p=0;p<f.length;++p){var d=f[p],g=d[1^h],v=n(e[t],e[r],e[s],e[g]);v>0&&(o=d,s=g,l=h)}return i?s:(o&&c(o,l),s)}function h(t,r){var i=a[r][t][0],o=[t];c(i,r);for(var s=i[1^r];;){for(;s!==t;)o.push(s),s=u(o[o.length-2],s,!1);if(a[0][t].length+a[1][t].length===0)break;var l=o[o.length-1],h=t,f=o[1],p=u(l,h,!0);if(n(e[l],e[h],e[f],e[p])<0)break;o.push(t),s=u(l,h)}return o}function f(t,e){return e[1]===e[e.length-1]}for(var o=0;o<r;++o)for(var p=0;p<2;++p){for(var d=[];a[p][o].length>0;){a[0][o].length;var g=h(o,p);f(d,g)?d.push.apply(d,g):(d.length>0&&l.push(d),d=g)}d.length>0&&l.push(d)}return l};var n=t(\"compare-angle\")},{\"compare-angle\":127}],467:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=n(t,e.length),i=new Array(e.length),a=new Array(e.length),o=[],s=0;s<e.length;++s){var l=r[s].length;a[s]=l,i[s]=!0,l<=1&&o.push(s)}for(;o.length>0;){var c=o.pop();i[c]=!1;for(var u=r[c],s=0;s<u.length;++s){var h=u[s];0==--a[h]&&o.push(h)}}for(var f=new Array(e.length),p=[],s=0;s<e.length;++s)if(i[s]){var c=p.length;f[s]=c,p.push(e[s])}else f[s]=-1;for(var d=[],s=0;s<t.length;++s){var g=t[s];i[g[0]]&&i[g[1]]&&d.push([f[g[0]],f[g[1]]])}return[d,p]};var n=t(\"edges-to-adjacency-list\")},{\"edges-to-adjacency-list\":171}],468:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=c(t,e);t=r[0];for(var h=(e=r[1]).length,f=(t.length,n(t,e.length)),p=0;p<h;++p)if(f[p].length%2==1)throw new Error(\"planar-graph-to-polyline: graph must be manifold\");var d=i(t,e);for(var g=(d=d.filter(function(t){for(var r=t.length,n=[0],i=0;i<r;++i){var a=e[t[i]],l=e[t[(i+1)%r]],c=o(-a[0],a[1]),u=o(-a[0],l[1]),h=o(l[0],a[1]),f=o(l[0],l[1]);n=s(n,s(s(c,u),s(h,f)))}return n[n.length-1]>0})).length,v=new Array(g),m=new Array(g),p=0;p<g;++p){v[p]=p;var y=new Array(g),x=d[p].map(function(t){return e[t]}),b=a([x]),_=0;t:for(var w=0;w<g;++w)if(y[w]=0,p!==w){for(var k=d[w],T=k.length,A=0;A<T;++A){var M=b(e[k[A]]);if(0!==M){M<0&&(y[w]=1,_+=1);continue t}}y[w]=1,_+=1}m[p]=[_,p,y]}m.sort(function(t,e){return e[0]-t[0]});for(var p=0;p<g;++p)for(var y=m[p],S=y[1],E=y[2],w=0;w<g;++w)E[w]&&(v[w]=S);for(var C=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=[];return e}(g),p=0;p<g;++p)C[p].push(v[p]),C[v[p]].push(p);for(var L={},P=u(h,!1),p=0;p<g;++p)for(var k=d[p],T=k.length,w=0;w<T;++w){var O=k[w],z=k[(w+1)%T],I=Math.min(O,z)+\":\"+Math.max(O,z);if(I in L){var D=L[I];C[D].push(p),C[p].push(D),P[O]=P[z]=!0}else L[I]=p}function R(t){for(var e=t.length,r=0;r<e;++r)if(!P[t[r]])return!1;return!0}for(var F=[],B=u(g,-1),p=0;p<g;++p)v[p]!==p||R(d[p])?B[p]=-1:(F.push(p),B[p]=0);var r=[];for(;F.length>0;){var N=F.pop(),j=C[N];l(j,function(t,e){return t-e});var U,V=j.length,q=B[N];if(0===q){var k=d[N];U=[k]}for(var p=0;p<V;++p){var H=j[p];if(!(B[H]>=0)&&(B[H]=1^q,F.push(H),0===q)){var k=d[H];R(k)||(k.reverse(),U.push(k))}}0===q&&r.push(U)}return r};var n=t(\"edges-to-adjacency-list\"),i=t(\"planar-dual\"),a=t(\"point-in-big-polygon\"),o=t(\"two-product\"),s=t(\"robust-sum\"),l=t(\"uniq\"),c=t(\"./lib/trim-leaves\");function u(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}},{\"./lib/trim-leaves\":467,\"edges-to-adjacency-list\":171,\"planar-dual\":466,\"point-in-big-polygon\":472,\"robust-sum\":515,\"two-product\":543,uniq:547}],469:[function(t,e,r){\"use strict\";e.exports=t(\"./quad\")},{\"./quad\":471}],470:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],471:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"clamp\"),a=t(\"parse-rect\"),o=t(\"array-bounds\"),s=t(\"pick-by-alias\"),l=t(\"defined\"),c=t(\"flatten-vertex-data\"),u=t(\"is-obj\"),h=t(\"dtype\"),f=t(\"math-log2\");function p(t,e){for(var r=e[0],n=e[1],a=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=i((t[2*l]-r)*a,0,1),s[2*l+1]=i((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,\"float64\"),e=s(e,{bounds:\"range bounds dataBox databox\",maxDepth:\"depth maxDepth maxdepth level maxLevel maxlevel levels\",dtype:\"type dtype format out dst output destination\"});var r=l(e.maxDepth,255),i=l(e.bounds,o(t,2));i[0]===i[2]&&i[2]++,i[1]===i[3]&&i[3]++;var d,g=p(t,i),v=t.length>>>1;e.dtype||(e.dtype=\"array\"),\"string\"==typeof e.dtype?d=new(h(e.dtype))(v):e.dtype&&(d=e.dtype,Array.isArray(d)&&(d.length=v));for(var m=0;m<v;++m)d[m]=m;var y=[],x=[],b=[],_=[];!function t(e,n,i,a,o,s){if(!a.length)return null;var l=y[o]||(y[o]=[]);var c=b[o]||(b[o]=[]);var u=x[o]||(x[o]=[]);var h=l.length;o++;if(o>r){for(var f=0;f<a.length;f++)l.push(a[f]),c.push(s),u.push(null,null,null,null);return h}l.push(a[0]);c.push(s);if(a.length<=1)return u.push(null,null,null,null),h;var p=.5*i;var d=e+p,v=n+p;var m=[],_=[],w=[],k=[];for(var T=1,A=a.length;T<A;T++){var M=a[T],S=g[2*M],E=g[2*M+1];S<d?E<v?m.push(M):_.push(M):E<v?w.push(M):k.push(M)}s<<=2;u.push(t(e,n,p,m,o,s),t(e,v,p,_,o,s+1),t(d,n,p,w,o,s+2),t(d,v,p,k,o,s+3));return h}(0,0,1,d,0,1);for(var w=0,k=0;k<y.length;k++){var T=y[k];if(d.set)d.set(T,w);else for(var A=0,M=T.length;A<M;A++)d[A+w]=T[A];var S=w+y[k].length;_[k]=[w,S],w=S}return d.range=function(){var e,r=[],o=arguments.length;for(;o--;)r[o]=arguments[o];if(u(r[r.length-1])){var c=r.pop();r.length||null==c.x&&null==c.l&&null==c.left||(r=[c],e={}),e=s(c,{level:\"level maxLevel\",d:\"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize\",lod:\"lod details ranges offsets\"})}else e={};r.length||(r=i);var h=a.apply(void 0,r),d=[Math.min(h.x,h.x+h.width),Math.min(h.y,h.y+h.height),Math.max(h.x,h.x+h.width),Math.max(h.y,h.y+h.height)],g=d[0],v=d[1],m=d[2],w=d[3],k=p([g,v,m,w],i),T=k[0],A=k[1],M=k[2],S=k[3],C=l(e.level,y.length);if(null!=e.d){var L;\"number\"==typeof e.d?L=[e.d,e.d]:e.d.length&&(L=e.d),C=Math.min(Math.max(Math.ceil(-f(Math.abs(L[0])/(i[2]-i[0]))),Math.ceil(-f(Math.abs(L[1])/(i[3]-i[1])))),C)}if(C=Math.min(C,y.length),e.lod)return function(t,e,r,i,a){for(var o=[],s=0;s<a;s++){var l=b[s],c=_[s][0],u=E(t,e,s),h=E(r,i,s),f=n.ge(l,u),p=n.gt(l,h,f,l.length-1);o[s]=[f+c,p+c]}return o}(T,A,M,S,C);var P=[];return function e(r,n,i,a,o,s){if(null!==o&&null!==s){var l=r+i,c=n+i;if(!(T>l||A>c||M<r||S<n||a>=C||o===s)){var u=y[a];void 0===s&&(s=u.length);for(var h=o;h<s;h++){var f=u[h],p=t[2*f],d=t[2*f+1];p>=g&&p<=m&&d>=v&&d<=w&&P.push(f)}var b=x[a],_=b[4*o+0],k=b[4*o+1],E=b[4*o+2],L=b[4*o+3],O=function(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}(b,o+1),z=.5*i,I=a+1;e(r,n,z,I,_,k||E||L||O),e(r,n+z,z,I,k,E||L||O),e(r+z,n,z,I,E,L||O),e(r+z,n+z,z,I,L,O)}}}(0,0,1,0,0,1),P},d;function E(t,e,r){for(var n=1,i=.5,a=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<i?e<a?0:1:e<a?2:3,o*=.5,i+=t<i?-o:o,a+=e<a?-o:o;return n}}},{\"array-bounds\":65,\"binary-search-bounds\":470,clamp:115,defined:164,dtype:169,\"flatten-vertex-data\":227,\"is-obj\":421,\"math-log2\":432,\"parse-rect\":459,\"pick-by-alias\":465}],472:[function(t,e,r){e.exports=function(t){for(var e=t.length,r=[],a=[],s=0;s<e;++s)for(var u=t[s],h=u.length,f=h-1,p=0;p<h;f=p++){var d=u[f],g=u[p];d[0]===g[0]?a.push([d,g]):r.push([d,g])}if(0===r.length)return 0===a.length?c:(v=l(a),function(t){return v(t[0],t[1])?0:1});var v;var m=i(r),y=function(t,e){return function(r){var i=o.le(e,r[0]);if(i<0)return 1;var a=t[i];if(!a){if(!(i>0&&e[i]===r[0]))return 1;a=t[i-1]}for(var s=1;a;){var l=a.key,c=n(r,l[0],l[1]);if(l[0][0]<l[1][0])if(c<0)a=a.left;else{if(!(c>0))return 0;s=-1,a=a.right}else if(c>0)a=a.left;else{if(!(c<0))return 0;s=1,a=a.right}}return s}}(m.slabs,m.coordinates);return 0===a.length?y:function(t,e){return function(r){return t(r[0],r[1])?0:e(r)}}(l(a),y)};var n=t(\"robust-orientation\")[3],i=t(\"slab-decomposition\"),a=t(\"interval-tree-1d\"),o=t(\"binary-search-bounds\");function s(){return!0}function l(t){for(var e={},r=0;r<t.length;++r){var n=t[r],i=n[0][0],o=n[0][1],l=n[1][1],c=[Math.min(o,l),Math.max(o,l)];i in e?e[i].push(c):e[i]=[c]}var u={},h=Object.keys(e);for(r=0;r<h.length;++r){var f=e[h[r]];u[h[r]]=a(f)}return function(t){return function(e,r){var n=t[e];return!!n&&!!n.queryPoint(r,s)}}(u)}function c(t){return 1}},{\"binary-search-bounds\":91,\"interval-tree-1d\":414,\"robust-orientation\":510,\"slab-decomposition\":526}],473:[function(t,e,r){var n,i=t(\"./lib/build-log\"),a=t(\"./lib/epsilon\"),o=t(\"./lib/intersecter\"),s=t(\"./lib/segment-chainer\"),l=t(\"./lib/segment-selector\"),c=t(\"./lib/geojson\"),u=!1,h=a();function f(t,e,r){var i=n.segments(t),a=n.segments(e),o=r(n.combine(i,a));return n.polygon(o)}n={buildLog:function(t){return!0===t?u=i():!1===t&&(u=!1),!1!==u&&u.list},epsilon:function(t){return h.epsilon(t)},segments:function(t){var e=o(!0,h,u);return t.regions.forEach(e.addRegion),{segments:e.calculate(t.inverted),inverted:t.inverted}},combine:function(t,e){return{combined:o(!1,h,u).calculate(t.segments,t.inverted,e.segments,e.inverted),inverted1:t.inverted,inverted2:e.inverted}},selectUnion:function(t){return{segments:l.union(t.combined,u),inverted:t.inverted1||t.inverted2}},selectIntersect:function(t){return{segments:l.intersect(t.combined,u),inverted:t.inverted1&&t.inverted2}},selectDifference:function(t){return{segments:l.difference(t.combined,u),inverted:t.inverted1&&!t.inverted2}},selectDifferenceRev:function(t){return{segments:l.differenceRev(t.combined,u),inverted:!t.inverted1&&t.inverted2}},selectXor:function(t){return{segments:l.xor(t.combined,u),inverted:t.inverted1!==t.inverted2}},polygon:function(t){return{regions:s(t.segments,h,u),inverted:t.inverted}},polygonFromGeoJSON:function(t){return c.toPolygon(n,t)},polygonToGeoJSON:function(t){return c.fromPolygon(n,h,t)},union:function(t,e){return f(t,e,n.selectUnion)},intersect:function(t,e){return f(t,e,n.selectIntersect)},difference:function(t,e){return f(t,e,n.selectDifference)},differenceRev:function(t,e){return f(t,e,n.selectDifferenceRev)},xor:function(t,e){return f(t,e,n.selectXor)}},\"object\"==typeof window&&(window.PolyBool=n),e.exports=n},{\"./lib/build-log\":474,\"./lib/epsilon\":475,\"./lib/geojson\":476,\"./lib/intersecter\":477,\"./lib/segment-chainer\":479,\"./lib/segment-selector\":480}],474:[function(t,e,r){e.exports=function(){var t,e=0,r=!1;function n(e,r){return t.list.push({type:e,data:r?JSON.parse(JSON.stringify(r)):void 0}),t}return t={list:[],segmentId:function(){return e++},checkIntersection:function(t,e){return n(\"check\",{seg1:t,seg2:e})},segmentChop:function(t,e){return n(\"div_seg\",{seg:t,pt:e}),n(\"chop\",{seg:t,pt:e})},statusRemove:function(t){return n(\"pop_seg\",{seg:t})},segmentUpdate:function(t){return n(\"seg_update\",{seg:t})},segmentNew:function(t,e){return n(\"new_seg\",{seg:t,primary:e})},segmentRemove:function(t){return n(\"rem_seg\",{seg:t})},tempStatus:function(t,e,r){return n(\"temp_status\",{seg:t,above:e,below:r})},rewind:function(t){return n(\"rewind\",{seg:t})},status:function(t,e,r){return n(\"status\",{seg:t,above:e,below:r})},vert:function(e){return e===r?t:(r=e,n(\"vert\",{x:e}))},log:function(t){return\"string\"!=typeof t&&(t=JSON.stringify(t,!1,\"  \")),n(\"log\",{txt:t})},reset:function(){return n(\"reset\")},selected:function(t){return n(\"selected\",{segs:t})},chainStart:function(t){return n(\"chain_start\",{seg:t})},chainRemoveHead:function(t,e){return n(\"chain_rem_head\",{index:t,pt:e})},chainRemoveTail:function(t,e){return n(\"chain_rem_tail\",{index:t,pt:e})},chainNew:function(t,e){return n(\"chain_new\",{pt1:t,pt2:e})},chainMatch:function(t){return n(\"chain_match\",{index:t})},chainClose:function(t){return n(\"chain_close\",{index:t})},chainAddHead:function(t,e){return n(\"chain_add_head\",{index:t,pt:e})},chainAddTail:function(t,e){return n(\"chain_add_tail\",{index:t,pt:e})},chainConnect:function(t,e){return n(\"chain_con\",{index1:t,index2:e})},chainReverse:function(t){return n(\"chain_rev\",{index:t})},chainJoin:function(t,e){return n(\"chain_join\",{index1:t,index2:e})},done:function(){return n(\"done\")}}}},{}],475:[function(t,e,r){e.exports=function(t){\"number\"!=typeof t&&(t=1e-10);var e={epsilon:function(e){return\"number\"==typeof e&&(t=e),t},pointAboveOrOnLine:function(e,r,n){var i=r[0],a=r[1],o=n[0],s=n[1],l=e[0];return(o-i)*(e[1]-a)-(s-a)*(l-i)>=-t},pointBetween:function(e,r,n){var i=e[1]-r[1],a=n[0]-r[0],o=e[0]-r[0],s=n[1]-r[1],l=o*a+i*s;return!(l<t||l-(a*a+s*s)>-t)},pointsSameX:function(e,r){return Math.abs(e[0]-r[0])<t},pointsSameY:function(e,r){return Math.abs(e[1]-r[1])<t},pointsSame:function(t,r){return e.pointsSameX(t,r)&&e.pointsSameY(t,r)},pointsCompare:function(t,r){return e.pointsSameX(t,r)?e.pointsSameY(t,r)?0:t[1]<r[1]?-1:1:t[0]<r[0]?-1:1},pointsCollinear:function(e,r,n){var i=e[0]-r[0],a=e[1]-r[1],o=r[0]-n[0],s=r[1]-n[1];return Math.abs(i*s-o*a)<t},linesIntersect:function(e,r,n,i){var a=r[0]-e[0],o=r[1]-e[1],s=i[0]-n[0],l=i[1]-n[1],c=a*l-o*s;if(Math.abs(c)<t)return!1;var u=e[0]-n[0],h=e[1]-n[1],f=(s*h-l*u)/c,p=(a*h-o*u)/c,d={alongA:0,alongB:0,pt:[e[0]+f*a,e[1]+f*o]};return d.alongA=f<=-t?-2:f<t?-1:f-1<=-t?0:f-1<t?1:2,d.alongB=p<=-t?-2:p<t?-1:p-1<=-t?0:p-1<t?1:2,d},pointInsideRegion:function(e,r){for(var n=e[0],i=e[1],a=r[r.length-1][0],o=r[r.length-1][1],s=!1,l=0;l<r.length;l++){var c=r[l][0],u=r[l][1];u-i>t!=o-i>t&&(a-c)*(i-u)/(o-u)+c-n>t&&(s=!s),a=c,o=u}return s}};return e}},{}],476:[function(t,e,r){var n={toPolygon:function(t,e){function r(e){if(e.length<=0)return t.segments({inverted:!1,regions:[]});function r(e){var r=e.slice(0,e.length-1);return t.segments({inverted:!1,regions:[r]})}for(var n=r(e[0]),i=1;i<e.length;i++)n=t.selectDifference(t.combine(n,r(e[i])));return n}if(\"Polygon\"===e.type)return t.polygon(r(e.coordinates));if(\"MultiPolygon\"===e.type){for(var n=t.segments({inverted:!1,regions:[]}),i=0;i<e.coordinates.length;i++)n=t.selectUnion(t.combine(n,r(e.coordinates[i])));return t.polygon(n)}throw new Error(\"PolyBool: Cannot convert GeoJSON object to PolyBool polygon\")},fromPolygon:function(t,e,r){function n(t,r){return e.pointInsideRegion([.5*(t[0][0]+t[1][0]),.5*(t[0][1]+t[1][1])],r)}function i(t){return{region:t,children:[]}}r=t.polygon(t.segments(r));var a=i(null);function o(t,e){for(var r=0;r<t.children.length;r++){if(n(e,(s=t.children[r]).region))return void o(s,e)}var a=i(e);for(r=0;r<t.children.length;r++){var s;n((s=t.children[r]).region,e)&&(a.children.push(s),t.children.splice(r,1),r--)}t.children.push(a)}for(var s=0;s<r.regions.length;s++){var l=r.regions[s];l.length<3||o(a,l)}function c(t,e){for(var r=0,n=t[t.length-1][0],i=t[t.length-1][1],a=[],o=0;o<t.length;o++){var s=t[o][0],l=t[o][1];a.push([s,l]),r+=l*n-s*i,n=s,i=l}return r<0!==e&&a.reverse(),a.push([a[0][0],a[0][1]]),a}var u=[];function h(t){var e=[c(t.region,!1)];u.push(e);for(var r=0;r<t.children.length;r++)e.push(f(t.children[r]))}function f(t){for(var e=0;e<t.children.length;e++)h(t.children[e]);return c(t.region,!0)}for(s=0;s<a.children.length;s++)h(a.children[s]);return u.length<=0?{type:\"Polygon\",coordinates:[]}:1==u.length?{type:\"Polygon\",coordinates:u[0]}:{type:\"MultiPolygon\",coordinates:u}}};e.exports=n},{}],477:[function(t,e,r){var n=t(\"./linked-list\");e.exports=function(t,e,r){function i(t,e,n){return{id:r?r.segmentId():-1,start:t,end:e,myFill:{above:n.myFill.above,below:n.myFill.below},otherFill:null}}var a=n.create();function o(t,r){a.insertBefore(t,function(n){return function(t,r,n,i,a,o){var s=e.pointsCompare(r,a);return 0!==s?s:e.pointsSame(n,o)?0:t!==i?t?1:-1:e.pointAboveOrOnLine(n,i?a:o,i?o:a)?1:-1}(t.isStart,t.pt,r,n.isStart,n.pt,n.other.pt)<0})}function s(t,e){var r=function(t,e){var r=n.node({isStart:!0,pt:t.start,seg:t,primary:e,other:null,status:null});return o(r,t.end),r}(t,e);return function(t,e,r){var i=n.node({isStart:!1,pt:e.end,seg:e,primary:r,other:t,status:null});t.other=i,o(i,t.pt)}(r,t,e),r}function l(t,e){var n=i(e,t.seg.end,t.seg);return function(t,e){r&&r.segmentChop(t.seg,e),t.other.remove(),t.seg.end=e,t.other.pt=e,o(t.other,t.pt)}(t,e),s(n,t.primary)}function c(i,o){var s=n.create();function c(t){return s.findTransition(function(r){var n,i,a,o,s,l;return n=t,i=r.ev,a=n.seg.start,o=n.seg.end,s=i.seg.start,l=i.seg.end,(e.pointsCollinear(a,s,l)?e.pointsCollinear(o,s,l)?1:e.pointAboveOrOnLine(o,s,l)?1:-1:e.pointAboveOrOnLine(a,s,l)?1:-1)>0})}function u(t,n){var i=t.seg,a=n.seg,o=i.start,s=i.end,c=a.start,u=a.end;r&&r.checkIntersection(i,a);var h=e.linesIntersect(o,s,c,u);if(!1===h){if(!e.pointsCollinear(o,s,c))return!1;if(e.pointsSame(o,u)||e.pointsSame(s,c))return!1;var f=e.pointsSame(o,c),p=e.pointsSame(s,u);if(f&&p)return n;var d=!f&&e.pointBetween(o,c,u),g=!p&&e.pointBetween(s,c,u);if(f)return g?l(n,s):l(t,u),n;d&&(p||(g?l(n,s):l(t,u)),l(n,o))}else 0===h.alongA&&(-1===h.alongB?l(t,c):0===h.alongB?l(t,h.pt):1===h.alongB&&l(t,u)),0===h.alongB&&(-1===h.alongA?l(n,o):0===h.alongA?l(n,h.pt):1===h.alongA&&l(n,s));return!1}for(var h=[];!a.isEmpty();){var f=a.getHead();if(r&&r.vert(f.pt[0]),f.isStart){r&&r.segmentNew(f.seg,f.primary);var p=c(f),d=p.before?p.before.ev:null,g=p.after?p.after.ev:null;function v(){if(d){var t=u(f,d);if(t)return t}return!!g&&u(f,g)}r&&r.tempStatus(f.seg,!!d&&d.seg,!!g&&g.seg);var m,y,x=v();if(x)t?(y=null===f.seg.myFill.below||f.seg.myFill.above!==f.seg.myFill.below)&&(x.seg.myFill.above=!x.seg.myFill.above):x.seg.otherFill=f.seg.myFill,r&&r.segmentUpdate(x.seg),f.other.remove(),f.remove();if(a.getHead()!==f){r&&r.rewind(f.seg);continue}t?(y=null===f.seg.myFill.below||f.seg.myFill.above!==f.seg.myFill.below,f.seg.myFill.below=g?g.seg.myFill.above:i,f.seg.myFill.above=y?!f.seg.myFill.below:f.seg.myFill.below):null===f.seg.otherFill&&(m=g?f.primary===g.primary?g.seg.otherFill.above:g.seg.myFill.above:f.primary?o:i,f.seg.otherFill={above:m,below:m}),r&&r.status(f.seg,!!d&&d.seg,!!g&&g.seg),f.other.status=p.insert(n.node({ev:f}))}else{var b=f.status;if(null===b)throw new Error(\"PolyBool: Zero-length segment detected; your epsilon is probably too small or too large\");if(s.exists(b.prev)&&s.exists(b.next)&&u(b.prev.ev,b.next.ev),r&&r.statusRemove(b.ev.seg),b.remove(),!f.primary){var _=f.seg.myFill;f.seg.myFill=f.seg.otherFill,f.seg.otherFill=_}h.push(f.seg)}a.getHead().remove()}return r&&r.done(),h}return t?{addRegion:function(t){for(var n,i,a,o=t[t.length-1],l=0;l<t.length;l++){n=o,o=t[l];var c=e.pointsCompare(n,o);0!==c&&s((i=c<0?n:o,a=c<0?o:n,{id:r?r.segmentId():-1,start:i,end:a,myFill:{above:null,below:null},otherFill:null}),!0)}},calculate:function(t){return c(t,!1)}}:{calculate:function(t,e,r,n){return t.forEach(function(t){s(i(t.start,t.end,t),!0)}),r.forEach(function(t){s(i(t.start,t.end,t),!1)}),c(e,n)}}}},{\"./linked-list\":478}],478:[function(t,e,r){e.exports={create:function(){var t={root:{root:!0,next:null},exists:function(e){return null!==e&&e!==t.root},isEmpty:function(){return null===t.root.next},getHead:function(){return t.root.next},insertBefore:function(e,r){for(var n=t.root,i=t.root.next;null!==i;){if(r(i))return e.prev=i.prev,e.next=i,i.prev.next=e,void(i.prev=e);n=i,i=i.next}n.next=e,e.prev=n,e.next=null},findTransition:function(e){for(var r=t.root,n=t.root.next;null!==n&&!e(n);)r=n,n=n.next;return{before:r===t.root?null:r,after:n,insert:function(t){return t.prev=r,t.next=n,r.next=t,null!==n&&(n.prev=t),t}}}};return t},node:function(t){return t.prev=null,t.next=null,t.remove=function(){t.prev.next=t.next,t.next&&(t.next.prev=t.prev),t.prev=null,t.next=null},t}}},{}],479:[function(t,e,r){e.exports=function(t,e,r){var n=[],i=[];return t.forEach(function(t){var a=t.start,o=t.end;if(e.pointsSame(a,o))console.warn(\"PolyBool: Warning: Zero-length segment detected; your epsilon is probably too small or too large\");else{r&&r.chainStart(t);for(var s={index:0,matches_head:!1,matches_pt1:!1},l={index:0,matches_head:!1,matches_pt1:!1},c=s,u=0;u<n.length;u++){var h=(v=n[u])[0],f=(v[1],v[v.length-1]);if(v[v.length-2],e.pointsSame(h,a)){if(T(u,!0,!0))break}else if(e.pointsSame(h,o)){if(T(u,!0,!1))break}else if(e.pointsSame(f,a)){if(T(u,!1,!0))break}else if(e.pointsSame(f,o)&&T(u,!1,!1))break}if(c===s)return n.push([a,o]),void(r&&r.chainNew(a,o));if(c===l){r&&r.chainMatch(s.index);var p=s.index,d=s.matches_pt1?o:a,g=s.matches_head,v=n[p],m=g?v[0]:v[v.length-1],y=g?v[1]:v[v.length-2],x=g?v[v.length-1]:v[0],b=g?v[v.length-2]:v[1];return e.pointsCollinear(y,m,d)&&(g?(r&&r.chainRemoveHead(s.index,d),v.shift()):(r&&r.chainRemoveTail(s.index,d),v.pop()),m=y),e.pointsSame(x,d)?(n.splice(p,1),e.pointsCollinear(b,x,m)&&(g?(r&&r.chainRemoveTail(s.index,m),v.pop()):(r&&r.chainRemoveHead(s.index,m),v.shift())),r&&r.chainClose(s.index),void i.push(v)):void(g?(r&&r.chainAddHead(s.index,d),v.unshift(d)):(r&&r.chainAddTail(s.index,d),v.push(d)))}var _=s.index,w=l.index;r&&r.chainConnect(_,w);var k=n[_].length<n[w].length;s.matches_head?l.matches_head?k?(A(_),M(_,w)):(A(w),M(w,_)):M(w,_):l.matches_head?M(_,w):k?(A(_),M(w,_)):(A(w),M(_,w))}function T(t,e,r){return c.index=t,c.matches_head=e,c.matches_pt1=r,c===s?(c=l,!1):(c=null,!0)}function A(t){r&&r.chainReverse(t),n[t].reverse()}function M(t,i){var a=n[t],o=n[i],s=a[a.length-1],l=a[a.length-2],c=o[0],u=o[1];e.pointsCollinear(l,s,c)&&(r&&r.chainRemoveTail(t,s),a.pop(),s=l),e.pointsCollinear(s,c,u)&&(r&&r.chainRemoveHead(i,c),o.shift()),r&&r.chainJoin(t,i),n[t]=a.concat(o),n.splice(i,1)}}),i}},{}],480:[function(t,e,r){function n(t,e,r){var n=[];return t.forEach(function(t){var i=(t.myFill.above?8:0)+(t.myFill.below?4:0)+(t.otherFill&&t.otherFill.above?2:0)+(t.otherFill&&t.otherFill.below?1:0);0!==e[i]&&n.push({id:r?r.segmentId():-1,start:t.start,end:t.end,myFill:{above:1===e[i],below:2===e[i]},otherFill:null})}),r&&r.selected(n),n}var i={union:function(t,e){return n(t,[0,2,1,0,2,2,0,0,1,0,1,0,0,0,0,0],e)},intersect:function(t,e){return n(t,[0,0,0,0,0,2,0,2,0,0,1,1,0,2,1,0],e)},difference:function(t,e){return n(t,[0,0,0,0,2,0,2,0,1,1,0,0,0,1,2,0],e)},differenceRev:function(t,e){return n(t,[0,2,1,0,0,0,1,1,0,2,0,2,0,0,0,0],e)},xor:function(t,e){return n(t,[0,2,1,0,2,0,0,1,1,0,0,2,0,1,2,0],e)}};e.exports=i},{}],481:[function(t,e,r){\"use strict\";var n=new Float64Array(4),i=new Float64Array(4),a=new Float64Array(4);e.exports=function(t,e,r,o,s){n.length<o.length&&(n=new Float64Array(o.length),i=new Float64Array(o.length),a=new Float64Array(o.length));for(var l=0;l<o.length;++l)n[l]=t[l]-o[l],i[l]=e[l]-t[l],a[l]=r[l]-t[l];var c=0,u=0,h=0,f=0,p=0,d=0;for(l=0;l<o.length;++l){var g=i[l],v=a[l],m=n[l];c+=g*g,u+=g*v,h+=v*v,f+=m*g,p+=m*v,d+=m*m}var y,x,b,_,w,k=Math.abs(c*h-u*u),T=u*p-h*f,A=u*f-c*p;if(T+A<=k)if(T<0)A<0&&f<0?(A=0,-f>=c?(T=1,y=c+2*f+d):y=f*(T=-f/c)+d):(T=0,p>=0?(A=0,y=d):-p>=h?(A=1,y=h+2*p+d):y=p*(A=-p/h)+d);else if(A<0)A=0,f>=0?(T=0,y=d):-f>=c?(T=1,y=c+2*f+d):y=f*(T=-f/c)+d;else{var M=1/k;y=(T*=M)*(c*T+u*(A*=M)+2*f)+A*(u*T+h*A+2*p)+d}else T<0?(b=h+p)>(x=u+f)?(_=b-x)>=(w=c-2*u+h)?(T=1,A=0,y=c+2*f+d):y=(T=_/w)*(c*T+u*(A=1-T)+2*f)+A*(u*T+h*A+2*p)+d:(T=0,b<=0?(A=1,y=h+2*p+d):p>=0?(A=0,y=d):y=p*(A=-p/h)+d):A<0?(b=c+f)>(x=u+p)?(_=b-x)>=(w=c-2*u+h)?(A=1,T=0,y=h+2*p+d):y=(T=1-(A=_/w))*(c*T+u*A+2*f)+A*(u*T+h*A+2*p)+d:(A=0,b<=0?(T=1,y=c+2*f+d):f>=0?(T=0,y=d):y=f*(T=-f/c)+d):(_=h+p-u-f)<=0?(T=0,A=1,y=h+2*p+d):_>=(w=c-2*u+h)?(T=1,A=0,y=c+2*f+d):y=(T=_/w)*(c*T+u*(A=1-T)+2*f)+A*(u*T+h*A+2*p)+d;var S=1-T-A;for(l=0;l<o.length;++l)s[l]=S*t[l]+T*e[l]+A*r[l];return y<0?0:y}},{}],482:[function(t,e,r){var n,i,a=e.exports={};function o(){throw new Error(\"setTimeout has not been defined\")}function s(){throw new Error(\"clearTimeout has not been defined\")}function l(t){if(n===setTimeout)return setTimeout(t,0);if((n===o||!n)&&setTimeout)return n=setTimeout,setTimeout(t,0);try{return n(t,0)}catch(e){try{return n.call(null,t,0)}catch(e){return n.call(this,t,0)}}}!function(){try{n=\"function\"==typeof setTimeout?setTimeout:o}catch(t){n=o}try{i=\"function\"==typeof clearTimeout?clearTimeout:s}catch(t){i=s}}();var c,u=[],h=!1,f=-1;function p(){h&&c&&(h=!1,c.length?u=c.concat(u):f=-1,u.length&&d())}function d(){if(!h){var t=l(p);h=!0;for(var e=u.length;e;){for(c=u,u=[];++f<e;)c&&c[f].run();f=-1,e=u.length}c=null,h=!1,function(t){if(i===clearTimeout)return clearTimeout(t);if((i===s||!i)&&clearTimeout)return i=clearTimeout,clearTimeout(t);try{i(t)}catch(e){try{return i.call(null,t)}catch(e){return i.call(this,t)}}}(t)}}function g(t,e){this.fun=t,this.array=e}function v(){}a.nextTick=function(t){var e=new Array(arguments.length-1);if(arguments.length>1)for(var r=1;r<arguments.length;r++)e[r-1]=arguments[r];u.push(new g(t,e)),1!==u.length||h||l(d)},g.prototype.run=function(){this.fun.apply(null,this.array)},a.title=\"browser\",a.browser=!0,a.env={},a.argv=[],a.version=\"\",a.versions={},a.on=v,a.addListener=v,a.once=v,a.off=v,a.removeListener=v,a.removeAllListeners=v,a.emit=v,a.prependListener=v,a.prependOnceListener=v,a.listeners=function(t){return[]},a.binding=function(t){throw new Error(\"process.binding is not supported\")},a.cwd=function(){return\"/\"},a.chdir=function(t){throw new Error(\"process.chdir is not supported\")},a.umask=function(){return 0}},{}],483:[function(t,e,r){e.exports=t(\"gl-quat/slerp\")},{\"gl-quat/slerp\":293}],484:[function(t,e,r){(function(r){for(var n=t(\"performance-now\"),i=\"undefined\"==typeof window?r:window,a=[\"moz\",\"webkit\"],o=\"AnimationFrame\",s=i[\"request\"+o],l=i[\"cancel\"+o]||i[\"cancelRequest\"+o],c=0;!s&&c<a.length;c++)s=i[a[c]+\"Request\"+o],l=i[a[c]+\"Cancel\"+o]||i[a[c]+\"CancelRequest\"+o];if(!s||!l){var u=0,h=0,f=[];s=function(t){if(0===f.length){var e=n(),r=Math.max(0,1e3/60-(e-u));u=r+e,setTimeout(function(){var t=f.slice(0);f.length=0;for(var e=0;e<t.length;e++)if(!t[e].cancelled)try{t[e].callback(u)}catch(t){setTimeout(function(){throw t},0)}},Math.round(r))}return f.push({handle:++h,callback:t,cancelled:!1}),h},l=function(t){for(var e=0;e<f.length;e++)f[e].handle===t&&(f[e].cancelled=!0)}}e.exports=function(t){return s.call(i,t)},e.exports.cancel=function(){l.apply(i,arguments)},e.exports.polyfill=function(t){t||(t=i),t.requestAnimationFrame=s,t.cancelAnimationFrame=l}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"performance-now\":462}],485:[function(t,e,r){\"use strict\";var n=t(\"big-rat/add\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/add\":75}],486:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t.length),r=0;r<t.length;++r)e[r]=n(t[r]);return e};var n=t(\"big-rat\")},{\"big-rat\":78}],487:[function(t,e,r){\"use strict\";var n=t(\"big-rat\"),i=t(\"big-rat/mul\");e.exports=function(t,e){for(var r=n(e),a=t.length,o=new Array(a),s=0;s<a;++s)o[s]=i(t[s],r);return o}},{\"big-rat\":78,\"big-rat/mul\":87}],488:[function(t,e,r){\"use strict\";var n=t(\"big-rat/sub\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/sub\":89}],489:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"compare-oriented-cell\"),a=t(\"cell-orientation\");e.exports=function(t){t.sort(i);for(var e=t.length,r=0,o=0;o<e;++o){var s=t[o],l=a(s);if(0!==l){if(r>0){var c=t[r-1];if(0===n(s,c)&&a(c)!==l){r-=1;continue}}t[r++]=s}}return t.length=r,t}},{\"cell-orientation\":112,\"compare-cell\":128,\"compare-oriented-cell\":129}],490:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\"),i=t(\"color-normalize\"),a=t(\"update-diff\"),o=t(\"pick-by-alias\"),s=t(\"object-assign\"),l=t(\"flatten-vertex-data\"),c=t(\"to-float32\"),u=c.float32,h=c.fract32;e.exports=function(t,e){\"function\"==typeof t?(e||(e={}),e.regl=t):e=t;e.length&&(e.positions=e);if(!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");var r,c,p,d,g,v,m=t._gl,y={color:\"black\",capSize:5,lineWidth:1,opacity:1,viewport:null,range:null,offset:0,count:0,bounds:null,positions:[],errors:[]},x=[];return d=t.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array(0)}),c=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),p=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),g=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),v=t.buffer({usage:\"static\",type:\"float\",data:f}),k(e),r=t({vert:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tattribute vec2 position, positionFract;\\n\\t\\tattribute vec4 error;\\n\\t\\tattribute vec4 color;\\n\\n\\t\\tattribute vec2 direction, lineOffset, capOffset;\\n\\n\\t\\tuniform vec4 viewport;\\n\\t\\tuniform float lineWidth, capSize;\\n\\t\\tuniform vec2 scale, scaleFract, translate, translateFract;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tfragColor = color / 255.;\\n\\n\\t\\t\\tvec2 pixelOffset = lineWidth * lineOffset + (capSize + lineWidth) * capOffset;\\n\\n\\t\\t\\tvec2 dxy = -step(.5, direction.xy) * error.xz + step(direction.xy, vec2(-.5)) * error.yw;\\n\\n\\t\\t\\tvec2 position = position + dxy;\\n\\n\\t\\t\\tvec2 pos = (position + translate) * scale\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scale\\n\\t\\t\\t\\t+ (position + translate) * scaleFract\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scaleFract;\\n\\n\\t\\t\\tpos += pixelOffset / viewport.zw;\\n\\n\\t\\t\\tgl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\t\\t}\\n\\t\\t\",frag:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tuniform float opacity;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tgl_FragColor = fragColor;\\n\\t\\t\\tgl_FragColor.a *= opacity;\\n\\t\\t}\\n\\t\\t\",uniforms:{range:t.prop(\"range\"),lineWidth:t.prop(\"lineWidth\"),capSize:t.prop(\"capSize\"),opacity:t.prop(\"opacity\"),scale:t.prop(\"scale\"),translate:t.prop(\"translate\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{color:{buffer:d,offset:function(t,e){return 4*e.offset},divisor:1},position:{buffer:c,offset:function(t,e){return 8*e.offset},divisor:1},positionFract:{buffer:p,offset:function(t,e){return 8*e.offset},divisor:1},error:{buffer:g,offset:function(t,e){return 16*e.offset},divisor:1},direction:{buffer:v,stride:24,offset:0},lineOffset:{buffer:v,stride:24,offset:8},capOffset:{buffer:v,stride:24,offset:16}},primitive:\"triangles\",blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:!1,instances:t.prop(\"count\"),count:f.length}),s(b,{update:k,draw:_,destroy:T,regl:t,gl:m,canvas:m.canvas,groups:x}),b;function b(t){t?k(t):null===t&&T(),_()}function _(e){if(\"number\"==typeof e)return w(e);e&&!Array.isArray(e)&&(e=[e]),t._refresh(),x.forEach(function(t,r){t&&(e&&(e[r]?t.draw=!0:t.draw=!1),t.draw?w(r):t.draw=!0)})}function w(t){\"number\"==typeof t&&(t=x[t]),null!=t&&t&&t.count&&t.color&&t.opacity&&t.positions&&t.positions.length>1&&(t.scaleRatio=[t.scale[0]*t.viewport.width,t.scale[1]*t.viewport.height],r(t),t.after&&t.after(t))}function k(t){if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var e=0,r=0;if(b.groups=x=t.map(function(t,c){var u=x[c];return t?(\"function\"==typeof t?t={after:t}:\"number\"==typeof t[0]&&(t={positions:t}),t=o(t,{color:\"color colors fill\",capSize:\"capSize cap capsize cap-size\",lineWidth:\"lineWidth line-width width line thickness\",opacity:\"opacity alpha\",range:\"range dataBox\",viewport:\"viewport viewBox\",errors:\"errors error\",positions:\"positions position data points\"}),u||(x[c]=u={id:c,scale:null,translate:null,scaleFract:null,translateFract:null,draw:!0},t=s({},y,t)),a(u,t,[{lineWidth:function(t){return.5*+t},capSize:function(t){return.5*+t},opacity:parseFloat,errors:function(t){return t=l(t),r+=t.length,t},positions:function(t,r){return t=l(t,\"float64\"),r.count=Math.floor(t.length/2),r.bounds=n(t,2),r.offset=e,e+=r.count,t}},{color:function(t,e){var r=e.count;if(t||(t=\"transparent\"),!Array.isArray(t)||\"number\"==typeof t[0]){var n=t;t=Array(r);for(var a=0;a<r;a++)t[a]=n}if(t.length<r)throw Error(\"Not enough colors\");for(var o=new Uint8Array(4*r),s=0;s<r;s++){var l=i(t[s],\"uint8\");o.set(l,4*s)}return o},range:function(t,e,r){var n=e.bounds;return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=h(e.scale),e.translateFract=h(e.translate),t},viewport:function(t){var e;return Array.isArray(t)?e={x:t[0],y:t[1],width:t[2]-t[0],height:t[3]-t[1]}:t?(e={x:t.x||t.left||0,y:t.y||t.top||0},t.right?e.width=t.right-e.x:e.width=t.w||t.width||0,t.bottom?e.height=t.bottom-e.y:e.height=t.h||t.height||0):e={x:0,y:0,width:m.drawingBufferWidth,height:m.drawingBufferHeight},e}}]),u):u}),e||r){var f=x.reduce(function(t,e,r){return t+(e?e.count:0)},0),v=new Float64Array(2*f),_=new Uint8Array(4*f),w=new Float32Array(4*f);x.forEach(function(t,e){if(t){var r=t.positions,n=t.count,i=t.offset,a=t.color,o=t.errors;n&&(_.set(a,4*i),w.set(o,4*i),v.set(r,2*i))}}),c(u(v)),p(h(v)),d(_),g(w)}}}function T(){c.destroy(),p.destroy(),d.destroy(),g.destroy(),v.destroy()}};var f=[[1,0,0,1,0,0],[1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,1,0,0],[1,0,0,1,0,0],[1,0,-1,0,0,1],[1,0,-1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,1],[1,0,-1,0,0,1],[-1,0,-1,0,0,1],[-1,0,-1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,1],[-1,0,-1,0,0,1],[0,1,1,0,0,0],[0,1,-1,0,0,0],[0,-1,-1,0,0,0],[0,-1,-1,0,0,0],[0,1,1,0,0,0],[0,-1,1,0,0,0],[0,1,0,-1,1,0],[0,1,0,-1,-1,0],[0,1,0,1,-1,0],[0,1,0,1,1,0],[0,1,0,-1,1,0],[0,1,0,1,-1,0],[0,-1,0,-1,1,0],[0,-1,0,-1,-1,0],[0,-1,0,1,-1,0],[0,-1,0,1,1,0],[0,-1,0,-1,1,0],[0,-1,0,1,-1,0]]},{\"array-bounds\":65,\"color-normalize\":120,\"flatten-vertex-data\":227,\"object-assign\":454,\"pick-by-alias\":465,\"to-float32\":538,\"update-diff\":549}],491:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\"),i=t(\"array-bounds\"),a=t(\"object-assign\"),o=t(\"glslify\"),s=t(\"pick-by-alias\"),l=t(\"flatten-vertex-data\"),c=t(\"earcut\"),u=t(\"array-normalize\"),h=t(\"to-float32\"),f=h.float32,p=h.fract32,d=t(\"es6-weak-map\"),g=t(\"parse-rect\");function v(t,e){if(!(this instanceof v))return new v(t,e);if(\"function\"==typeof t?(e||(e={}),e.regl=t):e=t,e.length&&(e.positions=e),!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");this.gl=t._gl,this.regl=t,this.passes=[],this.shaders=v.shaders.has(t)?v.shaders.get(t):v.shaders.set(t,v.createShaders(t)).get(t),this.update(e)}e.exports=v,v.dashMult=2,v.maxPatternLength=256,v.precisionThreshold=3e6,v.maxPoints=1e4,v.maxLines=2048,v.shaders=new d,v.createShaders=function(t){var e,r=t.buffer({usage:\"static\",type:\"float\",data:[0,1,0,0,1,1,1,0]}),n={primitive:\"triangle strip\",instances:t.prop(\"count\"),count:4,offset:0,uniforms:{miterMode:function(t,e){return\"round\"===e.join?2:1},miterLimit:t.prop(\"miterLimit\"),scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),thickness:t.prop(\"thickness\"),dashPattern:t.prop(\"dashTexture\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),dashSize:t.prop(\"dashLength\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]},depth:t.prop(\"depth\")},blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:function(t,e){return!e.overlay}},stencil:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\")},i=t(a({vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, aCoordFract, bCoordFract;\\nattribute vec4 color;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvec2 project(vec2 position, vec2 positionFract, vec2 scale, vec2 scaleFract, vec2 translate, vec2 translateFract) {\\n\\t// the order is important\\n\\treturn position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n}\\n\\nvoid main() {\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineOffset = lineTop * 2. - 1.;\\n\\n\\tvec2 diff = (bCoord + bCoordFract - aCoord - aCoordFract);\\n\\ttangent = normalize(diff * scale * viewport.zw);\\n\\tvec2 normal = vec2(-tangent.y, tangent.x);\\n\\n\\tvec2 position = project(aCoord, aCoordFract, scale, scaleFract, translate, translateFract) * lineStart\\n\\t\\t+ project(bCoord, bCoordFract, scale, scaleFract, translate, translateFract) * lineEnd\\n\\n\\t\\t+ thickness * normal * .5 * lineOffset / viewport.zw;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\n\\nuniform float dashSize, pixelRatio, thickness, opacity, id;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvoid main() {\\n\\tfloat alpha = 1.;\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},aCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8,divisor:1},bCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:16,divisor:1},color:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1}}},n));try{e=t(a({cull:{enable:!0,face:\"back\"},vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, nextCoord, prevCoord;\\nattribute vec4 aColor, bColor;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, translate;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\nuniform float miterLimit, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 tangent;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nconst float REVERSE_THRESHOLD = -.875;\\nconst float MIN_DIFF = 1e-6;\\n\\n// TODO: possible optimizations: avoid overcalculating all for vertices and calc just one instead\\n// TODO: precalculate dot products, normalize things beforehead etc.\\n// TODO: refactor to rectangular algorithm\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nbool isNaN( float val ){\\n  return ( val < 0.0 || 0.0 < val || val == 0.0 ) ? false : true;\\n}\\n\\nvoid main() {\\n\\tvec2 aCoord = aCoord, bCoord = bCoord, prevCoord = prevCoord, nextCoord = nextCoord;\\n\\n  vec2 adjustedScale;\\n  adjustedScale.x = (abs(scale.x) < MIN_DIFF) ? MIN_DIFF : scale.x;\\n  adjustedScale.y = (abs(scale.y) < MIN_DIFF) ? MIN_DIFF : scale.y;\\n\\n  vec2 scaleRatio = adjustedScale * viewport.zw;\\n\\tvec2 normalWidth = thickness / scaleRatio;\\n\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineBot = 1. - lineTop;\\n\\n\\tfragColor = (lineStart * aColor + lineEnd * bColor) / 255.;\\n\\n\\tif (isNaN(aCoord.x) || isNaN(aCoord.y) || isNaN(bCoord.x) || isNaN(bCoord.y)) return;\\n\\n\\tif (aCoord == prevCoord) prevCoord = aCoord + normalize(bCoord - aCoord);\\n\\tif (bCoord == nextCoord) nextCoord = bCoord - normalize(bCoord - aCoord);\\n\\n\\tvec2 prevDiff = aCoord - prevCoord;\\n\\tvec2 currDiff = bCoord - aCoord;\\n\\tvec2 nextDiff = nextCoord - bCoord;\\n\\n\\tvec2 prevTangent = normalize(prevDiff * scaleRatio);\\n\\tvec2 currTangent = normalize(currDiff * scaleRatio);\\n\\tvec2 nextTangent = normalize(nextDiff * scaleRatio);\\n\\n\\tvec2 prevNormal = vec2(-prevTangent.y, prevTangent.x);\\n\\tvec2 currNormal = vec2(-currTangent.y, currTangent.x);\\n\\tvec2 nextNormal = vec2(-nextTangent.y, nextTangent.x);\\n\\n\\tvec2 startJoinDirection = normalize(prevTangent - currTangent);\\n\\tvec2 endJoinDirection = normalize(currTangent - nextTangent);\\n\\n\\t// collapsed/unidirectional segment cases\\n\\t// FIXME: there should be more elegant solution\\n\\tvec2 prevTanDiff = abs(prevTangent - currTangent);\\n\\tvec2 nextTanDiff = abs(nextTangent - currTangent);\\n\\tif (max(prevTanDiff.x, prevTanDiff.y) < MIN_DIFF) {\\n\\t\\tstartJoinDirection = currNormal;\\n\\t}\\n\\tif (max(nextTanDiff.x, nextTanDiff.y) < MIN_DIFF) {\\n\\t\\tendJoinDirection = currNormal;\\n\\t}\\n\\tif (aCoord == bCoord) {\\n\\t\\tendJoinDirection = startJoinDirection;\\n\\t\\tcurrNormal = prevNormal;\\n\\t\\tcurrTangent = prevTangent;\\n\\t}\\n\\n\\ttangent = currTangent;\\n\\n\\t//calculate join shifts relative to normals\\n\\tfloat startJoinShift = dot(currNormal, startJoinDirection);\\n\\tfloat endJoinShift = dot(currNormal, endJoinDirection);\\n\\n\\tfloat startMiterRatio = abs(1. / startJoinShift);\\n\\tfloat endMiterRatio = abs(1. / endJoinShift);\\n\\n\\tvec2 startJoin = startJoinDirection * startMiterRatio;\\n\\tvec2 endJoin = endJoinDirection * endMiterRatio;\\n\\n\\tvec2 startTopJoin, startBotJoin, endTopJoin, endBotJoin;\\n\\tstartTopJoin = sign(startJoinShift) * startJoin * .5;\\n\\tstartBotJoin = -startTopJoin;\\n\\n\\tendTopJoin = sign(endJoinShift) * endJoin * .5;\\n\\tendBotJoin = -endTopJoin;\\n\\n\\tvec2 aTopCoord = aCoord + normalWidth * startTopJoin;\\n\\tvec2 bTopCoord = bCoord + normalWidth * endTopJoin;\\n\\tvec2 aBotCoord = aCoord + normalWidth * startBotJoin;\\n\\tvec2 bBotCoord = bCoord + normalWidth * endBotJoin;\\n\\n\\t//miter anti-clipping\\n\\tfloat baClipping = distToLine(bCoord, aCoord, aBotCoord) / dot(normalize(normalWidth * endBotJoin), normalize(normalWidth.yx * vec2(-startBotJoin.y, startBotJoin.x)));\\n\\tfloat abClipping = distToLine(aCoord, bCoord, bTopCoord) / dot(normalize(normalWidth * startBotJoin), normalize(normalWidth.yx * vec2(-endBotJoin.y, endBotJoin.x)));\\n\\n\\t//prevent close to reverse direction switch\\n\\tbool prevReverse = dot(currTangent, prevTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, prevNormal)) * min(length(prevDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\tbool nextReverse = dot(currTangent, nextTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, nextNormal)) * min(length(nextDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\n\\tif (prevReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * startJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / startMiterRatio, 1.);\\n\\t\\taBotCoord = aCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\taTopCoord = aCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!nextReverse && baClipping > 0. && baClipping < length(normalWidth * endBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\tbTopCoord -= normalWidth * endTopJoin;\\n\\t\\tbTopCoord += normalize(endTopJoin * normalWidth) * baClipping;\\n\\t}\\n\\n\\tif (nextReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * endJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / endMiterRatio, 1.);\\n\\t\\tbBotCoord = bCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\tbTopCoord = bCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!prevReverse && abClipping > 0. && abClipping < length(normalWidth * startBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\taBotCoord -= normalWidth * startBotJoin;\\n\\t\\taBotCoord += normalize(startBotJoin * normalWidth) * abClipping;\\n\\t}\\n\\n\\tvec2 aTopPosition = (aTopCoord) * adjustedScale + translate;\\n\\tvec2 aBotPosition = (aBotCoord) * adjustedScale + translate;\\n\\n\\tvec2 bTopPosition = (bTopCoord) * adjustedScale + translate;\\n\\tvec2 bBotPosition = (bBotCoord) * adjustedScale + translate;\\n\\n\\t//position is normalized 0..1 coord on the screen\\n\\tvec2 position = (aTopPosition * lineTop + aBotPosition * lineBot) * lineStart + (bTopPosition * lineTop + bBotPosition * lineBot) * lineEnd;\\n\\n\\tstartCoord = aCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\tendCoord = bCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\n\\tgl_Position = vec4(position  * 2.0 - 1.0, depth, 1);\\n\\n\\tenableStartMiter = step(dot(currTangent, prevTangent), .5);\\n\\tenableEndMiter = step(dot(currTangent, nextTangent), .5);\\n\\n\\t//bevel miter cutoffs\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n\\n\\t//round miter cutoffs\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * abs(dot(startJoinDirection, currNormal)) * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * abs(dot(endJoinDirection, currNormal)) * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\nuniform float dashSize, pixelRatio, thickness, opacity, id, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nvoid main() {\\n\\tfloat alpha = 1., distToStart, distToEnd;\\n\\tfloat cutoff = thickness * .5;\\n\\n\\t//bevel miter\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToStart + 1., 0.), 1.);\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToEnd + 1., 0.), 1.);\\n\\t\\t}\\n\\t}\\n\\n\\t// round miter\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - startCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - endCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\t}\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1},bColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:4,divisor:1},prevCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:0,divisor:1},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},nextCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:24,divisor:1}}},n))}catch(t){e=i}return{fill:t({primitive:\"triangle\",elements:function(t,e){return e.triangles},offset:0,vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position, positionFract;\\n\\nuniform vec4 color;\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio, id;\\nuniform vec4 viewport;\\nuniform float opacity;\\n\\nvarying vec4 fragColor;\\n\\nconst float MAX_LINES = 256.;\\n\\nvoid main() {\\n\\tfloat depth = (MAX_LINES - 4. - id) / (MAX_LINES);\\n\\n\\tvec2 position = position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n\\tfragColor.a *= opacity;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n\\tgl_FragColor = fragColor;\\n}\\n\"]),uniforms:{scale:t.prop(\"scale\"),color:t.prop(\"fill\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{position:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8},positionFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8}},blend:n.blend,depth:{enable:!1},scissor:n.scissor,stencil:n.stencil,viewport:n.viewport}),rect:i,miter:e}},v.defaults={dashes:null,join:\"miter\",miterLimit:1,thickness:10,cap:\"square\",color:\"black\",opacity:1,overlay:!1,viewport:null,range:null,close:!1,fill:null},v.prototype.render=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];e.length&&(t=this).update.apply(t,e),this.draw()},v.prototype.draw=function(){for(var t=this,e=[],r=arguments.length;r--;)e[r]=arguments[r];return(e.length?e:this.passes).forEach(function(e,r){var n;if(e&&Array.isArray(e))return(n=t).draw.apply(n,e);\"number\"==typeof e&&(e=t.passes[e]),e&&e.count>1&&e.opacity&&(t.regl._refresh(),e.fill&&e.triangles&&e.triangles.length>2&&t.shaders.fill(e),e.thickness&&(e.scale[0]*e.viewport.width>v.precisionThreshold||e.scale[1]*e.viewport.height>v.precisionThreshold?t.shaders.rect(e):\"rect\"===e.join||!e.join&&(e.thickness<=2||e.count>=v.maxPoints)?t.shaders.rect(e):t.shaders.miter(e)))}),this},v.prototype.update=function(t){var e=this;if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var r=this.regl,o=this.gl;if(t.forEach(function(t,h){var d=e.passes[h];if(void 0!==t)if(null!==t){if(\"number\"==typeof t[0]&&(t={positions:t}),t=s(t,{positions:\"positions points data coords\",thickness:\"thickness lineWidth lineWidths line-width linewidth width stroke-width strokewidth strokeWidth\",join:\"lineJoin linejoin join type mode\",miterLimit:\"miterlimit miterLimit\",dashes:\"dash dashes dasharray dash-array dashArray\",color:\"color colour stroke colors colours stroke-color strokeColor\",fill:\"fill fill-color fillColor\",opacity:\"alpha opacity\",overlay:\"overlay crease overlap intersect\",close:\"closed close closed-path closePath\",range:\"range dataBox\",viewport:\"viewport viewBox\",hole:\"holes hole hollow\"}),d||(e.passes[h]=d={id:h,scale:null,scaleFract:null,translate:null,translateFract:null,count:0,hole:[],depth:0,dashLength:1,dashTexture:r.texture({channels:1,data:new Uint8Array([255]),width:1,height:1,mag:\"linear\",min:\"linear\"}),colorBuffer:r.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array}),positionBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),positionFractBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array})},t=a({},v.defaults,t)),null!=t.thickness&&(d.thickness=parseFloat(t.thickness)),null!=t.opacity&&(d.opacity=parseFloat(t.opacity)),null!=t.miterLimit&&(d.miterLimit=parseFloat(t.miterLimit)),null!=t.overlay&&(d.overlay=!!t.overlay,h<v.maxLines&&(d.depth=2*(v.maxLines-1-h%v.maxLines)/v.maxLines-1)),null!=t.join&&(d.join=t.join),null!=t.hole&&(d.hole=t.hole),null!=t.fill&&(d.fill=t.fill?n(t.fill,\"uint8\"):null),null!=t.viewport&&(d.viewport=g(t.viewport)),d.viewport||(d.viewport=g([o.drawingBufferWidth,o.drawingBufferHeight])),null!=t.close&&(d.close=t.close),null===t.positions&&(t.positions=[]),t.positions){var m,y;if(t.positions.x&&t.positions.y){var x=t.positions.x,b=t.positions.y;y=d.count=Math.max(x.length,b.length),m=new Float64Array(2*y);for(var _=0;_<y;_++)m[2*_]=x[_],m[2*_+1]=b[_]}else m=l(t.positions,\"float64\"),y=d.count=Math.floor(m.length/2);var w=d.bounds=i(m,2);if(d.fill){for(var k=[],T={},A=0,M=0,S=0,E=d.count;M<E;M++){var C=m[2*M],L=m[2*M+1];isNaN(C)||isNaN(L)||null==C||null==L?(C=m[2*A],L=m[2*A+1],T[M]=A):A=M,k[S++]=C,k[S++]=L}for(var P=c(k,d.hole||[]),O=0,z=P.length;O<z;O++)null!=T[P[O]]&&(P[O]=T[P[O]]);d.triangles=P}var I=new Float64Array(m);u(I,2,w);var D=new Float64Array(2*y+6);d.close?m[0]===m[2*y-2]&&m[1]===m[2*y-1]?(D[0]=I[2*y-4],D[1]=I[2*y-3]):(D[0]=I[2*y-2],D[1]=I[2*y-1]):(D[0]=I[0],D[1]=I[1]),D.set(I,2),d.close?m[0]===m[2*y-2]&&m[1]===m[2*y-1]?(D[2*y+2]=I[2],D[2*y+3]=I[3],d.count-=1):(D[2*y+2]=I[0],D[2*y+3]=I[1],D[2*y+4]=I[2],D[2*y+5]=I[3]):(D[2*y+2]=I[2*y-2],D[2*y+3]=I[2*y-1],D[2*y+4]=I[2*y-2],D[2*y+5]=I[2*y-1]),d.positionBuffer(f(D)),d.positionFractBuffer(p(D))}if(t.range?d.range=t.range:d.range||(d.range=d.bounds),(t.range||t.positions)&&d.count){var R=d.bounds,F=R[2]-R[0],B=R[3]-R[1],N=d.range[2]-d.range[0],j=d.range[3]-d.range[1];d.scale=[F/N,B/j],d.translate=[-d.range[0]/N+R[0]/N||0,-d.range[1]/j+R[1]/j||0],d.scaleFract=p(d.scale),d.translateFract=p(d.translate)}if(t.dashes){var U,V=0;if(!t.dashes||t.dashes.length<2)V=1,U=new Uint8Array([255,255,255,255,255,255,255,255]);else{V=0;for(var q=0;q<t.dashes.length;++q)V+=t.dashes[q];U=new Uint8Array(V*v.dashMult);for(var H=0,G=255,Y=0;Y<2;Y++)for(var W=0;W<t.dashes.length;++W){for(var X=0,Z=t.dashes[W]*v.dashMult*.5;X<Z;++X)U[H++]=G;G^=255}}d.dashLength=V,d.dashTexture({channels:1,data:U,width:U.length,height:1,mag:\"linear\",min:\"linear\"},0,0)}if(t.color){var J=d.count,K=t.color;K||(K=\"transparent\");var $=new Uint8Array(4*J+4);if(Array.isArray(K)&&\"number\"!=typeof K[0]){for(var Q=0;Q<J;Q++){var tt=n(K[Q],\"uint8\");$.set(tt,4*Q)}$.set(n(K[0],\"uint8\"),4*J)}else for(var et=n(K,\"uint8\"),rt=0;rt<J+1;rt++)$.set(et,4*rt);d.colorBuffer({usage:\"dynamic\",type:\"uint8\",data:$})}}else e.passes[h]=null}),t.length<this.passes.length){for(var h=t.length;h<this.passes.length;h++){var d=e.passes[h];d&&(d.colorBuffer.destroy(),d.positionBuffer.destroy(),d.dashTexture.destroy())}this.passes.length=t.length}for(var m=[],y=0;y<this.passes.length;y++)null!==e.passes[y]&&m.push(e.passes[y]);return this.passes=m,this}},v.prototype.destroy=function(){return this.passes.forEach(function(t){t.colorBuffer.destroy(),t.positionBuffer.destroy(),t.dashTexture.destroy()}),this.passes.length=0,this}},{\"array-bounds\":65,\"array-normalize\":66,\"color-normalize\":120,earcut:492,\"es6-weak-map\":493,\"flatten-vertex-data\":227,glslify:409,\"object-assign\":454,\"parse-rect\":459,\"pick-by-alias\":465,\"to-float32\":538}],492:[function(t,e,r){\"use strict\";function n(t,e,r){r=r||2;var n,s,l,c,u,p,g,v=e&&e.length,m=v?e[0]*r:t.length,y=i(t,0,m,r,!0),x=[];if(!y||y.next===y.prev)return x;if(v&&(y=function(t,e,r,n){var o,s,l,c,u,p=[];for(o=0,s=e.length;o<s;o++)l=e[o]*n,c=o<s-1?e[o+1]*n:t.length,(u=i(t,l,c,n,!1))===u.next&&(u.steiner=!0),p.push(d(u));for(p.sort(h),o=0;o<p.length;o++)f(p[o],r),r=a(r,r.next);return r}(t,e,y,r)),t.length>80*r){n=l=t[0],s=c=t[1];for(var b=r;b<m;b+=r)(u=t[b])<n&&(n=u),(p=t[b+1])<s&&(s=p),u>l&&(l=u),p>c&&(c=p);g=0!==(g=Math.max(l-n,c-s))?1/g:0}return o(y,x,r,n,s,g),x}function i(t,e,r,n,i){var a,o;if(i===A(t,e,r,n)>0)for(a=e;a<r;a+=n)o=w(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=w(a,t[a],t[a+1],o);return o&&y(o,o.next)&&(k(o),o=o.next),o}function a(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!y(n,n.next)&&0!==m(n.prev,n,n.next))n=n.next;else{if(k(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function o(t,e,r,n,i,h,f){if(t){!f&&h&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=p(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,h);for(var d,g,v=t;t.prev!==t.next;)if(d=t.prev,g=t.next,h?l(t,n,i,h):s(t))e.push(d.i/r),e.push(t.i/r),e.push(g.i/r),k(t),t=g.next,v=g.next;else if((t=g)===v){f?1===f?o(t=c(t,e,r),e,r,n,i,h,2):2===f&&u(t,e,r,n,i,h):o(a(t),e,r,n,i,h,1);break}}}function s(t){var e=t.prev,r=t,n=t.next;if(m(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(g(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&m(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function l(t,e,r,n){var i=t.prev,a=t,o=t.next;if(m(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,h=p(s,l,e,r,n),f=p(c,u,e,r,n),d=t.prevZ,v=t.nextZ;d&&d.z>=h&&v&&v.z<=f;){if(d!==t.prev&&d!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&m(d.prev,d,d.next)>=0)return!1;if(d=d.prevZ,v!==t.prev&&v!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,v.x,v.y)&&m(v.prev,v,v.next)>=0)return!1;v=v.nextZ}for(;d&&d.z>=h;){if(d!==t.prev&&d!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&m(d.prev,d,d.next)>=0)return!1;d=d.prevZ}for(;v&&v.z<=f;){if(v!==t.prev&&v!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,v.x,v.y)&&m(v.prev,v,v.next)>=0)return!1;v=v.nextZ}return!0}function c(t,e,r){var n=t;do{var i=n.prev,a=n.next.next;!y(i,a)&&x(i,n,n.next,a)&&b(i,a)&&b(a,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(a.i/r),k(n),k(n.next),n=t=a),n=n.next}while(n!==t);return n}function u(t,e,r,n,i,s){var l=t;do{for(var c=l.next.next;c!==l.prev;){if(l.i!==c.i&&v(l,c)){var u=_(l,c);return l=a(l,l.next),u=a(u,u.next),o(l,e,r,n,i,s),void o(u,e,r,n,i,s)}c=c.next}l=l.next}while(l!==t)}function h(t,e){return t.x-e.x}function f(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r.prev;var l,c=r,u=r.x,h=r.y,f=1/0;n=r.next;for(;n!==c;)i>=n.x&&n.x>=u&&i!==n.x&&g(a<h?i:o,a,u,h,a<h?o:i,a,n.x,n.y)&&((l=Math.abs(a-n.y)/(i-n.x))<f||l===f&&n.x>r.x)&&b(n,t)&&(r=n,f=l),n=n.next;return r}(t,e)){var r=_(e,t);a(r,r.next)}}function p(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function d(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function g(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function v(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&x(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&b(t,e)&&b(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)}function m(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function y(t,e){return t.x===e.x&&t.y===e.y}function x(t,e,r,n){return!!(y(t,e)&&y(r,n)||y(t,n)&&y(r,e))||m(t,e,r)>0!=m(t,e,n)>0&&m(r,n,t)>0!=m(r,n,e)>0}function b(t,e){return m(t.prev,t,t.next)<0?m(t,e,t.next)>=0&&m(t,t.prev,e)>=0:m(t,e,t.prev)<0||m(t,t.next,e)<0}function _(t,e){var r=new T(t.i,t.x,t.y),n=new T(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function w(t,e,r,n){var i=new T(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function k(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function T(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function A(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}e.exports=n,e.exports.default=n,n.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(A(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(A(t,c,u,r))}var h=0;for(s=0;s<n.length;s+=3){var f=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;h+=Math.abs((t[f]-t[d])*(t[p+1]-t[f+1])-(t[f]-t[p])*(t[d+1]-t[f+1]))}return 0===o&&0===h?0:Math.abs((h-o)/o)},n.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r}},{}],493:[function(t,e,r){arguments[4][318][0].apply(r,arguments)},{\"./is-implemented\":494,\"./polyfill\":496,dup:318}],494:[function(t,e,r){arguments[4][319][0].apply(r,arguments)},{dup:319}],495:[function(t,e,r){arguments[4][320][0].apply(r,arguments)},{dup:320}],496:[function(t,e,r){arguments[4][321][0].apply(r,arguments)},{\"./is-native-implemented\":495,d:151,dup:321,\"es5-ext/object/is-value\":194,\"es5-ext/object/set-prototype-of\":200,\"es5-ext/object/valid-object\":204,\"es5-ext/object/valid-value\":205,\"es5-ext/string/random-uniq\":210,\"es6-iterator/for-of\":212,\"es6-iterator/get\":213,\"es6-symbol\":219}],497:[function(t,e,r){\"use strict\";function n(t,e){return function(t){if(Array.isArray(t))return t}(t)||function(t,e){var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{n||null==s.return||s.return()}finally{if(i)throw a}}return r}(t,e)||function(){throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")}()}function i(t){return function(t){if(Array.isArray(t)){for(var e=0,r=new Array(t.length);e<t.length;e++)r[e]=t[e];return r}}(t)||function(t){if(Symbol.iterator in Object(t)||\"[object Arguments]\"===Object.prototype.toString.call(t))return Array.from(t)}(t)||function(){throw new TypeError(\"Invalid attempt to spread non-iterable instance\")}()}var a=t(\"color-normalize\"),o=t(\"array-bounds\"),s=t(\"color-id\"),l=t(\"point-cluster\"),c=t(\"object-assign\"),u=t(\"glslify\"),h=t(\"pick-by-alias\"),f=t(\"update-diff\"),p=t(\"flatten-vertex-data\"),d=t(\"is-iexplorer\"),g=t(\"to-float32\"),v=t(\"parse-rect\"),m=y;function y(t,e){var r=this;if(!(this instanceof y))return new y(t,e);\"function\"==typeof t?(e||(e={}),e.regl=t):(e=t,t=null),e&&e.length&&(e.positions=e);var n,i=(t=e.regl)._gl,a=[];this.tooManyColors=d,n=t.texture({data:new Uint8Array(1020),width:255,height:1,type:\"uint8\",format:\"rgba\",wrapS:\"clamp\",wrapT:\"clamp\",mag:\"nearest\",min:\"nearest\"}),c(this,{regl:t,gl:i,groups:[],markerCache:[null],markerTextures:[null],palette:a,paletteIds:{},paletteTexture:n,maxColors:255,maxSize:100,canvas:i.canvas}),this.update(e);var o={uniforms:{pixelRatio:t.context(\"pixelRatio\"),palette:n,paletteSize:function(t,e){return[r.tooManyColors?0:255,n.height]},scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translate:t.prop(\"translate\"),translateFract:t.prop(\"translateFract\"),opacity:t.prop(\"opacity\"),marker:t.prop(\"markerTexture\")},attributes:{x:function(t,e){return e.xAttr||{buffer:e.positionBuffer,stride:8,offset:0}},y:function(t,e){return e.yAttr||{buffer:e.positionBuffer,stride:8,offset:4}},xFract:function(t,e){return e.xAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:0}},yFract:function(t,e){return e.yAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:4}},size:function(t,e){return e.size.length?{buffer:e.sizeBuffer,stride:2,offset:0}:{constant:[Math.round(255*e.size/r.maxSize)]}},borderSize:function(t,e){return e.borderSize.length?{buffer:e.sizeBuffer,stride:2,offset:1}:{constant:[Math.round(255*e.borderSize/r.maxSize)]}},colorId:function(t,e){return e.color.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:0}:{constant:r.tooManyColors?a.slice(4*e.color,4*e.color+4):[e.color]}},borderColorId:function(t,e){return e.borderColor.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:r.tooManyColors?4:2}:{constant:r.tooManyColors?a.slice(4*e.borderColor,4*e.borderColor+4):[e.borderColor]}},isActive:function(t,e){return!0===e.activation?{constant:[1]}:e.activation?e.activation:{constant:[0]}}},blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:{enable:!1},depth:{enable:!1},elements:t.prop(\"elements\"),count:t.prop(\"count\"),offset:t.prop(\"offset\"),primitive:\"points\"},s=c({},o);s.frag=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nuniform sampler2D marker;\\nuniform float pixelRatio, opacity;\\n\\nfloat smoothStep(float x, float y) {\\n  return 1.0 / (1.0 + exp(50.0*(x - y)));\\n}\\n\\nvoid main() {\\n  float dist = texture2D(marker, gl_PointCoord).r, delta = fragWidth;\\n\\n  // max-distance alpha\\n  if (dist < 0.003) discard;\\n\\n  // null-border case\\n  if (fragBorderColorLevel == fragColorLevel || fragBorderColor.a == 0.) {\\n    float colorAmt = smoothstep(.5 - delta, .5 + delta, dist);\\n    gl_FragColor = vec4(fragColor.rgb, colorAmt * fragColor.a * opacity);\\n  }\\n  else {\\n    float borderColorAmt = smoothstep(fragBorderColorLevel - delta, fragBorderColorLevel + delta, dist);\\n    float colorAmt = smoothstep(fragColorLevel - delta, fragColorLevel + delta, dist);\\n\\n    vec4 color = fragBorderColor;\\n    color.a *= borderColorAmt;\\n    color = mix(color, fragColor, colorAmt);\\n    color.a *= opacity;\\n\\n    gl_FragColor = color;\\n  }\\n\\n}\\n\"]),s.vert=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract, paletteSize;\\nuniform float pixelRatio;\\nuniform sampler2D palette;\\n\\nconst float maxSize = 100.;\\nconst float borderLevel = .5;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragPointSize, fragBorderRadius, fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = 2. * size * pixelRatio;\\n  fragPointSize = size * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\n  fragColor = color;\\n  fragBorderColor = borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n\\n  fragBorderColorLevel = clamp(borderLevel - borderLevel * borderSize / size, 0., 1.);\\n  fragColorLevel = clamp(borderLevel + (1. - borderLevel) * borderSize / size, 0., 1.);\\n}\"]),this.drawMarker=t(s);var l=c({},o);l.frag=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\n\\nuniform float opacity;\\nvarying float fragBorderRadius, fragWidth;\\n\\nfloat smoothStep(float edge0, float edge1, float x) {\\n\\tfloat t;\\n\\tt = clamp((x - edge0) / (edge1 - edge0), 0.0, 1.0);\\n\\treturn t * t * (3.0 - 2.0 * t);\\n}\\n\\nvoid main() {\\n\\tfloat radius, alpha = 1.0, delta = fragWidth;\\n\\n\\tradius = length(2.0 * gl_PointCoord.xy - 1.0);\\n\\n\\tif (radius > 1.0 + delta) {\\n\\t\\tdiscard;\\n\\t}\\n\\n\\talpha -= smoothstep(1.0 - delta, 1.0 + delta, radius);\\n\\n\\tfloat borderRadius = fragBorderRadius;\\n\\tfloat ratio = smoothstep(borderRadius - delta, borderRadius + delta, radius);\\n\\tvec4 color = mix(fragColor, fragBorderColor, ratio);\\n\\tcolor.a *= alpha * opacity;\\n\\tgl_FragColor = color;\\n}\\n\"]),l.vert=u([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio;\\nuniform sampler2D palette;\\nuniform vec2 paletteSize;\\n\\nconst float maxSize = 100.;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragBorderRadius, fragWidth;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  // ignore inactive points\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = (size + borderSize) * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\n  fragBorderRadius = 1. - 2. * borderSize / (size + borderSize);\\n  fragColor = color;\\n  fragBorderColor = borderColor.a == 0. || borderSize == 0. ? vec4(color.rgb, 0.) : borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n}\\n\"]),d&&(l.frag=l.frag.replace(\"smoothstep\",\"smoothStep\"),s.frag=s.frag.replace(\"smoothstep\",\"smoothStep\")),this.drawCircle=t(l)}y.defaults={color:\"black\",borderColor:\"transparent\",borderSize:0,size:12,opacity:1,marker:void 0,viewport:null,range:null,pixelSize:null,count:0,offset:0,bounds:null,positions:[],snap:1e4},y.prototype.render=function(){return arguments.length&&this.update.apply(this,arguments),this.draw(),this},y.prototype.draw=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var i=this.groups;if(1===r.length&&Array.isArray(r[0])&&(null===r[0][0]||Array.isArray(r[0][0]))&&(r=r[0]),this.regl._refresh(),r.length)for(var a=0;a<r.length;a++)this.drawItem(a,r[a]);else i.forEach(function(e,r){t.drawItem(r)});return this},y.prototype.drawItem=function(t,e){var r=this.groups,n=r[t];if(\"number\"==typeof e&&(t=e,n=r[e],e=null),n&&n.count&&n.opacity){n.activation[0]&&this.drawCircle(this.getMarkerDrawOptions(0,n,e));for(var a=[],o=1;o<n.activation.length;o++)n.activation[o]&&(!0===n.activation[o]||n.activation[o].data.length)&&a.push.apply(a,i(this.getMarkerDrawOptions(o,n,e)));a.length&&this.drawMarker(a)}},y.prototype.getMarkerDrawOptions=function(t,e,r){var i=e.range,a=e.tree,o=e.viewport,s=e.activation,l=e.selectionBuffer,u=e.count;this.regl;if(!a)return r?[c({},e,{markerTexture:this.markerTextures[t],activation:s[t],count:r.length,elements:r,offset:0})]:[c({},e,{markerTexture:this.markerTextures[t],activation:s[t],offset:0})];var h=[],f=a.range(i,{lod:!0,px:[(i[2]-i[0])/o.width,(i[3]-i[1])/o.height]});if(r){for(var p=s[t].data,d=new Uint8Array(u),g=0;g<r.length;g++){var v=r[g];d[v]=p?p[v]:1}l.subdata(d)}for(var m=f.length;m--;){var y=n(f[m],2),x=y[0],b=y[1];h.push(c({},e,{markerTexture:this.markerTextures[t],activation:r?l:s[t],offset:x,count:b-x}))}return h},y.prototype.update=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];if(r.length){1===r.length&&Array.isArray(r[0])&&(r=r[0]);var i=this.groups,a=this.gl,s=this.regl,u=this.maxSize,d=this.maxColors,m=this.palette;this.groups=i=r.map(function(e,r){var n=i[r];if(void 0===e)return n;null===e?e={positions:null}:\"function\"==typeof e?e={ondraw:e}:\"number\"==typeof e[0]&&(e={positions:e}),null===(e=h(e,{positions:\"positions data points\",snap:\"snap cluster lod tree\",size:\"sizes size radius\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",color:\"colors color fill fill-color fillColor\",borderColor:\"borderColors borderColor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range dataBox databox\",viewport:\"viewport viewPort viewBox viewbox\",opacity:\"opacity alpha transparency\",bounds:\"bound bounds boundaries limits\",tooManyColors:\"tooManyColors palette paletteMode optimizePalette enablePalette\"})).positions&&(e.positions=[]),null!=e.tooManyColors&&(t.tooManyColors=e.tooManyColors),n||(i[r]=n={id:r,scale:null,translate:null,scaleFract:null,translateFract:null,activation:[],selectionBuffer:s.buffer({data:new Uint8Array(0),usage:\"stream\",type:\"uint8\"}),sizeBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),colorBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),positionBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"}),positionFractBuffer:s.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"})},e=c({},y.defaults,e)),!e.positions||\"marker\"in e||(e.marker=n.marker,delete n.marker),!e.marker||\"positions\"in e||(e.positions=n.positions,delete n.positions);var x=0,b=0;if(f(n,e,[{snap:!0,size:function(t,e){return null==t&&(t=y.defaults.size),x+=t&&t.length?1:0,t},borderSize:function(t,e){return null==t&&(t=y.defaults.borderSize),x+=t&&t.length?1:0,t},opacity:parseFloat,color:function(e,r){return null==e&&(e=y.defaults.color),e=t.updateColor(e),b++,e},borderColor:function(e,r){return null==e&&(e=y.defaults.borderColor),e=t.updateColor(e),b++,e},bounds:function(t,e,r){return\"range\"in r||(r.range=null),t},positions:function(t,e,r){var n=e.snap,i=e.positionBuffer,a=e.positionFractBuffer,c=e.selectionBuffer;if(t.x||t.y)return t.x.length?e.xAttr={buffer:s.buffer(t.x),offset:0,stride:4,count:t.x.length}:e.xAttr={buffer:t.x.buffer,offset:4*t.x.offset||0,stride:4*(t.x.stride||1),count:t.x.count},t.y.length?e.yAttr={buffer:s.buffer(t.y),offset:0,stride:4,count:t.y.length}:e.yAttr={buffer:t.y.buffer,offset:4*t.y.offset||0,stride:4*(t.y.stride||1),count:t.y.count},e.count=Math.max(e.xAttr.count,e.yAttr.count),t;t=p(t,\"float64\");var u=e.count=Math.floor(t.length/2),h=e.bounds=u?o(t,2):null;if(r.range||e.range||(delete e.range,r.range=h),r.marker||e.marker||(delete e.marker,r.marker=null),n&&(!0===n||u>n)?e.tree=l(t,{bounds:h}):n&&n.length&&(e.tree=n),e.tree){var f={primitive:\"points\",usage:\"static\",data:e.tree,type:\"uint32\"};e.elements?e.elements(f):e.elements=s.elements(f)}return i({data:g.float(t),usage:\"dynamic\"}),a({data:g.fract(t),usage:\"dynamic\"}),c({data:new Uint8Array(u),type:\"uint8\",usage:\"stream\"}),t}},{marker:function(e,r,n){var i=r.activation;if(i.forEach(function(t){return t&&t.destroy&&t.destroy()}),i.length=0,e&&\"number\"!=typeof e[0]){for(var a=[],o=0,l=Math.min(e.length,r.count);o<l;o++){var c=t.addMarker(e[o]);a[c]||(a[c]=new Uint8Array(r.count)),a[c][o]=1}for(var u=0;u<a.length;u++)if(a[u]){var h={data:a[u],type:\"uint8\",usage:\"static\"};i[u]?i[u](h):i[u]=s.buffer(h),i[u].data=a[u]}}else{i[t.addMarker(e)]=!0}return e},range:function(t,e,r){var n=e.bounds;if(n)return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=g.fract(e.scale),e.translateFract=g.fract(e.translate),t},viewport:function(t){return v(t||[a.drawingBufferWidth,a.drawingBufferHeight])}}]),x){var _=n,w=_.count,k=_.size,T=_.borderSize,A=_.sizeBuffer,M=new Uint8Array(2*w);if(k.length||T.length)for(var S=0;S<w;S++)M[2*S]=Math.round(255*(null==k[S]?k:k[S])/u),M[2*S+1]=Math.round(255*(null==T[S]?T:T[S])/u);A({data:M,usage:\"dynamic\"})}if(b){var E,C=n,L=C.count,P=C.color,O=C.borderColor,z=C.colorBuffer;if(t.tooManyColors){if(P.length||O.length){E=new Uint8Array(8*L);for(var I=0;I<L;I++){var D=P[I];E[8*I]=m[4*D],E[8*I+1]=m[4*D+1],E[8*I+2]=m[4*D+2],E[8*I+3]=m[4*D+3];var R=O[I];E[8*I+4]=m[4*R],E[8*I+5]=m[4*R+1],E[8*I+6]=m[4*R+2],E[8*I+7]=m[4*R+3]}}}else if(P.length||O.length){E=new Uint8Array(4*L+2);for(var F=0;F<L;F++)null!=P[F]&&(E[4*F]=P[F]%d,E[4*F+1]=Math.floor(P[F]/d)),null!=O[F]&&(E[4*F+2]=O[F]%d,E[4*F+3]=Math.floor(O[F]/d))}z({data:E||new Uint8Array(0),type:\"uint8\",usage:\"dynamic\"})}return n})}},y.prototype.addMarker=function(t){var e,r=this.markerTextures,n=this.regl,i=this.markerCache,a=null==t?0:i.indexOf(t);if(a>=0)return a;if(t instanceof Uint8Array||t instanceof Uint8ClampedArray)e=t;else{e=new Uint8Array(t.length);for(var o=0,s=t.length;o<s;o++)e[o]=255*t[o]}var l=Math.floor(Math.sqrt(e.length));return a=r.length,i.push(t),r.push(n.texture({channels:1,data:e,radius:l,mag:\"linear\",min:\"linear\"})),a},y.prototype.updateColor=function(t){var e=this.paletteIds,r=this.palette,n=this.maxColors;Array.isArray(t)||(t=[t]);var i=[];if(\"number\"==typeof t[0]){var o=[];if(Array.isArray(t))for(var l=0;l<t.length;l+=4)o.push(t.slice(l,l+4));else for(var c=0;c<t.length;c+=4)o.push(t.subarray(c,c+4));t=o}for(var u=0;u<t.length;u++){var h=t[u];h=a(h,\"uint8\");var f=s(h,!1);if(null==e[f]){var p=r.length;e[f]=Math.floor(p/4),r[p]=h[0],r[p+1]=h[1],r[p+2]=h[2],r[p+3]=h[3]}i[u]=e[f]}return!this.tooManyColors&&r.length>4*n&&(this.tooManyColors=!0),this.updatePalette(r),1===i.length?i[0]:i},y.prototype.updatePalette=function(t){if(!this.tooManyColors){var e=this.maxColors,r=this.paletteTexture,n=Math.ceil(.25*t.length/e);if(n>1)for(var i=.25*(t=t.slice()).length%e;i<n*e;i++)t.push(0,0,0,0);r.height<n&&r.resize(e,n),r.subimage({width:Math.min(.25*t.length,e),height:n,data:t},0,0)}},y.prototype.destroy=function(){return this.groups.forEach(function(t){t.sizeBuffer.destroy(),t.positionBuffer.destroy(),t.positionFractBuffer.destroy(),t.colorBuffer.destroy(),t.activation.forEach(function(t){return t&&t.destroy&&t.destroy()}),t.selectionBuffer.destroy(),t.elements&&t.elements.destroy()}),this.groups.length=0,this.paletteTexture.destroy(),this.markerTextures.forEach(function(t){return t&&t.destroy&&t.destroy()}),this};var x=t(\"object-assign\");e.exports=function(t,e){var r=new m(t,e),n=r.render.bind(r);return x(n,{render:n,update:r.update.bind(r),draw:r.draw.bind(r),destroy:r.destroy.bind(r),regl:r.regl,gl:r.gl,canvas:r.gl.canvas,groups:r.groups,markers:r.markerCache,palette:r.palette}),n}},{\"array-bounds\":65,\"color-id\":118,\"color-normalize\":120,\"flatten-vertex-data\":227,glslify:409,\"is-iexplorer\":419,\"object-assign\":454,\"parse-rect\":459,\"pick-by-alias\":465,\"point-cluster\":499,\"to-float32\":538,\"update-diff\":549}],498:[function(t,e,r){arguments[4][111][0].apply(r,arguments)},{dup:111}],499:[function(t,e,r){\"use strict\";e.exports=t(\"./quad\")},{\"./quad\":500}],500:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"clamp\"),a=t(\"parse-rect\"),o=t(\"array-bounds\"),s=t(\"pick-by-alias\"),l=t(\"defined\"),c=t(\"flatten-vertex-data\"),u=t(\"is-obj\"),h=t(\"dtype\"),f=t(\"math-log2\"),p=1073741824;function d(t,e){for(var r=e[0],n=e[1],a=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=i((t[2*l]-r)*a,0,1),s[2*l+1]=i((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,\"float64\"),e=s(e,{bounds:\"range bounds dataBox databox\",maxDepth:\"depth maxDepth maxdepth level maxLevel maxlevel levels\",dtype:\"type dtype format out dst output destination\"});var r=l(e.maxDepth,255),i=l(e.bounds,o(t,2));i[0]===i[2]&&i[2]++,i[1]===i[3]&&i[3]++;var g,v=d(t,i),m=t.length>>>1;e.dtype||(e.dtype=\"array\"),\"string\"==typeof e.dtype?g=new(h(e.dtype))(m):e.dtype&&(g=e.dtype,Array.isArray(g)&&(g.length=m));for(var y=0;y<m;++y)g[y]=y;var x=[],b=[],_=[],w=[];!function t(e,n,i,a,o,s){if(!a.length)return null;var l=x[o]||(x[o]=[]);var c=_[o]||(_[o]=[]);var u=b[o]||(b[o]=[]);var h=l.length;o++;if(o>r||s>p){for(var f=0;f<a.length;f++)l.push(a[f]),c.push(s),u.push(null,null,null,null);return h}l.push(a[0]);c.push(s);if(a.length<=1)return u.push(null,null,null,null),h;var d=.5*i;var g=e+d,m=n+d;var y=[],w=[],k=[],T=[];for(var A=1,M=a.length;A<M;A++){var S=a[A],E=v[2*S],C=v[2*S+1];E<g?C<m?y.push(S):w.push(S):C<m?k.push(S):T.push(S)}s<<=2;u.push(t(e,n,d,y,o,s),t(e,m,d,w,o,s+1),t(g,n,d,k,o,s+2),t(g,m,d,T,o,s+3));return h}(0,0,1,g,0,1);for(var k=0,T=0;T<x.length;T++){var A=x[T];if(g.set)g.set(A,k);else for(var M=0,S=A.length;M<S;M++)g[M+k]=A[M];var E=k+x[T].length;w[T]=[k,E],k=E}return g.range=function(){var e,r=[],o=arguments.length;for(;o--;)r[o]=arguments[o];if(u(r[r.length-1])){var c=r.pop();r.length||null==c.x&&null==c.l&&null==c.left||(r=[c],e={}),e=s(c,{level:\"level maxLevel\",d:\"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize\",lod:\"lod details ranges offsets\"})}else e={};r.length||(r=i);var h=a.apply(void 0,r),p=[Math.min(h.x,h.x+h.width),Math.min(h.y,h.y+h.height),Math.max(h.x,h.x+h.width),Math.max(h.y,h.y+h.height)],g=p[0],v=p[1],m=p[2],y=p[3],k=d([g,v,m,y],i),T=k[0],A=k[1],M=k[2],S=k[3],E=l(e.level,x.length);if(null!=e.d){var L;\"number\"==typeof e.d?L=[e.d,e.d]:e.d.length&&(L=e.d),E=Math.min(Math.max(Math.ceil(-f(Math.abs(L[0])/(i[2]-i[0]))),Math.ceil(-f(Math.abs(L[1])/(i[3]-i[1])))),E)}if(E=Math.min(E,x.length),e.lod)return function(t,e,r,i,a){for(var o=[],s=0;s<a;s++){var l=_[s],c=w[s][0],u=C(t,e,s),h=C(r,i,s),f=n.ge(l,u),p=n.gt(l,h,f,l.length-1);o[s]=[f+c,p+c]}return o}(T,A,M,S,E);var P=[];return function e(r,n,i,a,o,s){if(null!==o&&null!==s){var l=r+i,c=n+i;if(!(T>l||A>c||M<r||S<n||a>=E||o===s)){var u=x[a];void 0===s&&(s=u.length);for(var h=o;h<s;h++){var f=u[h],p=t[2*f],d=t[2*f+1];p>=g&&p<=m&&d>=v&&d<=y&&P.push(f)}var _=b[a],w=_[4*o+0],k=_[4*o+1],C=_[4*o+2],L=_[4*o+3],O=function(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}(_,o+1),z=.5*i,I=a+1;e(r,n,z,I,w,k||C||L||O),e(r,n+z,z,I,k,C||L||O),e(r+z,n,z,I,C,L||O),e(r+z,n+z,z,I,L,O)}}}(0,0,1,0,0,1),P},g;function C(t,e,r){for(var n=1,i=.5,a=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<i?e<a?0:1:e<a?2:3,o*=.5,i+=t<i?-o:o,a+=e<a?-o:o;return n}}},{\"array-bounds\":65,\"binary-search-bounds\":498,clamp:115,defined:164,dtype:169,\"flatten-vertex-data\":227,\"is-obj\":421,\"math-log2\":432,\"parse-rect\":459,\"pick-by-alias\":465}],501:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"pick-by-alias\"),a=t(\"array-bounds\"),o=t(\"raf\"),s=t(\"array-range\"),l=t(\"parse-rect\"),c=t(\"flatten-vertex-data\");function u(t,e){if(!(this instanceof u))return new u(t,e);this.traces=[],this.passes={},this.regl=t,this.scatter=n(t),this.canvas=this.scatter.canvas}function h(t,e,r){return(null!=t.id?t.id:t)<<16|(255&e)<<8|255&r}function f(t,e,r){var n,i,a,o,s=t[e],l=t[r];return s.length>2?(s[0],s[2],n=s[1],i=s[3]):s.length?(n=s[0],i=s[1]):(s.x,n=s.y,s.x+s.width,i=s.y+s.height),l.length>2?(a=l[0],o=l[2],l[1],l[3]):l.length?(a=l[0],o=l[1]):(a=l.x,l.y,o=l.x+l.width,l.y+l.height),[a,n,o,i]}function p(t){if(\"number\"==typeof t)return[t,t,t,t];if(2===t.length)return[t[0],t[1],t[0],t[1]];var e=l(t);return[e.x,e.y,e.x+e.width,e.y+e.height]}e.exports=u,u.prototype.render=function(){for(var t,e=this,r=[],n=arguments.length;n--;)r[n]=arguments[n];return r.length&&(t=this).update.apply(t,r),this.regl.attributes.preserveDrawingBuffer?this.draw():(this.dirty?null==this.planned&&(this.planned=o(function(){e.draw(),e.dirty=!0,e.planned=null})):(this.draw(),this.dirty=!0,o(function(){e.dirty=!1})),this)},u.prototype.update=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=0;n<e.length;n++)this.updateItem(n,e[n]);this.traces=this.traces.filter(Boolean);for(var i=[],a=0,o=0;o<this.traces.length;o++){for(var s=this.traces[o],l=this.traces[o].passes,c=0;c<l.length;c++)i.push(this.passes[l[c]]);s.passOffset=a,a+=s.passes.length}return(t=this.scatter).update.apply(t,i),this}},u.prototype.updateItem=function(t,e){var r=this.regl;if(null===e)return this.traces[t]=null,this;if(!e)return this;var n,o=i(e,{data:\"data items columns rows values dimensions samples x\",snap:\"snap cluster\",size:\"sizes size radius\",color:\"colors color fill fill-color fillColor\",opacity:\"opacity alpha transparency opaque\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",borderColor:\"borderColors borderColor bordercolor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range ranges databox dataBox\",viewport:\"viewport viewBox viewbox\",domain:\"domain domains area areas\",padding:\"pad padding paddings pads margin margins\",transpose:\"transpose transposed\",diagonal:\"diagonal diag showDiagonal\",upper:\"upper up top upperhalf upperHalf showupperhalf showUpper showUpperHalf\",lower:\"lower low bottom lowerhalf lowerHalf showlowerhalf showLowerHalf showLower\"}),s=this.traces[t]||(this.traces[t]={id:t,buffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),color:\"black\",marker:null,size:12,borderColor:\"transparent\",borderSize:1,viewport:l([r._gl.drawingBufferWidth,r._gl.drawingBufferHeight]),padding:[0,0,0,0],opacity:1,diagonal:!0,upper:!0,lower:!0});if(null!=o.color&&(s.color=o.color),null!=o.size&&(s.size=o.size),null!=o.marker&&(s.marker=o.marker),null!=o.borderColor&&(s.borderColor=o.borderColor),null!=o.borderSize&&(s.borderSize=o.borderSize),null!=o.opacity&&(s.opacity=o.opacity),o.viewport&&(s.viewport=l(o.viewport)),null!=o.diagonal&&(s.diagonal=o.diagonal),null!=o.upper&&(s.upper=o.upper),null!=o.lower&&(s.lower=o.lower),o.data){s.buffer(c(o.data)),s.columns=o.data.length,s.count=o.data[0].length,s.bounds=[];for(var u=0;u<s.columns;u++)s.bounds[u]=a(o.data[u],1)}o.range&&(s.range=o.range,n=s.range&&\"number\"!=typeof s.range[0]),o.domain&&(s.domain=o.domain);var d=!1;null!=o.padding&&(Array.isArray(o.padding)&&o.padding.length===s.columns&&\"number\"==typeof o.padding[o.padding.length-1]?(s.padding=o.padding.map(p),d=!0):s.padding=p(o.padding));var g=s.columns,v=s.count,m=s.viewport.width,y=s.viewport.height,x=s.viewport.x,b=s.viewport.y,_=m/g,w=y/g;s.passes=[];for(var k=0;k<g;k++)for(var T=0;T<g;T++)if((s.diagonal||T!==k)&&(s.upper||!(k>T))&&(s.lower||!(k<T))){var A=h(s.id,k,T),M=this.passes[A]||(this.passes[A]={});if(o.data&&(o.transpose?M.positions={x:{buffer:s.buffer,offset:T,count:v,stride:g},y:{buffer:s.buffer,offset:k,count:v,stride:g}}:M.positions={x:{buffer:s.buffer,offset:T*v,count:v},y:{buffer:s.buffer,offset:k*v,count:v}},M.bounds=f(s.bounds,k,T)),o.domain||o.viewport||o.data){var S=d?f(s.padding,k,T):s.padding;if(s.domain){var E=f(s.domain,k,T),C=E[0],L=E[1],P=E[2],O=E[3];M.viewport=[x+C*m+S[0],b+L*y+S[1],x+P*m-S[2],b+O*y-S[3]]}else M.viewport=[x+T*_+_*S[0],b+k*w+w*S[1],x+(T+1)*_-_*S[2],b+(k+1)*w-w*S[3]]}o.color&&(M.color=s.color),o.size&&(M.size=s.size),o.marker&&(M.marker=s.marker),o.borderSize&&(M.borderSize=s.borderSize),o.borderColor&&(M.borderColor=s.borderColor),o.opacity&&(M.opacity=s.opacity),o.range&&(M.range=n?f(s.range,k,T):s.range||M.bounds),s.passes.push(A)}return this},u.prototype.draw=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=[],i=0;i<e.length;i++)if(\"number\"==typeof e[i]){var a=this.traces[e[i]],o=a.passes,l=a.passOffset;n.push.apply(n,s(l,l+o.length))}else if(e[i].length){var c=e[i],u=this.traces[i],h=u.passes,f=u.passOffset;h=h.map(function(t,e){n[f+e]=c})}(t=this.scatter).draw.apply(t,n)}else this.scatter.draw();return this},u.prototype.destroy=function(){return this.traces.forEach(function(t){t.buffer&&t.buffer.destroy&&t.buffer.destroy()}),this.traces=null,this.passes=null,this.scatter.destroy(),this}},{\"array-bounds\":65,\"array-range\":67,\"flatten-vertex-data\":227,\"parse-rect\":459,\"pick-by-alias\":465,raf:484,\"regl-scatter2d\":497}],502:[function(t,e,r){var n,i;n=this,i=function(){function t(t,e){this.id=U++,this.type=t,this.data=e}function e(t){return\"[\"+function t(e){if(0===e.length)return[];var r=e.charAt(0),n=e.charAt(e.length-1);if(1<e.length&&r===n&&('\"'===r||\"'\"===r))return['\"'+e.substr(1,e.length-2).replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];if(r=/\\[(false|true|null|\\d+|'[^']*'|\"[^\"]*\")\\]/.exec(e))return t(e.substr(0,r.index)).concat(t(r[1])).concat(t(e.substr(r.index+r[0].length)));if(1===(r=e.split(\".\")).length)return['\"'+e.replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];for(e=[],n=0;n<r.length;++n)e=e.concat(t(r[n]));return e}(t).join(\"][\")+\"]\"}function r(t){return\"string\"==typeof t?t.split():t}function n(t){return\"string\"==typeof t?document.querySelector(t):t}function i(t){var e,i,a,o,s=t||{};t={};var l=[],c=[],u=\"undefined\"==typeof window?1:window.devicePixelRatio,h=!1,f=function(t){},p=function(){};if(\"string\"==typeof s?e=document.querySelector(s):\"object\"==typeof s&&(\"string\"==typeof s.nodeName&&\"function\"==typeof s.appendChild&&\"function\"==typeof s.getBoundingClientRect?e=s:\"function\"==typeof s.drawArrays||\"function\"==typeof s.drawElements?a=(o=s).canvas:(\"gl\"in s?o=s.gl:\"canvas\"in s?a=n(s.canvas):\"container\"in s&&(i=n(s.container)),\"attributes\"in s&&(t=s.attributes),\"extensions\"in s&&(l=r(s.extensions)),\"optionalExtensions\"in s&&(c=r(s.optionalExtensions)),\"onDone\"in s&&(f=s.onDone),\"profile\"in s&&(h=!!s.profile),\"pixelRatio\"in s&&(u=+s.pixelRatio))),e&&(\"canvas\"===e.nodeName.toLowerCase()?a=e:i=e),!o){if(!a){if(!(e=function(t,e,r){function n(){var e=window.innerWidth,n=window.innerHeight;t!==document.body&&(e=(n=t.getBoundingClientRect()).right-n.left,n=n.bottom-n.top),i.width=r*e,i.height=r*n,j(i.style,{width:e+\"px\",height:n+\"px\"})}var i=document.createElement(\"canvas\");return j(i.style,{border:0,margin:0,padding:0,top:0,left:0}),t.appendChild(i),t===document.body&&(i.style.position=\"absolute\",j(t.style,{margin:0,padding:0})),window.addEventListener(\"resize\",n,!1),n(),{canvas:i,onDestroy:function(){window.removeEventListener(\"resize\",n),t.removeChild(i)}}}(i||document.body,0,u)))return null;a=e.canvas,p=e.onDestroy}o=function(t,e){function r(r){try{return t.getContext(r,e)}catch(t){return null}}return r(\"webgl\")||r(\"experimental-webgl\")||r(\"webgl-experimental\")}(a,t)}return o?{gl:o,canvas:a,container:i,extensions:l,optionalExtensions:c,pixelRatio:u,profile:h,onDone:f,onDestroy:p}:(p(),f(\"webgl not supported, try upgrading your browser or graphics drivers http://get.webgl.org\"),null)}function a(t,e){for(var r=Array(t),n=0;n<t;++n)r[n]=e(n);return r}function o(t){var e,r;return e=(65535<t)<<4,e|=r=(255<(t>>>=e))<<3,(e|=r=(15<(t>>>=r))<<2)|(r=(3<(t>>>=r))<<1)|t>>>r>>1}function s(){function t(t){t:{for(var e=16;268435456>=e;e*=16)if(t<=e){t=e;break t}t=0}return 0<(e=r[o(t)>>2]).length?e.pop():new ArrayBuffer(t)}function e(t){r[o(t.byteLength)>>2].push(t)}var r=a(8,function(){return[]});return{alloc:t,free:e,allocType:function(e,r){var n=null;switch(e){case 5120:n=new Int8Array(t(r),0,r);break;case 5121:n=new Uint8Array(t(r),0,r);break;case 5122:n=new Int16Array(t(2*r),0,r);break;case 5123:n=new Uint16Array(t(2*r),0,r);break;case 5124:n=new Int32Array(t(4*r),0,r);break;case 5125:n=new Uint32Array(t(4*r),0,r);break;case 5126:n=new Float32Array(t(4*r),0,r);break;default:return null}return n.length!==r?n.subarray(0,r):n},freeType:function(t){e(t.buffer)}}}function l(t){return!!t&&\"object\"==typeof t&&Array.isArray(t.shape)&&Array.isArray(t.stride)&&\"number\"==typeof t.offset&&t.shape.length===t.stride.length&&(Array.isArray(t.data)||W(t.data))}function c(t,e,r,n,i,a){for(var o=0;o<e;++o)for(var s=t[o],l=0;l<r;++l)for(var c=s[l],u=0;u<n;++u)i[a++]=c[u]}function u(t){return 0|J[Object.prototype.toString.call(t)]}function h(t,e){for(var r=0;r<e.length;++r)t[r]=e[r]}function f(t,e,r,n,i,a,o){for(var s=0,l=0;l<r;++l)for(var c=0;c<n;++c)t[s++]=e[i*l+a*c+o]}function p(t,e,r,n){function i(e){this.id=c++,this.buffer=t.createBuffer(),this.type=e,this.usage=35044,this.byteLength=0,this.dimension=1,this.dtype=5121,this.persistentData=null,r.profile&&(this.stats={size:0})}function a(e,r,n){e.byteLength=r.byteLength,t.bufferData(e.type,r,n)}function o(t,e,r,n,i,o){if(t.usage=r,Array.isArray(e)){if(t.dtype=n||5126,0<e.length)if(Array.isArray(e[0])){i=tt(e);for(var s=n=1;s<i.length;++s)n*=i[s];t.dimension=n,a(t,e=Q(e,i,t.dtype),r),o?t.persistentData=e:G.freeType(e)}else\"number\"==typeof e[0]?(t.dimension=i,h(i=G.allocType(t.dtype,e.length),e),a(t,i,r),o?t.persistentData=i:G.freeType(i)):W(e[0])&&(t.dimension=e[0].length,t.dtype=n||u(e[0])||5126,a(t,e=Q(e,[e.length,e[0].length],t.dtype),r),o?t.persistentData=e:G.freeType(e))}else if(W(e))t.dtype=n||u(e),t.dimension=i,a(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e.buffer)));else if(l(e)){i=e.shape;var c=e.stride,p=(s=e.offset,0),d=0,g=0,v=0;1===i.length?(p=i[0],d=1,g=c[0],v=0):2===i.length&&(p=i[0],d=i[1],g=c[0],v=c[1]),t.dtype=n||u(e.data)||5126,t.dimension=d,f(i=G.allocType(t.dtype,p*d),e.data,p,d,g,v,s),a(t,i,r),o?t.persistentData=i:G.freeType(i)}}function s(r){e.bufferCount--;for(var i=0;i<n.state.length;++i){var a=n.state[i];a.buffer===r&&(t.disableVertexAttribArray(i),a.buffer=null)}t.deleteBuffer(r.buffer),r.buffer=null,delete p[r.id]}var c=0,p={};i.prototype.bind=function(){t.bindBuffer(this.type,this.buffer)},i.prototype.destroy=function(){s(this)};var d=[];return r.profile&&(e.getTotalBufferSize=function(){var t=0;return Object.keys(p).forEach(function(e){t+=p[e].stats.size}),t}),{create:function(n,a,c,d){function g(e){var n=35044,i=null,a=0,s=0,c=1;return Array.isArray(e)||W(e)||l(e)?i=e:\"number\"==typeof e?a=0|e:e&&(\"data\"in e&&(i=e.data),\"usage\"in e&&(n=$[e.usage]),\"type\"in e&&(s=K[e.type]),\"dimension\"in e&&(c=0|e.dimension),\"length\"in e&&(a=0|e.length)),v.bind(),i?o(v,i,n,s,c,d):(a&&t.bufferData(v.type,a,n),v.dtype=s||5121,v.usage=n,v.dimension=c,v.byteLength=a),r.profile&&(v.stats.size=v.byteLength*et[v.dtype]),g}e.bufferCount++;var v=new i(a);return p[v.id]=v,c||g(n),g._reglType=\"buffer\",g._buffer=v,g.subdata=function(e,r){var n,i=0|(r||0);if(v.bind(),W(e))t.bufferSubData(v.type,i,e);else if(Array.isArray(e)){if(0<e.length)if(\"number\"==typeof e[0]){var a=G.allocType(v.dtype,e.length);h(a,e),t.bufferSubData(v.type,i,a),G.freeType(a)}else(Array.isArray(e[0])||W(e[0]))&&(n=tt(e),a=Q(e,n,v.dtype),t.bufferSubData(v.type,i,a),G.freeType(a))}else if(l(e)){n=e.shape;var o=e.stride,s=a=0,c=0,p=0;1===n.length?(a=n[0],s=1,c=o[0],p=0):2===n.length&&(a=n[0],s=n[1],c=o[0],p=o[1]),n=Array.isArray(e.data)?v.dtype:u(e.data),f(n=G.allocType(n,a*s),e.data,a,s,c,p,e.offset),t.bufferSubData(v.type,i,n),G.freeType(n)}return g},r.profile&&(g.stats=v.stats),g.destroy=function(){s(v)},g},createStream:function(t,e){var r=d.pop();return r||(r=new i(t)),r.bind(),o(r,e,35040,0,1,!1),r},destroyStream:function(t){d.push(t)},clear:function(){X(p).forEach(s),d.forEach(s)},getBuffer:function(t){return t&&t._buffer instanceof i?t._buffer:null},restore:function(){X(p).forEach(function(e){e.buffer=t.createBuffer(),t.bindBuffer(e.type,e.buffer),t.bufferData(e.type,e.persistentData||e.byteLength,e.usage)})},_initBuffer:o}}function d(t,e,r,n){function i(t){this.id=c++,s[this.id]=this,this.buffer=t,this.primType=4,this.type=this.vertCount=0}function a(n,i,a,o,s,c,u){if(n.buffer.bind(),i){var h=u;u||W(i)&&(!l(i)||W(i.data))||(h=e.oes_element_index_uint?5125:5123),r._initBuffer(n.buffer,i,a,h,3)}else t.bufferData(34963,c,a),n.buffer.dtype=h||5121,n.buffer.usage=a,n.buffer.dimension=3,n.buffer.byteLength=c;if(h=u,!u){switch(n.buffer.dtype){case 5121:case 5120:h=5121;break;case 5123:case 5122:h=5123;break;case 5125:case 5124:h=5125}n.buffer.dtype=h}n.type=h,0>(i=s)&&(i=n.buffer.byteLength,5123===h?i>>=1:5125===h&&(i>>=2)),n.vertCount=i,i=o,0>o&&(i=4,1===(o=n.buffer.dimension)&&(i=0),2===o&&(i=1),3===o&&(i=4)),n.primType=i}function o(t){n.elementsCount--,delete s[t.id],t.buffer.destroy(),t.buffer=null}var s={},c=0,u={uint8:5121,uint16:5123};e.oes_element_index_uint&&(u.uint32=5125),i.prototype.bind=function(){this.buffer.bind()};var h=[];return{create:function(t,e){function s(t){if(t)if(\"number\"==typeof t)c(t),h.primType=4,h.vertCount=0|t,h.type=5121;else{var e=null,r=35044,n=-1,i=-1,o=0,f=0;Array.isArray(t)||W(t)||l(t)?e=t:(\"data\"in t&&(e=t.data),\"usage\"in t&&(r=$[t.usage]),\"primitive\"in t&&(n=rt[t.primitive]),\"count\"in t&&(i=0|t.count),\"type\"in t&&(f=u[t.type]),\"length\"in t?o=0|t.length:(o=i,5123===f||5122===f?o*=2:5125!==f&&5124!==f||(o*=4))),a(h,e,r,n,i,o,f)}else c(),h.primType=4,h.vertCount=0,h.type=5121;return s}var c=r.create(null,34963,!0),h=new i(c._buffer);return n.elementsCount++,s(t),s._reglType=\"elements\",s._elements=h,s.subdata=function(t,e){return c.subdata(t,e),s},s.destroy=function(){o(h)},s},createStream:function(t){var e=h.pop();return e||(e=new i(r.create(null,34963,!0,!1)._buffer)),a(e,t,35040,-1,-1,0,0),e},destroyStream:function(t){h.push(t)},getElements:function(t){return\"function\"==typeof t&&t._elements instanceof i?t._elements:null},clear:function(){X(s).forEach(o)}}}function g(t){for(var e=G.allocType(5123,t.length),r=0;r<t.length;++r)if(isNaN(t[r]))e[r]=65535;else if(1/0===t[r])e[r]=31744;else if(-1/0===t[r])e[r]=64512;else{nt[0]=t[r];var n=(a=it[0])>>>31<<15,i=(a<<1>>>24)-127,a=a>>13&1023;e[r]=-24>i?n:-14>i?n+(a+1024>>-14-i):15<i?n+31744:n+(i+15<<10)+a}return e}function v(t){return Array.isArray(t)||W(t)}function m(t){return\"[object \"+t+\"]\"}function y(t){return Array.isArray(t)&&(0===t.length||\"number\"==typeof t[0])}function x(t){return!(!Array.isArray(t)||0===t.length||!v(t[0]))}function b(t){return Object.prototype.toString.call(t)}function _(t){if(!t)return!1;var e=b(t);return 0<=pt.indexOf(e)||(y(t)||x(t)||l(t))}function w(t,e){36193===t.type?(t.data=g(e),G.freeType(e)):t.data=e}function k(t,e,r,n,i,a){if(t=\"undefined\"!=typeof gt[t]?gt[t]:st[t]*dt[e],a&&(t*=6),i){for(n=0;1<=r;)n+=t*r*r,r/=2;return n}return t*r*n}function T(t,e,r,n,i,a,o){function s(){this.format=this.internalformat=6408,this.type=5121,this.flipY=this.premultiplyAlpha=this.compressed=!1,this.unpackAlignment=1,this.colorSpace=37444,this.channels=this.height=this.width=0}function c(t,e){t.internalformat=e.internalformat,t.format=e.format,t.type=e.type,t.compressed=e.compressed,t.premultiplyAlpha=e.premultiplyAlpha,t.flipY=e.flipY,t.unpackAlignment=e.unpackAlignment,t.colorSpace=e.colorSpace,t.width=e.width,t.height=e.height,t.channels=e.channels}function u(t,e){if(\"object\"==typeof e&&e){\"premultiplyAlpha\"in e&&(t.premultiplyAlpha=e.premultiplyAlpha),\"flipY\"in e&&(t.flipY=e.flipY),\"alignment\"in e&&(t.unpackAlignment=e.alignment),\"colorSpace\"in e&&(t.colorSpace=q[e.colorSpace]),\"type\"in e&&(t.type=H[e.type]);var r=t.width,n=t.height,i=t.channels,a=!1;\"shape\"in e?(r=e.shape[0],n=e.shape[1],3===e.shape.length&&(i=e.shape[2],a=!0)):(\"radius\"in e&&(r=n=e.radius),\"width\"in e&&(r=e.width),\"height\"in e&&(n=e.height),\"channels\"in e&&(i=e.channels,a=!0)),t.width=0|r,t.height=0|n,t.channels=0|i,r=!1,\"format\"in e&&(r=e.format,n=t.internalformat=Y[r],t.format=pt[n],r in H&&!(\"type\"in e)&&(t.type=H[r]),r in K&&(t.compressed=!0),r=!0),!a&&r?t.channels=st[t.format]:a&&!r&&t.channels!==ot[t.format]&&(t.format=t.internalformat=ot[t.channels])}}function h(e){t.pixelStorei(37440,e.flipY),t.pixelStorei(37441,e.premultiplyAlpha),t.pixelStorei(37443,e.colorSpace),t.pixelStorei(3317,e.unpackAlignment)}function f(){s.call(this),this.yOffset=this.xOffset=0,this.data=null,this.needsFree=!1,this.element=null,this.needsCopy=!1}function p(t,e){var r=null;if(_(e)?r=e:e&&(u(t,e),\"x\"in e&&(t.xOffset=0|e.x),\"y\"in e&&(t.yOffset=0|e.y),_(e.data)&&(r=e.data)),e.copy){var n=i.viewportWidth,a=i.viewportHeight;t.width=t.width||n-t.xOffset,t.height=t.height||a-t.yOffset,t.needsCopy=!0}else if(r){if(W(r))t.channels=t.channels||4,t.data=r,\"type\"in e||5121!==t.type||(t.type=0|J[Object.prototype.toString.call(r)]);else if(y(r)){switch(t.channels=t.channels||4,a=(n=r).length,t.type){case 5121:case 5123:case 5125:case 5126:(a=G.allocType(t.type,a)).set(n),t.data=a;break;case 36193:t.data=g(n)}t.alignment=1,t.needsFree=!0}else if(l(r)){n=r.data,Array.isArray(n)||5121!==t.type||(t.type=0|J[Object.prototype.toString.call(n)]);a=r.shape;var o,s,c,h,f=r.stride;3===a.length?(c=a[2],h=f[2]):h=c=1,o=a[0],s=a[1],a=f[0],f=f[1],t.alignment=1,t.width=o,t.height=s,t.channels=c,t.format=t.internalformat=ot[c],t.needsFree=!0,o=h,r=r.offset,c=t.width,h=t.height,s=t.channels;for(var p=G.allocType(36193===t.type?5126:t.type,c*h*s),d=0,m=0;m<h;++m)for(var k=0;k<c;++k)for(var T=0;T<s;++T)p[d++]=n[a*k+f*m+o*T+r];w(t,p)}else if(b(r)===lt||b(r)===ct)b(r)===lt?t.element=r:t.element=r.canvas,t.width=t.element.width,t.height=t.element.height,t.channels=4;else if(b(r)===ut)t.element=r,t.width=r.width,t.height=r.height,t.channels=4;else if(b(r)===ht)t.element=r,t.width=r.naturalWidth,t.height=r.naturalHeight,t.channels=4;else if(b(r)===ft)t.element=r,t.width=r.videoWidth,t.height=r.videoHeight,t.channels=4;else if(x(r)){for(n=t.width||r[0].length,a=t.height||r.length,f=t.channels,f=v(r[0][0])?f||r[0][0].length:f||1,o=Z.shape(r),c=1,h=0;h<o.length;++h)c*=o[h];c=G.allocType(36193===t.type?5126:t.type,c),Z.flatten(r,o,\"\",c),w(t,c),t.alignment=1,t.width=n,t.height=a,t.channels=f,t.format=t.internalformat=ot[f],t.needsFree=!0}}else t.width=t.width||1,t.height=t.height||1,t.channels=t.channels||4}function d(e,r,i,a,o){var s=e.element,l=e.data,c=e.internalformat,u=e.format,f=e.type,p=e.width,d=e.height;h(e),s?t.texSubImage2D(r,o,i,a,u,f,s):e.compressed?t.compressedTexSubImage2D(r,o,i,a,c,p,d,l):e.needsCopy?(n(),t.copyTexSubImage2D(r,o,i,a,e.xOffset,e.yOffset,p,d)):t.texSubImage2D(r,o,i,a,p,d,u,f,l)}function m(){return dt.pop()||new f}function T(t){t.needsFree&&G.freeType(t.data),f.call(t),dt.push(t)}function A(){s.call(this),this.genMipmaps=!1,this.mipmapHint=4352,this.mipmask=0,this.images=Array(16)}function M(t,e,r){var n=t.images[0]=m();t.mipmask=1,n.width=t.width=e,n.height=t.height=r,n.channels=t.channels=4}function S(t,e){var r=null;if(_(e))c(r=t.images[0]=m(),t),p(r,e),t.mipmask=1;else if(u(t,e),Array.isArray(e.mipmap))for(var n=e.mipmap,i=0;i<n.length;++i)c(r=t.images[i]=m(),t),r.width>>=i,r.height>>=i,p(r,n[i]),t.mipmask|=1<<i;else c(r=t.images[0]=m(),t),p(r,e),t.mipmask=1;c(t,t.images[0])}function E(e,r){for(var i=e.images,a=0;a<i.length&&i[a];++a){var o=i[a],s=r,l=a,c=o.element,u=o.data,f=o.internalformat,p=o.format,d=o.type,g=o.width,v=o.height,m=o.channels;h(o),c?t.texImage2D(s,l,p,p,d,c):o.compressed?t.compressedTexImage2D(s,l,f,g,v,0,u):o.needsCopy?(n(),t.copyTexImage2D(s,l,p,o.xOffset,o.yOffset,g,v,0)):((o=!u)&&(u=G.zero.allocType(d,g*v*m)),t.texImage2D(s,l,p,g,v,0,p,d,u),o&&u&&G.zero.freeType(u))}}function C(){var t=gt.pop()||new A;s.call(t);for(var e=t.mipmask=0;16>e;++e)t.images[e]=null;return t}function L(t){for(var e=t.images,r=0;r<e.length;++r)e[r]&&T(e[r]),e[r]=null;gt.push(t)}function P(){this.magFilter=this.minFilter=9728,this.wrapT=this.wrapS=33071,this.anisotropic=1,this.genMipmaps=!1,this.mipmapHint=4352}function O(t,e){\"min\"in e&&(t.minFilter=V[e.min],0<=at.indexOf(t.minFilter)&&!(\"faces\"in e)&&(t.genMipmaps=!0)),\"mag\"in e&&(t.magFilter=U[e.mag]);var r=t.wrapS,n=t.wrapT;if(\"wrap\"in e){var i=e.wrap;\"string\"==typeof i?r=n=N[i]:Array.isArray(i)&&(r=N[i[0]],n=N[i[1]])}else\"wrapS\"in e&&(r=N[e.wrapS]),\"wrapT\"in e&&(n=N[e.wrapT]);if(t.wrapS=r,t.wrapT=n,\"anisotropic\"in e&&(t.anisotropic=e.anisotropic),\"mipmap\"in e){switch(r=!1,typeof e.mipmap){case\"string\":t.mipmapHint=B[e.mipmap],r=t.genMipmaps=!0;break;case\"boolean\":r=t.genMipmaps=e.mipmap;break;case\"object\":t.genMipmaps=!1,r=!0}!r||\"min\"in e||(t.minFilter=9984)}}function z(r,n){t.texParameteri(n,10241,r.minFilter),t.texParameteri(n,10240,r.magFilter),t.texParameteri(n,10242,r.wrapS),t.texParameteri(n,10243,r.wrapT),e.ext_texture_filter_anisotropic&&t.texParameteri(n,34046,r.anisotropic),r.genMipmaps&&(t.hint(33170,r.mipmapHint),t.generateMipmap(n))}function I(e){s.call(this),this.mipmask=0,this.internalformat=6408,this.id=vt++,this.refCount=1,this.target=e,this.texture=t.createTexture(),this.unit=-1,this.bindCount=0,this.texInfo=new P,o.profile&&(this.stats={size:0})}function D(e){t.activeTexture(33984),t.bindTexture(e.target,e.texture)}function R(){var e=xt[0];e?t.bindTexture(e.target,e.texture):t.bindTexture(3553,null)}function F(e){var r=e.texture,n=e.unit,i=e.target;0<=n&&(t.activeTexture(33984+n),t.bindTexture(i,null),xt[n]=null),t.deleteTexture(r),e.texture=null,e.params=null,e.pixels=null,e.refCount=0,delete mt[e.id],a.textureCount--}var B={\"don't care\":4352,\"dont care\":4352,nice:4354,fast:4353},N={repeat:10497,clamp:33071,mirror:33648},U={nearest:9728,linear:9729},V=j({mipmap:9987,\"nearest mipmap nearest\":9984,\"linear mipmap nearest\":9985,\"nearest mipmap linear\":9986,\"linear mipmap linear\":9987},U),q={none:0,browser:37444},H={uint8:5121,rgba4:32819,rgb565:33635,\"rgb5 a1\":32820},Y={alpha:6406,luminance:6409,\"luminance alpha\":6410,rgb:6407,rgba:6408,rgba4:32854,\"rgb5 a1\":32855,rgb565:36194},K={};e.ext_srgb&&(Y.srgb=35904,Y.srgba=35906),e.oes_texture_float&&(H.float32=H.float=5126),e.oes_texture_half_float&&(H.float16=H[\"half float\"]=36193),e.webgl_depth_texture&&(j(Y,{depth:6402,\"depth stencil\":34041}),j(H,{uint16:5123,uint32:5125,\"depth stencil\":34042})),e.webgl_compressed_texture_s3tc&&j(K,{\"rgb s3tc dxt1\":33776,\"rgba s3tc dxt1\":33777,\"rgba s3tc dxt3\":33778,\"rgba s3tc dxt5\":33779}),e.webgl_compressed_texture_atc&&j(K,{\"rgb atc\":35986,\"rgba atc explicit alpha\":35987,\"rgba atc interpolated alpha\":34798}),e.webgl_compressed_texture_pvrtc&&j(K,{\"rgb pvrtc 4bppv1\":35840,\"rgb pvrtc 2bppv1\":35841,\"rgba pvrtc 4bppv1\":35842,\"rgba pvrtc 2bppv1\":35843}),e.webgl_compressed_texture_etc1&&(K[\"rgb etc1\"]=36196);var $=Array.prototype.slice.call(t.getParameter(34467));Object.keys(K).forEach(function(t){var e=K[t];0<=$.indexOf(e)&&(Y[t]=e)});var Q=Object.keys(Y);r.textureFormats=Q;var tt=[];Object.keys(Y).forEach(function(t){tt[Y[t]]=t});var et=[];Object.keys(H).forEach(function(t){et[H[t]]=t});var rt=[];Object.keys(U).forEach(function(t){rt[U[t]]=t});var nt=[];Object.keys(V).forEach(function(t){nt[V[t]]=t});var it=[];Object.keys(N).forEach(function(t){it[N[t]]=t});var pt=Q.reduce(function(t,e){var r=Y[e];return 6409===r||6406===r||6409===r||6410===r||6402===r||34041===r?t[r]=r:32855===r||0<=e.indexOf(\"rgba\")?t[r]=6408:t[r]=6407,t},{}),dt=[],gt=[],vt=0,mt={},yt=r.maxTextureUnits,xt=Array(yt).map(function(){return null});return j(I.prototype,{bind:function(){this.bindCount+=1;var e=this.unit;if(0>e){for(var r=0;r<yt;++r){var n=xt[r];if(n){if(0<n.bindCount)continue;n.unit=-1}xt[r]=this,e=r;break}o.profile&&a.maxTextureUnits<e+1&&(a.maxTextureUnits=e+1),this.unit=e,t.activeTexture(33984+e),t.bindTexture(this.target,this.texture)}return e},unbind:function(){--this.bindCount},decRef:function(){0>=--this.refCount&&F(this)}}),o.profile&&(a.getTotalTextureSize=function(){var t=0;return Object.keys(mt).forEach(function(e){t+=mt[e].stats.size}),t}),{create2D:function(e,r){function n(t,e){var r=i.texInfo;P.call(r);var a=C();return\"number\"==typeof t?M(a,0|t,\"number\"==typeof e?0|e:0|t):t?(O(r,t),S(a,t)):M(a,1,1),r.genMipmaps&&(a.mipmask=(a.width<<1)-1),i.mipmask=a.mipmask,c(i,a),i.internalformat=a.internalformat,n.width=a.width,n.height=a.height,D(i),E(a,3553),z(r,3553),R(),L(a),o.profile&&(i.stats.size=k(i.internalformat,i.type,a.width,a.height,r.genMipmaps,!1)),n.format=tt[i.internalformat],n.type=et[i.type],n.mag=rt[r.magFilter],n.min=nt[r.minFilter],n.wrapS=it[r.wrapS],n.wrapT=it[r.wrapT],n}var i=new I(3553);return mt[i.id]=i,a.textureCount++,n(e,r),n.subimage=function(t,e,r,a){e|=0,r|=0,a|=0;var o=m();return c(o,i),o.width=0,o.height=0,p(o,t),o.width=o.width||(i.width>>a)-e,o.height=o.height||(i.height>>a)-r,D(i),d(o,3553,e,r,a),R(),T(o),n},n.resize=function(e,r){var a=0|e,s=0|r||a;if(a===i.width&&s===i.height)return n;n.width=i.width=a,n.height=i.height=s,D(i);for(var l,c=i.channels,u=i.type,h=0;i.mipmask>>h;++h){var f=a>>h,p=s>>h;if(!f||!p)break;l=G.zero.allocType(u,f*p*c),t.texImage2D(3553,h,i.format,f,p,0,i.format,i.type,l),l&&G.zero.freeType(l)}return R(),o.profile&&(i.stats.size=k(i.internalformat,i.type,a,s,!1,!1)),n},n._reglType=\"texture2d\",n._texture=i,o.profile&&(n.stats=i.stats),n.destroy=function(){i.decRef()},n},createCube:function(e,r,n,i,s,l){function h(t,e,r,n,i,a){var s,l=f.texInfo;for(P.call(l),s=0;6>s;++s)g[s]=C();if(\"number\"!=typeof t&&t){if(\"object\"==typeof t)if(e)S(g[0],t),S(g[1],e),S(g[2],r),S(g[3],n),S(g[4],i),S(g[5],a);else if(O(l,t),u(f,t),\"faces\"in t)for(t=t.faces,s=0;6>s;++s)c(g[s],f),S(g[s],t[s]);else for(s=0;6>s;++s)S(g[s],t)}else for(t=0|t||1,s=0;6>s;++s)M(g[s],t,t);for(c(f,g[0]),f.mipmask=l.genMipmaps?(g[0].width<<1)-1:g[0].mipmask,f.internalformat=g[0].internalformat,h.width=g[0].width,h.height=g[0].height,D(f),s=0;6>s;++s)E(g[s],34069+s);for(z(l,34067),R(),o.profile&&(f.stats.size=k(f.internalformat,f.type,h.width,h.height,l.genMipmaps,!0)),h.format=tt[f.internalformat],h.type=et[f.type],h.mag=rt[l.magFilter],h.min=nt[l.minFilter],h.wrapS=it[l.wrapS],h.wrapT=it[l.wrapT],s=0;6>s;++s)L(g[s]);return h}var f=new I(34067);mt[f.id]=f,a.cubeCount++;var g=Array(6);return h(e,r,n,i,s,l),h.subimage=function(t,e,r,n,i){r|=0,n|=0,i|=0;var a=m();return c(a,f),a.width=0,a.height=0,p(a,e),a.width=a.width||(f.width>>i)-r,a.height=a.height||(f.height>>i)-n,D(f),d(a,34069+t,r,n,i),R(),T(a),h},h.resize=function(e){if((e|=0)!==f.width){h.width=f.width=e,h.height=f.height=e,D(f);for(var r=0;6>r;++r)for(var n=0;f.mipmask>>n;++n)t.texImage2D(34069+r,n,f.format,e>>n,e>>n,0,f.format,f.type,null);return R(),o.profile&&(f.stats.size=k(f.internalformat,f.type,h.width,h.height,!1,!0)),h}},h._reglType=\"textureCube\",h._texture=f,o.profile&&(h.stats=f.stats),h.destroy=function(){f.decRef()},h},clear:function(){for(var e=0;e<yt;++e)t.activeTexture(33984+e),t.bindTexture(3553,null),xt[e]=null;X(mt).forEach(F),a.cubeCount=0,a.textureCount=0},getTexture:function(t){return null},restore:function(){for(var e=0;e<yt;++e){var r=xt[e];r&&(r.bindCount=0,r.unit=-1,xt[e]=null)}X(mt).forEach(function(e){e.texture=t.createTexture(),t.bindTexture(e.target,e.texture);for(var r=0;32>r;++r)if(0!=(e.mipmask&1<<r))if(3553===e.target)t.texImage2D(3553,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);else for(var n=0;6>n;++n)t.texImage2D(34069+n,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);z(e.texInfo,e.target)})}}}function A(t,e,r,n,i,a){function o(t,e,r){this.target=t,this.texture=e,this.renderbuffer=r;var n=t=0;e?(t=e.width,n=e.height):r&&(t=r.width,n=r.height),this.width=t,this.height=n}function s(t){t&&(t.texture&&t.texture._texture.decRef(),t.renderbuffer&&t.renderbuffer._renderbuffer.decRef())}function l(t,e,r){t&&(t.texture?t.texture._texture.refCount+=1:t.renderbuffer._renderbuffer.refCount+=1)}function c(e,r){r&&(r.texture?t.framebufferTexture2D(36160,e,r.target,r.texture._texture.texture,0):t.framebufferRenderbuffer(36160,e,36161,r.renderbuffer._renderbuffer.renderbuffer))}function u(t){var e=3553,r=null,n=null,i=t;return\"object\"==typeof t&&(i=t.data,\"target\"in t&&(e=0|t.target)),\"texture2d\"===(t=i._reglType)?r=i:\"textureCube\"===t?r=i:\"renderbuffer\"===t&&(n=i,e=36161),new o(e,r,n)}function h(t,e,r,a,s){return r?((t=n.create2D({width:t,height:e,format:a,type:s}))._texture.refCount=0,new o(3553,t,null)):((t=i.create({width:t,height:e,format:a}))._renderbuffer.refCount=0,new o(36161,null,t))}function f(t){return t&&(t.texture||t.renderbuffer)}function p(t,e,r){t&&(t.texture?t.texture.resize(e,r):t.renderbuffer&&t.renderbuffer.resize(e,r),t.width=e,t.height=r)}function d(){this.id=k++,T[this.id]=this,this.framebuffer=t.createFramebuffer(),this.height=this.width=0,this.colorAttachments=[],this.depthStencilAttachment=this.stencilAttachment=this.depthAttachment=null}function g(t){t.colorAttachments.forEach(s),s(t.depthAttachment),s(t.stencilAttachment),s(t.depthStencilAttachment)}function v(e){t.deleteFramebuffer(e.framebuffer),e.framebuffer=null,a.framebufferCount--,delete T[e.id]}function m(e){var n;t.bindFramebuffer(36160,e.framebuffer);var i=e.colorAttachments;for(n=0;n<i.length;++n)c(36064+n,i[n]);for(n=i.length;n<r.maxColorAttachments;++n)t.framebufferTexture2D(36160,36064+n,3553,null,0);t.framebufferTexture2D(36160,33306,3553,null,0),t.framebufferTexture2D(36160,36096,3553,null,0),t.framebufferTexture2D(36160,36128,3553,null,0),c(36096,e.depthAttachment),c(36128,e.stencilAttachment),c(33306,e.depthStencilAttachment),t.checkFramebufferStatus(36160),t.isContextLost(),t.bindFramebuffer(36160,x.next?x.next.framebuffer:null),x.cur=x.next,t.getError()}function y(t,e){function r(t,e){var i,a=0,o=0,s=!0,c=!0;i=null;var p=!0,d=\"rgba\",v=\"uint8\",y=1,x=null,w=null,k=null,T=!1;\"number\"==typeof t?(a=0|t,o=0|e||a):t?(\"shape\"in t?(a=(o=t.shape)[0],o=o[1]):(\"radius\"in t&&(a=o=t.radius),\"width\"in t&&(a=t.width),\"height\"in t&&(o=t.height)),(\"color\"in t||\"colors\"in t)&&(i=t.color||t.colors,Array.isArray(i)),i||(\"colorCount\"in t&&(y=0|t.colorCount),\"colorTexture\"in t&&(p=!!t.colorTexture,d=\"rgba4\"),\"colorType\"in t&&(v=t.colorType,!p)&&(\"half float\"===v||\"float16\"===v?d=\"rgba16f\":\"float\"!==v&&\"float32\"!==v||(d=\"rgba32f\")),\"colorFormat\"in t&&(d=t.colorFormat,0<=b.indexOf(d)?p=!0:0<=_.indexOf(d)&&(p=!1))),(\"depthTexture\"in t||\"depthStencilTexture\"in t)&&(T=!(!t.depthTexture&&!t.depthStencilTexture)),\"depth\"in t&&(\"boolean\"==typeof t.depth?s=t.depth:(x=t.depth,c=!1)),\"stencil\"in t&&(\"boolean\"==typeof t.stencil?c=t.stencil:(w=t.stencil,s=!1)),\"depthStencil\"in t&&(\"boolean\"==typeof t.depthStencil?s=c=t.depthStencil:(k=t.depthStencil,c=s=!1))):a=o=1;var A=null,M=null,S=null,E=null;if(Array.isArray(i))A=i.map(u);else if(i)A=[u(i)];else for(A=Array(y),i=0;i<y;++i)A[i]=h(a,o,p,d,v);for(a=a||A[0].width,o=o||A[0].height,x?M=u(x):s&&!c&&(M=h(a,o,T,\"depth\",\"uint32\")),w?S=u(w):c&&!s&&(S=h(a,o,!1,\"stencil\",\"uint8\")),k?E=u(k):!x&&!w&&c&&s&&(E=h(a,o,T,\"depth stencil\",\"depth stencil\")),s=null,i=0;i<A.length;++i)l(A[i]),A[i]&&A[i].texture&&(c=yt[A[i].texture._texture.format]*xt[A[i].texture._texture.type],null===s&&(s=c));return l(M),l(S),l(E),g(n),n.width=a,n.height=o,n.colorAttachments=A,n.depthAttachment=M,n.stencilAttachment=S,n.depthStencilAttachment=E,r.color=A.map(f),r.depth=f(M),r.stencil=f(S),r.depthStencil=f(E),r.width=n.width,r.height=n.height,m(n),r}var n=new d;return a.framebufferCount++,r(t,e),j(r,{resize:function(t,e){var i=Math.max(0|t,1),a=Math.max(0|e||i,1);if(i===n.width&&a===n.height)return r;for(var o=n.colorAttachments,s=0;s<o.length;++s)p(o[s],i,a);return p(n.depthAttachment,i,a),p(n.stencilAttachment,i,a),p(n.depthStencilAttachment,i,a),n.width=r.width=i,n.height=r.height=a,m(n),r},_reglType:\"framebuffer\",_framebuffer:n,destroy:function(){v(n),g(n)},use:function(t){x.setFBO({framebuffer:r},t)}})}var x={cur:null,next:null,dirty:!1,setFBO:null},b=[\"rgba\"],_=[\"rgba4\",\"rgb565\",\"rgb5 a1\"];e.ext_srgb&&_.push(\"srgba\"),e.ext_color_buffer_half_float&&_.push(\"rgba16f\",\"rgb16f\"),e.webgl_color_buffer_float&&_.push(\"rgba32f\");var w=[\"uint8\"];e.oes_texture_half_float&&w.push(\"half float\",\"float16\"),e.oes_texture_float&&w.push(\"float\",\"float32\");var k=0,T={};return j(x,{getFramebuffer:function(t){return\"function\"==typeof t&&\"framebuffer\"===t._reglType&&(t=t._framebuffer)instanceof d?t:null},create:y,createCube:function(t){function e(t){var i,a={color:null},o=0,s=null;i=\"rgba\";var l=\"uint8\",c=1;if(\"number\"==typeof t?o=0|t:t?(\"shape\"in t?o=t.shape[0]:(\"radius\"in t&&(o=0|t.radius),\"width\"in t?o=0|t.width:\"height\"in t&&(o=0|t.height)),(\"color\"in t||\"colors\"in t)&&(s=t.color||t.colors,Array.isArray(s)),s||(\"colorCount\"in t&&(c=0|t.colorCount),\"colorType\"in t&&(l=t.colorType),\"colorFormat\"in t&&(i=t.colorFormat)),\"depth\"in t&&(a.depth=t.depth),\"stencil\"in t&&(a.stencil=t.stencil),\"depthStencil\"in t&&(a.depthStencil=t.depthStencil)):o=1,s)if(Array.isArray(s))for(t=[],i=0;i<s.length;++i)t[i]=s[i];else t=[s];else for(t=Array(c),s={radius:o,format:i,type:l},i=0;i<c;++i)t[i]=n.createCube(s);for(a.color=Array(t.length),i=0;i<t.length;++i)c=t[i],o=o||c.width,a.color[i]={target:34069,data:t[i]};for(i=0;6>i;++i){for(c=0;c<t.length;++c)a.color[c].target=34069+i;0<i&&(a.depth=r[0].depth,a.stencil=r[0].stencil,a.depthStencil=r[0].depthStencil),r[i]?r[i](a):r[i]=y(a)}return j(e,{width:o,height:o,color:t})}var r=Array(6);return e(t),j(e,{faces:r,resize:function(t){var n=0|t;if(n===e.width)return e;var i=e.color;for(t=0;t<i.length;++t)i[t].resize(n);for(t=0;6>t;++t)r[t].resize(n);return e.width=e.height=n,e},_reglType:\"framebufferCube\",destroy:function(){r.forEach(function(t){t.destroy()})}})},clear:function(){X(T).forEach(v)},restore:function(){x.cur=null,x.next=null,x.dirty=!0,X(T).forEach(function(e){e.framebuffer=t.createFramebuffer(),m(e)})}})}function M(){this.w=this.z=this.y=this.x=this.state=0,this.buffer=null,this.size=0,this.normalized=!1,this.type=5126,this.divisor=this.stride=this.offset=0}function S(t,e,r,n){function i(t,e,r,n){this.name=t,this.id=e,this.location=r,this.info=n}function a(t,e){for(var r=0;r<t.length;++r)if(t[r].id===e.id)return void(t[r].location=e.location);t.push(e)}function o(r,n,i){if(!(o=(i=35632===r?c:u)[n])){var a=e.str(n),o=t.createShader(r);t.shaderSource(o,a),t.compileShader(o),i[n]=o}return o}function s(t,e){this.id=p++,this.fragId=t,this.vertId=e,this.program=null,this.uniforms=[],this.attributes=[],n.profile&&(this.stats={uniformsCount:0,attributesCount:0})}function l(r,s){var l,c;l=o(35632,r.fragId),c=o(35633,r.vertId);var u=r.program=t.createProgram();t.attachShader(u,l),t.attachShader(u,c),t.linkProgram(u);var h=t.getProgramParameter(u,35718);n.profile&&(r.stats.uniformsCount=h);var f=r.uniforms;for(l=0;l<h;++l)if(c=t.getActiveUniform(u,l))if(1<c.size)for(var p=0;p<c.size;++p){var d=c.name.replace(\"[0]\",\"[\"+p+\"]\");a(f,new i(d,e.id(d),t.getUniformLocation(u,d),c))}else a(f,new i(c.name,e.id(c.name),t.getUniformLocation(u,c.name),c));for(h=t.getProgramParameter(u,35721),n.profile&&(r.stats.attributesCount=h),f=r.attributes,l=0;l<h;++l)(c=t.getActiveAttrib(u,l))&&a(f,new i(c.name,e.id(c.name),t.getAttribLocation(u,c.name),c))}var c={},u={},h={},f=[],p=0;return n.profile&&(r.getMaxUniformsCount=function(){var t=0;return f.forEach(function(e){e.stats.uniformsCount>t&&(t=e.stats.uniformsCount)}),t},r.getMaxAttributesCount=function(){var t=0;return f.forEach(function(e){e.stats.attributesCount>t&&(t=e.stats.attributesCount)}),t}),{clear:function(){var e=t.deleteShader.bind(t);X(c).forEach(e),c={},X(u).forEach(e),u={},f.forEach(function(e){t.deleteProgram(e.program)}),f.length=0,h={},r.shaderCount=0},program:function(t,e,n){var i=h[e];i||(i=h[e]={});var a=i[t];return a||(a=new s(e,t),r.shaderCount++,l(a),i[t]=a,f.push(a)),a},restore:function(){c={},u={};for(var t=0;t<f.length;++t)l(f[t])},shader:o,frag:-1,vert:-1}}function E(t,e,r,n,i,a,o){function s(i){var a;a=null===e.next?5121:e.next.colorAttachments[0].texture._texture.type;var o=0,s=0,l=n.framebufferWidth,c=n.framebufferHeight,u=null;return W(i)?u=i:i&&(o=0|i.x,s=0|i.y,l=0|(i.width||n.framebufferWidth-o),c=0|(i.height||n.framebufferHeight-s),u=i.data||null),r(),i=l*c*4,u||(5121===a?u=new Uint8Array(i):5126===a&&(u=u||new Float32Array(i))),t.pixelStorei(3333,4),t.readPixels(o,s,l,c,6408,a,u),u}return function(t){return t&&\"framebuffer\"in t?function(t){var r;return e.setFBO({framebuffer:t.framebuffer},function(){r=s(t)}),r}(t):s(t)}}function C(t){return Array.prototype.slice.call(t)}function L(t){return C(t).join(\"\")}function P(){function t(){var t=[],e=[];return j(function(){t.push.apply(t,C(arguments))},{def:function(){var n=\"v\"+r++;return e.push(n),0<arguments.length&&(t.push(n,\"=\"),t.push.apply(t,C(arguments)),t.push(\";\")),n},toString:function(){return L([0<e.length?\"var \"+e+\";\":\"\",L(t)])}})}function e(){function e(t,e){n(t,e,\"=\",r.def(t,e),\";\")}var r=t(),n=t(),i=r.toString,a=n.toString;return j(function(){r.apply(r,C(arguments))},{def:r.def,entry:r,exit:n,save:e,set:function(t,n,i){e(t,n),r(t,n,\"=\",i,\";\")},toString:function(){return i()+a()}})}var r=0,n=[],i=[],a=t(),o={};return{global:a,link:function(t){for(var e=0;e<i.length;++e)if(i[e]===t)return n[e];return e=\"g\"+r++,n.push(e),i.push(t),e},block:t,proc:function(t,r){function n(){var t=\"a\"+i.length;return i.push(t),t}var i=[];r=r||0;for(var a=0;a<r;++a)n();var s=(a=e()).toString;return o[t]=j(a,{arg:n,toString:function(){return L([\"function(\",i.join(),\"){\",s(),\"}\"])}})},scope:e,cond:function(){var t=L(arguments),r=e(),n=e(),i=r.toString,a=n.toString;return j(r,{then:function(){return r.apply(r,C(arguments)),this},else:function(){return n.apply(n,C(arguments)),this},toString:function(){var e=a();return e&&(e=\"else{\"+e+\"}\"),L([\"if(\",t,\"){\",i(),\"}\",e])}})},compile:function(){var t=['\"use strict\";',a,\"return {\"];Object.keys(o).forEach(function(e){t.push('\"',e,'\":',o[e].toString(),\",\")}),t.push(\"}\");var e=L(t).replace(/;/g,\";\\n\").replace(/}/g,\"}\\n\").replace(/{/g,\"{\\n\");return Function.apply(null,n.concat(e)).apply(null,i)}}}function O(t){return Array.isArray(t)||W(t)||l(t)}function z(t){return t.sort(function(t,e){return\"viewport\"===t?-1:\"viewport\"===e?1:t<e?-1:1})}function I(t,e,r,n){this.thisDep=t,this.contextDep=e,this.propDep=r,this.append=n}function D(t){return t&&!(t.thisDep||t.contextDep||t.propDep)}function R(t){return new I(!1,!1,!1,t)}function F(t,e){var r=t.type;return 0===r?new I(!0,1<=(r=t.data.length),2<=r,e):4===r?new I((r=t.data).thisDep,r.contextDep,r.propDep,e):new I(3===r,2===r,1===r,e)}function B(t,e,r,n,i,o,s,l,c,u,h,f,p,d,g){function m(t){return t.replace(\".\",\"_\")}function y(t,e,r){var n=m(t);nt.push(t),et[n]=tt[n]=!!r,it[n]=e}function x(t,e,r){var n=m(t);nt.push(t),Array.isArray(r)?(tt[n]=r.slice(),et[n]=r.slice()):tt[n]=et[n]=r,at[n]=e}function b(){var t=P(),r=t.link,n=t.global;t.id=lt++,t.batchId=\"0\";var i=r(ot),a=t.shared={props:\"a0\"};Object.keys(ot).forEach(function(t){a[t]=n.def(i,\".\",t)});var o=t.next={},s=t.current={};Object.keys(at).forEach(function(t){Array.isArray(tt[t])&&(o[t]=n.def(a.next,\".\",t),s[t]=n.def(a.current,\".\",t))});var l=t.constants={};Object.keys(st).forEach(function(t){l[t]=n.def(JSON.stringify(st[t]))}),t.invoke=function(e,n){switch(n.type){case 0:var i=[\"this\",a.context,a.props,t.batchId];return e.def(r(n.data),\".call(\",i.slice(0,Math.max(n.data.length+1,4)),\")\");case 1:return e.def(a.props,n.data);case 2:return e.def(a.context,n.data);case 3:return e.def(\"this\",n.data);case 4:return n.data.append(t,e),n.data.ref}},t.attribCache={};var c={};return t.scopeAttrib=function(t){if((t=e.id(t))in c)return c[t];var n=u.scope[t];return n||(n=u.scope[t]=new Z),c[t]=r(n)},t}function _(t,e){var r=t.static,n=t.dynamic;if(\"framebuffer\"in r){var i=r.framebuffer;return i?(i=l.getFramebuffer(i),R(function(t,e){var r=t.link(i),n=t.shared;return e.set(n.framebuffer,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\".width\"),e.set(n,\".framebufferHeight\",r+\".height\"),r})):R(function(t,e){var r=t.shared;return e.set(r.framebuffer,\".next\",\"null\"),r=r.context,e.set(r,\".framebufferWidth\",r+\".drawingBufferWidth\"),e.set(r,\".framebufferHeight\",r+\".drawingBufferHeight\"),\"null\"})}if(\"framebuffer\"in n){var a=n.framebuffer;return F(a,function(t,e){var r=t.invoke(e,a),n=t.shared,i=n.framebuffer;r=e.def(i,\".getFramebuffer(\",r,\")\");return e.set(i,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\"?\"+r+\".width:\"+n+\".drawingBufferWidth\"),e.set(n,\".framebufferHeight\",r+\"?\"+r+\".height:\"+n+\".drawingBufferHeight\"),r})}return null}function w(t){function r(t){if(t in n){var r=e.id(n[t]);return(t=R(function(){return r})).id=r,t}if(t in i){var a=i[t];return F(a,function(t,e){var r=t.invoke(e,a);return e.def(t.shared.strings,\".id(\",r,\")\")})}return null}var n=t.static,i=t.dynamic,a=r(\"frag\"),o=r(\"vert\"),s=null;return D(a)&&D(o)?(s=h.program(o.id,a.id),t=R(function(t,e){return t.link(s)})):t=new I(a&&a.thisDep||o&&o.thisDep,a&&a.contextDep||o&&o.contextDep,a&&a.propDep||o&&o.propDep,function(t,e){var r,n,i=t.shared.shader;return r=a?a.append(t,e):e.def(i,\".\",\"frag\"),n=o?o.append(t,e):e.def(i,\".\",\"vert\"),e.def(i+\".program(\"+n+\",\"+r+\")\")}),{frag:a,vert:o,progVar:t,program:s}}function k(t,e){function r(t,e){if(t in n){var r=0|n[t];return R(function(t,n){return e&&(t.OFFSET=r),r})}if(t in i){var o=i[t];return F(o,function(t,r){var n=t.invoke(r,o);return e&&(t.OFFSET=n),n})}return e&&a?R(function(t,e){return t.OFFSET=\"0\",0}):null}var n=t.static,i=t.dynamic,a=function(){if(\"elements\"in n){var t=n.elements;O(t)?t=o.getElements(o.create(t,!0)):t&&(t=o.getElements(t));var e=R(function(e,r){if(t){var n=e.link(t);return e.ELEMENTS=n}return e.ELEMENTS=null});return e.value=t,e}if(\"elements\"in i){var r=i.elements;return F(r,function(t,e){var n=(i=t.shared).isBufferArgs,i=i.elements,a=t.invoke(e,r),o=e.def(\"null\");n=e.def(n,\"(\",a,\")\"),a=t.cond(n).then(o,\"=\",i,\".createStream(\",a,\");\").else(o,\"=\",i,\".getElements(\",a,\");\");return e.entry(a),e.exit(t.cond(n).then(i,\".destroyStream(\",o,\");\")),t.ELEMENTS=o})}return null}(),s=r(\"offset\",!0);return{elements:a,primitive:function(){if(\"primitive\"in n){var t=n.primitive;return R(function(e,r){return rt[t]})}if(\"primitive\"in i){var e=i.primitive;return F(e,function(t,r){var n=t.constants.primTypes,i=t.invoke(r,e);return r.def(n,\"[\",i,\"]\")})}return a?D(a)?a.value?R(function(t,e){return e.def(t.ELEMENTS,\".primType\")}):R(function(){return 4}):new I(a.thisDep,a.contextDep,a.propDep,function(t,e){var r=t.ELEMENTS;return e.def(r,\"?\",r,\".primType:\",4)}):null}(),count:function(){if(\"count\"in n){var t=0|n.count;return R(function(){return t})}if(\"count\"in i){var e=i.count;return F(e,function(t,r){return t.invoke(r,e)})}return a?D(a)?a?s?new I(s.thisDep,s.contextDep,s.propDep,function(t,e){return e.def(t.ELEMENTS,\".vertCount-\",t.OFFSET)}):R(function(t,e){return e.def(t.ELEMENTS,\".vertCount\")}):R(function(){return-1}):new I(a.thisDep||s.thisDep,a.contextDep||s.contextDep,a.propDep||s.propDep,function(t,e){var r=t.ELEMENTS;return t.OFFSET?e.def(r,\"?\",r,\".vertCount-\",t.OFFSET,\":-1\"):e.def(r,\"?\",r,\".vertCount:-1\")}):null}(),instances:r(\"instances\",!1),offset:s}}function T(t,r){var n=t.static,a=t.dynamic,o={};return Object.keys(n).forEach(function(t){var r=n[t],a=e.id(t),s=new Z;if(O(r))s.state=1,s.buffer=i.getBuffer(i.create(r,34962,!1,!0)),s.type=0;else if(c=i.getBuffer(r))s.state=1,s.buffer=c,s.type=0;else if(\"constant\"in r){var l=r.constant;s.buffer=\"null\",s.state=2,\"number\"==typeof l?s.x=l:bt.forEach(function(t,e){e<l.length&&(s[t]=l[e])})}else{var c=O(r.buffer)?i.getBuffer(i.create(r.buffer,34962,!1,!0)):i.getBuffer(r.buffer),u=0|r.offset,h=0|r.stride,f=0|r.size,p=!!r.normalized,d=0;\"type\"in r&&(d=K[r.type]),r=0|r.divisor,s.buffer=c,s.state=1,s.size=f,s.normalized=p,s.type=d||c.dtype,s.offset=u,s.stride=h,s.divisor=r}o[t]=R(function(t,e){var r=t.attribCache;if(a in r)return r[a];var n={isStream:!1};return Object.keys(s).forEach(function(t){n[t]=s[t]}),s.buffer&&(n.buffer=t.link(s.buffer),n.type=n.type||n.buffer+\".dtype\"),r[a]=n})}),Object.keys(a).forEach(function(t){var e=a[t];o[t]=F(e,function(t,r){function n(t){r(l[t],\"=\",i,\".\",t,\"|0;\")}var i=t.invoke(r,e),a=t.shared,o=a.isBufferArgs,s=a.buffer,l={isStream:r.def(!1)},c=new Z;c.state=1,Object.keys(c).forEach(function(t){l[t]=r.def(\"\"+c[t])});var u=l.buffer,h=l.type;return r(\"if(\",o,\"(\",i,\")){\",l.isStream,\"=true;\",u,\"=\",s,\".createStream(\",34962,\",\",i,\");\",h,\"=\",u,\".dtype;\",\"}else{\",u,\"=\",s,\".getBuffer(\",i,\");\",\"if(\",u,\"){\",h,\"=\",u,\".dtype;\",'}else if(\"constant\" in ',i,\"){\",l.state,\"=\",2,\";\",\"if(typeof \"+i+'.constant === \"number\"){',l[bt[0]],\"=\",i,\".constant;\",bt.slice(1).map(function(t){return l[t]}).join(\"=\"),\"=0;\",\"}else{\",bt.map(function(t,e){return l[t]+\"=\"+i+\".constant.length>\"+e+\"?\"+i+\".constant[\"+e+\"]:0;\"}).join(\"\"),\"}}else{\",\"if(\",o,\"(\",i,\".buffer)){\",u,\"=\",s,\".createStream(\",34962,\",\",i,\".buffer);\",\"}else{\",u,\"=\",s,\".getBuffer(\",i,\".buffer);\",\"}\",h,'=\"type\" in ',i,\"?\",a.glTypes,\"[\",i,\".type]:\",u,\".dtype;\",l.normalized,\"=!!\",i,\".normalized;\"),n(\"size\"),n(\"offset\"),n(\"stride\"),n(\"divisor\"),r(\"}}\"),r.exit(\"if(\",l.isStream,\"){\",s,\".destroyStream(\",u,\");\",\"}\"),l})}),o}function A(t,e,r,n,i){var o=_(t),s=function(t,e,r){function n(t){if(t in i){var r=i[t];t=!0;var n,o,s=0|r.x,l=0|r.y;return\"width\"in r?n=0|r.width:t=!1,\"height\"in r?o=0|r.height:t=!1,new I(!t&&e&&e.thisDep,!t&&e&&e.contextDep,!t&&e&&e.propDep,function(t,e){var i=t.shared.context,a=n;\"width\"in r||(a=e.def(i,\".\",\"framebufferWidth\",\"-\",s));var c=o;return\"height\"in r||(c=e.def(i,\".\",\"framebufferHeight\",\"-\",l)),[s,l,a,c]})}if(t in a){var c=a[t];return t=F(c,function(t,e){var r=t.invoke(e,c),n=t.shared.context,i=e.def(r,\".x|0\"),a=e.def(r,\".y|0\");return[i,a,e.def('\"width\" in ',r,\"?\",r,\".width|0:\",\"(\",n,\".\",\"framebufferWidth\",\"-\",i,\")\"),r=e.def('\"height\" in ',r,\"?\",r,\".height|0:\",\"(\",n,\".\",\"framebufferHeight\",\"-\",a,\")\")]}),e&&(t.thisDep=t.thisDep||e.thisDep,t.contextDep=t.contextDep||e.contextDep,t.propDep=t.propDep||e.propDep),t}return e?new I(e.thisDep,e.contextDep,e.propDep,function(t,e){var r=t.shared.context;return[0,0,e.def(r,\".\",\"framebufferWidth\"),e.def(r,\".\",\"framebufferHeight\")]}):null}var i=t.static,a=t.dynamic;if(t=n(\"viewport\")){var o=t;t=new I(t.thisDep,t.contextDep,t.propDep,function(t,e){var r=o.append(t,e),n=t.shared.context;return e.set(n,\".viewportWidth\",r[2]),e.set(n,\".viewportHeight\",r[3]),r})}return{viewport:t,scissor_box:n(\"scissor.box\")}}(t,o),l=k(t),c=function(t,e){var r=t.static,n=t.dynamic,i={};return nt.forEach(function(t){function e(e,a){if(t in r){var s=e(r[t]);i[o]=R(function(){return s})}else if(t in n){var l=n[t];i[o]=F(l,function(t,e){return a(t,e,t.invoke(e,l))})}}var o=m(t);switch(t){case\"cull.enable\":case\"blend.enable\":case\"dither\":case\"stencil.enable\":case\"depth.enable\":case\"scissor.enable\":case\"polygonOffset.enable\":case\"sample.alpha\":case\"sample.enable\":case\"depth.mask\":return e(function(t){return t},function(t,e,r){return r});case\"depth.func\":return e(function(t){return kt[t]},function(t,e,r){return e.def(t.constants.compareFuncs,\"[\",r,\"]\")});case\"depth.range\":return e(function(t){return t},function(t,e,r){return[e.def(\"+\",r,\"[0]\"),e=e.def(\"+\",r,\"[1]\")]});case\"blend.func\":return e(function(t){return[wt[\"srcRGB\"in t?t.srcRGB:t.src],wt[\"dstRGB\"in t?t.dstRGB:t.dst],wt[\"srcAlpha\"in t?t.srcAlpha:t.src],wt[\"dstAlpha\"in t?t.dstAlpha:t.dst]]},function(t,e,r){function n(t,n){return e.def('\"',t,n,'\" in ',r,\"?\",r,\".\",t,n,\":\",r,\".\",t)}t=t.constants.blendFuncs;var i=n(\"src\",\"RGB\"),a=n(\"dst\",\"RGB\"),o=(i=e.def(t,\"[\",i,\"]\"),e.def(t,\"[\",n(\"src\",\"Alpha\"),\"]\"));return[i,a=e.def(t,\"[\",a,\"]\"),o,t=e.def(t,\"[\",n(\"dst\",\"Alpha\"),\"]\")]});case\"blend.equation\":return e(function(t){return\"string\"==typeof t?[J[t],J[t]]:\"object\"==typeof t?[J[t.rgb],J[t.alpha]]:void 0},function(t,e,r){var n=t.constants.blendEquations,i=e.def(),a=e.def();return(t=t.cond(\"typeof \",r,'===\"string\"')).then(i,\"=\",a,\"=\",n,\"[\",r,\"];\"),t.else(i,\"=\",n,\"[\",r,\".rgb];\",a,\"=\",n,\"[\",r,\".alpha];\"),e(t),[i,a]});case\"blend.color\":return e(function(t){return a(4,function(e){return+t[e]})},function(t,e,r){return a(4,function(t){return e.def(\"+\",r,\"[\",t,\"]\")})});case\"stencil.mask\":return e(function(t){return 0|t},function(t,e,r){return e.def(r,\"|0\")});case\"stencil.func\":return e(function(t){return[kt[t.cmp||\"keep\"],t.ref||0,\"mask\"in t?t.mask:-1]},function(t,e,r){return[t=e.def('\"cmp\" in ',r,\"?\",t.constants.compareFuncs,\"[\",r,\".cmp]\",\":\",7680),e.def(r,\".ref|0\"),e=e.def('\"mask\" in ',r,\"?\",r,\".mask|0:-1\")]});case\"stencil.opFront\":case\"stencil.opBack\":return e(function(e){return[\"stencil.opBack\"===t?1029:1028,Tt[e.fail||\"keep\"],Tt[e.zfail||\"keep\"],Tt[e.zpass||\"keep\"]]},function(e,r,n){function i(t){return r.def('\"',t,'\" in ',n,\"?\",a,\"[\",n,\".\",t,\"]:\",7680)}var a=e.constants.stencilOps;return[\"stencil.opBack\"===t?1029:1028,i(\"fail\"),i(\"zfail\"),i(\"zpass\")]});case\"polygonOffset.offset\":return e(function(t){return[0|t.factor,0|t.units]},function(t,e,r){return[e.def(r,\".factor|0\"),e=e.def(r,\".units|0\")]});case\"cull.face\":return e(function(t){var e=0;return\"front\"===t?e=1028:\"back\"===t&&(e=1029),e},function(t,e,r){return e.def(r,'===\"front\"?',1028,\":\",1029)});case\"lineWidth\":return e(function(t){return t},function(t,e,r){return r});case\"frontFace\":return e(function(t){return At[t]},function(t,e,r){return e.def(r+'===\"cw\"?2304:2305')});case\"colorMask\":return e(function(t){return t.map(function(t){return!!t})},function(t,e,r){return a(4,function(t){return\"!!\"+r+\"[\"+t+\"]\"})});case\"sample.coverage\":return e(function(t){return[\"value\"in t?t.value:1,!!t.invert]},function(t,e,r){return[e.def('\"value\" in ',r,\"?+\",r,\".value:1\"),e=e.def(\"!!\",r,\".invert\")]})}}),i}(t),u=w(t),h=s.viewport;return h&&(c.viewport=h),(s=s[h=m(\"scissor.box\")])&&(c[h]=s),(o={framebuffer:o,draw:l,shader:u,state:c,dirty:s=0<Object.keys(c).length}).profile=function(t){var e,r=t.static;if(t=t.dynamic,\"profile\"in r){var n=!!r.profile;(e=R(function(t,e){return n})).enable=n}else if(\"profile\"in t){var i=t.profile;e=F(i,function(t,e){return t.invoke(e,i)})}return e}(t),o.uniforms=function(t,e){var r=t.static,n=t.dynamic,i={};return Object.keys(r).forEach(function(t){var e,n=r[t];if(\"number\"==typeof n||\"boolean\"==typeof n)e=R(function(){return n});else if(\"function\"==typeof n){var o=n._reglType;\"texture2d\"===o||\"textureCube\"===o?e=R(function(t){return t.link(n)}):\"framebuffer\"!==o&&\"framebufferCube\"!==o||(e=R(function(t){return t.link(n.color[0])}))}else v(n)&&(e=R(function(t){return t.global.def(\"[\",a(n.length,function(t){return n[t]}),\"]\")}));e.value=n,i[t]=e}),Object.keys(n).forEach(function(t){var e=n[t];i[t]=F(e,function(t,r){return t.invoke(r,e)})}),i}(r),o.attributes=T(e),o.context=function(t){var e=t.static,r=t.dynamic,n={};return Object.keys(e).forEach(function(t){var r=e[t];n[t]=R(function(t,e){return\"number\"==typeof r||\"boolean\"==typeof r?\"\"+r:t.link(r)})}),Object.keys(r).forEach(function(t){var e=r[t];n[t]=F(e,function(t,r){return t.invoke(r,e)})}),n}(n),o}function M(t,e,r){var n=t.shared.context,i=t.scope();Object.keys(r).forEach(function(a){e.save(n,\".\"+a),i(n,\".\",a,\"=\",r[a].append(t,e),\";\")}),e(i)}function S(t,e,r,n){var i,a=(s=t.shared).gl,o=s.framebuffer;Q&&(i=e.def(s.extensions,\".webgl_draw_buffers\"));var s=(l=t.constants).drawBuffer,l=l.backBuffer;t=r?r.append(t,e):e.def(o,\".next\"),n||e(\"if(\",t,\"!==\",o,\".cur){\"),e(\"if(\",t,\"){\",a,\".bindFramebuffer(\",36160,\",\",t,\".framebuffer);\"),Q&&e(i,\".drawBuffersWEBGL(\",s,\"[\",t,\".colorAttachments.length]);\"),e(\"}else{\",a,\".bindFramebuffer(\",36160,\",null);\"),Q&&e(i,\".drawBuffersWEBGL(\",l,\");\"),e(\"}\",o,\".cur=\",t,\";\"),n||e(\"}\")}function E(t,e,r){var n=t.shared,i=n.gl,o=t.current,s=t.next,l=n.current,c=n.next,u=t.cond(l,\".dirty\");nt.forEach(function(e){var n,h;if(!((e=m(e))in r.state))if(e in s){n=s[e],h=o[e];var f=a(tt[e].length,function(t){return u.def(n,\"[\",t,\"]\")});u(t.cond(f.map(function(t,e){return t+\"!==\"+h+\"[\"+e+\"]\"}).join(\"||\")).then(i,\".\",at[e],\"(\",f,\");\",f.map(function(t,e){return h+\"[\"+e+\"]=\"+t}).join(\";\"),\";\"))}else n=u.def(c,\".\",e),f=t.cond(n,\"!==\",l,\".\",e),u(f),e in it?f(t.cond(n).then(i,\".enable(\",it[e],\");\").else(i,\".disable(\",it[e],\");\"),l,\".\",e,\"=\",n,\";\"):f(i,\".\",at[e],\"(\",n,\");\",l,\".\",e,\"=\",n,\";\")}),0===Object.keys(r.state).length&&u(l,\".dirty=false;\"),e(u)}function C(t,e,r,n){var i=t.shared,a=t.current,o=i.current,s=i.gl;z(Object.keys(r)).forEach(function(i){var l=r[i];if(!n||n(l)){var c=l.append(t,e);if(it[i]){var u=it[i];D(l)?e(s,c?\".enable(\":\".disable(\",u,\");\"):e(t.cond(c).then(s,\".enable(\",u,\");\").else(s,\".disable(\",u,\");\")),e(o,\".\",i,\"=\",c,\";\")}else if(v(c)){var h=a[i];e(s,\".\",at[i],\"(\",c,\");\",c.map(function(t,e){return h+\"[\"+e+\"]=\"+t}).join(\";\"),\";\")}else e(s,\".\",at[i],\"(\",c,\");\",o,\".\",i,\"=\",c,\";\")}})}function L(t,e){$&&(t.instancing=e.def(t.shared.extensions,\".angle_instanced_arrays\"))}function B(t,e,r,n,i){function a(){return\"undefined\"==typeof performance?\"Date.now()\":\"performance.now()\"}function o(t){t(c=e.def(),\"=\",a(),\";\"),\"string\"==typeof i?t(f,\".count+=\",i,\";\"):t(f,\".count++;\"),d&&(n?t(u=e.def(),\"=\",g,\".getNumPendingQueries();\"):t(g,\".beginQuery(\",f,\");\"))}function s(t){t(f,\".cpuTime+=\",a(),\"-\",c,\";\"),d&&(n?t(g,\".pushScopeStats(\",u,\",\",g,\".getNumPendingQueries(),\",f,\");\"):t(g,\".endQuery();\"))}function l(t){var r=e.def(p,\".profile\");e(p,\".profile=\",t,\";\"),e.exit(p,\".profile=\",r,\";\")}var c,u,h=t.shared,f=t.stats,p=h.current,g=h.timer;if(r=r.profile){if(D(r))return void(r.enable?(o(e),s(e.exit),l(\"true\")):l(\"false\"));l(r=r.append(t,e))}else r=e.def(p,\".profile\");o(h=t.block()),e(\"if(\",r,\"){\",h,\"}\"),s(t=t.block()),e.exit(\"if(\",r,\"){\",t,\"}\")}function N(t,e,r,n,i){function a(r,n,i){function a(){e(\"if(!\",u,\".buffer){\",l,\".enableVertexAttribArray(\",c,\");}\");var r,a=i.type;r=i.size?e.def(i.size,\"||\",n):n,e(\"if(\",u,\".type!==\",a,\"||\",u,\".size!==\",r,\"||\",p.map(function(t){return u+\".\"+t+\"!==\"+i[t]}).join(\"||\"),\"){\",l,\".bindBuffer(\",34962,\",\",h,\".buffer);\",l,\".vertexAttribPointer(\",[c,r,a,i.normalized,i.stride,i.offset],\");\",u,\".type=\",a,\";\",u,\".size=\",r,\";\",p.map(function(t){return u+\".\"+t+\"=\"+i[t]+\";\"}).join(\"\"),\"}\"),$&&(a=i.divisor,e(\"if(\",u,\".divisor!==\",a,\"){\",t.instancing,\".vertexAttribDivisorANGLE(\",[c,a],\");\",u,\".divisor=\",a,\";}\"))}function s(){e(\"if(\",u,\".buffer){\",l,\".disableVertexAttribArray(\",c,\");\",\"}if(\",bt.map(function(t,e){return u+\".\"+t+\"!==\"+f[e]}).join(\"||\"),\"){\",l,\".vertexAttrib4f(\",c,\",\",f,\");\",bt.map(function(t,e){return u+\".\"+t+\"=\"+f[e]+\";\"}).join(\"\"),\"}\")}var l=o.gl,c=e.def(r,\".location\"),u=e.def(o.attributes,\"[\",c,\"]\");r=i.state;var h=i.buffer,f=[i.x,i.y,i.z,i.w],p=[\"buffer\",\"normalized\",\"offset\",\"stride\"];1===r?a():2===r?s():(e(\"if(\",r,\"===\",1,\"){\"),a(),e(\"}else{\"),s(),e(\"}\"))}var o=t.shared;n.forEach(function(n){var o,s=n.name,l=r.attributes[s];if(l){if(!i(l))return;o=l.append(t,e)}else{if(!i(Mt))return;var c=t.scopeAttrib(s);o={},Object.keys(new Z).forEach(function(t){o[t]=e.def(c,\".\",t)})}a(t.link(n),function(t){switch(t){case 35664:case 35667:case 35671:return 2;case 35665:case 35668:case 35672:return 3;case 35666:case 35669:case 35673:return 4;default:return 1}}(n.info.type),o)})}function j(t,r,n,i,o){for(var s,l=t.shared,c=l.gl,u=0;u<i.length;++u){var h,f=(g=i[u]).name,p=g.info.type,d=n.uniforms[f],g=t.link(g)+\".location\";if(d){if(!o(d))continue;if(D(d)){if(f=d.value,35678===p||35680===p)r(c,\".uniform1i(\",g,\",\",(p=t.link(f._texture||f.color[0]._texture))+\".bind());\"),r.exit(p,\".unbind();\");else if(35674===p||35675===p||35676===p)d=2,35675===p?d=3:35676===p&&(d=4),r(c,\".uniformMatrix\",d,\"fv(\",g,\",false,\",f=t.global.def(\"new Float32Array([\"+Array.prototype.slice.call(f)+\"])\"),\");\");else{switch(p){case 5126:s=\"1f\";break;case 35664:s=\"2f\";break;case 35665:s=\"3f\";break;case 35666:s=\"4f\";break;case 35670:case 5124:s=\"1i\";break;case 35671:case 35667:s=\"2i\";break;case 35672:case 35668:s=\"3i\";break;case 35673:s=\"4i\";break;case 35669:s=\"4i\"}r(c,\".uniform\",s,\"(\",g,\",\",v(f)?Array.prototype.slice.call(f):f,\");\")}continue}h=d.append(t,r)}else{if(!o(Mt))continue;h=r.def(l.uniforms,\"[\",e.id(f),\"]\")}switch(35678===p?r(\"if(\",h,\"&&\",h,'._reglType===\"framebuffer\"){',h,\"=\",h,\".color[0];\",\"}\"):35680===p&&r(\"if(\",h,\"&&\",h,'._reglType===\"framebufferCube\"){',h,\"=\",h,\".color[0];\",\"}\"),f=1,p){case 35678:case 35680:p=r.def(h,\"._texture\"),r(c,\".uniform1i(\",g,\",\",p,\".bind());\"),r.exit(p,\".unbind();\");continue;case 5124:case 35670:s=\"1i\";break;case 35667:case 35671:s=\"2i\",f=2;break;case 35668:case 35672:s=\"3i\",f=3;break;case 35669:case 35673:s=\"4i\",f=4;break;case 5126:s=\"1f\";break;case 35664:s=\"2f\",f=2;break;case 35665:s=\"3f\",f=3;break;case 35666:s=\"4f\",f=4;break;case 35674:s=\"Matrix2fv\";break;case 35675:s=\"Matrix3fv\";break;case 35676:s=\"Matrix4fv\"}if(r(c,\".uniform\",s,\"(\",g,\",\"),\"M\"===s.charAt(0)){g=Math.pow(p-35674+2,2);var m=t.global.def(\"new Float32Array(\",g,\")\");r(\"false,(Array.isArray(\",h,\")||\",h,\" instanceof Float32Array)?\",h,\":(\",a(g,function(t){return m+\"[\"+t+\"]=\"+h+\"[\"+t+\"]\"}),\",\",m,\")\")}else r(1<f?a(f,function(t){return h+\"[\"+t+\"]\"}):h);r(\");\")}}function U(t,e,r,n){function i(i){var a=f[i];return a?a.contextDep&&n.contextDynamic||a.propDep?a.append(t,r):a.append(t,e):e.def(h,\".\",i)}function a(){function t(){r(l,\".drawElementsInstancedANGLE(\",[d,v,m,g+\"<<((\"+m+\"-5121)>>1)\",s],\");\")}function e(){r(l,\".drawArraysInstancedANGLE(\",[d,g,v,s],\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}function o(){function t(){r(u+\".drawElements(\"+[d,v,m,g+\"<<((\"+m+\"-5121)>>1)\"]+\");\")}function e(){r(u+\".drawArrays(\"+[d,g,v]+\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}var s,l,c=t.shared,u=c.gl,h=c.draw,f=n.draw,p=function(){var i=f.elements,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(h,\".\",\"elements\"),i&&a(\"if(\"+i+\")\"+u+\".bindBuffer(34963,\"+i+\".buffer.buffer);\"),i}(),d=i(\"primitive\"),g=i(\"offset\"),v=function(){var i=f.count,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(h,\".\",\"count\"),i}();if(\"number\"==typeof v){if(0===v)return}else r(\"if(\",v,\"){\"),r.exit(\"}\");$&&(s=i(\"instances\"),l=t.instancing);var m=p+\".type\",y=f.elements&&D(f.elements);$&&(\"number\"!=typeof s||0<=s)?\"string\"==typeof s?(r(\"if(\",s,\">0){\"),a(),r(\"}else if(\",s,\"<0){\"),o(),r(\"}\")):a():o()}function q(t,e,r,n,i){return i=(e=b()).proc(\"body\",i),$&&(e.instancing=i.def(e.shared.extensions,\".angle_instanced_arrays\")),t(e,i,r,n),e.compile().body}function H(t,e,r,n){L(t,e),N(t,e,r,n.attributes,function(){return!0}),j(t,e,r,n.uniforms,function(){return!0}),U(t,e,e,r)}function G(t,e,r,n){function i(){return!0}t.batchId=\"a1\",L(t,e),N(t,e,r,n.attributes,i),j(t,e,r,n.uniforms,i),U(t,e,e,r)}function Y(t,e,r,n){function i(t){return t.contextDep&&o||t.propDep}function a(t){return!i(t)}L(t,e);var o=r.contextDep,s=e.def(),l=e.def();t.shared.props=l,t.batchId=s;var c=t.scope(),u=t.scope();e(c.entry,\"for(\",s,\"=0;\",s,\"<\",\"a1\",\";++\",s,\"){\",l,\"=\",\"a0\",\"[\",s,\"];\",u,\"}\",c.exit),r.needsContext&&M(t,u,r.context),r.needsFramebuffer&&S(t,u,r.framebuffer),C(t,u,r.state,i),r.profile&&i(r.profile)&&B(t,u,r,!1,!0),n?(N(t,c,r,n.attributes,a),N(t,u,r,n.attributes,i),j(t,c,r,n.uniforms,a),j(t,u,r,n.uniforms,i),U(t,c,u,r)):(e=t.global.def(\"{}\"),n=r.shader.progVar.append(t,u),l=u.def(n,\".id\"),c=u.def(e,\"[\",l,\"]\"),u(t.shared.gl,\".useProgram(\",n,\".program);\",\"if(!\",c,\"){\",c,\"=\",e,\"[\",l,\"]=\",t.link(function(e){return q(G,t,r,e,2)}),\"(\",n,\");}\",c,\".call(this,a0[\",s,\"],\",s,\");\"))}function W(t,r){function n(e){var n=r.shader[e];n&&i.set(a.shader,\".\"+e,n.append(t,i))}var i=t.proc(\"scope\",3);t.batchId=\"a2\";var a=t.shared,o=a.current;M(t,i,r.context),r.framebuffer&&r.framebuffer.append(t,i),z(Object.keys(r.state)).forEach(function(e){var n=r.state[e].append(t,i);v(n)?n.forEach(function(r,n){i.set(t.next[e],\"[\"+n+\"]\",r)}):i.set(a.next,\".\"+e,n)}),B(t,i,r,!0,!0),[\"elements\",\"offset\",\"count\",\"instances\",\"primitive\"].forEach(function(e){var n=r.draw[e];n&&i.set(a.draw,\".\"+e,\"\"+n.append(t,i))}),Object.keys(r.uniforms).forEach(function(n){i.set(a.uniforms,\"[\"+e.id(n)+\"]\",r.uniforms[n].append(t,i))}),Object.keys(r.attributes).forEach(function(e){var n=r.attributes[e].append(t,i),a=t.scopeAttrib(e);Object.keys(new Z).forEach(function(t){i.set(a,\".\"+t,n[t])})}),n(\"vert\"),n(\"frag\"),0<Object.keys(r.state).length&&(i(o,\".dirty=true;\"),i.exit(o,\".dirty=true;\")),i(\"a1(\",t.shared.context,\",a0,\",t.batchId,\");\")}function X(t,e,r){var n=e.static[r];if(n&&function(t){if(\"object\"==typeof t&&!v(t)){for(var e=Object.keys(t),r=0;r<e.length;++r)if(V.isDynamic(t[e[r]]))return!0;return!1}}(n)){var i=t.global,a=Object.keys(n),o=!1,s=!1,l=!1,c=t.global.def(\"{}\");a.forEach(function(e){var r=n[e];if(V.isDynamic(r))\"function\"==typeof r&&(r=n[e]=V.unbox(r)),e=F(r,null),o=o||e.thisDep,l=l||e.propDep,s=s||e.contextDep;else{switch(i(c,\".\",e,\"=\"),typeof r){case\"number\":i(r);break;case\"string\":i('\"',r,'\"');break;case\"object\":Array.isArray(r)&&i(\"[\",r.join(),\"]\");break;default:i(t.link(r))}i(\";\")}}),e.dynamic[r]=new V.DynamicVariable(4,{thisDep:o,contextDep:s,propDep:l,ref:c,append:function(t,e){a.forEach(function(r){var i=n[r];V.isDynamic(i)&&(i=t.invoke(e,i),e(c,\".\",r,\"=\",i,\";\"))})}}),delete e.static[r]}}var Z=u.Record,J={add:32774,subtract:32778,\"reverse subtract\":32779};r.ext_blend_minmax&&(J.min=32775,J.max=32776);var $=r.angle_instanced_arrays,Q=r.webgl_draw_buffers,tt={dirty:!0,profile:g.profile},et={},nt=[],it={},at={};y(\"dither\",3024),y(\"blend.enable\",3042),x(\"blend.color\",\"blendColor\",[0,0,0,0]),x(\"blend.equation\",\"blendEquationSeparate\",[32774,32774]),x(\"blend.func\",\"blendFuncSeparate\",[1,0,1,0]),y(\"depth.enable\",2929,!0),x(\"depth.func\",\"depthFunc\",513),x(\"depth.range\",\"depthRange\",[0,1]),x(\"depth.mask\",\"depthMask\",!0),x(\"colorMask\",\"colorMask\",[!0,!0,!0,!0]),y(\"cull.enable\",2884),x(\"cull.face\",\"cullFace\",1029),x(\"frontFace\",\"frontFace\",2305),x(\"lineWidth\",\"lineWidth\",1),y(\"polygonOffset.enable\",32823),x(\"polygonOffset.offset\",\"polygonOffset\",[0,0]),y(\"sample.alpha\",32926),y(\"sample.enable\",32928),x(\"sample.coverage\",\"sampleCoverage\",[1,!1]),y(\"stencil.enable\",2960),x(\"stencil.mask\",\"stencilMask\",-1),x(\"stencil.func\",\"stencilFunc\",[519,0,-1]),x(\"stencil.opFront\",\"stencilOpSeparate\",[1028,7680,7680,7680]),x(\"stencil.opBack\",\"stencilOpSeparate\",[1029,7680,7680,7680]),y(\"scissor.enable\",3089),x(\"scissor.box\",\"scissor\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]),x(\"viewport\",\"viewport\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]);var ot={gl:t,context:p,strings:e,next:et,current:tt,draw:f,elements:o,buffer:i,shader:h,attributes:u.state,uniforms:c,framebuffer:l,extensions:r,timer:d,isBufferArgs:O},st={primTypes:rt,compareFuncs:kt,blendFuncs:wt,blendEquations:J,stencilOps:Tt,glTypes:K,orientationType:At};Q&&(st.backBuffer=[1029],st.drawBuffer=a(n.maxDrawbuffers,function(t){return 0===t?[0]:a(t,function(t){return 36064+t})}));var lt=0;return{next:et,current:tt,procs:function(){var t=b(),e=t.proc(\"poll\"),r=t.proc(\"refresh\"),i=t.block();e(i),r(i);var o,s=t.shared,l=s.gl,c=s.next,u=s.current;i(u,\".dirty=false;\"),S(t,e),S(t,r,null,!0),$&&(o=t.link($));for(var h=0;h<n.maxAttributes;++h){var f=r.def(s.attributes,\"[\",h,\"]\"),p=t.cond(f,\".buffer\");p.then(l,\".enableVertexAttribArray(\",h,\");\",l,\".bindBuffer(\",34962,\",\",f,\".buffer.buffer);\",l,\".vertexAttribPointer(\",h,\",\",f,\".size,\",f,\".type,\",f,\".normalized,\",f,\".stride,\",f,\".offset);\").else(l,\".disableVertexAttribArray(\",h,\");\",l,\".vertexAttrib4f(\",h,\",\",f,\".x,\",f,\".y,\",f,\".z,\",f,\".w);\",f,\".buffer=null;\"),r(p),$&&r(o,\".vertexAttribDivisorANGLE(\",h,\",\",f,\".divisor);\")}return Object.keys(it).forEach(function(n){var a=it[n],o=i.def(c,\".\",n),s=t.block();s(\"if(\",o,\"){\",l,\".enable(\",a,\")}else{\",l,\".disable(\",a,\")}\",u,\".\",n,\"=\",o,\";\"),r(s),e(\"if(\",o,\"!==\",u,\".\",n,\"){\",s,\"}\")}),Object.keys(at).forEach(function(n){var o,s,h=at[n],f=tt[n],p=t.block();p(l,\".\",h,\"(\"),v(f)?(h=f.length,o=t.global.def(c,\".\",n),s=t.global.def(u,\".\",n),p(a(h,function(t){return o+\"[\"+t+\"]\"}),\");\",a(h,function(t){return s+\"[\"+t+\"]=\"+o+\"[\"+t+\"];\"}).join(\"\")),e(\"if(\",a(h,function(t){return o+\"[\"+t+\"]!==\"+s+\"[\"+t+\"]\"}).join(\"||\"),\"){\",p,\"}\")):(o=i.def(c,\".\",n),s=i.def(u,\".\",n),p(o,\");\",u,\".\",n,\"=\",o,\";\"),e(\"if(\",o,\"!==\",s,\"){\",p,\"}\")),r(p)}),t.compile()}(),compile:function(t,e,r,n,i){var a=b();return a.stats=a.link(i),Object.keys(e.static).forEach(function(t){X(a,e,t)}),_t.forEach(function(e){X(a,t,e)}),r=A(t,e,r,n),function(t,e){var r=t.proc(\"draw\",1);L(t,r),M(t,r,e.context),S(t,r,e.framebuffer),E(t,r,e),C(t,r,e.state),B(t,r,e,!1,!0);var n=e.shader.progVar.append(t,r);if(r(t.shared.gl,\".useProgram(\",n,\".program);\"),e.shader.program)H(t,r,e,e.shader.program);else{var i=t.global.def(\"{}\"),a=r.def(n,\".id\"),o=r.def(i,\"[\",a,\"]\");r(t.cond(o).then(o,\".call(this,a0);\").else(o,\"=\",i,\"[\",a,\"]=\",t.link(function(r){return q(H,t,e,r,1)}),\"(\",n,\");\",o,\".call(this,a0);\"))}0<Object.keys(e.state).length&&r(t.shared.current,\".dirty=true;\")}(a,r),W(a,r),function(t,e){function r(t){return t.contextDep&&i||t.propDep}var n=t.proc(\"batch\",2);t.batchId=\"0\",L(t,n);var i=!1,a=!0;Object.keys(e.context).forEach(function(t){i=i||e.context[t].propDep}),i||(M(t,n,e.context),a=!1);var o=!1;if((s=e.framebuffer)?(s.propDep?i=o=!0:s.contextDep&&i&&(o=!0),o||S(t,n,s)):S(t,n,null),e.state.viewport&&e.state.viewport.propDep&&(i=!0),E(t,n,e),C(t,n,e.state,function(t){return!r(t)}),e.profile&&r(e.profile)||B(t,n,e,!1,\"a1\"),e.contextDep=i,e.needsContext=a,e.needsFramebuffer=o,(a=e.shader.progVar).contextDep&&i||a.propDep)Y(t,n,e,null);else if(a=a.append(t,n),n(t.shared.gl,\".useProgram(\",a,\".program);\"),e.shader.program)Y(t,n,e,e.shader.program);else{var s=t.global.def(\"{}\"),l=(o=n.def(a,\".id\"),n.def(s,\"[\",o,\"]\"));n(t.cond(l).then(l,\".call(this,a0,a1);\").else(l,\"=\",s,\"[\",o,\"]=\",t.link(function(r){return q(Y,t,e,r,2)}),\"(\",a,\");\",l,\".call(this,a0,a1);\"))}0<Object.keys(e.state).length&&n(t.shared.current,\".dirty=true;\")}(a,r),a.compile()}}}function N(t,e){for(var r=0;r<t.length;++r)if(t[r]===e)return r;return-1}var j=function(t,e){for(var r=Object.keys(e),n=0;n<r.length;++n)t[r[n]]=e[r[n]];return t},U=0,V={DynamicVariable:t,define:function(r,n){return new t(r,e(n+\"\"))},isDynamic:function(e){return\"function\"==typeof e&&!e._reglType||e instanceof t},unbox:function(e,r){return\"function\"==typeof e?new t(0,e):e},accessor:e},q={next:\"function\"==typeof requestAnimationFrame?function(t){return requestAnimationFrame(t)}:function(t){return setTimeout(t,16)},cancel:\"function\"==typeof cancelAnimationFrame?function(t){return cancelAnimationFrame(t)}:clearTimeout},H=\"undefined\"!=typeof performance&&performance.now?function(){return performance.now()}:function(){return+new Date},G=s();G.zero=s();var Y=function(t,e){var r=1;e.ext_texture_filter_anisotropic&&(r=t.getParameter(34047));var n=1,i=1;e.webgl_draw_buffers&&(n=t.getParameter(34852),i=t.getParameter(36063));var a=!!e.oes_texture_float;if(a){a=t.createTexture(),t.bindTexture(3553,a),t.texImage2D(3553,0,6408,1,1,0,6408,5126,null);var o=t.createFramebuffer();if(t.bindFramebuffer(36160,o),t.framebufferTexture2D(36160,36064,3553,a,0),t.bindTexture(3553,null),36053!==t.checkFramebufferStatus(36160))a=!1;else{t.viewport(0,0,1,1),t.clearColor(1,0,0,1),t.clear(16384);var s=G.allocType(5126,4);t.readPixels(0,0,1,1,6408,5126,s),t.getError()?a=!1:(t.deleteFramebuffer(o),t.deleteTexture(a),a=1===s[0]),G.freeType(s)}}return s=!0,\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion)||/Edge/.test(navigator.userAgent))||(s=t.createTexture(),o=G.allocType(5121,36),t.activeTexture(33984),t.bindTexture(34067,s),t.texImage2D(34069,0,6408,3,3,0,6408,5121,o),G.freeType(o),t.bindTexture(34067,null),t.deleteTexture(s),s=!t.getError()),{colorBits:[t.getParameter(3410),t.getParameter(3411),t.getParameter(3412),t.getParameter(3413)],depthBits:t.getParameter(3414),stencilBits:t.getParameter(3415),subpixelBits:t.getParameter(3408),extensions:Object.keys(e).filter(function(t){return!!e[t]}),maxAnisotropic:r,maxDrawbuffers:n,maxColorAttachments:i,pointSizeDims:t.getParameter(33901),lineWidthDims:t.getParameter(33902),maxViewportDims:t.getParameter(3386),maxCombinedTextureUnits:t.getParameter(35661),maxCubeMapSize:t.getParameter(34076),maxRenderbufferSize:t.getParameter(34024),maxTextureUnits:t.getParameter(34930),maxTextureSize:t.getParameter(3379),maxAttributes:t.getParameter(34921),maxVertexUniforms:t.getParameter(36347),maxVertexTextureUnits:t.getParameter(35660),maxVaryingVectors:t.getParameter(36348),maxFragmentUniforms:t.getParameter(36349),glsl:t.getParameter(35724),renderer:t.getParameter(7937),vendor:t.getParameter(7936),version:t.getParameter(7938),readFloat:a,npotTextureCube:s}},W=function(t){return t instanceof Uint8Array||t instanceof Uint16Array||t instanceof Uint32Array||t instanceof Int8Array||t instanceof Int16Array||t instanceof Int32Array||t instanceof Float32Array||t instanceof Float64Array||t instanceof Uint8ClampedArray},X=function(t){return Object.keys(t).map(function(e){return t[e]})},Z={shape:function(t){for(var e=[];t.length;t=t[0])e.push(t.length);return e},flatten:function(t,e,r,n){var i=1;if(e.length)for(var a=0;a<e.length;++a)i*=e[a];else i=0;switch(r=n||G.allocType(r,i),e.length){case 0:break;case 1:for(n=e[0],e=0;e<n;++e)r[e]=t[e];break;case 2:for(n=e[0],e=e[1],a=i=0;a<n;++a)for(var o=t[a],s=0;s<e;++s)r[i++]=o[s];break;case 3:c(t,e[0],e[1],e[2],r,0);break;default:!function t(e,r,n,i,a){for(var o=1,s=n+1;s<r.length;++s)o*=r[s];var l=r[n];if(4==r.length-n){var u=r[n+1],h=r[n+2];for(r=r[n+3],s=0;s<l;++s)c(e[s],u,h,r,i,a),a+=o}else for(s=0;s<l;++s)t(e[s],r,n+1,i,a),a+=o}(t,e,0,r,0)}return r}},J={\"[object Int8Array]\":5120,\"[object Int16Array]\":5122,\"[object Int32Array]\":5124,\"[object Uint8Array]\":5121,\"[object Uint8ClampedArray]\":5121,\"[object Uint16Array]\":5123,\"[object Uint32Array]\":5125,\"[object Float32Array]\":5126,\"[object Float64Array]\":5121,\"[object ArrayBuffer]\":5121},K={int8:5120,int16:5122,int32:5124,uint8:5121,uint16:5123,uint32:5125,float:5126,float32:5126},$={dynamic:35048,stream:35040,static:35044},Q=Z.flatten,tt=Z.shape,et=[];et[5120]=1,et[5122]=2,et[5124]=4,et[5121]=1,et[5123]=2,et[5125]=4,et[5126]=4;var rt={points:0,point:0,lines:1,line:1,triangles:4,triangle:4,\"line loop\":2,\"line strip\":3,\"triangle strip\":5,\"triangle fan\":6},nt=new Float32Array(1),it=new Uint32Array(nt.buffer),at=[9984,9986,9985,9987],ot=[0,6409,6410,6407,6408],st={};st[6409]=st[6406]=st[6402]=1,st[34041]=st[6410]=2,st[6407]=st[35904]=3,st[6408]=st[35906]=4;var lt=m(\"HTMLCanvasElement\"),ct=m(\"CanvasRenderingContext2D\"),ut=m(\"ImageBitmap\"),ht=m(\"HTMLImageElement\"),ft=m(\"HTMLVideoElement\"),pt=Object.keys(J).concat([lt,ct,ut,ht,ft]),dt=[];dt[5121]=1,dt[5126]=4,dt[36193]=2,dt[5123]=2,dt[5125]=4;var gt=[];gt[32854]=2,gt[32855]=2,gt[36194]=2,gt[34041]=4,gt[33776]=.5,gt[33777]=.5,gt[33778]=1,gt[33779]=1,gt[35986]=.5,gt[35987]=1,gt[34798]=1,gt[35840]=.5,gt[35841]=.25,gt[35842]=.5,gt[35843]=.25,gt[36196]=.5;var vt=[];vt[32854]=2,vt[32855]=2,vt[36194]=2,vt[33189]=2,vt[36168]=1,vt[34041]=4,vt[35907]=4,vt[34836]=16,vt[34842]=8,vt[34843]=6;var mt=function(t,e,r,n,i){function a(t){this.id=c++,this.refCount=1,this.renderbuffer=t,this.format=32854,this.height=this.width=0,i.profile&&(this.stats={size:0})}function o(e){var r=e.renderbuffer;t.bindRenderbuffer(36161,null),t.deleteRenderbuffer(r),e.renderbuffer=null,e.refCount=0,delete u[e.id],n.renderbufferCount--}var s={rgba4:32854,rgb565:36194,\"rgb5 a1\":32855,depth:33189,stencil:36168,\"depth stencil\":34041};e.ext_srgb&&(s.srgba=35907),e.ext_color_buffer_half_float&&(s.rgba16f=34842,s.rgb16f=34843),e.webgl_color_buffer_float&&(s.rgba32f=34836);var l=[];Object.keys(s).forEach(function(t){l[s[t]]=t});var c=0,u={};return a.prototype.decRef=function(){0>=--this.refCount&&o(this)},i.profile&&(n.getTotalRenderbufferSize=function(){var t=0;return Object.keys(u).forEach(function(e){t+=u[e].stats.size}),t}),{create:function(e,r){function o(e,r){var n=0,a=0,u=32854;if(\"object\"==typeof e&&e?(\"shape\"in e?(n=0|(a=e.shape)[0],a=0|a[1]):(\"radius\"in e&&(n=a=0|e.radius),\"width\"in e&&(n=0|e.width),\"height\"in e&&(a=0|e.height)),\"format\"in e&&(u=s[e.format])):\"number\"==typeof e?(n=0|e,a=\"number\"==typeof r?0|r:n):e||(n=a=1),n!==c.width||a!==c.height||u!==c.format)return o.width=c.width=n,o.height=c.height=a,c.format=u,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,u,n,a),i.profile&&(c.stats.size=vt[c.format]*c.width*c.height),o.format=l[c.format],o}var c=new a(t.createRenderbuffer());return u[c.id]=c,n.renderbufferCount++,o(e,r),o.resize=function(e,r){var n=0|e,a=0|r||n;return n===c.width&&a===c.height?o:(o.width=c.width=n,o.height=c.height=a,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,c.format,n,a),i.profile&&(c.stats.size=vt[c.format]*c.width*c.height),o)},o._reglType=\"renderbuffer\",o._renderbuffer=c,i.profile&&(o.stats=c.stats),o.destroy=function(){c.decRef()},o},clear:function(){X(u).forEach(o)},restore:function(){X(u).forEach(function(e){e.renderbuffer=t.createRenderbuffer(),t.bindRenderbuffer(36161,e.renderbuffer),t.renderbufferStorage(36161,e.format,e.width,e.height)}),t.bindRenderbuffer(36161,null)}}},yt=[];yt[6408]=4,yt[6407]=3;var xt=[];xt[5121]=1,xt[5126]=4,xt[36193]=2;var bt=[\"x\",\"y\",\"z\",\"w\"],_t=\"blend.func blend.equation stencil.func stencil.opFront stencil.opBack sample.coverage viewport scissor.box polygonOffset.offset\".split(\" \"),wt={0:0,1:1,zero:0,one:1,\"src color\":768,\"one minus src color\":769,\"src alpha\":770,\"one minus src alpha\":771,\"dst color\":774,\"one minus dst color\":775,\"dst alpha\":772,\"one minus dst alpha\":773,\"constant color\":32769,\"one minus constant color\":32770,\"constant alpha\":32771,\"one minus constant alpha\":32772,\"src alpha saturate\":776},kt={never:512,less:513,\"<\":513,equal:514,\"=\":514,\"==\":514,\"===\":514,lequal:515,\"<=\":515,greater:516,\">\":516,notequal:517,\"!=\":517,\"!==\":517,gequal:518,\">=\":518,always:519},Tt={0:0,zero:0,keep:7680,replace:7681,increment:7682,decrement:7683,\"increment wrap\":34055,\"decrement wrap\":34056,invert:5386},At={cw:2304,ccw:2305},Mt=new I(!1,!1,!1,function(){});return function(t){function e(){if(0===Z.length)w&&w.update(),Q=null;else{Q=q.next(e),h();for(var t=Z.length-1;0<=t;--t){var r=Z[t];r&&r(P,null,0)}v.flush(),w&&w.update()}}function r(){!Q&&0<Z.length&&(Q=q.next(e))}function n(){Q&&(q.cancel(e),Q=null)}function a(t){t.preventDefault(),n(),J.forEach(function(t){t()})}function o(t){v.getError(),y.restore(),D.restore(),z.restore(),R.restore(),F.restore(),U.restore(),w&&w.restore(),G.procs.refresh(),r(),K.forEach(function(t){t()})}function s(t){function e(t){var e={},r={};return Object.keys(t).forEach(function(n){var i=t[n];V.isDynamic(i)?r[n]=V.unbox(i,n):e[n]=i}),{dynamic:r,static:e}}var r=e(t.context||{}),n=e(t.uniforms||{}),i=e(t.attributes||{}),a=e(function(t){function e(t){if(t in r){var e=r[t];delete r[t],Object.keys(e).forEach(function(n){r[t+\".\"+n]=e[n]})}}var r=j({},t);return delete r.uniforms,delete r.attributes,delete r.context,\"stencil\"in r&&r.stencil.op&&(r.stencil.opBack=r.stencil.opFront=r.stencil.op,delete r.stencil.op),e(\"blend\"),e(\"depth\"),e(\"cull\"),e(\"stencil\"),e(\"polygonOffset\"),e(\"scissor\"),e(\"sample\"),r}(t));t={gpuTime:0,cpuTime:0,count:0};var o=(r=G.compile(a,i,n,r,t)).draw,s=r.batch,l=r.scope,c=[];return j(function(t,e){var r;if(\"function\"==typeof t)return l.call(this,null,t,0);if(\"function\"==typeof e)if(\"number\"==typeof t)for(r=0;r<t;++r)l.call(this,null,e,r);else{if(!Array.isArray(t))return l.call(this,t,e,0);for(r=0;r<t.length;++r)l.call(this,t[r],e,r)}else if(\"number\"==typeof t){if(0<t)return s.call(this,function(t){for(;c.length<t;)c.push(null);return c}(0|t),0|t)}else{if(!Array.isArray(t))return o.call(this,t);if(t.length)return s.call(this,t,t.length)}},{stats:t})}function l(t,e){var r=0;G.procs.poll();var n=e.color;n&&(v.clearColor(+n[0]||0,+n[1]||0,+n[2]||0,+n[3]||0),r|=16384),\"depth\"in e&&(v.clearDepth(+e.depth),r|=256),\"stencil\"in e&&(v.clearStencil(0|e.stencil),r|=1024),v.clear(r)}function c(t){return Z.push(t),r(),{cancel:function(){var e=N(Z,t);Z[e]=function t(){var e=N(Z,t);Z[e]=Z[Z.length-1],--Z.length,0>=Z.length&&n()}}}}function u(){var t=W.viewport,e=W.scissor_box;t[0]=t[1]=e[0]=e[1]=0,P.viewportWidth=P.framebufferWidth=P.drawingBufferWidth=t[2]=e[2]=v.drawingBufferWidth,P.viewportHeight=P.framebufferHeight=P.drawingBufferHeight=t[3]=e[3]=v.drawingBufferHeight}function h(){P.tick+=1,P.time=g(),u(),G.procs.poll()}function f(){u(),G.procs.refresh(),w&&w.update()}function g(){return(H()-k)/1e3}if(!(t=i(t)))return null;var v=t.gl,m=v.getContextAttributes();v.isContextLost();var y=function(t,e){function r(e){var r;e=e.toLowerCase();try{r=n[e]=t.getExtension(e)}catch(t){}return!!r}for(var n={},i=0;i<e.extensions.length;++i){var a=e.extensions[i];if(!r(a))return e.onDestroy(),e.onDone('\"'+a+'\" extension is not supported by the current WebGL context, try upgrading your system or a different browser'),null}return e.optionalExtensions.forEach(r),{extensions:n,restore:function(){Object.keys(n).forEach(function(t){if(n[t]&&!r(t))throw Error(\"(regl): error restoring extension \"+t)})}}}(v,t);if(!y)return null;var x=function(){var t={\"\":0},e=[\"\"];return{id:function(r){var n=t[r];return n||(n=t[r]=e.length,e.push(r),n)},str:function(t){return e[t]}}}(),b={bufferCount:0,elementsCount:0,framebufferCount:0,shaderCount:0,textureCount:0,cubeCount:0,renderbufferCount:0,maxTextureUnits:0},_=y.extensions,w=function(t,e){function r(){this.endQueryIndex=this.startQueryIndex=-1,this.sum=0,this.stats=null}function n(t,e,n){var i=o.pop()||new r;i.startQueryIndex=t,i.endQueryIndex=e,i.sum=0,i.stats=n,s.push(i)}if(!e.ext_disjoint_timer_query)return null;var i=[],a=[],o=[],s=[],l=[],c=[];return{beginQuery:function(t){var r=i.pop()||e.ext_disjoint_timer_query.createQueryEXT();e.ext_disjoint_timer_query.beginQueryEXT(35007,r),a.push(r),n(a.length-1,a.length,t)},endQuery:function(){e.ext_disjoint_timer_query.endQueryEXT(35007)},pushScopeStats:n,update:function(){var t,r;if(0!==(t=a.length)){c.length=Math.max(c.length,t+1),l.length=Math.max(l.length,t+1),l[0]=0;var n=c[0]=0;for(r=t=0;r<a.length;++r){var u=a[r];e.ext_disjoint_timer_query.getQueryObjectEXT(u,34919)?(n+=e.ext_disjoint_timer_query.getQueryObjectEXT(u,34918),i.push(u)):a[t++]=u,l[r+1]=n,c[r+1]=t}for(a.length=t,r=t=0;r<s.length;++r){var h=(n=s[r]).startQueryIndex;u=n.endQueryIndex,n.sum+=l[u]-l[h],h=c[h],(u=c[u])===h?(n.stats.gpuTime+=n.sum/1e6,o.push(n)):(n.startQueryIndex=h,n.endQueryIndex=u,s[t++]=n)}s.length=t}},getNumPendingQueries:function(){return a.length},clear:function(){i.push.apply(i,a);for(var t=0;t<i.length;t++)e.ext_disjoint_timer_query.deleteQueryEXT(i[t]);a.length=0,i.length=0},restore:function(){a.length=0,i.length=0}}}(0,_),k=H(),C=v.drawingBufferWidth,L=v.drawingBufferHeight,P={tick:0,time:0,viewportWidth:C,viewportHeight:L,framebufferWidth:C,framebufferHeight:L,drawingBufferWidth:C,drawingBufferHeight:L,pixelRatio:t.pixelRatio},O=Y(v,_),z=(C=function(t,e,r,n){for(t=r.maxAttributes,e=Array(t),r=0;r<t;++r)e[r]=new M;return{Record:M,scope:{},state:e}}(v,_,O),p(v,b,t,C)),I=d(v,_,z,b),D=S(v,x,b,t),R=T(v,_,O,function(){G.procs.poll()},P,b,t),F=mt(v,_,0,b,t),U=A(v,_,O,R,F,b),G=B(v,x,_,O,z,I,0,U,{},C,D,{elements:null,primitive:4,count:-1,offset:0,instances:-1},P,w,t),W=(x=E(v,U,G.procs.poll,P),G.next),X=v.canvas,Z=[],J=[],K=[],$=[t.onDestroy],Q=null;X&&(X.addEventListener(\"webglcontextlost\",a,!1),X.addEventListener(\"webglcontextrestored\",o,!1));var tt=U.setFBO=s({framebuffer:V.define.call(null,1,\"framebuffer\")});return f(),m=j(s,{clear:function(t){if(\"framebuffer\"in t)if(t.framebuffer&&\"framebufferCube\"===t.framebuffer_reglType)for(var e=0;6>e;++e)tt(j({framebuffer:t.framebuffer.faces[e]},t),l);else tt(t,l);else l(0,t)},prop:V.define.bind(null,1),context:V.define.bind(null,2),this:V.define.bind(null,3),draw:s({}),buffer:function(t){return z.create(t,34962,!1,!1)},elements:function(t){return I.create(t,!1)},texture:R.create2D,cube:R.createCube,renderbuffer:F.create,framebuffer:U.create,framebufferCube:U.createCube,attributes:m,frame:c,on:function(t,e){var r;switch(t){case\"frame\":return c(e);case\"lost\":r=J;break;case\"restore\":r=K;break;case\"destroy\":r=$}return r.push(e),{cancel:function(){for(var t=0;t<r.length;++t)if(r[t]===e){r[t]=r[r.length-1],r.pop();break}}}},limits:O,hasExtension:function(t){return 0<=O.extensions.indexOf(t.toLowerCase())},read:x,destroy:function(){Z.length=0,n(),X&&(X.removeEventListener(\"webglcontextlost\",a),X.removeEventListener(\"webglcontextrestored\",o)),D.clear(),U.clear(),F.clear(),R.clear(),I.clear(),z.clear(),w&&w.clear(),$.forEach(function(t){t()})},_gl:v,_refresh:f,poll:function(){h(),w&&w.update()},now:g,stats:b}),t.onDone(null,m),m}},\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=i():n.createREGL=i()},{}],503:[function(t,e,r){\"use strict\";var n,i=\"\";e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"expected a string\");if(1===e)return t;if(2===e)return t+t;var r=t.length*e;if(n!==t||\"undefined\"==typeof n)n=t,i=\"\";else if(i.length>=r)return i.substr(0,r);for(;r>i.length&&e>1;)1&e&&(i+=t),e>>=1,t+=t;return i=(i+=t).substr(0,r)}},{}],504:[function(t,e,r){(function(t){e.exports=t.performance&&t.performance.now?function(){return performance.now()}:Date.now||function(){return+new Date}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{}],505:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=t[t.length-1],n=e,i=e-2;i>=0;--i){var a=r,o=t[i],s=(r=a+o)-a,l=o-s;l&&(t[--n]=r,r=l)}for(var c=0,i=n;i<e;++i){var a=t[i],o=r,s=(r=a+o)-a,l=o-s;l&&(t[c++]=l)}return t[c++]=r,t.length=c,t}},{}],506:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-compress\"),s=6;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(2===t.length)return[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\");for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(l(t,r)),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return function t(e){if(1===e.length)return e[0];if(2===e.length)return[\"sum(\",e[0],\",\",e[1],\")\"].join(\"\");var r=e.length>>1;return[\"sum(\",t(e.slice(0,r)),\",\",t(e.slice(r)),\")\"].join(\"\")}(e);var n}function u(t){return new Function(\"sum\",\"scale\",\"prod\",\"compress\",[\"function robustDeterminant\",t,\"(m){return compress(\",c(function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m[\",r,\"][\",n,\"]\"].join(\"\")}return e}(t)),\")};return robustDeterminant\",t].join(\"\"))(i,a,n,o)}var h=[function(){return[0]},function(t){return[t[0][0]]}];!function(){for(;h.length<s;)h.push(u(h.length));for(var t=[],r=[\"function robustDeterminant(m){switch(m.length){\"],n=0;n<s;++n)t.push(\"det\"+n),r.push(\"case \",n,\":return det\",n,\"(m);\");r.push(\"}var det=CACHE[m.length];if(!det)det=CACHE[m.length]=gen(m.length);return det(m);}return robustDeterminant\"),t.push(\"CACHE\",\"gen\",r.join(\"\"));var i=Function.apply(void 0,t);for(e.exports=i.apply(void 0,h.concat([h,u])),n=0;n<h.length;++n)e.exports[n]=h[n]}()},{\"robust-compress\":505,\"robust-scale\":512,\"robust-sum\":515,\"two-product\":543}],507:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\");e.exports=function(t,e){for(var r=n(t[0],e[0]),a=1;a<t.length;++a)r=i(r,n(t[a],e[a]));return r}},{\"robust-sum\":515,\"two-product\":543}],508:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-subtract\"),o=t(\"robust-scale\"),s=6;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",c(t.slice(0,e)),\",\",c(t.slice(e)),\")\"].join(\"\")}function u(t,e){if(\"m\"===t.charAt(0)){if(\"w\"===e.charAt(0)){var r=t.split(\"[\");return[\"w\",e.substr(1),\"m\",r[0].substr(1)].join(\"\")}return[\"prod(\",t,\",\",e,\")\"].join(\"\")}return u(e,t)}function h(t){if(2===t.length)return[[\"diff(\",u(t[0][0],t[1][1]),\",\",u(t[1][0],t[0][1]),\")\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(h(l(t,r))),\",\",(n=r,!0&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function f(t,e){for(var r=[],n=0;n<e-2;++n)r.push([\"prod(m\",t,\"[\",n,\"],m\",t,\"[\",n,\"])\"].join(\"\"));return c(r)}function p(t){for(var e=[],r=[],s=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-2,\"]\"].join(\"\")}return e}(t),u=0;u<t;++u)s[0][u]=\"1\",s[t-1][u]=\"w\"+u;for(u=0;u<t;++u)0==(1&u)?e.push.apply(e,h(l(s,u))):r.push.apply(r,h(l(s,u)));var p=c(e),d=c(r),g=\"exactInSphere\"+t,v=[];for(u=0;u<t;++u)v.push(\"m\"+u);var m=[\"function \",g,\"(\",v.join(),\"){\"];for(u=0;u<t;++u){m.push(\"var w\",u,\"=\",f(u,t),\";\");for(var y=0;y<t;++y)y!==u&&m.push(\"var w\",u,\"m\",y,\"=scale(w\",u,\",m\",y,\"[0]);\")}return m.push(\"var p=\",p,\",n=\",d,\",d=diff(p,n);return d[d.length-1];}return \",g),new Function(\"sum\",\"diff\",\"prod\",\"scale\",m.join(\"\"))(i,a,n,o)}var d=[function(){return 0},function(){return 0},function(){return 0}];!function(){for(;d.length<=s;)d.push(p(d.length));for(var t=[],r=[\"slow\"],n=0;n<=s;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function testInSphere(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=s;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return testInSphere\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[function(t){var e=d[t.length];return e||(e=d[t.length]=p(t.length)),e.apply(void 0,t)}].concat(d)),n=0;n<=s;++n)e.exports[n]=d[n]}()},{\"robust-scale\":512,\"robust-subtract\":514,\"robust-sum\":515,\"two-product\":543}],509:[function(t,e,r){\"use strict\";var n=t(\"robust-determinant\"),i=6;function a(t){for(var e=\"robustLinearSolve\"+t+\"d\",r=[\"function \",e,\"(A,b){return [\"],i=0;i<t;++i){r.push(\"det([\");for(var a=0;a<t;++a){a>0&&r.push(\",\"),r.push(\"[\");for(var o=0;o<t;++o)o>0&&r.push(\",\"),o===i?r.push(\"+b[\",a,\"]\"):r.push(\"+A[\",a,\"][\",o,\"]\");r.push(\"]\")}r.push(\"]),\")}r.push(\"det(A)]}return \",e);var s=new Function(\"det\",r.join(\"\"));return s(t<6?n[t]:n)}var o=[function(){return[0]},function(t,e){return[[e[0]],[t[0][0]]]}];!function(){for(;o.length<i;)o.push(a(o.length));for(var t=[],r=[\"function dispatchLinearSolve(A,b){switch(A.length){\"],n=0;n<i;++n)t.push(\"s\"+n),r.push(\"case \",n,\":return s\",n,\"(A,b);\");r.push(\"}var s=CACHE[A.length];if(!s)s=CACHE[A.length]=g(A.length);return s(A,b)}return dispatchLinearSolve\"),t.push(\"CACHE\",\"g\",r.join(\"\"));var s=Function.apply(void 0,t);for(e.exports=s.apply(void 0,o.concat([o,a])),n=0;n<i;++n)e.exports[n]=o[n]}()},{\"robust-determinant\":506}],510:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-subtract\"),s=5;function l(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function c(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",c(t.slice(0,e)),\",\",c(t.slice(e)),\")\"].join(\"\")}function u(t){if(2===t.length)return[[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(u(l(t,r))),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function h(t){for(var e=[],r=[],s=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-1,\"]\"].join(\"\")}return e}(t),h=[],f=0;f<t;++f)0==(1&f)?e.push.apply(e,u(l(s,f))):r.push.apply(r,u(l(s,f))),h.push(\"m\"+f);var p=c(e),d=c(r),g=\"orientation\"+t+\"Exact\",v=[\"function \",g,\"(\",h.join(),\"){var p=\",p,\",n=\",d,\",d=sub(p,n);return d[d.length-1];};return \",g].join(\"\");return new Function(\"sum\",\"prod\",\"scale\",\"sub\",v)(i,n,a,o)}var f=h(3),p=h(4),d=[function(){return 0},function(){return 0},function(t,e){return e[0]-t[0]},function(t,e,r){var n,i=(t[1]-r[1])*(e[0]-r[0]),a=(t[0]-r[0])*(e[1]-r[1]),o=i-a;if(i>0){if(a<=0)return o;n=i+a}else{if(!(i<0))return o;if(a>=0)return o;n=-(i+a)}var s=3.3306690738754716e-16*n;return o>=s||o<=-s?o:f(t,e,r)},function(t,e,r,n){var i=t[0]-n[0],a=e[0]-n[0],o=r[0]-n[0],s=t[1]-n[1],l=e[1]-n[1],c=r[1]-n[1],u=t[2]-n[2],h=e[2]-n[2],f=r[2]-n[2],d=a*c,g=o*l,v=o*s,m=i*c,y=i*l,x=a*s,b=u*(d-g)+h*(v-m)+f*(y-x),_=7.771561172376103e-16*((Math.abs(d)+Math.abs(g))*Math.abs(u)+(Math.abs(v)+Math.abs(m))*Math.abs(h)+(Math.abs(y)+Math.abs(x))*Math.abs(f));return b>_||-b>_?b:p(t,e,r,n)}];!function(){for(;d.length<=s;)d.push(h(d.length));for(var t=[],r=[\"slow\"],n=0;n<=s;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function getOrientation(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=s;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return getOrientation\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[function(t){var e=d[t.length];return e||(e=d[t.length]=h(t.length)),e.apply(void 0,t)}].concat(d)),n=0;n<=s;++n)e.exports[n]=d[n]}()},{\"robust-scale\":512,\"robust-subtract\":514,\"robust-sum\":515,\"two-product\":543}],511:[function(t,e,r){\"use strict\";var n=t(\"robust-sum\"),i=t(\"robust-scale\");e.exports=function(t,e){if(1===t.length)return i(e,t[0]);if(1===e.length)return i(t,e[0]);if(0===t.length||0===e.length)return[0];var r=[0];if(t.length<e.length)for(var a=0;a<t.length;++a)r=n(r,i(e,t[a]));else for(var a=0;a<e.length;++a)r=n(r,i(t,e[a]));return r}},{\"robust-scale\":512,\"robust-sum\":515}],512:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"two-sum\");e.exports=function(t,e){var r=t.length;if(1===r){var a=n(t[0],e);return a[0]?a:[a[1]]}var o=new Array(2*r),s=[.1,.1],l=[.1,.1],c=0;n(t[0],e,s),s[0]&&(o[c++]=s[0]);for(var u=1;u<r;++u){n(t[u],e,l);var h=s[1];i(h,l[0],s),s[0]&&(o[c++]=s[0]);var f=l[1],p=s[1],d=f+p,g=d-f,v=p-g;s[1]=d,v&&(o[c++]=v)}s[1]&&(o[c++]=s[1]);0===c&&(o[c++]=0);return o.length=c,o}},{\"two-product\":543,\"two-sum\":544}],513:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){var a=n(t,r,i),o=n(e,r,i);if(a>0&&o>0||a<0&&o<0)return!1;var s=n(r,t,e),l=n(i,t,e);if(s>0&&l>0||s<0&&l<0)return!1;if(0===a&&0===o&&0===s&&0===l)return function(t,e,r,n){for(var i=0;i<2;++i){var a=t[i],o=e[i],s=Math.min(a,o),l=Math.max(a,o),c=r[i],u=n[i],h=Math.min(c,u),f=Math.max(c,u);if(f<s||l<h)return!1}return!0}(t,e,r,i);return!0};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":510}],514:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],-e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,h=t[l],f=u(h),p=-e[c],d=u(p);f<d?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=-e[c],d=u(p)));l<r&&f<d||c>=n?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p)));var g,v,m=i+a,y=m-i,x=a-y,b=x,_=m;for(;l<r&&c<n;)f<d?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p))),(x=(a=b)-(y=(m=i+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g;for(;l<r;)(x=(a=b)-(y=(m=(i=h)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(l+=1)<r&&(h=t[l]);for(;c<n;)(x=(a=b)-(y=(m=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(c+=1)<n&&(p=-e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],515:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,h=t[l],f=u(h),p=e[c],d=u(p);f<d?(a=h,(l+=1)<r&&(h=t[l],f=u(h))):(a=p,(c+=1)<n&&(p=e[c],d=u(p)));l<r&&f<d||c>=n?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=e[c],d=u(p)));var g,v,m=i+a,y=m-i,x=a-y,b=x,_=m;for(;l<r&&c<n;)f<d?(i=h,(l+=1)<r&&(h=t[l],f=u(h))):(i=p,(c+=1)<n&&(p=e[c],d=u(p))),(x=(a=b)-(y=(m=i+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g;for(;l<r;)(x=(a=b)-(y=(m=(i=h)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(l+=1)<r&&(h=t[l]);for(;c<n;)(x=(a=b)-(y=(m=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+m)-(v=g-_))+(m-v),_=g,(c+=1)<n&&(p=e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],516:[function(t,e,r){\"use strict\";e.exports=function(t){return t<0?-1:t>0?1:0}},{}],517:[function(t,e,r){\"use strict\";e.exports=function(t){return i(n(t))};var n=t(\"boundary-cells\"),i=t(\"reduce-simplicial-complex\")},{\"boundary-cells\":95,\"reduce-simplicial-complex\":489}],518:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,s){r=r||0,\"undefined\"==typeof s&&(s=function(t){for(var e=t.length,r=0,n=0;n<e;++n)r=0|Math.max(r,t[n].length);return r-1}(t));if(0===t.length||s<1)return{cells:[],vertexIds:[],vertexWeights:[]};var l=function(t,e){for(var r=t.length,n=i.mallocUint8(r),a=0;a<r;++a)n[a]=t[a]<e|0;return n}(e,+r),c=function(t,e){for(var r=t.length,o=e*(e+1)/2*r|0,s=i.mallocUint32(2*o),l=0,c=0;c<r;++c)for(var u=t[c],e=u.length,h=0;h<e;++h)for(var f=0;f<h;++f){var p=u[f],d=u[h];s[l++]=0|Math.min(p,d),s[l++]=0|Math.max(p,d)}a(n(s,[l/2|0,2]));for(var g=2,c=2;c<l;c+=2)s[c-2]===s[c]&&s[c-1]===s[c+1]||(s[g++]=s[c],s[g++]=s[c+1]);return n(s,[g/2|0,2])}(t,s),u=function(t,e,r,a){for(var o=t.data,s=t.shape[0],l=i.mallocDouble(s),c=0,u=0;u<s;++u){var h=o[2*u],f=o[2*u+1];if(r[h]!==r[f]){var p=e[h],d=e[f];o[2*c]=h,o[2*c+1]=f,l[c++]=(d-a)/(d-p)}}return t.shape[0]=c,n(l,[c])}(c,e,l,+r),h=function(t,e){var r=i.mallocInt32(2*e),n=t.shape[0],a=t.data;r[0]=0;for(var o=0,s=0;s<n;++s){var l=a[2*s];if(l!==o){for(r[2*o+1]=s;++o<l;)r[2*o]=s,r[2*o+1]=s;r[2*o]=s}}r[2*o+1]=n;for(;++o<e;)r[2*o]=r[2*o+1]=n;return r}(c,0|e.length),f=o(s)(t,c.data,h,l),p=function(t){for(var e=0|t.shape[0],r=t.data,n=new Array(e),i=0;i<e;++i)n[i]=[r[2*i],r[2*i+1]];return n}(c),d=[].slice.call(u.data,0,u.shape[0]);return i.free(l),i.free(c.data),i.free(u.data),i.free(h),{cells:f,vertexIds:p,vertexWeights:d}};var n=t(\"ndarray\"),i=t(\"typedarray-pool\"),a=t(\"ndarray-sort\"),o=t(\"./lib/codegen\")},{\"./lib/codegen\":519,ndarray:450,\"ndarray-sort\":448,\"typedarray-pool\":545}],519:[function(t,e,r){\"use strict\";e.exports=function(t){var e=a[t];e||(e=a[t]=function(t){var e=0,r=new Array(t+1);r[0]=[[]];for(var a=1;a<=t;++a)for(var o=r[a]=i(a),s=0;s<o.length;++s)e=Math.max(e,o[a].length);var l=[\"function B(C,E,i,j){\",\"var a=Math.min(i,j)|0,b=Math.max(i,j)|0,l=C[2*a],h=C[2*a+1];\",\"while(l<h){\",\"var m=(l+h)>>1,v=E[2*m+1];\",\"if(v===b){return m}\",\"if(b<v){h=m}else{l=m+1}\",\"}\",\"return l;\",\"};\",\"function getContour\",t,\"d(F,E,C,S){\",\"var n=F.length,R=[];\",\"for(var i=0;i<n;++i){var c=F[i],l=c.length;\"];function c(t){if(!(t.length<=0)){l.push(\"R.push(\");for(var e=0;e<t.length;++e){var r=t[e];e>0&&l.push(\",\"),l.push(\"[\");for(var n=0;n<r.length;++n){var i=r[n];n>0&&l.push(\",\"),l.push(\"B(C,E,c[\",i[0],\"],c[\",i[1],\"])\")}l.push(\"]\")}l.push(\");\")}}for(var a=t+1;a>1;--a){a<t+1&&l.push(\"else \"),l.push(\"if(l===\",a,\"){\");for(var u=[],s=0;s<a;++s)u.push(\"(S[c[\"+s+\"]]<<\"+s+\")\");l.push(\"var M=\",u.join(\"+\"),\";if(M===0||M===\",(1<<a)-1,\"){continue}switch(M){\");for(var o=r[a-1],s=0;s<o.length;++s)l.push(\"case \",s,\":\"),c(o[s]),l.push(\"break;\");l.push(\"}}\")}return l.push(\"}return R;};return getContour\",t,\"d\"),new Function(\"pool\",l.join(\"\"))(n)}(t));return e};var n=t(\"typedarray-pool\"),i=t(\"marching-simplex-table\"),a={}},{\"marching-simplex-table\":427,\"typedarray-pool\":545}],520:[function(t,e,r){\"use strict\";var n=t(\"bit-twiddle\"),i=t(\"union-find\");function a(t,e){var r=t.length,n=t.length-e.length,i=Math.min;if(n)return n;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return(s=t[0]+t[1]-e[0]-e[1])||i(t[0],t[1])-i(e[0],e[1]);case 3:var a=t[0]+t[1],o=e[0]+e[1];if(s=a+t[2]-(o+e[2]))return s;var s,l=i(t[0],t[1]),c=i(e[0],e[1]);return(s=i(l,t[2])-i(c,e[2]))||i(l+t[2],a)-i(c+e[2],o);default:var u=t.slice(0);u.sort();var h=e.slice(0);h.sort();for(var f=0;f<r;++f)if(n=u[f]-h[f])return n;return 0}}function o(t,e){return a(t[0],e[0])}function s(t,e){if(e){for(var r=t.length,n=new Array(r),i=0;i<r;++i)n[i]=[t[i],e[i]];n.sort(o);for(i=0;i<r;++i)t[i]=n[i][0],e[i]=n[i][1];return t}return t.sort(a),t}function l(t){if(0===t.length)return[];for(var e=1,r=t.length,n=1;n<r;++n){var i=t[n];if(a(i,t[n-1])){if(n===e){e++;continue}t[e++]=i}}return t.length=e,t}function c(t,e){for(var r=0,n=t.length-1,i=-1;r<=n;){var o=r+n>>1,s=a(t[o],e);s<=0?(0===s&&(i=o),r=o+1):s>0&&(n=o-1)}return i}function u(t,e){for(var r=new Array(t.length),i=0,o=r.length;i<o;++i)r[i]=[];for(var s=[],l=(i=0,e.length);i<l;++i)for(var u=e[i],h=u.length,f=1,p=1<<h;f<p;++f){s.length=n.popCount(f);for(var d=0,g=0;g<h;++g)f&1<<g&&(s[d++]=u[g]);var v=c(t,s);if(!(v<0))for(;r[v++].push(i),!(v>=t.length||0!==a(t[v],s)););}return r}function h(t,e){if(e<0)return[];for(var r=[],i=(1<<e+1)-1,a=0;a<t.length;++a)for(var o=t[a],l=i;l<1<<o.length;l=n.nextCombination(l)){for(var c=new Array(e+1),u=0,h=0;h<o.length;++h)l&1<<h&&(c[u++]=o[h]);r.push(c)}return s(r)}r.dimension=function(t){for(var e=0,r=Math.max,n=0,i=t.length;n<i;++n)e=r(e,t[n].length);return e-1},r.countVertices=function(t){for(var e=-1,r=Math.max,n=0,i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)e=r(e,a[o]);return e+1},r.cloneCells=function(t){for(var e=new Array(t.length),r=0,n=t.length;r<n;++r)e[r]=t[r].slice(0);return e},r.compareCells=a,r.normalize=s,r.unique=l,r.findCell=c,r.incidence=u,r.dual=function(t,e){if(!e)return u(l(h(t,0)),t);for(var r=new Array(e),n=0;n<e;++n)r[n]=[];n=0;for(var i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)r[a[o]].push(n);return r},r.explode=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0|i.length,o=1,l=1<<a;o<l;++o){for(var c=[],u=0;u<a;++u)o>>>u&1&&c.push(i[u]);e.push(c)}return s(e)},r.skeleton=h,r.boundary=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;++a){for(var l=new Array(i.length-1),c=0,u=0;c<o;++c)c!==a&&(l[u++]=i[c]);e.push(l)}return s(e)},r.connectedComponents=function(t,e){return e?function(t,e){for(var r=new i(e),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var s=o+1;s<a.length;++s)r.link(a[o],a[s]);var l=[],c=r.ranks;for(n=0;n<c.length;++n)c[n]=-1;for(n=0;n<t.length;++n){var u=r.find(t[n][0]);c[u]<0?(c[u]=l.length,l.push([t[n].slice(0)])):l[c[u]].push(t[n].slice(0))}return l}(t,e):function(t){for(var e=l(s(h(t,0))),r=new i(e.length),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var u=c(e,[a[o]]),f=o+1;f<a.length;++f)r.link(u,c(e,[a[f]]));var p=[],d=r.ranks;for(n=0;n<d.length;++n)d[n]=-1;for(n=0;n<t.length;++n){var g=r.find(c(e,[t[n][0]]));d[g]<0?(d[g]=p.length,p.push([t[n].slice(0)])):p[d[g]].push(t[n].slice(0))}return p}(t)}},{\"bit-twiddle\":92,\"union-find\":546}],521:[function(t,e,r){arguments[4][92][0].apply(r,arguments)},{dup:92}],522:[function(t,e,r){arguments[4][520][0].apply(r,arguments)},{\"bit-twiddle\":521,dup:520,\"union-find\":523}],523:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n,n.prototype.length=function(){return this.roots.length},n.prototype.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},n.prototype.find=function(t){for(var e=this.roots;e[t]!==t;){var r=e[t];e[t]=e[r],t=r}return t},n.prototype.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],524:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){for(var a=e.length,o=t.length,s=new Array(a),l=new Array(a),c=new Array(a),u=new Array(a),h=0;h<a;++h)s[h]=l[h]=-1,c[h]=1/0,u[h]=!1;for(var h=0;h<o;++h){var f=t[h];if(2!==f.length)throw new Error(\"Input must be a graph\");var p=f[1],d=f[0];-1!==l[d]?l[d]=-2:l[d]=p,-1!==s[p]?s[p]=-2:s[p]=d}function g(t){if(u[t])return 1/0;var r,i,a,o,c,h=s[t],f=l[t];return h<0||f<0?1/0:(r=e[t],i=e[h],a=e[f],o=Math.abs(n(r,i,a)),c=Math.sqrt(Math.pow(i[0]-a[0],2)+Math.pow(i[1]-a[1],2)),o/c)}function v(t,e){var r=T[t],n=T[e];T[t]=n,T[e]=r,A[r]=e,A[n]=t}function m(t){return c[T[t]]}function y(t){return 1&t?t-1>>1:(t>>1)-1}function x(t){for(var e=m(t);;){var r=e,n=2*t+1,i=2*(t+1),a=t;if(n<S){var o=m(n);o<r&&(a=n,r=o)}if(i<S){var s=m(i);s<r&&(a=i)}if(a===t)return t;v(t,a),t=a}}function b(t){for(var e=m(t);t>0;){var r=y(t);if(r>=0){var n=m(r);if(e<n){v(t,r),t=r;continue}}return t}}function _(){if(S>0){var t=T[0];return v(0,S-1),S-=1,x(0),t}return-1}function w(t,e){var r=T[t];return c[r]===e?t:(c[r]=-1/0,b(t),_(),c[r]=e,b((S+=1)-1))}function k(t){if(!u[t]){u[t]=!0;var e=s[t],r=l[t];s[r]>=0&&(s[r]=e),l[e]>=0&&(l[e]=r),A[e]>=0&&w(A[e],g(e)),A[r]>=0&&w(A[r],g(r))}}for(var T=[],A=new Array(a),h=0;h<a;++h){var M=c[h]=g(h);M<1/0?(A[h]=T.length,T.push(h)):A[h]=-1}for(var S=T.length,h=S>>1;h>=0;--h)x(h);for(;;){var E=_();if(E<0||c[E]>r)break;k(E)}for(var C=[],h=0;h<a;++h)u[h]||(A[h]=C.length,C.push(e[h].slice()));C.length;function L(t,e){if(t[e]<0)return e;var r=e,n=e;do{var i=t[n];if(!u[n]||i<0||i===n)break;if(i=t[n=i],!u[n]||i<0||i===n)break;n=i,r=t[r]}while(r!==n);for(var a=e;a!==n;a=t[a])t[a]=n;return n}var P=[];return t.forEach(function(t){var e=L(s,t[0]),r=L(l,t[1]);if(e>=0&&r>=0&&e!==r){var n=A[e],i=A[r];n!==i&&P.push([n,i])}}),i.unique(i.normalize(P)),{positions:C,edges:P}};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\")},{\"robust-orientation\":510,\"simplicial-complex\":522}],525:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,a,o,s;if(e[0][0]<e[1][0])r=e[0],a=e[1];else{if(!(e[0][0]>e[1][0]))return i(e,t);r=e[1],a=e[0]}if(t[0][0]<t[1][0])o=t[0],s=t[1];else{if(!(t[0][0]>t[1][0]))return-i(t,e);o=t[1],s=t[0]}var l=n(r,a,s),c=n(r,a,o);if(l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;if(l=n(s,o,a),c=n(s,o,r),l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;return a[0]-s[0]};var n=t(\"robust-orientation\");function i(t,e){var r,i,a,o;if(e[0][0]<e[1][0])r=e[0],i=e[1];else{if(!(e[0][0]>e[1][0])){var s=Math.min(t[0][1],t[1][1]),l=Math.max(t[0][1],t[1][1]),c=Math.min(e[0][1],e[1][1]),u=Math.max(e[0][1],e[1][1]);return l<c?l-c:s>u?s-u:l-u}r=e[1],i=e[0]}t[0][1]<t[1][1]?(a=t[0],o=t[1]):(a=t[1],o=t[0]);var h=n(i,r,a);return h||((h=n(i,r,o))||o-i)}},{\"robust-orientation\":510}],526:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=2*e,n=new Array(r),a=0;a<e;++a){var l=t[a],c=l[0][0]<l[1][0];n[2*a]=new h(l[0][0],l,c,a),n[2*a+1]=new h(l[1][0],l,!c,a)}n.sort(function(t,e){var r=t.x-e.x;return r||((r=t.create-e.create)||Math.min(t.segment[0][1],t.segment[1][1])-Math.min(e.segment[0][1],e.segment[1][1]))});for(var f=i(o),p=[],d=[],g=[],a=0;a<r;){for(var v=n[a].x,m=[];a<r;){var y=n[a];if(y.x!==v)break;a+=1,y.segment[0][0]===y.x&&y.segment[1][0]===y.x?y.create&&(y.segment[0][1]<y.segment[1][1]?(m.push(new u(y.segment[0][1],y.index,!0,!0)),m.push(new u(y.segment[1][1],y.index,!1,!1))):(m.push(new u(y.segment[1][1],y.index,!0,!1)),m.push(new u(y.segment[0][1],y.index,!1,!0)))):f=y.create?f.insert(y.segment,y.index):f.remove(y.segment)}p.push(f.root),d.push(v),g.push(m)}return new s(p,d,g)};var n=t(\"binary-search-bounds\"),i=t(\"functional-red-black-tree\"),a=t(\"robust-orientation\"),o=t(\"./lib/order-segments\");function s(t,e,r){this.slabs=t,this.coordinates=e,this.horizontal=r}function l(t,e){return t.y-e}function c(t,e){for(var r=null;t;){var n,i,o=t.key;o[0][0]<o[1][0]?(n=o[0],i=o[1]):(n=o[1],i=o[0]);var s=a(n,i,e);if(s<0)t=t.left;else if(s>0)if(e[0]!==o[1][0])r=t,t=t.right;else{if(l=c(t.right,e))return l;t=t.left}else{if(e[0]!==o[1][0])return t;var l;if(l=c(t.right,e))return l;t=t.left}}return r}function u(t,e,r,n){this.y=t,this.index=e,this.start=r,this.closed=n}function h(t,e,r,n){this.x=t,this.segment=e,this.create=r,this.index=n}s.prototype.castUp=function(t){var e=n.le(this.coordinates,t[0]);if(e<0)return-1;this.slabs[e];var r=c(this.slabs[e],t),i=-1;if(r&&(i=r.value),this.coordinates[e]===t[0]){var s=null;if(r&&(s=r.key),e>0){var u=c(this.slabs[e-1],t);u&&(s?o(u.key,s)>0&&(s=u.key,i=u.value):(i=u.value,s=u.key))}var h=this.horizontal[e];if(h.length>0){var f=n.ge(h,t[1],l);if(f<h.length){var p=h[f];if(t[1]===p.y){if(p.closed)return p.index;for(;f<h.length-1&&h[f+1].y===t[1];)if((p=h[f+=1]).closed)return p.index;if(p.y===t[1]&&!p.start){if((f+=1)>=h.length)return i;p=h[f]}}if(p.start)if(s){var d=a(s[0],s[1],[t[0],p.y]);s[0][0]>s[1][0]&&(d=-d),d>0&&(i=p.index)}else i=p.index;else p.y!==t[1]&&(i=p.index)}}}return i}},{\"./lib/order-segments\":525,\"binary-search-bounds\":91,\"functional-red-black-tree\":230,\"robust-orientation\":510}],527:[function(t,e,r){\"use strict\";var n=t(\"robust-dot-product\"),i=t(\"robust-sum\");function a(t,e){var r=i(n(t,e),[e[e.length-1]]);return r[r.length-1]}function o(t,e,r,n){var i=-e/(n-e);i<0?i=0:i>1&&(i=1);for(var a=1-i,o=t.length,s=new Array(o),l=0;l<o;++l)s[l]=i*t[l]+a*r[l];return s}e.exports=function(t,e){for(var r=[],n=[],i=a(t[t.length-1],e),s=t[t.length-1],l=t[0],c=0;c<t.length;++c,s=l){var u=a(l=t[c],e);if(i<0&&u>0||i>0&&u<0){var h=o(s,u,l,i);r.push(h),n.push(h.slice())}u<0?n.push(l.slice()):u>0?r.push(l.slice()):(r.push(l.slice()),n.push(l.slice())),i=u}return{positive:r,negative:n}},e.exports.positive=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c>=0&&r.push(s.slice()),n=c}return r},e.exports.negative=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c<=0&&r.push(s.slice()),n=c}return r}},{\"robust-dot-product\":507,\"robust-sum\":515}],528:[function(t,e,r){!function(){\"use strict\";var t={not_string:/[^s]/,not_bool:/[^t]/,not_type:/[^T]/,not_primitive:/[^v]/,number:/[diefg]/,numeric_arg:/[bcdiefguxX]/,json:/[j]/,not_json:/[^j]/,text:/^[^\\x25]+/,modulo:/^\\x25{2}/,placeholder:/^\\x25(?:([1-9]\\d*)\\$|\\(([^)]+)\\))?(\\+)?(0|'[^$])?(-)?(\\d+)?(?:\\.(\\d+))?([b-gijostTuvxX])/,key:/^([a-z_][a-z_\\d]*)/i,key_access:/^\\.([a-z_][a-z_\\d]*)/i,index_access:/^\\[(\\d+)\\]/,sign:/^[+-]/};function e(r){return function(r,n){var i,a,o,s,l,c,u,h,f,p=1,d=r.length,g=\"\";for(a=0;a<d;a++)if(\"string\"==typeof r[a])g+=r[a];else if(\"object\"==typeof r[a]){if((s=r[a]).keys)for(i=n[p],o=0;o<s.keys.length;o++){if(null==i)throw new Error(e('[sprintf] Cannot access property \"%s\" of undefined value \"%s\"',s.keys[o],s.keys[o-1]));i=i[s.keys[o]]}else i=s.param_no?n[s.param_no]:n[p++];if(t.not_type.test(s.type)&&t.not_primitive.test(s.type)&&i instanceof Function&&(i=i()),t.numeric_arg.test(s.type)&&\"number\"!=typeof i&&isNaN(i))throw new TypeError(e(\"[sprintf] expecting number but found %T\",i));switch(t.number.test(s.type)&&(h=i>=0),s.type){case\"b\":i=parseInt(i,10).toString(2);break;case\"c\":i=String.fromCharCode(parseInt(i,10));break;case\"d\":case\"i\":i=parseInt(i,10);break;case\"j\":i=JSON.stringify(i,null,s.width?parseInt(s.width):0);break;case\"e\":i=s.precision?parseFloat(i).toExponential(s.precision):parseFloat(i).toExponential();break;case\"f\":i=s.precision?parseFloat(i).toFixed(s.precision):parseFloat(i);break;case\"g\":i=s.precision?String(Number(i.toPrecision(s.precision))):parseFloat(i);break;case\"o\":i=(parseInt(i,10)>>>0).toString(8);break;case\"s\":i=String(i),i=s.precision?i.substring(0,s.precision):i;break;case\"t\":i=String(!!i),i=s.precision?i.substring(0,s.precision):i;break;case\"T\":i=Object.prototype.toString.call(i).slice(8,-1).toLowerCase(),i=s.precision?i.substring(0,s.precision):i;break;case\"u\":i=parseInt(i,10)>>>0;break;case\"v\":i=i.valueOf(),i=s.precision?i.substring(0,s.precision):i;break;case\"x\":i=(parseInt(i,10)>>>0).toString(16);break;case\"X\":i=(parseInt(i,10)>>>0).toString(16).toUpperCase()}t.json.test(s.type)?g+=i:(!t.number.test(s.type)||h&&!s.sign?f=\"\":(f=h?\"+\":\"-\",i=i.toString().replace(t.sign,\"\")),c=s.pad_char?\"0\"===s.pad_char?\"0\":s.pad_char.charAt(1):\" \",u=s.width-(f+i).length,l=s.width&&u>0?c.repeat(u):\"\",g+=s.align?f+i+l:\"0\"===c?f+l+i:l+f+i)}return g}(function(e){if(i[e])return i[e];var r,n=e,a=[],o=0;for(;n;){if(null!==(r=t.text.exec(n)))a.push(r[0]);else if(null!==(r=t.modulo.exec(n)))a.push(\"%\");else{if(null===(r=t.placeholder.exec(n)))throw new SyntaxError(\"[sprintf] unexpected placeholder\");if(r[2]){o|=1;var s=[],l=r[2],c=[];if(null===(c=t.key.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");for(s.push(c[1]);\"\"!==(l=l.substring(c[0].length));)if(null!==(c=t.key_access.exec(l)))s.push(c[1]);else{if(null===(c=t.index_access.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");s.push(c[1])}r[2]=s}else o|=2;if(3===o)throw new Error(\"[sprintf] mixing positional and named placeholders is not (yet) supported\");a.push({placeholder:r[0],param_no:r[1],keys:r[2],sign:r[3],pad_char:r[4],align:r[5],width:r[6],precision:r[7],type:r[8]})}n=n.substring(r[0].length)}return i[e]=a}(r),arguments)}function n(t,r){return e.apply(null,[t].concat(r||[]))}var i=Object.create(null);\"undefined\"!=typeof r&&(r.sprintf=e,r.vsprintf=n),\"undefined\"!=typeof window&&(window.sprintf=e,window.vsprintf=n)}()},{}],529:[function(t,e,r){\"use strict\";var n=t(\"parenthesis\");e.exports=function(t,e,r){if(null==t)throw Error(\"First argument should be a string\");if(null==e)throw Error(\"Separator should be a string or a RegExp\");r?(\"string\"==typeof r||Array.isArray(r))&&(r={ignore:r}):r={},null==r.escape&&(r.escape=!0),null==r.ignore?r.ignore=[\"[]\",\"()\",\"{}\",\"<>\",'\"\"',\"''\",\"``\",\"\\u201c\\u201d\",\"\\xab\\xbb\"]:(\"string\"==typeof r.ignore&&(r.ignore=[r.ignore]),r.ignore=r.ignore.map(function(t){return 1===t.length&&(t+=t),t}));var i=n.parse(t,{flat:!0,brackets:r.ignore}),a=i[0].split(e);if(r.escape){for(var o=[],s=0;s<a.length;s++){var l=a[s],c=a[s+1];\"\\\\\"===l[l.length-1]&&\"\\\\\"!==l[l.length-2]?(o.push(l+e+c),s++):o.push(l)}a=o}for(s=0;s<a.length;s++)i[0]=a[s],a[s]=n.stringify(i,{flat:!0});return a}},{parenthesis:458}],530:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=new Array(e),n=new Array(e),i=new Array(e),a=new Array(e),o=new Array(e),s=new Array(e),l=0;l<e;++l)r[l]=-1,n[l]=0,i[l]=!1,a[l]=0,o[l]=-1,s[l]=[];var c,u=0,h=[],f=[];function p(e){var l=[e],c=[e];for(r[e]=n[e]=u,i[e]=!0,u+=1;c.length>0;){e=c[c.length-1];var p=t[e];if(a[e]<p.length){for(var d=a[e];d<p.length;++d){var g=p[d];if(r[g]<0){r[g]=n[g]=u,i[g]=!0,u+=1,l.push(g),c.push(g);break}i[g]&&(n[e]=0|Math.min(n[e],n[g])),o[g]>=0&&s[e].push(o[g])}a[e]=d}else{if(n[e]===r[e]){for(var v=[],m=[],y=0,d=l.length-1;d>=0;--d){var x=l[d];if(i[x]=!1,v.push(x),m.push(s[x]),y+=s[x].length,o[x]=h.length,x===e){l.length=d;break}}h.push(v);for(var b=new Array(y),d=0;d<m.length;d++)for(var _=0;_<m[d].length;_++)b[--y]=m[d][_];f.push(b)}c.pop()}}}for(var l=0;l<e;++l)r[l]<0&&p(l);for(var l=0;l<f.length;l++){var d=f[l];if(0!==d.length){d.sort(function(t,e){return t-e}),c=[d[0]];for(var g=1;g<d.length;g++)d[g]!==d[g-1]&&c.push(d[g]);f[l]=c}}return{components:h,adjacencyList:f}}},{}],531:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(t.dimension<=0)return{positions:[],cells:[]};if(1===t.dimension)return function(t,e){for(var r=a(t,e),n=r.length,i=new Array(n),o=new Array(n),s=0;s<n;++s)i[s]=[r[s]],o[s]=[s];return{positions:i,cells:o}}(t,e);var r=t.order.join()+\"-\"+t.dtype,s=o[r],e=+e||0;s||(s=o[r]=function(t,e){var r=t.length,a=[\"'use strict';\"],o=\"surfaceNets\"+t.join(\"_\")+\"d\"+e;a.push(\"var contour=genContour({\",\"order:[\",t.join(),\"],\",\"scalarArguments: 3,\",\"phase:function phaseFunc(p,a,b,c) { return (p > c)|0 },\"),\"generic\"===e&&a.push(\"getters:[0],\");for(var s=[],l=[],c=0;c<r;++c)s.push(\"d\"+c),l.push(\"d\"+c);for(var c=0;c<1<<r;++c)s.push(\"v\"+c),l.push(\"v\"+c);for(var c=0;c<1<<r;++c)s.push(\"p\"+c),l.push(\"p\"+c);s.push(\"a\",\"b\",\"c\"),l.push(\"a\",\"c\"),a.push(\"vertex:function vertexFunc(\",s.join(),\"){\");for(var u=[],c=0;c<1<<r;++c)u.push(\"(p\"+c+\"<<\"+c+\")\");a.push(\"var m=(\",u.join(\"+\"),\")|0;if(m===0||m===\",(1<<(1<<r))-1,\"){return}\");var h=[],f=[];1<<(1<<r)<=128?(a.push(\"switch(m){\"),f=a):a.push(\"switch(m>>>7){\");for(var c=0;c<1<<(1<<r);++c){if(1<<(1<<r)>128&&c%128==0){h.length>0&&f.push(\"}}\");var p=\"vExtra\"+h.length;a.push(\"case \",c>>>7,\":\",p,\"(m&0x7f,\",l.join(),\");break;\"),f=[\"function \",p,\"(m,\",l.join(),\"){switch(m){\"],h.push(f)}f.push(\"case \",127&c,\":\");for(var d=new Array(r),g=new Array(r),v=new Array(r),m=new Array(r),y=0,x=0;x<r;++x)d[x]=[],g[x]=[],v[x]=0,m[x]=0;for(var x=0;x<1<<r;++x)for(var b=0;b<r;++b){var _=x^1<<b;if(!(_>x)&&!(c&1<<_)!=!(c&1<<x)){var w=1;c&1<<_?g[b].push(\"v\"+_+\"-v\"+x):(g[b].push(\"v\"+x+\"-v\"+_),w=-w),w<0?(d[b].push(\"-v\"+x+\"-v\"+_),v[b]+=2):(d[b].push(\"v\"+x+\"+v\"+_),v[b]-=2),y+=1;for(var k=0;k<r;++k)k!==b&&(_&1<<k?m[k]+=1:m[k]-=1)}}for(var T=[],b=0;b<r;++b)if(0===d[b].length)T.push(\"d\"+b+\"-0.5\");else{var A=\"\";v[b]<0?A=v[b]+\"*c\":v[b]>0&&(A=\"+\"+v[b]+\"*c\");var M=d[b].length/y*.5,S=.5+m[b]/y*.5;T.push(\"d\"+b+\"-\"+S+\"-\"+M+\"*(\"+d[b].join(\"+\")+A+\")/(\"+g[b].join(\"+\")+\")\")}f.push(\"a.push([\",T.join(),\"]);\",\"break;\")}a.push(\"}},\"),h.length>0&&f.push(\"}}\");for(var E=[],c=0;c<1<<r-1;++c)E.push(\"v\"+c);E.push(\"c0\",\"c1\",\"p0\",\"p1\",\"a\",\"b\",\"c\"),a.push(\"cell:function cellFunc(\",E.join(),\"){\");var C=i(r-1);a.push(\"if(p0){b.push(\",C.map(function(t){return\"[\"+t.map(function(t){return\"v\"+t})+\"]\"}).join(),\")}else{b.push(\",C.map(function(t){var e=t.slice();return e.reverse(),\"[\"+e.map(function(t){return\"v\"+t})+\"]\"}).join(),\")}}});function \",o,\"(array,level){var verts=[],cells=[];contour(array,verts,cells,level);return {positions:verts,cells:cells};} return \",o,\";\");for(var c=0;c<h.length;++c)a.push(h[c].join(\"\"));return new Function(\"genContour\",a.join(\"\"))(n)}(t.order,t.dtype));return s(t,e)};var n=t(\"ndarray-extract-contour\"),i=t(\"triangulate-hypercube\"),a=t(\"zero-crossings\");var o={}},{\"ndarray-extract-contour\":439,\"triangulate-hypercube\":541,\"zero-crossings\":574}],532:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=function(){return function(t,e){if(Array.isArray(t))return t;if(Symbol.iterator in Object(t))return function(t,e){var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{!n&&s.return&&s.return()}finally{if(i)throw a}}return r}(t,e);throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")}}(),i=2*Math.PI,a=function(t,e,r,n,i,a,o){var s=t.x,l=t.y;return{x:n*(s*=e)-i*(l*=r)+a,y:i*s+n*l+o}},o=function(t,e){var r=.551915024494*(e<0?-1:1),n=Math.cos(t),i=Math.sin(t),a=Math.cos(t+e),o=Math.sin(t+e);return[{x:n-i*r,y:i+n*r},{x:a+o*r,y:o-a*r},{x:a,y:o}]},s=function(t,e,r,n){var i=t*n-e*r<0?-1:1,a=(t*r+e*n)/(Math.sqrt(t*t+e*e)*Math.sqrt(t*t+e*e));return a>1&&(a=1),a<-1&&(a=-1),i*Math.acos(a)};r.default=function(t){var e=t.px,r=t.py,l=t.cx,c=t.cy,u=t.rx,h=t.ry,f=t.xAxisRotation,p=void 0===f?0:f,d=t.largeArcFlag,g=void 0===d?0:d,v=t.sweepFlag,m=void 0===v?0:v,y=[];if(0===u||0===h)return[];var x=Math.sin(p*i/360),b=Math.cos(p*i/360),_=b*(e-l)/2+x*(r-c)/2,w=-x*(e-l)/2+b*(r-c)/2;if(0===_&&0===w)return[];u=Math.abs(u),h=Math.abs(h);var k=Math.pow(_,2)/Math.pow(u,2)+Math.pow(w,2)/Math.pow(h,2);k>1&&(u*=Math.sqrt(k),h*=Math.sqrt(k));var T=function(t,e,r,n,a,o,l,c,u,h,f,p){var d=Math.pow(a,2),g=Math.pow(o,2),v=Math.pow(f,2),m=Math.pow(p,2),y=d*g-d*m-g*v;y<0&&(y=0),y/=d*m+g*v;var x=(y=Math.sqrt(y)*(l===c?-1:1))*a/o*p,b=y*-o/a*f,_=h*x-u*b+(t+r)/2,w=u*x+h*b+(e+n)/2,k=(f-x)/a,T=(p-b)/o,A=(-f-x)/a,M=(-p-b)/o,S=s(1,0,k,T),E=s(k,T,A,M);return 0===c&&E>0&&(E-=i),1===c&&E<0&&(E+=i),[_,w,S,E]}(e,r,l,c,u,h,g,m,x,b,_,w),A=n(T,4),M=A[0],S=A[1],E=A[2],C=A[3],L=Math.abs(C)/(i/4);Math.abs(1-L)<1e-7&&(L=1);var P=Math.max(Math.ceil(L),1);C/=P;for(var O=0;O<P;O++)y.push(o(E,C)),E+=C;return y.map(function(t){var e=a(t[0],u,h,b,x,M,S),r=e.x,n=e.y,i=a(t[1],u,h,b,x,M,S),o=i.x,s=i.y,l=a(t[2],u,h,b,x,M,S);return{x1:r,y1:n,x2:o,y2:s,x:l.x,y:l.y}})},e.exports=r.default},{}],533:[function(t,e,r){\"use strict\";var n=t(\"parse-svg-path\"),i=t(\"abs-svg-path\"),a=t(\"normalize-svg-path\"),o=t(\"is-svg-path\"),s=t(\"assert\");e.exports=function(t){Array.isArray(t)&&1===t.length&&\"string\"==typeof t[0]&&(t=t[0]);\"string\"==typeof t&&(s(o(t),\"String is not an SVG path.\"),t=n(t));if(s(Array.isArray(t),\"Argument should be a string or an array of path segments.\"),t=i(t),!(t=a(t)).length)return[0,0,0,0];for(var e=[1/0,1/0,-1/0,-1/0],r=0,l=t.length;r<l;r++)for(var c=t[r].slice(1),u=0;u<c.length;u+=2)c[u+0]<e[0]&&(e[0]=c[u+0]),c[u+1]<e[1]&&(e[1]=c[u+1]),c[u+0]>e[2]&&(e[2]=c[u+0]),c[u+1]>e[3]&&(e[3]=c[u+1]);return e}},{\"abs-svg-path\":60,assert:68,\"is-svg-path\":424,\"normalize-svg-path\":534,\"parse-svg-path\":460}],534:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=[],o=0,s=0,l=0,c=0,u=null,h=null,f=0,p=0,d=0,g=t.length;d<g;d++){var v=t[d],m=v[0];switch(m){case\"M\":l=v[1],c=v[2];break;case\"A\":var y=n({px:f,py:p,cx:v[6],cy:v[7],rx:v[1],ry:v[2],xAxisRotation:v[3],largeArcFlag:v[4],sweepFlag:v[5]});if(!y.length)continue;for(var x,b=0;b<y.length;b++)x=y[b],v=[\"C\",x.x1,x.y1,x.x2,x.y2,x.x,x.y],b<y.length-1&&r.push(v);break;case\"S\":var _=f,w=p;\"C\"!=e&&\"S\"!=e||(_+=_-o,w+=w-s),v=[\"C\",_,w,v[1],v[2],v[3],v[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(u=2*f-u,h=2*p-h):(u=f,h=p),v=a(f,p,u,h,v[1],v[2]);break;case\"Q\":u=v[1],h=v[2],v=a(f,p,v[1],v[2],v[3],v[4]);break;case\"L\":v=i(f,p,v[1],v[2]);break;case\"H\":v=i(f,p,v[1],p);break;case\"V\":v=i(f,p,f,v[1]);break;case\"Z\":v=i(f,p,l,c)}e=m,f=v[v.length-2],p=v[v.length-1],v.length>4?(o=v[v.length-4],s=v[v.length-3]):(o=f,s=p),r.push(v)}return r};var n=t(\"svg-arc-to-cubic-bezier\");function i(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function a(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}},{\"svg-arc-to-cubic-bezier\":532}],535:[function(t,e,r){\"use strict\";var n,i=t(\"svg-path-bounds\"),a=t(\"parse-svg-path\"),o=t(\"draw-svg-path\"),s=t(\"is-svg-path\"),l=t(\"bitmap-sdf\"),c=document.createElement(\"canvas\"),u=c.getContext(\"2d\");e.exports=function(t,e){if(!s(t))throw Error(\"Argument should be valid svg path string\");e||(e={});var r,h;e.shape?(r=e.shape[0],h=e.shape[1]):(r=c.width=e.w||e.width||200,h=c.height=e.h||e.height||200);var f=Math.min(r,h),p=e.stroke||0,d=e.viewbox||e.viewBox||i(t),g=[r/(d[2]-d[0]),h/(d[3]-d[1])],v=Math.min(g[0]||0,g[1]||0)/2;u.fillStyle=\"black\",u.fillRect(0,0,r,h),u.fillStyle=\"white\",p&&(\"number\"!=typeof p&&(p=1),u.strokeStyle=p>0?\"white\":\"black\",u.lineWidth=Math.abs(p));if(u.translate(.5*r,.5*h),u.scale(v,v),function(){if(null!=n)return n;var t=document.createElement(\"canvas\").getContext(\"2d\");if(t.canvas.width=t.canvas.height=1,!window.Path2D)return n=!1;var e=new Path2D(\"M0,0h1v1h-1v-1Z\");t.fillStyle=\"black\",t.fill(e);var r=t.getImageData(0,0,1,1);return n=r&&r.data&&255===r.data[3]}()){var m=new Path2D(t);u.fill(m),p&&u.stroke(m)}else{var y=a(t);o(u,y),u.fill(),p&&u.stroke()}return u.setTransform(1,0,0,1,0,0),l(u,{cutoff:null!=e.cutoff?e.cutoff:.5,radius:null!=e.radius?e.radius:.5*f})}},{\"bitmap-sdf\":93,\"draw-svg-path\":168,\"is-svg-path\":424,\"parse-svg-path\":460,\"svg-path-bounds\":533}],536:[function(t,e,r){(function(r){\"use strict\";e.exports=function t(e,r,i){var i=i||{};var o=a[e];o||(o=a[e]={\" \":{data:new Float32Array(0),shape:.2}});var s=o[r];if(!s)if(r.length<=1||!/\\d/.test(r))s=o[r]=function(t){for(var e=t.cells,r=t.positions,n=new Float32Array(6*e.length),i=0,a=0,o=0;o<e.length;++o)for(var s=e[o],l=0;l<3;++l){var c=r[s[l]];n[i++]=c[0],n[i++]=c[1]+1.4,a=Math.max(c[0],a)}return{data:n,shape:a}}(n(r,{triangles:!0,font:e,textAlign:i.textAlign||\"left\",textBaseline:\"alphabetic\",styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0}}));else{for(var l=r.split(/(\\d|\\s)/),c=new Array(l.length),u=0,h=0,f=0;f<l.length;++f)c[f]=t(e,l[f]),u+=c[f].data.length,h+=c[f].shape,f>0&&(h+=.02);for(var p=new Float32Array(u),d=0,g=-.5*h,f=0;f<c.length;++f){for(var v=c[f].data,m=0;m<v.length;m+=2)p[d++]=v[m]+g,p[d++]=v[m+1];g+=c[f].shape+.02}s=o[r]={data:p,shape:h}}return s};var n=t(\"vectorize-text\"),i=window||r.global||{},a=i.__TEXT_CACHE||{};i.__TEXT_CACHE={}}).call(this,t(\"_process\"))},{_process:482,\"vectorize-text\":550}],537:[function(t,e,r){!function(t){var r=/^\\s+/,n=/\\s+$/,i=0,a=t.round,o=t.min,s=t.max,l=t.random;function c(e,l){if(l=l||{},(e=e||\"\")instanceof c)return e;if(!(this instanceof c))return new c(e,l);var u=function(e){var i={r:0,g:0,b:0},a=1,l=null,c=null,u=null,h=!1,f=!1;\"string\"==typeof e&&(e=function(t){t=t.replace(r,\"\").replace(n,\"\").toLowerCase();var e,i=!1;if(S[t])t=S[t],i=!0;else if(\"transparent\"==t)return{r:0,g:0,b:0,a:0,format:\"name\"};if(e=j.rgb.exec(t))return{r:e[1],g:e[2],b:e[3]};if(e=j.rgba.exec(t))return{r:e[1],g:e[2],b:e[3],a:e[4]};if(e=j.hsl.exec(t))return{h:e[1],s:e[2],l:e[3]};if(e=j.hsla.exec(t))return{h:e[1],s:e[2],l:e[3],a:e[4]};if(e=j.hsv.exec(t))return{h:e[1],s:e[2],v:e[3]};if(e=j.hsva.exec(t))return{h:e[1],s:e[2],v:e[3],a:e[4]};if(e=j.hex8.exec(t))return{r:O(e[1]),g:O(e[2]),b:O(e[3]),a:R(e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex6.exec(t))return{r:O(e[1]),g:O(e[2]),b:O(e[3]),format:i?\"name\":\"hex\"};if(e=j.hex4.exec(t))return{r:O(e[1]+\"\"+e[1]),g:O(e[2]+\"\"+e[2]),b:O(e[3]+\"\"+e[3]),a:R(e[4]+\"\"+e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex3.exec(t))return{r:O(e[1]+\"\"+e[1]),g:O(e[2]+\"\"+e[2]),b:O(e[3]+\"\"+e[3]),format:i?\"name\":\"hex\"};return!1}(e));\"object\"==typeof e&&(U(e.r)&&U(e.g)&&U(e.b)?(p=e.r,d=e.g,g=e.b,i={r:255*L(p,255),g:255*L(d,255),b:255*L(g,255)},h=!0,f=\"%\"===String(e.r).substr(-1)?\"prgb\":\"rgb\"):U(e.h)&&U(e.s)&&U(e.v)?(l=I(e.s),c=I(e.v),i=function(e,r,n){e=6*L(e,360),r=L(r,100),n=L(n,100);var i=t.floor(e),a=e-i,o=n*(1-r),s=n*(1-a*r),l=n*(1-(1-a)*r),c=i%6;return{r:255*[n,s,o,o,l,n][c],g:255*[l,n,n,s,o,o][c],b:255*[o,o,l,n,n,s][c]}}(e.h,l,c),h=!0,f=\"hsv\"):U(e.h)&&U(e.s)&&U(e.l)&&(l=I(e.s),u=I(e.l),i=function(t,e,r){var n,i,a;function o(t,e,r){return r<0&&(r+=1),r>1&&(r-=1),r<1/6?t+6*(e-t)*r:r<.5?e:r<2/3?t+(e-t)*(2/3-r)*6:t}if(t=L(t,360),e=L(e,100),r=L(r,100),0===e)n=i=a=r;else{var s=r<.5?r*(1+e):r+e-r*e,l=2*r-s;n=o(l,s,t+1/3),i=o(l,s,t),a=o(l,s,t-1/3)}return{r:255*n,g:255*i,b:255*a}}(e.h,l,u),h=!0,f=\"hsl\"),e.hasOwnProperty(\"a\")&&(a=e.a));var p,d,g;return a=C(a),{ok:h,format:e.format||f,r:o(255,s(i.r,0)),g:o(255,s(i.g,0)),b:o(255,s(i.b,0)),a:a}}(e);this._originalInput=e,this._r=u.r,this._g=u.g,this._b=u.b,this._a=u.a,this._roundA=a(100*this._a)/100,this._format=l.format||u.format,this._gradientType=l.gradientType,this._r<1&&(this._r=a(this._r)),this._g<1&&(this._g=a(this._g)),this._b<1&&(this._b=a(this._b)),this._ok=u.ok,this._tc_id=i++}function u(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=(a+l)/2;if(a==l)n=i=0;else{var u=a-l;switch(i=c>.5?u/(2-a-l):u/(a+l),a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,l:c}}function h(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=a,u=a-l;if(i=0===a?0:u/a,a==l)n=0;else{switch(a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,v:c}}function f(t,e,r,n){var i=[z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16))];return n&&i[0].charAt(0)==i[0].charAt(1)&&i[1].charAt(0)==i[1].charAt(1)&&i[2].charAt(0)==i[2].charAt(1)?i[0].charAt(0)+i[1].charAt(0)+i[2].charAt(0):i.join(\"\")}function p(t,e,r,n){return[z(D(n)),z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16))].join(\"\")}function d(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s-=e/100,r.s=P(r.s),c(r)}function g(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s+=e/100,r.s=P(r.s),c(r)}function v(t){return c(t).desaturate(100)}function m(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l+=e/100,r.l=P(r.l),c(r)}function y(t,e){e=0===e?0:e||10;var r=c(t).toRgb();return r.r=s(0,o(255,r.r-a(-e/100*255))),r.g=s(0,o(255,r.g-a(-e/100*255))),r.b=s(0,o(255,r.b-a(-e/100*255))),c(r)}function x(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l-=e/100,r.l=P(r.l),c(r)}function b(t,e){var r=c(t).toHsl(),n=(r.h+e)%360;return r.h=n<0?360+n:n,c(r)}function _(t){var e=c(t).toHsl();return e.h=(e.h+180)%360,c(e)}function w(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+120)%360,s:e.s,l:e.l}),c({h:(r+240)%360,s:e.s,l:e.l})]}function k(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+90)%360,s:e.s,l:e.l}),c({h:(r+180)%360,s:e.s,l:e.l}),c({h:(r+270)%360,s:e.s,l:e.l})]}function T(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+72)%360,s:e.s,l:e.l}),c({h:(r+216)%360,s:e.s,l:e.l})]}function A(t,e,r){e=e||6,r=r||30;var n=c(t).toHsl(),i=360/r,a=[c(t)];for(n.h=(n.h-(i*e>>1)+720)%360;--e;)n.h=(n.h+i)%360,a.push(c(n));return a}function M(t,e){e=e||6;for(var r=c(t).toHsv(),n=r.h,i=r.s,a=r.v,o=[],s=1/e;e--;)o.push(c({h:n,s:i,v:a})),a=(a+s)%1;return o}c.prototype={isDark:function(){return this.getBrightness()<128},isLight:function(){return!this.isDark()},isValid:function(){return this._ok},getOriginalInput:function(){return this._originalInput},getFormat:function(){return this._format},getAlpha:function(){return this._a},getBrightness:function(){var t=this.toRgb();return(299*t.r+587*t.g+114*t.b)/1e3},getLuminance:function(){var e,r,n,i=this.toRgb();return e=i.r/255,r=i.g/255,n=i.b/255,.2126*(e<=.03928?e/12.92:t.pow((e+.055)/1.055,2.4))+.7152*(r<=.03928?r/12.92:t.pow((r+.055)/1.055,2.4))+.0722*(n<=.03928?n/12.92:t.pow((n+.055)/1.055,2.4))},setAlpha:function(t){return this._a=C(t),this._roundA=a(100*this._a)/100,this},toHsv:function(){var t=h(this._r,this._g,this._b);return{h:360*t.h,s:t.s,v:t.v,a:this._a}},toHsvString:function(){var t=h(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.v);return 1==this._a?\"hsv(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsva(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHsl:function(){var t=u(this._r,this._g,this._b);return{h:360*t.h,s:t.s,l:t.l,a:this._a}},toHslString:function(){var t=u(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.l);return 1==this._a?\"hsl(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsla(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHex:function(t){return f(this._r,this._g,this._b,t)},toHexString:function(t){return\"#\"+this.toHex(t)},toHex8:function(t){return function(t,e,r,n,i){var o=[z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16)),z(D(n))];if(i&&o[0].charAt(0)==o[0].charAt(1)&&o[1].charAt(0)==o[1].charAt(1)&&o[2].charAt(0)==o[2].charAt(1)&&o[3].charAt(0)==o[3].charAt(1))return o[0].charAt(0)+o[1].charAt(0)+o[2].charAt(0)+o[3].charAt(0);return o.join(\"\")}(this._r,this._g,this._b,this._a,t)},toHex8String:function(t){return\"#\"+this.toHex8(t)},toRgb:function(){return{r:a(this._r),g:a(this._g),b:a(this._b),a:this._a}},toRgbString:function(){return 1==this._a?\"rgb(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\")\":\"rgba(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\", \"+this._roundA+\")\"},toPercentageRgb:function(){return{r:a(100*L(this._r,255))+\"%\",g:a(100*L(this._g,255))+\"%\",b:a(100*L(this._b,255))+\"%\",a:this._a}},toPercentageRgbString:function(){return 1==this._a?\"rgb(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%)\":\"rgba(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%, \"+this._roundA+\")\"},toName:function(){return 0===this._a?\"transparent\":!(this._a<1)&&(E[f(this._r,this._g,this._b,!0)]||!1)},toFilter:function(t){var e=\"#\"+p(this._r,this._g,this._b,this._a),r=e,n=this._gradientType?\"GradientType = 1, \":\"\";if(t){var i=c(t);r=\"#\"+p(i._r,i._g,i._b,i._a)}return\"progid:DXImageTransform.Microsoft.gradient(\"+n+\"startColorstr=\"+e+\",endColorstr=\"+r+\")\"},toString:function(t){var e=!!t;t=t||this._format;var r=!1,n=this._a<1&&this._a>=0;return e||!n||\"hex\"!==t&&\"hex6\"!==t&&\"hex3\"!==t&&\"hex4\"!==t&&\"hex8\"!==t&&\"name\"!==t?(\"rgb\"===t&&(r=this.toRgbString()),\"prgb\"===t&&(r=this.toPercentageRgbString()),\"hex\"!==t&&\"hex6\"!==t||(r=this.toHexString()),\"hex3\"===t&&(r=this.toHexString(!0)),\"hex4\"===t&&(r=this.toHex8String(!0)),\"hex8\"===t&&(r=this.toHex8String()),\"name\"===t&&(r=this.toName()),\"hsl\"===t&&(r=this.toHslString()),\"hsv\"===t&&(r=this.toHsvString()),r||this.toHexString()):\"name\"===t&&0===this._a?this.toName():this.toRgbString()},clone:function(){return c(this.toString())},_applyModification:function(t,e){var r=t.apply(null,[this].concat([].slice.call(e)));return this._r=r._r,this._g=r._g,this._b=r._b,this.setAlpha(r._a),this},lighten:function(){return this._applyModification(m,arguments)},brighten:function(){return this._applyModification(y,arguments)},darken:function(){return this._applyModification(x,arguments)},desaturate:function(){return this._applyModification(d,arguments)},saturate:function(){return this._applyModification(g,arguments)},greyscale:function(){return this._applyModification(v,arguments)},spin:function(){return this._applyModification(b,arguments)},_applyCombination:function(t,e){return t.apply(null,[this].concat([].slice.call(e)))},analogous:function(){return this._applyCombination(A,arguments)},complement:function(){return this._applyCombination(_,arguments)},monochromatic:function(){return this._applyCombination(M,arguments)},splitcomplement:function(){return this._applyCombination(T,arguments)},triad:function(){return this._applyCombination(w,arguments)},tetrad:function(){return this._applyCombination(k,arguments)}},c.fromRatio=function(t,e){if(\"object\"==typeof t){var r={};for(var n in t)t.hasOwnProperty(n)&&(r[n]=\"a\"===n?t[n]:I(t[n]));t=r}return c(t,e)},c.equals=function(t,e){return!(!t||!e)&&c(t).toRgbString()==c(e).toRgbString()},c.random=function(){return c.fromRatio({r:l(),g:l(),b:l()})},c.mix=function(t,e,r){r=0===r?0:r||50;var n=c(t).toRgb(),i=c(e).toRgb(),a=r/100;return c({r:(i.r-n.r)*a+n.r,g:(i.g-n.g)*a+n.g,b:(i.b-n.b)*a+n.b,a:(i.a-n.a)*a+n.a})},c.readability=function(e,r){var n=c(e),i=c(r);return(t.max(n.getLuminance(),i.getLuminance())+.05)/(t.min(n.getLuminance(),i.getLuminance())+.05)},c.isReadable=function(t,e,r){var n,i,a=c.readability(t,e);switch(i=!1,(n=function(t){var e,r;e=((t=t||{level:\"AA\",size:\"small\"}).level||\"AA\").toUpperCase(),r=(t.size||\"small\").toLowerCase(),\"AA\"!==e&&\"AAA\"!==e&&(e=\"AA\");\"small\"!==r&&\"large\"!==r&&(r=\"small\");return{level:e,size:r}}(r)).level+n.size){case\"AAsmall\":case\"AAAlarge\":i=a>=4.5;break;case\"AAlarge\":i=a>=3;break;case\"AAAsmall\":i=a>=7}return i},c.mostReadable=function(t,e,r){var n,i,a,o,s=null,l=0;i=(r=r||{}).includeFallbackColors,a=r.level,o=r.size;for(var u=0;u<e.length;u++)(n=c.readability(t,e[u]))>l&&(l=n,s=c(e[u]));return c.isReadable(t,s,{level:a,size:o})||!i?s:(r.includeFallbackColors=!1,c.mostReadable(t,[\"#fff\",\"#000\"],r))};var S=c.names={aliceblue:\"f0f8ff\",antiquewhite:\"faebd7\",aqua:\"0ff\",aquamarine:\"7fffd4\",azure:\"f0ffff\",beige:\"f5f5dc\",bisque:\"ffe4c4\",black:\"000\",blanchedalmond:\"ffebcd\",blue:\"00f\",blueviolet:\"8a2be2\",brown:\"a52a2a\",burlywood:\"deb887\",burntsienna:\"ea7e5d\",cadetblue:\"5f9ea0\",chartreuse:\"7fff00\",chocolate:\"d2691e\",coral:\"ff7f50\",cornflowerblue:\"6495ed\",cornsilk:\"fff8dc\",crimson:\"dc143c\",cyan:\"0ff\",darkblue:\"00008b\",darkcyan:\"008b8b\",darkgoldenrod:\"b8860b\",darkgray:\"a9a9a9\",darkgreen:\"006400\",darkgrey:\"a9a9a9\",darkkhaki:\"bdb76b\",darkmagenta:\"8b008b\",darkolivegreen:\"556b2f\",darkorange:\"ff8c00\",darkorchid:\"9932cc\",darkred:\"8b0000\",darksalmon:\"e9967a\",darkseagreen:\"8fbc8f\",darkslateblue:\"483d8b\",darkslategray:\"2f4f4f\",darkslategrey:\"2f4f4f\",darkturquoise:\"00ced1\",darkviolet:\"9400d3\",deeppink:\"ff1493\",deepskyblue:\"00bfff\",dimgray:\"696969\",dimgrey:\"696969\",dodgerblue:\"1e90ff\",firebrick:\"b22222\",floralwhite:\"fffaf0\",forestgreen:\"228b22\",fuchsia:\"f0f\",gainsboro:\"dcdcdc\",ghostwhite:\"f8f8ff\",gold:\"ffd700\",goldenrod:\"daa520\",gray:\"808080\",green:\"008000\",greenyellow:\"adff2f\",grey:\"808080\",honeydew:\"f0fff0\",hotpink:\"ff69b4\",indianred:\"cd5c5c\",indigo:\"4b0082\",ivory:\"fffff0\",khaki:\"f0e68c\",lavender:\"e6e6fa\",lavenderblush:\"fff0f5\",lawngreen:\"7cfc00\",lemonchiffon:\"fffacd\",lightblue:\"add8e6\",lightcoral:\"f08080\",lightcyan:\"e0ffff\",lightgoldenrodyellow:\"fafad2\",lightgray:\"d3d3d3\",lightgreen:\"90ee90\",lightgrey:\"d3d3d3\",lightpink:\"ffb6c1\",lightsalmon:\"ffa07a\",lightseagreen:\"20b2aa\",lightskyblue:\"87cefa\",lightslategray:\"789\",lightslategrey:\"789\",lightsteelblue:\"b0c4de\",lightyellow:\"ffffe0\",lime:\"0f0\",limegreen:\"32cd32\",linen:\"faf0e6\",magenta:\"f0f\",maroon:\"800000\",mediumaquamarine:\"66cdaa\",mediumblue:\"0000cd\",mediumorchid:\"ba55d3\",mediumpurple:\"9370db\",mediumseagreen:\"3cb371\",mediumslateblue:\"7b68ee\",mediumspringgreen:\"00fa9a\",mediumturquoise:\"48d1cc\",mediumvioletred:\"c71585\",midnightblue:\"191970\",mintcream:\"f5fffa\",mistyrose:\"ffe4e1\",moccasin:\"ffe4b5\",navajowhite:\"ffdead\",navy:\"000080\",oldlace:\"fdf5e6\",olive:\"808000\",olivedrab:\"6b8e23\",orange:\"ffa500\",orangered:\"ff4500\",orchid:\"da70d6\",palegoldenrod:\"eee8aa\",palegreen:\"98fb98\",paleturquoise:\"afeeee\",palevioletred:\"db7093\",papayawhip:\"ffefd5\",peachpuff:\"ffdab9\",peru:\"cd853f\",pink:\"ffc0cb\",plum:\"dda0dd\",powderblue:\"b0e0e6\",purple:\"800080\",rebeccapurple:\"663399\",red:\"f00\",rosybrown:\"bc8f8f\",royalblue:\"4169e1\",saddlebrown:\"8b4513\",salmon:\"fa8072\",sandybrown:\"f4a460\",seagreen:\"2e8b57\",seashell:\"fff5ee\",sienna:\"a0522d\",silver:\"c0c0c0\",skyblue:\"87ceeb\",slateblue:\"6a5acd\",slategray:\"708090\",slategrey:\"708090\",snow:\"fffafa\",springgreen:\"00ff7f\",steelblue:\"4682b4\",tan:\"d2b48c\",teal:\"008080\",thistle:\"d8bfd8\",tomato:\"ff6347\",turquoise:\"40e0d0\",violet:\"ee82ee\",wheat:\"f5deb3\",white:\"fff\",whitesmoke:\"f5f5f5\",yellow:\"ff0\",yellowgreen:\"9acd32\"},E=c.hexNames=function(t){var e={};for(var r in t)t.hasOwnProperty(r)&&(e[t[r]]=r);return e}(S);function C(t){return t=parseFloat(t),(isNaN(t)||t<0||t>1)&&(t=1),t}function L(e,r){(function(t){return\"string\"==typeof t&&-1!=t.indexOf(\".\")&&1===parseFloat(t)})(e)&&(e=\"100%\");var n=function(t){return\"string\"==typeof t&&-1!=t.indexOf(\"%\")}(e);return e=o(r,s(0,parseFloat(e))),n&&(e=parseInt(e*r,10)/100),t.abs(e-r)<1e-6?1:e%r/parseFloat(r)}function P(t){return o(1,s(0,t))}function O(t){return parseInt(t,16)}function z(t){return 1==t.length?\"0\"+t:\"\"+t}function I(t){return t<=1&&(t=100*t+\"%\"),t}function D(e){return t.round(255*parseFloat(e)).toString(16)}function R(t){return O(t)/255}var F,B,N,j=(B=\"[\\\\s|\\\\(]+(\"+(F=\"(?:[-\\\\+]?\\\\d*\\\\.\\\\d+%?)|(?:[-\\\\+]?\\\\d+%?)\")+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",N=\"[\\\\s|\\\\(]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",{CSS_UNIT:new RegExp(F),rgb:new RegExp(\"rgb\"+B),rgba:new RegExp(\"rgba\"+N),hsl:new RegExp(\"hsl\"+B),hsla:new RegExp(\"hsla\"+N),hsv:new RegExp(\"hsv\"+B),hsva:new RegExp(\"hsva\"+N),hex3:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex6:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/,hex4:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex8:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/});function U(t){return!!j.CSS_UNIT.exec(t)}\"undefined\"!=typeof e&&e.exports?e.exports=c:window.tinycolor=c}(Math)},{}],538:[function(t,e,r){\"use strict\";e.exports=i,e.exports.float32=e.exports.float=i,e.exports.fract32=e.exports.fract=function(t){if(t.length){for(var e=i(t),r=0,n=e.length;r<n;r++)e[r]=t[r]-e[r];return e}return i(t-i(t))};var n=new Float32Array(1);function i(t){if(t.length){if(t instanceof Float32Array)return t;var e=new Float32Array(t);return e.set(t),e}return n[0]=t,n[0]}},{}],539:[function(t,e,r){\"use strict\";var n=t(\"parse-unit\");e.exports=o;var i=96;function a(t,e){var r=n(getComputedStyle(t).getPropertyValue(e));return r[0]*o(r[1],t)}function o(t,e){switch(e=e||document.body,t=(t||\"px\").trim().toLowerCase(),e!==window&&e!==document||(e=document.body),t){case\"%\":return e.clientHeight/100;case\"ch\":case\"ex\":return function(t,e){var r=document.createElement(\"div\");r.style[\"font-size\"]=\"128\"+t,e.appendChild(r);var n=a(r,\"font-size\")/128;return e.removeChild(r),n}(t,e);case\"em\":return a(e,\"font-size\");case\"rem\":return a(document.body,\"font-size\");case\"vw\":return window.innerWidth/100;case\"vh\":return window.innerHeight/100;case\"vmin\":return Math.min(window.innerWidth,window.innerHeight)/100;case\"vmax\":return Math.max(window.innerWidth,window.innerHeight)/100;case\"in\":return i;case\"cm\":return i/2.54;case\"mm\":return i/25.4;case\"pt\":return i/72;case\"pc\":return i/6}return 1}},{\"parse-unit\":461}],540:[function(t,e,r){var n;n=this,function(t){\"use strict\";var e=function(t){return t},r=function(t){if(null==(r=t.transform))return e;var r,n,i,a=r.scale[0],o=r.scale[1],s=r.translate[0],l=r.translate[1];return function(t,e){return e||(n=i=0),t[0]=(n+=t[0])*a+s,t[1]=(i+=t[1])*o+l,t}},n=function(t){var e=t.bbox;function n(t){l[0]=t[0],l[1]=t[1],s(l),l[0]<c&&(c=l[0]),l[0]>h&&(h=l[0]),l[1]<u&&(u=l[1]),l[1]>f&&(f=l[1])}function i(t){switch(t.type){case\"GeometryCollection\":t.geometries.forEach(i);break;case\"Point\":n(t.coordinates);break;case\"MultiPoint\":t.coordinates.forEach(n)}}if(!e){var a,o,s=r(t),l=new Array(2),c=1/0,u=c,h=-c,f=-c;for(o in t.arcs.forEach(function(t){for(var e=-1,r=t.length;++e<r;)a=t[e],l[0]=a[0],l[1]=a[1],s(l,e),l[0]<c&&(c=l[0]),l[0]>h&&(h=l[0]),l[1]<u&&(u=l[1]),l[1]>f&&(f=l[1])}),t.objects)i(t.objects[o]);e=t.bbox=[c,u,h,f]}return e},i=function(t,e){for(var r,n=t.length,i=n-e;i<--n;)r=t[i],t[i++]=t[n],t[n]=r};function a(t,e){var r=e.id,n=e.bbox,i=null==e.properties?{}:e.properties,a=o(t,e);return null==r&&null==n?{type:\"Feature\",properties:i,geometry:a}:null==n?{type:\"Feature\",id:r,properties:i,geometry:a}:{type:\"Feature\",id:r,bbox:n,properties:i,geometry:a}}function o(t,e){var n=r(t),a=t.arcs;function o(t,e){e.length&&e.pop();for(var r=a[t<0?~t:t],o=0,s=r.length;o<s;++o)e.push(n(r[o].slice(),o));t<0&&i(e,s)}function s(t){return n(t.slice())}function l(t){for(var e=[],r=0,n=t.length;r<n;++r)o(t[r],e);return e.length<2&&e.push(e[0].slice()),e}function c(t){for(var e=l(t);e.length<4;)e.push(e[0].slice());return e}function u(t){return t.map(c)}return function t(e){var r,n=e.type;switch(n){case\"GeometryCollection\":return{type:n,geometries:e.geometries.map(t)};case\"Point\":r=s(e.coordinates);break;case\"MultiPoint\":r=e.coordinates.map(s);break;case\"LineString\":r=l(e.arcs);break;case\"MultiLineString\":r=e.arcs.map(l);break;case\"Polygon\":r=u(e.arcs);break;case\"MultiPolygon\":r=e.arcs.map(u);break;default:return null}return{type:n,coordinates:r}}(e)}var s=function(t,e){var r={},n={},i={},a=[],o=-1;function s(t,e){for(var n in t){var i=t[n];delete e[i.start],delete i.start,delete i.end,i.forEach(function(t){r[t<0?~t:t]=1}),a.push(i)}}return e.forEach(function(r,n){var i,a=t.arcs[r<0?~r:r];a.length<3&&!a[1][0]&&!a[1][1]&&(i=e[++o],e[o]=r,e[n]=i)}),e.forEach(function(e){var r,a,o=function(e){var r,n=t.arcs[e<0?~e:e],i=n[0];t.transform?(r=[0,0],n.forEach(function(t){r[0]+=t[0],r[1]+=t[1]})):r=n[n.length-1];return e<0?[r,i]:[i,r]}(e),s=o[0],l=o[1];if(r=i[s])if(delete i[r.end],r.push(e),r.end=l,a=n[l]){delete n[a.start];var c=a===r?r:r.concat(a);n[c.start=r.start]=i[c.end=a.end]=c}else n[r.start]=i[r.end]=r;else if(r=n[l])if(delete n[r.start],r.unshift(e),r.start=s,a=i[s]){delete i[a.end];var u=a===r?r:a.concat(r);n[u.start=a.start]=i[u.end=r.end]=u}else n[r.start]=i[r.end]=r;else n[(r=[e]).start=s]=i[r.end=l]=r}),s(i,n),s(n,i),e.forEach(function(t){r[t<0?~t:t]||a.push([t])}),a};function l(t,e,r){var n,i,a;if(arguments.length>1)n=function(t,e,r){var n,i=[],a=[];function o(t){var e=t<0?~t:t;(a[e]||(a[e]=[])).push({i:t,g:n})}function s(t){t.forEach(o)}function l(t){t.forEach(s)}return function t(e){switch(n=e,e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"LineString\":s(e.arcs);break;case\"MultiLineString\":case\"Polygon\":l(e.arcs);break;case\"MultiPolygon\":e.arcs.forEach(l)}}(e),a.forEach(null==r?function(t){i.push(t[0].i)}:function(t){r(t[0].g,t[t.length-1].g)&&i.push(t[0].i)}),i}(0,e,r);else for(i=0,n=new Array(a=t.arcs.length);i<a;++i)n[i]=i;return{type:\"MultiLineString\",arcs:s(t,n)}}function c(t,e){var r={},n=[],i=[];function a(t){t.forEach(function(e){e.forEach(function(e){(r[e=e<0?~e:e]||(r[e]=[])).push(t)})}),n.push(t)}function l(e){return function(t){for(var e,r=-1,n=t.length,i=t[n-1],a=0;++r<n;)e=i,i=t[r],a+=e[0]*i[1]-e[1]*i[0];return Math.abs(a)}(o(t,{type:\"Polygon\",arcs:[e]}).coordinates[0])}return e.forEach(function t(e){switch(e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"Polygon\":a(e.arcs);break;case\"MultiPolygon\":e.arcs.forEach(a)}}),n.forEach(function(t){if(!t._){var e=[],n=[t];for(t._=1,i.push(e);t=n.pop();)e.push(t),t.forEach(function(t){t.forEach(function(t){r[t<0?~t:t].forEach(function(t){t._||(t._=1,n.push(t))})})})}}),n.forEach(function(t){delete t._}),{type:\"MultiPolygon\",arcs:i.map(function(e){var n,i=[];if(e.forEach(function(t){t.forEach(function(t){t.forEach(function(t){r[t<0?~t:t].length<2&&i.push(t)})})}),(n=(i=s(t,i)).length)>1)for(var a,o,c=1,u=l(i[0]);c<n;++c)(a=l(i[c]))>u&&(o=i[0],i[0]=i[c],i[c]=o,u=a);return i})}}var u=function(t,e){for(var r=0,n=t.length;r<n;){var i=r+n>>>1;t[i]<e?r=i+1:n=i}return r};t.bbox=n,t.feature=function(t,e){return\"GeometryCollection\"===e.type?{type:\"FeatureCollection\",features:e.geometries.map(function(e){return a(t,e)})}:a(t,e)},t.mesh=function(t){return o(t,l.apply(this,arguments))},t.meshArcs=l,t.merge=function(t){return o(t,c.apply(this,arguments))},t.mergeArcs=c,t.neighbors=function(t){var e={},r=t.map(function(){return[]});function n(t,r){t.forEach(function(t){t<0&&(t=~t);var n=e[t];n?n.push(r):e[t]=[r]})}function i(t,e){t.forEach(function(t){n(t,e)})}var a={LineString:n,MultiLineString:i,Polygon:i,MultiPolygon:function(t,e){t.forEach(function(t){i(t,e)})}};for(var o in t.forEach(function t(e,r){\"GeometryCollection\"===e.type?e.geometries.forEach(function(e){t(e,r)}):e.type in a&&a[e.type](e.arcs,r)}),e)for(var s=e[o],l=s.length,c=0;c<l;++c)for(var h=c+1;h<l;++h){var f,p=s[c],d=s[h];(f=r[p])[o=u(f,d)]!==d&&f.splice(o,0,d),(f=r[d])[o=u(f,p)]!==p&&f.splice(o,0,p)}return r},t.quantize=function(t,e){if(!((e=Math.floor(e))>=2))throw new Error(\"n must be \\u22652\");if(t.transform)throw new Error(\"already quantized\");var r,i=n(t),a=i[0],o=(i[2]-a)/(e-1)||1,s=i[1],l=(i[3]-s)/(e-1)||1;function c(t){t[0]=Math.round((t[0]-a)/o),t[1]=Math.round((t[1]-s)/l)}function u(t){switch(t.type){case\"GeometryCollection\":t.geometries.forEach(u);break;case\"Point\":c(t.coordinates);break;case\"MultiPoint\":t.coordinates.forEach(c)}}for(r in t.arcs.forEach(function(t){for(var e,r,n,i=1,c=1,u=t.length,h=t[0],f=h[0]=Math.round((h[0]-a)/o),p=h[1]=Math.round((h[1]-s)/l);i<u;++i)h=t[i],r=Math.round((h[0]-a)/o),n=Math.round((h[1]-s)/l),r===f&&n===p||((e=t[c++])[0]=r-f,f=r,e[1]=n-p,p=n);c<2&&((e=t[c++])[0]=0,e[1]=0),t.length=c}),t.objects)u(t.objects[r]);return t.transform={scale:[o,l],translate:[a,s]},t},t.transform=r,t.untransform=function(t){if(null==(r=t.transform))return e;var r,n,i,a=r.scale[0],o=r.scale[1],s=r.translate[0],l=r.translate[1];return function(t,e){e||(n=i=0);var r=Math.round((t[0]-s)/a),c=Math.round((t[1]-l)/o);return t[0]=r-n,n=r,t[1]=c-i,i=c,t}},Object.defineProperty(t,\"__esModule\",{value:!0})}(\"object\"==typeof r&&\"undefined\"!=typeof e?r:n.topojson=n.topojson||{})},{}],541:[function(t,e,r){\"use strict\";e.exports=function(t){if(t<0)return[];if(0===t)return[[0]];for(var e=0|Math.round(a(t+1)),r=[],o=0;o<e;++o){for(var s=n.unrank(t,o),l=[0],c=0,u=0;u<s.length;++u)c+=1<<s[u],l.push(c);i(s)<1&&(l[0]=c,l[t]=0),r.push(l)}return r};var n=t(\"permutation-rank\"),i=t(\"permutation-parity\"),a=t(\"gamma\")},{gamma:231,\"permutation-parity\":463,\"permutation-rank\":464}],542:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.up||[0,1,0],n=t.right||h(r),i=t.radius||1,a=t.theta||0,u=t.phi||0;if(e=[].slice.call(e,0,3),r=[].slice.call(r,0,3),s(r,r),n=[].slice.call(n,0,3),s(n,n),\"eye\"in t){var p=t.eye,d=[p[0]-e[0],p[1]-e[1],p[2]-e[2]];o(n,d,r),c(n[0],n[1],n[2])<1e-6?n=h(r):s(n,n),i=c(d[0],d[1],d[2]);var g=l(r,d)/i,v=l(n,d)/i;u=Math.acos(g),a=Math.acos(v)}return i=Math.log(i),new f(t.zoomMin,t.zoomMax,e,r,n,i,a,u)};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/invert\"),a=t(\"gl-mat4/rotate\"),o=t(\"gl-vec3/cross\"),s=t(\"gl-vec3/normalize\"),l=t(\"gl-vec3/dot\");function c(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function u(t){return Math.min(1,Math.max(-1,t))}function h(t){var e=Math.abs(t[0]),r=Math.abs(t[1]),n=Math.abs(t[2]),i=[0,0,0];e>Math.max(r,n)?i[2]=1:r>Math.max(e,n)?i[0]=1:i[1]=1;for(var a=0,o=0,l=0;l<3;++l)a+=t[l]*t[l],o+=i[l]*t[l];for(l=0;l<3;++l)i[l]-=o/a*t[l];return s(i,i),i}function f(t,e,r,i,a,o,s,l){this.center=n(r),this.up=n(i),this.right=n(a),this.radius=n([o]),this.angle=n([s,l]),this.angle.bounds=[[-1/0,-Math.PI/2],[1/0,Math.PI/2]],this.setDistanceLimits(t,e),this.computedCenter=this.center.curve(0),this.computedUp=this.up.curve(0),this.computedRight=this.right.curve(0),this.computedRadius=this.radius.curve(0),this.computedAngle=this.angle.curve(0),this.computedToward=[0,0,0],this.computedEye=[0,0,0],this.computedMatrix=new Array(16);for(var c=0;c<16;++c)this.computedMatrix[c]=.5;this.recalcMatrix(0)}var p=f.prototype;p.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},p.getDistanceLimits=function(t){var e=this.radius.bounds[0];return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},p.recalcMatrix=function(t){this.center.curve(t),this.up.curve(t),this.right.curve(t),this.radius.curve(t),this.angle.curve(t);for(var e=this.computedUp,r=this.computedRight,n=0,i=0,a=0;a<3;++a)i+=e[a]*r[a],n+=e[a]*e[a];var l=Math.sqrt(n),u=0;for(a=0;a<3;++a)r[a]-=e[a]*i/n,u+=r[a]*r[a],e[a]/=l;var h=Math.sqrt(u);for(a=0;a<3;++a)r[a]/=h;var f=this.computedToward;o(f,e,r),s(f,f);var p=Math.exp(this.computedRadius[0]),d=this.computedAngle[0],g=this.computedAngle[1],v=Math.cos(d),m=Math.sin(d),y=Math.cos(g),x=Math.sin(g),b=this.computedCenter,_=v*y,w=m*y,k=x,T=-v*x,A=-m*x,M=y,S=this.computedEye,E=this.computedMatrix;for(a=0;a<3;++a){var C=_*r[a]+w*f[a]+k*e[a];E[4*a+1]=T*r[a]+A*f[a]+M*e[a],E[4*a+2]=C,E[4*a+3]=0}var L=E[1],P=E[5],O=E[9],z=E[2],I=E[6],D=E[10],R=P*D-O*I,F=O*z-L*D,B=L*I-P*z,N=c(R,F,B);R/=N,F/=N,B/=N,E[0]=R,E[4]=F,E[8]=B;for(a=0;a<3;++a)S[a]=b[a]+E[2+4*a]*p;for(a=0;a<3;++a){u=0;for(var j=0;j<3;++j)u+=E[a+4*j]*S[j];E[12+a]=-u}E[15]=1},p.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r};var d=[0,0,0];p.rotate=function(t,e,r,n){if(this.angle.move(t,e,r),n){this.recalcMatrix(t);var i=this.computedMatrix;d[0]=i[2],d[1]=i[6],d[2]=i[10];for(var o=this.computedUp,s=this.computedRight,l=this.computedToward,c=0;c<3;++c)i[4*c]=o[c],i[4*c+1]=s[c],i[4*c+2]=l[c];a(i,i,n,d);for(c=0;c<3;++c)o[c]=i[4*c],s[c]=i[4*c+1];this.up.set(t,o[0],o[1],o[2]),this.right.set(t,s[0],s[1],s[2])}},p.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=(Math.exp(this.computedRadius[0]),i[1]),o=i[5],s=i[9],l=c(a,o,s);a/=l,o/=l,s/=l;var u=i[0],h=i[4],f=i[8],p=u*a+h*o+f*s,d=c(u-=a*p,h-=o*p,f-=s*p),g=(u/=d)*e+a*r,v=(h/=d)*e+o*r,m=(f/=d)*e+s*r;this.center.move(t,g,v,m);var y=Math.exp(this.computedRadius[0]);y=Math.max(1e-4,y+n),this.radius.set(t,Math.log(y))},p.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},p.setMatrix=function(t,e,r,n){var a=1;\"number\"==typeof r&&(a=0|r),(a<0||a>3)&&(a=1);var o=(a+2)%3;e||(this.recalcMatrix(t),e=this.computedMatrix);var s=e[a],l=e[a+4],h=e[a+8];if(n){var f=Math.abs(s),p=Math.abs(l),d=Math.abs(h),g=Math.max(f,p,d);f===g?(s=s<0?-1:1,l=h=0):d===g?(h=h<0?-1:1,s=l=0):(l=l<0?-1:1,s=h=0)}else{var v=c(s,l,h);s/=v,l/=v,h/=v}var m,y,x=e[o],b=e[o+4],_=e[o+8],w=x*s+b*l+_*h,k=c(x-=s*w,b-=l*w,_-=h*w),T=l*(_/=k)-h*(b/=k),A=h*(x/=k)-s*_,M=s*b-l*x,S=c(T,A,M);if(T/=S,A/=S,M/=S,this.center.jump(t,H,G,Y),this.radius.idle(t),this.up.jump(t,s,l,h),this.right.jump(t,x,b,_),2===a){var E=e[1],C=e[5],L=e[9],P=E*x+C*b+L*_,O=E*T+C*A+L*M;m=R<0?-Math.PI/2:Math.PI/2,y=Math.atan2(O,P)}else{var z=e[2],I=e[6],D=e[10],R=z*s+I*l+D*h,F=z*x+I*b+D*_,B=z*T+I*A+D*M;m=Math.asin(u(R)),y=Math.atan2(B,F)}this.angle.jump(t,y,m),this.recalcMatrix(t);var N=e[2],j=e[6],U=e[10],V=this.computedMatrix;i(V,e);var q=V[15],H=V[12]/q,G=V[13]/q,Y=V[14]/q,W=Math.exp(this.computedRadius[0]);this.center.jump(t,H-N*W,G-j*W,Y-U*W)},p.lastT=function(){return Math.max(this.center.lastT(),this.up.lastT(),this.right.lastT(),this.radius.lastT(),this.angle.lastT())},p.idle=function(t){this.center.idle(t),this.up.idle(t),this.right.idle(t),this.radius.idle(t),this.angle.idle(t)},p.flush=function(t){this.center.flush(t),this.up.flush(t),this.right.flush(t),this.radius.flush(t),this.angle.flush(t)},p.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},p.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||this.computedCenter;var i=(n=n||this.computedUp)[0],a=n[1],o=n[2],s=c(i,a,o);if(!(s<1e-6)){i/=s,a/=s,o/=s;var l=e[0]-r[0],h=e[1]-r[1],f=e[2]-r[2],p=c(l,h,f);if(!(p<1e-6)){l/=p,h/=p,f/=p;var d=this.computedRight,g=d[0],v=d[1],m=d[2],y=i*g+a*v+o*m,x=c(g-=y*i,v-=y*a,m-=y*o);if(!(x<.01&&(x=c(g=a*f-o*h,v=o*l-i*f,m=i*h-a*l))<1e-6)){g/=x,v/=x,m/=x,this.up.set(t,i,a,o),this.right.set(t,g,v,m),this.center.set(t,r[0],r[1],r[2]),this.radius.set(t,Math.log(p));var b=a*m-o*v,_=o*g-i*m,w=i*v-a*g,k=c(b,_,w),T=i*l+a*h+o*f,A=g*l+v*h+m*f,M=(b/=k)*l+(_/=k)*h+(w/=k)*f,S=Math.asin(u(T)),E=Math.atan2(M,A),C=this.angle._state,L=C[C.length-1],P=C[C.length-2];L%=2*Math.PI;var O=Math.abs(L+2*Math.PI-E),z=Math.abs(L-E),I=Math.abs(L-2*Math.PI-E);O<z&&(L+=2*Math.PI),I<z&&(L-=2*Math.PI),this.angle.jump(this.angle.lastT(),L,P),this.angle.set(t,E,S)}}}}},{\"filtered-vector\":226,\"gl-mat4/invert\":265,\"gl-mat4/rotate\":270,\"gl-vec3/cross\":334,\"gl-vec3/dot\":339,\"gl-vec3/normalize\":356}],543:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var i=t*e,a=n*t,o=a-(a-t),s=t-o,l=n*e,c=l-(l-e),u=e-c,h=s*u-(i-o*c-s*c-o*u);if(r)return r[0]=h,r[1]=i,r;return[h,i]};var n=+(Math.pow(2,27)+1)},{}],544:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=t+e,i=n-t,a=e-i,o=t-(n-i);if(r)return r[0]=o+a,r[1]=n,r;return[o+a,n]}},{}],545:[function(t,e,r){(function(e,n){\"use strict\";var i=t(\"bit-twiddle\"),a=t(\"dup\");e.__TYPEDARRAY_POOL||(e.__TYPEDARRAY_POOL={UINT8:a([32,0]),UINT16:a([32,0]),UINT32:a([32,0]),INT8:a([32,0]),INT16:a([32,0]),INT32:a([32,0]),FLOAT:a([32,0]),DOUBLE:a([32,0]),DATA:a([32,0]),UINT8C:a([32,0]),BUFFER:a([32,0])});var o=\"undefined\"!=typeof Uint8ClampedArray,s=e.__TYPEDARRAY_POOL;s.UINT8C||(s.UINT8C=a([32,0])),s.BUFFER||(s.BUFFER=a([32,0]));var l=s.DATA,c=s.BUFFER;function u(t){if(t){var e=t.length||t.byteLength,r=i.log2(e);l[r].push(t)}}function h(t){t=i.nextPow2(t);var e=i.log2(t),r=l[e];return r.length>0?r.pop():new ArrayBuffer(t)}function f(t){return new Uint8Array(h(t),0,t)}function p(t){return new Uint16Array(h(2*t),0,t)}function d(t){return new Uint32Array(h(4*t),0,t)}function g(t){return new Int8Array(h(t),0,t)}function v(t){return new Int16Array(h(2*t),0,t)}function m(t){return new Int32Array(h(4*t),0,t)}function y(t){return new Float32Array(h(4*t),0,t)}function x(t){return new Float64Array(h(8*t),0,t)}function b(t){return o?new Uint8ClampedArray(h(t),0,t):f(t)}function _(t){return new DataView(h(t),0,t)}function w(t){t=i.nextPow2(t);var e=i.log2(t),r=c[e];return r.length>0?r.pop():new n(t)}r.free=function(t){if(n.isBuffer(t))c[i.log2(t.length)].push(t);else{if(\"[object ArrayBuffer]\"!==Object.prototype.toString.call(t)&&(t=t.buffer),!t)return;var e=t.length||t.byteLength,r=0|i.log2(e);l[r].push(t)}},r.freeUint8=r.freeUint16=r.freeUint32=r.freeInt8=r.freeInt16=r.freeInt32=r.freeFloat32=r.freeFloat=r.freeFloat64=r.freeDouble=r.freeUint8Clamped=r.freeDataView=function(t){u(t.buffer)},r.freeArrayBuffer=u,r.freeBuffer=function(t){c[i.log2(t.length)].push(t)},r.malloc=function(t,e){if(void 0===e||\"arraybuffer\"===e)return h(t);switch(e){case\"uint8\":return f(t);case\"uint16\":return p(t);case\"uint32\":return d(t);case\"int8\":return g(t);case\"int16\":return v(t);case\"int32\":return m(t);case\"float\":case\"float32\":return y(t);case\"double\":case\"float64\":return x(t);case\"uint8_clamped\":return b(t);case\"buffer\":return w(t);case\"data\":case\"dataview\":return _(t);default:return null}return null},r.mallocArrayBuffer=h,r.mallocUint8=f,r.mallocUint16=p,r.mallocUint32=d,r.mallocInt8=g,r.mallocInt16=v,r.mallocInt32=m,r.mallocFloat32=r.mallocFloat=y,r.mallocFloat64=r.mallocDouble=x,r.mallocUint8Clamped=b,r.mallocDataView=_,r.mallocBuffer=w,r.clearCache=function(){for(var t=0;t<32;++t)s.UINT8[t].length=0,s.UINT16[t].length=0,s.UINT32[t].length=0,s.INT8[t].length=0,s.INT16[t].length=0,s.INT32[t].length=0,s.FLOAT[t].length=0,s.DOUBLE[t].length=0,s.UINT8C[t].length=0,l[t].length=0,c[t].length=0}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{},t(\"buffer\").Buffer)},{\"bit-twiddle\":92,buffer:105,dup:170}],546:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n;var i=n.prototype;Object.defineProperty(i,\"length\",{get:function(){return this.roots.length}}),i.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},i.find=function(t){for(var e=t,r=this.roots;r[t]!==t;)t=r[t];for(;r[e]!==t;){var n=r[e];r[e]=t,e=n}return t},i.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],547:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return 0===t.length?t:e?(r||t.sort(e),function(t,e){for(var r=1,n=t.length,i=t[0],a=t[0],o=1;o<n;++o)if(a=i,e(i=t[o],a)){if(o===r){r++;continue}t[r++]=i}return t.length=r,t}(t,e)):(r||t.sort(),function(t){for(var e=1,r=t.length,n=t[0],i=t[0],a=1;a<r;++a,i=n)if(i=n,(n=t[a])!==i){if(a===e){e++;continue}t[e++]=n}return t.length=e,t}(t))}},{}],548:[function(t,e,r){var n=/[\\'\\\"]/;e.exports=function(t){return t?(n.test(t.charAt(0))&&(t=t.substr(1)),n.test(t.charAt(t.length-1))&&(t=t.substr(0,t.length-1)),t):\"\"}},{}],549:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){Array.isArray(r)||(r=[].slice.call(arguments,2));for(var n=0,i=r.length;n<i;n++){var a=r[n];for(var o in a)if((void 0===e[o]||Array.isArray(e[o])||t[o]!==e[o])&&o in e){var s;if(!0===a[o])s=e[o];else{if(!1===a[o])continue;if(\"function\"==typeof a[o]&&void 0===(s=a[o](e[o],t,e)))continue}t[o]=s}}return t}},{}],550:[function(t,e,r){\"use strict\";e.exports=function(t,e){\"object\"==typeof e&&null!==e||(e={});return n(t,e.canvas||i,e.context||a,e)};var n=t(\"./lib/vtext\"),i=null,a=null;\"undefined\"!=typeof document&&((i=document.createElement(\"canvas\")).width=8192,i.height=1024,a=i.getContext(\"2d\"))},{\"./lib/vtext\":551}],551:[function(t,e,r){e.exports=function(t,e,r,n){var a=64,o=1.25,s={breaklines:!1,bolds:!1,italics:!1,subscripts:!1,superscripts:!1};n&&(n.size&&n.size>0&&(a=n.size),n.lineSpacing&&n.lineSpacing>0&&(o=n.lineSpacing),n.styletags&&n.styletags.breaklines&&(s.breaklines=!!n.styletags.breaklines),n.styletags&&n.styletags.bolds&&(s.bolds=!!n.styletags.bolds),n.styletags&&n.styletags.italics&&(s.italics=!!n.styletags.italics),n.styletags&&n.styletags.subscripts&&(s.subscripts=!!n.styletags.subscripts),n.styletags&&n.styletags.superscripts&&(s.superscripts=!!n.styletags.superscripts));return r.font=[n.fontStyle,n.fontVariant,n.fontWeight,a+\"px\",n.font].filter(function(t){return t}).join(\" \"),r.textAlign=\"start\",r.textBaseline=\"alphabetic\",r.direction=\"ltr\",w(function(t,e,r,n,a,o){r=r.replace(/\\n/g,\"\"),r=!0===o.breaklines?r.replace(/\\<br\\>/g,\"\\n\"):r.replace(/\\<br\\>/g,\" \");var s=\"\",l=[];for(k=0;k<r.length;++k)l[k]=s;!0===o.bolds&&(l=x(c,u,r,l)),!0===o.italics&&(l=x(h,f,r,l)),!0===o.superscripts&&(l=x(p,g,r,l)),!0===o.subscripts&&(l=x(v,y,r,l));var b=[],_=\"\";for(k=0;k<r.length;++k)null!==l[k]&&(_+=r[k],b.push(l[k]));var w,k,T,A,M,S=_.split(\"\\n\"),E=S.length,C=Math.round(a*n),L=n,P=2*n,O=0,z=E*C+P;t.height<z&&(t.height=z),e.fillStyle=\"#000\",e.fillRect(0,0,t.width,t.height),e.fillStyle=\"#fff\";var I=0,D=\"\";function R(){if(\"\"!==D){var t=e.measureText(D).width;e.fillText(D,L+T,P+A),T+=t}}function F(){return Math.round(M)+\"px \"}function B(t,r){var n=\"\"+e.font;if(!0===o.subscripts){var i=t.indexOf(m),a=r.indexOf(m),s=i>-1?parseInt(t[1+i]):0,l=a>-1?parseInt(r[1+a]):0;s!==l&&(n=n.replace(F(),\"?px \"),M*=Math.pow(.75,l-s),n=n.replace(\"?px \",F())),A+=.25*C*(l-s)}if(!0===o.superscripts){var c=t.indexOf(d),h=r.indexOf(d),p=c>-1?parseInt(t[1+c]):0,g=h>-1?parseInt(r[1+h]):0;p!==g&&(n=n.replace(F(),\"?px \"),M*=Math.pow(.75,g-p),n=n.replace(\"?px \",F())),A-=.25*C*(g-p)}if(!0===o.bolds){var v=t.indexOf(u)>-1,y=r.indexOf(u)>-1;!v&&y&&(n=x?n.replace(\"italic \",\"italic bold \"):\"bold \"+n),v&&!y&&(n=n.replace(\"bold \",\"\"))}if(!0===o.italics){var x=t.indexOf(f)>-1,b=r.indexOf(f)>-1;!x&&b&&(n=\"italic \"+n),x&&!b&&(n=n.replace(\"italic \",\"\"))}e.font=n}for(w=0;w<E;++w){var N=S[w]+\"\\n\";for(T=0,A=w*C,M=n,D=\"\",k=0;k<N.length;++k){var j=k+I<b.length?b[k+I]:b[b.length-1];s===j?D+=N[k]:(R(),D=N[k],void 0!==j&&(B(s,j),s=j))}R(),I+=N.length;var U=0|Math.round(T+2*L);O<U&&(O=U)}var V=O,q=P+C*E;return i(e.getImageData(0,0,V,q).data,[q,V,4]).pick(-1,-1,0).transpose(1,0)}(e,r,t,a,o,s),n,a)},e.exports.processPixels=w;var n=t(\"surface-nets\"),i=t(\"ndarray\"),a=t(\"simplify-planar-graph\"),o=t(\"clean-pslg\"),s=t(\"cdt2d\"),l=t(\"planar-graph-to-polyline\"),c=\"b\",u=\"b|\",h=\"i\",f=\"i|\",p=\"sup\",d=\"+\",g=\"+1\",v=\"sub\",m=\"-\",y=\"-1\";function x(t,e,r,n){for(var i=\"<\"+t+\">\",a=\"</\"+t+\">\",o=i.length,s=a.length,l=e[0]===d||e[0]===m,c=0,u=-s;c>-1&&-1!==(c=r.indexOf(i,c))&&-1!==(u=r.indexOf(a,c+o))&&!(u<=c);){for(var h=c;h<u+s;++h)if(h<c+o||h>=u)n[h]=null,r=r.substr(0,h)+\" \"+r.substr(h+1);else if(null!==n[h]){var f=n[h].indexOf(e[0]);-1===f?n[h]+=e:l&&(n[h]=n[h].substr(0,f+1)+(1+parseInt(n[h][f+1]))+n[h].substr(f+2))}var p=c+o,g=r.substr(p,u-p).indexOf(i);c=-1!==g?g:u+s}return n}function b(t,e){var r=n(t,128);return e?a(r.cells,r.positions,.25):{edges:r.cells,positions:r.positions}}function _(t,e,r,n){var i=b(t,n),a=function(t,e,r){for(var n=e.textAlign||\"start\",i=e.textBaseline||\"alphabetic\",a=[1<<30,1<<30],o=[0,0],s=t.length,l=0;l<s;++l)for(var c=t[l],u=0;u<2;++u)a[u]=0|Math.min(a[u],c[u]),o[u]=0|Math.max(o[u],c[u]);var h=0;switch(n){case\"center\":h=-.5*(a[0]+o[0]);break;case\"right\":case\"end\":h=-o[0];break;case\"left\":case\"start\":h=-a[0];break;default:throw new Error(\"vectorize-text: Unrecognized textAlign: '\"+n+\"'\")}var f=0;switch(i){case\"hanging\":case\"top\":f=-a[1];break;case\"middle\":f=-.5*(a[1]+o[1]);break;case\"alphabetic\":case\"ideographic\":f=-3*r;break;case\"bottom\":f=-o[1];break;default:throw new Error(\"vectorize-text: Unrecoginized textBaseline: '\"+i+\"'\")}var p=1/r;return\"lineHeight\"in e?p*=+e.lineHeight:\"width\"in e?p=e.width/(o[0]-a[0]):\"height\"in e&&(p=e.height/(o[1]-a[1])),t.map(function(t){return[p*(t[0]+h),p*(t[1]+f)]})}(i.positions,e,r),c=i.edges,u=\"ccw\"===e.orientation;if(o(a,c),e.polygons||e.polygon||e.polyline){for(var h=l(c,a),f=new Array(h.length),p=0;p<h.length;++p){for(var d=h[p],g=new Array(d.length),v=0;v<d.length;++v){for(var m=d[v],y=new Array(m.length),x=0;x<m.length;++x)y[x]=a[m[x]].slice();u&&y.reverse(),g[v]=y}f[p]=g}return f}return e.triangles||e.triangulate||e.triangle?{cells:s(a,c,{delaunay:!1,exterior:!1,interior:!0}),positions:a}:{edges:c,positions:a}}function w(t,e,r){try{return _(t,e,r,!0)}catch(t){}try{return _(t,e,r,!1)}catch(t){}return e.polygons||e.polyline||e.polygon?[]:e.triangles||e.triangulate||e.triangle?{cells:[],positions:[]}:{edges:[],positions:[]}}},{cdt2d:106,\"clean-pslg\":116,ndarray:450,\"planar-graph-to-polyline\":468,\"simplify-planar-graph\":524,\"surface-nets\":531}],552:[function(t,e,r){!function(){\"use strict\";if(\"undefined\"==typeof ses||!ses.ok||ses.ok()){\"undefined\"!=typeof ses&&(ses.weakMapPermitHostObjects=v);var t=!1;if(\"function\"==typeof WeakMap){var r=WeakMap;if(\"undefined\"!=typeof navigator&&/Firefox/.test(navigator.userAgent));else{var n=new r,i=Object.freeze({});if(n.set(i,1),1===n.get(i))return void(e.exports=WeakMap);t=!0}}Object.prototype.hasOwnProperty;var a=Object.getOwnPropertyNames,o=Object.defineProperty,s=Object.isExtensible,l=\"weakmap:\",c=l+\"ident:\"+Math.random()+\"___\";if(\"undefined\"!=typeof crypto&&\"function\"==typeof crypto.getRandomValues&&\"function\"==typeof ArrayBuffer&&\"function\"==typeof Uint8Array){var u=new ArrayBuffer(25),h=new Uint8Array(u);crypto.getRandomValues(h),c=l+\"rand:\"+Array.prototype.map.call(h,function(t){return(t%36).toString(36)}).join(\"\")+\"___\"}if(o(Object,\"getOwnPropertyNames\",{value:function(t){return a(t).filter(m)}}),\"getPropertyNames\"in Object){var f=Object.getPropertyNames;o(Object,\"getPropertyNames\",{value:function(t){return f(t).filter(m)}})}!function(){var t=Object.freeze;o(Object,\"freeze\",{value:function(e){return y(e),t(e)}});var e=Object.seal;o(Object,\"seal\",{value:function(t){return y(t),e(t)}});var r=Object.preventExtensions;o(Object,\"preventExtensions\",{value:function(t){return y(t),r(t)}})}();var p=!1,d=0,g=function(){this instanceof g||b();var t=[],e=[],r=d++;return Object.create(g.prototype,{get___:{value:x(function(n,i){var a,o=y(n);return o?r in o?o[r]:i:(a=t.indexOf(n))>=0?e[a]:i})},has___:{value:x(function(e){var n=y(e);return n?r in n:t.indexOf(e)>=0})},set___:{value:x(function(n,i){var a,o=y(n);return o?o[r]=i:(a=t.indexOf(n))>=0?e[a]=i:(a=t.length,e[a]=i,t[a]=n),this})},delete___:{value:x(function(n){var i,a,o=y(n);return o?r in o&&delete o[r]:!((i=t.indexOf(n))<0||(a=t.length-1,t[i]=void 0,e[i]=e[a],t[i]=t[a],t.length=a,e.length=a,0))})}})};g.prototype=Object.create(Object.prototype,{get:{value:function(t,e){return this.get___(t,e)},writable:!0,configurable:!0},has:{value:function(t){return this.has___(t)},writable:!0,configurable:!0},set:{value:function(t,e){return this.set___(t,e)},writable:!0,configurable:!0},delete:{value:function(t){return this.delete___(t)},writable:!0,configurable:!0}}),\"function\"==typeof r?function(){function n(){this instanceof g||b();var e,n=new r,i=void 0,a=!1;return e=t?function(t,e){return n.set(t,e),n.has(t)||(i||(i=new g),i.set(t,e)),this}:function(t,e){if(a)try{n.set(t,e)}catch(r){i||(i=new g),i.set___(t,e)}else n.set(t,e);return this},Object.create(g.prototype,{get___:{value:x(function(t,e){return i?n.has(t)?n.get(t):i.get___(t,e):n.get(t,e)})},has___:{value:x(function(t){return n.has(t)||!!i&&i.has___(t)})},set___:{value:x(e)},delete___:{value:x(function(t){var e=!!n.delete(t);return i&&i.delete___(t)||e})},permitHostObjects___:{value:x(function(t){if(t!==v)throw new Error(\"bogus call to permitHostObjects___\");a=!0})}})}t&&\"undefined\"!=typeof Proxy&&(Proxy=void 0),n.prototype=g.prototype,e.exports=n,Object.defineProperty(WeakMap.prototype,\"constructor\",{value:WeakMap,enumerable:!1,configurable:!0,writable:!0})}():(\"undefined\"!=typeof Proxy&&(Proxy=void 0),e.exports=g)}function v(t){t.permitHostObjects___&&t.permitHostObjects___(v)}function m(t){return!(t.substr(0,l.length)==l&&\"___\"===t.substr(t.length-3))}function y(t){if(t!==Object(t))throw new TypeError(\"Not an object: \"+t);var e=t[c];if(e&&e.key===t)return e;if(s(t)){e={key:t};try{return o(t,c,{value:e,writable:!1,enumerable:!1,configurable:!1}),e}catch(t){return}}}function x(t){return t.prototype=null,Object.freeze(t)}function b(){p||\"undefined\"==typeof console||(p=!0,console.warn(\"WeakMap should be invoked as new WeakMap(), not WeakMap(). This will be an error in the future.\"))}}()},{}],553:[function(t,e,r){var n=t(\"./hidden-store.js\");e.exports=function(){var t={};return function(e){if((\"object\"!=typeof e||null===e)&&\"function\"!=typeof e)throw new Error(\"Weakmap-shim: Key must be object\");var r=e.valueOf(t);return r&&r.identity===t?r:n(e,t)}}},{\"./hidden-store.js\":554}],554:[function(t,e,r){e.exports=function(t,e){var r={identity:e},n=t.valueOf;return Object.defineProperty(t,\"valueOf\",{value:function(t){return t!==e?n.apply(this,arguments):r},writable:!0}),r}},{}],555:[function(t,e,r){var n=t(\"./create-store.js\");e.exports=function(){var t=n();return{get:function(e,r){var n=t(e);return n.hasOwnProperty(\"value\")?n.value:r},set:function(e,r){return t(e).value=r,this},has:function(e){return\"value\"in t(e)},delete:function(e){return delete t(e).value}}}},{\"./create-store.js\":553}],556:[function(t,e,r){var n=t(\"get-canvas-context\");e.exports=function(t){return n(\"webgl\",t)}},{\"get-canvas-context\":232}],557:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Chinese\",jdEpoch:1721425.5,hasYearZero:!1,minMonth:0,firstMonth:0,minDay:1,regionalOptions:{\"\":{name:\"Chinese\",epochs:[\"BEC\",\"EC\"],monthNumbers:function(t,e){if(\"string\"==typeof t){var r=t.match(l);return r?r[0]:\"\"}var n=this._validateYear(t),i=t.month(),a=\"\"+this.toChineseMonth(n,i);return e&&a.length<2&&(a=\"0\"+a),this.isIntercalaryMonth(n,i)&&(a+=\"i\"),a},monthNames:function(t){if(\"string\"==typeof t){var e=t.match(c);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\\u6708\",\"\\u4e8c\\u6708\",\"\\u4e09\\u6708\",\"\\u56db\\u6708\",\"\\u4e94\\u6708\",\"\\u516d\\u6708\",\"\\u4e03\\u6708\",\"\\u516b\\u6708\",\"\\u4e5d\\u6708\",\"\\u5341\\u6708\",\"\\u5341\\u4e00\\u6708\",\"\\u5341\\u4e8c\\u6708\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},monthNamesShort:function(t){if(\"string\"==typeof t){var e=t.match(u);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},parseMonth:function(t,e){t=this._validateYear(t);var r,n=parseInt(e);if(isNaN(n))\"\\u95f0\"===e[0]&&(r=!0,e=e.substring(1)),\"\\u6708\"===e[e.length-1]&&(e=e.substring(0,e.length-1)),n=1+[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"].indexOf(e);else{var i=e[e.length-1];r=\"i\"===i||\"I\"===i}return this.toMonthIndex(t,n,r)},dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},_validateYear:function(t,e){if(t.year&&(t=t.year()),\"number\"!=typeof t||t<1888||t>2111)throw e.replace(/\\{0\\}/,this.local.name);return t},toMonthIndex:function(t,e,r){var i=this.intercalaryMonth(t);if(r&&e!==i||e<1||e>12)throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return i?!r&&e<=i?e-1:e:e-1},toChineseMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);if(e<0||e>(r?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r?e<r?e+1:e:e+1},intercalaryMonth:function(t){return t=this._validateYear(t),h[t-h[0]]>>13},isIntercalaryMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);return!!r&&r===e},leapYear:function(t){return 0!==this.intercalaryMonth(t)},weekOfYear:function(t,e,r){var i,o=this._validateYear(t,n.local.invalidyear),s=f[o-f[0]],l=s>>9&4095,c=s>>5&15,u=31&s;(i=a.newDate(l,c,u)).add(4-(i.dayOfWeek()||7),\"d\");var h=this.toJD(t,e,r)-i.toJD();return 1+Math.floor(h/7)},monthsInYear:function(t){return this.leapYear(t)?13:12},daysInMonth:function(t,e){t.year&&(e=t.month(),t=t.year()),t=this._validateYear(t);var r=h[t-h[0]];if(e>(r>>13?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r&1<<12-e?30:29},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,s,r,n.local.invalidDate);t=this._validateYear(i.year()),e=i.month(),r=i.day();var o=this.isIntercalaryMonth(t,e),s=this.toChineseMonth(t,e),l=function(t,e,r,n,i){var a,o,s;if(\"object\"==typeof t)o=t,a=e||{};else{var l=\"number\"==typeof t&&t>=1888&&t<=2111;if(!l)throw new Error(\"Lunar year outside range 1888-2111\");var c=\"number\"==typeof e&&e>=1&&e<=12;if(!c)throw new Error(\"Lunar month outside range 1 - 12\");var u,p=\"number\"==typeof r&&r>=1&&r<=30;if(!p)throw new Error(\"Lunar day outside range 1 - 30\");\"object\"==typeof n?(u=!1,a=n):(u=!!n,a=i||{}),o={year:t,month:e,day:r,isIntercalary:u}}s=o.day-1;var d,g=h[o.year-h[0]],v=g>>13;d=v?o.month>v?o.month:o.isIntercalary?o.month:o.month-1:o.month-1;for(var m=0;m<d;m++){var y=g&1<<12-m?30:29;s+=y}var x=f[o.year-f[0]],b=new Date(x>>9&4095,(x>>5&15)-1,(31&x)+s);return a.year=b.getFullYear(),a.month=1+b.getMonth(),a.day=b.getDate(),a}(t,s,r,o);return a.toJD(l.year,l.month,l.day)},fromJD:function(t){var e=a.fromJD(t),r=function(t,e,r,n){var i,a;if(\"object\"==typeof t)i=t,a=e||{};else{var o=\"number\"==typeof t&&t>=1888&&t<=2111;if(!o)throw new Error(\"Solar year outside range 1888-2111\");var s=\"number\"==typeof e&&e>=1&&e<=12;if(!s)throw new Error(\"Solar month outside range 1 - 12\");var l=\"number\"==typeof r&&r>=1&&r<=31;if(!l)throw new Error(\"Solar day outside range 1 - 31\");i={year:t,month:e,day:r},a=n||{}}var c=f[i.year-f[0]],u=i.year<<9|i.month<<5|i.day;a.year=u>=c?i.year:i.year-1,c=f[a.year-f[0]];var p,d=new Date(c>>9&4095,(c>>5&15)-1,31&c),g=new Date(i.year,i.month-1,i.day);p=Math.round((g-d)/864e5);var v,m=h[a.year-h[0]];for(v=0;v<13;v++){var y=m&1<<12-v?30:29;if(p<y)break;p-=y}var x=m>>13;!x||v<x?(a.isIntercalary=!1,a.month=1+v):v===x?(a.isIntercalary=!0,a.month=v):(a.isIntercalary=!1,a.month=v);return a.day=1+p,a}(e.year(),e.month(),e.day()),n=this.toMonthIndex(r.year,r.month,r.isIntercalary);return this.newDate(r.year,n,r.day)},fromString:function(t){var e=t.match(s),r=this._validateYear(+e[1]),n=+e[2],i=!!e[3],a=this.toMonthIndex(r,n,i),o=+e[4];return this.newDate(r,a,o)},add:function(t,e,r){var n=t.year(),i=t.month(),a=this.isIntercalaryMonth(n,i),s=this.toChineseMonth(n,i),l=Object.getPrototypeOf(o.prototype).add.call(this,t,e,r);if(\"y\"===r){var c=l.year(),u=l.month(),h=this.isIntercalaryMonth(c,s),f=a&&h?this.toMonthIndex(c,s,!0):this.toMonthIndex(c,s,!1);f!==u&&l.month(f)}return l}});var s=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)[-\\/](\\d?\\d)([iI]?)[-\\/](\\d?\\d)/m,l=/^\\d?\\d[iI]?/m,c=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?\\u6708/m,u=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?/m;n.calendars.chinese=o;var h=[1887,5780,5802,19157,2742,50359,1198,2646,46378,7466,3412,30122,5482,67949,2396,5294,43597,6732,6954,36181,2772,4954,18781,2396,54427,5274,6730,47781,5800,6868,21210,4790,59703,2350,5270,46667,3402,3496,38325,1388,4782,18735,2350,52374,6804,7498,44457,2906,1388,29294,4700,63789,6442,6804,56138,5802,2772,38235,1210,4698,22827,5418,63125,3476,5802,43701,2484,5302,27223,2646,70954,7466,3412,54698,5482,2412,38062,5294,2636,32038,6954,60245,2772,4826,43357,2394,5274,39501,6730,72357,5800,5844,53978,4790,2358,38039,5270,87627,3402,3496,54708,5484,4782,43311,2350,3222,27978,7498,68965,2904,5484,45677,4700,6444,39573,6804,6986,19285,2772,62811,1210,4698,47403,5418,5780,38570,5546,76469,2420,5302,51799,2646,5414,36501,3412,5546,18869,2412,54446,5276,6732,48422,6822,2900,28010,4826,92509,2394,5274,55883,6730,6820,47956,5812,2778,18779,2358,62615,5270,5450,46757,3492,5556,27318,4718,67887,2350,3222,52554,7498,3428,38252,5468,4700,31022,6444,64149,6804,6986,43861,2772,5338,35421,2650,70955,5418,5780,54954,5546,2740,38074,5302,2646,29991,3366,61011,3412,5546,43445,2412,5294,35406,6732,72998,6820,6996,52586,2778,2396,38045,5274,6698,23333,6820,64338,5812,2746,43355,2358,5270,39499,5450,79525,3492,5548],f=[1887,966732,967231,967733,968265,968766,969297,969798,970298,970829,971330,971830,972362,972863,973395,973896,974397,974928,975428,975929,976461,976962,977462,977994,978494,979026,979526,980026,980558,981059,981559,982091,982593,983124,983624,984124,984656,985157,985656,986189,986690,987191,987722,988222,988753,989254,989754,990286,990788,991288,991819,992319,992851,993352,993851,994383,994885,995385,995917,996418,996918,997450,997949,998481,998982,999483,1000014,1000515,1001016,1001548,1002047,1002578,1003080,1003580,1004111,1004613,1005113,1005645,1006146,1006645,1007177,1007678,1008209,1008710,1009211,1009743,1010243,1010743,1011275,1011775,1012306,1012807,1013308,1013840,1014341,1014841,1015373,1015874,1016404,1016905,1017405,1017937,1018438,1018939,1019471,1019972,1020471,1021002,1021503,1022035,1022535,1023036,1023568,1024069,1024568,1025100,1025601,1026102,1026633,1027133,1027666,1028167,1028666,1029198,1029699,1030199,1030730,1031231,1031763,1032264,1032764,1033296,1033797,1034297,1034828,1035329,1035830,1036362,1036861,1037393,1037894,1038394,1038925,1039427,1039927,1040459,1040959,1041491,1041992,1042492,1043023,1043524,1044024,1044556,1045057,1045558,1046090,1046590,1047121,1047622,1048122,1048654,1049154,1049655,1050187,1050689,1051219,1051720,1052220,1052751,1053252,1053752,1054284,1054786,1055285,1055817,1056317,1056849,1057349,1057850,1058382,1058883,1059383,1059915,1060415,1060947,1061447,1061947,1062479,1062981,1063480,1064012,1064514,1065014,1065545,1066045,1066577,1067078,1067578,1068110,1068611,1069112,1069642,1070142,1070674,1071175,1071675,1072207,1072709,1073209,1073740,1074241,1074741,1075273,1075773,1076305,1076807,1077308,1077839,1078340,1078840,1079372,1079871,1080403,1080904]},{\"../main\":571,\"object-assign\":454}],558:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Coptic\",jdEpoch:1825029.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Coptic\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Thout\",\"Paopi\",\"Hathor\",\"Koiak\",\"Tobi\",\"Meshir\",\"Paremhat\",\"Paremoude\",\"Pashons\",\"Paoni\",\"Epip\",\"Mesori\",\"Pi Kogi Enavot\"],monthNamesShort:[\"Tho\",\"Pao\",\"Hath\",\"Koi\",\"Tob\",\"Mesh\",\"Pat\",\"Pad\",\"Pash\",\"Pao\",\"Epi\",\"Meso\",\"PiK\"],dayNames:[\"Tkyriaka\",\"Pesnau\",\"Pshoment\",\"Peftoou\",\"Ptiou\",\"Psoou\",\"Psabbaton\"],dayNamesShort:[\"Tky\",\"Pes\",\"Psh\",\"Pef\",\"Pti\",\"Pso\",\"Psa\"],dayNamesMin:[\"Tk\",\"Pes\",\"Psh\",\"Pef\",\"Pt\",\"Pso\",\"Psa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.coptic=a},{\"../main\":571,\"object-assign\":454}],559:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Discworld\",jdEpoch:1721425.5,daysPerMonth:[16,32,32,32,32,32,32,32,32,32,32,32,32],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Discworld\",epochs:[\"BUC\",\"UC\"],monthNames:[\"Ick\",\"Offle\",\"February\",\"March\",\"April\",\"May\",\"June\",\"Grune\",\"August\",\"Spune\",\"Sektober\",\"Ember\",\"December\"],monthNamesShort:[\"Ick\",\"Off\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Gru\",\"Aug\",\"Spu\",\"Sek\",\"Emb\",\"Dec\"],dayNames:[\"Sunday\",\"Octeday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Oct\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Oc\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:2,isRTL:!1}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),13},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),400},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/8)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]},daysInWeek:function(){return 8},dayOfWeek:function(t,e,r){return(this._validate(t,e,r,n.local.invalidDate).day()+1)%8},weekDay:function(t,e,r){var n=this.dayOfWeek(t,e,r);return n>=2&&n<=6},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{century:o[Math.floor((i.year()-1)/100)+1]||\"\"}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year()+(i.year()<0?1:0),e=i.month(),(r=i.day())+(e>1?16:0)+(e>2?32*(e-2):0)+400*(t-1)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t+.5)-Math.floor(this.jdEpoch)-1;var e=Math.floor(t/400)+1;t-=400*(e-1),t+=t>15?16:0;var r=Math.floor(t/32)+1,n=t-32*(r-1)+1;return this.newDate(e<=0?e-1:e,r,n)}});var o={20:\"Fruitbat\",21:\"Anchovy\"};n.calendars.discworld=a},{\"../main\":571,\"object-assign\":454}],560:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Ethiopian\",jdEpoch:1724220.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Ethiopian\",epochs:[\"BEE\",\"EE\"],monthNames:[\"Meskerem\",\"Tikemet\",\"Hidar\",\"Tahesas\",\"Tir\",\"Yekatit\",\"Megabit\",\"Miazia\",\"Genbot\",\"Sene\",\"Hamle\",\"Nehase\",\"Pagume\"],monthNamesShort:[\"Mes\",\"Tik\",\"Hid\",\"Tah\",\"Tir\",\"Yek\",\"Meg\",\"Mia\",\"Gen\",\"Sen\",\"Ham\",\"Neh\",\"Pag\"],dayNames:[\"Ehud\",\"Segno\",\"Maksegno\",\"Irob\",\"Hamus\",\"Arb\",\"Kidame\"],dayNamesShort:[\"Ehu\",\"Seg\",\"Mak\",\"Iro\",\"Ham\",\"Arb\",\"Kid\"],dayNamesMin:[\"Eh\",\"Se\",\"Ma\",\"Ir\",\"Ha\",\"Ar\",\"Ki\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.ethiopian=a},{\"../main\":571,\"object-assign\":454}],561:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Hebrew\",jdEpoch:347995.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29,29],hasYearZero:!1,minMonth:1,firstMonth:7,minDay:1,regionalOptions:{\"\":{name:\"Hebrew\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Nisan\",\"Iyar\",\"Sivan\",\"Tammuz\",\"Av\",\"Elul\",\"Tishrei\",\"Cheshvan\",\"Kislev\",\"Tevet\",\"Shevat\",\"Adar\",\"Adar II\"],monthNamesShort:[\"Nis\",\"Iya\",\"Siv\",\"Tam\",\"Av\",\"Elu\",\"Tis\",\"Che\",\"Kis\",\"Tev\",\"She\",\"Ada\",\"Ad2\"],dayNames:[\"Yom Rishon\",\"Yom Sheni\",\"Yom Shlishi\",\"Yom Revi'i\",\"Yom Chamishi\",\"Yom Shishi\",\"Yom Shabbat\"],dayNamesShort:[\"Ris\",\"She\",\"Shl\",\"Rev\",\"Cha\",\"Shi\",\"Sha\"],dayNamesMin:[\"Ri\",\"She\",\"Shl\",\"Re\",\"Ch\",\"Shi\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return this._leapYear(e.year())},_leapYear:function(t){return o(7*(t=t<0?t+1:t)+1,19)<7},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),this._leapYear(t.year?t.year():t)?13:12},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),this.toJD(-1===t?1:t+1,7,1)-this.toJD(t,7,1)},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),12===e&&this.leapYear(t)?30:8===e&&5===o(this.daysInYear(t),10)?30:9===e&&3===o(this.daysInYear(t),10)?29:this.daysPerMonth[e-1]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{yearType:(this.leapYear(i)?\"embolismic\":\"common\")+\" \"+[\"deficient\",\"regular\",\"complete\"][this.daysInYear(i)%10-3]}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t<=0?t+1:t,o=this.jdEpoch+this._delay1(a)+this._delay2(a)+r+1;if(e<7){for(var s=7;s<=this.monthsInYear(t);s++)o+=this.daysInMonth(t,s);for(s=1;s<e;s++)o+=this.daysInMonth(t,s)}else for(s=7;s<e;s++)o+=this.daysInMonth(t,s);return o},_delay1:function(t){var e=Math.floor((235*t-234)/19),r=12084+13753*e,n=29*e+Math.floor(r/25920);return o(3*(n+1),7)<3&&n++,n},_delay2:function(t){var e=this._delay1(t-1),r=this._delay1(t);return this._delay1(t+1)-r==356?2:r-e==382?1:0},fromJD:function(t){t=Math.floor(t)+.5;for(var e=Math.floor(98496*(t-this.jdEpoch)/35975351)-1;t>=this.toJD(-1===e?1:e+1,7,1);)e++;for(var r=t<this.toJD(e,1,1)?7:1;t>this.toJD(e,r,this.daysInMonth(e,r));)r++;var n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.hebrew=a},{\"../main\":571,\"object-assign\":454}],562:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Islamic\",jdEpoch:1948439.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Islamic\",epochs:[\"BH\",\"AH\"],monthNames:[\"Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' al-thani\",\"Jumada al-awwal\",\"Jumada al-thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-ahad\",\"Yawm al-ithnayn\",\"Yawm ath-thulaathaa'\",\"Yawm al-arbi'aa'\",\"Yawm al-kham\\u012bs\",\"Yawm al-jum'a\",\"Yawm as-sabt\"],dayNamesShort:[\"Aha\",\"Ith\",\"Thu\",\"Arb\",\"Kha\",\"Jum\",\"Sab\"],dayNamesMin:[\"Ah\",\"It\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){return(11*this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year()+14)%30<11},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return this.leapYear(t)?355:354},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),t=t<=0?t+1:t,(r=i.day())+Math.ceil(29.5*(e-1))+354*(t-1)+Math.floor((3+11*t)/30)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t)+.5;var e=Math.floor((30*(t-this.jdEpoch)+10646)/10631);e=e<=0?e-1:e;var r=Math.min(12,Math.ceil((t-29-this.toJD(e,1,1))/29.5)+1),n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.islamic=a},{\"../main\":571,\"object-assign\":454}],563:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Julian\",jdEpoch:1721423.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Julian\",epochs:[\"BC\",\"AD\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()<0?e.year()+1:e.year())%4==0},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),r=i.day(),t<0&&t++,e<=2&&(t--,e+=12),Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r-1524.5},fromJD:function(t){var e=Math.floor(t+.5)+1524,r=Math.floor((e-122.1)/365.25),n=Math.floor(365.25*r),i=Math.floor((e-n)/30.6001),a=i-Math.floor(i<14?1:13),o=r-Math.floor(a>2?4716:4715),s=e-n-Math.floor(30.6001*i);return o<=0&&o--,this.newDate(o,a,s)}}),n.calendars.julian=a},{\"../main\":571,\"object-assign\":454}],564:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}function s(t,e){return o(t-1,e)+1}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Mayan\",jdEpoch:584282.5,hasYearZero:!0,minMonth:0,firstMonth:0,minDay:0,regionalOptions:{\"\":{name:\"Mayan\",epochs:[\"\",\"\"],monthNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],monthNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],dayNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesMin:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],digits:null,dateFormat:\"YYYY.m.d\",firstDay:0,isRTL:!1,haabMonths:[\"Pop\",\"Uo\",\"Zip\",\"Zotz\",\"Tzec\",\"Xul\",\"Yaxkin\",\"Mol\",\"Chen\",\"Yax\",\"Zac\",\"Ceh\",\"Mac\",\"Kankin\",\"Muan\",\"Pax\",\"Kayab\",\"Cumku\",\"Uayeb\"],tzolkinMonths:[\"Imix\",\"Ik\",\"Akbal\",\"Kan\",\"Chicchan\",\"Cimi\",\"Manik\",\"Lamat\",\"Muluc\",\"Oc\",\"Chuen\",\"Eb\",\"Ben\",\"Ix\",\"Men\",\"Cib\",\"Caban\",\"Etznab\",\"Cauac\",\"Ahau\"]}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},formatYear:function(t){t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year();var e=Math.floor(t/400);return t%=400,t+=t<0?400:0,e+\".\"+Math.floor(t/20)+\".\"+t%20},forYear:function(t){if((t=t.split(\".\")).length<3)throw\"Invalid Mayan year\";for(var e=0,r=0;r<t.length;r++){var n=parseInt(t[r],10);if(Math.abs(n)>19||r>0&&n<0)throw\"Invalid Mayan year\";e=20*e+n}return e},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),18},weekOfYear:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),0},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),360},daysInMonth:function(t,e){return this._validate(t,e,this.minDay,n.local.invalidMonth),20},daysInWeek:function(){return 5},dayOfWeek:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate).day()},weekDay:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),!0},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate).toJD(),a=this._toHaab(i),o=this._toTzolkin(i);return{haabMonthName:this.local.haabMonths[a[0]-1],haabMonth:a[0],haabDay:a[1],tzolkinDayName:this.local.tzolkinMonths[o[0]-1],tzolkinDay:o[0],tzolkinTrecena:o[1]}},_toHaab:function(t){var e=o((t-=this.jdEpoch)+8+340,365);return[Math.floor(e/20)+1,o(e,20)]},_toTzolkin:function(t){return[s((t-=this.jdEpoch)+20,20),s(t+4,13)]},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return i.day()+20*i.month()+360*i.year()+this.jdEpoch},fromJD:function(t){t=Math.floor(t)+.5-this.jdEpoch;var e=Math.floor(t/360);t%=360,t+=t<0?360:0;var r=Math.floor(t/20),n=t%20;return this.newDate(e,r,n)}}),n.calendars.mayan=a},{\"../main\":571,\"object-assign\":454}],565:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar;var o=n.instance(\"gregorian\");i(a.prototype,{name:\"Nanakshahi\",jdEpoch:2257673.5,daysPerMonth:[31,31,31,31,31,30,30,30,30,30,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Nanakshahi\",epochs:[\"BN\",\"AN\"],monthNames:[\"Chet\",\"Vaisakh\",\"Jeth\",\"Harh\",\"Sawan\",\"Bhadon\",\"Assu\",\"Katak\",\"Maghar\",\"Poh\",\"Magh\",\"Phagun\"],monthNamesShort:[\"Che\",\"Vai\",\"Jet\",\"Har\",\"Saw\",\"Bha\",\"Ass\",\"Kat\",\"Mgr\",\"Poh\",\"Mgh\",\"Pha\"],dayNames:[\"Somvaar\",\"Mangalvar\",\"Budhvaar\",\"Veervaar\",\"Shukarvaar\",\"Sanicharvaar\",\"Etvaar\"],dayNamesShort:[\"Som\",\"Mangal\",\"Budh\",\"Veer\",\"Shukar\",\"Sanichar\",\"Et\"],dayNamesMin:[\"So\",\"Ma\",\"Bu\",\"Ve\",\"Sh\",\"Sa\",\"Et\"],digits:null,dateFormat:\"dd-mm-yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear);return o.leapYear(e.year()+(e.year()<1?1:0)+1469)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(1-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidMonth);(t=i.year())<0&&t++;for(var a=i.day(),s=1;s<i.month();s++)a+=this.daysPerMonth[s-1];return a+o.toJD(t+1468,3,13)},fromJD:function(t){t=Math.floor(t+.5);for(var e=Math.floor((t-(this.jdEpoch-1))/366);t>=this.toJD(e+1,1,1);)e++;for(var r=t-Math.floor(this.toJD(e,1,1)+.5)+1,n=1;r>this.daysInMonth(e,n);)r-=this.daysInMonth(e,n),n++;return this.newDate(e,n,r)}}),n.calendars.nanakshahi=a},{\"../main\":571,\"object-assign\":454}],566:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Nepali\",jdEpoch:1700709.5,daysPerMonth:[31,31,32,32,31,30,30,29,30,29,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,daysPerYear:365,regionalOptions:{\"\":{name:\"Nepali\",epochs:[\"BBS\",\"ABS\"],monthNames:[\"Baisakh\",\"Jestha\",\"Ashadh\",\"Shrawan\",\"Bhadra\",\"Ashwin\",\"Kartik\",\"Mangsir\",\"Paush\",\"Mangh\",\"Falgun\",\"Chaitra\"],monthNamesShort:[\"Bai\",\"Je\",\"As\",\"Shra\",\"Bha\",\"Ash\",\"Kar\",\"Mang\",\"Pau\",\"Ma\",\"Fal\",\"Chai\"],dayNames:[\"Aaitabaar\",\"Sombaar\",\"Manglbaar\",\"Budhabaar\",\"Bihibaar\",\"Shukrabaar\",\"Shanibaar\"],dayNamesShort:[\"Aaita\",\"Som\",\"Mangl\",\"Budha\",\"Bihi\",\"Shukra\",\"Shani\"],dayNamesMin:[\"Aai\",\"So\",\"Man\",\"Bu\",\"Bi\",\"Shu\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:1,isRTL:!1}},leapYear:function(t){return this.daysInYear(t)!==this.daysPerYear},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){if(t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t])return this.daysPerYear;for(var e=0,r=this.minMonth;r<=12;r++)e+=this.NEPALI_CALENDAR_DATA[t][r];return e},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t]?this.daysPerMonth[e-1]:this.NEPALI_CALENDAR_DATA[t][e]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=n.instance(),o=0,s=e,l=t;this._createMissingCalendarData(t);var c=t-(s>9||9===s&&r>=this.NEPALI_CALENDAR_DATA[l][0]?56:57);for(9!==e&&(o=r,s--);9!==s;)s<=0&&(s=12,l--),o+=this.NEPALI_CALENDAR_DATA[l][s],s--;return 9===e?(o+=r-this.NEPALI_CALENDAR_DATA[l][0])<0&&(o+=a.daysInYear(c)):o+=this.NEPALI_CALENDAR_DATA[l][9]-this.NEPALI_CALENDAR_DATA[l][0],a.newDate(c,1,1).add(o,\"d\").toJD()},fromJD:function(t){var e=n.instance().fromJD(t),r=e.year(),i=e.dayOfYear(),a=r+56;this._createMissingCalendarData(a);for(var o=9,s=this.NEPALI_CALENDAR_DATA[a][0],l=this.NEPALI_CALENDAR_DATA[a][o]-s+1;i>l;)++o>12&&(o=1,a++),l+=this.NEPALI_CALENDAR_DATA[a][o];var c=this.NEPALI_CALENDAR_DATA[a][o]-(l-i);return this.newDate(a,o,c)},_createMissingCalendarData:function(t){var e=this.daysPerMonth.slice(0);e.unshift(17);for(var r=t-1;r<t+2;r++)\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[r]&&(this.NEPALI_CALENDAR_DATA[r]=e)},NEPALI_CALENDAR_DATA:{1970:[18,31,31,32,31,31,31,30,29,30,29,30,30],1971:[18,31,31,32,31,32,30,30,29,30,29,30,30],1972:[17,31,32,31,32,31,30,30,30,29,29,30,30],1973:[19,30,32,31,32,31,30,30,30,29,30,29,31],1974:[19,31,31,32,30,31,31,30,29,30,29,30,30],1975:[18,31,31,32,32,30,31,30,29,30,29,30,30],1976:[17,31,32,31,32,31,30,30,30,29,29,30,31],1977:[18,31,32,31,32,31,31,29,30,29,30,29,31],1978:[18,31,31,32,31,31,31,30,29,30,29,30,30],1979:[18,31,31,32,32,31,30,30,29,30,29,30,30],1980:[17,31,32,31,32,31,30,30,30,29,29,30,31],1981:[18,31,31,31,32,31,31,29,30,30,29,30,30],1982:[18,31,31,32,31,31,31,30,29,30,29,30,30],1983:[18,31,31,32,32,31,30,30,29,30,29,30,30],1984:[17,31,32,31,32,31,30,30,30,29,29,30,31],1985:[18,31,31,31,32,31,31,29,30,30,29,30,30],1986:[18,31,31,32,31,31,31,30,29,30,29,30,30],1987:[18,31,32,31,32,31,30,30,29,30,29,30,30],1988:[17,31,32,31,32,31,30,30,30,29,29,30,31],1989:[18,31,31,31,32,31,31,30,29,30,29,30,30],1990:[18,31,31,32,31,31,31,30,29,30,29,30,30],1991:[18,31,32,31,32,31,30,30,29,30,29,30,30],1992:[17,31,32,31,32,31,30,30,30,29,30,29,31],1993:[18,31,31,31,32,31,31,30,29,30,29,30,30],1994:[18,31,31,32,31,31,31,30,29,30,29,30,30],1995:[17,31,32,31,32,31,30,30,30,29,29,30,30],1996:[17,31,32,31,32,31,30,30,30,29,30,29,31],1997:[18,31,31,32,31,31,31,30,29,30,29,30,30],1998:[18,31,31,32,31,31,31,30,29,30,29,30,30],1999:[17,31,32,31,32,31,30,30,30,29,29,30,31],2000:[17,30,32,31,32,31,30,30,30,29,30,29,31],2001:[18,31,31,32,31,31,31,30,29,30,29,30,30],2002:[18,31,31,32,32,31,30,30,29,30,29,30,30],2003:[17,31,32,31,32,31,30,30,30,29,29,30,31],2004:[17,30,32,31,32,31,30,30,30,29,30,29,31],2005:[18,31,31,32,31,31,31,30,29,30,29,30,30],2006:[18,31,31,32,32,31,30,30,29,30,29,30,30],2007:[17,31,32,31,32,31,30,30,30,29,29,30,31],2008:[17,31,31,31,32,31,31,29,30,30,29,29,31],2009:[18,31,31,32,31,31,31,30,29,30,29,30,30],2010:[18,31,31,32,32,31,30,30,29,30,29,30,30],2011:[17,31,32,31,32,31,30,30,30,29,29,30,31],2012:[17,31,31,31,32,31,31,29,30,30,29,30,30],2013:[18,31,31,32,31,31,31,30,29,30,29,30,30],2014:[18,31,31,32,32,31,30,30,29,30,29,30,30],2015:[17,31,32,31,32,31,30,30,30,29,29,30,31],2016:[17,31,31,31,32,31,31,29,30,30,29,30,30],2017:[18,31,31,32,31,31,31,30,29,30,29,30,30],2018:[18,31,32,31,32,31,30,30,29,30,29,30,30],2019:[17,31,32,31,32,31,30,30,30,29,30,29,31],2020:[17,31,31,31,32,31,31,30,29,30,29,30,30],2021:[18,31,31,32,31,31,31,30,29,30,29,30,30],2022:[17,31,32,31,32,31,30,30,30,29,29,30,30],2023:[17,31,32,31,32,31,30,30,30,29,30,29,31],2024:[17,31,31,31,32,31,31,30,29,30,29,30,30],2025:[18,31,31,32,31,31,31,30,29,30,29,30,30],2026:[17,31,32,31,32,31,30,30,30,29,29,30,31],2027:[17,30,32,31,32,31,30,30,30,29,30,29,31],2028:[17,31,31,32,31,31,31,30,29,30,29,30,30],2029:[18,31,31,32,31,32,30,30,29,30,29,30,30],2030:[17,31,32,31,32,31,30,30,30,30,30,30,31],2031:[17,31,32,31,32,31,31,31,31,31,31,31,31],2032:[17,32,32,32,32,32,32,32,32,32,32,32,32],2033:[18,31,31,32,32,31,30,30,29,30,29,30,30],2034:[17,31,32,31,32,31,30,30,30,29,29,30,31],2035:[17,30,32,31,32,31,31,29,30,30,29,29,31],2036:[17,31,31,32,31,31,31,30,29,30,29,30,30],2037:[18,31,31,32,32,31,30,30,29,30,29,30,30],2038:[17,31,32,31,32,31,30,30,30,29,29,30,31],2039:[17,31,31,31,32,31,31,29,30,30,29,30,30],2040:[17,31,31,32,31,31,31,30,29,30,29,30,30],2041:[18,31,31,32,32,31,30,30,29,30,29,30,30],2042:[17,31,32,31,32,31,30,30,30,29,29,30,31],2043:[17,31,31,31,32,31,31,29,30,30,29,30,30],2044:[17,31,31,32,31,31,31,30,29,30,29,30,30],2045:[18,31,32,31,32,31,30,30,29,30,29,30,30],2046:[17,31,32,31,32,31,30,30,30,29,29,30,31],2047:[17,31,31,31,32,31,31,30,29,30,29,30,30],2048:[17,31,31,32,31,31,31,30,29,30,29,30,30],2049:[17,31,32,31,32,31,30,30,30,29,29,30,30],2050:[17,31,32,31,32,31,30,30,30,29,30,29,31],2051:[17,31,31,31,32,31,31,30,29,30,29,30,30],2052:[17,31,31,32,31,31,31,30,29,30,29,30,30],2053:[17,31,32,31,32,31,30,30,30,29,29,30,30],2054:[17,31,32,31,32,31,30,30,30,29,30,29,31],2055:[17,31,31,32,31,31,31,30,29,30,30,29,30],2056:[17,31,31,32,31,32,30,30,29,30,29,30,30],2057:[17,31,32,31,32,31,30,30,30,29,29,30,31],2058:[17,30,32,31,32,31,30,30,30,29,30,29,31],2059:[17,31,31,32,31,31,31,30,29,30,29,30,30],2060:[17,31,31,32,32,31,30,30,29,30,29,30,30],2061:[17,31,32,31,32,31,30,30,30,29,29,30,31],2062:[17,30,32,31,32,31,31,29,30,29,30,29,31],2063:[17,31,31,32,31,31,31,30,29,30,29,30,30],2064:[17,31,31,32,32,31,30,30,29,30,29,30,30],2065:[17,31,32,31,32,31,30,30,30,29,29,30,31],2066:[17,31,31,31,32,31,31,29,30,30,29,29,31],2067:[17,31,31,32,31,31,31,30,29,30,29,30,30],2068:[17,31,31,32,32,31,30,30,29,30,29,30,30],2069:[17,31,32,31,32,31,30,30,30,29,29,30,31],2070:[17,31,31,31,32,31,31,29,30,30,29,30,30],2071:[17,31,31,32,31,31,31,30,29,30,29,30,30],2072:[17,31,32,31,32,31,30,30,29,30,29,30,30],2073:[17,31,32,31,32,31,30,30,30,29,29,30,31],2074:[17,31,31,31,32,31,31,30,29,30,29,30,30],2075:[17,31,31,32,31,31,31,30,29,30,29,30,30],2076:[16,31,32,31,32,31,30,30,30,29,29,30,30],2077:[17,31,32,31,32,31,30,30,30,29,30,29,31],2078:[17,31,31,31,32,31,31,30,29,30,29,30,30],2079:[17,31,31,32,31,31,31,30,29,30,29,30,30],2080:[16,31,32,31,32,31,30,30,30,29,29,30,30],2081:[17,31,31,32,32,31,30,30,30,29,30,30,30],2082:[17,31,32,31,32,31,30,30,30,29,30,30,30],2083:[17,31,31,32,31,31,30,30,30,29,30,30,30],2084:[17,31,31,32,31,31,30,30,30,29,30,30,30],2085:[17,31,32,31,32,31,31,30,30,29,30,30,30],2086:[17,31,32,31,32,31,30,30,30,29,30,30,30],2087:[16,31,31,32,31,31,31,30,30,29,30,30,30],2088:[16,30,31,32,32,30,31,30,30,29,30,30,30],2089:[17,31,32,31,32,31,30,30,30,29,30,30,30],2090:[17,31,32,31,32,31,30,30,30,29,30,30,30],2091:[16,31,31,32,31,31,31,30,30,29,30,30,30],2092:[16,31,31,32,32,31,30,30,30,29,30,30,30],2093:[17,31,32,31,32,31,30,30,30,29,30,30,30],2094:[17,31,31,32,31,31,30,30,30,29,30,30,30],2095:[17,31,31,32,31,31,31,30,29,30,30,30,30],2096:[17,30,31,32,32,31,30,30,29,30,29,30,30],2097:[17,31,32,31,32,31,30,30,30,29,30,30,30],2098:[17,31,31,32,31,31,31,29,30,29,30,30,31],2099:[17,31,31,32,31,31,31,30,29,29,30,30,30],2100:[17,31,32,31,32,30,31,30,29,30,29,30,30]}}),n.calendars.nepali=a},{\"../main\":571,\"object-assign\":454}],567:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Persian\",jdEpoch:1948320.5,daysPerMonth:[31,31,31,31,31,31,30,30,30,30,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Persian\",epochs:[\"BP\",\"AP\"],monthNames:[\"Farvardin\",\"Ordibehesht\",\"Khordad\",\"Tir\",\"Mordad\",\"Shahrivar\",\"Mehr\",\"Aban\",\"Azar\",\"Day\",\"Bahman\",\"Esfand\"],monthNamesShort:[\"Far\",\"Ord\",\"Kho\",\"Tir\",\"Mor\",\"Sha\",\"Meh\",\"Aba\",\"Aza\",\"Day\",\"Bah\",\"Esf\"],dayNames:[\"Yekshambe\",\"Doshambe\",\"Seshambe\",\"Ch\\xe6harshambe\",\"Panjshambe\",\"Jom'e\",\"Shambe\"],dayNamesShort:[\"Yek\",\"Do\",\"Se\",\"Ch\\xe6\",\"Panj\",\"Jom\",\"Sha\"],dayNamesMin:[\"Ye\",\"Do\",\"Se\",\"Ch\",\"Pa\",\"Jo\",\"Sh\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 682*((e.year()-(e.year()>0?474:473))%2820+474+38)%2816<682},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-(n.dayOfWeek()+1)%7,\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t-(t>=0?474:473),s=474+o(a,2820);return r+(e<=7?31*(e-1):30*(e-1)+6)+Math.floor((682*s-110)/2816)+365*(s-1)+1029983*Math.floor(a/2820)+this.jdEpoch-1},fromJD:function(t){var e=(t=Math.floor(t)+.5)-this.toJD(475,1,1),r=Math.floor(e/1029983),n=o(e,1029983),i=2820;if(1029982!==n){var a=Math.floor(n/366),s=o(n,366);i=Math.floor((2134*a+2816*s+2815)/1028522)+a+1}var l=i+2820*r+474;l=l<=0?l-1:l;var c=t-this.toJD(l,1,1)+1,u=c<=186?Math.ceil(c/31):Math.ceil((c-6)/30),h=t-this.toJD(l,u,1)+1;return this.newDate(l,u,h)}}),n.calendars.persian=a,n.calendars.jalali=a},{\"../main\":571,\"object-assign\":454}],568:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Taiwan\",jdEpoch:2419402.5,yearsOffset:1911,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Taiwan\",epochs:[\"BROC\",\"ROC\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)},_g2tYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)}}),n.calendars.taiwan=o},{\"../main\":571,\"object-assign\":454}],569:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Thai\",jdEpoch:1523098.5,yearsOffset:543,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Thai\",epochs:[\"BBE\",\"BE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)},_g2tYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)}}),n.calendars.thai=o},{\"../main\":571,\"object-assign\":454}],570:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"UmmAlQura\",hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Umm al-Qura\",epochs:[\"BH\",\"AH\"],monthNames:[\"Al-Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' Al-Thani\",\"Jumada Al-Awwal\",\"Jumada Al-Thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-Ahad\",\"Yawm al-Ithnain\",\"Yawm al-Thal\\u0101th\\u0101\\u2019\",\"Yawm al-Arba\\u2018\\u0101\\u2019\",\"Yawm al-Kham\\u012bs\",\"Yawm al-Jum\\u2018a\",\"Yawm al-Sabt\"],dayNamesMin:[\"Ah\",\"Ith\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!0}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 355===this.daysInYear(e.year())},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){for(var e=0,r=1;r<=12;r++)e+=this.daysInMonth(t,r);return e},daysInMonth:function(t,e){for(var r=this._validate(t,e,this.minDay,n.local.invalidMonth).toJD()-24e5+.5,i=0,a=0;a<o.length;a++){if(o[a]>r)return o[i]-o[i-1];i++}return 30},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate),a=12*(i.year()-1)+i.month()-15292;return i.day()+o[a-1]-1+24e5-.5},fromJD:function(t){for(var e=t-24e5+.5,r=0,n=0;n<o.length&&!(o[n]>e);n++)r++;var i=r+15292,a=Math.floor((i-1)/12),s=a+1,l=i-12*a,c=e-o[r-1]+1;return this.newDate(s,l,c)},isValid:function(t,e,r){var i=n.baseCalendar.prototype.isValid.apply(this,arguments);return i&&(i=(t=null!=t.year?t.year:t)>=1276&&t<=1500),i},_validate:function(t,e,r,i){var a=n.baseCalendar.prototype._validate.apply(this,arguments);if(a.year<1276||a.year>1500)throw i.replace(/\\{0\\}/,this.local.name);return a}}),n.calendars.ummalqura=a;var o=[20,50,79,109,138,168,197,227,256,286,315,345,374,404,433,463,492,522,551,581,611,641,670,700,729,759,788,818,847,877,906,936,965,995,1024,1054,1083,1113,1142,1172,1201,1231,1260,1290,1320,1350,1379,1409,1438,1468,1497,1527,1556,1586,1615,1645,1674,1704,1733,1763,1792,1822,1851,1881,1910,1940,1969,1999,2028,2058,2087,2117,2146,2176,2205,2235,2264,2294,2323,2353,2383,2413,2442,2472,2501,2531,2560,2590,2619,2649,2678,2708,2737,2767,2796,2826,2855,2885,2914,2944,2973,3003,3032,3062,3091,3121,3150,3180,3209,3239,3268,3298,3327,3357,3386,3416,3446,3476,3505,3535,3564,3594,3623,3653,3682,3712,3741,3771,3800,3830,3859,3889,3918,3948,3977,4007,4036,4066,4095,4125,4155,4185,4214,4244,4273,4303,4332,4362,4391,4421,4450,4480,4509,4539,4568,4598,4627,4657,4686,4716,4745,4775,4804,4834,4863,4893,4922,4952,4981,5011,5040,5070,5099,5129,5158,5188,5218,5248,5277,5307,5336,5366,5395,5425,5454,5484,5513,5543,5572,5602,5631,5661,5690,5720,5749,5779,5808,5838,5867,5897,5926,5956,5985,6015,6044,6074,6103,6133,6162,6192,6221,6251,6281,6311,6340,6370,6399,6429,6458,6488,6517,6547,6576,6606,6635,6665,6694,6724,6753,6783,6812,6842,6871,6901,6930,6960,6989,7019,7048,7078,7107,7137,7166,7196,7225,7255,7284,7314,7344,7374,7403,7433,7462,7492,7521,7551,7580,7610,7639,7669,7698,7728,7757,7787,7816,7846,7875,7905,7934,7964,7993,8023,8053,8083,8112,8142,8171,8201,8230,8260,8289,8319,8348,8378,8407,8437,8466,8496,8525,8555,8584,8614,8643,8673,8702,8732,8761,8791,8821,8850,8880,8909,8938,8968,8997,9027,9056,9086,9115,9145,9175,9205,9234,9264,9293,9322,9352,9381,9410,9440,9470,9499,9529,9559,9589,9618,9648,9677,9706,9736,9765,9794,9824,9853,9883,9913,9943,9972,10002,10032,10061,10090,10120,10149,10178,10208,10237,10267,10297,10326,10356,10386,10415,10445,10474,10504,10533,10562,10592,10621,10651,10680,10710,10740,10770,10799,10829,10858,10888,10917,10947,10976,11005,11035,11064,11094,11124,11153,11183,11213,11242,11272,11301,11331,11360,11389,11419,11448,11478,11507,11537,11567,11596,11626,11655,11685,11715,11744,11774,11803,11832,11862,11891,11921,11950,11980,12010,12039,12069,12099,12128,12158,12187,12216,12246,12275,12304,12334,12364,12393,12423,12453,12483,12512,12542,12571,12600,12630,12659,12688,12718,12747,12777,12807,12837,12866,12896,12926,12955,12984,13014,13043,13072,13102,13131,13161,13191,13220,13250,13280,13310,13339,13368,13398,13427,13456,13486,13515,13545,13574,13604,13634,13664,13693,13723,13752,13782,13811,13840,13870,13899,13929,13958,13988,14018,14047,14077,14107,14136,14166,14195,14224,14254,14283,14313,14342,14372,14401,14431,14461,14490,14520,14550,14579,14609,14638,14667,14697,14726,14756,14785,14815,14844,14874,14904,14933,14963,14993,15021,15051,15081,15110,15140,15169,15199,15228,15258,15287,15317,15347,15377,15406,15436,15465,15494,15524,15553,15582,15612,15641,15671,15701,15731,15760,15790,15820,15849,15878,15908,15937,15966,15996,16025,16055,16085,16114,16144,16174,16204,16233,16262,16292,16321,16350,16380,16409,16439,16468,16498,16528,16558,16587,16617,16646,16676,16705,16734,16764,16793,16823,16852,16882,16912,16941,16971,17001,17030,17060,17089,17118,17148,17177,17207,17236,17266,17295,17325,17355,17384,17414,17444,17473,17502,17532,17561,17591,17620,17650,17679,17709,17738,17768,17798,17827,17857,17886,17916,17945,17975,18004,18034,18063,18093,18122,18152,18181,18211,18241,18270,18300,18330,18359,18388,18418,18447,18476,18506,18535,18565,18595,18625,18654,18684,18714,18743,18772,18802,18831,18860,18890,18919,18949,18979,19008,19038,19068,19098,19127,19156,19186,19215,19244,19274,19303,19333,19362,19392,19422,19452,19481,19511,19540,19570,19599,19628,19658,19687,19717,19746,19776,19806,19836,19865,19895,19924,19954,19983,20012,20042,20071,20101,20130,20160,20190,20219,20249,20279,20308,20338,20367,20396,20426,20455,20485,20514,20544,20573,20603,20633,20662,20692,20721,20751,20780,20810,20839,20869,20898,20928,20957,20987,21016,21046,21076,21105,21135,21164,21194,21223,21253,21282,21312,21341,21371,21400,21430,21459,21489,21519,21548,21578,21607,21637,21666,21696,21725,21754,21784,21813,21843,21873,21902,21932,21962,21991,22021,22050,22080,22109,22138,22168,22197,22227,22256,22286,22316,22346,22375,22405,22434,22464,22493,22522,22552,22581,22611,22640,22670,22700,22730,22759,22789,22818,22848,22877,22906,22936,22965,22994,23024,23054,23083,23113,23143,23173,23202,23232,23261,23290,23320,23349,23379,23408,23438,23467,23497,23527,23556,23586,23616,23645,23674,23704,23733,23763,23792,23822,23851,23881,23910,23940,23970,23999,24029,24058,24088,24117,24147,24176,24206,24235,24265,24294,24324,24353,24383,24413,24442,24472,24501,24531,24560,24590,24619,24648,24678,24707,24737,24767,24796,24826,24856,24885,24915,24944,24974,25003,25032,25062,25091,25121,25150,25180,25210,25240,25269,25299,25328,25358,25387,25416,25446,25475,25505,25534,25564,25594,25624,25653,25683,25712,25742,25771,25800,25830,25859,25888,25918,25948,25977,26007,26037,26067,26096,26126,26155,26184,26214,26243,26272,26302,26332,26361,26391,26421,26451,26480,26510,26539,26568,26598,26627,26656,26686,26715,26745,26775,26805,26834,26864,26893,26923,26952,26982,27011,27041,27070,27099,27129,27159,27188,27218,27248,27277,27307,27336,27366,27395,27425,27454,27484,27513,27542,27572,27602,27631,27661,27691,27720,27750,27779,27809,27838,27868,27897,27926,27956,27985,28015,28045,28074,28104,28134,28163,28193,28222,28252,28281,28310,28340,28369,28399,28428,28458,28488,28517,28547,28577,28607,28636,28665,28695,28724,28754,28783,28813,28843,28872,28901,28931,28960,28990,29019,29049,29078,29108,29137,29167,29196,29226,29255,29285,29315,29345,29375,29404,29434,29463,29492,29522,29551,29580,29610,29640,29669,29699,29729,29759,29788,29818,29847,29876,29906,29935,29964,29994,30023,30053,30082,30112,30141,30171,30200,30230,30259,30289,30318,30348,30378,30408,30437,30467,30496,30526,30555,30585,30614,30644,30673,30703,30732,30762,30791,30821,30850,30880,30909,30939,30968,30998,31027,31057,31086,31116,31145,31175,31204,31234,31263,31293,31322,31352,31381,31411,31441,31471,31500,31530,31559,31589,31618,31648,31676,31706,31736,31766,31795,31825,31854,31884,31913,31943,31972,32002,32031,32061,32090,32120,32150,32180,32209,32239,32268,32298,32327,32357,32386,32416,32445,32475,32504,32534,32563,32593,32622,32652,32681,32711,32740,32770,32799,32829,32858,32888,32917,32947,32976,33006,33035,33065,33094,33124,33153,33183,33213,33243,33272,33302,33331,33361,33390,33420,33450,33479,33509,33539,33568,33598,33627,33657,33686,33716,33745,33775,33804,33834,33863,33893,33922,33952,33981,34011,34040,34069,34099,34128,34158,34187,34217,34247,34277,34306,34336,34365,34395,34424,34454,34483,34512,34542,34571,34601,34631,34660,34690,34719,34749,34778,34808,34837,34867,34896,34926,34955,34985,35015,35044,35074,35103,35133,35162,35192,35222,35251,35280,35310,35340,35370,35399,35429,35458,35488,35517,35547,35576,35605,35635,35665,35694,35723,35753,35782,35811,35841,35871,35901,35930,35960,35989,36019,36048,36078,36107,36136,36166,36195,36225,36254,36284,36314,36343,36373,36403,36433,36462,36492,36521,36551,36580,36610,36639,36669,36698,36728,36757,36786,36816,36845,36875,36904,36934,36963,36993,37022,37052,37081,37111,37141,37170,37200,37229,37259,37288,37318,37347,37377,37406,37436,37465,37495,37524,37554,37584,37613,37643,37672,37701,37731,37760,37790,37819,37849,37878,37908,37938,37967,37997,38027,38056,38085,38115,38144,38174,38203,38233,38262,38292,38322,38351,38381,38410,38440,38469,38499,38528,38558,38587,38617,38646,38676,38705,38735,38764,38794,38823,38853,38882,38912,38941,38971,39001,39030,39059,39089,39118,39148,39178,39208,39237,39267,39297,39326,39355,39385,39414,39444,39473,39503,39532,39562,39592,39621,39650,39680,39709,39739,39768,39798,39827,39857,39886,39916,39946,39975,40005,40035,40064,40094,40123,40153,40182,40212,40241,40271,40300,40330,40359,40389,40418,40448,40477,40507,40536,40566,40595,40625,40655,40685,40714,40744,40773,40803,40832,40862,40892,40921,40951,40980,41009,41039,41068,41098,41127,41157,41186,41216,41245,41275,41304,41334,41364,41393,41422,41452,41481,41511,41540,41570,41599,41629,41658,41688,41718,41748,41777,41807,41836,41865,41894,41924,41953,41983,42012,42042,42072,42102,42131,42161,42190,42220,42249,42279,42308,42337,42367,42397,42426,42456,42485,42515,42545,42574,42604,42633,42662,42692,42721,42751,42780,42810,42839,42869,42899,42929,42958,42988,43017,43046,43076,43105,43135,43164,43194,43223,43253,43283,43312,43342,43371,43401,43430,43460,43489,43519,43548,43578,43607,43637,43666,43696,43726,43755,43785,43814,43844,43873,43903,43932,43962,43991,44021,44050,44080,44109,44139,44169,44198,44228,44258,44287,44317,44346,44375,44405,44434,44464,44493,44523,44553,44582,44612,44641,44671,44700,44730,44759,44788,44818,44847,44877,44906,44936,44966,44996,45025,45055,45084,45114,45143,45172,45202,45231,45261,45290,45320,45350,45380,45409,45439,45468,45498,45527,45556,45586,45615,45644,45674,45704,45733,45763,45793,45823,45852,45882,45911,45940,45970,45999,46028,46058,46088,46117,46147,46177,46206,46236,46265,46295,46324,46354,46383,46413,46442,46472,46501,46531,46560,46590,46620,46649,46679,46708,46738,46767,46797,46826,46856,46885,46915,46944,46974,47003,47033,47063,47092,47122,47151,47181,47210,47240,47269,47298,47328,47357,47387,47417,47446,47476,47506,47535,47565,47594,47624,47653,47682,47712,47741,47771,47800,47830,47860,47890,47919,47949,47978,48008,48037,48066,48096,48125,48155,48184,48214,48244,48273,48303,48333,48362,48392,48421,48450,48480,48509,48538,48568,48598,48627,48657,48687,48717,48746,48776,48805,48834,48864,48893,48922,48952,48982,49011,49041,49071,49100,49130,49160,49189,49218,49248,49277,49306,49336,49365,49395,49425,49455,49484,49514,49543,49573,49602,49632,49661,49690,49720,49749,49779,49809,49838,49868,49898,49927,49957,49986,50016,50045,50075,50104,50133,50163,50192,50222,50252,50281,50311,50340,50370,50400,50429,50459,50488,50518,50547,50576,50606,50635,50665,50694,50724,50754,50784,50813,50843,50872,50902,50931,50960,50990,51019,51049,51078,51108,51138,51167,51197,51227,51256,51286,51315,51345,51374,51403,51433,51462,51492,51522,51552,51582,51611,51641,51670,51699,51729,51758,51787,51816,51846,51876,51906,51936,51965,51995,52025,52054,52083,52113,52142,52171,52200,52230,52260,52290,52319,52349,52379,52408,52438,52467,52497,52526,52555,52585,52614,52644,52673,52703,52733,52762,52792,52822,52851,52881,52910,52939,52969,52998,53028,53057,53087,53116,53146,53176,53205,53235,53264,53294,53324,53353,53383,53412,53441,53471,53500,53530,53559,53589,53619,53648,53678,53708,53737,53767,53796,53825,53855,53884,53913,53943,53973,54003,54032,54062,54092,54121,54151,54180,54209,54239,54268,54297,54327,54357,54387,54416,54446,54476,54505,54535,54564,54593,54623,54652,54681,54711,54741,54770,54800,54830,54859,54889,54919,54948,54977,55007,55036,55066,55095,55125,55154,55184,55213,55243,55273,55302,55332,55361,55391,55420,55450,55479,55508,55538,55567,55597,55627,55657,55686,55716,55745,55775,55804,55834,55863,55892,55922,55951,55981,56011,56040,56070,56100,56129,56159,56188,56218,56247,56276,56306,56335,56365,56394,56424,56454,56483,56513,56543,56572,56601,56631,56660,56690,56719,56749,56778,56808,56837,56867,56897,56926,56956,56985,57015,57044,57074,57103,57133,57162,57192,57221,57251,57280,57310,57340,57369,57399,57429,57458,57487,57517,57546,57576,57605,57634,57664,57694,57723,57753,57783,57813,57842,57871,57901,57930,57959,57989,58018,58048,58077,58107,58137,58167,58196,58226,58255,58285,58314,58343,58373,58402,58432,58461,58491,58521,58551,58580,58610,58639,58669,58698,58727,58757,58786,58816,58845,58875,58905,58934,58964,58994,59023,59053,59082,59111,59141,59170,59200,59229,59259,59288,59318,59348,59377,59407,59436,59466,59495,59525,59554,59584,59613,59643,59672,59702,59731,59761,59791,59820,59850,59879,59909,59939,59968,59997,60027,60056,60086,60115,60145,60174,60204,60234,60264,60293,60323,60352,60381,60411,60440,60469,60499,60528,60558,60588,60618,60648,60677,60707,60736,60765,60795,60824,60853,60883,60912,60942,60972,61002,61031,61061,61090,61120,61149,61179,61208,61237,61267,61296,61326,61356,61385,61415,61445,61474,61504,61533,61563,61592,61621,61651,61680,61710,61739,61769,61799,61828,61858,61888,61917,61947,61976,62006,62035,62064,62094,62123,62153,62182,62212,62242,62271,62301,62331,62360,62390,62419,62448,62478,62507,62537,62566,62596,62625,62655,62685,62715,62744,62774,62803,62832,62862,62891,62921,62950,62980,63009,63039,63069,63099,63128,63157,63187,63216,63246,63275,63305,63334,63363,63393,63423,63453,63482,63512,63541,63571,63600,63630,63659,63689,63718,63747,63777,63807,63836,63866,63895,63925,63955,63984,64014,64043,64073,64102,64131,64161,64190,64220,64249,64279,64309,64339,64368,64398,64427,64457,64486,64515,64545,64574,64603,64633,64663,64692,64722,64752,64782,64811,64841,64870,64899,64929,64958,64987,65017,65047,65076,65106,65136,65166,65195,65225,65254,65283,65313,65342,65371,65401,65431,65460,65490,65520,65549,65579,65608,65638,65667,65697,65726,65755,65785,65815,65844,65874,65903,65933,65963,65992,66022,66051,66081,66110,66140,66169,66199,66228,66258,66287,66317,66346,66376,66405,66435,66465,66494,66524,66553,66583,66612,66641,66671,66700,66730,66760,66789,66819,66849,66878,66908,66937,66967,66996,67025,67055,67084,67114,67143,67173,67203,67233,67262,67292,67321,67351,67380,67409,67439,67468,67497,67527,67557,67587,67617,67646,67676,67705,67735,67764,67793,67823,67852,67882,67911,67941,67971,68e3,68030,68060,68089,68119,68148,68177,68207,68236,68266,68295,68325,68354,68384,68414,68443,68473,68502,68532,68561,68591,68620,68650,68679,68708,68738,68768,68797,68827,68857,68886,68916,68946,68975,69004,69034,69063,69092,69122,69152,69181,69211,69240,69270,69300,69330,69359,69388,69418,69447,69476,69506,69535,69565,69595,69624,69654,69684,69713,69743,69772,69802,69831,69861,69890,69919,69949,69978,70008,70038,70067,70097,70126,70156,70186,70215,70245,70274,70303,70333,70362,70392,70421,70451,70481,70510,70540,70570,70599,70629,70658,70687,70717,70746,70776,70805,70835,70864,70894,70924,70954,70983,71013,71042,71071,71101,71130,71159,71189,71218,71248,71278,71308,71337,71367,71397,71426,71455,71485,71514,71543,71573,71602,71632,71662,71691,71721,71751,71781,71810,71839,71869,71898,71927,71957,71986,72016,72046,72075,72105,72135,72164,72194,72223,72253,72282,72311,72341,72370,72400,72429,72459,72489,72518,72548,72577,72607,72637,72666,72695,72725,72754,72784,72813,72843,72872,72902,72931,72961,72991,73020,73050,73080,73109,73139,73168,73197,73227,73256,73286,73315,73345,73375,73404,73434,73464,73493,73523,73552,73581,73611,73640,73669,73699,73729,73758,73788,73818,73848,73877,73907,73936,73965,73995,74024,74053,74083,74113,74142,74172,74202,74231,74261,74291,74320,74349,74379,74408,74437,74467,74497,74526,74556,74586,74615,74645,74675,74704,74733,74763,74792,74822,74851,74881,74910,74940,74969,74999,75029,75058,75088,75117,75147,75176,75206,75235,75264,75294,75323,75353,75383,75412,75442,75472,75501,75531,75560,75590,75619,75648,75678,75707,75737,75766,75796,75826,75856,75885,75915,75944,75974,76003,76032,76062,76091,76121,76150,76180,76210,76239,76269,76299,76328,76358,76387,76416,76446,76475,76505,76534,76564,76593,76623,76653,76682,76712,76741,76771,76801,76830,76859,76889,76918,76948,76977,77007,77036,77066,77096,77125,77155,77185,77214,77243,77273,77302,77332,77361,77390,77420,77450,77479,77509,77539,77569,77598,77627,77657,77686,77715,77745,77774,77804,77833,77863,77893,77923,77952,77982,78011,78041,78070,78099,78129,78158,78188,78217,78247,78277,78307,78336,78366,78395,78425,78454,78483,78513,78542,78572,78601,78631,78661,78690,78720,78750,78779,78808,78838,78867,78897,78926,78956,78985,79015,79044,79074,79104,79133,79163,79192,79222,79251,79281,79310,79340,79369,79399,79428,79458,79487,79517,79546,79576,79606,79635,79665,79695,79724,79753,79783,79812,79841,79871,79900,79930,79960,79990]},{\"../main\":571,\"object-assign\":454}],571:[function(t,e,r){var n=t(\"object-assign\");function i(){this.regionalOptions=[],this.regionalOptions[\"\"]={invalidCalendar:\"Calendar {0} not found\",invalidDate:\"Invalid {0} date\",invalidMonth:\"Invalid {0} month\",invalidYear:\"Invalid {0} year\",differentCalendars:\"Cannot mix {0} and {1} dates\"},this.local=this.regionalOptions[\"\"],this.calendars={},this._localCals={}}function a(t,e,r,n){if(this._calendar=t,this._year=e,this._month=r,this._day=n,0===this._calendar._validateLevel&&!this._calendar.isValid(this._year,this._month,this._day))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name)}function o(t,e){return\"000000\".substring(0,e-(t=\"\"+t).length)+t}function s(){this.shortYearCutoff=\"+10\"}function l(t){this.local=this.regionalOptions[t]||this.regionalOptions[\"\"]}n(i.prototype,{instance:function(t,e){t=(t||\"gregorian\").toLowerCase(),e=e||\"\";var r=this._localCals[t+\"-\"+e];if(!r&&this.calendars[t]&&(r=new this.calendars[t](e),this._localCals[t+\"-\"+e]=r),!r)throw(this.local.invalidCalendar||this.regionalOptions[\"\"].invalidCalendar).replace(/\\{0\\}/,t);return r},newDate:function(t,e,r,n,i){return(n=(null!=t&&t.year?t.calendar():\"string\"==typeof n?this.instance(n,i):n)||this.instance()).newDate(t,e,r)},substituteDigits:function(t){return function(e){return(e+\"\").replace(/[0-9]/g,function(e){return t[e]})}},substituteChineseDigits:function(t,e){return function(r){for(var n=\"\",i=0;r>0;){var a=r%10;n=(0===a?\"\":t[a]+e[i])+n,i++,r=Math.floor(r/10)}return 0===n.indexOf(t[1]+e[1])&&(n=n.substr(1)),n||t[0]}}}),n(a.prototype,{newDate:function(t,e,r){return this._calendar.newDate(null==t?this:t,e,r)},year:function(t){return 0===arguments.length?this._year:this.set(t,\"y\")},month:function(t){return 0===arguments.length?this._month:this.set(t,\"m\")},day:function(t){return 0===arguments.length?this._day:this.set(t,\"d\")},date:function(t,e,r){if(!this._calendar.isValid(t,e,r))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name);return this._year=t,this._month=e,this._day=r,this},leapYear:function(){return this._calendar.leapYear(this)},epoch:function(){return this._calendar.epoch(this)},formatYear:function(){return this._calendar.formatYear(this)},monthOfYear:function(){return this._calendar.monthOfYear(this)},weekOfYear:function(){return this._calendar.weekOfYear(this)},daysInYear:function(){return this._calendar.daysInYear(this)},dayOfYear:function(){return this._calendar.dayOfYear(this)},daysInMonth:function(){return this._calendar.daysInMonth(this)},dayOfWeek:function(){return this._calendar.dayOfWeek(this)},weekDay:function(){return this._calendar.weekDay(this)},extraInfo:function(){return this._calendar.extraInfo(this)},add:function(t,e){return this._calendar.add(this,t,e)},set:function(t,e){return this._calendar.set(this,t,e)},compareTo:function(t){if(this._calendar.name!==t._calendar.name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this._calendar.local.name).replace(/\\{1\\}/,t._calendar.local.name);var e=this._year!==t._year?this._year-t._year:this._month!==t._month?this.monthOfYear()-t.monthOfYear():this._day-t._day;return 0===e?0:e<0?-1:1},calendar:function(){return this._calendar},toJD:function(){return this._calendar.toJD(this)},fromJD:function(t){return this._calendar.fromJD(t)},toJSDate:function(){return this._calendar.toJSDate(this)},fromJSDate:function(t){return this._calendar.fromJSDate(t)},toString:function(){return(this.year()<0?\"-\":\"\")+o(Math.abs(this.year()),4)+\"-\"+o(this.month(),2)+\"-\"+o(this.day(),2)}}),n(s.prototype,{_validateLevel:0,newDate:function(t,e,r){return null==t?this.today():(t.year&&(this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),r=t.day(),e=t.month(),t=t.year()),new a(this,t,e,r))},today:function(){return this.fromJSDate(new Date)},epoch:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear).year()<0?this.local.epochs[0]:this.local.epochs[1]},formatYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(e.year()<0?\"-\":\"\")+o(Math.abs(e.year()),4)},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear),12},monthOfYear:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return(r.month()+this.monthsInYear(r)-this.firstMonth)%this.monthsInYear(r)+this.minMonth},fromMonthOfYear:function(t,e){var r=(e+this.firstMonth-2*this.minMonth)%this.monthsInYear(t)+this.minMonth;return this._validate(t,r,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth),r},daysInYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return this.leapYear(e)?366:365},dayOfYear:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return n.toJD()-this.newDate(n.year(),this.fromMonthOfYear(n.year(),this.minMonth),this.minDay).toJD()+1},daysInWeek:function(){return 7},dayOfWeek:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return(Math.floor(this.toJD(n))+2)%this.daysInWeek()},extraInfo:function(t,e,r){return this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),{}},add:function(t,e,r){return this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),this._correctAdd(t,this._add(t,e,r),e,r)},_add:function(t,e,r){if(this._validateLevel++,\"d\"===r||\"w\"===r){var n=t.toJD()+e*(\"w\"===r?this.daysInWeek():1),i=t.calendar().fromJD(n);return this._validateLevel--,[i.year(),i.month(),i.day()]}try{var a=t.year()+(\"y\"===r?e:0),o=t.monthOfYear()+(\"m\"===r?e:0);i=t.day();\"y\"===r?(t.month()!==this.fromMonthOfYear(a,o)&&(o=this.newDate(a,t.month(),this.minDay).monthOfYear()),o=Math.min(o,this.monthsInYear(a)),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o)))):\"m\"===r&&(!function(t){for(;o<t.minMonth;)a--,o+=t.monthsInYear(a);for(var e=t.monthsInYear(a);o>e-1+t.minMonth;)a++,o-=e,e=t.monthsInYear(a)}(this),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o))));var s=[a,this.fromMonthOfYear(a,o),i];return this._validateLevel--,s}catch(t){throw this._validateLevel--,t}},_correctAdd:function(t,e,r,n){if(!(this.hasYearZero||\"y\"!==n&&\"m\"!==n||0!==e[0]&&t.year()>0==e[0]>0)){var i={y:[1,1,\"y\"],m:[1,this.monthsInYear(-1),\"m\"],w:[this.daysInWeek(),this.daysInYear(-1),\"d\"],d:[1,this.daysInYear(-1),\"d\"]}[n],a=r<0?-1:1;e=this._add(t,r*i[0]+a*i[1],i[2])}return t.date(e[0],e[1],e[2])},set:function(t,e,r){this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);var n=\"y\"===r?e:t.year(),i=\"m\"===r?e:t.month(),a=\"d\"===r?e:t.day();return\"y\"!==r&&\"m\"!==r||(a=Math.min(a,this.daysInMonth(n,i))),t.date(n,i,a)},isValid:function(t,e,r){this._validateLevel++;var n=this.hasYearZero||0!==t;if(n){var i=this.newDate(t,e,this.minDay);n=e>=this.minMonth&&e-this.minMonth<this.monthsInYear(i)&&r>=this.minDay&&r-this.minDay<this.daysInMonth(i)}return this._validateLevel--,n},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return c.instance().fromJD(this.toJD(n)).toJSDate()},fromJSDate:function(t){return this.fromJD(c.instance().fromJSDate(t).toJD())},_validate:function(t,e,r,n){if(t.year){if(0===this._validateLevel&&this.name!==t.calendar().name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this.local.name).replace(/\\{1\\}/,t.calendar().local.name);return t}try{if(this._validateLevel++,1===this._validateLevel&&!this.isValid(t,e,r))throw n.replace(/\\{0\\}/,this.local.name);var i=this.newDate(t,e,r);return this._validateLevel--,i}catch(t){throw this._validateLevel--,t}}}),l.prototype=new s,n(l.prototype,{name:\"Gregorian\",jdEpoch:1721425.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Gregorian\",epochs:[\"BCE\",\"CE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==0&&(t%100!=0||t%400==0)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);t=n.year(),e=n.month(),r=n.day(),t<0&&t++,e<3&&(e+=12,t--);var i=Math.floor(t/100),a=2-i+Math.floor(i/4);return Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r+a-1524.5},fromJD:function(t){var e=Math.floor(t+.5),r=Math.floor((e-1867216.25)/36524.25),n=(r=e+1+r-Math.floor(r/4))+1524,i=Math.floor((n-122.1)/365.25),a=Math.floor(365.25*i),o=Math.floor((n-a)/30.6001),s=n-a-Math.floor(30.6001*o),l=o-(o>13.5?13:1),c=i-(l>2.5?4716:4715);return c<=0&&c--,this.newDate(c,l,s)},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),i=new Date(n.year(),n.month()-1,n.day());return i.setHours(0),i.setMinutes(0),i.setSeconds(0),i.setMilliseconds(0),i.setHours(i.getHours()>12?i.getHours()+2:0),i},fromJSDate:function(t){return this.newDate(t.getFullYear(),t.getMonth()+1,t.getDate())}});var c=e.exports=new i;c.cdate=a,c.baseCalendar=s,c.calendars.gregorian=l},{\"object-assign\":454}],572:[function(t,e,r){var n=t(\"object-assign\"),i=t(\"./main\");n(i.regionalOptions[\"\"],{invalidArguments:\"Invalid arguments\",invalidFormat:\"Cannot format a date from another calendar\",missingNumberAt:\"Missing number at position {0}\",unknownNameAt:\"Unknown name at position {0}\",unexpectedLiteralAt:\"Unexpected literal at position {0}\",unexpectedText:\"Additional text found at end\"}),i.local=i.regionalOptions[\"\"],n(i.cdate.prototype,{formatDate:function(t,e){return\"string\"!=typeof t&&(e=t,t=\"\"),this._calendar.formatDate(t||\"\",this,e)}}),n(i.baseCalendar.prototype,{UNIX_EPOCH:i.instance().newDate(1970,1,1).toJD(),SECS_PER_DAY:86400,TICKS_EPOCH:i.instance().jdEpoch,TICKS_PER_DAY:864e9,ATOM:\"yyyy-mm-dd\",COOKIE:\"D, dd M yyyy\",FULL:\"DD, MM d, yyyy\",ISO_8601:\"yyyy-mm-dd\",JULIAN:\"J\",RFC_822:\"D, d M yy\",RFC_850:\"DD, dd-M-yy\",RFC_1036:\"D, d M yy\",RFC_1123:\"D, d M yyyy\",RFC_2822:\"D, d M yyyy\",RSS:\"D, d M yy\",TICKS:\"!\",TIMESTAMP:\"@\",W3C:\"yyyy-mm-dd\",formatDate:function(t,e,r){if(\"string\"!=typeof t&&(r=e,e=t,t=\"\"),!e)return\"\";if(e.calendar()!==this)throw i.local.invalidFormat||i.regionalOptions[\"\"].invalidFormat;t=t||this.local.dateFormat;for(var n,a,o,s,l=(r=r||{}).dayNamesShort||this.local.dayNamesShort,c=r.dayNames||this.local.dayNames,u=r.monthNumbers||this.local.monthNumbers,h=r.monthNamesShort||this.local.monthNamesShort,f=r.monthNames||this.local.monthNames,p=(r.calculateWeek||this.local.calculateWeek,function(e,r){for(var n=1;w+n<t.length&&t.charAt(w+n)===e;)n++;return w+=n-1,Math.floor(n/(r||1))>1}),d=function(t,e,r,n){var i=\"\"+e;if(p(t,n))for(;i.length<r;)i=\"0\"+i;return i},g=this,v=function(t){return\"function\"==typeof u?u.call(g,t,p(\"m\")):x(d(\"m\",t.month(),2))},m=function(t,e){return e?\"function\"==typeof f?f.call(g,t):f[t.month()-g.minMonth]:\"function\"==typeof h?h.call(g,t):h[t.month()-g.minMonth]},y=this.local.digits,x=function(t){return r.localNumbers&&y?y(t):t},b=\"\",_=!1,w=0;w<t.length;w++)if(_)\"'\"!==t.charAt(w)||p(\"'\")?b+=t.charAt(w):_=!1;else switch(t.charAt(w)){case\"d\":b+=x(d(\"d\",e.day(),2));break;case\"D\":b+=(n=\"D\",a=e.dayOfWeek(),o=l,s=c,p(n)?s[a]:o[a]);break;case\"o\":b+=d(\"o\",e.dayOfYear(),3);break;case\"w\":b+=d(\"w\",e.weekOfYear(),2);break;case\"m\":b+=v(e);break;case\"M\":b+=m(e,p(\"M\"));break;case\"y\":b+=p(\"y\",2)?e.year():(e.year()%100<10?\"0\":\"\")+e.year()%100;break;case\"Y\":p(\"Y\",2),b+=e.formatYear();break;case\"J\":b+=e.toJD();break;case\"@\":b+=(e.toJD()-this.UNIX_EPOCH)*this.SECS_PER_DAY;break;case\"!\":b+=(e.toJD()-this.TICKS_EPOCH)*this.TICKS_PER_DAY;break;case\"'\":p(\"'\")?b+=\"'\":_=!0;break;default:b+=t.charAt(w)}return b},parseDate:function(t,e,r){if(null==e)throw i.local.invalidArguments||i.regionalOptions[\"\"].invalidArguments;if(\"\"===(e=\"object\"==typeof e?e.toString():e+\"\"))return null;t=t||this.local.dateFormat;var n=(r=r||{}).shortYearCutoff||this.shortYearCutoff;n=\"string\"!=typeof n?n:this.today().year()%100+parseInt(n,10);for(var a=r.dayNamesShort||this.local.dayNamesShort,o=r.dayNames||this.local.dayNames,s=r.parseMonth||this.local.parseMonth,l=r.monthNumbers||this.local.monthNumbers,c=r.monthNamesShort||this.local.monthNamesShort,u=r.monthNames||this.local.monthNames,h=-1,f=-1,p=-1,d=-1,g=-1,v=!1,m=!1,y=function(e,r){for(var n=1;M+n<t.length&&t.charAt(M+n)===e;)n++;return M+=n-1,Math.floor(n/(r||1))>1},x=function(t,r){var n=y(t,r),a=[2,3,n?4:2,n?4:2,10,11,20][\"oyYJ@!\".indexOf(t)+1],o=new RegExp(\"^-?\\\\d{1,\"+a+\"}\"),s=e.substring(A).match(o);if(!s)throw(i.local.missingNumberAt||i.regionalOptions[\"\"].missingNumberAt).replace(/\\{0\\}/,A);return A+=s[0].length,parseInt(s[0],10)},b=this,_=function(){if(\"function\"==typeof l){y(\"m\");var t=l.call(b,e.substring(A));return A+=t.length,t}return x(\"m\")},w=function(t,r,n,a){for(var o=y(t,a)?n:r,s=0;s<o.length;s++)if(e.substr(A,o[s].length).toLowerCase()===o[s].toLowerCase())return A+=o[s].length,s+b.minMonth;throw(i.local.unknownNameAt||i.regionalOptions[\"\"].unknownNameAt).replace(/\\{0\\}/,A)},k=function(){if(\"function\"==typeof u){var t=y(\"M\")?u.call(b,e.substring(A)):c.call(b,e.substring(A));return A+=t.length,t}return w(\"M\",c,u)},T=function(){if(e.charAt(A)!==t.charAt(M))throw(i.local.unexpectedLiteralAt||i.regionalOptions[\"\"].unexpectedLiteralAt).replace(/\\{0\\}/,A);A++},A=0,M=0;M<t.length;M++)if(m)\"'\"!==t.charAt(M)||y(\"'\")?T():m=!1;else switch(t.charAt(M)){case\"d\":d=x(\"d\");break;case\"D\":w(\"D\",a,o);break;case\"o\":g=x(\"o\");break;case\"w\":x(\"w\");break;case\"m\":p=_();break;case\"M\":p=k();break;case\"y\":var S=M;v=!y(\"y\",2),M=S,f=x(\"y\",2);break;case\"Y\":f=x(\"Y\",2);break;case\"J\":h=x(\"J\")+.5,\".\"===e.charAt(A)&&(A++,x(\"J\"));break;case\"@\":h=x(\"@\")/this.SECS_PER_DAY+this.UNIX_EPOCH;break;case\"!\":h=x(\"!\")/this.TICKS_PER_DAY+this.TICKS_EPOCH;break;case\"*\":A=e.length;break;case\"'\":y(\"'\")?T():m=!0;break;default:T()}if(A<e.length)throw i.local.unexpectedText||i.regionalOptions[\"\"].unexpectedText;if(-1===f?f=this.today().year():f<100&&v&&(f+=-1===n?1900:this.today().year()-this.today().year()%100-(f<=n?0:100)),\"string\"==typeof p&&(p=s.call(this,f,p)),g>-1){p=1,d=g;for(var E=this.daysInMonth(f,p);d>E;E=this.daysInMonth(f,p))p++,d-=E}return h>-1?this.fromJD(h):this.newDate(f,p,d)},determineDate:function(t,e,r,n,i){r&&\"object\"!=typeof r&&(i=n,n=r,r=null),\"string\"!=typeof n&&(i=n,n=\"\");var a=this;return e=e?e.newDate():null,t=null==t?e:\"string\"==typeof t?function(t){try{return a.parseDate(n,t,i)}catch(t){}for(var e=((t=t.toLowerCase()).match(/^c/)&&r?r.newDate():null)||a.today(),o=/([+-]?[0-9]+)\\s*(d|w|m|y)?/g,s=o.exec(t);s;)e.add(parseInt(s[1],10),s[2]||\"d\"),s=o.exec(t);return e}(t):\"number\"==typeof t?isNaN(t)||t===1/0||t===-1/0?e:a.today().add(t,\"d\"):a.newDate(t)}})},{\"./main\":571,\"object-assign\":454}],573:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",{offset:[1],array:0},\"scalar\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\n        var _inline_1_da = _inline_1_arg0_ - _inline_1_arg3_\\n        var _inline_1_db = _inline_1_arg1_ - _inline_1_arg3_\\n        if((_inline_1_da >= 0) !== (_inline_1_db >= 0)) {\\n          _inline_1_arg2_.push(_inline_1_arg4_[0] + 0.5 + 0.5 * (_inline_1_da + _inline_1_db) / (_inline_1_da - _inline_1_db))\\n        }\\n      }\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg3_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[\"_inline_1_da\",\"_inline_1_db\"]},funcName:\"zeroCrossings\"})},{\"cwise-compiler\":146}],574:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=[];return e=+e||0,n(t.hi(t.shape[0]-1),r,e),r};var n=t(\"./lib/zc-core\")},{\"./lib/zc-core\":573}],575:[function(t,e,r){\"use strict\";e.exports=[{path:\"\",backoff:0},{path:\"M-2.4,-3V3L0.6,0Z\",backoff:.6},{path:\"M-3.7,-2.5V2.5L1.3,0Z\",backoff:1.3},{path:\"M-4.45,-3L-1.65,-0.2V0.2L-4.45,3L1.55,0Z\",backoff:1.55},{path:\"M-2.2,-2.2L-0.2,-0.2V0.2L-2.2,2.2L-1.4,3L1.6,0L-1.4,-3Z\",backoff:1.6},{path:\"M-4.4,-2.1L-0.6,-0.2V0.2L-4.4,2.1L-4,3L2,0L-4,-3Z\",backoff:2},{path:\"M2,0A2,2 0 1,1 0,-2A2,2 0 0,1 2,0Z\",backoff:0,noRotate:!0},{path:\"M2,2V-2H-2V2Z\",backoff:0,noRotate:!0}]},{}],576:[function(t,e,r){\"use strict\";var n=t(\"./arrow_paths\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../plots/cartesian/constants\"),o=t(\"../../plot_api/plot_template\").templatedArray;e.exports=o(\"annotation\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},text:{valType:\"string\",editType:\"calc+arraydraw\"},textangle:{valType:\"angle\",dflt:0,editType:\"calc+arraydraw\"},font:i({editType:\"calc+arraydraw\",colorEditType:\"arraydraw\"}),width:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},height:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"center\",editType:\"arraydraw\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"arraydraw\"},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},borderpad:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},showarrow:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},arrowcolor:{valType:\"color\",editType:\"arraydraw\"},arrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},startarrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},arrowside:{valType:\"flaglist\",flags:[\"end\",\"start\"],extras:[\"none\"],dflt:\"end\",editType:\"arraydraw\"},arrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},startarrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},arrowwidth:{valType:\"number\",min:.1,editType:\"calc+arraydraw\"},standoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},startstandoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},ax:{valType:\"any\",editType:\"calc+arraydraw\"},ay:{valType:\"any\",editType:\"calc+arraydraw\"},axref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.x.toString()],editType:\"calc\"},ayref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.y.toString()],editType:\"calc\"},xref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.x.toString()],editType:\"calc\"},x:{valType:\"any\",editType:\"calc+arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"auto\",editType:\"calc+arraydraw\"},xshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.y.toString()],editType:\"calc\"},y:{valType:\"any\",editType:\"calc+arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"calc+arraydraw\"},yshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},clicktoshow:{valType:\"enumerated\",values:[!1,\"onoff\",\"onout\"],dflt:!1,editType:\"arraydraw\"},xclick:{valType:\"any\",editType:\"arraydraw\"},yclick:{valType:\"any\",editType:\"arraydraw\"},hovertext:{valType:\"string\",editType:\"arraydraw\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",editType:\"arraydraw\"},font:i({editType:\"arraydraw\"}),editType:\"arraydraw\"},captureevents:{valType:\"boolean\",editType:\"arraydraw\"},editType:\"calc\",_deprecated:{ref:{valType:\"string\",editType:\"calc\"}}})},{\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773,\"../../plots/font_attributes\":793,\"./arrow_paths\":575}],577:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./draw\").draw;function o(t){var e=t._fullLayout;n.filterVisible(e.annotations).forEach(function(e){var r=i.getFromId(t,e.xref),n=i.getFromId(t,e.yref);e._extremes={},r&&s(e,r),n&&s(e,n)})}function s(t,e){var r,n=e._id,a=n.charAt(0),o=t[a],s=t[\"a\"+a],l=t[a+\"ref\"],c=t[\"a\"+a+\"ref\"],u=t[\"_\"+a+\"padplus\"],h=t[\"_\"+a+\"padminus\"],f={x:1,y:-1}[a]*t[a+\"shift\"],p=3*t.arrowsize*t.arrowwidth||0,d=p+f,g=p-f,v=3*t.startarrowsize*t.arrowwidth||0,m=v+f,y=v-f;if(c===l){var x=i.findExtremes(e,[e.r2c(o)],{ppadplus:d,ppadminus:g}),b=i.findExtremes(e,[e.r2c(s)],{ppadplus:Math.max(u,m),ppadminus:Math.max(h,y)});r={min:[x.min[0],b.min[0]],max:[x.max[0],b.max[0]]}}else m=s?m+s:m,y=s?y-s:y,r=i.findExtremes(e,[e.r2c(o)],{ppadplus:Math.max(u,d,m),ppadminus:Math.max(h,g,y)});t._extremes[n]=r}e.exports=function(t){var e=t._fullLayout;if(n.filterVisible(e.annotations).length&&t._fullData.length)return n.syncOrAsync([a,o],t)}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./draw\":582}],578:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../plot_api/plot_template\").arrayEditor;function o(t,e){var r,n,i,a,o,l,c,u=t._fullLayout.annotations,h=[],f=[],p=[],d=(e||[]).length;for(r=0;r<u.length;r++)if(a=(i=u[r]).clicktoshow){for(n=0;n<d;n++)if(l=(o=e[n]).xaxis,c=o.yaxis,l._id===i.xref&&c._id===i.yref&&l.d2r(o.x)===s(i._xclick,l)&&c.d2r(o.y)===s(i._yclick,c)){(i.visible?\"onout\"===a?f:p:h).push(r);break}n===d&&i.visible&&\"onout\"===a&&f.push(r)}return{on:h,off:f,explicitOff:p}}function s(t,e){return\"log\"===e.type?e.l2r(t):e.d2r(t)}e.exports={hasClickToShow:function(t,e){var r=o(t,e);return r.on.length>0||r.explicitOff.length>0},onClick:function(t,e){var r,s,l=o(t,e),c=l.on,u=l.off.concat(l.explicitOff),h={},f=t._fullLayout.annotations;if(!c.length&&!u.length)return;for(r=0;r<c.length;r++)(s=a(t.layout,\"annotations\",f[c[r]])).modifyItem(\"visible\",!0),n.extendFlat(h,s.getUpdateObj());for(r=0;r<u.length;r++)(s=a(t.layout,\"annotations\",f[u[r]])).modifyItem(\"visible\",!1),n.extendFlat(h,s.getUpdateObj());return i.call(\"update\",t,{},h)}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../registry\":847}],579:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\");e.exports=function(t,e,r,a){a(\"opacity\");var o=a(\"bgcolor\"),s=a(\"bordercolor\"),l=i.opacity(s);a(\"borderpad\");var c=a(\"borderwidth\"),u=a(\"showarrow\");if(a(\"text\",u?\" \":r._dfltTitle.annotation),a(\"textangle\"),n.coerceFont(a,\"font\",r.font),a(\"width\"),a(\"align\"),a(\"height\")&&a(\"valign\"),u){var h,f,p=a(\"arrowside\");-1!==p.indexOf(\"end\")&&(h=a(\"arrowhead\"),f=a(\"arrowsize\")),-1!==p.indexOf(\"start\")&&(a(\"startarrowhead\",h),a(\"startarrowsize\",f)),a(\"arrowcolor\",l?e.bordercolor:i.defaultLine),a(\"arrowwidth\",2*(l&&c||1)),a(\"standoff\"),a(\"startstandoff\")}var d=a(\"hovertext\"),g=r.hoverlabel||{};if(d){var v=a(\"hoverlabel.bgcolor\",g.bgcolor||(i.opacity(o)?i.rgb(o):i.defaultLine)),m=a(\"hoverlabel.bordercolor\",g.bordercolor||i.contrast(v));n.coerceFont(a,\"hoverlabel.font\",{family:g.font.family,size:g.font.size,color:g.font.color||m})}a(\"captureevents\",!!d)}},{\"../../lib\":719,\"../color\":593}],580:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.annotations,h=e._id.charAt(0),f=0;f<u.length;f++)l=u[f],c=\"annotations[\"+f+\"].\",l[h+\"ref\"]===e._id&&p(h),l[\"a\"+h+\"ref\"]===e._id&&p(\"a\"+h);function p(t){var r=l[t],s=null;s=o?i(r,e.range):Math.pow(10,r),n(s)||(s=null),a(c+t,s)}}},{\"../../lib/to_log_range\":745,\"fast-isnumeric\":225}],581:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./common_defaults\"),s=t(\"./attributes\");function l(t,e,r){function a(r,i){return n.coerce(t,e,s,r,i)}var l=a(\"visible\"),c=a(\"clicktoshow\");if(l||c){o(t,e,r,a);for(var u=e.showarrow,h=[\"x\",\"y\"],f=[-10,-30],p={_fullLayout:r},d=0;d<2;d++){var g=h[d],v=i.coerceRef(t,e,p,g,\"\",\"paper\");if(\"paper\"!==v)i.getFromId(p,v)._annIndices.push(e._index);if(i.coercePosition(e,p,a,v,g,.5),u){var m=\"a\"+g,y=i.coerceRef(t,e,p,m,\"pixel\");\"pixel\"!==y&&y!==v&&(y=e[m]=\"pixel\");var x=\"pixel\"===y?f[d]:.4;i.coercePosition(e,p,a,y,m,x)}a(g+\"anchor\"),a(g+\"shift\")}if(n.noneOrAll(t,e,[\"x\",\"y\"]),u&&n.noneOrAll(t,e,[\"ax\",\"ay\"]),c){var b=a(\"xclick\"),_=a(\"yclick\");e._xclick=void 0===b?e.x:i.cleanPosition(b,p,e.xref),e._yclick=void 0===_?e.y:i.cleanPosition(_,p,e.yref)}}}e.exports=function(t,e){a(t,e,{name:\"annotations\",handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"./attributes\":576,\"./common_defaults\":579}],582:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../color\"),c=t(\"../drawing\"),u=t(\"../fx\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"../../lib/setcursor\"),p=t(\"../dragelement\"),d=t(\"../../plot_api/plot_template\").arrayEditor,g=t(\"./draw_arrow_head\");function v(t,e){var r=t._fullLayout.annotations[e]||{},n=s.getFromId(t,r.xref),i=s.getFromId(t,r.yref);n&&n.setScale(),i&&i.setScale(),m(t,r,e,!1,n,i)}function m(t,e,r,a,s,v){var m,y,x=t._fullLayout,b=t._fullLayout._size,_=t._context.edits;a?(m=\"annotation-\"+a,y=a+\".annotations\"):(m=\"annotation\",y=\"annotations\");var w=d(t.layout,y,e),k=w.modifyBase,T=w.modifyItem,A=w.getUpdateObj;x._infolayer.selectAll(\".\"+m+'[data-index=\"'+r+'\"]').remove();var M=\"clip\"+x._uid+\"_ann\"+r;if(e._input&&!1!==e.visible){var S={x:{},y:{}},E=+e.textangle||0,C=x._infolayer.append(\"g\").classed(m,!0).attr(\"data-index\",String(r)).style(\"opacity\",e.opacity),L=C.append(\"g\").classed(\"annotation-text-g\",!0),P=_[e.showarrow?\"annotationTail\":\"annotationPosition\"],O=e.captureevents||_.annotationText||P,z=L.append(\"g\").style(\"pointer-events\",O?\"all\":null).call(f,\"pointer\").on(\"click\",function(){t._dragging=!1,t.emit(\"plotly_clickannotation\",q(n.event))});e.hovertext&&z.on(\"mouseover\",function(){var r=e.hoverlabel,n=r.font,i=this.getBoundingClientRect(),a=t.getBoundingClientRect();u.loneHover({x0:i.left-a.left,x1:i.right-a.left,y:(i.top+i.bottom)/2-a.top,text:e.hovertext,color:r.bgcolor,borderColor:r.bordercolor,fontFamily:n.family,fontSize:n.size,fontColor:n.color},{container:x._hoverlayer.node(),outerContainer:x._paper.node(),gd:t})}).on(\"mouseout\",function(){u.loneUnhover(x._hoverlayer.node())});var I=e.borderwidth,D=e.borderpad,R=I+D,F=z.append(\"rect\").attr(\"class\",\"bg\").style(\"stroke-width\",I+\"px\").call(l.stroke,e.bordercolor).call(l.fill,e.bgcolor),B=e.width||e.height,N=x._topclips.selectAll(\"#\"+M).data(B?[0]:[]);N.enter().append(\"clipPath\").classed(\"annclip\",!0).attr(\"id\",M).append(\"rect\"),N.exit().remove();var j=e.font,U=x._meta?o.templateString(e.text,x._meta):e.text,V=z.append(\"text\").classed(\"annotation-text\",!0).text(U);_.annotationText?V.call(h.makeEditable,{delegate:z,gd:t}).call(H).on(\"edit\",function(r){e.text=r,this.call(H),T(\"text\",r),s&&s.autorange&&k(s._name+\".autorange\",!0),v&&v.autorange&&k(v._name+\".autorange\",!0),i.call(\"_guiRelayout\",t,A())}):V.call(H)}else n.selectAll(\"#\"+M).remove();function q(t){var n={index:r,annotation:e._input,fullAnnotation:e,event:t};return a&&(n.subplotId=a),n}function H(r){return r.call(c.font,j).attr({\"text-anchor\":{left:\"start\",right:\"end\"}[e.align]||\"middle\"}),h.convertToTspans(r,t,G),r}function G(){var r=V.selectAll(\"a\");1===r.size()&&r.text()===V.text()&&z.insert(\"a\",\":first-child\").attr({\"xlink:xlink:href\":r.attr(\"xlink:href\"),\"xlink:xlink:show\":r.attr(\"xlink:show\")}).style({cursor:\"pointer\"}).node().appendChild(F.node());var n=z.select(\".annotation-text-math-group\"),u=!n.empty(),d=c.bBox((u?n:V).node()),m=d.width,y=d.height,w=e.width||m,O=e.height||y,D=Math.round(w+2*R),j=Math.round(O+2*R);function U(t,e){return\"auto\"===e&&(e=t<1/3?\"left\":t>2/3?\"right\":\"center\"),{center:0,middle:0,left:.5,bottom:-.5,right:-.5,top:.5}[e]}for(var H=!1,G=[\"x\",\"y\"],Y=0;Y<G.length;Y++){var W,X,Z,J,K,$=G[Y],Q=e[$+\"ref\"]||$,tt=e[\"a\"+$+\"ref\"],et={x:s,y:v}[$],rt=(E+(\"x\"===$?0:-90))*Math.PI/180,nt=D*Math.cos(rt),it=j*Math.sin(rt),at=Math.abs(nt)+Math.abs(it),ot=e[$+\"anchor\"],st=e[$+\"shift\"]*(\"x\"===$?1:-1),lt=S[$];if(et){var ct=et.r2fraction(e[$]);(ct<0||ct>1)&&(tt===Q?((ct=et.r2fraction(e[\"a\"+$]))<0||ct>1)&&(H=!0):H=!0),W=et._offset+et.r2p(e[$]),J=.5}else\"x\"===$?(Z=e[$],W=b.l+b.w*Z):(Z=1-e[$],W=b.t+b.h*Z),J=e.showarrow?.5:Z;if(e.showarrow){lt.head=W;var ut=e[\"a\"+$];K=nt*U(.5,e.xanchor)-it*U(.5,e.yanchor),tt===Q?(lt.tail=et._offset+et.r2p(ut),X=K):(lt.tail=W+ut,X=K+ut),lt.text=lt.tail+K;var ht=x[\"x\"===$?\"width\":\"height\"];if(\"paper\"===Q&&(lt.head=o.constrain(lt.head,1,ht-1)),\"pixel\"===tt){var ft=-Math.max(lt.tail-3,lt.text),pt=Math.min(lt.tail+3,lt.text)-ht;ft>0?(lt.tail+=ft,lt.text+=ft):pt>0&&(lt.tail-=pt,lt.text-=pt)}lt.tail+=st,lt.head+=st}else X=K=at*U(J,ot),lt.text=W+K;lt.text+=st,K+=st,X+=st,e[\"_\"+$+\"padplus\"]=at/2+X,e[\"_\"+$+\"padminus\"]=at/2-X,e[\"_\"+$+\"size\"]=at,e[\"_\"+$+\"shift\"]=K}if(t._dragging||!H){var dt=0,gt=0;if(\"left\"!==e.align&&(dt=(w-m)*(\"center\"===e.align?.5:1)),\"top\"!==e.valign&&(gt=(O-y)*(\"middle\"===e.valign?.5:1)),u)n.select(\"svg\").attr({x:R+dt-1,y:R+gt}).call(c.setClipUrl,B?M:null,t);else{var vt=R+gt-d.top,mt=R+dt-d.left;V.call(h.positionText,mt,vt).call(c.setClipUrl,B?M:null,t)}N.select(\"rect\").call(c.setRect,R,R,w,O),F.call(c.setRect,I/2,I/2,D-I,j-I),z.call(c.setTranslate,Math.round(S.x.text-D/2),Math.round(S.y.text-j/2)),L.attr({transform:\"rotate(\"+E+\",\"+S.x.text+\",\"+S.y.text+\")\"});var yt,xt=function(r,n){C.selectAll(\".annotation-arrow-g\").remove();var u=S.x.head,h=S.y.head,f=S.x.tail+r,d=S.y.tail+n,m=S.x.text+r,y=S.y.text+n,x=o.rotationXYMatrix(E,m,y),w=o.apply2DTransform(x),M=o.apply2DTransform2(x),P=+F.attr(\"width\"),O=+F.attr(\"height\"),I=m-.5*P,D=I+P,R=y-.5*O,B=R+O,N=[[I,R,I,B],[I,B,D,B],[D,B,D,R],[D,R,I,R]].map(M);if(!N.reduce(function(t,e){return t^!!o.segmentsIntersect(u,h,u+1e6,h+1e6,e[0],e[1],e[2],e[3])},!1)){N.forEach(function(t){var e=o.segmentsIntersect(f,d,u,h,t[0],t[1],t[2],t[3]);e&&(f=e.x,d=e.y)});var j=e.arrowwidth,U=e.arrowcolor,V=e.arrowside,q=C.append(\"g\").style({opacity:l.opacity(U)}).classed(\"annotation-arrow-g\",!0),H=q.append(\"path\").attr(\"d\",\"M\"+f+\",\"+d+\"L\"+u+\",\"+h).style(\"stroke-width\",j+\"px\").call(l.stroke,l.rgb(U));if(g(H,V,e),_.annotationPosition&&H.node().parentNode&&!a){var G=u,Y=h;if(e.standoff){var W=Math.sqrt(Math.pow(u-f,2)+Math.pow(h-d,2));G+=e.standoff*(f-u)/W,Y+=e.standoff*(d-h)/W}var X,Z,J=q.append(\"path\").classed(\"annotation-arrow\",!0).classed(\"anndrag\",!0).classed(\"cursor-move\",!0).attr({d:\"M3,3H-3V-3H3ZM0,0L\"+(f-G)+\",\"+(d-Y),transform:\"translate(\"+G+\",\"+Y+\")\"}).style(\"stroke-width\",j+6+\"px\").call(l.stroke,\"rgba(0,0,0,0)\").call(l.fill,\"rgba(0,0,0,0)\");p.init({element:J.node(),gd:t,prepFn:function(){var t=c.getTranslate(z);X=t.x,Z=t.y,s&&s.autorange&&k(s._name+\".autorange\",!0),v&&v.autorange&&k(v._name+\".autorange\",!0)},moveFn:function(t,r){var n=w(X,Z),i=n[0]+t,a=n[1]+r;z.call(c.setTranslate,i,a),T(\"x\",s?s.p2r(s.r2p(e.x)+t):e.x+t/b.w),T(\"y\",v?v.p2r(v.r2p(e.y)+r):e.y-r/b.h),e.axref===e.xref&&T(\"ax\",s.p2r(s.r2p(e.ax)+t)),e.ayref===e.yref&&T(\"ay\",v.p2r(v.r2p(e.ay)+r)),q.attr(\"transform\",\"translate(\"+t+\",\"+r+\")\"),L.attr({transform:\"rotate(\"+E+\",\"+i+\",\"+a+\")\"})},doneFn:function(){i.call(\"_guiRelayout\",t,A());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}}};if(e.showarrow&&xt(0,0),P)p.init({element:z.node(),gd:t,prepFn:function(){yt=L.attr(\"transform\")},moveFn:function(t,r){var n=\"pointer\";if(e.showarrow)e.axref===e.xref?T(\"ax\",s.p2r(s.r2p(e.ax)+t)):T(\"ax\",e.ax+t),e.ayref===e.yref?T(\"ay\",v.p2r(v.r2p(e.ay)+r)):T(\"ay\",e.ay+r),xt(t,r);else{if(a)return;var i,o;if(s)i=s.p2r(s.r2p(e.x)+t);else{var l=e._xsize/b.w,c=e.x+(e._xshift-e.xshift)/b.w-l/2;i=p.align(c+t/b.w,l,0,1,e.xanchor)}if(v)o=v.p2r(v.r2p(e.y)+r);else{var u=e._ysize/b.h,h=e.y-(e._yshift+e.yshift)/b.h-u/2;o=p.align(h-r/b.h,u,0,1,e.yanchor)}T(\"x\",i),T(\"y\",o),s&&v||(n=p.getCursor(s?.5:i,v?.5:o,e.xanchor,e.yanchor))}L.attr({transform:\"translate(\"+t+\",\"+r+\")\"+yt}),f(z,n)},clickFn:function(r,n){e.captureevents&&t.emit(\"plotly_clickannotation\",q(n))},doneFn:function(){f(z),i.call(\"_guiRelayout\",t,A());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}else z.remove()}}e.exports={draw:function(t){var e=t._fullLayout;e._infolayer.selectAll(\".annotation\").remove();for(var r=0;r<e.annotations.length;r++)e.annotations[r].visible&&v(t,r);return a.previousPromises(t)},drawOne:v,drawRaw:m}},{\"../../lib\":719,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/axes\":767,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"../fx\":632,\"./draw_arrow_head\":583,d3:163}],583:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\"),a=t(\"./arrow_paths\");e.exports=function(t,e,r){var o,s,l,c,u=t.node(),h=a[r.arrowhead||0],f=a[r.startarrowhead||0],p=(r.arrowwidth||1)*(r.arrowsize||1),d=(r.arrowwidth||1)*(r.startarrowsize||1),g=e.indexOf(\"start\")>=0,v=e.indexOf(\"end\")>=0,m=h.backoff*p+r.standoff,y=f.backoff*d+r.startstandoff;if(\"line\"===u.nodeName){o={x:+t.attr(\"x1\"),y:+t.attr(\"y1\")},s={x:+t.attr(\"x2\"),y:+t.attr(\"y2\")};var x=o.x-s.x,b=o.y-s.y;if(c=(l=Math.atan2(b,x))+Math.PI,m&&y&&m+y>Math.sqrt(x*x+b*b))return void P();if(m){if(m*m>x*x+b*b)return void P();var _=m*Math.cos(l),w=m*Math.sin(l);s.x+=_,s.y+=w,t.attr({x2:s.x,y2:s.y})}if(y){if(y*y>x*x+b*b)return void P();var k=y*Math.cos(l),T=y*Math.sin(l);o.x-=k,o.y-=T,t.attr({x1:o.x,y1:o.y})}}else if(\"path\"===u.nodeName){var A=u.getTotalLength(),M=\"\";if(A<m+y)return void P();var S=u.getPointAtLength(0),E=u.getPointAtLength(.1);l=Math.atan2(S.y-E.y,S.x-E.x),o=u.getPointAtLength(Math.min(y,A)),M=\"0px,\"+y+\"px,\";var C=u.getPointAtLength(A),L=u.getPointAtLength(A-.1);c=Math.atan2(C.y-L.y,C.x-L.x),s=u.getPointAtLength(Math.max(0,A-m)),M+=A-(M?y+m:m)+\"px,\"+A+\"px\",t.style(\"stroke-dasharray\",M)}function P(){t.style(\"stroke-dasharray\",\"0px,100px\")}function O(e,a,o,s){e.path&&(e.noRotate&&(o=0),n.select(u.parentNode).append(\"path\").attr({class:t.attr(\"class\"),d:e.path,transform:\"translate(\"+a.x+\",\"+a.y+\")\"+(o?\"rotate(\"+180*o/Math.PI+\")\":\"\")+\"scale(\"+s+\")\"}).style({fill:i.rgb(r.arrowcolor),\"stroke-width\":0}))}g&&O(f,o,l,d),v&&O(h,s,c,p)}},{\"../color\":593,\"./arrow_paths\":575,d3:163}],584:[function(t,e,r){\"use strict\";var n=t(\"./draw\"),i=t(\"./click\");e.exports={moduleType:\"component\",name:\"annotations\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"annotations\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne,drawRaw:n.drawRaw,hasClickToShow:i.hasClickToShow,onClick:i.onClick,convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":777,\"./attributes\":576,\"./calc_autorange\":577,\"./click\":578,\"./convert_coords\":580,\"./defaults\":581,\"./draw\":582}],585:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"../../plot_api/plot_template\").templatedArray;e.exports=i(a(\"annotation\",{visible:n.visible,x:{valType:\"any\"},y:{valType:\"any\"},z:{valType:\"any\"},ax:{valType:\"number\"},ay:{valType:\"number\"},xanchor:n.xanchor,xshift:n.xshift,yanchor:n.yanchor,yshift:n.yshift,text:n.text,textangle:n.textangle,font:n.font,width:n.width,height:n.height,opacity:n.opacity,align:n.align,valign:n.valign,bgcolor:n.bgcolor,bordercolor:n.bordercolor,borderpad:n.borderpad,borderwidth:n.borderwidth,showarrow:n.showarrow,arrowcolor:n.arrowcolor,arrowhead:n.arrowhead,startarrowhead:n.startarrowhead,arrowside:n.arrowside,arrowsize:n.arrowsize,startarrowsize:n.startarrowsize,arrowwidth:n.arrowwidth,standoff:n.standoff,startstandoff:n.startstandoff,hovertext:n.hovertext,hoverlabel:n.hoverlabel,captureevents:n.captureevents}),\"calc\",\"from-root\")},{\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../annotations/attributes\":576}],586:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\");function a(t,e){var r=e.fullSceneLayout.domain,a=e.fullLayout._size,o={pdata:null,type:\"linear\",autorange:!1,range:[-1/0,1/0]};t._xa={},n.extendFlat(t._xa,o),i.setConvert(t._xa),t._xa._offset=a.l+r.x[0]*a.w,t._xa.l2p=function(){return.5*(1+t._pdata[0]/t._pdata[3])*a.w*(r.x[1]-r.x[0])},t._ya={},n.extendFlat(t._ya,o),i.setConvert(t._ya),t._ya._offset=a.t+(1-r.y[1])*a.h,t._ya.l2p=function(){return.5*(1-t._pdata[1]/t._pdata[3])*a.h*(r.y[1]-r.y[0])}}e.exports=function(t){for(var e=t.fullSceneLayout.annotations,r=0;r<e.length;r++)a(e[r],t);t.fullLayout._infolayer.selectAll(\".annotation-\"+t.id).remove()}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767}],587:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"../annotations/common_defaults\"),s=t(\"./attributes\");function l(t,e,r,a){function l(r,i){return n.coerce(t,e,s,r,i)}function c(t){var n=t+\"axis\",a={_fullLayout:{}};return a._fullLayout[n]=r[n],i.coercePosition(e,a,l,t,t,.5)}l(\"visible\")&&(o(t,e,a.fullLayout,l),c(\"x\"),c(\"y\"),c(\"z\"),n.noneOrAll(t,e,[\"x\",\"y\",\"z\"]),e.xref=\"x\",e.yref=\"y\",e.zref=\"z\",l(\"xanchor\"),l(\"yanchor\"),l(\"xshift\"),l(\"yshift\"),e.showarrow&&(e.axref=\"pixel\",e.ayref=\"pixel\",l(\"ax\",-10),l(\"ay\",-30),n.noneOrAll(t,e,[\"ax\",\"ay\"])))}e.exports=function(t,e,r){a(t,e,{name:\"annotations\",handleItemDefaults:l,fullLayout:r.fullLayout})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"../annotations/common_defaults\":579,\"./attributes\":585}],588:[function(t,e,r){\"use strict\";var n=t(\"../annotations/draw\").drawRaw,i=t(\"../../plots/gl3d/project\"),a=[\"x\",\"y\",\"z\"];e.exports=function(t){for(var e=t.fullSceneLayout,r=t.dataScale,o=e.annotations,s=0;s<o.length;s++){for(var l=o[s],c=!1,u=0;u<3;u++){var h=a[u],f=l[h],p=e[h+\"axis\"].r2fraction(f);if(p<0||p>1){c=!0;break}}c?t.fullLayout._infolayer.select(\".annotation-\"+t.id+'[data-index=\"'+s+'\"]').remove():(l._pdata=i(t.glplot.cameraParams,[e.xaxis.r2l(l.x)*r[0],e.yaxis.r2l(l.y)*r[1],e.zaxis.r2l(l.z)*r[2]]),n(t.graphDiv,l,s,t.id,l._xa,l._ya))}}},{\"../../plots/gl3d/project\":816,\"../annotations/draw\":582}],589:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports={moduleType:\"component\",name:\"annotations3d\",schema:{subplots:{scene:{annotations:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),includeBasePlot:function(t,e){var r=n.subplotsRegistry.gl3d;if(!r)return;for(var a=r.attrRegex,o=Object.keys(t),s=0;s<o.length;s++){var l=o[s];a.test(l)&&(t[l].annotations||[]).length&&(i.pushUnique(e._basePlotModules,r),i.pushUnique(e._subplots.gl3d,l))}},convert:t(\"./convert\"),draw:t(\"./draw\")}},{\"../../lib\":719,\"../../registry\":847,\"./attributes\":585,\"./convert\":586,\"./defaults\":587,\"./draw\":588}],590:[function(t,e,r){\"use strict\";e.exports=t(\"world-calendars/dist/main\"),t(\"world-calendars/dist/plus\"),t(\"world-calendars/dist/calendars/chinese\"),t(\"world-calendars/dist/calendars/coptic\"),t(\"world-calendars/dist/calendars/discworld\"),t(\"world-calendars/dist/calendars/ethiopian\"),t(\"world-calendars/dist/calendars/hebrew\"),t(\"world-calendars/dist/calendars/islamic\"),t(\"world-calendars/dist/calendars/julian\"),t(\"world-calendars/dist/calendars/mayan\"),t(\"world-calendars/dist/calendars/nanakshahi\"),t(\"world-calendars/dist/calendars/nepali\"),t(\"world-calendars/dist/calendars/persian\"),t(\"world-calendars/dist/calendars/taiwan\"),t(\"world-calendars/dist/calendars/thai\"),t(\"world-calendars/dist/calendars/ummalqura\")},{\"world-calendars/dist/calendars/chinese\":557,\"world-calendars/dist/calendars/coptic\":558,\"world-calendars/dist/calendars/discworld\":559,\"world-calendars/dist/calendars/ethiopian\":560,\"world-calendars/dist/calendars/hebrew\":561,\"world-calendars/dist/calendars/islamic\":562,\"world-calendars/dist/calendars/julian\":563,\"world-calendars/dist/calendars/mayan\":564,\"world-calendars/dist/calendars/nanakshahi\":565,\"world-calendars/dist/calendars/nepali\":566,\"world-calendars/dist/calendars/persian\":567,\"world-calendars/dist/calendars/taiwan\":568,\"world-calendars/dist/calendars/thai\":569,\"world-calendars/dist/calendars/ummalqura\":570,\"world-calendars/dist/main\":571,\"world-calendars/dist/plus\":572}],591:[function(t,e,r){\"use strict\";var n=t(\"./calendars\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\"),o=a.EPOCHJD,s=a.ONEDAY,l={valType:\"enumerated\",values:Object.keys(n.calendars),editType:\"calc\",dflt:\"gregorian\"},c=function(t,e,r,n){var a={};return a[r]=l,i.coerce(t,e,a,r,n)},u=\"##\",h={d:{0:\"dd\",\"-\":\"d\"},e:{0:\"d\",\"-\":\"d\"},a:{0:\"D\",\"-\":\"D\"},A:{0:\"DD\",\"-\":\"DD\"},j:{0:\"oo\",\"-\":\"o\"},W:{0:\"ww\",\"-\":\"w\"},m:{0:\"mm\",\"-\":\"m\"},b:{0:\"M\",\"-\":\"M\"},B:{0:\"MM\",\"-\":\"MM\"},y:{0:\"yy\",\"-\":\"yy\"},Y:{0:\"yyyy\",\"-\":\"yyyy\"},U:u,w:u,c:{0:\"D M d %X yyyy\",\"-\":\"D M d %X yyyy\"},x:{0:\"mm/dd/yyyy\",\"-\":\"mm/dd/yyyy\"}};var f={};function p(t){var e=f[t];return e||(e=f[t]=n.instance(t))}function d(t){return i.extendFlat({},l,{description:t})}function g(t){return\"Sets the calendar system to use with `\"+t+\"` date data.\"}var v={xcalendar:d(g(\"x\"))},m=i.extendFlat({},v,{ycalendar:d(g(\"y\"))}),y=i.extendFlat({},m,{zcalendar:d(g(\"z\"))}),x=d([\"Sets the calendar system to use for `range` and `tick0`\",\"if this is a date axis. This does not set the calendar for\",\"interpreting data on this axis, that's specified in the trace\",\"or via the global `layout.calendar`\"].join(\" \"));e.exports={moduleType:\"component\",name:\"calendars\",schema:{traces:{scatter:m,bar:m,box:m,heatmap:m,contour:m,histogram:m,histogram2d:m,histogram2dcontour:m,scatter3d:y,surface:y,mesh3d:y,scattergl:m,ohlc:v,candlestick:v},layout:{calendar:d([\"Sets the default calendar system to use for interpreting and\",\"displaying dates throughout the plot.\"].join(\" \"))},subplots:{xaxis:{calendar:x},yaxis:{calendar:x},scene:{xaxis:{calendar:x},yaxis:{calendar:x},zaxis:{calendar:x}},polar:{radialaxis:{calendar:x}}},transforms:{filter:{valuecalendar:d([\"Sets the calendar system to use for `value`, if it is a date.\"].join(\" \")),targetcalendar:d([\"Sets the calendar system to use for `target`, if it is an\",\"array of dates. If `target` is a string (eg *x*) we use the\",\"corresponding trace attribute (eg `xcalendar`) if it exists,\",\"even if `targetcalendar` is provided.\"].join(\" \"))}}},layoutAttributes:l,handleDefaults:c,handleTraceDefaults:function(t,e,r,n){for(var i=0;i<r.length;i++)c(t,e,r[i]+\"calendar\",n.calendar)},CANONICAL_SUNDAY:{chinese:\"2000-01-02\",coptic:\"2000-01-03\",discworld:\"2000-01-03\",ethiopian:\"2000-01-05\",hebrew:\"5000-01-01\",islamic:\"1000-01-02\",julian:\"2000-01-03\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-05\",nepali:\"2000-01-05\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-04\",thai:\"2000-01-04\",ummalqura:\"1400-01-06\"},CANONICAL_TICK:{chinese:\"2000-01-01\",coptic:\"2000-01-01\",discworld:\"2000-01-01\",ethiopian:\"2000-01-01\",hebrew:\"5000-01-01\",islamic:\"1000-01-01\",julian:\"2000-01-01\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-01\",nepali:\"2000-01-01\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-01\",thai:\"2000-01-01\",ummalqura:\"1400-01-01\"},DFLTRANGE:{chinese:[\"2000-01-01\",\"2001-01-01\"],coptic:[\"1700-01-01\",\"1701-01-01\"],discworld:[\"1800-01-01\",\"1801-01-01\"],ethiopian:[\"2000-01-01\",\"2001-01-01\"],hebrew:[\"5700-01-01\",\"5701-01-01\"],islamic:[\"1400-01-01\",\"1401-01-01\"],julian:[\"2000-01-01\",\"2001-01-01\"],mayan:[\"5200-01-01\",\"5201-01-01\"],nanakshahi:[\"0500-01-01\",\"0501-01-01\"],nepali:[\"2000-01-01\",\"2001-01-01\"],persian:[\"1400-01-01\",\"1401-01-01\"],jalali:[\"1400-01-01\",\"1401-01-01\"],taiwan:[\"0100-01-01\",\"0101-01-01\"],thai:[\"2500-01-01\",\"2501-01-01\"],ummalqura:[\"1400-01-01\",\"1401-01-01\"]},getCal:p,worldCalFmt:function(t,e,r){for(var n,i,a,l,c,f=Math.floor((e+.05)/s)+o,d=p(r).fromJD(f),g=0;-1!==(g=t.indexOf(\"%\",g));)\"0\"===(n=t.charAt(g+1))||\"-\"===n||\"_\"===n?(a=3,i=t.charAt(g+2),\"_\"===n&&(n=\"-\")):(i=n,n=\"0\",a=2),(l=h[i])?(c=l===u?u:d.formatDate(l[n]),t=t.substr(0,g)+c+t.substr(g+a),g+=c.length):g+=a;return t}}},{\"../../constants/numerical\":695,\"../../lib\":719,\"./calendars\":590}],592:[function(t,e,r){\"use strict\";r.defaults=[\"#1f77b4\",\"#ff7f0e\",\"#2ca02c\",\"#d62728\",\"#9467bd\",\"#8c564b\",\"#e377c2\",\"#7f7f7f\",\"#bcbd22\",\"#17becf\"],r.defaultLine=\"#444\",r.lightLine=\"#eee\",r.background=\"#fff\",r.borderLine=\"#BEC8D9\",r.lightFraction=1e3/11},{}],593:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i=t(\"fast-isnumeric\"),a=e.exports={},o=t(\"./attributes\");a.defaults=o.defaults;var s=a.defaultLine=o.defaultLine;a.lightLine=o.lightLine;var l=a.background=o.background;function c(t){if(i(t)||\"string\"!=typeof t)return t;var e=t.trim();if(\"rgb\"!==e.substr(0,3))return t;var r=e.match(/^rgba?\\s*\\(([^()]*)\\)$/);if(!r)return t;var n=r[1].trim().split(/\\s*[\\s,]\\s*/),a=\"a\"===e.charAt(3)&&4===n.length;if(!a&&3!==n.length)return t;for(var o=0;o<n.length;o++){if(!n[o].length)return t;if(n[o]=Number(n[o]),!(n[o]>=0))return t;if(3===o)n[o]>1&&(n[o]=1);else if(n[o]>=1)return t}var s=Math.round(255*n[0])+\", \"+Math.round(255*n[1])+\", \"+Math.round(255*n[2]);return a?\"rgba(\"+s+\", \"+n[3]+\")\":\"rgb(\"+s+\")\"}a.tinyRGB=function(t){var e=t.toRgb();return\"rgb(\"+Math.round(e.r)+\", \"+Math.round(e.g)+\", \"+Math.round(e.b)+\")\"},a.rgb=function(t){return a.tinyRGB(n(t))},a.opacity=function(t){return t?n(t).getAlpha():0},a.addOpacity=function(t,e){var r=n(t).toRgb();return\"rgba(\"+Math.round(r.r)+\", \"+Math.round(r.g)+\", \"+Math.round(r.b)+\", \"+e+\")\"},a.combine=function(t,e){var r=n(t).toRgb();if(1===r.a)return n(t).toRgbString();var i=n(e||l).toRgb(),a=1===i.a?i:{r:255*(1-i.a)+i.r*i.a,g:255*(1-i.a)+i.g*i.a,b:255*(1-i.a)+i.b*i.a},o={r:a.r*(1-r.a)+r.r*r.a,g:a.g*(1-r.a)+r.g*r.a,b:a.b*(1-r.a)+r.b*r.a};return n(o).toRgbString()},a.contrast=function(t,e,r){var i=n(t);return 1!==i.getAlpha()&&(i=n(a.combine(t,l))),(i.isDark()?e?i.lighten(e):l:r?i.darken(r):s).toString()},a.stroke=function(t,e){var r=n(e);t.style({stroke:a.tinyRGB(r),\"stroke-opacity\":r.getAlpha()})},a.fill=function(t,e){var r=n(e);t.style({fill:a.tinyRGB(r),\"fill-opacity\":r.getAlpha()})},a.clean=function(t){if(t&&\"object\"==typeof t){var e,r,n,i,o=Object.keys(t);for(e=0;e<o.length;e++)if(i=t[n=o[e]],\"color\"===n.substr(n.length-5))if(Array.isArray(i))for(r=0;r<i.length;r++)i[r]=c(i[r]);else t[n]=c(i);else if(\"colorscale\"===n.substr(n.length-10)&&Array.isArray(i))for(r=0;r<i.length;r++)Array.isArray(i[r])&&(i[r][1]=c(i[r][1]));else if(Array.isArray(i)){var s=i[0];if(!Array.isArray(s)&&s&&\"object\"==typeof s)for(r=0;r<i.length;r++)a.clean(i[r])}else i&&\"object\"==typeof i&&a.clean(i)}}},{\"./attributes\":592,\"fast-isnumeric\":225,tinycolor2:537}],594:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/layout_attributes\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll;e.exports=o({thicknessmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"pixels\"},thickness:{valType:\"number\",min:0,dflt:30},lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",dflt:1.02,min:-2,max:3},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},xpad:{valType:\"number\",min:0,dflt:10},y:{valType:\"number\",dflt:.5,min:-2,max:3},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\"},ypad:{valType:\"number\",min:0,dflt:10},outlinecolor:n.linecolor,outlinewidth:n.linewidth,bordercolor:n.linecolor,borderwidth:{valType:\"number\",min:0,dflt:0},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\"},tickmode:n.tickmode,nticks:n.nticks,tick0:n.tick0,dtick:n.dtick,tickvals:n.tickvals,ticktext:n.ticktext,ticks:a({},n.ticks,{dflt:\"\"}),ticklen:n.ticklen,tickwidth:n.tickwidth,tickcolor:n.tickcolor,showticklabels:n.showticklabels,tickfont:i({}),tickangle:n.tickangle,tickformat:n.tickformat,tickformatstops:n.tickformatstops,tickprefix:n.tickprefix,showtickprefix:n.showtickprefix,ticksuffix:n.ticksuffix,showticksuffix:n.showticksuffix,separatethousands:n.separatethousands,exponentformat:n.exponentformat,showexponent:n.showexponent,title:{text:{valType:\"string\"},font:i({}),side:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}},_deprecated:{title:{valType:\"string\"},titlefont:i({}),titleside:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}}},\"colorbars\",\"from-root\")},{\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/font_attributes\":793}],595:[function(t,e,r){\"use strict\";e.exports={cn:{colorbar:\"colorbar\",cbbg:\"cbbg\",cbfill:\"cbfill\",cbfills:\"cbfills\",cbline:\"cbline\",cblines:\"cblines\",cbaxis:\"cbaxis\",cbtitleunshift:\"cbtitleunshift\",cbtitle:\"cbtitle\",cboutline:\"cboutline\",crisp:\"crisp\",jsPlaceholder:\"js-placeholder\"}}},{}],596:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/tick_value_defaults\"),o=t(\"../../plots/cartesian/tick_mark_defaults\"),s=t(\"../../plots/cartesian/tick_label_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r){var c=i.newContainer(e,\"colorbar\"),u=t.colorbar||{};function h(t,e){return n.coerce(u,c,l,t,e)}var f=h(\"thicknessmode\");h(\"thickness\",\"fraction\"===f?30/(r.width-r.margin.l-r.margin.r):30);var p=h(\"lenmode\");h(\"len\",\"fraction\"===p?1:r.height-r.margin.t-r.margin.b),h(\"x\"),h(\"xanchor\"),h(\"xpad\"),h(\"y\"),h(\"yanchor\"),h(\"ypad\"),n.noneOrAll(u,c,[\"x\",\"y\"]),h(\"outlinecolor\"),h(\"outlinewidth\"),h(\"bordercolor\"),h(\"borderwidth\"),h(\"bgcolor\"),a(u,c,h,\"linear\");var d={outerTicks:!1,font:r.font};s(u,c,h,\"linear\",d),o(u,c,h,\"linear\",d),h(\"title.text\",r._dfltTitle.colorbar),n.coerceFont(h,\"title.font\",r.font),h(\"title.side\")}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/tick_label_defaults\":786,\"../../plots/cartesian/tick_mark_defaults\":787,\"../../plots/cartesian/tick_value_defaults\":788,\"./attributes\":594}],597:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../dragelement\"),c=t(\"../../lib\"),u=t(\"../../lib/extend\").extendFlat,h=t(\"../../lib/setcursor\"),f=t(\"../drawing\"),p=t(\"../color\"),d=t(\"../titles\"),g=t(\"../../lib/svg_text_utils\"),v=t(\"../colorscale/helpers\").flipScale,m=t(\"../../plots/cartesian/axis_defaults\"),y=t(\"../../plots/cartesian/position_defaults\"),x=t(\"../../plots/cartesian/layout_attributes\"),b=t(\"../../constants/alignment\"),_=b.LINE_SPACING,w=b.FROM_TL,k=b.FROM_BR,T=t(\"./constants\").cn;e.exports={draw:function(t){var e=t._fullLayout._infolayer.selectAll(\"g.\"+T.colorbar).data(function(t){var e,r,n,i,a=t._fullLayout,o=t.calcdata,s=[];function l(t){return u(t,{_fillcolor:null,_line:{color:null,width:null,dash:null},_levels:{start:null,end:null,size:null},_filllevels:null,_fillgradient:null,_zrange:null})}function c(){\"function\"==typeof i.calc?i.calc(t,n,e):(e._fillgradient=r.reversescale?v(r.colorscale):r.colorscale,e._zrange=[r[i.min],r[i.max]])}for(var h=0;h<o.length;h++){var f=o[h],p=(n=f[0].trace)._module.colorbar;if(!0===n.visible&&p)for(var d=Array.isArray(p),g=d?p:[p],m=0;m<g.length;m++){var y=(i=g[m]).container;(r=y?n[y]:n)&&r.showscale&&((e=l(r.colorbar))._id=\"cb\"+n.uid+(d&&y?\"-\"+y:\"\"),e._traceIndex=n.index,e._propPrefix=(y?y+\".\":\"\")+\"colorbar.\",e._meta=n._meta,c(),s.push(e))}}for(var x in a._colorAxes)if((r=a[x]).showscale){var b=a._colorAxes[x];(e=l(r.colorbar))._id=\"cb\"+x,e._propPrefix=x+\".colorbar.\",e._meta=a._meta,i={min:\"cmin\",max:\"cmax\"},\"heatmap\"!==b[0]&&(n=b[1],i.calc=n._module.colorbar.calc),c(),s.push(e)}return s}(t),function(t){return t._id});e.enter().append(\"g\").attr(\"class\",function(t){return t._id}).classed(T.colorbar,!0),e.each(function(e){var r=n.select(this);c.ensureSingle(r,\"rect\",T.cbbg),c.ensureSingle(r,\"g\",T.cbfills),c.ensureSingle(r,\"g\",T.cblines),c.ensureSingle(r,\"g\",T.cbaxis,function(t){t.classed(T.crisp,!0)}),c.ensureSingle(r,\"g\",T.cbtitleunshift,function(t){t.append(\"g\").classed(T.cbtitle,!0)}),c.ensureSingle(r,\"rect\",T.cboutline);var v=function(t,e,r){var o=r._fullLayout,l=o._size,h=e._fillcolor,v=e._line,b=e.title,A=b.side,M=e._zrange||n.extent((\"function\"==typeof h?h:v.color).domain()),S=\"function\"==typeof v.color?v.color:function(){return v.color},E=\"function\"==typeof h?h:function(){return h},C=e._levels,L=function(t,e,r){var n,i,a=e._levels,o=[],s=[],l=a.end+a.size/100,c=a.size,u=1.001*r[0]-.001*r[1],h=1.001*r[1]-.001*r[0];for(i=0;i<1e5&&(n=a.start+i*c,!(c>0?n>=l:n<=l));i++)n>u&&n<h&&o.push(n);if(e._fillgradient)s=[0];else if(\"function\"==typeof e._fillcolor){var f=e._filllevels;if(f)for(l=f.end+f.size/100,c=f.size,i=0;i<1e5&&(n=f.start+i*c,!(c>0?n>=l:n<=l));i++)n>r[0]&&n<r[1]&&s.push(n);else(s=o.map(function(t){return t-a.size/2})).push(s[s.length-1]+a.size)}else e._fillcolor&&\"string\"==typeof e._fillcolor&&(s=[0]);return a.size<0&&(o.reverse(),s.reverse()),{line:o,fill:s}}(0,e,M),P=L.fill,O=L.line,z=Math.round(e.thickness*(\"fraction\"===e.thicknessmode?l.w:1)),I=z/l.w,D=Math.round(e.len*(\"fraction\"===e.lenmode?l.h:1)),R=D/l.h,F=e.xpad/l.w,B=(e.borderwidth+e.outlinewidth)/2,N=e.ypad/l.h,j=Math.round(e.x*l.w+e.xpad),U=e.x-I*({middle:.5,right:1}[e.xanchor]||0),V=e.y+R*(({top:-.5,bottom:.5}[e.yanchor]||0)-.5),q=Math.round(l.h*(1-V)),H=q-D;e._lenFrac=R,e._thickFrac=I,e._xLeftFrac=U,e._yBottomFrac=V;var G=function(t,e,r){var n=t._fullLayout,i={type:\"linear\",range:r,tickmode:e.tickmode,nticks:e.nticks,tick0:e.tick0,dtick:e.dtick,tickvals:e.tickvals,ticktext:e.ticktext,ticks:e.ticks,ticklen:e.ticklen,tickwidth:e.tickwidth,tickcolor:e.tickcolor,showticklabels:e.showticklabels,tickfont:e.tickfont,tickangle:e.tickangle,tickformat:e.tickformat,exponentformat:e.exponentformat,separatethousands:e.separatethousands,showexponent:e.showexponent,showtickprefix:e.showtickprefix,tickprefix:e.tickprefix,showticksuffix:e.showticksuffix,ticksuffix:e.ticksuffix,title:e.title,showline:!0,anchor:\"free\",side:\"right\",position:1},a={type:\"linear\",_id:\"y\"+e._id},o={letter:\"y\",font:n.font,noHover:!0,noTickson:!0,calendar:n.calendar};function s(t,e){return c.coerce(i,a,x,t,e)}return m(i,a,s,o,n),y(i,a,s,o),a}(r,e,M);if(G.position=e.x+F+I,-1!==[\"top\",\"bottom\"].indexOf(A)&&(G.title.side=A,G.titlex=e.x+F,G.titley=V+(\"top\"===b.side?R-N:N)),v.color&&\"auto\"===e.tickmode){G.tickmode=\"linear\",G.tick0=C.start;var Y=C.size,W=c.constrain((q-H)/50,4,15)+1,X=(M[1]-M[0])/((e.nticks||W)*Y);if(X>1){var Z=Math.pow(10,Math.floor(Math.log(X)/Math.LN10));Y*=Z*c.roundUp(X/Z,[2,5,10]),(Math.abs(C.start)/C.size+1e-6)%1<2e-6&&(G.tick0=0)}G.dtick=Y}G.domain=[V+N,V+R-N],G.setScale(),t.attr(\"transform\",\"translate(\"+Math.round(l.l)+\",\"+Math.round(l.t)+\")\");var J,K=t.select(\".\"+T.cbtitleunshift).attr(\"transform\",\"translate(-\"+Math.round(l.l)+\",-\"+Math.round(l.t)+\")\"),$=t.select(\".\"+T.cbaxis),Q=0;function tt(n,i){var a={propContainer:G,propName:e._propPrefix+\"title\",traceIndex:e._traceIndex,_meta:e._meta,placeholder:o._dfltTitle.colorbar,containerGroup:t.select(\".\"+T.cbtitle)},s=\"h\"===n.charAt(0)?n.substr(1):\"h\"+n;t.selectAll(\".\"+s+\",.\"+s+\"-math-group\").remove(),d.draw(r,n,u(a,i||{}))}return c.syncOrAsync([a.previousPromises,function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var t,r=l.l+(e.x+F)*l.w,n=G.title.font.size;t=\"top\"===A?(1-(V+R-N))*l.h+l.t+3+.75*n:(1-(V+N))*l.h+l.t-3-.25*n,tt(G._id+\"title\",{attributes:{x:r,y:t,\"text-anchor\":\"start\"}})}},function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var a=t.select(\".\"+T.cbtitle),o=a.select(\"text\"),u=[-e.outlinewidth/2,e.outlinewidth/2],h=a.select(\".h\"+G._id+\"title-math-group\").node(),p=15.6;if(o.node()&&(p=parseInt(o.node().style.fontSize,10)*_),h?(Q=f.bBox(h).height)>p&&(u[1]-=(Q-p)/2):o.node()&&!o.classed(T.jsPlaceholder)&&(Q=f.bBox(o.node()).height),Q){if(Q+=5,\"top\"===A)G.domain[1]-=Q/l.h,u[1]*=-1;else{G.domain[0]+=Q/l.h;var d=g.lineCount(o);u[1]+=(1-d)*p}a.attr(\"transform\",\"translate(\"+u+\")\"),G.setScale()}}t.selectAll(\".\"+T.cbfills+\",.\"+T.cblines).attr(\"transform\",\"translate(0,\"+Math.round(l.h*(1-G.domain[1]))+\")\"),$.attr(\"transform\",\"translate(0,\"+Math.round(-l.t)+\")\");var m=t.select(\".\"+T.cbfills).selectAll(\"rect.\"+T.cbfill).data(P);m.enter().append(\"rect\").classed(T.cbfill,!0).style(\"stroke\",\"none\"),m.exit().remove();var y=M.map(G.c2p).map(Math.round).sort(function(t,e){return t-e});m.each(function(t,a){var o=[0===a?M[0]:(P[a]+P[a-1])/2,a===P.length-1?M[1]:(P[a]+P[a+1])/2].map(G.c2p).map(Math.round);o[1]=c.constrain(o[1]+(o[1]>o[0])?1:-1,y[0],y[1]);var s=n.select(this).attr({x:j,width:Math.max(z,2),y:n.min(o),height:Math.max(n.max(o)-n.min(o),2)});if(e._fillgradient)f.gradient(s,r,e._id,\"vertical\",e._fillgradient,\"fill\");else{var l=E(t).replace(\"e-\",\"\");s.attr(\"fill\",i(l).toHexString())}});var x=t.select(\".\"+T.cblines).selectAll(\"path.\"+T.cbline).data(v.color&&v.width?O:[]);x.enter().append(\"path\").classed(T.cbline,!0),x.exit().remove(),x.each(function(t){n.select(this).attr(\"d\",\"M\"+j+\",\"+(Math.round(G.c2p(t))+v.width/2%1)+\"h\"+z).call(f.lineGroupStyle,v.width,S(t),v.dash)}),$.selectAll(\"g.\"+G._id+\"tick,path\").remove();var b=j+z+(e.outlinewidth||0)/2-(\"outside\"===e.ticks?1:0),w=s.calcTicks(G),k=s.makeTransFn(G),C=s.getTickSigns(G)[2];return s.drawTicks(r,G,{vals:\"inside\"===G.ticks?s.clipEnds(G,w):w,layer:$,path:s.makeTickPath(G,b,C),transFn:k}),s.drawLabels(r,G,{vals:w,layer:$,transFn:k,labelFns:s.makeLabelFns(G,b)})},function(){if(-1===[\"top\",\"bottom\"].indexOf(A)){var t=G.title.font.size,e=G._offset+G._length/2,i=l.l+(G.position||0)*l.w+(\"right\"===G.side?10+t*(G.showticklabels?1:.5):-10-t*(G.showticklabels?.5:0));tt(\"h\"+G._id+\"title\",{avoid:{selection:n.select(r).selectAll(\"g.\"+G._id+\"tick\"),side:A,offsetLeft:l.l,offsetTop:0,maxShift:o.width},attributes:{x:i,y:e,\"text-anchor\":\"middle\"},transform:{rotate:\"-90\",offset:0}})}},a.previousPromises,function(){var n=z+e.outlinewidth/2+f.bBox($.node()).width;if((J=K.select(\"text\")).node()&&!J.classed(T.jsPlaceholder)){var i,o=K.select(\".h\"+G._id+\"title-math-group\").node();i=o&&-1!==[\"top\",\"bottom\"].indexOf(A)?f.bBox(o).width:f.bBox(K.node()).right-j-l.l,n=Math.max(n,i)}var s=2*e.xpad+n+e.borderwidth+e.outlinewidth/2,c=q-H;t.select(\".\"+T.cbbg).attr({x:j-e.xpad-(e.borderwidth+e.outlinewidth)/2,y:H-B,width:Math.max(s,2),height:Math.max(c+2*B,2)}).call(p.fill,e.bgcolor).call(p.stroke,e.bordercolor).style(\"stroke-width\",e.borderwidth),t.selectAll(\".\"+T.cboutline).attr({x:j,y:H+e.ypad+(\"top\"===A?Q:0),width:Math.max(z,2),height:Math.max(c-2*e.ypad-Q,2)}).call(p.stroke,e.outlinecolor).style({fill:\"none\",\"stroke-width\":e.outlinewidth});var u=({center:.5,right:1}[e.xanchor]||0)*s;t.attr(\"transform\",\"translate(\"+(l.l-u)+\",\"+l.t+\")\");var h={},d=w[e.yanchor],g=k[e.yanchor];\"pixels\"===e.lenmode?(h.y=e.y,h.t=c*d,h.b=c*g):(h.t=h.b=0,h.yt=e.y+e.len*d,h.yb=e.y-e.len*g);var v=w[e.xanchor],m=k[e.xanchor];if(\"pixels\"===e.thicknessmode)h.x=e.x,h.l=s*v,h.r=s*m;else{var y=s-z;h.l=y*v,h.r=y*m,h.xl=e.x-e.thickness*v,h.xr=e.x+e.thickness*m}a.autoMargin(r,e._id,h)}],r)}(r,e,t);v&&v.then&&(t._promises||[]).push(v),t._context.edits.colorbarPosition&&function(t,e,r){var n,i,a,s=r._fullLayout._size;l.init({element:t.node(),gd:r,prepFn:function(){n=t.attr(\"transform\"),h(t)},moveFn:function(r,o){t.attr(\"transform\",n+\" translate(\"+r+\",\"+o+\")\"),i=l.align(e._xLeftFrac+r/s.w,e._thickFrac,0,1,e.xanchor),a=l.align(e._yBottomFrac-o/s.h,e._lenFrac,0,1,e.yanchor);var c=l.getCursor(i,a,e.xanchor,e.yanchor);h(t,c)},doneFn:function(){if(h(t),void 0!==i&&void 0!==a){var n={};n[e._propPrefix+\"x\"]=i,n[e._propPrefix+\"y\"]=a,void 0!==e._traceIndex?o.call(\"_guiRestyle\",r,n,e._traceIndex):o.call(\"_guiRelayout\",r,n)}}})}(r,e,t)}),e.exit().each(function(e){a.autoMargin(t,e._id)}).remove(),e.order()}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/extend\":710,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_defaults\":769,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/cartesian/position_defaults\":782,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../colorscale/helpers\":604,\"../dragelement\":611,\"../drawing\":614,\"../titles\":681,\"./constants\":595,d3:163,tinycolor2:537}],598:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t){return n.isPlainObject(t.colorbar)}},{\"../../lib\":719}],599:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"colorbar\",attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),draw:t(\"./draw\").draw,hasColorbar:t(\"./has_colorbar\")}},{\"./attributes\":594,\"./defaults\":596,\"./draw\":597,\"./has_colorbar\":598}],600:[function(t,e,r){\"use strict\";var n=t(\"../colorbar/attributes\"),i=t(\"../../lib/regex\").counter,a=t(\"./scales.js\").scales;Object.keys(a);function o(t){return\"`\"+t+\"`\"}e.exports=function(t,e){t=t||\"\";var r,s=(e=e||{}).cLetter||\"c\",l=(\"onlyIfNumerical\"in e?e.onlyIfNumerical:Boolean(t),\"noScale\"in e?e.noScale:\"marker.line\"===t),c=\"showScaleDflt\"in e?e.showScaleDflt:\"z\"===s,u=\"string\"==typeof e.colorscaleDflt?a[e.colorscaleDflt]:null,h=e.editTypeOverride||\"\",f=t?t+\".\":\"\";\"colorAttr\"in e?(r=e.colorAttr,e.colorAttr):o(f+(r={z:\"z\",c:\"color\"}[s]));var p=s+\"auto\",d=s+\"min\",g=s+\"max\",v=s+\"mid\",m=(o(f+p),o(f+d),o(f+g),{});m[d]=m[g]=void 0;var y={};y[p]=!1;var x={};return\"color\"===r&&(x.color={valType:\"color\",arrayOk:!0,editType:h||\"style\"},e.anim&&(x.color.anim=!0)),x[p]={valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:m},x[d]={valType:\"number\",dflt:null,editType:h||\"plot\",impliedEdits:y},x[g]={valType:\"number\",dflt:null,editType:h||\"plot\",impliedEdits:y},x[v]={valType:\"number\",dflt:null,editType:\"calc\",impliedEdits:m},x.colorscale={valType:\"colorscale\",editType:\"calc\",dflt:u,impliedEdits:{autocolorscale:!1}},x.autocolorscale={valType:\"boolean\",dflt:!1!==e.autoColorDflt,editType:\"calc\",impliedEdits:{colorscale:void 0}},x.reversescale={valType:\"boolean\",dflt:!1,editType:\"plot\"},l||(x.showscale={valType:\"boolean\",dflt:c,editType:\"calc\"},x.colorbar=n),e.noColorAxis||(x.coloraxis={valType:\"subplotid\",regex:i(\"coloraxis\"),dflt:null,editType:\"calc\"}),x}},{\"../../lib/regex\":735,\"../colorbar/attributes\":594,\"./scales.js\":608}],601:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"./helpers\").extractOpts;e.exports=function(t,e,r){var o,s=t._fullLayout,l=r.vals,c=r.containerStr,u=c?i.nestedProperty(e,c).get():e,h=a(u),f=!1!==h.auto,p=h.min,d=h.max,g=h.mid,v=function(){return i.aggNums(Math.min,null,l)},m=function(){return i.aggNums(Math.max,null,l)};(void 0===p?p=v():f&&(p=u._colorAx&&n(p)?Math.min(p,v()):v()),void 0===d?d=m():f&&(d=u._colorAx&&n(d)?Math.max(d,m()):m()),f&&void 0!==g&&(d-g>g-p?p=g-(d-g):d-g<g-p&&(d=g+(g-p))),p===d&&(p-=.5,d+=.5),h._sync(\"min\",p),h._sync(\"max\",d),h.autocolorscale)&&(o=p*d<0?s.colorscale.diverging:p>=0?s.colorscale.sequential:s.colorscale.sequentialminus,h._sync(\"colorscale\",o))}},{\"../../lib\":719,\"./helpers\":604,\"fast-isnumeric\":225}],602:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./helpers\").hasColorscale,a=t(\"./helpers\").extractOpts;e.exports=function(t,e){function r(t,e){var r=t[\"_\"+e];void 0!==r&&(t[e]=r)}function o(t,i){var o=i.container?n.nestedProperty(t,i.container).get():t;if(o)if(o.coloraxis)o._colorAx=e[o.coloraxis];else{var s=a(o),l=s.auto;(l||void 0===s.min)&&r(o,i.min),(l||void 0===s.max)&&r(o,i.max),s.autocolorscale&&r(o,\"colorscale\")}}for(var s=0;s<t.length;s++){var l=t[s],c=l._module.colorbar;if(c)if(Array.isArray(c))for(var u=0;u<c.length;u++)o(l,c[u]);else o(l,c);i(l,\"marker.line\")&&o(l,{container:\"marker.line\",min:\"cmin\",max:\"cmax\"})}for(var h in e._colorAxes)o(e[h],{min:\"cmin\",max:\"cmax\"})}},{\"../../lib\":719,\"./helpers\":604}],603:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../colorbar/has_colorbar\"),o=t(\"../colorbar/defaults\"),s=t(\"./scales\").isValid,l=t(\"../../registry\").traceIs;function c(t,e){var r=e.slice(0,e.length-1);return e?i.nestedProperty(t,r).get()||{}:t}e.exports=function t(e,r,u,h,f){var p=f.prefix,d=f.cLetter,g=\"_module\"in r,v=c(e,p),m=c(r,p),y=c(r._template||{},p)||{},x=function(){return delete e.coloraxis,delete r.coloraxis,t(e,r,u,h,f)};if(g){var b=u._colorAxes||{},_=h(p+\"coloraxis\");if(_){var w=l(r,\"contour\")&&i.nestedProperty(r,\"contours.coloring\").get()||\"heatmap\",k=b[_];return void(k?(k[2].push(x),k[0]!==w&&(k[0]=!1,i.warn([\"Ignoring coloraxis:\",_,\"setting\",\"as it is linked to incompatible colorscales.\"].join(\" \")))):b[_]=[w,r,[x]])}}var T=v[d+\"min\"],A=v[d+\"max\"],M=n(T)&&n(A)&&T<A;h(p+d+\"auto\",!M)?h(p+d+\"mid\"):(h(p+d+\"min\"),h(p+d+\"max\"));var S,E,C=v.colorscale,L=y.colorscale;(void 0!==C&&(S=!s(C)),void 0!==L&&(S=!s(L)),h(p+\"autocolorscale\",S),h(p+\"colorscale\"),h(p+\"reversescale\"),\"marker.line.\"!==p)&&(p&&g&&(E=a(v)),h(p+\"showscale\",E)&&o(v,m,u))}},{\"../../lib\":719,\"../../registry\":847,\"../colorbar/defaults\":596,\"../colorbar/has_colorbar\":598,\"./scales\":608,\"fast-isnumeric\":225}],604:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"fast-isnumeric\"),o=t(\"../../lib\"),s=t(\"../color\"),l=t(\"./scales\").isValid;var c=[\"showscale\",\"autocolorscale\",\"colorscale\",\"reversescale\",\"colorbar\"],u=[\"min\",\"max\",\"mid\",\"auto\"];function h(t){var e,r,n,i=t._colorAx,a=i||t,o={};for(r=0;r<c.length;r++)o[n=c[r]]=a[n];if(i)for(e=\"c\",r=0;r<u.length;r++)o[n=u[r]]=a[\"c\"+n];else{var s;for(r=0;r<u.length;r++)(s=\"c\"+(n=u[r]))in a?o[n]=a[s]:(s=\"z\"+n)in a&&(o[n]=a[s]);e=s.charAt(0)}return o._sync=function(t,r){var n=-1!==u.indexOf(t)?e+t:t;a[n]=a[\"_\"+n]=r},o}function f(t){for(var e=h(t),r=e.min,n=e.max,i=e.reversescale?p(e.colorscale):e.colorscale,a=i.length,o=new Array(a),s=new Array(a),l=0;l<a;l++){var c=i[l];o[l]=r+c[0]*(n-r),s[l]=c[1]}return{domain:o,range:s}}function p(t){for(var e=t.length,r=new Array(e),n=e-1,i=0;n>=0;n--,i++){var a=t[n];r[i]=[1-a[0],a[1]]}return r}function d(t,e){e=e||{};for(var r=t.domain,o=t.range,l=o.length,c=new Array(l),u=0;u<l;u++){var h=i(o[u]).toRgb();c[u]=[h.r,h.g,h.b,h.a]}var f,p=n.scale.linear().domain(r).range(c).clamp(!0),d=e.noNumericCheck,v=e.returnArray;return(f=d&&v?p:d?function(t){return g(p(t))}:v?function(t){return a(t)?p(t):i(t).isValid()?t:s.defaultLine}:function(t){return a(t)?g(p(t)):i(t).isValid()?t:s.defaultLine}).domain=p.domain,f.range=function(){return o},f}function g(t){var e={r:t[0],g:t[1],b:t[2],a:t[3]};return i(e).toRgbString()}e.exports={hasColorscale:function(t,e){var r=e?o.nestedProperty(t,e).get()||{}:t,n=r.color,i=!1;if(o.isArrayOrTypedArray(n))for(var s=0;s<n.length;s++)if(a(n[s])){i=!0;break}return o.isPlainObject(r)&&(i||!0===r.showscale||a(r.cmin)&&a(r.cmax)||l(r.colorscale)||o.isPlainObject(r.colorbar))},extractOpts:h,extractScale:f,flipScale:p,makeColorScaleFunc:d,makeColorScaleFuncFromTrace:function(t,e){return d(f(t),e)}}},{\"../../lib\":719,\"../color\":593,\"./scales\":608,d3:163,\"fast-isnumeric\":225,tinycolor2:537}],605:[function(t,e,r){\"use strict\";var n=t(\"./scales\"),i=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"colorscale\",attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),handleDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\"),scales:n.scales,defaultScale:n.defaultScale,getScale:n.get,isValidScale:n.isValid,hasColorscale:i.hasColorscale,extractOpts:i.extractOpts,extractScale:i.extractScale,flipScale:i.flipScale,makeColorScaleFunc:i.makeColorScaleFunc,makeColorScaleFuncFromTrace:i.makeColorScaleFuncFromTrace}},{\"./attributes\":600,\"./calc\":601,\"./cross_trace_defaults\":602,\"./defaults\":603,\"./helpers\":604,\"./layout_attributes\":606,\"./layout_defaults\":607,\"./scales\":608}],606:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"./attributes\"),a=t(\"./scales\").scales;e.exports={editType:\"calc\",colorscale:{editType:\"calc\",sequential:{valType:\"colorscale\",dflt:a.Reds,editType:\"calc\"},sequentialminus:{valType:\"colorscale\",dflt:a.Blues,editType:\"calc\"},diverging:{valType:\"colorscale\",dflt:a.RdBu,editType:\"calc\"}},coloraxis:n({_isSubplotObj:!0,editType:\"calc\"},i(\"\",{colorAttr:\"corresponding trace color array(s)\",noColorAxis:!0,showScaleDflt:!0}))}},{\"../../lib/extend\":710,\"./attributes\":600,\"./scales\":608}],607:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"./layout_attributes\"),o=t(\"./defaults\");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r(\"colorscale.sequential\"),r(\"colorscale.sequentialminus\"),r(\"colorscale.diverging\");var s,l,c=e._colorAxes;function u(t,e){return n.coerce(s,l,a.coloraxis,t,e)}for(var h in c){var f=c[h];if(f[0])s=t[h]||{},(l=i.newContainer(e,h,\"coloraxis\"))._name=h,o(s,l,e,u,{prefix:\"\",cLetter:\"c\"});else{for(var p=0;p<f[2].length;p++)f[2][p]();delete e._colorAxes[h]}}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"./defaults\":603,\"./layout_attributes\":606}],608:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i={Greys:[[0,\"rgb(0,0,0)\"],[1,\"rgb(255,255,255)\"]],YlGnBu:[[0,\"rgb(8,29,88)\"],[.125,\"rgb(37,52,148)\"],[.25,\"rgb(34,94,168)\"],[.375,\"rgb(29,145,192)\"],[.5,\"rgb(65,182,196)\"],[.625,\"rgb(127,205,187)\"],[.75,\"rgb(199,233,180)\"],[.875,\"rgb(237,248,217)\"],[1,\"rgb(255,255,217)\"]],Greens:[[0,\"rgb(0,68,27)\"],[.125,\"rgb(0,109,44)\"],[.25,\"rgb(35,139,69)\"],[.375,\"rgb(65,171,93)\"],[.5,\"rgb(116,196,118)\"],[.625,\"rgb(161,217,155)\"],[.75,\"rgb(199,233,192)\"],[.875,\"rgb(229,245,224)\"],[1,\"rgb(247,252,245)\"]],YlOrRd:[[0,\"rgb(128,0,38)\"],[.125,\"rgb(189,0,38)\"],[.25,\"rgb(227,26,28)\"],[.375,\"rgb(252,78,42)\"],[.5,\"rgb(253,141,60)\"],[.625,\"rgb(254,178,76)\"],[.75,\"rgb(254,217,118)\"],[.875,\"rgb(255,237,160)\"],[1,\"rgb(255,255,204)\"]],Bluered:[[0,\"rgb(0,0,255)\"],[1,\"rgb(255,0,0)\"]],RdBu:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(106,137,247)\"],[.5,\"rgb(190,190,190)\"],[.6,\"rgb(220,170,132)\"],[.7,\"rgb(230,145,90)\"],[1,\"rgb(178,10,28)\"]],Reds:[[0,\"rgb(220,220,220)\"],[.2,\"rgb(245,195,157)\"],[.4,\"rgb(245,160,105)\"],[1,\"rgb(178,10,28)\"]],Blues:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(40,60,190)\"],[.5,\"rgb(70,100,245)\"],[.6,\"rgb(90,120,245)\"],[.7,\"rgb(106,137,247)\"],[1,\"rgb(220,220,220)\"]],Picnic:[[0,\"rgb(0,0,255)\"],[.1,\"rgb(51,153,255)\"],[.2,\"rgb(102,204,255)\"],[.3,\"rgb(153,204,255)\"],[.4,\"rgb(204,204,255)\"],[.5,\"rgb(255,255,255)\"],[.6,\"rgb(255,204,255)\"],[.7,\"rgb(255,153,255)\"],[.8,\"rgb(255,102,204)\"],[.9,\"rgb(255,102,102)\"],[1,\"rgb(255,0,0)\"]],Rainbow:[[0,\"rgb(150,0,90)\"],[.125,\"rgb(0,0,200)\"],[.25,\"rgb(0,25,255)\"],[.375,\"rgb(0,152,255)\"],[.5,\"rgb(44,255,150)\"],[.625,\"rgb(151,255,0)\"],[.75,\"rgb(255,234,0)\"],[.875,\"rgb(255,111,0)\"],[1,\"rgb(255,0,0)\"]],Portland:[[0,\"rgb(12,51,131)\"],[.25,\"rgb(10,136,186)\"],[.5,\"rgb(242,211,56)\"],[.75,\"rgb(242,143,56)\"],[1,\"rgb(217,30,30)\"]],Jet:[[0,\"rgb(0,0,131)\"],[.125,\"rgb(0,60,170)\"],[.375,\"rgb(5,255,255)\"],[.625,\"rgb(255,255,0)\"],[.875,\"rgb(250,0,0)\"],[1,\"rgb(128,0,0)\"]],Hot:[[0,\"rgb(0,0,0)\"],[.3,\"rgb(230,0,0)\"],[.6,\"rgb(255,210,0)\"],[1,\"rgb(255,255,255)\"]],Blackbody:[[0,\"rgb(0,0,0)\"],[.2,\"rgb(230,0,0)\"],[.4,\"rgb(230,210,0)\"],[.7,\"rgb(255,255,255)\"],[1,\"rgb(160,200,255)\"]],Earth:[[0,\"rgb(0,0,130)\"],[.1,\"rgb(0,180,180)\"],[.2,\"rgb(40,210,40)\"],[.4,\"rgb(230,230,50)\"],[.6,\"rgb(120,70,20)\"],[1,\"rgb(255,255,255)\"]],Electric:[[0,\"rgb(0,0,0)\"],[.15,\"rgb(30,0,100)\"],[.4,\"rgb(120,0,100)\"],[.6,\"rgb(160,90,0)\"],[.8,\"rgb(230,200,0)\"],[1,\"rgb(255,250,220)\"]],Viridis:[[0,\"#440154\"],[.06274509803921569,\"#48186a\"],[.12549019607843137,\"#472d7b\"],[.18823529411764706,\"#424086\"],[.25098039215686274,\"#3b528b\"],[.3137254901960784,\"#33638d\"],[.3764705882352941,\"#2c728e\"],[.4392156862745098,\"#26828e\"],[.5019607843137255,\"#21918c\"],[.5647058823529412,\"#1fa088\"],[.6274509803921569,\"#28ae80\"],[.6901960784313725,\"#3fbc73\"],[.7529411764705882,\"#5ec962\"],[.8156862745098039,\"#84d44b\"],[.8784313725490196,\"#addc30\"],[.9411764705882353,\"#d8e219\"],[1,\"#fde725\"]],Cividis:[[0,\"rgb(0,32,76)\"],[.058824,\"rgb(0,42,102)\"],[.117647,\"rgb(0,52,110)\"],[.176471,\"rgb(39,63,108)\"],[.235294,\"rgb(60,74,107)\"],[.294118,\"rgb(76,85,107)\"],[.352941,\"rgb(91,95,109)\"],[.411765,\"rgb(104,106,112)\"],[.470588,\"rgb(117,117,117)\"],[.529412,\"rgb(131,129,120)\"],[.588235,\"rgb(146,140,120)\"],[.647059,\"rgb(161,152,118)\"],[.705882,\"rgb(176,165,114)\"],[.764706,\"rgb(192,177,109)\"],[.823529,\"rgb(209,191,102)\"],[.882353,\"rgb(225,204,92)\"],[.941176,\"rgb(243,219,79)\"],[1,\"rgb(255,233,69)\"]]},a=i.RdBu;function o(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var i=t[r];if(2!==i.length||+i[0]<e||!n(i[1]).isValid())return!1;e=+i[0]}return!0}e.exports={scales:i,defaultScale:a,get:function(t,e){if(e||(e=a),!t)return e;function r(){try{t=i[t]||JSON.parse(t)}catch(r){t=e}}return\"string\"==typeof t&&(r(),\"string\"==typeof t&&r()),o(t)?t:e},isValid:function(t){return void 0!==i[t]||o(t)}}},{tinycolor2:537}],609:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=(t-r)/(n-r),o=a+e/(n-r),s=(a+o)/2;return\"left\"===i||\"bottom\"===i?a:\"center\"===i||\"middle\"===i?s:\"right\"===i||\"top\"===i?o:a<2/3-s?a:o>4/3-s?o:s}},{}],610:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[\"sw-resize\",\"s-resize\",\"se-resize\"],[\"w-resize\",\"move\",\"e-resize\"],[\"nw-resize\",\"n-resize\",\"ne-resize\"]];e.exports=function(t,e,r,a){return t=\"left\"===r?0:\"center\"===r?1:\"right\"===r?2:n.constrain(Math.floor(3*t),0,2),e=\"bottom\"===a?0:\"middle\"===a?1:\"top\"===a?2:n.constrain(Math.floor(3*e),0,2),i[e][t]}},{\"../../lib\":719}],611:[function(t,e,r){\"use strict\";var n=t(\"mouse-event-offset\"),i=t(\"has-hover\"),a=t(\"has-passive-events\"),o=t(\"../../lib\").removeElement,s=t(\"../../plots/cartesian/constants\"),l=e.exports={};l.align=t(\"./align\"),l.getCursor=t(\"./cursor\");var c=t(\"./unhover\");function u(){var t=document.createElement(\"div\");t.className=\"dragcover\";var e=t.style;return e.position=\"fixed\",e.left=0,e.right=0,e.top=0,e.bottom=0,e.zIndex=999999999,e.background=\"none\",document.body.appendChild(t),t}function h(t){return n(t.changedTouches?t.changedTouches[0]:t,document.body)}l.unhover=c.wrapped,l.unhoverRaw=c.raw,l.init=function(t){var e,r,n,c,f,p,d,g,v=t.gd,m=1,y=v._context.doubleClickDelay,x=t.element;v._mouseDownTime||(v._mouseDownTime=0),x.style.pointerEvents=\"all\",x.onmousedown=_,a?(x._ontouchstart&&x.removeEventListener(\"touchstart\",x._ontouchstart),x._ontouchstart=_,x.addEventListener(\"touchstart\",_,{passive:!1})):x.ontouchstart=_;var b=t.clampFn||function(t,e,r){return Math.abs(t)<r&&(t=0),Math.abs(e)<r&&(e=0),[t,e]};function _(a){v._dragged=!1,v._dragging=!0;var o=h(a);e=o[0],r=o[1],d=a.target,p=a,g=2===a.buttons||a.ctrlKey,\"undefined\"==typeof a.clientX&&\"undefined\"==typeof a.clientY&&(a.clientX=e,a.clientY=r),(n=(new Date).getTime())-v._mouseDownTime<y?m+=1:(m=1,v._mouseDownTime=n),t.prepFn&&t.prepFn(a,e,r),i&&!g?(f=u()).style.cursor=window.getComputedStyle(x).cursor:i||(f=document,c=window.getComputedStyle(document.documentElement).cursor,document.documentElement.style.cursor=window.getComputedStyle(x).cursor),document.addEventListener(\"mouseup\",k),document.addEventListener(\"touchend\",k),!1!==t.dragmode&&(a.preventDefault(),document.addEventListener(\"mousemove\",w),document.addEventListener(\"touchmove\",w))}function w(n){n.preventDefault();var i=h(n),a=t.minDrag||s.MINDRAG,o=b(i[0]-e,i[1]-r,a),c=o[0],u=o[1];(c||u)&&(v._dragged=!0,l.unhover(v)),v._dragged&&t.moveFn&&!g&&(v._dragdata={element:x,dx:c,dy:u},t.moveFn(c,u))}function k(e){if(delete v._dragdata,!1!==t.dragmode&&(e.preventDefault(),document.removeEventListener(\"mousemove\",w),document.removeEventListener(\"touchmove\",w)),document.removeEventListener(\"mouseup\",k),document.removeEventListener(\"touchend\",k),i?o(f):c&&(f.documentElement.style.cursor=c,c=null),v._dragging){if(v._dragging=!1,(new Date).getTime()-v._mouseDownTime>y&&(m=Math.max(m-1,1)),v._dragged)t.doneFn&&t.doneFn();else if(t.clickFn&&t.clickFn(m,p),!g){var r;try{r=new MouseEvent(\"click\",e)}catch(t){var n=h(e);(r=document.createEvent(\"MouseEvents\")).initMouseEvent(\"click\",e.bubbles,e.cancelable,e.view,e.detail,e.screenX,e.screenY,n[0],n[1],e.ctrlKey,e.altKey,e.shiftKey,e.metaKey,e.button,e.relatedTarget)}d.dispatchEvent(r)}v._dragging=!1,v._dragged=!1}else v._dragged=!1}},l.coverSlip=u},{\"../../lib\":719,\"../../plots/cartesian/constants\":773,\"./align\":609,\"./cursor\":610,\"./unhover\":612,\"has-hover\":410,\"has-passive-events\":411,\"mouse-event-offset\":436}],612:[function(t,e,r){\"use strict\";var n=t(\"../../lib/events\"),i=t(\"../../lib/throttle\"),a=t(\"../../lib/dom\").getGraphDiv,o=t(\"../fx/constants\"),s=e.exports={};s.wrapped=function(t,e,r){(t=a(t))._fullLayout&&i.clear(t._fullLayout._uid+o.HOVERID),s.raw(t,e,r)},s.raw=function(t,e){var r=t._fullLayout,i=t._hoverdata;e||(e={}),e.target&&!1===n.triggerHandler(t,\"plotly_beforehover\",e)||(r._hoverlayer.selectAll(\"g\").remove(),r._hoverlayer.selectAll(\"line\").remove(),r._hoverlayer.selectAll(\"circle\").remove(),t._hoverdata=void 0,e.target&&i&&t.emit(\"plotly_unhover\",{event:e,points:i}))}},{\"../../lib/dom\":708,\"../../lib/events\":709,\"../../lib/throttle\":744,\"../fx/constants\":626}],613:[function(t,e,r){\"use strict\";r.dash={valType:\"string\",values:[\"solid\",\"dot\",\"dash\",\"longdash\",\"dashdot\",\"longdashdot\"],dflt:\"solid\",editType:\"style\"}},{}],614:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../registry\"),s=t(\"../color\"),l=t(\"../colorscale\"),c=t(\"../../lib\"),u=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/xmlns_namespaces\"),f=t(\"../../constants/alignment\").LINE_SPACING,p=t(\"../../constants/interactions\").DESELECTDIM,d=t(\"../../traces/scatter/subtypes\"),g=t(\"../../traces/scatter/make_bubble_size_func\"),v=e.exports={};v.font=function(t,e,r,n){c.isPlainObject(e)&&(n=e.color,r=e.size,e=e.family),e&&t.style(\"font-family\",e),r+1&&t.style(\"font-size\",r+\"px\"),n&&t.call(s.fill,n)},v.setPosition=function(t,e,r){t.attr(\"x\",e).attr(\"y\",r)},v.setSize=function(t,e,r){t.attr(\"width\",e).attr(\"height\",r)},v.setRect=function(t,e,r,n,i){t.call(v.setPosition,e,r).call(v.setSize,n,i)},v.translatePoint=function(t,e,r,n){var a=r.c2p(t.x),o=n.c2p(t.y);return!!(i(a)&&i(o)&&e.node())&&(\"text\"===e.node().nodeName?e.attr(\"x\",a).attr(\"y\",o):e.attr(\"transform\",\"translate(\"+a+\",\"+o+\")\"),!0)},v.translatePoints=function(t,e,r){t.each(function(t){var i=n.select(this);v.translatePoint(t,i,e,r)})},v.hideOutsideRangePoint=function(t,e,r,n,i,a){e.attr(\"display\",r.isPtWithinRange(t,i)&&n.isPtWithinRange(t,a)?null:\"none\")},v.hideOutsideRangePoints=function(t,e){if(e._hasClipOnAxisFalse){var r=e.xaxis,i=e.yaxis;t.each(function(e){var a=e[0].trace,s=a.xcalendar,l=a.ycalendar,c=o.traceIs(a,\"bar-like\")?\".bartext\":\".point,.textpoint\";t.selectAll(c).each(function(t){v.hideOutsideRangePoint(t,n.select(this),r,i,s,l)})})}},v.crispRound=function(t,e,r){return e&&i(e)?t._context.staticPlot?e:e<1?1:Math.round(e):r||0},v.singleLineStyle=function(t,e,r,n,i){e.style(\"fill\",\"none\");var a=(((t||[])[0]||{}).trace||{}).line||{},o=r||a.width||0,l=i||a.dash||\"\";s.stroke(e,n||a.color),v.dashLine(e,l,o)},v.lineGroupStyle=function(t,e,r,i){t.style(\"fill\",\"none\").each(function(t){var a=(((t||[])[0]||{}).trace||{}).line||{},o=e||a.width||0,l=i||a.dash||\"\";n.select(this).call(s.stroke,r||a.color).call(v.dashLine,l,o)})},v.dashLine=function(t,e,r){r=+r||0,e=v.dashStyle(e,r),t.style({\"stroke-dasharray\":e,\"stroke-width\":r+\"px\"})},v.dashStyle=function(t,e){e=+e||1;var r=Math.max(e,3);return\"solid\"===t?t=\"\":\"dot\"===t?t=r+\"px,\"+r+\"px\":\"dash\"===t?t=3*r+\"px,\"+3*r+\"px\":\"longdash\"===t?t=5*r+\"px,\"+5*r+\"px\":\"dashdot\"===t?t=3*r+\"px,\"+r+\"px,\"+r+\"px,\"+r+\"px\":\"longdashdot\"===t&&(t=5*r+\"px,\"+2*r+\"px,\"+r+\"px,\"+2*r+\"px\"),t},v.singleFillStyle=function(t){var e=(((n.select(t.node()).data()[0]||[])[0]||{}).trace||{}).fillcolor;e&&t.call(s.fill,e)},v.fillGroupStyle=function(t){t.style(\"stroke-width\",0).each(function(t){var e=n.select(this);t[0].trace&&e.call(s.fill,t[0].trace.fillcolor)})};var m=t(\"./symbol_defs\");v.symbolNames=[],v.symbolFuncs=[],v.symbolNeedLines={},v.symbolNoDot={},v.symbolNoFill={},v.symbolList=[],Object.keys(m).forEach(function(t){var e=m[t];v.symbolList=v.symbolList.concat([e.n,t,e.n+100,t+\"-open\"]),v.symbolNames[e.n]=t,v.symbolFuncs[e.n]=e.f,e.needLine&&(v.symbolNeedLines[e.n]=!0),e.noDot?v.symbolNoDot[e.n]=!0:v.symbolList=v.symbolList.concat([e.n+200,t+\"-dot\",e.n+300,t+\"-open-dot\"]),e.noFill&&(v.symbolNoFill[e.n]=!0)});var y=v.symbolNames.length,x=\"M0,0.5L0.5,0L0,-0.5L-0.5,0Z\";function b(t,e){var r=t%100;return v.symbolFuncs[r](e)+(t>=200?x:\"\")}v.symbolNumber=function(t){if(\"string\"==typeof t){var e=0;t.indexOf(\"-open\")>0&&(e=100,t=t.replace(\"-open\",\"\")),t.indexOf(\"-dot\")>0&&(e+=200,t=t.replace(\"-dot\",\"\")),(t=v.symbolNames.indexOf(t))>=0&&(t+=e)}return t%100>=y||t>=400?0:Math.floor(Math.max(t,0))};var _={x1:1,x2:0,y1:0,y2:0},w={x1:0,x2:0,y1:1,y2:0},k=n.format(\"~.1f\"),T={radial:{node:\"radialGradient\"},radialreversed:{node:\"radialGradient\",reversed:!0},horizontal:{node:\"linearGradient\",attrs:_},horizontalreversed:{node:\"linearGradient\",attrs:_,reversed:!0},vertical:{node:\"linearGradient\",attrs:w},verticalreversed:{node:\"linearGradient\",attrs:w,reversed:!0}};v.gradient=function(t,e,r,i,o,l){for(var u=o.length,h=T[i],f=new Array(u),p=0;p<u;p++)h.reversed?f[u-1-p]=[k(100*(1-o[p][0])),o[p][1]]:f[p]=[k(100*o[p][0]),o[p][1]];var d=\"g\"+e._fullLayout._uid+\"-\"+r,g=e._fullLayout._defs.select(\".gradients\").selectAll(\"#\"+d).data([i+f.join(\";\")],c.identity);g.exit().remove(),g.enter().append(h.node).each(function(){var t=n.select(this);h.attrs&&t.attr(h.attrs),t.attr(\"id\",d);var e=t.selectAll(\"stop\").data(f);e.exit().remove(),e.enter().append(\"stop\"),e.each(function(t){var e=a(t[1]);n.select(this).attr({offset:t[0]+\"%\",\"stop-color\":s.tinyRGB(e),\"stop-opacity\":e.getAlpha()})})}),t.style(l,I(d,e)).style(l+\"-opacity\",null)},v.initGradients=function(t){c.ensureSingle(t._fullLayout._defs,\"g\",\"gradients\").selectAll(\"linearGradient,radialGradient\").remove()},v.pointStyle=function(t,e,r){if(t.size()){var i=v.makePointStyleFns(e);t.each(function(t){v.singlePointStyle(t,n.select(this),e,i,r)})}},v.singlePointStyle=function(t,e,r,n,i){var a=r.marker,o=a.line;if(e.style(\"opacity\",n.selectedOpacityFn?n.selectedOpacityFn(t):void 0===t.mo?a.opacity:t.mo),n.ms2mrc){var l;l=\"various\"===t.ms||\"various\"===a.size?3:n.ms2mrc(t.ms),t.mrc=l,n.selectedSizeFn&&(l=t.mrc=n.selectedSizeFn(t));var u=v.symbolNumber(t.mx||a.symbol)||0;t.om=u%200>=100,e.attr(\"d\",b(u,l))}var h,f,p,d=!1;if(t.so)p=o.outlierwidth,f=o.outliercolor,h=a.outliercolor;else{var g=(o||{}).width;p=(t.mlw+1||g+1||(t.trace?(t.trace.marker.line||{}).width:0)+1)-1||0,f=\"mlc\"in t?t.mlcc=n.lineScale(t.mlc):c.isArrayOrTypedArray(o.color)?s.defaultLine:o.color,c.isArrayOrTypedArray(a.color)&&(h=s.defaultLine,d=!0),h=\"mc\"in t?t.mcc=n.markerScale(t.mc):a.color||\"rgba(0,0,0,0)\",n.selectedColorFn&&(h=n.selectedColorFn(t))}if(t.om)e.call(s.stroke,h).style({\"stroke-width\":(p||1)+\"px\",fill:\"none\"});else{e.style(\"stroke-width\",p+\"px\");var m=a.gradient,y=t.mgt;if(y?d=!0:y=m&&m.type,Array.isArray(y)&&(y=y[0],T[y]||(y=0)),y&&\"none\"!==y){var x=t.mgc;x?d=!0:x=m.color;var _=r.uid;d&&(_+=\"-\"+t.i),v.gradient(e,i,_,y,[[0,x],[1,h]],\"fill\")}else s.fill(e,h);p&&s.stroke(e,f)}},v.makePointStyleFns=function(t){var e={},r=t.marker;return e.markerScale=v.tryColorscale(r,\"\"),e.lineScale=v.tryColorscale(r,\"line\"),o.traceIs(t,\"symbols\")&&(e.ms2mrc=d.isBubble(t)?g(t):function(){return(r.size||6)/2}),t.selectedpoints&&c.extendFlat(e,v.makeSelectedPointStyleFns(t)),e},v.makeSelectedPointStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.marker||{},a=r.marker||{},s=n.marker||{},l=i.opacity,u=a.opacity,h=s.opacity,f=void 0!==u,d=void 0!==h;(c.isArrayOrTypedArray(l)||f||d)&&(e.selectedOpacityFn=function(t){var e=void 0===t.mo?i.opacity:t.mo;return t.selected?f?u:e:d?h:p*e});var g=i.color,v=a.color,m=s.color;(v||m)&&(e.selectedColorFn=function(t){var e=t.mcc||g;return t.selected?v||e:m||e});var y=i.size,x=a.size,b=s.size,_=void 0!==x,w=void 0!==b;return o.traceIs(t,\"symbols\")&&(_||w)&&(e.selectedSizeFn=function(t){var e=t.mrc||y/2;return t.selected?_?x/2:e:w?b/2:e}),e},v.makeSelectedTextStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.textfont||{},a=r.textfont||{},o=n.textfont||{},l=i.color,c=a.color,u=o.color;return e.selectedTextColorFn=function(t){var e=t.tc||l;return t.selected?c||e:u||(c?e:s.addOpacity(e,p))},e},v.selectedPointStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=v.makeSelectedPointStyleFns(e),i=e.marker||{},a=[];r.selectedOpacityFn&&a.push(function(t,e){t.style(\"opacity\",r.selectedOpacityFn(e))}),r.selectedColorFn&&a.push(function(t,e){s.fill(t,r.selectedColorFn(e))}),r.selectedSizeFn&&a.push(function(t,e){var n=e.mx||i.symbol||0,a=r.selectedSizeFn(e);t.attr(\"d\",b(v.symbolNumber(n),a)),e.mrc2=a}),a.length&&t.each(function(t){for(var e=n.select(this),r=0;r<a.length;r++)a[r](e,t)})}},v.tryColorscale=function(t,e){var r=e?c.nestedProperty(t,e).get():t;if(r){var n=r.color;if((r.colorscale||r._colorAx)&&c.isArrayOrTypedArray(n))return l.makeColorScaleFuncFromTrace(r)}return c.identity};var A={start:1,end:-1,middle:0,bottom:1,top:-1};function M(t,e,r,i){var a=n.select(t.node().parentNode),o=-1!==e.indexOf(\"top\")?\"top\":-1!==e.indexOf(\"bottom\")?\"bottom\":\"middle\",s=-1!==e.indexOf(\"left\")?\"end\":-1!==e.indexOf(\"right\")?\"start\":\"middle\",l=i?i/.8+1:0,c=(u.lineCount(t)-1)*f+1,h=A[s]*l,p=.75*r+A[o]*l+(A[o]-1)*c*r/2;t.attr(\"text-anchor\",s),a.attr(\"transform\",\"translate(\"+h+\",\"+p+\")\")}function S(t,e){var r=t.ts||e.textfont.size;return i(r)&&r>0?r:0}v.textPointStyle=function(t,e,r){if(t.size()){var i;if(e.selectedpoints){var a=v.makeSelectedTextStyleFns(e);i=a.selectedTextColorFn}t.each(function(t){var a=n.select(this),o=c.extractOption(t,e,\"tx\",\"text\");if(o||0===o){var s=t.tp||e.textposition,l=S(t,e),h=i?i(t):t.tc||e.textfont.color;a.call(v.font,t.tf||e.textfont.family,l,h).text(o).call(u.convertToTspans,r).call(M,s,l,t.mrc)}else a.remove()})}},v.selectedTextStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=v.makeSelectedTextStyleFns(e);t.each(function(t){var i=n.select(this),a=r.selectedTextColorFn(t),o=t.tp||e.textposition,l=S(t,e);s.fill(i,a),M(i,o,l,t.mrc2||t.mrc)})}};var E=.5;function C(t,e,r,i){var a=t[0]-e[0],o=t[1]-e[1],s=r[0]-e[0],l=r[1]-e[1],c=Math.pow(a*a+o*o,E/2),u=Math.pow(s*s+l*l,E/2),h=(u*u*a-c*c*s)*i,f=(u*u*o-c*c*l)*i,p=3*u*(c+u),d=3*c*(c+u);return[[n.round(e[0]+(p&&h/p),2),n.round(e[1]+(p&&f/p),2)],[n.round(e[0]-(d&&h/d),2),n.round(e[1]-(d&&f/d),2)]]}v.smoothopen=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\");var r,n=\"M\"+t[0],i=[];for(r=1;r<t.length-1;r++)i.push(C(t[r-1],t[r],t[r+1],e));for(n+=\"Q\"+i[0][0]+\" \"+t[1],r=2;r<t.length-1;r++)n+=\"C\"+i[r-2][1]+\" \"+i[r-1][0]+\" \"+t[r];return n+=\"Q\"+i[t.length-3][1]+\" \"+t[t.length-1]},v.smoothclosed=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\")+\"Z\";var r,n=\"M\"+t[0],i=t.length-1,a=[C(t[i],t[0],t[1],e)];for(r=1;r<i;r++)a.push(C(t[r-1],t[r],t[r+1],e));for(a.push(C(t[i-1],t[i],t[0],e)),r=1;r<=i;r++)n+=\"C\"+a[r-1][1]+\" \"+a[r][0]+\" \"+t[r];return n+=\"C\"+a[i][1]+\" \"+a[0][0]+\" \"+t[0]+\"Z\"};var L={hv:function(t,e){return\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)},vh:function(t,e){return\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},hvh:function(t,e){return\"H\"+n.round((t[0]+e[0])/2,2)+\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},vhv:function(t,e){return\"V\"+n.round((t[1]+e[1])/2,2)+\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)}},P=function(t,e){return\"L\"+n.round(e[0],2)+\",\"+n.round(e[1],2)};v.steps=function(t){var e=L[t]||P;return function(t){for(var r=\"M\"+n.round(t[0][0],2)+\",\"+n.round(t[0][1],2),i=1;i<t.length;i++)r+=e(t[i-1],t[i]);return r}},v.makeTester=function(){var t=c.ensureSingleById(n.select(\"body\"),\"svg\",\"js-plotly-tester\",function(t){t.attr(h.svgAttrs).style({position:\"absolute\",left:\"-10000px\",top:\"-10000px\",width:\"9000px\",height:\"9000px\",\"z-index\":\"1\"})}),e=c.ensureSingle(t,\"path\",\"js-reference-point\",function(t){t.attr(\"d\",\"M0,0H1V1H0Z\").style({\"stroke-width\":0,fill:\"black\"})});v.tester=t,v.testref=e},v.savedBBoxes={};var O=0;function z(t){var e=t.getAttribute(\"data-unformatted\");if(null!==e)return e+t.getAttribute(\"data-math\")+t.getAttribute(\"text-anchor\")+t.getAttribute(\"style\")}function I(t,e){if(!t)return null;var r=e._context;return\"url('\"+(r._exportedPlot?\"\":r._baseUrl||\"\")+\"#\"+t+\"')\"}v.bBox=function(t,e,r){var i,a,o;if(r||(r=z(t)),r){if(i=v.savedBBoxes[r])return c.extendFlat({},i)}else if(1===t.childNodes.length){var s=t.childNodes[0];if(r=z(s)){var l=+s.getAttribute(\"x\")||0,h=+s.getAttribute(\"y\")||0,f=s.getAttribute(\"transform\");if(!f){var p=v.bBox(s,!1,r);return l&&(p.left+=l,p.right+=l),h&&(p.top+=h,p.bottom+=h),p}if(r+=\"~\"+l+\"~\"+h+\"~\"+f,i=v.savedBBoxes[r])return c.extendFlat({},i)}}e?a=t:(o=v.tester.node(),a=t.cloneNode(!0),o.appendChild(a)),n.select(a).attr(\"transform\",null).call(u.positionText,0,0);var d=a.getBoundingClientRect(),g=v.testref.node().getBoundingClientRect();e||o.removeChild(a);var m={height:d.height,width:d.width,left:d.left-g.left,top:d.top-g.top,right:d.right-g.left,bottom:d.bottom-g.top};return O>=1e4&&(v.savedBBoxes={},O=0),r&&(v.savedBBoxes[r]=m),O++,c.extendFlat({},m)},v.setClipUrl=function(t,e,r){t.attr(\"clip-path\",I(e,r))},v.getTranslate=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\btranslate\\((-?\\d*\\.?\\d*)[^-\\d]*(-?\\d*\\.?\\d*)[^\\d].*/,function(t,e,r){return[e,r].join(\" \")}).split(\" \");return{x:+e[0]||0,y:+e[1]||0}},v.setTranslate=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||0,r=r||0,a=a.replace(/(\\btranslate\\(.*?\\);?)/,\"\").trim(),a=(a+=\" translate(\"+e+\", \"+r+\")\").trim(),t[i](\"transform\",a),a},v.getScale=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\bscale\\((\\d*\\.?\\d*)[^\\d]*(\\d*\\.?\\d*)[^\\d].*/,function(t,e,r){return[e,r].join(\" \")}).split(\" \");return{x:+e[0]||1,y:+e[1]||1}},v.setScale=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||1,r=r||1,a=a.replace(/(\\bscale\\(.*?\\);?)/,\"\").trim(),a=(a+=\" scale(\"+e+\", \"+r+\")\").trim(),t[i](\"transform\",a),a};var D=/\\s*sc.*/;v.setPointGroupScale=function(t,e,r){if(e=e||1,r=r||1,t){var n=1===e&&1===r?\"\":\" scale(\"+e+\",\"+r+\")\";t.each(function(){var t=(this.getAttribute(\"transform\")||\"\").replace(D,\"\");t=(t+=n).trim(),this.setAttribute(\"transform\",t)})}};var R=/translate\\([^)]*\\)\\s*$/;v.setTextPointsScale=function(t,e,r){t&&t.each(function(){var t,i=n.select(this),a=i.select(\"text\");if(a.node()){var o=parseFloat(a.attr(\"x\")||0),s=parseFloat(a.attr(\"y\")||0),l=(i.attr(\"transform\")||\"\").match(R);t=1===e&&1===r?[]:[\"translate(\"+o+\",\"+s+\")\",\"scale(\"+e+\",\"+r+\")\",\"translate(\"+-o+\",\"+-s+\")\"],l&&t.push(l),i.attr(\"transform\",t.join(\" \"))}})}},{\"../../constants/alignment\":688,\"../../constants/interactions\":694,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../registry\":847,\"../../traces/scatter/make_bubble_size_func\":1128,\"../../traces/scatter/subtypes\":1135,\"../color\":593,\"../colorscale\":605,\"./symbol_defs\":615,d3:163,\"fast-isnumeric\":225,tinycolor2:537}],615:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports={circle:{n:0,f:function(t){var e=n.round(t,2);return\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"}},square:{n:1,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"}},diamond:{n:2,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"Z\"}},cross:{n:3,f:function(t){var e=n.round(.4*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H\"+e+\"V\"+r+\"H-\"+e+\"V\"+e+\"H-\"+r+\"V-\"+e+\"H-\"+e+\"V-\"+r+\"H\"+e+\"V-\"+e+\"H\"+r+\"Z\"}},x:{n:4,f:function(t){var e=n.round(.8*t/Math.sqrt(2),2),r=\"l\"+e+\",\"+e,i=\"l\"+e+\",-\"+e,a=\"l-\"+e+\",-\"+e,o=\"l-\"+e+\",\"+e;return\"M0,\"+e+r+i+a+i+a+o+a+o+r+o+r+\"Z\"}},\"triangle-up\":{n:5,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",\"+n.round(t/2,2)+\"H\"+e+\"L0,-\"+n.round(t,2)+\"Z\"}},\"triangle-down\":{n:6,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",-\"+n.round(t/2,2)+\"H\"+e+\"L0,\"+n.round(t,2)+\"Z\"}},\"triangle-left\":{n:7,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L-\"+n.round(t,2)+\",0Z\"}},\"triangle-right\":{n:8,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L\"+n.round(t,2)+\",0Z\"}},\"triangle-ne\":{n:9,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+r+\",-\"+e+\"H\"+e+\"V\"+r+\"Z\"}},\"triangle-se\":{n:10,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+e+\",-\"+r+\"V\"+e+\"H-\"+r+\"Z\"}},\"triangle-sw\":{n:11,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H-\"+e+\"V-\"+r+\"Z\"}},\"triangle-nw\":{n:12,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+e+\",\"+r+\"V-\"+e+\"H\"+r+\"Z\"}},pentagon:{n:13,f:function(t){var e=n.round(.951*t,2),r=n.round(.588*t,2),i=n.round(-t,2),a=n.round(-.309*t,2);return\"M\"+e+\",\"+a+\"L\"+r+\",\"+n.round(.809*t,2)+\"H-\"+r+\"L-\"+e+\",\"+a+\"L0,\"+i+\"Z\"}},hexagon:{n:14,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M\"+i+\",-\"+r+\"V\"+r+\"L0,\"+e+\"L-\"+i+\",\"+r+\"V-\"+r+\"L0,-\"+e+\"Z\"}},hexagon2:{n:15,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M-\"+r+\",\"+i+\"H\"+r+\"L\"+e+\",0L\"+r+\",-\"+i+\"H-\"+r+\"L-\"+e+\",0Z\"}},octagon:{n:16,f:function(t){var e=n.round(.924*t,2),r=n.round(.383*t,2);return\"M-\"+r+\",-\"+e+\"H\"+r+\"L\"+e+\",-\"+r+\"V\"+r+\"L\"+r+\",\"+e+\"H-\"+r+\"L-\"+e+\",\"+r+\"V-\"+r+\"Z\"}},star:{n:17,f:function(t){var e=1.4*t,r=n.round(.225*e,2),i=n.round(.951*e,2),a=n.round(.363*e,2),o=n.round(.588*e,2),s=n.round(-e,2),l=n.round(-.309*e,2),c=n.round(.118*e,2),u=n.round(.809*e,2);return\"M\"+r+\",\"+l+\"H\"+i+\"L\"+a+\",\"+c+\"L\"+o+\",\"+u+\"L0,\"+n.round(.382*e,2)+\"L-\"+o+\",\"+u+\"L-\"+a+\",\"+c+\"L-\"+i+\",\"+l+\"H-\"+r+\"L0,\"+s+\"Z\"}},hexagram:{n:18,f:function(t){var e=n.round(.66*t,2),r=n.round(.38*t,2),i=n.round(.76*t,2);return\"M-\"+i+\",0l-\"+r+\",-\"+e+\"h\"+i+\"l\"+r+\",-\"+e+\"l\"+r+\",\"+e+\"h\"+i+\"l-\"+r+\",\"+e+\"l\"+r+\",\"+e+\"h-\"+i+\"l-\"+r+\",\"+e+\"l-\"+r+\",-\"+e+\"h-\"+i+\"Z\"}},\"star-triangle-up\":{n:19,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M-\"+e+\",\"+r+o+e+\",\"+r+o+\"0,-\"+i+o+\"-\"+e+\",\"+r+\"Z\"}},\"star-triangle-down\":{n:20,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M\"+e+\",-\"+r+o+\"-\"+e+\",-\"+r+o+\"0,\"+i+o+e+\",-\"+r+\"Z\"}},\"star-square\":{n:21,f:function(t){var e=n.round(1.1*t,2),r=n.round(2*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",-\"+e+i+\"-\"+e+\",\"+e+i+e+\",\"+e+i+e+\",-\"+e+i+\"-\"+e+\",-\"+e+\"Z\"}},\"star-diamond\":{n:22,f:function(t){var e=n.round(1.4*t,2),r=n.round(1.9*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",0\"+i+\"0,\"+e+i+e+\",0\"+i+\"0,-\"+e+i+\"-\"+e+\",0Z\"}},\"diamond-tall\":{n:23,f:function(t){var e=n.round(.7*t,2),r=n.round(1.4*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},\"diamond-wide\":{n:24,f:function(t){var e=n.round(1.4*t,2),r=n.round(.7*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},hourglass:{n:25,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"L\"+e+\",-\"+e+\"H-\"+e+\"Z\"},noDot:!0},bowtie:{n:26,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"V-\"+e+\"L-\"+e+\",\"+e+\"V-\"+e+\"Z\"},noDot:!0},\"circle-cross\":{n:27,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"circle-x\":{n:28,f:function(t){var e=n.round(t,2),r=n.round(t/Math.sqrt(2),2);return\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"square-cross\":{n:29,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"square-x\":{n:30,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"diamond-cross\":{n:31,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM0,-\"+e+\"V\"+e+\"M-\"+e+\",0H\"+e},needLine:!0,noDot:!0},\"diamond-x\":{n:32,f:function(t){var e=n.round(1.3*t,2),r=n.round(.65*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM-\"+r+\",-\"+r+\"L\"+r+\",\"+r+\"M-\"+r+\",\"+r+\"L\"+r+\",-\"+r},needLine:!0,noDot:!0},\"cross-thin\":{n:33,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"x-thin\":{n:34,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},asterisk:{n:35,f:function(t){var e=n.round(1.2*t,2),r=n.round(.85*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r},needLine:!0,noDot:!0,noFill:!0},hash:{n:36,f:function(t){var e=n.round(t/2,2),r=n.round(t,2);return\"M\"+e+\",\"+r+\"V-\"+r+\"m-\"+r+\",0V\"+r+\"M\"+r+\",\"+e+\"H-\"+r+\"m0,-\"+r+\"H\"+r},needLine:!0,noFill:!0},\"y-up\":{n:37,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",\"+i+\"L0,0M\"+e+\",\"+i+\"L0,0M0,-\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-down\":{n:38,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",-\"+i+\"L0,0M\"+e+\",-\"+i+\"L0,0M0,\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-left\":{n:39,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M\"+i+\",\"+e+\"L0,0M\"+i+\",-\"+e+\"L0,0M-\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-right\":{n:40,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+i+\",\"+e+\"L0,0M-\"+i+\",-\"+e+\"L0,0M\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"line-ew\":{n:41,f:function(t){var e=n.round(1.4*t,2);return\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ns\":{n:42,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ne\":{n:43,f:function(t){var e=n.round(t,2);return\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-nw\":{n:44,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e},needLine:!0,noDot:!0,noFill:!0}}},{d3:163}],616:[function(t,e,r){\"use strict\";e.exports={visible:{valType:\"boolean\",editType:\"calc\"},type:{valType:\"enumerated\",values:[\"percent\",\"constant\",\"sqrt\",\"data\"],editType:\"calc\"},symmetric:{valType:\"boolean\",editType:\"calc\"},array:{valType:\"data_array\",editType:\"calc\"},arrayminus:{valType:\"data_array\",editType:\"calc\"},value:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},valueminus:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},traceref:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},tracerefminus:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},copy_ystyle:{valType:\"boolean\",editType:\"plot\"},copy_zstyle:{valType:\"boolean\",editType:\"style\"},color:{valType:\"color\",editType:\"style\"},thickness:{valType:\"number\",min:0,dflt:2,editType:\"style\"},width:{valType:\"number\",min:0,editType:\"plot\"},editType:\"calc\",_deprecated:{opacity:{valType:\"number\",editType:\"style\"}}}},{}],617:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=t(\"./compute_error\");function l(t,e,r,i){var l=e[\"error_\"+i]||{},c=[];if(l.visible&&-1!==[\"linear\",\"log\"].indexOf(r.type)){for(var u=s(l),h=0;h<t.length;h++){var f=t[h],p=f.i;if(void 0===p)p=h;else if(null===p)continue;var d=f[i];if(n(r.c2l(d))){var g=u(d,p);if(n(g[0])&&n(g[1])){var v=f[i+\"s\"]=d-g[0],m=f[i+\"h\"]=d+g[1];c.push(v,m)}}}var y=r._id,x=e._extremes[y],b=a.findExtremes(r,c,o.extendFlat({tozero:x.opts.tozero},{padded:!0}));x.min=x.min.concat(b.min),x.max=x.max.concat(b.max)}}e.exports=function(t){for(var e=t.calcdata,r=0;r<e.length;r++){var n=e[r],o=n[0].trace;if(!0===o.visible&&i.traceIs(o,\"errorBarsOK\")){var s=a.getFromId(t,o.xaxis),c=a.getFromId(t,o.yaxis);l(n,o,s,\"x\"),l(n,o,c,\"y\")}}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./compute_error\":618,\"fast-isnumeric\":225}],618:[function(t,e,r){\"use strict\";function n(t,e){return\"percent\"===t?function(t){return Math.abs(t*e/100)}:\"constant\"===t?function(){return Math.abs(e)}:\"sqrt\"===t?function(t){return Math.sqrt(Math.abs(t))}:void 0}e.exports=function(t){var e=t.type,r=t.symmetric;if(\"data\"===e){var i=t.array||[];if(r)return function(t,e){var r=+i[e];return[r,r]};var a=t.arrayminus||[];return function(t,e){var r=+i[e],n=+a[e];return isNaN(r)&&isNaN(n)?[NaN,NaN]:[n||0,r||0]}}var o=n(e,t.value),s=n(e,t.valueminus);return r||void 0===t.valueminus?function(t){var e=o(t);return[e,e]}:function(t){return[s(t),o(t)]}}},{}],619:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../plot_api/plot_template\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){var c=\"error_\"+l.axis,u=o.newContainer(e,c),h=t[c]||{};function f(t,e){return a.coerce(h,u,s,t,e)}if(!1!==f(\"visible\",void 0!==h.array||void 0!==h.value||\"sqrt\"===h.type)){var p=f(\"type\",\"array\"in h?\"data\":\"percent\"),d=!0;\"sqrt\"!==p&&(d=f(\"symmetric\",!((\"data\"===p?\"arrayminus\":\"valueminus\")in h))),\"data\"===p?(f(\"array\"),f(\"traceref\"),d||(f(\"arrayminus\"),f(\"tracerefminus\"))):\"percent\"!==p&&\"constant\"!==p||(f(\"value\"),d||f(\"valueminus\"));var g=\"copy_\"+l.inherit+\"style\";if(l.inherit)(e[\"error_\"+l.inherit]||{}).visible&&f(g,!(h.color||n(h.thickness)||n(h.width)));l.inherit&&u[g]||(f(\"color\",r),f(\"thickness\"),f(\"width\",i.traceIs(e,\"gl3d\")?0:4))}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../registry\":847,\"./attributes\":616,\"fast-isnumeric\":225}],620:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"./attributes\"),o={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a)};delete o.error_x.copy_zstyle,delete o.error_y.copy_zstyle,delete o.error_y.copy_ystyle;var s={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a),error_z:n.extendFlat({},a)};delete s.error_x.copy_ystyle,delete s.error_y.copy_ystyle,delete s.error_z.copy_ystyle,delete s.error_z.copy_zstyle,e.exports={moduleType:\"component\",name:\"errorbars\",schema:{traces:{scatter:o,bar:o,histogram:o,scatter3d:i(s,\"calc\",\"nested\"),scattergl:i(o,\"calc\",\"nested\")}},supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),makeComputeError:t(\"./compute_error\"),plot:t(\"./plot\"),style:t(\"./style\"),hoverInfo:function(t,e,r){(e.error_y||{}).visible&&(r.yerr=t.yh-t.y,e.error_y.symmetric||(r.yerrneg=t.y-t.ys));(e.error_x||{}).visible&&(r.xerr=t.xh-t.x,e.error_x.symmetric||(r.xerrneg=t.x-t.xs))}}},{\"../../lib\":719,\"../../plot_api/edit_types\":750,\"./attributes\":616,\"./calc\":617,\"./compute_error\":618,\"./defaults\":619,\"./plot\":621,\"./style\":622}],621:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../drawing\"),o=t(\"../../traces/scatter/subtypes\");e.exports=function(t,e,r,s){var l=r.xaxis,c=r.yaxis,u=s&&s.duration>0;e.each(function(e){var h,f=e[0].trace,p=f.error_x||{},d=f.error_y||{};f.ids&&(h=function(t){return t.id});var g=o.hasMarkers(f)&&f.marker.maxdisplayed>0;d.visible||p.visible||(e=[]);var v=n.select(this).selectAll(\"g.errorbar\").data(e,h);if(v.exit().remove(),e.length){p.visible||v.selectAll(\"path.xerror\").remove(),d.visible||v.selectAll(\"path.yerror\").remove(),v.style(\"opacity\",1);var m=v.enter().append(\"g\").classed(\"errorbar\",!0);u&&m.style(\"opacity\",0).transition().duration(s.duration).style(\"opacity\",1),a.setClipUrl(v,r.layerClipId,t),v.each(function(t){var e=n.select(this),r=function(t,e,r){var n={x:e.c2p(t.x),y:r.c2p(t.y)};void 0!==t.yh&&(n.yh=r.c2p(t.yh),n.ys=r.c2p(t.ys),i(n.ys)||(n.noYS=!0,n.ys=r.c2p(t.ys,!0)));void 0!==t.xh&&(n.xh=e.c2p(t.xh),n.xs=e.c2p(t.xs),i(n.xs)||(n.noXS=!0,n.xs=e.c2p(t.xs,!0)));return n}(t,l,c);if(!g||t.vis){var a,o=e.select(\"path.yerror\");if(d.visible&&i(r.x)&&i(r.yh)&&i(r.ys)){var h=d.width;a=\"M\"+(r.x-h)+\",\"+r.yh+\"h\"+2*h+\"m-\"+h+\",0V\"+r.ys,r.noYS||(a+=\"m-\"+h+\",0h\"+2*h),!o.size()?o=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"yerror\",!0):u&&(o=o.transition().duration(s.duration).ease(s.easing)),o.attr(\"d\",a)}else o.remove();var f=e.select(\"path.xerror\");if(p.visible&&i(r.y)&&i(r.xh)&&i(r.xs)){var v=(p.copy_ystyle?d:p).width;a=\"M\"+r.xh+\",\"+(r.y-v)+\"v\"+2*v+\"m0,-\"+v+\"H\"+r.xs,r.noXS||(a+=\"m0,-\"+v+\"v\"+2*v),!f.size()?f=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"xerror\",!0):u&&(f=f.transition().duration(s.duration).ease(s.easing)),f.attr(\"d\",a)}else f.remove()}})}})}},{\"../../traces/scatter/subtypes\":1135,\"../drawing\":614,d3:163,\"fast-isnumeric\":225}],622:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\");e.exports=function(t){t.each(function(t){var e=t[0].trace,r=e.error_y||{},a=e.error_x||{},o=n.select(this);o.selectAll(\"path.yerror\").style(\"stroke-width\",r.thickness+\"px\").call(i.stroke,r.color),a.copy_ystyle&&(a=r),o.selectAll(\"path.xerror\").style(\"stroke-width\",a.thickness+\"px\").call(i.stroke,a.color)})}},{\"../color\":593,d3:163}],623:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./layout_attributes\").hoverlabel,a=t(\"../../lib/extend\").extendFlat;e.exports={hoverlabel:{bgcolor:a({},i.bgcolor,{arrayOk:!0}),bordercolor:a({},i.bordercolor,{arrayOk:!0}),font:n({arrayOk:!0,editType:\"none\"}),align:a({},i.align,{arrayOk:!0}),namelength:a({},i.namelength,{arrayOk:!0}),editType:\"none\"}}},{\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"./layout_attributes\":633}],624:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");function a(t,e,r,i){i=i||n.identity,Array.isArray(t)&&(e[0][r]=i(t))}e.exports=function(t){var e=t.calcdata,r=t._fullLayout;function o(t){return function(e){return n.coerceHoverinfo({hoverinfo:e},{_module:t._module},r)}}for(var s=0;s<e.length;s++){var l=e[s],c=l[0].trace;if(!i.traceIs(c,\"pie-like\")){var u=i.traceIs(c,\"2dMap\")?a:n.fillArray;u(c.hoverinfo,l,\"hi\",o(c)),c.hovertemplate&&u(c.hovertemplate,l,\"ht\"),c.hoverlabel&&(u(c.hoverlabel.bgcolor,l,\"hbg\"),u(c.hoverlabel.bordercolor,l,\"hbc\"),u(c.hoverlabel.font.size,l,\"hts\"),u(c.hoverlabel.font.color,l,\"htc\"),u(c.hoverlabel.font.family,l,\"htf\"),u(c.hoverlabel.namelength,l,\"hnl\"),u(c.hoverlabel.align,l,\"hta\"))}}}},{\"../../lib\":719,\"../../registry\":847}],625:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./hover\").hover;e.exports=function(t,e,r){var a=n.getComponentMethod(\"annotations\",\"onClick\")(t,t._hoverdata);function o(){t.emit(\"plotly_click\",{points:t._hoverdata,event:e})}void 0!==r&&i(t,e,r,!0),t._hoverdata&&e&&e.target&&(a&&a.then?a.then(o):o(),e.stopImmediatePropagation&&e.stopImmediatePropagation())}},{\"../../registry\":847,\"./hover\":629}],626:[function(t,e,r){\"use strict\";e.exports={YANGLE:60,HOVERARROWSIZE:6,HOVERTEXTPAD:3,HOVERFONTSIZE:13,HOVERFONT:\"Arial, sans-serif\",HOVERMINTIME:50,HOVERID:\"-hover\"}},{}],627:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./hoverlabel_defaults\");e.exports=function(t,e,r,o){var s=n.extendFlat({},o.hoverlabel);e.hovertemplate&&(s.namelength=-1),a(t,e,function(r,a){return n.coerce(t,e,i,r,a)},s)}},{\"../../lib\":719,\"./attributes\":623,\"./hoverlabel_defaults\":630}],628:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");r.getSubplot=function(t){return t.subplot||t.xaxis+t.yaxis||t.geo},r.isTraceInSubplots=function(t,e){if(\"splom\"===t.type){for(var n=t.xaxes||[],i=t.yaxes||[],a=0;a<n.length;a++)for(var o=0;o<i.length;o++)if(-1!==e.indexOf(n[a]+i[o]))return!0;return!1}return-1!==e.indexOf(r.getSubplot(t))},r.flat=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=e;return r},r.p2c=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=t[n].p2c(e);return r},r.getDistanceFunction=function(t,e,n,i){return\"closest\"===t?i||r.quadrature(e,n):\"x\"===t?e:n},r.getClosest=function(t,e,r){if(!1!==r.index)r.index>=0&&r.index<t.length?r.distance=0:r.index=!1;else for(var n=0;n<t.length;n++){var i=e(t[n]);i<=r.distance&&(r.index=n,r.distance=i)}return r},r.inbox=function(t,e,r){return t*e<0||0===t?r:1/0},r.quadrature=function(t,e){return function(r){var n=t(r),i=e(r);return Math.sqrt(n*n+i*i)}},r.makeEventData=function(t,e,n){var i=\"index\"in t?t.index:t.pointNumber,a={data:e._input,fullData:e,curveNumber:e.index,pointNumber:i};if(e._indexToPoints){var o=e._indexToPoints[i];1===o.length?a.pointIndex=o[0]:a.pointIndices=o}else a.pointIndex=i;return e._module.eventData?a=e._module.eventData(a,t,e,n,i):(\"xVal\"in t?a.x=t.xVal:\"x\"in t&&(a.x=t.x),\"yVal\"in t?a.y=t.yVal:\"y\"in t&&(a.y=t.y),t.xa&&(a.xaxis=t.xa),t.ya&&(a.yaxis=t.ya),void 0!==t.zLabelVal&&(a.z=t.zLabelVal)),r.appendArrayPointValue(a,e,i),a},r.appendArrayPointValue=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){var u=o(n.nestedProperty(e,l).get(),r);void 0!==u&&(t[c]=u)}}},r.appendArrayMultiPointValues=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){for(var u=n.nestedProperty(e,l).get(),h=new Array(r.length),f=0;f<r.length;f++)h[f]=o(u,r[f]);t[c]=h}}};var i={ids:\"id\",locations:\"location\",labels:\"label\",values:\"value\",\"marker.colors\":\"color\",parents:\"parent\"};function a(t){return i[t]||t}function o(t,e){return Array.isArray(e)?Array.isArray(t)&&Array.isArray(t[e[0]])?t[e[0]][e[1]]:void 0:t[e]}},{\"../../lib\":719}],629:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../lib\"),s=t(\"../../lib/events\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib/override_cursor\"),u=t(\"../drawing\"),h=t(\"../color\"),f=t(\"../dragelement\"),p=t(\"../../plots/cartesian/axes\"),d=t(\"../../registry\"),g=t(\"./helpers\"),v=t(\"./constants\"),m=v.YANGLE,y=Math.PI*m/180,x=1/Math.sin(y),b=Math.cos(y),_=Math.sin(y),w=v.HOVERARROWSIZE,k=v.HOVERTEXTPAD;r.hover=function(t,e,r,a){t=o.getGraphDiv(t),o.throttle(t._fullLayout._uid+v.HOVERID,v.HOVERMINTIME,function(){!function(t,e,r,a){r||(r=\"xy\");var l=Array.isArray(r)?r:[r],u=t._fullLayout,v=u._plots||[],m=v[r],y=u._has(\"cartesian\");if(m){var b=m.overlays.map(function(t){return t.id});l=l.concat(b)}for(var _=l.length,w=new Array(_),k=new Array(_),T=!1,L=0;L<_;L++){var P=l[L],O=v[P];if(O)T=!0,w[L]=p.getFromId(t,O.xaxis._id),k[L]=p.getFromId(t,O.yaxis._id);else{var z=u[P]._subplot;w[L]=z.xaxis,k[L]=z.yaxis}}var I=e.hovermode||u.hovermode;I&&!T&&(I=\"closest\");if(-1===[\"x\",\"y\",\"closest\"].indexOf(I)||!t.calcdata||t.querySelector(\".zoombox\")||t._dragging)return f.unhoverRaw(t,e);var D,R,F,B,N,j,U,V,q,H,G,Y,W,X=-1===u.hoverdistance?1/0:u.hoverdistance,Z=-1===u.spikedistance?1/0:u.spikedistance,J=[],K=[],$={hLinePoint:null,vLinePoint:null},Q=!1;if(Array.isArray(e))for(I=\"array\",F=0;F<e.length;F++)(N=t.calcdata[e[F].curveNumber||0])&&(j=N[0].trace,\"skip\"!==N[0].trace.hoverinfo&&(K.push(N),\"h\"===j.orientation&&(Q=!0)));else{for(B=0;B<t.calcdata.length;B++)N=t.calcdata[B],\"skip\"!==(j=N[0].trace).hoverinfo&&g.isTraceInSubplots(j,l)&&(K.push(N),\"h\"===j.orientation&&(Q=!0));var tt,et,rt=!e.target;if(rt)tt=\"xpx\"in e?e.xpx:w[0]._length/2,et=\"ypx\"in e?e.ypx:k[0]._length/2;else{if(!1===s.triggerHandler(t,\"plotly_beforehover\",e))return;var nt=e.target.getBoundingClientRect();if(tt=e.clientX-nt.left,et=e.clientY-nt.top,tt<0||tt>w[0]._length||et<0||et>k[0]._length)return f.unhoverRaw(t,e)}if(e.pointerX=tt+w[0]._offset,e.pointerY=et+k[0]._offset,D=\"xval\"in e?g.flat(l,e.xval):g.p2c(w,tt),R=\"yval\"in e?g.flat(l,e.yval):g.p2c(k,et),!i(D[0])||!i(R[0]))return o.warn(\"Fx.hover failed\",e,t),f.unhoverRaw(t,e)}var it=1/0;for(B=0;B<K.length;B++)if((N=K[B])&&N[0]&&N[0].trace&&!0===(j=N[0].trace).visible&&0!==j._length&&-1===[\"carpet\",\"contourcarpet\"].indexOf(j._module.name)){if(\"splom\"===j.type?U=l[V=0]:(U=g.getSubplot(j),V=l.indexOf(U)),q=I,Y={cd:N,trace:j,xa:w[V],ya:k[V],maxHoverDistance:X,maxSpikeDistance:Z,index:!1,distance:Math.min(it,X),spikeDistance:1/0,xSpike:void 0,ySpike:void 0,color:h.defaultLine,name:j.name,x0:void 0,x1:void 0,y0:void 0,y1:void 0,xLabelVal:void 0,yLabelVal:void 0,zLabelVal:void 0,text:void 0},u[U]&&(Y.subplot=u[U]._subplot),u._splomScenes&&u._splomScenes[j.uid]&&(Y.scene=u._splomScenes[j.uid]),W=J.length,\"array\"===q){var at=e[B];\"pointNumber\"in at?(Y.index=at.pointNumber,q=\"closest\"):(q=\"\",\"xval\"in at&&(H=at.xval,q=\"x\"),\"yval\"in at&&(G=at.yval,q=q?\"closest\":\"y\"))}else H=D[V],G=R[V];if(0!==X)if(j._module&&j._module.hoverPoints){var ot=j._module.hoverPoints(Y,H,G,q,u._hoverlayer);if(ot)for(var st,lt=0;lt<ot.length;lt++)st=ot[lt],i(st.x0)&&i(st.y0)&&J.push(S(st,I))}else o.log(\"Unrecognized trace type in hover:\",j);if(\"closest\"===I&&J.length>W&&(J.splice(0,W),it=J[0].distance),y&&0!==Z&&0===J.length){Y.distance=Z,Y.index=!1;var ct=j._module.hoverPoints(Y,H,G,\"closest\",u._hoverlayer);if(ct&&(ct=ct.filter(function(t){return t.spikeDistance<=Z})),ct&&ct.length){var ut,ht=ct.filter(function(t){return t.xa.showspikes});if(ht.length){var ft=ht[0];i(ft.x0)&&i(ft.y0)&&(ut=vt(ft),(!$.vLinePoint||$.vLinePoint.spikeDistance>ut.spikeDistance)&&($.vLinePoint=ut))}var pt=ct.filter(function(t){return t.ya.showspikes});if(pt.length){var dt=pt[0];i(dt.x0)&&i(dt.y0)&&(ut=vt(dt),(!$.hLinePoint||$.hLinePoint.spikeDistance>ut.spikeDistance)&&($.hLinePoint=ut))}}}}function gt(t,e){for(var r,n=null,i=1/0,a=0;a<t.length;a++)(r=t[a].spikeDistance)<i&&r<=e&&(n=t[a],i=r);return n}function vt(t){return t?{xa:t.xa,ya:t.ya,x:void 0!==t.xSpike?t.xSpike:(t.x0+t.x1)/2,y:void 0!==t.ySpike?t.ySpike:(t.y0+t.y1)/2,distance:t.distance,spikeDistance:t.spikeDistance,curveNumber:t.trace.index,color:t.color,pointNumber:t.index}:null}var mt={fullLayout:u,container:u._hoverlayer,outerContainer:u._paperdiv,event:e},yt=t._spikepoints,xt={vLinePoint:$.vLinePoint,hLinePoint:$.hLinePoint};if(t._spikepoints=xt,y&&0!==Z&&0!==J.length){var bt=J.filter(function(t){return t.ya.showspikes}),_t=gt(bt,Z);$.hLinePoint=vt(_t);var wt=J.filter(function(t){return t.xa.showspikes}),kt=gt(wt,Z);$.vLinePoint=vt(kt)}if(0===J.length){var Tt=f.unhoverRaw(t,e);return!y||null===$.hLinePoint&&null===$.vLinePoint||C(yt)&&E($,mt),Tt}y&&C(yt)&&E($,mt);J.sort(function(t,e){return t.distance-e.distance});var At=t._hoverdata,Mt=[];for(F=0;F<J.length;F++){var St=J[F],Et=g.makeEventData(St,St.trace,St.cd);if(!1!==St.hovertemplate){var Ct=!1;St.cd[St.index]&&St.cd[St.index].ht&&(Ct=St.cd[St.index].ht),St.hovertemplate=Ct||St.trace.hovertemplate||!1}St.eventData=[Et],Mt.push(Et)}t._hoverdata=Mt;var Lt=\"y\"===I&&(K.length>1||J.length>1)||\"closest\"===I&&Q&&J.length>1,Pt=h.combine(u.plot_bgcolor||h.background,u.paper_bgcolor),Ot={hovermode:I,rotateLabels:Lt,bgColor:Pt,container:u._hoverlayer,outerContainer:u._paperdiv,commonLabelOpts:u.hoverlabel,hoverdistance:u.hoverdistance},zt=A(J,Ot,t);if(function(t,e,r){var n,i,a,o,s,l,c,u=0,h=1,f=t.size(),p=new Array(f),d=0;function g(t){var e=t[0],r=t[t.length-1];if(i=e.pmin-e.pos-e.dp+e.size,a=r.pos+r.dp+r.size-e.pmax,i>.01){for(s=t.length-1;s>=0;s--)t[s].dp+=i;n=!1}if(!(a<.01)){if(i<-.01){for(s=t.length-1;s>=0;s--)t[s].dp-=a;n=!1}if(n){var c=0;for(o=0;o<t.length;o++)(l=t[o]).pos+l.dp+l.size>e.pmax&&c++;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos>e.pmax-1&&(l.del=!0,c--);for(o=0;o<t.length&&!(c<=0);o++)if((l=t[o]).pos<e.pmin+1)for(l.del=!0,c--,a=2*l.size,s=t.length-1;s>=0;s--)t[s].dp-=a;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos+l.dp+l.size>e.pmax&&(l.del=!0,c--)}}}for(t.each(function(t){var n=t[e],i=\"x\"===n._id.charAt(0),a=n.range;0===d&&a&&a[0]>a[1]!==i&&(h=-1),p[d++]=[{datum:t,traceIndex:t.trace.index,dp:0,pos:t.pos,posref:t.posref,size:t.by*(i?x:1)/2,pmin:0,pmax:i?r.width:r.height}]}),p.sort(function(t,e){return t[0].posref-e[0].posref||h*(e[0].traceIndex-t[0].traceIndex)});!n&&u<=f;){for(u++,n=!0,o=0;o<p.length-1;){var v=p[o],m=p[o+1],y=v[v.length-1],b=m[0];if((i=y.pos+y.dp+y.size-b.pos-b.dp+b.size)>.01&&y.pmin===b.pmin&&y.pmax===b.pmax){for(s=m.length-1;s>=0;s--)m[s].dp+=i;for(v.push.apply(v,m),p.splice(o+1,1),c=0,s=v.length-1;s>=0;s--)c+=v[s].dp;for(a=c/v.length,s=v.length-1;s>=0;s--)v[s].dp-=a;n=!1}else o++}p.forEach(g)}for(o=p.length-1;o>=0;o--){var _=p[o];for(s=_.length-1;s>=0;s--){var w=_[s],k=w.datum;k.offset=w.dp,k.del=w.del}}}(zt,Lt?\"xa\":\"ya\",u),M(zt,Lt),e.target&&e.target.tagName){var It=d.getComponentMethod(\"annotations\",\"hasClickToShow\")(t,Mt);c(n.select(e.target),It?\"pointer\":\"\")}if(!e.target||a||!function(t,e,r){if(!r||r.length!==t._hoverdata.length)return!0;for(var n=r.length-1;n>=0;n--){var i=r[n],a=t._hoverdata[n];if(i.curveNumber!==a.curveNumber||String(i.pointNumber)!==String(a.pointNumber)||String(i.pointNumbers)!==String(a.pointNumbers))return!0}return!1}(t,0,At))return;At&&t.emit(\"plotly_unhover\",{event:e,points:At});t.emit(\"plotly_hover\",{event:e,points:t._hoverdata,xaxes:w,yaxes:k,xvals:D,yvals:R})}(t,e,r,a)})},r.loneHover=function(t,e){var r=!0;Array.isArray(t)||(r=!1,t=[t]);var i=t.map(function(t){return{color:t.color||h.defaultLine,x0:t.x0||t.x||0,x1:t.x1||t.x||0,y0:t.y0||t.y||0,y1:t.y1||t.y||0,xLabel:t.xLabel,yLabel:t.yLabel,zLabel:t.zLabel,text:t.text,name:t.name,idealAlign:t.idealAlign,borderColor:t.borderColor,fontFamily:t.fontFamily,fontSize:t.fontSize,fontColor:t.fontColor,nameLength:t.nameLength,textAlign:t.textAlign,trace:t.trace||{index:0,hoverinfo:\"\"},xa:{_offset:0},ya:{_offset:0},index:0,hovertemplate:t.hovertemplate||!1,eventData:t.eventData||!1,hovertemplateLabels:t.hovertemplateLabels||!1}}),a=n.select(e.container),o=e.outerContainer?n.select(e.outerContainer):a,s={hovermode:\"closest\",rotateLabels:!1,bgColor:e.bgColor||h.background,container:a,outerContainer:o},l=A(i,s,e.gd),c=0,u=0;return l.sort(function(t,e){return t.y0-e.y0}).each(function(t,r){var n=t.y0-t.by/2;t.offset=n-5<c?c-n+5:0,c=n+t.by+t.offset,r===e.anchorIndex&&(u=t.offset)}).each(function(t){t.offset-=u}),M(l,s.rotateLabels),r?l:l.node()};var T=/<extra>([\\s\\S]*)<\\/extra>/;function A(t,e,r){var i=r._fullLayout,a=e.hovermode,s=e.rotateLabels,c=e.bgColor,f=e.container,p=e.outerContainer,d=e.commonLabelOpts||{},g=e.fontFamily||v.HOVERFONT,y=e.fontSize||v.HOVERFONTSIZE,x=t[0],b=x.xa,_=x.ya,A=\"y\"===a?\"yLabel\":\"xLabel\",M=x[A],S=(String(M)||\"\").split(\" \")[0],E=p.node().getBoundingClientRect(),C=E.top,P=E.width,O=E.height,z=void 0!==M&&x.distance<=e.hoverdistance&&(\"x\"===a||\"y\"===a);if(z){var I,D,R=!0;for(I=0;I<t.length;I++)if(R&&void 0===t[I].zLabel&&(R=!1),D=t[I].hoverinfo||t[I].trace.hoverinfo){var F=Array.isArray(D)?D:D.split(\"+\");if(-1===F.indexOf(\"all\")&&-1===F.indexOf(a)){z=!1;break}}R&&(z=!1)}var B=f.selectAll(\"g.axistext\").data(z?[0]:[]);B.enter().append(\"g\").classed(\"axistext\",!0),B.exit().remove(),B.each(function(){var e=n.select(this),i=o.ensureSingle(e,\"path\",\"\",function(t){t.style({\"stroke-width\":\"1px\"})}),s=o.ensureSingle(e,\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),c=d.bgcolor||h.defaultLine,f=d.bordercolor||h.contrast(c),p=h.contrast(c);i.style({fill:c,stroke:f}),s.text(M).call(u.font,d.font.family||g,d.font.size||y,d.font.color||p).call(l.positionText,0,0).call(l.convertToTspans,r),e.attr(\"transform\",\"\");var v=s.node().getBoundingClientRect();if(\"x\"===a){s.attr(\"text-anchor\",\"middle\").call(l.positionText,0,\"top\"===b.side?C-v.bottom-w-k:C-v.top+w+k);var m=\"top\"===b.side?\"-\":\"\";i.attr(\"d\",\"M0,0L\"+w+\",\"+m+w+\"H\"+(k+v.width/2)+\"v\"+m+(2*k+v.height)+\"H-\"+(k+v.width/2)+\"V\"+m+w+\"H-\"+w+\"Z\"),e.attr(\"transform\",\"translate(\"+(b._offset+(x.x0+x.x1)/2)+\",\"+(_._offset+(\"top\"===b.side?0:_._length))+\")\")}else{s.attr(\"text-anchor\",\"right\"===_.side?\"start\":\"end\").call(l.positionText,(\"right\"===_.side?1:-1)*(k+w),C-v.top-v.height/2);var T=\"right\"===_.side?\"\":\"-\";i.attr(\"d\",\"M0,0L\"+T+w+\",\"+w+\"V\"+(k+v.height/2)+\"h\"+T+(2*k+v.width)+\"V-\"+(k+v.height/2)+\"H\"+T+w+\"V-\"+w+\"Z\"),e.attr(\"transform\",\"translate(\"+(b._offset+(\"right\"===_.side?b._length:0))+\",\"+(_._offset+(x.y0+x.y1)/2)+\")\")}t=t.filter(function(t){return void 0!==t.zLabelVal||(t[A]||\"\").split(\" \")[0]===S})});var N=f.selectAll(\"g.hovertext\").data(t,function(t){return[t.trace.index,t.index,t.x0,t.y0,t.name,t.attr,t.xa,t.ya||\"\"].join(\",\")});return N.enter().append(\"g\").classed(\"hovertext\",!0).each(function(){var t=n.select(this);t.append(\"rect\").call(h.fill,h.addOpacity(c,.8)),t.append(\"text\").classed(\"name\",!0),t.append(\"path\").style(\"stroke-width\",\"1px\"),t.append(\"text\").classed(\"nums\",!0).call(u.font,g,y)}),N.exit().remove(),N.each(function(t){var e=n.select(this).attr(\"transform\",\"\"),f=\"\",p=\"\",d=t.bgcolor||t.color,v=h.combine(h.opacity(d)?d:h.defaultLine,c),x=h.combine(h.opacity(t.color)?t.color:h.defaultLine,c),b=t.borderColor||h.contrast(v);void 0!==t.nameOverride&&(t.name=t.nameOverride),t.name&&(t.trace._meta&&(t.name=o.templateString(t.name,t.trace._meta)),f=L(t.name,t.nameLength)),void 0!==t.zLabel?(void 0!==t.xLabel&&(p+=\"x: \"+t.xLabel+\"<br>\"),void 0!==t.yLabel&&(p+=\"y: \"+t.yLabel+\"<br>\"),\"choropleth\"!==t.trace.type&&\"choroplethmapbox\"!==t.trace.type&&(p+=(p?\"z: \":\"\")+t.zLabel)):z&&t[a+\"Label\"]===M?p=t[(\"x\"===a?\"y\":\"x\")+\"Label\"]||\"\":void 0===t.xLabel?void 0!==t.yLabel&&\"scattercarpet\"!==t.trace.type&&(p=t.yLabel):p=void 0===t.yLabel?t.xLabel:\"(\"+t.xLabel+\", \"+t.yLabel+\")\",!t.text&&0!==t.text||Array.isArray(t.text)||(p+=(p?\"<br>\":\"\")+t.text),void 0!==t.extraText&&(p+=(p?\"<br>\":\"\")+t.extraText),\"\"!==p||t.hovertemplate||(\"\"===f&&e.remove(),p=f);var _=i._d3locale,A=t.hovertemplate||!1,S=t.hovertemplateLabels||t,E=t.eventData[0]||{};A&&(p=(p=o.hovertemplateString(A,S,_,E,t.trace._meta)).replace(T,function(e,r){return f=L(r,t.nameLength),\"\"}));var I=e.select(\"text.nums\").call(u.font,t.fontFamily||g,t.fontSize||y,t.fontColor||b).text(p).attr(\"data-notex\",1).call(l.positionText,0,0).call(l.convertToTspans,r),D=e.select(\"text.name\"),R=0,F=0;if(f&&f!==p){D.call(u.font,t.fontFamily||g,t.fontSize||y,x).text(f).attr(\"data-notex\",1).call(l.positionText,0,0).call(l.convertToTspans,r);var B=D.node().getBoundingClientRect();R=B.width+2*k,F=B.height+2*k}else D.remove(),e.select(\"rect\").remove();e.select(\"path\").style({fill:v,stroke:b});var N,j,U=I.node().getBoundingClientRect(),V=t.xa._offset+(t.x0+t.x1)/2,q=t.ya._offset+(t.y0+t.y1)/2,H=Math.abs(t.x1-t.x0),G=Math.abs(t.y1-t.y0),Y=U.width+w+k+R;if(t.ty0=C-U.top,t.bx=U.width+2*k,t.by=Math.max(U.height+2*k,F),t.anchor=\"start\",t.txwidth=U.width,t.tx2width=R,t.offset=0,s)t.pos=V,N=q+G/2+Y<=O,j=q-G/2-Y>=0,\"top\"!==t.idealAlign&&N||!j?N?(q+=G/2,t.anchor=\"start\"):t.anchor=\"middle\":(q-=G/2,t.anchor=\"end\");else if(t.pos=q,N=V+H/2+Y<=P,j=V-H/2-Y>=0,\"left\"!==t.idealAlign&&N||!j)if(N)V+=H/2,t.anchor=\"start\";else{t.anchor=\"middle\";var W=Y/2,X=V+W-P,Z=V-W;X>0&&(V-=X),Z<0&&(V+=-Z)}else V-=H/2,t.anchor=\"end\";I.attr(\"text-anchor\",t.anchor),R&&D.attr(\"text-anchor\",t.anchor),e.attr(\"transform\",\"translate(\"+V+\",\"+q+\")\"+(s?\"rotate(\"+m+\")\":\"\"))}),N}function M(t,e){t.each(function(t){var r=n.select(this);if(t.del)return r.remove();var i=r.select(\"text.nums\"),a=t.anchor,o=\"end\"===a?-1:1,s={start:1,end:-1,middle:0}[a],c=s*(w+k),h=c+s*(t.txwidth+k),f=0,p=t.offset;\"middle\"===a&&(c-=t.tx2width/2,h+=t.txwidth/2+k),e&&(p*=-_,f=t.offset*b),r.select(\"path\").attr(\"d\",\"middle\"===a?\"M-\"+(t.bx/2+t.tx2width/2)+\",\"+(p-t.by/2)+\"h\"+t.bx+\"v\"+t.by+\"h-\"+t.bx+\"Z\":\"M0,0L\"+(o*w+f)+\",\"+(w+p)+\"v\"+(t.by/2-w)+\"h\"+o*t.bx+\"v-\"+t.by+\"H\"+(o*w+f)+\"V\"+(p-w)+\"Z\");var d=c+f,g=p+t.ty0-t.by/2+k,v=t.textAlign||\"auto\";\"auto\"!==v&&(\"left\"===v&&\"start\"!==a?(i.attr(\"text-anchor\",\"start\"),d=\"middle\"===a?-t.bx/2-t.tx2width/2+k:-t.bx-k):\"right\"===v&&\"end\"!==a&&(i.attr(\"text-anchor\",\"end\"),d=\"middle\"===a?t.bx/2-t.tx2width/2-k:t.bx+k)),i.call(l.positionText,d,g),t.tx2width&&(r.select(\"text.name\").call(l.positionText,h+s*k+f,p+t.ty0-t.by/2+k),r.select(\"rect\").call(u.setRect,h+(s-1)*t.tx2width/2+f,p-t.by/2-1,t.tx2width,t.by+2))})}function S(t,e){var r=t.index,n=t.trace||{},a=t.cd[0],s=t.cd[r]||{};function l(t){return t||i(t)&&0===t}var c=Array.isArray(r)?function(t,e){var i=o.castOption(a,r,t);return l(i)?i:o.extractOption({},n,\"\",e)}:function(t,e){return o.extractOption(s,n,t,e)};function u(e,r,n){var i=c(r,n);l(i)&&(t[e]=i)}if(u(\"hoverinfo\",\"hi\",\"hoverinfo\"),u(\"bgcolor\",\"hbg\",\"hoverlabel.bgcolor\"),u(\"borderColor\",\"hbc\",\"hoverlabel.bordercolor\"),u(\"fontFamily\",\"htf\",\"hoverlabel.font.family\"),u(\"fontSize\",\"hts\",\"hoverlabel.font.size\"),u(\"fontColor\",\"htc\",\"hoverlabel.font.color\"),u(\"nameLength\",\"hnl\",\"hoverlabel.namelength\"),u(\"textAlign\",\"hta\",\"hoverlabel.align\"),t.posref=\"y\"===e||\"closest\"===e&&\"h\"===n.orientation?t.xa._offset+(t.x0+t.x1)/2:t.ya._offset+(t.y0+t.y1)/2,t.x0=o.constrain(t.x0,0,t.xa._length),t.x1=o.constrain(t.x1,0,t.xa._length),t.y0=o.constrain(t.y0,0,t.ya._length),t.y1=o.constrain(t.y1,0,t.ya._length),void 0!==t.xLabelVal&&(t.xLabel=\"xLabel\"in t?t.xLabel:p.hoverLabelText(t.xa,t.xLabelVal),t.xVal=t.xa.c2d(t.xLabelVal)),void 0!==t.yLabelVal&&(t.yLabel=\"yLabel\"in t?t.yLabel:p.hoverLabelText(t.ya,t.yLabelVal),t.yVal=t.ya.c2d(t.yLabelVal)),void 0!==t.zLabelVal&&void 0===t.zLabel&&(t.zLabel=String(t.zLabelVal)),!(isNaN(t.xerr)||\"log\"===t.xa.type&&t.xerr<=0)){var h=p.tickText(t.xa,t.xa.c2l(t.xerr),\"hover\").text;void 0!==t.xerrneg?t.xLabel+=\" +\"+h+\" / -\"+p.tickText(t.xa,t.xa.c2l(t.xerrneg),\"hover\").text:t.xLabel+=\" \\xb1 \"+h,\"x\"===e&&(t.distance+=1)}if(!(isNaN(t.yerr)||\"log\"===t.ya.type&&t.yerr<=0)){var f=p.tickText(t.ya,t.ya.c2l(t.yerr),\"hover\").text;void 0!==t.yerrneg?t.yLabel+=\" +\"+f+\" / -\"+p.tickText(t.ya,t.ya.c2l(t.yerrneg),\"hover\").text:t.yLabel+=\" \\xb1 \"+f,\"y\"===e&&(t.distance+=1)}var d=t.hoverinfo||t.trace.hoverinfo;return d&&\"all\"!==d&&(-1===(d=Array.isArray(d)?d:d.split(\"+\")).indexOf(\"x\")&&(t.xLabel=void 0),-1===d.indexOf(\"y\")&&(t.yLabel=void 0),-1===d.indexOf(\"z\")&&(t.zLabel=void 0),-1===d.indexOf(\"text\")&&(t.text=void 0),-1===d.indexOf(\"name\")&&(t.name=void 0)),t}function E(t,e){var r,n,i=e.container,o=e.fullLayout,s=e.event,l=!!t.hLinePoint,c=!!t.vLinePoint;if(i.selectAll(\".spikeline\").remove(),c||l){var f=h.combine(o.plot_bgcolor,o.paper_bgcolor);if(l){var p,d,g=t.hLinePoint;r=g&&g.xa,\"cursor\"===(n=g&&g.ya).spikesnap?(p=s.pointerX,d=s.pointerY):(p=r._offset+g.x,d=n._offset+g.y);var v,m,y=a.readability(g.color,f)<1.5?h.contrast(f):g.color,x=n.spikemode,b=n.spikethickness,_=n.spikecolor||y,w=n._boundingBox,k=(w.left+w.right)/2<p?w.right:w.left;-1===x.indexOf(\"toaxis\")&&-1===x.indexOf(\"across\")||(-1!==x.indexOf(\"toaxis\")&&(v=k,m=p),-1!==x.indexOf(\"across\")&&(v=n._counterSpan[0],m=n._counterSpan[1]),i.insert(\"line\",\":first-child\").attr({x1:v,x2:m,y1:d,y2:d,\"stroke-width\":b,stroke:_,\"stroke-dasharray\":u.dashStyle(n.spikedash,b)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),i.insert(\"line\",\":first-child\").attr({x1:v,x2:m,y1:d,y2:d,\"stroke-width\":b+2,stroke:f}).classed(\"spikeline\",!0).classed(\"crisp\",!0)),-1!==x.indexOf(\"marker\")&&i.insert(\"circle\",\":first-child\").attr({cx:k+(\"right\"!==n.side?b:-b),cy:d,r:b,fill:_}).classed(\"spikeline\",!0)}if(c){var T,A,M=t.vLinePoint;r=M&&M.xa,n=M&&M.ya,\"cursor\"===r.spikesnap?(T=s.pointerX,A=s.pointerY):(T=r._offset+M.x,A=n._offset+M.y);var S,E,C=a.readability(M.color,f)<1.5?h.contrast(f):M.color,L=r.spikemode,P=r.spikethickness,O=r.spikecolor||C,z=r._boundingBox,I=(z.top+z.bottom)/2<A?z.bottom:z.top;-1===L.indexOf(\"toaxis\")&&-1===L.indexOf(\"across\")||(-1!==L.indexOf(\"toaxis\")&&(S=I,E=A),-1!==L.indexOf(\"across\")&&(S=r._counterSpan[0],E=r._counterSpan[1]),i.insert(\"line\",\":first-child\").attr({x1:T,x2:T,y1:S,y2:E,\"stroke-width\":P,stroke:O,\"stroke-dasharray\":u.dashStyle(r.spikedash,P)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),i.insert(\"line\",\":first-child\").attr({x1:T,x2:T,y1:S,y2:E,\"stroke-width\":P+2,stroke:f}).classed(\"spikeline\",!0).classed(\"crisp\",!0)),-1!==L.indexOf(\"marker\")&&i.insert(\"circle\",\":first-child\").attr({cx:T,cy:I-(\"top\"!==r.side?P:-P),r:P,fill:O}).classed(\"spikeline\",!0)}}}function C(t,e){return!e||(e.vLinePoint!==t._spikepoints.vLinePoint||e.hLinePoint!==t._spikepoints.hLinePoint)}function L(t,e){return l.plainText(t||\"\",{len:e,allowedTags:[\"br\",\"sub\",\"sup\",\"b\",\"i\",\"em\"]})}},{\"../../lib\":719,\"../../lib/events\":709,\"../../lib/override_cursor\":730,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"./constants\":626,\"./helpers\":628,d3:163,\"fast-isnumeric\":225,tinycolor2:537}],630:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i){r(\"hoverlabel.bgcolor\",(i=i||{}).bgcolor),r(\"hoverlabel.bordercolor\",i.bordercolor),r(\"hoverlabel.namelength\",i.namelength),n.coerceFont(r,\"hoverlabel.font\",i.font),r(\"hoverlabel.align\",i.align)}},{\"../../lib\":719}],631:[function(t,e,r){\"use strict\";t(\"../../constants/docs\").FORMAT_LINK;e.exports=function(t,e){t=t||{};(e=e||{}).description&&e.description;var r=e.keys||[];if(r.length>0){for(var n=[],i=0;i<r.length;i++)n[i]=\"`\"+r[i]+\"`\";\"Finally, the template string has access to \",1===r.length?\"variable \"+n[0]:\"variables \"+n.slice(0,-1).join(\", \")+\" and \"+n.slice(-1)+\".\"}var a={valType:\"string\",dflt:\"\",editType:t.editType||\"none\"};return!1!==t.arrayOk&&(a.arrayOk=!0),a}},{\"../../constants/docs\":690}],632:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../dragelement\"),o=t(\"./helpers\"),s=t(\"./layout_attributes\"),l=t(\"./hover\");e.exports={moduleType:\"component\",name:\"fx\",constants:t(\"./constants\"),schema:{layout:s},attributes:t(\"./attributes\"),layoutAttributes:s,supplyLayoutGlobalDefaults:t(\"./layout_global_defaults\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),getDistanceFunction:o.getDistanceFunction,getClosest:o.getClosest,inbox:o.inbox,quadrature:o.quadrature,appendArrayPointValue:o.appendArrayPointValue,castHoverOption:function(t,e,r){return i.castOption(t,e,\"hoverlabel.\"+r)},castHoverinfo:function(t,e,r){return i.castOption(t,r,\"hoverinfo\",function(r){return i.coerceHoverinfo({hoverinfo:r},{_module:t._module},e)})},hover:l.hover,unhover:a.unhover,loneHover:l.loneHover,loneUnhover:function(t){var e=i.isD3Selection(t)?t:n.select(t);e.selectAll(\"g.hovertext\").remove(),e.selectAll(\".spikeline\").remove()},click:t(\"./click\")}},{\"../../lib\":719,\"../dragelement\":611,\"./attributes\":623,\"./calc\":624,\"./click\":625,\"./constants\":626,\"./defaults\":627,\"./helpers\":628,\"./hover\":629,\"./layout_attributes\":633,\"./layout_defaults\":634,\"./layout_global_defaults\":635,d3:163}],633:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../plots/font_attributes\")({editType:\"none\"});i.family.dflt=n.HOVERFONT,i.size.dflt=n.HOVERFONTSIZE,e.exports={clickmode:{valType:\"flaglist\",flags:[\"event\",\"select\"],dflt:\"event\",editType:\"plot\",extras:[\"none\"]},dragmode:{valType:\"enumerated\",values:[\"zoom\",\"pan\",\"select\",\"lasso\",\"orbit\",\"turntable\",!1],dflt:\"zoom\",editType:\"modebar\"},hovermode:{valType:\"enumerated\",values:[\"x\",\"y\",\"closest\",!1],editType:\"modebar\"},hoverdistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},spikedistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"none\"},bordercolor:{valType:\"color\",editType:\"none\"},font:i,align:{valType:\"enumerated\",values:[\"left\",\"right\",\"auto\"],dflt:\"auto\",editType:\"none\"},namelength:{valType:\"integer\",min:-1,dflt:15,editType:\"none\"},editType:\"none\"},selectdirection:{valType:\"enumerated\",values:[\"h\",\"v\",\"d\",\"any\"],dflt:\"any\",editType:\"none\"}}},{\"../../plots/font_attributes\":793,\"./constants\":626}],634:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){function a(r,a){return n.coerce(t,e,i,r,a)}var o,s=a(\"clickmode\");\"select\"===a(\"dragmode\")&&a(\"selectdirection\"),e._has(\"cartesian\")?s.indexOf(\"select\")>-1?o=\"closest\":(e._isHoriz=function(t,e){for(var r=e._scatterStackOpts||{},n=0;n<t.length;n++){var i=t[n],a=i.xaxis+i.yaxis,o=r[a]||{},s=o[i.stackgroup]||{};if(\"h\"!==i.orientation&&\"h\"!==s.orientation)return!1}return!0}(r,e),o=e._isHoriz?\"y\":\"x\"):o=\"closest\",a(\"hovermode\",o)&&(a(\"hoverdistance\"),a(\"spikedistance\"));var l=e._has(\"mapbox\"),c=e._has(\"geo\"),u=e._basePlotModules.length;\"zoom\"===e.dragmode&&((l||c)&&1===u||l&&c&&2===u)&&(e.dragmode=\"pan\")}},{\"../../lib\":719,\"./layout_attributes\":633}],635:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./hoverlabel_defaults\"),a=t(\"./layout_attributes\");e.exports=function(t,e){i(t,e,function(r,i){return n.coerce(t,e,a,r,i)})}},{\"../../lib\":719,\"./hoverlabel_defaults\":630,\"./layout_attributes\":633}],636:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/regex\").counter,a=t(\"../../plots/domain\").attributes,o=t(\"../../plots/cartesian/constants\").idRegex,s=t(\"../../plot_api/plot_template\"),l={rows:{valType:\"integer\",min:1,editType:\"plot\"},roworder:{valType:\"enumerated\",values:[\"top to bottom\",\"bottom to top\"],dflt:\"top to bottom\",editType:\"plot\"},columns:{valType:\"integer\",min:1,editType:\"plot\"},subplots:{valType:\"info_array\",freeLength:!0,dimensions:2,items:{valType:\"enumerated\",values:[i(\"xy\").toString(),\"\"],editType:\"plot\"},editType:\"plot\"},xaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.x.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},yaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.y.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},pattern:{valType:\"enumerated\",values:[\"independent\",\"coupled\"],dflt:\"coupled\",editType:\"plot\"},xgap:{valType:\"number\",min:0,max:1,editType:\"plot\"},ygap:{valType:\"number\",min:0,max:1,editType:\"plot\"},domain:a({name:\"grid\",editType:\"plot\",noGridCell:!0},{}),xside:{valType:\"enumerated\",values:[\"bottom\",\"bottom plot\",\"top plot\",\"top\"],dflt:\"bottom plot\",editType:\"plot\"},yside:{valType:\"enumerated\",values:[\"left\",\"left plot\",\"right plot\",\"right\"],dflt:\"left plot\",editType:\"plot\"},editType:\"plot\"};function c(t,e,r){var n=e[r+\"axes\"],i=Object.keys((t._splomAxes||{})[r]||{});return Array.isArray(n)?n:i.length?i:void 0}function u(t,e,r,n,i,a){var o=e(t+\"gap\",r),s=e(\"domain.\"+t);e(t+\"side\",n);for(var l=new Array(i),c=s[0],u=(s[1]-c)/(i-o),h=u*(1-o),f=0;f<i;f++){var p=c+u*f;l[a?i-1-f:f]=[p,p+h]}return l}function h(t,e,r,n,i){var a,o=new Array(r);function s(t,r){-1!==e.indexOf(r)&&void 0===n[r]?(o[t]=r,n[r]=t):o[t]=\"\"}if(Array.isArray(t))for(a=0;a<r;a++)s(a,t[a]);else for(s(0,i),a=1;a<r;a++)s(a,i+(a+1));return o}e.exports={moduleType:\"component\",name:\"grid\",schema:{layout:{grid:l}},layoutAttributes:l,sizeDefaults:function(t,e){var r=t.grid||{},i=c(e,r,\"x\"),a=c(e,r,\"y\");if(t.grid||i||a){var o,h,f=Array.isArray(r.subplots)&&Array.isArray(r.subplots[0]),p=Array.isArray(i),d=Array.isArray(a),g=p&&i!==r.xaxes&&d&&a!==r.yaxes;f?(o=r.subplots.length,h=r.subplots[0].length):(d&&(o=a.length),p&&(h=i.length));var v=s.newContainer(e,\"grid\"),m=T(\"rows\",o),y=T(\"columns\",h);if(m*y>1){f||p||d||\"independent\"===T(\"pattern\")&&(f=!0),v._hasSubplotGrid=f;var x,b,_=\"top to bottom\"===T(\"roworder\"),w=f?.2:.1,k=f?.3:.1;g&&e._splomGridDflt&&(x=e._splomGridDflt.xside,b=e._splomGridDflt.yside),v._domains={x:u(\"x\",T,w,x,y),y:u(\"y\",T,k,b,m,_)}}else delete e.grid}function T(t,e){return n.coerce(r,v,l,t,e)}},contentDefaults:function(t,e){var r=e.grid;if(r&&r._domains){var n,i,a,o,s,l,u,f=t.grid||{},p=e._subplots,d=r._hasSubplotGrid,g=r.rows,v=r.columns,m=\"independent\"===r.pattern,y=r._axisMap={};if(d){var x=f.subplots||[];l=r.subplots=new Array(g);var b=1;for(n=0;n<g;n++){var _=l[n]=new Array(v),w=x[n]||[];for(i=0;i<v;i++)if(m?(s=1===b?\"xy\":\"x\"+b+\"y\"+b,b++):s=w[i],_[i]=\"\",-1!==p.cartesian.indexOf(s)){if(u=s.indexOf(\"y\"),a=s.slice(0,u),o=s.slice(u),void 0!==y[a]&&y[a]!==i||void 0!==y[o]&&y[o]!==n)continue;_[i]=s,y[a]=i,y[o]=n}}}else{var k=c(e,f,\"x\"),T=c(e,f,\"y\");r.xaxes=h(k,p.xaxis,v,y,\"x\"),r.yaxes=h(T,p.yaxis,g,y,\"y\")}var A=r._anchors={},M=\"top to bottom\"===r.roworder;for(var S in y){var E,C,L,P=S.charAt(0),O=r[P+\"side\"];if(O.length<8)A[S]=\"free\";else if(\"x\"===P){if(\"t\"===O.charAt(0)===M?(E=0,C=1,L=g):(E=g-1,C=-1,L=-1),d){var z=y[S];for(n=E;n!==L;n+=C)if((s=l[n][z])&&(u=s.indexOf(\"y\"),s.slice(0,u)===S)){A[S]=s.slice(u);break}}else for(n=E;n!==L;n+=C)if(o=r.yaxes[n],-1!==p.cartesian.indexOf(S+o)){A[S]=o;break}}else if(\"l\"===O.charAt(0)?(E=0,C=1,L=v):(E=v-1,C=-1,L=-1),d){var I=y[S];for(n=E;n!==L;n+=C)if((s=l[I][n])&&(u=s.indexOf(\"y\"),s.slice(u)===S)){A[S]=s.slice(0,u);break}}else for(n=E;n!==L;n+=C)if(a=r.xaxes[n],-1!==p.cartesian.indexOf(a+S)){A[S]=a;break}}}}}},{\"../../lib\":719,\"../../lib/regex\":735,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773,\"../../plots/domain\":792}],637:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/constants\"),i=t(\"../../plot_api/plot_template\").templatedArray;e.exports=i(\"image\",{visible:{valType:\"boolean\",dflt:!0,editType:\"arraydraw\"},source:{valType:\"string\",editType:\"arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},sizex:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizey:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizing:{valType:\"enumerated\",values:[\"fill\",\"contain\",\"stretch\"],dflt:\"contain\",editType:\"arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},x:{valType:\"any\",dflt:0,editType:\"arraydraw\"},y:{valType:\"any\",dflt:0,editType:\"arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"top\",editType:\"arraydraw\"},xref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.x.toString()],dflt:\"paper\",editType:\"arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.y.toString()],dflt:\"paper\",editType:\"arraydraw\"},editType:\"arraydraw\"})},{\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773}],638:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.images,h=e._id.charAt(0),f=0;f<u.length;f++)if(c=\"images[\"+f+\"].\",(l=u[f])[h+\"ref\"]===e._id){var p=l[h],d=l[\"size\"+h],g=null,v=null;if(o){g=i(p,e.range);var m=d/Math.pow(10,g)/2;v=2*Math.log(m+Math.sqrt(1+m*m))/Math.LN10}else v=(g=Math.pow(10,p))*(Math.pow(10,d/2)-Math.pow(10,-d/2));n(g)?n(v)||(v=null):(g=null,v=null),a(c+h,g),a(c+\"size\"+h,v)}}},{\"../../lib/to_log_range\":745,\"fast-isnumeric\":225}],639:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\");function s(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}var s=a(\"source\");if(!a(\"visible\",!!s))return e;a(\"layer\"),a(\"xanchor\"),a(\"yanchor\"),a(\"sizex\"),a(\"sizey\"),a(\"sizing\"),a(\"opacity\");for(var l={_fullLayout:r},c=[\"x\",\"y\"],u=0;u<2;u++){var h=c[u],f=i.coerceRef(t,e,l,h,\"paper\");if(\"paper\"!==f)i.getFromId(l,f)._imgIndices.push(e._index);i.coercePosition(e,l,a,f,h,0)}return e}e.exports=function(t,e){a(t,e,{name:\"images\",handleItemDefaults:s})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"./attributes\":637}],640:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../drawing\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/xmlns_namespaces\");e.exports=function(t){var e,r,s=t._fullLayout,l=[],c={},u=[];for(r=0;r<s.images.length;r++){var h=s.images[r];if(h.visible)if(\"below\"===h.layer&&\"paper\"!==h.xref&&\"paper\"!==h.yref){e=h.xref+h.yref;var f=s._plots[e];if(!f){u.push(h);continue}f.mainplot&&(e=f.mainplot.id),c[e]||(c[e]=[]),c[e].push(h)}else\"above\"===h.layer?l.push(h):u.push(h)}var p={x:{left:{sizing:\"xMin\",offset:0},center:{sizing:\"xMid\",offset:-.5},right:{sizing:\"xMax\",offset:-1}},y:{top:{sizing:\"YMin\",offset:0},middle:{sizing:\"YMid\",offset:-.5},bottom:{sizing:\"YMax\",offset:-1}}};function d(e){var r=n.select(this);if(!this.img||this.img.src!==e.source){r.attr(\"xmlns\",o.svg);var i=new Promise(function(t){var n=new Image;function i(){r.remove(),t()}this.img=n,n.setAttribute(\"crossOrigin\",\"anonymous\"),n.onerror=i,n.onload=function(){var e=document.createElement(\"canvas\");e.width=this.width,e.height=this.height,e.getContext(\"2d\").drawImage(this,0,0);var n=e.toDataURL(\"image/png\");r.attr(\"xlink:href\",n),t()},r.on(\"error\",i),n.src=e.source}.bind(this));t._promises.push(i)}}function g(e){var r=n.select(this),o=a.getFromId(t,e.xref),l=a.getFromId(t,e.yref),c=s._size,u=o?Math.abs(o.l2p(e.sizex)-o.l2p(0)):e.sizex*c.w,h=l?Math.abs(l.l2p(e.sizey)-l.l2p(0)):e.sizey*c.h,f=u*p.x[e.xanchor].offset,d=h*p.y[e.yanchor].offset,g=p.x[e.xanchor].sizing+p.y[e.yanchor].sizing,v=(o?o.r2p(e.x)+o._offset:e.x*c.w+c.l)+f,m=(l?l.r2p(e.y)+l._offset:c.h-e.y*c.h+c.t)+d;switch(e.sizing){case\"fill\":g+=\" slice\";break;case\"stretch\":g=\"none\"}r.attr({x:v,y:m,width:u,height:h,preserveAspectRatio:g,opacity:e.opacity});var y=(o?o._id:\"\")+(l?l._id:\"\");i.setClipUrl(r,y?\"clip\"+s._uid+y:null,t)}var v=s._imageLowerLayer.selectAll(\"image\").data(u),m=s._imageUpperLayer.selectAll(\"image\").data(l);v.enter().append(\"image\"),m.enter().append(\"image\"),v.exit().remove(),m.exit().remove(),v.each(function(t){d.bind(this)(t),g.bind(this)(t)}),m.each(function(t){d.bind(this)(t),g.bind(this)(t)});var y=Object.keys(s._plots);for(r=0;r<y.length;r++){e=y[r];var x=s._plots[e];if(x.imagelayer){var b=x.imagelayer.selectAll(\"image\").data(c[e]||[]);b.enter().append(\"image\"),b.exit().remove(),b.each(function(t){d.bind(this)(t),g.bind(this)(t)})}}}},{\"../../constants/xmlns_namespaces\":696,\"../../plots/cartesian/axes\":767,\"../drawing\":614,d3:163}],641:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"images\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"images\"),draw:t(\"./draw\"),convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":777,\"./attributes\":637,\"./convert_coords\":638,\"./defaults\":639,\"./draw\":640}],642:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",editType:\"legend\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"legend\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"legend\"},font:n({editType:\"legend\"}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"v\",editType:\"legend\"},traceorder:{valType:\"flaglist\",flags:[\"reversed\",\"grouped\"],extras:[\"normal\"],editType:\"legend\"},tracegroupgap:{valType:\"number\",min:0,dflt:10,editType:\"legend\"},itemsizing:{valType:\"enumerated\",values:[\"trace\",\"constant\"],dflt:\"trace\",editType:\"legend\"},itemclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggle\",editType:\"legend\"},itemdoubleclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggleothers\",editType:\"legend\"},x:{valType:\"number\",min:-2,max:3,dflt:1.02,editType:\"legend\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"legend\"},y:{valType:\"number\",min:-2,max:3,dflt:1,editType:\"legend\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"legend\"},uirevision:{valType:\"any\",editType:\"none\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"legend\"},editType:\"legend\"}},{\"../../plots/font_attributes\":793,\"../color/attributes\":592}],643:[function(t,e,r){\"use strict\";e.exports={scrollBarWidth:6,scrollBarMinHeight:20,scrollBarColor:\"#808BA4\",scrollBarMargin:4,textOffsetX:40}},{}],644:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plot_api/plot_template\"),o=t(\"./attributes\"),s=t(\"../../plots/layout_attributes\"),l=t(\"./helpers\");e.exports=function(t,e,r){for(var c,u,h,f,p=t.legend||{},d=0,g=!1,v=\"normal\",m=0;m<r.length;m++){var y=r[m];y.visible&&((y.showlegend||y._dfltShowLegend)&&(d++,y.showlegend&&(g=!0,(n.traceIs(y,\"pie-like\")||!0===y._input.showlegend)&&d++)),(n.traceIs(y,\"bar\")&&\"stack\"===e.barmode||-1!==[\"tonextx\",\"tonexty\"].indexOf(y.fill))&&(v=l.isGrouped({traceorder:v})?\"grouped+reversed\":\"reversed\"),void 0!==y.legendgroup&&\"\"!==y.legendgroup&&(v=l.isReversed({traceorder:v})?\"reversed+grouped\":\"grouped\"))}var x=i.coerce(t,e,s,\"showlegend\",g&&d>1);if(!1!==x||p.uirevision){var b=a.newContainer(e,\"legend\");if(w(\"uirevision\",e.uirevision),!1!==x){if(w(\"bgcolor\",e.paper_bgcolor),w(\"bordercolor\"),w(\"borderwidth\"),i.coerceFont(w,\"font\",e.font),w(\"orientation\"),\"h\"===b.orientation){var _=t.xaxis;n.getComponentMethod(\"rangeslider\",\"isVisible\")(_)?(c=0,h=\"left\",u=1.1,f=\"bottom\"):(c=0,h=\"left\",u=-.1,f=\"top\")}w(\"traceorder\",v),l.isGrouped(e.legend)&&w(\"tracegroupgap\"),w(\"itemsizing\"),w(\"itemclick\"),w(\"itemdoubleclick\"),w(\"x\",c),w(\"xanchor\",h),w(\"y\",u),w(\"yanchor\",f),w(\"valign\"),i.noneOrAll(p,b,[\"x\",\"y\"])}}function w(t,e){return i.coerce(p,b,o,t,e)}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/layout_attributes\":819,\"../../registry\":847,\"./attributes\":642,\"./helpers\":648}],645:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib/events\"),l=t(\"../dragelement\"),c=t(\"../drawing\"),u=t(\"../color\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"./handle_click\"),p=t(\"./constants\"),d=t(\"../../constants/alignment\"),g=d.LINE_SPACING,v=d.FROM_TL,m=d.FROM_BR,y=t(\"./get_legend_data\"),x=t(\"./style\"),b=t(\"./helpers\");function _(t,e,r,n,i){var a=r.data()[0][0].trace,l={event:i,node:r.node(),curveNumber:a.index,expandedIndex:a._expandedIndex,data:t.data,layout:t.layout,frames:t._transitionData._frames,config:t._context,fullData:t._fullData,fullLayout:t._fullLayout};if(a._group&&(l.group=a._group),o.traceIs(a,\"pie-like\")&&(l.label=r.datum()[0].label),!1!==s.triggerHandler(t,\"plotly_legendclick\",l))if(1===n)e._clickTimeout=setTimeout(function(){f(r,t,n)},t._context.doubleClickDelay);else if(2===n){e._clickTimeout&&clearTimeout(e._clickTimeout),t._legendMouseDownTime=0,!1!==s.triggerHandler(t,\"plotly_legenddoubleclick\",l)&&f(r,t,n)}}function w(t,e,r){var n=t.data()[0][0],a=e._fullLayout,s=n.trace,l=o.traceIs(s,\"pie-like\"),u=s.index,f=e._context.edits.legendText&&!l,d=l?n.label:s.name;s._meta&&(d=i.templateString(d,s._meta));var v=i.ensureSingle(t,\"text\",\"legendtext\");function m(r){h.convertToTspans(r,e,function(){!function(t,e){var r=t.data()[0][0];if(!r.trace.showlegend)return void t.remove();var n,i,a=t.select(\"g[class*=math-group]\"),o=a.node(),s=e._fullLayout.legend.font.size*g;if(o){var l=c.bBox(o);n=l.height,i=l.width,c.setTranslate(a,0,n/4)}else{var u=t.select(\".legendtext\"),f=h.lineCount(u),d=u.node();n=s*f,i=d?c.bBox(d).width:0;var v=s*(.3+(1-f)/2);h.positionText(u,p.textOffsetX,v)}r.lineHeight=s,r.height=Math.max(n,16)+3,r.width=i}(t,e)})}v.attr(\"text-anchor\",\"start\").classed(\"user-select-none\",!0).call(c.font,a.legend.font).text(f?k(d,r):d),h.positionText(v,p.textOffsetX,0),f?v.call(h.makeEditable,{gd:e,text:d}).call(m).on(\"edit\",function(t){this.text(k(t,r)).call(m);var a=n.trace._fullInput||{},s={};if(o.hasTransform(a,\"groupby\")){var l=o.getTransformIndices(a,\"groupby\"),c=l[l.length-1],h=i.keyedContainer(a,\"transforms[\"+c+\"].styles\",\"target\",\"value.name\");h.set(n.trace._group,t),s=h.constructUpdate()}else s.name=t;return o.call(\"_guiRestyle\",e,s,u)}):m(v)}function k(t,e){var r=Math.max(4,e);if(t&&t.trim().length>=r/2)return t;for(var n=r-(t=t||\"\").length;n>0;n--)t+=\" \";return t}function T(t,e){var r,a=e._context.doubleClickDelay,o=1,s=i.ensureSingle(t,\"rect\",\"legendtoggle\",function(t){t.style(\"cursor\",\"pointer\").attr(\"pointer-events\",\"all\").call(u.fill,\"rgba(0,0,0,0)\")});s.on(\"mousedown\",function(){(r=(new Date).getTime())-e._legendMouseDownTime<a?o+=1:(o=1,e._legendMouseDownTime=r)}),s.on(\"mouseup\",function(){if(!e._dragged&&!e._editing){var r=e._fullLayout.legend;(new Date).getTime()-e._legendMouseDownTime>a&&(o=Math.max(o-1,1)),_(e,r,t,o,n.event)}})}function A(t,e,r){var a=t._fullLayout,o=a.legend,s=o.borderwidth,l=b.isGrouped(o),u=0;if(o._width=0,o._height=0,b.isVertical(o))l&&e.each(function(t,e){c.setTranslate(this,0,e*o.tracegroupgap)}),r.each(function(t){var e=t[0],r=e.height,n=e.width;c.setTranslate(this,s,5+s+o._height+r/2),o._height+=r,o._width=Math.max(o._width,n)}),o._width+=45+2*s,o._height+=10+2*s,l&&(o._height+=(o._lgroupsLength-1)*o.tracegroupgap),u=40;else if(l){var h,f=0,p=0,d=e.data(),g=0;for(h=0;h<d.length;h++){var v=d[h],m=v.map(function(t){return t[0].width}),y=i.aggNums(Math.max,null,m),x=v.reduce(function(t,e){return t+e[0].height},0);p=Math.max(p,y),f=Math.max(f,x),g=Math.max(g,v.length)}p+=5,p+=40;var _=[o._width],w=[],k=0;for(h=0;h<d.length;h++){a._size.w<s+o._width+5+p?(_[_.length-1]=_[0],o._width=p,k++):o._width+=p+s;var T=k*f;T+=k>0?o.tracegroupgap:0,w.push(T),_.push(o._width)}e.each(function(t,e){c.setTranslate(this,_[e],w[e])}),e.each(function(){var t=n.select(this).selectAll(\"g.traces\"),e=0;t.each(function(t){var r=t[0].height;c.setTranslate(this,0,5+s+e+r/2),e+=r})});var A=w[w.length-1]+f;o._height=10+2*s+A;var M=Math.max.apply(null,_);o._width=M+p+40,o._width+=2*s}else{var S=0,E=0,C=0,L=0,P=0;r.each(function(t){C=Math.max(40+t[0].width,C),P+=40+t[0].width+5});var O=a._size.w>s+P-5;r.each(function(t){var e=t[0],r=O?40+t[0].width:C;s+L+5+r>a._size.w&&(L=0,S+=E,o._height+=E,E=0),c.setTranslate(this,s+L,5+s+e.height/2+S),o._width+=5+r,L+=5+r,E=Math.max(e.height,E)}),O?o._height=E:o._height+=E,o._width+=2*s,o._height+=10+2*s}o._width=Math.ceil(o._width),o._height=Math.ceil(o._height);var z=t._context.edits.legendText||t._context.edits.legendPosition;r.each(function(t){var e=t[0],r=n.select(this).select(\".legendtoggle\");c.setRect(r,0,-e.height/2,(z?0:o._width)+u,e.height)})}function M(t){var e=t._fullLayout.legend,r=\"left\";i.isRightAnchor(e)?r=\"right\":i.isCenterAnchor(e)&&(r=\"center\");var n=\"top\";i.isBottomAnchor(e)?n=\"bottom\":i.isMiddleAnchor(e)&&(n=\"middle\"),a.autoMargin(t,\"legend\",{x:e.x,y:e.y,l:e._width*v[r],r:e._width*m[r],b:e._height*m[n],t:e._height*v[n]})}e.exports=function(t){var e=t._fullLayout,r=\"legend\"+e._uid;if(e._infolayer&&t.calcdata){t._legendMouseDownTime||(t._legendMouseDownTime=0);var s=e.legend,h=e.showlegend&&y(t.calcdata,s),f=e.hiddenlabels||[];if(!e.showlegend||!h.length)return e._infolayer.selectAll(\".legend\").remove(),e._topdefs.select(\"#\"+r).remove(),void a.autoMargin(t,\"legend\");for(var d=0,g=0;g<h.length;g++)for(var b=0;b<h[g].length;b++){var k=h[g][b][0],S=k.trace,E=o.traceIs(S,\"pie-like\")?k.label:S.name;d=Math.max(d,E&&E.length||0)}var C=!1,L=i.ensureSingle(e._infolayer,\"g\",\"legend\",function(t){t.attr(\"pointer-events\",\"all\"),C=!0}),P=i.ensureSingleById(e._topdefs,\"clipPath\",r,function(t){t.append(\"rect\")}),O=i.ensureSingle(L,\"rect\",\"bg\",function(t){t.attr(\"shape-rendering\",\"crispEdges\")});O.call(u.stroke,s.bordercolor).call(u.fill,s.bgcolor).style(\"stroke-width\",s.borderwidth+\"px\");var z=i.ensureSingle(L,\"g\",\"scrollbox\"),I=i.ensureSingle(L,\"rect\",\"scrollbar\",function(t){t.attr({rx:20,ry:3,width:0,height:0}).call(u.fill,\"#808BA4\")}),D=z.selectAll(\"g.groups\").data(h);D.enter().append(\"g\").attr(\"class\",\"groups\"),D.exit().remove();var R=D.selectAll(\"g.traces\").data(i.identity);R.enter().append(\"g\").attr(\"class\",\"traces\"),R.exit().remove(),R.style(\"opacity\",function(t){var e=t[0].trace;return o.traceIs(e,\"pie-like\")?-1!==f.indexOf(t[0].label)?.5:1:\"legendonly\"===e.visible?.5:1}).each(function(){n.select(this).call(w,t,d)}).call(x,t).each(function(){n.select(this).call(T,t)}),i.syncOrAsync([a.previousPromises,function(){C&&(A(t,D,R),M(t));var u=e.width,h=e.height;A(t,D,R),s._height>h?function(t){var e=t._fullLayout.legend,r=\"left\";i.isRightAnchor(e)?r=\"right\":i.isCenterAnchor(e)&&(r=\"center\");a.autoMargin(t,\"legend\",{x:e.x,y:.5,l:e._width*v[r],r:e._width*m[r],b:0,t:0})}(t):M(t);var f=e._size,d=f.l+f.w*s.x,g=f.t+f.h*(1-s.y);i.isRightAnchor(s)?d-=s._width:i.isCenterAnchor(s)&&(d-=s._width/2),i.isBottomAnchor(s)?g-=s._height:i.isMiddleAnchor(s)&&(g-=s._height/2);var y=s._width,x=f.w;y>x?(d=f.l,y=x):(d+y>u&&(d=u-y),d<0&&(d=0),y=Math.min(u-d,s._width));var b,w,k,T,S=s._height,E=f.h;if(S>E?(g=f.t,S=E):(g+S>h&&(g=h-S),g<0&&(g=0),S=Math.min(h-g,s._height)),c.setTranslate(L,d,g),I.on(\".drag\",null),L.on(\"wheel\",null),s._height<=S||t._context.staticPlot)O.attr({width:y-s.borderwidth,height:S-s.borderwidth,x:s.borderwidth/2,y:s.borderwidth/2}),c.setTranslate(z,0,0),P.select(\"rect\").attr({width:y-2*s.borderwidth,height:S-2*s.borderwidth,x:s.borderwidth,y:s.borderwidth}),c.setClipUrl(z,r,t),c.setRect(I,0,0,0,0),delete s._scrollY;else{var F,B,N=Math.max(p.scrollBarMinHeight,S*S/s._height),j=S-N-2*p.scrollBarMargin,U=s._height-S,V=j/U,q=Math.min(s._scrollY||0,U);O.attr({width:y-2*s.borderwidth+p.scrollBarWidth+p.scrollBarMargin,height:S-s.borderwidth,x:s.borderwidth/2,y:s.borderwidth/2}),P.select(\"rect\").attr({width:y-2*s.borderwidth+p.scrollBarWidth+p.scrollBarMargin,height:S-2*s.borderwidth,x:s.borderwidth,y:s.borderwidth+q}),c.setClipUrl(z,r,t),G(q,N,V),L.on(\"wheel\",function(){G(q=i.constrain(s._scrollY+n.event.deltaY/j*U,0,U),N,V),0!==q&&q!==U&&n.event.preventDefault()});var H=n.behavior.drag().on(\"dragstart\",function(){F=n.event.sourceEvent.clientY,B=q}).on(\"drag\",function(){var t=n.event.sourceEvent;2===t.buttons||t.ctrlKey||G(q=i.constrain((t.clientY-F)/V+B,0,U),N,V)});I.call(H)}function G(e,r,n){s._scrollY=t._fullLayout.legend._scrollY=e,c.setTranslate(z,0,-e),c.setRect(I,y,p.scrollBarMargin+e*n,p.scrollBarWidth,r),P.select(\"rect\").attr({y:s.borderwidth+e})}t._context.edits.legendPosition&&(L.classed(\"cursor-move\",!0),l.init({element:L.node(),gd:t,prepFn:function(){var t=c.getTranslate(L);k=t.x,T=t.y},moveFn:function(t,e){var r=k+t,n=T+e;c.setTranslate(L,r,n),b=l.align(r,0,f.l,f.l+f.w,s.xanchor),w=l.align(n,0,f.t+f.h,f.t,s.yanchor)},doneFn:function(){void 0!==b&&void 0!==w&&o.call(\"_guiRelayout\",t,{\"legend.x\":b,\"legend.y\":w})},clickFn:function(r,n){var i=e._infolayer.selectAll(\"g.traces\").filter(function(){var t=this.getBoundingClientRect();return n.clientX>=t.left&&n.clientX<=t.right&&n.clientY>=t.top&&n.clientY<=t.bottom});i.size()>0&&_(t,L,i,r,n)}}))}],t)}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/events\":709,\"../../lib/svg_text_utils\":743,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"./constants\":643,\"./get_legend_data\":646,\"./handle_click\":647,\"./helpers\":648,\"./style\":650,d3:163}],646:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./helpers\");e.exports=function(t,e){var r,a,o={},s=[],l=!1,c={},u=0;function h(t,r){if(\"\"!==t&&i.isGrouped(e))-1===s.indexOf(t)?(s.push(t),l=!0,o[t]=[[r]]):o[t].push([r]);else{var n=\"~~i\"+u;s.push(n),o[n]=[[r]],u++}}for(r=0;r<t.length;r++){var f=t[r],p=f[0],d=p.trace,g=d.legendgroup;if(d.visible&&d.showlegend)if(n.traceIs(d,\"pie-like\"))for(c[g]||(c[g]={}),a=0;a<f.length;a++){var v=f[a].label;c[g][v]||(h(g,{label:v,color:f[a].color,i:f[a].i,trace:d,pts:f[a].pts}),c[g][v]=!0)}else h(g,p)}if(!s.length)return[];var m,y,x=s.length;if(l&&i.isGrouped(e))for(y=new Array(x),r=0;r<x;r++)m=o[s[r]],y[r]=i.isReversed(e)?m.reverse():m;else{for(y=[new Array(x)],r=0;r<x;r++)m=o[s[r]][0],y[0][i.isReversed(e)?x-r-1:r]=m;x=1}return e._lgroupsLength=x,y}},{\"../../registry\":847,\"./helpers\":648}],647:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=!0;e.exports=function(t,e,r){var o=e._fullLayout;if(!e._dragged&&!e._editing){var s,l=o.legend.itemclick,c=o.legend.itemdoubleclick;if(1===r&&\"toggle\"===l&&\"toggleothers\"===c&&a&&e.data&&e._context.showTips?(n.notifier(n._(e,\"Double-click on legend to isolate one trace\"),\"long\"),a=!1):a=!1,1===r?s=l:2===r&&(s=c),s){var u,h,f,p,d,g=o.hiddenlabels?o.hiddenlabels.slice():[],v=t.data()[0][0],m=e._fullData,y=v.trace,x=y.legendgroup,b={},_=[],w=[],k=[];if(i.traceIs(y,\"pie-like\")){var T=v.label,A=g.indexOf(T);\"toggle\"===s?-1===A?g.push(T):g.splice(A,1):\"toggleothers\"===s&&(g=[],e.calcdata[0].forEach(function(t){T!==t.label&&g.push(t.label)}),e._fullLayout.hiddenlabels&&e._fullLayout.hiddenlabels.length===g.length&&-1===A&&(g=[])),i.call(\"_guiRelayout\",e,\"hiddenlabels\",g)}else{var M,S=x&&x.length,E=[];if(S)for(u=0;u<m.length;u++)(M=m[u]).visible&&M.legendgroup===x&&E.push(u);if(\"toggle\"===s){var C;switch(y.visible){case!0:C=\"legendonly\";break;case!1:C=!1;break;case\"legendonly\":C=!0}if(S)for(u=0;u<m.length;u++)!1!==m[u].visible&&m[u].legendgroup===x&&R(m[u],C);else R(y,C)}else if(\"toggleothers\"===s){var L,P,O=!0;for(u=0;u<m.length;u++)if(!(m[u]===y)&&!(L=S&&m[u].legendgroup===x)&&!0===m[u].visible&&!i.traceIs(m[u],\"notLegendIsolatable\")){O=!1;break}for(u=0;u<m.length;u++)if(!1!==m[u].visible&&!i.traceIs(m[u],\"notLegendIsolatable\"))switch(y.visible){case\"legendonly\":R(m[u],!0);break;case!0:P=!!O||\"legendonly\",L=m[u]===y||S&&m[u].legendgroup===x,R(m[u],!!L||P)}}for(u=0;u<w.length;u++)if(f=w[u]){var z=f.constructUpdate(),I=Object.keys(z);for(h=0;h<I.length;h++)p=I[h],(b[p]=b[p]||[])[k[u]]=z[p]}for(d=Object.keys(b),u=0;u<d.length;u++)for(p=d[u],h=0;h<_.length;h++)b[p].hasOwnProperty(h)||(b[p][h]=void 0);i.call(\"_guiRestyle\",e,b,_)}}}function D(t,e,r){var n=_.indexOf(t),i=b[e];return i||(i=b[e]=[]),-1===_.indexOf(t)&&(_.push(t),n=_.length-1),i[n]=r,n}function R(t,e){var r=t._fullInput;if(i.hasTransform(r,\"groupby\")){var a=w[r.index];if(!a){var o=i.getTransformIndices(r,\"groupby\"),s=o[o.length-1];a=n.keyedContainer(r,\"transforms[\"+s+\"].styles\",\"target\",\"value.visible\"),w[r.index]=a}var l=a.get(t._group);void 0===l&&(l=!0),!1!==l&&a.set(t._group,e),k[r.index]=D(r.index,\"visible\",!1!==r.visible)}else{var c=!1!==r.visible&&e;D(r.index,\"visible\",c)}}}},{\"../../lib\":719,\"../../registry\":847}],648:[function(t,e,r){\"use strict\";r.isGrouped=function(t){return-1!==(t.traceorder||\"\").indexOf(\"grouped\")},r.isVertical=function(t){return\"h\"!==t.orientation},r.isReversed=function(t){return-1!==(t.traceorder||\"\").indexOf(\"reversed\")}},{}],649:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"legend\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\"),style:t(\"./style\")}},{\"./attributes\":642,\"./defaults\":644,\"./draw\":645,\"./style\":650}],650:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../drawing\"),s=t(\"../color\"),l=t(\"../../traces/scatter/subtypes\"),c=t(\"../../traces/pie/style_one\"),u=t(\"../../traces/pie/helpers\").castOption,h=12,f=5,p=2,d=10,g=5;e.exports=function(t,e){var r=e._fullLayout.legend,v=\"constant\"===r.itemsizing;function m(t,e,r,n){var i;if(t+1)i=t;else{if(!(e&&e.width>0))return 0;i=e.width}return v?n:Math.min(i,r)}function y(t,e,r){var a=t[0].trace,o=a.marker||{},l=o.line||{},c=r?a.type===r&&a.visible:i.traceIs(a,\"bar\"),u=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(c?[t]:[]);u.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),u.exit().remove(),u.each(function(t){var e=n.select(this),r=t[0],i=m(r.mlw,o.line,g,p);e.style(\"stroke-width\",i+\"px\").call(s.fill,r.mc||o.color),i&&s.stroke(e,r.mlc||l.color)})}function x(t,e,r){var o=t[0],s=o.trace,l=r?s.type===r&&s.visible:i.traceIs(s,r),h=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(l?[t]:[]);if(h.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),h.exit().remove(),h.size()){var f=(s.marker||{}).line,d=m(u(f.width,o.pts),f,g,p),v=a.minExtend(s,{marker:{line:{width:d}}});v.marker.line.color=f.color;var y=a.minExtend(o,{trace:v});c(h,y,v)}}t.each(function(t){var e=n.select(this),i=a.ensureSingle(e,\"g\",\"layers\");i.style(\"opacity\",t[0].trace.opacity);var o=r.valign,s=t[0].lineHeight,l=t[0].height;if(\"middle\"!==o&&s&&l){var c={top:1,bottom:-1}[o]*(.5*(s-l+3));i.attr(\"transform\",\"translate(0,\"+c+\")\")}else i.attr(\"transform\",null);i.selectAll(\"g.legendfill\").data([t]).enter().append(\"g\").classed(\"legendfill\",!0),i.selectAll(\"g.legendlines\").data([t]).enter().append(\"g\").classed(\"legendlines\",!0);var u=i.selectAll(\"g.legendsymbols\").data([t]);u.enter().append(\"g\").classed(\"legendsymbols\",!0),u.selectAll(\"g.legendpoints\").data([t]).enter().append(\"g\").classed(\"legendpoints\",!0)}).each(function(t){var e=t[0].trace,r=[];\"waterfall\"===e.type&&e.visible&&(r=t[0].hasTotals?[[\"increasing\",\"M-6,-6V6H0Z\"],[\"totals\",\"M6,6H0L-6,-6H-0Z\"],[\"decreasing\",\"M6,6V-6H0Z\"]]:[[\"increasing\",\"M-6,-6V6H6Z\"],[\"decreasing\",\"M6,6V-6H-6Z\"]]);var i=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendwaterfall\").data(r);i.enter().append(\"path\").classed(\"legendwaterfall\",!0).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),i.exit().remove(),i.each(function(t){var r=n.select(this),i=e[t[0]].marker,a=m(void 0,i.line,g,p);r.attr(\"d\",t[1]).style(\"stroke-width\",a+\"px\").call(s.fill,i.color),a&&r.call(s.stroke,i.line.color)})}).each(function(t){y(t,this,\"funnel\")}).each(function(t){y(t,this)}).each(function(t){var r=t[0].trace,l=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendbox\").data(i.traceIs(r,\"box-violin\")&&r.visible?[t]:[]);l.enter().append(\"path\").classed(\"legendbox\",!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",\"translate(20,0)\"),l.exit().remove(),l.each(function(){var t=n.select(this);if(\"all\"!==r.boxpoints&&\"all\"!==r.points||0!==s.opacity(r.fillcolor)||0!==s.opacity((r.line||{}).color)){var i=m(void 0,r.line,g,p);t.style(\"stroke-width\",i+\"px\").call(s.fill,r.fillcolor),i&&s.stroke(t,r.line.color)}else{var c=a.minExtend(r,{marker:{size:v?h:a.constrain(r.marker.size,2,16),sizeref:1,sizemin:1,sizemode:\"diameter\"}});l.call(o.pointStyle,c,e)}})}).each(function(t){x(t,this,\"funnelarea\")}).each(function(t){x(t,this,\"pie\")}).each(function(t){var r,i,s=t[0],c=s.trace,u=c.visible&&c.fill&&\"none\"!==c.fill,h=l.hasLines(c),p=c.contours,g=!1,v=!1;if(p){var y=p.coloring;\"lines\"===y?g=!0:h=\"none\"===y||\"heatmap\"===y||p.showlines,\"constraint\"===p.type?u=\"=\"!==p._operation:\"fill\"!==y&&\"heatmap\"!==y||(v=!0)}var x=l.hasMarkers(c)||l.hasText(c),b=u||v,_=h||g,w=x||!b?\"M5,0\":_?\"M5,-2\":\"M5,-3\",k=n.select(this),T=k.select(\".legendfill\").selectAll(\"path\").data(u||v?[t]:[]);if(T.enter().append(\"path\").classed(\"js-fill\",!0),T.exit().remove(),T.attr(\"d\",w+\"h30v6h-30z\").call(u?o.fillGroupStyle:function(t){if(t.size()){var r=\"legendfill-\"+c.uid;o.gradient(t,e,r,\"horizontalreversed\",c.colorscale,\"fill\")}}),h||g){var A=m(void 0,c.line,d,f);i=a.minExtend(c,{line:{width:A}}),r=[a.minExtend(s,{trace:i})]}var M=k.select(\".legendlines\").selectAll(\"path\").data(h||g?[r]:[]);M.enter().append(\"path\").classed(\"js-line\",!0),M.exit().remove(),M.attr(\"d\",w+(g?\"l30,0.0001\":\"h30\")).call(h?o.lineGroupStyle:function(t){if(t.size()){var r=\"legendline-\"+c.uid;o.lineGroupStyle(t),o.gradient(t,e,r,\"horizontalreversed\",c.colorscale,\"stroke\")}})}).each(function(t){var r,i,s=t[0],c=s.trace,u=l.hasMarkers(c),d=l.hasText(c),g=l.hasLines(c);function m(t,e,r,n){var i=a.nestedProperty(c,t).get(),o=a.isArrayOrTypedArray(i)&&e?e(i):i;if(v&&o&&void 0!==n&&(o=n),r){if(o<r[0])return r[0];if(o>r[1])return r[1]}return o}function y(t){return t[0]}if(u||d||g){var x={},b={};if(u){x.mc=m(\"marker.color\",y),x.mx=m(\"marker.symbol\",y),x.mo=m(\"marker.opacity\",a.mean,[.2,1]),x.mlc=m(\"marker.line.color\",y),x.mlw=m(\"marker.line.width\",a.mean,[0,5],p),b.marker={sizeref:1,sizemin:1,sizemode:\"diameter\"};var _=m(\"marker.size\",a.mean,[2,16],h);x.ms=_,b.marker.size=_}g&&(b.line={width:m(\"line.width\",y,[0,10],f)}),d&&(x.tx=\"Aa\",x.tp=m(\"textposition\",y),x.ts=10,x.tc=m(\"textfont.color\",y),x.tf=m(\"textfont.family\",y)),r=[a.minExtend(s,x)],(i=a.minExtend(c,b)).selectedpoints=null}var w=n.select(this).select(\"g.legendpoints\"),k=w.selectAll(\"path.scatterpts\").data(u?r:[]);k.enter().insert(\"path\",\":first-child\").classed(\"scatterpts\",!0).attr(\"transform\",\"translate(20,0)\"),k.exit().remove(),k.call(o.pointStyle,i,e),u&&(r[0].mrc=3);var T=w.selectAll(\"g.pointtext\").data(d?r:[]);T.enter().append(\"g\").classed(\"pointtext\",!0).append(\"text\").attr(\"transform\",\"translate(20,0)\"),T.exit().remove(),T.selectAll(\"text\").call(o.textPointStyle,i,e)}).each(function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendcandle\").data(\"candlestick\"===e.type&&e.visible?[t,t]:[]);r.enter().append(\"path\").classed(\"legendcandle\",!0).attr(\"d\",function(t,e){return e?\"M-15,0H-8M-8,6V-6H8Z\":\"M15,0H8M8,-6V6H-8Z\"}).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),r.exit().remove(),r.each(function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],o=m(void 0,a.line,g,p);i.style(\"stroke-width\",o+\"px\").call(s.fill,a.fillcolor),o&&s.stroke(i,a.line.color)})}).each(function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendohlc\").data(\"ohlc\"===e.type&&e.visible?[t,t]:[]);r.enter().append(\"path\").classed(\"legendohlc\",!0).attr(\"d\",function(t,e){return e?\"M-15,0H0M-8,-6V0\":\"M15,0H0M8,6V0\"}).attr(\"transform\",\"translate(20,0)\").style(\"stroke-miterlimit\",1),r.exit().remove(),r.each(function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],l=m(void 0,a.line,g,p);i.style(\"fill\",\"none\").call(o.dashLine,a.line.dash,l),l&&s.stroke(i,a.line.color)})})}},{\"../../lib\":719,\"../../registry\":847,\"../../traces/pie/helpers\":1091,\"../../traces/pie/style_one\":1097,\"../../traces/scatter/subtypes\":1135,\"../color\":593,\"../drawing\":614,d3:163}],651:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/plots\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../lib\"),s=t(\"../../fonts/ploticon\"),l=o._,c=e.exports={};function u(t,e){var r,i,o=e.currentTarget,s=o.getAttribute(\"data-attr\"),l=o.getAttribute(\"data-val\")||!0,c=t._fullLayout,u={},h=a.list(t,null,!0),f=\"on\";if(\"zoom\"===s){var p,d=\"in\"===l?.5:2,g=(1+d)/2,v=(1-d)/2;for(i=0;i<h.length;i++)if(!(r=h[i]).fixedrange)if(p=r._name,\"auto\"===l)u[p+\".autorange\"]=!0;else if(\"reset\"===l){if(void 0===r._rangeInitial)u[p+\".autorange\"]=!0;else{var m=r._rangeInitial.slice();u[p+\".range[0]\"]=m[0],u[p+\".range[1]\"]=m[1]}void 0!==r._showSpikeInitial&&(u[p+\".showspikes\"]=r._showSpikeInitial,\"on\"!==f||r._showSpikeInitial||(f=\"off\"))}else{var y=[r.r2l(r.range[0]),r.r2l(r.range[1])],x=[g*y[0]+v*y[1],g*y[1]+v*y[0]];u[p+\".range[0]\"]=r.l2r(x[0]),u[p+\".range[1]\"]=r.l2r(x[1])}c._cartesianSpikesEnabled=f}else{if(\"hovermode\"!==s||\"x\"!==l&&\"y\"!==l){if(\"hovermode\"===s&&\"closest\"===l){for(i=0;i<h.length;i++)r=h[i],\"on\"!==f||r.showspikes||(f=\"off\");c._cartesianSpikesEnabled=f}}else l=c._isHoriz?\"y\":\"x\",o.setAttribute(\"data-val\",l);u[s]=l}n.call(\"_guiRelayout\",t,u)}function h(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout._subplots.gl3d,s={},l=i.split(\".\"),c=0;c<o.length;c++)s[o[c]+\".\"+l[1]]=a;var u=\"pan\"===a?a:\"zoom\";s.dragmode=u,n.call(\"_guiRelayout\",t,s)}function f(t,e){for(var r=e.currentTarget.getAttribute(\"data-attr\"),i=t._fullLayout,a=i._subplots.gl3d,o={},s=0;s<a.length;s++){var l=a[s],c=l+\".camera\",u=i[l]._scene;\"resetLastSave\"===r?(o[c+\".up\"]=u.viewInitial.up,o[c+\".eye\"]=u.viewInitial.eye,o[c+\".center\"]=u.viewInitial.center):\"resetDefault\"===r&&(o[c+\".up\"]=null,o[c+\".eye\"]=null,o[c+\".center\"]=null)}n.call(\"_guiRelayout\",t,o)}function p(t,e){var r=e.currentTarget,n=r._previousVal,i=t._fullLayout,a=i._subplots.gl3d,o=[\"xaxis\",\"yaxis\",\"zaxis\"],s={},l={};if(n)l=n,r._previousVal=null;else{for(var c=0;c<a.length;c++){var u=a[c],h=i[u],f=u+\".hovermode\";s[f]=h.hovermode,l[f]=!1;for(var p=0;p<3;p++){var d=o[p],g=u+\".\"+d+\".showspikes\";l[g]=!1,s[g]=h[d].showspikes}}r._previousVal=s}return l}function d(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout,s=o._subplots.geo,l=0;l<s.length;l++){var c=s[l],u=o[c];if(\"zoom\"===i){var h=u.projection.scale,f=\"in\"===a?2*h:.5*h;n.call(\"_guiRelayout\",t,c+\".projection.scale\",f)}else\"reset\"===i&&m(t,\"geo\")}}function g(t){var e=t._fullLayout;return!e.hovermode&&(e._has(\"cartesian\")?e._isHoriz?\"y\":\"x\":\"closest\")}function v(t){var e=g(t);n.call(\"_guiRelayout\",t,\"hovermode\",e)}function m(t,e){for(var r=t._fullLayout,i=r._subplots[e],a={},o=0;o<i.length;o++)for(var s=i[o],l=r[s]._subplot.viewInitial,c=Object.keys(l),u=0;u<c.length;u++){var h=c[u];a[s+\".\"+h]=l[h]}n.call(\"_guiRelayout\",t,a)}c.toImage={name:\"toImage\",title:function(t){var e=(t._context.toImageButtonOptions||{}).format||\"png\";return l(t,\"png\"===e?\"Download plot as a png\":\"Download plot\")},icon:s.camera,click:function(t){var e=t._context.toImageButtonOptions,r={format:e.format||\"png\"};o.notifier(l(t,\"Taking snapshot - this may take a few seconds\"),\"long\"),\"svg\"!==r.format&&o.isIE()&&(o.notifier(l(t,\"IE only supports svg.  Changing format to svg.\"),\"long\"),r.format=\"svg\"),[\"filename\",\"width\",\"height\",\"scale\"].forEach(function(t){t in e&&(r[t]=e[t])}),n.call(\"downloadImage\",t,r).then(function(e){o.notifier(l(t,\"Snapshot succeeded\")+\" - \"+e,\"long\")}).catch(function(){o.notifier(l(t,\"Sorry, there was a problem downloading your snapshot!\"),\"long\")})}},c.sendDataToCloud={name:\"sendDataToCloud\",title:function(t){return l(t,\"Edit in Chart Studio\")},icon:s.disk,click:function(t){i.sendDataToCloud(t)}},c.editInChartStudio={name:\"editInChartStudio\",title:function(t){return l(t,\"Edit in Chart Studio\")},icon:s.pencil,click:function(t){i.sendDataToCloud(t)}},c.zoom2d={name:\"zoom2d\",title:function(t){return l(t,\"Zoom\")},attr:\"dragmode\",val:\"zoom\",icon:s.zoombox,click:u},c.pan2d={name:\"pan2d\",title:function(t){return l(t,\"Pan\")},attr:\"dragmode\",val:\"pan\",icon:s.pan,click:u},c.select2d={name:\"select2d\",title:function(t){return l(t,\"Box Select\")},attr:\"dragmode\",val:\"select\",icon:s.selectbox,click:u},c.lasso2d={name:\"lasso2d\",title:function(t){return l(t,\"Lasso Select\")},attr:\"dragmode\",val:\"lasso\",icon:s.lasso,click:u},c.zoomIn2d={name:\"zoomIn2d\",title:function(t){return l(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:s.zoom_plus,click:u},c.zoomOut2d={name:\"zoomOut2d\",title:function(t){return l(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:s.zoom_minus,click:u},c.autoScale2d={name:\"autoScale2d\",title:function(t){return l(t,\"Autoscale\")},attr:\"zoom\",val:\"auto\",icon:s.autoscale,click:u},c.resetScale2d={name:\"resetScale2d\",title:function(t){return l(t,\"Reset axes\")},attr:\"zoom\",val:\"reset\",icon:s.home,click:u},c.hoverClosestCartesian={name:\"hoverClosestCartesian\",title:function(t){return l(t,\"Show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:s.tooltip_basic,gravity:\"ne\",click:u},c.hoverCompareCartesian={name:\"hoverCompareCartesian\",title:function(t){return l(t,\"Compare data on hover\")},attr:\"hovermode\",val:function(t){return t._fullLayout._isHoriz?\"y\":\"x\"},icon:s.tooltip_compare,gravity:\"ne\",click:u},c.zoom3d={name:\"zoom3d\",title:function(t){return l(t,\"Zoom\")},attr:\"scene.dragmode\",val:\"zoom\",icon:s.zoombox,click:h},c.pan3d={name:\"pan3d\",title:function(t){return l(t,\"Pan\")},attr:\"scene.dragmode\",val:\"pan\",icon:s.pan,click:h},c.orbitRotation={name:\"orbitRotation\",title:function(t){return l(t,\"Orbital rotation\")},attr:\"scene.dragmode\",val:\"orbit\",icon:s[\"3d_rotate\"],click:h},c.tableRotation={name:\"tableRotation\",title:function(t){return l(t,\"Turntable rotation\")},attr:\"scene.dragmode\",val:\"turntable\",icon:s[\"z-axis\"],click:h},c.resetCameraDefault3d={name:\"resetCameraDefault3d\",title:function(t){return l(t,\"Reset camera to default\")},attr:\"resetDefault\",icon:s.home,click:f},c.resetCameraLastSave3d={name:\"resetCameraLastSave3d\",title:function(t){return l(t,\"Reset camera to last save\")},attr:\"resetLastSave\",icon:s.movie,click:f},c.hoverClosest3d={name:\"hoverClosest3d\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=p(t,e);n.call(\"_guiRelayout\",t,r)}},c.zoomInGeo={name:\"zoomInGeo\",title:function(t){return l(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:s.zoom_plus,click:d},c.zoomOutGeo={name:\"zoomOutGeo\",title:function(t){return l(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:s.zoom_minus,click:d},c.resetGeo={name:\"resetGeo\",title:function(t){return l(t,\"Reset\")},attr:\"reset\",val:null,icon:s.autoscale,click:d},c.hoverClosestGeo={name:\"hoverClosestGeo\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:v},c.hoverClosestGl2d={name:\"hoverClosestGl2d\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:v},c.hoverClosestPie={name:\"hoverClosestPie\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:s.tooltip_basic,gravity:\"ne\",click:v},c.resetViewSankey={name:\"resetSankeyGroup\",title:function(t){return l(t,\"Reset view\")},icon:s.home,click:function(t){for(var e={\"node.groups\":[],\"node.x\":[],\"node.y\":[]},r=0;r<t._fullData.length;r++){var i=t._fullData[r]._viewInitial;e[\"node.groups\"].push(i.node.groups.slice()),e[\"node.x\"].push(i.node.x.slice()),e[\"node.y\"].push(i.node.y.slice())}n.call(\"restyle\",t,e)}},c.toggleHover={name:\"toggleHover\",title:function(t){return l(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:s.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=p(t,e);r.hovermode=g(t),n.call(\"_guiRelayout\",t,r)}},c.resetViews={name:\"resetViews\",title:function(t){return l(t,\"Reset views\")},icon:s.home,click:function(t,e){var r=e.currentTarget;r.setAttribute(\"data-attr\",\"zoom\"),r.setAttribute(\"data-val\",\"reset\"),u(t,e),r.setAttribute(\"data-attr\",\"resetLastSave\"),f(t,e),m(t,\"geo\"),m(t,\"mapbox\")}},c.toggleSpikelines={name:\"toggleSpikelines\",title:function(t){return l(t,\"Toggle Spike Lines\")},icon:s.spikeline,attr:\"_cartesianSpikesEnabled\",val:\"on\",click:function(t){var e=t._fullLayout;e._cartesianSpikesEnabled=\"on\"===e._cartesianSpikesEnabled?\"off\":\"on\";var r=function(t){for(var e,r,n=t._fullLayout,i=a.list(t,null,!0),o={},s=0;s<i.length;s++)e=i[s],r=e._name,o[r+\".showspikes\"]=\"on\"===n._cartesianSpikesEnabled||e._showSpikeInitial;return o}(t);n.call(\"_guiRelayout\",t,r)}},c.resetViewMapbox={name:\"resetViewMapbox\",title:function(t){return l(t,\"Reset view\")},attr:\"reset\",icon:s.home,click:function(t){m(t,\"mapbox\")}}},{\"../../fonts/ploticon\":699,\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../../plots/plots\":828,\"../../registry\":847}],652:[function(t,e,r){\"use strict\";r.manage=t(\"./manage\")},{\"./manage\":653}],653:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"../../traces/scatter/subtypes\"),a=t(\"../../registry\"),o=t(\"./modebar\"),s=t(\"./buttons\");e.exports=function(t){var e=t._fullLayout,r=t._context,l=e._modeBar;if(r.displayModeBar||r.watermark){if(!Array.isArray(r.modeBarButtonsToRemove))throw new Error([\"*modeBarButtonsToRemove* configuration options\",\"must be an array.\"].join(\" \"));if(!Array.isArray(r.modeBarButtonsToAdd))throw new Error([\"*modeBarButtonsToAdd* configuration options\",\"must be an array.\"].join(\" \"));var c,u=r.modeBarButtons;c=Array.isArray(u)&&u.length?function(t){for(var e=0;e<t.length;e++)for(var r=t[e],n=0;n<r.length;n++){var i=r[n];if(\"string\"==typeof i){if(void 0===s[i])throw new Error([\"*modeBarButtons* configuration options\",\"invalid button name\"].join(\" \"));t[e][n]=s[i]}}return t}(u):!r.displayModeBar&&r.watermark?[]:function(t){var e=t._fullLayout,r=t._fullData,o=t._context,l=o.modeBarButtonsToRemove,c=o.modeBarButtonsToAdd,u=e._has(\"cartesian\"),h=e._has(\"gl3d\"),f=e._has(\"geo\"),p=e._has(\"pie\"),d=e._has(\"funnelarea\"),g=e._has(\"gl2d\"),v=e._has(\"ternary\"),m=e._has(\"mapbox\"),y=e._has(\"polar\"),x=e._has(\"sankey\"),b=function(t){for(var e=n.list({_fullLayout:t},null,!0),r=0;r<e.length;r++)if(!e[r].fixedrange)return!1;return!0}(e),_=[];function w(t){if(t.length){for(var e=[],r=0;r<t.length;r++){var n=t[r];-1===l.indexOf(n)&&e.push(s[n])}_.push(e)}}var k=[\"toImage\"];o.showEditInChartStudio?k.push(\"editInChartStudio\"):o.showSendToCloud&&k.push(\"sendDataToCloud\");w(k);var T=[],A=[],M=[],S=[];(u||g||p||d||v)+f+h+m+y>1?(A=[\"toggleHover\"],M=[\"resetViews\"]):f?(T=[\"zoomInGeo\",\"zoomOutGeo\"],A=[\"hoverClosestGeo\"],M=[\"resetGeo\"]):h?(A=[\"hoverClosest3d\"],M=[\"resetCameraDefault3d\",\"resetCameraLastSave3d\"]):m?(A=[\"toggleHover\"],M=[\"resetViewMapbox\"]):g?A=[\"hoverClosestGl2d\"]:p?A=[\"hoverClosestPie\"]:x?(A=[\"hoverClosestCartesian\",\"hoverCompareCartesian\"],M=[\"resetViewSankey\"]):A=[\"toggleHover\"];u&&(A=[\"toggleSpikelines\",\"hoverClosestCartesian\",\"hoverCompareCartesian\"]);(function(t){for(var e=0;e<t.length;e++)if(!a.traceIs(t[e],\"noHover\"))return!1;return!0})(r)&&(A=[]);!u&&!g||b||(T=[\"zoomIn2d\",\"zoomOut2d\",\"autoScale2d\"],\"resetViews\"!==M[0]&&(M=[\"resetScale2d\"]));h?S=[\"zoom3d\",\"pan3d\",\"orbitRotation\",\"tableRotation\"]:(u||g)&&!b||v?S=[\"zoom2d\",\"pan2d\"]:m||f?S=[\"pan2d\"]:y&&(S=[\"zoom2d\"]);(function(t){for(var e=!1,r=0;r<t.length&&!e;r++){var n=t[r];n._module&&n._module.selectPoints&&(a.traceIs(n,\"scatter-like\")?(i.hasMarkers(n)||i.hasText(n))&&(e=!0):a.traceIs(n,\"box-violin\")&&\"all\"!==n.boxpoints&&\"all\"!==n.points||(e=!0))}return e})(r)&&S.push(\"select2d\",\"lasso2d\");return w(S),w(T.concat(M)),w(A),function(t,e){if(e.length)if(Array.isArray(e[0]))for(var r=0;r<e.length;r++)t.push(e[r]);else t.push(e);return t}(_,c)}(t),l?l.update(t,c):e._modeBar=o(t,c)}else l&&(l.destroy(),delete e._modeBar)}},{\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../../traces/scatter/subtypes\":1135,\"./buttons\":651,\"./modebar\":654}],654:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../fonts/ploticon\"),s=new DOMParser;function l(t){this.container=t.container,this.element=document.createElement(\"div\"),this.update(t.graphInfo,t.buttons),this.container.appendChild(this.element)}var c=l.prototype;c.update=function(t,e){this.graphInfo=t;var r=this.graphInfo._context,n=this.graphInfo._fullLayout,i=\"modebar-\"+n._uid;this.element.setAttribute(\"id\",i),this._uid=i,this.element.className=\"modebar\",\"hover\"===r.displayModeBar&&(this.element.className+=\" modebar--hover ease-bg\"),\"v\"===n.modebar.orientation&&(this.element.className+=\" vertical\",e=e.reverse());var o=n.modebar,s=\"hover\"===r.displayModeBar?\".js-plotly-plot .plotly:hover \":\"\";a.deleteRelatedStyleRule(i),a.addRelatedStyleRule(i,s+\"#\"+i+\" .modebar-group\",\"background-color: \"+o.bgcolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn .icon path\",\"fill: \"+o.color),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn:hover .icon path\",\"fill: \"+o.activecolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn.active .icon path\",\"fill: \"+o.activecolor);var l=!this.hasButtons(e),c=this.hasLogo!==r.displaylogo,u=this.locale!==r.locale;if(this.locale=r.locale,(l||c||u)&&(this.removeAllButtons(),this.updateButtons(e),r.watermark||r.displaylogo)){var h=this.getLogo();r.watermark&&(h.className=h.className+\" watermark\"),\"v\"===n.modebar.orientation?this.element.insertBefore(h,this.element.childNodes[0]):this.element.appendChild(h),this.hasLogo=!0}this.updateActiveButton()},c.updateButtons=function(t){var e=this;this.buttons=t,this.buttonElements=[],this.buttonsNames=[],this.buttons.forEach(function(t){var r=e.createGroup();t.forEach(function(t){var n=t.name;if(!n)throw new Error(\"must provide button 'name' in button config\");if(-1!==e.buttonsNames.indexOf(n))throw new Error(\"button name '\"+n+\"' is taken\");e.buttonsNames.push(n);var i=e.createButton(t);e.buttonElements.push(i),r.appendChild(i)}),e.element.appendChild(r)})},c.createGroup=function(){var t=document.createElement(\"div\");return t.className=\"modebar-group\",t},c.createButton=function(t){var e=this,r=document.createElement(\"a\");r.setAttribute(\"rel\",\"tooltip\"),r.className=\"modebar-btn\";var i=t.title;void 0===i?i=t.name:\"function\"==typeof i&&(i=i(this.graphInfo)),(i||0===i)&&r.setAttribute(\"data-title\",i),void 0!==t.attr&&r.setAttribute(\"data-attr\",t.attr);var a=t.val;if(void 0!==a&&(\"function\"==typeof a&&(a=a(this.graphInfo)),r.setAttribute(\"data-val\",a)),\"function\"!=typeof t.click)throw new Error(\"must provide button 'click' function in button config\");r.addEventListener(\"click\",function(r){t.click(e.graphInfo,r),e.updateActiveButton(r.currentTarget)}),r.setAttribute(\"data-toggle\",t.toggle||!1),t.toggle&&n.select(r).classed(\"active\",!0);var s=t.icon;return\"function\"==typeof s?r.appendChild(s()):r.appendChild(this.createIcon(s||o.question)),r.setAttribute(\"data-gravity\",t.gravity||\"n\"),r},c.createIcon=function(t){var e,r=i(t.height)?Number(t.height):t.ascent-t.descent,n=\"http://www.w3.org/2000/svg\";if(t.path){(e=document.createElementNS(n,\"svg\")).setAttribute(\"viewBox\",[0,0,t.width,r].join(\" \")),e.setAttribute(\"class\",\"icon\");var a=document.createElementNS(n,\"path\");a.setAttribute(\"d\",t.path),t.transform?a.setAttribute(\"transform\",t.transform):void 0!==t.ascent&&a.setAttribute(\"transform\",\"matrix(1 0 0 -1 0 \"+t.ascent+\")\"),e.appendChild(a)}t.svg&&(e=s.parseFromString(t.svg,\"application/xml\").childNodes[0]);return e.setAttribute(\"height\",\"1em\"),e.setAttribute(\"width\",\"1em\"),e},c.updateActiveButton=function(t){var e=this.graphInfo._fullLayout,r=void 0!==t?t.getAttribute(\"data-attr\"):null;this.buttonElements.forEach(function(t){var i=t.getAttribute(\"data-val\")||!0,o=t.getAttribute(\"data-attr\"),s=\"true\"===t.getAttribute(\"data-toggle\"),l=n.select(t);if(s)o===r&&l.classed(\"active\",!l.classed(\"active\"));else{var c=null===o?o:a.nestedProperty(e,o).get();l.classed(\"active\",c===i)}})},c.hasButtons=function(t){var e=this.buttons;if(!e)return!1;if(t.length!==e.length)return!1;for(var r=0;r<t.length;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;n++)if(t[r][n].name!==e[r][n].name)return!1}return!0},c.getLogo=function(){var t=this.createGroup(),e=document.createElement(\"a\");return e.href=\"https://plot.ly/\",e.target=\"_blank\",e.setAttribute(\"data-title\",a._(this.graphInfo,\"Produced with Plotly\")),e.className=\"modebar-btn plotlyjsicon modebar-btn--logo\",e.appendChild(this.createIcon(o.newplotlylogo)),t.appendChild(e),t},c.removeAllButtons=function(){for(;this.element.firstChild;)this.element.removeChild(this.element.firstChild);this.hasLogo=!1},c.destroy=function(){a.removeElement(this.container.querySelector(\".modebar\")),a.deleteRelatedStyleRule(this._uid)},e.exports=function(t,e){var r=t._fullLayout,i=new l({graphInfo:t,container:r._modebardiv.node(),buttons:e});return r._privateplot&&n.select(i.element).append(\"span\").classed(\"badge-private float--left\",!0).text(\"PRIVATE\"),i}},{\"../../fonts/ploticon\":699,\"../../lib\":719,d3:163,\"fast-isnumeric\":225}],655:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=(0,t(\"../../plot_api/plot_template\").templatedArray)(\"button\",{visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},step:{valType:\"enumerated\",values:[\"month\",\"year\",\"day\",\"hour\",\"minute\",\"second\",\"all\"],dflt:\"month\",editType:\"plot\"},stepmode:{valType:\"enumerated\",values:[\"backward\",\"todate\"],dflt:\"backward\",editType:\"plot\"},count:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},label:{valType:\"string\",editType:\"plot\"},editType:\"plot\"});e.exports={visible:{valType:\"boolean\",editType:\"plot\"},buttons:a,x:{valType:\"number\",min:-2,max:3,editType:\"plot\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"plot\"},y:{valType:\"number\",min:-2,max:3,editType:\"plot\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"bottom\",editType:\"plot\"},font:n({editType:\"plot\"}),bgcolor:{valType:\"color\",dflt:i.lightLine,editType:\"plot\"},activecolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"plot\"}},{\"../../plot_api/plot_template\":757,\"../../plots/font_attributes\":793,\"../color/attributes\":592}],656:[function(t,e,r){\"use strict\";e.exports={yPad:.02,minButtonWidth:30,rx:3,ry:3,lightAmount:25,darkAmount:10}},{}],657:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../../plots/array_container_defaults\"),s=t(\"./attributes\"),l=t(\"./constants\");function c(t,e,r,i){var a=i.calendar;function o(r,i){return n.coerce(t,e,s.buttons,r,i)}if(o(\"visible\")){var l=o(\"step\");\"all\"!==l&&(!a||\"gregorian\"===a||\"month\"!==l&&\"year\"!==l?o(\"stepmode\"):e.stepmode=\"backward\",o(\"count\")),o(\"label\")}}e.exports=function(t,e,r,u,h){var f=t.rangeselector||{},p=a.newContainer(e,\"rangeselector\");function d(t,e){return n.coerce(f,p,s,t,e)}if(d(\"visible\",o(f,p,{name:\"buttons\",handleItemDefaults:c,calendar:h}).length>0)){var g=function(t,e,r){for(var n=r.filter(function(r){return e[r].anchor===t._id}),i=0,a=0;a<n.length;a++){var o=e[n[a]].domain;o&&(i=Math.max(o[1],i))}return[t.domain[0],i+l.yPad]}(e,r,u);d(\"x\",g[0]),d(\"y\",g[1]),n.noneOrAll(t,e,[\"x\",\"y\"]),d(\"xanchor\"),d(\"yanchor\"),n.coerceFont(d,\"font\",r.font);var v=d(\"bgcolor\");d(\"activecolor\",i.contrast(v,l.lightAmount,l.darkAmount)),d(\"bordercolor\"),d(\"borderwidth\")}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/array_container_defaults\":763,\"../color\":593,\"./attributes\":655,\"./constants\":656}],658:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../color\"),s=t(\"../drawing\"),l=t(\"../../lib\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"../../plots/cartesian/axis_ids\"),h=t(\"../../constants/alignment\"),f=h.LINE_SPACING,p=h.FROM_TL,d=h.FROM_BR,g=t(\"./constants\"),v=t(\"./get_update_object\");function m(t){return t._id}function y(t,e,r){var n=l.ensureSingle(t,\"rect\",\"selector-rect\",function(t){t.attr(\"shape-rendering\",\"crispEdges\")});n.attr({rx:g.rx,ry:g.ry}),n.call(o.stroke,e.bordercolor).call(o.fill,function(t,e){return e._isActive||e._isHovered?t.activecolor:t.bgcolor}(e,r)).style(\"stroke-width\",e.borderwidth+\"px\")}function x(t,e,r,n){l.ensureSingle(t,\"text\",\"selector-text\",function(t){t.classed(\"user-select-none\",!0).attr(\"text-anchor\",\"middle\")}).call(s.font,e.font).text(function(t,e){if(t.label)return e?l.templateString(t.label,e):t.label;return\"all\"===t.step?\"all\":t.count+t.step.charAt(0)}(r,n._fullLayout._meta)).call(function(t){c.convertToTspans(t,n)})}e.exports=function(t){var e=t._fullLayout._infolayer.selectAll(\".rangeselector\").data(function(t){for(var e=u.list(t,\"x\",!0),r=[],n=0;n<e.length;n++){var i=e[n];i.rangeselector&&i.rangeselector.visible&&r.push(i)}return r}(t),m);e.enter().append(\"g\").classed(\"rangeselector\",!0),e.exit().remove(),e.style({cursor:\"pointer\",\"pointer-events\":\"all\"}),e.each(function(e){var r=n.select(this),o=e,u=o.rangeselector,h=r.selectAll(\"g.button\").data(l.filterVisible(u.buttons));h.enter().append(\"g\").classed(\"button\",!0),h.exit().remove(),h.each(function(e){var r=n.select(this),a=v(o,e);e._isActive=function(t,e,r){if(\"all\"===e.step)return!0===t.autorange;var n=Object.keys(r);return t.range[0]===r[n[0]]&&t.range[1]===r[n[1]]}(o,e,a),r.call(y,u,e),r.call(x,u,e,t),r.on(\"click\",function(){t._dragged||i.call(\"_guiRelayout\",t,a)}),r.on(\"mouseover\",function(){e._isHovered=!0,r.call(y,u,e)}),r.on(\"mouseout\",function(){e._isHovered=!1,r.call(y,u,e)})}),function(t,e,r,i,o){var u=0,h=0,v=r.borderwidth;e.each(function(){var t=n.select(this),e=t.select(\".selector-text\"),i=r.font.size*f,a=Math.max(i*c.lineCount(e),16)+3;h=Math.max(h,a)}),e.each(function(){var t=n.select(this),e=t.select(\".selector-rect\"),i=t.select(\".selector-text\"),a=i.node()&&s.bBox(i.node()).width,o=r.font.size*f,l=c.lineCount(i),p=Math.max(a+10,g.minButtonWidth);t.attr(\"transform\",\"translate(\"+(v+u)+\",\"+v+\")\"),e.attr({x:0,y:0,width:p,height:h}),c.positionText(i,p/2,h/2-(l-1)*o/2+3),u+=p+5});var m=t._fullLayout._size,y=m.l+m.w*r.x,x=m.t+m.h*(1-r.y),b=\"left\";l.isRightAnchor(r)&&(y-=u,b=\"right\");l.isCenterAnchor(r)&&(y-=u/2,b=\"center\");var _=\"top\";l.isBottomAnchor(r)&&(x-=h,_=\"bottom\");l.isMiddleAnchor(r)&&(x-=h/2,_=\"middle\");u=Math.ceil(u),h=Math.ceil(h),y=Math.round(y),x=Math.round(x),a.autoMargin(t,i+\"-range-selector\",{x:r.x,y:r.y,l:u*p[b],r:u*d[b],b:h*d[_],t:h*p[_]}),o.attr(\"transform\",\"translate(\"+y+\",\"+x+\")\")}(t,h,u,o._name,r)})}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axis_ids\":770,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../drawing\":614,\"./constants\":656,\"./get_update_object\":659,d3:163}],659:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e){var r=t._name,i={};if(\"all\"===e.step)i[r+\".autorange\"]=!0;else{var a=function(t,e){var r,i=t.range,a=new Date(t.r2l(i[1])),o=e.step,s=e.count;switch(e.stepmode){case\"backward\":r=t.l2r(+n.time[o].utc.offset(a,-s));break;case\"todate\":var l=n.time[o].utc.offset(a,-s);r=t.l2r(+n.time[o].utc.ceil(l))}var c=i[1];return[r,c]}(t,e);i[r+\".range[0]\"]=a[0],i[r+\".range[1]\"]=a[1]}return i}},{d3:163}],660:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"rangeselector\",schema:{subplots:{xaxis:{rangeselector:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":655,\"./defaults\":657,\"./draw\":658}],661:[function(t,e,r){\"use strict\";var n=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",dflt:n.background,editType:\"plot\"},bordercolor:{valType:\"color\",dflt:n.defaultLine,editType:\"plot\"},borderwidth:{valType:\"integer\",dflt:0,min:0,editType:\"plot\"},autorange:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}}],editType:\"calc\",impliedEdits:{autorange:!1}},thickness:{valType:\"number\",dflt:.15,min:0,max:1,editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"}},{\"../color/attributes\":592}],662:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\").list,i=t(\"../../plots/cartesian/autorange\").getAutoRange,a=t(\"./constants\");e.exports=function(t){for(var e=n(t,\"x\",!0),r=0;r<e.length;r++){var o=e[r],s=o[a.name];s&&s.visible&&s.autorange&&(s._input.autorange=!0,s._input.range=s.range=i(t,o))}}},{\"../../plots/cartesian/autorange\":766,\"../../plots/cartesian/axis_ids\":770,\"./constants\":663}],663:[function(t,e,r){\"use strict\";e.exports={name:\"rangeslider\",containerClassName:\"rangeslider-container\",bgClassName:\"rangeslider-bg\",rangePlotClassName:\"rangeslider-rangeplot\",maskMinClassName:\"rangeslider-mask-min\",maskMaxClassName:\"rangeslider-mask-max\",slideBoxClassName:\"rangeslider-slidebox\",grabberMinClassName:\"rangeslider-grabber-min\",grabAreaMinClassName:\"rangeslider-grabarea-min\",handleMinClassName:\"rangeslider-handle-min\",grabberMaxClassName:\"rangeslider-grabber-max\",grabAreaMaxClassName:\"rangeslider-grabarea-max\",handleMaxClassName:\"rangeslider-handle-max\",maskMinOppAxisClassName:\"rangeslider-mask-min-opp-axis\",maskMaxOppAxisClassName:\"rangeslider-mask-max-opp-axis\",maskColor:\"rgba(0,0,0,0.4)\",maskOppAxisColor:\"rgba(0,0,0,0.2)\",slideBoxFill:\"transparent\",slideBoxCursor:\"ew-resize\",grabAreaFill:\"transparent\",grabAreaCursor:\"col-resize\",grabAreaWidth:10,handleWidth:4,handleRadius:1,handleStrokeWidth:1,extraPad:15}},{}],664:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"./attributes\"),s=t(\"./oppaxis_attributes\");e.exports=function(t,e,r){var l=t[r],c=e[r];if(l.rangeslider||e._requestRangeslider[c._id]){n.isPlainObject(l.rangeslider)||(l.rangeslider={});var u,h,f=l.rangeslider,p=i.newContainer(c,\"rangeslider\");if(_(\"visible\")){_(\"bgcolor\",e.plot_bgcolor),_(\"bordercolor\"),_(\"borderwidth\"),_(\"thickness\"),_(\"autorange\",!c.isValidRange(f.range)),_(\"range\");var d=e._subplots;if(d)for(var g=d.cartesian.filter(function(t){return t.substr(0,t.indexOf(\"y\"))===a.name2id(r)}).map(function(t){return t.substr(t.indexOf(\"y\"),t.length)}),v=n.simpleMap(g,a.id2name),m=0;m<v.length;m++){var y=v[m];u=f[y]||{},h=i.newContainer(p,y,\"yaxis\");var x,b=e[y];u.range&&b.isValidRange(u.range)&&(x=\"fixed\"),\"match\"!==w(\"rangemode\",x)&&w(\"range\",b.range.slice())}p._input=f}}function _(t,e){return n.coerce(f,p,o,t,e)}function w(t,e){return n.coerce(u,h,s,t,e)}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/axis_ids\":770,\"./attributes\":661,\"./oppaxis_attributes\":668}],665:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=t(\"../drawing\"),l=t(\"../color\"),c=t(\"../titles\"),u=t(\"../../plots/cartesian\"),h=t(\"../../plots/cartesian/axis_ids\"),f=t(\"../dragelement\"),p=t(\"../../lib/setcursor\"),d=t(\"./constants\");function g(t,e,r,n){var i=o.ensureSingle(t,\"rect\",d.bgClassName,function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})}),a=n.borderwidth%2==0?n.borderwidth:n.borderwidth-1,l=-n._offsetShift,c=s.crispRound(e,n.borderwidth);i.attr({width:n._width+a,height:n._height+a,transform:\"translate(\"+l+\",\"+l+\")\",fill:n.bgcolor,stroke:n.bordercolor,\"stroke-width\":c})}function v(t,e,r,n){var i=e._fullLayout;o.ensureSingleById(i._topdefs,\"clipPath\",n._clipId,function(t){t.append(\"rect\").attr({x:0,y:0})}).select(\"rect\").attr({width:n._width,height:n._height})}function m(t,e,r,i){var l,c=e.calcdata,f=t.selectAll(\"g.\"+d.rangePlotClassName).data(r._subplotsWith,o.identity);f.enter().append(\"g\").attr(\"class\",function(t){return d.rangePlotClassName+\" \"+t}).call(s.setClipUrl,i._clipId,e),f.order(),f.exit().remove(),f.each(function(t,o){var s=n.select(this),f=0===o,p=h.getFromId(e,t,\"y\"),d=p._name,g=i[d],v={data:[],layout:{xaxis:{type:r.type,domain:[0,1],range:i.range.slice(),calendar:r.calendar},width:i._width,height:i._height,margin:{t:0,b:0,l:0,r:0}},_context:e._context};v.layout[d]={type:p.type,domain:[0,1],range:\"match\"!==g.rangemode?g.range.slice():p.range.slice(),calendar:p.calendar},a.supplyDefaults(v);var m=v._fullLayout.xaxis,y=v._fullLayout[d];m.clearCalc(),m.setScale(),y.clearCalc(),y.setScale();var x={id:t,plotgroup:s,xaxis:m,yaxis:y,isRangePlot:!0};f?l=x:(x.mainplot=\"xy\",x.mainplotinfo=l),u.rangePlot(e,x,function(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n],a=i[0].trace;a.xaxis+a.yaxis===e&&r.push(i)}return r}(c,t))})}function y(t,e,r,n,i){(o.ensureSingle(t,\"rect\",d.maskMinClassName,function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"height\",n._height).call(l.fill,d.maskColor),o.ensureSingle(t,\"rect\",d.maskMaxClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"height\",n._height).call(l.fill,d.maskColor),\"match\"!==i.rangemode)&&(o.ensureSingle(t,\"rect\",d.maskMinOppAxisClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"width\",n._width).call(l.fill,d.maskOppAxisColor),o.ensureSingle(t,\"rect\",d.maskMaxOppAxisClassName,function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})}).attr(\"width\",n._width).style(\"border-top\",d.maskOppBorder).call(l.fill,d.maskOppAxisColor))}function x(t,e,r,n){e._context.staticPlot||o.ensureSingle(t,\"rect\",d.slideBoxClassName,function(t){t.attr({y:0,cursor:d.slideBoxCursor,\"shape-rendering\":\"crispEdges\"})}).attr({height:n._height,fill:d.slideBoxFill})}function b(t,e,r,n){var i=o.ensureSingle(t,\"g\",d.grabberMinClassName),a=o.ensureSingle(t,\"g\",d.grabberMaxClassName),s={x:0,width:d.handleWidth,rx:d.handleRadius,fill:l.background,stroke:l.defaultLine,\"stroke-width\":d.handleStrokeWidth,\"shape-rendering\":\"crispEdges\"},c={y:Math.round(n._height/4),height:Math.round(n._height/2)};if(o.ensureSingle(i,\"rect\",d.handleMinClassName,function(t){t.attr(s)}).attr(c),o.ensureSingle(a,\"rect\",d.handleMaxClassName,function(t){t.attr(s)}).attr(c),!e._context.staticPlot){var u={width:d.grabAreaWidth,x:0,y:0,fill:d.grabAreaFill,cursor:d.grabAreaCursor};o.ensureSingle(i,\"rect\",d.grabAreaMinClassName,function(t){t.attr(u)}).attr(\"height\",n._height),o.ensureSingle(a,\"rect\",d.grabAreaMaxClassName,function(t){t.attr(u)}).attr(\"height\",n._height)}}e.exports=function(t){for(var e=t._fullLayout,r=e._rangeSliderData,a=0;a<r.length;a++){var s=r[a][d.name];s._clipId=s._id+\"-\"+e._uid}var l=e._infolayer.selectAll(\"g.\"+d.containerClassName).data(r,function(t){return t._name});l.exit().each(function(t){var r=t[d.name];e._topdefs.select(\"#\"+r._clipId).remove()}).remove(),0!==r.length&&(l.enter().append(\"g\").classed(d.containerClassName,!0).attr(\"pointer-events\",\"all\"),l.each(function(r){var a=n.select(this),s=r[d.name],l=e[h.id2name(r.anchor)],u=s[h.id2name(r.anchor)];if(s.range){var _,w=o.simpleMap(s.range,r.r2l),k=o.simpleMap(r.range,r.r2l);_=k[0]<k[1]?[Math.min(w[0],k[0]),Math.max(w[1],k[1])]:[Math.max(w[0],k[0]),Math.min(w[1],k[1])],s.range=s._input.range=o.simpleMap(_,r.l2r)}r.cleanRange(\"rangeslider.range\");var T=e.margin,A=e._size,M=r.domain,S=s._tickHeight,E=s._oppBottom;s._width=A.w*(M[1]-M[0]);var C=Math.round(T.l+A.w*M[0]),L=Math.round(A.t+A.h*(1-E)+S+s._offsetShift+d.extraPad);a.attr(\"transform\",\"translate(\"+C+\",\"+L+\")\");var P=r.r2l(s.range[0]),O=r.r2l(s.range[1]),z=O-P;if(s.p2d=function(t){return t/s._width*z+P},s.d2p=function(t){return(t-P)/z*s._width},s._rl=[P,O],\"match\"!==u.rangemode){var I=l.r2l(u.range[0]),D=l.r2l(u.range[1])-I;s.d2pOppAxis=function(t){return(t-I)/D*s._height}}a.call(g,t,r,s).call(v,t,r,s).call(m,t,r,s).call(y,t,r,s,u).call(x,t,r,s).call(b,t,r,s),function(t,e,r,a){var s=t.select(\"rect.\"+d.slideBoxClassName).node(),l=t.select(\"rect.\"+d.grabAreaMinClassName).node(),c=t.select(\"rect.\"+d.grabAreaMaxClassName).node();t.on(\"mousedown\",function(){var u=n.event,h=u.target,d=u.clientX,g=d-t.node().getBoundingClientRect().left,v=a.d2p(r._rl[0]),m=a.d2p(r._rl[1]),y=f.coverSlip();function x(t){var u,f,x,b=+t.clientX-d;switch(h){case s:x=\"ew-resize\",u=v+b,f=m+b;break;case l:x=\"col-resize\",u=v+b,f=m;break;case c:x=\"col-resize\",u=v,f=m+b;break;default:x=\"ew-resize\",u=g,f=g+b}if(f<u){var _=f;f=u,u=_}a._pixelMin=u,a._pixelMax=f,p(n.select(y),x),function(t,e,r,n){function a(t){return r.l2r(o.constrain(t,n._rl[0],n._rl[1]))}var s=a(n.p2d(n._pixelMin)),l=a(n.p2d(n._pixelMax));window.requestAnimationFrame(function(){i.call(\"_guiRelayout\",e,r._name+\".range\",[s,l])})}(0,e,r,a)}y.addEventListener(\"mousemove\",x),y.addEventListener(\"mouseup\",function t(){y.removeEventListener(\"mousemove\",x);y.removeEventListener(\"mouseup\",t);o.removeElement(y)})})}(a,t,r,s),function(t,e,r,n,i,a){var s=d.handleWidth/2;function l(t){return o.constrain(t,0,n._width)}function c(t){return o.constrain(t,0,n._height)}function u(t){return o.constrain(t,-s,n._width+s)}var h=l(n.d2p(r._rl[0])),f=l(n.d2p(r._rl[1]));if(t.select(\"rect.\"+d.slideBoxClassName).attr(\"x\",h).attr(\"width\",f-h),t.select(\"rect.\"+d.maskMinClassName).attr(\"width\",h),t.select(\"rect.\"+d.maskMaxClassName).attr(\"x\",f).attr(\"width\",n._width-f),\"match\"!==a.rangemode){var p=n._height-c(n.d2pOppAxis(i._rl[1])),g=n._height-c(n.d2pOppAxis(i._rl[0]));t.select(\"rect.\"+d.maskMinOppAxisClassName).attr(\"x\",h).attr(\"height\",p).attr(\"width\",f-h),t.select(\"rect.\"+d.maskMaxOppAxisClassName).attr(\"x\",h).attr(\"y\",g).attr(\"height\",n._height-g).attr(\"width\",f-h),t.select(\"rect.\"+d.slideBoxClassName).attr(\"y\",p).attr(\"height\",g-p)}var v=Math.round(u(h-s))-.5,m=Math.round(u(f-s))+.5;t.select(\"g.\"+d.grabberMinClassName).attr(\"transform\",\"translate(\"+v+\",0.5)\"),t.select(\"g.\"+d.grabberMaxClassName).attr(\"transform\",\"translate(\"+m+\",0.5)\")}(a,0,r,s,l,u),\"bottom\"===r.side&&c.draw(t,r._id+\"title\",{propContainer:r,propName:r._name+\".title\",placeholder:e._dfltTitle.x,attributes:{x:r._offset+r._length/2,y:L+s._height+s._offsetShift+10+1.5*r.title.font.size,\"text-anchor\":\"middle\"}})}))}},{\"../../lib\":719,\"../../lib/setcursor\":739,\"../../plots/cartesian\":778,\"../../plots/cartesian/axis_ids\":770,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"../titles\":681,\"./constants\":663,d3:163}],666:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"./constants\"),a=i.name;function o(t){var e=t&&t[a];return e&&e.visible}r.isVisible=o,r.makeData=function(t){var e=n.list({_fullLayout:t},\"x\",!0),r=t.margin,i=[];if(!t._has(\"gl2d\"))for(var s=0;s<e.length;s++){var l=e[s];if(o(l)){i.push(l);var c=l[a];c._id=a+l._id,c._height=(t.height-r.b-r.t)*c.thickness,c._offsetShift=Math.floor(c.borderwidth/2)}}t._rangeSliderData=i},r.autoMarginOpts=function(t,e){for(var r=e[a],o=1/0,s=e._counterAxes,l=0;l<s.length;l++){var c=s[l],u=n.getFromId(t,c);o=Math.min(o,u.domain[0])}r._oppBottom=o;var h=\"bottom\"===e.side&&e._boundingBox.height||0;return r._tickHeight=h,{x:0,y:o,l:0,r:0,t:0,b:r._height+t._fullLayout.margin.b+h,pad:i.extraPad+2*r._offsetShift}}},{\"../../plots/cartesian/axis_ids\":770,\"./constants\":663}],667:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./oppaxis_attributes\"),o=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"rangeslider\",schema:{subplots:{xaxis:{rangeslider:n.extendFlat({},i,{yaxis:a})}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),calcAutorange:t(\"./calc_autorange\"),draw:t(\"./draw\"),isVisible:o.isVisible,makeData:o.makeData,autoMarginOpts:o.autoMarginOpts}},{\"../../lib\":719,\"./attributes\":661,\"./calc_autorange\":662,\"./defaults\":664,\"./draw\":665,\"./helpers\":666,\"./oppaxis_attributes\":668}],668:[function(t,e,r){\"use strict\";e.exports={_isSubplotObj:!0,rangemode:{valType:\"enumerated\",values:[\"auto\",\"fixed\",\"match\"],dflt:\"match\",editType:\"calc\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"plot\"},{valType:\"any\",editType:\"plot\"}],editType:\"plot\"},editType:\"calc\"}},{}],669:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../traces/scatter/attributes\").line,a=t(\"../drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray;e.exports=s(\"shape\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},type:{valType:\"enumerated\",values:[\"circle\",\"rect\",\"path\",\"line\"],editType:\"calc+arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},xref:o({},n.xref,{}),xsizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},xanchor:{valType:\"any\",editType:\"calc+arraydraw\"},x0:{valType:\"any\",editType:\"calc+arraydraw\"},x1:{valType:\"any\",editType:\"calc+arraydraw\"},yref:o({},n.yref,{}),ysizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},yanchor:{valType:\"any\",editType:\"calc+arraydraw\"},y0:{valType:\"any\",editType:\"calc+arraydraw\"},y1:{valType:\"any\",editType:\"calc+arraydraw\"},path:{valType:\"string\",editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},line:{color:o({},i.color,{editType:\"arraydraw\"}),width:o({},i.width,{editType:\"calc+arraydraw\"}),dash:o({},a,{editType:\"arraydraw\"}),editType:\"calc+arraydraw\"},fillcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},editType:\"arraydraw\"})},{\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../../traces/scatter/attributes\":1112,\"../annotations/attributes\":576,\"../drawing/attributes\":613}],670:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./constants\"),o=t(\"./helpers\");function s(t){return c(t.line.width,t.xsizemode,t.x0,t.x1,t.path,!1)}function l(t){return c(t.line.width,t.ysizemode,t.y0,t.y1,t.path,!0)}function c(t,e,r,i,s,l){var c=t/2,u=l;if(\"pixel\"===e){var h=s?o.extractPathCoords(s,l?a.paramIsY:a.paramIsX):[r,i],f=n.aggNums(Math.max,null,h),p=n.aggNums(Math.min,null,h),d=p<0?Math.abs(p)+c:c,g=f>0?f+c:c;return{ppad:c,ppadplus:u?d:g,ppadminus:u?g:d}}return{ppad:c}}function u(t,e,r,n,i){var s=\"category\"===t.type||\"multicategory\"===t.type?t.r2c:t.d2c;if(void 0!==e)return[s(e),s(r)];if(n){var l,c,u,h,f=1/0,p=-1/0,d=n.match(a.segmentRE);for(\"date\"===t.type&&(s=o.decodeDate(s)),l=0;l<d.length;l++)void 0!==(c=i[d[l].charAt(0)].drawn)&&(!(u=d[l].substr(1).match(a.paramRE))||u.length<c||((h=s(u[c]))<f&&(f=h),h>p&&(p=h)));return p>=f?[f,p]:void 0}}e.exports=function(t){var e=t._fullLayout,r=n.filterVisible(e.shapes);if(r.length&&t._fullData.length)for(var o=0;o<r.length;o++){var c,h,f=r[o];if(f._extremes={},\"paper\"!==f.xref){var p=\"pixel\"===f.xsizemode?f.xanchor:f.x0,d=\"pixel\"===f.xsizemode?f.xanchor:f.x1;(h=u(c=i.getFromId(t,f.xref),p,d,f.path,a.paramIsX))&&(f._extremes[c._id]=i.findExtremes(c,h,s(f)))}if(\"paper\"!==f.yref){var g=\"pixel\"===f.ysizemode?f.yanchor:f.y0,v=\"pixel\"===f.ysizemode?f.yanchor:f.y1;(h=u(c=i.getFromId(t,f.yref),g,v,f.path,a.paramIsY))&&(f._extremes[c._id]=i.findExtremes(c,h,l(f)))}}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./constants\":671,\"./helpers\":674}],671:[function(t,e,r){\"use strict\";e.exports={segmentRE:/[MLHVQCTSZ][^MLHVQCTSZ]*/g,paramRE:/[^\\s,]+/g,paramIsX:{M:{0:!0,drawn:0},L:{0:!0,drawn:0},H:{0:!0,drawn:0},V:{},Q:{0:!0,2:!0,drawn:2},C:{0:!0,2:!0,4:!0,drawn:4},T:{0:!0,drawn:0},S:{0:!0,2:!0,drawn:2},Z:{}},paramIsY:{M:{1:!0,drawn:1},L:{1:!0,drawn:1},H:{},V:{0:!0,drawn:0},Q:{1:!0,3:!0,drawn:3},C:{1:!0,3:!0,5:!0,drawn:5},T:{1:!0,drawn:1},S:{1:!0,3:!0,drawn:5},Z:{}},numParams:{M:2,L:2,H:1,V:1,Q:4,C:6,T:2,S:4,Z:0}}},{}],672:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\"),s=t(\"./helpers\");function l(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}if(a(\"visible\")){a(\"layer\"),a(\"opacity\"),a(\"fillcolor\"),a(\"line.color\"),a(\"line.width\"),a(\"line.dash\");for(var l=a(\"type\",t.path?\"path\":\"rect\"),c=a(\"xsizemode\"),u=a(\"ysizemode\"),h=[\"x\",\"y\"],f=0;f<2;f++){var p,d,g,v=h[f],m=v+\"anchor\",y=\"x\"===v?c:u,x={_fullLayout:r},b=i.coerceRef(t,e,x,v,\"\",\"paper\");if(\"paper\"!==b?((p=i.getFromId(x,b))._shapeIndices.push(e._index),g=s.rangeToShapePosition(p),d=s.shapePositionToRange(p)):d=g=n.identity,\"path\"!==l){var _=v+\"0\",w=v+\"1\",k=t[_],T=t[w];t[_]=d(t[_],!0),t[w]=d(t[w],!0),\"pixel\"===y?(a(_,0),a(w,10)):(i.coercePosition(e,x,a,b,_,.25),i.coercePosition(e,x,a,b,w,.75)),e[_]=g(e[_]),e[w]=g(e[w]),t[_]=k,t[w]=T}if(\"pixel\"===y){var A=t[m];t[m]=d(t[m],!0),i.coercePosition(e,x,a,b,m,.25),e[m]=g(e[m]),t[m]=A}}\"path\"===l?a(\"path\"):n.noneOrAll(t,e,[\"x0\",\"x1\",\"y0\",\"y1\"])}}e.exports=function(t,e){a(t,e,{name:\"shapes\",handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"./attributes\":669,\"./helpers\":674}],673:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../color\"),s=t(\"../drawing\"),l=t(\"../../plot_api/plot_template\").arrayEditor,c=t(\"../dragelement\"),u=t(\"../../lib/setcursor\"),h=t(\"./constants\"),f=t(\"./helpers\");function p(t,e){t._fullLayout._paperdiv.selectAll('.shapelayer [data-index=\"'+e+'\"]').remove();var r=t._fullLayout.shapes[e]||{};if(r._input&&!1!==r.visible)if(\"below\"!==r.layer)m(t._fullLayout._shapeUpperLayer);else if(\"paper\"===r.xref||\"paper\"===r.yref)m(t._fullLayout._shapeLowerLayer);else{var p=t._fullLayout._plots[r.xref+r.yref];if(p)m((p.mainplotinfo||p).shapelayer);else m(t._fullLayout._shapeLowerLayer)}function m(p){var m={\"data-index\":e,\"fill-rule\":\"evenodd\",d:g(t,r)},y=r.line.width?r.line.color:\"rgba(0,0,0,0)\",x=p.append(\"path\").attr(m).style(\"opacity\",r.opacity).call(o.stroke,y).call(o.fill,r.fillcolor).call(s.dashLine,r.line.dash,r.line.width);d(x,t,r),t._context.edits.shapePosition&&function(t,e,r,o,p){var m,y,x,b,_,w,k,T,A,M,S,E,C,L,P,O,z=10,I=10,D=\"pixel\"===r.xsizemode,R=\"pixel\"===r.ysizemode,F=\"line\"===r.type,B=\"path\"===r.type,N=l(t.layout,\"shapes\",r),j=N.modifyItem,U=a.getFromId(t,r.xref),V=a.getFromId(t,r.yref),q=f.getDataToPixel(t,U),H=f.getDataToPixel(t,V,!0),G=f.getPixelToData(t,U),Y=f.getPixelToData(t,V,!0),W=F?function(){var t=Math.max(r.line.width,10),n=p.append(\"g\").attr(\"data-index\",o);n.append(\"path\").attr(\"d\",e.attr(\"d\")).style({cursor:\"move\",\"stroke-width\":t,\"stroke-opacity\":\"0\"});var i={\"fill-opacity\":\"0\"},a=t/2>10?t/2:10;return n.append(\"circle\").attr({\"data-line-point\":\"start-point\",cx:D?q(r.xanchor)+r.x0:q(r.x0),cy:R?H(r.yanchor)-r.y0:H(r.y0),r:a}).style(i).classed(\"cursor-grab\",!0),n.append(\"circle\").attr({\"data-line-point\":\"end-point\",cx:D?q(r.xanchor)+r.x1:q(r.x1),cy:R?H(r.yanchor)-r.y1:H(r.y1),r:a}).style(i).classed(\"cursor-grab\",!0),n}():e,X={element:W.node(),gd:t,prepFn:function(n){D&&(_=q(r.xanchor));R&&(w=H(r.yanchor));\"path\"===r.type?P=r.path:(m=D?r.x0:q(r.x0),y=R?r.y0:H(r.y0),x=D?r.x1:q(r.x1),b=R?r.y1:H(r.y1));m<x?(A=m,C=\"x0\",M=x,L=\"x1\"):(A=x,C=\"x1\",M=m,L=\"x0\");!R&&y<b||R&&y>b?(k=y,S=\"y0\",T=b,E=\"y1\"):(k=b,S=\"y1\",T=y,E=\"y0\");Z(n),$(p,r),function(t,e,r){var n=e.xref,i=e.yref,o=a.getFromId(r,n),l=a.getFromId(r,i),c=\"\";\"paper\"===n||o.autorange||(c+=n);\"paper\"===i||l.autorange||(c+=i);s.setClipUrl(t,c?\"clip\"+r._fullLayout._uid+c:null,r)}(e,r,t),X.moveFn=\"move\"===O?J:K},doneFn:function(){u(e),Q(p),d(e,t,r),n.call(\"_guiRelayout\",t,N.getUpdateObj())},clickFn:function(){Q(p)}};function Z(t){if(F)O=\"path\"===t.target.tagName?\"move\":\"start-point\"===t.target.attributes[\"data-line-point\"].value?\"resize-over-start-point\":\"resize-over-end-point\";else{var r=X.element.getBoundingClientRect(),n=r.right-r.left,i=r.bottom-r.top,a=t.clientX-r.left,o=t.clientY-r.top,s=!B&&n>z&&i>I&&!t.shiftKey?c.getCursor(a/n,1-o/i):\"move\";u(e,s),O=s.split(\"-\")[0]}}function J(n,i){if(\"path\"===r.type){var a=function(t){return t},o=a,s=a;D?j(\"xanchor\",r.xanchor=G(_+n)):(o=function(t){return G(q(t)+n)},U&&\"date\"===U.type&&(o=f.encodeDate(o))),R?j(\"yanchor\",r.yanchor=Y(w+i)):(s=function(t){return Y(H(t)+i)},V&&\"date\"===V.type&&(s=f.encodeDate(s))),j(\"path\",r.path=v(P,o,s))}else D?j(\"xanchor\",r.xanchor=G(_+n)):(j(\"x0\",r.x0=G(m+n)),j(\"x1\",r.x1=G(x+n))),R?j(\"yanchor\",r.yanchor=Y(w+i)):(j(\"y0\",r.y0=Y(y+i)),j(\"y1\",r.y1=Y(b+i)));e.attr(\"d\",g(t,r)),$(p,r)}function K(n,i){if(B){var a=function(t){return t},o=a,s=a;D?j(\"xanchor\",r.xanchor=G(_+n)):(o=function(t){return G(q(t)+n)},U&&\"date\"===U.type&&(o=f.encodeDate(o))),R?j(\"yanchor\",r.yanchor=Y(w+i)):(s=function(t){return Y(H(t)+i)},V&&\"date\"===V.type&&(s=f.encodeDate(s))),j(\"path\",r.path=v(P,o,s))}else if(F){if(\"resize-over-start-point\"===O){var l=m+n,c=R?y-i:y+i;j(\"x0\",r.x0=D?l:G(l)),j(\"y0\",r.y0=R?c:Y(c))}else if(\"resize-over-end-point\"===O){var u=x+n,h=R?b-i:b+i;j(\"x1\",r.x1=D?u:G(u)),j(\"y1\",r.y1=R?h:Y(h))}}else{var d=~O.indexOf(\"n\")?k+i:k,N=~O.indexOf(\"s\")?T+i:T,W=~O.indexOf(\"w\")?A+n:A,X=~O.indexOf(\"e\")?M+n:M;~O.indexOf(\"n\")&&R&&(d=k-i),~O.indexOf(\"s\")&&R&&(N=T-i),(!R&&N-d>I||R&&d-N>I)&&(j(S,r[S]=R?d:Y(d)),j(E,r[E]=R?N:Y(N))),X-W>z&&(j(C,r[C]=D?W:G(W)),j(L,r[L]=D?X:G(X)))}e.attr(\"d\",g(t,r)),$(p,r)}function $(t,e){(D||R)&&function(){var r=\"path\"!==e.type,n=t.selectAll(\".visual-cue\").data([0]);n.enter().append(\"path\").attr({fill:\"#fff\",\"fill-rule\":\"evenodd\",stroke:\"#000\",\"stroke-width\":1}).classed(\"visual-cue\",!0);var a=q(D?e.xanchor:i.midRange(r?[e.x0,e.x1]:f.extractPathCoords(e.path,h.paramIsX))),o=H(R?e.yanchor:i.midRange(r?[e.y0,e.y1]:f.extractPathCoords(e.path,h.paramIsY)));if(a=f.roundPositionForSharpStrokeRendering(a,1),o=f.roundPositionForSharpStrokeRendering(o,1),D&&R){var s=\"M\"+(a-1-1)+\",\"+(o-1-1)+\"h-8v2h8 v8h2v-8 h8v-2h-8 v-8h-2 Z\";n.attr(\"d\",s)}else if(D){var l=\"M\"+(a-1-1)+\",\"+(o-9-1)+\"v18 h2 v-18 Z\";n.attr(\"d\",l)}else{var c=\"M\"+(a-9-1)+\",\"+(o-1-1)+\"h18 v2 h-18 Z\";n.attr(\"d\",c)}}()}function Q(t){t.selectAll(\".visual-cue\").remove()}c.init(X),W.node().onmousemove=Z}(t,x,r,e,p)}}function d(t,e,r){var n=(r.xref+r.yref).replace(/paper/g,\"\");s.setClipUrl(t,n?\"clip\"+e._fullLayout._uid+n:null,e)}function g(t,e){var r,n,o,s,l,c,u,p,d=e.type,g=a.getFromId(t,e.xref),v=a.getFromId(t,e.yref),m=t._fullLayout._size;if(g?(r=f.shapePositionToRange(g),n=function(t){return g._offset+g.r2p(r(t,!0))}):n=function(t){return m.l+m.w*t},v?(o=f.shapePositionToRange(v),s=function(t){return v._offset+v.r2p(o(t,!0))}):s=function(t){return m.t+m.h*(1-t)},\"path\"===d)return g&&\"date\"===g.type&&(n=f.decodeDate(n)),v&&\"date\"===v.type&&(s=f.decodeDate(s)),function(t,e,r){var n=t.path,a=t.xsizemode,o=t.ysizemode,s=t.xanchor,l=t.yanchor;return n.replace(h.segmentRE,function(t){var n=0,c=t.charAt(0),u=h.paramIsX[c],f=h.paramIsY[c],p=h.numParams[c],d=t.substr(1).replace(h.paramRE,function(t){return u[n]?t=\"pixel\"===a?e(s)+Number(t):e(t):f[n]&&(t=\"pixel\"===o?r(l)-Number(t):r(t)),++n>p&&(t=\"X\"),t});return n>p&&(d=d.replace(/[\\s,]*X.*/,\"\"),i.log(\"Ignoring extra params in segment \"+t)),c+d})}(e,n,s);if(\"pixel\"===e.xsizemode){var y=n(e.xanchor);l=y+e.x0,c=y+e.x1}else l=n(e.x0),c=n(e.x1);if(\"pixel\"===e.ysizemode){var x=s(e.yanchor);u=x-e.y0,p=x-e.y1}else u=s(e.y0),p=s(e.y1);if(\"line\"===d)return\"M\"+l+\",\"+u+\"L\"+c+\",\"+p;if(\"rect\"===d)return\"M\"+l+\",\"+u+\"H\"+c+\"V\"+p+\"H\"+l+\"Z\";var b=(l+c)/2,_=(u+p)/2,w=Math.abs(b-l),k=Math.abs(_-u),T=\"A\"+w+\",\"+k,A=b+w+\",\"+_;return\"M\"+A+T+\" 0 1,1 \"+(b+\",\"+(_-k))+T+\" 0 0,1 \"+A+\"Z\"}function v(t,e,r){return t.replace(h.segmentRE,function(t){var n=0,i=t.charAt(0),a=h.paramIsX[i],o=h.paramIsY[i],s=h.numParams[i];return i+t.substr(1).replace(h.paramRE,function(t){return n>=s?t:(a[n]?t=e(t):o[n]&&(t=r(t)),n++,t)})})}e.exports={draw:function(t){var e=t._fullLayout;for(var r in e._shapeUpperLayer.selectAll(\"path\").remove(),e._shapeLowerLayer.selectAll(\"path\").remove(),e._plots){var n=e._plots[r].shapelayer;n&&n.selectAll(\"path\").remove()}for(var i=0;i<e.shapes.length;i++)e.shapes[i].visible&&p(t,i)},drawOne:p}},{\"../../lib\":719,\"../../lib/setcursor\":739,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../color\":593,\"../dragelement\":611,\"../drawing\":614,\"./constants\":671,\"./helpers\":674}],674:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib\");r.rangeToShapePosition=function(t){return\"log\"===t.type?t.r2d:function(t){return t}},r.shapePositionToRange=function(t){return\"log\"===t.type?t.d2r:function(t){return t}},r.decodeDate=function(t){return function(e){return e.replace&&(e=e.replace(\"_\",\" \")),t(e)}},r.encodeDate=function(t){return function(e){return t(e).replace(\" \",\"_\")}},r.extractPathCoords=function(t,e){var r=[];return t.match(n.segmentRE).forEach(function(t){var a=e[t.charAt(0)].drawn;if(void 0!==a){var o=t.substr(1).match(n.paramRE);!o||o.length<a||r.push(i.cleanNumber(o[a]))}}),r},r.getDataToPixel=function(t,e,n){var i,a=t._fullLayout._size;if(e){var o=r.shapePositionToRange(e);i=function(t){return e._offset+e.r2p(o(t,!0))},\"date\"===e.type&&(i=r.decodeDate(i))}else i=n?function(t){return a.t+a.h*(1-t)}:function(t){return a.l+a.w*t};return i},r.getPixelToData=function(t,e,n){var i,a=t._fullLayout._size;if(e){var o=r.rangeToShapePosition(e);i=function(t){return o(e.p2r(t-e._offset))}}else i=n?function(t){return 1-(t-a.t)/a.h}:function(t){return(t-a.l)/a.w};return i},r.roundPositionForSharpStrokeRendering=function(t,e){var r=1===Math.round(e%2),n=Math.round(t);return r?n+.5:n}},{\"../../lib\":719,\"./constants\":671}],675:[function(t,e,r){\"use strict\";var n=t(\"./draw\");e.exports={moduleType:\"component\",name:\"shapes\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"shapes\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne}},{\"../../plots/cartesian/include_components\":777,\"./attributes\":669,\"./calc_autorange\":670,\"./defaults\":672,\"./draw\":673}],676:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/pad_attributes\"),a=t(\"../../lib/extend\").extendDeepAll,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/animation_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"./constants\"),u=l(\"step\",{visible:{valType:\"boolean\",dflt:!0},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\"},value:{valType:\"string\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"slider\",{visible:{valType:\"boolean\",dflt:!0},active:{valType:\"number\",min:0,dflt:0},steps:u,lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",min:-2,max:3,dflt:0},pad:a(i({editType:\"arraydraw\"}),{},{t:{dflt:20}}),xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\"},y:{valType:\"number\",min:-2,max:3,dflt:0},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},transition:{duration:{valType:\"number\",min:0,dflt:150},easing:{valType:\"enumerated\",values:s.transition.easing.values,dflt:\"cubic-in-out\"}},currentvalue:{visible:{valType:\"boolean\",dflt:!0},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},offset:{valType:\"number\",dflt:10},prefix:{valType:\"string\"},suffix:{valType:\"string\"},font:n({})},font:n({}),activebgcolor:{valType:\"color\",dflt:c.gripBgActiveColor},bgcolor:{valType:\"color\",dflt:c.railBgColor},bordercolor:{valType:\"color\",dflt:c.railBorderColor},borderwidth:{valType:\"number\",min:0,dflt:c.railBorderWidth},ticklen:{valType:\"number\",min:0,dflt:c.tickLength},tickcolor:{valType:\"color\",dflt:c.tickColor},tickwidth:{valType:\"number\",min:0,dflt:1},minorticklen:{valType:\"number\",min:0,dflt:c.minorTickLength}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/animation_attributes\":762,\"../../plots/font_attributes\":793,\"../../plots/pad_attributes\":827,\"./constants\":677}],677:[function(t,e,r){\"use strict\";e.exports={name:\"sliders\",containerClassName:\"slider-container\",groupClassName:\"slider-group\",inputAreaClass:\"slider-input-area\",railRectClass:\"slider-rail-rect\",railTouchRectClass:\"slider-rail-touch-rect\",gripRectClass:\"slider-grip-rect\",tickRectClass:\"slider-tick-rect\",inputProxyClass:\"slider-input-proxy\",labelsClass:\"slider-labels\",labelGroupClass:\"slider-label-group\",labelClass:\"slider-label\",currentValueClass:\"slider-current-value\",railHeight:5,menuIndexAttrName:\"slider-active-index\",autoMarginIdRoot:\"slider-\",minWidth:30,minHeight:30,textPadX:40,arrowOffsetX:4,railRadius:2,railWidth:5,railBorder:4,railBorderWidth:1,railBorderColor:\"#bec8d9\",railBgColor:\"#f8fafc\",railInset:8,stepInset:10,gripRadius:10,gripWidth:20,gripHeight:20,gripBorder:20,gripBorderWidth:1,gripBorderColor:\"#bec8d9\",gripBgColor:\"#f6f8fa\",gripBgActiveColor:\"#dbdde0\",labelPadding:8,labelOffset:0,tickWidth:1,tickColor:\"#333\",tickOffset:25,tickLength:7,minorTickOffset:25,minorTickColor:\"#333\",minorTickLength:4,currentValuePadding:8,currentValueInset:0}},{}],678:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.steps;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}for(var s=i(t,e,{name:\"steps\",handleItemDefaults:c}),l=0,u=0;u<s.length;u++)s[u].visible&&l++;if(l<2?e.visible=!1:o(\"visible\")){e._stepCount=l;var h=e._visibleSteps=n.filterVisible(s);(s[o(\"active\")]||{}).visible||(e.active=h[0]._index),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"len\"),o(\"lenmode\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"currentvalue.visible\")&&(o(\"currentvalue.xanchor\"),o(\"currentvalue.prefix\"),o(\"currentvalue.suffix\"),o(\"currentvalue.offset\"),n.coerceFont(o,\"currentvalue.font\",e.font)),o(\"transition.duration\"),o(\"transition.easing\"),o(\"bgcolor\"),o(\"activebgcolor\"),o(\"bordercolor\"),o(\"borderwidth\"),o(\"ticklen\"),o(\"tickwidth\"),o(\"tickcolor\"),o(\"minorticklen\")}}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}if(\"skip\"===t.method||Array.isArray(t.args)?r(\"visible\"):e.visible=!1){r(\"method\"),r(\"args\");var i=r(\"label\",\"step-\"+e._index);r(\"value\",i),r(\"execute\")}}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"./attributes\":676,\"./constants\":677}],679:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"./constants\"),h=t(\"../../constants/alignment\"),f=h.LINE_SPACING,p=h.FROM_TL,d=h.FROM_BR;function g(t){return u.autoMarginIdRoot+t._index}function v(t){return t._index}function m(t,e){var r=o.tester.selectAll(\"g.\"+u.labelGroupClass).data(e._visibleSteps);r.enter().append(\"g\").classed(u.labelGroupClass,!0);var a=0,c=0;r.each(function(t){var r=b(n.select(this),{step:t},e).node();if(r){var i=o.bBox(r);c=Math.max(c,i.height),a=Math.max(a,i.width)}}),r.remove();var h=e._dims={};h.inputAreaWidth=Math.max(u.railWidth,u.gripHeight);var f=t._fullLayout._size;h.lx=f.l+f.w*e.x,h.ly=f.t+f.h*(1-e.y),\"fraction\"===e.lenmode?h.outerLength=Math.round(f.w*e.len):h.outerLength=e.len,h.inputAreaStart=0,h.inputAreaLength=Math.round(h.outerLength-e.pad.l-e.pad.r);var v=(h.inputAreaLength-2*u.stepInset)/(e._stepCount-1),m=a+u.labelPadding;if(h.labelStride=Math.max(1,Math.ceil(m/v)),h.labelHeight=c,h.currentValueMaxWidth=0,h.currentValueHeight=0,h.currentValueTotalHeight=0,h.currentValueMaxLines=1,e.currentvalue.visible){var x=o.tester.append(\"g\");r.each(function(t){var r=y(x,e,t.label),n=r.node()&&o.bBox(r.node())||{width:0,height:0},i=l.lineCount(r);h.currentValueMaxWidth=Math.max(h.currentValueMaxWidth,Math.ceil(n.width)),h.currentValueHeight=Math.max(h.currentValueHeight,Math.ceil(n.height)),h.currentValueMaxLines=Math.max(h.currentValueMaxLines,i)}),h.currentValueTotalHeight=h.currentValueHeight+e.currentvalue.offset,x.remove()}h.height=h.currentValueTotalHeight+u.tickOffset+e.ticklen+u.labelOffset+h.labelHeight+e.pad.t+e.pad.b;var _=\"left\";s.isRightAnchor(e)&&(h.lx-=h.outerLength,_=\"right\"),s.isCenterAnchor(e)&&(h.lx-=h.outerLength/2,_=\"center\");var w=\"top\";s.isBottomAnchor(e)&&(h.ly-=h.height,w=\"bottom\"),s.isMiddleAnchor(e)&&(h.ly-=h.height/2,w=\"middle\"),h.outerLength=Math.ceil(h.outerLength),h.height=Math.ceil(h.height),h.lx=Math.round(h.lx),h.ly=Math.round(h.ly);var k={y:e.y,b:h.height*d[w],t:h.height*p[w]};\"fraction\"===e.lenmode?(k.l=0,k.xl=e.x-e.len*p[_],k.r=0,k.xr=e.x+e.len*d[_]):(k.x=e.x,k.l=h.outerLength*p[_],k.r=h.outerLength*d[_]),i.autoMargin(t,g(e),k)}function y(t,e,r){if(e.currentvalue.visible){var n,i,a=e._dims;switch(e.currentvalue.xanchor){case\"right\":n=a.inputAreaLength-u.currentValueInset-a.currentValueMaxWidth,i=\"left\";break;case\"center\":n=.5*a.inputAreaLength,i=\"middle\";break;default:n=u.currentValueInset,i=\"left\"}var c=s.ensureSingle(t,\"text\",u.labelClass,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":i,\"data-notex\":1})}),h=e.currentvalue.prefix?e.currentvalue.prefix:\"\";if(\"string\"==typeof r)h+=r;else{var p=e.steps[e.active].label,d=e._gd._fullLayout._meta;d&&(p=s.templateString(p,d)),h+=p}e.currentvalue.suffix&&(h+=e.currentvalue.suffix),c.call(o.font,e.currentvalue.font).text(h).call(l.convertToTspans,e._gd);var g=l.lineCount(c),v=(a.currentValueMaxLines+1-g)*e.currentvalue.font.size*f;return l.positionText(c,n,v),c}}function x(t,e,r){s.ensureSingle(t,\"rect\",u.gripRectClass,function(n){n.call(T,e,t,r).style(\"pointer-events\",\"all\")}).attr({width:u.gripWidth,height:u.gripHeight,rx:u.gripRadius,ry:u.gripRadius}).call(a.stroke,r.bordercolor).call(a.fill,r.bgcolor).style(\"stroke-width\",r.borderwidth+\"px\")}function b(t,e,r){var n=s.ensureSingle(t,\"text\",u.labelClass,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":\"middle\",\"data-notex\":1})}),i=e.step.label,a=r._gd._fullLayout._meta;return a&&(i=s.templateString(i,a)),n.call(o.font,r.font).text(i).call(l.convertToTspans,r._gd),n}function _(t,e){var r=s.ensureSingle(t,\"g\",u.labelsClass),i=e._dims,a=r.selectAll(\"g.\"+u.labelGroupClass).data(i.labelSteps);a.enter().append(\"g\").classed(u.labelGroupClass,!0),a.exit().remove(),a.each(function(t){var r=n.select(this);r.call(b,t,e),o.setTranslate(r,S(e,t.fraction),u.tickOffset+e.ticklen+e.font.size*f+u.labelOffset+i.currentValueTotalHeight)})}function w(t,e,r,n,i){var a=Math.round(n*(r._stepCount-1)),o=r._visibleSteps[a]._index;o!==r.active&&k(t,e,r,o,!0,i)}function k(t,e,r,n,a,o){var s=r.active;r.active=n,c(t.layout,u.name,r).applyUpdate(\"active\",n);var l=r.steps[r.active];e.call(M,r,o),e.call(y,r),t.emit(\"plotly_sliderchange\",{slider:r,step:r.steps[r.active],interaction:a,previousActive:s}),l&&l.method&&a&&(e._nextMethod?(e._nextMethod.step=l,e._nextMethod.doCallback=a,e._nextMethod.doTransition=o):(e._nextMethod={step:l,doCallback:a,doTransition:o},e._nextMethodRaf=window.requestAnimationFrame(function(){var r=e._nextMethod.step;r.method&&(r.execute&&i.executeAPICommand(t,r.method,r.args),e._nextMethod=null,e._nextMethodRaf=null)})))}function T(t,e,r){var i=r.node(),o=n.select(e);function s(){return r.data()[0]}t.on(\"mousedown\",function(){var t=s();e.emit(\"plotly_sliderstart\",{slider:t});var l=r.select(\".\"+u.gripRectClass);n.event.stopPropagation(),n.event.preventDefault(),l.call(a.fill,t.activebgcolor);var c=E(t,n.mouse(i)[0]);w(e,r,t,c,!0),t._dragging=!0,o.on(\"mousemove\",function(){var t=s(),a=E(t,n.mouse(i)[0]);w(e,r,t,a,!1)}),o.on(\"mouseup\",function(){var t=s();t._dragging=!1,l.call(a.fill,t.bgcolor),o.on(\"mouseup\",null),o.on(\"mousemove\",null),e.emit(\"plotly_sliderend\",{slider:t,step:t.steps[t.active]})})})}function A(t,e){var r=t.selectAll(\"rect.\"+u.tickRectClass).data(e._visibleSteps),i=e._dims;r.enter().append(\"rect\").classed(u.tickRectClass,!0),r.exit().remove(),r.attr({width:e.tickwidth+\"px\",\"shape-rendering\":\"crispEdges\"}),r.each(function(t,r){var s=r%i.labelStride==0,l=n.select(this);l.attr({height:s?e.ticklen:e.minorticklen}).call(a.fill,e.tickcolor),o.setTranslate(l,S(e,r/(e._stepCount-1))-.5*e.tickwidth,(s?u.tickOffset:u.minorTickOffset)+i.currentValueTotalHeight)})}function M(t,e,r){for(var n=t.select(\"rect.\"+u.gripRectClass),i=0,a=0;a<e._stepCount;a++)if(e._visibleSteps[a]._index===e.active){i=a;break}var o=S(e,i/(e._stepCount-1));if(!e._invokingCommand){var s=n;r&&e.transition.duration>0&&(s=s.transition().duration(e.transition.duration).ease(e.transition.easing)),s.attr(\"transform\",\"translate(\"+(o-.5*u.gripWidth)+\",\"+e._dims.currentValueTotalHeight+\")\")}}function S(t,e){var r=t._dims;return r.inputAreaStart+u.stepInset+(r.inputAreaLength-2*u.stepInset)*Math.min(1,Math.max(0,e))}function E(t,e){var r=t._dims;return Math.min(1,Math.max(0,(e-u.stepInset-r.inputAreaStart)/(r.inputAreaLength-2*u.stepInset-2*r.inputAreaStart)))}function C(t,e,r){var n=r._dims,i=s.ensureSingle(t,\"rect\",u.railTouchRectClass,function(n){n.call(T,e,t,r).style(\"pointer-events\",\"all\")});i.attr({width:n.inputAreaLength,height:Math.max(n.inputAreaWidth,u.tickOffset+r.ticklen+n.labelHeight)}).call(a.fill,r.bgcolor).attr(\"opacity\",0),o.setTranslate(i,0,n.currentValueTotalHeight)}function L(t,e){var r=e._dims,n=r.inputAreaLength-2*u.railInset,i=s.ensureSingle(t,\"rect\",u.railRectClass);i.attr({width:n,height:u.railWidth,rx:u.railRadius,ry:u.railRadius,\"shape-rendering\":\"crispEdges\"}).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\"),o.setTranslate(i,u.railInset,.5*(r.inputAreaWidth-u.railWidth)+r.currentValueTotalHeight)}e.exports=function(t){var e=t._fullLayout,r=function(t,e){for(var r=t[u.name],n=[],i=0;i<r.length;i++){var a=r[i];a.visible&&(a._gd=e,n.push(a))}return n}(e,t),a=e._infolayer.selectAll(\"g.\"+u.containerClassName).data(r.length>0?[0]:[]);function s(e){e._commandObserver&&(e._commandObserver.remove(),delete e._commandObserver),i.autoMargin(t,g(e))}if(a.enter().append(\"g\").classed(u.containerClassName,!0).style(\"cursor\",\"ew-resize\"),a.exit().each(function(){n.select(this).selectAll(\"g.\"+u.groupClassName).each(s)}).remove(),0!==r.length){var l=a.selectAll(\"g.\"+u.groupClassName).data(r,v);l.enter().append(\"g\").classed(u.groupClassName,!0),l.exit().each(s).remove();for(var c=0;c<r.length;c++){var h=r[c];m(t,h)}l.each(function(e){var r=n.select(this);!function(t){var e=t._dims;e.labelSteps=[];for(var r=t._stepCount,n=0;n<r;n+=e.labelStride)e.labelSteps.push({fraction:n/(r-1),step:t._visibleSteps[n]})}(e),i.manageCommandObserver(t,e,e._visibleSteps,function(e){var n=r.data()[0];n.active!==e.index&&(n._dragging||k(t,r,n,e.index,!1,!0))}),function(t,e,r){(r.steps[r.active]||{}).visible||(r.active=r._visibleSteps[0]._index);e.call(y,r).call(L,r).call(_,r).call(A,r).call(C,t,r).call(x,t,r);var n=r._dims;o.setTranslate(e,n.lx+r.pad.l,n.ly+r.pad.t),e.call(M,r,!1),e.call(y,r)}(t,n.select(this),e)})}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_template\":757,\"../../plots/plots\":828,\"../color\":593,\"../drawing\":614,\"./constants\":677,d3:163}],680:[function(t,e,r){\"use strict\";var n=t(\"./constants\");e.exports={moduleType:\"component\",name:n.name,layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":676,\"./constants\":677,\"./defaults\":678,\"./draw\":679}],681:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../drawing\"),c=t(\"../color\"),u=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/interactions\");e.exports={draw:function(t,e,r){var p,d=r.propContainer,g=r.propName,v=r.placeholder,m=r.traceIndex,y=r.avoid||{},x=r.attributes,b=r.transform,_=r.containerGroup,w=t._fullLayout,k=1,T=!1,A=d.title,M=(A&&A.text?A.text:\"\").trim(),S=A&&A.font?A.font:{},E=S.family,C=S.size,L=S.color;\"title.text\"===g?p=\"titleText\":-1!==g.indexOf(\"axis\")?p=\"axisTitleText\":g.indexOf(!0)&&(p=\"colorbarTitleText\");var P=t._context.edits[p];\"\"===M?k=0:M.replace(f,\" % \")===v.replace(f,\" % \")&&(k=.2,T=!0,P||(M=\"\"));r._meta?M=s.templateString(M,r._meta):w._meta&&(M=s.templateString(M,w._meta));var O=M||P;_||(_=s.ensureSingle(w._infolayer,\"g\",\"g-\"+e));var z=_.selectAll(\"text\").data(O?[0]:[]);if(z.enter().append(\"text\"),z.text(M).attr(\"class\",e),z.exit().remove(),!O)return _;function I(t){s.syncOrAsync([D,R],t)}function D(e){var r;return b?(r=\"\",b.rotate&&(r+=\"rotate(\"+[b.rotate,x.x,x.y]+\")\"),b.offset&&(r+=\"translate(0, \"+b.offset+\")\")):r=null,e.attr(\"transform\",r),e.style({\"font-family\":E,\"font-size\":n.round(C,2)+\"px\",fill:c.rgb(L),opacity:k*c.opacity(L),\"font-weight\":a.fontWeight}).attr(x).call(u.convertToTspans,t),a.previousPromises(t)}function R(t){var e=n.select(t.node().parentNode);if(y&&y.selection&&y.side&&M){e.attr(\"transform\",null);var r=0,a={left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}[y.side],o=-1!==[\"left\",\"top\"].indexOf(y.side)?-1:1,c=i(y.pad)?y.pad:2,u=l.bBox(e.node()),h={left:0,top:0,right:w.width,bottom:w.height},f=y.maxShift||(h[y.side]-u[y.side])*(\"left\"===y.side||\"top\"===y.side?-1:1);if(f<0)r=f;else{var p=y.offsetLeft||0,d=y.offsetTop||0;u.left-=p,u.right-=p,u.top-=d,u.bottom-=d,y.selection.each(function(){var t=l.bBox(this);s.bBoxIntersect(u,t,c)&&(r=Math.max(r,o*(t[y.side]-u[a])+c))}),r=Math.min(f,r)}if(r>0||f<0){var g={left:[-r,0],right:[r,0],top:[0,-r],bottom:[0,r]}[y.side];e.attr(\"transform\",\"translate(\"+g+\")\")}}}z.call(I),P&&(M?z.on(\".opacity\",null):(k=0,T=!0,z.text(v).on(\"mouseover.opacity\",function(){n.select(this).transition().duration(h.SHOW_PLACEHOLDER).style(\"opacity\",1)}).on(\"mouseout.opacity\",function(){n.select(this).transition().duration(h.HIDE_PLACEHOLDER).style(\"opacity\",0)})),z.call(u.makeEditable,{gd:t}).on(\"edit\",function(e){void 0!==m?o.call(\"_guiRestyle\",t,g,e,m):o.call(\"_guiRelayout\",t,g,e)}).on(\"cancel\",function(){this.text(this.attr(\"data-unformatted\")).call(I)}).on(\"input\",function(t){this.text(t||\" \").call(u.positionText,x.x,x.y)}));return z.classed(\"js-placeholder\",T),_}};var f=/ [XY][0-9]* /},{\"../../constants/interactions\":694,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/plots\":828,\"../../registry\":847,\"../color\":593,\"../drawing\":614,d3:163,\"fast-isnumeric\":225}],682:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/pad_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=l(\"button\",{visible:{valType:\"boolean\"},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\",dflt:\"\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"updatemenu\",{_arrayAttrRegexps:[/^updatemenus\\[(0|[1-9][0-9]+)\\]\\.buttons/],visible:{valType:\"boolean\"},type:{valType:\"enumerated\",values:[\"dropdown\",\"buttons\"],dflt:\"dropdown\"},direction:{valType:\"enumerated\",values:[\"left\",\"right\",\"up\",\"down\"],dflt:\"down\"},active:{valType:\"integer\",min:-1,dflt:0},showactive:{valType:\"boolean\",dflt:!0},buttons:c,x:{valType:\"number\",min:-2,max:3,dflt:-.05},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"right\"},y:{valType:\"number\",min:-2,max:3,dflt:1},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},pad:a(s({editType:\"arraydraw\"}),{}),font:n({}),bgcolor:{valType:\"color\"},bordercolor:{valType:\"color\",dflt:i.borderLine},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"arraydraw\"}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/font_attributes\":793,\"../../plots/pad_attributes\":827,\"../color/attributes\":592}],683:[function(t,e,r){\"use strict\";e.exports={name:\"updatemenus\",containerClassName:\"updatemenu-container\",headerGroupClassName:\"updatemenu-header-group\",headerClassName:\"updatemenu-header\",headerArrowClassName:\"updatemenu-header-arrow\",dropdownButtonGroupClassName:\"updatemenu-dropdown-button-group\",dropdownButtonClassName:\"updatemenu-dropdown-button\",buttonClassName:\"updatemenu-button\",itemRectClassName:\"updatemenu-item-rect\",itemTextClassName:\"updatemenu-item-text\",menuIndexAttrName:\"updatemenu-active-index\",autoMarginIdRoot:\"updatemenu-\",blankHeaderOpts:{label:\"  \"},minWidth:30,minHeight:30,textPadX:24,arrowPadX:16,rx:2,ry:2,textOffsetX:12,textOffsetY:3,arrowOffsetX:4,gapButtonHeader:5,gapButton:2,activeColor:\"#F4FAFF\",hoverColor:\"#F4FAFF\",arrowSymbol:{left:\"\\u25c4\",right:\"\\u25ba\",up:\"\\u25b2\",down:\"\\u25bc\"}}},{}],684:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.buttons;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}o(\"visible\",i(t,e,{name:\"buttons\",handleItemDefaults:c}).length>0)&&(o(\"active\"),o(\"direction\"),o(\"type\"),o(\"showactive\"),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"bgcolor\",r.paper_bgcolor),o(\"bordercolor\"),o(\"borderwidth\"))}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}r(\"visible\",\"skip\"===t.method||Array.isArray(t.args))&&(r(\"method\"),r(\"args\"),r(\"label\"),r(\"execute\"))}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"./attributes\":682,\"./constants\":683}],685:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"../../constants/alignment\").LINE_SPACING,h=t(\"./constants\"),f=t(\"./scrollbox\");function p(t){return t._index}function d(t,e){return+t.attr(h.menuIndexAttrName)===e._index}function g(t,e,r,n,i,a,o,s){e.active=o,c(t.layout,h.name,e).applyUpdate(\"active\",o),\"buttons\"===e.type?m(t,n,null,null,e):\"dropdown\"===e.type&&(i.attr(h.menuIndexAttrName,\"-1\"),v(t,n,i,a,e),s||m(t,n,i,a,e))}function v(t,e,r,n,i){var a=s.ensureSingle(e,\"g\",h.headerClassName,function(t){t.style(\"pointer-events\",\"all\")}),l=i._dims,c=i.active,u=i.buttons[c]||h.blankHeaderOpts,f={y:i.pad.t,yPad:0,x:i.pad.l,xPad:0,index:0},p={width:l.headerWidth,height:l.headerHeight};a.call(y,i,u,t).call(M,i,f,p),s.ensureSingle(e,\"text\",h.headerArrowClassName,function(t){t.classed(\"user-select-none\",!0).attr(\"text-anchor\",\"end\").call(o.font,i.font).text(h.arrowSymbol[i.direction])}).attr({x:l.headerWidth-h.arrowOffsetX+i.pad.l,y:l.headerHeight/2+h.textOffsetY+i.pad.t}),a.on(\"click\",function(){r.call(S,String(d(r,i)?-1:i._index)),m(t,e,r,n,i)}),a.on(\"mouseover\",function(){a.call(w)}),a.on(\"mouseout\",function(){a.call(k,i)}),o.setTranslate(e,l.lx,l.ly)}function m(t,e,r,a,o){r||(r=e).attr(\"pointer-events\",\"all\");var l=function(t){return-1==+t.attr(h.menuIndexAttrName)}(r)&&\"buttons\"!==o.type?[]:o.buttons,c=\"dropdown\"===o.type?h.dropdownButtonClassName:h.buttonClassName,u=r.selectAll(\"g.\"+c).data(s.filterVisible(l)),f=u.enter().append(\"g\").classed(c,!0),p=u.exit();\"dropdown\"===o.type?(f.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\"),p.transition().attr(\"opacity\",\"0\").remove()):p.remove();var d=0,v=0,m=o._dims,x=-1!==[\"up\",\"down\"].indexOf(o.direction);\"dropdown\"===o.type&&(x?v=m.headerHeight+h.gapButtonHeader:d=m.headerWidth+h.gapButtonHeader),\"dropdown\"===o.type&&\"up\"===o.direction&&(v=-h.gapButtonHeader+h.gapButton-m.openHeight),\"dropdown\"===o.type&&\"left\"===o.direction&&(d=-h.gapButtonHeader+h.gapButton-m.openWidth);var b={x:m.lx+d+o.pad.l,y:m.ly+v+o.pad.t,yPad:h.gapButton,xPad:h.gapButton,index:0},T={l:b.x+o.borderwidth,t:b.y+o.borderwidth};u.each(function(s,l){var c=n.select(this);c.call(y,o,s,t).call(M,o,b),c.on(\"click\",function(){n.event.defaultPrevented||(g(t,o,0,e,r,a,l),s.execute&&i.executeAPICommand(t,s.method,s.args),t.emit(\"plotly_buttonclicked\",{menu:o,button:s,active:o.active}))}),c.on(\"mouseover\",function(){c.call(w)}),c.on(\"mouseout\",function(){c.call(k,o),u.call(_,o)})}),u.call(_,o),x?(T.w=Math.max(m.openWidth,m.headerWidth),T.h=b.y-T.t):(T.w=b.x-T.l,T.h=Math.max(m.openHeight,m.headerHeight)),T.direction=o.direction,a&&(u.size()?function(t,e,r,n,i,a){var o,s,l,c=i.direction,u=\"up\"===c||\"down\"===c,f=i._dims,p=i.active;if(u)for(s=0,l=0;l<p;l++)s+=f.heights[l]+h.gapButton;else for(o=0,l=0;l<p;l++)o+=f.widths[l]+h.gapButton;n.enable(a,o,s),n.hbar&&n.hbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\");n.vbar&&n.vbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\")}(0,0,0,a,o,T):function(t){var e=!!t.hbar,r=!!t.vbar;e&&t.hbar.transition().attr(\"opacity\",\"0\").each(\"end\",function(){e=!1,r||t.disable()});r&&t.vbar.transition().attr(\"opacity\",\"0\").each(\"end\",function(){r=!1,e||t.disable()})}(a))}function y(t,e,r,n){t.call(x,e).call(b,e,r,n)}function x(t,e){s.ensureSingle(t,\"rect\",h.itemRectClassName,function(t){t.attr({rx:h.rx,ry:h.ry,\"shape-rendering\":\"crispEdges\"})}).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\")}function b(t,e,r,n){var i=s.ensureSingle(t,\"text\",h.itemTextClassName,function(t){t.classed(\"user-select-none\",!0).attr({\"text-anchor\":\"start\",\"data-notex\":1})}),a=r.label,c=n._fullLayout._meta;c&&(a=s.templateString(a,c)),i.call(o.font,e.font).text(a).call(l.convertToTspans,n)}function _(t,e){var r=e.active;t.each(function(t,i){var o=n.select(this);i===r&&e.showactive&&o.select(\"rect.\"+h.itemRectClassName).call(a.fill,h.activeColor)})}function w(t){t.select(\"rect.\"+h.itemRectClassName).call(a.fill,h.hoverColor)}function k(t,e){t.select(\"rect.\"+h.itemRectClassName).call(a.fill,e.bgcolor)}function T(t,e){var r=e._dims={width1:0,height1:0,heights:[],widths:[],totalWidth:0,totalHeight:0,openWidth:0,openHeight:0,lx:0,ly:0},a=o.tester.selectAll(\"g.\"+h.dropdownButtonClassName).data(s.filterVisible(e.buttons));a.enter().append(\"g\").classed(h.dropdownButtonClassName,!0);var c=-1!==[\"up\",\"down\"].indexOf(e.direction);a.each(function(i,a){var s=n.select(this);s.call(y,e,i,t);var f=s.select(\".\"+h.itemTextClassName),p=f.node()&&o.bBox(f.node()).width,d=Math.max(p+h.textPadX,h.minWidth),g=e.font.size*u,v=l.lineCount(f),m=Math.max(g*v,h.minHeight)+h.textOffsetY;m=Math.ceil(m),d=Math.ceil(d),r.widths[a]=d,r.heights[a]=m,r.height1=Math.max(r.height1,m),r.width1=Math.max(r.width1,d),c?(r.totalWidth=Math.max(r.totalWidth,d),r.openWidth=r.totalWidth,r.totalHeight+=m+h.gapButton,r.openHeight+=m+h.gapButton):(r.totalWidth+=d+h.gapButton,r.openWidth+=d+h.gapButton,r.totalHeight=Math.max(r.totalHeight,m),r.openHeight=r.totalHeight)}),c?r.totalHeight-=h.gapButton:r.totalWidth-=h.gapButton,r.headerWidth=r.width1+h.arrowPadX,r.headerHeight=r.height1,\"dropdown\"===e.type&&(c?(r.width1+=h.arrowPadX,r.totalHeight=r.height1):r.totalWidth=r.width1,r.totalWidth+=h.arrowPadX),a.remove();var f=r.totalWidth+e.pad.l+e.pad.r,p=r.totalHeight+e.pad.t+e.pad.b,d=t._fullLayout._size;r.lx=d.l+d.w*e.x,r.ly=d.t+d.h*(1-e.y);var g=\"left\";s.isRightAnchor(e)&&(r.lx-=f,g=\"right\"),s.isCenterAnchor(e)&&(r.lx-=f/2,g=\"center\");var v=\"top\";s.isBottomAnchor(e)&&(r.ly-=p,v=\"bottom\"),s.isMiddleAnchor(e)&&(r.ly-=p/2,v=\"middle\"),r.totalWidth=Math.ceil(r.totalWidth),r.totalHeight=Math.ceil(r.totalHeight),r.lx=Math.round(r.lx),r.ly=Math.round(r.ly),i.autoMargin(t,A(e),{x:e.x,y:e.y,l:f*({right:1,center:.5}[g]||0),r:f*({left:1,center:.5}[g]||0),b:p*({top:1,middle:.5}[v]||0),t:p*({bottom:1,middle:.5}[v]||0)})}function A(t){return h.autoMarginIdRoot+t._index}function M(t,e,r,n){n=n||{};var i=t.select(\".\"+h.itemRectClassName),a=t.select(\".\"+h.itemTextClassName),s=e.borderwidth,c=r.index,f=e._dims;o.setTranslate(t,s+r.x,s+r.y);var p=-1!==[\"up\",\"down\"].indexOf(e.direction),d=n.height||(p?f.heights[c]:f.height1);i.attr({x:0,y:0,width:n.width||(p?f.width1:f.widths[c]),height:d});var g=e.font.size*u,v=(l.lineCount(a)-1)*g/2;l.positionText(a,h.textOffsetX,d/2-v+h.textOffsetY),p?r.y+=f.heights[c]+r.yPad:r.x+=f.widths[c]+r.xPad,r.index++}function S(t,e){t.attr(h.menuIndexAttrName,e||\"-1\").selectAll(\"g.\"+h.dropdownButtonClassName).remove()}e.exports=function(t){var e=t._fullLayout,r=s.filterVisible(e[h.name]);function a(e){i.autoMargin(t,A(e))}var o=e._menulayer.selectAll(\"g.\"+h.containerClassName).data(r.length>0?[0]:[]);if(o.enter().append(\"g\").classed(h.containerClassName,!0).style(\"cursor\",\"pointer\"),o.exit().each(function(){n.select(this).selectAll(\"g.\"+h.headerGroupClassName).each(a)}).remove(),0!==r.length){var l=o.selectAll(\"g.\"+h.headerGroupClassName).data(r,p);l.enter().append(\"g\").classed(h.headerGroupClassName,!0);for(var c=s.ensureSingle(o,\"g\",h.dropdownButtonGroupClassName,function(t){t.style(\"pointer-events\",\"all\")}),u=0;u<r.length;u++){var y=r[u];T(t,y)}var x=\"updatemenus\"+e._uid,b=new f(t,c,x);l.enter().size()&&(c.node().parentNode.appendChild(c.node()),c.call(S)),l.exit().each(function(t){c.call(S),a(t)}).remove(),l.each(function(e){var r=n.select(this),a=\"dropdown\"===e.type?c:null;i.manageCommandObserver(t,e,e.buttons,function(n){g(t,e,e.buttons[n.index],r,a,b,n.index,!0)}),\"dropdown\"===e.type?(v(t,r,c,b,e),d(c,e)&&m(t,r,c,b,e)):m(t,r,null,null,e)})}}},{\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_template\":757,\"../../plots/plots\":828,\"../color\":593,\"../drawing\":614,\"./constants\":683,\"./scrollbox\":687,d3:163}],686:[function(t,e,r){arguments[4][680][0].apply(r,arguments)},{\"./attributes\":682,\"./constants\":683,\"./defaults\":684,\"./draw\":685,dup:680}],687:[function(t,e,r){\"use strict\";e.exports=s;var n=t(\"d3\"),i=t(\"../color\"),a=t(\"../drawing\"),o=t(\"../../lib\");function s(t,e,r){this.gd=t,this.container=e,this.id=r,this.position=null,this.translateX=null,this.translateY=null,this.hbar=null,this.vbar=null,this.bg=this.container.selectAll(\"rect.scrollbox-bg\").data([0]),this.bg.exit().on(\".drag\",null).on(\"wheel\",null).remove(),this.bg.enter().append(\"rect\").classed(\"scrollbox-bg\",!0).style(\"pointer-events\",\"all\").attr({opacity:0,x:0,y:0,width:0,height:0})}s.barWidth=2,s.barLength=20,s.barRadius=2,s.barPad=1,s.barColor=\"#808BA4\",s.prototype.enable=function(t,e,r){var o=this.gd._fullLayout,l=o.width,c=o.height;this.position=t;var u,h,f,p,d=this.position.l,g=this.position.w,v=this.position.t,m=this.position.h,y=this.position.direction,x=\"down\"===y,b=\"left\"===y,_=\"up\"===y,w=g,k=m;x||b||\"right\"===y||_||(this.position.direction=\"down\",x=!0),x||_?(h=(u=d)+w,x?(f=v,k=(p=Math.min(f+k,c))-f):k=(p=v+k)-(f=Math.max(p-k,0))):(p=(f=v)+k,b?w=(h=d+w)-(u=Math.max(h-w,0)):(u=d,w=(h=Math.min(u+w,l))-u)),this._box={l:u,t:f,w:w,h:k};var T=g>w,A=s.barLength+2*s.barPad,M=s.barWidth+2*s.barPad,S=d,E=v+m;E+M>c&&(E=c-M);var C=this.container.selectAll(\"rect.scrollbar-horizontal\").data(T?[0]:[]);C.exit().on(\".drag\",null).remove(),C.enter().append(\"rect\").classed(\"scrollbar-horizontal\",!0).call(i.fill,s.barColor),T?(this.hbar=C.attr({rx:s.barRadius,ry:s.barRadius,x:S,y:E,width:A,height:M}),this._hbarXMin=S+A/2,this._hbarTranslateMax=w-A):(delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax);var L=m>k,P=s.barWidth+2*s.barPad,O=s.barLength+2*s.barPad,z=d+g,I=v;z+P>l&&(z=l-P);var D=this.container.selectAll(\"rect.scrollbar-vertical\").data(L?[0]:[]);D.exit().on(\".drag\",null).remove(),D.enter().append(\"rect\").classed(\"scrollbar-vertical\",!0).call(i.fill,s.barColor),L?(this.vbar=D.attr({rx:s.barRadius,ry:s.barRadius,x:z,y:I,width:P,height:O}),this._vbarYMin=I+O/2,this._vbarTranslateMax=k-O):(delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax);var R=this.id,F=u-.5,B=L?h+P+.5:h+.5,N=f-.5,j=T?p+M+.5:p+.5,U=o._topdefs.selectAll(\"#\"+R).data(T||L?[0]:[]);if(U.exit().remove(),U.enter().append(\"clipPath\").attr(\"id\",R).append(\"rect\"),T||L?(this._clipRect=U.select(\"rect\").attr({x:Math.floor(F),y:Math.floor(N),width:Math.ceil(B)-Math.floor(F),height:Math.ceil(j)-Math.floor(N)}),this.container.call(a.setClipUrl,R,this.gd),this.bg.attr({x:d,y:v,width:g,height:m})):(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),T||L){var V=n.behavior.drag().on(\"dragstart\",function(){n.event.sourceEvent.preventDefault()}).on(\"drag\",this._onBoxDrag.bind(this));this.container.on(\"wheel\",null).on(\"wheel\",this._onBoxWheel.bind(this)).on(\".drag\",null).call(V);var q=n.behavior.drag().on(\"dragstart\",function(){n.event.sourceEvent.preventDefault(),n.event.sourceEvent.stopPropagation()}).on(\"drag\",this._onBarDrag.bind(this));T&&this.hbar.on(\".drag\",null).call(q),L&&this.vbar.on(\".drag\",null).call(q)}this.setTranslate(e,r)},s.prototype.disable=function(){(this.hbar||this.vbar)&&(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),this.hbar&&(this.hbar.on(\".drag\",null),this.hbar.remove(),delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax),this.vbar&&(this.vbar.on(\".drag\",null),this.vbar.remove(),delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax)},s.prototype._onBoxDrag=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t-=n.event.dx),this.vbar&&(e-=n.event.dy),this.setTranslate(t,e)},s.prototype._onBoxWheel=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t+=n.event.deltaY),this.vbar&&(e+=n.event.deltaY),this.setTranslate(t,e)},s.prototype._onBarDrag=function(){var t=this.translateX,e=this.translateY;if(this.hbar){var r=t+this._hbarXMin,i=r+this._hbarTranslateMax;t=(o.constrain(n.event.x,r,i)-r)/(i-r)*(this.position.w-this._box.w)}if(this.vbar){var a=e+this._vbarYMin,s=a+this._vbarTranslateMax;e=(o.constrain(n.event.y,a,s)-a)/(s-a)*(this.position.h-this._box.h)}this.setTranslate(t,e)},s.prototype.setTranslate=function(t,e){var r=this.position.w-this._box.w,n=this.position.h-this._box.h;if(t=o.constrain(t||0,0,r),e=o.constrain(e||0,0,n),this.translateX=t,this.translateY=e,this.container.call(a.setTranslate,this._box.l-this.position.l-t,this._box.t-this.position.t-e),this._clipRect&&this._clipRect.attr({x:Math.floor(this.position.l+t-.5),y:Math.floor(this.position.t+e-.5)}),this.hbar){var i=t/r;this.hbar.call(a.setTranslate,t+i*this._hbarTranslateMax,e)}if(this.vbar){var s=e/n;this.vbar.call(a.setTranslate,t,e+s*this._vbarTranslateMax)}}},{\"../../lib\":719,\"../color\":593,\"../drawing\":614,d3:163}],688:[function(t,e,r){\"use strict\";e.exports={FROM_BL:{left:0,center:.5,right:1,bottom:0,middle:.5,top:1},FROM_TL:{left:0,center:.5,right:1,bottom:1,middle:.5,top:0},FROM_BR:{left:1,center:.5,right:0,bottom:0,middle:.5,top:1},LINE_SPACING:1.3,CAP_SHIFT:.7,MID_SHIFT:.35,OPPOSITE_SIDE:{left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}}},{}],689:[function(t,e,r){\"use strict\";e.exports={INCREASING:{COLOR:\"#3D9970\",SYMBOL:\"\\u25b2\"},DECREASING:{COLOR:\"#FF4136\",SYMBOL:\"\\u25bc\"}}},{}],690:[function(t,e,r){\"use strict\";e.exports={FORMAT_LINK:\"https://github.com/d3/d3-3.x-api-reference/blob/master/Formatting.md#d3_format\",DATE_FORMAT_LINK:\"https://github.com/d3/d3-3.x-api-reference/blob/master/Time-Formatting.md#format\"}},{}],691:[function(t,e,r){\"use strict\";e.exports={COMPARISON_OPS:[\"=\",\"!=\",\"<\",\">=\",\">\",\"<=\"],COMPARISON_OPS2:[\"=\",\"<\",\">=\",\">\",\"<=\"],INTERVAL_OPS:[\"[]\",\"()\",\"[)\",\"(]\",\"][\",\")(\",\"](\",\")[\"],SET_OPS:[\"{}\",\"}{\"],CONSTRAINT_REDUCTION:{\"=\":\"=\",\"<\":\"<\",\"<=\":\"<\",\">\":\">\",\">=\":\">\",\"[]\":\"[]\",\"()\":\"[]\",\"[)\":\"[]\",\"(]\":\"[]\",\"][\":\"][\",\")(\":\"][\",\"](\":\"][\",\")[\":\"][\"}}},{}],692:[function(t,e,r){\"use strict\";e.exports={solid:[[],0],dot:[[.5,1],200],dash:[[.5,1],50],longdash:[[.5,1],10],dashdot:[[.5,.625,.875,1],50],longdashdot:[[.5,.7,.8,1],10]}},{}],693:[function(t,e,r){\"use strict\";e.exports={circle:\"\\u25cf\",\"circle-open\":\"\\u25cb\",square:\"\\u25a0\",\"square-open\":\"\\u25a1\",diamond:\"\\u25c6\",\"diamond-open\":\"\\u25c7\",cross:\"+\",x:\"\\u274c\"}},{}],694:[function(t,e,r){\"use strict\";e.exports={SHOW_PLACEHOLDER:100,HIDE_PLACEHOLDER:1e3,DESELECTDIM:.2}},{}],695:[function(t,e,r){\"use strict\";e.exports={BADNUM:void 0,FP_SAFE:Number.MAX_VALUE/1e4,ONEAVGYEAR:315576e5,ONEAVGMONTH:26298e5,ONEDAY:864e5,ONEHOUR:36e5,ONEMIN:6e4,ONESEC:1e3,EPOCHJD:2440587.5,ALMOST_EQUAL:1-1e-6,LOG_CLIP:10,MINUS_SIGN:\"\\u2212\"}},{}],696:[function(t,e,r){\"use strict\";r.xmlns=\"http://www.w3.org/2000/xmlns/\",r.svg=\"http://www.w3.org/2000/svg\",r.xlink=\"http://www.w3.org/1999/xlink\",r.svgAttrs={xmlns:r.svg,\"xmlns:xlink\":r.xlink}},{}],697:[function(t,e,r){\"use strict\";r.version=\"1.49.1\",t(\"es6-promise\").polyfill(),t(\"../build/plotcss\"),t(\"./fonts/mathjax_config\")();for(var n=t(\"./registry\"),i=r.register=n.register,a=t(\"./plot_api\"),o=Object.keys(a),s=0;s<o.length;s++){var l=o[s];\"_\"!==l.charAt(0)&&(r[l]=a[l]),i({moduleType:\"apiMethod\",name:l,fn:a[l]})}i(t(\"./traces/scatter\")),i([t(\"./components/fx\"),t(\"./components/legend\"),t(\"./components/annotations\"),t(\"./components/annotations3d\"),t(\"./components/shapes\"),t(\"./components/images\"),t(\"./components/updatemenus\"),t(\"./components/sliders\"),t(\"./components/rangeslider\"),t(\"./components/rangeselector\"),t(\"./components/grid\"),t(\"./components/errorbars\"),t(\"./components/colorscale\"),t(\"./components/colorbar\")]),i([t(\"./locale-en\"),t(\"./locale-en-us\")]),r.Icons=t(\"./fonts/ploticon\"),r.Plots=t(\"./plots/plots\"),r.Fx=t(\"./components/fx\"),r.Snapshot=t(\"./snapshot\"),r.PlotSchema=t(\"./plot_api/plot_schema\"),r.Queue=t(\"./lib/queue\"),r.d3=t(\"d3\")},{\"../build/plotcss\":1,\"./components/annotations\":584,\"./components/annotations3d\":589,\"./components/colorbar\":599,\"./components/colorscale\":605,\"./components/errorbars\":620,\"./components/fx\":632,\"./components/grid\":636,\"./components/images\":641,\"./components/legend\":649,\"./components/rangeselector\":660,\"./components/rangeslider\":667,\"./components/shapes\":675,\"./components/sliders\":680,\"./components/updatemenus\":686,\"./fonts/mathjax_config\":698,\"./fonts/ploticon\":699,\"./lib/queue\":734,\"./locale-en\":748,\"./locale-en-us\":747,\"./plot_api\":752,\"./plot_api/plot_schema\":756,\"./plots/plots\":828,\"./registry\":847,\"./snapshot\":852,\"./traces/scatter\":1123,d3:163,\"es6-promise\":218}],698:[function(t,e,r){\"use strict\";e.exports=function(){\"undefined\"!=typeof MathJax&&(\"local\"!==(window.PlotlyConfig||{}).MathJaxConfig&&(MathJax.Hub.Config({messageStyle:\"none\",skipStartupTypeset:!0,displayAlign:\"left\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]}}),MathJax.Hub.Configured()))}},{}],699:[function(t,e,r){\"use strict\";e.exports={undo:{width:857.1,height:1e3,path:\"m857 350q0-87-34-166t-91-137-137-92-166-34q-96 0-183 41t-147 114q-4 6-4 13t5 11l76 77q6 5 14 5 9-1 13-7 41-53 100-82t126-29q58 0 110 23t92 61 61 91 22 111-22 111-61 91-92 61-110 23q-55 0-105-20t-90-57l77-77q17-16 8-38-10-23-33-23h-250q-15 0-25 11t-11 25v250q0 24 22 33 22 10 39-8l72-72q60 57 137 88t159 31q87 0 166-34t137-92 91-137 34-166z\",transform:\"matrix(1 0 0 -1 0 850)\"},home:{width:928.6,height:1e3,path:\"m786 296v-267q0-15-11-26t-25-10h-214v214h-143v-214h-214q-15 0-25 10t-11 26v267q0 1 0 2t0 2l321 264 321-264q1-1 1-4z m124 39l-34-41q-5-5-12-6h-2q-7 0-12 3l-386 322-386-322q-7-4-13-4-7 2-12 7l-35 41q-4 5-3 13t6 12l401 334q18 15 42 15t43-15l136-114v109q0 8 5 13t13 5h107q8 0 13-5t5-13v-227l122-102q5-5 6-12t-4-13z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"camera-retro\":{width:1e3,height:1e3,path:\"m518 386q0 8-5 13t-13 5q-37 0-63-27t-26-63q0-8 5-13t13-5 12 5 5 13q0 23 16 38t38 16q8 0 13 5t5 13z m125-73q0-59-42-101t-101-42-101 42-42 101 42 101 101 42 101-42 42-101z m-572-320h858v71h-858v-71z m643 320q0 89-62 152t-152 62-151-62-63-152 63-151 151-63 152 63 62 151z m-571 358h214v72h-214v-72z m-72-107h858v143h-462l-36-71h-360v-72z m929 143v-714q0-30-21-51t-50-21h-858q-29 0-50 21t-21 51v714q0 30 21 51t50 21h858q29 0 50-21t21-51z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoombox:{width:1e3,height:1e3,path:\"m1000-25l-250 251c40 63 63 138 63 218 0 224-182 406-407 406-224 0-406-182-406-406s183-406 407-406c80 0 155 22 218 62l250-250 125 125z m-812 250l0 438 437 0 0-438-437 0z m62 375l313 0 0-312-313 0 0 312z\",transform:\"matrix(1 0 0 -1 0 850)\"},pan:{width:1e3,height:1e3,path:\"m1000 350l-187 188 0-125-250 0 0 250 125 0-188 187-187-187 125 0 0-250-250 0 0 125-188-188 186-187 0 125 252 0 0-250-125 0 187-188 188 188-125 0 0 250 250 0 0-126 187 188z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_plus:{width:875,height:1e3,path:\"m1 787l0-875 875 0 0 875-875 0z m687-500l-187 0 0-187-125 0 0 187-188 0 0 125 188 0 0 187 125 0 0-187 187 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_minus:{width:875,height:1e3,path:\"m0 788l0-876 875 0 0 876-875 0z m688-500l-500 0 0 125 500 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},autoscale:{width:1e3,height:1e3,path:\"m250 850l-187 0-63 0 0-62 0-188 63 0 0 188 187 0 0 62z m688 0l-188 0 0-62 188 0 0-188 62 0 0 188 0 62-62 0z m-875-938l0 188-63 0 0-188 0-62 63 0 187 0 0 62-187 0z m875 188l0-188-188 0 0-62 188 0 62 0 0 62 0 188-62 0z m-125 188l-1 0-93-94-156 156 156 156 92-93 2 0 0 250-250 0 0-2 93-92-156-156-156 156 94 92 0 2-250 0 0-250 0 0 93 93 157-156-157-156-93 94 0 0 0-250 250 0 0 0-94 93 156 157 156-157-93-93 0 0 250 0 0 250z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_basic:{width:1500,height:1e3,path:\"m375 725l0 0-375-375 375-374 0-1 1125 0 0 750-1125 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_compare:{width:1125,height:1e3,path:\"m187 786l0 2-187-188 188-187 0 0 937 0 0 373-938 0z m0-499l0 1-187-188 188-188 0 0 937 0 0 376-938-1z\",transform:\"matrix(1 0 0 -1 0 850)\"},plotlylogo:{width:1542,height:1e3,path:\"m0-10h182v-140h-182v140z m228 146h183v-286h-183v286z m225 714h182v-1000h-182v1000z m225-285h182v-715h-182v715z m225 142h183v-857h-183v857z m231-428h182v-429h-182v429z m225-291h183v-138h-183v138z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"z-axis\":{width:1e3,height:1e3,path:\"m833 5l-17 108v41l-130-65 130-66c0 0 0 38 0 39 0-1 36-14 39-25 4-15-6-22-16-30-15-12-39-16-56-20-90-22-187-23-279-23-261 0-341 34-353 59 3 60 228 110 228 110-140-8-351-35-351-116 0-120 293-142 474-142 155 0 477 22 477 142 0 50-74 79-163 96z m-374 94c-58-5-99-21-99-40 0-24 65-43 144-43 79 0 143 19 143 43 0 19-42 34-98 40v216h87l-132 135-133-135h88v-216z m167 515h-136v1c16 16 31 34 46 52l84 109v54h-230v-71h124v-1c-16-17-28-32-44-51l-89-114v-51h245v72z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"3d_rotate\":{width:1e3,height:1e3,path:\"m922 660c-5 4-9 7-14 11-359 263-580-31-580-31l-102 28 58-400c0 1 1 1 2 2 118 108 351 249 351 249s-62 27-100 42c88 83 222 183 347 122 16-8 30-17 44-27-2 1-4 2-6 4z m36-329c0 0 64 229-88 296-62 27-124 14-175-11 157-78 225-208 249-266 8-19 11-31 11-31 2 5 6 15 11 32-5-13-8-20-8-20z m-775-239c70-31 117-50 198-32-121 80-199 346-199 346l-96-15-58-12c0 0 55-226 155-287z m603 133l-317-139c0 0 4-4 19-14 7-5 24-15 24-15s-177-147-389 4c235-287 536-112 536-112l31-22 100 299-4-1z m-298-153c6-4 14-9 24-15 0 0-17 10-24 15z\",transform:\"matrix(1 0 0 -1 0 850)\"},camera:{width:1e3,height:1e3,path:\"m500 450c-83 0-150-67-150-150 0-83 67-150 150-150 83 0 150 67 150 150 0 83-67 150-150 150z m400 150h-120c-16 0-34 13-39 29l-31 93c-6 15-23 28-40 28h-340c-16 0-34-13-39-28l-31-94c-6-15-23-28-40-28h-120c-55 0-100-45-100-100v-450c0-55 45-100 100-100h800c55 0 100 45 100 100v450c0 55-45 100-100 100z m-400-550c-138 0-250 112-250 250 0 138 112 250 250 250 138 0 250-112 250-250 0-138-112-250-250-250z m365 380c-19 0-35 16-35 35 0 19 16 35 35 35 19 0 35-16 35-35 0-19-16-35-35-35z\",transform:\"matrix(1 0 0 -1 0 850)\"},movie:{width:1e3,height:1e3,path:\"m938 413l-188-125c0 37-17 71-44 94 64 38 107 107 107 187 0 121-98 219-219 219-121 0-219-98-219-219 0-61 25-117 66-156h-115c30 33 49 76 49 125 0 103-84 187-187 187s-188-84-188-187c0-57 26-107 65-141-38-22-65-62-65-109v-250c0-70 56-126 125-126h500c69 0 125 56 125 126l188-126c34 0 62 28 62 63v375c0 35-28 63-62 63z m-750 0c-69 0-125 56-125 125s56 125 125 125 125-56 125-125-56-125-125-125z m406-1c-87 0-157 70-157 157 0 86 70 156 157 156s156-70 156-156-70-157-156-157z\",transform:\"matrix(1 0 0 -1 0 850)\"},question:{width:857.1,height:1e3,path:\"m500 82v107q0 8-5 13t-13 5h-107q-8 0-13-5t-5-13v-107q0-8 5-13t13-5h107q8 0 13 5t5 13z m143 375q0 49-31 91t-77 65-95 23q-136 0-207-119-9-14 4-24l74-55q4-4 10-4 9 0 14 7 30 38 48 51 19 14 48 14 27 0 48-15t21-33q0-21-11-34t-38-25q-35-16-65-48t-29-70v-20q0-8 5-13t13-5h107q8 0 13 5t5 13q0 10 12 27t30 28q18 10 28 16t25 19 25 27 16 34 7 45z m214-107q0-117-57-215t-156-156-215-58-216 58-155 156-58 215 58 215 155 156 216 58 215-58 156-156 57-215z\",transform:\"matrix(1 0 0 -1 0 850)\"},disk:{width:857.1,height:1e3,path:\"m214-7h429v214h-429v-214z m500 0h72v500q0 8-6 21t-11 20l-157 156q-5 6-19 12t-22 5v-232q0-22-15-38t-38-16h-322q-22 0-37 16t-16 38v232h-72v-714h72v232q0 22 16 38t37 16h465q22 0 38-16t15-38v-232z m-214 518v178q0 8-5 13t-13 5h-107q-7 0-13-5t-5-13v-178q0-8 5-13t13-5h107q7 0 13 5t5 13z m357-18v-518q0-22-15-38t-38-16h-750q-23 0-38 16t-16 38v750q0 22 16 38t38 16h517q23 0 50-12t42-26l156-157q16-15 27-42t11-49z\",transform:\"matrix(1 0 0 -1 0 850)\"},lasso:{width:1031,height:1e3,path:\"m1018 538c-36 207-290 336-568 286-277-48-473-256-436-463 10-57 36-108 76-151-13-66 11-137 68-183 34-28 75-41 114-42l-55-70 0 0c-2-1-3-2-4-3-10-14-8-34 5-45 14-11 34-8 45 4 1 1 2 3 2 5l0 0 113 140c16 11 31 24 45 40 4 3 6 7 8 11 48-3 100 0 151 9 278 48 473 255 436 462z m-624-379c-80 14-149 48-197 96 42 42 109 47 156 9 33-26 47-66 41-105z m-187-74c-19 16-33 37-39 60 50-32 109-55 174-68-42-25-95-24-135 8z m360 75c-34-7-69-9-102-8 8 62-16 128-68 170-73 59-175 54-244-5-9 20-16 40-20 61-28 159 121 317 333 354s407-60 434-217c28-159-121-318-333-355z\",transform:\"matrix(1 0 0 -1 0 850)\"},selectbox:{width:1e3,height:1e3,path:\"m0 850l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-285l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},spikeline:{width:1e3,height:1e3,path:\"M512 409c0-57-46-104-103-104-57 0-104 47-104 104 0 57 47 103 104 103 57 0 103-46 103-103z m-327-39l92 0 0 92-92 0z m-185 0l92 0 0 92-92 0z m370-186l92 0 0 93-92 0z m0-184l92 0 0 92-92 0z\",transform:\"matrix(1.5 0 0 -1.5 0 850)\"},pencil:{width:1792,height:1792,path:\"M491 1536l91-91-235-235-91 91v107h128v128h107zm523-928q0-22-22-22-10 0-17 7l-542 542q-7 7-7 17 0 22 22 22 10 0 17-7l542-542q7-7 7-17zm-54-192l416 416-832 832h-416v-416zm683 96q0 53-37 90l-166 166-416-416 166-165q36-38 90-38 53 0 91 38l235 234q37 39 37 91z\",transform:\"matrix(1 0 0 1 0 1)\"},newplotlylogo:{name:\"newplotlylogo\",svg:\"<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 132 132'><defs><style>.cls-1 {fill: #119dff;} .cls-2 {fill: #25fefd;} .cls-3 {fill: #fff;}</style></defs><title>plotly-logomark</title><g id='symbol'><rect class='cls-1' width='132' height='132' rx='6' ry='6'/><circle class='cls-2' cx='78' cy='54' r='6'/><circle class='cls-2' cx='102' cy='30' r='6'/><circle class='cls-2' cx='78' cy='30' r='6'/><circle class='cls-2' cx='54' cy='30' r='6'/><circle class='cls-2' cx='30' cy='30' r='6'/><circle class='cls-2' cx='30' cy='54' r='6'/><path class='cls-3' d='M30,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,30,72Z'/><path class='cls-3' d='M78,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,78,72Z'/><path class='cls-3' d='M54,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,54,48Z'/><path class='cls-3' d='M102,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,102,48Z'/></g></svg>\"}}},{}],700:[function(t,e,r){\"use strict\";r.isLeftAnchor=function(t){return\"left\"===t.xanchor||\"auto\"===t.xanchor&&t.x<=1/3},r.isCenterAnchor=function(t){return\"center\"===t.xanchor||\"auto\"===t.xanchor&&t.x>1/3&&t.x<2/3},r.isRightAnchor=function(t){return\"right\"===t.xanchor||\"auto\"===t.xanchor&&t.x>=2/3},r.isTopAnchor=function(t){return\"top\"===t.yanchor||\"auto\"===t.yanchor&&t.y>=2/3},r.isMiddleAnchor=function(t){return\"middle\"===t.yanchor||\"auto\"===t.yanchor&&t.y>1/3&&t.y<2/3},r.isBottomAnchor=function(t){return\"bottom\"===t.yanchor||\"auto\"===t.yanchor&&t.y<=1/3}},{}],701:[function(t,e,r){\"use strict\";var n=t(\"./mod\"),i=n.mod,a=n.modHalf,o=Math.PI,s=2*o;function l(t){return Math.abs(t[1]-t[0])>s-1e-14}function c(t,e){return a(e-t,s)}function u(t,e){if(l(e))return!0;var r,n;e[0]<e[1]?(r=e[0],n=e[1]):(r=e[1],n=e[0]),(r=i(r,s))>(n=i(n,s))&&(n+=s);var a=i(t,s),o=a+s;return a>=r&&a<=n||o>=r&&o<=n}function h(t,e,r,n,i,a,c){i=i||0,a=a||0;var u,h,f,p,d,g=l([r,n]);function v(t,e){return[t*Math.cos(e)+i,a-t*Math.sin(e)]}g?(u=0,h=o,f=s):r<n?(u=r,f=n):(u=n,f=r),t<e?(p=t,d=e):(p=e,d=t);var m,y=Math.abs(f-u)<=o?0:1;function x(t,e,r){return\"A\"+[t,t]+\" \"+[0,y,r]+\" \"+v(t,e)}return g?m=null===p?\"M\"+v(d,u)+x(d,h,0)+x(d,f,0)+\"Z\":\"M\"+v(p,u)+x(p,h,0)+x(p,f,0)+\"ZM\"+v(d,u)+x(d,h,1)+x(d,f,1)+\"Z\":null===p?(m=\"M\"+v(d,u)+x(d,f,0),c&&(m+=\"L0,0Z\")):m=\"M\"+v(p,u)+\"L\"+v(d,u)+x(d,f,0)+\"L\"+v(p,f)+x(p,u,1)+\"Z\",m}e.exports={deg2rad:function(t){return t/180*o},rad2deg:function(t){return t/o*180},angleDelta:c,angleDist:function(t,e){return Math.abs(c(t,e))},isFullCircle:l,isAngleInsideSector:u,isPtInsideSector:function(t,e,r,n){return!!u(e,n)&&(r[0]<r[1]?(i=r[0],a=r[1]):(i=r[1],a=r[0]),t>=i&&t<=a);var i,a},pathArc:function(t,e,r,n,i){return h(null,t,e,r,n,i,0)},pathSector:function(t,e,r,n,i){return h(null,t,e,r,n,i,1)},pathAnnulus:function(t,e,r,n,i,a){return h(t,e,r,n,i,a,1)}}},{\"./mod\":726}],702:[function(t,e,r){\"use strict\";var n=Array.isArray,i=\"undefined\"!=typeof ArrayBuffer&&ArrayBuffer.isView?ArrayBuffer:{isView:function(){return!1}},a=\"undefined\"==typeof DataView?function(){}:DataView;function o(t){return i.isView(t)&&!(t instanceof a)}function s(t){return n(t)||o(t)}function l(t,e,r){if(s(t)){if(s(t[0])){for(var n=r,i=0;i<t.length;i++)n=e(n,t[i].length);return n}return t.length}return 0}r.isTypedArray=o,r.isArrayOrTypedArray=s,r.isArray1D=function(t){return!s(t[0])},r.ensureArray=function(t,e){return n(t)||(t=[]),t.length=e,t},r.concat=function(){var t,e,r,i,a,o,s,l,c=[],u=!0,h=0;for(r=0;r<arguments.length;r++)(o=(i=arguments[r]).length)&&(e?c.push(i):(e=i,a=o),n(i)?t=!1:(u=!1,h?t!==i.constructor&&(t=!1):t=i.constructor),h+=o);if(!h)return[];if(!c.length)return e;if(u)return e.concat.apply(e,c);if(t){for((s=new t(h)).set(e),r=0;r<c.length;r++)i=c[r],s.set(i,a),a+=i.length;return s}for(s=new Array(h),l=0;l<e.length;l++)s[l]=e[l];for(r=0;r<c.length;r++){for(i=c[r],l=0;l<i.length;l++)s[a+l]=i[l];a+=l}return s},r.maxRowLength=function(t){return l(t,Math.max,0)},r.minRowLength=function(t){return l(t,Math.min,1/0)}},{}],703:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../constants/numerical\").BADNUM,a=/^['\"%,$#\\s']+|[, ]|['\"%,$#\\s']+$/g;e.exports=function(t){return\"string\"==typeof t&&(t=t.replace(a,\"\")),n(t)?Number(t):i}},{\"../constants/numerical\":695,\"fast-isnumeric\":225}],704:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t._fullLayout;e._glcanvas&&e._glcanvas.size()&&e._glcanvas.each(function(t){t.regl&&t.regl.clear({color:!0,depth:!0})})}},{}],705:[function(t,e,r){\"use strict\";e.exports=function(t){t._responsiveChartHandler&&(window.removeEventListener(\"resize\",t._responsiveChartHandler),delete t._responsiveChartHandler)}},{}],706:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../plots/attributes\"),o=t(\"../components/colorscale/scales\"),s=t(\"../constants/interactions\").DESELECTDIM,l=t(\"./nested_property\"),c=t(\"./regex\").counter,u=t(\"./mod\").modHalf,h=t(\"./array\").isArrayOrTypedArray;function f(t,e){var n=r.valObjectMeta[e.valType];if(e.arrayOk&&h(t))return!0;if(n.validateFunction)return n.validateFunction(t,e);var i={},a=i,o={set:function(t){a=t}};return n.coerceFunction(t,o,i,e),a!==i}r.valObjectMeta={data_array:{coerceFunction:function(t,e,r){h(t)?e.set(t):void 0!==r&&e.set(r)}},enumerated:{coerceFunction:function(t,e,r,n){n.coerceNumber&&(t=+t),-1===n.values.indexOf(t)?e.set(r):e.set(t)},validateFunction:function(t,e){e.coerceNumber&&(t=+t);for(var r=e.values,n=0;n<r.length;n++){var i=String(r[n]);if(\"/\"===i.charAt(0)&&\"/\"===i.charAt(i.length-1)){if(new RegExp(i.substr(1,i.length-2)).test(t))return!0}else if(t===r[n])return!0}return!1}},boolean:{coerceFunction:function(t,e,r){!0===t||!1===t?e.set(t):e.set(r)}},number:{coerceFunction:function(t,e,r,i){!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},integer:{coerceFunction:function(t,e,r,i){t%1||!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},string:{coerceFunction:function(t,e,r,n){if(\"string\"!=typeof t){var i=\"number\"==typeof t;!0!==n.strict&&i?e.set(String(t)):e.set(r)}else n.noBlank&&!t?e.set(r):e.set(t)}},color:{coerceFunction:function(t,e,r){i(t).isValid()?e.set(t):e.set(r)}},colorlist:{coerceFunction:function(t,e,r){Array.isArray(t)&&t.length&&t.every(function(t){return i(t).isValid()})?e.set(t):e.set(r)}},colorscale:{coerceFunction:function(t,e,r){e.set(o.get(t,r))}},angle:{coerceFunction:function(t,e,r){\"auto\"===t?e.set(\"auto\"):n(t)?e.set(u(+t,360)):e.set(r)}},subplotid:{coerceFunction:function(t,e,r,n){var i=n.regex||c(r);\"string\"==typeof t&&i.test(t)?e.set(t):e.set(r)},validateFunction:function(t,e){var r=e.dflt;return t===r||\"string\"==typeof t&&!!c(r).test(t)}},flaglist:{coerceFunction:function(t,e,r,n){if(\"string\"==typeof t)if(-1===(n.extras||[]).indexOf(t)){for(var i=t.split(\"+\"),a=0;a<i.length;){var o=i[a];-1===n.flags.indexOf(o)||i.indexOf(o)<a?i.splice(a,1):a++}i.length?e.set(i.join(\"+\")):e.set(r)}else e.set(t);else e.set(r)}},any:{coerceFunction:function(t,e,r){void 0===t?e.set(r):e.set(t)}},info_array:{coerceFunction:function(t,e,n,i){function a(t,e,n){var i,a={set:function(t){i=t}};return void 0===n&&(n=e.dflt),r.valObjectMeta[e.valType].coerceFunction(t,a,n,e),i}var o=2===i.dimensions||\"1-2\"===i.dimensions&&Array.isArray(t)&&Array.isArray(t[0]);if(Array.isArray(t)){var s,l,c,u,h,f,p=i.items,d=[],g=Array.isArray(p),v=g&&o&&Array.isArray(p[0]),m=o&&g&&!v,y=g&&!m?p.length:t.length;if(n=Array.isArray(n)?n:[],o)for(s=0;s<y;s++)for(d[s]=[],c=Array.isArray(t[s])?t[s]:[],h=m?p.length:g?p[s].length:c.length,l=0;l<h;l++)u=m?p[l]:g?p[s][l]:p,void 0!==(f=a(c[l],u,(n[s]||[])[l]))&&(d[s][l]=f);else for(s=0;s<y;s++)void 0!==(f=a(t[s],g?p[s]:p,n[s]))&&(d[s]=f);e.set(d)}else e.set(n)},validateFunction:function(t,e){if(!Array.isArray(t))return!1;var r=e.items,n=Array.isArray(r),i=2===e.dimensions;if(!e.freeLength&&t.length!==r.length)return!1;for(var a=0;a<t.length;a++)if(i){if(!Array.isArray(t[a])||!e.freeLength&&t[a].length!==r[a].length)return!1;for(var o=0;o<t[a].length;o++)if(!f(t[a][o],n?r[a][o]:r))return!1}else if(!f(t[a],n?r[a]:r))return!1;return!0}}},r.coerce=function(t,e,n,i,a){var o=l(n,i).get(),s=l(t,i),c=l(e,i),u=s.get(),p=e._template;if(void 0===u&&p&&(u=l(p,i).get(),p=0),void 0===a&&(a=o.dflt),o.arrayOk&&h(u))return c.set(u),u;var d=r.valObjectMeta[o.valType].coerceFunction;d(u,c,a,o);var g=c.get();return p&&g===a&&!f(u,o)&&(d(u=l(p,i).get(),c,a,o),g=c.get()),g},r.coerce2=function(t,e,n,i,a){var o=l(t,i),s=r.coerce(t,e,n,i,a),c=o.get();return null!=c&&s},r.coerceFont=function(t,e,r){var n={};return r=r||{},n.family=t(e+\".family\",r.family),n.size=t(e+\".size\",r.size),n.color=t(e+\".color\",r.color),n},r.coerceHoverinfo=function(t,e,n){var i,o=e._module.attributes,s=o.hoverinfo?o:a,l=s.hoverinfo;if(1===n._dataLength){var c=\"all\"===l.dflt?l.flags.slice():l.dflt.split(\"+\");c.splice(c.indexOf(\"name\"),1),i=c.join(\"+\")}return r.coerce(t,e,s,\"hoverinfo\",i)},r.coerceSelectionMarkerOpacity=function(t,e){if(t.marker){var r,n,i=t.marker.opacity;if(void 0!==i)h(i)||t.selected||t.unselected||(r=i,n=s*i),e(\"selected.marker.opacity\",r),e(\"unselected.marker.opacity\",n)}},r.validate=f},{\"../components/colorscale/scales\":608,\"../constants/interactions\":694,\"../plots/attributes\":764,\"./array\":702,\"./mod\":726,\"./nested_property\":727,\"./regex\":735,\"fast-isnumeric\":225,tinycolor2:537}],707:[function(t,e,r){\"use strict\";var n,i,a=t(\"d3\"),o=t(\"fast-isnumeric\"),s=t(\"./loggers\"),l=t(\"./mod\").mod,c=t(\"../constants/numerical\"),u=c.BADNUM,h=c.ONEDAY,f=c.ONEHOUR,p=c.ONEMIN,d=c.ONESEC,g=c.EPOCHJD,v=t(\"../registry\"),m=a.time.format.utc,y=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\d)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d:?\\d\\d)?)?)?)?)?\\s*$/m,x=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\di?)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d:?\\d\\d)?)?)?)?)?\\s*$/m,b=(new Date).getFullYear()-70;function _(t){return t&&v.componentsRegistry.calendars&&\"string\"==typeof t&&\"gregorian\"!==t}function w(t,e){return String(t+Math.pow(10,e)).substr(1)}r.dateTick0=function(t,e){return _(t)?e?v.getComponentMethod(\"calendars\",\"CANONICAL_SUNDAY\")[t]:v.getComponentMethod(\"calendars\",\"CANONICAL_TICK\")[t]:e?\"2000-01-02\":\"2000-01-01\"},r.dfltRange=function(t){return _(t)?v.getComponentMethod(\"calendars\",\"DFLTRANGE\")[t]:[\"2000-01-01\",\"2001-01-01\"]},r.isJSDate=function(t){return\"object\"==typeof t&&null!==t&&\"function\"==typeof t.getTime},r.dateTime2ms=function(t,e){if(r.isJSDate(t)){var a=t.getTimezoneOffset()*p,o=(t.getUTCMinutes()-t.getMinutes())*p+(t.getUTCSeconds()-t.getSeconds())*d+(t.getUTCMilliseconds()-t.getMilliseconds());if(o){var s=3*p;a=a-s/2+l(o-a+s/2,s)}return(t=Number(t)-a)>=n&&t<=i?t:u}if(\"string\"!=typeof t&&\"number\"!=typeof t)return u;t=String(t);var c=_(e),m=t.charAt(0);!c||\"G\"!==m&&\"g\"!==m||(t=t.substr(1),e=\"\");var w=c&&\"chinese\"===e.substr(0,7),k=t.match(w?x:y);if(!k)return u;var T=k[1],A=k[3]||\"1\",M=Number(k[5]||1),S=Number(k[7]||0),E=Number(k[9]||0),C=Number(k[11]||0);if(c){if(2===T.length)return u;var L;T=Number(T);try{var P=v.getComponentMethod(\"calendars\",\"getCal\")(e);if(w){var O=\"i\"===A.charAt(A.length-1);A=parseInt(A,10),L=P.newDate(T,P.toMonthIndex(T,A,O),M)}else L=P.newDate(T,Number(A),M)}catch(t){return u}return L?(L.toJD()-g)*h+S*f+E*p+C*d:u}T=2===T.length?(Number(T)+2e3-b)%100+b:Number(T),A-=1;var z=new Date(Date.UTC(2e3,A,M,S,E));return z.setUTCFullYear(T),z.getUTCMonth()!==A?u:z.getUTCDate()!==M?u:z.getTime()+C*d},n=r.MIN_MS=r.dateTime2ms(\"-9999\"),i=r.MAX_MS=r.dateTime2ms(\"9999-12-31 23:59:59.9999\"),r.isDateTime=function(t,e){return r.dateTime2ms(t,e)!==u};var k=90*h,T=3*f,A=5*p;function M(t,e,r,n,i){if((e||r||n||i)&&(t+=\" \"+w(e,2)+\":\"+w(r,2),(n||i)&&(t+=\":\"+w(n,2),i))){for(var a=4;i%10==0;)a-=1,i/=10;t+=\".\"+w(i,a)}return t}r.ms2DateTime=function(t,e,r){if(\"number\"!=typeof t||!(t>=n&&t<=i))return u;e||(e=0);var a,o,s,c,y,x,b=Math.floor(10*l(t+.05,1)),w=Math.round(t-b/10);if(_(r)){var S=Math.floor(w/h)+g,E=Math.floor(l(t,h));try{a=v.getComponentMethod(\"calendars\",\"getCal\")(r).fromJD(S).formatDate(\"yyyy-mm-dd\")}catch(t){a=m(\"G%Y-%m-%d\")(new Date(w))}if(\"-\"===a.charAt(0))for(;a.length<11;)a=\"-0\"+a.substr(1);else for(;a.length<10;)a=\"0\"+a;o=e<k?Math.floor(E/f):0,s=e<k?Math.floor(E%f/p):0,c=e<T?Math.floor(E%p/d):0,y=e<A?E%d*10+b:0}else x=new Date(w),a=m(\"%Y-%m-%d\")(x),o=e<k?x.getUTCHours():0,s=e<k?x.getUTCMinutes():0,c=e<T?x.getUTCSeconds():0,y=e<A?10*x.getUTCMilliseconds()+b:0;return M(a,o,s,c,y)},r.ms2DateTimeLocal=function(t){if(!(t>=n+h&&t<=i-h))return u;var e=Math.floor(10*l(t+.05,1)),r=new Date(Math.round(t-e/10));return M(a.time.format(\"%Y-%m-%d\")(r),r.getHours(),r.getMinutes(),r.getSeconds(),10*r.getUTCMilliseconds()+e)},r.cleanDate=function(t,e,n){if(t===u)return e;if(r.isJSDate(t)||\"number\"==typeof t&&isFinite(t)){if(_(n))return s.error(\"JS Dates and milliseconds are incompatible with world calendars\",t),e;if(!(t=r.ms2DateTimeLocal(+t))&&void 0!==e)return e}else if(!r.isDateTime(t,n))return s.error(\"unrecognized date\",t),e;return t};var S=/%\\d?f/g;function E(t,e,r,n){t=t.replace(S,function(t){var r=Math.min(+t.charAt(1)||6,6);return(e/1e3%1+2).toFixed(r).substr(2).replace(/0+$/,\"\")||\"0\"});var i=new Date(Math.floor(e+.05));if(_(n))try{t=v.getComponentMethod(\"calendars\",\"worldCalFmt\")(t,e,n)}catch(t){return\"Invalid\"}return r(t)(i)}var C=[59,59.9,59.99,59.999,59.9999];r.formatDate=function(t,e,r,n,i,a){if(i=_(i)&&i,!e)if(\"y\"===r)e=a.year;else if(\"m\"===r)e=a.month;else{if(\"d\"!==r)return function(t,e){var r=l(t+.05,h),n=w(Math.floor(r/f),2)+\":\"+w(l(Math.floor(r/p),60),2);if(\"M\"!==e){o(e)||(e=0);var i=(100+Math.min(l(t/d,60),C[e])).toFixed(e).substr(1);e>0&&(i=i.replace(/0+$/,\"\").replace(/[\\.]$/,\"\")),n+=\":\"+i}return n}(t,r)+\"\\n\"+E(a.dayMonthYear,t,n,i);e=a.dayMonth+\"\\n\"+a.year}return E(e,t,n,i)};var L=3*h;r.incrementMonth=function(t,e,r){r=_(r)&&r;var n=l(t,h);if(t=Math.round(t-n),r)try{var i=Math.round(t/h)+g,a=v.getComponentMethod(\"calendars\",\"getCal\")(r),o=a.fromJD(i);return e%12?a.add(o,e,\"m\"):a.add(o,e/12,\"y\"),(o.toJD()-g)*h+n}catch(e){s.error(\"invalid ms \"+t+\" in calendar \"+r)}var c=new Date(t+L);return c.setUTCMonth(c.getUTCMonth()+e)+n-L},r.findExactDates=function(t,e){for(var r,n,i=0,a=0,s=0,l=0,c=_(e)&&v.getComponentMethod(\"calendars\",\"getCal\")(e),u=0;u<t.length;u++)if(n=t[u],o(n)){if(!(n%h))if(c)try{1===(r=c.fromJD(n/h+g)).day()?1===r.month()?i++:a++:s++}catch(t){}else 1===(r=new Date(n)).getUTCDate()?0===r.getUTCMonth()?i++:a++:s++}else l++;s+=a+=i;var f=t.length-l;return{exactYears:i/f,exactMonths:a/f,exactDays:s/f}}},{\"../constants/numerical\":695,\"../registry\":847,\"./loggers\":723,\"./mod\":726,d3:163,\"fast-isnumeric\":225}],708:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./loggers\");function a(t){var e=t&&t.parentNode;e&&e.removeChild(t)}function o(t,e,r){var n=\"plotly.js-style-\"+t,a=document.getElementById(n);a||((a=document.createElement(\"style\")).setAttribute(\"id\",n),a.appendChild(document.createTextNode(\"\")),document.head.appendChild(a));var o=a.sheet;o.insertRule?o.insertRule(e+\"{\"+r+\"}\",0):o.addRule?o.addRule(e,r,0):i.warn(\"addStyleRule failed\")}e.exports={getGraphDiv:function(t){var e;if(\"string\"==typeof t){if(null===(e=document.getElementById(t)))throw new Error(\"No DOM element with id '\"+t+\"' exists on the page.\");return e}if(null==t)throw new Error(\"DOM element provided is null or undefined\");return t},isPlotDiv:function(t){var e=n.select(t);return e.node()instanceof HTMLElement&&e.size()&&e.classed(\"js-plotly-plot\")},removeElement:a,addStyleRule:function(t,e){o(\"global\",t,e)},addRelatedStyleRule:o,deleteRelatedStyleRule:function(t){var e=\"plotly.js-style-\"+t,r=document.getElementById(e);r&&a(r)}}},{\"./loggers\":723,d3:163}],709:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i={init:function(t){if(t._ev instanceof n)return t;var e=new n,r=new n;return t._ev=e,t._internalEv=r,t.on=e.on.bind(e),t.once=e.once.bind(e),t.removeListener=e.removeListener.bind(e),t.removeAllListeners=e.removeAllListeners.bind(e),t._internalOn=r.on.bind(r),t._internalOnce=r.once.bind(r),t._removeInternalListener=r.removeListener.bind(r),t._removeAllInternalListeners=r.removeAllListeners.bind(r),t.emit=function(n,i){\"undefined\"!=typeof jQuery&&jQuery(t).trigger(n,i),e.emit(n,i),r.emit(n,i)},t},triggerHandler:function(t,e,r){var n,i;\"undefined\"!=typeof jQuery&&(n=jQuery(t).triggerHandler(e,r));var a=t._ev;if(!a)return n;var o,s=a._events[e];if(!s)return n;function l(t){return t.listener?(a.removeListener(e,t.listener),t.fired?void 0:(t.fired=!0,t.listener.apply(a,[r]))):t.apply(a,[r])}for(s=Array.isArray(s)?s:[s],o=0;o<s.length-1;o++)l(s[o]);return i=l(s[o]),void 0!==n?n:i},purge:function(t){return delete t._ev,delete t.on,delete t.once,delete t.removeListener,delete t.removeAllListeners,delete t.emit,delete t._ev,delete t._internalEv,delete t._internalOn,delete t._internalOnce,delete t._removeInternalListener,delete t._removeAllInternalListeners,t}};e.exports=i},{events:104}],710:[function(t,e,r){\"use strict\";var n=t(\"./is_plain_object.js\"),i=Array.isArray;function a(t,e,r,o){var s,l,c,u,h,f,p=t[0],d=t.length;if(2===d&&i(p)&&i(t[1])&&0===p.length){if(function(t,e){var r,n;for(r=0;r<t.length;r++){if(null!==(n=t[r])&&\"object\"==typeof n)return!1;void 0!==n&&(e[r]=n)}return!0}(t[1],p))return p;p.splice(0,p.length)}for(var g=1;g<d;g++)for(l in s=t[g])c=p[l],u=s[l],o&&i(u)?p[l]=u:e&&u&&(n(u)||(h=i(u)))?(h?(h=!1,f=c&&i(c)?c:[]):f=c&&n(c)?c:{},p[l]=a([f,u],e,r,o)):(\"undefined\"!=typeof u||r)&&(p[l]=u);return p}r.extendFlat=function(){return a(arguments,!1,!1,!1)},r.extendDeep=function(){return a(arguments,!0,!1,!1)},r.extendDeepAll=function(){return a(arguments,!0,!0,!1)},r.extendDeepNoArrays=function(){return a(arguments,!0,!1,!0)}},{\"./is_plain_object.js\":720}],711:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e={},r=[],n=0,i=0;i<t.length;i++){var a=t[i];1!==e[a]&&(e[a]=1,r[n++]=a)}return r}},{}],712:[function(t,e,r){\"use strict\";function n(t){return!0===t.visible}function i(t){var e=t[0].trace;return!0===e.visible&&0!==e._length}e.exports=function(t){for(var e,r=(e=t,Array.isArray(e)&&Array.isArray(e[0])&&e[0][0]&&e[0][0].trace?i:n),a=[],o=0;o<t.length;o++){var s=t[o];r(s)&&a.push(s)}return a}},{}],713:[function(t,e,r){\"use strict\";var n=t(\"country-regex\"),i=t(\"../lib\"),a=Object.keys(n),o={\"ISO-3\":i.identity,\"USA-states\":i.identity,\"country names\":function(t){for(var e=0;e<a.length;e++){var r=a[e],o=new RegExp(n[r]);if(o.test(t.trim().toLowerCase()))return r}return i.log(\"Unrecognized country name: \"+t+\".\"),!1}};e.exports={locationToFeature:function(t,e,r){if(!e||\"string\"!=typeof e)return!1;var n,a,s,l=o[t](e);if(l){if(\"USA-states\"===t)for(n=[],s=0;s<r.length;s++)(a=r[s]).properties&&a.properties.gu&&\"USA\"===a.properties.gu&&n.push(a);else n=r;for(s=0;s<n.length;s++)if((a=n[s]).id===l)return a;i.log([\"Location with id\",l,\"does not have a matching topojson feature at this resolution.\"].join(\" \"))}return!1}}},{\"../lib\":719,\"country-regex\":134}],714:[function(t,e,r){\"use strict\";var n=t(\"../constants/numerical\").BADNUM;r.calcTraceToLineCoords=function(t){for(var e=t[0].trace.connectgaps,r=[],i=[],a=0;a<t.length;a++){var o=t[a].lonlat;o[0]!==n?i.push(o):!e&&i.length>0&&(r.push(i),i=[])}return i.length>0&&r.push(i),r},r.makeLine=function(t){return 1===t.length?{type:\"LineString\",coordinates:t[0]}:{type:\"MultiLineString\",coordinates:t}},r.makePolygon=function(t){if(1===t.length)return{type:\"Polygon\",coordinates:t};for(var e=new Array(t.length),r=0;r<t.length;r++)e[r]=[t[r]];return{type:\"MultiPolygon\",coordinates:e}},r.makeBlank=function(){return{type:\"Point\",coordinates:[]}}},{\"../constants/numerical\":695}],715:[function(t,e,r){\"use strict\";var n,i,a,o=t(\"./mod\").mod;function s(t,e,r,n,i,a,o,s){var l=r-t,c=i-t,u=o-i,h=n-e,f=a-e,p=s-a,d=l*p-u*h;if(0===d)return null;var g=(c*p-u*f)/d,v=(c*h-l*f)/d;return v<0||v>1||g<0||g>1?null:{x:t+l*g,y:e+h*g}}function l(t,e,r,n,i){var a=n*t+i*e;if(a<0)return n*n+i*i;if(a>r){var o=n-t,s=i-e;return o*o+s*s}var l=n*e-i*t;return l*l/r}r.segmentsIntersect=s,r.segmentDistance=function(t,e,r,n,i,a,o,c){if(s(t,e,r,n,i,a,o,c))return 0;var u=r-t,h=n-e,f=o-i,p=c-a,d=u*u+h*h,g=f*f+p*p,v=Math.min(l(u,h,d,i-t,a-e),l(u,h,d,o-t,c-e),l(f,p,g,t-i,e-a),l(f,p,g,r-i,n-a));return Math.sqrt(v)},r.getTextLocation=function(t,e,r,s){if(t===i&&s===a||(n={},i=t,a=s),n[r])return n[r];var l=t.getPointAtLength(o(r-s/2,e)),c=t.getPointAtLength(o(r+s/2,e)),u=Math.atan((c.y-l.y)/(c.x-l.x)),h=t.getPointAtLength(o(r,e)),f={x:(4*h.x+l.x+c.x)/6,y:(4*h.y+l.y+c.y)/6,theta:u};return n[r]=f,f},r.clearLocationCache=function(){i=null},r.getVisibleSegment=function(t,e,r){var n,i,a=e.left,o=e.right,s=e.top,l=e.bottom,c=0,u=t.getTotalLength(),h=u;function f(e){var r=t.getPointAtLength(e);0===e?n=r:e===u&&(i=r);var c=r.x<a?a-r.x:r.x>o?r.x-o:0,h=r.y<s?s-r.y:r.y>l?r.y-l:0;return Math.sqrt(c*c+h*h)}for(var p=f(c);p;){if((c+=p+r)>h)return;p=f(c)}for(p=f(h);p;){if(c>(h-=p+r))return;p=f(h)}return{min:c,max:h,len:h-c,total:u,isClosed:0===c&&h===u&&Math.abs(n.x-i.x)<.1&&Math.abs(n.y-i.y)<.1}},r.findPointOnPath=function(t,e,r,n){for(var i,a,o,s=(n=n||{}).pathLength||t.getTotalLength(),l=n.tolerance||.001,c=n.iterationLimit||30,u=t.getPointAtLength(0)[r]>t.getPointAtLength(s)[r]?-1:1,h=0,f=0,p=s;h<c;){if(i=(f+p)/2,o=(a=t.getPointAtLength(i))[r]-e,Math.abs(o)<l)return a;u*o>0?p=i:f=i,h++}return a}},{\"./mod\":726}],716:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"color-normalize\"),o=t(\"../components/colorscale\"),s=t(\"../components/color/attributes\").defaultLine,l=t(\"./array\").isArrayOrTypedArray,c=a(s),u=1;function h(t,e){var r=t;return r[3]*=e,r}function f(t){if(n(t))return c;var e=a(t);return e.length?e:c}function p(t){return n(t)?t:u}e.exports={formatColor:function(t,e,r){var n,i,s,d,g,v=t.color,m=l(v),y=l(e),x=o.extractOpts(t),b=[];if(n=void 0!==x.colorscale?o.makeColorScaleFuncFromTrace(t):f,i=m?function(t,e){return void 0===t[e]?c:a(n(t[e]))}:f,s=y?function(t,e){return void 0===t[e]?u:p(t[e])}:p,m||y)for(var _=0;_<r;_++)d=i(v,_),g=s(e,_),b[_]=h(d,g);else b=h(a(v),e);return b},parseColorScale:function(t,e){void 0===e&&(e=1);var r=o.extractOpts(t);return(r.reversescale?o.flipScale(r.colorscale):r.colorscale).map(function(t){var r=t[0],n=i(t[1]).toRgb();return{index:r,rgb:[n.r,n.g,n.b,e]}})}}},{\"../components/color/attributes\":592,\"../components/colorscale\":605,\"./array\":702,\"color-normalize\":120,\"fast-isnumeric\":225,tinycolor2:537}],717:[function(t,e,r){\"use strict\";var n=t(\"./identity\");function i(t){return[t]}e.exports={keyFun:function(t){return t.key},repeat:i,descend:n,wrap:i,unwrap:function(t){return t[0]}}},{\"./identity\":718}],718:[function(t,e,r){\"use strict\";e.exports=function(t){return t}},{}],719:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../constants/numerical\"),o=a.FP_SAFE,s=a.BADNUM,l=e.exports={};l.nestedProperty=t(\"./nested_property\"),l.keyedContainer=t(\"./keyed_container\"),l.relativeAttr=t(\"./relative_attr\"),l.isPlainObject=t(\"./is_plain_object\"),l.toLogRange=t(\"./to_log_range\"),l.relinkPrivateKeys=t(\"./relink_private\");var c=t(\"./array\");l.isTypedArray=c.isTypedArray,l.isArrayOrTypedArray=c.isArrayOrTypedArray,l.isArray1D=c.isArray1D,l.ensureArray=c.ensureArray,l.concat=c.concat,l.maxRowLength=c.maxRowLength,l.minRowLength=c.minRowLength;var u=t(\"./mod\");l.mod=u.mod,l.modHalf=u.modHalf;var h=t(\"./coerce\");l.valObjectMeta=h.valObjectMeta,l.coerce=h.coerce,l.coerce2=h.coerce2,l.coerceFont=h.coerceFont,l.coerceHoverinfo=h.coerceHoverinfo,l.coerceSelectionMarkerOpacity=h.coerceSelectionMarkerOpacity,l.validate=h.validate;var f=t(\"./dates\");l.dateTime2ms=f.dateTime2ms,l.isDateTime=f.isDateTime,l.ms2DateTime=f.ms2DateTime,l.ms2DateTimeLocal=f.ms2DateTimeLocal,l.cleanDate=f.cleanDate,l.isJSDate=f.isJSDate,l.formatDate=f.formatDate,l.incrementMonth=f.incrementMonth,l.dateTick0=f.dateTick0,l.dfltRange=f.dfltRange,l.findExactDates=f.findExactDates,l.MIN_MS=f.MIN_MS,l.MAX_MS=f.MAX_MS;var p=t(\"./search\");l.findBin=p.findBin,l.sorterAsc=p.sorterAsc,l.sorterDes=p.sorterDes,l.distinctVals=p.distinctVals,l.roundUp=p.roundUp,l.sort=p.sort,l.findIndexOfMin=p.findIndexOfMin;var d=t(\"./stats\");l.aggNums=d.aggNums,l.len=d.len,l.mean=d.mean,l.median=d.median,l.midRange=d.midRange,l.variance=d.variance,l.stdev=d.stdev,l.interp=d.interp;var g=t(\"./matrix\");l.init2dArray=g.init2dArray,l.transposeRagged=g.transposeRagged,l.dot=g.dot,l.translationMatrix=g.translationMatrix,l.rotationMatrix=g.rotationMatrix,l.rotationXYMatrix=g.rotationXYMatrix,l.apply2DTransform=g.apply2DTransform,l.apply2DTransform2=g.apply2DTransform2;var v=t(\"./angles\");l.deg2rad=v.deg2rad,l.rad2deg=v.rad2deg,l.angleDelta=v.angleDelta,l.angleDist=v.angleDist,l.isFullCircle=v.isFullCircle,l.isAngleInsideSector=v.isAngleInsideSector,l.isPtInsideSector=v.isPtInsideSector,l.pathArc=v.pathArc,l.pathSector=v.pathSector,l.pathAnnulus=v.pathAnnulus;var m=t(\"./anchor_utils\");l.isLeftAnchor=m.isLeftAnchor,l.isCenterAnchor=m.isCenterAnchor,l.isRightAnchor=m.isRightAnchor,l.isTopAnchor=m.isTopAnchor,l.isMiddleAnchor=m.isMiddleAnchor,l.isBottomAnchor=m.isBottomAnchor;var y=t(\"./geometry2d\");l.segmentsIntersect=y.segmentsIntersect,l.segmentDistance=y.segmentDistance,l.getTextLocation=y.getTextLocation,l.clearLocationCache=y.clearLocationCache,l.getVisibleSegment=y.getVisibleSegment,l.findPointOnPath=y.findPointOnPath;var x=t(\"./extend\");l.extendFlat=x.extendFlat,l.extendDeep=x.extendDeep,l.extendDeepAll=x.extendDeepAll,l.extendDeepNoArrays=x.extendDeepNoArrays;var b=t(\"./loggers\");l.log=b.log,l.warn=b.warn,l.error=b.error;var _=t(\"./regex\");l.counterRegex=_.counter;var w=t(\"./throttle\");l.throttle=w.throttle,l.throttleDone=w.done,l.clearThrottle=w.clear;var k=t(\"./dom\");function T(t){var e={};for(var r in t)for(var n=t[r],i=0;i<n.length;i++)e[n[i]]=+r;return e}l.getGraphDiv=k.getGraphDiv,l.isPlotDiv=k.isPlotDiv,l.removeElement=k.removeElement,l.addStyleRule=k.addStyleRule,l.addRelatedStyleRule=k.addRelatedStyleRule,l.deleteRelatedStyleRule=k.deleteRelatedStyleRule,l.clearResponsive=t(\"./clear_responsive\"),l.makeTraceGroups=t(\"./make_trace_groups\"),l._=t(\"./localize\"),l.notifier=t(\"./notifier\"),l.filterUnique=t(\"./filter_unique\"),l.filterVisible=t(\"./filter_visible\"),l.pushUnique=t(\"./push_unique\"),l.cleanNumber=t(\"./clean_number\"),l.ensureNumber=function(t){return i(t)?(t=Number(t))<-o||t>o?s:i(t)?Number(t):s:s},l.isIndex=function(t,e){return!(void 0!==e&&t>=e)&&(i(t)&&t>=0&&t%1==0)},l.noop=t(\"./noop\"),l.identity=t(\"./identity\"),l.repeat=function(t,e){for(var r=new Array(e),n=0;n<e;n++)r[n]=t;return r},l.swapAttrs=function(t,e,r,n){r||(r=\"x\"),n||(n=\"y\");for(var i=0;i<e.length;i++){var a=e[i],o=l.nestedProperty(t,a.replace(\"?\",r)),s=l.nestedProperty(t,a.replace(\"?\",n)),c=o.get();o.set(s.get()),s.set(c)}},l.raiseToTop=function(t){t.parentNode.appendChild(t)},l.cancelTransition=function(t){return t.transition().duration(0)},l.constrain=function(t,e,r){return e>r?Math.max(r,Math.min(e,t)):Math.max(e,Math.min(r,t))},l.bBoxIntersect=function(t,e,r){return r=r||0,t.left<=e.right+r&&e.left<=t.right+r&&t.top<=e.bottom+r&&e.top<=t.bottom+r},l.simpleMap=function(t,e,r,n){for(var i=t.length,a=new Array(i),o=0;o<i;o++)a[o]=e(t[o],r,n);return a},l.randstr=function t(e,r,n,i){if(n||(n=16),void 0===r&&(r=24),r<=0)return\"0\";var a,o,s=Math.log(Math.pow(2,r))/Math.log(n),c=\"\";for(a=2;s===1/0;a*=2)s=Math.log(Math.pow(2,r/a))/Math.log(n)*a;var u=s-Math.floor(s);for(a=0;a<Math.floor(s);a++)c=Math.floor(Math.random()*n).toString(n)+c;u&&(o=Math.pow(n,u),c=Math.floor(Math.random()*o).toString(n)+c);var h=parseInt(c,n);return e&&e[c]||h!==1/0&&h>=Math.pow(2,r)?i>10?(l.warn(\"randstr failed uniqueness\"),c):t(e,r,n,(i||0)+1):c},l.OptionControl=function(t,e){t||(t={}),e||(e=\"opt\");var r={optionList:[],_newoption:function(n){n[e]=t,r[n.name]=n,r.optionList.push(n)}};return r[\"_\"+e]=t,r},l.smooth=function(t,e){if((e=Math.round(e)||0)<2)return t;var r,n,i,a,o=t.length,s=2*o,l=2*e-1,c=new Array(l),u=new Array(o);for(r=0;r<l;r++)c[r]=(1-Math.cos(Math.PI*(r+1)/e))/(2*e);for(r=0;r<o;r++){for(a=0,n=0;n<l;n++)(i=r+n+1-e)<-o?i-=s*Math.round(i/s):i>=s&&(i-=s*Math.floor(i/s)),i<0?i=-1-i:i>=o&&(i=s-1-i),a+=t[i]*c[n];u[r]=a}return u},l.syncOrAsync=function(t,e,r){var n;function i(){return l.syncOrAsync(t,e,r)}for(;t.length;)if((n=(0,t.splice(0,1)[0])(e))&&n.then)return n.then(i).then(void 0,l.promiseError);return r&&r(e)},l.stripTrailingSlash=function(t){return\"/\"===t.substr(-1)?t.substr(0,t.length-1):t},l.noneOrAll=function(t,e,r){if(t){var n,i=!1,a=!0;for(n=0;n<r.length;n++)null!=t[r[n]]?i=!0:a=!1;if(i&&!a)for(n=0;n<r.length;n++)t[r[n]]=e[r[n]]}},l.mergeArray=function(t,e,r,n){var i=\"function\"==typeof n;if(l.isArrayOrTypedArray(t))for(var a=Math.min(t.length,e.length),o=0;o<a;o++){var s=t[o];e[o][r]=i?n(s):s}},l.mergeArrayCastPositive=function(t,e,r){return l.mergeArray(t,e,r,function(t){var e=+t;return isFinite(e)&&e>0?e:0})},l.fillArray=function(t,e,r,n){if(n=n||l.identity,l.isArrayOrTypedArray(t))for(var i=0;i<e.length;i++)e[i][r]=n(t[i])},l.castOption=function(t,e,r,n){n=n||l.identity;var i=l.nestedProperty(t,r).get();return l.isArrayOrTypedArray(i)?Array.isArray(e)&&l.isArrayOrTypedArray(i[e[0]])?n(i[e[0]][e[1]]):n(i[e]):i},l.extractOption=function(t,e,r,n){if(r in t)return t[r];var i=l.nestedProperty(e,n).get();return Array.isArray(i)?void 0:i},l.tagSelected=function(t,e,r){var n,i,a=e.selectedpoints,o=e._indexToPoints;o&&(n=T(o));for(var s=0;s<a.length;s++){var c=a[s];if(l.isIndex(c)){var u=n?n[c]:c,h=r?r[u]:u;void 0!==(i=h)&&i<t.length&&(t[h].selected=1)}}},l.selIndices2selPoints=function(t){var e=t.selectedpoints,r=t._indexToPoints;if(r){for(var n=T(r),i=[],a=0;a<e.length;a++){var o=e[a];if(l.isIndex(o)){var s=n[o];l.isIndex(s)&&i.push(s)}}return i}return e},l.getTargetArray=function(t,e){var r=e.target;if(\"string\"==typeof r&&r){var n=l.nestedProperty(t,r).get();return!!Array.isArray(n)&&n}return!!Array.isArray(r)&&r},l.minExtend=function(t,e){var r={};\"object\"!=typeof e&&(e={});var n,i,a,o=Object.keys(t);for(n=0;n<o.length;n++)a=t[i=o[n]],\"_\"!==i.charAt(0)&&\"function\"!=typeof a&&(\"module\"===i?r[i]=a:Array.isArray(a)?r[i]=\"colorscale\"===i?a.slice():a.slice(0,3):r[i]=a&&\"object\"==typeof a?l.minExtend(t[i],e[i]):a);for(o=Object.keys(e),n=0;n<o.length;n++)\"object\"==typeof(a=e[i=o[n]])&&i in r&&\"object\"==typeof r[i]||(r[i]=a);return r},l.titleCase=function(t){return t.charAt(0).toUpperCase()+t.substr(1)},l.containsAny=function(t,e){for(var r=0;r<e.length;r++)if(-1!==t.indexOf(e[r]))return!0;return!1},l.isIE=function(){return\"undefined\"!=typeof window.navigator.msSaveBlob};var A=/MSIE [1-9]\\./;l.isIE9orBelow=function(){return l.isIE()&&A.test(window.navigator.userAgent)};var M=/Version\\/[\\d\\.]+.*Safari/;l.isSafari=function(){return M.test(window.navigator.userAgent)},l.isD3Selection=function(t){return t&&\"function\"==typeof t.classed},l.ensureSingle=function(t,e,r,n){var i=t.select(e+(r?\".\"+r:\"\"));if(i.size())return i;var a=t.append(e);return r&&a.classed(r,!0),n&&a.call(n),a},l.ensureSingleById=function(t,e,r,n){var i=t.select(e+\"#\"+r);if(i.size())return i;var a=t.append(e).attr(\"id\",r);return n&&a.call(n),a},l.objectFromPath=function(t,e){for(var r,n=t.split(\".\"),i=r={},a=0;a<n.length;a++){var o=n[a],s=null,l=n[a].match(/(.*)\\[([0-9]+)\\]/);l?(o=l[1],s=l[2],r=r[o]=[],a===n.length-1?r[s]=e:r[s]={},r=r[s]):(a===n.length-1?r[o]=e:r[o]={},r=r[o])}return i};var S=/^([^\\[\\.]+)\\.(.+)?/,E=/^([^\\.]+)\\[([0-9]+)\\](\\.)?(.+)?/;l.expandObjectPaths=function(t){var e,r,n,i,a,o,s;if(\"object\"==typeof t&&!Array.isArray(t))for(r in t)t.hasOwnProperty(r)&&((e=r.match(S))?(i=t[r],n=e[1],delete t[r],t[n]=l.extendDeepNoArrays(t[n]||{},l.objectFromPath(r,l.expandObjectPaths(i))[n])):(e=r.match(E))?(i=t[r],n=e[1],a=parseInt(e[2]),delete t[r],t[n]=t[n]||[],\".\"===e[3]?(s=e[4],o=t[n][a]=t[n][a]||{},l.extendDeepNoArrays(o,l.objectFromPath(s,l.expandObjectPaths(i)))):t[n][a]=l.expandObjectPaths(i)):t[r]=l.expandObjectPaths(t[r]));return t},l.numSeparate=function(t,e,r){if(r||(r=!1),\"string\"!=typeof e||0===e.length)throw new Error(\"Separator string required for formatting!\");\"number\"==typeof t&&(t=String(t));var n=/(\\d+)(\\d{3})/,i=e.charAt(0),a=e.charAt(1),o=t.split(\".\"),s=o[0],l=o.length>1?i+o[1]:\"\";if(a&&(o.length>1||s.length>4||r))for(;n.test(s);)s=s.replace(n,\"$1\"+a+\"$2\");return s+l},l.TEMPLATE_STRING_REGEX=/%{([^\\s%{}:]*)(:[^}]*)?}/g;var C=/^\\w*$/;l.templateString=function(t,e){var r={};return t.replace(l.TEMPLATE_STRING_REGEX,function(t,n){return C.test(n)?e[n]||\"\":(r[n]=r[n]||l.nestedProperty(e,n).get,r[n]()||\"\")})};var L=/^:/,P=0;l.hovertemplateString=function(t,e,r){var i=arguments,a={};return t.replace(l.TEMPLATE_STRING_REGEX,function(t,o,s){var c,u,h;for(h=3;h<i.length;h++){if((c=i[h]).hasOwnProperty(o)){u=c[o];break}if(C.test(o)||(u=a[o]||l.nestedProperty(c,o).get())&&(a[o]=u),void 0!==u)break}(void 0===u&&(P<10&&(l.warn(\"Variable '\"+o+\"' in hovertemplate could not be found!\"),u=t),10===P&&l.warn(\"Too many hovertemplate warnings - additional warnings will be suppressed\"),P++),s)?u=(r?r.numberFormat:n.format)(s.replace(L,\"\"))(u):e.hasOwnProperty(o+\"Label\")&&(u=e[o+\"Label\"]);return u})};l.subplotSort=function(t,e){for(var r=Math.min(t.length,e.length)+1,n=0,i=0,a=0;a<r;a++){var o=t.charCodeAt(a)||0,s=e.charCodeAt(a)||0,l=o>=48&&o<=57,c=s>=48&&s<=57;if(l&&(n=10*n+o-48),c&&(i=10*i+s-48),!l||!c){if(n!==i)return n-i;if(o!==s)return o-s}}return i-n};var O=2e9;l.seedPseudoRandom=function(){O=2e9},l.pseudoRandom=function(){var t=O;return O=(69069*O+1)%4294967296,Math.abs(O-t)<429496729?l.pseudoRandom():O/4294967296},l.fillText=function(t,e,r){var n=Array.isArray(r)?function(t){r.push(t)}:function(t){r.text=t},i=l.extractOption(t,e,\"htx\",\"hovertext\");if(l.isValidTextValue(i))return n(i);var a=l.extractOption(t,e,\"tx\",\"text\");return l.isValidTextValue(a)?n(a):void 0},l.isValidTextValue=function(t){return t||0===t},l.formatPercent=function(t,e){e=e||0;for(var r=(Math.round(100*t*Math.pow(10,e))*Math.pow(.1,e)).toFixed(e)+\"%\",n=0;n<e;n++)-1!==r.indexOf(\".\")&&(r=(r=r.replace(\"0%\",\"%\")).replace(\".%\",\"%\"));return r},l.isHidden=function(t){var e=window.getComputedStyle(t).display;return!e||\"none\"===e}},{\"../constants/numerical\":695,\"./anchor_utils\":700,\"./angles\":701,\"./array\":702,\"./clean_number\":703,\"./clear_responsive\":705,\"./coerce\":706,\"./dates\":707,\"./dom\":708,\"./extend\":710,\"./filter_unique\":711,\"./filter_visible\":712,\"./geometry2d\":715,\"./identity\":718,\"./is_plain_object\":720,\"./keyed_container\":721,\"./localize\":722,\"./loggers\":723,\"./make_trace_groups\":724,\"./matrix\":725,\"./mod\":726,\"./nested_property\":727,\"./noop\":728,\"./notifier\":729,\"./push_unique\":733,\"./regex\":735,\"./relative_attr\":736,\"./relink_private\":737,\"./search\":738,\"./stats\":741,\"./throttle\":744,\"./to_log_range\":745,d3:163,\"fast-isnumeric\":225}],720:[function(t,e,r){\"use strict\";e.exports=function(t){return window&&window.process&&window.process.versions?\"[object Object]\"===Object.prototype.toString.call(t):\"[object Object]\"===Object.prototype.toString.call(t)&&Object.getPrototypeOf(t)===Object.prototype}},{}],721:[function(t,e,r){\"use strict\";var n=t(\"./nested_property\"),i=/^\\w*$/;e.exports=function(t,e,r,a){var o,s,l;r=r||\"name\",a=a||\"value\";var c={};e&&e.length?(l=n(t,e),s=l.get()):s=t,e=e||\"\";var u={};if(s)for(o=0;o<s.length;o++)u[s[o][r]]=o;var h=i.test(a),f={set:function(t,e){var i=null===e?4:0;if(!s){if(!l||4===i)return;s=[],l.set(s)}var o=u[t];if(void 0===o){if(4===i)return;i|=3,o=s.length,u[t]=o}else e!==(h?s[o][a]:n(s[o],a).get())&&(i|=2);var p=s[o]=s[o]||{};return p[r]=t,h?p[a]=e:n(p,a).set(e),null!==e&&(i&=-5),c[o]=c[o]|i,f},get:function(t){if(s){var e=u[t];return void 0===e?void 0:h?s[e][a]:n(s[e],a).get()}},rename:function(t,e){var n=u[t];return void 0===n?f:(c[n]=1|c[n],u[e]=n,delete u[t],s[n][r]=e,f)},remove:function(t){var e=u[t];if(void 0===e)return f;var i=s[e];if(Object.keys(i).length>2)return c[e]=2|c[e],f.set(t,null);if(h){for(o=e;o<s.length;o++)c[o]=3|c[o];for(o=e;o<s.length;o++)u[s[o][r]]--;s.splice(e,1),delete u[t]}else n(i,a).set(null),c[e]=6|c[e];return f},constructUpdate:function(){for(var t,i,o={},l=Object.keys(c),u=0;u<l.length;u++)i=l[u],t=e+\"[\"+i+\"]\",s[i]?(1&c[i]&&(o[t+\".\"+r]=s[i][r]),2&c[i]&&(o[t+\".\"+a]=h?4&c[i]?null:s[i][a]:4&c[i]?null:n(s[i],a).get())):o[t]=null;return o}};return f}},{\"./nested_property\":727}],722:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t,e){for(var r=t._context.locale,i=0;i<2;i++){for(var a=t._context.locales,o=0;o<2;o++){var s=(a[r]||{}).dictionary;if(s){var l=s[e];if(l)return l}a=n.localeRegistry}var c=r.split(\"-\")[0];if(c===r)break;r=c}return e}},{\"../registry\":847}],723:[function(t,e,r){\"use strict\";var n=t(\"../plot_api/plot_config\").dfltConfig,i=e.exports={};function a(t,e){if(t&&t.apply)try{return void t.apply(console,e)}catch(t){}for(var r=0;r<e.length;r++)try{t(e[r])}catch(t){console.log(e[r])}}i.log=function(){if(n.logging>1){for(var t=[\"LOG:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.trace||console.log,t)}},i.warn=function(){if(n.logging>0){for(var t=[\"WARN:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.trace||console.log,t)}},i.error=function(){if(n.logging>0){for(var t=[\"ERROR:\"],e=0;e<arguments.length;e++)t.push(arguments[e]);a(console.error,t)}}},{\"../plot_api/plot_config\":755}],724:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e,r){var i=t.selectAll(\"g.\"+r.replace(/\\s/g,\".\")).data(e,function(t){return t[0].trace.uid});i.exit().remove(),i.enter().append(\"g\").attr(\"class\",r),i.order();var a=t.classed(\"rangeplot\")?\"nodeRangePlot3\":\"node3\";return i.each(function(t){t[0][a]=n.select(this)}),i}},{d3:163}],725:[function(t,e,r){\"use strict\";r.init2dArray=function(t,e){for(var r=new Array(t),n=0;n<t;n++)r[n]=new Array(e);return r},r.transposeRagged=function(t){var e,r,n=0,i=t.length;for(e=0;e<i;e++)n=Math.max(n,t[e].length);var a=new Array(n);for(e=0;e<n;e++)for(a[e]=new Array(i),r=0;r<i;r++)a[e][r]=t[r][e];return a},r.dot=function(t,e){if(!t.length||!e.length||t.length!==e.length)return null;var n,i,a=t.length;if(t[0].length)for(n=new Array(a),i=0;i<a;i++)n[i]=r.dot(t[i],e);else if(e[0].length){var o=r.transposeRagged(e);for(n=new Array(o.length),i=0;i<o.length;i++)n[i]=r.dot(t,o[i])}else for(n=0,i=0;i<a;i++)n+=t[i]*e[i];return n},r.translationMatrix=function(t,e){return[[1,0,t],[0,1,e],[0,0,1]]},r.rotationMatrix=function(t){var e=t*Math.PI/180;return[[Math.cos(e),-Math.sin(e),0],[Math.sin(e),Math.cos(e),0],[0,0,1]]},r.rotationXYMatrix=function(t,e,n){return r.dot(r.dot(r.translationMatrix(e,n),r.rotationMatrix(t)),r.translationMatrix(-e,-n))},r.apply2DTransform=function(t){return function(){var e=arguments;3===e.length&&(e=e[0]);var n=1===arguments.length?e[0]:[e[0],e[1]];return r.dot(t,[n[0],n[1],1]).slice(0,2)}},r.apply2DTransform2=function(t){var e=r.apply2DTransform(t);return function(t){return e(t.slice(0,2)).concat(e(t.slice(2,4)))}}},{}],726:[function(t,e,r){\"use strict\";e.exports={mod:function(t,e){var r=t%e;return r<0?r+e:r},modHalf:function(t,e){return Math.abs(t)>e/2?t-Math.round(t/e)*e:t}}},{}],727:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;e.exports=function(t,e){if(n(e))e=String(e);else if(\"string\"!=typeof e||\"[-1]\"===e.substr(e.length-4))throw\"bad property string\";for(var r,a,o,l=0,c=e.split(\".\");l<c.length;){if(r=String(c[l]).match(/^([^\\[\\]]*)((\\[\\-?[0-9]*\\])+)$/)){if(r[1])c[l]=r[1];else{if(0!==l)throw\"bad property string\";c.splice(0,1)}for(a=r[2].substr(1,r[2].length-2).split(\"][\"),o=0;o<a.length;o++)l++,c.splice(l,0,Number(a[o]))}l++}return\"object\"!=typeof t?function(t,e,r){return{set:function(){throw\"bad container\"},get:function(){},astr:e,parts:r,obj:t}}(t,e,c):{set:s(t,c,e),get:function t(e,r){return function(){var n,a,o,s,l,c=e;for(s=0;s<r.length-1;s++){if(-1===(n=r[s])){for(a=!0,o=[],l=0;l<c.length;l++)o[l]=t(c[l],r.slice(s+1))(),o[l]!==o[0]&&(a=!1);return a?o[0]:o}if(\"number\"==typeof n&&!i(c))return;if(\"object\"!=typeof(c=c[n])||null===c)return}if(\"object\"==typeof c&&null!==c&&null!==(o=c[r[s]]))return o}}(t,c),astr:e,parts:c,obj:t}};var a=/(^|\\.)args\\[/;function o(t,e){return void 0===t||null===t&&!e.match(a)}function s(t,e,r){return function(n){var a,s,h=t,f=\"\",p=[[t,f]],d=o(n,r);for(s=0;s<e.length-1;s++){if(\"number\"==typeof(a=e[s])&&!i(h))throw\"array index but container is not an array\";if(-1===a){if(d=!c(h,e.slice(s+1),n,r))break;return}if(!u(h,a,e[s+1],d))break;if(\"object\"!=typeof(h=h[a])||null===h)throw\"container is not an object\";f=l(f,a),p.push([h,f])}if(d){if(s===e.length-1&&(delete h[e[s]],Array.isArray(h)&&+e[s]==h.length-1))for(;h.length&&void 0===h[h.length-1];)h.pop()}else h[e[s]]=n}}function l(t,e){var r=e;return n(e)?r=\"[\"+e+\"]\":t&&(r=\".\"+e),t+r}function c(t,e,r,n){var a,l=i(r),c=!0,h=r,f=n.replace(\"-1\",0),p=!l&&o(r,f),d=e[0];for(a=0;a<t.length;a++)f=n.replace(\"-1\",a),l&&(p=o(h=r[a%r.length],f)),p&&(c=!1),u(t,a,d,p)&&s(t[a],e,n.replace(\"-1\",a))(h);return c}function u(t,e,r,n){if(void 0===t[e]){if(n)return!1;t[e]=\"number\"==typeof r?[]:{}}return!0}},{\"./array\":702,\"fast-isnumeric\":225}],728:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],729:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=[];e.exports=function(t,e){if(-1===a.indexOf(t)){a.push(t);var r=1e3;i(e)?r=e:\"long\"===e&&(r=3e3);var o=n.select(\"body\").selectAll(\".plotly-notifier\").data([0]);o.enter().append(\"div\").classed(\"plotly-notifier\",!0),o.selectAll(\".notifier-note\").data(a).enter().append(\"div\").classed(\"notifier-note\",!0).style(\"opacity\",0).each(function(t){var e=n.select(this);e.append(\"button\").classed(\"notifier-close\",!0).html(\"&times;\").on(\"click\",function(){e.transition().call(s)});for(var i=e.append(\"p\"),a=t.split(/<br\\s*\\/?>/g),o=0;o<a.length;o++)o&&i.append(\"br\"),i.append(\"span\").text(a[o]);e.transition().duration(700).style(\"opacity\",1).transition().delay(r).call(s)})}function s(t){t.duration(700).style(\"opacity\",0).each(\"end\",function(t){var e=a.indexOf(t);-1!==e&&a.splice(e,1),n.select(this).remove()})}}},{d3:163,\"fast-isnumeric\":225}],730:[function(t,e,r){\"use strict\";var n=t(\"./setcursor\"),i=\"data-savedcursor\";e.exports=function(t,e){var r=t.attr(i);if(e){if(!r){for(var a=(t.attr(\"class\")||\"\").split(\" \"),o=0;o<a.length;o++){var s=a[o];0===s.indexOf(\"cursor-\")&&t.attr(i,s.substr(7)).classed(s,!1)}t.attr(i)||t.attr(i,\"!!\")}n(t,e)}else r&&(t.attr(i,null),\"!!\"===r?n(t):n(t,r))}},{\"./setcursor\":739}],731:[function(t,e,r){\"use strict\";var n=t(\"./matrix\").dot,i=t(\"../constants/numerical\").BADNUM,a=e.exports={};a.tester=function(t){var e,r=t.slice(),n=r[0][0],a=n,o=r[0][1],s=o;for(r.push(r[0]),e=1;e<r.length;e++)n=Math.min(n,r[e][0]),a=Math.max(a,r[e][0]),o=Math.min(o,r[e][1]),s=Math.max(s,r[e][1]);var l,c=!1;5===r.length&&(r[0][0]===r[1][0]?r[2][0]===r[3][0]&&r[0][1]===r[3][1]&&r[1][1]===r[2][1]&&(c=!0,l=function(t){return t[0]===r[0][0]}):r[0][1]===r[1][1]&&r[2][1]===r[3][1]&&r[0][0]===r[3][0]&&r[1][0]===r[2][0]&&(c=!0,l=function(t){return t[1]===r[0][1]}));var u=!0,h=r[0];for(e=1;e<r.length;e++)if(h[0]!==r[e][0]||h[1]!==r[e][1]){u=!1;break}return{xmin:n,xmax:a,ymin:o,ymax:s,pts:r,contains:c?function(t,e){var r=t[0],c=t[1];return!(r===i||r<n||r>a||c===i||c<o||c>s||e&&l(t))}:function(t,e){var l=t[0],c=t[1];if(l===i||l<n||l>a||c===i||c<o||c>s)return!1;var u,h,f,p,d,g=r.length,v=r[0][0],m=r[0][1],y=0;for(u=1;u<g;u++)if(h=v,f=m,v=r[u][0],m=r[u][1],!(l<(p=Math.min(h,v))||l>Math.max(h,v)||c>Math.max(f,m)))if(c<Math.min(f,m))l!==p&&y++;else{if(c===(d=v===h?c:f+(l-h)*(m-f)/(v-h)))return 1!==u||!e;c<=d&&l!==p&&y++}return y%2==1},isRect:c,degenerate:u}},a.isSegmentBent=function(t,e,r,i){var a,o,s,l=t[e],c=[t[r][0]-l[0],t[r][1]-l[1]],u=n(c,c),h=Math.sqrt(u),f=[-c[1]/h,c[0]/h];for(a=e+1;a<r;a++)if(o=[t[a][0]-l[0],t[a][1]-l[1]],(s=n(o,c))<0||s>u||Math.abs(n(o,f))>i)return!0;return!1},a.filter=function(t,e){var r=[t[0]],n=0,i=0;function o(o){t.push(o);var s=r.length,l=n;r.splice(i+1);for(var c=l+1;c<t.length;c++)(c===t.length-1||a.isSegmentBent(t,l,c+1,e))&&(r.push(t[c]),r.length<s-2&&(n=c,i=r.length-1),l=c)}t.length>1&&o(t.pop());return{addPt:o,raw:t,filtered:r}}},{\"../constants/numerical\":695,\"./matrix\":725}],732:[function(t,e,r){(function(r){\"use strict\";var n=t(\"./show_no_webgl_msg\"),i=t(\"regl\");e.exports=function(t,e){var a=t._fullLayout,o=!0;return a._glcanvas.each(function(n){if(!n.regl&&(!n.pick||a._has(\"parcoords\"))){try{n.regl=i({canvas:this,attributes:{antialias:!n.pick,preserveDrawingBuffer:!0},pixelRatio:t._context.plotGlPixelRatio||r.devicePixelRatio,extensions:e||[]})}catch(t){o=!1}o&&this.addEventListener(\"webglcontextlost\",function(e){t&&t.emit&&t.emit(\"plotly_webglcontextlost\",{event:e,layer:n.key})},!1)}}),o||n({container:a._glcontainer.node()}),o}}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./show_no_webgl_msg\":740,regl:502}],733:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(e instanceof RegExp){for(var r=e.toString(),n=0;n<t.length;n++)if(t[n]instanceof RegExp&&t[n].toString()===r)return t;t.push(e)}else!e&&0!==e||-1!==t.indexOf(e)||t.push(e);return t}},{}],734:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_config\").dfltConfig;var a={add:function(t,e,r,n,a){var o,s;t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},s=t.undoQueue.index,t.autoplay?t.undoQueue.inSequence||(t.autoplay=!1):(!t.undoQueue.sequence||t.undoQueue.beginSequence?(o={undo:{calls:[],args:[]},redo:{calls:[],args:[]}},t.undoQueue.queue.splice(s,t.undoQueue.queue.length-s,o),t.undoQueue.index+=1):o=t.undoQueue.queue[s-1],t.undoQueue.beginSequence=!1,o&&(o.undo.calls.unshift(e),o.undo.args.unshift(r),o.redo.calls.push(n),o.redo.args.push(a)),t.undoQueue.queue.length>i.queueLength&&(t.undoQueue.queue.shift(),t.undoQueue.index--))},startSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!0,t.undoQueue.beginSequence=!0},stopSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!1,t.undoQueue.beginSequence=!1},undo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.undo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index<=0)){for(t.undoQueue.index--,e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.undo.calls.length;r++)a.plotDo(t,e.undo.calls[r],e.undo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1}},redo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.redo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index>=t.undoQueue.queue.length)){for(e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.redo.calls.length;r++)a.plotDo(t,e.redo.calls[r],e.redo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1,t.undoQueue.index++}}};a.plotDo=function(t,e,r){t.autoplay=!0,r=function(t,e){for(var r,i=[],a=0;a<e.length;a++)r=e[a],i[a]=r===t?r:\"object\"==typeof r?Array.isArray(r)?n.extendDeep([],r):n.extendDeepAll({},r):r;return i}(t,r),e.apply(null,r)},e.exports=a},{\"../lib\":719,\"../plot_api/plot_config\":755}],735:[function(t,e,r){\"use strict\";r.counter=function(t,e,r,n){var i=(e||\"\")+(r?\"\":\"$\"),a=!1===n?\"\":\"^\";return\"xy\"===t?new RegExp(a+\"x([2-9]|[1-9][0-9]+)?y([2-9]|[1-9][0-9]+)?\"+i):new RegExp(a+t+\"([2-9]|[1-9][0-9]+)?\"+i)}},{}],736:[function(t,e,r){\"use strict\";var n=/^(.*)(\\.[^\\.\\[\\]]+|\\[\\d\\])$/,i=/^[^\\.\\[\\]]+$/;e.exports=function(t,e){for(;e;){var r=t.match(n);if(r)t=r[1];else{if(!t.match(i))throw new Error(\"bad relativeAttr call:\"+[t,e]);t=\"\"}if(\"^\"!==e.charAt(0))break;e=e.slice(1)}return t&&\"[\"!==e.charAt(0)?t+\".\"+e:t+e}},{}],737:[function(t,e,r){\"use strict\";var n=t(\"./array\").isArrayOrTypedArray,i=t(\"./is_plain_object\");e.exports=function t(e,r){for(var a in r){var o=r[a],s=e[a];if(s!==o)if(\"_\"===a.charAt(0)||\"function\"==typeof o){if(a in e)continue;e[a]=o}else if(n(o)&&n(s)&&i(o[0])){if(\"customdata\"===a||\"ids\"===a)continue;for(var l=Math.min(o.length,s.length),c=0;c<l;c++)s[c]!==o[c]&&i(o[c])&&i(s[c])&&t(s[c],o[c])}else i(o)&&i(s)&&(t(s,o),Object.keys(s).length||delete e[a])}}},{\"./array\":702,\"./is_plain_object\":720}],738:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./loggers\"),a=t(\"./identity\");function o(t,e){return t<e}function s(t,e){return t<=e}function l(t,e){return t>e}function c(t,e){return t>=e}r.findBin=function(t,e,r){if(n(e.start))return r?Math.ceil((t-e.start)/e.size-1e-9)-1:Math.floor((t-e.start)/e.size+1e-9);var a,u,h=0,f=e.length,p=0,d=f>1?(e[f-1]-e[0])/(f-1):1;for(u=d>=0?r?o:s:r?c:l,t+=1e-9*d*(r?-1:1)*(d>=0?1:-1);h<f&&p++<100;)u(e[a=Math.floor((h+f)/2)],t)?h=a+1:f=a;return p>90&&i.log(\"Long binary search...\"),h-1},r.sorterAsc=function(t,e){return t-e},r.sorterDes=function(t,e){return e-t},r.distinctVals=function(t){var e=t.slice();e.sort(r.sorterAsc);for(var n=e.length-1,i=e[n]-e[0]||1,a=i/(n||1)/1e4,o=[e[0]],s=0;s<n;s++)e[s+1]>e[s]+a&&(i=Math.min(i,e[s+1]-e[s]),o.push(e[s+1]));return{vals:o,minDiff:i}},r.roundUp=function(t,e,r){for(var n,i=0,a=e.length-1,o=0,s=r?0:1,l=r?1:0,c=r?Math.ceil:Math.floor;i<a&&o++<100;)e[n=c((i+a)/2)]<=t?i=n+s:a=n-l;return e[i]},r.sort=function(t,e){for(var r=0,n=0,i=1;i<t.length;i++){var a=e(t[i],t[i-1]);if(a<0?r=1:a>0&&(n=1),r&&n)return t.sort(e)}return n?t:t.reverse()},r.findIndexOfMin=function(t,e){e=e||a;for(var r,n=1/0,i=0;i<t.length;i++){var o=e(t[i]);o<n&&(n=o,r=i)}return r}},{\"./identity\":718,\"./loggers\":723,\"fast-isnumeric\":225}],739:[function(t,e,r){\"use strict\";e.exports=function(t,e){(t.attr(\"class\")||\"\").split(\" \").forEach(function(e){0===e.indexOf(\"cursor-\")&&t.classed(e,!1)}),e&&t.classed(\"cursor-\"+e,!0)}},{}],740:[function(t,e,r){\"use strict\";var n=t(\"../components/color\"),i=function(){};e.exports=function(t){for(var e in t)\"function\"==typeof t[e]&&(t[e]=i);t.destroy=function(){t.container.parentNode.removeChild(t.container)};var r=document.createElement(\"div\");r.className=\"no-webgl\",r.style.cursor=\"pointer\",r.style.fontSize=\"24px\",r.style.color=n.defaults[0],r.style.position=\"absolute\",r.style.left=r.style.top=\"0px\",r.style.width=r.style.height=\"100%\",r.style[\"background-color\"]=n.lightLine,r.style[\"z-index\"]=30;var a=document.createElement(\"p\");return a.textContent=\"WebGL is not supported by your browser - visit https://get.webgl.org for more info\",a.style.position=\"relative\",a.style.top=\"50%\",a.style.left=\"50%\",a.style.height=\"30%\",a.style.width=\"50%\",a.style.margin=\"-15% 0 0 -25%\",r.appendChild(a),t.container.appendChild(r),t.container.style.background=\"#FFFFFF\",t.container.onclick=function(){window.open(\"https://get.webgl.org\")},!1}},{\"../components/color\":593}],741:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;r.aggNums=function(t,e,a,o){var s,l;if((!o||o>a.length)&&(o=a.length),n(e)||(e=!1),i(a[0])){for(l=new Array(o),s=0;s<o;s++)l[s]=r.aggNums(t,e,a[s]);a=l}for(s=0;s<o;s++)n(e)?n(a[s])&&(e=t(+e,+a[s])):e=a[s];return e},r.len=function(t){return r.aggNums(function(t){return t+1},0,t)},r.mean=function(t,e){return e||(e=r.len(t)),r.aggNums(function(t,e){return t+e},0,t)/e},r.midRange=function(t){if(void 0!==t&&0!==t.length)return(r.aggNums(Math.max,null,t)+r.aggNums(Math.min,null,t))/2},r.variance=function(t,e,i){return e||(e=r.len(t)),n(i)||(i=r.mean(t,e)),r.aggNums(function(t,e){return t+Math.pow(e-i,2)},0,t)/e},r.stdev=function(t,e,n){return Math.sqrt(r.variance(t,e,n))},r.median=function(t){var e=t.slice().sort();return r.interp(e,.5)},r.interp=function(t,e){if(!n(e))throw\"n should be a finite number\";if((e=e*t.length-.5)<0)return t[0];if(e>t.length-1)return t[t.length-1];var r=e%1;return r*t[Math.ceil(e)]+(1-r)*t[Math.floor(e)]}},{\"./array\":702,\"fast-isnumeric\":225}],742:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\");e.exports=function(t){return t?n(t):[0,0,0,1]}},{\"color-normalize\":120}],743:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=t(\"../constants/xmlns_namespaces\"),o=t(\"../constants/alignment\").LINE_SPACING;function s(t,e){return t.node().getBoundingClientRect()[e]}var l=/([^$]*)([$]+[^$]*[$]+)([^$]*)/;r.convertToTspans=function(t,e,M){var S=t.text(),C=!t.attr(\"data-notex\")&&\"undefined\"!=typeof MathJax&&S.match(l),L=n.select(t.node().parentNode);if(!L.empty()){var P=t.attr(\"class\")?t.attr(\"class\").split(\" \")[0]:\"text\";return P+=\"-math\",L.selectAll(\"svg.\"+P).remove(),L.selectAll(\"g.\"+P+\"-group\").remove(),t.style(\"display\",null).attr({\"data-unformatted\":S,\"data-math\":\"N\"}),C?(e&&e._promises||[]).push(new Promise(function(e){t.style(\"display\",\"none\");var r=parseInt(t.node().style.fontSize,10),a={fontSize:r};!function(t,e,r){var a,o,s,l;MathJax.Hub.Queue(function(){return o=i.extendDeepAll({},MathJax.Hub.config),s=MathJax.Hub.processSectionDelay,void 0!==MathJax.Hub.processSectionDelay&&(MathJax.Hub.processSectionDelay=0),MathJax.Hub.Config({messageStyle:\"none\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]},displayAlign:\"left\"})},function(){if(\"SVG\"!==(a=MathJax.Hub.config.menuSettings.renderer))return MathJax.Hub.setRenderer(\"SVG\")},function(){var r=\"math-output-\"+i.randstr({},64);return l=n.select(\"body\").append(\"div\").attr({id:r}).style({visibility:\"hidden\",position:\"absolute\"}).style({\"font-size\":e.fontSize+\"px\"}).text(t.replace(c,\"\\\\lt \").replace(u,\"\\\\gt \")),MathJax.Hub.Typeset(l.node())},function(){var e=n.select(\"body\").select(\"#MathJax_SVG_glyphs\");if(l.select(\".MathJax_SVG\").empty()||!l.select(\"svg\").node())i.log(\"There was an error in the tex syntax.\",t),r();else{var o=l.select(\"svg\").node().getBoundingClientRect();r(l.select(\".MathJax_SVG\"),e,o)}if(l.remove(),\"SVG\"!==a)return MathJax.Hub.setRenderer(a)},function(){return void 0!==s&&(MathJax.Hub.processSectionDelay=s),MathJax.Hub.Config(o)})}(C[2],a,function(n,i,a){L.selectAll(\"svg.\"+P).remove(),L.selectAll(\"g.\"+P+\"-group\").remove();var o=n&&n.select(\"svg\");if(!o||!o.node())return O(),void e();var l=L.append(\"g\").classed(P+\"-group\",!0).attr({\"pointer-events\":\"none\",\"data-unformatted\":S,\"data-math\":\"Y\"});l.node().appendChild(o.node()),i&&i.node()&&o.node().insertBefore(i.node().cloneNode(!0),o.node().firstChild),o.attr({class:P,height:a.height,preserveAspectRatio:\"xMinYMin meet\"}).style({overflow:\"visible\",\"pointer-events\":\"none\"});var c=t.node().style.fill||\"black\",u=o.select(\"g\");u.attr({fill:c,stroke:c});var h=s(u,\"width\"),f=s(u,\"height\"),p=+t.attr(\"x\")-h*{start:0,middle:.5,end:1}[t.attr(\"text-anchor\")||\"start\"],d=-(r||s(t,\"height\"))/4;\"y\"===P[0]?(l.attr({transform:\"rotate(\"+[-90,+t.attr(\"x\"),+t.attr(\"y\")]+\") translate(\"+[-h/2,d-f/2]+\")\"}),o.attr({x:+t.attr(\"x\"),y:+t.attr(\"y\")})):\"l\"===P[0]?o.attr({x:t.attr(\"x\"),y:d-f/2}):\"a\"===P[0]&&0!==P.indexOf(\"atitle\")?o.attr({x:0,y:d}):o.attr({x:p,y:+t.attr(\"y\")+d-f/2}),M&&M.call(t,l),e(l)})})):O(),t}function O(){L.empty()||(P=t.attr(\"class\")+\"-math\",L.select(\"svg.\"+P).remove()),t.text(\"\").style(\"white-space\",\"pre\"),function(t,e){e=e.replace(v,\" \");var r,s=!1,l=[],c=-1;function u(){c++;var e=document.createElementNS(a.svg,\"tspan\");n.select(e).attr({class:\"line\",dy:c*o+\"em\"}),t.appendChild(e),r=e;var i=l;if(l=[{node:e}],i.length>1)for(var s=1;s<i.length;s++)M(i[s])}function M(t){var e,i=t.type,o={};if(\"a\"===i){e=\"a\";var s=t.target,c=t.href,u=t.popup;c&&(o={\"xlink:xlink:show\":\"_blank\"===s||\"_\"!==s.charAt(0)?\"new\":\"replace\",target:s,\"xlink:xlink:href\":c},u&&(o.onclick='window.open(this.href.baseVal,this.target.baseVal,\"'+u+'\");return false;'))}else e=\"tspan\";t.style&&(o.style=t.style);var h=document.createElementNS(a.svg,e);if(\"sup\"===i||\"sub\"===i){S(r,d),r.appendChild(h);var g=document.createElementNS(a.svg,\"tspan\");S(g,d),n.select(g).attr(\"dy\",p[i]),o.dy=f[i],r.appendChild(h),r.appendChild(g)}else r.appendChild(h);n.select(h).attr(o),r=t.node=h,l.push(t)}function S(t,e){t.appendChild(document.createTextNode(e))}function C(t){if(1!==l.length){var n=l.pop();t!==n.type&&i.log(\"Start tag <\"+n.type+\"> doesnt match end tag <\"+t+\">. Pretending it did match.\",e),r=l[l.length-1].node}else i.log(\"Ignoring unexpected end tag </\"+t+\">.\",e)}x.test(e)?u():(r=t,l=[{node:t}]);for(var L=e.split(m),P=0;P<L.length;P++){var O=L[P],z=O.match(y),I=z&&z[2].toLowerCase(),D=h[I];if(\"br\"===I)u();else if(void 0===D)S(r,E(O));else if(z[1])C(I);else{var R=z[4],F={type:I},B=T(R,b);if(B?(B=B.replace(A,\"$1 fill:\"),D&&(B+=\";\"+D)):D&&(B=D),B&&(F.style=B),\"a\"===I){s=!0;var N=T(R,_);if(N){var j=document.createElement(\"a\");j.href=N,-1!==g.indexOf(j.protocol)&&(F.href=encodeURI(decodeURI(N)),F.target=T(R,w)||\"_blank\",F.popup=T(R,k))}}M(F)}}return s}(t.node(),S)&&t.style(\"pointer-events\",\"all\"),r.positionText(t),M&&M.call(t)}};var c=/(<|&lt;|&#60;)/g,u=/(>|&gt;|&#62;)/g;var h={sup:\"font-size:70%\",sub:\"font-size:70%\",b:\"font-weight:bold\",i:\"font-style:italic\",a:\"cursor:pointer\",span:\"\",em:\"font-style:italic;font-weight:bold\"},f={sub:\"0.3em\",sup:\"-0.6em\"},p={sub:\"-0.21em\",sup:\"0.42em\"},d=\"\\u200b\",g=[\"http:\",\"https:\",\"mailto:\",\"\",void 0,\":\"],v=/(\\r\\n?|\\n)/g,m=/(<[^<>]*>)/,y=/<(\\/?)([^ >]*)(\\s+(.*))?>/i,x=/<br(\\s+.*)?>/i,b=/(^|[\\s\"'])style\\s*=\\s*(\"([^\"]*);?\"|'([^']*);?')/i,_=/(^|[\\s\"'])href\\s*=\\s*(\"([^\"]*)\"|'([^']*)')/i,w=/(^|[\\s\"'])target\\s*=\\s*(\"([^\"\\s]*)\"|'([^'\\s]*)')/i,k=/(^|[\\s\"'])popup\\s*=\\s*(\"([\\w=,]*)\"|'([\\w=,]*)')/i;function T(t,e){if(!t)return null;var r=t.match(e),n=r&&(r[3]||r[4]);return n&&E(n)}var A=/(^|;)\\s*color:/;r.plainText=function(t,e){for(var r=void 0!==(e=e||{}).len&&-1!==e.len?e.len:1/0,n=void 0!==e.allowedTags?e.allowedTags:[\"br\"],i=\"...\".length,a=t.split(m),o=[],s=\"\",l=0,c=0;c<a.length;c++){var u=a[c],h=u.match(y),f=h&&h[2].toLowerCase();if(f)-1!==n.indexOf(f)&&(o.push(u),s=f);else{var p=u.length;if(l+p<r)o.push(u),l+=p;else if(l<r){var d=r-l;s&&(\"br\"!==s||d<=i||p<=i)&&o.pop(),r>i?o.push(u.substr(0,d-i)+\"...\"):o.push(u.substr(0,d));break}s=\"\"}}return o.join(\"\")};var M={mu:\"\\u03bc\",amp:\"&\",lt:\"<\",gt:\">\",nbsp:\"\\xa0\",times:\"\\xd7\",plusmn:\"\\xb1\",deg:\"\\xb0\"},S=/&(#\\d+|#x[\\da-fA-F]+|[a-z]+);/g;function E(t){return t.replace(S,function(t,e){return(\"#\"===e.charAt(0)?function(t){if(t>1114111)return;var e=String.fromCodePoint;if(e)return e(t);var r=String.fromCharCode;return t<=65535?r(t):r(55232+(t>>10),t%1024+56320)}(\"x\"===e.charAt(1)?parseInt(e.substr(2),16):parseInt(e.substr(1),10)):M[e])||t})}function C(t,e,r){var n,i,a,o=r.horizontalAlign,s=r.verticalAlign||\"top\",l=t.node().getBoundingClientRect(),c=e.node().getBoundingClientRect();return i=\"bottom\"===s?function(){return l.bottom-n.height}:\"middle\"===s?function(){return l.top+(l.height-n.height)/2}:function(){return l.top},a=\"right\"===o?function(){return l.right-n.width}:\"center\"===o?function(){return l.left+(l.width-n.width)/2}:function(){return l.left},function(){return n=this.node().getBoundingClientRect(),this.style({top:i()-c.top+\"px\",left:a()-c.left+\"px\",\"z-index\":1e3}),this}}r.convertEntities=E,r.lineCount=function(t){return t.selectAll(\"tspan.line\").size()||1},r.positionText=function(t,e,r){return t.each(function(){var t=n.select(this);function i(e,r){return void 0===r?null===(r=t.attr(e))&&(t.attr(e,0),r=0):t.attr(e,r),r}var a=i(\"x\",e),o=i(\"y\",r);\"text\"===this.nodeName&&t.selectAll(\"tspan.line\").attr({x:a,y:o})})},r.makeEditable=function(t,e){var r=e.gd,i=e.delegate,a=n.dispatch(\"edit\",\"input\",\"cancel\"),o=i||t;if(t.style({\"pointer-events\":i?\"none\":\"all\"}),1!==t.size())throw new Error(\"boo\");function s(){!function(){var i=n.select(r).select(\".svg-container\"),o=i.append(\"div\"),s=t.node().style,c=parseFloat(s.fontSize||12),u=e.text;void 0===u&&(u=t.attr(\"data-unformatted\"));o.classed(\"plugin-editable editable\",!0).style({position:\"absolute\",\"font-family\":s.fontFamily||\"Arial\",\"font-size\":c,color:e.fill||s.fill||\"black\",opacity:1,\"background-color\":e.background||\"transparent\",outline:\"#ffffff33 1px solid\",margin:[-c/8+1,0,0,-1].join(\"px \")+\"px\",padding:\"0\",\"box-sizing\":\"border-box\"}).attr({contenteditable:!0}).text(u).call(C(t,i,e)).on(\"blur\",function(){r._editing=!1,t.text(this.textContent).style({opacity:1});var e,i=n.select(this).attr(\"class\");(e=i?\".\"+i.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(e).style({opacity:0});var o=this.textContent;n.select(this).transition().duration(0).remove(),n.select(document).on(\"mouseup\",null),a.edit.call(t,o)}).on(\"focus\",function(){var t=this;r._editing=!0,n.select(document).on(\"mouseup\",function(){if(n.event.target===t)return!1;document.activeElement===o.node()&&o.node().blur()})}).on(\"keyup\",function(){27===n.event.which?(r._editing=!1,t.style({opacity:1}),n.select(this).style({opacity:0}).on(\"blur\",function(){return!1}).transition().remove(),a.cancel.call(t,this.textContent)):(a.input.call(t,this.textContent),n.select(this).call(C(t,i,e)))}).on(\"keydown\",function(){13===n.event.which&&this.blur()}).call(l)}(),t.style({opacity:0});var i,s=o.attr(\"class\");(i=s?\".\"+s.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(i).style({opacity:0})}function l(t){var e=t.node(),r=document.createRange();r.selectNodeContents(e);var n=window.getSelection();n.removeAllRanges(),n.addRange(r),e.focus()}return e.immediate?s():o.on(\"click\",s),n.rebind(t,a,\"on\")}},{\"../constants/alignment\":688,\"../constants/xmlns_namespaces\":696,\"../lib\":719,d3:163}],744:[function(t,e,r){\"use strict\";var n={};function i(t){t&&null!==t.timer&&(clearTimeout(t.timer),t.timer=null)}r.throttle=function(t,e,r){var a=n[t],o=Date.now();if(!a){for(var s in n)n[s].ts<o-6e4&&delete n[s];a=n[t]={ts:0,timer:null}}function l(){r(),a.ts=Date.now(),a.onDone&&(a.onDone(),a.onDone=null)}i(a),o>a.ts+e?l():a.timer=setTimeout(function(){l(),a.timer=null},e)},r.done=function(t){var e=n[t];return e&&e.timer?new Promise(function(t){var r=e.onDone;e.onDone=function(){r&&r(),t(),e.onDone=null}}):Promise.resolve()},r.clear=function(t){if(t)i(n[t]),delete n[t];else for(var e in n)r.clear(e)}},{}],745:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t,e){if(t>0)return Math.log(t)/Math.LN10;var r=Math.log(Math.min(e[0],e[1]))/Math.LN10;return n(r)||(r=Math.log(Math.max(e[0],e[1]))/Math.LN10-6),r}},{\"fast-isnumeric\":225}],746:[function(t,e,r){\"use strict\";var n=e.exports={},i=t(\"../plots/geo/constants\").locationmodeToLayer,a=t(\"topojson-client\").feature;n.getTopojsonName=function(t){return[t.scope.replace(/ /g,\"-\"),\"_\",t.resolution.toString(),\"m\"].join(\"\")},n.getTopojsonPath=function(t,e){return t+e+\".json\"},n.getTopojsonFeatures=function(t,e){var r=i[t.locationmode],n=e.objects[r];return a(e,n).features}},{\"../plots/geo/constants\":795,\"topojson-client\":540}],747:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en-US\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colorscale title\"},format:{date:\"%m/%d/%Y\"}}},{}],748:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colourscale title\"},format:{days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],periods:[\"AM\",\"PM\"],dateTime:\"%a %b %e %X %Y\",date:\"%d/%m/%Y\",time:\"%H:%M:%S\",decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],year:\"%Y\",month:\"%b %Y\",dayMonth:\"%b %-d\",dayMonthYear:\"%b %-d, %Y\"}}},{}],749:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t){for(var e,r,i=n.layoutArrayContainers,a=n.layoutArrayRegexes,o=t.split(\"[\")[0],s=0;s<a.length;s++)if((r=t.match(a[s]))&&0===r.index){e=r[0];break}if(e||(e=i[i.indexOf(o)]),!e)return!1;var l=t.substr(e.length);return l?!!(r=l.match(/^\\[(0|[1-9][0-9]*)\\](\\.(.+))?$/))&&{array:e,index:Number(r[1]),property:r[3]||\"\"}:{array:e,index:\"\",property:\"\"}}},{\"../registry\":847}],750:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.extendFlat,a=n.isPlainObject,o={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"clearAxisTypes\",\"plot\",\"style\",\"markerSize\",\"colorbars\"]},s={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"plot\",\"legend\",\"ticks\",\"axrange\",\"layoutstyle\",\"modebar\",\"camera\",\"arraydraw\",\"colorbars\"]},l=o.flags.slice().concat([\"fullReplot\"]),c=s.flags.slice().concat(\"layoutReplot\");function u(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=!1;return e}function h(t,e,r){var n=i({},t);for(var o in n){var s=n[o];a(s)&&(n[o]=f(s,e,r,o))}return\"from-root\"===r&&(n.editType=e),n}function f(t,e,r,n){if(t.valType){var a=i({},t);if(a.editType=e,Array.isArray(t.items)){a.items=new Array(t.items.length);for(var o=0;o<t.items.length;o++)a.items[o]=f(t.items[o],e,\"from-root\")}return a}return h(t,e,\"_\"===n.charAt(0)?\"nested\":\"from-root\")}e.exports={traces:o,layout:s,traceFlags:function(){return u(l)},layoutFlags:function(){return u(c)},update:function(t,e){var r=e.editType;if(r&&\"none\"!==r)for(var n=r.split(\"+\"),i=0;i<n.length;i++)t[n[i]]=!0},overrideAll:h}},{\"../lib\":719}],751:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"gl-mat4/fromQuat\"),a=t(\"../registry\"),o=t(\"../lib\"),s=t(\"../plots/plots\"),l=t(\"../plots/cartesian/axis_ids\"),c=t(\"../components/color\"),u=l.cleanId,h=l.getFromTrace,f=a.traceIs;function p(t,e){var r=t[e],n=e.charAt(0);r&&\"paper\"!==r&&(t[e]=u(r,n))}function d(t){function e(e,r){var n=t[e],i=t.title&&t.title[r];n&&!i&&(t.title||(t.title={}),t.title[r]=t[e],delete t[e])}t&&(\"string\"!=typeof t.title&&\"number\"!=typeof t.title||(t.title={text:t.title}),e(\"titlefont\",\"font\"),e(\"titleposition\",\"position\"),e(\"titleside\",\"side\"),e(\"titleoffset\",\"offset\"))}function g(t){if(!o.isPlainObject(t))return!1;var e=t.name;return delete t.name,delete t.showlegend,(\"string\"==typeof e||\"number\"==typeof e)&&String(e)}function v(t,e,r,n){if(r&&!n)return t;if(n&&!r)return e;if(!t.trim())return e;if(!e.trim())return t;var i,a=Math.min(t.length,e.length);for(i=0;i<a&&t.charAt(i)===e.charAt(i);i++);return t.substr(0,i).trim()}function m(t){var e=\"middle\",r=\"center\";return\"string\"==typeof t&&(-1!==t.indexOf(\"top\")?e=\"top\":-1!==t.indexOf(\"bottom\")&&(e=\"bottom\"),-1!==t.indexOf(\"left\")?r=\"left\":-1!==t.indexOf(\"right\")&&(r=\"right\")),e+\" \"+r}function y(t,e){return e in t&&\"object\"==typeof t[e]&&0===Object.keys(t[e]).length}r.clearPromiseQueue=function(t){Array.isArray(t._promises)&&t._promises.length>0&&o.log(\"Clearing previous rejected promises from queue.\"),t._promises=[]},r.cleanLayout=function(t){var e,n;t||(t={}),t.xaxis1&&(t.xaxis||(t.xaxis=t.xaxis1),delete t.xaxis1),t.yaxis1&&(t.yaxis||(t.yaxis=t.yaxis1),delete t.yaxis1),t.scene1&&(t.scene||(t.scene=t.scene1),delete t.scene1);var a=(s.subplotsRegistry.cartesian||{}).attrRegex,l=(s.subplotsRegistry.polar||{}).attrRegex,h=(s.subplotsRegistry.ternary||{}).attrRegex,f=(s.subplotsRegistry.gl3d||{}).attrRegex,g=Object.keys(t);for(e=0;e<g.length;e++){var v=g[e];if(a&&a.test(v)){var m=t[v];m.anchor&&\"free\"!==m.anchor&&(m.anchor=u(m.anchor)),m.overlaying&&(m.overlaying=u(m.overlaying)),m.type||(m.isdate?m.type=\"date\":m.islog?m.type=\"log\":!1===m.isdate&&!1===m.islog&&(m.type=\"linear\")),\"withzero\"!==m.autorange&&\"tozero\"!==m.autorange||(m.autorange=!0,m.rangemode=\"tozero\"),delete m.islog,delete m.isdate,delete m.categories,y(m,\"domain\")&&delete m.domain,void 0!==m.autotick&&(void 0===m.tickmode&&(m.tickmode=m.autotick?\"auto\":\"linear\"),delete m.autotick),d(m)}else if(l&&l.test(v)){d(t[v].radialaxis)}else if(h&&h.test(v)){var x=t[v];d(x.aaxis),d(x.baxis),d(x.caxis)}else if(f&&f.test(v)){var b=t[v],_=b.cameraposition;if(Array.isArray(_)&&4===_[0].length){var w=_[0],k=_[1],T=_[2],A=i([],w),M=[];for(n=0;n<3;++n)M[n]=k[n]+T*A[2+4*n];b.camera={eye:{x:M[0],y:M[1],z:M[2]},center:{x:k[0],y:k[1],z:k[2]},up:{x:0,y:0,z:1}},delete b.cameraposition}d(b.xaxis),d(b.yaxis),d(b.zaxis)}}var S=Array.isArray(t.annotations)?t.annotations.length:0;for(e=0;e<S;e++){var E=t.annotations[e];o.isPlainObject(E)&&(E.ref&&(\"paper\"===E.ref?(E.xref=\"paper\",E.yref=\"paper\"):\"data\"===E.ref&&(E.xref=\"x\",E.yref=\"y\"),delete E.ref),p(E,\"xref\"),p(E,\"yref\"))}var C=Array.isArray(t.shapes)?t.shapes.length:0;for(e=0;e<C;e++){var L=t.shapes[e];o.isPlainObject(L)&&(p(L,\"xref\"),p(L,\"yref\"))}var P=t.legend;return P&&(P.x>3?(P.x=1.02,P.xanchor=\"left\"):P.x<-2&&(P.x=-.02,P.xanchor=\"right\"),P.y>3?(P.y=1.02,P.yanchor=\"bottom\"):P.y<-2&&(P.y=-.02,P.yanchor=\"top\")),d(t),\"rotate\"===t.dragmode&&(t.dragmode=\"orbit\"),c.clean(t),t.template&&t.template.layout&&r.cleanLayout(t.template.layout),t},r.cleanData=function(t){for(var e=0;e<t.length;e++){var n,i=t[e];if(\"histogramy\"===i.type&&\"xbins\"in i&&!(\"ybins\"in i)&&(i.ybins=i.xbins,delete i.xbins),i.error_y&&\"opacity\"in i.error_y){var l=c.defaults,h=i.error_y.color||(f(i,\"bar\")?c.defaultLine:l[e%l.length]);i.error_y.color=c.addOpacity(c.rgb(h),c.opacity(h)*i.error_y.opacity),delete i.error_y.opacity}if(\"bardir\"in i&&(\"h\"!==i.bardir||!f(i,\"bar\")&&\"histogram\"!==i.type.substr(0,9)||(i.orientation=\"h\",r.swapXYData(i)),delete i.bardir),\"histogramy\"===i.type&&r.swapXYData(i),\"histogramx\"!==i.type&&\"histogramy\"!==i.type||(i.type=\"histogram\"),\"scl\"in i&&!(\"colorscale\"in i)&&(i.colorscale=i.scl,delete i.scl),\"reversescl\"in i&&!(\"reversescale\"in i)&&(i.reversescale=i.reversescl,delete i.reversescl),i.xaxis&&(i.xaxis=u(i.xaxis,\"x\")),i.yaxis&&(i.yaxis=u(i.yaxis,\"y\")),f(i,\"gl3d\")&&i.scene&&(i.scene=s.subplotsRegistry.gl3d.cleanId(i.scene)),!f(i,\"pie-like\")&&!f(i,\"bar-like\"))if(Array.isArray(i.textposition))for(n=0;n<i.textposition.length;n++)i.textposition[n]=m(i.textposition[n]);else i.textposition&&(i.textposition=m(i.textposition));var p=a.getModule(i);if(p&&p.colorbar){var x=p.colorbar.container,b=x?i[x]:i;b&&b.colorscale&&(\"YIGnBu\"===b.colorscale&&(b.colorscale=\"YlGnBu\"),\"YIOrRd\"===b.colorscale&&(b.colorscale=\"YlOrRd\"))}if(\"surface\"===i.type&&o.isPlainObject(i.contours)){var _=[\"x\",\"y\",\"z\"];for(n=0;n<_.length;n++){var w=i.contours[_[n]];o.isPlainObject(w)&&(w.highlightColor&&(w.highlightcolor=w.highlightColor,delete w.highlightColor),w.highlightWidth&&(w.highlightwidth=w.highlightWidth,delete w.highlightWidth))}}if(\"candlestick\"===i.type||\"ohlc\"===i.type){var k=!1!==(i.increasing||{}).showlegend,T=!1!==(i.decreasing||{}).showlegend,A=g(i.increasing),M=g(i.decreasing);if(!1!==A&&!1!==M){var S=v(A,M,k,T);S&&(i.name=S)}else!A&&!M||i.name||(i.name=A||M)}if(Array.isArray(i.transforms)){var E=i.transforms;for(n=0;n<E.length;n++){var C=E[n];if(o.isPlainObject(C))switch(C.type){case\"filter\":C.filtersrc&&(C.target=C.filtersrc,delete C.filtersrc),C.calendar&&(C.valuecalendar||(C.valuecalendar=C.calendar),delete C.calendar);break;case\"groupby\":if(C.styles=C.styles||C.style,C.styles&&!Array.isArray(C.styles)){var L=C.styles,P=Object.keys(L);C.styles=[];for(var O=0;O<P.length;O++)C.styles.push({target:P[O],value:L[P[O]]})}}}}y(i,\"line\")&&delete i.line,\"marker\"in i&&(y(i.marker,\"line\")&&delete i.marker.line,y(i,\"marker\")&&delete i.marker),c.clean(i),i.autobinx&&(delete i.autobinx,delete i.xbins),i.autobiny&&(delete i.autobiny,delete i.ybins),d(i),i.colorbar&&d(i.colorbar),i.marker&&i.marker.colorbar&&d(i.marker.colorbar),i.line&&i.line.colorbar&&d(i.line.colorbar),i.aaxis&&d(i.aaxis),i.baxis&&d(i.baxis)}},r.swapXYData=function(t){var e;if(o.swapAttrs(t,[\"?\",\"?0\",\"d?\",\"?bins\",\"nbins?\",\"autobin?\",\"?src\",\"error_?\"]),Array.isArray(t.z)&&Array.isArray(t.z[0])&&(t.transpose?delete t.transpose:t.transpose=!0),t.error_x&&t.error_y){var r=t.error_y,n=\"copy_ystyle\"in r?r.copy_ystyle:!(r.color||r.thickness||r.width);o.swapAttrs(t,[\"error_?.copy_ystyle\"]),n&&o.swapAttrs(t,[\"error_?.color\",\"error_?.thickness\",\"error_?.width\"])}if(\"string\"==typeof t.hoverinfo){var i=t.hoverinfo.split(\"+\");for(e=0;e<i.length;e++)\"x\"===i[e]?i[e]=\"y\":\"y\"===i[e]&&(i[e]=\"x\");t.hoverinfo=i.join(\"+\")}},r.coerceTraceIndices=function(t,e){if(n(e))return[e];if(!Array.isArray(e)||!e.length)return t.data.map(function(t,e){return e});if(Array.isArray(e)){for(var r=[],i=0;i<e.length;i++)o.isIndex(e[i],t.data.length)?r.push(e[i]):o.warn(\"trace index (\",e[i],\") is not a number or is out of bounds\");return r}return e},r.manageArrayContainers=function(t,e,r){var i=t.obj,a=t.parts,s=a.length,l=a[s-1],c=n(l);if(c&&null===e){var u=a.slice(0,s-1).join(\".\");o.nestedProperty(i,u).get().splice(l,1)}else c&&void 0===t.get()?(void 0===t.get()&&(r[t.astr]=null),t.set(e)):t.set(e)};var x=/(\\.[^\\[\\]\\.]+|\\[[^\\[\\]\\.]+\\])$/;function b(t){var e=t.search(x);if(e>0)return t.substr(0,e)}r.hasParent=function(t,e){for(var r=b(e);r;){if(r in t)return!0;r=b(r)}return!1};var _=[\"x\",\"y\",\"z\"];r.clearAxisTypes=function(t,e,r){for(var n=0;n<e.length;n++)for(var i=t._fullData[n],a=0;a<3;a++){var s=h(t,i,_[a]);if(s&&\"log\"!==s.type){var l=s._name,c=s._id.substr(1);if(\"scene\"===c.substr(0,5)){if(void 0!==r[c])continue;l=c+\".\"+l}var u=l+\".type\";void 0===r[l]&&void 0===r[u]&&o.nestedProperty(t.layout,u).set(null)}}}},{\"../components/color\":593,\"../lib\":719,\"../plots/cartesian/axis_ids\":770,\"../plots/plots\":828,\"../registry\":847,\"fast-isnumeric\":225,\"gl-mat4/fromQuat\":262}],752:[function(t,e,r){\"use strict\";var n=t(\"./plot_api\");r.plot=n.plot,r.newPlot=n.newPlot,r.restyle=n.restyle,r.relayout=n.relayout,r.redraw=n.redraw,r.update=n.update,r._guiRestyle=n._guiRestyle,r._guiRelayout=n._guiRelayout,r._guiUpdate=n._guiUpdate,r._storeDirectGUIEdit=n._storeDirectGUIEdit,r.react=n.react,r.extendTraces=n.extendTraces,r.prependTraces=n.prependTraces,r.addTraces=n.addTraces,r.deleteTraces=n.deleteTraces,r.moveTraces=n.moveTraces,r.purge=n.purge,r.addFrames=n.addFrames,r.deleteFrames=n.deleteFrames,r.animate=n.animate,r.setPlotConfig=n.setPlotConfig,r.toImage=t(\"./to_image\"),r.validate=t(\"./validate\"),r.downloadImage=t(\"../snapshot/download\");var i=t(\"./template_api\");r.makeTemplate=i.makeTemplate,r.validateTemplate=i.validateTemplate},{\"../snapshot/download\":849,\"./plot_api\":754,\"./template_api\":759,\"./to_image\":760,\"./validate\":761}],753:[function(t,e,r){\"use strict\";var n=t(\"../lib/is_plain_object\"),i=t(\"../lib/noop\"),a=t(\"../lib/loggers\"),o=t(\"../lib/search\").sorterAsc,s=t(\"../registry\");r.containerArrayMatch=t(\"./container_array_match\");var l=r.isAddVal=function(t){return\"add\"===t||n(t)},c=r.isRemoveVal=function(t){return null===t||\"remove\"===t};r.applyContainerArrayChanges=function(t,e,r,n,u){var h=e.astr,f=s.getComponentMethod(h,\"supplyLayoutDefaults\"),p=s.getComponentMethod(h,\"draw\"),d=s.getComponentMethod(h,\"drawOne\"),g=n.replot||n.recalc||f===i||p===i,v=t.layout,m=t._fullLayout;if(r[\"\"]){Object.keys(r).length>1&&a.warn(\"Full array edits are incompatible with other edits\",h);var y=r[\"\"][\"\"];if(c(y))e.set(null);else{if(!Array.isArray(y))return a.warn(\"Unrecognized full array edit value\",h,y),!0;e.set(y)}return!g&&(f(v,m),p(t),!0)}var x,b,_,w,k,T,A,M,S=Object.keys(r).map(Number).sort(o),E=e.get(),C=E||[],L=u(m,h).get(),P=[],O=-1,z=C.length;for(x=0;x<S.length;x++)if(w=r[_=S[x]],k=Object.keys(w),T=w[\"\"],A=l(T),_<0||_>C.length-(A?0:1))a.warn(\"index out of range\",h,_);else if(void 0!==T)k.length>1&&a.warn(\"Insertion & removal are incompatible with edits to the same index.\",h,_),c(T)?P.push(_):A?(\"add\"===T&&(T={}),C.splice(_,0,T),L&&L.splice(_,0,{})):a.warn(\"Unrecognized full object edit value\",h,_,T),-1===O&&(O=_);else for(b=0;b<k.length;b++)M=h+\"[\"+_+\"].\",u(C[_],k[b],M).set(w[k[b]]);for(x=P.length-1;x>=0;x--)C.splice(P[x],1),L&&L.splice(P[x],1);if(C.length?E||e.set(C):e.set(null),g)return!1;if(f(v,m),d!==i){var I;if(-1===O)I=S;else{for(z=Math.max(C.length,z),I=[],x=0;x<S.length&&!((_=S[x])>=O);x++)I.push(_);for(x=O;x<z;x++)I.push(x)}for(x=0;x<I.length;x++)d(t,I[x])}else p(t);return!0}},{\"../lib/is_plain_object\":720,\"../lib/loggers\":723,\"../lib/noop\":728,\"../lib/search\":738,\"../registry\":847,\"./container_array_match\":749}],754:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"has-hover\"),o=t(\"../lib\"),s=o.nestedProperty,l=t(\"../lib/events\"),c=t(\"../lib/queue\"),u=t(\"../registry\"),h=t(\"./plot_schema\"),f=t(\"../plots/plots\"),p=t(\"../plots/polar/legacy\"),d=t(\"../plots/cartesian/axes\"),g=t(\"../components/drawing\"),v=t(\"../components/color\"),m=t(\"../plots/cartesian/graph_interact\").initInteractions,y=t(\"../constants/xmlns_namespaces\"),x=t(\"../lib/svg_text_utils\"),b=t(\"../plots/cartesian/select\").clearSelect,_=t(\"./plot_config\").dfltConfig,w=t(\"./manage_arrays\"),k=t(\"./helpers\"),T=t(\"./subroutines\"),A=t(\"./edit_types\"),M=t(\"../plots/cartesian/constants\").AX_NAME_PATTERN,S=0,E=5;function C(t){var e=t._fullLayout;e._redrawFromAutoMarginCount?e._redrawFromAutoMarginCount--:t.emit(\"plotly_afterplot\")}function L(t,e){try{t._fullLayout._paper.style(\"background\",e)}catch(t){o.error(t)}}function P(t,e){L(t,v.combine(e,\"white\"))}function O(t,e){if(!t._context){t._context=o.extendDeep({},_);var r=n.select(\"base\");t._context._baseUrl=r.size()&&r.attr(\"href\")?window.location.href.split(\"#\")[0]:\"\"}var i,s,l,c=t._context;if(e){for(s=Object.keys(e),i=0;i<s.length;i++)\"editable\"!==(l=s[i])&&\"edits\"!==l&&l in c&&(\"setBackground\"===l&&\"opaque\"===e[l]?c[l]=P:c[l]=e[l]);e.plot3dPixelRatio&&!c.plotGlPixelRatio&&(c.plotGlPixelRatio=c.plot3dPixelRatio);var u=e.editable;if(void 0!==u)for(c.editable=u,s=Object.keys(c.edits),i=0;i<s.length;i++)c.edits[s[i]]=u;if(e.edits)for(s=Object.keys(e.edits),i=0;i<s.length;i++)(l=s[i])in c.edits&&(c.edits[l]=e.edits[l]);c._exportedPlot=e._exportedPlot}c.staticPlot&&(c.editable=!1,c.edits={},c.autosizable=!1,c.scrollZoom=!1,c.doubleClick=!1,c.showTips=!1,c.showLink=!1,c.displayModeBar=!1),\"hover\"!==c.displayModeBar||a||(c.displayModeBar=!0),\"transparent\"!==c.setBackground&&\"function\"==typeof c.setBackground||(c.setBackground=L),c._hasZeroHeight=c._hasZeroHeight||0===t.clientHeight,c._hasZeroWidth=c._hasZeroWidth||0===t.clientWidth;var h=c.scrollZoom,f=c._scrollZoom={};if(!0===h)f.cartesian=1,f.gl3d=1,f.geo=1,f.mapbox=1;else if(\"string\"==typeof h){var p=h.split(\"+\");for(i=0;i<p.length;i++)f[p[i]]=1}else!1!==h&&(f.gl3d=1,f.geo=1,f.mapbox=1)}function z(t,e){var r,n,i=e+1,a=[];for(r=0;r<t.length;r++)(n=t[r])<0?a.push(i+n):a.push(n);return a}function I(t,e,r){var n,i;for(n=0;n<e.length;n++){if((i=e[n])!==parseInt(i,10))throw new Error(\"all values in \"+r+\" must be integers\");if(i>=t.data.length||i<-t.data.length)throw new Error(r+\" must be valid indices for gd.data.\");if(e.indexOf(i,n+1)>-1||i>=0&&e.indexOf(-t.data.length+i)>-1||i<0&&e.indexOf(t.data.length+i)>-1)throw new Error(\"each index in \"+r+\" must be unique.\")}}function D(t,e,r){if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"currentIndices is a required argument.\");if(Array.isArray(e)||(e=[e]),I(t,e,\"currentIndices\"),\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&I(t,r,\"newIndices\"),\"undefined\"!=typeof r&&e.length!==r.length)throw new Error(\"current and new indices must be of equal length.\")}function R(t,e,r,n,a){!function(t,e,r,n){var i=o.isPlainObject(n);if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array\");if(!o.isPlainObject(e))throw new Error(\"update must be a key:value object\");if(\"undefined\"==typeof r)throw new Error(\"indices must be an integer or array of integers\");for(var a in I(t,r,\"indices\"),e){if(!Array.isArray(e[a])||e[a].length!==r.length)throw new Error(\"attribute \"+a+\" must be an array of length equal to indices array length\");if(i&&(!(a in n)||!Array.isArray(n[a])||n[a].length!==e[a].length))throw new Error(\"when maxPoints is set as a key:value object it must contain a 1:1 corrispondence with the keys and number of traces in the update object\")}}(t,e,r,n);for(var l=function(t,e,r,n){var a,l,c,u,h,f=o.isPlainObject(n),p=[];for(var d in Array.isArray(r)||(r=[r]),r=z(r,t.data.length-1),e)for(var g=0;g<r.length;g++){if(a=t.data[r[g]],l=(c=s(a,d)).get(),u=e[d][g],!o.isArrayOrTypedArray(u))throw new Error(\"attribute: \"+d+\" index: \"+g+\" must be an array\");if(!o.isArrayOrTypedArray(l))throw new Error(\"cannot extend missing or non-array attribute: \"+d);if(l.constructor!==u.constructor)throw new Error(\"cannot extend array with an array of a different type: \"+d);h=f?n[d][g]:n,i(h)||(h=-1),p.push({prop:c,target:l,insert:u,maxp:Math.floor(h)})}return p}(t,e,r,n),c={},u={},h=0;h<l.length;h++){var f=l[h].prop,p=l[h].maxp,d=a(l[h].target,l[h].insert,p);f.set(d[0]),Array.isArray(c[f.astr])||(c[f.astr]=[]),c[f.astr].push(d[1]),Array.isArray(u[f.astr])||(u[f.astr]=[]),u[f.astr].push(l[h].target.length)}return{update:c,maxPoints:u}}function F(t,e){var r=new t.constructor(t.length+e.length);return r.set(t),r.set(e,t.length),r}function B(t,e,n,i){t=o.getGraphDiv(t),k.clearPromiseQueue(t);var a={};if(\"string\"==typeof e)a[e]=n;else{if(!o.isPlainObject(e))return o.warn(\"Restyle fail.\",e,n,i),Promise.reject();a=o.extendFlat({},e),void 0===i&&(i=n)}Object.keys(a).length&&(t.changed=!0);var s=k.coerceTraceIndices(t,i),l=V(t,a,s),u=l.flags;u.calc&&(t.calcdata=void 0),u.clearAxisTypes&&k.clearAxisTypes(t,s,{});var h=[];u.fullReplot?h.push(r.plot):(h.push(f.previousPromises),f.supplyDefaults(t),u.markerSize&&(f.doCalcdata(t),Y(h)),u.style&&h.push(T.doTraceStyle),u.colorbars&&h.push(T.doColorBars),h.push(C)),h.push(f.rehover,f.redrag),c.add(t,B,[t,l.undoit,l.traces],B,[t,l.redoit,l.traces]);var p=o.syncOrAsync(h,t);return p&&p.then||(p=Promise.resolve()),p.then(function(){return t.emit(\"plotly_restyle\",l.eventData),t})}function N(t){return void 0===t?null:t}function j(t,e){return e?function(e,r,n){var i=s(e,r),a=i.set;return i.set=function(e){U((n||\"\")+r,i.get(),e,t),a(e)},i}:s}function U(t,e,r,n){if(Array.isArray(e)||Array.isArray(r))for(var i=Array.isArray(e)?e:[],a=Array.isArray(r)?r:[],s=Math.max(i.length,a.length),l=0;l<s;l++)U(t+\"[\"+l+\"]\",i[l],a[l],n);else if(o.isPlainObject(e)||o.isPlainObject(r)){var c=o.isPlainObject(e)?e:{},u=o.isPlainObject(r)?r:{},h=o.extendFlat({},c,u);for(var f in h)U(t+\".\"+f,c[f],u[f],n)}else void 0===n[t]&&(n[t]=N(e))}function V(t,e,r){var n,i=t._fullLayout,a=t._fullData,l=t.data,c=i._guiEditing,p=j(i._preGUI,c),g=o.extendDeepAll({},e);q(e);var v,m=A.traceFlags(),y={},x={};function b(){return r.map(function(){})}function _(t){var e=d.id2name(t);-1===v.indexOf(e)&&v.push(e)}function w(t){return\"LAYOUT\"+t+\".autorange\"}function T(t){return\"LAYOUT\"+t+\".range\"}function M(t){for(var e=t;e<a.length;e++)if(a[e]._input===l[t])return a[e]}function S(n,a,o){if(Array.isArray(n))n.forEach(function(t){S(t,a,o)});else if(!(n in e||k.hasParent(e,n))){var s;if(\"LAYOUT\"===n.substr(0,6))s=p(t.layout,n.replace(\"LAYOUT\",\"\"));else{var u=r[o];s=j(i._tracePreGUI[M(u)._fullInput.uid],c)(l[u],n)}n in x||(x[n]=b()),void 0===x[n][o]&&(x[n][o]=N(s.get())),void 0!==a&&s.set(a)}}function E(t){return function(e){return a[e][t]}}function C(t){return function(e,n){return!1===e?a[r[n]][t]:null}}for(var L in e){if(k.hasParent(e,L))throw new Error(\"cannot set \"+L+\" and a parent attribute simultaneously\");var P,O,z,I,D,R,F=e[L];if(\"autobinx\"!==L&&\"autobiny\"!==L||(L=L.charAt(L.length-1)+\"bins\",F=Array.isArray(F)?F.map(C(L)):!1===F?r.map(E(L)):null),y[L]=F,\"LAYOUT\"!==L.substr(0,6)){for(x[L]=b(),n=0;n<r.length;n++){if(P=l[r[n]],O=M(r[n]),I=(z=j(i._tracePreGUI[O._fullInput.uid],c)(P,L)).get(),void 0!==(D=Array.isArray(F)?F[n%F.length]:F)){var B=z.parts[z.parts.length-1],U=L.substr(0,L.length-B.length-1),V=U?U+\".\":\"\",H=U?s(O,U).get():O;if((R=h.getTraceValObject(O,z.parts))&&R.impliedEdits&&null!==D)for(var G in R.impliedEdits)S(o.relativeAttr(L,G),R.impliedEdits[G],n);else if(\"thicknessmode\"!==B&&\"lenmode\"!==B||I===D||\"fraction\"!==D&&\"pixels\"!==D||!H){if(\"type\"===L&&(\"pie\"===D!=(\"pie\"===I)||\"funnelarea\"===D!=(\"funnelarea\"===I))){var Y=\"x\",W=\"y\";\"bar\"!==D&&\"bar\"!==I||\"h\"!==P.orientation||(Y=\"y\",W=\"x\"),o.swapAttrs(P,[\"?\",\"?src\"],\"labels\",Y),o.swapAttrs(P,[\"d?\",\"?0\"],\"label\",Y),o.swapAttrs(P,[\"?\",\"?src\"],\"values\",W),\"pie\"===I||\"funnelarea\"===I?(s(P,\"marker.color\").set(s(P,\"marker.colors\").get()),i._pielayer.selectAll(\"g.trace\").remove()):u.traceIs(P,\"cartesian\")&&s(P,\"marker.colors\").set(s(P,\"marker.color\").get())}}else{var X=i._size,Z=H.orient,J=\"top\"===Z||\"bottom\"===Z;if(\"thicknessmode\"===B){var K=J?X.h:X.w;S(V+\"thickness\",H.thickness*(\"fraction\"===D?1/K:K),n)}else{var $=J?X.w:X.h;S(V+\"len\",H.len*(\"fraction\"===D?1/$:$),n)}}x[L][n]=N(I);if(-1!==[\"swapxy\",\"swapxyaxes\",\"orientation\",\"orientationaxes\"].indexOf(L)){if(\"orientation\"===L){z.set(D);var Q=P.x&&!P.y?\"h\":\"v\";if((z.get()||Q)===O.orientation)continue}else\"orientationaxes\"===L&&(P.orientation={v:\"h\",h:\"v\"}[O.orientation]);k.swapXYData(P),m.calc=m.clearAxisTypes=!0}else-1!==f.dataArrayContainers.indexOf(z.parts[0])?(k.manageArrayContainers(z,D,x),m.calc=!0):(R?R.arrayOk&&!u.traceIs(O,\"regl\")&&(o.isArrayOrTypedArray(D)||o.isArrayOrTypedArray(I))?m.calc=!0:A.update(m,R):m.calc=!0,z.set(D))}}if(-1!==[\"swapxyaxes\",\"orientationaxes\"].indexOf(L)&&d.swap(t,r),\"orientationaxes\"===L){var tt=s(t.layout,\"hovermode\");\"x\"===tt.get()?tt.set(\"y\"):\"y\"===tt.get()&&tt.set(\"x\")}if(-1!==[\"orientation\",\"type\"].indexOf(L)){for(v=[],n=0;n<r.length;n++){var et=l[r[n]];u.traceIs(et,\"cartesian\")&&(_(et.xaxis||\"x\"),_(et.yaxis||\"y\"))}S(v.map(w),!0,0),S(v.map(T),[0,1],0)}}else z=p(t.layout,L.replace(\"LAYOUT\",\"\")),x[L]=[N(z.get())],z.set(Array.isArray(F)?F[0]:F),m.calc=!0}return(m.calc||m.plot)&&(m.fullReplot=!0),{flags:m,undoit:x,redoit:y,traces:r,eventData:o.extendDeepNoArrays([],[g,r])}}function q(t){var e,r,n,i=o.counterRegex(\"axis\",\".title\",!1,!1),a=/colorbar\\.title$/,s=Object.keys(t);for(e=0;e<s.length;e++)r=s[e],n=t[r],\"title\"!==r&&!i.test(r)&&!a.test(r)||\"string\"!=typeof n&&\"number\"!=typeof n?r.indexOf(\"titlefont\")>-1?l(r,r.replace(\"titlefont\",\"title.font\")):r.indexOf(\"titleposition\")>-1?l(r,r.replace(\"titleposition\",\"title.position\")):r.indexOf(\"titleside\")>-1?l(r,r.replace(\"titleside\",\"title.side\")):r.indexOf(\"titleoffset\")>-1&&l(r,r.replace(\"titleoffset\",\"title.offset\")):l(r,r.replace(\"title\",\"title.text\"));function l(e,r){t[r]=t[e],delete t[e]}}function H(t,e,r){if(t=o.getGraphDiv(t),k.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);var n={};if(\"string\"==typeof e)n[e]=r;else{if(!o.isPlainObject(e))return o.warn(\"Relayout fail.\",e,r),Promise.reject();n=o.extendFlat({},e)}Object.keys(n).length&&(t.changed=!0);var i=J(t,n),a=i.flags;a.calc&&(t.calcdata=void 0);var s=[f.previousPromises];a.layoutReplot?s.push(T.layoutReplot):Object.keys(n).length&&(G(t,a,i)||f.supplyDefaults(t),a.legend&&s.push(T.doLegend),a.layoutstyle&&s.push(T.layoutStyles),a.axrange&&Y(s,i.rangesAltered),a.ticks&&s.push(T.doTicksRelayout),a.modebar&&s.push(T.doModeBar),a.camera&&s.push(T.doCamera),a.colorbars&&s.push(T.doColorBars),s.push(C)),s.push(f.rehover,f.redrag),c.add(t,H,[t,i.undoit],H,[t,i.redoit]);var l=o.syncOrAsync(s,t);return l&&l.then||(l=Promise.resolve(t)),l.then(function(){return t.emit(\"plotly_relayout\",i.eventData),t})}function G(t,e,r){var n=t._fullLayout;if(!e.axrange)return!1;for(var i in e)if(\"axrange\"!==i&&e[i])return!1;for(var a in r.rangesAltered){var o=d.id2name(a),s=t.layout[o],l=n[o];if(l.autorange=s.autorange,l.range=s.range.slice(),l.cleanRange(),l._matchGroup)for(var c in l._matchGroup)if(c!==a){var u=n[d.id2name(c)];u.autorange=l.autorange,u.range=l.range.slice(),u._input.range=l.range.slice()}}return!0}function Y(t,e){var r=e?function(t){var r=[],n=!0;for(var i in e){var a=d.getFromId(t,i);if(r.push(i),a._matchGroup)for(var o in a._matchGroup)e[o]||r.push(o);a.automargin&&(n=!1)}return d.draw(t,r,{skipTitle:n})}:function(t){return d.draw(t,\"redraw\")};t.push(b,T.doAutoRangeAndConstraints,r,T.drawData,T.finalDraw)}var W=/^[xyz]axis[0-9]*\\.range(\\[[0|1]\\])?$/,X=/^[xyz]axis[0-9]*\\.autorange$/,Z=/^[xyz]axis[0-9]*\\.domain(\\[[0|1]\\])?$/;function J(t,e){var r,n,i,a=t.layout,l=t._fullLayout,c=l._guiEditing,f=j(l._preGUI,c),p=Object.keys(e),g=d.list(t),v=o.extendDeepAll({},e),m={};for(q(e),p=Object.keys(e),n=0;n<p.length;n++)if(0===p[n].indexOf(\"allaxes\")){for(i=0;i<g.length;i++){var y=g[i]._id.substr(1),x=-1!==y.indexOf(\"scene\")?y+\".\":\"\",b=p[n].replace(\"allaxes\",x+g[i]._name);e[b]||(e[b]=e[p[n]])}delete e[p[n]]}var _=A.layoutFlags(),T={},S={};function E(t,r){if(Array.isArray(t))t.forEach(function(t){E(t,r)});else if(!(t in e||k.hasParent(e,t))){var n=f(a,t);t in S||(S[t]=N(n.get())),void 0!==r&&n.set(r)}}var C,L={};function P(t){var e=d.name2id(t.split(\".\")[0]);return L[e]=1,e}for(var O in e){if(k.hasParent(e,O))throw new Error(\"cannot set \"+O+\" and a parent attribute simultaneously\");for(var z=f(a,O),I=e[O],D=z.parts.length-1;D>0&&\"string\"!=typeof z.parts[D];)D--;var R=z.parts[D],F=z.parts[D-1]+\".\"+R,B=z.parts.slice(0,D).join(\".\"),U=s(t.layout,B).get(),V=s(l,B).get(),H=z.get();if(void 0!==I){T[O]=I,S[O]=\"reverse\"===R?I:N(H);var G=h.getLayoutValObject(l,z.parts);if(G&&G.impliedEdits&&null!==I)for(var Y in G.impliedEdits)E(o.relativeAttr(O,Y),G.impliedEdits[Y]);if(-1!==[\"width\",\"height\"].indexOf(O))if(I){E(\"autosize\",null);var J=\"height\"===O?\"width\":\"height\";E(J,l[J])}else l[O]=t._initialAutoSize[O];else if(\"autosize\"===O)E(\"width\",I?null:l.width),E(\"height\",I?null:l.height);else if(F.match(W))P(F),s(l,B+\"._inputRange\").set(null);else if(F.match(X)){P(F),s(l,B+\"._inputRange\").set(null);var $=s(l,B).get();$._inputDomain&&($._input.domain=$._inputDomain.slice())}else F.match(Z)&&s(l,B+\"._inputDomain\").set(null);if(\"type\"===R){var Q=U,tt=\"linear\"===V.type&&\"log\"===I,et=\"log\"===V.type&&\"linear\"===I;if(tt||et){if(Q&&Q.range)if(V.autorange)tt&&(Q.range=Q.range[1]>Q.range[0]?[1,2]:[2,1]);else{var rt=Q.range[0],nt=Q.range[1];tt?(rt<=0&&nt<=0&&E(B+\".autorange\",!0),rt<=0?rt=nt/1e6:nt<=0&&(nt=rt/1e6),E(B+\".range[0]\",Math.log(rt)/Math.LN10),E(B+\".range[1]\",Math.log(nt)/Math.LN10)):(E(B+\".range[0]\",Math.pow(10,rt)),E(B+\".range[1]\",Math.pow(10,nt)))}else E(B+\".autorange\",!0);Array.isArray(l._subplots.polar)&&l._subplots.polar.length&&l[z.parts[0]]&&\"radialaxis\"===z.parts[1]&&delete l[z.parts[0]]._subplot.viewInitial[\"radialaxis.range\"],u.getComponentMethod(\"annotations\",\"convertCoords\")(t,V,I,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,V,I,E)}else E(B+\".autorange\",!0),E(B+\".range\",null);s(l,B+\"._inputRange\").set(null)}else if(R.match(M)){var it=s(l,O).get(),at=(I||{}).type;at&&\"-\"!==at||(at=\"linear\"),u.getComponentMethod(\"annotations\",\"convertCoords\")(t,it,at,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,it,at,E)}var ot=w.containerArrayMatch(O);if(ot){r=ot.array,n=ot.index;var st=ot.property,lt=G||{editType:\"calc\"};\"\"!==n&&\"\"===st&&(w.isAddVal(I)?S[O]=null:w.isRemoveVal(I)?S[O]=(s(a,r).get()||[])[n]:o.warn(\"unrecognized full object value\",e)),A.update(_,lt),m[r]||(m[r]={});var ct=m[r][n];ct||(ct=m[r][n]={}),ct[st]=I,delete e[O]}else\"reverse\"===R?(U.range?U.range.reverse():(E(B+\".autorange\",!0),U.range=[1,0]),V.autorange?_.calc=!0:_.plot=!0):(l._has(\"scatter-like\")&&l._has(\"regl\")&&\"dragmode\"===O&&(\"lasso\"===I||\"select\"===I)&&\"lasso\"!==H&&\"select\"!==H?_.plot=!0:l._has(\"gl2d\")?_.plot=!0:G?A.update(_,G):_.calc=!0,z.set(I))}}for(r in m){w.applyContainerArrayChanges(t,f(a,r),m[r],_,f)||(_.plot=!0)}var ut=l._axisConstraintGroups||[];for(C in L)for(n=0;n<ut.length;n++){var ht=ut[n];if(ht[C])for(var ft in _.calc=!0,ht)L[ft]||(d.getFromId(t,ft)._constraintShrinkable=!0)}return(K(t)||e.height||e.width)&&(_.plot=!0),(_.plot||_.calc)&&(_.layoutReplot=!0),{flags:_,rangesAltered:L,undoit:S,redoit:T,eventData:v}}function K(t){var e=t._fullLayout,r=e.width,n=e.height;return t.layout.autosize&&f.plotAutoSize(t,t.layout,e),e.width!==r||e.height!==n}function $(t,e,n,i){if(t=o.getGraphDiv(t),k.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);o.isPlainObject(e)||(e={}),o.isPlainObject(n)||(n={}),Object.keys(e).length&&(t.changed=!0),Object.keys(n).length&&(t.changed=!0);var a=k.coerceTraceIndices(t,i),s=V(t,o.extendFlat({},e),a),l=s.flags,u=J(t,o.extendFlat({},n)),h=u.flags;(l.calc||h.calc)&&(t.calcdata=void 0),l.clearAxisTypes&&k.clearAxisTypes(t,a,n);var p=[];h.layoutReplot?p.push(T.layoutReplot):l.fullReplot?p.push(r.plot):(p.push(f.previousPromises),G(t,h,u)||f.supplyDefaults(t),l.style&&p.push(T.doTraceStyle),(l.colorbars||h.colorbars)&&p.push(T.doColorBars),h.legend&&p.push(T.doLegend),h.layoutstyle&&p.push(T.layoutStyles),h.axrange&&Y(p,u.rangesAltered),h.ticks&&p.push(T.doTicksRelayout),h.modebar&&p.push(T.doModeBar),h.camera&&p.push(T.doCamera),p.push(C)),p.push(f.rehover,f.redrag),c.add(t,$,[t,s.undoit,u.undoit,s.traces],$,[t,s.redoit,u.redoit,s.traces]);var d=o.syncOrAsync(p,t);return d&&d.then||(d=Promise.resolve(t)),d.then(function(){return t.emit(\"plotly_update\",{data:s.eventData,layout:u.eventData}),t})}function Q(t){return function(e){e._fullLayout._guiEditing=!0;var r=t.apply(null,arguments);return e._fullLayout._guiEditing=!1,r}}var tt=[{pattern:/^hiddenlabels/,attr:\"legend.uirevision\"},{pattern:/^((x|y)axis\\d*)\\.((auto)?range|title\\.text)/},{pattern:/axis\\d*\\.showspikes$/,attr:\"modebar.uirevision\"},{pattern:/(hover|drag)mode$/,attr:\"modebar.uirevision\"},{pattern:/^(scene\\d*)\\.camera/},{pattern:/^(geo\\d*)\\.(projection|center)/},{pattern:/^(ternary\\d*\\.[abc]axis)\\.(min|title\\.text)$/},{pattern:/^(polar\\d*\\.radialaxis)\\.((auto)?range|angle|title\\.text)/},{pattern:/^(polar\\d*\\.angularaxis)\\.rotation/},{pattern:/^(mapbox\\d*)\\.(center|zoom|bearing|pitch)/},{pattern:/^legend\\.(x|y)$/,attr:\"editrevision\"},{pattern:/^(shapes|annotations)/,attr:\"editrevision\"},{pattern:/^title\\.text$/,attr:\"editrevision\"}],et=[{pattern:/^selectedpoints$/,attr:\"selectionrevision\"},{pattern:/(^|value\\.)visible$/,attr:\"legend.uirevision\"},{pattern:/^dimensions\\[\\d+\\]\\.constraintrange/},{pattern:/^node\\.(x|y|groups)/},{pattern:/^level$/},{pattern:/(^|value\\.)name$/},{pattern:/colorbar\\.title\\.text$/},{pattern:/colorbar\\.(x|y)$/,attr:\"editrevision\"}];function rt(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=t.match(n.pattern);if(i)return{head:i[1],attr:n.attr}}}function nt(t,e){var r=s(e,t).get();if(void 0!==r)return r;var n=t.split(\".\");for(n.pop();n.length>1;)if(n.pop(),void 0!==(r=s(e,n.join(\".\")+\".uirevision\").get()))return r;return e.uirevision}function it(t,e){for(var r=0;r<e.length;r++)if(e[r]._fullInput.uid===t)return r;return-1}function at(t,e,r){for(var n=0;n<e.length;n++)if(e[n].uid===t)return n;return!e[r]||e[r].uid?-1:r}function ot(t,e){var r=o.isPlainObject(t),n=Array.isArray(t);return r||n?(r&&o.isPlainObject(e)||n&&Array.isArray(e))&&JSON.stringify(t)===JSON.stringify(e):t===e}function st(t,e,r,n){var i,a,l,c=n.getValObject,u=n.flags,h=n.immutable,f=n.inArray,p=n.arrayIndex;function d(){var t=i.editType;f&&-1!==t.indexOf(\"arraydraw\")?o.pushUnique(u.arrays[f],p):(A.update(u,i),\"none\"!==t&&u.nChanges++,n.transition&&i.anim&&u.nChangesAnim++,(W.test(l)||X.test(l))&&(u.rangesAltered[r[0]]=1),Z.test(l)&&s(e,\"_inputDomain\").set(null),\"datarevision\"===a&&(u.newDataRevision=1))}function g(t){return\"data_array\"===t.valType||t.arrayOk}for(a in t){if(u.calc&&!n.transition)return;var v=t[a],m=e[a],y=r.concat(a);if(l=y.join(\".\"),\"_\"!==a.charAt(0)&&\"function\"!=typeof v&&v!==m){if((\"tick0\"===a||\"dtick\"===a)&&\"geo\"!==r[0]){var x=e.tickmode;if(\"auto\"===x||\"array\"===x||!x)continue}if((\"range\"!==a||!e.autorange)&&(\"zmin\"!==a&&\"zmax\"!==a||\"contourcarpet\"!==e.type)&&(i=c(y))&&(!i._compareAsJSON||JSON.stringify(v)!==JSON.stringify(m))){var b,_=i.valType,w=g(i),k=Array.isArray(v),T=Array.isArray(m);if(k&&T){var M=\"_input_\"+a,S=t[M],E=e[M];if(Array.isArray(S)&&S===E)continue}if(void 0===m)w&&k?u.calc=!0:d();else if(i._isLinkedToArray){var C=[],L=!1;f||(u.arrays[a]=C);var P=Math.min(v.length,m.length),O=Math.max(v.length,m.length);if(P!==O){if(\"arraydraw\"!==i.editType){d();continue}L=!0}for(b=0;b<P;b++)st(v[b],m[b],y.concat(b),o.extendFlat({inArray:a,arrayIndex:b},n));if(L)for(b=P;b<O;b++)C.push(b)}else!_&&o.isPlainObject(v)?st(v,m,y,n):w?k&&T?(h&&(u.calc=!0),(h||n.newDataRevision)&&d()):k!==T?u.calc=!0:d():k&&T&&v.length===m.length&&String(v)===String(m)||d()}}}for(a in e)if(!(a in t||\"_\"===a.charAt(0)||\"function\"==typeof e[a])){if(g(i=c(r.concat(a)))&&Array.isArray(e[a]))return void(u.calc=!0);d()}}function lt(t){var e=n.select(t),r=t._fullLayout;if(r._container=e.selectAll(\".plot-container\").data([0]),r._container.enter().insert(\"div\",\":first-child\").classed(\"plot-container\",!0).classed(\"plotly\",!0),r._paperdiv=r._container.selectAll(\".svg-container\").data([0]),r._paperdiv.enter().append(\"div\").classed(\"svg-container\",!0).style(\"position\",\"relative\"),r._glcontainer=r._paperdiv.selectAll(\".gl-container\").data([{}]),r._glcontainer.enter().append(\"div\").classed(\"gl-container\",!0),r._paperdiv.selectAll(\".main-svg\").remove(),r._paperdiv.select(\".modebar-container\").remove(),r._paper=r._paperdiv.insert(\"svg\",\":first-child\").classed(\"main-svg\",!0),r._toppaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),r._modebardiv=r._paperdiv.append(\"div\"),r._hoverpaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),!r._uid){var i={};n.selectAll(\"defs\").each(function(){this.id&&(i[this.id.split(\"-\")[1]]=1)}),r._uid=o.randstr(i)}r._paperdiv.selectAll(\".main-svg\").attr(y.svgAttrs),r._defs=r._paper.append(\"defs\").attr(\"id\",\"defs-\"+r._uid),r._clips=r._defs.append(\"g\").classed(\"clips\",!0),r._topdefs=r._toppaper.append(\"defs\").attr(\"id\",\"topdefs-\"+r._uid),r._topclips=r._topdefs.append(\"g\").classed(\"clips\",!0),r._bgLayer=r._paper.append(\"g\").classed(\"bglayer\",!0),r._draggers=r._paper.append(\"g\").classed(\"draglayer\",!0);var a=r._paper.append(\"g\").classed(\"layer-below\",!0);r._imageLowerLayer=a.append(\"g\").classed(\"imagelayer\",!0),r._shapeLowerLayer=a.append(\"g\").classed(\"shapelayer\",!0),r._cartesianlayer=r._paper.append(\"g\").classed(\"cartesianlayer\",!0),r._polarlayer=r._paper.append(\"g\").classed(\"polarlayer\",!0),r._ternarylayer=r._paper.append(\"g\").classed(\"ternarylayer\",!0),r._geolayer=r._paper.append(\"g\").classed(\"geolayer\",!0),r._funnelarealayer=r._paper.append(\"g\").classed(\"funnelarealayer\",!0),r._pielayer=r._paper.append(\"g\").classed(\"pielayer\",!0),r._sunburstlayer=r._paper.append(\"g\").classed(\"sunburstlayer\",!0),r._indicatorlayer=r._toppaper.append(\"g\").classed(\"indicatorlayer\",!0),r._glimages=r._paper.append(\"g\").classed(\"glimages\",!0);var s=r._toppaper.append(\"g\").classed(\"layer-above\",!0);r._imageUpperLayer=s.append(\"g\").classed(\"imagelayer\",!0),r._shapeUpperLayer=s.append(\"g\").classed(\"shapelayer\",!0),r._infolayer=r._toppaper.append(\"g\").classed(\"infolayer\",!0),r._menulayer=r._toppaper.append(\"g\").classed(\"menulayer\",!0),r._zoomlayer=r._toppaper.append(\"g\").classed(\"zoomlayer\",!0),r._hoverlayer=r._hoverpaper.append(\"g\").classed(\"hoverlayer\",!0),r._modebardiv.classed(\"modebar-container\",!0).style(\"position\",\"absolute\").style(\"top\",\"0px\").style(\"right\",\"0px\"),t.emit(\"plotly_framework\")}r.animate=function(t,e,r){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before animating it. For more details, see https://plot.ly/javascript/animations/\");var n=t._transitionData;n._frameQueue||(n._frameQueue=[]);var i=(r=f.supplyAnimationDefaults(r)).transition,a=r.frame;function s(t){return Array.isArray(i)?t>=i.length?i[0]:i[t]:i}function l(t){return Array.isArray(a)?t>=a.length?a[0]:a[t]:a}function c(t,e){var r=0;return function(){if(t&&++r===e)return t()}}return void 0===n._frameWaitingCnt&&(n._frameWaitingCnt=0),new Promise(function(a,u){function h(){n._currentFrame&&n._currentFrame.onComplete&&n._currentFrame.onComplete();var e=n._currentFrame=n._frameQueue.shift();if(e){var r=e.name?e.name.toString():null;t._fullLayout._currentFrame=r,n._lastFrameAt=Date.now(),n._timeToNext=e.frameOpts.duration,f.transition(t,e.frame.data,e.frame.layout,k.coerceTraceIndices(t,e.frame.traces),e.frameOpts,e.transitionOpts).then(function(){e.onComplete&&e.onComplete()}),t.emit(\"plotly_animatingframe\",{name:r,frame:e.frame,animation:{frame:e.frameOpts,transition:e.transitionOpts}})}else t.emit(\"plotly_animated\"),window.cancelAnimationFrame(n._animationRaf),n._animationRaf=null}function p(){t.emit(\"plotly_animating\"),n._lastFrameAt=-1/0,n._timeToNext=0,n._runningTransitions=0,n._currentFrame=null;var e=function(){n._animationRaf=window.requestAnimationFrame(e),Date.now()-n._lastFrameAt>n._timeToNext&&h()};e()}var d,g,v=0;function m(t){return Array.isArray(i)?v>=i.length?t.transitionOpts=i[v]:t.transitionOpts=i[0]:t.transitionOpts=i,v++,t}var y=[],x=null==e,b=Array.isArray(e);if(x||b||!o.isPlainObject(e)){if(x||-1!==[\"string\",\"number\"].indexOf(typeof e))for(d=0;d<n._frames.length;d++)(g=n._frames[d])&&(x||String(g.group)===String(e))&&y.push({type:\"byname\",name:String(g.name),data:m({name:g.name})});else if(b)for(d=0;d<e.length;d++){var _=e[d];-1!==[\"number\",\"string\"].indexOf(typeof _)?(_=String(_),y.push({type:\"byname\",name:_,data:m({name:_})})):o.isPlainObject(_)&&y.push({type:\"object\",data:m(o.extendFlat({},_))})}}else y.push({type:\"object\",data:m(o.extendFlat({},e))});for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&!n._frameHash[g.data.name])return o.warn('animate failure: frame not found: \"'+g.data.name+'\"'),void u();-1!==[\"next\",\"immediate\"].indexOf(r.mode)&&function(){if(0!==n._frameQueue.length){for(;n._frameQueue.length;){var e=n._frameQueue.pop();e.onInterrupt&&e.onInterrupt()}t.emit(\"plotly_animationinterrupted\",[])}}(),\"reverse\"===r.direction&&y.reverse();var w=t._fullLayout._currentFrame;if(w&&r.fromcurrent){var T=-1;for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&g.name===w){T=d;break}if(T>0&&T<y.length-1){var A=[];for(d=0;d<y.length;d++)g=y[d],(\"byname\"!==y[d].type||d>T)&&A.push(g);y=A}}y.length>0?function(e){if(0!==e.length){for(var i=0;i<e.length;i++){var o;o=\"byname\"===e[i].type?f.computeFrame(t,e[i].name):e[i].data;var h=l(i),d=s(i);d.duration=Math.min(d.duration,h.duration);var g={frame:o,name:e[i].name,frameOpts:h,transitionOpts:d};i===e.length-1&&(g.onComplete=c(a,2),g.onInterrupt=u),n._frameQueue.push(g)}\"immediate\"===r.mode&&(n._lastFrameAt=-1/0),n._animationRaf||p()}}(y):(t.emit(\"plotly_animated\"),a())})},r.addFrames=function(t,e,r){if(t=o.getGraphDiv(t),null==e)return Promise.resolve();if(!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before adding frames. For more details, see https://plot.ly/javascript/animations/\");var n,i,a,s,l=t._transitionData._frames,u=t._transitionData._frameHash;if(!Array.isArray(e))throw new Error(\"addFrames failure: frameList must be an Array of frame definitions\"+e);var h=l.length+2*e.length,p=[],d={};for(n=e.length-1;n>=0;n--)if(o.isPlainObject(e[n])){var g=e[n].name,v=(u[g]||d[g]||{}).name,m=e[n].name,y=u[v]||d[v];v&&m&&\"number\"==typeof m&&y&&S<E&&(S++,o.warn('addFrames: overwriting frame \"'+(u[v]||d[v]).name+'\" with a frame whose name of type \"number\" also equates to \"'+v+'\". This is valid but may potentially lead to unexpected behavior since all plotly.js frame names are stored internally as strings.'),S===E&&o.warn(\"addFrames: This API call has yielded too many of these warnings. For the rest of this call, further warnings about numeric frame names will be suppressed.\")),d[g]={name:g},p.push({frame:f.supplyFrameDefaults(e[n]),index:r&&void 0!==r[n]&&null!==r[n]?r[n]:h+n})}p.sort(function(t,e){return t.index>e.index?-1:t.index<e.index?1:0});var x=[],b=[],_=l.length;for(n=p.length-1;n>=0;n--){if(\"number\"==typeof(i=p[n].frame).name&&o.warn(\"Warning: addFrames accepts frames with numeric names, but the numbers areimplicitly cast to strings\"),!i.name)for(;u[i.name=\"frame \"+t._transitionData._counter++];);if(u[i.name]){for(a=0;a<l.length&&(l[a]||{}).name!==i.name;a++);x.push({type:\"replace\",index:a,value:i}),b.unshift({type:\"replace\",index:a,value:l[a]})}else s=Math.max(0,Math.min(p[n].index,_)),x.push({type:\"insert\",index:s,value:i}),b.unshift({type:\"delete\",index:s}),_++}var w=f.modifyFrames,k=f.modifyFrames,T=[t,b],A=[t,x];return c&&c.add(t,w,T,k,A),f.modifyFrames(t,x)},r.deleteFrames=function(t,e){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);var r,n,i=t._transitionData._frames,a=[],s=[];if(!e)for(e=[],r=0;r<i.length;r++)e.push(r);for((e=e.slice()).sort(),r=e.length-1;r>=0;r--)n=e[r],a.push({type:\"delete\",index:n}),s.unshift({type:\"insert\",index:n,value:i[n]});var l=f.modifyFrames,u=f.modifyFrames,h=[t,s],p=[t,a];return c&&c.add(t,l,h,u,p),f.modifyFrames(t,a)},r.addTraces=function t(e,n,i){e=o.getGraphDiv(e);var a,s,l=[],u=r.deleteTraces,h=t,f=[e,l],p=[e,n];for(function(t,e,r){var n,i;if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"traces must be defined.\");for(Array.isArray(e)||(e=[e]),n=0;n<e.length;n++)if(\"object\"!=typeof(i=e[n])||Array.isArray(i)||null===i)throw new Error(\"all values in traces array must be non-array objects\");if(\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&r.length!==e.length)throw new Error(\"if indices is specified, traces.length must equal indices.length\")}(e,n,i),Array.isArray(n)||(n=[n]),n=n.map(function(t){return o.extendFlat({},t)}),k.cleanData(n),a=0;a<n.length;a++)e.data.push(n[a]);for(a=0;a<n.length;a++)l.push(-n.length+a);if(\"undefined\"==typeof i)return s=r.redraw(e),c.add(e,u,f,h,p),s;Array.isArray(i)||(i=[i]);try{D(e,l,i)}catch(t){throw e.data.splice(e.data.length-n.length,n.length),t}return c.startSequence(e),c.add(e,u,f,h,p),s=r.moveTraces(e,l,i),c.stopSequence(e),s},r.deleteTraces=function t(e,n){e=o.getGraphDiv(e);var i,a,s=[],l=r.addTraces,u=t,h=[e,s,n],f=[e,n];if(\"undefined\"==typeof n)throw new Error(\"indices must be an integer or array of integers.\");for(Array.isArray(n)||(n=[n]),I(e,n,\"indices\"),(n=z(n,e.data.length-1)).sort(o.sorterDes),i=0;i<n.length;i+=1)a=e.data.splice(n[i],1)[0],s.push(a);var p=r.redraw(e);return c.add(e,l,h,u,f),p},r.extendTraces=function t(e,n,i,a){var s=R(e=o.getGraphDiv(e),n,i,a,function(t,e,r){var n,i;if(o.isTypedArray(t))if(r<0){var a=new t.constructor(0),s=F(t,e);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(l)),i.set(t),i.set(e.subarray(0,l),t.length)}else{var c=r-e.length,u=t.length-c;n.set(t.subarray(u)),n.set(e,c),i.set(t.subarray(0,u))}else n=t.concat(e),i=r>=0&&r<n.length?n.splice(0,n.length-r):[];return[n,i]}),l=r.redraw(e),u=[e,s.update,i,s.maxPoints];return c.add(e,r.prependTraces,u,t,arguments),l},r.moveTraces=function t(e,n,i){var a,s=[],l=[],u=t,h=t,f=[e=o.getGraphDiv(e),i,n],p=[e,n,i];if(D(e,n,i),n=Array.isArray(n)?n:[n],\"undefined\"==typeof i)for(i=[],a=0;a<n.length;a++)i.push(-n.length+a);for(i=Array.isArray(i)?i:[i],n=z(n,e.data.length-1),i=z(i,e.data.length-1),a=0;a<e.data.length;a++)-1===n.indexOf(a)&&s.push(e.data[a]);for(a=0;a<n.length;a++)l.push({newIndex:i[a],trace:e.data[n[a]]});for(l.sort(function(t,e){return t.newIndex-e.newIndex}),a=0;a<l.length;a+=1)s.splice(l[a].newIndex,0,l[a].trace);e.data=s;var d=r.redraw(e);return c.add(e,u,f,h,p),d},r.prependTraces=function t(e,n,i,a){var s=R(e=o.getGraphDiv(e),n,i,a,function(t,e,r){var n,i;if(o.isTypedArray(t))if(r<=0){var a=new t.constructor(0),s=F(e,t);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(0,l)),i.set(e.subarray(l)),i.set(t,l)}else{var c=r-e.length;n.set(e),n.set(t.subarray(0,c),e.length),i.set(t.subarray(c))}else n=e.concat(t),i=r>=0&&r<n.length?n.splice(r,n.length):[];return[n,i]}),l=r.redraw(e),u=[e,s.update,i,s.maxPoints];return c.add(e,r.extendTraces,u,t,arguments),l},r.newPlot=function(t,e,n,i){return t=o.getGraphDiv(t),f.cleanPlot([],{},t._fullData||[],t._fullLayout||{}),f.purge(t),r.plot(t,e,n,i)},r.plot=function(t,e,i,a){var s;if(t=o.getGraphDiv(t),l.init(t),o.isPlainObject(e)){var c=e;e=c.data,i=c.layout,a=c.config,s=c.frames}if(!1===l.triggerHandler(t,\"plotly_beforeplot\",[e,i,a]))return Promise.reject();e||i||o.isPlotDiv(t)||o.warn(\"Calling Plotly.plot as if redrawing but this container doesn't yet have a plot.\",t),O(t,a),i||(i={}),n.select(t).classed(\"js-plotly-plot\",!0),g.makeTester(),Array.isArray(t._promises)||(t._promises=[]);var h=0===(t.data||[]).length&&Array.isArray(e);Array.isArray(e)&&(k.cleanData(e),h?t.data=e:t.data.push.apply(t.data,e),t.empty=!1),t.layout&&!h||(t.layout=k.cleanLayout(i)),f.supplyDefaults(t);var v=t._fullLayout,y=v._has(\"cartesian\");if(!v._has(\"polar\")&&e&&e[0]&&e[0].r)return o.log(\"Legacy polar charts are deprecated!\"),function(t,e,r){var i=n.select(t).selectAll(\".plot-container\").data([0]);i.enter().insert(\"div\",\":first-child\").classed(\"plot-container plotly\",!0);var a=i.selectAll(\".svg-container\").data([0]);a.enter().append(\"div\").classed(\"svg-container\",!0).style(\"position\",\"relative\"),a.html(\"\"),e&&(t.data=e),r&&(t.layout=r),p.manager.fillLayout(t),a.style({width:t._fullLayout.width+\"px\",height:t._fullLayout.height+\"px\"}),t.framework=p.manager.framework(t),t.framework({data:t.data,layout:t.layout},a.node()),t.framework.setUndoPoint();var s=t.framework.svg(),l=1,c=t._fullLayout.title?t._fullLayout.title.text:\"\";\"\"!==c&&c||(l=0);var u=function(){this.call(x.convertToTspans,t)},h=s.select(\".title-group text\").call(u);if(t._context.edits.titleText){var d=o._(t,\"Click to enter Plot title\");c&&c!==d||(l=.2,h.attr({\"data-unformatted\":d}).text(d).style({opacity:l}).on(\"mouseover.opacity\",function(){n.select(this).transition().duration(100).style(\"opacity\",1)}).on(\"mouseout.opacity\",function(){n.select(this).transition().duration(1e3).style(\"opacity\",0)}));var g=function(){this.call(x.makeEditable,{gd:t}).on(\"edit\",function(e){t.framework({layout:{title:{text:e}}}),this.text(e).call(u),this.call(g)}).on(\"cancel\",function(){var t=this.attr(\"data-unformatted\");this.text(t).call(u)})};h.call(g)}return t._context.setBackground(t,t._fullLayout.paper_bgcolor),f.addLinks(t),Promise.resolve()}(t,e,i);v._replotting=!0,h&&lt(t),t.framework!==lt&&(t.framework=lt,lt(t)),g.initGradients(t),h&&d.saveShowSpikeInitial(t);var b=!t.calcdata||t.calcdata.length!==(t._fullData||[]).length;b&&f.doCalcdata(t);for(var _=0;_<t.calcdata.length;_++)t.calcdata[_][0].trace=t._fullData[_];t._context.responsive?t._responsiveChartHandler||(t._responsiveChartHandler=function(){o.isHidden(t)||f.resize(t)},window.addEventListener(\"resize\",t._responsiveChartHandler)):o.clearResponsive(t);var w=o.extendFlat({},v._size),A=0;function M(){return f.clearAutoMarginIds(t),T.drawMarginPushers(t),d.allowAutoMargin(t),f.doAutoMargin(t),f.previousPromises(t)}function S(){t._transitioning||(T.doAutoRangeAndConstraints(t),h&&d.saveRangeInitial(t),u.getComponentMethod(\"rangeslider\",\"calcAutorange\")(t))}var E=[f.previousPromises,function(){if(s)return r.addFrames(t,s)},function e(){for(var r=v._basePlotModules,n=0;n<r.length;n++)r[n].drawFramework&&r[n].drawFramework(t);if(!v._glcanvas&&v._has(\"gl\")&&(v._glcanvas=v._glcontainer.selectAll(\".gl-canvas\").data([{key:\"contextLayer\",context:!0,pick:!1},{key:\"focusLayer\",context:!1,pick:!1},{key:\"pickLayer\",context:!1,pick:!0}],function(t){return t.key}),v._glcanvas.enter().append(\"canvas\").attr(\"class\",function(t){return\"gl-canvas gl-canvas-\"+t.key.replace(\"Layer\",\"\")}).style({position:\"absolute\",top:0,left:0,overflow:\"visible\",\"pointer-events\":\"none\"})),v._glcanvas){v._glcanvas.attr(\"width\",v.width).attr(\"height\",v.height);var i=v._glcanvas.data()[0].regl;if(i&&(Math.floor(v.width)!==i._gl.drawingBufferWidth||Math.floor(v.height)!==i._gl.drawingBufferHeight)){var a=\"WebGL context buffer and canvas dimensions do not match due to browser/WebGL bug.\";if(!A)return o.log(a+\" Clearing graph and plotting again.\"),f.cleanPlot([],{},t._fullData,v),f.supplyDefaults(t),v=t._fullLayout,f.doCalcdata(t),A++,e();o.error(a)}}return\"h\"===v.modebar.orientation?v._modebardiv.style(\"height\",null).style(\"width\",\"100%\"):v._modebardiv.style(\"width\",null).style(\"height\",v.height+\"px\"),f.previousPromises(t)},M,function(){if(f.didMarginChange(w,v._size))return o.syncOrAsync([M,T.layoutStyles],t)}];y&&E.push(function(){if(b)return o.syncOrAsync([u.getComponentMethod(\"shapes\",\"calcAutorange\"),u.getComponentMethod(\"annotations\",\"calcAutorange\"),S],t);S()}),E.push(T.layoutStyles),y&&E.push(function(){return d.draw(t,h?\"\":\"redraw\")}),E.push(T.drawData,T.finalDraw,m,f.addLinks,f.rehover,f.redrag,f.doAutoMargin,f.previousPromises);var L=o.syncOrAsync(E,t);return L&&L.then||(L=Promise.resolve()),L.then(function(){return C(t),t})},r.purge=function(t){var e=(t=o.getGraphDiv(t))._fullLayout||{},r=t._fullData||[];return f.cleanPlot([],{},r,e),f.purge(t),l.purge(t),e._container&&e._container.remove(),delete t._context,t},r.react=function(t,e,n,i){var a,l,c=(t=o.getGraphDiv(t))._fullData,p=t._fullLayout;if(o.isPlotDiv(t)&&c&&p){if(o.isPlainObject(e)){var d=e;e=d.data,n=d.layout,i=d.config,a=d.frames}var g=!1;if(i){var v=o.extendDeep({},t._context);t._context=void 0,O(t,i),g=function t(e,r){var n;for(n in e)if(\"_\"!==n.charAt(0)){var i=e[n],a=r[n];if(i!==a)if(o.isPlainObject(i)&&o.isPlainObject(a)){if(t(i,a))return!0}else{if(!Array.isArray(i)||!Array.isArray(a))return!0;if(i.length!==a.length)return!0;for(var s=0;s<i.length;s++)if(i[s]!==a[s]){if(!o.isPlainObject(i[s])||!o.isPlainObject(a[s]))return!0;if(t(i[s],a[s]))return!0}}}}(v,t._context)}t.data=e||[],k.cleanData(t.data),t.layout=n||{},k.cleanLayout(t.layout),function(t,e,r,n){var i,a,l,c,u,h,f,p,d=n._preGUI,g=[],v={};for(i in d){if(u=rt(i,tt)){if(a=u.attr||u.head+\".uirevision\",(c=(l=s(n,a).get())&&nt(a,e))&&c===l&&(null===(h=d[i])&&(h=void 0),ot(p=(f=s(e,i)).get(),h))){void 0===p&&\"autorange\"===i.substr(i.length-9)&&g.push(i.substr(0,i.length-10)),f.set(N(s(n,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i);delete d[i],\"range[\"===i.substr(i.length-8,6)&&(v[i.substr(0,i.length-9)]=1)}for(var m=0;m<g.length;m++){var y=g[m];if(v[y]){var x=s(e,y).get();x&&delete x.autorange}}var b=n._tracePreGUI;for(var _ in b){var w,k=b[_],T=null;for(i in k){if(!T){var A=it(_,r);if(A<0){delete b[_];break}var M=at(_,t,(w=r[A]._fullInput).index);if(M<0){delete b[_];break}T=t[M]}if(u=rt(i,et)){if(u.attr?c=(l=s(n,u.attr).get())&&nt(u.attr,e):(l=w.uirevision,void 0===(c=T.uirevision)&&(c=e.uirevision)),c&&c===l&&(null===(h=k[i])&&(h=void 0),ot(p=(f=s(T,i)).get(),h))){f.set(N(s(w,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i+\" in trace uid \"+_);delete k[i]}}}(t.data,t.layout,c,p),f.supplyDefaults(t,{skipUpdateCalc:!0});var m=t._fullData,y=t._fullLayout,x=void 0===y.datarevision,b=y.transition,_=function(t,e,r,n,i){var a=A.layoutFlags();return a.arrays={},a.rangesAltered={},a.nChanges=0,a.nChangesAnim=0,st(e,r,[],{getValObject:function(t){return h.getLayoutValObject(r,t)},flags:a,immutable:n,transition:i,gd:t}),(a.plot||a.calc)&&(a.layoutReplot=!0),i&&a.nChanges&&a.nChangesAnim&&(a.anim=a.nChanges===a.nChangesAnim?\"all\":\"some\"),a}(t,p,y,x,b),w=_.newDataRevision,M=function(t,e,r,n,i,a){var o=e.length===r.length;if(!i&&!o)return{fullReplot:!0,calc:!0};var s,l,c=A.traceFlags();c.arrays={},c.nChanges=0,c.nChangesAnim=0;var u={getValObject:function(t){var e=h.getTraceValObject(l,t);return!l._module.animatable&&e.anim&&(e.anim=!1),e},flags:c,immutable:n,transition:i,newDataRevision:a,gd:t},p={};for(s=0;s<e.length;s++)if(r[s]){if(l=r[s]._fullInput,f.hasMakesDataTransform(l)&&(l=r[s]),p[l.uid])continue;p[l.uid]=1,st(e[s]._fullInput,l,[],u)}return(c.calc||c.plot)&&(c.fullReplot=!0),i&&c.nChanges&&c.nChangesAnim&&(c.anim=c.nChanges===c.nChangesAnim&&o?\"all\":\"some\"),c}(t,c,m,x,b,w);K(t)&&(_.layoutReplot=!0),M.calc||_.calc?t.calcdata=void 0:f.supplyDefaultsUpdateCalc(t.calcdata,m);var S=[];if(a&&(t._transitionData={},f.createTransitionData(t),S.push(function(){return r.addFrames(t,a)})),y.transition&&!g&&(M.anim||_.anim))f.doCalcdata(t),T.doAutoRangeAndConstraints(t),S.push(function(){return f.transitionFromReact(t,M,_,p)});else if(M.fullReplot||_.layoutReplot||g)t._fullLayout._skipDefaults=!0,S.push(r.plot);else{for(var E in _.arrays){var L=_.arrays[E];if(L.length){var P=u.getComponentMethod(E,\"drawOne\");if(P!==o.noop)for(var z=0;z<L.length;z++)P(t,L[z]);else{var I=u.getComponentMethod(E,\"draw\");if(I===o.noop)throw new Error(\"cannot draw components: \"+E);I(t)}}}S.push(f.previousPromises),M.style&&S.push(T.doTraceStyle),(M.colorbars||_.colorbars)&&S.push(T.doColorBars),_.legend&&S.push(T.doLegend),_.layoutstyle&&S.push(T.layoutStyles),_.axrange&&Y(S),_.ticks&&S.push(T.doTicksRelayout),_.modebar&&S.push(T.doModeBar),_.camera&&S.push(T.doCamera),S.push(C)}S.push(f.rehover,f.redrag),(l=o.syncOrAsync(S,t))&&l.then||(l=Promise.resolve(t))}else l=r.newPlot(t,e,n,i);return l.then(function(){return t.emit(\"plotly_react\",{data:e,layout:n}),t})},r.redraw=function(t){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);return k.cleanData(t.data),k.cleanLayout(t.layout),t.calcdata=void 0,r.plot(t).then(function(){return t.emit(\"plotly_redraw\"),t})},r.relayout=H,r.restyle=B,r.setPlotConfig=function(t){return o.extendFlat(_,t)},r.update=$,r._guiRelayout=Q(H),r._guiRestyle=Q(B),r._guiUpdate=Q($),r._storeDirectGUIEdit=function(t,e,r){for(var n in r)U(n,s(t,n).get(),r[n],e)}},{\"../components/color\":593,\"../components/drawing\":614,\"../constants/xmlns_namespaces\":696,\"../lib\":719,\"../lib/events\":709,\"../lib/queue\":734,\"../lib/svg_text_utils\":743,\"../plots/cartesian/axes\":767,\"../plots/cartesian/constants\":773,\"../plots/cartesian/graph_interact\":776,\"../plots/cartesian/select\":784,\"../plots/plots\":828,\"../plots/polar/legacy\":836,\"../registry\":847,\"./edit_types\":750,\"./helpers\":751,\"./manage_arrays\":753,\"./plot_config\":755,\"./plot_schema\":756,\"./subroutines\":758,d3:163,\"fast-isnumeric\":225,\"has-hover\":410}],755:[function(t,e,r){\"use strict\";var n={staticPlot:{valType:\"boolean\",dflt:!1},plotlyServerURL:{valType:\"string\",dflt:\"https://plot.ly\"},editable:{valType:\"boolean\",dflt:!1},edits:{annotationPosition:{valType:\"boolean\",dflt:!1},annotationTail:{valType:\"boolean\",dflt:!1},annotationText:{valType:\"boolean\",dflt:!1},axisTitleText:{valType:\"boolean\",dflt:!1},colorbarPosition:{valType:\"boolean\",dflt:!1},colorbarTitleText:{valType:\"boolean\",dflt:!1},legendPosition:{valType:\"boolean\",dflt:!1},legendText:{valType:\"boolean\",dflt:!1},shapePosition:{valType:\"boolean\",dflt:!1},titleText:{valType:\"boolean\",dflt:!1}},autosizable:{valType:\"boolean\",dflt:!1},responsive:{valType:\"boolean\",dflt:!1},fillFrame:{valType:\"boolean\",dflt:!1},frameMargins:{valType:\"number\",dflt:0,min:0,max:.5},scrollZoom:{valType:\"flaglist\",flags:[\"cartesian\",\"gl3d\",\"geo\",\"mapbox\"],extras:[!0,!1],dflt:\"gl3d+geo+mapbox\"},doubleClick:{valType:\"enumerated\",values:[!1,\"reset\",\"autosize\",\"reset+autosize\"],dflt:\"reset+autosize\"},doubleClickDelay:{valType:\"number\",dflt:300,min:0},showAxisDragHandles:{valType:\"boolean\",dflt:!0},showAxisRangeEntryBoxes:{valType:\"boolean\",dflt:!0},showTips:{valType:\"boolean\",dflt:!0},showLink:{valType:\"boolean\",dflt:!1},linkText:{valType:\"string\",dflt:\"Edit chart\",noBlank:!0},sendData:{valType:\"boolean\",dflt:!0},showSources:{valType:\"any\",dflt:!1},displayModeBar:{valType:\"enumerated\",values:[\"hover\",!0,!1],dflt:\"hover\"},showSendToCloud:{valType:\"boolean\",dflt:!1},showEditInChartStudio:{valType:\"boolean\",dflt:!1},modeBarButtonsToRemove:{valType:\"any\",dflt:[]},modeBarButtonsToAdd:{valType:\"any\",dflt:[]},modeBarButtons:{valType:\"any\",dflt:!1},toImageButtonOptions:{valType:\"any\",dflt:{}},displaylogo:{valType:\"boolean\",dflt:!0},watermark:{valType:\"boolean\",dflt:!1},plotGlPixelRatio:{valType:\"number\",dflt:2,min:1,max:4},setBackground:{valType:\"any\",dflt:\"transparent\"},topojsonURL:{valType:\"string\",noBlank:!0,dflt:\"https://cdn.plot.ly/\"},mapboxAccessToken:{valType:\"string\",dflt:null},logging:{valType:\"boolean\",dflt:1},queueLength:{valType:\"integer\",min:0,dflt:0},globalTransforms:{valType:\"any\",dflt:[]},locale:{valType:\"string\",dflt:\"en-US\"},locales:{valType:\"any\",dflt:{}}},i={};!function t(e,r){for(var n in e){var i=e[n];i.valType?r[n]=i.dflt:(r[n]||(r[n]={}),t(i,r[n]))}}(n,i),e.exports={configAttributes:n,dfltConfig:i}},{}],756:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=t(\"../plots/attributes\"),o=t(\"../plots/layout_attributes\"),s=t(\"../plots/frame_attributes\"),l=t(\"../plots/animation_attributes\"),c=t(\"./plot_config\").configAttributes,u=t(\"../plots/polar/legacy/area_attributes\"),h=t(\"../plots/polar/legacy/axis_attributes\"),f=t(\"./edit_types\"),p=i.extendFlat,d=i.extendDeepAll,g=i.isPlainObject,v=i.isArrayOrTypedArray,m=i.nestedProperty,y=i.valObjectMeta,x=\"_isSubplotObj\",b=\"_isLinkedToArray\",_=[x,b,\"_arrayAttrRegexps\",\"_deprecated\"];function w(t,e,r){if(!t)return!1;if(t._isLinkedToArray)if(k(e[r]))r++;else if(r<e.length)return!1;for(;r<e.length;r++){var n=t[e[r]];if(!g(n))break;if(t=n,r===e.length-1)break;if(t._isLinkedToArray){if(!k(e[++r]))return!1}else if(\"info_array\"===t.valType){var i=e[++r];if(!k(i))return!1;var a=t.items;if(Array.isArray(a)){if(i>=a.length)return!1;if(2===t.dimensions){if(r++,e.length===r)return t;var o=e[r];if(!k(o))return!1;t=a[i][o]}else t=a[i]}else t=a}}return t}function k(t){return t===Math.round(t)&&t>=0}function T(t){return function(t){r.crawl(t,function(t,e,n){r.isValObject(t)?\"data_array\"===t.valType?(t.role=\"data\",n[e+\"src\"]={valType:\"string\",editType:\"none\"}):!0===t.arrayOk&&(n[e+\"src\"]={valType:\"string\",editType:\"none\"}):g(t)&&(t.role=\"object\")})}(t),function(t){r.crawl(t,function(t,e,r){if(!t)return;var n=t[b];if(!n)return;delete t[b],r[e]={items:{}},r[e].items[n]=t,r[e].role=\"object\"})}(t),function(t){!function t(e){for(var r in e)if(g(e[r]))t(e[r]);else if(Array.isArray(e[r]))for(var n=0;n<e[r].length;n++)t(e[r][n]);else e[r]instanceof RegExp&&(e[r]=e[r].toString())}(t)}(t),t}function A(t,e,r){var n=m(t,r),i=d({},e.layoutAttributes);i[x]=!0,n.set(i)}function M(t,e,r){var n=m(t,r);n.set(d(n.get()||{},e))}r.IS_SUBPLOT_OBJ=x,r.IS_LINKED_TO_ARRAY=b,r.DEPRECATED=\"_deprecated\",r.UNDERSCORE_ATTRS=_,r.get=function(){var t={};n.allTypes.concat(\"area\").forEach(function(e){t[e]=function(t){var e,i;\"area\"===t?(e={attributes:u},i={}):(e=n.modules[t]._module,i=e.basePlotModule);var o={type:null},s=d({},a),l=d({},e.attributes);r.crawl(l,function(t,e,r,n,i){m(s,i).set(void 0),void 0===t&&m(l,i).set(void 0)}),d(o,s),n.traceIs(t,\"noOpacity\")&&delete o.opacity;n.traceIs(t,\"showLegend\")||(delete o.showlegend,delete o.legendgroup);n.traceIs(t,\"noHover\")&&(delete o.hoverinfo,delete o.hoverlabel);e.selectPoints||delete o.selectedpoints;d(o,l),i.attributes&&d(o,i.attributes);o.type=t;var c={meta:e.meta||{},categories:e.categories||{},animatable:Boolean(e.animatable),type:t,attributes:T(o)};if(e.layoutAttributes){var h={};d(h,e.layoutAttributes),c.layoutAttributes=T(h)}e.animatable||r.crawl(c,function(t){r.isValObject(t)&&\"anim\"in t&&delete t.anim});return c}(e)});var e,i={};return Object.keys(n.transformsRegistry).forEach(function(t){i[t]=function(t){var e=n.transformsRegistry[t],r=d({},e.attributes);return Object.keys(n.componentsRegistry).forEach(function(e){var i=n.componentsRegistry[e];i.schema&&i.schema.transforms&&i.schema.transforms[t]&&Object.keys(i.schema.transforms[t]).forEach(function(e){M(r,i.schema.transforms[t][e],e)})}),{attributes:T(r)}}(t)}),{defs:{valObjects:y,metaKeys:_.concat([\"description\",\"role\",\"editType\",\"impliedEdits\"]),editType:{traces:f.traces,layout:f.layout},impliedEdits:{}},traces:t,layout:function(){var t,e,r={};for(t in d(r,o),n.subplotsRegistry)if((e=n.subplotsRegistry[t]).layoutAttributes)if(Array.isArray(e.attr))for(var i=0;i<e.attr.length;i++)A(r,e,e.attr[i]);else{var a=\"subplot\"===e.attr?e.name:e.attr;A(r,e,a)}for(t in r=function(t){return p(t,{radialaxis:h.radialaxis,angularaxis:h.angularaxis}),p(t,h.layout),t}(r),n.componentsRegistry){var s=(e=n.componentsRegistry[t]).schema;if(s&&(s.subplots||s.layout)){var l=s.subplots;if(l&&l.xaxis&&!l.yaxis)for(var c in l.xaxis)delete r.yaxis[c]}else\"colorscale\"===e.name?d(r,e.layoutAttributes):e.layoutAttributes&&M(r,e.layoutAttributes,e.name)}return{layoutAttributes:T(r)}}(),transforms:i,frames:(e={frames:d({},s)},T(e),e.frames),animation:T(l),config:T(c)}},r.crawl=function(t,e,n,i){var a=n||0;i=i||\"\",Object.keys(t).forEach(function(n){var o=t[n];if(-1===_.indexOf(n)){var s=(i?i+\".\":\"\")+n;e(o,n,t,a,s),r.isValObject(o)||g(o)&&\"impliedEdits\"!==n&&r.crawl(o,e,a+1,s)}})},r.isValObject=function(t){return t&&void 0!==t.valType},r.findArrayAttributes=function(t){var e,n,i=[],o=[],s=[];function l(t,r,a,l){o=o.slice(0,l).concat([r]),s=s.slice(0,l).concat([t&&t._isLinkedToArray]),t&&(\"data_array\"===t.valType||!0===t.arrayOk)&&!(\"colorbar\"===o[l-1]&&(\"ticktext\"===r||\"tickvals\"===r))&&function t(e,r,a){var l=e[o[r]];var c=a+o[r];if(r===o.length-1)v(l)&&i.push(n+c);else if(s[r]){if(Array.isArray(l))for(var u=0;u<l.length;u++)g(l[u])&&t(l[u],r+1,c+\"[\"+u+\"].\")}else g(l)&&t(l,r+1,c+\".\")}(e,0,\"\")}e=t,n=\"\",r.crawl(a,l),t._module&&t._module.attributes&&r.crawl(t._module.attributes,l);var c=t.transforms;if(c)for(var u=0;u<c.length;u++){var h=c[u],f=h._module;f&&(n=\"transforms[\"+u+\"].\",e=h,r.crawl(f.attributes,l))}return i},r.getTraceValObject=function(t,e){var r,i,o=e[0],s=1;if(\"transforms\"===o){if(1===e.length)return a.transforms;var l=t.transforms;if(!Array.isArray(l)||!l.length)return!1;var c=e[1];if(!k(c)||c>=l.length)return!1;i=(r=(n.transformsRegistry[l[c].type]||{}).attributes)&&r[e[2]],s=3}else if(\"area\"===t.type)i=u[o];else{var h=t._module;if(h||(h=(n.modules[t.type||a.type.dflt]||{})._module),!h)return!1;if(!(i=(r=h.attributes)&&r[o])){var f=h.basePlotModule;f&&f.attributes&&(i=f.attributes[o])}i||(i=a[o])}return w(i,e,s)},r.getLayoutValObject=function(t,e){return w(function(t,e){var r,i,a,s,l=t._basePlotModules;if(l){var c;for(r=0;r<l.length;r++){if((a=l[r]).attrRegex&&a.attrRegex.test(e)){if(a.layoutAttrOverrides)return a.layoutAttrOverrides;!c&&a.layoutAttributes&&(c=a.layoutAttributes)}var u=a.baseLayoutAttrOverrides;if(u&&e in u)return u[e]}if(c)return c}var f=t._modules;if(f)for(r=0;r<f.length;r++)if((s=f[r].layoutAttributes)&&e in s)return s[e];for(i in n.componentsRegistry){if(\"colorscale\"===(a=n.componentsRegistry[i]).name&&0===e.indexOf(\"coloraxis\"))return a.layoutAttributes[e];if(!a.schema&&e===a.name)return a.layoutAttributes}if(e in o)return o[e];if(\"radialaxis\"===e||\"angularaxis\"===e)return h[e];return h.layout[e]||!1}(t,e[0]),e,1)}},{\"../lib\":719,\"../plots/animation_attributes\":762,\"../plots/attributes\":764,\"../plots/frame_attributes\":794,\"../plots/layout_attributes\":819,\"../plots/polar/legacy/area_attributes\":834,\"../plots/polar/legacy/axis_attributes\":835,\"../registry\":847,\"./edit_types\":750,\"./plot_config\":755}],757:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/attributes\"),a=\"templateitemname\",o={name:{valType:\"string\",editType:\"none\"}};function s(t){return t&&\"string\"==typeof t}function l(t){var e=t.length-1;return\"s\"!==t.charAt(e)&&n.warn(\"bad argument to arrayDefaultKey: \"+t),t.substr(0,t.length-1)+\"defaults\"}o[a]={valType:\"string\",editType:\"calc\"},r.templatedArray=function(t,e){return e._isLinkedToArray=t,e.name=o.name,e[a]=o[a],e},r.traceTemplater=function(t){var e,r,a={};for(e in t)r=t[e],Array.isArray(r)&&r.length&&(a[e]=0);return{newTrace:function(o){var s={type:e=n.coerce(o,{},i,\"type\"),_template:null};if(e in a){r=t[e];var l=a[e]%r.length;a[e]++,s._template=r[l]}return s}}},r.newContainer=function(t,e,r){var i=t._template,a=i&&(i[e]||r&&i[r]);return n.isPlainObject(a)||(a=null),t[e]={_template:a}},r.arrayTemplater=function(t,e,r){var n=t._template,i=n&&n[l(e)],o=n&&n[e];Array.isArray(o)&&o.length||(o=[]);var c={};return{newItem:function(t){var e={name:t.name,_input:t},n=e[a]=t[a];if(!s(n))return e._template=i,e;for(var l=0;l<o.length;l++){var u=o[l];if(u.name===n)return c[n]=1,e._template=u,e}return e[r]=t[r]||!1,e._template=!1,e},defaultItems:function(){for(var t=[],e=0;e<o.length;e++){var r=o[e],n=r.name;if(s(n)&&!c[n]){var i={_template:r,name:n,_input:{_templateitemname:n}};i[a]=r[a],t.push(i),c[n]=1}}return t}}},r.arrayDefaultKey=l,r.arrayEditor=function(t,e,r){var i=(n.nestedProperty(t,e).get()||[]).length,o=r._index,s=o>=i&&(r._input||{})._templateitemname;s&&(o=i);var l,c=e+\"[\"+o+\"]\";function u(){l={},s&&(l[c]={},l[c][a]=s)}function h(t,e){s?n.nestedProperty(l[c],t).set(e):l[c+\".\"+t]=e}function f(){var t=l;return u(),t}return u(),{modifyBase:function(t,e){l[t]=e},modifyItem:h,getUpdateObj:f,applyUpdate:function(e,r){e&&h(e,r);var i=f();for(var a in i)n.nestedProperty(t,a).set(i[a])}}}},{\"../lib\":719,\"../plots/attributes\":764}],758:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../registry\"),a=t(\"../plots/plots\"),o=t(\"../lib\"),s=t(\"../lib/clear_gl_canvases\"),l=t(\"../components/color\"),c=t(\"../components/drawing\"),u=t(\"../components/titles\"),h=t(\"../components/modebar\"),f=t(\"../plots/cartesian/axes\"),p=t(\"../constants/alignment\"),d=t(\"../plots/cartesian/constraints\"),g=d.enforce,v=d.clean,m=t(\"../plots/cartesian/autorange\").doAutoRange,y=\"start\",x=\"middle\",b=\"end\";function _(t,e,r){for(var n=0;n<r.length;n++){var i=r[n][0],a=r[n][1];if(!(i[0]>=t[1]||i[1]<=t[0])&&(a[0]<e[1]&&a[1]>e[0]))return!0}return!1}function w(t){var e,i,a,s,u,d,g=t._fullLayout,v=g._size,m=v.p,y=f.list(t,\"\",!0);if(g._paperdiv.style({width:t._context.responsive&&g.autosize&&!t._context._hasZeroWidth&&!t.layout.width?\"100%\":g.width+\"px\",height:t._context.responsive&&g.autosize&&!t._context._hasZeroHeight&&!t.layout.height?\"100%\":g.height+\"px\"}).selectAll(\".main-svg\").call(c.setSize,g.width,g.height),t._context.setBackground(t,g.paper_bgcolor),r.drawMainTitle(t),h.manage(t),!g._has(\"cartesian\"))return t._promises.length&&Promise.all(t._promises);function x(t,e,r){var n=t._lw/2;return\"x\"===t._id.charAt(0)?e?\"top\"===r?e._offset-m-n:e._offset+e._length+m+n:v.t+v.h*(1-(t.position||0))+n%1:e?\"right\"===r?e._offset+e._length+m+n:e._offset-m-n:v.l+v.w*(t.position||0)+n%1}for(e=0;e<y.length;e++){var b=(s=y[e])._anchorAxis;s._linepositions={},s._lw=c.crispRound(t,s.linewidth,1),s._mainLinePosition=x(s,b,s.side),s._mainMirrorPosition=s.mirror&&b?x(s,b,p.OPPOSITE_SIDE[s.side]):null}var w=[],T=[],M=[],S=1===l.opacity(g.paper_bgcolor)&&1===l.opacity(g.plot_bgcolor)&&g.paper_bgcolor===g.plot_bgcolor;for(i in g._plots)if((a=g._plots[i]).mainplot)a.bg&&a.bg.remove(),a.bg=void 0;else{var E=a.xaxis.domain,C=a.yaxis.domain,L=a.plotgroup;if(_(E,C,M)){var P=L.node(),O=a.bg=o.ensureSingle(L,\"rect\",\"bg\");P.insertBefore(O.node(),P.childNodes[0]),T.push(i)}else L.select(\"rect.bg\").remove(),M.push([E,C]),S||(w.push(i),T.push(i))}var z,I,D,R,F,B,N,j,U,V,q,H,G,Y=g._bgLayer.selectAll(\".bg\").data(w);for(Y.enter().append(\"rect\").classed(\"bg\",!0),Y.exit().remove(),Y.each(function(t){g._plots[t].bg=n.select(this)}),e=0;e<T.length;e++)a=g._plots[T[e]],u=a.xaxis,d=a.yaxis,a.bg&&a.bg.call(c.setRect,u._offset-m,d._offset-m,u._length+2*m,d._length+2*m).call(l.fill,g.plot_bgcolor).style(\"stroke-width\",0);if(!g._hasOnlyLargeSploms)for(i in g._plots){a=g._plots[i],u=a.xaxis,d=a.yaxis;var W,X,Z=a.clipId=\"clip\"+g._uid+i+\"plot\",J=o.ensureSingleById(g._clips,\"clipPath\",Z,function(t){t.classed(\"plotclip\",!0).append(\"rect\")});a.clipRect=J.select(\"rect\").attr({width:u._length,height:d._length}),c.setTranslate(a.plot,u._offset,d._offset),a._hasClipOnAxisFalse?(W=null,X=Z):(W=Z,X=null),c.setClipUrl(a.plot,W,t),a.layerClipId=X}function K(t){return\"M\"+z+\",\"+t+\"H\"+I}function $(t){return\"M\"+u._offset+\",\"+t+\"h\"+u._length}function Q(t){return\"M\"+t+\",\"+j+\"V\"+N}function tt(t){return\"M\"+t+\",\"+d._offset+\"v\"+d._length}function et(t,e,r){if(!t.showline||i!==t._mainSubplot)return\"\";if(!t._anchorAxis)return r(t._mainLinePosition);var n=e(t._mainLinePosition);return t.mirror&&(n+=e(t._mainMirrorPosition)),n}for(i in g._plots){a=g._plots[i],u=a.xaxis,d=a.yaxis;var rt=\"M0,0\";k(u,i)&&(F=A(u,\"left\",d,y),z=u._offset-(F?m+F:0),B=A(u,\"right\",d,y),I=u._offset+u._length+(B?m+B:0),D=x(u,d,\"bottom\"),R=x(u,d,\"top\"),!(G=!u._anchorAxis||i!==u._mainSubplot)||\"allticks\"!==u.mirror&&\"all\"!==u.mirror||(u._linepositions[i]=[D,R]),rt=et(u,K,$),G&&u.showline&&(\"all\"===u.mirror||\"allticks\"===u.mirror)&&(rt+=K(D)+K(R)),a.xlines.style(\"stroke-width\",u._lw+\"px\").call(l.stroke,u.showline?u.linecolor:\"rgba(0,0,0,0)\")),a.xlines.attr(\"d\",rt);var nt=\"M0,0\";k(d,i)&&(q=A(d,\"bottom\",u,y),N=d._offset+d._length+(q?m:0),H=A(d,\"top\",u,y),j=d._offset-(H?m:0),U=x(d,u,\"left\"),V=x(d,u,\"right\"),!(G=!d._anchorAxis||i!==d._mainSubplot)||\"allticks\"!==d.mirror&&\"all\"!==d.mirror||(d._linepositions[i]=[U,V]),nt=et(d,Q,tt),G&&d.showline&&(\"all\"===d.mirror||\"allticks\"===d.mirror)&&(nt+=Q(U)+Q(V)),a.ylines.style(\"stroke-width\",d._lw+\"px\").call(l.stroke,d.showline?d.linecolor:\"rgba(0,0,0,0)\")),a.ylines.attr(\"d\",nt)}return f.makeClipPaths(t),t._promises.length&&Promise.all(t._promises)}function k(t,e){return(t.ticks||t.showline)&&(e===t._mainSubplot||\"all\"===t.mirror||\"allticks\"===t.mirror)}function T(t,e,r){if(!r.showline||!r._lw)return!1;if(\"all\"===r.mirror||\"allticks\"===r.mirror)return!0;var n=r._anchorAxis;if(!n)return!1;var i=p.FROM_BL[e];return r.side===e?n.domain[i]===t.domain[i]:r.mirror&&n.domain[1-i]===t.domain[1-i]}function A(t,e,r,n){if(T(t,e,r))return r._lw;for(var i=0;i<n.length;i++){var a=n[i];if(a._mainAxis===r._mainAxis&&T(t,e,a))return a._lw}return 0}r.layoutStyles=function(t){return o.syncOrAsync([a.doAutoMargin,w],t)},r.drawMainTitle=function(t){var e=t._fullLayout,r=function(t){var e=t.title,r=x;o.isRightAnchor(e)?r=b:o.isLeftAnchor(e)&&(r=y);return r}(e),n=function(t){var e=t.title,r=\"0em\";o.isTopAnchor(e)?r=p.CAP_SHIFT+\"em\":o.isMiddleAnchor(e)&&(r=p.MID_SHIFT+\"em\");return r}(e);u.draw(t,\"gtitle\",{propContainer:e,propName:\"title.text\",placeholder:e._dfltTitle.plot,attributes:{x:function(t,e){var r=t.title,n=t._size,i=0;e===y?i=r.pad.l:e===b&&(i=-r.pad.r);switch(r.xref){case\"paper\":return n.l+n.w*r.x+i;case\"container\":default:return t.width*r.x+i}}(e,r),y:function(t,e){var r=t.title,n=t._size,i=0;\"0em\"!==e&&e?e===p.CAP_SHIFT+\"em\"&&(i=r.pad.t):i=-r.pad.b;if(\"auto\"===r.y)return n.t/2;switch(r.yref){case\"paper\":return n.t+n.h-n.h*r.y+i;case\"container\":default:return t.height-t.height*r.y+i}}(e,n),\"text-anchor\":r,dy:n}})},r.doTraceStyle=function(t){var e,n=t.calcdata,o=[];for(e=0;e<n.length;e++){var l=n[e],c=l[0]||{},u=c.trace||{},h=u._module||{},f=h.arraysToCalcdata;f&&f(l,u);var p=h.editStyle;p&&o.push({fn:p,cd0:c})}if(o.length){for(e=0;e<o.length;e++){var d=o[e];d.fn(t,d.cd0)}s(t),r.redrawReglTraces(t)}return a.style(t),i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doColorBars=function(t){return i.getComponentMethod(\"colorbar\",\"draw\")(t),a.previousPromises(t)},r.layoutReplot=function(t){var e=t.layout;return t.layout=void 0,i.call(\"plot\",t,\"\",e)},r.doLegend=function(t){return i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doTicksRelayout=function(t){return f.draw(t,\"redraw\"),t._fullLayout._hasOnlyLargeSploms&&(i.subplotsRegistry.splom.updateGrid(t),s(t),r.redrawReglTraces(t)),r.drawMainTitle(t),a.previousPromises(t)},r.doModeBar=function(t){var e=t._fullLayout;h.manage(t);for(var r=0;r<e._basePlotModules.length;r++){var n=e._basePlotModules[r].updateFx;n&&n(t)}return a.previousPromises(t)},r.doCamera=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){var i=e[r[n]],a=i._scene,o=i.camera;a.setCamera(o)}},r.drawData=function(t){var e=t._fullLayout;s(t);for(var n=e._basePlotModules,o=0;o<n.length;o++)n[o].plot(t);return r.redrawReglTraces(t),a.style(t),i.getComponentMethod(\"shapes\",\"draw\")(t),i.getComponentMethod(\"annotations\",\"draw\")(t),e._replotting=!1,a.previousPromises(t)},r.redrawReglTraces=function(t){var e=t._fullLayout;if(e._has(\"regl\")){var r,n,i=t._fullData,a=[],s=[];for(e._hasOnlyLargeSploms&&e._splomGrid.draw(),r=0;r<i.length;r++){var l=i[r];!0===l.visible&&0!==l._length&&(\"splom\"===l.type?e._splomScenes[l.uid].draw():\"scattergl\"===l.type?o.pushUnique(a,l.xaxis+l.yaxis):\"scatterpolargl\"===l.type&&o.pushUnique(s,l.subplot))}for(r=0;r<a.length;r++)(n=e._plots[a[r]])._scene&&n._scene.draw();for(r=0;r<s.length;r++)(n=e[s[r]]._subplot)._scene&&n._scene.draw()}},r.doAutoRangeAndConstraints=function(t){for(var e,r,n=t._fullLayout,i=f.list(t,\"\",!0),a=n._axisMatchGroups||[],s=0;s<i.length;s++)e=i[s],v(t,e),m(t,e);g(t);t:for(var l=0;l<a.length;l++){var c,u=a[l],h=null;for(c in u){if(!1===(e=f.getFromId(t,c)).autorange)continue t;r=o.simpleMap(e.range,e.r2l),h?h[0]<h[1]?(h[0]=Math.min(h[0],r[0]),h[1]=Math.max(h[1],r[1])):(h[0]=Math.max(h[0],r[0]),h[1]=Math.min(h[1],r[1])):h=r}for(c in u)(e=f.getFromId(t,c)).range=o.simpleMap(h,e.l2r),e._input.range=e.range.slice(),e.setScale()}},r.finalDraw=function(t){i.getComponentMethod(\"shapes\",\"draw\")(t),i.getComponentMethod(\"images\",\"draw\")(t),i.getComponentMethod(\"annotations\",\"draw\")(t),i.getComponentMethod(\"rangeslider\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t)},r.drawMarginPushers=function(t){i.getComponentMethod(\"legend\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t),i.getComponentMethod(\"sliders\",\"draw\")(t),i.getComponentMethod(\"updatemenus\",\"draw\")(t),i.getComponentMethod(\"colorbar\",\"draw\")(t)}},{\"../components/color\":593,\"../components/drawing\":614,\"../components/modebar\":652,\"../components/titles\":681,\"../constants/alignment\":688,\"../lib\":719,\"../lib/clear_gl_canvases\":704,\"../plots/cartesian/autorange\":766,\"../plots/cartesian/axes\":767,\"../plots/cartesian/constraints\":774,\"../plots/plots\":828,\"../registry\":847,d3:163}],759:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.isPlainObject,a=t(\"./plot_schema\"),o=t(\"../plots/plots\"),s=t(\"../plots/attributes\"),l=t(\"./plot_template\"),c=t(\"./plot_config\").dfltConfig;function u(t,e){t=n.extendDeep({},t);var r,a,o=Object.keys(t).sort();function s(e,r,n){if(i(r)&&i(e))u(e,r);else if(Array.isArray(r)&&Array.isArray(e)){var o=l.arrayTemplater({_template:t},n);for(a=0;a<r.length;a++){var s=r[a],c=o.newItem(s)._template;c&&u(c,s)}var h=o.defaultItems();for(a=0;a<h.length;a++)r.push(h[a]._template);for(a=0;a<r.length;a++)delete r[a].templateitemname}}for(r=0;r<o.length;r++){var c=o[r],f=t[c];if(c in e?s(f,e[c],c):e[c]=f,h(c)===c)for(var p in e){var d=h(p);p===d||d!==c||p in t||s(f,e[p],c)}}}function h(t){return t.replace(/[0-9]+$/,\"\")}function f(t,e,r,a,o){var s=o&&r(o);for(var c in t){var u=t[c],d=p(t,c,a),g=p(t,c,o),v=r(g);if(!v){var m=h(c);m!==c&&(v=r(g=p(t,m,o)))}if((!s||s!==v)&&!(!v||v._noTemplating||\"data_array\"===v.valType||v.arrayOk&&Array.isArray(u)))if(!v.valType&&i(u))f(u,e,r,d,g);else if(v._isLinkedToArray&&Array.isArray(u))for(var y=!1,x=0,b={},_=0;_<u.length;_++){var w=u[_];if(i(w)){var k=w.name;if(k)b[k]||(f(w,e,r,p(u,x,d),p(u,x,g)),x++,b[k]=1);else if(!y){var T=p(t,l.arrayDefaultKey(c),a),A=p(u,x,d);f(w,e,r,A,p(u,x,g));var M=n.nestedProperty(e,A);n.nestedProperty(e,T).set(M.get()),M.set(null),y=!0}}}else{n.nestedProperty(e,d).set(u)}}}function p(t,e,r){return r?Array.isArray(t)?r+\"[\"+e+\"]\":r+\".\"+e:e}function d(t){for(var e=0;e<t.length;e++)if(i(t[e]))return!0}function g(t){var e;switch(t.code){case\"data\":e=\"The template has no key data.\";break;case\"layout\":e=\"The template has no key layout.\";break;case\"missing\":e=t.path?\"There are no templates for item \"+t.path+\" with name \"+t.templateitemname:\"There are no templates for trace \"+t.index+\", of type \"+t.traceType+\".\";break;case\"unused\":e=t.path?\"The template item at \"+t.path+\" was not used in constructing the plot.\":t.dataCount?\"Some of the templates of type \"+t.traceType+\" were not used. The template has \"+t.templateCount+\" traces, the data only has \"+t.dataCount+\" of this type.\":\"The template has \"+t.templateCount+\" traces of type \"+t.traceType+\" but there are none in the data.\";break;case\"reused\":e=\"Some of the templates of type \"+t.traceType+\" were used more than once. The template has \"+t.templateCount+\" traces, the data has \"+t.dataCount+\" of this type.\"}return t.msg=e,t}r.makeTemplate=function(t){t=n.isPlainObject(t)?t:n.getGraphDiv(t),t=n.extendDeep({_context:c},{data:t.data,layout:t.layout}),o.supplyDefaults(t);var e=t.data||[],r=t.layout||{};r._basePlotModules=t._fullLayout._basePlotModules,r._modules=t._fullLayout._modules;var l={data:{},layout:{}};e.forEach(function(t){var e={};f(t,e,function(t,e){return a.getTraceValObject(t,n.nestedProperty({},e).parts)}.bind(null,t));var r=n.coerce(t,{},s,\"type\"),i=l.data[r];i||(i=l.data[r]=[]),i.push(e)}),f(r,l.layout,function(t,e){return a.getLayoutValObject(t,n.nestedProperty({},e).parts)}.bind(null,r)),delete l.layout.template;var h=r.template;if(i(h)){var p,d,g,v,m,y,x=h.layout;i(x)&&u(x,l.layout);var b=h.data;if(i(b)){for(d in l.data)if(g=b[d],Array.isArray(g)){for(y=(m=l.data[d]).length,v=g.length,p=0;p<y;p++)u(g[p%v],m[p]);for(p=y;p<v;p++)m.push(n.extendDeep({},g[p]))}for(d in b)d in l.data||(l.data[d]=n.extendDeep([],b[d]))}}return l},r.validateTemplate=function(t,e){var r=n.extendDeep({},{_context:c,data:t.data,layout:t.layout}),a=r.layout||{};i(e)||(e=a.template||{});var s=e.layout,l=e.data,u=[];r.layout=a,r.layout.template=e,o.supplyDefaults(r);var f=r._fullLayout,v=r._fullData,m={};if(i(s)?(!function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)&&i(e[n])){var a,o=h(n),s=[];for(a=0;a<r.length;a++)s.push(p(e,n,r[a])),o!==n&&s.push(p(e,o,r[a]));for(a=0;a<s.length;a++)m[s[a]]=1;t(e[n],s)}}(f,[\"layout\"]),function t(e,r){for(var n in e)if(-1===n.indexOf(\"defaults\")&&i(e[n])){var a=p(e,n,r);m[a]?t(e[n],a):u.push({code:\"unused\",path:a})}}(s,\"layout\")):u.push({code:\"layout\"}),i(l)){for(var y,x={},b=0;b<v.length;b++){var _=v[b];x[y=_.type]=(x[y]||0)+1,_._fullInput._template||u.push({code:\"missing\",index:_._fullInput.index,traceType:y})}for(y in l){var w=l[y].length,k=x[y]||0;w>k?u.push({code:\"unused\",traceType:y,templateCount:w,dataCount:k}):k>w&&u.push({code:\"reused\",traceType:y,templateCount:w,dataCount:k})}}else u.push({code:\"data\"});if(function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)){var a=e[n],o=p(e,n,r);i(a)?(Array.isArray(e)&&!1===a._template&&a.templateitemname&&u.push({code:\"missing\",path:o,templateitemname:a.templateitemname}),t(a,o)):Array.isArray(a)&&d(a)&&t(a,o)}}({data:v,layout:f},\"\"),u.length)return u.map(g)}},{\"../lib\":719,\"../plots/attributes\":764,\"../plots/plots\":828,\"./plot_config\":755,\"./plot_schema\":756,\"./plot_template\":757}],760:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./plot_api\"),a=t(\"../lib\"),o=t(\"../snapshot/helpers\"),s=t(\"../snapshot/tosvg\"),l=t(\"../snapshot/svgtoimg\"),c={format:{valType:\"enumerated\",values:[\"png\",\"jpeg\",\"webp\",\"svg\"],dflt:\"png\"},width:{valType:\"number\",min:1},height:{valType:\"number\",min:1},scale:{valType:\"number\",min:0,dflt:1},setBackground:{valType:\"any\",dflt:!1},imageDataOnly:{valType:\"boolean\",dflt:!1}};e.exports=function(t,e){var r,u,h,f;function p(t){return!(t in e)||a.validate(e[t],c[t])}if(e=e||{},a.isPlainObject(t)?(r=t.data||[],u=t.layout||{},h=t.config||{},f={}):(t=a.getGraphDiv(t),r=a.extendDeep([],t.data),u=a.extendDeep({},t.layout),h=t._context,f=t._fullLayout||{}),!p(\"width\")&&null!==e.width||!p(\"height\")&&null!==e.height)throw new Error(\"Height and width should be pixel values.\");if(!p(\"format\"))throw new Error(\"Image format is not jpeg, png, svg or webp.\");var d={};function g(t,r){return a.coerce(e,d,c,t,r)}var v=g(\"format\"),m=g(\"width\"),y=g(\"height\"),x=g(\"scale\"),b=g(\"setBackground\"),_=g(\"imageDataOnly\"),w=document.createElement(\"div\");w.style.position=\"absolute\",w.style.left=\"-5000px\",document.body.appendChild(w);var k=a.extendFlat({},u);m?k.width=m:null===e.width&&n(f.width)&&(k.width=f.width),y?k.height=y:null===e.height&&n(f.height)&&(k.height=f.height);var T=a.extendFlat({},h,{_exportedPlot:!0,staticPlot:!0,setBackground:b}),A=o.getRedrawFunc(w);function M(){return new Promise(function(t){setTimeout(t,o.getDelay(w._fullLayout))})}function S(){return new Promise(function(t,e){var r=s(w,v,x),n=w._fullLayout.width,c=w._fullLayout.height;if(i.purge(w),document.body.removeChild(w),\"svg\"===v)return t(_?r:o.encodeSVG(r));var u=document.createElement(\"canvas\");u.id=a.randstr(),l({format:v,width:n,height:c,scale:x,canvas:u,svg:r,promise:!0}).then(t).catch(e)})}return new Promise(function(t,e){i.plot(w,r,k,T).then(A).then(M).then(S).then(function(e){t(function(t){return _?t.replace(o.IMAGE_URL_PREFIX,\"\"):t}(e))}).catch(function(t){e(t)})})}},{\"../lib\":719,\"../snapshot/helpers\":851,\"../snapshot/svgtoimg\":853,\"../snapshot/tosvg\":855,\"./plot_api\":754,\"fast-isnumeric\":225}],761:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/plots\"),a=t(\"./plot_schema\"),o=t(\"./plot_config\").dfltConfig,s=n.isPlainObject,l=Array.isArray,c=n.isArrayOrTypedArray;function u(t,e,r,i,a,o){o=o||[];for(var h=Object.keys(t),f=0;f<h.length;f++){var v=h[f];if(\"transforms\"!==v){var m=o.slice();m.push(v);var y=t[v],x=e[v],b=g(r,v),_=\"info_array\"===(b||{}).valType,w=\"colorscale\"===(b||{}).valType,k=(b||{}).items;if(d(r,v))if(s(y)&&s(x))u(y,x,b,i,a,m);else if(_&&l(y)){y.length>x.length&&i.push(p(\"unused\",a,m.concat(x.length)));var T,A,M,S,E,C=x.length,L=Array.isArray(k);if(L&&(C=Math.min(C,k.length)),2===b.dimensions)for(A=0;A<C;A++)if(l(y[A])){y[A].length>x[A].length&&i.push(p(\"unused\",a,m.concat(A,x[A].length)));var P=x[A].length;for(T=0;T<(L?Math.min(P,k[A].length):P);T++)M=L?k[A][T]:k,S=y[A][T],E=x[A][T],n.validate(S,M)?E!==S&&E!==+S&&i.push(p(\"dynamic\",a,m.concat(A,T),S,E)):i.push(p(\"value\",a,m.concat(A,T),S))}else i.push(p(\"array\",a,m.concat(A),y[A]));else for(A=0;A<C;A++)M=L?k[A]:k,S=y[A],E=x[A],n.validate(S,M)?E!==S&&E!==+S&&i.push(p(\"dynamic\",a,m.concat(A),S,E)):i.push(p(\"value\",a,m.concat(A),S))}else if(b.items&&!_&&l(y)){var O,z,I=k[Object.keys(k)[0]],D=[];for(O=0;O<x.length;O++){var R=x[O]._index||O;if((z=m.slice()).push(R),s(y[R])&&s(x[O])){D.push(R);var F=y[R],B=x[O];s(F)&&!1!==F.visible&&!1===B.visible?i.push(p(\"invisible\",a,z)):u(F,B,I,i,a,z)}}for(O=0;O<y.length;O++)(z=m.slice()).push(O),s(y[O])?-1===D.indexOf(O)&&i.push(p(\"unused\",a,z)):i.push(p(\"object\",a,z,y[O]))}else!s(y)&&s(x)?i.push(p(\"object\",a,m,y)):c(y)||!c(x)||_||w?v in e?n.validate(y,b)?\"enumerated\"===b.valType&&(b.coerceNumber&&y!==+x||y!==x)&&i.push(p(\"dynamic\",a,m,y,x)):i.push(p(\"value\",a,m,y)):i.push(p(\"unused\",a,m,y)):i.push(p(\"array\",a,m,y));else i.push(p(\"schema\",a,m))}}return i}e.exports=function(t,e){var r,c,h=a.get(),f=[],d={_context:n.extendFlat({},o)};l(t)?(d.data=n.extendDeep([],t),r=t):(d.data=[],r=[],f.push(p(\"array\",\"data\"))),s(e)?(d.layout=n.extendDeep({},e),c=e):(d.layout={},c={},arguments.length>1&&f.push(p(\"object\",\"layout\"))),i.supplyDefaults(d);for(var g=d._fullData,v=r.length,m=0;m<v;m++){var y=r[m],x=[\"data\",m];if(s(y)){var b=g[m],_=b.type,w=h.traces[_].attributes;w.type={valType:\"enumerated\",values:[_]},!1===b.visible&&!1!==y.visible&&f.push(p(\"invisible\",x)),u(y,b,w,f,x);var k=y.transforms,T=b.transforms;if(k){l(k)||f.push(p(\"array\",x,[\"transforms\"])),x.push(\"transforms\");for(var A=0;A<k.length;A++){var M=[\"transforms\",A],S=k[A].type;if(s(k[A])){var E=h.transforms[S]?h.transforms[S].attributes:{};E.type={valType:\"enumerated\",values:Object.keys(h.transforms)},u(k[A],T[A],E,f,x,M)}else f.push(p(\"object\",x,M))}}}else f.push(p(\"object\",x))}return u(c,d._fullLayout,function(t,e){for(var r=t.layout.layoutAttributes,i=0;i<e.length;i++){var a=e[i],o=t.traces[a.type],s=o.layoutAttributes;s&&(a.subplot?n.extendFlat(r[o.attributes.subplot.dflt],s):n.extendFlat(r,s))}return r}(h,g),f,\"layout\"),0===f.length?void 0:f};var h={object:function(t,e){return(\"layout\"===t&&\"\"===e?\"The layout argument\":\"data\"===t[0]&&\"\"===e?\"Trace \"+t[1]+\" in the data argument\":f(t)+\"key \"+e)+\" must be linked to an object container\"},array:function(t,e){return(\"data\"===t?\"The data argument\":f(t)+\"key \"+e)+\" must be linked to an array container\"},schema:function(t,e){return f(t)+\"key \"+e+\" is not part of the schema\"},unused:function(t,e,r){var n=s(r)?\"container\":\"key\";return f(t)+n+\" \"+e+\" did not get coerced\"},dynamic:function(t,e,r,n){return[f(t)+\"key\",e,\"(set to '\"+r+\"')\",\"got reset to\",\"'\"+n+\"'\",\"during defaults.\"].join(\" \")},invisible:function(t,e){return(e?f(t)+\"item \"+e:\"Trace \"+t[1])+\" got defaulted to be not visible\"},value:function(t,e,r){return[f(t)+\"key \"+e,\"is set to an invalid value (\"+r+\")\"].join(\" \")}};function f(t){return l(t)?\"In data trace \"+t[1]+\", \":\"In \"+t+\", \"}function p(t,e,r,i,a){var o,s;r=r||\"\",l(e)?(o=e[0],s=e[1]):(o=e,s=null);var c=function(t){if(!l(t))return String(t);for(var e=\"\",r=0;r<t.length;r++){var n=t[r];\"number\"==typeof n?e=e.substr(0,e.length-1)+\"[\"+n+\"]\":e+=n,r<t.length-1&&(e+=\".\")}return e}(r),u=h[t](e,c,i,a);return n.log(u),{code:t,container:o,trace:s,path:r,astr:c,msg:u}}function d(t,e){var r=m(e),n=r.keyMinusId,i=r.id;return!!(n in t&&t[n]._isSubplotObj&&i)||e in t}function g(t,e){return e in t?t[e]:t[m(e).keyMinusId]}var v=n.counterRegex(\"([a-z]+)\");function m(t){var e=t.match(v);return{keyMinusId:e&&e[1],id:e&&e[2]}}},{\"../lib\":719,\"../plots/plots\":828,\"./plot_config\":755,\"./plot_schema\":756}],762:[function(t,e,r){\"use strict\";e.exports={mode:{valType:\"enumerated\",dflt:\"afterall\",values:[\"immediate\",\"next\",\"afterall\"]},direction:{valType:\"enumerated\",values:[\"forward\",\"reverse\"],dflt:\"forward\"},fromcurrent:{valType:\"boolean\",dflt:!1},frame:{duration:{valType:\"number\",min:0,dflt:500},redraw:{valType:\"boolean\",dflt:!0}},transition:{duration:{valType:\"number\",min:0,dflt:500,editType:\"none\"},easing:{valType:\"enumerated\",dflt:\"cubic-in-out\",values:[\"linear\",\"quad\",\"cubic\",\"sin\",\"exp\",\"circle\",\"elastic\",\"back\",\"bounce\",\"linear-in\",\"quad-in\",\"cubic-in\",\"sin-in\",\"exp-in\",\"circle-in\",\"elastic-in\",\"back-in\",\"bounce-in\",\"linear-out\",\"quad-out\",\"cubic-out\",\"sin-out\",\"exp-out\",\"circle-out\",\"elastic-out\",\"back-out\",\"bounce-out\",\"linear-in-out\",\"quad-in-out\",\"cubic-in-out\",\"sin-in-out\",\"exp-in-out\",\"circle-in-out\",\"elastic-in-out\",\"back-in-out\",\"bounce-in-out\"],editType:\"none\"},ordering:{valType:\"enumerated\",values:[\"layout first\",\"traces first\"],dflt:\"layout first\",editType:\"none\"}}}},{}],763:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\");e.exports=function(t,e,r){var a,o,s=r.name,l=r.inclusionAttr||\"visible\",c=e[s],u=n.isArrayOrTypedArray(t[s])?t[s]:[],h=e[s]=[],f=i.arrayTemplater(e,s,l);for(a=0;a<u.length;a++){var p=u[a];n.isPlainObject(p)?o=f.newItem(p):(o=f.newItem({}))[l]=!1,o._index=a,!1!==o[l]&&r.handleItemDefaults(p,o,e,r),h.push(o)}var d=f.defaultItems();for(a=0;a<d.length;a++)(o=d[a])._index=h.length,r.handleItemDefaults({},o,e,r,{}),h.push(o);if(n.isArrayOrTypedArray(c)){var g=Math.min(c.length,h.length);for(a=0;a<g;a++)n.relinkPrivateKeys(h[a],c[a])}return h}},{\"../lib\":719,\"../plot_api/plot_template\":757}],764:[function(t,e,r){\"use strict\";var n=t(\"../components/fx/attributes\");e.exports={type:{valType:\"enumerated\",values:[],dflt:\"scatter\",editType:\"calc+clearAxisTypes\",_noTemplating:!0},visible:{valType:\"enumerated\",values:[!0,!1,\"legendonly\"],dflt:!0,editType:\"calc\"},showlegend:{valType:\"boolean\",dflt:!0,editType:\"style\"},legendgroup:{valType:\"string\",dflt:\"\",editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"style\"},name:{valType:\"string\",editType:\"style\"},uid:{valType:\"string\",editType:\"plot\",anim:!0},ids:{valType:\"data_array\",editType:\"calc\",anim:!0},customdata:{valType:\"data_array\",editType:\"calc\"},meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},selectedpoints:{valType:\"any\",editType:\"calc\"},hoverinfo:{valType:\"flaglist\",flags:[\"x\",\"y\",\"z\",\"text\",\"name\"],extras:[\"all\",\"none\",\"skip\"],arrayOk:!0,dflt:\"all\",editType:\"none\"},hoverlabel:n.hoverlabel,stream:{token:{valType:\"string\",noBlank:!0,strict:!0,editType:\"calc\"},maxpoints:{valType:\"number\",min:0,max:1e4,dflt:500,editType:\"calc\"},editType:\"calc\"},transforms:{_isLinkedToArray:\"transform\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"}}},{\"../components/fx/attributes\":623}],765:[function(t,e,r){\"use strict\";e.exports={xaxis:{valType:\"subplotid\",dflt:\"x\",editType:\"calc+clearAxisTypes\"},yaxis:{valType:\"subplotid\",dflt:\"y\",editType:\"calc+clearAxisTypes\"}}},{}],766:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").FP_SAFE,o=t(\"../../registry\");function s(t,e){var r,n,a=[],o=l(e),s=c(t,e),u=s.min,h=s.max;if(0===u.length||0===h.length)return i.simpleMap(e.range,e.r2l);var f=u[0].val,p=h[0].val;for(r=1;r<u.length&&f===p;r++)f=Math.min(f,u[r].val);for(r=1;r<h.length&&f===p;r++)p=Math.max(p,h[r].val);var d=!1;if(e.range){var g=i.simpleMap(e.range,e.r2l);d=g[1]<g[0]}\"reversed\"===e.autorange&&(d=!0,e.autorange=!0);var v,m,y,x,b,_,w=e.rangemode,k=\"tozero\"===w,T=\"nonnegative\"===w,A=e._length,M=A/10,S=0;for(r=0;r<u.length;r++)for(v=u[r],n=0;n<h.length;n++)(_=(m=h[n]).val-v.val)>0&&((b=A-o(v)-o(m))>M?_/b>S&&(y=v,x=m,S=_/b):_/A>S&&(y={val:v.val,pad:0},x={val:m.val,pad:0},S=_/A));if(f===p){var E=f-1,C=f+1;if(k)if(0===f)a=[0,1];else{var L=(f>0?h:u).reduce(function(t,e){return Math.max(t,o(e))},0),P=f/(1-Math.min(.5,L/A));a=f>0?[0,P]:[P,0]}else a=T?[Math.max(0,E),Math.max(1,C)]:[E,C]}else k?(y.val>=0&&(y={val:0,pad:0}),x.val<=0&&(x={val:0,pad:0})):T&&(y.val-S*o(y)<0&&(y={val:0,pad:0}),x.val<=0&&(x={val:1,pad:0})),S=(x.val-y.val)/(A-o(y)-o(x)),a=[y.val-S*o(y),x.val+S*o(x)];return d&&a.reverse(),i.simpleMap(a,e.l2r||Number)}function l(t){var e=t._length/20;return\"domain\"===t.constrain&&t._inputDomain&&(e*=(t._inputDomain[1]-t._inputDomain[0])/(t.domain[1]-t.domain[0])),function(t){return t.pad+(t.extrapad?e:0)}}function c(t,e){var r,n,i,a=e._id,o=t._fullData,s=t._fullLayout,l=[],c=[];function f(t,e){for(r=0;r<e.length;r++){var o=t[e[r]],s=(o._extremes||{})[a];if(!0===o.visible&&s){for(n=0;n<s.min.length;n++)i=s.min[n],u(l,i.val,i.pad,{extrapad:i.extrapad});for(n=0;n<s.max.length;n++)i=s.max[n],h(c,i.val,i.pad,{extrapad:i.extrapad})}}}return f(o,e._traceIndices),f(s.annotations||[],e._annIndices||[]),f(s.shapes||[],e._shapeIndices||[]),{min:l,max:c}}function u(t,e,r,n){f(t,e,r,n,d)}function h(t,e,r,n){f(t,e,r,n,g)}function f(t,e,r,n,i){for(var a=n.tozero,o=n.extrapad,s=!0,l=0;l<t.length&&s;l++){var c=t[l];if(i(c.val,e)&&c.pad>=r&&(c.extrapad||!o)){s=!1;break}i(e,c.val)&&c.pad<=r&&(o||!c.extrapad)&&(t.splice(l,1),l--)}if(s){var u=a&&0===e;t.push({val:e,pad:u?0:r,extrapad:!u&&o})}}function p(t){return n(t)&&Math.abs(t)<a}function d(t,e){return t<=e}function g(t,e){return t>=e}e.exports={getAutoRange:s,makePadFn:l,doAutoRange:function(t,e){if(e.setScale(),e.autorange){e.range=s(t,e),e._r=e.range.slice(),e._rl=i.simpleMap(e._r,e.r2l);var r=e._input,n={};n[e._attr+\".range\"]=e.range,n[e._attr+\".autorange\"]=e.autorange,o.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,n),r.range=e.range.slice(),r.autorange=e.autorange}var a=e._anchorAxis;if(a&&a.rangeslider){var l=a.rangeslider[e._name];l&&\"auto\"===l.rangemode&&(l.range=s(t,e)),a._input.rangeslider[e._name]=i.extendFlat({},l)}},findExtremes:function(t,e,r){r||(r={});t._m||t.setScale();var i,o,s,l,c,f,d,g,v,m=[],y=[],x=e.length,b=r.padded||!1,_=r.tozero&&(\"linear\"===t.type||\"-\"===t.type),w=\"log\"===t.type,k=!1;function T(t){if(Array.isArray(t))return k=!0,function(e){return Math.max(Number(t[e]||0),0)};var e=Math.max(Number(t||0),0);return function(){return e}}var A=T((t._m>0?r.ppadplus:r.ppadminus)||r.ppad||0),M=T((t._m>0?r.ppadminus:r.ppadplus)||r.ppad||0),S=T(r.vpadplus||r.vpad),E=T(r.vpadminus||r.vpad);if(!k){if(g=1/0,v=-1/0,w)for(i=0;i<x;i++)(o=e[i])<g&&o>0&&(g=o),o>v&&o<a&&(v=o);else for(i=0;i<x;i++)(o=e[i])<g&&o>-a&&(g=o),o>v&&o<a&&(v=o);e=[g,v],x=2}var C={tozero:_,extrapad:b};function L(r){s=e[r],n(s)&&(f=A(r),d=M(r),g=s-E(r),v=s+S(r),w&&g<v/10&&(g=v/10),l=t.c2l(g),c=t.c2l(v),_&&(l=Math.min(0,l),c=Math.max(0,c)),p(l)&&u(m,l,d,C),p(c)&&h(y,c,f,C))}var P=Math.min(6,x);for(i=0;i<P;i++)L(i);for(i=x-1;i>=P;i--)L(i);return{min:m,max:y,opts:r}},concatExtremes:c}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../registry\":847,\"fast-isnumeric\":225}],767:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../components/titles\"),u=t(\"../../components/color\"),h=t(\"../../components/drawing\"),f=t(\"./layout_attributes\"),p=t(\"./clean_ticks\"),d=t(\"../../constants/numerical\"),g=d.ONEAVGYEAR,v=d.ONEAVGMONTH,m=d.ONEDAY,y=d.ONEHOUR,x=d.ONEMIN,b=d.ONESEC,_=d.MINUS_SIGN,w=d.BADNUM,k=t(\"../../constants/alignment\").MID_SHIFT,T=t(\"../../constants/alignment\").LINE_SPACING,A=e.exports={};A.setConvert=t(\"./set_convert\");var M=t(\"./axis_autotype\"),S=t(\"./axis_ids\");A.id2name=S.id2name,A.name2id=S.name2id,A.cleanId=S.cleanId,A.list=S.list,A.listIds=S.listIds,A.getFromId=S.getFromId,A.getFromTrace=S.getFromTrace;var E=t(\"./autorange\");A.getAutoRange=E.getAutoRange,A.findExtremes=E.findExtremes,A.coerceRef=function(t,e,r,n,i,a){var o=n.charAt(n.length-1),l=r._fullLayout._subplots[o+\"axis\"],c=n+\"ref\",u={};return i||(i=l[0]||a),a||(a=i),u[c]={valType:\"enumerated\",values:l.concat(a?[a]:[]),dflt:i},s.coerce(t,e,u,c)},A.coercePosition=function(t,e,r,n,i,a){var o,l;if(\"paper\"===n||\"pixel\"===n)o=s.ensureNumber,l=r(i,a);else{var c=A.getFromId(e,n);l=r(i,a=c.fraction2r(a)),o=c.cleanPos}t[i]=o(l)},A.cleanPosition=function(t,e,r){return(\"paper\"===r||\"pixel\"===r?s.ensureNumber:A.getFromId(e,r).cleanPos)(t)},A.redrawComponents=function(t,e){e=e||A.listIds(t);var r=t._fullLayout;function n(n,i,a,s){for(var l=o.getComponentMethod(n,i),c={},u=0;u<e.length;u++)for(var h=r[A.id2name(e[u])][a],f=0;f<h.length;f++){var p=h[f];if(!c[p]&&(l(t,p),c[p]=1,s))return}}n(\"annotations\",\"drawOne\",\"_annIndices\"),n(\"shapes\",\"drawOne\",\"_shapeIndices\"),n(\"images\",\"draw\",\"_imgIndices\",!0)};var C=A.getDataConversions=function(t,e,r,n){var i,a=\"x\"===r||\"y\"===r||\"z\"===r?r:n;if(Array.isArray(a)){if(i={type:M(n),_categories:[]},A.setConvert(i),\"category\"===i.type)for(var o=0;o<n.length;o++)i.d2c(n[o])}else i=A.getFromTrace(t,e,a);return i?{d2c:i.d2c,c2d:i.c2d}:\"ids\"===a?{d2c:P,c2d:P}:{d2c:L,c2d:L}};function L(t){return+t}function P(t){return String(t)}A.getDataToCoordFunc=function(t,e,r,n){return C(t,e,r,n).d2c},A.counterLetter=function(t){var e=t.charAt(0);return\"x\"===e?\"y\":\"y\"===e?\"x\":void 0},A.minDtick=function(t,e,r,n){-1===[\"log\",\"category\",\"multicategory\"].indexOf(t.type)&&n?void 0===t._minDtick?(t._minDtick=e,t._forceTick0=r):t._minDtick&&((t._minDtick/e+1e-6)%1<2e-6&&((r-t._forceTick0)/e%1+1.000001)%1<2e-6?(t._minDtick=e,t._forceTick0=r):((e/t._minDtick+1e-6)%1>2e-6||((r-t._forceTick0)/t._minDtick%1+1.000001)%1>2e-6)&&(t._minDtick=0)):t._minDtick=0},A.saveRangeInitial=function(t,e){for(var r=A.list(t,\"\",!0),n=!1,i=0;i<r.length;i++){var a=r[i],o=void 0===a._rangeInitial,s=o||!(a.range[0]===a._rangeInitial[0]&&a.range[1]===a._rangeInitial[1]);(o&&!1===a.autorange||e&&s)&&(a._rangeInitial=a.range.slice(),n=!0)}return n},A.saveShowSpikeInitial=function(t,e){for(var r=A.list(t,\"\",!0),n=!1,i=\"on\",a=0;a<r.length;a++){var o=r[a],s=void 0===o._showSpikeInitial,l=s||!(o.showspikes===o._showspikes);(s||e&&l)&&(o._showSpikeInitial=o.showspikes,n=!0),\"on\"!==i||o.showspikes||(i=\"off\")}return t._fullLayout._cartesianSpikesEnabled=i,n},A.autoBin=function(t,e,r,n,a,o){var l,c=s.aggNums(Math.min,null,t),u=s.aggNums(Math.max,null,t);if(\"category\"===e.type||\"multicategory\"===e.type)return{start:c-.5,end:u+.5,size:Math.max(1,Math.round(o)||1),_dataSpan:u-c};if(a||(a=e.calendar),l=\"log\"===e.type?{type:\"linear\",range:[c,u]}:{type:e.type,range:s.simpleMap([c,u],e.c2r,0,a),calendar:a},A.setConvert(l),o=o&&p.dtick(o,l.type))l.dtick=o,l.tick0=p.tick0(void 0,l.type,a);else{var h;if(r)h=(u-c)/r;else{var f=s.distinctVals(t),d=Math.pow(10,Math.floor(Math.log(f.minDiff)/Math.LN10)),g=d*s.roundUp(f.minDiff/d,[.9,1.9,4.9,9.9],!0);h=Math.max(g,2*s.stdev(t)/Math.pow(t.length,n?.25:.4)),i(h)||(h=1)}A.autoTicks(l,h)}var v,y=l.dtick,x=A.tickIncrement(A.tickFirst(l),y,\"reverse\",a);if(\"number\"==typeof y)v=(x=function(t,e,r,n,a){var o=0,s=0,l=0,c=0;function u(e){return(1+100*(e-t)/r.dtick)%100<2}for(var h=0;h<e.length;h++)e[h]%1==0?l++:i(e[h])||c++,u(e[h])&&o++,u(e[h]+r.dtick/2)&&s++;var f=e.length-c;if(l===f&&\"date\"!==r.type)r.dtick<1?t=n-.5*r.dtick:(t-=.5)+r.dtick<n&&(t+=r.dtick);else if(s<.1*f&&(o>.3*f||u(n)||u(a))){var p=r.dtick/2;t+=t+p<n?p:-p}return t}(x,t,l,c,u))+(1+Math.floor((u-x)/y))*y;else for(\"M\"===l.dtick.charAt(0)&&(x=function(t,e,r,n,i){var a=s.findExactDates(e,i);if(a.exactDays>.8){var o=Number(r.substr(1));a.exactYears>.8&&o%12==0?t=A.tickIncrement(t,\"M6\",\"reverse\")+1.5*m:a.exactMonths>.8?t=A.tickIncrement(t,\"M1\",\"reverse\")+15.5*m:t-=m/2;var l=A.tickIncrement(t,r);if(l<=n)return l}return t}(x,t,y,c,a)),v=x,0;v<=u;)v=A.tickIncrement(v,y,!1,a),0;return{start:e.c2r(x,0,a),end:e.c2r(v,0,a),size:y,_dataSpan:u-c}},A.prepTicks=function(t){var e=s.simpleMap(t.range,t.r2l);if(\"auto\"===t.tickmode||!t.dtick){var r,n=t.nticks;n||(\"category\"===t.type||\"multicategory\"===t.type?(r=t.tickfont?1.2*(t.tickfont.size||12):15,n=t._length/r):(r=\"y\"===t._id.charAt(0)?40:80,n=s.constrain(t._length/r,4,9)+1),\"radialaxis\"===t._name&&(n*=2)),\"array\"===t.tickmode&&(n*=100),A.autoTicks(t,Math.abs(e[1]-e[0])/n),t._minDtick>0&&t.dtick<2*t._minDtick&&(t.dtick=t._minDtick,t.tick0=t.l2r(t._forceTick0))}t.tick0||(t.tick0=\"date\"===t.type?\"2000-01-01\":0),\"date\"===t.type&&t.dtick<.1&&(t.dtick=.1),j(t)},A.calcTicks=function(t){A.prepTicks(t);var e=s.simpleMap(t.range,t.r2l);if(\"array\"===t.tickmode)return function(t){var e=t.tickvals,r=t.ticktext,n=new Array(e.length),i=s.simpleMap(t.range,t.r2l),a=1.0001*i[0]-1e-4*i[1],o=1.0001*i[1]-1e-4*i[0],l=Math.min(a,o),c=Math.max(a,o),u=0;Array.isArray(r)||(r=[]);var h=\"category\"===t.type?t.d2l_noadd:t.d2l;\"log\"===t.type&&\"L\"!==String(t.dtick).charAt(0)&&(t.dtick=\"L\"+Math.pow(10,Math.floor(Math.min(t.range[0],t.range[1]))-1));for(var f=0;f<e.length;f++){var p=h(e[f]);p>l&&p<c&&(void 0===r[f]?n[u]=A.tickText(t,p):n[u]=U(t,p,String(r[f])),u++)}u<e.length&&n.splice(u,e.length-u);return n}(t);t._tmin=A.tickFirst(t);var r=1.0001*e[0]-1e-4*e[1],n=1.0001*e[1]-1e-4*e[0],a=e[1]<e[0];if(t._tmin<r!==a)return[];var o=[];\"category\"!==t.type&&\"multicategory\"!==t.type||(n=a?Math.max(-.5,n):Math.min(t._categories.length-.5,n));for(var l=\"log\"===t.type&&!(i(t.dtick)||\"L\"===t.dtick.charAt(0)),c=null,u=Math.max(1e3,t._length||0),h=t._tmin;(a?h>=n:h<=n)&&!(o.length>u||h===c);h=A.tickIncrement(h,t.dtick,a,t.calendar)){c=h;var f=!1;l&&h!==(0|h)&&(f=!0),o.push({minor:f,value:h})}rt(t)&&360===Math.abs(e[1]-e[0])&&o.pop(),t._tmax=(o[o.length-1]||{}).value,t._prevDateHead=\"\",t._inCalcTicks=!0;for(var p=new Array(o.length),d=0;d<o.length;d++)p[d]=A.tickText(t,o[d].value,!1,o[d].minor);return t._inCalcTicks=!1,p};var O=[2,5,10],z=[1,2,3,6,12],I=[1,2,5,10,15,30],D=[1,2,3,7,14],R=[-.046,0,.301,.477,.602,.699,.778,.845,.903,.954,1],F=[-.301,0,.301,.699,1],B=[15,30,45,90,180];function N(t,e,r){return e*s.roundUp(t/e,r)}function j(t){var e=t.dtick;if(t._tickexponent=0,i(e)||\"string\"==typeof e||(e=1),\"category\"!==t.type&&\"multicategory\"!==t.type||(t._tickround=null),\"date\"===t.type){var r=t.r2l(t.tick0),n=t.l2r(r).replace(/(^-|i)/g,\"\"),a=n.length;if(\"M\"===String(e).charAt(0))a>10||\"01-01\"!==n.substr(5)?t._tickround=\"d\":t._tickround=+e.substr(1)%12==0?\"y\":\"m\";else if(e>=m&&a<=10||e>=15*m)t._tickround=\"d\";else if(e>=x&&a<=16||e>=y)t._tickround=\"M\";else if(e>=b&&a<=19||e>=x)t._tickround=\"S\";else{var o=t.l2r(r+e).replace(/^-/,\"\").length;t._tickround=Math.max(a,o)-20,t._tickround<0&&(t._tickround=4)}}else if(i(e)||\"L\"===e.charAt(0)){var s=t.range.map(t.r2d||Number);i(e)||(e=Number(e.substr(1))),t._tickround=2-Math.floor(Math.log(e)/Math.LN10+.01);var l=Math.max(Math.abs(s[0]),Math.abs(s[1])),c=Math.floor(Math.log(l)/Math.LN10+.01);Math.abs(c)>3&&(q(t.exponentformat)&&!H(c)?t._tickexponent=3*Math.round((c-1)/3):t._tickexponent=c)}else t._tickround=null}function U(t,e,r){var n=t.tickfont||{};return{x:e,dx:0,dy:0,text:r||\"\",fontSize:n.size,font:n.family,fontColor:n.color}}A.autoTicks=function(t,e){var r;function n(t){return Math.pow(t,Math.floor(Math.log(e)/Math.LN10))}if(\"date\"===t.type){t.tick0=s.dateTick0(t.calendar);var a=2*e;a>g?(e/=g,r=n(10),t.dtick=\"M\"+12*N(e,r,O)):a>v?(e/=v,t.dtick=\"M\"+N(e,1,z)):a>m?(t.dtick=N(e,m,D),t.tick0=s.dateTick0(t.calendar,!0)):a>y?t.dtick=N(e,y,z):a>x?t.dtick=N(e,x,I):a>b?t.dtick=N(e,b,I):(r=n(10),t.dtick=N(e,r,O))}else if(\"log\"===t.type){t.tick0=0;var o=s.simpleMap(t.range,t.r2l);if(e>.7)t.dtick=Math.ceil(e);else if(Math.abs(o[1]-o[0])<1){var l=1.5*Math.abs((o[1]-o[0])/e);e=Math.abs(Math.pow(10,o[1])-Math.pow(10,o[0]))/l,r=n(10),t.dtick=\"L\"+N(e,r,O)}else t.dtick=e>.3?\"D2\":\"D1\"}else\"category\"===t.type||\"multicategory\"===t.type?(t.tick0=0,t.dtick=Math.ceil(Math.max(e,1))):rt(t)?(t.tick0=0,r=1,t.dtick=N(e,r,B)):(t.tick0=0,r=n(10),t.dtick=N(e,r,O));if(0===t.dtick&&(t.dtick=1),!i(t.dtick)&&\"string\"!=typeof t.dtick){var c=t.dtick;throw t.dtick=1,\"ax.dtick error: \"+String(c)}},A.tickIncrement=function(t,e,r,a){var o=r?-1:1;if(i(e))return t+o*e;var l=e.charAt(0),c=o*Number(e.substr(1));if(\"M\"===l)return s.incrementMonth(t,c,a);if(\"L\"===l)return Math.log(Math.pow(10,t)+c)/Math.LN10;if(\"D\"===l){var u=\"D2\"===e?F:R,h=t+.01*o,f=s.roundUp(s.mod(h,1),u,r);return Math.floor(h)+Math.log(n.round(Math.pow(10,f),1))/Math.LN10}throw\"unrecognized dtick \"+String(e)},A.tickFirst=function(t){var e=t.r2l||Number,r=s.simpleMap(t.range,e),a=r[1]<r[0],o=a?Math.floor:Math.ceil,l=1.0001*r[0]-1e-4*r[1],c=t.dtick,u=e(t.tick0);if(i(c)){var h=o((l-u)/c)*c+u;return\"category\"!==t.type&&\"multicategory\"!==t.type||(h=s.constrain(h,0,t._categories.length-1)),h}var f=c.charAt(0),p=Number(c.substr(1));if(\"M\"===f){for(var d,g,v,m=0,y=u;m<10;){if(((d=A.tickIncrement(y,c,a,t.calendar))-l)*(y-l)<=0)return a?Math.min(y,d):Math.max(y,d);g=(l-(y+d)/2)/(d-y),v=f+(Math.abs(Math.round(g))||1)*p,y=A.tickIncrement(y,v,g<0?!a:a,t.calendar),m++}return s.error(\"tickFirst did not converge\",t),y}if(\"L\"===f)return Math.log(o((Math.pow(10,l)-u)/p)*p+u)/Math.LN10;if(\"D\"===f){var x=\"D2\"===c?F:R,b=s.roundUp(s.mod(l,1),x,a);return Math.floor(l)+Math.log(n.round(Math.pow(10,b),1))/Math.LN10}throw\"unrecognized dtick \"+String(c)},A.tickText=function(t,e,r,n){var a,o=U(t,e),l=\"array\"===t.tickmode,c=r||l,u=t.type,h=\"category\"===u?t.d2l_noadd:t.d2l;if(l&&Array.isArray(t.ticktext)){var f=s.simpleMap(t.range,t.r2l),p=Math.abs(f[1]-f[0])/1e4;for(a=0;a<t.ticktext.length&&!(Math.abs(e-h(t.tickvals[a]))<p);a++);if(a<t.ticktext.length)return o.text=String(t.ticktext[a]),o}function d(n){if(void 0===n)return!0;if(r)return\"none\"===n;var i={first:t._tmin,last:t._tmax}[n];return\"all\"!==n&&e!==i}var g=r?\"never\":\"none\"!==t.exponentformat&&d(t.showexponent)?\"hide\":\"\";if(\"date\"===u?function(t,e,r,n){var a=t._tickround,o=r&&t.hoverformat||A.getTickFormat(t);n&&(a=i(a)?4:{y:\"m\",m:\"d\",d:\"M\",M:\"S\",S:4}[a]);var l,c=s.formatDate(e.x,o,a,t._dateFormat,t.calendar,t._extraFormat),u=c.indexOf(\"\\n\");-1!==u&&(l=c.substr(u+1),c=c.substr(0,u));n&&(\"00:00:00\"===c||\"00:00\"===c?(c=l,l=\"\"):8===c.length&&(c=c.replace(/:00$/,\"\")));l&&(r?\"d\"===a?c+=\", \"+l:c=l+(c?\", \"+c:\"\"):t._inCalcTicks&&l===t._prevDateHead||(c+=\"<br>\"+l,t._prevDateHead=l));e.text=c}(t,o,r,c):\"log\"===u?function(t,e,r,n,a){var o=t.dtick,l=e.x,c=t.tickformat,u=\"string\"==typeof o&&o.charAt(0);\"never\"===a&&(a=\"\");n&&\"L\"!==u&&(o=\"L3\",u=\"L\");if(c||\"L\"===u)e.text=G(Math.pow(10,l),t,a,n);else if(i(o)||\"D\"===u&&s.mod(l+.01,1)<.1){var h=Math.round(l),f=Math.abs(h),p=t.exponentformat;\"power\"===p||q(p)&&H(h)?(e.text=0===h?1:1===h?\"10\":\"10<sup>\"+(h>1?\"\":_)+f+\"</sup>\",e.fontSize*=1.25):(\"e\"===p||\"E\"===p)&&f>2?e.text=\"1\"+p+(h>0?\"+\":_)+f:(e.text=G(Math.pow(10,l),t,\"\",\"fakehover\"),\"D1\"===o&&\"y\"===t._id.charAt(0)&&(e.dy-=e.fontSize/6))}else{if(\"D\"!==u)throw\"unrecognized dtick \"+String(o);e.text=String(Math.round(Math.pow(10,s.mod(l,1)))),e.fontSize*=.75}if(\"D1\"===t.dtick){var d=String(e.text).charAt(0);\"0\"!==d&&\"1\"!==d||(\"y\"===t._id.charAt(0)?e.dx-=e.fontSize/4:(e.dy+=e.fontSize/2,e.dx+=(t.range[1]>t.range[0]?1:-1)*e.fontSize*(l<0?.5:.25)))}}(t,o,0,c,g):\"category\"===u?function(t,e){var r=t._categories[Math.round(e.x)];void 0===r&&(r=\"\");e.text=String(r)}(t,o):\"multicategory\"===u?function(t,e,r){var n=Math.round(e.x),i=t._categories[n]||[],a=void 0===i[1]?\"\":String(i[1]),o=void 0===i[0]?\"\":String(i[0]);r?e.text=o+\" - \"+a:(e.text=a,e.text2=o)}(t,o,r):rt(t)?function(t,e,r,n,i){if(\"radians\"!==t.thetaunit||r)e.text=G(e.x,t,i,n);else{var a=e.x/180;if(0===a)e.text=\"0\";else{var o=function(t){function e(t,e){return Math.abs(t-e)<=1e-6}var r=function(t){var r=1;for(;!e(Math.round(t*r)/r,t);)r*=10;return r}(t),n=t*r,i=Math.abs(function t(r,n){return e(n,0)?r:t(n,r%n)}(n,r));return[Math.round(n/i),Math.round(r/i)]}(a);if(o[1]>=100)e.text=G(s.deg2rad(e.x),t,i,n);else{var l=e.x<0;1===o[1]?1===o[0]?e.text=\"\\u03c0\":e.text=o[0]+\"\\u03c0\":e.text=[\"<sup>\",o[0],\"</sup>\",\"\\u2044\",\"<sub>\",o[1],\"</sub>\",\"\\u03c0\"].join(\"\"),l&&(e.text=_+e.text)}}}}(t,o,r,c,g):function(t,e,r,n,i){\"never\"===i?i=\"\":\"all\"===t.showexponent&&Math.abs(e.x/t.dtick)<1e-6&&(i=\"hide\");e.text=G(e.x,t,i,n)}(t,o,0,c,g),n||(t.tickprefix&&!d(t.showtickprefix)&&(o.text=t.tickprefix+o.text),t.ticksuffix&&!d(t.showticksuffix)&&(o.text+=t.ticksuffix)),\"boundaries\"===t.tickson||t.showdividers){var v=function(e){var r=t.l2p(e);return r>=0&&r<=t._length?e:null};o.xbnd=[v(o.x-.5),v(o.x+t.dtick-.5)]}return o},A.hoverLabelText=function(t,e,r){if(r!==w&&r!==e)return A.hoverLabelText(t,e)+\" - \"+A.hoverLabelText(t,r);var n=\"log\"===t.type&&e<=0,i=A.tickText(t,t.c2l(n?-e:e),\"hover\").text;return n?0===e?\"0\":_+i:i};var V=[\"f\",\"p\",\"n\",\"\\u03bc\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\"];function q(t){return\"SI\"===t||\"B\"===t}function H(t){return t>14||t<-15}function G(t,e,r,n){var a=t<0,o=e._tickround,l=r||e.exponentformat||\"B\",c=e._tickexponent,u=A.getTickFormat(e),h=e.separatethousands;if(n){var f={exponentformat:l,dtick:\"none\"===e.showexponent?e.dtick:i(t)&&Math.abs(t)||1,range:\"none\"===e.showexponent?e.range.map(e.r2d):[0,t||1]};j(f),o=(Number(f._tickround)||0)+4,c=f._tickexponent,e.hoverformat&&(u=e.hoverformat)}if(u)return e._numFormat(u)(t).replace(/-/g,_);var p,d=Math.pow(10,-o)/2;if(\"none\"===l&&(c=0),(t=Math.abs(t))<d)t=\"0\",a=!1;else{if(t+=d,c&&(t*=Math.pow(10,-c),o+=c),0===o)t=String(Math.floor(t));else if(o<0){t=(t=String(Math.round(t))).substr(0,t.length+o);for(var g=o;g<0;g++)t+=\"0\"}else{var v=(t=String(t)).indexOf(\".\")+1;v&&(t=t.substr(0,v+o).replace(/\\.?0+$/,\"\"))}t=s.numSeparate(t,e._separators,h)}c&&\"hide\"!==l&&(q(l)&&H(c)&&(l=\"power\"),p=c<0?_+-c:\"power\"!==l?\"+\"+c:String(c),\"e\"===l||\"E\"===l?t+=l+p:\"power\"===l?t+=\"\\xd710<sup>\"+p+\"</sup>\":\"B\"===l&&9===c?t+=\"B\":q(l)&&(t+=V[c/3+5]));return a?_+t:t}function Y(t,e){var r=t._id.charAt(0),n=t._tickAngles[e]||0,i=s.deg2rad(n),a=Math.sin(i),o=Math.cos(i),l=0,c=0;return t._selections[e].each(function(){var t=J(this),e=h.bBox(t.node()),r=e.width,n=e.height;l=Math.max(l,o*r,a*n),c=Math.max(c,a*r,o*n)}),{x:c,y:l}[r]}function W(t){return[t.text,t.x,t.axInfo,t.font,t.fontSize,t.fontColor].join(\"_\")}function X(t,e){var r,n=t._fullLayout._size,i=e._id.charAt(0),a=e.side;return\"free\"!==e.anchor?r=S.getFromId(t,e.anchor):\"x\"===i?r={_offset:n.t+(1-(e.position||0))*n.h,_length:0}:\"y\"===i&&(r={_offset:n.l+(e.position||0)*n.w,_length:0}),\"top\"===a||\"left\"===a?r._offset:\"bottom\"===a||\"right\"===a?r._offset+r._length:void 0}function Z(t,e){var r=t.l2p(e);return r>1&&r<t._length-1}function J(t){var e=n.select(t),r=e.select(\".text-math-group\");return r.empty()?e.select(\"text\"):r}function K(t){return t._id+\".automargin\"}function $(t){return t._id+\".rangeslider\"}function Q(t,e){for(var r=0;r<e.length;r++)-1===t.indexOf(e[r])&&t.push(e[r])}function tt(t,e,r){var n,i,a=[],o=[],l=t.layout;for(n=0;n<e.length;n++)a.push(A.getFromId(t,e[n]));for(n=0;n<r.length;n++)o.push(A.getFromId(t,r[n]));var c=Object.keys(f),u=[\"anchor\",\"domain\",\"overlaying\",\"position\",\"side\",\"tickangle\",\"editType\"],h=[\"linear\",\"log\"];for(n=0;n<c.length;n++){var p=c[n],d=a[0][p],g=o[0][p],v=!0,m=!1,y=!1;if(\"_\"!==p.charAt(0)&&\"function\"!=typeof d&&-1===u.indexOf(p)){for(i=1;i<a.length&&v;i++){var x=a[i][p];\"type\"===p&&-1!==h.indexOf(d)&&-1!==h.indexOf(x)&&d!==x?m=!0:x!==d&&(v=!1)}for(i=1;i<o.length&&v;i++){var b=o[i][p];\"type\"===p&&-1!==h.indexOf(g)&&-1!==h.indexOf(b)&&g!==b?y=!0:o[i][p]!==g&&(v=!1)}v&&(m&&(l[a[0]._name].type=\"linear\"),y&&(l[o[0]._name].type=\"linear\"),et(l,p,a,o,t._fullLayout._dfltTitle))}}for(n=0;n<t._fullLayout.annotations.length;n++){var _=t._fullLayout.annotations[n];-1!==e.indexOf(_.xref)&&-1!==r.indexOf(_.yref)&&s.swapAttrs(l.annotations[n],[\"?\"])}}function et(t,e,r,n,i){var a,o=s.nestedProperty,l=o(t[r[0]._name],e).get(),c=o(t[n[0]._name],e).get();for(\"title\"===e&&(l&&l.text===i.x&&(l.text=i.y),c&&c.text===i.y&&(c.text=i.x)),a=0;a<r.length;a++)o(t,r[a]._name+\".\"+e).set(c);for(a=0;a<n.length;a++)o(t,n[a]._name+\".\"+e).set(l)}function rt(t){return\"angularaxis\"===t._id}A.getTickFormat=function(t){var e,r,n,i,a,o,s,l;function c(t){return\"string\"!=typeof t?t:Number(t.replace(\"M\",\"\"))*v}function u(t,e){var r=[\"L\",\"D\"];if(typeof t==typeof e){if(\"number\"==typeof t)return t-e;var n=r.indexOf(t.charAt(0)),i=r.indexOf(e.charAt(0));return n===i?Number(t.replace(/(L|D)/g,\"\"))-Number(e.replace(/(L|D)/g,\"\")):n-i}return\"number\"==typeof t?1:-1}function h(t,e){var r=null===e[0],n=null===e[1],i=u(t,e[0])>=0,a=u(t,e[1])<=0;return(r||i)&&(n||a)}if(t.tickformatstops&&t.tickformatstops.length>0)switch(t.type){case\"date\":case\"linear\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&(i=t.dtick,a=n.dtickrange,o=void 0,void 0,void 0,o=c||function(t){return t},s=a[0],l=a[1],(!s&&\"number\"!=typeof s||o(s)<=o(i))&&(!l&&\"number\"!=typeof l||o(l)>=o(i)))){r=n;break}break;case\"log\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&h(t.dtick,n.dtickrange)){r=n;break}}return r?r.value:t.tickformat},A.getSubplots=function(t,e){var r=t._fullLayout._subplots,n=r.cartesian.concat(r.gl2d||[]),i=e?A.findSubplotsWithAxis(n,e):n;return i.sort(function(t,e){var r=t.substr(1).split(\"y\"),n=e.substr(1).split(\"y\");return r[0]===n[0]?+r[1]-+n[1]:+r[0]-+n[0]}),i},A.findSubplotsWithAxis=function(t,e){for(var r=new RegExp(\"x\"===e._id.charAt(0)?\"^\"+e._id+\"y\":e._id+\"$\"),n=[],i=0;i<t.length;i++){var a=t[i];r.test(a)&&n.push(a)}return n},A.makeClipPaths=function(t){var e=t._fullLayout;if(!e._hasOnlyLargeSploms){var r,i,a={_offset:0,_length:e.width,_id:\"\"},o={_offset:0,_length:e.height,_id:\"\"},s=A.list(t,\"x\",!0),l=A.list(t,\"y\",!0),c=[];for(r=0;r<s.length;r++)for(c.push({x:s[r],y:o}),i=0;i<l.length;i++)0===r&&c.push({x:a,y:l[i]}),c.push({x:s[r],y:l[i]});var u=e._clips.selectAll(\".axesclip\").data(c,function(t){return t.x._id+t.y._id});u.enter().append(\"clipPath\").classed(\"axesclip\",!0).attr(\"id\",function(t){return\"clip\"+e._uid+t.x._id+t.y._id}).append(\"rect\"),u.exit().remove(),u.each(function(t){n.select(this).select(\"rect\").attr({x:t.x._offset||0,y:t.y._offset||0,width:t.x._length||1,height:t.y._length||1})})}},A.draw=function(t,e,r){var n=t._fullLayout;\"redraw\"===e&&n._paper.selectAll(\"g.subplot\").each(function(t){var e=t[0],r=n._plots[e],i=r.xaxis,a=r.yaxis;r.xaxislayer.selectAll(\".\"+i._id+\"tick\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"tick2\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick2\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"divider\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"divider\").remove(),r.gridlayer&&r.gridlayer.selectAll(\"path\").remove(),r.zerolinelayer&&r.zerolinelayer.selectAll(\"path\").remove(),n._infolayer.select(\".g-\"+i._id+\"title\").remove(),n._infolayer.select(\".g-\"+a._id+\"title\").remove()});var i=e&&\"redraw\"!==e?e:A.listIds(t);return s.syncOrAsync(i.map(function(e){return function(){if(e){var n=A.getFromId(t,e),i=A.drawOne(t,n,r);return n._r=n.range.slice(),n._rl=s.simpleMap(n._r,n.r2l),i}}}))},A.drawOne=function(t,e,r){var n,i,l;r=r||{},e.setScale();var f=t._fullLayout,p=e._id,d=p.charAt(0),g=A.counterLetter(p),v=e._mainSubplot,m=e._mainLinePosition,y=e._mainMirrorPosition,x=f._plots[v][d+\"axislayer\"],b=e._subplotsWith,_=e._vals=A.calcTicks(e),w=[e.mirror,m,y].join(\"_\");for(n=0;n<_.length;n++)_[n].axInfo=w;if(e.visible){e._selections={},e._tickAngles={};var k,M,S=A.makeTransFn(e);if(\"boundaries\"===e.tickson){var E=function(t,e){var r,n=[],i=function(t,e){var r=t.xbnd[e];null!==r&&n.push(s.extendFlat({},t,{x:r}))};if(e.length){for(r=0;r<e.length;r++)i(e[r],0);i(e[r-1],1)}return n}(0,_);M=A.clipEnds(e,E),k=\"inside\"===e.ticks?M:E}else M=A.clipEnds(e,_),k=\"inside\"===e.ticks?M:_;var C=e._gridVals=M,L=function(t,e){var r,n,i=[],a=function(t,e){var r=t.xbnd[e];null!==r&&i.push(s.extendFlat({},t,{x:r}))};if(t.showdividers&&e.length){for(r=0;r<e.length;r++){var o=e[r];o.text2!==n&&a(o,0),n=o.text2}a(e[r-1],1)}return i}(e,_);if(!f._hasOnlyLargeSploms){var P={};for(n=0;n<b.length;n++){i=b[n];var O=(l=f._plots[i])[g+\"axis\"],z=O._mainAxis._id;if(!P[z]){P[z]=1;var I=\"x\"===d?\"M0,\"+O._offset+\"v\"+O._length:\"M\"+O._offset+\",0h\"+O._length;A.drawGrid(t,e,{vals:C,counterAxis:O,layer:l.gridlayer.select(\".\"+p),path:I,transFn:S}),A.drawZeroLine(t,e,{counterAxis:O,layer:l.zerolinelayer,path:I,transFn:S})}}}var D=A.getTickSigns(e),R=[];if(e.ticks){var F,B,N,j=A.makeTickPath(e,m,D[2]);if(e._anchorAxis&&e.mirror&&!0!==e.mirror?(F=A.makeTickPath(e,y,D[3]),B=j+F):(F=\"\",B=j),e.showdividers&&\"outside\"===e.ticks&&\"boundaries\"===e.tickson){var V={};for(n=0;n<L.length;n++)V[L[n].x]=1;N=function(t){return V[t.x]?F:B}}else N=B;A.drawTicks(t,e,{vals:k,layer:x,path:N,transFn:S}),R=Object.keys(e._linepositions||{})}for(n=0;n<R.length;n++){i=R[n],l=f._plots[i];var q=e._linepositions[i]||[],H=A.makeTickPath(e,q[0],D[0])+A.makeTickPath(e,q[1],D[1]);A.drawTicks(t,e,{vals:k,layer:l[d+\"axislayer\"],path:H,transFn:S})}var G=[];if(G.push(function(){return A.drawLabels(t,e,{vals:_,layer:x,transFn:S,labelFns:A.makeLabelFns(e,m)})}),\"multicategory\"===e.type){var Z=0,J={x:2,y:10}[d],Q=D[2]*(\"inside\"===e.ticks?-1:1);G.push(function(){return Z+=Y(e,p+\"tick\")+J,Z+=e._tickAngles[p+\"tick\"]?e.tickfont.size*T:0,A.drawLabels(t,e,{vals:function(t,e){for(var r=[],n={},i=0;i<e.length;i++){var a=e[i];n[a.text2]?n[a.text2].push(a.x):n[a.text2]=[a.x]}for(var o in n)r.push(U(t,s.interp(n[o],.5),o));return r}(e,_),layer:x,cls:p+\"tick2\",repositionOnUpdate:!0,secondary:!0,transFn:S,labelFns:A.makeLabelFns(e,m+Z*Q)})}),G.push(function(){return Z+=Y(e,p+\"tick2\"),e._labelLength=Z,function(t,e,r){var n=e._id+\"divider\",i=r.vals,a=r.layer.selectAll(\"path.\"+n).data(i,W);a.exit().remove(),a.enter().insert(\"path\",\":first-child\").classed(n,1).classed(\"crisp\",1).call(u.stroke,e.dividercolor).style(\"stroke-width\",h.crispRound(t,e.dividerwidth,1)+\"px\"),a.attr(\"transform\",r.transFn).attr(\"d\",r.path)}(t,e,{vals:L,layer:x,path:A.makeTickPath(e,m,Q,Z),transFn:S})})}var tt=o.getComponentMethod(\"rangeslider\",\"isVisible\")(e);return G.push(function(){if(e.showticklabels){var r=t.getBoundingClientRect(),n=x.node().getBoundingClientRect();e._boundingBox={width:n.width,height:n.height,left:n.left-r.left,right:n.right-r.left,top:n.top-r.top,bottom:n.bottom-r.top}}else{var i,a=f._size;\"x\"===d?(i=\"free\"===e.anchor?a.t+a.h*(1-e.position):a.t+a.h*(1-e._anchorAxis.domain[{bottom:0,top:1}[e.side]]),e._boundingBox={top:i,bottom:i,left:e._offset,right:e._offset+e._length,width:e._length,height:0}):(i=\"free\"===e.anchor?a.l+a.w*e.position:a.l+a.w*e._anchorAxis.domain[{left:0,right:1}[e.side]],e._boundingBox={left:i,right:i,bottom:e._offset+e._length,top:e._offset,height:e._length,width:0})}if(b){for(var o=e._counterSpan=[1/0,-1/0],s=0;s<b.length;s++){var l=f._plots[b[s]][\"x\"===d?\"yaxis\":\"xaxis\"];et(o,[l._offset,l._offset+l._length])}\"free\"===e.anchor&&et(o,\"x\"===d?[e._boundingBox.bottom,e._boundingBox.top]:[e._boundingBox.right,e._boundingBox.left])}},function(){var r,n,i=e.side.charAt(0);if(tt&&(n=o.getComponentMethod(\"rangeslider\",\"autoMarginOpts\")(t,e)),a.autoMargin(t,$(e),n),e.automargin&&(!tt||\"b\"!==i)){r={x:0,y:0,r:0,l:0,t:0,b:0};var s,l,c=e._boundingBox,u=X(t,e);switch(d+i){case\"xb\":s=0,l=c.top-u,r[i]=c.height;break;case\"xt\":s=1,l=u-c.bottom,r[i]=c.height;break;case\"yl\":s=0,l=u-c.right,r[i]=c.width;break;case\"yr\":s=1,l=c.left-u,r[i]=c.width}if(r[g]=\"free\"===e.anchor?e.position:e._anchorAxis.domain[s],r[i]>0&&(r[i]+=l),e.title.text!==f._dfltTitle[d]&&(r[i]+=e.title.font.size),\"x\"===d&&c.width>0){var h=c.right-(e._offset+e._length);h>0&&(r.x=1,r.r=h);var p=e._offset-c.left;p>0&&(r.x=0,r.l=p)}else if(\"y\"===d&&c.height>0){var v=c.bottom-(e._offset+e._length);v>0&&(r.y=0,r.b=v);var m=e._offset-c.top;m>0&&(r.y=1,r.t=m)}}a.autoMargin(t,K(e),r)}),r.skipTitle||tt&&e._boundingBox&&\"bottom\"===e.side||G.push(function(){return function(t,e){var r,n=t._fullLayout,i=e._id,a=i.charAt(0),o=e.title.font.size;if(\"multicategory\"===e.type)r=e._labelLength;else{r=10+1.5*o+(e.linewidth?e.linewidth-1:0)}var s,l,u,f,p=X(t,e);\"x\"===a?(l=e._offset+e._length/2,u=\"top\"===e.side?-r-o*(e.showticklabels?1:0):r+o*(e.showticklabels?1.5:.5),u+=p):(u=e._offset+e._length/2,l=\"right\"===e.side?r+o*(e.showticklabels?1:.5):-r-o*(e.showticklabels?.5:0),l+=p,s={rotate:\"-90\",offset:0});if(\"multicategory\"!==e.type){var d=e._selections[e._id+\"tick\"];if(f={selection:d,side:e.side},d&&d.node()&&d.node().parentNode){var g=h.getTranslate(d.node().parentNode);f.offsetLeft=g.x,f.offsetTop=g.y}}return c.draw(t,i+\"title\",{propContainer:e,propName:e._name+\".title.text\",placeholder:n._dfltTitle[a],avoid:f,transform:s,attributes:{x:l,y:u,\"text-anchor\":\"middle\"}})}(t,e)}),s.syncOrAsync(G)}function et(t,e){t[0]=Math.min(t[0],e[0]),t[1]=Math.max(t[1],e[1])}},A.getTickSigns=function(t){var e=t._id.charAt(0),r={x:\"top\",y:\"right\"}[e],n=t.side===r?1:-1,i=[-1,1,n,-n];return\"inside\"!==t.ticks==(\"x\"===e)&&(i=i.map(function(t){return-t})),i},A.makeTransFn=function(t){var e=t._id.charAt(0),r=t._offset;return\"x\"===e?function(e){return\"translate(\"+(r+t.l2p(e.x))+\",0)\"}:function(e){return\"translate(0,\"+(r+t.l2p(e.x))+\")\"}},A.makeTickPath=function(t,e,r,n){n=void 0!==n?n:t.ticklen;var i=t._id.charAt(0),a=(t.linewidth||1)/2;return\"x\"===i?\"M0,\"+(e+a*r)+\"v\"+n*r:\"M\"+(e+a*r)+\",0h\"+n*r},A.makeLabelFns=function(t,e,r){var n=t._id.charAt(0),a=\"boundaries\"!==t.tickson&&\"outside\"===t.ticks,o=0,l=0;if(a&&(o+=t.ticklen),r&&\"outside\"===t.ticks){var c=s.deg2rad(r);o=t.ticklen*Math.cos(c)+1,l=t.ticklen*Math.sin(c)}t.showticklabels&&(a||t.showline)&&(o+=.2*t.tickfont.size);var u,h,f,p,d={labelStandoff:o+=(t.linewidth||1)/2,labelShift:l};return\"x\"===n?(p=\"bottom\"===t.side?1:-1,u=l*p,h=e+o*p,f=\"bottom\"===t.side?1:-.2,d.xFn=function(t){return t.dx+u},d.yFn=function(t){return t.dy+h+t.fontSize*f},d.anchorFn=function(t,e){return i(e)&&0!==e&&180!==e?e*p<0?\"end\":\"start\":\"middle\"},d.heightFn=function(e,r,n){return r<-60||r>60?-.5*n:\"top\"===t.side?-n:0}):\"y\"===n&&(p=\"right\"===t.side?1:-1,u=o,h=-l*p,f=90===Math.abs(t.tickangle)?.5:0,d.xFn=function(t){return t.dx+e+(u+t.fontSize*f)*p},d.yFn=function(t){return t.dy+h+t.fontSize*k},d.anchorFn=function(e,r){return i(r)&&90===Math.abs(r)?\"middle\":\"right\"===t.side?\"start\":\"end\"},d.heightFn=function(e,r,n){return(r*=\"left\"===t.side?1:-1)<-30?-n:r<30?-.5*n:0}),d},A.drawTicks=function(t,e,r){r=r||{};var n=e._id+\"tick\",i=r.layer.selectAll(\"path.\"+n).data(e.ticks?r.vals:[],W);i.exit().remove(),i.enter().append(\"path\").classed(n,1).classed(\"ticks\",1).classed(\"crisp\",!1!==r.crisp).call(u.stroke,e.tickcolor).style(\"stroke-width\",h.crispRound(t,e.tickwidth,1)+\"px\").attr(\"d\",r.path),i.attr(\"transform\",r.transFn)},A.drawGrid=function(t,e,r){r=r||{};var n=e._id+\"grid\",i=r.vals,a=r.counterAxis;if(!1===e.showgrid)i=[];else if(a&&A.shouldShowZeroLine(t,e,a))for(var o=\"array\"===e.tickmode,s=0;s<i.length;s++){var l=i[s].x;if(o?!l:Math.abs(l)<e.dtick/100){if(i=i.slice(0,s).concat(i.slice(s+1)),!o)break;s--}}var c=r.layer.selectAll(\"path.\"+n).data(i,W);c.exit().remove(),c.enter().append(\"path\").classed(n,1).classed(\"crisp\",!1!==r.crisp),e._gw=h.crispRound(t,e.gridwidth,1),c.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(u.stroke,e.gridcolor||\"#ddd\").style(\"stroke-width\",e._gw+\"px\"),\"function\"==typeof r.path&&c.attr(\"d\",r.path)},A.drawZeroLine=function(t,e,r){r=r||r;var n=e._id+\"zl\",i=A.shouldShowZeroLine(t,e,r.counterAxis),a=r.layer.selectAll(\"path.\"+n).data(i?[{x:0,id:e._id}]:[]);a.exit().remove(),a.enter().append(\"path\").classed(n,1).classed(\"zl\",1).classed(\"crisp\",!1!==r.crisp).each(function(){r.layer.selectAll(\"path\").sort(function(t,e){return S.idSort(t.id,e.id)})}),a.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(u.stroke,e.zerolinecolor||u.defaultLine).style(\"stroke-width\",h.crispRound(t,e.zerolinewidth,e._gw||1)+\"px\")},A.drawLabels=function(t,e,r){r=r||{};var a=e._id,o=a.charAt(0),c=r.cls||a+\"tick\",u=r.vals,f=r.labelFns,p=r.secondary?0:e.tickangle,d=(e._tickAngles||{})[c],g=r.layer.selectAll(\"g.\"+c).data(e.showticklabels?u:[],W),v=[];function m(t,e){t.each(function(t){var a=n.select(this),o=a.select(\".text-math-group\"),s=f.anchorFn(t,e),c=r.transFn.call(a.node(),t)+(i(e)&&0!=+e?\" rotate(\"+e+\",\"+f.xFn(t)+\",\"+(f.yFn(t)-t.fontSize/2)+\")\":\"\"),u=l.lineCount(a),p=T*t.fontSize,d=f.heightFn(t,i(e)?+e:0,(u-1)*p);if(d&&(c+=\" translate(0, \"+d+\")\"),o.empty())a.select(\"text\").attr({transform:c,\"text-anchor\":s});else{var g=h.bBox(o.node()).width*{end:-.5,start:.5}[s];o.attr(\"transform\",c+(g?\"translate(\"+g+\",0)\":\"\"))}})}g.enter().append(\"g\").classed(c,1).append(\"text\").attr(\"text-anchor\",\"middle\").each(function(e){var r=n.select(this),i=t._promises.length;r.call(l.positionText,f.xFn(e),f.yFn(e)).call(h.font,e.font,e.fontSize,e.fontColor).text(e.text).call(l.convertToTspans,t),t._promises[i]?v.push(t._promises.pop().then(function(){m(r,p)})):m(r,p)}),g.exit().remove(),r.repositionOnUpdate&&g.each(function(t){n.select(this).select(\"text\").call(l.positionText,f.xFn(t),f.yFn(t))}),m(g,d||p),e._selections&&(e._selections[c]=g);var y=s.syncOrAsync([function(){return v.length&&Promise.all(v)},function(){m(g,p);var t=null;if(u.length&&\"x\"===o&&!i(p)&&(\"log\"!==e.type||\"D\"!==String(e.dtick).charAt(0))){t=0;var n,a=0,l=[];if(g.each(function(t){a=Math.max(a,t.fontSize);var r=e.l2p(t.x),n=J(this),i=h.bBox(n.node());l.push({top:0,bottom:10,height:10,left:r-i.width/2,right:r+i.width/2+2,width:i.width+2})}),\"boundaries\"!==e.tickson&&!e.showdividers||r.secondary){var f=u.length,d=Math.abs((u[f-1].x-u[0].x)*e._m)/(f-1)<2.5*a||\"multicategory\"===e.type;for(n=0;n<l.length-1;n++)if(s.bBoxIntersect(l[n],l[n+1])){t=d?90:30;break}}else{var v=2;for(e.ticks&&(v+=e.tickwidth/2),n=0;n<l.length;n++){var y=u[n].xbnd,x=l[n];if(null!==y[0]&&x.left-e.l2p(y[0])<v||null!==y[1]&&e.l2p(y[1])-x.right<v){t=90;break}}}t&&m(g,t)}e._tickAngles&&(e._tickAngles[c]=null===t?i(p)?p:0:t)}]);return y&&y.then&&t._promises.push(y),y},A.shouldShowZeroLine=function(t,e,r){var n=s.simpleMap(e.range,e.r2l);return n[0]*n[1]<=0&&e.zeroline&&(\"linear\"===e.type||\"-\"===e.type)&&e._gridVals.length&&(Z(e,0)||!function(t,e,r,n){var i=r._mainAxis;if(!i)return;var a=t._fullLayout,o=e._id.charAt(0),s=A.counterLetter(e._id),l=e._offset+(Math.abs(n[0])<Math.abs(n[1])==(\"x\"===o)?0:e._length);function c(t){if(!t.showline||!t.linewidth)return!1;var r=Math.max((t.linewidth+e.zerolinewidth)/2,1);function n(t){return\"number\"==typeof t&&Math.abs(t-l)<r}if(n(t._mainLinePosition)||n(t._mainMirrorPosition))return!0;var i=t._linepositions||{};for(var a in i)if(n(i[a][0])||n(i[a][1]))return!0}var u=a._plots[r._mainSubplot];if(!(u.mainplotinfo||u).overlays.length)return c(r);for(var h=A.list(t,s),f=0;f<h.length;f++){var p=h[f];if(p._mainAxis===i&&c(p))return!0}}(t,e,r,n)||function(t,e){for(var r=t._fullData,n=e._mainSubplot,i=e._id.charAt(0),a=0;a<r.length;a++){var s=r[a];if(!0===s.visible&&s.xaxis+s.yaxis===n){if(o.traceIs(s,\"bar-like\")&&s.orientation==={x:\"h\",y:\"v\"}[i])return!0;if(s.fill&&s.fill.charAt(s.fill.length-1)===i)return!0}}return!1}(t,e))},A.clipEnds=function(t,e){return e.filter(function(e){return Z(t,e.x)})},A.allowAutoMargin=function(t){for(var e=A.list(t,\"\",!0),r=0;r<e.length;r++){var n=e[r];n.automargin&&a.allowAutoMargin(t,K(n)),o.getComponentMethod(\"rangeslider\",\"isVisible\")(n)&&a.allowAutoMargin(t,$(n))}},A.swap=function(t,e){for(var r=function(t,e){var r,n,i=[];for(r=0;r<e.length;r++){var a=[],o=t._fullData[e[r]].xaxis,s=t._fullData[e[r]].yaxis;if(o&&s){for(n=0;n<i.length;n++)-1===i[n].x.indexOf(o)&&-1===i[n].y.indexOf(s)||a.push(n);if(a.length){var l,c=i[a[0]];if(a.length>1)for(n=1;n<a.length;n++)l=i[a[n]],Q(c.x,l.x),Q(c.y,l.y);Q(c.x,[o]),Q(c.y,[s])}else i.push({x:[o],y:[s]})}}return i}(t,e),n=0;n<r.length;n++)tt(t,r[n].x,r[n].y)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../components/titles\":681,\"../../constants/alignment\":688,\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/plots\":828,\"../../registry\":847,\"./autorange\":766,\"./axis_autotype\":768,\"./axis_ids\":770,\"./clean_ticks\":772,\"./layout_attributes\":779,\"./set_convert\":785,d3:163,\"fast-isnumeric\":225}],768:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){return!(r=r||{}).noMultiCategory&&(o=t,i.isArrayOrTypedArray(o[0])&&i.isArrayOrTypedArray(o[1]))?\"multicategory\":function(t,e){for(var r=Math.max(1,(t.length-1)/1e3),a=0,o=0,s={},l=0;l<t.length;l+=r){var c=t[Math.round(l)],u=String(c);s[u]||(s[u]=1,i.isDateTime(c,e)&&(a+=1),n(c)&&(o+=1))}return a>2*o}(t,e)?\"date\":function(t){for(var e=Math.max(1,(t.length-1)/1e3),r=0,n=0,o={},s=0;s<t.length;s+=e){var l=t[Math.round(s)],c=String(l);o[c]||(o[c]=1,\"boolean\"==typeof l?n++:i.cleanNumber(l)!==a?r++:\"string\"==typeof l&&n++)}return n>2*r}(t)?\"category\":function(t){if(!t)return!1;for(var e=0;e<t.length;e++)if(n(t[e]))return!0;return!1}(t)?\"linear\":\"-\";var o}},{\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],769:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./layout_attributes\"),o=t(\"./tick_value_defaults\"),s=t(\"./tick_mark_defaults\"),l=t(\"./tick_label_defaults\"),c=t(\"./category_order_defaults\"),u=t(\"./line_grid_defaults\"),h=t(\"./set_convert\");e.exports=function(t,e,r,f,p){var d=f.letter,g=f.font||{},v=f.splomStash||{},m=r(\"visible\",!f.visibleDflt),y=e.type;\"date\"===y&&n.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",f.calendar);h(e,p);var x=!e.isValidRange(t.range);x&&f.reverseDflt&&(x=\"reversed\"),!r(\"autorange\",x)||\"linear\"!==y&&\"-\"!==y||r(\"rangemode\"),r(\"range\"),e.cleanRange(),c(t,e,r,f),\"category\"===y||f.noHover||r(\"hoverformat\");var b=r(\"color\"),_=b!==a.color.dflt?b:g.color,w=v.label||p._dfltTitle[d];if(l(t,e,r,y,f,{pass:1}),!m)return e;r(\"title.text\",w),i.coerceFont(r,\"title.font\",{family:g.family,size:Math.round(1.2*g.size),color:_}),o(t,e,r,y),l(t,e,r,y,f,{pass:2}),s(t,e,r,f),u(t,e,r,{dfltColor:b,bgColor:f.bgColor,showGrid:f.showGrid,attributes:a}),(e.showline||e.ticks)&&r(\"mirror\"),f.automargin&&r(\"automargin\");var k,T=\"multicategory\"===e.type;f.noTickson||\"category\"!==e.type&&!T||!e.ticks&&!e.showgrid||(T&&(k=\"boundaries\"),r(\"tickson\",k));T&&(r(\"showdividers\")&&(r(\"dividercolor\"),r(\"dividerwidth\")));return e}},{\"../../lib\":719,\"../../registry\":847,\"./category_order_defaults\":771,\"./layout_attributes\":779,\"./line_grid_defaults\":781,\"./set_convert\":785,\"./tick_label_defaults\":786,\"./tick_mark_defaults\":787,\"./tick_value_defaults\":788}],770:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./constants\");r.id2name=function(t){if(\"string\"==typeof t&&t.match(i.AX_ID_PATTERN)){var e=t.substr(1);return\"1\"===e&&(e=\"\"),t.charAt(0)+\"axis\"+e}},r.name2id=function(t){if(t.match(i.AX_NAME_PATTERN)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),t.charAt(0)+e}},r.cleanId=function(t,e){if(t.match(i.AX_ID_PATTERN)&&(!e||t.charAt(0)===e)){var r=t.substr(1).replace(/^0+/,\"\");return\"1\"===r&&(r=\"\"),t.charAt(0)+r}},r.list=function(t,e,n){var i=t._fullLayout;if(!i)return[];var a,o=r.listIds(t,e),s=new Array(o.length);for(a=0;a<o.length;a++){var l=o[a];s[a]=i[l.charAt(0)+\"axis\"+l.substr(1)]}if(!n){var c=i._subplots.gl3d||[];for(a=0;a<c.length;a++){var u=i[c[a]];e?s.push(u[e+\"axis\"]):s.push(u.xaxis,u.yaxis,u.zaxis)}}return s},r.listIds=function(t,e){var r=t._fullLayout;if(!r)return[];var n=r._subplots;return e?n[e+\"axis\"]:n.xaxis.concat(n.yaxis)},r.getFromId=function(t,e,n){var i=t._fullLayout;return\"x\"===n?e=e.replace(/y[0-9]*/,\"\"):\"y\"===n&&(e=e.replace(/x[0-9]*/,\"\")),i[r.id2name(e)]},r.getFromTrace=function(t,e,i){var a=t._fullLayout,o=null;if(n.traceIs(e,\"gl3d\")){var s=e.scene;\"scene\"===s.substr(0,5)&&(o=a[s][i+\"axis\"])}else o=r.getFromId(t,e[i+\"axis\"]||i);return o},r.idSort=function(t,e){var r=t.charAt(0),n=e.charAt(0);return r!==n?r>n?1:-1:+(t.substr(1)||1)-+(e.substr(1)||1)},r.getAxisGroup=function(t,e){for(var r=t._axisMatchGroups,n=0;n<r.length;n++){if(r[n][e])return\"g\"+n}return e}},{\"../../registry\":847,\"./constants\":773}],771:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){if(\"category\"===e.type){var i,a=t.categoryarray,o=Array.isArray(a)&&a.length>0;o&&(i=\"array\");var s,l=r(\"categoryorder\",i);\"array\"===l&&(s=r(\"categoryarray\")),o||\"array\"!==l||(l=e.categoryorder=\"trace\"),\"trace\"===l?e._initialCategories=[]:\"array\"===l?e._initialCategories=s.slice():(s=function(t,e){var r,n,i,a=e.dataAttr||t._id.charAt(0),o={};if(e.axData)r=e.axData;else for(r=[],n=0;n<e.data.length;n++){var s=e.data[n];s[a+\"axis\"]===t._id&&r.push(s)}for(n=0;n<r.length;n++){var l=r[n][a];for(i=0;i<l.length;i++){var c=l[i];null!=c&&(o[c]=1)}}return Object.keys(o)}(e,n).sort(),\"category ascending\"===l?e._initialCategories=s:\"category descending\"===l&&(e._initialCategories=s.reverse()))}}},{}],772:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").ONEDAY;r.dtick=function(t,e){var r=\"log\"===e,i=\"date\"===e,o=\"category\"===e,s=i?a:1;if(!t)return s;if(n(t))return(t=Number(t))<=0?s:o?Math.max(1,Math.round(t)):i?Math.max(.1,t):t;if(\"string\"!=typeof t||!i&&!r)return s;var l=t.charAt(0),c=t.substr(1);return(c=n(c)?Number(c):0)<=0||!(i&&\"M\"===l&&c===Math.round(c)||r&&\"L\"===l||r&&\"D\"===l&&(1===c||2===c))?s:t},r.tick0=function(t,e,r,a){return\"date\"===e?i.cleanDate(t,i.dateTick0(r)):\"D1\"!==a&&\"D2\"!==a?n(t)?Number(t):0:void 0}},{\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],773:[function(t,e,r){\"use strict\";var n=t(\"../../lib/regex\").counter;e.exports={idRegex:{x:n(\"x\"),y:n(\"y\")},attrRegex:n(\"[xy]axis\"),xAxisMatch:n(\"xaxis\"),yAxisMatch:n(\"yaxis\"),AX_ID_PATTERN:/^[xyz][0-9]*$/,AX_NAME_PATTERN:/^[xyz]axis[0-9]*$/,SUBPLOT_PATTERN:/^x([0-9]*)y([0-9]*)$/,MINDRAG:8,MINSELECT:12,MINZOOM:20,DRAGGERSIZE:20,BENDPX:1.5,REDRAWDELAY:50,SELECTDELAY:100,SELECTID:\"-select\",DFLTRANGEX:[-1,6],DFLTRANGEY:[-1,4],traceLayerClasses:[\"heatmaplayer\",\"contourcarpetlayer\",\"contourlayer\",\"funnellayer\",\"waterfalllayer\",\"barlayer\",\"carpetlayer\",\"violinlayer\",\"boxlayer\",\"ohlclayer\",\"scattercarpetlayer\",\"scatterlayer\"],clipOnAxisFalseQuery:[\".scatterlayer\",\".barlayer\",\".funnellayer\",\".waterfalllayer\"],layerValue2layerClass:{\"above traces\":\"above\",\"below traces\":\"below\"}}},{\"../../lib/regex\":735}],774:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./axis_ids\").id2name,a=t(\"./scale_zoom\"),o=t(\"./autorange\").makePadFn,s=t(\"./autorange\").concatExtremes,l=t(\"../../constants/numerical\").ALMOST_EQUAL,c=t(\"../../constants/alignment\").FROM_BL;function u(t,e,r,n,a){var o,s,l,c,u=\"range\"!==a,h=n[i(e)].type,f=[];for(s=0;s<r.length;s++)if((l=r[s])!==e&&(c=n[i(l)]).type===h)if(c.fixedrange){if(u&&c.anchor){n[i(c.anchor)].fixedrange&&f.push(l)}}else f.push(l);for(o=0;o<t.length;o++)if(t[o][e]){var p=t[o],d=[];for(s=0;s<f.length;s++)p[l=f[s]]||d.push(l);return{linkableAxes:d,thisGroup:p}}return{linkableAxes:f,thisGroup:null}}function h(t,e,r,n,i){var a,o,s,l,c;null===e?((e={})[r]=1,c=t.length,t.push(e)):c=t.indexOf(e);var u=Object.keys(e);for(a=0;a<t.length;a++)if(s=t[a],a!==c&&s[n]){var h=s[n];for(o=0;o<u.length;o++)s[l=u[o]]=h*i*e[l];return void t.splice(c,1)}if(1!==i)for(o=0;o<u.length;o++)e[u[o]]*=i;e[n]=1}function f(t,e){var r=t._inputDomain,n=c[t.constraintoward],i=r[0]+(r[1]-r[0])*n;t.domain=t._input.domain=[i+(r[0]-i)/e,i+(r[1]-i)/e],t.setScale()}r.handleConstraintDefaults=function(t,e,r,i,a){var o,s,l,c,f=a._axisConstraintGroups,p=a._axisMatchGroups,d=e._id,g=d.charAt(0),v=((a._splomAxes||{})[g]||{})[d]||{},m=e._id,y=m.charAt(0),x=r(\"constrain\");if(n.coerce(t,e,{constraintoward:{valType:\"enumerated\",values:\"x\"===y?[\"left\",\"center\",\"right\"]:[\"bottom\",\"middle\",\"top\"],dflt:\"x\"===y?\"center\":\"middle\"}},\"constraintoward\"),!t.matches&&!v.matches||e.fixedrange||(s=u(p,m,i,a),o=n.coerce(t,e,{matches:{valType:\"enumerated\",values:s.linkableAxes||[],dflt:v.matches}},\"matches\")),o||!t.scaleanchor||e.fixedrange&&\"domain\"!==x||(c=u(f,m,i,a,x),l=n.coerce(t,e,{scaleanchor:{valType:\"enumerated\",values:c.linkableAxes||[]}},\"scaleanchor\")),o?(delete e.constrain,h(p,s.thisGroup,m,o,1)):-1!==i.indexOf(t.matches)&&n.warn(\"ignored \"+e._name+'.matches: \"'+t.matches+'\" to avoid either an infinite loop or because the target axis has fixed range.'),l){var b=r(\"scaleratio\");b||(b=e.scaleratio=1),h(f,c.thisGroup,m,l,b)}else-1!==i.indexOf(t.scaleanchor)&&n.warn(\"ignored \"+e._name+'.scaleanchor: \"'+t.scaleanchor+'\" to avoid either an infinite loop and possibly inconsistent scaleratios, or because the target axis has fixed range or this axis declares a *matches* constraint.')},r.enforce=function(t){var e,r,n,c,u,h,p,d=t._fullLayout,g=d._axisConstraintGroups||[];for(e=0;e<g.length;e++){var v=g[e],m=Object.keys(v),y=1/0,x=0,b=1/0,_={},w={},k=!1;for(r=0;r<m.length;r++)w[n=m[r]]=c=d[i(n)],c._inputDomain?c.domain=c._inputDomain.slice():c._inputDomain=c.domain.slice(),c._inputRange||(c._inputRange=c.range.slice()),c.setScale(),_[n]=u=Math.abs(c._m)/v[n],y=Math.min(y,u),\"domain\"!==c.constrain&&c._constraintShrinkable||(b=Math.min(b,u)),delete c._constraintShrinkable,x=Math.max(x,u),\"domain\"===c.constrain&&(k=!0);if(!(y>l*x)||k)for(r=0;r<m.length;r++)if(u=_[n=m[r]],h=(c=w[n]).constrain,u!==b||\"domain\"===h)if(p=u/b,\"range\"===h)a(c,p);else{var T=c._inputDomain,A=(c.domain[1]-c.domain[0])/(T[1]-T[0]),M=(c.r2l(c.range[1])-c.r2l(c.range[0]))/(c.r2l(c._inputRange[1])-c.r2l(c._inputRange[0]));if((p/=A)*M<1){c.domain=c._input.domain=T.slice(),a(c,p);continue}if(M<1&&(c.range=c._input.range=c._inputRange.slice(),p*=M),c.autorange){var S=c.r2l(c.range[0]),E=c.r2l(c.range[1]),C=(S+E)/2,L=C,P=C,O=Math.abs(E-C),z=C-O*p*1.0001,I=C+O*p*1.0001,D=o(c);f(c,p);var R,F,B=Math.abs(c._m),N=s(t,c),j=N.min,U=N.max;for(F=0;F<j.length;F++)(R=j[F].val-D(j[F])/B)>z&&R<L&&(L=R);for(F=0;F<U.length;F++)(R=U[F].val+D(U[F])/B)<I&&R>P&&(P=R);p/=(P-L)/(2*O),L=c.l2r(L),P=c.l2r(P),c.range=c._input.range=S<E?[L,P]:[P,L]}f(c,p)}}},r.clean=function(t,e){if(e._inputDomain){for(var r=!1,n=e._id,i=t._fullLayout._axisConstraintGroups,a=0;a<i.length;a++)if(i[a][n]){r=!0;break}r&&\"domain\"===e.constrain||(e._input.domain=e.domain=e._inputDomain,delete e._inputDomain)}}},{\"../../constants/alignment\":688,\"../../constants/numerical\":695,\"../../lib\":719,\"./autorange\":766,\"./axis_ids\":770,\"./scale_zoom\":783}],775:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"has-passive-events\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../components/color\"),u=t(\"../../components/drawing\"),h=t(\"../../components/fx\"),f=t(\"./axes\"),p=t(\"../../lib/setcursor\"),d=t(\"../../components/dragelement\"),g=t(\"../../constants/alignment\").FROM_TL,v=t(\"../../lib/clear_gl_canvases\"),m=t(\"../../plot_api/subroutines\").redrawReglTraces,y=t(\"../plots\"),x=t(\"./axis_ids\").getFromId,b=t(\"./select\").prepSelect,_=t(\"./select\").clearSelect,w=t(\"./select\").selectOnClick,k=t(\"./scale_zoom\"),T=t(\"./constants\"),A=T.MINDRAG,M=T.MINZOOM,S=!0;function E(t,e,r,n){var i=s.ensureSingle(t.draglayer,e,r,function(e){e.classed(\"drag\",!0).style({fill:\"transparent\",\"stroke-width\":0}).attr(\"data-subplot\",t.id)});return i.call(p,n),i.node()}function C(t,e,r,i,a,o,s){var l=E(t,\"rect\",e,r);return n.select(l).call(u.setRect,i,a,o,s),l}function L(t,e){for(var r=0;r<t.length;r++)if(!t[r].fixedrange)return e;return\"\"}function P(t,e,r,n,i){for(var a=0;a<t.length;a++){var o=t[a];if(!o.fixedrange){var s=o._rl[0],l=o._rl[1]-s;n[o._name+\".range[0]\"]=o.l2r(s+l*e),n[o._name+\".range[1]\"]=o.l2r(s+l*r)}}if(i&&i.length){var c=(e+(1-r))/2;P(i,c,1-c,n,[])}}function O(t,e){for(var r=0;r<t.length;r++){var n=t[r];n.fixedrange||(n.range=[n.l2r(n._rl[0]-e/n._m),n.l2r(n._rl[1]-e/n._m)])}}function z(t){return 1-(t>=0?Math.min(t,.9):1/(1/Math.max(t,-.3)+3.222))}function I(t,e,r,n,i){return t.append(\"path\").attr(\"class\",\"zoombox\").style({fill:e>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"transform\",\"translate(\"+r+\", \"+n+\")\").attr(\"d\",i+\"Z\")}function D(t,e,r){return t.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:c.background,stroke:c.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"transform\",\"translate(\"+e+\", \"+r+\")\").attr(\"d\",\"M0,0Z\")}function R(t,e,r,n,i,a){t.attr(\"d\",n+\"M\"+r.l+\",\"+r.t+\"v\"+r.h+\"h\"+r.w+\"v-\"+r.h+\"h-\"+r.w+\"Z\"),F(t,e,i,a)}function F(t,e,r,n){r||(t.transition().style(\"fill\",n>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),e.transition().style(\"opacity\",1).duration(200))}function B(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}function N(t){S&&t.data&&t._context.showTips&&(s.notifier(s._(t,\"Double-click to zoom back out\"),\"long\"),S=!1)}function j(t){return\"lasso\"===t||\"select\"===t}function U(t){var e=Math.floor(Math.min(t.b-t.t,t.r-t.l,M)/2);return\"M\"+(t.l-3.5)+\",\"+(t.t-.5+e)+\"h3v\"+-e+\"h\"+e+\"v-3h-\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.t-.5+e)+\"h-3v\"+-e+\"h\"+-e+\"v-3h\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.b+.5-e)+\"h-3v\"+e+\"h\"+-e+\"v3h\"+(e+3)+\"ZM\"+(t.l-3.5)+\",\"+(t.b+.5-e)+\"h3v\"+e+\"h\"+e+\"v3h-\"+(e+3)+\"Z\"}function V(t,e,r,n){for(var i,a,o,l,c=!1,u={},h={},f=0;f<e.length;f++){var p=e[f];for(i in r)if(p[i]){for(o in p)(\"x\"===o.charAt(0)?r:n)[o]||(u[o]=i);for(a in n)p[a]&&(c=!0)}for(a in n)if(p[a])for(l in p)(\"x\"===l.charAt(0)?r:n)[l]||(h[l]=a)}c&&(s.extendFlat(u,h),h={});var d={},g=[];for(o in u){var v=x(t,o);g.push(v),d[v._id]=v}var m={},y=[];for(l in h){var b=x(t,l);y.push(b),m[b._id]=b}return{xaHash:d,yaHash:m,xaxes:g,yaxes:y,xLinks:u,yLinks:h,isSubplotConstrained:c}}function q(t,e){if(a){var r=void 0!==t.onwheel?\"wheel\":\"mousewheel\";t._onwheel&&t.removeEventListener(r,t._onwheel),t._onwheel=e,t.addEventListener(r,e,{passive:!1})}else void 0!==t.onwheel?t.onwheel=e:void 0!==t.onmousewheel&&(t.onmousewheel=e)}function H(t){var e=[];for(var r in t)e.push(t[r]);return e}e.exports={makeDragBox:function(t,e,r,a,c,p,S,E){var F,G,Y,W,X,Z,J,K,$,Q,tt,et,rt,nt,it,at,ot,st,lt,ct,ut,ht=t._fullLayout._zoomlayer,ft=S+E===\"nsew\",pt=1===(S+E).length;function dt(){if(F=e.xaxis,G=e.yaxis,$=F._length,Q=G._length,J=F._offset,K=G._offset,(Y={})[F._id]=F,(W={})[G._id]=G,S&&E)for(var r=e.overlays,n=0;n<r.length;n++){var i=r[n].xaxis;Y[i._id]=i;var a=r[n].yaxis;W[a._id]=a}X=H(Y),Z=H(W),rt=L(X,E),nt=L(Z,S),it=!nt&&!rt,tt=V(t,t._fullLayout._axisConstraintGroups,Y,W),et=V(t,t._fullLayout._axisMatchGroups,Y,W),at=E||tt.isSubplotConstrained||et.isSubplotConstrained,ot=S||tt.isSubplotConstrained||et.isSubplotConstrained;var o=t._fullLayout;st=o._has(\"scattergl\"),lt=o._has(\"splom\"),ct=o._has(\"svg\")}dt();var gt=function(t,e,r){return t?\"nsew\"===t?r?\"\":\"pan\"===e?\"move\":\"crosshair\":t.toLowerCase()+\"-resize\":\"pointer\"}(nt+rt,t._fullLayout.dragmode,ft),vt=C(e,S+E+\"drag\",gt,r,a,c,p);if(it&&!ft)return vt.onmousedown=null,vt.style.pointerEvents=\"none\",vt;var mt,yt,xt,bt,_t,wt,kt,Tt,At,Mt,St={element:vt,gd:t,plotinfo:e};function Et(){St.plotinfo.selection=!1,_(t)}function Ct(r,i){var a=t._fullLayout.clickmode;if(B(t),2!==r||pt||function(){if(!t._transitioningWithDuration){var e=t._context.doubleClick,r=[];rt&&(r=r.concat(X)),nt&&(r=r.concat(Z)),et.xaxes&&(r=r.concat(et.xaxes)),et.yaxes&&(r=r.concat(et.yaxes));var n,i,a,s={};if(\"reset+autosize\"===e)for(e=\"autosize\",i=0;i<r.length;i++)if((n=r[i])._rangeInitial&&(n.range[0]!==n._rangeInitial[0]||n.range[1]!==n._rangeInitial[1])||!n._rangeInitial&&!n.autorange){e=\"reset\";break}if(\"autosize\"===e)for(i=0;i<r.length;i++)(n=r[i]).fixedrange||(s[n._name+\".autorange\"]=!0);else if(\"reset\"===e)for((rt||tt.isSubplotConstrained)&&(r=r.concat(tt.xaxes)),nt&&!tt.isSubplotConstrained&&(r=r.concat(tt.yaxes)),tt.isSubplotConstrained&&(rt?nt||(r=r.concat(Z)):r=r.concat(X)),i=0;i<r.length;i++)(n=r[i]).fixedrange||(n._rangeInitial?(a=n._rangeInitial,s[n._name+\".range[0]\"]=a[0],s[n._name+\".range[1]\"]=a[1]):s[n._name+\".autorange\"]=!0);t.emit(\"plotly_doubleclick\",null),o.call(\"_guiRelayout\",t,s)}}(),ft)a.indexOf(\"select\")>-1&&w(i,t,X,Z,e.id,St),a.indexOf(\"event\")>-1&&h.click(t,i,e.id);else if(1===r&&pt){var s=S?G:F,c=\"s\"===S||\"w\"===E?0:1,u=s._name+\".range[\"+c+\"]\",f=function(t,e){var r,i=t.range[e],a=Math.abs(i-t.range[1-e]);return\"date\"===t.type?i:\"log\"===t.type?(r=Math.ceil(Math.max(0,-Math.log(a)/Math.LN10))+3,n.format(\".\"+r+\"g\")(Math.pow(10,i))):(r=Math.floor(Math.log(Math.abs(i))/Math.LN10)-Math.floor(Math.log(a)/Math.LN10)+4,n.format(\".\"+String(r)+\"g\")(i))}(s,c),p=\"left\",d=\"middle\";if(s.fixedrange)return;S?(d=\"n\"===S?\"top\":\"bottom\",\"right\"===s.side&&(p=\"right\")):\"e\"===E&&(p=\"right\"),t._context.showAxisRangeEntryBoxes&&n.select(vt).call(l.makeEditable,{gd:t,immediate:!0,background:t._fullLayout.paper_bgcolor,text:String(f),fill:s.tickfont?s.tickfont.color:\"#444\",horizontalAlign:p,verticalAlign:d}).on(\"edit\",function(e){var r=s.d2r(e);void 0!==r&&o.call(\"_guiRelayout\",t,u,r)})}}function Lt(e,r){if(t._transitioningWithDuration)return!1;var n=Math.max(0,Math.min($,e+mt)),i=Math.max(0,Math.min(Q,r+yt)),a=Math.abs(n-mt),o=Math.abs(i-yt);function s(){kt=\"\",xt.r=xt.l,xt.t=xt.b,At.attr(\"d\",\"M0,0Z\")}if(xt.l=Math.min(mt,n),xt.r=Math.max(mt,n),xt.t=Math.min(yt,i),xt.b=Math.max(yt,i),tt.isSubplotConstrained)a>M||o>M?(kt=\"xy\",a/$>o/Q?(o=a*Q/$,yt>i?xt.t=yt-o:xt.b=yt+o):(a=o*$/Q,mt>n?xt.l=mt-a:xt.r=mt+a),At.attr(\"d\",U(xt))):s();else if(et.isSubplotConstrained)if(a>M||o>M){kt=\"xy\";var l=Math.min(xt.l/$,(Q-xt.b)/Q),c=Math.max(xt.r/$,(Q-xt.t)/Q);xt.l=l*$,xt.r=c*$,xt.b=(1-l)*Q,xt.t=(1-c)*Q,At.attr(\"d\",U(xt))}else s();else!nt||o<Math.min(Math.max(.6*a,A),M)?a<A||!rt?s():(xt.t=0,xt.b=Q,kt=\"x\",At.attr(\"d\",function(t,e){return\"M\"+(t.l-.5)+\",\"+(e-M-.5)+\"h-3v\"+(2*M+1)+\"h3ZM\"+(t.r+.5)+\",\"+(e-M-.5)+\"h3v\"+(2*M+1)+\"h-3Z\"}(xt,yt))):!rt||a<Math.min(.6*o,M)?(xt.l=0,xt.r=$,kt=\"y\",At.attr(\"d\",function(t,e){return\"M\"+(e-M-.5)+\",\"+(t.t-.5)+\"v-3h\"+(2*M+1)+\"v3ZM\"+(e-M-.5)+\",\"+(t.b+.5)+\"v3h\"+(2*M+1)+\"v-3Z\"}(xt,mt))):(kt=\"xy\",At.attr(\"d\",U(xt)));xt.w=xt.r-xt.l,xt.h=xt.b-xt.t,kt&&(Mt=!0),t._dragged=Mt,R(Tt,At,xt,_t,wt,bt),Pt(),t.emit(\"plotly_relayouting\",ut),wt=!0}function Pt(){ut={},\"xy\"!==kt&&\"x\"!==kt||(P(X,xt.l/$,xt.r/$,ut,tt.xaxes),Bt(\"x\",ut)),\"xy\"!==kt&&\"y\"!==kt||(P(Z,(Q-xt.b)/Q,(Q-xt.t)/Q,ut,tt.yaxes),Bt(\"y\",ut))}function Ot(){if(Math.min(xt.h,xt.w)<2*A)return B(t);Pt(),B(t),jt(),N(t)}St.prepFn=function(e,r,n){var a=St.dragmode,o=t._fullLayout.dragmode;o!==a&&(St.dragmode=o),dt(),it||(ft?e.shiftKey?\"pan\"===o?o=\"zoom\":j(o)||(o=\"pan\"):e.ctrlKey&&(o=\"pan\"):o=\"pan\"),St.minDrag=\"lasso\"===o?1:void 0,j(o)?(St.xaxes=X,St.yaxes=Z,b(e,r,n,St,o)):(St.clickFn=Ct,j(a)&&Et(),it||(\"zoom\"===o?(St.moveFn=Lt,St.doneFn=Ot,St.minDrag=1,function(e,r,n){var a=vt.getBoundingClientRect();mt=r-a.left,yt=n-a.top,xt={l:mt,r:mt,w:0,t:yt,b:yt,h:0},bt=t._hmpixcount?t._hmlumcount/t._hmpixcount:i(t._fullLayout.plot_bgcolor).getLuminance(),wt=!1,kt=\"xy\",Mt=!1,Tt=I(ht,bt,J,K,_t=\"M0,0H\"+$+\"V\"+Q+\"H0V0\"),At=D(ht,J,K)}(0,r,n)):\"pan\"===o&&(St.moveFn=Ft,St.doneFn=jt))),t._fullLayout._redrag=function(){var e=t._dragdata;e&&e.element===vt&&(j(t._fullLayout.dragmode)||(dt(),Ut([0,0,$,Q]),St.moveFn(e.dx,e.dy)))}},d.init(St);var zt=[0,0,$,Q],It=null,Dt=T.REDRAWDELAY,Rt=e.mainplot?t._fullLayout._plots[e.mainplot]:e;function Ft(e,r){if(!t._transitioningWithDuration){if(t._fullLayout._replotting=!0,\"ew\"===rt||\"ns\"===nt)return rt&&(O(X,e),Bt(\"x\")),nt&&(O(Z,r),Bt(\"y\")),Ut([rt?-e:0,nt?-r:0,$,Q]),Nt(),void t.emit(\"plotly_relayouting\",ut);if(tt.isSubplotConstrained&&rt&&nt){var n=\"w\"===rt==(\"n\"===nt)?1:-1,i=(e/$+n*r/Q)/2;e=i*$,r=n*i*Q}\"w\"===rt?e=l(X,0,e):\"e\"===rt?e=l(X,1,-e):rt||(e=0),\"n\"===nt?r=l(Z,1,r):\"s\"===nt?r=l(Z,0,-r):nt||(r=0);var a=\"w\"===rt?e:0,o=\"n\"===nt?r:0;if(tt.isSubplotConstrained){var s;if(!rt&&1===nt.length){for(s=0;s<X.length;s++)X[s].range=X[s]._r.slice(),k(X[s],1-r/Q);a=(e=r*$/Q)/2}if(!nt&&1===rt.length){for(s=0;s<Z.length;s++)Z[s].range=Z[s]._r.slice(),k(Z[s],1-e/$);o=(r=e*Q/$)/2}}Bt(\"x\"),Bt(\"y\"),Ut([a,o,$-e,Q-r]),Nt(),t.emit(\"plotly_relayouting\",ut)}function l(t,e,r){for(var n,i,a=1-e,o=0;o<t.length;o++){var s=t[o];if(!s.fixedrange){n=s,i=s._rl[a]+(s._rl[e]-s._rl[a])/z(r/s._length);var l=s.l2r(i);!1!==l&&void 0!==l&&(s.range[e]=l)}}return n._length*(n._rl[e]-i)/(n._rl[e]-n._rl[a])}}function Bt(t,e){for(var r=et.isSubplotConstrained?{x:Z,y:X}[t]:et[t+\"axes\"],n=et.isSubplotConstrained?{x:X,y:Z}[t]:[],i=0;i<r.length;i++){var a=r[i],o=a._id,s=et.xLinks[o]||et.yLinks[o],l=n[0]||Y[s]||W[s];l&&(e?(e[a._name+\".range[0]\"]=e[l._name+\".range[0]\"],e[a._name+\".range[1]\"]=e[l._name+\".range[1]\"]):a.range=l.range.slice())}}function Nt(){var e,r=[];function n(t){for(e=0;e<t.length;e++)t[e].fixedrange||r.push(t[e]._id)}for(at&&(n(X),n(tt.xaxes),n(et.xaxes)),ot&&(n(Z),n(tt.yaxes),n(et.yaxes)),ut={},e=0;e<r.length;e++){var i=r[e],a=x(t,i);f.drawOne(t,a,{skipTitle:!0}),ut[a._name+\".range[0]\"]=a.range[0],ut[a._name+\".range[1]\"]=a.range[1]}f.redrawComponents(t,r)}function jt(){Ut([0,0,$,Q]),s.syncOrAsync([y.previousPromises,function(){t._fullLayout._replotting=!1,o.call(\"_guiRelayout\",t,ut)}],t)}function Ut(e){var r,n,i,a,l=t._fullLayout,c=l._plots,h=l._subplots.cartesian;if(lt&&o.subplotsRegistry.splom.drag(t),st)for(r=0;r<h.length;r++)if(i=(n=c[h[r]]).xaxis,a=n.yaxis,n._scene){var f=s.simpleMap(i.range,i.r2l),p=s.simpleMap(a.range,a.r2l);n._scene.update({range:[f[0],p[0],f[1],p[1]]})}if((lt||st)&&(v(t),m(t)),ct){var d=e[2]/F._length,g=e[3]/G._length;for(r=0;r<h.length;r++){i=(n=c[h[r]]).xaxis,a=n.yaxis;var y,x,b,_,w=at&&!i.fixedrange&&Y[i._id],k=ot&&!a.fixedrange&&W[a._id];if(w?(y=d,b=E?e[0]:Ht(i,y)):et.xaHash[i._id]?(y=d,b=e[0]*i._length/F._length):et.yaHash[i._id]?(y=g,b=\"ns\"===nt?-e[1]*i._length/G._length:Ht(i,y,{n:\"top\",s:\"bottom\"}[nt])):b=qt(i,y=Vt(i,d,g)),k?(x=g,_=S?e[1]:Ht(a,x)):et.yaHash[a._id]?(x=g,_=e[1]*a._length/G._length):et.xaHash[a._id]?(x=d,_=\"ew\"===rt?-e[0]*a._length/F._length:Ht(a,x,{e:\"right\",w:\"left\"}[rt])):_=qt(a,x=Vt(a,d,g)),y||x){y||(y=1),x||(x=1);var T=i._offset-b/y,A=a._offset-_/x;n.clipRect.call(u.setTranslate,b,_).call(u.setScale,y,x),n.plot.call(u.setTranslate,T,A).call(u.setScale,1/y,1/x),y===n.xScaleFactor&&x===n.yScaleFactor||(u.setPointGroupScale(n.zoomScalePts,y,x),u.setTextPointsScale(n.zoomScaleTxt,y,x)),u.hideOutsideRangePoints(n.clipOnAxisFalseTraces,n),n.xScaleFactor=y,n.yScaleFactor=x}}}}function Vt(t,e,r){return t.fixedrange?0:at&&tt.xaHash[t._id]?e:ot&&(tt.isSubplotConstrained?tt.xaHash:tt.yaHash)[t._id]?r:0}function qt(t,e){return e?(t.range=t._r.slice(),k(t,e),Ht(t,e)):0}function Ht(t,e,r){return t._length*(1-e)*g[r||t.constraintoward||\"middle\"]}return S.length*E.length!=1&&q(vt,function(e){if(t._context._scrollZoom.cartesian||t._fullLayout._enablescrollzoom){if(Et(),t._transitioningWithDuration)return e.preventDefault(),void e.stopPropagation();dt(),clearTimeout(It);var r=-e.deltaY;if(isFinite(r)||(r=e.wheelDelta/10),isFinite(r)){var n,i=Math.exp(-Math.min(Math.max(r,-20),20)/200),a=Rt.draglayer.select(\".nsewdrag\").node().getBoundingClientRect(),o=(e.clientX-a.left)/a.width,l=(a.bottom-e.clientY)/a.height;if(at){for(E||(o=.5),n=0;n<X.length;n++)c(X[n],o,i);Bt(\"x\"),zt[2]*=i,zt[0]+=zt[2]*o*(1/i-1)}if(ot){for(S||(l=.5),n=0;n<Z.length;n++)c(Z[n],l,i);Bt(\"y\"),zt[3]*=i,zt[1]+=zt[3]*(1-l)*(1/i-1)}Ut(zt),Nt(),t.emit(\"plotly_relayouting\",ut),It=setTimeout(function(){zt=[0,0,$,Q],jt()},Dt),e.preventDefault()}else s.log(\"Did not find wheel motion attributes: \",e)}function c(t,e,r){if(!t.fixedrange){var n=s.simpleMap(t.range,t.r2l),i=n[0]+(n[1]-n[0])*e;t.range=n.map(function(e){return t.l2r(i+(e-i)*r)})}}}),vt},makeDragger:E,makeRectDragger:C,makeZoombox:I,makeCorners:D,updateZoombox:R,xyCorners:U,transitionZoombox:F,removeZoombox:B,showDoubleClickNotifier:N,attachWheelEventHandler:q}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/clear_gl_canvases\":704,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../plot_api/subroutines\":758,\"../../registry\":847,\"../plots\":828,\"./axes\":767,\"./axis_ids\":770,\"./constants\":773,\"./scale_zoom\":783,\"./select\":784,d3:163,\"has-passive-events\":411,tinycolor2:537}],776:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/fx\"),a=t(\"../../components/dragelement\"),o=t(\"../../lib/setcursor\"),s=t(\"./dragbox\").makeDragBox,l=t(\"./constants\").DRAGGERSIZE;r.initInteractions=function(t){var e=t._fullLayout;if(t._context.staticPlot)n.select(t).selectAll(\".drag\").remove();else if(e._has(\"cartesian\")||e._has(\"splom\")){Object.keys(e._plots||{}).sort(function(t,r){if((e._plots[t].mainplot&&!0)===(e._plots[r].mainplot&&!0)){var n=t.split(\"y\"),i=r.split(\"y\");return n[0]===i[0]?Number(n[1]||1)-Number(i[1]||1):Number(n[0]||1)-Number(i[0]||1)}return e._plots[t].mainplot?1:-1}).forEach(function(r){var n=e._plots[r],o=n.xaxis,c=n.yaxis;if(!n.mainplot){var u=s(t,n,o._offset,c._offset,o._length,c._length,\"ns\",\"ew\");u.onmousemove=function(e){t._fullLayout._rehover=function(){t._fullLayout._hoversubplot===r&&i.hover(t,e,r)},i.hover(t,e,r),t._fullLayout._lasthover=u,t._fullLayout._hoversubplot=r},u.onmouseout=function(e){t._dragging||(t._fullLayout._hoversubplot=null,a.unhover(t,e))},t._context.showAxisDragHandles&&(s(t,n,o._offset-l,c._offset-l,l,l,\"n\",\"w\"),s(t,n,o._offset+o._length,c._offset-l,l,l,\"n\",\"e\"),s(t,n,o._offset-l,c._offset+c._length,l,l,\"s\",\"w\"),s(t,n,o._offset+o._length,c._offset+c._length,l,l,\"s\",\"e\"))}if(t._context.showAxisDragHandles){if(r===o._mainSubplot){var h=o._mainLinePosition;\"top\"===o.side&&(h-=l),s(t,n,o._offset+.1*o._length,h,.8*o._length,l,\"\",\"ew\"),s(t,n,o._offset,h,.1*o._length,l,\"\",\"w\"),s(t,n,o._offset+.9*o._length,h,.1*o._length,l,\"\",\"e\")}if(r===c._mainSubplot){var f=c._mainLinePosition;\"right\"!==c.side&&(f-=l),s(t,n,f,c._offset+.1*c._length,l,.8*c._length,\"ns\",\"\"),s(t,n,f,c._offset+.9*c._length,l,.1*c._length,\"s\",\"\"),s(t,n,f,c._offset,l,.1*c._length,\"n\",\"\")}}});var o=e._hoverlayer.node();o.onmousemove=function(r){r.target=t._fullLayout._lasthover,i.hover(t,r,e._hoversubplot)},o.onclick=function(e){e.target=t._fullLayout._lasthover,i.click(t,e)},o.onmousedown=function(e){t._fullLayout._lasthover.onmousedown(e)},r.updateFx(t)}},r.updateFx=function(t){var e=t._fullLayout,r=\"pan\"===e.dragmode?\"move\":\"crosshair\";o(e._draggers,r)}},{\"../../components/dragelement\":611,\"../../components/fx\":632,\"../../lib/setcursor\":739,\"./constants\":773,\"./dragbox\":775,d3:163}],777:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t){return function(e,r){var a=e[t];if(Array.isArray(a))for(var o=n.subplotsRegistry.cartesian,s=o.idRegex,l=r._subplots,c=l.xaxis,u=l.yaxis,h=l.cartesian,f=r._has(\"cartesian\")||r._has(\"gl2d\"),p=0;p<a.length;p++){var d=a[p];if(i.isPlainObject(d)){var g=d.xref,v=d.yref,m=s.x.test(g),y=s.y.test(v);if(m||y){f||i.pushUnique(r._basePlotModules,o);var x=!1;m&&-1===c.indexOf(g)&&(c.push(g),x=!0),y&&-1===u.indexOf(v)&&(u.push(v),x=!0),x&&m&&y&&h.push(g+v)}}}}}},{\"../../lib\":719,\"../../registry\":847}],778:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../plots\"),s=t(\"../../components/drawing\"),l=t(\"../get_data\").getModuleCalcData,c=t(\"./axis_ids\"),u=t(\"./constants\"),h=t(\"../../constants/xmlns_namespaces\"),f=a.ensureSingle;function p(t,e,r){return a.ensureSingle(t,e,r,function(t){t.datum(r)})}function d(t,e,r,a,o){for(var c,h,f,p=u.traceLayerClasses,d=t._fullLayout,g=d._modules,v=[],m=[],y=0;y<g.length;y++){var x=(c=g[y]).name,b=i.modules[x].categories;if(b.svg){var _=c.layerName||x+\"layer\",w=c.plot;f=(h=l(r,w))[0],r=h[1],f.length&&v.push({i:p.indexOf(_),className:_,plotMethod:w,cdModule:f}),b.zoomScale&&m.push(\".\"+_)}}v.sort(function(t,e){return t.i-e.i});var k=e.plot.selectAll(\"g.mlayer\").data(v,function(t){return t.className});if(k.enter().append(\"g\").attr(\"class\",function(t){return t.className}).classed(\"mlayer\",!0).classed(\"rangeplot\",e.isRangePlot),k.exit().remove(),k.order(),k.each(function(r){var i=n.select(this),l=r.className;r.plotMethod(t,e,r.cdModule,i,a,o),-1===u.clipOnAxisFalseQuery.indexOf(\".\"+l)&&s.setClipUrl(i,e.layerClipId,t)}),d._has(\"scattergl\")&&(c=i.getModule(\"scattergl\"),f=l(r,c)[0],c.plot(t,e,f)),!t._context.staticPlot&&(e._hasClipOnAxisFalse&&(e.clipOnAxisFalseTraces=e.plot.selectAll(u.clipOnAxisFalseQuery.join(\",\")).selectAll(\".trace\")),m.length)){var T=e.plot.selectAll(m.join(\",\")).selectAll(\".trace\");e.zoomScalePts=T.selectAll(\"path.point\"),e.zoomScaleTxt=T.selectAll(\".textpoint\")}}function g(t,e){var r=e.plotgroup,n=e.id,i=u.layerValue2layerClass[e.xaxis.layer],a=u.layerValue2layerClass[e.yaxis.layer],o=t._fullLayout._hasOnlyLargeSploms;if(e.mainplot){var s=e.mainplotinfo,l=s.plotgroup,h=n+\"-x\",d=n+\"-y\";e.gridlayer=s.gridlayer,e.zerolinelayer=s.zerolinelayer,f(s.overlinesBelow,\"path\",h),f(s.overlinesBelow,\"path\",d),f(s.overaxesBelow,\"g\",h),f(s.overaxesBelow,\"g\",d),e.plot=f(s.overplot,\"g\",n),f(s.overlinesAbove,\"path\",h),f(s.overlinesAbove,\"path\",d),f(s.overaxesAbove,\"g\",h),f(s.overaxesAbove,\"g\",d),e.xlines=l.select(\".overlines-\"+i).select(\".\"+h),e.ylines=l.select(\".overlines-\"+a).select(\".\"+d),e.xaxislayer=l.select(\".overaxes-\"+i).select(\".\"+h),e.yaxislayer=l.select(\".overaxes-\"+a).select(\".\"+d)}else if(o)e.xlines=f(r,\"path\",\"xlines-above\"),e.ylines=f(r,\"path\",\"ylines-above\"),e.xaxislayer=f(r,\"g\",\"xaxislayer-above\"),e.yaxislayer=f(r,\"g\",\"yaxislayer-above\");else{var g=f(r,\"g\",\"layer-subplot\");e.shapelayer=f(g,\"g\",\"shapelayer\"),e.imagelayer=f(g,\"g\",\"imagelayer\"),e.gridlayer=f(r,\"g\",\"gridlayer\"),e.zerolinelayer=f(r,\"g\",\"zerolinelayer\"),f(r,\"path\",\"xlines-below\"),f(r,\"path\",\"ylines-below\"),e.overlinesBelow=f(r,\"g\",\"overlines-below\"),f(r,\"g\",\"xaxislayer-below\"),f(r,\"g\",\"yaxislayer-below\"),e.overaxesBelow=f(r,\"g\",\"overaxes-below\"),e.plot=f(r,\"g\",\"plot\"),e.overplot=f(r,\"g\",\"overplot\"),e.xlines=f(r,\"path\",\"xlines-above\"),e.ylines=f(r,\"path\",\"ylines-above\"),e.overlinesAbove=f(r,\"g\",\"overlines-above\"),f(r,\"g\",\"xaxislayer-above\"),f(r,\"g\",\"yaxislayer-above\"),e.overaxesAbove=f(r,\"g\",\"overaxes-above\"),e.xlines=r.select(\".xlines-\"+i),e.ylines=r.select(\".ylines-\"+a),e.xaxislayer=r.select(\".xaxislayer-\"+i),e.yaxislayer=r.select(\".yaxislayer-\"+a)}o||(p(e.gridlayer,\"g\",e.xaxis._id),p(e.gridlayer,\"g\",e.yaxis._id),e.gridlayer.selectAll(\"g\").map(function(t){return t[0]}).sort(c.idSort)),e.xlines.style(\"fill\",\"none\").classed(\"crisp\",!0),e.ylines.style(\"fill\",\"none\").classed(\"crisp\",!0)}function v(t,e){if(t){var r={};for(var i in t.each(function(t){var i=t[0];n.select(this).remove(),m(i,e),r[i]=!0}),e._plots)for(var a=e._plots[i].overlays||[],o=0;o<a.length;o++){var s=a[o];r[s.id]&&s.plot.selectAll(\".trace\").remove()}}}function m(t,e){e._draggers.selectAll(\"g.\"+t).remove(),e._defs.select(\"#clip\"+e._uid+t+\"plot\").remove()}r.name=\"cartesian\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=u.idRegex,r.attrRegex=u.attrRegex,r.attributes=t(\"./attributes\"),r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.transitionAxes=t(\"./transition_axes\"),r.finalizeSubplots=function(t,e){var r,n,i,o=e._subplots,s=o.xaxis,l=o.yaxis,h=o.cartesian,f=h.concat(o.gl2d||[]),p={},d={};for(r=0;r<f.length;r++){var g=f[r].split(\"y\");p[g[0]]=1,d[\"y\"+g[1]]=1}for(r=0;r<s.length;r++)p[n=s[r]]||(i=(t[c.id2name(n)]||{}).anchor,u.idRegex.y.test(i)||(i=\"y\"),h.push(n+i),f.push(n+i),d[i]||(d[i]=1,a.pushUnique(l,i)));for(r=0;r<l.length;r++)d[i=l[r]]||(n=(t[c.id2name(i)]||{}).anchor,u.idRegex.x.test(n)||(n=\"x\"),h.push(n+i),f.push(n+i),p[n]||(p[n]=1,a.pushUnique(s,n)));if(!f.length){for(var v in n=\"\",i=\"\",t){if(u.attrRegex.test(v))\"x\"===v.charAt(0)?(!n||+v.substr(5)<+n.substr(5))&&(n=v):(!i||+v.substr(5)<+i.substr(5))&&(i=v)}n=n?c.name2id(n):\"x\",i=i?c.name2id(i):\"y\",s.push(n),l.push(i),h.push(n+i)}},r.plot=function(t,e,r,n){var i,a=t._fullLayout,o=a._subplots.cartesian,s=t.calcdata;if(!Array.isArray(e))for(e=[],i=0;i<s.length;i++)e.push(i);for(i=0;i<o.length;i++){for(var l,c=o[i],u=a._plots[c],h=[],f=0;f<s.length;f++){var p=s[f],g=p[0].trace;g.xaxis+g.yaxis===c&&((-1!==e.indexOf(g.index)||g.carpet)&&(l&&l[0].trace.xaxis+l[0].trace.yaxis===c&&-1!==[\"tonextx\",\"tonexty\",\"tonext\"].indexOf(g.fill)&&-1===h.indexOf(l)&&h.push(l),h.push(p)),l=p)}d(t,u,h,r,n)}},r.clean=function(t,e,r,n){var i,a,o,s=n._plots||{},l=e._plots||{},u=n._subplots||{};if(n._hasOnlyLargeSploms&&!e._hasOnlyLargeSploms)for(o in s)(i=s[o]).plotgroup&&i.plotgroup.remove();var h=n._has&&n._has(\"gl\"),f=e._has&&e._has(\"gl\");if(h&&!f)for(o in s)(i=s[o])._scene&&i._scene.destroy();if(u.xaxis&&u.yaxis){var p=c.listIds({_fullLayout:n});for(a=0;a<p.length;a++){var d=p[a];e[c.id2name(d)]||n._infolayer.selectAll(\".g-\"+d+\"title\").remove()}}var g=n._has&&n._has(\"cartesian\"),y=e._has&&e._has(\"cartesian\");if(g&&!y)v(n._cartesianlayer.selectAll(\".subplot\"),n),n._defs.selectAll(\".axesclip\").remove(),delete n._axisConstraintGroups;else if(u.cartesian)for(a=0;a<u.cartesian.length;a++){var x=u.cartesian[a];if(!l[x]){var b=\".\"+x+\",.\"+x+\"-x,.\"+x+\"-y\";n._cartesianlayer.selectAll(b).remove(),m(x,n)}}},r.drawFramework=function(t){var e=t._fullLayout,r=function(t){var e,r,n,i,a,o,s=t._fullLayout,l=s._subplots.cartesian,c=l.length,u=[],h=[];for(e=0;e<c;e++){n=l[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var f=a._mainAxis,p=o._mainAxis,d=f._id+p._id,g=s._plots[d];i.overlays=[],d!==n&&g?(i.mainplot=d,i.mainplotinfo=g,h.push(n)):(i.mainplot=void 0,i.mainPlotinfo=void 0,u.push(n))}for(e=0;e<h.length;e++)n=h[e],(i=s._plots[n]).mainplotinfo.overlays.push(i);var v=u.concat(h),m=new Array(c);for(e=0;e<c;e++){n=v[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var y=[n,a.layer,o.layer,a.overlaying||\"\",o.overlaying||\"\"];for(r=0;r<i.overlays.length;r++)y.push(i.overlays[r].id);m[e]=y}return m}(t),i=e._cartesianlayer.selectAll(\".subplot\").data(r,String);i.enter().append(\"g\").attr(\"class\",function(t){return\"subplot \"+t[0]}),i.order(),i.exit().call(v,e),i.each(function(r){var i=r[0],a=e._plots[i];a.plotgroup=n.select(this),g(t,a),a.draglayer=f(e._draggers,\"g\",i)})},r.rangePlot=function(t,e,r){g(t,e),d(t,e,r),o.style(t)},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter(function(t,e){return e===r.size()-1}).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each(function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:h.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})})},r.updateFx=t(\"./graph_interact\").updateFx},{\"../../components/drawing\":614,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../registry\":847,\"../get_data\":802,\"../plots\":828,\"./attributes\":765,\"./axis_ids\":770,\"./constants\":773,\"./graph_interact\":776,\"./layout_attributes\":779,\"./layout_defaults\":780,\"./transition_axes\":789,d3:163}],779:[function(t,e,r){\"use strict\";var n=t(\"../font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray,l=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").DATE_FORMAT_LINK,t(\"./constants\"));e.exports={visible:{valType:\"boolean\",editType:\"plot\"},color:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},title:{text:{valType:\"string\",editType:\"ticks\"},font:n({editType:\"ticks\"}),editType:\"ticks\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"log\",\"date\",\"category\",\"multicategory\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"axrange\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0},{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0}],editType:\"axrange\",impliedEdits:{autorange:!1},anim:!0},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},scaleanchor:{valType:\"enumerated\",values:[l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},scaleratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},constrain:{valType:\"enumerated\",values:[\"range\",\"domain\"],dflt:\"range\",editType:\"plot\"},constraintoward:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\",\"top\",\"middle\",\"bottom\"],editType:\"plot\"},matches:{valType:\"enumerated\",values:[l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"calc\"},tickmode:{valType:\"enumerated\",values:[\"auto\",\"linear\",\"array\"],editType:\"ticks\",impliedEdits:{tick0:void 0,dtick:void 0}},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"ticks\"},tick0:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},dtick:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},tickvals:{valType:\"data_array\",editType:\"ticks\"},ticktext:{valType:\"data_array\",editType:\"ticks\"},ticks:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"\"],editType:\"ticks\"},tickson:{valType:\"enumerated\",values:[\"labels\",\"boundaries\"],dflt:\"labels\",editType:\"ticks\"},mirror:{valType:\"enumerated\",values:[!0,\"ticks\",!1,\"all\",\"allticks\"],dflt:!1,editType:\"ticks+layoutstyle\"},ticklen:{valType:\"number\",min:0,dflt:5,editType:\"ticks\"},tickwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},tickcolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},showticklabels:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},automargin:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},showspikes:{valType:\"boolean\",dflt:!1,editType:\"modebar\"},spikecolor:{valType:\"color\",dflt:null,editType:\"none\"},spikethickness:{valType:\"number\",dflt:3,editType:\"none\"},spikedash:o({},a,{dflt:\"dash\",editType:\"none\"}),spikemode:{valType:\"flaglist\",flags:[\"toaxis\",\"across\",\"marker\"],dflt:\"toaxis\",editType:\"none\"},spikesnap:{valType:\"enumerated\",values:[\"data\",\"cursor\"],dflt:\"data\",editType:\"none\"},tickfont:n({editType:\"ticks\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"ticks\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"ticks\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"ticks\"},tickformatstops:s(\"tickformatstop\",{enabled:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dtickrange:{valType:\"info_array\",items:[{valType:\"any\",editType:\"ticks\"},{valType:\"any\",editType:\"ticks\"}],editType:\"ticks\"},value:{valType:\"string\",dflt:\"\",editType:\"ticks\"},editType:\"ticks\"}),hoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},showline:{valType:\"boolean\",dflt:!1,editType:\"ticks+layoutstyle\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"layoutstyle\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks+layoutstyle\"},showgrid:{valType:\"boolean\",editType:\"ticks\"},gridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"ticks\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},zeroline:{valType:\"boolean\",editType:\"ticks\"},zerolinecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},zerolinewidth:{valType:\"number\",dflt:1,editType:\"ticks\"},showdividers:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dividercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},dividerwidth:{valType:\"number\",dflt:1,editType:\"ticks\"},anchor:{valType:\"enumerated\",values:[\"free\",l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},side:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],editType:\"plot\"},overlaying:{valType:\"enumerated\",values:[\"free\",l.idRegex.x.toString(),l.idRegex.y.toString()],editType:\"plot\"},layer:{valType:\"enumerated\",values:[\"above traces\",\"below traces\"],dflt:\"above traces\",editType:\"plot\"},domain:{valType:\"info_array\",items:[{valType:\"number\",min:0,max:1,editType:\"plot\"},{valType:\"number\",min:0,max:1,editType:\"plot\"}],dflt:[0,1],editType:\"plot\"},position:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\",\"total ascending\",\"total descending\",\"min ascending\",\"min descending\",\"max ascending\",\"max descending\",\"sum ascending\",\"sum descending\",\"mean ascending\",\"mean descending\",\"median ascending\",\"median descending\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{autotick:{valType:\"boolean\",editType:\"ticks\"},title:{valType:\"string\",editType:\"ticks\"},titlefont:n({editType:\"ticks\"})}}},{\"../../components/color/attributes\":592,\"../../components/drawing/attributes\":613,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../font_attributes\":793,\"./constants\":773}],780:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../layout_attributes\"),s=t(\"./layout_attributes\"),l=t(\"./type_defaults\"),c=t(\"./axis_defaults\"),u=t(\"./constraints\").handleConstraintDefaults,h=t(\"./position_defaults\"),f=t(\"./axis_ids\"),p=f.id2name,d=f.name2id,g=t(\"../../registry\"),v=g.traceIs,m=g.getComponentMethod;function y(t,e,r){Array.isArray(t[e])?t[e].push(r):t[e]=[r]}e.exports=function(t,e,r){var f,g,x={},b={},_={},w={},k={},T={},A={},M={},S={};for(f=0;f<r.length;f++){var E=r[f];if(v(E,\"cartesian\")||v(E,\"gl2d\")){var C,L;if(E.xaxis)y(x,C=p(E.xaxis),E);else if(E.xaxes)for(g=0;g<E.xaxes.length;g++)y(x,p(E.xaxes[g]),E);if(E.yaxis)y(x,L=p(E.yaxis),E);else if(E.yaxes)for(g=0;g<E.yaxes.length;g++)y(x,p(E.yaxes[g]),E);if(\"funnel\"===E.type?\"h\"===E.orientation?(C&&(b[C]=!0),L&&(A[L]=!0)):L&&(_[L]=!0):(L&&(k[L]=!0,T[L]=!0),v(E,\"carpet\")&&(\"carpet\"!==E.type||E._cheater)||C&&(w[C]=!0)),\"carpet\"===E.type&&E._cheater&&C&&(b[C]=!0),v(E,\"2dMap\")&&(M[C]=!0,M[L]=!0),v(E,\"oriented\"))S[\"h\"===E.orientation?L:C]=!0}}var P=e._subplots,O=P.xaxis,z=P.yaxis,I=n.simpleMap(O,p),D=n.simpleMap(z,p),R=I.concat(D),F=i.background;O.length&&z.length&&(F=n.coerce(t,e,o,\"plot_bgcolor\"));var B,N,j,U,V=i.combine(F,e.paper_bgcolor);function q(t,e){return n.coerce(j,U,s,t,e)}function H(t,e){return n.coerce2(j,U,s,t,e)}function G(t){return\"x\"===t?z:O}var Y={x:G(\"x\"),y:G(\"y\")},W=Y.x.concat(Y.y);function X(e,r){for(var n=\"x\"===e?I:D,i=[],a=0;a<n.length;a++){var o=n[a];o===r||(t[o]||{}).overlaying||i.push(d(o))}return i}for(f=0;f<R.length;f++){N=(B=R[f]).charAt(0),n.isPlainObject(t[B])||(t[B]={}),j=t[B],U=a.newContainer(e,B,N+\"axis\");var Z=x[B]||[];U._traceIndices=Z.map(function(t){return t._expandedIndex}),U._annIndices=[],U._shapeIndices=[],U._imgIndices=[],U._subplotsWith=[],U._counterAxes=[],U._name=U._attr=B;var J=U._id=d(B),K=X(N,B),$=\"x\"===N&&!w[B]&&b[B]||\"y\"===N&&!k[B]&&_[B],Q=\"y\"===N&&!T[B]&&A[B],tt={letter:N,font:e.font,outerTicks:M[B],showGrid:!S[B],data:Z,bgColor:V,calendar:e.calendar,automargin:!0,visibleDflt:$,reverseDflt:Q,splomStash:((e._splomAxes||{})[N]||{})[J]};q(\"uirevision\",e.uirevision),l(j,U,q,tt),c(j,U,q,tt,e);var et=H(\"spikecolor\"),rt=H(\"spikethickness\"),nt=H(\"spikedash\"),it=H(\"spikemode\"),at=H(\"spikesnap\");q(\"showspikes\",!!(et||rt||nt||it||at))||(delete U.spikecolor,delete U.spikethickness,delete U.spikedash,delete U.spikemode,delete U.spikesnap),h(j,U,q,{letter:N,counterAxes:Y[N],overlayableAxes:K,grid:e.grid}),U._input=j}var ot=m(\"rangeslider\",\"handleDefaults\"),st=m(\"rangeselector\",\"handleDefaults\");for(f=0;f<I.length;f++)B=I[f],j=t[B],U=e[B],ot(t,e,B),\"date\"===U.type&&st(j,U,e,D,U.calendar),q(\"fixedrange\");for(f=0;f<D.length;f++){B=D[f],j=t[B],U=e[B];var lt=e[p(U.anchor)];q(\"fixedrange\",m(\"rangeslider\",\"isVisible\")(lt))}var ct=e._axisConstraintGroups=[],ut=e._axisMatchGroups=[];for(f=0;f<R.length;f++)N=(B=R[f]).charAt(0),j=t[B],U=e[B],u(j,U,q,W,e);for(f=0;f<ut.length;f++){var ht,ft=ut[f],pt=null,dt=null;for(ht in ft)(U=e[p(ht)]).matches||(pt=U.range,dt=U.autorange);if(null===pt||null===dt)for(ht in ft){pt=(U=e[p(ht)]).range,dt=U.autorange;break}for(ht in ft)(U=e[p(ht)]).matches&&(U.range=pt.slice(),U.autorange=dt),U._matchGroup=ft;if(ct.length)for(ht in ft)for(g=0;g<ct.length;g++){var gt=ct[g];for(var vt in gt)ht===vt&&(n.warn(\"Axis \"+vt+\" is set with both a *scaleanchor* and *matches* constraint; ignoring the scale constraint.\"),delete gt[vt],Object.keys(gt).length<2&&ct.splice(g,1))}}}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../registry\":847,\"../layout_attributes\":819,\"./axis_defaults\":769,\"./axis_ids\":770,\"./constraints\":774,\"./layout_attributes\":779,\"./position_defaults\":782,\"./type_defaults\":790}],781:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../components/color/attributes\").lightFraction,a=t(\"../../lib\");e.exports=function(t,e,r,o){var s=(o=o||{}).dfltColor;function l(r,n){return a.coerce2(t,e,o.attributes,r,n)}var c=l(\"linecolor\",s),u=l(\"linewidth\");r(\"showline\",o.showLine||!!c||!!u)||(delete e.linecolor,delete e.linewidth);var h=l(\"gridcolor\",n(s,o.bgColor,o.blend||i).toRgbString()),f=l(\"gridwidth\");if(r(\"showgrid\",o.showGrid||!!h||!!f)||(delete e.gridcolor,delete e.gridwidth),!o.noZeroLine){var p=l(\"zerolinecolor\",s),d=l(\"zerolinewidth\");r(\"zeroline\",o.showGrid||!!p||!!d)||(delete e.zerolinecolor,delete e.zerolinewidth)}}},{\"../../components/color/attributes\":592,\"../../lib\":719,tinycolor2:537}],782:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o,s,l,c,u=a.counterAxes||[],h=a.overlayableAxes||[],f=a.letter,p=a.grid;p&&(s=p._domains[f][p._axisMap[e._id]],o=p._anchors[e._id],s&&(l=p[f+\"side\"].split(\" \")[0],c=p.domain[f][\"right\"===l||\"top\"===l?1:0])),s=s||[0,1],o=o||(n(t.position)?\"free\":u[0]||\"free\"),l=l||(\"x\"===f?\"bottom\":\"left\"),c=c||0,\"free\"===i.coerce(t,e,{anchor:{valType:\"enumerated\",values:[\"free\"].concat(u),dflt:o}},\"anchor\")&&r(\"position\",c),i.coerce(t,e,{side:{valType:\"enumerated\",values:\"x\"===f?[\"bottom\",\"top\"]:[\"left\",\"right\"],dflt:l}},\"side\");var d=!1;if(h.length&&(d=i.coerce(t,e,{overlaying:{valType:\"enumerated\",values:[!1].concat(h),dflt:!1}},\"overlaying\")),!d){var g=r(\"domain\",s);g[0]>g[1]-1/4096&&(e.domain=s),i.noneOrAll(t.domain,e.domain,s)}return r(\"layer\"),e}},{\"../../lib\":719,\"fast-isnumeric\":225}],783:[function(t,e,r){\"use strict\";var n=t(\"../../constants/alignment\").FROM_BL;e.exports=function(t,e,r){void 0===r&&(r=n[t.constraintoward||\"center\"]);var i=[t.r2l(t.range[0]),t.r2l(t.range[1])],a=i[0]+(i[1]-i[0])*r;t.range=t._input.range=[t.l2r(a+(i[0]-a)*e),t.l2r(a+(i[1]-a)*e)]}},{\"../../constants/alignment\":688}],784:[function(t,e,r){\"use strict\";var n=t(\"polybooljs\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../../components/fx\"),s=t(\"../../lib\"),l=t(\"../../lib/polygon\"),c=t(\"../../lib/throttle\"),u=t(\"../../components/fx/helpers\").makeEventData,h=t(\"./axis_ids\").getFromId,f=t(\"../../lib/clear_gl_canvases\"),p=t(\"../../plot_api/subroutines\").redrawReglTraces,d=t(\"./constants\"),g=d.MINSELECT,v=l.filter,m=l.tester;function y(t){return t._id}function x(t,e,r,n,i,a,o){var s,l,c,u,h,f,p,d,g,v=e._hoverdata,m=e._fullLayout.clickmode.indexOf(\"event\")>-1,y=[];if(function(t){return t&&Array.isArray(t)&&!0!==t[0].hoverOnBox}(v)){k(t,e,a);var x=function(t,e){var r,n,i=t[0],a=-1,o=[];for(n=0;n<e.length;n++)if(r=e[n],i.fullData._expandedIndex===r.cd[0].trace._expandedIndex){if(!0===i.hoverOnBox)break;void 0!==i.pointNumber?a=i.pointNumber:void 0!==i.binNumber&&(a=i.binNumber,o=i.pointNumbers);break}return{pointNumber:a,pointNumbers:o,searchInfo:r}}(v,s=A(e,r,n,i));if(x.pointNumbers.length>0?function(t,e){var r,n,i,a=[];for(i=0;i<t.length;i++)(r=t[i]).cd[0].trace.selectedpoints&&r.cd[0].trace.selectedpoints.length>0&&a.push(r);if(1===a.length&&a[0]===e.searchInfo&&(n=e.searchInfo.cd[0].trace).selectedpoints.length===e.pointNumbers.length){for(i=0;i<e.pointNumbers.length;i++)if(n.selectedpoints.indexOf(e.pointNumbers[i])<0)return!1;return!0}return!1}(s,x):function(t){var e,r,n,i=0;for(n=0;n<t.length;n++)if(e=t[n],(r=e.cd[0].trace).selectedpoints){if(r.selectedpoints.length>1)return!1;if((i+=r.selectedpoints.length)>1)return!1}return 1===i}(s)&&(f=S(x))){for(o&&o.remove(),g=0;g<s.length;g++)(l=s[g])._module.selectPoints(l,!1);E(e,s),T(a),m&&e.emit(\"plotly_deselect\",null)}else{for(p=t.shiftKey&&(void 0!==f?f:S(x)),c=function(t,e,r){return{pointNumber:t,searchInfo:e,subtract:r}}(x.pointNumber,x.searchInfo,p),u=w(a.selectionDefs.concat([c])),g=0;g<s.length;g++)if(h=C(s[g]._module.selectPoints(s[g],u),s[g]),y.length)for(var b=0;b<h.length;b++)y.push(h[b]);else y=h;E(e,s,d={points:y}),c&&a&&a.selectionDefs.push(c),o&&M(a.mergedPolygons,o),m&&e.emit(\"plotly_selected\",d)}}}function b(t){return\"pointNumber\"in t&&\"searchInfo\"in t}function _(t){return{xmin:0,xmax:0,ymin:0,ymax:0,pts:[],contains:function(e,r,n,i){var a=t.searchInfo.cd[0].trace._expandedIndex;return i.cd[0].trace._expandedIndex===a&&n===t.pointNumber},isRect:!1,degenerate:!1,subtract:t.subtract}}function w(t){for(var e=[],r=b(t[0])?0:t[0][0][0],n=r,i=b(t[0])?0:t[0][0][1],a=i,o=0;o<t.length;o++)if(b(t[o]))e.push(_(t[o]));else{var s=l.tester(t[o]);s.subtract=t[o].subtract,e.push(s),r=Math.min(r,s.xmin),n=Math.max(n,s.xmax),i=Math.min(i,s.ymin),a=Math.max(a,s.ymax)}return{xmin:r,xmax:n,ymin:i,ymax:a,pts:[],contains:function(t,r,n,i){for(var a=!1,o=0;o<e.length;o++)e[o].contains(t,r,n,i)&&(a=!1===e[o].subtract);return a},isRect:!1,degenerate:!1}}function k(t,e,r){var n=e._fullLayout,i=r.plotinfo,a=n._lastSelectedSubplot&&n._lastSelectedSubplot===i.id,o=t.shiftKey||t.altKey;a&&o&&i.selection&&i.selection.selectionDefs&&!r.selectionDefs?(r.selectionDefs=i.selection.selectionDefs,r.mergedPolygons=i.selection.mergedPolygons):o&&i.selection||T(r),a||(L(e),n._lastSelectedSubplot=i.id)}function T(t){var e=t.plotinfo;e.selection={},e.selection.selectionDefs=t.selectionDefs=[],e.selection.mergedPolygons=t.mergedPolygons=[]}function A(t,e,r,n){var i,a,o,s=[],l=e.map(y),c=r.map(y);for(o=0;o<t.calcdata.length;o++)if(!0===(a=(i=t.calcdata[o])[0].trace).visible&&a._module&&a._module.selectPoints)if(!n||a.subplot!==n&&a.geo!==n)if(\"splom\"===a.type&&a._xaxes[l[0]]&&a._yaxes[c[0]]){var u=p(a._module,i,e[0],r[0]);u.scene=t._fullLayout._splomScenes[a.uid],s.push(u)}else if(\"sankey\"===a.type){var f=p(a._module,i,e[0],r[0]);s.push(f)}else{if(-1===l.indexOf(a.xaxis))continue;if(-1===c.indexOf(a.yaxis))continue;s.push(p(a._module,i,h(t,a.xaxis),h(t,a.yaxis)))}else s.push(p(a._module,i,e[0],r[0]));return s;function p(t,e,r,n){return{_module:t,cd:e,xaxis:r,yaxis:n}}}function M(t,e){var r,n,i=[];for(r=0;r<t.length;r++){var a=t[r];i.push(a.join(\"L\")+\"L\"+a[0])}n=t.length>0?\"M\"+i.join(\"M\")+\"Z\":\"M0,0Z\",e.attr(\"d\",n)}function S(t){var e=t.searchInfo.cd[0].trace,r=t.pointNumber,n=t.pointNumbers,i=n.length>0?n[0]:r;return!!e.selectedpoints&&e.selectedpoints.indexOf(i)>-1}function E(t,e,r){var n,a,o,s;for(n=0;n<e.length;n++){var l=e[n].cd[0].trace._fullInput,c=t._fullLayout._tracePreGUI[l.uid]||{};void 0===c.selectedpoints&&(c.selectedpoints=l._input.selectedpoints||null)}if(r){var u=r.points||[];for(n=0;n<e.length;n++)(s=e[n].cd[0].trace)._input.selectedpoints=s._fullInput.selectedpoints=[],s._fullInput!==s&&(s.selectedpoints=[]);for(n=0;n<u.length;n++){var h=u[n],d=h.data,g=h.fullData;h.pointIndices?([].push.apply(d.selectedpoints,h.pointIndices),s._fullInput!==s&&[].push.apply(g.selectedpoints,h.pointIndices)):(d.selectedpoints.push(h.pointIndex),s._fullInput!==s&&g.selectedpoints.push(h.pointIndex))}}else for(n=0;n<e.length;n++)delete(s=e[n].cd[0].trace).selectedpoints,delete s._input.selectedpoints,s._fullInput!==s&&delete s._fullInput.selectedpoints;var v=!1;for(n=0;n<e.length;n++){s=(o=(a=e[n]).cd)[0].trace,i.traceIs(s,\"regl\")&&(v=!0);var m=a._module,y=m.styleOnSelect||m.style;y&&(y(t,o,o[0].node3),o[0].nodeRangePlot3&&y(t,o,o[0].nodeRangePlot3))}v&&(f(t),p(t))}function C(t,e){if(Array.isArray(t))for(var r=e.cd,n=e.cd[0].trace,i=0;i<t.length;i++)t[i]=u(t[i],n,r);return t}function L(t){var e=(t._fullLayout||{})._zoomlayer;e&&e.selectAll(\".select-outline\").remove()}e.exports={prepSelect:function(t,e,r,i,l){var u,h,f,p,y,b,_,S=i.gd,L=S._fullLayout,P=L._zoomlayer,O=i.element.getBoundingClientRect(),z=i.plotinfo,I=z.xaxis._offset,D=z.yaxis._offset,R=e-O.left,F=r-O.top,B=R,N=F,j=\"M\"+R+\",\"+F,U=i.xaxes[0]._length,V=i.yaxes[0]._length,q=i.xaxes.concat(i.yaxes),H=t.altKey;k(t,S,i),\"lasso\"===l&&(u=v([[R,F]],d.BENDPX));var G=P.selectAll(\"path.select-outline-\"+z.id).data([1,2]);G.enter().append(\"path\").attr(\"class\",function(t){return\"select-outline select-outline-\"+t+\" select-outline-\"+z.id}).attr(\"transform\",\"translate(\"+I+\", \"+D+\")\").attr(\"d\",j+\"Z\");var Y,W=P.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:a.background,stroke:a.defaultLine,\"stroke-width\":1}).attr(\"transform\",\"translate(\"+I+\", \"+D+\")\").attr(\"d\",\"M0,0Z\"),X=L._uid+d.SELECTID,Z=[],J=A(S,i.xaxes,i.yaxes,i.subplot);function K(t,e){return\"log\"===t.type?t.p2d(e):t.p2r(e)}function $(t){var e=\"y\"===t._id.charAt(0)?1:0;return function(r){return K(t,r[e])}}function Q(t,e){return t-e}Y=z.fillRangeItems?z.fillRangeItems:\"select\"===l?function(t,e){var r=t.range={};for(y=0;y<q.length;y++){var n=q[y],i=n._id.charAt(0);r[n._id]=[K(n,e[i+\"min\"]),K(n,e[i+\"max\"])].sort(Q)}}:function(t,e,r){var n=t.lassoPoints={};for(y=0;y<q.length;y++){var i=q[y];n[i._id]=r.filtered.map($(i))}},i.moveFn=function(t,e){B=Math.max(0,Math.min(U,t+R)),N=Math.max(0,Math.min(V,e+F));var r=Math.abs(B-R),a=Math.abs(N-F);if(\"select\"===l){var o=L.selectdirection;\"h\"===(o=\"any\"===L.selectdirection?a<Math.min(.6*r,g)?\"h\":r<Math.min(.6*a,g)?\"v\":\"d\":L.selectdirection)?((p=[[R,0],[R,V],[B,V],[B,0]]).xmin=Math.min(R,B),p.xmax=Math.max(R,B),p.ymin=Math.min(0,V),p.ymax=Math.max(0,V),W.attr(\"d\",\"M\"+p.xmin+\",\"+(F-g)+\"h-4v\"+2*g+\"h4ZM\"+(p.xmax-1)+\",\"+(F-g)+\"h4v\"+2*g+\"h-4Z\")):\"v\"===o?((p=[[0,F],[0,N],[U,N],[U,F]]).xmin=Math.min(0,U),p.xmax=Math.max(0,U),p.ymin=Math.min(F,N),p.ymax=Math.max(F,N),W.attr(\"d\",\"M\"+(R-g)+\",\"+p.ymin+\"v-4h\"+2*g+\"v4ZM\"+(R-g)+\",\"+(p.ymax-1)+\"v4h\"+2*g+\"v-4Z\")):\"d\"===o&&((p=[[R,F],[R,N],[B,N],[B,F]]).xmin=Math.min(R,B),p.xmax=Math.max(R,B),p.ymin=Math.min(F,N),p.ymax=Math.max(F,N),W.attr(\"d\",\"M0,0Z\"))}else\"lasso\"===l&&(u.addPt([B,N]),p=u.filtered);i.selectionDefs&&i.selectionDefs.length?(f=function(t,e,r){return r?n.difference({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions:n.union({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions}(i.mergedPolygons,p,H),p.subtract=H,h=w(i.selectionDefs.concat([p]))):(f=[p],h=m(p)),M(f,G),c.throttle(X,d.SELECTDELAY,function(){var t;Z=[];var e,r=[];for(y=0;y<J.length;y++)if(e=(b=J[y])._module.selectPoints(b,h),r.push(e),t=C(e,b),Z.length)for(var n=0;n<t.length;n++)Z.push(t[n]);else Z=t;E(S,J,_={points:Z}),Y(_,p,u),i.gd.emit(\"plotly_selecting\",_)})},i.clickFn=function(t,e){var r=L.clickmode;W.remove(),c.done(X).then(function(){if(c.clear(X),2===t){for(G.remove(),y=0;y<J.length;y++)(b=J[y])._module.selectPoints(b,!1);E(S,J),T(i),S.emit(\"plotly_deselect\",null)}else r.indexOf(\"select\")>-1&&x(e,S,i.xaxes,i.yaxes,i.subplot,i,G),\"event\"===r&&S.emit(\"plotly_selected\",void 0);o.click(S,e)}).catch(s.error)},i.doneFn=function(){W.remove(),c.done(X).then(function(){c.clear(X),i.gd.emit(\"plotly_selected\",_),p&&i.selectionDefs&&(p.subtract=H,i.selectionDefs.push(p),i.mergedPolygons.length=0,[].push.apply(i.mergedPolygons,f)),i.doneFnCompleted&&i.doneFnCompleted(Z)}).catch(s.error)}},clearSelect:L,selectOnClick:x}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../components/fx/helpers\":628,\"../../lib\":719,\"../../lib/clear_gl_canvases\":704,\"../../lib/polygon\":731,\"../../lib/throttle\":744,\"../../plot_api/subroutines\":758,\"../../registry\":847,\"./axis_ids\":770,\"./constants\":773,polybooljs:473}],785:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=a.cleanNumber,s=a.ms2DateTime,l=a.dateTime2ms,c=a.ensureNumber,u=a.isArrayOrTypedArray,h=t(\"../../constants/numerical\"),f=h.FP_SAFE,p=h.BADNUM,d=h.LOG_CLIP,g=t(\"./constants\"),v=t(\"./axis_ids\");function m(t){return Math.pow(10,t)}function y(t){return null!=t}e.exports=function(t,e){e=e||{};var r=t._id||\"x\",h=r.charAt(0);function x(e,r){if(e>0)return Math.log(e)/Math.LN10;if(e<=0&&r&&t.range&&2===t.range.length){var n=t.range[0],i=t.range[1];return.5*(n+i-2*d*Math.abs(n-i))}return p}function b(e,r,n){var o=l(e,n||t.calendar);if(o===p){if(!i(e))return p;e=+e;var s=Math.floor(10*a.mod(e+.05,1)),c=Math.round(e-s/10);o=l(new Date(c))+s/10}return o}function _(e,r,n){return s(e,r,n||t.calendar)}function w(e){return t._categories[Math.round(e)]}function k(e){if(y(e)){if(void 0===t._categoriesMap&&(t._categoriesMap={}),void 0!==t._categoriesMap[e])return t._categoriesMap[e];t._categories.push(\"number\"==typeof e?String(e):e);var r=t._categories.length-1;return t._categoriesMap[e]=r,r}return p}function T(e){if(t._categoriesMap)return t._categoriesMap[e]}function A(t){var e=T(t);return void 0!==e?e:i(t)?+t:void 0}function M(e){return i(e)?n.round(t._b+t._m*e,2):p}function S(e){return(e-t._b)/t._m}t.c2l=\"log\"===t.type?x:c,t.l2c=\"log\"===t.type?m:c,t.l2p=M,t.p2l=S,t.c2p=\"log\"===t.type?function(t,e){return M(x(t,e))}:M,t.p2c=\"log\"===t.type?function(t){return m(S(t))}:S,-1!==[\"linear\",\"-\"].indexOf(t.type)?(t.d2r=t.r2d=t.d2c=t.r2c=t.d2l=t.r2l=o,t.c2d=t.c2r=t.l2d=t.l2r=c,t.d2p=t.r2p=function(e){return t.l2p(o(e))},t.p2d=t.p2r=S,t.cleanPos=c):\"log\"===t.type?(t.d2r=t.d2l=function(t,e){return x(o(t),e)},t.r2d=t.r2c=function(t){return m(o(t))},t.d2c=t.r2l=o,t.c2d=t.l2r=c,t.c2r=x,t.l2d=m,t.d2p=function(e,r){return t.l2p(t.d2r(e,r))},t.p2d=function(t){return m(S(t))},t.r2p=function(e){return t.l2p(o(e))},t.p2r=S,t.cleanPos=c):\"date\"===t.type?(t.d2r=t.r2d=a.identity,t.d2c=t.r2c=t.d2l=t.r2l=b,t.c2d=t.c2r=t.l2d=t.l2r=_,t.d2p=t.r2p=function(e,r,n){return t.l2p(b(e,0,n))},t.p2d=t.p2r=function(t,e,r){return _(S(t),e,r)},t.cleanPos=function(e){return a.cleanDate(e,p,t.calendar)}):\"category\"===t.type?(t.d2c=t.d2l=k,t.r2d=t.c2d=t.l2d=w,t.d2r=t.d2l_noadd=A,t.r2c=function(e){var r=A(e);return void 0!==r?r:t.fraction2r(.5)},t.l2r=t.c2r=c,t.r2l=A,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return w(S(t))},t.r2p=t.d2p,t.p2r=S,t.cleanPos=function(t){return\"string\"==typeof t&&\"\"!==t?t:c(t)}):\"multicategory\"===t.type&&(t.r2d=t.c2d=t.l2d=w,t.d2r=t.d2l_noadd=A,t.r2c=function(e){var r=A(e);return void 0!==r?r:t.fraction2r(.5)},t.r2c_just_indices=T,t.l2r=t.c2r=c,t.r2l=A,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return w(S(t))},t.r2p=t.d2p,t.p2r=S,t.cleanPos=function(t){return Array.isArray(t)||\"string\"==typeof t&&\"\"!==t?t:c(t)},t.setupMultiCategory=function(n){var i,o,s=t._traceIndices,l=e._axisMatchGroups;if(l&&l.length&&0===t._categories.length)for(i=0;i<l.length;i++){var c=l[i];if(c[r])for(var f in c)if(f!==r){var p=e[v.id2name(f)];s=s.concat(p._traceIndices)}}var d=[[0,{}],[0,{}]],g=[];for(i=0;i<s.length;i++){var m=n[s[i]];if(h in m){var x=m[h],b=m._length||a.minRowLength(x);if(u(x[0])&&u(x[1]))for(o=0;o<b;o++){var _=x[0][o],w=x[1][o];y(_)&&y(w)&&(g.push([_,w]),_ in d[0][1]||(d[0][1][_]=d[0][0]++),w in d[1][1]||(d[1][1][w]=d[1][0]++))}}}for(g.sort(function(t,e){var r=d[0][1],n=r[t[0]]-r[e[0]];if(n)return n;var i=d[1][1];return i[t[1]]-i[e[1]]}),i=0;i<g.length;i++)k(g[i])}),t.fraction2r=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return t.l2r(r+e*(n-r))},t.r2fraction=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return(t.r2l(e)-r)/(n-r)},t.cleanRange=function(e,r){r||(r={}),e||(e=\"range\");var n,o,s=a.nestedProperty(t,e).get();if(o=(o=\"date\"===t.type?a.dfltRange(t.calendar):\"y\"===h?g.DFLTRANGEY:r.dfltRange||g.DFLTRANGEX).slice(),s&&2===s.length)for(\"date\"!==t.type||t.autorange||(s[0]=a.cleanDate(s[0],p,t.calendar),s[1]=a.cleanDate(s[1],p,t.calendar)),n=0;n<2;n++)if(\"date\"===t.type){if(!a.isDateTime(s[n],t.calendar)){t[e]=o;break}if(t.r2l(s[0])===t.r2l(s[1])){var l=a.constrain(t.r2l(s[0]),a.MIN_MS+1e3,a.MAX_MS-1e3);s[0]=t.l2r(l-1e3),s[1]=t.l2r(l+1e3);break}}else{if(!i(s[n])){if(!i(s[1-n])){t[e]=o;break}s[n]=s[1-n]*(n?10:.1)}if(s[n]<-f?s[n]=-f:s[n]>f&&(s[n]=f),s[0]===s[1]){var c=Math.max(1,Math.abs(1e-6*s[0]));s[0]-=c,s[1]+=c}}else a.nestedProperty(t,e).set(o)},t.setScale=function(r){var n=e._size;if(t.overlaying){var i=v.getFromId({_fullLayout:e},t.overlaying);t.domain=i.domain}var a=r&&t._r?\"_r\":\"range\",o=t.calendar;t.cleanRange(a);var s=t.r2l(t[a][0],o),l=t.r2l(t[a][1],o);if(\"y\"===h?(t._offset=n.t+(1-t.domain[1])*n.h,t._length=n.h*(t.domain[1]-t.domain[0]),t._m=t._length/(s-l),t._b=-t._m*l):(t._offset=n.l+t.domain[0]*n.w,t._length=n.w*(t.domain[1]-t.domain[0]),t._m=t._length/(l-s),t._b=-t._m*s),!isFinite(t._m)||!isFinite(t._b)||t._length<0)throw e._replotting=!1,new Error(\"Something went wrong with axis scaling\")},t.makeCalcdata=function(e,r){var n,i,o,s,l=t.type,c=\"date\"===l&&e[r+\"calendar\"];if(r in e){if(n=e[r],s=e._length||a.minRowLength(n),a.isTypedArray(n)&&(\"linear\"===l||\"log\"===l)){if(s===n.length)return n;if(n.subarray)return n.subarray(0,s)}if(\"multicategory\"===l)return function(t,e){for(var r=new Array(e),n=0;n<e;n++){var i=(t[0]||[])[n],a=(t[1]||[])[n];r[n]=T([i,a])}return r}(n,s);for(i=new Array(s),o=0;o<s;o++)i[o]=t.d2c(n[o],0,c)}else{var u=r+\"0\"in e?t.d2c(e[r+\"0\"],0,c):0,h=e[\"d\"+r]?Number(e[\"d\"+r]):1;for(n=e[{x:\"y\",y:\"x\"}[r]],s=e._length||n.length,i=new Array(s),o=0;o<s;o++)i[o]=u+o*h}return i},t.isValidRange=function(e){return Array.isArray(e)&&2===e.length&&i(t.r2l(e[0]))&&i(t.r2l(e[1]))},t.isPtWithinRange=function(e,r){var n=t.c2l(e[h],null,r),i=t.r2l(t.range[0]),a=t.r2l(t.range[1]);return i<a?i<=n&&n<=a:a<=n&&n<=i},t.clearCalc=function(){var n=function(){t._categories=[],t._categoriesMap={}},i=e._axisMatchGroups;if(i&&i.length){for(var a=!1,o=0;o<i.length;o++){var s=i[o];if(s[r]){a=!0;var l=null,c=null;for(var u in s){var h=e[v.id2name(u)];if(h._categories){l=h._categories,c=h._categoriesMap;break}}l&&c?(t._categories=l,t._categoriesMap=c):n();break}}a||n()}else n();if(t._initialCategories)for(var f=0;f<t._initialCategories.length;f++)k(t._initialCategories[f])},t.sortByInitialCategories=function(){var n=[];if(t._categories=[],t._categoriesMap={},t._initialCategories)for(var i=0;i<t._initialCategories.length;i++)k(t._initialCategories[i]);n=n.concat(t._traceIndices);var a=t._matchGroup;for(var o in a)if(r!==o){var s=e[v.id2name(o)];s._categories=t._categories,s._categoriesMap=t._categoriesMap,n=n.concat(s._traceIndices)}return n};var E=e._d3locale;\"date\"===t.type&&(t._dateFormat=E?E.timeFormat.utc:n.time.format.utc,t._extraFormat=e._extraFormat),t._separators=e.separators,t._numFormat=E?E.numberFormat:n.format,delete t._minDtick,delete t._forceTick0}},{\"../../constants/numerical\":695,\"../../lib\":719,\"./axis_ids\":770,\"./constants\":773,d3:163,\"fast-isnumeric\":225}],786:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"../array_container_defaults\");function o(t){var e=[\"showexponent\",\"showtickprefix\",\"showticksuffix\"].filter(function(e){return void 0!==t[e]});if(e.every(function(r){return t[r]===t[e[0]]})||1===e.length)return t[e[0]]}function s(t,e){function r(r,a){return n.coerce(t,e,i.tickformatstops,r,a)}r(\"enabled\")&&(r(\"dtickrange\"),r(\"value\"))}e.exports=function(t,e,r,l,c,u){u&&1!==u.pass||function(t,e,r,n,i){var a=o(t);r(\"tickprefix\")&&r(\"showtickprefix\",a);r(\"ticksuffix\",i.tickSuffixDflt)&&r(\"showticksuffix\",a)}(t,0,r,0,c),u&&2!==u.pass||function(t,e,r,l,c){var u=o(t);r(\"tickprefix\")&&r(\"showtickprefix\",u);r(\"ticksuffix\",c.tickSuffixDflt)&&r(\"showticksuffix\",u);if(r(\"showticklabels\")){var h=c.font||{},f=e.color,p=f&&f!==i.color.dflt?f:h.color;if(n.coerceFont(r,\"tickfont\",{family:h.family,size:h.size,color:p}),r(\"tickangle\"),\"category\"!==l){var d=r(\"tickformat\"),g=t.tickformatstops;Array.isArray(g)&&g.length&&a(t,e,{name:\"tickformatstops\",inclusionAttr:\"enabled\",handleItemDefaults:s}),d||\"date\"===l||(r(\"showexponent\",u),r(\"exponentformat\"),r(\"separatethousands\"))}}}(t,e,r,l,c)}},{\"../../lib\":719,\"../array_container_defaults\":763,\"./layout_attributes\":779}],787:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r,a){var o=n.coerce2(t,e,i,\"ticklen\"),s=n.coerce2(t,e,i,\"tickwidth\"),l=n.coerce2(t,e,i,\"tickcolor\",e.color);r(\"ticks\",a.outerTicks||o||s||l?\"outside\":\"\")||(delete e.ticklen,delete e.tickwidth,delete e.tickcolor)}},{\"../../lib\":719,\"./layout_attributes\":779}],788:[function(t,e,r){\"use strict\";var n=t(\"./clean_ticks\");e.exports=function(t,e,r,i){var a;\"array\"!==t.tickmode||\"log\"!==i&&\"date\"!==i?a=r(\"tickmode\",Array.isArray(t.tickvals)?\"array\":t.dtick?\"linear\":\"auto\"):a=e.tickmode=\"auto\";if(\"auto\"===a)r(\"nticks\");else if(\"linear\"===a){var o=e.dtick=n.dtick(t.dtick,i);e.tick0=n.tick0(t.tick0,i,e.calendar,o)}else if(\"multicategory\"!==i){void 0===r(\"tickvals\")?e.tickmode=\"auto\":r(\"ticktext\")}}},{\"./clean_ticks\":772}],789:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../components/drawing\"),o=t(\"./axes\");e.exports=function(t,e,r,s){var l=t._fullLayout;if(0!==e.length){var c,u,h,f;s&&(c=s());var p=n.ease(r.easing);return t._transitionData._interruptCallbacks.push(function(){return window.cancelAnimationFrame(f),f=null,function(){for(var r={},n=0;n<e.length;n++){var a=e[n];a.xr0&&(r[a.plotinfo.xaxis._name+\".range\"]=a.xr0.slice()),a.yr0&&(r[a.plotinfo.yaxis._name+\".range\"]=a.yr0.slice())}return i.call(\"relayout\",t,r).then(function(){for(var t=0;t<e.length;t++)d(e[t].plotinfo)})}()}),u=Date.now(),f=window.requestAnimationFrame(function n(){h=Date.now();for(var a=Math.min(1,(h-u)/r.duration),o=p(a),s=0;s<e.length;s++)g(e[s],o);h-u>r.duration?(function(){for(var r={},n=0;n<e.length;n++){var a=e[n];a.xr1&&(r[a.plotinfo.xaxis._name+\".range\"]=a.xr1.slice()),a.yr1&&(r[a.plotinfo.yaxis._name+\".range\"]=a.yr1.slice())}c&&c(),i.call(\"relayout\",t,r).then(function(){for(var t=0;t<e.length;t++)d(e[t].plotinfo)})}(),f=window.cancelAnimationFrame(n)):f=window.requestAnimationFrame(n)}),Promise.resolve()}function d(t){var e=t.xaxis,r=t.yaxis;l._defs.select(\"#\"+t.clipId+\"> rect\").call(a.setTranslate,0,0).call(a.setScale,1,1),t.plot.call(a.setTranslate,e._offset,r._offset).call(a.setScale,1,1);var n=t.plot.selectAll(\".scatterlayer .trace\");n.selectAll(\".point\").call(a.setPointGroupScale,1,1),n.selectAll(\".textpoint\").call(a.setTextPointsScale,1,1),n.call(a.hideOutsideRangePoints,t)}function g(e,r){var n=e.plotinfo,i=n.xaxis,s=n.yaxis,l=e.xr0,c=e.xr1,u=i._length,h=e.yr0,f=e.yr1,p=s._length,d=!!c,g=!!f,v=[];if(d){var m=l[1]-l[0],y=c[1]-c[0];v[0]=(l[0]*(1-r)+r*c[0]-l[0])/(l[1]-l[0])*u,v[2]=u*(1-r+r*y/m),i.range[0]=l[0]*(1-r)+r*c[0],i.range[1]=l[1]*(1-r)+r*c[1]}else v[0]=0,v[2]=u;if(g){var x=h[1]-h[0],b=f[1]-f[0];v[1]=(h[1]*(1-r)+r*f[1]-h[1])/(h[0]-h[1])*p,v[3]=p*(1-r+r*b/x),s.range[0]=h[0]*(1-r)+r*f[0],s.range[1]=h[1]*(1-r)+r*f[1]}else v[1]=0,v[3]=p;o.drawOne(t,i,{skipTitle:!0}),o.drawOne(t,s,{skipTitle:!0}),o.redrawComponents(t,[i._id,s._id]);var _=d?u/v[2]:1,w=g?p/v[3]:1,k=d?v[0]:0,T=g?v[1]:0,A=d?v[0]/v[2]*u:0,M=g?v[1]/v[3]*p:0,S=i._offset-A,E=s._offset-M;n.clipRect.call(a.setTranslate,k,T).call(a.setScale,1/_,1/w),n.plot.call(a.setTranslate,S,E).call(a.setScale,_,w),a.setPointGroupScale(n.zoomScalePts,1/_,1/w),a.setTextPointsScale(n.zoomScaleTxt,1/_,1/w)}o.redrawComponents(t)}},{\"../../components/drawing\":614,\"../../registry\":847,\"./axes\":767,d3:163}],790:[function(t,e,r){\"use strict\";var n=t(\"../../registry\").traceIs,i=t(\"./axis_autotype\");function a(t){return{v:\"x\",h:\"y\"}[t.orientation||\"v\"]}function o(t,e){var r=a(t),i=n(t,\"box-violin\"),o=n(t._fullInput||{},\"candlestick\");return i&&!o&&e===r&&void 0===t[r]&&void 0===t[r+\"0\"]}e.exports=function(t,e,r,s){\"-\"===r(\"type\",(s.splomStash||{}).type)&&(!function(t,e){if(\"-\"!==t.type)return;var r=t._id,s=r.charAt(0);-1!==r.indexOf(\"scene\")&&(r=s);var l=function(t,e,r){for(var n=0;n<t.length;n++){var i=t[n];if(\"splom\"===i.type&&i._length>0&&(i[\"_\"+r+\"axes\"]||{})[e])return i;if((i[r+\"axis\"]||r)===e){if(o(i,r))return i;if((i[r]||[]).length||i[r+\"0\"])return i}}}(e,r,s);if(!l)return;if(\"histogram\"===l.type&&s==={v:\"y\",h:\"x\"}[l.orientation||\"v\"])return void(t.type=\"linear\");var c,u=s+\"calendar\",h=l[u],f={noMultiCategory:!n(l,\"cartesian\")||n(l,\"noMultiCategory\")};if(o(l,s)){var p=a(l),d=[];for(c=0;c<e.length;c++){var g=e[c];n(g,\"box-violin\")&&(g[s+\"axis\"]||s)===r&&(void 0!==g[p]?d.push(g[p][0]):void 0!==g.name?d.push(g.name):d.push(\"text\"),g[u]!==h&&(h=void 0))}t.type=i(d,h,f)}else if(\"splom\"===l.type){var v=l.dimensions,m=v[l._axesDim[r]];m.visible&&(t.type=i(m.values,h,f))}else t.type=i(l[s]||[l[s+\"0\"]],h,f)}(e,s.data),\"-\"===e.type?e.type=\"linear\":t.type=e.type)}},{\"../../registry\":847,\"./axis_autotype\":768}],791:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\");function a(t,e,r){var n,a,o,s=!1;if(\"data\"===e.type)n=t._fullData[null!==e.traces?e.traces[0]:0];else{if(\"layout\"!==e.type)return!1;n=t._fullLayout}return a=i.nestedProperty(n,e.prop).get(),(o=r[e.type]=r[e.type]||{}).hasOwnProperty(e.prop)&&o[e.prop]!==a&&(s=!0),o[e.prop]=a,{changed:s,value:a}}function o(t,e){var r=[],n=e[0],a={};if(\"string\"==typeof n)a[n]=e[1];else{if(!i.isPlainObject(n))return r;a=n}return l(a,function(t,e,n){r.push({type:\"layout\",prop:t,value:n})},\"\",0),r}function s(t,e){var r,n,a,o,s=[];if(n=e[0],a=e[1],r=e[2],o={},\"string\"==typeof n)o[n]=a;else{if(!i.isPlainObject(n))return s;o=n,void 0===r&&(r=a)}return void 0===r&&(r=null),l(o,function(e,n,i){var a,o;if(Array.isArray(i)){o=i.slice();var l=Math.min(o.length,t.data.length);r&&(l=Math.min(l,r.length)),a=[];for(var c=0;c<l;c++)a[c]=r?r[c]:c}else o=i,a=r?r.slice():null;if(null===a)Array.isArray(o)&&(o=o[0]);else if(Array.isArray(a)){if(!Array.isArray(o)){var u=o;o=[];for(var h=0;h<a.length;h++)o[h]=u}o.length=Math.min(a.length,o.length)}s.push({type:\"data\",prop:e,traces:a,value:o})},\"\",0),s}function l(t,e,r,n){Object.keys(t).forEach(function(a){var o=t[a];if(\"_\"!==a[0]){var s=r+(n>0?\".\":\"\")+a;i.isPlainObject(o)?l(o,e,s,n+1):e(s,a,o)}})}r.manageCommandObserver=function(t,e,n,o){var s={},l=!0;e&&e._commandObserver&&(s=e._commandObserver),s.cache||(s.cache={}),s.lookupTable={};var c=r.hasSimpleAPICommandBindings(t,n,s.lookupTable);if(e&&e._commandObserver){if(c)return s;if(e._commandObserver.remove)return e._commandObserver.remove(),e._commandObserver=null,s}if(c){a(t,c,s.cache),s.check=function(){if(l){var e=a(t,c,s.cache);return e.changed&&o&&void 0!==s.lookupTable[e.value]&&(s.disable(),Promise.resolve(o({value:e.value,type:c.type,prop:c.prop,traces:c.traces,index:s.lookupTable[e.value]})).then(s.enable,s.enable)),e.changed}};for(var u=[\"plotly_relayout\",\"plotly_redraw\",\"plotly_restyle\",\"plotly_update\",\"plotly_animatingframe\",\"plotly_afterplot\"],h=0;h<u.length;h++)t._internalOn(u[h],s.check);s.remove=function(){for(var e=0;e<u.length;e++)t._removeInternalListener(u[e],s.check)}}else i.log(\"Unable to automatically bind plot updates to API command\"),s.lookupTable={},s.remove=function(){};return s.disable=function(){l=!1},s.enable=function(){l=!0},e&&(e._commandObserver=s),s},r.hasSimpleAPICommandBindings=function(t,e,n){var i,a,o=e.length;for(i=0;i<o;i++){var s,l=e[i],c=l.method,u=l.args;if(Array.isArray(u)||(u=[]),!c)return!1;var h=r.computeAPICommandBindings(t,c,u);if(1!==h.length)return!1;if(a){if((s=h[0]).type!==a.type)return!1;if(s.prop!==a.prop)return!1;if(Array.isArray(a.traces)){if(!Array.isArray(s.traces))return!1;s.traces.sort();for(var f=0;f<a.traces.length;f++)if(a.traces[f]!==s.traces[f])return!1}else if(s.prop!==a.prop)return!1}else a=h[0],Array.isArray(a.traces)&&a.traces.sort();var p=(s=h[0]).value;if(Array.isArray(p)){if(1!==p.length)return!1;p=p[0]}n&&(n[p]=i)}return a},r.executeAPICommand=function(t,e,r){if(\"skip\"===e)return Promise.resolve();var a=n.apiMethodRegistry[e],o=[t];Array.isArray(r)||(r=[]);for(var s=0;s<r.length;s++)o.push(r[s]);return a.apply(null,o).catch(function(t){return i.warn(\"API call to Plotly.\"+e+\" rejected.\",t),Promise.reject(t)})},r.computeAPICommandBindings=function(t,e,r){var n;switch(Array.isArray(r)||(r=[]),e){case\"restyle\":n=s(t,r);break;case\"relayout\":n=o(t,r);break;case\"update\":n=s(t,[r[0],r[2]]).concat(o(t,[r[1]]));break;case\"animate\":n=function(t,e){return Array.isArray(e[0])&&1===e[0].length&&-1!==[\"string\",\"number\"].indexOf(typeof e[0][0])?[{type:\"layout\",prop:\"_currentFrame\",value:e[0][0].toString()}]:[]}(0,r);break;default:n=[]}return n}},{\"../lib\":719,\"../registry\":847}],792:[function(t,e,r){\"use strict\";var n=t(\"../lib/extend\").extendFlat;r.attributes=function(t,e){e=e||{};var r={valType:\"info_array\",editType:(t=t||{}).editType,items:[{valType:\"number\",min:0,max:1,editType:t.editType},{valType:\"number\",min:0,max:1,editType:t.editType}],dflt:[0,1]},i=(t.name&&t.name,t.trace,e.description&&e.description,{x:n({},r,{}),y:n({},r,{}),editType:t.editType});return t.noGridCell||(i.row={valType:\"integer\",min:0,dflt:0,editType:t.editType},i.column={valType:\"integer\",min:0,dflt:0,editType:t.editType}),i},r.defaults=function(t,e,r,n){var i=n&&n.x||[0,1],a=n&&n.y||[0,1],o=e.grid;if(o){var s=r(\"domain.column\");void 0!==s&&(s<o.columns?i=o._domains.x[s]:delete t.domain.column);var l=r(\"domain.row\");void 0!==l&&(l<o.rows?a=o._domains.y[l]:delete t.domain.row)}r(\"domain.x\",i),r(\"domain.y\",a)}},{\"../lib/extend\":710}],793:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType,r=t.colorEditType;void 0===r&&(r=e);var n={family:{valType:\"string\",noBlank:!0,strict:!0,editType:e},size:{valType:\"number\",min:1,editType:e},color:{valType:\"color\",editType:r},editType:e};return t.arrayOk&&(n.family.arrayOk=!0,n.size.arrayOk=!0,n.color.arrayOk=!0),n}},{}],794:[function(t,e,r){\"use strict\";e.exports={_isLinkedToArray:\"frames_entry\",group:{valType:\"string\"},name:{valType:\"string\"},traces:{valType:\"any\"},baseframe:{valType:\"string\"},data:{valType:\"any\"},layout:{valType:\"any\"}}},{}],795:[function(t,e,r){\"use strict\";r.projNames={equirectangular:\"equirectangular\",mercator:\"mercator\",orthographic:\"orthographic\",\"natural earth\":\"naturalEarth\",kavrayskiy7:\"kavrayskiy7\",miller:\"miller\",robinson:\"robinson\",eckert4:\"eckert4\",\"azimuthal equal area\":\"azimuthalEqualArea\",\"azimuthal equidistant\":\"azimuthalEquidistant\",\"conic equal area\":\"conicEqualArea\",\"conic conformal\":\"conicConformal\",\"conic equidistant\":\"conicEquidistant\",gnomonic:\"gnomonic\",stereographic:\"stereographic\",mollweide:\"mollweide\",hammer:\"hammer\",\"transverse mercator\":\"transverseMercator\",\"albers usa\":\"albersUsa\",\"winkel tripel\":\"winkel3\",aitoff:\"aitoff\",sinusoidal:\"sinusoidal\"},r.axesNames=[\"lonaxis\",\"lataxis\"],r.lonaxisSpan={orthographic:180,\"azimuthal equal area\":360,\"azimuthal equidistant\":360,\"conic conformal\":180,gnomonic:160,stereographic:180,\"transverse mercator\":180,\"*\":360},r.lataxisSpan={\"conic conformal\":150,stereographic:179.5,\"*\":180},r.scopeDefaults={world:{lonaxisRange:[-180,180],lataxisRange:[-90,90],projType:\"equirectangular\",projRotate:[0,0,0]},usa:{lonaxisRange:[-180,-50],lataxisRange:[15,80],projType:\"albers usa\"},europe:{lonaxisRange:[-30,60],lataxisRange:[30,85],projType:\"conic conformal\",projRotate:[15,0,0],projParallels:[0,60]},asia:{lonaxisRange:[22,160],lataxisRange:[-15,55],projType:\"mercator\",projRotate:[0,0,0]},africa:{lonaxisRange:[-30,60],lataxisRange:[-40,40],projType:\"mercator\",projRotate:[0,0,0]},\"north america\":{lonaxisRange:[-180,-45],lataxisRange:[5,85],projType:\"conic conformal\",projRotate:[-100,0,0],projParallels:[29.5,45.5]},\"south america\":{lonaxisRange:[-100,-30],lataxisRange:[-60,15],projType:\"mercator\",projRotate:[0,0,0]}},r.clipPad=.001,r.precision=.1,r.landColor=\"#F0DC82\",r.waterColor=\"#3399FF\",r.locationmodeToLayer={\"ISO-3\":\"countries\",\"USA-states\":\"subunits\",\"country names\":\"countries\"},r.sphereSVG={type:\"Sphere\"},r.fillLayers={ocean:1,land:1,lakes:1},r.lineLayers={subunits:1,countries:1,coastlines:1,rivers:1,frame:1},r.layers=[\"bg\",\"ocean\",\"land\",\"lakes\",\"subunits\",\"countries\",\"coastlines\",\"rivers\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"frontplot\"],r.layersForChoropleth=[\"bg\",\"ocean\",\"land\",\"subunits\",\"countries\",\"coastlines\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"rivers\",\"lakes\",\"frontplot\"],r.layerNameToAdjective={ocean:\"ocean\",land:\"land\",lakes:\"lake\",subunits:\"subunit\",countries:\"country\",coastlines:\"coastline\",rivers:\"river\",frame:\"frame\"}},{}],796:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"../../components/fx\"),c=t(\"../plots\"),u=t(\"../cartesian/axes\"),h=t(\"../../components/dragelement\"),f=t(\"../cartesian/select\").prepSelect,p=t(\"../cartesian/select\").selectOnClick,d=t(\"./zoom\"),g=t(\"./constants\"),v=t(\"../../lib/topojson_utils\"),m=t(\"topojson-client\").feature;function y(t){this.id=t.id,this.graphDiv=t.graphDiv,this.container=t.container,this.topojsonURL=t.topojsonURL,this.isStatic=t.staticPlot,this.topojsonName=null,this.topojson=null,this.projection=null,this.scope=null,this.viewInitial=null,this.fitScale=null,this.bounds=null,this.midPt=null,this.hasChoropleth=!1,this.traceHash={},this.layers={},this.basePaths={},this.dataPaths={},this.dataPoints={},this.clipDef=null,this.clipRect=null,this.bgRect=null,this.makeFramework()}t(\"./projections\")(n);var x=y.prototype;e.exports=function(t){return new y(t)},x.plot=function(t,e,r){var n=this,i=e[this.id],a=!1;for(var o in g.layerNameToAdjective)if(\"frame\"!==o&&i[\"show\"+o]){a=!0;break}for(var s=0;s<t.length;s++)if(t[0][0].trace.locationmode){a=!0;break}if(!a)return n.update(t,e);var l=v.getTopojsonName(i);null===n.topojson||l!==n.topojsonName?(n.topojsonName=l,void 0===PlotlyGeoAssets.topojson[n.topojsonName]?r.push(n.fetchTopojson().then(function(r){PlotlyGeoAssets.topojson[n.topojsonName]=r,n.topojson=r,n.update(t,e)})):(n.topojson=PlotlyGeoAssets.topojson[n.topojsonName],n.update(t,e))):n.update(t,e)},x.fetchTopojson=function(){var t=v.getTopojsonPath(this.topojsonURL,this.topojsonName);return new Promise(function(e,r){n.json(t,function(n,i){if(n)return 404===n.status?r(new Error([\"plotly.js could not find topojson file at\",t,\".\",\"Make sure the *topojsonURL* plot config option\",\"is set properly.\"].join(\" \"))):r(new Error([\"unexpected error while fetching topojson file at\",t].join(\" \")));e(i)})})},x.update=function(t,e){var r=e[this.id];if(!this.updateProjection(e,r)){this.hasChoropleth=!1;for(var n=0;n<t.length;n++)if(\"choropleth\"===t[n][0].trace.type){this.hasChoropleth=!0;break}this.viewInitial&&this.scope===r.scope||this.saveViewInitial(r),this.scope=r.scope,this.updateBaseLayers(e,r),this.updateDims(e,r),this.updateFx(e,r),c.generalUpdatePerTraceModule(this.graphDiv,this,t,r);var i=this.layers.frontplot.select(\".scatterlayer\");this.dataPoints.point=i.selectAll(\".point\"),this.dataPoints.text=i.selectAll(\"text\"),this.dataPaths.line=i.selectAll(\".js-line\");var a=this.layers.backplot.select(\".choroplethlayer\");this.dataPaths.choropleth=a.selectAll(\"path\"),this.render()}},x.updateProjection=function(t,e){var r=t._size,o=e.domain,s=e.projection,l=s.rotation||{},c=e.center||{},u=this.projection=function(t){for(var e=t.projection.type,r=n.geo[g.projNames[e]](),i=t._isClipped?g.lonaxisSpan[e]/2:null,a=[\"center\",\"rotate\",\"parallels\",\"clipExtent\"],o=function(t){return t?r:[]},s=0;s<a.length;s++){var l=a[s];\"function\"!=typeof r[l]&&(r[l]=o)}r.isLonLatOverEdges=function(t){if(null===r(t))return!0;if(i){var e=r.rotate();return n.geo.distance(t,[-e[0],-e[1]])>i*Math.PI/180}return!1},r.getPath=function(){return n.geo.path().projection(r)},r.getBounds=function(t){return r.getPath().bounds(t)},r.fitExtent=function(t,e){var n=t[1][0]-t[0][0],i=t[1][1]-t[0][1],a=r.clipExtent&&r.clipExtent();r.scale(150).translate([0,0]),a&&r.clipExtent(null);var o=r.getBounds(e),s=Math.min(n/(o[1][0]-o[0][0]),i/(o[1][1]-o[0][1])),l=+t[0][0]+(n-s*(o[1][0]+o[0][0]))/2,c=+t[0][1]+(i-s*(o[1][1]+o[0][1]))/2;return a&&r.clipExtent(a),r.scale(150*s).translate([l,c])},r.precision(g.precision),i&&r.clipAngle(i-g.clipPad);return r}(e);u.center([c.lon-l.lon,c.lat-l.lat]).rotate([-l.lon,-l.lat,l.roll]).parallels(s.parallels);var h=[[r.l+r.w*o.x[0],r.t+r.h*(1-o.y[1])],[r.l+r.w*o.x[1],r.t+r.h*(1-o.y[0])]],f=e.lonaxis,p=e.lataxis,d=function(t,e){var r=g.clipPad,n=t[0]+r,i=t[1]-r,a=e[0]+r,o=e[1]-r;n>0&&i<0&&(i+=360);var s=(i-n)/4;return{type:\"Polygon\",coordinates:[[[n,a],[n,o],[n+s,o],[n+2*s,o],[n+3*s,o],[i,o],[i,a],[i-s,a],[i-2*s,a],[i-3*s,a],[n,a]]]}}(f.range,p.range);u.fitExtent(h,d);var v=this.bounds=u.getBounds(d),m=this.fitScale=u.scale(),y=u.translate();if(!isFinite(v[0][0])||!isFinite(v[0][1])||!isFinite(v[1][0])||!isFinite(v[1][1])||isNaN(y[0])||isNaN(y[0])){for(var x=this.graphDiv,b=[\"projection.rotation\",\"center\",\"lonaxis.range\",\"lataxis.range\"],_=\"Invalid geo settings, relayout'ing to default view.\",w={},k=0;k<b.length;k++)w[this.id+\".\"+b[k]]=null;return this.viewInitial=null,a.warn(_),x._promises.push(i.call(\"relayout\",x,w)),_}var T=this.midPt=[(v[0][0]+v[1][0])/2,(v[0][1]+v[1][1])/2];if(u.scale(s.scale*m).translate([y[0]+(T[0]-y[0]),y[1]+(T[1]-y[1])]).clipExtent(v),e._isAlbersUsa){var A=u([c.lon,c.lat]),M=u.translate();u.translate([M[0]-(A[0]-M[0]),M[1]-(A[1]-M[1])])}},x.updateBaseLayers=function(t,e){var r=this,i=r.topojson,a=r.layers,l=r.basePaths;function c(t){return\"lonaxis\"===t||\"lataxis\"===t}function h(t){return Boolean(g.lineLayers[t])}function f(t){return Boolean(g.fillLayers[t])}var p=(this.hasChoropleth?g.layersForChoropleth:g.layers).filter(function(t){return h(t)||f(t)?e[\"show\"+t]:!c(t)||e[t].showgrid}),d=r.framework.selectAll(\".layer\").data(p,String);d.exit().each(function(t){delete a[t],delete l[t],n.select(this).remove()}),d.enter().append(\"g\").attr(\"class\",function(t){return\"layer \"+t}).each(function(t){var e=a[t]=n.select(this);\"bg\"===t?r.bgRect=e.append(\"rect\").style(\"pointer-events\",\"all\"):c(t)?l[t]=e.append(\"path\").style(\"fill\",\"none\"):\"backplot\"===t?e.append(\"g\").classed(\"choroplethlayer\",!0):\"frontplot\"===t?e.append(\"g\").classed(\"scatterlayer\",!0):h(t)?l[t]=e.append(\"path\").style(\"fill\",\"none\").style(\"stroke-miterlimit\",2):f(t)&&(l[t]=e.append(\"path\").style(\"stroke\",\"none\"))}),d.order(),d.each(function(r){var n=l[r],a=g.layerNameToAdjective[r];\"frame\"===r?n.datum(g.sphereSVG):h(r)||f(r)?n.datum(m(i,i.objects[r])):c(r)&&n.datum(function(t,e,r){var n,i,a,o=e[t],s=g.scopeDefaults[e.scope];\"lonaxis\"===t?(n=s.lonaxisRange,i=s.lataxisRange,a=function(t,e){return[t,e]}):\"lataxis\"===t&&(n=s.lataxisRange,i=s.lonaxisRange,a=function(t,e){return[e,t]});var l={type:\"linear\",range:[n[0],n[1]-1e-6],tick0:o.tick0,dtick:o.dtick};u.setConvert(l,r);var c=u.calcTicks(l);e.isScoped||\"lonaxis\"!==t||c.pop();for(var h=c.length,f=new Array(h),p=0;p<h;p++)for(var d=c[p].x,v=f[p]=[],m=i[0];m<i[1]+2.5;m+=2.5)v.push(a(d,m));return{type:\"MultiLineString\",coordinates:f}}(r,e,t)).call(o.stroke,e[r].gridcolor).call(s.dashLine,\"\",e[r].gridwidth),h(r)?n.call(o.stroke,e[a+\"color\"]).call(s.dashLine,\"\",e[a+\"width\"]):f(r)&&n.call(o.fill,e[a+\"color\"])})},x.updateDims=function(t,e){var r=this.bounds,n=(e.framewidth||0)/2,i=r[0][0]-n,a=r[0][1]-n,l=r[1][0]-i+n,c=r[1][1]-a+n;s.setRect(this.clipRect,i,a,l,c),this.bgRect.call(s.setRect,i,a,l,c).call(o.fill,e.bgcolor),this.xaxis._offset=i,this.xaxis._length=l,this.yaxis._offset=a,this.yaxis._length=c},x.updateFx=function(t,e){var r=this,a=r.graphDiv,o=r.bgRect,s=t.dragmode,c=t.clickmode;if(!r.isStatic){var u;\"select\"===s?u=function(t,e){(t.range={})[r.id]=[v([e.xmin,e.ymin]),v([e.xmax,e.ymax])]}:\"lasso\"===s&&(u=function(t,e,n){(t.lassoPoints={})[r.id]=n.filtered.map(v)});var g={element:r.bgRect.node(),gd:a,plotinfo:{id:r.id,xaxis:r.xaxis,yaxis:r.yaxis,fillRangeItems:u},xaxes:[r.xaxis],yaxes:[r.yaxis],subplot:r.id,clickFn:function(e){2===e&&t._zoomlayer.selectAll(\".select-outline\").remove()}};\"pan\"===s?(o.node().onmousedown=null,o.call(d(r,e)),o.on(\"dblclick.zoom\",function(){var t=r.viewInitial,e={};for(var n in t)e[r.id+\".\"+n]=t[n];i.call(\"_guiRelayout\",a,e),a.emit(\"plotly_doubleclick\",null)}),a._context._scrollZoom.geo||o.on(\"wheel.zoom\",null)):\"select\"!==s&&\"lasso\"!==s||(o.on(\".zoom\",null),g.prepFn=function(t,e,r){f(t,e,r,g,s)},h.init(g)),o.on(\"mousemove\",function(){var t=r.projection.invert(n.mouse(this));if(!t||isNaN(t[0])||isNaN(t[1]))return h.unhover(a,n.event);r.xaxis.p2c=function(){return t[0]},r.yaxis.p2c=function(){return t[1]},l.hover(a,n.event,r.id)}),o.on(\"mouseout\",function(){a._dragging||h.unhover(a,n.event)}),o.on(\"click\",function(){\"select\"!==s&&\"lasso\"!==s&&(c.indexOf(\"select\")>-1&&p(n.event,a,[r.xaxis],[r.yaxis],r.id,g),c.indexOf(\"event\")>-1&&l.click(a,n.event))})}function v(t){return r.projection.invert([t[0]+r.xaxis._offset,t[1]+r.yaxis._offset])}},x.makeFramework=function(){var t=this,e=t.graphDiv,r=e._fullLayout,i=\"clip\"+r._uid+t.id;t.clipDef=r._clips.append(\"clipPath\").attr(\"id\",i),t.clipRect=t.clipDef.append(\"rect\"),t.framework=n.select(t.container).append(\"g\").attr(\"class\",\"geo \"+t.id).call(s.setClipUrl,i,e),t.project=function(e){var r=t.projection(e);return r?[r[0]-t.xaxis._offset,r[1]-t.yaxis._offset]:[null,null]},t.xaxis={_id:\"x\",c2p:function(e){return t.project(e)[0]}},t.yaxis={_id:\"y\",c2p:function(e){return t.project(e)[1]}},t.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},u.setConvert(t.mockAxis,r)},x.saveViewInitial=function(t){var e=t.center||{},r=t.projection,n=r.rotation||{};t._isScoped?this.viewInitial={\"center.lon\":e.lon,\"center.lat\":e.lat,\"projection.scale\":r.scale}:t._isClipped?this.viewInitial={\"projection.scale\":r.scale,\"projection.rotation.lon\":n.lon,\"projection.rotation.lat\":n.lat}:this.viewInitial={\"center.lon\":e.lon,\"center.lat\":e.lat,\"projection.scale\":r.scale,\"projection.rotation.lon\":n.lon}},x.render=function(){var t,e=this.projection,r=e.getPath();function n(t){var r=e(t.lonlat);return r?\"translate(\"+r[0]+\",\"+r[1]+\")\":null}function i(t){return e.isLonLatOverEdges(t.lonlat)?\"none\":null}for(t in this.basePaths)this.basePaths[t].attr(\"d\",r);for(t in this.dataPaths)this.dataPaths[t].attr(\"d\",function(t){return r(t.geojson)});for(t in this.dataPoints)this.dataPoints[t].attr(\"display\",i).attr(\"transform\",n)}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../lib\":719,\"../../lib/topojson_utils\":746,\"../../registry\":847,\"../cartesian/axes\":767,\"../cartesian/select\":784,\"../plots\":828,\"./constants\":795,\"./projections\":800,\"./zoom\":801,d3:163,\"topojson-client\":540}],797:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./geo\"),o=\"geo\",s=i(o),l={};l[o]={valType:\"subplotid\",dflt:o,editType:\"calc\"},e.exports={attr:o,name:o,idRoot:o,idRegex:s,attrRegex:s,attributes:l,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[o],s=0;s<i.length;s++){var l=i[s],c=n(r,o,l),u=e[l]._subplot;u||(u=a({id:l,graphDiv:t,container:e._geolayer.node(),topojsonURL:t._context.topojsonURL,staticPlot:t._context.staticPlot}),e[l]._subplot=u),u.plot(c,e,t._promises)}},updateFx:function(t){for(var e=t._fullLayout,r=e._subplots[o],n=0;n<r.length;n++){var i=e[r[n]];i._subplot.updateFx(e,i)}},clean:function(t,e,r,n){for(var i=n._subplots[o]||[],a=0;a<i.length;a++){var s=i[a],l=n[s]._subplot;!e[s]&&l&&(l.framework.remove(),l.clipDef.remove())}}}},{\"../../lib\":719,\"../../plots/get_data\":802,\"./geo\":796,\"./layout_attributes\":798,\"./layout_defaults\":799}],798:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"./constants\"),o=t(\"../../plot_api/edit_types\").overrideAll,s={range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},showgrid:{valType:\"boolean\",dflt:!1},tick0:{valType:\"number\",dflt:0},dtick:{valType:\"number\"},gridcolor:{valType:\"color\",dflt:n.lightLine},gridwidth:{valType:\"number\",min:0,dflt:1}};(e.exports=o({domain:i({name:\"geo\"},{}),resolution:{valType:\"enumerated\",values:[110,50],dflt:110,coerceNumber:!0},scope:{valType:\"enumerated\",values:Object.keys(a.scopeDefaults),dflt:\"world\"},projection:{type:{valType:\"enumerated\",values:Object.keys(a.projNames)},rotation:{lon:{valType:\"number\"},lat:{valType:\"number\"},roll:{valType:\"number\"}},parallels:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},scale:{valType:\"number\",min:0,dflt:1}},center:{lon:{valType:\"number\"},lat:{valType:\"number\"}},showcoastlines:{valType:\"boolean\"},coastlinecolor:{valType:\"color\",dflt:n.defaultLine},coastlinewidth:{valType:\"number\",min:0,dflt:1},showland:{valType:\"boolean\",dflt:!1},landcolor:{valType:\"color\",dflt:a.landColor},showocean:{valType:\"boolean\",dflt:!1},oceancolor:{valType:\"color\",dflt:a.waterColor},showlakes:{valType:\"boolean\",dflt:!1},lakecolor:{valType:\"color\",dflt:a.waterColor},showrivers:{valType:\"boolean\",dflt:!1},rivercolor:{valType:\"color\",dflt:a.waterColor},riverwidth:{valType:\"number\",min:0,dflt:1},showcountries:{valType:\"boolean\"},countrycolor:{valType:\"color\",dflt:n.defaultLine},countrywidth:{valType:\"number\",min:0,dflt:1},showsubunits:{valType:\"boolean\"},subunitcolor:{valType:\"color\",dflt:n.defaultLine},subunitwidth:{valType:\"number\",min:0,dflt:1},showframe:{valType:\"boolean\"},framecolor:{valType:\"color\",dflt:n.defaultLine},framewidth:{valType:\"number\",min:0,dflt:1},bgcolor:{valType:\"color\",dflt:n.background},lonaxis:s,lataxis:s},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":592,\"../../plot_api/edit_types\":750,\"../domain\":792,\"./constants\":795}],799:[function(t,e,r){\"use strict\";var n=t(\"../subplot_defaults\"),i=t(\"./constants\"),a=t(\"./layout_attributes\"),o=i.axesNames;function s(t,e,r){var n=r(\"resolution\"),a=r(\"scope\"),s=i.scopeDefaults[a],l=r(\"projection.type\",s.projType),c=e._isAlbersUsa=\"albers usa\"===l;c&&(a=e.scope=\"usa\");var u=e._isScoped=\"world\"!==a,h=e._isConic=-1!==l.indexOf(\"conic\");e._isClipped=!!i.lonaxisSpan[l];for(var f=0;f<o.length;f++){var p,d=o[f],g=[30,10][f];if(u)p=s[d+\"Range\"];else{var v=i[d+\"Span\"],m=(v[l]||v[\"*\"])/2,y=r(\"projection.rotation.\"+d.substr(0,3),s.projRotate[f]);p=[y-m,y+m]}r(d+\".range\",p),r(d+\".tick0\"),r(d+\".dtick\",g),r(d+\".showgrid\")&&(r(d+\".gridcolor\"),r(d+\".gridwidth\"))}var x=e.lonaxis.range,b=e.lataxis.range,_=x[0],w=x[1];_>0&&w<0&&(w+=360);var k,T,A,M=(_+w)/2;if(!c){var S=u?s.projRotate:[M,0,0];k=r(\"projection.rotation.lon\",S[0]),r(\"projection.rotation.lat\",S[1]),r(\"projection.rotation.roll\",S[2]),r(\"showcoastlines\",!u)&&(r(\"coastlinecolor\"),r(\"coastlinewidth\")),r(\"showocean\")&&r(\"oceancolor\")}(c?(T=-96.6,A=38.7):(T=u?M:k,A=(b[0]+b[1])/2),r(\"center.lon\",T),r(\"center.lat\",A),h)&&r(\"projection.parallels\",s.projParallels||[0,60]);r(\"projection.scale\"),r(\"showland\")&&r(\"landcolor\"),r(\"showlakes\")&&r(\"lakecolor\"),r(\"showrivers\")&&(r(\"rivercolor\"),r(\"riverwidth\")),r(\"showcountries\",u&&\"usa\"!==a)&&(r(\"countrycolor\"),r(\"countrywidth\")),(\"usa\"===a||\"north america\"===a&&50===n)&&(r(\"showsubunits\",!0),r(\"subunitcolor\"),r(\"subunitwidth\")),u||r(\"showframe\",!0)&&(r(\"framecolor\"),r(\"framewidth\")),r(\"bgcolor\")}e.exports=function(t,e,r){n(t,e,r,{type:\"geo\",attributes:a,handleDefaults:s,partition:\"y\"})}},{\"../subplot_defaults\":842,\"./constants\":795,\"./layout_attributes\":798}],800:[function(t,e,r){\"use strict\";e.exports=function(t){function e(t,e){return{type:\"Feature\",id:t.id,properties:t.properties,geometry:r(t.geometry,e)}}function r(e,n){if(!e)return null;if(\"GeometryCollection\"===e.type)return{type:\"GeometryCollection\",geometries:object.geometries.map(function(t){return r(t,n)})};if(!c.hasOwnProperty(e.type))return null;var i=c[e.type];return t.geo.stream(e,n(i)),i.result()}t.geo.project=function(t,e){var i=e.stream;if(!i)throw new Error(\"not yet supported\");return(t&&n.hasOwnProperty(t.type)?n[t.type]:r)(t,i)};var n={Feature:e,FeatureCollection:function(t,r){return{type:\"FeatureCollection\",features:t.features.map(function(t){return e(t,r)})}}},i=[],a=[],o={point:function(t,e){i.push([t,e])},result:function(){var t=i.length?i.length<2?{type:\"Point\",coordinates:i[0]}:{type:\"MultiPoint\",coordinates:i}:null;return i=[],t}},s={lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){i.length&&(a.push(i),i=[])},result:function(){var t=a.length?a.length<2?{type:\"LineString\",coordinates:a[0]}:{type:\"MultiLineString\",coordinates:a}:null;return a=[],t}},l={polygonStart:u,lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){var t=i.length;if(t){do{i.push(i[0].slice())}while(++t<4);a.push(i),i=[]}},polygonEnd:u,result:function(){if(!a.length)return null;var t=[],e=[];return a.forEach(function(r){!function(t){if((e=t.length)<4)return!1;for(var e,r=0,n=t[e-1][1]*t[0][0]-t[e-1][0]*t[0][1];++r<e;)n+=t[r-1][1]*t[r][0]-t[r-1][0]*t[r][1];return n<=0}(r)?e.push(r):t.push([r])}),e.forEach(function(e){var r=e[0];t.some(function(t){if(function(t,e){for(var r=e[0],n=e[1],i=!1,a=0,o=t.length,s=o-1;a<o;s=a++){var l=t[a],c=l[0],u=l[1],h=t[s],f=h[0],p=h[1];u>n^p>n&&r<(f-c)*(n-u)/(p-u)+c&&(i=!i)}return i}(t[0],r))return t.push(e),!0})||t.push([e])}),a=[],t.length?t.length>1?{type:\"MultiPolygon\",coordinates:t}:{type:\"Polygon\",coordinates:t[0]}:null}},c={Point:o,MultiPoint:o,LineString:s,MultiLineString:s,Polygon:l,MultiPolygon:l,Sphere:l};function u(){}var h=1e-6,f=h*h,p=Math.PI,d=p/2,g=(Math.sqrt(p),p/180),v=180/p;function m(t){return t>1?d:t<-1?-d:Math.asin(t)}function y(t){return t>1?0:t<-1?p:Math.acos(t)}var x=t.geo.projection,b=t.geo.projectionMutator;function _(t,e){var r=(2+d)*Math.sin(e);e/=2;for(var n=0,i=1/0;n<10&&Math.abs(i)>h;n++){var a=Math.cos(e);e-=i=(e+Math.sin(e)*(a+2)-r)/(2*a*(1+a))}return[2/Math.sqrt(p*(4+p))*t*(1+Math.cos(e)),2*Math.sqrt(p/(4+p))*Math.sin(e)]}t.geo.interrupt=function(e){var r,n=[[[[-p,0],[0,d],[p,0]]],[[[-p,0],[0,-d],[p,0]]]];function i(t,r){for(var i=r<0?-1:1,a=n[+(r<0)],o=0,s=a.length-1;o<s&&t>a[o][2][0];++o);var l=e(t-a[o][1][0],r);return l[0]+=e(a[o][1][0],i*r>i*a[o][0][1]?a[o][0][1]:r)[0],l}e.invert&&(i.invert=function(t,a){for(var o=r[+(a<0)],s=n[+(a<0)],c=0,u=o.length;c<u;++c){var h=o[c];if(h[0][0]<=t&&t<h[1][0]&&h[0][1]<=a&&a<h[1][1]){var f=e.invert(t-e(s[c][1][0],0)[0],a);return f[0]+=s[c][1][0],l(i(f[0],f[1]),[t,a])?f:null}}});var a=t.geo.projection(i),o=a.stream;function s(t,e){for(var r,n,i,a=-1,o=t.length,s=t[0],l=[];++a<o;){n=((r=t[a])[0]-s[0])/e,i=(r[1]-s[1])/e;for(var c=0;c<e;++c)l.push([s[0]+c*n,s[1]+c*i]);s=r}return l.push(r),l}function l(t,e){return Math.abs(t[0]-e[0])<h&&Math.abs(t[1]-e[1])<h}return a.stream=function(e){var r=a.rotate(),i=o(e),l=(a.rotate([0,0]),o(e));return a.rotate(r),i.sphere=function(){t.geo.stream(function(){for(var e=1e-6,r=[],i=0,a=n[0].length;i<a;++i){var o=n[0][i],l=180*o[0][0]/p,c=180*o[0][1]/p,u=180*o[1][1]/p,h=180*o[2][0]/p,f=180*o[2][1]/p;r.push(s([[l+e,c+e],[l+e,u-e],[h-e,u-e],[h-e,f+e]],30))}for(var i=n[1].length-1;i>=0;--i){var o=n[1][i],l=180*o[0][0]/p,c=180*o[0][1]/p,u=180*o[1][1]/p,h=180*o[2][0]/p,f=180*o[2][1]/p;r.push(s([[h-e,f-e],[h-e,u+e],[l+e,u+e],[l+e,c-e]],30))}return{type:\"Polygon\",coordinates:[t.merge(r)]}}(),l)},i},a.lobes=function(t){return arguments.length?(n=t.map(function(t){return t.map(function(t){return[[t[0][0]*p/180,t[0][1]*p/180],[t[1][0]*p/180,t[1][1]*p/180],[t[2][0]*p/180,t[2][1]*p/180]]})}),r=n.map(function(t){return t.map(function(t){var r,n=e(t[0][0],t[0][1])[0],i=e(t[2][0],t[2][1])[0],a=e(t[1][0],t[0][1])[1],o=e(t[1][0],t[1][1])[1];return a>o&&(r=a,a=o,o=r),[[n,a],[i,o]]})}),a):n.map(function(t){return t.map(function(t){return[[180*t[0][0]/p,180*t[0][1]/p],[180*t[1][0]/p,180*t[1][1]/p],[180*t[2][0]/p,180*t[2][1]/p]]})})},a},_.invert=function(t,e){var r=.5*e*Math.sqrt((4+p)/p),n=m(r),i=Math.cos(n);return[t/(2/Math.sqrt(p*(4+p))*(1+i)),m((n+r*(i+2))/(2+d))]},(t.geo.eckert4=function(){return x(_)}).raw=_;var w=t.geo.azimuthalEqualArea.raw;function k(t,e){if(arguments.length<2&&(e=t),1===e)return w;if(e===1/0)return T;function r(r,n){var i=w(r/e,n);return i[0]*=t,i}return r.invert=function(r,n){var i=w.invert(r/t,n);return i[0]*=e,i},r}function T(t,e){return[t*Math.cos(e)/Math.cos(e/=2),2*Math.sin(e)]}function A(t,e){return[3*t/(2*p)*Math.sqrt(p*p/3-e*e),e]}function M(t,e){return[t,1.25*Math.log(Math.tan(p/4+.4*e))]}function S(t){return function(e){var r,n=t*Math.sin(e),i=30;do{e-=r=(e+Math.sin(e)-n)/(1+Math.cos(e))}while(Math.abs(r)>h&&--i>0);return e/2}}T.invert=function(t,e){var r=2*m(e/2);return[t*Math.cos(r/2)/Math.cos(r),r]},(t.geo.hammer=function(){var t=2,e=b(k),r=e(t);return r.coefficient=function(r){return arguments.length?e(t=+r):t},r}).raw=k,A.invert=function(t,e){return[2/3*p*t/Math.sqrt(p*p/3-e*e),e]},(t.geo.kavrayskiy7=function(){return x(A)}).raw=A,M.invert=function(t,e){return[t,2.5*Math.atan(Math.exp(.8*e))-.625*p]},(t.geo.miller=function(){return x(M)}).raw=M,S(p);var E=function(t,e,r){var n=S(r);function i(r,i){return[t*r*Math.cos(i=n(i)),e*Math.sin(i)]}return i.invert=function(n,i){var a=m(i/e);return[n/(t*Math.cos(a)),m((2*a+Math.sin(2*a))/r)]},i}(Math.SQRT2/d,Math.SQRT2,p);function C(t,e){var r=e*e,n=r*r;return[t*(.8707-.131979*r+n*(n*(.003971*r-.001529*n)-.013791)),e*(1.007226+r*(.015085+n*(.028874*r-.044475-.005916*n)))]}(t.geo.mollweide=function(){return x(E)}).raw=E,C.invert=function(t,e){var r,n=e,i=25;do{var a=n*n,o=a*a;n-=r=(n*(1.007226+a*(.015085+o*(.028874*a-.044475-.005916*o)))-e)/(1.007226+a*(.045255+o*(.259866*a-.311325-.005916*11*o)))}while(Math.abs(r)>h&&--i>0);return[t/(.8707+(a=n*n)*(a*(a*a*a*(.003971-.001529*a)-.013791)-.131979)),n]},(t.geo.naturalEarth=function(){return x(C)}).raw=C;var L=[[.9986,-.062],[1,0],[.9986,.062],[.9954,.124],[.99,.186],[.9822,.248],[.973,.31],[.96,.372],[.9427,.434],[.9216,.4958],[.8962,.5571],[.8679,.6176],[.835,.6769],[.7986,.7346],[.7597,.7903],[.7186,.8435],[.6732,.8936],[.6213,.9394],[.5722,.9761],[.5322,1]];function P(t,e){var r,n=Math.min(18,36*Math.abs(e)/p),i=Math.floor(n),a=n-i,o=(r=L[i])[0],s=r[1],l=(r=L[++i])[0],c=r[1],u=(r=L[Math.min(19,++i)])[0],h=r[1];return[t*(l+a*(u-o)/2+a*a*(u-2*l+o)/2),(e>0?d:-d)*(c+a*(h-s)/2+a*a*(h-2*c+s)/2)]}function O(t,e){return[t*Math.cos(e),e]}function z(t,e){var r,n=Math.cos(e),i=(r=y(n*Math.cos(t/=2)))?r/Math.sin(r):1;return[2*n*Math.sin(t)*i,Math.sin(e)*i]}function I(t,e){var r=z(t,e);return[(r[0]+t/d)/2,(r[1]+e)/2]}L.forEach(function(t){t[1]*=1.0144}),P.invert=function(t,e){var r=e/d,n=90*r,i=Math.min(18,Math.abs(n/5)),a=Math.max(0,Math.floor(i));do{var o=L[a][1],s=L[a+1][1],l=L[Math.min(19,a+2)][1],c=l-o,u=l-2*s+o,h=2*(Math.abs(r)-s)/c,p=u/c,m=h*(1-p*h*(1-2*p*h));if(m>=0||1===a){n=(e>=0?5:-5)*(m+i);var y,x=50;do{m=(i=Math.min(18,Math.abs(n)/5))-(a=Math.floor(i)),o=L[a][1],s=L[a+1][1],l=L[Math.min(19,a+2)][1],n-=(y=(e>=0?d:-d)*(s+m*(l-o)/2+m*m*(l-2*s+o)/2)-e)*v}while(Math.abs(y)>f&&--x>0);break}}while(--a>=0);var b=L[a][0],_=L[a+1][0],w=L[Math.min(19,a+2)][0];return[t/(_+m*(w-b)/2+m*m*(w-2*_+b)/2),n*g]},(t.geo.robinson=function(){return x(P)}).raw=P,O.invert=function(t,e){return[t/Math.cos(e),e]},(t.geo.sinusoidal=function(){return x(O)}).raw=O,z.invert=function(t,e){if(!(t*t+4*e*e>p*p+h)){var r=t,n=e,i=25;do{var a,o=Math.sin(r),s=Math.sin(r/2),l=Math.cos(r/2),c=Math.sin(n),u=Math.cos(n),f=Math.sin(2*n),d=c*c,g=u*u,v=s*s,m=1-g*l*l,x=m?y(u*l)*Math.sqrt(a=1/m):a=0,b=2*x*u*s-t,_=x*c-e,w=a*(g*v+x*u*l*d),k=a*(.5*o*f-2*x*c*s),T=.25*a*(f*s-x*c*g*o),A=a*(d*l+x*v*u),M=k*T-A*w;if(!M)break;var S=(_*k-b*A)/M,E=(b*T-_*w)/M;r-=S,n-=E}while((Math.abs(S)>h||Math.abs(E)>h)&&--i>0);return[r,n]}},(t.geo.aitoff=function(){return x(z)}).raw=z,I.invert=function(t,e){var r=t,n=e,i=25;do{var a,o=Math.cos(n),s=Math.sin(n),l=Math.sin(2*n),c=s*s,u=o*o,f=Math.sin(r),p=Math.cos(r/2),g=Math.sin(r/2),v=g*g,m=1-u*p*p,x=m?y(o*p)*Math.sqrt(a=1/m):a=0,b=.5*(2*x*o*g+r/d)-t,_=.5*(x*s+n)-e,w=.5*a*(u*v+x*o*p*c)+.5/d,k=a*(f*l/4-x*s*g),T=.125*a*(l*g-x*s*u*f),A=.5*a*(c*p+x*v*o)+.5,M=k*T-A*w,S=(_*k-b*A)/M,E=(b*T-_*w)/M;r-=S,n-=E}while((Math.abs(S)>h||Math.abs(E)>h)&&--i>0);return[r,n]},(t.geo.winkel3=function(){return x(I)}).raw=I}},{}],801:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=Math.PI/180,s=180/Math.PI,l={cursor:\"pointer\"},c={cursor:\"auto\"};function u(t,e){return n.behavior.zoom().translate(e.translate()).scale(e.scale())}function h(t,e,r){var n=t.id,o=t.graphDiv,s=o.layout,l=s[n],c=o._fullLayout,u=c[n],h={},f={};function p(t,e){h[n+\".\"+t]=i.nestedProperty(l,t).get(),a.call(\"_storeDirectGUIEdit\",s,c._preGUI,h);var r=i.nestedProperty(u,t);r.get()!==e&&(r.set(e),i.nestedProperty(l,t).set(e),f[n+\".\"+t]=e)}r(p),p(\"projection.scale\",e.scale()/t.fitScale),o.emit(\"plotly_relayout\",f)}function f(t,e){var r=u(0,e);function i(r){var n=e.invert(t.midPt);r(\"center.lon\",n[0]),r(\"center.lat\",n[1])}return r.on(\"zoomstart\",function(){n.select(this).style(l)}).on(\"zoom\",function(){e.scale(n.event.scale).translate(n.event.translate),t.render();var r=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":r[0],\"geo.center.lat\":r[1]})}).on(\"zoomend\",function(){n.select(this).style(c),h(t,e,i)}),r}function p(t,e){var r,i,a,o,s,f,p,d,g,v=u(0,e),m=2;function y(t){return e.invert(t)}function x(r){var n=e.rotate(),i=e.invert(t.midPt);r(\"projection.rotation.lon\",-n[0]),r(\"center.lon\",i[0]),r(\"center.lat\",i[1])}return v.on(\"zoomstart\",function(){n.select(this).style(l),r=n.mouse(this),i=e.rotate(),a=e.translate(),o=i,s=y(r)}).on(\"zoom\",function(){if(f=n.mouse(this),function(t){var r=y(t);if(!r)return!0;var n=e(r);return Math.abs(n[0]-t[0])>m||Math.abs(n[1]-t[1])>m}(r))return v.scale(e.scale()),void v.translate(e.translate());e.scale(n.event.scale),e.translate([a[0],n.event.translate[1]]),s?y(f)&&(d=y(f),p=[o[0]+(d[0]-s[0]),i[1],i[2]],e.rotate(p),o=p):s=y(r=f),g=!0,t.render();var l=e.rotate(),c=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":c[0],\"geo.center.lat\":c[1],\"geo.projection.rotation.lon\":-l[0]})}).on(\"zoomend\",function(){n.select(this).style(c),g&&h(t,e,x)}),v}function d(t,e){var r,i={r:e.rotate(),k:e.scale()},a=u(0,e),f=function(t){var e=0,r=arguments.length,i=[];for(;++e<r;)i.push(arguments[e]);var a=n.dispatch.apply(null,i);return a.of=function(e,r){return function(i){var o;try{o=i.sourceEvent=n.event,i.target=t,n.event=i,a[i.type].apply(e,r)}finally{n.event=o}}},a}(a,\"zoomstart\",\"zoom\",\"zoomend\"),p=0,d=a.on;function m(t){var r=e.rotate();t(\"projection.rotation.lon\",-r[0]),t(\"projection.rotation.lat\",-r[1])}return a.on(\"zoomstart\",function(){n.select(this).style(l);var t,c,u,h,m,b,_,w,k,T,A,M=n.mouse(this),S=e.rotate(),E=S,C=e.translate(),L=(c=.5*(t=S)[0]*o,u=.5*t[1]*o,h=.5*t[2]*o,m=Math.sin(c),b=Math.cos(c),_=Math.sin(u),w=Math.cos(u),k=Math.sin(h),T=Math.cos(h),[b*w*T+m*_*k,m*w*T-b*_*k,b*_*T+m*w*k,b*w*k-m*_*T]);r=g(e,M),d.call(a,\"zoom\",function(){var t,a,o,l,c,u,h,p,d,m,b=n.mouse(this);if(e.scale(i.k=n.event.scale),r){if(g(e,b)){e.rotate(S).translate(C);var _=g(e,b),w=function(t,e){if(!t||!e)return;var r=function(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}(t,e),n=Math.sqrt(x(r,r)),i=.5*Math.acos(Math.max(-1,Math.min(1,x(t,e)))),a=Math.sin(i)/n;return n&&[Math.cos(i),r[2]*a,-r[1]*a,r[0]*a]}(r,_),k=function(t){return[Math.atan2(2*(t[0]*t[1]+t[2]*t[3]),1-2*(t[1]*t[1]+t[2]*t[2]))*s,Math.asin(Math.max(-1,Math.min(1,2*(t[0]*t[2]-t[3]*t[1]))))*s,Math.atan2(2*(t[0]*t[3]+t[1]*t[2]),1-2*(t[2]*t[2]+t[3]*t[3]))*s]}((a=w,o=(t=L)[0],l=t[1],c=t[2],u=t[3],h=a[0],p=a[1],d=a[2],m=a[3],[o*h-l*p-c*d-u*m,o*p+l*h+c*m-u*d,o*d-l*m+c*h+u*p,o*m+l*d-c*p+u*h])),T=i.r=function(t,e,r){var n=y(e,2,t[0]);n=y(n,1,t[1]),n=y(n,0,t[2]-r[2]);var i,a,o=e[0],l=e[1],c=e[2],u=n[0],h=n[1],f=n[2],p=Math.atan2(l,o)*s,d=Math.sqrt(o*o+l*l);Math.abs(h)>d?(a=(h>0?90:-90)-p,i=0):(a=Math.asin(h/d)*s-p,i=Math.sqrt(d*d-h*h));var g=180-a-2*p,m=(Math.atan2(f,u)-Math.atan2(c,i))*s,x=(Math.atan2(f,u)-Math.atan2(c,-i))*s,b=v(r[0],r[1],a,m),_=v(r[0],r[1],g,x);return b<=_?[a,m,r[2]]:[g,x,r[2]]}(k,r,E);isFinite(T[0])&&isFinite(T[1])&&isFinite(T[2])||(T=E),e.rotate(T),E=T}}else r=g(e,M=b);f.of(this,arguments)({type:\"zoom\"})}),A=f.of(this,arguments),p++||A({type:\"zoomstart\"})}).on(\"zoomend\",function(){var r;n.select(this).style(c),d.call(a,\"zoom\",null),r=f.of(this,arguments),--p||r({type:\"zoomend\"}),h(t,e,m)}).on(\"zoom.redraw\",function(){t.render();var r=e.rotate();t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.projection.rotation.lon\":-r[0],\"geo.projection.rotation.lat\":-r[1]})}),n.rebind(a,f,\"on\")}function g(t,e){var r=t.invert(e);return r&&isFinite(r[0])&&isFinite(r[1])&&function(t){var e=t[0]*o,r=t[1]*o,n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}(r)}function v(t,e,r,n){var i=m(r-t),a=m(n-e);return Math.sqrt(i*i+a*a)}function m(t){return(t%360+540)%360-180}function y(t,e,r){var n=r*o,i=t.slice(),a=0===e?1:0,s=2===e?1:2,l=Math.cos(n),c=Math.sin(n);return i[a]=t[a]*l-t[s]*c,i[s]=t[s]*l+t[a]*c,i}function x(t,e){for(var r=0,n=0,i=t.length;n<i;++n)r+=t[n]*e[n];return r}e.exports=function(t,e){var r=t.projection;return(e._isScoped?f:e._isClipped?d:p)(t,r)}},{\"../../lib\":719,\"../../registry\":847,d3:163}],802:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"./cartesian/constants\").SUBPLOT_PATTERN;r.getSubplotCalcData=function(t,e,r){var i=n.subplotsRegistry[e];if(!i)return[];for(var a=i.attr,o=[],s=0;s<t.length;s++){var l=t[s];l[0].trace[a]===r&&o.push(l)}return o},r.getModuleCalcData=function(t,e){var r,i=[],a=[];if(!(r=\"string\"==typeof e?n.getModule(e).plot:\"function\"==typeof e?e:e.plot))return[i,t];for(var o=0;o<t.length;o++){var s=t[o],l=s[0].trace;!0===l.visible&&0!==l._length&&(l._module.plot===r?i.push(s):a.push(s))}return[i,a]},r.getSubplotData=function(t,e,r){if(!n.subplotsRegistry[e])return[];var a,o,s,l=n.subplotsRegistry[e].attr,c=[];if(\"gl2d\"===e){var u=r.match(i);o=\"x\"+u[1],s=\"y\"+u[2]}for(var h=0;h<t.length;h++)a=t[h],\"gl2d\"===e&&n.traceIs(a,\"gl2d\")?a[l[0]]===o&&a[l[1]]===s&&c.push(a):a[l]===r&&c.push(a);return c}},{\"../registry\":847,\"./cartesian/constants\":773}],803:[function(t,e,r){\"use strict\";var n=t(\"mouse-change\"),i=t(\"mouse-wheel\"),a=t(\"mouse-event-offset\"),o=t(\"../cartesian/constants\"),s=t(\"has-passive-events\");function l(t,e){this.element=t,this.plot=e,this.mouseListener=null,this.wheelListener=null,this.lastInputTime=Date.now(),this.lastPos=[0,0],this.boxEnabled=!1,this.boxInited=!1,this.boxStart=[0,0],this.boxEnd=[0,0],this.dragStart=[0,0]}e.exports=function(t){var e=t.mouseContainer,r=t.glplot,c=new l(e,r);function u(){t.xaxis.autorange=!1,t.yaxis.autorange=!1}function h(e,n,i){var a,s,l=t.calcDataBox(),h=r.viewBox,f=c.lastPos[0],p=c.lastPos[1],d=o.MINDRAG*r.pixelRatio,g=o.MINZOOM*r.pixelRatio;function v(e,r,n){var i=Math.min(r,n),a=Math.max(r,n);i!==a?(l[e]=i,l[e+2]=a,c.dataBox=l,t.setRanges(l)):(t.selectBox.selectBox=[0,0,1,1],t.glplot.setDirty())}switch(n*=r.pixelRatio,i*=r.pixelRatio,i=h[3]-h[1]-i,t.fullLayout.dragmode){case\"zoom\":if(e){var m=n/(h[2]-h[0])*(l[2]-l[0])+l[0],y=i/(h[3]-h[1])*(l[3]-l[1])+l[1];c.boxInited||(c.boxStart[0]=m,c.boxStart[1]=y,c.dragStart[0]=n,c.dragStart[1]=i),c.boxEnd[0]=m,c.boxEnd[1]=y,c.boxInited=!0,c.boxEnabled||c.boxStart[0]===c.boxEnd[0]&&c.boxStart[1]===c.boxEnd[1]||(c.boxEnabled=!0);var x=Math.abs(c.dragStart[0]-n)<g,b=Math.abs(c.dragStart[1]-i)<g;if(!function(){for(var e=t.graphDiv._fullLayout._axisConstraintGroups,r=t.xaxis._id,n=t.yaxis._id,i=0;i<e.length;i++)if(-1!==e[i][r]){if(-1!==e[i][n])return!0;break}return!1}()||x&&b)x&&(c.boxEnd[0]=c.boxStart[0]),b&&(c.boxEnd[1]=c.boxStart[1]);else{a=c.boxEnd[0]-c.boxStart[0],s=c.boxEnd[1]-c.boxStart[1];var _=(l[3]-l[1])/(l[2]-l[0]);Math.abs(a*_)>Math.abs(s)?(c.boxEnd[1]=c.boxStart[1]+Math.abs(a)*_*(s>=0?1:-1),c.boxEnd[1]<l[1]?(c.boxEnd[1]=l[1],c.boxEnd[0]=c.boxStart[0]+(l[1]-c.boxStart[1])/Math.abs(_)):c.boxEnd[1]>l[3]&&(c.boxEnd[1]=l[3],c.boxEnd[0]=c.boxStart[0]+(l[3]-c.boxStart[1])/Math.abs(_))):(c.boxEnd[0]=c.boxStart[0]+Math.abs(s)/_*(a>=0?1:-1),c.boxEnd[0]<l[0]?(c.boxEnd[0]=l[0],c.boxEnd[1]=c.boxStart[1]+(l[0]-c.boxStart[0])*Math.abs(_)):c.boxEnd[0]>l[2]&&(c.boxEnd[0]=l[2],c.boxEnd[1]=c.boxStart[1]+(l[2]-c.boxStart[0])*Math.abs(_)))}}else c.boxEnabled?(a=c.boxStart[0]!==c.boxEnd[0],s=c.boxStart[1]!==c.boxEnd[1],a||s?(a&&(v(0,c.boxStart[0],c.boxEnd[0]),t.xaxis.autorange=!1),s&&(v(1,c.boxStart[1],c.boxEnd[1]),t.yaxis.autorange=!1),t.relayoutCallback()):t.glplot.setDirty(),c.boxEnabled=!1,c.boxInited=!1):c.boxInited&&(c.boxInited=!1);break;case\"pan\":c.boxEnabled=!1,c.boxInited=!1,e?(c.panning||(c.dragStart[0]=n,c.dragStart[1]=i),Math.abs(c.dragStart[0]-n)<d&&(n=c.dragStart[0]),Math.abs(c.dragStart[1]-i)<d&&(i=c.dragStart[1]),a=(f-n)*(l[2]-l[0])/(r.viewBox[2]-r.viewBox[0]),s=(p-i)*(l[3]-l[1])/(r.viewBox[3]-r.viewBox[1]),l[0]+=a,l[2]+=a,l[1]+=s,l[3]+=s,t.setRanges(l),c.panning=!0,c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations()):c.panning&&(c.panning=!1,t.relayoutCallback())}c.lastPos[0]=n,c.lastPos[1]=i}return c.mouseListener=n(e,h),e.addEventListener(\"touchstart\",function(t){var r=a(t.changedTouches[0],e);h(0,r[0],r[1]),h(1,r[0],r[1]),t.preventDefault()},!!s&&{passive:!1}),e.addEventListener(\"touchmove\",function(t){t.preventDefault();var r=a(t.changedTouches[0],e);h(1,r[0],r[1]),t.preventDefault()},!!s&&{passive:!1}),e.addEventListener(\"touchend\",function(t){h(0,c.lastPos[0],c.lastPos[1]),t.preventDefault()},!!s&&{passive:!1}),c.wheelListener=i(e,function(e,n){if(!t.scrollZoom)return!1;var i=t.calcDataBox(),a=r.viewBox,o=c.lastPos[0],s=c.lastPos[1],l=Math.exp(5*n/(a[3]-a[1])),h=o/(a[2]-a[0])*(i[2]-i[0])+i[0],f=s/(a[3]-a[1])*(i[3]-i[1])+i[1];return i[0]=(i[0]-h)*l+h,i[2]=(i[2]-h)*l+h,i[1]=(i[1]-f)*l+f,i[3]=(i[3]-f)*l+f,t.setRanges(i),c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations(),t.relayoutCallback(),!0},!0),c}},{\"../cartesian/constants\":773,\"has-passive-events\":411,\"mouse-change\":435,\"mouse-event-offset\":436,\"mouse-wheel\":438}],804:[function(t,e,r){\"use strict\";var n=t(\"../cartesian/axes\"),i=t(\"../../lib/str2rgbarray\");function a(t){this.scene=t,this.gl=t.gl,this.pixelRatio=t.pixelRatio,this.screenBox=[0,0,1,1],this.viewBox=[0,0,1,1],this.dataBox=[-1,-1,1,1],this.borderLineEnable=[!1,!1,!1,!1],this.borderLineWidth=[1,1,1,1],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.ticks=[[],[]],this.tickEnable=[!0,!0,!1,!1],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labels=[\"x\",\"y\"],this.labelEnable=[!0,!0,!1,!1],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelPad=[15,15,15,15],this.labelSize=[12,12],this.labelFont=[\"sans-serif\",\"sans-serif\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.title=\"\",this.titleEnable=!0,this.titleCenter=[0,0,0,0],this.titleAngle=0,this.titleColor=[0,0,0,1],this.titleFont=\"sans-serif\",this.titleSize=18,this.gridLineEnable=[!0,!0],this.gridLineColor=[[0,0,0,.5],[0,0,0,.5]],this.gridLineWidth=[1,1],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[1,1],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.static=this.scene.staticPlot}var o=a.prototype,s=[\"xaxis\",\"yaxis\"];o.merge=function(t){var e,r,n,a,o,l,c,u,h,f,p;for(this.titleEnable=!1,this.backgroundColor=i(t.plot_bgcolor),f=0;f<2;++f){var d=(e=s[f]).charAt(0);for(n=(r=t[this.scene[e]._name]).title.text===this.scene.fullLayout._dfltTitle[d]?\"\":r.title.text,p=0;p<=2;p+=2)this.labelEnable[f+p]=!1,this.labels[f+p]=n,this.labelColor[f+p]=i(r.title.font.color),this.labelFont[f+p]=r.title.font.family,this.labelSize[f+p]=r.title.font.size,this.labelPad[f+p]=this.getLabelPad(e,r),this.tickEnable[f+p]=!1,this.tickColor[f+p]=i((r.tickfont||{}).color),this.tickAngle[f+p]=\"auto\"===r.tickangle?0:Math.PI*-r.tickangle/180,this.tickPad[f+p]=this.getTickPad(r),this.tickMarkLength[f+p]=0,this.tickMarkWidth[f+p]=r.tickwidth||0,this.tickMarkColor[f+p]=i(r.tickcolor),this.borderLineEnable[f+p]=!1,this.borderLineColor[f+p]=i(r.linecolor),this.borderLineWidth[f+p]=r.linewidth||0;c=this.hasSharedAxis(r),o=this.hasAxisInDfltPos(e,r)&&!c,l=this.hasAxisInAltrPos(e,r)&&!c,a=r.mirror||!1,u=c?-1!==String(a).indexOf(\"all\"):!!a,h=c?\"allticks\"===a:-1!==String(a).indexOf(\"ticks\"),o?this.labelEnable[f]=!0:l&&(this.labelEnable[f+2]=!0),o?this.tickEnable[f]=r.showticklabels:l&&(this.tickEnable[f+2]=r.showticklabels),(o||u)&&(this.borderLineEnable[f]=r.showline),(l||u)&&(this.borderLineEnable[f+2]=r.showline),(o||h)&&(this.tickMarkLength[f]=this.getTickMarkLength(r)),(l||h)&&(this.tickMarkLength[f+2]=this.getTickMarkLength(r)),this.gridLineEnable[f]=r.showgrid,this.gridLineColor[f]=i(r.gridcolor),this.gridLineWidth[f]=r.gridwidth,this.zeroLineEnable[f]=r.zeroline,this.zeroLineColor[f]=i(r.zerolinecolor),this.zeroLineWidth[f]=r.zerolinewidth}},o.hasSharedAxis=function(t){var e=this.scene,r=e.fullLayout._subplots.gl2d;return 0!==n.findSubplotsWithAxis(r,t).indexOf(e.id)},o.hasAxisInDfltPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"bottom\"===r:\"yaxis\"===t?\"left\"===r:void 0},o.hasAxisInAltrPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"top\"===r:\"yaxis\"===t?\"right\"===r:void 0},o.getLabelPad=function(t,e){var r=e.title.font.size,n=e.showticklabels;return\"xaxis\"===t?\"top\"===e.side?r*(1.5+(n?1:0))-10:r*(1.5+(n?.5:0))-10:\"yaxis\"===t?\"right\"===e.side?10+r*(1.5+(n?1:.5)):10+r*(1.5+(n?.5:0)):void 0},o.getTickPad=function(t){return\"outside\"===t.ticks?10+t.ticklen:15},o.getTickMarkLength=function(t){if(!t.ticks)return 0;var e=t.ticklen;return\"inside\"===t.ticks?-e:e},e.exports=function(t){return new a(t)}},{\"../../lib/str2rgbarray\":742,\"../cartesian/axes\":767}],805:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"./scene2d\"),a=t(\"../layout_attributes\"),o=t(\"../../constants/xmlns_namespaces\"),s=t(\"../cartesian/constants\"),l=t(\"../cartesian\"),c=t(\"../../components/fx/layout_attributes\"),u=t(\"../get_data\").getSubplotData;r.name=\"gl2d\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=s.idRegex,r.attrRegex=s.attrRegex,r.attributes=t(\"../cartesian/attributes\"),r.supplyLayoutDefaults=function(t,e,r){e._has(\"cartesian\")||l.supplyLayoutDefaults(t,e,r)},r.layoutAttrOverrides=n(l.layoutAttributes,\"plot\",\"from-root\"),r.baseLayoutAttrOverrides=n({plot_bgcolor:a.plot_bgcolor,hoverlabel:c.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl2d,a=0;a<n.length;a++){var o=n[a],s=e._plots[o],l=u(r,\"gl2d\",o),c=s._scene2d;void 0===c&&(c=new i({id:o,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio},e),s._scene2d=c),c.plot(l,t.calcdata,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl2d||[],a=0;a<i.length;a++){var o=i[a],s=n._plots[o];if(s._scene2d)0===u(t,\"gl2d\",o).length&&(s._scene2d.destroy(),delete n._plots[o])}l.clean.apply(this,arguments)},r.drawFramework=function(t){t._context.staticPlot||l.drawFramework(t)},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){var i=e._plots[r[n]]._scene2d,a=i.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":a,x:0,y:0,width:\"100%\",height:\"100%\",preserveAspectRatio:\"none\"}),i.destroy()}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){e._plots[r[n]]._scene2d.updateFx(e.dragmode)}}},{\"../../components/fx/layout_attributes\":633,\"../../constants/xmlns_namespaces\":696,\"../../plot_api/edit_types\":750,\"../cartesian\":778,\"../cartesian/attributes\":765,\"../cartesian/constants\":773,\"../get_data\":802,\"../layout_attributes\":819,\"./scene2d\":806}],806:[function(t,e,r){\"use strict\";var n,i,a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../../components/fx\"),l=t(\"gl-plot2d\"),c=t(\"gl-spikes2d\"),u=t(\"gl-select-box\"),h=t(\"webgl-context\"),f=t(\"./convert\"),p=t(\"./camera\"),d=t(\"../../lib/show_no_webgl_msg\"),g=t(\"../cartesian/constraints\"),v=g.enforce,m=g.clean,y=t(\"../cartesian/autorange\").doAutoRange,x=[\"xaxis\",\"yaxis\"],b=t(\"../cartesian/constants\").SUBPLOT_PATTERN;function _(t,e){this.container=t.container,this.graphDiv=t.graphDiv,this.pixelRatio=t.plotGlPixelRatio||window.devicePixelRatio,this.id=t.id,this.staticPlot=!!t.staticPlot,this.scrollZoom=this.graphDiv._context._scrollZoom.cartesian,this.fullData=null,this.updateRefs(e),this.makeFramework(),this.stopped||(this.glplotOptions=f(this),this.glplotOptions.merge(e),this.glplot=l(this.glplotOptions),this.camera=p(this),this.traces={},this.spikes=c(this.glplot),this.selectBox=u(this.glplot,{innerFill:!1,outerFill:!0}),this.lastButtonState=0,this.pickResult=null,this.isMouseOver=!0,this.stopped=!1,this.redraw=this.draw.bind(this),this.redraw())}e.exports=_;var w=_.prototype;w.makeFramework=function(){if(this.staticPlot){if(!(i||(n=document.createElement(\"canvas\"),i=h({canvas:n,preserveDrawingBuffer:!1,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"Error creating static canvas/context for image server\");this.canvas=n,this.gl=i}else{var t=this.container.querySelector(\".gl-canvas-focus\"),e=h({canvas:t,preserveDrawingBuffer:!0,premultipliedAlpha:!0});if(!e)return d(this),void(this.stopped=!0);this.canvas=t,this.gl=e}var r=this.canvas;r.style.width=\"100%\",r.style.height=\"100%\",r.style.position=\"absolute\",r.style.top=\"0px\",r.style.left=\"0px\",r.style[\"pointer-events\"]=\"none\",this.updateSize(r),r.className+=\" user-select-none\";var a=this.svgContainer=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");a.style.position=\"absolute\",a.style.top=a.style.left=\"0px\",a.style.width=a.style.height=\"100%\",a.style[\"z-index\"]=20,a.style[\"pointer-events\"]=\"none\";var o=this.mouseContainer=document.createElement(\"div\");o.style.position=\"absolute\",o.style[\"pointer-events\"]=\"auto\",this.pickCanvas=this.container.querySelector(\".gl-canvas-pick\");var s=this.container;s.appendChild(a),s.appendChild(o);var l=this;o.addEventListener(\"mouseout\",function(){l.isMouseOver=!1,l.unhover()}),o.addEventListener(\"mouseover\",function(){l.isMouseOver=!0})},w.toImage=function(t){t||(t=\"png\"),this.stopped=!0,this.staticPlot&&this.container.appendChild(n),this.updateSize(this.canvas);var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.clearColor(1,1,1,0),e.clear(e.COLOR_BUFFER_BIT|e.DEPTH_BUFFER_BIT),this.glplot.setDirty(),this.glplot.draw(),e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a);for(var o=0,s=i-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=a[4*(r*o+l)+c];a[4*(r*o+l)+c]=a[4*(r*s+l)+c],a[4*(r*s+l)+c]=u}var h=document.createElement(\"canvas\");h.width=r,h.height=i;var f,p=h.getContext(\"2d\"),d=p.createImageData(r,i);switch(d.data.set(a),p.putImageData(d,0,0),t){case\"jpeg\":f=h.toDataURL(\"image/jpeg\");break;case\"webp\":f=h.toDataURL(\"image/webp\");break;default:f=h.toDataURL(\"image/png\")}return this.staticPlot&&this.container.removeChild(n),f},w.updateSize=function(t){t||(t=this.canvas);var e=this.pixelRatio,r=this.fullLayout,n=r.width,i=r.height,a=0|Math.ceil(e*n),o=0|Math.ceil(e*i);return t.width===a&&t.height===o||(t.width=a,t.height=o),t},w.computeTickMarks=function(){this.xaxis.setScale(),this.yaxis.setScale();for(var t=[o.calcTicks(this.xaxis),o.calcTicks(this.yaxis)],e=0;e<2;++e)for(var r=0;r<t[e].length;++r)t[e][r].text=t[e][r].text+\"\";return t},w.updateRefs=function(t){this.fullLayout=t;var e=this.id.match(b),r=\"xaxis\"+e[1],n=\"yaxis\"+e[2];this.xaxis=this.fullLayout[r],this.yaxis=this.fullLayout[n]},w.relayoutCallback=function(){var t=this.graphDiv,e=this.xaxis,r=this.yaxis,n=t.layout,i={},o=i[e._name+\".range\"]=e.range.slice(),s=i[r._name+\".range\"]=r.range.slice();i[e._name+\".autorange\"]=e.autorange,i[r._name+\".autorange\"]=r.autorange,a.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,i);var l=n[e._name];l.range=o,l.autorange=e.autorange;var c=n[r._name];c.range=s,c.autorange=r.autorange,i.lastInputTime=this.camera.lastInputTime,t.emit(\"plotly_relayout\",i)},w.cameraChanged=function(){var t=this.camera;this.glplot.setDataBox(this.calcDataBox());var e=this.computeTickMarks();(function(t,e){for(var r=0;r<2;++r){var n=t[r],i=e[r];if(n.length!==i.length)return!0;for(var a=0;a<n.length;++a)if(n[a].x!==i[a].x)return!0}return!1})(e,this.glplotOptions.ticks)&&(this.glplotOptions.ticks=e,this.glplotOptions.dataBox=t.dataBox,this.glplot.update(this.glplotOptions),this.handleAnnotations())},w.handleAnnotations=function(){for(var t=this.graphDiv,e=this.fullLayout.annotations,r=0;r<e.length;r++){var n=e[r];n.xref===this.xaxis._id&&n.yref===this.yaxis._id&&a.getComponentMethod(\"annotations\",\"drawOne\")(t,r)}},w.destroy=function(){if(this.glplot){var t=this.traces;t&&Object.keys(t).map(function(e){t[e].dispose(),delete t[e]}),this.glplot.dispose(),this.container.removeChild(this.svgContainer),this.container.removeChild(this.mouseContainer),this.fullData=null,this.glplot=null,this.stopped=!0,this.camera.mouseListener.enabled=!1,this.mouseContainer.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=null}},w.plot=function(t,e,r){var n=this.glplot;this.updateRefs(r),this.xaxis.clearCalc(),this.yaxis.clearCalc(),this.updateTraces(t,e),this.updateFx(r.dragmode);var i=r.width,a=r.height;this.updateSize(this.canvas);var o=this.glplotOptions;o.merge(r),o.screenBox=[0,0,i,a];var s={_fullLayout:{_axisConstraintGroups:this.graphDiv._fullLayout._axisConstraintGroups,xaxis:this.xaxis,yaxis:this.yaxis}};m(s,this.xaxis),m(s,this.yaxis);var l,c,u=r._size,h=this.xaxis.domain,f=this.yaxis.domain;for(o.viewBox=[u.l+h[0]*u.w,u.b+f[0]*u.h,i-u.r-(1-h[1])*u.w,a-u.t-(1-f[1])*u.h],this.mouseContainer.style.width=u.w*(h[1]-h[0])+\"px\",this.mouseContainer.style.height=u.h*(f[1]-f[0])+\"px\",this.mouseContainer.height=u.h*(f[1]-f[0]),this.mouseContainer.style.left=u.l+h[0]*u.w+\"px\",this.mouseContainer.style.top=u.t+(1-f[1])*u.h+\"px\",c=0;c<2;++c)(l=this[x[c]])._length=o.viewBox[c+2]-o.viewBox[c],y(this.graphDiv,l),l.setScale();v(s),o.ticks=this.computeTickMarks(),o.dataBox=this.calcDataBox(),o.merge(r),n.update(o),this.glplot.draw()},w.calcDataBox=function(){var t=this.xaxis,e=this.yaxis,r=t.range,n=e.range,i=t.r2l,a=e.r2l;return[i(r[0]),a(n[0]),i(r[1]),a(n[1])]},w.setRanges=function(t){var e=this.xaxis,r=this.yaxis,n=e.l2r,i=r.l2r;e.range=[n(t[0]),n(t[2])],r.range=[i(t[1]),i(t[3])]},w.updateTraces=function(t,e){var r,n,i,a=Object.keys(this.traces);this.fullData=t;t:for(r=0;r<a.length;r++){var o=a[r],s=this.traces[o];for(n=0;n<t.length;n++)if((i=t[n]).uid===o&&i.type===s.type)continue t;s.dispose(),delete this.traces[o]}for(r=0;r<t.length;r++){i=t[r];var l=e[r],c=this.traces[i.uid];c?c.update(i,l):(c=i._module.plot(this,i,l),this.traces[i.uid]=c)}this.glplot.objects.sort(function(t,e){return t._trace.index-e._trace.index})},w.updateFx=function(t){\"lasso\"===t||\"select\"===t?(this.pickCanvas.style[\"pointer-events\"]=\"none\",this.mouseContainer.style[\"pointer-events\"]=\"none\"):(this.pickCanvas.style[\"pointer-events\"]=\"auto\",this.mouseContainer.style[\"pointer-events\"]=\"auto\"),this.mouseContainer.style.cursor=\"pan\"===t?\"move\":\"zoom\"===t?\"crosshair\":null},w.emitPointAction=function(t,e){for(var r,n=t.trace.uid,i=t.pointIndex,a=0;a<this.fullData.length;a++)this.fullData[a].uid===n&&(r=this.fullData[a]);var o={x:t.traceCoord[0],y:t.traceCoord[1],curveNumber:r.index,pointNumber:i,data:r._input,fullData:this.fullData,xaxis:this.xaxis,yaxis:this.yaxis};s.appendArrayPointValue(o,r,i),this.graphDiv.emit(e,{points:[o]})},w.draw=function(){if(!this.stopped){requestAnimationFrame(this.redraw);var t=this.glplot,e=this.camera,r=e.mouseListener,n=1===this.lastButtonState&&0===r.buttons,i=this.fullLayout;this.lastButtonState=r.buttons,this.cameraChanged();var a,o=r.x*t.pixelRatio,l=this.canvas.height-t.pixelRatio*r.y;if(e.boxEnabled&&\"zoom\"===i.dragmode){this.selectBox.enabled=!0;for(var c=this.selectBox.selectBox=[Math.min(e.boxStart[0],e.boxEnd[0]),Math.min(e.boxStart[1],e.boxEnd[1]),Math.max(e.boxStart[0],e.boxEnd[0]),Math.max(e.boxStart[1],e.boxEnd[1])],u=0;u<2;u++)e.boxStart[u]===e.boxEnd[u]&&(c[u]=t.dataBox[u],c[u+2]=t.dataBox[u+2]);t.setDirty()}else if(!e.panning&&this.isMouseOver){this.selectBox.enabled=!1;var h=i._size,f=this.xaxis.domain,p=this.yaxis.domain,d=(a=t.pick(o/t.pixelRatio+h.l+f[0]*h.w,l/t.pixelRatio-(h.t+(1-p[1])*h.h)))&&a.object._trace.handlePick(a);if(d&&n&&this.emitPointAction(d,\"plotly_click\"),a&&\"skip\"!==a.object._trace.hoverinfo&&i.hovermode&&d&&(!this.lastPickResult||this.lastPickResult.traceUid!==d.trace.uid||this.lastPickResult.dataCoord[0]!==d.dataCoord[0]||this.lastPickResult.dataCoord[1]!==d.dataCoord[1])){var g=d;this.lastPickResult={traceUid:d.trace?d.trace.uid:null,dataCoord:d.dataCoord.slice()},this.spikes.update({center:a.dataCoord}),g.screenCoord=[((t.viewBox[2]-t.viewBox[0])*(a.dataCoord[0]-t.dataBox[0])/(t.dataBox[2]-t.dataBox[0])+t.viewBox[0])/t.pixelRatio,(this.canvas.height-(t.viewBox[3]-t.viewBox[1])*(a.dataCoord[1]-t.dataBox[1])/(t.dataBox[3]-t.dataBox[1])-t.viewBox[1])/t.pixelRatio],this.emitPointAction(d,\"plotly_hover\");var v=this.fullData[g.trace.index]||{},m=g.pointIndex,y=s.castHoverinfo(v,i,m);if(y&&\"all\"!==y){var x=y.split(\"+\");-1===x.indexOf(\"x\")&&(g.traceCoord[0]=void 0),-1===x.indexOf(\"y\")&&(g.traceCoord[1]=void 0),-1===x.indexOf(\"z\")&&(g.traceCoord[2]=void 0),-1===x.indexOf(\"text\")&&(g.textLabel=void 0),-1===x.indexOf(\"name\")&&(g.name=void 0)}s.loneHover({x:g.screenCoord[0],y:g.screenCoord[1],xLabel:this.hoverFormatter(\"xaxis\",g.traceCoord[0]),yLabel:this.hoverFormatter(\"yaxis\",g.traceCoord[1]),zLabel:g.traceCoord[2],text:g.textLabel,name:g.name,color:s.castHoverOption(v,m,\"bgcolor\")||g.color,borderColor:s.castHoverOption(v,m,\"bordercolor\"),fontFamily:s.castHoverOption(v,m,\"font.family\"),fontSize:s.castHoverOption(v,m,\"font.size\"),fontColor:s.castHoverOption(v,m,\"font.color\"),nameLength:s.castHoverOption(v,m,\"namelength\"),textAlign:s.castHoverOption(v,m,\"align\")},{container:this.svgContainer,gd:this.graphDiv})}}a||this.unhover(),t.draw()}},w.unhover=function(){this.lastPickResult&&(this.spikes.update({}),this.lastPickResult=null,this.graphDiv.emit(\"plotly_unhover\"),s.loneUnhover(this.svgContainer))},w.hoverFormatter=function(t,e){if(void 0!==e){var r=this[t];return o.tickText(r,r.c2l(e),\"hover\").text}}},{\"../../components/fx\":632,\"../../lib/show_no_webgl_msg\":740,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../cartesian/autorange\":766,\"../cartesian/constants\":773,\"../cartesian/constraints\":774,\"./camera\":803,\"./convert\":804,\"gl-plot2d\":287,\"gl-select-box\":299,\"gl-spikes2d\":308,\"webgl-context\":556}],807:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../components/fx/layout_attributes\"),a=t(\"./scene\"),o=t(\"../get_data\").getSubplotData,s=t(\"../../lib\"),l=t(\"../../constants/xmlns_namespaces\");r.name=\"gl3d\",r.attr=\"scene\",r.idRoot=\"scene\",r.idRegex=r.attrRegex=s.counterRegex(\"scene\"),r.attributes=t(\"./layout/attributes\"),r.layoutAttributes=t(\"./layout/layout_attributes\"),r.baseLayoutAttrOverrides=n({hoverlabel:i.hoverlabel},\"plot\",\"nested\"),r.supplyLayoutDefaults=t(\"./layout/defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl3d,i=0;i<n.length;i++){var s=n[i],l=o(r,\"gl3d\",s),c=e[s],u=c.camera,h=c._scene;h||(h=new a({id:s,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio,camera:u},e),c._scene=h),h.viewInitial||(h.viewInitial={up:{x:u.up.x,y:u.up.y,z:u.up.z},eye:{x:u.eye.x,y:u.eye.y,z:u.eye.z},center:{x:u.center.x,y:u.center.y,z:u.center.z}}),h.plot(l,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl3d||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._scene&&(n[o]._scene.destroy(),n._infolayer&&n._infolayer.selectAll(\".annotation-\"+o).remove())}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=e._size,i=0;i<r.length;i++){var a=e[r[i]],o=a.domain,s=a._scene,c=s.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:l.svg,\"xlink:href\":c,x:n.l+n.w*o.x[0],y:n.t+n.h*(1-o.y[1]),width:n.w*(o.x[1]-o.x[0]),height:n.h*(o.y[1]-o.y[0]),preserveAspectRatio:\"none\"}),s.destroy()}},r.cleanId=function(t){if(t.match(/^scene[0-9]*$/)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),\"scene\"+e}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){e[r[n]]._scene.updateFx(e.dragmode,e.hovermode)}}},{\"../../components/fx/layout_attributes\":633,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../plot_api/edit_types\":750,\"../get_data\":802,\"./layout/attributes\":808,\"./layout/defaults\":812,\"./layout/layout_attributes\":813,\"./scene\":817}],808:[function(t,e,r){\"use strict\";e.exports={scene:{valType:\"subplotid\",dflt:\"scene\",editType:\"calc+clearAxisTypes\"}}},{}],809:[function(t,e,r){\"use strict\";var n=t(\"../../../components/color\"),i=t(\"../../cartesian/layout_attributes\"),a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../plot_api/edit_types\").overrideAll;e.exports=o({visible:i.visible,showspikes:{valType:\"boolean\",dflt:!0},spikesides:{valType:\"boolean\",dflt:!0},spikethickness:{valType:\"number\",min:0,dflt:2},spikecolor:{valType:\"color\",dflt:n.defaultLine},showbackground:{valType:\"boolean\",dflt:!1},backgroundcolor:{valType:\"color\",dflt:\"rgba(204, 204, 204, 0.5)\"},showaxeslabels:{valType:\"boolean\",dflt:!0},color:i.color,categoryorder:i.categoryorder,categoryarray:i.categoryarray,title:i.title,type:a({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autorange:i.autorange,rangemode:i.rangemode,range:a({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],anim:!1}),tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,mirror:i.mirror,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,tickfont:i.tickfont,tickangle:i.tickangle,tickprefix:i.tickprefix,showtickprefix:i.showtickprefix,ticksuffix:i.ticksuffix,showticksuffix:i.showticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,separatethousands:i.separatethousands,tickformat:i.tickformat,tickformatstops:i.tickformatstops,hoverformat:i.hoverformat,showline:i.showline,linecolor:i.linecolor,linewidth:i.linewidth,showgrid:i.showgrid,gridcolor:a({},i.gridcolor,{dflt:\"rgb(204, 204, 204)\"}),gridwidth:i.gridwidth,zeroline:i.zeroline,zerolinecolor:i.zerolinecolor,zerolinewidth:i.zerolinewidth,_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}},\"plot\",\"from-root\")},{\"../../../components/color\":593,\"../../../lib/extend\":710,\"../../../plot_api/edit_types\":750,\"../../cartesian/layout_attributes\":779}],810:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../../lib\"),a=t(\"../../../plot_api/plot_template\"),o=t(\"./axis_attributes\"),s=t(\"../../cartesian/type_defaults\"),l=t(\"../../cartesian/axis_defaults\"),c=[\"xaxis\",\"yaxis\",\"zaxis\"];e.exports=function(t,e,r){var u,h;function f(t,e){return i.coerce(u,h,o,t,e)}for(var p=0;p<c.length;p++){var d=c[p];u=t[d]||{},(h=a.newContainer(e,d))._id=d[0]+r.scene,h._name=d,s(u,h,f,r),l(u,h,f,{font:r.font,letter:d[0],data:r.data,showGrid:!0,noTickson:!0,bgColor:r.bgColor,calendar:r.calendar},r.fullLayout),f(\"gridcolor\",n(h.color,r.bgColor,13600/187).toRgbString()),f(\"title.text\",d[0]),h.setScale=i.noop,f(\"showspikes\")&&(f(\"spikesides\"),f(\"spikethickness\"),f(\"spikecolor\",h.color)),f(\"showaxeslabels\"),f(\"showbackground\")&&f(\"backgroundcolor\")}}},{\"../../../lib\":719,\"../../../plot_api/plot_template\":757,\"../../cartesian/axis_defaults\":769,\"../../cartesian/type_defaults\":790,\"./axis_attributes\":809,tinycolor2:537}],811:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"];function o(){this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[18,18,18],this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=[\"Open Sans\",\"Open Sans\",\"Open Sans\"],this.labelSize=[20,20,20],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[30,30,30],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[10,10,10],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!0,!0,!0],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._defaultTickPad=this.tickPad.slice(),this._defaultLabelPad=this.labelPad.slice(),this._defaultLineTickLength=this.lineTickLength.slice()}o.prototype.merge=function(t,e){for(var r=0;r<3;++r){var o=e[a[r]];o.visible?(this.labels[r]=t._meta?i.templateString(o.title.text,t._meta):o.title.text,\"font\"in o.title&&(o.title.font.color&&(this.labelColor[r]=n(o.title.font.color)),o.title.font.family&&(this.labelFont[r]=o.title.font.family),o.title.font.size&&(this.labelSize[r]=o.title.font.size)),\"showline\"in o&&(this.lineEnable[r]=o.showline),\"linecolor\"in o&&(this.lineColor[r]=n(o.linecolor)),\"linewidth\"in o&&(this.lineWidth[r]=o.linewidth),\"showgrid\"in o&&(this.gridEnable[r]=o.showgrid),\"gridcolor\"in o&&(this.gridColor[r]=n(o.gridcolor)),\"gridwidth\"in o&&(this.gridWidth[r]=o.gridwidth),\"log\"===o.type?this.zeroEnable[r]=!1:\"zeroline\"in o&&(this.zeroEnable[r]=o.zeroline),\"zerolinecolor\"in o&&(this.zeroLineColor[r]=n(o.zerolinecolor)),\"zerolinewidth\"in o&&(this.zeroLineWidth[r]=o.zerolinewidth),\"ticks\"in o&&o.ticks?this.lineTickEnable[r]=!0:this.lineTickEnable[r]=!1,\"ticklen\"in o&&(this.lineTickLength[r]=this._defaultLineTickLength[r]=o.ticklen),\"tickcolor\"in o&&(this.lineTickColor[r]=n(o.tickcolor)),\"tickwidth\"in o&&(this.lineTickWidth[r]=o.tickwidth),\"tickangle\"in o&&(this.tickAngle[r]=\"auto\"===o.tickangle?-3600:Math.PI*-o.tickangle/180),\"showticklabels\"in o&&(this.tickEnable[r]=o.showticklabels),\"tickfont\"in o&&(o.tickfont.color&&(this.tickColor[r]=n(o.tickfont.color)),o.tickfont.family&&(this.tickFont[r]=o.tickfont.family),o.tickfont.size&&(this.tickSize[r]=o.tickfont.size)),\"mirror\"in o?-1!==[\"ticks\",\"all\",\"allticks\"].indexOf(o.mirror)?(this.lineTickMirror[r]=!0,this.lineMirror[r]=!0):!0===o.mirror?(this.lineTickMirror[r]=!1,this.lineMirror[r]=!0):(this.lineTickMirror[r]=!1,this.lineMirror[r]=!1):this.lineMirror[r]=!1,\"showbackground\"in o&&!1!==o.showbackground?(this.backgroundEnable[r]=!0,this.backgroundColor[r]=n(o.backgroundcolor)):this.backgroundEnable[r]=!1):(this.tickEnable[r]=!1,this.labelEnable[r]=!1,this.lineEnable[r]=!1,this.lineTickEnable[r]=!1,this.gridEnable[r]=!1,this.zeroEnable[r]=!1,this.backgroundEnable[r]=!1)}},e.exports=function(t,e){var r=new o;return r.merge(t,e),r}},{\"../../../lib\":719,\"../../../lib/str2rgbarray\":742}],812:[function(t,e,r){\"use strict\";var n=t(\"../../../lib\"),i=t(\"../../../components/color\"),a=t(\"../../../registry\"),o=t(\"../../subplot_defaults\"),s=t(\"./axis_defaults\"),l=t(\"./layout_attributes\"),c=t(\"../../get_data\").getSubplotData,u=\"gl3d\";function h(t,e,r,n){for(var o=r(\"bgcolor\"),l=i.combine(o,n.paper_bgcolor),h=[\"up\",\"center\",\"eye\"],f=0;f<h.length;f++)r(\"camera.\"+h[f]+\".x\"),r(\"camera.\"+h[f]+\".y\"),r(\"camera.\"+h[f]+\".z\");r(\"camera.projection.type\");var p=!!r(\"aspectratio.x\")&&!!r(\"aspectratio.y\")&&!!r(\"aspectratio.z\"),d=r(\"aspectmode\",p?\"manual\":\"auto\");p||(t.aspectratio=e.aspectratio={x:1,y:1,z:1},\"manual\"===d&&(e.aspectmode=\"auto\"),t.aspectmode=e.aspectmode);var g=c(n.fullData,u,n.id);s(t,e,{font:n.font,scene:n.id,data:g,bgColor:l,calendar:n.calendar,fullLayout:n.fullLayout}),a.getComponentMethod(\"annotations3d\",\"handleDefaults\")(t,e,n);var v=n.getDfltFromLayout(\"dragmode\");if(!1!==v&&!v)if(v=\"orbit\",t.camera&&t.camera.up){var m=t.camera.up.x,y=t.camera.up.y,x=t.camera.up.z;0!==x&&(m&&y&&x?x/Math.sqrt(m*m+y*y+x*x)>.999&&(v=\"turntable\"):v=\"turntable\")}else v=\"turntable\";r(\"dragmode\",v),r(\"hovermode\",n.getDfltFromLayout(\"hovermode\"))}e.exports=function(t,e,r){var i=e._basePlotModules.length>1;o(t,e,r,{type:u,attributes:l,handleDefaults:h,fullLayout:e,font:e.font,fullData:r,getDfltFromLayout:function(e){if(!i)return n.validate(t[e],l[e])?t[e]:void 0},paper_bgcolor:e.paper_bgcolor,calendar:e.calendar})}},{\"../../../components/color\":593,\"../../../lib\":719,\"../../../registry\":847,\"../../get_data\":802,\"../../subplot_defaults\":842,\"./axis_defaults\":810,\"./layout_attributes\":813}],813:[function(t,e,r){\"use strict\";var n=t(\"./axis_attributes\"),i=t(\"../../domain\").attributes,a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../lib\").counterRegex;function s(t,e,r){return{x:{valType:\"number\",dflt:t,editType:\"camera\"},y:{valType:\"number\",dflt:e,editType:\"camera\"},z:{valType:\"number\",dflt:r,editType:\"camera\"},editType:\"camera\"}}e.exports={_arrayAttrRegexps:[o(\"scene\",\".annotations\",!0)],bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"plot\"},camera:{up:a(s(0,0,1),{}),center:a(s(0,0,0),{}),eye:a(s(1.25,1.25,1.25),{}),projection:{type:{valType:\"enumerated\",values:[\"perspective\",\"orthographic\"],dflt:\"perspective\",editType:\"calc\"},editType:\"calc\"},editType:\"camera\"},domain:i({name:\"scene\",editType:\"plot\"}),aspectmode:{valType:\"enumerated\",values:[\"auto\",\"cube\",\"data\",\"manual\"],dflt:\"auto\",editType:\"plot\",impliedEdits:{\"aspectratio.x\":void 0,\"aspectratio.y\":void 0,\"aspectratio.z\":void 0}},aspectratio:{x:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},y:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},z:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},editType:\"plot\",impliedEdits:{aspectmode:\"manual\"}},xaxis:n,yaxis:n,zaxis:n,dragmode:{valType:\"enumerated\",values:[\"orbit\",\"turntable\",\"zoom\",\"pan\",!1],editType:\"plot\"},hovermode:{valType:\"enumerated\",values:[\"closest\",!1],dflt:\"closest\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"plot\",_deprecated:{cameraposition:{valType:\"info_array\",editType:\"camera\"}}}},{\"../../../lib\":719,\"../../../lib/extend\":710,\"../../domain\":792,\"./axis_attributes\":809}],814:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=[\"xaxis\",\"yaxis\",\"zaxis\"];function a(){this.enabled=[!0,!0,!0],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.drawSides=[!0,!0,!0],this.lineWidth=[1,1,1]}a.prototype.merge=function(t){for(var e=0;e<3;++e){var r=t[i[e]];r.visible?(this.enabled[e]=r.showspikes,this.colors[e]=n(r.spikecolor),this.drawSides[e]=r.spikesides,this.lineWidth[e]=r.spikethickness):(this.enabled[e]=!1,this.drawSides[e]=!1)}},e.exports=function(t){var e=new a;return e.merge(t),e}},{\"../../../lib/str2rgbarray\":742}],815:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.axesOptions,r=t.glplot.axesPixels,s=t.fullSceneLayout,l=[[],[],[]],c=0;c<3;++c){var u=s[a[c]];if(u._length=(r[c].hi-r[c].lo)*r[c].pixelsPerDataUnit/t.dataScale[c],Math.abs(u._length)===1/0||isNaN(u._length))l[c]=[];else{u._input_range=u.range.slice(),u.range[0]=r[c].lo/t.dataScale[c],u.range[1]=r[c].hi/t.dataScale[c],u._m=1/(t.dataScale[c]*r[c].pixelsPerDataUnit),u.range[0]===u.range[1]&&(u.range[0]-=1,u.range[1]+=1);var h=u.tickmode;if(\"auto\"===u.tickmode){u.tickmode=\"linear\";var f=u.nticks||i.constrain(u._length/40,4,9);n.autoTicks(u,Math.abs(u.range[1]-u.range[0])/f)}for(var p=n.calcTicks(u),d=0;d<p.length;++d)p[d].x=p[d].x*t.dataScale[c],\"date\"===u.type&&(p[d].text=p[d].text.replace(/\\<br\\>/g,\" \"));l[c]=p,u.tickmode=h}}e.ticks=l;for(var c=0;c<3;++c){o[c]=.5*(t.glplot.bounds[0][c]+t.glplot.bounds[1][c]);for(var d=0;d<2;++d)e.bounds[d][c]=t.glplot.bounds[d][c]}t.contourLevels=function(t){for(var e=new Array(3),r=0;r<3;++r){for(var n=t[r],i=new Array(n.length),a=0;a<n.length;++a)i[a]=n[a].x;e[r]=i}return e}(l)};var n=t(\"../../cartesian/axes\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"],o=[0,0,0]},{\"../../../lib\":719,\"../../cartesian/axes\":767}],816:[function(t,e,r){\"use strict\";function n(t,e){var r,n,i=[0,0,0,0];for(r=0;r<4;++r)for(n=0;n<4;++n)i[n]+=t[4*r+n]*e[r];return i}e.exports=function(t,e){return n(t.projection,n(t.view,n(t.model,[e[0],e[1],e[2],1])))}},{}],817:[function(t,e,r){\"use strict\";var n,i,a=t(\"gl-plot3d\").createCamera,o=t(\"gl-plot3d\").createScene,s=t(\"webgl-context\"),l=t(\"has-passive-events\"),c=t(\"../../registry\"),u=t(\"../../lib\"),h=t(\"../../plots/cartesian/axes\"),f=t(\"../../components/fx\"),p=t(\"../../lib/str2rgbarray\"),d=t(\"../../lib/show_no_webgl_msg\"),g=t(\"./project\"),v=t(\"./layout/convert\"),m=t(\"./layout/spikes\"),y=t(\"./layout/tick_marks\");function x(t,e,r,a){if(t.initializeGLCamera(),!function(t,e,r,a,l){var c={canvas:a,gl:l,container:t.container,axes:t.axesOptions,spikes:t.spikeOptions,pickRadius:10,snapToData:!0,autoScale:!0,autoBounds:!1,cameraObject:e,pixelRatio:r};if(t.staticMode){if(!(i||(n=document.createElement(\"canvas\"),i=s({canvas:n,preserveDrawingBuffer:!0,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"error creating static canvas/context for image server\");c.pixelRatio=t.pixelRatio,c.gl=i,c.canvas=n}try{t.glplot=o(c)}catch(t){return!1}return!0}(t,t.camera,e,r,a))return d(t);var c=t.graphDiv,p=function(t){if(!1!==t.fullSceneLayout.dragmode){var e={};e[t.id+\".camera\"]=T(t.camera),t.saveCamera(c.layout),t.graphDiv.emit(\"plotly_relayout\",e)}};return t.glplot.canvas.addEventListener(\"mouseup\",function(){p(t)}),t.glplot.canvas.addEventListener(\"wheel\",function(){c._context._scrollZoom.gl3d&&p(t)},!!l&&{passive:!1}),t.glplot.canvas.addEventListener(\"mousemove\",function(){if(!1!==t.fullSceneLayout.dragmode&&0!==t.camera.mouseListener.buttons){var e={};e[t.id+\".camera\"]=T(t.camera),t.graphDiv.emit(\"plotly_relayouting\",e)}}),t.staticMode||t.glplot.canvas.addEventListener(\"webglcontextlost\",function(e){c&&c.emit&&c.emit(\"plotly_webglcontextlost\",{event:e,layer:t.id})},!1),t.glplot.camera=t.camera,t.glplot.oncontextloss=function(){t.recoverContext()},t.glplot.onrender=function(t){var e,r=t.graphDiv,n=t.svgContainer,i=t.container.getBoundingClientRect(),a=i.width,o=i.height;n.setAttributeNS(null,\"viewBox\",\"0 0 \"+a+\" \"+o),n.setAttributeNS(null,\"width\",a),n.setAttributeNS(null,\"height\",o),y(t),t.glplot.axes.update(t.axesOptions);for(var s,l=Object.keys(t.traces),c=null,p=t.glplot.selection,d=0;d<l.length;++d)\"skip\"!==(e=t.traces[l[d]]).data.hoverinfo&&e.handlePick(p)&&(c=e),e.setContourLevels&&e.setContourLevels();function v(e,r){var n=t.fullSceneLayout[e];return h.tickText(n,n.d2l(r),\"hover\").text}if(null!==c){var m=g(t.glplot.cameraParams,p.dataCoordinate);e=c.data;var x,b=r._fullData[e.index],_=p.index,w={xLabel:v(\"xaxis\",p.traceCoordinate[0]),yLabel:v(\"yaxis\",p.traceCoordinate[1]),zLabel:v(\"zaxis\",p.traceCoordinate[2])},k=f.castHoverinfo(b,t.fullLayout,_),T=(k||\"\").split(\"+\"),A=k&&\"all\"===k;b.hovertemplate||A||(-1===T.indexOf(\"x\")&&(w.xLabel=void 0),-1===T.indexOf(\"y\")&&(w.yLabel=void 0),-1===T.indexOf(\"z\")&&(w.zLabel=void 0),-1===T.indexOf(\"text\")&&(p.textLabel=void 0),-1===T.indexOf(\"name\")&&(c.name=void 0));var M=[];\"cone\"===e.type||\"streamtube\"===e.type?(w.uLabel=v(\"xaxis\",p.traceCoordinate[3]),(A||-1!==T.indexOf(\"u\"))&&M.push(\"u: \"+w.uLabel),w.vLabel=v(\"yaxis\",p.traceCoordinate[4]),(A||-1!==T.indexOf(\"v\"))&&M.push(\"v: \"+w.vLabel),w.wLabel=v(\"zaxis\",p.traceCoordinate[5]),(A||-1!==T.indexOf(\"w\"))&&M.push(\"w: \"+w.wLabel),w.normLabel=p.traceCoordinate[6].toPrecision(3),(A||-1!==T.indexOf(\"norm\"))&&M.push(\"norm: \"+w.normLabel),\"streamtube\"===e.type&&(w.divergenceLabel=p.traceCoordinate[7].toPrecision(3),(A||-1!==T.indexOf(\"divergence\"))&&M.push(\"divergence: \"+w.divergenceLabel)),p.textLabel&&M.push(p.textLabel),x=M.join(\"<br>\")):\"isosurface\"===e.type||\"volume\"===e.type?(w.valueLabel=h.tickText(t.mockAxis,t.mockAxis.d2l(p.traceCoordinate[3]),\"hover\").text,M.push(\"value: \"+w.valueLabel),p.textLabel&&M.push(p.textLabel),x=M.join(\"<br>\")):x=p.textLabel;var S={x:p.traceCoordinate[0],y:p.traceCoordinate[1],z:p.traceCoordinate[2],data:b._input,fullData:b,curveNumber:b.index,pointNumber:_};f.appendArrayPointValue(S,b,_),e._module.eventData&&(S=b._module.eventData(S,p,b,{},_));var E={points:[S]};t.fullSceneLayout.hovermode&&f.loneHover({trace:b,x:(.5+.5*m[0]/m[3])*a,y:(.5-.5*m[1]/m[3])*o,xLabel:w.xLabel,yLabel:w.yLabel,zLabel:w.zLabel,text:x,name:c.name,color:f.castHoverOption(b,_,\"bgcolor\")||c.color,borderColor:f.castHoverOption(b,_,\"bordercolor\"),fontFamily:f.castHoverOption(b,_,\"font.family\"),fontSize:f.castHoverOption(b,_,\"font.size\"),fontColor:f.castHoverOption(b,_,\"font.color\"),nameLength:f.castHoverOption(b,_,\"namelength\"),textAlign:f.castHoverOption(b,_,\"align\"),hovertemplate:u.castOption(b,_,\"hovertemplate\"),hovertemplateLabels:u.extendFlat({},S,w),eventData:[S]},{container:n,gd:r}),p.buttons&&p.distance<5?r.emit(\"plotly_click\",E):r.emit(\"plotly_hover\",E),s=E}else f.loneUnhover(n),r.emit(\"plotly_unhover\",s);t.drawAnnotations(t)}.bind(null,t),t.traces={},t.make4thDimension(),!0}function b(t,e){var r=document.createElement(\"div\"),n=t.container;this.graphDiv=t.graphDiv;var i=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");i.style.position=\"absolute\",i.style.top=i.style.left=\"0px\",i.style.width=i.style.height=\"100%\",i.style[\"z-index\"]=20,i.style[\"pointer-events\"]=\"none\",r.appendChild(i),this.svgContainer=i,r.id=t.id,r.style.position=\"absolute\",r.style.top=r.style.left=\"0px\",r.style.width=r.style.height=\"100%\",n.appendChild(r),this.fullLayout=e,this.id=t.id||\"scene\",this.fullSceneLayout=e[this.id],this.plotArgs=[[],{},{}],this.axesOptions=v(e,e[this.id]),this.spikeOptions=m(e[this.id]),this.container=r,this.staticMode=!!t.staticPlot,this.pixelRatio=this.pixelRatio||t.plotGlPixelRatio||2,this.dataScale=[1,1,1],this.contourLevels=[[],[],[]],this.convertAnnotations=c.getComponentMethod(\"annotations3d\",\"convert\"),this.drawAnnotations=c.getComponentMethod(\"annotations3d\",\"draw\"),x(this,this.pixelRatio)}var _=b.prototype;_.initializeGLCamera=function(){var t=this.fullSceneLayout.camera,e=\"orthographic\"===t.projection.type;this.camera=a(this.container,{center:[t.center.x,t.center.y,t.center.z],eye:[t.eye.x,t.eye.y,t.eye.z],up:[t.up.x,t.up.y,t.up.z],_ortho:e,zoomMin:.01,zoomMax:100,mode:\"orbit\"})},_.recoverContext=function(){var t=this,e=this.glplot.gl,r=this.glplot.canvas,n=this.glplot.camera,i=this.glplot.pixelRatio;this.glplot.dispose(),requestAnimationFrame(function a(){e.isContextLost()?requestAnimationFrame(a):x(t,n,i,r)?t.plot.apply(t,t.plotArgs):u.error(\"Catastrophic and unrecoverable WebGL error. Context lost.\")})};var w=[\"xaxis\",\"yaxis\",\"zaxis\"];function k(t,e,r){for(var n=t.fullSceneLayout,i=0;i<3;i++){var a=w[i],o=a.charAt(0),s=n[a],l=e[o],c=e[o+\"calendar\"],h=e[\"_\"+o+\"length\"];if(u.isArrayOrTypedArray(l))for(var f,p=0;p<(h||l.length);p++)if(u.isArrayOrTypedArray(l[p]))for(var d=0;d<l[p].length;++d)f=s.d2l(l[p][d],0,c),!isNaN(f)&&isFinite(f)&&(r[0][i]=Math.min(r[0][i],f),r[1][i]=Math.max(r[1][i],f));else f=s.d2l(l[p],0,c),!isNaN(f)&&isFinite(f)&&(r[0][i]=Math.min(r[0][i],f),r[1][i]=Math.max(r[1][i],f));else r[0][i]=Math.min(r[0][i],0),r[1][i]=Math.max(r[1][i],h-1)}}function T(t){return{up:{x:t.up[0],y:t.up[1],z:t.up[2]},center:{x:t.center[0],y:t.center[1],z:t.center[2]},eye:{x:t.eye[0],y:t.eye[1],z:t.eye[2]},projection:{type:!0===t._ortho?\"orthographic\":\"perspective\"}}}_.plot=function(t,e,r){if(this.plotArgs=[t,e,r],!this.glplot.contextLost){var n,i,a,o,s,l,c=e[this.id],u=r[this.id];c.bgcolor?this.glplot.clearColor=p(c.bgcolor):this.glplot.clearColor=[0,0,0,0],this.glplot.snapToData=!0,this.fullLayout=e,this.fullSceneLayout=c,this.glplotLayout=c,this.axesOptions.merge(e,c),this.spikeOptions.merge(c),this.setCamera(c.camera),this.updateFx(c.dragmode,c.hovermode),this.camera.enableWheel=this.graphDiv._context._scrollZoom.gl3d,this.glplot.update({}),this.setConvert(s),t?Array.isArray(t)||(t=[t]):t=[];var h=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&k(this,n,h);!function(t,e){for(var r=t.fullSceneLayout,n=r.annotations||[],i=0;i<3;i++)for(var a=w[i],o=a.charAt(0),s=r[a],l=0;l<n.length;l++){var c=n[l];if(c.visible){var u=s.r2l(c[o]);!isNaN(u)&&isFinite(u)&&(e[0][i]=Math.min(e[0][i],u),e[1][i]=Math.max(e[1][i],u))}}}(this,h);var f=[1,1,1];for(o=0;o<3;++o)h[1][o]===h[0][o]?f[o]=1:f[o]=1/(h[1][o]-h[0][o]);for(this.dataScale=f,this.convertAnnotations(this),a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&((i=this.traces[n.uid])?i.data.type===n.type?i.update(n):(i.dispose(),i=n._module.plot(this,n),this.traces[n.uid]=i):(i=n._module.plot(this,n),this.traces[n.uid]=i),i.name=n.name);var d=Object.keys(this.traces);t:for(a=0;a<d.length;++a){for(o=0;o<t.length;++o)if(t[o].uid===d[a]&&!0===t[o].visible&&0!==t[o]._length)continue t;(i=this.traces[d[a]]).dispose(),delete this.traces[d[a]]}this.glplot.objects.sort(function(t,e){return t._trace.data.index-e._trace.data.index});var g=[[0,0,0],[0,0,0]],v=[],m={};for(a=0;a<3;++a){if((l=(s=c[w[a]]).type)in m?(m[l].acc*=f[a],m[l].count+=1):m[l]={acc:f[a],count:1},s.autorange){g[0][a]=1/0,g[1][a]=-1/0;var y=this.glplot.objects,x=this.fullSceneLayout.annotations||[],b=s._name.charAt(0);for(o=0;o<y.length;o++){var _=y[o],T=_.bounds,A=_._trace.data._pad||0;\"ErrorBars\"===_.constructor.name&&s._lowerLogErrorBound?g[0][a]=Math.min(g[0][a],s._lowerLogErrorBound):g[0][a]=Math.min(g[0][a],T[0][a]/f[a]-A),g[1][a]=Math.max(g[1][a],T[1][a]/f[a]+A)}for(o=0;o<x.length;o++){var M=x[o];if(M.visible){var S=s.r2l(M[b]);g[0][a]=Math.min(g[0][a],S),g[1][a]=Math.max(g[1][a],S)}}if(\"rangemode\"in s&&\"tozero\"===s.rangemode&&(g[0][a]=Math.min(g[0][a],0),g[1][a]=Math.max(g[1][a],0)),g[0][a]>g[1][a])g[0][a]=-1,g[1][a]=1;else{var E=g[1][a]-g[0][a];g[0][a]-=E/32,g[1][a]+=E/32}if(\"reversed\"===s.autorange){var C=g[0][a];g[0][a]=g[1][a],g[1][a]=C}}else{var L=s.range;g[0][a]=s.r2l(L[0]),g[1][a]=s.r2l(L[1])}g[0][a]===g[1][a]&&(g[0][a]-=1,g[1][a]+=1),v[a]=g[1][a]-g[0][a],this.glplot.bounds[0][a]=g[0][a]*f[a],this.glplot.bounds[1][a]=g[1][a]*f[a]}var P=[1,1,1];for(a=0;a<3;++a){var O=m[l=(s=c[w[a]]).type];P[a]=Math.pow(O.acc,1/O.count)/f[a]}var z;if(\"auto\"===c.aspectmode)z=Math.max.apply(null,P)/Math.min.apply(null,P)<=4?P:[1,1,1];else if(\"cube\"===c.aspectmode)z=[1,1,1];else if(\"data\"===c.aspectmode)z=P;else{if(\"manual\"!==c.aspectmode)throw new Error(\"scene.js aspectRatio was not one of the enumerated types\");var I=c.aspectratio;z=[I.x,I.y,I.z]}c.aspectratio.x=u.aspectratio.x=z[0],c.aspectratio.y=u.aspectratio.y=z[1],c.aspectratio.z=u.aspectratio.z=z[2],this.glplot.aspect=z;var D=c.domain||null,R=e._size||null;if(D&&R){var F=this.container.style;F.position=\"absolute\",F.left=R.l+D.x[0]*R.w+\"px\",F.top=R.t+(1-D.y[1])*R.h+\"px\",F.width=R.w*(D.x[1]-D.x[0])+\"px\",F.height=R.h*(D.y[1]-D.y[0])+\"px\"}this.glplot.redraw()}},_.destroy=function(){this.glplot&&(this.camera.mouseListener.enabled=!1,this.container.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=this.glplot.camera=null,this.glplot.dispose(),this.container.parentNode.removeChild(this.container),this.glplot=null)},_.getCamera=function(){return this.glplot.camera.view.recalcMatrix(this.camera.view.lastT()),T(this.glplot.camera)},_.setCamera=function(t){var e;this.glplot.camera.lookAt.apply(this,[[(e=t).eye.x,e.eye.y,e.eye.z],[e.center.x,e.center.y,e.center.z],[e.up.x,e.up.y,e.up.z]]);var r=\"orthographic\"===t.projection.type;if(r!==this.glplot.camera._ortho){this.glplot.redraw();var n=this.glplot.pixelRatio,i=this.glplot.clearColor;this.glplot.gl.clearColor(i[0],i[1],i[2],i[3]),this.glplot.gl.clear(this.glplot.gl.DEPTH_BUFFER_BIT|this.glplot.gl.COLOR_BUFFER_BIT),this.glplot.dispose(),x(this,n),this.glplot.camera._ortho=r}},_.saveCamera=function(t){var e=this.fullLayout,r=this.getCamera(),n=u.nestedProperty(t,this.id+\".camera\"),i=n.get(),a=!1;function o(t,e,r,n){var i=[\"up\",\"center\",\"eye\"],a=[\"x\",\"y\",\"z\"];return e[i[r]]&&t[i[r]][a[n]]===e[i[r]][a[n]]}if(void 0===i)a=!0;else{for(var s=0;s<3;s++)for(var l=0;l<3;l++)if(!o(r,i,s,l)){a=!0;break}(!i.projection||r.projection&&r.projection.type!==i.projection.type)&&(a=!0)}if(a){var h={};h[this.id+\".camera\"]=i,c.call(\"_storeDirectGUIEdit\",t,e._preGUI,h),n.set(r),u.nestedProperty(e,this.id+\".camera\").set(r)}return a},_.updateFx=function(t,e){var r=this.camera;if(r)if(\"orbit\"===t)r.mode=\"orbit\",r.keyBindingMode=\"rotate\";else if(\"turntable\"===t){r.up=[0,0,1],r.mode=\"turntable\",r.keyBindingMode=\"rotate\";var n=this.graphDiv,i=n._fullLayout,a=this.fullSceneLayout.camera,o=a.up.x,s=a.up.y,l=a.up.z;if(l/Math.sqrt(o*o+s*s+l*l)<.999){var h=this.id+\".camera.up\",f={x:0,y:0,z:1},p={};p[h]=f;var d=n.layout;c.call(\"_storeDirectGUIEdit\",d,i._preGUI,p),a.up=f,u.nestedProperty(d,h).set(f)}}else r.keyBindingMode=t;this.fullSceneLayout.hovermode=e},_.toImage=function(t){t||(t=\"png\"),this.staticMode&&this.container.appendChild(n),this.glplot.redraw();var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a);for(var o=0,s=i-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=a[4*(r*o+l)+c];a[4*(r*o+l)+c]=a[4*(r*s+l)+c],a[4*(r*s+l)+c]=u}var h=document.createElement(\"canvas\");h.width=r,h.height=i;var f,p=h.getContext(\"2d\"),d=p.createImageData(r,i);switch(d.data.set(a),p.putImageData(d,0,0),t){case\"jpeg\":f=h.toDataURL(\"image/jpeg\");break;case\"webp\":f=h.toDataURL(\"image/webp\");break;default:f=h.toDataURL(\"image/png\")}return this.staticMode&&this.container.removeChild(n),f},_.setConvert=function(){for(var t=0;t<3;t++){var e=this.fullSceneLayout[w[t]];h.setConvert(e,this.fullLayout),e.setScale=u.noop}},_.make4thDimension=function(){var t=this.graphDiv._fullLayout;this.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},h.setConvert(this.mockAxis,t)},e.exports=b},{\"../../components/fx\":632,\"../../lib\":719,\"../../lib/show_no_webgl_msg\":740,\"../../lib/str2rgbarray\":742,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./layout/convert\":811,\"./layout/spikes\":814,\"./layout/tick_marks\":815,\"./project\":816,\"gl-plot3d\":290,\"has-passive-events\":411,\"webgl-context\":556}],818:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){n=n||t.length;for(var i=new Array(n),a=0;a<n;a++)i[a]=[t[a],e[a],r[a]];return i}},{}],819:[function(t,e,r){\"use strict\";var n=t(\"./font_attributes\"),i=t(\"./animation_attributes\"),a=t(\"../components/color/attributes\"),o=t(\"./pad_attributes\"),s=t(\"../lib/extend\").extendFlat,l=n({editType:\"calc\"});l.family.dflt='\"Open Sans\", verdana, arial, sans-serif',l.size.dflt=12,l.color.dflt=a.defaultLine,e.exports={font:l,title:{text:{valType:\"string\",editType:\"layoutstyle\"},font:n({editType:\"layoutstyle\"}),xref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},yref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},x:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"layoutstyle\"},y:{valType:\"number\",min:0,max:1,dflt:\"auto\",editType:\"layoutstyle\"},xanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"left\",\"center\",\"right\"],editType:\"layoutstyle\"},yanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],editType:\"layoutstyle\"},pad:s(o({editType:\"layoutstyle\"}),{}),editType:\"layoutstyle\"},autosize:{valType:\"boolean\",dflt:!1,editType:\"none\"},width:{valType:\"number\",min:10,dflt:700,editType:\"plot\"},height:{valType:\"number\",min:10,dflt:450,editType:\"plot\"},margin:{l:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},r:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},t:{valType:\"number\",min:0,dflt:100,editType:\"plot\"},b:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},pad:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},autoexpand:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},paper_bgcolor:{valType:\"color\",dflt:a.background,editType:\"plot\"},plot_bgcolor:{valType:\"color\",dflt:a.background,editType:\"layoutstyle\"},separators:{valType:\"string\",editType:\"plot\"},hidesources:{valType:\"boolean\",dflt:!1,editType:\"plot\"},showlegend:{valType:\"boolean\",editType:\"legend\"},colorway:{valType:\"colorlist\",dflt:a.defaults,editType:\"calc\"},datarevision:{valType:\"any\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editrevision:{valType:\"any\",editType:\"none\"},selectionrevision:{valType:\"any\",editType:\"none\"},template:{valType:\"any\",editType:\"calc\"},modebar:{orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\",editType:\"modebar\"},bgcolor:{valType:\"color\",editType:\"modebar\"},color:{valType:\"color\",editType:\"modebar\"},activecolor:{valType:\"color\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"modebar\"},meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},transition:s({},i.transition,{editType:\"none\"}),_deprecated:{title:{valType:\"string\",editType:\"layoutstyle\"},titlefont:n({editType:\"layoutstyle\"})}}},{\"../components/color/attributes\":592,\"../lib/extend\":710,\"./animation_attributes\":762,\"./font_attributes\":793,\"./pad_attributes\":827}],820:[function(t,e,r){\"use strict\";var n={\"open-street-map\":{id:\"osm\",version:8,sources:{\"plotly-osm-tiles\":{type:\"raster\",attribution:'<a href=\"http://www.openstreetmap.org/about/\" target=\"_blank\">\\xa9 OpenStreetMap</a>',tiles:[\"https://a.tile.openstreetmap.org/{z}/{x}/{y}.png\",\"https://b.tile.openstreetmap.org/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-osm-tiles\",type:\"raster\",source:\"plotly-osm-tiles\",minzoom:0,maxzoom:22}]},\"white-bg\":{id:\"white-bg\",version:8,sources:{},layers:[{id:\"white-bg\",type:\"background\",paint:{\"background-color\":\"#FFFFFF\"},minzoom:0,maxzoom:22}]},\"carto-positron\":{id:\"carto-positron\",version:8,sources:{\"plotly-carto-positron\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/light_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-positron\",type:\"raster\",source:\"plotly-carto-positron\",minzoom:0,maxzoom:22}]},\"carto-darkmatter\":{id:\"carto-darkmatter\",version:8,sources:{\"plotly-carto-darkmatter\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/dark_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-darkmatter\",type:\"raster\",source:\"plotly-carto-darkmatter\",minzoom:0,maxzoom:22}]},\"stamen-terrain\":{id:\"stamen-terrain\",version:8,sources:{\"plotly-stamen-terrain\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/terrain/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-terrain\",type:\"raster\",source:\"plotly-stamen-terrain\",minzoom:0,maxzoom:22}]},\"stamen-toner\":{id:\"stamen-toner\",version:8,sources:{\"plotly-stamen-toner\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/toner/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-toner\",type:\"raster\",source:\"plotly-stamen-toner\",minzoom:0,maxzoom:22}]},\"stamen-watercolor\":{id:\"stamen-watercolor\",version:8,sources:{\"plotly-stamen-watercolor\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://creativecommons.org/licenses/by-sa/3.0\">CC BY SA</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/watercolor/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-watercolor\",type:\"raster\",source:\"plotly-stamen-watercolor\",minzoom:0,maxzoom:22}]}},i=Object.keys(n);e.exports={requiredVersion:\"1.1.1\",styleUrlPrefix:\"mapbox://styles/mapbox/\",styleUrlSuffix:\"v9\",styleValuesMapbox:[\"basic\",\"streets\",\"outdoors\",\"light\",\"dark\",\"satellite\",\"satellite-streets\"],styleValueDflt:\"basic\",stylesNonMapbox:n,styleValuesNonMapbox:i,traceLayerPrefix:\"plotly-trace-layer-\",layoutLayerPrefix:\"plotly-layout-layer-\",wrongVersionErrorMsg:[\"Your custom plotly.js bundle is not using the correct mapbox-gl version\",\"Please install mapbox-gl@1.1.1.\"].join(\"\\n\"),noAccessTokenErrorMsg:[\"Missing Mapbox access token.\",\"Mapbox trace type require a Mapbox access token to be registered.\",\"For example:\",\"  Plotly.plot(gd, data, layout, { mapboxAccessToken: 'my-access-token' });\",\"More info here: https://www.mapbox.com/help/define-access-token/\"].join(\"\\n\"),missingStyleErrorMsg:[\"No valid mapbox style found, please set `mapbox.style` to one of:\",i.join(\", \"),\"or register a Mapbox access token to use a Mapbox-served style.\"].join(\"\\n\"),multipleTokensErrorMsg:[\"Set multiple mapbox access token across different mapbox subplot,\",\"using first token found as mapbox-gl does not allow multipleaccess tokens on the same page.\"].join(\"\\n\"),mapOnErrorMsg:\"Mapbox error.\",mapboxLogo:{path0:\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\",path1:\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\",path2:\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\",polygon:\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34\"},styleRules:{map:\"overflow:hidden;position:relative;\",\"missing-css\":\"display:none;\",canary:\"background-color:salmon;\",\"ctrl-bottom-left\":\"position: absolute; pointer-events: none; z-index: 2; bottom: 0; left: 0;\",\"ctrl-bottom-right\":\"position: absolute; pointer-events: none; z-index: 2; right: 0; bottom: 0;\",ctrl:\"clear: both; pointer-events: auto; transform: translate(0, 0);\",\"ctrl-attrib.mapboxgl-compact .mapboxgl-ctrl-attrib-inner\":\"display: none;\",\"ctrl-attrib.mapboxgl-compact:hover .mapboxgl-ctrl-attrib-inner\":\"display: block; margin-top:2px\",\"ctrl-attrib.mapboxgl-compact:hover\":\"padding: 2px 24px 2px 4px; visibility: visible; margin-top: 6px;\",\"ctrl-attrib.mapboxgl-compact::after\":'content: \"\"; cursor: pointer; position: absolute; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3Csvg viewBox=\"0 0 20 20\" xmlns=\"http://www.w3.org/2000/svg\"%3E %3Cpath fill=\"%23333333\" fill-rule=\"evenodd\" d=\"M4,10a6,6 0 1,0 12,0a6,6 0 1,0 -12,0 M9,7a1,1 0 1,0 2,0a1,1 0 1,0 -2,0 M9,10a1,1 0 1,1 2,0l0,3a1,1 0 1,1 -2,0\"/%3E %3C/svg%3E\\'); background-color: rgba(255, 255, 255, 0.5); width: 24px; height: 24px; box-sizing: border-box; border-radius: 12px;',\"ctrl-attrib.mapboxgl-compact\":\"min-height: 20px; padding: 0; margin: 10px; position: relative; background-color: #fff; border-radius: 3px 12px 12px 3px;\",\"ctrl-bottom-right > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; right: 0\",\"ctrl-bottom-left > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; left: 0\",\"ctrl-bottom-left .mapboxgl-ctrl\":\"margin: 0 0 10px 10px; float: left;\",\"ctrl-bottom-right .mapboxgl-ctrl\":\"margin: 0 10px 10px 0; float: right;\",\"ctrl-attrib\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a:hover\":\"color: inherit; text-decoration: underline;\",\"ctrl-attrib .mapbox-improve-map\":\"font-weight: bold; margin-left: 2px;\",\"attrib-empty\":\"display: none;\",\"ctrl-logo\":'display:block; width: 21px; height: 21px; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3C?xml version=\"1.0\" encoding=\"utf-8\"?%3E %3Csvg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\" viewBox=\"0 0 21 21\" style=\"enable-background:new 0 0 21 21;\" xml:space=\"preserve\"%3E%3Cg transform=\"translate(0,0.01)\"%3E%3Cpath d=\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3Cpath d=\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpath d=\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpolygon points=\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34 \" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3C/g%3E%3C/svg%3E\\')'}}},{}],821:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t.split(\" \"),i=r[0],a=r[1],o=n.isArrayOrTypedArray(e)?n.mean(e):e,s=.5+o/100,l=1.5+o/100,c=[\"\",\"\"],u=[0,0];switch(i){case\"top\":c[0]=\"top\",u[1]=-l;break;case\"bottom\":c[0]=\"bottom\",u[1]=l}switch(a){case\"left\":c[1]=\"right\",u[0]=-s;break;case\"right\":c[1]=\"left\",u[0]=s}return{anchor:c[0]&&c[1]?c.join(\"-\"):c[0]?c[0]:c[1]?c[1]:\"center\",offset:u}}},{\"../../lib\":719}],822:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"../../lib\"),a=t(\"../../plots/get_data\").getSubplotCalcData,o=t(\"../../constants/xmlns_namespaces\"),s=t(\"d3\"),l=t(\"../../components/drawing\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"./mapbox\"),h=r.constants=t(\"./constants\");function f(t){return\"string\"==typeof t&&-1!==h.styleValuesMapbox.indexOf(t)}r.name=\"mapbox\",r.attr=\"subplot\",r.idRoot=\"mapbox\",r.idRegex=r.attrRegex=i.counterRegex(\"mapbox\"),r.attributes={subplot:{valType:\"subplotid\",dflt:\"mapbox\",editType:\"calc\"}},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){var e=t._fullLayout,r=t.calcdata,o=e._subplots.mapbox;if(n.version!==h.requiredVersion)throw new Error(h.wrongVersionErrorMsg);var s=function(t,e){var r=t._fullLayout;if(\"\"===t._context.mapboxAccessToken)return\"\";for(var n=[],a=[],o=!1,s=!1,l=0;l<e.length;l++){var c=r[e[l]],u=c.accesstoken;f(c.style)&&(u?i.pushUnique(n,u):(f(c._input.style)&&(i.error(\"Uses Mapbox map style, but did not set an access token.\"),o=!0),s=!0)),u&&i.pushUnique(a,u)}if(s){var p=o?h.noAccessTokenErrorMsg:h.missingStyleErrorMsg;throw new Error(p)}return n.length?(n.length>1&&i.warn(h.multipleTokensErrorMsg),n[0]):(a.length&&i.log([\"Listed mapbox access token(s)\",a.join(\",\"),\"but did not use a Mapbox map style, ignoring token(s).\"].join(\" \")),\"\")}(t,o);n.accessToken=s;for(var l=0;l<o.length;l++){var c=o[l],p=a(r,\"mapbox\",c),d=e[c],g=d._subplot;g||(g=new u(t,c),e[c]._subplot=g),g.viewInitial||(g.viewInitial={center:i.extendFlat({},d.center),zoom:d.zoom,bearing:d.bearing,pitch:d.pitch}),g.plot(p,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.mapbox||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._subplot&&n[o]._subplot.destroy()}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=e._size,i=0;i<r.length;i++){var a=e[r[i]],u=a.domain,f=a._subplot.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":f,x:n.l+n.w*u.x[0],y:n.t+n.h*(1-u.y[1]),width:n.w*(u.x[1]-u.x[0]),height:n.h*(u.y[1]-u.y[0]),preserveAspectRatio:\"none\"});var p=s.select(a._subplot.div);if(!(null===p.select(\".mapboxgl-ctrl-logo\").node().offsetParent)){var d=e._glimages.append(\"g\");d.attr(\"transform\",\"translate(\"+(n.l+n.w*u.x[0]+10)+\", \"+(n.t+n.h*(1-u.y[0])-31)+\")\"),d.append(\"path\").attr(\"d\",h.mapboxLogo.path0).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"}),d.append(\"path\").attr(\"d\",h.mapboxLogo.path1).style(\"opacity\",.35).style(\"enable-background\",\"new\"),d.append(\"path\").attr(\"d\",h.mapboxLogo.path2).style(\"opacity\",.35).style(\"enable-background\",\"new\"),d.append(\"polygon\").attr(\"points\",h.mapboxLogo.polygon).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"})}var g=p.select(\".mapboxgl-ctrl-attrib\").text().replace(\"Improve this map\",\"\"),v=e._glimages.append(\"g\"),m=v.append(\"text\");m.text(g).classed(\"static-attribution\",!0).attr({\"font-size\":12,\"font-family\":\"Arial\",color:\"rgba(0, 0, 0, 0.75)\",\"text-anchor\":\"end\",\"data-unformatted\":g});var y=l.bBox(m.node()),x=n.w*(u.x[1]-u.x[0]);if(y.width>x/2){var b=g.split(\"|\").join(\"<br>\");m.text(b).attr(\"data-unformatted\",b).call(c.convertToTspans,t),y=l.bBox(m.node())}m.attr(\"transform\",\"translate(-3, \"+(8-y.height)+\")\"),v.insert(\"rect\",\".static-attribution\").attr({x:-y.width-6,y:-y.height-3,width:y.width+6,height:y.height+3,fill:\"rgba(255, 255, 255, 0.75)\"});var _=1;y.width+6>x&&(_=x/(y.width+6));var w=[n.l+n.w*u.x[1],n.t+n.h*(1-u.y[0])];v.attr(\"transform\",\"translate(\"+w[0]+\",\"+w[1]+\") scale(\"+_+\")\")}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=0;n<r.length;n++){e[r[n]]._subplot.updateFx(e)}}},{\"../../components/drawing\":614,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/get_data\":802,\"./constants\":820,\"./layout_attributes\":824,\"./layout_defaults\":825,\"./mapbox\":826,d3:163,\"mapbox-gl\":426}],823:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./convert_text_opts\"),a=t(\"./constants\");function o(t,e){this.subplot=t,this.uid=t.uid+\"-\"+e,this.index=e,this.idSource=\"source-\"+this.uid,this.idLayer=a.layoutLayerPrefix+this.uid,this.sourceType=null,this.source=null,this.layerType=null,this.below=null,this.visible=!1}var s=o.prototype;function l(t){var e=t.source;return t.visible&&(n.isPlainObject(e)||(\"string\"==typeof e||Array.isArray(e))&&e.length>0)}function c(t){var e={},r={};switch(t.type){case\"circle\":n.extendFlat(r,{\"circle-radius\":t.circle.radius,\"circle-color\":t.color,\"circle-opacity\":t.opacity});break;case\"line\":n.extendFlat(r,{\"line-width\":t.line.width,\"line-color\":t.color,\"line-opacity\":t.opacity,\"line-dasharray\":t.line.dash});break;case\"fill\":n.extendFlat(r,{\"fill-color\":t.color,\"fill-outline-color\":t.fill.outlinecolor,\"fill-opacity\":t.opacity});break;case\"symbol\":var a=t.symbol,o=i(a.textposition,a.iconsize);n.extendFlat(e,{\"icon-image\":a.icon+\"-15\",\"icon-size\":a.iconsize/10,\"text-field\":a.text,\"text-size\":a.textfont.size,\"text-anchor\":o.anchor,\"text-offset\":o.offset,\"symbol-placement\":a.placement}),n.extendFlat(r,{\"icon-color\":t.color,\"text-color\":a.textfont.color,\"text-opacity\":t.opacity})}return{layout:e,paint:r}}s.update=function(t){this.visible?this.needsNewSource(t)?(this.removeLayer(),this.updateSource(t),this.updateLayer(t)):this.needsNewLayer(t)?this.updateLayer(t):this.updateStyle(t):(this.updateSource(t),this.updateLayer(t)),this.visible=l(t)},s.needsNewSource=function(t){return this.sourceType!==t.sourcetype||this.source!==t.source||this.layerType!==t.type},s.needsNewLayer=function(t){return this.layerType!==t.type||this.below!==this.subplot.belowLookup[\"layout-\"+this.index]},s.updateSource=function(t){var e=this.subplot.map;if(e.getSource(this.idSource)&&e.removeSource(this.idSource),this.sourceType=t.sourcetype,this.source=t.source,l(t)){var r=function(t){var e,r=t.sourcetype,n=t.source,i={type:r};\"geojson\"===r?e=\"data\":\"vector\"===r?e=\"string\"==typeof n?\"url\":\"tiles\":\"raster\"===r?(e=\"tiles\",i.tileSize=256):\"image\"===r&&(e=\"url\",i.coordinates=t.coordinates);i[e]=n,t.sourceattribution&&(i.attribution=t.sourceattribution);return i}(t);e.addSource(this.idSource,r)}},s.updateLayer=function(t){var e,r=this.subplot,n=c(t),i=this.subplot.belowLookup[\"layout-\"+this.index];if(\"traces\"===i)for(var o=r.getMapLayers(),s=0;s<o.length;s++){var u=o[s].id;if(\"string\"==typeof u&&0===u.indexOf(a.traceLayerPrefix)){e=u;break}}else e=i;this.removeLayer(),l(t)&&r.addLayer({id:this.idLayer,source:this.idSource,\"source-layer\":t.sourcelayer||\"\",type:t.type,minzoom:t.minzoom,maxzoom:t.maxzoom,layout:n.layout,paint:n.paint},e),this.layerType=t.type,this.below=i},s.updateStyle=function(t){if(l(t)){var e=c(t);this.subplot.setOptions(this.idLayer,\"setLayoutProperty\",e.layout),this.subplot.setOptions(this.idLayer,\"setPaintProperty\",e.paint)}},s.removeLayer=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer)},s.dispose=function(){var t=this.subplot.map;t.removeLayer(this.idLayer),t.removeSource(this.idSource)},e.exports=function(t,e,r){var n=new o(t,e);return n.update(r),n}},{\"../../lib\":719,\"./constants\":820,\"./convert_text_opts\":821}],824:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\").defaultLine,a=t(\"../domain\").attributes,o=t(\"../font_attributes\"),s=t(\"../../traces/scatter/attributes\").textposition,l=t(\"../../plot_api/edit_types\").overrideAll,c=t(\"../../plot_api/plot_template\").templatedArray,u=t(\"./constants\"),h=o({});h.family.dflt=\"Open Sans Regular, Arial Unicode MS Regular\",(e.exports=l({_arrayAttrRegexps:[n.counterRegex(\"mapbox\",\".layers\",!0)],domain:a({name:\"mapbox\"}),accesstoken:{valType:\"string\",noBlank:!0,strict:!0},style:{valType:\"any\",values:u.styleValuesMapbox.concat(u.styleValuesNonMapbox),dflt:u.styleValueDflt},center:{lon:{valType:\"number\",dflt:0},lat:{valType:\"number\",dflt:0}},zoom:{valType:\"number\",dflt:1},bearing:{valType:\"number\",dflt:0},pitch:{valType:\"number\",dflt:0},layers:c(\"layer\",{visible:{valType:\"boolean\",dflt:!0},sourcetype:{valType:\"enumerated\",values:[\"geojson\",\"vector\",\"raster\",\"image\"],dflt:\"geojson\"},source:{valType:\"any\"},sourcelayer:{valType:\"string\",dflt:\"\"},sourceattribution:{valType:\"string\"},type:{valType:\"enumerated\",values:[\"circle\",\"line\",\"fill\",\"symbol\",\"raster\"],dflt:\"circle\"},coordinates:{valType:\"any\"},below:{valType:\"string\"},color:{valType:\"color\",dflt:i},opacity:{valType:\"number\",min:0,max:1,dflt:1},minzoom:{valType:\"number\",min:0,max:24,dflt:0},maxzoom:{valType:\"number\",min:0,max:24,dflt:24},circle:{radius:{valType:\"number\",dflt:15}},line:{width:{valType:\"number\",dflt:2},dash:{valType:\"data_array\"}},fill:{outlinecolor:{valType:\"color\",dflt:i}},symbol:{icon:{valType:\"string\",dflt:\"marker\"},iconsize:{valType:\"number\",dflt:10},text:{valType:\"string\",dflt:\"\"},placement:{valType:\"enumerated\",values:[\"point\",\"line\",\"line-center\"],dflt:\"point\"},textfont:h,textposition:n.extendFlat({},s,{arrayOk:!1})}})},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../traces/scatter/attributes\":1112,\"../domain\":792,\"../font_attributes\":793,\"./constants\":820}],825:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../subplot_defaults\"),a=t(\"../array_container_defaults\"),o=t(\"./layout_attributes\");function s(t,e,r,n){r(\"accesstoken\",n.accessToken),r(\"style\"),r(\"center.lon\"),r(\"center.lat\"),r(\"zoom\"),r(\"bearing\"),r(\"pitch\"),a(t,e,{name:\"layers\",handleItemDefaults:l}),e._input=t}function l(t,e){function r(r,i){return n.coerce(t,e,o.layers,r,i)}if(r(\"visible\")){var i,a=r(\"sourcetype\"),s=\"raster\"===a||\"image\"===a;r(\"source\"),r(\"sourceattribution\"),\"vector\"===a&&r(\"sourcelayer\"),\"image\"===a&&r(\"coordinates\"),s&&(i=\"raster\");var l=r(\"type\",i);s&&\"raster\"!==l&&(l=e.type=\"raster\",n.log(\"Source types *raster* and *image* must drawn *raster* layer type.\")),r(\"below\"),r(\"color\"),r(\"opacity\"),r(\"minzoom\"),r(\"maxzoom\"),\"circle\"===l&&r(\"circle.radius\"),\"line\"===l&&(r(\"line.width\"),r(\"line.dash\")),\"fill\"===l&&r(\"fill.outlinecolor\"),\"symbol\"===l&&(r(\"symbol.icon\"),r(\"symbol.iconsize\"),r(\"symbol.text\"),n.coerceFont(r,\"symbol.textfont\"),r(\"symbol.textposition\"),r(\"symbol.placement\"))}}e.exports=function(t,e,r){i(t,e,r,{type:\"mapbox\",attributes:o,handleDefaults:s,partition:\"y\",accessToken:e._mapboxAccessToken})}},{\"../../lib\":719,\"../array_container_defaults\":763,\"../subplot_defaults\":842,\"./layout_attributes\":824}],826:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"d3\"),a=t(\"../../components/fx\"),o=t(\"../../lib\"),s=t(\"../../registry\"),l=t(\"../cartesian/axes\"),c=t(\"../../components/dragelement\"),u=t(\"../cartesian/select\").prepSelect,h=t(\"../cartesian/select\").selectOnClick,f=t(\"./constants\"),p=t(\"./layers\");function d(t,e){this.id=e,this.gd=t;var r=t._fullLayout,n=t._context;this.container=r._glcontainer.node(),this.isStatic=n.staticPlot,this.uid=r._uid+\"-\"+this.id,this.div=null,this.xaxis=null,this.yaxis=null,this.createFramework(r),this.map=null,this.accessToken=null,this.styleObj=null,this.traceHash={},this.layerList=[],this.belowLookup={}}var g=d.prototype;g.plot=function(t,e,r){var n,i=this,a=e[i.id];i.map&&a.accesstoken!==i.accessToken&&(i.map.remove(),i.map=null,i.styleObj=null,i.traceHash=[],i.layerList={}),n=i.map?new Promise(function(r,n){i.updateMap(t,e,r,n)}):new Promise(function(r,n){i.createMap(t,e,r,n)}),r.push(n)},g.createMap=function(t,e,r,i){var a=this,o=e[a.id],s=a.styleObj=m(o.style);a.accessToken=o.accesstoken;var l=a.map=new n.Map({container:a.div,style:s.style,center:x(o.center),zoom:o.zoom,bearing:o.bearing,pitch:o.pitch,interactive:!a.isStatic,preserveDrawingBuffer:a.isStatic,doubleClickZoom:!1,boxZoom:!1,attributionControl:!1}).addControl(new n.AttributionControl({compact:!0}));l._canvas.style.left=\"0px\",l._canvas.style.top=\"0px\",a.rejectOnError(i),a.isStatic||a.initFx(t,e);var c=[];c.push(new Promise(function(t){l.once(\"load\",t)})),c=c.concat(a.fetchMapData(t,e)),Promise.all(c).then(function(){a.fillBelowLookup(t,e),a.updateData(t),a.updateLayout(e),a.resolveOnRender(r)}).catch(i)},g.fetchMapData=function(t){var e=[];function r(t){return new Promise(function(e,r){i.json(t,function(n,i){if(n){delete PlotlyGeoAssets[t];var a=404===n.status?'GeoJSON at URL \"'+t+'\" does not exist.':\"Unexpected error while fetching from \"+t;return r(new Error(a))}PlotlyGeoAssets[t]=i,e(i)})})}for(var n=0;n<t.length;n++){var a=t[n][0].trace.geojson;\"string\"!=typeof a||PlotlyGeoAssets[a]||(PlotlyGeoAssets[a]=\"pending\",e.push(r(a)))}return e},g.updateMap=function(t,e,r,n){var i=this,a=i.map,o=e[this.id];i.rejectOnError(n);var s=[],l=m(o.style);i.styleObj.id!==l.id&&(i.styleObj=l,a.setStyle(l.style),i.traceHash={},s.push(new Promise(function(t){a.once(\"styledata\",t)}))),s=s.concat(i.fetchMapData(t,e)),Promise.all(s).then(function(){i.fillBelowLookup(t,e),i.updateData(t),i.updateLayout(e),i.resolveOnRender(r)}).catch(n)},g.fillBelowLookup=function(t,e){var r,n,i=e[this.id].layers,a=this.belowLookup={},o=!1;for(r=0;r<t.length;r++){var s=t[r][0].trace,l=s._module;\"string\"==typeof s.below?n=s.below:l.getBelow&&(n=l.getBelow(s,this)),\"\"===n&&(o=!0),a[\"trace-\"+s.uid]=n||\"\"}for(r=0;r<i.length;r++){var c=i[r];n=\"string\"==typeof c.below?c.below:o?\"traces\":\"\",a[\"layout-\"+r]=n}var u,h,f={};for(u in a)f[n=a[u]]?f[n].push(u):f[n]=[u];for(n in f){var p=f[n];if(p.length>1)for(r=0;r<p.length;r++)0===(u=p[r]).indexOf(\"trace-\")?(h=u.split(\"trace-\")[1],this.traceHash[h]&&(this.traceHash[h].below=null)):0===u.indexOf(\"layout-\")&&(h=u.split(\"layout-\")[1],this.layerList[h]&&(this.layerList[h].below=null))}};var v={choroplethmapbox:0,densitymapbox:1,scattermapbox:2};function m(t){var e={};return o.isPlainObject(t)?(e.id=t.id,e.style=t):\"string\"==typeof t?(e.id=t,-1!==f.styleValuesMapbox.indexOf(t)?e.style=y(t):f.stylesNonMapbox[t]?e.style=f.stylesNonMapbox[t]:e.style=t):(e.id=f.styleValueDflt,e.style=y(f.styleValueDflt)),e.transition={duration:0,delay:0},e}function y(t){return f.styleUrlPrefix+t+\"-\"+f.styleUrlSuffix}function x(t){return[t.lon,t.lat]}g.updateData=function(t){var e,r,n,i,a=this.traceHash,o=t.slice().sort(function(t,e){return v[t[0].trace.type]-v[e[0].trace.type]});for(n=0;n<o.length;n++){var s=o[n];(e=a[(r=s[0].trace).uid])?e.update(s):r._module&&(a[r.uid]=r._module.plot(this,s))}var l=Object.keys(a);t:for(n=0;n<l.length;n++){var c=l[n];for(i=0;i<t.length;i++)if(c===(r=t[i][0].trace).uid)continue t;(e=a[c]).dispose(),delete a[c]}},g.updateLayout=function(t){var e=this.map,r=t[this.id];e.setCenter(x(r.center)),e.setZoom(r.zoom),e.setBearing(r.bearing),e.setPitch(r.pitch),this.updateLayers(t),this.updateFramework(t),this.updateFx(t),this.map.resize(),this.gd._context._scrollZoom.mapbox?e.scrollZoom.enable():e.scrollZoom.disable()},g.resolveOnRender=function(t){var e=this.map;e.on(\"render\",function r(){e.loaded()&&(e.off(\"render\",r),setTimeout(t,0))})},g.rejectOnError=function(t){var e=this.map;function r(){t(new Error(f.mapOnErrorMsg))}e.once(\"error\",r),e.once(\"style.error\",r),e.once(\"source.error\",r),e.once(\"tile.error\",r),e.once(\"layer.error\",r)},g.createFramework=function(t){var e=this,r=e.div=document.createElement(\"div\");r.id=e.uid,r.style.position=\"absolute\",e.container.appendChild(r),e.xaxis={_id:\"x\",c2p:function(t){return e.project(t).x}},e.yaxis={_id:\"y\",c2p:function(t){return e.project(t).y}},e.updateFramework(t),e.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},l.setConvert(e.mockAxis,t)},g.initFx=function(t,e){var r=this,n=r.gd,i=r.map,o=!1;function l(){a.loneUnhover(e._hoverlayer)}function c(){var t=r.getView();n.emit(\"plotly_relayouting\",r.getViewEdits(t))}i.on(\"moveend\",function(t){if(r.map){var e=n._fullLayout;if(t.originalEvent||o){var i=e[r.id];s.call(\"_storeDirectGUIEdit\",n.layout,e._preGUI,r.getViewEdits(i));var a=r.getView();i._input.center=i.center=a.center,i._input.zoom=i.zoom=a.zoom,i._input.bearing=i.bearing=a.bearing,i._input.pitch=i.pitch=a.pitch,n.emit(\"plotly_relayout\",r.getViewEdits(a))}o=!1,e._rehover&&e._rehover()}}),i.on(\"wheel\",function(){o=!0}),i.on(\"mousemove\",function(t){var e=r.div.getBoundingClientRect();t.clientX=t.point.x+e.left,t.clientY=t.point.y+e.top,t.target.getBoundingClientRect=function(){return e},r.xaxis.p2c=function(){return t.lngLat.lng},r.yaxis.p2c=function(){return t.lngLat.lat},n._fullLayout._rehover=function(){n._fullLayout._hoversubplot===r.id&&a.hover(n,t,r.id)},a.hover(n,t,r.id),n._fullLayout._hoversubplot=r.id}),i.on(\"dragstart\",l),i.on(\"zoomstart\",l),i.on(\"mouseout\",function(){n._fullLayout._hoversubplot=null}),i.on(\"drag\",c),i.on(\"zoom\",c),i.on(\"dblclick\",function(){var t=n._fullLayout[r.id];s.call(\"_storeDirectGUIEdit\",n.layout,n._fullLayout._preGUI,r.getViewEdits(t));var e=r.viewInitial;i.setCenter(x(e.center)),i.setZoom(e.zoom),i.setBearing(e.bearing),i.setPitch(e.pitch);var a=r.getView();t._input.center=t.center=a.center,t._input.zoom=t.zoom=a.zoom,t._input.bearing=t.bearing=a.bearing,t._input.pitch=t.pitch=a.pitch,n.emit(\"plotly_doubleclick\",null),n.emit(\"plotly_relayout\",r.getViewEdits(a))}),r.clearSelect=function(){n._fullLayout._zoomlayer.selectAll(\".select-outline\").remove()},r.onClickInPanFn=function(t){return function(e){var i=n._fullLayout.clickmode;i.indexOf(\"select\")>-1&&h(e.originalEvent,n,[r.xaxis],[r.yaxis],r.id,t),i.indexOf(\"event\")>-1&&a.click(n,e.originalEvent)}}},g.updateFx=function(t){var e=this,r=e.map,n=e.gd;if(!e.isStatic){var i,a=t.dragmode;i=\"select\"===a?function(t,r){(t.range={})[e.id]=[l([r.xmin,r.ymin]),l([r.xmax,r.ymax])]}:function(t,r,n){(t.lassoPoints={})[e.id]=n.filtered.map(l)};var s=e.dragOptions;e.dragOptions=o.extendDeep(s||{},{element:e.div,gd:n,plotinfo:{id:e.id,xaxis:e.xaxis,yaxis:e.yaxis,fillRangeItems:i},xaxes:[e.xaxis],yaxes:[e.yaxis],subplot:e.id}),r.off(\"click\",e.onClickInPanHandler),\"select\"===a||\"lasso\"===a?(r.dragPan.disable(),r.on(\"zoomstart\",e.clearSelect),e.dragOptions.prepFn=function(t,r,n){u(t,r,n,e.dragOptions,a)},c.init(e.dragOptions)):(r.dragPan.enable(),r.off(\"zoomstart\",e.clearSelect),e.div.onmousedown=null,e.onClickInPanHandler=e.onClickInPanFn(e.dragOptions),r.on(\"click\",e.onClickInPanHandler))}function l(t){var r=e.map.unproject(t);return[r.lng,r.lat]}},g.updateFramework=function(t){var e=t[this.id].domain,r=t._size,n=this.div.style;n.width=r.w*(e.x[1]-e.x[0])+\"px\",n.height=r.h*(e.y[1]-e.y[0])+\"px\",n.left=r.l+e.x[0]*r.w+\"px\",n.top=r.t+(1-e.y[1])*r.h+\"px\",this.xaxis._offset=r.l+e.x[0]*r.w,this.xaxis._length=r.w*(e.x[1]-e.x[0]),this.yaxis._offset=r.t+(1-e.y[1])*r.h,this.yaxis._length=r.h*(e.y[1]-e.y[0])},g.updateLayers=function(t){var e,r=t[this.id].layers,n=this.layerList;if(r.length!==n.length){for(e=0;e<n.length;e++)n[e].dispose();for(n=this.layerList=[],e=0;e<r.length;e++)n.push(p(this,e,r[e]))}else for(e=0;e<r.length;e++)n[e].update(r[e])},g.destroy=function(){this.map&&(this.map.remove(),this.map=null,this.container.removeChild(this.div))},g.toImage=function(){return this.map.stop(),this.map.getCanvas().toDataURL()},g.setOptions=function(t,e,r){for(var n in r)this.map[e](t,n,r[n])},g.getMapLayers=function(){return this.map.getStyle().layers},g.addLayer=function(t,e){var r=this.map;if(\"string\"==typeof e){if(\"\"===e)return void r.addLayer(t,e);for(var n=this.getMapLayers(),i=0;i<n.length;i++)if(e===n[i].id)return void r.addLayer(t,e);o.warn([\"Trying to add layer with *below* value\",e,\"referencing a layer that does not exist\",\"or that does not yet exist.\"].join(\" \"))}r.addLayer(t)},g.project=function(t){return this.map.project(new n.LngLat(t[0],t[1]))},g.getView=function(){var t=this.map,e=t.getCenter();return{center:{lon:e.lng,lat:e.lat},zoom:t.getZoom(),bearing:t.getBearing(),pitch:t.getPitch()}},g.getViewEdits=function(t){for(var e=this.id,r=[\"center\",\"zoom\",\"bearing\",\"pitch\"],n={},i=0;i<r.length;i++){var a=r[i];n[e+\".\"+a]=t[a]}return n},e.exports=d},{\"../../components/dragelement\":611,\"../../components/fx\":632,\"../../lib\":719,\"../../registry\":847,\"../cartesian/axes\":767,\"../cartesian/select\":784,\"./constants\":820,\"./layers\":823,d3:163,\"mapbox-gl\":426}],827:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType;return{t:{valType:\"number\",dflt:0,editType:e},r:{valType:\"number\",dflt:0,editType:e},b:{valType:\"number\",dflt:0,editType:e},l:{valType:\"number\",dflt:0,editType:e},editType:e}}},{}],828:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../registry\"),o=t(\"../plot_api/plot_schema\"),s=t(\"../plot_api/plot_template\"),l=t(\"../lib\"),c=t(\"../components/color\"),u=t(\"../constants/numerical\").BADNUM,h=t(\"./cartesian/axis_ids\"),f=t(\"./animation_attributes\"),p=t(\"./frame_attributes\"),d=l.relinkPrivateKeys,g=l._,v=e.exports={};l.extendFlat(v,a),v.attributes=t(\"./attributes\"),v.attributes.type.values=v.allTypes,v.fontAttrs=t(\"./font_attributes\"),v.layoutAttributes=t(\"./layout_attributes\"),v.fontWeight=\"normal\";var m=v.transformsRegistry,y=t(\"./command\");v.executeAPICommand=y.executeAPICommand,v.computeAPICommandBindings=y.computeAPICommandBindings,v.manageCommandObserver=y.manageCommandObserver,v.hasSimpleAPICommandBindings=y.hasSimpleAPICommandBindings,v.redrawText=function(t){var e=(t=l.getGraphDiv(t))._fullLayout||{};if(!(!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r))return new Promise(function(e){setTimeout(function(){a.getComponentMethod(\"annotations\",\"draw\")(t),a.getComponentMethod(\"legend\",\"draw\")(t),a.getComponentMethod(\"colorbar\",\"draw\")(t),e(v.previousPromises(t))},300)})},v.resize=function(t){return t=l.getGraphDiv(t),new Promise(function(e,r){t&&!l.isHidden(t)||r(new Error(\"Resize must be passed a displayed plot div element.\")),t._redrawTimer&&clearTimeout(t._redrawTimer),t._redrawTimer=setTimeout(function(){if(!t.layout||t.layout.width&&t.layout.height||l.isHidden(t))e(t);else{delete t.layout.width,delete t.layout.height;var r=t.changed;t.autoplay=!0,a.call(\"relayout\",t,{autosize:!0}).then(function(){t.changed=r,e(t)})}},100)})},v.previousPromises=function(t){if((t._promises||[]).length)return Promise.all(t._promises).then(function(){t._promises=[]})},v.addLinks=function(t){if(t._context.showLink||t._context.showSources){var e=t._fullLayout,r=l.ensureSingle(e._paper,\"text\",\"js-plot-link-container\",function(t){t.style({\"font-family\":'\"Open Sans\", Arial, sans-serif',\"font-size\":\"12px\",fill:c.defaultLine,\"pointer-events\":\"all\"}).each(function(){var t=n.select(this);t.append(\"tspan\").classed(\"js-link-to-tool\",!0),t.append(\"tspan\").classed(\"js-link-spacer\",!0),t.append(\"tspan\").classed(\"js-sourcelinks\",!0)})}),i=r.node(),a={y:e._paper.attr(\"height\")-9};document.body.contains(i)&&i.getComputedTextLength()>=e.width-20?(a[\"text-anchor\"]=\"start\",a.x=5):(a[\"text-anchor\"]=\"end\",a.x=e._paper.attr(\"width\")-7),r.attr(a);var o=r.select(\".js-link-to-tool\"),s=r.select(\".js-link-spacer\"),u=r.select(\".js-sourcelinks\");t._context.showSources&&t._context.showSources(t),t._context.showLink&&function(t,e){e.text(\"\");var r=e.append(\"a\").attr({\"xlink:xlink:href\":\"#\",class:\"link--impt link--embedview\",\"font-weight\":\"bold\"}).text(t._context.linkText+\" \"+String.fromCharCode(187));if(t._context.sendData)r.on(\"click\",function(){v.sendDataToCloud(t)});else{var n=window.location.pathname.split(\"/\"),i=window.location.search;r.attr({\"xlink:xlink:show\":\"new\",\"xlink:xlink:href\":\"/\"+n[2].split(\".\")[0]+\"/\"+n[1]+i})}}(t,o),s.text(o.text()&&u.text()?\" - \":\"\")}},v.sendDataToCloud=function(t){t.emit(\"plotly_beforeexport\");var e=(window.PLOTLYENV||{}).BASE_URL||t._context.plotlyServerURL,r=n.select(t).append(\"div\").attr(\"id\",\"hiddenform\").style(\"display\",\"none\"),i=r.append(\"form\").attr({action:e+\"/external\",method:\"post\",target:\"_blank\"});return i.append(\"input\").attr({type:\"text\",name:\"data\"}).node().value=v.graphJson(t,!1,\"keepdata\"),i.node().submit(),r.remove(),t.emit(\"plotly_afterexport\"),!1};var x=[\"days\",\"shortDays\",\"months\",\"shortMonths\",\"periods\",\"dateTime\",\"date\",\"time\",\"decimal\",\"thousands\",\"grouping\",\"currency\"],b=[\"year\",\"month\",\"dayMonth\",\"dayMonthYear\"];function _(t,e){var r=t._context.locale,n=!1,i={};function o(t){for(var r=!0,a=0;a<e.length;a++){var o=e[a];i[o]||(t[o]?i[o]=t[o]:r=!1)}r&&(n=!0)}for(var s=0;s<2;s++){for(var l=t._context.locales,c=0;c<2;c++){var u=(l[r]||{}).format;if(u&&(o(u),n))break;l=a.localeRegistry}var h=r.split(\"-\")[0];if(n||h===r)break;r=h}return n||o(a.localeRegistry.en.format),i}function w(t,e){var r={_fullLayout:e},n=\"x\"===t._id.charAt(0),i=t._mainAxis._anchorAxis,a=\"\",o=\"\",s=\"\";if(i&&(s=i._mainAxis._id,a=n?t._id+s:s+t._id),!a||!e._plots[a]){a=\"\";for(var l=t._counterAxes,c=0;c<l.length;c++){var u=l[c],f=n?t._id+u:u+t._id;o||(o=f);var p=h.getFromId(r,u);if(s&&p.overlaying===s){a=f;break}}}return a||o}function k(t){var e=t.transforms;if(Array.isArray(e)&&e.length)for(var r=0;r<e.length;r++){var n=e[r],i=n._module||m[n.type];if(i&&i.makesData)return!0}return!1}function T(t,e,r,n){for(var i=t.transforms,a=[t],o=0;o<i.length;o++){var s=i[o],l=m[s.type];l&&l.transform&&(a=l.transform(a,{transform:s,fullTrace:t,fullData:e,layout:r,fullLayout:n,transformIndex:o}))}return a}function A(t){var e=t.margin;if(!t._size){var r=t._size={l:Math.round(e.l),r:Math.round(e.r),t:Math.round(e.t),b:Math.round(e.b),p:Math.round(e.pad)};r.w=Math.round(t.width)-r.l-r.r,r.h=Math.round(t.height)-r.t-r.b}t._pushmargin||(t._pushmargin={}),t._pushmarginIds||(t._pushmarginIds={})}v.supplyDefaults=function(t,e){var r=e&&e.skipUpdateCalc,i=t._fullLayout||{};if(i._skipDefaults)delete i._skipDefaults;else{var o,s=t._fullLayout={},c=t.layout||{},u=t._fullData||[],h=t._fullData=[],f=t.data||[],p=t.calcdata||[],m=t._context||{};t._transitionData||v.createTransitionData(t),s._dfltTitle={plot:g(t,\"Click to enter Plot title\"),x:g(t,\"Click to enter X axis title\"),y:g(t,\"Click to enter Y axis title\"),colorbar:g(t,\"Click to enter Colorscale title\"),annotation:g(t,\"new text\")},s._traceWord=g(t,\"trace\");var y=_(t,x);if(s._mapboxAccessToken=m.mapboxAccessToken,i._initialAutoSizeIsDone){var w=i.width,k=i.height;v.supplyLayoutGlobalDefaults(c,s,y),c.width||(s.width=w),c.height||(s.height=k),v.sanitizeMargins(s)}else{v.supplyLayoutGlobalDefaults(c,s,y);var T=!c.width||!c.height,M=s.autosize,S=m.autosizable;T&&(M||S)?v.plotAutoSize(t,c,s):T&&v.sanitizeMargins(s),!M&&T&&(c.width=s.width,c.height=s.height)}s._d3locale=function(t,e){return t.decimal=e.charAt(0),t.thousands=e.charAt(1),n.locale(t)}(y,s.separators),s._extraFormat=_(t,b),s._initialAutoSizeIsDone=!0,s._dataLength=f.length,s._modules=[],s._visibleModules=[],s._basePlotModules=[];var E=s._subplots=function(){var t,e,r=a.collectableSubplotTypes,n={};if(!r){r=[];var i=a.subplotsRegistry;for(var o in i){var s=i[o],c=s.attr;if(c&&(r.push(o),Array.isArray(c)))for(e=0;e<c.length;e++)l.pushUnique(r,c[e])}}for(t=0;t<r.length;t++)n[r[t]]=[];return n}(),C=s._splomAxes={x:{},y:{}},L=s._splomSubplots={};s._splomGridDflt={},s._scatterStackOpts={},s._firstScatter={},s._alignmentOpts={},s._colorAxes={},s._requestRangeslider={},s._traceUids=function(t,e){var r,n,i=e.length,a=[];for(r=0;r<t.length;r++){var o=t[r]._fullInput;o!==n&&a.push(o),n=o}var s=a.length,c=new Array(i),u={};function h(t,e){c[e]=t,u[t]=1}function f(t,e){if(t&&\"string\"==typeof t&&!u[t])return h(t,e),!0}for(r=0;r<i;r++){var p=e[r].uid;\"number\"==typeof p&&(p=String(p)),f(p,r)||(r<s&&f(a[r].uid,r)||h(l.randstr(u),r))}return c}(u,f),s._globalTransforms=(t._context||{}).globalTransforms,v.supplyDataDefaults(f,h,c,s);var P=Object.keys(C.x),O=Object.keys(C.y);if(P.length>1&&O.length>1){for(a.getComponentMethod(\"grid\",\"sizeDefaults\")(c,s),o=0;o<P.length;o++)l.pushUnique(E.xaxis,P[o]);for(o=0;o<O.length;o++)l.pushUnique(E.yaxis,O[o]);for(var z in L)l.pushUnique(E.cartesian,z)}if(s._has=v._hasPlotType.bind(s),u.length===h.length)for(o=0;o<h.length;o++)d(h[o],u[o]);v.supplyLayoutModuleDefaults(c,s,h,t._transitionData);var I=s._visibleModules,D=[];for(o=0;o<I.length;o++){var R=I[o].crossTraceDefaults;R&&l.pushUnique(D,R)}for(o=0;o<D.length;o++)D[o](h,s);s._hasOnlyLargeSploms=1===s._basePlotModules.length&&\"splom\"===s._basePlotModules[0].name&&P.length>15&&O.length>15&&0===s.shapes.length&&0===s.images.length,s._hasCartesian=s._has(\"cartesian\"),s._hasGeo=s._has(\"geo\"),s._hasGL3D=s._has(\"gl3d\"),s._hasGL2D=s._has(\"gl2d\"),s._hasTernary=s._has(\"ternary\"),s._hasPie=s._has(\"pie\"),v.linkSubplots(h,s,u,i),v.cleanPlot(h,s,u,i),i._zoomlayer&&!t._dragging&&i._zoomlayer.selectAll(\".select-outline\").remove(),function(t,e){var r,n=[];e.meta&&(r=e._meta={meta:e.meta,layout:{meta:e.meta}});for(var i=0;i<t.length;i++){var a=t[i];a.meta?n[a.index]=a._meta={meta:a.meta}:e.meta&&(a._meta={meta:e.meta}),e.meta&&(a._meta.layout={meta:e.meta})}n.length&&(r||(r=e._meta={}),r.data=n)}(h,s),d(s,i),a.getComponentMethod(\"colorscale\",\"crossTraceDefaults\")(h,s),s._preGUI||(s._preGUI={}),s._tracePreGUI||(s._tracePreGUI={});var F,B=s._tracePreGUI,N={};for(F in B)N[F]=\"old\";for(o=0;o<h.length;o++)N[F=h[o]._fullInput.uid]||(B[F]={}),N[F]=\"new\";for(F in N)\"old\"===N[F]&&delete B[F];A(s),a.getComponentMethod(\"rangeslider\",\"makeData\")(s),r||p.length!==h.length||v.supplyDefaultsUpdateCalc(p,h)}},v.supplyDefaultsUpdateCalc=function(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=(t[r]||[])[0];if(i&&i.trace){var a=i.trace;if(a._hasCalcTransform){var o,s,c,u=a._arrayAttrs;for(o=0;o<u.length;o++)s=u[o],c=l.nestedProperty(a,s).get().slice(),l.nestedProperty(n,s).set(c)}i.trace=n}}},v.createTransitionData=function(t){t._transitionData||(t._transitionData={}),t._transitionData._frames||(t._transitionData._frames=[]),t._transitionData._frameHash||(t._transitionData._frameHash={}),t._transitionData._counter||(t._transitionData._counter=0),t._transitionData._interruptCallbacks||(t._transitionData._interruptCallbacks=[])},v._hasPlotType=function(t){var e,r=this._basePlotModules||[];for(e=0;e<r.length;e++)if(r[e].name===t)return!0;var n=this._modules||[];for(e=0;e<n.length;e++){var i=n[e].name;if(i===t)return!0;var o=a.modules[i];if(o&&o.categories[t])return!0}return!1},v.cleanPlot=function(t,e,r,n){var i,a,o=n._basePlotModules||[];for(i=0;i<o.length;i++){var s=o[i];s.clean&&s.clean(t,e,r,n)}var l=n._has&&n._has(\"gl\"),c=e._has&&e._has(\"gl\");l&&!c&&void 0!==n._glcontainer&&(n._glcontainer.selectAll(\".gl-canvas\").remove(),n._glcontainer.selectAll(\".no-webgl\").remove(),n._glcanvas=null);var u=!!n._infolayer;t:for(i=0;i<r.length;i++){var h=r[i].uid;for(a=0;a<t.length;a++){if(h===t[a].uid)continue t}u&&n._infolayer.select(\".cb\"+h).remove()}},v.linkSubplots=function(t,e,r,n){var i,a,o=n._plots||{},s=e._plots={},c=e._subplots,u={_fullData:t,_fullLayout:e},f=c.cartesian.concat(c.gl2d||[]);for(i=0;i<f.length;i++){var p,d=f[i],g=o[d],v=h.getFromId(u,d,\"x\"),m=h.getFromId(u,d,\"y\");for(g?p=s[d]=g:(p=s[d]={}).id=d,v._counterAxes.push(m._id),m._counterAxes.push(v._id),v._subplotsWith.push(d),m._subplotsWith.push(d),p.xaxis=v,p.yaxis=m,p._hasClipOnAxisFalse=!1,a=0;a<t.length;a++){var y=t[a];if(y.xaxis===p.xaxis._id&&y.yaxis===p.yaxis._id&&!1===y.cliponaxis){p._hasClipOnAxisFalse=!0;break}}}var x,b=h.list(u,null,!0);for(i=0;i<b.length;i++){var _=null;(x=b[i]).overlaying&&(_=h.getFromId(u,x.overlaying))&&_.overlaying&&(x.overlaying=!1,_=null),x._mainAxis=_||x,_&&(x.domain=_.domain.slice()),x._anchorAxis=\"free\"===x.anchor?null:h.getFromId(u,x.anchor)}for(i=0;i<b.length;i++)(x=b[i])._counterAxes.sort(h.idSort),x._subplotsWith.sort(l.subplotSort),x._mainSubplot=w(x,e)},v.clearExpandedTraceDefaultColors=function(t){var e,r,n;for(r=[],(e=t._module._colorAttrs)||(t._module._colorAttrs=e=[],o.crawl(t._module.attributes,function(t,n,i,a){r[a]=n,r.length=a+1,\"color\"===t.valType&&void 0===t.dflt&&e.push(r.join(\".\"))})),n=0;n<e.length;n++){l.nestedProperty(t,\"_input.\"+e[n]).get()||l.nestedProperty(t,e[n]).set(null)}},v.supplyDataDefaults=function(t,e,r,n){var i,o,c,u=n._modules,h=n._visibleModules,f=n._basePlotModules,p=0,g=0;function m(t){e.push(t);var r=t._module;r&&(l.pushUnique(u,r),!0===t.visible&&l.pushUnique(h,r),l.pushUnique(f,t._module.basePlotModule),p++,!1!==t._input.visible&&g++)}n._transformModules=[];var y={},x=[],b=(r.template||{}).data||{},_=s.traceTemplater(b);for(i=0;i<t.length;i++){if(c=t[i],(o=_.newTrace(c)).uid=n._traceUids[i],v.supplyTraceDefaults(c,o,g,n,i),o.index=i,o._input=c,o._expandedIndex=p,o.transforms&&o.transforms.length)for(var w=!1!==c.visible&&!1===o.visible,k=T(o,e,r,n),A=0;A<k.length;A++){var M=k[A],S={_template:o._template,type:o.type,uid:o.uid+A};w&&!1===M.visible&&delete M.visible,v.supplyTraceDefaults(M,S,p,n,i),d(S,M),S.index=i,S._input=c,S._fullInput=o,S._expandedIndex=p,S._expandedInput=M,m(S)}else o._fullInput=o,o._expandedInput=o,m(o);a.traceIs(o,\"carpetAxis\")&&(y[o.carpet]=o),a.traceIs(o,\"carpetDependent\")&&x.push(i)}for(i=0;i<x.length;i++)if((o=e[x[i]]).visible){var E=y[o.carpet];o._carpet=E,E&&E.visible?(o.xaxis=E.xaxis,o.yaxis=E.yaxis):o.visible=!1}},v.supplyAnimationDefaults=function(t){var e;t=t||{};var r={};function n(e,n){return l.coerce(t||{},r,f,e,n)}if(n(\"mode\"),n(\"direction\"),n(\"fromcurrent\"),Array.isArray(t.frame))for(r.frame=[],e=0;e<t.frame.length;e++)r.frame[e]=v.supplyAnimationFrameDefaults(t.frame[e]||{});else r.frame=v.supplyAnimationFrameDefaults(t.frame||{});if(Array.isArray(t.transition))for(r.transition=[],e=0;e<t.transition.length;e++)r.transition[e]=v.supplyAnimationTransitionDefaults(t.transition[e]||{});else r.transition=v.supplyAnimationTransitionDefaults(t.transition||{});return r},v.supplyAnimationFrameDefaults=function(t){var e={};function r(r,n){return l.coerce(t||{},e,f.frame,r,n)}return r(\"duration\"),r(\"redraw\"),e},v.supplyAnimationTransitionDefaults=function(t){var e={};function r(r,n){return l.coerce(t||{},e,f.transition,r,n)}return r(\"duration\"),r(\"easing\"),e},v.supplyFrameDefaults=function(t){var e={};function r(r,n){return l.coerce(t,e,p,r,n)}return r(\"group\"),r(\"name\"),r(\"traces\"),r(\"baseframe\"),r(\"data\"),r(\"layout\"),e},v.supplyTraceDefaults=function(t,e,r,n,i){var o,s=n.colorway||c.defaults,u=s[r%s.length];function h(r,n){return l.coerce(t,e,v.attributes,r,n)}var f=h(\"visible\");h(\"type\"),h(\"name\",n._traceWord+\" \"+i),h(\"uirevision\",n.uirevision);var p=v.getModule(e);if(e._module=p,p){var d=p.basePlotModule,g=d.attr,m=d.attributes;if(g&&m){var y=n._subplots,x=\"\";if(\"gl2d\"!==d.name||f){if(Array.isArray(g))for(o=0;o<g.length;o++){var b=g[o],_=l.coerce(t,e,m,b);y[b]&&l.pushUnique(y[b],_),x+=_}else x=l.coerce(t,e,m,g);y[d.name]&&l.pushUnique(y[d.name],x)}}}return f&&(h(\"customdata\"),h(\"ids\"),h(\"meta\"),a.traceIs(e,\"showLegend\")?(e._dfltShowLegend=!0,h(\"showlegend\"),h(\"legendgroup\")):e._dfltShowLegend=!1,p&&p.supplyDefaults(t,e,u,n),a.traceIs(e,\"noOpacity\")||h(\"opacity\"),a.traceIs(e,\"notLegendIsolatable\")&&(e.visible=!!e.visible),a.traceIs(e,\"noHover\")||(e.hovertemplate||l.coerceHoverinfo(t,e,n),\"parcats\"!==e.type&&a.getComponentMethod(\"fx\",\"supplyDefaults\")(t,e,u,n)),p&&p.selectPoints&&h(\"selectedpoints\"),v.supplyTransformDefaults(t,e,n)),e},v.hasMakesDataTransform=k,v.supplyTransformDefaults=function(t,e,r){if(e._length||k(t)){var n=r._globalTransforms||[],i=r._transformModules||[];if(Array.isArray(t.transforms)||0!==n.length)for(var a=t.transforms||[],o=n.concat(a),s=e.transforms=[],c=0;c<o.length;c++){var u,h=o[c],f=h.type,p=m[f],d=!(h._module&&h._module===p),g=p&&\"function\"==typeof p.transform;p||l.warn(\"Unrecognized transform type \"+f+\".\"),p&&p.supplyDefaults&&(d||g)?((u=p.supplyDefaults(h,e,r,t)).type=f,u._module=p,l.pushUnique(i,p)):u=l.extendFlat({},h),s.push(u)}}},v.supplyLayoutGlobalDefaults=function(t,e,r){function n(r,n){return l.coerce(t,e,v.layoutAttributes,r,n)}var i=t.template;l.isPlainObject(i)&&(e.template=i,e._template=i.layout,e._dataTemplate=i.data);var o=l.coerceFont(n,\"font\");n(\"title.text\",e._dfltTitle.plot),l.coerceFont(n,\"title.font\",{family:o.family,size:Math.round(1.4*o.size),color:o.color}),n(\"title.xref\"),n(\"title.yref\"),n(\"title.x\"),n(\"title.y\"),n(\"title.xanchor\"),n(\"title.yanchor\"),n(\"title.pad.t\"),n(\"title.pad.r\"),n(\"title.pad.b\"),n(\"title.pad.l\"),n(\"autosize\",!(t.width&&t.height)),n(\"width\"),n(\"height\"),n(\"margin.l\"),n(\"margin.r\"),n(\"margin.t\"),n(\"margin.b\"),n(\"margin.pad\"),n(\"margin.autoexpand\"),t.width&&t.height&&v.sanitizeMargins(e),a.getComponentMethod(\"grid\",\"sizeDefaults\")(t,e),n(\"paper_bgcolor\"),n(\"separators\",r.decimal+r.thousands),n(\"hidesources\"),n(\"colorway\"),n(\"datarevision\");var s=n(\"uirevision\");n(\"editrevision\",s),n(\"selectionrevision\",s),n(\"modebar.orientation\"),n(\"modebar.bgcolor\",c.addOpacity(e.paper_bgcolor,.5));var u=c.contrast(c.rgb(e.modebar.bgcolor));n(\"modebar.color\",c.addOpacity(u,.3)),n(\"modebar.activecolor\",c.addOpacity(u,.7)),n(\"modebar.uirevision\",s),n(\"meta\"),l.isPlainObject(t.transition)&&(n(\"transition.duration\"),n(\"transition.easing\"),n(\"transition.ordering\")),a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\"),a.getComponentMethod(\"fx\",\"supplyLayoutGlobalDefaults\")(t,e,n)},v.plotAutoSize=function(t,e,r){var n,a,o=t._context||{},s=o.frameMargins,c=l.isPlotDiv(t);if(c&&t.emit(\"plotly_autosize\"),o.fillFrame)n=window.innerWidth,a=window.innerHeight,document.body.style.overflow=\"hidden\";else{var u=c?window.getComputedStyle(t):{};if(n=parseFloat(u.width)||parseFloat(u.maxWidth)||r.width,a=parseFloat(u.height)||parseFloat(u.maxHeight)||r.height,i(s)&&s>0){var h=1-2*s;n=Math.round(h*n),a=Math.round(h*a)}}var f=v.layoutAttributes.width.min,p=v.layoutAttributes.height.min;n<f&&(n=f),a<p&&(a=p);var d=!e.width&&Math.abs(r.width-n)>1,g=!e.height&&Math.abs(r.height-a)>1;(g||d)&&(d&&(r.width=n),g&&(r.height=a)),t._initialAutoSize||(t._initialAutoSize={width:n,height:a}),v.sanitizeMargins(r)},v.supplyLayoutModuleDefaults=function(t,e,r,n){var i,o,s,c=a.componentsRegistry,u=e._basePlotModules,h=a.subplotsRegistry.cartesian;for(i in c)(s=c[i]).includeBasePlot&&s.includeBasePlot(t,e);for(var f in u.length||u.push(h),e._has(\"cartesian\")&&(a.getComponentMethod(\"grid\",\"contentDefaults\")(t,e),h.finalizeSubplots(t,e)),e._subplots)e._subplots[f].sort(l.subplotSort);for(o=0;o<u.length;o++)(s=u[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var p=e._modules;for(o=0;o<p.length;o++)(s=p[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var d=e._transformModules;for(o=0;o<d.length;o++)(s=d[o]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r,n);for(i in c)(s=c[i]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r)},v.purge=function(t){var e=t._fullLayout||{};void 0!==e._glcontainer&&(e._glcontainer.selectAll(\".gl-canvas\").remove(),e._glcontainer.remove(),e._glcanvas=null),void 0!==e._geocontainer&&e._geocontainer.remove(),e._modeBar&&e._modeBar.destroy(),t._transitionData&&(t._transitionData._interruptCallbacks&&(t._transitionData._interruptCallbacks.length=0),t._transitionData._animationRaf&&window.cancelAnimationFrame(t._transitionData._animationRaf)),l.clearThrottle(),l.clearResponsive(t),delete t.data,delete t.layout,delete t._fullData,delete t._fullLayout,delete t.calcdata,delete t.framework,delete t.empty,delete t.fid,delete t.undoqueue,delete t.undonum,delete t.autoplay,delete t.changed,delete t._promises,delete t._redrawTimer,delete t._hmlumcount,delete t._hmpixcount,delete t._transitionData,delete t._transitioning,delete t._initialAutoSize,delete t._transitioningWithDuration,delete t._dragging,delete t._dragged,delete t._dragdata,delete t._hoverdata,delete t._snapshotInProgress,delete t._editing,delete t._mouseDownTime,delete t._legendMouseDownTime,t.removeAllListeners&&t.removeAllListeners()},v.style=function(t){var e,r=t._fullLayout._visibleModules,n=[];for(e=0;e<r.length;e++){var i=r[e];i.style&&l.pushUnique(n,i.style)}for(e=0;e<n.length;e++)n[e](t)},v.sanitizeMargins=function(t){if(t&&t.margin){var e,r=t.width,n=t.height,i=t.margin,a=r-(i.l+i.r),o=n-(i.t+i.b);a<0&&(e=(r-1)/(i.l+i.r),i.l=Math.floor(e*i.l),i.r=Math.floor(e*i.r)),o<0&&(e=(n-1)/(i.t+i.b),i.t=Math.floor(e*i.t),i.b=Math.floor(e*i.b))}},v.clearAutoMarginIds=function(t){t._fullLayout._pushmarginIds={}},v.allowAutoMargin=function(t,e){t._fullLayout._pushmarginIds[e]=1},v.autoMargin=function(t,e,r){var n=t._fullLayout,i=n._pushmargin,a=n._pushmarginIds;if(!1!==n.margin.autoexpand){if(r){var o=r.pad;if(void 0===o){var s=n.margin;o=Math.min(12,s.l,s.r,s.t,s.b)}r.l+r.r>.5*n.width&&(r.l=r.r=0),r.b+r.t>.5*n.height&&(r.b=r.t=0);var l=void 0!==r.xl?r.xl:r.x,c=void 0!==r.xr?r.xr:r.x,u=void 0!==r.yt?r.yt:r.y,h=void 0!==r.yb?r.yb:r.y;i[e]={l:{val:l,size:r.l+o},r:{val:c,size:r.r+o},b:{val:h,size:r.b+o},t:{val:u,size:r.t+o}},a[e]=1}else delete i[e],delete a[e];n._replotting||v.doAutoMargin(t)}},v.doAutoMargin=function(t){var e=t._fullLayout;e._size||(e._size={}),A(e);var r=e._size,n=e.margin,o=l.extendFlat({},r),s=n.l,c=n.r,u=n.t,h=n.b,f=e.width,p=e.height,d=e._pushmargin,g=e._pushmarginIds;if(!1!==e.margin.autoexpand){for(var m in d)g[m]||delete d[m];for(var y in d.base={l:{val:0,size:s},r:{val:1,size:c},t:{val:1,size:u},b:{val:0,size:h}},d){var x=d[y].l||{},b=d[y].b||{},_=x.val,w=x.size,k=b.val,T=b.size;for(var M in d){if(i(w)&&d[M].r){var S=d[M].r.val,E=d[M].r.size;if(S>_){var C=(w*S+(E-f)*_)/(S-_),L=(E*(1-_)+(w-f)*(1-S))/(S-_);C>=0&&L>=0&&f-(C+L)>0&&C+L>s+c&&(s=C,c=L)}}if(i(T)&&d[M].t){var P=d[M].t.val,O=d[M].t.size;if(P>k){var z=(T*P+(O-p)*k)/(P-k),I=(O*(1-k)+(T-p)*(1-P))/(P-k);z>=0&&I>=0&&p-(I+z)>0&&z+I>h+u&&(h=z,u=I)}}}}}if(r.l=Math.round(s),r.r=Math.round(c),r.t=Math.round(u),r.b=Math.round(h),r.p=Math.round(n.pad),r.w=Math.round(f)-r.l-r.r,r.h=Math.round(p)-r.t-r.b,!e._replotting&&v.didMarginChange(o,r))return\"_redrawFromAutoMarginCount\"in e?e._redrawFromAutoMarginCount++:e._redrawFromAutoMarginCount=1,a.call(\"plot\",t)};var M=[\"l\",\"r\",\"t\",\"b\",\"p\",\"w\",\"h\"];function S(t,e,r){var n=!1;var i=[v.previousPromises,function(){if(t._transitionData)return t._transitioning=!1,function(t){var e=Promise.resolve();if(!t)return e;for(;t.length;)e=e.then(t.shift());return e}(t._transitionData._interruptCallbacks)},r.prepareFn,v.rehover,function(){return t.emit(\"plotly_transitioning\",[]),new Promise(function(i){t._transitioning=!0,e.duration>0&&(t._transitioningWithDuration=!0),t._transitionData._interruptCallbacks.push(function(){n=!0}),r.redraw&&t._transitionData._interruptCallbacks.push(function(){return a.call(\"redraw\",t)}),t._transitionData._interruptCallbacks.push(function(){t.emit(\"plotly_transitioninterrupted\",[])});var o=0,s=0;function l(){return o++,function(){var e;s++,n||s!==o||(e=i,t._transitionData&&(function(t){if(t)for(;t.length;)t.shift()}(t._transitionData._interruptCallbacks),Promise.resolve().then(function(){if(r.redraw)return a.call(\"redraw\",t)}).then(function(){t._transitioning=!1,t._transitioningWithDuration=!1,t.emit(\"plotly_transitioned\",[])}).then(e)))}}r.runFn(l),setTimeout(l())})}],o=l.syncOrAsync(i,t);return o&&o.then||(o=Promise.resolve()),o.then(function(){return t})}v.didMarginChange=function(t,e){for(var r=0;r<M.length;r++){var n=M[r],a=t[n],o=e[n];if(!i(a)||Math.abs(o-a)>1)return!0}return!1},v.graphJson=function(t,e,r,n,i){(i&&e&&!t._fullData||i&&!e&&!t._fullLayout)&&v.supplyDefaults(t);var a=i?t._fullData:t.data,o=i?t._fullLayout:t.layout,s=(t._transitionData||{})._frames;function c(t){if(\"function\"==typeof t)return null;if(l.isPlainObject(t)){var e,n,i={};for(e in t)if(\"function\"!=typeof t[e]&&-1===[\"_\",\"[\"].indexOf(e.charAt(0))){if(\"keepdata\"===r){if(\"src\"===e.substr(e.length-3))continue}else if(\"keepstream\"===r){if(\"string\"==typeof(n=t[e+\"src\"])&&n.indexOf(\":\")>0&&!l.isPlainObject(t.stream))continue}else if(\"keepall\"!==r&&\"string\"==typeof(n=t[e+\"src\"])&&n.indexOf(\":\")>0)continue;i[e]=c(t[e])}return i}return Array.isArray(t)?t.map(c):l.isTypedArray(t)?l.simpleMap(t,l.identity):l.isJSDate(t)?l.ms2DateTimeLocal(+t):t}var u={data:(a||[]).map(function(t){var r=c(t);return e&&delete r.fit,r})};return e||(u.layout=c(o)),t.framework&&t.framework.isPolar&&(u=t.framework.getConfig()),s&&(u.frames=c(s)),\"object\"===n?u:JSON.stringify(u)},v.modifyFrames=function(t,e){var r,n,i,a=t._transitionData._frames,o=t._transitionData._frameHash;for(r=0;r<e.length;r++)switch((n=e[r]).type){case\"replace\":i=n.value;var s=(a[n.index]||{}).name,l=i.name;a[n.index]=o[l]=i,l!==s&&(delete o[s],o[l]=i);break;case\"insert\":o[(i=n.value).name]=i,a.splice(n.index,0,i);break;case\"delete\":delete o[(i=a[n.index]).name],a.splice(n.index,1)}return Promise.resolve()},v.computeFrame=function(t,e){var r,n,i,a,o=t._transitionData._frameHash;if(!e)throw new Error(\"computeFrame must be given a string frame name\");var s=o[e.toString()];if(!s)return!1;for(var l=[s],c=[s.name];s.baseframe&&(s=o[s.baseframe.toString()])&&-1===c.indexOf(s.name);)l.push(s),c.push(s.name);for(var u={};s=l.pop();)if(s.layout&&(u.layout=v.extendLayout(u.layout,s.layout)),s.data){if(u.data||(u.data=[]),!(n=s.traces))for(n=[],r=0;r<s.data.length;r++)n[r]=r;for(u.traces||(u.traces=[]),r=0;r<s.data.length;r++)null!=(i=n[r])&&(-1===(a=u.traces.indexOf(i))&&(a=u.data.length,u.traces[a]=i),u.data[a]=v.extendTrace(u.data[a],s.data[r]))}return u},v.recomputeFrameHash=function(t){for(var e=t._transitionData._frameHash={},r=t._transitionData._frames,n=0;n<r.length;n++){var i=r[n];i&&i.name&&(e[i.name]=i)}},v.extendObjectWithContainers=function(t,e,r){var n,i,a,o,s,c,u,h=l.extendDeepNoArrays({},e||{}),f=l.expandObjectPaths(h),p={};if(r&&r.length)for(a=0;a<r.length;a++)void 0===(i=(n=l.nestedProperty(f,r[a])).get())?l.nestedProperty(p,r[a]).set(null):(n.set(null),l.nestedProperty(p,r[a]).set(i));if(t=l.extendDeepNoArrays(t||{},f),r&&r.length)for(a=0;a<r.length;a++)if(c=l.nestedProperty(p,r[a]).get()){for(u=(s=l.nestedProperty(t,r[a])).get(),Array.isArray(u)||(u=[],s.set(u)),o=0;o<c.length;o++){var d=c[o];u[o]=null===d?null:v.extendObjectWithContainers(u[o],d)}s.set(u)}return t},v.dataArrayContainers=[\"transforms\",\"dimensions\"],v.layoutArrayContainers=a.layoutArrayContainers,v.extendTrace=function(t,e){return v.extendObjectWithContainers(t,e,v.dataArrayContainers)},v.extendLayout=function(t,e){return v.extendObjectWithContainers(t,e,v.layoutArrayContainers)},v.transition=function(t,e,r,n,i,a){var o={redraw:i.redraw},s={},c=[];return o.prepareFn=function(){for(var i=Array.isArray(e)?e.length:0,a=n.slice(0,i),o=0;o<a.length;o++){var u=a[o],h=t._fullData[u]._module;if(h){if(h.animatable){var f=h.basePlotModule.name;s[f]||(s[f]=[]),s[f].push(u)}t.data[a[o]]=v.extendTrace(t.data[a[o]],e[o])}}var p=l.expandObjectPaths(l.extendDeepNoArrays({},r)),d=/^[xy]axis[0-9]*$/;for(var g in p)d.test(g)&&delete p[g].range;v.extendLayout(t.layout,p),delete t.calcdata,v.supplyDefaults(t),v.doCalcdata(t);var m=l.expandObjectPaths(r);if(m){var y=t._fullLayout._plots;for(var x in y){var b,_,w,k,T=y[x],A=T.xaxis,M=T.yaxis,S=A.range.slice(),E=M.range.slice();Array.isArray(m[A._name+\".range\"])?b=m[A._name+\".range\"].slice():Array.isArray((m[A._name]||{}).range)&&(b=m[A._name].range.slice()),Array.isArray(m[M._name+\".range\"])?_=m[M._name+\".range\"].slice():Array.isArray((m[M._name]||{}).range)&&(_=m[M._name].range.slice()),S&&b&&(S[0]!==b[0]||S[1]!==b[1])&&(w={xr0:S,xr1:b}),E&&_&&(E[0]!==_[0]||E[1]!==_[1])&&(k={yr0:E,yr1:_}),(w||k)&&c.push(l.extendFlat({plotinfo:T},w,k))}}return Promise.resolve()},o.runFn=function(e){var n,i,o=t._fullLayout._basePlotModules,u=c.length;if(r)for(i=0;i<o.length;i++)o[i].transitionAxes&&o[i].transitionAxes(t,c,a,e);for(var h in u?((n=l.extendFlat({},a)).duration=0,delete s.cartesian):n=a,s){var f=s[h];t._fullData[f[0]]._module.basePlotModule.plot(t,f,n,e)}},S(t,a,o)},v.transitionFromReact=function(t,e,r,n){var i=t._fullLayout,a=i.transition,o={},s=[];return o.prepareFn=function(){var t=i._plots;for(var a in o.redraw=!1,\"some\"===e.anim&&(o.redraw=!0),\"some\"===r.anim&&(o.redraw=!0),t){var c,u,h=t[a],f=h.xaxis,p=h.yaxis,d=n[f._name].range.slice(),g=n[p._name].range.slice(),v=f.range.slice(),m=p.range.slice();f.setScale(),p.setScale(),d[0]===v[0]&&d[1]===v[1]||(c={xr0:d,xr1:v}),g[0]===m[0]&&g[1]===m[1]||(u={yr0:g,yr1:m}),(c||u)&&s.push(l.extendFlat({plotinfo:h},c,u))}return Promise.resolve()},o.runFn=function(r){for(var n,i,o,c=t._fullData,u=t._fullLayout._basePlotModules,h=[],f=0;f<c.length;f++)h.push(f);function p(){for(var e=0;e<u.length;e++)u[e].transitionAxes&&u[e].transitionAxes(t,s,n,r)}function d(){for(var e=0;e<u.length;e++)u[e].plot(t,o,i,r)}s.length&&e.anim?\"traces first\"===a.ordering?(n=l.extendFlat({},a,{duration:0}),o=h,i=a,d(),setTimeout(p,a.duration)):(n=a,o=null,i=l.extendFlat({},a,{duration:0}),p(),d()):s.length?(n=a,p()):e.anim&&(o=h,i=a,d())},S(t,a,o)},v.doCalcdata=function(t,e){var r,n,i,s,c=h.list(t),f=t._fullData,p=t._fullLayout,d=new Array(f.length),g=(t.calcdata||[]).slice();for(t.calcdata=d,p._numBoxes=0,p._numViolins=0,p._violinScaleGroupStats={},t._hmpixcount=0,t._hmlumcount=0,p._piecolormap={},p._sunburstcolormap={},p._funnelareacolormap={},i=0;i<f.length;i++)Array.isArray(e)&&-1===e.indexOf(i)&&(d[i]=g[i]);for(i=0;i<f.length;i++)(r=f[i])._arrayAttrs=o.findArrayAttributes(r),r._extremes={};var v=p._subplots.polar||[];for(i=0;i<v.length;i++)c.push(p[v[i]].radialaxis,p[v[i]].angularaxis);var y=!1;function x(e){if(r=f[e],n=r._module,!0===r.visible&&r.transforms){if(n&&n.calc){var i=n.calc(t,r);i[0]&&i[0].t&&i[0].t._scene&&delete i[0].t._scene.dirty}for(s=0;s<r.transforms.length;s++){var a=r.transforms[s];(n=m[a.type])&&n.calcTransform&&(r._hasCalcTransform=!0,y=!0,n.calcTransform(t,r,a))}}}function b(e,i){if(r=f[e],!!(n=r._module).isContainer===i){var a=[];if(!0===r.visible&&0!==r._length){delete r._indexToPoints;var o=r.transforms||[];for(s=o.length-1;s>=0;s--)if(o[s].enabled){r._indexToPoints=o[s]._indexToPoints;break}n&&n.calc&&(a=n.calc(t,r))}Array.isArray(a)&&a[0]||(a=[{x:u,y:u}]),a[0].t||(a[0].t={}),a[0].trace=r,d[e]=a}}for(C(c,f),i=0;i<f.length;i++)b(i,!0);for(i=0;i<f.length;i++)x(i);for(y&&C(c,f),i=0;i<f.length;i++)b(i,!0);for(i=0;i<f.length;i++)b(i,!1);L(t);var _=function(t,e){var r,n,i,o,s,c=[];function u(t,r,n){var i=r._id.charAt(0);if(\"histogram2dcontour\"===t){var a=r._counterAxes[0],o=h.getFromId(e,a),s=\"x\"===i||\"x\"===a&&\"category\"===o.type,l=\"y\"===i||\"y\"===a&&\"category\"===o.type;return function(t,e){return 0===t||0===e?-1:s&&t===n[e].length-1?-1:l&&e===n.length-1?-1:(\"y\"===i?e:t)-1}}return function(t,e){return\"y\"===i?e:t}}var f={min:function(t){return l.aggNums(Math.min,null,t)},max:function(t){return l.aggNums(Math.max,null,t)},sum:function(t){return l.aggNums(function(t,e){return t+e},null,t)},total:function(t){return l.aggNums(function(t,e){return t+e},null,t)},mean:function(t){return l.mean(t)},median:function(t){return l.median(t)}};for(r=0;r<t.length;r++){var p=t[r];if(\"category\"===p.type){var d=p.categoryorder.match(E);if(d){var g=d[1],v=d[2],m=[];for(n=0;n<p._categories.length;n++)m.push([p._categories[n],[]]);for(n=0;n<p._traceIndices.length;n++){var y=p._traceIndices[n],x=e._fullData[y],b=p._id.charAt(0);if(!0===x.visible){var _=x.type;a.traceIs(x,\"histogram\")&&(delete x._xautoBinFinished,delete x._yautoBinFinished);var w=e.calcdata[y];for(i=0;i<w.length;i++){var k,T,A,M=w[i];if(\"splom\"===_){var S=x._axesDim[p._id];if(\"y\"===b){var C=x._diag[S][0];C&&(p=e._fullLayout[h.id2name(C)])}var L=M.trace.dimensions[S].values;for(o=0;o<L.length;o++)for(k=L[o],T=p._categoriesMap[k],s=0;s<M.trace.dimensions.length;s++)if(s!==S){var P=M.trace.dimensions[s];m[T][1].push(P.values[o])}}else if(\"scattergl\"===_){for(o=0;o<M.t.x.length;o++)\"x\"===b&&(k=M.t.x[o],T=k,A=M.t.y[o]),\"y\"===b&&(k=M.t.y[o],T=k,A=M.t.x[o]),m[T][1].push(A);M.t&&M.t._scene&&delete M.t._scene.dirty}else if(M.hasOwnProperty(\"z\")){A=M.z;var O=u(x.type,p,A);for(o=0;o<A.length;o++)for(s=0;s<A[o].length;s++)(T=O(s,o))+1&&m[T][1].push(A[o][s])}else for(\"x\"===b?(k=M.p+1?M.p:M.x,A=M.s||M.v||M.y):\"y\"===b&&(k=M.p+1?M.p:M.y,A=M.s||M.v||M.x),Array.isArray(A)||(A=[A]),o=0;o<A.length;o++)m[k][1].push(A[o])}}}p._categoriesValue=m;var z=[];for(n=0;n<m.length;n++)z.push([m[n][0],f[g](m[n][1])]);z.sort(function(t,e){return t[1]-e[1]}),p._categoriesAggregatedValue=z,p._initialCategories=z.map(function(t){return t[0]}),\"descending\"===v&&p._initialCategories.reverse(),c=c.concat(p.sortByInitialCategories())}}}return c}(c,t);if(_.length){for(p._numBoxes=0,p._numViolins=0,i=0;i<_.length;i++)b(_[i],!0);for(i=0;i<_.length;i++)b(_[i],!1);L(t)}a.getComponentMethod(\"fx\",\"calc\")(t),a.getComponentMethod(\"errorbars\",\"calc\")(t)};var E=/(total|sum|min|max|mean|median) (ascending|descending)/;function C(t,e){for(var r=0;r<t.length;r++){var n=t[r];n.clearCalc(),\"multicategory\"===n.type&&n.setupMultiCategory(e)}}function L(t){var e,r,n,i=t._fullLayout,a=i._visibleModules,o={};for(r=0;r<a.length;r++){var s=a[r],c=s.crossTraceCalc;if(c){var u=s.basePlotModule.name;o[u]?l.pushUnique(o[u],c):o[u]=[c]}}for(n in o){var h=o[n],f=i._subplots[n];if(Array.isArray(f))for(e=0;e<f.length;e++){var p=f[e],d=\"cartesian\"===n?i._plots[p]:i[p];for(r=0;r<h.length;r++)h[r](t,d,p)}else for(r=0;r<h.length;r++)h[r](t)}}v.rehover=function(t){t._fullLayout._rehover&&t._fullLayout._rehover()},v.redrag=function(t){t._fullLayout._redrag&&t._fullLayout._redrag()},v.generalUpdatePerTraceModule=function(t,e,r,n){var i,a=e.traceHash,o={};for(i=0;i<r.length;i++){var s=r[i],c=s[0].trace;c.visible&&(o[c.type]=o[c.type]||[],o[c.type].push(s))}for(var u in a)if(!o[u]){var h=a[u][0];h[0].trace.visible=!1,o[u]=[h]}for(var f in o){var p=o[f];p[0][0].trace._module.plot(t,e,l.filterVisible(p),n)}e.traceHash=o}},{\"../components/color\":593,\"../constants/numerical\":695,\"../lib\":719,\"../plot_api/plot_schema\":756,\"../plot_api/plot_template\":757,\"../registry\":847,\"./animation_attributes\":762,\"./attributes\":764,\"./cartesian/axis_ids\":770,\"./command\":791,\"./font_attributes\":793,\"./frame_attributes\":794,\"./layout_attributes\":819,d3:163,\"fast-isnumeric\":225}],829:[function(t,e,r){\"use strict\";e.exports={attr:\"subplot\",name:\"polar\",axisNames:[\"angularaxis\",\"radialaxis\"],axisName2dataArray:{angularaxis:\"theta\",radialaxis:\"r\"},layerNames:[\"draglayer\",\"plotbg\",\"backplot\",\"angular-grid\",\"radial-grid\",\"frontplot\",\"angular-line\",\"radial-line\",\"angular-axis\",\"radial-axis\"],radialDragBoxSize:50,angularDragBoxSize:30,cornerLen:25,cornerHalfWidth:2,MINDRAG:8,MINZOOM:20,OFFEDGE:20}},{}],830:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/polygon\").tester,a=n.findIndexOfMin,o=n.isAngleInsideSector,s=n.angleDelta,l=n.angleDist;function c(t,e,r,n){var i,a,o=n[0],s=n[1],l=h(Math.sin(e)-Math.sin(t)),c=h(Math.cos(e)-Math.cos(t)),u=Math.tan(r),f=h(1/u),p=l/c,d=s-p*o;return f?l&&c?a=u*(i=d/(u-p)):c?(i=s*f,a=s):(i=o,a=o*u):l&&c?(i=0,a=d):c?(i=0,a=s):i=a=NaN,[i,a]}function u(t,e,r,i){return n.isFullCircle([e,r])?function(t,e){var r,n=e.length,i=new Array(n+1);for(r=0;r<n;r++){var a=e[r];i[r]=[t*Math.cos(a),t*Math.sin(a)]}return i[r]=i[0].slice(),i}(t,i):function(t,e,r,i){var s,u,h=i.length,f=[];function p(e){return[t*Math.cos(e),t*Math.sin(e)]}function d(t,e,r){return c(t,e,r,p(t))}function g(t){return n.mod(t,h)}function v(t){return o(t,[e,r])}var m=a(i,function(t){return v(t)?l(t,e):1/0}),y=d(i[m],i[g(m-1)],e);for(f.push(y),s=m,u=0;u<h;s++,u++){var x=i[g(s)];if(!v(x))break;f.push(p(x))}var b=a(i,function(t){return v(t)?l(t,r):1/0}),_=d(i[b],i[g(b+1)],r);return f.push(_),f.push([0,0]),f.push(f[0].slice()),f}(t,e,r,i)}function h(t){return Math.abs(t)>1e-10?t:0}function f(t,e,r){e=e||0,r=r||0;for(var n=t.length,i=new Array(n),a=0;a<n;a++){var o=t[a];i[a]=[e+o[0],r-o[1]]}return i}e.exports={isPtInsidePolygon:function(t,e,r,n,a){if(!o(e,n))return!1;var s,l;r[0]<r[1]?(s=r[0],l=r[1]):(s=r[1],l=r[0]);var c=i(u(s,n[0],n[1],a)),h=i(u(l,n[0],n[1],a)),f=[t*Math.cos(e),t*Math.sin(e)];return h.contains(f)&&!c.contains(f)},findPolygonOffset:function(t,e,r,n){for(var i=1/0,a=1/0,o=u(t,e,r,n),s=0;s<o.length;s++){var l=o[s];i=Math.min(i,l[0]),a=Math.min(a,-l[1])}return[i,a]},findEnclosingVertexAngles:function(t,e){var r=a(e,function(e){var r=s(e,t);return r>0?r:1/0}),i=n.mod(r+1,e.length);return[e[r],e[i]]},findIntersectionXY:c,findXYatLength:function(t,e,r,n){var i=-e*r,a=e*e+1,o=2*(e*i-r),s=i*i+r*r-t*t,l=Math.sqrt(o*o-4*a*s),c=(-o+l)/(2*a),u=(-o-l)/(2*a);return[[c,e*c+i+n],[u,e*u+i+n]]},clampTiny:h,pathPolygon:function(t,e,r,n,i,a){return\"M\"+f(u(t,e,r,n),i,a).join(\"L\")},pathPolygonAnnulus:function(t,e,r,n,i,a,o){var s,l;t<e?(s=t,l=e):(s=e,l=t);var c=f(u(s,r,n,i),a,o);return\"M\"+f(u(l,r,n,i),a,o).reverse().join(\"L\")+\"M\"+c.join(\"L\")}}},{\"../../lib\":719,\"../../lib/polygon\":731}],831:[function(t,e,r){\"use strict\";var n=t(\"../get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./polar\"),o=t(\"./constants\"),s=o.attr,l=o.name,c=i(l),u={};u[s]={valType:\"subplotid\",dflt:l,editType:\"calc\"},e.exports={attr:s,name:l,idRoot:l,idRegex:c,attrRegex:c,attributes:u,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[l],o=0;o<i.length;o++){var s=i[o],c=n(r,l,s),u=e[s]._subplot;u||(u=a(t,s),e[s]._subplot=u),u.plot(c,e,t._promises)}},clean:function(t,e,r,n){for(var i=n._subplots[l]||[],a=n._has&&n._has(\"gl\"),o=e._has&&e._has(\"gl\"),s=a&&!o,c=0;c<i.length;c++){var u=i[c],h=n[u]._subplot;if(!e[u]&&h)for(var f in h.framework.remove(),h.layers[\"radial-axis-title\"].remove(),h.clipPaths)h.clipPaths[f].remove();s&&h._scene&&(h._scene.destroy(),h._scene=null)}},toSVG:t(\"../cartesian\").toSVG}},{\"../../lib\":719,\"../cartesian\":778,\"../get_data\":802,\"./constants\":829,\"./layout_attributes\":832,\"./layout_defaults\":833,\"./polar\":840}],832:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../cartesian/layout_attributes\"),a=t(\"../domain\").attributes,o=t(\"../../lib\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=s({color:i.color,showline:o({},i.showline,{dflt:!0}),linecolor:i.linecolor,linewidth:i.linewidth,showgrid:o({},i.showgrid,{dflt:!0}),gridcolor:i.gridcolor,gridwidth:i.gridwidth},\"plot\",\"from-root\"),c=s({tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,showtickprefix:i.showtickprefix,tickprefix:i.tickprefix,showticksuffix:i.showticksuffix,ticksuffix:i.ticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,separatethousands:i.separatethousands,tickfont:i.tickfont,tickangle:i.tickangle,tickformat:i.tickformat,tickformatstops:i.tickformatstops,layer:i.layer},\"plot\",\"from-root\"),u={visible:o({},i.visible,{dflt:!0}),type:o({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autorange:o({},i.autorange,{editType:\"plot\"}),rangemode:{valType:\"enumerated\",values:[\"tozero\",\"nonnegative\",\"normal\"],dflt:\"tozero\",editType:\"calc\"},range:o({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],editType:\"plot\"}),categoryorder:i.categoryorder,categoryarray:i.categoryarray,angle:{valType:\"angle\",editType:\"plot\"},side:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"clockwise\",editType:\"plot\"},title:s(i.title,\"plot\",\"from-root\"),hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}};u.title.text.dflt=\"\",o(u,l,c);var h={visible:o({},i.visible,{dflt:!0}),type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"category\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},categoryorder:i.categoryorder,categoryarray:i.categoryarray,thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\"],dflt:\"degrees\",editType:\"calc\"},period:{valType:\"number\",editType:\"calc\",min:0},direction:{valType:\"enumerated\",values:[\"counterclockwise\",\"clockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"angle\",editType:\"calc\"},hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"};o(h,l,c),e.exports={domain:a({name:\"polar\",editType:\"plot\"}),sector:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],dflt:[0,360],editType:\"plot\"},hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},bgcolor:{valType:\"color\",editType:\"plot\",dflt:n.background},radialaxis:u,angularaxis:h,gridshape:{valType:\"enumerated\",values:[\"circular\",\"linear\"],dflt:\"circular\",editType:\"plot\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"}},{\"../../components/color/attributes\":592,\"../../lib\":719,\"../../plot_api/edit_types\":750,\"../cartesian/layout_attributes\":779,\"../domain\":792}],833:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../subplot_defaults\"),s=t(\"../get_data\").getSubplotData,l=t(\"../cartesian/tick_value_defaults\"),c=t(\"../cartesian/tick_mark_defaults\"),u=t(\"../cartesian/tick_label_defaults\"),h=t(\"../cartesian/category_order_defaults\"),f=t(\"../cartesian/line_grid_defaults\"),p=t(\"../cartesian/axis_autotype\"),d=t(\"./layout_attributes\"),g=t(\"./set_convert\"),v=t(\"./constants\"),m=v.axisNames;function y(t,e,r,o){var p=r(\"bgcolor\");o.bgColor=i.combine(p,o.paper_bgcolor);var y=r(\"sector\");r(\"hole\");var b,_=s(o.fullData,v.name,o.id),w=o.layoutOut;function k(t,e){return r(b+\".\"+t,e)}for(var T=0;T<m.length;T++){b=m[T],n.isPlainObject(t[b])||(t[b]={});var A=t[b],M=a.newContainer(e,b);M._id=M._name=b,M._attr=o.id+\".\"+b,M._traceIndices=_.map(function(t){return t._expandedIndex});var S=v.axisName2dataArray[b],E=x(A,M,k,_,S);h(A,M,k,{axData:_,dataAttr:S});var C,L,P=k(\"visible\");switch(g(M,e,w),k(\"uirevision\",e.uirevision),P&&(L=(C=k(\"color\"))===A.color?C:o.font.color),M._m=1,b){case\"radialaxis\":var O=k(\"autorange\",!M.isValidRange(A.range));A.autorange=O,!O||\"linear\"!==E&&\"-\"!==E||k(\"rangemode\"),\"reversed\"===O&&(M._m=-1),k(\"range\"),M.cleanRange(\"range\",{dfltRange:[0,1]}),P&&(k(\"side\"),k(\"angle\",y[0]),k(\"title.text\"),n.coerceFont(k,\"title.font\",{family:o.font.family,size:Math.round(1.2*o.font.size),color:L}));break;case\"angularaxis\":if(\"date\"===E){n.log(\"Polar plots do not support date angular axes yet.\");for(var z=0;z<_.length;z++)_[z].visible=!1;E=A.type=M.type=\"linear\"}k(\"linear\"===E?\"thetaunit\":\"period\");var I=k(\"direction\");k(\"rotation\",{counterclockwise:0,clockwise:90}[I])}if(P)l(A,M,k,M.type),u(A,M,k,M.type,{tickSuffixDflt:\"degrees\"===M.thetaunit?\"\\xb0\":void 0}),c(A,M,k,{outerTicks:!0}),k(\"showticklabels\")&&(n.coerceFont(k,\"tickfont\",{family:o.font.family,size:o.font.size,color:L}),k(\"tickangle\"),k(\"tickformat\")),f(A,M,k,{dfltColor:C,bgColor:o.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:d[b]}),k(\"layer\");\"category\"!==E&&k(\"hoverformat\"),M._input=A}\"category\"===e.angularaxis.type&&r(\"gridshape\")}function x(t,e,r,n,i){if(\"-\"===r(\"type\")){for(var a,o=0;o<n.length;o++)if(n[o].visible){a=n[o];break}a&&a[i]&&(e.type=p(a[i],\"gregorian\")),\"-\"===e.type?e.type=\"linear\":t.type=e.type}return e.type}e.exports=function(t,e,r){o(t,e,r,{type:v.name,attributes:d,handleDefaults:y,font:e.font,paper_bgcolor:e.paper_bgcolor,fullData:r,layoutOut:e})}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../cartesian/axis_autotype\":768,\"../cartesian/category_order_defaults\":771,\"../cartesian/line_grid_defaults\":781,\"../cartesian/tick_label_defaults\":786,\"../cartesian/tick_mark_defaults\":787,\"../cartesian/tick_value_defaults\":788,\"../get_data\":802,\"../subplot_defaults\":842,\"./constants\":829,\"./layout_attributes\":832,\"./set_convert\":841}],834:[function(t,e,r){\"use strict\";var n=t(\"../../../traces/scatter/attributes\"),i=n.marker,a=t(\"../../../lib/extend\").extendFlat;[\"Area traces are deprecated!\",\"Please switch to the *barpolar* trace type.\"].join(\" \");e.exports={r:a({},n.r,{}),t:a({},n.t,{}),marker:{color:a({},i.color,{}),size:a({},i.size,{}),symbol:a({},i.symbol,{}),opacity:a({},i.opacity,{}),editType:\"calc\"}}},{\"../../../lib/extend\":710,\"../../../traces/scatter/attributes\":1112}],835:[function(t,e,r){\"use strict\";var n=t(\"../../cartesian/layout_attributes\"),i=t(\"../../../lib/extend\").extendFlat,a=t(\"../../../plot_api/edit_types\").overrideAll,o=[\"Legacy polar charts are deprecated!\",\"Please switch to *polar* subplots.\"].join(\" \"),s=i({},n.domain,{});function l(t,e){return i({},e,{showline:{valType:\"boolean\"},showticklabels:{valType:\"boolean\"},tickorientation:{valType:\"enumerated\",values:[\"horizontal\",\"vertical\"]},ticklen:{valType:\"number\",min:0},tickcolor:{valType:\"color\"},ticksuffix:{valType:\"string\"},endpadding:{valType:\"number\",description:o},visible:{valType:\"boolean\"}})}e.exports=a({radialaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},domain:s,orientation:{valType:\"number\"}}),angularaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\",dflt:0},{valType:\"number\",dflt:360}]},domain:s}),layout:{direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"]},orientation:{valType:\"angle\"}}},\"plot\",\"nested\")},{\"../../../lib/extend\":710,\"../../../plot_api/edit_types\":750,\"../../cartesian/layout_attributes\":779}],836:[function(t,e,r){\"use strict\";(e.exports=t(\"./micropolar\")).manager=t(\"./micropolar_manager\")},{\"./micropolar\":837,\"./micropolar_manager\":838}],837:[function(t,e,r){var n=t(\"d3\"),i=t(\"../../../lib\").extendDeepAll,a=t(\"../../../constants/alignment\").MID_SHIFT,o=e.exports={version:\"0.2.2\"};o.Axis=function(){var t,e,r,s,l={data:[],layout:{}},c={},u={},h=n.dispatch(\"hover\"),f={};return f.render=function(c){return function(c){e=c||e;var h=l.data,f=l.layout;(\"string\"==typeof e||e.nodeName)&&(e=n.select(e)),e.datum(h).each(function(e,l){var c=e.slice();u={data:o.util.cloneJson(c),layout:o.util.cloneJson(f)};var h=0;c.forEach(function(t,e){t.color||(t.color=f.defaultColorRange[h],h=(h+1)%f.defaultColorRange.length),t.strokeColor||(t.strokeColor=\"LinePlot\"===t.geometry?t.color:n.rgb(t.color).darker().toString()),u.data[e].color=t.color,u.data[e].strokeColor=t.strokeColor,u.data[e].strokeDash=t.strokeDash,u.data[e].strokeSize=t.strokeSize});var p=c.filter(function(t,e){var r=t.visible;return\"undefined\"==typeof r||!0===r}),d=!1,g=p.map(function(t,e){return d=d||\"undefined\"!=typeof t.groupId,t});if(d){var v=n.nest().key(function(t,e){return\"undefined\"!=typeof t.groupId?t.groupId:\"unstacked\"}).entries(g),m=[],y=v.map(function(t,e){if(\"unstacked\"===t.key)return t.values;var r=t.values[0].r.map(function(t,e){return 0});return t.values.forEach(function(t,e,n){t.yStack=[r],m.push(r),r=o.util.sumArrays(t.r,r)}),t.values});p=n.merge(y)}p.forEach(function(t,e){t.t=Array.isArray(t.t[0])?t.t:[t.t],t.r=Array.isArray(t.r[0])?t.r:[t.r]});var x=Math.min(f.width-f.margin.left-f.margin.right,f.height-f.margin.top-f.margin.bottom)/2;x=Math.max(10,x);var b,_=[f.margin.left+x,f.margin.top+x];b=d?[0,n.max(o.util.sumArrays(o.util.arrayLast(p).r[0],o.util.arrayLast(m)))]:n.extent(o.util.flattenArray(p.map(function(t,e){return t.r}))),f.radialAxis.domain!=o.DATAEXTENT&&(b[0]=0),r=n.scale.linear().domain(f.radialAxis.domain!=o.DATAEXTENT&&f.radialAxis.domain?f.radialAxis.domain:b).range([0,x]),u.layout.radialAxis.domain=r.domain();var w,k=o.util.flattenArray(p.map(function(t,e){return t.t})),T=\"string\"==typeof k[0];T&&(k=o.util.deduplicate(k),w=k.slice(),k=n.range(k.length),p=p.map(function(t,e){var r=t;return t.t=[k],d&&(r.yStack=t.yStack),r}));var A=p.filter(function(t,e){return\"LinePlot\"===t.geometry||\"DotPlot\"===t.geometry}).length===p.length,M=null===f.needsEndSpacing?T||!A:f.needsEndSpacing,S=f.angularAxis.domain&&f.angularAxis.domain!=o.DATAEXTENT&&!T&&f.angularAxis.domain[0]>=0?f.angularAxis.domain:n.extent(k),E=Math.abs(k[1]-k[0]);A&&!T&&(E=0);var C=S.slice();M&&T&&(C[1]+=E);var L=f.angularAxis.ticksCount||4;L>8&&(L=L/(L/8)+L%8),f.angularAxis.ticksStep&&(L=(C[1]-C[0])/L);var P=f.angularAxis.ticksStep||(C[1]-C[0])/(L*(f.minorTicks+1));w&&(P=Math.max(Math.round(P),1)),C[2]||(C[2]=P);var O=n.range.apply(this,C);if(O=O.map(function(t,e){return parseFloat(t.toPrecision(12))}),s=n.scale.linear().domain(C.slice(0,2)).range(\"clockwise\"===f.direction?[0,360]:[360,0]),u.layout.angularAxis.domain=s.domain(),u.layout.angularAxis.endPadding=M?E:0,\"undefined\"==typeof(t=n.select(this).select(\"svg.chart-root\"))||t.empty()){var z=(new DOMParser).parseFromString(\"<svg xmlns='http://www.w3.org/2000/svg' class='chart-root'>' + '<g class='outer-group'>' + '<g class='chart-group'>' + '<circle class='background-circle'></circle>' + '<g class='geometry-group'></g>' + '<g class='radial axis-group'>' + '<circle class='outside-circle'></circle>' + '</g>' + '<g class='angular axis-group'></g>' + '<g class='guides-group'><line></line><circle r='0'></circle></g>' + '</g>' + '<g class='legend-group'></g>' + '<g class='tooltips-group'></g>' + '<g class='title-group'><text></text></g>' + '</g>' + '</svg>\",\"application/xml\"),I=this.appendChild(this.ownerDocument.importNode(z.documentElement,!0));t=n.select(I)}t.select(\".guides-group\").style({\"pointer-events\":\"none\"}),t.select(\".angular.axis-group\").style({\"pointer-events\":\"none\"}),t.select(\".radial.axis-group\").style({\"pointer-events\":\"none\"});var D,R=t.select(\".chart-group\"),F={fill:\"none\",stroke:f.tickColor},B={\"font-size\":f.font.size,\"font-family\":f.font.family,fill:f.font.color,\"text-shadow\":[\"-1px 0px\",\"1px -1px\",\"-1px 1px\",\"1px 1px\"].map(function(t,e){return\" \"+t+\" 0 \"+f.font.outlineColor}).join(\",\")};if(f.showLegend){D=t.select(\".legend-group\").attr({transform:\"translate(\"+[x,f.margin.top]+\")\"}).style({display:\"block\"});var N=p.map(function(t,e){var r=o.util.cloneJson(t);return r.symbol=\"DotPlot\"===t.geometry?t.dotType||\"circle\":\"LinePlot\"!=t.geometry?\"square\":\"line\",r.visibleInLegend=\"undefined\"==typeof t.visibleInLegend||t.visibleInLegend,r.color=\"LinePlot\"===t.geometry?t.strokeColor:t.color,r});o.Legend().config({data:p.map(function(t,e){return t.name||\"Element\"+e}),legendConfig:i({},o.Legend.defaultConfig().legendConfig,{container:D,elements:N,reverseOrder:f.legend.reverseOrder})})();var j=D.node().getBBox();x=Math.min(f.width-j.width-f.margin.left-f.margin.right,f.height-f.margin.top-f.margin.bottom)/2,x=Math.max(10,x),_=[f.margin.left+x,f.margin.top+x],r.range([0,x]),u.layout.radialAxis.domain=r.domain(),D.attr(\"transform\",\"translate(\"+[_[0]+x,_[1]-x]+\")\")}else D=t.select(\".legend-group\").style({display:\"none\"});t.attr({width:f.width,height:f.height}).style({opacity:f.opacity}),R.attr(\"transform\",\"translate(\"+_+\")\").style({cursor:\"crosshair\"});var U=[(f.width-(f.margin.left+f.margin.right+2*x+(j?j.width:0)))/2,(f.height-(f.margin.top+f.margin.bottom+2*x))/2];if(U[0]=Math.max(0,U[0]),U[1]=Math.max(0,U[1]),t.select(\".outer-group\").attr(\"transform\",\"translate(\"+U+\")\"),f.title&&f.title.text){var V=t.select(\"g.title-group text\").style(B).text(f.title.text),q=V.node().getBBox();V.attr({x:_[0]-q.width/2,y:_[1]-x-20})}var H=t.select(\".radial.axis-group\");if(f.radialAxis.gridLinesVisible){var G=H.selectAll(\"circle.grid-circle\").data(r.ticks(5));G.enter().append(\"circle\").attr({class:\"grid-circle\"}).style(F),G.attr(\"r\",r),G.exit().remove()}H.select(\"circle.outside-circle\").attr({r:x}).style(F);var Y=t.select(\"circle.background-circle\").attr({r:x}).style({fill:f.backgroundColor,stroke:f.stroke});function W(t,e){return s(t)%360+f.orientation}if(f.radialAxis.visible){var X=n.svg.axis().scale(r).ticks(5).tickSize(5);H.call(X).attr({transform:\"rotate(\"+f.radialAxis.orientation+\")\"}),H.selectAll(\".domain\").style(F),H.selectAll(\"g>text\").text(function(t,e){return this.textContent+f.radialAxis.ticksSuffix}).style(B).style({\"text-anchor\":\"start\"}).attr({x:0,y:0,dx:0,dy:0,transform:function(t,e){return\"horizontal\"===f.radialAxis.tickOrientation?\"rotate(\"+-f.radialAxis.orientation+\") translate(\"+[0,B[\"font-size\"]]+\")\":\"translate(\"+[0,B[\"font-size\"]]+\")\"}}),H.selectAll(\"g>line\").style({stroke:\"black\"})}var Z=t.select(\".angular.axis-group\").selectAll(\"g.angular-tick\").data(O),J=Z.enter().append(\"g\").classed(\"angular-tick\",!0);Z.attr({transform:function(t,e){return\"rotate(\"+W(t)+\")\"}}).style({display:f.angularAxis.visible?\"block\":\"none\"}),Z.exit().remove(),J.append(\"line\").classed(\"grid-line\",!0).classed(\"major\",function(t,e){return e%(f.minorTicks+1)==0}).classed(\"minor\",function(t,e){return!(e%(f.minorTicks+1)==0)}).style(F),J.selectAll(\".minor\").style({stroke:f.minorTickColor}),Z.select(\"line.grid-line\").attr({x1:f.tickLength?x-f.tickLength:0,x2:x}).style({display:f.angularAxis.gridLinesVisible?\"block\":\"none\"}),J.append(\"text\").classed(\"axis-text\",!0).style(B);var K=Z.select(\"text.axis-text\").attr({x:x+f.labelOffset,dy:a+\"em\",transform:function(t,e){var r=W(t),n=x+f.labelOffset,i=f.angularAxis.tickOrientation;return\"horizontal\"==i?\"rotate(\"+-r+\" \"+n+\" 0)\":\"radial\"==i?r<270&&r>90?\"rotate(180 \"+n+\" 0)\":null:\"rotate(\"+(r<=180&&r>0?-90:90)+\" \"+n+\" 0)\"}}).style({\"text-anchor\":\"middle\",display:f.angularAxis.labelsVisible?\"block\":\"none\"}).text(function(t,e){return e%(f.minorTicks+1)!=0?\"\":w?w[t]+f.angularAxis.ticksSuffix:t+f.angularAxis.ticksSuffix}).style(B);f.angularAxis.rewriteTicks&&K.text(function(t,e){return e%(f.minorTicks+1)!=0?\"\":f.angularAxis.rewriteTicks(this.textContent,e)});var $=n.max(R.selectAll(\".angular-tick text\")[0].map(function(t,e){return t.getCTM().e+t.getBBox().width}));D.attr({transform:\"translate(\"+[x+$,f.margin.top]+\")\"});var Q=t.select(\"g.geometry-group\").selectAll(\"g\").size()>0,tt=t.select(\"g.geometry-group\").selectAll(\"g.geometry\").data(p);if(tt.enter().append(\"g\").attr({class:function(t,e){return\"geometry geometry\"+e}}),tt.exit().remove(),p[0]||Q){var et=[];p.forEach(function(t,e){var n={};n.radialScale=r,n.angularScale=s,n.container=tt.filter(function(t,r){return r==e}),n.geometry=t.geometry,n.orientation=f.orientation,n.direction=f.direction,n.index=e,et.push({data:t,geometryConfig:n})});var rt=n.nest().key(function(t,e){return\"undefined\"!=typeof t.data.groupId||\"unstacked\"}).entries(et),nt=[];rt.forEach(function(t,e){\"unstacked\"===t.key?nt=nt.concat(t.values.map(function(t,e){return[t]})):nt.push(t.values)}),nt.forEach(function(t,e){var r;r=Array.isArray(t)?t[0].geometryConfig.geometry:t.geometryConfig.geometry;var n=t.map(function(t,e){return i(o[r].defaultConfig(),t)});o[r]().config(n)()})}var it,at,ot=t.select(\".guides-group\"),st=t.select(\".tooltips-group\"),lt=o.tooltipPanel().config({container:st,fontSize:8})(),ct=o.tooltipPanel().config({container:st,fontSize:8})(),ut=o.tooltipPanel().config({container:st,hasTick:!0})();if(!T){var ht=ot.select(\"line\").attr({x1:0,y1:0,y2:0}).style({stroke:\"grey\",\"pointer-events\":\"none\"});R.on(\"mousemove.angular-guide\",function(t,e){var r=o.util.getMousePos(Y).angle;ht.attr({x2:-x,transform:\"rotate(\"+r+\")\"}).style({opacity:.5});var n=(r+180+360-f.orientation)%360;it=s.invert(n);var i=o.util.convertToCartesian(x+12,r+180);lt.text(o.util.round(it)).move([i[0]+_[0],i[1]+_[1]])}).on(\"mouseout.angular-guide\",function(t,e){ot.select(\"line\").style({opacity:0})})}var ft=ot.select(\"circle\").style({stroke:\"grey\",fill:\"none\"});R.on(\"mousemove.radial-guide\",function(t,e){var n=o.util.getMousePos(Y).radius;ft.attr({r:n}).style({opacity:.5}),at=r.invert(o.util.getMousePos(Y).radius);var i=o.util.convertToCartesian(n,f.radialAxis.orientation);ct.text(o.util.round(at)).move([i[0]+_[0],i[1]+_[1]])}).on(\"mouseout.radial-guide\",function(t,e){ft.style({opacity:0}),ut.hide(),lt.hide(),ct.hide()}),t.selectAll(\".geometry-group .mark\").on(\"mouseover.tooltip\",function(e,r){var i=n.select(this),a=this.style.fill,s=\"black\",l=this.style.opacity||1;if(i.attr({\"data-opacity\":l}),a&&\"none\"!==a){i.attr({\"data-fill\":a}),s=n.hsl(a).darker().toString(),i.style({fill:s,opacity:1});var c={t:o.util.round(e[0]),r:o.util.round(e[1])};T&&(c.t=w[e[0]]);var u=\"t: \"+c.t+\", r: \"+c.r,h=this.getBoundingClientRect(),f=t.node().getBoundingClientRect(),p=[h.left+h.width/2-U[0]-f.left,h.top+h.height/2-U[1]-f.top];ut.config({color:s}).text(u),ut.move(p)}else a=this.style.stroke||\"black\",i.attr({\"data-stroke\":a}),s=n.hsl(a).darker().toString(),i.style({stroke:s,opacity:1})}).on(\"mousemove.tooltip\",function(t,e){if(0!=n.event.which)return!1;n.select(this).attr(\"data-fill\")&&ut.show()}).on(\"mouseout.tooltip\",function(t,e){ut.hide();var r=n.select(this),i=r.attr(\"data-fill\");i?r.style({fill:i,opacity:r.attr(\"data-opacity\")}):r.style({stroke:r.attr(\"data-stroke\"),opacity:r.attr(\"data-opacity\")})})})}(c),this},f.config=function(t){if(!arguments.length)return l;var e=o.util.cloneJson(t);return e.data.forEach(function(t,e){l.data[e]||(l.data[e]={}),i(l.data[e],o.Axis.defaultConfig().data[0]),i(l.data[e],t)}),i(l.layout,o.Axis.defaultConfig().layout),i(l.layout,e.layout),this},f.getLiveConfig=function(){return u},f.getinputConfig=function(){return c},f.radialScale=function(t){return r},f.angularScale=function(t){return s},f.svg=function(){return t},n.rebind(f,h,\"on\"),f},o.Axis.defaultConfig=function(t,e){return{data:[{t:[1,2,3,4],r:[10,11,12,13],name:\"Line1\",geometry:\"LinePlot\",color:null,strokeDash:\"solid\",strokeColor:null,strokeSize:\"1\",visibleInLegend:!0,opacity:1}],layout:{defaultColorRange:n.scale.category10().range(),title:null,height:450,width:500,margin:{top:40,right:40,bottom:40,left:40},font:{size:12,color:\"gray\",outlineColor:\"white\",family:\"Tahoma, sans-serif\"},direction:\"clockwise\",orientation:0,labelOffset:10,radialAxis:{domain:null,orientation:-45,ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null},angularAxis:{domain:[0,360],ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,labelsVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null,ticksCount:null,ticksStep:null},minorTicks:0,tickLength:null,tickColor:\"silver\",minorTickColor:\"#eee\",backgroundColor:\"none\",needsEndSpacing:null,showLegend:!0,legend:{reverseOrder:!1},opacity:1}}},o.util={},o.DATAEXTENT=\"dataExtent\",o.AREA=\"AreaChart\",o.LINE=\"LinePlot\",o.DOT=\"DotPlot\",o.BAR=\"BarChart\",o.util._override=function(t,e){for(var r in t)r in e&&(e[r]=t[r])},o.util._extend=function(t,e){for(var r in t)e[r]=t[r]},o.util._rndSnd=function(){return 2*Math.random()-1+(2*Math.random()-1)+(2*Math.random()-1)},o.util.dataFromEquation2=function(t,e){var r=e||6;return n.range(0,360+r,r).map(function(e,r){var n=e*Math.PI/180;return[e,t(n)]})},o.util.dataFromEquation=function(t,e,r){var i=e||6,a=[],o=[];n.range(0,360+i,i).forEach(function(e,r){var n=e*Math.PI/180,i=t(n);a.push(e),o.push(i)});var s={t:a,r:o};return r&&(s.name=r),s},o.util.ensureArray=function(t,e){if(\"undefined\"==typeof t)return null;var r=[].concat(t);return n.range(e).map(function(t,e){return r[e]||r[0]})},o.util.fillArrays=function(t,e,r){return e.forEach(function(e,n){t[e]=o.util.ensureArray(t[e],r)}),t},o.util.cloneJson=function(t){return JSON.parse(JSON.stringify(t))},o.util.validateKeys=function(t,e){\"string\"==typeof e&&(e=e.split(\".\"));var r=e.shift();return t[r]&&(!e.length||objHasKeys(t[r],e))},o.util.sumArrays=function(t,e){return n.zip(t,e).map(function(t,e){return n.sum(t)})},o.util.arrayLast=function(t){return t[t.length-1]},o.util.arrayEqual=function(t,e){for(var r=Math.max(t.length,e.length,1);r-- >=0&&t[r]===e[r];);return-2===r},o.util.flattenArray=function(t){for(var e=[];!o.util.arrayEqual(e,t);)e=t,t=[].concat.apply([],t);return t},o.util.deduplicate=function(t){return t.filter(function(t,e,r){return r.indexOf(t)==e})},o.util.convertToCartesian=function(t,e){var r=e*Math.PI/180;return[t*Math.cos(r),t*Math.sin(r)]},o.util.round=function(t,e){var r=e||2,n=Math.pow(10,r);return Math.round(t*n)/n},o.util.getMousePos=function(t){var e=n.mouse(t.node()),r=e[0],i=e[1],a={};return a.x=r,a.y=i,a.pos=e,a.angle=180*(Math.atan2(i,r)+Math.PI)/Math.PI,a.radius=Math.sqrt(r*r+i*i),a},o.util.duplicatesCount=function(t){for(var e,r={},n={},i=0,a=t.length;i<a;i++)(e=t[i])in r?(r[e]++,n[e]=r[e]):r[e]=1;return n},o.util.duplicates=function(t){return Object.keys(o.util.duplicatesCount(t))},o.util.translator=function(t,e,r,n){if(n){var i=r.slice();r=e,e=i}var a=e.reduce(function(t,e){if(\"undefined\"!=typeof t)return t[e]},t);\"undefined\"!=typeof a&&(e.reduce(function(t,r,n){if(\"undefined\"!=typeof t)return n===e.length-1&&delete t[r],t[r]},t),r.reduce(function(t,e,n){return\"undefined\"==typeof t[e]&&(t[e]={}),n===r.length-1&&(t[e]=a),t[e]},t))},o.PolyChart=function(){var t=[o.PolyChart.defaultConfig()],e=n.dispatch(\"hover\"),r={solid:\"none\",dash:[5,2],dot:[2,5]};function a(){var e=t[0].geometryConfig,i=e.container;\"string\"==typeof i&&(i=n.select(i)),i.datum(t).each(function(t,i){var a=!!t[0].data.yStack,o=t.map(function(t,e){return a?n.zip(t.data.t[0],t.data.r[0],t.data.yStack[0]):n.zip(t.data.t[0],t.data.r[0])}),s=e.angularScale,l=e.radialScale.domain()[0],c={bar:function(r,i,a){var o=t[a].data,l=e.radialScale(r[1])-e.radialScale(0),c=e.radialScale(r[2]||0),u=o.barWidth;n.select(this).attr({class:\"mark bar\",d:\"M\"+[[l+c,-u/2],[l+c,u/2],[c,u/2],[c,-u/2]].join(\"L\")+\"Z\",transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0]))+\")\"}})}};c.dot=function(r,i,a){var o=r[2]?[r[0],r[1]+r[2]]:r,s=n.svg.symbol().size(t[a].data.dotSize).type(t[a].data.dotType)(r,i);n.select(this).attr({class:\"mark dot\",d:s,transform:function(t,r){var n,i,a,s=(n=function(t,r){var n=e.radialScale(t[1]),i=(e.angularScale(t[0])+e.orientation)*Math.PI/180;return{r:n,t:i}}(o),i=n.r*Math.cos(n.t),a=n.r*Math.sin(n.t),{x:i,y:a});return\"translate(\"+[s.x,s.y]+\")\"}})};var u=n.svg.line.radial().interpolate(t[0].data.lineInterpolation).radius(function(t){return e.radialScale(t[1])}).angle(function(t){return e.angularScale(t[0])*Math.PI/180});c.line=function(r,i,a){var s=r[2]?o[a].map(function(t,e){return[t[0],t[1]+t[2]]}):o[a];if(n.select(this).each(c.dot).style({opacity:function(e,r){return+t[a].data.dotVisible},fill:d.stroke(r,i,a)}).attr({class:\"mark dot\"}),!(i>0)){var l=n.select(this.parentNode).selectAll(\"path.line\").data([0]);l.enter().insert(\"path\"),l.attr({class:\"line\",d:u(s),transform:function(t,r){return\"rotate(\"+(e.orientation+90)+\")\"},\"pointer-events\":\"none\"}).style({fill:function(t,e){return d.fill(r,i,a)},\"fill-opacity\":0,stroke:function(t,e){return d.stroke(r,i,a)},\"stroke-width\":function(t,e){return d[\"stroke-width\"](r,i,a)},\"stroke-dasharray\":function(t,e){return d[\"stroke-dasharray\"](r,i,a)},opacity:function(t,e){return d.opacity(r,i,a)},display:function(t,e){return d.display(r,i,a)}})}};var h=e.angularScale.range(),f=Math.abs(h[1]-h[0])/o[0].length*Math.PI/180,p=n.svg.arc().startAngle(function(t){return-f/2}).endAngle(function(t){return f/2}).innerRadius(function(t){return e.radialScale(l+(t[2]||0))}).outerRadius(function(t){return e.radialScale(l+(t[2]||0))+e.radialScale(t[1])});c.arc=function(t,r,i){n.select(this).attr({class:\"mark arc\",d:p,transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0])+90)+\")\"}})};var d={fill:function(e,r,n){return t[n].data.color},stroke:function(e,r,n){return t[n].data.strokeColor},\"stroke-width\":function(e,r,n){return t[n].data.strokeSize+\"px\"},\"stroke-dasharray\":function(e,n,i){return r[t[i].data.strokeDash]},opacity:function(e,r,n){return t[n].data.opacity},display:function(e,r,n){return\"undefined\"==typeof t[n].data.visible||t[n].data.visible?\"block\":\"none\"}},g=n.select(this).selectAll(\"g.layer\").data(o);g.enter().append(\"g\").attr({class:\"layer\"});var v=g.selectAll(\"path.mark\").data(function(t,e){return t});v.enter().append(\"path\").attr({class:\"mark\"}),v.style(d).each(c[e.geometryType]),v.exit().remove(),g.exit().remove()})}return a.config=function(e){return arguments.length?(e.forEach(function(e,r){t[r]||(t[r]={}),i(t[r],o.PolyChart.defaultConfig()),i(t[r],e)}),this):t},a.getColorScale=function(){},n.rebind(a,e,\"on\"),a},o.PolyChart.defaultConfig=function(){return{data:{name:\"geom1\",t:[[1,2,3,4]],r:[[1,2,3,4]],dotType:\"circle\",dotSize:64,dotVisible:!1,barWidth:20,color:\"#ffa500\",strokeSize:1,strokeColor:\"silver\",strokeDash:\"solid\",opacity:1,index:0,visible:!0,visibleInLegend:!0},geometryConfig:{geometry:\"LinePlot\",geometryType:\"arc\",direction:\"clockwise\",orientation:0,container:\"body\",radialScale:null,angularScale:null,colorScale:n.scale.category20()}}},o.BarChart=function(){return o.PolyChart()},o.BarChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"bar\"}}},o.AreaChart=function(){return o.PolyChart()},o.AreaChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"arc\"}}},o.DotPlot=function(){return o.PolyChart()},o.DotPlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"dot\",dotType:\"circle\"}}},o.LinePlot=function(){return o.PolyChart()},o.LinePlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"line\"}}},o.Legend=function(){var t=o.Legend.defaultConfig(),e=n.dispatch(\"hover\");function r(){var e=t.legendConfig,a=t.data.map(function(t,r){return[].concat(t).map(function(t,n){var a=i({},e.elements[r]);return a.name=t,a.color=[].concat(e.elements[r].color)[n],a})}),o=n.merge(a);o=o.filter(function(t,r){return e.elements[r]&&(e.elements[r].visibleInLegend||\"undefined\"==typeof e.elements[r].visibleInLegend)}),e.reverseOrder&&(o=o.reverse());var s=e.container;(\"string\"==typeof s||s.nodeName)&&(s=n.select(s));var l=o.map(function(t,e){return t.color}),c=e.fontSize,u=null==e.isContinuous?\"number\"==typeof o[0]:e.isContinuous,h=u?e.height:c*o.length,f=s.classed(\"legend-group\",!0).selectAll(\"svg\").data([0]),p=f.enter().append(\"svg\").attr({width:300,height:h+c,xmlns:\"http://www.w3.org/2000/svg\",\"xmlns:xlink\":\"http://www.w3.org/1999/xlink\",version:\"1.1\"});p.append(\"g\").classed(\"legend-axis\",!0),p.append(\"g\").classed(\"legend-marks\",!0);var d=n.range(o.length),g=n.scale[u?\"linear\":\"ordinal\"]().domain(d).range(l),v=n.scale[u?\"linear\":\"ordinal\"]().domain(d)[u?\"range\":\"rangePoints\"]([0,h]);if(u){var m=f.select(\".legend-marks\").append(\"defs\").append(\"linearGradient\").attr({id:\"grad1\",x1:\"0%\",y1:\"0%\",x2:\"0%\",y2:\"100%\"}).selectAll(\"stop\").data(l);m.enter().append(\"stop\"),m.attr({offset:function(t,e){return e/(l.length-1)*100+\"%\"}}).style({\"stop-color\":function(t,e){return t}}),f.append(\"rect\").classed(\"legend-mark\",!0).attr({height:e.height,width:e.colorBandWidth,fill:\"url(#grad1)\"})}else{var y=f.select(\".legend-marks\").selectAll(\"path.legend-mark\").data(o);y.enter().append(\"path\").classed(\"legend-mark\",!0),y.attr({transform:function(t,e){return\"translate(\"+[c/2,v(e)+c/2]+\")\"},d:function(t,e){var r,i,a,o=t.symbol;return a=3*(i=c),\"line\"===(r=o)?\"M\"+[[-i/2,-i/12],[i/2,-i/12],[i/2,i/12],[-i/2,i/12]]+\"Z\":-1!=n.svg.symbolTypes.indexOf(r)?n.svg.symbol().type(r).size(a)():n.svg.symbol().type(\"square\").size(a)()},fill:function(t,e){return g(e)}}),y.exit().remove()}var x=n.svg.axis().scale(v).orient(\"right\"),b=f.select(\"g.legend-axis\").attr({transform:\"translate(\"+[u?e.colorBandWidth:c,c/2]+\")\"}).call(x);return b.selectAll(\".domain\").style({fill:\"none\",stroke:\"none\"}),b.selectAll(\"line\").style({fill:\"none\",stroke:u?e.textColor:\"none\"}),b.selectAll(\"text\").style({fill:e.textColor,\"font-size\":e.fontSize}).text(function(t,e){return o[e].name}),r}return r.config=function(e){return arguments.length?(i(t,e),this):t},n.rebind(r,e,\"on\"),r},o.Legend.defaultConfig=function(t,e){return{data:[\"a\",\"b\",\"c\"],legendConfig:{elements:[{symbol:\"line\",color:\"red\"},{symbol:\"square\",color:\"yellow\"},{symbol:\"diamond\",color:\"limegreen\"}],height:150,colorBandWidth:30,fontSize:12,container:\"body\",isContinuous:null,textColor:\"grey\",reverseOrder:!1}}},o.tooltipPanel=function(){var t,e,r,a={container:null,hasTick:!1,fontSize:12,color:\"white\",padding:5},s=\"tooltip-\"+o.tooltipPanel.uid++,l=10,c=function(){var n=(t=a.container.selectAll(\"g.\"+s).data([0])).enter().append(\"g\").classed(s,!0).style({\"pointer-events\":\"none\",display:\"none\"});return r=n.append(\"path\").style({fill:\"white\",\"fill-opacity\":.9}).attr({d:\"M0 0\"}),e=n.append(\"text\").attr({dx:a.padding+l,dy:.3*+a.fontSize}),c};return c.text=function(i){var o=n.hsl(a.color).l,s=o>=.5?\"#aaa\":\"white\",u=o>=.5?\"black\":\"white\",h=i||\"\";e.style({fill:u,\"font-size\":a.fontSize+\"px\"}).text(h);var f=a.padding,p=e.node().getBBox(),d={fill:a.color,stroke:s,\"stroke-width\":\"2px\"},g=p.width+2*f+l,v=p.height+2*f;return r.attr({d:\"M\"+[[l,-v/2],[l,-v/4],[a.hasTick?0:l,0],[l,v/4],[l,v/2],[g,v/2],[g,-v/2]].join(\"L\")+\"Z\"}).style(d),t.attr({transform:\"translate(\"+[l,-v/2+2*f]+\")\"}),t.style({display:\"block\"}),c},c.move=function(e){if(t)return t.attr({transform:\"translate(\"+[e[0],e[1]]+\")\"}).style({display:\"block\"}),c},c.hide=function(){if(t)return t.style({display:\"none\"}),c},c.show=function(){if(t)return t.style({display:\"block\"}),c},c.config=function(t){return i(a,t),c},c},o.tooltipPanel.uid=1,o.adapter={},o.adapter.plotly=function(){var t={convert:function(t,e){var r={};if(t.data&&(r.data=t.data.map(function(t,r){var n=i({},t);return[[n,[\"marker\",\"color\"],[\"color\"]],[n,[\"marker\",\"opacity\"],[\"opacity\"]],[n,[\"marker\",\"line\",\"color\"],[\"strokeColor\"]],[n,[\"marker\",\"line\",\"dash\"],[\"strokeDash\"]],[n,[\"marker\",\"line\",\"width\"],[\"strokeSize\"]],[n,[\"marker\",\"symbol\"],[\"dotType\"]],[n,[\"marker\",\"size\"],[\"dotSize\"]],[n,[\"marker\",\"barWidth\"],[\"barWidth\"]],[n,[\"line\",\"interpolation\"],[\"lineInterpolation\"]],[n,[\"showlegend\"],[\"visibleInLegend\"]]].forEach(function(t,r){o.util.translator.apply(null,t.concat(e))}),e||delete n.marker,e&&delete n.groupId,e?(\"LinePlot\"===n.geometry?(n.type=\"scatter\",!0===n.dotVisible?(delete n.dotVisible,n.mode=\"lines+markers\"):n.mode=\"lines\"):\"DotPlot\"===n.geometry?(n.type=\"scatter\",n.mode=\"markers\"):\"AreaChart\"===n.geometry?n.type=\"area\":\"BarChart\"===n.geometry&&(n.type=\"bar\"),delete n.geometry):(\"scatter\"===n.type?\"lines\"===n.mode?n.geometry=\"LinePlot\":\"markers\"===n.mode?n.geometry=\"DotPlot\":\"lines+markers\"===n.mode&&(n.geometry=\"LinePlot\",n.dotVisible=!0):\"area\"===n.type?n.geometry=\"AreaChart\":\"bar\"===n.type&&(n.geometry=\"BarChart\"),delete n.mode,delete n.type),n}),!e&&t.layout&&\"stack\"===t.layout.barmode)){var a=o.util.duplicates(r.data.map(function(t,e){return t.geometry}));r.data.forEach(function(t,e){var n=a.indexOf(t.geometry);-1!=n&&(r.data[e].groupId=n)})}if(t.layout){var s=i({},t.layout);if([[s,[\"plot_bgcolor\"],[\"backgroundColor\"]],[s,[\"showlegend\"],[\"showLegend\"]],[s,[\"radialaxis\"],[\"radialAxis\"]],[s,[\"angularaxis\"],[\"angularAxis\"]],[s.angularaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularaxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularaxis,[\"nticks\"],[\"ticksCount\"]],[s.angularaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularaxis,[\"range\"],[\"domain\"]],[s.angularaxis,[\"endpadding\"],[\"endPadding\"]],[s.radialaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialaxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularAxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularAxis,[\"nticks\"],[\"ticksCount\"]],[s.angularAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularAxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"endpadding\"],[\"endPadding\"]],[s.radialAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialAxis,[\"range\"],[\"domain\"]],[s.font,[\"outlinecolor\"],[\"outlineColor\"]],[s.legend,[\"traceorder\"],[\"reverseOrder\"]],[s,[\"labeloffset\"],[\"labelOffset\"]],[s,[\"defaultcolorrange\"],[\"defaultColorRange\"]]].forEach(function(t,r){o.util.translator.apply(null,t.concat(e))}),e?(\"undefined\"!=typeof s.tickLength&&(s.angularaxis.ticklen=s.tickLength,delete s.tickLength),s.tickColor&&(s.angularaxis.tickcolor=s.tickColor,delete s.tickColor)):(s.angularAxis&&\"undefined\"!=typeof s.angularAxis.ticklen&&(s.tickLength=s.angularAxis.ticklen),s.angularAxis&&\"undefined\"!=typeof s.angularAxis.tickcolor&&(s.tickColor=s.angularAxis.tickcolor)),s.legend&&\"boolean\"!=typeof s.legend.reverseOrder&&(s.legend.reverseOrder=\"normal\"!=s.legend.reverseOrder),s.legend&&\"boolean\"==typeof s.legend.traceorder&&(s.legend.traceorder=s.legend.traceorder?\"reversed\":\"normal\",delete s.legend.reverseOrder),s.margin&&\"undefined\"!=typeof s.margin.t){var l=[\"t\",\"r\",\"b\",\"l\",\"pad\"],c=[\"top\",\"right\",\"bottom\",\"left\",\"pad\"],u={};n.entries(s.margin).forEach(function(t,e){u[c[l.indexOf(t.key)]]=t.value}),s.margin=u}e&&(delete s.needsEndSpacing,delete s.minorTickColor,delete s.minorTicks,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksStep,delete s.angularaxis.rewriteTicks,delete s.angularaxis.nticks,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksStep,delete s.radialaxis.rewriteTicks,delete s.radialaxis.nticks),r.layout=s}return r}};return t}},{\"../../../constants/alignment\":688,\"../../../lib\":719,d3:163}],838:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../../lib\"),a=t(\"../../../components/color\"),o=t(\"./micropolar\"),s=t(\"./undo_manager\"),l=i.extendDeepAll,c=e.exports={};c.framework=function(t){var e,r,i,a,u,h=new s;function f(r,s){return s&&(u=s),n.select(n.select(u).node().parentNode).selectAll(\".svg-container>*:not(.chart-root)\").remove(),e=e?l(e,r):r,i||(i=o.Axis()),a=o.adapter.plotly().convert(e),i.config(a).render(u),t.data=e.data,t.layout=e.layout,c.fillLayout(t),e}return f.isPolar=!0,f.svg=function(){return i.svg()},f.getConfig=function(){return e},f.getLiveConfig=function(){return o.adapter.plotly().convert(i.getLiveConfig(),!0)},f.getLiveScales=function(){return{t:i.angularScale(),r:i.radialScale()}},f.setUndoPoint=function(){var t,n,i=this,a=o.util.cloneJson(e);t=a,n=r,h.add({undo:function(){n&&i(n)},redo:function(){i(t)}}),r=o.util.cloneJson(a)},f.undo=function(){h.undo()},f.redo=function(){h.redo()},f},c.fillLayout=function(t){var e=n.select(t).selectAll(\".plot-container\"),r=e.selectAll(\".svg-container\"),i=t.framework&&t.framework.svg&&t.framework.svg(),o={width:800,height:600,paper_bgcolor:a.background,_container:e,_paperdiv:r,_paper:i};t._fullLayout=l(o,t.layout)}},{\"../../../components/color\":593,\"../../../lib\":719,\"./micropolar\":837,\"./undo_manager\":839,d3:163}],839:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=[],r=-1,n=!1;function i(t,e){return t?(n=!0,t[e](),n=!1,this):this}return{add:function(t){return n?this:(e.splice(r+1,e.length-r),e.push(t),r=e.length-1,this)},setCallback:function(e){t=e},undo:function(){var n=e[r];return n?(i(n,\"undo\"),r-=1,t&&t(n.undo),this):this},redo:function(){var n=e[r+1];return n?(i(n,\"redo\"),r+=1,t&&t(n.redo),this):this},clear:function(){e=[],r=-1},hasUndo:function(){return-1!==r},hasRedo:function(){return r<e.length-1},getCommands:function(){return e},getPreviousCommand:function(){return e[r-1]},getIndex:function(){return r}}}},{}],840:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../plots\"),u=t(\"../../plots/cartesian/axes\"),h=t(\"../cartesian/set_convert\"),f=t(\"./set_convert\"),p=t(\"../cartesian/autorange\").doAutoRange,d=t(\"../cartesian/dragbox\"),g=t(\"../../components/dragelement\"),v=t(\"../../components/fx\"),m=t(\"../../components/titles\"),y=t(\"../cartesian/select\").prepSelect,x=t(\"../cartesian/select\").selectOnClick,b=t(\"../cartesian/select\").clearSelect,_=t(\"../../lib/setcursor\"),w=t(\"../../lib/clear_gl_canvases\"),k=t(\"../../plot_api/subroutines\").redrawReglTraces,T=t(\"../../constants/alignment\").MID_SHIFT,A=t(\"./constants\"),M=t(\"./helpers\"),S=o._,E=o.mod,C=o.deg2rad,L=o.rad2deg;function P(t,e){this.id=e,this.gd=t,this._hasClipOnAxisFalse=null,this.vangles=null,this.radialAxisAngle=null,this.traceHash={},this.layers={},this.clipPaths={},this.clipIds={},this.viewInitial={};var r=t._fullLayout,n=\"clip\"+r._uid+e;this.clipIds.forTraces=n+\"-for-traces\",this.clipPaths.forTraces=r._clips.append(\"clipPath\").attr(\"id\",this.clipIds.forTraces),this.clipPaths.forTraces.append(\"path\"),this.framework=r._polarlayer.append(\"g\").attr(\"class\",e),this.radialTickLayout=null,this.angularTickLayout=null}var O=P.prototype;function z(t){var e=t.ticks+String(t.ticklen)+String(t.showticklabels);return\"side\"in t&&(e+=t.side),e}function I(t,e){return e[o.findIndexOfMin(e,function(e){return o.angleDist(t,e)})]}function D(t,e,r){return e?(t.attr(\"display\",null),t.attr(r)):t&&t.attr(\"display\",\"none\"),t}function R(t,e){return\"translate(\"+t+\",\"+e+\")\"}function F(t){return\"rotate(\"+t+\")\"}e.exports=function(t,e){return new P(t,e)},O.plot=function(t,e){var r=e[this.id];this._hasClipOnAxisFalse=!1;for(var n=0;n<t.length;n++){if(!1===t[n][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(e,r),this.updateLayout(e,r),c.generalUpdatePerTraceModule(this.gd,this,t,r),this.updateFx(e,r)},O.updateLayers=function(t,e){var r=this.layers,i=e.radialaxis,a=e.angularaxis,o=A.layerNames,s=o.indexOf(\"frontplot\"),l=o.slice(0,s),c=\"below traces\"===a.layer,u=\"below traces\"===i.layer;c&&l.push(\"angular-line\"),u&&l.push(\"radial-line\"),c&&l.push(\"angular-axis\"),u&&l.push(\"radial-axis\"),l.push(\"frontplot\"),c||l.push(\"angular-line\"),u||l.push(\"radial-line\"),c||l.push(\"angular-axis\"),u||l.push(\"radial-axis\");var h=this.framework.selectAll(\".polarsublayer\").data(l,String);h.enter().append(\"g\").attr(\"class\",function(t){return\"polarsublayer \"+t}).each(function(t){var e=r[t]=n.select(this);switch(t){case\"frontplot\":e.append(\"g\").classed(\"barlayer\",!0),e.append(\"g\").classed(\"scatterlayer\",!0);break;case\"backplot\":e.append(\"g\").classed(\"maplayer\",!0);break;case\"plotbg\":r.bg=e.append(\"path\");break;case\"radial-grid\":case\"angular-grid\":e.style(\"fill\",\"none\");break;case\"radial-line\":e.append(\"line\").style(\"fill\",\"none\");break;case\"angular-line\":e.append(\"path\").style(\"fill\",\"none\")}}),h.order()},O.updateLayout=function(t,e){var r=this.layers,n=t._size,i=e.radialaxis,a=e.angularaxis,o=e.domain.x,c=e.domain.y;this.xOffset=n.l+n.w*o[0],this.yOffset=n.t+n.h*(1-c[1]);var u=this.xLength=n.w*(o[1]-o[0]),h=this.yLength=n.h*(c[1]-c[0]),f=e.sector;this.sectorInRad=f.map(C);var p,d,g,v,m,y=this.sectorBBox=function(t){var e,r,n,i,a=t[0],o=t[1]-a,s=E(a,360),l=s+o,c=Math.cos(C(s)),u=Math.sin(C(s)),h=Math.cos(C(l)),f=Math.sin(C(l));i=s<=90&&l>=90||s>90&&l>=450?1:u<=0&&f<=0?0:Math.max(u,f);e=s<=180&&l>=180||s>180&&l>=540?-1:c>=0&&h>=0?0:Math.min(c,h);r=s<=270&&l>=270||s>270&&l>=630?-1:u>=0&&f>=0?0:Math.min(u,f);n=l>=360?1:c<=0&&h<=0?0:Math.max(c,h);return[e,r,n,i]}(f),x=y[2]-y[0],b=y[3]-y[1],_=h/u,w=Math.abs(b/x);_>w?(p=u,m=(h-(d=u*w))/n.h/2,g=[o[0],o[1]],v=[c[0]+m,c[1]-m]):(d=h,m=(u-(p=h/w))/n.w/2,g=[o[0]+m,o[1]-m],v=[c[0],c[1]]),this.xLength2=p,this.yLength2=d,this.xDomain2=g,this.yDomain2=v;var k=this.xOffset2=n.l+n.w*g[0],T=this.yOffset2=n.t+n.h*(1-v[1]),A=this.radius=p/x,M=this.innerRadius=e.hole*A,S=this.cx=k-A*y[0],L=this.cy=T+A*y[3],P=this.cxx=S-k,O=this.cyy=L-T;this.radialAxis=this.mockAxis(t,e,i,{_id:\"x\",side:{counterclockwise:\"top\",clockwise:\"bottom\"}[i.side],domain:[M/n.w,A/n.w]}),this.angularAxis=this.mockAxis(t,e,a,{side:\"right\",domain:[0,Math.PI],autorange:!1}),this.doAutoRange(t,e),this.updateAngularAxis(t,e),this.updateRadialAxis(t,e),this.updateRadialAxisTitle(t,e),this.xaxis=this.mockCartesianAxis(t,e,{_id:\"x\",domain:g}),this.yaxis=this.mockCartesianAxis(t,e,{_id:\"y\",domain:v});var z=this.pathSubplot();this.clipPaths.forTraces.select(\"path\").attr(\"d\",z).attr(\"transform\",R(P,O)),r.frontplot.attr(\"transform\",R(k,T)).call(l.setClipUrl,this._hasClipOnAxisFalse?null:this.clipIds.forTraces,this.gd),r.bg.attr(\"d\",z).attr(\"transform\",R(S,L)).call(s.fill,e.bgcolor)},O.mockAxis=function(t,e,r,n){var i=o.extendFlat({anchor:\"free\",position:0},r,n);return f(i,e,t),i},O.mockCartesianAxis=function(t,e,r){var n=this,i=r._id,a=o.extendFlat({type:\"linear\"},r);h(a,t);var s={x:[0,2],y:[1,3]};return a.setRange=function(){var t=n.sectorBBox,r=s[i],o=n.radialAxis._rl,l=(o[1]-o[0])/(1-e.hole);a.range=[t[r[0]]*l,t[r[1]]*l]},a.isPtWithinRange=\"x\"===i?function(t){return n.isPtInside(t)}:function(){return!0},a.setRange(),a.setScale(),a},O.doAutoRange=function(t,e){var r=this.gd,n=this.radialAxis,i=e.radialaxis;n.setScale(),p(r,n);var a=n.range;i.range=a.slice(),i._input.range=a.slice(),n._rl=[n.r2l(a[0],null,\"gregorian\"),n.r2l(a[1],null,\"gregorian\")]},O.updateRadialAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,l=r.innerRadius,c=r.cx,h=r.cy,f=e.radialaxis,p=E(e.sector[0],360),d=r.radialAxis,g=l<a;r.fillViewInitialKey(\"radialaxis.angle\",f.angle),r.fillViewInitialKey(\"radialaxis.range\",d.range.slice()),d.setGeometry(),\"auto\"===d.tickangle&&p>90&&p<=270&&(d.tickangle=180);var v=function(t){return\"translate(\"+(d.l2p(t.x)+l)+\",0)\"},m=z(f);if(r.radialTickLayout!==m&&(i[\"radial-axis\"].selectAll(\".xtick\").remove(),r.radialTickLayout=m),g){d.setScale();var y=u.calcTicks(d),x=u.clipEnds(d,y),b=u.getTickSigns(d)[2];u.drawTicks(n,d,{vals:y,layer:i[\"radial-axis\"],path:u.makeTickPath(d,0,b),transFn:v,crisp:!1}),u.drawGrid(n,d,{vals:x,layer:i[\"radial-grid\"],path:function(t){return r.pathArc(d.r2p(t.x)+l)},transFn:o.noop,crisp:!1}),u.drawLabels(n,d,{vals:y,layer:i[\"radial-axis\"],transFn:v,labelFns:u.makeLabelFns(d,0)})}var _=r.radialAxisAngle=r.vangles?L(I(C(f.angle),r.vangles)):f.angle,w=R(c,h),k=w+F(-_);D(i[\"radial-axis\"],g&&(f.showticklabels||f.ticks),{transform:k}),D(i[\"radial-grid\"],g&&f.showgrid,{transform:w}),D(i[\"radial-line\"].select(\"line\"),g&&f.showline,{x1:l,y1:0,x2:a,y2:0,transform:k}).attr(\"stroke-width\",f.linewidth).call(s.stroke,f.linecolor)},O.updateRadialAxisTitle=function(t,e,r){var n=this.gd,i=this.radius,a=this.cx,o=this.cy,s=e.radialaxis,c=this.id+\"title\",u=void 0!==r?r:this.radialAxisAngle,h=C(u),f=Math.cos(h),p=Math.sin(h),d=0;if(s.title){var g=l.bBox(this.layers[\"radial-axis\"].node()).height,v=s.title.font.size;d=\"counterclockwise\"===s.side?-g-.4*v:g+.8*v}this.layers[\"radial-axis-title\"]=m.draw(n,c,{propContainer:s,propName:this.id+\".radialaxis.title\",placeholder:S(n,\"Click to enter radial axis title\"),attributes:{x:a+i/2*f+d*p,y:o-i/2*p+d*f,\"text-anchor\":\"middle\"},transform:{rotate:-u}})},O.updateAngularAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,l=r.innerRadius,c=r.cx,h=r.cy,f=e.angularaxis,p=r.angularAxis;r.fillViewInitialKey(\"angularaxis.rotation\",f.rotation),p.setGeometry(),p.setScale();var d=function(t){return p.t2g(t.x)};\"linear\"===p.type&&\"radians\"===p.thetaunit&&(p.tick0=L(p.tick0),p.dtick=L(p.dtick));var g=function(t){return R(c+a*Math.cos(t),h-a*Math.sin(t))},v=u.makeLabelFns(p,0).labelStandoff,m={xFn:function(t){var e=d(t);return Math.cos(e)*v},yFn:function(t){var e=d(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(v+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*T)},anchorFn:function(t){var e=d(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},heightFn:function(t,e,r){var n=d(t);return-.5*(1+Math.sin(n))*r}},y=z(f);r.angularTickLayout!==y&&(i[\"angular-axis\"].selectAll(\".\"+p._id+\"tick\").remove(),r.angularTickLayout=y);var x,b=u.calcTicks(p);if(\"linear\"===e.gridshape?(x=b.map(d),o.angleDelta(x[0],x[1])<0&&(x=x.slice().reverse())):x=null,r.vangles=x,\"category\"===p.type&&(b=b.filter(function(t){return o.isAngleInsideSector(d(t),r.sectorInRad)})),p.visible){var _=\"inside\"===p.ticks?-1:1,w=(p.linewidth||1)/2;u.drawTicks(n,p,{vals:b,layer:i[\"angular-axis\"],path:\"M\"+_*w+\",0h\"+_*p.ticklen,transFn:function(t){var e=d(t);return g(e)+F(-L(e))},crisp:!1}),u.drawGrid(n,p,{vals:b,layer:i[\"angular-grid\"],path:function(t){var e=d(t),r=Math.cos(e),n=Math.sin(e);return\"M\"+[c+l*r,h-l*n]+\"L\"+[c+a*r,h-a*n]},transFn:o.noop,crisp:!1}),u.drawLabels(n,p,{vals:b,layer:i[\"angular-axis\"],repositionOnUpdate:!0,transFn:function(t){return g(d(t))},labelFns:m})}D(i[\"angular-line\"].select(\"path\"),f.showline,{d:r.pathSubplot(),transform:R(c,h)}).attr(\"stroke-width\",f.linewidth).call(s.stroke,f.linecolor)},O.updateFx=function(t,e){this.gd._context.staticPlot||(this.updateAngularDrag(t),this.updateRadialDrag(t,e,0),this.updateRadialDrag(t,e,1),this.updateMainDrag(t))},O.updateMainDrag=function(t){var e=this,r=e.gd,o=e.layers,s=t._zoomlayer,l=A.MINZOOM,c=A.OFFEDGE,u=e.radius,h=e.innerRadius,f=e.cx,p=e.cy,m=e.cxx,_=e.cyy,w=e.sectorInRad,k=e.vangles,T=e.radialAxis,S=M.clampTiny,E=M.findXYatLength,C=M.findEnclosingVertexAngles,L=A.cornerHalfWidth,P=A.cornerLen/2,O=d.makeDragger(o,\"path\",\"maindrag\",\"crosshair\");n.select(O).attr(\"d\",e.pathSubplot()).attr(\"transform\",R(f,p));var z,I,D,F,B,N,j,U,V,q={element:O,gd:r,subplot:e.id,plotinfo:{id:e.id,xaxis:e.xaxis,yaxis:e.yaxis},xaxes:[e.xaxis],yaxes:[e.yaxis]};function H(t,e){return Math.sqrt(t*t+e*e)}function G(t,e){return H(t-m,e-_)}function Y(t,e){return Math.atan2(_-e,t-m)}function W(t,e){return[t*Math.cos(e),t*Math.sin(-e)]}function X(t,r){if(0===t)return e.pathSector(2*L);var n=P/t,i=r-n,a=r+n,o=Math.max(0,Math.min(t,u)),s=o-L,l=o+L;return\"M\"+W(s,i)+\"A\"+[s,s]+\" 0,0,0 \"+W(s,a)+\"L\"+W(l,a)+\"A\"+[l,l]+\" 0,0,1 \"+W(l,i)+\"Z\"}function Z(t,r,n){if(0===t)return e.pathSector(2*L);var i,a,o=W(t,r),s=W(t,n),l=S((o[0]+s[0])/2),c=S((o[1]+s[1])/2);if(l&&c){var u=c/l,h=-1/u,f=E(L,u,l,c);i=E(P,h,f[0][0],f[0][1]),a=E(P,h,f[1][0],f[1][1])}else{var p,d;c?(p=P,d=L):(p=L,d=P),i=[[l-p,c-d],[l+p,c-d]],a=[[l-p,c+d],[l+p,c+d]]}return\"M\"+i.join(\"L\")+\"L\"+a.reverse().join(\"L\")+\"Z\"}function J(t,e){return e=Math.max(Math.min(e,u),h),t<c?t=0:u-t<c?t=u:e<c?e=0:u-e<c&&(e=u),Math.abs(e-t)>l?(t<e?(D=t,F=e):(D=e,F=t),!0):(D=null,F=null,!1)}function K(t,e){t=t||B,e=e||\"M0,0Z\",U.attr(\"d\",t),V.attr(\"d\",e),d.transitionZoombox(U,V,N,j),N=!0;var n={};rt(n),r.emit(\"plotly_relayouting\",n)}function $(t,r){var n,i,a=z+t,o=I+r,s=G(z,I),l=Math.min(G(a,o),u),c=Y(z,I);J(s,l)&&(n=B+e.pathSector(F),D&&(n+=e.pathSector(D)),i=X(D,c)+X(F,c)),K(n,i)}function Q(t,e,r,n){var i=M.findIntersectionXY(r,n,r,[t-m,_-e]);return H(i[0],i[1])}function tt(t,r){var n,i,a=z+t,o=I+r,s=Y(z,I),l=Y(a,o),c=C(s,k),h=C(l,k);J(Q(z,I,c[0],c[1]),Math.min(Q(a,o,h[0],h[1]),u))&&(n=B+e.pathSector(F),D&&(n+=e.pathSector(D)),i=[Z(D,c[0],c[1]),Z(F,c[0],c[1])].join(\" \")),K(n,i)}function et(){if(d.removeZoombox(r),null!==D&&null!==F){var t={};rt(t),d.showDoubleClickNotifier(r),a.call(\"_guiRelayout\",r,t)}}function rt(t){var r=T._rl,n=(r[1]-r[0])/(1-h/u)/u,i=[r[0]+(D-h)*n,r[0]+(F-h)*n];t[e.id+\".radialaxis.range\"]=i}function nt(t,n){var i=r._fullLayout.clickmode;if(d.removeZoombox(r),2===t){var o={};for(var s in e.viewInitial)o[e.id+\".\"+s]=e.viewInitial[s];r.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",r,o)}i.indexOf(\"select\")>-1&&1===t&&x(n,r,[e.xaxis],[e.yaxis],e.id,q),i.indexOf(\"event\")>-1&&v.click(r,n,e.id)}q.prepFn=function(t,n,a){var o=r._fullLayout.dragmode,l=O.getBoundingClientRect();if(z=n-l.left,I=a-l.top,k){var c=M.findPolygonOffset(u,w[0],w[1],k);z+=m+c[0],I+=_+c[1]}switch(o){case\"zoom\":q.moveFn=k?tt:$,q.clickFn=nt,q.doneFn=et,function(){D=null,F=null,B=e.pathSubplot(),N=!1;var t=r._fullLayout[e.id];j=i(t.bgcolor).getLuminance(),(U=d.makeZoombox(s,j,f,p,B)).attr(\"fill-rule\",\"evenodd\"),V=d.makeCorners(s,f,p),b(r)}();break;case\"select\":case\"lasso\":y(t,n,a,q,o)}},O.onmousemove=function(t){v.hover(r,t,e.id),r._fullLayout._lasthover=O,r._fullLayout._hoversubplot=e.id},O.onmouseout=function(t){r._dragging||g.unhover(r,t)},g.init(q)},O.updateRadialDrag=function(t,e,r){var i=this,s=i.gd,l=i.layers,c=i.radius,u=i.innerRadius,h=i.cx,f=i.cy,p=i.radialAxis,v=A.radialDragBoxSize,m=v/2;if(p.visible){var y,x,_,T=C(i.radialAxisAngle),M=p._rl,S=M[0],E=M[1],P=M[r],O=.75*(M[1]-M[0])/(1-e.hole)/c;r?(y=h+(c+m)*Math.cos(T),x=f-(c+m)*Math.sin(T),_=\"radialdrag\"):(y=h+(u-m)*Math.cos(T),x=f-(u-m)*Math.sin(T),_=\"radialdrag-inner\");var z,B,N,j=d.makeRectDragger(l,_,\"crosshair\",-m,-m,v,v),U={element:j,gd:s};D(n.select(j),p.visible&&u<c,{transform:R(y,x)}),U.prepFn=function(){z=null,B=null,N=null,U.moveFn=V,U.doneFn=q,b(s)},U.clampFn=function(t,e){return Math.sqrt(t*t+e*e)<A.MINDRAG&&(t=0,e=0),[t,e]},g.init(U)}function V(t,e){if(z)z(t,e);else{var n=[t,-e],a=[Math.cos(T),Math.sin(T)],l=Math.abs(o.dot(n,a)/Math.sqrt(o.dot(n,n)));isNaN(l)||(z=l<.5?H:G)}var c={};!function(t){null!==B?t[i.id+\".radialaxis.angle\"]=B:null!==N&&(t[i.id+\".radialaxis.range[\"+r+\"]\"]=N)}(c),s.emit(\"plotly_relayouting\",c)}function q(){null!==B?a.call(\"_guiRelayout\",s,i.id+\".radialaxis.angle\",B):null!==N&&a.call(\"_guiRelayout\",s,i.id+\".radialaxis.range[\"+r+\"]\",N)}function H(t,e){if(0!==r){var n=y+t,a=x+e;B=Math.atan2(f-a,n-h),i.vangles&&(B=I(B,i.vangles)),B=L(B);var o=R(h,f)+F(-B);l[\"radial-axis\"].attr(\"transform\",o),l[\"radial-line\"].select(\"line\").attr(\"transform\",o);var s=i.gd._fullLayout,c=s[i.id];i.updateRadialAxisTitle(s,c,B)}}function G(t,e){var n=o.dot([t,-e],[Math.cos(T),Math.sin(T)]);if(N=P-O*n,O>0==(r?N>S:N<E)){var l=s._fullLayout,c=l[i.id];p.range[r]=N,p._rl[r]=N,i.updateRadialAxis(l,c),i.xaxis.setRange(),i.xaxis.setScale(),i.yaxis.setRange(),i.yaxis.setScale();var u=!1;for(var h in i.traceHash){var f=i.traceHash[h],d=o.filterVisible(f);f[0][0].trace._module.plot(s,i,d,c),a.traceIs(h,\"gl\")&&d.length&&(u=!0)}u&&(w(s),k(s))}else N=null}},O.updateAngularDrag=function(t){var e=this,r=e.gd,i=e.layers,s=e.radius,c=e.angularAxis,u=e.cx,h=e.cy,f=e.cxx,p=e.cyy,v=A.angularDragBoxSize,m=d.makeDragger(i,\"path\",\"angulardrag\",\"move\"),y={element:m,gd:r};function x(t,e){return Math.atan2(p+v-e,t-f-v)}n.select(m).attr(\"d\",e.pathAnnulus(s,s+v)).attr(\"transform\",R(u,h)).call(_,\"move\");var T,M,S,E,C,P,O=i.frontplot.select(\".scatterlayer\").selectAll(\".trace\"),z=O.selectAll(\".point\"),I=O.selectAll(\".textpoint\");function D(t,s){var d=e.gd._fullLayout,g=d[e.id],v=x(T+t,M+s),m=L(v-P);if(E=S+m,i.frontplot.attr(\"transform\",R(e.xOffset2,e.yOffset2)+F([-m,f,p])),e.vangles){C=e.radialAxisAngle+m;var y=R(u,h)+F(-m),b=R(u,h)+F(-C);i.bg.attr(\"transform\",y),i[\"radial-grid\"].attr(\"transform\",y),i[\"radial-axis\"].attr(\"transform\",b),i[\"radial-line\"].select(\"line\").attr(\"transform\",b),e.updateRadialAxisTitle(d,g,C)}else e.clipPaths.forTraces.select(\"path\").attr(\"transform\",R(f,p)+F(m));z.each(function(){var t=n.select(this),e=l.getTranslate(t);t.attr(\"transform\",R(e.x,e.y)+F([m]))}),I.each(function(){var t=n.select(this),e=t.select(\"text\"),r=l.getTranslate(t);t.attr(\"transform\",F([m,e.attr(\"x\"),e.attr(\"y\")])+R(r.x,r.y))}),c.rotation=o.modHalf(E,360),e.updateAngularAxis(d,g),e._hasClipOnAxisFalse&&!o.isFullCircle(e.sectorInRad)&&O.call(l.hideOutsideRangePoints,e);var _=!1;for(var A in e.traceHash)if(a.traceIs(A,\"gl\")){var D=e.traceHash[A],N=o.filterVisible(D);D[0][0].trace._module.plot(r,e,N,g),N.length&&(_=!0)}_&&(w(r),k(r));var j={};B(j),r.emit(\"plotly_relayouting\",j)}function B(t){t[e.id+\".angularaxis.rotation\"]=E,e.vangles&&(t[e.id+\".radialaxis.angle\"]=C)}function N(){I.select(\"text\").attr(\"transform\",null);var t={};B(t),a.call(\"_guiRelayout\",r,t)}y.prepFn=function(n,i,a){var o=t[e.id];S=o.angularaxis.rotation;var s=m.getBoundingClientRect();T=i-s.left,M=a-s.top,P=x(T,M),y.moveFn=D,y.doneFn=N,b(r)},e.vangles&&!o.isFullCircle(e.sectorInRad)&&(y.prepFn=o.noop,_(n.select(m),null)),g.init(y)},O.isPtInside=function(t){var e=this.sectorInRad,r=this.vangles,n=this.angularAxis.c2g(t.theta),i=this.radialAxis,a=i.c2l(t.r),s=i._rl;return(r?M.isPtInsidePolygon:o.isPtInsideSector)(a,n,s,e,r)},O.pathArc=function(t){var e=this.sectorInRad,r=this.vangles;return(r?M.pathPolygon:o.pathArc)(t,e[0],e[1],r)},O.pathSector=function(t){var e=this.sectorInRad,r=this.vangles;return(r?M.pathPolygon:o.pathSector)(t,e[0],e[1],r)},O.pathAnnulus=function(t,e){var r=this.sectorInRad,n=this.vangles;return(n?M.pathPolygonAnnulus:o.pathAnnulus)(t,e,r[0],r[1],n)},O.pathSubplot=function(){var t=this.innerRadius,e=this.radius;return t?this.pathAnnulus(t,e):this.pathSector(e)},O.fillViewInitialKey=function(t,e){t in this.viewInitial||(this.viewInitial[t]=e)}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../components/titles\":681,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/clear_gl_canvases\":704,\"../../lib/setcursor\":739,\"../../plot_api/subroutines\":758,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../cartesian/autorange\":766,\"../cartesian/dragbox\":775,\"../cartesian/select\":784,\"../cartesian/set_convert\":785,\"../plots\":828,\"./constants\":829,\"./helpers\":830,\"./set_convert\":841,d3:163,tinycolor2:537}],841:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../cartesian/set_convert\"),a=n.deg2rad,o=n.rad2deg;e.exports=function(t,e,r){switch(i(t,r),t._id){case\"x\":case\"radialaxis\":!function(t,e){var r=e._subplot;t.setGeometry=function(){var e=t._rl[0],n=t._rl[1],i=r.innerRadius,a=(r.radius-i)/(n-e),o=i/a,s=e>n?function(t){return t<=0}:function(t){return t>=0};t.c2g=function(r){var n=t.c2l(r)-e;return(s(n)?n:0)+o},t.g2c=function(r){return t.l2c(r+e-o)},t.g2p=function(t){return t*a},t.c2p=function(e){return t.g2p(t.c2g(e))}}}(t,e);break;case\"angularaxis\":!function(t,e){var r=t.type;if(\"linear\"===r){var i=t.d2c,s=t.c2d;t.d2c=function(t,e){return function(t,e){return\"degrees\"===e?a(t):t}(i(t),e)},t.c2d=function(t,e){return s(function(t,e){return\"degrees\"===e?o(t):t}(t,e))}}t.makeCalcdata=function(e,i){var a,o,s=e[i],l=e._length,c=function(r){return t.d2c(r,e.thetaunit)};if(s){if(n.isTypedArray(s)&&\"linear\"===r){if(l===s.length)return s;if(s.subarray)return s.subarray(0,l)}for(a=new Array(l),o=0;o<l;o++)a[o]=c(s[o])}else{var u=i+\"0\",h=\"d\"+i,f=u in e?c(e[u]):0,p=e[h]?c(e[h]):(t.period||2*Math.PI)/l;for(a=new Array(l),o=0;o<l;o++)a[o]=f+o*p}return a},t.setGeometry=function(){var i,s,l,c,u=e.sector,h=u.map(a),f={clockwise:-1,counterclockwise:1}[t.direction],p=a(t.rotation),d=function(t){return f*t+p},g=function(t){return(t-p)/f};switch(r){case\"linear\":s=i=n.identity,c=a,l=o,t.range=n.isFullCircle(h)?[u[0],u[0]+360]:h.map(g).map(o);break;case\"category\":var v=t._categories.length,m=t.period?Math.max(t.period,v):v;0===m&&(m=1),s=c=function(t){return 2*t*Math.PI/m},i=l=function(t){return t*m/Math.PI/2},t.range=[0,m]}t.c2g=function(t){return d(s(t))},t.g2c=function(t){return i(g(t))},t.t2g=function(t){return d(c(t))},t.g2t=function(t){return l(g(t))}}}(t,e)}}},{\"../../lib\":719,\"../cartesian/set_convert\":785}],842:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\"),a=t(\"./domain\").defaults;e.exports=function(t,e,r,o){var s,l,c=o.type,u=o.attributes,h=o.handleDefaults,f=o.partition||\"x\",p=e._subplots[c],d=p.length,g=d&&p[0].replace(/\\d+$/,\"\");function v(t,e){return n.coerce(s,l,u,t,e)}for(var m=0;m<d;m++){var y=p[m];s=t[y]?t[y]:t[y]={},l=i.newContainer(e,y,g),v(\"uirevision\",e.uirevision);var x={};x[f]=[m/d,(m+1)/d],a(l,e,v,x),o.id=y,h(s,l,v,o)}}},{\"../lib\":719,\"../plot_api/plot_template\":757,\"./domain\":792}],843:[function(t,e,r){\"use strict\";var n=t(\"./ternary\"),i=t(\"../../plots/get_data\").getSubplotCalcData,a=t(\"../../lib\").counterRegex;r.name=\"ternary\";var o=r.attr=\"subplot\";r.idRoot=\"ternary\",r.idRegex=r.attrRegex=a(\"ternary\"),(r.attributes={})[o]={valType:\"subplotid\",dflt:\"ternary\",editType:\"calc\"},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t.calcdata,a=e._subplots.ternary,o=0;o<a.length;o++){var s=a[o],l=i(r,\"ternary\",s),c=e[s]._subplot;c||(c=new n({id:s,graphDiv:t,container:e._ternarylayer.node()},e),e[s]._subplot=c),c.plot(l,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.ternary||[],a=0;a<i.length;a++){var o=i[a],s=n[o]._subplot;!e[o]&&s&&(s.plotContainer.remove(),s.clipDef.remove(),s.clipDefRelative.remove(),s.layers[\"a-title\"].remove(),s.layers[\"b-title\"].remove(),s.layers[\"c-title\"].remove())}}},{\"../../lib\":719,\"../../plots/get_data\":802,\"./layout_attributes\":844,\"./layout_defaults\":845,\"./ternary\":846}],844:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"../cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../lib/extend\").extendFlat,l={title:a.title,color:a.color,tickmode:a.tickmode,nticks:s({},a.nticks,{dflt:6,min:1}),tick0:a.tick0,dtick:a.dtick,tickvals:a.tickvals,ticktext:a.ticktext,ticks:a.ticks,ticklen:a.ticklen,tickwidth:a.tickwidth,tickcolor:a.tickcolor,showticklabels:a.showticklabels,showtickprefix:a.showtickprefix,tickprefix:a.tickprefix,showticksuffix:a.showticksuffix,ticksuffix:a.ticksuffix,showexponent:a.showexponent,exponentformat:a.exponentformat,separatethousands:a.separatethousands,tickfont:a.tickfont,tickangle:a.tickangle,tickformat:a.tickformat,tickformatstops:a.tickformatstops,hoverformat:a.hoverformat,showline:s({},a.showline,{dflt:!0}),linecolor:a.linecolor,linewidth:a.linewidth,showgrid:s({},a.showgrid,{dflt:!0}),gridcolor:a.gridcolor,gridwidth:a.gridwidth,layer:a.layer,min:{valType:\"number\",dflt:0,min:0},_deprecated:{title:a._deprecated.title,titlefont:a._deprecated.titlefont}},c=e.exports=o({domain:i({name:\"ternary\"}),bgcolor:{valType:\"color\",dflt:n.background},sum:{valType:\"number\",dflt:1,min:0},aaxis:l,baxis:l,caxis:l},\"plot\",\"from-root\");c.uirevision={valType:\"any\",editType:\"none\"},c.aaxis.uirevision=c.baxis.uirevision=c.caxis.uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":592,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../cartesian/layout_attributes\":779,\"../domain\":792}],845:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../lib\"),o=t(\"../subplot_defaults\"),s=t(\"../cartesian/tick_label_defaults\"),l=t(\"../cartesian/tick_mark_defaults\"),c=t(\"../cartesian/tick_value_defaults\"),u=t(\"../cartesian/line_grid_defaults\"),h=t(\"./layout_attributes\"),f=[\"aaxis\",\"baxis\",\"caxis\"];function p(t,e,r,a){var o,s,l,c=r(\"bgcolor\"),u=r(\"sum\");a.bgColor=n.combine(c,a.paper_bgcolor);for(var h=0;h<f.length;h++)s=t[o=f[h]]||{},(l=i.newContainer(e,o))._name=o,d(s,l,a,e);var p=e.aaxis,g=e.baxis,v=e.caxis;p.min+g.min+v.min>=u&&(p.min=0,g.min=0,v.min=0,t.aaxis&&delete t.aaxis.min,t.baxis&&delete t.baxis.min,t.caxis&&delete t.caxis.min)}function d(t,e,r,n){var i=h[e._name];function o(r,n){return a.coerce(t,e,i,r,n)}o(\"uirevision\",n.uirevision),e.type=\"linear\";var f=o(\"color\"),p=f!==i.color.dflt?f:r.font.color,d=e._name.charAt(0).toUpperCase(),g=\"Component \"+d,v=o(\"title.text\",g);e._hovertitle=v===g?v:d,a.coerceFont(o,\"title.font\",{family:r.font.family,size:Math.round(1.2*r.font.size),color:p}),o(\"min\"),c(t,e,o,\"linear\"),s(t,e,o,\"linear\",{}),l(t,e,o,{outerTicks:!0}),o(\"showticklabels\")&&(a.coerceFont(o,\"tickfont\",{family:r.font.family,size:r.font.size,color:p}),o(\"tickangle\"),o(\"tickformat\")),u(t,e,o,{dfltColor:f,bgColor:r.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:i}),o(\"hoverformat\"),o(\"layer\")}e.exports=function(t,e,r){o(t,e,r,{type:\"ternary\",attributes:h,handleDefaults:p,font:e.font,paper_bgcolor:e.paper_bgcolor})}},{\"../../components/color\":593,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../cartesian/line_grid_defaults\":781,\"../cartesian/tick_label_defaults\":786,\"../cartesian/tick_mark_defaults\":787,\"../cartesian/tick_value_defaults\":788,\"../subplot_defaults\":842,\"./layout_attributes\":844}],846:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=o._,l=t(\"../../components/color\"),c=t(\"../../components/drawing\"),u=t(\"../cartesian/set_convert\"),h=t(\"../../lib/extend\").extendFlat,f=t(\"../plots\"),p=t(\"../cartesian/axes\"),d=t(\"../../components/dragelement\"),g=t(\"../../components/fx\"),v=t(\"../../components/titles\"),m=t(\"../cartesian/select\").prepSelect,y=t(\"../cartesian/select\").selectOnClick,x=t(\"../cartesian/select\").clearSelect,b=t(\"../cartesian/constants\");function _(t,e){this.id=t.id,this.graphDiv=t.graphDiv,this.init(e),this.makeFramework(e),this.aTickLayout=null,this.bTickLayout=null,this.cTickLayout=null}e.exports=_;var w=_.prototype;w.init=function(t){this.container=t._ternarylayer,this.defs=t._defs,this.layoutId=t._uid,this.traceHash={},this.layers={}},w.plot=function(t,e){var r=e[this.id],n=e._size;this._hasClipOnAxisFalse=!1;for(var i=0;i<t.length;i++){if(!1===t[i][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(r),this.adjustLayout(r,n),f.generalUpdatePerTraceModule(this.graphDiv,this,t,r),this.layers.plotbg.select(\"path\").call(l.fill,r.bgcolor)},w.makeFramework=function(t){var e=this.graphDiv,r=t[this.id],n=this.clipId=\"clip\"+this.layoutId+this.id,i=this.clipIdRelative=\"clip-relative\"+this.layoutId+this.id;this.clipDef=o.ensureSingleById(t._clips,\"clipPath\",n,function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")}),this.clipDefRelative=o.ensureSingleById(t._clips,\"clipPath\",i,function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")}),this.plotContainer=o.ensureSingle(this.container,\"g\",this.id),this.updateLayers(r),c.setClipUrl(this.layers.backplot,n,e),c.setClipUrl(this.layers.grids,n,e)},w.updateLayers=function(t){var e=this.layers,r=[\"draglayer\",\"plotbg\",\"backplot\",\"grids\"];\"below traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"below traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"below traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\"),r.push(\"frontplot\"),\"above traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"above traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"above traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\");var i=this.plotContainer.selectAll(\"g.toplevel\").data(r,String),a=[\"agrid\",\"bgrid\",\"cgrid\"];i.enter().append(\"g\").attr(\"class\",function(t){return\"toplevel \"+t}).each(function(t){var r=n.select(this);e[t]=r,\"frontplot\"===t?r.append(\"g\").classed(\"scatterlayer\",!0):\"backplot\"===t?r.append(\"g\").classed(\"maplayer\",!0):\"plotbg\"===t?r.append(\"path\").attr(\"d\",\"M0,0Z\"):\"aline\"===t||\"bline\"===t||\"cline\"===t?r.append(\"path\"):\"grids\"===t&&a.forEach(function(t){e[t]=r.append(\"g\").classed(\"grid \"+t,!0)})}),i.order()};var k=Math.sqrt(4/3);w.adjustLayout=function(t,e){var r,n,i,a,o,s,f=this,p=t.domain,d=(p.x[0]+p.x[1])/2,g=(p.y[0]+p.y[1])/2,v=p.x[1]-p.x[0],m=p.y[1]-p.y[0],y=v*e.w,x=m*e.h,b=t.sum,_=t.aaxis.min,w=t.baxis.min,T=t.caxis.min;y>k*x?i=(a=x)*k:a=(i=y)/k,o=v*i/y,s=m*a/x,r=e.l+e.w*d-i/2,n=e.t+e.h*(1-g)-a/2,f.x0=r,f.y0=n,f.w=i,f.h=a,f.sum=b,f.xaxis={type:\"linear\",range:[_+2*T-b,b-_-2*w],domain:[d-o/2,d+o/2],_id:\"x\"},u(f.xaxis,f.graphDiv._fullLayout),f.xaxis.setScale(),f.xaxis.isPtWithinRange=function(t){return t.a>=f.aaxis.range[0]&&t.a<=f.aaxis.range[1]&&t.b>=f.baxis.range[1]&&t.b<=f.baxis.range[0]&&t.c>=f.caxis.range[1]&&t.c<=f.caxis.range[0]},f.yaxis={type:\"linear\",range:[_,b-w-T],domain:[g-s/2,g+s/2],_id:\"y\"},u(f.yaxis,f.graphDiv._fullLayout),f.yaxis.setScale(),f.yaxis.isPtWithinRange=function(){return!0};var A=f.yaxis.domain[0],M=f.aaxis=h({},t.aaxis,{range:[_,b-w-T],side:\"left\",tickangle:(+t.aaxis.tickangle||0)-30,domain:[A,A+s*k],anchor:\"free\",position:0,_id:\"y\",_length:i});u(M,f.graphDiv._fullLayout),M.setScale();var S=f.baxis=h({},t.baxis,{range:[b-_-T,w],side:\"bottom\",domain:f.xaxis.domain,anchor:\"free\",position:0,_id:\"x\",_length:i});u(S,f.graphDiv._fullLayout),S.setScale();var E=f.caxis=h({},t.caxis,{range:[b-_-w,T],side:\"right\",tickangle:(+t.caxis.tickangle||0)+30,domain:[A,A+s*k],anchor:\"free\",position:0,_id:\"y\",_length:i});u(E,f.graphDiv._fullLayout),E.setScale();var C=\"M\"+r+\",\"+(n+a)+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";f.clipDef.select(\"path\").attr(\"d\",C),f.layers.plotbg.select(\"path\").attr(\"d\",C);var L=\"M0,\"+a+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";f.clipDefRelative.select(\"path\").attr(\"d\",L);var P=\"translate(\"+r+\",\"+n+\")\";f.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",P),f.clipDefRelative.select(\"path\").attr(\"transform\",null);var O=\"translate(\"+(r-S._offset)+\",\"+(n+a)+\")\";f.layers.baxis.attr(\"transform\",O),f.layers.bgrid.attr(\"transform\",O);var z=\"translate(\"+(r+i/2)+\",\"+n+\")rotate(30)translate(0,\"+-M._offset+\")\";f.layers.aaxis.attr(\"transform\",z),f.layers.agrid.attr(\"transform\",z);var I=\"translate(\"+(r+i/2)+\",\"+n+\")rotate(-30)translate(0,\"+-E._offset+\")\";f.layers.caxis.attr(\"transform\",I),f.layers.cgrid.attr(\"transform\",I),f.drawAxes(!0),f.layers.aline.select(\"path\").attr(\"d\",M.showline?\"M\"+r+\",\"+(n+a)+\"l\"+i/2+\",-\"+a:\"M0,0\").call(l.stroke,M.linecolor||\"#000\").style(\"stroke-width\",(M.linewidth||0)+\"px\"),f.layers.bline.select(\"path\").attr(\"d\",S.showline?\"M\"+r+\",\"+(n+a)+\"h\"+i:\"M0,0\").call(l.stroke,S.linecolor||\"#000\").style(\"stroke-width\",(S.linewidth||0)+\"px\"),f.layers.cline.select(\"path\").attr(\"d\",E.showline?\"M\"+(r+i/2)+\",\"+n+\"l\"+i/2+\",\"+a:\"M0,0\").call(l.stroke,E.linecolor||\"#000\").style(\"stroke-width\",(E.linewidth||0)+\"px\"),f.graphDiv._context.staticPlot||f.initInteractions(),c.setClipUrl(f.layers.frontplot,f._hasClipOnAxisFalse?null:f.clipId,f.graphDiv)},w.drawAxes=function(t){var e=this.graphDiv,r=this.id.substr(7)+\"title\",n=this.layers,i=this.aaxis,a=this.baxis,o=this.caxis;if(this.drawAx(i),this.drawAx(a),this.drawAx(o),t){var l=Math.max(i.showticklabels?i.tickfont.size/2:0,(o.showticklabels?.75*o.tickfont.size:0)+(\"outside\"===o.ticks?.87*o.ticklen:0)),c=(a.showticklabels?a.tickfont.size:0)+(\"outside\"===a.ticks?a.ticklen:0)+3;n[\"a-title\"]=v.draw(e,\"a\"+r,{propContainer:i,propName:this.id+\".aaxis.title\",placeholder:s(e,\"Click to enter Component A title\"),attributes:{x:this.x0+this.w/2,y:this.y0-i.title.font.size/3-l,\"text-anchor\":\"middle\"}}),n[\"b-title\"]=v.draw(e,\"b\"+r,{propContainer:a,propName:this.id+\".baxis.title\",placeholder:s(e,\"Click to enter Component B title\"),attributes:{x:this.x0-c,y:this.y0+this.h+.83*a.title.font.size+c,\"text-anchor\":\"middle\"}}),n[\"c-title\"]=v.draw(e,\"c\"+r,{propContainer:o,propName:this.id+\".caxis.title\",placeholder:s(e,\"Click to enter Component C title\"),attributes:{x:this.x0+this.w+c,y:this.y0+this.h+.83*o.title.font.size+c,\"text-anchor\":\"middle\"}})}},w.drawAx=function(t){var e,r=this.graphDiv,n=t._name,i=n.charAt(0),a=t._id,s=this.layers[n],l=i+\"tickLayout\",c=(e=t).ticks+String(e.ticklen)+String(e.showticklabels);this[l]!==c&&(s.selectAll(\".\"+a+\"tick\").remove(),this[l]=c),t.setScale();var u=p.calcTicks(t),h=p.clipEnds(t,u),f=p.makeTransFn(t),d=p.getTickSigns(t)[2],g=o.deg2rad(30),v=d*(t.linewidth||1)/2,m=d*t.ticklen,y=this.w,x=this.h,b=\"b\"===i?\"M0,\"+v+\"l\"+Math.sin(g)*m+\",\"+Math.cos(g)*m:\"M\"+v+\",0l\"+Math.cos(g)*m+\",\"+-Math.sin(g)*m,_={a:\"M0,0l\"+x+\",-\"+y/2,b:\"M0,0l-\"+y/2+\",-\"+x,c:\"M0,0l-\"+x+\",\"+y/2}[i];p.drawTicks(r,t,{vals:\"inside\"===t.ticks?h:u,layer:s,path:b,transFn:f,crisp:!1}),p.drawGrid(r,t,{vals:h,layer:this.layers[i+\"grid\"],path:_,transFn:f,crisp:!1}),p.drawLabels(r,t,{vals:u,layer:s,transFn:f,labelFns:p.makeLabelFns(t,0,30)})};var T=b.MINZOOM/2+.87,A=\"m-0.87,.5h\"+T+\"v3h-\"+(T+5.2)+\"l\"+(T/2+2.6)+\",-\"+(.87*T+4.5)+\"l2.6,1.5l-\"+T/2+\",\"+.87*T+\"Z\",M=\"m0.87,.5h-\"+T+\"v3h\"+(T+5.2)+\"l-\"+(T/2+2.6)+\",-\"+(.87*T+4.5)+\"l-2.6,1.5l\"+T/2+\",\"+.87*T+\"Z\",S=\"m0,1l\"+T/2+\",\"+.87*T+\"l2.6,-1.5l-\"+(T/2+2.6)+\",-\"+(.87*T+4.5)+\"l-\"+(T/2+2.6)+\",\"+(.87*T+4.5)+\"l2.6,1.5l\"+T/2+\",-\"+.87*T+\"Z\",E=\"m0.5,0.5h5v-2h-5v-5h-2v5h-5v2h5v5h2Z\",C=!0;function L(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}w.initInteractions=function(){var t,e,r,n,u,h,f,p,v,_,w=this,T=w.layers.plotbg.select(\"path\").node(),P=w.graphDiv,O=P._fullLayout._zoomlayer,z={element:T,gd:P,plotinfo:{id:w.id,xaxis:w.xaxis,yaxis:w.yaxis},subplot:w.id,prepFn:function(a,o,s){z.xaxes=[w.xaxis],z.yaxes=[w.yaxis];var c=P._fullLayout.dragmode;z.minDrag=\"lasso\"===c?1:void 0,\"zoom\"===c?(z.moveFn=N,z.clickFn=D,z.doneFn=j,function(a,o,s){var c=T.getBoundingClientRect();t=o-c.left,e=s-c.top,r={a:w.aaxis.range[0],b:w.baxis.range[1],c:w.caxis.range[1]},u=r,n=w.aaxis.range[1]-r.a,h=i(w.graphDiv._fullLayout[w.id].bgcolor).getLuminance(),f=\"M0,\"+w.h+\"L\"+w.w/2+\", 0L\"+w.w+\",\"+w.h+\"Z\",p=!1,v=O.append(\"path\").attr(\"class\",\"zoombox\").attr(\"transform\",\"translate(\"+w.x0+\", \"+w.y0+\")\").style({fill:h>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"d\",f),_=O.append(\"path\").attr(\"class\",\"zoombox-corners\").attr(\"transform\",\"translate(\"+w.x0+\", \"+w.y0+\")\").style({fill:l.background,stroke:l.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"d\",\"M0,0Z\"),x(P)}(0,o,s)):\"pan\"===c?(z.moveFn=U,z.clickFn=D,z.doneFn=V,r={a:w.aaxis.range[0],b:w.baxis.range[1],c:w.caxis.range[1]},u=r,x(P)):\"select\"!==c&&\"lasso\"!==c||m(a,o,s,z,c)}};function I(t){var e={};return e[w.id+\".aaxis.min\"]=t.a,e[w.id+\".baxis.min\"]=t.b,e[w.id+\".caxis.min\"]=t.c,e}function D(t,e){var r=P._fullLayout.clickmode;L(P),2===t&&(P.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",P,I({a:0,b:0,c:0}))),r.indexOf(\"select\")>-1&&1===t&&y(e,P,[w.xaxis],[w.yaxis],w.id,z),r.indexOf(\"event\")>-1&&g.click(P,e,w.id)}function R(t,e){return 1-e/w.h}function F(t,e){return 1-(t+(w.h-e)/Math.sqrt(3))/w.w}function B(t,e){return(t-(w.h-e)/Math.sqrt(3))/w.w}function N(i,a){var o=t+i,s=e+a,l=Math.max(0,Math.min(1,R(0,e),R(0,s))),c=Math.max(0,Math.min(1,F(t,e),F(o,s))),d=Math.max(0,Math.min(1,B(t,e),B(o,s))),g=(l/2+d)*w.w,m=(1-l/2-c)*w.w,y=(g+m)/2,x=m-g,T=(1-l)*w.h,C=T-x/k;x<b.MINZOOM?(u=r,v.attr(\"d\",f),_.attr(\"d\",\"M0,0Z\")):(u={a:r.a+l*n,b:r.b+c*n,c:r.c+d*n},v.attr(\"d\",f+\"M\"+g+\",\"+T+\"H\"+m+\"L\"+y+\",\"+C+\"L\"+g+\",\"+T+\"Z\"),_.attr(\"d\",\"M\"+t+\",\"+e+E+\"M\"+g+\",\"+T+A+\"M\"+m+\",\"+T+M+\"M\"+y+\",\"+C+S)),p||(v.transition().style(\"fill\",h>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),_.transition().style(\"opacity\",1).duration(200),p=!0),P.emit(\"plotly_relayouting\",I(u))}function j(){L(P),u!==r&&(a.call(\"_guiRelayout\",P,I(u)),C&&P.data&&P._context.showTips&&(o.notifier(s(P,\"Double-click to zoom back out\"),\"long\"),C=!1))}function U(t,e){var n=t/w.xaxis._m,i=e/w.yaxis._m,a=[(u={a:r.a-i,b:r.b+(n+i)/2,c:r.c-(n-i)/2}).a,u.b,u.c].sort(),o=a.indexOf(u.a),s=a.indexOf(u.b),l=a.indexOf(u.c);a[0]<0&&(a[1]+a[0]/2<0?(a[2]+=a[0]+a[1],a[0]=a[1]=0):(a[2]+=a[0]/2,a[1]+=a[0]/2,a[0]=0),u={a:a[o],b:a[s],c:a[l]},e=(r.a-u.a)*w.yaxis._m,t=(r.c-u.c-r.b+u.b)*w.xaxis._m);var h=\"translate(\"+(w.x0+t)+\",\"+(w.y0+e)+\")\";w.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",h);var f=\"translate(\"+-t+\",\"+-e+\")\";w.clipDefRelative.select(\"path\").attr(\"transform\",f),w.aaxis.range=[u.a,w.sum-u.b-u.c],w.baxis.range=[w.sum-u.a-u.c,u.b],w.caxis.range=[w.sum-u.a-u.b,u.c],w.drawAxes(!1),w._hasClipOnAxisFalse&&w.plotContainer.select(\".scatterlayer\").selectAll(\".trace\").call(c.hideOutsideRangePoints,w),P.emit(\"plotly_relayouting\",I(u))}function V(){a.call(\"_guiRelayout\",P,I(u))}T.onmousemove=function(t){g.hover(P,t,w.id),P._fullLayout._lasthover=T,P._fullLayout._hoversubplot=w.id},T.onmouseout=function(t){P._dragging||d.unhover(P,t)},d.init(z)}},{\"../../components/color\":593,\"../../components/dragelement\":611,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../components/titles\":681,\"../../lib\":719,\"../../lib/extend\":710,\"../../registry\":847,\"../cartesian/axes\":767,\"../cartesian/constants\":773,\"../cartesian/select\":784,\"../cartesian/set_convert\":785,\"../plots\":828,d3:163,tinycolor2:537}],847:[function(t,e,r){\"use strict\";var n=t(\"./lib/loggers\"),i=t(\"./lib/noop\"),a=t(\"./lib/push_unique\"),o=t(\"./lib/is_plain_object\"),s=t(\"./lib/dom\").addStyleRule,l=t(\"./lib/extend\"),c=t(\"./plots/attributes\"),u=t(\"./plots/layout_attributes\"),h=l.extendFlat,f=l.extendDeepAll;function p(t){var e=t.name,i=t.categories,a=t.meta;if(r.modules[e])n.log(\"Type \"+e+\" already registered\");else{r.subplotsRegistry[t.basePlotModule.name]||function(t){var e=t.name;if(r.subplotsRegistry[e])return void n.log(\"Plot type \"+e+\" already registered.\");for(var i in m(t),r.subplotsRegistry[e]=t,r.componentsRegistry)b(i,t.name)}(t.basePlotModule);for(var o={},l=0;l<i.length;l++)o[i[l]]=!0,r.allCategories[i[l]]=!0;for(var c in r.modules[e]={_module:t,categories:o},a&&Object.keys(a).length&&(r.modules[e].meta=a),r.allTypes.push(e),r.componentsRegistry)y(c,e);t.layoutAttributes&&h(r.traceLayoutAttributes,t.layoutAttributes);var u=t.basePlotModule,f=u.name;if(\"mapbox\"===f){var p=u.constants.styleRules;for(var d in p)s(\".js-plotly-plot .plotly .mapboxgl-\"+d,p[d])}\"geo\"!==f&&\"mapbox\"!==f||void 0===typeof window||void 0!==window.PlotlyGeoAssets||(window.PlotlyGeoAssets={topojson:{}})}}function d(t){if(\"string\"!=typeof t.name)throw new Error(\"Component module *name* must be a string.\");var e=t.name;for(var n in r.componentsRegistry[e]=t,t.layoutAttributes&&(t.layoutAttributes._isLinkedToArray&&a(r.layoutArrayContainers,e),m(t)),r.modules)y(e,n);for(var i in r.subplotsRegistry)b(e,i);for(var o in r.transformsRegistry)x(e,o);t.schema&&t.schema.layout&&f(u,t.schema.layout)}function g(t){if(\"string\"!=typeof t.name)throw new Error(\"Transform module *name* must be a string.\");var e=\"Transform module \"+t.name,i=\"function\"==typeof t.transform,a=\"function\"==typeof t.calcTransform;if(!i&&!a)throw new Error(e+\" is missing a *transform* or *calcTransform* method.\");for(var s in i&&a&&n.log([e+\" has both a *transform* and *calcTransform* methods.\",\"Please note that all *transform* methods are executed\",\"before all *calcTransform* methods.\"].join(\" \")),o(t.attributes)||n.log(e+\" registered without an *attributes* object.\"),\"function\"!=typeof t.supplyDefaults&&n.log(e+\" registered without a *supplyDefaults* method.\"),r.transformsRegistry[t.name]=t,r.componentsRegistry)x(s,t.name)}function v(t){var e=t.name,n=e.split(\"-\")[0],i=t.dictionary,a=t.format,o=i&&Object.keys(i).length,s=a&&Object.keys(a).length,l=r.localeRegistry,c=l[e];if(c||(l[e]=c={}),n!==e){var u=l[n];u||(l[n]=u={}),o&&u.dictionary===c.dictionary&&(u.dictionary=i),s&&u.format===c.format&&(u.format=a)}o&&(c.dictionary=i),s&&(c.format=a)}function m(t){if(t.layoutAttributes){var e=t.layoutAttributes._arrayAttrRegexps;if(e)for(var n=0;n<e.length;n++)a(r.layoutArrayRegexes,e[n])}}function y(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.traces){var i=n.traces[e];i&&f(r.modules[e]._module.attributes,i)}}function x(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.transforms){var i=n.transforms[e];i&&f(r.transformsRegistry[e].attributes,i)}}function b(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.subplots){var i=r.subplotsRegistry[e],a=i.layoutAttributes,o=\"subplot\"===i.attr?i.name:i.attr;Array.isArray(o)&&(o=o[0]);var s=n.subplots[o];a&&s&&f(a,s)}}function _(t){return\"object\"==typeof t&&(t=t.type),t}r.modules={},r.allCategories={},r.allTypes=[],r.subplotsRegistry={},r.transformsRegistry={},r.componentsRegistry={},r.layoutArrayContainers=[],r.layoutArrayRegexes=[],r.traceLayoutAttributes={},r.localeRegistry={},r.apiMethodRegistry={},r.collectableSubplotTypes=null,r.register=function(t){if(r.collectableSubplotTypes=null,!t)throw new Error(\"No argument passed to Plotly.register.\");t&&!Array.isArray(t)&&(t=[t]);for(var e=0;e<t.length;e++){var n=t[e];if(!n)throw new Error(\"Invalid module was attempted to be registered!\");switch(n.moduleType){case\"trace\":p(n);break;case\"transform\":g(n);break;case\"component\":d(n);break;case\"locale\":v(n);break;case\"apiMethod\":var i=n.name;r.apiMethodRegistry[i]=n.fn;break;default:throw new Error(\"Invalid module was attempted to be registered!\")}}},r.getModule=function(t){var e=r.modules[_(t)];return!!e&&e._module},r.traceIs=function(t,e){if(\"various\"===(t=_(t)))return!1;var i=r.modules[t];return i||(t&&\"area\"!==t&&n.log(\"Unrecognized trace type \"+t+\".\"),i=r.modules[c.type.dflt]),!!i.categories[e]},r.getTransformIndices=function(t,e){for(var r=[],n=t.transforms||[],i=0;i<n.length;i++)n[i].type===e&&r.push(i);return r},r.hasTransform=function(t,e){for(var r=t.transforms||[],n=0;n<r.length;n++)if(r[n].type===e)return!0;return!1},r.getComponentMethod=function(t,e){var n=r.componentsRegistry[t];return n&&n[e]||i},r.call=function(){var t=arguments[0],e=[].slice.call(arguments,1);return r.apiMethodRegistry[t].apply(null,e)}},{\"./lib/dom\":708,\"./lib/extend\":710,\"./lib/is_plain_object\":720,\"./lib/loggers\":723,\"./lib/noop\":728,\"./lib/push_unique\":733,\"./plots/attributes\":764,\"./plots/layout_attributes\":819}],848:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=i.extendFlat,o=i.extendDeep;function s(t){var e;switch(t){case\"themes__thumb\":e={autosize:!0,width:150,height:150,title:{text:\"\"},showlegend:!1,margin:{l:5,r:5,t:5,b:5,pad:0},annotations:[]};break;case\"thumbnail\":e={title:{text:\"\"},hidesources:!0,showlegend:!1,borderwidth:0,bordercolor:\"\",margin:{l:1,r:1,t:1,b:1,pad:0},annotations:[]};break;default:e={}}return e}e.exports=function(t,e){var r;t.framework&&t.framework.isPolar&&(t=t.framework.getConfig());var i,l=t.data,c=t.layout,u=o([],l),h=o({},c,s(e.tileClass)),f=t._context||{};if(e.width&&(h.width=e.width),e.height&&(h.height=e.height),\"thumbnail\"===e.tileClass||\"themes__thumb\"===e.tileClass){h.annotations=[];var p=Object.keys(h);for(r=0;r<p.length;r++)i=p[r],[\"xaxis\",\"yaxis\",\"zaxis\"].indexOf(i.slice(0,5))>-1&&(h[p[r]].title={text:\"\"});for(r=0;r<u.length;r++){var d=u[r];d.showscale=!1,d.marker&&(d.marker.showscale=!1),n.traceIs(d,\"pie-like\")&&(d.textposition=\"none\")}}if(Array.isArray(e.annotations))for(r=0;r<e.annotations.length;r++)h.annotations.push(e.annotations[r]);var g=Object.keys(h).filter(function(t){return t.match(/^scene\\d*$/)});if(g.length){var v={};for(\"thumbnail\"===e.tileClass&&(v={title:{text:\"\"},showaxeslabels:!1,showticklabels:!1,linetickenable:!1}),r=0;r<g.length;r++){var m=h[g[r]];m.xaxis||(m.xaxis={}),m.yaxis||(m.yaxis={}),m.zaxis||(m.zaxis={}),a(m.xaxis,v),a(m.yaxis,v),a(m.zaxis,v),m._scene=null}}var y=document.createElement(\"div\");e.tileClass&&(y.className=e.tileClass);var x={gd:y,td:y,layout:h,data:u,config:{staticPlot:void 0===e.staticPlot||e.staticPlot,plotGlPixelRatio:void 0===e.plotGlPixelRatio?2:e.plotGlPixelRatio,displaylogo:e.displaylogo||!1,showLink:e.showLink||!1,showTips:e.showTips||!1,mapboxAccessToken:f.mapboxAccessToken}};return\"transparent\"!==e.setBackground&&(x.config.setBackground=e.setBackground||\"opaque\"),x.gd.defaultLayout=s(e.tileClass),x}},{\"../lib\":719,\"../registry\":847}],849:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/to_image\"),a=t(\"./filesaver\"),o=t(\"./helpers\");e.exports=function(t,e){var r;return n.isPlainObject(t)||(r=n.getGraphDiv(t)),(e=e||{}).format=e.format||\"png\",e.imageDataOnly=!0,new Promise(function(s,l){r&&r._snapshotInProgress&&l(new Error(\"Snapshotting already in progress.\")),n.isIE()&&\"svg\"!==e.format&&l(new Error(o.MSG_IE_BAD_FORMAT)),r&&(r._snapshotInProgress=!0);var c=i(t,e),u=e.filename||t.fn||\"newplot\";u+=\".\"+e.format,c.then(function(t){return r&&(r._snapshotInProgress=!1),a(t,u,e.format)}).then(function(t){s(t)}).catch(function(t){r&&(r._snapshotInProgress=!1),l(t)})})}},{\"../lib\":719,\"../plot_api/to_image\":760,\"./filesaver\":850,\"./helpers\":851}],850:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"./helpers\");e.exports=function(t,e,r){var a=document.createElement(\"a\"),o=\"download\"in a;return new Promise(function(s,l){var c,u;if(n.isIE9orBelow()&&l(new Error(\"IE < 10 unsupported\")),n.isSafari()){var h=\"svg\"===r?\",\":\";base64,\";return i.octetStream(h+encodeURIComponent(t)),s(e)}return n.isIE()?(c=i.createBlob(t,\"svg\"),window.navigator.msSaveBlob(c,e),c=null,s(e)):o?(c=i.createBlob(t,r),u=i.createObjectURL(c),a.href=u,a.download=e,document.body.appendChild(a),a.click(),document.body.removeChild(a),i.revokeObjectURL(u),c=null,s(e)):void l(new Error(\"download error\"))})}},{\"../lib\":719,\"./helpers\":851}],851:[function(t,e,r){\"use strict\";var n=t(\"../registry\");r.getDelay=function(t){return t._has&&(t._has(\"gl3d\")||t._has(\"gl2d\")||t._has(\"mapbox\"))?500:0},r.getRedrawFunc=function(t){return function(){var e=t._fullLayout||{};!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r||n.getComponentMethod(\"colorbar\",\"draw\")(t)}},r.encodeSVG=function(t){return\"data:image/svg+xml,\"+encodeURIComponent(t)};var i=window.URL||window.webkitURL;r.createObjectURL=function(t){return i.createObjectURL(t)},r.revokeObjectURL=function(t){return i.revokeObjectURL(t)},r.createBlob=function(t,e){if(\"svg\"===e)return new window.Blob([t],{type:\"image/svg+xml;charset=utf-8\"});var r=function(t){for(var e=t.length,r=new ArrayBuffer(e),n=new Uint8Array(r),i=0;i<e;i++)n[i]=t.charCodeAt(i);return r}(window.atob(t));return new window.Blob([r],{type:\"image/\"+e})},r.octetStream=function(t){document.location.href=\"data:application/octet-stream\"+t},r.IMAGE_URL_PREFIX=/^data:image\\/\\w+;base64,/,r.MSG_IE_BAD_FORMAT=\"Sorry IE does not support downloading from canvas. Try {format:'svg'} instead.\"},{\"../registry\":847}],852:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i={getDelay:n.getDelay,getRedrawFunc:n.getRedrawFunc,clone:t(\"./cloneplot\"),toSVG:t(\"./tosvg\"),svgToImg:t(\"./svgtoimg\"),toImage:t(\"./toimage\"),downloadImage:t(\"./download\")};e.exports=i},{\"./cloneplot\":848,\"./download\":849,\"./helpers\":851,\"./svgtoimg\":853,\"./toimage\":854,\"./tosvg\":855}],853:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"events\").EventEmitter,a=t(\"./helpers\");e.exports=function(t){var e=t.emitter||new i,r=new Promise(function(i,o){var s=window.Image,l=t.svg,c=t.format||\"png\";if(n.isIE()&&\"svg\"!==c){var u=new Error(a.MSG_IE_BAD_FORMAT);return o(u),t.promise?r:e.emit(\"error\",u)}var h,f,p=t.canvas,d=t.scale||1,g=t.width||300,v=t.height||150,m=d*g,y=d*v,x=p.getContext(\"2d\"),b=new s;\"svg\"===c||n.isIE9orBelow()||n.isSafari()?f=a.encodeSVG(l):(h=a.createBlob(l,\"svg\"),f=a.createObjectURL(h)),p.width=m,p.height=y,b.onload=function(){var r;switch(h=null,a.revokeObjectURL(f),\"svg\"!==c&&x.drawImage(b,0,0,m,y),c){case\"jpeg\":r=p.toDataURL(\"image/jpeg\");break;case\"png\":r=p.toDataURL(\"image/png\");break;case\"webp\":r=p.toDataURL(\"image/webp\");break;case\"svg\":r=f;break;default:var n=\"Image format is not jpeg, png, svg or webp.\";if(o(new Error(n)),!t.promise)return e.emit(\"error\",n)}i(r),t.promise||e.emit(\"success\",r)},b.onerror=function(r){if(h=null,a.revokeObjectURL(f),o(r),!t.promise)return e.emit(\"error\",r)},b.src=f});return t.promise?r:e}},{\"../lib\":719,\"./helpers\":851,events:104}],854:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i=t(\"../registry\"),a=t(\"../lib\"),o=t(\"./helpers\"),s=t(\"./cloneplot\"),l=t(\"./tosvg\"),c=t(\"./svgtoimg\");e.exports=function(t,e){var r=new n,u=s(t,{format:\"png\"}),h=u.gd;h.style.position=\"absolute\",h.style.left=\"-5000px\",document.body.appendChild(h);var f=o.getRedrawFunc(h);return i.call(\"plot\",h,u.data,u.layout,u.config).then(f).then(function(){var t=o.getDelay(h._fullLayout);setTimeout(function(){var t=l(h),n=document.createElement(\"canvas\");n.id=a.randstr(),(r=c({format:e.format,width:h._fullLayout.width,height:h._fullLayout.height,canvas:n,emitter:r,svg:t})).clean=function(){h&&document.body.removeChild(h)}},t)}).catch(function(t){r.emit(\"error\",t)}),r}},{\"../lib\":719,\"../registry\":847,\"./cloneplot\":848,\"./helpers\":851,\"./svgtoimg\":853,\"./tosvg\":855,events:104}],855:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=t(\"../components/drawing\"),o=t(\"../components/color\"),s=t(\"../constants/xmlns_namespaces\"),l=/\"/g,c=new RegExp('(\"TOBESTRIPPED)|(TOBESTRIPPED\")',\"g\");e.exports=function(t,e,r){var u,h=t._fullLayout,f=h._paper,p=h._toppaper,d=h.width,g=h.height;f.insert(\"rect\",\":first-child\").call(a.setRect,0,0,d,g).call(o.fill,h.paper_bgcolor);var v=h._basePlotModules||[];for(u=0;u<v.length;u++){var m=v[u];m.toSVG&&m.toSVG(t)}if(p){var y=p.node().childNodes,x=Array.prototype.slice.call(y);for(u=0;u<x.length;u++){var b=x[u];b.childNodes.length&&f.node().appendChild(b)}}h._draggers&&h._draggers.remove(),f.node().style.background=\"\",f.selectAll(\"text\").attr({\"data-unformatted\":null,\"data-math\":null}).each(function(){var t=n.select(this);if(\"hidden\"!==this.style.visibility&&\"none\"!==this.style.display){t.style({visibility:null,display:null});var e=this.style.fontFamily;e&&-1!==e.indexOf('\"')&&t.style(\"font-family\",e.replace(l,\"TOBESTRIPPED\"))}else t.remove()}),f.selectAll(\".point, .scatterpts, .legendfill>path, .legendlines>path, .cbfill\").each(function(){var t=n.select(this),e=this.style.fill;e&&-1!==e.indexOf(\"url(\")&&t.style(\"fill\",e.replace(l,\"TOBESTRIPPED\"));var r=this.style.stroke;r&&-1!==r.indexOf(\"url(\")&&t.style(\"stroke\",r.replace(l,\"TOBESTRIPPED\"))}),\"pdf\"!==e&&\"eps\"!==e||f.selectAll(\"#MathJax_SVG_glyphs path\").attr(\"stroke-width\",0),f.node().setAttributeNS(s.xmlns,\"xmlns\",s.svg),f.node().setAttributeNS(s.xmlns,\"xmlns:xlink\",s.xlink),\"svg\"===e&&r&&(f.attr(\"width\",r*d),f.attr(\"height\",r*g),f.attr(\"viewBox\",\"0 0 \"+d+\" \"+g));var _=(new window.XMLSerializer).serializeToString(f.node());return _=function(t){var e=n.select(\"body\").append(\"div\").style({display:\"none\"}).html(\"\"),r=t.replace(/(&[^;]*;)/gi,function(t){return\"&lt;\"===t?\"&#60;\":\"&rt;\"===t?\"&#62;\":-1!==t.indexOf(\"<\")||-1!==t.indexOf(\">\")?\"\":e.html(t).text()});return e.remove(),r}(_),_=(_=_.replace(/&(?!\\w+;|\\#[0-9]+;| \\#x[0-9A-F]+;)/g,\"&amp;\")).replace(c,\"'\"),i.isIE()&&(_=(_=(_=_.replace(/\"/gi,\"'\")).replace(/(\\('#)([^']*)('\\))/gi,'(\"#$2\")')).replace(/(\\\\')/gi,'\"')),_}},{\"../components/color\":593,\"../components/drawing\":614,\"../constants/xmlns_namespaces\":696,\"../lib\":719,d3:163}],856:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\",!0),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":719}],857:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/font_attributes\"),s=t(\"./constants.js\"),l=t(\"../../lib/extend\").extendFlat,c=o({editType:\"calc\",arrayOk:!0,colorEditType:\"style\"}),u=l({},n.marker.line.width,{dflt:0}),h=l({width:u,editType:\"calc\"},a(\"marker.line\")),f=l({line:h,editType:\"calc\"},a(\"marker\"),{opacity:{valType:\"number\",arrayOk:!0,dflt:1,min:0,max:1,editType:\"style\"}});e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,text:n.text,hovertext:n.hovertext,hovertemplate:i({},{keys:s.eventDataKeys}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"none\",arrayOk:!0,editType:\"calc\"},insidetextanchor:{valType:\"enumerated\",values:[\"end\",\"middle\",\"start\"],dflt:\"end\",editType:\"plot\"},textangle:{valType:\"angle\",dflt:\"auto\",editType:\"plot\"},textfont:l({},c,{}),insidetextfont:l({},c,{}),outsidetextfont:l({},c,{}),constraintext:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"both\",\"none\"],dflt:\"both\",editType:\"calc\"},cliponaxis:l({},n.cliponaxis,{}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},base:{valType:\"any\",dflt:null,arrayOk:!0,editType:\"calc\"},offset:{valType:\"number\",dflt:null,arrayOk:!0,editType:\"calc\"},width:{valType:\"number\",dflt:null,min:0,arrayOk:!0,editType:\"calc\"},marker:f,offsetgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},alignmentgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},selected:{marker:{opacity:n.selected.marker.opacity,color:n.selected.marker.color,editType:\"style\"},textfont:n.selected.textfont,editType:\"style\"},unselected:{marker:{opacity:n.unselected.marker.opacity,color:n.unselected.marker.color,editType:\"style\"},textfont:n.unselected.textfont,editType:\"style\"},r:n.r,t:n.t,_deprecated:{bardir:{valType:\"enumerated\",editType:\"calc\",values:[\"v\",\"h\"]}}}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"../scatter/attributes\":1112,\"./constants.js\":859}],858:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),o=t(\"./arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\");e.exports=function(t,e){var r,l,c=n.getFromId(t,e.xaxis||\"x\"),u=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=c.makeCalcdata(e,\"x\"),l=u.makeCalcdata(e,\"y\")):(r=u.makeCalcdata(e,\"y\"),l=c.makeCalcdata(e,\"x\"));for(var h=Math.min(l.length,r.length),f=new Array(h),p=0;p<h;p++)f[p]={p:l[p],s:r[p]},e.ids&&(f[p].id=String(e.ids[p]));return i(e,\"marker\")&&a(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),i(e,\"marker.line\")&&a(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),o(f,e),s(f,e),f}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"../../plots/cartesian/axes\":767,\"../scatter/calc_selection\":1114,\"./arrays_to_calcdata\":856}],859:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[]}},{}],860:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,c=t(\"./sieve.js\");function u(t,e,r,o,u){if(o.length){var b,_,w,k;switch(function(t,e){var r,a;for(r=0;r<e.length;r++){var o,s=e[r],l=s[0].trace,c=\"funnel\"===l.type?l._base:l.base,u=\"h\"===l.orientation?l.xcalendar:l.ycalendar,h=\"category\"===t.type||\"multicategory\"===t.type?function(){return null}:t.d2c;if(i(c)){for(a=0;a<Math.min(c.length,s.length);a++)o=h(c[a],0,u),n(o)?(s[a].b=+o,s[a].hasB=1):s[a].b=0;for(;a<s.length;a++)s[a].b=0}else{o=h(c,0,u);var f=n(o);for(o=f?o:0,a=0;a<s.length;a++)s[a].b=o,f&&(s[a].hasB=1)}}}(r,o),u.mode){case\"overlay\":h(e,r,o,u);break;case\"group\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(k=o[w])[0].trace.offset?_.push(k):b.push(k);_.length&&function(t,e,r,n,i){var o=new c(n,{sepNegVal:!1,overlapNoMerge:!i.norm});(function(t,e,r,n){for(var i=t._fullLayout,a=r.positions,o=r.distinctPositions,s=r.minDiff,c=r.traces,u=c.length,h=a.length!==o.length,f=s*(1-n.gap),v=l(i,e._id)+c[0][0].trace.orientation,m=i._alignmentOpts[v]||{},y=0;y<u;y++){var x,b,_=c[y],w=_[0].trace,k=m[w.alignmentgroup]||{},T=Object.keys(k.offsetGroups||{}).length,A=(x=T?f/T:h?f/u:f)*(1-(n.groupgap||0));b=T?((2*w._offsetIndex+1-T)*x-A)/2:h?((2*y+1-u)*x-A)/2:-A/2;var M=_[0].t;M.barwidth=A,M.poffset=b,M.bargroupwidth=f,M.bardelta=s}r.binWidth=c[0][0].t.barwidth/100,p(r),d(e,r),g(e,r,h)})(t,e,o,i),function(t){for(var e=t.traces,r=0;r<e.length;r++){var n=e[r],i=n[0].trace;if(void 0===i.base)for(var o=new c([n],{sepNegVal:!0,overlapNoMerge:!0}),s=0;s<n.length;s++){var l=n[s];if(l.p!==a){var u=o.put(l.p,l.b+l.s);u&&(l.b=u)}}}}(o),i.norm?(m(o),y(r,o,i)):v(r,o)}(t,e,r,_,u),b.length&&h(e,r,b,u);break;case\"stack\":case\"relative\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(k=o[w])[0].trace.base?_.push(k):b.push(k);_.length&&function(t,e,r,n,i){var o=new c(n,{sepNegVal:\"relative\"===i.mode,overlapNoMerge:!(i.norm||\"stack\"===i.mode||\"relative\"===i.mode)});f(e,o,i),function(t,e,r){var n,i,o,l,c,u,h=x(t),f=e.traces;for(l=0;l<f.length;l++)if(n=f[l],\"funnel\"===(i=n[0].trace).type)for(c=0;c<n.length;c++)(u=n[c]).s!==a&&e.put(u.p,-.5*u.s);for(l=0;l<f.length;l++){n=f[l],i=n[0].trace,o=\"funnel\"===i.type;var p=[];for(c=0;c<n.length;c++)if((u=n[c]).s!==a){var d;d=o?u.s:u.s+u.b;var g=e.put(u.p,d),v=g+d;u.b=g,u[h]=v,r.norm||(p.push(v),u.hasB&&p.push(g))}r.norm||(i._extremes[t._id]=s.findExtremes(t,p,{tozero:!0,padded:!0}))}}(r,o,i);for(var l=0;l<n.length;l++)for(var u=n[l],h=0;h<u.length;h++){var p=u[h];if(p.s!==a){var d=p.b+p.s===o.get(p.p,p.s);d&&(p._outmost=!0)}}i.norm&&y(r,o,i)}(0,e,r,_,u),b.length&&h(e,r,b,u)}!function(t,e){var r,i,a,o=x(e),s={},l=1/0,c=-1/0;for(r=0;r<t.length;r++)for(a=t[r],i=0;i<a.length;i++){var u=a[i].p;n(u)&&(l=Math.min(l,u),c=Math.max(c,u))}var h=1e4/(c-l),f=s.round=function(t){return String(Math.round(h*(t-l)))};for(r=0;r<t.length;r++){(a=t[r])[0].t.extents=s;var p=a[0].t.poffset,d=Array.isArray(p);for(i=0;i<a.length;i++){var g=a[i],v=g[o]-g.w/2;if(n(v)){var m=g[o]+g.w/2,y=f(g.p);s[y]?s[y]=[Math.min(v,s[y][0]),Math.max(m,s[y][1])]:s[y]=[v,m]}g.p0=g.p+(d?p[i]:p),g.p1=g.p0+g.w,g.s0=g.b,g.s1=g.s0+g.s}}}(o,e)}}function h(t,e,r,n){for(var i=0;i<r.length;i++){var a=r[i],o=new c([a],{sepNegVal:!1,overlapNoMerge:!n.norm});f(t,o,n),n.norm?(m(o),y(e,o,n)):v(e,o)}}function f(t,e,r){for(var n=e.minDiff,i=e.traces,a=n*(1-r.gap),o=a*(1-(r.groupgap||0)),s=-o/2,l=0;l<i.length;l++){var c=i[l][0].t;c.barwidth=o,c.poffset=s,c.bargroupwidth=a,c.bardelta=n}e.binWidth=i[0][0].t.barwidth/100,p(e),d(t,e),g(t,e)}function p(t){var e,r,a=t.traces;for(e=0;e<a.length;e++){var o,s=a[e],l=s[0],c=l.trace,u=l.t,h=c._offset||c.offset,f=u.poffset;if(i(h)){for(o=Array.prototype.slice.call(h,0,s.length),r=0;r<o.length;r++)n(o[r])||(o[r]=f);for(r=o.length;r<s.length;r++)o.push(f);u.poffset=o}else void 0!==h&&(u.poffset=h);var p=c._width||c.width,d=u.barwidth;if(i(p)){var g=Array.prototype.slice.call(p,0,s.length);for(r=0;r<g.length;r++)n(g[r])||(g[r]=d);for(r=g.length;r<s.length;r++)g.push(d);if(u.barwidth=g,void 0===h){for(o=[],r=0;r<s.length;r++)o.push(f+(d-g[r])/2);u.poffset=o}}else void 0!==p&&(u.barwidth=p,void 0===h&&(u.poffset=f+(d-p)/2))}}function d(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++)for(var a=r[i],o=a[0].t,s=o.poffset,l=Array.isArray(s),c=o.barwidth,u=Array.isArray(c),h=0;h<a.length;h++){var f=a[h],p=f.w=u?c[h]:c;f[n]=f.p+(l?s[h]:s)+p/2}}function g(t,e,r){var n=e.traces,i=e.minDiff/2;s.minDtick(t,e.minDiff,e.distinctPositions[0],r);for(var a=0;a<n.length;a++){var o,l,c,u,h=n[a],f=h[0],p=f.trace,d=[];for(u=0;u<h.length;u++)l=(o=h[u]).p-i,c=o.p+i,d.push(l,c);if(p.width||p.offset){var g=f.t,v=g.poffset,m=g.barwidth,y=Array.isArray(v),x=Array.isArray(m);for(u=0;u<h.length;u++){o=h[u];var b=y?v[u]:v,_=x?m[u]:m;c=(l=o.p+b)+_,d.push(l,c)}}p._extremes[t._id]=s.findExtremes(t,d,{padded:!1})}}function v(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++){for(var a=r[i],o=a[0].trace,l=[],c=!0,u=0;u<a.length;u++){var h=a[u],f=h.b,p=f+h.s;h[n]=p,l.push(p),h.hasB&&l.push(f),h.hasB&&h.b>0&&h.s>0||(c=!1)}o._extremes[t._id]=s.findExtremes(t,l,{tozero:!c,padded:!0})}}function m(t){for(var e=t.traces,r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++){var o=n[i];o.s!==a&&t.put(o.p,o.b+o.s)}}function y(t,e,r){var i=e.traces,o=x(t),l=\"fraction\"===r.norm?1:100,c=l/1e9,u=t.l2c(t.c2l(0)),h=\"stack\"===r.mode?l:u;function f(e){return n(t.c2l(e))&&(e<u-c||e>h+c||!n(u))}for(var p=0;p<i.length;p++){for(var d=i[p],g=d[0].trace,v=[],m=!0,y=!1,b=0;b<d.length;b++){var _=d[b];if(_.s!==a){var w=Math.abs(l/e.get(_.p,_.s));_.b*=w,_.s*=w;var k=_.b,T=k+_.s;_[o]=T,v.push(T),y=y||f(T),_.hasB&&(v.push(k),y=y||f(k)),_.hasB&&_.b>0&&_.s>0||(m=!1)}}g._extremes[t._id]=s.findExtremes(t,v,{tozero:!m,padded:y})}}function x(t){return t._id.charAt(0)}e.exports={crossTraceCalc:function(t,e){for(var r=e.xaxis,n=e.yaxis,i=t._fullLayout,a=t._fullData,s=t.calcdata,l=[],c=[],h=0;h<a.length;h++){var f=a[h];!0===f.visible&&o.traceIs(f,\"bar\")&&f.xaxis===r._id&&f.yaxis===n._id&&(\"h\"===f.orientation?l.push(s[h]):c.push(s[h]))}var p={mode:i.barmode,norm:i.barnorm,gap:i.bargap,groupgap:i.bargroupgap};u(t,r,n,c,p),u(t,n,r,l,p)},setGroupPositions:u}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"./sieve.js\":869,\"fast-isnumeric\":225}],861:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../registry\"),o=t(\"../scatter/xy_defaults\"),s=t(\"./style_defaults\"),l=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,c=t(\"./attributes\"),u=n.coerceFont;function h(t,e,r,n){var i=e.orientation,a=e[{v:\"x\",h:\"y\"}[i]+\"axis\"],o=l(r,a)+i,s=r._alignmentOpts||{},c=n(\"alignmentgroup\"),u=s[o];u||(u=s[o]={});var h=u[c];h?h.traces.push(e):h=u[c]={traces:[e],alignmentIndex:Object.keys(u).length,offsetGroups:{}};var f=n(\"offsetgroup\"),p=h.offsetGroups,d=p[f];f&&(d||(d=p[f]={offsetIndex:Object.keys(p).length}),e._offsetIndex=d.offsetIndex)}function f(t,e,r,i,a,o){var s=!(!1===(o=o||{}).moduleHasSelected),l=!(!1===o.moduleHasUnselected),c=!(!1===o.moduleHasConstrain),h=!(!1===o.moduleHasCliponaxis),f=!(!1===o.moduleHasTextangle),p=!(!1===o.moduleHasInsideanchor),d=Array.isArray(a)||\"auto\"===a,g=d||\"inside\"===a,v=d||\"outside\"===a;if(g||v){var m=u(i,\"textfont\",r.font),y=n.extendFlat({},m);!(t.textfont&&t.textfont.color)&&delete y.color,u(i,\"insidetextfont\",y),v&&u(i,\"outsidetextfont\",m),s&&i(\"selected.textfont.color\"),l&&i(\"unselected.textfont.color\"),c&&i(\"constraintext\"),h&&i(\"cliponaxis\"),f&&i(\"textangle\")}g&&p&&i(\"insidetextanchor\")}e.exports={supplyDefaults:function(t,e,r,l){function u(r,i){return n.coerce(t,e,c,r,i)}if(o(t,e,l,u)){u(\"orientation\",e.x&&!e.y?\"h\":\"v\"),u(\"base\"),u(\"offset\"),u(\"width\"),u(\"text\"),u(\"hovertext\"),u(\"hovertemplate\");var h=u(\"textposition\");f(t,0,l,u,h,{moduleHasSelected:!0,moduleHasUnselected:!0,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),s(t,e,u,r,l);var p=(e.marker.line||{}).color,d=a.getComponentMethod(\"errorbars\",\"supplyDefaults\");d(t,e,p||i.defaultLine,{axis:\"y\"}),d(t,e,p||i.defaultLine,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,u)}else e.visible=!1},crossTraceDefaults:function(t,e){var r;function i(t){return n.coerce(r._input,r,c,t)}if(\"group\"===e.barmode)for(var a=0;a<t.length;a++)\"bar\"===(r=t[a]).type&&(r._input,h(0,r,e,i))},handleGroupingDefaults:h,handleText:f}},{\"../../components/color\":593,\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../scatter/xy_defaults\":1137,\"./attributes\":857,\"./style_defaults\":871}],862:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../../lib\").isArrayOrTypedArray;r.coerceString=function(t,e,r){if(\"string\"==typeof e){if(e||!t.noBlank)return e}else if((\"number\"==typeof e||!0===e)&&!t.strict)return String(e);return void 0!==r?r:t.dflt},r.coerceNumber=function(t,e,r){if(n(e)){e=+e;var i=t.min,a=t.max;if(!(void 0!==i&&e<i||void 0!==a&&e>a))return e}return void 0!==r?r:t.dflt},r.coerceColor=function(t,e,r){return i(e).isValid()?e:void 0!==r?r:t.dflt},r.coerceEnumerated=function(t,e,r){return t.coerceNumber&&(e=+e),-1!==t.values.indexOf(e)?e:void 0!==r?r:t.dflt},r.getValue=function(t,e){var r;return Array.isArray(t)?e<t.length&&(r=t[e]):r=t,r},r.getLineWidth=function(t,e){return 0<e.mlw?e.mlw:a(t.marker.line.width)?0:t.marker.line.width}},{\"../../lib\":719,\"fast-isnumeric\":225,tinycolor2:537}],863:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../../lib\").fillText,s=t(\"./helpers\").getLineWidth;function l(t,e,r,i){var a,s,l,c,u,h,f,p=t.cd,d=p[0].trace,g=p[0].t,v=\"closest\"===i,m=\"waterfall\"===d.type,y=t.maxHoverDistance,x=t.maxSpikeDistance;function b(t){return t[l]-t.w/2}function _(t){return t[l]+t.w/2}var w=v?b:function(t){return Math.min(b(t),t.p-g.bardelta/2)},k=v?_:function(t){return Math.max(_(t),t.p+g.bardelta/2)};function T(t,e){return n.inbox(t-a,e-a,y+Math.min(1,Math.abs(e-t)/f)-1)}function A(t){return T(w(t),k(t))}function M(t){var e=s,r=t.b,i=t[c];return m&&(i+=Math.abs(t.rawS||0)),n.inbox(r-e,i-e,y+(i-e)/(i-r)-1)}\"h\"===d.orientation?(a=r,s=e,l=\"y\",c=\"x\",u=M,h=A):(a=e,s=r,l=\"x\",c=\"y\",h=M,u=A);var S=t[l+\"a\"],E=t[c+\"a\"];f=Math.abs(S.r2c(S.range[1])-S.r2c(S.range[0]));var C=n.getDistanceFunction(i,u,h,function(t){return(u(t)+h(t))/2});if(n.getClosest(p,C,t),!1!==t.index){v||(w=function(t){return Math.min(b(t),t.p-g.bargroupwidth/2)},k=function(t){return Math.max(_(t),t.p+g.bargroupwidth/2)});var L=p[t.index],P=d.base?L.b+L.s:L.s;t[c+\"0\"]=t[c+\"1\"]=E.c2p(L[c],!0),t[c+\"LabelVal\"]=P;var O=g.extents[g.extents.round(L.p)];return t[l+\"0\"]=S.c2p(v?w(L):O[0],!0),t[l+\"1\"]=S.c2p(v?k(L):O[1],!0),t[l+\"LabelVal\"]=L.p,t.spikeDistance=(M(L)+function(t){return T(b(t),_(t))}(L))/2+x-y,t[l+\"Spike\"]=S.c2p(L.p,!0),o(L,d,t),t.hovertemplate=d.hovertemplate,t}}function c(t,e){var r=e.mcc||t.marker.color,n=e.mlcc||t.marker.line.color,i=s(t,e);return a.opacity(r)?r:a.opacity(n)&&i?n:void 0}e.exports={hoverPoints:function(t,e,r,n){var a=l(t,e,r,n);if(a){var o=a.cd,s=o[0].trace,u=o[a.index];return a.color=c(s,u),i.getComponentMethod(\"errorbars\",\"hoverInfo\")(u,s,a),[a]}},hoverOnBars:l,getTraceColor:c}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"../../registry\":847,\"./helpers\":862}],864:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,colorbar:t(\"../scatter/marker_colorbar\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"bar\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"oriented\",\"errorBarsOK\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../scatter/marker_colorbar\":1129,\"./arrays_to_calcdata\":856,\"./attributes\":857,\"./calc\":858,\"./cross_trace_calc\":860,\"./defaults\":861,\"./hover\":863,\"./layout_attributes\":865,\"./layout_defaults\":866,\"./plot\":867,\"./select\":868,\"./style\":870}],865:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\",\"relative\"],dflt:\"group\",editType:\"calc\"},barnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},bargap:{valType:\"number\",min:0,max:1,editType:\"calc\"},bargroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],866:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\"),o=t(\"./layout_attributes\");e.exports=function(t,e,r){function s(r,n){return a.coerce(t,e,o,r,n)}for(var l=!1,c=!1,u=!1,h={},f=s(\"barmode\"),p=0;p<r.length;p++){var d=r[p];if(n.traceIs(d,\"bar\")&&d.visible){if(l=!0,\"group\"===f){var g=d.xaxis+d.yaxis;h[g]&&(u=!0),h[g]=!0}if(d.visible&&\"histogram\"===d.type)\"category\"!==i.getFromId({_fullLayout:e},d[\"v\"===d.orientation?\"xaxis\":\"yaxis\"]).type&&(c=!0)}}l?(\"overlay\"!==f&&s(\"barnorm\"),s(\"bargap\",c&&!u?0:.2),s(\"bargroupgap\")):delete e.barmode}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./layout_attributes\":865}],867:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../registry\"),u=t(\"../../plots/cartesian/axes\").tickText,h=t(\"./style\"),f=t(\"./helpers\"),p=t(\"./attributes\"),d=p.text,g=p.textposition,v=3;function m(t,e){return t<e?1:-1}function y(t){return\"auto\"===t?0:t}function x(t,e,r,n,i,a){var o=!!a.isHorizontal,s=!!a.constrained,l=a.angle||0,c=a.anchor||0,u=i.width,h=i.height,f=Math.abs(e-t),p=Math.abs(n-r),d=f>2*v&&p>2*v?v:0;f-=2*d,p-=2*d;var g=!1;if(!(\"auto\"===l)||u<=f&&h<=p||!(u>f||h>p)||(u>p||h>f)&&u<h==f<p||(g=!0),g){var x=p;p=f,f=x}var b=y(l),_=Math.abs(Math.sin(Math.PI/180*b)),w=Math.abs(Math.cos(Math.PI/180*b)),k=Math.max(f*w,p*_),T=Math.max(f*_,p*w),A=s?Math.min(k/u,T/h):Math.max(w,_);A=Math.min(1,A);var M=(t+e)/2,S=(r+n)/2;\"middle\"!==c&&(d+=.5*(A*(o!==g?h:u)*_+A*(o!==g?u:h)*w),o?(d*=m(t,e),M=\"start\"===c?t+d:e-d):(d*=m(r,n),S=\"start\"===c?r+d:n-d));return g&&(b+=90),{textX:(i.left+i.right)/2,textY:(i.top+i.bottom)/2,targetX:M,targetY:S,scale:A,rotate:b}}function b(t,e,r,n,i,a){var o,s=!!a.isHorizontal,l=!!a.constrained,c=a.angle||0,u=i.width,h=i.height,f=Math.abs(e-t),p=Math.abs(n-r);o=s?p>2*v?v:0:f>2*v?v:0;var d=1;l&&(d=s?Math.min(1,p/h):Math.min(1,f/u));var g=y(c);o+=.5*(d*(s?h:u)*Math.abs(Math.sin(Math.PI/180*g))+d*(s?u:h)*Math.abs(Math.cos(Math.PI/180*g)));var x=(t+e)/2,b=(r+n)/2;return s?x=e-o*m(e,t):b=n+o*m(r,n),{textX:(i.left+i.right)/2,textY:(i.top+i.bottom)/2,targetX:x,targetY:b,scale:d,rotate:g}}function _(t){var e,r=t.textX,n=t.textY,i=t.targetX,a=t.targetY,o=t.scale,s=t.rotate;return o<1?e=\"scale(\"+o+\") \":(o=1,e=\"\"),\"translate(\"+(i-o*r)+\" \"+(a-o*n)+\")\"+e+(s?\"rotate(\"+s+\" \"+r+\" \"+n+\") \":\"\")}e.exports={plot:function(t,e,r,p,y){var w=e.xaxis,k=e.yaxis,T=t._fullLayout;y||(y={mode:T.barmode,norm:T.barmode,gap:T.bargap,groupgap:T.bargroupgap});var A=a.makeTraceGroups(p,r,\"trace bars\").each(function(r){var c=n.select(this),p=r[0].trace,T=\"waterfall\"===p.type,A=\"funnel\"===p.type,M=\"bar\"===p.type||A,S=0;T&&p.connector.visible&&\"between\"===p.connector.mode&&(S=p.connector.line.width/2);var E=\"h\"===p.orientation,C=a.ensureSingle(c,\"g\",\"points\").selectAll(\"g.point\").data(a.identity);C.enter().append(\"g\").classed(\"point\",!0),C.exit().remove(),C.each(function(c,T){var A,C,L=n.select(this),P=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),n?[i,a]:[a,i]}(c,w,k,E),O=P[0][0],z=P[0][1],I=P[1][0],D=P[1][1],R=!(O!==z&&I!==D&&i(O)&&i(z)&&i(I)&&i(D));if(R&&M&&f.getLineWidth(p,c)&&(E?z-O==0:D-I==0)&&(R=!1),c.isBlank=R,S&&(E?(O-=m(O,z)*S,z+=m(O,z)*S):(I-=m(I,D)*S,D+=m(I,D)*S)),\"waterfall\"===p.type){if(!R){var F=p[c.dir].marker;A=F.line.width,C=F.color}}else A=f.getLineWidth(p,c),C=c.mc||p.marker.color;var B=n.round(A/2%1,2);function N(t){return 0===y.gap&&0===y.groupgap?n.round(Math.round(t)-B,2):t}if(!t._context.staticPlot){var j=s.opacity(C)<1||A>.01?N:function(t,e){return Math.abs(t-e)>=2?N(t):t>e?Math.ceil(t):Math.floor(t)};O=j(O,z),z=j(z,O),I=j(I,D),D=j(D,I)}a.ensureSingle(L,\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"d\",R?\"M0,0Z\":\"M\"+O+\",\"+I+\"V\"+D+\"H\"+z+\"V\"+I+\"Z\").call(l.setClipUrl,e.layerClipId,t),function(t,e,r,n,i,s,c,p,m,y){var w,k=e.xaxis,T=e.yaxis,A=t._fullLayout;function M(e,r,n){var i=a.ensureSingle(e,\"text\").text(r).attr({class:\"bartext bartext-\"+w,transform:\"\",\"text-anchor\":\"middle\",\"data-notex\":1}).call(l.font,n).call(o.convertToTspans,t);return i}var S=n[0].trace,E=\"h\"===S.orientation,C=function(t,e,r,n){var i,o=t[0].trace;return i=o.textinfo?function(t,e,r,n){var i=t[0].trace,o=\"h\"===i.orientation,s=\"waterfall\"===i.type,l=\"funnel\"===i.type;function c(t){var e=o?r:n;return u(e,+t,!0).text}var h,f,p=i.textinfo,d=t[e],g=p.split(\"+\"),v=[],m=function(t){return-1!==g.indexOf(t)};if(m(\"label\")&&v.push((f=t[e].p,u(o?n:r,f,!0).text)),m(\"text\")&&(0===(h=a.castOption(i,d.i,\"text\"))||h)&&v.push(h),s){var y=+d.rawS||d.s,x=d.v,b=x-y;m(\"initial\")&&v.push(c(b)),m(\"delta\")&&v.push(c(y)),m(\"final\")&&v.push(c(x))}if(l){m(\"value\")&&v.push(c(d.s));var _=0;m(\"percent initial\")&&_++,m(\"percent previous\")&&_++,m(\"percent total\")&&_++;var w=_>1;m(\"percent initial\")&&(h=a.formatPercent(d.begR),w&&(h+=\" of initial\"),v.push(h)),m(\"percent previous\")&&(h=a.formatPercent(d.difR),w&&(h+=\" of previous\"),v.push(h)),m(\"percent total\")&&(h=a.formatPercent(d.sumR),w&&(h+=\" of total\"),v.push(h))}return v.join(\"<br>\")}(t,e,r,n):f.getValue(o.text,e),f.coerceString(d,i)}(n,i,k,T);w=function(t,e){var r=f.getValue(t.textposition,e);return f.coerceEnumerated(g,r)}(S,i);var L=\"stack\"===y.mode||\"relative\"===y.mode,P=n[i],O=!L||P._outmost;if(C&&\"none\"!==w&&(!P.isBlank&&s!==c&&p!==m||\"auto\"!==w&&\"inside\"!==w)){var z=A.font,I=h.getBarColor(n[i],S),D=h.getInsideTextFont(S,i,z,I),R=h.getOutsideTextFont(S,i,z),F=r.datum();E?\"log\"===k.type&&F.s0<=0&&(s=k.range[0]<k.range[1]?0:k._length):\"log\"===T.type&&F.s0<=0&&(p=T.range[0]<T.range[1]?T._length:0);var B,N,j,U,V,q,H=Math.abs(c-s)-2*v,G=Math.abs(m-p)-2*v;if(\"outside\"===w&&(O||P.hasB||(w=\"inside\")),\"auto\"===w)if(O){w=\"inside\",B=M(r,C,D),N=l.bBox(B.node()),j=N.width,U=N.height;var Y=j>0&&U>0,W=j<=H&&U<=G,X=j<=G&&U<=H,Z=E?H>=j*(G/U):G>=U*(H/j);Y&&(W||X||Z)?w=\"inside\":(w=\"outside\",B.remove(),B=null)}else w=\"inside\";!B&&(B=M(r,C,\"outside\"===w?R:D),N=l.bBox(B.node()),j=N.width,U=N.height,j<=0||U<=0)?B.remove():(\"outside\"===w?(q=\"both\"===S.constraintext||\"outside\"===S.constraintext,V=_(b(s,c,p,m,N,{isHorizontal:E,constrained:q,angle:S.textangle}))):(q=\"both\"===S.constraintext||\"inside\"===S.constraintext,V=_(x(s,c,p,m,N,{isHorizontal:E,constrained:q,angle:S.textangle,anchor:S.insidetextanchor}))),B.attr(\"transform\",V))}else r.select(\"text\").remove()}(t,e,L,r,T,O,z,I,D,y),e.layerClipId&&l.hideOutsideRangePoint(c,L.select(\"text\"),w,k,p.xcalendar,p.ycalendar)});var L=!1===p.cliponaxis;l.setClipUrl(c,L?null:e.layerClipId,t)});c.getComponentMethod(\"errorbars\",\"plot\")(t,A,e)},getTransform:_,toMoveInsideBar:x,toMoveOutsideBar:b}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"./attributes\":857,\"./helpers\":862,\"./style\":870,d3:163,\"fast-isnumeric\":225}],868:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=e.c2p(n?t.s0:t.p0,!0),o=e.c2p(n?t.s1:t.p1,!0),s=r.c2p(n?t.p0:t.s0,!0),l=r.c2p(n?t.p1:t.s1,!0);return i?[(a+o)/2,(s+l)/2]:n?[o,(s+l)/2]:[(a+o)/2,l]}e.exports=function(t,e){var r,i=t.cd,a=t.xaxis,o=t.yaxis,s=i[0].trace,l=\"funnel\"===s.type,c=\"h\"===s.orientation,u=[];if(!1===e)for(r=0;r<i.length;r++)i[r].selected=0;else for(r=0;r<i.length;r++){var h=i[r],f=\"ct\"in h?h.ct:n(h,a,o,c,l);e.contains(f,!1,r,t)?(u.push({pointNumber:r,x:a.c2d(h.x),y:o.c2d(h.y)}),h.selected=1):h.selected=0}return u}},{}],869:[function(t,e,r){\"use strict\";e.exports=a;var n=t(\"../../lib\").distinctVals,i=t(\"../../constants/numerical\").BADNUM;function a(t,e){this.traces=t,this.sepNegVal=e.sepNegVal,this.overlapNoMerge=e.overlapNoMerge;for(var r=1/0,a=[],o=0;o<t.length;o++){for(var s=t[o],l=0;l<s.length;l++){var c=s[l];c.p!==i&&a.push(c.p)}s[0]&&s[0].width1&&(r=Math.min(s[0].width1,r))}this.positions=a;var u=n(a);this.distinctPositions=u.vals,1===u.vals.length&&r!==1/0?this.minDiff=r:this.minDiff=Math.min(u.minDiff,r),this.binWidth=this.minDiff,this.bins={}}a.prototype.put=function(t,e){var r=this.getLabel(t,e),n=this.bins[r]||0;return this.bins[r]=n+e,n},a.prototype.get=function(t,e){var r=this.getLabel(t,e);return this.bins[r]||0},a.prototype.getLabel=function(t,e){return(e<0&&this.sepNegVal?\"v\":\"^\")+(this.overlapNoMerge?t:Math.round(t/this.binWidth))}},{\"../../constants/numerical\":695,\"../../lib\":719}],870:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../lib\"),s=t(\"../../registry\"),l=t(\"./attributes\"),c=l.textfont,u=l.insidetextfont,h=l.outsidetextfont,f=t(\"./helpers\");function p(t,e,r){a.pointStyle(t.selectAll(\"path\"),e,r),d(t,e,r)}function d(t,e,r){t.selectAll(\"text\").each(function(t){var i=n.select(this),o=g(i,t,e,r);a.font(i,o)})}function g(t,e,r,n){var i=n._fullLayout.font,a=r.textfont;if(t.classed(\"bartext-inside\")){var o=b(e,r);a=m(r,e.i,i,o)}else t.classed(\"bartext-outside\")&&(a=y(r,e.i,i));return a}function v(t,e,r){return x(c,t.textfont,e,r)}function m(t,e,r,n){var a=v(t,e,r);return(void 0===t._input.textfont||void 0===t._input.textfont.color||Array.isArray(t.textfont.color)&&void 0===t.textfont.color[e])&&(a={color:i.contrast(n),family:a.family,size:a.size}),x(u,t.insidetextfont,e,a)}function y(t,e,r){var n=v(t,e,r);return x(h,t.outsidetextfont,e,n)}function x(t,e,r,n){e=e||{};var i=f.getValue(e.family,r),a=f.getValue(e.size,r),o=f.getValue(e.color,r);return{family:f.coerceString(t.family,i,n.family),size:f.coerceNumber(t.size,a,n.size),color:f.coerceColor(t.color,o,n.color)}}function b(t,e){return\"waterfall\"===e.type?e[t.dir].marker.color:t.mc||e.marker.color}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.barlayer\").selectAll(\"g.trace\"),r=e.size(),i=t._fullLayout;e.style(\"opacity\",function(t){return t[0].trace.opacity}).each(function(t){(\"stack\"===i.barmode&&r>1||0===i.bargap&&0===i.bargroupgap&&!t[0].trace.marker.line.width)&&n.select(this).attr(\"shape-rendering\",\"crispEdges\")}),e.selectAll(\"g.points\").each(function(e){p(n.select(this),e[0].trace,t)}),s.getComponentMethod(\"errorbars\",\"style\")(e)},styleTextPoints:d,styleOnSelect:function(t,e,r){var i=e[0].trace;i.selectedpoints?function(t,e,r){a.selectedPointStyle(t.selectAll(\"path\"),e),function(t,e,r){t.each(function(t){var i,s=n.select(this);if(t.selected){i=o.extendFlat({},g(s,t,e,r));var l=e.selected.textfont&&e.selected.textfont.color;l&&(i.color=l),a.font(s,i)}else a.selectedTextStyle(s,e)})}(t.selectAll(\"text\"),e,r)}(r,i,t):(p(r,i,t),s.getComponentMethod(\"errorbars\",\"style\")(r))},getInsideTextFont:m,getOutsideTextFont:y,getBarColor:b}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../registry\":847,\"./attributes\":857,\"./helpers\":862,d3:163}],871:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s){r(\"marker.color\",o),i(t,\"marker\")&&a(t,e,s,r,{prefix:\"marker.\",cLetter:\"c\"}),r(\"marker.line.color\",n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,r,{prefix:\"marker.line.\",cLetter:\"c\"}),r(\"marker.line.width\"),r(\"marker.opacity\"),r(\"selected.marker.color\"),r(\"unselected.marker.color\")}},{\"../../components/color\":593,\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604}],872:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../scatterpolar/attributes\"),o=t(\"../bar/attributes\");e.exports={r:a.r,theta:a.theta,r0:a.r0,dr:a.dr,theta0:a.theta0,dtheta:a.dtheta,thetaunit:a.thetaunit,base:i({},o.base,{}),offset:i({},o.offset,{}),width:i({},o.width,{}),text:i({},o.text,{}),hovertext:i({},o.hovertext,{}),marker:o.marker,hoverinfo:a.hoverinfo,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../bar/attributes\":857,\"../scatterpolar/attributes\":1179}],873:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"../bar/arrays_to_calcdata\"),o=t(\"../bar/cross_trace_calc\").setGroupPositions,s=t(\"../scatter/calc_selection\"),l=t(\"../../registry\").traceIs,c=t(\"../../lib\").extendFlat;e.exports={calc:function(t,e){for(var r=t._fullLayout,o=e.subplot,l=r[o].radialaxis,c=r[o].angularaxis,u=l.makeCalcdata(e,\"r\"),h=c.makeCalcdata(e,\"theta\"),f=e._length,p=new Array(f),d=u,g=h,v=0;v<f;v++)p[v]={p:g[v],s:d[v]};function m(t){var r=e[t];void 0!==r&&(e[\"_\"+t]=Array.isArray(r)?c.makeCalcdata(e,t):c.d2c(r,e.thetaunit))}return\"linear\"===c.type&&(m(\"width\"),m(\"offset\")),n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),a(p,e),s(p,e),p},crossTraceCalc:function(t,e,r){for(var n=t.calcdata,i=[],a=0;a<n.length;a++){var s=n[a],u=s[0].trace;!0===u.visible&&l(u,\"bar\")&&u.subplot===r&&i.push(s)}var h=c({},e.radialaxis,{_id:\"x\"}),f=e.angularaxis;o(t,f,h,i,{mode:e.barmode,norm:e.barnorm,gap:e.bargap,groupgap:e.bargroupgap})}}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"../../lib\":719,\"../../registry\":847,\"../bar/arrays_to_calcdata\":856,\"../bar/cross_trace_calc\":860,\"../scatter/calc_selection\":1114}],874:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatterpolar/defaults\").handleRThetaDefaults,a=t(\"../bar/style_defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}i(t,e,s,l)?(l(\"thetaunit\"),l(\"base\"),l(\"offset\"),l(\"width\"),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),a(t,e,l,r,s),n.coerceSelectionMarkerOpacity(e,l)):e.visible=!1}},{\"../../lib\":719,\"../bar/style_defaults\":871,\"../scatterpolar/defaults\":1181,\"./attributes\":872}],875:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../bar/hover\").getTraceColor,o=i.fillText,s=t(\"../scatterpolar/hover\").makeHoverPointText,l=t(\"../../plots/polar/helpers\").isPtInsidePolygon;e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,h=t.subplot,f=h.radialAxis,p=h.angularAxis,d=h.vangles,g=d?l:i.isPtInsideSector,v=t.maxHoverDistance,m=p._period||2*Math.PI,y=Math.abs(f.g2p(Math.sqrt(e*e+r*r))),x=Math.atan2(r,e);f.range[0]>f.range[1]&&(x+=Math.PI);if(n.getClosest(c,function(t){return g(y,x,[t.rp0,t.rp1],[t.thetag0,t.thetag1],d)?v+Math.min(1,Math.abs(t.thetag1-t.thetag0)/m)-1+(t.rp1-y)/(t.rp1-t.rp0)-1:1/0},t),!1!==t.index){var b=c[t.index];t.x0=t.x1=b.ct[0],t.y0=t.y1=b.ct[1];var _=i.extendFlat({},b,{r:b.s,theta:b.p});return o(b,u,t),s(_,u,h,t),t.hovertemplate=u.hovertemplate,t.color=a(u,b),t.xLabelVal=t.yLabelVal=void 0,b.s<0&&(t.idealAlign=\"left\"),[t]}}},{\"../../components/fx\":632,\"../../lib\":719,\"../../plots/polar/helpers\":830,\"../bar/hover\":863,\"../scatterpolar/hover\":1182}],876:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"barpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"bar\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),colorbar:t(\"../scatter/marker_colorbar\"),style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),meta:{}}},{\"../../plots/polar\":831,\"../bar/select\":868,\"../bar/style\":870,\"../scatter/marker_colorbar\":1129,\"./attributes\":872,\"./calc\":873,\"./defaults\":874,\"./hover\":875,\"./layout_attributes\":877,\"./layout_defaults\":878,\"./plot\":879}],877:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},bargap:{valType:\"number\",dflt:.1,min:0,max:1,editType:\"calc\"}}},{}],878:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a,o={};function s(r,o){return n.coerce(t[a]||{},e[a],i,r,o)}for(var l=0;l<r.length;l++){var c=r[l];\"barpolar\"===c.type&&!0===c.visible&&(o[a=c.subplot]||(s(\"barmode\"),s(\"bargap\"),o[a]=1))}}},{\"../../lib\":719,\"./layout_attributes\":877}],879:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../components/drawing\"),s=t(\"../../plots/polar/helpers\");e.exports=function(t,e,r){var l=e.xaxis,c=e.yaxis,u=e.radialAxis,h=e.angularAxis,f=function(t){var e=t.cxx,r=t.cyy;if(t.vangles)return function(n,i,o,l){var c,u;a.angleDelta(o,l)>0?(c=o,u=l):(c=l,u=o);var h=s.findEnclosingVertexAngles(c,t.vangles)[0],f=s.findEnclosingVertexAngles(u,t.vangles)[1],p=[h,(c+u)/2,f];return s.pathPolygonAnnulus(n,i,c,u,p,e,r)};return function(t,n,i,o){return a.pathAnnulus(t,n,i,o,e,r)}}(e),p=e.layers.frontplot.select(\"g.barlayer\");a.makeTraceGroups(p,r,\"trace bars\").each(function(){var r=n.select(this),s=a.ensureSingle(r,\"g\",\"points\").selectAll(\"g.point\").data(a.identity);s.enter().append(\"g\").style(\"vector-effect\",\"non-scaling-stroke\").style(\"stroke-miterlimit\",2).classed(\"point\",!0),s.exit().remove(),s.each(function(t){var e,r=n.select(this),o=t.rp0=u.c2p(t.s0),s=t.rp1=u.c2p(t.s1),p=t.thetag0=h.c2g(t.p0),d=t.thetag1=h.c2g(t.p1);if(i(o)&&i(s)&&i(p)&&i(d)&&o!==s&&p!==d){var g=u.c2g(t.s1),v=(p+d)/2;t.ct=[l.c2p(g*Math.cos(v)),c.c2p(g*Math.sin(v))],e=f(o,s,p,d)}else e=\"M0,0Z\";a.ensureSingle(r,\"path\").attr(\"d\",e)}),o.setClipUrl(r,e._hasClipOnAxisFalse?e.clipIds.forTraces:null,t)})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../plots/polar/helpers\":830,d3:163,\"fast-isnumeric\":225}],880:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../bar/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../lib/extend\").extendFlat,l=n.marker,c=l.line;e.exports={y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},y0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},name:{valType:\"string\",editType:\"calc+clearAxisTypes\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),hovertemplate:o({}),whiskerwidth:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"calc\"},notched:{valType:\"boolean\",editType:\"calc\"},notchwidth:{valType:\"number\",min:0,max:.5,dflt:.25,editType:\"calc\"},boxpoints:{valType:\"enumerated\",values:[\"all\",\"outliers\",\"suspectedoutliers\",!1],dflt:\"outliers\",editType:\"calc\"},boxmean:{valType:\"enumerated\",values:[!0,\"sd\",!1],dflt:!1,editType:\"calc\"},jitter:{valType:\"number\",min:0,max:1,editType:\"calc\"},pointpos:{valType:\"number\",min:-2,max:2,editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},width:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},marker:{outliercolor:{valType:\"color\",dflt:\"rgba(0, 0, 0, 0)\",editType:\"style\"},symbol:s({},l.symbol,{arrayOk:!1,editType:\"plot\"}),opacity:s({},l.opacity,{arrayOk:!1,dflt:1,editType:\"style\"}),size:s({},l.size,{arrayOk:!1,editType:\"calc\"}),color:s({},l.color,{arrayOk:!1,editType:\"style\"}),line:{color:s({},c.color,{arrayOk:!1,dflt:a.defaultLine,editType:\"style\"}),width:s({},c.width,{arrayOk:!1,dflt:0,editType:\"style\"}),outliercolor:{valType:\"color\",editType:\"style\"},outlierwidth:{valType:\"number\",min:0,dflt:1,editType:\"style\"},editType:\"style\"},editType:\"plot\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,offsetgroup:i.offsetgroup,alignmentgroup:i.alignmentgroup,selected:{marker:n.selected.marker,editType:\"style\"},unselected:{marker:n.unselected.marker,editType:\"style\"},hoveron:{valType:\"flaglist\",flags:[\"boxes\",\"points\"],dflt:\"boxes+points\",editType:\"style\"}}},{\"../../components/color/attributes\":592,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../bar/attributes\":857,\"../scatter/attributes\":1112}],881:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=i._,o=t(\"../../plots/cartesian/axes\");function s(t,e,r){var n={text:\"tx\",hovertext:\"htx\"};for(var i in n)Array.isArray(e[i])&&(t[n[i]]=e[i][r])}function l(t,e){return t.v-e.v}function c(t){return t.v}e.exports=function(t,e){var r,u,h,f,p,d=t._fullLayout,g=o.getFromId(t,e.xaxis||\"x\"),v=o.getFromId(t,e.yaxis||\"y\"),m=[],y=\"violin\"===e.type?\"_numViolins\":\"_numBoxes\";\"h\"===e.orientation?(u=g,h=\"x\",f=v,p=\"y\"):(u=v,h=\"y\",f=g,p=\"x\");var x,b=u.makeCalcdata(e,h),_=function(t,e,r,a,o){if(e in t)return r.makeCalcdata(t,e);var s;s=e+\"0\"in t?t[e+\"0\"]:\"name\"in t&&(\"category\"===r.type||n(t.name)&&-1!==[\"linear\",\"log\"].indexOf(r.type)||i.isDateTime(t.name)&&\"date\"===r.type)?t.name:o;var l=\"multicategory\"===r.type?r.r2c_just_indices(s):r.d2c(s,0,t[e+\"calendar\"]);return a.map(function(){return l})}(e,p,f,b,d[y]),w=i.distinctVals(_),k=w.vals,T=w.minDiff/2,A=function(t,e){for(var r=t.length,n=new Array(r+1),i=0;i<r;i++)n[i]=t[i]-e;return n[r]=t[r-1]+e,n}(k,T),M=k.length,S=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=[];return e}(M);for(r=0;r<e._length;r++){var E=b[r];if(n(E)){var C=i.findBin(_[r],A);if(C>=0&&C<M){var L={v:E,i:r};s(L,e,r),S[C].push(L)}}}var P=\"all\"===(e.boxpoints||e.points)?i.identity:function(t){return t.v<x.lf||t.v>x.uf};for(r=0;r<M;r++)if(S[r].length>0){var O=S[r].sort(l),z=O.map(c),I=z.length;(x={}).pos=k[r],x.pts=O,x[p]=x.pos,x[h]=x.pts.map(function(t){return t.v}),x.min=z[0],x.max=z[I-1],x.mean=i.mean(z,I),x.sd=i.stdev(z,I,x.mean),x.q1=i.interp(z,.25),x.med=i.interp(z,.5),x.q3=i.interp(z,.75),x.lf=Math.min(x.q1,z[Math.min(i.findBin(2.5*x.q1-1.5*x.q3,z,!0)+1,I-1)]),x.uf=Math.max(x.q3,z[Math.max(i.findBin(2.5*x.q3-1.5*x.q1,z),0)]),x.lo=4*x.q1-3*x.q3,x.uo=4*x.q3-3*x.q1;var D=1.57*(x.q3-x.q1)/Math.sqrt(I);x.ln=x.med-D,x.un=x.med+D,x.pts2=O.filter(P),m.push(x)}!function(t,e){if(i.isArrayOrTypedArray(e.selectedpoints))for(var r=0;r<t.length;r++){for(var n=t[r].pts||[],a={},o=0;o<n.length;o++)a[n[o].i]=o;i.tagSelected(n,e,a)}}(m,e);var R=o.findExtremes(u,b,{padded:!0});return e._extremes[u._id]=R,m.length>0?(m[0].t={num:d[y],dPos:T,posLetter:p,valLetter:h,labels:{med:a(t,\"median:\"),min:a(t,\"min:\"),q1:a(t,\"q1:\"),q3:a(t,\"q3:\"),max:a(t,\"max:\"),mean:\"sd\"===e.boxmean?a(t,\"mean \\xb1 \\u03c3:\"):a(t,\"mean:\"),lf:a(t,\"lower fence:\"),uf:a(t,\"upper fence:\")}},d[y]++,m):[{t:{empty:!0}}]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"fast-isnumeric\":225}],882:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\").getAxisGroup,o=[\"v\",\"h\"];function s(t,e,r,o){var s,l,c,u=e.calcdata,h=e._fullLayout,f=o._id,p=f.charAt(0),d=[],g=0;for(s=0;s<r.length;s++)for(c=u[r[s]],l=0;l<c.length;l++)d.push(c[l].pos),g+=(c[l].pts2||[]).length;if(d.length){var v=i.distinctVals(d),m=v.minDiff/2;n.minDtick(o,v.minDiff,v.vals[0],!0);var y=h[\"violin\"===t?\"_numViolins\":\"_numBoxes\"],x=\"group\"===h[t+\"mode\"]&&y>1,b=1-h[t+\"gap\"],_=1-h[t+\"groupgap\"];for(s=0;s<r.length;s++){var w,k,T,A,M,S,E=(c=u[r[s]])[0].trace,C=c[0].t,L=E.width,P=E.side;if(L)w=k=A=L/2,T=0;else if(w=m,x){var O=a(h,o._id)+E.orientation,z=(h._alignmentOpts[O]||{})[E.alignmentgroup]||{},I=Object.keys(z.offsetGroups||{}).length,D=I||y;k=w*b*_/D,T=2*w*(((I?E._offsetIndex:C.num)+.5)/D-.5)*b,A=w*b/D}else k=w*b*_,T=0,A=w;C.dPos=w,C.bPos=T,C.bdPos=k,C.wHover=A;var R,F,B,N,j,U,V=T+k,q=Boolean(L);if(\"positive\"===P?(M=w*(L?1:.5),R=V,S=R=T):\"negative\"===P?(M=R=T,S=w*(L?1:.5),F=V):(M=S=w,R=F=V),(E.boxpoints||E.points)&&g>0){var H=E.pointpos,G=E.jitter,Y=E.marker.size/2,W=0;H+G>=0&&((W=V*(H+G))>M?(q=!0,j=Y,B=W):W>R&&(j=Y,B=M)),W<=M&&(B=M);var X=0;H-G<=0&&((X=-V*(H-G))>S?(q=!0,U=Y,N=X):X>F&&(U=Y,N=S)),X<=S&&(N=S)}else B=M,N=S;var Z=new Array(c.length);for(l=0;l<c.length;l++)Z[l]=c[l].pos;E._extremes[f]=n.findExtremes(o,Z,{padded:q,vpadminus:N,vpadplus:B,ppadminus:{x:U,y:j}[p],ppadplus:{x:j,y:U}[p]})}}}e.exports={crossTraceCalc:function(t,e){for(var r=t.calcdata,n=e.xaxis,i=e.yaxis,a=0;a<o.length;a++){for(var l=o[a],c=\"h\"===l?i:n,u=[],h=0;h<r.length;h++){var f=r[h],p=f[0].t,d=f[0].trace;!0!==d.visible||\"box\"!==d.type&&\"candlestick\"!==d.type||p.empty||(d.orientation||\"v\")!==l||d.xaxis!==n._id||d.yaxis!==i._id||u.push(h)}s(\"box\",t,u,c)}},setPositionOffset:s}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_ids\":770}],883:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../bar/defaults\").handleGroupingDefaults,s=t(\"./attributes\");function l(t,e,r,a){var o,s,l=r(\"y\"),c=r(\"x\"),u=c&&c.length;if(l&&l.length)o=\"v\",u?s=Math.min(n.minRowLength(c),n.minRowLength(l)):(r(\"x0\"),s=n.minRowLength(l));else{if(!u)return void(e.visible=!1);o=\"h\",r(\"y0\"),s=n.minRowLength(c)}e._length=s,i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a),r(\"orientation\",o)}function c(t,e,r,i){var a=i.prefix,o=n.coerce2(t,e,s,\"marker.outliercolor\"),l=r(\"marker.line.outliercolor\"),c=r(a+\"points\",o||l?\"suspectedoutliers\":void 0);c?(r(\"jitter\",\"all\"===c?.3:0),r(\"pointpos\",\"all\"===c?-1.5:0),r(\"marker.symbol\"),r(\"marker.opacity\"),r(\"marker.size\"),r(\"marker.color\",e.line.color),r(\"marker.line.color\"),r(\"marker.line.width\"),\"suspectedoutliers\"===c&&(r(\"marker.line.outliercolor\",e.marker.color),r(\"marker.line.outlierwidth\")),r(\"selected.marker.color\"),r(\"unselected.marker.color\"),r(\"selected.marker.size\"),r(\"unselected.marker.size\"),r(\"text\"),r(\"hovertext\")):delete e.marker;var u=r(\"hoveron\");\"all\"!==u&&-1===u.indexOf(\"points\")||r(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,r)}e.exports={supplyDefaults:function(t,e,r,i){function o(r,i){return n.coerce(t,e,s,r,i)}l(t,e,o,i),!1!==e.visible&&(o(\"line.color\",(t.marker||{}).color||r),o(\"line.width\"),o(\"fillcolor\",a.addOpacity(e.line.color,.5)),o(\"whiskerwidth\"),o(\"boxmean\"),o(\"width\"),o(\"notched\",void 0!==t.notchwidth)&&o(\"notchwidth\"),c(t,e,o,{prefix:\"box\"}))},crossTraceDefaults:function(t,e){var r,i;function a(t){return n.coerce(i._input,i,s,t)}for(var l=0;l<t.length;l++){var c=(i=t[l]).type;\"box\"!==c&&\"violin\"!==c||(r=i._input,\"group\"===e[c+\"mode\"]&&o(r,i,e,a))}},handleSampleDefaults:l,handlePointsDefaults:c}},{\"../../components/color\":593,\"../../lib\":719,\"../../registry\":847,\"../bar/defaults\":861,\"./attributes\":880}],884:[function(t,e,r){\"use strict\";e.exports=function(t,e){return e.hoverOnBox&&(t.hoverOnBox=e.hoverOnBox),\"xVal\"in e&&(t.x=e.xVal),\"yVal\"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],885:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=i.fillText;function l(t,e,r,s){var l,c,u,h,f,p,d,g,v,m,y,x,b,_,w=t.cd,k=t.xa,T=t.ya,A=w[0].trace,M=w[0].t,S=\"violin\"===A.type,E=[],C=M.bdPos,L=M.wHover,P=function(t){return t.pos+M.bPos-p};S&&\"both\"!==A.side?(\"positive\"===A.side&&(v=function(t){var e=P(t);return a.inbox(e,e+L,m)},x=C,b=0),\"negative\"===A.side&&(v=function(t){var e=P(t);return a.inbox(e-L,e,m)},x=0,b=C)):(v=function(t){var e=P(t);return a.inbox(e-L,e+L,m)},x=b=C),_=S?function(t){return a.inbox(t.span[0]-f,t.span[1]-f,m)}:function(t){return a.inbox(t.min-f,t.max-f,m)},\"h\"===A.orientation?(f=e,p=r,d=_,g=v,l=\"y\",u=T,c=\"x\",h=k):(f=r,p=e,d=v,g=_,l=\"x\",u=k,c=\"y\",h=T);var O=Math.min(1,C/Math.abs(u.r2c(u.range[1])-u.r2c(u.range[0])));function z(t){return(d(t)+g(t))/2}m=t.maxHoverDistance-O,y=t.maxSpikeDistance-O;var I=a.getDistanceFunction(s,d,g,z);if(a.getClosest(w,I,t),!1===t.index)return[];var D=w[t.index],R=A.line.color,F=(A.marker||{}).color;o.opacity(R)&&A.line.width?t.color=R:o.opacity(F)&&A.boxpoints?t.color=F:t.color=A.fillcolor,t[l+\"0\"]=u.c2p(D.pos+M.bPos-b,!0),t[l+\"1\"]=u.c2p(D.pos+M.bPos+x,!0),t[l+\"LabelVal\"]=D.pos;var B=l+\"Spike\";t.spikeDistance=z(D)*y/m,t[B]=u.c2p(D.pos,!0);var N={},j=[\"med\",\"q1\",\"q3\",\"min\",\"max\"];(A.boxmean||(A.meanline||{}).visible)&&j.push(\"mean\"),(A.boxpoints||A.points)&&j.push(\"lf\",\"uf\");for(var U=0;U<j.length;U++){var V=j[U];if(V in D&&!(D[V]in N)){N[D[V]]=!0;var q=D[V],H=h.c2p(q,!0),G=i.extendFlat({},t);G.attr=V,G[c+\"0\"]=G[c+\"1\"]=H,G[c+\"LabelVal\"]=q,G[c+\"Label\"]=(M.labels?M.labels[V]+\" \":\"\")+n.hoverLabelText(h,q),G.hoverOnBox=!0,\"mean\"===V&&\"sd\"in D&&\"sd\"===A.boxmean&&(G[c+\"err\"]=D.sd),t.name=\"\",t.spikeDistance=void 0,t[B]=void 0,G.hovertemplate=!1,E.push(G)}}return E}function c(t,e,r){for(var n,o,l,c=t.cd,u=t.xa,h=t.ya,f=c[0].trace,p=u.c2p(e),d=h.c2p(r),g=a.quadrature(function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(u.c2p(t.x)-p)-e,1-3/e)},function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(h.c2p(t.y)-d)-e,1-3/e)}),v=!1,m=0;m<c.length;m++){o=c[m];for(var y=0;y<(o.pts||[]).length;y++){var x=g(l=o.pts[y]);x<=t.distance&&(t.distance=x,v=[m,y])}}if(!v)return!1;l=(o=c[v[0]]).pts[v[1]];var b,_=u.c2p(l.x,!0),w=h.c2p(l.y,!0),k=l.mrc||1;return n=i.extendFlat({},t,{index:l.i,color:(f.marker||{}).color,name:f.name,x0:_-k,x1:_+k,y0:w-k,y1:w+k,spikeDistance:t.distance,hovertemplate:f.hovertemplate}),\"h\"===f.orientation?(b=h,n.xLabelVal=l.x,n.yLabelVal=o.pos):(b=u,n.xLabelVal=o.pos,n.yLabelVal=l.y),n[b._id.charAt(0)+\"Spike\"]=b.c2p(o.pos,!0),s(l,f,n),n}e.exports={hoverPoints:function(t,e,r,n){var i,a=t.cd[0].trace.hoveron,o=[];return-1!==a.indexOf(\"boxes\")&&(o=o.concat(l(t,e,r,n))),-1!==a.indexOf(\"points\")&&(i=c(t,e,r)),\"closest\"===n?i?[i]:o:i?(o.push(i),o):o},hoverOnBoxes:l,hoverOnPoints:c}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],886:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\").supplyLayoutDefaults,calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"box\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"boxLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":880,\"./calc\":881,\"./cross_trace_calc\":882,\"./defaults\":883,\"./event_data\":884,\"./hover\":885,\"./layout_attributes\":887,\"./layout_defaults\":888,\"./plot\":889,\"./select\":890,\"./style\":891}],887:[function(t,e,r){\"use strict\";e.exports={boxmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"overlay\",editType:\"calc\"},boxgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"},boxgroupgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"}}},{}],888:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./layout_attributes\");function o(t,e,r,i,a){for(var o=a+\"Layout\",s=!1,l=0;l<r.length;l++){var c=r[l];if(n.traceIs(c,o)){s=!0;break}}s&&(i(a+\"mode\"),i(a+\"gap\"),i(a+\"groupgap\"))}e.exports={supplyLayoutDefaults:function(t,e,r){o(0,0,r,function(r,n){return i.coerce(t,e,a,r,n)},\"box\")},_supply:o}},{\"../../lib\":719,\"../../registry\":847,\"./layout_attributes\":887}],889:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=5,s=.01;function l(t,e,r,a){var o,s,l=e.pos,c=e.val,u=a.bPos,h=a.wdPos||0,f=a.bPosPxOffset||0,p=r.whiskerwidth||0,d=r.notched||!1,g=d?1-2*r.notchwidth:1;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var v=t.selectAll(\"path.box\").data(\"violin\"!==r.type||r.box.visible?i.identity:[]);v.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"box\"),v.exit().remove(),v.each(function(t){if(t.empty)return\"M0,0Z\";var e=t.pos,a=l.c2p(e+u,!0)+f,v=l.c2p(e+u-o,!0)+f,m=l.c2p(e+u+s,!0)+f,y=l.c2p(e+u-h,!0)+f,x=l.c2p(e+u+h,!0)+f,b=l.c2p(e+u-o*g,!0)+f,_=l.c2p(e+u+s*g,!0)+f,w=c.c2p(t.q1,!0),k=c.c2p(t.q3,!0),T=i.constrain(c.c2p(t.med,!0),Math.min(w,k)+1,Math.max(w,k)-1),A=void 0===t.lf||!1===r.boxpoints,M=c.c2p(A?t.min:t.lf,!0),S=c.c2p(A?t.max:t.uf,!0),E=c.c2p(t.ln,!0),C=c.c2p(t.un,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+T+\",\"+b+\"V\"+_+\"M\"+w+\",\"+v+\"V\"+m+(d?\"H\"+E+\"L\"+T+\",\"+_+\"L\"+C+\",\"+m:\"\")+\"H\"+k+\"V\"+v+(d?\"H\"+C+\"L\"+T+\",\"+b+\"L\"+E+\",\"+v:\"\")+\"ZM\"+w+\",\"+a+\"H\"+M+\"M\"+k+\",\"+a+\"H\"+S+(0===p?\"\":\"M\"+M+\",\"+y+\"V\"+x+\"M\"+S+\",\"+y+\"V\"+x)):n.select(this).attr(\"d\",\"M\"+b+\",\"+T+\"H\"+_+\"M\"+v+\",\"+w+\"H\"+m+(d?\"V\"+E+\"L\"+_+\",\"+T+\"L\"+m+\",\"+C:\"\")+\"V\"+k+\"H\"+v+(d?\"V\"+C+\"L\"+b+\",\"+T+\"L\"+v+\",\"+E:\"\")+\"ZM\"+a+\",\"+w+\"V\"+M+\"M\"+a+\",\"+k+\"V\"+S+(0===p?\"\":\"M\"+y+\",\"+M+\"H\"+x+\"M\"+y+\",\"+S+\"H\"+x))})}function c(t,e,r,n){var l=e.x,c=e.y,u=n.bdPos,h=n.bPos,f=r.boxpoints||r.points;i.seedPseudoRandom();var p=t.selectAll(\"g.points\").data(f?function(t){return t.forEach(function(t){t.t=n,t.trace=r}),t}:[]);p.enter().append(\"g\").attr(\"class\",\"points\"),p.exit().remove();var d=p.selectAll(\"path\").data(function(t){var e,n,a=t.pts2,l=Math.max((t.max-t.min)/10,t.q3-t.q1),c=1e-9*l,p=l*s,d=[],g=0;if(r.jitter){if(0===l)for(g=1,d=new Array(a.length),e=0;e<a.length;e++)d[e]=1;else for(e=0;e<a.length;e++){var v=Math.max(0,e-o),m=a[v].v,y=Math.min(a.length-1,e+o),x=a[y].v;\"all\"!==f&&(a[e].v<t.lf?x=Math.min(x,t.lf):m=Math.max(m,t.uf));var b=Math.sqrt(p*(y-v)/(x-m+c))||0;b=i.constrain(Math.abs(b),0,1),d.push(b),g=Math.max(b,g)}n=2*r.jitter/(g||1)}for(e=0;e<a.length;e++){var _=a[e],w=_.v,k=r.jitter?n*d[e]*(i.pseudoRandom()-.5):0,T=t.pos+h+u*(r.pointpos+k);\"h\"===r.orientation?(_.y=T,_.x=w):(_.x=T,_.y=w),\"suspectedoutliers\"===f&&w<t.uo&&w>t.lo&&(_.so=!0)}return a});d.enter().append(\"path\").classed(\"point\",!0),d.exit().remove(),d.call(a.translatePoints,l,c)}function u(t,e,r,a){var o,s,l=e.pos,c=e.val,u=a.bPos,h=a.bPosPxOffset||0,f=r.boxmean||(r.meanline||{}).visible;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var p=t.selectAll(\"path.mean\").data(\"box\"===r.type&&r.boxmean||\"violin\"===r.type&&r.box.visible&&r.meanline.visible?i.identity:[]);p.enter().append(\"path\").attr(\"class\",\"mean\").style({fill:\"none\",\"vector-effect\":\"non-scaling-stroke\"}),p.exit().remove(),p.each(function(t){var e=l.c2p(t.pos+u,!0)+h,i=l.c2p(t.pos+u-o,!0)+h,a=l.c2p(t.pos+u+s,!0)+h,p=c.c2p(t.mean,!0),d=c.c2p(t.mean-t.sd,!0),g=c.c2p(t.mean+t.sd,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+p+\",\"+i+\"V\"+a+(\"sd\"===f?\"m0,0L\"+d+\",\"+e+\"L\"+p+\",\"+i+\"L\"+g+\",\"+e+\"Z\":\"\")):n.select(this).attr(\"d\",\"M\"+i+\",\"+p+\"H\"+a+(\"sd\"===f?\"m0,0L\"+e+\",\"+d+\"L\"+i+\",\"+p+\"L\"+e+\",\"+g+\"Z\":\"\"))})}e.exports={plot:function(t,e,r,a){var o=e.xaxis,s=e.yaxis;i.makeTraceGroups(a,r,\"trace boxes\").each(function(t){var e,r,i=n.select(this),a=t[0],h=a.t,f=a.trace;h.wdPos=h.bdPos*f.whiskerwidth,!0!==f.visible||h.empty?i.remove():(\"h\"===f.orientation?(e=s,r=o):(e=o,r=s),l(i,{pos:e,val:r},f,h),c(i,{x:o,y:s},f,h),u(i,{pos:e,val:r},f,h))})},plotBoxAndWhiskers:l,plotPoints:c,plotBoxMean:u}},{\"../../components/drawing\":614,\"../../lib\":719,d3:163}],890:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i=t.cd,a=t.xaxis,o=t.yaxis,s=[];if(!1===e)for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++)i[r].pts[n].selected=0;else for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++){var l=i[r].pts[n],c=a.c2p(l.x),u=o.c2p(l.y);e.contains([c,u],null,l.i,t)?(s.push({pointNumber:l.i,x:a.c2d(l.x),y:o.c2d(l.y)}),l.selected=1):l.selected=0}return s}},{}],891:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\");e.exports={style:function(t,e,r){var o=r||n.select(t).selectAll(\"g.trace.boxes\");o.style(\"opacity\",function(t){return t[0].trace.opacity}),o.each(function(e){var r=n.select(this),o=e[0].trace,s=o.line.width;function l(t,e,r,n){t.style(\"stroke-width\",e+\"px\").call(i.stroke,r).call(i.fill,n)}var c=r.selectAll(\"path.box\");if(\"candlestick\"===o.type)c.each(function(t){if(!t.empty){var e=n.select(this),r=o[t.dir];l(e,r.line.width,r.line.color,r.fillcolor),e.style(\"opacity\",o.selectedpoints&&!t.selected?.3:1)}});else{l(c,s,o.line.color,o.fillcolor),r.selectAll(\"path.mean\").style({\"stroke-width\":s,\"stroke-dasharray\":2*s+\"px,\"+s+\"px\"}).call(i.stroke,o.line.color);var u=r.selectAll(\"path.point\");a.pointStyle(u,o,t)}})},styleOnSelect:function(t,e,r){var n=e[0].trace,i=r.selectAll(\"path.point\");n.selectedpoints?a.selectedPointStyle(i,n):a.pointStyle(i,n,t)}}},{\"../../components/color\":593,\"../../components/drawing\":614,d3:163}],892:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../ohlc/attributes\"),a=t(\"../box/attributes\");function o(t){return{line:{color:n({},a.line.color,{dflt:t}),width:a.line.width,editType:\"style\"},fillcolor:a.fillcolor,editType:\"style\"}}e.exports={x:i.x,open:i.open,high:i.high,low:i.low,close:i.close,line:{width:n({},a.line.width,{}),editType:\"style\"},increasing:o(i.increasing.line.color.dflt),decreasing:o(i.decreasing.line.color.dflt),text:i.text,hovertext:i.hovertext,whiskerwidth:n({},a.whiskerwidth,{dflt:0}),hoverlabel:i.hoverlabel}},{\"../../lib\":719,\"../box/attributes\":880,\"../ohlc/attributes\":1058}],893:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../ohlc/calc\").calcCommon;function o(t,e,r,n){return{min:r,q1:Math.min(t,n),med:n,q3:Math.max(t,n),max:e}}e.exports=function(t,e){var r=t._fullLayout,s=i.getFromId(t,e.xaxis),l=i.getFromId(t,e.yaxis),c=s.makeCalcdata(e,\"x\"),u=a(t,e,c,l,o);return u.length?(n.extendFlat(u[0].t,{num:r._numBoxes,dPos:n.distinctVals(c).minDiff/2,posLetter:\"x\",valLetter:\"y\"}),r._numBoxes++,u):[{t:{empty:!0}}]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../ohlc/calc\":1059}],894:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../ohlc/ohlc_defaults\"),o=t(\"./attributes\");function s(t,e,r,n){var a=r(n+\".line.color\");r(n+\".line.width\",e.line.width),r(n+\".fillcolor\",i.addOpacity(a,.5))}e.exports=function(t,e,r,i){function l(r,i){return n.coerce(t,e,o,r,i)}a(t,e,l,i)?(l(\"line.width\"),s(t,e,l,\"increasing\"),s(t,e,l,\"decreasing\"),l(\"text\"),l(\"hovertext\"),l(\"whiskerwidth\"),i._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../components/color\":593,\"../../lib\":719,\"../ohlc/ohlc_defaults\":1063,\"./attributes\":892}],895:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"candlestick\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\",\"candlestick\",\"boxLayout\"],meta:{},attributes:t(\"./attributes\"),layoutAttributes:t(\"../box/layout_attributes\"),supplyLayoutDefaults:t(\"../box/layout_defaults\").supplyLayoutDefaults,crossTraceCalc:t(\"../box/cross_trace_calc\").crossTraceCalc,supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"../box/plot\").plot,layerName:\"boxlayer\",style:t(\"../box/style\").style,hoverPoints:t(\"../ohlc/hover\").hoverPoints,selectPoints:t(\"../ohlc/select\")}},{\"../../plots/cartesian\":778,\"../box/cross_trace_calc\":882,\"../box/layout_attributes\":887,\"../box/layout_defaults\":888,\"../box/plot\":889,\"../box/style\":891,\"../ohlc/hover\":1061,\"../ohlc/select\":1065,\"./attributes\":892,\"./calc\":893,\"./defaults\":894}],896:[function(t,e,r){\"use strict\";var n=t(\"./axis_defaults\"),i=t(\"../../plot_api/plot_template\");e.exports=function(t,e,r,a,o){a(\"a\")||(a(\"da\"),a(\"a0\")),a(\"b\")||(a(\"db\"),a(\"b0\")),function(t,e,r,a){[\"aaxis\",\"baxis\"].forEach(function(o){var s=o.charAt(0),l=t[o]||{},c=i.newContainer(e,o),u={tickfont:\"x\",id:s+\"axis\",letter:s,font:e.font,name:o,data:t[s],calendar:e.calendar,dfltColor:a,bgColor:r.paper_bgcolor,fullLayout:r};n(l,c,u),c._categories=c._categories||[],t[o]||\"-\"===l.type||(t[o]={type:l.type})})}(t,e,r,o)}},{\"../../plot_api/plot_template\":757,\"./axis_defaults\":901}],897:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t){return function t(e,r){if(!n(e)||r>=10)return null;var i=1/0;var a=-1/0;var o=e.length;for(var s=0;s<o;s++){var l=e[s];if(n(l)){var c=t(l,r+1);c&&(i=Math.min(c[0],i),a=Math.max(c[1],a))}else i=Math.min(l,i),a=Math.max(l,a)}return[i,a]}(t,0)}},{\"../../lib\":719}],898:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./axis_attributes\"),a=t(\"../../components/color/attributes\"),o=n({editType:\"calc\"});o.family.dflt='\"Open Sans\", verdana, arial, sans-serif',o.size.dflt=12,o.color.dflt=a.defaultLine,e.exports={carpet:{valType:\"string\",editType:\"calc\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},a:{valType:\"data_array\",editType:\"calc\"},a0:{valType:\"number\",dflt:0,editType:\"calc\"},da:{valType:\"number\",dflt:1,editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},b0:{valType:\"number\",dflt:0,editType:\"calc\"},db:{valType:\"number\",dflt:1,editType:\"calc\"},cheaterslope:{valType:\"number\",dflt:1,editType:\"calc\"},aaxis:i,baxis:i,font:o,color:{valType:\"color\",dflt:a.defaultLine,editType:\"plot\"},transforms:void 0}},{\"../../components/color/attributes\":592,\"../../plots/font_attributes\":793,\"./axis_attributes\":900}],899:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,i){var a,o,s,l,c,u,h,f,p,d,g,v,m,y=n(r)?\"a\":\"b\",x=(\"a\"===y?t.aaxis:t.baxis).smoothing,b=\"a\"===y?t.a2i:t.b2j,_=\"a\"===y?r:i,w=\"a\"===y?i:r,k=\"a\"===y?e.a.length:e.b.length,T=\"a\"===y?e.b.length:e.a.length,A=Math.floor(\"a\"===y?t.b2j(w):t.a2i(w)),M=\"a\"===y?function(e){return t.evalxy([],e,A)}:function(e){return t.evalxy([],A,e)};x&&(s=Math.max(0,Math.min(T-2,A)),l=A-s,o=\"a\"===y?function(e,r){return t.dxydi([],e,s,r,l)}:function(e,r){return t.dxydj([],s,e,l,r)});var S=b(_[0]),E=b(_[1]),C=S<E?1:-1,L=1e-8*(E-S),P=C>0?Math.floor:Math.ceil,O=C>0?Math.ceil:Math.floor,z=C>0?Math.min:Math.max,I=C>0?Math.max:Math.min,D=P(S+L),R=O(E-L),F=[[h=M(S)]];for(a=D;a*C<R*C;a+=C)c=[],g=I(S,a),m=(v=z(E,a+C))-g,u=Math.max(0,Math.min(k-2,Math.floor(.5*(g+v)))),f=M(v),x&&(p=o(u,g-u),d=o(u,v-u),c.push([h[0]+p[0]/3*m,h[1]+p[1]/3*m]),c.push([f[0]-d[0]/3*m,f[1]-d[1]/3*m])),c.push(f),F.push(c),h=f;return F}},{\"../../lib\":719}],900:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../plots/cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").TIME_FORMAT_LINK;e.exports={color:{valType:\"color\",editType:\"calc\"},smoothing:{valType:\"number\",dflt:1,min:0,max:1.3,editType:\"calc\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"calc\"},font:n({editType:\"calc\"}),offset:{valType:\"number\",dflt:10,editType:\"calc\"},editType:\"calc\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"date\",\"category\"],dflt:\"-\",editType:\"calc\"},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"calc\"},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"calc\"},range:{valType:\"info_array\",editType:\"calc\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}]},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cheatertype:{valType:\"enumerated\",values:[\"index\",\"value\"],dflt:\"value\",editType:\"calc\"},tickmode:{valType:\"enumerated\",values:[\"linear\",\"array\"],dflt:\"array\",editType:\"calc\"},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},tickvals:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},showticklabels:{valType:\"enumerated\",values:[\"start\",\"end\",\"both\",\"none\"],dflt:\"start\",editType:\"calc\"},tickfont:n({editType:\"calc\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"calc\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"calc\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"calc\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"calc\"},tickformatstops:o(a.tickformatstops,\"calc\",\"from-root\"),categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},labelpadding:{valType:\"integer\",dflt:10,editType:\"calc\"},labelprefix:{valType:\"string\",editType:\"calc\"},labelsuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showline:{valType:\"boolean\",dflt:!1,editType:\"calc\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"calc\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},gridcolor:{valType:\"color\",editType:\"calc\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},showgrid:{valType:\"boolean\",dflt:!0,editType:\"calc\"},minorgridcount:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},minorgridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},minorgridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"calc\"},startline:{valType:\"boolean\",editType:\"calc\"},startlinecolor:{valType:\"color\",editType:\"calc\"},startlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endline:{valType:\"boolean\",editType:\"calc\"},endlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endlinecolor:{valType:\"color\",editType:\"calc\"},tick0:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},dtick:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},arraytick0:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},arraydtick:{valType:\"integer\",min:1,dflt:1,editType:\"calc\"},_deprecated:{title:{valType:\"string\",editType:\"calc\"},titlefont:n({editType:\"calc\"}),titleoffset:{valType:\"number\",dflt:10,editType:\"calc\"}},editType:\"calc\"}},{\"../../components/color/attributes\":592,\"../../constants/docs\":690,\"../../plot_api/edit_types\":750,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/font_attributes\":793}],901:[function(t,e,r){\"use strict\";var n=t(\"./attributes\"),i=t(\"../../components/color\").addOpacity,a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/tick_value_defaults\"),l=t(\"../../plots/cartesian/tick_label_defaults\"),c=t(\"../../plots/cartesian/category_order_defaults\"),u=t(\"../../plots/cartesian/set_convert\"),h=t(\"../../plots/cartesian/axis_autotype\");e.exports=function(t,e,r){var f=r.letter,p=r.font||{},d=n[f+\"axis\"];function g(r,n){return o.coerce(t,e,d,r,n)}function v(r,n){return o.coerce2(t,e,d,r,n)}r.name&&(e._name=r.name,e._id=r.name);var m=g(\"type\");(\"-\"===m&&(r.data&&function(t,e){if(\"-\"!==t.type)return;var r=t._id.charAt(0),n=t[r+\"calendar\"];t.type=h(e,n)}(e,r.data),\"-\"===e.type?e.type=\"linear\":m=t.type=e.type),g(\"smoothing\"),g(\"cheatertype\"),g(\"showticklabels\"),g(\"labelprefix\",f+\" = \"),g(\"labelsuffix\"),g(\"showtickprefix\"),g(\"showticksuffix\"),g(\"separatethousands\"),g(\"tickformat\"),g(\"exponentformat\"),g(\"showexponent\"),g(\"categoryorder\"),g(\"tickmode\"),g(\"tickvals\"),g(\"ticktext\"),g(\"tick0\"),g(\"dtick\"),\"array\"===e.tickmode&&(g(\"arraytick0\"),g(\"arraydtick\")),g(\"labelpadding\"),e._hovertitle=f,\"date\"===m)&&a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",r.calendar);u(e,r.fullLayout),e.c2p=o.identity;var y=g(\"color\",r.dfltColor),x=y===t.color?y:p.color;g(\"title.text\")&&(o.coerceFont(g,\"title.font\",{family:p.family,size:Math.round(1.2*p.size),color:x}),g(\"title.offset\")),g(\"tickangle\"),g(\"autorange\",!e.isValidRange(t.range))&&g(\"rangemode\"),g(\"range\"),e.cleanRange(),g(\"fixedrange\"),s(t,e,g,m),l(t,e,g,m,r),c(t,e,g,{data:r.data,dataAttr:f});var b=v(\"gridcolor\",i(y,.3)),_=v(\"gridwidth\"),w=g(\"showgrid\");w||(delete e.gridcolor,delete e.gridwidth);var k=v(\"startlinecolor\",y),T=v(\"startlinewidth\",_);g(\"startline\",e.showgrid||!!k||!!T)||(delete e.startlinecolor,delete e.startlinewidth);var A=v(\"endlinecolor\",y),M=v(\"endlinewidth\",_);return g(\"endline\",e.showgrid||!!A||!!M)||(delete e.endlinecolor,delete e.endlinewidth),w?(g(\"minorgridcount\"),g(\"minorgridwidth\",_),g(\"minorgridcolor\",i(b,.06)),e.minorgridcount||(delete e.minorgridwidth,delete e.minorgridcolor)):(delete e.gridcolor,delete e.gridWidth),\"none\"===e.showticklabels&&(delete e.tickfont,delete e.tickangle,delete e.showexponent,delete e.exponentformat,delete e.tickformat,delete e.showticksuffix,delete e.showtickprefix),e.showticksuffix||delete e.ticksuffix,e.showtickprefix||delete e.tickprefix,g(\"tickmode\"),e}},{\"../../components/color\":593,\"../../lib\":719,\"../../plots/cartesian/axis_autotype\":768,\"../../plots/cartesian/category_order_defaults\":771,\"../../plots/cartesian/set_convert\":785,\"../../plots/cartesian/tick_label_defaults\":786,\"../../plots/cartesian/tick_value_defaults\":788,\"../../registry\":847,\"./attributes\":898}],902:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\").isArray1D,a=t(\"./cheater_basis\"),o=t(\"./array_minmax\"),s=t(\"./calc_gridlines\"),l=t(\"./calc_labels\"),c=t(\"./calc_clippath\"),u=t(\"../heatmap/clean_2d_array\"),h=t(\"./smooth_fill_2d_array\"),f=t(\"../heatmap/convert_column_xyz\"),p=t(\"./set_convert\");e.exports=function(t,e){var r=n.getFromId(t,e.xaxis),d=n.getFromId(t,e.yaxis),g=e.aaxis,v=e.baxis,m=e.x,y=e.y,x=[];m&&i(m)&&x.push(\"x\"),y&&i(y)&&x.push(\"y\"),x.length&&f(e,g,v,\"a\",\"b\",x);var b=e._a=e._a||e.a,_=e._b=e._b||e.b;m=e._x||e.x,y=e._y||e.y;var w={};if(e._cheater){var k=\"index\"===g.cheatertype?b.length:b,T=\"index\"===v.cheatertype?_.length:_;m=a(k,T,e.cheaterslope)}e._x=m=u(m),e._y=y=u(y),h(m,b,_),h(y,b,_),p(e),e.setScale();var A=o(m),M=o(y),S=.5*(A[1]-A[0]),E=.5*(A[1]+A[0]),C=.5*(M[1]-M[0]),L=.5*(M[1]+M[0]);return A=[E-1.3*S,E+1.3*S],M=[L-1.3*C,L+1.3*C],e._extremes[r._id]=n.findExtremes(r,A,{padded:!0}),e._extremes[d._id]=n.findExtremes(d,M,{padded:!0}),s(e,\"a\",\"b\"),s(e,\"b\",\"a\"),l(e,g),l(e,v),w.clipsegments=c(e._xctrl,e._yctrl,g,v),w.x=m,w.y=y,w.a=b,w.b=_,[w]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../heatmap/clean_2d_array\":1003,\"../heatmap/convert_column_xyz\":1005,\"./array_minmax\":897,\"./calc_clippath\":903,\"./calc_gridlines\":904,\"./calc_labels\":905,\"./cheater_basis\":907,\"./set_convert\":920,\"./smooth_fill_2d_array\":921}],903:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a,o,s=[],l=!!r.smoothing,c=!!n.smoothing,u=t[0].length-1,h=t.length-1;for(i=0,a=[],o=[];i<=u;i++)a[i]=t[0][i],o[i]=e[0][i];for(s.push({x:a,y:o,bicubic:l}),i=0,a=[],o=[];i<=h;i++)a[i]=t[i][u],o[i]=e[i][u];for(s.push({x:a,y:o,bicubic:c}),i=u,a=[],o=[];i>=0;i--)a[u-i]=t[h][i],o[u-i]=e[h][i];for(s.push({x:a,y:o,bicubic:l}),i=h,a=[],o=[];i>=0;i--)a[h-i]=t[i][0],o[h-i]=e[i][0];return s.push({x:a,y:o,bicubic:c}),s}},{}],904:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e,r){var a,o,s,l,c,u,h,f,p,d,g,v,m,y,x=t[\"_\"+e],b=t[e+\"axis\"],_=b._gridlines=[],w=b._minorgridlines=[],k=b._boundarylines=[],T=t[\"_\"+r],A=t[r+\"axis\"];\"array\"===b.tickmode&&(b.tickvals=x.slice());var M=t._xctrl,S=t._yctrl,E=M[0].length,C=M.length,L=t._a.length,P=t._b.length;n.prepTicks(b),\"array\"===b.tickmode&&delete b.tickvals;var O=b.smoothing?3:1;function z(n){var i,a,o,s,l,c,u,h,p,d,g,v,m=[],y=[],x={};if(\"b\"===e)for(a=t.b2j(n),o=Math.floor(Math.max(0,Math.min(P-2,a))),s=a-o,x.length=P,x.crossLength=L,x.xy=function(e){return t.evalxy([],e,a)},x.dxy=function(e,r){return t.dxydi([],e,o,r,s)},i=0;i<L;i++)c=Math.min(L-2,i),u=i-c,h=t.evalxy([],i,a),A.smoothing&&i>0&&(p=t.dxydi([],i-1,o,0,s),m.push(l[0]+p[0]/3),y.push(l[1]+p[1]/3),d=t.dxydi([],i-1,o,1,s),m.push(h[0]-d[0]/3),y.push(h[1]-d[1]/3)),m.push(h[0]),y.push(h[1]),l=h;else for(i=t.a2i(n),c=Math.floor(Math.max(0,Math.min(L-2,i))),u=i-c,x.length=L,x.crossLength=P,x.xy=function(e){return t.evalxy([],i,e)},x.dxy=function(e,r){return t.dxydj([],c,e,u,r)},a=0;a<P;a++)o=Math.min(P-2,a),s=a-o,h=t.evalxy([],i,a),A.smoothing&&a>0&&(g=t.dxydj([],c,a-1,u,0),m.push(l[0]+g[0]/3),y.push(l[1]+g[1]/3),v=t.dxydj([],c,a-1,u,1),m.push(h[0]-v[0]/3),y.push(h[1]-v[1]/3)),m.push(h[0]),y.push(h[1]),l=h;return x.axisLetter=e,x.axis=b,x.crossAxis=A,x.value=n,x.constvar=r,x.index=f,x.x=m,x.y=y,x.smoothing=A.smoothing,x}function I(n){var i,a,o,s,l,c=[],u=[],h={};if(h.length=x.length,h.crossLength=T.length,\"b\"===e)for(o=Math.max(0,Math.min(P-2,n)),l=Math.min(1,Math.max(0,n-o)),h.xy=function(e){return t.evalxy([],e,n)},h.dxy=function(e,r){return t.dxydi([],e,o,r,l)},i=0;i<E;i++)c[i]=M[n*O][i],u[i]=S[n*O][i];else for(a=Math.max(0,Math.min(L-2,n)),s=Math.min(1,Math.max(0,n-a)),h.xy=function(e){return t.evalxy([],n,e)},h.dxy=function(e,r){return t.dxydj([],a,e,s,r)},i=0;i<C;i++)c[i]=M[i][n*O],u[i]=S[i][n*O];return h.axisLetter=e,h.axis=b,h.crossAxis=A,h.value=x[n],h.constvar=r,h.index=n,h.x=c,h.y=u,h.smoothing=A.smoothing,h}if(\"array\"===b.tickmode){for(l=5e-15,u=(c=[Math.floor((x.length-1-b.arraytick0)/b.arraydtick*(1+l)),Math.ceil(-b.arraytick0/b.arraydtick/(1+l))].sort(function(t,e){return t-e}))[0]-1,h=c[1]+1,f=u;f<h;f++)(o=b.arraytick0+b.arraydtick*f)<0||o>x.length-1||_.push(i(I(o),{color:b.gridcolor,width:b.gridwidth}));for(f=u;f<h;f++)if(s=b.arraytick0+b.arraydtick*f,g=Math.min(s+b.arraydtick,x.length-1),!(s<0||s>x.length-1||g<0||g>x.length-1))for(v=x[s],m=x[g],a=0;a<b.minorgridcount;a++)(y=g-s)<=0||(d=v+(m-v)*(a+1)/(b.minorgridcount+1)*(b.arraydtick/y))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&k.push(i(I(0),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&k.push(i(I(x.length-1),{color:b.endlinecolor,width:b.endlinewidth}))}else{for(l=5e-15,u=(c=[Math.floor((x[x.length-1]-b.tick0)/b.dtick*(1+l)),Math.ceil((x[0]-b.tick0)/b.dtick/(1+l))].sort(function(t,e){return t-e}))[0],h=c[1],f=u;f<=h;f++)p=b.tick0+b.dtick*f,_.push(i(z(p),{color:b.gridcolor,width:b.gridwidth}));for(f=u-1;f<h+1;f++)for(p=b.tick0+b.dtick*f,a=0;a<b.minorgridcount;a++)(d=p+b.dtick*(a+1)/(b.minorgridcount+1))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&k.push(i(z(x[0]),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&k.push(i(z(x[x.length-1]),{color:b.endlinecolor,width:b.endlinewidth}))}}},{\"../../lib/extend\":710,\"../../plots/cartesian/axes\":767}],905:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e){var r,a,o,s=e._labels=[],l=e._gridlines;for(r=0;r<l.length;r++)o=l[r],-1!==[\"start\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{prefix:void 0,suffix:void 0,endAnchor:!0,xy:o.xy(0),dxy:o.dxy(0,0),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a)),-1!==[\"end\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{endAnchor:!1,xy:o.xy(o.crossLength-1),dxy:o.dxy(o.crossLength-2,1),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a))}},{\"../../lib/extend\":710,\"../../plots/cartesian/axes\":767}],906:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=t[0]-e[0],a=t[1]-e[1],o=r[0]-e[0],s=r[1]-e[1],l=Math.pow(i*i+a*a,.25),c=Math.pow(o*o+s*s,.25),u=(c*c*i-l*l*o)*n,h=(c*c*a-l*l*s)*n,f=c*(l+c)*3,p=l*(l+c)*3;return[[e[0]+(f&&u/f),e[1]+(f&&h/f)],[e[0]-(p&&u/p),e[1]-(p&&h/p)]]}},{}],907:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i,a,o,s,l,c,u=[],h=n(t)?t.length:t,f=n(e)?e.length:e,p=n(t)?t:null,d=n(e)?e:null;p&&(o=(p.length-1)/(p[p.length-1]-p[0])/(h-1)),d&&(s=(d.length-1)/(d[d.length-1]-d[0])/(f-1));var g=1/0,v=-1/0;for(a=0;a<f;a++)for(u[a]=[],l=d?(d[a]-d[0])*s:a/(f-1),i=0;i<h;i++)c=(p?(p[i]-p[0])*o:i/(h-1))-l*r,g=Math.min(c,g),v=Math.max(c,v),u[a][i]=c;var m=1/(v-g),y=-g*m;for(a=0;a<f;a++)for(i=0;i<h;i++)u[a][i]=m*u[a][i]+y;return u}},{\"../../lib\":719}],908:[function(t,e,r){\"use strict\";var n=t(\"./catmull_rom\"),i=t(\"../../lib\").ensureArray;function a(t,e,r){var n=-.5*r[0]+1.5*e[0],i=-.5*r[1]+1.5*e[1];return[(2*n+t[0])/3,(2*i+t[1])/3]}e.exports=function(t,e,r,o,s,l){var c,u,h,f,p,d,g,v,m,y,x=r[0].length,b=r.length,_=s?3*x-2:x,w=l?3*b-2:b;for(t=i(t,w),e=i(e,w),h=0;h<w;h++)t[h]=i(t[h],_),e[h]=i(e[h],_);for(u=0,f=0;u<b;u++,f+=l?3:1)for(p=t[f],d=e[f],g=r[u],v=o[u],c=0,h=0;c<x;c++,h+=s?3:1)p[h]=g[c],d[h]=v[c];if(s)for(u=0,f=0;u<b;u++,f+=l?3:1){for(c=1,h=3;c<x-1;c++,h+=3)m=n([r[u][c-1],o[u][c-1]],[r[u][c],o[u][c]],[r[u][c+1],o[u][c+1]],s),t[f][h-1]=m[0][0],e[f][h-1]=m[0][1],t[f][h+1]=m[1][0],e[f][h+1]=m[1][1];y=a([t[f][0],e[f][0]],[t[f][2],e[f][2]],[t[f][3],e[f][3]]),t[f][1]=y[0],e[f][1]=y[1],y=a([t[f][_-1],e[f][_-1]],[t[f][_-3],e[f][_-3]],[t[f][_-4],e[f][_-4]]),t[f][_-2]=y[0],e[f][_-2]=y[1]}if(l)for(h=0;h<_;h++){for(f=3;f<w-3;f+=3)m=n([t[f-3][h],e[f-3][h]],[t[f][h],e[f][h]],[t[f+3][h],e[f+3][h]],l),t[f-1][h]=m[0][0],e[f-1][h]=m[0][1],t[f+1][h]=m[1][0],e[f+1][h]=m[1][1];y=a([t[0][h],e[0][h]],[t[2][h],e[2][h]],[t[3][h],e[3][h]]),t[1][h]=y[0],e[1][h]=y[1],y=a([t[w-1][h],e[w-1][h]],[t[w-3][h],e[w-3][h]],[t[w-4][h],e[w-4][h]]),t[w-2][h]=y[0],e[w-2][h]=y[1]}if(s&&l)for(f=1;f<w;f+=(f+1)%3==0?2:1){for(h=3;h<_-3;h+=3)m=n([t[f][h-3],e[f][h-3]],[t[f][h],e[f][h]],[t[f][h+3],e[f][h+3]],s),t[f][h-1]=.5*(t[f][h-1]+m[0][0]),e[f][h-1]=.5*(e[f][h-1]+m[0][1]),t[f][h+1]=.5*(t[f][h+1]+m[1][0]),e[f][h+1]=.5*(e[f][h+1]+m[1][1]);y=a([t[f][0],e[f][0]],[t[f][2],e[f][2]],[t[f][3],e[f][3]]),t[f][1]=.5*(t[f][1]+y[0]),e[f][1]=.5*(e[f][1]+y[1]),y=a([t[f][_-1],e[f][_-1]],[t[f][_-3],e[f][_-3]],[t[f][_-4],e[f][_-4]]),t[f][_-2]=.5*(t[f][_-2]+y[0]),e[f][_-2]=.5*(e[f][_-2]+y[1])}return[t,e]}},{\"../../lib\":719,\"./catmull_rom\":906}],909:[function(t,e,r){\"use strict\";e.exports={RELATIVE_CULL_TOLERANCE:1e-6}},{}],910:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3,n*=3;var f=i*i,p=1-i,d=p*p,g=p*i*2,v=-3*d,m=3*(d-g),y=3*(g-f),x=3*f,b=a*a,_=b*a,w=1-a,k=w*w,T=k*w;for(h=0;h<t.length;h++)o=v*(u=t[h])[n][r]+m*u[n][r+1]+y*u[n][r+2]+x*u[n][r+3],s=v*u[n+1][r]+m*u[n+1][r+1]+y*u[n+1][r+2]+x*u[n+1][r+3],l=v*u[n+2][r]+m*u[n+2][r+1]+y*u[n+2][r+2]+x*u[n+2][r+3],c=v*u[n+3][r]+m*u[n+3][r+1]+y*u[n+3][r+2]+x*u[n+3][r+3],e[h]=T*o+3*(k*a*s+w*b*l)+_*c;return e}:e?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),r*=3;var u=i*i,h=1-i,f=h*h,p=h*i*2,d=-3*f,g=3*(f-p),v=3*(p-u),m=3*u,y=1-a;for(l=0;l<t.length;l++)o=d*(c=t[l])[n][r]+g*c[n][r+1]+v*c[n][r+2]+m*c[n][r+3],s=d*c[n+1][r]+g*c[n+1][r+1]+v*c[n+1][r+2]+m*c[n+1][r+3],e[l]=y*o+a*s;return e}:r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),n*=3;var f=a*a,p=f*a,d=1-a,g=d*d,v=g*d;for(u=0;u<t.length;u++)o=(h=t[u])[n][r+1]-h[n][r],s=h[n+1][r+1]-h[n+1][r],l=h[n+2][r+1]-h[n+2][r],c=h[n+3][r+1]-h[n+3][r],e[u]=v*o+3*(g*a*s+d*f*l)+p*c;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-a;for(l=0;l<t.length;l++)o=(c=t[l])[n][r+1]-c[n][r],s=c[n+1][r+1]-c[n+1][r],e[l]=u*o+a*s;return e}}},{}],911:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3,n*=3;var f=i*i,p=f*i,d=1-i,g=d*d,v=g*d,m=a*a,y=1-a,x=y*y,b=y*a*2,_=-3*x,w=3*(x-b),k=3*(b-m),T=3*m;for(h=0;h<t.length;h++)o=_*(u=t[h])[n][r]+w*u[n+1][r]+k*u[n+2][r]+T*u[n+3][r],s=_*u[n][r+1]+w*u[n+1][r+1]+k*u[n+2][r+1]+T*u[n+3][r+1],l=_*u[n][r+2]+w*u[n+1][r+2]+k*u[n+2][r+2]+T*u[n+3][r+2],c=_*u[n][r+3]+w*u[n+1][r+3]+k*u[n+2][r+3]+T*u[n+3][r+3],e[h]=v*o+3*(g*i*s+d*f*l)+p*c;return e}:e?function(e,r,n,i,a){var o,s,l,c,u,h;e||(e=[]),r*=3;var f=a*a,p=f*a,d=1-a,g=d*d,v=g*d;for(u=0;u<t.length;u++)o=(h=t[u])[n+1][r]-h[n][r],s=h[n+1][r+1]-h[n][r+1],l=h[n+1][r+2]-h[n][r+2],c=h[n+1][r+3]-h[n][r+3],e[u]=v*o+3*(g*a*s+d*f*l)+p*c;return e}:r?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),n*=3;var u=1-i,h=a*a,f=1-a,p=f*f,d=f*a*2,g=-3*p,v=3*(p-d),m=3*(d-h),y=3*h;for(l=0;l<t.length;l++)o=g*(c=t[l])[n][r]+v*c[n+1][r]+m*c[n+2][r]+y*c[n+3][r],s=g*c[n][r+1]+v*c[n+1][r+1]+m*c[n+2][r+1]+y*c[n+3][r+1],e[l]=u*o+i*s;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-i;for(l=0;l<t.length;l++)o=(c=t[l])[n+1][r]-c[n][r],s=c[n+1][r+1]-c[n][r+1],e[l]=u*o+i*s;return e}}},{}],912:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=e-2,o=r-2;return n&&i?function(e,r,n){var i,s,l,c,u,h;e||(e=[]);var f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));f*=3,p*=3;var v=d*d,m=v*d,y=1-d,x=y*y,b=x*y,_=g*g,w=_*g,k=1-g,T=k*k,A=T*k;for(h=0;h<t.length;h++)i=b*(u=t[h])[p][f]+3*(x*d*u[p][f+1]+y*v*u[p][f+2])+m*u[p][f+3],s=b*u[p+1][f]+3*(x*d*u[p+1][f+1]+y*v*u[p+1][f+2])+m*u[p+1][f+3],l=b*u[p+2][f]+3*(x*d*u[p+2][f+1]+y*v*u[p+2][f+2])+m*u[p+2][f+3],c=b*u[p+3][f]+3*(x*d*u[p+3][f+1]+y*v*u[p+3][f+2])+m*u[p+3][f+3],e[h]=A*i+3*(T*g*s+k*_*l)+w*c;return e}:n?function(e,r,n){e||(e=[]);var i,s,l,c,u,h,f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));f*=3;var v=d*d,m=v*d,y=1-d,x=y*y,b=x*y,_=1-g;for(u=0;u<t.length;u++)i=_*(h=t[u])[p][f]+g*h[p+1][f],s=_*h[p][f+1]+g*h[p+1][f+1],l=_*h[p][f+2]+g*h[p+1][f+1],c=_*h[p][f+3]+g*h[p+1][f+1],e[u]=b*i+3*(x*d*s+y*v*l)+m*c;return e}:i?function(e,r,n){e||(e=[]);var i,s,l,c,u,h,f=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-f)),g=Math.max(0,Math.min(1,n-p));p*=3;var v=g*g,m=v*g,y=1-g,x=y*y,b=x*y,_=1-d;for(u=0;u<t.length;u++)i=_*(h=t[u])[p][f]+d*h[p][f+1],s=_*h[p+1][f]+d*h[p+1][f+1],l=_*h[p+2][f]+d*h[p+2][f+1],c=_*h[p+3][f]+d*h[p+3][f+1],e[u]=b*i+3*(x*g*s+y*v*l)+m*c;return e}:function(e,r,n){e||(e=[]);var i,s,l,c,u=Math.max(0,Math.min(Math.floor(r),a)),h=Math.max(0,Math.min(Math.floor(n),o)),f=Math.max(0,Math.min(1,r-u)),p=Math.max(0,Math.min(1,n-h)),d=1-p,g=1-f;for(l=0;l<t.length;l++)i=g*(c=t[l])[h][u]+f*c[h][u+1],s=g*c[h+1][u]+f*c[h+1][u+1],e[l]=d*i+p*s;return e}}},{}],913:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xy_defaults\"),a=t(\"./ab_defaults\"),o=t(\"./attributes\"),s=t(\"../../components/color/attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,o,r,i)}e._clipPathId=\"clip\"+e.uid+\"carpet\";var u=c(\"color\",s.defaultLine);(n.coerceFont(c,\"font\"),c(\"carpet\"),a(t,e,l,c,u),e.a&&e.b)?(e.a.length<3&&(e.aaxis.smoothing=0),e.b.length<3&&(e.baxis.smoothing=0),i(t,e,c)||(e.visible=!1),e._cheater&&c(\"cheaterslope\")):e.visible=!1}},{\"../../components/color/attributes\":592,\"../../lib\":719,\"./ab_defaults\":896,\"./attributes\":898,\"./xy_defaults\":922}],914:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),plot:t(\"./plot\"),calc:t(\"./calc\"),animatable:!0,isContainer:!0,moduleType:\"trace\",name:\"carpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"carpetAxis\",\"notLegendIsolatable\",\"noMultiCategory\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":898,\"./calc\":902,\"./defaults\":913,\"./plot\":919}],915:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r,n=t._fullData.length,i=0;i<n;i++){var a=t._fullData[i];if(a.index!==e.index&&(\"carpet\"===a.type&&(r||(r=a),a.carpet===e.carpet)))return a}return r}},{}],916:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(0===t.length)return\"\";var n,i=[],a=r?3:1;for(n=0;n<t.length;n+=a)i.push(t[n]+\",\"+e[n]),r&&n<t.length-a&&(i.push(\"C\"),i.push([t[n+1]+\",\"+e[n+1],t[n+2]+\",\"+e[n+2]+\" \"].join(\" \")));return i.join(r?\"\":\"L\")}},{}],917:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i;for(n(t)?t.length>e.length&&(t=t.slice(0,e.length)):t=[],i=0;i<e.length;i++)t[i]=r(e[i]);return t}},{\"../../lib\":719}],918:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i[0]*t.dpdx(e),s=i[1]*t.dpdy(r),l=1,c=1;if(a){var u=Math.sqrt(i[0]*i[0]+i[1]*i[1]),h=Math.sqrt(a[0]*a[0]+a[1]*a[1]),f=(i[0]*a[0]+i[1]*a[1])/u/h;c=Math.max(0,f)}var p=180*Math.atan2(s,o)/Math.PI;return p<-90?(p+=180,l=-l):p>90&&(p-=180,l=-l),{angle:p,flip:l,p:t.c2p(n,e,r),offsetMultplier:c}}},{}],919:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"./map_1d_array\"),o=t(\"./makepath\"),s=t(\"./orient_text\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib\"),u=t(\"../../constants/alignment\");function h(t,e,r,i,s,l){var c=\"const-\"+s+\"-lines\",u=r.selectAll(\".\"+c).data(l);u.enter().append(\"path\").classed(c,!0).style(\"vector-effect\",\"non-scaling-stroke\"),u.each(function(r){var i=r,s=i.x,l=i.y,c=a([],s,t.c2p),u=a([],l,e.c2p),h=\"M\"+o(c,u,i.smoothing);n.select(this).attr(\"d\",h).style(\"stroke-width\",i.width).style(\"stroke\",i.color).style(\"fill\",\"none\")}),u.exit().remove()}function f(t,e,r,a,o,c,u,h){var f=c.selectAll(\"text.\"+h).data(u);f.enter().append(\"text\").classed(h,!0);var p=0,d={};return f.each(function(o,c){var u;if(\"auto\"===o.axis.tickangle)u=s(a,e,r,o.xy,o.dxy);else{var h=(o.axis.tickangle+180)*Math.PI/180;u=s(a,e,r,o.xy,[Math.cos(h),Math.sin(h)])}c||(d={angle:u.angle,flip:u.flip});var f=(o.endAnchor?-1:1)*u.flip,g=n.select(this).attr({\"text-anchor\":f>0?\"start\":\"end\",\"data-notex\":1}).call(i.font,o.font).text(o.text).call(l.convertToTspans,t),v=i.bBox(this);g.attr(\"transform\",\"translate(\"+u.p[0]+\",\"+u.p[1]+\") rotate(\"+u.angle+\")translate(\"+o.axis.labelpadding*f+\",\"+.3*v.height+\")\"),p=Math.max(p,v.width+o.axis.labelpadding)}),f.exit().remove(),d.maxExtent=p,d}e.exports=function(t,e,r,i){var l=e.xaxis,u=e.yaxis,p=t._fullLayout._clips;c.makeTraceGroups(i,r,\"trace\").each(function(e){var r=n.select(this),i=e[0],d=i.trace,v=d.aaxis,m=d.baxis,y=c.ensureSingle(r,\"g\",\"minorlayer\"),x=c.ensureSingle(r,\"g\",\"majorlayer\"),b=c.ensureSingle(r,\"g\",\"boundarylayer\"),_=c.ensureSingle(r,\"g\",\"labellayer\");r.style(\"opacity\",d.opacity),h(l,u,x,v,\"a\",v._gridlines),h(l,u,x,m,\"b\",m._gridlines),h(l,u,y,v,\"a\",v._minorgridlines),h(l,u,y,m,\"b\",m._minorgridlines),h(l,u,b,v,\"a-boundary\",v._boundarylines),h(l,u,b,m,\"b-boundary\",m._boundarylines);var w=f(t,l,u,d,i,_,v._labels,\"a-label\"),k=f(t,l,u,d,i,_,m._labels,\"b-label\");!function(t,e,r,n,i,a,o,l){var u,h,f,p,d=c.aggNums(Math.min,null,r.a),v=c.aggNums(Math.max,null,r.a),m=c.aggNums(Math.min,null,r.b),y=c.aggNums(Math.max,null,r.b);u=.5*(d+v),h=m,f=r.ab2xy(u,h,!0),p=r.dxyda_rough(u,h),void 0===o.angle&&c.extendFlat(o,s(r,i,a,f,r.dxydb_rough(u,h)));g(t,e,r,n,f,p,r.aaxis,i,a,o,\"a-title\"),u=d,h=.5*(m+y),f=r.ab2xy(u,h,!0),p=r.dxydb_rough(u,h),void 0===l.angle&&c.extendFlat(l,s(r,i,a,f,r.dxyda_rough(u,h)));g(t,e,r,n,f,p,r.baxis,i,a,l,\"b-title\")}(t,_,d,i,l,u,w,k),function(t,e,r,n,i){var s,l,u,h,f=r.select(\"#\"+t._clipPathId);f.size()||(f=r.append(\"clipPath\").classed(\"carpetclip\",!0));var p=c.ensureSingle(f,\"path\",\"carpetboundary\"),d=e.clipsegments,g=[];for(h=0;h<d.length;h++)s=d[h],l=a([],s.x,n.c2p),u=a([],s.y,i.c2p),g.push(o(l,u,s.bicubic));var v=\"M\"+g.join(\"L\")+\"Z\";f.attr(\"id\",t._clipPathId),p.attr(\"d\",v)}(d,i,p,l,u)})};var p=u.LINE_SPACING,d=(1-u.MID_SHIFT)/p+1;function g(t,e,r,a,o,c,u,h,f,g,v){var m=[];u.title.text&&m.push(u.title.text);var y=e.selectAll(\"text.\"+v).data(m),x=g.maxExtent;y.enter().append(\"text\").classed(v,!0),y.each(function(){var e=s(r,h,f,o,c);-1===[\"start\",\"both\"].indexOf(u.showticklabels)&&(x=0);var a=u.title.font.size;x+=a+u.title.offset;var v=(g.angle+(g.flip<0?180:0)-e.angle+450)%360,m=v>90&&v<270,y=n.select(this);y.text(u.title.text).call(l.convertToTspans,t),m&&(x=(-l.lineCount(y)+d)*p*a-x),y.attr(\"transform\",\"translate(\"+e.p[0]+\",\"+e.p[1]+\") rotate(\"+e.angle+\") translate(0,\"+x+\")\").classed(\"user-select-none\",!0).attr(\"text-anchor\",\"middle\").call(i.font,u.title.font)}),y.exit().remove()}},{\"../../components/drawing\":614,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"./makepath\":916,\"./map_1d_array\":917,\"./orient_text\":918,d3:163}],920:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/search\").findBin,a=t(\"./compute_control_points\"),o=t(\"./create_spline_evaluator\"),s=t(\"./create_i_derivative_evaluator\"),l=t(\"./create_j_derivative_evaluator\");e.exports=function(t){var e=t._a,r=t._b,c=e.length,u=r.length,h=t.aaxis,f=t.baxis,p=e[0],d=e[c-1],g=r[0],v=r[u-1],m=e[e.length-1]-e[0],y=r[r.length-1]-r[0],x=m*n.RELATIVE_CULL_TOLERANCE,b=y*n.RELATIVE_CULL_TOLERANCE;p-=x,d+=x,g-=b,v+=b,t.isVisible=function(t,e){return t>p&&t<d&&e>g&&e<v},t.isOccluded=function(t,e){return t<p||t>d||e<g||e>v},t.setScale=function(){var e=t._x,r=t._y,n=a(t._xctrl,t._yctrl,e,r,h.smoothing,f.smoothing);t._xctrl=n[0],t._yctrl=n[1],t.evalxy=o([t._xctrl,t._yctrl],c,u,h.smoothing,f.smoothing),t.dxydi=s([t._xctrl,t._yctrl],h.smoothing,f.smoothing),t.dxydj=l([t._xctrl,t._yctrl],h.smoothing,f.smoothing)},t.i2a=function(t){var r=Math.max(0,Math.floor(t[0]),c-2),n=t[0]-r;return(1-n)*e[r]+n*e[r+1]},t.j2b=function(t){var e=Math.max(0,Math.floor(t[1]),c-2),n=t[1]-e;return(1-n)*r[e]+n*r[e+1]},t.ij2ab=function(e){return[t.i2a(e[0]),t.j2b(e[1])]},t.a2i=function(t){var r=Math.max(0,Math.min(i(t,e),c-2)),n=e[r],a=e[r+1];return Math.max(0,Math.min(c-1,r+(t-n)/(a-n)))},t.b2j=function(t){var e=Math.max(0,Math.min(i(t,r),u-2)),n=r[e],a=r[e+1];return Math.max(0,Math.min(u-1,e+(t-n)/(a-n)))},t.ab2ij=function(e){return[t.a2i(e[0]),t.b2j(e[1])]},t.i2c=function(e,r){return t.evalxy([],e,r)},t.ab2xy=function(n,i,a){if(!a&&(n<e[0]||n>e[c-1]|i<r[0]||i>r[u-1]))return[!1,!1];var o=t.a2i(n),s=t.b2j(i),l=t.evalxy([],o,s);if(a){var h,f,p,d,g=0,v=0,m=[];n<e[0]?(h=0,f=0,g=(n-e[0])/(e[1]-e[0])):n>e[c-1]?(h=c-2,f=1,g=(n-e[c-1])/(e[c-1]-e[c-2])):f=o-(h=Math.max(0,Math.min(c-2,Math.floor(o)))),i<r[0]?(p=0,d=0,v=(i-r[0])/(r[1]-r[0])):i>r[u-1]?(p=u-2,d=1,v=(i-r[u-1])/(r[u-1]-r[u-2])):d=s-(p=Math.max(0,Math.min(u-2,Math.floor(s)))),g&&(t.dxydi(m,h,p,f,d),l[0]+=m[0]*g,l[1]+=m[1]*g),v&&(t.dxydj(m,h,p,f,d),l[0]+=m[0]*v,l[1]+=m[1]*v)}return l},t.c2p=function(t,e,r){return[e.c2p(t[0]),r.c2p(t[1])]},t.p2x=function(t,e,r){return[e.p2c(t[0]),r.p2c(t[1])]},t.dadi=function(t){var r=Math.max(0,Math.min(e.length-2,t));return e[r+1]-e[r]},t.dbdj=function(t){var e=Math.max(0,Math.min(r.length-2,t));return r[e+1]-r[e]},t.dxyda=function(e,r,n,i){var a=t.dxydi(null,e,r,n,i),o=t.dadi(e,n);return[a[0]/o,a[1]/o]},t.dxydb=function(e,r,n,i){var a=t.dxydj(null,e,r,n,i),o=t.dbdj(r,i);return[a[0]/o,a[1]/o]},t.dxyda_rough=function(e,r,n){var i=m*(n||.1),a=t.ab2xy(e+i,r,!0),o=t.ab2xy(e-i,r,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dxydb_rough=function(e,r,n){var i=y*(n||.1),a=t.ab2xy(e,r+i,!0),o=t.ab2xy(e,r-i,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dpdx=function(t){return t._m},t.dpdy=function(t){return t._m}}},{\"../../lib/search\":738,\"./compute_control_points\":908,\"./constants\":909,\"./create_i_derivative_evaluator\":910,\"./create_j_derivative_evaluator\":911,\"./create_spline_evaluator\":912}],921:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r){var i,a,o,s=[],l=[],c=t[0].length,u=t.length;function h(e,r){var n,i=0,a=0;return e>0&&void 0!==(n=t[r][e-1])&&(a++,i+=n),e<c-1&&void 0!==(n=t[r][e+1])&&(a++,i+=n),r>0&&void 0!==(n=t[r-1][e])&&(a++,i+=n),r<u-1&&void 0!==(n=t[r+1][e])&&(a++,i+=n),i/Math.max(1,a)}var f,p,d,g,v,m,y,x,b,_,w,k=0;for(i=0;i<c;i++)for(a=0;a<u;a++)void 0===t[a][i]&&(s.push(i),l.push(a),t[a][i]=h(i,a)),k=Math.max(k,Math.abs(t[a][i]));if(!s.length)return t;var T=0,A=0,M=s.length;do{for(T=0,o=0;o<M;o++){i=s[o],a=l[o];var S,E,C,L,P,O,z=0,I=0;0===i?(C=e[P=Math.min(c-1,2)],L=e[1],S=t[a][P],I+=(E=t[a][1])+(E-S)*(e[0]-L)/(L-C),z++):i===c-1&&(C=e[P=Math.max(0,c-3)],L=e[c-2],S=t[a][P],I+=(E=t[a][c-2])+(E-S)*(e[c-1]-L)/(L-C),z++),(0===i||i===c-1)&&a>0&&a<u-1&&(f=r[a+1]-r[a],I+=((p=r[a]-r[a-1])*t[a+1][i]+f*t[a-1][i])/(p+f),z++),0===a?(C=r[O=Math.min(u-1,2)],L=r[1],S=t[O][i],I+=(E=t[1][i])+(E-S)*(r[0]-L)/(L-C),z++):a===u-1&&(C=r[O=Math.max(0,u-3)],L=r[u-2],S=t[O][i],I+=(E=t[u-2][i])+(E-S)*(r[u-1]-L)/(L-C),z++),(0===a||a===u-1)&&i>0&&i<c-1&&(f=e[i+1]-e[i],I+=((p=e[i]-e[i-1])*t[a][i+1]+f*t[a][i-1])/(p+f),z++),z?I/=z:(d=e[i+1]-e[i],g=e[i]-e[i-1],x=(v=r[a+1]-r[a])*(m=r[a]-r[a-1])*(v+m),I=((y=d*g*(d+g))*(m*t[a+1][i]+v*t[a-1][i])+x*(g*t[a][i+1]+d*t[a][i-1]))/(x*(g+d)+y*(m+v))),T+=(_=(b=I-t[a][i])/k)*_,w=z?0:.85,t[a][i]+=b*(1+w)}T=Math.sqrt(T)}while(A++<100&&T>1e-5);return n.log(\"Smoother converged to\",T,\"after\",A,\"iterations\"),t}},{\"../../lib\":719}],922:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArray1D;e.exports=function(t,e,r){var i=r(\"x\"),a=i&&i.length,o=r(\"y\"),s=o&&o.length;if(!a&&!s)return!1;if(e._cheater=!i,a&&!n(i)||s&&!n(o))e._length=null;else{var l=a?i.length:1/0;s&&(l=Math.min(l,o.length)),e.a&&e.a.length&&(l=Math.min(l,e.a.length)),e.b&&e.b.length&&(l=Math.min(l,e.b.length)),e._length=l}return!0}},{\"../../lib\":719}],923:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scattergeo/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/color/attributes\").defaultLine,l=t(\"../../lib/extend\").extendFlat,c=i.marker.line;e.exports=l({locations:{valType:\"data_array\",editType:\"calc\"},locationmode:i.locationmode,z:{valType:\"data_array\",editType:\"calc\"},text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),marker:{line:{color:l({},c.color,{dflt:s}),width:l({},c.width,{dflt:1}),editType:\"calc\"},opacity:{valType:\"number\",arrayOk:!0,min:0,max:1,dflt:1,editType:\"style\"},editType:\"calc\"},selected:{marker:{opacity:i.selected.marker.opacity,editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:i.unselected.marker.opacity,editType:\"plot\"},editType:\"plot\"},hoverinfo:l({},o.hoverinfo,{editType:\"calc\",flags:[\"location\",\"z\",\"text\",\"name\"]}),hovertemplate:n()},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/color/attributes\":592,\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scattergeo/attributes\":1151}],924:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../components/colorscale/calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\");function l(t){return t&&\"string\"==typeof t}e.exports=function(t,e){var r,c=e._length,u=new Array(c);r=e.geojson?function(t){return l(t)||n(t)}:l;for(var h=0;h<c;h++){var f=u[h]={},p=e.locations[h],d=e.z[h];r(p)&&n(d)?(f.loc=p,f.z=d):(f.loc=null,f.z=i),f.index=h}return o(u,e),a(t,e,{vals:e.z,containerStr:\"\",cLetter:\"z\"}),s(u,e),u}},{\"../../components/colorscale/calc\":601,\"../../constants/numerical\":695,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc_selection\":1114,\"fast-isnumeric\":225}],925:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\");l&&l.length&&n.isArrayOrTypedArray(c)&&c.length?(e._length=Math.min(l.length,c.length),s(\"locationmode\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":923}],926:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){t.location=e.location,t.z=e.z;var a=n[i];return a.fIn&&(t.properties=a.fIn.properties),t}},{}],927:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"./attributes\"),a=t(\"../../lib\").fillText;e.exports=function(t,e,r){var o,s,l,c,u=t.cd,h=u[0].trace,f=t.subplot;for(s=0;s<u.length;s++)if(c=!1,(o=u[s])._polygons){for(l=0;l<o._polygons.length;l++)o._polygons[l].contains([e,r])&&(c=!c),o._polygons[l].contains([e+360,r])&&(c=!c);if(c)break}if(c&&o)return t.x0=t.x1=t.xa.c2p(o.ct),t.y0=t.y1=t.ya.c2p(o.ct),t.index=o.index,t.location=o.loc,t.z=o.z,t.zLabel=n.tickText(f.mockAxis,f.mockAxis.c2l(o.z),\"hover\").text,t.hovertemplate=o.hovertemplate,function(t,e,r){if(e.hovertemplate)return;var n=r.hi||e.hoverinfo,o=\"all\"===n?i.hoverinfo.flags:n.split(\"+\"),s=-1!==o.indexOf(\"name\"),l=-1!==o.indexOf(\"location\"),c=-1!==o.indexOf(\"z\"),u=-1!==o.indexOf(\"text\"),h=[];!s&&l?t.nameOverride=r.loc:(s&&(t.nameOverride=e.name),l&&h.push(r.loc));c&&h.push(t.zLabel);u&&a(r,e,h);t.extraText=h.join(\"<br>\")}(t,h,o,f.mockAxis),[t]}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./attributes\":923}],928:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"choropleth\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"noOpacity\"],meta:{}}},{\"../../plots/geo\":797,\"../heatmap/colorbar\":1004,\"./attributes\":923,\"./calc\":924,\"./defaults\":925,\"./event_data\":926,\"./hover\":927,\"./plot\":929,\"./select\":930,\"./style\":931}],929:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../lib/polygon\"),o=t(\"../../lib/topojson_utils\").getTopojsonFeatures,s=t(\"../../lib/geo_location_utils\").locationToFeature,l=t(\"./style\").style;function c(t,e){for(var r=t[0].trace,n=t.length,i=o(r,e),a=0;a<n;a++){var l=t[a],c=s(r.locationmode,l.loc,i);c?(l.geojson=c,l.ct=c.properties.ct,l._polygons=u(c)):l.geojson=null}}function u(t){var e,r,n,i,o=t.geometry,s=o.coordinates,l=t.id,c=[];function u(t){for(var e=0;e<t.length-1;e++)if(t[e][0]>0&&t[e+1][0]<0)return e;return null}switch(e=\"RUS\"===l||\"FJI\"===l?function(t){var e;if(null===u(t))e=t;else for(e=new Array(t.length),i=0;i<t.length;i++)e[i]=[t[i][0]<0?t[i][0]+360:t[i][0],t[i][1]];c.push(a.tester(e))}:\"ATA\"===l?function(t){var e=u(t);if(null===e)return c.push(a.tester(t));var r=new Array(t.length+1),n=0;for(i=0;i<t.length;i++)i>e?r[n++]=[t[i][0]+360,t[i][1]]:i===e?(r[n++]=t[i],r[n++]=[t[i][0],-90]):r[n++]=t[i];var o=a.tester(r);o.pts.pop(),c.push(o)}:function(t){c.push(a.tester(t))},o.type){case\"MultiPolygon\":for(r=0;r<s.length;r++)for(n=0;n<s[r].length;n++)e(s[r][n]);break;case\"Polygon\":for(r=0;r<s.length;r++)e(s[r])}return c}e.exports={plot:function(t,e,r){for(var a=0;a<r.length;a++)c(r[a],e.topojson);var o=e.layers.backplot.select(\".choroplethlayer\");i.makeTraceGroups(o,r,\"trace choropleth\").each(function(e){var r=n.select(this).selectAll(\"path.choroplethlocation\").data(i.identity);r.enter().append(\"path\").classed(\"choroplethlocation\",!0),r.exit().remove(),l(t,e)})},feature2polygons:u}},{\"../../lib\":719,\"../../lib/geo_location_utils\":713,\"../../lib/polygon\":731,\"../../lib/topojson_utils\":746,\"./style\":931,d3:163}],930:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)(i=(n=s[r]).ct)&&(a=l.c2p(i),o=c.c2p(i),e.contains([a,o],null,r,t)?(u.push({pointNumber:r,lon:i[0],lat:i[1]}),n.selected=1):n.selected=0);return u}},{}],931:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../components/colorscale\");function s(t,e){var r=e[0].trace,s=e[0].node3.selectAll(\".choroplethlocation\"),l=r.marker||{},c=l.line||{},u=o.makeColorScaleFuncFromTrace(r);s.each(function(t){n.select(this).attr(\"fill\",u(t.z)).call(i.stroke,t.mlc||c.color).call(a.dashLine,\"\",t.mlw||c.width||0).style(\"opacity\",l.opacity)}),a.selectedPointStyle(s,r,t)}e.exports={style:function(t,e){e&&s(t,e)},styleOnSelect:function(t,e){var r=e[0].node3,n=e[0].trace;n.selectedpoints?a.selectedPointStyle(r.selectAll(\".choroplethlocation\"),n,t):s(t,e)}}},{\"../../components/color\":593,\"../../components/colorscale\":605,\"../../components/drawing\":614,d3:163}],932:[function(t,e,r){\"use strict\";var n=t(\"../choropleth/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../lib/extend\").extendFlat;e.exports=o({locations:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},geojson:{valType:\"any\",editType:\"calc\"},below:{valType:\"string\",editType:\"plot\"},text:n.text,hovertext:n.hovertext,marker:{line:{color:o({},n.marker.line.color,{editType:\"plot\"}),width:o({},n.marker.line.width,{editType:\"plot\"}),editType:\"calc\"},opacity:o({},n.marker.opacity,{editType:\"plot\"}),editType:\"calc\"},selected:{marker:{opacity:o({},n.selected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:o({},n.unselected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},hoverinfo:n.hoverinfo,hovertemplate:a({},{keys:[\"properties\"]})},i(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../choropleth/attributes\":923}],933:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"@turf/area\"),a=t(\"@turf/centroid\"),o=t(\"../../lib\"),s=t(\"../../components/colorscale\"),l=t(\"../../components/drawing\"),c=t(\"../../lib/geojson_utils\").makeBlank,u=t(\"../choropleth/plot\").feature2polygons;function h(t){var e,r=t[0].trace,n=r._opts;if(r.selectedpoints){for(var i=l.makeSelectedPointStyleFns(r),a=0;a<t.length;a++){var s=t[a];s.fOut&&(s.fOut.properties.mo2=i.selectedOpacityFn(s))}e={type:\"identity\",property:\"mo2\"}}else e=o.isArrayOrTypedArray(r.marker.opacity)?{type:\"identity\",property:\"mo\"}:r.marker.opacity;return o.extendFlat(n.fill.paint,{\"fill-opacity\":e}),o.extendFlat(n.line.paint,{\"line-opacity\":e}),n}e.exports={convert:function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,l={layout:{visibility:\"none\"},paint:{}},f={layout:{visibility:\"none\"},paint:{}},p=e._opts={fill:l,line:f,geojson:c()};if(!r)return p;var d=\"string\"==typeof e.geojson?(window.PlotlyGeoAssets||{})[e.geojson]:e.geojson;if(!o.isPlainObject(d))return o.error(\"Oops ... something when wrong when fetching \"+e.geojson),p;var g,v={},m=[];for(g=0;g<t.length;g++){var y=t[g];y.loc&&(v[y.loc]=y)}var x,b,_,w=s.makeColorScaleFuncFromTrace(e),k=e.marker,T=k.line||{};function A(t){var e=v[t.id];if(e){var r=t.geometry;if(\"Polygon\"===r.type||\"MultiPolygon\"===r.type){var n={fc:w(e.z)};x&&(n.mo=x(e)),b&&(n.mlc=b(e)),_&&(n.mlw=_(e));var s={type:\"Feature\",geometry:r,properties:n};e._polygons=u(s),e.ct=function(t){var e,r=t.geometry;if(\"MultiPolygon\"===r.type)for(var n=r.coordinates,o=0,s=0;s<n.length;s++){var l={type:\"Polygon\",coordinates:n[s]},c=i.default(l);c>o&&(o=c,e=l)}else e=r;return a.default(e).geometry.coordinates}(s),e.fIn=t,e.fOut=s,m.push(s)}else o.log([\"Location with id\",e.loc,\"does not have a valid GeoJSON geometry,\",\"choroplethmapbox traces only support *Polygon* and *MultiPolygon* geometries.\"].join(\" \"))}delete v[t.id]}switch(o.isArrayOrTypedArray(k.opacity)&&(x=function(t){var e=t.mo;return n(e)?+o.constrain(e,0,1):0}),o.isArrayOrTypedArray(T.color)&&(b=function(t){return t.mlc}),o.isArrayOrTypedArray(T.width)&&(_=function(t){return t.mlw}),d.type){case\"FeatureCollection\":var M=d.features;for(g=0;g<M.length;g++)A(M[g]);break;case\"Feature\":A(d);break;default:return o.warn([\"Invalid GeoJSON type\",(d.type||\"none\")+\",\",\"choroplethmapbox traces only support *FeatureCollection* and *Feature* types.\"].join(\" \")),p}for(var S in v)o.log(\"Location with id \"+S+\" does not have a matching feature\");var E=x?{type:\"identity\",property:\"mo\"}:k.opacity;return o.extendFlat(l.paint,{\"fill-color\":{type:\"identity\",property:\"fc\"},\"fill-opacity\":E}),o.extendFlat(f.paint,{\"line-color\":b?{type:\"identity\",property:\"mlc\"}:T.color,\"line-width\":_?{type:\"identity\",property:\"mlw\"}:T.width,\"line-opacity\":E}),l.layout.visibility=\"visible\",f.layout.visibility=\"visible\",p.geojson={type:\"FeatureCollection\",features:m},h(t),p},convertOnSelect:h}},{\"../../components/colorscale\":605,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/geojson_utils\":714,\"../choropleth/plot\":929,\"@turf/area\":55,\"@turf/centroid\":56,\"fast-isnumeric\":225}],934:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\"),u=s(\"geojson\");n.isArrayOrTypedArray(l)&&l.length&&n.isArrayOrTypedArray(c)&&c.length&&(\"string\"==typeof u&&\"\"!==u||n.isPlainObject(u))?(e._length=Math.min(l.length,c.length),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":932}],935:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../choropleth/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"../choropleth/hover\"),eventData:t(\"../choropleth/event_data\"),selectPoints:t(\"../choropleth/select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.updateOnSelect(e)},getBelow:function(t,e){for(var r=e.getMapLayers(),n=r.length-2;n>=0;n--){var i=r[n].id;if(\"string\"==typeof i&&0===i.indexOf(\"water\"))for(var a=n+1;a<r.length;a++)if(\"string\"==typeof(i=r[a].id)&&-1===i.indexOf(\"plotly-\"))return i}},moduleType:\"trace\",name:\"choroplethmapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"noOpacity\"],meta:{hr_name:\"choropleth_mapbox\"}}},{\"../../plots/mapbox\":822,\"../choropleth/calc\":924,\"../choropleth/event_data\":926,\"../choropleth/hover\":927,\"../choropleth/select\":930,\"../heatmap/colorbar\":1004,\"./attributes\":932,\"./defaults\":934,\"./plot\":936}],936:[function(t,e,r){\"use strict\";var n=t(\"./convert\").convert,i=t(\"./convert\").convertOnSelect,a=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function o(t,e){this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"fill\",a+e+\"-fill\"],[\"line\",a+e+\"-line\"]],this.below=null}var s=o.prototype;s.update=function(t){this._update(n(t))},s.updateOnSelect=function(t){this._update(i(t))},s._update=function(t){var e=this.subplot,r=this.layerList,n=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(t.geojson),n!==this.below&&(this._removeLayers(),this._addLayers(t,n),this.below=n);for(var i=0;i<r.length;i++){var a=r[i],o=a[0],s=a[1],l=t[o];e.setOptions(s,\"setLayoutProperty\",l.layout),\"visible\"===l.layout.visibility&&e.setOptions(s,\"setPaintProperty\",l.paint)}},s._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},s._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},s.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new o(t,r.uid),a=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(a,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":820,\"./convert\":933}],937:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"scaled\",\"absolute\"],editType:\"calc\",dflt:\"scaled\"},sizeref:{valType:\"number\",editType:\"calc\",min:0},anchor:{valType:\"enumerated\",editType:\"calc\",values:[\"tip\",\"tail\",\"cm\",\"center\"],dflt:\"cm\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:i({editType:\"calc\"},{keys:[\"norm\"]})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach(function(t){l[t]=a[t]}),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../mesh3d/attributes\":1053}],938:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){for(var r=e.u,i=e.v,a=e.w,o=Math.min(e.x.length,e.y.length,e.z.length,r.length,i.length,a.length),s=-1/0,l=1/0,c=0;c<o;c++){var u=r[c],h=i[c],f=a[c],p=Math.sqrt(u*u+h*h+f*f);s=Math.max(s,p),l=Math.min(l,p)}e._len=o,e._normMax=s,n(t,e,{vals:[l,s],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],939:[function(t,e,r){\"use strict\";var n=t(\"gl-cone3d\"),i=t(\"gl-cone3d\").createConeMesh,a=t(\"../../lib\").simpleMap,o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\");function c(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var u=c.prototype;u.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index,r=this.data.x[e],n=this.data.y[e],i=this.data.z[e],a=this.data.u[e],o=this.data.v[e],s=this.data.w[e];t.traceCoordinate=[r,n,i,a,o,s,Math.sqrt(a*a+o*o+s*s)];var l=this.data.hovertext||this.data.text;return Array.isArray(l)&&void 0!==l[e]?t.textLabel=l[e]:l&&(t.textLabel=l),!0}};var h={xaxis:0,yaxis:1,zaxis:2},f={tip:1,tail:0,cm:.25,center:.5},p={tip:1,tail:1,cm:.75,center:.5};function d(t,e){var r=t.fullSceneLayout,i=t.dataScale,c={};function u(t,e){var n=r[e],o=i[h[e]];return a(t,function(t){return n.d2l(t)*o})}c.vectors=l(u(e.u,\"xaxis\"),u(e.v,\"yaxis\"),u(e.w,\"zaxis\"),e._len),c.positions=l(u(e.x,\"xaxis\"),u(e.y,\"yaxis\"),u(e.z,\"zaxis\"),e._len);var d=s(e);c.colormap=o(e),c.vertexIntensityBounds=[d.min/e._normMax,d.max/e._normMax],c.coneOffset=f[e.anchor],\"scaled\"===e.sizemode?c.coneSize=e.sizeref||.5:c.coneSize=e.sizeref&&e._normMax?e.sizeref/e._normMax:.5;var g=n(c),v=e.lightposition;return g.lightPosition=[v.x,v.y,v.z],g.ambient=e.lighting.ambient,g.diffuse=e.lighting.diffuse,g.specular=e.lighting.specular,g.roughness=e.lighting.roughness,g.fresnel=e.lighting.fresnel,g.opacity=e.opacity,e._pad=p[e.anchor]*g.vectorScale*g.coneScale*e._normMax,g}u.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),a=i(r,n),o=new c(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../plots/gl3d/zip3\":818,\"gl-cone3d\":242}],940:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),h=s(\"x\"),f=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length&&p&&p.length?(s(\"sizeref\"),s(\"sizemode\"),s(\"anchor\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":937}],941:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"cone\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),eventData:function(t,e){return t.norm=e.traceCoordinate[6],t},meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":937,\"./calc\":938,\"./convert\":939,\"./defaults\":940}],942:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../components/drawing/attributes\").dash,s=t(\"../../plots/font_attributes\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../constants/filter_ops\"),u=c.COMPARISON_OPS2,h=c.INTERVAL_OPS,f=(t(\"../../constants/docs\").FORMAT_LINK,i.line);e.exports=l({z:n.z,x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,xtype:n.xtype,ytype:n.ytype,zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate,connectgaps:n.connectgaps,fillcolor:{valType:\"color\",editType:\"calc\"},autocontour:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"contours.start\":void 0,\"contours.end\":void 0,\"contours.size\":void 0}},ncontours:{valType:\"integer\",dflt:15,min:1,editType:\"calc\"},contours:{type:{valType:\"enumerated\",values:[\"levels\",\"constraint\"],dflt:\"levels\",editType:\"calc\"},start:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},end:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},coloring:{valType:\"enumerated\",values:[\"fill\",\"heatmap\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:{valType:\"boolean\",dflt:!0,editType:\"plot\"},showlabels:{valType:\"boolean\",dflt:!1,editType:\"plot\"},labelfont:s({editType:\"plot\",colorEditType:\"style\"}),labelformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},operation:{valType:\"enumerated\",values:[].concat(u).concat(h),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:l({},f.color,{editType:\"style+colorbars\"}),width:l({},f.width,{editType:\"style+colorbars\"}),dash:o,smoothing:l({},f.smoothing,{}),editType:\"plot\"}},a(\"\",{cLetter:\"z\",autoColorDflt:!1,editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../components/drawing/attributes\":613,\"../../constants/docs\":690,\"../../constants/filter_ops\":691,\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"../heatmap/attributes\":1001,\"../scatter/attributes\":1112}],943:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\"),i=t(\"../heatmap/calc\"),a=t(\"./set_contours\"),o=t(\"./end_plus\");e.exports=function(t,e){var r=i(t,e),s=r[0].z;a(e,s);var l,c=e.contours,u=n.extractOpts(e);if(\"heatmap\"===c.coloring&&u.auto&&!1===e.autocontour){var h=c.start,f=o(c),p=c.size||1,d=Math.floor((f-h)/p)+1;isFinite(p)||(p=1,d=1);var g=h-p/2;l=[g,g+d*p]}else l=s;return n.calc(t,e,{vals:l,cLetter:\"z\"}),r}},{\"../../components/colorscale\":605,\"../heatmap/calc\":1002,\"./end_plus\":953,\"./set_contours\":961}],944:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a,o,s=t[0],l=s.x.length,c=s.y.length,u=s.z,h=n.contours,f=-1/0,p=1/0;for(i=0;i<c;i++)p=Math.min(p,u[i][0]),p=Math.min(p,u[i][l-1]),f=Math.max(f,u[i][0]),f=Math.max(f,u[i][l-1]);for(i=1;i<l-1;i++)p=Math.min(p,u[0][i]),p=Math.min(p,u[c-1][i]),f=Math.max(f,u[0][i]),f=Math.max(f,u[c-1][i]);switch(s.prefixBoundary=!1,e){case\">\":h.value>f&&(s.prefixBoundary=!0);break;case\"<\":h.value<p&&(s.prefixBoundary=!0);break;case\"[]\":a=Math.min.apply(null,h.value),((o=Math.max.apply(null,h.value))<p||a>f)&&(s.prefixBoundary=!0);break;case\"][\":a=Math.min.apply(null,h.value),o=Math.max.apply(null,h.value),a<p&&o>f&&(s.prefixBoundary=!0)}}},{}],945:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\").extractOpts,i=t(\"./make_color_map\"),a=t(\"./end_plus\");e.exports={min:\"zmin\",max:\"zmax\",calc:function(t,e,r){var o=e.contours,s=e.line,l=o.size||1,c=o.coloring,u=i(e,{isColorbar:!0});if(\"heatmap\"===c){var h=n(e);r._fillgradient=e.colorscale,r._zrange=[h.min,h.max]}else\"fill\"===c&&(r._fillcolor=u);r._line={color:\"lines\"===c?u:s.color,width:!1!==o.showlines?s.width:0,dash:s.dash},r._levels={start:o.start,end:a(o),size:l}}}},{\"../../components/colorscale\":605,\"./end_plus\":953,\"./make_color_map\":958}],946:[function(t,e,r){\"use strict\";e.exports={BOTTOMSTART:[1,9,13,104,713],TOPSTART:[4,6,7,104,713],LEFTSTART:[8,12,14,208,1114],RIGHTSTART:[2,3,11,208,1114],NEWDELTA:[null,[-1,0],[0,-1],[-1,0],[1,0],null,[0,-1],[-1,0],[0,1],[0,1],null,[0,1],[1,0],[1,0],[0,-1]],CHOOSESADDLE:{104:[4,1],208:[2,8],713:[7,13],1114:[11,14]},SADDLEREMAINDER:{1:4,2:8,4:1,7:13,8:2,11:14,13:7,14:11},LABELDISTANCE:2,LABELINCREASE:10,LABELMIN:3,LABELMAX:10,LABELOPTIMIZER:{EDGECOST:1,ANGLECOST:1,NEIGHBORCOST:5,SAMELEVELFACTOR:10,SAMELEVELDISTANCE:5,MAXCOST:100,INITIALSEARCHPOINTS:10,ITERATIONS:5}}},{}],947:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./label_defaults\"),a=t(\"../../components/color\"),o=a.addOpacity,s=a.opacity,l=t(\"../../constants/filter_ops\"),c=l.CONSTRAINT_REDUCTION,u=l.COMPARISON_OPS2;e.exports=function(t,e,r,a,l,h){var f,p,d,g=e.contours,v=r(\"contours.operation\");(g._operation=c[v],function(t,e){var r;-1===u.indexOf(e.operation)?(t(\"contours.value\",[0,1]),Array.isArray(e.value)?e.value.length>2?e.value=e.value.slice(2):0===e.length?e.value=[0,1]:e.length<2?(r=parseFloat(e.value[0]),e.value=[r,r+1]):e.value=[parseFloat(e.value[0]),parseFloat(e.value[1])]:n(e.value)&&(r=parseFloat(e.value),e.value=[r,r+1])):(t(\"contours.value\",0),n(e.value)||(Array.isArray(e.value)?e.value=parseFloat(e.value[0]):e.value=0))}(r,g),\"=\"===v?f=g.showlines=!0:(f=r(\"contours.showlines\"),d=r(\"fillcolor\",o((t.line||{}).color||l,.5))),f)&&(p=r(\"line.color\",d&&s(d)?o(e.fillcolor,1):l),r(\"line.width\",2),r(\"line.dash\"));r(\"line.smoothing\"),i(r,a,p,h)}},{\"../../components/color\":593,\"../../constants/filter_ops\":691,\"./label_defaults\":957,\"fast-isnumeric\":225}],948:[function(t,e,r){\"use strict\";var n=t(\"../../constants/filter_ops\"),i=t(\"fast-isnumeric\");function a(t,e){var r,a=Array.isArray(e);function o(t){return i(t)?+t:null}return-1!==n.COMPARISON_OPS2.indexOf(t)?r=o(a?e[0]:e):-1!==n.INTERVAL_OPS.indexOf(t)?r=a?[o(e[0]),o(e[1])]:[o(e),o(e)]:-1!==n.SET_OPS.indexOf(t)&&(r=a?e.map(o):[o(e)]),r}function o(t){return function(e){e=a(t,e);var r=Math.min(e[0],e[1]),n=Math.max(e[0],e[1]);return{start:r,end:n,size:n-r}}}function s(t){return function(e){return{start:e=a(t,e),end:1/0,size:1/0}}}e.exports={\"[]\":o(\"[]\"),\"][\":o(\"][\"),\">\":s(\">\"),\"<\":s(\"<\"),\"=\":s(\"=\")}},{\"../../constants/filter_ops\":691,\"fast-isnumeric\":225}],949:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=n(\"contours.start\"),a=n(\"contours.end\"),o=!1===i||!1===a,s=r(\"contours.size\");!(o?e.autocontour=!0:r(\"autocontour\",!1))&&s||r(\"ncontours\")}},{}],950:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");function i(t){return n.extendFlat({},t,{edgepaths:n.extendDeep([],t.edgepaths),paths:n.extendDeep([],t.paths)})}e.exports=function(t,e){var r,a,o,s=function(t){return t.reverse()},l=function(t){return t};switch(e){case\"=\":case\"<\":return t;case\">\":for(1!==t.length&&n.warn(\"Contour data invalid for the specified inequality operation.\"),a=t[0],r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);return t;case\"][\":var c=s;s=l,l=c;case\"[]\":for(2!==t.length&&n.warn(\"Contour data invalid for the specified inequality range operation.\"),a=i(t[0]),o=i(t[1]),r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);for(;o.edgepaths.length;)a.edgepaths.push(l(o.edgepaths.shift()));for(;o.paths.length;)a.paths.push(l(o.paths.shift()));return[a]}}},{\"../../lib\":719}],951:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"./constraint_defaults\"),o=t(\"./contours_defaults\"),s=t(\"./style_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,l,r,i)}if(i(t,e,u,c)){u(\"text\"),u(\"hovertext\"),u(\"hovertemplate\");var h=\"constraint\"===u(\"contours.type\");u(\"connectgaps\",n.isArray1D(e.z)),h?a(t,e,u,c,r):(o(t,e,u,function(r){return n.coerce2(t,e,l,r)}),s(t,e,u,c))}else e.visible=!1}},{\"../../lib\":719,\"../heatmap/xyz_defaults\":1015,\"./attributes\":942,\"./constraint_defaults\":947,\"./contours_defaults\":949,\"./style_defaults\":963}],952:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constraint_mapping\"),a=t(\"./end_plus\");e.exports=function(t,e,r){for(var o=\"constraint\"===t.type?i[t._operation](t.value):t,s=o.size,l=[],c=a(o),u=r.trace._carpetTrace,h=u?{xaxis:u.aaxis,yaxis:u.baxis,x:r.a,y:r.b}:{xaxis:e.xaxis,yaxis:e.yaxis,x:r.x,y:r.y},f=o.start;f<c;f+=s)if(l.push(n.extendFlat({level:f,crossings:{},starts:[],edgepaths:[],paths:[],z:r.z,smoothing:r.trace.line.smoothing},h)),l.length>1e3){n.warn(\"Too many contours, clipping at 1000\",t);break}return l}},{\"../../lib\":719,\"./constraint_mapping\":948,\"./end_plus\":953}],953:[function(t,e,r){\"use strict\";e.exports=function(t){return t.end+t.size/1e6}},{}],954:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constants\");function a(t,e,r,n){return Math.abs(t[0]-e[0])<r&&Math.abs(t[1]-e[1])<n}function o(t,e,r,o,l){var c,u=e.join(\",\"),h=u,f=t.crossings[h],p=function(t,e,r){var n=0,a=0;t>20&&e?208===t||1114===t?n=0===r[0]?1:-1:a=0===r[1]?1:-1:-1!==i.BOTTOMSTART.indexOf(t)?a=1:-1!==i.LEFTSTART.indexOf(t)?n=1:-1!==i.TOPSTART.indexOf(t)?a=-1:n=-1;return[n,a]}(f,r,e),d=[s(t,e,[-p[0],-p[1]])],g=p.join(\",\"),v=t.z.length,m=t.z[0].length;for(c=0;c<1e4;c++){if(f>20?(f=i.CHOOSESADDLE[f][(p[0]||p[1])<0?0:1],t.crossings[h]=i.SADDLEREMAINDER[f]):delete t.crossings[h],!(p=i.NEWDELTA[f])){n.log(\"Found bad marching index:\",f,e,t.level);break}d.push(s(t,e,p)),e[0]+=p[0],e[1]+=p[1],a(d[d.length-1],d[d.length-2],o,l)&&d.pop(),h=e.join(\",\");var y=p[0]&&(e[0]<0||e[0]>m-2)||p[1]&&(e[1]<0||e[1]>v-2);if(h===u&&p.join(\",\")===g||r&&y)break;f=t.crossings[h]}1e4===c&&n.log(\"Infinite loop in contour?\");var x,b,_,w,k,T,A,M,S,E,C,L,P,O,z,I=a(d[0],d[d.length-1],o,l),D=0,R=.2*t.smoothing,F=[],B=0;for(c=1;c<d.length;c++)L=d[c],P=d[c-1],void 0,void 0,O=L[2]-P[2],z=L[3]-P[3],D+=A=Math.sqrt(O*O+z*z),F.push(A);var N=D/F.length*R;function j(t){return d[t%d.length]}for(c=d.length-2;c>=B;c--)if((x=F[c])<N){for(_=0,b=c-1;b>=B&&x+F[b]<N;b--)x+=F[b];if(I&&c===d.length-2)for(_=0;_<b&&x+F[_]<N;_++)x+=F[_];k=c-b+_+1,T=Math.floor((c+b+_+2)/2),w=I||c!==d.length-2?I||-1!==b?k%2?j(T):[(j(T)[0]+j(T+1)[0])/2,(j(T)[1]+j(T+1)[1])/2]:d[0]:d[d.length-1],d.splice(b+1,c-b+1,w),c=b+1,_&&(B=_),I&&(c===d.length-2?d[_]=d[d.length-1]:0===c&&(d[d.length-1]=d[0]))}for(d.splice(0,B),c=0;c<d.length;c++)d[c].length=2;if(!(d.length<2))if(I)d.pop(),t.paths.push(d);else{r||n.log(\"Unclosed interior contour?\",t.level,u,d.join(\"L\"));var U=!1;for(M=0;M<t.edgepaths.length;M++)if(E=t.edgepaths[M],!U&&a(E[0],d[d.length-1],o,l)){d.pop(),U=!0;var V=!1;for(S=0;S<t.edgepaths.length;S++)if(a((C=t.edgepaths[S])[C.length-1],d[0],o,l)){V=!0,d.shift(),t.edgepaths.splice(M,1),S===M?t.paths.push(d.concat(C)):(S>M&&S--,t.edgepaths[S]=C.concat(d,E));break}V||(t.edgepaths[M]=d.concat(E))}for(M=0;M<t.edgepaths.length&&!U;M++)a((E=t.edgepaths[M])[E.length-1],d[0],o,l)&&(d.shift(),t.edgepaths[M]=E.concat(d),U=!0);U||t.edgepaths.push(d)}}function s(t,e,r){var n=e[0]+Math.max(r[0],0),i=e[1]+Math.max(r[1],0),a=t.z[i][n],o=t.xaxis,s=t.yaxis;if(r[1]){var l=(t.level-a)/(t.z[i][n+1]-a);return[o.c2p((1-l)*t.x[n]+l*t.x[n+1],!0),s.c2p(t.y[i],!0),n+l,i]}var c=(t.level-a)/(t.z[i+1][n]-a);return[o.c2p(t.x[n],!0),s.c2p((1-c)*t.y[i]+c*t.y[i+1],!0),n,i+c]}e.exports=function(t,e,r){var i,a,s,l;for(e=e||.01,r=r||.01,a=0;a<t.length;a++){for(s=t[a],l=0;l<s.starts.length;l++)o(s,s.starts[l],\"edge\",e,r);for(i=0;Object.keys(s.crossings).length&&i<1e4;)i++,o(s,Object.keys(s.crossings)[0].split(\",\").map(Number),void 0,e,r);1e4===i&&n.log(\"Infinite loop in contour?\")}}},{\"../../lib\":719,\"./constants\":946}],955:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../heatmap/hover\");e.exports=function(t,e,r,a,o){var s=i(t,e,r,a,o,!0);return s&&s.forEach(function(t){var e=t.trace;\"constraint\"===e.contours.type&&(e.fillcolor&&n.opacity(e.fillcolor)?t.color=n.addOpacity(e.fillcolor,1):e.contours.showlines&&n.opacity(e.line.color)&&(t.color=n.addOpacity(e.line.color,1)))}),s}},{\"../../components/color\":593,\"../heatmap/hover\":1008}],956:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\").plot,style:t(\"./style\"),colorbar:t(\"./colorbar\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"contour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":942,\"./calc\":943,\"./colorbar\":945,\"./defaults\":951,\"./hover\":955,\"./plot\":960,\"./style\":962}],957:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i){if(i||(i={}),t(\"contours.showlabels\")){var a=e.font;n.coerceFont(t,\"contours.labelfont\",{family:a.family,size:a.size,color:r}),t(\"contours.labelformat\")}!1!==i.hasHover&&t(\"zhoverformat\")}},{\"../../lib\":719}],958:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/colorscale\"),a=t(\"./end_plus\");e.exports=function(t){var e=t.contours,r=e.start,o=a(e),s=e.size||1,l=Math.floor((o-r)/s)+1,c=\"lines\"===e.coloring?0:1,u=i.extractOpts(t);isFinite(s)||(s=1,l=1);var h,f,p=u.reversescale?i.flipScale(u.colorscale):u.colorscale,d=p.length,g=new Array(d),v=new Array(d);if(\"heatmap\"===e.coloring){var m=u.min,y=u.max;for(f=0;f<d;f++)h=p[f],g[f]=h[0]*(y-m)+m,v[f]=h[1];var x=n.extent([m,y,e.start,e.start+s*(l-1)]),b=x[m<y?0:1],_=x[m<y?1:0];b!==m&&(g.splice(0,0,b),v.splice(0,0,v[0])),_!==y&&(g.push(_),v.push(v[v.length-1]))}else for(f=0;f<d;f++)h=p[f],g[f]=(h[0]*(l+c-1)-c/2)*s+r,v[f]=h[1];return i.makeColorScaleFunc({domain:g,range:v},{noNumericCheck:!0})}},{\"../../components/colorscale\":605,\"./end_plus\":953,d3:163}],959:[function(t,e,r){\"use strict\";var n=t(\"./constants\");function i(t,e){var r=(e[0][0]>t?0:1)+(e[0][1]>t?0:2)+(e[1][1]>t?0:4)+(e[1][0]>t?0:8);return 5===r||10===r?t>(e[0][0]+e[0][1]+e[1][0]+e[1][1])/4?5===r?713:1114:5===r?104:208:15===r?0:r}e.exports=function(t){var e,r,a,o,s,l,c,u,h,f=t[0].z,p=f.length,d=f[0].length,g=2===p||2===d;for(r=0;r<p-1;r++)for(o=[],0===r&&(o=o.concat(n.BOTTOMSTART)),r===p-2&&(o=o.concat(n.TOPSTART)),e=0;e<d-1;e++)for(a=o.slice(),0===e&&(a=a.concat(n.LEFTSTART)),e===d-2&&(a=a.concat(n.RIGHTSTART)),s=e+\",\"+r,l=[[f[r][e],f[r][e+1]],[f[r+1][e],f[r+1][e+1]]],h=0;h<t.length;h++)(c=i((u=t[h]).level,l))&&(u.crossings[s]=c,-1!==a.indexOf(c)&&(u.starts.push([e,r]),g&&-1!==a.indexOf(c,a.indexOf(c)+1)&&u.starts.push([e,r])))}},{\"./constants\":946}],960:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../../plots/cartesian/set_convert\"),c=t(\"../heatmap/plot\"),u=t(\"./make_crossings\"),h=t(\"./find_all_paths\"),f=t(\"./empty_pathinfo\"),p=t(\"./convert_to_constraints\"),d=t(\"./close_boundaries\"),g=t(\"./constants\"),v=g.LABELOPTIMIZER;function m(t,e){var r,n,o,s,l,c,u,h=function(t,e){var r=t.prefixBoundary;if(void 0===r){var n=Math.min(t.z[0][0],t.z[0][1]);r=!t.edgepaths.length&&n>t.level}return r?\"M\"+e.join(\"L\")+\"Z\":\"\"}(t,e),f=0,p=t.edgepaths.map(function(t,e){return e}),d=!0;function g(t){return Math.abs(t[1]-e[2][1])<.01}function v(t){return Math.abs(t[0]-e[0][0])<.01}function m(t){return Math.abs(t[0]-e[2][0])<.01}for(;p.length;){for(c=a.smoothopen(t.edgepaths[f],t.smoothing),h+=d?c:c.replace(/^M/,\"L\"),p.splice(p.indexOf(f),1),r=t.edgepaths[f][t.edgepaths[f].length-1],s=-1,o=0;o<4;o++){if(!r){i.log(\"Missing end?\",f,t);break}for(u=r,Math.abs(u[1]-e[0][1])<.01&&!m(r)?n=e[1]:v(r)?n=e[0]:g(r)?n=e[3]:m(r)&&(n=e[2]),l=0;l<t.edgepaths.length;l++){var y=t.edgepaths[l][0];Math.abs(r[0]-n[0])<.01?Math.abs(r[0]-y[0])<.01&&(y[1]-r[1])*(n[1]-y[1])>=0&&(n=y,s=l):Math.abs(r[1]-n[1])<.01?Math.abs(r[1]-y[1])<.01&&(y[0]-r[0])*(n[0]-y[0])>=0&&(n=y,s=l):i.log(\"endpt to newendpt is not vert. or horz.\",r,n,y)}if(r=n,s>=0)break;h+=\"L\"+n}if(s===t.edgepaths.length){i.log(\"unclosed perimeter path\");break}f=s,(d=-1===p.indexOf(f))&&(f=p[0],h+=\"Z\")}for(f=0;f<t.paths.length;f++)h+=a.smoothclosed(t.paths[f],t.smoothing);return h}function y(t,e,r,n){var a=e.width/2,o=e.height/2,s=t.x,l=t.y,c=t.theta,u=Math.cos(c)*a,h=Math.sin(c)*a,f=(s>n.center?n.right-s:s-n.left)/(u+Math.abs(Math.sin(c)*o)),p=(l>n.middle?n.bottom-l:l-n.top)/(Math.abs(h)+Math.cos(c)*o);if(f<1||p<1)return 1/0;var d=v.EDGECOST*(1/(f-1)+1/(p-1));d+=v.ANGLECOST*c*c;for(var g=s-u,m=l-h,y=s+u,x=l+h,b=0;b<r.length;b++){var _=r[b],w=Math.cos(_.theta)*_.width/2,k=Math.sin(_.theta)*_.width/2,T=2*i.segmentDistance(g,m,y,x,_.x-w,_.y-k,_.x+w,_.y+k)/(e.height+_.height),A=_.level===e.level,M=A?v.SAMELEVELDISTANCE:1;if(T<=M)return 1/0;d+=v.NEIGHBORCOST*(A?v.SAMELEVELFACTOR:1)/(T-M)}return d}r.plot=function(t,e,o,s){var l=e.xaxis,v=e.yaxis;i.makeTraceGroups(s,o,\"contour\").each(function(o){var s=n.select(this),y=o[0],x=y.trace,b=y.x,_=y.y,w=x.contours,k=f(w,e,y),T=i.ensureSingle(s,\"g\",\"heatmapcoloring\"),A=[];\"heatmap\"===w.coloring&&(A=[o]),c(t,e,A,T),u(k),h(k);var M=l.c2p(b[0],!0),S=l.c2p(b[b.length-1],!0),E=v.c2p(_[0],!0),C=v.c2p(_[_.length-1],!0),L=[[M,C],[S,C],[S,E],[M,E]],P=k;\"constraint\"===w.type&&(P=p(k,w._operation),d(P,w._operation,L,x)),function(t,e,r){var n=i.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"===r.coloring?[0]:[]);n.enter().append(\"path\"),n.exit().remove(),n.attr(\"d\",\"M\"+e.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(s,L,w),function(t,e,r,a){var o=i.ensureSingle(t,\"g\",\"contourfill\").selectAll(\"path\").data(\"fill\"===a.coloring||\"constraint\"===a.type&&\"=\"!==a._operation?e:[]);o.enter().append(\"path\"),o.exit().remove(),o.each(function(t){var e=m(t,r);e?n.select(this).attr(\"d\",e).style(\"stroke\",\"none\"):n.select(this).remove()})}(s,P,L,w),function(t,e,o,s,l){var c=i.ensureSingle(t,\"g\",\"contourlines\"),u=!1!==l.showlines,h=l.showlabels,f=u&&h,p=r.createLines(c,u||h,e),d=r.createLineClip(c,f,o,s.trace.uid),v=t.selectAll(\"g.contourlabels\").data(h?[0]:[]);if(v.exit().remove(),v.enter().append(\"g\").classed(\"contourlabels\",!0),h){var m=[],y=[];i.clearLocationCache();var x=r.labelFormatter(l,s.t.cb,o._fullLayout),b=a.tester.append(\"text\").attr(\"data-notex\",1).call(a.font,l.labelfont),_=e[0].xaxis,w=e[0].yaxis,k=_._length,T=w._length,A=_.range,M=w.range,S=i.aggNums(Math.min,null,s.x),E=i.aggNums(Math.max,null,s.x),C=i.aggNums(Math.min,null,s.y),L=i.aggNums(Math.max,null,s.y),P=Math.max(_.c2p(S,!0),0),O=Math.min(_.c2p(E,!0),k),z=Math.max(w.c2p(L,!0),0),I=Math.min(w.c2p(C,!0),T),D={};A[0]<A[1]?(D.left=P,D.right=O):(D.left=O,D.right=P),M[0]<M[1]?(D.top=z,D.bottom=I):(D.top=I,D.bottom=z),D.middle=(D.top+D.bottom)/2,D.center=(D.left+D.right)/2,m.push([[D.left,D.top],[D.right,D.top],[D.right,D.bottom],[D.left,D.bottom]]);var R=Math.sqrt(k*k+T*T),F=g.LABELDISTANCE*R/Math.max(1,e.length/g.LABELINCREASE);p.each(function(t){var e=r.calcTextOpts(t.level,x,b,o);n.select(this).selectAll(\"path\").each(function(){var t=i.getVisibleSegment(this,D,e.height/2);if(t&&!(t.len<(e.width+e.height)*g.LABELMIN))for(var n=Math.min(Math.ceil(t.len/F),g.LABELMAX),a=0;a<n;a++){var o=r.findBestTextLocation(this,t,e,y,D);if(!o)break;r.addLabelData(o,e,y,m)}})}),b.remove(),r.drawLabels(v,y,o,d,f?m:null)}h&&!u&&p.remove()}(s,k,t,y,w),function(t,e,r,n,o){var s=r._fullLayout._clips,l=\"clip\"+n.trace.uid,c=s.selectAll(\"#\"+l).data(n.trace.connectgaps?[]:[0]);if(c.enter().append(\"clipPath\").classed(\"contourclip\",!0).attr(\"id\",l),c.exit().remove(),!1===n.trace.connectgaps){var f={level:.9,crossings:{},starts:[],edgepaths:[],paths:[],xaxis:e.xaxis,yaxis:e.yaxis,x:n.x,y:n.y,z:function(t){var e,r,n=t.trace._emptypoints,i=[],a=t.z.length,o=t.z[0].length,s=[];for(e=0;e<o;e++)s.push(1);for(e=0;e<a;e++)i.push(s.slice());for(e=0;e<n.length;e++)r=n[e],i[r[0]][r[1]]=0;return t.zmask=i,i}(n),smoothing:0};u([f]),h([f]);var p=m(f,o),d=i.ensureSingle(c,\"path\",\"\");d.attr(\"d\",p)}else l=null;a.setClipUrl(t,l,r)}(s,e,t,y,L)})},r.createLines=function(t,e,r){var n=r[0].smoothing,i=t.selectAll(\"g.contourlevel\").data(e?r:[]);if(i.exit().remove(),i.enter().append(\"g\").classed(\"contourlevel\",!0),e){var o=i.selectAll(\"path.openline\").data(function(t){return t.pedgepaths||t.edgepaths});o.exit().remove(),o.enter().append(\"path\").classed(\"openline\",!0),o.attr(\"d\",function(t){return a.smoothopen(t,n)}).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\");var s=i.selectAll(\"path.closedline\").data(function(t){return t.ppaths||t.paths});s.exit().remove(),s.enter().append(\"path\").classed(\"closedline\",!0),s.attr(\"d\",function(t){return a.smoothclosed(t,n)}).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\")}return i},r.createLineClip=function(t,e,r,n){var i=e?\"clipline\"+n:null,o=r._fullLayout._clips.selectAll(\"#\"+i).data(e?[0]:[]);return o.exit().remove(),o.enter().append(\"clipPath\").classed(\"contourlineclip\",!0).attr(\"id\",i),a.setClipUrl(t,i,r),o},r.labelFormatter=function(t,e,r){if(t.labelformat)return r._d3locale.numberFormat(t.labelformat);var n;if(e)n=e.axis;else{if(n={type:\"linear\",_id:\"ycontour\",showexponent:\"all\",exponentformat:\"B\"},\"constraint\"===t.type){var i=t.value;Array.isArray(i)?n.range=[i[0],i[i.length-1]]:n.range=[i,i]}else n.range=[t.start,t.end],n.nticks=(t.end-t.start)/t.size;n.range[0]===n.range[1]&&(n.range[1]+=n.range[0]||1),n.nticks||(n.nticks=1e3),l(n,r),s.prepTicks(n),n._tmin=null,n._tmax=null}return function(t){return s.tickText(n,t).text}},r.calcTextOpts=function(t,e,r,n){var i=e(t);r.text(i).call(o.convertToTspans,n);var s=a.bBox(r.node(),!0);return{text:i,width:s.width,height:s.height,level:t,dy:(s.top+s.bottom)/2}},r.findBestTextLocation=function(t,e,r,n,a){var o,s,l,c,u,h=r.width;e.isClosed?(s=e.len/v.INITIALSEARCHPOINTS,o=e.min+s/2,l=e.max):(s=(e.len-h)/(v.INITIALSEARCHPOINTS+1),o=e.min+s+h/2,l=e.max-(s+h)/2);for(var f=1/0,p=0;p<v.ITERATIONS;p++){for(var d=o;d<l;d+=s){var g=i.getTextLocation(t,e.total,d,h),m=y(g,r,n,a);m<f&&(f=m,u=g,c=d)}if(f>2*v.MAXCOST)break;p&&(s/=2),l=(o=c-s/2)+1.5*s}if(f<=v.MAXCOST)return u},r.addLabelData=function(t,e,r,n){var i=e.width/2,a=e.height/2,o=t.x,s=t.y,l=t.theta,c=Math.sin(l),u=Math.cos(l),h=i*u,f=a*c,p=i*c,d=-a*u,g=[[o-h-f,s-p-d],[o+h-f,s+p-d],[o+h+f,s+p+d],[o-h+f,s-p+d]];r.push({text:e.text,x:o,y:s,dy:e.dy,theta:l,level:e.level,width:e.width,height:e.height}),n.push(g)},r.drawLabels=function(t,e,r,a,s){var l=t.selectAll(\"text\").data(e,function(t){return t.text+\",\"+t.x+\",\"+t.y+\",\"+t.theta});if(l.exit().remove(),l.enter().append(\"text\").attr({\"data-notex\":1,\"text-anchor\":\"middle\"}).each(function(t){var e=t.x+Math.sin(t.theta)*t.dy,i=t.y-Math.cos(t.theta)*t.dy;n.select(this).text(t.text).attr({x:e,y:i,transform:\"rotate(\"+180*t.theta/Math.PI+\" \"+e+\" \"+i+\")\"}).call(o.convertToTspans,r)}),s){for(var c=\"\",u=0;u<s.length;u++)c+=\"M\"+s[u].join(\"L\")+\"Z\";i.ensureSingle(a,\"path\",\"\").attr(\"d\",c)}}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/set_convert\":785,\"../heatmap/plot\":1012,\"./close_boundaries\":944,\"./constants\":946,\"./convert_to_constraints\":950,\"./empty_pathinfo\":952,\"./find_all_paths\":954,\"./make_crossings\":959,d3:163}],961:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\");function a(t,e,r){var i={type:\"linear\",range:[t,e]};return n.autoTicks(i,(e-t)/(r||15)),i}e.exports=function(t,e){var r=t.contours;if(t.autocontour){var o=t.zmin,s=t.zmax;(t.zauto||void 0===o)&&(o=i.aggNums(Math.min,null,e)),(t.zauto||void 0===s)&&(s=i.aggNums(Math.max,null,e));var l=a(o,s,t.ncontours);r.size=l.dtick,r.start=n.tickFirst(l),l.range.reverse(),r.end=n.tickFirst(l),r.start===o&&(r.start+=r.size),r.end===s&&(r.end-=r.size),r.start>r.end&&(r.start=r.end=(r.start+r.end)/2),t._input.contours||(t._input.contours={}),i.extendFlat(t._input.contours,{start:r.start,end:r.end,size:r.size}),t._input.autocontour=!0}else if(\"constraint\"!==r.type){var c,u=r.start,h=r.end,f=t._input.contours;if(u>h&&(r.start=f.start=h,h=r.end=f.end=u,u=r.start),!(r.size>0))c=u===h?1:a(u,h,t.ncontours).dtick,f.size=r.size=c}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767}],962:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../heatmap/style\"),o=t(\"./make_color_map\");e.exports=function(t){var e=n.select(t).selectAll(\"g.contour\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.each(function(t){var e=n.select(this),r=t[0].trace,a=r.contours,s=r.line,l=a.size||1,c=a.start,u=\"constraint\"===a.type,h=!u&&\"lines\"===a.coloring,f=!u&&\"fill\"===a.coloring,p=h||f?o(r):null;e.selectAll(\"g.contourlevel\").each(function(t){n.select(this).selectAll(\"path\").call(i.lineGroupStyle,s.width,h?p(t.level):s.color,s.dash)});var d=a.labelfont;if(e.selectAll(\"g.contourlabels text\").each(function(t){i.font(n.select(this),{family:d.family,size:d.size,color:d.color||(h?p(t.level):s.color)})}),u)e.selectAll(\"g.contourfill path\").style(\"fill\",r.fillcolor);else if(f){var g;e.selectAll(\"g.contourfill path\").style(\"fill\",function(t){return void 0===g&&(g=t.level),p(t.level+.5*l)}),void 0===g&&(g=c),e.selectAll(\"g.contourbg path\").style(\"fill\",p(g-.5*l))}}),a(t)}},{\"../../components/drawing\":614,\"../heatmap/style\":1013,\"./make_color_map\":958,d3:163}],963:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/defaults\"),i=t(\"./label_defaults\");e.exports=function(t,e,r,a,o){var s,l=r(\"contours.coloring\"),c=\"\";\"fill\"===l&&(s=r(\"contours.showlines\")),!1!==s&&(\"lines\"!==l&&(c=r(\"line.color\",\"#000\")),r(\"line.width\",.5),r(\"line.dash\")),\"none\"!==l&&(!0!==t.showlegend&&(e.showlegend=!1),e._dfltShowLegend=!1,n(t,e,a,r,{prefix:\"\",cLetter:\"z\"})),r(\"line.smoothing\"),i(r,a,c,o)}},{\"../../components/colorscale/defaults\":603,\"./label_defaults\":957}],964:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../contour/attributes\"),a=i.contours,o=t(\"../scatter/attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../lib/extend\").extendFlat,c=o.line;e.exports=l({carpet:{valType:\"string\",editType:\"calc\"},z:n.z,a:n.x,a0:n.x0,da:n.dx,b:n.y,b0:n.y0,db:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,atype:n.xtype,btype:n.ytype,fillcolor:i.fillcolor,autocontour:i.autocontour,ncontours:i.ncontours,contours:{type:a.type,start:a.start,end:a.end,size:a.size,coloring:{valType:\"enumerated\",values:[\"fill\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:a.showlines,showlabels:a.showlabels,labelfont:a.labelfont,labelformat:a.labelformat,operation:a.operation,value:a.value,editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:l({},c.color,{}),width:c.width,dash:c.dash,smoothing:l({},c.smoothing,{}),editType:\"plot\"},transforms:void 0},s(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../contour/attributes\":942,\"../heatmap/attributes\":1001,\"../scatter/attributes\":1112}],965:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\"),i=t(\"../../lib\"),a=t(\"../heatmap/convert_column_xyz\"),o=t(\"../heatmap/clean_2d_array\"),s=t(\"../heatmap/interp2d\"),l=t(\"../heatmap/find_empties\"),c=t(\"../heatmap/make_bound_array\"),u=t(\"./defaults\"),h=t(\"../carpet/lookup_carpetid\"),f=t(\"../contour/set_contours\");e.exports=function(t,e){var r=e._carpetTrace=h(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){if(!e.a||!e.b){var p=t.data[r.index],d=t.data[e.index];d.a||(d.a=p.a),d.b||(d.b=p.b),u(d,e,e._defaultColor,t._fullLayout)}var g=function(t,e){var r,u,h,f,p,d,g,v=e._carpetTrace,m=v.aaxis,y=v.baxis;m._minDtick=0,y._minDtick=0,i.isArray1D(e.z)&&a(e,m,y,\"a\",\"b\",[\"z\"]);r=e._a=e._a||e.a,f=e._b=e._b||e.b,r=r?m.makeCalcdata(e,\"_a\"):[],f=f?y.makeCalcdata(e,\"_b\"):[],u=e.a0||0,h=e.da||1,p=e.b0||0,d=e.db||1,g=e._z=o(e._z||e.z,e.transpose),e._emptypoints=l(g),s(g,e._emptypoints);var x=i.maxRowLength(g),b=\"scaled\"===e.xtype?\"\":r,_=c(e,b,u,h,x,m),w=\"scaled\"===e.ytype?\"\":f,k=c(e,w,p,d,g.length,y),T={a:_,b:k,z:g};\"levels\"===e.contours.type&&\"none\"!==e.contours.coloring&&n(t,e,{vals:g,containerStr:\"\",cLetter:\"z\"});return[T]}(t,e);return f(e,e._z),g}}},{\"../../components/colorscale/calc\":601,\"../../lib\":719,\"../carpet/lookup_carpetid\":915,\"../contour/set_contours\":961,\"../heatmap/clean_2d_array\":1003,\"../heatmap/convert_column_xyz\":1005,\"../heatmap/find_empties\":1007,\"../heatmap/interp2d\":1010,\"../heatmap/make_bound_array\":1011,\"./defaults\":966}],966:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"./attributes\"),o=t(\"../contour/constraint_defaults\"),s=t(\"../contour/contours_defaults\"),l=t(\"../contour/style_defaults\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,a,r,i)}if(u(\"carpet\"),t.a&&t.b){if(!i(t,e,u,c,\"a\",\"b\"))return void(e.visible=!1);u(\"text\"),\"constraint\"===u(\"contours.type\")?o(t,e,u,c,r,{hasHover:!1}):(s(t,e,u,function(r){return n.coerce2(t,e,a,r)}),l(t,e,u,c,{hasHover:!1}))}else e._defaultColor=r,e._length=null}},{\"../../lib\":719,\"../contour/constraint_defaults\":947,\"../contour/contours_defaults\":949,\"../contour/style_defaults\":963,\"../heatmap/xyz_defaults\":1015,\"./attributes\":964}],967:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../contour/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../contour/style\"),moduleType:\"trace\",name:\"contourcarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"contour\",\"symbols\",\"showLegend\",\"hasLines\",\"carpetDependent\"],meta:{}}},{\"../../plots/cartesian\":778,\"../contour/colorbar\":945,\"../contour/style\":962,\"./attributes\":964,\"./calc\":965,\"./defaults\":966,\"./plot\":970}],968:[function(t,e,r){\"use strict\";var n=t(\"../../components/drawing\"),i=t(\"../carpet/axis_aligned_line\"),a=t(\"../../lib\");e.exports=function(t,e,r,o,s,l,c,u){var h,f,p,d,g,v,m,y=\"\",x=e.edgepaths.map(function(t,e){return e}),b=!0,_=1e-4*Math.abs(r[0][0]-r[2][0]),w=1e-4*Math.abs(r[0][1]-r[2][1]);function k(t){return Math.abs(t[1]-r[0][1])<w}function T(t){return Math.abs(t[1]-r[2][1])<w}function A(t){return Math.abs(t[0]-r[0][0])<_}function M(t){return Math.abs(t[0]-r[2][0])<_}function S(t,e){var r,n,a,o,h=\"\";for(k(t)&&!M(t)||T(t)&&!A(t)?(o=s.aaxis,a=i(s,l,[t[0],e[0]],.5*(t[1]+e[1]))):(o=s.baxis,a=i(s,l,.5*(t[0]+e[0]),[t[1],e[1]])),r=1;r<a.length;r++)for(h+=o.smoothing?\"C\":\"L\",n=0;n<a[r].length;n++){var f=a[r][n];h+=[c.c2p(f[0]),u.c2p(f[1])]+\" \"}return h}for(h=0,f=null;x.length;){var E=e.edgepaths[h][0];for(f&&(y+=S(f,E)),m=n.smoothopen(e.edgepaths[h].map(o),e.smoothing),y+=b?m:m.replace(/^M/,\"L\"),x.splice(x.indexOf(h),1),f=e.edgepaths[h][e.edgepaths[h].length-1],g=-1,d=0;d<4;d++){if(!f){a.log(\"Missing end?\",h,e);break}for(k(f)&&!M(f)?p=r[1]:A(f)?p=r[0]:T(f)?p=r[3]:M(f)&&(p=r[2]),v=0;v<e.edgepaths.length;v++){var C=e.edgepaths[v][0];Math.abs(f[0]-p[0])<_?Math.abs(f[0]-C[0])<_&&(C[1]-f[1])*(p[1]-C[1])>=0&&(p=C,g=v):Math.abs(f[1]-p[1])<w?Math.abs(f[1]-C[1])<w&&(C[0]-f[0])*(p[0]-C[0])>=0&&(p=C,g=v):a.log(\"endpt to newendpt is not vert. or horz.\",f,p,C)}if(g>=0)break;y+=S(f,p),f=p}if(g===e.edgepaths.length){a.log(\"unclosed perimeter path\");break}h=g,(b=-1===x.indexOf(h))&&(h=x[0],y+=S(f,p)+\"Z\",f=null)}for(h=0;h<e.paths.length;h++)y+=n.smoothclosed(e.paths[h].map(o),e.smoothing);return y}},{\"../../components/drawing\":614,\"../../lib\":719,\"../carpet/axis_aligned_line\":899}],969:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i,a,o,s,l,c,u;for(r=0;r<t.length;r++){for(o=(a=t[r]).pedgepaths=[],s=a.ppaths=[],n=0;n<a.edgepaths.length;n++){for(u=a.edgepaths[n],l=[],i=0;i<u.length;i++)l[i]=e(u[i]);o.push(l)}for(n=0;n<a.paths.length;n++){for(u=a.paths[n],c=[],i=0;i<u.length;i++)c[i]=e(u[i]);s.push(c)}}}},{}],970:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../carpet/map_1d_array\"),a=t(\"../carpet/makepath\"),o=t(\"../../components/drawing\"),s=t(\"../../lib\"),l=t(\"../contour/make_crossings\"),c=t(\"../contour/find_all_paths\"),u=t(\"../contour/plot\"),h=t(\"../contour/constants\"),f=t(\"../contour/convert_to_constraints\"),p=t(\"./join_all_paths\"),d=t(\"../contour/empty_pathinfo\"),g=t(\"./map_pathinfo\"),v=t(\"../carpet/lookup_carpetid\"),m=t(\"../contour/close_boundaries\");function y(t,e,r){var n=t.getPointAtLength(e),i=t.getPointAtLength(r),a=i.x-n.x,o=i.y-n.y,s=Math.sqrt(a*a+o*o);return[a/s,o/s]}function x(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]);return[t[0]/e,t[1]/e]}function b(t,e){var r=Math.abs(t[0]*e[0]+t[1]*e[1]);return Math.sqrt(1-r*r)/r}e.exports=function(t,e,r,_){var w=e.xaxis,k=e.yaxis;s.makeTraceGroups(_,r,\"contour\").each(function(r){var _=n.select(this),T=r[0],A=T.trace,M=A._carpetTrace=v(t,A),S=t.calcdata[M.index][0];if(M.visible&&\"legendonly\"!==M.visible){var E=T.a,C=T.b,L=A.contours,P=d(L,e,T),O=\"constraint\"===L.type,z=L._operation,I=O?\"=\"===z?\"lines\":\"fill\":L.coloring,D=[[E[0],C[C.length-1]],[E[E.length-1],C[C.length-1]],[E[E.length-1],C[0]],[E[0],C[0]]];l(P);var R=1e-8*(E[E.length-1]-E[0]),F=1e-8*(C[C.length-1]-C[0]);c(P,R,F);var B,N,j,U,V=P;\"constraint\"===L.type&&(V=f(P,z),m(V,z,D,A)),g(P,G);var q=[];for(U=S.clipsegments.length-1;U>=0;U--)B=S.clipsegments[U],N=i([],B.x,w.c2p),j=i([],B.y,k.c2p),N.reverse(),j.reverse(),q.push(a(N,j,B.bicubic));var H=\"M\"+q.join(\"L\")+\"Z\";!function(t,e,r,n,o,l){var c,u,h,f,p=s.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"!==l||o?[]:[0]);p.enter().append(\"path\"),p.exit().remove();var d=[];for(f=0;f<e.length;f++)c=e[f],u=i([],c.x,r.c2p),h=i([],c.y,n.c2p),d.push(a(u,h,c.bicubic));p.attr(\"d\",\"M\"+d.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(_,S.clipsegments,w,k,O,I),function(t,e,r,i,a,o,l,c,u,h,f){var d=s.ensureSingle(e,\"g\",\"contourfill\").selectAll(\"path\").data(\"fill\"===h?a:[]);d.enter().append(\"path\"),d.exit().remove(),d.each(function(e){var a=p(t,e,o,l,c,u,r,i);e.prefixBoundary&&(a=f+a),a?n.select(this).attr(\"d\",a).style(\"stroke\",\"none\"):n.select(this).remove()})}(A,_,w,k,V,D,G,M,S,I,H),function(t,e,r,i,a,l,c){var f=s.ensureSingle(t,\"g\",\"contourlines\"),p=!1!==a.showlines,d=a.showlabels,g=p&&d,v=u.createLines(f,p||d,e),m=u.createLineClip(f,g,r,i.trace.uid),_=t.selectAll(\"g.contourlabels\").data(d?[0]:[]);if(_.exit().remove(),_.enter().append(\"g\").classed(\"contourlabels\",!0),d){var w=l.xaxis,k=l.yaxis,T=w._length,A=k._length,M=[[[0,0],[T,0],[T,A],[0,A]]],S=[];s.clearLocationCache();var E=u.labelFormatter(a,i.t.cb,r._fullLayout),C=o.tester.append(\"text\").attr(\"data-notex\",1).call(o.font,a.labelfont),L={left:0,right:T,center:T/2,top:0,bottom:A,middle:A/2},P=Math.sqrt(T*T+A*A),O=h.LABELDISTANCE*P/Math.max(1,e.length/h.LABELINCREASE);v.each(function(t){var e=u.calcTextOpts(t.level,E,C,r);n.select(this).selectAll(\"path\").each(function(r){var n=s.getVisibleSegment(this,L,e.height/2);if(n&&(function(t,e,r,n,i,a){for(var o,s=0;s<r.pedgepaths.length;s++)e===r.pedgepaths[s]&&(o=r.edgepaths[s]);if(!o)return;var l=i.a[0],c=i.a[i.a.length-1],u=i.b[0],h=i.b[i.b.length-1];function f(t,e){var r,n=0;return(Math.abs(t[0]-l)<.1||Math.abs(t[0]-c)<.1)&&(r=x(i.dxydb_rough(t[0],t[1],.1)),n=Math.max(n,a*b(e,r)/2)),(Math.abs(t[1]-u)<.1||Math.abs(t[1]-h)<.1)&&(r=x(i.dxyda_rough(t[0],t[1],.1)),n=Math.max(n,a*b(e,r)/2)),n}var p=y(t,0,1),d=y(t,n.total,n.total-1),g=f(o[0],p),v=n.total-f(o[o.length-1],d);n.min<g&&(n.min=g);n.max>v&&(n.max=v);n.len=n.max-n.min}(this,r,t,n,c,e.height),!(n.len<(e.width+e.height)*h.LABELMIN)))for(var i=Math.min(Math.ceil(n.len/O),h.LABELMAX),a=0;a<i;a++){var o=u.findBestTextLocation(this,n,e,S,L);if(!o)break;u.addLabelData(o,e,S,M)}})}),C.remove(),u.drawLabels(_,S,r,m,g?M:null)}d&&!p&&v.remove()}(_,P,t,T,L,e,M),o.setClipUrl(_,M._clipPathId,t)}function G(t){var e=M.ab2xy(t[0],t[1],!0);return[w.c2p(e[0]),k.c2p(e[1])]}})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../carpet/lookup_carpetid\":915,\"../carpet/makepath\":916,\"../carpet/map_1d_array\":917,\"../contour/close_boundaries\":944,\"../contour/constants\":946,\"../contour/convert_to_constraints\":950,\"../contour/empty_pathinfo\":952,\"../contour/find_all_paths\":954,\"../contour/make_crossings\":959,\"../contour/plot\":960,\"./join_all_paths\":968,\"./map_pathinfo\":969,d3:163}],971:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../scattermapbox/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({lon:o.lon,lat:o.lat,z:{valType:\"data_array\",editType:\"calc\"},radius:{valType:\"number\",editType:\"plot\",arrayOk:!0,min:1,dflt:30},below:{valType:\"string\",editType:\"plot\"},text:o.text,hovertext:o.hovertext,hoverinfo:s({},a.hoverinfo,{flags:[\"lon\",\"lat\",\"z\",\"text\",\"name\"]}),hovertemplate:i()},n(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scattermapbox/attributes\":1171}],972:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../components/colorscale/calc\"),s=t(\"../../lib\")._;e.exports=function(t,e){for(var r=e._length,l=new Array(r),c=e.z,u=i(c)&&c.length,h=0;h<r;h++){var f=l[h]={},p=e.lon[h],d=e.lat[h];if(f.lonlat=n(p)&&n(d)?[+p,+d]:[a,a],u){var g=c[h];f.z=n(g)?g:a}}return o(t,e,{vals:u?c:[0,1],containerStr:\"\",cLetter:\"z\"}),r&&(l[0].t={labels:{lat:s(t,\"lat:\")+\" \",lon:s(t,\"lon:\")+\" \"}}),l}},{\"../../components/colorscale/calc\":601,\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],973:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../../components/colorscale\"),s=t(\"../../constants/numerical\").BADNUM,l=t(\"../../lib/geojson_utils\").makeBlank;e.exports=function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,c=e._opts={heatmap:{layout:{visibility:\"none\"},paint:{}},geojson:l()};if(!r)return c;var u,h=[],f=e.z,p=e.radius,d=i.isArrayOrTypedArray(f)&&f.length,g=i.isArrayOrTypedArray(p);for(u=0;u<t.length;u++){var v=t[u],m=v.lonlat;if(m[0]!==s){var y={};if(d){var x=v.z;y.z=x!==s?x:0}g&&(y.r=n(p[u])&&p[u]>0?+p[u]:0),h.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:m},properties:y})}}var b=o.extractOpts(e),_=b.reversescale?o.flipScale(b.colorscale):b.colorscale,w=_[0][1],k=[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,a.opacity(w)<1?w:a.addOpacity(w,0)];for(u=1;u<_.length;u++)k.push(_[u][0],_[u][1]);var T=[\"interpolate\",[\"linear\"],[\"get\",\"z\"],b.min,0,b.max,1];return i.extendFlat(c.heatmap.paint,{\"heatmap-weight\":d?T:1/(b.max-b.min),\"heatmap-color\":k,\"heatmap-radius\":g?{type:\"identity\",property:\"r\"}:e.radius,\"heatmap-opacity\":e.opacity}),c.geojson={type:\"FeatureCollection\",features:h},c.heatmap.layout.visibility=\"visible\",c}},{\"../../components/color\":593,\"../../components/colorscale\":605,\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/geojson_utils\":714,\"fast-isnumeric\":225}],974:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"lon\")||[],c=s(\"lat\")||[],u=Math.min(l.length,c.length);u?(e._length=u,s(\"z\"),s(\"radius\"),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":971}],975:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.z=e.z,t}},{}],976:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../scattermapbox/hover\");e.exports=function(t,e,r){var o=a(t,e,r);if(o){var s=o[0],l=s.cd,c=l[0].trace,u=l[s.index];if(delete s.color,\"z\"in u){var h=s.subplot.mockAxis;s.z=u.z,s.zLabel=i.tickText(h,h.c2l(u.z),\"hover\").text}return s.extraText=function(t,e,r){if(t.hovertemplate)return;var i=(e.hi||t.hoverinfo).split(\"+\"),a=-1!==i.indexOf(\"all\"),o=-1!==i.indexOf(\"lon\"),s=-1!==i.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}a||o&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):o?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(a||-1!==i.indexOf(\"text\"))&&n.fillText(e,t,c);return c.join(\"<br>\")}(c,u,l[0].t.labels),[s]}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scattermapbox/hover\":1175}],977:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),getBelow:function(t,e){for(var r=e.getMapLayers(),n=0;n<r.length;n++){var i=r[n],a=i.id;if(\"symbol\"===i.type&&\"string\"==typeof a&&-1===a.indexOf(\"plotly-\"))return a}},moduleType:\"trace\",name:\"densitymapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\"],meta:{hr_name:\"density_mapbox\"}}},{\"../../plots/mapbox\":822,\"../heatmap/colorbar\":1004,\"./attributes\":971,\"./calc\":972,\"./defaults\":974,\"./event_data\":975,\"./hover\":976,\"./plot\":978}],978:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function a(t,e){this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"heatmap\",i+e+\"-heatmap\"]],this.below=null}var o=a.prototype;o.update=function(t){var e=this.subplot,r=this.layerList,i=n(t),a=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(i.geojson),a!==this.below&&(this._removeLayers(),this._addLayers(i,a),this.below=a);for(var o=0;o<r.length;o++){var s=r[o],l=s[0],c=s[1],u=i[l];e.setOptions(c,\"setLayoutProperty\",u.layout),\"visible\"===u.layout.visibility&&e.setOptions(c,\"setPaintProperty\",u.paint)}},o._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},o._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},o.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new a(t,r.uid),o=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(o,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),i}},{\"../../plots/mapbox/constants\":820,\"./convert\":973}],979:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":719}],980:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"./constants\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../components/color\");e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,hovertext:n.hovertext,hovertemplate:o({},{keys:s.eventDataKeys}),hoverinfo:l({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"percent initial\",\"percent previous\",\"percent total\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"percent initial\",\"percent previous\",\"percent total\",\"value\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},text:n.text,textposition:l({},n.textposition,{dflt:\"auto\"}),insidetextanchor:l({},n.insidetextanchor,{dflt:\"middle\"}),textangle:l({},n.textangle,{dflt:0}),textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:l({},n.orientation,{}),offset:l({},n.offset,{arrayOk:!1}),width:l({},n.width,{arrayOk:!1}),marker:n.marker,connector:{fillcolor:{valType:\"color\",editType:\"style\"},line:{color:l({},i.color,{dflt:c.defaultLine}),width:l({},i.width,{dflt:0,editType:\"plot\"}),dash:i.dash,editType:\"style\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":593,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../bar/attributes\":857,\"../scatter/attributes\":1112,\"./constants\":982}],981:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"./arrays_to_calcdata\"),a=t(\"../scatter/calc_selection\"),o=t(\"../../constants/numerical\").BADNUM;function s(t){return t===o?0:t}e.exports=function(t,e){var r,l,c,u,h=n.getFromId(t,e.xaxis||\"x\"),f=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=h.makeCalcdata(e,\"x\"),l=f.makeCalcdata(e,\"y\")):(r=f.makeCalcdata(e,\"y\"),l=h.makeCalcdata(e,\"x\"));var p,d=Math.min(l.length,r.length),g=new Array(d);for(e._base=[],c=0;c<d;c++){r[c]<0&&(r[c]=o);var v=!1;r[c]!==o&&c+1<d&&r[c+1]!==o&&(v=!0),u=g[c]={p:l[c],s:r[c],cNext:v},e._base[c]=-.5*u.s,e.ids&&(u.id=String(e.ids[c])),0===c&&(g[0].vTotal=0),g[0].vTotal+=s(u.s),u.begR=s(u.s)/s(g[0].s)}for(c=0;c<d;c++)(u=g[c]).s!==o&&(u.sumR=u.s/g[0].vTotal,u.difR=void 0!==p?u.s/p:1,p=u.s);return i(g,e),a(g,e),g}},{\"../../constants/numerical\":695,\"../../plots/cartesian/axes\":767,\"../scatter/calc_selection\":1114,\"./arrays_to_calcdata\":979}],982:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"percentInitial\",\"percentPrevious\",\"percentTotal\"]}},{}],983:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],h=[],f=[];for(i=0;i<o.length;i++){var p=o[i],d=\"h\"===p.orientation;!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"funnel\"===p.type&&(r=s[i],d?f.push(r):h.push(r),u.push(r))}var g={mode:a.funnelmode,norm:a.funnelnorm,gap:a.funnelgap,groupgap:a.funnelgroupgap};for(n(t,l,c,h,g),n(t,c,l,f,g),i=0;i<u.length;i++){r=u[i];for(var v=0;v<r.length;v++)v+1<r.length&&(r[v].nextP0=r[v+1].p0,r[v].nextS0=r[v+1].s0,r[v].nextP1=r[v+1].p1,r[v].nextS1=r[v+1].s1)}}},{\"../bar/cross_trace_calc\":860}],984:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"./attributes\"),l=t(\"../../components/color\");e.exports={supplyDefaults:function(t,e,r,i){function c(r,i){return n.coerce(t,e,s,r,i)}if(o(t,e,i,c)){c(\"orientation\",e.y&&!e.x?\"v\":\"h\"),c(\"offset\"),c(\"width\");var u=c(\"text\");c(\"hovertext\"),c(\"hovertemplate\");var h=c(\"textposition\");a(t,e,i,c,h,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"!==e.textposition&&c(\"textinfo\",Array.isArray(u)?\"text+value\":\"value\");var f=c(\"marker.color\",r);c(\"marker.line.color\",l.defaultLine),c(\"marker.line.width\"),c(\"connector.visible\")&&(c(\"connector.fillcolor\",function(t){var e=n.isArrayOrTypedArray(t)?\"#000\":t;return l.addOpacity(e,.5*l.opacity(e))}(f)),c(\"connector.line.width\")&&(c(\"connector.line.color\"),c(\"connector.line.dash\")))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,s,t)}if(\"group\"===e.funnelmode)for(var l=0;l<t.length;l++)r=(a=t[l])._input,i(r,a,e,o)}}},{\"../../components/color\":593,\"../../lib\":719,\"../bar/defaults\":861,\"../scatter/xy_defaults\":1137,\"./attributes\":980}],985:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"percentInitial\"in e&&(t.percentInitial=e.percentInitial),\"percentPrevious\"in e&&(t.percentPrevious=e.percentPrevious),\"percentTotal\"in e&&(t.percentTotal=e.percentTotal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],986:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\").opacity,i=t(\"../bar/hover\").hoverOnBars,a=t(\"../../lib\").formatPercent;e.exports=function(t,e,r,o){var s=i(t,e,r,o);if(s){var l=s.cd,c=l[0].trace,u=\"h\"===c.orientation,h=l[s.index];s[(u?\"x\":\"y\")+\"LabelVal\"]=h.s,s.percentInitial=h.begR,s.percentInitialLabel=a(h.begR,1),s.percentPrevious=h.difR,s.percentPreviousLabel=a(h.difR,1),s.percentTotal=h.sumR,s.percentTotalLabel=a(h.sumR,1);var f=h.hi||c.hoverinfo,p=[];if(f&&\"none\"!==f&&\"skip\"!==f){var d=\"all\"===f,g=f.split(\"+\"),v=function(t){return d||-1!==g.indexOf(t)};v(\"percent initial\")&&p.push(s.percentInitialLabel+\" of initial\"),v(\"percent previous\")&&p.push(s.percentPreviousLabel+\" of previous\"),v(\"percent total\")&&p.push(s.percentTotalLabel+\" of total\")}return s.extraText=p.join(\"<br>\"),s.color=function(t,e){var r=t.marker,i=e.mc||r.color,a=e.mlc||r.line.color,o=e.mlw||r.line.width;if(n(i))return i;if(n(a)&&o)return a}(c,h),[s]}}},{\"../../components/color\":593,\"../../lib\":719,\"../bar/hover\":863}],987:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"funnel\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../bar/select\":868,\"./attributes\":980,\"./calc\":981,\"./cross_trace_calc\":983,\"./defaults\":984,\"./event_data\":985,\"./hover\":986,\"./layout_attributes\":988,\"./layout_defaults\":989,\"./plot\":990,\"./style\":991}],988:[function(t,e,r){\"use strict\";e.exports={funnelmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},funnelgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},funnelgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],989:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"funnel\"===l.type){a=!0;break}}a&&(o(\"funnelmode\"),o(\"funnelgap\",.2),o(\"funnelgroupgap\"))}},{\"../../lib\":719,\"./layout_attributes\":988}],990:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../bar/plot\").plot;function s(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),i[3]=o.c2p(t.nextS1,!0),a[3]=s.c2p(t.nextP1,!0),n?[i,a]:[a,i]}e.exports=function(t,e,r,l){var c=t._fullLayout;!function(t,e,r,o){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each(function(r){var o=n.select(this),u=r[0].trace,h=i.ensureSingle(o,\"g\",\"regions\");if(u.connector&&u.connector.visible){var f=\"h\"===u.orientation,p=h.selectAll(\"g.region\").data(i.identity);p.enter().append(\"g\").classed(\"region\",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var u=s(r,l,c,f),h=u[0],p=u[1],g=\"\";void 0!==h[3]&&void 0!==p[3]&&(g+=f?\"M\"+h[0]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[2]+\"H\"+h[3]+\"L\"+h[1]+\",\"+p[1]+\"Z\":\"M\"+h[1]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[3]+\"V\"+p[2]+\"L\"+h[1]+\",\"+p[0]+\"Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}})}else h.remove()})}(t,e,r,l),function(t,e,r,o){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each(function(r){var o=n.select(this),u=r[0].trace,h=i.ensureSingle(o,\"g\",\"lines\");if(u.connector&&u.connector.visible&&u.connector.line.width){var f=\"h\"===u.orientation,p=h.selectAll(\"g.line\").data(i.identity);p.enter().append(\"g\").classed(\"line\",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var u=s(r,l,c,f),h=u[0],p=u[1],g=\"\";void 0!==h[3]&&void 0!==p[3]&&(f?(g+=\"M\"+h[0]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[2],g+=\"M\"+h[1]+\",\"+p[1]+\"L\"+h[3]+\",\"+p[2]):(g+=\"M\"+h[1]+\",\"+p[1]+\"L\"+h[2]+\",\"+p[3],g+=\"M\"+h[1]+\",\"+p[0]+\"L\"+h[2]+\",\"+p[2])),\"\"===g&&(g=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}})}else h.remove()})}(t,e,r,l),o(t,e,r,l,{mode:c.funnelmode,norm:c.funnelmode,gap:c.funnelgap,groupgap:c.funnelgroupgap})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../bar/plot\":867,d3:163}],991:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\").styleTextPoints;e.exports={style:function(t,e,r){var l=r||n.select(t).selectAll(\"g.funnellayer\").selectAll(\"g.trace\");l.style(\"opacity\",function(t){return t[0].trace.opacity}),l.each(function(e){var r=n.select(this),l=e[0].trace;r.selectAll(\".point > path\").each(function(t){if(!t.isBlank){var e=l.marker;n.select(this).call(a.fill,t.mc||e.color).call(a.stroke,t.mlc||e.line.color).call(i.dashLine,e.line.dash,t.mlw||e.line.width).style(\"opacity\",l.selectedpoints&&!t.selected?o:1)}}),s(r,l,t),r.selectAll(\".regions\").each(function(){n.select(this).selectAll(\"path\").style(\"stroke-width\",0).call(a.fill,l.connector.fillcolor)}),r.selectAll(\".lines\").each(function(){var t=l.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)})})}}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../constants/interactions\":694,\"../bar/style\":870,d3:163}],992:[function(t,e,r){\"use strict\";var n=t(\"../pie/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../plots/domain\").attributes,o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports={labels:n.labels,label0:n.label0,dlabel:n.dlabel,values:n.values,marker:{colors:n.marker.colors,line:{color:s({},n.marker.line.color,{dflt:null}),width:s({},n.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},text:n.text,hovertext:n.hovertext,scalegroup:s({},n.scalegroup,{}),textinfo:s({},n.textinfo,{flags:[\"label\",\"text\",\"value\",\"percent\"]}),hoverinfo:s({},i.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:o({},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),textposition:s({},n.textposition,{values:[\"inside\",\"none\"],dflt:\"inside\"}),textfont:n.textfont,insidetextfont:n.insidetextfont,title:{text:n.title.text,font:n.title.font,position:s({},n.title.position,{values:[\"top left\",\"top center\",\"top right\"],dflt:\"top center\"}),editType:\"plot\"},domain:a({name:\"funnelarea\",trace:!0,editType:\"calc\"}),aspectratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},baseratio:{valType:\"number\",min:0,max:1,dflt:.333,editType:\"plot\"}}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../pie/attributes\":1086}],993:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData;r.name=\"funnelarea\",r.plot=function(t){var e=n.getModule(\"funnelarea\"),r=i(t.calcdata,e)[0];e.plot(t,r)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"funnelarea\"),a=e._has&&e._has(\"funnelarea\");i&&!a&&n._funnelarealayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],994:[function(t,e,r){\"use strict\";var n=t(\"../pie/calc\");e.exports={calc:function(t,e){return n.calc(t,e)},crossTraceCalc:function(t){n.crossTraceCalc(t,{type:\"funnelarea\"})}}},{\"../pie/calc\":1088}],995:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}var c,u=l(\"values\"),h=n.isArrayOrTypedArray(u),f=l(\"labels\");if(Array.isArray(f)?(c=f.length,h&&(c=Math.min(c,u.length))):h&&(c=u.length,l(\"label0\"),l(\"dlabel\")),c){e._length=c,l(\"marker.line.width\")&&l(\"marker.line.color\",s.paper_bgcolor),l(\"marker.colors\"),l(\"scalegroup\");var p=l(\"text\"),d=l(\"textinfo\",Array.isArray(p)?\"text+percent\":\"percent\");if(l(\"hovertext\"),l(\"hovertemplate\"),d&&\"none\"!==d){var g=l(\"textposition\");o(t,e,s,l,g,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}a(e,s,l),l(\"title.text\")&&(l(\"title.position\"),n.coerceFont(l,\"title.font\",s.font)),l(\"aspectratio\"),l(\"baseratio\")}else e.visible=!1}},{\"../../lib\":719,\"../../plots/domain\":792,\"../bar/defaults\":861,\"./attributes\":992}],996:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"funnelarea\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"funnelarea\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\"),styleOne:t(\"../pie/style_one\"),meta:{}}},{\"../pie/style_one\":1097,\"./attributes\":992,\"./base_plot\":993,\"./calc\":994,\"./defaults\":995,\"./layout_attributes\":997,\"./layout_defaults\":998,\"./plot\":999,\"./style\":1e3}],997:[function(t,e,r){\"use strict\";var n=t(\"../pie/layout_attributes\").hiddenlabels;e.exports={hiddenlabels:n,funnelareacolorway:{valType:\"colorlist\",editType:\"calc\"},extendfunnelareacolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{\"../pie/layout_attributes\":1093}],998:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"funnelareacolorway\",e.colorway),r(\"extendfunnelareacolors\")}},{\"../../lib\":719,\"./layout_attributes\":997}],999:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../lib\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../bar/plot\"),l=s.getTransform,c=s.toMoveInsideBar,u=t(\"../pie/helpers\"),h=t(\"../pie/plot\"),f=h.attachFxHandlers,p=h.determineInsideTextFont,d=h.layoutAreas,g=h.prerenderTitles,v=h.positionTitleOutside;function m(t,e){return\"l\"+(e[0]-t[0])+\",\"+(e[1]-t[1])}e.exports=function(t,e){var r=t._fullLayout;g(e,t),d(e,r._size),a.makeTraceGroups(r._funnelarealayer,e,\"trace\").each(function(e){var s=n.select(this),h=e[0],d=h.trace;!function(t){if(!t.length)return;var e=t[0],r=e.trace,n=r.aspectratio,i=r.baseratio;i>.999&&(i=.999);var a,o=Math.pow(i,2),s=e.vTotal,l=s,c=s*o/(1-o)/s;function u(){var t,e={x:t=Math.sqrt(c),y:-t};return[e.x,e.y]}var h,f,p=[];for(p.push(u()),h=t.length-1;h>-1;h--)if(!(f=t[h]).hidden){var d=f.v/l;c+=d,p.push(u())}var g=1/0,v=-1/0;for(h=0;h<p.length;h++)a=p[h],g=Math.min(g,a[1]),v=Math.max(v,a[1]);for(h=0;h<p.length;h++)p[h][1]-=(v+g)/2;var m=p[p.length-1][0],y=e.r,x=(v-g)/2,b=y/m,_=y/x*n;for(e.r=_*x,h=0;h<p.length;h++)p[h][0]*=b,p[h][1]*=_;var w=[-(a=p[0])[0],a[1]],k=[a[0],a[1]],T=0;for(h=t.length-1;h>-1;h--)if(!(f=t[h]).hidden){var A=p[T+=1][0],M=p[T][1];f.TL=[-A,M],f.TR=[A,M],f.BL=w,f.BR=k,f.pxmid=(S=f.TR,E=f.BR,[.5*(S[0]+E[0]),.5*(S[1]+E[1])]),w=f.TL,k=f.TR}var S,E}(e),s.each(function(){var s=n.select(this).selectAll(\"g.slice\").data(e);s.enter().append(\"g\").classed(\"slice\",!0),s.exit().remove(),s.each(function(r){if(r.hidden)n.select(this).selectAll(\"path,g\").remove();else{r.pointNumber=r.i,r.curveNumber=d.index;var s=h.cx,g=h.cy,v=n.select(this),y=v.selectAll(\"path.surface\").data([r]);y.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),v.call(f,t,e);var x=\"M\"+(s+r.TR[0])+\",\"+(g+r.TR[1])+m(r.TR,r.BR)+m(r.BR,r.BL)+m(r.BL,r.TL)+\"Z\";y.attr(\"d\",x);var b=u.castOption(d.textposition,r.pts),_=v.selectAll(\"g.slicetext\").data(r.text&&\"none\"!==b?[0]:[]);_.enter().append(\"g\").classed(\"slicetext\",!0),_.exit().remove(),_.each(function(){var e=a.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)});e.text(r.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,p(d,r,t._fullLayout.font)).call(o.convertToTspans,t);var u,h,f,v=i.bBox(e.node()),m=Math.min(r.BL[1],r.BR[1]),y=Math.max(r.TL[1],r.TR[1]);h=Math.max(r.TL[0],r.BL[0]),f=Math.min(r.TR[0],r.BR[0]),u=l(c(h,f,m,y,v,{isHorizontal:!0,constrained:!0,angle:0,anchor:\"middle\"})),e.attr(\"transform\",\"translate(\"+s+\",\"+g+\")\"+u)})}});var g=n.select(this).selectAll(\"g.titletext\").data(d.title.text?[0]:[]);g.enter().append(\"g\").classed(\"titletext\",!0),g.exit().remove(),g.each(function(){var e=a.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),s=d.title.text;d._meta&&(s=a.templateString(s,d._meta)),e.text(s).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,d.title.font).call(o.convertToTspans,t);var l=v(h,r._size);e.attr(\"transform\",\"translate(\"+l.x+\",\"+l.y+\")\"+(l.scale<1?\"scale(\"+l.scale+\")\":\"\")+\"translate(\"+l.tx+\",\"+l.ty+\")\")})})})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../bar/plot\":867,\"../pie/helpers\":1091,\"../pie/plot\":1095,d3:163}],1000:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../pie/style_one\");e.exports=function(t){t._fullLayout._funnelarealayer.selectAll(\".trace\").each(function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each(function(t){n.select(this).call(i,t,e)})})}},{\"../pie/style_one\":1097,d3:163}],1001:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../components/colorscale/attributes\"),o=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../lib/extend\").extendFlat);e.exports=o({z:{valType:\"data_array\",editType:\"calc\"},x:o({},n.x,{impliedEdits:{xtype:\"array\"}}),x0:o({},n.x0,{impliedEdits:{xtype:\"scaled\"}}),dx:o({},n.dx,{impliedEdits:{xtype:\"scaled\"}}),y:o({},n.y,{impliedEdits:{ytype:\"array\"}}),y0:o({},n.y0,{impliedEdits:{ytype:\"scaled\"}}),dy:o({},n.dy,{impliedEdits:{ytype:\"scaled\"}}),text:{valType:\"data_array\",editType:\"calc\"},hovertext:{valType:\"data_array\",editType:\"calc\"},transpose:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xtype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},ytype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},zsmooth:{valType:\"enumerated\",values:[\"fast\",\"best\",!1],dflt:!1,editType:\"calc\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xgap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},ygap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},zhoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},hovertemplate:i()},{transforms:void 0},a(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../scatter/attributes\":1112}],1002:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../histogram2d/calc\"),s=t(\"../../components/colorscale/calc\"),l=t(\"./convert_column_xyz\"),c=t(\"./clean_2d_array\"),u=t(\"./interp2d\"),h=t(\"./find_empties\"),f=t(\"./make_bound_array\");e.exports=function(t,e){var r,p,d,g,v,m,y,x,b,_=a.getFromId(t,e.xaxis||\"x\"),w=a.getFromId(t,e.yaxis||\"y\"),k=n.traceIs(e,\"contour\"),T=n.traceIs(e,\"histogram\"),A=n.traceIs(e,\"gl2d\"),M=k?\"best\":e.zsmooth;if(_._minDtick=0,w._minDtick=0,T)r=(b=o(t,e)).x,p=b.x0,d=b.dx,g=b.y,v=b.y0,m=b.dy,y=b.z;else{var S=e.z;i.isArray1D(S)?(l(e,_,w,\"x\",\"y\",[\"z\"]),r=e._x,g=e._y,S=e._z):(r=e._x=e.x?_.makeCalcdata(e,\"x\"):[],g=e._y=e.y?w.makeCalcdata(e,\"y\"):[]),p=e.x0,d=e.dx,v=e.y0,m=e.dy,y=c(S,e,_,w),(k||e.connectgaps)&&(e._emptypoints=h(y),u(y,e._emptypoints))}function E(t){M=e._input.zsmooth=e.zsmooth=!1,i.warn('cannot use zsmooth: \"fast\": '+t)}if(\"fast\"===M)if(\"log\"===_.type||\"log\"===w.type)E(\"log axis found\");else if(!T){if(r.length){var C=(r[r.length-1]-r[0])/(r.length-1),L=Math.abs(C/100);for(x=0;x<r.length-1;x++)if(Math.abs(r[x+1]-r[x]-C)>L){E(\"x scale is not linear\");break}}if(g.length&&\"fast\"===M){var P=(g[g.length-1]-g[0])/(g.length-1),O=Math.abs(P/100);for(x=0;x<g.length-1;x++)if(Math.abs(g[x+1]-g[x]-P)>O){E(\"y scale is not linear\");break}}}var z=i.maxRowLength(y),I=\"scaled\"===e.xtype?\"\":r,D=f(e,I,p,d,z,_),R=\"scaled\"===e.ytype?\"\":g,F=f(e,R,v,m,y.length,w);A||(e._extremes[_._id]=a.findExtremes(_,D),e._extremes[w._id]=a.findExtremes(w,F));var B={x:D,y:F,z:y,text:e._text||e.text,hovertext:e._hovertext||e.hovertext};if(I&&I.length===D.length-1&&(B.xCenter=I),R&&R.length===F.length-1&&(B.yCenter=R),T&&(B.xRanges=b.xRanges,B.yRanges=b.yRanges,B.pts=b.pts),k||s(t,e,{vals:y,cLetter:\"z\"}),k&&e.contours&&\"heatmap\"===e.contours.coloring){var N={type:\"contour\"===e.type?\"heatmap\":\"histogram2d\",xcalendar:e.xcalendar,ycalendar:e.ycalendar};B.xfill=f(N,I,p,d,z,_),B.yfill=f(N,R,v,m,y.length,w)}return[B]}},{\"../../components/colorscale/calc\":601,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../histogram2d/calc\":1033,\"./clean_2d_array\":1003,\"./convert_column_xyz\":1005,\"./find_empties\":1007,\"./interp2d\":1010,\"./make_bound_array\":1011}],1003:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r,o){var s,l,c,u,h,f;function p(t){if(n(t))return+t}if(e&&e.transpose){for(s=0,h=0;h<t.length;h++)s=Math.max(s,t[h].length);if(0===s)return!1;c=function(t){return t.length},u=function(t,e,r){return(t[r]||[])[e]}}else s=t.length,c=function(t,e){return t[e].length},u=function(t,e,r){return(t[e]||[])[r]};var d=function(t,e,r){return e===a||r===a?a:u(t,e,r)};function g(t){if(e&&\"carpet\"!==e.type&&\"contourcarpet\"!==e.type&&t&&\"category\"===t.type&&e[\"_\"+t._id.charAt(0)].length){var r=t._id.charAt(0),n={},o=e[\"_\"+r+\"CategoryMap\"]||e[r];for(h=0;h<o.length;h++)n[o[h]]=h;return function(e){var r=n[t._categories[e]];return r+1?r:a}}return i.identity}var v=g(r),m=g(o);o&&\"category\"===o.type&&(s=o._categories.length);var y=new Array(s);for(h=0;h<s;h++)for(l=r&&\"category\"===r.type?r._categories.length:c(t,h),y[h]=new Array(l),f=0;f<l;f++)y[h][f]=p(d(t,m(h),v(f)));return y}},{\"../../constants/numerical\":695,\"../../lib\":719,\"fast-isnumeric\":225}],1004:[function(t,e,r){\"use strict\";e.exports={min:\"zmin\",max:\"zmax\"}},{}],1005:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r,a,o,s){var l,c,u,h,f=t._length,p=e.makeCalcdata(t,a),d=r.makeCalcdata(t,o),g=t.text,v=void 0!==g&&n.isArray1D(g),m=t.hovertext,y=void 0!==m&&n.isArray1D(m),x=n.distinctVals(p),b=x.vals,_=n.distinctVals(d),w=_.vals,k=[];for(l=0;l<s.length;l++)k[l]=n.init2dArray(w.length,b.length);for(v&&(u=n.init2dArray(w.length,b.length)),y&&(h=n.init2dArray(w.length,b.length)),l=0;l<f;l++)if(p[l]!==i&&d[l]!==i){var T=n.findBin(p[l]+x.minDiff/2,b),A=n.findBin(d[l]+_.minDiff/2,w);for(c=0;c<s.length;c++){var M=t[s[c]];k[c][A][T]=M[l]}v&&(u[A][T]=g[l]),y&&(h[A][T]=m[l])}for(t[\"_\"+a]=b,t[\"_\"+o]=w,c=0;c<s.length;c++)t[\"_\"+s[c]]=k[c];v&&(t._text=u),y&&(t._hovertext=h),e&&\"category\"===e.type&&(t[\"_\"+a+\"CategoryMap\"]=b.map(function(t){return e._categories[t]})),r&&\"category\"===r.type&&(t[\"_\"+o+\"CategoryMap\"]=w.map(function(t){return r._categories[t]}))}},{\"../../constants/numerical\":695,\"../../lib\":719}],1006:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xyz_defaults\"),a=t(\"./style_defaults\"),o=t(\"../../components/colorscale/defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l)?(c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\"),a(t,e,c,l),c(\"connectgaps\",n.isArray1D(e.z)&&!1!==e.zsmooth),o(t,e,l,c,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":1001,\"./style_defaults\":1014,\"./xyz_defaults\":1015}],1007:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").maxRowLength;e.exports=function(t){var e,r,i,a,o,s,l,c,u=[],h={},f=[],p=t[0],d=[],g=[0,0,0],v=n(t);for(r=0;r<t.length;r++)for(e=d,d=p,p=t[r+1]||[],i=0;i<v;i++)void 0===d[i]&&((s=(void 0!==d[i-1]?1:0)+(void 0!==d[i+1]?1:0)+(void 0!==e[i]?1:0)+(void 0!==p[i]?1:0))?(0===r&&s++,0===i&&s++,r===t.length-1&&s++,i===d.length-1&&s++,s<4&&(h[[r,i]]=[r,i,s]),u.push([r,i,s])):f.push([r,i]));for(;f.length;){for(l={},c=!1,o=f.length-1;o>=0;o--)(s=((h[[(r=(a=f[o])[0])-1,i=a[1]]]||g)[2]+(h[[r+1,i]]||g)[2]+(h[[r,i-1]]||g)[2]+(h[[r,i+1]]||g)[2])/20)&&(l[a]=[r,i,s],f.splice(o,1),c=!0);if(!c)throw\"findEmpties iterated with no new neighbors\";for(a in l)h[a]=l[a],u.push(l[a])}return u.sort(function(t,e){return e[2]-t[2]})}},{\"../../lib\":719}],1008:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../components/colorscale\").extractOpts;e.exports=function(t,e,r,s,l,c){var u,h,f,p,d=t.cd[0],g=d.trace,v=t.xa,m=t.ya,y=d.x,x=d.y,b=d.z,_=d.xCenter,w=d.yCenter,k=d.zmask,T=g.zhoverformat,A=y,M=x;if(!1!==t.index){try{f=Math.round(t.index[1]),p=Math.round(t.index[0])}catch(e){return void i.error(\"Error hovering on heatmap, pointNumber must be [row,col], found:\",t.index)}if(f<0||f>=b[0].length||p<0||p>b.length)return}else{if(n.inbox(e-y[0],e-y[y.length-1],0)>0||n.inbox(r-x[0],r-x[x.length-1],0)>0)return;if(c){var S;for(A=[2*y[0]-y[1]],S=1;S<y.length;S++)A.push((y[S]+y[S-1])/2);for(A.push([2*y[y.length-1]-y[y.length-2]]),M=[2*x[0]-x[1]],S=1;S<x.length;S++)M.push((x[S]+x[S-1])/2);M.push([2*x[x.length-1]-x[x.length-2]])}f=Math.max(0,Math.min(A.length-2,i.findBin(e,A))),p=Math.max(0,Math.min(M.length-2,i.findBin(r,M)))}var E=v.c2p(y[f]),C=v.c2p(y[f+1]),L=m.c2p(x[p]),P=m.c2p(x[p+1]);c?(C=E,u=y[f],P=L,h=x[p]):(u=_?_[f]:(y[f]+y[f+1])/2,h=w?w[p]:(x[p]+x[p+1])/2,v&&\"category\"===v.type&&(u=y[f]),m&&\"category\"===m.type&&(h=x[p]),g.zsmooth&&(E=C=v.c2p(u),L=P=m.c2p(h)));var O,z=b[p][f];k&&!k[p][f]&&(z=void 0),Array.isArray(d.hovertext)&&Array.isArray(d.hovertext[p])?O=d.hovertext[p][f]:Array.isArray(d.text)&&Array.isArray(d.text[p])&&(O=d.text[p][f]);var I=o(g),D={type:\"linear\",range:[I.min,I.max],hoverformat:T,_separators:v._separators,_numFormat:v._numFormat},R=a.tickText(D,z,\"hover\").text;return[i.extendFlat(t,{index:[p,f],distance:t.maxHoverDistance,spikeDistance:t.maxSpikeDistance,x0:E,x1:C,y0:L,y1:P,xLabelVal:u,yLabelVal:h,zLabelVal:z,zLabel:R,text:O})]}},{\"../../components/colorscale\":605,\"../../components/fx\":632,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],1009:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:t(\"./colorbar\"),style:t(\"./style\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"heatmap\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\"],meta:{}}},{\"../../plots/cartesian\":778,\"./attributes\":1001,\"./calc\":1002,\"./colorbar\":1004,\"./defaults\":1006,\"./hover\":1008,\"./plot\":1012,\"./style\":1013}],1010:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[-1,0],[1,0],[0,-1],[0,1]];function a(t){return.5-.25*Math.min(1,.5*t)}function o(t,e,r){var n,a,o,s,l,c,u,h,f,p,d,g,v,m=0;for(s=0;s<e.length;s++){for(a=(n=e[s])[0],o=n[1],d=t[a][o],p=0,f=0,l=0;l<4;l++)(u=t[a+(c=i[l])[0]])&&void 0!==(h=u[o+c[1]])&&(0===p?g=v=h:(g=Math.min(g,h),v=Math.max(v,h)),f++,p+=h);if(0===f)throw\"iterateInterp2d order is wrong: no defined neighbors\";t[a][o]=p/f,void 0===d?f<4&&(m=1):(t[a][o]=(1+r)*t[a][o]-r*d,v>g&&(m=Math.max(m,Math.abs(t[a][o]-d)/(v-g))))}return m}e.exports=function(t,e){var r,i=1;for(o(t,e),r=0;r<e.length&&!(e[r][2]<4);r++);for(e=e.slice(r),r=0;r<100&&i>.01;r++)i=o(t,e,a(i));return i>.01&&n.log(\"interp2d didn't converge quickly\",i),t}},{\"../../lib\":719}],1011:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a,o,s){var l,c,u,h=[],f=n.traceIs(t,\"contour\"),p=n.traceIs(t,\"histogram\"),d=n.traceIs(t,\"gl2d\");if(i(e)&&e.length>1&&!p&&\"category\"!==s.type){var g=e.length;if(!(g<=o))return f?e.slice(0,o):e.slice(0,o+1);if(f||d)h=e.slice(0,o);else if(1===o)h=[e[0]-.5,e[0]+.5];else{for(h=[1.5*e[0]-.5*e[1]],u=1;u<g;u++)h.push(.5*(e[u-1]+e[u]));h.push(1.5*e[g-1]-.5*e[g-2])}if(g<o){var v=h[h.length-1],m=v-h[h.length-2];for(u=g;u<o;u++)v+=m,h.push(v)}}else{var y=t[s._id.charAt(0)+\"calendar\"];if(p)l=s.r2c(r,0,y);else if(i(e)&&1===e.length)l=e[0];else if(void 0===r)l=0;else{l=(\"log\"===s.type?s.d2c:s.r2c)(r,0,y)}for(c=a||1,u=f||d?0:-.5;u<o;u++)h.push(l+c*u)}return h}},{\"../../lib\":719,\"../../registry\":847}],1012:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/colorscale\").makeColorScaleFuncFromTrace,l=t(\"../../constants/xmlns_namespaces\");function c(t,e){var r=e.length-2,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=e[n+1],s=o.constrain(n+(t-i)/(a-i)-.5,0,r),l=Math.round(s),c=Math.abs(s-l);return s&&s!==r&&c?{bin0:l,frac:c,bin1:Math.round(l+c/(s-l))}:{bin0:l,bin1:l,frac:0}}function u(t,e){var r=e.length-1,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=(t-i)/(e[n+1]-i)||0;return a<=0?{bin0:n,bin1:n,frac:0}:a<.5?{bin0:n,bin1:n+1,frac:a}:{bin0:n+1,bin1:n,frac:1-a}}function h(t,e,r){t[e]=r[0],t[e+1]=r[1],t[e+2]=r[2],t[e+3]=Math.round(255*r[3])}e.exports=function(t,e,r,f){var p=e.xaxis,d=e.yaxis;o.makeTraceGroups(f,r,\"hm\").each(function(e){var r,f,g,v,m,y,x=n.select(this),b=e[0],_=b.trace,w=b.z,k=b.x,T=b.y,A=b.xCenter,M=b.yCenter,S=a.traceIs(_,\"contour\"),E=S?\"best\":_.zsmooth,C=w.length,L=o.maxRowLength(w),P=!1,O=!1;for(y=0;void 0===r&&y<k.length-1;)r=p.c2p(k[y]),y++;for(y=k.length-1;void 0===f&&y>0;)f=p.c2p(k[y]),y--;for(f<r&&(g=f,f=r,r=g,P=!0),y=0;void 0===v&&y<T.length-1;)v=d.c2p(T[y]),y++;for(y=T.length-1;void 0===m&&y>0;)m=d.c2p(T[y]),y--;if(m<v&&(g=v,v=m,m=g,O=!0),S&&(A=k,M=T,k=b.xfill,T=b.yfill),\"fast\"!==E){var z=\"best\"===E?0:.5;r=Math.max(-z*p._length,r),f=Math.min((1+z)*p._length,f),v=Math.max(-z*d._length,v),m=Math.min((1+z)*d._length,m)}var I=Math.round(f-r),D=Math.round(m-v);if(I<=0||D<=0){x.selectAll(\"image\").data([]).exit().remove()}else{var R,F;\"fast\"===E?(R=L,F=C):(R=I,F=D);var B=document.createElement(\"canvas\");B.width=R,B.height=F;var N,j,U=B.getContext(\"2d\"),V=s(_,{noNumericCheck:!0,returnArray:!0});\"fast\"===E?(N=P?function(t){return L-1-t}:o.identity,j=O?function(t){return C-1-t}:o.identity):(N=function(t){return o.constrain(Math.round(p.c2p(k[t])-r),0,I)},j=function(t){return o.constrain(Math.round(d.c2p(T[t])-v),0,D)});var q,H,G,Y,W,X=j(0),Z=[X,X],J=P?0:1,K=O?0:1,$=0,Q=0,tt=0,et=0;if(E){var rt,nt=0;try{rt=new Uint8Array(I*D*4)}catch(t){rt=new Array(I*D*4)}if(\"best\"===E){var it,at,ot,st=A||k,lt=M||T,ct=new Array(st.length),ut=new Array(lt.length),ht=new Array(I),ft=A?u:c,pt=M?u:c;for(y=0;y<st.length;y++)ct[y]=Math.round(p.c2p(st[y])-r);for(y=0;y<lt.length;y++)ut[y]=Math.round(d.c2p(lt[y])-v);for(y=0;y<I;y++)ht[y]=ft(y,ct);for(H=0;H<D;H++)for(at=w[(it=pt(H,ut)).bin0],ot=w[it.bin1],y=0;y<I;y++,nt+=4)h(rt,nt,W=Tt(at,ot,ht[y],it))}else for(H=0;H<C;H++)for(Y=w[H],Z=j(H),y=0;y<I;y++)W=kt(Y[y],1),h(rt,nt=4*(Z*I+N(y)),W);var dt=U.createImageData(I,D);try{dt.data.set(rt)}catch(t){var gt=dt.data,vt=gt.length;for(H=0;H<vt;H++)gt[H]=rt[H]}U.putImageData(dt,0,0)}else{var mt=_.xgap,yt=_.ygap,xt=Math.floor(mt/2),bt=Math.floor(yt/2);for(H=0;H<C;H++)if(Y=w[H],Z.reverse(),Z[K]=j(H+1),Z[0]!==Z[1]&&void 0!==Z[0]&&void 0!==Z[1])for(q=[G=N(0),G],y=0;y<L;y++)q.reverse(),q[J]=N(y+1),q[0]!==q[1]&&void 0!==q[0]&&void 0!==q[1]&&(W=kt(Y[y],(q[1]-q[0])*(Z[1]-Z[0])),U.fillStyle=\"rgba(\"+W.join(\",\")+\")\",U.fillRect(q[0]+xt,Z[0]+bt,q[1]-q[0]-mt,Z[1]-Z[0]-yt))}Q=Math.round(Q/$),tt=Math.round(tt/$),et=Math.round(et/$);var _t=i(\"rgb(\"+Q+\",\"+tt+\",\"+et+\")\");t._hmpixcount=(t._hmpixcount||0)+$,t._hmlumcount=(t._hmlumcount||0)+$*_t.getLuminance();var wt=x.selectAll(\"image\").data(e);wt.enter().append(\"svg:image\").attr({xmlns:l.svg,preserveAspectRatio:\"none\"}),wt.attr({height:D,width:I,x:r,y:v,\"xlink:href\":B.toDataURL(\"image/png\")})}function kt(t,e){if(void 0!==t){var r=V(t);return r[0]=Math.round(r[0]),r[1]=Math.round(r[1]),r[2]=Math.round(r[2]),$+=e,Q+=r[0]*e,tt+=r[1]*e,et+=r[2]*e,r}return[0,0,0,0]}function Tt(t,e,r,n){var i=t[r.bin0];if(void 0===i)return kt(void 0,1);var a,o=t[r.bin1],s=e[r.bin0],l=e[r.bin1],c=o-i||0,u=s-i||0;return a=void 0===o?void 0===l?0:void 0===s?2*(l-i):2*(2*l-s-i)/3:void 0===l?void 0===s?0:2*(2*i-o-s)/3:void 0===s?2*(2*l-o-i)/3:l+i-o-s,kt(i+r.frac*c+n.frac*(u+r.frac*a))}})}},{\"../../components/colorscale\":605,\"../../constants/xmlns_namespaces\":696,\"../../lib\":719,\"../../registry\":847,d3:163,tinycolor2:537}],1013:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t){n.select(t).selectAll(\".hm image\").style(\"opacity\",function(t){return t.trace.opacity})}},{d3:163}],1014:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){!1===r(\"zsmooth\")&&(r(\"xgap\"),r(\"ygap\")),r(\"zhoverformat\")}},{}],1015:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\");function o(t,e){var r=e(t);return\"scaled\"===(r?e(t+\"type\",\"array\"):\"scaled\")&&(e(t+\"0\"),e(\"d\"+t)),r}e.exports=function(t,e,r,s,l,c){var u,h,f=r(\"z\");if(l=l||\"x\",c=c||\"y\",void 0===f||!f.length)return 0;if(i.isArray1D(t.z)){u=r(l),h=r(c);var p=i.minRowLength(u),d=i.minRowLength(h);if(0===p||0===d)return 0;e._length=Math.min(p,d,f.length)}else{if(u=o(l,r),h=o(c,r),!function(t){for(var e,r=!0,a=!1,o=!1,s=0;s<t.length;s++){if(e=t[s],!i.isArrayOrTypedArray(e)){r=!1;break}e.length>0&&(a=!0);for(var l=0;l<e.length;l++)if(n(e[l])){o=!0;break}}return r&&a&&o}(f))return 0;r(\"transpose\"),e._length=null}return a.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[l,c],s),!0}},{\"../../lib\":719,\"../../registry\":847,\"fast-isnumeric\":225}],1016:[function(t,e,r){\"use strict\";for(var n=t(\"../heatmap/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=[\"z\",\"x\",\"x0\",\"dx\",\"y\",\"y0\",\"dy\",\"text\",\"transpose\",\"xtype\",\"ytype\"],l={},c=0;c<s.length;c++){var u=s[c];l[u]=n[u]}a(l,i(\"\",{cLetter:\"z\",autoColorDflt:!1})),e.exports=o(l,\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../heatmap/attributes\":1001}],1017:[function(t,e,r){\"use strict\";var n=t(\"gl-heatmap2d\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib/str2rgbarray\");function o(t,e){this.scene=t,this.uid=e,this.type=\"heatmapgl\",this.name=\"\",this.hoverinfo=\"all\",this.xData=[],this.yData=[],this.zData=[],this.textLabels=[],this.idToIndex=[],this.bounds=[0,0,0,0],this.options={z:[],x:[],y:[],shape:[0,0],colorLevels:[0],colorValues:[0,0,0,1]},this.heatmap=n(t.glplot,this.options),this.heatmap._trace=this}var s=o.prototype;s.handlePick=function(t){var e=this.options,r=e.shape,n=t.pointId,i=n%r[0],a=Math.floor(n/r[0]),o=n;return{trace:this,dataCoord:t.dataCoord,traceCoord:[e.x[i],e.y[a],e.z[o]],textLabel:this.textLabels[n],name:this.name,pointIndex:[a,i],hoverinfo:this.hoverinfo}},s.update=function(t,e){var r=e[0];this.index=t.index,this.name=t.name,this.hoverinfo=t.hoverinfo;var n=r.z;this.options.z=[].concat.apply([],n);var o=n[0].length,s=n.length;this.options.shape=[o,s],this.options.x=r.x,this.options.y=r.y;var l=function(t){for(var e=t.colorscale,r=t.zmin,n=t.zmax,i=e.length,o=new Array(i),s=new Array(4*i),l=0;l<i;l++){var c=e[l],u=a(c[1]);o[l]=r+c[0]*(n-r);for(var h=0;h<4;h++)s[4*l+h]=u[h]}return{colorLevels:o,colorValues:s}}(t);this.options.colorLevels=l.colorLevels,this.options.colorValues=l.colorValues,this.textLabels=[].concat.apply([],t.text),this.heatmap.update(this.options);var c=this.scene.xaxis,u=this.scene.yaxis;t._extremes[c._id]=i.findExtremes(c,r.x),t._extremes[u._id]=i.findExtremes(u,r.y)},s.dispose=function(){this.heatmap.dispose()},e.exports=function(t,e,r){var n=new o(t,e.uid);return n.update(e,r),n}},{\"../../lib/str2rgbarray\":742,\"../../plots/cartesian/axes\":767,\"gl-heatmap2d\":251}],1018:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"../heatmap/defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../heatmap/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"heatmapgl\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"2dMap\"],meta:{}}},{\"../../plots/gl2d\":805,\"../heatmap/calc\":1002,\"../heatmap/colorbar\":1004,\"../heatmap/defaults\":1006,\"./attributes\":1016,\"./convert\":1017}],1019:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"./bin_attributes\"),o=t(\"./constants\"),s=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),orientation:n.orientation,histfunc:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"min\",\"max\"],dflt:\"count\",editType:\"calc\"},histnorm:{valType:\"enumerated\",values:[\"\",\"percent\",\"probability\",\"density\",\"probability density\"],dflt:\"\",editType:\"calc\"},cumulative:{enabled:{valType:\"boolean\",dflt:!1,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"increasing\",\"decreasing\"],dflt:\"increasing\",editType:\"calc\"},currentbin:{valType:\"enumerated\",values:[\"include\",\"exclude\",\"half\"],dflt:\"include\",editType:\"calc\"},editType:\"calc\"},nbinsx:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},xbins:a(\"x\",!0),nbinsy:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},ybins:a(\"y\",!0),autobinx:{valType:\"boolean\",dflt:null,editType:\"calc\"},autobiny:{valType:\"boolean\",dflt:null,editType:\"calc\"},bingroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:i({},{keys:o.eventDataKeys}),marker:n.marker,offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,_deprecated:{bardir:n._deprecated.bardir}}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../bar/attributes\":857,\"./bin_attributes\":1021,\"./constants\":1025}],1020:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=t.length,n=0,i=0;i<r;i++)e[i]?(t[i]/=e[i],n+=t[i]):t[i]=null;return n}},{}],1021:[function(t,e,r){\"use strict\";e.exports=function(t,e){return{start:{valType:\"any\",editType:\"calc\"},end:{valType:\"any\",editType:\"calc\"},size:{valType:\"any\",editType:\"calc\"},editType:\"calc\"}}},{}],1022:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports={count:function(t,e,r){return r[t]++,1},sum:function(t,e,r,i){var a=i[e];return n(a)?(a=Number(a),r[t]+=a,a):0},avg:function(t,e,r,i,a){var o=i[e];return n(o)&&(o=Number(o),r[t]+=o,a[t]++),0},min:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]>a){var o=a-r[t];return r[t]=a,o}}return 0},max:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]<a){var o=a-r[t];return r[t]=a,o}}return 0}}},{\"fast-isnumeric\":225}],1023:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.ONEAVGYEAR,a=n.ONEAVGMONTH,o=n.ONEDAY,s=n.ONEHOUR,l=n.ONEMIN,c=n.ONESEC,u=t(\"../../plots/cartesian/axes\").tickIncrement;function h(t,e,r,n){if(t*e<=0)return 1/0;for(var i=Math.abs(e-t),a=\"date\"===r.type,o=f(i,a),s=0;s<10;s++){var l=f(80*o,a);if(o===l)break;if(!p(l,t,e,a,r,n))break;o=l}return o}function f(t,e){return e&&t>c?t>o?t>1.1*i?i:t>1.1*a?a:o:t>s?s:t>l?l:c:Math.pow(10,Math.floor(Math.log(t)/Math.LN10))}function p(t,e,r,n,a,s){if(n&&t>o){var l=d(e,a,s),c=d(r,a,s),u=t===i?0:1;return l[u]!==c[u]}return Math.floor(r/t)-Math.floor(e/t)>.1}function d(t,e,r){var n=e.c2d(t,i,r).split(\"-\");return\"\"===n[0]&&(n.unshift(),n[0]=\"-\"+n[0]),n}e.exports=function(t,e,r,n,a){var s,l,c=-1.1*e,f=-.1*e,p=t-f,d=r[0],g=r[1],v=Math.min(h(d+f,d+p,n,a),h(g+f,g+p,n,a)),m=Math.min(h(d+c,d+f,n,a),h(g+c,g+f,n,a));if(v>m&&m<Math.abs(g-d)/4e3?(s=v,l=!1):(s=Math.min(v,m),l=!0),\"date\"===n.type&&s>o){var y=s===i?1:6,x=s===i?\"M12\":\"M1\";return function(e,r){var o=n.c2d(e,i,a),s=o.indexOf(\"-\",y);s>0&&(o=o.substr(0,s));var c=n.d2c(o,0,a);if(c<e){var h=u(c,x,!1,a);(c+h)/2<e+t&&(c=h)}return r&&l?u(c,x,!0,a):c}}return function(e,r){var n=s*Math.round(e/s);return n+s/10<e&&n+.9*s<e+t&&(n+=s),r&&l&&(n-=s),n}}},{\"../../constants/numerical\":695,\"../../plots/cartesian/axes\":767}],1024:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../bar/arrays_to_calcdata\"),l=t(\"./bin_functions\"),c=t(\"./norm_functions\"),u=t(\"./average\"),h=t(\"./bin_label_vals\");function f(t,e,r,s,l){var c,u,h,p,d,g,v,m=s+\"bins\",y=t._fullLayout,x=e[\"_\"+s+\"bingroup\"],b=y._histogramBinOpts[x],_=\"overlay\"===y.barmode,w=function(t){return r.r2c(t,0,p)},k=function(t){return r.c2r(t,0,p)},T=\"date\"===r.type?function(t){return t||0===t?i.cleanDate(t,null,p):null}:function(t){return n(t)?Number(t):null};function A(t,e,r){e[t+\"Found\"]?(e[t]=T(e[t]),null===e[t]&&(e[t]=r[t])):(g[t]=e[t]=r[t],i.nestedProperty(u[0],m+\".\"+t).set(r[t]))}if(e[\"_\"+s+\"autoBinFinished\"])delete e[\"_\"+s+\"autoBinFinished\"];else{u=b.traces;var M=[],S=!0,E=!1,C=!1;for(c=0;c<u.length;c++)if((h=u[c]).visible){var L=b.dirs[c];d=h[\"_\"+L+\"pos0\"]=r.makeCalcdata(h,L),M=i.concat(M,d),delete h[\"_\"+s+\"autoBinFinished\"],!0===e.visible&&(S?S=!1:(delete h._autoBin,h[\"_\"+s+\"autoBinFinished\"]=1),a.traceIs(h,\"2dMap\")&&(E=!0),\"histogram2dcontour\"===h.type&&(C=!0))}p=u[0][s+\"calendar\"];var P=o.autoBin(M,r,b.nbins,E,p,b.sizeFound&&b.size),O=u[0]._autoBin={};if(g=O[b.dirs[0]]={},C&&(b.size||(P.start=k(o.tickIncrement(w(P.start),P.size,!0,p))),void 0===b.end&&(P.end=k(o.tickIncrement(w(P.end),P.size,!1,p)))),_&&!a.traceIs(e,\"2dMap\")&&0===P._dataSpan&&\"category\"!==r.type&&\"multicategory\"!==r.type){if(l)return[P,d,!0];P=function(t,e,r,n,a){var o,s,l,c=t._fullLayout,u=function(t,e){for(var r=e.xaxis,n=e.yaxis,i=e.orientation,a=[],o=t._fullData,s=0;s<o.length;s++){var l=o[s];\"histogram\"===l.type&&!0===l.visible&&l.orientation===i&&l.xaxis===r&&l.yaxis===n&&a.push(l)}return a}(t,e),h=!1,p=1/0,d=[e];for(o=0;o<u.length;o++)if((s=u[o])===e)h=!0;else if(h){var g=f(t,s,r,n,!0),v=g[0],m=g[2];s[\"_\"+n+\"autoBinFinished\"]=1,s[\"_\"+n+\"pos0\"]=g[1],m?d.push(s):p=Math.min(p,v.size)}else l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]],p=Math.min(p,l.size||s[a].size);var y=new Array(d.length);for(o=0;o<d.length;o++)for(var x=d[o][\"_\"+n+\"pos0\"],b=0;b<x.length;b++)if(void 0!==x[b]){y[o]=x[b];break}isFinite(p)||(p=i.distinctVals(y).minDiff);for(o=0;o<d.length;o++){var _=(s=d[o])[n+\"calendar\"],w={start:r.c2r(y[o]-p/2,0,_),end:r.c2r(y[o]+p/2,0,_),size:p};s._input[a]=s[a]=w,(l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]])&&i.extendFlat(l,w)}return e[a]}(t,e,r,s,m)}(v=h.cumulative||{}).enabled&&\"include\"!==v.currentbin&&(\"decreasing\"===v.direction?P.start=k(o.tickIncrement(w(P.start),P.size,!0,p)):P.end=k(o.tickIncrement(w(P.end),P.size,!1,p))),b.size=P.size,b.sizeFound||(g.size=P.size,i.nestedProperty(u[0],m+\".size\").set(P.size)),A(\"start\",b,P),A(\"end\",b,P)}d=e[\"_\"+s+\"pos0\"],delete e[\"_\"+s+\"pos0\"];var z=e._input[m]||{},I=i.extendFlat({},b),D=b.start,R=r.r2l(z.start),F=void 0!==R;if((b.startFound||F)&&R!==r.r2l(D)){var B=F?R:i.aggNums(Math.min,null,d),N={type:\"category\"===r.type||\"multicategory\"===r.type?\"linear\":r.type,r2l:r.r2l,dtick:b.size,tick0:D,calendar:p,range:[B,o.tickIncrement(B,b.size,!1,p)].map(r.l2r)},j=o.tickFirst(N);j>r.r2l(B)&&(j=o.tickIncrement(j,b.size,!0,p)),I.start=r.l2r(j),F||i.nestedProperty(e,m+\".start\").set(I.start)}var U=b.end,V=r.r2l(z.end),q=void 0!==V;if((b.endFound||q)&&V!==r.r2l(U)){var H=q?V:i.aggNums(Math.max,null,d);I.end=r.l2r(H),q||i.nestedProperty(e,m+\".start\").set(I.end)}var G=\"autobin\"+s;return!1===e._input[G]&&(e._input[m]=i.extendFlat({},e[m]||{}),delete e._input[G],delete e[G]),[I,d]}e.exports={calc:function(t,e){var r,a,p,d,g=[],v=[],m=o.getFromId(t,\"h\"===e.orientation?e.yaxis:e.xaxis),y=\"h\"===e.orientation?\"y\":\"x\",x={x:\"y\",y:\"x\"}[y],b=e[y+\"calendar\"],_=e.cumulative,w=f(t,e,m,y),k=w[0],T=w[1],A=\"string\"==typeof k.size,M=[],S=A?M:k,E=[],C=[],L=[],P=0,O=e.histnorm,z=e.histfunc,I=-1!==O.indexOf(\"density\");_.enabled&&I&&(O=O.replace(/ ?density$/,\"\"),I=!1);var D,R=\"max\"===z||\"min\"===z?null:0,F=l.count,B=c[O],N=!1,j=function(t){return m.r2c(t,0,b)};for(i.isArrayOrTypedArray(e[x])&&\"count\"!==z&&(D=e[x],N=\"avg\"===z,F=l[z]),r=j(k.start),p=j(k.end)+(r-o.tickIncrement(r,k.size,!1,b))/1e6;r<p&&g.length<1e6&&(a=o.tickIncrement(r,k.size,!1,b),g.push((r+a)/2),v.push(R),L.push([]),M.push(r),I&&E.push(1/(a-r)),N&&C.push(0),!(a<=r));)r=a;M.push(r),A||\"date\"!==m.type||(S={start:j(S.start),end:j(S.end),size:S.size});var U,V=v.length,q=!0,H=1/0,G=1/0,Y={};for(r=0;r<T.length;r++){var W=T[r];(d=i.findBin(W,S))>=0&&d<V&&(P+=F(d,r,v,D,C),q&&L[d].length&&W!==T[L[d][0]]&&(q=!1),L[d].push(r),Y[r]=d,H=Math.min(H,W-M[d]),G=Math.min(G,M[d+1]-W))}q||(U=h(H,G,M,m,b)),N&&(P=u(v,C)),B&&B(v,P,E),_.enabled&&function(t,e,r){var n,i,a;function o(e){a=t[e],t[e]/=2}function s(e){i=t[e],t[e]=a+i/2,a+=i}if(\"half\"===r)if(\"increasing\"===e)for(o(0),n=1;n<t.length;n++)s(n);else for(o(t.length-1),n=t.length-2;n>=0;n--)s(n);else if(\"increasing\"===e){for(n=1;n<t.length;n++)t[n]+=t[n-1];\"exclude\"===r&&(t.unshift(0),t.pop())}else{for(n=t.length-2;n>=0;n--)t[n]+=t[n+1];\"exclude\"===r&&(t.push(0),t.shift())}}(v,_.direction,_.currentbin);var X=Math.min(g.length,v.length),Z=[],J=0,K=X-1;for(r=0;r<X;r++)if(v[r]){J=r;break}for(r=X-1;r>=J;r--)if(v[r]){K=r;break}for(r=J;r<=K;r++)if(n(g[r])&&n(v[r])){var $={p:g[r],s:v[r],b:0};_.enabled||($.pts=L[r],q?$.ph0=$.ph1=L[r].length?T[L[r][0]]:g[r]:($.ph0=U(M[r]),$.ph1=U(M[r+1],!0))),Z.push($)}return 1===Z.length&&(Z[0].width1=o.tickIncrement(Z[0].p,k.size,!1,b)-Z[0].p),s(Z,e),i.isArrayOrTypedArray(e.selectedpoints)&&i.tagSelected(Z,e,Y),Z},calcAllAutoBins:f}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../../registry\":847,\"../bar/arrays_to_calcdata\":856,\"./average\":1020,\"./bin_functions\":1022,\"./bin_label_vals\":1023,\"./norm_functions\":1031,\"fast-isnumeric\":225}],1025:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"binNumber\"]}},{}],1026:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../../registry\").traceIs,o=t(\"../bar/defaults\").handleGroupingDefaults,s=n.nestedProperty,l=i.getAxisGroup,c=[{aStr:{x:\"xbins.start\",y:\"ybins.start\"},name:\"start\"},{aStr:{x:\"xbins.end\",y:\"ybins.end\"},name:\"end\"},{aStr:{x:\"xbins.size\",y:\"ybins.size\"},name:\"size\"},{aStr:{x:\"nbinsx\",y:\"nbinsy\"},name:\"nbins\"}],u=[\"x\",\"y\"];e.exports=function(t,e){var r,h,f,p,d,g,v,m=e._histogramBinOpts={},y=[],x={},b=[];function _(t,e){return n.coerce(r._input,r,r._module.attributes,t,e)}function w(t){return\"v\"===t.orientation?\"x\":\"y\"}function k(t,r,a){var o=t.uid+\"__\"+a;r||(r=o);var s=function(t,r){return i.getFromTrace({_fullLayout:e},t,r).type}(t,a),l=t[a+\"calendar\"],c=m[r],u=!0;c&&(s===c.axType&&l===c.calendar?(u=!1,c.traces.push(t),c.dirs.push(a)):(r=o,s!==c.axType&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set on a\",\"type:\"+s,\"axis\",\"with bins on\",\"type:\"+c.axType,\"axis.\"].join(\" \")),l!==c.calendar&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set with a\",l,\"calendar\",\"with bins\",c.calendar?\"on a \"+c.calendar+\" calendar\":\"w/o a set calendar\"].join(\" \")))),u&&(m[r]={traces:[t],dirs:[a],axType:s,calendar:t[a+\"calendar\"]||\"\"}),t[\"_\"+a+\"bingroup\"]=r}for(d=0;d<t.length;d++)r=t[d],a(r,\"histogram\")&&(y.push(r),delete r._xautoBinFinished,delete r._yautoBinFinished,a(r,\"2dMap\")||o(r._input,r,e,_));var T=e._alignmentOpts||{};for(d=0;d<y.length;d++){if(r=y[d],f=\"\",!a(r,\"2dMap\")){if(p=w(r),\"group\"===e.barmode&&r.alignmentgroup){var A=r[p+\"axis\"],M=l(e,A)+r.orientation;(T[M]||{})[r.alignmentgroup]&&(f=M)}f||\"overlay\"===e.barmode||(f=l(e,r.xaxis)+l(e,r.yaxis)+w(r))}f?(x[f]||(x[f]=[]),x[f].push(r)):b.push(r)}for(f in x)if(1!==(h=x[f]).length){var S=!1;for(d=0;d<h.length;d++){r=h[d],S=_(\"bingroup\");break}for(f=S||f,d=0;d<h.length;d++){var E=(r=h[d])._input.bingroup;E&&E!==f&&n.warn([\"Trace\",r.index,\"must match\",\"within bingroup\",f+\".\",\"Ignoring its bingroup:\",E,\"setting.\"].join(\" \")),r.bingroup=f,k(r,f,w(r))}}else b.push(h[0]);for(d=0;d<b.length;d++){r=b[d];var C=_(\"bingroup\");if(a(r,\"2dMap\"))for(v=0;v<2;v++){var L=_((p=u[v])+\"bingroup\",C?C+\"__\"+p:null);k(r,L,p)}else k(r,C,w(r))}for(f in m){var P=m[f];for(h=P.traces,g=0;g<c.length;g++){var O,z,I=c[g],D=I.name;if(\"nbins\"!==D||!P.sizeFound){for(d=0;d<h.length;d++){if(r=h[d],p=P.dirs[d],O=I.aStr[p],void 0!==s(r._input,O).get()){P[D]=_(O),P[D+\"Found\"]=!0;break}(z=(r._autoBin||{})[p]||{})[D]&&s(r,O).set(z[D])}if(\"start\"===D||\"end\"===D)for(;d<h.length;d++)(r=h[d])[\"_\"+p+\"bingroup\"]&&_(O,(z=(r._autoBin||{})[p]||{})[D]);\"nbins\"!==D||P.sizeFound||P.nbinsFound||(r=h[0],P[D]=_(O))}}}}},{\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../bar/defaults\":861}],1027:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../bar/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,n){return i.coerce(t,e,s,r,n)}var u=c(\"x\"),h=c(\"y\");c(\"cumulative.enabled\")&&(c(\"cumulative.direction\"),c(\"cumulative.currentbin\")),c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\");var f=c(\"orientation\",h&&!u?\"h\":\"v\"),p=\"v\"===f?\"x\":\"y\",d=\"v\"===f?\"y\":\"x\",g=u&&h?Math.min(i.minRowLength(u)&&i.minRowLength(h)):i.minRowLength(e[p]||[]);if(g){e._length=g,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],l),e[d]&&c(\"histfunc\"),c(\"histnorm\"),c(\"autobin\"+p),o(t,e,c,r,l),i.coerceSelectionMarkerOpacity(e,c);var v=(e.marker.line||{}).color,m=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");m(t,e,v||a.defaultLine,{axis:\"y\"}),m(t,e,v||a.defaultLine,{axis:\"x\",inherit:\"y\"})}else e.visible=!1}},{\"../../components/color\":593,\"../../lib\":719,\"../../registry\":847,\"../bar/style_defaults\":871,\"./attributes\":1019}],1028:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"zLabelVal\"in e&&(t.z=e.zLabelVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),!(r.cumulative||{}).enabled){var a,o=Array.isArray(i)?n[0].pts[i[0]][i[1]]:n[i].pts;if(t.pointNumbers=o,t.binNumber=t.pointNumber,delete t.pointNumber,delete t.pointIndex,r._indexToPoints){a=[];for(var s=0;s<o.length;s++)a=a.concat(r._indexToPoints[o[s]])}else a=o;t.pointIndices=a}return t}},{}],1029:[function(t,e,r){\"use strict\";var n=t(\"../bar/hover\").hoverPoints,i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o){var s=(t=o[0]).cd[t.index],l=t.cd[0].trace;if(!l.cumulative.enabled){var c=\"h\"===l.orientation?\"y\":\"x\";t[c+\"Label\"]=i(t[c+\"a\"],s.ph0,s.ph1)}return l.hovermplate&&(t.hovertemplate=l.hovertemplate),o}}},{\"../../plots/cartesian/axes\":767,\"../bar/hover\":863}],1030:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"../bar/layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),supplyLayoutDefaults:t(\"../bar/layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"../bar/cross_trace_calc\").crossTraceCalc,plot:t(\"../bar/plot\").plot,layerName:\"barlayer\",style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,colorbar:t(\"../scatter/marker_colorbar\"),hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"histogram\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"histogram\",\"oriented\",\"errorBarsOK\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":778,\"../bar/cross_trace_calc\":860,\"../bar/layout_attributes\":865,\"../bar/layout_defaults\":866,\"../bar/plot\":867,\"../bar/select\":868,\"../bar/style\":870,\"../scatter/marker_colorbar\":1129,\"./attributes\":1019,\"./calc\":1024,\"./cross_trace_defaults\":1026,\"./defaults\":1027,\"./event_data\":1028,\"./hover\":1029}],1031:[function(t,e,r){\"use strict\";e.exports={percent:function(t,e){for(var r=t.length,n=100/e,i=0;i<r;i++)t[i]*=n},probability:function(t,e){for(var r=t.length,n=0;n<r;n++)t[n]/=e},density:function(t,e,r,n){var i=t.length;n=n||1;for(var a=0;a<i;a++)t[a]*=r[a]*n},\"probability density\":function(t,e,r,n){var i=t.length;n&&(e/=n);for(var a=0;a<i;a++)t[a]*=r[a]/e}}},{}],1032:[function(t,e,r){\"use strict\";var n=t(\"../histogram/attributes\"),i=t(\"../histogram/bin_attributes\"),a=t(\"../heatmap/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../lib/extend\").extendFlat;e.exports=l({x:n.x,y:n.y,z:{valType:\"data_array\",editType:\"calc\"},marker:{color:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:i(\"x\"),nbinsy:n.nbinsy,ybins:i(\"y\"),autobinx:n.autobinx,autobiny:n.autobiny,bingroup:l({},n.bingroup,{}),xbingroup:l({},n.bingroup,{}),ybingroup:l({},n.bingroup,{}),xgap:a.xgap,ygap:a.ygap,zsmooth:a.zsmooth,zhoverformat:a.zhoverformat,hovertemplate:o({},{keys:\"z\"})},s(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../heatmap/attributes\":1001,\"../histogram/attributes\":1019,\"../histogram/bin_attributes\":1021}],1033:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../histogram/bin_functions\"),o=t(\"../histogram/norm_functions\"),s=t(\"../histogram/average\"),l=t(\"../histogram/bin_label_vals\"),c=t(\"../histogram/calc\").calcAllAutoBins;function u(t,e,r,n){var i,a=new Array(t);if(n)for(i=0;i<t;i++)a[i]=1/(e[i+1]-e[i]);else{var o=1/r;for(i=0;i<t;i++)a[i]=o}return a}function h(t,e){return{start:t(e.start),end:t(e.end),size:e.size}}function f(t,e,r,n,i,a){var o,s=t.length-1,c=new Array(s),u=l(r,n,t,i,a);for(o=0;o<s;o++){var h=(e||[])[o];c[o]=void 0===h?[u(t[o]),u(t[o+1],!0)]:[h,h]}return c}e.exports=function(t,e){var r,l,p,d,g=i.getFromId(t,e.xaxis),v=i.getFromId(t,e.yaxis),m=e.xcalendar,y=e.ycalendar,x=function(t){return g.r2c(t,0,m)},b=function(t){return v.r2c(t,0,y)},_=c(t,e,g,\"x\"),w=_[0],k=_[1],T=c(t,e,v,\"y\"),A=T[0],M=T[1],S=e._length;k.length>S&&k.splice(S,k.length-S),M.length>S&&M.splice(S,M.length-S);var E=[],C=[],L=[],P=\"string\"==typeof w.size,O=\"string\"==typeof A.size,z=[],I=[],D=P?z:w,R=O?I:A,F=0,B=[],N=[],j=e.histnorm,U=e.histfunc,V=-1!==j.indexOf(\"density\"),q=\"max\"===U||\"min\"===U?null:0,H=a.count,G=o[j],Y=!1,W=[],X=[],Z=\"z\"in e?e.z:\"marker\"in e&&Array.isArray(e.marker.color)?e.marker.color:\"\";Z&&\"count\"!==U&&(Y=\"avg\"===U,H=a[U]);var J=w.size,K=x(w.start),$=x(w.end)+(K-i.tickIncrement(K,J,!1,m))/1e6;for(r=K;r<$;r=i.tickIncrement(r,J,!1,m))C.push(q),z.push(r),Y&&L.push(0);z.push(r);var Q,tt=C.length,et=(r-K)/tt,rt=(Q=K+et/2,g.c2r(Q,0,m)),nt=A.size,it=b(A.start),at=b(A.end)+(it-i.tickIncrement(it,nt,!1,y))/1e6;for(r=it;r<at;r=i.tickIncrement(r,nt,!1,y)){E.push(C.slice()),I.push(r);var ot=new Array(tt);for(l=0;l<tt;l++)ot[l]=[];N.push(ot),Y&&B.push(L.slice())}I.push(r);var st=E.length,lt=(r-it)/st,ct=function(t){return v.c2r(t,0,y)}(it+lt/2);V&&(W=u(C.length,D,et,P),X=u(E.length,R,lt,O)),P||\"date\"!==g.type||(D=h(x,D)),O||\"date\"!==v.type||(R=h(b,R));var ut=!0,ht=!0,ft=new Array(tt),pt=new Array(st),dt=1/0,gt=1/0,vt=1/0,mt=1/0;for(r=0;r<S;r++){var yt=k[r],xt=M[r];p=n.findBin(yt,D),d=n.findBin(xt,R),p>=0&&p<tt&&d>=0&&d<st&&(F+=H(p,r,E[d],Z,B[d]),N[d][p].push(r),ut&&(void 0===ft[p]?ft[p]=yt:ft[p]!==yt&&(ut=!1)),ht&&(void 0===pt[d]?pt[d]=xt:pt[d]!==xt&&(ht=!1)),dt=Math.min(dt,yt-z[p]),gt=Math.min(gt,z[p+1]-yt),vt=Math.min(vt,xt-I[d]),mt=Math.min(mt,I[d+1]-xt))}if(Y)for(d=0;d<st;d++)F+=s(E[d],B[d]);if(G)for(d=0;d<st;d++)G(E[d],F,W,X[d]);return{x:k,xRanges:f(z,ut&&ft,dt,gt,g,m),x0:rt,dx:et,y:M,yRanges:f(I,ht&&pt,vt,mt,v,y),y0:ct,dy:lt,z:E,pts:N}}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../histogram/average\":1020,\"../histogram/bin_functions\":1022,\"../histogram/bin_label_vals\":1023,\"../histogram/calc\":1024,\"../histogram/norm_functions\":1031}],1034:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./sample_defaults\"),a=t(\"../heatmap/style_defaults\"),o=t(\"../../components/colorscale/defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,l),o(t,e,l,c,{prefix:\"\",cLetter:\"z\"}),c(\"hovertemplate\"))}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../heatmap/style_defaults\":1014,\"./attributes\":1032,\"./sample_defaults\":1037}],1035:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/hover\"),i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a,o,s){var l=n(t,e,r,a,o,s);if(l){var c=(t=l[0]).index,u=c[0],h=c[1],f=t.cd[0],p=f.xRanges[h],d=f.yRanges[u];return t.xLabel=i(t.xa,p[0],p[1]),t.yLabel=i(t.ya,d[0],d[1]),l}}},{\"../../plots/cartesian/axes\":767,\"../heatmap/hover\":1008}],1036:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../heatmap/calc\"),plot:t(\"../heatmap/plot\"),layerName:\"heatmaplayer\",colorbar:t(\"../heatmap/colorbar\"),style:t(\"../heatmap/style\"),hoverPoints:t(\"./hover\"),eventData:t(\"../histogram/event_data\"),moduleType:\"trace\",name:\"histogram2d\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"histogram\"],meta:{}}},{\"../../plots/cartesian\":778,\"../heatmap/calc\":1002,\"../heatmap/colorbar\":1004,\"../heatmap/plot\":1012,\"../heatmap/style\":1013,\"../histogram/cross_trace_defaults\":1026,\"../histogram/event_data\":1028,\"./attributes\":1032,\"./defaults\":1034,\"./hover\":1035}],1037:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"y\"),l=i.minRowLength(o),c=i.minRowLength(s);l&&c?(e._length=Math.min(l,c),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a),(r(\"z\")||r(\"marker.color\"))&&r(\"histfunc\"),r(\"histnorm\"),r(\"autobinx\"),r(\"autobiny\")):e.visible=!1}},{\"../../lib\":719,\"../../registry\":847}],1038:[function(t,e,r){\"use strict\";var n=t(\"../histogram2d/attributes\"),i=t(\"../contour/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat;e.exports=o({x:n.x,y:n.y,z:n.z,marker:n.marker,histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:n.xbins,nbinsy:n.nbinsy,ybins:n.ybins,autobinx:n.autobinx,autobiny:n.autobiny,bingroup:n.bingroup,xbingroup:n.xbingroup,ybingroup:n.ybingroup,autocontour:i.autocontour,ncontours:i.ncontours,contours:i.contours,line:i.line,zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../contour/attributes\":942,\"../histogram2d/attributes\":1032}],1039:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../histogram2d/sample_defaults\"),a=t(\"../contour/contours_defaults\"),o=t(\"../contour/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,function(r){return n.coerce2(t,e,s,r)}),o(t,e,c,l),c(\"hovertemplate\"))}},{\"../../lib\":719,\"../contour/contours_defaults\":949,\"../contour/style_defaults\":963,\"../histogram2d/sample_defaults\":1037,\"./attributes\":1038}],1040:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../contour/calc\"),plot:t(\"../contour/plot\").plot,layerName:\"contourlayer\",style:t(\"../contour/style\"),colorbar:t(\"../contour/colorbar\"),hoverPoints:t(\"../contour/hover\"),moduleType:\"trace\",name:\"histogram2dcontour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"histogram\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":778,\"../contour/calc\":943,\"../contour/colorbar\":945,\"../contour/hover\":955,\"../contour/plot\":960,\"../contour/style\":962,\"../histogram/cross_trace_defaults\":1026,\"./attributes\":1038,\"./defaults\":1039}],1041:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../lib/extend\").extendDeep,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../components/color/attributes\"),l=t(\"../../plots/domain\").attributes,c=t(\"../../plots/cartesian/layout_attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,h=t(\"../../constants/delta.js\"),f=(t(\"../../constants/docs\").FORMAT_LINK,o({editType:\"plot\",colorEditType:\"plot\"})),p={color:{valType:\"color\",editType:\"plot\"},line:{color:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},width:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"calc\"},thickness:{valType:\"number\",min:0,max:1,dflt:1,editType:\"plot\"},editType:\"calc\"},d={valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},g=u(\"steps\",i({},p,{range:d}));e.exports={mode:{valType:\"flaglist\",editType:\"calc\",flags:[\"number\",\"delta\",\"gauge\"],dflt:\"number\"},value:{valType:\"number\",editType:\"calc\",anim:!0},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},domain:l({name:\"indicator\",trace:!0,editType:\"calc\"}),title:{text:{valType:\"string\",editType:\"plot\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},font:n({},f,{}),editType:\"plot\"},number:{valueformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:n({},f,{}),prefix:{valType:\"string\",dflt:\"\",editType:\"plot\"},suffix:{valType:\"string\",dflt:\"\",editType:\"plot\"},editType:\"plot\"},delta:{reference:{valType:\"number\",editType:\"calc\"},position:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],dflt:\"bottom\",editType:\"plot\"},relative:{valType:\"boolean\",editType:\"plot\",dflt:!1},valueformat:{valType:\"string\",editType:\"plot\"},increasing:{symbol:{valType:\"string\",dflt:h.INCREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:h.INCREASING.COLOR,editType:\"plot\"},editType:\"plot\"},decreasing:{symbol:{valType:\"string\",dflt:h.DECREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:h.DECREASING.COLOR,editType:\"plot\"},editType:\"plot\"},font:n({},f,{}),editType:\"calc\"},gauge:{shape:{valType:\"enumerated\",editType:\"plot\",dflt:\"angular\",values:[\"angular\",\"bullet\"]},bar:i({},p,{color:{dflt:\"green\"}}),bgcolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},axis:a({range:d,visible:n({},c.visible,{dflt:!0}),tickmode:c.tickmode,nticks:c.nticks,tick0:c.tick0,dtick:c.dtick,tickvals:c.tickvals,ticktext:c.ticktext,ticks:n({},c.ticks,{dflt:\"outside\"}),ticklen:c.ticklen,tickwidth:c.tickwidth,tickcolor:c.tickcolor,showticklabels:c.showticklabels,tickfont:o({}),tickangle:c.tickangle,tickformat:c.tickformat,tickformatstops:c.tickformatstops,tickprefix:c.tickprefix,showtickprefix:c.showtickprefix,ticksuffix:c.ticksuffix,showticksuffix:c.showticksuffix,separatethousands:c.separatethousands,exponentformat:c.exponentformat,showexponent:c.showexponent,editType:\"plot\"},\"plot\"),steps:g,threshold:{line:{color:n({},p.line.color,{}),width:n({},p.line.width,{dflt:1}),editType:\"plot\"},thickness:n({},p.thickness,{dflt:.85}),value:{valType:\"number\",editType:\"calc\",dflt:!1},editType:\"plot\"},editType:\"plot\"}}},{\"../../components/color/attributes\":592,\"../../constants/delta.js\":689,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1042:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=r.name=\"indicator\";r.plot=function(t,e,r,o){var s=n.getModule(a),l=i(t.calcdata,s)[0];s.plot(t,l,r,o)},r.clean=function(t,e,r,n){var i=n._has&&n._has(a),o=e._has&&e._has(a);i&&!o&&n._indicatorlayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],1043:[function(t,e,r){\"use strict\";e.exports={calc:function(t,e){var r=[],n=e.value;\"number\"!=typeof e._lastValue&&(e._lastValue=e.value);var i=e._lastValue,a=i;return e._hasDelta&&\"number\"==typeof e.delta.reference&&(a=e.delta.reference),r[0]={y:n,lastY:i,delta:n-a,relativeDelta:(n-a)/a},r}}},{}],1044:[function(t,e,r){\"use strict\";e.exports={defaultNumberFontSize:80,bulletNumberDomainSize:.25,bulletPadding:.025,innerRadius:.75,valueThickness:.5,titlePadding:5,horizontalPadding:10}},{}],1045:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../../plot_api/plot_template\"),s=t(\"../../plots/array_container_defaults\"),l=t(\"./constants.js\"),c=t(\"../../plots/cartesian/tick_value_defaults\"),u=t(\"../../plots/cartesian/tick_mark_defaults\"),h=t(\"../../plots/cartesian/tick_label_defaults\");function f(t,e){function r(r,a){return n.coerce(t,e,i.gauge.steps,r,a)}r(\"color\"),r(\"line.color\"),r(\"line.width\"),r(\"range\"),r(\"thickness\")}e.exports={supplyDefaults:function(t,e,r,p){function d(r,a){return n.coerce(t,e,i,r,a)}a(e,p,d),d(\"mode\"),e._hasNumber=-1!==e.mode.indexOf(\"number\"),e._hasDelta=-1!==e.mode.indexOf(\"delta\"),e._hasGauge=-1!==e.mode.indexOf(\"gauge\");var g=d(\"value\");e._range=[0,\"number\"==typeof g?1.5*g:1];var v,m,y,x,b,_,w=new Array(2);function k(t,e){return n.coerce(y,x,i.gauge,t,e)}function T(t,e){return n.coerce(b,_,i.gauge.axis,t,e)}if(e._hasNumber&&(d(\"number.valueformat\"),d(\"number.font.color\",p.font.color),d(\"number.font.family\",p.font.family),d(\"number.font.size\"),void 0===e.number.font.size&&(e.number.font.size=l.defaultNumberFontSize,w[0]=!0),d(\"number.prefix\"),d(\"number.suffix\"),v=e.number.font.size),e._hasDelta&&(d(\"delta.font.color\",p.font.color),d(\"delta.font.family\",p.font.family),d(\"delta.font.size\"),void 0===e.delta.font.size&&(e.delta.font.size=(e._hasNumber?.5:1)*(v||l.defaultNumberFontSize),w[1]=!0),d(\"delta.reference\",e.value),d(\"delta.relative\"),d(\"delta.valueformat\",e.delta.relative?\"2%\":\"\"),d(\"delta.increasing.symbol\"),d(\"delta.increasing.color\"),d(\"delta.decreasing.symbol\"),d(\"delta.decreasing.color\"),d(\"delta.position\"),m=e.delta.font.size),e._scaleNumbers=(!e._hasNumber||w[0])&&(!e._hasDelta||w[1])||!1,d(\"title.font.color\",p.font.color),d(\"title.font.family\",p.font.family),d(\"title.font.size\",.25*(v||m||l.defaultNumberFontSize)),d(\"title.text\"),e._hasGauge){(y=t.gauge)||(y={}),x=o.newContainer(e,\"gauge\"),k(\"shape\"),(e._isBullet=\"bullet\"===e.gauge.shape)||d(\"title.align\",\"center\"),(e._isAngular=\"angular\"===e.gauge.shape)||d(\"align\",\"center\"),k(\"bgcolor\",p.paper_bgcolor),k(\"borderwidth\"),k(\"bordercolor\"),k(\"bar.color\"),k(\"bar.line.color\"),k(\"bar.line.width\"),k(\"bar.thickness\",l.valueThickness*(\"bullet\"===e.gauge.shape?.5:1)),s(y,x,{name:\"steps\",handleItemDefaults:f}),k(\"threshold.value\"),k(\"threshold.thickness\"),k(\"threshold.line.width\"),k(\"threshold.line.color\"),b={},y&&(b=y.axis||{}),_=o.newContainer(x,\"axis\"),T(\"visible\"),e._range=T(\"range\",e._range);var A={outerTicks:!0};c(b,_,T,\"linear\"),h(b,_,T,\"linear\",A),u(b,_,T,A)}else d(\"title.align\",\"center\"),d(\"align\",\"center\"),e._isAngular=e._isBullet=!1;e._length=null}}},{\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/tick_label_defaults\":786,\"../../plots/cartesian/tick_mark_defaults\":787,\"../../plots/cartesian/tick_value_defaults\":788,\"../../plots/domain\":792,\"./attributes\":1041,\"./constants.js\":1044}],1046:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"indicator\",basePlotModule:t(\"./base_plot\"),categories:[\"svg\",\"noOpacity\",\"noHover\"],animatable:!0,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\").calc,plot:t(\"./plot\"),meta:{}}},{\"./attributes\":1041,\"./base_plot\":1042,\"./calc\":1043,\"./defaults\":1045,\"./plot\":1047}],1047:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=i.rad2deg,o=t(\"../../constants/alignment\").MID_SHIFT,s=t(\"../../components/drawing\"),l=t(\"./constants\"),c=t(\"../../lib/svg_text_utils\"),u=t(\"../../plots/cartesian/axes\"),h=t(\"../../plots/cartesian/axis_defaults\"),f=t(\"../../plots/cartesian/position_defaults\"),p=t(\"../../plots/cartesian/layout_attributes\"),d=t(\"../../components/color\"),g={left:\"start\",center:\"middle\",right:\"end\"},v={left:0,center:.5,right:1},m=/[yzafpn\\xb5mkMGTPEZY]/;function y(t){return t&&t.duration>0}function x(t){t.each(function(t){d.stroke(n.select(this),t.line.color)}).each(function(t){d.fill(n.select(this),t.color)}).style(\"stroke-width\",function(t){return t.line.width})}function b(t,e,r){var n=t._fullLayout,a=i.extendFlat({type:\"linear\",ticks:\"outside\",range:r,showline:!0},e),o={type:\"linear\",_id:\"x\"+e._id},s={letter:\"x\",font:n.font,noHover:!0,noTickson:!0};function l(t,e){return i.coerce(a,o,p,t,e)}return h(a,o,l,s,n),f(a,o,l,s),o}function _(t,e){return\"translate(\"+t+\",\"+e+\")\"}function w(t,e,r){return[Math.min(e/t.width,r/t.height),t,e+\"x\"+r]}function k(t,e,r,i){var a=document.createElementNS(\"http://www.w3.org/2000/svg\",\"text\"),o=n.select(a);return o.text(t).attr(\"x\",0).attr(\"y\",0).attr(\"text-anchor\",r).attr(\"data-unformatted\",t).call(c.convertToTspans,i).call(s.font,e),s.bBox(o.node())}function T(t,e,r,n,a,o){var s=\"_cache\"+e;t[s]&&t[s].key===a||(t[s]={key:a,value:r});var l=i.aggNums(o,null,[t[s].value,n],2);return t[s].value=l,l}e.exports=function(t,e,r,h){var f,p=t._fullLayout;y(r)&&h&&(f=h()),i.makeTraceGroups(p._indicatorlayer,e,\"trace\").each(function(e){var h,A,M,S,E,C=e[0].trace,L=n.select(this),P=C._hasGauge,O=C._isAngular,z=C._isBullet,I=C.domain,D={w:p._size.w*(I.x[1]-I.x[0]),h:p._size.h*(I.y[1]-I.y[0]),l:p._size.l+p._size.w*I.x[0],r:p._size.r+p._size.w*(1-I.x[1]),t:p._size.t+p._size.h*(1-I.y[1]),b:p._size.b+p._size.h*I.y[0]},R=D.l+D.w/2,F=D.t+D.h/2,B=Math.min(D.w/2,D.h),N=l.innerRadius*B,j=C.align||\"center\";if(A=F,P){if(O&&(h=R,A=F+B/2,M=function(t){return e=t,r=.9*N,n=Math.sqrt(e.width/2*(e.width/2)+e.height*e.height),[r/n,e,r];var e,r,n}),z){var U=l.bulletPadding,V=1-l.bulletNumberDomainSize+U;h=D.l+(V+(1-V)*v[j])*D.w,M=function(t){return w(t,(l.bulletNumberDomainSize-U)*D.w,D.h)}}}else h=D.l+v[j]*D.w,M=function(t){return w(t,D.w,D.h)};!function(t,e,r,a){var o,l,h,f=r[0].trace,p=a.numbersX,x=a.numbersY,w=f.align||\"center\",A=g[w],M=a.transitionOpts,S=a.onComplete,E=i.ensureSingle(e,\"g\",\"numbers\"),C=[];f._hasNumber&&C.push(\"number\");f._hasDelta&&(C.push(\"delta\"),\"left\"===f.delta.position&&C.reverse());var L=E.selectAll(\"text\").data(C);function P(e,r,n,i){if(!e.match(\"s\")||n>=0==i>=0||r(n).slice(-1).match(m)||r(i).slice(-1).match(m))return r;var a=e.slice().replace(\"s\",\"f\").replace(/\\d+/,function(t){return parseInt(t)-1}),o=b(t,{tickformat:a});return function(t){return Math.abs(t)<1?u.tickText(o,t).text:r(t)}}L.enter().append(\"text\"),L.attr(\"text-anchor\",function(){return A}).attr(\"class\",function(t){return t}).attr(\"x\",null).attr(\"y\",null).attr(\"dx\",null).attr(\"dy\",null),L.exit().remove();var O,z=f.mode+f.align;f._hasDelta&&(O=function(){var e=b(t,{tickformat:f.delta.valueformat},f._range);e.setScale(),u.calcTicks(e);var i=function(t){return u.tickText(e,t).text},a=function(t){var e=f.delta.relative?t.relativeDelta:t.delta;return e},o=function(t,e){return 0===t||\"number\"!=typeof t||isNaN(t)?\"-\":(t>0?f.delta.increasing.symbol:f.delta.decreasing.symbol)+e(t)},h=function(t){return t.delta>=0?f.delta.increasing.color:f.delta.decreasing.color};void 0===f._deltaLastValue&&(f._deltaLastValue=a(r[0]));var p=E.select(\"text.delta\");function g(){p.text(o(a(r[0]),i)).call(d.fill,h(r[0])).call(c.convertToTspans,t)}p.call(s.font,f.delta.font).call(d.fill,h({delta:f._deltaLastValue})),y(M)?p.transition().duration(M.duration).ease(M.easing).tween(\"text\",function(){var t=n.select(this),e=a(r[0]),s=f._deltaLastValue,l=P(f.delta.valueformat,i,s,e),c=n.interpolateNumber(s,e);return f._deltaLastValue=e,function(e){t.text(o(c(e),l)),t.call(d.fill,h({delta:c(e)}))}}).each(\"end\",function(){g(),S&&S()}).each(\"interrupt\",function(){g(),S&&S()}):g();return l=k(o(a(r[0]),i),f.delta.font,A,t),p}(),z+=f.delta.position+f.delta.font.size+f.delta.font.family+f.delta.valueformat,z+=f.delta.increasing.symbol+f.delta.decreasing.symbol,h=l);f._hasNumber&&(!function(){var e=b(t,{tickformat:f.number.valueformat},f._range);e.setScale(),u.calcTicks(e);var i=function(t){return u.tickText(e,t).text},a=f.number.suffix,l=f.number.prefix,h=E.select(\"text.number\");function p(){var e=\"number\"==typeof r[0].y?l+i(r[0].y)+a:\"-\";h.text(e).call(s.font,f.number.font).call(c.convertToTspans,t)}y(M)?h.transition().duration(M.duration).ease(M.easing).each(\"end\",function(){p(),S&&S()}).each(\"interrupt\",function(){p(),S&&S()}).attrTween(\"text\",function(){var t=n.select(this),e=n.interpolateNumber(r[0].lastY,r[0].y);f._lastValue=r[0].y;var o=P(f.number.valueformat,i,r[0].lastY,r[0].y);return function(r){t.text(l+o(e(r))+a)}}):p();o=k(l+i(r[0].y)+a,f.number.font,A,t)}(),z+=f.number.font.size+f.number.font.family+f.number.valueformat+f.number.suffix+f.number.prefix,h=o);if(f._hasDelta&&f._hasNumber){var I,D,R=[(o.left+o.right)/2,(o.top+o.bottom)/2],F=[(l.left+l.right)/2,(l.top+l.bottom)/2],B=.75*f.delta.font.size;\"left\"===f.delta.position&&(I=T(f,\"deltaPos\",0,-1*(o.width*v[f.align]+l.width*(1-v[f.align])+B),z,Math.min),D=R[1]-F[1],h={width:o.width+l.width+B,height:Math.max(o.height,l.height),left:l.left+I,right:o.right,top:Math.min(o.top,l.top+D),bottom:Math.max(o.bottom,l.bottom+D)}),\"right\"===f.delta.position&&(I=T(f,\"deltaPos\",0,o.width*(1-v[f.align])+l.width*v[f.align]+B,z,Math.max),D=R[1]-F[1],h={width:o.width+l.width+B,height:Math.max(o.height,l.height),left:o.left,right:l.right+I,top:Math.min(o.top,l.top+D),bottom:Math.max(o.bottom,l.bottom+D)}),\"bottom\"===f.delta.position&&(I=null,D=l.height,h={width:Math.max(o.width,l.width),height:o.height+l.height,left:Math.min(o.left,l.left),right:Math.max(o.right,l.right),top:o.bottom-o.height,bottom:o.bottom+l.height}),\"top\"===f.delta.position&&(I=null,D=o.top,h={width:Math.max(o.width,l.width),height:o.height+l.height,left:Math.min(o.left,l.left),right:Math.max(o.right,l.right),top:o.bottom-o.height-l.height,bottom:o.bottom}),O.attr({dx:I,dy:D})}(f._hasNumber||f._hasDelta)&&E.attr(\"transform\",function(){var t=a.numbersScaler(h);z+=t[2];var e,r=T(f,\"numbersScale\",1,t[0],z,Math.min);f._scaleNumbers||(r=1),e=f._isAngular?x-r*h.bottom:x-r*(h.top+h.bottom)/2,f._numbersTop=r*h.top+e;var n=h[w];\"center\"===w&&(n=(h.left+h.right)/2);var i=p-r*n;return _(i=T(f,\"numbersTranslate\",0,i,z,Math.max),e)+\" scale(\"+r+\")\"})}(t,L,e,{numbersX:h,numbersY:A,numbersScaler:M,transitionOpts:r,onComplete:f}),P&&(S={range:C.gauge.axis.range,color:C.gauge.bgcolor,line:{color:C.gauge.bordercolor,width:0},thickness:1},E={range:C.gauge.axis.range,color:\"rgba(0, 0, 0, 0)\",line:{color:C.gauge.bordercolor,width:C.gauge.borderwidth},thickness:1});var q=L.selectAll(\"g.angular\").data(O?e:[]);q.exit().remove();var H=L.selectAll(\"g.angularaxis\").data(O?e:[]);H.exit().remove(),O&&function(t,e,r,i){var s,l,c,h,f=r[0].trace,p=i.size,d=i.radius,g=i.innerRadius,v=i.gaugeBg,m=i.gaugeOutline,w=[p.l+p.w/2,p.t+p.h/2+d/2],k=i.gauge,T=i.layer,A=i.transitionOpts,M=i.onComplete,S=Math.PI/2;function E(t){var e=f.gauge.axis.range[0],r=f.gauge.axis.range[1],n=(t-e)/(r-e)*Math.PI-S;return n<-S?-S:n>S?S:n}function C(t){return n.svg.arc().innerRadius((g+d)/2-t/2*(d-g)).outerRadius((g+d)/2+t/2*(d-g)).startAngle(-S)}function L(t){t.attr(\"d\",function(t){return C(t.thickness).startAngle(E(t.range[0])).endAngle(E(t.range[1]))()})}k.enter().append(\"g\").classed(\"angular\",!0),k.attr(\"transform\",_(w[0],w[1])),T.enter().append(\"g\").classed(\"angularaxis\",!0).classed(\"crisp\",!0),T.selectAll(\"g.xangularaxistick,path,text\").remove(),(s=b(t,f.gauge.axis)).type=\"linear\",s.range=f.gauge.axis.range,s._id=\"xangularaxis\",s.setScale();var P=function(t){return(s.range[0]-t.x)/(s.range[1]-s.range[0])*Math.PI+Math.PI},O={},z=u.makeLabelFns(s,0).labelStandoff;O.xFn=function(t){var e=P(t);return Math.cos(e)*z},O.yFn=function(t){var e=P(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(z+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*o)},O.anchorFn=function(t){var e=P(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},O.heightFn=function(t,e,r){var n=P(t);return-.5*(1+Math.sin(n))*r};var I=function(t){return _(w[0]+d*Math.cos(t),w[1]-d*Math.sin(t))};c=function(t){return I(P(t))};if(l=u.calcTicks(s),h=u.getTickSigns(s)[2],s.visible){h=\"inside\"===s.ticks?-1:1;var D=(s.linewidth||1)/2;u.drawTicks(t,s,{vals:l,layer:T,path:\"M\"+h*D+\",0h\"+h*s.ticklen,transFn:function(t){var e=P(t);return I(e)+\"rotate(\"+-a(e)+\")\"}}),u.drawLabels(t,s,{vals:l,layer:T,transFn:c,labelFns:O})}var R=[v].concat(f.gauge.steps),F=k.selectAll(\"g.bg-arc\").data(R);F.enter().append(\"g\").classed(\"bg-arc\",!0).append(\"path\"),F.select(\"path\").call(L).call(x),F.exit().remove();var B=C(f.gauge.bar.thickness),N=k.selectAll(\"g.value-arc\").data([f.gauge.bar]);N.enter().append(\"g\").classed(\"value-arc\",!0).append(\"path\");var j=N.select(\"path\");y(A)?(j.transition().duration(A.duration).ease(A.easing).each(\"end\",function(){M&&M()}).each(\"interrupt\",function(){M&&M()}).attrTween(\"d\",(U=B,V=E(r[0].lastY),q=E(r[0].y),function(){var t=n.interpolate(V,q);return function(e){return U.endAngle(t(e))()}})),f._lastValue=r[0].y):j.attr(\"d\",\"number\"==typeof r[0].y?B.endAngle(E(r[0].y)):\"M0,0Z\");var U,V,q;j.call(x),N.exit().remove(),R=[];var H=f.gauge.threshold.value;H&&R.push({range:[H,H],color:f.gauge.threshold.color,line:{color:f.gauge.threshold.line.color,width:f.gauge.threshold.line.width},thickness:f.gauge.threshold.thickness});var G=k.selectAll(\"g.threshold-arc\").data(R);G.enter().append(\"g\").classed(\"threshold-arc\",!0).append(\"path\"),G.select(\"path\").call(L).call(x),G.exit().remove();var Y=k.selectAll(\"g.gauge-outline\").data([m]);Y.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"path\"),Y.select(\"path\").call(L).call(x),Y.exit().remove()}(t,0,e,{radius:B,innerRadius:N,gauge:q,layer:H,size:D,gaugeBg:S,gaugeOutline:E,transitionOpts:r,onComplete:f});var G=L.selectAll(\"g.bullet\").data(z?e:[]);G.exit().remove();var Y=L.selectAll(\"g.bulletaxis\").data(z?e:[]);Y.exit().remove(),z&&function(t,e,r,n){var i,a,o,s,c,h=r[0].trace,f=n.gauge,p=n.layer,g=n.gaugeBg,v=n.gaugeOutline,m=n.size,_=h.domain,w=n.transitionOpts,k=n.onComplete;f.enter().append(\"g\").classed(\"bullet\",!0),f.attr(\"transform\",\"translate(\"+m.l+\", \"+m.t+\")\"),p.enter().append(\"g\").classed(\"bulletaxis\",!0).classed(\"crisp\",!0),p.selectAll(\"g.xbulletaxistick,path,text\").remove();var T=m.h,A=h.gauge.bar.thickness*T,M=_.x[0],S=_.x[0]+(_.x[1]-_.x[0])*(h._hasNumber||h._hasDelta?1-l.bulletNumberDomainSize:1);(i=b(t,h.gauge.axis))._id=\"xbulletaxis\",i.domain=[M,S],i.setScale(),a=u.calcTicks(i),o=u.makeTransFn(i),s=u.getTickSigns(i)[2],c=m.t+m.h,i.visible&&(u.drawTicks(t,i,{vals:\"inside\"===i.ticks?u.clipEnds(i,a):a,layer:p,path:u.makeTickPath(i,c,s),transFn:o}),u.drawLabels(t,i,{vals:a,layer:p,transFn:o,labelFns:u.makeLabelFns(i,c)}));function E(t){t.attr(\"width\",function(t){return Math.max(0,i.c2p(t.range[1])-i.c2p(t.range[0]))}).attr(\"x\",function(t){return i.c2p(t.range[0])}).attr(\"y\",function(t){return.5*(1-t.thickness)*T}).attr(\"height\",function(t){return t.thickness*T})}var C=[g].concat(h.gauge.steps),L=f.selectAll(\"g.bg-bullet\").data(C);L.enter().append(\"g\").classed(\"bg-bullet\",!0).append(\"rect\"),L.select(\"rect\").call(E).call(x),L.exit().remove();var P=f.selectAll(\"g.value-bullet\").data([h.gauge.bar]);P.enter().append(\"g\").classed(\"value-bullet\",!0).append(\"rect\"),P.select(\"rect\").attr(\"height\",A).attr(\"y\",(T-A)/2).call(x),y(w)?P.select(\"rect\").transition().duration(w.duration).ease(w.easing).each(\"end\",function(){k&&k()}).each(\"interrupt\",function(){k&&k()}).attr(\"width\",Math.max(0,i.c2p(Math.min(h.gauge.axis.range[1],r[0].y)))):P.select(\"rect\").attr(\"width\",\"number\"==typeof r[0].y?Math.max(0,i.c2p(Math.min(h.gauge.axis.range[1],r[0].y))):0);P.exit().remove();var O=r.filter(function(){return h.gauge.threshold.value}),z=f.selectAll(\"g.threshold-bullet\").data(O);z.enter().append(\"g\").classed(\"threshold-bullet\",!0).append(\"line\"),z.select(\"line\").attr(\"x1\",i.c2p(h.gauge.threshold.value)).attr(\"x2\",i.c2p(h.gauge.threshold.value)).attr(\"y1\",(1-h.gauge.threshold.thickness)/2*T).attr(\"y2\",(1-(1-h.gauge.threshold.thickness)/2)*T).call(d.stroke,h.gauge.threshold.line.color).style(\"stroke-width\",h.gauge.threshold.line.width),z.exit().remove();var I=f.selectAll(\"g.gauge-outline\").data([v]);I.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"rect\"),I.select(\"rect\").call(E).call(x),I.exit().remove()}(t,0,e,{gauge:G,layer:Y,size:D,gaugeBg:S,gaugeOutline:E,transitionOpts:r,onComplete:f});var W=L.selectAll(\"text.title\").data(e);W.exit().remove(),W.enter().append(\"text\").classed(\"title\",!0),W.attr(\"text-anchor\",function(){return z?g.right:g[C.title.align]}).text(C.title.text).call(s.font,C.title.font).call(c.convertToTspans,t),W.attr(\"transform\",function(){var t,e=D.l+D.w*v[C.title.align],r=l.titlePadding,n=s.bBox(W.node());if(P){if(O)if(C.gauge.axis.visible)t=s.bBox(H.node()).top-r-n.bottom;else t=D.t+D.h/2-B/2-n.bottom-r;z&&(t=A-(n.top+n.bottom)/2,e=D.l-l.bulletPadding*D.w)}else t=C._numbersTop-r-n.bottom;return _(e,t)})})}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../constants/alignment\":688,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_defaults\":769,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/cartesian/position_defaults\":782,\"./constants\":1044,d3:163}],1048:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;var c=e.exports=l(s({x:{valType:\"data_array\"},y:{valType:\"data_array\"},z:{valType:\"data_array\"},value:{valType:\"data_array\"},isomin:{valType:\"number\"},isomax:{valType:\"number\"},surface:{show:{valType:\"boolean\",dflt:!0},count:{valType:\"integer\",dflt:2,min:1},fill:{valType:\"number\",min:0,max:1,dflt:1},pattern:{valType:\"flaglist\",flags:[\"A\",\"B\",\"C\",\"D\",\"E\"],extras:[\"all\",\"odd\",\"even\"],dflt:\"all\"}},spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:.15}},slices:{x:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}}},caps:{x:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}}},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:i()},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:a.opacity,lightposition:a.lightposition,lighting:a.lighting,flatshading:a.flatshading,contour:a.contour,hoverinfo:s({},o.hoverinfo)}),\"calc\",\"nested\");c.flatshading.dflt=!0,c.lighting.facenormalsepsilon.dflt=0,c.x.editType=c.y.editType=c.z.editType=c.value.editType=\"calc+clearAxisTypes\",c.transforms=void 0},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../mesh3d/attributes\":1053}],1049:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e._len=Math.min(e.x.length,e.y.length,e.z.length,e.value.length);for(var r=1/0,i=-1/0,a=e.value.length,o=0;o<a;o++){var s=e.value[o];r=Math.min(r,s),i=Math.max(i,s)}e._minValues=r,e._maxValues=i,e._vMin=void 0===e.isomin||null===e.isomin?r:e.isomin,e._vMax=void 0===e.isomax||null===e.isomin?i:e.isomax,n(t,e,{vals:[e._vMin,e._vMax],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],1050:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib\"),a=t(\"../../lib/gl_format_color\").parseColorScale,o=t(\"../../lib/str2rgbarray\"),s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\");function c(t){return i.distinctVals(t).vals}var u=function(t,e){for(var r=e.length-1;r>0;r--){var n=Math.min(e[r],e[r-1]),i=Math.max(e[r],e[r-1]);if(i>n&&n<t&&t<=i)return{id:r,distRatio:(i-t)/(i-n)}}return{id:0,distRatio:0}};function h(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var f=h.prototype;function p(t){t._i=[],t._j=[],t._k=[];var e,r,n=t.surface.show,i=t.spaceframe.show,a=t.surface.fill,o=t.spaceframe.fill,s=!1,l=!1,h=0,f=c(t.x.slice(0,t._len)),p=c(t.y.slice(0,t._len)),d=c(t.z.slice(0,t._len)),g=f.length,v=p.length,m=d.length;function y(t,e,r){return r+m*e+m*v*t}var x,b,_,w,k,T=t._minValues,A=t._maxValues,M=t._vMin,S=t._vMax;function E(t,e,n){for(var i=w.length,a=r;a<i;a++)if(t===x[a]&&e===b[a]&&n===_[a])return a;return-1}function C(){r=e}function L(){x=[],b=[],_=[],w=[],e=0,C()}function P(t,r,n,i){return x.push(t),b.push(r),_.push(n),w.push(i),++e-1}function O(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=t[i]*(1-r)+r*e[i];return n}function z(t){k=t}function I(t,e){return\"all\"===t||null===t||t.indexOf(e)>-1}function D(t,e){return null===t?e:t}function R(e,r,n){C();var i,a,o,s=[r],l=[n];if(k>=1)s=[r],l=[n];else if(k>0){var c=function(t,e){var r=t[0],n=t[1],i=t[2],a=function(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=(t[i]+e[i]+r[i])/3;return n}(r,n,i),o=Math.sqrt(1-k),s=O(a,r,o),l=O(a,n,o),c=O(a,i,o),u=e[0],h=e[1],f=e[2];return{xyzv:[[r,n,l],[l,s,r],[n,i,c],[c,l,n],[i,r,s],[s,c,i]],abc:[[u,h,-1],[-1,-1,u],[h,f,-1],[-1,-1,h],[f,u,-1],[-1,-1,f]]}}(r,n);s=c.xyzv,l=c.abc}for(var u=0;u<s.length;u++){r=s[u],n=l[u];for(var f=[],p=0;p<3;p++){var d=r[p][0],g=r[p][1],v=r[p][2],m=r[p][3],y=n[p]>-1?n[p]:E(d,g,v);f[p]=y>-1?y:P(d,g,v,D(e,m))}i=f[0],a=f[1],o=f[2],t._i.push(i),t._j.push(a),t._k.push(o),++h}}function F(t,e,r,n){var i=t[3];i<r&&(i=r),i>n&&(i=n);for(var a=(t[3]-i)/(t[3]-e[3]+1e-9),o=[],s=0;s<4;s++)o[s]=(1-a)*t[s]+a*e[s];return o}function B(t,e,r){return t>=e&&t<=r}function N(t){var e=.001*(S-M);return t>=M-e&&t<=S+e}function j(e){for(var r=[],n=0;n<4;n++){var i=e[n];r.push([t.x[i],t.y[i],t.z[i],t.value[i]])}return r}var U=3;function V(t,e,r,n,i,a){a||(a=1),r=[-1,-1,-1];var o=!1,s=[B(e[0][3],n,i),B(e[1][3],n,i),B(e[2][3],n,i)];if(!s[0]&&!s[1]&&!s[2])return!1;var l=function(t,e,r){return N(e[0][3])&&N(e[1][3])&&N(e[2][3])?(R(t,e,r),!0):a<U&&V(t,e,r,M,S,++a)};if(s[0]&&s[1]&&s[2])return l(t,e,r)||o;var c=!1;return[[0,1,2],[2,0,1],[1,2,0]].forEach(function(a){if(s[a[0]]&&s[a[1]]&&!s[a[2]]){var u=e[a[0]],h=e[a[1]],f=e[a[2]],p=F(f,u,n,i),d=F(f,h,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,o=l(t,[u,h,d],[r[a[0]],r[a[1]],-1])||o,c=!0}}),c?o:([[0,1,2],[1,2,0],[2,0,1]].forEach(function(a){if(s[a[0]]&&!s[a[1]]&&!s[a[2]]){var u=e[a[0]],h=e[a[1]],f=e[a[2]],p=F(h,u,n,i),d=F(f,u,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,c=!0}}),o)}function q(t,e,r,n){var i=!1,a=j(e),o=[B(a[0][3],r,n),B(a[1][3],r,n),B(a[2][3],r,n),B(a[3][3],r,n)];if(!(o[0]||o[1]||o[2]||o[3]))return i;if(o[0]&&o[1]&&o[2]&&o[3])return l&&(i=function(t,e,r){var n=function(n,i,a){R(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(3,0,1),n(2,3,0),n(1,2,3)}(t,a,e)||i),i;var s=!1;return[[0,1,2,3],[3,0,1,2],[2,3,0,1],[1,2,3,0]].forEach(function(c){if(o[c[0]]&&o[c[1]]&&o[c[2]]&&!o[c[3]]){var u=a[c[0]],h=a[c[1]],f=a[c[2]],p=a[c[3]];if(l)i=R(t,[u,h,f],[e[c[0]],e[c[1]],e[c[2]]])||i;else{var d=F(p,u,r,n),g=F(p,h,r,n),v=F(p,f,r,n);i=R(null,[d,g,v],[-1,-1,-1])||i}s=!0}}),s?i:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2],[0,2,3,1],[1,3,2,0]].forEach(function(c){if(o[c[0]]&&o[c[1]]&&!o[c[2]]&&!o[c[3]]){var u=a[c[0]],h=a[c[1]],f=a[c[2]],p=a[c[3]],d=F(f,u,r,n),g=F(f,h,r,n),v=F(p,h,r,n),m=F(p,u,r,n);l?(i=R(t,[u,m,d],[e[c[0]],-1,-1])||i,i=R(t,[h,g,v],[e[c[1]],-1,-1])||i):i=function(t,e,r){var n=function(n,i,a){R(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(2,3,0)}(null,[d,g,v,m],[-1,-1,-1,-1])||i,s=!0}}),s?i:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2]].forEach(function(c){if(o[c[0]]&&!o[c[1]]&&!o[c[2]]&&!o[c[3]]){var u=a[c[0]],h=a[c[1]],f=a[c[2]],p=a[c[3]],d=F(h,u,r,n),g=F(f,u,r,n),v=F(p,u,r,n);l?(i=R(t,[u,d,g],[e[c[0]],-1,-1])||i,i=R(t,[u,g,v],[e[c[0]],-1,-1])||i,i=R(t,[u,v,d],[e[c[0]],-1,-1])||i):i=R(null,[d,g,v],[-1,-1,-1])||i,s=!0}}),i))}function H(t,e,r,n,i,a,o,c,u,h,f){var p=!1;return s&&(I(t,\"A\")&&(p=q(null,[e,r,n,a],h,f)||p),I(t,\"B\")&&(p=q(null,[r,n,i,u],h,f)||p),I(t,\"C\")&&(p=q(null,[r,a,o,u],h,f)||p),I(t,\"D\")&&(p=q(null,[n,a,c,u],h,f)||p),I(t,\"E\")&&(p=q(null,[r,n,a,u],h,f)||p)),l&&(p=q(t,[r,n,a,u],h,f)||p),p}function G(t,e,r,n,i,a,o,s){return[!0===s[0]||V(t,j([e,r,n]),[e,r,n],a,o),!0===s[1]||V(t,j([n,i,e]),[n,i,e],a,o)]}function Y(t,e,r,n,i,a,o,s,l){return s?G(t,e,r,i,n,a,o,l):G(t,r,i,n,e,a,o,l)}function W(t,e,r,n,i,a,o){var s,l,c,u,h=!1,f=function(){h=V(t,[s,l,c],[-1,-1,-1],i,a)||h,h=V(t,[c,u,s],[-1,-1,-1],i,a)||h},p=o[0],d=o[1],g=o[2];return p&&(s=O(j([y(e,r-0,n-0)])[0],j([y(e-1,r-0,n-0)])[0],p),l=O(j([y(e,r-0,n-1)])[0],j([y(e-1,r-0,n-1)])[0],p),c=O(j([y(e,r-1,n-1)])[0],j([y(e-1,r-1,n-1)])[0],p),u=O(j([y(e,r-1,n-0)])[0],j([y(e-1,r-1,n-0)])[0],p),f()),d&&(s=O(j([y(e-0,r,n-0)])[0],j([y(e-0,r-1,n-0)])[0],d),l=O(j([y(e-0,r,n-1)])[0],j([y(e-0,r-1,n-1)])[0],d),c=O(j([y(e-1,r,n-1)])[0],j([y(e-1,r-1,n-1)])[0],d),u=O(j([y(e-1,r,n-0)])[0],j([y(e-1,r-1,n-0)])[0],d),f()),g&&(s=O(j([y(e-0,r-0,n)])[0],j([y(e-0,r-0,n-1)])[0],g),l=O(j([y(e-0,r-1,n)])[0],j([y(e-0,r-1,n-1)])[0],g),c=O(j([y(e-1,r-1,n)])[0],j([y(e-1,r-1,n-1)])[0],g),u=O(j([y(e-1,r-0,n)])[0],j([y(e-1,r-0,n-1)])[0],g),f()),h}function X(t,e,r,n,i,a,o,l,c,u,h,f){var p=t;return f?(s&&\"even\"===t&&(p=null),H(p,e,r,n,i,a,o,l,c,u,h)):(s&&\"odd\"===t&&(p=null),H(p,c,l,o,a,i,n,r,e,u,h))}function Z(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<m;c++)for(var u=1;u<v;u++)a.push(Y(t,y(l,u-1,c-1),y(l,u-1,c),y(l,u,c-1),y(l,u,c),r,n,(l+u+c)%2,i&&i[o]?i[o]:[])),o++;return a}function J(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<g;c++)for(var u=1;u<m;u++)a.push(Y(t,y(c-1,l,u-1),y(c,l,u-1),y(c-1,l,u),y(c,l,u),r,n,(c+l+u)%2,i&&i[o]?i[o]:[])),o++;return a}function K(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<v;c++)for(var u=1;u<g;u++)a.push(Y(t,y(u-1,c-1,l),y(u-1,c,l),y(u,c-1,l),y(u,c,l),r,n,(u+c+l)%2,i&&i[o]?i[o]:[])),o++;return a}function $(t,e,r){for(var n=1;n<m;n++)for(var i=1;i<v;i++)for(var a=1;a<g;a++)X(t,y(a-1,i-1,n-1),y(a-1,i-1,n),y(a-1,i,n-1),y(a-1,i,n),y(a,i-1,n-1),y(a,i-1,n),y(a,i,n-1),y(a,i,n),e,r,(a+i+n)%2)}function Q(t,e,r){s=!0,$(t,e,r),s=!1}function tt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<m;u++)for(var h=1;h<v;h++)o.push(W(t,c,h,u,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function et(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<g;u++)for(var h=1;h<m;h++)o.push(W(t,u,c,h,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function rt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<v;u++)for(var h=1;h<g;h++)o.push(W(t,h,u,c,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function nt(t,e){for(var r=[],n=t;n<e;n++)r.push(n);return r}return function(){if(L(),function(){for(var e=0;e<g;e++)for(var r=0;r<v;r++)for(var n=0;n<m;n++){var i=y(e,r,n);P(t.x[i],t.y[i],t.z[i],t.value[i])}}(),i&&o&&(z(o),l=!0,$(null,M,S),l=!1),n&&a){z(a);for(var e=t.surface.pattern,r=t.surface.count,s=0;s<r;s++){var c=1===r?.5:s/(r-1),k=(1-c)*M+c*S,E=Math.abs(k-T)>Math.abs(k-A)?[T,k]:[k,A];Q(e,E[0],E[1])}}var C=[[Math.min(M,A),Math.max(M,A)],[Math.min(T,S),Math.max(T,S)]];[\"x\",\"y\",\"z\"].forEach(function(e){for(var r=[],n=0;n<C.length;n++){var i=0,a=C[n][0],o=C[n][1],s=t.slices[e];if(s.show&&s.fill){z(s.fill);var l=[],c=[],h=[];if(s.locations.length)for(var y=0;y<s.locations.length;y++){var x=u(s.locations[y],\"x\"===e?f:\"y\"===e?p:d);0===x.distRatio?l.push(x.id):x.id>0&&(c.push(x.id),\"x\"===e?h.push([x.distRatio,0,0]):\"y\"===e?h.push([0,x.distRatio,0]):h.push([0,0,x.distRatio]))}else l=nt(1,\"x\"===e?g-1:\"y\"===e?v-1:m-1);c.length>0&&(r[i]=\"x\"===e?tt(null,c,a,o,h,r[i]):\"y\"===e?et(null,c,a,o,h,r[i]):rt(null,c,a,o,h,r[i]),i++),l.length>0&&(r[i]=\"x\"===e?Z(null,l,a,o,r[i]):\"y\"===e?J(null,l,a,o,r[i]):K(null,l,a,o,r[i]),i++)}var b=t.caps[e];b.show&&b.fill&&(z(b.fill),r[i]=\"x\"===e?Z(null,[0,g-1],a,o,r[i]):\"y\"===e?J(null,[0,v-1],a,o,r[i]):K(null,[0,m-1],a,o,r[i]),i++)}}),0===h&&L(),t._x=x,t._y=b,t._z=_,t._intensity=w,t._Xs=f,t._Ys=p,t._Zs=d}(),t}f.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._x[e],n=this.data._y[e],i=this.data._z[e],a=this.data._Ys.length,o=this.data._Zs.length,s=u(r,this.data._Xs).id,l=u(n,this.data._Ys).id,c=u(i,this.data._Zs).id,h=t.index=c+o*l+o*a*s;t.traceCoordinate=[this.data._x[h],this.data._y[h],this.data._z[h],this.data.value[h]];var f=this.data.hovertext||this.data.text;return Array.isArray(f)&&void 0!==f[h]?t.textLabel=f[h]:f&&(t.textLabel=f),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map(function(e){return t.d2l(e,0,n)*r})}this.data=p(t);var i={positions:l(n(r.xaxis,t._x,e.dataScale[0],t.xcalendar),n(r.yaxis,t._y,e.dataScale[1],t.ycalendar),n(r.zaxis,t._z,e.dataScale[2],t.zcalendar)),cells:l(t._i,t._j,t._k),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:o(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},c=s(t);i.vertexIntensity=t._intensity,i.vertexIntensityBounds=[c.min,c.max],i.colormap=a(t),this.mesh.update(i)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports={findNearestOnAxis:u,generateIsoMeshes:p,createIsosurfaceTrace:function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new h(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../../plots/gl3d/zip3\":818,\"gl-mesh3d\":280}],1051:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"../../components/colorscale/defaults\");function s(t,e,r,n,a){var s=a(\"isomin\"),l=a(\"isomax\");null!=l&&null!=s&&s>l&&(e.isomin=null,e.isomax=null);var c=a(\"x\"),u=a(\"y\"),h=a(\"z\"),f=a(\"value\");c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length?(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],n),[\"x\",\"y\",\"z\"].forEach(function(t){var e=\"caps.\"+t;a(e+\".show\")&&a(e+\".fill\");var r=\"slices.\"+t;a(r+\".show\")&&(a(r+\".fill\"),a(r+\".locations\"))}),a(\"spaceframe.show\")&&a(\"spaceframe.fill\"),a(\"surface.show\")&&(a(\"surface.count\"),a(\"surface.fill\"),a(\"surface.pattern\")),a(\"contour.show\")&&(a(\"contour.color\"),a(\"contour.width\")),[\"text\",\"hovertext\",\"hovertemplate\",\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"flatshading\",\"opacity\"].forEach(function(t){a(t)}),o(t,e,n,a,{prefix:\"\",cLetter:\"c\"}),e._length=null):e.visible=!1}e.exports={supplyDefaults:function(t,e,r,i){s(t,e,0,i,function(r,i){return n.coerce(t,e,a,r,i)})},supplyIsoDefaults:s}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../../registry\":847,\"./attributes\":1048}],1052:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\").createIsosurfaceTrace,moduleType:\"trace\",name:\"isosurface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1048,\"./calc\":1049,\"./convert\":1050,\"./defaults\":1051}],1053:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../surface/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},i:{valType:\"data_array\",editType:\"calc\"},j:{valType:\"data_array\",editType:\"calc\"},k:{valType:\"data_array\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:i({editType:\"calc\"}),delaunayaxis:{valType:\"enumerated\",values:[\"x\",\"y\",\"z\"],dflt:\"z\",editType:\"calc\"},alphahull:{valType:\"number\",dflt:-1,editType:\"calc\"},intensity:{valType:\"data_array\",editType:\"calc\"},color:{valType:\"color\",editType:\"calc\"},vertexcolor:{valType:\"data_array\",editType:\"calc\"},facecolor:{valType:\"data_array\",editType:\"calc\"},transforms:void 0},n(\"\",{colorAttr:\"`intensity`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:a.opacity,flatshading:{valType:\"boolean\",dflt:!1,editType:\"calc\"},contour:{show:s({},a.contours.x.show,{}),color:a.contours.x.color,width:a.contours.x.width,editType:\"calc\"},lightposition:{x:s({},a.lightposition.x,{dflt:1e5}),y:s({},a.lightposition.y,{dflt:1e5}),z:s({},a.lightposition.z,{dflt:0}),editType:\"calc\"},lighting:s({vertexnormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-12,editType:\"calc\"},facenormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-6,editType:\"calc\"},editType:\"calc\"},a.lighting),hoverinfo:s({},o.hoverinfo,{editType:\"calc\"})})},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../surface/attributes\":1224}],1054:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.intensity&&n(t,e,{vals:e.intensity,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],1055:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"delaunay-triangulate\"),a=t(\"alpha-shape\"),o=t(\"convex-hull\"),s=t(\"../../lib/gl_format_color\").parseColorScale,l=t(\"../../lib/str2rgbarray\"),c=t(\"../../components/colorscale\").extractOpts,u=t(\"../../plots/gl3d/zip3\");function h(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.color=\"#fff\",this.data=null,this.showContour=!1}var f=h.prototype;function p(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=l(t[n]);return e}function d(t,e,r,n){for(var i=[],a=e.length,o=0;o<a;o++)i[o]=t.d2l(e[o],0,n)*r;return i}function g(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=Math.round(t[n]);return e}function v(t,e){for(var r=t.length,n=0;n<r;n++)if(t[n]<=-.5||t[n]>=e-.5)return!1;return!0}f.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index;t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]];var r=this.data.hovertext||this.data.text;return Array.isArray(r)&&void 0!==r[e]?t.textLabel=r[e]:r&&(t.textLabel=r),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;this.data=t;var n,h=t.x.length,f=u(d(r.xaxis,t.x,e.dataScale[0],t.xcalendar),d(r.yaxis,t.y,e.dataScale[1],t.ycalendar),d(r.zaxis,t.z,e.dataScale[2],t.zcalendar));if(t.i&&t.j&&t.k){if(t.i.length!==t.j.length||t.j.length!==t.k.length||!v(t.i,h)||!v(t.j,h)||!v(t.k,h))return;n=u(g(t.i),g(t.j),g(t.k))}else n=0===t.alphahull?o(f):t.alphahull>0?a(t.alphahull,f):function(t,e){for(var r=[\"x\",\"y\",\"z\"].indexOf(t),n=[],a=e.length,o=0;o<a;o++)n[o]=[e[o][(r+1)%3],e[o][(r+2)%3]];return i(n)}(t.delaunayaxis,f);var m={positions:f,cells:n,lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:l(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading};if(t.intensity){var y=c(t);this.color=\"#fff\",m.vertexIntensity=t.intensity,m.vertexIntensityBounds=[y.min,y.max],m.colormap=s(t)}else t.vertexcolor?(this.color=t.vertexcolor[0],m.vertexColors=p(t.vertexcolor)):t.facecolor?(this.color=t.facecolor[0],m.cellColors=p(t.facecolor)):(this.color=t.color,m.meshColor=l(t.color));this.mesh.update(m)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new h(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":605,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../../plots/gl3d/zip3\":818,\"alpha-shape\":64,\"convex-hull\":130,\"delaunay-triangulate\":165,\"gl-mesh3d\":280}],1056:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,n){return i.coerce(t,e,o,r,n)}function c(t){var e=t.map(function(t){var e=l(t);return e&&i.isArrayOrTypedArray(e)?e:null});return e.every(function(t){return t&&t.length===e[0].length})&&e}c([\"x\",\"y\",\"z\"])?(c([\"i\",\"j\",\"k\"]),(!e.i||e.j&&e.k)&&(!e.j||e.k&&e.i)&&(!e.k||e.i&&e.j)?(n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],s),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"contour.show\",\"contour.color\",\"contour.width\",\"colorscale\",\"reversescale\",\"flatshading\",\"alphahull\",\"delaunayaxis\",\"opacity\"].forEach(function(t){l(t)}),\"intensity\"in t?(l(\"intensity\"),a(t,e,s,l,{prefix:\"\",cLetter:\"c\"})):(e.showscale=!1,\"facecolor\"in t?l(\"facecolor\"):\"vertexcolor\"in t?l(\"vertexcolor\"):l(\"color\",r)),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),e._length=null):e.visible=!1):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../../registry\":847,\"./attributes\":1053}],1057:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"mesh3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1053,\"./calc\":1054,\"./convert\":1055,\"./defaults\":1056}],1058:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../scatter/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../components/fx/attributes\"),s=t(\"../../constants/delta.js\"),l=s.INCREASING.COLOR,c=s.DECREASING.COLOR,u=i.line;function h(t){return{line:{color:n({},u.color,{dflt:t}),width:u.width,dash:a,editType:\"style\"},editType:\"style\"}}e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},open:{valType:\"data_array\",editType:\"calc\"},high:{valType:\"data_array\",editType:\"calc\"},low:{valType:\"data_array\",editType:\"calc\"},close:{valType:\"data_array\",editType:\"calc\"},line:{width:n({},u.width,{}),dash:n({},a,{}),editType:\"style\"},increasing:h(l),decreasing:h(c),text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},tickwidth:{valType:\"number\",min:0,max:.5,dflt:.3,editType:\"calc\"},hoverlabel:n({},o.hoverlabel,{split:{valType:\"boolean\",dflt:!1,editType:\"style\"}})}},{\"../../components/drawing/attributes\":613,\"../../components/fx/attributes\":623,\"../../constants/delta.js\":689,\"../../lib\":719,\"../scatter/attributes\":1112}],1059:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=n._,a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/numerical\").BADNUM;function s(t,e,r,n){return{o:t,h:e,l:r,c:n}}function l(t,e,r,s,l){for(var c=s.makeCalcdata(e,\"open\"),u=s.makeCalcdata(e,\"high\"),h=s.makeCalcdata(e,\"low\"),f=s.makeCalcdata(e,\"close\"),p=Array.isArray(e.text),d=Array.isArray(e.hovertext),g=!0,v=null,m=[],y=0;y<r.length;y++){var x=r[y],b=c[y],_=u[y],w=h[y],k=f[y];if(x!==o&&b!==o&&_!==o&&w!==o&&k!==o){k===b?null!==v&&k!==v&&(g=k>v):g=k>b,v=k;var T=l(b,_,w,k);T.pos=x,T.yc=(b+k)/2,T.i=y,T.dir=g?\"increasing\":\"decreasing\",T.x=T.pos,T.y=[w,_],p&&(T.tx=e.text[y]),d&&(T.htx=e.hovertext[y]),m.push(T)}else m.push({pos:x,empty:!0})}return e._extremes[s._id]=a.findExtremes(s,n.concat(h,u),{padded:!0}),m.length&&(m[0].t={labels:{open:i(t,\"open:\")+\" \",high:i(t,\"high:\")+\" \",low:i(t,\"low:\")+\" \",close:i(t,\"close:\")+\" \"}}),m}e.exports={calc:function(t,e){var r=a.getFromId(t,e.xaxis),i=a.getFromId(t,e.yaxis),o=function(t,e,r){var i=r._minDiff;if(!i){var a,o=t._fullData,s=[];for(i=1/0,a=0;a<o.length;a++){var l=o[a];if(\"ohlc\"===l.type&&!0===l.visible&&l.xaxis===e._id){s.push(l);var c=e.makeCalcdata(l,\"x\");l._xcalc=c;var u=n.distinctVals(c).minDiff;u&&isFinite(u)&&(i=Math.min(i,u))}}for(i===1/0&&(i=1),a=0;a<s.length;a++)s[a]._minDiff=i}return i*r.tickwidth}(t,r,e),c=e._minDiff;e._minDiff=null;var u=e._xcalc;e._xcalc=null;var h=l(t,e,u,i,s);return e._extremes[r._id]=a.findExtremes(r,u,{vpad:c/2}),h.length?(n.extendFlat(h[0].t,{wHover:c/2,tickLen:o}),h):[{t:{empty:!0}}]},calcCommon:l}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],1060:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./ohlc_defaults\"),a=t(\"./attributes\");function o(t,e,r,n){r(n+\".line.color\"),r(n+\".line.width\",e.line.width),r(n+\".line.dash\",e.line.dash)}e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,a,r,i)}i(t,e,l,s)?(l(\"line.width\"),l(\"line.dash\"),o(t,e,l,\"increasing\"),o(t,e,l,\"decreasing\"),l(\"text\"),l(\"hovertext\"),l(\"tickwidth\"),s._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../lib\":719,\"./attributes\":1058,\"./ohlc_defaults\":1063}],1061:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\").fillText,l=t(\"../../constants/delta.js\"),c={increasing:l.INCREASING.SYMBOL,decreasing:l.DECREASING.SYMBOL};function u(t,e,r,n){var i,s,l=t.cd,c=t.xa,u=l[0].trace,h=l[0].t,f=u.type,p=\"ohlc\"===f?\"l\":\"min\",d=\"ohlc\"===f?\"h\":\"max\",g=h.bPos||0,v=function(t){return t.pos+g-e},m=h.bdPos||h.tickLen,y=h.wHover,x=Math.min(1,m/Math.abs(c.r2c(c.range[1])-c.r2c(c.range[0])));function b(t){var e=v(t);return a.inbox(e-y,e+y,i)}function _(t){var e=t[p],n=t[d];return e===n||a.inbox(e-r,n-r,i)}function w(t){return(b(t)+_(t))/2}i=t.maxHoverDistance-x,s=t.maxSpikeDistance-x;var k=a.getDistanceFunction(n,b,_,w);if(a.getClosest(l,k,t),!1===t.index)return null;var T=l[t.index];if(T.empty)return null;var A=u[T.dir],M=A.line.color;return o.opacity(M)&&A.line.width?t.color=M:t.color=A.fillcolor,t.x0=c.c2p(T.pos+g-m,!0),t.x1=c.c2p(T.pos+g+m,!0),t.xLabelVal=T.pos,t.spikeDistance=w(T)*s/i,t.xSpike=c.c2p(T.pos,!0),t}function h(t,e,r,a){var o=t.cd,s=t.ya,l=o[0].trace,c=o[0].t,h=[],f=u(t,e,r,a);if(!f)return[];var p=o[f.index].hi||l.hoverinfo,d=p.split(\"+\");if(!(\"all\"===p||-1!==d.indexOf(\"y\")))return[];for(var g=[\"high\",\"open\",\"close\",\"low\"],v={},m=0;m<g.length;m++){var y,x=g[m],b=l[x][f.index],_=s.c2p(b,!0);b in v?(y=v[b]).yLabel+=\"<br>\"+c.labels[x]+n.hoverLabelText(s,b):((y=i.extendFlat({},f)).y0=y.y1=_,y.yLabelVal=b,y.yLabel=c.labels[x]+n.hoverLabelText(s,b),y.name=\"\",h.push(y),v[b]=y)}return h}function f(t,e,r,i){var a=t.cd,o=t.ya,l=a[0].trace,h=a[0].t,f=u(t,e,r,i);if(!f)return[];var p=a[f.index],d=f.index=p.i,g=p.dir;function v(t){return h.labels[t]+n.hoverLabelText(o,l[t][d])}var m=p.hi||l.hoverinfo,y=m.split(\"+\"),x=\"all\"===m,b=x||-1!==y.indexOf(\"y\"),_=x||-1!==y.indexOf(\"text\"),w=b?[v(\"open\"),v(\"high\"),v(\"low\"),v(\"close\")+\"  \"+c[g]]:[];return _&&s(p,l,w),f.extraText=w.join(\"<br>\"),f.y0=f.y1=o.c2p(p.yc,!0),[f]}e.exports={hoverPoints:function(t,e,r,n){return t.cd[0].trace.hoverlabel.split?h(t,e,r,n):f(t,e,r,n)},hoverSplit:h,hoverOnPoints:f}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../constants/delta.js\":689,\"../../lib\":719,\"../../plots/cartesian/axes\":767}],1062:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"ohlc\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\"],meta:{},attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\").calc,plot:t(\"./plot\"),style:t(\"./style\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\")}},{\"../../plots/cartesian\":778,\"./attributes\":1058,\"./calc\":1059,\"./defaults\":1060,\"./hover\":1061,\"./plot\":1064,\"./select\":1065,\"./style\":1066}],1063:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"open\"),l=r(\"high\"),c=r(\"low\"),u=r(\"close\");if(r(\"hoverlabel.split\"),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\"],a),s&&l&&c&&u){var h=Math.min(s.length,l.length,c.length,u.length);return o&&(h=Math.min(h,i.minRowLength(o))),e._length=h,h}}},{\"../../lib\":719,\"../../registry\":847}],1064:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=e.xaxis,s=e.yaxis;i.makeTraceGroups(a,r,\"trace ohlc\").each(function(t){var e=n.select(this),r=t[0],a=r.t;if(!0!==r.trace.visible||a.empty)e.remove();else{var l=a.tickLen,c=e.selectAll(\"path\").data(i.identity);c.enter().append(\"path\"),c.exit().remove(),c.attr(\"d\",function(t){if(t.empty)return\"M0,0Z\";var e=o.c2p(t.pos,!0),r=o.c2p(t.pos-l,!0),n=o.c2p(t.pos+l,!0);return\"M\"+r+\",\"+s.c2p(t.o,!0)+\"H\"+e+\"M\"+e+\",\"+s.c2p(t.h,!0)+\"V\"+s.c2p(t.l,!0)+\"M\"+n+\",\"+s.c2p(t.c,!0)+\"H\"+e})}})}},{\"../../lib\":719,d3:163}],1065:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n=t.cd,i=t.xaxis,a=t.yaxis,o=[],s=n[0].t.bPos||0;if(!1===e)for(r=0;r<n.length;r++)n[r].selected=0;else for(r=0;r<n.length;r++){var l=n[r];e.contains([i.c2p(l.pos+s),a.c2p(l.yc)],null,l.i,t)?(o.push({pointNumber:l.i,x:i.c2d(l.pos),y:a.c2d(l.yc)}),l.selected=1):l.selected=0}return o}},{}],1066:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\");e.exports=function(t,e,r){var o=r||n.select(t).selectAll(\"g.ohlclayer\").selectAll(\"g.trace\");o.style(\"opacity\",function(t){return t[0].trace.opacity}),o.each(function(t){var e=t[0].trace;n.select(this).selectAll(\"path\").each(function(t){if(!t.empty){var r=e[t.dir].line;n.select(this).style(\"fill\",\"none\").call(a.stroke,r.color).call(i.dashLine,r.dash,r.width).style(\"opacity\",e.selectedpoints&&!t.selected?.3:1)}})})}},{\"../../components/color\":593,\"../../components/drawing\":614,d3:163}],1067:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../plots/attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/fx/hovertemplate_attributes\"),l=t(\"../../plots/domain\").attributes,c=n({editType:\"calc\"},o(\"line\",{editTypeOverride:\"calc\"}),{shape:{valType:\"enumerated\",values:[\"linear\",\"hspline\"],dflt:\"linear\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\"]})});e.exports={domain:l({name:\"parcats\",trace:!0,editType:\"calc\"}),hoverinfo:n({},i.hoverinfo,{flags:[\"count\",\"probability\"],editType:\"plot\",arrayOk:!1}),hoveron:{valType:\"enumerated\",values:[\"category\",\"color\",\"dimension\"],dflt:\"category\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\",\"category\",\"categorycount\",\"colorcount\",\"bandcolorcount\"]}),arrangement:{valType:\"enumerated\",values:[\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"perpendicular\",editType:\"plot\"},bundlecolors:{valType:\"boolean\",dflt:!0,editType:\"plot\"},sortpaths:{valType:\"enumerated\",values:[\"forward\",\"backward\"],dflt:\"forward\",editType:\"plot\"},labelfont:a({editType:\"calc\"}),tickfont:a({editType:\"calc\"}),dimensions:{_isLinkedToArray:\"dimension\",label:{valType:\"string\",editType:\"calc\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",dflt:[],editType:\"calc\"},displayindex:{valType:\"integer\",editType:\"calc\"},editType:\"calc\",visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"}},line:c,counts:{valType:\"number\",min:0,dflt:1,arrayOk:!0,editType:\"calc\"},customdata:void 0,hoverlabel:void 0,ids:void 0,legendgroup:void 0,opacity:void 0,selectedpoints:void 0,showlegend:void 0}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1068:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"parcats\",r.plot=function(t,e,r,a){var o=n(t.calcdata,\"parcats\");if(o.length){var s=o[0];i(t,s,r,a)}},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcats\"),a=e._has&&e._has(\"parcats\");i&&!a&&n._paperdiv.selectAll(\".parcats\").remove()}},{\"../../plots/get_data\":802,\"./plot\":1073}],1069:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),o=t(\"../../lib/filter_unique.js\"),s=t(\"../../components/drawing\"),l=t(\"../../lib\");function c(t,e,r){t.valueInds.push(e),t.count+=r}function u(t,e,r){t.valueInds.push(e),t.count+=r}e.exports=function(t,e){var r=l.filterVisible(e.dimensions);if(0===r.length)return[];var h,f,p,d=r.map(function(t){var e;return\"trace\"===t.categoryorder?e=null:\"array\"===t.categoryorder?e=t.categoryarray:(e=o(t.values).sort(),\"category descending\"===t.categoryorder&&(e=e.reverse())),function(t,e){e=null==e?[]:e.map(function(t){return t});var r={},n={},i=[];e.forEach(function(t,e){r[t]=0,n[t]=e});for(var a=0;a<t.length;a++){var o,s=t[a];void 0===r[s]?(r[s]=1,o=e.push(s)-1,n[s]=o):(r[s]++,o=n[s]),i.push(o)}var l=e.map(function(t){return r[t]});return{uniqueValues:e,uniqueCounts:l,inds:i}}(t.values,e)});h=l.isArrayOrTypedArray(e.counts)?e.counts:[e.counts],function(t){var e;if(function(t){for(var e=new Array(t.length),r=0;r<t.length;r++){if(t[r]<0||t[r]>=t.length)return!1;if(void 0!==e[t[r]])return!1;e[t[r]]=!0}return!0}(t.map(function(t){return t.displayindex})))for(e=0;e<t.length;e++)t[e]._displayindex=t[e].displayindex;else for(e=0;e<t.length;e++)t[e]._displayindex=e}(r),r.forEach(function(t,e){!function(t,e){t._categoryarray=e.uniqueValues,null===t.ticktext||void 0===t.ticktext?t._ticktext=[]:t._ticktext=t.ticktext.slice();for(var r=t._ticktext.length;r<e.uniqueValues.length;r++)t._ticktext.push(e.uniqueValues[r])}(t,d[e])});var g,v=e.line;v?(i(e,\"line\")&&a(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),g=s.tryColorscale(v)):g=l.identity;var m,y,x,b,_=r[0].values.length,w={},k=d.map(function(t){return t.inds});for(p=0,m=0;m<_;m++){var T=[];for(y=0;y<k.length;y++)T.push(k[y][m]);f=h[m%h.length],p+=f;var A=(x=m,b=void 0,b=l.isArrayOrTypedArray(v.color)?v.color[x%v.color.length]:v.color,{color:g(b),rawColor:b}),M=T+\"-\"+A.rawColor;void 0===w[M]&&(w[M]={categoryInds:T,color:A.color,rawColor:A.rawColor,valueInds:[],count:0}),u(w[M],m,f)}var S,E=r.map(function(t,e){return r=e,n=t._index,i=t._displayindex,a=t.label,{dimensionInd:r,containerInd:n,displayInd:i,dimensionLabel:a,count:p,categories:[],dragX:null};var r,n,i,a});for(m=0;m<_;m++)for(f=h[m%h.length],y=0;y<E.length;y++){var C=E[y].containerInd,L=d[y].inds[m],P=E[y].categories;if(void 0===P[L]){var O=e.dimensions[C]._categoryarray[L],z=e.dimensions[C]._ticktext[L];P[L]={dimensionInd:y,categoryInd:S=L,categoryValue:O,displayInd:S,categoryLabel:z,valueInds:[],count:0,dragY:null}}c(P[L],m,f)}return n(function(t,e,r){var n=t.map(function(t){return t.categories.length}).reduce(function(t,e){return Math.max(t,e)});return{dimensions:t,paths:e,trace:void 0,maxCats:n,count:r}}(E,w,p))}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/filter_unique.js\":711,\"../../lib/gup\":717}],1070:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"./attributes\"),c=t(\"../parcoords/merge_length\");function u(t,e){function r(r,i){return n.coerce(t,e,l.dimensions,r,i)}var i=r(\"values\"),a=r(\"visible\");if(i&&i.length||(a=e.visible=!1),a){r(\"label\"),r(\"displayindex\",e._index);var o,s=t.categoryarray,c=Array.isArray(s)&&s.length>0;c&&(o=\"array\");var u=r(\"categoryorder\",o);\"array\"===u?(r(\"categoryarray\"),r(\"ticktext\")):(delete t.categoryarray,delete t.ticktext),c||\"array\"!==u||(e.categoryorder=\"trace\")}}e.exports=function(t,e,r,h){function f(r,i){return n.coerce(t,e,l,r,i)}var p=s(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=function(t,e,r,o,s){s(\"line.shape\"),s(\"line.hovertemplate\");var l=s(\"line.color\",o.colorway[0]);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,h,f);o(e,h,f),Array.isArray(p)&&p.length||(e.visible=!1),c(e,p,\"values\",d),f(\"hoveron\"),f(\"hovertemplate\"),f(\"arrangement\"),f(\"bundlecolors\"),f(\"sortpaths\"),f(\"counts\");var g={family:h.font.family,size:Math.round(h.font.size),color:h.font.color};n.coerceFont(f,\"labelfont\",g);var v={family:h.font.family,size:Math.round(h.font.size/1.2),color:h.font.color};n.coerceFont(f,\"tickfont\",v)}},{\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/domain\":792,\"../parcoords/merge_length\":1083,\"./attributes\":1067}],1071:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcats\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1067,\"./base_plot\":1068,\"./calc\":1069,\"./defaults\":1070,\"./plot\":1073}],1072:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plot_api/plot_api\"),a=t(\"../../components/fx\"),o=t(\"../../lib\"),s=t(\"../../components/drawing\"),l=t(\"tinycolor2\"),c=t(\"../../lib/svg_text_utils\");function u(t,e,r,i){var a=t.map(function(t,e,r){var n,i=r[0],a=e.margin||{l:80,r:80,t:100,b:80},o=i.trace,s=o.domain,l=e.width,c=e.height,u=Math.floor(l*(s.x[1]-s.x[0])),h=Math.floor(c*(s.y[1]-s.y[0])),f=s.x[0]*l+a.l,p=e.height-s.y[1]*e.height+a.t,d=o.line.shape;n=\"all\"===o.hoverinfo?[\"count\",\"probability\"]:(o.hoverinfo||\"\").split(\"+\");var g={trace:o,key:o.uid,model:i,x:f,y:p,width:u,height:h,hoveron:o.hoveron,hoverinfoItems:n,arrangement:o.arrangement,bundlecolors:o.bundlecolors,sortpaths:o.sortpaths,labelfont:o.labelfont,categorylabelfont:o.tickfont,pathShape:d,dragDimension:null,margin:a,paths:[],dimensions:[],graphDiv:t,traceSelection:null,pathSelection:null,dimensionSelection:null};i.dimensions&&(R(g),D(g));return g}.bind(0,e,r)),l=i.selectAll(\"g.parcatslayer\").data([null]);l.enter().append(\"g\").attr(\"class\",\"parcatslayer\").style(\"pointer-events\",\"all\");var u=l.selectAll(\"g.trace.parcats\").data(a,h),v=u.enter().append(\"g\").attr(\"class\",\"trace parcats\");u.attr(\"transform\",function(t){return\"translate(\"+t.x+\", \"+t.y+\")\"}),v.append(\"g\").attr(\"class\",\"paths\");var x=u.select(\"g.paths\").selectAll(\"path.path\").data(function(t){return t.paths},h);x.attr(\"fill\",function(t){return t.model.color});var w=x.enter().append(\"path\").attr(\"class\",\"path\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.model.color}).attr(\"fill-opacity\",0);y(w),x.attr(\"d\",function(t){return t.svgD}),w.empty()||x.sort(p),x.exit().remove(),x.on(\"mouseover\",d).on(\"mouseout\",g).on(\"click\",m),v.append(\"g\").attr(\"class\",\"dimensions\");var k=u.select(\"g.dimensions\").selectAll(\"g.dimension\").data(function(t){return t.dimensions},h);k.enter().append(\"g\").attr(\"class\",\"dimension\"),k.attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),k.exit().remove();var T=k.selectAll(\"g.category\").data(function(t){return t.categories},h),A=T.enter().append(\"g\").attr(\"class\",\"category\");T.attr(\"transform\",function(t){return\"translate(0, \"+t.y+\")\"}),A.append(\"rect\").attr(\"class\",\"catrect\").attr(\"pointer-events\",\"none\"),T.select(\"rect.catrect\").attr(\"fill\",\"none\").attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}),b(A);var P=T.selectAll(\"rect.bandrect\").data(function(t){return t.bands},h);P.each(function(){o.raiseToTop(this)}),P.attr(\"fill\",function(t){return t.color});var O=P.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.color}).attr(\"fill-opacity\",0);P.attr(\"fill\",function(t){return t.color}).attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}).attr(\"y\",function(t){return t.y}).attr(\"cursor\",function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"perpendicular\"===t.parcatsViewModel.arrangement?\"ns-resize\":\"move\"}),_(O),P.exit().remove(),A.append(\"text\").attr(\"class\",\"catlabel\").attr(\"pointer-events\",\"none\");var z=e._fullLayout.paper_bgcolor;T.select(\"text.catlabel\").attr(\"text-anchor\",function(t){return f(t)?\"start\":\"end\"}).attr(\"alignment-baseline\",\"middle\").style(\"text-shadow\",z+\" -1px  1px 2px, \"+z+\" 1px  1px 2px, \"+z+\"  1px -1px 2px, \"+z+\" -1px -1px 2px\").style(\"fill\",\"rgb(0, 0, 0)\").attr(\"x\",function(t){return f(t)?t.width+5:-5}).attr(\"y\",function(t){return t.height/2}).text(function(t){return t.model.categoryLabel}).each(function(t){s.font(n.select(this),t.parcatsViewModel.categorylabelfont),c.convertToTspans(n.select(this),e)}),A.append(\"text\").attr(\"class\",\"dimlabel\"),T.select(\"text.dimlabel\").attr(\"text-anchor\",\"middle\").attr(\"alignment-baseline\",\"baseline\").attr(\"cursor\",function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"ew-resize\"}).attr(\"x\",function(t){return t.width/2}).attr(\"y\",-5).text(function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null}).each(function(t){s.font(n.select(this),t.parcatsViewModel.labelfont)}),T.selectAll(\"rect.bandrect\").on(\"mouseover\",M).on(\"mouseout\",S),T.exit().remove(),k.call(n.behavior.drag().origin(function(t){return{x:t.x,y:0}}).on(\"dragstart\",E).on(\"drag\",C).on(\"dragend\",L)),u.each(function(t){t.traceSelection=n.select(this),t.pathSelection=n.select(this).selectAll(\"g.paths\").selectAll(\"path.path\"),t.dimensionSelection=n.select(this).selectAll(\"g.dimensions\").selectAll(\"g.dimension\")}),u.exit().remove()}function h(t){return t.key}function f(t){var e=t.parcatsViewModel.dimensions.length,r=t.parcatsViewModel.dimensions[e-1].model.dimensionInd;return t.model.dimensionInd===r}function p(t,e){return t.model.rawColor>e.model.rawColor?1:t.model.rawColor<e.model.rawColor?-1:0}function d(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){o.raiseToTop(this),x(n.select(this));var e=v(t);if(t.parcatsViewModel.graphDiv.emit(\"plotly_hover\",{points:e,event:n.event}),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\")){var r,i,s,c=n.mouse(this)[0],u=t.parcatsViewModel.graphDiv,h=t.parcatsViewModel.trace,f=u._fullLayout,p=f._paperdiv.node().getBoundingClientRect(),d=t.parcatsViewModel.graphDiv.getBoundingClientRect();for(s=0;s<t.leftXs.length-1;s++)if(t.leftXs[s]+t.dimWidths[s]-2<=c&&c<=t.leftXs[s+1]+2){var g=t.parcatsViewModel.dimensions[s],m=t.parcatsViewModel.dimensions[s+1];r=(g.x+g.width+m.x)/2,i=(t.topYs[s]+t.topYs[s+1]+t.height)/2;break}var y=t.parcatsViewModel.x+r,b=t.parcatsViewModel.y+i,_=l.mostReadable(t.model.color,[\"black\",\"white\"]),w=t.model.count,k=w/t.parcatsViewModel.model.count,T={countLabel:w,probabilityLabel:k.toFixed(3)},A=[];-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&A.push([\"Count:\",T.countLabel].join(\" \")),-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&A.push([\"P:\",T.probabilityLabel].join(\" \"));var M=A.join(\"<br>\"),S=n.mouse(u)[0];a.loneHover({trace:h,x:y-p.left+d.left,y:b-p.top+d.top,text:M,color:t.model.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:10,fontColor:_,idealAlign:S<y?\"right\":\"left\",hovertemplate:(h.line||{}).hovertemplate,hovertemplateLabels:T,eventData:[{data:h._input,fullData:h,count:w,probability:k}]},{container:f._hoverlayer.node(),outerContainer:f._paper.node(),gd:u})}}}function g(t){if(!t.parcatsViewModel.dragDimension&&(y(n.select(this)),a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()),t.parcatsViewModel.pathSelection.sort(p),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\"))){var e=v(t);t.parcatsViewModel.graphDiv.emit(\"plotly_unhover\",{points:e,event:n.event})}}function v(t){for(var e=[],r=P(t.parcatsViewModel),n=0;n<t.model.valueInds.length;n++){var i=t.model.valueInds[n];e.push({curveNumber:r,pointNumber:i})}return e}function m(t){if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){var e=v(t);t.parcatsViewModel.graphDiv.emit(\"plotly_click\",{points:e,event:n.event})}}function y(t){t.attr(\"fill\",function(t){return t.model.color}).attr(\"fill-opacity\",.6).attr(\"stroke\",\"lightgray\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1)}function x(t){t.attr(\"fill-opacity\",.8).attr(\"stroke\",function(t){return l.mostReadable(t.model.color,[\"black\",\"white\"])}).attr(\"stroke-width\",.3)}function b(t){t.select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",1).attr(\"stroke-opacity\",1)}function _(t){t.attr(\"stroke\",\"black\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1).attr(\"fill-opacity\",1)}function w(t){var e=t.parcatsViewModel.pathSelection,r=t.categoryViewModel.model.dimensionInd,n=t.categoryViewModel.model.categoryInd;return e.filter(function(e){return e.model.categoryInds[r]===n&&e.model.color===t.color})}function k(t,e,r){var i=n.select(t).datum().parcatsViewModel.graphDiv,a=n.select(t.parentNode).selectAll(\"rect.bandrect\"),o=[];a.each(function(t){w(t).each(function(t){Array.prototype.push.apply(o,v(t))})}),i.emit(e,{points:o,event:r})}function T(t,e,r){var i=n.select(t).datum(),a=i.parcatsViewModel.graphDiv,o=w(i),s=[];o.each(function(t){Array.prototype.push.apply(s,v(t))}),a.emit(e,{points:s,event:r})}function A(t,e){var r,i,a=n.select(e.parentNode).select(\"rect.catrect\"),o=a.node().getBoundingClientRect(),s=a.datum(),l=s.parcatsViewModel,c=l.model.dimensions[s.model.dimensionInd],u=l.trace,h=o.top+o.height/2;l.dimensions.length>1&&c.displayInd===l.dimensions.length-1?(r=o.left,i=\"left\"):(r=o.left+o.width,i=\"right\");var f=s.model.count,p=s.model.categoryLabel,d=f/s.parcatsViewModel.model.count,g={countLabel:f,categoryLabel:p,probabilityLabel:d.toFixed(3)},v=[];-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&v.push([\"Count:\",g.countLabel].join(\" \")),-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&v.push([\"P(\"+g.categoryLabel+\"):\",g.probabilityLabel].join(\" \"));var m=v.join(\"<br>\");return{trace:u,x:r-t.left,y:h-t.top,text:m,color:\"lightgray\",borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:12,fontColor:\"black\",idealAlign:i,hovertemplate:u.hovertemplate,hovertemplateLabels:g,eventData:[{data:u._input,fullData:u,count:f,category:p,probability:d}]}}function M(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){if(n.mouse(this)[1]<-1)return;var e,r=t.parcatsViewModel.graphDiv,i=r._fullLayout,s=i._paperdiv.node().getBoundingClientRect(),c=t.parcatsViewModel.hoveron;if(\"color\"===c?(!function(t){var e=n.select(t).datum(),r=w(e);x(r),r.each(function(){o.raiseToTop(this)}),n.select(t.parentNode).selectAll(\"rect.bandrect\").filter(function(t){return t.color===e.color}).each(function(){o.raiseToTop(this),n.select(this).attr(\"stroke\",\"black\").attr(\"stroke-width\",1.5)})}(this),T(this,\"plotly_hover\",n.event)):(!function(t){n.select(t.parentNode).selectAll(\"rect.bandrect\").each(function(t){var e=w(t);x(e),e.each(function(){o.raiseToTop(this)})}),n.select(t.parentNode).select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",2.5)}(this),k(this,\"plotly_hover\",n.event)),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\"))\"category\"===c?e=A(s,this):\"color\"===c?e=function(t,e){var r,i,a=e.getBoundingClientRect(),o=n.select(e).datum(),s=o.categoryViewModel,c=s.parcatsViewModel,u=c.model.dimensions[s.model.dimensionInd],h=c.trace,f=a.y+a.height/2;c.dimensions.length>1&&u.displayInd===c.dimensions.length-1?(r=a.left,i=\"left\"):(r=a.left+a.width,i=\"right\");var p=s.model.categoryLabel,d=o.parcatsViewModel.model.count,g=0;o.categoryViewModel.bands.forEach(function(t){t.color===o.color&&(g+=t.count)});var v=s.model.count,m=0;c.pathSelection.each(function(t){t.model.color===o.color&&(m+=t.model.count)});var y=g/d,x=g/m,b=g/v,_={countLabel:d,categoryLabel:p,probabilityLabel:y.toFixed(3)},w=[];-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&w.push([\"Count:\",_.countLabel].join(\" \")),-1!==s.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&(w.push(\"P(color \\u2229 \"+p+\"): \"+_.probabilityLabel),w.push(\"P(\"+p+\" | color): \"+x.toFixed(3)),w.push(\"P(color | \"+p+\"): \"+b.toFixed(3)));var k=w.join(\"<br>\"),T=l.mostReadable(o.color,[\"black\",\"white\"]);return{trace:h,x:r-t.left,y:f-t.top,text:k,color:o.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontColor:T,fontSize:10,idealAlign:i,hovertemplate:h.hovertemplate,hovertemplateLabels:_,eventData:[{data:h._input,fullData:h,category:p,count:d,probability:y,categorycount:v,colorcount:m,bandcolorcount:g}]}}(s,this):\"dimension\"===c&&(e=function(t,e){var r=[];return n.select(e.parentNode.parentNode).selectAll(\"g.category\").select(\"rect.catrect\").each(function(){r.push(A(t,this))}),r}(s,this)),e&&a.loneHover(e,{container:i._hoverlayer.node(),outerContainer:i._paper.node(),gd:r})}}function S(t){var e=t.parcatsViewModel;if(!e.dragDimension&&(y(e.pathSelection),b(e.dimensionSelection.selectAll(\"g.category\")),_(e.dimensionSelection.selectAll(\"g.category\").selectAll(\"rect.bandrect\")),a.loneUnhover(e.graphDiv._fullLayout._hoverlayer.node()),e.pathSelection.sort(p),-1===e.hoverinfoItems.indexOf(\"skip\"))){\"color\"===t.parcatsViewModel.hoveron?T(this,\"plotly_unhover\",n.event):k(this,\"plotly_unhover\",n.event)}}function E(t){\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragDimensionDisplayInd=t.model.displayInd,t.initialDragDimensionDisplayInds=t.parcatsViewModel.model.dimensions.map(function(t){return t.displayInd}),t.dragHasMoved=!1,t.dragCategoryDisplayInd=null,n.select(this).selectAll(\"g.category\").select(\"rect.catrect\").each(function(e){var r=n.mouse(this)[0],i=n.mouse(this)[1];-2<=r&&r<=e.width+2&&-2<=i&&i<=e.height+2&&(t.dragCategoryDisplayInd=e.model.displayInd,t.initialDragCategoryDisplayInds=t.model.categories.map(function(t){return t.displayInd}),e.model.dragY=e.y,o.raiseToTop(this.parentNode),n.select(this.parentNode).selectAll(\"rect.bandrect\").each(function(e){e.y<i&&i<=e.y+e.height&&(t.potentialClickBand=this)}))}),t.parcatsViewModel.dragDimension=t,a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()))}function C(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragHasMoved=!0,null!==t.dragDimensionDisplayInd)){var e=t.dragDimensionDisplayInd,r=e-1,i=e+1,a=t.parcatsViewModel.dimensions[e];if(null!==t.dragCategoryDisplayInd){var o=a.categories[t.dragCategoryDisplayInd];o.model.dragY+=n.event.dy;var s=o.model.dragY,l=o.model.displayInd,c=a.categories,u=c[l-1],h=c[l+1];void 0!==u&&s<u.y+u.height/2&&(o.model.displayInd=u.model.displayInd,u.model.displayInd=l),void 0!==h&&s+o.height>h.y+h.height/2&&(o.model.displayInd=h.model.displayInd,h.model.displayInd=l),t.dragCategoryDisplayInd=o.model.displayInd}if(null===t.dragCategoryDisplayInd||\"freeform\"===t.parcatsViewModel.arrangement){a.model.dragX=n.event.x;var f=t.parcatsViewModel.dimensions[r],p=t.parcatsViewModel.dimensions[i];void 0!==f&&a.model.dragX<f.x+f.width&&(a.model.displayInd=f.model.displayInd,f.model.displayInd=e),void 0!==p&&a.model.dragX+a.width>p.x&&(a.model.displayInd=p.model.displayInd,p.model.displayInd=t.dragDimensionDisplayInd),t.dragDimensionDisplayInd=a.model.displayInd}R(t.parcatsViewModel),D(t.parcatsViewModel),z(t.parcatsViewModel),O(t.parcatsViewModel)}}function L(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&null!==t.dragDimensionDisplayInd){n.select(this).selectAll(\"text\").attr(\"font-weight\",\"normal\");var e={},r=P(t.parcatsViewModel),a=t.parcatsViewModel.model.dimensions.map(function(t){return t.displayInd}),o=t.initialDragDimensionDisplayInds.some(function(t,e){return t!==a[e]});o&&a.forEach(function(r,n){var i=t.parcatsViewModel.model.dimensions[n].containerInd;e[\"dimensions[\"+i+\"].displayindex\"]=r});var s=!1;if(null!==t.dragCategoryDisplayInd){var l=t.model.categories.map(function(t){return t.displayInd});if(s=t.initialDragCategoryDisplayInds.some(function(t,e){return t!==l[e]})){var c=t.model.categories.slice().sort(function(t,e){return t.displayInd-e.displayInd}),u=c.map(function(t){return t.categoryValue}),h=c.map(function(t){return t.categoryLabel});e[\"dimensions[\"+t.model.containerInd+\"].categoryarray\"]=[u],e[\"dimensions[\"+t.model.containerInd+\"].ticktext\"]=[h],e[\"dimensions[\"+t.model.containerInd+\"].categoryorder\"]=\"array\"}}if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")&&!t.dragHasMoved&&t.potentialClickBand&&(\"color\"===t.parcatsViewModel.hoveron?T(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent):k(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent)),t.model.dragX=null,null!==t.dragCategoryDisplayInd)t.parcatsViewModel.dimensions[t.dragDimensionDisplayInd].categories[t.dragCategoryDisplayInd].model.dragY=null,t.dragCategoryDisplayInd=null;t.dragDimensionDisplayInd=null,t.parcatsViewModel.dragDimension=null,t.dragHasMoved=null,t.potentialClickBand=null,R(t.parcatsViewModel),D(t.parcatsViewModel),n.transition().duration(300).ease(\"cubic-in-out\").each(function(){z(t.parcatsViewModel,!0),O(t.parcatsViewModel,!0)}).each(\"end\",function(){(o||s)&&i.restyle(t.parcatsViewModel.graphDiv,e,[r])})}}function P(t){for(var e,r=t.graphDiv._fullData,n=0;n<r.length;n++)if(t.key===r[n].uid){e=n;break}return e}function O(t,e){var r;void 0===e&&(e=!1),t.pathSelection.data(function(t){return t.paths},h),(r=t.pathSelection,e?r.transition():r).attr(\"d\",function(t){return t.svgD})}function z(t,e){function r(t){return e?t.transition():t}void 0===e&&(e=!1),t.dimensionSelection.data(function(t){return t.dimensions},h);var i=t.dimensionSelection.selectAll(\"g.category\").data(function(t){return t.categories},h);r(t.dimensionSelection).attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),r(i).attr(\"transform\",function(t){return\"translate(0, \"+t.y+\")\"}),i.select(\".dimlabel\").text(function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null}),i.select(\".catlabel\").attr(\"text-anchor\",function(t){return f(t)?\"start\":\"end\"}).attr(\"x\",function(t){return f(t)?t.width+5:-5}).each(function(t){var e,r;f(t)?(e=t.width+5,r=\"start\"):(e=-5,r=\"end\"),n.select(this).selectAll(\"tspan\").attr(\"x\",e).attr(\"text-anchor\",r)});var a=i.selectAll(\"rect.bandrect\").data(function(t){return t.bands},h),s=a.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"cursor\",\"move\").attr(\"stroke-opacity\",0).attr(\"fill\",function(t){return t.color}).attr(\"fill-opacity\",0);a.attr(\"fill\",function(t){return t.color}).attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}).attr(\"y\",function(t){return t.y}),_(s),a.each(function(){o.raiseToTop(this)}),a.exit().remove()}function I(t,e,r,i,a){var o,s,l=[],c=[];for(s=0;s<r.length-1;s++)o=n.interpolateNumber(r[s]+t[s],t[s+1]),l.push(o(a)),c.push(o(1-a));var u=\"M \"+t[0]+\",\"+e[0];for(u+=\"l\"+r[0]+\",0 \",s=1;s<r.length;s++)u+=\"C\"+l[s-1]+\",\"+e[s-1]+\" \"+c[s-1]+\",\"+e[s]+\" \"+t[s]+\",\"+e[s],u+=\"l\"+r[s]+\",0 \";for(u+=\"l0,\"+i+\" \",u+=\"l -\"+r[r.length-1]+\",0 \",s=r.length-2;s>=0;s--)u+=\"C\"+c[s]+\",\"+(e[s+1]+i)+\" \"+l[s]+\",\"+(e[s]+i)+\" \"+(t[s]+r[s])+\",\"+(e[s]+i),u+=\"l-\"+r[s]+\",0 \";return u+=\"Z\"}function D(t){var e=t.dimensions,r=t.model,n=e.map(function(t){return t.categories.map(function(t){return t.y})}),i=t.model.dimensions.map(function(t){return t.categories.map(function(t){return t.displayInd})}),a=t.model.dimensions.map(function(t){return t.displayInd}),o=t.dimensions.map(function(t){return t.model.dimensionInd}),s=e.map(function(t){return t.x}),l=e.map(function(t){return t.width}),c=[];for(var u in r.paths)r.paths.hasOwnProperty(u)&&c.push(r.paths[u]);function h(t){var e=t.categoryInds.map(function(t,e){return i[e][t]});return o.map(function(t){return e[t]})}c.sort(function(e,r){var n=h(e),i=h(r);return\"backward\"===t.sortpaths&&(n.reverse(),i.reverse()),n.push(e.valueInds[0]),i.push(r.valueInds[0]),t.bundlecolors&&(n.unshift(e.rawColor),i.unshift(r.rawColor)),n<i?-1:n>i?1:0});for(var f=new Array(c.length),p=e[0].model.count,d=e[0].categories.map(function(t){return t.height}).reduce(function(t,e){return t+e}),g=0;g<c.length;g++){var v,m=c[g];v=p>0?d*(m.count/p):0;for(var y,x=new Array(n.length),b=0;b<m.categoryInds.length;b++){var _=m.categoryInds[b],w=i[b][_],k=a[b];x[k]=n[k][w],n[k][w]+=v;var T=t.dimensions[k].categories[w],A=T.bands.length,M=T.bands[A-1];if(void 0===M||m.rawColor!==M.rawColor){var S=void 0===M?0:M.y+M.height;T.bands.push({key:S,color:m.color,rawColor:m.rawColor,height:v,width:T.width,count:m.count,y:S,categoryViewModel:T,parcatsViewModel:t})}else{var E=T.bands[A-1];E.height+=v,E.count+=m.count}}y=\"hspline\"===t.pathShape?I(s,x,l,v,.5):I(s,x,l,v,0),f[g]={key:m.valueInds[0],model:m,height:v,leftXs:s,topYs:x,dimWidths:l,svgD:y,parcatsViewModel:t}}t.paths=f}function R(t){var e=t.model.dimensions.map(function(t){return{displayInd:t.displayInd,dimensionInd:t.dimensionInd}});e.sort(function(t,e){return t.displayInd-e.displayInd});var r=[];for(var n in e){var i=e[n].dimensionInd,a=t.model.dimensions[i];r.push(F(t,a))}t.dimensions=r}function F(t,e){var r,n=t.model.dimensions.length,i=e.displayInd;r=40+(n>1?(t.width-80-16)/(n-1):0)*i;var a,o,s,l,c,u=[],h=t.model.maxCats,f=e.categories.length,p=e.count,d=t.height-8*(h-1),g=8*(h-f)/2,v=e.categories.map(function(t){return{displayInd:t.displayInd,categoryInd:t.categoryInd}});for(v.sort(function(t,e){return t.displayInd-e.displayInd}),c=0;c<f;c++)l=v[c].categoryInd,o=e.categories[l],a=p>0?o.count/p*d:0,s={key:o.valueInds[0],model:o,width:16,height:a,y:null!==o.dragY?o.dragY:g,bands:[],parcatsViewModel:t},g=g+a+8,u.push(s);return{key:e.dimensionInd,x:null!==e.dragX?e.dragX:r,y:0,width:16,model:e,categories:u,parcatsViewModel:t,dragCategoryDisplayInd:null,dragDimensionDisplayInd:null,initialDragDimensionDisplayInds:null,initialDragCategoryDisplayInds:null,dragHasMoved:null,potentialClickBand:null}}e.exports=function(t,e,r,n){u(r,t,n,e)}},{\"../../components/drawing\":614,\"../../components/fx\":632,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"../../plot_api/plot_api\":754,d3:163,tinycolor2:537}],1073:[function(t,e,r){\"use strict\";var n=t(\"./parcats\");e.exports=function(t,e,r,i){var a=t._fullLayout,o=a._paper,s=a._size;n(t,o,e,{width:s.w,height:s.h,margin:{t:s.t,r:s.r,b:s.b,l:s.l}},r,i)}},{\"./parcats\":1072}],1074:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/cartesian/layout_attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../plots/domain\").attributes,s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/plot_template\").templatedArray;e.exports={domain:o({name:\"parcoords\",trace:!0,editType:\"plot\"}),labelangle:{valType:\"angle\",dflt:0,editType:\"plot\"},labelside:{valType:\"enumerated\",values:[\"top\",\"bottom\"],dflt:\"top\",editType:\"plot\"},labelfont:a({editType:\"plot\"}),tickfont:a({editType:\"plot\"}),rangefont:a({editType:\"plot\"}),dimensions:l(\"dimension\",{label:{valType:\"string\",editType:\"plot\"},tickvals:s({},i.tickvals,{editType:\"plot\"}),ticktext:s({},i.ticktext,{editType:\"plot\"}),tickformat:s({},i.tickformat,{editType:\"plot\"}),visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},constraintrange:{valType:\"info_array\",freeLength:!0,dimensions:\"1-2\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},multiselect:{valType:\"boolean\",dflt:!0,editType:\"plot\"},values:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"}),line:s({editType:\"calc\"},n(\"line\",{colorscaleDflt:\"Viridis\",autoColorDflt:!1,editTypeOverride:\"calc\"}))}},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/layout_attributes\":779,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1075:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\").keyFun,o=t(\"../../lib/gup\").repeat,s=t(\"../../lib\").sorterAsc,l=n.bar.snapRatio;function c(t,e){return t*(1-l)+e*l}var u=n.bar.snapClose;function h(t,e){return t*(1-u)+e*u}function f(t,e,r,n){if(function(t,e){for(var r=0;r<e.length;r++)if(t>=e[r][0]&&t<=e[r][1])return!0;return!1}(r,n))return r;var i=t?-1:1,a=0,o=e.length-1;if(i<0){var s=a;a=o,o=s}for(var l=e[a],u=l,f=a;i*f<i*o;f+=i){var p=f+i,d=e[p];if(i*r<i*h(l,d))return c(l,u);if(i*r<i*d||p===o)return c(d,l);u=l,l=d}}function p(t){t.attr(\"x\",-n.bar.captureWidth/2).attr(\"width\",n.bar.captureWidth)}function d(t){t.attr(\"visibility\",\"visible\").style(\"visibility\",\"visible\").attr(\"fill\",\"yellow\").attr(\"opacity\",0)}function g(t){if(!t.brush.filterSpecified)return\"0,\"+t.height;for(var e,r,n,i=v(t.brush.filter.getConsolidated(),t.height),a=[0],o=i.length?i[0][0]:null,s=0;s<i.length;s++)r=(e=i[s])[1]-e[0],a.push(o),a.push(r),(n=s+1)<i.length&&(o=i[n][0]-e[1]);return a.push(t.height),a}function v(t,e){return t.map(function(t){return t.map(function(t){return Math.max(0,t*e)}).sort(s)})}function m(){i.select(document.body).style(\"cursor\",null)}function y(t){t.attr(\"stroke-dasharray\",g)}function x(t,e){var r=i.select(t).selectAll(\".highlight, .highlight-shadow\");y(e?r.transition().duration(n.bar.snapDuration).each(\"end\",e):r)}function b(t,e){var r,i=t.brush,a=NaN,o={};if(i.filterSpecified){var s=t.height,l=i.filter.getConsolidated(),c=v(l,s),u=NaN,h=NaN,f=NaN;for(r=0;r<=c.length;r++){var p=c[r];if(p&&p[0]<=e&&e<=p[1]){u=r;break}if(h=r?r-1:NaN,p&&p[0]>e){f=r;break}}if(a=u,isNaN(a)&&(a=isNaN(h)||isNaN(f)?isNaN(h)?f:h:e-c[h][1]<c[f][0]-e?h:f),!isNaN(a)){var d=c[a],g=function(t,e){var r=n.bar.handleHeight;if(!(e>t[1]+r||e<t[0]-r))return e>=.9*t[1]+.1*t[0]?\"n\":e<=.9*t[0]+.1*t[1]?\"s\":\"ns\"}(d,e);g&&(o.interval=l[a],o.intervalPix=d,o.region=g)}}if(t.ordinal&&!o.region){var m=t.unitTickvals,y=t.unitToPaddedPx.invert(e);for(r=0;r<m.length;r++){var x=[.25*m[Math.max(r-1,0)]+.75*m[r],.25*m[Math.min(r+1,m.length-1)]+.75*m[r]];if(y>=x[0]&&y<=x[1]){o.clickableOrdinalRange=x;break}}}return o}function _(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.brush.svgBrush;a.wasDragged=!0,a._dragging=!0,a.grabbingBar?a.newExtent=[r-a.grabPoint,r+a.barLength-a.grabPoint].map(e.unitToPaddedPx.invert):a.newExtent=[a.startExtent,e.unitToPaddedPx.invert(r)].sort(s),e.brush.filterSpecified=!0,a.extent=a.stayingIntervals.concat([a.newExtent]),a.brushCallback(e),x(t.parentNode)}function w(t,e){var r=b(e,e.height-i.mouse(t)[1]-2*n.verticalPadding),a=\"crosshair\";r.clickableOrdinalRange?a=\"pointer\":r.region&&(a=r.region+\"-resize\"),i.select(document.body).style(\"cursor\",a)}function k(t){t.on(\"mousemove\",function(t){i.event.preventDefault(),t.parent.inBrushDrag||w(this,t)}).on(\"mouseleave\",function(t){t.parent.inBrushDrag||m()}).call(i.behavior.drag().on(\"dragstart\",function(t){!function(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.unitToPaddedPx.invert(r),o=e.brush,s=b(e,r),l=s.interval,c=o.svgBrush;if(c.wasDragged=!1,c.grabbingBar=\"ns\"===s.region,c.grabbingBar){var u=l.map(e.unitToPaddedPx);c.grabPoint=r-u[0]-n.verticalPadding,c.barLength=u[1]-u[0]}c.clickableOrdinalRange=s.clickableOrdinalRange,c.stayingIntervals=e.multiselect&&o.filterSpecified?o.filter.getConsolidated():[],l&&(c.stayingIntervals=c.stayingIntervals.filter(function(t){return t[0]!==l[0]&&t[1]!==l[1]})),c.startExtent=s.region?l[\"s\"===s.region?1:0]:a,e.parent.inBrushDrag=!0,c.brushStartCallback()}(this,t)}).on(\"drag\",function(t){_(this,t)}).on(\"dragend\",function(t){!function(t,e){var r=e.brush,n=r.filter,a=r.svgBrush;a._dragging||(w(t,e),_(t,e),e.brush.svgBrush.wasDragged=!1),a._dragging=!1,i.event.sourceEvent.stopPropagation();var o=a.grabbingBar;if(a.grabbingBar=!1,a.grabLocation=void 0,e.parent.inBrushDrag=!1,m(),!a.wasDragged)return a.wasDragged=void 0,a.clickableOrdinalRange?r.filterSpecified&&e.multiselect?a.extent.push(a.clickableOrdinalRange):(a.extent=[a.clickableOrdinalRange],r.filterSpecified=!0):o?(a.extent=a.stayingIntervals,0===a.extent.length&&A(r)):A(r),a.brushCallback(e),x(t.parentNode),void a.brushEndCallback(r.filterSpecified?n.getConsolidated():[]);var s=function(){n.set(n.getConsolidated())};if(e.ordinal){var l=e.unitTickvals;l[l.length-1]<l[0]&&l.reverse(),a.newExtent=[f(0,l,a.newExtent[0],a.stayingIntervals),f(1,l,a.newExtent[1],a.stayingIntervals)];var c=a.newExtent[1]>a.newExtent[0];a.extent=a.stayingIntervals.concat(c?[a.newExtent]:[]),a.extent.length||A(r),a.brushCallback(e),c?x(t.parentNode,s):(s(),x(t.parentNode))}else s();a.brushEndCallback(r.filterSpecified?n.getConsolidated():[])}(this,t)}))}function T(t,e){return t[0]-e[0]}function A(t){t.filterSpecified=!1,t.svgBrush.extent=[[-1/0,1/0]]}function M(t){for(var e,r=t.slice(),n=[],i=r.shift();i;){for(e=i.slice();(i=r.shift())&&i[0]<=e[1];)e[1]=Math.max(e[1],i[1]);n.push(e)}return n}e.exports={makeBrush:function(t,e,r,n,i,a){var o,l=function(){var t,e,r=[];return{set:function(n){1===(r=n.map(function(t){return t.slice().sort(s)}).sort(T)).length&&r[0][0]===-1/0&&r[0][1]===1/0&&(r=[[0,-1]]),t=M(r),e=r.reduce(function(t,e){return[Math.min(t[0],e[0]),Math.max(t[1],e[1])]},[1/0,-1/0])},get:function(){return r.slice()},getConsolidated:function(){return t},getBounds:function(){return e}}}();return l.set(r),{filter:l,filterSpecified:e,svgBrush:{extent:[],brushStartCallback:n,brushCallback:(o=i,function(t){var e=t.brush,r=function(t){return t.svgBrush.extent.map(function(t){return t.slice()})}(e).slice();e.filter.set(r),o()}),brushEndCallback:a}}},ensureAxisBrush:function(t){var e=t.selectAll(\".\"+n.cn.axisBrush).data(o,a);e.enter().append(\"g\").classed(n.cn.axisBrush,!0),function(t){var e=t.selectAll(\".background\").data(o);e.enter().append(\"rect\").classed(\"background\",!0).call(p).call(d).style(\"pointer-events\",\"auto\").attr(\"transform\",\"translate(0 \"+n.verticalPadding+\")\"),e.call(k).attr(\"height\",function(t){return t.height-n.verticalPadding});var r=t.selectAll(\".highlight-shadow\").data(o);r.enter().append(\"line\").classed(\"highlight-shadow\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width+n.bar.strokeWidth).attr(\"stroke\",n.bar.strokeColor).attr(\"opacity\",n.bar.strokeOpacity).attr(\"stroke-linecap\",\"butt\"),r.attr(\"y1\",function(t){return t.height}).call(y);var i=t.selectAll(\".highlight\").data(o);i.enter().append(\"line\").classed(\"highlight\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width-n.bar.strokeWidth).attr(\"stroke\",n.bar.fillColor).attr(\"opacity\",n.bar.fillOpacity).attr(\"stroke-linecap\",\"butt\"),i.attr(\"y1\",function(t){return t.height}).call(y)}(e)},cleanRanges:function(t,e){if(Array.isArray(t[0])?(t=t.map(function(t){return t.sort(s)}),t=e.multiselect?M(t.sort(T)):[t[0]]):t=[t.sort(s)],e.tickvals){var r=e.tickvals.slice().sort(s);if(!(t=t.map(function(t){var e=[f(0,r,t[0],[]),f(1,r,t[1],[])];if(e[1]>e[0])return e}).filter(function(t){return t})).length)return}return t.length>1?t:t[0]}}},{\"../../lib\":719,\"../../lib/gup\":717,\"./constants\":1078,d3:163}],1076:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../constants/xmlns_namespaces\");r.name=\"parcoords\",r.plot=function(t){var e=i(t.calcdata,\"parcoords\")[0];e.length&&a(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcoords\"),a=e._has&&e._has(\"parcoords\");i&&!a&&(n._paperdiv.selectAll(\".parcoords\").remove(),n._glimages.selectAll(\"*\").remove())},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter(function(t,e){return e===r.size()-1}).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each(function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})}),window.setTimeout(function(){n.selectAll(\"#filterBarPattern\").attr(\"id\",\"filterBarPattern\")},60)}},{\"../../constants/xmlns_namespaces\":696,\"../../plots/get_data\":802,\"./plot\":1085,d3:163}],1077:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale\"),a=t(\"../../lib/gup\").wrap;e.exports=function(t,e){var r,o;return i.hasColorscale(e,\"line\")&&n(e.line.color)?(r=e.line.color,o=i.extractOpts(e.line).colorscale,i.calc(t,e,{vals:r,containerStr:\"line\",cLetter:\"c\"})):(r=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=.5;return e}(e._length),o=[[0,e.line.color],[1,e.line.color]]),a({lineColor:r,cscale:o})}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gup\":717}],1078:[function(t,e,r){\"use strict\";e.exports={maxDimensionCount:60,overdrag:45,verticalPadding:2,tickDistance:50,canvasPixelRatio:1,blockLineCount:5e3,layers:[\"contextLineLayer\",\"focusLineLayer\",\"pickLineLayer\"],axisTitleOffset:28,axisExtentOffset:10,deselectedLineColor:\"#777\",bar:{width:4,captureWidth:10,fillColor:\"magenta\",fillOpacity:1,snapDuration:150,snapRatio:.25,snapClose:.01,strokeColor:\"white\",strokeOpacity:1,strokeWidth:1,handleHeight:8,handleOpacity:1,handleOverlap:0},cn:{axisExtentText:\"axis-extent-text\",parcoordsLineLayers:\"parcoords-line-layers\",parcoordsLineLayer:\"parcoords-lines\",parcoords:\"parcoords\",parcoordsControlView:\"parcoords-control-view\",yAxis:\"y-axis\",axisOverlays:\"axis-overlays\",axis:\"axis\",axisHeading:\"axis-heading\",axisTitle:\"axis-title\",axisExtent:\"axis-extent\",axisExtentTop:\"axis-extent-top\",axisExtentTopText:\"axis-extent-top-text\",axisExtentBottom:\"axis-extent-bottom\",axisExtentBottomText:\"axis-extent-bottom-text\",axisBrush:\"axis-brush\"},id:{filterBarPattern:\"filter-bar-pattern\"}}},{}],1079:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"../../plots/cartesian/axes\"),c=t(\"./attributes\"),u=t(\"./axisbrush\"),h=t(\"./constants\").maxDimensionCount,f=t(\"./merge_length\");function p(t,e,r,i){function a(r,i){return n.coerce(t,e,c.dimensions,r,i)}var o=a(\"values\"),s=a(\"visible\");if(o&&o.length||(s=e.visible=!1),s){a(\"label\"),a(\"tickvals\"),a(\"ticktext\"),a(\"tickformat\");var h=a(\"range\");e._ax={_id:\"y\",type:\"linear\",showexponent:\"all\",exponentformat:\"B\",range:h},l.setConvert(e._ax,i.layout),a(\"multiselect\");var f=a(\"constraintrange\");f&&(e.constraintrange=u.cleanRanges(f,e))}}e.exports=function(t,e,r,l){function u(r,i){return n.coerce(t,e,c,r,i)}var d=t.dimensions;Array.isArray(d)&&d.length>h&&(n.log(\"parcoords traces support up to \"+h+\" dimensions at the moment\"),d.splice(h));var g=s(t,e,{name:\"dimensions\",layout:l,handleItemDefaults:p}),v=function(t,e,r,o,s){var l=s(\"line.color\",r);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,l,u);o(e,l,u),Array.isArray(g)&&g.length||(e.visible=!1),f(e,g,\"values\",v);var m={family:l.font.family,size:Math.round(l.font.size/1.2),color:l.font.color};n.coerceFont(u,\"labelfont\",m),n.coerceFont(u,\"tickfont\",m),n.coerceFont(u,\"rangefont\",m),u(\"labelangle\"),u(\"labelside\")}},{\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../../plots/cartesian/axes\":767,\"../../plots/domain\":792,\"./attributes\":1074,\"./axisbrush\":1075,\"./constants\":1078,\"./merge_length\":1083}],1080:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isTypedArray;r.convertTypedArray=function(t){return n(t)?Array.prototype.slice.call(t):t},r.isOrdinal=function(t){return!!t.tickvals},r.isVisible=function(t){return t.visible||!(\"visible\"in t)}},{\"../../lib\":719}],1081:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcoords\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"noOpacity\",\"noHover\"],meta:{}}},{\"./attributes\":1074,\"./base_plot\":1076,\"./calc\":1077,\"./defaults\":1079,\"./plot\":1085}],1082:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nattribute vec4 p01_04, p05_08, p09_12, p13_16,\\n               p17_20, p21_24, p25_28, p29_32,\\n               p33_36, p37_40, p41_44, p45_48,\\n               p49_52, p53_56, p57_60, colors;\\n\\nuniform mat4 dim0A, dim1A, dim0B, dim1B, dim0C, dim1C, dim0D, dim1D,\\n             loA, hiA, loB, hiB, loC, hiC, loD, hiD;\\n\\nuniform vec2 resolution, viewBoxPos, viewBoxSize;\\nuniform sampler2D mask, palette;\\nuniform float maskHeight;\\nuniform float drwLayer; // 0: context, 1: focus, 2: pick\\nuniform vec4 contextColor;\\n\\nbool isPick    = (drwLayer > 1.5);\\nbool isContext = (drwLayer < 0.5);\\n\\nconst vec4 ZEROS = vec4(0.0, 0.0, 0.0, 0.0);\\nconst vec4 UNITS = vec4(1.0, 1.0, 1.0, 1.0);\\n\\nfloat val(mat4 p, mat4 v) {\\n    return dot(matrixCompMult(p, v) * UNITS, UNITS);\\n}\\n\\nfloat axisY(float ratio, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float y1 = val(A, dim0A) + val(B, dim0B) + val(C, dim0C) + val(D, dim0D);\\n    float y2 = val(A, dim1A) + val(B, dim1B) + val(C, dim1C) + val(D, dim1D);\\n    return y1 * (1.0 - ratio) + y2 * ratio;\\n}\\n\\nint iMod(int a, int b) {\\n    return a - b * (a / b);\\n}\\n\\nbool fOutside(float p, float lo, float hi) {\\n    return (lo < hi) && (lo > p || p > hi);\\n}\\n\\nbool vOutside(vec4 p, vec4 lo, vec4 hi) {\\n    return (\\n        fOutside(p[0], lo[0], hi[0]) ||\\n        fOutside(p[1], lo[1], hi[1]) ||\\n        fOutside(p[2], lo[2], hi[2]) ||\\n        fOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool mOutside(mat4 p, mat4 lo, mat4 hi) {\\n    return (\\n        vOutside(p[0], lo[0], hi[0]) ||\\n        vOutside(p[1], lo[1], hi[1]) ||\\n        vOutside(p[2], lo[2], hi[2]) ||\\n        vOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool outsideBoundingBox(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    return mOutside(A, loA, hiA) ||\\n           mOutside(B, loB, hiB) ||\\n           mOutside(C, loC, hiC) ||\\n           mOutside(D, loD, hiD);\\n}\\n\\nbool outsideRasterMask(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    mat4 pnts[4];\\n    pnts[0] = A;\\n    pnts[1] = B;\\n    pnts[2] = C;\\n    pnts[3] = D;\\n\\n    for(int i = 0; i < 4; ++i) {\\n        for(int j = 0; j < 4; ++j) {\\n            for(int k = 0; k < 4; ++k) {\\n                if(0 == iMod(\\n                    int(255.0 * texture2D(mask,\\n                        vec2(\\n                            (float(i * 2 + j / 2) + 0.5) / 8.0,\\n                            (pnts[i][j][k] * (maskHeight - 1.0) + 1.0) / maskHeight\\n                        ))[3]\\n                    ) / int(pow(2.0, float(iMod(j * 4 + k, 8)))),\\n                    2\\n                )) return true;\\n            }\\n        }\\n    }\\n    return false;\\n}\\n\\nvec4 position(bool isContext, float v, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float x = 0.5 * sign(v) + 0.5;\\n    float y = axisY(x, A, B, C, D);\\n    float z = 1.0 - abs(v);\\n\\n    z += isContext ? 0.0 : 2.0 * float(\\n        outsideBoundingBox(A, B, C, D) ||\\n        outsideRasterMask(A, B, C, D)\\n    );\\n\\n    return vec4(\\n        2.0 * (vec2(x, y) * viewBoxSize + viewBoxPos) / resolution - 1.0,\\n        z,\\n        1.0\\n    );\\n}\\n\\nvoid main() {\\n    mat4 A = mat4(p01_04, p05_08, p09_12, p13_16);\\n    mat4 B = mat4(p17_20, p21_24, p25_28, p29_32);\\n    mat4 C = mat4(p33_36, p37_40, p41_44, p45_48);\\n    mat4 D = mat4(p49_52, p53_56, p57_60, ZEROS);\\n\\n    float v = colors[3];\\n\\n    gl_Position = position(isContext, v, A, B, C, D);\\n\\n    fragColor =\\n        isContext ? vec4(contextColor) :\\n        isPick ? vec4(colors.rgb, 1.0) : texture2D(palette, vec2(abs(v), 0.5));\\n}\\n\"]),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n    gl_FragColor = fragColor;\\n}\\n\"]),o=t(\"./constants\").maxDimensionCount,s=t(\"../../lib\"),l=1e-6,c=2048,u=new Uint8Array(4),h=new Uint8Array(4),f={shape:[256,1],format:\"rgba\",type:\"uint8\",mag:\"nearest\",min:\"nearest\"};function p(t,e,r,n,i){var a=t._gl;a.enable(a.SCISSOR_TEST),a.scissor(e,r,n,i),t.clear({color:[0,0,0,0],depth:1})}function d(t,e,r,n,i,a){var o=a.key;r.drawCompleted||(!function(t){t.read({x:0,y:0,width:1,height:1,data:u})}(t),r.drawCompleted=!0),function s(l){var c=Math.min(n,i-l*n);0===l&&(window.cancelAnimationFrame(r.currentRafs[o]),delete r.currentRafs[o],p(t,a.scissorX,a.scissorY,a.scissorWidth,a.viewBoxSize[1])),r.clearOnly||(a.count=2*c,a.offset=2*l*n,e(a),l*n+c<i&&(r.currentRafs[o]=window.requestAnimationFrame(function(){s(l+1)})),r.drawCompleted=!1)}(0)}function g(t,e){return(t>>>8*e)%256/255}function v(t,e,r){for(var n=new Array(8*e),i=0,a=0;a<e;a++)for(var o=0;o<2;o++)for(var s=0;s<4;s++){var l=4*t+s,c=r[64*a+l];63===l&&0===o&&(c*=-1),n[i++]=c}return n}function m(t){var e=\"0\"+t;return e.substr(e.length-2)}function y(t){return t<o?\"p\"+m(t+1)+\"_\"+m(t+4):\"colors\"}function x(t,e,r,n,i,a,o,l,c,u,h,f,p){for(var d=[[],[]],g=0;g<64;g++)d[0][g]=g===i?1:0,d[1][g]=g===a?1:0;var v=t.lines.canvasOverdrag,m=t.domain,y=t.canvasWidth,x=t.canvasHeight,b=t.deselectedLines.color;return s.extendFlat({key:h,resolution:[y,x],viewBoxPos:[o+v,l],viewBoxSize:[c,u],i0:i,i1:a,dim0A:d[0].slice(0,16),dim0B:d[0].slice(16,32),dim0C:d[0].slice(32,48),dim0D:d[0].slice(48,64),dim1A:d[1].slice(0,16),dim1B:d[1].slice(16,32),dim1C:d[1].slice(32,48),dim1D:d[1].slice(48,64),drwLayer:f,contextColor:[b[0]/255,b[1]/255,b[2]/255,b[3]<1?b[3]:Math.max(1/255,Math.pow(1/t.lines.color.length,1/3))],scissorX:(n===e?0:o+v)+(t.pad.l-v)+t.layoutWidth*m.x[0],scissorWidth:(n===r?y-o+v:c+.5)+(n===e?o+v:0),scissorY:l+t.pad.b+t.layoutHeight*m.y[0],scissorHeight:u,viewportX:t.pad.l-v+t.layoutWidth*m.x[0],viewportY:t.pad.b+t.layoutHeight*m.y[0],viewportWidth:y,viewportHeight:x},p)}function b(t){var e=c-1,r=Math.max(0,Math.floor(t[0]*e),0),n=Math.min(e,Math.ceil(t[1]*e),e);return[Math.min(r,n),Math.max(r,n)]}e.exports=function(t,e){var r,n,u,m,_,w=e.context,k=e.pick,T=e.regl,A={currentRafs:{},drawCompleted:!0,clearOnly:!1},M=function(t){for(var e={},r=0;r<=o;r+=4)e[y(r)]=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)});return e}(T),S=T.texture(f),E=[];L(e);var C=T({profile:!1,blend:{enable:w,func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:1,dstAlpha:1},equation:{rgb:\"add\",alpha:\"add\"},color:[0,0,0,0]},depth:{enable:!w,mask:!0,func:\"less\",range:[0,1]},cull:{enable:!0,face:\"back\"},scissor:{enable:!0,box:{x:T.prop(\"scissorX\"),y:T.prop(\"scissorY\"),width:T.prop(\"scissorWidth\"),height:T.prop(\"scissorHeight\")}},viewport:{x:T.prop(\"viewportX\"),y:T.prop(\"viewportY\"),width:T.prop(\"viewportWidth\"),height:T.prop(\"viewportHeight\")},dither:!1,vert:i,frag:a,primitive:\"lines\",lineWidth:1,attributes:M,uniforms:{resolution:T.prop(\"resolution\"),viewBoxPos:T.prop(\"viewBoxPos\"),viewBoxSize:T.prop(\"viewBoxSize\"),dim0A:T.prop(\"dim0A\"),dim1A:T.prop(\"dim1A\"),dim0B:T.prop(\"dim0B\"),dim1B:T.prop(\"dim1B\"),dim0C:T.prop(\"dim0C\"),dim1C:T.prop(\"dim1C\"),dim0D:T.prop(\"dim0D\"),dim1D:T.prop(\"dim1D\"),loA:T.prop(\"loA\"),hiA:T.prop(\"hiA\"),loB:T.prop(\"loB\"),hiB:T.prop(\"hiB\"),loC:T.prop(\"loC\"),hiC:T.prop(\"hiC\"),loD:T.prop(\"loD\"),hiD:T.prop(\"hiD\"),palette:S,contextColor:T.prop(\"contextColor\"),mask:T.prop(\"maskTexture\"),drwLayer:T.prop(\"drwLayer\"),maskHeight:T.prop(\"maskHeight\")},offset:T.prop(\"offset\"),count:T.prop(\"count\")});function L(t){r=t.model,n=t.viewModel,u=n.dimensions.slice(),m=u[0]?u[0].values.length:0;var e=r.lines,i=k?e.color.map(function(t,r){return r/e.color.length}):e.color,a=function(t,e,r){for(var n,i=new Array(t*(o+4)),a=0,s=0;s<t;s++){for(var c=0;c<o;c++)i[a++]=c<e.length?e[c].paddedUnitValues[s]:.5;i[a++]=g(s,2),i[a++]=g(s,1),i[a++]=g(s,0),i[a++]=(n=r[s],Math.max(l,Math.min(1-l,n)))}return i}(m,u,i);!function(t,e,r){for(var n=0;n<=o;n+=4)t[y(n)](v(n/4,e,r))}(M,m,a),w||k||(S=T.texture(s.extendFlat({data:function(t,e){for(var r=new Array(256),n=0;n<256;n++)r[n]=t(n/255).concat(e);return r}(r.unitToColor,255)},f)))}return{render:function(t,e,n){var i,a,o,s=t.length,l=1/0,h=-1/0;for(i=0;i<s;i++)t[i].dim0.canvasX<l&&(l=t[i].dim0.canvasX,a=i),t[i].dim1.canvasX>h&&(h=t[i].dim1.canvasX,o=i);0===s&&p(T,0,0,r.canvasWidth,r.canvasHeight);var f=function(t){var e,r,n,i=[[],[]];for(n=0;n<64;n++){var a=!t&&n<u.length?u[n].brush.filter.getBounds():[-1/0,1/0];i[0][n]=a[0],i[1][n]=a[1]}var o=8*c,s=new Array(o);for(e=0;e<o;e++)s[e]=255;if(!t)for(e=0;e<u.length;e++){var l=e%8,h=(e-l)/8,f=Math.pow(2,l),p=u[e].brush.filter.get();if(!(p.length<2)){var d=b(p[0])[1];for(r=1;r<p.length;r++){var g=b(p[r]);for(n=d+1;n<g[0];n++)s[8*n+h]&=~f;d=Math.max(d,g[1])}}}var v={shape:[8,c],format:\"alpha\",type:\"uint8\",mag:\"nearest\",min:\"nearest\",data:s};return _?_(v):_=T.texture(v),{maskTexture:_,maskHeight:c,loA:i[0].slice(0,16),loB:i[0].slice(16,32),loC:i[0].slice(32,48),loD:i[0].slice(48,64),hiA:i[1].slice(0,16),hiB:i[1].slice(16,32),hiC:i[1].slice(32,48),hiD:i[1].slice(48,64)}}(w);for(i=0;i<s;i++){var g=t[i],v=g.dim0.crossfilterDimensionIndex,y=g.dim1.crossfilterDimensionIndex,M=g.canvasX,S=g.canvasY,L=M+g.panelSizeX;if(e||!E[v]||E[v][0]!==M||E[v][1]!==L){E[v]=[M,L];var P=x(r,a,o,i,v,y,M,S,g.panelSizeX,g.panelSizeY,g.dim0.crossfilterDimensionIndex,w?0:k?2:1,f);A.clearOnly=n;var O=e?r.lines.blockLineCount:m;d(T,C,A,O,m,P)}}},readPixel:function(t,e){return T.read({x:t,y:e,width:1,height:1,data:h}),h},readPixels:function(t,e,r,n){var i=new Uint8Array(4*r*n);return T.read({x:t,y:e,width:r,height:n,data:i}),i},destroy:function(){for(var e in t.style[\"pointer-events\"]=\"none\",S.destroy(),_&&_.destroy(),M)M[e].destroy()},update:L}}},{\"../../lib\":719,\"./constants\":1078,glslify:409}],1083:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a;for(n||(n=1/0),i=0;i<e.length;i++)(a=e[i]).visible&&(n=Math.min(n,a[r].length));for(n===1/0&&(n=0),t._length=n,i=0;i<e.length;i++)(a=e[i]).visible&&(a._length=n);return n}},{}],1084:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"color-rgba\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../components/drawing\"),c=t(\"../../components/colorscale\"),u=t(\"../../lib/gup\"),h=u.keyFun,f=u.repeat,p=u.unwrap,d=t(\"./helpers\"),g=t(\"./constants\"),v=t(\"./axisbrush\"),m=t(\"./lines\");function y(t,e,r){return o.aggNums(t,null,e,r)}function x(t,e){return _(y(Math.min,t,e),y(Math.max,t,e))}function b(t){var e=t.range;return e?_(e[0],e[1]):x(t.values,t._length)}function _(t,e){return!isNaN(t)&&isFinite(t)||(t=0),!isNaN(e)&&isFinite(e)||(e=0),t===e&&(0===t?(t-=1,e+=1):(t*=.9,e*=1.1)),[t,e]}function w(t){return t.dimensions.some(function(t){return t.brush.filterSpecified})}function k(t,e,r){var a=p(e),s=a.trace,l=d.convertTypedArray(a.lineColor),u=s.line,h={color:i(g.deselectedLineColor)},f=c.extractOpts(u),v=f.reversescale?c.flipScale(a.cscale):a.cscale,m=s.domain,y=s.dimensions,x=t.width,_=s.labelangle,w=s.labelside,k=s.labelfont,T=s.tickfont,A=s.rangefont,M=o.extendDeepNoArrays({},u,{color:l.map(n.scale.linear().domain(b({values:l,range:[f.min,f.max],_length:s._length}))),blockLineCount:g.blockLineCount,canvasOverdrag:g.overdrag*g.canvasPixelRatio}),S=Math.floor(x*(m.x[1]-m.x[0])),E=Math.floor(t.height*(m.y[1]-m.y[0])),C=t.margin||{l:80,r:80,t:100,b:80},L=S,P=E;return{key:r,colCount:y.filter(d.isVisible).length,dimensions:y,tickDistance:g.tickDistance,unitToColor:function(t){var e=t.map(function(t){return t[0]}),r=t.map(function(t){var e=i(t[1]);return n.rgb(\"rgb(\"+e[0]+\",\"+e[1]+\",\"+e[2]+\")\")}),a=\"rgb\".split(\"\").map(function(t){return n.scale.linear().clamp(!0).domain(e).range(r.map((i=t,function(t){return t[i]})));var i});return function(t){return a.map(function(e){return e(t)})}}(v),lines:M,deselectedLines:h,labelAngle:_,labelSide:w,labelFont:k,tickFont:T,rangeFont:A,layoutWidth:x,layoutHeight:t.height,domain:m,translateX:m.x[0]*x,translateY:t.height-m.y[1]*t.height,pad:C,canvasWidth:L*g.canvasPixelRatio+2*M.canvasOverdrag,canvasHeight:P*g.canvasPixelRatio,width:L,height:P,canvasPixelRatio:g.canvasPixelRatio}}function T(t,e,r){var i=r.width,a=r.height,s=r.dimensions,l=r.canvasPixelRatio,c=function(t){return i*t/Math.max(1,r.colCount-1)},u=g.verticalPadding/a,h=function(t,e){return n.scale.linear().range([e,t-e])}(a,g.verticalPadding),f={key:r.key,xScale:c,model:r,inBrushDrag:!1},p={};return f.dimensions=s.filter(d.isVisible).map(function(i,s){var m=function(t,e){return n.scale.linear().domain(b(t)).range([e,1-e])}(i,u),y=p[i.label];p[i.label]=(y||0)+1;var x=i.label+(y?\"__\"+y:\"\"),_=i.constraintrange,k=_&&_.length;k&&!Array.isArray(_[0])&&(_=[_]);var T=k?_.map(function(t){return t.map(m)}):[[-1/0,1/0]],A=i.values;A.length>i._length&&(A=A.slice(0,i._length));var M,S=i.tickvals;function E(t,e){return{val:t,text:M[e]}}function C(t,e){return t.val-e.val}if(Array.isArray(S)&&S.length){M=i.ticktext,Array.isArray(M)&&M.length?M.length>S.length?M=M.slice(0,S.length):S.length>M.length&&(S=S.slice(0,M.length)):M=S.map(n.format(i.tickformat));for(var L=1;L<S.length;L++)if(S[L]<S[L-1]){for(var P=S.map(E).sort(C),O=0;O<S.length;O++)S[O]=P[O].val,M[O]=P[O].text;break}}else S=void 0;return A=d.convertTypedArray(A),A=d.convertTypedArray(A),{key:x,label:i.label,tickFormat:i.tickformat,tickvals:S,ticktext:M,ordinal:d.isOrdinal(i),multiselect:i.multiselect,xIndex:s,crossfilterDimensionIndex:s,visibleIndex:i._index,height:a,values:A,paddedUnitValues:A.map(m),unitTickvals:S&&S.map(m),xScale:c,x:c(s),canvasX:c(s)*l,unitToPaddedPx:h,domainScale:function(t,e,r,i,a){var o,s,l=b(r);return i?n.scale.ordinal().domain(i.map((o=n.format(r.tickformat),s=a,s?function(t,e){var r=s[e];return null==r?o(t):r}:o))).range(i.map(function(r){var n=(r-l[0])/(l[1]-l[0]);return t-e+n*(2*e-t)})):n.scale.linear().domain(l).range([t-e,e])}(a,g.verticalPadding,i,S,M),ordinalScale:function(t){if(t.tickvals){var e=b(t);return n.scale.ordinal().domain(t.tickvals).range(t.tickvals.map(function(t){return(t-e[0])/(e[1]-e[0])}))}}(i),parent:f,model:r,brush:v.makeBrush(t,k,T,function(){t.linePickActive(!1)},function(){var e=f;e.focusLayer&&e.focusLayer.render(e.panels,!0);var r=w(e);!t.contextShown()&&r?(e.contextLayer&&e.contextLayer.render(e.panels,!0),t.contextShown(!0)):t.contextShown()&&!r&&(e.contextLayer&&e.contextLayer.render(e.panels,!0,!0),t.contextShown(!1))},function(r){if(f.focusLayer.render(f.panels,!0),f.pickLayer&&f.pickLayer.render(f.panels,!0),t.linePickActive(!0),e&&e.filterChanged){var n=m.invert,a=r.map(function(t){return t.map(n).sort(o.sorterAsc)}).sort(function(t,e){return t[0]-e[0]});e.filterChanged(f.key,i._index,a)}})}}),f}function A(t){t.classed(g.cn.axisExtentText,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"default\").style(\"user-select\",\"none\")}function M(t,e){var r=\"top\"===e?1:-1,n=t*Math.PI/180;return{dir:r,dx:Math.sin(n),dy:Math.cos(n),degrees:t}}function S(t,e){for(var r=e.panels||(e.panels=[]),n=t.data(),i=0;i<n.length-1;i++){var a=r[i]||(r[i]={}),o=n[i],s=n[i+1];a.dim0=o,a.dim1=s,a.canvasX=o.canvasX,a.panelSizeX=s.canvasX-o.canvasX,a.panelSizeY=e.model.canvasHeight,a.y=0,a.canvasY=0}}function E(t,e){return a.tickText(t._ax,e,!1).text}function C(t,e){if(t.ordinal)return\"\";var r=t.domainScale.domain(),n=r[e?r.length-1:0];return E(t.model.dimensions[t.visibleIndex],n)}e.exports=function(t,e,r,i){var c=t._fullLayout,u=c._toppaper,y=c._glcontainer;!function(t){for(var e=0;e<t.length;e++)for(var r=0;r<t[e].length;r++)for(var n=t[e][r].trace,i=n.dimensions,o=0;o<i.length;o++){var s=i[o].values,l=i[o]._ax;l&&(l.range?l.range=_(l.range[0],l.range[1]):l.range=x(s,n._length),l.dtick||(l.dtick=.01*(Math.abs(l.range[1]-l.range[0])||1)),l.tickformat=i[o].tickformat,a.calcTicks(l),l.cleanRange())}}(e);var b,L,P=(b=!0,L=!1,{linePickActive:function(t){return arguments.length?b=!!t:b},contextShown:function(t){return arguments.length?L=!!t:L}}),O=e.filter(function(t){return p(t).trace.visible}).map(k.bind(0,r)).map(T.bind(0,P,i));y.each(function(t,e){return o.extendFlat(t,O[e])});var z=y.selectAll(\".gl-canvas\").each(function(t){t.viewModel=O[0],t.model=t.viewModel?t.viewModel.model:null}),I=null;z.filter(function(t){return t.pick}).style(\"pointer-events\",\"auto\").on(\"mousemove\",function(t){if(P.linePickActive()&&t.lineLayer&&i&&i.hover){var e=n.event,r=this.width,a=this.height,o=n.mouse(this),s=o[0],l=o[1];if(s<0||l<0||s>=r||l>=a)return;var c=t.lineLayer.readPixel(s,a-1-l),u=0!==c[3],h=u?c[2]+256*(c[1]+256*c[0]):null,f={x:s,y:l,clientX:e.clientX,clientY:e.clientY,dataIndex:t.model.key,curveNumber:h};h!==I&&(u?i.hover(f):i.unhover&&i.unhover(f),I=h)}}),z.style(\"opacity\",function(t){return t.pick?0:1}),u.style(\"background\",\"rgba(255, 255, 255, 0)\");var D=u.selectAll(\".\"+g.cn.parcoords).data(O,h);D.exit().remove(),D.enter().append(\"g\").classed(g.cn.parcoords,!0).style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"none\"),D.attr(\"transform\",function(t){return\"translate(\"+t.model.translateX+\",\"+t.model.translateY+\")\"});var R=D.selectAll(\".\"+g.cn.parcoordsControlView).data(f,h);R.enter().append(\"g\").classed(g.cn.parcoordsControlView,!0),R.attr(\"transform\",function(t){return\"translate(\"+t.model.pad.l+\",\"+t.model.pad.t+\")\"});var F=R.selectAll(\".\"+g.cn.yAxis).data(function(t){return t.dimensions},h);F.enter().append(\"g\").classed(g.cn.yAxis,!0),R.each(function(t){S(F,t)}),z.each(function(t){if(t.viewModel){!t.lineLayer||i?t.lineLayer=m(this,t):t.lineLayer.update(t),(t.key||0===t.key)&&(t.viewModel[t.key]=t.lineLayer);var e=!t.context||i;t.lineLayer.render(t.viewModel.panels,e)}}),F.attr(\"transform\",function(t){return\"translate(\"+t.xScale(t.xIndex)+\", 0)\"}),F.call(n.behavior.drag().origin(function(t){return t}).on(\"drag\",function(t){var e=t.parent;P.linePickActive(!1),t.x=Math.max(-g.overdrag,Math.min(t.model.width+g.overdrag,n.event.x)),t.canvasX=t.x*t.model.canvasPixelRatio,F.sort(function(t,e){return t.x-e.x}).each(function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e.xIndex),e.canvasX=e.x*e.model.canvasPixelRatio}),S(F,e),F.filter(function(e){return 0!==Math.abs(t.xIndex-e.xIndex)}).attr(\"transform\",function(t){return\"translate(\"+t.xScale(t.xIndex)+\", 0)\"}),n.select(this).attr(\"transform\",\"translate(\"+t.x+\", 0)\"),F.each(function(r,n,i){i===t.parent.key&&(e.dimensions[n]=r)}),e.contextLayer&&e.contextLayer.render(e.panels,!1,!w(e)),e.focusLayer.render&&e.focusLayer.render(e.panels)}).on(\"dragend\",function(t){var e=t.parent;t.x=t.xScale(t.xIndex),t.canvasX=t.x*t.model.canvasPixelRatio,S(F,e),n.select(this).attr(\"transform\",function(t){return\"translate(\"+t.x+\", 0)\"}),e.contextLayer&&e.contextLayer.render(e.panels,!1,!w(e)),e.focusLayer&&e.focusLayer.render(e.panels),e.pickLayer&&e.pickLayer.render(e.panels,!0),P.linePickActive(!0),i&&i.axesMoved&&i.axesMoved(e.key,e.dimensions.map(function(t){return t.crossfilterDimensionIndex}))})),F.exit().remove();var B=F.selectAll(\".\"+g.cn.axisOverlays).data(f,h);B.enter().append(\"g\").classed(g.cn.axisOverlays,!0),B.selectAll(\".\"+g.cn.axis).remove();var N=B.selectAll(\".\"+g.cn.axis).data(f,h);N.enter().append(\"g\").classed(g.cn.axis,!0),N.each(function(t){var e=t.model.height/t.model.tickDistance,r=t.domainScale,i=r.domain();n.select(this).call(n.svg.axis().orient(\"left\").tickSize(4).outerTickSize(2).ticks(e,t.tickFormat).tickValues(t.ordinal?i:null).tickFormat(function(e){return d.isOrdinal(t)?e:E(t.model.dimensions[t.visibleIndex],e)}).scale(r)),l.font(N.selectAll(\"text\"),t.model.tickFont)}),N.selectAll(\".domain, .tick>line\").attr(\"fill\",\"none\").attr(\"stroke\",\"black\").attr(\"stroke-opacity\",.25).attr(\"stroke-width\",\"1px\"),N.selectAll(\"text\").style(\"text-shadow\",\"1px 1px 1px #fff, -1px -1px 1px #fff, 1px -1px 1px #fff, -1px 1px 1px #fff\").style(\"cursor\",\"default\").style(\"user-select\",\"none\");var j=B.selectAll(\".\"+g.cn.axisHeading).data(f,h);j.enter().append(\"g\").classed(g.cn.axisHeading,!0);var U=j.selectAll(\".\"+g.cn.axisTitle).data(f,h);U.enter().append(\"text\").classed(g.cn.axisTitle,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"ew-resize\").style(\"user-select\",\"none\").style(\"pointer-events\",\"auto\"),U.text(function(t){return t.label}).each(function(e){var r=n.select(this);l.font(r,e.model.labelFont),s.convertToTspans(r,t)}).attr(\"transform\",function(t){var e=M(t.model.labelAngle,t.model.labelSide),r=g.axisTitleOffset;return(e.dir>0?\"\":\"translate(0,\"+(2*r+t.model.height)+\")\")+\"rotate(\"+e.degrees+\")translate(\"+-r*e.dx+\",\"+-r*e.dy+\")\"}).attr(\"text-anchor\",function(t){var e=M(t.model.labelAngle,t.model.labelSide);return 2*Math.abs(e.dx)>Math.abs(e.dy)?e.dir*e.dx<0?\"start\":\"end\":\"middle\"});var V=B.selectAll(\".\"+g.cn.axisExtent).data(f,h);V.enter().append(\"g\").classed(g.cn.axisExtent,!0);var q=V.selectAll(\".\"+g.cn.axisExtentTop).data(f,h);q.enter().append(\"g\").classed(g.cn.axisExtentTop,!0),q.attr(\"transform\",\"translate(0,\"+-g.axisExtentOffset+\")\");var H=q.selectAll(\".\"+g.cn.axisExtentTopText).data(f,h);H.enter().append(\"text\").classed(g.cn.axisExtentTopText,!0).call(A),H.text(function(t){return C(t,!0)}).each(function(t){l.font(n.select(this),t.model.rangeFont)});var G=V.selectAll(\".\"+g.cn.axisExtentBottom).data(f,h);G.enter().append(\"g\").classed(g.cn.axisExtentBottom,!0),G.attr(\"transform\",function(t){return\"translate(0,\"+(t.model.height+g.axisExtentOffset)+\")\"});var Y=G.selectAll(\".\"+g.cn.axisExtentBottomText).data(f,h);Y.enter().append(\"text\").classed(g.cn.axisExtentBottomText,!0).attr(\"dy\",\"0.75em\").call(A),Y.text(function(t){return C(t,!1)}).each(function(t){l.font(n.select(this),t.model.rangeFont)}),v.ensureAxisBrush(B)}},{\"../../components/colorscale\":605,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/gup\":717,\"../../lib/svg_text_utils\":743,\"../../plots/cartesian/axes\":767,\"./axisbrush\":1075,\"./constants\":1078,\"./helpers\":1080,\"./lines\":1082,\"color-rgba\":122,d3:163}],1085:[function(t,e,r){\"use strict\";var n=t(\"./parcoords\"),i=t(\"../../lib/prepare_regl\"),a=t(\"./helpers\").isVisible;function o(t,e,r){var n=e.indexOf(r),i=t.indexOf(n);return-1===i&&(i+=e.length),i}e.exports=function(t,e){var r=t._fullLayout;if(i(t)){var s={},l={},c={},u={},h=r._size;e.forEach(function(e,r){var n=e[0].trace;c[r]=n.index;var i=u[r]=n._fullInput.index;s[r]=t.data[i].dimensions,l[r]=t.data[i].dimensions.slice()});n(t,e,{width:h.w,height:h.h,margin:{t:h.t,r:h.r,b:h.b,l:h.l}},{filterChanged:function(e,n,i){var a=l[e][n],o=i.map(function(t){return t.slice()}),s=\"dimensions[\"+n+\"].constraintrange\",h=r._tracePreGUI[t._fullData[c[e]]._fullInput.uid];if(void 0===h[s]){var f=a.constraintrange;h[s]=f||null}var p=t._fullData[c[e]].dimensions[n];o.length?(1===o.length&&(o=o[0]),a.constraintrange=o,p.constraintrange=o.slice(),o=[o]):(delete a.constraintrange,delete p.constraintrange,o=null);var d={};d[s]=o,t.emit(\"plotly_restyle\",[d,[u[e]]])},hover:function(e){t.emit(\"plotly_hover\",e)},unhover:function(e){t.emit(\"plotly_unhover\",e)},axesMoved:function(e,r){var n=function(t,e){return function(r,n){return o(t,e,r)-o(t,e,n)}}(r,l[e].filter(a));s[e].sort(n),l[e].filter(function(t){return!a(t)}).sort(function(t){return l[e].indexOf(t)}).forEach(function(t){s[e].splice(s[e].indexOf(t),1),s[e].splice(l[e].indexOf(t),0,t)}),t.emit(\"plotly_restyle\",[{dimensions:[s[e]]},[u[e]]])}})}}},{\"../../lib/prepare_regl\":732,\"./helpers\":1080,\"./parcoords\":1084}],1086:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../plots/domain\").attributes,a=t(\"../../plots/font_attributes\"),o=t(\"../../components/color/attributes\"),s=t(\"../../components/fx/hovertemplate_attributes\"),l=t(\"../../lib/extend\").extendFlat,c=a({editType:\"plot\",arrayOk:!0,colorEditType:\"plot\"});e.exports={labels:{valType:\"data_array\",editType:\"calc\"},label0:{valType:\"number\",dflt:0,editType:\"calc\"},dlabel:{valType:\"number\",dflt:1,editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},marker:{colors:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:o.defaultLine,arrayOk:!0,editType:\"style\"},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0,editType:\"style\"},editType:\"calc\"},editType:\"calc\"},text:{valType:\"data_array\",editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"value\",\"percent\"],extras:[\"none\"],editType:\"calc\"},hoverinfo:l({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:s({},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"auto\",arrayOk:!0,editType:\"plot\"},textfont:l({},c,{}),insidetextfont:l({},c,{}),outsidetextfont:l({},c,{}),title:{text:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:l({},c,{}),position:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"plot\"},editType:\"plot\"},domain:i({name:\"pie\",trace:!0,editType:\"calc\"}),hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},sort:{valType:\"boolean\",dflt:!0,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"number\",min:-360,max:360,dflt:0,editType:\"calc\"},pull:{valType:\"number\",min:0,max:1,dflt:0,arrayOk:!0,editType:\"calc\"},_deprecated:{title:{valType:\"string\",dflt:\"\",editType:\"calc\"},titlefont:l({},c,{}),titleposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"calc\"}}}},{\"../../components/color/attributes\":592,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1087:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData;r.name=\"pie\",r.plot=function(t){var e=n.getModule(\"pie\"),r=i(t.calcdata,e)[0];e.plot(t,r)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"pie\"),a=e._has&&e._has(\"pie\");i&&!a&&n._pielayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],1088:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"tinycolor2\"),o=t(\"../../components/color\"),s=t(\"./helpers\"),l=t(\"../../lib\").isValidTextValue,c={};function u(t){return function(e,r){return!!e&&(!!(e=a(e)).isValid()&&(e=o.addOpacity(e,e.getAlpha()),t[r]||(t[r]=e),e))}}function h(t,e){var r,n=JSON.stringify(t),i=e[n];if(!i){for(i=t.slice(),r=0;r<t.length;r++)i.push(a(t[r]).lighten(20).toHexString());for(r=0;r<t.length;r++)i.push(a(t[r]).darken(20).toHexString());e[n]=i}return i}e.exports={calc:function(t,e){var r,a,o=[],c=t._fullLayout,h=c.hiddenlabels||[],f=e.labels,p=e.marker.colors||[],d=e.values,g=i(d)&&d.length;if(e.dlabel)for(f=new Array(d.length),r=0;r<d.length;r++)f[r]=String(e.label0+r*e.dlabel);var v={},m=u(c[\"_\"+e.type+\"colormap\"]),y=(g?d:f).length,x=0,b=!1;for(r=0;r<y;r++){var _,w,k;if(g){if(_=d[r],!n(_))continue;if((_=+_)<0)continue}else _=1;void 0!==(w=f[r])&&\"\"!==w||(w=r);var T=v[w=String(w)];void 0===T?(v[w]=o.length,(k=-1!==h.indexOf(w))||(x+=_),o.push({v:_,label:w,color:m(p[r],w),i:r,pts:[r],hidden:k})):(b=!0,(a=o[T]).v+=_,a.pts.push(r),a.hidden||(x+=_),!1===a.color&&p[r]&&(a.color=m(p[r],w)))}(\"funnelarea\"===e.type?b:e.sort)&&o.sort(function(t,e){return e.v-t.v}),o[0]&&(o[0].vTotal=x);var A=e.textinfo;if(A&&\"none\"!==A){var M,S=A.split(\"+\"),E=function(t){return-1!==S.indexOf(t)},C=E(\"label\"),L=E(\"text\"),P=E(\"value\"),O=E(\"percent\"),z=c.separators;for(r=0;r<o.length;r++){if(a=o[r],M=C?[a.label]:[],L){var I=s.getFirstFilled(e.text,a.pts);l(I)&&M.push(I)}P&&M.push(s.formatPieValue(a.v,z)),O&&M.push(s.formatPiePercent(a.v/x,z)),a.text=M.join(\"<br>\")}}return o},crossTraceCalc:function(t,e){var r=(e||{}).type;r||(r=\"pie\");var n=t._fullLayout,i=t.calcdata,a=n[r+\"colorway\"],o=n[\"_\"+r+\"colormap\"];n[\"extend\"+r+\"colors\"]&&(a=h(a,c));for(var s=0,l=0;l<i.length;l++){var u=i[l];if(u[0].trace.type===r)for(var f=0;f<u.length;f++){var p=u[f];!1===p.color&&(o[p.label]?p.color=o[p.label]:(o[p.label]=p.color=a[s%a.length],s++))}}},makePullColorFn:u,generateExtendedColors:h}},{\"../../components/color\":593,\"../../lib\":719,\"./helpers\":1091,\"fast-isnumeric\":225,tinycolor2:537}],1089:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}var c,u=l(\"values\"),h=n.isArrayOrTypedArray(u),f=l(\"labels\");if(Array.isArray(f)?(c=f.length,h&&(c=Math.min(c,u.length))):h&&(c=u.length,l(\"label0\"),l(\"dlabel\")),c){e._length=c,l(\"marker.line.width\")&&l(\"marker.line.color\"),l(\"marker.colors\"),l(\"scalegroup\");var p=l(\"text\"),d=l(\"textinfo\",Array.isArray(p)?\"text+percent\":\"percent\");if(l(\"hovertext\"),l(\"hovertemplate\"),d&&\"none\"!==d){var g=l(\"textposition\");o(t,e,s,l,g,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}a(e,s,l);var v=l(\"hole\");if(l(\"title.text\")){var m=l(\"title.position\",v?\"middle center\":\"top center\");v||\"middle center\"!==m||(e.title.position=\"top center\"),n.coerceFont(l,\"title.font\",s.font)}l(\"sort\"),l(\"direction\"),l(\"rotation\"),l(\"pull\")}else e.visible=!1}},{\"../../lib\":719,\"../../plots/domain\":792,\"../bar/defaults\":861,\"./attributes\":1086}],1090:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/helpers\").appendArrayMultiPointValues;e.exports=function(t,e){var r={curveNumber:e.index,pointNumbers:t.pts,data:e._input,fullData:e,label:t.label,color:t.color,value:t.v,percent:t.percent,text:t.text,v:t.v};return 1===t.pts.length&&(r.pointNumber=r.i=t.pts[0]),n(r,e,t.pts),\"funnelarea\"===e.type&&(delete r.v,delete r.i),r}},{\"../../components/fx/helpers\":628}],1091:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");r.formatPiePercent=function(t,e){var r=(100*t).toPrecision(3);return-1!==r.lastIndexOf(\".\")&&(r=r.replace(/[.]?0+$/,\"\")),n.numSeparate(r,e)+\"%\"},r.formatPieValue=function(t,e){var r=t.toPrecision(10);return-1!==r.lastIndexOf(\".\")&&(r=r.replace(/[.]?0+$/,\"\")),n.numSeparate(r,e)},r.getFirstFilled=function(t,e){if(Array.isArray(t))for(var r=0;r<e.length;r++){var n=t[e[r]];if(n||0===n)return n}},r.castOption=function(t,e){return Array.isArray(t)?r.getFirstFilled(t,e):t||void 0}},{\"../../lib\":719}],1092:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),layoutAttributes:t(\"./layout_attributes\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\"),styleOne:t(\"./style_one\"),moduleType:\"trace\",name:\"pie\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"pie\",\"showLegend\"],meta:{}}},{\"./attributes\":1086,\"./base_plot\":1087,\"./calc\":1088,\"./defaults\":1089,\"./layout_attributes\":1093,\"./layout_defaults\":1094,\"./plot\":1095,\"./style\":1096,\"./style_one\":1097}],1093:[function(t,e,r){\"use strict\";e.exports={hiddenlabels:{valType:\"data_array\",editType:\"calc\"},piecolorway:{valType:\"colorlist\",editType:\"calc\"},extendpiecolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1094:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"piecolorway\",e.colorway),r(\"extendpiecolors\")}},{\"../../lib\":719,\"./layout_attributes\":1093}],1095:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/fx\"),a=t(\"../../components/color\"),o=t(\"../../components/drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"./helpers\"),u=t(\"./event_data\");function h(t,e,r){var a=r[0],o=a.trace,l=a.cx,h=a.cy;\"_hasHoverLabel\"in o||(o._hasHoverLabel=!1),\"_hasHoverEvent\"in o||(o._hasHoverEvent=!1),t.on(\"mouseover\",function(t){var r=e._fullLayout,f=e._fullData[o.index];if(!e._dragging&&!1!==r.hovermode){var p=f.hoverinfo;if(Array.isArray(p)&&(p=i.castHoverinfo({hoverinfo:[c.castOption(p,t.pts)],_module:o._module},r,0)),\"all\"===p&&(p=\"label+text+value+percent+name\"),f.hovertemplate||\"none\"!==p&&\"skip\"!==p&&p){var d=t.rInscribed||0,g=l+t.pxmid[0]*(1-d),v=h+t.pxmid[1]*(1-d),m=r.separators,y=[];if(p&&-1!==p.indexOf(\"label\")&&y.push(t.label),t.text=c.castOption(f.hovertext||f.text,t.pts),p&&-1!==p.indexOf(\"text\")){var x=t.text;s.isValidTextValue(x)&&y.push(x)}t.value=t.v,t.valueLabel=c.formatPieValue(t.v,m),p&&-1!==p.indexOf(\"value\")&&y.push(t.valueLabel),t.percent=t.v/a.vTotal,t.percentLabel=c.formatPiePercent(t.percent,m),p&&-1!==p.indexOf(\"percent\")&&y.push(t.percentLabel);var b=f.hoverlabel,_=b.font;i.loneHover({trace:o,x0:g-d*a.r,x1:g+d*a.r,y:v,text:y.join(\"<br>\"),name:f.hovertemplate||-1!==p.indexOf(\"name\")?f.name:void 0,idealAlign:t.pxmid[0]<0?\"left\":\"right\",color:c.castOption(b.bgcolor,t.pts)||t.color,borderColor:c.castOption(b.bordercolor,t.pts),fontFamily:c.castOption(_.family,t.pts),fontSize:c.castOption(_.size,t.pts),fontColor:c.castOption(_.color,t.pts),nameLength:c.castOption(b.namelength,t.pts),textAlign:c.castOption(b.align,t.pts),hovertemplate:c.castOption(f.hovertemplate,t.pts),hovertemplateLabels:t,eventData:[u(t,f)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e}),o._hasHoverLabel=!0}o._hasHoverEvent=!0,e.emit(\"plotly_hover\",{points:[u(t,f)],event:n.event})}}),t.on(\"mouseout\",function(t){var r=e._fullLayout,a=e._fullData[o.index],s=n.select(this).datum();o._hasHoverEvent&&(t.originalEvent=n.event,e.emit(\"plotly_unhover\",{points:[u(s,a)],event:n.event}),o._hasHoverEvent=!1),o._hasHoverLabel&&(i.loneUnhover(r._hoverlayer.node()),o._hasHoverLabel=!1)}),t.on(\"click\",function(t){var r=e._fullLayout,a=e._fullData[o.index];e._dragging||!1===r.hovermode||(e._hoverdata=[u(t,a)],i.click(e,n.event))})}function f(t,e,r){var n=c.castOption(t.insidetextfont.color,e.pts);!n&&t._input.textfont&&(n=c.castOption(t._input.textfont.color,e.pts));var i=c.castOption(t.insidetextfont.family,e.pts)||c.castOption(t.textfont.family,e.pts)||r.family,o=c.castOption(t.insidetextfont.size,e.pts)||c.castOption(t.textfont.size,e.pts)||r.size;return{color:n||a.contrast(e.color),family:i,size:o}}function p(t,e){for(var r,n,i=0;i<t.length;i++)if((n=(r=t[i][0]).trace).title.text){var a=n.title.text;n._meta&&(a=s.templateString(a,n._meta));var c=o.tester.append(\"text\").attr(\"data-notex\",1).text(a).call(o.font,n.title.font).call(l.convertToTspans,e),u=o.bBox(c.node(),!0);r.titleBox={width:u.width,height:u.height},c.remove()}}function d(t,e,r){var n=Math.sqrt(t.width*t.width+t.height*t.height),i=t.width/t.height,a=e.halfangle,o=e.ring,s=e.rInscribed,l=r.r||e.rpx1,c={scale:s*l*2/n,rCenter:1-s,rotate:0};if(c.scale>=1)return c;var u=i+1/(2*Math.tan(a)),h=l*Math.min(1/(Math.sqrt(u*u+.5)+u),o/(Math.sqrt(i*i+o/2)+i)),f={scale:2*h/t.height,rCenter:Math.cos(h/l)-h*i/l,rotate:(180/Math.PI*e.midangle+720)%180-90},p=1/i,d=p+1/(2*Math.tan(a)),g=l*Math.min(1/(Math.sqrt(d*d+.5)+d),o/(Math.sqrt(p*p+o/2)+p)),v={scale:2*g/t.width,rCenter:Math.cos(g/l)-g/i/l,rotate:(180/Math.PI*e.midangle+810)%180-90},m=v.scale>f.scale?v:f;return c.scale<1&&m.scale>c.scale?m:c}function g(t,e){return t.v!==e.vTotal||e.trace.hole?Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2):1}function v(t,e){var r=e.pxmid[0],n=e.pxmid[1],i=t.width/2,a=t.height/2;return r<0&&(i*=-1),n<0&&(a*=-1),{scale:1,rCenter:1,rotate:0,x:i+Math.abs(a)*(i>0?1:-1)/2,y:a/(1+r*r/(n*n)),outside:!0}}function m(t,e){var r,n,i,a=t.trace,o={x:t.cx,y:t.cy},s={tx:0,ty:0};s.ty+=a.title.font.size,i=x(a),-1!==a.title.position.indexOf(\"top\")?(o.y-=(1+i)*t.r,s.ty-=t.titleBox.height):-1!==a.title.position.indexOf(\"bottom\")&&(o.y+=(1+i)*t.r);var l,c,u=(l=t.r,c=t.trace.aspectratio,l/(void 0===c?1:c)),h=e.w*(a.domain.x[1]-a.domain.x[0])/2;return-1!==a.title.position.indexOf(\"left\")?(h+=u,o.x-=(1+i)*u,s.tx+=t.titleBox.width/2):-1!==a.title.position.indexOf(\"center\")?h*=2:-1!==a.title.position.indexOf(\"right\")&&(h+=u,o.x+=(1+i)*u,s.tx-=t.titleBox.width/2),r=h/t.titleBox.width,n=y(t,e)/t.titleBox.height,{x:o.x,y:o.y,scale:Math.min(r,n),tx:s.tx,ty:s.ty}}function y(t,e){var r=t.trace,n=e.h*(r.domain.y[1]-r.domain.y[0]);return Math.min(t.titleBox.height,n/2)}function x(t){var e,r=t.pull;if(!r)return 0;if(Array.isArray(r))for(r=0,e=0;e<t.pull.length;e++)t.pull[e]>r&&(r=t.pull[e]);return r}function b(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n][0],a=i.trace,o=a.domain,s=e.w*(o.x[1]-o.x[0]),l=e.h*(o.y[1]-o.y[0]);a.title.text&&\"middle center\"!==a.title.position&&(l-=y(i,e));var c=s/2,u=l/2;\"funnelarea\"!==a.type||a.scalegroup||(u/=a.aspectratio),i.r=Math.min(c,u)/(1+x(a)),i.cx=e.l+e.w*(a.domain.x[1]+a.domain.x[0])/2,i.cy=e.t+e.h*(1-a.domain.y[0])-l/2,a.title.text&&-1!==a.title.position.indexOf(\"bottom\")&&(i.cy-=y(i,e)),a.scalegroup&&-1===r.indexOf(a.scalegroup)&&r.push(a.scalegroup)}!function(t,e){for(var r,n,i,a=0;a<e.length;a++){var o=1/0,s=e[a];for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var l;if(\"pie\"===i.type)l=r.r*r.r;else if(\"funnelarea\"===i.type){var c,u;i.aspectratio>1?(c=r.r,u=c/i.aspectratio):(u=r.r,c=u*i.aspectratio),c*=(1+i.baseratio)/2,l=c*u}o=Math.min(o,l/r.vTotal)}for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var h=o*r.vTotal;\"funnelarea\"===i.type&&(h/=(1+i.baseratio)/2,h/=i.aspectratio),r.r=Math.sqrt(h)}}}(t,r)}e.exports={plot:function(t,e){var r=t._fullLayout;p(e,t),b(e,r._size);var i=s.makeTraceGroups(r._pielayer,e,\"trace\").each(function(e){var i=n.select(this),u=e[0],p=u.trace;!function(t){var e,r,n,i=t[0],a=i.trace,o=a.rotation*Math.PI/180,s=2*Math.PI/i.vTotal,l=\"px0\",c=\"px1\";if(\"counterclockwise\"===a.direction){for(e=0;e<t.length&&t[e].hidden;e++);if(e===t.length)return;o+=s*t[e].v,s*=-1,l=\"px1\",c=\"px0\"}function u(t){return[i.r*Math.sin(t),-i.r*Math.cos(t)]}for(n=u(o),e=0;e<t.length;e++)(r=t[e]).hidden||(r[l]=n,o+=s*r.v/2,r.pxmid=u(o),r.midangle=o,o+=s*r.v/2,n=u(o),r[c]=n,r.largeArc=r.v>i.vTotal/2?1:0,r.halfangle=Math.PI*Math.min(r.v/i.vTotal,.5),r.ring=1-a.hole,r.rInscribed=g(r,i))}(e),i.attr(\"stroke-linejoin\",\"round\"),i.each(function(){var i=n.select(this).selectAll(\"g.slice\").data(e);i.enter().append(\"g\").classed(\"slice\",!0),i.exit().remove();var g=[[[],[]],[[],[]]],y=!1;i.each(function(r){if(r.hidden)n.select(this).selectAll(\"path,g\").remove();else{r.pointNumber=r.i,r.curveNumber=p.index,g[r.pxmid[1]<0?0:1][r.pxmid[0]<0?0:1].push(r);var i=u.cx,a=u.cy,m=n.select(this),x=m.selectAll(\"path.surface\").data([r]);if(x.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),m.call(h,t,e),p.pull){var b=+c.castOption(p.pull,r.pts)||0;b>0&&(i+=b*r.pxmid[0],a+=b*r.pxmid[1])}r.cxFinal=i,r.cyFinal=a;var _=p.hole;if(r.v===u.vTotal){var w=\"M\"+(i+r.px0[0])+\",\"+(a+r.px0[1])+S(r.px0,r.pxmid,!0,1)+S(r.pxmid,r.px0,!0,1)+\"Z\";_?x.attr(\"d\",\"M\"+(i+_*r.px0[0])+\",\"+(a+_*r.px0[1])+S(r.px0,r.pxmid,!1,_)+S(r.pxmid,r.px0,!1,_)+\"Z\"+w):x.attr(\"d\",w)}else{var k=S(r.px0,r.px1,!0,1);if(_){var T=1-_;x.attr(\"d\",\"M\"+(i+_*r.px1[0])+\",\"+(a+_*r.px1[1])+S(r.px1,r.px0,!1,_)+\"l\"+T*r.px0[0]+\",\"+T*r.px0[1]+k+\"Z\")}else x.attr(\"d\",\"M\"+i+\",\"+a+\"l\"+r.px0[0]+\",\"+r.px0[1]+k+\"Z\")}var A=c.castOption(p.textposition,r.pts),M=m.selectAll(\"g.slicetext\").data(r.text&&\"none\"!==A?[0]:[]);M.enter().append(\"g\").classed(\"slicetext\",!0),M.exit().remove(),M.each(function(){var e=s.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)});e.text(r.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(o.font,\"outside\"===A?function(t,e,r){var n=c.castOption(t.outsidetextfont.color,e.pts)||c.castOption(t.textfont.color,e.pts)||r.color,i=c.castOption(t.outsidetextfont.family,e.pts)||c.castOption(t.textfont.family,e.pts)||r.family,a=c.castOption(t.outsidetextfont.size,e.pts)||c.castOption(t.textfont.size,e.pts)||r.size;return{color:n,family:i,size:a}}(p,r,t._fullLayout.font):f(p,r,t._fullLayout.font)).call(l.convertToTspans,t);var h,g=o.bBox(e.node());\"outside\"===A?h=v(g,r):(h=d(g,r,u),\"auto\"===A&&h.scale<1&&(e.call(o.font,p.outsidetextfont),p.outsidetextfont.family===p.insidetextfont.family&&p.outsidetextfont.size===p.insidetextfont.size||(g=o.bBox(e.node())),h=v(g,r)));var m=i+r.pxmid[0]*h.rCenter+(h.x||0),x=a+r.pxmid[1]*h.rCenter+(h.y||0);h.outside&&(r.yLabelMin=x-g.height/2,r.yLabelMid=x,r.yLabelMax=x+g.height/2,r.labelExtraX=0,r.labelExtraY=0,y=!0),e.attr(\"transform\",\"translate(\"+m+\",\"+x+\")\"+(h.scale<1?\"scale(\"+h.scale+\")\":\"\")+(h.rotate?\"rotate(\"+h.rotate+\")\":\"\")+\"translate(\"+-(g.left+g.right)/2+\",\"+-(g.top+g.bottom)/2+\")\")})}function S(t,e,n,i){var a=i*(e[0]-t[0]),o=i*(e[1]-t[1]);return\"a\"+i*u.r+\",\"+i*u.r+\" 0 \"+r.largeArc+(n?\" 1 \":\" 0 \")+a+\",\"+o}});var x=n.select(this).selectAll(\"g.titletext\").data(p.title.text?[0]:[]);x.enter().append(\"g\").classed(\"titletext\",!0),x.exit().remove(),x.each(function(){var e,i=s.ensureSingle(n.select(this),\"text\",\"\",function(t){t.attr(\"data-notex\",1)}),a=p.title.text;p._meta&&(a=s.templateString(a,p._meta)),i.text(a).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(o.font,p.title.font).call(l.convertToTspans,t),e=\"middle center\"===p.title.position?function(t){var e=Math.sqrt(t.titleBox.width*t.titleBox.width+t.titleBox.height*t.titleBox.height);return{x:t.cx,y:t.cy,scale:t.trace.hole*t.r*2/e,tx:0,ty:-t.titleBox.height/2+t.trace.title.font.size}}(u):m(u,r._size),i.attr(\"transform\",\"translate(\"+e.x+\",\"+e.y+\")\"+(e.scale<1?\"scale(\"+e.scale+\")\":\"\")+\"translate(\"+e.tx+\",\"+e.ty+\")\")}),y&&function(t,e){var r,n,i,a,o,s,l,u,h,f,p,d,g;function v(t,e){return t.pxmid[1]-e.pxmid[1]}function m(t,e){return e.pxmid[1]-t.pxmid[1]}function y(t,r){r||(r={});var i,u,h,p,d,g,v=r.labelExtraY+(n?r.yLabelMax:r.yLabelMin),m=n?t.yLabelMin:t.yLabelMax,y=n?t.yLabelMax:t.yLabelMin,x=t.cyFinal+o(t.px0[1],t.px1[1]),b=v-m;if(b*l>0&&(t.labelExtraY=b),Array.isArray(e.pull))for(u=0;u<f.length;u++)(h=f[u])===t||(c.castOption(e.pull,t.pts)||0)>=(c.castOption(e.pull,h.pts)||0)||((t.pxmid[1]-h.pxmid[1])*l>0?(p=h.cyFinal+o(h.px0[1],h.px1[1]),(b=p-m-t.labelExtraY)*l>0&&(t.labelExtraY+=b)):(y+t.labelExtraY-x)*l>0&&(i=3*s*Math.abs(u-f.indexOf(t)),d=h.cxFinal+a(h.px0[0],h.px1[0]),(g=d+i-(t.cxFinal+t.pxmid[0])-t.labelExtraX)*s>0&&(t.labelExtraX+=g)))}for(n=0;n<2;n++)for(i=n?v:m,o=n?Math.max:Math.min,l=n?1:-1,r=0;r<2;r++){for(a=r?Math.max:Math.min,s=r?1:-1,(u=t[n][r]).sort(i),h=t[1-n][r],f=h.concat(u),d=[],p=0;p<u.length;p++)void 0!==u[p].yLabelMid&&d.push(u[p]);for(g=!1,p=0;n&&p<h.length;p++)if(void 0!==h[p].yLabelMid){g=h[p];break}for(p=0;p<d.length;p++){var x=p&&d[p-1];g&&!p&&(x=g),y(d[p],x)}}}(g,p),function(t,e){t.each(function(t){var r=n.select(this);if(t.labelExtraX||t.labelExtraY){var i=r.select(\"g.slicetext text\");i.attr(\"transform\",\"translate(\"+t.labelExtraX+\",\"+t.labelExtraY+\")\"+i.attr(\"transform\"));var o=t.cxFinal+t.pxmid[0],l=t.cyFinal+t.pxmid[1],c=\"M\"+o+\",\"+l,u=(t.yLabelMax-t.yLabelMin)*(t.pxmid[0]<0?-1:1)/4;if(t.labelExtraX){var h=t.labelExtraX*t.pxmid[1]/t.pxmid[0],f=t.yLabelMid+t.labelExtraY-(t.cyFinal+t.pxmid[1]);Math.abs(h)>Math.abs(f)?c+=\"l\"+f*t.pxmid[0]/t.pxmid[1]+\",\"+f+\"H\"+(o+t.labelExtraX+u):c+=\"l\"+t.labelExtraX+\",\"+h+\"v\"+(f-h)+\"h\"+u}else c+=\"V\"+(t.yLabelMid+t.labelExtraY)+\"h\"+u;s.ensureSingle(r,\"path\",\"textline\").call(a.stroke,e.outsidetextfont.color).attr({\"stroke-width\":Math.min(2,e.outsidetextfont.size/8),d:c,fill:\"none\"})}else r.select(\"path.textline\").remove()})}(i,p)})});setTimeout(function(){i.selectAll(\"tspan\").each(function(){var t=n.select(this);t.attr(\"dy\")&&t.attr(\"dy\",t.attr(\"dy\"))})},0)},transformInsideText:d,determineInsideTextFont:f,positionTitleOutside:m,prerenderTitles:p,layoutAreas:b,attachFxHandlers:h}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../lib\":719,\"../../lib/svg_text_utils\":743,\"./event_data\":1090,\"./helpers\":1091,d3:163}],1096:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./style_one\");e.exports=function(t){t._fullLayout._pielayer.selectAll(\".trace\").each(function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each(function(t){n.select(this).call(i,t,e)})})}},{\"./style_one\":1097,d3:163}],1097:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./helpers\").castOption;e.exports=function(t,e,r){var a=r.marker.line,o=i(a.color,e.pts)||n.defaultLine,s=i(a.width,e.pts)||0;t.style(\"stroke-width\",s).call(n.fill,e.color).call(n.stroke,o)}},{\"../../components/color\":593,\"./helpers\":1091}],1098:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\");e.exports={x:n.x,y:n.y,xy:{valType:\"data_array\",editType:\"calc\"},indices:{valType:\"data_array\",editType:\"calc\"},xbounds:{valType:\"data_array\",editType:\"calc\"},ybounds:{valType:\"data_array\",editType:\"calc\"},text:n.text,marker:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,arrayOk:!1,editType:\"calc\"},blend:{valType:\"boolean\",dflt:null,editType:\"calc\"},sizemin:{valType:\"number\",min:.1,max:2,dflt:.5,editType:\"calc\"},sizemax:{valType:\"number\",min:.1,dflt:20,editType:\"calc\"},border:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},arearatio:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},transforms:void 0}},{\"../scatter/attributes\":1112}],1099:[function(t,e,r){\"use strict\";var n=t(\"gl-pointcloud2d\"),i=t(\"../../lib/str2rgbarray\"),a=t(\"../../plots/cartesian/autorange\").findExtremes,o=t(\"../scatter/get_trace_color\");function s(t,e){this.scene=t,this.uid=e,this.type=\"pointcloud\",this.pickXData=[],this.pickYData=[],this.xData=[],this.yData=[],this.textLabels=[],this.color=\"rgb(0, 0, 0)\",this.name=\"\",this.hoverinfo=\"all\",this.idToIndex=new Int32Array(0),this.bounds=[0,0,0,0],this.pointcloudOptions={positions:new Float32Array(0),idToIndex:this.idToIndex,sizemin:.5,sizemax:12,color:[0,0,0,1],areaRatio:1,borderColor:[0,0,0,1]},this.pointcloud=n(t.glplot,this.pointcloudOptions),this.pointcloud._trace=this}var l=s.prototype;l.handlePick=function(t){var e=this.idToIndex[t.pointId];return{trace:this,dataCoord:t.dataCoord,traceCoord:this.pickXYData?[this.pickXYData[2*e],this.pickXYData[2*e+1]]:[this.pickXData[e],this.pickYData[e]],textLabel:Array.isArray(this.textLabels)?this.textLabels[e]:this.textLabels,color:this.color,name:this.name,pointIndex:e,hoverinfo:this.hoverinfo}},l.update=function(t){this.index=t.index,this.textLabels=t.text,this.name=t.name,this.hoverinfo=t.hoverinfo,this.bounds=[1/0,1/0,-1/0,-1/0],this.updateFast(t),this.color=o(t,{})},l.updateFast=function(t){var e,r,n,o,s,l,c=this.xData=this.pickXData=t.x,u=this.yData=this.pickYData=t.y,h=this.pickXYData=t.xy,f=t.xbounds&&t.ybounds,p=t.indices,d=this.bounds;if(h){if(n=h,e=h.length>>>1,f)d[0]=t.xbounds[0],d[2]=t.xbounds[1],d[1]=t.ybounds[0],d[3]=t.ybounds[1];else for(l=0;l<e;l++)o=n[2*l],s=n[2*l+1],o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);if(p)r=p;else for(r=new Int32Array(e),l=0;l<e;l++)r[l]=l}else for(e=c.length,n=new Float32Array(2*e),r=new Int32Array(e),l=0;l<e;l++)o=c[l],s=u[l],r[l]=l,n[2*l]=o,n[2*l+1]=s,o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);this.idToIndex=r,this.pointcloudOptions.idToIndex=r,this.pointcloudOptions.positions=n;var g=i(t.marker.color),v=i(t.marker.border.color),m=t.opacity*t.marker.opacity;g[3]*=m,this.pointcloudOptions.color=g;var y=t.marker.blend;if(null===y){y=c.length<100||u.length<100}this.pointcloudOptions.blend=y,v[3]*=m,this.pointcloudOptions.borderColor=v;var x=t.marker.sizemin,b=Math.max(t.marker.sizemax,t.marker.sizemin);this.pointcloudOptions.sizeMin=x,this.pointcloudOptions.sizeMax=b,this.pointcloudOptions.areaRatio=t.marker.border.arearatio,this.pointcloud.update(this.pointcloudOptions);var _=this.scene.xaxis,w=this.scene.yaxis,k=b/2||.5;t._extremes[_._id]=a(_,[d[0],d[2]],{ppad:k}),t._extremes[w._id]=a(w,[d[1],d[3]],{ppad:k})},l.dispose=function(){this.pointcloud.dispose()},e.exports=function(t,e){var r=new s(t,e.uid);return r.update(e),r}},{\"../../lib/str2rgbarray\":742,\"../../plots/cartesian/autorange\":766,\"../scatter/get_trace_color\":1121,\"gl-pointcloud2d\":292}],1100:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\");e.exports=function(t,e,r){function a(r,a){return n.coerce(t,e,i,r,a)}a(\"x\"),a(\"y\"),a(\"xbounds\"),a(\"ybounds\"),t.xy&&t.xy instanceof Float32Array&&(e.xy=t.xy),t.indices&&t.indices instanceof Int32Array&&(e.indices=t.indices),a(\"text\"),a(\"marker.color\",r),a(\"marker.opacity\"),a(\"marker.blend\"),a(\"marker.sizemin\"),a(\"marker.sizemax\"),a(\"marker.border.color\",r),a(\"marker.border.arearatio\"),e._length=null}},{\"../../lib\":719,\"./attributes\":1098}],1101:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../scatter3d/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"pointcloud\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"showLegend\"],meta:{}}},{\"../../plots/gl2d\":805,\"../scatter3d/calc\":1139,\"./attributes\":1098,\"./convert\":1099,\"./defaults\":1100}],1102:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../components/fx/attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../../components/fx/hovertemplate_attributes\"),c=t(\"../../components/colorscale/attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,h=t(\"../../lib/extend\").extendFlat,f=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=f({hoverinfo:h({},i.hoverinfo,{flags:[],arrayOk:!1}),hoverlabel:o.hoverlabel,domain:s({name:\"sankey\",trace:!0}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\"},valueformat:{valType:\"string\",dflt:\".3s\"},valuesuffix:{valType:\"string\",dflt:\"\"},arrangement:{valType:\"enumerated\",values:[\"snap\",\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"snap\"},textfont:n({}),node:{label:{valType:\"data_array\",dflt:[]},groups:{valType:\"info_array\",impliedEdits:{x:[],y:[]},dimensions:2,freeLength:!0,dflt:[],items:{valType:\"number\",editType:\"calc\"}},x:{valType:\"data_array\",dflt:[]},y:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:.5,arrayOk:!0}},pad:{valType:\"number\",arrayOk:!1,min:0,dflt:20},thickness:{valType:\"number\",arrayOk:!1,min:1,dflt:20},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]})},link:{label:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0}},source:{valType:\"data_array\",dflt:[]},target:{valType:\"data_array\",dflt:[]},value:{valType:\"data_array\",dflt:[]},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]}),colorscales:u(\"concentrationscales\",{editType:\"calc\",label:{valType:\"string\",editType:\"calc\",dflt:\"\"},cmax:{valType:\"number\",editType:\"calc\",dflt:1},cmin:{valType:\"number\",editType:\"calc\",dflt:0},colorscale:h(c().colorscale,{dflt:[[0,\"white\"],[1,\"black\"]]})})}},\"calc\",\"nested\")).transforms=void 0},{\"../../components/color/attributes\":592,\"../../components/colorscale/attributes\":600,\"../../components/fx/attributes\":623,\"../../components/fx/hovertemplate_attributes\":631,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plot_api/plot_template\":757,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1103:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../components/fx/layout_attributes\"),s=t(\"../../lib/setcursor\"),l=t(\"../../components/dragelement\"),c=t(\"../../plots/cartesian/select\").prepSelect,u=t(\"../../lib\"),h=t(\"../../registry\");function f(t,e){var r=t._fullData[e],n=t._fullLayout,i=n.dragmode,a=\"pan\"===n.dragmode?\"move\":\"crosshair\",o=r._bgRect;if(\"pan\"!==i&&\"zoom\"!==i){s(o,a);var f={_id:\"x\",c2p:u.identity,_offset:r._sankey.translateX,_length:r._sankey.width},p={_id:\"y\",c2p:u.identity,_offset:r._sankey.translateY,_length:r._sankey.height},d={gd:t,element:o.node(),plotinfo:{id:e,xaxis:f,yaxis:p,fillRangeItems:u.noop},subplot:e,xaxes:[f],yaxes:[p],doneFnCompleted:function(r){var n,i=t._fullData[e],a=i.node.groups.slice(),o=[];function s(t){for(var e=i._sankey.graph.nodes,r=0;r<e.length;r++)if(e[r].pointNumber===t)return e[r]}for(var l=0;l<r.length;l++){var c=s(r[l].pointNumber);if(c)if(c.group){for(var u=0;u<c.childrenNodes.length;u++)o.push(c.childrenNodes[u].pointNumber);a[c.pointNumber-i.node._count]=!1}else o.push(c.pointNumber)}n=a.filter(Boolean).concat([o]),h.call(\"_guiRestyle\",t,{\"node.groups\":[n]},e)},prepFn:function(t,e,r){c(t,e,r,d,i)}};l.init(d)}}r.name=\"sankey\",r.baseLayoutAttrOverrides=n({hoverlabel:o.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){var e=i(t.calcdata,\"sankey\")[0];a(t,e),r.updateFx(t)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"sankey\"),a=e._has&&e._has(\"sankey\");i&&!a&&(n._paperdiv.selectAll(\".sankey\").remove(),n._paperdiv.selectAll(\".bgsankey\").remove())},r.updateFx=function(t){for(var e=0;e<t._fullData.length;e++)f(t,e)}},{\"../../components/dragelement\":611,\"../../components/fx/layout_attributes\":633,\"../../lib\":719,\"../../lib/setcursor\":739,\"../../plot_api/edit_types\":750,\"../../plots/cartesian/select\":784,\"../../plots/get_data\":802,\"../../registry\":847,\"./plot\":1108}],1104:[function(t,e,r){\"use strict\";var n=t(\"strongly-connected-components\"),i=t(\"../../lib\"),a=t(\"../../lib/gup\").wrap,o=i.isArrayOrTypedArray,s=i.isIndex,l=t(\"../../components/colorscale\");function c(t){var e,r=t.node,a=t.link,c=[],u=o(a.color),h={},f={},p=a.colorscales.length;for(e=0;e<p;e++){var d=a.colorscales[e],g=l.extractScale(d,{cLetter:\"c\"}),v=l.makeColorScaleFunc(g);f[d.label]=v}var m=0;for(e=0;e<a.value.length;e++)a.source[e]>m&&(m=a.source[e]),a.target[e]>m&&(m=a.target[e]);var y,x=m+1;t.node._count=x;var b=t.node.groups,_={};for(e=0;e<b.length;e++){var w=b[e];for(y=0;y<w.length;y++){var k=w[y],T=x+e;_.hasOwnProperty(k)?i.warn(\"Node \"+k+\" is already part of a group.\"):_[k]=T}}var A={source:[],target:[]};for(e=0;e<a.value.length;e++){var M=a.value[e],S=a.source[e],E=a.target[e];if(M>0&&s(S,x)&&s(E,x)&&(!_.hasOwnProperty(S)||!_.hasOwnProperty(E)||_[S]!==_[E])){_.hasOwnProperty(E)&&(E=_[E]),_.hasOwnProperty(S)&&(S=_[S]),E=+E,h[S=+S]=h[E]=!0;var C=\"\";a.label&&a.label[e]&&(C=a.label[e]);var L=null;C&&f.hasOwnProperty(C)&&(L=f[C]),c.push({pointNumber:e,label:C,color:u?a.color[e]:a.color,concentrationscale:L,source:S,target:E,value:+M}),A.source.push(S),A.target.push(E)}}var P=x+b.length,O=o(r.color),z=[];for(e=0;e<P;e++)if(h[e]){var I=r.label[e];z.push({group:e>x-1,childrenNodes:[],pointNumber:e,label:I,color:O?r.color[e]:r.color})}var D=!1;return function(t,e,r){for(var a=i.init2dArray(t,0),o=0;o<Math.min(e.length,r.length);o++)if(i.isIndex(e[o],t)&&i.isIndex(r[o],t)){if(e[o]===r[o])return!0;a[e[o]].push(r[o])}return n(a).components.some(function(t){return t.length>1})}(P,A.source,A.target)&&(D=!0),{circular:D,links:c,nodes:z,groups:b,groupLookup:_}}e.exports=function(t,e){var r=c(e);return a({circular:r.circular,_nodes:r.nodes,_links:r.links,_groups:r.groups,_groupLookup:r.groupLookup})}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gup\":717,\"strongly-connected-components\":530}],1105:[function(t,e,r){\"use strict\";e.exports={nodeTextOffsetHorizontal:4,nodeTextOffsetVertical:3,nodePadAcross:10,sankeyIterations:50,forceIterations:5,forceTicksPerFrame:10,duration:500,ease:\"linear\",cn:{sankey:\"sankey\",sankeyLinks:\"sankey-links\",sankeyLink:\"sankey-link\",sankeyNodeSet:\"sankey-node-set\",sankeyNode:\"sankey-node\",nodeRect:\"node-rect\",nodeCapture:\"node-capture\",nodeCentered:\"node-entered\",nodeLabelGuide:\"node-label-guide\",nodeLabel:\"node-label\",nodeLabelTextPath:\"node-label-text-path\"}}},{}],1106:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../components/color\"),o=t(\"tinycolor2\"),s=t(\"../../plots/domain\").defaults,l=t(\"../../components/fx/hoverlabel_defaults\"),c=t(\"../../plot_api/plot_template\"),u=t(\"../../plots/array_container_defaults\");function h(t,e){function r(r,a){return n.coerce(t,e,i.link.colorscales,r,a)}r(\"label\"),r(\"cmin\"),r(\"cmax\"),r(\"colorscale\")}e.exports=function(t,e,r,f){function p(r,a){return n.coerce(t,e,i,r,a)}var d=n.extendDeep(f.hoverlabel,t.hoverlabel),g=t.node,v=c.newContainer(e,\"node\");function m(t,e){return n.coerce(g,v,i.node,t,e)}m(\"label\"),m(\"groups\"),m(\"x\"),m(\"y\"),m(\"pad\"),m(\"thickness\"),m(\"line.color\"),m(\"line.width\"),m(\"hoverinfo\",t.hoverinfo),l(g,v,m,d),m(\"hovertemplate\");var y=f.colorway;m(\"color\",v.label.map(function(t,e){return a.addOpacity(function(t){return y[t%y.length]}(e),.8)}));var x=t.link||{},b=c.newContainer(e,\"link\");function _(t,e){return n.coerce(x,b,i.link,t,e)}_(\"label\"),_(\"source\"),_(\"target\"),_(\"value\"),_(\"line.color\"),_(\"line.width\"),_(\"hoverinfo\",t.hoverinfo),l(x,b,_,d),_(\"hovertemplate\");var w,k=o(f.paper_bgcolor).getLuminance()<.333?\"rgba(255, 255, 255, 0.6)\":\"rgba(0, 0, 0, 0.2)\";_(\"color\",n.repeat(k,b.value.length)),u(x,b,{name:\"colorscales\",handleItemDefaults:h}),s(e,f,p),p(\"orientation\"),p(\"valueformat\"),p(\"valuesuffix\"),v.x.length&&v.y.length&&(w=\"freeform\"),p(\"arrangement\",w),n.coerceFont(p,\"textfont\",n.extendFlat({},f.font)),e._length=null}},{\"../../components/color\":593,\"../../components/fx/hoverlabel_defaults\":630,\"../../lib\":719,\"../../plot_api/plot_template\":757,\"../../plots/array_container_defaults\":763,\"../../plots/domain\":792,\"./attributes\":1102,tinycolor2:537}],1107:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"sankey\",basePlotModule:t(\"./base_plot\"),selectPoints:t(\"./select.js\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1102,\"./base_plot\":1103,\"./calc\":1104,\"./defaults\":1106,\"./plot\":1108,\"./select.js\":1110}],1108:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./render\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\"),l=t(\"./constants\").cn,c=s._;function u(t){return\"\"!==t}function h(t,e){return t.filter(function(t){return t.key===e.traceId})}function f(t,e){n.select(t).select(\"path\").style(\"fill-opacity\",e),n.select(t).select(\"rect\").style(\"fill-opacity\",e)}function p(t){n.select(t).select(\"text.name\").style(\"fill\",\"black\")}function d(t){return function(e){return-1!==t.node.sourceLinks.indexOf(e.link)||-1!==t.node.targetLinks.indexOf(e.link)}}function g(t){return function(e){return-1!==e.node.sourceLinks.indexOf(t.link)||-1!==e.node.targetLinks.indexOf(t.link)}}function v(t,e,r){e&&r&&h(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(y.bind(0,e,r,!1))}function m(t,e,r){e&&r&&h(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(x.bind(0,e,r,!1))}function y(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",function(t){if(!t.link.concentrationscale)return.4}),i&&h(e,t).selectAll(\".\"+l.sankeyLink).filter(function(t){return t.link.label===i}).style(\"fill-opacity\",function(t){if(!t.link.concentrationscale)return.4}),r&&h(e,t).selectAll(\".\"+l.sankeyNode).filter(g(t)).call(v)}function x(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),i&&h(e,t).selectAll(\".\"+l.sankeyLink).filter(function(t){return t.link.label===i}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),r&&h(e,t).selectAll(l.sankeyNode).filter(g(t)).call(m)}function b(t,e){var r=t.hoverlabel||{},n=s.nestedProperty(r,e).get();return!Array.isArray(n)&&n}e.exports=function(t,e){for(var r=t._fullLayout,s=r._paper,h=r._size,d=0;d<t._fullData.length;d++)if(t._fullData[d].type===l.sankey&&!t._fullData[d]._viewInitial){var g=t._fullData[d].node;t._fullData[d]._viewInitial={node:{groups:g.groups.slice(),x:g.x.slice(),y:g.y.slice()}}}var _=c(t,\"source:\")+\" \",w=c(t,\"target:\")+\" \",k=c(t,\"concentration:\")+\" \",T=c(t,\"incoming flow count:\")+\" \",A=c(t,\"outgoing flow count:\")+\" \";i(t,s,e,{width:h.w,height:h.h,margin:{t:h.t,r:h.r,b:h.b,l:h.l}},{linkEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(y.bind(0,r,i,!0)),\"skip\"!==r.link.trace.link.hoverinfo&&(r.link.fullData=r.link.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.link]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var s=i.link.trace.link;if(\"none\"!==s.hoverinfo&&\"skip\"!==s.hoverinfo){for(var l=[],c=0,h=0;h<i.flow.links.length;h++){var d=i.flow.links[h];if(\"closest\"!==t._fullLayout.hovermode||i.link.pointNumber===d.pointNumber){i.link.pointNumber===d.pointNumber&&(c=h),d.fullData=d.trace,s=i.link.trace.link;var g=m(d),v={valueLabel:n.format(i.valueFormat)(d.value)+i.valueSuffix};l.push({x:g[0],y:g[1],name:v.valueLabel,text:[d.label||\"\",_+d.source.label,w+d.target.label,d.concentrationscale?k+n.format(\"%0.2f\")(d.flow.labelConcentration):\"\"].filter(u).join(\"<br>\"),color:b(s,\"bgcolor\")||o.addOpacity(d.color,1),borderColor:b(s,\"bordercolor\"),fontFamily:b(s,\"font.family\"),fontSize:b(s,\"font.size\"),fontColor:b(s,\"font.color\"),nameLength:b(s,\"namelength\"),textAlign:b(s,\"align\"),idealAlign:n.event.x<g[0]?\"right\":\"left\",hovertemplate:s.hovertemplate,hovertemplateLabels:v,eventData:[d]})}}a.loneHover(l,{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t,anchorIndex:c}).each(function(){i.link.concentrationscale||f(this,.65),p(this)})}}function m(t){var e,r;return t.circular?(e=(t.circularPathData.leftInnerExtent+t.circularPathData.rightInnerExtent)/2+i.parent.translateX,r=t.circularPathData.verticalFullExtent+i.parent.translateY):(e=(t.source.x1+t.target.x0)/2+i.parent.translateX,r=(t.y0+t.y1)/2+i.parent.translateY),[e,r]}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(x.bind(0,i,o,!0)),\"skip\"!==i.link.trace.link.hoverinfo&&(i.link.fullData=i.link.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.link]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r){var i=r.link;i.originalEvent=n.event,t._hoverdata=[i],a.click(t,{target:!0})}},nodeEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(v,r,i),\"skip\"!==r.node.trace.node.hoverinfo&&(r.node.fullData=r.node.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.node]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var o=i.node.trace.node;if(\"none\"!==o.hoverinfo&&\"skip\"!==o.hoverinfo){var s=n.select(e).select(\".\"+l.nodeRect),c=t._fullLayout._paperdiv.node().getBoundingClientRect(),h=s.node().getBoundingClientRect(),d=h.left-2-c.left,g=h.right+2-c.left,v=h.top+h.height/4-c.top,m={valueLabel:n.format(i.valueFormat)(i.node.value)+i.valueSuffix};i.node.fullData=i.node.trace;var y=a.loneHover({x0:d,x1:g,y:v,name:n.format(i.valueFormat)(i.node.value)+i.valueSuffix,text:[i.node.label,T+i.node.targetLinks.length,A+i.node.sourceLinks.length].filter(u).join(\"<br>\"),color:b(o,\"bgcolor\")||i.tinyColorHue,borderColor:b(o,\"bordercolor\"),fontFamily:b(o,\"font.family\"),fontSize:b(o,\"font.size\"),fontColor:b(o,\"font.color\"),nameLength:b(o,\"namelength\"),textAlign:b(o,\"align\"),idealAlign:\"left\",hovertemplate:o.hovertemplate,hovertemplateLabels:m,eventData:[i.node]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t});f(y,.85),p(y)}}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(m,i,o),\"skip\"!==i.node.trace.node.hoverinfo&&(i.node.fullData=i.node.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.node]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r,i){var o=r.node;o.originalEvent=n.event,t._hoverdata=[o],n.select(e).call(m,r,i),a.click(t,{target:!0})}}})}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"./constants\":1105,\"./render\":1109,d3:163}],1109:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"tinycolor2\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"@plotly/d3-sankey\"),c=t(\"@plotly/d3-sankey-circular\"),u=t(\"d3-force\"),h=t(\"../../lib\"),f=t(\"../../lib/gup\"),p=f.keyFun,d=f.repeat,g=f.unwrap,v=t(\"d3-interpolate\").interpolateNumber,m=t(\"../../registry\");function y(){var t=.5;return function(e){if(e.link.circular)return r=e.link,n=r.width/2,i=r.circularPathData,\"top\"===r.circularLinkType?\"M \"+i.targetX+\" \"+(i.targetY+n)+\" L\"+i.rightInnerExtent+\" \"+(i.targetY+n)+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightSmallArcRadius+n)+\" 0 0 1 \"+(i.rightFullExtent-n)+\" \"+(i.targetY-i.rightSmallArcRadius)+\"L\"+(i.rightFullExtent-n)+\" \"+i.verticalRightInnerExtent+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightLargeArcRadius+n)+\" 0 0 1 \"+i.rightInnerExtent+\" \"+(i.verticalFullExtent-n)+\"L\"+i.leftInnerExtent+\" \"+(i.verticalFullExtent-n)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftLargeArcRadius+n)+\" 0 0 1 \"+(i.leftFullExtent+n)+\" \"+i.verticalLeftInnerExtent+\"L\"+(i.leftFullExtent+n)+\" \"+(i.sourceY-i.leftSmallArcRadius)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftSmallArcRadius+n)+\" 0 0 1 \"+i.leftInnerExtent+\" \"+(i.sourceY+n)+\"L\"+i.sourceX+\" \"+(i.sourceY+n)+\"L\"+i.sourceX+\" \"+(i.sourceY-n)+\"L\"+i.leftInnerExtent+\" \"+(i.sourceY-n)+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftSmallArcRadius-n)+\" 0 0 0 \"+(i.leftFullExtent-n)+\" \"+(i.sourceY-i.leftSmallArcRadius)+\"L\"+(i.leftFullExtent-n)+\" \"+i.verticalLeftInnerExtent+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftLargeArcRadius-n)+\" 0 0 0 \"+i.leftInnerExtent+\" \"+(i.verticalFullExtent+n)+\"L\"+i.rightInnerExtent+\" \"+(i.verticalFullExtent+n)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightLargeArcRadius-n)+\" 0 0 0 \"+(i.rightFullExtent+n)+\" \"+i.verticalRightInnerExtent+\"L\"+(i.rightFullExtent+n)+\" \"+(i.targetY-i.rightSmallArcRadius)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightSmallArcRadius-n)+\" 0 0 0 \"+i.rightInnerExtent+\" \"+(i.targetY-n)+\"L\"+i.targetX+\" \"+(i.targetY-n)+\"Z\":\"M \"+i.targetX+\" \"+(i.targetY-n)+\" L\"+i.rightInnerExtent+\" \"+(i.targetY-n)+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightSmallArcRadius+n)+\" 0 0 0 \"+(i.rightFullExtent-n)+\" \"+(i.targetY+i.rightSmallArcRadius)+\"L\"+(i.rightFullExtent-n)+\" \"+i.verticalRightInnerExtent+\"A\"+(i.rightLargeArcRadius+n)+\" \"+(i.rightLargeArcRadius+n)+\" 0 0 0 \"+i.rightInnerExtent+\" \"+(i.verticalFullExtent+n)+\"L\"+i.leftInnerExtent+\" \"+(i.verticalFullExtent+n)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftLargeArcRadius+n)+\" 0 0 0 \"+(i.leftFullExtent+n)+\" \"+i.verticalLeftInnerExtent+\"L\"+(i.leftFullExtent+n)+\" \"+(i.sourceY+i.leftSmallArcRadius)+\"A\"+(i.leftLargeArcRadius+n)+\" \"+(i.leftSmallArcRadius+n)+\" 0 0 0 \"+i.leftInnerExtent+\" \"+(i.sourceY-n)+\"L\"+i.sourceX+\" \"+(i.sourceY-n)+\"L\"+i.sourceX+\" \"+(i.sourceY+n)+\"L\"+i.leftInnerExtent+\" \"+(i.sourceY+n)+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftSmallArcRadius-n)+\" 0 0 1 \"+(i.leftFullExtent-n)+\" \"+(i.sourceY+i.leftSmallArcRadius)+\"L\"+(i.leftFullExtent-n)+\" \"+i.verticalLeftInnerExtent+\"A\"+(i.leftLargeArcRadius-n)+\" \"+(i.leftLargeArcRadius-n)+\" 0 0 1 \"+i.leftInnerExtent+\" \"+(i.verticalFullExtent-n)+\"L\"+i.rightInnerExtent+\" \"+(i.verticalFullExtent-n)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightLargeArcRadius-n)+\" 0 0 1 \"+(i.rightFullExtent+n)+\" \"+i.verticalRightInnerExtent+\"L\"+(i.rightFullExtent+n)+\" \"+(i.targetY+i.rightSmallArcRadius)+\"A\"+(i.rightLargeArcRadius-n)+\" \"+(i.rightSmallArcRadius-n)+\" 0 0 1 \"+i.rightInnerExtent+\" \"+(i.targetY+n)+\"L\"+i.targetX+\" \"+(i.targetY+n)+\"Z\";var r,n,i,a=e.link.source.x1,o=e.link.target.x0,s=v(a,o),l=s(t),c=s(1-t),u=e.link.y0-e.link.width/2,h=e.link.y0+e.link.width/2,f=e.link.y1-e.link.width/2,p=e.link.y1+e.link.width/2;return\"M\"+a+\",\"+u+\"C\"+l+\",\"+u+\" \"+c+\",\"+f+\" \"+o+\",\"+f+\"L\"+o+\",\"+p+\"C\"+c+\",\"+p+\" \"+l+\",\"+h+\" \"+a+\",\"+h+\"Z\"}}function x(t){t.attr(\"transform\",function(t){return\"translate(\"+t.node.x0.toFixed(3)+\", \"+t.node.y0.toFixed(3)+\")\"})}function b(t){t.call(x)}function _(t,e){t.call(b),e.attr(\"d\",y())}function w(t){t.attr(\"width\",function(t){return t.node.x1-t.node.x0}).attr(\"height\",function(t){return t.visibleHeight})}function k(t){return t.link.width>1||t.linkLineWidth>0}function T(t){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"+(t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\")}function A(t){return\"translate(\"+(t.horizontal?0:t.labelY)+\" \"+(t.horizontal?t.labelY:0)+\")\"}function M(t){return i.svg.line()([[t.horizontal?t.left?-t.sizeAcross:t.visibleWidth+n.nodeTextOffsetHorizontal:n.nodeTextOffsetHorizontal,0],[t.horizontal?t.left?-n.nodeTextOffsetHorizontal:t.sizeAcross:t.visibleHeight-n.nodeTextOffsetHorizontal,0]])}function S(t){return t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\"}function E(t){return t.horizontal?\"scale(1 1)\":\"scale(-1 1)\"}function C(t){return t.darkBackground&&!t.horizontal?\"rgb(255,255,255)\":\"rgb(0,0,0)\"}function L(t){return t.horizontal&&t.left?\"100%\":\"0%\"}function P(t,e,r){t.on(\".basic\",null).on(\"mouseover.basic\",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.hover(this,t,e),t.interactionState.hovered=[this,t])}).on(\"mousemove.basic\",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.follow(this,t),t.interactionState.hovered=[this,t])}).on(\"mouseout.basic\",function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.unhover(this,t,e),t.interactionState.hovered=!1)}).on(\"click.basic\",function(t){t.interactionState.hovered&&(r.unhover(this,t,e),t.interactionState.hovered=!1),t.interactionState.dragInProgress||t.partOfGroup||r.select(this,t,e)})}function O(t,e,r,a){var o=i.behavior.drag().origin(function(t){return{x:t.node.x0+t.visibleWidth/2,y:t.node.y0+t.visibleHeight/2}}).on(\"dragstart\",function(i){if(\"fixed\"!==i.arrangement&&(h.ensureSingle(a._fullLayout._infolayer,\"g\",\"dragcover\",function(t){a._fullLayout._dragCover=t}),h.raiseToTop(this),i.interactionState.dragInProgress=i.node,I(i.node),i.interactionState.hovered&&(r.nodeEvents.unhover.apply(0,i.interactionState.hovered),i.interactionState.hovered=!1),\"snap\"===i.arrangement)){var o=i.traceId+\"|\"+i.key;i.forceLayouts[o]?i.forceLayouts[o].alpha(1):function(t,e,r,i){!function(t){for(var e=0;e<t.length;e++)t[e].y=(t[e].y0+t[e].y1)/2,t[e].x=(t[e].x0+t[e].x1)/2}(r.graph.nodes);var a=r.graph.nodes.filter(function(t){return t.originalX===r.node.originalX}).filter(function(t){return!t.partOfGroup});r.forceLayouts[e]=u.forceSimulation(a).alphaDecay(0).force(\"collide\",u.forceCollide().radius(function(t){return t.dy/2+r.nodePad/2}).strength(1).iterations(n.forceIterations)).force(\"constrain\",function(t,e,r,i){return function(){for(var t=0,a=0;a<r.length;a++){var o=r[a];o===i.interactionState.dragInProgress?(o.x=o.lastDraggedX,o.y=o.lastDraggedY):(o.vx=(o.originalX-o.x)/n.forceTicksPerFrame,o.y=Math.min(i.size-o.dy/2,Math.max(o.dy/2,o.y))),t=Math.max(t,Math.abs(o.vx),Math.abs(o.vy))}!i.interactionState.dragInProgress&&t<.1&&i.forceLayouts[e].alpha()>0&&i.forceLayouts[e].alpha(0)}}(0,e,a,r)).stop()}(0,o,i),function(t,e,r,i,a){window.requestAnimationFrame(function o(){var s;for(s=0;s<n.forceTicksPerFrame;s++)r.forceLayouts[i].tick();var l=r.graph.nodes;if(function(t){for(var e=0;e<t.length;e++)t[e].y0=t[e].y-t[e].dy/2,t[e].y1=t[e].y0+t[e].dy,t[e].x0=t[e].x-t[e].dx/2,t[e].x1=t[e].x0+t[e].dx}(l),r.sankey.update(r.graph),_(t.filter(D(r)),e),r.forceLayouts[i].alpha()>0)window.requestAnimationFrame(o);else{var c=r.node.originalX;r.node.x0=c-r.visibleWidth/2,r.node.x1=c+r.visibleWidth/2,z(r,a)}})}(t,e,i,o,a)}}).on(\"drag\",function(r){if(\"fixed\"!==r.arrangement){var n=i.event.x,a=i.event.y;\"snap\"===r.arrangement?(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2,r.node.y0=a-r.visibleHeight/2,r.node.y1=a+r.visibleHeight/2):(\"freeform\"===r.arrangement&&(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2),a=Math.max(0,Math.min(r.size-r.visibleHeight/2,a)),r.node.y0=a-r.visibleHeight/2,r.node.y1=a+r.visibleHeight/2),I(r.node),\"snap\"!==r.arrangement&&(r.sankey.update(r.graph),_(t.filter(D(r)),e))}}).on(\"dragend\",function(t){if(\"fixed\"!==t.arrangement){t.interactionState.dragInProgress=!1;for(var e=0;e<t.node.childrenNodes.length;e++)t.node.childrenNodes[e].x=t.node.x,t.node.childrenNodes[e].y=t.node.y;\"snap\"!==t.arrangement&&z(t,a)}});t.on(\".drag\",null).call(o)}function z(t,e){for(var r=[],n=[],i=0;i<t.graph.nodes.length;i++){var a=(t.graph.nodes[i].x0+t.graph.nodes[i].x1)/2,o=(t.graph.nodes[i].y0+t.graph.nodes[i].y1)/2;r.push(a/t.figure.width),n.push(o/t.figure.height)}m.call(\"_guiRestyle\",e,{\"node.x\":[r],\"node.y\":[n]},t.trace.index).then(function(){e._fullLayout._dragCover&&e._fullLayout._dragCover.remove()})}function I(t){t.lastDraggedX=t.x0+t.dx/2,t.lastDraggedY=t.y0+t.dy/2}function D(t){return function(e){return e.node.originalX===t.node.originalX}}e.exports=function(t,e,r,u,f){var v=!1;h.ensureSingle(t._fullLayout._infolayer,\"g\",\"first-render\",function(){v=!0});var m=t._fullLayout._dragCover,b=r.filter(function(t){return g(t).trace.visible}).map(function(t,e,r){var i,o=g(e),s=o.trace,u=s.domain,f=\"h\"===s.orientation,p=s.node.pad,d=s.node.thickness,v=t.width*(u.x[1]-u.x[0]),m=t.height*(u.y[1]-u.y[0]),y=o._nodes,x=o._links,b=o.circular;(i=b?c.sankeyCircular().circularLinkGap(0):l.sankey()).iterations(n.sankeyIterations).size(f?[v,m]:[m,v]).nodeWidth(d).nodePadding(p).nodeId(function(t){return t.pointNumber}).nodes(y).links(x);var _,w,k,T=i();for(var A in i.nodePadding()<p&&h.warn(\"node.pad was reduced to \",i.nodePadding(),\" to fit within the figure.\"),o._groupLookup){var M,S=parseInt(o._groupLookup[A]);for(_=0;_<T.nodes.length;_++)if(T.nodes[_].pointNumber===S){M=T.nodes[_];break}if(M){var E={pointNumber:parseInt(A),x0:M.x0,x1:M.x1,y0:M.y0,y1:M.y1,partOfGroup:!0,sourceLinks:[],targetLinks:[]};T.nodes.unshift(E),M.childrenNodes.unshift(E)}}if(function(){for(_=0;_<T.nodes.length;_++){var t,e,r=T.nodes[_],n={};for(w=0;w<r.targetLinks.length;w++)t=(e=r.targetLinks[w]).source.pointNumber+\":\"+e.target.pointNumber,n.hasOwnProperty(t)||(n[t]=[]),n[t].push(e);var i=Object.keys(n);for(w=0;w<i.length;w++){var o=n[t=i[w]],s=0,l={};for(k=0;k<o.length;k++)l[(e=o[k]).label]||(l[e.label]=0),l[e.label]+=e.value,s+=e.value;for(k=0;k<o.length;k++)(e=o[k]).flow={value:s,labelConcentration:l[e.label]/s,concentration:e.value/s,links:o},e.concentrationscale&&(e.color=a(e.concentrationscale(e.flow.labelConcentration)))}var c=0;for(w=0;w<r.sourceLinks.length;w++)c+=r.sourceLinks[w].value;for(w=0;w<r.sourceLinks.length;w++)(e=r.sourceLinks[w]).concentrationOut=e.value/c;var u=0;for(w=0;w<r.targetLinks.length;w++)u+=r.targetLinks[w].value;for(w=0;w<r.targetLinks.length;w++)(e=r.targetLinks[w]).concenrationIn=e.value/u}}(),s.node.x.length&&s.node.y.length){for(_=0;_<Math.min(s.node.x.length,s.node.y.length,T.nodes.length);_++)if(s.node.x[_]&&s.node.y[_]){var C=[s.node.x[_]*v,s.node.y[_]*m];T.nodes[_].x0=C[0]-d/2,T.nodes[_].x1=C[0]+d/2;var L=T.nodes[_].y1-T.nodes[_].y0;T.nodes[_].y0=C[1]-L/2,T.nodes[_].y1=C[1]+L/2}\"snap\"===s.arrangement&&function(t){t.forEach(function(t){var e,r,n,i=0,a=t.length;for(t.sort(function(t,e){return t.y0-e.y0}),n=0;n<a;++n)(e=t[n]).y0>=i||(r=i-e.y0)>1e-6&&(e.y0+=r,e.y1+=r),i=e.y1+p})}(function(t){var e,r,n=t.map(function(t,e){return{x0:t.x0,index:e}}).sort(function(t,e){return t.x0-e.x0}),i=[],a=-1,o=-1/0;for(_=0;_<n.length;_++){var s=t[n[_].index];s.x0>o+d&&(a+=1,e=s.x0),o=s.x0,i[a]||(i[a]=[]),i[a].push(s),r=e-s.x0,s.x0+=r,s.x1+=r}return i}(y=T.nodes)),i.update(T)}return{circular:b,key:r,trace:s,guid:h.randstr(),horizontal:f,width:v,height:m,nodePad:s.node.pad,nodeLineColor:s.node.line.color,nodeLineWidth:s.node.line.width,linkLineColor:s.link.line.color,linkLineWidth:s.link.line.width,valueFormat:s.valueformat,valueSuffix:s.valuesuffix,textFont:s.textfont,translateX:u.x[0]*t.width+t.margin.l,translateY:t.height-u.y[1]*t.height+t.margin.t,dragParallel:f?m:v,dragPerpendicular:f?v:m,arrangement:s.arrangement,sankey:i,graph:T,forceLayouts:{},interactionState:{dragInProgress:!1,hovered:!1}}}.bind(null,u)),_=e.selectAll(\".\"+n.cn.sankey).data(b,p);_.exit().remove(),_.enter().append(\"g\").classed(n.cn.sankey,!0).style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"shape-rendering\",\"geometricPrecision\").style(\"pointer-events\",\"auto\").attr(\"transform\",T),_.each(function(e,r){t._fullData[r]._sankey=e;var n=\"bgsankey-\"+e.trace.uid+\"-\"+r;h.ensureSingle(t._fullLayout._draggers,\"rect\",n),t._fullData[r]._bgRect=i.select(\".\"+n),t._fullData[r]._bgRect.style(\"pointer-events\",\"all\").attr(\"width\",e.width).attr(\"height\",e.height).attr(\"x\",e.translateX).attr(\"y\",e.translateY).classed(\"bgsankey\",!0).style({fill:\"transparent\",\"stroke-width\":0})}),_.transition().ease(n.ease).duration(n.duration).attr(\"transform\",T);var z=_.selectAll(\".\"+n.cn.sankeyLinks).data(d,p);z.enter().append(\"g\").classed(n.cn.sankeyLinks,!0).style(\"fill\",\"none\");var I=z.selectAll(\".\"+n.cn.sankeyLink).data(function(t){return t.graph.links.filter(function(t){return t.value}).map(function(t,e,r){var n=a(e.color),i=e.source.label+\"|\"+e.target.label+\"__\"+r;return e.trace=t.trace,e.curveNumber=t.trace.index,{circular:t.circular,key:i,traceId:t.key,pointNumber:e.pointNumber,link:e,tinyColorHue:o.tinyRGB(n),tinyColorAlpha:n.getAlpha(),linkPath:y,linkLineColor:t.linkLineColor,linkLineWidth:t.linkLineWidth,valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,parent:t,interactionState:t.interactionState,flow:e.flow}}.bind(null,t))},p);I.enter().append(\"path\").classed(n.cn.sankeyLink,!0).call(P,_,f.linkEvents),I.style(\"stroke\",function(t){return k(t)?o.tinyRGB(a(t.linkLineColor)):t.tinyColorHue}).style(\"stroke-opacity\",function(t){return k(t)?o.opacity(t.linkLineColor):t.tinyColorAlpha}).style(\"fill\",function(t){return t.tinyColorHue}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}).style(\"stroke-width\",function(t){return k(t)?t.linkLineWidth:1}).attr(\"d\",y()),I.style(\"opacity\",function(){return t._context.staticPlot||v||m?1:0}).transition().ease(n.ease).duration(n.duration).style(\"opacity\",1),I.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var D=_.selectAll(\".\"+n.cn.sankeyNodeSet).data(d,p);D.enter().append(\"g\").classed(n.cn.sankeyNodeSet,!0),D.style(\"cursor\",function(t){switch(t.arrangement){case\"fixed\":return\"default\";case\"perpendicular\":return\"ns-resize\";default:return\"move\"}});var R=D.selectAll(\".\"+n.cn.sankeyNode).data(function(t){var e=t.graph.nodes;return function(t){var e,r=[];for(e=0;e<t.length;e++)t[e].originalX=(t[e].x0+t[e].x1)/2,t[e].originalY=(t[e].y0+t[e].y1)/2,-1===r.indexOf(t[e].originalX)&&r.push(t[e].originalX);for(r.sort(function(t,e){return t-e}),e=0;e<t.length;e++)t[e].originalLayerIndex=r.indexOf(t[e].originalX),t[e].originalLayer=t[e].originalLayerIndex/(r.length-1)}(e),e.map(function(t,e){var r=a(e.color),i=n.nodePadAcross,s=t.nodePad/2;e.dx=e.x1-e.x0,e.dy=e.y1-e.y0;var l=e.dx,c=Math.max(.5,e.dy),u=\"node_\"+e.pointNumber;return e.group&&(u=h.randstr()),e.trace=t.trace,e.curveNumber=t.trace.index,{index:e.pointNumber,key:u,partOfGroup:e.partOfGroup||!1,group:e.group,traceId:t.key,trace:t.trace,node:e,nodePad:t.nodePad,nodeLineColor:t.nodeLineColor,nodeLineWidth:t.nodeLineWidth,textFont:t.textFont,size:t.horizontal?t.height:t.width,visibleWidth:Math.ceil(l),visibleHeight:c,zoneX:-i,zoneY:-s,zoneWidth:l+2*i,zoneHeight:c+2*s,labelY:t.horizontal?e.dy/2+1:e.dx/2+1,left:1===e.originalLayer,sizeAcross:t.width,forceLayouts:t.forceLayouts,horizontal:t.horizontal,darkBackground:r.getBrightness()<=128,tinyColorHue:o.tinyRGB(r),tinyColorAlpha:r.getAlpha(),valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,graph:t.graph,arrangement:t.arrangement,uniqueNodeLabelPathId:[t.guid,t.key,u].join(\"_\"),interactionState:t.interactionState,figure:t}}.bind(null,t))},p);R.enter().append(\"g\").classed(n.cn.sankeyNode,!0).call(x).style(\"opacity\",function(e){return!t._context.staticPlot&&!v||e.partOfGroup?0:1}),R.call(P,_,f.nodeEvents).call(O,I,f,t),R.transition().ease(n.ease).duration(n.duration).call(x).style(\"opacity\",function(t){return t.partOfGroup?0:1}),R.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var F=R.selectAll(\".\"+n.cn.nodeRect).data(d);F.enter().append(\"rect\").classed(n.cn.nodeRect,!0).call(w),F.style(\"stroke-width\",function(t){return t.nodeLineWidth}).style(\"stroke\",function(t){return o.tinyRGB(a(t.nodeLineColor))}).style(\"stroke-opacity\",function(t){return o.opacity(t.nodeLineColor)}).style(\"fill\",function(t){return t.tinyColorHue}).style(\"fill-opacity\",function(t){return t.tinyColorAlpha}),F.transition().ease(n.ease).duration(n.duration).call(w);var B=R.selectAll(\".\"+n.cn.nodeCapture).data(d);B.enter().append(\"rect\").classed(n.cn.nodeCapture,!0).style(\"fill-opacity\",0),B.attr(\"x\",function(t){return t.zoneX}).attr(\"y\",function(t){return t.zoneY}).attr(\"width\",function(t){return t.zoneWidth}).attr(\"height\",function(t){return t.zoneHeight});var N=R.selectAll(\".\"+n.cn.nodeCentered).data(d);N.enter().append(\"g\").classed(n.cn.nodeCentered,!0).attr(\"transform\",A),N.transition().ease(n.ease).duration(n.duration).attr(\"transform\",A);var j=N.selectAll(\".\"+n.cn.nodeLabelGuide).data(d);j.enter().append(\"path\").classed(n.cn.nodeLabelGuide,!0).attr(\"id\",function(t){return t.uniqueNodeLabelPathId}).attr(\"d\",M).attr(\"transform\",S),j.transition().ease(n.ease).duration(n.duration).attr(\"d\",M).attr(\"transform\",S);var U=N.selectAll(\".\"+n.cn.nodeLabel).data(d);U.enter().append(\"text\").classed(n.cn.nodeLabel,!0).attr(\"transform\",E).style(\"user-select\",\"none\").style(\"cursor\",\"default\").style(\"fill\",\"black\"),U.style(\"text-shadow\",function(t){return t.horizontal?\"-1px 1px 1px #fff, 1px 1px 1px #fff, 1px -1px 1px #fff, -1px -1px 1px #fff\":\"none\"}).each(function(t){s.font(U,t.textFont)}),U.transition().ease(n.ease).duration(n.duration).attr(\"transform\",E);var V=U.selectAll(\".\"+n.cn.nodeLabelTextPath).data(d);V.enter().append(\"textPath\").classed(n.cn.nodeLabelTextPath,!0).attr(\"alignment-baseline\",\"middle\").attr(\"xlink:href\",function(t){return\"#\"+t.uniqueNodeLabelPathId}).attr(\"startOffset\",L).style(\"fill\",C),V.text(function(t){return t.horizontal||t.node.dy>5?t.node.label:\"\"}).attr(\"text-anchor\",function(t){return t.horizontal&&t.left?\"end\":\"start\"}),V.transition().ease(n.ease).duration(n.duration).attr(\"startOffset\",L).style(\"fill\",C)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/gup\":717,\"../../registry\":847,\"./constants\":1105,\"@plotly/d3-sankey\":54,\"@plotly/d3-sankey-circular\":53,d3:163,\"d3-force\":156,\"d3-interpolate\":158,tinycolor2:537}],1110:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=[],n=t.cd[0].trace,i=n._sankey.graph.nodes,a=0;a<i.length;a++){var o=i[a];if(!o.partOfGroup){var s=[(o.x0+o.x1)/2,(o.y0+o.y1)/2];\"v\"===n.orientation&&s.reverse(),e&&e.contains(s,!1,a,t)&&r.push({pointNumber:o.pointNumber})}}return r}},{}],1111:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\"),n.mergeArray(e.customdata,t,\"data\"),n.mergeArray(e.textposition,t,\"tp\"),e.textfont&&(n.mergeArrayCastPositive(e.textfont.size,t,\"ts\"),n.mergeArray(e.textfont.color,t,\"tc\"),n.mergeArray(e.textfont.family,t,\"tf\"));var i=e.marker;if(i){n.mergeArrayCastPositive(i.size,t,\"ms\"),n.mergeArrayCastPositive(i.opacity,t,\"mo\"),n.mergeArray(i.symbol,t,\"mx\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;i.line&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"));var o=i.gradient;o&&\"none\"!==o.type&&(n.mergeArray(o.type,t,\"mgt\"),n.mergeArray(o.color,t,\"mgc\"))}}},{\"../../lib\":719}],1112:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../components/drawing/attributes\").dash,s=t(\"../../components/drawing\"),l=t(\"./constants\"),c=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},x0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dx:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},y0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dy:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},stackgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc\"},groupnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},stackgaps:{valType:\"enumerated\",values:[\"infer zero\",\"interpolate\"],dflt:\"infer zero\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"],editType:\"calc\"},hoveron:{valType:\"flaglist\",flags:[\"points\",\"fills\"],editType:\"style\"},hovertemplate:n({},{keys:l.eventDataKeys}),line:{color:{valType:\"color\",editType:\"style\",anim:!0},width:{valType:\"number\",min:0,dflt:2,editType:\"style\",anim:!0},shape:{valType:\"enumerated\",values:[\"linear\",\"spline\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},smoothing:{valType:\"number\",min:0,max:1.3,dflt:1,editType:\"plot\"},dash:c({},o,{editType:\"style\"}),simplify:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cliponaxis:{valType:\"boolean\",dflt:!0,editType:\"plot\"},fill:{valType:\"enumerated\",values:[\"none\",\"tozeroy\",\"tozerox\",\"tonexty\",\"tonextx\",\"toself\",\"tonext\"],editType:\"calc\"},fillcolor:{valType:\"color\",editType:\"style\",anim:!0},marker:c({symbol:{valType:\"enumerated\",values:s.symbolList,dflt:\"circle\",arrayOk:!0,editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,arrayOk:!0,editType:\"style\",anim:!0},size:{valType:\"number\",min:0,dflt:6,arrayOk:!0,editType:\"calc\",anim:!0},maxdisplayed:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},sizeref:{valType:\"number\",dflt:1,editType:\"calc\"},sizemin:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"diameter\",\"area\"],dflt:\"diameter\",editType:\"calc\"},line:c({width:{valType:\"number\",min:0,arrayOk:!0,editType:\"style\",anim:!0},editType:\"calc\"},i(\"marker.line\",{anim:!0})),gradient:{type:{valType:\"enumerated\",values:[\"radial\",\"horizontal\",\"vertical\",\"none\"],arrayOk:!0,dflt:\"none\",editType:\"calc\"},color:{valType:\"color\",arrayOk:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},i(\"marker\",{anim:!0})),selected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},unselected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\"],dflt:\"middle center\",arrayOk:!0,editType:\"calc\"},textfont:a({editType:\"calc\",colorEditType:\"style\",arrayOk:!0}),r:{valType:\"data_array\",editType:\"calc\"},t:{valType:\"data_array\",editType:\"calc\"}}},{\"../../components/colorscale/attributes\":600,\"../../components/drawing\":614,\"../../components/drawing/attributes\":613,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/font_attributes\":793,\"./constants\":1116}],1113:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../constants/numerical\").BADNUM,s=t(\"./subtypes\"),l=t(\"./colorscale_calc\"),c=t(\"./arrays_to_calcdata\"),u=t(\"./calc_selection\");function h(t,e,r,n,i,o,l){var c=e._length,u=t._fullLayout,h=r._id,f=n._id,p=u._firstScatter[d(e)]===e.uid,v=(g(e,u,r,n)||{}).orientation,m=e.fill;r._minDtick=0,n._minDtick=0;var y={padded:!0},x={padded:!0};l&&(y.ppad=x.ppad=l);var b=c<2||i[0]!==i[c-1]||o[0]!==o[c-1];b&&(\"tozerox\"===m||\"tonextx\"===m&&(p||\"h\"===v))?y.tozero=!0:(e.error_y||{}).visible||\"tonexty\"!==m&&\"tozeroy\"!==m&&(s.hasMarkers(e)||s.hasText(e))||(y.padded=!1,y.ppad=0),b&&(\"tozeroy\"===m||\"tonexty\"===m&&(p||\"v\"===v))?x.tozero=!0:\"tonextx\"!==m&&\"tozerox\"!==m||(x.padded=!1),h&&(e._extremes[h]=a.findExtremes(r,i,y)),f&&(e._extremes[f]=a.findExtremes(n,o,x))}function f(t,e){if(s.hasMarkers(t)){var r,n=t.marker,o=1.6*(t.marker.sizeref||1);if(r=\"area\"===t.marker.sizemode?function(t){return Math.max(Math.sqrt((t||0)/o),3)}:function(t){return Math.max((t||0)/o,3)},i.isArrayOrTypedArray(n.size)){var l={type:\"linear\"};a.setConvert(l);for(var c=l.makeCalcdata(t.marker,\"size\"),u=new Array(e),h=0;h<e;h++)u[h]=r(c[h]);return u}return r(n.size)}}function p(t,e){var r=d(e),n=t._firstScatter;n[r]||(n[r]=e.uid)}function d(t){var e=t.stackgroup;return t.xaxis+t.yaxis+t.type+(e?\"-\"+e:\"\")}function g(t,e,r,n){var i=t.stackgroup;if(i){var a=e._scatterStackOpts[r._id+n._id][i],o=\"v\"===a.orientation?n:r;return\"linear\"===o.type||\"log\"===o.type?a:void 0}}e.exports={calc:function(t,e){var r,s,d,v,m,y,x=t._fullLayout,b=a.getFromId(t,e.xaxis||\"x\"),_=a.getFromId(t,e.yaxis||\"y\"),w=b.makeCalcdata(e,\"x\"),k=_.makeCalcdata(e,\"y\"),T=e._length,A=new Array(T),M=e.ids,S=g(e,x,b,_),E=!1;p(x,e);var C,L=\"x\",P=\"y\";for(S?(i.pushUnique(S.traceIndices,e._expandedIndex),(r=\"v\"===S.orientation)?(P=\"s\",C=\"x\"):(L=\"s\",C=\"y\"),m=\"interpolate\"===S.stackgaps):h(t,e,b,_,w,k,f(e,T)),s=0;s<T;s++){var O=A[s]={},z=n(w[s]),I=n(k[s]);z&&I?(O[L]=w[s],O[P]=k[s]):S&&(r?z:I)?(O[C]=r?w[s]:k[s],O.gap=!0,m?(O.s=o,E=!0):O.s=0):O[L]=O[P]=o,M&&(O.id=String(M[s]))}if(c(A,e),l(t,e),u(A,e),S){for(s=0;s<A.length;)A[s][C]===o?A.splice(s,1):s++;if(i.sort(A,function(t,e){return t[C]-e[C]||t.i-e.i}),E){for(s=0;s<A.length-1&&A[s].gap;)s++;for((y=A[s].s)||(y=A[s].s=0),d=0;d<s;d++)A[d].s=y;for(v=A.length-1;v>s&&A[v].gap;)v--;for(y=A[v].s,d=A.length-1;d>v;d--)A[d].s=y;for(;s<v;)if(A[++s].gap){for(d=s+1;A[d].gap;)d++;for(var D=A[s-1][C],R=A[s-1].s,F=(A[d].s-R)/(A[d][C]-D);s<d;)A[s].s=R+(A[s][C]-D)*F,s++}}}return A},calcMarkerSize:f,calcAxisExpansion:h,setFirstScatter:p,getStackOpts:g}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"./arrays_to_calcdata\":1111,\"./calc_selection\":1114,\"./colorscale_calc\":1115,\"./subtypes\":1135,\"fast-isnumeric\":225}],1114:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){n.isArrayOrTypedArray(e.selectedpoints)&&n.tagSelected(t,e)}},{\"../../lib\":719}],1115:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"./subtypes\");e.exports=function(t,e){a.hasLines(e)&&n(e,\"line\")&&i(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),a.hasMarkers(e)&&(n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}))}},{\"../../components/colorscale/calc\":601,\"../../components/colorscale/helpers\":604,\"./subtypes\":1135}],1116:[function(t,e,r){\"use strict\";e.exports={PTS_LINESONLY:20,minTolerance:.2,toleranceGrowth:10,maxScreensAway:20,eventDataKeys:[]}},{}],1117:[function(t,e,r){\"use strict\";var n=t(\"./calc\");function i(t,e,r,n,i,a,o){i[n]=!0;var s={i:null,gap:!0,s:0};if(s[o]=r,t.splice(e,0,s),e&&r===t[e-1][o]){var l=t[e-1];s.s=l.s,s.i=l.i,s.gap=l.gap}else a&&(s.s=function(t,e,r,n){var i=t[e-1],a=t[e+1];return a?i?i.s+(a.s-i.s)*(r-i[n])/(a[n]-i[n]):a.s:i.s}(t,e,r,o));e||(t[0].t=t[1].t,t[0].trace=t[1].trace,delete t[1].t,delete t[1].trace)}e.exports=function(t,e){var r=e.xaxis,a=e.yaxis,o=r._id+a._id,s=t._fullLayout._scatterStackOpts[o];if(s){var l,c,u,h,f,p,d,g,v,m,y,x,b,_,w,k=t.calcdata;for(var T in s){var A=(m=s[T]).traceIndices;if(A.length){for(y=\"interpolate\"===m.stackgaps,x=m.groupnorm,\"v\"===m.orientation?(b=\"x\",_=\"y\"):(b=\"y\",_=\"x\"),w=new Array(A.length),l=0;l<w.length;l++)w[l]=!1;p=k[A[0]];var M=new Array(p.length);for(l=0;l<p.length;l++)M[l]=p[l][b];for(l=1;l<A.length;l++){for(f=k[A[l]],c=u=0;c<f.length;c++){for(d=f[c][b];d>M[u]&&u<M.length;u++)i(f,c,M[u],l,w,y,b),c++;if(d!==M[u]){for(h=0;h<l;h++)i(k[A[h]],u,d,h,w,y,b);M.splice(u,0,d)}u++}for(;u<M.length;u++)i(f,c,M[u],l,w,y,b),c++}var S=M.length;for(c=0;c<p.length;c++){for(g=p[c][_]=p[c].s,l=1;l<A.length;l++)(f=k[A[l]])[0].trace._rawLength=f[0].trace._length,f[0].trace._length=S,g+=f[c].s,f[c][_]=g;if(x)for(v=(\"fraction\"===x?g:g/100)||1,l=0;l<A.length;l++){var E=k[A[l]][c];E[_]/=v,E.sNorm=E.s/v}}for(l=0;l<A.length;l++){var C=(f=k[A[l]])[0].trace,L=n.calcMarkerSize(C,C._rawLength),P=Array.isArray(L);if(L&&w[l]||P){var O=L;for(L=new Array(S),c=0;c<S;c++)L[c]=f[c].gap?0:P?O[f[c].i]:O}var z=new Array(S),I=new Array(S);for(c=0;c<S;c++)z[c]=f[c].x,I[c]=f[c].y;n.calcAxisExpansion(t,C,r,a,z,I,L),f[0].t.orientation=m.orientation}}}}}},{\"./calc\":1113}],1118:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0;e<t.length;e++){var r=t[e];if(\"scatter\"===r.type){var n=r.fill;if(\"none\"!==n&&\"toself\"!==n&&(r.opacity=void 0,\"tonexty\"===n||\"tonextx\"===n))for(var i=e-1;i>=0;i--){var a=t[i];if(\"scatter\"===a.type&&a.xaxis===r.xaxis&&a.yaxis===r.yaxis){a.opacity=void 0;break}}}}}},{}],1119:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"./constants\"),s=t(\"./subtypes\"),l=t(\"./xy_defaults\"),c=t(\"./stack_defaults\"),u=t(\"./marker_defaults\"),h=t(\"./line_defaults\"),f=t(\"./line_shape_defaults\"),p=t(\"./text_defaults\"),d=t(\"./fillcolor_defaults\");e.exports=function(t,e,r,g){function v(r,i){return n.coerce(t,e,a,r,i)}var m=l(t,e,g,v);if(m||(e.visible=!1),e.visible){var y=c(t,e,g,v),x=!y&&m<o.PTS_LINESONLY?\"lines+markers\":\"lines\";v(\"text\"),v(\"hovertext\"),v(\"mode\",x),s.hasLines(e)&&(h(t,e,r,g,v),f(t,e,v),v(\"connectgaps\"),v(\"line.simplify\")),s.hasMarkers(e)&&u(t,e,r,g,v,{gradient:!0}),s.hasText(e)&&p(t,e,g,v);var b=[];(s.hasMarkers(e)||s.hasText(e))&&(v(\"cliponaxis\"),v(\"marker.maxdisplayed\"),b.push(\"points\")),v(\"fill\",y?y.fillDflt:\"none\"),\"none\"!==e.fill&&(d(t,e,r,v),s.hasLines(e)||f(t,e,v));var _=(e.line||{}).color,w=(e.marker||{}).color;\"tonext\"!==e.fill&&\"toself\"!==e.fill||b.push(\"fills\"),v(\"hoveron\",b.join(\"+\")||\"points\"),\"fills\"!==e.hoveron&&v(\"hovertemplate\");var k=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");k(t,e,_||w||r,{axis:\"y\"}),k(t,e,_||w||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,v)}}},{\"../../lib\":719,\"../../registry\":847,\"./attributes\":1112,\"./constants\":1116,\"./fillcolor_defaults\":1120,\"./line_defaults\":1124,\"./line_shape_defaults\":1126,\"./marker_defaults\":1130,\"./stack_defaults\":1133,\"./subtypes\":1135,\"./text_defaults\":1136,\"./xy_defaults\":1137}],1120:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a){var o=!1;if(e.marker){var s=e.marker.color,l=(e.marker.line||{}).color;s&&!i(s)?o=s:l&&!i(l)&&(o=l)}a(\"fillcolor\",n.addOpacity((e.line||{}).color||o||r,.5))}},{\"../../components/color\":593,\"../../lib\":719}],1121:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./subtypes\");e.exports=function(t,e){var r,a;if(\"lines\"===t.mode)return(r=t.line.color)&&n.opacity(r)?r:t.fillcolor;if(\"none\"===t.mode)return t.fill?t.fillcolor:\"\";var o=e.mcc||(t.marker||{}).color,s=e.mlcc||((t.marker||{}).line||{}).color;return(a=o&&n.opacity(o)?o:s&&n.opacity(s)&&(e.mlw||((t.marker||{}).line||{}).width)?s:\"\")?n.opacity(a)<.3?n.addOpacity(a,.3):a:(r=(t.line||{}).color)&&n.opacity(r)&&i.hasLines(t)&&t.line.width?r:t.fillcolor}},{\"../../components/color\":593,\"./subtypes\":1135}],1122:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/fx\"),a=t(\"../../registry\"),o=t(\"./get_trace_color\"),s=t(\"../../components/color\"),l=n.fillText;e.exports=function(t,e,r,c){var u=t.cd,h=u[0].trace,f=t.xa,p=t.ya,d=f.c2p(e),g=p.c2p(r),v=[d,g],m=h.hoveron||\"\",y=-1!==h.mode.indexOf(\"markers\")?3:.5;if(-1!==m.indexOf(\"points\")){var x=function(t){var e=Math.max(y,t.mrc||0),r=f.c2p(t.x)-d,n=p.c2p(t.y)-g;return Math.max(Math.sqrt(r*r+n*n)-e,1-y/e)},b=i.getDistanceFunction(c,function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(f.c2p(t.x)-d);return n<e?r*n/e:n-e+r},function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(p.c2p(t.y)-g);return n<e?r*n/e:n-e+r},x);if(i.getClosest(u,b,t),!1!==t.index){var _=u[t.index],w=f.c2p(_.x,!0),k=p.c2p(_.y,!0),T=_.mrc||1;t.index=_.i;var A=u[0].t.orientation,M=A&&(_.sNorm||_.s),S=\"h\"===A?M:_.x,E=\"v\"===A?M:_.y;return n.extendFlat(t,{color:o(h,_),x0:w-T,x1:w+T,xLabelVal:S,y0:k-T,y1:k+T,yLabelVal:E,spikeDistance:x(_),hovertemplate:h.hovertemplate}),l(_,h,t),a.getComponentMethod(\"errorbars\",\"hoverInfo\")(_,h,t),[t]}}if(-1!==m.indexOf(\"fills\")&&h._polygons){var C,L,P,O,z,I,D,R,F,B=h._polygons,N=[],j=!1,U=1/0,V=-1/0,q=1/0,H=-1/0;for(C=0;C<B.length;C++)(P=B[C]).contains(v)&&(j=!j,N.push(P),q=Math.min(q,P.ymin),H=Math.max(H,P.ymax));if(j){var G=((q=Math.max(q,0))+(H=Math.min(H,p._length)))/2;for(C=0;C<N.length;C++)for(O=N[C].pts,L=1;L<O.length;L++)(R=O[L-1][1])>G!=(F=O[L][1])>=G&&(I=O[L-1][0],D=O[L][0],F-R&&(z=I+(D-I)*(G-R)/(F-R),U=Math.min(U,z),V=Math.max(V,z)));U=Math.max(U,0),V=Math.min(V,f._length);var Y=s.defaultLine;return s.opacity(h.fillcolor)?Y=h.fillcolor:s.opacity((h.line||{}).color)&&(Y=h.line.color),n.extendFlat(t,{distance:t.maxHoverDistance,x0:U,x1:V,y0:G,y1:G,color:Y,hovertemplate:!1}),delete t.index,h.text&&!Array.isArray(h.text)?t.text=String(h.text):t.text=h.name,[t]}}}},{\"../../components/color\":593,\"../../components/fx\":632,\"../../lib\":719,\"../../registry\":847,\"./get_trace_color\":1121}],1123:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports={hasLines:n.hasLines,hasMarkers:n.hasMarkers,hasText:n.hasText,isBubble:n.isBubble,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./cross_trace_calc\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\"),colorbar:t(\"./marker_colorbar\"),style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"./select\"),animatable:!0,moduleType:\"trace\",name:\"scatter\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"./arrays_to_calcdata\":1111,\"./attributes\":1112,\"./calc\":1113,\"./cross_trace_calc\":1117,\"./cross_trace_defaults\":1118,\"./defaults\":1119,\"./hover\":1122,\"./marker_colorbar\":1129,\"./plot\":1131,\"./select\":1132,\"./style\":1134,\"./subtypes\":1135}],1124:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s,l){var c=(t.marker||{}).color;(s(\"line.color\",r),i(t,\"line\"))?a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}):s(\"line.color\",!n(c)&&c||r);s(\"line.width\"),(l||{}).noDash||s(\"line.dash\")}},{\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"../../lib\":719}],1125:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.BADNUM,a=n.LOG_CLIP,o=a+.5,s=a-.5,l=t(\"../../lib\"),c=l.segmentsIntersect,u=l.constrain,h=t(\"./constants\");e.exports=function(t,e){var r,n,a,f,p,d,g,v,m,y,x,b,_,w,k,T,A,M,S=e.xaxis,E=e.yaxis,C=\"log\"===S.type,L=\"log\"===E.type,P=S._length,O=E._length,z=e.connectGaps,I=e.baseTolerance,D=e.shape,R=\"linear\"===D,F=e.fill&&\"none\"!==e.fill,B=[],N=h.minTolerance,j=t.length,U=new Array(j),V=0;function q(e){var r=t[e];if(!r)return!1;var n=S.c2p(r.x),a=E.c2p(r.y);if(n===i){if(C&&(n=S.c2p(r.x,!0)),n===i)return!1;L&&a===i&&(n*=Math.abs(S._m*O*(S._m>0?o:s)/(E._m*P*(E._m>0?o:s)))),n*=1e3}if(a===i){if(L&&(a=E.c2p(r.y,!0)),a===i)return!1;a*=1e3}return[n,a]}function H(t,e,r,n){var i=r-t,a=n-e,o=.5-t,s=.5-e,l=i*i+a*a,c=i*o+a*s;if(c>0&&c<l){var u=o*a-s*i;if(u*u<l)return!0}}function G(t,e){var r=t[0]/P,n=t[1]/O,i=Math.max(0,-r,r-1,-n,n-1);return i&&void 0!==A&&H(r,n,A,M)&&(i=0),i&&e&&H(r,n,e[0]/P,e[1]/O)&&(i=0),(1+h.toleranceGrowth*i)*I}function Y(t,e){var r=t[0]-e[0],n=t[1]-e[1];return Math.sqrt(r*r+n*n)}var W,X,Z,J,K,$,Q,tt=h.maxScreensAway,et=-P*tt,rt=P*(1+tt),nt=-O*tt,it=O*(1+tt),at=[[et,nt,rt,nt],[rt,nt,rt,it],[rt,it,et,it],[et,it,et,nt]];function ot(t){if(t[0]<et||t[0]>rt||t[1]<nt||t[1]>it)return[u(t[0],et,rt),u(t[1],nt,it)]}function st(t,e){return t[0]===e[0]&&(t[0]===et||t[0]===rt)||(t[1]===e[1]&&(t[1]===nt||t[1]===it)||void 0)}function lt(t,e,r){return function(n,i){var a=ot(n),o=ot(i),s=[];if(a&&o&&st(a,o))return s;a&&s.push(a),o&&s.push(o);var c=2*l.constrain((n[t]+i[t])/2,e,r)-((a||n)[t]+(o||i)[t]);c&&((a&&o?c>0==a[t]>o[t]?a:o:a||o)[t]+=c);return s}}function ct(t){var e=t[0],r=t[1],n=e===U[V-1][0],i=r===U[V-1][1];if(!n||!i)if(V>1){var a=e===U[V-2][0],o=r===U[V-2][1];n&&(e===et||e===rt)&&a?o?V--:U[V-1]=t:i&&(r===nt||r===it)&&o?a?V--:U[V-1]=t:U[V++]=t}else U[V++]=t}function ut(t){U[V-1][0]!==t[0]&&U[V-1][1]!==t[1]&&ct([Z,J]),ct(t),K=null,Z=J=0}function ht(t){if(A=t[0]/P,M=t[1]/O,W=t[0]<et?et:t[0]>rt?rt:0,X=t[1]<nt?nt:t[1]>it?it:0,W||X){if(V)if(K){var e=Q(K,t);e.length>1&&(ut(e[0]),U[V++]=e[1])}else $=Q(U[V-1],t)[0],U[V++]=$;else U[V++]=[W||t[0],X||t[1]];var r=U[V-1];W&&X&&(r[0]!==W||r[1]!==X)?(K&&(Z!==W&&J!==X?ct(Z&&J?(n=K,a=(i=t)[0]-n[0],o=(i[1]-n[1])/a,(n[1]*i[0]-i[1]*n[0])/a>0?[o>0?et:rt,it]:[o>0?rt:et,nt]):[Z||W,J||X]):Z&&J&&ct([Z,J])),ct([W,X])):Z-W&&J-X&&ct([W||Z,X||J]),K=t,Z=W,J=X}else K&&ut(Q(K,t)[0]),U[V++]=t;var n,i,a,o}for(\"linear\"===D||\"spline\"===D?Q=function(t,e){for(var r=[],n=0,i=0;i<4;i++){var a=at[i],o=c(t[0],t[1],e[0],e[1],a[0],a[1],a[2],a[3]);o&&(!n||Math.abs(o.x-r[0][0])>1||Math.abs(o.y-r[0][1])>1)&&(o=[o.x,o.y],n&&Y(o,t)<Y(r[0],t)?r.unshift(o):r.push(o),n++)}return r}:\"hv\"===D||\"vh\"===D?Q=function(t,e){var r=[],n=ot(t),i=ot(e);return n&&i&&st(n,i)?r:(n&&r.push(n),i&&r.push(i),r)}:\"hvh\"===D?Q=lt(0,et,rt):\"vhv\"===D&&(Q=lt(1,nt,it)),r=0;r<j;r++)if(n=q(r)){for(V=0,K=null,ht(n),r++;r<j;r++){if(!(f=q(r))){if(z)continue;break}if(R&&e.simplify){var ft=q(r+1);if(y=Y(f,n),F&&(0===V||V===j-1)||!(y<G(f,ft)*N)){for(v=[(f[0]-n[0])/y,(f[1]-n[1])/y],p=n,x=y,b=w=k=0,g=!1,a=f,r++;r<t.length;r++){if(d=ft,ft=q(r+1),!d){if(z)continue;break}if(T=(m=[d[0]-n[0],d[1]-n[1]])[0]*v[1]-m[1]*v[0],w=Math.min(w,T),(k=Math.max(k,T))-w>G(d,ft))break;a=d,(_=m[0]*v[0]+m[1]*v[1])>x?(x=_,f=d,g=!1):_<b&&(b=_,p=d,g=!0)}if(g?(ht(f),a!==p&&ht(p)):(p!==n&&ht(p),a!==f&&ht(f)),ht(a),r>=t.length||!d)break;ht(d),n=d}}else ht(f)}K&&ct([Z||K[0],J||K[1]]),B.push(U.slice(0,V))}return B}},{\"../../constants/numerical\":695,\"../../lib\":719,\"./constants\":1116}],1126:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){\"spline\"===r(\"line.shape\")&&r(\"line.smoothing\")}},{}],1127:[function(t,e,r){\"use strict\";var n={tonextx:1,tonexty:1,tonext:1};e.exports=function(t,e,r){var i,a,o,s,l,c={},u=!1,h=-1,f=0,p=-1;for(a=0;a<r.length;a++)(o=(i=r[a][0].trace).stackgroup||\"\")?o in c?l=c[o]:(l=c[o]=f,f++):i.fill in n&&p>=0?l=p:(l=p=f,f++),l<h&&(u=!0),i._groupIndex=h=l;var d=r.slice();u&&d.sort(function(t,e){var r=t[0].trace,n=e[0].trace;return r._groupIndex-n._groupIndex||r.index-n.index});var g={};for(a=0;a<d.length;a++)o=(i=d[a][0].trace).stackgroup||\"\",!0===i.visible?(i._nexttrace=null,i.fill in n&&(s=g[o],i._prevtrace=s||null,s&&(s._nexttrace=i)),i._ownfill=i.fill&&(\"tozero\"===i.fill.substr(0,6)||\"toself\"===i.fill||\"to\"===i.fill.substr(0,2)&&!i._prevtrace),g[o]=i):i._prevtrace=i._nexttrace=i._ownfill=null;return d}},{}],1128:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t){var e=t.marker,r=e.sizeref||1,i=e.sizemin||0,a=\"area\"===e.sizemode?function(t){return Math.sqrt(t/r)}:function(t){return t/r};return function(t){var e=a(t/2);return n(e)&&e>0?Math.max(e,i):0}}},{\"fast-isnumeric\":225}],1129:[function(t,e,r){\"use strict\";e.exports={container:\"marker\",min:\"cmin\",max:\"cmax\"}},{}],1130:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"./subtypes\");e.exports=function(t,e,r,s,l,c){var u=o.isBubble(t),h=(t.line||{}).color;(c=c||{},h&&(r=h),l(\"marker.symbol\"),l(\"marker.opacity\",u?.7:1),l(\"marker.size\"),l(\"marker.color\",r),i(t,\"marker\")&&a(t,e,s,l,{prefix:\"marker.\",cLetter:\"c\"}),c.noSelect||(l(\"selected.marker.color\"),l(\"unselected.marker.color\"),l(\"selected.marker.size\"),l(\"unselected.marker.size\")),c.noLine||(l(\"marker.line.color\",h&&!Array.isArray(h)&&e.marker.color!==h?h:u?n.background:n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,l,{prefix:\"marker.line.\",cLetter:\"c\"}),l(\"marker.line.width\",u?1:0)),u&&(l(\"marker.sizeref\"),l(\"marker.sizemin\"),l(\"marker.sizemode\")),c.gradient)&&(\"none\"!==l(\"marker.gradient.type\")&&l(\"marker.gradient.color\"))}},{\"../../components/color\":593,\"../../components/colorscale/defaults\":603,\"../../components/colorscale/helpers\":604,\"./subtypes\":1135}],1131:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=a.ensureSingle,s=a.identity,l=t(\"../../components/drawing\"),c=t(\"./subtypes\"),u=t(\"./line_points\"),h=t(\"./link_traces\"),f=t(\"../../lib/polygon\").tester;function p(t,e,r,h,p,d,g){var v;!function(t,e,r,i,o){var s=r.xaxis,l=r.yaxis,u=n.extent(a.simpleMap(s.range,s.r2c)),h=n.extent(a.simpleMap(l.range,l.r2c)),f=i[0].trace;if(!c.hasMarkers(f))return;var p=f.marker.maxdisplayed;if(0===p)return;var d=i.filter(function(t){return t.x>=u[0]&&t.x<=u[1]&&t.y>=h[0]&&t.y<=h[1]}),g=Math.ceil(d.length/p),v=0;o.forEach(function(t,r){var n=t[0].trace;c.hasMarkers(n)&&n.marker.maxdisplayed>0&&r<e&&v++});var m=Math.round(v*g/3+Math.floor(v/3)*g/7.1);i.forEach(function(t){delete t.vis}),d.forEach(function(t,e){0===Math.round((e+m)%g)&&(t.vis=!0)})}(0,e,r,h,p);var m=!!g&&g.duration>0;function y(t){return m?t.transition():t}var x=r.xaxis,b=r.yaxis,_=h[0].trace,w=_.line,k=n.select(d),T=o(k,\"g\",\"errorbars\"),A=o(k,\"g\",\"lines\"),M=o(k,\"g\",\"points\"),S=o(k,\"g\",\"text\");if(i.getComponentMethod(\"errorbars\",\"plot\")(t,T,r,g),!0===_.visible){var E,C;y(k).style(\"opacity\",_.opacity);var L=_.fill.charAt(_.fill.length-1);\"x\"!==L&&\"y\"!==L&&(L=\"\"),h[0][r.isRangePlot?\"nodeRangePlot3\":\"node3\"]=k;var P,O,z=\"\",I=[],D=_._prevtrace;D&&(z=D._prevRevpath||\"\",C=D._nextFill,I=D._polygons);var R,F,B,N,j,U,V,q=\"\",H=\"\",G=[],Y=a.noop;if(E=_._ownFill,c.hasLines(_)||\"none\"!==_.fill){for(C&&C.datum(h),-1!==[\"hv\",\"vh\",\"hvh\",\"vhv\"].indexOf(w.shape)?(R=l.steps(w.shape),F=l.steps(w.shape.split(\"\").reverse().join(\"\"))):R=F=\"spline\"===w.shape?function(t){var e=t[t.length-1];return t.length>1&&t[0][0]===e[0]&&t[0][1]===e[1]?l.smoothclosed(t.slice(1),w.smoothing):l.smoothopen(t,w.smoothing)}:function(t){return\"M\"+t.join(\"L\")},B=function(t){return F(t.reverse())},G=u(h,{xaxis:x,yaxis:b,connectGaps:_.connectgaps,baseTolerance:Math.max(w.width||1,3)/4,shape:w.shape,simplify:w.simplify,fill:_.fill}),V=_._polygons=new Array(G.length),v=0;v<G.length;v++)_._polygons[v]=f(G[v]);G.length&&(N=G[0][0],U=(j=G[G.length-1])[j.length-1]),Y=function(t){return function(e){if(P=R(e),O=B(e),q?L?(q+=\"L\"+P.substr(1),H=O+\"L\"+H.substr(1)):(q+=\"Z\"+P,H=O+\"Z\"+H):(q=P,H=O),c.hasLines(_)&&e.length>1){var r=n.select(this);if(r.datum(h),t)y(r.style(\"opacity\",0).attr(\"d\",P).call(l.lineGroupStyle)).style(\"opacity\",1);else{var i=y(r);i.attr(\"d\",P),l.singleLineStyle(h,i)}}}}}var W=A.selectAll(\".js-line\").data(G);y(W.exit()).style(\"opacity\",0).remove(),W.each(Y(!1)),W.enter().append(\"path\").classed(\"js-line\",!0).style(\"vector-effect\",\"non-scaling-stroke\").call(l.lineGroupStyle).each(Y(!0)),l.setClipUrl(W,r.layerClipId,t),G.length?(E?(E.datum(h),N&&U&&(L?(\"y\"===L?N[1]=U[1]=b.c2p(0,!0):\"x\"===L&&(N[0]=U[0]=x.c2p(0,!0)),y(E).attr(\"d\",\"M\"+U+\"L\"+N+\"L\"+q.substr(1)).call(l.singleFillStyle)):y(E).attr(\"d\",q+\"Z\").call(l.singleFillStyle))):C&&(\"tonext\"===_.fill.substr(0,6)&&q&&z?(\"tonext\"===_.fill?y(C).attr(\"d\",q+\"Z\"+z+\"Z\").call(l.singleFillStyle):y(C).attr(\"d\",q+\"L\"+z.substr(1)+\"Z\").call(l.singleFillStyle),_._polygons=_._polygons.concat(I)):(Z(C),_._polygons=null)),_._prevRevpath=H,_._prevPolygons=V):(E?Z(E):C&&Z(C),_._polygons=_._prevRevpath=_._prevPolygons=null),M.datum(h),S.datum(h),function(e,i,a){var o,u=a[0].trace,h=c.hasMarkers(u),f=c.hasText(u),p=tt(u),d=et,g=et;if(h||f){var v=s,_=u.stackgroup,w=_&&\"infer zero\"===t._fullLayout._scatterStackOpts[x._id+b._id][_].stackgaps;u.marker.maxdisplayed||u._needsCull?v=w?K:J:_&&!w&&(v=$),h&&(d=v),f&&(g=v)}var k,T=(o=e.selectAll(\"path.point\").data(d,p)).enter().append(\"path\").classed(\"point\",!0);m&&T.call(l.pointStyle,u,t).call(l.translatePoints,x,b).style(\"opacity\",0).transition().style(\"opacity\",1),o.order(),h&&(k=l.makePointStyleFns(u)),o.each(function(e){var i=n.select(this),a=y(i);l.translatePoint(e,a,x,b)?(l.singlePointStyle(e,a,u,k,t),r.layerClipId&&l.hideOutsideRangePoint(e,a,x,b,u.xcalendar,u.ycalendar),u.customdata&&i.classed(\"plotly-customdata\",null!==e.data&&void 0!==e.data)):a.remove()}),m?o.exit().transition().style(\"opacity\",0).remove():o.exit().remove(),(o=i.selectAll(\"g\").data(g,p)).enter().append(\"g\").classed(\"textpoint\",!0).append(\"text\"),o.order(),o.each(function(t){var e=n.select(this),i=y(e.select(\"text\"));l.translatePoint(t,i,x,b)?r.layerClipId&&l.hideOutsideRangePoint(t,e,x,b,u.xcalendar,u.ycalendar):e.remove()}),o.selectAll(\"text\").call(l.textPointStyle,u,t).each(function(t){var e=x.c2p(t.x),r=b.c2p(t.y);n.select(this).selectAll(\"tspan.line\").each(function(){y(n.select(this)).attr({x:e,y:r})})}),o.exit().remove()}(M,S,h);var X=!1===_.cliponaxis?null:r.layerClipId;l.setClipUrl(M,X,t),l.setClipUrl(S,X,t)}function Z(t){y(t).attr(\"d\",\"M0,0Z\")}function J(t){return t.filter(function(t){return!t.gap&&t.vis})}function K(t){return t.filter(function(t){return t.vis})}function $(t){return t.filter(function(t){return!t.gap})}function Q(t){return t.id}function tt(t){if(t.ids)return Q}function et(){return!1}}e.exports=function(t,e,r,i,a,c){var u,f,d=!a,g=!!a&&a.duration>0,v=h(t,e,r);((u=i.selectAll(\"g.trace\").data(v,function(t){return t[0].trace.uid})).enter().append(\"g\").attr(\"class\",function(t){return\"trace scatter trace\"+t[0].trace.uid}).style(\"stroke-miterlimit\",2),u.order(),function(t,e,r){e.each(function(e){var i=o(n.select(this),\"g\",\"fills\");l.setClipUrl(i,r.layerClipId,t);var a=e[0].trace,c=[];a._ownfill&&c.push(\"_ownFill\"),a._nexttrace&&c.push(\"_nextFill\");var u=i.selectAll(\"g\").data(c,s);u.enter().append(\"g\"),u.exit().each(function(t){a[t]=null}).remove(),u.order().each(function(t){a[t]=o(n.select(this),\"path\",\"js-fill\")})})}(t,u,e),g)?(c&&(f=c()),n.transition().duration(a.duration).ease(a.easing).each(\"end\",function(){f&&f()}).each(\"interrupt\",function(){f&&f()}).each(function(){i.selectAll(\"g.trace\").each(function(r,n){p(t,n,e,r,v,this,a)})})):u.each(function(r,n){p(t,n,e,r,v,this,a)});d&&u.exit().remove(),i.selectAll(\"path:not([d])\").remove()}},{\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/polygon\":731,\"../../registry\":847,\"./line_points\":1125,\"./link_traces\":1127,\"./subtypes\":1135,d3:163}],1132:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports=function(t,e){var r,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[],h=s[0].trace;if(!n.hasMarkers(h)&&!n.hasText(h))return[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)i=s[r],a=l.c2p(i.x),o=c.c2p(i.y),null!==i.i&&e.contains([a,o],!1,r,t)?(u.push({pointNumber:i.i,x:l.c2d(i.x),y:c.c2d(i.y)}),i.selected=1):i.selected=0;return u}},{\"./subtypes\":1135}],1133:[function(t,e,r){\"use strict\";var n=[\"orientation\",\"groupnorm\",\"stackgaps\"];e.exports=function(t,e,r,i){var a=r._scatterStackOpts,o=i(\"stackgroup\");if(o){var s=e.xaxis+e.yaxis,l=a[s];l||(l=a[s]={});var c=l[o],u=!1;c?c.traces.push(e):(c=l[o]={traceIndices:[],traces:[e]},u=!0);for(var h={orientation:e.x&&!e.y?\"h\":\"v\"},f=0;f<n.length;f++){var p=n[f],d=p+\"Found\";if(!c[d]){var g=void 0!==t[p],v=\"orientation\"===p;if((g||u)&&(c[p]=i(p,h[p]),v&&(c.fillDflt=\"h\"===c[p]?\"tonextx\":\"tonexty\"),g&&(c[d]=!0,!u&&(delete c.traces[0][p],v))))for(var m=0;m<c.traces.length-1;m++){var y=c.traces[m];y._input.fill!==y.fill&&(y.fill=c.fillDflt)}}}return c}}},{}],1134:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../registry\");function o(t,e,r){i.pointStyle(t.selectAll(\"path.point\"),e,r)}function s(t,e,r){i.textPointStyle(t.selectAll(\"text\"),e,r)}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.trace.scatter\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.selectAll(\"g.points\").each(function(e){o(n.select(this),e.trace||e[0].trace,t)}),e.selectAll(\"g.text\").each(function(e){s(n.select(this),e.trace||e[0].trace,t)}),e.selectAll(\"g.trace path.js-line\").call(i.lineGroupStyle),e.selectAll(\"g.trace path.js-fill\").call(i.fillGroupStyle),a.getComponentMethod(\"errorbars\",\"style\")(e)},stylePoints:o,styleText:s,styleOnSelect:function(t,e,r){var n=e[0].trace;n.selectedpoints?(i.selectedPointStyle(r.selectAll(\"path.point\"),n),i.selectedTextStyle(r.selectAll(\"text\"),n)):(o(r,n,t),s(r,n,t))}}},{\"../../components/drawing\":614,\"../../registry\":847,d3:163}],1135:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports={hasLines:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"lines\")},hasMarkers:function(t){return t.visible&&(t.mode&&-1!==t.mode.indexOf(\"markers\")||\"splom\"===t.type)},hasText:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"text\")},isBubble:function(t){return n.isPlainObject(t.marker)&&n.isArrayOrTypedArray(t.marker.size)}}},{\"../../lib\":719}],1136:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i,a){a=a||{},i(\"textposition\"),n.coerceFont(i,\"textfont\",r.font),a.noSelect||(i(\"selected.textfont.color\"),i(\"unselected.textfont.color\"))}},{\"../../lib\":719}],1137:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");e.exports=function(t,e,r,a){var o,s=a(\"x\"),l=a(\"y\");if(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],r),s){var c=n.minRowLength(s);l?o=Math.min(c,n.minRowLength(l)):(o=c,a(\"y0\"),a(\"dy\"))}else{if(!l)return 0;o=n.minRowLength(l),a(\"x0\"),a(\"dx\")}return e._length=o,o}},{\"../../lib\":719,\"../../registry\":847}],1138:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../constants/gl3d_dashes\"),l=t(\"../../constants/gl3d_markers\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../plot_api/edit_types\").overrideAll,h=n.line,f=n.marker,p=f.line,d=c({width:h.width,dash:{valType:\"enumerated\",values:Object.keys(s),dflt:\"solid\"}},i(\"line\"));var g=e.exports=u({x:n.x,y:n.y,z:{valType:\"data_array\"},text:c({},n.text,{}),hovertext:c({},n.hovertext,{}),hovertemplate:a(),mode:c({},n.mode,{dflt:\"lines+markers\"}),surfaceaxis:{valType:\"enumerated\",values:[-1,0,1,2],dflt:-1},surfacecolor:{valType:\"color\"},projection:{x:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},y:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},z:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}}},connectgaps:n.connectgaps,line:d,marker:c({symbol:{valType:\"enumerated\",values:Object.keys(l),dflt:\"circle\",arrayOk:!0},size:c({},f.size,{dflt:8}),sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode,opacity:c({},f.opacity,{arrayOk:!1}),colorbar:f.colorbar,line:c({width:c({},p.width,{arrayOk:!1})},i(\"marker.line\"))},i(\"marker\")),textposition:c({},n.textposition,{dflt:\"top center\"}),textfont:{color:n.textfont.color,size:n.textfont.size,family:c({},n.textfont.family,{arrayOk:!1})},hoverinfo:c({},o.hoverinfo)},\"calc\",\"nested\");g.x.editType=g.y.editType=g.z.editType=\"calc+clearAxisTypes\"},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../constants/gl3d_dashes\":692,\"../../constants/gl3d_markers\":693,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1139:[function(t,e,r){\"use strict\";var n=t(\"../scatter/arrays_to_calcdata\"),i=t(\"../scatter/colorscale_calc\");e.exports=function(t,e){var r=[{x:!1,y:!1,trace:e,t:{}}];return n(r,e),i(t,e),r}},{\"../scatter/arrays_to_calcdata\":1111,\"../scatter/colorscale_calc\":1115}],1140:[function(t,e,r){\"use strict\";var n=t(\"../../registry\");function i(t,e,r,i){if(!e||!e.visible)return null;for(var a=n.getComponentMethod(\"errorbars\",\"makeComputeError\")(e),o=new Array(t.length),s=0;s<t.length;s++){var l=a(+t[s],s);if(\"log\"===i.type){var c=i.c2l(t[s]),u=t[s]-l[0],h=t[s]+l[1];if(o[s]=[(i.c2l(u,!0)-c)*r,(i.c2l(h,!0)-c)*r],u>0){var f=i.c2l(u);i._lowerLogErrorBound||(i._lowerLogErrorBound=f),i._lowerErrorBound=Math.min(i._lowerLogErrorBound,f)}}else o[s]=[-l[0]*r,l[1]*r]}return o}e.exports=function(t,e,r){var n=[i(t.x,t.error_x,e[0],r.xaxis),i(t.y,t.error_y,e[1],r.yaxis),i(t.z,t.error_z,e[2],r.zaxis)],a=function(t){for(var e=0;e<t.length;e++)if(t[e])return t[e].length;return 0}(n);if(0===a)return null;for(var o=new Array(a),s=0;s<a;s++){for(var l=[[0,0,0],[0,0,0]],c=0;c<3;c++)if(n[c])for(var u=0;u<2;u++)l[u][c]=n[c][s][u];o[s]=l}return o}},{\"../../registry\":847}],1141:[function(t,e,r){\"use strict\";var n=t(\"gl-line3d\"),i=t(\"gl-scatter3d\"),a=t(\"gl-error3d\"),o=t(\"gl-mesh3d\"),s=t(\"delaunay-triangulate\"),l=t(\"../../lib\"),c=t(\"../../lib/str2rgbarray\"),u=t(\"../../lib/gl_format_color\").formatColor,h=t(\"../scatter/make_bubble_size_func\"),f=t(\"../../constants/gl3d_dashes\"),p=t(\"../../constants/gl3d_markers\"),d=t(\"./calc_errors\");function g(t,e){this.scene=t,this.uid=e,this.linePlot=null,this.scatterPlot=null,this.errorBars=null,this.textMarkers=null,this.delaunayMesh=null,this.color=null,this.mode=\"\",this.dataPoints=[],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.textLabels=null,this.data=null}var v=g.prototype;function m(t){return null==t?0:t.indexOf(\"left\")>-1?-1:t.indexOf(\"right\")>-1?1:0}function y(t){return null==t?0:t.indexOf(\"top\")>-1?-1:t.indexOf(\"bottom\")>-1?1:0}function x(t,e){return e(4*t)}function b(t){return p[t]}function _(t,e,r,n,i){var a=null;if(l.isArrayOrTypedArray(t)){a=[];for(var o=0;o<e;o++)void 0===t[o]?a[o]=n:a[o]=r(t[o],i)}else a=r(t,l.identity);return a}function w(t,e){var r,n,i,a,o,s,f=[],p=t.fullSceneLayout,g=t.dataScale,v=p.xaxis,w=p.yaxis,k=p.zaxis,T=e.marker,A=e.line,M=e.x||[],S=e.y||[],E=e.z||[],C=M.length,L=e.xcalendar,P=e.ycalendar,O=e.zcalendar;for(o=0;o<C;o++)r=v.d2l(M[o],0,L)*g[0],n=w.d2l(S[o],0,P)*g[1],i=k.d2l(E[o],0,O)*g[2],f[o]=[r,n,i];if(Array.isArray(e.text))s=e.text;else if(void 0!==e.text)for(s=new Array(C),o=0;o<C;o++)s[o]=e.text;if(a={position:f,mode:e.mode,text:s},\"line\"in e&&(a.lineColor=u(A,1,C),a.lineWidth=A.width,a.lineDashes=A.dash),\"marker\"in e){var z=h(e);a.scatterColor=u(T,1,C),a.scatterSize=_(T.size,C,x,20,z),a.scatterMarker=_(T.symbol,C,b,\"\\u25cf\"),a.scatterLineWidth=T.line.width,a.scatterLineColor=u(T.line,1,C),a.scatterAngle=0}\"textposition\"in e&&(a.textOffset=function(t){var e=[0,0];if(Array.isArray(t))for(var r=0;r<t.length;r++)e[r]=[0,0],t[r]&&(e[r][0]=m(t[r]),e[r][1]=y(t[r]));else e[0]=m(t),e[1]=y(t);return e}(e.textposition),a.textColor=u(e.textfont,1,C),a.textSize=_(e.textfont.size,C,l.identity,12),a.textFont=e.textfont.family,a.textAngle=0);var I=[\"x\",\"y\",\"z\"];for(a.project=[!1,!1,!1],a.projectScale=[1,1,1],a.projectOpacity=[1,1,1],o=0;o<3;++o){var D=e.projection[I[o]];(a.project[o]=D.show)&&(a.projectOpacity[o]=D.opacity,a.projectScale[o]=D.scale)}a.errorBounds=d(e,g,p);var R=function(t){for(var e=[0,0,0],r=[[0,0,0],[0,0,0],[0,0,0]],n=[1,1,1],i=0;i<3;i++){var a=t[i];a&&!1!==a.copy_zstyle&&!1!==t[2].visible&&(a=t[2]),a&&a.visible&&(e[i]=a.width/2,r[i]=c(a.color),n[i]=a.thickness)}return{capSize:e,color:r,lineWidth:n}}([e.error_x,e.error_y,e.error_z]);return a.errorColor=R.color,a.errorLineWidth=R.lineWidth,a.errorCapSize=R.capSize,a.delaunayAxis=e.surfaceaxis,a.delaunayColor=c(e.surfacecolor),a}function k(t){if(Array.isArray(t)){var e=t[0];return Array.isArray(e)&&(t=e),\"rgb(\"+t.slice(0,3).map(function(t){return Math.round(255*t)})+\")\"}return null}v.handlePick=function(t){if(t.object&&(t.object===this.linePlot||t.object===this.delaunayMesh||t.object===this.textMarkers||t.object===this.scatterPlot)){var e=t.index=t.data.index;return t.object.highlight&&t.object.highlight(null),this.scatterPlot&&(t.object=this.scatterPlot,this.scatterPlot.highlight(t.data)),t.textLabel=\"\",this.textLabels&&(Array.isArray(this.textLabels)?(this.textLabels[e]||0===this.textLabels[e])&&(t.textLabel=this.textLabels[e]):t.textLabel=this.textLabels),t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]],!0}},v.update=function(t){var e,r,l,c,u=this.scene.glplot.gl,h=f.solid;this.data=t;var p=w(this.scene,t);\"mode\"in p&&(this.mode=p.mode),\"lineDashes\"in p&&p.lineDashes in f&&(h=f[p.lineDashes]),this.color=k(p.scatterColor)||k(p.lineColor),this.dataPoints=p.position,e={gl:this.scene.glplot.gl,position:p.position,color:p.lineColor,lineWidth:p.lineWidth||1,dashes:h[0],dashScale:h[1],opacity:t.opacity,connectGaps:t.connectgaps},-1!==this.mode.indexOf(\"lines\")?this.linePlot?this.linePlot.update(e):(this.linePlot=n(e),this.linePlot._trace=this,this.scene.glplot.add(this.linePlot)):this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose(),this.linePlot=null);var d=t.opacity;if(t.marker&&t.marker.opacity&&(d*=t.marker.opacity),r={gl:this.scene.glplot.gl,position:p.position,color:p.scatterColor,size:p.scatterSize,glyph:p.scatterMarker,opacity:d,orthographic:!0,lineWidth:p.scatterLineWidth,lineColor:p.scatterLineColor,project:p.project,projectScale:p.projectScale,projectOpacity:p.projectOpacity},-1!==this.mode.indexOf(\"markers\")?this.scatterPlot?this.scatterPlot.update(r):(this.scatterPlot=i(r),this.scatterPlot._trace=this,this.scatterPlot.highlightScale=1,this.scene.glplot.add(this.scatterPlot)):this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose(),this.scatterPlot=null),c={gl:this.scene.glplot.gl,position:p.position,glyph:p.text,color:p.textColor,size:p.textSize,angle:p.textAngle,alignment:p.textOffset,font:p.textFont,orthographic:!0,lineWidth:0,project:!1,opacity:t.opacity},this.textLabels=t.hovertext||t.text,-1!==this.mode.indexOf(\"text\")?this.textMarkers?this.textMarkers.update(c):(this.textMarkers=i(c),this.textMarkers._trace=this,this.textMarkers.highlightScale=1,this.scene.glplot.add(this.textMarkers)):this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose(),this.textMarkers=null),l={gl:this.scene.glplot.gl,position:p.position,color:p.errorColor,error:p.errorBounds,lineWidth:p.errorLineWidth,capSize:p.errorCapSize,opacity:t.opacity},this.errorBars?p.errorBounds?this.errorBars.update(l):(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose(),this.errorBars=null):p.errorBounds&&(this.errorBars=a(l),this.errorBars._trace=this,this.scene.glplot.add(this.errorBars)),p.delaunayAxis>=0){var g=function(t,e,r){var n,i=(r+1)%3,a=(r+2)%3,o=[],l=[];for(n=0;n<t.length;++n){var c=t[n];!isNaN(c[i])&&isFinite(c[i])&&!isNaN(c[a])&&isFinite(c[a])&&(o.push([c[i],c[a]]),l.push(n))}var u=s(o);for(n=0;n<u.length;++n)for(var h=u[n],f=0;f<h.length;++f)h[f]=l[h[f]];return{positions:t,cells:u,meshColor:e}}(p.position,p.delaunayColor,p.delaunayAxis);g.opacity=t.opacity,this.delaunayMesh?this.delaunayMesh.update(g):(g.gl=u,this.delaunayMesh=o(g),this.delaunayMesh._trace=this,this.scene.glplot.add(this.delaunayMesh))}else this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose(),this.delaunayMesh=null)},v.dispose=function(){this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose()),this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose()),this.errorBars&&(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose()),this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose()),this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose())},e.exports=function(t,e){var r=new g(t,e.uid);return r.update(e),r}},{\"../../constants/gl3d_dashes\":692,\"../../constants/gl3d_markers\":693,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../scatter/make_bubble_size_func\":1128,\"./calc_errors\":1140,\"delaunay-triangulate\":165,\"gl-error3d\":247,\"gl-line3d\":255,\"gl-mesh3d\":280,\"gl-scatter3d\":297}],1142:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,n){return i.coerce(t,e,c,r,n)}if(function(t,e,r,i){var a=0,o=r(\"x\"),s=r(\"y\"),l=r(\"z\");n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],i),o&&s&&l&&(a=Math.min(o.length,s.length,l.length),e._length=e._xlength=e._ylength=e._zlength=a);return a}(t,e,h,u)){h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),a.hasLines(e)&&(h(\"connectgaps\"),s(t,e,r,u,h)),a.hasMarkers(e)&&o(t,e,r,u,h,{noSelect:!0}),a.hasText(e)&&l(t,e,u,h,{noSelect:!0});var f=(e.line||{}).color,p=(e.marker||{}).color;h(\"surfaceaxis\")>=0&&h(\"surfacecolor\",f||p);for(var d=[\"x\",\"y\",\"z\"],g=0;g<3;++g){var v=\"projection.\"+d[g];h(v+\".show\")&&(h(v+\".opacity\"),h(v+\".scale\"))}var m=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");m(t,e,f||p||r,{axis:\"z\"}),m(t,e,f||p||r,{axis:\"y\",inherit:\"z\"}),m(t,e,f||p||r,{axis:\"x\",inherit:\"z\"})}else e.visible=!1}},{\"../../lib\":719,\"../../registry\":847,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1138}],1143:[function(t,e,r){\"use strict\";e.exports={plot:t(\"./convert\"),attributes:t(\"./attributes\"),markerSymbols:t(\"../../constants/gl3d_markers\"),supplyDefaults:t(\"./defaults\"),colorbar:[{container:\"marker\",min:\"cmin\",max:\"cmax\"},{container:\"line\",min:\"cmin\",max:\"cmax\"}],calc:t(\"./calc\"),moduleType:\"trace\",name:\"scatter3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"symbols\",\"showLegend\"],meta:{}}},{\"../../constants/gl3d_markers\":693,\"../../plots/gl3d\":807,\"./attributes\":1138,\"./calc\":1139,\"./convert\":1141,\"./defaults\":1142}],1144:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=n.marker,c=n.line,u=l.line;e.exports={carpet:{valType:\"string\",editType:\"calc\"},a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},mode:s({},n.mode,{dflt:\"markers\"}),text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),line:{color:c.color,width:c.width,dash:c.dash,shape:s({},c.shape,{values:[\"linear\",\"spline\"]}),smoothing:c.smoothing,editType:\"calc\"},connectgaps:n.connectgaps,fill:s({},n.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:n.fillcolor,marker:s({symbol:l.symbol,opacity:l.opacity,maxdisplayed:l.maxdisplayed,size:l.size,sizeref:l.sizeref,sizemin:l.sizemin,sizemode:l.sizemode,line:s({width:u.width,editType:\"calc\"},o(\"marker.line\")),gradient:l.gradient,editType:\"calc\"},o(\"marker\")),textfont:n.textfont,textposition:n.textposition,selected:n.selected,unselected:n.unselected,hoverinfo:s({},i.hoverinfo,{flags:[\"a\",\"b\",\"text\",\"name\"]}),hoveron:n.hoveron,hovertemplate:a()}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1145:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=t(\"../carpet/lookup_carpetid\");e.exports=function(t,e){var r=e._carpetTrace=l(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){var c;e.xaxis=r.xaxis,e.yaxis=r.yaxis;var u,h,f=e._length,p=new Array(f),d=!1;for(c=0;c<f;c++)if(u=e.a[c],h=e.b[c],n(u)&&n(h)){var g=r.ab2xy(+u,+h,!0),v=r.isVisible(+u,+h);v||(d=!0),p[c]={x:g[0],y:g[1],a:u,b:h,vis:v}}else p[c]={x:!1,y:!1};return e._needsCull=d,p[0].carpet=r,p[0].trace=e,s(e,f),i(t,e),a(p,e),o(p,e),p}}},{\"../carpet/lookup_carpetid\":915,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc\":1113,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1146:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}p(\"carpet\"),e.xaxis=\"x\",e.yaxis=\"y\";var d=p(\"a\"),g=p(\"b\"),v=Math.min(d.length,g.length);if(v){e._length=v,p(\"text\"),p(\"hovertext\"),p(\"mode\",v<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,f,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,f,p,{gradient:!0}),a.hasText(e)&&c(t,e,f,p);var m=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"marker.maxdisplayed\"),m.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||m.push(\"fills\"),\"fills\"!==p(\"hoveron\",m.join(\"+\")||\"points\")&&p(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/line_shape_defaults\":1126,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1144}],1147:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=n[i];return t.a=a.a,t.b=a.b,t.y=a.y,t}},{}],1148:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../lib\").fillText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,h=c-u;return s.x0=Math.max(Math.min(s.x0,h),u),s.x1=Math.max(Math.min(s.x1,h),u),o}var f=s.cd[s.index];s.a=f.a,s.b=f.b,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.trace,d=p._carpet,g=d.ab2ij([f.a,f.b]),v=Math.floor(g[0]),m=g[0]-v,y=Math.floor(g[1]),x=g[1]-y,b=d.evalxy([],v,y,m,x);s.yLabel=b[1].toFixed(3),delete s.text;var _=[];if(!p.hovertemplate){var w=(f.hi||p.hoverinfo).split(\"+\");-1!==w.indexOf(\"all\")&&(w=[\"a\",\"b\",\"text\"]),-1!==w.indexOf(\"a\")&&k(d.aaxis,f.a),-1!==w.indexOf(\"b\")&&k(d.baxis,f.b),_.push(\"y: \"+s.yLabel),-1!==w.indexOf(\"text\")&&i(f,p,_),s.extraText=_.join(\"<br>\")}return o}function k(t,e){var r;r=t.labelprefix&&t.labelprefix.length>0?t.labelprefix.replace(/ = $/,\"\"):t._hovertitle,_.push(r+\": \"+e.toFixed(3)+t.labelsuffix)}}},{\"../../lib\":719,\"../scatter/hover\":1122}],1149:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scattercarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"svg\",\"carpet\",\"symbols\",\"showLegend\",\"carpetDependent\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../scatter/marker_colorbar\":1129,\"../scatter/select\":1132,\"../scatter/style\":1134,\"./attributes\":1144,\"./calc\":1145,\"./defaults\":1146,\"./event_data\":1147,\"./hover\":1148,\"./plot\":1150}],1150:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../components/drawing\");e.exports=function(t,e,r,o){var s,l,c,u=r[0][0].carpet,h={xaxis:i.getFromId(t,u.xaxis||\"x\"),yaxis:i.getFromId(t,u.yaxis||\"y\"),plot:e.plot};for(n(t,h,r,o),s=0;s<r.length;s++)l=r[s][0].trace,c=o.selectAll(\"g.trace\"+l.uid+\" .js-line\"),a.setClipUrl(c,r[s][0].carpet._clipPathId,t)}},{\"../../components/drawing\":614,\"../../plots/cartesian/axes\":767,\"../scatter/plot\":1131}],1151:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/drawing/attributes\").dash,l=t(\"../../lib/extend\").extendFlat,c=t(\"../../plot_api/edit_types\").overrideAll,u=i.marker,h=i.line,f=u.line;e.exports=c({lon:{valType:\"data_array\"},lat:{valType:\"data_array\"},locations:{valType:\"data_array\"},locationmode:{valType:\"enumerated\",values:[\"ISO-3\",\"USA-states\",\"country names\"],dflt:\"ISO-3\"},mode:l({},i.mode,{dflt:\"markers\"}),text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),textfont:i.textfont,textposition:i.textposition,line:{color:h.color,width:h.width,dash:s},connectgaps:i.connectgaps,marker:l({symbol:u.symbol,opacity:u.opacity,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,colorbar:u.colorbar,line:l({width:f.width},o(\"marker.line\")),gradient:u.gradient},o(\"marker\")),fill:{valType:\"enumerated\",values:[\"none\",\"toself\"],dflt:\"none\"},fillcolor:i.fillcolor,selected:i.selected,unselected:i.unselected,hoverinfo:l({},a.hoverinfo,{flags:[\"lon\",\"lat\",\"location\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":600,\"../../components/drawing/attributes\":613,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1152:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../scatter/colorscale_calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\"),l=t(\"../../lib\")._;e.exports=function(t,e){for(var r=Array.isArray(e.locations),c=r?e.locations.length:e._length,u=new Array(c),h=0;h<c;h++){var f=u[h]={};if(r){var p=e.locations[h];f.loc=\"string\"==typeof p?p:null}else{var d=e.lon[h],g=e.lat[h];n(d)&&n(g)?f.lonlat=[+d,+g]:f.lonlat=[i,i]}}return o(u,e),a(t,e),s(u,e),c&&(u[0].t={labels:{lat:l(t,\"lat:\")+\" \",lon:l(t,\"lon:\")+\" \"}}),u}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1153:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,i){return n.coerce(t,e,c,r,i)}!function(t,e,r){var n,i,a=0,o=r(\"locations\");if(o)return r(\"locationmode\"),a=o.length;return n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length),e._length=a,a}(0,e,h)?e.visible=!1:(h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),i.hasLines(e)&&(o(t,e,r,u,h),h(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,u,h,{gradient:!0}),i.hasText(e)&&s(t,e,u,h),h(\"fill\"),\"none\"!==e.fill&&l(t,e,r,h),n.coerceSelectionMarkerOpacity(e,h))}},{\"../../lib\":719,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1151}],1154:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.location=e.loc?e.loc:null,t}},{}],1155:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../scatter/get_trace_color\"),s=t(\"../../lib\").fillText,l=t(\"./attributes\");e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,h=t.xa,f=t.ya,p=t.subplot,d=p.projection.isLonLatOverEdges,g=p.project;if(n.getClosest(c,function(t){var n=t.lonlat;if(n[0]===a)return 1/0;if(d(n))return 1/0;var i=g(n),o=g([e,r]),s=Math.abs(i[0]-o[0]),l=Math.abs(i[1]-o[1]),c=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(s*s+l*l)-c,1-3/c)},t),!1!==t.index){var v=c[t.index],m=v.lonlat,y=[h.c2p(m),f.c2p(m)],x=v.mrc||1;t.x0=y[0]-x,t.x1=y[0]+x,t.y0=y[1]-x,t.y1=y[1]+x,t.loc=v.loc,t.lon=m[0],t.lat=m[1];var b=p.mockAxis;return t.lonLabel=i.tickText(b,b.c2l(t.lon),\"hover\").text,t.latLabel=i.tickText(b,b.c2l(t.lat),\"hover\").text,t.color=o(u,v),t.extraText=function(t,e,r,n){if(t.hovertemplate)return;var i=e.hi||t.hoverinfo,a=\"all\"===i?l.hoverinfo.flags:i.split(\"+\"),o=-1!==a.indexOf(\"location\")&&Array.isArray(t.locations),c=-1!==a.indexOf(\"lon\"),u=-1!==a.indexOf(\"lat\"),h=-1!==a.indexOf(\"text\"),f=[];function p(t){return t+\"\\xb0\"}o?f.push(e.loc):c&&u?f.push(\"(\"+p(r.lonLabel)+\", \"+p(r.latLabel)+\")\"):c?f.push(n.lon+p(r.lonLabel)):u&&f.push(n.lat+p(r.latLabel));h&&s(e,t,f);return f.join(\"<br>\")}(u,v,t,c[0].t.labels),t.hovertemplate=u.hovertemplate,[t]}}},{\"../../components/fx\":632,\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scatter/get_trace_color\":1121,\"./attributes\":1151}],1156:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"scattergeo\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/geo\":797,\"../scatter/marker_colorbar\":1129,\"../scatter/style\":1134,\"./attributes\":1151,\"./calc\":1152,\"./defaults\":1153,\"./event_data\":1154,\"./hover\":1155,\"./plot\":1157,\"./select\":1158,\"./style\":1159}],1157:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../lib/topojson_utils\").getTopojsonFeatures,s=t(\"../../lib/geo_location_utils\").locationToFeature,l=t(\"../../lib/geojson_utils\"),c=t(\"../scatter/subtypes\"),u=t(\"./style\");function h(t,e){var r=t[0].trace;if(Array.isArray(r.locations))for(var n=o(r,e),i=r.locationmode,l=0;l<t.length;l++){var c=t[l],u=s(i,c.loc,n);c.lonlat=u?u.properties.ct:[a,a]}}e.exports=function(t,e,r){for(var o=0;o<r.length;o++)h(r[o],e.topojson);function s(t,e){t.lonlat[0]===a&&n.select(e).remove()}var f=e.layers.frontplot.select(\".scatterlayer\"),p=i.makeTraceGroups(f,r,\"trace scattergeo\");p.selectAll(\"*\").remove(),p.each(function(e){var r=n.select(this),a=e[0].trace;if(c.hasLines(a)||\"none\"!==a.fill){var o=l.calcTraceToLineCoords(e),h=\"none\"!==a.fill?l.makePolygon(o):l.makeLine(o);r.selectAll(\"path.js-line\").data([{geojson:h,trace:a}]).enter().append(\"path\").classed(\"js-line\",!0).style(\"stroke-miterlimit\",2)}c.hasMarkers(a)&&r.selectAll(\"path.point\").data(i.identity).enter().append(\"path\").classed(\"point\",!0).each(function(t){s(t,this)}),c.hasText(a)&&r.selectAll(\"g\").data(i.identity).enter().append(\"g\").append(\"text\").each(function(t){s(t,this)}),u(t,e)})}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/geo_location_utils\":713,\"../../lib/geojson_utils\":714,\"../../lib/topojson_utils\":746,\"../scatter/subtypes\":1135,\"./style\":1159,d3:163}],1158:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,a,o,s,l,c=t.cd,u=t.xaxis,h=t.yaxis,f=[],p=c[0].trace;if(!n.hasMarkers(p)&&!n.hasText(p))return[];if(!1===e)for(l=0;l<c.length;l++)c[l].selected=0;else for(l=0;l<c.length;l++)(a=(r=c[l]).lonlat)[0]!==i&&(o=u.c2p(a),s=h.c2p(a),e.contains([o,s],null,l,t)?(f.push({pointNumber:l,lon:a[0],lat:a[1]}),r.selected=1):r.selected=0);return f}},{\"../../constants/numerical\":695,\"../scatter/subtypes\":1135}],1159:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../scatter/style\"),s=o.stylePoints,l=o.styleText;e.exports=function(t,e){e&&function(t,e){var r=e[0].trace,o=e[0].node3;o.style(\"opacity\",e[0].trace.opacity),s(o,r,t),l(o,r,t),o.selectAll(\"path.js-line\").style(\"fill\",\"none\").each(function(t){var e=n.select(this),r=t.trace,o=r.line||{};e.call(a.stroke,o.color).call(i.dashLine,o.dash||\"\",o.width||0),\"none\"!==r.fill&&e.call(a.fill,r.fillcolor)})}(t,e)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../scatter/style\":1134,d3:163}],1160:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=t(\"./constants\").DASHES,c=i.line,u=i.marker,h=u.line,f=e.exports=s({x:i.x,x0:i.x0,dx:i.dx,y:i.y,y0:i.y0,dy:i.dy,text:i.text,hovertext:i.hovertext,textposition:i.textposition,textfont:i.textfont,mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"]},line:{color:c.color,width:c.width,shape:{valType:\"enumerated\",values:[\"linear\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},dash:{valType:\"enumerated\",values:Object.keys(l),dflt:\"solid\"}},marker:o({},a(\"marker\"),{symbol:u.symbol,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:o({},a(\"marker.line\"),{width:h.width})}),connectgaps:i.connectgaps,fill:o({},i.fill,{dflt:\"none\"}),fillcolor:i.fillcolor,selected:{marker:i.selected.marker,textfont:i.selected.textfont},unselected:{marker:i.unselected.marker,textfont:i.unselected.textfont},opacity:n.opacity},\"calc\",\"nested\");f.x.editType=f.y.editType=f.x0.editType=f.y0.editType=\"calc+clearAxisTypes\",f.hovertemplate=i.hovertemplate},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../scatter/attributes\":1112,\"./constants\":1162}],1161:[function(t,e,r){\"use strict\";var n=t(\"point-cluster\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../plots/cartesian/autorange\").findExtremes,s=t(\"../scatter/calc\"),l=s.calcMarkerSize,c=s.calcAxisExpansion,u=s.setFirstScatter,h=t(\"../scatter/colorscale_calc\"),f=t(\"./convert\"),p=t(\"./scene_update\"),d=t(\"../../constants/numerical\").BADNUM,g=t(\"./constants\").TOO_MANY_POINTS;function v(t,e,r){var n=t._extremes[e._id],i=o(e,r._bnds,{padded:!0});n.min=n.min.concat(i.min),n.max=n.max.concat(i.max)}e.exports=function(t,e){var r,o,s,m=t._fullLayout,y=a.getFromId(t,e.xaxis),x=a.getFromId(t,e.yaxis),b=m._plots[e.xaxis+e.yaxis],_=e._length,w=_>=g,k=2*_,T={},A=y.makeCalcdata(e,\"x\"),M=x.makeCalcdata(e,\"y\"),S=new Array(k);for(r=0;r<_;r++)o=A[r],s=M[r],S[2*r]=o===d?NaN:o,S[2*r+1]=s===d?NaN:s;if(\"log\"===y.type)for(r=0;r<k;r+=2)S[r]=y.c2l(S[r]);if(\"log\"===x.type)for(r=1;r<k;r+=2)S[r]=x.c2l(S[r]);if(w&&\"log\"!==y.type&&\"log\"!==x.type)T.tree=n(S);else{var E=T.ids=new Array(_);for(r=0;r<_;r++)E[r]=r}h(t,e);var C,L=function(t,e,r,n,a,o){var s=f.style(t,r);s.marker&&(s.marker.positions=n);s.line&&n.length>1&&i.extendFlat(s.line,f.linePositions(t,r,n));if(s.errorX||s.errorY){var l=f.errorBarPositions(t,r,n,a,o);s.errorX&&i.extendFlat(s.errorX,l.x),s.errorY&&i.extendFlat(s.errorY,l.y)}s.text&&(i.extendFlat(s.text,{positions:n},f.textPosition(t,r,s.text,s.marker)),i.extendFlat(s.textSel,{positions:n},f.textPosition(t,r,s.text,s.markerSel)),i.extendFlat(s.textUnsel,{positions:n},f.textPosition(t,r,s.text,s.markerUnsel)));return s}(t,0,e,S,A,M),P=p(t,b);return u(m,e),w?L.marker&&(C=2*(L.marker.sizeAvg||Math.max(L.marker.size,3))):C=l(e,_),c(t,e,y,x,A,M,C),L.errorX&&v(e,y,L.errorX),L.errorY&&v(e,x,L.errorY),L.fill&&!P.fill2d&&(P.fill2d=!0),L.marker&&!P.scatter2d&&(P.scatter2d=!0),L.line&&!P.line2d&&(P.line2d=!0),!L.errorX&&!L.errorY||P.error2d||(P.error2d=!0),L.text&&!P.glText&&(P.glText=!0),L.marker&&(L.marker.snap=T.tree||g),P.lineOptions.push(L.line),P.errorXOptions.push(L.errorX),P.errorYOptions.push(L.errorY),P.fillOptions.push(L.fill),P.markerOptions.push(L.marker),P.markerSelectedOptions.push(L.markerSel),P.markerUnselectedOptions.push(L.markerUnsel),P.textOptions.push(L.text),P.textSelectedOptions.push(L.textSel),P.textUnselectedOptions.push(L.textUnsel),P.selectBatch.push([]),P.unselectBatch.push([]),T._scene=P,T.index=P.count,T.x=A,T.y=M,T.positions=S,P.count++,[{x:!1,y:!1,t:T,trace:e}]}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/autorange\":766,\"../../plots/cartesian/axis_ids\":770,\"../scatter/calc\":1113,\"../scatter/colorscale_calc\":1115,\"./constants\":1162,\"./convert\":1163,\"./scene_update\":1169,\"point-cluster\":469}],1162:[function(t,e,r){\"use strict\";e.exports={TOO_MANY_POINTS:1e5,SYMBOL_SDF_SIZE:200,SYMBOL_SIZE:20,SYMBOL_STROKE:1,DOT_RE:/-dot/,OPEN_RE:/-open/,DASHES:{solid:[1],dot:[1,1],dash:[4,1],longdash:[8,1],dashdot:[4,1,1,1],longdashdot:[8,1,1,1]}}},{}],1163:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"svg-path-sdf\"),a=t(\"color-normalize\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../components/drawing\"),c=t(\"../../plots/cartesian/axis_ids\"),u=t(\"../../lib/gl_format_color\").formatColor,h=t(\"../scatter/subtypes\"),f=t(\"../scatter/make_bubble_size_func\"),p=t(\"./constants\"),d=t(\"../../constants/interactions\").DESELECTDIM,g={start:1,left:1,end:-1,right:-1,middle:0,center:0,bottom:1,top:-1};function v(t){var e,r=t._length,i=t.textfont,a=t.textposition,o=Array.isArray(a)?a:[a],s=i.color,l=i.size,c=i.family,u={};for(u.text=t.text,u.opacity=t.opacity,u.font={},u.align=[],u.baseline=[],e=0;e<o.length;e++){var h=o[e].split(/\\s+/);switch(h[1]){case\"left\":u.align.push(\"right\");break;case\"right\":u.align.push(\"left\");break;default:u.align.push(h[1])}switch(h[0]){case\"top\":u.baseline.push(\"bottom\");break;case\"bottom\":u.baseline.push(\"top\");break;default:u.baseline.push(h[0])}}if(Array.isArray(s))for(u.color=new Array(r),e=0;e<r;e++)u.color[e]=s[e];else u.color=s;if(Array.isArray(l)||Array.isArray(c))for(u.font=new Array(r),e=0;e<r;e++){var f=u.font[e]={};f.size=Array.isArray(l)?n(l[e])?l[e]:0:l,f.family=Array.isArray(c)?c[e]:c}else u.font={size:l,family:c};return u}function m(t){var e,r,n=t._length,i=t.marker,o={},l=Array.isArray(i.symbol),c=s.isArrayOrTypedArray(i.color),h=s.isArrayOrTypedArray(i.line.color),d=s.isArrayOrTypedArray(i.opacity),g=s.isArrayOrTypedArray(i.size),v=s.isArrayOrTypedArray(i.line.width);if(l||(r=p.OPEN_RE.test(i.symbol)),l||c||h||d){o.colors=new Array(n),o.borderColors=new Array(n);var m=u(i,i.opacity,n),y=u(i.line,i.opacity,n);if(!Array.isArray(y[0])){var x=y;for(y=Array(n),e=0;e<n;e++)y[e]=x}if(!Array.isArray(m[0])){var b=m;for(m=Array(n),e=0;e<n;e++)m[e]=b}for(o.colors=m,o.borderColors=y,e=0;e<n;e++){if(l){var _=i.symbol[e];r=p.OPEN_RE.test(_)}r&&(y[e]=m[e].slice(),m[e]=m[e].slice(),m[e][3]=0)}o.opacity=t.opacity}else r?(o.color=a(i.color,\"uint8\"),o.color[3]=0,o.borderColor=a(i.color,\"uint8\")):(o.color=a(i.color,\"uint8\"),o.borderColor=a(i.line.color,\"uint8\")),o.opacity=t.opacity*i.opacity;if(l)for(o.markers=new Array(n),e=0;e<n;e++)o.markers[e]=M(i.symbol[e]);else o.marker=M(i.symbol);var w,k=f(t);if(g||v){var T,A=o.sizes=new Array(n),S=o.borderSizes=new Array(n),E=0;if(g){for(e=0;e<n;e++)A[e]=k(i.size[e]),E+=A[e];T=E/n}else for(w=k(i.size),e=0;e<n;e++)A[e]=w;if(v)for(e=0;e<n;e++)S[e]=i.line.width[e]/2;else for(w=i.line.width/2,e=0;e<n;e++)S[e]=w;o.sizeAvg=T}else o.size=k(i&&i.size||10),o.borderSizes=k(i.line.width);return o}function y(t,e){var r=t.marker,n={};return e?(e.marker&&e.marker.symbol?n=m(s.extendFlat({},r,e.marker)):e.marker&&(e.marker.size&&(n.size=e.marker.size/2),e.marker.color&&(n.colors=e.marker.color),void 0!==e.marker.opacity&&(n.opacity=e.marker.opacity)),n):n}function x(t,e){var r={};if(!e)return r;if(e.textfont){var n={opacity:1,text:t.text,textposition:t.textposition,textfont:s.extendFlat({},t.textfont)};e.textfont&&s.extendFlat(n.textfont,e.textfont),r=v(n)}return r}function b(t,e){var r={capSize:2*e.width,lineWidth:e.thickness,color:e.color};return e.copy_ystyle&&(r=t.error_y),r}var _=p.SYMBOL_SDF_SIZE,w=p.SYMBOL_SIZE,k=p.SYMBOL_STROKE,T={},A=l.symbolFuncs[0](.05*w);function M(t){if(\"circle\"===t)return null;var e,r,n=l.symbolNumber(t),a=l.symbolFuncs[n%100],o=!!l.symbolNoDot[n%100],s=!!l.symbolNoFill[n%100],c=p.DOT_RE.test(t);return T[t]?T[t]:(e=c&&!o?a(1.1*w)+A:a(w),r=i(e,{w:_,h:_,viewBox:[-w,-w,w,w],stroke:s?k:-k}),T[t]=r,r||null)}e.exports={style:function(t,e){var r,n={marker:void 0,markerSel:void 0,markerUnsel:void 0,line:void 0,fill:void 0,errorX:void 0,errorY:void 0,text:void 0,textSel:void 0,textUnsel:void 0};if(!0!==e.visible)return n;if(h.hasText(e)&&(n.text=v(e),n.textSel=x(e,e.selected),n.textUnsel=x(e,e.unselected)),h.hasMarkers(e)&&(n.marker=m(e),n.markerSel=y(e,e.selected),n.markerUnsel=y(e,e.unselected),!e.unselected&&Array.isArray(e.marker.opacity))){var i=e.marker.opacity;for(n.markerUnsel.opacity=new Array(i.length),r=0;r<i.length;r++)n.markerUnsel.opacity[r]=d*i[r]}if(h.hasLines(e)){n.line={overlay:!0,thickness:e.line.width,color:e.line.color,opacity:e.opacity};var a=(p.DASHES[e.line.dash]||[1]).slice();for(r=0;r<a.length;++r)a[r]*=e.line.width;n.line.dashes=a}return e.error_x&&e.error_x.visible&&(n.errorX=b(e,e.error_x)),e.error_y&&e.error_y.visible&&(n.errorY=b(e,e.error_y)),e.fill&&\"none\"!==e.fill&&(n.fill={closed:!0,fill:e.fillcolor,thickness:0}),n},markerStyle:m,markerSelection:y,linePositions:function(t,e,r){var n,i,a=r.length,o=a/2;if(h.hasLines(e)&&o)if(\"hv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i+2],r[2*i+1]));n.push(r[a-2],r[a-1])}else if(\"hvh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var s=(r[2*i]+r[2*i+2])/2;n.push(r[2*i],r[2*i+1],s,r[2*i+1],s,r[2*i+3])}n.push(r[a-2],r[a-1])}else if(\"vhv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var l=(r[2*i+1]+r[2*i+3])/2;n.push(r[2*i],r[2*i+1],r[2*i],l,r[2*i+2],l)}n.push(r[a-2],r[a-1])}else if(\"vh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+3]));n.push(r[a-2],r[a-1])}else n=r;var c=!1;for(i=0;i<n.length;i++)if(isNaN(n[i])){c=!0;break}var u=c||n.length>p.TOO_MANY_POINTS?\"rect\":h.hasMarkers(e)?\"rect\":\"round\";if(c&&e.connectgaps){var f=n[0],d=n[1];for(i=0;i<n.length;i+=2)isNaN(n[i])||isNaN(n[i+1])?(n[i]=f,n[i+1]=d):(f=n[i],d=n[i+1])}return{join:u,positions:n}},errorBarPositions:function(t,e,r,i,a){var s=o.getComponentMethod(\"errorbars\",\"makeComputeError\"),l=c.getFromId(t,e.xaxis),u=c.getFromId(t,e.yaxis),h=r.length/2,f={};function p(t,i){var a=i._id.charAt(0),o=e[\"error_\"+a];if(o&&o.visible&&(\"linear\"===i.type||\"log\"===i.type)){for(var l=s(o),c={x:0,y:1}[a],u={x:[0,1,2,3],y:[2,3,0,1]}[a],p=new Float64Array(4*h),d=1/0,g=-1/0,v=0,m=0;v<h;v++,m+=4){var y=t[v];if(n(y)){var x=r[2*v+c],b=l(y,v),_=b[0],w=b[1];if(n(_)&&n(w)){var k=y-_,T=y+w;p[m+u[0]]=x-i.c2l(k),p[m+u[1]]=i.c2l(T)-x,p[m+u[2]]=0,p[m+u[3]]=0,d=Math.min(d,y-_),g=Math.max(g,y+w)}}}f[a]={positions:r,errors:p,_bnds:[d,g]}}}return p(i,l),p(a,u),f},textPosition:function(t,e,r,n){var i,a=e._length,o={};if(h.hasMarkers(e)){var s=r.font,l=r.align,c=r.baseline;for(o.offset=new Array(a),i=0;i<a;i++){var u=n.sizes?n.sizes[i]:n.size,f=Array.isArray(s)?s[i].size:s.size,p=Array.isArray(l)?l.length>1?l[i]:l[0]:l,d=Array.isArray(c)?c.length>1?c[i]:c[0]:c,v=g[p],m=g[d],y=u?u/.8+1:0,x=-m*y-.5*m;o.offset[i]=[v*y/f,x/f]}}return o}}},{\"../../components/drawing\":614,\"../../constants/interactions\":694,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../plots/cartesian/axis_ids\":770,\"../../registry\":847,\"../scatter/make_bubble_size_func\":1128,\"../scatter/subtypes\":1135,\"./constants\":1162,\"color-normalize\":120,\"fast-isnumeric\":225,\"svg-path-sdf\":535}],1164:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"../scatter/constants\"),s=t(\"../scatter/subtypes\"),l=t(\"../scatter/xy_defaults\"),c=t(\"../scatter/marker_defaults\"),u=t(\"../scatter/line_defaults\"),h=t(\"../scatter/fillcolor_defaults\"),f=t(\"../scatter/text_defaults\");e.exports=function(t,e,r,p){function d(r,i){return n.coerce(t,e,a,r,i)}var g=!!t.marker&&/-open/.test(t.marker.symbol),v=s.isBubble(t),m=l(t,e,p,d);if(m){var y=m<o.PTS_LINESONLY?\"lines+markers\":\"lines\";d(\"text\"),d(\"hovertext\"),d(\"hovertemplate\"),d(\"mode\",y),s.hasLines(e)&&(d(\"connectgaps\"),u(t,e,r,p,d),d(\"line.shape\")),s.hasMarkers(e)&&(c(t,e,r,p,d),d(\"marker.line.width\",g||v?1:0)),s.hasText(e)&&f(t,e,p,d);var x=(e.line||{}).color,b=(e.marker||{}).color;d(\"fill\"),\"none\"!==e.fill&&h(t,e,r,d);var _=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");_(t,e,x||b||r,{axis:\"y\"}),_(t,e,x||b||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}},{\"../../lib\":719,\"../../registry\":847,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"../scatter/xy_defaults\":1137,\"./attributes\":1160}],1165:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../constants/interactions\").DESELECTDIM;e.exports={styleTextSelection:function(t){var e,r,o=t[0],s=o.trace,l=o.t,c=l._scene,u=l.index,h=c.selectBatch[u],f=c.unselectBatch[u],p=c.textOptions[u],d=c.textSelectedOptions[u]||{},g=c.textUnselectedOptions[u]||{},v=n.extendFlat({},p);if(h.length||f.length){var m=d.color,y=g.color,x=p.color,b=Array.isArray(x);for(v.color=new Array(s._length),e=0;e<h.length;e++)r=h[e],v.color[r]=m||(b?x[r]:x);for(e=0;e<f.length;e++){r=f[e];var _=b?x[r]:x;v.color[r]=y||(m?_:i.addOpacity(_,a))}}c.glText[u].update(v)}}},{\"../../components/color\":593,\"../../constants/interactions\":694,\"../../lib\":719}],1166:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\");function o(t,e,r,o){var s=t.xa,l=t.ya,c=t.distance,u=t.dxy,h=t.index,f={pointNumber:h,x:e[h],y:r[h]};f.tx=Array.isArray(o.text)?o.text[h]:o.text,f.htx=Array.isArray(o.hovertext)?o.hovertext[h]:o.hovertext,f.data=Array.isArray(o.customdata)?o.customdata[h]:o.customdata,f.tp=Array.isArray(o.textposition)?o.textposition[h]:o.textposition;var p=o.textfont;p&&(f.ts=Array.isArray(p.size)?p.size[h]:p.size,f.tc=Array.isArray(p.color)?p.color[h]:p.color,f.tf=Array.isArray(p.family)?p.family[h]:p.family);var d=o.marker;d&&(f.ms=i.isArrayOrTypedArray(d.size)?d.size[h]:d.size,f.mo=i.isArrayOrTypedArray(d.opacity)?d.opacity[h]:d.opacity,f.mx=Array.isArray(d.symbol)?d.symbol[h]:d.symbol,f.mc=i.isArrayOrTypedArray(d.color)?d.color[h]:d.color);var g=d&&d.line;g&&(f.mlc=Array.isArray(g.color)?g.color[h]:g.color,f.mlw=i.isArrayOrTypedArray(g.width)?g.width[h]:g.width);var v=d&&d.gradient;v&&\"none\"!==v.type&&(f.mgt=Array.isArray(v.type)?v.type[h]:v.type,f.mgc=Array.isArray(v.color)?v.color[h]:v.color);var m=s.c2p(f.x,!0),y=l.c2p(f.y,!0),x=f.mrc||1,b=o.hoverlabel;b&&(f.hbg=Array.isArray(b.bgcolor)?b.bgcolor[h]:b.bgcolor,f.hbc=Array.isArray(b.bordercolor)?b.bordercolor[h]:b.bordercolor,f.hts=Array.isArray(b.font.size)?b.font.size[h]:b.font.size,f.htc=Array.isArray(b.font.color)?b.font.color[h]:b.font.color,f.htf=Array.isArray(b.font.family)?b.font.family[h]:b.font.family,f.hnl=Array.isArray(b.namelength)?b.namelength[h]:b.namelength);var _=o.hoverinfo;_&&(f.hi=Array.isArray(_)?_[h]:_);var w=o.hovertemplate;w&&(f.ht=Array.isArray(w)?w[h]:w);var k={};return k[t.index]=f,i.extendFlat(t,{color:a(o,f),x0:m-x,x1:m+x,xLabelVal:f.x,y0:y-x,y1:y+x,yLabelVal:f.y,cd:k,distance:c,spikeDistance:u,hovertemplate:f.ht}),f.htx?t.text=f.htx:f.tx?t.text=f.tx:o.text&&(t.text=o.text),i.fillText(f,o,t),n.getComponentMethod(\"errorbars\",\"hoverInfo\")(f,o,t),t}e.exports={hoverPoints:function(t,e,r,n){var i,a,s,l,c,u,h,f,p,d=t.cd,g=d[0].t,v=d[0].trace,m=t.xa,y=t.ya,x=g.x,b=g.y,_=m.c2p(e),w=y.c2p(r),k=t.distance;if(g.tree){var T=m.p2c(_-k),A=m.p2c(_+k),M=y.p2c(w-k),S=y.p2c(w+k);i=\"x\"===n?g.tree.range(Math.min(T,A),Math.min(y._rl[0],y._rl[1]),Math.max(T,A),Math.max(y._rl[0],y._rl[1])):g.tree.range(Math.min(T,A),Math.min(M,S),Math.max(T,A),Math.max(M,S))}else{if(!g.ids)return[t];i=g.ids}var E=k;if(\"x\"===n)for(c=0;c<i.length;c++)s=x[i[c]],(u=Math.abs(m.c2p(s)-_))<E&&(E=u,h=y.c2p(b[i[c]])-w,p=Math.sqrt(u*u+h*h),a=i[c]);else for(c=i.length-1;c>-1;c--)s=x[i[c]],l=b[i[c]],u=m.c2p(s)-_,h=y.c2p(l)-w,(f=Math.sqrt(u*u+h*h))<E&&(E=p=f,a=i[c]);return t.index=a,t.distance=E,t.dxy=p,void 0===a?[t]:(o(t,x,b,v),[t])},calcHover:o}},{\"../../lib\":719,\"../../registry\":847,\"../scatter/get_trace_color\":1121}],1167:[function(t,e,r){\"use strict\";var n=t(\"./hover\");e.exports={moduleType:\"trace\",name:\"scattergl\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../scatter/cross_trace_defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:n.hoverPoints,selectPoints:t(\"./select\"),meta:{}}},{\"../../plots/cartesian\":778,\"../scatter/cross_trace_defaults\":1118,\"../scatter/marker_colorbar\":1129,\"./attributes\":1160,\"./calc\":1161,\"./defaults\":1164,\"./hover\":1166,\"./plot\":1168,\"./select\":1170}],1168:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"regl-line2d\"),a=t(\"regl-error2d\"),o=t(\"gl-text\"),s=t(\"../../lib\"),l=t(\"../../lib/prepare_regl\"),c=t(\"../scatter/subtypes\"),u=t(\"../scatter/link_traces\"),h=t(\"./edit_style\").styleTextSelection;e.exports=function(t,e,r){if(r.length){var f,p,d=t._fullLayout,g=e._scene,v=e.xaxis,m=e.yaxis;if(g)if(l(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])){var y=g.count,x=d._glcanvas.data()[0].regl;if(u(t,e,r),g.dirty){if(!0===g.error2d&&(g.error2d=a(x)),!0===g.line2d&&(g.line2d=i(x)),!0===g.scatter2d&&(g.scatter2d=n(x)),!0===g.fill2d&&(g.fill2d=i(x)),!0===g.glText)for(g.glText=new Array(y),f=0;f<y;f++)g.glText[f]=new o(x);if(g.glText){if(y>g.glText.length){var b=y-g.glText.length;for(f=0;f<b;f++)g.glText.push(new o(x))}else if(y<g.glText.length){var _=g.glText.length-y;g.glText.splice(y,_).forEach(function(t){t.destroy()})}for(f=0;f<y;f++)g.glText[f].update(g.textOptions[f])}if(g.line2d&&(g.line2d.update(g.lineOptions),g.lineOptions=g.lineOptions.map(function(t){if(t&&t.positions){for(var e=t.positions,r=0;r<e.length&&(isNaN(e[r])||isNaN(e[r+1]));)r+=2;for(var n=e.length-2;n>r&&(isNaN(e[n])||isNaN(e[n+1]));)n-=2;t.positions=e.slice(r,n+2)}return t}),g.line2d.update(g.lineOptions)),g.error2d){var w=(g.errorXOptions||[]).concat(g.errorYOptions||[]);g.error2d.update(w)}g.scatter2d&&g.scatter2d.update(g.markerOptions),g.fillOrder=s.repeat(null,y),g.fill2d&&(g.fillOptions=g.fillOptions.map(function(t,e){var n=r[e];if(t&&n&&n[0]&&n[0].trace){var i,a,o=n[0],s=o.trace,l=o.t,c=g.lineOptions[e],u=[];s._ownfill&&u.push(e),s._nexttrace&&u.push(e+1),u.length&&(g.fillOrder[e]=u);var h,f,p=[],d=c&&c.positions||l.positions;if(\"tozeroy\"===s.fill){for(h=0;h<d.length&&isNaN(d[h+1]);)h+=2;for(f=d.length-2;f>h&&isNaN(d[f+1]);)f-=2;0!==d[h+1]&&(p=[d[h],0]),p=p.concat(d.slice(h,f+2)),0!==d[f+1]&&(p=p.concat([d[f],0]))}else if(\"tozerox\"===s.fill){for(h=0;h<d.length&&isNaN(d[h]);)h+=2;for(f=d.length-2;f>h&&isNaN(d[f]);)f-=2;0!==d[h]&&(p=[0,d[h+1]]),p=p.concat(d.slice(h,f+2)),0!==d[f]&&(p=p.concat([0,d[f+1]]))}else if(\"toself\"===s.fill||\"tonext\"===s.fill){for(p=[],i=0,a=0;a<d.length;a+=2)(isNaN(d[a])||isNaN(d[a+1]))&&((p=p.concat(d.slice(i,a))).push(d[i],d[i+1]),i=a+2);p=p.concat(d.slice(i)),i&&p.push(d[i],d[i+1])}else{var v=s._nexttrace;if(v){var m=g.lineOptions[e+1];if(m){var y=m.positions;if(\"tonexty\"===s.fill){for(p=d.slice(),e=Math.floor(y.length/2);e--;){var x=y[2*e],b=y[2*e+1];isNaN(x)||isNaN(b)||p.push(x,b)}t.fill=v.fillcolor}}}}if(s._prevtrace&&\"tonext\"===s._prevtrace.fill){var _=g.lineOptions[e-1].positions,w=p.length/2,k=[i=w];for(a=0;a<_.length;a+=2)(isNaN(_[a])||isNaN(_[a+1]))&&(k.push(a/2+w+1),i=a+2);p=p.concat(_),t.hole=k}return t.fillmode=s.fill,t.opacity=s.opacity,t.positions=p,t}}),g.fill2d.update(g.fillOptions))}var k=d.dragmode,T=\"lasso\"===k||\"select\"===k,A=d.clickmode.indexOf(\"select\")>-1;for(f=0;f<y;f++){var M=r[f][0],S=M.trace,E=M.t,C=E.index,L=S._length,P=E.x,O=E.y;if(S.selectedpoints||T||A){if(T||(T=!0),S.selectedpoints){var z=g.selectBatch[C]=s.selIndices2selPoints(S),I={};for(p=0;p<z.length;p++)I[z[p]]=1;var D=[];for(p=0;p<L;p++)I[p]||D.push(p);g.unselectBatch[C]=D}var R=E.xpx=new Array(L),F=E.ypx=new Array(L);for(p=0;p<L;p++)R[p]=v.c2p(P[p]),F[p]=m.c2p(O[p])}else E.xpx=E.ypx=null}if(T){if(g.select2d||(g.select2d=n(d._glcanvas.data()[1].regl)),g.scatter2d){var B=new Array(y);for(f=0;f<y;f++)B[f]=g.selectBatch[f].length||g.unselectBatch[f].length?g.markerUnselectedOptions[f]:{};g.scatter2d.update(B)}g.select2d&&(g.select2d.update(g.markerOptions),g.select2d.update(g.markerSelectedOptions)),g.glText&&r.forEach(function(t){var e=((t||[])[0]||{}).trace||{};c.hasText(e)&&h(t)})}else g.scatter2d&&g.scatter2d.update(g.markerOptions);var N={viewport:function(t,e,r){var n=t._size,i=t.width,a=t.height;return[n.l+e.domain[0]*n.w,n.b+r.domain[0]*n.h,i-n.r-(1-e.domain[1])*n.w,a-n.t-(1-r.domain[1])*n.h]}(d,v,m),range:[(v._rl||v.range)[0],(m._rl||m.range)[0],(v._rl||v.range)[1],(m._rl||m.range)[1]]},j=s.repeat(N,g.count);g.fill2d&&g.fill2d.update(j),g.line2d&&g.line2d.update(j),g.error2d&&g.error2d.update(j.concat(j)),g.scatter2d&&g.scatter2d.update(j),g.select2d&&g.select2d.update(j),g.glText&&g.glText.forEach(function(t){t.update(N)})}else g.init()}}},{\"../../lib\":719,\"../../lib/prepare_regl\":732,\"../scatter/link_traces\":1127,\"../scatter/subtypes\":1135,\"./edit_style\":1165,\"gl-text\":317,\"regl-error2d\":490,\"regl-line2d\":491,\"regl-scatter2d\":497}],1169:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=e._scene,i={count:0,dirty:!0,lineOptions:[],fillOptions:[],markerOptions:[],markerSelectedOptions:[],markerUnselectedOptions:[],errorXOptions:[],errorYOptions:[],textOptions:[],textSelectedOptions:[],textUnselectedOptions:[],selectBatch:[],unselectBatch:[]},a={fill2d:!1,scatter2d:!1,error2d:!1,line2d:!1,glText:!1,select2d:!1};return e._scene||((r=e._scene={}).init=function(){n.extendFlat(r,a,i)},r.init(),r.update=function(t){var e=n.repeat(t,r.count);if(r.fill2d&&r.fill2d.update(e),r.scatter2d&&r.scatter2d.update(e),r.line2d&&r.line2d.update(e),r.error2d&&r.error2d.update(e.concat(e)),r.select2d&&r.select2d.update(e),r.glText)for(var i=0;i<r.count;i++)r.glText[i].update(t)},r.draw=function(){for(var t=r.count,e=r.fill2d,i=r.error2d,a=r.line2d,o=r.scatter2d,s=r.glText,l=r.select2d,c=r.selectBatch,u=r.unselectBatch,h=0;h<t;h++){if(e&&r.fillOrder[h]&&e.draw(r.fillOrder[h]),a&&r.lineOptions[h]&&a.draw(h),i&&(r.errorXOptions[h]&&i.draw(h),r.errorYOptions[h]&&i.draw(h+t)),o&&r.markerOptions[h])if(u[h].length){var f=n.repeat([],r.count);f[h]=u[h],o.draw(f)}else c[h].length||o.draw(h);s[h]&&r.textOptions[h]&&s[h].render()}l&&l.draw(c),r.dirty=!1},r.destroy=function(){r.fill2d&&r.fill2d.destroy&&r.fill2d.destroy(),r.scatter2d&&r.scatter2d.destroy&&r.scatter2d.destroy(),r.error2d&&r.error2d.destroy&&r.error2d.destroy(),r.line2d&&r.line2d.destroy&&r.line2d.destroy(),r.select2d&&r.select2d.destroy&&r.select2d.destroy(),r.glText&&r.glText.forEach(function(t){t.destroy&&t.destroy()}),r.lineOptions=null,r.fillOptions=null,r.markerOptions=null,r.markerSelectedOptions=null,r.markerUnselectedOptions=null,r.errorXOptions=null,r.errorYOptions=null,r.textOptions=null,r.textSelectedOptions=null,r.textUnselectedOptions=null,r.selectBatch=null,r.unselectBatch=null,e._scene=null}),r.dirty||n.extendFlat(r,i),r}},{\"../../lib\":719}],1170:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"./edit_style\").styleTextSelection;e.exports=function(t,e){var r=t.cd,a=[],o=r[0].trace,s=r[0].t,l=o._length,c=s.x,u=s.y,h=s._scene,f=s.index;if(!h)return a;var p=n.hasText(o),d=n.hasMarkers(o),g=!d&&!p;if(!0!==o.visible||g)return a;var v=[],m=[];if(!1!==e&&!e.degenerate)for(var y=0;y<l;y++)e.contains([s.xpx[y],s.ypx[y]],!1,y,t)?(v.push(y),a.push({pointNumber:y,x:c[y],y:u[y]})):m.push(y);if(d){var x=h.scatter2d;if(v.length||m.length){if(!h.selectBatch[f].length&&!h.unselectBatch[f].length){var b=new Array(h.count);b[f]=h.markerUnselectedOptions[f],x.update.apply(x,b)}}else{var _=new Array(h.count);_[f]=h.markerOptions[f],x.update.apply(x,_)}}return h.selectBatch[f]=v,h.unselectBatch[f]=m,p&&i(r),a}},{\"../scatter/subtypes\":1135,\"./edit_style\":1165}],1171:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scattergeo/attributes\"),a=t(\"../scatter/attributes\"),o=t(\"../../plots/mapbox/layout_attributes\"),s=t(\"../../plots/attributes\"),l=t(\"../../components/colorscale/attributes\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../plot_api/edit_types\").overrideAll,h=i.line,f=i.marker;e.exports=u({lon:i.lon,lat:i.lat,mode:c({},a.mode,{dflt:\"markers\"}),text:c({},a.text,{}),hovertext:c({},a.hovertext,{}),line:{color:h.color,width:h.width},connectgaps:a.connectgaps,marker:c({symbol:{valType:\"string\",dflt:\"circle\",arrayOk:!0},opacity:f.opacity,size:f.size,sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode},l(\"marker\")),fill:i.fill,fillcolor:a.fillcolor,textfont:o.layers.symbol.textfont,textposition:o.layers.symbol.textposition,below:{valType:\"string\"},selected:{marker:a.selected.marker},unselected:{marker:a.unselected.marker},hoverinfo:c({},s.hoverinfo,{flags:[\"lon\",\"lat\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../../plots/mapbox/layout_attributes\":824,\"../scatter/attributes\":1112,\"../scattergeo/attributes\":1151}],1172:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../lib/geojson_utils\"),s=t(\"../../components/colorscale\"),l=t(\"../../components/drawing\"),c=t(\"../scatter/make_bubble_size_func\"),u=t(\"../scatter/subtypes\"),h=t(\"../../plots/mapbox/convert_text_opts\");function f(){return{geojson:o.makeBlank(),layout:{visibility:\"none\"},paint:{}}}function p(t){return i.isArrayOrTypedArray(t)?function(t){return t}:t?function(){return t}:d}function d(){return\"\"}function g(t){return t[0]===a}e.exports=function(t){var e,r=t[0].trace,a=!0===r.visible&&0!==r._length,v=\"none\"!==r.fill,m=u.hasLines(r),y=u.hasMarkers(r),x=u.hasText(r),b=y&&\"circle\"===r.marker.symbol,_=y&&\"circle\"!==r.marker.symbol,w=f(),k=f(),T=f(),A=f(),M={fill:w,line:k,circle:T,symbol:A};if(!a)return M;if((v||m)&&(e=o.calcTraceToLineCoords(t)),v&&(w.geojson=o.makePolygon(e),w.layout.visibility=\"visible\",i.extendFlat(w.paint,{\"fill-color\":r.fillcolor})),m&&(k.geojson=o.makeLine(e),k.layout.visibility=\"visible\",i.extendFlat(k.paint,{\"line-width\":r.line.width,\"line-color\":r.line.color,\"line-opacity\":r.opacity})),b){var S=function(t){var e,r,a,o,u=t[0].trace,h=u.marker,f=u.selectedpoints,p=i.isArrayOrTypedArray(h.color),d=i.isArrayOrTypedArray(h.size),v=i.isArrayOrTypedArray(h.opacity);function m(t){return u.opacity*t}p&&(r=s.hasColorscale(u,\"marker\")?s.makeColorScaleFuncFromTrace(h):i.identity);d&&(a=c(u));v&&(o=function(t){var e=n(t)?+i.constrain(t,0,1):0;return m(e)});var y,x=[];for(e=0;e<t.length;e++){var b=t[e],_=b.lonlat;if(!g(_)){var w={};r&&(w.mcc=b.mcc=r(b.mc)),a&&(w.mrc=b.mrc=a(b.ms)),o&&(w.mo=o(b.mo)),f&&(w.selected=b.selected||0),x.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:_},properties:w})}}if(f)for(y=l.makeSelectedPointStyleFns(u),e=0;e<x.length;e++){var k=x[e].properties;y.selectedOpacityFn&&(k.mo=m(y.selectedOpacityFn(k))),y.selectedColorFn&&(k.mcc=y.selectedColorFn(k)),y.selectedSizeFn&&(k.mrc=y.selectedSizeFn(k))}return{geojson:{type:\"FeatureCollection\",features:x},mcc:p||y&&y.selectedColorFn?{type:\"identity\",property:\"mcc\"}:h.color,mrc:d||y&&y.selectedSizeFn?{type:\"identity\",property:\"mrc\"}:(T=h.size,T/2),mo:v||y&&y.selectedOpacityFn?{type:\"identity\",property:\"mo\"}:m(h.opacity)};var T}(t);T.geojson=S.geojson,T.layout.visibility=\"visible\",i.extendFlat(T.paint,{\"circle-color\":S.mcc,\"circle-radius\":S.mrc,\"circle-opacity\":S.mo})}if((_||x)&&(A.geojson=function(t){for(var e=t[0].trace,r=(e.marker||{}).symbol,n=e.text,i=\"circle\"!==r?p(r):d,a=u.hasText(e)?p(n):d,o=[],s=0;s<t.length;s++){var l=t[s];g(l.lonlat)||o.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:l.lonlat},properties:{symbol:i(l.mx),text:a(l.tx)}})}return{type:\"FeatureCollection\",features:o}}(t),i.extendFlat(A.layout,{visibility:\"visible\",\"icon-image\":\"{symbol}-15\",\"text-field\":\"{text}\"}),_&&(i.extendFlat(A.layout,{\"icon-size\":r.marker.size/10}),i.extendFlat(A.paint,{\"icon-opacity\":r.opacity*r.marker.opacity,\"icon-color\":r.marker.color})),x)){var E=(r.marker||{}).size,C=h(r.textposition,E);i.extendFlat(A.layout,{\"text-size\":r.textfont.size,\"text-anchor\":C.anchor,\"text-offset\":C.offset}),i.extendFlat(A.paint,{\"text-color\":r.textfont.color,\"text-opacity\":r.opacity})}return M}},{\"../../components/colorscale\":605,\"../../components/drawing\":614,\"../../constants/numerical\":695,\"../../lib\":719,\"../../lib/geojson_utils\":714,\"../../plots/mapbox/convert_text_opts\":821,\"../scatter/make_bubble_size_func\":1128,\"../scatter/subtypes\":1135,\"fast-isnumeric\":225}],1173:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function h(r,i){return n.coerce(t,e,c,r,i)}if(function(t,e,r){var n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length);return e._length=a,a}(0,e,h)){if(h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"mode\"),h(\"below\"),i.hasLines(e)&&(o(t,e,r,u,h,{noDash:!0}),h(\"connectgaps\")),i.hasMarkers(e)){a(t,e,r,u,h,{noLine:!0});var f=e.marker;\"circle\"!==f.symbol&&(n.isArrayOrTypedArray(f.size)&&(f.size=f.size[0]),n.isArrayOrTypedArray(f.color)&&(f.color=f.color[0]))}i.hasText(e)&&s(t,e,u,h,{noSelect:!0}),h(\"fill\"),\"none\"!==e.fill&&l(t,e,r,h),n.coerceSelectionMarkerOpacity(e,h)}else e.visible=!1}},{\"../../lib\":719,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1171}],1174:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t}},{}],1175:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\"),o=i.fillText,s=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,h=t.ya,f=t.subplot,p=360*(e>=0?Math.floor((e+180)/360):Math.ceil((e-180)/360)),d=e-p;if(n.getClosest(l,function(t){var e=t.lonlat;if(e[0]===s)return 1/0;var n=i.modHalf(e[0],360),a=e[1],o=f.project([n,a]),l=o.x-u.c2p([d,a]),c=o.y-h.c2p([n,r]),p=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(l*l+c*c)-p,1-3/p)},t),!1!==t.index){var g=l[t.index],v=g.lonlat,m=[i.modHalf(v[0],360)+p,v[1]],y=u.c2p(m),x=h.c2p(m),b=g.mrc||1;return t.x0=y-b,t.x1=y+b,t.y0=x-b,t.y1=x+b,t.color=a(c,g),t.extraText=function(t,e,r){if(t.hovertemplate)return;var n=(e.hi||t.hoverinfo).split(\"+\"),i=-1!==n.indexOf(\"all\"),a=-1!==n.indexOf(\"lon\"),s=-1!==n.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}i||a&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):a?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(i||-1!==n.indexOf(\"text\"))&&o(e,t,c);return c.join(\"<br>\")}(c,g,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},{\"../../components/fx\":632,\"../../constants/numerical\":695,\"../../lib\":719,\"../scatter/get_trace_color\":1121}],1176:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"../scattergeo/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.update(e)},moduleType:\"trace\",name:\"scattermapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"symbols\",\"showLegend\",\"scatterlike\"],meta:{}}},{\"../../plots/mapbox\":822,\"../scatter/marker_colorbar\":1129,\"../scattergeo/calc\":1152,\"./attributes\":1171,\"./defaults\":1173,\"./event_data\":1174,\"./hover\":1175,\"./plot\":1177,\"./select\":1178}],1177:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix,a=[\"fill\",\"line\",\"circle\",\"symbol\"];function o(t,e){this.subplot=t,this.uid=e,this.sourceIds={fill:\"source-\"+e+\"-fill\",line:\"source-\"+e+\"-line\",circle:\"source-\"+e+\"-circle\",symbol:\"source-\"+e+\"-symbol\"},this.layerIds={fill:i+e+\"-fill\",line:i+e+\"-line\",circle:i+e+\"-circle\",symbol:i+e+\"-symbol\"},this.below=null}var s=o.prototype;s.addSource=function(t,e){this.subplot.map.addSource(this.sourceIds[t],{type:\"geojson\",data:e.geojson})},s.setSourceData=function(t,e){this.subplot.map.getSource(this.sourceIds[t]).setData(e.geojson)},s.addLayer=function(t,e,r){this.subplot.addLayer({type:t,id:this.layerIds[t],source:this.sourceIds[t],layout:e.layout,paint:e.paint},r)},s.update=function(t){var e,r,i,o=this.subplot,s=o.map,l=n(t),c=o.belowLookup[\"trace-\"+this.uid];if(c!==this.below){for(e=a.length-1;e>=0;e--)r=a[e],s.removeLayer(this.layerIds[r]);for(e=0;e<a.length;e++)i=l[r=a[e]],this.addLayer(r,i,c);this.below=c}for(e=0;e<a.length;e++)i=l[r=a[e]],o.setOptions(this.layerIds[r],\"setLayoutProperty\",i.layout),\"visible\"===i.layout.visibility&&(this.setSourceData(r,i),o.setOptions(this.layerIds[r],\"setPaintProperty\",i.paint));t[0].trace._glTrace=this},s.dispose=function(){for(var t=this.subplot.map,e=a.length-1;e>=0;e--){var r=a[e];t.removeLayer(this.layerIds[r]),t.removeSource(this.sourceIds[r])}},e.exports=function(t,e){for(var r=e[0].trace,i=new o(t,r.uid),s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid],c=0;c<a.length;c++){var u=a[c],h=s[u];i.addSource(u,h),i.addLayer(u,h,l)}return e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":820,\"./convert\":1172}],1178:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,o=t.cd,s=t.xaxis,l=t.yaxis,c=[],u=o[0].trace;if(!i.hasMarkers(u))return[];if(!1===e)for(r=0;r<o.length;r++)o[r].selected=0;else for(r=0;r<o.length;r++){var h=o[r],f=h.lonlat;if(f[0]!==a){var p=[n.modHalf(f[0],360),f[1]],d=[s.c2p(p),l.c2p(p)];e.contains(d,null,r,t)?(c.push({pointNumber:r,lon:f[0],lat:f[1]}),h.selected=1):h.selected=0}}return c}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../scatter/subtypes\":1135}],1179:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../scatter/attributes\"),o=t(\"../../plots/attributes\"),s=a.line;e.exports={mode:a.mode,r:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},theta:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},r0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dr:{valType:\"number\",dflt:1,editType:\"calc\"},theta0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dtheta:{valType:\"number\",editType:\"calc\"},thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\",\"gradians\"],dflt:\"degrees\",editType:\"calc+clearAxisTypes\"},text:a.text,hovertext:a.hovertext,line:{color:s.color,width:s.width,dash:s.dash,shape:i({},s.shape,{values:[\"linear\",\"spline\"]}),smoothing:s.smoothing,editType:\"calc\"},connectgaps:a.connectgaps,marker:a.marker,cliponaxis:i({},a.cliponaxis,{dflt:!1}),textposition:a.textposition,textfont:a.textfont,fill:i({},a.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:a.fillcolor,hoverinfo:i({},o.hoverinfo,{flags:[\"r\",\"theta\",\"text\",\"name\"]}),hoveron:a.hoveron,hovertemplate:n(),selected:a.selected,unselected:a.unselected}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1180:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../plots/cartesian/axes\"),o=t(\"../scatter/colorscale_calc\"),s=t(\"../scatter/arrays_to_calcdata\"),l=t(\"../scatter/calc_selection\"),c=t(\"../scatter/calc\").calcMarkerSize;e.exports=function(t,e){for(var r=t._fullLayout,u=e.subplot,h=r[u].radialaxis,f=r[u].angularaxis,p=h.makeCalcdata(e,\"r\"),d=f.makeCalcdata(e,\"theta\"),g=e._length,v=new Array(g),m=0;m<g;m++){var y=p[m],x=d[m],b=v[m]={};n(y)&&n(x)?(b.r=y,b.theta=x):b.r=i}var _=c(e,g);return e._extremes.x=a.findExtremes(h,p,{ppad:_}),o(t,e),s(v,e),l(v,e),v}},{\"../../constants/numerical\":695,\"../../plots/cartesian/axes\":767,\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc\":1113,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1181:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/line_shape_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,h=t(\"./attributes\");function f(t,e,r,n){var i,a=n(\"r\"),o=n(\"theta\");if(a)o?i=Math.min(a.length,o.length):(i=a.length,n(\"theta0\"),n(\"dtheta\"));else{if(!o)return 0;i=e.theta.length,n(\"r0\"),n(\"dr\")}return e._length=i,i}e.exports={handleRThetaDefaults:f,supplyDefaults:function(t,e,r,p){function d(r,i){return n.coerce(t,e,h,r,i)}var g=f(0,e,0,d);if(g){d(\"thetaunit\"),d(\"mode\",g<u?\"lines+markers\":\"lines\"),d(\"text\"),d(\"hovertext\"),\"fills\"!==e.hoveron&&d(\"hovertemplate\"),i.hasLines(e)&&(o(t,e,r,p,d),s(t,e,d),d(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,p,d,{gradient:!0}),i.hasText(e)&&l(t,e,p,d);var v=[];(i.hasMarkers(e)||i.hasText(e))&&(d(\"cliponaxis\"),d(\"marker.maxdisplayed\"),v.push(\"points\")),d(\"fill\"),\"none\"!==e.fill&&(c(t,e,r,d),i.hasLines(e)||s(t,e,d)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||v.push(\"fills\"),d(\"hoveron\",v.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/line_shape_defaults\":1126,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1179}],1182:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\");function o(t,e,r,n){var o=r.radialAxis,s=r.angularAxis;o._hovertitle=\"r\",s._hovertitle=\"\\u03b8\";var l=o.c2l(t.r);n.rLabel=i.tickText(o,l,\"hover\").text;var c=\"degrees\"===s.thetaunit?a.rad2deg(t.theta):t.theta;n.thetaLabel=i.tickText(s,c,\"hover\").text;var u=t.hi||e.hoverinfo,h=[];function f(t,e){h.push(t._hovertitle+\": \"+e)}if(!e.hovertemplate){var p=u.split(\"+\");-1!==p.indexOf(\"all\")&&(p=[\"r\",\"theta\",\"text\"]),-1!==p.indexOf(\"r\")&&f(o,n.rLabel),-1!==p.indexOf(\"theta\")&&f(s,n.thetaLabel),-1!==p.indexOf(\"text\")&&n.text&&(h.push(n.text),delete n.text),n.extraText=h.join(\"<br>\")}}e.exports={hoverPoints:function(t,e,r,i){var a=n(t,e,r,i);if(a&&!1!==a[0].index){var s=a[0];if(void 0===s.index)return a;var l=t.subplot,c=s.cd[s.index],u=s.trace;if(l.isPtInside(c))return s.xLabelVal=void 0,s.yLabelVal=void 0,o(c,u,l,s),s.hovertemplate=u.hovertemplate,a}},makeHoverPointText:o}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scatter/hover\":1122}],1183:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scatter/select\"),meta:{}}},{\"../../plots/polar\":831,\"../scatter/marker_colorbar\":1129,\"../scatter/select\":1132,\"../scatter/style\":1134,\"./attributes\":1179,\"./calc\":1180,\"./defaults\":1181,\"./hover\":1182,\"./plot\":1184}],1184:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){for(var a=e.layers.frontplot.select(\"g.scatterlayer\"),o={xaxis:e.xaxis,yaxis:e.yaxis,plot:e.framework,layerClipId:e._hasClipOnAxisFalse?e.clipIds.forTraces:null},s=e.radialAxis,l=e.angularAxis,c=0;c<r.length;c++)for(var u=r[c],h=0;h<u.length;h++){var f=u[h],p=f.r;if(p===i)f.x=f.y=i;else{var d=s.c2g(p),g=l.c2g(f.theta);f.x=d*Math.cos(g),f.y=d*Math.sin(g)}}n(t,o,r,a)}},{\"../../constants/numerical\":695,\"../scatter/plot\":1131}],1185:[function(t,e,r){\"use strict\";var n=t(\"../scatterpolar/attributes\"),i=t(\"../scattergl/attributes\");e.exports={mode:n.mode,r:n.r,theta:n.theta,r0:n.r0,dr:n.dr,theta0:n.theta0,dtheta:n.dtheta,thetaunit:n.thetaunit,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,line:i.line,connectgaps:i.connectgaps,marker:i.marker,fill:i.fill,fillcolor:i.fillcolor,textposition:i.textposition,textfont:i.textfont,hoverinfo:n.hoverinfo,selected:n.selected,unselected:n.unselected}},{\"../scattergl/attributes\":1160,\"../scatterpolar/attributes\":1179}],1186:[function(t,e,r){\"use strict\";var n=t(\"../scatter/colorscale_calc\"),i=t(\"../scatter/calc\").calcMarkerSize,a=t(\"../scattergl/convert\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r=t._fullLayout,l=e.subplot,c=r[l].radialaxis,u=r[l].angularaxis,h=c.makeCalcdata(e,\"r\"),f=u.makeCalcdata(e,\"theta\"),p=e._length,d={};p<h.length&&(h=h.slice(0,p)),p<f.length&&(f=f.slice(0,p)),d.r=h,d.theta=f,n(t,e);var g,v=d.opts=a.style(t,e);return p<s?g=i(e,p):v.marker&&(g=2*(v.marker.sizeAvg||Math.max(v.marker.size,3))),e._extremes.x=o.findExtremes(c,h,{ppad:g}),[{x:!1,y:!1,t:d,trace:e}]}},{\"../../plots/cartesian/axes\":767,\"../scatter/calc\":1113,\"../scatter/colorscale_calc\":1115,\"../scattergl/constants\":1162,\"../scattergl/convert\":1163}],1187:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatterpolar/defaults\").handleRThetaDefaults,o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}var d=a(t,e,f,p);d?(p(\"thetaunit\"),p(\"mode\",d<u?\"lines+markers\":\"lines\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),i.hasLines(e)&&(s(t,e,r,f,p),p(\"connectgaps\")),i.hasMarkers(e)&&o(t,e,r,f,p),i.hasText(e)&&l(t,e,f,p),p(\"fill\"),\"none\"!==e.fill&&c(t,e,r,p),n.coerceSelectionMarkerOpacity(e,p)):e.visible=!1}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"../scatterpolar/defaults\":1181,\"./attributes\":1185}],1188:[function(t,e,r){\"use strict\";var n=t(\"../scattergl/hover\"),i=t(\"../scatterpolar/hover\").makeHoverPointText;e.exports={hoverPoints:function(t,e,r,a){var o=t.cd[0].t,s=o.r,l=o.theta,c=n.hoverPoints(t,e,r,a);if(c&&!1!==c[0].index){var u=c[0];if(void 0===u.index)return c;var h=t.subplot,f=u.cd[u.index],p=u.trace;if(f.r=s[u.index],f.theta=l[u.index],h.isPtInside(f))return u.xLabelVal=void 0,u.yLabelVal=void 0,i(f,p,h,u),c}}}},{\"../scattergl/hover\":1166,\"../scatterpolar/hover\":1182}],1189:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolargl\",basePlotModule:t(\"../../plots/polar\"),categories:[\"gl\",\"regl\",\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scattergl/select\"),meta:{}}},{\"../../plots/polar\":831,\"../scatter/marker_colorbar\":1129,\"../scattergl/select\":1170,\"./attributes\":1185,\"./calc\":1186,\"./defaults\":1187,\"./hover\":1188,\"./plot\":1190}],1190:[function(t,e,r){\"use strict\";var n=t(\"point-cluster\"),i=t(\"fast-isnumeric\"),a=t(\"../scattergl/plot\"),o=t(\"../scattergl/scene_update\"),s=t(\"../scattergl/convert\"),l=t(\"../../lib\"),c=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e,r){if(r.length){var u=e.radialAxis,h=e.angularAxis,f=o(t,e);return r.forEach(function(r){if(r&&r[0]&&r[0].trace){var a,o=r[0],p=o.trace,d=o.t,g=p._length,v=d.r,m=d.theta,y=d.opts,x=v.slice(),b=m.slice();for(a=0;a<v.length;a++)e.isPtInside({r:v[a],theta:m[a]})||(x[a]=NaN,b[a]=NaN);var _=new Array(2*g),w=Array(g),k=Array(g);for(a=0;a<g;a++){var T,A,M=x[a];if(i(M)){var S=u.c2g(M),E=h.c2g(b[a],p.thetaunit);T=S*Math.cos(E),A=S*Math.sin(E)}else T=A=NaN;w[a]=_[2*a]=T,k[a]=_[2*a+1]=A}d.tree=n(_),y.marker&&g>=c&&(y.marker.cluster=d.tree),y.marker&&(y.markerSel.positions=y.markerUnsel.positions=y.marker.positions=_),y.line&&_.length>1&&l.extendFlat(y.line,s.linePositions(t,p,_)),y.text&&(l.extendFlat(y.text,{positions:_},s.textPosition(t,p,y.text,y.marker)),l.extendFlat(y.textSel,{positions:_},s.textPosition(t,p,y.text,y.markerSel)),l.extendFlat(y.textUnsel,{positions:_},s.textPosition(t,p,y.text,y.markerUnsel))),y.fill&&!f.fill2d&&(f.fill2d=!0),y.marker&&!f.scatter2d&&(f.scatter2d=!0),y.line&&!f.line2d&&(f.line2d=!0),y.text&&!f.glText&&(f.glText=!0),f.lineOptions.push(y.line),f.fillOptions.push(y.fill),f.markerOptions.push(y.marker),f.markerSelectedOptions.push(y.markerSel),f.markerUnselectedOptions.push(y.markerUnsel),f.textOptions.push(y.text),f.textSelectedOptions.push(y.textSel),f.textUnselectedOptions.push(y.textUnsel),f.selectBatch.push([]),f.unselectBatch.push([]),d.x=w,d.y=k,d.rawx=w,d.rawy=k,d.r=v,d.theta=m,d.positions=_,d._scene=f,d.index=f.count,f.count++}}),a(t,e,r)}}},{\"../../lib\":719,\"../scattergl/constants\":1162,\"../scattergl/convert\":1163,\"../scattergl/plot\":1168,\"../scattergl/scene_update\":1169,\"fast-isnumeric\":225,\"point-cluster\":469}],1191:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/hovertemplate_attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../components/drawing/attributes\").dash,l=t(\"../../lib/extend\").extendFlat,c=i.marker,u=i.line,h=c.line;e.exports={a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},c:{valType:\"data_array\",editType:\"calc\"},sum:{valType:\"number\",dflt:0,min:0,editType:\"calc\"},mode:l({},i.mode,{dflt:\"markers\"}),text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),line:{color:u.color,width:u.width,dash:s,shape:l({},u.shape,{values:[\"linear\",\"spline\"]}),smoothing:u.smoothing,editType:\"calc\"},connectgaps:i.connectgaps,cliponaxis:i.cliponaxis,fill:l({},i.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:i.fillcolor,marker:l({symbol:c.symbol,opacity:c.opacity,maxdisplayed:c.maxdisplayed,size:c.size,sizeref:c.sizeref,sizemin:c.sizemin,sizemode:c.sizemode,line:l({width:h.width,editType:\"calc\"},o(\"marker.line\")),gradient:c.gradient,editType:\"calc\"},o(\"marker\")),textfont:i.textfont,textposition:i.textposition,selected:i.selected,unselected:i.unselected,hoverinfo:l({},a.hoverinfo,{flags:[\"a\",\"b\",\"c\",\"text\",\"name\"]}),hoveron:i.hoveron,hovertemplate:n()}},{\"../../components/colorscale/attributes\":600,\"../../components/drawing/attributes\":613,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../scatter/attributes\":1112}],1192:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=[\"a\",\"b\",\"c\"],c={a:[\"b\",\"c\"],b:[\"a\",\"c\"],c:[\"a\",\"b\"]};e.exports=function(t,e){var r,u,h,f,p,d,g=t._fullLayout[e.subplot].sum,v=e.sum||g,m={a:e.a,b:e.b,c:e.c};for(r=0;r<l.length;r++)if(!m[h=l[r]]){for(p=m[c[h][0]],d=m[c[h][1]],f=new Array(p.length),u=0;u<p.length;u++)f[u]=v-p[u]-d[u];m[h]=f}var y,x,b,_,w,k,T=e._length,A=new Array(T);for(r=0;r<T;r++)y=m.a[r],x=m.b[r],b=m.c[r],n(y)&&n(x)&&n(b)?(1!==(_=g/((y=+y)+(x=+x)+(b=+b)))&&(y*=_,x*=_,b*=_),k=y,w=b-x,A[r]={x:w,y:k,a:y,b:x,c:b}):A[r]={x:!1,y:!1};return s(e,T),i(t,e),a(A,e),o(A,e),A}},{\"../scatter/arrays_to_calcdata\":1111,\"../scatter/calc\":1113,\"../scatter/calc_selection\":1114,\"../scatter/colorscale_calc\":1115,\"fast-isnumeric\":225}],1193:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),h=t(\"./attributes\");e.exports=function(t,e,r,f){function p(r,i){return n.coerce(t,e,h,r,i)}var d,g=p(\"a\"),v=p(\"b\"),m=p(\"c\");if(g?(d=g.length,v?(d=Math.min(d,v.length),m&&(d=Math.min(d,m.length))):d=m?Math.min(d,m.length):0):v&&m&&(d=Math.min(v.length,m.length)),d){e._length=d,p(\"sum\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),p(\"mode\",d<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,f,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,f,p,{gradient:!0}),a.hasText(e)&&c(t,e,f,p);var y=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"cliponaxis\"),p(\"marker.maxdisplayed\"),y.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||y.push(\"fills\"),p(\"hoveron\",y.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":719,\"../scatter/constants\":1116,\"../scatter/fillcolor_defaults\":1120,\"../scatter/line_defaults\":1124,\"../scatter/line_shape_defaults\":1126,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"../scatter/text_defaults\":1136,\"./attributes\":1191}],1194:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),n[i]){var a=n[i];t.a=a.a,t.b=a.b,t.c=a.c}else t.a=e.a,t.b=e.b,t.c=e.c;return t}},{}],1195:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,h=c-u;return s.x0=Math.max(Math.min(s.x0,h),u),s.x1=Math.max(Math.min(s.x1,h),u),o}var f=s.cd[s.index];s.a=f.a,s.b=f.b,s.c=f.c,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.subplot;s.aLabel=i.tickText(p.aaxis,f.a,\"hover\").text,s.bLabel=i.tickText(p.baxis,f.b,\"hover\").text,s.cLabel=i.tickText(p.caxis,f.c,\"hover\").text;var d=s.trace,g=f.hi||d.hoverinfo,v=[];if(!d.hovertemplate){var m=g.split(\"+\");-1!==m.indexOf(\"all\")&&(m=[\"a\",\"b\",\"c\"]),-1!==m.indexOf(\"a\")&&y(p.aaxis,s.aLabel),-1!==m.indexOf(\"b\")&&y(p.baxis,s.bLabel),-1!==m.indexOf(\"c\")&&y(p.caxis,s.cLabel)}return s.extraText=v.join(\"<br>\"),s.hovertemplate=d.hovertemplate,o}function y(t,e){v.push(t._hovertitle+\": \"+e)}}},{\"../../plots/cartesian/axes\":767,\"../scatter/hover\":1122}],1196:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scatterternary\",basePlotModule:t(\"../../plots/ternary\"),categories:[\"ternary\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/ternary\":843,\"../scatter/marker_colorbar\":1129,\"../scatter/select\":1132,\"../scatter/style\":1134,\"./attributes\":1191,\"./calc\":1192,\"./defaults\":1193,\"./event_data\":1194,\"./hover\":1195,\"./plot\":1197}],1197:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\");e.exports=function(t,e,r){var i=e.plotContainer;i.select(\".scatterlayer\").selectAll(\"*\").remove();var a={xaxis:e.xaxis,yaxis:e.yaxis,plot:i,layerClipId:e._hasClipOnAxisFalse?e.clipIdRelative:null},o=e.layers.frontplot.select(\"g.scatterlayer\");n(t,a,r,o)}},{\"../scatter/plot\":1131}],1198:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../scattergl/attributes\"),s=t(\"../../plots/cartesian/constants\").idRegex,l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"../../lib/extend\").extendFlat,u=n.marker,h=u.line,f=c(i(\"marker.line\",{editTypeOverride:\"calc\"}),{width:c({},h.width,{editType:\"calc\"}),editType:\"calc\"}),p=c(i(\"marker\"),{symbol:u.symbol,size:c({},u.size,{editType:\"markerSize\"}),sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:f,editType:\"calc\"});function d(t){return{valType:\"info_array\",freeLength:!0,editType:\"calc\",items:{valType:\"subplotid\",regex:s[t],editType:\"plot\"}}}p.color.editType=p.cmin.editType=p.cmax.editType=\"style\",e.exports={dimensions:l(\"dimension\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},label:{valType:\"string\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},axis:{type:{valType:\"enumerated\",values:[\"linear\",\"log\",\"date\",\"category\"],editType:\"calc+clearAxisTypes\"},matches:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc+clearAxisTypes\"},editType:\"calc+clearAxisTypes\"}),text:c({},o.text,{}),hovertext:c({},o.hovertext,{}),hovertemplate:a(),marker:p,xaxes:d(\"x\"),yaxes:d(\"y\"),diagonal:{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},showupperhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},showlowerhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},selected:{marker:o.selected.marker,editType:\"calc\"},unselected:{marker:o.unselected.marker,editType:\"calc\"},opacity:o.opacity}},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/plot_template\":757,\"../../plots/cartesian/constants\":773,\"../scatter/attributes\":1112,\"../scattergl/attributes\":1160}],1199:[function(t,e,r){\"use strict\";var n=t(\"regl-line2d\"),i=t(\"../../registry\"),a=t(\"../../lib/prepare_regl\"),o=t(\"../../plots/get_data\").getModuleCalcData,s=t(\"../../plots/cartesian\"),l=t(\"../../plots/cartesian/axis_ids\").getFromId,c=t(\"../../plots/cartesian/axes\").shouldShowZeroLine,u=\"splom\";function h(t,e,r){for(var n=r.matrixOptions.data.length,i=e._visibleDims,a=r.viewOpts.ranges=new Array(n),o=0;o<i.length;o++){var s=i[o],c=a[o]=new Array(4),u=l(t,e._diag[s][0]);u&&(c[0]=u.r2l(u.range[0]),c[2]=u.r2l(u.range[1]));var h=l(t,e._diag[s][1]);h&&(c[1]=h.r2l(h.range[0]),c[3]=h.r2l(h.range[1]))}r.selectBatch.length||r.unselectBatch.length?r.matrix.update({ranges:a},{ranges:a}):r.matrix.update({ranges:a})}function f(t){var e=t._fullLayout,r=e._glcanvas.data()[0].regl,i=e._splomGrid;i||(i=e._splomGrid=n(r)),i.update(function(t){var e,r=t._fullLayout,n=r._size,i=[0,0,r.width,r.height],a={};function o(t,e,r,n,o,s){var l=e[t+\"color\"],c=e[t+\"width\"],u=String(l+c);u in a?a[u].data.push(NaN,NaN,r,n,o,s):a[u]={data:[r,n,o,s],join:\"rect\",thickness:c,color:l,viewport:i,range:i,overlay:!1}}for(e in r._splomSubplots){var s,l,u=r._plots[e],h=u.xaxis,f=u.yaxis,p=h._vals,d=f._vals,g=n.b+f.domain[0]*n.h,v=-f._m,m=-v*f.r2l(f.range[0],f.calendar);if(h.showgrid)for(e=0;e<p.length;e++)s=h._offset+h.l2p(p[e].x),o(\"grid\",h,s,g,s,g+f._length);if(f.showgrid)for(e=0;e<d.length;e++)l=g+m+v*d[e].x,o(\"grid\",f,h._offset,l,h._offset+h._length,l);c(t,h,f)&&(s=h._offset+h.l2p(0),o(\"zeroline\",h,s,g,s,g+f._length)),c(t,f,h)&&(l=g+m+0,o(\"zeroline\",f,h._offset,l,h._offset+h._length,l))}var y=[];for(e in a)y.push(a[e]);return y}(t))}e.exports={name:u,attr:s.attr,attrRegex:s.attrRegex,layoutAttributes:s.layoutAttributes,supplyLayoutDefaults:s.supplyLayoutDefaults,drawFramework:s.drawFramework,plot:function(t){var e=t._fullLayout,r=i.getModule(u),n=o(t.calcdata,r)[0];a(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])&&(e._hasOnlyLargeSploms&&f(t),r.plot(t,{},n))},drag:function(t){var e=t.calcdata,r=t._fullLayout;r._hasOnlyLargeSploms&&f(t);for(var n=0;n<e.length;n++){var i=e[n][0].trace,a=r._splomScenes[i.uid];\"splom\"===i.type&&a&&a.matrix&&h(t,i,a)}},updateGrid:f,clean:function(t,e,r,n){var i,a={};if(n._splomScenes){for(i=0;i<t.length;i++){var o=t[i];\"splom\"===o.type&&(a[o.uid]=1)}for(i=0;i<r.length;i++){var l=r[i];if(!a[l.uid]){var c=n._splomScenes[l.uid];c&&c.destroy&&c.destroy(),n._splomScenes[l.uid]=null,delete n._splomScenes[l.uid]}}}0===Object.keys(n._splomScenes||{}).length&&delete n._splomScenes,n._splomGrid&&!e._hasOnlyLargeSploms&&n._hasOnlyLargeSploms&&(n._splomGrid.destroy(),n._splomGrid=null,delete n._splomGrid),s.clean(t,e,r,n)},updateFx:s.updateFx,toSVG:s.toSVG}},{\"../../lib/prepare_regl\":732,\"../../plots/cartesian\":778,\"../../plots/cartesian/axes\":767,\"../../plots/cartesian/axis_ids\":770,\"../../plots/get_data\":802,\"../../registry\":847,\"regl-line2d\":491}],1200:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../scatter/calc\").calcMarkerSize,o=t(\"../scatter/calc\").calcAxisExpansion,s=t(\"../scatter/colorscale_calc\"),l=t(\"../scattergl/convert\").markerSelection,c=t(\"../scattergl/convert\").markerStyle,u=t(\"./scene_update\"),h=t(\"../../constants/numerical\").BADNUM,f=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r,p,d,g,v,m,y=e.dimensions,x=e._length,b={},_=b.cdata=[],w=b.data=[],k=e._visibleDims=[];function T(t,r){for(var i=t.makeCalcdata({v:r.values,vcalendar:e.calendar},\"v\"),a=0;a<i.length;a++)i[a]=i[a]===h?NaN:i[a];_.push(i),w.push(\"log\"===t.type?n.simpleMap(i,t.c2l):i)}for(r=0;r<y.length;r++)if((d=y[r]).visible){if(g=i.getFromId(t,e._diag[r][0]),v=i.getFromId(t,e._diag[r][1]),g&&v&&g.type!==v.type){n.log(\"Skipping splom dimension \"+r+\" with conflicting axis types\");continue}g?(T(g,d),v&&\"category\"===v.type&&(v._categories=g._categories.slice())):T(v,d),k.push(r)}for(s(t,e),n.extendFlat(b,c(e)),m=_.length*x>f?2*(b.sizeAvg||Math.max(b.size,3)):a(e,x),p=0;p<k.length;p++)d=y[r=k[p]],g=i.getFromId(t,e._diag[r][0])||{},v=i.getFromId(t,e._diag[r][1])||{},o(t,e,g,v,_[p],_[p],m);var A=u(t,e);return A.matrix||(A.matrix=!0),A.matrixOptions=b,A.selectedOptions=l(e,e.selected),A.unselectedOptions=l(e,e.unselected),[{x:!1,y:!1,t:{},trace:e}]}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"../scatter/calc\":1113,\"../scatter/colorscale_calc\":1115,\"../scattergl/constants\":1162,\"../scattergl/convert\":1163,\"./scene_update\":1207}],1201:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"../scatter/subtypes\"),s=t(\"../scatter/marker_defaults\"),l=t(\"../parcoords/merge_length\"),c=/-open/;function u(t,e){function r(r,i){return n.coerce(t,e,a.dimensions,r,i)}r(\"label\");var i=r(\"values\");i&&i.length?r(\"visible\"):e.visible=!1,r(\"axis.type\"),r(\"axis.matches\")}e.exports=function(t,e,r,h){function f(r,i){return n.coerce(t,e,a,r,i)}var p=i(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=f(\"diagonal.visible\"),g=f(\"showupperhalf\"),v=f(\"showlowerhalf\");if(l(e,p,\"values\")&&(d||g||v)){f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),s(t,e,r,h,f);var m=c.test(e.marker.symbol),y=o.isBubble(e);f(\"marker.line.width\",m||y?1:0),function(t,e,r,n){var i,a,o=e.dimensions,s=o.length,l=e.showupperhalf,c=e.showlowerhalf,u=e.diagonal.visible,h=new Array(s),f=new Array(s);for(i=0;i<s;i++){var p=i?i+1:\"\";h[i]=\"x\"+p,f[i]=\"y\"+p}var d=n(\"xaxes\",h),g=n(\"yaxes\",f),v=e._diag=new Array(s);e._xaxes={},e._yaxes={};var m=[],y=[];function x(t,n,i,a){if(t){var o=t.charAt(0),s=r._splomAxes[o];if(e[\"_\"+o+\"axes\"][t]=1,a.push(t),!(t in s)){var l=s[t]={};i&&(l.label=i.label||\"\",i.visible&&i.axis&&(i.axis.type&&(l.type=i.axis.type),i.axis.matches&&(l.matches=n)))}}}var b=!u&&!c,_=!u&&!l;for(e._axesDim={},i=0;i<s;i++){var w=o[i],k=0===i,T=i===s-1,A=k&&b||T&&_?void 0:d[i],M=k&&_||T&&b?void 0:g[i];x(A,M,w,m),x(M,A,w,y),v[i]=[A,M],e._axesDim[A]=i,e._axesDim[M]=i}for(i=0;i<m.length;i++)for(a=0;a<y.length;a++){var S=m[i]+y[a];i>a&&l?r._splomSubplots[S]=1:i<a&&c?r._splomSubplots[S]=1:i!==a||!u&&c&&l||(r._splomSubplots[S]=1)}(!c||!u&&l&&c)&&(r._splomGridDflt.xside=\"bottom\",r._splomGridDflt.yside=\"left\")}(0,e,h,f),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1}},{\"../../lib\":719,\"../../plots/array_container_defaults\":763,\"../parcoords/merge_length\":1083,\"../scatter/marker_defaults\":1130,\"../scatter/subtypes\":1135,\"./attributes\":1198}],1202:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scattergl/convert\").markerStyle;e.exports=function(t,e){var r=e.trace,o=t._fullLayout._splomScenes[r.uid];if(o){i(t,r),n.extendFlat(o.matrixOptions,a(r));var s=n.extendFlat({},o.matrixOptions,o.viewOpts);o.matrix.update(s,null)}}},{\"../../lib\":719,\"../scatter/colorscale_calc\":1115,\"../scattergl/convert\":1163}],1203:[function(t,e,r){\"use strict\";r.getDimIndex=function(t,e){for(var r=e._id,n={x:0,y:1}[r.charAt(0)],i=t._visibleDims,a=0;a<i.length;a++){var o=i[a];if(t._diag[o][n]===r)return a}return!1}},{}],1204:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i=t(\"../scattergl/hover\").calcHover;e.exports={hoverPoints:function(t,e,r){var a=t.cd[0].trace,o=t.scene.matrixOptions.cdata,s=t.xa,l=t.ya,c=s.c2p(e),u=l.c2p(r),h=t.distance,f=n.getDimIndex(a,s),p=n.getDimIndex(a,l);if(!1===f||!1===p)return[t];for(var d,g,v=o[f],m=o[p],y=h,x=0;x<v.length;x++){var b=v[x],_=m[x],w=s.c2p(b)-c,k=l.c2p(_)-u,T=Math.sqrt(w*w+k*k);T<y&&(y=g=T,d=x)}return t.index=d,t.distance=y,t.dxy=g,void 0===d?[t]:(i(t,v,m,a),[t])}}},{\"../scattergl/hover\":1166,\"./helpers\":1203}],1205:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../components/grid\");e.exports={moduleType:\"trace\",name:\"splom\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\"),editStyle:t(\"./edit_style\"),meta:{}},n.register(i)},{\"../../components/grid\":636,\"../../registry\":847,\"../scatter/marker_colorbar\":1129,\"./attributes\":1198,\"./base_plot\":1199,\"./calc\":1200,\"./defaults\":1201,\"./edit_style\":1202,\"./hover\":1204,\"./plot\":1206,\"./select\":1208}],1206:[function(t,e,r){\"use strict\";var n=t(\"regl-splom\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\");function o(t,e){var r,o,s,l,c,u=t._fullLayout,h=u._size,f=e.trace,p=e.t,d=u._splomScenes[f.uid],g=d.matrixOptions,v=g.cdata,m=u._glcanvas.data()[0].regl,y=u.dragmode;if(0!==v.length){g.lower=f.showupperhalf,g.upper=f.showlowerhalf,g.diagonal=f.diagonal.visible;var x=f._visibleDims,b=v.length,_=d.viewOpts={};for(_.ranges=new Array(b),_.domains=new Array(b),c=0;c<x.length;c++){s=x[c];var w=_.ranges[c]=new Array(4),k=_.domains[c]=new Array(4);(r=a.getFromId(t,f._diag[s][0]))&&(w[0]=r._rl[0],w[2]=r._rl[1],k[0]=r.domain[0],k[2]=r.domain[1]),(o=a.getFromId(t,f._diag[s][1]))&&(w[1]=o._rl[0],w[3]=o._rl[1],k[1]=o.domain[0],k[3]=o.domain[1])}_.viewport=[h.l,h.b,h.w+h.l,h.h+h.b],!0===d.matrix&&(d.matrix=n(m));var T=u.clickmode.indexOf(\"select\")>-1,A=!0;if(\"lasso\"===y||\"select\"===y||!!f.selectedpoints||T){var M=f._length;if(f.selectedpoints){d.selectBatch=f.selectedpoints;var S=f.selectedpoints,E={};for(s=0;s<S.length;s++)E[S[s]]=!0;var C=[];for(s=0;s<M;s++)E[s]||C.push(s);d.unselectBatch=C}var L=p.xpx=new Array(b),P=p.ypx=new Array(b);for(c=0;c<x.length;c++){if(s=x[c],r=a.getFromId(t,f._diag[s][0]))for(L[c]=new Array(M),l=0;l<M;l++)L[c][l]=r.c2p(v[c][l]);if(o=a.getFromId(t,f._diag[s][1]))for(P[c]=new Array(M),l=0;l<M;l++)P[c][l]=o.c2p(v[c][l])}if(d.selectBatch.length||d.unselectBatch.length){var O=i.extendFlat({},g,d.unselectedOptions,_),z=i.extendFlat({},g,d.selectedOptions,_);d.matrix.update(O,z),A=!1}}else p.xpx=p.ypx=null;if(A){var I=i.extendFlat({},g,_);d.matrix.update(I,null)}}}e.exports=function(t,e,r){if(r.length)for(var n=0;n<r.length;n++)o(t,r[n][0])}},{\"../../lib\":719,\"../../plots/cartesian/axis_ids\":770,\"regl-splom\":501}],1207:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t._fullLayout,i=e.uid,a=r._splomScenes;a||(a=r._splomScenes={});var o={dirty:!0},s=a[e.uid];return s||((s=a[i]=n.extendFlat({},o,{matrix:!1,selectBatch:[],unselectBatch:[]})).draw=function(){s.matrix&&s.matrix.draw&&(s.selectBatch.length||s.unselectBatch.length?s.matrix.draw(s.unselectBatch,s.selectBatch):s.matrix.draw()),s.dirty=!1},s.destroy=function(){s.matrix&&s.matrix.destroy&&s.matrix.destroy(),s.matrixOptions=null,s.selectBatch=null,s.unselectBatch=null,s=null}),s.dirty||n.extendFlat(s,o),s}},{\"../../lib\":719}],1208:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"./helpers\");e.exports=function(t,e){var r=t.cd,o=r[0].trace,s=r[0].t,l=t.scene,c=l.matrixOptions.cdata,u=t.xaxis,h=t.yaxis,f=[];if(!l)return f;var p=!i.hasMarkers(o)&&!i.hasText(o);if(!0!==o.visible||p)return f;var d=a.getDimIndex(o,u),g=a.getDimIndex(o,h);if(!1===d||!1===g)return f;var v=s.xpx[d],m=s.ypx[g],y=c[d],x=c[g],b=[],_=[];if(!1!==e&&!e.degenerate)for(var w=0;w<y.length;w++)e.contains([v[w],m[w]],null,w,t)?(b.push(w),f.push({pointNumber:w,x:y[w],y:x[w]})):_.push(w);var k=l.matrixOptions;return b.length||_.length?l.selectBatch.length||l.unselectBatch.length||l.matrix.update(l.unselectedOptions,n.extendFlat({},k,l.selectedOptions,l.viewOpts)):l.matrix.update(k,null),l.selectBatch=b,l.unselectBatch=_,f}},{\"../../lib\":719,\"../scatter/subtypes\":1135,\"./helpers\":1203}],1209:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},starts:{x:{valType:\"data_array\",editType:\"calc\"},y:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},maxdisplayed:{valType:\"integer\",min:0,dflt:1e3,editType:\"calc\"},sizeref:{valType:\"number\",editType:\"calc\",min:0,dflt:1},text:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:i({editType:\"calc\"},{keys:[\"tubex\",\"tubey\",\"tubez\",\"tubeu\",\"tubev\",\"tubew\",\"norm\",\"divergence\"]})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach(function(t){l[t]=a[t]}),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"divergence\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../mesh3d/attributes\":1053}],1210:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){var r,i,a,o,s=e.u,l=e.v,c=e.w,u=e.x,h=e.y,f=e.z,p=Math.min(u.length,h.length,f.length,s.length,l.length,c.length),d=0;e.starts&&(i=e.starts.x||[],a=e.starts.y||[],o=e.starts.z||[],d=Math.min(i.length,a.length,o.length));var g=0,v=1/0;for(r=0;r<p;r++){var m=s[r],y=l[r],x=c[r],b=Math.sqrt(m*m+y*y+x*x);g=Math.max(g,b),v=Math.min(v,b)}n(t,e,{vals:[v,g],containerStr:\"\",cLetter:\"c\"});var _=-1/0,w=1/0,k=-1/0,T=1/0,A=-1/0,M=1/0;for(r=0;r<p;r++){var S=u[r];_=Math.max(_,S),w=Math.min(w,S);var E=h[r];k=Math.max(k,E),T=Math.min(T,E);var C=f[r];A=Math.max(A,C),M=Math.min(M,C)}for(r=0;r<d;r++){var L=i[r];_=Math.max(_,L),w=Math.min(w,L);var P=a[r];k=Math.max(k,P),T=Math.min(T,P);var O=o[r];A=Math.max(A,O),M=Math.min(M,O)}e._len=p,e._slen=d,e._normMax=g,e._xbnds=[w,_],e._ybnds=[T,k],e._zbnds=[M,A]}},{\"../../components/colorscale/calc\":601}],1211:[function(t,e,r){\"use strict\";var n=t(\"gl-streamtube3d\"),i=n.createTubeMesh,a=t(\"../../lib\"),o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\"),c={xaxis:0,yaxis:1,zaxis:2};function u(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var h=u.prototype;function f(t){return a.distinctVals(t).vals}function p(t){var e=t.length;return e>2?t.slice(1,e-1):2===e?[(t[0]+t[1])/2]:t}function d(t){var e=t.length;return 1===e?[.5,.5]:[t[1]-t[0],t[e-1]-t[e-2]]}function g(t,e){var r=t.fullSceneLayout,i=t.dataScale,u=e._len,h={};function g(t,e){var n=r[e],o=i[c[e]];return a.simpleMap(t,function(t){return n.d2l(t)*o})}h.vectors=l(g(e.u,\"xaxis\"),g(e.v,\"yaxis\"),g(e.w,\"zaxis\"),u);var v=f(e.x.slice(0,u)),m=f(e.y.slice(0,u)),y=f(e.z.slice(0,u));if(v.length*m.length*y.length>u)return{positions:[],cells:[]};var x=g(v,\"xaxis\"),b=g(m,\"yaxis\"),_=g(y,\"zaxis\");if(h.meshgrid=[x,b,_],e.starts){var w=e._slen;h.startingPositions=l(g(e.starts.x.slice(0,w),\"xaxis\"),g(e.starts.y.slice(0,w),\"yaxis\"),g(e.starts.z.slice(0,w),\"zaxis\"))}else{for(var k=b[0],T=p(x),A=p(_),M=new Array(T.length*A.length),S=0,E=0;E<T.length;E++)for(var C=0;C<A.length;C++)M[S++]=[T[E],k,A[C]];h.startingPositions=M}h.colormap=o(e),h.tubeSize=e.sizeref,h.maxLength=e.maxdisplayed;var L=g(e._xbnds,\"xaxis\"),P=g(e._ybnds,\"yaxis\"),O=g(e._zbnds,\"zaxis\"),z=d(x),I=d(b),D=d(_),R=[[L[0]-z[0],P[0]-I[0],O[0]-D[0]],[L[1]+z[1],P[1]+I[1],O[1]+D[1]]],F=n(h,R),B=s(e);F.vertexIntensityBounds=[B.min/e._normMax,B.max/e._normMax];var N=e.lightposition;return F.lightPosition=[N.x,N.y,N.z],F.ambient=e.lighting.ambient,F.diffuse=e.lighting.diffuse,F.specular=e.lighting.specular,F.roughness=e.lighting.roughness,F.fresnel=e.lighting.fresnel,F.opacity=e.opacity,e._pad=F.tubeScale*e.sizeref*2,F}h.handlePick=function(t){var e=this.scene.fullSceneLayout,r=this.scene.dataScale;function n(t,n){var i=e[n],a=r[c[n]];return i.l2c(t)/a}if(t.object===this.mesh){var i=t.data.position,a=t.data.velocity;return t.traceCoordinate=[n(i[0],\"xaxis\"),n(i[1],\"yaxis\"),n(i[2],\"zaxis\"),n(a[0],\"xaxis\"),n(a[1],\"yaxis\"),n(a[2],\"zaxis\"),t.data.intensity*this.data._normMax,t.data.divergence],t.textLabel=this.data.hovertext||this.data.text,!0}},h.update=function(t){this.data=t;var e=g(this.scene,t);this.mesh.update(e)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=g(t,e),a=i(r,n),o=new u(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../plots/gl3d/zip3\":818,\"gl-streamtube3d\":313}],1212:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),h=s(\"x\"),f=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&h&&h.length&&f&&f.length&&p&&p.length?(s(\"starts.x\"),s(\"starts.y\"),s(\"starts.z\"),s(\"maxdisplayed\"),s(\"sizeref\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"./attributes\":1209}],1213:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"streamtube\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),eventData:function(t,e){return t.tubex=t.x,t.tubey=t.y,t.tubez=t.z,t.tubeu=e.traceCoordinate[3],t.tubev=e.traceCoordinate[4],t.tubew=e.traceCoordinate[5],t.norm=e.traceCoordinate[6],t.divergence=e.traceCoordinate[7],delete t.x,delete t.y,delete t.z,t},meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1209,\"./calc\":1210,\"./convert\":1211,\"./defaults\":1212}],1214:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../components/fx/hovertemplate_attributes\"),a=t(\"../../plots/domain\").attributes,o=t(\"../pie/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports={labels:{valType:\"data_array\",editType:\"calc\"},parents:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},branchvalues:{valType:\"enumerated\",values:[\"remainder\",\"total\"],dflt:\"remainder\",editType:\"calc\"},level:{valType:\"any\",editType:\"plot\",anim:!0},maxdepth:{valType:\"integer\",editType:\"plot\",dflt:-1},marker:{colors:{valType:\"data_array\",editType:\"calc\"},line:{color:s({},o.marker.line.color,{dflt:null}),width:s({},o.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},leaf:{opacity:{valType:\"number\",editType:\"style\",min:0,max:1,dflt:.7},editType:\"plot\"},text:o.text,textinfo:s({},o.textinfo,{editType:\"plot\",flags:[\"label\",\"text\",\"value\"]}),textfont:o.textfont,hovertext:o.hovertext,hoverinfo:s({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"name\"]}),hovertemplate:i(),insidetextfont:o.insidetextfont,outsidetextfont:o.outsidetextfont,domain:a({name:\"sunburst\",trace:!0,editType:\"calc\"})}},{\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../../plots/domain\":792,\"../pie/attributes\":1086}],1215:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=r.name=\"sunburst\";r.plot=function(t,e,r,o){var s=n.getModule(a),l=i(t.calcdata,s)[0];s.plot(t,l,r,o)},r.clean=function(t,e,r,n){var i=n._has&&n._has(a),o=e._has&&e._has(a);i&&!o&&n._sunburstlayer.selectAll(\"g.trace\").remove()}},{\"../../plots/get_data\":802,\"../../registry\":847}],1216:[function(t,e,r){\"use strict\";var n=t(\"d3-hierarchy\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../pie/calc\").makePullColorFn,s=t(\"../pie/calc\").generateExtendedColors,l=a.isArrayOrTypedArray,c={};r.calc=function(t,e){var r,s,c,u,h,f,p=t._fullLayout,d=e.ids,g=l(d),v=e.labels,m=e.parents,y=e.values,x=l(y),b=[],_={},w={},k=function(t){return t||\"number\"==typeof t},T=function(t){return!x||i(y[t])&&y[t]>=0};g?(r=Math.min(d.length,m.length),s=function(t){return k(d[t])&&T(t)},c=function(t){return String(d[t])}):(r=Math.min(v.length,m.length),s=function(t){return k(v[t])&&T(t)},c=function(t){return String(v[t])}),x&&(r=Math.min(r,y.length));for(var A=0;A<r;A++)if(s(A)){var M=c(A),S=k(m[A])?String(m[A]):\"\",E={i:A,id:M,pid:S,label:k(v[A])?String(v[A]):\"\"};x&&(E.v=+y[A]),b.push(E),h=M,_[u=S]?_[u].push(h):_[u]=[h],w[h]=1}if(_[\"\"]){if(_[\"\"].length>1){for(var C=a.randstr(),L=0;L<b.length;L++)\"\"===b[L].pid&&(b[L].pid=C);b.unshift({hasMultipleRoots:!0,id:C,pid:\"\"})}}else{var P,O=[];for(P in _)w[P]||O.push(P);if(1!==O.length)return a.warn(\"Multiple implied roots, cannot build sunburst hierarchy.\");P=O[0],b.unshift({id:P,pid:\"\",label:P})}try{f=n.stratify().id(function(t){return t.id}).parentId(function(t){return t.pid})(b)}catch(t){return a.warn(\"Failed to build sunburst hierarchy. Error: \"+t.message)}var z=n.hierarchy(f),I=!1;if(x)switch(e.branchvalues){case\"remainder\":z.sum(function(t){return t.data.v});break;case\"total\":z.each(function(t){var e=t.data.data.v;if(t.children&&e<t.children.reduce(function(t,e){return t+e.data.data.v},0))return I=!0,a.warn([\"Total value for node\",t.data.data.id,\"is smaller than the sum of its children.\"].join(\" \"));t.value=e})}else z.count();if(!I){z.sort(function(t,e){return e.value-t.value});var D=e.marker.colors||[],R=o(p._sunburstcolormap);return z.each(function(t){var e=t.data.data,r=e.id;e.color=R(D[e.i],r)}),b[0].hierarchy=z,b}},r.crossTraceCalc=function(t){var e=t._fullLayout,r=t.calcdata,n=e.sunburstcolorway,i=e._sunburstcolormap;e.extendsunburstcolors&&(n=s(n,c));var a=0;function o(t){var e=t.data.data,r=e.id;!1===e.color&&(i[r]?e.color=i[r]:t.parent?t.parent.parent?e.color=t.parent.data.data.color:(i[r]=e.color=n[a%n.length],a++):e.color=\"rgba(0,0,0,0)\")}for(var l=0;l<r.length;l++){var u=r[l][0];\"sunburst\"===u.trace.type&&u.hierarchy&&u.hierarchy.each(o)}}},{\"../../lib\":719,\"../pie/calc\":1088,\"d3-hierarchy\":157,\"fast-isnumeric\":225}],1217:[function(t,e,r){\"use strict\";e.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:\"linear\"}},{}],1218:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}var c=l(\"labels\"),u=l(\"parents\");if(c&&c.length&&u&&u.length){var h=l(\"values\");h&&h.length&&l(\"branchvalues\"),l(\"level\"),l(\"maxdepth\"),l(\"marker.line.width\")&&l(\"marker.line.color\",s.paper_bgcolor),l(\"marker.colors\"),l(\"leaf.opacity\");var f=l(\"text\");l(\"textinfo\",Array.isArray(f)?\"text+label\":\"label\"),l(\"hovertext\"),l(\"hovertemplate\");o(t,e,s,l,\"auto\",{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),a(e,s,l),e._length=null}else e.visible=!1}},{\"../../lib\":719,\"../../plots/domain\":792,\"../bar/defaults\":861,\"./attributes\":1214}],1219:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"sunburst\",basePlotModule:t(\"./base_plot\"),categories:[],animatable:!0,attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\").style,meta:{}}},{\"./attributes\":1214,\"./base_plot\":1215,\"./calc\":1216,\"./defaults\":1218,\"./layout_attributes\":1220,\"./layout_defaults\":1221,\"./plot\":1222,\"./style\":1223}],1220:[function(t,e,r){\"use strict\";e.exports={sunburstcolorway:{valType:\"colorlist\",editType:\"calc\"},extendsunburstcolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1221:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"sunburstcolorway\",e.colorway),r(\"extendsunburstcolors\")}},{\"../../lib\":719,\"./layout_attributes\":1220}],1222:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"d3-hierarchy\"),a=t(\"../../registry\"),o=t(\"../../components/fx\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../lib\"),u=t(\"../../lib/events\"),h=t(\"../../lib/svg_text_utils\"),f=t(\"../../lib/setcursor\"),p=t(\"../../components/fx/helpers\").appendArrayPointValue,d=t(\"../pie/plot\").transformInsideText,g=t(\"../pie/helpers\").formatPieValue,v=t(\"./style\").styleOne,m=t(\"./constants\");function y(t,e,r,a){var o=t._fullLayout,u=a&&a.duration>0,f=n.select(r).selectAll(\"g.slice\"),p=e[0],m=p.trace,y=x(p.hierarchy,m.level),w=m.maxdepth>=0?m.maxdepth:1/0,M=o._size,S=m.domain,E=M.w*(S.x[1]-S.x[0]),C=M.h*(S.y[1]-S.y[0]),L=.5*Math.min(E,C),P=p.cx=M.l+M.w*(S.x[1]+S.x[0])/2,O=p.cy=M.t+M.h*(1-S.y[0])-C/2;if(!y)return f.remove();var z=null,I={};u&&f.each(function(t){I[k(t)]={rpx0:t.rpx0,rpx1:t.rpx1,x0:t.x0,x1:t.x1,transform:t.transform},!z&&_(t)&&(z=t)});var D=function(t){return i.partition().size([2*Math.PI,t.height+1])(t)}(y).descendants(),R=y.height+1,F=0,B=w;p.hasMultipleRoots&&b(y)&&(D=D.slice(1),R-=1,F=1,B+=1),D=D.filter(function(t){return t.y1<=B});var N=Math.min(R,w),j=function(t){return(t-F)/N*L},U=function(t,e){return[t*Math.cos(e),-t*Math.sin(e)]},V=function(t){return c.pathAnnulus(t.rpx0,t.rpx1,t.x0,t.x1,P,O)},q=function(t){return P+t.pxmid[0]*t.transform.rCenter+(t.transform.x||0)},H=function(t){return O+t.pxmid[1]*t.transform.rCenter+(t.transform.y||0)};(f=f.data(D,function(t){return k(t)})).enter().append(\"g\").classed(\"slice\",!0),u?f.exit().transition().each(function(){var t=n.select(this);t.select(\"path.surface\").transition().attrTween(\"d\",function(t){var e=function(t){var e,r=k(t),i=I[r],a=I[k(y)];if(a){var o=t.x1>a.x1?2*Math.PI:0;e=t.rpx1<a.rpx1?{rpx0:0,rpx1:0}:{x0:o,x1:o}}else{var s,l=k(t.parent);f.each(function(t){if(k(t)===l)return s=t});var c,u=s.children;u.forEach(function(t,e){if(k(t)===r)return c=e});var h=u.length,p=n.interpolate(s.x0,s.x1);e={rpx0:L,rpx1:L,x0:p(c/h),x1:p((c+1)/h)}}return n.interpolate(i,e)}(t);return function(t){return V(e(t))}}),t.select(\"g.slicetext\").attr(\"opacity\",0)}).remove():f.exit().remove(),f.order();var G=null;if(u&&z){var Y=k(z);f.each(function(t){null===G&&k(t)===Y&&(G=t.x1)})}var W=f;function X(t){var e=t.parent,r=I[k(e)],i={};if(r){var a=e.children,o=a.indexOf(t),s=a.length,l=n.interpolate(r.x0,r.x1);i.x0=l(o/s),i.x1=l(o/s)}else i.x0=i.x1=0;return i}u&&(W=W.transition().each(\"end\",function(){T(n.select(this),t,{isTransitioning:!1})})),W.each(function(r){var i=n.select(this),a=c.ensureSingle(i,\"path\",\"surface\",function(t){t.style(\"pointer-events\",\"all\")});r.rpx0=j(r.y0),r.rpx1=j(r.y1),r.xmid=(r.x0+r.x1)/2,r.pxmid=U(r.rpx1,r.xmid),r.midangle=-(r.xmid-Math.PI/2),r.halfangle=.5*Math.min(c.angleDelta(r.x0,r.x1)||Math.PI,Math.PI),r.ring=1-r.rpx0/r.rpx1,r.rInscribed=function(t){return 0===t.rpx0&&c.isFullCircle([t.x0,t.x1])?1:Math.max(0,Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2))}(r),u?a.transition().attrTween(\"d\",function(t){var e=function(t){var e,r=I[k(t)],i={x0:t.x0,x1:t.x1,rpx0:t.rpx0,rpx1:t.rpx1};if(r)e=r;else if(z)if(t.parent)if(G){var a=t.x1>G?2*Math.PI:0;e={x0:a,x1:a}}else e={rpx0:L,rpx1:L},c.extendFlat(e,X(t));else e={rpx0:0,rpx1:0};else e={x0:0,x1:0};return n.interpolate(e,i)}(t);return function(t){return V(e(t))}}):a.attr(\"d\",V),i.call(A,t,e).call(T,t,{isTransitioning:t._transitioning}),a.call(v,r,m);var f=c.ensureSingle(i,\"g\",\"slicetext\"),y=c.ensureSingle(f,\"text\",\"\",function(t){t.attr(\"data-notex\",1)});y.text(function(t,e,r){var n=e.textinfo;if(!n||\"none\"===n)return\"\";var i=t.data.data,a=r.separators,o=n.split(\"+\"),s=function(t){return-1!==o.indexOf(t)},l=[];s(\"label\")&&i.label&&l.push(i.label);i.hasOwnProperty(\"v\")&&s(\"value\")&&l.push(g(i.v,a));if(s(\"text\")){var u=c.castOption(e,i.i,\"text\");c.isValidTextValue(u)&&l.push(u)}return l.join(\"<br>\")}(r,m,o)).classed(\"slicetext\",!0).attr(\"text-anchor\",\"middle\").call(l.font,b(r)?function(t,e,r){var n=e.data.data.i,i=c.castOption(t,n,\"outsidetextfont.color\")||c.castOption(t,n,\"textfont.color\")||r.color,a=c.castOption(t,n,\"outsidetextfont.family\")||c.castOption(t,n,\"textfont.family\")||r.family,o=c.castOption(t,n,\"outsidetextfont.size\")||c.castOption(t,n,\"textfont.size\")||r.size;return{color:i,family:a,size:o}}(m,r,o.font):function(t,e,r){var n=e.data.data,i=n.i,a=c.castOption(t,i,\"insidetextfont.color\");!a&&t._input.textfont&&(a=c.castOption(t._input,i,\"textfont.color\"));var o=c.castOption(t,i,\"insidetextfont.family\")||c.castOption(t,i,\"textfont.family\")||r.family,l=c.castOption(t,i,\"insidetextfont.size\")||c.castOption(t,i,\"textfont.size\")||r.size;return{color:a||s.contrast(n.color),family:o,size:l}}(m,r,o.font)).call(h.convertToTspans,t);var x=l.bBox(y.node());r.transform=d(x,r,p),r.translateX=q(r),r.translateY=H(r);var _=function(t,e){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"+(t.transform.scale<1?\"scale(\"+t.transform.scale+\")\":\"\")+(t.transform.rotate?\"rotate(\"+t.transform.rotate+\")\":\"\")+\"translate(\"+-(e.left+e.right)/2+\",\"+-(e.top+e.bottom)/2+\")\"};u?y.transition().attrTween(\"transform\",function(t){var e=function(t){var e,r=I[k(t)],i=t.transform;if(r)e=r;else if(e={rpx1:t.rpx1,transform:{scale:0,rotate:i.rotate,rCenter:i.rCenter,x:i.x,y:i.y}},z)if(t.parent)if(G){var a=t.x1>G?2*Math.PI:0;e.x0=e.x1=a}else c.extendFlat(e,X(t));else e.x0=e.x1=0;else e.x0=e.x1=0;var o=n.interpolate(e.rpx1,t.rpx1),s=n.interpolate(e.x0,t.x0),l=n.interpolate(e.x1,t.x1),u=n.interpolate(e.transform.scale,i.scale),h=n.interpolate(e.transform.rotate,i.rotate),f=0===i.rCenter?3:0===e.transform.rCenter?1/3:1,p=n.interpolate(e.transform.rCenter,i.rCenter);return function(t){var e=o(t),r=s(t),n=l(t),a=function(t){return p(Math.pow(t,f))}(t),c={pxmid:U(e,(r+n)/2),transform:{rCenter:a,x:i.x,y:i.y}},d={rpx1:o(t),translateX:q(c),translateY:H(c),transform:{scale:u(t),rotate:h(t),rCenter:a}};return d}}(t);return function(t){return _(e(t),x)}}):y.attr(\"transform\",_(r,x))})}function x(t,e){var r;return e&&t.eachAfter(function(t){if(k(t)===e)return r=t.copy()}),r||t}function b(t){return\"\"===t.data.data.pid}function _(t){return!t.parent}function w(t){return!t.children}function k(t){return t.data.data.id}function T(t,e,r){var n=t.datum(),i=(r||{}).isTransitioning;f(t,i||w(n)||b(n)?null:\"pointer\")}function A(t,e,r){var i=r[0],s=i.trace;\"_hasHoverLabel\"in s||(s._hasHoverLabel=!1),\"_hasHoverEvent\"in s||(s._hasHoverEvent=!1),t.on(\"mouseover\",function(t){var r=e._fullLayout;if(!e._dragging&&!1!==r.hovermode){var a=e._fullData[s.index],l=t.data.data,u=l.i,h=function(t){return c.castOption(a,u,t)},f=h(\"hovertemplate\"),p=o.castHoverinfo(a,r,u),d=r.separators;if(f||p&&\"none\"!==p&&\"skip\"!==p){var v=t.rInscribed,m=i.cx+t.pxmid[0]*(1-v),y=i.cy+t.pxmid[1]*(1-v),x={},b=[],_=[],w=function(t){return-1!==b.indexOf(t)};if(p&&(b=\"all\"===p?a._module.attributes.hoverinfo.flags:p.split(\"+\")),x.label=l.label,w(\"label\")&&x.label&&_.push(x.label),l.hasOwnProperty(\"v\")&&(x.value=l.v,x.valueLabel=g(x.value,d),w(\"value\")&&_.push(x.valueLabel)),x.text=h(\"hovertext\")||h(\"text\"),w(\"text\")){var k=x.text;c.isValidTextValue(k)&&_.push(k)}o.loneHover({trace:a,x0:m-v*t.rpx1,x1:m+v*t.rpx1,y:y,idealAlign:t.pxmid[0]<0?\"left\":\"right\",text:_.join(\"<br>\"),name:f||w(\"name\")?a.name:void 0,color:h(\"hoverlabel.bgcolor\")||l.color,borderColor:h(\"hoverlabel.bordercolor\"),fontFamily:h(\"hoverlabel.font.family\"),fontSize:h(\"hoverlabel.font.size\"),fontColor:h(\"hoverlabel.font.color\"),nameLength:h(\"hoverlabel.namelength\"),textAlign:h(\"hoverlabel.align\"),hovertemplate:f,hovertemplateLabels:x,eventData:[M(t,a)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e}),s._hasHoverLabel=!0}s._hasHoverEvent=!0,e.emit(\"plotly_hover\",{points:[M(t,a)],event:n.event})}}),t.on(\"mouseout\",function(t){var r=e._fullLayout,i=e._fullData[s.index],a=n.select(this).datum();s._hasHoverEvent&&(t.originalEvent=n.event,e.emit(\"plotly_unhover\",{points:[M(a,i)],event:n.event}),s._hasHoverEvent=!1),s._hasHoverLabel&&(o.loneUnhover(r._hoverlayer.node()),s._hasHoverLabel=!1)}),t.on(\"click\",function(t){var r=e._fullLayout,l=e._fullData[s.index];if(!1===u.triggerHandler(e,\"plotly_sunburstclick\",{points:[M(t,l)],event:n.event})||w(t)||b(t))r.hovermode&&(e._hoverdata=[M(t,l)],o.click(e,n.event));else if(!e._dragging&&!e._transitioning){a.call(\"_storeDirectGUIEdit\",l,r._tracePreGUI[l.uid],{level:l.level});var c=i.hierarchy,h=k(t),f=_(t)?function(t,e){var r;return t.eachAfter(function(t){for(var n=t.children||[],i=0;i<n.length;i++)if(k(n[i])===e)return r=t.copy()}),r||t}(c,h):x(c,h),p={data:[{level:k(f)}],traces:[s.index]},d={frame:{redraw:!1,duration:m.CLICK_TRANSITION_TIME},transition:{duration:m.CLICK_TRANSITION_TIME,easing:m.CLICK_TRANSITION_EASING},mode:\"immediate\",fromcurrent:!0};o.loneUnhover(r._hoverlayer.node()),a.call(\"animate\",e,p,d)}})}function M(t,e){var r=t.data.data,n={curveNumber:e.index,pointNumber:r.i,data:e._input,fullData:e};return p(n,e,r.i),n}e.exports=function(t,e,r,i){var a,o,s=t._fullLayout._sunburstlayer,l=!r,c=r&&r.duration>0;((a=s.selectAll(\"g.trace.sunburst\").data(e,function(t){return t[0].trace.uid})).enter().append(\"g\").classed(\"trace\",!0).classed(\"sunburst\",!0).attr(\"stroke-linejoin\",\"round\"),a.order(),c)?(i&&(o=i()),n.transition().duration(r.duration).ease(r.easing).each(\"end\",function(){o&&o()}).each(\"interrupt\",function(){o&&o()}).each(function(){s.selectAll(\"g.trace\").each(function(e){y(t,e,this,r)})})):a.each(function(e){y(t,e,this,r)});l&&a.exit().remove()}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../components/fx\":632,\"../../components/fx/helpers\":628,\"../../lib\":719,\"../../lib/events\":709,\"../../lib/setcursor\":739,\"../../lib/svg_text_utils\":743,\"../../registry\":847,\"../pie/helpers\":1091,\"../pie/plot\":1095,\"./constants\":1217,\"./style\":1223,d3:163,\"d3-hierarchy\":157}],1223:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../lib\");function o(t,e,r){var n=e.data.data,o=!e.children,s=n.i,l=a.castOption(r,s,\"marker.line.color\")||i.defaultLine,c=a.castOption(r,s,\"marker.line.width\")||0;t.style(\"stroke-width\",c).call(i.fill,n.color).call(i.stroke,l).style(\"opacity\",o?r.leaf.opacity:null)}e.exports={style:function(t){t._fullLayout._sunburstlayer.selectAll(\".trace\").each(function(t){var e=n.select(this),r=t[0].trace;e.style(\"opacity\",r.opacity),e.selectAll(\"path.surface\").each(function(t){n.select(this).call(o,t,r)})})},styleOne:o}},{\"../../components/color\":593,\"../../lib\":719,d3:163}],1224:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../components/fx/hovertemplate_attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;function c(t){return{show:{valType:\"boolean\",dflt:!1},start:{valType:\"number\",dflt:null,editType:\"plot\"},end:{valType:\"number\",dflt:null,editType:\"plot\"},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\"},project:{x:{valType:\"boolean\",dflt:!1},y:{valType:\"boolean\",dflt:!1},z:{valType:\"boolean\",dflt:!1}},color:{valType:\"color\",dflt:n.defaultLine},usecolormap:{valType:\"boolean\",dflt:!1},width:{valType:\"number\",min:1,max:16,dflt:2},highlight:{valType:\"boolean\",dflt:!0},highlightcolor:{valType:\"color\",dflt:n.defaultLine},highlightwidth:{valType:\"number\",min:1,max:16,dflt:2}}}var u=e.exports=l(s({z:{valType:\"data_array\"},x:{valType:\"data_array\"},y:{valType:\"data_array\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:a(),connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},surfacecolor:{valType:\"data_array\"}},i(\"\",{colorAttr:\"z or surfacecolor\",showScaleDflt:!0,autoColorDflt:!1,editTypeOverride:\"calc\"}),{contours:{x:c(),y:c(),z:c()},hidesurface:{valType:\"boolean\",dflt:!1},lightposition:{x:{valType:\"number\",min:-1e5,max:1e5,dflt:10},y:{valType:\"number\",min:-1e5,max:1e5,dflt:1e4},z:{valType:\"number\",min:-1e5,max:1e5,dflt:0}},lighting:{ambient:{valType:\"number\",min:0,max:1,dflt:.8},diffuse:{valType:\"number\",min:0,max:1,dflt:.8},specular:{valType:\"number\",min:0,max:2,dflt:.05},roughness:{valType:\"number\",min:0,max:1,dflt:.5},fresnel:{valType:\"number\",min:0,max:5,dflt:.2}},opacity:{valType:\"number\",min:0,max:1,dflt:1},_deprecated:{zauto:s({},i.zauto,{}),zmin:s({},i.zmin,{}),zmax:s({},i.zmax,{})},hoverinfo:s({},o.hoverinfo)}),\"calc\",\"nested\");u.x.editType=u.y.editType=u.z.editType=\"calc+clearAxisTypes\",u.transforms=void 0},{\"../../components/color\":593,\"../../components/colorscale/attributes\":600,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764}],1225:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.surfacecolor?n(t,e,{vals:e.surfacecolor,containerStr:\"\",cLetter:\"c\"}):n(t,e,{vals:e.z,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":601}],1226:[function(t,e,r){\"use strict\";var n=t(\"gl-surface3d\"),i=t(\"ndarray\"),a=t(\"ndarray-homography\"),o=t(\"ndarray-fill\"),s=t(\"../../lib\").isArrayOrTypedArray,l=t(\"../../lib/gl_format_color\").parseColorScale,c=t(\"../../lib/str2rgbarray\"),u=t(\"../../components/colorscale\").extractOpts,h=t(\"../heatmap/interp2d\"),f=t(\"../heatmap/find_empties\");function p(t,e,r){this.scene=t,this.uid=r,this.surface=e,this.data=null,this.showContour=[!1,!1,!1],this.contourStart=[null,null,null],this.contourEnd=[null,null,null],this.contourSize=[0,0,0],this.minValues=[1/0,1/0,1/0],this.maxValues=[-1/0,-1/0,-1/0],this.dataScaleX=1,this.dataScaleY=1,this.refineData=!0,this.objectOffset=[0,0,0]}var d=p.prototype;d.getXat=function(t,e,r,n){var i=s(this.data.x)?s(this.data.x[0])?this.data.x[e][t]:this.data.x[t]:t;return void 0===r?i:n.d2l(i,0,r)},d.getYat=function(t,e,r,n){var i=s(this.data.y)?s(this.data.y[0])?this.data.y[e][t]:this.data.y[e]:e;return void 0===r?i:n.d2l(i,0,r)},d.getZat=function(t,e,r,n){var i=this.data.z[e][t];return null===i&&this.data.connectgaps&&this.data._interpolatedZ&&(i=this.data._interpolatedZ[e][t]),void 0===r?i:n.d2l(i,0,r)},d.handlePick=function(t){if(t.object===this.surface){var e=(t.data.index[0]-1)/this.dataScaleX-1,r=(t.data.index[1]-1)/this.dataScaleY-1,n=Math.max(Math.min(Math.round(e),this.data.z[0].length-1),0),i=Math.max(Math.min(Math.round(r),this.data._ylength-1),0);t.index=[n,i],t.traceCoordinate=[this.getXat(n,i),this.getYat(n,i),this.getZat(n,i)],t.dataCoordinate=[this.getXat(n,i,this.data.xcalendar,this.scene.fullSceneLayout.xaxis),this.getYat(n,i,this.data.ycalendar,this.scene.fullSceneLayout.yaxis),this.getZat(n,i,this.data.zcalendar,this.scene.fullSceneLayout.zaxis)];for(var a=0;a<3;a++){var o=t.dataCoordinate[a];null!=o&&(t.dataCoordinate[a]*=this.scene.dataScale[a])}var s=this.data.hovertext||this.data.text;return Array.isArray(s)&&s[i]&&void 0!==s[i][n]?t.textLabel=s[i][n]:t.textLabel=s||\"\",t.data.dataCoordinate=t.dataCoordinate.slice(),this.surface.highlight(t.data),this.scene.glplot.spikes.position=t.dataCoordinate,!0}};var g=[2,3,5,7,11,13,17,19,23,29,31,37,41,43,47,53,59,61,67,71,73,79,83,89,97,101,103,107,109,113,127,131,137,139,149,151,157,163,167,173,179,181,191,193,197,199,211,223,227,229,233,239,241,251,257,263,269,271,277,281,283,293,307,311,313,317,331,337,347,349,353,359,367,373,379,383,389,397,401,409,419,421,431,433,439,443,449,457,461,463,467,479,487,491,499,503,509,521,523,541,547,557,563,569,571,577,587,593,599,601,607,613,617,619,631,641,643,647,653,659,661,673,677,683,691,701,709,719,727,733,739,743,751,757,761,769,773,787,797,809,811,821,823,827,829,839,853,857,859,863,877,881,883,887,907,911,919,929,937,941,947,953,967,971,977,983,991,997,1009,1013,1019,1021,1031,1033,1039,1049,1051,1061,1063,1069,1087,1091,1093,1097,1103,1109,1117,1123,1129,1151,1153,1163,1171,1181,1187,1193,1201,1213,1217,1223,1229,1231,1237,1249,1259,1277,1279,1283,1289,1291,1297,1301,1303,1307,1319,1321,1327,1361,1367,1373,1381,1399,1409,1423,1427,1429,1433,1439,1447,1451,1453,1459,1471,1481,1483,1487,1489,1493,1499,1511,1523,1531,1543,1549,1553,1559,1567,1571,1579,1583,1597,1601,1607,1609,1613,1619,1621,1627,1637,1657,1663,1667,1669,1693,1697,1699,1709,1721,1723,1733,1741,1747,1753,1759,1777,1783,1787,1789,1801,1811,1823,1831,1847,1861,1867,1871,1873,1877,1879,1889,1901,1907,1913,1931,1933,1949,1951,1973,1979,1987,1993,1997,1999,2003,2011,2017,2027,2029,2039,2053,2063,2069,2081,2083,2087,2089,2099,2111,2113,2129,2131,2137,2141,2143,2153,2161,2179,2203,2207,2213,2221,2237,2239,2243,2251,2267,2269,2273,2281,2287,2293,2297,2309,2311,2333,2339,2341,2347,2351,2357,2371,2377,2381,2383,2389,2393,2399,2411,2417,2423,2437,2441,2447,2459,2467,2473,2477,2503,2521,2531,2539,2543,2549,2551,2557,2579,2591,2593,2609,2617,2621,2633,2647,2657,2659,2663,2671,2677,2683,2687,2689,2693,2699,2707,2711,2713,2719,2729,2731,2741,2749,2753,2767,2777,2789,2791,2797,2801,2803,2819,2833,2837,2843,2851,2857,2861,2879,2887,2897,2903,2909,2917,2927,2939,2953,2957,2963,2969,2971,2999];function v(t,e){if(t<e)return 0;for(var r=0;0===Math.floor(t%e);)t/=e,r++;return r}function m(t){for(var e=[],r=0;r<g.length;r++){var n=g[r];e.push(v(t,n))}return e}function y(t){for(var e=m(t),r=t,n=0;n<g.length;n++)if(e[n]>0){r=g[n];break}return r}function x(t,e){if(!(t<1||e<1)){for(var r=m(t),n=m(e),i=1,a=0;a<g.length;a++)i*=Math.pow(g[a],Math.max(r[a],n[a]));return i}}d.calcXnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getXat(e-1,0),i=this.getXat(e,0);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r},d.calcYnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getYat(0,e-1),i=this.getYat(0,e);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r};var b=[1,2,4,6,12,24,36,48,60,120,180,240,360,720,840,1260],_=b[9],w=b[13];function k(t,e){for(var r=!1,n=0;n<t.length;n++)if(e===t[n]){r=!0;break}!1===r&&t.push(e)}d.estimateScale=function(t,e){for(var r=1+function(t){if(0!==t.length){for(var e=1,r=0;r<t.length;r++)e=x(e,t[r]);return e}}(0===e?this.calcXnums(t):this.calcYnums(t));r<_;)r*=2;for(;r>w;)r--,r/=y(r),++r<_&&(r=w);var n=Math.round(r/t);return n>1?n:1},d.refineCoords=function(t){for(var e=this.dataScaleX,r=this.dataScaleY,n=t[0].shape[0],o=t[0].shape[1],s=0|Math.floor(t[0].shape[0]*e+1),l=0|Math.floor(t[0].shape[1]*r+1),c=1+n+1,u=1+o+1,h=i(new Float32Array(c*u),[c,u]),f=0;f<t.length;++f){this.surface.padField(h,t[f]);var p=i(new Float32Array(s*l),[s,l]);a(p,h,[e,0,0,0,r,0,0,0,1]),t[f]=p}},d.setContourLevels=function(){var t,e,r,n=[[],[],[]],i=[!1,!1,!1],a=!1;for(t=0;t<3;++t)if(this.showContour[t]&&(a=!0,this.contourSize[t]>0&&null!==this.contourStart[t]&&null!==this.contourEnd[t]&&this.contourEnd[t]>this.contourStart[t]))for(i[t]=!0,e=this.contourStart[t];e<this.contourEnd[t];e+=this.contourSize[t])r=e*this.scene.dataScale[t],k(n[t],r);if(a){var o=[[],[],[]];for(t=0;t<3;++t)this.showContour[t]&&(o[t]=i[t]?n[t]:this.scene.contourLevels[t]);this.surface.update({levels:o})}},d.update=function(t){var e,r,n,a,s=this.scene,p=s.fullSceneLayout,d=this.surface,g=t.opacity,v=l(t,g),m=s.dataScale,y=t.z[0].length,x=t._ylength,b=s.contourLevels;this.data=t;var _=[];for(e=0;e<3;e++)for(_[e]=[],r=0;r<y;r++)_[e][r]=[];for(r=0;r<y;r++)for(n=0;n<x;n++)_[0][r][n]=this.getXat(r,n,t.xcalendar,p.xaxis),_[1][r][n]=this.getYat(r,n,t.ycalendar,p.yaxis),_[2][r][n]=this.getZat(r,n,t.zcalendar,p.zaxis);if(t.connectgaps)for(t._emptypoints=f(_[2]),h(_[2],t._emptypoints),t._interpolatedZ=[],r=0;r<y;r++)for(t._interpolatedZ[r]=[],n=0;n<x;n++)t._interpolatedZ[r][n]=_[2][r][n];for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null==(a=_[e][r][n])?_[e][r][n]=NaN:a=_[e][r][n]*=m[e];for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null!=(a=_[e][r][n])&&(this.minValues[e]>a&&(this.minValues[e]=a),this.maxValues[e]<a&&(this.maxValues[e]=a));for(e=0;e<3;e++)this.objectOffset[e]=.5*(this.minValues[e]+this.maxValues[e]);for(e=0;e<3;e++)for(r=0;r<y;r++)for(n=0;n<x;n++)null!=(a=_[e][r][n])&&(_[e][r][n]-=this.objectOffset[e]);var k=[i(new Float32Array(y*x),[y,x]),i(new Float32Array(y*x),[y,x]),i(new Float32Array(y*x),[y,x])];o(k[0],function(t,e){return _[0][t][e]}),o(k[1],function(t,e){return _[1][t][e]}),o(k[2],function(t,e){return _[2][t][e]}),_=[];var T={colormap:v,levels:[[],[],[]],showContour:[!0,!0,!0],showSurface:!t.hidesurface,contourProject:[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],contourWidth:[1,1,1],contourColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],contourTint:[1,1,1],dynamicColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],dynamicWidth:[1,1,1],dynamicTint:[1,1,1],opacity:t.opacity},A=u(t);if(T.intensityBounds=[A.min,A.max],t.surfacecolor){var M=i(new Float32Array(y*x),[y,x]);o(M,function(e,r){return t.surfacecolor[r][e]}),k.push(M)}else T.intensityBounds[0]*=m[2],T.intensityBounds[1]*=m[2];(w<k[0].shape[0]||w<k[0].shape[1])&&(this.refineData=!1),!0===this.refineData&&(this.dataScaleX=this.estimateScale(k[0].shape[0],0),this.dataScaleY=this.estimateScale(k[0].shape[1],1),1===this.dataScaleX&&1===this.dataScaleY||this.refineCoords(k)),t.surfacecolor&&(T.intensity=k.pop());var S=[!0,!0,!0],E=[\"x\",\"y\",\"z\"];for(e=0;e<3;++e){var C=t.contours[E[e]];S[e]=C.highlight,T.showContour[e]=C.show||C.highlight,T.showContour[e]&&(T.contourProject[e]=[C.project.x,C.project.y,C.project.z],C.show?(this.showContour[e]=!0,T.levels[e]=b[e],d.highlightColor[e]=T.contourColor[e]=c(C.color),C.usecolormap?d.highlightTint[e]=T.contourTint[e]=0:d.highlightTint[e]=T.contourTint[e]=1,T.contourWidth[e]=C.width,this.contourStart[e]=C.start,this.contourEnd[e]=C.end,this.contourSize[e]=C.size):(this.showContour[e]=!1,this.contourStart[e]=null,this.contourEnd[e]=null,this.contourSize[e]=0),C.highlight&&(T.dynamicColor[e]=c(C.highlightcolor),T.dynamicWidth[e]=C.highlightwidth))}(function(t){var e=t[0].rgb,r=t[t.length-1].rgb;return e[0]===r[0]&&e[1]===r[1]&&e[2]===r[2]&&e[3]===r[3]})(v)&&(T.vertexColor=!0),T.objectOffset=this.objectOffset,T.coords=k,d.update(T),d.visible=t.visible,d.enableDynamic=S,d.enableHighlight=S,d.snapToData=!0,\"lighting\"in t&&(d.ambientLight=t.lighting.ambient,d.diffuseLight=t.lighting.diffuse,d.specularLight=t.lighting.specular,d.roughness=t.lighting.roughness,d.fresnel=t.lighting.fresnel),\"lightposition\"in t&&(d.lightPosition=[t.lightposition.x,t.lightposition.y,t.lightposition.z]),g&&g<1&&(d.supportsTransparency=!0)},d.dispose=function(){this.scene.glplot.remove(this.surface),this.surface.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new p(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":605,\"../../lib\":719,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../heatmap/find_empties\":1007,\"../heatmap/interp2d\":1010,\"gl-surface3d\":316,ndarray:450,\"ndarray-fill\":440,\"ndarray-homography\":442}],1227:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");function s(t,e,r){e in t&&!(r in t)&&(t[r]=t[e])}e.exports=function(t,e,r,l){var c,u;function h(r,n){return i.coerce(t,e,o,r,n)}var f=h(\"x\"),p=h(\"y\"),d=h(\"z\");if(!d||!d.length||f&&f.length<1||p&&p.length<1)e.visible=!1;else{e._xlength=Array.isArray(f)&&i.isArrayOrTypedArray(f[0])?d.length:d[0].length,e._ylength=d.length,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],l),h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"hidesurface\",\"connectgaps\",\"opacity\"].forEach(function(t){h(t)});var g=h(\"surfacecolor\"),v=[\"x\",\"y\",\"z\"];for(c=0;c<3;++c){var m=\"contours.\"+v[c],y=h(m+\".show\"),x=h(m+\".highlight\");if(y||x)for(u=0;u<3;++u)h(m+\".project.\"+v[u]);y&&(h(m+\".color\"),h(m+\".width\"),h(m+\".usecolormap\")),x&&(h(m+\".highlightcolor\"),h(m+\".highlightwidth\")),h(m+\".start\"),h(m+\".end\"),h(m+\".size\")}g||(s(t,\"zmin\",\"cmin\"),s(t,\"zmax\",\"cmax\"),s(t,\"zauto\",\"cauto\")),a(t,e,l,h,{prefix:\"\",cLetter:\"c\"}),e._length=null}}},{\"../../components/colorscale/defaults\":603,\"../../lib\":719,\"../../registry\":847,\"./attributes\":1224}],1228:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"surface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"2dMap\",\"noOpacity\"],meta:{}}},{\"../../plots/gl3d\":807,\"./attributes\":1224,\"./calc\":1225,\"./convert\":1226,\"./defaults\":1227}],1229:[function(t,e,r){\"use strict\";var n=t(\"../../components/annotations/attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../plots/domain\").attributes;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=a({domain:s({name:\"table\",trace:!0}),columnwidth:{valType:\"number\",arrayOk:!0,dflt:null},columnorder:{valType:\"data_array\"},header:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:28},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))},cells:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:20},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))}},\"calc\",\"from-root\")).transforms=void 0},{\"../../components/annotations/attributes\":576,\"../../constants/docs\":690,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/domain\":792,\"../../plots/font_attributes\":793}],1230:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"table\",r.plot=function(t){var e=n(t.calcdata,\"table\")[0];e.length&&i(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"table\"),a=e._has&&e._has(\"table\");i&&!a&&n._paperdiv.selectAll(\".table\").remove()}},{\"../../plots/get_data\":802,\"./plot\":1237}],1231:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap;e.exports=function(){return n({})}},{\"../../lib/gup\":717}],1232:[function(t,e,r){\"use strict\";e.exports={cellPad:8,columnExtentOffset:10,columnTitleOffset:28,emptyHeaderHeight:16,latexCheck:/^\\$.*\\$$/,goldenRatio:1.618,lineBreaker:\"<br>\",maxDimensionCount:60,overdrag:45,releaseTransitionDuration:120,releaseTransitionEase:\"cubic-out\",scrollbarCaptureWidth:18,scrollbarHideDelay:1e3,scrollbarHideDuration:1e3,scrollbarOffset:5,scrollbarWidth:8,transitionDuration:100,transitionEase:\"cubic-out\",uplift:5,wrapSpacer:\" \",wrapSplitCharacter:\" \",cn:{table:\"table\",tableControlView:\"table-control-view\",scrollBackground:\"scroll-background\",yColumn:\"y-column\",columnBlock:\"column-block\",scrollAreaClip:\"scroll-area-clip\",scrollAreaClipRect:\"scroll-area-clip-rect\",columnBoundary:\"column-boundary\",columnBoundaryClippath:\"column-boundary-clippath\",columnBoundaryRect:\"column-boundary-rect\",columnCells:\"column-cells\",columnCell:\"column-cell\",cellRect:\"cell-rect\",cellText:\"cell-text\",cellTextHolder:\"cell-text-holder\",scrollbarKit:\"scrollbar-kit\",scrollbar:\"scrollbar\",scrollbarSlider:\"scrollbar-slider\",scrollbarGlyph:\"scrollbar-glyph\",scrollbarCaptureZone:\"scrollbar-capture-zone\"}}},{}],1233:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"fast-isnumeric\");function o(t){if(Array.isArray(t)){for(var e=0,r=0;r<t.length;r++)e=Math.max(e,o(t[r]));return e}return t}function s(t,e){return t+e}function l(t){var e,r=t.slice(),n=1/0,i=0;for(e=0;e<r.length;e++)Array.isArray(r[e])||(r[e]=[r[e]]),n=Math.min(n,r[e].length),i=Math.max(i,r[e].length);if(n!==i)for(e=0;e<r.length;e++){var a=i-r[e].length;a&&(r[e]=r[e].concat(c(a)))}return r}function c(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=\"\";return e}function u(t){return t.calcdata.columns.reduce(function(e,r){return r.xIndex<t.xIndex?e+r.columnWidth:e},0)}function h(t,e){return Object.keys(t).map(function(r){return i({},t[r],{auxiliaryBlocks:e})})}function f(t,e){for(var r,n={},i=0,a=0,o={firstRowIndex:null,lastRowIndex:null,rows:[]},s=0,l=0,c=0;c<t.length;c++)r=t[c],o.rows.push({rowIndex:c,rowHeight:r}),((a+=r)>=e||c===t.length-1)&&(n[i]=o,o.key=l++,o.firstRowIndex=s,o.lastRowIndex=c,o={firstRowIndex:null,lastRowIndex:null,rows:[]},i+=a,s=c+1,a=0);return n}e.exports=function(t,e){var r=l(e.cells.values),p=function(t){return t.slice(e.header.values.length,t.length)},d=l(e.header.values);d.length&&!d[0].length&&(d[0]=[\"\"],d=l(d));var g=d.concat(p(r).map(function(){return c((d[0]||[\"\"]).length)})),v=e.domain,m=Math.floor(t._fullLayout._size.w*(v.x[1]-v.x[0])),y=Math.floor(t._fullLayout._size.h*(v.y[1]-v.y[0])),x=e.header.values.length?g[0].map(function(){return e.header.height}):[n.emptyHeaderHeight],b=r.length?r[0].map(function(){return e.cells.height}):[],_=x.reduce(s,0),w=f(b,y-_+n.uplift),k=h(f(x,_),[]),T=h(w,k),A={},M=e._fullInput.columnorder.concat(p(r.map(function(t,e){return e}))),S=g.map(function(t,r){var n=Array.isArray(e.columnwidth)?e.columnwidth[Math.min(r,e.columnwidth.length-1)]:e.columnwidth;return a(n)?Number(n):1}),E=S.reduce(s,0);S=S.map(function(t){return t/E*m});var C=Math.max(o(e.header.line.width),o(e.cells.line.width)),L={key:e.uid+t._context.staticPlot,translateX:v.x[0]*t._fullLayout._size.w,translateY:t._fullLayout._size.h*(1-v.y[1]),size:t._fullLayout._size,width:m,maxLineWidth:C,height:y,columnOrder:M,groupHeight:y,rowBlocks:T,headerRowBlocks:k,scrollY:0,cells:i({},e.cells,{values:r}),headerCells:i({},e.header,{values:g}),gdColumns:g.map(function(t){return t[0]}),gdColumnsOriginalOrder:g.map(function(t){return t[0]}),prevPages:[0,0],scrollbarState:{scrollbarScrollInProgress:!1},columns:g.map(function(t,e){var r=A[t];return A[t]=(r||0)+1,{key:t+\"__\"+A[t],label:t,specIndex:e,xIndex:M[e],xScale:u,x:void 0,calcdata:void 0,columnWidth:S[e]}})};return L.columns.forEach(function(t){t.calcdata=L,t.x=u(t)}),L}},{\"../../lib/extend\":710,\"./constants\":1232,\"fast-isnumeric\":225}],1234:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat;r.splitToPanels=function(t){var e=[0,0],r=n({},t,{key:\"header\",type:\"header\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!0,values:t.calcdata.headerCells.values[t.specIndex],rowBlocks:t.calcdata.headerRowBlocks,calcdata:n({},t.calcdata,{cells:t.calcdata.headerCells})});return[n({},t,{key:\"cells1\",type:\"cells\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),n({},t,{key:\"cells2\",type:\"cells\",page:1,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),r]},r.splitToCells=function(t){var e=function(t){var e=t.rowBlocks[t.page],r=e?e.rows[0].rowIndex:0,n=e?r+e.rows.length:0;return[r,n]}(t);return(t.values||[]).slice(e[0],e[1]).map(function(r,n){return{keyWithinBlock:n+(\"string\"==typeof r&&r.match(/[<$&> ]/)?\"_keybuster_\"+Math.random():\"\"),key:e[0]+n,column:t,calcdata:t.calcdata,page:t.page,rowBlocks:t.rowBlocks,value:r}})}},{\"../../lib/extend\":710}],1235:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults;e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}a(e,o,s),s(\"columnwidth\"),s(\"header.values\"),s(\"header.format\"),s(\"header.align\"),s(\"header.prefix\"),s(\"header.suffix\"),s(\"header.height\"),s(\"header.line.width\"),s(\"header.line.color\"),s(\"header.fill.color\"),n.coerceFont(s,\"header.font\",n.extendFlat({},o.font)),function(t,e){for(var r=t.columnorder||[],n=t.header.values.length,i=r.slice(0,n),a=i.slice().sort(function(t,e){return t-e}),o=i.map(function(t){return a.indexOf(t)}),s=o.length;s<n;s++)o.push(s);e(\"columnorder\",o)}(e,s),s(\"cells.values\"),s(\"cells.format\"),s(\"cells.align\"),s(\"cells.prefix\"),s(\"cells.suffix\"),s(\"cells.height\"),s(\"cells.line.width\"),s(\"cells.line.color\"),s(\"cells.fill.color\"),n.coerceFont(s,\"cells.font\",n.extendFlat({},o.font)),e._length=null}},{\"../../lib\":719,\"../../plots/domain\":792,\"./attributes\":1229}],1236:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"table\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1229,\"./base_plot\":1230,\"./calc\":1231,\"./defaults\":1235,\"./plot\":1237}],1237:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\"),o=t(\"../../components/drawing\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../lib\").raiseToTop,c=t(\"../../lib\").cancelTransition,u=t(\"./data_preparation_helper\"),h=t(\"./data_split_helpers\"),f=t(\"../../components/color\");function p(t){return Math.ceil(t.calcdata.maxLineWidth/2)}function d(t,e){return\"clip\"+t._fullLayout._uid+\"_scrollAreaBottomClip_\"+e.key}function g(t,e){return\"clip\"+t._fullLayout._uid+\"_columnBoundaryClippath_\"+e.calcdata.key+\"_\"+e.specIndex}function v(t){return[].concat.apply([],t.map(function(t){return t})).map(function(t){return t.__data__})}function m(t,e,r){var o=t.selectAll(\".\"+n.cn.scrollbarKit).data(a.repeat,a.keyFun);o.enter().append(\"g\").classed(n.cn.scrollbarKit,!0).style(\"shape-rendering\",\"geometricPrecision\"),o.each(function(t){var e=t.scrollbarState;e.totalHeight=function(t){var e=t.rowBlocks;return z(e,e.length-1)+(e.length?I(e[e.length-1],1/0):1)}(t),e.scrollableAreaHeight=t.groupHeight-A(t),e.currentlyVisibleHeight=Math.min(e.totalHeight,e.scrollableAreaHeight),e.ratio=e.currentlyVisibleHeight/e.totalHeight,e.barLength=Math.max(e.ratio*e.currentlyVisibleHeight,n.goldenRatio*n.scrollbarWidth),e.barWiggleRoom=e.currentlyVisibleHeight-e.barLength,e.wiggleRoom=Math.max(0,e.totalHeight-e.scrollableAreaHeight),e.topY=0===e.barWiggleRoom?0:t.scrollY/e.wiggleRoom*e.barWiggleRoom,e.bottomY=e.topY+e.barLength,e.dragMultiplier=e.wiggleRoom/e.barWiggleRoom}).attr(\"transform\",function(t){return\"translate(\"+(t.width+n.scrollbarWidth/2+n.scrollbarOffset)+\" \"+A(t)+\")\"});var s=o.selectAll(\".\"+n.cn.scrollbar).data(a.repeat,a.keyFun);s.enter().append(\"g\").classed(n.cn.scrollbar,!0);var l=s.selectAll(\".\"+n.cn.scrollbarSlider).data(a.repeat,a.keyFun);l.enter().append(\"g\").classed(n.cn.scrollbarSlider,!0),l.attr(\"transform\",function(t){return\"translate(0 \"+(t.scrollbarState.topY||0)+\")\"});var c=l.selectAll(\".\"+n.cn.scrollbarGlyph).data(a.repeat,a.keyFun);c.enter().append(\"line\").classed(n.cn.scrollbarGlyph,!0).attr(\"stroke\",\"black\").attr(\"stroke-width\",n.scrollbarWidth).attr(\"stroke-linecap\",\"round\").attr(\"y1\",n.scrollbarWidth/2),c.attr(\"y2\",function(t){return t.scrollbarState.barLength-n.scrollbarWidth/2}).attr(\"stroke-opacity\",function(t){return t.columnDragInProgress||!t.scrollbarState.barWiggleRoom||r?0:.4}),c.transition().delay(0).duration(0),c.transition().delay(n.scrollbarHideDelay).duration(n.scrollbarHideDuration).attr(\"stroke-opacity\",0);var u=s.selectAll(\".\"+n.cn.scrollbarCaptureZone).data(a.repeat,a.keyFun);u.enter().append(\"line\").classed(n.cn.scrollbarCaptureZone,!0).attr(\"stroke\",\"white\").attr(\"stroke-opacity\",.01).attr(\"stroke-width\",n.scrollbarCaptureWidth).attr(\"stroke-linecap\",\"butt\").attr(\"y1\",0).on(\"mousedown\",function(r){var n=i.event.y,a=this.getBoundingClientRect(),o=r.scrollbarState,s=n-a.top,l=i.scale.linear().domain([0,o.scrollableAreaHeight]).range([0,o.totalHeight]).clamp(!0);o.topY<=s&&s<=o.bottomY||S(e,t,null,l(s-o.barLength/2))(r)}).call(i.behavior.drag().origin(function(t){return i.event.stopPropagation(),t.scrollbarState.scrollbarScrollInProgress=!0,t}).on(\"drag\",S(e,t)).on(\"dragend\",function(){})),u.attr(\"y2\",function(t){return t.scrollbarState.scrollableAreaHeight}),e._context.staticPlot&&(c.remove(),u.remove())}function y(t,e,r,s){var l=function(t){var e=t.selectAll(\".\"+n.cn.columnCell).data(h.splitToCells,function(t){return t.keyWithinBlock});return e.enter().append(\"g\").classed(n.cn.columnCell,!0),e.exit().remove(),e}(function(t){var e=t.selectAll(\".\"+n.cn.columnCells).data(a.repeat,a.keyFun);return e.enter().append(\"g\").classed(n.cn.columnCells,!0),e.exit().remove(),e}(r));!function(t){t.each(function(t,e){var r=t.calcdata.cells.font,n=t.column.specIndex,i={size:_(r.size,n,e),color:_(r.color,n,e),family:_(r.family,n,e)};t.rowNumber=t.key,t.align=_(t.calcdata.cells.align,n,e),t.cellBorderWidth=_(t.calcdata.cells.line.width,n,e),t.font=i})}(l),function(t){t.attr(\"width\",function(t){return t.column.columnWidth}).attr(\"stroke-width\",function(t){return t.cellBorderWidth}).each(function(t){var e=i.select(this);f.stroke(e,_(t.calcdata.cells.line.color,t.column.specIndex,t.rowNumber)),f.fill(e,_(t.calcdata.cells.fill.color,t.column.specIndex,t.rowNumber))})}(function(t){var e=t.selectAll(\".\"+n.cn.cellRect).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"rect\").classed(n.cn.cellRect,!0),e}(l));var c=function(t){var e=t.selectAll(\".\"+n.cn.cellText).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"text\").classed(n.cn.cellText,!0).style(\"cursor\",function(){return\"auto\"}).on(\"mousedown\",function(){i.event.stopPropagation()}),e}(function(t){var e=t.selectAll(\".\"+n.cn.cellTextHolder).data(a.repeat,function(t){return t.keyWithinBlock});return e.enter().append(\"g\").classed(n.cn.cellTextHolder,!0).style(\"shape-rendering\",\"geometricPrecision\"),e}(l));!function(t){t.each(function(t){o.font(i.select(this),t.font)})}(c),x(c,e,s,t),O(l)}function x(t,e,r,a){t.text(function(t){var e=t.column.specIndex,r=t.rowNumber,a=t.value,o=\"string\"==typeof a,s=o&&a.match(/<br>/i),l=!o||s;t.mayHaveMarkup=o&&a.match(/[<&>]/);var c,u=\"string\"==typeof(c=a)&&c.match(n.latexCheck);t.latex=u;var h,f,p=u?\"\":_(t.calcdata.cells.prefix,e,r)||\"\",d=u?\"\":_(t.calcdata.cells.suffix,e,r)||\"\",g=u?null:_(t.calcdata.cells.format,e,r)||null,v=p+(g?i.format(g)(t.value):t.value)+d;if(t.wrappingNeeded=!t.wrapped&&!l&&!u&&(h=b(v)),t.cellHeightMayIncrease=s||u||t.mayHaveMarkup||(void 0===h?b(v):h),t.needsConvertToTspans=t.mayHaveMarkup||t.wrappingNeeded||t.latex,t.wrappingNeeded){var m=(\" \"===n.wrapSplitCharacter?v.replace(/<a href=/gi,\"<a_href=\"):v).split(n.wrapSplitCharacter),y=\" \"===n.wrapSplitCharacter?m.map(function(t){return t.replace(/<a_href=/gi,\"<a href=\")}):m;t.fragments=y.map(function(t){return{text:t,width:null}}),t.fragments.push({fragment:n.wrapSpacer,width:null}),f=y.join(n.lineBreaker)+n.lineBreaker+n.wrapSpacer}else delete t.fragments,f=v;return f}).attr(\"dy\",function(t){return t.needsConvertToTspans?0:\"0.75em\"}).each(function(t){var o=i.select(this),l=t.wrappingNeeded?C:L;t.needsConvertToTspans?s.convertToTspans(o,a,l(r,this,e,a,t)):i.select(this.parentNode).attr(\"transform\",function(t){return\"translate(\"+P(t)+\" \"+n.cellPad+\")\"}).attr(\"text-anchor\",function(t){return{left:\"start\",center:\"middle\",right:\"end\"}[t.align]})})}function b(t){return-1!==t.indexOf(n.wrapSplitCharacter)}function _(t,e,r){if(Array.isArray(t)){var n=t[Math.min(e,t.length-1)];return Array.isArray(n)?n[Math.min(r,n.length-1)]:n}return t}function w(t,e,r){t.transition().ease(n.releaseTransitionEase).duration(n.releaseTransitionDuration).attr(\"transform\",\"translate(\"+e.x+\" \"+r+\")\")}function k(t){return\"cells\"===t.type}function T(t){return\"header\"===t.type}function A(t){return(t.rowBlocks.length?t.rowBlocks[0].auxiliaryBlocks:[]).reduce(function(t,e){return t+I(e,1/0)},0)}function M(t,e,r){var n=v(e)[0];if(void 0!==n){var i=n.rowBlocks,a=n.calcdata,o=z(i,i.length),s=n.calcdata.groupHeight-A(n),l=a.scrollY=Math.max(0,Math.min(o-s,a.scrollY)),c=function(t,e,r){for(var n=[],i=0,a=0;a<t.length;a++){for(var o=t[a],s=o.rows,l=0,c=0;c<s.length;c++)l+=s[c].rowHeight;o.allRowsHeight=l,e<i+l&&e+r>i&&n.push(a),i+=l}return n}(i,l,s);1===c.length&&(c[0]===i.length-1?c.unshift(c[0]-1):c.push(c[0]+1)),c[0]%2&&c.reverse(),e.each(function(t,e){t.page=c[e],t.scrollY=l}),e.attr(\"transform\",function(t){return\"translate(0 \"+(z(t.rowBlocks,t.page)-t.scrollY)+\")\"}),t&&(E(t,r,e,c,n.prevPages,n,0),E(t,r,e,c,n.prevPages,n,1),m(r,t))}}function S(t,e,r,a){return function(o){var s=o.calcdata?o.calcdata:o,l=e.filter(function(t){return s.key===t.key}),c=r||s.scrollbarState.dragMultiplier,u=s.scrollY;s.scrollY=void 0===a?s.scrollY+c*i.event.dy:a;var h=l.selectAll(\".\"+n.cn.yColumn).selectAll(\".\"+n.cn.columnBlock).filter(k);return M(t,h,l),s.scrollY===u}}function E(t,e,r,n,i,a,o){n[o]!==i[o]&&(clearTimeout(a.currentRepaint[o]),a.currentRepaint[o]=setTimeout(function(){var a=r.filter(function(t,e){return e===o&&n[e]!==i[e]});y(t,e,a,r),i[o]=n[o]}))}function C(t,e,r,a){return function(){var o=i.select(e.parentNode);o.each(function(t){var e=t.fragments;o.selectAll(\"tspan.line\").each(function(t,r){e[r].width=this.getComputedTextLength()});var r,i,a=e[e.length-1].width,s=e.slice(0,-1),l=[],c=0,u=t.column.columnWidth-2*n.cellPad;for(t.value=\"\";s.length;)c+(i=(r=s.shift()).width+a)>u&&(t.value+=l.join(n.wrapSpacer)+n.lineBreaker,l=[],c=0),l.push(r.text),c+=i;c&&(t.value+=l.join(n.wrapSpacer)),t.wrapped=!0}),o.selectAll(\"tspan.line\").remove(),x(o.select(\".\"+n.cn.cellText),r,t,a),i.select(e.parentNode.parentNode).call(O)}}function L(t,e,r,a,o){return function(){if(!o.settledY){var s=i.select(e.parentNode),l=R(o),c=o.key-l.firstRowIndex,u=l.rows[c].rowHeight,h=o.cellHeightMayIncrease?e.parentNode.getBoundingClientRect().height+2*n.cellPad:u,f=Math.max(h,u);f-l.rows[c].rowHeight&&(l.rows[c].rowHeight=f,t.selectAll(\".\"+n.cn.columnCell).call(O),M(null,t.filter(k),0),m(r,a,!0)),s.attr(\"transform\",function(){var t=this.parentNode.getBoundingClientRect(),e=i.select(this.parentNode).select(\".\"+n.cn.cellRect).node().getBoundingClientRect(),r=this.transform.baseVal.consolidate(),a=e.top-t.top+(r?r.matrix.f:n.cellPad);return\"translate(\"+P(o,i.select(this.parentNode).select(\".\"+n.cn.cellTextHolder).node().getBoundingClientRect().width)+\" \"+a+\")\"}),o.settledY=!0}}}function P(t,e){switch(t.align){case\"left\":return n.cellPad;case\"right\":return t.column.columnWidth-(e||0)-n.cellPad;case\"center\":return(t.column.columnWidth-(e||0))/2;default:return n.cellPad}}function O(t){t.attr(\"transform\",function(t){var e=t.rowBlocks[0].auxiliaryBlocks.reduce(function(t,e){return t+I(e,1/0)},0);return\"translate(0 \"+(I(R(t),t.key)+e)+\")\"}).selectAll(\".\"+n.cn.cellRect).attr(\"height\",function(t){return(e=R(t),r=t.key,e.rows[r-e.firstRowIndex]).rowHeight;var e,r})}function z(t,e){for(var r=0,n=e-1;n>=0;n--)r+=D(t[n]);return r}function I(t,e){for(var r=0,n=0;n<t.rows.length&&t.rows[n].rowIndex<e;n++)r+=t.rows[n].rowHeight;return r}function D(t){var e=t.allRowsHeight;if(void 0!==e)return e;for(var r=0,n=0;n<t.rows.length;n++)r+=t.rows[n].rowHeight;return t.allRowsHeight=r,r}function R(t){return t.rowBlocks[t.page]}e.exports=function(t,e){var r=!t._context.staticPlot,s=t._fullLayout._paper.selectAll(\".\"+n.cn.table).data(e.map(function(e){var r=a.unwrap(e).trace;return u(t,r)}),a.keyFun);s.exit().remove(),s.enter().append(\"g\").classed(n.cn.table,!0).attr(\"overflow\",\"visible\").style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"overflow\",\"visible\").style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"all\"),s.attr(\"width\",function(t){return t.width+t.size.l+t.size.r}).attr(\"height\",function(t){return t.height+t.size.t+t.size.b}).attr(\"transform\",function(t){return\"translate(\"+t.translateX+\",\"+t.translateY+\")\"});var f=s.selectAll(\".\"+n.cn.tableControlView).data(a.repeat,a.keyFun),x=f.enter().append(\"g\").classed(n.cn.tableControlView,!0).style(\"box-sizing\",\"content-box\");r&&x.on(\"mousemove\",function(e){f.filter(function(t){return e===t}).call(m,t)}).on(\"mousewheel\",function(e){if(!e.scrollbarState.wheeling){e.scrollbarState.wheeling=!0;var r=e.scrollY+i.event.deltaY;S(t,f,null,r)(e)||(i.event.stopPropagation(),i.event.preventDefault()),e.scrollbarState.wheeling=!1}}).call(m,t,!0),f.attr(\"transform\",function(t){return\"translate(\"+t.size.l+\" \"+t.size.t+\")\"});var b=f.selectAll(\".\"+n.cn.scrollBackground).data(a.repeat,a.keyFun);b.enter().append(\"rect\").classed(n.cn.scrollBackground,!0).attr(\"fill\",\"none\"),b.attr(\"width\",function(t){return t.width}).attr(\"height\",function(t){return t.height}),f.each(function(e){o.setClipUrl(i.select(this),d(t,e),t)});var _=f.selectAll(\".\"+n.cn.yColumn).data(function(t){return t.columns},a.keyFun);_.enter().append(\"g\").classed(n.cn.yColumn,!0),_.exit().remove(),_.attr(\"transform\",function(t){return\"translate(\"+t.x+\" 0)\"}),r&&_.call(i.behavior.drag().origin(function(e){return w(i.select(this),e,-n.uplift),l(this),e.calcdata.columnDragInProgress=!0,m(f.filter(function(t){return e.calcdata.key===t.key}),t),e}).on(\"drag\",function(t){var e=i.select(this),r=function(e){return(t===e?i.event.x:e.x)+e.columnWidth/2};t.x=Math.max(-n.overdrag,Math.min(t.calcdata.width+n.overdrag-t.columnWidth,i.event.x)),v(_).filter(function(e){return e.calcdata.key===t.calcdata.key}).sort(function(t,e){return r(t)-r(e)}).forEach(function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e)}),_.filter(function(e){return t!==e}).transition().ease(n.transitionEase).duration(n.transitionDuration).attr(\"transform\",function(t){return\"translate(\"+t.x+\" 0)\"}),e.call(c).attr(\"transform\",\"translate(\"+t.x+\" -\"+n.uplift+\" )\")}).on(\"dragend\",function(e){var r=i.select(this),n=e.calcdata;e.x=e.xScale(e),e.calcdata.columnDragInProgress=!1,w(r,e,0),function(t,e,r){var n=e.gdColumnsOriginalOrder;e.gdColumns.sort(function(t,e){return r[n.indexOf(t)]-r[n.indexOf(e)]}),e.columnorder=r,t.emit(\"plotly_restyle\")}(t,n,n.columns.map(function(t){return t.xIndex}))})),_.each(function(e){o.setClipUrl(i.select(this),g(t,e),t)});var A=_.selectAll(\".\"+n.cn.columnBlock).data(h.splitToPanels,a.keyFun);A.enter().append(\"g\").classed(n.cn.columnBlock,!0).attr(\"id\",function(t){return t.key}),A.style(\"cursor\",function(t){return t.dragHandle?\"ew-resize\":t.calcdata.scrollbarState.barWiggleRoom?\"ns-resize\":\"default\"});var E=A.filter(T),C=A.filter(k);r&&C.call(i.behavior.drag().origin(function(t){return i.event.stopPropagation(),t}).on(\"drag\",S(t,f,-1)).on(\"dragend\",function(){})),y(t,f,E,A),y(t,f,C,A);var L=f.selectAll(\".\"+n.cn.scrollAreaClip).data(a.repeat,a.keyFun);L.enter().append(\"clipPath\").classed(n.cn.scrollAreaClip,!0).attr(\"id\",function(e){return d(t,e)});var P=L.selectAll(\".\"+n.cn.scrollAreaClipRect).data(a.repeat,a.keyFun);P.enter().append(\"rect\").classed(n.cn.scrollAreaClipRect,!0).attr(\"x\",-n.overdrag).attr(\"y\",-n.uplift).attr(\"fill\",\"none\"),P.attr(\"width\",function(t){return t.width+2*n.overdrag}).attr(\"height\",function(t){return t.height+n.uplift}),_.selectAll(\".\"+n.cn.columnBoundary).data(a.repeat,a.keyFun).enter().append(\"g\").classed(n.cn.columnBoundary,!0);var O=_.selectAll(\".\"+n.cn.columnBoundaryClippath).data(a.repeat,a.keyFun);O.enter().append(\"clipPath\").classed(n.cn.columnBoundaryClippath,!0),O.attr(\"id\",function(e){return g(t,e)});var z=O.selectAll(\".\"+n.cn.columnBoundaryRect).data(a.repeat,a.keyFun);z.enter().append(\"rect\").classed(n.cn.columnBoundaryRect,!0).attr(\"fill\",\"none\"),z.attr(\"width\",function(t){return t.columnWidth+2*p(t)}).attr(\"height\",function(t){return t.calcdata.height+2*p(t)+n.uplift}).attr(\"x\",function(t){return-p(t)}).attr(\"y\",function(t){return-p(t)}),M(null,C,f)}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../lib\":719,\"../../lib/gup\":717,\"../../lib/svg_text_utils\":743,\"./constants\":1232,\"./data_preparation_helper\":1233,\"./data_split_helpers\":1234,d3:163}],1238:[function(t,e,r){\"use strict\";var n=t(\"../box/attributes\"),i=t(\"../../lib/extend\").extendFlat;e.exports={y:n.y,x:n.x,x0:n.x0,y0:n.y0,name:i({},n.name,{}),orientation:i({},n.orientation,{}),bandwidth:{valType:\"number\",min:0,editType:\"calc\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},scalemode:{valType:\"enumerated\",values:[\"width\",\"count\"],dflt:\"width\",editType:\"calc\"},spanmode:{valType:\"enumerated\",values:[\"soft\",\"hard\",\"manual\"],dflt:\"soft\",editType:\"calc\"},span:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}],editType:\"calc\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,points:i({},n.boxpoints,{}),jitter:i({},n.jitter,{}),pointpos:i({},n.pointpos,{}),width:i({},n.width,{}),marker:n.marker,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,box:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},width:{valType:\"number\",min:0,max:1,dflt:.25,editType:\"plot\"},fillcolor:{valType:\"color\",editType:\"style\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},editType:\"plot\"},meanline:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"plot\"},side:{valType:\"enumerated\",values:[\"both\",\"positive\",\"negative\"],dflt:\"both\",editType:\"calc\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,hoveron:{valType:\"flaglist\",flags:[\"violins\",\"points\",\"kde\"],dflt:\"violins+points+kde\",extras:[\"all\"],editType:\"style\"}}},{\"../../lib/extend\":710,\"../box/attributes\":880}],1239:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/calc\"),o=t(\"./helpers\"),s=t(\"../../constants/numerical\").BADNUM;function l(t,e,r){var i=e.max-e.min;if(!i)return t.bandwidth?t.bandwidth:0;if(t.bandwidth)return Math.max(t.bandwidth,i/1e4);var a=r.length,o=n.stdev(r,a-1,e.mean);return Math.max(function(t,e,r){return 1.059*Math.min(e,r/1.349)*Math.pow(t,-.2)}(a,o,e.q3-e.q1),i/100)}function c(t,e,r,n){var a,o=t.spanmode,l=t.span||[],c=[e.min,e.max],u=[e.min-2*n,e.max+2*n];function h(n){var i=l[n],a=\"multicategory\"===r.type?r.r2c(i):r.d2c(i,0,t[e.valLetter+\"calendar\"]);return a===s?u[n]:a}var f={type:\"linear\",range:a=\"soft\"===o?u:\"hard\"===o?c:[h(0),h(1)]};return i.setConvert(f),f.cleanRange(),a}e.exports=function(t,e){var r=a(t,e);if(r[0].t.empty)return r;for(var s=t._fullLayout,u=i.getFromId(t,e[\"h\"===e.orientation?\"xaxis\":\"yaxis\"]),h=1/0,f=-1/0,p=0,d=0,g=0;g<r.length;g++){var v=r[g],m=v.pts.map(o.extractVal),y=v.bandwidth=l(e,v,m),x=v.span=c(e,v,u,y);if(v.min===v.max&&0===y)x=v.span=[v.min,v.max],v.density=[{v:1,t:x[0]}],v.bandwidth=y,p=Math.max(p,1);else{var b=x[1]-x[0],_=Math.ceil(b/(y/3)),w=b/_;if(!isFinite(w)||!isFinite(_))return n.error(\"Something went wrong with computing the violin span\"),r[0].t.empty=!0,r;var k=o.makeKDE(v,e,m);v.density=new Array(_);for(var T=0,A=x[0];A<x[1]+w/2;T++,A+=w){var M=k(A);v.density[T]={v:M,t:A},p=Math.max(p,M)}}d=Math.max(d,m.length),h=Math.min(h,x[0]),f=Math.max(f,x[1])}var S=i.findExtremes(u,[h,f],{padded:!0});if(e._extremes[u._id]=S,e.width)r[0].t.maxKDE=p;else{var E=s._violinScaleGroupStats,C=e.scalegroup,L=E[C];L?(L.maxKDE=Math.max(L.maxKDE,p),L.maxCount=Math.max(L.maxCount,d)):E[C]={maxKDE:p,maxCount:d}}return r[0].t.labels.kde=n._(t,\"kde:\"),r}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../box/calc\":881,\"./helpers\":1242}],1240:[function(t,e,r){\"use strict\";var n=t(\"../box/cross_trace_calc\").setPositionOffset,i=[\"v\",\"h\"];e.exports=function(t,e){for(var r=t.calcdata,a=e.xaxis,o=e.yaxis,s=0;s<i.length;s++){for(var l=i[s],c=\"h\"===l?o:a,u=[],h=0;h<r.length;h++){var f=r[h],p=f[0].t,d=f[0].trace;!0!==d.visible||\"violin\"!==d.type||p.empty||d.orientation!==l||d.xaxis!==a._id||d.yaxis!==o._id||u.push(h)}n(\"violin\",t,u,c)}}},{\"../box/cross_trace_calc\":882}],1241:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../box/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}function c(r,i){return n.coerce2(t,e,o,r,i)}if(a.handleSampleDefaults(t,e,l,s),!1!==e.visible){l(\"bandwidth\"),l(\"side\"),l(\"width\")||(l(\"scalegroup\",e.name),l(\"scalemode\"));var u,h=l(\"span\");Array.isArray(h)&&(u=\"manual\"),l(\"spanmode\",u);var f=l(\"line.color\",(t.marker||{}).color||r),p=l(\"line.width\"),d=l(\"fillcolor\",i.addOpacity(e.line.color,.5));a.handlePointsDefaults(t,e,l,{prefix:\"\"});var g=c(\"box.width\"),v=c(\"box.fillcolor\",d),m=c(\"box.line.color\",f),y=c(\"box.line.width\",p);l(\"box.visible\",Boolean(g||v||m||y))||(e.box={visible:!1});var x=c(\"meanline.color\",f),b=c(\"meanline.width\",p);l(\"meanline.visible\",Boolean(x||b))||(e.meanline={visible:!1})}}},{\"../../components/color\":593,\"../../lib\":719,\"../box/defaults\":883,\"./attributes\":1238}],1242:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=function(t){return 1/Math.sqrt(2*Math.PI)*Math.exp(-.5*t*t)};r.makeKDE=function(t,e,r){var n=r.length,a=i,o=t.bandwidth,s=1/(n*o);return function(t){for(var e=0,i=0;i<n;i++)e+=a((t-r[i])/o);return s*e}},r.getPositionOnKdePath=function(t,e,r){var i,a;\"h\"===e.orientation?(i=\"y\",a=\"x\"):(i=\"x\",a=\"y\");var o=n.findPointOnPath(t.path,r,a,{pathLength:t.pathLength}),s=t.posCenterPx,l=o[i];return[l,\"both\"===e.side?2*s-l:s]},r.getKdeValue=function(t,e,n){var i=t.pts.map(r.extractVal);return r.makeKDE(t,e,i)(n)/t.posDensityScale},r.extractVal=function(t){return t.v}},{\"../../lib\":719}],1243:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/hover\"),o=t(\"./helpers\");e.exports=function(t,e,r,s,l){var c,u,h=t.cd,f=h[0].trace,p=f.hoveron,d=-1!==p.indexOf(\"violins\"),g=-1!==p.indexOf(\"kde\"),v=[];if(d||g){var m=a.hoverOnBoxes(t,e,r,s);if(g&&m.length>0){var y,x,b,_,w,k=t.xa,T=t.ya;\"h\"===f.orientation?(w=e,y=\"y\",b=T,x=\"x\",_=k):(w=r,y=\"x\",b=k,x=\"y\",_=T);var A=h[t.index];if(w>=A.span[0]&&w<=A.span[1]){var M=n.extendFlat({},t),S=_.c2p(w,!0),E=o.getKdeValue(A,f,w),C=o.getPositionOnKdePath(A,f,S),L=b._offset,P=b._length;M[y+\"0\"]=C[0],M[y+\"1\"]=C[1],M[x+\"0\"]=M[x+\"1\"]=S,M[x+\"Label\"]=x+\": \"+i.hoverLabelText(_,w)+\", \"+h[0].t.labels.kde+\" \"+E.toFixed(3),M.spikeDistance=m[0].spikeDistance;var O=y+\"Spike\";M[O]=m[0][O],m[0].spikeDistance=void 0,m[0][O]=void 0,M.hovertemplate=!1,v.push(M),(u={stroke:t.color})[y+\"1\"]=n.constrain(L+C[0],L,L+P),u[y+\"2\"]=n.constrain(L+C[1],L,L+P),u[x+\"1\"]=u[x+\"2\"]=_._offset+S}}d&&(v=v.concat(m))}-1!==p.indexOf(\"points\")&&(c=a.hoverOnPoints(t,e,r));var z=l.selectAll(\".violinline-\"+f.uid).data(u?[0]:[]);return z.enter().append(\"line\").classed(\"violinline-\"+f.uid,!0).attr(\"stroke-width\",1.5),z.exit().remove(),z.attr(u),\"closest\"===s?c?[c]:v:c?(v.push(c),v):v}},{\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../box/hover\":885,\"./helpers\":1242}],1244:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../box/defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../box/select\"),moduleType:\"trace\",name:\"violin\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"violinLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../box/defaults\":883,\"../box/select\":890,\"../scatter/style\":1134,\"./attributes\":1238,\"./calc\":1239,\"./cross_trace_calc\":1240,\"./defaults\":1241,\"./hover\":1243,\"./layout_attributes\":1245,\"./layout_defaults\":1246,\"./plot\":1247,\"./style\":1248}],1245:[function(t,e,r){\"use strict\";var n=t(\"../box/layout_attributes\"),i=t(\"../../lib\").extendFlat;e.exports={violinmode:i({},n.boxmode,{}),violingap:i({},n.boxgap,{}),violingroupgap:i({},n.boxgroupgap,{})}},{\"../../lib\":719,\"../box/layout_attributes\":887}],1246:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"../box/layout_defaults\");e.exports=function(t,e,r){a._supply(t,e,r,function(r,a){return n.coerce(t,e,i,r,a)},\"violin\")}},{\"../../lib\":719,\"../box/layout_defaults\":888,\"./layout_attributes\":1245}],1247:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../box/plot\"),s=t(\"../scatter/line_points\"),l=t(\"./helpers\");e.exports=function(t,e,r,c){var u=t._fullLayout,h=e.xaxis,f=e.yaxis;function p(t){var e=s(t,{xaxis:h,yaxis:f,connectGaps:!0,baseTolerance:.75,shape:\"spline\",simplify:!0});return a.smoothopen(e[0],1)}i.makeTraceGroups(c,r,\"trace violins\").each(function(t){var r=n.select(this),a=t[0],s=a.t,c=a.trace;if(!0!==c.visible||s.empty)r.remove();else{var d=s.bPos,g=s.bdPos,v=e[s.valLetter+\"axis\"],m=e[s.posLetter+\"axis\"],y=\"both\"===c.side,x=y||\"positive\"===c.side,b=y||\"negative\"===c.side,_=r.selectAll(\"path.violin\").data(i.identity);_.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"violin\"),_.exit().remove(),_.each(function(t){var e,r,i,a,o,l,h,f,_=n.select(this),w=t.density,k=w.length,T=t.pos+d,A=m.c2p(T);if(c.width)e=s.maxKDE/g;else{var M=u._violinScaleGroupStats[c.scalegroup];e=\"count\"===c.scalemode?M.maxKDE/g*(M.maxCount/t.pts.length):M.maxKDE/g}if(x){for(h=new Array(k),o=0;o<k;o++)(f=h[o]={})[s.posLetter]=T+w[o].v/e,f[s.valLetter]=w[o].t;r=p(h)}if(b){for(h=new Array(k),l=0,o=k-1;l<k;l++,o--)(f=h[l]={})[s.posLetter]=T-w[o].v/e,f[s.valLetter]=w[o].t;i=p(h)}if(y)a=r+\"L\"+i.substr(1)+\"Z\";else{var S=[A,v.c2p(w[0].t)],E=[A,v.c2p(w[k-1].t)];\"h\"===c.orientation&&(S.reverse(),E.reverse()),a=x?\"M\"+S+\"L\"+r.substr(1)+\"L\"+E:\"M\"+E+\"L\"+i.substr(1)+\"L\"+S}_.attr(\"d\",a),t.posCenterPx=A,t.posDensityScale=e*g,t.path=_.node(),t.pathLength=t.path.getTotalLength()/(y?2:1)});var w,k,T,A=c.box,M=A.width,S=(A.line||{}).width;y?(w=g*M,k=0):x?(w=[0,g*M/2],k=-S):(w=[g*M/2,0],k=S),o.plotBoxAndWhiskers(r,{pos:m,val:v},c,{bPos:d,bdPos:w,bPosPxOffset:k}),o.plotBoxMean(r,{pos:m,val:v},c,{bPos:d,bdPos:w,bPosPxOffset:k}),!c.box.visible&&c.meanline.visible&&(T=i.identity);var E=r.selectAll(\"path.meanline\").data(T||[]);E.enter().append(\"path\").attr(\"class\",\"meanline\").style(\"fill\",\"none\").style(\"vector-effect\",\"non-scaling-stroke\"),E.exit().remove(),E.each(function(t){var e=v.c2p(t.mean,!0),r=l.getPositionOnKdePath(t,c,e);n.select(this).attr(\"d\",\"h\"===c.orientation?\"M\"+e+\",\"+r[0]+\"V\"+r[1]:\"M\"+r[0]+\",\"+e+\"H\"+r[1])}),o.plotPoints(r,{x:h,y:f},c,s)}})}},{\"../../components/drawing\":614,\"../../lib\":719,\"../box/plot\":889,\"../scatter/line_points\":1125,\"./helpers\":1242,d3:163}],1248:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../scatter/style\").stylePoints;e.exports=function(t){var e=n.select(t).selectAll(\"g.trace.violins\");e.style(\"opacity\",function(t){return t[0].trace.opacity}),e.each(function(e){var r=e[0].trace,o=n.select(this),s=r.box||{},l=s.line||{},c=r.meanline||{},u=c.width;o.selectAll(\"path.violin\").style(\"stroke-width\",r.line.width+\"px\").call(i.stroke,r.line.color).call(i.fill,r.fillcolor),o.selectAll(\"path.box\").style(\"stroke-width\",l.width+\"px\").call(i.stroke,l.color).call(i.fill,s.fillcolor);var h={\"stroke-width\":u+\"px\",\"stroke-dasharray\":2*u+\"px,\"+u+\"px\"};o.selectAll(\"path.mean\").style(h).call(i.stroke,c.color),o.selectAll(\"path.meanline\").style(h).call(i.stroke,c.color),a(o,r,t)})}},{\"../../components/color\":593,\"../scatter/style\":1134,d3:163}],1249:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../isosurface/attributes\"),a=t(\"../../plots/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=e.exports=s(o({x:i.x,y:i.y,z:i.z,value:i.value,isomin:i.isomin,isomax:i.isomax,surface:i.surface,spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:1}},slices:i.slices,caps:i.caps,text:i.text,hovertext:i.hovertext,hovertemplate:i.hovertemplate},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{colorbar:i.colorbar,opacity:i.opacity,opacityscale:{valType:\"any\",editType:\"calc\"},lightposition:i.lightposition,lighting:i.lighting,flatshading:i.flatshading,contour:i.contour,hoverinfo:o({},a.hoverinfo)}),\"calc\",\"nested\");l.x.editType=l.y.editType=l.z.editType=l.value.editType=\"calc+clearAxisTypes\",l.transforms=void 0},{\"../../components/colorscale/attributes\":600,\"../../lib/extend\":710,\"../../plot_api/edit_types\":750,\"../../plots/attributes\":764,\"../isosurface/attributes\":1048}],1250:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib/gl_format_color\").parseColorScale,a=t(\"../../lib/str2rgbarray\"),o=t(\"../../components/colorscale\").extractOpts,s=t(\"../../plots/gl3d/zip3\"),l=t(\"../isosurface/convert\").findNearestOnAxis,c=t(\"../isosurface/convert\").generateIsoMeshes;function u(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var h=u.prototype;h.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._x[e],n=this.data._y[e],i=this.data._z[e],a=this.data._Ys.length,o=this.data._Zs.length,s=l(r,this.data._Xs).id,c=l(n,this.data._Ys).id,u=l(i,this.data._Zs).id,h=t.index=u+o*c+o*a*s;t.traceCoordinate=[this.data._x[h],this.data._y[h],this.data._z[h],this.data.value[h]];var f=this.data.hovertext||this.data.text;return Array.isArray(f)&&void 0!==f[h]?t.textLabel=f[h]:f&&(t.textLabel=f),!0}},h.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map(function(e){return t.d2l(e,0,n)*r})}this.data=c(t);var l={positions:s(n(r.xaxis,t._x,e.dataScale[0],t.xcalendar),n(r.yaxis,t._y,e.dataScale[1],t.ycalendar),n(r.zaxis,t._z,e.dataScale[2],t.zcalendar)),cells:s(t._i,t._j,t._k),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,opacityscale:t.opacityscale,contourEnable:t.contour.show,contourColor:a(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},u=o(t);l.vertexIntensity=t._intensity,l.vertexIntensityBounds=[u.min,u.max],l.colormap=i(t),this.mesh.update(l)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new u(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":605,\"../../lib/gl_format_color\":716,\"../../lib/str2rgbarray\":742,\"../../plots/gl3d/zip3\":818,\"../isosurface/convert\":1050,\"gl-mesh3d\":280}],1251:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../isosurface/defaults\").supplyIsoDefaults;e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}a(t,e,r,o,s);var l=s(\"opacityscale\");\"max\"===l?e.opacityscale=[[0,.1],[1,1]]:\"min\"===l?e.opacityscale=[[0,1],[1,.1]]:\"extremes\"===l?e.opacityscale=function(t,e){for(var r=[],n=0;n<32;n++){var i=n/31,a=e+(1-e)*(1-Math.pow(Math.sin(t*i*Math.PI),2));r.push([i,Math.max(1,Math.min(0,a))])}return r}(1,.1):function(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var n=t[r];if(2!==n.length||+n[0]<e)return!1;e=+n[0]}return!0}(l)||(e.opacityscale=void 0)}},{\"../../lib\":719,\"../isosurface/defaults\":1051,\"./attributes\":1249}],1252:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../isosurface/calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"volume\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\"],meta:{}}},{\"../../plots/gl3d\":807,\"../isosurface/calc\":1049,\"./attributes\":1249,\"./convert\":1250,\"./defaults\":1251}],1253:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../components/fx/hovertemplate_attributes\"),s=t(\"./constants\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../components/color\");function u(t){return{marker:{color:l({},n.marker.color,{arrayOk:!1,editType:\"style\"}),line:{color:l({},n.marker.line.color,{arrayOk:!1,editType:\"style\"}),width:l({},n.marker.line.width,{arrayOk:!1,editType:\"style\"}),editType:\"style\"},editType:\"style\"},editType:\"style\"}}e.exports={measure:{valType:\"data_array\",dflt:[],editType:\"calc\"},base:{valType:\"number\",dflt:null,arrayOk:!1,editType:\"calc\"},x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,hovertext:n.hovertext,hovertemplate:o({},{keys:s.eventDataKeys}),hoverinfo:l({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"initial\",\"delta\",\"final\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"initial\",\"delta\",\"final\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},text:n.text,textposition:n.textposition,insidetextanchor:n.insidetextanchor,textangle:n.textangle,textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:n.orientation,offset:n.offset,width:n.width,increasing:u(),decreasing:u(),totals:u(),connector:{line:{color:l({},i.color,{dflt:c.defaultLine}),width:l({},i.width,{editType:\"plot\"}),dash:i.dash,editType:\"plot\"},mode:{valType:\"enumerated\",values:[\"spanning\",\"between\"],dflt:\"between\",editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":593,\"../../components/fx/hovertemplate_attributes\":631,\"../../lib/extend\":710,\"../../plots/attributes\":764,\"../bar/attributes\":857,\"../scatter/attributes\":1112,\"./constants\":1255}],1254:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\").mergeArray,a=t(\"../scatter/calc_selection\"),o=t(\"../../constants/numerical\").BADNUM;function s(t){return\"a\"===t||\"absolute\"===t}function l(t){return\"t\"===t||\"total\"===t}e.exports=function(t,e){var r,c,u=n.getFromId(t,e.xaxis||\"x\"),h=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=u.makeCalcdata(e,\"x\"),c=h.makeCalcdata(e,\"y\")):(r=h.makeCalcdata(e,\"y\"),c=u.makeCalcdata(e,\"x\"));for(var f,p=Math.min(c.length,r.length),d=new Array(p),g=0,v=!1,m=0;m<p;m++){var y=r[m]||0,x=!1;(r[m]!==o||l(e.measure[m])||s(e.measure[m]))&&m+1<p&&(r[m+1]!==o||l(e.measure[m+1])||s(e.measure[m+1]))&&(x=!0);var b=d[m]={i:m,p:c[m],s:y,rawS:y,cNext:x};s(e.measure[m])?(g=b.s,b.isSum=!0,b.dir=\"totals\",b.s=g):l(e.measure[m])?(b.isSum=!0,b.dir=\"totals\",b.s=g):(b.isSum=!1,b.dir=b.rawS<0?\"decreasing\":\"increasing\",f=b.s,b.s=g+f,g+=f),\"totals\"===b.dir&&(v=!0),e.ids&&(b.id=String(e.ids[m])),b.v=(e.base||0)+g}return d.length&&(d[0].hasTotals=v),i(e.text,d,\"tx\"),i(e.hovertext,d,\"htx\"),a(d,e),d}},{\"../../constants/numerical\":695,\"../../lib\":719,\"../../plots/cartesian/axes\":767,\"../scatter/calc_selection\":1114}],1255:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"initial\",\"delta\",\"final\"]}},{}],1256:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],h=[],f=[];for(i=0;i<o.length;i++){var p=o[i];!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"waterfall\"===p.type&&(r=s[i],\"h\"===p.orientation?f.push(r):h.push(r),u.push(r))}var d={mode:a.waterfallmode,norm:a.waterfallnorm,gap:a.waterfallgap,groupgap:a.waterfallgroupgap};for(n(t,l,c,h,d),n(t,c,l,f,d),i=0;i<u.length;i++){r=u[i];for(var g=0;g<r.length;g++){var v=r[g];!1===v.isSum&&(v.s0+=0===g?0:r[g-1].s),g+1<r.length&&(r[g].nextP0=r[g+1].p0,r[g].nextS0=r[g+1].s0)}}}},{\"../bar/cross_trace_calc\":860}],1257:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"./attributes\"),l=t(\"../../components/color\"),c=t(\"../../constants/delta.js\"),u=c.INCREASING.COLOR,h=c.DECREASING.COLOR,f=\"#4499FF\";function p(t,e,r){t(e+\".marker.color\",r),t(e+\".marker.line.color\",l.defaultLine),t(e+\".marker.line.width\")}e.exports={supplyDefaults:function(t,e,r,i){function l(r,i){return n.coerce(t,e,s,r,i)}if(o(t,e,i,l)){l(\"measure\"),l(\"orientation\",e.x&&!e.y?\"h\":\"v\"),l(\"base\"),l(\"offset\"),l(\"width\"),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\");var c=l(\"textposition\");a(t,e,i,l,c,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"!==e.textposition&&l(\"textinfo\"),p(l,\"increasing\",u),p(l,\"decreasing\",h),p(l,\"totals\",f),l(\"connector.visible\")&&(l(\"connector.mode\"),l(\"connector.line.width\")&&(l(\"connector.line.color\"),l(\"connector.line.dash\")))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,s,t)}if(\"group\"===e.waterfallmode)for(var l=0;l<t.length;l++)r=(a=t[l])._input,i(r,a,e,o)}}},{\"../../components/color\":593,\"../../constants/delta.js\":689,\"../../lib\":719,\"../bar/defaults\":861,\"../scatter/xy_defaults\":1137,\"./attributes\":1253}],1258:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"initial\"in e&&(t.initial=e.initial),\"delta\"in e&&(t.delta=e.delta),\"final\"in e&&(t.final=e.final),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],1259:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\").hoverLabelText,i=t(\"../../components/color\").opacity,a=t(\"../bar/hover\").hoverOnBars,o=t(\"../../constants/delta.js\"),s=o.INCREASING.SYMBOL,l=o.DECREASING.SYMBOL;e.exports=function(t,e,r,o){var c=a(t,e,r,o);if(c){var u=c.cd,h=u[0].trace,f=\"h\"===h.orientation,p=f?t.xa:t.ya,d=u[c.index],g=d.isSum?d.b+d.s:d.rawS;if(!d.isSum){c.initial=d.b+d.s-g,c.delta=g,c.final=c.initial+c.delta;var v=w(Math.abs(c.delta));c.deltaLabel=g<0?\"(\"+v+\")\":v,c.finalLabel=w(c.final),c.initialLabel=w(c.initial)}var m=d.hi||h.hoverinfo,y=[];if(m&&\"none\"!==m&&\"skip\"!==m){var x=\"all\"===m,b=m.split(\"+\"),_=function(t){return x||-1!==b.indexOf(t)};d.isSum||(!_(\"final\")||_(f?\"x\":\"y\")||y.push(c.finalLabel),_(\"delta\")&&(g<0?y.push(c.deltaLabel+\" \"+l):y.push(c.deltaLabel+\" \"+s)),_(\"initial\")&&y.push(\"Initial: \"+c.initialLabel))}return y.length&&(c.extraText=y.join(\"<br>\")),c.color=function(t,e){var r=t[e.dir].marker,n=r.color,a=r.line.color,o=r.line.width;if(i(n))return n;if(i(a)&&o)return a}(h,d),[c]}function w(t){return n(p,t)}}},{\"../../components/color\":593,\"../../constants/delta.js\":689,\"../../plots/cartesian/axes\":767,\"../bar/hover\":863}],1260:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"waterfall\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":778,\"../bar/select\":868,\"./attributes\":1253,\"./calc\":1254,\"./cross_trace_calc\":1256,\"./defaults\":1257,\"./event_data\":1258,\"./hover\":1259,\"./layout_attributes\":1261,\"./layout_defaults\":1262,\"./plot\":1263,\"./style\":1264}],1261:[function(t,e,r){\"use strict\";e.exports={waterfallmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"group\",editType:\"calc\"},waterfallgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},waterfallgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],1262:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"waterfall\"===l.type){a=!0;break}}a&&(o(\"waterfallmode\"),o(\"waterfallgap\",.2),o(\"waterfallgroupgap\"))}},{\"../../lib\":719,\"./layout_attributes\":1261}],1263:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../bar/plot\").plot;e.exports=function(t,e,r,s){var l=t._fullLayout;o(t,e,r,s,{mode:l.waterfallmode,norm:l.waterfallmode,gap:l.waterfallgap,groupgap:l.waterfallgroupgap}),function(t,e,r,o){var s=e.xaxis,l=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each(function(r){var o=n.select(this),c=r[0].trace,u=i.ensureSingle(o,\"g\",\"lines\");if(c.connector&&c.connector.visible){var h=\"h\"===c.orientation,f=c.connector.mode,p=u.selectAll(\"g.line\").data(i.identity);p.enter().append(\"g\").classed(\"line\",!0),p.exit().remove();var d=p.size();p.each(function(r,o){if(o===d-1||r.cNext){var c=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),n?[i,a]:[a,i]}(r,s,l,h),u=c[0],p=c[1],g=\"\";\"spanning\"===f&&!r.isSum&&o>0&&(g+=h?\"M\"+u[0]+\",\"+p[1]+\"V\"+p[0]:\"M\"+u[1]+\",\"+p[0]+\"H\"+u[0]),\"between\"!==f&&(r.isSum||o<d-1)&&(g+=h?\"M\"+u[1]+\",\"+p[0]+\"V\"+p[1]:\"M\"+u[0]+\",\"+p[1]+\"H\"+u[1]),void 0!==u[2]&&void 0!==p[2]&&(g+=h?\"M\"+u[1]+\",\"+p[1]+\"V\"+p[2]:\"M\"+u[1]+\",\"+p[1]+\"H\"+u[2]),\"\"===g&&(g=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}})}else u.remove()})}(t,e,r,s)}},{\"../../components/drawing\":614,\"../../lib\":719,\"../bar/plot\":867,d3:163}],1264:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\").styleTextPoints;e.exports={style:function(t,e,r){var l=r||n.select(t).selectAll(\"g.waterfalllayer\").selectAll(\"g.trace\");l.style(\"opacity\",function(t){return t[0].trace.opacity}),l.each(function(e){var r=n.select(this),l=e[0].trace;r.selectAll(\".point > path\").each(function(t){if(!t.isBlank){var e=l[t.dir].marker;n.select(this).call(a.fill,e.color).call(a.stroke,e.line.color).call(i.dashLine,e.line.dash,e.line.width).style(\"opacity\",l.selectedpoints&&!t.selected?o:1)}}),s(r,l,t),r.selectAll(\".lines\").each(function(){var t=l.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)})})}}},{\"../../components/color\":593,\"../../components/drawing\":614,\"../../constants/interactions\":694,\"../bar/style\":870,d3:163}],1265:[function(t,e,r){\"use strict\";var n=t(\"../plots/cartesian/axes\"),i=t(\"../lib\"),a=t(\"../plot_api/plot_schema\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/numerical\").BADNUM;r.moduleType=\"transform\",r.name=\"aggregate\";var l=r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},aggregations:{_isLinkedToArray:\"aggregation\",target:{valType:\"string\",editType:\"calc\"},func:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"median\",\"mode\",\"rms\",\"stddev\",\"min\",\"max\",\"first\",\"last\",\"change\",\"range\"],dflt:\"first\",editType:\"calc\"},funcmode:{valType:\"enumerated\",values:[\"sample\",\"population\"],dflt:\"sample\",editType:\"calc\"},enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},c=l.aggregations;function u(t,e,r,a){if(a.enabled){for(var o=a.target,l=i.nestedProperty(e,o),c=l.get(),u=function(t,e){var r=t.func,n=e.d2c,i=e.c2d;switch(r){case\"count\":return h;case\"first\":return f;case\"last\":return p;case\"sum\":return function(t,e){for(var r=0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r+=o)}return i(r)};case\"avg\":return function(t,e){for(var r=0,a=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l,a++)}return a?i(r/a):s};case\"min\":return function(t,e){for(var r=1/0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r=Math.min(r,o))}return r===1/0?s:i(r)};case\"max\":return function(t,e){for(var r=-1/0,a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&(r=Math.max(r,o))}return r===-1/0?s:i(r)};case\"range\":return function(t,e){for(var r=1/0,a=-1/0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r=Math.min(r,l),a=Math.max(a,l))}return a===-1/0||r===1/0?s:i(a-r)};case\"change\":return function(t,e){var r=n(t[e[0]]),a=n(t[e[e.length-1]]);return r===s||a===s?s:i(a-r)};case\"median\":return function(t,e){for(var r=[],a=0;a<e.length;a++){var o=n(t[e[a]]);o!==s&&r.push(o)}if(!r.length)return s;r.sort();var l=(r.length-1)/2;return i((r[Math.floor(l)]+r[Math.ceil(l)])/2)};case\"mode\":return function(t,e){for(var r={},a=0,o=s,l=0;l<e.length;l++){var c=n(t[e[l]]);if(c!==s){var u=r[c]=(r[c]||0)+1;u>a&&(a=u,o=c)}}return a?i(o):s};case\"rms\":return function(t,e){for(var r=0,a=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l*l,a++)}return a?i(Math.sqrt(r/a)):s};case\"stddev\":return function(e,r){var i,a=0,o=0,l=1,c=s;for(i=0;i<r.length&&c===s;i++)c=n(e[r[i]]);if(c===s)return s;for(;i<r.length;i++){var u=n(e[r[i]]);if(u!==s){var h=u-c;a+=h,o+=h*h,l++}}var f=\"sample\"===t.funcmode?l-1:l;return f?Math.sqrt((o-a*a/l)/f):0}}}(a,n.getDataConversions(t,e,o,c)),d=new Array(r.length),g=0;g<r.length;g++)d[g]=u(c,r[g]);l.set(d),\"count\"===a.func&&i.pushUnique(e._arrayAttrs,o)}}function h(t,e){return e.length}function f(t,e){return t[e[0]]}function p(t,e){return t[e[e.length-1]]}r.supplyDefaults=function(t,e){var r,n={};function o(e,r){return i.coerce(t,n,l,e,r)}if(!o(\"enabled\"))return n;var s=a.findArrayAttributes(e),u={};for(r=0;r<s.length;r++)u[s[r]]=1;var h=o(\"groups\");if(!Array.isArray(h)){if(!u[h])return n.enabled=!1,n;u[h]=0}var f,p=t.aggregations||[],d=n.aggregations=new Array(p.length);function g(t,e){return i.coerce(p[r],f,c,t,e)}for(r=0;r<p.length;r++){f={_index:r};var v=g(\"target\"),m=g(\"func\");g(\"enabled\")&&v&&(u[v]||\"count\"===m&&void 0===u[v])?(\"stddev\"===m&&g(\"funcmode\"),u[v]=0,d[r]=f):d[r]={enabled:!1,_index:r}}for(r=0;r<s.length;r++)u[s[r]]&&d.push({target:s[r],func:c.func.dflt,enabled:!0,_index:-1});return n},r.calcTransform=function(t,e,r){if(r.enabled){var n=r.groups,a=i.getTargetArray(e,{target:n});if(a){var s,l,c,h,f={},p={},d=[],g=o(e.transforms,r),v=a.length;for(e._length&&(v=Math.min(v,e._length)),s=0;s<v;s++)void 0===(c=f[l=a[s]])?(f[l]=d.length,h=[s],d.push(h),p[f[l]]=g(s)):(d[c].push(s),p[f[l]]=(p[f[l]]||[]).concat(g(s)));r._indexToPoints=p;var m=r.aggregations;for(s=0;s<m.length;s++)u(t,e,d,m[s]);\"string\"==typeof n&&u(t,e,d,{target:n,func:\"first\",enabled:!0}),e._length=d.length}}}},{\"../constants/numerical\":695,\"../lib\":719,\"../plot_api/plot_schema\":756,\"../plots/cartesian/axes\":767,\"./helpers\":1268}],1266:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../registry\"),a=t(\"../plots/cartesian/axes\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/filter_ops\"),l=s.COMPARISON_OPS,c=s.INTERVAL_OPS,u=s.SET_OPS;r.moduleType=\"transform\",r.name=\"filter\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},operation:{valType:\"enumerated\",values:[].concat(l).concat(c).concat(u),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},preservegaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function a(i,a){return n.coerce(t,e,r.attributes,i,a)}if(a(\"enabled\")){var o=a(\"target\");if(n.isArrayOrTypedArray(o)&&0===o.length)return e.enabled=!1,e;a(\"preservegaps\"),a(\"operation\"),a(\"value\");var s=i.getComponentMethod(\"calendars\",\"handleDefaults\");s(t,e,\"valuecalendar\",null),s(t,e,\"targetcalendar\",null)}return e},r.calcTransform=function(t,e,r){if(r.enabled){var i=n.getTargetArray(e,r);if(i){var s=r.target,h=i.length;e._length&&(h=Math.min(h,e._length));var f=r.targetcalendar,p=e._arrayAttrs,d=r.preservegaps;if(\"string\"==typeof s){var g=n.nestedProperty(e,s+\"calendar\").get();g&&(f=g)}var v,m,y=function(t,e,r){var n=t.operation,i=t.value,a=Array.isArray(i);function o(t){return-1!==t.indexOf(n)}var s,h=function(r){return e(r,0,t.valuecalendar)},f=function(t){return e(t,0,r)};o(l)?s=h(a?i[0]:i):o(c)?s=a?[h(i[0]),h(i[1])]:[h(i),h(i)]:o(u)&&(s=a?i.map(h):[h(i)]);switch(n){case\"=\":return function(t){return f(t)===s};case\"!=\":return function(t){return f(t)!==s};case\"<\":return function(t){return f(t)<s};case\"<=\":return function(t){return f(t)<=s};case\">\":return function(t){return f(t)>s};case\">=\":return function(t){return f(t)>=s};case\"[]\":return function(t){var e=f(t);return e>=s[0]&&e<=s[1]};case\"()\":return function(t){var e=f(t);return e>s[0]&&e<s[1]};case\"[)\":return function(t){var e=f(t);return e>=s[0]&&e<s[1]};case\"(]\":return function(t){var e=f(t);return e>s[0]&&e<=s[1]};case\"][\":return function(t){var e=f(t);return e<=s[0]||e>=s[1]};case\")(\":return function(t){var e=f(t);return e<s[0]||e>s[1]};case\"](\":return function(t){var e=f(t);return e<=s[0]||e>s[1]};case\")[\":return function(t){var e=f(t);return e<s[0]||e>=s[1]};case\"{}\":return function(t){return-1!==s.indexOf(f(t))};case\"}{\":return function(t){return-1===s.indexOf(f(t))}}}(r,a.getDataToCoordFunc(t,e,s,i),f),x={},b={},_=0;d?(v=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set(new Array(h))},m=function(t,e){var r=x[t.astr][e];t.get()[e]=r}):(v=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set([])},m=function(t,e){var r=x[t.astr][e];t.get().push(r)}),T(v);for(var w=o(e.transforms,r),k=0;k<h;k++){y(i[k])?(T(m,k),b[_++]=w(k)):d&&_++}r._indexToPoints=b,e._length=_}}function T(t,r){for(var i=0;i<p.length;i++){t(n.nestedProperty(e,p[i]),r)}}}},{\"../constants/filter_ops\":691,\"../lib\":719,\"../plots/cartesian/axes\":767,\"../registry\":847,\"./helpers\":1268}],1267:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_schema\"),a=t(\"../plots/plots\"),o=t(\"./helpers\").pointsAccessorFunction;function s(t,e){var r,s,l,c,u,h,f,p,d,g,v=e.transform,m=e.transformIndex,y=t.transforms[m].groups,x=o(t.transforms,v);if(!Array.isArray(y)||0===y.length)return[t];var b=n.filterUnique(y),_=new Array(b.length),w=y.length,k=i.findArrayAttributes(t),T=v.styles||[],A={};for(r=0;r<T.length;r++)A[T[r].target]=T[r].value;v.styles&&(g=n.keyedContainer(v,\"styles\",\"target\",\"value.name\"));var M={},S={};for(r=0;r<b.length;r++){M[h=b[r]]=r,S[h]=0,(f=_[r]=n.extendDeepNoArrays({},t))._group=h,f.transforms[m]._indexToPoints={};var E=null;for(g&&(E=g.get(h)),f.name=E||\"\"===E?E:n.templateString(v.nameformat,{trace:t.name,group:h}),p=f.transforms,f.transforms=[],s=0;s<p.length;s++)f.transforms[s]=n.extendDeepNoArrays({},p[s]);for(s=0;s<k.length;s++)n.nestedProperty(f,k[s]).set([])}for(l=0;l<k.length;l++){for(c=k[l],s=0,d=[];s<b.length;s++)d[s]=n.nestedProperty(_[s],c).get();for(u=n.nestedProperty(t,c).get(),s=0;s<w;s++)d[M[y[s]]].push(u[s])}for(s=0;s<w;s++){(f=_[M[y[s]]]).transforms[m]._indexToPoints[S[y[s]]]=x(s),S[y[s]]++}for(r=0;r<b.length;r++)h=b[r],f=_[r],a.clearExpandedTraceDefaultColors(f),f=n.extendDeepNoArrays(f,A[h]||{});return _}r.moduleType=\"transform\",r.name=\"groupby\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"data_array\",dflt:[],editType:\"calc\"},nameformat:{valType:\"string\",editType:\"calc\"},styles:{_isLinkedToArray:\"style\",target:{valType:\"string\",editType:\"calc\"},value:{valType:\"any\",dflt:{},editType:\"calc\",_compareAsJSON:!0},editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t,e,i){var a,o={};function s(e,i){return n.coerce(t,o,r.attributes,e,i)}if(!s(\"enabled\"))return o;s(\"groups\"),s(\"nameformat\",i._dataLength>1?\"%{group} (%{trace})\":\"%{group}\");var l=t.styles,c=o.styles=[];if(l)for(a=0;a<l.length;a++){var u=c[a]={};n.coerce(l[a],c[a],r.attributes.styles,\"target\");var h=n.coerce(l[a],c[a],r.attributes.styles,\"value\");n.isPlainObject(h)?u.value=n.extendDeep({},h):h&&delete u.value}return o},r.transform=function(t,e){var r,n,i,a=[];for(n=0;n<t.length;n++)for(r=s(t[n],e),i=0;i<r.length;i++)a.push(r[i]);return a}},{\"../lib\":719,\"../plot_api/plot_schema\":756,\"../plots/plots\":828,\"./helpers\":1268}],1268:[function(t,e,r){\"use strict\";r.pointsAccessorFunction=function(t,e){for(var r,n,i=0;i<t.length&&(r=t[i])!==e;i++)r._indexToPoints&&!1!==r.enabled&&(n=r._indexToPoints);return n?function(t){return n[t]}:function(t){return[t]}}},{}],1269:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/cartesian/axes\"),a=t(\"./helpers\").pointsAccessorFunction;r.moduleType=\"transform\",r.name=\"sort\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},order:{valType:\"enumerated\",values:[\"ascending\",\"descending\"],dflt:\"ascending\",editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function i(i,a){return n.coerce(t,e,r.attributes,i,a)}return i(\"enabled\")&&(i(\"target\"),i(\"order\")),e},r.calcTransform=function(t,e,r){if(r.enabled){var o=n.getTargetArray(e,r);if(o){var s=r.target,l=o.length;e._length&&(l=Math.min(l,e._length));var c,u,h=e._arrayAttrs,f=function(t,e,r,n){var i,a=new Array(n),o=new Array(n);for(i=0;i<n;i++)a[i]={v:e[i],i:i};for(a.sort(function(t,e){switch(t.order){case\"ascending\":return function(t,r){return e(t.v)-e(r.v)};case\"descending\":return function(t,r){return e(r.v)-e(t.v)}}}(t,r)),i=0;i<n;i++)o[i]=a[i].i;return o}(r,o,i.getDataToCoordFunc(t,e,s,o),l),p=a(e.transforms,r),d={};for(c=0;c<h.length;c++){var g=n.nestedProperty(e,h[c]),v=g.get(),m=new Array(l);for(u=0;u<l;u++)m[u]=v[f[u]];g.set(m)}for(u=0;u<l;u++)d[u]=p(f[u]);r._indexToPoints=d,e._length=l}}}},{\"../lib\":719,\"../plots/cartesian/axes\":767,\"./helpers\":1268}]},{},[25])(25)});</script>    \n",
       "            <div id=\"696e260b-fe59-4ca0-aa25-72b0834bb3bd\" class=\"plotly-graph-div\" style=\"height:600px; width:500px;\"></div>\n",
       "            <script type=\"text/javascript\">\n",
       "                \n",
       "                    window.PLOTLYENV=window.PLOTLYENV || {};\n",
       "                    \n",
       "                if (document.getElementById(\"696e260b-fe59-4ca0-aa25-72b0834bb3bd\")) {\n",
       "                    Plotly.newPlot(\n",
       "                        '696e260b-fe59-4ca0-aa25-72b0834bb3bd',\n",
       "                        [{\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 0.1\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.7943282347242816, 0.8223401594268892, 0.8391818122440673, 0.8513399225207846, 0.8608916593317348, 0.8687754949419235, 0.8754974832997147, 0.8813623600516043, 0.8865681505652134, 0.8912509381337456, 0.8955083387753222, 0.8994127966063055, 0.9030195809896556, 0.9063718353715968, 0.9095038942869436, 0.9124435365554809, 0.9152135599416146, 0.9178329088750865, 0.9203174994833567, 0.9226808345905885, 0.9249344698235435, 0.9270883721415525, 0.9291511993099916, 0.9311305203805873, 0.9330329915368074, 0.9348644977405286, 0.9366302678733724, 0.9383349691179459, 0.939982784920566, 0.9415774798524089, 0.9431224539289232, 0.9446207883816671, 0.9460752844496325, 0.9474884964315516, 0.9488627599902302, 0.9502002165056764, 0.9515028341218914, 0.9527724260125243, 0.954010666295673, 0.955219103952324, 0.9563991750420213, 0.9575522134601357, 0.9586794604411084, 0.9597820729793508, 0.9608611313126507, 0.961917645590783, 0.9629525618336756, 0.9639667672681909, 0.9649610951198176, 0.9659363289248456, 0.9668932064195587, 0.9678324230553559, 0.9687546351822214, 0.9696604629374559, 0.9705504928718682, 0.9714252803415914, 0.9722853516902226, 0.9731312062429956, 0.973963318132117, 0.9747821379701602, 0.9755880943864668, 0.9763815954398198, 0.9771630299191728, 0.9779327685429284, 0.978691165066134, 0.9794385573039582, 0.9801752680789495, 0.9809016060987915, 0.981617866770602, 0.9823243329572049, 0.9830212756802801, 0.9837089547748096, 0.984387619498822, 0.9850575091020549, 0.9857188533568146, 0.9863718730540204, 0.9870167804671348, 0.9876537797864516, 0.9882830675259884, 0.9889048329050317, 0.9895192582062143, 0.9901265191118345, 0.9907267850199871, 0.9913202193419499, 0.9919069797821397, 0.992487218601857, 0.9930610828679294, 0.9936287146872871, 0.9941902514284112, 0.9947458259305311, 0.9952955667013749, 0.9958395981042191, 0.9963780405349252, 0.9969110105895995, 0.9974386212234697, 0.9979609819015223, 0.9984781987414115, 0.9989903746491102, 0.9994976094477416, 1.0, 1.0004976403245405], [0.0, 0.8223401594268892, 0.8513399225207847, 0.8687754949419234, 0.8813623600516043, 0.8912509381337456, 0.8994127966063055, 0.9063718353715968, 0.9124435365554809, 0.9178329088750865, 0.9226808345905884, 0.9270883721415525, 0.9311305203805872, 0.9348644977405285, 0.9383349691179458, 0.9415774798524089, 0.9446207883816672, 0.9474884964315516, 0.9502002165056764, 0.9527724260125243, 0.9552191039523241, 0.9575522134601356, 0.9597820729793509, 0.961917645590783, 0.9639667672681909, 0.9659363289248456, 0.967832423055356, 0.9696604629374559, 0.9714252803415915, 0.9731312062429956, 0.9747821379701603, 0.9763815954398198, 0.9779327685429285, 0.9794385573039583, 0.9809016060987916, 0.9823243329572049, 0.9837089547748096, 0.9850575091020548, 0.9863718730540205, 0.9876537797864517, 0.9889048329050316, 0.9901265191118345, 0.9913202193419499, 0.9924872186018571, 0.9936287146872871, 0.9947458259305312, 0.9958395981042191, 0.9969110105895996, 0.9979609819015225, 0.9989903746491102, 1.0, 1.0009906217066897, 1.0019629597456188, 1.0029176936129038, 1.00385546531494, 1.004776882087206, 1.0056825188704264, 1.0065729205696652, 1.0074486041188226, 1.0083100603703414, 1.009157755827613, 1.00999213423556, 1.0108136180431277, 1.0116226097498822, 1.0124194931475823, 1.0132046344664203, 1.013978383434591, 1.0147410742589553, 1.0154930265337503, 1.0162345460836029, 1.0169659257464727, 1.017687446101599, 1.0183993761470242, 1.019101973930843, 1.019795487139916, 1.0204801536494528, 1.0211562020365474, 1.0218238520604699, 1.0224833151122694, 1.0231347946360152, 1.0237784865237978, 1.0244145794864328, 1.0250432554016415, 1.0256646896413297, 1.0262790513794613, 1.0268865038818877, 1.0274872047793921, 1.0280813063251029, 1.02866895563734, 1.029250294928874, 1.0298254617234994, 1.0303945890607595, 1.0309578056895923, 1.0315152362516102, 1.0320670014546725, 1.032613218237364, 1.033153999924946, 1.0336894563773034, 1.0342196941293802, 1.034744816524555, 1.0352649238413774, 1.0357801134140634], [0.0, 0.8391818122440673, 0.8687754949419234, 0.8865681505652133, 0.8994127966063054, 0.9095038942869436, 0.9178329088750865, 0.9249344698235435, 0.9311305203805871, 0.9366302678733723, 0.9415774798524088, 0.9460752844496324, 0.9502002165056764, 0.9540106662956729, 0.9575522134601356, 0.9608611313126506, 0.9639667672681907, 0.9668932064195587, 0.9696604629374559, 0.9722853516902226, 0.9747821379701602, 0.9771630299191727, 0.9794385573039582, 0.9816178667706019, 0.9837089547748096, 0.9857188533568146, 0.9876537797864517, 0.9895192582062144, 0.9913202193419499, 0.9930610828679294, 0.9947458259305312, 0.9963780405349251, 0.9979609819015223, 0.9994976094477416, 1.0009906217066897, 1.0024424862297645, 1.00385546531494, 1.005231638242012, 1.0065729205696652, 1.007881080948941, 1.009157755827613, 1.0104044623556425, 1.0116226097498822, 1.012813509333941, 1.0139783834345908, 1.0151183732877402, 1.0162345460836026, 1.0173279012613057, 1.0183993761470242, 1.0194498510162482, 1.0204801536494528, 1.0214910634409038, 1.0224833151122694, 1.0234576020758508, 1.0244145794864328, 1.02535486701577, 1.0262790513794613, 1.0271876886423101, 1.0280813063251026, 1.028960405333015, 1.0298254617234994, 1.030676928329443, 1.0315152362516102, 1.03234079623282, 1.0331539999249457, 1.03395522105863, 1.034744816524555, 1.0355231273741894, 1.036290479747109, 1.0370471857312769, 1.0377935441620183, 1.0385298413648787, 1.039256351847022, 1.039973338941407, 1.0406810554075598, 1.0413797439924104, 1.0420696379543473, 1.042750961553344, 1.0434239305097706, 1.0440887524342621, 1.0447456272308093, 1.0453947474750545, 1.0460362987696021, 1.0466704600780024, 1.0472974040389273, 1.047917297261938, 1.0485303006061206, 1.049136569442771, 1.049736253903215, 1.0503294991127619, 1.0509164454117152, 1.0514972285642885, 1.0520719799562177, 1.0526408267817946, 1.053203892220994, 1.0537612956073208, 1.0543131525869553, 1.0548595752697296, 1.0554006723724398, 1.0559365493549526, 1.0564673085495377, 1.0569930492838309], [0.0, 0.8513399225207846, 0.8813623600516043, 0.8994127966063054, 0.9124435365554808, 0.9226808345905884, 0.9311305203805871, 0.9383349691179457, 0.944620788381667, 0.9502002165056763, 0.955219103952324, 0.9597820729793509, 0.9639667672681907, 0.9678324230553558, 0.9714252803415914, 0.9747821379701602, 0.9779327685429285, 0.9809016060987915, 0.9837089547748095, 0.9863718730540204, 0.9889048329050316, 0.9913202193419497, 0.9936287146872871, 0.995839598104219, 0.9979609819015224, 0.9999999999999999, 1.0019629597456188, 1.00385546531494, 1.0056825188704264, 1.0074486041188226, 1.009157755827613, 1.0108136180431275, 1.0124194931475823, 1.013978383434591, 1.0154930265337503, 1.0169659257464725, 1.0183993761470242, 1.0197954871399157, 1.0211562020365474, 1.0224833151122694, 1.0237784865237975, 1.0250432554016413, 1.0262790513794613, 1.027487204779392, 1.02866895563734, 1.0298254617234994, 1.0309578056895923, 1.0320670014546725, 1.033153999924946, 1.0342196941293802, 1.0352649238413774, 1.036290479747109, 1.0372971072129291, 1.038285509697333, 1.039256351847022, 1.040210262311588, 1.0411478363069966, 1.0420696379543473, 1.042976202417175, 1.0438680378577962, 1.0447456272308093, 1.0456094299297674, 1.046459883301246, 1.0472974040389273, 1.0481223894689577, 1.0489352187366092, 1.049736253903215, 1.0505258409614149, 1.0513043107759128, 1.052071979956218, 1.052829151667198, 1.0535761163826978, 1.0543131525869553, 1.0550405274281114, 1.0557584973276855, 1.0564673085495377, 1.0571671977315165, 1.0578583923826854, 1.0585411113487828, 1.0592155652483177, 1.0598819568815, 1.0605404816140185, 1.061191327737498, 1.0618346768083213, 1.0624707039663592, 1.0630995782350208, 1.063721462803927, 1.0643365152954014, 1.06494488801588, 1.065546728193256, 1.06614217820109, 1.0667313757705545, 1.0673144541909094, 1.0678915424992437, 1.0684627656601702, 1.0690282447361041, 1.0695880970487135, 1.0701424363320837, 1.0706913728781056, 1.0712350136745536, 1.0717734625362931, 1.0723068202300237], [0.0, 0.8608916593317348, 0.8912509381337456, 0.9095038942869436, 0.9226808345905884, 0.9330329915368075, 0.9415774798524089, 0.9488627599902302, 0.9552191039523241, 0.9608611313126507, 0.9659363289248456, 0.9705504928718682, 0.9747821379701602, 0.9786911650661339, 0.982324332957205, 0.9857188533568148, 0.9889048329050317, 0.9919069797821398, 0.9947458259305312, 0.9974386212234698, 1.0000000000000002, 1.0024424862297645, 1.004776882087206, 1.0070125708444722, 1.0091577558276132, 1.0112196509975333, 1.0132046344664203, 1.01511837328774, 1.016965925746473, 1.018751825854988, 1.0204801536494528, 1.0221545940611254, 1.0237784865237978, 1.0253548670157702, 1.026886503881888, 1.0283759285097314, 1.0298254617234994, 1.031237236594485, 1.032613218237364, 1.03395522105863, 1.0352649238413776, 1.0365438829846232, 1.0377935441620185, 1.0390152526214478, 1.040210262311588, 1.0413797439924108, 1.0425247924626122, 1.0436464330170645, 1.0447456272308093, 1.0458232781522876, 1.0468802349768656, 1.0479172972619382, 1.0489352187366092, 1.0499347107519328, 1.0509164454117152, 1.0518810584187765, 1.052829151667198, 1.053761295607321, 1.0546780314070283, 1.0555798729300405, 1.056467308549538, 1.057340802813309, 1.0582007979748054, 1.0590477154028666, 1.0598819568815, 1.060703905809855, 1.061513928311467, 1.0623123742608922, 1.063099578235021, 1.0638758603956104, 1.064641527308933, 1.065396872707848, 1.06614217820109, 1.0668777139341084, 1.0676037392053823, 1.0683205030417668, 1.0690282447361044, 1.0697271943500308, 1.0704175731846572, 1.0710995942215589, 1.0717734625362934, 1.0724393756864838, 1.0730975240763216, 1.0737480912991892, 1.0743912544599652, 1.0750271844784427, 1.0756560463751728, 1.0762779995409466, 1.0768931979910255, 1.0775017906051478, 1.0781039213542563, 1.0786997295148189, 1.0792893498715541, 1.0798729129093028, 1.0804505449947366, 1.081022368548549, 1.081588502208716, 1.0821490609853797, 1.0827041564078677, 1.08325389666432, 1.0837983867343681, 1.084337728515279], [0.0, 0.8687754949419235, 0.8994127966063055, 0.9178329088750865, 0.9311305203805871, 0.9415774798524089, 0.9502002165056764, 0.9575522134601357, 0.9639667672681907, 0.9696604629374559, 0.9747821379701602, 0.9794385573039583, 0.9837089547748096, 0.9876537797864516, 0.9913202193419499, 0.9947458259305312, 0.9979609819015225, 1.0009906217066897, 1.00385546531494, 1.0065729205696652, 1.0091577558276132, 1.0116226097498822, 1.013978383434591, 1.0162345460836026, 1.0183993761470242, 1.0204801536494528, 1.0224833151122696, 1.024414579486433, 1.0262790513794615, 1.0280813063251029, 1.0298254617234996, 1.0315152362516102, 1.033153999924946, 1.0347448165245552, 1.0362904797471093, 1.0377935441620183, 1.0392563518470221, 1.0406810554075596, 1.0420696379543475, 1.0434239305097706, 1.0447456272308093, 1.0460362987696024, 1.0472974040389273, 1.0485303006061206, 1.049736253903215, 1.0509164454117155, 1.0520719799562177, 1.053203892220994, 1.0543131525869556, 1.05540067237244, 1.056467308549538, 1.0575138679977951, 1.0585411113487828, 1.0595497564679346, 1.0605404816140187, 1.061513928311467, 1.0624707039663592, 1.063411384253082, 1.0643365152954014, 1.0652466156628766, 1.06614217820109, 1.0670236717120458, 1.067891542499244, 1.0687462157903176, 1.0695880970487135, 1.0704175731846572, 1.0712350136745536, 1.0720407715970253, 1.0728351845929356, 1.0736185757560053, 1.0743912544599652, 1.075153517127609, 1.0759056479465752, 1.0766479195362388, 1.0773805935696719, 1.078103921354256, 1.0788181443742193, 1.0795234947980459, 1.0802201959534683, 1.0809084627724952, 1.081588502208716, 1.0822605136289383, 1.0829246891810287, 1.0835812141396728, 1.0842302672316324, 1.0848720209419425, 1.0855066418023722, 1.0861342906633744, 1.0867551229506447, 1.0873692889073256, 1.0879769338228105, 1.0885781982490277, 1.089173218205021, 1.0897621253705794, 1.0903450472696097, 1.0909221074439044, 1.091493425617897, 1.0920591178549646, 1.0926192967057926, 1.0931740713492821, 1.0937235477264424, 1.0942678286676906], [0.0, 0.8754974832997147, 0.9063718353715968, 0.9249344698235435, 0.9383349691179457, 0.9488627599902302, 0.9575522134601357, 0.9649610951198175, 0.9714252803415914, 0.9771630299191728, 0.9823243329572049, 0.9870167804671348, 0.9913202193419498, 0.9952955667013746, 0.9989903746491101, 1.0024424862297647, 1.0056825188704264, 1.0087355999485315, 1.0116226097498822, 1.0143610908078111, 1.0169659257464727, 1.0194498510162482, 1.0218238520604699, 1.024097471347184, 1.0262790513794615, 1.0283759285097314, 1.0303945890607595, 1.03234079623282, 1.0342196941293804, 1.036035893686527, 1.0377935441620185, 1.0394963930053824, 1.0411478363069966, 1.042750961553344, 1.044308584056803, 1.0458232781522874, 1.0472974040389271, 1.0487331309775447, 1.0501324574228053, 1.0514972285642885, 1.052829151667198, 1.0541298095363008, 1.0554006723724398, 1.056643108246876, 1.0578583923826852, 1.0590477154028666, 1.0602121906803896, 1.0613528609052032, 1.0624707039663592, 1.0635666382333517, 1.064641527308933, 1.0656961843157284, 1.0667313757705545, 1.0677478250931944, 1.0687462157903174, 1.0697271943500306, 1.0706913728781056, 1.0716393315031016, 1.0725716205743159, 1.0734887626736427, 1.0743912544599652, 1.0752795683625556, 1.076154154138104, 1.0770154403043632, 1.0778638354619778, 1.0786997295148186, 1.0795234947980459, 1.0803354871221615, 1.0811360467404627, 1.081925499246547, 1.0827041564078677, 1.0834723169407336, 1.0842302672316324, 1.084978282009281, 1.0857166249713972, 1.0864455493698078, 1.0871652985571791, 1.0878761064983558, 1.0885781982490275, 1.0892717904041989, 1.089957091518724, 1.0906343025019742, 1.0913036169885242, 1.091965221686588, 1.0926192967057926, 1.0932660158657435, 1.0939055469867183, 1.0945380521637205, 1.0951636880250228, 1.095782605976246, 1.0963949524309333, 1.0970008690285074, 1.0976004928404337, 1.0981939565653491, 1.0987813887138531, 1.0993629137836196, 1.0999386524254275, 1.1005087216006728, 1.101073234730881, 1.1016323018397038, 1.1021860296878503, 1.1027345219013682], [0.0, 0.8813623600516043, 0.9124435365554809, 0.9311305203805871, 0.944620788381667, 0.9552191039523241, 0.9639667672681907, 0.9714252803415914, 0.9779327685429285, 0.9837089547748095, 0.9889048329050316, 0.9936287146872872, 0.9979609819015224, 1.0019629597456188, 1.0056825188704264, 1.009157755827613, 1.0124194931475825, 1.0154930265337503, 1.0183993761470242, 1.0211562020365474, 1.0237784865237978, 1.0262790513794613, 1.02866895563734, 1.0309578056895923, 1.033153999924946, 1.0352649238413774, 1.0372971072129293, 1.0392563518470221, 1.0411478363069968, 1.042976202417175, 1.0447456272308093, 1.0464598833012457, 1.0481223894689577, 1.049736253903215, 1.051304310775913, 1.052829151667198, 1.0543131525869553, 1.0557584973276852, 1.0571671977315165, 1.0585411113487828, 1.0598819568815, 1.061191327737498, 1.0624707039663592, 1.063721462803927, 1.06494488801588, 1.06614217820109, 1.0673144541909094, 1.0684627656601704, 1.0695880970487137, 1.0706913728781056, 1.0717734625362931, 1.0728351845929356, 1.0738773106996744, 1.0749005691224152, 1.075905647946575, 1.0768931979910255, 1.0778638354619778, 1.0788181443742193, 1.0797566787637858, 1.0806799647132996, 1.081588502208716, 1.0824827668440669, 1.083363211388921, 1.0842302672316324, 1.0850843457100232, 1.0859258393398943, 1.0867551229506447, 1.0875725547363184, 1.0883784772295373, 1.089173218205021, 1.0899570915187238, 1.0907303978880278, 1.091493425617897, 1.0922464512774306, 1.0929897403308335, 1.0937235477264422, 1.0944481184471209, 1.0951636880250228, 1.0958704830234647, 1.0965687214884012, 1.0972586133717765, 1.0979403609288347, 1.0986141590912912, 1.0992801958181004, 1.0999386524254275, 1.1005897038972794, 1.1012335191781464, 1.1018702614488909, 1.1025000883870246, 1.1031231524124203, 1.1037396009194318, 1.1043495764963112, 1.1049532171327532, 1.1055506564163307, 1.1061420237185238, 1.1067274443710045, 1.1073070398327802, 1.107880927848761, 1.1084492226002718, 1.1090120348480037, 1.1095694720678448, 1.110121638580025], [0.0, 0.8865681505652134, 0.9178329088750865, 0.9366302678733723, 0.9502002165056763, 0.9608611313126507, 0.9696604629374559, 0.9771630299191728, 0.9837089547748095, 0.9895192582062144, 0.9947458259305311, 0.9994976094477416, 1.00385546531494, 1.007881080948941, 1.0116226097498822, 1.0151183732877402, 1.0183993761470242, 1.021491063440904, 1.024414579486433, 1.0271876886423104, 1.0298254617234994, 1.03234079623282, 1.034744816524555, 1.0370471857312766, 1.0392563518470221, 1.0413797439924106, 1.0434239305097706, 1.0453947474750545, 1.0472974040389273, 1.049136569442771, 1.0509164454117152, 1.0526408267817946, 1.0543131525869553, 1.0559365493549528, 1.0575138679977951, 1.0590477154028666, 1.0605404816140187, 1.0619943633223812, 1.0634113842530821, 1.0647934129281265, 1.06614217820109, 1.0674592828913085, 1.0687462157903174, 1.0700043622686408, 1.0712350136745534, 1.0724393756864838, 1.073618575756005, 1.0747736697578816, 1.0759056479465752, 1.0770154403043632, 1.0781039213542563, 1.079171914500817, 1.0802201959534683, 1.0812494982796381, 1.0822605136289383, 1.08325389666432, 1.0842302672316324, 1.0851902127951623, 1.0861342906633742, 1.0870630300262119, 1.0879769338228107, 1.0888764804563116, 1.0897621253705794, 1.0906343025019742, 1.091493425617897, 1.0923398895525533, 1.0931740713492821, 1.0939963313178103, 1.0948070140139379, 1.0956064491483948, 1.0963949524309335, 1.097172826355132, 1.097940360928835, 1.0986978343547047, 1.0994455136649173, 1.1001836553136688, 1.1009125057308207, 1.1016323018397038, 1.1023432715418373, 1.1030456341710697, 1.1037396009194318, 1.1044253752367945, 1.1051031532062419, 1.1057731238969137, 1.1064354696959233, 1.1070903666208256, 1.107737984613986, 1.1083784878200995, 1.1090120348480037, 1.1096387790178437, 1.110258868594562, 1.1108724470086122, 1.1114796530647288, 1.1120806211395229, 1.112675481368611, 1.1132643598239402, 1.113847378681919, 1.1144246563829199, 1.114996307782684, 1.1155624442961132, 1.1161231740339044, 1.116678601932458], [0.0, 0.8912509381337456, 0.9226808345905884, 0.9415774798524088, 0.955219103952324, 0.9659363289248456, 0.9747821379701602, 0.9823243329572049, 0.9889048329050316, 0.9947458259305311, 1.0, 1.004776882087206, 1.009157755827613, 1.01320463446642, 1.0169659257464727, 1.0204801536494528, 1.0237784865237978, 1.0268865038818877, 1.0298254617234994, 1.032613218237364, 1.0352649238413776, 1.0377935441620183, 1.040210262311588, 1.0425247924626122, 1.0447456272308093, 1.0468802349768656, 1.0489352187366092, 1.0509164454117152, 1.0528291516671981, 1.0546780314070283, 1.056467308549538, 1.0582007979748052, 1.0598819568815, 1.061513928311467, 1.063099578235021, 1.064641527308933, 1.06614217820109, 1.067603739205382, 1.0690282447361044, 1.0704175731846572, 1.0717734625362931, 1.0730975240763216, 1.0743912544599652, 1.0756560463751728, 1.0768931979910255, 1.0781039213542563, 1.0792893498715541, 1.0804505449947366, 1.081588502208716, 1.0827041564078677, 1.0837983867343681, 1.0848720209419425, 1.0859258393398943, 1.0869605783650185, 1.0879769338228105, 1.0889755638341023, 1.0899570915187238, 1.0909221074439044, 1.091871171861771, 1.0928048167574094, 1.0937235477264424, 1.0946278456989014, 1.0955181685242716, 1.0963949524309335, 1.0972586133717763, 1.0981095482664913, 1.0989481361499323, 1.0997747392349555, 1.1005897038972794, 1.1013933615891416, 1.1021860296878503, 1.102968012284732, 1.1037396009194318, 1.1045010752640576, 1.1052527037612299, 1.1059947442197169, 1.1067274443710045, 1.107451042389835, 1.1081657673814862, 1.1088718398383124, 1.109569472067845, 1.110258868594562, 1.110940226537244, 1.1116137359636795, 1.112279580224338, 1.1129379362664853, 1.1135889749301104, 1.1142328612269081, 1.1148697546034765, 1.1154998091897863, 1.1161231740339044, 1.1167399933238733, 1.1173504065975843, 1.1179545489414158, 1.1185525511783507, 1.119144540046239, 1.1197306383668157, 1.1203109652060472, 1.120885636026334, 1.1214547628310625, 1.1220184543019633, 1.1225768159297027], [0.0, 0.8955083387753222, 0.9270883721415525, 0.9460752844496324, 0.9597820729793509, 0.9705504928718682, 0.9794385573039583, 0.9870167804671348, 0.9936287146872872, 0.9994976094477416, 1.004776882087206, 1.0095765827768872, 1.013978383434591, 1.018044593535477, 1.0218238520604699, 1.0253548670157702, 1.0286689556373403, 1.0317918196278748, 1.0347448165245552, 1.0375458898225742, 1.0402102623115883, 1.042750961553344, 1.0451792240805522, 1.047504810469195, 1.0497362539032151, 1.0518810584187765, 1.0539458585936317, 1.0559365493549526, 1.0578583923826856, 1.0597161040030263, 1.061513928311467, 1.0632556984113182, 1.0649448880158803, 1.0665846551809377, 1.068177879567208, 1.0697271943500306, 1.0712350136745536, 1.0727035563834264, 1.0741348666091015, 1.0755308317158336, 1.0768931979910255, 1.078223584416907, 1.0795234947980459, 1.0807943284750972, 1.0820373898183429, 1.08325389666432, 1.0844449878338678, 1.085611729849234, 1.0867551229506447, 1.087876106498356, 1.0889755638341023, 1.090054326665691, 1.0911131790298711, 1.0921528608813094, 1.0931740713492821, 1.0941774716983865, 1.0951636880250228, 1.0961333137174902, 1.0970869117041742, 1.0980250165113903, 1.0989481361499323, 1.0998567538471775, 1.100751329639704, 1.101632301839704, 1.1025000883870246, 1.1033550880973955, 1.1041976818162753, 1.1050282334867687, 1.1058470911391898, 1.1066545878090843, 1.107451042389835, 1.1082367604253762, 1.1090120348480037, 1.1097771466657864, 1.110532365603663, 1.1112779507019241, 1.1120141508754398, 1.1127412054366845, 1.1134593445853458, 1.1141687898670432, 1.1148697546034767, 1.115562444296113, 1.1162470570053462, 1.1169237837068966, 1.1175928086270766, 1.1182543095584088, 1.1189084581569642, 1.1195554202226794, 1.1201953559638096, 1.1208284202465868, 1.1214547628310625, 1.1220745285940488, 1.1226878577399928, 1.1232948860005645, 1.1238957448236733, 1.1244905615525804, 1.125079459595726, 1.1256625585878406, 1.1262399745428746, 1.126811819999242, 1.127378204157833, 1.12793923301323], [0.0, 0.8994127966063055, 0.9311305203805872, 0.9502002165056764, 0.9639667672681907, 0.9747821379701602, 0.9837089547748096, 0.9913202193419498, 0.9979609819015224, 1.00385546531494, 1.009157755827613, 1.013978383434591, 1.0183993761470242, 1.0224833151122694, 1.0262790513794613, 1.0298254617234994, 1.033153999924946, 1.0362904797471093, 1.0392563518470221, 1.0420696379543475, 1.0447456272308093, 1.0472974040389271, 1.049736253903215, 1.0520719799562177, 1.0543131525869556, 1.0564673085495377, 1.058541111348783, 1.0605404816140187, 1.0624707039663592, 1.0643365152954014, 1.0661421782010903, 1.0678915424992437, 1.0695880970487135, 1.0712350136745536, 1.0728351845929358, 1.0743912544599652, 1.0759056479465752, 1.0773805935696716, 1.0788181443742193, 1.0802201959534685, 1.081588502208716, 1.0829246891810287, 1.0842302672316324, 1.0855066418023722, 1.0867551229506447, 1.0879769338228107, 1.089173218205021, 1.09034504726961, 1.091493425617897, 1.0926192967057926, 1.0937235477264424, 1.0948070140139379, 1.0958704830234647, 1.0969146979359263, 1.097940360928835, 1.0989481361499323, 1.0999386524254275, 1.1009125057308207, 1.1018702614488909, 1.1028124564365132, 1.1037396009194318, 1.104652180231918, 1.1055506564163307, 1.1064354696959233, 1.1073070398327802, 1.1081657673814862, 1.1090120348480037, 1.109846207762246, 1.1106686356719555, 1.1114796530647288, 1.112279580224338, 1.1130687240269033, 1.113847378681919, 1.114615826422662, 1.1153743381500842, 1.1161231740339044, 1.1168625840742723, 1.1175928086270766, 1.1183140788956853, 1.1190266173916676, 1.119730638366816, 1.120426348218593, 1.1211139458709451, 1.1217936231322556, 1.1224655650320723, 1.1231299501381014, 1.1237869508548424, 1.1244367337051269, 1.1250794595957259, 1.1257152840680953, 1.1263443575352472, 1.1269668255056635, 1.127582828795089, 1.1281925037269904, 1.1287959823223956, 1.1293933924797888, 1.1299848581456764, 1.1305704994764016, 1.131150432991742, 1.131724771720783, 1.1322936253405365, 1.1328571003077261], [0.0, 0.9030195809896556, 0.9348644977405285, 0.9540106662956729, 0.9678324230553558, 0.9786911650661339, 0.9876537797864516, 0.9952955667013746, 1.0019629597456188, 1.007881080948941, 1.01320463446642, 1.018044593535477, 1.0224833151122694, 1.0265836313042318, 1.0303945890607593, 1.03395522105863, 1.0372971072129293, 1.040446164804148, 1.0434239305097706, 1.046248498329382, 1.0489352187366092, 1.0514972285642883, 1.0539458585936314, 1.0562909512692615, 1.0585411113487828, 1.060703905809855, 1.0627860248789804, 1.0647934129281265, 1.0667313757705545, 1.0686046692915216, 1.0704175731846572, 1.0721739527041365, 1.0738773106996744, 1.0755308317158334, 1.0771374195670198, 1.0786997295148186, 1.0802201959534683, 1.0817010563365723, 1.0831443719421232, 1.084552045964993, 1.0859258393398943, 1.0872673846285699, 1.0885781982490275, 1.0898596912791516, 1.0911131790298711, 1.0923398895525533, 1.093540971220108, 1.0947174995004365, 1.095870483023465, 1.0970008690285074, 1.0981095482664913, 1.0991973594213271, 1.100265093106018, 1.1013134954817372, 1.102343271541837, 1.1033550880973952, 1.104349576496311, 1.1053273351040378, 1.1062889315706275, 1.107234904905834, 1.1081657673814862, 1.1090820062781201, 1.1099840854909566, 1.110872447008612, 1.1117475122764815, 1.112609683455436, 1.1134593445853458, 1.1142968626619556, 1.1151225886347484, 1.1159368583326679, 1.116739993323873, 1.1175323017151058, 1.1183140788956853, 1.1190856082306875, 1.1198471617074193, 1.12059900053892, 1.1213413757278787, 1.1220745285940485, 1.1227986912679586, 1.1235140871534839, 1.1242209313615996, 1.1249194311174544, 1.1256097861427101, 1.1262921890149316, 1.1269668255056635, 1.127633874898696, 1.1282935102898979, 1.1289458988698828, 1.1295912021906829, 1.1302295764174988, 1.1308611725665225, 1.1314861367297475, 1.1321046102876113, 1.1327167301102588, 1.1333226287481424, 1.1339224346126393, 1.1345162721473008, 1.1351042619903153, 1.1356865211287224, 1.1362631630448725, 1.1368342978555983, 1.1374000324445321], [0.0, 0.9063718353715968, 0.9383349691179458, 0.9575522134601356, 0.9714252803415914, 0.982324332957205, 0.9913202193419499, 0.9989903746491101, 1.0056825188704264, 1.0116226097498822, 1.0169659257464727, 1.0218238520604699, 1.0262790513794613, 1.0303945890607593, 1.0342196941293802, 1.0377935441620185, 1.0411478363069968, 1.0443085840568027, 1.0472974040389273, 1.0501324574228053, 1.0528291516671981, 1.0554006723724398, 1.0578583923826854, 1.0602121906803899, 1.0624707039663592, 1.064641527308933, 1.0667313757705545, 1.0687462157903174, 1.0706913728781058, 1.0725716205743159, 1.0743912544599652, 1.076154154138104, 1.0778638354619778, 1.0795234947980459, 1.0811360467404627, 1.0827041564078677, 1.0842302672316324, 1.0857166249713972, 1.0871652985571791, 1.0885781982490277, 1.0899570915187238, 1.0913036169885242, 1.0926192967057926, 1.0939055469867183, 1.0951636880250226, 1.0963949524309335, 1.0976004928404337, 1.0987813887138533, 1.0999386524254275, 1.101073234730881, 1.1021860296878503, 1.1032778790936693, 1.104349576496311, 1.1054018708269024, 1.1064354696959233, 1.107451042389835, 1.1084492226002718, 1.109430610913983, 1.110395777088292, 1.1113452621339033, 1.112279580224338, 1.1131992204490504, 1.1141046484253663, 1.1149963077826843, 1.1158746215309194, 1.1167399933238733, 1.1175928086270766, 1.118433435798662, 1.119262227090933, 1.120079519579521, 1.120885636026334, 1.1216808856818894, 1.1224655650320723, 1.1232399584938868, 1.124004339064331, 1.1247589689261377, 1.1255041000137864, 1.1262399745428746, 1.1269668255056635, 1.1276848771353638, 1.128394345341501, 1.1290954381185, 1.1297883559294444, 1.1304732920667984, 1.131150432991742, 1.131819958653615, 1.1324820427908653, 1.1331368532147637, 1.1337845520770673, 1.1344252961227046, 1.135059236928481, 1.1356865211287226, 1.13630729062871, 1.1369216828066873, 1.1375298307051702, 1.138131863212234, 1.1387279052333976, 1.1393180778546923, 1.1399024984974446, 1.1404812810652825, 1.1410545360838225, 1.1416223708334778], [0.0, 0.9095038942869436, 0.9415774798524089, 0.9608611313126506, 0.9747821379701602, 0.9857188533568148, 0.9947458259305312, 1.0024424862297647, 1.009157755827613, 1.0151183732877402, 1.0204801536494528, 1.0253548670157702, 1.0298254617234994, 1.03395522105863, 1.0377935441620185, 1.0413797439924108, 1.0447456272308093, 1.0479172972619382, 1.0509164454117152, 1.053761295607321, 1.056467308549538, 1.0590477154028666, 1.061513928311467, 1.0638758603956104, 1.0661421782010903, 1.068320503041767, 1.0704175731846572, 1.0724393756864838, 1.0743912544599654, 1.0762779995409466, 1.0781039213542563, 1.0798729129093028, 1.081588502208716, 1.08325389666432, 1.0848720209419427, 1.086445549369808, 1.0879769338228107, 1.0894684278210387, 1.0909221074439046, 1.0923398895525533, 1.0937235477264424, 1.095074726250252, 1.0963949524309335, 1.0976856474788992, 1.0989481361499323, 1.100183655313669, 1.1013933615891416, 1.1025783381668637, 1.103739600919432, 1.104878103888002, 1.105994744219717, 1.1070903666208258, 1.1081657673814862, 1.109221698020832, 1.1102588685945622, 1.1112779507019241, 1.112279580224338, 1.1132643598239405, 1.1142328612269081, 1.1151856273134633, 1.1161231740339046, 1.1170459921677844, 1.1179545489414158, 1.1188492895172035, 1.1197306383668157, 1.1205990005389201, 1.1214547628310627, 1.1222982948742743, 1.1231299501381014, 1.1239500668629745, 1.1247589689261377, 1.1255569666467549, 1.1263443575352474, 1.1271214269914513, 1.127888448955733, 1.128645686516824, 1.1293933924797888, 1.1301318098972253, 1.1308611725665227, 1.1315817054957524, 1.1322936253405367, 1.1329971408140462, 1.1336924530720844, 1.134379756075058, 1.135059236928481, 1.1357310762035278, 1.1363954482390157, 1.1370525214261047, 1.1377024584768833, 1.1383454166779283, 1.1389815481298335, 1.139610999973635, 1.1402339146049814, 1.1408504298768407, 1.1414606792914708, 1.1420647921823321, 1.142662893886568, 1.1432551059086338, 1.143841546075618, 1.1444223286847532, 1.144997564643589, 1.1455673616032565], [0.0, 0.9124435365554809, 0.9446207883816672, 0.9639667672681907, 0.9779327685429285, 0.9889048329050317, 0.9979609819015225, 1.0056825188704264, 1.0124194931475825, 1.0183993761470242, 1.0237784865237978, 1.0286689556373403, 1.033153999924946, 1.0372971072129293, 1.0411478363069968, 1.0447456272308093, 1.048122389468958, 1.051304310775913, 1.0543131525869556, 1.0571671977315165, 1.0598819568815003, 1.0624707039663592, 1.0649448880158803, 1.0673144541909094, 1.0695880970487137, 1.0717734625362931, 1.0738773106996746, 1.0759056479465752, 1.077863835461978, 1.079756678763786, 1.0815885022087162, 1.083363211388921, 1.0850843457100232, 1.086755122950645, 1.0883784772295375, 1.0899570915187238, 1.091493425617897, 1.0929897403308333, 1.094448118447121, 1.095870483023465, 1.0972586133717765, 1.0986141590912912, 1.0999386524254278, 1.1012335191781464, 1.1025000883870246, 1.103739600919432, 1.1049532171327534, 1.106142023718524, 1.1073070398327804, 1.108449222600272, 1.109569472067845, 1.1106686356719557, 1.1117475122764817, 1.1128068558295705, 1.113847378681919, 1.1148697546034767, 1.1158746215309197, 1.1168625840742723, 1.1178342158076096, 1.1187900613658168, 1.119730638366816, 1.1206564391764264, 1.1215679325311017, 1.1224655650320723, 1.123349762522958, 1.1242209313615998, 1.125079459595726, 1.1259257180510671, 1.1267600613396314, 1.1275828287950893, 1.128394345341501, 1.1291949223010247, 1.1299848581456764, 1.130764439197744, 1.1315339402830074, 1.1322936253405367, 1.1330437479924975, 1.1337845520770675, 1.1345162721473008, 1.1352391339385266, 1.1359533548066276, 1.1366591441393648, 1.1373567037427046, 1.1380462282039603, 1.1387279052333978, 1.1394019159858213, 1.1400684353635357, 1.1407276323019648, 1.141379670039105, 1.1420247063699047, 1.142662893886568, 1.143294380205711, 1.1439193081832248, 1.1445378161176376, 1.1451500379427049, 1.1457561034099104, 1.1463561382615046, 1.146950264394662, 1.1475386000173047, 1.1481212597960897, 1.1486983549970349, 1.149269993619215], [0.0, 0.9152135599416146, 0.9474884964315516, 0.9668932064195587, 0.9809016060987915, 0.9919069797821398, 1.0009906217066897, 1.0087355999485315, 1.0154930265337503, 1.021491063440904, 1.0268865038818877, 1.0317918196278748, 1.0362904797471093, 1.040446164804148, 1.0443085840568027, 1.0479172972619382, 1.051304310775913, 1.0544958918547662, 1.0575138679977951, 1.0603765775379914, 1.063099578235021, 1.0656961843157284, 1.068177879567208, 1.0705546393421224, 1.0728351845929358, 1.0750271844784427, 1.0771374195670198, 1.079171914500817, 1.081136046740463, 1.0830346363925951, 1.0848720209419427, 1.0866521178373714, 1.0883784772295373, 1.090054326665691, 1.0916826091720702, 1.0932660158657435, 1.0948070140139379, 1.0963078712838454, 1.0977706767880493, 1.0991973594213273, 1.1005897038972794, 1.1019493648230438, 1.1032778790936693, 1.1045766768416148, 1.1058470911391896, 1.1070903666208258, 1.1083076671665557, 1.1095000827669252, 1.1106686356719557, 1.1118142859120639, 1.1129379362664853, 1.1140404367443495, 1.1151225886347484, 1.1161851481746885, 1.1172288298774418, 1.1182543095584088, 1.119262227090933, 1.120253188920532, 1.121227770362554, 1.122186517705303, 1.1231299501381014, 1.1240585615215073, 1.124972822014978, 1.1258731795755499, 1.1267600613396314, 1.1276338748986963, 1.1284950094785207, 1.1293438370305982, 1.1301807132434794, 1.1310059784809934, 1.131819958653615, 1.1326229660286236, 1.1334152999841454, 1.134197247711694, 1.1349690848713732, 1.1357310762035278, 1.1364834761002771, 1.1372265291400498, 1.1379604705879636, 1.1386855268646412, 1.1394019159858213, 1.14010984797493, 1.1408095252505828, 1.1415011429908266, 1.142184889475784, 1.1428609464102142, 1.1435294892273962, 1.1441906873756122, 1.144844704588422, 1.1454916991398125, 1.1461318240852318, 1.1467652274894349, 1.1473920526419992, 1.1480124382613033, 1.148626518687703, 1.1492344240665857, 1.1498362805219338, 1.150432210320981, 1.1510223320305082, 1.1516067606652813, 1.1521856078291028, 1.152758981848914], [0.0, 0.9178329088750865, 0.9502002165056764, 0.9696604629374559, 0.9837089547748095, 0.9947458259305312, 1.00385546531494, 1.0116226097498822, 1.0183993761470242, 1.024414579486433, 1.0298254617234994, 1.0347448165245552, 1.0392563518470221, 1.0434239305097706, 1.0472974040389273, 1.0509164454117152, 1.0543131525869556, 1.0575138679977951, 1.0605404816140187, 1.0634113842530821, 1.06614217820109, 1.0687462157903174, 1.0712350136745536, 1.073618575756005, 1.0759056479465752, 1.078103921354256, 1.0802201959534685, 1.0822605136289385, 1.0842302672316326, 1.0861342906633744, 1.0879769338228107, 1.0897621253705791, 1.091493425617897, 1.0931740713492821, 1.094807014013938, 1.0963949524309335, 1.097940360928835, 1.099445513664917, 1.100912505730821, 1.1023432715418373, 1.1037396009194318, 1.105103153206242, 1.1064354696959233, 1.107737984613986, 1.1090120348480037, 1.1102588685945622, 1.1114796530647286, 1.1126754813686113, 1.113847378681919, 1.1149963077826843, 1.1161231740339044, 1.1172288298774418, 1.1183140788956853, 1.119379679489997, 1.120426348218593, 1.1214547628310625, 1.1224655650320723, 1.1234593630027918, 1.1244367337051269, 1.1253982249908634, 1.1263443575352474, 1.1272756266122705, 1.1281925037269904, 1.1290954381185003, 1.1299848581456764, 1.1308611725665227, 1.131724771720783, 1.1325760286244793, 1.1334152999841454, 1.1342429271377348, 1.135059236928481, 1.1358645425173746, 1.1366591441393648, 1.1374433298079096, 1.1382173759720546, 1.1389815481298335, 1.1397361014014382, 1.1404812810652825, 1.141217323059815, 1.1419444544536763, 1.142662893886568, 1.1433728519830049, 1.1440745317409262, 1.1447681288969804, 1.1454538322701489, 1.1461318240852318, 1.1468022802775995, 1.1474653707804965, 1.1481212597960897, 1.148770106051347, 1.1494120630397633, 1.1500472792498555, 1.150675898381297, 1.15129805954948, 1.1519138974792433, 1.1525235426884515, 1.1531271216620549, 1.1537247570172169, 1.1543165676600577, 1.1549026689345165, 1.1554831727638066, 1.1560581877849019], [0.0, 0.9203174994833567, 0.9527724260125243, 0.9722853516902226, 0.9863718730540204, 0.9974386212234698, 1.0065729205696652, 1.0143610908078111, 1.0211562020365474, 1.0271876886423104, 1.032613218237364, 1.0375458898225742, 1.0420696379543475, 1.046248498329382, 1.0501324574228053, 1.053761295607321, 1.0571671977315165, 1.0603765775379914, 1.0634113842530821, 1.0662900584785258, 1.0690282447361044, 1.0716393315031016, 1.0741348666091015, 1.076524881037058, 1.0788181443742193, 1.081022368548549, 1.0831443719421234, 1.0851902127951623, 1.0871652985571791, 1.0890744762154592, 1.0909221074439046, 1.09271213153811, 1.0944481184471209, 1.0961333137174905, 1.0977706767880493, 1.0993629137836196, 1.1009125057308207, 1.102421732943113, 1.103892696183589, 1.105327335104038, 1.1067274443710045, 1.1080946878189977, 1.1094306109139833, 1.1107366517639463, 1.1120141508754395, 1.1132643598239405, 1.1144884489801778, 1.1156875144133287, 1.1168625840742723, 1.1180146233472985, 1.119144540046239, 1.120253188920532, 1.121341375727879, 1.1224098609226483, 1.1234593630027918, 1.1244905615525804, 1.1255041000137864, 1.1265005882139374, 1.1274806046767853, 1.1284446987371612, 1.1293933924797888, 1.1303271825193753, 1.131246541637351, 1.1321519202889079, 1.1330437479924975, 1.1339224346126395, 1.1347883715457343, 1.135641932817565, 1.1364834761002771, 1.1373133436558323, 1.138131863212234, 1.1389393487782056, 1.1397361014014382, 1.1405224098750475, 1.1412985513964313, 1.1420647921823321, 1.142821388043556, 1.1435685849224908, 1.1443066193962745, 1.1450357191482265, 1.1457561034099104, 1.1464679833760052, 1.1471715625939696, 1.1478670373303144, 1.1485545969151578, 1.1492344240665857, 1.1499066951962285, 1.1505715806973438, 1.151229245216596, 1.1518798479106307, 1.1525235426884515, 1.1531604784405372, 1.1537907992555587, 1.154414644625496, 1.1550321496398905, 1.1556434451699213, 1.1562486580429356, 1.1568479112080239, 1.1574413238931873, 1.1580290117546033, 1.1586110870184632, 1.1591876586158232], [0.0, 0.9226808345905885, 0.9552191039523241, 0.9747821379701602, 0.9889048329050316, 1.0000000000000002, 1.0091577558276132, 1.0169659257464727, 1.0237784865237978, 1.0298254617234994, 1.0352649238413776, 1.0402102623115883, 1.0447456272308093, 1.0489352187366092, 1.0528291516671981, 1.056467308549538, 1.0598819568815003, 1.063099578235021, 1.06614217820109, 1.0690282447361044, 1.0717734625362934, 1.0743912544599652, 1.0768931979910257, 1.0792893498715541, 1.0815885022087162, 1.0837983867343681, 1.0859258393398945, 1.0879769338228107, 1.089957091518724, 1.0918711718617713, 1.0937235477264426, 1.0955181685242716, 1.0972586133717765, 1.0989481361499325, 1.1005897038972796, 1.1021860296878503, 1.1037396009194318, 1.1052527037612299, 1.1067274443710047, 1.1081657673814864, 1.109569472067845, 1.110940226537244, 1.112279580224338, 1.1135889749301104, 1.1148697546034765, 1.1161231740339046, 1.1173504065975843, 1.118552551178351, 1.119730638366816, 1.1208856360263342, 1.1220184543019636, 1.1231299501381014, 1.1242209313615996, 1.1252921603796406, 1.1263443575352474, 1.127378204157833, 1.128394345341501, 1.1293933924797888, 1.1303759255820722, 1.13134249539385, 1.1322936253405367, 1.1332298133121244, 1.1341515333041254, 1.1350592369284813, 1.1359533548066276, 1.1368342978555988, 1.1377024584768836, 1.1385582116567472, 1.1394019159858213, 1.1402339146049816, 1.1410545360838227, 1.1418640952374288, 1.142662893886568, 1.1434512215659642, 1.1442293561848462, 1.144997564643589, 1.1457561034099104, 1.1465052190577667, 1.147245148771816, 1.1479761208200587, 1.148698354997035, 1.1494120630397633, 1.1501174490184025, 1.1508147097034678, 1.1515040349112686, 1.1521856078291028, 1.1528596053216185, 1.1535261982196352, 1.1541855515926234, 1.1548378250059352, 1.1554831727638066, 1.15612174413906, 1.1567536835903804, 1.1573791309679564, 1.1579982217082339, 1.1586110870184632, 1.1592178540516787, 1.1598186460726987, 1.1604135826156967, 1.16100277963385, 1.1615863496415422, 1.1621644018495598], [0.0, 0.9249344698235435, 0.9575522134601356, 0.9771630299191727, 0.9913202193419497, 1.0024424862297645, 1.0116226097498822, 1.0194498510162482, 1.0262790513794613, 1.03234079623282, 1.0377935441620183, 1.042750961553344, 1.0472974040389271, 1.0514972285642883, 1.0554006723724398, 1.0590477154028666, 1.0624707039663592, 1.0656961843157284, 1.0687462157903174, 1.0716393315031016, 1.0743912544599652, 1.077015440304363, 1.0795234947980457, 1.0819254992465468, 1.0842302672316324, 1.0864455493698078, 1.0885781982490277, 1.0906343025019742, 1.0926192967057926, 1.0945380521637205, 1.0963949524309335, 1.098193956565349, 1.0999386524254275, 1.1016323018397038, 1.1032778790936693, 1.1048781038880018, 1.1064354696959233, 1.1079522682705765, 1.1094306109139833, 1.110872447008612, 1.1122795802243377, 1.1136536827426526, 1.114996307782684, 1.1163089006669948, 1.1175928086270763, 1.1188492895172035, 1.1200795195795208, 1.121284600381872, 1.1224655650320723, 1.1236233837574692, 1.1247589689261377, 1.1258731795755499, 1.1269668255056633, 1.1280406709858297, 1.1290954381185, 1.1301318098972253, 1.1311504329917417, 1.1321519202889077, 1.1331368532147637, 1.1341057838599968, 1.135059236928481, 1.1359977115262978, 1.136921682806687, 1.137831603484646, 1.1387279052333976, 1.139610999973635, 1.1404812810652825, 1.141339124410504, 1.1421848894757838, 1.1430189202401146, 1.1438415460756177, 1.1446530825663086, 1.1454538322701489, 1.1462440854290465, 1.14702412063102, 1.147794205428345, 1.1485545969151576, 1.1493055422676683, 1.1500472792498553, 1.15078003668726, 1.1515040349112684, 1.152219486176063, 1.1529265950502419, 1.153625558784929, 1.1543165676600575, 1.1549998053103583, 1.1556754490324683, 1.1563436700744594, 1.1570046339089815, 1.1576585004911235, 1.1583054245020068, 1.158945555579051, 1.1595790385337792, 1.1602060135579624, 1.1608266164188479, 1.1614409786441582, 1.162049227697497, 1.1626514871447553, 1.163247876812067, 1.163838512935824, 1.1644235083052241, 1.1650029723977997], [0.0, 0.9270883721415525, 0.9597820729793509, 0.9794385573039582, 0.9936287146872871, 1.004776882087206, 1.013978383434591, 1.0218238520604699, 1.02866895563734, 1.034744816524555, 1.040210262311588, 1.0451792240805522, 1.049736253903215, 1.0539458585936314, 1.0578583923826854, 1.061513928311467, 1.0649448880158803, 1.068177879567208, 1.0712350136745536, 1.0741348666091015, 1.0768931979910257, 1.0795234947980457, 1.0820373898183429, 1.0844449878338678, 1.0867551229506447, 1.0889755638341023, 1.0911131790298714, 1.0931740713492821, 1.0951636880250228, 1.0970869117041742, 1.0989481361499323, 1.1007513296397038, 1.1025000883870246, 1.1041976818162753, 1.1058470911391898, 1.107451042389835, 1.1090120348480037, 1.1105323656036628, 1.1120141508754398, 1.1134593445853458, 1.1148697546034765, 1.1162470570053462, 1.1175928086270766, 1.1189084581569642, 1.1201953559638096, 1.1214547628310627, 1.1226878577399926, 1.1238957448236733, 1.125079459595726, 1.1262399745428746, 1.127378204157833, 1.1284950094785207, 1.1295912021906829, 1.1306675483434314, 1.131724771720783, 1.132763556906781, 1.1337845520770673, 1.1347883715457343, 1.135775598092794, 1.1367467850945918, 1.1377024584768833, 1.1386431185080228, 1.1395692414477432, 1.1404812810652825, 1.1413796700391048, 1.1422648212491464, 1.143137128971352, 1.1439969699832515, 1.144844704588422, 1.1456806775668829, 1.1465052190577665, 1.147318645379992, 1.1481212597960897, 1.1489133532238565, 1.1496952049000608, 1.1504670830000294, 1.151229245216596, 1.1519819393015718, 1.152725403572618, 1.1534598673881442, 1.1541855515926234, 1.1549026689345163, 1.1556114244588016, 1.1563120158759435, 1.1570046339089817, 1.1576894626202783, 1.1583666797193426, 1.1590364568530334, 1.1596989598793381, 1.1603543491258341, 1.16100277963385, 1.1616444013892673, 1.1622793595408327, 1.1629077946067832, 1.1635298426705283, 1.1641456355660798, 1.1647553010538674, 1.1653589629875307, 1.165956741472244, 1.1665487530150793, 1.167135110667888, 1.1677159241631434], [0.0, 0.9291511993099916, 0.961917645590783, 0.9816178667706019, 0.995839598104219, 1.0070125708444722, 1.0162345460836026, 1.024097471347184, 1.0309578056895923, 1.0370471857312766, 1.0425247924626122, 1.047504810469195, 1.0520719799562177, 1.0562909512692615, 1.0602121906803899, 1.0638758603956104, 1.0673144541909094, 1.0705546393421224, 1.073618575756005, 1.076524881037058, 1.0792893498715541, 1.0819254992465468, 1.0844449878338678, 1.0868579428992127, 1.089173218205021, 1.0913985997024676, 1.0935409712201083, 1.0956064491483946, 1.097600492840434, 1.0995279958074886, 1.1013933615891416, 1.1032005672924543, 1.1049532171327532, 1.1066545878090843, 1.108307667166556, 1.1099151873048239, 1.1114796530647286, 1.1130033666473997, 1.1144884489801778, 1.1159368583326679, 1.1173504065975843, 1.1187307735798102, 1.1200795195795208, 1.121398096508431, 1.1226878577399926, 1.1239500668629745, 1.1251859054819495, 1.126396480186754, 1.127582828795089, 1.1287459259575199, 1.129886688201561, 1.1310059784809932, 1.1321046102876113, 1.1331833513750318, 1.1342429271377346, 1.1352840236830037, 1.13630729062871, 1.137313343655832, 1.138302766841102, 1.139276114792161, 1.1402339146049814, 1.1411766676610435, 1.1421048512797873, 1.1430189202401146, 1.1439193081832248, 1.1448064289077367, 1.1456806775668826, 1.1465424317765454, 1.147392052641999, 1.1482298857104187, 1.1490562618555167, 1.1498714981000402, 1.150675898381297, 1.1514697542643937, 1.152253345607417, 1.1530269411824001, 1.1537907992555587, 1.1545451681299663, 1.1552902866535553, 1.1560263846950716, 1.1567536835903804, 1.1574723965613205, 1.1581827291091076, 1.158884879384124, 1.1595790385337794, 1.1602653910299856, 1.1609441149776665, 1.161615382405605, 1.1622793595408327, 1.1629362070676654, 1.163586080372408, 1.1642291297746699, 1.164865500746162, 1.1654953341177827, 1.1661187662757355, 1.166735929347371, 1.1673469513773929, 1.1679519564950231, 1.168551065072677, 1.1691443938766615, 1.1697320562103752, 1.1703141620504534], [0.0, 0.9311305203805873, 0.9639667672681909, 0.9837089547748096, 0.9979609819015224, 1.0091577558276132, 1.0183993761470242, 1.0262790513794615, 1.033153999924946, 1.0392563518470221, 1.0447456272308093, 1.0497362539032151, 1.0543131525869556, 1.0585411113487828, 1.0624707039663592, 1.0661421782010903, 1.0695880970487137, 1.0728351845929358, 1.0759056479465752, 1.0788181443742193, 1.0815885022087162, 1.0842302672316324, 1.0867551229506447, 1.089173218205021, 1.0914934256178972, 1.0937235477264424, 1.095870483023465, 1.097940360928835, 1.0999386524254278, 1.101870261448891, 1.103739600919432, 1.1055506564163307, 1.1073070398327804, 1.109012034848004, 1.110668635671956, 1.112279580224338, 1.1138473786819192, 1.1153743381500842, 1.1168625840742725, 1.1183140788956856, 1.119730638366816, 1.1211139458709451, 1.1224655650320725, 1.1237869508548424, 1.125079459595726, 1.1263443575352476, 1.1275828287950893, 1.1287959823223959, 1.1299848581456766, 1.131150432991742, 1.1322936253405367, 1.1334152999841454, 1.134516272147301, 1.1355973112191244, 1.1366591441393648, 1.1377024584768836, 1.1387279052333976, 1.1397361014014382, 1.1407276323019648, 1.1417030537240693, 1.1426628938865682, 1.1436076552390082, 1.1445378161176376, 1.145453832270149, 1.1463561382615046, 1.1472451487718163, 1.14812125979609, 1.1489848497546233, 1.1498362805219338, 1.1506758983812972, 1.1515040349112686, 1.1523210078099315, 1.1531271216620549, 1.1539226686538513, 1.1547079292395739, 1.1554831727638066, 1.1562486580429356, 1.1570046339089817, 1.157751339718682, 1.1584890058304593, 1.1592178540516787, 1.1599380980583944, 1.1606499437895903, 1.1613535898177576, 1.1620492276974972, 1.1627370422936916, 1.1634172120906723, 1.1640899094836854, 1.1647553010538676, 1.1654135478278314, 1.1660648055228933, 1.1667092247788797, 1.167346951377393, 1.1679781264493359, 1.168602886671448, 1.1692213644525435, 1.1698336881100935, 1.1704399820377451, 1.171040366864337, 1.171634959604917, 1.1722238738042479, 1.172807219673242], [0.0, 0.9330329915368074, 0.9659363289248456, 0.9857188533568146, 0.9999999999999999, 1.0112196509975333, 1.0204801536494528, 1.0283759285097314, 1.0352649238413774, 1.0413797439924106, 1.0468802349768656, 1.0518810584187765, 1.0564673085495377, 1.060703905809855, 1.064641527308933, 1.068320503041767, 1.0717734625362931, 1.0750271844784427, 1.078103921354256, 1.081022368548549, 1.0837983867343681, 1.0864455493698078, 1.0889755638341023, 1.0913985997024676, 1.0937235477264424, 1.0959582263852172, 1.0981095482664913, 1.1001836553136688, 1.1021860296878505, 1.1041215853443278, 1.105994744219717, 1.1078095000365706, 1.1095694720678448, 1.1112779507019241, 1.1129379362664855, 1.1145521722753047, 1.1161231740339044, 1.1176532533615107, 1.119144540046239, 1.1205990005389201, 1.1220184543019633, 1.1234045881581123, 1.1247589689261377, 1.126083054583527, 1.1273782041578329, 1.128645686516824, 1.129886688201561, 1.1311023204249724, 1.1322936253405367, 1.1334615816706974, 1.1346071097720232, 1.1357310762035278, 1.1368342978555985, 1.1379175456893602, 1.1389815481298335, 1.1400269941507097, 1.1410545360838225, 1.142064792182332, 1.1430583489631165, 1.1440357633508473, 1.144997564643589, 1.145944256317486, 1.146876317686115, 1.147794205428345, 1.1486983549970349, 1.149589181919564, 1.1504670830000294, 1.1513324374319112, 1.1521856078291028, 1.1530269411824003, 1.1538567697478352, 1.1546754118726066, 1.1554831727638066, 1.1562803452046373, 1.1570672102223722, 1.1578440377119155, 1.158611087018463, 1.1593686074824452, 1.1601168389496488, 1.1608560122491618, 1.1615863496415424, 1.162308065239424, 1.163021365402562, 1.1637264491091681, 1.1644235083052243, 1.165112728233326, 1.165794287742481, 1.1664683595801708, 1.167135110667888, 1.1677947023612523, 1.1684472906957388, 1.1690930266189599, 1.1697320562103755, 1.170364520889245, 1.1709905576115642, 1.1716102990566828, 1.1722238738042476, 1.1728314065020657, 1.173433018025442, 1.1740288256285076, 1.174618943088019, 1.1752034808400686], [0.0, 0.9348644977405286, 0.967832423055356, 0.9876537797864517, 1.0019629597456188, 1.0132046344664203, 1.0224833151122696, 1.0303945890607595, 1.0372971072129293, 1.0434239305097706, 1.0489352187366092, 1.0539458585936317, 1.058541111348783, 1.0627860248789804, 1.0667313757705545, 1.0704175731846572, 1.0738773106996746, 1.0771374195670198, 1.0802201959534685, 1.0831443719421234, 1.0859258393398945, 1.0885781982490277, 1.0911131790298714, 1.0935409712201083, 1.095870483023465, 1.0981095482664913, 1.1002650931060183, 1.1023432715418373, 1.1043495764963112, 1.1062889315706277, 1.1081657673814864, 1.1099840854909566, 1.1117475122764817, 1.113459344585346, 1.1151225886347487, 1.1167399933238733, 1.1183140788956853, 1.1198471617074193, 1.121341375727879, 1.1227986912679588, 1.1242209313615996, 1.1256097861427101, 1.1269668255056635, 1.128293510289898, 1.1295912021906829, 1.130861172566523, 1.1321046102876113, 1.1333226287481426, 1.134516272147301, 1.1356865211287226, 1.1368342978555985, 1.1379604705879638, 1.139065857819728, 1.140151232025382, 1.141217323059815, 1.1422648212491464, 1.143294380205711, 1.1443066193962745, 1.1453021264890246, 1.1462814595018533, 1.147245148771816, 1.1481936987633605, 1.1491275897309363, 1.1500472792498555, 1.1509532036277528, 1.1518457792076713, 1.1527254035726182, 1.1535924566604154, 1.1544473017967527, 1.1552902866535555, 1.15612174413906, 1.1569419932253686, 1.157751339718682, 1.1585500769769244, 1.1593384865790144, 1.1601168389496488, 1.160885393943108, 1.1616444013892675, 1.1623941016047217, 1.1631347258716664, 1.163866496886949, 1.1645896291834972, 1.165304329526142, 1.1660107972836815, 1.1667092247788797, 1.1673997976179562, 1.168082695000992, 1.1687580900145649, 1.1694261499078273, 1.1700870363531344, 1.170740905692252, 1.1713879091690966, 1.1720281931498764, 1.1726618993314513, 1.1732891649386556, 1.1739101229112836, 1.174524902081379, 1.175133627341427, 1.175736419804006, 1.1763333969534127, 1.176924672789742, 1.177510357965869], [0.0, 0.9366302678733724, 0.9696604629374559, 0.9895192582062144, 1.00385546531494, 1.01511837328774, 1.024414579486433, 1.03234079623282, 1.0392563518470221, 1.0453947474750545, 1.0509164454117152, 1.0559365493549526, 1.0605404816140187, 1.0647934129281265, 1.0687462157903174, 1.0724393756864838, 1.0759056479465752, 1.079171914500817, 1.0822605136289385, 1.0851902127951623, 1.0879769338228107, 1.0906343025019742, 1.0931740713492821, 1.0956064491483946, 1.097940360928835, 1.1001836553136688, 1.1023432715418373, 1.1044253752367947, 1.1064354696959235, 1.1083784878200995, 1.1102588685945622, 1.1120806211395229, 1.113847378681919, 1.1155624442961132, 1.117228829877442, 1.1188492895172033, 1.120426348218593, 1.121962326713976, 1.123459363002792, 1.1249194311174546, 1.1263443575352474, 1.1277358355824005, 1.1290954381185003, 1.1304246287422157, 1.131724771720783, 1.1329971408140465, 1.1342429271377348, 1.135463246189019, 1.136659144139365, 1.137831603484646, 1.1389815481298335, 1.14010984797493, 1.141217323059815, 1.1423047473180274, 1.1433728519830049, 1.1444223286847532, 1.1454538322701489, 1.1464679833760052, 1.1474653707804965, 1.1484465535554975, 1.1494120630397633, 1.150362404650573, 1.15129805954948, 1.1522194861760633, 1.1531271216620547, 1.1540213831368855, 1.1549026689345165, 1.1557713597103956, 1.156627819476461, 1.1574723965613207, 1.1583054245020068, 1.1591272228730958, 1.1599380980583944, 1.1607383439699208, 1.1615282427184392, 1.162308065239424, 1.1630780718779679, 1.1638385129358242, 1.1645896291834972, 1.1653316523400281, 1.1660648055228933, 1.1667893036702297, 1.167505353937406, 1.168213156069787, 1.168912902753396, 1.1696047799450249, 1.1702889671832273, 1.1709656378815072, 1.1716349596049167, 1.1722970943311768, 1.1729521986973521, 1.1736004242330276, 1.174241917580868, 1.1748768207053701, 1.175505271090558, 1.1761274019273225, 1.1767433422910447, 1.177353217310107, 1.1779571483258444, 1.1785552530444583, 1.1791476456813663, 1.1797344370984446], [0.0, 0.9383349691179459, 0.9714252803415915, 0.9913202193419499, 1.0056825188704264, 1.016965925746473, 1.0262790513794615, 1.0342196941293804, 1.0411478363069968, 1.0472974040389273, 1.0528291516671981, 1.0578583923826856, 1.0624707039663592, 1.0667313757705545, 1.0706913728781058, 1.0743912544599654, 1.077863835461978, 1.081136046740463, 1.0842302672316326, 1.0871652985571791, 1.089957091518724, 1.0926192967057926, 1.0951636880250228, 1.097600492840434, 1.0999386524254278, 1.1021860296878505, 1.1043495764963112, 1.1064354696959235, 1.1084492226002722, 1.1103957770882922, 1.1122795802243381, 1.1141046484253663, 1.1158746215309197, 1.1175928086270768, 1.1192622270909334, 1.120885636026334, 1.1224655650320725, 1.124004339064331, 1.1255041000137866, 1.1269668255056637, 1.128394345341501, 1.1297883559294444, 1.131150432991742, 1.1324820427908655, 1.1337845520770673, 1.1350592369284813, 1.1363072906287102, 1.1375298307051704, 1.1387279052333978, 1.1399024984974446, 1.1410545360838227, 1.142184889475784, 1.143294380205711, 1.1443837836157293, 1.1454538322701489, 1.1465052190577667, 1.1475386000173047, 1.1485545969151578, 1.149553799601098, 1.1505367681645313, 1.1515040349112686, 1.152456106178467, 1.1533934640034116, 1.1543165676600577, 1.1552258550757335, 1.1561217441390603, 1.1570046339089817, 1.1578749057337523, 1.1587329242878255, 1.1595790385337796, 1.1604135826156967, 1.1612368766897903, 1.1620492276974972, 1.162850930085766, 1.1636422664788126, 1.1644235083052243, 1.1651949163839308, 1.1659567414722443, 1.1667092247788797, 1.1674525984446156, 1.1681870859930101, 1.168912902753396, 1.1696302562581715, 1.1703393466162455, 1.171040366864337, 1.1717335032976859, 1.172418935781613, 1.1730968380452407, 1.1737673779585955, 1.1744307177942042, 1.175087014474216, 1.1757364198040061, 1.1763790806931336, 1.1770151393644759, 1.1776447335522833, 1.1782679966898584, 1.1788850580875048, 1.1794960431013426, 1.180101073293553, 1.1807002665845665, 1.181293737397677, 1.1818815967965333], [0.0, 0.939982784920566, 0.9731312062429956, 0.9930610828679294, 1.0074486041188226, 1.018751825854988, 1.0280813063251029, 1.036035893686527, 1.042976202417175, 1.049136569442771, 1.0546780314070283, 1.0597161040030263, 1.0643365152954014, 1.0686046692915216, 1.0725716205743159, 1.0762779995409466, 1.079756678763786, 1.0830346363925951, 1.0861342906633744, 1.0890744762154592, 1.0918711718617713, 1.0945380521637205, 1.0970869117041742, 1.0995279958074886, 1.101870261448891, 1.1041215853443278, 1.1062889315706277, 1.1083784878200995, 1.1103957770882922, 1.1123457499326046, 1.1142328612269083, 1.116061134441414, 1.1178342158076093, 1.1195554202226794, 1.121227770362554, 1.1228540301763574, 1.1244367337051269, 1.1259782099879148, 1.1274806046767853, 1.128945898869883, 1.130375925582072, 1.1317723842005711, 1.1331368532147637, 1.1344708014620344, 1.135775598092794, 1.1370525214261047, 1.138302766841102, 1.1395274538276996, 1.1407276323019648, 1.1419042882764572, 1.1430583489631165, 1.1441906873756122, 1.1453021264890246, 1.1463934430070626, 1.1474653707804965, 1.1485186039149098, 1.1495537996010978, 1.1505715806973438, 1.1515725380892579, 1.1525572328498228, 1.1535261982196352, 1.1544799414250337, 1.1554189453498118, 1.1563436700744594, 1.1572545542953507, 1.1581520166349641, 1.1590364568530336, 1.1599082569675008, 1.1607677822932267, 1.1616153824056052, 1.1624513920355104, 1.1632761319013842, 1.1640899094836854, 1.1648930197464422, 1.1656857458101892, 1.1664683595801708, 1.1672411223333423, 1.1680042852673727, 1.1687580900145647, 1.1695027691233608, 1.1702385465098506, 1.1709656378815072, 1.1716842511351784, 1.1723945867311856, 1.1730968380452405, 1.1737911916997374, 1.1744778278758594, 1.175156920607816, 1.1758286380604313, 1.1764931427911995, 1.1771505919978422, 1.1778011377523205, 1.1784449272221829, 1.1790821028800647, 1.1797128027020922, 1.1803371603558914, 1.1809553053788484, 1.1815673633472217, 1.1821734560366688, 1.1827737015747009, 1.1833682145855515, 1.1839571063279088], [0.0, 0.9415774798524089, 0.9747821379701603, 0.9947458259305312, 1.009157755827613, 1.0204801536494528, 1.0298254617234996, 1.0377935441620185, 1.0447456272308093, 1.0509164454117152, 1.056467308549538, 1.061513928311467, 1.0661421782010903, 1.0704175731846572, 1.0743912544599652, 1.0781039213542563, 1.0815885022087162, 1.0848720209419427, 1.0879769338228107, 1.0909221074439046, 1.0937235477264426, 1.0963949524309335, 1.0989481361499323, 1.1013933615891416, 1.103739600919432, 1.105994744219717, 1.1081657673814864, 1.1102588685945622, 1.1122795802243381, 1.1142328612269083, 1.1161231740339046, 1.1179545489414158, 1.119730638366816, 1.1214547628310627, 1.1231299501381016, 1.1247589689261377, 1.1263443575352474, 1.1278884489557328, 1.129393392479789, 1.130861172566523, 1.1322936253405367, 1.1336924530720844, 1.135059236928481, 1.1363954482390157, 1.1377024584768833, 1.1389815481298338, 1.1402339146049814, 1.1414606792914708, 1.1426628938865682, 1.143841546075618, 1.1449975646435893, 1.1461318240852318, 1.147245148771816, 1.1483383167247403, 1.1494120630397633, 1.1504670830000296, 1.1515040349112686, 1.1525235426884515, 1.1535261982196352, 1.1545125635296714, 1.1554831727638069, 1.1564385340088972, 1.1573791309679564, 1.158305424502007, 1.1592178540516787, 1.160116838949649, 1.1610027796338502, 1.1618760587703234, 1.1627370422936918, 1.1635860803724085, 1.1644235083052243, 1.1652496473546847, 1.1660648055228933, 1.1668692782742895, 1.1676633492097264, 1.168447290695739, 1.1692213644525435, 1.1699858221039692, 1.1707409056922522, 1.1714868481603562, 1.172223873804248, 1.1729521986973521, 1.1736720310892161, 1.1743835717802453, 1.1750870144742163, 1.175782546110131, 1.1764703471748528, 1.1771505919978424, 1.1778234490292188, 1.1784890811022566, 1.1791476456813665, 1.1797992950965015, 1.180444176764882, 1.1810824334008503, 1.1817142032146115, 1.1823396201005607, 1.1829588138158458, 1.1835719101497677, 1.1841790310845781, 1.184780294948193, 1.185375816559308, 1.185965707365363], [0.0, 0.9431224539289232, 0.9763815954398198, 0.9963780405349251, 1.0108136180431275, 1.0221545940611254, 1.0315152362516102, 1.0394963930053824, 1.0464598833012457, 1.0526408267817946, 1.0582007979748052, 1.0632556984113182, 1.0678915424992437, 1.0721739527041365, 1.076154154138104, 1.0798729129093028, 1.083363211388921, 1.0866521178373714, 1.0897621253705791, 1.09271213153811, 1.0955181685242716, 1.098193956565349, 1.1007513296397038, 1.1032005672924543, 1.1055506564163307, 1.1078095000365706, 1.1099840854909566, 1.1120806211395229, 1.1141046484253663, 1.116061134441414, 1.1179545489414158, 1.1197889288345144, 1.1215679325311014, 1.1232948860005645, 1.124972822014978, 1.1266045137554281, 1.1281925037269904, 1.1297391287480212, 1.131246541637351, 1.1327167301102588, 1.1341515333041254, 1.1355526562823512, 1.136921682806687, 1.1382600866206318, 1.139569241447743, 1.1408504298768405, 1.1421048512797873, 1.1433336288857434, 1.1445378161176376, 1.1457184022814437, 1.1468763176861148, 1.148012438261303, 1.149127589730936, 1.1502225513930182, 1.1512980595494797, 1.1523548106243104, 1.1533934640034111, 1.1544146446254957, 1.1554189453498118, 1.1564069291234014, 1.1573791309679562, 1.1583360598040193, 1.1592782001282813, 1.1602060135579624, 1.1611199402547419, 1.162020400239354, 1.1629077946067832, 1.163782506650963, 1.1646449029069557, 1.1654953341177827, 1.1663341361323654, 1.1671616307403883, 1.1679781264493356, 1.1687839192084561, 1.1695792930839444, 1.170364520889245, 1.1711398647740137, 1.171905576774953, 1.172661899331451, 1.1734090657686924, 1.1741473007506769, 1.17487682070537, 1.1755978342240223, 1.1763105424365201, 1.1770151393644757, 1.1777118122536276, 1.1784007418869882, 1.1790821028800644, 1.179756063959374, 1.1804227882253748, 1.1810824334008498, 1.1817351520657013, 1.1823810918790367, 1.1830203957893695, 1.1836532022336848, 1.1842796453260764, 1.1848998550366023, 1.1855139573609634, 1.1861220744815637, 1.1867243249204762, 1.187320823684795, 1.1879116824048275], [0.0, 0.9446207883816671, 0.9779327685429285, 0.9979609819015223, 1.0124194931475823, 1.0237784865237978, 1.033153999924946, 1.0411478363069966, 1.0481223894689577, 1.0543131525869553, 1.0598819568815, 1.0649448880158803, 1.0695880970487135, 1.0738773106996744, 1.0778638354619778, 1.081588502208716, 1.0850843457100232, 1.0883784772295373, 1.091493425617897, 1.0944481184471209, 1.0972586133717765, 1.0999386524254275, 1.1025000883870246, 1.1049532171327532, 1.1073070398327804, 1.1095694720678448, 1.1117475122764817, 1.113847378681919, 1.1158746215309197, 1.1178342158076093, 1.119730638366816, 1.1215679325311014, 1.123349762522958, 1.125079459595726, 1.1267600613396316, 1.1283943453415008, 1.1299848581456764, 1.1315339402830071, 1.1330437479924975, 1.1345162721473008, 1.1359533548066274, 1.1373567037427044, 1.1387279052333976, 1.1400684353635357, 1.1413796700391048, 1.142662893886568, 1.1439193081832248, 1.1451500379427046, 1.1463561382615046, 1.1475386000173045, 1.1486983549970349, 1.1498362805219338, 1.1509532036277526, 1.152049904850563, 1.1531271216620547, 1.1541855515926234, 1.1552258550757333, 1.1562486580429354, 1.1572545542953507, 1.1582441076743721, 1.1592178540516787, 1.1601763031563324, 1.161119940254742, 1.162049227697497, 1.1629646063455596, 1.163866496886949, 1.1647553010538674, 1.165631402749186, 1.1664951690902792, 1.167346951377393, 1.16818708599301, 1.1690158952380403, 1.1698336881100933, 1.1706407610285905, 1.1714373985110211, 1.1722238738042476, 1.1730004494744017, 1.1737673779585953, 1.1745249020813788, 1.1752732555386198, 1.1760126633512407, 1.1767433422910447, 1.1774655012806712, 1.1781793417695399, 1.1788850580875048, 1.1795828377777806, 1.1802728619105893, 1.1809553053788484, 1.1816303371771304, 1.1822981206650107, 1.1829588138158458, 1.1836125694519402, 1.1842595354669876, 1.1848998550366026, 1.1855336668177048, 1.186161105137454, 1.186782300172392, 1.1873973781183875, 1.1880064613519556, 1.188609668583465, 1.1892071150027208, 1.189798912417377], [0.0, 0.9460752844496325, 0.9794385573039583, 0.9994976094477416, 1.013978383434591, 1.0253548670157702, 1.0347448165245552, 1.042750961553344, 1.049736253903215, 1.0559365493549528, 1.061513928311467, 1.0665846551809377, 1.0712350136745536, 1.0755308317158334, 1.0795234947980459, 1.08325389666432, 1.086755122950645, 1.090054326665691, 1.0931740713492821, 1.0961333137174905, 1.0989481361499325, 1.1016323018397038, 1.1041976818162753, 1.1066545878090843, 1.109012034848004, 1.1112779507019241, 1.113459344585346, 1.1155624442961132, 1.1175928086270768, 1.1195554202226794, 1.1214547628310627, 1.1232948860005645, 1.125079459595726, 1.1268118199992423, 1.1284950094785209, 1.1301318098972253, 1.131724771720783, 1.133276239083916, 1.1347883715457345, 1.1362631630448727, 1.1377024584768833, 1.1391079682435652, 1.1404812810652825, 1.1418238752996912, 1.143137128971352, 1.1444223286847535, 1.1456806775668826, 1.1469133023636282, 1.14812125979609, 1.1493055422676686, 1.1504670830000296, 1.1516067606652813, 1.1527254035726182, 1.153823793459955, 1.1549026689345165, 1.1559627286007326, 1.1570046339089817, 1.1580290117546033, 1.1590364568530336, 1.1600275339138504, 1.16100277963385, 1.1619627045269592, 1.1629077946067832, 1.1638385129358242, 1.1647553010538674, 1.1656585802966937, 1.1665487530150793, 1.1674262037030168, 1.1682913000431552, 1.1691443938766617, 1.1699858221039692, 1.1708159075222564, 1.171634959604917, 1.1724432752277891, 1.1732411393464532, 1.1740288256285079, 1.1748065970443755, 1.1755747064198625, 1.1763333969534127, 1.1770829027007308, 1.1778234490292188, 1.1785552530444583, 1.1792785239907808, 1.1799934636277913, 1.1807002665845665, 1.1813991206930938, 1.1820902073024013, 1.1827737015747009, 1.1834497727647775, 1.1841185844837419, 1.184780294948193, 1.1854350572157462, 1.1860830194078167, 1.1867243249204764, 1.1873591126241443, 1.187987517052813, 1.1886096685834653, 1.1892256936062824, 1.1898357146862109, 1.1904398507164056, 1.1910382170640372, 1.1916309257089173], [0.0, 0.9474884964315516, 0.9809016060987916, 1.0009906217066897, 1.0154930265337503, 1.026886503881888, 1.0362904797471093, 1.044308584056803, 1.051304310775913, 1.0575138679977951, 1.063099578235021, 1.068177879567208, 1.0728351845929358, 1.0771374195670198, 1.0811360467404627, 1.0848720209419427, 1.0883784772295375, 1.0916826091720702, 1.094807014013938, 1.0977706767880493, 1.1005897038972796, 1.1032778790936693, 1.1058470911391898, 1.108307667166556, 1.110668635671956, 1.1129379362664855, 1.1151225886347487, 1.117228829877442, 1.1192622270909334, 1.121227770362554, 1.1231299501381016, 1.124972822014978, 1.1267600613396316, 1.1284950094785209, 1.1301807132434796, 1.131819958653615, 1.1334152999841454, 1.1349690848713732, 1.1364834761002773, 1.1379604705879638, 1.1394019159858213, 1.1408095252505828, 1.142184889475784, 1.1435294892273964, 1.144844704588422, 1.146131824085232, 1.1473920526419992, 1.148626518687703, 1.149836280521934, 1.1510223320305084, 1.1521856078291028, 1.153326987902354, 1.1544473017967527, 1.1555473324179457, 1.1566278194764612, 1.1576894626202783, 1.1587329242878255, 1.159758832310875, 1.160767782293227, 1.1617603397880012, 1.1627370422936918, 1.1636984010868117, 1.1646449029069559, 1.1655770115083313, 1.1664951690902794, 1.1673997976179564, 1.1682913000431554, 1.1691700614342113, 1.1700364500230043, 1.1708908181762683, 1.1717335032976859, 1.1725648286666182, 1.1733851042187384, 1.1741946272733468, 1.17499368321168, 1.175782546110131, 1.1765614793319374, 1.1773307360805678, 1.1780905599177465, 1.1788411852488017, 1.179582837777781, 1.1803157349345705, 1.1810400862760626, 1.1817560938632437, 1.1824639526159197, 1.183163850646655, 1.1838559695753699, 1.1845404848259267, 1.1852175659059372, 1.1858873766709082, 1.1865500755737766, 1.1872058159007899, 1.1878547459946212, 1.1884970094655423, 1.1891327453914113, 1.1897620885071831, 1.1903851693845926, 1.1910021146026182, 1.191613046909289, 1.1922180853753581, 1.1928173455403275, 1.1934109395512797], [0.0, 0.9488627599902302, 0.9823243329572049, 1.0024424862297645, 1.0169659257464725, 1.0283759285097314, 1.0377935441620183, 1.0458232781522874, 1.052829151667198, 1.0590477154028666, 1.064641527308933, 1.0697271943500306, 1.0743912544599652, 1.0786997295148186, 1.0827041564078677, 1.086445549369808, 1.0899570915187238, 1.0932660158657435, 1.0963949524309335, 1.0993629137836196, 1.1021860296878503, 1.1048781038880018, 1.107451042389835, 1.1099151873048239, 1.112279580224338, 1.1145521722753047, 1.1167399933238733, 1.1188492895172033, 1.120885636026334, 1.1228540301763574, 1.1247589689261377, 1.1266045137554281, 1.1283943453415008, 1.1301318098972253, 1.131819958653615, 1.1334615816706974, 1.135059236928481, 1.1366152754683456, 1.138131863212234, 1.139610999973635, 1.1410545360838225, 1.1424641869840495, 1.1438415460756177, 1.1451880960719523, 1.1465052190577665, 1.147794205428345, 1.1490562618555167, 1.1502925184049653, 1.1515040349112684, 1.152691806701802, 1.1538567697478352, 1.1549998053103583, 1.1561217441390599, 1.1572233702751342, 1.1583054245020068, 1.159368607482445, 1.1604135826156965, 1.1614409786441582, 1.1624513920355104, 1.1634453891631669, 1.1644235083052243, 1.1653862614797652, 1.1663341361323656, 1.167267596689874, 1.16818708599301, 1.1690930266189596, 1.169985822103969, 1.1708658580748865, 1.1717335032976857, 1.1725891106501836, 1.1734330180254418, 1.174265549171715, 1.175087014474216, 1.175897711683485, 1.1766979265946833, 1.1774879336817319, 1.1782679966898584, 1.1790383691897837, 1.179799295096501, 1.1805510091553273, 1.1812937373976768, 1.1820276975688024, 1.1827530995295432, 1.1834701456339607, 1.184179031084578, 1.1848799442668028, 1.1855730670639817, 1.1862585751544177, 1.1869366382915805, 1.1876074205686373, 1.1882710806683499, 1.1889277720992961, 1.1895776434193093, 1.1902208384469581, 1.1908574964618226, 1.191487752394281, 1.1921117370054533, 1.192729577057911, 1.1933413954777208, 1.1939473115083394, 1.1945474408568504, 1.1951418958329976], [0.0, 0.9502002165056764, 0.9837089547748096, 1.00385546531494, 1.0183993761470242, 1.0298254617234994, 1.0392563518470221, 1.0472974040389271, 1.0543131525869553, 1.0605404816140187, 1.06614217820109, 1.0712350136745536, 1.0759056479465752, 1.0802201959534683, 1.0842302672316324, 1.0879769338228107, 1.091493425617897, 1.0948070140139379, 1.097940360928835, 1.1009125057308207, 1.1037396009194318, 1.1064354696959233, 1.1090120348480037, 1.1114796530647286, 1.1138473786819192, 1.1161231740339044, 1.1183140788956853, 1.120426348218593, 1.1224655650320725, 1.1244367337051269, 1.1263443575352474, 1.1281925037269904, 1.1299848581456764, 1.131724771720783, 1.1334152999841454, 1.135059236928481, 1.1366591441393648, 1.1382173759720546, 1.1397361014014382, 1.1412173230598153, 1.142662893886568, 1.1440745317409262, 1.1454538322701489, 1.1468022802775995, 1.1481212597960895, 1.1494120630397635, 1.150675898381297, 1.1519138974792433, 1.1531271216620549, 1.1543165676600577, 1.1554831727638066, 1.156627819476461, 1.1577513397186818, 1.1588545186367973, 1.1599380980583944, 1.16100277963385, 1.162049227697497, 1.1630780718779679, 1.1640899094836854, 1.1650853076863874, 1.1660648055228933, 1.1670289157329934, 1.1679781264493359, 1.168912902753396, 1.1698336881100933, 1.170740905692252, 1.171634959604917, 1.1725162360184913, 1.1733851042187382, 1.1742419175808683, 1.175087014474216, 1.175920719103371, 1.176743342291045, 1.1775551822074684, 1.1783565250506416, 1.1791476456813663, 1.1799288082166284, 1.1807002665845663, 1.18146226504398, 1.1822150386710686, 1.1829588138158458, 1.1836938085304842, 1.1844202329716296, 1.1851382897785687, 1.1858481744289697, 1.1865500755737766, 1.187244175352707, 1.1879306496916886, 1.188609668583465, 1.189281396352499, 1.189945991905221, 1.190603608966585, 1.1912543963038222, 1.1918984979382181, 1.192536053345673, 1.1931671976467542, 1.193792061786894, 1.1944107727073408, 1.1950234535074298, 1.1956302235986958, 1.1962311988513155, 1.1968264917333373], [0.0, 0.9515028341218914, 0.9850575091020548, 1.005231638242012, 1.0197954871399157, 1.031237236594485, 1.0406810554075596, 1.0487331309775447, 1.0557584973276852, 1.0619943633223812, 1.067603739205382, 1.0727035563834264, 1.0773805935696716, 1.0817010563365723, 1.0857166249713972, 1.0894684278210387, 1.0929897403308333, 1.0963078712838454, 1.099445513664917, 1.102421732943113, 1.1052527037612299, 1.1079522682705765, 1.1105323656036628, 1.1130033666473997, 1.1153743381500842, 1.1176532533615107, 1.1198471617074193, 1.121962326713976, 1.124004339064331, 1.1259782099879148, 1.1278884489557328, 1.1297391287480212, 1.1315339402830071, 1.133276239083916, 1.1349690848713732, 1.1366152754683456, 1.1382173759720546, 1.1397777439653136, 1.1412985513964313, 1.1427818036430908, 1.144229356184846, 1.1456429292359185, 1.14702412063102, 1.1483744172090122, 1.1496952049000606, 1.1509877776897892, 1.152253345607417, 1.1534930418628737, 1.1547079292395739, 1.1558990058342484, 1.1570672102223722, 1.1582134261169175, 1.1593384865790142, 1.1604431778313384, 1.161528242718439, 1.162594383852577, 1.1636422664788124, 1.164672521088928, 1.1656857458101892, 1.1666825085918626, 1.1676633492097261, 1.168628781106479, 1.1695792930839444, 1.1705153508611716, 1.1714373985110211, 1.1723458597864391, 1.173241139346453, 1.1741236238908626, 1.1749936832116799, 1.175851671168553, 1.1766979265946833, 1.1775327741391077, 1.1783565250506416, 1.179169477908273, 1.1799719193023475, 1.1807641244704699, 1.181546357891701, 1.1823188738422858, 1.1830819169158764, 1.183835722510934, 1.1845805172877732, 1.1853165195974913, 1.186043939884836, 1.1867629810668885, 1.187473838889296, 1.188176702261621, 1.1888717535732745, 1.1895591689913587, 1.1902391187416583, 1.190911767373906, 1.1915772740123758, 1.1922357925927605, 1.192887472086235, 1.1935324567115217, 1.1941708861357268, 1.1948028956646521, 1.195428616423242, 1.1960481755267667, 1.196661696243317, 1.1972692981481272, 1.1978710972702191, 1.1984672062318225], [0.0, 0.9527724260125243, 0.9863718730540205, 1.0065729205696652, 1.0211562020365474, 1.032613218237364, 1.0420696379543475, 1.0501324574228053, 1.0571671977315165, 1.0634113842530821, 1.0690282447361044, 1.0741348666091015, 1.0788181443742193, 1.0831443719421232, 1.0871652985571791, 1.0909221074439046, 1.094448118447121, 1.0977706767880493, 1.100912505730821, 1.103892696183589, 1.1067274443710047, 1.1094306109139833, 1.1120141508754398, 1.1144884489801778, 1.1168625840742725, 1.119144540046239, 1.121341375727879, 1.123459363002792, 1.1255041000137866, 1.1274806046767853, 1.129393392479789, 1.131246541637351, 1.1330437479924975, 1.1347883715457345, 1.1364834761002773, 1.138131863212234, 1.1397361014014382, 1.1412985513964313, 1.1428213880435563, 1.1443066193962748, 1.1457561034099104, 1.1471715625939696, 1.1485545969151578, 1.1499066951962287, 1.151229245216596, 1.1525235426884517, 1.1537907992555587, 1.1550321496398905, 1.1562486580429356, 1.1574413238931873, 1.1586110870184632, 1.159758832310875, 1.160885393943108, 1.1619915591868966, 1.1630780718779679, 1.16414563556608, 1.1651949163839308, 1.1662265456645688, 1.1672411223333425, 1.1682392150973335, 1.1692213644525435, 1.1701880845267598, 1.1711398647740139, 1.1720771715347655, 1.1730004494744017, 1.1739101229112836, 1.1748065970443755, 1.1756902590894514, 1.1765614793319374, 1.1774206121036375, 1.1782679966898584, 1.179103958172817, 1.1799288082166286, 1.1807428457986755, 1.1815463578917011, 1.1823396201005607, 1.1831228972572094, 1.1838964439771744, 1.1846605051804684, 1.1854153165796457, 1.1861611051374543, 1.1868980894963377, 1.18762648038184, 1.1883464809817956, 1.1890582873030349, 1.1897620885071831, 1.1904580672270137, 1.191146399864689, 1.1918272568731259, 1.1925008030216167, 1.1931671976467544, 1.1938265948896292, 1.194479143920188, 1.195124989149585, 1.1957642704312839, 1.1963971232516257, 1.1970236789105146, 1.1976440646928315, 1.1982584040311437, 1.198866816660235, 1.1994694187639448, 1.200066323114775], [0.0, 0.954010666295673, 0.9876537797864517, 1.007881080948941, 1.0224833151122694, 1.03395522105863, 1.0434239305097706, 1.0514972285642885, 1.0585411113487828, 1.0647934129281265, 1.0704175731846572, 1.0755308317158336, 1.0802201959534685, 1.084552045964993, 1.0885781982490277, 1.0923398895525533, 1.095870483023465, 1.0991973594213273, 1.1023432715418373, 1.105327335104038, 1.1081657673814864, 1.110872447008612, 1.1134593445853458, 1.1159368583326679, 1.1183140788956856, 1.1205990005389201, 1.1227986912679588, 1.1249194311174546, 1.1269668255056637, 1.128945898869883, 1.130861172566523, 1.1327167301102588, 1.1345162721473008, 1.1362631630448727, 1.1379604705879638, 1.139610999973635, 1.1412173230598153, 1.1427818036430908, 1.1443066193962748, 1.1457937809825312, 1.147245148771816, 1.1486624475122404, 1.1500472792498555, 1.1514011347423156, 1.152725403572618, 1.1540213831368855, 1.1552902866535555, 1.1565332503193062, 1.157751339718682, 1.1589455555790513, 1.160116838949649, 1.1612660758726088, 1.1623941016047217, 1.1635017044408744, 1.1645896291834972, 1.1656585802966937, 1.1667092247788797, 1.167742194783596, 1.1687580900145649, 1.1697574799179702, 1.1707409056922522, 1.1717088821333674, 1.1726618993314513, 1.1736004242330276, 1.1745249020813788, 1.175435757746318, 1.1763333969534129, 1.1772182074216704, 1.1780905599177462, 1.1789508092339407, 1.1797992950965013, 1.180636343010128, 1.1814622650439803, 1.182277360563997, 1.1830819169158766, 1.183876210062655, 1.1846605051804684, 1.1854350572157462, 1.186200111406804, 1.1869559037725324, 1.187702661570644, 1.1884406037277344, 1.18916994124321, 1.1898908775689723, 1.190603608966585, 1.191308324843512, 1.1920052080698789, 1.192694435277104, 1.1933761771396276, 1.1940505986408794, 1.1947178593245287, 1.1953781135319907, 1.1960315106270762, 1.1966781952086183, 1.1973183073118374, 1.1979519825991545, 1.198579352541114, 1.199200544588018, 1.1998156823328494, 1.2004248856660014, 1.201028270922308, 1.201625951020832], [0.0, 0.955219103952324, 0.9889048329050316, 1.009157755827613, 1.0237784865237975, 1.0352649238413776, 1.0447456272308093, 1.052829151667198, 1.0598819568815, 1.06614217820109, 1.0717734625362931, 1.0768931979910255, 1.081588502208716, 1.0859258393398943, 1.0899570915187238, 1.0937235477264424, 1.0972586133717765, 1.1005897038972794, 1.1037396009194318, 1.1067274443710045, 1.109569472067845, 1.1122795802243377, 1.1148697546034765, 1.1173504065975843, 1.119730638366816, 1.1220184543019633, 1.1242209313615996, 1.1263443575352474, 1.128394345341501, 1.130375925582072, 1.1322936253405367, 1.1341515333041254, 1.1359533548066274, 1.1377024584768833, 1.1394019159858213, 1.1410545360838225, 1.142662893886568, 1.144229356184846, 1.1457561034099104, 1.147245148771816, 1.1486983549970349, 1.1501174490184025, 1.1515040349112684, 1.1528596053216185, 1.1541855515926231, 1.1554831727638066, 1.1567536835903802, 1.1579982217082339, 1.1592178540516787, 1.1604135826156967, 1.1615863496415422, 1.1627370422936916, 1.1638664968869488, 1.1649755027147277, 1.166064805522893, 1.167135110667888, 1.16818708599301, 1.1692213644525433, 1.1702385465098504, 1.171239202332428, 1.1722238738042479, 1.1731930763733547, 1.1741473007506769, 1.175087014474216, 1.1760126633512404, 1.176924672789742, 1.1778234490292185, 1.1787093802797972, 1.1795828377777808, 1.180444176764882, 1.1812937373976768, 1.18213184559318, 1.1829588138158458, 1.1837749418108179, 1.1845805172877732, 1.1853758165593078, 1.186161105137454, 1.1869366382915805, 1.1877026615706439, 1.188459411292498, 1.189207115002721, 1.189945991905221, 1.1906762532666757, 1.1913981027966976, 1.1921117370054533, 1.1928173455403273, 1.1935151115030858, 1.1942052117488844, 1.1948878171683555, 1.1955630929539116, 1.1962311988513155, 1.1968922893974845, 1.197546514145428, 1.1981940178771409, 1.1988349408052252, 1.1994694187639448, 1.200097583390376, 1.2007195622962619, 1.201335479231139, 1.2019454542372652, 1.2025496037968348, 1.2031480409719444], [0.0, 0.9563991750420213, 0.9901265191118345, 1.0104044623556425, 1.0250432554016413, 1.0365438829846232, 1.0460362987696024, 1.0541298095363008, 1.061191327737498, 1.0674592828913085, 1.0730975240763216, 1.078223584416907, 1.0829246891810287, 1.0872673846285699, 1.0913036169885242, 1.095074726250252, 1.0986141590912912, 1.1019493648230438, 1.105103153206242, 1.1080946878189977, 1.110940226537244, 1.1136536827426526, 1.1162470570053462, 1.1187307735798102, 1.1211139458709451, 1.1234045881581123, 1.1256097861427101, 1.1277358355824005, 1.1297883559294444, 1.1317723842005711, 1.1336924530720844, 1.1355526562823512, 1.1373567037427044, 1.1391079682435652, 1.1408095252505828, 1.1424641869840495, 1.1440745317409262, 1.1456429292359185, 1.1471715625939696, 1.1486624475122404, 1.1501174490184025, 1.1515382961787317, 1.1529265950502419, 1.154283840122923, 1.1556114244588014, 1.1569106487022258, 1.1581827291091076, 1.1594288047207642, 1.1606499437895903, 1.1618471495484253, 1.163021365402562, 1.1641734796124739, 1.165304329526142, 1.166414705412068, 1.1675053539374058, 1.1685769813299915, 1.1696302562581713, 1.1706658124581768, 1.1716842511351784, 1.1726861431610545, 1.173672031089216, 1.174642431004489, 1.1755978342240223, 1.1765387088634112, 1.177465501280671, 1.17837863740934, 1.1792785239907808, 1.180165549714713, 1.1810400862760624, 1.1819024893554047, 1.1827530995295432, 1.1835922431181278, 1.1844202329716296, 1.1852373692054952, 1.186043939884836, 1.186840221663603, 1.18762648038184, 1.1884029716242734, 1.1891699412432097, 1.1899276258484486, 1.190676253266676, 1.1914160429726026, 1.1921472064939043, 1.1928699477918545, 1.1935844636193873, 1.1942909438581764, 1.1949895718361905, 1.1956805246270708, 1.1963639733325668, 1.197040083349169, 1.1977090146199882, 1.1983709218728564, 1.199025954845539, 1.1996742584988942, 1.2003159732187412, 1.200951235007153, 1.2015801756638291, 1.2022029229581634, 1.202819600792572, 1.2034303293576116, 1.2040352252793782, 1.2046344017596446], [0.0, 0.9575522134601357, 0.9913202193419499, 1.0116226097498822, 1.0262790513794613, 1.0377935441620185, 1.0472974040389273, 1.0554006723724398, 1.0624707039663592, 1.0687462157903174, 1.0743912544599652, 1.0795234947980459, 1.0842302672316324, 1.0885781982490275, 1.0926192967057926, 1.0963949524309335, 1.0999386524254278, 1.1032778790936693, 1.1064354696959233, 1.1094306109139833, 1.112279580224338, 1.114996307782684, 1.1175928086270766, 1.1200795195795208, 1.1224655650320725, 1.1247589689261377, 1.1269668255056635, 1.1290954381185003, 1.131150432991742, 1.1331368532147637, 1.135059236928481, 1.136921682806687, 1.1387279052333976, 1.1404812810652825, 1.142184889475784, 1.1438415460756177, 1.1454538322701489, 1.14702412063102, 1.1485545969151578, 1.1500472792498555, 1.1515040349112684, 1.1529265950502419, 1.1543165676600577, 1.1556754490324683, 1.1570046339089815, 1.158305424502007, 1.1595790385337792, 1.160826616418848, 1.1620492276974972, 1.1632478768120673, 1.1644235083052243, 1.1655770115083313, 1.1667092247788797, 1.1678209393381216, 1.1689129027533958, 1.1699858221039692, 1.1710403668643368, 1.1720771715347653, 1.1730968380452405, 1.1740999379558854, 1.175087014474216, 1.176058584307252, 1.1770151393644757, 1.1779571483258446, 1.1788850580875048, 1.1797992950965013, 1.1807002665845663, 1.181588361710025, 1.1824639526159197, 1.183327395411636, 1.184179031084578, 1.1850191863478077, 1.1858481744289697, 1.1866662958053313, 1.187473838889296, 1.1882710806683499, 1.1890582873030349, 1.1898357146862109, 1.190603608966585, 1.191362207039214, 1.1921117370054535, 1.1928524186046132, 1.1935844636193873, 1.1943080762569462, 1.19502345350743, 1.1957307854814339, 1.196430255727948, 1.1971220415340942, 1.1978063142079027, 1.1984832393452662, 1.1991529770821245, 1.1998156823328494, 1.2004715050157309, 1.2011205902663922, 1.2017630786399027, 1.2023991063022994, 1.2030288052121807, 1.2036523032929796, 1.2042697245964888, 1.204881189458168, 1.2054868146447175, 1.2060867134943867], [0.0, 0.9586794604411084, 0.9924872186018571, 1.012813509333941, 1.027487204779392, 1.0390152526214478, 1.0485303006061206, 1.056643108246876, 1.063721462803927, 1.0700043622686408, 1.0756560463751728, 1.0807943284750972, 1.0855066418023722, 1.0898596912791516, 1.0939055469867183, 1.0976856474788992, 1.1012335191781464, 1.1045766768416148, 1.107737984613986, 1.1107366517639463, 1.1135889749301104, 1.1163089006669948, 1.1189084581569642, 1.121398096508431, 1.1237869508548424, 1.126083054583527, 1.128293510289898, 1.1304246287422157, 1.1324820427908655, 1.1344708014620344, 1.1363954482390157, 1.1382600866206318, 1.1400684353635357, 1.1418238752996912, 1.1435294892273964, 1.1451880960719523, 1.1468022802775995, 1.1483744172090122, 1.1499066951962287, 1.1514011347423156, 1.1528596053216185, 1.154283840122923, 1.1556754490324683, 1.1570359301034678, 1.1583666797193426, 1.1596690016254896, 1.1609441149776665, 1.162193161532939, 1.1634172120906723, 1.1646172722756536, 1.165794287742481, 1.1669491488694534, 1.1680826950009917, 1.169195718289787, 1.1702889671832273, 1.171363149592965, 1.1724189357816128, 1.1734569609963816, 1.1744778278758594, 1.17548210865302, 1.1764703471748525, 1.1774430607566528, 1.1784007418869882, 1.1793438597975536, 1.180272861910589, 1.181188175175161, 1.182090207302401, 1.182979347908759, 1.1838559695753696, 1.184720428830837, 1.185573067063982, 1.1864142113724778, 1.187244175352707, 1.1880632598356633, 1.1888717535732745, 1.189669933879101, 1.1904580672270135, 1.1912364098111137, 1.1920052080698789, 1.192764699177243, 1.193515111503086, 1.194256665045399, 1.1949895718361905, 1.1957140363230268, 1.196430255727948, 1.1971384203853517, 1.197838714060304, 1.1985313142486325, 1.1992163924600345, 1.1998941144853452, 1.2005646406490185, 1.2012281260477944, 1.2018847207764494, 1.202534570141463, 1.2031778148633678, 1.2038145912684985, 1.2044450314707973, 1.2050692635442906, 1.2056874116868073, 1.2062995963754677, 1.2069059345144324, 1.2075065395753741], [0.0, 0.9597820729793508, 0.9936287146872871, 1.0139783834345908, 1.02866895563734, 1.040210262311588, 1.049736253903215, 1.0578583923826852, 1.06494488801588, 1.0712350136745534, 1.0768931979910255, 1.0820373898183429, 1.0867551229506447, 1.0911131790298711, 1.0951636880250226, 1.0989481361499323, 1.1025000883870246, 1.1058470911391896, 1.1090120348480037, 1.1120141508754395, 1.1148697546034765, 1.1175928086270763, 1.1201953559638096, 1.1226878577399926, 1.125079459595726, 1.1273782041578329, 1.1295912021906829, 1.131724771720783, 1.1337845520770673, 1.135775598092794, 1.1377024584768833, 1.139569241447743, 1.1413796700391048, 1.143137128971352, 1.144844704588422, 1.1465052190577665, 1.1481212597960895, 1.1496952049000606, 1.151229245216596, 1.152725403572618, 1.1541855515926231, 1.1556114244588014, 1.1570046339089815, 1.1583666797193426, 1.159698959879338, 1.16100277963385, 1.1622793595408327, 1.1635298426705283, 1.1647553010538674, 1.165956741472244, 1.1671351106678878, 1.1682913000431552, 1.1694261499078273, 1.1705404533256794, 1.1716349596049167, 1.1727103774713865, 1.1737673779585953, 1.1748065970443753, 1.1758286380604313, 1.176834073897883, 1.1778234490292185, 1.1787972813647167, 1.179756063959374, 1.1807002665845663, 1.1816303371771304, 1.1825467031771821, 1.1834497727647775, 1.1843399360044773, 1.185217565905937, 1.1860830194078165, 1.1869366382915805, 1.1877787500311097, 1.188609668583465, 1.1894296951256373, 1.1902391187416583, 1.1910382170640372, 1.1918272568731256, 1.192606494657684, 1.1933761771396274, 1.1941365417656724, 1.1948878171683555, 1.1956302235986955, 1.1963639733325668, 1.1970892710526781, 1.1978063142079025, 1.1985152933515475, 1.1992163924600345, 1.1999097892333355, 1.2005956553784076, 1.2012741568767678, 1.2019454542372652, 1.2026097027350224, 1.2032670526374452, 1.2039176494181356, 1.2045616339594742, 1.2051991427445896, 1.2058303080393726, 1.2064552580651526, 1.2070741171626034, 1.2076870059474099, 1.2082940414581886, 1.2088953372971203], [0.0, 0.9608611313126507, 0.9947458259305312, 1.0151183732877402, 1.0298254617234994, 1.0413797439924108, 1.0509164454117155, 1.0590477154028666, 1.06614217820109, 1.0724393756864838, 1.0781039213542563, 1.08325389666432, 1.0879769338228107, 1.0923398895525533, 1.0963949524309335, 1.100183655313669, 1.103739600919432, 1.1070903666208258, 1.1102588685945622, 1.1132643598239405, 1.1161231740339046, 1.1188492895172035, 1.1214547628310627, 1.1239500668629745, 1.1263443575352476, 1.128645686516824, 1.130861172566523, 1.1329971408140465, 1.1350592369284813, 1.1370525214261047, 1.1389815481298338, 1.1408504298768405, 1.142662893886568, 1.1444223286847535, 1.146131824085232, 1.147794205428345, 1.1494120630397635, 1.1509877776897892, 1.1525235426884517, 1.1540213831368855, 1.1554831727638066, 1.1569106487022258, 1.158305424502007, 1.1596690016254896, 1.16100277963385, 1.1623080652394244, 1.1635860803724083, 1.1648379693881687, 1.1660648055228933, 1.167267596689874, 1.168447290695739, 1.1696047799450249, 1.1707409056922522, 1.1718564618928167, 1.1729521986973521, 1.1740288256285079, 1.175087014474216, 1.1761274019273227, 1.1771505919978424, 1.1781571582209824, 1.1791476456813665, 1.1801225728715472, 1.1810824334008503, 1.1820276975688027, 1.1829588138158458, 1.1838762100626552, 1.1847802949481931, 1.1856714589755601, 1.1865500755737768, 1.1874165020827998, 1.18827108066835, 1.189114139172479, 1.1899459919052213, 1.190766940382173, 1.191577274012376, 1.1923772707404745, 1.1931671976467544, 1.1939473115083397, 1.194717859324529, 1.1954790788089933, 1.1962311988513157, 1.1969744399501372, 1.1977090146199885, 1.1984351277736978, 1.1991529770821248, 1.1998627533128112, 1.2005646406490187, 1.2012588169905025, 1.2019454542372654, 1.2026247185574332, 1.2032967706403113, 1.2039617659355937, 1.2046198548796283, 1.205271183109569, 1.2059158916661874, 1.2065541171860557, 1.2071859920837686, 1.2078116447248113, 1.2084311995896502, 1.2090447774295758, 1.209652495414788, 1.2102544672751876], [0.0, 0.961917645590783, 0.9958395981042191, 1.0162345460836026, 1.0309578056895923, 1.0425247924626122, 1.0520719799562177, 1.0602121906803896, 1.0673144541909094, 1.073618575756005, 1.0792893498715541, 1.0844449878338678, 1.089173218205021, 1.093540971220108, 1.0976004928404337, 1.1013933615891416, 1.1049532171327534, 1.1083076671665557, 1.1114796530647286, 1.1144884489801778, 1.1173504065975843, 1.1200795195795208, 1.1226878577399926, 1.1251859054819495, 1.1275828287950893, 1.129886688201561, 1.1321046102876113, 1.1342429271377348, 1.1363072906287102, 1.138302766841102, 1.1402339146049814, 1.1421048512797873, 1.1439193081832248, 1.1456806775668826, 1.1473920526419992, 1.1490562618555167, 1.150675898381297, 1.152253345607417, 1.1537907992555587, 1.1552902866535555, 1.1567536835903802, 1.1581827291091076, 1.1595790385337792, 1.1609441149776665, 1.1622793595408327, 1.1635860803724083, 1.164865500746162, 1.1661187662757355, 1.167346951377393, 1.168551065072677, 1.1697320562103755, 1.170890818176268, 1.1720281931498762, 1.1731449759595893, 1.174241917580868, 1.1753197283165173, 1.1763790806931333, 1.1774206121036372, 1.1784449272221829, 1.1794526002146073, 1.1804441767648817, 1.181420175935667, 1.1823810918790367, 1.1833273954116357, 1.1842595354669874, 1.1851779404362874, 1.1860830194078165, 1.186975163314053, 1.187854745994621, 1.18872212518239, 1.1895776434193093, 1.1904216289079088, 1.1912543963038222, 1.1920762474541773, 1.1928874720862352, 1.193688348450254, 1.194479143920188, 1.1952601155554998, 1.196031510627076, 1.1967935671099663, 1.197546514145428, 1.198290572474552, 1.199025954845539, 1.1997528663965291, 1.2004715050157309, 1.201182061680444, 1.2018847207764494, 1.2025796603991112, 1.2032670526374452, 1.2039470638422871, 1.204619854879628, 1.205285581370087, 1.2059443939154235, 1.206596438312927, 1.2072418557584503, 1.2078807830388048, 1.208513352714181, 1.209139693291208, 1.2097599293872254, 1.2103741818862954, 1.210982568087452, 1.211585201845648], [0.0, 0.9629525618336756, 0.9969110105895996, 1.0173279012613057, 1.0320670014546725, 1.0436464330170645, 1.053203892220994, 1.0613528609052032, 1.0684627656601704, 1.0747736697578816, 1.0804505449947366, 1.085611729849234, 1.09034504726961, 1.0947174995004365, 1.0987813887138533, 1.1025783381668637, 1.106142023718524, 1.1095000827669252, 1.1126754813686113, 1.1156875144133287, 1.118552551178351, 1.121284600381872, 1.1238957448236733, 1.126396480186754, 1.1287959823223959, 1.1311023204249724, 1.1333226287481426, 1.135463246189019, 1.1375298307051704, 1.1395274538276996, 1.1414606792914708, 1.1433336288857434, 1.1451500379427046, 1.1469133023636282, 1.148626518687703, 1.1502925184049653, 1.1519138974792433, 1.1534930418628737, 1.1550321496398905, 1.1565332503193062, 1.1579982217082339, 1.1594288047207642, 1.160826616418848, 1.162193161532939, 1.1635298426705283, 1.1648379693881687, 1.1661187662757355, 1.1673733801794233, 1.168602886671448, 1.169808295858947, 1.1709905576115642, 1.172150566276263, 1.1732891649386556, 1.1744071492822783, 1.175505271090558, 1.1765842414305063, 1.177644733552283, 1.178687385534573, 1.1797128027020922, 1.1807215598384162, 1.1817142032146115, 1.1826912524517925, 1.183653202233685, 1.1846005238834805, 1.1855336668177048, 1.1864530598884546, 1.1873591126241443, 1.188252216377852, 1.1891327453914113, 1.190001057782573, 1.1908574964618228, 1.1917023899848, 1.1925360533456733, 1.1933587887163235, 1.194170886135727, 1.1949726241535075, 1.1957642704312839, 1.1965460823050862, 1.1973183073118372, 1.1980811836826208, 1.1988349408052255, 1.1995797996582342, 1.2003159732187414, 1.2010436668455928, 1.2017630786399027, 1.2024743997844414, 1.2031778148633678, 1.2038735021636575, 1.2045616339594745, 1.2052423767806293, 1.2059158916661872, 1.2065823344041975, 1.2072418557584506, 1.2078946016830976, 1.208540713525902, 1.2091803282208426, 1.2098135784707305, 1.2104405929204531, 1.2110614963214246, 1.2116764096877646, 1.2122854504447083, 1.2128887325697033], [0.0, 0.9639667672681909, 0.9979609819015225, 1.0183993761470242, 1.033153999924946, 1.0447456272308093, 1.0543131525869556, 1.0624707039663592, 1.0695880970487137, 1.0759056479465752, 1.081588502208716, 1.0867551229506447, 1.091493425617897, 1.095870483023465, 1.0999386524254275, 1.103739600919432, 1.1073070398327804, 1.1106686356719557, 1.113847378681919, 1.1168625840742723, 1.119730638366816, 1.1224655650320723, 1.125079459595726, 1.127582828795089, 1.1299848581456766, 1.1322936253405367, 1.134516272147301, 1.136659144139365, 1.1387279052333978, 1.1407276323019648, 1.1426628938865682, 1.1445378161176376, 1.1463561382615046, 1.14812125979609, 1.149836280521934, 1.1515040349112684, 1.1531271216620549, 1.1547079292395739, 1.1562486580429356, 1.157751339718682, 1.1592178540516787, 1.1606499437895903, 1.1620492276974972, 1.1634172120906723, 1.1647553010538674, 1.1660648055228933, 1.167346951377393, 1.168602886671448, 1.1698336881100935, 1.171040366864337, 1.1722238738042479, 1.1733851042187382, 1.174524902081379, 1.17564406391374, 1.176743342291045, 1.1778234490292188, 1.1788850580875048, 1.1799288082166284, 1.1809553053788484, 1.1819651249631167, 1.182958813815846, 1.183936892105428, 1.1848998550366026, 1.1858481744289697, 1.186782300172392, 1.187702661570644, 1.1886096685834653, 1.1895037129761166, 1.1903851693845926, 1.1912543963038222, 1.1921117370054533, 1.192957520391168, 1.193792061786894, 1.1946156636827683, 1.1954286164232422, 1.1962311988513155, 1.1970236789105146, 1.1978063142079027, 1.198579352541114, 1.1993430323921435, 1.2000975833903762, 1.2008432267471358, 1.2015801756638291, 1.2023086357155912, 1.203028805212181, 1.2037408755377272, 1.2044450314707975, 1.2051414514861436, 1.2058303080393729, 1.2065117678356894, 1.2071859920837686, 1.2078531367357395, 1.208513352714181, 1.2091667861269666, 1.2098135784707305, 1.210453866823674, 1.2110877840283736, 1.2117154588652095, 1.2123370162169864, 1.2129525772252796, 1.2135622594389992, 1.2141661769556367], [0.0, 0.9649610951198176, 0.9989903746491102, 1.0194498510162482, 1.0342196941293802, 1.0458232781522876, 1.05540067237244, 1.0635666382333517, 1.0706913728781056, 1.0770154403043632, 1.0827041564078677, 1.087876106498356, 1.0926192967057926, 1.0970008690285074, 1.101073234730881, 1.104878103888002, 1.108449222600272, 1.1118142859120639, 1.1149963077826843, 1.1180146233472985, 1.1208856360263342, 1.1236233837574692, 1.1262399745428746, 1.1287459259575199, 1.131150432991742, 1.1334615816706974, 1.1356865211287226, 1.137831603484646, 1.1399024984974446, 1.1419042882764572, 1.143841546075618, 1.1457184022814437, 1.1475386000173045, 1.1493055422676686, 1.1510223320305084, 1.152691806701802, 1.1543165676600577, 1.1558990058342484, 1.1574413238931873, 1.1589455555790513, 1.1604135826156967, 1.1618471495484253, 1.1632478768120673, 1.1646172722756536, 1.165956741472244, 1.167267596689874, 1.168551065072677, 1.169808295858947, 1.171040366864337, 1.1722482903028724, 1.173433018025442, 1.1745954462444443, 1.175736419804006, 1.1768567360473052, 1.1779571483258444, 1.1790383691897839, 1.1801010732935528, 1.1811459000467457, 1.1821734560366688, 1.1831843172457852, 1.1841790310845781, 1.1851581182579904, 1.1861220744815637, 1.1870713720615782, 1.1880064613519556, 1.1889277720992961, 1.1898357146862109, 1.190730681282065, 1.1916130469092887, 1.192483170432597, 1.193341395477721, 1.1941880512856033, 1.19502345350743, 1.1958479049453543, 1.1966616962433172, 1.197465106531944, 1.1982584040311437, 1.1990418466136998, 1.1998156823328494, 1.2005801499165802, 1.2013354792311393, 1.202081891716029, 1.202819600792572, 1.2035488122479538, 1.2042697245964888, 1.204982529419718, 1.2056874116868073, 1.2063845500566042, 1.2070741171626034, 1.207756279881965, 1.2084311995896502, 1.209099032398652, 1.2097599293872254, 1.2104140368139538, 1.2110614963214243, 1.2117024451292342, 1.2123370162169864, 1.2129653384978973, 1.213587536983588, 1.2142037329405908, 1.214814044039067, 1.215418584494199], [0.0, 0.9659363289248456, 1.0, 1.0204801536494528, 1.0352649238413774, 1.0468802349768656, 1.056467308549538, 1.064641527308933, 1.0717734625362931, 1.0781039213542563, 1.0837983867343681, 1.0889755638341023, 1.0937235477264424, 1.0981095482664913, 1.1021860296878503, 1.105994744219717, 1.109569472067845, 1.1129379362664853, 1.1161231740339044, 1.119144540046239, 1.1220184543019636, 1.1247589689261377, 1.127378204157833, 1.129886688201561, 1.1322936253405367, 1.1346071097720232, 1.1368342978555985, 1.1389815481298335, 1.1410545360838227, 1.1430583489631165, 1.1449975646435893, 1.1468763176861148, 1.1486983549970349, 1.1504670830000296, 1.1521856078291028, 1.1538567697478352, 1.1554831727638066, 1.1570672102223722, 1.1586110870184632, 1.160116838949649, 1.1615863496415422, 1.163021365402562, 1.1644235083052243, 1.165794287742481, 1.1671351106678878, 1.168447290695739, 1.1697320562103755, 1.1709905576115642, 1.1722238738042479, 1.173433018025442, 1.174618943088019, 1.1757825461101308, 1.176924672789742, 1.1780461212758628, 1.1791476456813663, 1.180229959276549, 1.1812937373976768, 1.1823396201005605, 1.1833682145855515, 1.1843800974172272, 1.185375816559308, 1.186355893242986, 1.1873208236847952, 1.18827108066835, 1.189207115002721, 1.1901293568688291, 1.1910382170640372, 1.1919340881540552, 1.1928173455403273, 1.1936883484502543, 1.1945474408568506, 1.1953949523338054, 1.1962311988513155, 1.1970564835175606, 1.1978710972702193, 1.1986753195220192, 1.1994694187639448, 1.2002536531293975, 1.201028270922308, 1.2017935111119336, 1.202549603796835, 1.203296770640311, 1.2040352252793785, 1.2047651737091998, 1.2054868146447177, 1.2062003398610939, 1.2069059345144324, 1.2076037774441422, 1.2082940414581886, 1.208976893602386, 1.209652495414788, 1.2103210031661629, 1.2109825680874522, 1.2116373365850546, 1.2122854504447083, 1.2129270470246902, 1.213562259438999, 1.2141912167311368, 1.214814044039067, 1.2154308627518788, 1.2160417906586571, 1.2166469420900154], [0.0, 0.9668932064195587, 1.0009906217066897, 1.0214910634409038, 1.036290479747109, 1.0479172972619382, 1.0575138679977951, 1.0656961843157284, 1.0728351845929356, 1.079171914500817, 1.0848720209419425, 1.090054326665691, 1.0948070140139379, 1.0991973594213271, 1.1032778790936693, 1.1070903666208258, 1.1106686356719557, 1.1140404367443495, 1.1172288298774418, 1.120253188920532, 1.1231299501381014, 1.1258731795755499, 1.1284950094785207, 1.1310059784809932, 1.1334152999841454, 1.1357310762035278, 1.1379604705879638, 1.14010984797493, 1.142184889475784, 1.1441906873756122, 1.1461318240852318, 1.148012438261303, 1.1498362805219338, 1.1516067606652813, 1.153326987902354, 1.1549998053103583, 1.156627819476461, 1.1582134261169175, 1.159758832310875, 1.1612660758726088, 1.1627370422936916, 1.1641734796124739, 1.1655770115083313, 1.1669491488694534, 1.1682913000431552, 1.1696047799450249, 1.170890818176268, 1.172150566276263, 1.1733851042187382, 1.1745954462444443, 1.1757825461101308, 1.1769473018226544, 1.1780905599177462, 1.17921311933508, 1.1803157349345703, 1.1813991206930938, 1.1824639526159195, 1.1835108713929114, 1.1845404848259267, 1.1855533700506997, 1.1865500755737766, 1.187531123142692, 1.188497009465542, 1.1894482077942918, 1.1903851693845924, 1.191308324843512, 1.192218085375358, 1.193114843934724, 1.1939989762949355, 1.1948708420392515, 1.1957307854814339, 1.1965791365216545, 1.197416211443117, 1.1982423136542666, 1.1990577343809914, 1.199862753312811, 1.2006576392066828, 1.201442650451721, 1.2022180355978314, 1.2029840338509998, 1.2037408755377272, 1.204488782540897, 1.2052279687091592, 1.20595864024174, 1.206680996050433, 1.2073952281003766, 1.208101521731095, 1.2088000559591587, 1.209491003763721, 1.2101745323560746, 1.2108508034342973, 1.2115199734239617, 1.2121821937058224, 1.2128376108313115, 1.213486366726623, 1.214128598886104, 1.2147644405556188, 1.2153940209065026, 1.2160174652006834, 1.2166348949475014, 1.2172464280527255, 1.2178521789602275], [0.0, 0.9678324230553559, 1.0019629597456188, 1.0224833151122694, 1.0372971072129291, 1.0489352187366092, 1.0585411113487828, 1.0667313757705545, 1.0738773106996744, 1.0802201959534683, 1.0859258393398943, 1.0911131790298711, 1.0958704830234647, 1.100265093106018, 1.104349576496311, 1.1081657673814862, 1.1117475122764817, 1.1151225886347484, 1.1183140788956853, 1.121341375727879, 1.1242209313615996, 1.1269668255056633, 1.1295912021906829, 1.1321046102876113, 1.134516272147301, 1.1368342978555985, 1.139065857819728, 1.141217323059815, 1.143294380205711, 1.1453021264890246, 1.147245148771816, 1.149127589730936, 1.1509532036277526, 1.1527254035726182, 1.1544473017967527, 1.1561217441390599, 1.1577513397186818, 1.1593384865790142, 1.160885393943108, 1.1623941016047217, 1.1638664968869488, 1.165304329526142, 1.1667092247788797, 1.1680826950009917, 1.1694261499078273, 1.1707409056922522, 1.1720281931498762, 1.1732891649386556, 1.174524902081379, 1.175736419804006, 1.176924672789742, 1.1780905599177462, 1.179234928546054, 1.1803585783904096, 1.18146226504398, 1.1825467031771821, 1.1836125694519402, 1.1846605051804682, 1.1856911187550276, 1.186704987871969, 1.1877026615706439, 1.1886846621053997, 1.1896514866668235, 1.190603608966585, 1.1915414806986748, 1.1924655328884417, 1.1933761771396276, 1.1942738067885323, 1.1951587979734988, 1.1960315106270762, 1.1968922893974845, 1.1977414645053526, 1.198579352541114, 1.1994062572079376, 1.2002224700146011, 1.2010282709223077, 1.201823928949079, 1.2026097027350224, 1.2033858410714784, 1.204152583396792, 1.204910160261198, 1.2056587937631111, 1.206398697958909, 1.2071300792481143, 1.2078531367357395, 1.2085680625733928, 1.2092750422806327, 1.2099742550479222, 1.210665874022442, 1.2113500665779107, 1.2120269945694746, 1.212696814574655, 1.213359678121254, 1.2140157319030598, 1.2146651179841306, 1.215307973992372, 1.21594443330308, 1.216574625213064, 1.217198675105928, 1.2178167046090436, 1.2184288317427103, 1.2190351710619685], [0.0, 0.9687546351822214, 1.0029176936129038, 1.0234576020758508, 1.038285509697333, 1.0499347107519328, 1.0595497564679346, 1.0677478250931944, 1.0749005691224152, 1.0812494982796381, 1.0869605783650185, 1.0921528608813094, 1.0969146979359263, 1.1013134954817372, 1.1054018708269024, 1.109221698020832, 1.1128068558295705, 1.1161851481746885, 1.119379679489997, 1.1224098609226483, 1.1252921603796406, 1.1280406709858297, 1.1306675483434314, 1.1331833513750318, 1.1355973112191244, 1.1379175456893602, 1.140151232025382, 1.1423047473180274, 1.1443837836157293, 1.1463934430070626, 1.1483383167247403, 1.1502225513930182, 1.152049904850563, 1.153823793459955, 1.1555473324179457, 1.1572233702751342, 1.1588545186367973, 1.1604431778313384, 1.1619915591868966, 1.1635017044408744, 1.1649755027147277, 1.166414705412068, 1.1678209393381216, 1.169195718289787, 1.1705404533256794, 1.1718564618928167, 1.1731449759595893, 1.1744071492822783, 1.17564406391374, 1.1768567360473052, 1.1780461212758628, 1.17921311933508, 1.1803585783904096, 1.1814832989196156, 1.1825880372358415, 1.183673508690488, 1.1847403905902454, 1.185789324858411, 1.186820920466961, 1.1878357556627117, 1.1888343800081738, 1.189817316255332, 1.190785062068528, 1.1917380916108145, 1.1926768570065842, 1.1936017896918947, 1.1945133016626894, 1.1954117866300646, 1.1962976210907712, 1.1971711653203252, 1.1980327642953492, 1.198882748551127, 1.1997214349797602, 1.200549127573805, 1.2013661181198068, 1.202172686845734, 1.2029691030259457, 1.2037556255469977, 1.2045325034372947, 1.205299976363334, 1.206058275095033, 1.2068076219424362, 1.2075482311658872, 1.20828030936158, 1.2090040558242463, 1.209719662888589, 1.210427316250941, 1.2111271952725093, 1.211819473265461, 1.212504317762998, 1.213181890774493, 1.2138523490266642, 1.2145158441916988, 1.2151725231031647, 1.215822527960487, 1.2164659965227125, 1.2171030622922254, 1.2177338546890373, 1.2183584992162255, 1.2189771176170563, 1.219589828024286, 1.2201967451021105], [0.0, 0.9696604629374559, 1.00385546531494, 1.0244145794864328, 1.039256351847022, 1.0509164454117152, 1.0605404816140187, 1.0687462157903174, 1.075905647946575, 1.0822605136289383, 1.0879769338228105, 1.0931740713492821, 1.097940360928835, 1.102343271541837, 1.1064354696959233, 1.1102588685945622, 1.113847378681919, 1.1172288298774418, 1.120426348218593, 1.1234593630027918, 1.1263443575352474, 1.1290954381185, 1.131724771720783, 1.1342429271377346, 1.1366591441393648, 1.1389815481298335, 1.141217323059815, 1.1433728519830049, 1.1454538322701489, 1.1474653707804965, 1.1494120630397633, 1.1512980595494797, 1.1531271216620547, 1.1549026689345165, 1.1566278194764612, 1.1583054245020068, 1.1599380980583944, 1.161528242718439, 1.1630780718779679, 1.1645896291834972, 1.166064805522893, 1.1675053539374058, 1.1689129027533958, 1.1702889671832273, 1.1716349596049167, 1.1729521986973521, 1.174241917580868, 1.175505271090558, 1.176743342291045, 1.1779571483258444, 1.1791476456813663, 1.1803157349345703, 1.18146226504398, 1.1825880372358415, 1.183693808530484, 1.184780294948193, 1.1858481744289695, 1.1868980894963377, 1.1879306496916886, 1.1889464338025244, 1.189945991905221, 1.1909298472405592, 1.1918984979382181, 1.1928524186046132, 1.1937920617868938, 1.1947178593245287, 1.1956302235986958, 1.1965295486886278, 1.1974162114431168, 1.1982905724745523, 1.1991529770821245, 1.2000037561101828, 1.2008432267471358, 1.2016716932697866, 1.2024894477375139, 1.203296770640311, 1.2040939315043204, 1.204881189458168, 1.2056587937631111, 1.2064269843097457, 1.2071859920837686, 1.2079360396030943, 1.208677341328409, 1.2094101040490832, 1.2101345272461979, 1.210850803434297, 1.211559118483348, 1.2122596519222686, 1.2129525772252794, 1.2136380620822338, 1.2143162686539903, 1.2149873538138134, 1.2156514693757103, 1.2163087623105446, 1.2169593749507044, 1.2176034451840465, 1.2182411066377865, 1.2188724888529485, 1.2194977174499615, 1.2201169142859265, 1.2207301976040592, 1.2213376821757715], [0.0, 0.9705504928718682, 1.004776882087206, 1.02535486701577, 1.040210262311588, 1.0518810584187765, 1.061513928311467, 1.0697271943500306, 1.0768931979910255, 1.08325389666432, 1.0889755638341023, 1.0941774716983865, 1.0989481361499323, 1.1033550880973952, 1.107451042389835, 1.1112779507019241, 1.1148697546034767, 1.1182543095584088, 1.1214547628310625, 1.1244905615525804, 1.127378204157833, 1.1301318098972253, 1.132763556906781, 1.1352840236830037, 1.1377024584768836, 1.1400269941507097, 1.1422648212491464, 1.1444223286847532, 1.1465052190577667, 1.1485186039149098, 1.1504670830000296, 1.1523548106243104, 1.1541855515926234, 1.1559627286007326, 1.1576894626202783, 1.159368607482445, 1.16100277963385, 1.162594383852577, 1.16414563556608, 1.1656585802966937, 1.167135110667888, 1.1685769813299915, 1.1699858221039692, 1.171363149592965, 1.1727103774713865, 1.1740288256285079, 1.1753197283165173, 1.1765842414305063, 1.1778234490292188, 1.1790383691897839, 1.180229959276549, 1.1813991206930938, 1.1825467031771821, 1.183673508690488, 1.184780294948193, 1.1858677786278011, 1.1869366382915805, 1.187987517052813, 1.1890210250123743, 1.1900377414890226, 1.1910382170640375, 1.19202297545847, 1.1929925152592218, 1.1939473115083397, 1.1948878171683555, 1.1958144644751139, 1.1967276661883084, 1.1976278167488885, 1.1985152933515475, 1.1993904569396727, 1.2002536531293975, 1.2011052130687452, 1.2019454542372654, 1.2027746811910494, 1.2035931862575513, 1.20440125018422, 1.2051991427445896, 1.205987123305135, 1.2067654413559046, 1.2075343370076845, 1.2082940414581889, 1.2090447774295756, 1.2097867595793805, 1.2105201948867808, 1.211245283015957, 1.211962216658158, 1.212671181853957, 1.2133723582970573, 1.214065919620908, 1.2147520336692812, 1.2154308627518788, 1.2161025638859566, 1.216767289024868, 1.2174251852743778, 1.218076395097518, 1.21872105650871, 1.2193593032578225, 1.2199912650047826, 1.2206170674853234, 1.2212368326683958, 1.2218506789057486, 1.2224587210741393], [0.0, 0.9714252803415914, 1.0056825188704264, 1.0262790513794613, 1.0411478363069966, 1.052829151667198, 1.0624707039663592, 1.0706913728781056, 1.0778638354619778, 1.0842302672316324, 1.0899570915187238, 1.0951636880250228, 1.0999386524254275, 1.104349576496311, 1.1084492226002718, 1.112279580224338, 1.1158746215309197, 1.119262227090933, 1.1224655650320723, 1.1255041000137864, 1.128394345341501, 1.1311504329917417, 1.1337845520770673, 1.13630729062871, 1.1387279052333976, 1.1410545360838225, 1.143294380205711, 1.1454538322701489, 1.1475386000173047, 1.1495537996010978, 1.1515040349112686, 1.1533934640034111, 1.1552258550757333, 1.1570046339089817, 1.1587329242878255, 1.1604135826156965, 1.162049227697497, 1.1636422664788124, 1.1651949163839308, 1.1667092247788797, 1.16818708599301, 1.1696302562581713, 1.1710403668643368, 1.1724189357816128, 1.1737673779585953, 1.175087014474216, 1.1763790806931333, 1.177644733552283, 1.1788850580875048, 1.1801010732935528, 1.1812937373976768, 1.1824639526159195, 1.1836125694519402, 1.1847403905902454, 1.1858481744289695, 1.1869366382915805, 1.1880064613519556, 1.1890582873030346, 1.1900927267955965, 1.191110359670558, 1.1921117370054533, 1.1930973829933809, 1.1940677966706341, 1.1950234535074298, 1.1959648068745692, 1.1968922893974845, 1.1978063142079027, 1.198707276102295, 1.1995955526153321, 1.2004715050157309, 1.201335479231139, 1.2021878067080545, 1.2030288052121807, 1.2038587795741154, 1.2046780223847957, 1.2054868146447175, 1.2062854263705702, 1.2070741171626034, 1.2078531367357392, 1.208622725417183, 1.2093831146130343, 1.2101345272461979, 1.2108771781676864, 1.2116112745432346, 1.2123370162169864, 1.213054596053869, 1.2137642002621403, 1.2144660086974666, 1.2151601951497986, 1.2158469276141908, 1.2165263685466408, 1.217198675105928, 1.2178639993823666, 1.2185224886143122, 1.2191742853932035, 1.2198195278578585, 1.2204583498786983, 1.2210908812325174, 1.2217172477683778, 1.222337571565165, 1.2229519710813022, 1.2235605612970886], [0.0, 0.9722853516902226, 1.0065729205696652, 1.0271876886423101, 1.0420696379543473, 1.053761295607321, 1.063411384253082, 1.0716393315031016, 1.0788181443742193, 1.0851902127951623, 1.0909221074439044, 1.0961333137174902, 1.1009125057308207, 1.1053273351040378, 1.109430610913983, 1.1132643598239405, 1.1168625840742723, 1.120253188920532, 1.1234593630027918, 1.1265005882139374, 1.1293933924797888, 1.1321519202889077, 1.1347883715457343, 1.137313343655832, 1.1397361014014382, 1.142064792182332, 1.1443066193962745, 1.1464679833760052, 1.1485545969151578, 1.1505715806973438, 1.1525235426884515, 1.1544146446254957, 1.1562486580429354, 1.1580290117546033, 1.159758832310875, 1.1614409786441582, 1.1630780718779679, 1.164672521088928, 1.1662265456645688, 1.167742194783596, 1.1692213644525433, 1.1706658124581768, 1.1720771715347653, 1.1734569609963816, 1.1748065970443753, 1.1761274019273227, 1.1774206121036372, 1.178687385534573, 1.1799288082166284, 1.1811459000467457, 1.1823396201005605, 1.1835108713929114, 1.1846605051804682, 1.185789324858411, 1.1868980894963377, 1.187987517052813, 1.1890582873030346, 1.1901110445098497, 1.1911463998646887, 1.1921649337218427, 1.1931671976467544, 1.1941537162966265, 1.1951249891495848, 1.1960814920968132, 1.1970236789105144, 1.1979519825991545, 1.1988668166602348, 1.199768576239768, 1.2006576392066828, 1.2015343671495526, 1.2023991063022994, 1.2032521884048741, 1.2040939315043204, 1.2049246407011243, 1.2057446088452741, 1.2065541171860554, 1.2073534359792226, 1.2081428250548674, 1.2089225343490024, 1.2096928044016113, 1.210453866823674, 1.2112059447354646, 1.2119492531782186, 1.2126839995010892, 1.213410383725156, 1.214128598886104, 1.2148388313570533, 1.2155412611529102, 1.216236062217493, 1.216923402694595, 1.2176034451840467, 1.2182763469837716, 1.21894226031874, 1.219601332557669, 1.2202537064182422, 1.220899520161582, 1.221538907776635, 1.2221719991550957, 1.2227989202574494, 1.2234197932706667, 1.22403473675805, 1.2246438658016991], [0.0, 0.9731312062429956, 1.0074486041188226, 1.0280813063251026, 1.042976202417175, 1.0546780314070283, 1.0643365152954014, 1.0725716205743159, 1.0797566787637858, 1.0861342906633742, 1.091871171861771, 1.0970869117041742, 1.1018702614488909, 1.1062889315706275, 1.110395777088292, 1.1142328612269081, 1.1178342158076096, 1.121227770362554, 1.1244367337051269, 1.1274806046767853, 1.1303759255820722, 1.1331368532147637, 1.135775598092794, 1.138302766841102, 1.1407276323019648, 1.1430583489631165, 1.1453021264890246, 1.1474653707804965, 1.149553799601098, 1.1515725380892579, 1.1535261982196352, 1.1554189453498118, 1.1572545542953507, 1.1590364568530336, 1.160767782293227, 1.1624513920355104, 1.1640899094836854, 1.1656857458101892, 1.1672411223333425, 1.1687580900145649, 1.1702385465098504, 1.1716842511351784, 1.1730968380452405, 1.1744778278758594, 1.1758286380604313, 1.1771505919978424, 1.1784449272221829, 1.1797128027020922, 1.1809553053788484, 1.1821734560366688, 1.1833682145855515, 1.1845404848259267, 1.1856911187550276, 1.186820920466961, 1.1879306496916886, 1.1890210250123743, 1.1900927267955965, 1.1911463998646887, 1.1921826559427973, 1.1932020758891007, 1.1942052117488844, 1.1951925886357853, 1.1961647064624576, 1.1971220415340942, 1.1980650480176633, 1.198994159298334, 1.1999097892333357, 1.2008123333124445, 1.2017021697333221, 1.2025796603991115, 1.2034451518449458, 1.2042989760993787, 1.2051414514861436, 1.2059728833711527, 1.206793564859165, 1.207603777444142, 1.2084037916169517, 1.209193867433729, 1.2099742550479222, 1.2107451952087762, 1.2115069197287647, 1.2122596519222686, 1.213003607017602, 1.213738992544304, 1.2144660086974666, 1.2151848486807084, 1.2158956990292882, 1.2165987399147182, 1.217294145432143, 1.217982083871634, 1.2186627179744787, 1.219336205175444, 1.2200026978319307, 1.2206623434408614, 1.2213152848440794, 1.2219616604229897, 1.222601604283104, 1.2232352464291185, 1.2238627129311, 1.2244841260823167, 1.2250996045492177, 1.22570926351402], [0.0, 0.973963318132117, 1.0083100603703414, 1.028960405333015, 1.0438680378577962, 1.0555798729300405, 1.0652466156628766, 1.0734887626736427, 1.0806799647132996, 1.0870630300262119, 1.0928048167574094, 1.0980250165113903, 1.1028124564365132, 1.107234904905834, 1.1113452621339033, 1.1151856273134633, 1.1187900613658168, 1.122186517705303, 1.1253982249908634, 1.1284446987371612, 1.13134249539385, 1.1341057838599968, 1.1367467850945918, 1.139276114792161, 1.1417030537240693, 1.1440357633508473, 1.1462814595018533, 1.1484465535554975, 1.1505367681645313, 1.1525572328498228, 1.1545125635296714, 1.1564069291234014, 1.1582441076743721, 1.1600275339138504, 1.1617603397880012, 1.1634453891631669, 1.1650853076863874, 1.1666825085918626, 1.1682392150973335, 1.1697574799179702, 1.171239202332428, 1.1726861431610545, 1.1740999379558854, 1.17548210865302, 1.176834073897883, 1.1781571582209824, 1.1794526002146073, 1.1807215598384162, 1.1819651249631167, 1.1831843172457852, 1.1843800974172272, 1.1855533700506997, 1.186704987871969, 1.1878357556627117, 1.1889464338025244, 1.1900377414890226, 1.191110359670558, 1.1921649337218427, 1.1932020758891007, 1.194222367528195, 1.1952263611564586, 1.1962145823365458, 1.1971875314085794, 1.198145685085035, 1.1990894979212332, 1.2000194036729246, 1.2009358165512234, 1.2018391323840831, 1.2027297296925579, 1.203607970689249, 1.2044742022056079, 1.2053287565541007, 1.2061719523306558, 1.2070040951623, 1.207825478404422, 1.2086363837916856, 1.2094370820462514, 1.2102278334466257, 1.2110088883601589, 1.2117804877419585, 1.212542863602717, 1.213296239447769, 1.2140408306894677, 1.214776845034808, 1.2155044828500658, 1.2162239375040658, 1.2169353956915707, 1.2176390377381552, 1.2183350378878302, 1.2190235645745695, 1.219704780678819, 1.2203788437699659, 1.22104590633569, 1.2217061159990361, 1.2223596157239904, 1.2230065440102853, 1.223647035078105, 1.2242812190433108, 1.22490922208377, 1.2255311665973232, 1.2261471713518888, 1.226757351628175], [0.0, 0.9747821379701602, 1.009157755827613, 1.0298254617234994, 1.0447456272308093, 1.056467308549538, 1.06614217820109, 1.0743912544599652, 1.081588502208716, 1.0879769338228107, 1.0937235477264424, 1.0989481361499323, 1.1037396009194318, 1.1081657673814862, 1.112279580224338, 1.1161231740339046, 1.119730638366816, 1.1231299501381014, 1.1263443575352474, 1.1293933924797888, 1.1322936253405367, 1.135059236928481, 1.1377024584768833, 1.1402339146049814, 1.1426628938865682, 1.144997564643589, 1.147245148771816, 1.1494120630397633, 1.1515040349112686, 1.1535261982196352, 1.1554831727638069, 1.1573791309679562, 1.1592178540516787, 1.16100277963385, 1.1627370422936918, 1.1644235083052243, 1.1660648055228933, 1.1676633492097261, 1.1692213644525435, 1.1707409056922522, 1.1722238738042479, 1.173672031089216, 1.175087014474216, 1.1764703471748525, 1.1778234490292185, 1.1791476456813665, 1.1804441767648817, 1.1817142032146115, 1.182958813815846, 1.1841790310845781, 1.185375816559308, 1.1865500755737766, 1.1877026615706439, 1.1888343800081738, 1.189945991905221, 1.1910382170640375, 1.1921117370054533, 1.1931671976467544, 1.1942052117488844, 1.1952263611564586, 1.1962311988513157, 1.1972202508379552, 1.198194017877141, 1.1991529770821248, 1.200097583390376, 1.201028270922308, 1.2019454542372654, 1.2028495294959787, 1.2037408755377272, 1.2046198548796283, 1.2054868146447175, 1.2063420874248394, 1.2071859920837686, 1.2080188345054754, 1.208840908291975, 1.209652495414788, 1.210453866823674, 1.211245283015957, 1.2120269945694746, 1.2127992426419065, 1.2135622594389992, 1.2143162686539903, 1.2150614858803321, 1.2157981189996403, 1.216526368546641, 1.2172464280527255, 1.2179584843696127, 1.2186627179744787, 1.2193593032578225, 1.2200484087952226, 1.2207301976040594, 1.2214048273861904, 1.222072450757493, 1.22273321546512, 1.2233872645932489, 1.2240347367580502, 1.2246757662925478, 1.225310483421993, 1.225939014430332, 1.2265614818183057, 1.2271780044536826, 1.227788697714088], [0.0, 0.9755880943864668, 1.00999213423556, 1.030676928329443, 1.0456094299297674, 1.057340802813309, 1.0670236717120458, 1.0752795683625556, 1.0824827668440669, 1.0888764804563116, 1.0946278456989014, 1.0998567538471775, 1.104652180231918, 1.1090820062781201, 1.1131992204490504, 1.1170459921677844, 1.1206564391764264, 1.1240585615215073, 1.1272756266122705, 1.1303271825193753, 1.1332298133121244, 1.1359977115262978, 1.1386431185080228, 1.1411766676610435, 1.1436076552390082, 1.145944256317486, 1.1481936987633605, 1.150362404650573, 1.152456106178467, 1.1544799414250337, 1.1564385340088972, 1.1583360598040193, 1.1601763031563324, 1.1619627045269592, 1.1636984010868117, 1.1653862614797652, 1.1670289157329934, 1.168628781106479, 1.1701880845267598, 1.1717088821333674, 1.1731930763733547, 1.174642431004489, 1.176058584307252, 1.1774430607566528, 1.1787972813647167, 1.1801225728715472, 1.181420175935667, 1.1826912524517925, 1.183936892105428, 1.1851581182579904, 1.186355893242986, 1.187531123142692, 1.1886846621053997, 1.189817316255332, 1.1909298472405592, 1.19202297545847, 1.1930973829933809, 1.1941537162966265, 1.1951925886357853, 1.1962145823365458, 1.1972202508379552, 1.1982101205794178, 1.1991846927357295, 1.2001444448146221, 1.2010898321297112, 1.2020212891603432, 1.2029392308086233, 1.2038440535628303, 1.2047361365754707, 1.2056158426633932, 1.206483519236637, 1.2073394991620356, 1.2081841015670027, 1.2090176325884154, 1.2098403860710412, 1.2106526442195362, 1.2114546782076834, 1.2122467487481876, 1.2130291066260661, 1.213801993198389, 1.2145656408628926, 1.215320273497765, 1.2160661068747127, 1.2168033490472299, 1.2175322007158453, 1.218252855571964, 1.2189655006217948, 1.2196703164917333, 1.2203674777164664, 1.2210571530109513, 1.2217395055273528, 1.222414693097917, 1.2230828684647053, 1.223744179497029, 1.2243987693973681, 1.2250467768965023, 1.2256883364385232, 1.2263235783563524, 1.2269526290383488, 1.2275756110865383, 1.2281926434669694, 1.2288038416526625], [0.0, 0.9763815954398198, 1.0108136180431277, 1.0315152362516102, 1.046459883301246, 1.0582007979748054, 1.067891542499244, 1.076154154138104, 1.083363211388921, 1.0897621253705794, 1.0955181685242716, 1.100751329639704, 1.1055506564163307, 1.1099840854909566, 1.1141046484253663, 1.1179545489414158, 1.1215679325311017, 1.124972822014978, 1.1281925037269904, 1.131246541637351, 1.1341515333041254, 1.136921682806687, 1.1395692414477432, 1.1421048512797873, 1.1445378161176376, 1.146876317686115, 1.1491275897309363, 1.15129805954948, 1.1533934640034116, 1.1554189453498118, 1.1573791309679564, 1.1592782001282813, 1.161119940254742, 1.1629077946067832, 1.1646449029069559, 1.1663341361323656, 1.1679781264493359, 1.1695792930839444, 1.1711398647740139, 1.1726618993314513, 1.1741473007506769, 1.1755978342240223, 1.1770151393644757, 1.1784007418869882, 1.179756063959374, 1.1810824334008503, 1.1823810918790367, 1.183653202233685, 1.1848998550366026, 1.1861220744815637, 1.1873208236847952, 1.188497009465542, 1.1896514866668235, 1.190785062068528, 1.1918984979382181, 1.1929925152592218, 1.1940677966706341, 1.1951249891495848, 1.1961647064624576, 1.1971875314085794, 1.198194017877141, 1.1991846927357295, 1.2001600575667744, 1.2011205902663922, 1.2020667465185302, 1.2029989611559218, 1.2039176494181356, 1.204823208115937, 1.2057160167102179, 1.2065964383129273, 1.2074648206166723, 1.2083214967590261, 1.2091667861269664, 1.210000995106369, 1.210824417781002, 1.2116373365850546, 1.2124400229128705, 1.2132327376892076, 1.2140157319030598, 1.2147892471078074, 1.2155535158902087, 1.2163087623105446, 1.2170552023160208, 1.2177930441293534, 1.2185224886143124, 1.2192437296198426, 1.2199569543042557, 1.2206623434408612, 1.2213600717063047, 1.2220503079527691, 1.2227332154651198, 1.223408952203977, 1.2240776710356358, 1.224739519949678, 1.2253946422650583, 1.226043176825394, 1.2266852581841274, 1.2273210167801878, 1.2279505791047327, 1.228574067859507, 1.229191602107321, 1.2298032974151163], [0.0, 0.9771630299191728, 1.0116226097498822, 1.03234079623282, 1.0472974040389273, 1.0590477154028666, 1.0687462157903176, 1.0770154403043632, 1.0842302672316324, 1.0906343025019742, 1.0963949524309335, 1.101632301839704, 1.1064354696959233, 1.110872447008612, 1.1149963077826843, 1.1188492895172035, 1.1224655650320723, 1.1258731795755499, 1.1290954381185003, 1.1321519202889079, 1.1350592369284813, 1.137831603484646, 1.1404812810652825, 1.1430189202401146, 1.145453832270149, 1.147794205428345, 1.1500472792498555, 1.1522194861760633, 1.1543165676600577, 1.1563436700744594, 1.158305424502007, 1.1602060135579624, 1.162049227697497, 1.1638385129358242, 1.1655770115083313, 1.167267596689874, 1.168912902753396, 1.1705153508611716, 1.1720771715347655, 1.1736004242330276, 1.175087014474216, 1.1765387088634112, 1.1779571483258446, 1.1793438597975536, 1.1807002665845663, 1.1820276975688027, 1.1833273954116357, 1.1846005238834805, 1.1858481744289697, 1.1870713720615782, 1.18827108066835, 1.1894482077942918, 1.190603608966585, 1.1917380916108145, 1.1928524186046132, 1.1939473115083397, 1.1950234535074298, 1.1960814920968132, 1.1971220415340942, 1.198145685085035, 1.1991529770821248, 1.2001444448146221, 1.2011205902663922, 1.202081891716029, 1.2030288052121807, 1.2039617659355937, 1.2048811894581681, 1.2057874729082514, 1.2066809960504328, 1.2075621222872728, 1.2084311995896502, 1.20928856136176, 1.210134527246198, 1.2109694038740515, 1.2117934855644543, 1.212607054977639, 1.213410383725156, 1.2142037329405908, 1.2149873538138136, 1.2157614880915282, 1.216526368546641, 1.217282219418757, 1.218029256827912, 1.2187676891634707, 1.2194977174499617, 1.2202195356914745, 1.2209333311961106, 1.221639284881859, 1.2223375715651652, 1.2230283602333512, 1.2237118143019652, 1.2243880918580492, 1.2250573458902427, 1.2257197245065694, 1.2263753711406873, 1.2270244247473352, 1.2276670199876438, 1.2283032874049373, 1.2289333535916092, 1.2295573413476066, 1.2301753698310307, 1.2307875547013152], [0.0, 0.9779327685429284, 1.0124194931475823, 1.0331539999249457, 1.0481223894689577, 1.0598819568815, 1.0695880970487135, 1.0778638354619778, 1.0850843457100232, 1.091493425617897, 1.0972586133717763, 1.1025000883870246, 1.1073070398327802, 1.1117475122764815, 1.1158746215309194, 1.1197306383668157, 1.123349762522958, 1.1267600613396314, 1.1299848581456764, 1.1330437479924975, 1.1359533548066276, 1.1387279052333976, 1.1413796700391048, 1.1439193081832248, 1.1463561382615046, 1.1486983549970349, 1.1509532036277528, 1.1531271216620547, 1.1552258550757335, 1.1572545542953507, 1.1592178540516787, 1.1611199402547419, 1.1629646063455596, 1.1647553010538674, 1.1664951690902794, 1.16818708599301, 1.1698336881100933, 1.1714373985110211, 1.1730004494744017, 1.1745249020813788, 1.1760126633512404, 1.177465501280671, 1.1788850580875048, 1.180272861910589, 1.1816303371771304, 1.1829588138158458, 1.1842595354669874, 1.1855336668177048, 1.186782300172392, 1.1880064613519556, 1.189207115002721, 1.1903851693845924, 1.1915414806986748, 1.1926768570065842, 1.1937920617868938, 1.1948878171683555, 1.1959648068745692, 1.1970236789105144, 1.1980650480176633, 1.1990894979212332, 1.200097583390376, 1.2010898321297112, 1.2020667465185302, 1.2030288052121807, 1.2039764646185533, 1.204910160261198, 1.2058303080393726, 1.206737305394254, 1.2076315323895828, 1.208513352714181, 1.209383114613034, 1.2102411517529694, 1.2110877840283736, 1.2119233183118758, 1.2127480491544538, 1.213562259438999, 1.214366220991018, 1.2151601951497986, 1.21594443330308, 1.216719177387997, 1.2174846603608176, 1.2182411066377863, 1.2189887325091833, 1.2197277465285268, 1.2204583498786985, 1.22118073671661, 1.2218950944979108, 1.222601604283104, 1.223300441026343, 1.223991773848066, 1.2246757662925476, 1.22535257657136, 1.2260223577936558, 1.2266852581841274, 1.22734142128942, 1.2279909861737306, 1.228634087604266, 1.2292708562271837, 1.2299014187345967, 1.230525898023186, 1.231144413344916, 1.2317570804503293], [0.0, 0.978691165066134, 1.0132046344664203, 1.03395522105863, 1.0489352187366092, 1.060703905809855, 1.0704175731846572, 1.0786997295148186, 1.0859258393398943, 1.0923398895525533, 1.0981095482664913, 1.1033550880973955, 1.1081657673814862, 1.112609683455436, 1.1167399933238733, 1.1205990005389201, 1.1242209313615998, 1.1276338748986963, 1.1308611725665227, 1.1339224346126395, 1.1368342978555988, 1.139610999973635, 1.1422648212491464, 1.1448064289077367, 1.1472451487718163, 1.149589181919564, 1.1518457792076713, 1.1540213831368855, 1.1561217441390603, 1.1581520166349641, 1.160116838949649, 1.162020400239354, 1.163866496886949, 1.1656585802966937, 1.1673997976179564, 1.1690930266189596, 1.170740905692252, 1.1723458597864391, 1.1739101229112836, 1.175435757746318, 1.176924672789742, 1.17837863740934, 1.1797992950965013, 1.181188175175161, 1.1825467031771821, 1.1838762100626552, 1.1851779404362874, 1.1864530598884546, 1.187702661570644, 1.1889277720992961, 1.1901293568688291, 1.191308324843512, 1.1924655328884417, 1.1936017896918947, 1.1947178593245287, 1.1958144644751139, 1.1968922893974845, 1.1979519825991545, 1.198994159298334, 1.2000194036729246, 1.201028270922308, 1.2020212891603432, 1.2029989611559218, 1.2039617659355937, 1.204910160261198, 1.2058445799940376, 1.2067654413559048, 1.2076731420961953, 1.208568062573393, 1.2094505667583646, 1.2103210031661629, 1.211179705722377, 1.2120269945694746, 1.2128631768180682, 1.2136885472475623, 1.214503388960227, 1.215307973992372, 1.2161025638859566, 1.2168874102236735, 1.2176627551302823, 1.2184288317427105, 1.2191858646512403, 1.2199340703138863, 1.220673657445903, 1.2214048273861904, 1.2221277744422312, 1.2228426862150488, 1.2235497439055603, 1.2242491226035976, 1.2249409915607534, 1.2256255144481332, 1.226302849600003, 1.2269731502442538, 1.2276365647205272, 1.22829323668679, 1.2289433053150858, 1.229586905477134, 1.2302241679204093, 1.2308552194352764, 1.2314801830137232, 1.2320991780001957, 1.232712320235002], [0.0, 0.9794385573039582, 1.013978383434591, 1.034744816524555, 1.049736253903215, 1.061513928311467, 1.0712350136745536, 1.0795234947980459, 1.0867551229506447, 1.0931740713492821, 1.0989481361499323, 1.1041976818162753, 1.1090120348480037, 1.1134593445853458, 1.1175928086270766, 1.1214547628310627, 1.125079459595726, 1.1284950094785207, 1.131724771720783, 1.1347883715457343, 1.1377024584768836, 1.1404812810652825, 1.143137128971352, 1.1456806775668826, 1.14812125979609, 1.1504670830000294, 1.1527254035726182, 1.1549026689345165, 1.1570046339089817, 1.1590364568530336, 1.1610027796338502, 1.1629077946067832, 1.1647553010538674, 1.1665487530150793, 1.1682913000431554, 1.169985822103969, 1.171634959604917, 1.173241139346453, 1.1748065970443755, 1.1763333969534129, 1.1778234490292185, 1.1792785239907808, 1.1807002665845663, 1.182090207302401, 1.1834497727647775, 1.1847802949481931, 1.1860830194078165, 1.1873591126241443, 1.1886096685834653, 1.1898357146862109, 1.1910382170640372, 1.192218085375358, 1.1933761771396276, 1.1945133016626894, 1.1956302235986958, 1.1967276661883084, 1.1978063142079027, 1.1988668166602348, 1.1999097892333357, 1.2009358165512234, 1.2019454542372654, 1.2029392308086233, 1.2039176494181356, 1.2048811894581681, 1.2058303080393726, 1.2067654413559048, 1.20768700594741, 1.208595399867032, 1.209491003763721, 1.2103741818862954, 1.211245283015957, 1.2121046413333019, 1.2129525772252796, 1.2137893980370322, 1.2146153987730768, 1.2154308627518788, 1.2162360622174933, 1.2170312589116088, 1.2178167046090436, 1.2185926416194597, 1.2193593032578227, 1.2201169142859265, 1.2208656913270877, 1.2216058432559485, 1.2223375715651652, 1.2230610707106062, 1.2237765284365585, 1.2244841260823167, 1.2251840388714228, 1.2258764361847208, 1.2265614818183057, 1.2272393342273584, 1.2279101467567843, 1.2285740678595072, 1.2292312413032003, 1.2298818063661876, 1.230525898023186, 1.2311636471215173, 1.2317951805483711, 1.2324206213896605, 1.2330400890809705, 1.2336536995510723], [0.0, 0.9801752680789495, 1.0147410742589553, 1.0355231273741894, 1.0505258409614149, 1.0623123742608922, 1.0720407715970253, 1.0803354871221615, 1.0875725547363184, 1.0939963313178103, 1.0997747392349555, 1.1050282334867687, 1.109846207762246, 1.1142968626619556, 1.118433435798662, 1.1222982948742743, 1.1259257180510671, 1.1293438370305982, 1.1325760286244793, 1.135641932817565, 1.1385582116567472, 1.141339124410504, 1.1439969699832515, 1.1465424317765454, 1.1489848497546233, 1.1513324374319112, 1.1535924566604154, 1.1557713597103956, 1.1578749057337523, 1.1599082569675008, 1.1618760587703234, 1.163782506650963, 1.165631402749186, 1.1674262037030168, 1.1691700614342113, 1.1708658580748865, 1.1725162360184913, 1.1741236238908626, 1.1756902590894514, 1.1772182074216704, 1.1787093802797972, 1.180165549714713, 1.181588361710025, 1.182979347908759, 1.1843399360044773, 1.1856714589755601, 1.186975163314053, 1.188252216377852, 1.1895037129761166, 1.190730681282065, 1.1919340881540552, 1.193114843934724, 1.1942738067885323, 1.1954117866300646, 1.1965295486886278, 1.1976278167488885, 1.198707276102295, 1.199768576239768, 1.2008123333124445, 1.2018391323840831, 1.2028495294959787, 1.2038440535628303, 1.204823208115937, 1.2057874729082514, 1.206737305394254, 1.2076731420961953, 1.208595399867032, 1.2095044770593144, 1.2104007546083073, 1.2112845970368091, 1.2121563533883666, 1.2130163580949385, 1.2138649317844619, 1.214702382033257, 1.215529004067736, 1.2163450814194705, 1.2171508865372902, 1.2179466813597604, 1.2187327178510783, 1.2195092385031654, 1.2202764768064815, 1.2210346576918811, 1.2217839979456198, 1.2225247065994502, 1.223256985297587, 1.2239810286421633, 1.2246970245186837, 1.2254051544028413, 1.2261055936499772, 1.2267985117683398, 1.227484072677228, 1.2281624349510087, 1.2288337520499297, 1.2294981725385778, 1.2301558402927648, 1.2308068946955766, 1.2314514708232551, 1.2320896996215418, 1.2327217080730686, 1.2333476193563306, 1.2339675529967495, 1.2345816250102954], [0.0, 0.9809016060987915, 1.0154930265337503, 1.036290479747109, 1.0513043107759128, 1.063099578235021, 1.0728351845929356, 1.0811360467404627, 1.0883784772295373, 1.0948070140139379, 1.1005897038972794, 1.1058470911391898, 1.1106686356719555, 1.1151225886347484, 1.119262227090933, 1.1231299501381014, 1.1267600613396314, 1.1301807132434794, 1.1334152999841454, 1.1364834761002771, 1.1394019159858213, 1.1421848894757838, 1.144844704588422, 1.147392052641999, 1.1498362805219338, 1.1521856078291028, 1.1544473017967527, 1.156627819476461, 1.1587329242878255, 1.1607677822932267, 1.1627370422936918, 1.1646449029069557, 1.1664951690902792, 1.1682913000431552, 1.1700364500230043, 1.1717335032976857, 1.1733851042187382, 1.1749936832116799, 1.1765614793319374, 1.1780905599177462, 1.1795828377777808, 1.1810400862760624, 1.1824639526159197, 1.1838559695753696, 1.185217565905937, 1.1865500755737768, 1.187854745994621, 1.1891327453914113, 1.1903851693845926, 1.1916130469092887, 1.1928173455403273, 1.1939989762949355, 1.1951587979734988, 1.1962976210907712, 1.1974162114431168, 1.1985152933515475, 1.1995955526153321, 1.2006576392066828, 1.2017021697333221, 1.2027297296925579, 1.2037408755377272, 1.2047361365754707, 1.2057160167102179, 1.2066809960504328, 1.2076315323895828, 1.208568062573393, 1.209491003763721, 1.2104007546083073, 1.211297696324701, 1.2121821937058226, 1.2130545960538692, 1.213915238048624, 1.2147644405556188, 1.2156025113790958, 1.2164297459642395, 1.2172464280527255, 1.2180528302952764, 1.2188492148245618, 1.2196358337914912, 1.2204129298676796, 1.2211807367166103, 1.2219394794358174, 1.2226893749722016, 1.2234306325124145, 1.2241634538500943, 1.2248880337315802, 1.2256045601816052, 1.2263132148103413, 1.2270141731030728, 1.2277076046936586, 1.2283936736228664, 1.2290725385825716, 1.22974435314674, 1.2304092659900494, 1.2310674210949275, 1.231718957947747, 1.2323640117248453, 1.2330027134689987, 1.2336351902569365, 1.2342615653584328, 1.234881958387481, 1.2354964854460222], [0.0, 0.981617866770602, 1.0162345460836029, 1.0370471857312769, 1.052071979956218, 1.0638758603956104, 1.0736185757560053, 1.081925499246547, 1.089173218205021, 1.0956064491483948, 1.1013933615891416, 1.1066545878090843, 1.1114796530647288, 1.1159368583326679, 1.120079519579521, 1.1239500668629745, 1.1275828287950893, 1.1310059784809934, 1.1342429271377348, 1.1373133436558323, 1.1402339146049816, 1.1430189202401146, 1.1456806775668829, 1.1482298857104187, 1.1506758983812972, 1.1530269411824003, 1.1552902866535555, 1.1574723965613207, 1.1595790385337796, 1.1616153824056052, 1.1635860803724085, 1.1654953341177827, 1.167346951377393, 1.1691443938766617, 1.1708908181762683, 1.1725891106501836, 1.1742419175808683, 1.175851671168553, 1.1774206121036375, 1.1789508092339407, 1.180444176764882, 1.1819024893554047, 1.183327395411636, 1.184720428830837, 1.1860830194078165, 1.1874165020827998, 1.18872212518239, 1.190001057782573, 1.1912543963038222, 1.192483170432597, 1.1936883484502543, 1.1948708420392515, 1.1960315106270762, 1.1971711653203252, 1.1982905724745523, 1.1993904569396727, 1.2004715050157309, 1.2015343671495526, 1.2025796603991115, 1.203607970689249, 1.2046198548796283, 1.2056158426633932, 1.2065964383129273, 1.2075621222872728, 1.208513352714181, 1.2094505667583646, 1.2103741818862954, 1.2112845970368091, 1.2121821937058226, 1.2130673369526295, 1.213940376334491, 1.2148016467755747, 1.2156514693757106, 1.216490152163902, 1.2173179908010687, 1.2181352692360767, 1.2189422603187403, 1.2197392263731393, 1.2205264197343058, 1.221304083251055, 1.222072450757493, 1.2228317475155217, 1.2235821906304576, 1.2243239894417015, 1.2250573458902427, 1.2257824548646261, 1.2264995045268807, 1.2272086766197918, 1.2279101467567843, 1.2286040846955848, 1.2292906545967444, 1.2299700152680164, 1.2306423203955075, 1.2313077187624584, 1.231966354456434, 1.2326183670656607, 1.2332638918651826, 1.2339030599934642, 1.234535998620027, 1.2351628311046574, 1.235783677148692, 1.2363986529388502], [0.0, 0.9823243329572049, 1.0169659257464727, 1.0377935441620183, 1.052829151667198, 1.064641527308933, 1.0743912544599652, 1.0827041564078677, 1.0899570915187238, 1.0963949524309335, 1.1021860296878503, 1.107451042389835, 1.112279580224338, 1.116739993323873, 1.120885636026334, 1.1247589689261377, 1.128394345341501, 1.131819958653615, 1.135059236928481, 1.138131863212234, 1.1410545360838227, 1.1438415460756177, 1.1465052190577665, 1.1490562618555167, 1.1515040349112686, 1.1538567697478352, 1.15612174413906, 1.1583054245020068, 1.1604135826156967, 1.1624513920355104, 1.1644235083052243, 1.1663341361323654, 1.16818708599301, 1.1699858221039692, 1.1717335032976859, 1.1734330180254418, 1.175087014474216, 1.1766979265946833, 1.1782679966898584, 1.1797992950965013, 1.1812937373976768, 1.1827530995295432, 1.184179031084578, 1.185573067063982, 1.1869366382915805, 1.18827108066835, 1.1895776434193093, 1.1908574964618228, 1.1921117370054533, 1.193341395477721, 1.1945474408568506, 1.1957307854814339, 1.1968922893974845, 1.1980327642953492, 1.1991529770821245, 1.2002536531293975, 1.201335479231139, 1.2023991063022994, 1.2034451518449458, 1.2044742022056079, 1.2054868146447175, 1.206483519236637, 1.2074648206166723, 1.2084311995896502, 1.209383114613034, 1.2103210031661629, 1.211245283015957, 1.2121563533883666, 1.2130545960538692, 1.213940376334491, 1.214814044039067, 1.215675934332809, 1.216526368546641, 1.2173656549312533, 1.2181940893603518, 1.2190119559871593, 1.2198195278578585, 1.2206170674853234, 1.2214048273861902, 1.2221830505840514, 1.2229519710813022, 1.223711814301965, 1.224462797507606, 1.2252051301882863, 1.2259390144303317, 1.2266646452625471, 1.2273822109823815, 1.2280918934634193, 1.2287938684454738, 1.2294883058084451, 1.2301753698310307, 1.2308552194352764, 1.2315280084178968, 1.2321938856692105, 1.2328529953804823, 1.2335054772403995, 1.2341514666213627, 1.2347910947562166, 1.2354244889060058, 1.2360517725192985, 1.2366730653835796, 1.2372884837691878], [0.0, 0.9830212756802801, 1.017687446101599, 1.0385298413648787, 1.0535761163826978, 1.065396872707848, 1.075153517127609, 1.0834723169407336, 1.0907303978880278, 1.097172826355132, 1.102968012284732, 1.1082367604253762, 1.1130687240269033, 1.1175323017151058, 1.1216808856818894, 1.1255569666467549, 1.1291949223010247, 1.1326229660286236, 1.1358645425173746, 1.1389393487782056, 1.1418640952374288, 1.1446530825663086, 1.147318645379992, 1.1498714981000402, 1.1523210078099315, 1.1546754118726066, 1.1569419932253686, 1.1591272228730958, 1.1612368766897903, 1.1632761319013842, 1.1652496473546847, 1.1671616307403883, 1.1690158952380403, 1.1708159075222564, 1.1725648286666182, 1.174265549171715, 1.175920719103371, 1.1775327741391077, 1.179103958172817, 1.180636343010128, 1.18213184559318, 1.1835922431181278, 1.1850191863478077, 1.1864142113724778, 1.1877787500311097, 1.189114139172479, 1.1904216289079088, 1.1917023899848, 1.192957520391168, 1.1941880512856033, 1.1953949523338054, 1.1965791365216545, 1.1977414645053526, 1.198882748551127, 1.2000037561101828, 1.2011052130687452, 1.2021878067080545, 1.2032521884048741, 1.2042989760993787, 1.2053287565541007, 1.2063420874248394, 1.2073394991620356, 1.2083214967590261, 1.20928856136176, 1.2102411517529694, 1.211179705722377, 1.2121046413333019, 1.2130163580949385, 1.213915238048624, 1.2148016467755747, 1.215675934332809, 1.216538436123333, 1.217389473706049, 1.218229355550347, 1.2190583777398496, 1.2198768246293819, 1.2206849694588482, 1.2214830749273708, 1.2222713937307426, 1.223050169064977, 1.2238196350984907, 1.2245800174152397, 1.2253315334309338, 1.2260743927842646, 1.2268087977049342, 1.227534943360117, 1.2282530181808562, 1.2289632041697724, 1.2296656771913634, 1.2303606072460564, 1.2310481587291016, 1.2317284906752974, 1.2324017569904748, 1.2330681066705875, 1.2337276840092015, 1.234380628794111, 1.235027076493761, 1.2356671584341035, 1.2363010019664733, 1.2369287306270227, 1.237550464288224, 1.2381663193029078], [0.0, 0.9837089547748096, 1.0183993761470242, 1.039256351847022, 1.0543131525869553, 1.06614217820109, 1.0759056479465752, 1.0842302672316324, 1.091493425617897, 1.097940360928835, 1.1037396009194318, 1.1090120348480037, 1.113847378681919, 1.1183140788956853, 1.1224655650320723, 1.1263443575352474, 1.1299848581456764, 1.1334152999841454, 1.1366591441393648, 1.1397361014014382, 1.142662893886568, 1.1454538322701489, 1.1481212597960897, 1.150675898381297, 1.1531271216620549, 1.1554831727638066, 1.157751339718682, 1.1599380980583944, 1.1620492276974972, 1.1640899094836854, 1.1660648055228933, 1.1679781264493356, 1.1698336881100933, 1.171634959604917, 1.1733851042187384, 1.175087014474216, 1.176743342291045, 1.1783565250506416, 1.1799288082166286, 1.1814622650439803, 1.1829588138158458, 1.1844202329716296, 1.1858481744289697, 1.187244175352707, 1.188609668583465, 1.1899459919052213, 1.1912543963038222, 1.1925360533456733, 1.193792061786894, 1.19502345350743, 1.1962311988513155, 1.197416211443117, 1.198579352541114, 1.1997214349797602, 1.2008432267471358, 1.2019454542372654, 1.2030288052121807, 1.2040939315043204, 1.2051414514861436, 1.2061719523306558, 1.2071859920837686, 1.2081841015670027, 1.2091667861269664, 1.210134527246198, 1.2110877840283736, 1.2120269945694746, 1.2129525772252796, 1.2138649317844619, 1.2147644405556188, 1.2156514693757106, 1.216526368546641, 1.217389473706049, 1.2182411066377865, 1.2190815760270342, 1.2199111781645429, 1.2207301976040594, 1.2215389077766352, 1.2223375715651652, 1.2231264418422174, 1.223905761973935, 1.224675766292548, 1.2254366805398218, 1.2261887222835608, 1.2269321013091103, 1.2276670199876438, 1.2283936736228664, 1.2291122507776393, 1.2298229335819042, 1.230525898023186, 1.231221314220837, 1.2319093466851112, 1.2325901545620608, 1.2332638918651826, 1.2339307076946617, 1.2345907464450052, 1.2352441480017968, 1.2358910479282499, 1.236531577642186, 1.2371658645840293, 1.237794032376353, 1.2384162009754867, 1.2390324868156566], [0.0, 0.984387619498822, 1.019101973930843, 1.039973338941407, 1.0550405274281114, 1.0668777139341084, 1.0766479195362388, 1.084978282009281, 1.0922464512774306, 1.0986978343547047, 1.1045010752640576, 1.1097771466657864, 1.114615826422662, 1.1190856082306875, 1.1232399584938868, 1.1271214269914513, 1.130764439197744, 1.134197247711694, 1.1374433298079096, 1.1405224098750475, 1.1434512215659642, 1.1462440854290465, 1.1489133532238565, 1.1514697542643937, 1.1539226686538513, 1.1562803452046373, 1.1585500769769244, 1.1607383439699208, 1.162850930085766, 1.1648930197464422, 1.1668692782742895, 1.1687839192084561, 1.1706407610285905, 1.1724432752277891, 1.1741946272733468, 1.175897711683485, 1.1775551822074684, 1.179169477908273, 1.1807428457986755, 1.182277360563997, 1.1837749418108179, 1.1852373692054952, 1.1866662958053313, 1.1880632598356633, 1.1894296951256373, 1.190766940382173, 1.1920762474541773, 1.1933587887163235, 1.1946156636827683, 1.1958479049453543, 1.1970564835175606, 1.1982423136542666, 1.1994062572079376, 1.200549127573805, 1.2016716932697866, 1.2027746811910494, 1.2038587795741154, 1.2049246407011243, 1.2059728833711527, 1.2070040951623, 1.2080188345054754, 1.2090176325884154, 1.210000995106369, 1.2109694038740515, 1.2119233183118758, 1.2128631768180682, 1.2137893980370322, 1.214702382033257, 1.2156025113790958, 1.216490152163902, 1.2173656549312533, 1.218229355550347, 1.2190815760270342, 1.2199226252594595, 1.2207527997427854, 1.2215723842270736, 1.222381652332017, 1.2231808671218742, 1.223970281643671, 1.22475013943145, 1.2255206749791077, 1.2262821141841498, 1.2270346747644816, 1.2277785666501801, 1.2285139923520358, 1.2292411473084943, 1.2299602202125066, 1.2306713933196676, 1.2313748427389157, 1.23207073870697, 1.2327592458475802, 1.2334405234165946, 1.234114725533764, 1.2347820014021382, 1.2354424955158432, 1.2360963478569702, 1.2367436940822576, 1.2373846657001935, 1.238019390239123, 1.2386479914069073, 1.2392705892426343, 1.2398873002608588], [0.0, 0.9850575091020549, 1.019795487139916, 1.0406810554075598, 1.0557584973276855, 1.0676037392053823, 1.0773805935696719, 1.0857166249713972, 1.0929897403308335, 1.0994455136649173, 1.1052527037612299, 1.110532365603663, 1.1153743381500842, 1.1198471617074193, 1.124004339064331, 1.127888448955733, 1.1315339402830074, 1.1349690848713732, 1.1382173759720546, 1.1412985513964313, 1.1442293561848462, 1.14702412063102, 1.1496952049000608, 1.152253345607417, 1.1547079292395739, 1.1570672102223722, 1.1593384865790144, 1.1615282427184392, 1.1636422664788126, 1.1656857458101892, 1.1676633492097264, 1.1695792930839444, 1.1714373985110211, 1.1732411393464532, 1.17499368321168, 1.1766979265946833, 1.1783565250506416, 1.1799719193023475, 1.1815463578917011, 1.1830819169158766, 1.1845805172877732, 1.186043939884836, 1.187473838889296, 1.1888717535732745, 1.1902391187416583, 1.191577274012376, 1.1928874720862352, 1.194170886135727, 1.1954286164232422, 1.1966616962433172, 1.1978710972702193, 1.1990577343809914, 1.2002224700146011, 1.2013661181198068, 1.2024894477375139, 1.2035931862575513, 1.2046780223847957, 1.2057446088452741, 1.206793564859165, 1.207825478404422, 1.208840908291975, 1.2098403860710412, 1.210824417781002, 1.2117934855644543, 1.2127480491544538, 1.2136885472475623, 1.2146153987730768, 1.215529004067736, 1.2164297459642395, 1.2173179908010687, 1.2181940893603518, 1.2190583777398496, 1.2199111781645429, 1.2207527997427854, 1.2215835391715089, 1.222403681394552, 1.2232135002178088, 1.2240132588845574, 1.2248032106140256, 1.2255835991059842, 1.2263546590139063, 1.2271166163890237, 1.227869689097402, 1.2286140872119786, 1.2293500133813553, 1.230077663176976, 1.230797225420201, 1.2315088824906515, 1.2322128106171113, 1.2329091801521472, 1.2335981558315385, 1.2342798970195088, 1.2349545579406895, 1.2356222878996659, 1.2362832314888936, 1.2369375287857236, 1.237585315539211, 1.2382267233473367, 1.2388618798252313, 1.2394909087649406, 1.2401139302872408, 1.2407310609859763], [0.0, 0.9857188533568146, 1.0204801536494528, 1.0413797439924104, 1.0564673085495377, 1.0683205030417668, 1.078103921354256, 1.0864455493698078, 1.0937235477264422, 1.1001836553136688, 1.1059947442197169, 1.1112779507019241, 1.1161231740339044, 1.12059900053892, 1.1247589689261377, 1.128645686516824, 1.1322936253405367, 1.1357310762035278, 1.1389815481298335, 1.1420647921823321, 1.144997564643589, 1.147794205428345, 1.1504670830000294, 1.1530269411824001, 1.1554831727638066, 1.1578440377119155, 1.1601168389496488, 1.162308065239424, 1.1644235083052243, 1.1664683595801708, 1.168447290695739, 1.170364520889245, 1.1722238738042476, 1.1740288256285079, 1.175782546110131, 1.1774879336817319, 1.1791476456813663, 1.1807641244704699, 1.1823396201005607, 1.183876210062655, 1.1853758165593078, 1.186840221663603, 1.1882710806683499, 1.189669933879101, 1.1910382170640372, 1.1923772707404745, 1.193688348450254, 1.1949726241535075, 1.1962311988513155, 1.197465106531944, 1.1986753195220192, 1.199862753312811, 1.2010282709223077, 1.202172686845734, 1.203296770640311, 1.20440125018422, 1.2054868146447175, 1.2065541171860554, 1.207603777444142, 1.2086363837916856, 1.209652495414788, 1.2106526442195362, 1.2116373365850546, 1.212607054977639, 1.213562259438999, 1.214503388960227, 1.2154308627518788, 1.2163450814194705, 1.2172464280527255, 1.2181352692360767, 1.2190119559871593, 1.2198768246293819, 1.2207301976040594, 1.2215723842270736, 1.222403681394552, 1.2232243742416369, 1.22403473675805, 1.2248350323638044, 1.2256255144481332, 1.2264064268744213, 1.2271780044536826, 1.227940473388915, 1.2286940516924534, 1.2294389495782736, 1.2301753698310307, 1.230903508153471, 1.2316235534937243, 1.2323356883538577, 1.2330400890809705, 1.2337369261420006, 1.2344263643833266, 1.2351085632761656, 1.2357836771486919, 1.23645185540573, 1.237113242736812, 1.2377679793133327, 1.2384162009754867, 1.2390580394096062, 1.2396936223164998, 1.2403230735713242, 1.240946513375502, 1.2415640584011558], [0.0, 0.9863718730540204, 1.0211562020365474, 1.0420696379543473, 1.0571671977315165, 1.0690282447361044, 1.0788181443742193, 1.0871652985571791, 1.0944481184471209, 1.1009125057308207, 1.1067274443710045, 1.1120141508754398, 1.1168625840742723, 1.1213413757278787, 1.1255041000137864, 1.1293933924797888, 1.1330437479924975, 1.1364834761002771, 1.1397361014014382, 1.142821388043556, 1.1457561034099104, 1.1485545969151576, 1.151229245216596, 1.1537907992555587, 1.1562486580429356, 1.158611087018463, 1.160885393943108, 1.1630780718779679, 1.1651949163839308, 1.1672411223333423, 1.1692213644525435, 1.1711398647740137, 1.1730004494744017, 1.1748065970443755, 1.1765614793319374, 1.1782679966898584, 1.1799288082166284, 1.181546357891701, 1.1831228972572094, 1.1846605051804684, 1.186161105137454, 1.18762648038184, 1.1890582873030349, 1.1904580672270135, 1.1918272568731256, 1.1931671976467544, 1.194479143920188, 1.1957642704312839, 1.1970236789105146, 1.1982584040311437, 1.1994694187639448, 1.2006576392066828, 1.201823928949079, 1.2029691030259457, 1.2040939315043204, 1.2051991427445896, 1.2062854263705702, 1.2073534359792226, 1.2084037916169517, 1.2094370820462514, 1.210453866823674, 1.2114546782076834, 1.2124400229128705, 1.213410383725156, 1.214366220991018, 1.215307973992372, 1.2162360622174933, 1.2171508865372902, 1.2180528302952764, 1.2189422603187403, 1.2198195278578585, 1.2206849694588482, 1.2215389077766352, 1.222381652332017, 1.2232135002178088, 1.22403473675805, 1.2248456361239748, 1.2256464619101068, 1.2264374676735452, 1.2272188974392293, 1.2279909861737308, 1.2287539602299025, 1.2295080377645087, 1.2302534291307876, 1.230990337247735, 1.231718957947747, 1.2324394803041276, 1.233152086939848, 1.2338569543188345, 1.2345542530209552, 1.2352441480017968, 1.235926798838223, 1.2366023599606473, 1.2372709808728721, 1.2379328063602832, 1.2385879766871373, 1.2392366277836193, 1.2398788914233019, 1.2405148953915925, 1.2411447636457127, 1.2417686164667165, 1.2423865706040194], [0.0, 0.9870167804671348, 1.0218238520604699, 1.042750961553344, 1.0578583923826854, 1.0697271943500308, 1.0795234947980459, 1.0878761064983558, 1.0951636880250228, 1.1016323018397038, 1.107451042389835, 1.1127412054366845, 1.1175928086270766, 1.1220745285940485, 1.1262399745428746, 1.1301318098972253, 1.1337845520770675, 1.1372265291400498, 1.1404812810652825, 1.1435685849224908, 1.1465052190577667, 1.1493055422676683, 1.1519819393015718, 1.1545451681299663, 1.1570046339089817, 1.1593686074824452, 1.1616444013892675, 1.1638385129358242, 1.1659567414722443, 1.1680042852673727, 1.1699858221039692, 1.171905576774953, 1.1737673779585953, 1.1755747064198625, 1.1773307360805678, 1.1790383691897837, 1.1807002665845663, 1.1823188738422858, 1.1838964439771744, 1.1854350572157462, 1.1869366382915805, 1.1884029716242734, 1.1898357146862109, 1.1912364098111137, 1.192606494657684, 1.1939473115083397, 1.1952601155554998, 1.1965460823050862, 1.1978063142079027, 1.1990418466136998, 1.2002536531293975, 1.201442650451721, 1.2026097027350224, 1.2037556255469977, 1.204881189458168, 1.205987123305135, 1.2070741171626034, 1.2081428250548674, 1.209193867433729, 1.2102278334466257, 1.211245283015957, 1.2122467487481876, 1.2132327376892076, 1.2142037329405908, 1.2151601951497986, 1.2161025638859566, 1.2170312589116088, 1.2179466813597604, 1.2188492148245618, 1.2197392263731393, 1.2206170674853234, 1.2214830749273708, 1.2223375715651652, 1.2231808671218742, 1.2240132588845574, 1.2248350323638044, 1.2256464619101068, 1.226447811290332, 1.2272393342273582, 1.2280212749056731, 1.2287938684454738, 1.2295573413476064, 1.23031191191147, 1.2310577906278357, 1.2317951805483711, 1.2325242776335108, 1.2332452710801787, 1.2339583436307477, 1.2346636718645194, 1.2353614264728907, 1.2360517725192985, 1.2367348696849407, 1.2374108725012007, 1.2380799305696286, 1.2387421887702736, 1.2393977874590998, 1.2400468626551655, 1.240689546218199, 1.2413259660171567, 1.2419562460903053, 1.2425805067973408, 1.243198864964011], [0.0, 0.9876537797864516, 1.0224833151122694, 1.0434239305097706, 1.0585411113487828, 1.0704175731846572, 1.0802201959534683, 1.0885781982490275, 1.0958704830234647, 1.1023432715418373, 1.1081657673814862, 1.1134593445853458, 1.1183140788956853, 1.1227986912679586, 1.1269668255056635, 1.1308611725665227, 1.1345162721473008, 1.1379604705879636, 1.141217323059815, 1.1443066193962745, 1.147245148771816, 1.1500472792498553, 1.152725403572618, 1.1552902866535553, 1.157751339718682, 1.1601168389496488, 1.1623941016047217, 1.1645896291834972, 1.1667092247788797, 1.1687580900145647, 1.1707409056922522, 1.172661899331451, 1.1745249020813788, 1.1763333969534127, 1.1780905599177465, 1.179799295096501, 1.18146226504398, 1.1830819169158764, 1.1846605051804684, 1.186200111406804, 1.1877026615706439, 1.1891699412432097, 1.190603608966585, 1.1920052080698789, 1.1933761771396274, 1.194717859324529, 1.196031510627076, 1.1973183073118372, 1.198579352541114, 1.1998156823328494, 1.201028270922308, 1.2022180355978314, 1.2033858410714784, 1.2045325034372947, 1.2056587937631111, 1.2067654413559046, 1.2078531367357392, 1.2089225343490024, 1.2099742550479222, 1.2110088883601589, 1.2120269945694746, 1.2130291066260661, 1.2140157319030598, 1.2149873538138136, 1.21594443330308, 1.2168874102236735, 1.2178167046090436, 1.2187327178510783, 1.2196358337914912, 1.2205264197343058, 1.2214048273861902, 1.2222713937307426, 1.2231264418422174, 1.223970281643671, 1.2248032106140256, 1.2256255144481332, 1.2264374676735452, 1.2272393342273582, 1.2280313679961983, 1.228813813322144, 1.229586905477134, 1.2303508711081934, 1.231105928655607, 1.2318522887459917, 1.2325901545620608, 1.2333197221907173, 1.2340411809509884, 1.2347547137031856, 1.2354604971405707, 1.236158702064701, 1.2368494936455416, 1.2375330316673459, 1.2382094707612277, 1.2388789606252872, 1.2395416462330762, 1.2401976680311408, 1.2408471621263237, 1.2414902604634528, 1.2421270909940076, 1.242757777836307, 1.2433824414277241, 1.2440011986694044], [0.0, 0.9882830675259884, 1.0231347946360152, 1.0440887524342621, 1.0592155652483177, 1.0710995942215589, 1.0809084627724952, 1.0892717904041989, 1.0965687214884012, 1.1030456341710697, 1.1088718398383124, 1.1141687898670432, 1.1190266173916676, 1.1235140871534839, 1.1276848771353638, 1.1315817054957524, 1.1352391339385266, 1.1386855268646412, 1.1419444544536763, 1.1450357191482265, 1.1479761208200587, 1.15078003668726, 1.1534598673881442, 1.1560263846950716, 1.1584890058304593, 1.1608560122491618, 1.1631347258716664, 1.1653316523400281, 1.1674525984446156, 1.1695027691233608, 1.1714868481603562, 1.1734090657686924, 1.1752732555386198, 1.1770829027007308, 1.1788411852488017, 1.1805510091553273, 1.1822150386710686, 1.183835722510934, 1.1854153165796457, 1.1869559037725324, 1.188459411292498, 1.1899276258484486, 1.191362207039214, 1.192764699177243, 1.1941365417656724, 1.1954790788089933, 1.1967935671099663, 1.1980811836826208, 1.1993430323921435, 1.2005801499165802, 1.2017935111119336, 1.2029840338509998, 1.204152583396792, 1.205299976363334, 1.2064269843097457, 1.2075343370076845, 1.208622725417183, 1.2096928044016113, 1.2107451952087762, 1.2117804877419585, 1.2127992426419065, 1.213801993198389, 1.2147892471078074, 1.2157614880915282, 1.216719177387997, 1.2176627551302823, 1.2185926416194597, 1.2195092385031654, 1.2204129298676796, 1.221304083251055, 1.2221830505840514, 1.223050169064977, 1.223905761973935, 1.22475013943145, 1.2255835991059842, 1.2264064268744213, 1.2272188974392293, 1.2280212749056731, 1.228813813322144, 1.229596757186404, 1.2303703419202963, 1.231134794315255, 1.2318903329507451, 1.2326371685875852, 1.2333755045379473, 1.234105537013672, 1.2348274554544119, 1.2355414428369886, 1.2362476759672447, 1.2369463257555648, 1.2376375574771525, 1.2383215310180682, 1.2389984011079498, 1.2396683175402783, 1.2403314253809758, 1.2409878651660748, 1.241637773089139, 1.2422812811790651, 1.242918517468858, 1.2435496061559186, 1.2441746677543575, 1.244793819239804], [0.0, 0.9889048329050317, 1.0237784865237978, 1.0447456272308093, 1.0598819568815, 1.0717734625362934, 1.081588502208716, 1.089957091518724, 1.0972586133717765, 1.1037396009194318, 1.109569472067845, 1.1148697546034767, 1.119730638366816, 1.1242209313615996, 1.128394345341501, 1.1322936253405367, 1.1359533548066276, 1.1394019159858213, 1.142662893886568, 1.1457561034099104, 1.148698354997035, 1.1515040349112684, 1.1541855515926234, 1.1567536835903804, 1.1592178540516787, 1.1615863496415424, 1.163866496886949, 1.1660648055228933, 1.1681870859930101, 1.1702385465098506, 1.172223873804248, 1.1741473007506769, 1.1760126633512407, 1.1778234490292188, 1.179582837777781, 1.1812937373976768, 1.1829588138158458, 1.1845805172877732, 1.1861611051374543, 1.187702661570644, 1.189207115002721, 1.190676253266676, 1.1921117370054535, 1.193515111503086, 1.1948878171683555, 1.1962311988513157, 1.197546514145428, 1.1988349408052255, 1.2000975833903762, 1.2013354792311393, 1.202549603796835, 1.2037408755377272, 1.204910160261198, 1.206058275095033, 1.2071859920837686, 1.2082940414581889, 1.2093831146130343, 1.210453866823674, 1.2115069197287647, 1.212542863602717, 1.2135622594389992, 1.2145656408628926, 1.2155535158902087, 1.216526368546641, 1.2174846603608176, 1.2184288317427105, 1.2193593032578227, 1.2202764768064815, 1.2211807367166103, 1.222072450757493, 1.2229519710813022, 1.2238196350984907, 1.224675766292548, 1.2255206749791077, 1.2263546590139063, 1.2271780044536826, 1.2279909861737308, 1.2287938684454738, 1.229586905477134, 1.2303703419202963, 1.2311444133449163, 1.2319093466851112, 1.232665360657862, 1.2334126661565847, 1.2341514666213629, 1.234881958387481, 1.2356043310137754, 1.236318767592185, 1.2370254450397873, 1.2377245343744931, 1.2384162009754869, 1.2391006048294189, 1.2397779007632737, 1.2404482386647726, 1.2411117636911038, 1.2417686164667168, 1.2424189332708588, 1.2430628462154918, 1.24370048341417, 1.2443319691424324, 1.244957423990209, 1.2455769650067228], [0.0, 0.9895192582062143, 1.0244145794864328, 1.0453947474750545, 1.0605404816140185, 1.0724393756864838, 1.0822605136289383, 1.0906343025019742, 1.0979403609288347, 1.1044253752367945, 1.110258868594562, 1.115562444296113, 1.120426348218593, 1.1249194311174544, 1.1290954381185, 1.1329971408140462, 1.1366591441393648, 1.14010984797493, 1.1433728519830049, 1.1464679833760052, 1.1494120630397633, 1.152219486176063, 1.1549026689345163, 1.1574723965613205, 1.1599380980583944, 1.162308065239424, 1.1645896291834972, 1.1667893036702297, 1.168912902753396, 1.1709656378815072, 1.1729521986973521, 1.17487682070537, 1.1767433422910447, 1.1785552530444583, 1.1803157349345705, 1.1820276975688024, 1.1836938085304842, 1.1853165195974913, 1.1868980894963377, 1.1884406037277344, 1.189945991905221, 1.1914160429726026, 1.1928524186046132, 1.194256665045399, 1.1956302235986955, 1.1969744399501372, 1.198290572474552, 1.1995797996582342, 1.2008432267471358, 1.202081891716029, 1.203296770640311, 1.204488782540897, 1.2056587937631111, 1.2068076219424362, 1.2079360396030943, 1.2090447774295756, 1.2101345272461979, 1.2112059447354646, 1.2122596519222686, 1.213296239447769, 1.2143162686539903, 1.215320273497765, 1.2163087623105446, 1.217282219418757, 1.2182411066377863, 1.2191858646512403, 1.2201169142859265, 1.2210346576918811, 1.2219394794358174, 1.2228317475155217, 1.223711814301965, 1.2245800174152397, 1.2254366805398218, 1.2262821141841498, 1.2271166163890237, 1.227940473388915, 1.2287539602299025, 1.2295573413476064, 1.2303508711081934, 1.231134794315255, 1.2319093466851112, 1.232674755292877, 1.2334312389914268, 1.234179008805209, 1.2349182683007078, 1.2356492139351947, 1.2363720353852825, 1.2370869158566686, 1.2377940323763528, 1.238493556068502, 1.2391856524150542, 1.2398704815020622, 1.2405481982527078, 1.24121895264784, 1.2418828899348366, 1.2425401508255187, 1.2431908716838076, 1.2438351847037477, 1.2444732180784936, 1.2451050961607983, 1.2457309396155172, 1.2463508655645976], [0.0, 0.9901265191118345, 1.0250432554016415, 1.0460362987696021, 1.061191327737498, 1.0730975240763216, 1.0829246891810287, 1.0913036169885242, 1.0986141590912912, 1.1051031532062419, 1.110940226537244, 1.1162470570053462, 1.1211139458709451, 1.1256097861427101, 1.1297883559294444, 1.1336924530720844, 1.1373567037427046, 1.1408095252505828, 1.1440745317409262, 1.1471715625939696, 1.1501174490184025, 1.1529265950502419, 1.1556114244588016, 1.1581827291091076, 1.1606499437895903, 1.163021365402562, 1.165304329526142, 1.167505353937406, 1.1696302562581715, 1.1716842511351784, 1.1736720310892161, 1.1755978342240223, 1.1774655012806712, 1.1792785239907808, 1.1810400862760626, 1.1827530995295432, 1.1844202329716296, 1.186043939884836, 1.18762648038184, 1.18916994124321, 1.1906762532666757, 1.1921472064939043, 1.1935844636193873, 1.1949895718361905, 1.1963639733325668, 1.1977090146199885, 1.199025954845539, 1.2003159732187414, 1.2015801756638291, 1.202819600792572, 1.2040352252793785, 1.2052279687091592, 1.206398697958909, 1.2075482311658872, 1.208677341328409, 1.2097867595793805, 1.2108771781676864, 1.2119492531782186, 1.213003607017602, 1.2140408306894677, 1.2150614858803321, 1.2160661068747127, 1.2170552023160208, 1.218029256827912, 1.2189887325091833, 1.2199340703138863, 1.2208656913270877, 1.2217839979456198, 1.2226893749722016, 1.2235821906304576, 1.224462797507606, 1.2253315334309338, 1.2261887222835608, 1.2270346747644816, 1.227869689097402, 1.2286940516924534, 1.2295080377645087, 1.23031191191147, 1.231105928655607, 1.2318903329507451, 1.232665360657862, 1.2334312389914268, 1.2341881869386229, 1.2349364156534022, 1.2356761288271765, 1.2364075230377818, 1.237130788078234, 1.2378461072666627, 1.2385536577387077, 1.2392536107235534, 1.2399461318046934, 1.240631381166424, 1.2413095138270018, 1.2419806798593187, 1.242645024599889, 1.2433026888468883, 1.243953809047923, 1.2445985174781644, 1.245236942409438, 1.2458692082708116, 1.2464954358011915, 1.247115742194402], [0.0, 0.9907267850199871, 1.0256646896413297, 1.0466704600780024, 1.0618346768083213, 1.0737480912991892, 1.0835812141396728, 1.091965221686588, 1.0992801958181004, 1.1057731238969137, 1.1116137359636795, 1.1169237837068966, 1.1217936231322556, 1.1262921890149316, 1.1304732920667984, 1.134379756075058, 1.1380462282039603, 1.1415011429908266, 1.1447681288969804, 1.1478670373303144, 1.1508147097034678, 1.153625558784929, 1.1563120158759435, 1.158884879384124, 1.1613535898177576, 1.1637264491091681, 1.1660107972836815, 1.168213156069787, 1.1703393466162455, 1.1723945867311856, 1.1743835717802453, 1.1763105424365201, 1.1781793417695399, 1.1799934636277913, 1.1817560938632437, 1.1834701456339607, 1.1851382897785687, 1.1867629810668885, 1.1883464809817956, 1.1898908775689723, 1.1913981027966976, 1.1928699477918545, 1.1943080762569462, 1.1957140363230268, 1.1970892710526781, 1.1984351277736978, 1.1997528663965291, 1.2010436668455928, 1.2023086357155912, 1.2035488122479538, 1.2047651737091998, 1.20595864024174, 1.2071300792481143, 1.20828030936158, 1.2094101040490832, 1.2105201948867808, 1.2116112745432346, 1.2126839995010892, 1.213738992544304, 1.214776845034808, 1.2157981189996403, 1.2168033490472299, 1.2177930441293534, 1.2187676891634707, 1.2197277465285268, 1.220673657445903, 1.2216058432559485, 1.2225247065994502, 1.2234306325124145, 1.2243239894417015, 1.2252051301882863, 1.2260743927842646, 1.2269321013091103, 1.2277785666501801, 1.2286140872119786, 1.2294389495782736, 1.2302534291307876, 1.2310577906278357, 1.2318522887459917, 1.2326371685875852, 1.2334126661565847, 1.234179008805209, 1.2349364156534022, 1.235685097983129, 1.2364252596092895, 1.2371570972288952, 1.2378808007500244, 1.2385965536019434, 1.239304533027681, 1.24000491036023, 1.2406978512834685, 1.2413835160788054, 1.242062059858477, 1.2427336327863574, 1.2433983802870714, 1.2440564432441534, 1.244707958187932, 1.24535305747377, 1.2459918694512582, 1.2466245186248994, 1.2472511258067984, 1.2478718082618285], [0.0, 0.9913202193419499, 1.0262790513794613, 1.0472974040389273, 1.0624707039663592, 1.0743912544599652, 1.0842302672316324, 1.0926192967057926, 1.0999386524254275, 1.1064354696959233, 1.112279580224338, 1.1175928086270766, 1.1224655650320723, 1.1269668255056635, 1.131150432991742, 1.135059236928481, 1.1387279052333978, 1.142184889475784, 1.1454538322701489, 1.1485545969151578, 1.1515040349112686, 1.1543165676600575, 1.1570046339089817, 1.1595790385337794, 1.1620492276974972, 1.1644235083052243, 1.1667092247788797, 1.168912902753396, 1.171040366864337, 1.1730968380452405, 1.1750870144742163, 1.1770151393644757, 1.1788850580875048, 1.1807002665845665, 1.1824639526159197, 1.184179031084578, 1.1858481744289697, 1.187473838889296, 1.1890582873030349, 1.190603608966585, 1.1921117370054533, 1.1935844636193873, 1.19502345350743, 1.196430255727948, 1.1978063142079025, 1.1991529770821248, 1.2004715050157309, 1.2017630786399027, 1.203028805212181, 1.2042697245964888, 1.2054868146447177, 1.206680996050433, 1.2078531367357395, 1.2090040558242463, 1.2101345272461979, 1.211245283015957, 1.2123370162169864, 1.213410383725156, 1.2144660086974666, 1.2155044828500658, 1.216526368546641, 1.2175322007158453, 1.2185224886143124, 1.2194977174499617, 1.2204583498786985, 1.2214048273861904, 1.2223375715651652, 1.223256985297587, 1.2241634538500943, 1.2250573458902427, 1.2259390144303317, 1.2268087977049342, 1.2276670199876438, 1.2285139923520358, 1.2293500133813553, 1.2301753698310307, 1.230990337247735, 1.2317951805483711, 1.2325901545620608, 1.2333755045379473, 1.2341514666213629, 1.2349182683007078, 1.2356761288271765, 1.2364252596092895, 1.2371658645840293, 1.2378981405662273, 1.238622277577714, 1.2393384591576284, 1.2400468626551655, 1.2407476595059446, 1.2414410154930868, 1.2421270909940076, 1.2428060412138544, 1.243478016406447, 1.2441431620835182, 1.2448016192129905, 1.2454535244069718, 1.246099010100105, 1.2467382047188607, 1.2473712328423185, 1.2479982153549483, 1.2486192695918636], [0.0, 0.9919069797821397, 1.0268865038818877, 1.047917297261938, 1.0630995782350208, 1.0750271844784427, 1.0848720209419425, 1.0932660158657435, 1.1005897038972794, 1.1070903666208256, 1.1129379362664853, 1.1182543095584088, 1.1231299501381014, 1.127633874898696, 1.131819958653615, 1.1357310762035278, 1.1394019159858213, 1.1428609464102142, 1.1461318240852318, 1.1492344240665857, 1.1521856078291028, 1.1549998053103583, 1.1576894626202783, 1.1602653910299856, 1.1627370422936916, 1.165112728233326, 1.1673997976179562, 1.1696047799450249, 1.1717335032976859, 1.1737911916997374, 1.175782546110131, 1.1777118122536276, 1.1795828377777806, 1.1813991206930938, 1.183163850646655, 1.1848799442668028, 1.1865500755737766, 1.188176702261621, 1.1897620885071831, 1.191308324843512, 1.1928173455403273, 1.1942909438581764, 1.1957307854814339, 1.1971384203853517, 1.1985152933515475, 1.1998627533128112, 1.201182061680444, 1.2024743997844414, 1.2037408755377272, 1.204982529419718, 1.2062003398610939, 1.2073952281003766, 1.2085680625733928, 1.209719662888589, 1.210850803434297, 1.211962216658158, 1.213054596053869, 1.214128598886104, 1.2151848486807084, 1.2162239375040658, 1.2172464280527255, 1.218252855571964, 1.2192437296198426, 1.2202195356914745, 1.22118073671661, 1.2221277744422312, 1.2230610707106062, 1.2239810286421633, 1.2248880337315802, 1.2257824548646261, 1.2266646452625471, 1.227534943360117, 1.2283936736228664, 1.2292411473084943, 1.230077663176976, 1.230903508153471, 1.231718957947747, 1.2325242776335108, 1.2333197221907173, 1.234105537013672, 1.234881958387481, 1.2356492139351947, 1.2364075230377818, 1.2371570972288952, 1.2378981405662273, 1.2386308499811032, 1.239355415607828, 1.2400720210941762, 1.240780843894316, 1.241482055545339, 1.2421758219284929, 1.2428623035161201, 1.2435416556052337, 1.2442140285385888, 1.2448795679140459, 1.245538414782966, 1.2461907058383181, 1.2468365735931324, 1.247476146549895, 1.2481095493614234, 1.2487369029837387, 1.2493583248214055], [0.0, 0.992487218601857, 1.0274872047793921, 1.0485303006061206, 1.063721462803927, 1.0756560463751728, 1.0855066418023722, 1.0939055469867183, 1.1012335191781464, 1.107737984613986, 1.1135889749301104, 1.1189084581569642, 1.1237869508548424, 1.1282935102898979, 1.1324820427908653, 1.1363954482390157, 1.1400684353635357, 1.1435294892273962, 1.1468022802775995, 1.1499066951962285, 1.1528596053216185, 1.1556754490324683, 1.1583666797193426, 1.1609441149776665, 1.1634172120906723, 1.165794287742481, 1.168082695000992, 1.1702889671832273, 1.172418935781613, 1.1744778278758594, 1.1764703471748528, 1.1784007418869882, 1.1802728619105893, 1.1820902073024013, 1.1838559695753699, 1.1855730670639817, 1.187244175352707, 1.1888717535732745, 1.1904580672270137, 1.1920052080698789, 1.1935151115030858, 1.1949895718361905, 1.196430255727948, 1.197838714060304, 1.1992163924600345, 1.2005646406490187, 1.2018847207764494, 1.2031778148633678, 1.2044450314707975, 1.2056874116868073, 1.2069059345144324, 1.208101521731095, 1.2092750422806327, 1.210427316250941, 1.211559118483348, 1.212671181853957, 1.2137642002621403, 1.2148388313570533, 1.2158956990292882, 1.2169353956915707, 1.2179584843696127, 1.2189655006217948, 1.2199569543042557, 1.2209333311961106, 1.2218950944979108, 1.2228426862150488, 1.2237765284365585, 1.2246970245186837, 1.2256045601816052, 1.2264995045268807, 1.2273822109823815, 1.2282530181808562, 1.2291122507776393, 1.2299602202125066, 1.230797225420201, 1.2316235534937243, 1.2324394803041276, 1.2332452710801787, 1.2340411809509884, 1.2348274554544119, 1.2356043310137754, 1.2363720353852825, 1.237130788078234, 1.2378808007500244, 1.238622277577714, 1.239355415607828, 1.2400804050858942, 1.2407974297671167, 1.2415066672094692, 1.2422082890503878, 1.2429024612681567, 1.2435893444289905, 1.2442690939207461, 1.2449418601741251, 1.2456077888721595, 1.2462670211487212, 1.2469196937767406, 1.2475659393467649, 1.24820588643645, 1.248839659771533, 1.2494673803787903, 1.250089165731465], [0.0, 0.9930610828679294, 1.0280813063251029, 1.049136569442771, 1.0643365152954014, 1.0762779995409466, 1.0861342906633744, 1.0945380521637205, 1.1018702614488909, 1.1083784878200995, 1.1142328612269081, 1.1195554202226794, 1.1244367337051269, 1.1289458988698828, 1.1331368532147637, 1.1370525214261047, 1.1407276323019648, 1.1441906873756122, 1.1474653707804965, 1.1505715806973438, 1.1535261982196352, 1.1563436700744594, 1.1590364568530334, 1.161615382405605, 1.1640899094836854, 1.1664683595801708, 1.1687580900145649, 1.1709656378815072, 1.1730968380452407, 1.175156920607816, 1.1771505919978424, 1.1790821028800644, 1.1809553053788484, 1.1827737015747009, 1.1845404848259267, 1.1862585751544177, 1.1879306496916886, 1.1895591689913587, 1.191146399864689, 1.192694435277104, 1.1942052117488844, 1.1956805246270708, 1.1971220415340942, 1.1985313142486325, 1.1999097892333355, 1.2012588169905025, 1.2025796603991112, 1.2038735021636575, 1.2051414514861436, 1.2063845500566042, 1.2076037774441422, 1.2088000559591587, 1.2099742550479222, 1.2111271952725093, 1.2122596519222686, 1.2133723582970573, 1.2144660086974666, 1.2155412611529102, 1.2165987399147182, 1.2176390377381552, 1.2186627179744787, 1.2196703164917333, 1.2206623434408612, 1.221639284881859, 1.222601604283104, 1.2235497439055603, 1.2244841260823167, 1.2254051544028413, 1.2263132148103413, 1.2272086766197918, 1.2280918934634193, 1.2289632041697724, 1.2298229335819042, 1.2306713933196676, 1.2315088824906515, 1.2323356883538577, 1.233152086939848, 1.2339583436307477, 1.2347547137031856, 1.2355414428369886, 1.236318767592185, 1.2370869158566686, 1.2378461072666627, 1.2385965536019434, 1.2393384591576284, 1.2400720210941762, 1.2407974297671167, 1.2415148690379023, 1.2422245165671726, 1.2429265440916057, 1.2436211176854557, 1.2443083980077776, 1.2449885405362755, 1.2456616957886313, 1.2463280095321112, 1.246987622982193, 1.2476406729908895, 1.2482872922254131, 1.2489276093377648, 1.2495617491257984, 1.2501898326862695, 1.2508119775603448], [0.0, 0.9936287146872871, 1.02866895563734, 1.049736253903215, 1.06494488801588, 1.0768931979910255, 1.0867551229506447, 1.0951636880250228, 1.1025000883870246, 1.1090120348480037, 1.1148697546034765, 1.1201953559638096, 1.1250794595957259, 1.1295912021906829, 1.1337845520770673, 1.1377024584768833, 1.141379670039105, 1.144844704588422, 1.1481212597960897, 1.151229245216596, 1.1541855515926234, 1.1570046339089815, 1.1596989598793381, 1.1622793595408327, 1.1647553010538676, 1.167135110667888, 1.1694261499078273, 1.1716349596049167, 1.1737673779585955, 1.1758286380604313, 1.1778234490292188, 1.179756063959374, 1.1816303371771304, 1.1834497727647775, 1.1852175659059372, 1.1869366382915805, 1.188609668583465, 1.1902391187416583, 1.1918272568731259, 1.1933761771396276, 1.1948878171683555, 1.1963639733325668, 1.1978063142079027, 1.1992163924600345, 1.2005956553784076, 1.2019454542372654, 1.2032670526374452, 1.2045616339594745, 1.2058303080393729, 1.2070741171626034, 1.2082940414581886, 1.209491003763721, 1.210665874022442, 1.211819473265461, 1.2129525772252794, 1.214065919620908, 1.2151601951497986, 1.216236062217493, 1.217294145432143, 1.2183350378878302, 1.2193593032578225, 1.2203674777164664, 1.2213600717063047, 1.2223375715651652, 1.223300441026343, 1.2242491226035976, 1.2251840388714228, 1.2261055936499772, 1.2270141731030728, 1.2279101467567843, 1.2287938684454738, 1.2296656771913634, 1.230525898023186, 1.2313748427389157, 1.2322128106171113, 1.2330400890809705, 1.2338569543188345, 1.2346636718645194, 1.2354604971405707, 1.2362476759672447, 1.2370254450397873, 1.2377940323763528, 1.2385536577387077, 1.239304533027681, 1.2400468626551655, 1.240780843894316, 1.2415066672094692, 1.2422245165671726, 1.242934569729616, 1.243636998531642, 1.2443319691424322, 1.2450196423128745, 1.2457001736095434, 1.2463737136361563, 1.2470404082433004, 1.247700398727171, 1.248353822018006, 1.2490008108588497, 1.2496414939752405, 1.2502759962363665, 1.2509044388082018, 1.2515269392990997], [0.0, 0.9941902514284112, 1.029250294928874, 1.0503294991127619, 1.065546728193256, 1.0775017906051478, 1.0873692889073256, 1.095782605976246, 1.1031231524124203, 1.1096387790178437, 1.1154998091897863, 1.1208284202465868, 1.1257152840680953, 1.1302295764174988, 1.1344252961227046, 1.1383454166779283, 1.1420247063699047, 1.1454916991398125, 1.148770106051347, 1.1518798479106307, 1.1548378250059352, 1.1576585004911235, 1.1603543491258341, 1.1629362070676654, 1.1654135478278314, 1.1677947023612523, 1.1700870363531344, 1.1722970943311768, 1.1744307177942042, 1.1764931427911995, 1.1784890811022566, 1.1804227882253748, 1.1822981206650107, 1.1841185844837419, 1.1858873766709082, 1.1876074205686373, 1.189281396352499, 1.190911767373906, 1.1925008030216167, 1.1940505986408794, 1.1955630929539116, 1.197040083349169, 1.1984832393452662, 1.1998941144853452, 1.2012741568767678, 1.2026247185574332, 1.2039470638422871, 1.2052423767806293, 1.2065117678356894, 1.207756279881965, 1.208976893602386, 1.2101745323560746, 1.2113500665779107, 1.212504317762998, 1.2136380620822338, 1.2147520336692812, 1.2158469276141908, 1.216923402694595, 1.217982083871634, 1.2190235645745695, 1.2200484087952226, 1.2210571530109513, 1.2220503079527691, 1.2230283602333512, 1.223991773848066, 1.2249409915607534, 1.2258764361847208, 1.2267985117683398, 1.2277076046936586, 1.2286040846955848, 1.2294883058084451, 1.2303606072460564, 1.231221314220837, 1.23207073870697, 1.2329091801521472, 1.2337369261420006, 1.2345542530209552, 1.2353614264728907, 1.236158702064701, 1.2369463257555648, 1.2377245343744931, 1.238493556068502, 1.2392536107235534, 1.24000491036023, 1.2407476595059446, 1.241482055545339, 1.2422082890503878, 1.2429265440916057, 1.243636998531642, 1.2443398243024497, 1.245035187667119, 1.245723249467384, 1.2464041653577356, 1.247078086027003, 1.247745157408199, 1.2484055208773708, 1.2490593134421406, 1.249706667920571, 1.2503477131109477, 1.2509825739530274, 1.2516113716812591, 1.2522342239704611], [0.0, 0.9947458259305311, 1.0298254617234994, 1.0509164454117152, 1.06614217820109, 1.0781039213542563, 1.0879769338228105, 1.0963949524309333, 1.1037396009194318, 1.110258868594562, 1.1161231740339044, 1.1214547628310625, 1.1263443575352472, 1.1308611725665225, 1.135059236928481, 1.1389815481298335, 1.142662893886568, 1.1461318240852318, 1.1494120630397633, 1.1525235426884515, 1.1554831727638066, 1.1583054245020068, 1.16100277963385, 1.163586080372408, 1.1660648055228933, 1.1684472906957388, 1.170740905692252, 1.1729521986973521, 1.175087014474216, 1.1771505919978422, 1.1791476456813665, 1.1810824334008498, 1.1829588138158458, 1.184780294948193, 1.1865500755737766, 1.1882710806683499, 1.189945991905221, 1.1915772740123758, 1.1931671976467544, 1.1947178593245287, 1.1962311988513155, 1.1977090146199882, 1.1991529770821245, 1.2005646406490185, 1.2019454542372652, 1.2032967706403113, 1.204619854879628, 1.2059158916661872, 1.2071859920837686, 1.2084311995896502, 1.209652495414788, 1.2108508034342973, 1.2120269945694746, 1.213181890774493, 1.2143162686539903, 1.2154308627518788, 1.2165263685466408, 1.2176034451840467, 1.2186627179744787, 1.219704780678819, 1.2207301976040594, 1.2217395055273528, 1.2227332154651198, 1.2237118143019652, 1.2246757662925476, 1.2256255144481332, 1.2265614818183057, 1.227484072677228, 1.2283936736228664, 1.2292906545967444, 1.2301753698310307, 1.2310481587291016, 1.2319093466851112, 1.2327592458475802, 1.2335981558315385, 1.2344263643833266, 1.2352441480017968, 1.2360517725192985, 1.2368494936455416, 1.2376375574771525, 1.2384162009754869, 1.2391856524150542, 1.2399461318046934, 1.2406978512834685, 1.2414410154930868, 1.2421758219284929, 1.2429024612681567, 1.2436211176854557, 1.2443319691424322, 1.245035187667119, 1.2457309396155172, 1.2464193859192427, 1.2471006823197694, 1.247774979590135, 1.248442423744902, 1.2491031562391222, 1.2497573141569804, 1.2504050303907603, 1.2510464338107234, 1.2516816494264449, 1.2523107985401225, 1.2529339988923338], [0.0, 0.9952955667013749, 1.0303945890607595, 1.0514972285642885, 1.0667313757705545, 1.0786997295148189, 1.0885781982490277, 1.0970008690285074, 1.1043495764963112, 1.1108724470086122, 1.1167399933238733, 1.1220745285940488, 1.1269668255056635, 1.1314861367297475, 1.1356865211287226, 1.139610999973635, 1.143294380205711, 1.1467652274894349, 1.1500472792498555, 1.1531604784405372, 1.15612174413906, 1.158945555579051, 1.1616444013892673, 1.1642291297746699, 1.1667092247788797, 1.1690930266189599, 1.1713879091690966, 1.1736004242330276, 1.1757364198040061, 1.1778011377523205, 1.1797992950965015, 1.1817351520657013, 1.1836125694519402, 1.1854350572157462, 1.1872058159007899, 1.1889277720992961, 1.190603608966585, 1.1922357925927605, 1.1938265948896292, 1.1953781135319907, 1.1968922893974845, 1.1983709218728564, 1.1998156823328494, 1.2012281260477944, 1.2026097027350224, 1.2039617659355937, 1.205285581370087, 1.2065823344041975, 1.2078531367357395, 1.209099032398652, 1.2103210031661629, 1.2115199734239617, 1.212696814574655, 1.2138523490266642, 1.2149873538138134, 1.2161025638859566, 1.217198675105928, 1.2182763469837716, 1.219336205175444, 1.2203788437699659, 1.2214048273861904, 1.222414693097917, 1.223408952203977, 1.2243880918580492, 1.22535257657136, 1.226302849600003, 1.2272393342273584, 1.2281624349510087, 1.2290725385825716, 1.2299700152680164, 1.2308552194352764, 1.2317284906752974, 1.2325901545620608, 1.2334405234165946, 1.2342798970195088, 1.2351085632761656, 1.235926798838223, 1.2367348696849407, 1.2375330316673459, 1.2383215310180682, 1.2391006048294189, 1.2398704815020622, 1.240631381166424, 1.2413835160788054, 1.2421270909940076, 1.2428623035161201, 1.2435893444289905, 1.2443083980077776, 1.2450196423128745, 1.245723249467384, 1.2464193859192427, 1.2471082126890045, 1.2477898856042136, 1.2484645555212304, 1.2491323685353128, 1.2497934661796861, 1.2504479856142943, 1.2510960598048633, 1.2517378176928737, 1.2523733843569866, 1.253002881166437, 1.2536264259268712], [0.0, 0.9958395981042191, 1.0309578056895923, 1.0520719799562177, 1.0673144541909094, 1.0792893498715541, 1.089173218205021, 1.0976004928404337, 1.1049532171327532, 1.1114796530647288, 1.1173504065975843, 1.1226878577399928, 1.127582828795089, 1.1321046102876113, 1.13630729062871, 1.1402339146049814, 1.1439193081832248, 1.1473920526419992, 1.150675898381297, 1.1537907992555587, 1.1567536835903804, 1.1595790385337792, 1.1622793595408327, 1.164865500746162, 1.167346951377393, 1.1697320562103755, 1.1720281931498764, 1.174241917580868, 1.1763790806931336, 1.1784449272221829, 1.180444176764882, 1.1823810918790367, 1.1842595354669876, 1.1860830194078167, 1.1878547459946212, 1.1895776434193093, 1.1912543963038222, 1.192887472086235, 1.194479143920188, 1.1960315106270762, 1.197546514145428, 1.199025954845539, 1.2004715050157309, 1.2018847207764494, 1.2032670526374452, 1.2046198548796283, 1.2059443939154235, 1.2072418557584506, 1.208513352714181, 1.2097599293872254, 1.2109825680874522, 1.2121821937058224, 1.213359678121254, 1.2145158441916988, 1.2156514693757103, 1.216767289024868, 1.2178639993823666, 1.21894226031874, 1.2200026978319307, 1.22104590633569, 1.222072450757493, 1.2230828684647053, 1.2240776710356358, 1.2250573458902427, 1.2260223577936558, 1.2269731502442538, 1.2279101467567843, 1.2288337520499297, 1.22974435314674, 1.2306423203955075, 1.2315280084178968, 1.2324017569904748, 1.2332638918651826, 1.234114725533764, 1.2349545579406895, 1.2357836771486919, 1.2366023599606473, 1.2374108725012007, 1.2382094707612277, 1.2389984011079498, 1.2397779007632737, 1.2405481982527078, 1.2413095138270018, 1.242062059858477, 1.2428060412138544, 1.2435416556052337, 1.2442690939207461, 1.2449885405362755, 1.2457001736095434, 1.2464041653577356, 1.2471006823197694, 1.2477898856042136, 1.248471931123787, 1.2491469698173099, 1.2498151478598953, 1.2504766068621316, 1.2511314840589343, 1.251779912488709, 1.252422021163416, 1.2530579352300852, 1.253687776124292, 1.254311661716075], [0.0, 0.9963780405349252, 1.0315152362516102, 1.0526408267817946, 1.0678915424992437, 1.0798729129093028, 1.0897621253705794, 1.0981939565653491, 1.1055506564163307, 1.1120806211395229, 1.1179545489414158, 1.1232948860005645, 1.1281925037269904, 1.1327167301102588, 1.1369216828066873, 1.1408504298768407, 1.1445378161176376, 1.1480124382613033, 1.15129805954948, 1.154414644625496, 1.1573791309679564, 1.1602060135579624, 1.1629077946067832, 1.1654953341177827, 1.1679781264493359, 1.170364520889245, 1.1726618993314513, 1.1748768207053701, 1.1770151393644759, 1.1790821028800647, 1.1810824334008503, 1.1830203957893695, 1.1848998550366026, 1.1867243249204764, 1.1884970094655423, 1.1902208384469581, 1.1918984979382181, 1.1935324567115217, 1.195124989149585, 1.1966781952086183, 1.1981940178771409, 1.1996742584988942, 1.2011205902663922, 1.202534570141463, 1.2039176494181356, 1.205271183109569, 1.206596438312927, 1.2078946016830976, 1.2091667861269666, 1.2104140368139538, 1.2116373365850546, 1.2128376108313115, 1.2140157319030598, 1.2151725231031647, 1.2163087623105446, 1.2174251852743778, 1.2185224886143122, 1.219601332557669, 1.2206623434408614, 1.2217061159990361, 1.22273321546512, 1.223744179497029, 1.224739519949678, 1.2257197245065694, 1.2266852581841274, 1.2276365647205272, 1.2285740678595072, 1.2294981725385778, 1.2304092659900494, 1.2313077187624584, 1.2321938856692105, 1.2330681066705875, 1.2339307076946617, 1.2347820014021382, 1.2356222878996659, 1.23645185540573, 1.2372709808728721, 1.2380799305696286, 1.2388789606252872, 1.2396683175402783, 1.2404482386647726, 1.24121895264784, 1.2419806798593187, 1.2427336327863574, 1.243478016406447, 1.2442140285385888, 1.2449418601741251, 1.2456616957886313, 1.2463737136361563, 1.247078086027003, 1.247774979590135, 1.2484645555212304, 1.2491469698173099, 1.2498223734988043, 1.250490912819863, 1.2511527294676412, 1.251807960751257, 1.2524567397810487, 1.253099195638732, 1.2537354535390028, 1.254365634983096, 1.2549898579047816], [0.0, 0.9969110105895995, 1.0320670014546725, 1.053203892220994, 1.0684627656601702, 1.0804505449947366, 1.0903450472696097, 1.0987813887138531, 1.1061420237185238, 1.112675481368611, 1.1185525511783507, 1.1238957448236733, 1.1287959823223956, 1.1333226287481424, 1.1375298307051702, 1.1414606792914708, 1.1451500379427049, 1.148626518687703, 1.1519138974792433, 1.1550321496398905, 1.1579982217082339, 1.1608266164188479, 1.1635298426705283, 1.1661187662757355, 1.168602886671448, 1.1709905576115642, 1.1732891649386556, 1.175505271090558, 1.1776447335522833, 1.1797128027020922, 1.1817142032146115, 1.1836532022336848, 1.1855336668177048, 1.1873591126241443, 1.1891327453914113, 1.1908574964618226, 1.192536053345673, 1.1941708861357268, 1.1957642704312839, 1.1973183073118374, 1.1988349408052252, 1.2003159732187412, 1.2017630786399027, 1.2031778148633678, 1.2045616339594742, 1.2059158916661874, 1.2072418557584503, 1.208540713525902, 1.2098135784707305, 1.2110614963214243, 1.2122854504447083, 1.213486366726623, 1.2146651179841306, 1.215822527960487, 1.2169593749507044, 1.218076395097518, 1.2191742853932035, 1.2202537064182422, 1.2213152848440794, 1.2223596157239904, 1.2233872645932489, 1.2243987693973681, 1.2253946422650583, 1.2263753711406873, 1.22734142128942, 1.22829323668679, 1.2292312413032003, 1.2301558402927648, 1.2310674210949275, 1.231966354456434, 1.2328529953804823, 1.2337276840092015, 1.2345907464450052, 1.2354424955158432, 1.2362832314888936, 1.237113242736812, 1.2379328063602832, 1.2387421887702736, 1.2395416462330762, 1.2403314253809758, 1.2411117636911038, 1.2418828899348366, 1.242645024599889, 1.2433983802870714, 1.2441431620835182, 1.2448795679140459, 1.2456077888721595, 1.2463280095321112, 1.2470404082433004, 1.247745157408199, 1.248442423744902, 1.2491323685353128, 1.2498151478598953, 1.250490912819863, 1.2511598097475969, 1.2518219804060424, 1.252477562177765, 1.2531266882443046, 1.253769487756424, 1.2544060859957973, 1.2550366045286507, 1.2556611613518387], [0.0, 0.9974386212234697, 1.032613218237364, 1.0537612956073208, 1.0690282447361041, 1.081022368548549, 1.0909221074439044, 1.0993629137836196, 1.1067274443710045, 1.1132643598239402, 1.119144540046239, 1.1244905615525804, 1.1293933924797888, 1.1339224346126393, 1.138131863212234, 1.1420647921823321, 1.1457561034099104, 1.1492344240665857, 1.1525235426884515, 1.1556434451699213, 1.1586110870184632, 1.1614409786441582, 1.1641456355660798, 1.166735929347371, 1.1692213644525435, 1.1716102990566828, 1.1739101229112836, 1.1761274019273225, 1.1782679966898584, 1.1803371603558914, 1.1823396201005607, 1.1842796453260764, 1.186161105137454, 1.187987517052813, 1.1897620885071831, 1.191487752394281, 1.1931671976467542, 1.1948028956646521, 1.1963971232516257, 1.1979519825991545, 1.1994694187639448, 1.200951235007153, 1.2023991063022994, 1.2038145912684985, 1.2051991427445896, 1.2065541171860557, 1.2078807830388048, 1.2091803282208426, 1.210453866823674, 1.2117024451292342, 1.2129270470246902, 1.214128598886104, 1.215307973992372, 1.2164659965227125, 1.2176034451840465, 1.21872105650871, 1.2198195278578585, 1.220899520161582, 1.2219616604229897, 1.2230065440102853, 1.2240347367580502, 1.2250467768965023, 1.226043176825394, 1.2270244247473352, 1.2279909861737306, 1.2289433053150858, 1.2298818063661876, 1.2308068946955766, 1.231718957947747, 1.2326183670656607, 1.2335054772403995, 1.234380628794111, 1.2352441480017968, 1.2360963478569702, 1.2369375287857236, 1.2377679793133327, 1.2385879766871373, 1.2393977874590998, 1.2401976680311408, 1.2409878651660748, 1.2417686164667168, 1.2425401508255187, 1.2433026888468883, 1.2440564432441534, 1.2448016192129905, 1.245538414782966, 1.2462670211487212, 1.246987622982193, 1.247700398727171, 1.2484055208773708, 1.2491031562391222, 1.2497934661796861, 1.2504766068621316, 1.2511527294676412, 1.2518219804060424, 1.2524845015153079, 1.2531404302507116, 1.2537898998642798, 1.2544330395751275, 1.2550699747312335, 1.2557008269631629, 1.2563257143302187], [0.0, 0.9979609819015223, 1.033153999924946, 1.0543131525869553, 1.0695880970487135, 1.081588502208716, 1.091493425617897, 1.0999386524254275, 1.1073070398327802, 1.113847378681919, 1.1197306383668157, 1.125079459595726, 1.1299848581456764, 1.1345162721473008, 1.1387279052333976, 1.142662893886568, 1.1463561382615046, 1.1498362805219338, 1.1531271216620549, 1.1562486580429356, 1.1592178540516787, 1.162049227697497, 1.1647553010538674, 1.1673469513773929, 1.1698336881100935, 1.1722238738042476, 1.174524902081379, 1.1767433422910447, 1.1788850580875048, 1.1809553053788484, 1.1829588138158458, 1.1848998550366023, 1.186782300172392, 1.1886096685834653, 1.1903851693845926, 1.1921117370054533, 1.193792061786894, 1.195428616423242, 1.1970236789105146, 1.198579352541114, 1.200097583390376, 1.2015801756638291, 1.2030288052121807, 1.2044450314707973, 1.2058303080393726, 1.2071859920837686, 1.208513352714181, 1.2098135784707305, 1.2110877840283736, 1.2123370162169864, 1.213562259438999, 1.2147644405556188, 1.21594443330308, 1.2171030622922254, 1.2182411066377865, 1.2193593032578225, 1.2204583498786983, 1.221538907776635, 1.222601604283104, 1.223647035078105, 1.2246757662925478, 1.2256883364385232, 1.2266852581841274, 1.2276670199876438, 1.228634087604266, 1.229586905477134, 1.230525898023186, 1.2314514708232551, 1.2323640117248453, 1.2332638918651826, 1.2341514666213627, 1.235027076493761, 1.2358910479282499, 1.2367436940822576, 1.237585315539211, 1.2384162009754867, 1.2392366277836193, 1.2400468626551655, 1.2408471621263237, 1.241637773089139, 1.2424189332708588, 1.2431908716838076, 1.243953809047923, 1.244707958187932, 1.2454535244069718, 1.2461907058383181, 1.2469196937767406, 1.2476406729908895, 1.248353822018006, 1.2490593134421406, 1.2497573141569804, 1.2504479856142943, 1.2511314840589343, 1.251807960751257, 1.252477562177765, 1.2531404302507116, 1.2537967024973566, 1.2544465122395108, 1.2550899887639613, 1.2557272574843314, 1.2563584400948853, 1.2569836547167534], [0.0, 0.9984781987414115, 1.0336894563773034, 1.0548595752697296, 1.0701424363320837, 1.0821490609853797, 1.0920591178549646, 1.1005087216006728, 1.107880927848761, 1.1144246563829199, 1.1203109652060472, 1.1256625585878406, 1.1305704994764016, 1.1351042619903153, 1.1393180778546923, 1.1432551059086338, 1.146950264394662, 1.150432210320981, 1.1537247570172169, 1.1568479112080239, 1.1598186460726987, 1.1626514871447553, 1.1653589629875307, 1.1679519564950231, 1.1704399820377451, 1.1728314065020657, 1.175133627341427, 1.177353217310107, 1.1794960431013426, 1.1815673633472217, 1.1835719101497677, 1.1855139573609634, 1.1873973781183875, 1.1892256936062824, 1.1910021146026182, 1.192729577057911, 1.1944107727073408, 1.1960481755267667, 1.1976440646928315, 1.199200544588018, 1.2007195622962619, 1.2022029229581634, 1.2036523032929796, 1.2050692635442906, 1.2064552580651526, 1.2078116447248113, 1.209139693291208, 1.2104405929204531, 1.2117154588652095, 1.2129653384978973, 1.2141912167311368, 1.2153940209065026, 1.216574625213064, 1.2177338546890373, 1.2188724888529485, 1.2199912650047826, 1.2210908812325174, 1.2221719991550957, 1.2232352464291185, 1.2242812190433108, 1.225310483421993, 1.2263235783563524, 1.2273210167801878, 1.2283032874049373, 1.2292708562271837, 1.2302241679204093, 1.2311636471215173, 1.2320896996215418, 1.2330027134689987, 1.2339030599934642, 1.2347910947562166, 1.2356671584341035, 1.236531577642186, 1.2373846657001935, 1.2382267233473367, 1.2390580394096062, 1.2398788914233019, 1.240689546218199, 1.2414902604634528, 1.2422812811790651, 1.2430628462154918, 1.2438351847037477, 1.2445985174781644, 1.24535305747377, 1.246099010100105, 1.2468365735931324, 1.2475659393467649, 1.2482872922254131, 1.2490008108588497, 1.249706667920571, 1.2504050303907603, 1.2510960598048633, 1.251779912488709, 1.2524567397810487, 1.2531266882443046, 1.2537898998642798, 1.2544465122395108, 1.2550966587609051, 1.2557404687822564, 1.2563780677821863, 1.2570095775180297, 1.2576351161721364], [0.0, 0.9989903746491102, 1.0342196941293802, 1.0554006723724398, 1.0706913728781056, 1.0827041564078677, 1.0926192967057926, 1.101073234730881, 1.1084492226002718, 1.114996307782684, 1.120885636026334, 1.1262399745428746, 1.131150432991742, 1.1356865211287224, 1.1399024984974446, 1.143841546075618, 1.1475386000173047, 1.1510223320305082, 1.1543165676600577, 1.1574413238931873, 1.1604135826156967, 1.163247876812067, 1.165956741472244, 1.168551065072677, 1.171040366864337, 1.173433018025442, 1.175736419804006, 1.1779571483258444, 1.180101073293553, 1.1821734560366688, 1.1841790310845781, 1.1861220744815637, 1.1880064613519556, 1.1898357146862109, 1.191613046909289, 1.1933413954777208, 1.1950234535074298, 1.196661696243317, 1.1982584040311437, 1.1998156823328494, 1.201335479231139, 1.202819600792572, 1.2042697245964888, 1.2056874116868073, 1.2070741171626034, 1.2084311995896502, 1.2097599293872254, 1.2110614963214246, 1.2123370162169864, 1.213587536983588, 1.214814044039067, 1.2160174652006834, 1.217198675105928, 1.2183584992162255, 1.2194977174499615, 1.2206170674853234, 1.2217172477683778, 1.2227989202574494, 1.2238627129311, 1.22490922208377, 1.225939014430332, 1.2269526290383488, 1.2279505791047327, 1.2289333535916092, 1.2299014187345967, 1.2308552194352764, 1.2317951805483711, 1.2327217080730686, 1.2336351902569365, 1.234535998620027, 1.2354244889060058, 1.2363010019664733, 1.2371658645840293, 1.238019390239123, 1.2388618798252313, 1.2396936223164998, 1.2405148953915925, 1.2413259660171567, 1.2421270909940076, 1.242918517468858, 1.24370048341417, 1.2444732180784936, 1.245236942409438, 1.2459918694512582, 1.2467382047188607, 1.247476146549895, 1.24820588643645, 1.2489276093377648, 1.2496414939752405, 1.2503477131109477, 1.2510464338107234, 1.2517378176928737, 1.252422021163416, 1.253099195638732, 1.253769487756424, 1.2544330395751275, 1.2550899887639613, 1.2557404687822564, 1.2563846090501591, 1.257022535110657, 1.2576543687835402, 1.2582802283117815], [0.0, 0.9994976094477416, 1.034744816524555, 1.0559365493549526, 1.0712350136745536, 1.08325389666432, 1.0931740713492821, 1.1016323018397038, 1.1090120348480037, 1.1155624442961132, 1.1214547628310625, 1.126811819999242, 1.131724771720783, 1.1362631630448725, 1.1404812810652825, 1.1444223286847532, 1.1481212597960897, 1.1516067606652813, 1.1549026689345165, 1.1580290117546033, 1.16100277963385, 1.163838512935824, 1.1665487530150793, 1.1691443938766615, 1.171634959604917, 1.1740288256285076, 1.1763333969534127, 1.1785552530444583, 1.1807002665845665, 1.1827737015747009, 1.184780294948193, 1.1867243249204762, 1.188609668583465, 1.1904398507164056, 1.1922180853753581, 1.1939473115083394, 1.1956302235986958, 1.1972692981481272, 1.198866816660235, 1.2004248856660014, 1.2019454542372652, 1.2034303293576116, 1.204881189458168, 1.2062995963754677, 1.2076870059474099, 1.2090447774295758, 1.2103741818862954, 1.2116764096877646, 1.2129525772252796, 1.2142037329405908, 1.2154308627518788, 1.2166348949475014, 1.2178167046090436, 1.2189771176170563, 1.2201169142859265, 1.2212368326683958, 1.222337571565165, 1.2234197932706667, 1.2244841260823167, 1.2255311665973232, 1.2265614818183057, 1.2275756110865383, 1.228574067859507, 1.2295573413476066, 1.230525898023186, 1.2314801830137232, 1.2324206213896605, 1.2333476193563306, 1.2342615653584328, 1.2351628311046574, 1.2360517725192985, 1.2369287306270227, 1.237794032376353, 1.2386479914069073, 1.2394909087649406, 1.2403230735713242, 1.2411447636457127, 1.2419562460903053, 1.242757777836307, 1.2435496061559186, 1.2443319691424324, 1.2451050961607983, 1.2458692082708116, 1.2466245186248994, 1.2473712328423185, 1.2481095493614234, 1.248839659771533, 1.2495617491257984, 1.2502759962363665, 1.2509825739530274, 1.2516816494264449, 1.2523733843569866, 1.2530579352300852, 1.2537354535390028, 1.2544060859957973, 1.2550699747312335, 1.2557272574843314, 1.2563780677821863, 1.257022535110657, 1.2576607850764747, 1.2582929395612836, 1.258919116868094], [0.0, 1.0, 1.0352649238413774, 1.0564673085495377, 1.0717734625362931, 1.0837983867343681, 1.0937235477264424, 1.1021860296878503, 1.1095694720678448, 1.1161231740339044, 1.1220184543019633, 1.127378204157833, 1.1322936253405365, 1.1368342978555983, 1.1410545360838225, 1.144997564643589, 1.1486983549970349, 1.1521856078291028, 1.1554831727638066, 1.1586110870184632, 1.1615863496415422, 1.1644235083052241, 1.167135110667888, 1.1697320562103752, 1.1722238738042479, 1.174618943088019, 1.176924672789742, 1.1791476456813663, 1.181293737397677, 1.1833682145855515, 1.185375816559308, 1.187320823684795, 1.1892071150027208, 1.1910382170640372, 1.1928173455403275, 1.1945474408568504, 1.1962311988513155, 1.1978710972702191, 1.1994694187639448, 1.201028270922308, 1.2025496037968348, 1.2040352252793782, 1.2054868146447175, 1.2069059345144324, 1.2082940414581886, 1.209652495414788, 1.210982568087452, 1.2122854504447083, 1.2135622594389992, 1.214814044039067, 1.2160417906586571, 1.2172464280527255, 1.2184288317427103, 1.219589828024286, 1.2207301976040592, 1.2218506789057486, 1.2229519710813022, 1.22403473675805, 1.2250996045492177, 1.2261471713518888, 1.2271780044536826, 1.2281926434669694, 1.229191602107321, 1.2301753698310307, 1.231144413344916, 1.2320991780001957, 1.2330400890809705, 1.2339675529967495, 1.234881958387481, 1.235783677148692, 1.2366730653835796, 1.237550464288224, 1.2384162009754867, 1.2392705892426343, 1.2401139302872408, 1.240946513375502, 1.2417686164667165, 1.2425805067973408, 1.2433824414277241, 1.2441746677543575, 1.244957423990209, 1.2457309396155172, 1.2464954358011915, 1.2472511258067984, 1.2479982153549483, 1.2487369029837387, 1.2494673803787903, 1.2501898326862695, 1.2509044388082018, 1.2516113716812591, 1.2523107985401225, 1.253002881166437, 1.253687776124292, 1.254365634983096, 1.2550366045286507, 1.2557008269631629, 1.2563584400948853, 1.2570095775180297, 1.2576543687835402, 1.2582929395612836, 1.258925411794167, 1.2595519038446648], [0.0, 1.0004976403245405, 1.0357801134140634, 1.0569930492838309, 1.0723068202300237, 1.084337728515279, 1.0942678286676906, 1.1027345219013682, 1.110121638580025, 1.116678601932458, 1.1225768159297027, 1.12793923301323, 1.1328571003077261, 1.1374000324445321, 1.1416223708334778, 1.1455673616032565, 1.149269993619215, 1.152758981848914, 1.1560581877849019, 1.1591876586158232, 1.1621644018495598, 1.1650029723977997, 1.1677159241631434, 1.1703141620504534, 1.172807219673242, 1.1752034808400686, 1.177510357965869, 1.1797344370984446, 1.1818815967965333, 1.1839571063279088, 1.185965707365363, 1.1879116824048275, 1.189798912417377, 1.1916309257089173, 1.1934109395512797, 1.1951418958329976, 1.1968264917333373, 1.1984672062318225, 1.200066323114775, 1.201625951020832, 1.2031480409719444, 1.2046344017596446, 1.2060867134943867, 1.2075065395753741, 1.2088953372971203, 1.2102544672751876, 1.211585201845648, 1.2128887325697033, 1.2141661769556367, 1.215418584494199, 1.2166469420900154, 1.2178521789602275, 1.2190351710619685, 1.2201967451021105, 1.2213376821757715, 1.2224587210741393, 1.2235605612970886, 1.2246438658016991, 1.22570926351402, 1.226757351628175, 1.227788697714088, 1.2288038416526625, 1.2298032974151163, 1.2307875547013152, 1.2317570804503293, 1.232712320235002, 1.2336536995510723, 1.2345816250102954, 1.2354964854460222, 1.2363986529388502, 1.2372884837691878, 1.2381663193029078, 1.2390324868156566, 1.2398873002608588, 1.2407310609859763, 1.2415640584011558, 1.2423865706040194, 1.243198864964011, 1.2440011986694044, 1.244793819239804, 1.2455769650067228, 1.2463508655645976, 1.247115742194402, 1.2478718082618285, 1.2486192695918636, 1.2493583248214055, 1.250089165731465, 1.2508119775603448, 1.2515269392990997, 1.2522342239704611, 1.2529339988923338, 1.2536264259268712, 1.254311661716075, 1.2549898579047816, 1.2556611613518387, 1.2563257143302187, 1.2569836547167534, 1.2576351161721364, 1.2582802283117815, 1.258919116868094, 1.2595519038446648, 1.2601787076628697]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 0.2\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.6309573444801932, 0.6762433378062415, 0.7042261140012369, 0.7247796636776955, 0.7411344491069477, 0.754770860611584, 0.7664958432641342, 0.7767996097157338, 0.7860030855966228, 0.7943282347242815, 0.8019351848161371, 0.8089433786991753, 0.8154443636507333, 0.8215099039548769, 0.8271973337231157, 0.8325532074018731, 0.8376158603010033, 0.8424172486141028, 0.8469842998552982, 0.8513399225207846, 0.8555037734677596, 0.8594928497600736, 0.8633219511791957, 0.867004045984223, 0.870550563296124, 0.8739716291356505, 0.8772762586965454, 0.8804725142695762, 0.8835676359470229, 0.8865681505652133, 0.8894799631049141, 0.8923084338428022, 0.8950584438464528, 0.8977344508701224, 0.900340537296277, 0.9028804514474342, 0.9053576433419919, 0.9077752957697911, 0.9101363514059138, 0.9124435365554809, 0.9146993820210588, 0.9169062415024053, 0.9190663078716548, 0.92118162761254, 0.9232541136674268, 0.9252855568989151, 0.9272776363420389, 0.9292319283974863, 0.9311499150948377, 0.9330329915368074, 0.9348824726202953, 0.9366995991172012, 0.9384855431870388, 0.9402414133840812, 0.9419682592138261, 0.9436670752867394, 0.9453388051113799, 0.9469843445639475, 0.9486045450669235, 0.9502002165056763, 0.9517721299086176, 0.9533210199136081, 0.9548475870408182, 0.956352499790037, 0.9578363965785065, 0.9592998875336589, 0.9607435561536403, 0.9621679608471888, 0.9635736363632673, 0.9649610951198175, 0.9663308284400851, 0.9676833077041481, 0.9690189854225578, 0.9703382962383448, 0.9716416578630734, 0.9729294719520967, 0.9742021249237081, 0.9754599887264647, 0.976703421558577, 0.9779327685429285, 0.9791483623609768, 0.9803505238485178, 0.9815395625560397, 0.9827157772761715, 0.9838794565405263, 0.9850308790880501, 0.9861703143068244, 0.9872980226511102, 0.9884142560352877, 0.9895192582062144, 0.9906132650954107, 0.9916965051523725, 0.9927691996602168, 0.9938315630347765, 0.9948838031081764, 0.9959261213978506, 0.9969587133618939, 0.9979817686415696, 0.9989954712917499, 1.0, 1.0009955282949736], [0.0, 0.6762433378062415, 0.7247796636776955, 0.754770860611584, 0.7767996097157337, 0.7943282347242815, 0.8089433786991753, 0.821509903954877, 0.8325532074018732, 0.8424172486141028, 0.8513399225207846, 0.8594928497600735, 0.867004045984223, 0.8739716291356506, 0.8804725142695761, 0.8865681505652133, 0.8923084338428021, 0.8977344508701224, 0.9028804514474342, 0.907775295769791, 0.9124435365554808, 0.9169062415024053, 0.92118162761254, 0.9252855568989152, 0.9292319283974861, 0.9330329915368073, 0.9366995991172012, 0.9402414133840813, 0.9436670752867395, 0.9469843445639476, 0.9502002165056763, 0.9533210199136081, 0.9563524997900371, 0.959299887533659, 0.9621679608471888, 0.9649610951198175, 0.9676833077041481, 0.970338296238345, 0.9729294719520967, 0.9754599887264648, 0.9779327685429285, 0.9803505238485177, 0.9827157772761715, 0.9850308790880503, 0.9872980226511102, 0.9895192582062144, 0.9916965051523726, 0.9938315630347766, 0.9959261213978506, 0.9979817686415696, 1.0, 1.0019822247447452, 1.0039297727022005, 1.0058439001618265, 1.0077257952426748, 1.009576582776887, 1.0113973287615656, 1.0131890444241456, 1.0149526899409642, 1.0166891778440417, 1.0183993761470242, 1.0200841112177017, 1.0217441704214383, 1.0233803045571623, 1.0249932301052076, 1.026583631304232, 1.0281521620726262, 1.0296994477882186, 1.031226086938676, 1.0327326526537461, 1.0342196941293802, 1.0356877379527947, 1.0371372893366482, 1.0385688332697407, 1.0399828355909382, 1.0413797439924106, 1.042759988957706, 1.044123984639697, 1.0454721296829765, 1.0468048079948808, 1.048122389468958, 1.0494252306643652, 1.0507136754443949, 1.0519880555770453, 1.053248691300327, 1.0544958918547664, 1.0557299559853681, 1.0569511724151297, 1.058159820292016, 1.0593561696111744, 1.0605404816140187, 1.0617130091656912, 1.0628739971122991, 1.064023682619215, 1.0651622954916387, 1.066290058478526, 1.067407187560915, 1.0685138922256048, 1.069610375725069, 1.070696835324435, 1.0717734625362931, 1.07284044334405], [0.0, 0.7042261140012369, 0.754770860611584, 0.7860030855966228, 0.8089433786991752, 0.8271973337231157, 0.8424172486141028, 0.8555037734677596, 0.867004045984223, 0.8772762586965454, 0.8865681505652133, 0.8950584438464527, 0.9028804514474343, 0.9101363514059139, 0.9169062415024052, 0.9232541136674268, 0.9292319283974861, 0.9348824726202953, 0.9402414133840812, 0.9453388051113797, 0.9502002165056763, 0.9548475870408182, 0.959299887533659, 0.9635736363632674, 0.9676833077041481, 0.9716416578630734, 0.9754599887264647, 0.9791483623609769, 0.9827157772761717, 0.9861703143068246, 0.9895192582062143, 0.9927691996602169, 0.9959261213978506, 0.9989954712917501, 1.0019822247447452, 1.0048909381985118, 1.0077257952426748, 1.0104906465227195, 1.0131890444241456, 1.0158242733348055, 1.0183993761470242, 1.020917177548195, 1.0233803045571623, 1.025791204689333, 1.0281521620726264, 1.0304653117863476, 1.0327326526537461, 1.0349560586847328, 1.0371372893366482, 1.0392779987370508, 1.0413797439924106, 1.0434439926896288, 1.0454721296829765, 1.0474654632468507, 1.0494252306643652, 1.0513526033129272, 1.0532486913003272, 1.055114547698332, 1.0569511724151297, 1.0587595157430827, 1.0605404816140187, 1.062294930590616, 1.0640236826192153, 1.065727519566613, 1.067407187560915, 1.0690633991544003, 1.0706968353244348, 1.0723081473268217, 1.0738979584144939, 1.0754668654331612, 1.0770154403043632, 1.0785442314053602, 1.0800537648543813, 1.081544545708939, 1.0830170590841923, 1.0844717711976986, 1.0859091303463049, 1.0873295678204233, 1.0887334987604584, 1.0901213229597335, 1.091493425617897, 1.092850178048433, 1.0941919383436087, 1.0955190519998972, 1.096831852506676, 1.0981306619007651, 1.0994157912891616, 1.100687541342146, 1.1019462027587548, 1.1031920567064655, 1.1044253752367947, 1.1056464216783795, 1.1068554510089963, 1.1080527102078601, 1.1092384385894511, 1.1104128681200198, 1.1115762237178446, 1.1127287235382346, 1.1138705792441983, 1.1150019962636442, 1.1161231740339044, 1.117234306234331], [0.0, 0.7247796636776955, 0.7767996097157337, 0.8089433786991752, 0.8325532074018731, 0.8513399225207846, 0.867004045984223, 0.8804725142695762, 0.8923084338428022, 0.9028804514474343, 0.9124435365554808, 0.9211816276125399, 0.9292319283974861, 0.9366995991172012, 0.9436670752867393, 0.9502002165056764, 0.9563524997900369, 0.9621679608471887, 0.9676833077041481, 0.9729294719520966, 0.9779327685429284, 0.9827157772761715, 0.9872980226511102, 0.9916965051523726, 0.9959261213978505, 0.9999999999999999, 1.0039297727022005, 1.007725795242675, 1.0113973287615656, 1.0149526899409642, 1.018399376147024, 1.0217441704214383, 1.0249932301052076, 1.0281521620726264, 1.031226086938676, 1.0342196941293802, 1.037137289336648, 1.0399828355909384, 1.042759988957706, 1.0454721296829765, 1.048122389468958, 1.0507136754443946, 1.0532486913003272, 1.0557299559853683, 1.058159820292016, 1.0605404816140187, 1.0628739971122994, 1.0651622954916389, 1.067407187560915, 1.0696103757250688, 1.0717734625362931, 1.0738979584144939, 1.0759852886323111, 1.0780367996474503, 1.0800537648543813, 1.0820373898183426, 1.0839888170467407, 1.0859091303463047, 1.087799358808552, 1.0896604804610857, 1.091493425617897, 1.0932990799580533, 1.0950782873588571, 1.096831852506676, 1.0985605433061179, 1.100265093106018, 1.1019462027587545, 1.1036045425276881, 1.1052407538560174, 1.1068554510089963, 1.1084492226002718, 1.1100226330120477, 1.1115762237178446, 1.113110514515788, 1.1146260046796124, 1.1161231740339044, 1.1176024839595073, 1.1190643783344794, 1.1205092844155162, 1.121937613664313, 1.123349762522958, 1.1247461131420948, 1.126127034065274, 1.127492880872632, 1.1288439967867707, 1.1301807132434794, 1.1315033504297265, 1.1328122177911581, 1.1341076145111557, 1.1353898299633531, 1.1366591441393648, 1.1379158280533401, 1.139160144124839, 1.140392346541414, 1.1416126816021799, 1.1428213880435563, 1.1440186973482884, 1.145204834038768, 1.1463800159556026, 1.1475444545223208, 1.148698354997035, 1.1498419167118241], [0.0, 0.7411344491069477, 0.7943282347242815, 0.8271973337231157, 0.8513399225207846, 0.8705505632961241, 0.8865681505652133, 0.9003405372962773, 0.9124435365554809, 0.9232541136674268, 0.9330329915368074, 0.9419682592138261, 0.9502002165056764, 0.9578363965785065, 0.9649610951198175, 0.9716416578630735, 0.9779327685429284, 0.9838794565405262, 0.9895192582062143, 0.9948838031081763, 1.0, 1.0048909381985118, 1.009576582776887, 1.0140743178387932, 1.0183993761470242, 1.0225651825635729, 1.026583631304232, 1.0304653117863476, 1.0342196941293804, 1.0378552826828715, 1.0413797439924106, 1.0448000141602642, 1.048122389468958, 1.0513526033129275, 1.0544958918547662, 1.057557050338252, 1.0605404816140187, 1.06345023813903, 1.066290058478526, 1.0690633991544003, 1.0717734625362934, 1.0744232213528402, 1.0770154403043632, 1.079552695180011, 1.0820373898183429, 1.0844717711976988, 1.086857942899213, 1.089197877149242, 1.091493425617897, 1.0937463291251968, 1.0959582263852172, 1.0981306619007651, 1.100265093106018, 1.102362896841745, 1.1044253752367945, 1.1064537610602057, 1.108449222600272, 1.1104128681200198, 1.1123457499326046, 1.1142488681350007, 1.1161231740339044, 1.117969573293893, 1.1197889288345146, 1.121582063500031, 1.1233497625229583, 1.125092775800282, 1.1268118199992418, 1.1285075805078137, 1.1301807132434794, 1.1318318463325003, 1.1334615816706974, 1.1350704963756626, 1.1366591441393648, 1.1382280564892693, 1.1397777439653136, 1.141308697219414, 1.1428213880435563, 1.1443162703319882, 1.145793780982531, 1.1472543407415876, 1.148698354997035, 1.1501262145228153, 1.1515382961787317, 1.1529349635686519, 1.1543165676600577, 1.1556834473676476, 1.1570359301034676, 1.1583743322958617, 1.1596989598793381, 1.1610101087573002, 1.1623080652394242, 1.1635931064553429, 1.1648655007461621, 1.1661255080352224, 1.167373380179423, 1.168609361302315, 1.1698336881100935, 1.171046590191539, 1.1722482903028724, 1.1734390046384329, 1.1746189430880192, 1.1757883094816752], [0.0, 0.754770860611584, 0.8089433786991753, 0.8424172486141028, 0.867004045984223, 0.8865681505652133, 0.9028804514474343, 0.9169062415024054, 0.9292319283974863, 0.9402414133840813, 0.9502002165056764, 0.959299887533659, 0.9676833077041482, 0.9754599887264648, 0.9827157772761715, 0.9895192582062144, 0.9959261213978505, 1.0019822247447452, 1.007725795242675, 1.0131890444241456, 1.0183993761470242, 1.0233803045571623, 1.0281521620726264, 1.0327326526537461, 1.0371372893366482, 1.0413797439924106, 1.0454721296829765, 1.0494252306643652, 1.0532486913003272, 1.05695117241513, 1.0605404816140187, 1.0640236826192153, 1.0674071875609152, 1.070696835324435, 1.0738979584144939, 1.0770154403043632, 1.0800537648543813, 1.0830170590841925, 1.0859091303463049, 1.0887334987604584, 1.0914934256178972, 1.0941919383436087, 1.0968318525066763, 1.0994157912891618, 1.1019462027587548, 1.1044253752367947, 1.1068554510089965, 1.1092384385894514, 1.1115762237178448, 1.1138705792441983, 1.1161231740339044, 1.118335581007658, 1.1205092844155162, 1.1226456864312595, 1.1247461131420948, 1.126811819999242, 1.128843996786771, 1.130843772159056, 1.1328122177911584, 1.1347503521812128, 1.1366591441393648, 1.1385395159938556, 1.1403923465414143, 1.1422184737661238, 1.1440186973482884, 1.145793780982531, 1.147544454522321, 1.1492714159663453, 1.1509753333005583, 1.1526568462083528, 1.1543165676600577, 1.1559550853918679, 1.1575729632833396, 1.1591707426417117, 1.1607489434005382, 1.1623080652394242, 1.1638485886310341, 1.1653709758209863, 1.1668756717457496, 1.1683631048931984, 1.1698336881100935, 1.1712878193603735, 1.1727258824378277, 1.1741482476364073, 1.175555272381177, 1.1769473018226546, 1.1783246693970635, 1.1796876973548314, 1.1810366972594708, 1.1823719704588234, 1.1836938085304844, 1.1850024937030992, 1.1862982992550823, 1.1875814898922024, 1.1888523221053675, 1.19011104450985, 1.1913578981670916, 1.1925931168901633, 1.193816927533861, 1.1950295502703652, 1.1962311988513157, 1.1974220808571023], [0.0, 0.7664958432641342, 0.821509903954877, 0.8555037734677596, 0.8804725142695762, 0.9003405372962773, 0.9169062415024054, 0.9311499150948378, 0.9436670752867394, 0.9548475870408183, 0.9649610951198176, 0.9742021249237081, 0.9827157772761717, 0.9906132650954108, 0.9979817686415695, 1.0048909381985118, 1.0113973287615654, 1.017547510603524, 1.0233803045571623, 1.0289284225448125, 1.0342196941293802, 1.0392779987370508, 1.0441239846396972, 1.0487756308196967, 1.0532486913003272, 1.0575570503382523, 1.0617130091656912, 1.065727519566613, 1.069610375725069, 1.073370373006841, 1.0770154403043632, 1.0805527510712007, 1.0839888170467409, 1.0873295678204236, 1.0905804187347243, 1.0937463291251968, 1.096831852506676, 1.0998411800099643, 1.10277817813286, 1.1056464216783795, 1.108449222600272, 1.1111896553530378, 1.1138705792441983, 1.1164946582056192, 1.1190643783344796, 1.1215820635000313, 1.1240498892673114, 1.1264698953516594, 1.128843996786771, 1.1311739939629937, 1.1334615816706974, 1.1357083572651034, 1.1379158280533401, 1.1400854179912472, 1.1422184737661238, 1.1443162703319882, 1.1463800159556026, 1.148410856824415, 1.1504098812614145, 1.1523781235865886, 1.1543165676600577, 1.156226150137964, 1.1581077634686983, 1.1599622586540013, 1.1617904477968057, 1.163593106455343, 1.1653709758209863, 1.167124764735478, 1.1688551515615961, 1.1705627859198902, 1.1722482903028724, 1.1739122615769217, 1.175555272381177, 1.1771778724318112, 1.1787805897392818, 1.1803639317454637, 1.1819283863869205, 1.183474423090022, 1.1850024937030992, 1.1865130333703686, 1.1880064613519559, 1.189483181793968, 1.1909435844522358, 1.1923880453730393, 1.193816927533861, 1.1952305814469564, 1.1966293457283115, 1.1980135476343512, 1.1993835035685696, 1.2007395195600936, 1.2020818917160292, 1.2034109066493002, 1.204726841883563, 1.206029966236656, 1.2073205401839437, 1.2085988162028105, 1.2098650390994656, 1.2111194463191473, 1.2123622682407258, 1.2135937284566445, 1.2148140440390671, 1.2160234257930393], [0.0, 0.7767996097157338, 0.8325532074018732, 0.867004045984223, 0.8923084338428022, 0.9124435365554809, 0.9292319283974863, 0.9436670752867394, 0.956352499790037, 0.9676833077041482, 0.9779327685429285, 0.9872980226511102, 0.9959261213978506, 1.0039297727022007, 1.0113973287615654, 1.0183993761470242, 1.0249932301052074, 1.031226086938676, 1.0371372893366482, 1.042759988957706, 1.0481223894689577, 1.0532486913003272, 1.058159820292016, 1.0628739971122994, 1.067407187560915, 1.0717734625362931, 1.0759852886323114, 1.0800537648543813, 1.0839888170467409, 1.0877993588085522, 1.091493425617897, 1.0950782873588574, 1.0985605433061179, 1.1019462027587548, 1.1052407538560174, 1.1084492226002718, 1.1115762237178446, 1.1146260046796126, 1.1176024839595073, 1.1205092844155164, 1.1233497625229583, 1.126127034065274, 1.128843996786771, 1.1315033504297267, 1.1341076145111557, 1.136659144139365, 1.1391601441248391, 1.14161268160218, 1.1440186973482884, 1.1463800159556026, 1.148698354997035, 1.1509753333005583, 1.153212478435565, 1.155411233499692, 1.1575729632833396, 1.1596989598793381, 1.1617904477968057, 1.163848588631034, 1.1658744853350014, 1.1678691861327388, 1.1698336881100935, 1.1717689405143865, 1.1736758477909164, 1.175555272381177, 1.1774080373049494, 1.1792349285460542, 1.1810366972594708, 1.1828140618156822, 1.1845677096964866, 1.1862982992550826, 1.1880064613519559, 1.1896928008769756, 1.1913578981670916, 1.193002310328141, 1.1946265724684626, 1.1962311988513155, 1.1978166839724433, 1.1993835035685694, 1.200932115562082, 1.2024629609467068, 1.2039764646185536, 1.2054730361565404, 1.2069530705558649, 1.2084169489178813, 1.2098650390994656, 1.2112976963247015, 1.2127152637614846, 1.214118073065447, 1.215506444893397, 1.2168806893883162, 1.2182411066377867, 1.2195879871075817, 1.2209216120520214, 1.22224225390258, 1.2235501766361112, 1.224845636123975, 1.2261288804632346, 1.2274001502910314, 1.2286596790831472, 1.2299076934377098, 1.2311444133449163, 1.2323700524435999], [0.0, 0.7860030855966228, 0.8424172486141028, 0.8772762586965454, 0.9028804514474343, 0.9232541136674268, 0.9402414133840813, 0.9548475870408183, 0.9676833077041482, 0.9791483623609769, 0.9895192582062144, 0.99899547129175, 1.007725795242675, 1.0158242733348055, 1.0233803045571623, 1.0304653117863476, 1.0371372893366482, 1.0434439926896288, 1.0494252306643652, 1.055114547698332, 1.0605404816140187, 1.065727519566613, 1.070696835324435, 1.0754668654331614, 1.0800537648543813, 1.0844717711976986, 1.0887334987604584, 1.0928501780484332, 1.0968318525066763, 1.1006875413421462, 1.1044253752367947, 1.1080527102078603, 1.1115762237178448, 1.1150019962636444, 1.118335581007658, 1.121582063500031, 1.1247461131420948, 1.1278320277285099, 1.130843772159056, 1.1337850122151278, 1.136659144139365, 1.1394693206308266, 1.1422184737661238, 1.1449093352739208, 1.147544454522321, 1.1501262145228153, 1.1526568462083528, 1.155138441204824, 1.1575729632833398, 1.1599622586540015, 1.1623080652394242, 1.1646120210473587, 1.1668756717457496, 1.1691004775299692, 1.1712878193603735, 1.1734390046384329, 1.175555272381177, 1.1776377979464099, 1.1796876973548314, 1.1817060312497691, 1.1836938085304842, 1.1856519896909246, 1.1875814898922024, 1.189483181793968, 1.1913578981670918, 1.1932064343076842, 1.1950295502703652, 1.1968279729368279, 1.198602397934115, 1.2003534914155538, 1.202081891716029, 1.2037882108921085, 1.2054730361565402, 1.2071369312157183, 1.2087804375179136, 1.2104040754193457, 1.2120083452745145, 1.2135937284566445, 1.2151606883135608, 1.216709671063857, 1.2182411066377867, 1.2197554094669347, 1.2212529792263789, 1.2227342015327394, 1.2241994486012386, 1.2256490798646344, 1.2270834425566557, 1.2285028722623705, 1.2299076934377098, 1.2312982199002114, 1.2326747552928774, 1.2340375935229018, 1.2353870191768899, 1.2367233079140671, 1.2380467268388704, 1.2393575348542079, 1.2406559829965822, 1.2419423147541893, 1.2432167663690183, 1.2444795671239184, 1.2457309396155174, 1.2469711000138288], [0.0, 0.7943282347242815, 0.8513399225207846, 0.8865681505652133, 0.9124435365554808, 0.9330329915368074, 0.9502002165056764, 0.9649610951198176, 0.9779327685429285, 0.9895192582062144, 1.0, 1.009576582776887, 1.0183993761470242, 1.026583631304232, 1.0342196941293802, 1.0413797439924106, 1.0481223894689577, 1.0544958918547662, 1.0605404816140187, 1.0662900584785258, 1.0717734625362931, 1.0770154403043632, 1.0820373898183429, 1.086857942899213, 1.091493425617897, 1.0959582263852172, 1.100265093106018, 1.1044253752367947, 1.108449222600272, 1.1123457499326046, 1.1161231740339044, 1.1197889288345146, 1.1233497625229583, 1.126811819999242, 1.1301807132434794, 1.1334615816706974, 1.1366591441393648, 1.1397777439653138, 1.1428213880435563, 1.145793780982531, 1.148698354997035, 1.1515382961787317, 1.1543165676600577, 1.1570359301034678, 1.1596989598793381, 1.1623080652394242, 1.1648655007461621, 1.1673733801794233, 1.1698336881100935, 1.1722482903028724, 1.174618943088019, 1.1769473018226546, 1.179234928546054, 1.1814832989196156, 1.1836938085304842, 1.185867778627801, 1.1880064613519559, 1.19011104450985, 1.1921826559427973, 1.1942223675281953, 1.1962311988513155, 1.198210120579418, 1.2001600575667746, 1.202081891716029, 1.2039764646185536, 1.2058445799940376, 1.2076870059474099, 1.2095044770593142, 1.2112976963247013, 1.2130673369526295, 1.214814044039067, 1.216538436123333, 1.2182411066377865, 1.2199226252594597, 1.2215835391715089, 1.223224374241637, 1.224845636123975, 1.2264478112903319, 1.2280313679961983, 1.2295967571864037, 1.2311444133449163, 1.2326747552928772, 1.2341881869386229, 1.235685097983129, 1.2371658645840293, 1.2386308499811036, 1.240080405085894, 1.2415148690379023, 1.242934569729616, 1.24433982430245, 1.2457309396155174, 1.2471082126890045, 1.248471931123787, 1.2498223734988043, 1.2511598097475969, 1.252484501515308, 1.2537967024973569, 1.2550966587609054, 1.2563846090501594, 1.2576607850764745, 1.2589254117941673, 1.2601787076628697], [0.0, 0.8019351848161371, 0.8594928497600735, 0.8950584438464527, 0.9211816276125399, 0.9419682592138261, 0.959299887533659, 0.9742021249237081, 0.9872980226511102, 0.99899547129175, 1.009576582776887, 1.0192448764914566, 1.0281521620726264, 1.0364147944268143, 1.044123984639697, 1.0513526033129272, 1.0581598202920157, 1.0645943590510007, 1.070696835324435, 1.076501473487717, 1.0820373898183426, 1.0873295678204233, 1.092399610449625, 1.0972663279561043, 1.1019462027587548, 1.1064537610602054, 1.110801872846667, 1.1150019962636444, 1.1190643783344796, 1.1229982210833527, 1.1268118199992418, 1.13051268020414, 1.1341076145111557, 1.1376028266674396, 1.1410039823966966, 1.1443162703319882, 1.147544454522321, 1.1506929198776512, 1.1537657116653524, 1.1567665699713525, 1.1596989598793381, 1.1625660979928427, 1.1653709758209865, 1.168116380463936, 1.1708049129648923, 1.1734390046384329, 1.1760209316379977, 1.1785528279862458, 1.1810366972594708, 1.183474423090022, 1.185867778627801, 1.188218435082593, 1.1905279694526716, 1.1927978715312288, 1.195029550270365, 1.1972243395722733, 1.1993835035685694, 1.2015082414412859, 1.2035996918326024, 1.2056589368848392, 1.2076870059474099, 1.2096848789832506, 1.2116534897035762, 1.2135937284566445, 1.215506444893397, 1.217392450430411, 1.2192525205284361, 1.2210873968028881, 1.2228977889810073, 1.2246843767188942, 1.2264478112903319, 1.2281887171581327, 1.2299076934377098, 1.2316053152616542, 1.2332821350532674, 1.234938683716268, 1.236575471747225, 1.2381929902766857, 1.2397917120444277, 1.2413720923137912, 1.242934569729616, 1.2444795671239184, 1.2460074922730966, 1.2475187386101303, 1.2490136858949572, 1.2504927008459537, 1.2519561377351947, 1.2534043389499798, 1.254837635522886, 1.2562563476324593, 1.2576607850764747, 1.2590512477195563, 1.260428025916814, 1.261791400915021, 1.2631416452327588, 1.2644790230208376, 1.2658037904042108, 1.2671161958065236, 1.268416480258335, 1.269704877690004, 1.2709816152101407, 1.2722469133704737], [0.0, 0.8089433786991753, 0.867004045984223, 0.9028804514474343, 0.9292319283974861, 0.9502002165056764, 0.9676833077041482, 0.9827157772761717, 0.9959261213978506, 1.007725795242675, 1.0183993761470242, 1.0281521620726264, 1.0371372893366482, 1.0454721296829768, 1.053248691300327, 1.0605404816140187, 1.067407187560915, 1.0738979584144939, 1.0800537648543813, 1.0859091303463047, 1.091493425617897, 1.0968318525066763, 1.1019462027587548, 1.1068554510089965, 1.1115762237178446, 1.1161231740339044, 1.1205092844155164, 1.1247461131420948, 1.128843996786771, 1.1328122177911584, 1.1366591441393648, 1.1403923465414143, 1.1440186973482884, 1.147544454522321, 1.1509753333005583, 1.1543165676600577, 1.1575729632833396, 1.1607489434005382, 1.163848588631034, 1.1668756717457496, 1.1698336881100935, 1.1727258824378277, 1.175555272381177, 1.1783246693970637, 1.1810366972594708, 1.1836938085304844, 1.1862982992550826, 1.1888523221053677, 1.1913578981670918, 1.193816927533861, 1.1962311988513155, 1.198602397934115, 1.200932115562082, 1.2032218545478646, 1.2054730361565402, 1.2076870059474099, 1.2098650390994656, 1.2120083452745145, 1.2141180730654473, 1.2161953140715365, 1.2182411066377865, 1.22025643929113, 1.22224225390258, 1.2241994486012386, 1.2261288804632349, 1.2280313679961983, 1.2299076934377098, 1.2317586048842384, 1.2335848182654034, 1.2353870191768899, 1.2371658645840293, 1.2389219844068788, 1.2406559829965822, 1.2423684405118738, 1.2440599142037385, 1.2457309396155174, 1.2473820317050612, 1.2490136858949572, 1.250626379056305, 1.2522205704310376, 1.2537967024973569, 1.2553552017824519, 1.2568964796263205, 1.2584209329001932, 1.2599289446827693, 1.2614208848972144, 1.2628971109116236, 1.2643579681054542, 1.2658037904042108, 1.2672349007845127, 1.2686516117514892, 1.2700542257903127, 1.2714430357935353, 1.2728183254657754, 1.2741803697071823, 1.2755294349770063, 1.2768657796385043, 1.2781896542863207, 1.2795013020574053, 1.2808009589264584, 1.2820888539868156, 1.2833652097176298], [0.0, 0.8154443636507333, 0.8739716291356506, 0.9101363514059139, 0.9366995991172012, 0.9578363965785065, 0.9754599887264648, 0.9906132650954108, 1.0039297727022007, 1.0158242733348055, 1.026583631304232, 1.0364147944268143, 1.0454721296829768, 1.0538739520617835, 1.0617130091656912, 1.0690633991544003, 1.0759852886323111, 1.0825282218556607, 1.0887334987604584, 1.0946359202564868, 1.100265093106018, 1.1056464216783795, 1.1108018728466673, 1.1157505737333215, 1.1205092844155164, 1.125092775800282, 1.129514134678065, 1.1337850122151278, 1.1379158280533404, 1.1419159392316425, 1.145793780982531, 1.1495569848572122, 1.1532124784355653, 1.1567665699713525, 1.160225020631498, 1.1635931064553429, 1.1668756717457496, 1.170077175279657, 1.1732017304698967, 1.1762531404068526, 1.1792349285460542, 1.1821503656770507, 1.1850024937030994, 1.1877941466750876, 1.1905279694526718, 1.1932064343076842, 1.1958318557370178, 1.1984064037124882, 1.2009321155620822, 1.2034109066493002, 1.2058445799940376, 1.2082348349588188, 1.2105832751075947, 1.2128914153302024, 1.2151606883135608, 1.217392450430411, 1.2195879871075817, 1.2217485177281944, 1.2238752001156807, 1.225969134641832, 1.2280313679961983, 1.2300628966499005, 1.2320646700431956, 1.2340375935229015, 1.235982531052946, 1.2379003077188055, 1.2397917120444277, 1.2416574981382769, 1.2434983876834627, 1.2453150717853847, 1.2471082126890045, 1.2488784453766626, 1.250626379056305, 1.252352598549048, 1.254057665584163, 1.2557421200088268, 1.2574064809192924, 1.2590512477195563, 1.260676901113041, 1.2622839040323264, 1.2638727025115426, 1.2654437265056175, 1.2669973906602379, 1.2685340950360464, 1.2700542257903127, 1.2715581558190487, 1.2730462453623002, 1.2745188425751277, 1.2759762840665922, 1.2774188954088792, 1.2788469916185308, 1.280260877611609, 1.2816608486344643, 1.2830471906716767, 1.2844201808326001, 1.2857800877178558, 1.2871271717670085, 1.2884616855885789, 1.2897838742734604, 1.2910939756927384, 1.2923922207808318, 1.293678833804823], [0.0, 0.8215099039548769, 0.8804725142695761, 0.9169062415024052, 0.9436670752867393, 0.9649610951198175, 0.9827157772761715, 0.9979817686415695, 1.0113973287615654, 1.0233803045571623, 1.0342196941293802, 1.044123984639697, 1.053248691300327, 1.0617130091656912, 1.0696103757250688, 1.0770154403043632, 1.0839888170467407, 1.0905804187347243, 1.096831852506676, 1.1027781781328598, 1.1084492226002718, 1.1138705792441983, 1.1190643783344796, 1.1240498892673114, 1.1288439967867707, 1.1334615816706974, 1.13791582805334, 1.1422184737661238, 1.1463800159556026, 1.1504098812614143, 1.1543165676600575, 1.158107763468698, 1.1617904477968057, 1.1653709758209863, 1.168855151561596, 1.1722482903028721, 1.1755552723811769, 1.1787805897392818, 1.1819283863869205, 1.1850024937030992, 1.1880064613519559, 1.1909435844522356, 1.1938169275338608, 1.1966293457283115, 1.1993835035685694, 1.202081891716029, 1.204726841883563, 1.2073205401839437, 1.2098650390994656, 1.2123622682407256, 1.214814044039067, 1.2172220784974253, 1.2195879871075814, 1.2219132960276158, 1.2241994486012384, 1.2264478112903319, 1.2286596790831472, 1.2308362804329742, 1.2329787817755118, 1.2350882916674744, 1.2371658645840293, 1.2392125044083735, 1.241229167643009, 1.2432167663690181, 1.245176170976773, 1.2471082126890045, 1.2490136858949572, 1.2508933503123998, 1.2527479329925555, 1.2545781301814902, 1.2563846090501591, 1.2581680093041079, 1.2599289446827693, 1.261668004357349, 1.2633857542354436, 1.2650827381797884, 1.2667594791478436, 1.2684164802583349, 1.2700542257903125, 1.2716731821198002, 1.2732737985986746, 1.274856508380008, 1.2764217291937567, 1.277969864076345, 1.279501302057405, 1.2810164188066713, 1.2825155772437713, 1.2839991281134568, 1.2854674105285961, 1.2869207524830866, 1.2883594713366657, 1.2897838742734602, 1.2911942587359597, 1.2925909128359894, 1.2939741157441331, 1.2953441380589512, 1.296701242157242, 1.2980456825265105, 1.2993777060807168, 1.3006975524603077, 1.3020054543174677, 1.3033016375874507], [0.0, 0.8271973337231157, 0.8865681505652133, 0.9232541136674268, 0.9502002165056764, 0.9716416578630735, 0.9895192582062144, 1.0048909381985118, 1.0183993761470242, 1.0304653117863476, 1.0413797439924106, 1.0513526033129272, 1.0605404816140187, 1.0690633991544003, 1.0770154403043632, 1.0844717711976988, 1.091493425617897, 1.0981306619007651, 1.1044253752367947, 1.1104128681200196, 1.1161231740339044, 1.1215820635000313, 1.126811819999242, 1.1318318463325003, 1.1366591441393648, 1.141308697219414, 1.145793780982531, 1.1501262145228153, 1.1543165676600577, 1.1583743322958617, 1.1623080652394242, 1.1661255080352226, 1.1698336881100935, 1.173439004638433, 1.1769473018226546, 1.1803639317454637, 1.1836938085304842, 1.186941455218846, 1.19011104450985, 1.1932064343076842, 1.1962311988513157, 1.1991886560720644, 1.202081891716029, 1.20491378068117, 1.20768700594741, 1.2104040754193457, 1.2130673369526295, 1.2156789917948028, 1.2182411066377867, 1.2207556244511462, 1.223224374241637, 1.2256490798646344, 1.2280313679961983, 1.230372775360218, 1.2326747552928772, 1.234938683716268, 1.2371658645840296, 1.2393575348542079, 1.2415148690379023, 1.2436389833665225, 1.2457309396155174, 1.2477917486181098, 1.2498223734988045, 1.251823732653151, 1.2537967024973569, 1.2557421200088268, 1.2576607850764745, 1.2595534626777032, 1.2614208848972142, 1.2632637528012847, 1.2650827381797884, 1.266878485167044, 1.2686516117514892, 1.2704027111832457, 1.2721323532877689, 1.2738410856930327, 1.2755294349770063, 1.277197907741578, 1.2788469916185308, 1.2804771562126753, 1.2820888539868156, 1.2836825210928038, 1.2852585781526005, 1.286817430992908, 1.2883594713366657, 1.2898850774544237, 1.2913946147783533, 1.292888436481462, 1.2943668840243445, 1.2958302876716465, 1.2972789669802327, 1.2987132312609082, 1.3001333800153998, 1.3015397033501719, 1.3029324823685455, 1.3043119895424735, 1.3056784890652262, 1.3070322371861616, 1.30837348252866, 1.3097024663922332, 1.31101942303975, 1.312324579970646], [0.0, 0.8325532074018731, 0.8923084338428021, 0.9292319283974861, 0.9563524997900369, 0.9779327685429284, 0.9959261213978505, 1.0113973287615654, 1.0249932301052074, 1.0371372893366482, 1.0481223894689577, 1.0581598202920157, 1.067407187560915, 1.0759852886323111, 1.0839888170467407, 1.091493425617897, 1.0985605433061176, 1.1052407538560172, 1.1115762237178446, 1.1176024839595071, 1.123349762522958, 1.1288439967867707, 1.1341076145111557, 1.1391601441248391, 1.1440186973482882, 1.1486983549970349, 1.1532124784355648, 1.1575729632833396, 1.1617904477968057, 1.1658744853350014, 1.1698336881100933, 1.1736758477909162, 1.1774080373049494, 1.1810366972594708, 1.1845677096964866, 1.1880064613519556, 1.1913578981670914, 1.1946265724684626, 1.1978166839724431, 1.200932115562082, 1.2039764646185536, 1.2069530705558646, 1.2098650390994656, 1.2127152637614846, 1.2155064448933968, 1.2182411066377865, 1.2209216120520214, 1.2235501766361112, 1.2261288804632346, 1.228659679083147, 1.231144413344916, 1.2335848182654034, 1.2359825310529458, 1.2383390983812943, 1.2406559829965822, 1.2429345697296157, 1.245176170976773, 1.247382031705061, 1.249553334030213, 1.251691201410928, 1.2537967024973566, 1.2558708546675876, 1.2579146272820896, 1.2599289446827693, 1.2619146889603865, 1.2638727025115424, 1.2658037904042105, 1.2677087225688106, 1.2695882358300898, 1.2714430357935353, 1.2732737985986744, 1.2750811725504168, 1.2768657796385041, 1.278628216954189, 1.280369058012388, 1.2820888539868154, 1.2837881348648863, 1.285467410528596, 1.2871271717670083, 1.2887678912254954, 1.290390024296432, 1.2919940099556333, 1.29358027154847, 1.2951492175292605, 1.296701242157242, 1.2982367261521606, 1.2997560373122603, 1.3012595310972463, 1.302747551178576, 1.3042204299592668, 1.305678489065226, 1.3071220398099606, 1.3085513836343878, 1.309966812523331, 1.3113686094001777, 1.3127570485010611, 1.3141323957298296, 1.3154949089949852, 1.3168448385296754, 1.3181824271957598, 1.3195079107728942, 1.3208215182335101], [0.0, 0.8376158603010033, 0.8977344508701224, 0.9348824726202953, 0.9621679608471887, 0.9838794565405262, 1.0019822247447452, 1.017547510603524, 1.031226086938676, 1.0434439926896288, 1.0544958918547662, 1.0645943590510007, 1.0738979584144939, 1.0825282218556607, 1.0905804187347243, 1.0981306619007651, 1.1052407538560172, 1.1119615859385787, 1.1183355810076578, 1.1243984861911838, 1.1301807132434794, 1.1357083572651032, 1.1410039823966969, 1.146087235816942, 1.1509753333005581, 1.1556834473676474, 1.160225020631498, 1.1646120210473587, 1.1688551515615961, 1.1729640236260406, 1.1769473018226544, 1.1808128252004448, 1.1845677096964866, 1.188218435082593, 1.1917709191687385, 1.195230581446956, 1.1986023979341147, 1.201890948638917, 1.2051004588156917, 1.2082348349588186, 1.2112976963247013, 1.2142924026339097, 1.2172220784974253, 1.2200896350224653, 1.2228977889810073, 1.2256490798646344, 1.2283458851001732, 1.230990433659814, 1.2335848182654034, 1.2361310063581523, 1.2386308499811034, 1.241086094701541, 1.2434983876834627, 1.2458692850057513, 1.248200258309318, 1.2504927008459534, 1.2527479329925555, 1.2549672072866216, 1.2571517130321839, 1.2593025805195548, 1.2614208848972142, 1.2635076497298003, 1.2655638502723434, 1.2675904164875584, 1.26958823583009, 1.2715581558190487, 1.2735009864179263, 1.2754175022389942, 1.2773084445875398, 1.2791745233597491, 1.281016418806671, 1.2828347831754765, 1.2846302422381501, 1.2864033967167818, 1.2881548236137619, 1.2898850774544235, 1.2915946914489695, 1.2932841785799245, 1.2949540326207798, 1.2966047290910052, 1.2982367261521606, 1.2998504654494183, 1.3014463729024601, 1.3030248594493639, 1.304586321746809, 1.306131142829651, 1.3076596927326696, 1.309172329077076, 1.3106693976241515, 1.312151232798215, 1.313618158180941, 1.3150704869788954, 1.31650852246602, 1.3179325584026624, 1.3193428794326318, 1.3207397614596572, 1.3221234720045154, 1.323494270544018, 1.3248524088329496, 1.3261981312099824, 1.3275316748885193, 1.3288532702333444], [0.0, 0.8424172486141028, 0.9028804514474342, 0.9402414133840812, 0.9676833077041481, 0.9895192582062143, 1.007725795242675, 1.0233803045571623, 1.0371372893366482, 1.0494252306643652, 1.0605404816140187, 1.070696835324435, 1.0800537648543813, 1.0887334987604584, 1.096831852506676, 1.1044253752367947, 1.1115762237178446, 1.1183355810076578, 1.1247461131420948, 1.1308437721590558, 1.1366591441393648, 1.1422184737661238, 1.147544454522321, 1.1526568462083528, 1.1575729632833396, 1.162308065239424, 1.1668756717457496, 1.1712878193603735, 1.175555272381177, 1.1796876973548314, 1.1836938085304842, 1.1875814898922024, 1.1913578981670916, 1.1950295502703652, 1.1986023979341147, 1.2020818917160287, 1.2054730361565402, 1.2087804375179136, 1.2120083452745145, 1.2151606883135608, 1.2182411066377867, 1.2212529792263787, 1.2241994486012386, 1.227083442556656, 1.2299076934377098, 1.2326747552928772, 1.2353870191768899, 1.2380467268388704, 1.2406559829965822, 1.2432167663690183, 1.2457309396155172, 1.248200258309318, 1.250626379056305, 1.2530108668551287, 1.2553552017824519, 1.2576607850764745, 1.2599289446827693, 1.2621609403186391, 1.2643579681054542, 1.266521164812586, 1.268651611751489, 1.2707503383540875, 1.2728183254657754, 1.274856508380008, 1.2768657796385043, 1.2788469916185308, 1.2808009589264584, 1.2827284606147968, 1.2846302422381501, 1.2865070177619768, 1.2883594713366657, 1.2901882589482045, 1.2919940099556333, 1.2937773285245056, 1.2955387949647095, 1.2972789669802325, 1.2989983808377497, 1.3006975524603077, 1.3023769784518104, 1.3040371370575041, 1.305678489065226, 1.3073014786517505, 1.3089065341782196, 1.3104940689382936, 1.3120644818623703, 1.313618158180941, 1.3151554700499015, 1.3166767771404222, 1.31818242719576, 1.3196727565572237, 1.3211480906613249, 1.322608744509995, 1.3240550231156052, 1.3254872219223979, 1.3269056272058204, 1.328310516451139, 1.3297021587126154, 1.3310808149544362, 1.3324467383744967, 1.3338001747120691, 1.335141362540313, 1.3364705335445115], [0.0, 0.8469842998552982, 0.907775295769791, 0.9453388051113797, 0.9729294719520966, 0.9948838031081763, 1.0131890444241456, 1.0289284225448125, 1.042759988957706, 1.055114547698332, 1.0662900584785258, 1.076501473487717, 1.0859091303463047, 1.0946359202564868, 1.1027781781328598, 1.1104128681200196, 1.1176024839595071, 1.1243984861911838, 1.1308437721590558, 1.1369744888101379, 1.142821388043556, 1.1484108568244147, 1.1537657116653521, 1.158905819491852, 1.1638485886310337, 1.1686093613023147, 1.1732017304698965, 1.1776377979464097, 1.1819283863869205, 1.1860832147439766, 1.1901110445098497, 1.1940198024105604, 1.1978166839724431, 1.2015082414412859, 1.2051004588156915, 1.2085988162028103, 1.2120083452745143, 1.2153336772652967, 1.2185790846874736, 1.2217485177281941, 1.2248456361239748, 1.2278738371726818, 1.2308362804329742, 1.2337359095717821, 1.236575471747225, 1.2393575348542079, 1.2420845029102423, 1.2447586298177915, 1.247382031705061, 1.2499566980184016, 1.2524845015153079, 1.2549672072866216, 1.257406480919292, 1.2598038958963984, 1.262160940318639, 1.2644790230208374, 1.2667594791478434, 1.2690035752463473, 1.2712125139223294, 1.2733874381080028, 1.275529434977006, 1.2776395395421891, 1.279718737966467, 1.2817679706138614, 1.283788134864886, 1.2857800877178558, 1.2877446481954193, 1.2896825995736148, 1.2915946914489693, 1.2934816416576087, 1.295344138058951, 1.297182840195323, 1.2989983808377492, 1.300791367427186, 1.3025623834195927, 1.3043119895424733, 1.3060407249698005, 1.307749108421628, 1.3094376391941303, 1.311106798125296, 1.3127570485010611, 1.3143888369062444, 1.3160025940242899, 1.3175987353894736, 1.3191776620949405, 1.320739761459657, 1.3222854076571118, 1.3238149623083841, 1.3253287750419733, 1.3268271840226178, 1.3283105164511388, 1.3297790890372083, 1.3312332084467808, 1.33267317172581, 1.3340992667017462, 1.3355117723642052, 1.3369109592260895, 1.3382970896663682, 1.339670418255614, 1.3410311920653426, 1.3423796509621047, 1.3437160278872342], [0.0, 0.8513399225207846, 0.9124435365554808, 0.9502002165056763, 0.9779327685429284, 1.0, 1.0183993761470242, 1.0342196941293802, 1.0481223894689577, 1.0605404816140187, 1.0717734625362931, 1.0820373898183426, 1.091493425617897, 1.100265093106018, 1.1084492226002718, 1.1161231740339044, 1.123349762522958, 1.1301807132434794, 1.1366591441393648, 1.142821388043556, 1.1486983549970349, 1.1543165676600577, 1.1596989598793381, 1.1648655007461621, 1.1698336881100933, 1.174618943088019, 1.179234928546054, 1.1836938085304842, 1.1880064613519559, 1.1921826559427973, 1.1962311988513155, 1.2001600575667746, 1.2039764646185536, 1.2076870059474099, 1.2112976963247013, 1.214814044039067, 1.2182411066377865, 1.221583539171509, 1.224845636123975, 1.2280313679961983, 1.2311444133449163, 1.2341881869386226, 1.2371658645840293, 1.2400804050858942, 1.242934569729616, 1.2457309396155174, 1.248471931123787, 1.2511598097475969, 1.2537967024973569, 1.2563846090501591, 1.258925411794167, 1.2614208848972142, 1.2638727025115424, 1.2662824462118787, 1.268651611751489, 1.2709816152101405, 1.2732737985986746, 1.2755294349770063, 1.277749733135526, 1.2799358418839835, 1.2820888539868154, 1.284209809779432, 1.286299700496099, 1.2883594713366657, 1.290390024296432, 1.2923922207808318, 1.2943668840243443, 1.2963148013310097, 1.2982367261521603, 1.3001333800153998, 1.3020054543174677, 1.3038536119923916, 1.305678489065226, 1.307480696100696, 1.3092608195551876, 1.3110194230397498, 1.3127570485010613, 1.3144742173266972, 1.3161714313804662, 1.3178491739730696, 1.3195079107728942, 1.3211480906613249, 1.3227701465365977, 1.324374496069877, 1.3259615424169318, 1.3275316748885193, 1.3290852695823177, 1.330622689979045, 1.3321442875051681, 1.3336504020644393, 1.335141362540313, 1.3366174872711423, 1.3380790844999138, 1.3395264528001418, 1.3409598814794317, 1.3423796509621049, 1.3437860331521787, 1.345179291777908, 1.3465596827189963, 1.347927454317526, 1.3492828476735634, 1.3506260969263448], [0.0, 0.8555037734677596, 0.9169062415024053, 0.9548475870408182, 0.9827157772761715, 1.0048909381985118, 1.0233803045571623, 1.0392779987370508, 1.0532486913003272, 1.065727519566613, 1.0770154403043632, 1.0873295678204233, 1.0968318525066763, 1.1056464216783795, 1.1138705792441983, 1.1215820635000313, 1.1288439967867707, 1.1357083572651032, 1.1422184737661238, 1.1484108568244147, 1.1543165676600577, 1.1599622586540015, 1.1653709758209865, 1.1705627859198902, 1.175555272381177, 1.1803639317454637, 1.1850024937030992, 1.1894831817939682, 1.193816927533861, 1.1980135476343512, 1.202081891716029, 1.206029966236656, 1.2098650390994659, 1.2135937284566447, 1.2172220784974253, 1.2207556244511462, 1.2241994486012386, 1.2275582287659164, 1.2308362804329742, 1.2340375935229018, 1.2371658645840296, 1.240224525086273, 1.2432167663690183, 1.2461455617083548, 1.2490136858949574, 1.251823732653151, 1.2545781301814904, 1.2572791550535345, 1.2599289446827695, 1.262529508526585, 1.2650827381797884, 1.2675904164875587, 1.2700542257903127, 1.2724757553981614, 1.274856508380008, 1.2771979077415783, 1.2795013020574053, 1.2817679706138616, 1.283999128113457, 1.2861959289846985, 1.2883594713366657, 1.290490800592986, 1.2925909128359896, 1.2946607578884408, 1.2967012421572421, 1.2987132312609084, 1.3006975524603077, 1.302654996910136, 1.304586321746809, 1.3064922520268776, 1.3083734825286597, 1.3102306794285528, 1.3120644818623703, 1.3138755033810718, 1.315664333309365, 1.317431538014886, 1.319177662094941, 1.3209032294871794, 1.322608744509995, 1.3242946928379318, 1.325961542416932, 1.3276097443238313, 1.3292397335741446, 1.33085192988184, 1.3324467383744967, 1.334024550266966, 1.3355857434963974, 1.3371306833212702, 1.3386597228868566, 1.3401732037593572, 1.3416714564307746, 1.3431548007964358, 1.3446235466069243, 1.346077993896059, 1.3475184333864314, 1.3489451468739004, 1.3503584075923496, 1.3517584805599117, 1.3531456229077827, 1.3545200841926703, 1.355882106693847, 1.357231925695709], [0.0, 0.8594928497600736, 0.92118162761254, 0.959299887533659, 0.9872980226511102, 1.009576582776887, 1.0281521620726264, 1.0441239846396972, 1.058159820292016, 1.070696835324435, 1.0820373898183429, 1.092399610449625, 1.1019462027587548, 1.1108018728466673, 1.1190643783344796, 1.126811819999242, 1.1341076145111557, 1.1410039823966969, 1.147544454522321, 1.1537657116653521, 1.1596989598793381, 1.1653709758209865, 1.1708049129648925, 1.176020931637998, 1.1810366972594708, 1.185867778627801, 1.1905279694526718, 1.1950295502703652, 1.1993835035685696, 1.2035996918326026, 1.2076870059474099, 1.2116534897035762, 1.215506444893397, 1.2192525205284364, 1.2228977889810075, 1.2264478112903319, 1.2299076934377098, 1.2332821350532677, 1.2365754717472253, 1.2397917120444277, 1.2429345697296161, 1.2460074922730966, 1.2490136858949574, 1.2519561377351949, 1.254837635522886, 1.2576607850764747, 1.2604280259168141, 1.263141645232759, 1.265803790404211, 1.268416480258335, 1.2709816152101407, 1.2735009864179265, 1.2759762840665922, 1.2784091048769457, 1.2808009589264584, 1.2831532758561022, 1.2854674105285964, 1.2877446481954198, 1.2899862092230439, 1.2921932534228902, 1.2943668840243445, 1.2965081513256753, 1.2986180560537848, 1.300697552460308, 1.3027475511785762, 1.3047689218633445, 1.306762495632865, 1.30872906733086, 1.3106693976241515, 1.3125842149501115, 1.3144742173266974, 1.31634007403658, 1.31818242719576, 1.3200018932160862, 1.3217990641701929, 1.3235745090665967, 1.3253287750419738, 1.3270623884770103, 1.3287758560416552, 1.330469665675075, 1.3321442875051683, 1.3338001747120694, 1.3354377643397004, 1.3370574780590883, 1.3386597228868564, 1.3402448918620287, 1.341813364684014, 1.3433655083144336, 1.3449016775452187, 1.3464222155352383, 1.3479274543175261, 1.3494177152790292, 1.3508933096146485, 1.3523545387572122, 1.353801694784904, 1.3552350608075523, 1.3566549113330855, 1.3580615126153734, 1.3594551229845735, 1.3608359931610363, 1.362204366553743, 1.363560479544184], [0.0, 0.8633219511791957, 0.9252855568989152, 0.9635736363632674, 0.9916965051523726, 1.0140743178387932, 1.0327326526537461, 1.0487756308196967, 1.0628739971122994, 1.0754668654331614, 1.086857942899213, 1.0972663279561043, 1.1068554510089965, 1.1157505737333215, 1.1240498892673114, 1.1318318463325003, 1.1391601441248391, 1.146087235816942, 1.1526568462083528, 1.158905819491852, 1.1648655007461621, 1.1705627859198902, 1.176020931637998, 1.1812601880431086, 1.1862982992550826, 1.191150903432507, 1.1958318557370178, 1.200353491415554, 1.2047268418835633, 1.2089618135644329, 1.2130673369526295, 1.2170514916743937, 1.2209216120520217, 1.2246843767188944, 1.2283458851001732, 1.2319117230099024, 1.2353870191768899, 1.2387764941684467, 1.2420845029102427, 1.245315071785385, 1.2484719311237873, 1.251558543754481, 1.2545781301814904, 1.2575336908527326, 1.2604280259168144, 1.2632637528012847, 1.2660433218952354, 1.2687690305771087, 1.2714430357935356, 1.274067365365699, 1.2766439281750919, 1.2791745233597493, 1.2816608486344645, 1.2841045078335491, 1.2865070177619768, 1.288869814429871, 1.29119425873596, 1.2934816416576091, 1.2957331889981087, 1.2979500657359222, 1.3001333800154, 1.302284186813964, 1.3044034913168256, 1.3064922520268776, 1.308551383634388, 1.310581759668485, 1.3125842149501115, 1.3145595478640744, 1.3165085224660202, 1.3184318704385611, 1.320330292909374, 1.322204462142831, 1.3240550231156052, 1.3258825949857038, 1.3276877724634861, 1.3294711270924426, 1.3312332084467813, 1.3329745452522521, 1.3346956464360544, 1.3363970021111578, 1.338079084499914, 1.339742348801407, 1.3413872340066209, 1.343014163665156, 1.3446235466069243, 1.3462157776219659, 1.3477912381012773, 1.3493502966413202, 1.3508933096146487, 1.3524206217089287, 1.3539325664364248, 1.3554294666158855, 1.356911634828607, 1.3583793738503223, 1.3598329770604438, 1.3612727288300739, 1.3626989048900937, 1.364111772680553, 1.365511591682488, 1.3668986137332262, 1.3682730833261532, 1.3696352378958552], [0.0, 0.867004045984223, 0.9292319283974861, 0.9676833077041481, 0.9959261213978505, 1.0183993761470242, 1.0371372893366482, 1.0532486913003272, 1.067407187560915, 1.0800537648543813, 1.091493425617897, 1.1019462027587548, 1.1115762237178446, 1.1205092844155164, 1.1288439967867707, 1.1366591441393648, 1.1440186973482882, 1.1509753333005581, 1.1575729632833396, 1.1638485886310337, 1.1698336881100933, 1.175555272381177, 1.1810366972594708, 1.1862982992550826, 1.1913578981670916, 1.1962311988513155, 1.200932115562082, 1.2054730361565404, 1.2098650390994656, 1.2141180730654473, 1.2182411066377865, 1.22224225390258, 1.2261288804632349, 1.2299076934377098, 1.2335848182654034, 1.2371658645840293, 1.2406559829965822, 1.2440599142037387, 1.2473820317050612, 1.250626379056305, 1.2537967024973569, 1.2568964796263202, 1.2599289446827693, 1.2628971109116238, 1.2658037904042108, 1.2686516117514892, 1.2714430357935353, 1.2741803697071823, 1.2768657796385043, 1.279501302057405, 1.2820888539868154, 1.2846302422381501, 1.2871271717670083, 1.289581253248105, 1.2919940099556333, 1.2943668840243443, 1.2967012421572421, 1.2989983808377497, 1.3012595310972463, 1.3034858628828652, 1.305678489065226, 1.3078384691212623, 1.3099668125233312, 1.3120644818623703, 1.3141323957298299, 1.3161714313804662, 1.3181824271957598, 1.3201661849656539, 1.3221234720045154, 1.3240550231156052, 1.325961542416932, 1.3278437050400957, 1.3297021587126152, 1.3315375252332258, 1.3333504018487445, 1.3351413625403128, 1.3369109592260897, 1.3386597228868564, 1.3403881646204028, 1.3420967766300453, 1.343786033152179, 1.3454563913273254, 1.347108292018779, 1.3487421605825922, 1.3503584075923494, 1.3519574295218821, 1.3535396093888319, 1.3551053173617347, 1.3566549113330852, 1.3581887374606532, 1.3597071306791426, 1.3612104151841344, 1.3626989048900935, 1.3641729038641006, 1.3656327067368408, 1.3670785990922678, 1.3685108578372633, 1.3699297515525173, 1.3713355408257606, 1.3727284785684148, 1.3741088103166372, 1.37547677451768], [0.0, 0.870550563296124, 0.9330329915368073, 0.9716416578630734, 0.9999999999999999, 1.0225651825635729, 1.0413797439924106, 1.0575570503382523, 1.0717734625362931, 1.0844717711976986, 1.0959582263852172, 1.1064537610602054, 1.1161231740339044, 1.125092775800282, 1.1334615816706974, 1.141308697219414, 1.1486983549970349, 1.1556834473676474, 1.162308065239424, 1.1686093613023147, 1.174618943088019, 1.1803639317454637, 1.185867778627801, 1.191150903432507, 1.1962311988513155, 1.201124433981431, 1.2058445799940374, 1.2104040754193455, 1.214814044039067, 1.2190844752232717, 1.2232243742416369, 1.2272418883712768, 1.2311444133449163, 1.234938683716268, 1.2386308499811034, 1.2422265447236005, 1.2457309396155172, 1.2491487947495696, 1.252484501515308, 1.2557421200088266, 1.2589254117941673, 1.2620378686946978, 1.2650827381797884, 1.2680630458201667, 1.2709816152101405, 1.2738410856930327, 1.2766439281750919, 1.2793924592707566, 1.2820888539868154, 1.2847351571234393, 1.2873332935452237, 1.2898850774544235, 1.2923922207808316, 1.2948563407876974, 1.2972789669802325, 1.299661547392302, 1.3020054543174677, 1.3043119895424735, 1.3065823891342858, 1.308817827825756, 1.3110194230397498, 1.3131882385870361, 1.3153252880692625, 1.3174315380148858, 1.3195079107728942, 1.3215552871864926, 1.3235745090665967, 1.3255663814829057, 1.327531674888519, 1.3294711270924424, 1.331385445092909, 1.3332753067831737, 1.3351413625403128, 1.3369842367065554, 1.3388045289717834, 1.3406028156650318, 1.3423796509621049, 1.3441355680157836, 1.3458710800145255, 1.3475866811750257, 1.3492828476735632, 1.3509600385206133, 1.35261869638284, 1.3542592483562335, 1.3558821066938467, 1.3574876694913045, 1.3590763213329982, 1.3606484339016547, 1.3622043665537429, 1.3637444668630059, 1.3652690711342126, 1.3667785048890797, 1.3682730833261527, 1.3697531117563122, 1.3712188860154422, 1.37267069285569, 1.374108810316637, 1.375533508077614, 1.376945047792297, 1.378343683406653, 1.379729661461215, 1.3811032213786139], [0.0, 0.8739716291356505, 0.9366995991172012, 0.9754599887264647, 1.0039297727022005, 1.026583631304232, 1.0454721296829765, 1.0617130091656912, 1.0759852886323114, 1.0887334987604584, 1.100265093106018, 1.110801872846667, 1.1205092844155164, 1.129514134678065, 1.13791582805334, 1.145793780982531, 1.1532124784355648, 1.160225020631498, 1.1668756717457496, 1.1732017304698965, 1.179234928546054, 1.1850024937030992, 1.1905279694526718, 1.1958318557370178, 1.200932115562082, 1.2058445799940374, 1.2105832751075947, 1.2151606883135608, 1.2195879871075817, 1.2238752001156807, 1.2280313679961983, 1.2320646700431954, 1.235982531052946, 1.2397917120444277, 1.2434983876834627, 1.2471082126890045, 1.250626379056305, 1.2540576655841633, 1.2574064809192922, 1.2606769011130408, 1.2638727025115426, 1.2669973906602376, 1.2700542257903127, 1.2730462453623002, 1.2759762840665922, 1.2788469916185308, 1.2816608486344645, 1.2844201808326001, 1.2871271717670085, 1.2897838742734604, 1.2923922207808316, 1.2949540326207798, 1.2974710284505926, 1.2999448318889961, 1.3023769784518104, 1.3047689218633443, 1.3071220398099608, 1.3094376391941305, 1.3117169609402817, 1.313961184397699, 1.3161714313804662, 1.3183487698798864, 1.3204942174808312, 1.322608744509995, 1.3246932769409874, 1.326748699078527, 1.3287758560416552, 1.330775556063812, 1.3327485726258026, 1.3346956464360542, 1.3366174872711423, 1.3385147756882885, 1.3403881646204026, 1.3422382808632374, 1.3440657264633193, 1.3458710800145255, 1.3476548978704452, 1.349417715279029, 1.3511600474454477, 1.3528823905285563, 1.3545852225758983, 1.3562690044017556, 1.3579341804123715, 1.3595811793821266, 1.3612104151841344, 1.3628222874784452, 1.3644171823607798, 1.3659954729744934, 1.3675575200882444, 1.3691036726416612, 1.3706342682611146, 1.3721496337475474, 1.3736500855381637, 1.3751359301436463, 1.3766074645624475, 1.378064976673585, 1.3795087456092727, 1.3809390421086196, 1.3823561288535418, 1.3837602607879549, 1.3851516854212416, 1.3865306431169089], [0.0, 0.8772762586965454, 0.9402414133840813, 0.9791483623609769, 1.007725795242675, 1.0304653117863476, 1.0494252306643652, 1.065727519566613, 1.0800537648543813, 1.0928501780484332, 1.1044253752367947, 1.1150019962636444, 1.1247461131420948, 1.1337850122151278, 1.1422184737661238, 1.1501262145228153, 1.1575729632833396, 1.1646120210473587, 1.1712878193603735, 1.1776377979464097, 1.1836938085304842, 1.1894831817939682, 1.1950295502703652, 1.200353491415554, 1.2054730361565404, 1.2104040754193455, 1.2151606883135608, 1.219755409466935, 1.2241994486012389, 1.2285028722623708, 1.2326747552928772, 1.2367233079140674, 1.2406559829965824, 1.2444795671239186, 1.248200258309318, 1.251823732653151, 1.2553552017824519, 1.258799462565439, 1.2621609403186391, 1.2654437265056175, 1.2686516117514894, 1.2717881148567352, 1.2748565083800083, 1.2778598412669764, 1.2808009589264586, 1.283682521092804, 1.2865070177619768, 1.289276783446105, 1.2919940099556335, 1.2946607578884408, 1.2972789669802325, 1.2998504654494185, 1.3023769784518104, 1.3048601357453025, 1.3073014786517507, 1.3097024663922332, 1.3120644818623706, 1.3143888369062449, 1.3166767771404224, 1.3189294863735006, 1.3211480906613249, 1.3233336620334488, 1.325487221922398, 1.3276097443238313, 1.3297021587126154, 1.3317653527371702, 1.3338001747120694, 1.3358074359268162, 1.3377879127868733, 1.339742348801407, 1.3416714564307746, 1.3435759188054954, 1.3454563913273254, 1.3473135031620345, 1.3491478586325854, 1.3509600385206135, 1.3527506012833717, 1.3545200841926703, 1.3562690044017556, 1.35799785994554, 1.3597071306791426, 1.36139727915926, 1.363068751472508, 1.3647219780145328, 1.3663573742233701, 1.3679753412702504, 1.369576266710785, 1.3711605250992454, 1.372728478568415, 1.3742804773773205, 1.3758168604289527, 1.3773379557599423, 1.3788440810039944, 1.3803355438307583, 1.3818126423616863, 1.383275665564314, 1.3847248936262992, 1.3861605983104601, 1.3875830432919558, 1.3889924844786872, 1.3903891703159095, 1.391773342075984], [0.0, 0.8804725142695762, 0.9436670752867395, 0.9827157772761717, 1.0113973287615656, 1.0342196941293804, 1.0532486913003272, 1.069610375725069, 1.0839888170467409, 1.0968318525066763, 1.108449222600272, 1.1190643783344796, 1.128843996786771, 1.1379158280533404, 1.1463800159556026, 1.1543165676600577, 1.1617904477968057, 1.1688551515615961, 1.175555272381177, 1.1819283863869205, 1.1880064613519559, 1.193816927533861, 1.1993835035685696, 1.2047268418835633, 1.2098650390994656, 1.214814044039067, 1.2195879871075817, 1.2241994486012389, 1.2286596790831474, 1.2329787817755122, 1.2371658645840293, 1.2412291676430092, 1.2451761709767732, 1.2490136858949574, 1.2527479329925557, 1.2563846090501594, 1.2599289446827693, 1.263385754235444, 1.2667594791478438, 1.2700542257903127, 1.2732737985986748, 1.276421729193757, 1.2795013020574053, 1.2825155772437715, 1.2854674105285964, 1.288359471336666, 1.29119425873596, 1.2939741157441336, 1.2967012421572421, 1.2993777060807168, 1.3020054543174677, 1.3045863217468092, 1.3071220398099608, 1.3096142442026526, 1.3120644818623706, 1.3144742173266974, 1.3168448385296756, 1.319177662094941, 1.3214739381773213, 1.3237348548984844, 1.325961542416932, 1.3281550766680341, 1.330316482805789, 1.3324467383744967, 1.3345467762354597, 1.3366174872711425, 1.3386597228868566, 1.3406742973279453, 1.3426619898286156, 1.3446235466069243, 1.3465596827189963, 1.348471083784259, 1.3503584075923496, 1.352222285601331, 1.354063324335948, 1.355882106693847, 1.3576791931669558, 1.3594551229845735, 1.3612104151841344, 1.3629455696150847, 1.3646610678808404, 1.3663573742233703, 1.3680349363545556, 1.3696941862381404, 1.3713355408257608, 1.3729594027502685, 1.3745661609792896, 1.3761561914317413, 1.3777298575597963, 1.3792875108986098, 1.3808294915859267, 1.3823561288535418, 1.383867741492422, 1.3853646382931764, 1.386847118463428, 1.3883154720235324, 1.3897699801819798, 1.3912109156917245, 1.392638543188596, 1.394053119512866, 1.395454894014972, 1.3968441088463233], [0.0, 0.8835676359470229, 0.9469843445639476, 0.9861703143068246, 1.0149526899409642, 1.0378552826828715, 1.05695117241513, 1.073370373006841, 1.0877993588085522, 1.1006875413421462, 1.1123457499326046, 1.1229982210833527, 1.1328122177911584, 1.1419159392316425, 1.1504098812614143, 1.1583743322958617, 1.1658744853350014, 1.1729640236260406, 1.1796876973548314, 1.1860832147439766, 1.1921826559427973, 1.1980135476343512, 1.2035996918326026, 1.2089618135644329, 1.2141180730654473, 1.2190844752232717, 1.2238752001156807, 1.2285028722623708, 1.2329787817755122, 1.2373130673931285, 1.2415148690379023, 1.2455924558106561, 1.2495533340302134, 1.25340433894998, 1.257151713032184, 1.2608011730832882, 1.2643579681054542, 1.2678269293675892, 1.2712125139223298, 1.274518842575128, 1.2777497331355263, 1.2809087296390451, 1.283999128113457, 1.2870239993699106, 1.2899862092230439, 1.2928884364814621, 1.2957331889981087, 1.29852281802704, 1.3012595310972466, 1.3039454035841622, 1.3065823891342858, 1.3091723290770763, 1.3117169609402817, 1.3142179261695874, 1.3166767771404224, 1.3190949835386532, 1.3214739381773213, 1.3238149623083844, 1.3261193104813351, 1.328388174994441, 1.3306226899790452, 1.3328239351527493, 1.3349929392732718, 1.3371306833212702, 1.3392381034373309, 1.3413160936356343, 1.3433655083144336, 1.3453871645813855, 1.3473818444099361, 1.3493502966413202, 1.351293238845296, 1.3532113590514467, 1.3551053173617347, 1.3569757474539854, 1.3588232579850572, 1.360648433901655, 1.362451837666001, 1.3642340104029458, 1.3659954729744934, 1.367736726987209, 1.3694582557374875, 1.3711605250992454, 1.372843984358204, 1.3745090669965878, 1.3761561914317413, 1.3777857617118903, 1.379398168171997, 1.3809937880524448, 1.382572986083049, 1.3841361150347142, 1.385683516240871, 1.3872155200906608, 1.388732446495696, 1.3902346053320753, 1.3917222968592255, 1.3931958121170098, 1.3946554333024492, 1.3961014341273057, 1.3975340801576817, 1.3989536291367193, 1.4003603312913961, 1.4017544296243551], [0.0, 0.8865681505652133, 0.9502002165056763, 0.9895192582062143, 1.018399376147024, 1.0413797439924106, 1.0605404816140187, 1.0770154403043632, 1.091493425617897, 1.1044253752367947, 1.1161231740339044, 1.1268118199992418, 1.1366591441393648, 1.145793780982531, 1.1543165676600575, 1.1623080652394242, 1.1698336881100933, 1.1769473018226544, 1.1836938085304842, 1.1901110445098497, 1.1962311988513155, 1.202081891716029, 1.2076870059474099, 1.2130673369526295, 1.2182411066377865, 1.2232243742416369, 1.2280313679961983, 1.2326747552928772, 1.2371658645840293, 1.2415148690379023, 1.2457309396155172, 1.2498223734988043, 1.2537967024973569, 1.2576607850764745, 1.2614208848972142, 1.2650827381797884, 1.268651611751489, 1.2721323532877689, 1.2755294349770063, 1.2788469916185308, 1.2820888539868154, 1.2852585781526003, 1.2883594713366657, 1.2913946147783533, 1.2943668840243443, 1.2972789669802325, 1.3001333800153998, 1.3029324823685458, 1.305678489065226, 1.3083734825286597, 1.3110194230397498, 1.313618158180941, 1.3161714313804662, 1.3186808896582096, 1.3211480906613247, 1.3235745090665967, 1.325961542416932, 1.328310516451139, 1.330622689979045, 1.3328992593478532, 1.3351413625403128, 1.3373500829406473, 1.3395264528001418, 1.3416714564307743, 1.3437860331521787, 1.3458710800145255, 1.347927454317526, 1.3499559759436595, 1.3519574295218821, 1.3539325664364246, 1.3558821066938467, 1.3578067406602166, 1.3597071306791424, 1.3615839125803615, 1.363437697087675, 1.3652690711342126, 1.3670785990922676, 1.3688668239243003, 1.3706342682611146, 1.3723814354126849, 1.3741088103166372, 1.3758168604289525, 1.3775060365610854, 1.3791767736673262, 1.3808294915859263, 1.3824645957372221, 1.384082477781718, 1.3856835162408707, 1.387268077083084, 1.3888365142772414, 1.3903891703159093, 1.3919263767102013, 1.3934484544581194, 1.3949557144880733, 1.3964484580791439, 1.3979269772595382, 1.3993915551845928, 1.4008424664955699, 1.40227997766041, 1.4037043472975268, 1.405115826483646, 1.4065146590466258], [0.0, 0.8894799631049141, 0.9533210199136081, 0.9927691996602169, 1.0217441704214383, 1.0448000141602642, 1.0640236826192153, 1.0805527510712007, 1.0950782873588574, 1.1080527102078603, 1.1197889288345146, 1.13051268020414, 1.1403923465414143, 1.1495569848572122, 1.158107763468698, 1.1661255080352226, 1.1736758477909162, 1.1808128252004448, 1.1875814898922024, 1.1940198024105604, 1.2001600575667746, 1.206029966236656, 1.2116534897035762, 1.2170514916743937, 1.22224225390258, 1.2272418883712768, 1.2320646700431954, 1.2367233079140674, 1.2412291676430092, 1.2455924558106561, 1.2498223734988043, 1.2539272451403496, 1.2579146272820898, 1.2617914009150213, 1.2655638502723434, 1.269237730414105, 1.2728183254657754, 1.2763104990243386, 1.279718737966467, 1.2830471906716767, 1.286299700496099, 1.289479835189904, 1.2925909128359896, 1.2956360247936085, 1.2986180560537848, 1.3015397033501719, 1.3044034913168254, 1.3072117869410431, 1.3099668125233312, 1.3126706573263447, 1.3153252880692625, 1.3179325584026627, 1.3204942174808312, 1.323011917733065, 1.325487221922398, 1.3279216095689905, 1.330316482805789, 1.3326731717258102, 1.3349929392732716, 1.3372769857246158, 1.3395264528001418, 1.341742427442301, 1.343925945292668, 1.3460779938960592, 1.348199515657176, 1.3502914105724286, 1.3523545387572122, 1.3543897227867991, 1.3563977498671524, 1.3583793738503223, 1.3603353171076316, 1.3622662722725625, 1.3641729038641006, 1.3660558498002795, 1.3679157228107393, 1.3697531117563122, 1.3715685828628956, 1.3733626808762356, 1.3751359301436465, 1.376888835628156, 1.3786218838601008, 1.3803355438307583, 1.3820302678322123, 1.3837064922473004, 1.3853646382931764, 1.3870051127217244, 1.3886283084798043, 1.3902346053320753, 1.391824370448915, 1.3933979589617687, 1.3949557144880738, 1.3964979696277464, 1.3980250464330635, 1.3995372568536368, 1.4010349031580567, 1.4025182783336578, 1.4039876664657618, 1.4054433430976525, 1.4068855755724483, 1.4083146233579602, 1.4097307383555409, 1.4111341651938678], [0.0, 0.8923084338428022, 0.9563524997900371, 0.9959261213978506, 1.0249932301052076, 1.048122389468958, 1.0674071875609152, 1.0839888170467409, 1.0985605433061179, 1.1115762237178448, 1.1233497625229583, 1.1341076145111557, 1.1440186973482884, 1.1532124784355653, 1.1617904477968057, 1.1698336881100935, 1.1774080373049494, 1.1845677096964866, 1.1913578981670916, 1.1978166839724431, 1.2039764646185536, 1.2098650390994659, 1.215506444893397, 1.2209216120520217, 1.2261288804632349, 1.2311444133449163, 1.235982531052946, 1.2406559829965824, 1.2451761709767732, 1.2495533340302134, 1.2537967024973569, 1.2579146272820898, 1.2619146889603867, 1.265803790404211, 1.26958823583009, 1.2732737985986746, 1.2768657796385043, 1.2803690580123883, 1.2837881348648865, 1.2871271717670085, 1.2903900242964321, 1.2935802715484703, 1.2967012421572421, 1.2997560373122607, 1.3027475511785762, 1.3056784890652262, 1.308551383634388, 1.3113686094001782, 1.3141323957298299, 1.3168448385296756, 1.3195079107728944, 1.3221234720045156, 1.3246932769409874, 1.3272189832661914, 1.3297021587126154, 1.3321442875051681, 1.3345467762354597, 1.3369109592260897, 1.339238103437331, 1.3415294129624031, 1.343786033152179, 1.3460090544054943, 1.3481995156571762, 1.3503584075923496, 1.352486675612483, 1.3545852225758985, 1.3566549113330852, 1.3586965670750355, 1.3607109795109595, 1.3626989048900937, 1.3646610678808404, 1.366598163319197, 1.3685108578372633, 1.370399791381598, 1.3722655786302693, 1.3741088103166372, 1.375930054467149, 1.3777298575597963, 1.379508745609273, 1.381267225184346, 1.3830057843624786, 1.3847248936262992, 1.3864250067061423, 1.3881065613725065, 1.3897699801819796, 1.3914156711798826, 1.393044028562613, 1.3946554333024492, 1.3962502537373394, 1.3978288461280168, 1.399391555184593, 1.4009387145646242, 1.4024706473444852, 1.4039876664657618, 1.4054900751582327, 1.4069781673409072, 1.408452228002474, 1.4099125335624214, 1.4113593522139962, 1.4127929442500948, 1.4142135623730951, 1.4156214519895731], [0.0, 0.8950584438464528, 0.959299887533659, 0.9989954712917501, 1.0281521620726264, 1.0513526033129275, 1.070696835324435, 1.0873295678204236, 1.1019462027587548, 1.1150019962636444, 1.126811819999242, 1.1376028266674396, 1.147544454522321, 1.1567665699713525, 1.1653709758209863, 1.173439004638433, 1.1810366972594708, 1.188218435082593, 1.1950295502703652, 1.2015082414412859, 1.2076870059474099, 1.2135937284566447, 1.2192525205284364, 1.2246843767188944, 1.2299076934377098, 1.234938683716268, 1.2397917120444277, 1.2444795671239186, 1.2490136858949574, 1.25340433894998, 1.2576607850764745, 1.2617914009150213, 1.265803790404211, 1.2697048776900044, 1.2735009864179265, 1.277197907741578, 1.2808009589264584, 1.2843150340721854, 1.2877446481954198, 1.2910939756927386, 1.2943668840243445, 1.297566963315983, 1.300697552460308, 1.3037617622044044, 1.306762495632865, 1.3097024663922334, 1.3125842149501115, 1.315410123138643, 1.31818242719576, 1.3209032294871794, 1.3235745090665967, 1.3261981312099826, 1.3287758560416552, 1.3313093463543206, 1.3338001747120694, 1.3362498299140506, 1.3386597228868566, 1.341031192065343, 1.3433655083144336, 1.3456638794382496, 1.347927454317526, 1.3501573267116054, 1.3523545387572125, 1.3545200841926703, 1.3566549113330855, 1.358759925819303, 1.3608359931610363, 1.3628839410924374, 1.3649045617565259, 1.3668986137332262, 1.3688668239243005, 1.3708098893071645, 1.3727284785684148, 1.3746232336268651, 1.3764947710549633, 1.3783436834066531, 1.3801705404589857, 1.381975890374146, 1.383760260787955, 1.3855241598303778, 1.3872680770830843, 1.3889924844786874, 1.3906978371458745, 1.3923845742043115, 1.394053119512866, 1.3957038823744154, 1.3973372582002337, 1.3989536291367193, 1.4005533646570034, 1.4021368221197807, 1.403704347297527, 1.405256274876099, 1.406792928927563, 1.4083146233579602, 1.4098216623315951, 1.4113143406733077, 1.412792944250095, 1.4142577503333436, 1.4157090279428464, 1.417147038173698, 1.418572034507081, 1.419984263105891], [0.0, 0.8977344508701224, 0.9621679608471888, 1.0019822247447452, 1.031226086938676, 1.0544958918547662, 1.0738979584144939, 1.0905804187347243, 1.1052407538560174, 1.118335581007658, 1.1301807132434794, 1.1410039823966966, 1.1509753333005583, 1.160225020631498, 1.168855151561596, 1.1769473018226546, 1.1845677096964866, 1.1917709191687385, 1.1986023979341147, 1.2051004588156915, 1.2112976963247013, 1.2172220784974253, 1.2228977889810075, 1.2283458851001732, 1.2335848182654034, 1.2386308499811034, 1.2434983876834627, 1.248200258309318, 1.2527479329925557, 1.257151713032184, 1.2614208848972142, 1.2655638502723434, 1.26958823583009, 1.2735009864179265, 1.2773084445875398, 1.281016418806671, 1.2846302422381501, 1.288154823613762, 1.2915946914489695, 1.2949540326207798, 1.2982367261521606, 1.30144637290246, 1.304586321746809, 1.3076596927326698, 1.3106693976241515, 1.313618158180941, 1.3165085224660202, 1.319342879432632, 1.3221234720045154, 1.3248524088329496, 1.327531674888519, 1.3301631410239163, 1.3327485726258026, 1.33528963745823, 1.337787912786873, 1.3402448918620284, 1.3426619898286154, 1.3450405491230844, 1.3473818444099361, 1.3496870871043323, 1.3519574295218821, 1.354193968692002, 1.3563977498671524, 1.3585697697566925, 1.3607109795109595, 1.3628222874784452, 1.3649045617565259, 1.3669586325540772, 1.3689852943824343, 1.370985308089491, 1.372959402750268, 1.3749082774259753, 1.3768326028024191, 1.378733022717594, 1.3806101555873498, 1.3824645957372221, 1.3842969146477573, 1.3861076621200115, 1.387897367367309, 1.389666540038799, 1.3914156711798824, 1.3931452341341353, 1.3948556853909695, 1.3965474653829115, 1.3982209992360641, 1.3998766974770207, 1.4015149566992384, 1.4031361601916412, 1.4047406785319945, 1.4063288701474086, 1.407901081844135, 1.40945764930866, 1.4109988975819456, 1.412525141508537, 1.414036686162115, 1.4155338272489746, 1.4170168514907853, 1.4184860369879078, 1.4199416535644391, 1.421383963096084, 1.422813219821873, 1.424229670640668], [0.0, 0.900340537296277, 0.9649610951198175, 1.0048909381985118, 1.0342196941293802, 1.057557050338252, 1.0770154403043632, 1.0937463291251968, 1.1084492226002718, 1.121582063500031, 1.1334615816706974, 1.1443162703319882, 1.1543165676600577, 1.1635931064553429, 1.1722482903028721, 1.1803639317454637, 1.1880064613519556, 1.195230581446956, 1.2020818917160287, 1.2085988162028103, 1.214814044039067, 1.2207556244511462, 1.2264478112903319, 1.2319117230099024, 1.2371658645840293, 1.2422265447236005, 1.2471082126890045, 1.251823732653151, 1.2563846090501594, 1.2608011730832882, 1.2650827381797884, 1.269237730414105, 1.2732737985986746, 1.277197907741578, 1.281016418806671, 1.284735157123439, 1.2883594713366657, 1.291894284427984, 1.2953441380589512, 1.2987132312609082, 1.3020054543174677, 1.3052244185411253, 1.3083734825286597, 1.3114557753849032, 1.3144742173266972, 1.317431538014886, 1.3203302929093739, 1.3231728778984375, 1.325961542416932, 1.3286984012374645, 1.3313854450929088, 1.3340245502669659, 1.3366174872711423, 1.339165928710941, 1.3416714564307743, 1.3441355680157836, 1.3465596827189963, 1.3489451468739002, 1.3512932388452958, 1.3536051735650332, 1.3558821066938467, 1.3581251384457842, 1.3603353171076316, 1.3625136422821542, 1.3646610678808402, 1.3667785048890797, 1.3688668239243003, 1.37092685760544, 1.372959402750268, 1.3749652224153883, 1.376945047792297, 1.3788995799715495, 1.3808294915859263, 1.3827354283424567, 1.3846180104522268, 1.386477833966075, 1.3883154720235322, 1.3901314760217045, 1.3919263767102013, 1.3937006852176617, 1.3954548940149718, 1.3971894778198044, 1.398904894446742, 1.4006015856068683, 1.4022799776604098, 1.403940482325702, 1.4055834973474965, 1.4072094071273895, 1.4088185833189182, 1.4104113853896927, 1.4119881611527285, 1.4135492472689957, 1.4150949697230377, 1.41662564427338, 1.41814157687932, 1.4196430641055762, 1.421130393506159, 1.4226038439887434, 1.4240636861607145, 1.425510182657992, 1.426943588457651, 1.4283641511752916], [0.0, 0.9028804514474342, 0.9676833077041481, 1.0077257952426748, 1.037137289336648, 1.0605404816140187, 1.0800537648543813, 1.096831852506676, 1.1115762237178446, 1.1247461131420948, 1.1366591441393648, 1.147544454522321, 1.1575729632833396, 1.1668756717457496, 1.1755552723811769, 1.1836938085304842, 1.1913578981670914, 1.1986023979341147, 1.2054730361565402, 1.2120083452745143, 1.2182411066377865, 1.2241994486012386, 1.2299076934377098, 1.2353870191768899, 1.2406559829965822, 1.2457309396155172, 1.250626379056305, 1.2553552017824519, 1.2599289446827693, 1.2643579681054542, 1.268651611751489, 1.2728183254657754, 1.2768657796385043, 1.2808009589264584, 1.2846302422381501, 1.2883594713366657, 1.291994009955633, 1.2955387949647097, 1.2989983808377494, 1.3023769784518104, 1.305678489065226, 1.3089065341782196, 1.3120644818623703, 1.3151554700499015, 1.31818242719576, 1.3211480906613249, 1.3240550231156052, 1.3269056272058206, 1.3297021587126154, 1.3324467383744965, 1.3351413625403128, 1.3377879127868733, 1.3403881646204026, 1.3429437953649235, 1.3454563913273252, 1.347927454317526, 1.3503584075923494, 1.3527506012833714, 1.3551053173617347, 1.3574237741866844, 1.3597071306791424, 1.3619564901569263, 1.3641729038641006, 1.3663573742233701, 1.3685108578372633, 1.3706342682611146, 1.3727284785684148, 1.37479432372697, 1.3768326028024191, 1.3788440810039941, 1.3808294915859263, 1.3827895376165888, 1.384724893626299, 1.3866362071436644, 1.3885241001294235, 1.3903891703159093, 1.3922319924595132, 1.3940531195128658, 1.395853083722852, 1.397632397660036, 1.3993915551845928, 1.4011310323534027, 1.4028512882725694, 1.4045527658992705, 1.40623589279652, 1.407901081844135, 1.409548731908929, 1.4111792284769176, 1.4127929442500948, 1.4143902397101502, 1.4159714636513008, 1.4175369536842568, 1.4190870367131838, 1.4206220293873804, 1.422142238529274, 1.423647961540209, 1.4251394867854035, 1.426617093959347, 1.4280810544328246, 1.4295316315826672, 1.4309690811052556, 1.4323936513147282], [0.0, 0.9053576433419919, 0.970338296238345, 1.0104906465227195, 1.0399828355909384, 1.06345023813903, 1.0830170590841925, 1.0998411800099643, 1.1146260046796126, 1.1278320277285099, 1.1397777439653138, 1.1506929198776512, 1.1607489434005382, 1.170077175279657, 1.1787805897392818, 1.186941455218846, 1.1946265724684626, 1.201890948638917, 1.2087804375179136, 1.2153336772652967, 1.221583539171509, 1.2275582287659164, 1.2332821350532677, 1.2387764941684467, 1.2440599142037387, 1.2491487947495696, 1.2540576655841633, 1.258799462565439, 1.263385754235444, 1.2678269293675892, 1.2721323532877689, 1.2763104990243386, 1.2803690580123883, 1.2843150340721854, 1.288154823613762, 1.291894284427984, 1.2955387949647097, 1.2990933056386604, 1.302562383419593, 1.305950250737756, 1.3092608195551878, 1.3124977213082563, 1.3156643333093652, 1.318763802100139, 1.321799064170193, 1.3247728643912797, 1.3276877724634863, 1.3305461976260657, 1.333350401848745, 1.336102511688604, 1.3388045289717836, 1.3414583404374887, 1.3440657264633193, 1.346628368975296, 1.3491478586325856, 1.351625701365553, 1.3540633243359481, 1.35646208137964, 1.3588232579850574, 1.3611480758542023, 1.3634376970876751, 1.3656932280304157, 1.3679157228107395, 1.3701061866016522, 1.3722655786302695, 1.3743948149584055, 1.3764947710549633, 1.3785662841786117, 1.3806101555873498, 1.3826271525898792, 1.384618010452227, 1.3865834341717433, 1.3885241001294237, 1.39044065763047, 1.392333730342066, 1.394203917636516, 1.396051795847144, 1.3978779194436914, 1.399682822133345, 1.4014670178929851, 1.4032310019377685, 1.4049752516307108, 1.4067002273375446, 1.4084063732307686, 1.4100941180464819, 1.4117638757973014, 1.4134160464443928, 1.4150510165314123, 1.4166691597829197, 1.4182708376696413, 1.419856399942765, 1.4214261851392884, 1.4229805210602886, 1.424519725223841, 1.4260441052941872, 1.4275539594886386, 1.4290495769635871, 1.430531238180908, 1.4319992152559335, 1.4334537722881096, 1.4348951656753597, 1.4363236444131102], [0.0, 0.9077752957697911, 0.9729294719520967, 1.0131890444241456, 1.042759988957706, 1.066290058478526, 1.0859091303463049, 1.10277817813286, 1.1176024839595073, 1.130843772159056, 1.1428213880435563, 1.1537657116653524, 1.163848588631034, 1.1732017304698967, 1.1819283863869205, 1.19011104450985, 1.1978166839724431, 1.2051004588156917, 1.2120083452745145, 1.2185790846874736, 1.224845636123975, 1.2308362804329742, 1.2365754717472253, 1.2420845029102427, 1.2473820317050612, 1.252484501515308, 1.2574064809192922, 1.2621609403186391, 1.2667594791478438, 1.2712125139223298, 1.2755294349770063, 1.279718737966467, 1.2837881348648865, 1.2877446481954198, 1.2915946914489695, 1.2953441380589512, 1.2989983808377494, 1.302562383419593, 1.3060407249698005, 1.3094376391941305, 1.3127570485010613, 1.3160025940242899, 1.319177662094941, 1.3222854076571122, 1.3253287750419738, 1.328310516451139, 1.3312332084467813, 1.3340992667017466, 1.3369109592260897, 1.3396704182556143, 1.3423796509621049, 1.3450405491230846, 1.3476548978704452, 1.350224383621595, 1.3527506012833714, 1.355235060807552, 1.3576791931669556, 1.3600843558127134, 1.362451837666001, 1.3647828636912342, 1.3670785990922676, 1.3693401531684073, 1.3715685828628956, 1.373764896032936, 1.3759300544671489, 1.378064976673585, 1.3801705404589855, 1.382247585317821, 1.3842969146477573, 1.3863192978065044, 1.3883154720235322, 1.3902861441788046, 1.3922319924595132, 1.3941536679047548, 1.3960517958471437, 1.3979269772595382, 1.3997797900142939, 1.4016107900617987, 1.4034205125344426, 1.4052094727816216, 1.406978167340907, 1.4087270748500569, 1.410456656904157, 1.4121673588618173, 1.4138596106040269, 1.4155338272489748, 1.417190409825877, 1.4188297459106094, 1.42045221022572, 1.4220581652072009, 1.4236479615402091, 1.4252219386657667, 1.4267804252603056, 1.4283237396897956, 1.4298521904400605, 1.431366076524766, 1.432865687872463, 1.4343513056939676, 1.4358232028312639, 1.4372816440890452, 1.4387268865499159, 1.4401591798742157], [0.0, 0.9101363514059138, 0.9754599887264648, 1.0158242733348055, 1.0454721296829765, 1.0690633991544003, 1.0887334987604584, 1.1056464216783795, 1.1205092844155164, 1.1337850122151278, 1.145793780982531, 1.1567665699713525, 1.1668756717457496, 1.1762531404068526, 1.1850024937030992, 1.1932064343076842, 1.200932115562082, 1.2082348349588186, 1.2151606883135608, 1.2217485177281941, 1.2280313679961983, 1.2340375935229018, 1.2397917120444277, 1.245315071785385, 1.250626379056305, 1.2557421200088266, 1.2606769011130408, 1.2654437265056175, 1.2700542257903127, 1.274518842575128, 1.2788469916185308, 1.2830471906716767, 1.2871271717670085, 1.2910939756927386, 1.2949540326207798, 1.2987132312609082, 1.3023769784518104, 1.305950250737756, 1.3094376391941305, 1.312843388538244, 1.3161714313804664, 1.3194254183248106, 1.322608744509995, 1.3257245730858918, 1.3287758560416554, 1.33176535273717, 1.3346956464360542, 1.337569159094139, 1.3403881646204028, 1.3431548007964356, 1.3458710800145255, 1.3485388989725675, 1.351160047445448, 1.35373621623682, 1.3562690044017556, 1.358759925819303, 1.3612104151841344, 1.3636218334780101, 1.3659954729744934, 1.3683325618240405, 1.3706342682611146, 1.3729017044702256, 1.3751359301436465, 1.3773379557599421, 1.379508745609273, 1.3816492205886604, 1.383760260787955, 1.3858427078850903, 1.387897367367309, 1.3899250105933632, 1.3919263767102013, 1.3939021744363287, 1.395853083722852, 1.3977797573021715, 1.3996828221333448, 1.4015628807523157, 1.4034205125344426, 1.4052562748760988, 1.4070707043015138, 1.4088643175004685, 1.4106376123019915, 1.4123910685887417, 1.4141251491563793, 1.4158403005218587, 1.4175369536842568, 1.4192155248414549, 1.420876416065715, 1.4225200159409699, 1.424146700164392, 1.4257568321146423, 1.4273507633889846, 1.428928834311301, 1.430491374412886, 1.432038702887756, 1.4335711290240831, 1.4350889526132453, 1.436592464337876, 1.4380819461401992, 1.439557671571841, 1.4410199061262319, 1.4424689075546286, 1.443904926166719], [0.0, 0.9124435365554809, 0.9779327685429285, 1.0183993761470242, 1.048122389468958, 1.0717734625362934, 1.0914934256178972, 1.108449222600272, 1.1233497625229583, 1.136659144139365, 1.148698354997035, 1.1596989598793381, 1.1698336881100935, 1.1792349285460542, 1.1880064613519559, 1.1962311988513157, 1.2039764646185536, 1.2112976963247013, 1.2182411066377867, 1.2248456361239748, 1.2311444133449163, 1.2371658645840296, 1.2429345697296161, 1.2484719311237873, 1.2537967024973569, 1.2589254117941673, 1.2638727025115426, 1.2686516117514894, 1.2732737985986748, 1.2777497331355263, 1.2820888539868154, 1.286299700496099, 1.2903900242964321, 1.2943668840243445, 1.2982367261521606, 1.3020054543174677, 1.305678489065226, 1.3092608195551878, 1.3127570485010613, 1.3161714313804664, 1.3195079107728944, 1.3227701465365977, 1.3259615424169322, 1.3290852695823179, 1.3321442875051683, 1.3351413625403132, 1.338079084499914, 1.340959881479432, 1.343786033152179, 1.3465596827189963, 1.3492828476735634, 1.3519574295218824, 1.3545852225758983, 1.3571679219254327, 1.3597071306791426, 1.362204366553743, 1.3646610678808404, 1.3670785990922678, 1.3694582557374875, 1.3718012690803025, 1.3741088103166372, 1.3763819944503766, 1.378621883860101, 1.3808294915859265, 1.3830057843624786, 1.3851516854212418, 1.3872680770830843, 1.3893558031595834, 1.3914156711798826, 1.3934484544581196, 1.3954548940149718, 1.3974357003655382, 1.399391555184593, 1.4013231128592059, 1.4032310019377685, 1.405115826483646, 1.4069781673409072, 1.4088185833189184, 1.4106376123019917, 1.4124357722897107, 1.4142135623730951, 1.4159714636513008, 1.4177099400931694, 1.4194294393475706, 1.4211303935061592, 1.422813219821873, 1.4244783213862233, 1.4261260877681978, 1.4277568956173574, 1.429371109233524, 1.4309690811052558, 1.432551152419152, 1.4341176535418658, 1.4356689044765665, 1.437205215295468, 1.4387268865499159, 1.4402342096594207, 1.441727467280927, 1.443206933659511, 1.444672874961626, 1.446125549591925, 1.447565208494628], [0.0, 0.9146993820210588, 0.9803505238485177, 1.020917177548195, 1.0507136754443946, 1.0744232213528402, 1.0941919383436087, 1.1111896553530378, 1.126127034065274, 1.1394693206308266, 1.1515382961787317, 1.1625660979928427, 1.1727258824378277, 1.1821503656770507, 1.1909435844522356, 1.1991886560720644, 1.2069530705558646, 1.2142924026339097, 1.2212529792263787, 1.2278738371726818, 1.2341881869386226, 1.240224525086273, 1.2460074922730966, 1.251558543754481, 1.2568964796263202, 1.2620378686946978, 1.2669973906602376, 1.2717881148567352, 1.276421729193757, 1.2809087296390451, 1.2852585781526003, 1.289479835189904, 1.2935802715484703, 1.297566963315983, 1.30144637290246, 1.3052244185411253, 1.3089065341782196, 1.3124977213082563, 1.3160025940242899, 1.3194254183248106, 1.3227701465365977, 1.3260404475662164, 1.3292397335741446, 1.3323711835689214, 1.3354377643397004, 1.3384422490806047, 1.3413872340066206, 1.3442751532162198, 1.347108292018779, 1.3498887989138009, 1.35261869638284, 1.3552998906330151, 1.3579341804123715, 1.3605232650015213, 1.3630687514725077, 1.3655721612943152, 1.3680349363545556, 1.3704584444583634, 1.3728439843582039, 1.3751927903619492, 1.3775060365610854, 1.3797848407161357, 1.382030267832212, 1.3842433334539828, 1.3864250067061423, 1.3885762131026924, 1.3906978371458742, 1.3927907247334306, 1.3948556853909693, 1.3968934943445024, 1.398904894446742, 1.4008905979694015, 1.4028512882725692, 1.4047876213611636, 1.4067002273375442, 1.40858971175851, 1.410456656904157, 1.4123016229654035, 1.4141251491563793, 1.415927754757325, 1.4177099400931692, 1.419472187452495, 1.4212149619512198, 1.4229387123449415, 1.4246438717935808, 1.4263308585816543, 1.4280000767972418, 1.4296519169724673, 1.431286756688087, 1.4329049611445857, 1.4345068837019834, 1.4360928663903996, 1.4376632403932565, 1.4392183265048715, 1.440758435564054, 1.442283868865206, 1.4437949185483185, 1.445291867969152, 1.4467749920508024, 1.4482445576177696, 1.4497008237135636, 1.451144041902817], [0.0, 0.9169062415024053, 0.9827157772761715, 1.0233803045571623, 1.0532486913003272, 1.0770154403043632, 1.0968318525066763, 1.1138705792441983, 1.128843996786771, 1.1422184737661238, 1.1543165676600577, 1.1653709758209865, 1.175555272381177, 1.1850024937030994, 1.1938169275338608, 1.202081891716029, 1.2098650390994656, 1.2172220784974253, 1.2241994486012386, 1.2308362804329742, 1.2371658645840293, 1.2432167663690183, 1.2490136858949574, 1.2545781301814904, 1.2599289446827693, 1.2650827381797884, 1.2700542257903127, 1.2748565083800083, 1.2795013020574053, 1.283999128113457, 1.2883594713366657, 1.2925909128359896, 1.2967012421572421, 1.300697552460308, 1.304586321746809, 1.3083734825286597, 1.3120644818623703, 1.3156643333093652, 1.319177662094941, 1.322608744509995, 1.3259615424169322, 1.3292397335741446, 1.3324467383744967, 1.3355857434963976, 1.3386597228868566, 1.3416714564307746, 1.3446235466069243, 1.3475184333864316, 1.3503584075923496, 1.3531456229077825, 1.3558821066938467, 1.3585697697566927, 1.3612104151841344, 1.3638057463565727, 1.3663573742233701, 1.3688668239243003, 1.3713355408257608, 1.3737648960329363, 1.3761561914317413, 1.3785106643080145, 1.3808294915859265, 1.3831137937227778, 1.3853646382931766, 1.3875830432919558, 1.3897699801819796, 1.3919263767102015, 1.3940531195128658, 1.3961510565285806, 1.3982209992360641, 1.400263724731686, 1.40227997766041, 1.40427047201242, 1.4062358927965202, 1.4081768976003464, 1.4100941180464819, 1.4119881611527285, 1.4138596106040269, 1.4157090279428461, 1.4175369536842568, 1.419343908361347, 1.4211303935061592, 1.4228968925708756, 1.4246438717935808, 1.4263717810125678, 1.4280810544328246, 1.4297721113480475, 1.4314453568212433, 1.4331011823267574, 1.434739966356321, 1.4363620749915234, 1.4379678624449228, 1.439557671571841, 1.441131834354734, 1.4426906723618864, 1.4442344971820569, 1.4457636108365688, 1.4472783061702474, 1.448778867222495, 1.4502655695797035, 1.4517386807101296, 1.453198460282268, 1.454645160467691], [0.0, 0.9190663078716548, 0.9850308790880503, 1.025791204689333, 1.0557299559853683, 1.079552695180011, 1.0994157912891618, 1.1164946582056192, 1.1315033504297267, 1.1449093352739208, 1.1570359301034678, 1.168116380463936, 1.1783246693970637, 1.1877941466750876, 1.1966293457283115, 1.20491378068117, 1.2127152637614846, 1.2200896350224653, 1.227083442556656, 1.2337359095717821, 1.2400804050858942, 1.2461455617083548, 1.2519561377351949, 1.2575336908527326, 1.2628971109116238, 1.2680630458201667, 1.2730462453623002, 1.2778598412669764, 1.2825155772437715, 1.2870239993699106, 1.2913946147783533, 1.2956360247936085, 1.2997560373122607, 1.3037617622044044, 1.3076596927326698, 1.3114557753849032, 1.3151554700499015, 1.318763802100139, 1.3222854076571122, 1.3257245730858918, 1.3290852695823179, 1.3323711835689214, 1.3355857434963976, 1.338732143550397, 1.3418133646840142, 1.3448321933310594, 1.3477912381012775, 1.3506929447139282, 1.353539609388832, 1.356333390882784, 1.3590763213329984, 1.3617703160471422, 1.36441718236078, 1.367018627667171, 1.369576266710785, 1.372091628224351, 1.3745661609792899, 1.377001239310864, 1.3793981681719971, 1.381758187763351, 1.3840824777817182, 1.3863721613239952, 1.3886283084798046, 1.3908519396421917, 1.3930440285626131, 1.3952055051736267, 1.3973372582002337, 1.399440137578632, 1.4015149566992386, 1.4035624944891225, 1.405583497347497, 1.4075786809465787, 1.4095487319089293, 1.4114943093713432, 1.4134160464443928, 1.415314551575905, 1.4171904098258772, 1.4190441840596715, 1.4208764160657152, 1.4226876276033784, 1.4244783213862235, 1.4262489820053588, 1.428000076797242, 1.4297320566599045, 1.4314453568212433, 1.4331403975627353, 1.4348175849016425, 1.4364773112345544, 1.4381199559448596, 1.4397458859765708, 1.441355456376707, 1.4429490108082956, 1.4445268820358836, 1.4460893923853129, 1.4476368541793887, 1.4491695701509428, 1.4506878338346902, 1.452191929939179, 1.453682134700033, 1.4551587162156163, 1.4566219347661555, 1.4580720431172944], [0.0, 0.92118162761254, 0.9872980226511102, 1.0281521620726264, 1.058159820292016, 1.0820373898183429, 1.1019462027587548, 1.1190643783344796, 1.1341076145111557, 1.147544454522321, 1.1596989598793381, 1.1708049129648923, 1.1810366972594708, 1.1905279694526718, 1.1993835035685694, 1.20768700594741, 1.2155064448933968, 1.2228977889810073, 1.2299076934377098, 1.236575471747225, 1.242934569729616, 1.2490136858949574, 1.254837635522886, 1.2604280259168144, 1.2658037904042108, 1.2709816152101405, 1.2759762840665922, 1.2808009589264586, 1.2854674105285964, 1.2899862092230439, 1.2943668840243443, 1.2986180560537848, 1.3027475511785762, 1.306762495632865, 1.3106693976241515, 1.3144742173266972, 1.31818242719576, 1.321799064170193, 1.3253287750419738, 1.3287758560416554, 1.3321442875051683, 1.3354377643397004, 1.3386597228868566, 1.3418133646840142, 1.3449016775452187, 1.3479274543175261, 1.3508933096146487, 1.3538016947849043, 1.3566549113330855, 1.3594551229845735, 1.362204366553743, 1.364904561756526, 1.3675575200882444, 1.3701649528718873, 1.372728478568415, 1.375249629429082, 1.3777298575597963, 1.3801705404589857, 1.382572986083049, 1.3849384374870888, 1.3872680770830843, 1.3895630305528475, 1.391824370448915, 1.394053119512866, 1.3962502537373394, 1.3984167051952228, 1.4005533646570032, 1.4026610840150895, 1.4047406785319945, 1.406792928927563, 1.4088185833189184, 1.4108183590254657, 1.4127929442500948, 1.414742999646667, 1.4166691597829195, 1.4185720345070807, 1.42045221022572, 1.4223102510996886, 1.424146700164392, 1.4259620803800794, 1.4277568956173574, 1.4295316315826674, 1.4312867566880871, 1.4330227228694328, 1.434739966356321, 1.4364389083975464, 1.4381199559448596, 1.439783502297988, 1.4414299277135083, 1.4430595999799896, 1.444672874961626, 1.446270097112419, 1.4478515999628045, 1.449417706580489, 1.4509687300071188, 1.4525049736722941, 1.4540267317863287, 1.4555342897130545, 1.4570279243238786, 1.4585079043342193, 1.4599744906233632, 1.4614279365387184], [0.0, 0.9232541136674268, 0.9895192582062144, 1.0304653117863476, 1.0605404816140187, 1.0844717711976988, 1.1044253752367947, 1.1215820635000313, 1.136659144139365, 1.1501262145228153, 1.1623080652394242, 1.1734390046384329, 1.1836938085304844, 1.1932064343076842, 1.202081891716029, 1.2104040754193457, 1.2182411066377865, 1.2256490798646344, 1.2326747552928772, 1.2393575348542079, 1.2457309396155174, 1.251823732653151, 1.2576607850764747, 1.2632637528012847, 1.2686516117514892, 1.2738410856930327, 1.2788469916185308, 1.283682521092804, 1.288359471336666, 1.2928884364814621, 1.2972789669802325, 1.3015397033501719, 1.3056784890652262, 1.3097024663922334, 1.313618158180941, 1.317431538014886, 1.3211480906613249, 1.3247728643912797, 1.328310516451139, 1.33176535273717, 1.3351413625403132, 1.3384422490806047, 1.3416714564307746, 1.3448321933310594, 1.3479274543175261, 1.3509600385206135, 1.3539325664364248, 1.3568474949283522, 1.3597071306791428, 1.3625136422821544, 1.3652690711342126, 1.3679753412702502, 1.3706342682611146, 1.3732475672799507, 1.3758168604289525, 1.3783436834066531, 1.3808294915859267, 1.383275665564314, 1.3856835162408707, 1.3880542894673413, 1.3903891703159095, 1.3926892870009606, 1.3949557144880738, 1.3971894778198046, 1.399391555184593, 1.401562880752316, 1.403704347297527, 1.405816808629233, 1.407901081844135, 1.4099579494185515, 1.4119881611527285, 1.4139924359799059, 1.4159714636513008, 1.4179259063071217, 1.419856399942765, 1.4217635557785027, 1.4236479615402091, 1.4255101826579921, 1.4273507633889846, 1.429170227869999, 1.4309690811052556, 1.4327478098939448, 1.4345068837019836, 1.4362467554819591, 1.4379678624449226, 1.4396706267874, 1.4413554563767068, 1.4430227453974214, 1.444672874961626, 1.4463062136853457, 1.447923118233402, 1.4495239338347532, 1.4511089947702167, 1.4526786248343402, 1.4542331377730555, 1.4557728376986225, 1.4572980194832728, 1.4588089691328536, 1.4603059641416811, 1.4617892738297324, 1.463259159663224, 1.464715875559548], [0.0, 0.9252855568989151, 0.9916965051523726, 1.0327326526537461, 1.0628739971122994, 1.086857942899213, 1.1068554510089965, 1.1240498892673114, 1.1391601441248391, 1.1526568462083528, 1.1648655007461621, 1.1760209316379977, 1.1862982992550826, 1.1958318557370178, 1.204726841883563, 1.2130673369526295, 1.2209216120520214, 1.2283458851001732, 1.2353870191768899, 1.2420845029102423, 1.248471931123787, 1.2545781301814904, 1.2604280259168141, 1.2660433218952354, 1.2714430357935353, 1.2766439281750919, 1.2816608486344645, 1.2865070177619768, 1.29119425873596, 1.2957331889981087, 1.3001333800153998, 1.3044034913168254, 1.308551383634388, 1.3125842149501115, 1.3165085224660202, 1.3203302929093739, 1.3240550231156052, 1.3276877724634863, 1.3312332084467813, 1.3346956464360542, 1.338079084499914, 1.3413872340066206, 1.3446235466069243, 1.3477912381012775, 1.3508933096146487, 1.3539325664364248, 1.356911634828607, 1.3598329770604438, 1.3626989048900937, 1.3655115916824878, 1.368273083326153, 1.370985308089491, 1.373650085538164, 1.3762691346192255, 1.3788440810039944, 1.3813764637700123, 1.383867741492422, 1.3863192978065044, 1.388732446495696, 1.3911084361529986, 1.3934484544581194, 1.395753632107863, 1.3980250464330637, 1.400263724731686, 1.4024706473444855, 1.4046467504968, 1.406792928927563, 1.408910038324423, 1.4109988975819459, 1.413060290898138, 1.415094969723038, 1.4171036545717592, 1.4190870367131838, 1.4210457797444331, 1.4229805210602886, 1.4248918732258955, 1.4267804252603056, 1.428646743837747, 1.430491374412886, 1.4323148422757972, 1.434117653541866, 1.4359002960813902, 1.437663240393257, 1.439406940426688, 1.441131834354734, 1.4428383453028828, 1.4445268820358834, 1.446197839605642, 1.4478515999628045, 1.4494885325344649, 1.4511089947702167, 1.4527133326586286, 1.4543018812160382, 1.4558749649494416, 1.4574328982951075, 1.4589759860344367, 1.4605045236884704, 1.4620187978923571, 1.463519086750985, 1.4650056601769188, 1.466478780211681, 1.46793870133136], [0.0, 0.9272776363420389, 0.9938315630347766, 1.0349560586847328, 1.0651622954916389, 1.089197877149242, 1.1092384385894514, 1.1264698953516594, 1.14161268160218, 1.155138441204824, 1.1673733801794233, 1.1785528279862458, 1.1888523221053677, 1.1984064037124882, 1.2073205401839437, 1.2156789917948028, 1.2235501766361112, 1.230990433659814, 1.2380467268388704, 1.2447586298177915, 1.2511598097475969, 1.2572791550535345, 1.263141645232759, 1.2687690305771087, 1.2741803697071823, 1.2793924592707566, 1.2844201808326001, 1.289276783446105, 1.2939741157441336, 1.29852281802704, 1.3029324823685458, 1.3072117869410431, 1.3113686094001782, 1.315410123138643, 1.319342879432632, 1.3231728778984375, 1.3269056272058206, 1.3305461976260657, 1.3340992667017466, 1.337569159094139, 1.340959881479432, 1.3442751532162198, 1.3475184333864316, 1.3506929447139282, 1.3538016947849043, 1.3568474949283522, 1.3598329770604438, 1.3627606087515323, 1.365632706736841, 1.368451449060414, 1.3712188860154424, 1.3739369500217642, 1.3766074645624478, 1.3792321522853275, 1.3818126423616863, 1.3843504771826, 1.3868471184634281, 1.3893039528183275, 1.3917222968592255, 1.394103401867263, 1.3964484580791439, 1.3987585986259896, 1.401034903158057, 1.4032784011850161, 1.4054900751582327, 1.4076708633186765, 1.4098216623315951, 1.4119433297268773, 1.4140366861621152, 1.4161025175236426, 1.4181415768793202, 1.4201545862954845, 1.4221422385292741, 1.4241051986064914, 1.4260441052941872, 1.4279595724763197, 1.4298521904400605, 1.43172252707965, 1.4335711290240831, 1.4353985226943498, 1.437205215295468, 1.4389916957480895, 1.4407584355640541, 1.4425058896699072, 1.4442344971820569, 1.445944682136953, 1.4476368541793885, 1.44931140921179, 1.4509687300071188, 1.4526091867878206, 1.4542331377730555, 1.4558409296962824, 1.4574328982951075, 1.4590093687751688, 1.4605706562496963, 1.4621170661562652, 1.4636488946521542, 1.4651664289896182, 1.4666699478722878, 1.4681597217938311, 1.4696360133599293, 1.4710990775945414], [0.0, 0.9292319283974863, 0.9959261213978506, 1.0371372893366482, 1.067407187560915, 1.091493425617897, 1.1115762237178448, 1.128843996786771, 1.1440186973482884, 1.1575729632833398, 1.1698336881100935, 1.1810366972594708, 1.1913578981670918, 1.2009321155620822, 1.2098650390994656, 1.2182411066377867, 1.2261288804632346, 1.2335848182654034, 1.2406559829965822, 1.247382031705061, 1.2537967024973569, 1.2599289446827695, 1.265803790404211, 1.2714430357935356, 1.2768657796385043, 1.2820888539868154, 1.2871271717670085, 1.2919940099556335, 1.2967012421572421, 1.3012595310972466, 1.305678489065226, 1.3099668125233312, 1.3141323957298299, 1.31818242719576, 1.3221234720045154, 1.325961542416932, 1.3297021587126154, 1.333350401848745, 1.3369109592260897, 1.3403881646204028, 1.343786033152179, 1.347108292018779, 1.3503584075923496, 1.353539609388832, 1.3566549113330855, 1.3597071306791428, 1.3626989048900937, 1.365632706736841, 1.3685108578372633, 1.3713355408257606, 1.3741088103166372, 1.3768326028024194, 1.3795087456092727, 1.382138965015614, 1.3847248936262992, 1.3872680770830843, 1.3897699801819798, 1.3922319924595135, 1.3946554333024492, 1.3970415566290764, 1.399391555184593, 1.4017065644882605, 1.403987666465762, 1.4062358927965202, 1.408452228002474, 1.4106376123019917, 1.4127929442500948, 1.4149190831839675, 1.4170168514907853, 1.419087036713184, 1.4211303935061592, 1.4231476454578438, 1.4251394867854035, 1.4271065839162211, 1.4290495769635871, 1.4309690811052556, 1.4328656878724633, 1.434739966356321, 1.436592464337876, 1.4384237093475818, 1.4402342096594207, 1.4420244552244734, 1.4437949185483188, 1.4455460555162862, 1.4472783061702474, 1.4489920954403344, 1.45068783383469, 1.452365918090129, 1.4540267317863287, 1.4556706459260007, 1.4572980194832728, 1.4589091999223651, 1.4605045236884704, 1.462084316672617, 1.4636488946521542, 1.4651985637083849, 1.4667336206227566, 1.4682543532529253, 1.4697610408899058, 1.4712539545974477, 1.4727333575346888, 1.474199505263066], [0.0, 0.9311499150948377, 0.9979817686415696, 1.0392779987370508, 1.0696103757250688, 1.0937463291251968, 1.1138705792441983, 1.1311739939629937, 1.1463800159556026, 1.1599622586540015, 1.1722482903028724, 1.183474423090022, 1.193816927533861, 1.2034109066493002, 1.2123622682407256, 1.2207556244511462, 1.228659679083147, 1.2361310063581523, 1.2432167663690183, 1.2499566980184016, 1.2563846090501591, 1.262529508526585, 1.268416480258335, 1.274067365365699, 1.279501302057405, 1.2847351571234393, 1.2897838742734604, 1.2946607578884408, 1.2993777060807168, 1.3039454035841622, 1.3083734825286597, 1.3126706573263447, 1.3168448385296756, 1.3209032294871794, 1.3248524088329496, 1.3286984012374645, 1.3324467383744965, 1.336102511688604, 1.3396704182556143, 1.3431548007964356, 1.3465596827189963, 1.3498887989138009, 1.3531456229077825, 1.356333390882784, 1.3594551229845735, 1.3625136422821544, 1.3655115916824878, 1.368451449060414, 1.3713355408257606, 1.3741660541180074, 1.376945047792297, 1.3796744623381856, 1.3823561288535415, 1.3849917771799167, 1.3875830432919556, 1.3901314760217047, 1.3926385431885957, 1.3951056371972372, 1.3975340801576817, 1.3999251285763754, 1.4022799776604098, 1.4045997652728213, 1.4068855755724483, 1.4091384423681574, 1.4113593522139962, 1.413549247268996, 1.4157090279428461, 1.4178395553464507, 1.419941653564439, 1.4220161117649783, 1.4240636861607145, 1.4260851018333072, 1.4280810544328244, 1.4300522117621932, 1.431999215255933, 1.43392268136156, 1.4358232028312639, 1.4377013499307914, 1.439557671571841, 1.4413926963737178, 1.443206933659511, 1.4450008743915868, 1.4467749920508024, 1.4485297434634603, 1.4502655695797033, 1.4519828962067423, 1.4536821347000326, 1.4553636826152754, 1.4570279243238786, 1.4586752315943234, 1.460305964141681, 1.4619204701473565, 1.4635190867509849, 1.4651021405162514, 1.4666699478722875, 1.4682228155321653, 1.4697610408899058, 1.4712849123973188, 1.472794709921892, 1.4742907050868654, 1.4757731615945522, 1.4772423355338822], [0.0, 0.9330329915368074, 1.0, 1.0413797439924106, 1.0717734625362931, 1.0959582263852172, 1.1161231740339044, 1.1334615816706974, 1.148698354997035, 1.1623080652394242, 1.174618943088019, 1.185867778627801, 1.1962311988513155, 1.2058445799940376, 1.214814044039067, 1.223224374241637, 1.231144413344916, 1.2386308499811034, 1.2457309396155172, 1.2524845015153079, 1.258925411794167, 1.2650827381797884, 1.2709816152101407, 1.2766439281750919, 1.2820888539868154, 1.2873332935452237, 1.2923922207808316, 1.2972789669802325, 1.3020054543174677, 1.3065823891342858, 1.3110194230397498, 1.3153252880692625, 1.3195079107728944, 1.3235745090665967, 1.327531674888519, 1.3313854450929088, 1.3351413625403128, 1.3388045289717836, 1.3423796509621049, 1.3458710800145255, 1.3492828476735634, 1.35261869638284, 1.3558821066938467, 1.3590763213329984, 1.362204366553743, 1.3652690711342126, 1.368273083326153, 1.3712188860154424, 1.3741088103166372, 1.376945047792297, 1.3797296614612147, 1.3824645957372221, 1.3851516854212413, 1.3877926638531048, 1.3903891703159093, 1.3929427567739243, 1.3954548940149718, 1.3979269772595382, 1.400360331291396, 1.4027562151580406, 1.405115826483646, 1.4074403054323636, 1.4097307383555406, 1.4119881611527283, 1.414213562373095, 1.4164078860810125, 1.4185720345070807, 1.4207068705036388, 1.4228132198218728, 1.4248918732258953, 1.426943588457651, 1.4289690920651408, 1.4309690811052553, 1.432944224731428, 1.4348951656753592, 1.4368225216312152, 1.4387268865499159, 1.4406088318504637, 1.4424689075546284, 1.444307643350749, 1.4461255495919247, 1.4479231182334018, 1.4497008237135636, 1.4514591237825583, 1.4531984602822676, 1.4549192598810186, 1.4566219347661553, 1.4583068832973611, 1.459974490623363, 1.4616251292644749, 1.4632591596632238, 1.4648769307051468, 1.4664787802116808, 1.468065035406925, 1.469636013359929, 1.4711920214040355, 1.4727333575346886, 1.4742603107870387, 1.4757731615945522, 1.4772721821297767, 1.4787576366283137, 1.4802297816969856], [0.0, 0.9348824726202953, 1.0019822247447452, 1.0434439926896288, 1.0738979584144939, 1.0981306619007651, 1.118335581007658, 1.1357083572651034, 1.1509753333005583, 1.1646120210473587, 1.1769473018226546, 1.188218435082593, 1.198602397934115, 1.2082348349588188, 1.2172220784974253, 1.2256490798646344, 1.2335848182654034, 1.241086094701541, 1.248200258309318, 1.2549672072866216, 1.2614208848972142, 1.2675904164875587, 1.2735009864179265, 1.2791745233597493, 1.2846302422381501, 1.2898850774544235, 1.2949540326207798, 1.2998504654494185, 1.3045863217468092, 1.3091723290770763, 1.313618158180941, 1.3179325584026627, 1.3221234720045156, 1.3261981312099826, 1.3301631410239163, 1.3340245502669659, 1.3377879127868733, 1.3414583404374887, 1.3450405491230846, 1.3485388989725675, 1.3519574295218824, 1.3552998906330151, 1.3585697697566927, 1.3617703160471422, 1.364904561756526, 1.3679753412702502, 1.370985308089491, 1.3739369500217642, 1.3768326028024194, 1.3796744623381856, 1.3824645957372221, 1.3852049512676268, 1.3878973673673092, 1.3905435808119704, 1.3931452341341353, 1.3957038823744154, 1.3982209992360644, 1.400697982705209, 1.4031361601916414, 1.405536793238572, 1.407901081844135, 1.4102301684325436, 1.4125251415085371, 1.4147870390250528, 1.4170168514907855, 1.4192155248414549, 1.4213839630960843, 1.4235230308173807, 1.4256335553933543, 1.4277163291555903, 1.4297721113480473, 1.4318016299589085, 1.4338055834267878, 1.4357846422315306, 1.4377394503788765, 1.4396706267874, 1.4415787665853654, 1.4434644423244565, 1.445328205116709, 1.4471705857004236, 1.4489920954403344, 1.450793227266853, 1.4525744565588063, 1.4543362419737065, 1.456079026229265, 1.4578032368395613, 1.4595092868089874, 1.4611975752868656, 1.4628684881853735, 1.4645223987632445, 1.4661596681774836, 1.4677806460051972, 1.4693856707374602, 1.470975070247004, 1.47254916223138, 1.4741082546331343, 1.4756526460384058, 1.4771826260552767, 1.4786984756730959, 1.4802004676039182, 1.4816888666071195, 1.4831639297981742], [0.0, 0.9366995991172012, 1.0039297727022005, 1.0454721296829765, 1.0759852886323111, 1.100265093106018, 1.1205092844155162, 1.1379158280533401, 1.153212478435565, 1.1668756717457496, 1.179234928546054, 1.1905279694526716, 1.200932115562082, 1.2105832751075947, 1.2195879871075814, 1.2280313679961983, 1.2359825310529458, 1.2434983876834627, 1.250626379056305, 1.257406480919292, 1.2638727025115424, 1.2700542257903127, 1.2759762840665922, 1.2816608486344645, 1.2871271717670083, 1.2923922207808316, 1.2974710284505926, 1.3023769784518104, 1.3071220398099608, 1.3117169609402817, 1.3161714313804662, 1.3204942174808312, 1.3246932769409874, 1.3287758560416552, 1.3327485726258026, 1.3366174872711423, 1.3403881646204026, 1.3440657264633193, 1.3476548978704452, 1.351160047445448, 1.3545852225758983, 1.3579341804123715, 1.3612104151841344, 1.36441718236078, 1.3675575200882444, 1.3706342682611146, 1.373650085538164, 1.3766074645624478, 1.3795087456092727, 1.3823561288535415, 1.3851516854212413, 1.3878973673673092, 1.390595016703017, 1.393246373579829, 1.395853083722852, 1.3984167051952225, 1.4009387145646242, 1.4034205125344426, 1.4058634290945493, 1.4082687282402109, 1.4106376123019915, 1.4129712259246288, 1.4152706597285833, 1.4175369536842568, 1.4197711002255906, 1.4219740471269153, 1.4241467001643917, 1.4262899255811727, 1.428404552373459, 1.430491374412886, 1.4325511524191519, 1.4345846157954267, 1.4365924643378758, 1.4385753698295536, 1.44053397752795, 1.4424689075546284, 1.4443807561946016, 1.4462700971124187, 1.4481374824913098, 1.4499834441011683, 1.451808494300666, 1.4536131269783206, 1.4553978184369507, 1.457163028225559, 1.458909199922365, 1.4606367618724048, 1.4623461278828258, 1.4640376978787744, 1.465711858522524, 1.4673689837983088, 1.4690094355651133, 1.4706335640795152, 1.472241708490513, 1.4738341973081222, 1.4754113488474019, 1.4769734716494443, 1.4785208648807486, 1.4800538187123073, 1.4815726146796266, 1.4830775260248306, 1.4845688180219063, 1.4860467482860826], [0.0, 0.9384855431870388, 1.0058439001618265, 1.0474654632468507, 1.0780367996474503, 1.102362896841745, 1.1226456864312595, 1.1400854179912472, 1.155411233499692, 1.1691004775299692, 1.1814832989196156, 1.1927978715312288, 1.2032218545478646, 1.2128914153302024, 1.2219132960276158, 1.230372775360218, 1.2383390983812943, 1.2458692850057513, 1.2530108668551287, 1.2598038958963984, 1.2662824462118787, 1.2724757553981614, 1.2784091048769457, 1.2841045078335491, 1.289581253248105, 1.2948563407876974, 1.2999448318889961, 1.3048601357453025, 1.3096142442026526, 1.3142179261695874, 1.3186808896582096, 1.323011917733065, 1.3272189832661914, 1.3313093463543206, 1.33528963745823, 1.339165928710941, 1.3429437953649235, 1.346628368975296, 1.350224383621595, 1.35373621623682, 1.3571679219254327, 1.3605232650015213, 1.3638057463565727, 1.367018627667171, 1.3701649528718873, 1.3732475672799507, 1.3762691346192255, 1.3792321522853275, 1.382138965015614, 1.3849917771799167, 1.3877926638531048, 1.3905435808119704, 1.393246373579829, 1.3959027856259776, 1.3985144658133204, 1.4010829751756506, 1.4036097930959275, 1.4060963229481669, 1.408543897258045, 1.4109537824308058, 1.4133271830894187, 1.415665246061041, 1.4179690640455485, 1.420239678996186, 1.4224780852391046, 1.4246852323556938, 1.426862027849099, 1.429009339614083, 1.4311279982274387, 1.4332187990744256, 1.4352825043251558, 1.4373198447735054, 1.4393315215498952, 1.4413182077182245, 1.4432805497662538, 1.445219168997892, 1.447134662835049, 1.4490276060360434, 1.4508985518369168, 1.4527480330214537, 1.4545765629252065, 1.4563846363783584, 1.4581727305918633, 1.4599413059909156, 1.4616908069994774, 1.4634216627792818, 1.4651342879264553, 1.4668290831286552, 1.4685064357853796, 1.4701667205939133, 1.471810300103174, 1.4734375252375507, 1.475048735792675, 1.4766442609049113, 1.4782244194962293, 1.4797895206959966, 1.481339864241113, 1.4828757408558215, 1.4843974326124139, 1.4859052132739867, 1.4873993486203083, 1.488880096757785], [0.0, 0.9402414133840812, 1.0077257952426748, 1.0494252306643652, 1.0800537648543813, 1.1044253752367945, 1.1247461131420948, 1.1422184737661238, 1.1575729632833396, 1.1712878193603735, 1.1836938085304842, 1.195029550270365, 1.2054730361565402, 1.2151606883135608, 1.2241994486012384, 1.2326747552928772, 1.2406559829965822, 1.248200258309318, 1.2553552017824519, 1.262160940318639, 1.268651611751489, 1.274856508380008, 1.2808009589264584, 1.2865070177619768, 1.2919940099556333, 1.2972789669802325, 1.3023769784518104, 1.3073014786517507, 1.3120644818623706, 1.3166767771404224, 1.3211480906613247, 1.325487221922398, 1.3297021587126154, 1.3338001747120694, 1.337787912786873, 1.3416714564307743, 1.3454563913273252, 1.3491478586325856, 1.3527506012833714, 1.3562690044017556, 1.3597071306791426, 1.3630687514725077, 1.3663573742233701, 1.369576266710785, 1.372728478568415, 1.3758168604289525, 1.3788440810039944, 1.3818126423616863, 1.3847248936262992, 1.3875830432919556, 1.3903891703159093, 1.3931452341341353, 1.395853083722852, 1.3985144658133204, 1.4011310323534027, 1.4037043472975268, 1.4062358927965202, 1.4087270748500569, 1.4111792284769176, 1.4135936224517411, 1.4159714636513006, 1.418313901048422, 1.4206220293873806, 1.4228968925708754, 1.4251394867854035, 1.4273507633889846, 1.4295316315826672, 1.4316829608850112, 1.4338055834267875, 1.4359002960813902, 1.4379678624449226, 1.4400090146785471, 1.4420244552244732, 1.4440148584058765, 1.4459808719200713, 1.4479231182334018, 1.4498421958855316, 1.4517386807101296, 1.4536131269783206, 1.4554660684707073, 1.4572980194832728, 1.4591094757720084, 1.4609009154407118, 1.4626727997760147, 1.464425574033379, 1.4661596681774833, 1.4678754975801476, 1.4695734636787, 1.4712539545974477, 1.4729173457347207, 1.4745640003177505, 1.4761942699274928, 1.4778084949953239, 1.479407005273409, 1.480990120280409, 1.48255814972406, 1.484111393902059, 1.4856501440825816, 1.4871746828656667, 1.488685284526611, 1.490182215342446, 1.491665733902486], [0.0, 0.9419682592138261, 1.009576582776887, 1.0513526033129272, 1.0820373898183426, 1.1064537610602057, 1.126811819999242, 1.1443162703319882, 1.1596989598793381, 1.1734390046384329, 1.185867778627801, 1.1972243395722733, 1.2076870059474099, 1.217392450430411, 1.2264478112903319, 1.234938683716268, 1.2429345697296157, 1.2504927008459534, 1.2576607850764745, 1.2644790230208374, 1.2709816152101405, 1.2771979077415783, 1.2831532758561022, 1.288869814429871, 1.2943668840243443, 1.299661547392302, 1.3047689218633443, 1.3097024663922332, 1.3144742173266974, 1.3190949835386532, 1.3235745090665967, 1.3279216095689905, 1.3321442875051681, 1.3362498299140506, 1.3402448918620284, 1.3441355680157836, 1.347927454317526, 1.351625701365553, 1.355235060807552, 1.358759925819303, 1.362204366553743, 1.3655721612943152, 1.3688668239243003, 1.372091628224351, 1.375249629429082, 1.3783436834066531, 1.3813764637700123, 1.3843504771826, 1.3872680770830843, 1.3901314760217047, 1.3929427567739243, 1.3957038823744154, 1.3984167051952225, 1.4010829751756506, 1.4037043472975268, 1.406282388387635, 1.4088185833189184, 1.4113143406733077, 1.4137709979214768, 1.4161898261682941, 1.4185720345070807, 1.420918774020864, 1.4232311414645247, 1.425510182657992, 1.4277568956173572, 1.429972233447903, 1.4321571070205148, 1.4343123874507089, 1.4364389083975462, 1.4385374681979568, 1.4406088318504637, 1.4426537328609157, 1.4446728749616258, 1.4466669337142306, 1.4486365580056044, 1.450582371445312, 1.452504973672294, 1.4544049415777942, 1.4562828304509112, 1.458139175052588, 1.459974490623363, 1.4617892738297322, 1.4635840036535779, 1.4653591422287298, 1.4671151356284056, 1.4688524146069564, 1.4705713952990727, 1.4722724798793623, 1.473956057184961, 1.4756225033036543, 1.4772721821297767, 1.4789054458899968, 1.4805226356409262, 1.4821240817403527, 1.4837101042937648, 1.485281013577707, 1.4868371104414024, 1.4883786866879698, 1.4899060254364707, 1.491419401465935, 1.4929190815424387, 1.4944053247302203], [0.0, 0.9436670752867394, 1.0113973287615656, 1.0532486913003272, 1.0839888170467407, 1.108449222600272, 1.128843996786771, 1.1463800159556026, 1.1617904477968057, 1.175555272381177, 1.1880064613519559, 1.1993835035685694, 1.2098650390994656, 1.2195879871075817, 1.2286596790831472, 1.2371658645840296, 1.245176170976773, 1.2527479329925555, 1.2599289446827693, 1.2667594791478434, 1.2732737985986746, 1.2795013020574053, 1.2854674105285964, 1.29119425873596, 1.2967012421572421, 1.3020054543174677, 1.3071220398099608, 1.3120644818623706, 1.3168448385296756, 1.3214739381773213, 1.325961542416932, 1.330316482805789, 1.3345467762354597, 1.3386597228868566, 1.3426619898286154, 1.3465596827189963, 1.3503584075923494, 1.3540633243359481, 1.3576791931669556, 1.3612104151841344, 1.3646610678808404, 1.3680349363545556, 1.3713355408257608, 1.3745661609792899, 1.3777298575597963, 1.3808294915859267, 1.383867741492422, 1.3868471184634281, 1.3897699801819798, 1.3926385431885957, 1.3954548940149718, 1.3982209992360644, 1.4009387145646242, 1.4036097930959275, 1.4062358927965202, 1.4088185833189184, 1.4113593522139962, 1.4138596106040269, 1.4163206983717789, 1.4187438889145263, 1.4211303935061592, 1.4234813653056548, 1.4257979030458634, 1.4280810544328246, 1.430331819282526, 1.432551152419152, 1.434739966356321, 1.4368991337805836, 1.4390294898544844, 1.4411318343547341, 1.443206933659511, 1.4452555225975232, 1.4472783061702474, 1.4492759611576789, 1.4512491376169425, 1.4531984602822678, 1.455124529874029, 1.4570279243238784, 1.4589091999223651, 1.4607688923948596, 1.4626075179111238, 1.4644255740333791, 1.4662235406073396, 1.4680018806002821, 1.4697610408899058, 1.4715014530074162, 1.4732235338379929, 1.4749276862815552, 1.4766142998764968, 1.478283751388868, 1.4799364053692778, 1.4815726146796266, 1.4831927209916131, 1.484797055258817, 1.486385938164029, 1.4879596805433697, 1.489518583788636, 1.4910629402292064, 1.4925930334947404, 1.494109138859825, 1.4956115235716425, 1.4971004471616467], [0.0, 0.9453388051113799, 1.0131890444241456, 1.055114547698332, 1.0859091303463047, 1.1104128681200198, 1.130843772159056, 1.148410856824415, 1.163848588631034, 1.1776377979464099, 1.19011104450985, 1.2015082414412859, 1.2120083452745145, 1.2217485177281944, 1.2308362804329742, 1.2393575348542079, 1.247382031705061, 1.2549672072866216, 1.2621609403186391, 1.2690035752463473, 1.2755294349770063, 1.2817679706138616, 1.2877446481954198, 1.2934816416576091, 1.2989983808377497, 1.3043119895424735, 1.3094376391941305, 1.3143888369062449, 1.319177662094941, 1.3238149623083844, 1.328310516451139, 1.3326731717258102, 1.3369109592260897, 1.341031192065343, 1.3450405491230844, 1.3489451468739002, 1.3527506012833714, 1.35646208137964, 1.3600843558127134, 1.3636218334780101, 1.3670785990922678, 1.3704584444583634, 1.3737648960329363, 1.377001239310864, 1.3801705404589857, 1.383275665564314, 1.3863192978065044, 1.3893039528183275, 1.3922319924595135, 1.3951056371972372, 1.3979269772595382, 1.400697982705209, 1.4034205125344426, 1.4060963229481669, 1.4087270748500569, 1.4113143406733077, 1.4138596106040269, 1.416364298264326, 1.4188297459106096, 1.4212572291960064, 1.4236479615402091, 1.4260030981450444, 1.4283237396897956, 1.4306109357365395, 1.4328656878724633, 1.4350889526132453, 1.4372816440890452, 1.4394446365324003, 1.4415787665853652, 1.443684835441476, 1.4457636108365688, 1.4478158289011192, 1.4498421958855316, 1.451843389768734, 1.4538200617594437, 1.4557728376986223, 1.4577023193708356, 1.4596090857315562, 1.4614936940568155, 1.4633566810210352, 1.4651985637083849, 1.4670198405625297, 1.4688209922792423, 1.470602482645958, 1.4723647593320308, 1.4741082546331346, 1.475833386172971, 1.4775405575652074, 1.4792301590383141, 1.480902568025792, 1.4825581497240603, 1.4841972576201232, 1.4858202339909596, 1.4874274103764418, 1.4890191080274577, 1.4905956383307821, 1.492157303212135, 1.4937043955187639, 1.4952371993827847, 1.496755990566441, 1.4982610367903495, 1.4997525980457307], [0.0, 0.9469843445639475, 1.0149526899409642, 1.0569511724151297, 1.087799358808552, 1.1123457499326046, 1.1328122177911584, 1.1504098812614145, 1.1658744853350014, 1.1796876973548314, 1.1921826559427973, 1.2035996918326024, 1.2141180730654473, 1.2238752001156807, 1.2329787817755118, 1.2415148690379023, 1.249553334030213, 1.2571517130321839, 1.2643579681054542, 1.2712125139223294, 1.277749733135526, 1.283999128113457, 1.2899862092230439, 1.2957331889981087, 1.3012595310972463, 1.3065823891342858, 1.3117169609402817, 1.3166767771404224, 1.3214739381773213, 1.3261193104813351, 1.330622689979045, 1.3349929392732716, 1.339238103437331, 1.3433655083144336, 1.3473818444099361, 1.3512932388452958, 1.3551053173617347, 1.3588232579850574, 1.362451837666001, 1.3659954729744934, 1.3694582557374875, 1.3728439843582039, 1.3761561914317413, 1.3793981681719971, 1.382572986083049, 1.3856835162408707, 1.388732446495696, 1.3917222968592255, 1.3946554333024492, 1.3975340801576817, 1.400360331291396, 1.4031361601916414, 1.4058634290945493, 1.408543897258045, 1.4111792284769176, 1.4137709979214768, 1.4163206983717789, 1.4188297459106096, 1.421299485130822, 1.4237311939060593, 1.4261260877681978, 1.42848532392991, 1.4308100049864179, 1.4331011823267574, 1.4353598592815664, 1.4375869940315187, 1.439783502297988, 1.4419502598352774, 1.4440881047417744, 1.446197839605642, 1.448280233499105, 1.450336023834012, 1.4523659180901287, 1.4543705954265325, 1.4563507081854916, 1.4583068832973611, 1.4602397235942255, 1.4621498090393386, 1.4640376978787744, 1.4659039277211376, 1.4677490165506792, 1.4695734636787, 1.471377750637713, 1.4731623420224624, 1.4749276862815552, 1.4766742164631566, 1.478402350917921, 1.4801124939620804, 1.4818050365033715, 1.4834803566322885, 1.485138820180944, 1.4867807812516523, 1.4884065827171895, 1.4900165566945354, 1.491611024993775, 1.4931902995437105, 1.4947546827956202, 1.496304468106507, 1.497839940103072, 1.499361375027575, 1.50086904106665, 1.5023631986640817], [0.0, 0.9486045450669235, 1.0166891778440417, 1.0587595157430827, 1.0896604804610857, 1.1142488681350007, 1.1347503521812128, 1.1523781235865886, 1.1678691861327388, 1.1817060312497691, 1.1942223675281953, 1.2056589368848392, 1.2161953140715365, 1.225969134641832, 1.2350882916674744, 1.2436389833665225, 1.251691201410928, 1.2593025805195548, 1.266521164812586, 1.2733874381080028, 1.2799358418839835, 1.2861959289846985, 1.2921932534228902, 1.2979500657359222, 1.3034858628828652, 1.308817827825756, 1.313961184397699, 1.3189294863735006, 1.3237348548984844, 1.328388174994441, 1.3328992593478532, 1.3372769857246158, 1.3415294129624031, 1.3456638794382496, 1.3496870871043323, 1.3536051735650332, 1.3574237741866844, 1.3611480758542023, 1.3647828636912342, 1.3683325618240405, 1.3718012690803025, 1.3751927903619492, 1.3785106643080145, 1.381758187763351, 1.3849384374870888, 1.3880542894673413, 1.3911084361529986, 1.394103401867263, 1.3970415566290764, 1.3999251285763754, 1.4027562151580406, 1.405536793238572, 1.4082687282402109, 1.4109537824308058, 1.4135936224517411, 1.4161898261682941, 1.4187438889145263, 1.4212572291960064, 1.4237311939060593, 1.4261670631046481, 1.4285660544033094, 1.430929326994597, 1.4332579853601688, 1.435553082687888, 1.4378156240249955, 1.4400465691915219, 1.4422468354755535, 1.444417300129726, 1.4465588026863339, 1.4486721471066923, 1.4507581037788357, 1.4528174113762549, 1.454850778589146, 1.4568588857385634, 1.4588423862828712, 1.4608019082250432, 1.4627380554285518, 1.4646514088489135, 1.4665425276873083, 1.4684119504721385, 1.470260196073877, 1.4720877646580985, 1.4738951385811732, 1.4756827832327224, 1.4774511478286063, 1.4792006661578945, 1.4809317572869998, 1.4826448262239011, 1.4843402645451407, 1.4860184509880903, 1.4876797520107665, 1.4893245223213192, 1.490953105379147, 1.4925658338694505, 1.4941630301529016, 1.4957450066919828, 1.4973120664554378, 1.498864503302176, 1.5004026023458674, 1.5019266403013962, 1.5034368858142386, 1.5049335997737738], [0.0, 0.9502002165056763, 1.0183993761470242, 1.0605404816140187, 1.091493425617897, 1.1161231740339044, 1.1366591441393648, 1.1543165676600577, 1.1698336881100935, 1.1836938085304842, 1.1962311988513155, 1.2076870059474099, 1.2182411066377865, 1.2280313679961983, 1.2371658645840293, 1.2457309396155174, 1.2537967024973566, 1.2614208848972142, 1.268651611751489, 1.275529434977006, 1.2820888539868154, 1.2883594713366657, 1.2943668840243445, 1.3001333800154, 1.305678489065226, 1.3110194230397498, 1.3161714313804662, 1.3211480906613249, 1.325961542416932, 1.3306226899790452, 1.3351413625403128, 1.3395264528001418, 1.343786033152179, 1.347927454317526, 1.3519574295218821, 1.3558821066938467, 1.3597071306791424, 1.3634376970876751, 1.3670785990922676, 1.3706342682611146, 1.3741088103166372, 1.3775060365610854, 1.3808294915859265, 1.3840824777817182, 1.3872680770830843, 1.3903891703159095, 1.3934484544581194, 1.3964484580791439, 1.399391555184593, 1.4022799776604098, 1.405115826483646, 1.407901081844135, 1.4106376123019915, 1.4133271830894187, 1.4159714636513006, 1.4185720345070807, 1.4211303935061592, 1.4236479615402091, 1.4261260877681978, 1.4285660544033094, 1.4309690811052553, 1.4333363290164964, 1.4356689044765665, 1.4379678624449226, 1.4402342096594207, 1.4424689075546286, 1.4446728749616258, 1.4468469906086967, 1.4489920954403341, 1.4511089947702165, 1.4531984602822676, 1.4552612318925189, 1.4572980194832725, 1.4593095045199675, 1.461296341560167, 1.4632591596632236, 1.4651985637083846, 1.4671151356284056, 1.4690094355651133, 1.4708820029527816, 1.4727333575346886, 1.4745640003177505, 1.4763744144697202, 1.4781650661630636, 1.4799364053692776, 1.4816888666071195, 1.483422869647924, 1.485138820180944, 1.4868371104414024, 1.488518119803755, 1.490182215342446, 1.4918297523622892, 1.4934610749004247, 1.4950765162016713, 1.4966763991689516, 1.4982610367903493, 1.4998307325442393, 1.5013857807838382, 1.5029264671024134, 1.5044530686803177, 1.5059658546149228, 1.5074650862344559], [0.0, 0.9517721299086176, 1.0200841112177017, 1.062294930590616, 1.0932990799580533, 1.117969573293893, 1.1385395159938556, 1.156226150137964, 1.1717689405143865, 1.1856519896909246, 1.198210120579418, 1.2096848789832506, 1.22025643929113, 1.2300628966499005, 1.2392125044083735, 1.2477917486181098, 1.2558708546675876, 1.2635076497298003, 1.2707503383540875, 1.2776395395421891, 1.284209809779432, 1.290490800592986, 1.2965081513256753, 1.302284186813964, 1.3078384691212623, 1.3131882385870361, 1.3183487698798864, 1.3233336620334488, 1.3281550766680341, 1.3328239351527493, 1.3373500829406473, 1.341742427442301, 1.3460090544054943, 1.3501573267116054, 1.354193968692002, 1.3581251384457842, 1.3619564901569263, 1.3656932280304157, 1.3693401531684073, 1.3729017044702256, 1.3763819944503766, 1.3797848407161357, 1.3831137937227778, 1.3863721613239952, 1.3895630305528475, 1.3926892870009606, 1.395753632107863, 1.3987585986259896, 1.4017065644882605, 1.4045997652728213, 1.4074403054323636, 1.4102301684325436, 1.4129712259246288, 1.415665246061041, 1.418313901048422, 1.420918774020864, 1.4234813653056548, 1.4260030981450444, 1.42848532392991, 1.430929326994597, 1.4333363290164964, 1.4357074930589435, 1.4380439272916863, 1.440346688419398, 1.4426167848453784, 1.4448551795946936, 1.4470627930184423, 1.4492405052985868, 1.4513891587707917, 1.4535095600809635, 1.4556024821896207, 1.4576686662368352, 1.4597088232792659, 1.4617236359096974, 1.463713759768526, 1.4656798249557552, 1.467622437351282, 1.469542179850552, 1.4714396135220325, 1.4733152786923822, 1.475169695964689, 1.477003367174683, 1.4788167762894207, 1.4806103902525551, 1.4823846597799697, 1.4841400201092452, 1.4858768917061427, 1.4875956809310453, 1.4892967806680502, 1.4909805709192103, 1.4926474193662207, 1.4942976819016747, 1.4959317031318518, 1.4975498168528567, 1.4991523465017897, 1.5007396055845095, 1.5023118980814347, 1.5038695188327291, 1.5054127539041164, 1.506941880934488, 1.5084571694663826, 1.5099588812603422], [0.0, 0.9533210199136081, 1.0217441704214383, 1.0640236826192153, 1.0950782873588571, 1.1197889288345146, 1.1403923465414143, 1.1581077634686983, 1.1736758477909164, 1.1875814898922024, 1.2001600575667746, 1.2116534897035762, 1.22224225390258, 1.2320646700431956, 1.241229167643009, 1.2498223734988045, 1.2579146272820896, 1.2655638502723434, 1.2728183254657754, 1.279718737966467, 1.286299700496099, 1.2925909128359896, 1.2986180560537848, 1.3044034913168256, 1.3099668125233312, 1.3153252880692625, 1.3204942174808312, 1.325487221922398, 1.330316482805789, 1.3349929392732718, 1.3395264528001418, 1.343925945292668, 1.3481995156571762, 1.3523545387572125, 1.3563977498671524, 1.3603353171076316, 1.3641729038641006, 1.3679157228107395, 1.3715685828628956, 1.3751359301436465, 1.378621883860101, 1.382030267832212, 1.3853646382931766, 1.3886283084798046, 1.391824370448915, 1.3949557144880738, 1.3980250464330637, 1.401034903158057, 1.403987666465762, 1.4068855755724483, 1.4097307383555406, 1.4125251415085371, 1.4152706597285833, 1.4179690640455485, 1.4206220293873806, 1.4232311414645247, 1.4257979030458634, 1.4283237396897956, 1.4308100049864179, 1.4332579853601688, 1.4356689044765665, 1.4380439272916863, 1.4403841637786836, 1.4426906723618866, 1.444964463085645, 1.4472065005422272, 1.449417706580489, 1.451598962814778, 1.453751112951555, 1.4558749649494418, 1.4579712930268527, 1.460040839529973, 1.462084316672617, 1.464102408158404, 1.4660957706947022, 1.468065035406925, 1.4700108091609625, 1.4719336758008494, 1.4738341973081222, 1.4757129148887536, 1.4775703499930477, 1.4794070052734092, 1.4812233654844909, 1.4830198983298377, 1.484797055258817, 1.4865552722173043, 1.4882949703553157, 1.4900165566945354, 1.49172042475843, 1.4934069551674585, 1.4950765162016715, 1.496729464332833, 1.4983661447280265, 1.4999868917265677, 1.5015920292919105, 1.503181871440105, 1.50475672264626, 1.5063168782303547, 1.5078626247236488, 1.5093942402168565, 1.510911994691163, 1.5124161503330933], [0.0, 0.9548475870408182, 1.0233803045571623, 1.065727519566613, 1.096831852506676, 1.121582063500031, 1.1422184737661238, 1.1599622586540013, 1.175555272381177, 1.189483181793968, 1.202081891716029, 1.2135937284566445, 1.2241994486012386, 1.2340375935229015, 1.2432167663690181, 1.251823732653151, 1.2599289446827693, 1.2675904164875584, 1.274856508380008, 1.2817679706138614, 1.2883594713366657, 1.2946607578884408, 1.300697552460308, 1.3064922520268776, 1.3120644818623703, 1.3174315380148858, 1.322608744509995, 1.3276097443238313, 1.3324467383744967, 1.3371306833212702, 1.3416714564307743, 1.3460779938960592, 1.3503584075923496, 1.3545200841926703, 1.3585697697566925, 1.3625136422821542, 1.3663573742233701, 1.3701061866016522, 1.373764896032936, 1.3773379557599421, 1.3808294915859265, 1.3842433334539828, 1.3875830432919558, 1.3908519396421917, 1.394053119512866, 1.3971894778198046, 1.400263724731686, 1.4032784011850161, 1.4062358927965202, 1.4091384423681574, 1.4119881611527283, 1.4147870390250528, 1.4175369536842568, 1.420239678996186, 1.4228968925708754, 1.425510182657992, 1.4280810544328246, 1.4306109357365395, 1.4331011823267574, 1.435553082687888, 1.4379678624449226, 1.440346688419398, 1.4426906723618866, 1.4450008743915868, 1.4472783061702474, 1.4495239338347532, 1.4517386807101296, 1.4539234298224668, 1.4560790262292649, 1.4582062791829424, 1.460305964141681, 1.4623788246403955, 1.464425574033379, 1.4664468971190756, 1.468443451656449, 1.4704158697815428, 1.4723647593320308, 1.4742907050868654, 1.476194269927493, 1.4780759959265268, 1.4799364053692776, 1.4817760017130548, 1.4835952704887558, 1.4853946801488664, 1.4871746828656665, 1.488935715283118, 1.490678199225631, 1.4924025423666596, 1.4941091388598253, 1.49579836993508, 1.4974706044622075, 1.4991261994837943, 1.5007655007196459, 1.50238884304446, 1.5039965509404583, 1.5055889389265291, 1.507166311965342, 1.5087289658497764, 1.510277187569919, 1.5118112556617946, 1.5133314405389133, 1.514838004807643], [0.0, 0.956352499790037, 1.0249932301052076, 1.067407187560915, 1.0985605433061179, 1.1233497625229583, 1.1440186973482884, 1.1617904477968057, 1.1774080373049494, 1.1913578981670918, 1.2039764646185536, 1.215506444893397, 1.2261288804632349, 1.235982531052946, 1.245176170976773, 1.2537967024973569, 1.2619146889603865, 1.26958823583009, 1.2768657796385043, 1.283788134864886, 1.290390024296432, 1.2967012421572421, 1.3027475511785762, 1.308551383634388, 1.3141323957298299, 1.3195079107728942, 1.3246932769409874, 1.3297021587126154, 1.3345467762354597, 1.3392381034373309, 1.3437860331521787, 1.348199515657176, 1.352486675612483, 1.3566549113330855, 1.3607109795109595, 1.3646610678808402, 1.3685108578372633, 1.3722655786302695, 1.3759300544671489, 1.379508745609273, 1.3830057843624786, 1.3864250067061423, 1.3897699801819796, 1.3930440285626131, 1.3962502537373394, 1.399391555184593, 1.4024706473444855, 1.4054900751582327, 1.408452228002474, 1.4113593522139962, 1.414213562373095, 1.4170168514907855, 1.4197711002255906, 1.4224780852391046, 1.4251394867854035, 1.4277568956173572, 1.430331819282526, 1.4328656878724633, 1.4353598592815664, 1.4378156240249955, 1.4402342096594207, 1.4426167848453784, 1.444964463085645, 1.4472783061702474, 1.449559327355391, 1.451808494300666, 1.4540267317863287, 1.4562149242301856, 1.4583739180216122, 1.4605045236884704, 1.4626075179111235, 1.4646836453963543, 1.4667336206227566, 1.468758129468069, 1.4707578307279336, 1.4727333575346888, 1.4746853186840068, 1.4766142998764966, 1.4785208648807489, 1.4804055566237244, 1.4822688982138956, 1.484111393902059, 1.4859335299843457, 1.4877357756515588, 1.4895185837886358, 1.4912823917277231, 1.4930276219580585, 1.4947546827956202, 1.496463969015246, 1.4981558624477358, 1.4998307325442395, 1.5014889369100708, 1.5031308218099155, 1.50475672264626, 1.5063669644127338, 1.5079618621239321, 1.509541721223168, 1.511106837969514, 1.5126574998053743, 1.5141939857057682, 1.5157165665103982, 1.5172255052395196], [0.0, 0.9578363965785065, 1.026583631304232, 1.0690633991544003, 1.100265093106018, 1.125092775800282, 1.145793780982531, 1.163593106455343, 1.1792349285460542, 1.1932064343076842, 1.2058445799940376, 1.217392450430411, 1.2280313679961983, 1.2379003077188055, 1.2471082126890045, 1.2557421200088268, 1.2638727025115424, 1.2715581558190487, 1.2788469916185308, 1.2857800877178558, 1.2923922207808318, 1.2987132312609084, 1.3047689218633445, 1.310581759668485, 1.3161714313804662, 1.3215552871864926, 1.326748699078527, 1.3317653527371702, 1.3366174872711425, 1.3413160936356343, 1.3458710800145255, 1.3502914105724286, 1.3545852225758985, 1.358759925819303, 1.3628222874784452, 1.3667785048890797, 1.3706342682611146, 1.3743948149584055, 1.378064976673585, 1.3816492205886604, 1.3851516854212418, 1.3885762131026924, 1.3919263767102015, 1.3952055051736267, 1.3984167051952228, 1.401562880752316, 1.4046467504968, 1.4076708633186765, 1.4106376123019917, 1.413549247268996, 1.4164078860810125, 1.4192155248414549, 1.4219740471269153, 1.4246852323556938, 1.4273507633889846, 1.429972233447903, 1.432551152419152, 1.4350889526132453, 1.4375869940315187, 1.4400465691915219, 1.4424689075546286, 1.4448551795946936, 1.4472065005422272, 1.4495239338347532, 1.451808494300666, 1.4540611511009969, 1.4562828304509112, 1.4584744181404967, 1.4606367618724048, 1.462770673432129, 1.464876930705147, 1.4669562795537436, 1.4690094355651133, 1.471037085681217, 1.4730398897198982, 1.4750184817958765, 1.4769734716494445, 1.4789054458899968, 1.4808149691608792, 1.4827025852314697, 1.4845688180219063, 1.4864141725653925, 1.4882391359126064, 1.4900441779823574, 1.4918297523622892, 1.4935962970631218, 1.4953442352296358, 1.4970739758113618, 1.4987859141956785, 1.5004804328058423, 1.5021579016662514, 1.5038186789370875, 1.505463111420308, 1.507091535038817, 1.5087042752905109, 1.5103016476787683, 1.5118839581208345, 1.5134515033354639, 1.5150045712110625, 1.516543441155513, 1.5180683844287586, 1.5195796644591621], [0.0, 0.9592998875336589, 1.0281521620726262, 1.0706968353244348, 1.1019462027587545, 1.1268118199992418, 1.147544454522321, 1.1653709758209863, 1.1810366972594708, 1.1950295502703652, 1.2076870059474099, 1.2192525205284361, 1.2299076934377098, 1.2397917120444277, 1.2490136858949572, 1.2576607850764745, 1.2658037904042105, 1.2735009864179263, 1.2808009589264584, 1.2877446481954193, 1.2943668840243443, 1.3006975524603077, 1.306762495632865, 1.3125842149501115, 1.3181824271957598, 1.3235745090665967, 1.3287758560416552, 1.3338001747120694, 1.3386597228868566, 1.3433655083144336, 1.347927454317526, 1.3523545387572122, 1.3566549113330852, 1.3608359931610363, 1.3649045617565259, 1.3688668239243003, 1.3727284785684148, 1.3764947710549633, 1.3801705404589855, 1.383760260787955, 1.3872680770830843, 1.3906978371458742, 1.3940531195128658, 1.3973372582002337, 1.4005533646570032, 1.403704347297527, 1.406792928927563, 1.4098216623315951, 1.4127929442500948, 1.4157090279428461, 1.4185720345070807, 1.4213839630960843, 1.4241467001643917, 1.426862027849099, 1.4295316315826672, 1.4321571070205148, 1.434739966356321, 1.4372816440890452, 1.439783502297988, 1.4422468354755535, 1.4446728749616258, 1.4470627930184423, 1.449417706580489, 1.4517386807101296, 1.4540267317863287, 1.4562828304509112, 1.458507904334219, 1.4607028405797509, 1.4628684881853733, 1.4650056601769188, 1.4671151356284056, 1.4691976615417321, 1.4712539545974477, 1.473284702787101, 1.47529056693668, 1.4772721821297767, 1.4792301590383141, 1.4811650851679747, 1.4830775260248306, 1.4849680262090923, 1.4868371104414024, 1.488685284526611, 1.4905130362595675, 1.492320836277077, 1.494109138859825, 1.4958783826877744, 1.4976289915522345, 1.499361375027575, 1.501075929105292, 1.5027730367929517, 1.504453068680318, 1.5061163834748095, 1.5077633285082672, 1.5093942402168563, 1.5110094445958062, 1.5126092576305565, 1.5141939857057682, 1.5157639259935558, 1.517319366822194, 1.5188605880264765, 1.520387861280808, 1.5219014504160473], [0.0, 0.9607435561536403, 1.0296994477882186, 1.0723081473268217, 1.1036045425276881, 1.1285075805078137, 1.1492714159663453, 1.167124764735478, 1.1828140618156822, 1.1968279729368279, 1.2095044770593142, 1.2210873968028881, 1.2317586048842384, 1.2416574981382769, 1.2508933503123998, 1.2595534626777032, 1.2677087225688106, 1.2754175022389942, 1.2827284606147968, 1.2896825995736148, 1.2963148013310097, 1.302654996910136, 1.30872906733086, 1.3145595478640744, 1.3201661849656539, 1.3255663814829057, 1.330775556063812, 1.3358074359268162, 1.3406742973279453, 1.3453871645813855, 1.3499559759436595, 1.3543897227867991, 1.3586965670750355, 1.3628839410924374, 1.3669586325540772, 1.37092685760544, 1.37479432372697, 1.3785662841786117, 1.382247585317821, 1.3858427078850903, 1.3893558031595834, 1.3927907247334306, 1.3961510565285806, 1.399440137578632, 1.4026610840150895, 1.405816808629233, 1.408910038324423, 1.4119433297268773, 1.4149190831839675, 1.4178395553464507, 1.4207068705036388, 1.4235230308173807, 1.4262899255811727, 1.429009339614083, 1.4316829608850112, 1.4343123874507089, 1.4368991337805836, 1.4394446365324003, 1.4419502598352774, 1.444417300129726, 1.4468469906086967, 1.4492405052985868, 1.451598962814778, 1.4539234298224668, 1.4562149242301856, 1.4584744181404967, 1.4607028405797509, 1.462901080026525, 1.46506998675636, 1.467210375018625, 1.4693230250597822, 1.4714086850059076, 1.4734680726160962, 1.4755018769172685, 1.477510759729902, 1.479495357093338, 1.4814562805985114, 1.4833941186352533, 1.485309437560676, 1.4872027827945697, 1.4890746798472392, 1.4909256352847295, 1.4927561376359821, 1.494566658246072, 1.4963576520793407, 1.4981295584759287, 1.4998828018649166, 1.501617792437051, 1.5033349267797629, 1.5050345884770135, 1.5067171486762745, 1.5083829666247903, 1.5100323901771082, 1.511665756275702, 1.5132833914063981, 1.5148856120301686, 1.516472724992758, 1.5180450279135014, 1.519602809554584, 1.5211463501719278, 1.522675921848786, 1.5241917888130616], [0.0, 0.9621679608471888, 1.031226086938676, 1.0738979584144939, 1.1052407538560174, 1.1301807132434794, 1.1509753333005583, 1.1688551515615961, 1.1845677096964866, 1.198602397934115, 1.2112976963247013, 1.2228977889810073, 1.2335848182654034, 1.2434983876834627, 1.2527479329925555, 1.2614208848972142, 1.2695882358300898, 1.2773084445875398, 1.2846302422381501, 1.2915946914489693, 1.2982367261521603, 1.304586321746809, 1.3106693976241515, 1.3165085224660202, 1.3221234720045154, 1.327531674888519, 1.3327485726258026, 1.3377879127868733, 1.3426619898286156, 1.3473818444099361, 1.3519574295218821, 1.3563977498671524, 1.3607109795109595, 1.3649045617565259, 1.3689852943824343, 1.372959402750268, 1.3768326028024191, 1.3806101555873498, 1.3842969146477573, 1.387897367367309, 1.3914156711798826, 1.3948556853909693, 1.3982209992360641, 1.4015149566992386, 1.4047406785319945, 1.407901081844135, 1.4109988975819459, 1.4140366861621152, 1.4170168514907853, 1.419941653564439, 1.4228132198218728, 1.4256335553933543, 1.428404552373459, 1.4311279982274387, 1.4338055834267875, 1.4364389083975462, 1.4390294898544844, 1.4415787665853652, 1.4440881047417744, 1.4465588026863339, 1.4489920954403341, 1.4513891587707917, 1.453751112951555, 1.4560790262292649, 1.4583739180216122, 1.4606367618724048, 1.4628684881853733, 1.46506998675636, 1.4672421091215282, 1.4693856707374602, 1.471501453007416, 1.4735902051666478, 1.4756526460384056, 1.4776894656711654, 1.4797013268666241, 1.4816888666071193, 1.4836526973903343, 1.485593408478451, 1.4875115670682666, 1.4894077193882138, 1.491282391727723, 1.493136091403877, 1.4949693076699138, 1.4967825125697272, 1.498576161742192, 1.5003506951788175, 1.502106537937946, 1.5038441008184742, 1.5055637809958176, 1.5072659626226412, 1.5089510173966818, 1.5106193050978067, 1.5122711740962944, 1.513906961834172, 1.5155269952813157, 1.5171315913678847, 1.5187210573945553, 1.5202956914219143, 1.5218557826402686, 1.523401611721049, 1.5249334511509007, 1.5264515655494733], [0.0, 0.9635736363632673, 1.0327326526537461, 1.0754668654331612, 1.1068554510089963, 1.1318318463325003, 1.1526568462083528, 1.1705627859198902, 1.1862982992550826, 1.2003534914155538, 1.2130673369526295, 1.2246843767188942, 1.2353870191768899, 1.2453150717853847, 1.2545781301814902, 1.2632637528012847, 1.2714430357935353, 1.2791745233597491, 1.2865070177619768, 1.2934816416576087, 1.3001333800153998, 1.3064922520268776, 1.3125842149501115, 1.3184318704385611, 1.3240550231156052, 1.3294711270924424, 1.3346956464360542, 1.339742348801407, 1.3446235466069243, 1.3493502966413202, 1.3539325664364246, 1.3583793738503223, 1.3626989048900937, 1.3668986137332262, 1.370985308089491, 1.3749652224153883, 1.3788440810039941, 1.3826271525898792, 1.3863192978065044, 1.3899250105933632, 1.3934484544581196, 1.3968934943445024, 1.400263724731686, 1.4035624944891225, 1.406792928927563, 1.4099579494185515, 1.413060290898138, 1.4161025175236426, 1.419087036713184, 1.4220161117649783, 1.4248918732258953, 1.4277163291555903, 1.430491374412886, 1.4332187990744256, 1.4359002960813902, 1.4385374681979568, 1.4411318343547341, 1.443684835441476, 1.446197839605642, 1.4486721471066923, 1.4511089947702165, 1.4535095600809635, 1.4558749649494418, 1.4582062791829424, 1.4605045236884704, 1.462770673432129, 1.4650056601769188, 1.467210375018625, 1.4693856707374602, 1.4715323639813442, 1.4736512372951251, 1.475743041008648, 1.477808494995324, 1.4798482903117534, 1.4818630907279504, 1.4838535341568493, 1.4858202339909599, 1.487763780353344, 1.4896847412694427, 1.4915836637656996, 1.493461074900425, 1.4953174827318647, 1.4971533772280292, 1.4989692311224434, 1.5007655007196459, 1.5025426266539492, 1.5043010346046835, 1.5060411359709007, 1.5077633285082674, 1.5094679969306757, 1.5111555134788925, 1.5128262384584041, 1.514480520748439, 1.5161186982840091, 1.5177410985126758, 1.5193480388276164, 1.5209398269784569, 1.5225167614612347, 1.5240791318887472, 1.5256272193424723, 1.5271612967071428, 1.5286816289890035], [0.0, 0.9649610951198175, 1.0342196941293802, 1.0770154403043632, 1.1084492226002718, 1.1334615816706974, 1.1543165676600577, 1.1722482903028724, 1.1880064613519559, 1.202081891716029, 1.214814044039067, 1.2264478112903319, 1.2371658645840293, 1.2471082126890045, 1.2563846090501591, 1.2650827381797884, 1.2732737985986744, 1.281016418806671, 1.2883594713366657, 1.295344138058951, 1.3020054543174677, 1.3083734825286597, 1.3144742173266974, 1.320330292909374, 1.325961542416932, 1.331385445092909, 1.3366174872711423, 1.3416714564307746, 1.3465596827189963, 1.351293238845296, 1.3558821066938467, 1.3603353171076316, 1.3646610678808404, 1.3688668239243005, 1.372959402750268, 1.376945047792297, 1.3808294915859263, 1.384618010452227, 1.3883154720235322, 1.3919263767102013, 1.3954548940149718, 1.398904894446742, 1.40227997766041, 1.405583497347497, 1.4088185833189184, 1.4119881611527285, 1.415094969723038, 1.4181415768793202, 1.4211303935061592, 1.4240636861607145, 1.426943588457651, 1.4297721113480473, 1.4325511524191519, 1.4352825043251558, 1.4379678624449226, 1.4406088318504637, 1.443206933659511, 1.4457636108365688, 1.448280233499105, 1.4507581037788357, 1.4531984602822676, 1.4556024821896207, 1.4579712930268527, 1.460305964141681, 1.4626075179111235, 1.464876930705147, 1.4671151356284056, 1.4693230250597822, 1.471501453007416, 1.4736512372951251, 1.475773161594552, 1.4778679773159482, 1.4799364053692776, 1.4819791378061995, 1.4839968393524965, 1.48599014883964, 1.4879596805433695, 1.4899060254364704, 1.4918297523622892, 1.4937314091349376, 1.4956115235716423, 1.4974706044622073, 1.4993091424801523, 1.5011276110396956, 1.5029264671024132, 1.5047061519370912, 1.5064670918359993, 1.5082096987905667, 1.5099343711291924, 1.5116414941197212, 1.5133314405389133, 1.5150045712110622, 1.5166612355177511, 1.5183017718805876, 1.5199265082186277, 1.5215357623820662, 1.523129842563661, 1.5247090476892562, 1.5262736677886661, 1.5278239843480996, 1.52936027064522, 1.5308827920678558], [0.0, 0.9663308284400851, 1.0356877379527947, 1.0785442314053602, 1.1100226330120477, 1.1350704963756626, 1.1559550853918679, 1.1739122615769217, 1.1896928008769756, 1.2037882108921085, 1.216538436123333, 1.2281887171581327, 1.2389219844068788, 1.2488784453766626, 1.2581680093041079, 1.266878485167044, 1.2750811725504168, 1.2828347831754765, 1.2901882589482045, 1.297182840195323, 1.3038536119923916, 1.3102306794285528, 1.31634007403658, 1.322204462142831, 1.3278437050400957, 1.3332753067831737, 1.3385147756882885, 1.3435759188054954, 1.348471083784259, 1.3532113590514467, 1.3578067406602166, 1.3622662722725625, 1.366598163319197, 1.3708098893071645, 1.3749082774259753, 1.3788995799715495, 1.3827895376165888, 1.3865834341717433, 1.3902861441788046, 1.3939021744363287, 1.3974357003655382, 1.4008905979694015, 1.40427047201242, 1.4075786809465787, 1.4108183590254657, 1.4139924359799059, 1.4171036545717592, 1.4201545862954845, 1.4231476454578438, 1.4260851018333072, 1.4289690920651408, 1.4318016299589085, 1.4345846157954267, 1.4373198447735054, 1.4400090146785471, 1.4426537328609157, 1.4452555225975232, 1.4478158289011192, 1.450336023834012, 1.4528174113762549, 1.4552612318925189, 1.4576686662368352, 1.460040839529973, 1.4623788246403955, 1.4646836453963543, 1.4669562795537436, 1.4691976615417321, 1.4714086850059076, 1.4735902051666478, 1.475743041008648, 1.4778679773159482, 1.4799657665654045, 1.4820371306902913, 1.4840827627246138, 1.4861033283377136, 1.4880994672678638, 1.4900717946627495, 1.4920209023340247, 1.4939473599324922, 1.495851716049869, 1.4977344992526027, 1.4995962190527088, 1.501437366820204, 1.5032584166413032, 1.505059826126226, 1.5068420371701263, 1.5086054766703827, 1.510350557203234, 1.5120776776624947, 1.5137872238628853, 1.5154795691103116, 1.5171550747412463, 1.5188140906332093, 1.5204569556881875, 1.5220839982907082, 1.5236955367421452, 1.5252918796727262, 1.5268733264326122, 1.528440167463306, 1.5299926846505774, 1.5315311516599992, 1.5330558342561103], [0.0, 0.9676833077041481, 1.0371372893366482, 1.0800537648543813, 1.1115762237178446, 1.1366591441393648, 1.1575729632833396, 1.175555272381177, 1.1913578981670916, 1.2054730361565402, 1.2182411066377865, 1.2299076934377098, 1.2406559829965822, 1.250626379056305, 1.2599289446827693, 1.2686516117514892, 1.2768657796385041, 1.2846302422381501, 1.2919940099556333, 1.2989983808377492, 1.305678489065226, 1.3120644818623703, 1.31818242719576, 1.3240550231156052, 1.3297021587126152, 1.3351413625403128, 1.3403881646204026, 1.3454563913273254, 1.3503584075923496, 1.3551053173617347, 1.3597071306791424, 1.3641729038641006, 1.3685108578372633, 1.3727284785684148, 1.3768326028024191, 1.3808294915859263, 1.384724893626299, 1.3885241001294237, 1.3922319924595132, 1.395853083722852, 1.399391555184593, 1.4028512882725692, 1.4062358927965202, 1.4095487319089293, 1.4127929442500948, 1.4159714636513008, 1.4190870367131838, 1.4221422385292741, 1.4251394867854035, 1.4280810544328244, 1.4309690811052553, 1.4338055834267878, 1.4365924643378758, 1.4393315215498952, 1.4420244552244732, 1.4446728749616258, 1.4472783061702474, 1.4498421958855316, 1.4523659180901287, 1.454850778589146, 1.4572980194832725, 1.4597088232792659, 1.462084316672617, 1.464425574033379, 1.4667336206227566, 1.4690094355651133, 1.4712539545974477, 1.4734680726160962, 1.4756526460384056, 1.477808494995324, 1.4799364053692776, 1.4820371306902913, 1.4841113939020587, 1.4861598890085579, 1.4881832826108028, 1.490182215342446, 1.492157303212135, 1.494109138859825, 1.4960382927336033, 1.4979453141929981, 1.4998307325442393, 1.5016950580124573, 1.5035387826553912, 1.5053623812227888, 1.5071663119653418, 1.5089510173966818, 1.510716925011674, 1.5124644479640008, 1.5141939857057682, 1.5159059245916855, 1.5176006384501375, 1.5192784891233249, 1.5209398269784566, 1.5225849913918483, 1.524214311207635, 1.5258281051726854, 1.5274266823491875, 1.5290103425062738, 1.5305793764919489, 1.5321340665865117, 1.5336746868385573, 1.53520150338459], [0.0, 0.9690189854225578, 1.0385688332697407, 1.081544545708939, 1.113110514515788, 1.1382280564892693, 1.1591707426417117, 1.1771778724318112, 1.193002310328141, 1.2071369312157183, 1.2199226252594597, 1.2316053152616542, 1.2423684405118738, 1.252352598549048, 1.261668004357349, 1.2704027111832457, 1.278628216954189, 1.2864033967167818, 1.2937773285245056, 1.300791367427186, 1.307480696100696, 1.3138755033810718, 1.3200018932160862, 1.3258825949857038, 1.3315375252332258, 1.3369842367065554, 1.3422382808632374, 1.3473135031620345, 1.352222285601331, 1.3569757474539854, 1.3615839125803615, 1.3660558498002795, 1.370399791381598, 1.3746232336268651, 1.378733022717594, 1.3827354283424567, 1.3866362071436644, 1.39044065763047, 1.3941536679047548, 1.3977797573021715, 1.4013231128592059, 1.4047876213611636, 1.4081768976003464, 1.4114943093713432, 1.414742999646667, 1.4179259063071217, 1.4210457797444331, 1.4241051986064914, 1.4271065839162211, 1.4300522117621932, 1.432944224731428, 1.4357846422315306, 1.4385753698295536, 1.4413182077182245, 1.4440148584058765, 1.4466669337142306, 1.4492759611576789, 1.451843389768734, 1.4543705954265325, 1.4568588857385634, 1.4593095045199675, 1.4617236359096974, 1.464102408158404, 1.4664468971190756, 1.468758129468069, 1.471037085681217, 1.473284702787101, 1.4755018769172685, 1.4776894656711654, 1.4798482903117534, 1.4819791378061995, 1.4840827627246138, 1.4861598890085579, 1.4882112116199322, 1.4902373980798491, 1.4922390899062177, 1.4942169039579525, 1.49617143369302, 1.4981032503468878, 1.500012904037356, 1.5019009248012478, 1.5037678235679488, 1.5056140930743775, 1.5074402087255716, 1.5092466294047382, 1.511033798236304, 1.5128021433051981, 1.514552078335372, 1.51628400333029, 1.5179983051779395, 1.5196953582226955, 1.521375524806203, 1.5230391557792777, 1.5246865909866703, 1.5263181597264146, 1.5279341811853404, 1.5295349648522294, 1.5311208109099799, 1.5326920106080504, 1.534248846616366, 1.535791593361787, 1.5373205173481612], [0.0, 0.9703382962383448, 1.0399828355909382, 1.0830170590841923, 1.1146260046796124, 1.1397777439653136, 1.1607489434005382, 1.1787805897392818, 1.1946265724684626, 1.2087804375179136, 1.2215835391715089, 1.2332821350532674, 1.2440599142037385, 1.254057665584163, 1.2633857542354436, 1.2721323532877689, 1.280369058012388, 1.2881548236137619, 1.2955387949647095, 1.3025623834195927, 1.3092608195551876, 1.315664333309365, 1.3217990641701929, 1.3276877724634861, 1.3333504018487445, 1.3388045289717834, 1.3440657264633193, 1.3491478586325854, 1.354063324335948, 1.3588232579850572, 1.363437697087675, 1.3679157228107393, 1.3722655786302693, 1.3764947710549633, 1.3806101555873498, 1.3846180104522268, 1.3885241001294235, 1.392333730342066, 1.3960517958471437, 1.3996828221333448, 1.4032310019377685, 1.4067002273375442, 1.4100941180464819, 1.4134160464443928, 1.4166691597829195, 1.419856399942765, 1.4229805210602886, 1.4260441052941872, 1.4290495769635871, 1.431999215255933, 1.4348951656753592, 1.4377394503788765, 1.44053397752795, 1.4432805497662538, 1.4459808719200713, 1.4486365580056044, 1.4512491376169425, 1.4538200617594437, 1.4563507081854916, 1.4588423862828712, 1.461296341560167, 1.463713759768526, 1.4660957706947022, 1.468443451656449, 1.4707578307279336, 1.4730398897198982, 1.47529056693668, 1.477510759729902, 1.4797013268666241, 1.4818630907279504, 1.4839968393524965, 1.4861033283377136, 1.4881832826108028, 1.4902373980798491, 1.4922663431747893, 1.4942707602869534, 1.4962512671151036, 1.4982084579251944, 1.5001429047304256, 1.5020551583975774, 1.5039457496851139, 1.5058151902180466, 1.5076639734041508, 1.5094925752957236, 1.5113014554007382, 1.5130910574469307, 1.5148618101020648, 1.5166141276533731, 1.5183484106489207, 1.5200650465034402, 1.5217644100709729, 1.523446864186489, 1.525112760178484, 1.5267624383544047, 1.5283962284606212, 1.530014450118533, 1.5316174132382885, 1.5332054184114823, 1.5347787572841063, 1.5363377129109381, 1.5378825600924682, 1.5394135656953865], [0.0, 0.9716416578630734, 1.0413797439924106, 1.0844717711976986, 1.1161231740339044, 1.141308697219414, 1.1623080652394242, 1.1803639317454637, 1.1962311988513155, 1.2104040754193457, 1.223224374241637, 1.234938683716268, 1.2457309396155174, 1.2557421200088268, 1.2650827381797884, 1.2738410856930327, 1.2820888539868154, 1.2898850774544235, 1.2972789669802325, 1.3043119895424733, 1.3110194230397498, 1.317431538014886, 1.3235745090665967, 1.3294711270924426, 1.3351413625403128, 1.3406028156650318, 1.3458710800145255, 1.3509600385206135, 1.355882106693847, 1.360648433901655, 1.3652690711342126, 1.3697531117563122, 1.3741088103166372, 1.3783436834066531, 1.3824645957372221, 1.386477833966075, 1.3903891703159093, 1.394203917636516, 1.3979269772595382, 1.4015628807523157, 1.405115826483646, 1.40858971175851, 1.4119881611527285, 1.415314551575905, 1.4185720345070807, 1.4217635557785027, 1.4248918732258955, 1.4279595724763197, 1.4309690811052556, 1.43392268136156, 1.4368225216312152, 1.4396706267874, 1.4424689075546284, 1.445219168997892, 1.4479231182334018, 1.450582371445312, 1.4531984602822678, 1.4557728376986223, 1.4583068832973611, 1.4608019082250432, 1.4632591596632236, 1.4656798249557552, 1.468065035406925, 1.4704158697815428, 1.4727333575346888, 1.4750184817958765, 1.4772721821297767, 1.479495357093338, 1.4816888666071193, 1.4838535341568493, 1.48599014883964, 1.4880994672678638, 1.490182215342446, 1.4922390899062177, 1.4942707602869534, 1.4962778697388446, 1.4982610367903493, 1.5002208565056416, 1.5021579016662512, 1.504072723878885, 1.5059658546149226, 1.507837806186593, 1.5096890726644177, 1.5115201307401291, 1.5133314405389133, 1.5151234463845225, 1.5168965775205085, 1.5186512487905761, 1.520387861280808, 1.522106802926313, 1.523808449084638, 1.5254931630781141, 1.5271612967071426, 1.5288131907362725, 1.53044917535479, 1.5320695706134115, 1.5336746868385573, 1.535264825025578, 1.536840277212205, 1.5384013268334165, 1.5399482490588157, 1.5414813111135486], [0.0, 0.9729294719520967, 1.042759988957706, 1.0859091303463049, 1.1176024839595073, 1.1428213880435563, 1.1638485886310341, 1.1819283863869205, 1.1978166839724433, 1.2120083452745145, 1.224845636123975, 1.236575471747225, 1.2473820317050612, 1.2574064809192924, 1.2667594791478436, 1.2755294349770063, 1.2837881348648863, 1.2915946914489695, 1.2989983808377497, 1.3060407249698005, 1.3127570485010613, 1.319177662094941, 1.3253287750419738, 1.3312332084467813, 1.3369109592260897, 1.3423796509621049, 1.3476548978704452, 1.3527506012833717, 1.3576791931669558, 1.362451837666001, 1.3670785990922676, 1.3715685828628956, 1.375930054467149, 1.3801705404589857, 1.3842969146477573, 1.3883154720235322, 1.3922319924595132, 1.396051795847144, 1.3997797900142939, 1.4034205125344426, 1.4069781673409072, 1.410456656904157, 1.4138596106040269, 1.4171904098258772, 1.42045221022572, 1.4236479615402091, 1.4267804252603056, 1.4298521904400605, 1.4328656878724633, 1.4358232028312639, 1.4387268865499159, 1.4415787665853654, 1.4443807561946016, 1.447134662835049, 1.4498421958855316, 1.452504973672294, 1.455124529874029, 1.4577023193708356, 1.4602397235942255, 1.4627380554285518, 1.4651985637083846, 1.467622437351282, 1.4700108091609625, 1.4723647593320308, 1.4746853186840068, 1.4769734716494445, 1.4792301590383141, 1.4814562805985114, 1.4836526973903343, 1.4858202339909599, 1.4879596805433695, 1.4900717946627495, 1.492157303212135, 1.4942169039579525, 1.4962512671151036, 1.4982610367903493, 1.500246832331945, 1.5022092495927635, 1.5041488621134986, 1.5060662222319574, 1.5079618621239321, 1.5098362947806694, 1.511690014927533, 1.5135234998880622, 1.5153372103972929, 1.5171315913678847, 1.5189070726123084, 1.520664069524103, 1.5224029837209505, 1.5241242036521296, 1.5258281051726854, 1.5275150520864973, 1.5291853966602424, 1.5308394801101193, 1.532477633063047, 1.5341001759939372, 1.5357074196405174, 1.5372996653970767, 1.5388772056884141, 1.5404403243251723, 1.541989296841664, 1.5435243908172163], [0.0, 0.9742021249237081, 1.044123984639697, 1.0873295678204233, 1.1190643783344794, 1.1443162703319882, 1.1653709758209863, 1.183474423090022, 1.1993835035685694, 1.2135937284566445, 1.2264478112903319, 1.2381929902766857, 1.2490136858949572, 1.2590512477195563, 1.2684164802583349, 1.277197907741578, 1.285467410528596, 1.2932841785799245, 1.3006975524603077, 1.307749108421628, 1.3144742173266972, 1.3209032294871794, 1.3270623884770103, 1.3329745452522521, 1.3386597228868564, 1.3441355680157836, 1.349417715279029, 1.3545200841926703, 1.3594551229845735, 1.3642340104029458, 1.3688668239243003, 1.3733626808762356, 1.3777298575597963, 1.381975890374146, 1.3861076621200115, 1.3901314760217045, 1.3940531195128658, 1.3978779194436914, 1.4016107900617987, 1.4052562748760988, 1.4088185833189184, 1.4123016229654035, 1.4157090279428461, 1.4190441840596715, 1.4223102510996886, 1.4255101826579921, 1.428646743837747, 1.43172252707965, 1.434739966356321, 1.4377013499307914, 1.4406088318504637, 1.4434644423244565, 1.4462700971124187, 1.4490276060360434, 1.4517386807101296, 1.4544049415777942, 1.4570279243238784, 1.4596090857315562, 1.4621498090393386, 1.4646514088489135, 1.4671151356284056, 1.469542179850552, 1.4719336758008494, 1.4742907050868654, 1.4766142998764966, 1.4789054458899968, 1.4811650851679747, 1.4833941186352533, 1.485593408478451, 1.487763780353344, 1.4899060254364704, 1.4920209023340247, 1.494109138859825, 1.49617143369302, 1.4982084579251944, 1.5002208565056416, 1.5022092495927635, 1.5041742338188455, 1.5061163834748095, 1.5080362516209544, 1.5099343711291922, 1.5118112556617946, 1.513667400591257, 1.515503283865488, 1.5173193668221938, 1.5191160949560079, 1.520893898641623, 1.5226531938159382, 1.524394382621978, 1.5261178540171358, 1.5278239843480999, 1.5295131378946272, 1.5311856673841826, 1.5328419144792962, 1.5344822102393683, 1.5361068755585119, 1.5377162215809188, 1.539310550095121, 1.5408901539084272, 1.5424553172027227, 1.5440063158727362, 1.5455434178478054], [0.0, 0.9754599887264647, 1.0454721296829765, 1.0887334987604584, 1.1205092844155162, 1.145793780982531, 1.1668756717457496, 1.1850024937030992, 1.200932115562082, 1.2151606883135608, 1.2280313679961983, 1.2397917120444277, 1.250626379056305, 1.260676901113041, 1.2700542257903125, 1.2788469916185308, 1.2871271717670083, 1.2949540326207798, 1.3023769784518104, 1.3094376391941303, 1.3161714313804662, 1.322608744509995, 1.3287758560416552, 1.3346956464360544, 1.3403881646204028, 1.3458710800145255, 1.3511600474454477, 1.3562690044017556, 1.3612104151841344, 1.3659954729744934, 1.3706342682611146, 1.3751359301436465, 1.379508745609273, 1.383760260787955, 1.387897367367309, 1.3919263767102013, 1.395853083722852, 1.399682822133345, 1.4034205125344426, 1.4070707043015138, 1.4106376123019917, 1.4141251491563793, 1.4175369536842568, 1.4208764160657152, 1.424146700164392, 1.4273507633889846, 1.430491374412886, 1.4335711290240831, 1.436592464337876, 1.439557671571841, 1.4424689075546284, 1.445328205116709, 1.4481374824913098, 1.4508985518369168, 1.4536131269783206, 1.4562828304509112, 1.4589091999223651, 1.4614936940568155, 1.4640376978787744, 1.4665425276873083, 1.4690094355651133, 1.4714396135220325, 1.4738341973081222, 1.476194269927493, 1.4785208648807489, 1.4808149691608792, 1.4830775260248306, 1.485309437560676, 1.4875115670682666, 1.4896847412694427, 1.4918297523622892, 1.4939473599324922, 1.4960382927336033, 1.4981032503468878, 1.5001429047304256, 1.5021579016662512, 1.5041488621134986, 1.5061163834748095, 1.508061040782614, 1.5099833878113087, 1.5118839581208345, 1.5137632660366909, 1.5156218075709846, 1.5174600612887383, 1.5192784891233249, 1.5210775371445886, 1.52285763628291, 1.524619203012236, 1.5263626399948262, 1.5280883366902867, 1.5297966699312333, 1.5314880044677721, 1.5331626934827998, 1.534821079079992, 1.5364634927462046, 1.5380902557898803, 1.5397016797569516, 1.5412980668256122, 1.542879710181236, 1.5444468943726357, 1.5459998956507686, 1.5475389822909151], [0.0, 0.976703421558577, 1.0468048079948808, 1.0901213229597335, 1.121937613664313, 1.1472543407415876, 1.1683631048931984, 1.1865130333703686, 1.2024629609467068, 1.216709671063857, 1.2295967571864037, 1.2413720923137912, 1.2522205704310376, 1.2622839040323264, 1.2716731821198002, 1.2804771562126753, 1.2887678912254954, 1.2966047290910052, 1.3040371370575041, 1.311106798125296, 1.3178491739730696, 1.3242946928379318, 1.330469665675075, 1.3363970021111578, 1.3420967766300453, 1.3475866811750257, 1.3528823905285563, 1.35799785994554, 1.3629455696150847, 1.367736726987209, 1.3723814354126849, 1.376888835628156, 1.381267225184346, 1.3855241598303778, 1.389666540038799, 1.3937006852176617, 1.397632397660036, 1.4014670178929851, 1.4052094727816216, 1.4088643175004685, 1.4124357722897107, 1.415927754757325, 1.419343908361347, 1.4226876276033784, 1.4259620803800794, 1.429170227869999, 1.4323148422757972, 1.4353985226943498, 1.4384237093475818, 1.4413926963737178, 1.444307643350749, 1.4471705857004236, 1.4499834441011683, 1.4527480330214537, 1.4554660684707073, 1.458139175052588, 1.4607688923948596, 1.4633566810210352, 1.4659039277211376, 1.4684119504721385, 1.4708820029527816, 1.4733152786923822, 1.4757129148887536, 1.4780759959265268, 1.4804055566237244, 1.4827025852314697, 1.4849680262090923, 1.4872027827945697, 1.4894077193882138, 1.4915836637656996, 1.4937314091349376, 1.495851716049869, 1.4979453141929981, 1.500012904037356, 1.5020551583975774, 1.504072723878885, 1.5060662222319574, 1.5080362516209544, 1.5099833878113087, 1.5119081852833198, 1.5138111782770665, 1.5156928817736655, 1.5175537924174978, 1.519394389383619, 1.521215135194236, 1.5230164764878038, 1.5247988447440173, 1.5265626569677073, 1.5283083163344138, 1.5300362128001919, 1.5317467236780118, 1.5334402141829317, 1.5351170379480557, 1.536777537513144, 1.538422044787603, 1.5400508814894522, 1.541664359561756, 1.5432627815678996, 1.5448464410669835, 1.5464156229705397, 1.547970603881666, 1.5495116524176176], [0.0, 0.9779327685429285, 1.048122389468958, 1.091493425617897, 1.123349762522958, 1.148698354997035, 1.1698336881100935, 1.1880064613519559, 1.2039764646185536, 1.2182411066377867, 1.2311444133449163, 1.242934569729616, 1.2537967024973569, 1.2638727025115426, 1.2732737985986746, 1.2820888539868156, 1.290390024296432, 1.2982367261521606, 1.305678489065226, 1.3127570485010611, 1.3195079107728942, 1.325961542416932, 1.3321442875051683, 1.338079084499914, 1.343786033152179, 1.3492828476735632, 1.3545852225758983, 1.3597071306791426, 1.3646610678808404, 1.3694582557374875, 1.3741088103166372, 1.3786218838601008, 1.3830057843624786, 1.3872680770830843, 1.3914156711798824, 1.3954548940149718, 1.3993915551845928, 1.4032310019377685, 1.406978167340907, 1.4106376123019915, 1.4142135623730951, 1.4177099400931692, 1.4211303935061592, 1.4244783213862235, 1.4277568956173574, 1.4309690811052556, 1.434117653541866, 1.437205215295468, 1.4402342096594207, 1.443206933659511, 1.4461255495919247, 1.4489920954403344, 1.451808494300666, 1.4545765629252065, 1.4572980194832728, 1.459974490623363, 1.4626075179111238, 1.4651985637083849, 1.4677490165506792, 1.470260196073877, 1.4727333575346886, 1.475169695964689, 1.4775703499930477, 1.4799364053692776, 1.4822688982138956, 1.4845688180219063, 1.4868371104414024, 1.4890746798472392, 1.491282391727723, 1.493461074900425, 1.4956115235716423, 1.4977344992526027, 1.4998307325442393, 1.5019009248012478, 1.5039457496851139, 1.5059658546149226, 1.5079618621239321, 1.5099343711291922, 1.5118839581208345, 1.5138111782770665, 1.5157165665103982, 1.5176006384501375, 1.5194638913657768, 1.521306805035495, 1.523129842563661, 1.524933451150901, 1.5267180628199992, 1.5284840951006589, 1.530231951675884, 1.531962022992556, 1.5336746868385576, 1.5353703088886317, 1.5370492432209897, 1.5387118328065363, 1.5403584099724423, 1.541989296841664, 1.543604805749899, 1.5452052396413594, 1.5467908924446405, 1.548362049429883, 1.5499189875483372, 1.5514619757553585], [0.0, 0.9791483623609768, 1.0494252306643652, 1.092850178048433, 1.1247461131420948, 1.1501262145228153, 1.1712878193603735, 1.189483181793968, 1.2054730361565404, 1.2197554094669347, 1.2326747552928772, 1.2444795671239184, 1.2553552017824519, 1.2654437265056175, 1.274856508380008, 1.2836825210928038, 1.2919940099556333, 1.2998504654494183, 1.3073014786517505, 1.3143888369062444, 1.3211480906613249, 1.3276097443238313, 1.3338001747120694, 1.339742348801407, 1.3454563913273254, 1.3509600385206133, 1.3562690044017556, 1.36139727915926, 1.3663573742233703, 1.3711605250992454, 1.3758168604289525, 1.3803355438307583, 1.3847248936262992, 1.3889924844786874, 1.3931452341341353, 1.3971894778198044, 1.4011310323534027, 1.4049752516307108, 1.4087270748500569, 1.4123910685887417, 1.4159714636513008, 1.419472187452495, 1.4228968925708756, 1.4262489820053588, 1.4295316315826674, 1.4327478098939448, 1.4359002960813902, 1.4389916957480895, 1.4420244552244734, 1.4450008743915868, 1.4479231182334018, 1.450793227266853, 1.4536131269783206, 1.4563846363783584, 1.4591094757720084, 1.4617892738297322, 1.4644255740333791, 1.4670198405625297, 1.4695734636787, 1.4720877646580985, 1.4745640003177505, 1.477003367174683, 1.4794070052734092, 1.4817760017130548, 1.484111393902059, 1.4864141725653925, 1.488685284526611, 1.4909256352847295, 1.493136091403877, 1.4953174827318647, 1.4974706044622073, 1.4995962190527088, 1.5016950580124573, 1.5037678235679488, 1.5058151902180466, 1.507837806186593, 1.5098362947806694, 1.5118112556617946, 1.5137632660366909, 1.5156928817736655, 1.5176006384501375, 1.5194870523363546, 1.5213526213199267, 1.5231978257754086, 1.5250231293828191, 1.5268289798986654, 1.5286158098827465, 1.5303840373837647, 1.532134066586512, 1.5338662884232042, 1.535581081151324, 1.537278810900156, 1.53895983218804, 1.5406244884122016, 1.5422731123129017, 1.5439060264135036, 1.5455235434379457, 1.5471259667070068, 1.5487135905146423, 1.550286700485591, 1.5518455739153598, 1.553390480093622], [0.0, 0.9803505238485178, 1.0507136754443949, 1.0941919383436087, 1.126127034065274, 1.1515382961787317, 1.1727258824378277, 1.1909435844522358, 1.2069530705558649, 1.2212529792263789, 1.2341881869386229, 1.2460074922730966, 1.2568964796263205, 1.2669973906602379, 1.2764217291937567, 1.2852585781526005, 1.29358027154847, 1.3014463729024601, 1.3089065341782196, 1.3160025940242899, 1.3227701465365977, 1.3292397335741446, 1.3354377643397004, 1.3413872340066209, 1.347108292018779, 1.35261869638284, 1.3579341804123715, 1.363068751472508, 1.3680349363545556, 1.372843984358204, 1.3775060365610854, 1.3820302678322123, 1.3864250067061423, 1.3906978371458745, 1.3948556853909695, 1.398904894446742, 1.4028512882725694, 1.4067002273375446, 1.410456656904157, 1.4141251491563793, 1.4177099400931694, 1.4212149619512198, 1.4246438717935808, 1.428000076797242, 1.4312867566880871, 1.4345068837019836, 1.437663240393257, 1.4407584355640541, 1.4437949185483188, 1.4467749920508024, 1.4497008237135636, 1.4525744565588063, 1.4553978184369507, 1.4581727305918633, 1.4609009154407118, 1.4635840036535779, 1.4662235406073396, 1.4688209922792423, 1.471377750637713, 1.4738951385811732, 1.4763744144697202, 1.4788167762894207, 1.4812233654844909, 1.4835952704887558, 1.4859335299843457, 1.4882391359126064, 1.4905130362595675, 1.4927561376359821, 1.4949693076699138, 1.4971533772280292, 1.4993091424801523, 1.501437366820204, 1.5035387826553912, 1.5056140930743775, 1.5076639734041508, 1.5096890726644177, 1.511690014927533, 1.513667400591257, 1.5156218075709846, 1.5175537924174978, 1.5194638913657768, 1.5213526213199267, 1.5232204807788452, 1.5250679507068727, 1.526895495353317, 1.5287035630244237, 1.5304925868110726, 1.5322629852752305, 1.534015163097932, 1.5357495116913653, 1.5374664097774224, 1.5391662239349089, 1.540849309117428, 1.5425160091438157, 1.544166657162859, 1.545801576093903, 1.5474210790448368, 1.5490254697088452, 1.5506150427412067, 1.552190084117339, 1.5537508714732025, 1.555297674429094], [0.0, 0.9815395625560397, 1.0519880555770453, 1.0955190519998972, 1.127492880872632, 1.1529349635686519, 1.1741482476364073, 1.1923880453730393, 1.2084169489178813, 1.2227342015327394, 1.235685097983129, 1.2475187386101303, 1.2584209329001932, 1.2685340950360464, 1.277969864076345, 1.286817430992908, 1.2951492175292605, 1.3030248594493639, 1.3104940689382936, 1.3175987353894736, 1.324374496069877, 1.33085192988184, 1.3370574780590883, 1.343014163665156, 1.3487421605825922, 1.3542592483562335, 1.3595811793821266, 1.3647219780145328, 1.3696941862381404, 1.3745090669965878, 1.3791767736673262, 1.3837064922473004, 1.3881065613725065, 1.3923845742043115, 1.3965474653829115, 1.4006015856068683, 1.4045527658992705, 1.4084063732307686, 1.4121673588618173, 1.4158403005218587, 1.4194294393475706, 1.4229387123449415, 1.4263717810125678, 1.4297320566599045, 1.4330227228694328, 1.4362467554819591, 1.439406940426688, 1.4425058896699072, 1.4455460555162862, 1.4485297434634603, 1.4514591237825583, 1.4543362419737065, 1.457163028225559, 1.4599413059909156, 1.4626727997760147, 1.4653591422287298, 1.4680018806002821, 1.470602482645958, 1.4731623420224624, 1.4756827832327224, 1.4781650661630636, 1.4806103902525551, 1.4830198983298377, 1.4853946801488664, 1.4877357756515588, 1.4900441779823574, 1.492320836277077, 1.494566658246072, 1.4967825125697272, 1.4989692311224434, 1.5011276110396956, 1.5032584166413032, 1.5053623812227888, 1.5074402087255716, 1.5094925752957236, 1.5115201307401291, 1.5135234998880622, 1.515503283865488, 1.5174600612887383, 1.519394389383619, 1.521306805035495, 1.5231978257754086, 1.5250679507068727, 1.5269176613775752, 1.528747422599899, 1.5305576832238266, 1.5323488768655213, 1.534121422594612, 1.535875725582959, 1.5376121777174825, 1.539331158179416, 1.5410330339921776, 1.5427181605398832, 1.544386882058377, 1.5460395321005125, 1.5476764339772942, 1.5492979011763706, 1.5509042377592672, 1.5524957387386416, 1.5540726904367625, 1.5556353708263266, 1.557184049854646], [0.0, 0.9827157772761715, 1.053248691300327, 1.096831852506676, 1.1288439967867707, 1.1543165676600577, 1.175555272381177, 1.193816927533861, 1.2098650390994656, 1.2241994486012386, 1.2371658645840293, 1.2490136858949572, 1.2599289446827693, 1.2700542257903127, 1.279501302057405, 1.2883594713366657, 1.296701242157242, 1.304586321746809, 1.3120644818623703, 1.3191776620949405, 1.3259615424169318, 1.3324467383744967, 1.3386597228868564, 1.3446235466069243, 1.3503584075923494, 1.3558821066938467, 1.3612104151841344, 1.3663573742233701, 1.3713355408257608, 1.3761561914317413, 1.3808294915859263, 1.3853646382931764, 1.3897699801819796, 1.394053119512866, 1.3982209992360641, 1.4022799776604098, 1.40623589279652, 1.4100941180464819, 1.4138596106040269, 1.4175369536842568, 1.4211303935061592, 1.4246438717935808, 1.4280810544328246, 1.4314453568212433, 1.434739966356321, 1.4379678624449226, 1.441131834354734, 1.4442344971820569, 1.4472783061702474, 1.4502655695797033, 1.4531984602822676, 1.456079026229265, 1.458909199922365, 1.4616908069994774, 1.464425574033379, 1.4671151356284056, 1.4697610408899058, 1.4723647593320308, 1.4749276862815552, 1.4774511478286063, 1.4799364053692776, 1.4823846597799697, 1.484797055258817, 1.4871746828656665, 1.4895185837886358, 1.4918297523622892, 1.494109138859825, 1.4963576520793407, 1.498576161742192, 1.5007655007196459, 1.5029264671024132, 1.505059826126226, 1.5071663119653418, 1.5092466294047382, 1.5113014554007382, 1.5133314405389133, 1.5153372103972929, 1.5173193668221938, 1.5192784891233249, 1.521215135194236, 1.523129842563661, 1.5250231293828191, 1.526895495353317, 1.528747422599899, 1.5305793764919489, 1.5323918064173232, 1.5341851465118035, 1.5359598163472044, 1.5377162215809188, 1.5394547545694797, 1.5411757949485068, 1.5428797101812357, 1.5445668560776527, 1.5462375772861119, 1.5478922077591752, 1.5495310711952832, 1.5511544814577476, 1.552762742972462, 1.554356151105608, 1.5559349925225656, 1.557499545529136, 1.559050080396119], [0.0, 0.9838794565405263, 1.0544958918547664, 1.0981306619007651, 1.1301807132434794, 1.1556834473676476, 1.1769473018226546, 1.1952305814469564, 1.2112976963247015, 1.2256490798646344, 1.2386308499811036, 1.2504927008459537, 1.2614208848972144, 1.2715581558190487, 1.2810164188066713, 1.2898850774544237, 1.2982367261521606, 1.306131142829651, 1.313618158180941, 1.320739761459657, 1.3275316748885193, 1.334024550266966, 1.3402448918620287, 1.3462157776219659, 1.3519574295218821, 1.3574876694913045, 1.3628222874784452, 1.3679753412702504, 1.3729594027502685, 1.3777857617118903, 1.3824645957372221, 1.3870051127217244, 1.3914156711798826, 1.3957038823744154, 1.3998766974770207, 1.403940482325702, 1.407901081844135, 1.4117638757973014, 1.4155338272489748, 1.4192155248414549, 1.422813219821873, 1.4263308585816543, 1.4297721113480475, 1.4331403975627353, 1.4364389083975464, 1.4396706267874, 1.4428383453028828, 1.445944682136953, 1.4489920954403344, 1.4519828962067423, 1.4549192598810186, 1.4578032368395613, 1.4606367618724048, 1.4634216627792818, 1.4661596681774833, 1.4688524146069564, 1.4715014530074162, 1.4741082546331346, 1.4766742164631566, 1.4792006661578945, 1.4816888666071195, 1.4841400201092452, 1.4865552722173043, 1.488935715283118, 1.4912823917277231, 1.4935962970631218, 1.4958783826877744, 1.4981295584759287, 1.5003506951788175, 1.5025426266539492, 1.5047061519370912, 1.5068420371701263, 1.5089510173966818, 1.511033798236304, 1.5130910574469307, 1.5151234463845225, 1.5171315913678847, 1.5191160949560079, 1.5210775371445886, 1.5230164764878038, 1.524933451150901, 1.5268289798986654, 1.5287035630244237, 1.5305576832238266, 1.5323918064173232, 1.5342063825249113, 1.5360018461964522, 1.5377786175005954, 1.5395371025750915, 1.5412776942410806, 1.5430007725837271, 1.5447067055013965, 1.5463958492254062, 1.5480685488122243, 1.5497251386098618, 1.551365942700065, 1.5529912753178061, 1.5546014412494633, 1.5561967362109754, 1.5577774472071757, 1.5593438528734203, 1.560896223800549], [0.0, 0.9850308790880501, 1.0557299559853681, 1.0994157912891616, 1.1315033504297265, 1.1570359301034676, 1.1783246693970635, 1.1966293457283115, 1.2127152637614846, 1.2270834425566557, 1.240080405085894, 1.2519561377351947, 1.2628971109116236, 1.2730462453623002, 1.2825155772437713, 1.2913946147783533, 1.2997560373122603, 1.3076596927326696, 1.3151554700499015, 1.3222854076571118, 1.3290852695823177, 1.3355857434963974, 1.341813364684014, 1.3477912381012773, 1.3535396093888319, 1.3590763213329982, 1.3644171823607798, 1.369576266710785, 1.3745661609792896, 1.379398168171997, 1.384082477781718, 1.3886283084798043, 1.393044028562613, 1.3973372582002337, 1.4015149566992384, 1.4055834973474965, 1.409548731908929, 1.4134160464443928, 1.417190409825877, 1.420876416065715, 1.4244783213862233, 1.4280000767972418, 1.4314453568212433, 1.4348175849016425, 1.4381199559448596, 1.4413554563767068, 1.4445268820358834, 1.4476368541793885, 1.45068783383469, 1.4536821347000326, 1.4566219347661553, 1.4595092868089874, 1.4623461278828258, 1.4651342879264553, 1.4678754975801476, 1.4705713952990727, 1.4732235338379929, 1.475833386172971, 1.478402350917921, 1.4809317572869998, 1.483422869647924, 1.4858768917061427, 1.4882949703553157, 1.490678199225631, 1.4930276219580585, 1.4953442352296358, 1.4976289915522345, 1.4998828018649166, 1.502106537937946, 1.5043010346046835, 1.5064670918359993, 1.5086054766703827, 1.510716925011674, 1.5128021433051981, 1.5148618101020648, 1.5168965775205085, 1.5189070726123084, 1.520893898641623, 1.52285763628291, 1.5247988447440173, 1.5267180628199992, 1.5286158098827465, 1.5304925868110726, 1.5323488768655213, 1.5341851465118035, 1.5360018461964522, 1.537799411077995, 1.5395782617166827, 1.5413388047255634, 1.5430814333854923, 1.5448065282264423, 1.546514457577326, 1.5482055780863542, 1.5498802352138108, 1.5515387636989901, 1.5531814880029073, 1.5548087227282805, 1.5564207730181756, 1.5580179349346042, 1.559600495818278, 1.5611687346306369, 1.5627229222791899], [0.0, 0.9861703143068244, 1.0569511724151297, 1.100687541342146, 1.1328122177911581, 1.1583743322958617, 1.1796876973548314, 1.1980135476343512, 1.214118073065447, 1.2285028722623705, 1.2415148690379023, 1.2534043389499798, 1.2643579681054542, 1.2745188425751277, 1.2839991281134568, 1.292888436481462, 1.3012595310972463, 1.309172329077076, 1.3166767771404222, 1.3238149623083841, 1.330622689979045, 1.3371306833212702, 1.3433655083144336, 1.3493502966413202, 1.3551053173617347, 1.3606484339016547, 1.3659954729744934, 1.3711605250992454, 1.3761561914317413, 1.3809937880524448, 1.3856835162408707, 1.3902346053320753, 1.3946554333024492, 1.3989536291367193, 1.4031361601916412, 1.4072094071273895, 1.4111792284769176, 1.4150510165314123, 1.4188297459106094, 1.4225200159409699, 1.4261260877681978, 1.4296519169724673, 1.4331011823267574, 1.4364773112345544, 1.439783502297988, 1.4430227453974214, 1.446197839605642, 1.44931140921179, 1.452365918090129, 1.4553636826152754, 1.4583068832973611, 1.4611975752868656, 1.4640376978787744, 1.4668290831286552, 1.4695734636787, 1.4722724798793623, 1.4749276862815552, 1.4775405575652074, 1.4801124939620804, 1.4826448262239011, 1.485138820180944, 1.4875956809310453, 1.4900165566945354, 1.4924025423666596, 1.4947546827956202, 1.4970739758113618, 1.499361375027575, 1.501617792437051, 1.5038441008184742, 1.5060411359709007, 1.5082096987905667, 1.510350557203234, 1.5124644479640008, 1.514552078335372, 1.5166141276533731, 1.5186512487905761, 1.520664069524103, 1.5226531938159382, 1.524619203012236, 1.5265626569677073, 1.5284840951006589, 1.5303840373837647, 1.5322629852752305, 1.534121422594612, 1.5359598163472044, 1.5377786175005954, 1.5395782617166827, 1.5413591700421998, 1.5431217495605456, 1.5448663940075025, 1.546593484353222, 1.5483033893526819, 1.5499964660666454, 1.5516730603550082, 1.5533335073442744, 1.55497813187078, 1.5566072489011598, 1.5582211639314543, 1.5598201733661448, 1.5614045648783246, 1.5629746177521229, 1.5645306032084205], [0.0, 0.9872980226511102, 1.058159820292016, 1.1019462027587548, 1.1341076145111557, 1.1596989598793381, 1.1810366972594708, 1.1993835035685696, 1.215506444893397, 1.2299076934377098, 1.242934569729616, 1.254837635522886, 1.2658037904042108, 1.2759762840665922, 1.2854674105285961, 1.2943668840243445, 1.302747551178576, 1.3106693976241515, 1.31818242719576, 1.3253287750419733, 1.3321442875051681, 1.3386597228868566, 1.3449016775452187, 1.3508933096146487, 1.3566549113330852, 1.3622043665537429, 1.3675575200882444, 1.372728478568415, 1.3777298575597963, 1.382572986083049, 1.387268077083084, 1.391824370448915, 1.3962502537373394, 1.4005533646570034, 1.4047406785319945, 1.4088185833189182, 1.4127929442500948, 1.4166691597829197, 1.42045221022572, 1.424146700164392, 1.4277568956173574, 1.431286756688087, 1.434739966356321, 1.4381199559448596, 1.4414299277135083, 1.444672874961626, 1.4478515999628045, 1.4509687300071188, 1.4540267317863287, 1.4570279243238786, 1.459974490623363, 1.4628684881853735, 1.465711858522524, 1.4685064357853796, 1.4712539545974477, 1.473956057184961, 1.4766142998764968, 1.4792301590383141, 1.4818050365033715, 1.4843402645451407, 1.4868371104414024, 1.4892967806680502, 1.49172042475843, 1.4941091388598253, 1.496463969015246, 1.4987859141956785, 1.501075929105292, 1.5033349267797629, 1.5055637809958176, 1.5077633285082674, 1.5099343711291924, 1.5120776776624947, 1.5141939857057682, 1.51628400333029, 1.5183484106489207, 1.520387861280808, 1.5224029837209505, 1.524394382621978, 1.5263626399948262, 1.5283083163344138, 1.530231951675884, 1.532134066586512, 1.534015163097932, 1.535875725582959, 1.5377162215809188, 1.5395371025750915, 1.5413388047255634, 1.5431217495605456, 1.5448863446289454, 1.5466329841167914, 1.5483620494298833, 1.5500739097448781, 1.5517689225308469, 1.5534474340431836, 1.5551097797916174, 1.556756284983942, 1.5583872649469634, 1.5600030255260644, 1.5616038634646716, 1.5631900667648388, 1.564761915030063, 1.5663196797913723], [0.0, 0.9884142560352877, 1.0593561696111744, 1.1031920567064655, 1.1353898299633531, 1.1610101087573002, 1.1823719704588234, 1.2007395195600936, 1.2168806893883162, 1.2312982199002114, 1.24433982430245, 1.2562563476324593, 1.2672349007845127, 1.2774188954088792, 1.2869207524830866, 1.2958302876716465, 1.3042204299592668, 1.312151232798215, 1.3196727565572237, 1.3268271840226178, 1.3336504020644393, 1.3401732037593572, 1.3464222155352383, 1.3524206217089287, 1.3581887374606532, 1.3637444668630059, 1.3691036726416612, 1.3742804773773205, 1.3792875108986098, 1.3841361150347142, 1.3888365142772414, 1.3933979589617687, 1.3978288461280168, 1.4021368221197807, 1.4063288701474086, 1.4104113853896927, 1.4143902397101502, 1.4182708376696413, 1.4220581652072009, 1.4257568321146423, 1.429371109233524, 1.4329049611445857, 1.4363620749915234, 1.4397458859765708, 1.4430595999799896, 1.4463062136853457, 1.4494885325344649, 1.4526091867878206, 1.4556706459260007, 1.4586752315943234, 1.4616251292644749, 1.4645223987632445, 1.4673689837983088, 1.4701667205939133, 1.4729173457347207, 1.4756225033036543, 1.478283751388868, 1.480902568025792, 1.4834803566322885, 1.4860184509880903, 1.488518119803755, 1.4909805709192103, 1.4934069551674585, 1.49579836993508, 1.4981558624477358, 1.5004804328058423, 1.5027730367929517, 1.5050345884770135, 1.5072659626226412, 1.5094679969306757, 1.5116414941197212, 1.5137872238628853, 1.5159059245916855, 1.5179983051779395, 1.5200650465034402, 1.522106802926313, 1.5241242036521296, 1.5261178540171358, 1.5280883366902867, 1.5300362128001919, 1.531962022992556, 1.5338662884232042, 1.5357495116913653, 1.5376121777174825, 1.5394547545694797, 1.5412776942410806, 1.5430814333854923, 1.5448663940075025, 1.5466329841167914, 1.548381598345052, 1.5501126185292988, 1.5518264142635783, 1.5535233434211135, 1.5552037526487732, 1.5568679778356114, 1.5585163445571, 1.560149168496552, 1.561766755845137, 1.5633694036817776, 1.5649574003341415, 1.5665310257218437, 1.5680905516829036], [0.0, 0.9895192582062144, 1.0605404816140187, 1.1044253752367947, 1.1366591441393648, 1.1623080652394242, 1.1836938085304844, 1.2020818917160292, 1.2182411066377867, 1.2326747552928774, 1.2457309396155174, 1.2576607850764747, 1.2686516117514892, 1.2788469916185308, 1.2883594713366657, 1.2972789669802327, 1.305678489065226, 1.313618158180941, 1.3211480906613249, 1.3283105164511388, 1.335141362540313, 1.3416714564307746, 1.3479274543175261, 1.3539325664364248, 1.3597071306791426, 1.3652690711342126, 1.3706342682611146, 1.3758168604289527, 1.3808294915859267, 1.385683516240871, 1.3903891703159093, 1.3949557144880738, 1.399391555184593, 1.403704347297527, 1.407901081844135, 1.4119881611527285, 1.4159714636513008, 1.419856399942765, 1.4236479615402091, 1.4273507633889846, 1.4309690811052558, 1.4345068837019834, 1.4379678624449228, 1.441355456376707, 1.444672874961626, 1.447923118233402, 1.4511089947702167, 1.4542331377730555, 1.4572980194832728, 1.460305964141681, 1.4632591596632238, 1.4661596681774836, 1.4690094355651133, 1.471810300103174, 1.4745640003177505, 1.4772721821297767, 1.4799364053692778, 1.4825581497240603, 1.485138820180944, 1.4876797520107665, 1.490182215342446, 1.4926474193662207, 1.4950765162016715, 1.4974706044622075, 1.4998307325442395, 1.5021579016662514, 1.504453068680318, 1.5067171486762745, 1.5089510173966818, 1.5111555134788925, 1.5133314405389133, 1.5154795691103116, 1.5176006384501375, 1.5196953582226955, 1.5217644100709729, 1.523808449084638, 1.5258281051726854, 1.5278239843480999, 1.5297966699312333, 1.5317467236780118, 1.5336746868385576, 1.535581081151324, 1.5374664097774224, 1.539331158179416, 1.5411757949485068, 1.5430007725837271, 1.5448065282264423, 1.546593484353222, 1.5483620494298833, 1.5501126185292988, 1.5518455739153598, 1.553561285595302, 1.5552601118424347, 1.5569423996911615, 1.5586084854060458, 1.5602586949265378, 1.5618933442888696, 1.563512740026519, 1.5651171795505294, 1.5667069515109058, 1.5682823361402, 1.569843605580335], [0.0, 0.9906132650954107, 1.0617130091656912, 1.1056464216783795, 1.1379158280533401, 1.1635931064553429, 1.1850024937030992, 1.2034109066493002, 1.2195879871075817, 1.2340375935229018, 1.2471082126890045, 1.2590512477195563, 1.2700542257903127, 1.280260877611609, 1.2897838742734602, 1.2987132312609082, 1.3071220398099606, 1.3150704869788954, 1.322608744509995, 1.3297790890372083, 1.3366174872711423, 1.3431548007964358, 1.3494177152790292, 1.3554294666158855, 1.3612104151841344, 1.3667785048890797, 1.3721496337475474, 1.3773379557599423, 1.3823561288535418, 1.3872155200906608, 1.3919263767102013, 1.3964979696277464, 1.4009387145646242, 1.405256274876099, 1.40945764930866, 1.4135492472689957, 1.4175369536842568, 1.4214261851392884, 1.4252219386657667, 1.428928834311301, 1.432551152419152, 1.4360928663903996, 1.439557671571841, 1.4429490108082956, 1.446270097112419, 1.4495239338347532, 1.4527133326586286, 1.4558409296962824, 1.4589091999223651, 1.4619204701473565, 1.4648769307051468, 1.4677806460051972, 1.4706335640795152, 1.4734375252375507, 1.4761942699274928, 1.4789054458899968, 1.4815726146796266, 1.4841972576201232, 1.4867807812516523, 1.4893245223213192, 1.4918297523622892, 1.4942976819016747, 1.496729464332833, 1.4991261994837943, 1.5014889369100708, 1.5038186789370875, 1.5061163834748095, 1.5083829666247903, 1.5106193050978067, 1.5128262384584041, 1.5150045712110622, 1.5171550747412463, 1.5192784891233249, 1.521375524806203, 1.523446864186489, 1.5254931630781141, 1.5275150520864973, 1.5295131378946272, 1.5314880044677721, 1.5334402141829317, 1.5353703088886317, 1.537278810900156, 1.5391662239349089, 1.5410330339921776, 1.5428797101812357, 1.5447067055013965, 1.546514457577326, 1.5483033893526819, 1.5500739097448781, 1.5518264142635783, 1.553561285595302, 1.5552788941563633, 1.556979598616176, 1.5586637463928232, 1.5603316741226405, 1.5619837081054346, 1.5636201647268462, 1.5652413508592542, 1.566847564242518, 1.5684390938457724, 1.570016220211393, 1.5715792157821808], [0.0, 0.9916965051523725, 1.0628739971122991, 1.1068554510089963, 1.139160144124839, 1.1648655007461621, 1.1862982992550823, 1.204726841883563, 1.2209216120520214, 1.2353870191768899, 1.248471931123787, 1.260428025916814, 1.2714430357935353, 1.2816608486344643, 1.2911942587359597, 1.3001333800153998, 1.3085513836343878, 1.31650852246602, 1.3240550231156052, 1.3312332084467808, 1.3380790844999138, 1.3446235466069243, 1.3508933096146485, 1.356911634828607, 1.3626989048900935, 1.3682730833261527, 1.3736500855381637, 1.3788440810039944, 1.383867741492422, 1.388732446495696, 1.3934484544581194, 1.3980250464330635, 1.4024706473444852, 1.406792928927563, 1.4109988975819456, 1.4150949697230377, 1.4190870367131838, 1.4229805210602886, 1.4267804252603056, 1.430491374412886, 1.4341176535418658, 1.4376632403932565, 1.441131834354734, 1.4445268820358836, 1.4478515999628045, 1.4511089947702167, 1.4543018812160382, 1.4574328982951075, 1.4605045236884704, 1.4635190867509849, 1.4664787802116808, 1.4693856707374602, 1.472241708490513, 1.475048735792675, 1.4778084949953239, 1.4805226356409262, 1.4831927209916131, 1.4858202339909596, 1.4884065827171895, 1.490953105379147, 1.4934610749004247, 1.4959317031318518, 1.4983661447280265, 1.5007655007196459, 1.5031308218099155, 1.505463111420308, 1.5077633285082672, 1.5100323901771082, 1.5122711740962944, 1.514480520748439, 1.5166612355177511, 1.5188140906332093, 1.5209398269784566, 1.5230391557792777, 1.525112760178484, 1.5271612967071426, 1.5291853966602424, 1.5311856673841826, 1.5331626934827998, 1.5351170379480557, 1.5370492432209897, 1.53895983218804, 1.540849309117428, 1.5427181605398832, 1.5445668560776527, 1.5463958492254062, 1.5482055780863542, 1.5499964660666454, 1.5517689225308469, 1.5535233434211135, 1.5552601118424347, 1.556979598616176, 1.5586821628039582, 1.5603681522037673, 1.5620379038200523, 1.5636917443094305, 1.5653299904035114, 1.5669529493102403, 1.5685609190950567, 1.5701541890430843, 1.5717330400034728, 1.5732977447169412], [0.0, 0.9927691996602168, 1.064023682619215, 1.1080527102078601, 1.140392346541414, 1.1661255080352224, 1.1875814898922024, 1.206029966236656, 1.22224225390258, 1.2367233079140671, 1.2498223734988043, 1.261791400915021, 1.2728183254657754, 1.2830471906716767, 1.2925909128359894, 1.3015397033501719, 1.309966812523331, 1.3179325584026624, 1.3254872219223979, 1.33267317172581, 1.3395264528001418, 1.346077993896059, 1.3523545387572122, 1.3583793738503223, 1.3641729038641006, 1.3697531117563122, 1.3751359301436463, 1.3803355438307583, 1.3853646382931764, 1.3902346053320753, 1.3949557144880733, 1.3995372568536368, 1.4039876664657618, 1.4083146233579602, 1.412525141508537, 1.41662564427338, 1.4206220293873804, 1.424519725223841, 1.4283237396897956, 1.432038702887756, 1.4356689044765665, 1.4392183265048715, 1.4426906723618864, 1.4460893923853129, 1.449417706580489, 1.4526786248343402, 1.4558749649494416, 1.4590093687751688, 1.462084316672617, 1.4651021405162514, 1.468065035406925, 1.470975070247004, 1.4738341973081222, 1.4766442609049113, 1.479407005273409, 1.4821240817403527, 1.484797055258817, 1.4874274103764418, 1.4900165566945354, 1.4925658338694505, 1.4950765162016713, 1.4975498168528567, 1.4999868917265677, 1.50238884304446, 1.50475672264626, 1.507091535038817, 1.5093942402168563, 1.511665756275702, 1.513906961834172, 1.5161186982840091, 1.5183017718805876, 1.5204569556881875, 1.5225849913918483, 1.5246865909866703, 1.5267624383544047, 1.5288131907362725, 1.5308394801101193, 1.5328419144792962, 1.534821079079992, 1.536777537513144, 1.5387118328065363, 1.5406244884122016, 1.5425160091438157, 1.544386882058377, 1.5462375772861119, 1.5480685488122243, 1.5498802352138108, 1.5516730603550082, 1.5534474340431836, 1.5552037526487732, 1.5569423996911615, 1.5586637463928232, 1.5603681522037673, 1.5620559652981847, 1.563727523045054, 1.5653831524543291, 1.567023170600221, 1.5686478850229737, 1.5702575941104375, 1.571852587460649, 1.5734331462265458, 1.5749995434438637], [0.0, 0.9938315630347765, 1.0651622954916387, 1.1092384385894511, 1.1416126816021799, 1.167373380179423, 1.1888523221053675, 1.2073205401839437, 1.2235501766361112, 1.2380467268388704, 1.2511598097475969, 1.2631416452327588, 1.2741803697071823, 1.2844201808326001, 1.2939741157441331, 1.3029324823685455, 1.3113686094001777, 1.3193428794326318, 1.3269056272058204, 1.3340992667017462, 1.3409598814794317, 1.3475184333864314, 1.353801694784904, 1.3598329770604438, 1.3656327067368408, 1.3712188860154422, 1.3766074645624475, 1.3818126423616863, 1.386847118463428, 1.3917222968592255, 1.3964484580791439, 1.4010349031580567, 1.4054900751582327, 1.4098216623315951, 1.414036686162115, 1.41814157687932, 1.422142238529274, 1.4260441052941872, 1.4298521904400605, 1.4335711290240831, 1.437205215295468, 1.440758435564054, 1.4442344971820569, 1.4476368541793887, 1.4509687300071188, 1.4542331377730555, 1.4574328982951075, 1.4605706562496963, 1.4636488946521542, 1.4666699478722875, 1.469636013359929, 1.47254916223138, 1.4754113488474019, 1.4782244194962293, 1.480990120280409, 1.4837101042937648, 1.486385938164029, 1.4890191080274577, 1.491611024993775, 1.4941630301529016, 1.4966763991689516, 1.4991523465017897, 1.5015920292919105, 1.5039965509404583, 1.5063669644127338, 1.5087042752905109, 1.5110094445958062, 1.5132833914063981, 1.5155269952813157, 1.5177410985126758, 1.5199265082186277, 1.5220839982907082, 1.524214311207635, 1.5263181597264146, 1.5283962284606212, 1.53044917535479, 1.532477633063047, 1.5344822102393683, 1.5364634927462046, 1.538422044787603, 1.5403584099724423, 1.5422731123129017, 1.544166657162859, 1.5460395321005125, 1.5478922077591752, 1.5497251386098618, 1.5515387636989901, 1.5533335073442744, 1.5551097797916174, 1.5568679778356114, 1.5586084854060458, 1.5603316741226405, 1.5620379038200523, 1.563727523045054, 1.565400869527643, 1.5670582706277065, 1.5687000437587573, 1.570326496790139, 1.5719379284290063, 1.5735346285832952, 1.5751168787068055, 1.5766849521274484], [0.0, 0.9948838031081764, 1.066290058478526, 1.1104128681200198, 1.1428213880435563, 1.168609361302315, 1.19011104450985, 1.2085988162028105, 1.224845636123975, 1.2393575348542079, 1.252484501515308, 1.2644790230208376, 1.2755294349770063, 1.2857800877178558, 1.2953441380589512, 1.3043119895424735, 1.3127570485010611, 1.3207397614596572, 1.328310516451139, 1.3355117723642052, 1.3423796509621049, 1.3489451468739004, 1.3552350608075523, 1.3612727288300739, 1.3670785990922678, 1.37267069285569, 1.378064976673585, 1.383275665564314, 1.3883154720235324, 1.3931958121170098, 1.3979269772595382, 1.4025182783336578, 1.4069781673409072, 1.4113143406733077, 1.4155338272489746, 1.4196430641055762, 1.423647961540209, 1.4275539594886386, 1.431366076524766, 1.4350889526132453, 1.4387268865499159, 1.442283868865206, 1.4457636108365688, 1.4491695701509428, 1.4525049736722941, 1.4557728376986225, 1.4589759860344367, 1.4621170661562652, 1.4651985637083849, 1.4682228155321653, 1.4711920214040355, 1.4741082546331343, 1.4769734716494443, 1.4797895206959966, 1.48255814972406, 1.485281013577707, 1.4879596805433697, 1.4905956383307821, 1.4931902995437105, 1.4957450066919828, 1.4982610367903493, 1.5007396055845095, 1.503181871440105, 1.5055889389265291, 1.5079618621239321, 1.5103016476787683, 1.5126092576305565, 1.5148856120301686, 1.5171315913678847, 1.5193480388276164, 1.5215357623820662, 1.5236955367421452, 1.5258281051726854, 1.5279341811853404, 1.530014450118533, 1.5320695706134115, 1.5341001759939372, 1.5361068755585119, 1.5380902557898803, 1.5400508814894522, 1.541989296841664, 1.5439060264135036, 1.545801576093903, 1.5476764339772942, 1.5495310711952832, 1.551365942700065, 1.5531814880029073, 1.55497813187078, 1.556756284983942, 1.5585163445571, 1.5602586949265378, 1.5619837081054346, 1.5636917443094305, 1.5653831524543291, 1.5670582706277065, 1.5687174265360497, 1.5703609379289392, 1.5719891130016814, 1.5736022507776941, 1.5752006414718591, 1.5767845668359717, 1.5783543004873344], [0.0, 0.9959261213978506, 1.067407187560915, 1.1115762237178446, 1.1440186973482884, 1.1698336881100935, 1.1913578981670916, 1.2098650390994656, 1.2261288804632346, 1.2406559829965822, 1.2537967024973569, 1.2658037904042108, 1.2768657796385043, 1.2871271717670085, 1.296701242157242, 1.3056784890652262, 1.3141323957298296, 1.3221234720045154, 1.3297021587126154, 1.3369109592260895, 1.3437860331521787, 1.3503584075923496, 1.3566549113330855, 1.3626989048900937, 1.3685108578372633, 1.374108810316637, 1.3795087456092727, 1.3847248936262992, 1.3897699801819798, 1.3946554333024492, 1.3993915551845928, 1.4039876664657618, 1.408452228002474, 1.412792944250095, 1.4170168514907853, 1.421130393506159, 1.4251394867854035, 1.4290495769635871, 1.432865687872463, 1.436592464337876, 1.4402342096594207, 1.4437949185483185, 1.4472783061702474, 1.4506878338346902, 1.4540267317863287, 1.4572980194832728, 1.4605045236884704, 1.4636488946521542, 1.4667336206227566, 1.4697610408899058, 1.4727333575346886, 1.4756526460384058, 1.4785208648807486, 1.481339864241113, 1.484111393902059, 1.4868371104414024, 1.489518583788636, 1.492157303212135, 1.4947546827956202, 1.4973120664554378, 1.4998307325442393, 1.5023118980814347, 1.50475672264626, 1.507166311965342, 1.509541721223168, 1.5118839581208345, 1.5141939857057682, 1.516472724992758, 1.5187210573945553, 1.5209398269784569, 1.523129842563661, 1.5252918796727262, 1.5274266823491875, 1.5295349648522294, 1.5316174132382885, 1.5336746868385573, 1.5357074196405174, 1.5377162215809188, 1.5397016797569516, 1.541664359561756, 1.543604805749899, 1.5455235434379457, 1.5474210790448368, 1.5492979011763706, 1.5511544814577476, 1.5529912753178061, 1.5548087227282805, 1.5566072489011598, 1.5583872649469634, 1.560149168496552, 1.5618933442888696, 1.5636201647268462, 1.5653299904035114, 1.567023170600221, 1.5687000437587573, 1.5703609379289392, 1.5720061711932456, 1.5736360520698736, 1.5752508798955207, 1.5768509451891208, 1.578436529997654, 1.5800079082250866], [0.0, 0.9969587133618939, 1.0685138922256048, 1.1127287235382346, 1.145204834038768, 1.171046590191539, 1.1925931168901633, 1.2111194463191473, 1.2274001502910314, 1.2419423147541893, 1.2550966587609054, 1.2671161958065236, 1.2781896542863207, 1.2884616855885789, 1.2980456825265105, 1.3070322371861616, 1.3154949089949852, 1.323494270544018, 1.3310808149544362, 1.3382970896663682, 1.345179291777908, 1.3517584805599117, 1.3580615126153734, 1.364111772680553, 1.3699297515525173, 1.375533508077614, 1.3809390421086196, 1.3861605983104601, 1.3912109156917245, 1.3961014341273057, 1.4008424664955699, 1.4054433430976525, 1.4099125335624214, 1.4142577503333436, 1.4184860369879078, 1.4226038439887434, 1.426617093959347, 1.430531238180908, 1.4343513056939676, 1.4380819461401992, 1.441727467280927, 1.445291867969152, 1.448778867222495, 1.452191929939179, 1.4555342897130545, 1.4588089691328536, 1.4620187978923571, 1.4651664289896182, 1.4682543532529253, 1.4712849123973188, 1.4742603107870387, 1.4771826260552767, 1.4800538187123073, 1.4828757408558215, 1.4856501440825816, 1.4883786866879698, 1.4910629402292064, 1.4937043955187639, 1.496304468106507, 1.498864503302176, 1.5013857807838382, 1.5038695188327291, 1.5063168782303547, 1.5087289658497764, 1.511106837969514, 1.5134515033354639, 1.5157639259935558, 1.5180450279135014, 1.5202956914219143, 1.5225167614612347, 1.5247090476892562, 1.5268733264326122, 1.5290103425062738, 1.5311208109099799, 1.5332054184114823, 1.535264825025578, 1.5372996653970767, 1.539310550095121, 1.5412980668256122, 1.5432627815678996, 1.5452052396413594, 1.5471259667070068, 1.5490254697088452, 1.5509042377592672, 1.552762742972462, 1.5546014412494633, 1.5564207730181756, 1.5582211639314543, 1.5600030255260644, 1.561766755845137, 1.563512740026519, 1.5652413508592542, 1.5669529493102403, 1.5686478850229737, 1.570326496790139, 1.5719891130016814, 1.5736360520698736, 1.5752676228327886, 1.5768841249374814, 1.5784858492041003, 1.5800730779720562, 1.5816460854293035], [0.0, 0.9979817686415696, 1.069610375725069, 1.1138705792441983, 1.1463800159556026, 1.1722482903028724, 1.193816927533861, 1.2123622682407258, 1.2286596790831472, 1.2432167663690183, 1.2563846090501594, 1.268416480258335, 1.2795013020574053, 1.2897838742734604, 1.2993777060807168, 1.30837348252866, 1.3168448385296754, 1.3248524088329496, 1.3324467383744967, 1.339670418255614, 1.3465596827189963, 1.3531456229077827, 1.3594551229845735, 1.365511591682488, 1.3713355408257606, 1.376945047792297, 1.3823561288535418, 1.3875830432919558, 1.392638543188596, 1.3975340801576817, 1.40227997766041, 1.4068855755724483, 1.4113593522139962, 1.4157090279428464, 1.4199416535644391, 1.4240636861607145, 1.4280810544328246, 1.4319992152559335, 1.4358232028312639, 1.439557671571841, 1.443206933659511, 1.4467749920508024, 1.4502655695797035, 1.453682134700033, 1.4570279243238786, 1.4603059641416811, 1.463519086750985, 1.4666699478722878, 1.4697610408899058, 1.472794709921892, 1.4757731615945522, 1.4786984756730959, 1.4815726146796266, 1.4843974326124139, 1.4871746828656667, 1.4899060254364707, 1.4925930334947404, 1.4952371993827847, 1.497839940103072, 1.5004026023458674, 1.5029264671024134, 1.5054127539041164, 1.5078626247236488, 1.510277187569919, 1.5126574998053743, 1.5150045712110625, 1.517319366822194, 1.519602809554584, 1.5218557826402686, 1.5240791318887472, 1.5262736677886661, 1.528440167463306, 1.5305793764919489, 1.5326920106080504, 1.5347787572841063, 1.536840277212205, 1.5388772056884141, 1.5408901539084272, 1.542879710181236, 1.5448464410669835, 1.5467908924446405, 1.5487135905146423, 1.5506150427412067, 1.5524957387386416, 1.554356151105608, 1.5561967362109754, 1.5580179349346042, 1.5598201733661448, 1.5616038634646716, 1.5633694036817776, 1.5651171795505294, 1.566847564242518, 1.5685609190950567, 1.5702575941104375, 1.5719379284290063, 1.5736022507776941, 1.5752508798955207, 1.5768841249374814, 1.5785022858581217, 1.580105653776023, 1.5816945113203258, 1.5832691329603497], [0.0, 0.9989954712917499, 1.070696835324435, 1.1150019962636442, 1.1475444545223208, 1.1734390046384329, 1.1950295502703652, 1.2135937284566445, 1.2299076934377098, 1.2444795671239184, 1.2576607850764745, 1.269704877690004, 1.2808009589264584, 1.2910939756927384, 1.3006975524603077, 1.3097024663922332, 1.3181824271957598, 1.3261981312099824, 1.3338001747120691, 1.3410311920653426, 1.347927454317526, 1.3545200841926703, 1.3608359931610363, 1.3668986137332262, 1.3727284785684148, 1.378343683406653, 1.3837602607879549, 1.3889924844786872, 1.394053119512866, 1.3989536291367193, 1.4037043472975268, 1.4083146233579602, 1.4127929442500948, 1.417147038173698, 1.421383963096084, 1.425510182657992, 1.4295316315826672, 1.4334537722881096, 1.4372816440890452, 1.4410199061262319, 1.444672874961626, 1.4482445576177696, 1.4517386807101296, 1.4551587162156163, 1.4585079043342193, 1.4617892738297324, 1.4650056601769188, 1.4681597217938311, 1.4712539545974477, 1.4742907050868654, 1.4772721821297767, 1.4802004676039182, 1.4830775260248306, 1.4859052132739867, 1.488685284526611, 1.491419401465935, 1.494109138859825, 1.496755990566441, 1.499361375027575, 1.5019266403013962, 1.5044530686803177, 1.506941880934488, 1.5093942402168565, 1.5118112556617946, 1.5141939857057682, 1.516543441155513, 1.5188605880264765, 1.5211463501719278, 1.523401611721049, 1.5256272193424723, 1.5278239843480996, 1.5299926846505774, 1.5321340665865117, 1.534248846616366, 1.5363377129109381, 1.5384013268334165, 1.5404403243251723, 1.5424553172027227, 1.5444468943726357, 1.5464156229705397, 1.548362049429883, 1.550286700485591, 1.552190084117339, 1.5540726904367625, 1.5559349925225656, 1.5577774472071757, 1.559600495818278, 1.5614045648783246, 1.5631900667648388, 1.5649574003341415, 1.5667069515109058, 1.5684390938457724, 1.5701541890430843, 1.571852587460649, 1.5735346285832952, 1.5752006414718591, 1.5768509451891208, 1.5784858492041003, 1.580105653776023, 1.5817106503191742, 1.5833011217497763, 1.5848773428159417], [0.0, 1.0, 1.0717734625362931, 1.1161231740339044, 1.148698354997035, 1.1746189430880192, 1.1962311988513157, 1.2148140440390671, 1.2311444133449163, 1.2457309396155174, 1.2589254117941673, 1.2709816152101407, 1.2820888539868156, 1.2923922207808318, 1.3020054543174677, 1.31101942303975, 1.3195079107728942, 1.3275316748885193, 1.335141362540313, 1.3423796509621047, 1.3492828476735634, 1.355882106693847, 1.362204366553743, 1.3682730833261532, 1.3741088103166372, 1.379729661461215, 1.3851516854212416, 1.3903891703159095, 1.395454894014972, 1.4003603312913961, 1.405115826483646, 1.4097307383555409, 1.4142135623730951, 1.418572034507081, 1.422813219821873, 1.426943588457651, 1.4309690811052556, 1.4348951656753597, 1.4387268865499159, 1.4424689075546286, 1.446125549591925, 1.4497008237135636, 1.453198460282268, 1.4566219347661555, 1.4599744906233632, 1.463259159663224, 1.466478780211681, 1.4696360133599293, 1.4727333575346888, 1.4757731615945522, 1.4787576366283137, 1.4816888666071195, 1.4845688180219063, 1.4873993486203083, 1.490182215342446, 1.4929190815424387, 1.4956115235716425, 1.4982610367903495, 1.50086904106665, 1.5034368858142386, 1.5059658546149228, 1.5084571694663826, 1.510911994691163, 1.5133314405389133, 1.5157165665103982, 1.5180683844287586, 1.520387861280808, 1.522675921848786, 1.5249334511509007, 1.5271612967071428, 1.52936027064522, 1.5315311516599992, 1.5336746868385573, 1.535791593361787, 1.5378825600924682, 1.5399482490588157, 1.541989296841664, 1.5440063158727362, 1.5459998956507686, 1.547970603881666, 1.5499189875483372, 1.5518455739153598, 1.5537508714732025, 1.5556353708263266, 1.557499545529136, 1.5593438528734203, 1.5611687346306369, 1.5629746177521229, 1.564761915030063, 1.5665310257218437, 1.5682823361402, 1.570016220211393, 1.5717330400034728, 1.5734331462265458, 1.5751168787068055, 1.5767845668359717, 1.578436529997654, 1.5800730779720562, 1.5816945113203258, 1.5833011217497763, 1.5848931924611136, 1.5864709984787198], [0.0, 1.0009955282949736, 1.07284044334405, 1.117234306234331, 1.1498419167118241, 1.1757883094816752, 1.1974220808571023, 1.2160234257930393, 1.2323700524435999, 1.2469711000138288, 1.2601787076628697, 1.2722469133704737, 1.2833652097176298, 1.293678833804823, 1.3033016375874507, 1.312324579970646, 1.3208215182335101, 1.3288532702333444, 1.3364705335445115, 1.3437160278872342, 1.3506260969263448, 1.357231925695709, 1.363560479544184, 1.3696352378958552, 1.37547677451768, 1.3811032213786139, 1.3865306431169089, 1.391773342075984, 1.3968441088463233, 1.4017544296243551, 1.4065146590466258, 1.4111341651938678, 1.4156214519895731, 1.419984263105891, 1.424229670640668, 1.4283641511752916, 1.4323936513147282, 1.4363236444131102, 1.4401591798742157, 1.443904926166719, 1.447565208494628, 1.451144041902817, 1.454645160467691, 1.4580720431172944, 1.4614279365387184, 1.464715875559548, 1.46793870133136, 1.4710990775945414, 1.474199505263066, 1.4772423355338822, 1.4802297816969856, 1.4831639297981742, 1.4860467482860826, 1.488880096757785, 1.491665733902486, 1.4944053247302203, 1.4971004471616467, 1.4997525980457307, 1.5023631986640817, 1.5049335997737738, 1.5074650862344559, 1.5099588812603422, 1.5124161503330933, 1.514838004807643, 1.5172255052395196, 1.5195796644591621, 1.5219014504160473, 1.5241917888130616, 1.5264515655494733, 1.5286816289890035, 1.5308827920678558, 1.5330558342561103, 1.53520150338459, 1.5373205173481612, 1.5394135656953865, 1.5414813111135486, 1.5435243908172163, 1.5455434178478054, 1.5475389822909151, 1.5495116524176176, 1.5514619757553585, 1.553390480093622, 1.555297674429094, 1.557184049854646, 1.559050080396119, 1.560896223800549, 1.5627229222791899, 1.5645306032084205, 1.5663196797913723, 1.5680905516829036, 1.569843605580335, 1.5715792157821808, 1.5732977447169412, 1.5749995434438637, 1.5766849521274484, 1.5783543004873344, 1.5800079082250866, 1.5816460854293035, 1.5832691329603497, 1.5848773428159417, 1.5864709984787198, 1.5880503752468602]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 0.30000000000000004\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.5011872336272722, 0.5561020542229561, 0.5909737465771551, 0.6170338627200096, 0.6380364656795914, 0.6557264279955705, 0.671065181737442, 0.6846419373062242, 0.696845301935949, 0.7079457843841379, 0.7181396451601799, 0.7275740265319789, 0.7363622275842615, 0.7445934394235262, 0.7523391963649502, 0.7596577929323739, 0.7665973933696394, 0.7731982737820289, 0.7794944729444898, 0.7855150302317644, 0.7912849291444431, 0.7968258269513704, 0.8021566263287917, 0.8072939285093641, 0.8122523963562356, 0.8170450481113714, 0.8216834971818952, 0.8261781494863427, 0.8305383671031632, 0.8347726049266045, 0.8388885255241149, 0.8428930962561983, 0.8467926718610781, 0.8505930650497369, 0.8542996071500324, 0.857917200444095, 0.8614503635338218, 0.8649032708248208, 0.8682797870246687, 0.8715834973956161, 0.8748177343763873, 0.877985601086042, 0.8810899921399995, 0.884133612140456, 0.8871189921475423, 0.890048504391361, 0.8929243754466416, 0.8957486980597117, 0.8985234417906397, 0.9012504626108302, 0.9039315115772826, 0.9065682426885815, 0.9091622200139485, 0.911714924174976, 0.9142277582496346, 0.9167020531595504, 0.9191390725941327, 0.9215400175187469, 0.9239060303085882, 0.9262381985451124, 0.9285375585076968, 0.9308050983895649, 0.933041761263817, 0.9352484478226214, 0.937426018910166, 0.9395752978678164, 0.9416970727080176, 0.9437920981318068, 0.9458610974033023, 0.9479047640932289, 0.9499237637023544, 0.9519187351746781, 0.9538902923092755, 0.9558390250788759, 0.9577655008625032, 0.9596702655988487, 0.9615538448664398, 0.9634167448961425, 0.9652594535210391, 0.9670824410682998, 0.9688861611972635, 0.9706710516875964, 0.9724375351810698, 0.9741860198802093, 0.9759169002068065, 0.977630557423041, 0.9793273602177414, 0.9810076652601227, 0.9826718177231486, 0.9843201517785073, 0.9859529910650362, 0.9875706491322975, 0.9891734298608728, 0.9907616278608403, 0.9923355288497813, 0.9938954100115739, 0.995441540337139, 0.9969741809482233, 0.9984935854052241, 1.0, 1.001493664034538], [0.0, 0.5561020542229561, 0.6170338627200096, 0.6557264279955703, 0.6846419373062241, 0.7079457843841378, 0.7275740265319788, 0.744593439423526, 0.7596577929323738, 0.7731982737820289, 0.7855150302317643, 0.7968258269513704, 0.807293928509364, 0.8170450481113714, 0.8261781494863428, 0.8347726049266045, 0.8428930962561983, 0.8505930650497369, 0.8579172004440948, 0.8649032708248207, 0.871583497395616, 0.8779856010860418, 0.8841336121404559, 0.890048504391361, 0.8957486980597117, 0.9012504626108302, 0.9065682426885813, 0.9117149241749759, 0.9167020531595503, 0.9215400175187468, 0.9262381985451124, 0.9308050983895649, 0.9352484478226212, 0.9395752978678162, 0.9437920981318065, 0.9479047640932288, 0.951918735174678, 0.9558390250788756, 0.9596702655988486, 0.9634167448961425, 0.9670824410682997, 0.9706710516875963, 0.9741860198802091, 0.977630557423041, 0.9810076652601226, 0.9843201517785072, 0.9875706491322973, 0.9907616278608403, 0.9938954100115738, 0.9969741809482231, 0.9999999999999999, 1.0029748100862945, 1.0059004464334433, 1.0087786444849067, 1.0116110470932034, 1.0143992110708164, 1.017144613167752, 1.0198486555352004, 1.0225126707276686, 1.0251379262897986, 1.027725628968772, 1.030276928588551, 1.032792921618168, 1.0352746544627456, 1.0377231265028173, 1.0401392929048145, 1.042524067223181, 1.0448783238124701, 1.0472029000659124, 1.0494985984952945, 1.051766188665519, 1.0540064089959216, 1.0562199684392581, 1.058407548048245, 1.0605698024386119, 1.0627073611568028, 1.064820829959723, 1.066910792013262, 1.0689778090157345, 1.0710224222518359, 1.073045153582236, 1.0750465063734884, 1.077026966372546, 1.0789870025298158, 1.0809270677743588, 1.0828475997445541, 1.0847490214772766, 1.0866317420583955, 1.0884961572371834, 1.0903426500070237, 1.0921715911546193, 1.093983339779745, 1.0957782437874222, 1.097556640354268, 1.0993188563706313, 1.1010652088600175, 1.1027960053771964, 1.1045115443862819, 1.1062121156199922, 1.1078980004212042, 1.109569472067845, 1.1112267960820938], [0.0, 0.5909737465771551, 0.6557264279955703, 0.696845301935949, 0.7275740265319789, 0.7523391963649502, 0.773198273782029, 0.7912849291444431, 0.807293928509364, 0.8216834971818952, 0.8347726049266045, 0.8467926718610782, 0.857917200444095, 0.8682797870246686, 0.8779856010860421, 0.8871189921475423, 0.8957486980597117, 0.9039315115772827, 0.911714924174976, 0.9191390725941329, 0.9262381985451124, 0.933041761263817, 0.9395752978678164, 0.9458610974033024, 0.9519187351746781, 0.9577655008625033, 0.9634167448961424, 0.9688861611972635, 0.9741860198802091, 0.9793273602177414, 0.9843201517785073, 0.9891734298608729, 0.9938954100115738, 0.9984935854052241, 1.0029748100862947, 1.007345370477477, 1.0116110470932036, 1.0157771680322631, 1.0198486555352007, 1.0238300666628564, 1.0277256289687722, 1.031539271890224, 1.0352746544627458, 1.038935189865294, 1.0425240672231812, 1.046044271030001, 1.0494985984952947, 1.0528896750794121, 1.0562199684392584, 1.0594918009769512, 1.062707361156803, 1.0658687137335516, 1.0689778090157345, 1.072036491271892, 1.0750465063734886, 1.0780095087566102, 1.0809270677743588, 1.0838006735031263, 1.0866317420583957, 1.0894216204691891, 1.0921715911546193, 1.094882876041075, 1.0975566403542683, 1.1001939961166254, 1.1027960053771964, 1.1053636831983784, 1.1078980004212042, 1.1103998862286935, 1.1128702305247973, 1.1153098861446975, 1.117719670910682, 1.1201003695464138, 1.1224527354612057, 1.1247774924147926, 1.127075336072129, 1.1293469354568555, 1.1315929343112943, 1.1338139523701285, 1.136010586554292, 1.1381834120910157, 1.1403329835654745, 1.1424598359090101, 1.1445644853284853, 1.1466474301809495, 1.1487091517974497, 1.1507501152595132, 1.1527707701315408, 1.1547715511520973, 1.1567528788868477, 1.1587151603456796, 1.1606587895663523, 1.1625841481668389, 1.1644916058683674, 1.1663815209910104, 1.1682542409235481, 1.1701101025691933, 1.1719494327686637, 1.1737725487019706, 1.1755797582702063, 1.1773713604585165, 1.1791476456813665, 1.180908896111131], [0.0, 0.6170338627200096, 0.6846419373062241, 0.7275740265319789, 0.7596577929323738, 0.7855150302317643, 0.807293928509364, 0.8261781494863427, 0.8428930962561983, 0.8579172004440949, 0.871583497395616, 0.884133612140456, 0.8957486980597117, 0.9065682426885813, 0.9167020531595506, 0.9262381985451124, 0.9352484478226213, 0.9437920981318066, 0.951918735174678, 0.9596702655988486, 0.9670824410682997, 0.974186019880209, 0.9810076652601226, 0.9875706491322974, 0.9938954100115738, 1.0, 1.0059004464334431, 1.0116110470932034, 1.017144613167752, 1.0225126707276686, 1.0277256289687722, 1.0327929216181682, 1.0377231265028173, 1.042524067223181, 1.0472029000659124, 1.051766188665519, 1.0562199684392581, 1.0605698024386119, 1.064820829959723, 1.0689778090157345, 1.073045153582236, 1.077026966372546, 1.0809270677743588, 1.0847490214772766, 1.0884961572371834, 1.0921715911546193, 1.0957782437874222, 1.0993188563706313, 1.1027960053771964, 1.1062121156199922, 1.1095694720678448, 1.1128702305247968, 1.1161164273019653, 1.1193099879944344, 1.1224527354612055, 1.1255463970938844, 1.1285926114491949, 1.131592934311294, 1.1345488442419815, 1.1374617476700972, 1.1403329835654743, 1.1431638277376792, 1.1459554967952779, 1.1487091517974495, 1.1514259016263246, 1.1541068061054167, 1.1567528788868477, 1.1593650901277373, 1.1619443689740507, 1.1644916058683672, 1.1670076546964094, 1.16949333478573, 1.1719494327686637, 1.1743767043205136, 1.1767758757829092, 1.1791476456813663, 1.1814926861452546, 1.1838116442376416, 1.1861051432018301, 1.1883737836307942, 1.1906181445652015, 1.1928387845252129, 1.1950362424808187, 1.1972110387650745, 1.199363675934239, 1.201494639578498, 1.2036043990866532, 1.2056934083678967, 1.2077621065335398, 1.2098109185413484, 1.2118402558049293, 1.2138505167704294, 1.2158420874626406, 1.217815342002443, 1.2197706430973885, 1.2217083425070812, 1.223628781484904, 1.2255322911975268, 1.2274191931235288, 1.2292897994323768, 1.2311444133449163, 1.2329833294764518], [0.0, 0.6380364656795914, 0.7079457843841378, 0.7523391963649502, 0.7855150302317643, 0.8122523963562355, 0.8347726049266045, 0.8542996071500323, 0.871583497395616, 0.8871189921475422, 0.9012504626108302, 0.9142277582496346, 0.9262381985451124, 0.937426018910166, 0.9479047640932289, 0.9577655008625032, 0.9670824410682995, 0.9759169002068065, 0.9843201517785071, 0.9923355288497813, 1.0, 1.0073453704774769, 1.0143992110708164, 1.0211855858341976, 1.0277256289687722, 1.034038007034165, 1.0401392929048145, 1.046044271030001, 1.051766188665519, 1.0573169642064197, 1.062707361156803, 1.0679471343490432, 1.073045153582236, 1.0780095087566102, 1.082847599744554, 1.087566213593613, 1.0921715911546193, 1.0966694848342402, 1.1010652088600177, 1.1053636831983784, 1.109569472067845, 1.1136868178299202, 1.1177196709106818, 1.1216717163006238, 1.1255463970938844, 1.1293469354568555, 1.1330763513573434, 1.1367374793365652, 1.1403329835654743, 1.143865371392744, 1.147337005562985, 1.1507501152595128, 1.1541068061054167, 1.1574090692392, 1.160658789566352, 1.163857753275445, 1.1670076546964094, 1.1701101025691933, 1.1731666257828939, 1.1761786786383857, 1.1791476456813663, 1.1820748461474175, 1.1849615380560357, 1.1878089219865409, 1.1906181445652013, 1.1933903016898106, 1.1961264415151889, 1.1988275672206705, 1.201494639578498, 1.2041285793401408, 1.2067302694558903, 1.2093005571415758, 1.2118402558049293, 1.214350146842935, 1.2168309813204436, 1.219283481539388, 1.2217083425070814, 1.224106233311329, 1.2264777984093933, 1.2288236588372365, 1.2311444133449163, 1.233440639463507, 1.235712894508463, 1.23796171652394, 1.2401876251722108, 1.2423911225719826, 1.2445726940891166, 1.2467328090829697, 1.2488719216113264, 1.2509904710966684, 1.2530888829563018, 1.2551675691986863, 1.2572269289881277, 1.259267349179836, 1.2612892048272055, 1.2632928596630353, 1.265278666556294, 1.2672469679459046, 1.2691980962529366, 1.2711323742724834, 1.2730501155464236, 1.2749516247181796], [0.0, 0.6557264279955705, 0.7275740265319788, 0.773198273782029, 0.807293928509364, 0.8347726049266045, 0.857917200444095, 0.877985601086042, 0.8957486980597117, 0.911714924174976, 0.9262381985451124, 0.9395752978678165, 0.9519187351746781, 0.9634167448961424, 0.9741860198802093, 0.9843201517785073, 0.9938954100115738, 1.0029748100862947, 1.0116110470932036, 1.0198486555352007, 1.0277256289687722, 1.0352746544627458, 1.0425240672231812, 1.0494985984952947, 1.0562199684392584, 1.062707361156803, 1.0689778090157345, 1.0750465063734886, 1.0809270677743588, 1.0866317420583955, 1.0921715911546195, 1.0975566403542683, 1.1027960053771961, 1.1078980004212042, 1.112870230524797, 1.1177196709106818, 1.1224527354612057, 1.127075336072129, 1.1315929343112943, 1.1360105865542922, 1.1403329835654745, 1.1445644853284853, 1.1487091517974495, 1.1527707701315408, 1.1567528788868477, 1.160658789566352, 1.1644916058683674, 1.1682542409235481, 1.1719494327686637, 1.175579758270206, 1.1791476456813665, 1.1826553859909699, 1.1861051432018301, 1.1894989636580182, 1.1928387845252129, 1.1961264415151889, 1.199363675934239, 1.2025521411256388, 1.2056934083678967, 1.2087889722832943, 1.2118402558049293, 1.2148486147450193, 1.217815342002443, 1.2207416714433368, 1.223628781484904, 1.2264777984093935, 1.2292897994323768, 1.2320658155469666, 1.2348068341634202, 1.2375138015616205, 1.2401876251722108, 1.2428291757006125, 1.2454392891067987, 1.2480187684524762, 1.2505683856262413, 1.2530888829563018, 1.2555809747194864, 1.2580453485544802, 1.2604826667865288, 1.2628935676702069, 1.2652786665562943, 1.267638556988277, 1.2699738117335322, 1.2722849837538273, 1.2745726071193981, 1.2768371978705098, 1.2790792548300967, 1.281299260370799, 1.2834976811394396, 1.2856749687417641, 1.2878315603900414, 1.2899678795159246, 1.2920843363508014, 1.2941813284756856, 1.2962592413425622, 1.2983184487689519, 1.3003593134073368, 1.3023821871909744, 1.3043874117575176, 1.3063753188517566, 1.3083462307087164, 1.310300460418249], [0.0, 0.671065181737442, 0.744593439423526, 0.7912849291444431, 0.8261781494863427, 0.8542996071500323, 0.877985601086042, 0.8985234417906397, 0.9167020531595504, 0.933041761263817, 0.9479047640932288, 0.9615538448664398, 0.9741860198802091, 0.985952991065036, 0.9969741809482233, 1.007345370477477, 1.017144613167752, 1.0264363985847806, 1.0352746544627456, 1.0437049570557166, 1.051766188665519, 1.0594918009769512, 1.066910792013262, 1.0740484715329992, 1.0809270677743588, 1.087566213593613, 1.0939833397797447, 1.1001939961166254, 1.1062121156199922, 1.1120502336547833, 1.1177196709106818, 1.1232306871905562, 1.1285926114491949, 1.1338139523701283, 1.138902492888935, 1.143865371392744, 1.1487091517974495, 1.1534398842898872, 1.1580631581949046, 1.1625841481668389, 1.1670076546964094, 1.1713381397560054, 1.175579758270206, 1.1797363859874186, 1.1838116442376416, 1.1878089219865409, 1.1917313955341458, 1.1955820461550684, 1.199363675934239, 1.2030789220162148, 1.2067302694558903, 1.2103200628329045, 1.2138505167704294, 1.2173237254806193, 1.2207416714433368, 1.224106233311329, 1.2274191931235285, 1.23068224289822, 1.2338969906692616, 1.2370649660211412, 1.2401876251722106, 1.243266355649849, 1.246302480596428, 1.2492972627406829, 1.2522519080653538, 1.255167569198686, 1.25804534855448, 1.260886301242841, 1.2636914377715285, 1.266461726555806, 1.2691980962529366, 1.271901437935884, 1.2745726071193981, 1.277212425650407, 1.2798216834735265, 1.2824011402815068, 1.2849515270595415, 1.287473547531561, 1.2899678795159246, 1.2924351761972583, 1.294876067320629, 1.2972911603136932, 1.2996810413420028, 1.3020462763022083, 1.3043874117575174, 1.3067049758194098, 1.3089994789792874, 1.3112714148934512, 1.3135212611245277, 1.3157494798422251, 1.3179565184860822, 1.3201428103926665, 1.3223087753894984, 1.3244548203578077, 1.326581339766073, 1.3286887161761551, 1.3307773207237037, 1.3328475135743993, 1.3348996443574839, 1.3369340525779219, 1.3389510680084606, 1.340951011062751], [0.0, 0.6846419373062242, 0.7596577929323738, 0.807293928509364, 0.8428930962561983, 0.871583497395616, 0.8957486980597117, 0.9167020531595504, 0.9352484478226213, 0.951918735174678, 0.9670824410682997, 0.9810076652601227, 0.9938954100115738, 1.0059004464334431, 1.0171446131677522, 1.0277256289687722, 1.0377231265028173, 1.0472029000659124, 1.0562199684392581, 1.064820829959723, 1.073045153582236, 1.0809270677743588, 1.0884961572371834, 1.0957782437874222, 1.1027960053771964, 1.109569472067845, 1.1161164273019653, 1.1224527354612057, 1.1285926114491949, 1.1345488442419813, 1.1403329835654745, 1.145955496795278, 1.1514259016263246, 1.1567528788868475, 1.1619443689740507, 1.1670076546964094, 1.1719494327686637, 1.1767758757829092, 1.1814926861452546, 1.1861051432018301, 1.1906181445652013, 1.1950362424808187, 1.199363675934239, 1.2036043990866534, 1.2077621065335398, 1.2118402558049293, 1.2158420874626403, 1.2197706430973885, 1.223628781484904, 1.2274191931235285, 1.2311444133449163, 1.23480683416342, 1.238408715007691, 1.2419521924592505, 1.2454392891067985, 1.2488719216113264, 1.2522519080653538, 1.2555809747194862, 1.2588607621407593, 1.2620928308596782, 1.265278666556294, 1.2684196848299538, 1.2715172355923816, 1.274572607119398, 1.2775870297927636, 1.280561679560294, 1.2834976811394394, 1.286396110986923, 1.289258000054743, 1.2920843363508012, 1.294876067320629, 1.297634102065066, 1.3003593134073366, 1.3030525398216881, 1.3057145872346185, 1.3083462307087161, 1.3109482160182102, 1.3135212611245275, 1.3160660575594103, 1.318583271722488, 1.3210735460996077, 1.3235375004076904, 1.3259757326713832, 1.32838882023636, 1.3307773207237037, 1.33314177292946, 1.3354826976731136, 1.3378005985984478, 1.340095962929968, 1.3423692621878385, 1.3446209528640376, 1.3468514770622464, 1.3490612631037886, 1.3512507261017728, 1.3534202685054253, 1.355570280616464, 1.3577011410792255, 1.3598132173461364, 1.3619068661200142, 1.3639824337745694, 1.3660402567543957, 1.3680806619556405], [0.0, 0.696845301935949, 0.7731982737820289, 0.8216834971818952, 0.8579172004440949, 0.8871189921475422, 0.911714924174976, 0.933041761263817, 0.951918735174678, 0.9688861611972635, 0.9843201517785072, 0.9984935854052241, 1.0116110470932036, 1.0238300666628561, 1.0352746544627458, 1.046044271030001, 1.0562199684392581, 1.0658687137335516, 1.0750465063734884, 1.0838006735031263, 1.0921715911546193, 1.1001939961166254, 1.1078980004212042, 1.1153098861446977, 1.1224527354612057, 1.1293469354568555, 1.136010586554292, 1.1424598359090101, 1.1487091517974495, 1.1547715511520973, 1.160658789566352, 1.1663815209910104, 1.1719494327686635, 1.1773713604585163, 1.1826553859909699, 1.1878089219865409, 1.1928387845252129, 1.1977512562221289, 1.2025521411256388, 1.2072468126833036, 1.2118402558049293, 1.2163371038772288, 1.220741671443337, 1.225057983145185, 1.2292897994323768, 1.2334406394635071, 1.2375138015616203, 1.2415123815321076, 1.2454392891067985, 1.2492972627406829, 1.2530888829563018, 1.2568165844043437, 1.2604826667865288, 1.2640893047677642, 1.267638556988277, 1.2711323742724834, 1.274572607119398, 1.2779610125490908, 1.281299260370799, 1.2845889389306233, 1.2878315603900412, 1.2910285655806768, 1.2941813284756856, 1.2972911603136934, 1.3003593134073366, 1.3033869846650517, 1.3063753188517566, 1.3093254116114212, 1.3122383122721941, 1.315115026452673, 1.3179565184860822, 1.3207637136774824, 1.3235375004076904, 1.3262787320962939, 1.328988229034986, 1.3316667801014173, 1.3343151443628316, 1.3369340525779219, 1.3395242086046018, 1.3420862907207056, 1.3446209528640376, 1.3471288257976295, 1.3496105182055882, 1.3520666177244556, 1.3544976919146021, 1.3569042891758158, 1.359286939610902, 1.3616461558408153, 1.3639824337745694, 1.3662962533369152, 1.3685880791565488, 1.370858361217405, 1.3731075354753992, 1.3753360244428012, 1.3775442377422735, 1.3797325726324465, 1.3819014145067827, 1.3840511373673456, 1.3861821042749836, 1.3882946677773274, 1.3903891703159095, 1.3924659446136214], [0.0, 0.7079457843841379, 0.7855150302317643, 0.8347726049266045, 0.871583497395616, 0.9012504626108302, 0.9262381985451124, 0.9479047640932288, 0.9670824410682997, 0.9843201517785072, 1.0, 1.0143992110708167, 1.0277256289687722, 1.0401392929048145, 1.0517661886655192, 1.062707361156803, 1.073045153582236, 1.0828475997445541, 1.0921715911546193, 1.1010652088600177, 1.109569472067845, 1.1177196709106818, 1.1255463970938844, 1.1330763513573436, 1.1403329835654745, 1.1473370055629852, 1.1541068061054167, 1.160658789566352, 1.1670076546964094, 1.1731666257828939, 1.1791476456813665, 1.1849615380560359, 1.1906181445652013, 1.1961264415151889, 1.201494639578498, 1.2067302694558903, 1.2118402558049293, 1.2168309813204436, 1.2217083425070814, 1.2264777984093935, 1.2311444133449163, 1.235712894508463, 1.2401876251722108, 1.2445726940891169, 1.2488719216113264, 1.2530888829563018, 1.2572269289881277, 1.2612892048272055, 1.265278666556294, 1.2691980962529366, 1.2730501155464236, 1.2768371978705095, 1.280561679560294, 1.2842257699222752, 1.2878315603900412, 1.291381032863904, 1.294876067320629, 1.2983184487689519, 1.3017098736175408, 1.3050519555142492, 1.3083462307087161, 1.3115941629844692, 1.3147971482015373, 1.3179565184860822, 1.3210735460996077, 1.3241494470168496, 1.3271853842383983, 1.3301824708614185, 1.33314177292946, 1.3360643120802445, 1.3389510680084606, 1.3418029807589291, 1.3446209528640376, 1.3474058513380254, 1.3501585095395225, 1.3528797289127028, 1.3555702806164642, 1.3582309070502097, 1.3608623232840436, 1.3634652184005103, 1.3660402567543957, 1.3685880791565486, 1.371109303987184, 1.3736045282436715, 1.3760743285274044, 1.3785192619739721, 1.3809398671305169, 1.383336664783852, 1.3857101587426346, 1.3880608365766351, 1.3903891703159095, 1.3926956171124667, 1.394980619866835, 1.3972446078217455, 1.3994879971249945, 1.4017111913633924, 1.4039145820695742, 1.406098549203315, 1.408263461608885, 1.4104096774498658, 1.4125375446227544, 1.4146474011505918], [0.0, 0.7181396451601799, 0.7968258269513704, 0.8467926718610782, 0.884133612140456, 0.9142277582496346, 0.9395752978678165, 0.9615538448664398, 0.9810076652601227, 0.9984935854052241, 1.0143992110708167, 1.0290057594210953, 1.0425240672231812, 1.0551164781264009, 1.0669107920132623, 1.0780095087566104, 1.0884961572371836, 1.0984397508908033, 1.1078980004212042, 1.116919679205126, 1.1255463970938846, 1.1338139523701285, 1.1417533772356365, 1.1493917568998888, 1.156752878886848, 1.1638577532754455, 1.1707250336047947, 1.1773713604585165, 1.1838116442376418, 1.1900592996487795, 1.196126441515189, 1.2020240493533043, 1.2077621065335398, 1.213349718613951, 1.2187952144942436, 1.224106233311329, 1.2292897994323768, 1.2343523874579856, 1.2392999787978185, 1.2441381111023608, 1.2488719216113264, 1.2535061852994203, 1.2580453485544802, 1.262493559004281, 1.2668546920110244, 1.2711323742724834, 1.2753300049025424, 1.279450774308855, 1.2834976811394396, 1.2874735475315613, 1.291381032863904, 1.295222646185717, 1.2990007574734823, 1.3027176078459681, 1.3063753188517566, 1.3099759009289604, 1.3135212611245277, 1.3170132101499112, 1.320453468840726, 1.323843674080081, 1.3271853842383983, 1.3304800841765336, 1.333729189853799, 1.3369340525779219, 1.3400959629299682, 1.3432161543937504, 1.34629580671615, 1.3493360490220525, 1.352337962705194, 1.3553025841140733, 1.3582309070502099, 1.361123885094328, 1.3639824337745694, 1.366807432589495, 1.3695997268974414, 1.3723601296827461, 1.3750894232083868, 1.3777883605637324, 1.3804576671153324, 1.3830980418679764, 1.3857101587426348, 1.3882946677773271, 1.390852196256456, 1.3933833497736816, 1.395888713233003, 1.3983688517923218, 1.4008243117534347, 1.4032556214020744, 1.4056632918013445, 1.4080478175416364, 1.410409677449866, 1.4127493352606704, 1.4150672402519964, 1.4173638278473313, 1.4196395201866718, 1.4218947266681599, 1.4241298444621913, 1.4263452589996626, 1.42854134443591, 1.430718464091789, 1.4328769708732305, 1.4350172076705414], [0.0, 0.7275740265319789, 0.807293928509364, 0.857917200444095, 0.8957486980597117, 0.9262381985451124, 0.9519187351746781, 0.9741860198802091, 0.9938954100115738, 1.0116110470932036, 1.0277256289687722, 1.0425240672231812, 1.0562199684392584, 1.0689778090157345, 1.080927067774359, 1.0921715911546195, 1.1027960053771964, 1.112870230524797, 1.1224527354612057, 1.1315929343112943, 1.1403329835654745, 1.1487091517974495, 1.1567528788868477, 1.1644916058683674, 1.171949432768664, 1.1791476456813668, 1.1861051432018301, 1.1928387845252129, 1.199363675934239, 1.2056934083678967, 1.2118402558049293, 1.2178153420024431, 1.223628781484904, 1.2292897994323768, 1.2348068341634202, 1.2401876251722108, 1.2454392891067987, 1.2505683856262413, 1.2555809747194864, 1.260482666786529, 1.265278666556294, 1.2699738117335322, 1.2745726071193981, 1.2790792548300969, 1.2834976811394396, 1.2878315603900414, 1.2920843363508014, 1.2962592413425622, 1.3003593134073366, 1.3043874117575174, 1.3083462307087161, 1.3122383122721941, 1.3160660575594105, 1.319831737131276, 1.3235375004076904, 1.3271853842383983, 1.3307773207237037, 1.3343151443628316, 1.337800598598448, 1.3412353418178078, 1.3446209528640376, 1.347958936104984, 1.3512507261017728, 1.3544976919146021, 1.3577011410792255, 1.3608623232840436, 1.3639824337745694, 1.3670626165092867, 1.3701039670884732, 1.3731075354753992, 1.3760743285274044, 1.3790053123526438, 1.3819014145067827, 1.3847635260425761, 1.3875925034240457, 1.3903891703159095, 1.3931543192579308, 1.3958887132330027, 1.3985930871369983, 1.4012681491577088, 1.4039145820695744, 1.4065330444503277, 1.4091241718251641, 1.4116885777435808, 1.4142268547936074, 1.416739575557768, 1.4192272935147632, 1.4216905438905478, 1.4241298444621913, 1.4265456963176424, 1.4289385845742875, 1.4313089790589621, 1.4336573349518908, 1.4359840933968289, 1.4382896820795321, 1.4405745157765095, 1.4428389968758841, 1.4450835158720547, 1.4473084518357315, 1.4495141728608063, 1.4517010364894254, 1.453869390116531], [0.0, 0.7363622275842615, 0.8170450481113714, 0.8682797870246686, 0.9065682426885813, 0.937426018910166, 0.9634167448961424, 0.985952991065036, 1.0059004464334431, 1.0238300666628561, 1.0401392929048145, 1.0551164781264009, 1.0689778090157345, 1.0818897486445276, 1.093983339779745, 1.1053636831983784, 1.1161164273019653, 1.1263123367219763, 1.136010586554292, 1.1452611877857508, 1.1541068061054167, 1.1625841481668386, 1.1707250336047945, 1.1785572349079947, 1.1861051432018301, 1.1933903016898106, 1.200431837239122, 1.2072468126833034, 1.2138505167704292, 1.2202567046013464, 1.2264777984093933, 1.2325250563130066, 1.2384087150076908, 1.2441381111023606, 1.2497217848401039, 1.255167569198686, 1.2604826667865288, 1.2656737164953178, 1.2707468515112286, 1.2757077500010003, 1.2805616795602939, 1.2853135363273944, 1.2899678795159246, 1.294528961998494, 1.299000757473482, 1.3033869846650517, 1.3076911289386026, 1.3119164616574455, 1.3160660575594103, 1.3201428103926662, 1.3241494470168496, 1.3280885401475966, 1.331962519898846, 1.3357736842570964, 1.3395242086046015, 1.3432161543937502, 1.3468514770622462, 1.3504320332678132, 1.3539595875117643, 1.3574358182126367, 1.3608623232840433, 1.3642406252647479, 1.3675721760436137, 1.3708583612174048, 1.3741005041153018, 1.377299869520407, 1.3804576671153321, 1.383575054676175, 1.3866531410367193, 1.389692988842503, 1.3926956171124665, 1.395662003624165, 1.398593087136998, 1.4014897694665434, 1.4043529174218572, 1.407183364616516, 1.40998191316319, 1.41274933526067, 1.415486374681468, 1.4181937481674154, 1.4208721467400285, 1.4235222369318508, 1.426144661944442, 1.428740042738224, 1.431308979058962, 1.433852050405274, 1.4363698169412045, 1.4388628203575804, 1.4413315846855823, 1.4437766170656867, 1.4461984084749018, 1.4485974344149954, 1.4509741555642097, 1.4533290183947754, 1.4556624557583668, 1.4579748874414842, 1.4602667206926052, 1.4625383507228216, 1.464790161181552, 1.4670225246088109, 1.4692358028654147, 1.4714303475424102], [0.0, 0.7445934394235262, 0.8261781494863428, 0.8779856010860421, 0.9167020531595506, 0.9479047640932289, 0.9741860198802093, 0.9969741809482233, 1.0171446131677522, 1.0352746544627458, 1.0517661886655192, 1.0669107920132623, 1.080927067774359, 1.093983339779745, 1.1062121156199924, 1.117719670910682, 1.128592611449195, 1.1389024928889353, 1.1487091517974495, 1.1580631581949046, 1.1670076546964097, 1.175579758270206, 1.1838116442376418, 1.191731395534146, 1.1993636759342392, 1.2067302694558906, 1.2138505167704294, 1.220741671443337, 1.2274191931235288, 1.2338969906692616, 1.240187625172211, 1.2463024805964285, 1.252251908065354, 1.2580453485544802, 1.2636914377715285, 1.2691980962529368, 1.2745726071193983, 1.2798216834735265, 1.2849515270595417, 1.2899678795159248, 1.2948760673206292, 1.2996810413420028, 1.3043874117575176, 1.3089994789792876, 1.313521261124528, 1.3179565184860824, 1.3223087753894984, 1.3265813397660733, 1.3307773207237037, 1.3348996443574839, 1.3389510680084606, 1.3429341931506271, 1.3468514770622464, 1.3507052434171933, 1.3544976919146021, 1.3582309070502099, 1.3619068661200142, 1.3655274465358496, 1.3690944325229955, 1.3726095212617047, 1.3760743285274044, 1.379490393878117, 1.3828591854322245, 1.3861821042749836, 1.3894604885280264, 1.3926956171124667, 1.3958887132330027, 1.3990409476075971, 1.4021534414648111, 1.4052272693286576, 1.408263461608885, 1.4112630070128518, 1.4142268547936077, 1.4171559168474142, 1.4200510696727016, 1.4229131562013542, 1.425742987512227, 1.42854134443591, 1.4313089790589621, 1.4340466161351044, 1.436754954410238, 1.439434667867547, 1.4420864068984334, 1.444710799404545, 1.4473084518357318, 1.449879950168369, 1.4524258608281322, 1.454946731560983, 1.4574430922558324, 1.4599154557220797, 1.4623643184249775, 1.4647901611815524, 1.4671934498196046, 1.4695746358021253, 1.4719341568192965, 1.4742724373500795, 1.4765898891952614, 1.4788869119836865, 1.4811638936532876, 1.4834212109084095, 1.4856592296548252, 1.4878783054137399], [0.0, 0.7523391963649502, 0.8347726049266045, 0.8871189921475423, 0.9262381985451124, 0.9577655008625032, 0.9843201517785073, 1.007345370477477, 1.0277256289687722, 1.046044271030001, 1.062707361156803, 1.0780095087566104, 1.0921715911546195, 1.1053636831983784, 1.117719670910682, 1.1293469354568557, 1.1403329835654745, 1.1507501152595132, 1.160658789566352, 1.1701101025691936, 1.1791476456813665, 1.1878089219865409, 1.1961264415151889, 1.204128579340141, 1.2118402558049295, 1.2192834815393883, 1.2264777984093935, 1.2334406394635071, 1.2401876251722108, 1.2467328090829697, 1.253088882956302, 1.2592673491798365, 1.265278666556294, 1.2711323742724834, 1.2768371978705098, 1.282401140281507, 1.2878315603900414, 1.2931352411328916, 1.298318448768952, 1.3033869846650519, 1.3083462307087164, 1.3132011892705235, 1.3179565184860824, 1.3226165635032583, 1.3271853842383985, 1.3316667801014175, 1.3360643120802445, 1.3403813225174819, 1.3446209528640376, 1.3487861596541963, 1.3528797289127028, 1.3569042891758158, 1.3608623232840438, 1.3647561790836646, 1.3685880791565486, 1.372360129682746, 1.3760743285274044, 1.3797325726324468, 1.3833366647838523, 1.3868883198170732, 1.3903891703159095, 1.393840771853891, 1.3972446078217458, 1.4006020938797517, 1.4039145820695742, 1.4071833646165162, 1.4104096774498658, 1.413594703466174, 1.416739575557768, 1.419845379426576, 1.4229131562013542, 1.425943904874654, 1.4289385845742875, 1.4318981166826685, 1.4348233868161482, 1.4377152466753493, 1.4405745157765095, 1.4434019830729392, 1.446198408474902, 1.4489645242754903, 1.4517010364894254, 1.4544086261111135, 1.4570879502977612, 1.4597396434828673, 1.4623643184249775, 1.4649625671961835, 1.4675349621144977, 1.4700820566239003, 1.4726043861255598, 1.4751024687634602, 1.4775768061674168, 1.4800278841562347, 1.4824561734035655, 1.4848621300688192, 1.4872461963953223, 1.4896088012777493, 1.4919503608007132, 1.4942712787502639, 1.4965719470999228, 1.4988527464727646, 1.5011140465809572, 1.5033562066440747], [0.0, 0.7596577929323739, 0.8428930962561983, 0.8957486980597117, 0.9352484478226213, 0.9670824410682995, 0.9938954100115738, 1.017144613167752, 1.0377231265028173, 1.0562199684392581, 1.073045153582236, 1.0884961572371836, 1.1027960053771964, 1.1161164273019653, 1.128592611449195, 1.1403329835654745, 1.1514259016263246, 1.1619443689740507, 1.1719494327686635, 1.1814926861452546, 1.1906181445652013, 1.199363675934239, 1.2077621065335395, 1.2158420874626406, 1.223628781484904, 1.2311444133449163, 1.2384087150076908, 1.2454392891067985, 1.2522519080653538, 1.258860762140759, 1.265278666556294, 1.2715172355923816, 1.2775870297927634, 1.2834976811394394, 1.2892580000547427, 1.294876067320629, 1.3003593134073366, 1.3057145872346185, 1.3109482160182102, 1.3160660575594105, 1.3210735460996077, 1.3259757326713832, 1.3307773207237035, 1.3354826976731138, 1.340095962929968, 1.3446209528640376, 1.3490612631037886, 1.353420268505425, 1.3577011410792255, 1.361906866120014, 1.3660402567543954, 1.370103967088473, 1.374100504115302, 1.3780322385205133, 1.3819014145067825, 1.3857101587426344, 1.3894604885280262, 1.3931543192579305, 1.396793471255447, 1.400379676037585, 1.403914582069574, 1.407399760057234, 1.4108367078214046, 1.4142268547936072, 1.4175715661678827, 1.4208721467400283, 1.424129844462191, 1.4273458537378891, 1.4305213184799868, 1.4336573349518904, 1.4367549544102376, 1.4398151855655672, 1.442838996875884, 1.445827318686615, 1.4487810452291998, 1.4517010364894252, 1.4545881199556088, 1.4574430922558321, 1.460266720692605, 1.4630597446826126, 1.4658228771085378, 1.468556805589356, 1.4712621936749606, 1.4739396819704855, 1.4765898891952611, 1.4792134131809316, 1.4818108318128982, 1.4843827039189268, 1.486929570108455, 1.4894519535658626, 1.4919503608007127, 1.494425282357754, 1.4968771934892509, 1.4993065547920361, 1.5017138128114857, 1.5040994006144706, 1.506463738333187, 1.5088072336816303, 1.5111302824463573, 1.5134332689530632, 1.5157165665103982, 1.5179805378323479], [0.0, 0.7665973933696394, 0.8505930650497369, 0.9039315115772827, 0.9437920981318066, 0.9759169002068065, 1.0029748100862947, 1.0264363985847806, 1.0472029000659124, 1.0658687137335516, 1.0828475997445541, 1.0984397508908033, 1.112870230524797, 1.1263123367219763, 1.1389024928889353, 1.1507501152595132, 1.1619443689740507, 1.172558924272542, 1.18265538599097, 1.1922858185763063, 1.2014946395784982, 1.2103200628329047, 1.2187952144942436, 1.2269490073946165, 1.2348068341634202, 1.2423911225719828, 1.249721784840104, 1.256816584404344, 1.2636914377715285, 1.2703606648294241, 1.2768371978705098, 1.2831327572735935, 1.289258000054743, 1.295222646185717, 1.3010355865735248, 1.3067049758194098, 1.3122383122721941, 1.3176425074176528, 1.3229239462716906, 1.3280885401475968, 1.33314177292946, 1.3380887417918845, 1.3429341931506273, 1.3476825545020135, 1.3523379627051937, 1.356904289175816, 1.3613851623890112, 1.3657839880308569, 1.3701039670884732, 1.37434811212785, 1.3785192619739721, 1.3826200949786436, 1.3866531410367193, 1.3906207924904377, 1.39452531404364, 1.3983688517923216, 1.4021534414648107, 1.4058810159535324, 1.4095534122105409, 1.4131723775705414, 1.4167395755577679, 1.4202565912267, 1.4237249360810194, 1.4271460526103432, 1.4305213184799868, 1.4338520504052743, 1.4371395077386033, 1.4403848957945673, 1.443589368935865, 1.4467540334404516, 1.4498799501683688, 1.4529681370448946, 1.4560195713750583, 1.4590351920031484, 1.4620159013295566, 1.4649625671961832, 1.46787602465059, 1.4707570775981882, 1.473606500350924, 1.4764250390801767, 1.4792134131809318, 1.4819723165536784, 1.4847024188099485, 1.4874043664069103, 1.490078783715999, 1.49272627403015, 1.4953474205138437, 1.4979427870998312, 1.5005129193361069, 1.5030583451864272, 1.5055795757874046, 1.5080771061649951, 1.5105514159129727, 1.513002969835798, 1.5154322185581137, 1.5178395991029288, 1.5202255354404173, 1.5225904390091094, 1.524934709211138, 1.5272587338830779, 1.5295628897438156, 1.5318475428207898], [0.0, 0.7731982737820289, 0.8579172004440948, 0.911714924174976, 0.951918735174678, 0.9843201517785071, 1.0116110470932036, 1.0352746544627456, 1.0562199684392581, 1.0750465063734884, 1.0921715911546193, 1.1078980004212042, 1.1224527354612057, 1.136010586554292, 1.1487091517974495, 1.160658789566352, 1.1719494327686635, 1.18265538599097, 1.1928387845252129, 1.2025521411256388, 1.2118402558049293, 1.2207416714433368, 1.2292897994323766, 1.2375138015616205, 1.2454392891067987, 1.2530888829563018, 1.2604826667865285, 1.267638556988277, 1.274572607119398, 1.2812992603707989, 1.2878315603900412, 1.2941813284756856, 1.3003593134073363, 1.3063753188517564, 1.312238312272194, 1.3179565184860822, 1.3235375004076904, 1.3289882290349857, 1.3343151443628316, 1.3395242086046018, 1.3446209528640376, 1.3496105182055882, 1.3544976919146021, 1.359286939610902, 1.3639824337745694, 1.3685880791565486, 1.373107535475399, 1.3775442377422735, 1.3819014145067827, 1.3861821042749833, 1.3903891703159093, 1.3945253140436398, 1.398593087136998, 1.4025949025377773, 1.4065330444503275, 1.4104096774498656, 1.4142268547936072, 1.4179865260173832, 1.4216905438905478, 1.425340670793445, 1.428938584574287, 1.4324858839358587, 1.4359840933968286, 1.4394346678675467, 1.442838996875884, 1.4461984084749018, 1.449514172860806, 1.4527875057266983, 1.4560195713750583, 1.4592114856095824, 1.4623643184249773, 1.4654790965114906, 1.4685568055893563, 1.4715983925868956, 1.4746047676747296, 1.4775768061674166, 1.4805153503027975, 1.4834212109084093, 1.4862951689635058, 1.4891379770644657, 1.491950360800713, 1.4947330200476516, 1.4974866301825853, 1.500211843229081, 1.5029092889347995, 1.5055795757874046, 1.5082232919727852, 1.510841006279504, 1.5134332689530632, 1.5160006125033156, 1.5185435524680777, 1.521062588135787, 1.5235582032298183, 1.5260308665568878, 1.5284810326217964, 1.5309091422105934, 1.5333156229440992, 1.5357008898035862, 1.538065345630288, 1.5404093816002933, 1.5427333776762726, 1.545037703037389], [0.0, 0.7794944729444898, 0.8649032708248207, 0.9191390725941329, 0.9596702655988486, 0.9923355288497813, 1.0198486555352007, 1.0437049570557166, 1.064820829959723, 1.0838006735031263, 1.1010652088600177, 1.116919679205126, 1.1315929343112943, 1.1452611877857508, 1.1580631581949046, 1.1701101025691936, 1.1814926861452546, 1.1922858185763063, 1.2025521411256388, 1.2123445941619544, 1.2217083425070814, 1.23068224289822, 1.2392999787978183, 1.2475909494616204, 1.2555809747194864, 1.2632928596630355, 1.2707468515112286, 1.2779610125490908, 1.2849515270595415, 1.2917329558452442, 1.298318448768952, 1.304719923390757, 1.3109482160182102, 1.3170132101499112, 1.3229239462716906, 1.3286887161761554, 1.3343151443628316, 1.3398102585949345, 1.3451805513085855, 1.3504320332678135, 1.3555702806164642, 1.3606004762829778, 1.3655274465358496, 1.3703556933587084, 1.3750894232083868, 1.3797325726324468, 1.3842888311507515, 1.3887616617459526, 1.3931543192579305, 1.3974698669354764, 1.4017111913633924, 1.4058810159535322, 1.4099819131631903, 1.4140163155828869, 1.4179865260173832, 1.4218947266681596, 1.4257429875122267, 1.4295332739606001, 1.4332674538698447, 1.4369473039714713, 1.4405745157765095, 1.4441507010060746, 1.4476773965930811, 1.4511560692952998, 1.4545881199556088, 1.4579748874414844, 1.4613176522924147, 1.464617640100962, 1.46787602465059, 1.4710939308310502, 1.4742724373500795, 1.4774125792583246, 1.4805153503027975, 1.483581705122713, 1.4866125613002645, 1.4896088012777493, 1.4925712741514, 1.4955007973513703, 1.4983981582164743, 1.5012641154715274, 1.5040994006144708, 1.5069047192198355, 1.5096807521645623, 1.5124281567816842, 1.515147567946935, 1.517839599102929, 1.5205048432251875, 1.5231438737339524, 1.5257572453554071, 1.5283454949356636, 1.5309091422105936, 1.5334486905343694, 1.5359646275693537, 1.5384574259397839, 1.54092754385152, 1.543375425679958, 1.5458015025280603, 1.5482061927563158, 1.5505899024863183, 1.5529530260795266, 1.5552959465926697, 1.5576190362111577], [0.0, 0.7855150302317644, 0.871583497395616, 0.9262381985451124, 0.9670824410682997, 1.0, 1.0277256289687722, 1.051766188665519, 1.073045153582236, 1.0921715911546193, 1.109569472067845, 1.1255463970938846, 1.1403329835654745, 1.1541068061054167, 1.1670076546964097, 1.1791476456813665, 1.1906181445652013, 1.2014946395784982, 1.2118402558049293, 1.2217083425070814, 1.2311444133449163, 1.2401876251722108, 1.2488719216113264, 1.257226928988128, 1.2652786665562943, 1.2730501155464238, 1.280561679560294, 1.2878315603900412, 1.294876067320629, 1.3017098736175408, 1.3083462307087164, 1.3147971482015375, 1.3210735460996077, 1.3271853842383983, 1.33314177292946, 1.3389510680084606, 1.3446209528640376, 1.3501585095395225, 1.3555702806164642, 1.3608623232840438, 1.3660402567543957, 1.371109303987184, 1.3760743285274044, 1.380939867130517, 1.3857101587426346, 1.3903891703159095, 1.394980619866835, 1.3994879971249945, 1.4039145820695742, 1.4082634616088847, 1.4125375446227544, 1.4167395755577679, 1.4208721467400285, 1.4249377095485807, 1.4289385845742872, 1.4328769708732303, 1.4367549544102378, 1.4405745157765095, 1.444337537255316, 1.4480458093010544, 1.4517010364894252, 1.4553048429899447, 1.458858777606288, 1.4623643184249773, 1.4658228771085378, 1.4692358028654147, 1.4726043861255598, 1.4759298619476058, 1.4792134131809318, 1.4824561734035655, 1.485659229654825, 1.488823624979746, 1.491950360800713, 1.495040399130258, 1.4980946646376765, 1.501114046580957, 1.5040994006144708, 1.5070515504819315, 1.5099712896032973, 1.5128593825635233, 1.5157165665103982, 1.5185435524680777, 1.5213410265723701, 1.524109651233332, 1.5268500662302664, 1.5295628897438156, 1.5322487193294476, 1.5349081328363123, 1.5375416892751148, 1.5401499296383885, 1.5427333776762728, 1.5452925406306814, 1.5478279099305194, 1.5503399618504174, 1.552829158135266, 1.5552959465926695, 1.5577407616552867, 1.560164024914885, 1.5625661456298066, 1.5649475212074273, 1.5673085376630798, 1.5696495700568112], [0.0, 0.7912849291444431, 0.8779856010860418, 0.933041761263817, 0.974186019880209, 1.0073453704774769, 1.0352746544627458, 1.0594918009769512, 1.0809270677743588, 1.1001939961166254, 1.1177196709106818, 1.1338139523701285, 1.1487091517974495, 1.1625841481668386, 1.175579758270206, 1.1878089219865409, 1.199363675934239, 1.2103200628329047, 1.2207416714433368, 1.23068224289822, 1.2401876251722108, 1.2492972627406829, 1.25804534855448, 1.2664617265558062, 1.2745726071193981, 1.282401140281507, 1.2899678795159244, 1.2972911603136934, 1.3043874117575174, 1.3112714148934512, 1.3179565184860822, 1.3244548203578077, 1.3307773207237035, 1.3369340525779219, 1.3429341931506271, 1.3487861596541961, 1.354497691914602, 1.3600759239954083, 1.3655274465358496, 1.3708583612174048, 1.3760743285274042, 1.3811806097900854, 1.3861821042749836, 1.3910833820617083, 1.3958887132330027, 1.4006020938797517, 1.4052272693286572, 1.4097677549426597, 1.4142268547936072, 1.418607678464296, 1.422913156201354, 1.427146052610343, 1.431308979058962, 1.4354044049325425, 1.4394346678675467, 1.443401983072939, 1.4473084518357313, 1.4511560692952998, 1.4549467315609828, 1.4586822422387284, 1.4623643184249773, 1.4659945962193721, 1.469574635802125, 1.4731059261168518, 1.476589889195261, 1.4800278841562344, 1.4834212109084093, 1.4867711135823822, 1.4900787837159988, 1.4933453632138374, 1.4965719470999226, 1.4997595860808421, 1.5029092889347995, 1.5060220247406648, 1.5090987249597718, 1.5121402853820385, 1.515147567946935, 1.5181214024488772, 1.521062588135787, 1.5239718952087793, 1.5268500662302664, 1.5296978174471396, 1.5325158400351293, 1.5353048012699388, 1.538065345630288, 1.540798095837584, 1.543503653836562, 1.5461826017208873, 1.548835502607406, 1.5514629014624424, 1.5540653258832742, 1.5566432868376952, 1.5591972793643378, 1.5617277832362462, 1.564235263589998, 1.5667201715225108, 1.5691829446575118, 1.5716240076835162, 1.5740437728650205, 1.5764426405285048, 1.5788209995247275, 1.5811792276686907], [0.0, 0.7968258269513704, 0.8841336121404559, 0.9395752978678164, 0.9810076652601226, 1.0143992110708164, 1.0425240672231812, 1.066910792013262, 1.0884961572371834, 1.1078980004212042, 1.1255463970938844, 1.1417533772356365, 1.1567528788868477, 1.1707250336047945, 1.1838116442376418, 1.1961264415151889, 1.2077621065335395, 1.2187952144942436, 1.2292897994323766, 1.2392999787978183, 1.2488719216113264, 1.25804534855448, 1.266854692011024, 1.2753300049025424, 1.2834976811394394, 1.291381032863904, 1.299000757473482, 1.3063753188517564, 1.3135212611245275, 1.3204534688407255, 1.3271853842383983, 1.3337291898537988, 1.340095962929968, 1.3462958067161497, 1.3523379627051937, 1.3582309070502097, 1.3639824337745694, 1.3695997268974411, 1.3750894232083868, 1.3804576671153324, 1.3857101587426346, 1.3908521962564557, 1.3958887132330027, 1.4008243117534347, 1.4056632918013445, 1.4104096774498658, 1.415067240251996, 1.4196395201866716, 1.424129844462191, 1.4285413444359099, 1.4328769708732303, 1.437139507738603, 1.4413315846855823, 1.4454556883911365, 1.449514172860806, 1.4535092688153461, 1.4574430922558321, 1.4613176522924147, 1.4651348583117585, 1.4688965265493914, 1.4726043861255596, 1.4762600845965383, 1.4798651930675542, 1.4834212109084093, 1.486929570108455, 1.4903916393036745, 1.4938087275051917, 1.4971820875555104, 1.5005129193361069, 1.5038023727476384, 1.5070515504819315, 1.5102615106030473, 1.5134332689530632, 1.5165678013967325, 1.5196660459178586, 1.5227289045790435, 1.5257572453554071, 1.528751903851922, 1.531713684913168, 1.5346433641335204, 1.5375416892751148, 1.540409381600293, 1.5432471371246785, 1.5460556277965092, 1.5488355026074063, 1.5515873886393248, 1.5543118920520607, 1.5570095990153352, 1.5596810765891669, 1.5623268735559548, 1.564947521207427, 1.5675435340893809, 1.5701154107069097, 1.5726636341926232, 1.575188672940174, 1.5776909812052426, 1.5801709996759756, 1.582629156014729, 1.5850658653728422, 1.587481530880044, 1.5898765441099831, 1.5922512855232756], [0.0, 0.8021566263287917, 0.890048504391361, 0.9458610974033024, 0.9875706491322974, 1.0211855858341976, 1.0494985984952947, 1.0740484715329992, 1.0957782437874222, 1.1153098861446977, 1.1330763513573436, 1.1493917568998888, 1.1644916058683674, 1.1785572349079947, 1.191731395534146, 1.204128579340141, 1.2158420874626406, 1.2269490073946165, 1.2375138015616205, 1.2475909494616204, 1.257226928988128, 1.2664617265558062, 1.2753300049025424, 1.2838620180052704, 1.2920843363508017, 1.3000204280405676, 1.3076911289386028, 1.315115026452673, 1.3223087753894984, 1.3292873598762875, 1.3360643120802447, 1.3426518960393192, 1.3490612631037886, 1.3553025841140733, 1.3613851623890112, 1.3673175307875445, 1.3731075354753992, 1.3787624085331442, 1.3842888311507517, 1.3896929888425034, 1.394980619866835, 1.4001570578348714, 1.4052272693286576, 1.410195887217476, 1.4150672402519962, 1.419845379426576, 1.424534101526066, 1.4291369702120154, 1.4336573349518906, 1.438098348051964, 1.4424629800183864, 1.4467540334404516, 1.45097415556421, 1.4551258497026072, 1.4592114856095824, 1.4632333089295102, 1.4671934498196044, 1.4710939308310502, 1.4749366741243919, 1.4787235080858518, 1.4824561734035655, 1.4861363286560314, 1.4897655554592384, 1.4933453632138374, 1.496877193489251, 1.500362424077696, 1.5038023727476384, 1.5071983007231522, 1.5105514159129727, 1.5138628759106427, 1.517133790785045, 1.5203652256787354, 1.5235582032298185, 1.5267137058316251, 1.5298326777431115, 1.5329160270617175, 1.5359646275693537, 1.538979320461227, 1.5419609159663619, 1.5449101948678938, 1.5478279099305194, 1.5507147872418574, 1.5535715274739055, 1.5563988070702646, 1.559197279364338, 1.5619675756332865, 1.564710306092141, 1.567426060832124, 1.57011541070691, 1.5727789081702759, 1.575417088068315, 1.578030468389158, 1.580619550972919, 1.583184822184386, 1.5857267535507853, 1.588245802366788, 1.590742412268763, 1.5932170137801465, 1.595670024829658, 1.5981018512439817, 1.6005128872164116, 1.602903515752861], [0.0, 0.8072939285093641, 0.8957486980597117, 0.9519187351746781, 0.9938954100115738, 1.0277256289687722, 1.0562199684392584, 1.0809270677743588, 1.1027960053771964, 1.1224527354612057, 1.1403329835654745, 1.156752878886848, 1.171949432768664, 1.1861051432018301, 1.1993636759342392, 1.2118402558049295, 1.223628781484904, 1.2348068341634202, 1.2454392891067987, 1.2555809747194864, 1.2652786665562943, 1.2745726071193981, 1.2834976811394394, 1.2920843363508017, 1.3003593134073368, 1.3083462307087164, 1.3160660575594105, 1.3235375004076906, 1.3307773207237037, 1.337800598598448, 1.3446209528640378, 1.351250726101773, 1.3577011410792255, 1.3639824337745694, 1.3701039670884732, 1.3760743285274044, 1.381901414506783, 1.3875925034240457, 1.3931543192579308, 1.3985930871369983, 1.4039145820695742, 1.4091241718251641, 1.4142268547936077, 1.4192272935147632, 1.4241298444621913, 1.4289385845742875, 1.4336573349518906, 1.4382896820795321, 1.442838996875884, 1.4473084518357315, 1.4517010364894252, 1.4560195713750583, 1.4602667206926052, 1.4644450037871368, 1.4685568055893563, 1.4726043861255598, 1.4765898891952611, 1.4805153503027975, 1.484382703918927, 1.4881937901395208, 1.491950360800713, 1.495654085103141, 1.4993065547920363, 1.5029092889347997, 1.5064637383331871, 1.5099712896032973, 1.5134332689530634, 1.5168509456838963, 1.5202255354404173, 1.5235582032298185, 1.5268500662302664, 1.5301021964058767, 1.5333156229440992, 1.5364913345298687, 1.539630281469518, 1.5427333776762728, 1.5458015025280603, 1.5488355026074063, 1.5518361933323368, 1.5548043604864052, 1.557740761655287, 1.560646127576729, 1.5635211634100867, 1.566366549931152, 1.569182944657512, 1.5719709829092556, 1.5747312788094523, 1.5774644262284827, 1.5801709996759759, 1.582851555143823, 1.5855066309034658, 1.588136748260419, 1.590742412268763, 1.5933241124081425, 1.5958823232256152, 1.598417504944533, 1.6009301040424737, 1.6034205538001012, 1.605889274822703, 1.608336675536024, 1.6107631526579151, 1.613169091647199], [0.0, 0.8122523963562356, 0.9012504626108302, 0.9577655008625033, 1.0, 1.034038007034165, 1.062707361156803, 1.087566213593613, 1.109569472067845, 1.1293469354568555, 1.1473370055629852, 1.1638577532754455, 1.1791476456813668, 1.1933903016898106, 1.2067302694558906, 1.2192834815393883, 1.2311444133449163, 1.2423911225719828, 1.2530888829563018, 1.2632928596630355, 1.2730501155464238, 1.282401140281507, 1.291381032863904, 1.3000204280405676, 1.3083462307087164, 1.3163822043342377, 1.3241494470168496, 1.3316667801014173, 1.3389510680084606, 1.3460174834521768, 1.352879728912703, 1.3595502227805216, 1.3660402567543954, 1.372360129682746, 1.3785192619739721, 1.3845262938797356, 1.3903891703159095, 1.3961152143844666, 1.4017111913633926, 1.4071833646165162, 1.4125375446227544, 1.417779132120909, 1.4229131562013544, 1.4279443080416645, 1.4328769708732305, 1.4377152466753493, 1.4424629800183864, 1.4471237794153646, 1.4517010364894254, 1.4561979432210856, 1.460617507502646, 1.4649625671961832, 1.4692358028654149, 1.4734397493294424, 1.4775768061674166, 1.4816492472869065, 1.485659229654825, 1.4896088012777493, 1.493499908508121, 1.497334402743837, 1.501114046580957, 1.504840519472491, 1.5085154229403044, 1.5121402853820387, 1.5157165665103982, 1.5192456614581948, 1.5227289045790438, 1.5261675729705129, 1.5295628897438158, 1.5329160270617175, 1.5362281089641883, 1.5395002139994376, 1.5427333776762728, 1.5459285947522148, 1.549086821370459, 1.5522089770575636, 1.5552959465926697, 1.5583485817580849, 1.5613677029802018, 1.5643541008689232, 1.5673085376630798, 1.5702317485886723, 1.5731244431362046, 1.575987306262851, 1.5788209995247278, 1.5816261621441134, 1.584403412016074, 1.5871533466585919, 1.5898765441099834, 1.5925735637770888, 1.595244947237459, 1.5978912189985113, 1.6005128872164116, 1.6031104443772293, 1.6056843679427308, 1.6082351209629993, 1.6107631526579151, 1.613268898969389, 1.615752783086102, 1.6182152159423848, 1.6206565966927626, 1.6230773131635792], [0.0, 0.8170450481113714, 0.9065682426885813, 0.9634167448961424, 1.0059004464334431, 1.0401392929048145, 1.0689778090157345, 1.0939833397797447, 1.1161164273019653, 1.136010586554292, 1.1541068061054167, 1.1707250336047947, 1.1861051432018301, 1.200431837239122, 1.2138505167704294, 1.2264777984093935, 1.2384087150076908, 1.249721784840104, 1.2604826667865285, 1.2707468515112286, 1.280561679560294, 1.2899678795159244, 1.299000757473482, 1.3076911289386028, 1.3160660575594105, 1.3241494470168496, 1.3319625198988458, 1.3395242086046015, 1.3468514770622462, 1.3539595875117643, 1.3608623232840436, 1.3675721760436137, 1.3741005041153018, 1.3804576671153321, 1.386653141036719, 1.3926956171124665, 1.398593087136998, 1.4043529174218572, 1.40998191316319, 1.4154863746814683, 1.4208721467400283, 1.426144661944442, 1.431308979058962, 1.4363698169412045, 1.4413315846855823, 1.4461984084749018, 1.4509741555642097, 1.4556624557583668, 1.460266720692605, 1.464790161181552, 1.4692358028654147, 1.4736065003509238, 1.477904950018319, 1.4821337016432667, 1.4862951689635056, 1.4903916393036742, 1.4944252823577537, 1.498398158216474, 1.5023122247166256, 1.5061693441801787, 1.509971289603297, 1.5137197503485131, 1.5174163373873863, 1.5210625881357869, 1.5246599709193753, 1.52820988910287, 1.531713684913168, 1.5351726429832833, 1.5385879936413316, 1.5419609159663616, 1.5452925406306812, 1.5485839525464156, 1.5518361933323366, 1.5550502636154784, 1.5582271251807083, 1.5613677029802013, 1.564472887013691, 1.5675435340893806, 1.5705804694745447, 1.5735844884440373, 1.576556357734239, 1.5794968169093115, 1.5824065796460698, 1.5852863349432413, 1.5881367482604187, 1.5909584625915771, 1.5937520994776393, 1.596518259962211, 1.599257525494292, 1.6019704587814732, 1.6046576045968546, 1.6073194905426813, 1.6099566277734674, 1.6125695116811702, 1.615158622544794, 1.6177244261466233, 1.6202673743571372, 1.622787905690498, 1.6252864458323883, 1.6277634081418355, 1.6302191941285546, 1.6326541939072376], [0.0, 0.8216834971818952, 0.9117149241749759, 0.9688861611972635, 1.0116110470932034, 1.046044271030001, 1.0750465063734886, 1.1001939961166254, 1.1224527354612057, 1.1424598359090101, 1.160658789566352, 1.1773713604585165, 1.1928387845252129, 1.2072468126833034, 1.220741671443337, 1.2334406394635071, 1.2454392891067985, 1.256816584404344, 1.267638556988277, 1.2779610125490908, 1.2878315603900412, 1.2972911603136934, 1.3063753188517564, 1.315115026452673, 1.3235375004076906, 1.3316667801014173, 1.3395242086046015, 1.3471288257976295, 1.354497691914602, 1.361646155840815, 1.3685880791565486, 1.3753360244428015, 1.3819014145067825, 1.3882946677773271, 1.39452531404364, 1.4006020938797514, 1.4065330444503277, 1.4123255738862224, 1.4179865260173834, 1.423522236931851, 1.4289385845742872, 1.4342410323917258, 1.439434667867547, 1.444524236648808, 1.4495141728608063, 1.4544086261111135, 1.4592114856095824, 1.463926401767851, 1.4685568055893563, 1.4731059261168518, 1.4775768061674166, 1.4819723165536782, 1.4862951689635058, 1.4905479276479046, 1.4947330200476516, 1.4988527464727641, 1.5029092889347995, 1.5069047192198355, 1.510841006279504, 1.5147200230083693, 1.5185435524680777, 1.5223132936118466, 1.5260308665568878, 1.5296978174471396, 1.533315622944099, 1.536885694379531, 1.5404093816002933, 1.5438879765323934, 1.5473227164886474, 1.5507147872418574, 1.5540653258832742, 1.557375423484182, 1.5606461275767287, 1.5638784444686127, 1.5670733414048523, 1.570231748588672, 1.5733545610724256, 1.5764426405285048, 1.5794968169093115, 1.582517890004558, 1.5855066309034656, 1.5884637833687785, 1.5913900651289283, 1.5942861690941599, 1.5971527645019479, 1.5999904979966115, 1.6027999946476248, 1.6055818589107802, 1.6083366755360238, 1.6110650104254953, 1.613767411445028, 1.6164444091921193, 1.6190965177231602, 1.6217242352424994, 1.6243280447557344, 1.6269084146894444, 1.629465799479423, 1.6320006401293232, 1.6345133647414893, 1.6370043890216301, 1.6394741167588731, 1.6419229402826316], [0.0, 0.8261781494863427, 0.9167020531595503, 0.9741860198802091, 1.017144613167752, 1.051766188665519, 1.0809270677743588, 1.1062121156199922, 1.1285926114491949, 1.1487091517974495, 1.1670076546964094, 1.1838116442376418, 1.199363675934239, 1.2138505167704292, 1.2274191931235288, 1.2401876251722108, 1.2522519080653538, 1.2636914377715285, 1.274572607119398, 1.2849515270595415, 1.294876067320629, 1.3043874117575174, 1.3135212611245275, 1.3223087753894984, 1.3307773207237037, 1.3389510680084606, 1.3468514770622462, 1.354497691914602, 1.361906866120014, 1.3690944325229952, 1.3760743285274044, 1.3828591854322245, 1.3894604885280262, 1.3958887132330025, 1.4021534414648107, 1.4082634616088847, 1.4142268547936074, 1.4200510696727013, 1.4257429875122267, 1.431308979058962, 1.4367549544102376, 1.442086406898433, 1.4473084518357315, 1.4524258608281322, 1.4574430922558321, 1.4623643184249773, 1.4671934498196042, 1.4719341568192963, 1.476589889195261, 1.4811638936532872, 1.4856592296548248, 1.4900787837159986, 1.4944252823577537, 1.498701303857685, 1.5029092889347995, 1.5070515504819313, 1.5111302824463573, 1.5151475679469348, 1.5191053867055657, 1.5230056218616468, 1.5268500662302662, 1.5306404280580055, 1.5343783363242034, 1.5380653456302877, 1.541702940715172, 1.545292540630681, 1.548835502607406, 1.552333125638259, 1.5557866538042222, 1.5591972793643378, 1.5625661456298063, 1.5658943496401292, 1.5691829446575118, 1.5724329424942078, 1.5756453156861179, 1.5788209995247275, 1.5819608939583736, 1.585065865372842, 1.5881367482604185, 1.5911743467857071, 1.5941794362558284, 1.5971527645019477, 1.6000950531785099, 1.603006998986015, 1.6058892748227027, 1.6087425308700705, 1.6115673956167558, 1.6143644768249563, 1.6171343624432313, 1.619877621469235, 1.622594804765656, 1.6252864458323883, 1.6279530615377387, 1.6305951528112597, 1.6332132053006152, 1.6358076899947025, 1.6383790638151037, 1.6409277701777845, 1.643454239526832, 1.645958889841887, 1.6484421271208254, 1.6509043458391228], [0.0, 0.8305383671031632, 0.9215400175187468, 0.9793273602177414, 1.0225126707276686, 1.0573169642064197, 1.0866317420583955, 1.1120502336547833, 1.1345488442419813, 1.1547715511520973, 1.1731666257828939, 1.1900592996487795, 1.2056934083678967, 1.2202567046013464, 1.2338969906692616, 1.2467328090829697, 1.258860762140759, 1.2703606648294241, 1.2812992603707989, 1.2917329558452442, 1.3017098736175408, 1.3112714148934512, 1.3204534688407255, 1.3292873598762875, 1.337800598598448, 1.3460174834521768, 1.3539595875117643, 1.361646155840815, 1.3690944325229952, 1.3763199318508206, 1.383336664783852, 1.3901573292837077, 1.396793471255447, 1.4032556214020742, 1.4095534122105406, 1.415695678447649, 1.4216905438905478, 1.4275454965037924, 1.4332674538698447, 1.4388628203575806, 1.4443375372553158, 1.4496971268869066, 1.454946731560983, 1.460091148066055, 1.4651348583117585, 1.4700820566239003, 1.4749366741243917, 1.479702400563522, 1.4843827039189268, 1.4889808480311302, 1.4934999085081209, 1.497942787099831, 1.5023122247166256, 1.5066108132431546, 1.5108410062795037, 1.5150051289249746, 1.5191053867055657, 1.5231438737339522, 1.5271225801801676, 1.5310433991220191, 1.5349081328363121, 1.5387184985850286, 1.542476133944569, 1.5461826017208873, 1.549839394488719, 1.5534479387890423, 1.5570095990153352, 1.5605256810160428, 1.5639974354378794, 1.5674260608321238, 1.570812706543888, 1.574158475402382, 1.5774644262284825, 1.5807315761743588, 1.5839609029085429, 1.5871533466585916, 1.590309812122388, 1.5934311702581339, 1.596518259962211, 1.5995718896432631, 1.6025928387001525, 1.6055818589107802, 1.6085396757381767, 1.6114669895597318, 1.6143644768249563, 1.61723279114673, 1.6200725643305862, 1.6228844073462338, 1.6256689112451748, 1.6284266480279919, 1.6311581714645929, 1.6338640178704578, 1.6365447068417047, 1.6392007419515802, 1.6418326114107902, 1.6444407886939114, 1.647025733133964, 1.6495878904870753, 1.6521276934690334, 1.6546455622653988, 1.6571419050167306, 1.6596171182803798], [0.0, 0.8347726049266045, 0.9262381985451124, 0.9843201517785073, 1.0277256289687722, 1.062707361156803, 1.0921715911546195, 1.1177196709106818, 1.1403329835654745, 1.160658789566352, 1.1791476456813665, 1.196126441515189, 1.2118402558049293, 1.2264777984093933, 1.240187625172211, 1.253088882956302, 1.265278666556294, 1.2768371978705098, 1.2878315603900412, 1.298318448768952, 1.3083462307087164, 1.3179565184860822, 1.3271853842383983, 1.3360643120802447, 1.3446209528640378, 1.352879728912703, 1.3608623232840436, 1.3685880791565486, 1.3760743285274044, 1.383336664783852, 1.3903891703159095, 1.3972446078217458, 1.403914582069574, 1.4104096774498658, 1.4167395755577679, 1.4229131562013542, 1.4289385845742872, 1.434823386816148, 1.4405745157765095, 1.446198408474902, 1.4517010364894252, 1.457087950297761, 1.4623643184249775, 1.4675349621144977, 1.4726043861255598, 1.4775768061674168, 1.4824561734035653, 1.4872461963953223, 1.491950360800713, 1.4965719470999226, 1.501114046580957, 1.5055795757874044, 1.5099712896032973, 1.514291793127191, 1.5185435524680777, 1.5227289045790438, 1.5268500662302664, 1.5309091422105934, 1.5349081328363123, 1.5388489408364905, 1.5427333776762726, 1.5465631693725594, 1.5503399618504174, 1.5540653258832742, 1.5577407616552867, 1.5613677029802016, 1.564947521207427, 1.5684815288428646, 1.5719709829092556, 1.5754170880683147, 1.5788209995247278, 1.5821838257301313, 1.5855066309034658, 1.58879043738253, 1.592036227820191, 1.5952449472374588, 1.5984175049445333, 1.6015547763399216, 1.6046576045968546, 1.6077268022453919, 1.6107631526579151, 1.613767411445028, 1.6167403077683051, 1.6196825455757895, 1.6225948047656562, 1.6254777422830242, 1.6283319931544882, 1.6311581714645929, 1.6339568712781303, 1.6367286675118473, 1.6394741167588731, 1.642193758068923, 1.6448881136871119, 1.6475576897539956, 1.6502029769692683, 1.6528244512213677, 1.655422574185078, 1.657997793889074, 1.6605505452552083, 1.663081250611225, 1.665590320178459, 1.668078152535984], [0.0, 0.8388885255241149, 0.9308050983895649, 0.9891734298608729, 1.0327929216181682, 1.0679471343490432, 1.0975566403542683, 1.1232306871905562, 1.145955496795278, 1.1663815209910104, 1.1849615380560359, 1.2020240493533043, 1.2178153420024431, 1.2325250563130066, 1.2463024805964285, 1.2592673491798365, 1.2715172355923816, 1.2831327572735935, 1.2941813284756856, 1.304719923390757, 1.3147971482015375, 1.3244548203578077, 1.3337291898537988, 1.3426518960393192, 1.351250726101773, 1.3595502227805216, 1.3675721760436137, 1.3753360244428015, 1.3828591854322245, 1.3901573292837077, 1.3972446078217458, 1.4041338466721263, 1.4108367078214046, 1.4173638278473313, 1.4237249360810196, 1.4299289561132265, 1.4359840933968289, 1.4418979111797083, 1.4476773965930814, 1.4533290183947756, 1.458858777606288, 1.4642722520724243, 1.4695746358021256, 1.4747707738103841, 1.4798651930675544, 1.4848621300688194, 1.4897655554592384, 1.49457919608552, 1.4993065547920363, 1.5039509282336723, 1.5085154229403042, 1.513002969835798, 1.5174163373873866, 1.521758143538296, 1.5260308665568878, 1.530236854918804, 1.5343783363242036, 1.5384574259397839, 1.5424761339445692, 1.546436372449202, 1.5503399618504174, 1.5541886366753956, 1.5579840509645833, 1.5617277832362462, 1.5654213410713325, 1.5690661653531355, 1.5726636341926234, 1.5762150665671246, 1.5797217256972433, 1.583184822184386, 1.5866055169290774, 1.5899849238482742, 1.5933241124081425, 1.596624109987209, 1.5998859040833977, 1.6031104443772293, 1.6062986446623375, 1.609451384653461, 1.6125695116811705, 1.6156538422817774, 1.6187051636901508, 1.6217242352424996, 1.6247117896955945, 1.6276685344683566, 1.6305951528112599, 1.6334923049085495, 1.6363606289178751, 1.6392007419515804, 1.642013241003546, 1.6447987038251974, 1.6475576897539956, 1.6502907404974885, 1.6529983808757671, 1.6556811195249583, 1.6583394495641945, 1.660973849228324, 1.6635847824684595, 1.6661726995223207, 1.6687380374561815, 1.6712812206801104, 1.6738026614380754, 1.6763027602743792], [0.0, 0.8428930962561983, 0.9352484478226212, 0.9938954100115738, 1.0377231265028173, 1.073045153582236, 1.1027960053771961, 1.1285926114491949, 1.1514259016263246, 1.1719494327686635, 1.1906181445652013, 1.2077621065335398, 1.223628781484904, 1.2384087150076908, 1.252251908065354, 1.265278666556294, 1.2775870297927634, 1.289258000054743, 1.3003593134073363, 1.3109482160182102, 1.3210735460996077, 1.3307773207237035, 1.340095962929968, 1.3490612631037886, 1.3577011410792255, 1.3660402567543954, 1.3741005041153018, 1.3819014145067825, 1.3894604885280262, 1.396793471255447, 1.403914582069574, 1.4108367078214046, 1.4175715661678827, 1.424129844462191, 1.4305213184799865, 1.4367549544102376, 1.442838996875884, 1.4487810452291998, 1.4545881199556088, 1.4602667206926052, 1.4658228771085375, 1.4712621936749606, 1.476589889195261, 1.4818108318128982, 1.486929570108455, 1.4919503608007127, 1.4968771934892506, 1.5017138128114855, 1.506463738333187, 1.511130282446357, 1.515716566510398, 1.5202255354404168, 1.5246599709193753, 1.5290225033876765, 1.533315622944099, 1.5375416892751146, 1.541702940715172, 1.5458015025280598, 1.549839394488719, 1.5538185378355631, 1.5577407616552865, 1.5616078087551168, 1.5654213410713322, 1.5691829446575116, 1.5728941342912859, 1.5765563577342387, 1.5801709996759756, 1.5837393853901771, 1.5872627841276366, 1.5907424122687628, 1.5941794362558281, 1.5975749753232527, 1.6009301040424735, 1.6042458546963752, 1.607523219496864, 1.6107631526579147, 1.6139665723353038, 1.617134362443231, 1.6202673743571372, 1.6233664285112026, 1.6264323158982898, 1.6294657994794228, 1.6324676155093056, 1.6354384747838389, 1.6383790638151035, 1.6412900459388413, 1.6441720623590517, 1.647025733133964, 1.6498516581073062, 1.6526504177884944, 1.6554225741850779, 1.658168671590533, 1.6608892373302655, 1.663584782468459, 1.6662558024782308, 1.6689027778773602, 1.6715261748317065, 1.6741264457282723, 1.6767040297197382, 1.6792593532421634, 1.681792830507429, 1.6843048639719016], [0.0, 0.8467926718610781, 0.9395752978678162, 0.9984935854052241, 1.042524067223181, 1.0780095087566102, 1.1078980004212042, 1.1338139523701283, 1.1567528788868475, 1.1773713604585163, 1.1961264415151889, 1.213349718613951, 1.2292897994323768, 1.2441381111023606, 1.2580453485544802, 1.2711323742724834, 1.2834976811394394, 1.295222646185717, 1.3063753188517564, 1.3170132101499112, 1.3271853842383983, 1.3369340525779219, 1.3462958067161497, 1.3553025841140733, 1.3639824337745694, 1.372360129682746, 1.3804576671153321, 1.3882946677773271, 1.3958887132330025, 1.4032556214020742, 1.4104096774498658, 1.4173638278473313, 1.424129844462191, 1.4307184640917885, 1.4371395077386033, 1.4434019830729392, 1.4495141728608063, 1.4554837116122574, 1.4613176522924147, 1.467022524608811, 1.4726043861255596, 1.478068867242842, 1.4834212109084095, 1.488666307787787, 1.493808727505192, 1.4988527464727643, 1.5038023727476382, 1.5086613682914876, 1.5134332689530632, 1.5181214024488772, 1.5227289045790435, 1.5272587338830776, 1.531713684913168, 1.5360964002792348, 1.540409381600293, 1.5446549994797105, 1.548835502607406, 1.5529530260795263, 1.5570095990153352, 1.5610071515416974, 1.5649475212074269, 1.5688324588827058, 1.5726636341926232, 1.5764426405285048, 1.5801709996759756, 1.5838501660945694, 1.587481530880044, 1.5910664254373499, 1.5946061248893648, 1.5981018512439815, 1.6015547763399216, 1.6049660245896513, 1.6083366755360238, 1.611667766237696, 1.6149602934969602, 1.6182152159423846, 1.6214334559775174, 1.6246159016059145, 1.6277634081418355, 1.6308767998151321, 1.6339568712781303, 1.6370043890216301, 1.6400200927065578, 1.6430046964172527, 1.645958889841887, 1.6488833393850717, 1.6517786892172828, 1.6546455622653986, 1.657484561148275, 1.6602962690610068, 1.6630812506112247, 1.6658400526105348, 1.6685732048239699, 1.6712812206801102, 1.6739645979443385, 1.6766238193575105, 1.6792593532421634, 1.6818716540782308, 1.6844611630500974, 1.6870283085666933, 1.6895735067562174, 1.6920971619369674], [0.0, 0.8505930650497369, 0.9437920981318065, 1.0029748100862947, 1.0472029000659124, 1.082847599744554, 1.112870230524797, 1.138902492888935, 1.1619443689740507, 1.1826553859909699, 1.201494639578498, 1.2187952144942436, 1.2348068341634202, 1.2497217848401039, 1.2636914377715285, 1.2768371978705098, 1.2892580000547427, 1.3010355865735248, 1.312238312272194, 1.3229239462716906, 1.33314177292946, 1.3429341931506271, 1.3523379627051937, 1.3613851623890112, 1.3701039670884732, 1.3785192619739721, 1.386653141036719, 1.39452531404364, 1.4021534414648107, 1.4095534122105406, 1.4167395755577679, 1.4237249360810196, 1.4305213184799865, 1.4371395077386033, 1.4435893689358648, 1.4498799501683688, 1.4560195713750583, 1.4620159013295564, 1.46787602465059, 1.473606500350924, 1.4792134131809316, 1.4847024188099482, 1.4900787837159988, 1.4953474205138437, 1.5005129193361069, 1.5055795757874046, 1.5105514159129725, 1.5154322185581137, 1.520225535440417, 1.5249347092111378, 1.5295628897438154, 1.5341130488558472, 1.5385879936413316, 1.542990378570183, 1.5473227164886472, 1.5515873886393248, 1.555786653804222, 1.5599226566617665, 1.5639974354378794, 1.568012928921807, 1.5719709829092552, 1.5758733561282865, 1.5797217256972431, 1.5835176921585674, 1.5872627841276363, 1.5909584625915771, 1.5946061248893648, 1.5982071084012759, 1.6017626939729213, 1.6052741090965472, 1.6087425308700705, 1.612169088752304, 1.6155548671310733, 1.6189009077193401, 1.6222082117930308, 1.625477742283024, 1.6287104257326022, 1.631907154130668, 1.6350687866301192, 1.6381961511599392, 1.6412900459388415, 1.6443512408976262, 1.647380479016807, 1.6503784775855228, 1.6533459293872574, 1.6562835038174346, 1.6591918479375594, 1.662071587470196, 1.664923327738745, 1.6677476545556726, 1.6705451350625604, 1.673316318525097, 1.6760617370858928, 1.678781906477788, 1.6814773267001293, 1.6841484826603061, 1.6867958447826807, 1.6894198695868858, 1.6920210002373353, 1.694599667065652, 1.6971562880676128, 1.6996912693760893], [0.0, 0.8542996071500324, 0.9479047640932288, 1.007345370477477, 1.051766188665519, 1.087566213593613, 1.1177196709106818, 1.143865371392744, 1.1670076546964094, 1.1878089219865409, 1.2067302694558903, 1.224106233311329, 1.2401876251722108, 1.255167569198686, 1.2691980962529368, 1.282401140281507, 1.294876067320629, 1.3067049758194098, 1.3179565184860822, 1.3286887161761554, 1.3389510680084606, 1.3487861596541961, 1.3582309070502097, 1.3673175307875445, 1.3760743285274044, 1.3845262938797356, 1.3926956171124665, 1.4006020938797514, 1.4082634616088847, 1.415695678447649, 1.4229131562013542, 1.4299289561132265, 1.4367549544102376, 1.4434019830729392, 1.4498799501683688, 1.4561979432210856, 1.4623643184249773, 1.4683867779710944, 1.4742724373500795, 1.4800278841562347, 1.485659229654825, 1.4911721541603158, 1.4965719470999228, 1.5018635424956033, 1.5070515504819315, 1.5121402853820387, 1.5171337907850448, 1.5220358620029395, 1.5268500662302664, 1.5315797606842092, 1.536228108964188, 1.540798095837584, 1.5452925406306812, 1.5497141093805054, 1.5540653258832742, 1.5583485817580849, 1.5625661456298063, 1.5667201715225108, 1.570812706543888, 1.5748456979316465, 1.5788209995247275, 1.5827403777150215, 1.5866055169290771, 1.590418024683857, 1.5941794362558281, 1.597891218998511, 1.6015547763399216, 1.6051714514881015, 1.6087425308700705, 1.6122692473269922, 1.6157527830861018, 1.6191942725279393, 1.6225948047656562, 1.6259554260515787, 1.6292771420247913, 1.6325609198122377, 1.6358076899947027, 1.6390183484480179, 1.6421937580689228, 1.6453347503941822, 1.6484421271208256, 1.6515166615347012, 1.6545590998539328, 1.6575701624933168, 1.660550545255208, 1.6635009204519864, 1.66642193796479, 1.6693142262428304, 1.672178393247264, 1.6750150273432916, 1.6778246981438694, 1.6806079573081645, 1.6833653392976509, 1.6860973620925248, 1.688804527870929, 1.6914873236532837, 1.694146221913871, 1.6967816811616527, 1.6993941464921747, 1.7019840501122718, 1.704551811839178, 1.7070978395755287], [0.0, 0.857917200444095, 0.951918735174678, 1.0116110470932036, 1.0562199684392581, 1.0921715911546193, 1.1224527354612057, 1.1487091517974495, 1.1719494327686637, 1.1928387845252129, 1.2118402558049293, 1.2292897994323768, 1.2454392891067987, 1.2604826667865288, 1.2745726071193983, 1.2878315603900414, 1.3003593134073366, 1.3122383122721941, 1.3235375004076904, 1.3343151443628316, 1.3446209528640376, 1.354497691914602, 1.3639824337745694, 1.3731075354753992, 1.381901414506783, 1.3903891703159095, 1.398593087136998, 1.4065330444503277, 1.4142268547936074, 1.4216905438905478, 1.4289385845742872, 1.4359840933968289, 1.442838996875884, 1.4495141728608063, 1.4560195713750583, 1.4623643184249773, 1.4685568055893563, 1.4746047676747296, 1.4805153503027977, 1.486295168963506, 1.491950360800713, 1.4974866301825853, 1.5029092889347997, 1.5082232919727854, 1.5134332689530634, 1.518543552468078, 1.5235582032298183, 1.5284810326217966, 1.5333156229440992, 1.538065345630288, 1.5427333776762726, 1.5473227164886474, 1.5518361933323366, 1.5562764855338922, 1.5606461275767287, 1.564947521207427, 1.5691829446575118, 1.5733545610724256, 1.5774644262284827, 1.581514495609111, 1.5855066309034656, 1.5894426059833513, 1.5933241124081423, 1.5971527645019479, 1.6009301040424737, 1.6046576045968546, 1.608336675536024, 1.6119686657559342, 1.6155548671310735, 1.6190965177231602, 1.6225948047656562, 1.6260508674427172, 1.629465799479423, 1.6328406515585312, 1.636176433577577, 1.6394741167588731, 1.6427346356238157, 1.645958889841887, 1.6491477459638257, 1.6523020390475982, 1.655422574185078, 1.6585101279366485, 1.6615654496803476, 1.6645892628816201, 1.667582266289246, 1.6705451350625606, 1.6734785218346706, 1.676383057716001, 1.6792593532421634, 1.6821079992698336, 1.684929567824035, 1.6877246128999754, 1.6904936712223442, 1.693237262964762, 1.6959558924318814, 1.6986500487064455, 1.7013202062634631, 1.703966825553485, 1.7065903535568463, 1.7091912243105931, 1.7117698594097053, 1.7143266684841116], [0.0, 0.8614503635338218, 0.9558390250788756, 1.0157771680322631, 1.0605698024386119, 1.0966694848342402, 1.127075336072129, 1.1534398842898872, 1.1767758757829092, 1.1977512562221289, 1.2168309813204436, 1.2343523874579856, 1.2505683856262413, 1.2656737164953178, 1.2798216834735265, 1.2931352411328916, 1.3057145872346185, 1.3176425074176528, 1.3289882290349857, 1.3398102585949345, 1.3501585095395225, 1.3600759239954083, 1.3695997268974411, 1.3787624085331442, 1.3875925034240457, 1.3961152143844666, 1.4043529174218572, 1.4123255738862224, 1.4200510696727013, 1.4275454965037924, 1.434823386816148, 1.4418979111797083, 1.4487810452291998, 1.4554837116122574, 1.4620159013295564, 1.4683867779710944, 1.4746047676747296, 1.480677637101274, 1.4866125613002645, 1.4924161830062397, 1.4980946646376765, 1.5036537340550589, 1.5090987249597718, 1.5144346126730883, 1.5196660459178586, 1.5247973751294552, 1.5298326777431113, 1.5347757808387705, 1.5396302814695177, 1.5443995649534996, 1.5490868213704587, 1.5536950604712176, 1.5582271251807083, 1.5626857038515245, 1.567073341404852, 1.5713924494783924, 1.5756453156861179, 1.57983411208196, 1.5839609029085429, 1.5880276517025678, 1.5920362278201907, 1.5959884124385575, 1.5998859040833973, 1.6037303237270948, 1.607523219496864, 1.6112660710284359, 1.6149602934969602, 1.6186072413535524, 1.6222082117930308, 1.6257644479758273, 1.6292771420247913, 1.6327474378155842, 1.6361764335775768, 1.6395651843205572, 1.6429147041011247, 1.64622596814138, 1.6494999148113614, 1.6527374474856629, 1.6559394362837416, 1.659106719702586, 1.662240106149682, 1.665340375383524, 1.6684082798683155, 1.6714445460489518, 1.674449875551872, 1.6774249463169222, 1.68037041366495, 1.6832869113054842, 1.6861750522885077, 1.689035429904023, 1.6918686185328256, 1.6946751744516437, 1.6974556365955618, 1.700210527280433, 1.7029403528877893, 1.705645604514565, 1.7083267585898005, 1.710984277460322, 1.7136186099472643, 1.7162301918751706, 1.7188194465752762, 1.72138678536449], [0.0, 0.8649032708248208, 0.9596702655988486, 1.0198486555352007, 1.064820829959723, 1.1010652088600177, 1.1315929343112943, 1.1580631581949046, 1.1814926861452546, 1.2025521411256388, 1.2217083425070814, 1.2392999787978185, 1.2555809747194864, 1.2707468515112286, 1.2849515270595417, 1.298318448768952, 1.3109482160182102, 1.3229239462716906, 1.3343151443628316, 1.3451805513085855, 1.3555702806164642, 1.3655274465358496, 1.3750894232083868, 1.3842888311507517, 1.3931543192579308, 1.4017111913633926, 1.40998191316319, 1.4179865260173834, 1.4257429875122267, 1.4332674538698447, 1.4405745157765095, 1.4476773965930814, 1.4545881199556088, 1.4613176522924147, 1.46787602465059, 1.4742724373500795, 1.4805153503027977, 1.4866125613002645, 1.4925712741514001, 1.4983981582164745, 1.5040994006144708, 1.5096807521645623, 1.5151475679469353, 1.5205048432251878, 1.5257572453554074, 1.5309091422105936, 1.5359646275693537, 1.54092754385152, 1.54580150252806, 1.5505899024863183, 1.5552959465926695, 1.5599226566617665, 1.5644728870136912, 1.5689493367766234, 1.5733545610724256, 1.5776909812052429, 1.5819608939583736, 1.5861664800918813, 1.5903098121223882, 1.5943928614569387, 1.598417504944533, 1.6023855309017185, 1.6062986446623375, 1.610158473696035, 1.613966572335304, 1.6177244261466237, 1.6214334559775174, 1.6250950217080777, 1.6287104257326024, 1.6322809161944194, 1.635807689994703, 1.6392918955940525, 1.6427346356238157, 1.6461369693225218, 1.6494999148113616, 1.6528244512213677, 1.6561115206837997, 1.6593620301942014, 1.6625768533596847, 1.665756832038143, 1.6689027778773606, 1.6720154737612973, 1.6750956751702206, 1.6781441114607973, 1.6811614870717602, 1.6841484826603066, 1.6871057561739728, 1.690033943862354, 1.6929336612326886, 1.6958055039530338, 1.6986500487064458, 1.7014678539993486, 1.704259460927012, 1.7070253938988618, 1.7097661613261321, 1.7124822562741966, 1.7151741570817414, 1.7178423279487935, 1.7204872194954757, 1.7231092692932228, 1.7257089023700878, 1.7282865316916398], [0.0, 0.8682797870246687, 0.9634167448961425, 1.0238300666628564, 1.0689778090157345, 1.1053636831983784, 1.1360105865542922, 1.1625841481668389, 1.1861051432018301, 1.2072468126833036, 1.2264777984093935, 1.2441381111023608, 1.260482666786529, 1.2757077500010003, 1.2899678795159248, 1.3033869846650519, 1.3160660575594105, 1.3280885401475968, 1.3395242086046018, 1.3504320332678135, 1.3608623232840438, 1.3708583612174048, 1.3804576671153324, 1.3896929888425034, 1.3985930871369983, 1.4071833646165162, 1.4154863746814683, 1.423522236931851, 1.431308979058962, 1.4388628203575806, 1.446198408474902, 1.4533290183947756, 1.4602667206926052, 1.467022524608811, 1.473606500350924, 1.4800278841562347, 1.486295168963506, 1.4924161830062397, 1.4983981582164745, 1.504247789991153, 1.5099712896032973, 1.515574430322839, 1.5210625881357873, 1.5264407778068676, 1.5317136849131683, 1.5368856943795313, 1.5419609159663619, 1.5469432070940057, 1.5518361933323366, 1.5566432868376952, 1.5613677029802016, 1.5660124753714417, 1.5705804694745449, 1.5750743949548804, 1.5794968169093118, 1.5838501660945696, 1.5881367482604187, 1.592358752680443, 1.5965182599622112, 1.6006172492089903, 1.6046576045968546, 1.608641121423803, 1.6125695116811705, 1.6164444091921193, 1.6202673743571372, 1.6240398985422415, 1.6277634081418357, 1.6314392683448797, 1.6350687866301197, 1.6386532160135392, 1.642193758068923, 1.6456915657403732, 1.6491477459638257, 1.652563362112996, 1.6559394362837419, 1.659276951429549, 1.6625768533596847, 1.6658400526105348, 1.669067426199706, 1.6722598192716407, 1.675418046642734, 1.6785428942532645, 1.6816351205328373, 1.6846954576854718, 1.6877246128999754, 1.6907232694907792, 1.6936920879739967, 1.696631707083092, 1.6995427447281977, 1.7024257989028124, 1.70528144854132, 1.7081102543305098, 1.7109127594780469, 1.713689490440611, 1.716440957614235, 1.7191676559891815, 1.7218700657715351, 1.7245486529735239, 1.7272038699744567, 1.7298361560540143, 1.7324459378995263, 1.7350336300887481], [0.0, 0.8715834973956161, 0.9670824410682997, 1.0277256289687722, 1.073045153582236, 1.109569472067845, 1.1403329835654745, 1.1670076546964094, 1.1906181445652013, 1.2118402558049293, 1.2311444133449163, 1.2488719216113264, 1.265278666556294, 1.2805616795602939, 1.2948760673206292, 1.3083462307087164, 1.3210735460996077, 1.33314177292946, 1.3446209528640376, 1.3555702806164642, 1.3660402567543957, 1.3760743285274042, 1.3857101587426346, 1.394980619866835, 1.4039145820695742, 1.4125375446227544, 1.4208721467400283, 1.4289385845742872, 1.4367549544102376, 1.4443375372553158, 1.4517010364894252, 1.458858777606288, 1.4658228771085375, 1.4726043861255596, 1.4792134131809316, 1.485659229654825, 1.491950360800713, 1.4980946646376765, 1.5040994006144708, 1.5099712896032973, 1.5157165665103982, 1.5213410265723701, 1.5268500662302664, 1.5322487193294478, 1.5375416892751148, 1.5427333776762726, 1.5478279099305192, 1.552829158135266, 1.5577407616552867, 1.5625661456298061, 1.5673085376630795, 1.5719709829092552, 1.576556357734239, 1.581067382113383, 1.5855066309034656, 1.5898765441099831, 1.5941794362558281, 1.598417504944533, 1.6025928387001525, 1.6067074241562262, 1.610763152657915, 1.6147618263341308, 1.6187051636901506, 1.622594804765656, 1.6264323158982898, 1.6302191941285546, 1.6339568712781303, 1.6376467177303724, 1.6412900459388415, 1.6448881136871116, 1.6484421271208254, 1.6519532435709119, 1.6554225741850779, 1.6588511863830608, 1.662240106149682, 1.665590320178459, 1.6689027778773604, 1.672178393247264, 1.6754180466427337, 1.6786225864238944, 1.6817928305074292, 1.6849295678240348, 1.688033559689058, 1.6911055410924756, 1.694146221913871, 1.697156288067613, 1.7001364025830068, 1.7030872066238287, 1.7060093204512916, 1.7089033443341952, 1.7117698594097053, 1.714609428497964, 1.7174225968734824, 1.7202098929960505, 1.7229718292037033, 1.7257089023700876, 1.7284215945284194, 1.7311103734640532, 1.7337756932775517, 1.7364179949200076, 1.7390377067022496, 1.7416352447794559], [0.0, 0.8748177343763873, 0.9706710516875963, 1.031539271890224, 1.077026966372546, 1.1136868178299202, 1.1445644853284853, 1.1713381397560054, 1.1950362424808187, 1.2163371038772288, 1.235712894508463, 1.2535061852994203, 1.2699738117335322, 1.2853135363273944, 1.2996810413420028, 1.3132011892705235, 1.3259757326713832, 1.3380887417918845, 1.3496105182055882, 1.3606004762829778, 1.371109303987184, 1.3811806097900854, 1.3908521962564557, 1.4001570578348714, 1.4091241718251641, 1.417779132120909, 1.426144661944442, 1.4342410323917258, 1.442086406898433, 1.4496971268869066, 1.457087950297761, 1.4642722520724243, 1.4712621936749606, 1.478068867242842, 1.4847024188099482, 1.4911721541603158, 1.4974866301825853, 1.5036537340550589, 1.5096807521645623, 1.515574430322839, 1.5213410265723701, 1.5269863576544838, 1.5325158400351293, 1.5379345262390585, 1.5432471371246785, 1.5484580906343084, 1.5535715274739053, 1.5585913341093038, 1.5635211634100865, 1.5683644532253471, 1.5731244431362044, 1.5778041895966424, 1.58240657964607, 1.586934343353014, 1.5913900651289283, 1.5957761940335833, 1.6000950531785099, 1.6043488483220192, 1.608539675738177, 1.612669529432443, 1.616740307768305, 1.620753819561943, 1.6247117896955943, 1.6286158642947333, 1.6324676155093056, 1.6362685459349717, 1.6400200927065578, 1.6437236312925827, 1.647380479016807, 1.6509918983301373, 1.6545590998539328, 1.6580832452136998, 1.6615654496803476, 1.665006784634551, 1.6684082798683157, 1.6717709257365407, 1.6750956751702204, 1.6783834455618698, 1.6816351205328373, 1.6848515515913083, 1.6880335596890583, 1.6911819366843162, 1.6942974467174872, 1.6973808275059192, 1.7004327915633886, 1.7034540273495273, 1.7064452003539834, 1.7094069541197372, 1.7123399112096427, 1.7152446741199525, 1.7181218261442928, 1.7209719321912964, 1.7237955395588567, 1.7265931786677513, 1.7293653637571784, 1.7321125935445636, 1.7348353518518327, 1.7375341082001787, 1.740209318375223, 1.7428614249643213, 1.7454908578676611, 1.7480980347846726], [0.0, 0.877985601086042, 0.9741860198802091, 1.0352746544627458, 1.0809270677743588, 1.1177196709106818, 1.1487091517974495, 1.175579758270206, 1.199363675934239, 1.220741671443337, 1.2401876251722108, 1.2580453485544802, 1.2745726071193981, 1.2899678795159246, 1.3043874117575176, 1.3179565184860824, 1.3307773207237035, 1.3429341931506273, 1.3544976919146021, 1.3655274465358496, 1.3760743285274044, 1.3861821042749836, 1.3958887132330027, 1.4052272693286576, 1.4142268547936077, 1.4229131562013544, 1.431308979058962, 1.439434667867547, 1.4473084518357315, 1.454946731560983, 1.4623643184249775, 1.4695746358021256, 1.476589889195261, 1.4834212109084095, 1.4900787837159988, 1.4965719470999228, 1.5029092889347997, 1.5090987249597718, 1.5151475679469353, 1.5210625881357873, 1.5268500662302664, 1.5325158400351293, 1.5380653456302882, 1.5435036538365623, 1.5488355026074063, 1.5540653258832744, 1.5591972793643378, 1.564235263589998, 1.5691829446575118, 1.5740437728650205, 1.5788209995247275, 1.5835176921585674, 1.5881367482604187, 1.5926809077848605, 1.5971527645019479, 1.6015547763399218, 1.6058892748227027, 1.610158473696035, 1.6143644768249565, 1.6185092854355665, 1.6225948047656562, 1.6266228501814424, 1.6305951528112599, 1.6345133647414893, 1.6383790638151037, 1.6421937580689228, 1.6459588898418873, 1.6496758395833262, 1.6533459293872577, 1.656970426276142, 1.660550545255208, 1.66408745215641, 1.667582266289246, 1.6710360629140466, 1.6744498755518722, 1.6778246981438691, 1.6811614870717602, 1.6844611630500974, 1.6877246128999754, 1.6909526912130386, 1.694146221913871, 1.6973059997281577, 1.7004327915633886, 1.703527337808314, 1.7065903535568463, 1.7096225297616492, 1.712624534322224, 1.7155970131119322, 1.7185405909480354, 1.7214558725085294, 1.7243434431992484, 1.7272038699744567, 1.7300377021139088, 1.7328454719591277, 1.7356276956114607, 1.738384873594276, 1.7411174914815022, 1.7438260204945502, 1.74651091806952, 1.7491726283964528, 1.7518115829322796, 1.7544282008889924], [0.0, 0.8810899921399995, 0.977630557423041, 1.038935189865294, 1.0847490214772766, 1.1216717163006238, 1.1527707701315408, 1.1797363859874186, 1.2036043990866534, 1.225057983145185, 1.2445726940891169, 1.262493559004281, 1.2790792548300969, 1.294528961998494, 1.3089994789792876, 1.3226165635032583, 1.3354826976731138, 1.3476825545020135, 1.359286939610902, 1.3703556933587084, 1.380939867130517, 1.3910833820617083, 1.4008243117534347, 1.410195887217476, 1.4192272935147632, 1.4279443080416645, 1.4363698169412045, 1.444524236648808, 1.4524258608281322, 1.460091148066055, 1.4675349621144977, 1.4747707738103841, 1.4818108318128982, 1.488666307787787, 1.4953474205138437, 1.5018635424956033, 1.5082232919727854, 1.5144346126730883, 1.5205048432251878, 1.5264407778068676, 1.5322487193294478, 1.5379345262390585, 1.5435036538365623, 1.5489611908722425, 1.5543118920520609, 1.5595602069940466, 1.564710306092141, 1.5697661036773152, 1.5747312788094523, 1.5796092939862956, 1.584403412016074, 1.589116711266899, 1.5937520994776395, 1.5983123262908363, 1.6027999946476248, 1.6072175711670154, 1.6115673956167558, 1.6158516895699775, 1.6200725643305864, 1.6242320282006395, 1.6283319931544882, 1.632374280977141, 1.6363606289178751, 1.6402926949045362, 1.644172062359052, 1.6480002446503748, 1.651778689217283, 1.6555087813901137, 1.6591918479375596, 1.6628291603620324, 1.6664219379647902, 1.6699713506999478, 1.6734785218346706, 1.6769445304312063, 1.6803704136649502, 1.6837571689914366, 1.687105756173973, 1.6904170991825842, 1.6936920879739967, 1.6969315801615292, 1.700136402583007, 1.7033073527741152, 1.7064452003539834, 1.7095506883292366, 1.7126245343222242, 1.7156674317286875, 1.7186800508096944, 1.7216630397222923, 1.7246170254929785, 1.7275426149377762, 1.7304403955324035, 1.733310936235768, 1.7361547882697732, 1.7389724858582014, 1.7417645469272367, 1.7445314737700028, 1.7472737536773266, 1.7499918595367683, 1.7526862504018355, 1.7553573720331417, 1.7580056574131675, 1.7606315272361597], [0.0, 0.884133612140456, 0.9810076652601226, 1.0425240672231812, 1.0884961572371834, 1.1255463970938844, 1.1567528788868477, 1.1838116442376416, 1.2077621065335398, 1.2292897994323768, 1.2488719216113264, 1.2668546920110244, 1.2834976811394396, 1.299000757473482, 1.313521261124528, 1.3271853842383985, 1.340095962929968, 1.3523379627051937, 1.3639824337745694, 1.3750894232083868, 1.3857101587426346, 1.3958887132330027, 1.4056632918013445, 1.4150672402519962, 1.4241298444621913, 1.4328769708732305, 1.4413315846855823, 1.4495141728608063, 1.4574430922558321, 1.4651348583117585, 1.4726043861255598, 1.4798651930675544, 1.486929570108455, 1.493808727505192, 1.5005129193361069, 1.5070515504819315, 1.5134332689530634, 1.5196660459178586, 1.5257572453554074, 1.5317136849131683, 1.5375416892751148, 1.5432471371246785, 1.5488355026074063, 1.5543118920520609, 1.559681076589167, 1.564947521207427, 1.5701154107069097, 1.575188672940174, 1.5801709996759756, 1.5850658653728422, 1.5898765441099831, 1.5946061248893646, 1.5992575254942922, 1.603833505065617, 1.6083366755360238, 1.6127695120451633, 1.6171343624432313, 1.6214334559775174, 1.625668911245175, 1.6298427434856997, 1.63395687127813, 1.6380131227006134, 1.6420132410035457, 1.645958889841887, 1.6498516581073064, 1.6536930643965082, 1.6574845611482751, 1.6612275384784019, 1.6649233277387452, 1.6685732048239699, 1.672178393247264, 1.6757400670042095, 1.6792593532421634, 1.682737334750865, 1.686175052288508, 1.6895735067562174, 1.6929336612326886, 1.6962564428796902, 1.6995427447281977, 1.7027934273540521, 1.7060093204512918, 1.709191224310593, 1.712339911209643, 1.7154561267216935, 1.7185405909480354, 1.721593999679662, 1.7246170254929785, 1.7276103187840126, 1.7305745087452502, 1.7335102042888877, 1.7364179949200076, 1.7392984515629184, 1.7421521273436535, 1.7449795583314076, 1.7477812642414783, 1.7505577491021016, 1.7533095018873914, 1.7560369971184422, 1.7587406954345066, 1.761421044136025, 1.764078477701164, 1.7667134182774087], [0.0, 0.8871189921475423, 0.9843201517785072, 1.046044271030001, 1.0921715911546193, 1.1293469354568555, 1.160658789566352, 1.1878089219865409, 1.2118402558049293, 1.2334406394635071, 1.2530888829563018, 1.2711323742724834, 1.2878315603900414, 1.3033869846650517, 1.3179565184860824, 1.3316667801014175, 1.3446209528640376, 1.356904289175816, 1.3685880791565486, 1.3797325726324468, 1.3903891703159095, 1.4006020938797517, 1.4104096774498658, 1.419845379426576, 1.4289385845742875, 1.4377152466753493, 1.4461984084749018, 1.4544086261111135, 1.4623643184249773, 1.4700820566239003, 1.4775768061674168, 1.4848621300688194, 1.4919503608007127, 1.4988527464727643, 1.5055795757874046, 1.5121402853820387, 1.518543552468078, 1.5247973751294552, 1.5309091422105936, 1.5368856943795313, 1.5427333776762726, 1.5484580906343084, 1.5540653258832744, 1.5595602069940466, 1.564947521207427, 1.5702317485886723, 1.5754170880683147, 1.5805074807617652, 1.5855066309034656, 1.590418024683857, 1.5952449472374588, 1.5999904979966113, 1.6046576045968546, 1.6092490354956006, 1.613767411445028, 1.6182152159423846, 1.622594804765656, 1.6269084146894446, 1.631158171464593, 1.6353460971352878, 1.6394741167588731, 1.6435440645862143, 1.6475576897539956, 1.6515166615347012, 1.6554225741850779, 1.659276951429549, 1.6630812506112247, 1.6668368665397884, 1.6705451350625606, 1.6742073363824133, 1.6778246981438694, 1.6813983983066427, 1.684929567824035, 1.688419293141951, 1.6918686185328258, 1.6952785482774433, 1.6986500487064458, 1.7019840501122718, 1.70528144854132, 1.7085431074752655, 1.7117698594097055, 1.7149625073375903, 1.718121826144293, 1.7212485639205803, 1.7243434431992484, 1.7274071621207103, 1.7304403955324033, 1.7334437960264935, 1.7364179949200076, 1.7393636031812056, 1.7422812123057023, 1.7451713951455983, 1.7480347066946218, 1.7508716848320671, 1.7536828510281115, 1.7564687110129005, 1.759229755411626, 1.7619664603476586, 1.7646792880156525, 1.7673686872264103, 1.7700350939251646, 1.7726789316848306], [0.0, 0.890048504391361, 0.9875706491322973, 1.0494985984952947, 1.0957782437874222, 1.1330763513573434, 1.1644916058683674, 1.1917313955341458, 1.2158420874626403, 1.2375138015616203, 1.2572269289881277, 1.2753300049025424, 1.2920843363508014, 1.3076911289386026, 1.3223087753894984, 1.3360643120802445, 1.3490612631037886, 1.3613851623890112, 1.373107535475399, 1.3842888311507515, 1.394980619866835, 1.4052272693286572, 1.415067240251996, 1.424534101526066, 1.4336573349518906, 1.4424629800183864, 1.4509741555642097, 1.4592114856095824, 1.4671934498196042, 1.4749366741243917, 1.4824561734035653, 1.4897655554592384, 1.4968771934892506, 1.5038023727476382, 1.5105514159129725, 1.5171337907850448, 1.5235582032298183, 1.5298326777431113, 1.5359646275693537, 1.5419609159663619, 1.5478279099305192, 1.5535715274739053, 1.5591972793643378, 1.564710306092141, 1.5701154107069097, 1.5754170880683147, 1.5806195509729186, 1.5857267535507853, 1.5907424122687628, 1.5956700248296576, 1.6005128872164112, 1.605274109096547, 1.6099566277734674, 1.614563220846796, 1.61909651772316, 1.6235590101010025, 1.6279530615377384, 1.6322809161944192, 1.6365447068417047, 1.6407464622011303, 1.6448881136871116, 1.648971501607718, 1.652998380875767, 1.6569704262761418, 1.6608892373302655, 1.6647563427943213, 1.6685732048239696, 1.6723412228349408, 1.6760617370858928, 1.6797360320072812, 1.6833653392976506, 1.6869508408066642, 1.690493671222344, 1.6939949205783393, 1.6974556365955618, 1.700876826871208, 1.7042594609270119, 1.7076044721274943, 1.7109127594780467, 1.7141851893118003, 1.7174225968734824, 1.7206257878077482, 1.7237955395588567, 1.726932602687977, 1.7300377021139086, 1.7331115382825173, 1.7361547882697728, 1.7391681068228815, 1.7421521273436535, 1.7451074628179344, 1.7480347066946218, 1.7509344337175319, 1.7538072007131358, 1.756653547336954, 1.7594739967812025, 1.7622690564460877, 1.7650392185769816, 1.7677849608695453, 1.7705067470447284, 1.7732050273954305, 1.7758802393064959, 1.7785328077495945], [0.0, 0.8929243754466416, 0.9907616278608403, 1.0528896750794121, 1.0993188563706313, 1.1367374793365652, 1.1682542409235481, 1.1955820461550684, 1.2197706430973885, 1.2415123815321076, 1.2612892048272055, 1.279450774308855, 1.2962592413425622, 1.3119164616574455, 1.3265813397660733, 1.3403813225174819, 1.353420268505425, 1.3657839880308569, 1.3775442377422735, 1.3887616617459526, 1.3994879971249945, 1.4097677549426597, 1.4196395201866716, 1.4291369702120154, 1.4382896820795321, 1.4471237794153646, 1.4556624557583668, 1.463926401767851, 1.4719341568192963, 1.479702400563522, 1.4872461963953223, 1.49457919608552, 1.5017138128114855, 1.5086613682914876, 1.5154322185581137, 1.5220358620029395, 1.5284810326217966, 1.5347757808387705, 1.54092754385152, 1.5469432070940057, 1.552829158135266, 1.5585913341093038, 1.564235263589998, 1.5697661036773152, 1.575188672940174, 1.5805074807617652, 1.5857267535507853, 1.5908504582136445, 1.595882323225615, 1.6008258575910694, 1.6056843679427306, 1.6104609739958922, 1.615158622544794, 1.6197801001638723, 1.6243280447557344, 1.6288049560698488, 1.6332132053006152, 1.6375550438602822, 1.6418326114107902, 1.646047943228757, 1.650202976969268, 1.6542995588866853, 1.6583394495641943, 1.6623243291981429, 1.6662558024782308, 1.670135403100266, 1.6739645979443385, 1.677744790947886, 1.6814773267001295, 1.6851634937816988, 1.688804527870929, 1.6924016146362038, 1.6959558924318814, 1.6994684548136618, 1.7029403528877893, 1.7063725975071482, 1.7097661613261321, 1.713121980725093, 1.7164409576142348, 1.7197239611259316, 1.7229718292037033, 1.7261853700953558, 1.7293653637571784, 1.7325125631755092, 1.7356276956114607, 1.7387114637741374, 1.7417645469272365, 1.7447876019335433, 1.7477812642414783, 1.7507461488175298, 1.7536828510281115, 1.7565919474741174, 1.7594739967812028, 1.7623295403485901, 1.7651591030590028, 1.767963193952128, 1.770742306863852, 1.7734969210333364, 1.7762275016798783, 1.7789345005513366, 1.7816183564458072, 1.7842794957081027], [0.0, 0.8957486980597117, 0.9938954100115738, 1.0562199684392584, 1.1027960053771964, 1.1403329835654743, 1.1719494327686637, 1.199363675934239, 1.223628781484904, 1.2454392891067985, 1.265278666556294, 1.2834976811394396, 1.3003593134073366, 1.3160660575594103, 1.3307773207237037, 1.3446209528640376, 1.3577011410792255, 1.3701039670884732, 1.3819014145067827, 1.3931543192579305, 1.4039145820695742, 1.4142268547936072, 1.424129844462191, 1.4336573349518906, 1.442838996875884, 1.4517010364894254, 1.460266720692605, 1.4685568055893563, 1.476589889195261, 1.4843827039189268, 1.491950360800713, 1.4993065547920363, 1.506463738333187, 1.5134332689530632, 1.520225535440417, 1.5268500662302664, 1.5333156229440992, 1.5396302814695177, 1.54580150252806, 1.5518361933323366, 1.5577407616552867, 1.5635211634100865, 1.5691829446575118, 1.5747312788094523, 1.5801709996759756, 1.5855066309034656, 1.5907424122687628, 1.595882323225615, 1.6009301040424735, 1.6058892748227025, 1.610763152657915, 1.6155548671310733, 1.6202673743571372, 1.6249034697244864, 1.6294657994794228, 1.63395687127813, 1.6383790638151035, 1.6427346356238155, 1.647025733133964, 1.6512543980597534, 1.6554225741850779, 1.6595321136040078, 1.6635847824684593, 1.6675822662892459, 1.6715261748317065, 1.6754180466427335, 1.6792593532421634, 1.6830515030080921, 1.6867958447826807, 1.690493671222344, 1.694146221913871, 1.6977546862759185, 1.701320206263463, 1.7048438788911249, 1.7083267585898005, 1.7117698594097053, 1.7151741570817411, 1.7185405909480351, 1.721870065771535, 1.725163453433684, 1.7284215945284194, 1.7316452998600376, 1.7348353518518327, 1.7379925058718402, 1.741117491481502, 1.7442110136125941, 1.7472737536773262, 1.7503063706161435, 1.7533095018873912, 1.756283764402699, 1.759229755411626, 1.762148053338857, 1.7650392185769816, 1.7679037942376703, 1.7707423068638517, 1.7735552671053074, 1.7763431703599277, 1.77910649738271, 1.7818457148644407, 1.784561275981859, 1.7872536209209804, 1.7899231773751476], [0.0, 0.8985234417906397, 0.9969741809482231, 1.0594918009769512, 1.1062121156199922, 1.143865371392744, 1.175579758270206, 1.2030789220162148, 1.2274191931235285, 1.2492972627406829, 1.2691980962529366, 1.2874735475315613, 1.3043874117575174, 1.3201428103926662, 1.3348996443574839, 1.3487861596541963, 1.361906866120014, 1.37434811212785, 1.3861821042749833, 1.3974698669354764, 1.4082634616088847, 1.418607678464296, 1.4285413444359099, 1.438098348051964, 1.4473084518357315, 1.4561979432210856, 1.464790161181552, 1.4731059261168518, 1.4811638936532872, 1.4889808480311302, 1.4965719470999226, 1.5039509282336723, 1.511130282446357, 1.5181214024488772, 1.5249347092111378, 1.5315797606842092, 1.538065345630288, 1.5443995649534996, 1.5505899024863183, 1.5566432868376952, 1.5625661456298061, 1.5683644532253471, 1.5740437728650205, 1.5796092939862956, 1.5850658653728422, 1.590418024683857, 1.5956700248296576, 1.6008258575910694, 1.6058892748227025, 1.6108638075320785, 1.6157527830861016, 1.6205593407621848, 1.6252864458323883, 1.6299369023443133, 1.634513364741489, 1.6390183484480179, 1.6434542395268317, 1.6478233035076195, 1.6521276934690334, 1.656369457449857, 1.6605505452552078, 1.664672814716352, 1.668738037456181, 1.6727479042066837, 1.6767040297197382, 1.680607957308164, 1.6844611630500972, 1.6882650596863396, 1.692021000237335, 1.6957302813637356, 1.6993941464921745, 1.7030137887257486, 1.706590353556846, 1.710124941398289, 1.7136186099472643, 1.7170723763951914, 1.7204872194954755, 1.7238640815000252, 1.7272038699744563, 1.730507459501022, 1.7337756932775517, 1.7370093846199546, 1.7402093183752227, 1.743376252251281, 1.7465109180695197, 1.7496140229453685, 1.7526862504018352, 1.7557282614205518, 1.7587406954345064, 1.7617241712663239, 1.7646792880156523, 1.7676066258989513, 1.7705067470447284, 1.7733801962470404, 1.776227501679878, 1.7790491755748532, 1.7818457148644407, 1.7846176017928632, 1.7873653044965672, 1.790089277556088, 1.7927899625209973, 1.7954677884094954], [0.0, 0.9012504626108302, 0.9999999999999999, 1.062707361156803, 1.1095694720678448, 1.147337005562985, 1.1791476456813665, 1.2067302694558903, 1.2311444133449163, 1.2530888829563018, 1.2730501155464236, 1.291381032863904, 1.3083462307087161, 1.3241494470168496, 1.3389510680084606, 1.3528797289127028, 1.3660402567543954, 1.3785192619739721, 1.3903891703159093, 1.4017111913633924, 1.4125375446227544, 1.422913156201354, 1.4328769708732303, 1.4424629800183864, 1.4517010364894252, 1.460617507502646, 1.4692358028654147, 1.4775768061674166, 1.4856592296548248, 1.4934999085081209, 1.501114046580957, 1.5085154229403042, 1.515716566510398, 1.5227289045790435, 1.5295628897438154, 1.536228108964188, 1.5427333776762726, 1.5490868213704587, 1.5552959465926695, 1.5613677029802016, 1.5673085376630795, 1.5731244431362044, 1.5788209995247275, 1.584403412016074, 1.5898765441099831, 1.5952449472374588, 1.6005128872164112, 1.6056843679427306, 1.610763152657915, 1.6157527830861016, 1.6206565966927624, 1.6254777422830238, 1.6302191941285546, 1.6348837647872472, 1.639474116758873, 1.6439927731018527, 1.6484421271208252, 1.6528244512213675, 1.6571419050167306, 1.661396542761501, 1.6655903201784588, 1.6697251007373932, 1.6738026614380752, 1.6778246981438691, 1.681792830507429, 1.6857086065255331, 1.6895735067562174, 1.693388948227956, 1.697156288067613, 1.700876826871208, 1.704551811839178, 1.7081824396956902, 1.7117698594097053, 1.7153151747338005, 1.7188194465752762, 1.7222836952127305, 1.7257089023700876, 1.729096013158993, 1.732445937899526, 1.7357595538282993, 1.7390377067022496, 1.742281212305702, 1.745490857867661, 1.7486674033956966, 1.7518115829322793, 1.7549241057389358, 1.7580056574131673, 1.761056900942687, 1.764078477701164, 1.7670710083893508, 1.7700350939251646, 1.7729713162860234, 1.7758802393064959, 1.7787624094340904, 1.781618356445807, 1.7844485941278818, 1.7872536209209804, 1.7900339205329385, 1.7927899625209973, 1.7955222028453457, 1.7982310843956588, 1.8009170374922088], [0.0, 0.9039315115772826, 1.0029748100862945, 1.0658687137335516, 1.1128702305247968, 1.1507501152595128, 1.1826553859909699, 1.2103200628329045, 1.23480683416342, 1.2568165844043437, 1.2768371978705095, 1.295222646185717, 1.3122383122721941, 1.3280885401475966, 1.3429341931506271, 1.3569042891758158, 1.370103967088473, 1.3826200949786436, 1.3945253140436398, 1.4058810159535322, 1.4167395755577679, 1.427146052610343, 1.437139507738603, 1.4467540334404516, 1.4560195713750583, 1.4649625671961832, 1.4736065003509238, 1.4819723165536782, 1.4900787837159986, 1.497942787099831, 1.5055795757874044, 1.513002969835798, 1.5202255354404168, 1.5272587338830776, 1.5341130488558472, 1.540798095837584, 1.5473227164886474, 1.5536950604712176, 1.5599226566617665, 1.5660124753714417, 1.5719709829092552, 1.5778041895966424, 1.5835176921585674, 1.589116711266899, 1.5946061248893646, 1.5999904979966113, 1.605274109096547, 1.6104609739958922, 1.6155548671310733, 1.6205593407621848, 1.6254777422830238, 1.6303132298658147, 1.6350687866301192, 1.6397472335006555, 1.6443512408976262, 1.6488833393850715, 1.6533459293872572, 1.6577412900697353, 1.662071587470196, 1.6663388819542428, 1.6705451350625604, 1.674692215808406, 1.6787819064777878, 1.6828159079789415, 1.6867958447826805, 1.690723269490779, 1.694599667065652, 1.6984264587511644, 1.7022050057113747, 1.7059366124113293, 1.709622529761649, 1.7132639580465283, 1.7168620496528924, 1.7204179116167726, 1.7239326080014676, 1.72740716212071, 1.7308425586188665, 1.73423974541911, 1.7375996355495495, 1.7409231088564099, 1.744211013612594, 1.7474641680292307, 1.7506833616771806, 1.7538693568248926, 1.757022889698474, 1.7601446716693694, 1.763235390374603, 1.7662957107741502, 1.7693262761496444, 1.772327709048306, 1.7753006121756685, 1.778245569240422, 1.7811631457544361, 1.7840538897907965, 1.7869183327024898, 1.7897569898041674, 1.7925703610192627, 1.7953589314945493, 1.7981231721841124, 1.800863540404536, 1.8035804803630076, 1.8062744236599204], [0.0, 0.9065682426885815, 1.0059004464334433, 1.0689778090157345, 1.1161164273019653, 1.1541068061054167, 1.1861051432018301, 1.2138505167704294, 1.238408715007691, 1.2604826667865288, 1.280561679560294, 1.2990007574734823, 1.3160660575594105, 1.331962519898846, 1.3468514770622464, 1.3608623232840438, 1.374100504115302, 1.3866531410367193, 1.398593087136998, 1.4099819131631903, 1.4208721467400285, 1.431308979058962, 1.4413315846855823, 1.45097415556421, 1.4602667206926052, 1.4692358028654149, 1.477904950018319, 1.4862951689635058, 1.4944252823577537, 1.5023122247166256, 1.5099712896032973, 1.5174163373873866, 1.5246599709193753, 1.531713684913168, 1.5385879936413316, 1.5452925406306812, 1.5518361933323366, 1.5582271251807083, 1.5644728870136912, 1.5705804694745449, 1.576556357734239, 1.58240657964607, 1.5881367482604187, 1.5937520994776395, 1.5992575254942922, 1.6046576045968546, 1.6099566277734674, 1.615158622544794, 1.6202673743571372, 1.6252864458323883, 1.6302191941285546, 1.6350687866301192, 1.6398382151582813, 1.6445303088662806, 1.6491477459638255, 1.6536930643965082, 1.658168671590533, 1.6625768533596847, 1.6669197820598962, 1.6711995240667732, 1.6754180466427335, 1.67957722425287, 1.6836788443820454, 1.6877246128999752, 1.6917161590159873, 1.6956550398607315, 1.6995427447281977, 1.70338069900796, 1.7071702678345373, 1.7109127594780467, 1.7146094284979638, 1.7182614786796633, 1.7218700657715351, 1.7254363000387898, 1.7289612486485544, 1.732445937899526, 1.7358913553082387, 1.7392984515629182, 1.7426681423549388, 1.7460013100970007, 1.7492988055363843, 1.7525614492709065, 1.7557900331745742, 1.7589853217393414, 1.762148053338857, 1.7652789414196068, 1.768378675624424, 1.7714479228529452, 1.7744873282632299, 1.7774975162184428, 1.7804790911821848, 1.7834326385658006, 1.7863587255307345, 1.7892579017487789, 1.792130700122855, 1.7949776374707667, 1.7977992151742024, 1.8005959197950898, 1.8033682236612674, 1.8061165854232928, 1.8088414505840882, 1.811543252003007], [0.0, 0.9091622200139485, 1.0087786444849067, 1.072036491271892, 1.1193099879944344, 1.1574090692392, 1.1894989636580182, 1.2173237254806193, 1.2419521924592505, 1.2640893047677642, 1.2842257699222752, 1.3027176078459681, 1.319831737131276, 1.3357736842570964, 1.3507052434171933, 1.3647561790836646, 1.3780322385205133, 1.3906207924904377, 1.4025949025377773, 1.4140163155828869, 1.4249377095485807, 1.4354044049325425, 1.4454556883911365, 1.4551258497026072, 1.4644450037871368, 1.4734397493294424, 1.4821337016432667, 1.4905479276479046, 1.498701303857685, 1.5066108132431546, 1.514291793127191, 1.521758143538296, 1.5290225033876765, 1.5360964002792348, 1.542990378570183, 1.5497141093805054, 1.5562764855338922, 1.5626857038515245, 1.5689493367766234, 1.5750743949548804, 1.581067382113383, 1.586934343353014, 1.5926809077848605, 1.5983123262908363, 1.603833505065617, 1.6092490354956006, 1.614563220846796, 1.6197801001638723, 1.6249034697244864, 1.6299369023443133, 1.6348837647872472, 1.6397472335006555, 1.6445303088662806, 1.6492358281324606, 1.6538664771721057, 1.65842480119267, 1.6629132145087626, 1.6673340094746012, 1.6716893646619138, 1.6759813523588576, 1.6802119454568076, 1.684383023784292, 1.6884963799407309, 1.6925537246768703, 1.696556691863719, 1.7005068430873687, 1.7044056719031477, 1.7082546077791196, 1.7120550197558826, 1.7158082198469269, 1.719515466201418, 1.7231779660491395, 1.726796878445442, 1.7303733168323543, 1.733908351430505, 1.7374030114751546, 1.7408582873084335, 1.7442751323387857, 1.747654464877667, 1.7509971698626385, 1.7543041004752362, 1.7575760796612663, 1.7608139015605362, 1.7640183328524528, 1.7671901140233839, 1.770329960561211, 1.7734385640820525, 1.7765165933937548, 1.779564695500378, 1.7825834965515868, 1.7855736027405422, 1.7885356011536357, 1.791470060575139, 1.7943775322496287, 1.7972585506048289, 1.8001136339373223, 1.8029432850634082, 1.8057479919372212, 1.8085282282380788, 1.8112844539288817, 1.8140171157872769, 1.8167266479111646], [0.0, 0.911714924174976, 1.0116110470932034, 1.0750465063734886, 1.1224527354612055, 1.160658789566352, 1.1928387845252129, 1.2207416714433368, 1.2454392891067985, 1.267638556988277, 1.2878315603900412, 1.3063753188517566, 1.3235375004076904, 1.3395242086046015, 1.3544976919146021, 1.3685880791565486, 1.3819014145067825, 1.39452531404364, 1.4065330444503275, 1.4179865260173832, 1.4289385845742872, 1.4394346678675467, 1.449514172860806, 1.4592114856095824, 1.4685568055893563, 1.4775768061674166, 1.4862951689635056, 1.4947330200476516, 1.5029092889347995, 1.5108410062795037, 1.5185435524680777, 1.5260308665568878, 1.533315622944099, 1.540409381600293, 1.5473227164886472, 1.5540653258832742, 1.5606461275767287, 1.567073341404852, 1.5733545610724256, 1.5794968169093118, 1.5855066309034656, 1.5913900651289283, 1.5971527645019479, 1.6027999946476248, 1.6083366755360238, 1.613767411445028, 1.61909651772316, 1.6243280447557344, 1.6294657994794228, 1.634513364741489, 1.639474116758873, 1.6443512408976262, 1.6491477459638255, 1.6538664771721057, 1.6585101279366483, 1.6630812506112245, 1.6675822662892457, 1.672015473761297, 1.6763830577160008, 1.6806870962599902, 1.6849295678240348, 1.689112357514759, 1.693237262964762, 1.6973059997281574, 1.701320206263463, 1.7052814485413195, 1.709191224310593, 1.713050967052941, 1.7168620496528924, 1.7206257878077482, 1.7243434431992481, 1.7280162264467802, 1.7316452998600376, 1.7352317800073211, 1.7387767401141756, 1.742281212305702, 1.745746189704667, 1.7491726283964526, 1.7525614492709065, 1.7559135397502774, 1.7592297554116259, 1.7625109215113872, 1.7657578344191185, 1.768971262966874, 1.7721519497201255, 1.7753006121756685, 1.7784179438915098, 1.7815046155533436, 1.7845612759818588, 1.787588553084794, 1.7905870547573524, 1.7935573697343195, 1.7965000683969732, 1.7994157035376497, 1.8023048110846152, 1.8051679107897012, 1.8080055068809924, 1.8108180886826781, 1.8136061312040512, 1.8163700956994753, 1.8191104302010392, 1.8218275700254833], [0.0, 0.9142277582496346, 1.0143992110708164, 1.0780095087566102, 1.1255463970938844, 1.163857753275445, 1.1961264415151889, 1.224106233311329, 1.2488719216113264, 1.2711323742724834, 1.291381032863904, 1.3099759009289604, 1.3271853842383983, 1.3432161543937502, 1.3582309070502099, 1.372360129682746, 1.3857101587426344, 1.3983688517923216, 1.4104096774498656, 1.4218947266681596, 1.4328769708732303, 1.443401983072939, 1.4535092688153461, 1.4632333089295102, 1.4726043861255598, 1.4816492472869065, 1.4903916393036742, 1.4988527464727641, 1.5070515504819313, 1.5150051289249746, 1.5227289045790438, 1.530236854918804, 1.5375416892751146, 1.5446549994797105, 1.5515873886393248, 1.5583485817580849, 1.564947521207427, 1.5713924494783924, 1.5776909812052429, 1.5838501660945696, 1.5898765441099831, 1.5957761940335833, 1.6015547763399218, 1.6072175711670154, 1.6127695120451633, 1.6182152159423846, 1.6235590101010025, 1.6288049560698488, 1.63395687127813, 1.6390183484480179, 1.6439927731018527, 1.6488833393850715, 1.6536930643965082, 1.65842480119267, 1.6630812506112245, 1.6676649720406433, 1.6721783932472638, 1.6766238193575107, 1.6810034410813617, 1.6853193422530488, 1.6895735067562174, 1.6937678248931514, 1.6979040992510166, 1.7019840501122718, 1.7060093204512916, 1.7099814805547864, 1.7139020322996599, 1.7177724131184784, 1.721593999679662, 1.7253681113067874, 1.7290960131589932, 1.7327789191923308, 1.7364179949200076, 1.740014359987767, 1.7435690905791377, 1.7470832216639245, 1.7505577491021016, 1.7539936316141769, 1.7573917926281202, 1.7607531220120594, 1.764078477701164, 1.76736868722641, 1.770624549152278, 1.773846834429848, 1.7770362876712227, 1.7801936283507347, 1.7833195519379492, 1.786414730967079, 1.7894798160470677, 1.7925154368162697, 1.7955222028453457, 1.7985007044917294, 1.8014515137087623, 1.8043751848123661, 1.8072722552079117, 1.810143246079751, 1.8129886630457028, 1.8158089967786137, 1.8186047235969784, 1.8213763060264532, 1.8241241933339754, 1.8268488220360888], [0.0, 0.9167020531595504, 1.017144613167752, 1.0809270677743588, 1.1285926114491949, 1.1670076546964094, 1.199363675934239, 1.2274191931235285, 1.2522519080653538, 1.274572607119398, 1.294876067320629, 1.3135212611245277, 1.3307773207237037, 1.3468514770622462, 1.3619068661200142, 1.3760743285274044, 1.3894604885280262, 1.4021534414648107, 1.4142268547936072, 1.4257429875122267, 1.4367549544102378, 1.4473084518357313, 1.4574430922558321, 1.4671934498196044, 1.4765898891952611, 1.485659229654825, 1.4944252823577537, 1.5029092889347995, 1.5111302824463573, 1.5191053867055657, 1.5268500662302664, 1.5343783363242036, 1.541702940715172, 1.548835502607406, 1.555786653804222, 1.5625661456298063, 1.5691829446575118, 1.5756453156861179, 1.5819608939583736, 1.5881367482604187, 1.5941794362558281, 1.6000950531785099, 1.6058892748227027, 1.6115673956167558, 1.6171343624432313, 1.622594804765656, 1.6279530615377384, 1.6332132053006152, 1.6383790638151035, 1.6434542395268317, 1.6484421271208252, 1.6533459293872572, 1.658168671590533, 1.6629132145087626, 1.6675822662892457, 1.6721783932472638, 1.6767040297197382, 1.68116148707176, 1.6855529619423142, 1.6898805438053874, 1.6941462219138708, 1.6983518916860216, 1.7024993605875847, 1.706590353556846, 1.7106265180147777, 1.7146094284979638, 1.7185405909480351, 1.7224214466878707, 1.72625337611175, 1.7300377021139084, 1.7337756932775517, 1.7374685668442198, 1.7411174914815017, 1.7447235898653863, 1.748287941092019, 1.7518115829322793, 1.7552955139413686, 1.7587406954345062, 1.7621480533388567, 1.7655184799309152, 1.7688528354677941, 1.7721519497201252, 1.7754166234136497, 1.7786476295859732, 1.7818457148644407, 1.785011600670593, 1.7881459843562355, 1.7912495402757496, 1.794322920798907, 1.7973667572681356, 1.800381660903857, 1.8033682236612674, 1.8063270190416607, 1.8092586028611763, 1.8121635139796366, 1.8150422749919433, 1.8178953928843347, 1.8207233596576304, 1.8235266529194485, 1.826305736447239, 1.8290610607238498, 1.8317930634472266], [0.0, 0.9191390725941327, 1.0198486555352004, 1.0838006735031263, 1.131592934311294, 1.1701101025691933, 1.2025521411256388, 1.23068224289822, 1.2555809747194862, 1.2779610125490908, 1.2983184487689519, 1.3170132101499112, 1.3343151443628316, 1.3504320332678132, 1.3655274465358496, 1.3797325726324468, 1.3931543192579305, 1.4058810159535324, 1.4179865260173832, 1.4295332739606001, 1.4405745157765095, 1.4511560692952998, 1.4613176522924147, 1.4710939308310502, 1.4805153503027975, 1.4896088012777493, 1.498398158216474, 1.5069047192198355, 1.5151475679469348, 1.5231438737339522, 1.5309091422105934, 1.5384574259397839, 1.5458015025280598, 1.5529530260795263, 1.5599226566617665, 1.5667201715225108, 1.5733545610724256, 1.57983411208196, 1.5861664800918813, 1.592358752680443, 1.598417504944533, 1.6043488483220192, 1.610158473696035, 1.6158516895699775, 1.6214334559775174, 1.6269084146894446, 1.6322809161944192, 1.6375550438602822, 1.6427346356238155, 1.6478233035076195, 1.6528244512213675, 1.6577412900697353, 1.6625768533596847, 1.6673340094746012, 1.672015473761297, 1.6766238193575107, 1.68116148707176, 1.6856307944138176, 1.690033943862354, 1.6943730304461473, 1.6986500487064455, 1.702866899100408, 1.7070253938988615, 1.7111272626257787, 1.7151741570817411, 1.7191676559891815, 1.7231092692932226, 1.7270004421484484, 1.7308425586188667, 1.7346369451155799, 1.738384873594276, 1.7420875645324887, 1.7457461897046673, 1.7493618747713942, 1.752935701697553, 1.7564687110129005, 1.7599619039272607, 1.7634162443114747, 1.7668326605542513, 1.7702120473041707, 1.7735552671053076, 1.7768631519342097, 1.780136504645318, 1.7833761003313315, 1.7865826876044768, 1.7897569898041679, 1.7928997061360952, 1.7960115127473864, 1.7990930637421154, 1.8021449921411106, 1.8051679107897016, 1.808162413216776, 1.8111290744482602, 1.814068451777911, 1.8169810854980901, 1.819867499592999, 1.8227282023966809, 1.8255636872179215, 1.828374432934042, 1.8311609045554276, 1.8339235537625185, 1.8366628194168655], [0.0, 0.9215400175187469, 1.0225126707276686, 1.0866317420583957, 1.1345488442419815, 1.1731666257828939, 1.2056934083678967, 1.2338969906692616, 1.2588607621407593, 1.281299260370799, 1.3017098736175408, 1.320453468840726, 1.337800598598448, 1.3539595875117643, 1.3690944325229955, 1.3833366647838523, 1.396793471255447, 1.4095534122105409, 1.4216905438905478, 1.4332674538698447, 1.444337537255316, 1.4549467315609828, 1.4651348583117585, 1.4749366741243919, 1.484382703918927, 1.493499908508121, 1.5023122247166256, 1.510841006279504, 1.5191053867055657, 1.5271225801801676, 1.5349081328363123, 1.5424761339445692, 1.549839394488719, 1.5570095990153352, 1.5639974354378794, 1.570812706543888, 1.5774644262284827, 1.5839609029085429, 1.5903098121223882, 1.5965182599622112, 1.6025928387001525, 1.608539675738177, 1.6143644768249565, 1.6200725643305864, 1.625668911245175, 1.631158171464593, 1.6365447068417047, 1.6418326114107902, 1.647025733133964, 1.6521276934690334, 1.6571419050167306, 1.662071587470196, 1.6669197820598962, 1.6716893646619138, 1.6763830577160008, 1.6810034410813617, 1.6855529619423142, 1.690033943862354, 1.6944485950733938, 1.6987990160767779, 1.7030872066238287, 1.7073150721360175, 1.711484429618126, 1.715597013111932, 1.7196544787327968, 1.7236584093270397, 1.7276103187840126, 1.7315116560332853, 1.7353638087542715, 1.7391681068228815, 1.7429258255173645, 1.746638188503345, 1.7503063706161437, 1.753931500456756, 1.7575146628163392, 1.761056900942687, 1.764559218660952, 1.7680225823597662, 1.7714479228529452, 1.7748361371260408, 1.7781880899762372, 1.7815046155533436, 1.7847865188089915, 1.7880345768605515, 1.7912495402757498, 1.7944321342834848, 1.7975830599158886, 1.8007029950862985, 1.8037925956074172, 1.8068524961536296, 1.80988331117112, 1.812885635739172, 1.8158600463857766, 1.8188071018604346, 1.8217273438668418, 1.824621297757934, 1.827489473195608, 1.8303323647772545, 1.833150452631102, 1.8359442029822213, 1.838714068690917, 1.8414604897651194], [0.0, 0.9239060303085882, 1.0251379262897986, 1.0894216204691891, 1.1374617476700972, 1.1761786786383857, 1.2087889722832943, 1.2370649660211412, 1.2620928308596782, 1.2845889389306233, 1.3050519555142492, 1.323843674080081, 1.3412353418178078, 1.3574358182126367, 1.3726095212617047, 1.3868883198170732, 1.400379676037585, 1.4131723775705414, 1.425340670793445, 1.4369473039714713, 1.4480458093010544, 1.4586822422387284, 1.4688965265493914, 1.4787235080858518, 1.4881937901395208, 1.497334402743837, 1.5061693441801787, 1.5147200230083693, 1.5230056218616468, 1.5310433991220191, 1.5388489408364905, 1.546436372449202, 1.5538185378355631, 1.5610071515416974, 1.568012928921807, 1.5748456979316465, 1.581514495609111, 1.5880276517025678, 1.5943928614569387, 1.6006172492089903, 1.6067074241562262, 1.612669529432443, 1.6185092854355665, 1.6242320282006395, 1.6298427434856997, 1.6353460971352878, 1.6407464622011303, 1.646047943228757, 1.6512543980597534, 1.656369457449857, 1.661396542761501, 1.6663388819542428, 1.6711995240667732, 1.6759813523588576, 1.6806870962599902, 1.6853193422530488, 1.6898805438053874, 1.6943730304461473, 1.6987990160767779, 1.7031606065915659, 1.707459806876107, 1.7116985272439564, 1.7158785893649744, 1.7200017317330134, 1.7240696147154366, 1.7280838252224513, 1.732045881030252, 1.73595723478847, 1.7398192777393249, 1.7436333431731232, 1.747400709642334, 1.751122603954289, 1.7548002039606454, 1.7584346411600318, 1.762027003128758, 1.7655783357931103, 1.7690896455555163, 1.7725619012857685, 1.7759960361875056, 1.7793929495492489, 1.782753508388511, 1.786078548996744, 1.7893688783922557, 1.7926252756876313, 1.7958484933776466, 1.799039258553192, 1.8021982740462685, 1.8053262195107256, 1.808423752443036, 1.8114915091470825, 1.814530105646612, 1.8175401385487489, 1.8205221858616927, 1.8234768077695094, 1.826404547366694, 1.8293059313550033, 1.8321814707048678, 1.835031661283535, 1.8378569844519412, 1.840657907632169, 1.8434348848472217, 1.8461883572347304], [0.0, 0.9262381985451124, 1.027725628968772, 1.0921715911546193, 1.1403329835654743, 1.1791476456813663, 1.2118402558049293, 1.2401876251722106, 1.265278666556294, 1.2878315603900412, 1.3083462307087161, 1.3271853842383983, 1.3446209528640376, 1.3608623232840433, 1.3760743285274044, 1.3903891703159095, 1.403914582069574, 1.4167395755577679, 1.428938584574287, 1.4405745157765095, 1.4517010364894252, 1.4623643184249773, 1.4726043861255596, 1.4824561734035655, 1.491950360800713, 1.501114046580957, 1.509971289603297, 1.5185435524680777, 1.5268500662302662, 1.5349081328363121, 1.5427333776762726, 1.5503399618504174, 1.5577407616552865, 1.5649475212074269, 1.5719709829092552, 1.5788209995247275, 1.5855066309034656, 1.5920362278201907, 1.598417504944533, 1.6046576045968546, 1.610763152657915, 1.616740307768305, 1.6225948047656562, 1.6283319931544882, 1.63395687127813, 1.6394741167588731, 1.6448881136871116, 1.650202976969268, 1.6554225741850779, 1.6605505452552078, 1.6655903201784588, 1.6705451350625604, 1.6754180466427335, 1.6802119454568076, 1.6849295678240348, 1.6895735067562174, 1.6941462219138708, 1.6986500487064455, 1.7030872066238287, 1.707459806876107, 1.711769859409705, 1.7160192793602838, 1.7202098929960505, 1.724343443199248, 1.7284215945284191, 1.732445937899526, 1.7364179949200076, 1.7403392219063436, 1.7442110136125941, 1.7480347066946216, 1.7518115829322793, 1.7555428722296649, 1.7592297554116259, 1.7628733668329741, 1.7664747968153325, 1.7700350939251643, 1.7735552671053076, 1.7770362876712225, 1.7804790911821846, 1.7838845791967441, 1.7872536209209804, 1.7905870547573524, 1.7938856897612834, 1.7971503070120318, 1.8003816609038572, 1.8035804803630076, 1.806747469995607, 1.8098833111711197, 1.8129886630457026, 1.816064163529428, 1.8191104302010392, 1.8221280611736452, 1.825117635914482, 1.828079716021659, 1.831014845960577, 1.8339235537625183, 1.83680635168773, 1.8396637368551514, 1.8424961918407934, 1.845304185246628, 1.8480881722417257, 1.850848595077258], [0.0, 0.9285375585076968, 1.030276928588551, 1.094882876041075, 1.1431638277376792, 1.1820748461474175, 1.2148486147450193, 1.243266355649849, 1.2684196848299538, 1.2910285655806768, 1.3115941629844692, 1.3304800841765336, 1.347958936104984, 1.3642406252647479, 1.379490393878117, 1.393840771853891, 1.407399760057234, 1.4202565912267, 1.4324858839358587, 1.4441507010060746, 1.4553048429899447, 1.4659945962193721, 1.4762600845965383, 1.4861363286560314, 1.495654085103141, 1.504840519472491, 1.5137197503485131, 1.5223132936118466, 1.5306404280580055, 1.5387184985850286, 1.5465631693725594, 1.5541886366753956, 1.5616078087551168, 1.5688324588827058, 1.5758733561282865, 1.5827403777150215, 1.5894426059833513, 1.5959884124385575, 1.6023855309017185, 1.608641121423803, 1.6147618263341308, 1.620753819561943, 1.6266228501814424, 1.632374280977141, 1.6380131227006134, 1.6435440645862143, 1.648971501607718, 1.6542995588866853, 1.6595321136040078, 1.664672814716352, 1.6697251007373932, 1.674692215808406, 1.67957722425287, 1.684383023784292, 1.689112357514759, 1.6937678248931514, 1.6983518916860216, 1.702866899100408, 1.7073150721360175, 1.7116985272439564, 1.7160192793602838, 1.7202792483749303, 1.7244802650897624, 1.728624076713678, 1.7327123519374394, 1.7367466856264124, 1.740728603165383, 1.7446595644860952, 1.7485409678050463, 1.7523741530963088, 1.756160405321718, 1.7599009574385736, 1.7635969932030868, 1.7672496497860735, 1.7708600202158484, 1.774429155661912, 1.7779580675717734, 1.781447729672156, 1.7848990798448352, 1.7883130218864538, 1.791690427160871, 1.7950321361518558, 1.7983389599232886, 1.801611681493435, 1.8048510571293164, 1.8080578175667201, 1.8112326691609344, 1.8143762949729036, 1.8174893557951217, 1.8205724911212537, 1.823626320063166, 1.8266514422187645, 1.8296484384937974, 1.8326178718805253, 1.8355602881959683, 1.8384762167822317, 1.8413661711712341, 1.8442306497159981, 1.8470701361905166, 1.8498851003600518, 1.8526759985236188, 1.855443274030265], [0.0, 0.9308050983895649, 1.032792921618168, 1.0975566403542683, 1.1459554967952779, 1.1849615380560357, 1.217815342002443, 1.246302480596428, 1.2715172355923816, 1.2941813284756856, 1.3147971482015373, 1.333729189853799, 1.3512507261017728, 1.3675721760436137, 1.3828591854322245, 1.3972446078217458, 1.4108367078214046, 1.4237249360810194, 1.4359840933968286, 1.4476773965930811, 1.458858777606288, 1.469574635802125, 1.4798651930675542, 1.4897655554592384, 1.4993065547920363, 1.5085154229403044, 1.5174163373873863, 1.5260308665568878, 1.5343783363242034, 1.542476133944569, 1.5503399618504174, 1.5579840509645833, 1.5654213410713322, 1.5726636341926232, 1.5797217256972431, 1.5866055169290771, 1.5933241124081423, 1.5998859040833973, 1.6062986446623375, 1.6125695116811705, 1.6187051636901506, 1.6247117896955943, 1.6305951528112599, 1.6363606289178751, 1.6420132410035457, 1.6475576897539956, 1.652998380875767, 1.6583394495641943, 1.6635847824684593, 1.668738037456181, 1.6738026614380752, 1.6787819064777878, 1.6836788443820454, 1.6884963799407309, 1.693237262964762, 1.6979040992510166, 1.7024993605875847, 1.7070253938988615, 1.711484429618126, 1.7158785893649744, 1.7202098929960505, 1.7244802650897624, 1.7286915409188952, 1.7328454719591275, 1.7369437309762563, 1.7409879167303963, 1.7449795583314076, 1.7489201192762676, 1.7528110011959952, 1.756653547336954, 1.7604490457989266, 1.7641987325501622, 1.7679037942376703, 1.7715653708093002, 1.7751845579626022, 1.7787624094340904, 1.7822999391412848, 1.785798123188803, 1.7892579017487789, 1.792680180824977, 1.796065833909175, 1.7994157035376497, 1.8027306027549441, 1.8060113164914973, 1.8092586028611766, 1.8124731943842665, 1.8156557991410134, 1.8188071018604346, 1.8219277649487156, 1.8250184294612, 1.8280797160216593, 1.8311122256922512, 1.8341165407973274, 1.8370932257040065, 1.840042827562224, 1.8429658770067676, 1.8458628888236293, 1.8487343625828374, 1.851580783239787, 1.8544026217069336, 1.8572003353975992, 1.8599743687435142], [0.0, 0.933041761263817, 1.0352746544627456, 1.1001939961166254, 1.1487091517974495, 1.1878089219865409, 1.2207416714433368, 1.2492972627406829, 1.274572607119398, 1.2972911603136934, 1.3179565184860822, 1.3369340525779219, 1.3544976919146021, 1.3708583612174048, 1.3861821042749836, 1.4006020938797517, 1.4142268547936072, 1.4271460526103432, 1.4394346678675467, 1.4511560692952998, 1.4623643184249773, 1.4731059261168518, 1.4834212109084093, 1.4933453632138374, 1.5029092889347997, 1.5121402853820387, 1.5210625881357869, 1.5296978174471396, 1.5380653456302877, 1.5461826017208873, 1.5540653258832742, 1.5617277832362462, 1.5691829446575116, 1.5764426405285048, 1.5835176921585674, 1.590418024683857, 1.5971527645019479, 1.6037303237270948, 1.610158473696035, 1.6164444091921193, 1.622594804765656, 1.6286158642947333, 1.6345133647414893, 1.6402926949045362, 1.645958889841887, 1.6515166615347012, 1.6569704262761418, 1.6623243291981429, 1.6675822662892459, 1.6727479042066837, 1.6778246981438691, 1.6828159079789415, 1.6877246128999752, 1.6925537246768703, 1.6973059997281574, 1.7019840501122718, 1.706590353556846, 1.7111272626257787, 1.715597013111932, 1.7200017317330134, 1.724343443199248, 1.728624076713678, 1.7328454719591275, 1.7370093846199548, 1.7411174914815017, 1.745171395145598, 1.7491726283964526, 1.7531226582477295, 1.757022889698474, 1.7608746692227815, 1.7646792880156523, 1.7684379850152858, 1.7721519497201255, 1.7758223248172396, 1.779450208637067, 1.7830366574481804, 1.7865826876044766, 1.790089277556088, 1.7935573697343192, 1.7969878723200021, 1.8003816609038572, 1.8037395800467195, 1.8070624447468244, 1.8103510418207467, 1.8136061312040512, 1.8168284471772198, 1.820018699521969, 1.8231775746126742, 1.826305736447239, 1.8294038276214208, 1.8324724702503083, 1.8355122668403723, 1.838523801115251, 1.841507638798199, 1.844464328353918, 1.8473944016922752, 1.8502983748362591, 1.853176748556332, 1.8560300089732045, 1.8588586281309032, 1.8616630645418843, 1.8644437637058182], [0.0, 0.9352484478226214, 1.0377231265028173, 1.1027960053771964, 1.1514259016263246, 1.1906181445652013, 1.223628781484904, 1.2522519080653538, 1.2775870297927636, 1.3003593134073366, 1.3210735460996077, 1.3400959629299682, 1.3577011410792255, 1.3741005041153018, 1.3894604885280264, 1.4039145820695742, 1.4175715661678827, 1.4305213184799868, 1.442838996875884, 1.4545881199556088, 1.4658228771085378, 1.476589889195261, 1.486929570108455, 1.496877193489251, 1.5064637383331871, 1.5157165665103982, 1.5246599709193753, 1.533315622944099, 1.541702940715172, 1.549839394488719, 1.5577407616552867, 1.5654213410713325, 1.5728941342912859, 1.5801709996759756, 1.5872627841276363, 1.5941794362558281, 1.6009301040424737, 1.607523219496864, 1.613966572335304, 1.6202673743571372, 1.6264323158982898, 1.6324676155093056, 1.6383790638151037, 1.644172062359052, 1.6498516581073064, 1.6554225741850779, 1.6608892373302655, 1.6662558024782308, 1.6715261748317065, 1.6767040297197382, 1.681792830507429, 1.6867958447826805, 1.6917161590159873, 1.696556691863719, 1.701320206263463, 1.7060093204512916, 1.7106265180147777, 1.7151741570817411, 1.7196544787327968, 1.7240696147154366, 1.7284215945284191, 1.7327123519374394, 1.7369437309762563, 1.7411174914815017, 1.7452353142041923, 1.749298805536384, 1.7533095018873912, 1.7572688737404323, 1.7611783294174397, 1.7650392185769814, 1.7688528354677941, 1.7726204219582222, 1.7763431703599275, 1.780022226062486, 1.783658689993938, 1.7872536209209802, 1.7908080376012327, 1.794322920798907, 1.7977992151742022, 1.8012378310558381, 1.804639646105348, 1.8080055068809922, 1.811336230308514, 1.8146326050653458, 1.8178953928843347, 1.8211253297825694, 1.824323127220433, 1.8274894731956077, 1.8306250332763825, 1.8337304515782835, 1.83680635168773, 1.8398533375361479, 1.8428719942277088, 1.845862888823629, 1.848826571085754, 1.8517635741819425, 1.8546744153556012, 1.857559596561537, 1.8604196050701585, 1.8632549140418981, 1.866065983073615, 1.8688532587186066], [0.0, 0.937426018910166, 1.0401392929048145, 1.1053636831983784, 1.1541068061054167, 1.1933903016898106, 1.2264777984093935, 1.255167569198686, 1.280561679560294, 1.3033869846650517, 1.3241494470168496, 1.3432161543937504, 1.3608623232840436, 1.377299869520407, 1.3926956171124667, 1.4071833646165162, 1.4208721467400283, 1.4338520504052743, 1.4461984084749018, 1.4579748874414844, 1.4692358028654147, 1.4800278841562344, 1.4903916393036745, 1.500362424077696, 1.5099712896032973, 1.5192456614581948, 1.52820988910287, 1.536885694379531, 1.545292540630681, 1.5534479387890423, 1.5613677029802016, 1.5690661653531355, 1.5765563577342387, 1.5838501660945694, 1.5909584625915771, 1.597891218998511, 1.6046576045968546, 1.6112660710284359, 1.6177244261466237, 1.6240398985422415, 1.6302191941285546, 1.6362685459349717, 1.6421937580689228, 1.6480002446503748, 1.6536930643965082, 1.659276951429549, 1.6647563427943213, 1.670135403100266, 1.6754180466427335, 1.680607957308164, 1.6857086065255331, 1.690723269490779, 1.6956550398607315, 1.7005068430873687, 1.7052814485413195, 1.7099814805547864, 1.7146094284979638, 1.7191676559891815, 1.7236584093270397, 1.7280838252224513, 1.732445937899526, 1.7367466856264124, 1.7409879167303963, 1.745171395145598, 1.749298805536384, 1.7533717580350285, 1.7573917926281202, 1.7613603832226539, 1.7652789414196068, 1.7691488200200032, 1.7729713162860232, 1.7767476749774964, 1.7804790911821846, 1.7841667129565137, 1.7878116437918525, 1.7914149449200607, 1.7949776374707667, 1.7985007044917292, 1.8019850928426313, 1.8054317149717436, 1.8088414505840882, 1.812215148208996, 1.815553626674287, 1.8188576764936981, 1.822128061173645, 1.8253655184449107, 1.8285707614243956, 1.8317444797116706, 1.8348873404246904, 1.8379999891786971, 1.8410830510120277, 1.8441371312622628, 1.8471628163958917, 1.8501606747944392, 1.8531312574997798, 1.8560750989211654, 1.8589927175063181, 1.861884616378764, 1.8647512839434393, 1.8675931944624529, 1.8704108086027587, 1.8732045739573795], [0.0, 0.9395752978678164, 1.042524067223181, 1.1078980004212042, 1.1567528788868477, 1.1961264415151889, 1.2292897994323768, 1.25804534855448, 1.2834976811394394, 1.3063753188517566, 1.3271853842383983, 1.34629580671615, 1.3639824337745694, 1.3804576671153321, 1.3958887132330027, 1.4104096774498658, 1.424129844462191, 1.4371395077386033, 1.449514172860806, 1.4613176522924147, 1.4726043861255598, 1.4834212109084093, 1.4938087275051917, 1.5038023727476384, 1.5134332689530634, 1.5227289045790438, 1.531713684913168, 1.5404093816002933, 1.548835502607406, 1.5570095990153352, 1.564947521207427, 1.5726636341926234, 1.5801709996759756, 1.587481530880044, 1.5946061248893648, 1.6015547763399216, 1.608336675536024, 1.6149602934969602, 1.6214334559775174, 1.6277634081418357, 1.6339568712781303, 1.6400200927065578, 1.6459588898418873, 1.651778689217283, 1.6574845611482751, 1.6630812506112247, 1.6685732048239696, 1.6739645979443385, 1.6792593532421634, 1.6844611630500972, 1.6895735067562174, 1.694599667065652, 1.6995427447281977, 1.7044056719031477, 1.709191224310593, 1.7139020322996599, 1.7185405909480351, 1.7231092692932226, 1.7276103187840126, 1.732045881030252, 1.7364179949200076, 1.740728603165383, 1.7449795583314076, 1.7491726283964526, 1.7533095018873912, 1.7573917926281202, 1.761421044136025, 1.7653987336973938, 1.7693262761496447, 1.7732050273954305, 1.7770362876712227, 1.7808213045907675, 1.784561275981859, 1.7882573525331233, 1.7919106402659544, 1.7955222028453455, 1.7990930637421154, 1.8026242082579007, 1.8061165854232928, 1.809571109778573, 1.8129886630457028, 1.8163700956994753, 1.8197162284450736, 1.823027853608681, 1.826305736447239, 1.8295506163829593, 1.8327632081677376, 1.835944202982221, 1.8390942694738954, 1.842214054738234, 1.845304185246628, 1.8483652677245423, 1.8513978899830845, 1.8544026217069334, 1.8573800152013622, 1.8603306061008869, 1.8632549140418981, 1.866153443301456, 1.8690266834042848, 1.8718751096998554, 1.8746991839113138, 1.8774993546578997], [0.0, 0.9416970727080176, 1.0448783238124701, 1.1103998862286935, 1.1593650901277373, 1.1988275672206705, 1.2320658155469666, 1.260886301242841, 1.286396110986923, 1.3093254116114212, 1.3301824708614185, 1.3493360490220525, 1.3670626165092867, 1.383575054676175, 1.3990409476075971, 1.413594703466174, 1.4273458537378891, 1.4403848957945673, 1.4527875057266983, 1.464617640100962, 1.4759298619476058, 1.4867711135823822, 1.4971820875555104, 1.5071983007231522, 1.5168509456838963, 1.5261675729705129, 1.5351726429832833, 1.5438879765323934, 1.552333125638259, 1.5605256810160428, 1.5684815288428646, 1.5762150665671246, 1.5837393853901771, 1.5910664254373499, 1.5982071084012759, 1.6051714514881015, 1.6119686657559342, 1.6186072413535524, 1.6250950217080777, 1.6314392683448797, 1.6376467177303724, 1.6437236312925827, 1.6496758395833262, 1.6555087813901137, 1.6612275384784019, 1.6668368665397884, 1.6723412228349408, 1.677744790947886, 1.6830515030080921, 1.6882650596863396, 1.693388948227956, 1.6984264587511644, 1.70338069900796, 1.7082546077791196, 1.713050967052941, 1.7177724131184784, 1.7224214466878707, 1.7270004421484484, 1.7315116560332853, 1.73595723478847, 1.7403392219063436, 1.7446595644860952, 1.7489201192762676, 1.7531226582477295, 1.7572688737404323, 1.7613603832226539, 1.7653987336973938, 1.7693854057869884, 1.7733218175238812, 1.7772093278726608, 1.7810492400060294, 1.7848428043551288, 1.7885912214527204, 1.7922956445859477, 1.7959571822738523, 1.799576900583425, 1.8031558252967148, 1.8066949439403934, 1.8101952076881795, 1.8136575331455944, 1.8170828040257285, 1.8204718727239404, 1.8238255617987522, 1.8271446653656, 1.83042995040955, 1.8336821580225973, 1.8369020045707098, 1.8400901827953782, 1.8432473628540462, 1.846374193303476, 1.8494713020297742, 1.852539297128529, 1.8555787677382598, 1.8585902848301232, 1.861574401956623, 1.8645316559618599, 1.867462567655682, 1.8703676424539213, 1.873247370986761, 1.8761022296771188, 1.8789326812908167, 1.8817391754601784], [0.0, 0.9437920981318068, 1.0472029000659124, 1.1128702305247973, 1.1619443689740507, 1.201494639578498, 1.2348068341634202, 1.2636914377715285, 1.289258000054743, 1.3122383122721941, 1.33314177292946, 1.352337962705194, 1.3701039670884732, 1.3866531410367193, 1.4021534414648111, 1.416739575557768, 1.4305213184799868, 1.443589368935865, 1.4560195713750583, 1.46787602465059, 1.4792134131809318, 1.4900787837159988, 1.5005129193361069, 1.5105514159129727, 1.5202255354404173, 1.5295628897438158, 1.5385879936413316, 1.5473227164886474, 1.5557866538042222, 1.5639974354378794, 1.5719709829092556, 1.5797217256972433, 1.5872627841276366, 1.5946061248893648, 1.6017626939729213, 1.6087425308700705, 1.6155548671310735, 1.6222082117930308, 1.6287104257326024, 1.6350687866301197, 1.6412900459388415, 1.647380479016807, 1.6533459293872577, 1.6591918479375596, 1.6649233277387452, 1.6705451350625606, 1.6760617370858928, 1.6814773267001295, 1.6867958447826807, 1.692021000237335, 1.697156288067613, 1.7022050057113747, 1.7071702678345373, 1.7120550197558826, 1.7168620496528924, 1.721593999679662, 1.72625337611175, 1.7308425586188667, 1.7353638087542715, 1.7398192777393249, 1.7442110136125941, 1.7485409678050463, 1.7528110011959952, 1.757022889698474, 1.7611783294174397, 1.7652789414196068, 1.7693262761496447, 1.7733218175238812, 1.7772669867295037, 1.7811631457544363, 1.7850116006705932, 1.7888136046909928, 1.792570361019263, 1.7962830255083033, 1.7999527091433163, 1.8035804803630078, 1.8071673672315185, 1.810714359472505, 1.8142224103757936, 1.8176924385861095, 1.8211253297825696, 1.8245219382568851, 1.8278830883975523, 1.8312095760867027, 1.83450217001574, 1.8377616129253918, 1.84098862277535, 1.8441838938482706, 1.8473480977925192, 1.8504818846077247, 1.8535858835768724, 1.856660704148402, 1.8597069367715096, 1.8627251536876097, 1.865715909680714, 1.8686797427892583, 1.8716171749817538, 1.8745287127984487, 1.8774148479610473, 1.8802760579523818, 1.8831128065678049, 1.885925544439953], [0.0, 0.9458610974033023, 1.0494985984952945, 1.1153098861446975, 1.1644916058683672, 1.2041285793401408, 1.2375138015616205, 1.266461726555806, 1.2920843363508012, 1.315115026452673, 1.3360643120802445, 1.3553025841140733, 1.3731075354753992, 1.389692988842503, 1.4052272693286576, 1.419845379426576, 1.4336573349518904, 1.4467540334404516, 1.4592114856095824, 1.4710939308310502, 1.4824561734035655, 1.4933453632138374, 1.5038023727476384, 1.5138628759106427, 1.5235582032298185, 1.5329160270617175, 1.5419609159663616, 1.5507147872418574, 1.5591972793643378, 1.5674260608321238, 1.5754170880683147, 1.583184822184386, 1.5907424122687628, 1.5981018512439815, 1.6052741090965472, 1.6122692473269922, 1.6190965177231602, 1.6257644479758273, 1.6322809161944194, 1.6386532160135392, 1.6448881136871116, 1.6509918983301373, 1.656970426276142, 1.6628291603620324, 1.6685732048239699, 1.6742073363824133, 1.6797360320072812, 1.6851634937816988, 1.690493671222344, 1.6957302813637356, 1.700876826871208, 1.7059366124113293, 1.7109127594780467, 1.7158082198469269, 1.7206257878077482, 1.7253681113067874, 1.7300377021139084, 1.7346369451155799, 1.7391681068228815, 1.7436333431731232, 1.7480347066946216, 1.7523741530963088, 1.756653547336954, 1.7608746692227815, 1.7650392185769814, 1.7691488200200032, 1.7732050273954305, 1.7772093278726608, 1.7811631457544363, 1.785067846014457, 1.7889247375878325, 1.7927350764349002, 1.7965000683969732, 1.800220871860835, 1.8038986002472104, 1.8075343243370579, 1.8111290744482602, 1.814683842474165, 1.818199583794419, 1.821677219067618, 1.825117635914482, 1.8285216904995172, 1.8318902090184597, 1.8352239890981896, 1.838523801115251, 1.8417903894386214, 1.8450244736019181, 1.848226749409817, 1.8513978899830845, 1.8545385467462907, 1.8576493503619473, 1.8607309116145394, 1.863783822247656, 1.8668086557571915, 1.869805968143365, 1.8727762986241108, 1.8757201703122095, 1.8786380908583566, 1.8815305530622186, 1.8843980354533745, 1.887241002843918, 1.890059906854371], [0.0, 0.9479047640932289, 1.051766188665519, 1.117719670910682, 1.1670076546964094, 1.2067302694558903, 1.2401876251722108, 1.2691980962529366, 1.294876067320629, 1.3179565184860822, 1.3389510680084606, 1.3582309070502099, 1.3760743285274044, 1.3926956171124665, 1.408263461608885, 1.4229131562013542, 1.4367549544102376, 1.4498799501683688, 1.4623643184249773, 1.4742724373500795, 1.485659229654825, 1.4965719470999226, 1.5070515504819315, 1.517133790785045, 1.5268500662302664, 1.5362281089641883, 1.5452925406306812, 1.5540653258832742, 1.5625661456298063, 1.570812706543888, 1.5788209995247278, 1.5866055169290774, 1.5941794362558281, 1.6015547763399216, 1.6087425308700705, 1.6157527830861018, 1.6225948047656562, 1.6292771420247913, 1.635807689994703, 1.642193758068923, 1.6484421271208254, 1.6545590998539328, 1.660550545255208, 1.6664219379647902, 1.672178393247264, 1.6778246981438694, 1.6833653392976506, 1.688804527870929, 1.694146221913871, 1.6993941464921745, 1.704551811839178, 1.709622529761649, 1.7146094284979638, 1.719515466201418, 1.7243434431992481, 1.7290960131589932, 1.7337756932775517, 1.738384873594276, 1.7429258255173645, 1.747400709642334, 1.7518115829322793, 1.756160405321718, 1.7604490457989266, 1.7646792880156523, 1.7688528354677941, 1.7729713162860232, 1.7770362876712227, 1.7810492400060294, 1.7850116006705932, 1.7889247375878325, 1.7927899625209973, 1.796608534144104, 1.8003816609038572, 1.8041105036898981, 1.8077961783286551, 1.8114397579146602, 1.8150422749919435, 1.8186047235969784, 1.8221280611736452, 1.8256132103697522, 1.8290610607238498, 1.8324724702503083, 1.8358482669299772, 1.8391892501131217, 1.8424961918407934, 1.845769838090285, 1.8490109099498673, 1.8522201047276006, 1.8553980969986241, 1.858545539595003, 1.8616630645418846, 1.8647512839434395, 1.8678107908218033, 1.8708421599119889, 1.873845948415533, 1.876822696715426, 1.879772929054708, 1.8826971541809254, 1.8855958659585084, 1.8884695439509662, 1.8913186539746856, 1.8941436486259782], [0.0, 0.9499237637023544, 1.0540064089959216, 1.1201003695464138, 1.16949333478573, 1.2093005571415758, 1.2428291757006125, 1.271901437935884, 1.297634102065066, 1.3207637136774824, 1.3418029807589291, 1.361123885094328, 1.3790053123526438, 1.395662003624165, 1.4112630070128518, 1.425943904874654, 1.4398151855655672, 1.4529681370448946, 1.4654790965114906, 1.4774125792583246, 1.488823624979746, 1.4997595860808421, 1.5102615106030473, 1.5203652256787354, 1.5301021964058767, 1.5395002139994376, 1.5485839525464156, 1.557375423484182, 1.5658943496401292, 1.574158475402382, 1.5821838257301313, 1.5899849238482742, 1.5975749753232527, 1.6049660245896513, 1.612169088752304, 1.6191942725279393, 1.6260508674427172, 1.6327474378155842, 1.6392918955940525, 1.6456915657403732, 1.6519532435709119, 1.6580832452136998, 1.66408745215641, 1.6699713506999478, 1.6757400670042095, 1.6813983983066427, 1.6869508408066642, 1.6924016146362038, 1.6977546862759185, 1.7030137887257486, 1.7081824396956902, 1.7132639580465283, 1.7182614786796633, 1.7231779660491395, 1.7280162264467802, 1.7327789191923308, 1.7374685668442198, 1.7420875645324887, 1.746638188503345, 1.751122603954289, 1.7555428722296649, 1.7599009574385736, 1.7641987325501622, 1.7684379850152858, 1.7726204219582222, 1.7767476749774964, 1.7808213045907675, 1.7848428043551288, 1.7888136046909928, 1.7927350764349002, 1.796608534144104, 1.8004352391735472, 1.8042164025438772, 1.8079531876173849, 1.8116467125971645, 1.8152980528633966, 1.8189082431593897, 1.8224782796388752, 1.8260091217850511, 1.829501694210929, 1.832956888349741, 1.836375564043394, 1.8397585510363041, 1.8431066503813212, 1.846420635763913, 1.849701254750275, 1.8529492299645671, 1.8561652602000882, 1.859350021468796, 1.862504167993262, 1.8656283331448218, 1.868723130331404, 1.8717891538382578, 1.8748269796245591, 1.8778371660786612, 1.8808202547345496, 1.883776770951881, 1.8867072245618137, 1.8896121104806896, 1.8924919092934698, 1.8953470878087106, 1.8981780995867368], [0.0, 0.9519187351746781, 1.0562199684392581, 1.1224527354612057, 1.1719494327686637, 1.2118402558049293, 1.2454392891067987, 1.2745726071193981, 1.3003593134073366, 1.3235375004076904, 1.3446209528640376, 1.3639824337745694, 1.3819014145067827, 1.398593087136998, 1.4142268547936077, 1.4289385845742875, 1.442838996875884, 1.4560195713750583, 1.4685568055893563, 1.4805153503027975, 1.491950360800713, 1.5029092889347995, 1.5134332689530632, 1.5235582032298185, 1.5333156229440992, 1.5427333776762728, 1.5518361933323366, 1.5606461275767287, 1.5691829446575118, 1.5774644262284825, 1.5855066309034658, 1.5933241124081425, 1.6009301040424735, 1.6083366755360238, 1.6155548671310733, 1.6225948047656562, 1.629465799479423, 1.6361764335775768, 1.6427346356238157, 1.6491477459638257, 1.6554225741850779, 1.6615654496803476, 1.667582266289246, 1.6734785218346706, 1.6792593532421634, 1.684929567824035, 1.690493671222344, 1.6959558924318814, 1.701320206263463, 1.706590353556846, 1.7117698594097053, 1.7168620496528924, 1.7218700657715351, 1.726796878445442, 1.7316452998600376, 1.7364179949200076, 1.7411174914815017, 1.7457461897046673, 1.7503063706161437, 1.7548002039606454, 1.7592297554116259, 1.7635969932030868, 1.7679037942376703, 1.7721519497201255, 1.7763431703599275, 1.7804790911821846, 1.784561275981859, 1.7885912214527204, 1.792570361019263, 1.7965000683969732, 1.8003816609038572, 1.8042164025438772, 1.8080055068809924, 1.8117501397207154, 1.8154514216145217, 1.8191104302010392, 1.8227282023966809, 1.826305736447239, 1.8298439938509585, 1.8333439011626673, 1.83680635168773, 1.8402322070738413, 1.8436222988079947, 1.8469774296253625, 1.8502983748362591, 1.8535858835768724, 1.856840679988973, 1.860063464333423, 1.8632549140418981, 1.8664156847109283, 1.8695464110420168, 1.872647707731334, 1.8757201703122095, 1.878764375953414, 1.8817808842159935, 1.88477023777123, 1.887732963082108, 1.8906695710505022, 1.893580557632147, 1.8964664044212984, 1.899327579206876, 1.9021645365017432], [0.0, 0.9538902923092755, 1.058407548048245, 1.1247774924147926, 1.1743767043205136, 1.214350146842935, 1.2480187684524762, 1.277212425650407, 1.3030525398216881, 1.3262787320962939, 1.3474058513380254, 1.366807432589495, 1.3847635260425761, 1.4014897694665434, 1.4171559168474142, 1.4318981166826685, 1.445827318686615, 1.4590351920031484, 1.4715983925868956, 1.483581705122713, 1.495040399130258, 1.5060220247406648, 1.5165678013967325, 1.5267137058316251, 1.5364913345298687, 1.5459285947522148, 1.5550502636154784, 1.5638784444686127, 1.5724329424942078, 1.5807315761743588, 1.58879043738253, 1.596624109987209, 1.6042458546963752, 1.611667766237696, 1.6189009077193401, 1.6259554260515787, 1.6328406515585312, 1.6395651843205572, 1.6461369693225218, 1.652563362112996, 1.6588511863830608, 1.665006784634551, 1.6710360629140466, 1.6769445304312063, 1.682737334750865, 1.688419293141951, 1.6939949205783393, 1.6994684548136618, 1.7048438788911249, 1.710124941398289, 1.7153151747338005, 1.7204179116167726, 1.7254363000387898, 1.7303733168323543, 1.7352317800073211, 1.740014359987767, 1.7447235898653863, 1.7493618747713942, 1.753931500456756, 1.7584346411600318, 1.7628733668329741, 1.7672496497860735, 1.7715653708093002, 1.7758223248172396, 1.780022226062486, 1.7841667129565137, 1.7882573525331233, 1.7922956445859477, 1.7962830255083033, 1.800220871860835, 1.8041105036898981, 1.8079531876173849, 1.8117501397207154, 1.8155025282199488, 1.8192114759873799, 1.8228780628935772, 1.8265033280025529, 1.8300882716276061, 1.83363385725838, 1.8371410133687263, 1.8406106351141713, 1.8440435859270021, 1.847440699016339, 1.850802778779931, 1.854130602133869, 1.8574249197659063, 1.8606864573176136, 1.8639159165001908, 1.86711397614837, 1.8702812932165127, 1.8734185037206788, 1.8765262236301599, 1.8796050497117194, 1.8826555603295245, 1.8856783162035513, 1.8886738611290295, 1.8916427226593227, 1.8945854127544548, 1.8975024283973543, 1.9003942521797261, 1.9032613528593463, 1.9061041858904384], [0.0, 0.9558390250788759, 1.0605698024386119, 1.127075336072129, 1.1767758757829092, 1.2168309813204436, 1.2505683856262413, 1.2798216834735265, 1.3057145872346185, 1.328988229034986, 1.3501585095395225, 1.3695997268974414, 1.3875925034240457, 1.4043529174218572, 1.4200510696727016, 1.4348233868161482, 1.4487810452291998, 1.4620159013295566, 1.4746047676747296, 1.4866125613002645, 1.4980946646376765, 1.5090987249597718, 1.5196660459178586, 1.5298326777431115, 1.539630281469518, 1.549086821370459, 1.5582271251807083, 1.5670733414048523, 1.5756453156861179, 1.5839609029085429, 1.592036227820191, 1.5998859040833977, 1.607523219496864, 1.6149602934969602, 1.6222082117930308, 1.6292771420247913, 1.636176433577577, 1.6429147041011247, 1.6494999148113616, 1.6559394362837419, 1.662240106149682, 1.6684082798683157, 1.6744498755518722, 1.6803704136649502, 1.686175052288508, 1.6918686185328258, 1.6974556365955618, 1.7029403528877893, 1.7083267585898005, 1.7136186099472643, 1.7188194465752762, 1.7239326080014676, 1.7289612486485544, 1.733908351430505, 1.7387767401141756, 1.7435690905791377, 1.748287941092019, 1.752935701697553, 1.7575146628163392, 1.762027003128758, 1.7664747968153325, 1.7708600202158484, 1.7751845579626022, 1.779450208637067, 1.783658689993938, 1.7878116437918525, 1.7919106402659544, 1.7959571822738523, 1.7999527091433163, 1.8038986002472104, 1.8077961783286551, 1.8116467125971645, 1.8154514216145217, 1.8192114759873799, 1.822928000881985, 1.826602078375008, 1.8302347496531977, 1.8338270170734248, 1.837379846093676, 1.8408941670846126, 1.8443708770305016, 1.8478108411275638, 1.8512148942871085, 1.8545838425502146, 1.8579184644201596, 1.8612195121183008, 1.864487712768645, 1.8677237695159399, 1.8709283625817308, 1.8741021502624924, 1.8772457698736218, 1.8803598386427935, 1.8834449545559253, 1.8865016971587427, 1.8895306283167341, 1.8925322929360664, 1.895507219647858, 1.8984559214580325, 1.9013788963648206, 1.9042766279458296, 1.9071495859164749, 1.9099982266614421], [0.0, 0.9577655008625032, 1.0627073611568028, 1.1293469354568555, 1.1791476456813663, 1.219283481539388, 1.2530888829563018, 1.2824011402815068, 1.3083462307087161, 1.3316667801014173, 1.3528797289127028, 1.3723601296827461, 1.3903891703159095, 1.407183364616516, 1.4229131562013542, 1.4377152466753493, 1.4517010364894252, 1.4649625671961832, 1.4775768061674166, 1.4896088012777493, 1.501114046580957, 1.5121402853820385, 1.5227289045790435, 1.5329160270617175, 1.5427333776762728, 1.5522089770575636, 1.5613677029802013, 1.570231748588672, 1.5788209995247275, 1.5871533466585916, 1.5952449472374588, 1.6031104443772293, 1.6107631526579147, 1.6182152159423846, 1.625477742283024, 1.6325609198122377, 1.6394741167588731, 1.64622596814138, 1.6528244512213677, 1.659276951429549, 1.665590320178459, 1.6717709257365407, 1.6778246981438691, 1.6837571689914366, 1.6895735067562174, 1.6952785482774433, 1.700876826871208, 1.7063725975071482, 1.7117698594097053, 1.7170723763951914, 1.7222836952127305, 1.72740716212071, 1.732445937899526, 1.7374030114751546, 1.742281212305702, 1.7470832216639245, 1.7518115829322793, 1.7564687110129005, 1.761056900942687, 1.7655783357931103, 1.7700350939251643, 1.774429155661912, 1.7787624094340904, 1.7830366574481804, 1.7872536209209802, 1.7914149449200607, 1.7955222028453455, 1.799576900583425, 1.8035804803630078, 1.8075343243370579, 1.8114397579146602, 1.8152980528633966, 1.8191104302010392, 1.8228780628935772, 1.826602078375008, 1.8302835609029082, 1.8339235537625187, 1.8375230613309421, 1.8410830510120277, 1.8446044550515814, 1.8480881722417257, 1.8515350695224682, 1.854945983487866, 1.8583217218035593, 1.8616630645418843, 1.8649707654402865, 1.8682455530882776, 1.8714881320477803, 1.8746991839113138, 1.8778793683021375, 1.8810293238201454, 1.8841496689370232, 1.887241002843918, 1.8903039062546187, 1.893338942167044, 1.896346656585608, 1.899327579206876, 1.9022822240707253, 1.9052110901790926, 1.908114662084227, 1.9109934104482469, 1.9138477925756723], [0.0, 0.9596702655988487, 1.064820829959723, 1.1315929343112943, 1.1814926861452546, 1.2217083425070814, 1.2555809747194864, 1.2849515270595415, 1.3109482160182102, 1.3343151443628316, 1.3555702806164642, 1.3750894232083868, 1.3931543192579308, 1.40998191316319, 1.425742987512227, 1.4405745157765095, 1.4545881199556088, 1.46787602465059, 1.4805153503027975, 1.4925712741514, 1.5040994006144708, 1.515147567946935, 1.5257572453554071, 1.5359646275693537, 1.5458015025280603, 1.5552959465926697, 1.564472887013691, 1.5733545610724256, 1.5819608939583736, 1.590309812122388, 1.5984175049445333, 1.6062986446623375, 1.6139665723353038, 1.6214334559775174, 1.6287104257326022, 1.6358076899947027, 1.6427346356238157, 1.6494999148113614, 1.6561115206837997, 1.6625768533596847, 1.6689027778773604, 1.6750956751702204, 1.6811614870717602, 1.687105756173973, 1.6929336612326886, 1.6986500487064458, 1.7042594609270119, 1.7097661613261321, 1.7151741570817411, 1.7204872194954755, 1.7257089023700876, 1.7308425586188665, 1.7358913553082387, 1.7408582873084335, 1.745746189704667, 1.7505577491021016, 1.7552955139413686, 1.7599619039272607, 1.764559218660952, 1.7690896455555163, 1.7735552671053076, 1.7779580675717734, 1.7822999391412848, 1.7865826876044766, 1.7908080376012327, 1.7949776374707667, 1.7990930637421154, 1.8031558252967148, 1.8071673672315185, 1.8111290744482602, 1.8150422749919435, 1.8189082431593897, 1.8227282023966809, 1.8265033280025529, 1.8302347496531977, 1.8339235537625187, 1.8375707856905996, 1.8411774518120074, 1.8447445214545244, 1.8482729287179684, 1.851763574181943, 1.8552173265105902, 1.858635023961752, 1.8620174758073198, 1.8653654636710062, 1.8686797427892585, 1.8719610432005775, 1.87521007086809, 1.8784275087398383, 1.8816140177509133, 1.8847702377712303, 1.8878967885024662, 1.8909942703274147, 1.894063265114765, 1.8971043369821023, 1.9001180330197123, 1.9031048839775988, 1.9060654049179409, 1.9090000958350695, 1.9119094422448915, 1.9147939157455585, 1.9176539745510597], [0.0, 0.9615538448664398, 1.066910792013262, 1.1338139523701285, 1.1838116442376416, 1.224106233311329, 1.2580453485544802, 1.287473547531561, 1.3135212611245275, 1.3369340525779219, 1.3582309070502097, 1.3777883605637324, 1.3958887132330027, 1.41274933526067, 1.42854134443591, 1.4434019830729392, 1.4574430922558321, 1.4707570775981882, 1.4834212109084093, 1.4955007973513703, 1.5070515504819315, 1.5181214024488772, 1.528751903851922, 1.538979320461227, 1.5488355026074063, 1.5583485817580849, 1.5675435340893806, 1.5764426405285048, 1.585065865372842, 1.5934311702581339, 1.6015547763399216, 1.609451384653461, 1.617134362443231, 1.6246159016059145, 1.631907154130668, 1.6390183484480179, 1.645958889841887, 1.6527374474856629, 1.6593620301942014, 1.6658400526105348, 1.672178393247264, 1.6783834455618698, 1.6844611630500974, 1.6904170991825842, 1.6962564428796902, 1.7019840501122718, 1.7076044721274943, 1.713121980725093, 1.7185405909480351, 1.7238640815000252, 1.729096013158993, 1.73423974541911, 1.7392984515629182, 1.7442751323387857, 1.7491726283964526, 1.7539936316141769, 1.7587406954345062, 1.7634162443114747, 1.7680225823597662, 1.7725619012857685, 1.7770362876712225, 1.781447729672156, 1.785798123188803, 1.790089277556088, 1.794322920798907, 1.7985007044917292, 1.8026242082579007, 1.8066949439403934, 1.810714359472505, 1.814683842474165, 1.8186047235969784, 1.8224782796388752, 1.826305736447239, 1.8300882716276061, 1.8338270170734248, 1.8375230613309421, 1.8411774518120074, 1.8447911968664352, 1.8483652677245421, 1.8519006003195373, 1.8553980969986241, 1.8588586281309032, 1.8622830336194947, 1.8656721243246772, 1.8690266834042848, 1.8723474675770937, 1.8756352083144778, 1.8788906129651832, 1.8821143658176986, 1.885307129104356, 1.8884695439509662, 1.8916022312755172, 1.894705792639195, 1.8977808110527439, 1.9008278517409625, 1.9038474628679305, 1.9068401762253737, 1.9098065078864022, 1.9127469588267039, 1.915662015515125, 1.9185521504754397, 1.9214178228209902], [0.0, 0.9634167448961425, 1.0689778090157345, 1.136010586554292, 1.1861051432018301, 1.2264777984093933, 1.2604826667865288, 1.2899678795159246, 1.3160660575594103, 1.3395242086046018, 1.3608623232840436, 1.3804576671153324, 1.3985930871369983, 1.415486374681468, 1.4313089790589621, 1.446198408474902, 1.460266720692605, 1.473606500350924, 1.4862951689635058, 1.4983981582164743, 1.5099712896032973, 1.521062588135787, 1.531713684913168, 1.5419609159663619, 1.5518361933323368, 1.5613677029802018, 1.5705804694745447, 1.5794968169093115, 1.5881367482604185, 1.596518259962211, 1.6046576045968546, 1.6125695116811705, 1.6202673743571372, 1.6277634081418355, 1.6350687866301192, 1.6421937580689228, 1.6491477459638257, 1.6559394362837416, 1.6625768533596847, 1.669067426199706, 1.6754180466427337, 1.6816351205328373, 1.6877246128999754, 1.6936920879739967, 1.6995427447281977, 1.70528144854132, 1.7109127594780467, 1.7164409576142348, 1.721870065771535, 1.7272038699744563, 1.732445937899526, 1.7375996355495495, 1.7426681423549388, 1.747654464877667, 1.7525614492709065, 1.7573917926281202, 1.7621480533388567, 1.7668326605542513, 1.7714479228529452, 1.7759960361875056, 1.7804790911821846, 1.7848990798448352, 1.7892579017487789, 1.7935573697343192, 1.7977992151742022, 1.8019850928426313, 1.8061165854232928, 1.8101952076881795, 1.8142224103757936, 1.818199583794419, 1.8221280611736452, 1.8260091217850511, 1.8298439938509585, 1.83363385725838, 1.837379846093676, 1.8410830510120277, 1.8447445214545244, 1.8483652677245421, 1.8519462629340446, 1.8554884448295041, 1.8589927175063183, 1.8624599530198271, 1.865890992900367, 1.8692866495791653, 1.8726477077313337, 1.8759749255417049, 1.8792690358987936, 1.8825307475217532, 1.8857607460248025, 1.8889596949232728, 1.8921282365850822, 1.8952669931311763, 1.8983765672881965, 1.901457543196403, 1.9045104871756529, 1.9075359484520307, 1.9105344598475478, 1.9135065384351462, 1.9164526861610967, 1.919373390436723, 1.9222691247012598, 1.9251403489575287], [0.0, 0.9652594535210391, 1.0710224222518359, 1.1381834120910157, 1.1883737836307942, 1.2288236588372365, 1.2628935676702069, 1.2924351761972583, 1.318583271722488, 1.3420862907207056, 1.3634652184005103, 1.3830980418679764, 1.4012681491577088, 1.4181937481674154, 1.4340466161351044, 1.4489645242754903, 1.4630597446826126, 1.4764250390801767, 1.4891379770644657, 1.5012641154715274, 1.5128593825635233, 1.5239718952087793, 1.5346433641335204, 1.5449101948678938, 1.5548043604864052, 1.5643541008689232, 1.5735844884440373, 1.582517890004558, 1.5911743467857071, 1.5995718896432631, 1.6077268022453919, 1.6156538422817774, 1.6233664285112026, 1.6308767998151321, 1.6381961511599392, 1.6453347503941822, 1.6523020390475982, 1.659106719702586, 1.665756832038143, 1.6722598192716407, 1.6786225864238944, 1.6848515515913083, 1.6909526912130386, 1.6969315801615292, 1.7027934273540521, 1.7085431074752655, 1.7141851893118003, 1.7197239611259316, 1.725163453433684, 1.730507459501022, 1.7357595538282993, 1.7409231088564099, 1.7460013100970007, 1.7509971698626385, 1.7559135397502774, 1.7607531220120594, 1.7655184799309152, 1.7702120473041707, 1.7748361371260408, 1.7793929495492489, 1.7838845791967441, 1.7883130218864538, 1.792680180824977, 1.7969878723200021, 1.8012378310558381, 1.8054317149717436, 1.809571109778573, 1.8136575331455944, 1.8176924385861095, 1.821677219067618, 1.8256132103697522, 1.829501694210929, 1.8333439011626673, 1.8371410133687263, 1.8408941670846126, 1.8446044550515814, 1.8482729287179684, 1.8519006003195373, 1.8554884448295041, 1.8590374017879512, 1.8625483770195213, 1.8660222442475183, 1.8694598466118575, 1.8728619980976875, 1.8762294848809529, 1.879563066596652, 1.8828634775350819, 1.8861314277709484, 1.889367604229832, 1.8925726716961568, 1.8957472737664858, 1.8988920337516828, 1.9020075555312135, 1.9050944243626116, 1.9081532076489234, 1.9111844556667272, 1.914188702257153, 1.9171664654821383, 1.9201182482480168, 1.9230445388983746, 1.9259458117779844, 1.928822527769506], [0.0, 0.9670824410682998, 1.073045153582236, 1.1403329835654745, 1.1906181445652015, 1.2311444133449163, 1.2652786665562943, 1.294876067320629, 1.3210735460996077, 1.3446209528640376, 1.3660402567543957, 1.3857101587426348, 1.4039145820695744, 1.4208721467400285, 1.436754954410238, 1.4517010364894254, 1.4658228771085378, 1.4792134131809318, 1.491950360800713, 1.5040994006144708, 1.5157165665103982, 1.5268500662302664, 1.5375416892751148, 1.5478279099305194, 1.557740761655287, 1.5673085376630798, 1.576556357734239, 1.5855066309034656, 1.5941794362558284, 1.6025928387001525, 1.6107631526579151, 1.6187051636901508, 1.6264323158982898, 1.6339568712781303, 1.6412900459388415, 1.6484421271208256, 1.655422574185078, 1.662240106149682, 1.6689027778773606, 1.675418046642734, 1.6817928305074292, 1.6880335596890583, 1.694146221913871, 1.700136402583007, 1.7060093204512918, 1.7117698594097055, 1.7174225968734824, 1.7229718292037033, 1.7284215945284194, 1.7337756932775517, 1.7390377067022496, 1.744211013612594, 1.7492988055363843, 1.7543041004752362, 1.7592297554116259, 1.764078477701164, 1.7688528354677941, 1.7735552671053076, 1.7781880899762372, 1.782753508388511, 1.7872536209209804, 1.791690427160871, 1.796065833909175, 1.8003816609038572, 1.804639646105348, 1.8088414505840882, 1.8129886630457028, 1.8170828040257285, 1.8211253297825696, 1.825117635914482, 1.8290610607238498, 1.832956888349741, 1.83680635168773, 1.8406106351141713, 1.8443708770305016, 1.8480881722417257, 1.851763574181943, 1.8553980969986241, 1.8589927175063183, 1.8625483770195213, 1.8660659830736153, 1.8695464110420168, 1.8729905056569935, 1.8763990824409855, 1.879772929054708, 1.8831128065678049, 1.8864194506573524, 1.8896935727391027, 1.892935861035963, 1.896146981587868, 1.8993275792068762, 1.9024782783810354, 1.9055996841302973, 1.9086923828175122, 1.9117569429173225, 1.9147939157455585, 1.9178038361515612, 1.9207872231756795, 1.9237445806740352, 1.926676397912499, 1.9295831501316911, 1.9324652990846931], [0.0, 0.9688861611972635, 1.0750465063734884, 1.1424598359090101, 1.1928387845252129, 1.233440639463507, 1.267638556988277, 1.2972911603136932, 1.3235375004076904, 1.3471288257976295, 1.3685880791565486, 1.3882946677773271, 1.4065330444503277, 1.4235222369318508, 1.439434667867547, 1.4544086261111135, 1.468556805589356, 1.4819723165536784, 1.4947330200476516, 1.5069047192198355, 1.5185435524680777, 1.5296978174471396, 1.540409381600293, 1.5507147872418574, 1.560646127576729, 1.5702317485886723, 1.5794968169093115, 1.5884637833687785, 1.5971527645019477, 1.6055818589107802, 1.613767411445028, 1.6217242352424996, 1.6294657994794228, 1.6370043890216301, 1.6443512408976262, 1.6515166615347012, 1.6585101279366485, 1.665340375383524, 1.6720154737612973, 1.6785428942532645, 1.6849295678240348, 1.6911819366843162, 1.6973059997281577, 1.7033073527741152, 1.709191224310593, 1.7149625073375903, 1.7206257878077482, 1.7261853700953558, 1.7316452998600376, 1.7370093846199546, 1.742281212305702, 1.7474641680292307, 1.7525614492709065, 1.7575760796612663, 1.7625109215113872, 1.76736868722641, 1.7721519497201252, 1.7768631519342097, 1.7815046155533436, 1.786078548996744, 1.7905870547573524, 1.7950321361518558, 1.7994157035376497, 1.8037395800467195, 1.8080055068809922, 1.812215148208996, 1.8163700956994753, 1.8204718727239404, 1.8245219382568851, 1.8285216904995172, 1.8324724702503083, 1.836375564043394, 1.8402322070738413, 1.8440435859270021, 1.8478108411275638, 1.8515350695224682, 1.8552173265105902, 1.8588586281309032, 1.8624599530198271, 1.8660222442475183, 1.8695464110420168, 1.8730333304094113, 1.8764838486574924, 1.8798987828297435, 1.8832789220559578, 1.8866250288252615, 1.8899378401868534, 1.8932180688833584, 1.8964664044212982, 1.899683514082849, 1.9028700438827177, 1.9060266194736948, 1.9091538470041634, 1.9122523139306078, 1.9153225897879416, 1.9183652269202625, 1.9213807611744673, 1.9243697125589745, 1.9273325858696557, 1.9302698712849191, 1.933182044931763, 1.9360695694244918], [0.0, 0.9706710516875964, 1.077026966372546, 1.1445644853284853, 1.1950362424808187, 1.235712894508463, 1.2699738117335322, 1.2996810413420028, 1.3259757326713832, 1.3496105182055882, 1.371109303987184, 1.390852196256456, 1.4091241718251641, 1.426144661944442, 1.4420864068984334, 1.4570879502977612, 1.4712621936749606, 1.4847024188099485, 1.4974866301825853, 1.5096807521645623, 1.5213410265723701, 1.5325158400351293, 1.5432471371246785, 1.5535715274739055, 1.5635211634100867, 1.5731244431362046, 1.5824065796460698, 1.5913900651289283, 1.6000950531785099, 1.6085396757381767, 1.6167403077683051, 1.6247117896955945, 1.6324676155093056, 1.6400200927065578, 1.647380479016807, 1.6545590998539328, 1.6615654496803476, 1.6684082798683155, 1.6750956751702206, 1.6816351205328373, 1.688033559689058, 1.6942974467174872, 1.7004327915633886, 1.7064452003539834, 1.712339911209643, 1.718121826144293, 1.7237955395588567, 1.7293653637571784, 1.7348353518518327, 1.7402093183752227, 1.745490857867661, 1.7506833616771806, 1.7557900331745742, 1.7608139015605362, 1.7657578344191185, 1.770624549152278, 1.7754166234136497, 1.780136504645318, 1.7847865188089915, 1.7893688783922557, 1.7938856897612834, 1.7983389599232886, 1.8027306027549441, 1.8070624447468244, 1.811336230308514, 1.815553626674287, 1.8197162284450736, 1.8238255617987522, 1.8278830883975523, 1.8318902090184597, 1.8358482669299772, 1.8397585510363041, 1.8436222988079947, 1.847440699016339, 1.8512148942871085, 1.854945983487866, 1.858635023961752, 1.8622830336194947, 1.865890992900367, 1.8694598466118575, 1.8729905056569935, 1.8764838486574924, 1.8799407234802201, 1.8833619486738247, 1.8867483148218411, 1.8901005858180595, 1.8934195000694773, 1.89670577163174, 1.899960091281584, 1.9031831275304585, 1.9063755275831649, 1.909537918245076, 1.9126709067812266, 1.9157750817303194, 1.9188510136764694, 1.9218992559813075, 1.9249203454788721, 1.9279148031355462, 1.9308831346771407, 1.9338258311850742, 1.9367433696634706, 1.9396362135788667], [0.0, 0.9724375351810698, 1.0789870025298158, 1.1466474301809495, 1.1972110387650745, 1.23796171652394, 1.2722849837538273, 1.3020462763022083, 1.32838882023636, 1.3520666177244556, 1.3736045282436715, 1.3933833497736816, 1.4116885777435808, 1.428740042738224, 1.444710799404545, 1.4597396434828673, 1.4739396819704855, 1.4874043664069103, 1.500211843229081, 1.5124281567816842, 1.524109651233332, 1.5353048012699388, 1.5460556277965092, 1.5563988070702646, 1.566366549931152, 1.575987306262851, 1.5852863349432413, 1.5942861690941599, 1.603006998986015, 1.6114669895597318, 1.6196825455757895, 1.6276685344683566, 1.6354384747838389, 1.6430046964172527, 1.6503784775855228, 1.6575701624933168, 1.6645892628816201, 1.6714445460489518, 1.6781441114607973, 1.6846954576854718, 1.6911055410924756, 1.6973808275059192, 1.703527337808314, 1.7095506883292366, 1.7154561267216935, 1.7212485639205803, 1.726932602687977, 1.7325125631755092, 1.7379925058718402, 1.743376252251281, 1.7486674033956966, 1.7538693568248926, 1.7589853217393414, 1.7640183328524528, 1.768971262966874, 1.773846834429848, 1.7786476295859732, 1.7833761003313315, 1.7880345768605515, 1.7926252756876313, 1.7971503070120318, 1.801611681493435, 1.8060113164914973, 1.8103510418207467, 1.8146326050653458, 1.8188576764936981, 1.823027853608681, 1.8271446653656, 1.8312095760867027, 1.8352239890981896, 1.8391892501131217, 1.8431066503813212, 1.8469774296253625, 1.850802778779931, 1.8545838425502146, 1.8583217218035593, 1.8620174758073198, 1.8656721243246772, 1.8692866495791653, 1.8728619980976875, 1.8763990824409855, 1.8798987828297435, 1.8833619486738247, 1.8867894000115193, 1.8901819288651125, 1.8935403005185723, 1.896865254722692, 1.900157506832597, 1.9034177488821398, 1.906646650599365, 1.9098448603668947, 1.9130130061307988, 1.9161516962612484, 1.9192615203680026, 1.9223430500735588, 1.9253968397465875, 1.9284234271980887, 1.9314233343425302, 1.9343970678260722, 1.9373451196238318, 1.9402679676080126, 1.9431660760885947], [0.0, 0.9741860198802093, 1.0809270677743588, 1.1487091517974497, 1.199363675934239, 1.2401876251722108, 1.2745726071193981, 1.3043874117575174, 1.3307773207237037, 1.3544976919146021, 1.3760743285274044, 1.395888713233003, 1.4142268547936074, 1.431308979058962, 1.4473084518357318, 1.4623643184249775, 1.4765898891952611, 1.490078783715999, 1.5029092889347995, 1.515147567946935, 1.5268500662302664, 1.538065345630288, 1.5488355026074063, 1.559197279364338, 1.569182944657512, 1.5788209995247278, 1.5881367482604187, 1.5971527645019479, 1.6058892748227027, 1.6143644768249563, 1.6225948047656562, 1.6305951528112599, 1.6383790638151035, 1.645958889841887, 1.6533459293872574, 1.660550545255208, 1.667582266289246, 1.674449875551872, 1.6811614870717602, 1.6877246128999754, 1.694146221913871, 1.7004327915633886, 1.7065903535568463, 1.7126245343222242, 1.7185405909480354, 1.7243434431992484, 1.7300377021139086, 1.7356276956114607, 1.741117491481502, 1.7465109180695197, 1.7518115829322793, 1.757022889698474, 1.762148053338857, 1.7671901140233839, 1.7721519497201255, 1.7770362876712227, 1.7818457148644407, 1.7865826876044768, 1.7912495402757498, 1.7958484933776466, 1.8003816609038572, 1.8048510571293164, 1.8092586028611766, 1.8136061312040512, 1.8178953928843347, 1.822128061173645, 1.826305736447239, 1.83042995040955, 1.83450217001574, 1.838523801115251, 1.8424961918407934, 1.846420635763913, 1.8502983748362591, 1.854130602133869, 1.8579184644201596, 1.8616630645418843, 1.8653654636710062, 1.8690266834042848, 1.8726477077313337, 1.8762294848809529, 1.879772929054708, 1.8832789220559578, 1.8867483148218411, 1.8901819288651125, 1.893580557632147, 1.8969449677829269, 1.9002759003983491, 1.9035740721197785, 1.906840176225374, 1.9100748836473804, 1.91327884393424, 1.9164526861610967, 1.9195970197919974, 1.922712435496845, 1.925799505925939, 1.9288587864447282, 1.931890815831221, 1.934896116938309, 1.9378751973231245, 1.940828549845377, 1.9437566532365054, 1.9466599726413383], [0.0, 0.9759169002068065, 1.0828475997445541, 1.1507501152595132, 1.201494639578498, 1.2423911225719826, 1.2768371978705098, 1.3067049758194098, 1.33314177292946, 1.3569042891758158, 1.3785192619739721, 1.3983688517923218, 1.416739575557768, 1.433852050405274, 1.449879950168369, 1.4649625671961835, 1.4792134131809316, 1.49272627403015, 1.5055795757874046, 1.517839599102929, 1.5295628897438156, 1.540798095837584, 1.5515873886393248, 1.5619675756332865, 1.5719709829092556, 1.5816261621441134, 1.5909584625915771, 1.5999904979966115, 1.6087425308700705, 1.61723279114673, 1.6254777422830242, 1.6334923049085495, 1.6412900459388413, 1.6488833393850717, 1.6562835038174346, 1.6635009204519864, 1.6705451350625606, 1.6774249463169222, 1.6841484826603066, 1.6907232694907792, 1.697156288067613, 1.7034540273495273, 1.7096225297616492, 1.7156674317286875, 1.721593999679662, 1.7274071621207103, 1.7331115382825173, 1.7387114637741374, 1.7442110136125941, 1.7496140229453685, 1.7549241057389358, 1.7601446716693694, 1.7652789414196068, 1.770329960561211, 1.7753006121756685, 1.7801936283507347, 1.785011600670593, 1.7897569898041679, 1.7944321342834848, 1.799039258553192, 1.8035804803630076, 1.8080578175667201, 1.8124731943842665, 1.8168284471772198, 1.8211253297825694, 1.8253655184449107, 1.8295506163829593, 1.8336821580225973, 1.8377616129253918, 1.8417903894386214, 1.845769838090285, 1.849701254750275, 1.8535858835768724, 1.8574249197659063, 1.8612195121183008, 1.8649707654402865, 1.8686797427892585, 1.8723474675770937, 1.8759749255417049, 1.879563066596652, 1.8831128065678049, 1.8866250288252615, 1.8901005858180595, 1.8935403005185723, 1.8969449677829269, 1.9003153556332648, 1.9036522064671952, 1.9069562381993719, 1.9102281453397323, 1.9134686000125973, 1.9166782529204909, 1.9198577342562633, 1.9230076545668235, 1.9261286055715447, 1.9292211609381797, 1.9322858770189208, 1.935323293549047, 1.9383339343104267, 1.9413183077619913, 1.944276907639137, 1.947210213523886, 1.9501186913875115], [0.0, 0.977630557423041, 1.0847490214772766, 1.1527707701315408, 1.2036043990866532, 1.2445726940891166, 1.2790792548300967, 1.3089994789792874, 1.3354826976731136, 1.359286939610902, 1.3809398671305169, 1.4008243117534347, 1.4192272935147632, 1.4363698169412045, 1.4524258608281322, 1.4675349621144977, 1.4818108318128982, 1.4953474205138437, 1.5082232919727852, 1.5205048432251875, 1.5322487193294476, 1.543503653836562, 1.5543118920520607, 1.564710306092141, 1.5747312788094523, 1.584403412016074, 1.5937520994776393, 1.6027999946476248, 1.6115673956167558, 1.6200725643305862, 1.6283319931544882, 1.6363606289178751, 1.6441720623590517, 1.6517786892172828, 1.6591918479375594, 1.66642193796479, 1.6734785218346706, 1.68037041366495, 1.6871057561739728, 1.6936920879739967, 1.7001364025830068, 1.7064452003539834, 1.712624534322224, 1.7186800508096944, 1.7246170254929785, 1.7304403955324033, 1.7361547882697728, 1.7417645469272365, 1.7472737536773262, 1.7526862504018352, 1.7580056574131673, 1.763235390374603, 1.768378675624424, 1.7734385640820525, 1.7784179438915098, 1.7833195519379492, 1.7881459843562355, 1.7928997061360952, 1.7975830599158886, 1.8021982740462685, 1.806747469995607, 1.8112326691609344, 1.8156557991410134, 1.820018699521969, 1.824323127220433, 1.8285707614243956, 1.8327632081677376, 1.8369020045707098, 1.84098862277535, 1.8450244736019181, 1.8490109099498673, 1.8529492299645671, 1.856840679988973, 1.8606864573176136, 1.864487712768645, 1.8682455530882776, 1.8719610432005775, 1.8756352083144778, 1.8792690358987936, 1.8828634775350819, 1.8864194506573524, 1.8899378401868534, 1.8934195000694773, 1.896865254722692, 1.9002759003983491, 1.9036522064671952, 1.9069949166304496, 1.910304750063385, 1.9135824024954613, 1.9168285472312125, 1.9200438361157617, 1.923228900448543, 1.9263843518485533, 1.9295107830741924, 1.932608768800543, 1.9356788663567215, 1.9387216164257528, 1.9417375437092381, 1.9447271575589353, 1.9476909525772128, 1.950629409188213, 1.9535429941814293], [0.0, 0.9793273602177414, 1.0866317420583955, 1.1547715511520973, 1.2056934083678967, 1.2467328090829697, 1.281299260370799, 1.3112714148934512, 1.3378005985984478, 1.3616461558408153, 1.383336664783852, 1.4032556214020744, 1.4216905438905478, 1.4388628203575804, 1.454946731560983, 1.4700820566239003, 1.4843827039189268, 1.4979427870998312, 1.510841006279504, 1.5231438737339524, 1.5349081328363123, 1.5461826017208873, 1.5570095990153352, 1.567426060832124, 1.5774644262284827, 1.5871533466585919, 1.596518259962211, 1.6055818589107802, 1.6143644768249563, 1.6228844073462338, 1.6311581714645929, 1.6392007419515804, 1.647025733133964, 1.6546455622653986, 1.662071587470196, 1.6693142262428304, 1.676383057716001, 1.6832869113054842, 1.690033943862354, 1.696631707083092, 1.7030872066238287, 1.7094069541197372, 1.7155970131119322, 1.7216630397222923, 1.7276103187840126, 1.7334437960264935, 1.7391681068228815, 1.7447876019335433, 1.7503063706161435, 1.7557282614205518, 1.761056900942687, 1.7662957107741502, 1.7714479228529452, 1.7765165933937548, 1.7815046155533436, 1.786414730967079, 1.7912495402757496, 1.7960115127473864, 1.8007029950862985, 1.8053262195107256, 1.8098833111711197, 1.8143762949729036, 1.8188071018604346, 1.8231775746126742, 1.8274894731956077, 1.8317444797116706, 1.835944202982221, 1.8400901827953782, 1.8441838938482706, 1.848226749409817, 1.8522201047276006, 1.8561652602000882, 1.860063464333423, 1.8639159165001908, 1.8677237695159399, 1.8714881320477803, 1.87521007086809, 1.8788906129651832, 1.8825307475217532, 1.8861314277709484, 1.8896935727391027, 1.8932180688833584, 1.89670577163174, 1.900157506832597, 1.9035740721197785, 1.9069562381993719, 1.910304750063385, 1.9136203281353115, 1.9169036693521384, 1.920155448187006, 1.9233763176163974, 1.9265669100354483, 1.9297278381246983, 1.9328596956713548, 1.935963058347923, 1.939038484450835, 1.9420865156015403, 1.9451076774123268, 1.9481024801189972, 1.951071419182366, 1.9540149758604126, 1.9569336177528038], [0.0, 0.9810076652601227, 1.0884961572371834, 1.1567528788868477, 1.2077621065335398, 1.2488719216113264, 1.2834976811394396, 1.3135212611245277, 1.340095962929968, 1.3639824337745694, 1.3857101587426346, 1.4056632918013445, 1.4241298444621913, 1.4413315846855823, 1.4574430922558324, 1.4726043861255598, 1.486929570108455, 1.5005129193361069, 1.5134332689530632, 1.5257572453554071, 1.5375416892751148, 1.548835502607406, 1.5596810765891669, 1.57011541070691, 1.5801709996759759, 1.5898765441099834, 1.599257525494292, 1.6083366755360238, 1.6171343624432313, 1.6256689112451748, 1.6339568712781303, 1.642013241003546, 1.6498516581073062, 1.657484561148275, 1.664923327738745, 1.672178393247264, 1.6792593532421634, 1.6861750522885077, 1.6929336612326886, 1.6995427447281977, 1.7060093204512916, 1.7123399112096427, 1.7185405909480354, 1.7246170254929785, 1.7305745087452502, 1.7364179949200076, 1.7421521273436535, 1.7477812642414783, 1.7533095018873912, 1.7587406954345064, 1.764078477701164, 1.7693262761496444, 1.7744873282632299, 1.779564695500378, 1.7845612759818588, 1.7894798160470677, 1.794322920798907, 1.7990930637421154, 1.8037925956074172, 1.808423752443036, 1.8129886630457026, 1.8174893557951217, 1.8219277649487156, 1.826305736447239, 1.8306250332763825, 1.8348873404246904, 1.8390942694738954, 1.8432473628540462, 1.8473480977925192, 1.8513978899830845, 1.8553980969986241, 1.859350021468796, 1.8632549140418981, 1.86711397614837, 1.8709283625817308, 1.8746991839113138, 1.8784275087398383, 1.8821143658176986, 1.8857607460248025, 1.889367604229832, 1.892935861035963, 1.8964664044212982, 1.899960091281584, 1.9034177488821398, 1.906840176225374, 1.9102281453397323, 1.9135824024954613, 1.9169036693521384, 1.9201926440425376, 1.9234500021970433, 1.926676397912499, 1.9298724646690877, 1.9330388161985708, 1.9361760473069611, 1.939284734654488, 1.942365437495494, 1.9454186983807291, 1.9484450438243137, 1.9514449849375, 1.9544190180312015, 1.9573676251891283, 1.9602912748132422], [0.0, 0.9826718177231486, 1.0903426500070237, 1.1587151603456796, 1.2098109185413484, 1.2509904710966684, 1.2856749687417641, 1.3157494798422251, 1.3423692621878385, 1.3662962533369152, 1.3880608365766351, 1.4080478175416364, 1.4265456963176424, 1.4437766170656867, 1.4599154557220797, 1.4751024687634602, 1.4894519535658626, 1.5030583451864272, 1.5160006125033156, 1.5283454949356636, 1.5401499296383885, 1.5514629014624424, 1.5623268735559548, 1.5727789081702759, 1.582851555143823, 1.5925735637770888, 1.6019704587814732, 1.6110650104254953, 1.619877621469235, 1.6284266480279919, 1.6367286675118473, 1.6447987038251974, 1.6526504177884944, 1.6602962690610068, 1.6677476545556726, 1.6750150273432916, 1.6821079992698336, 1.689035429904023, 1.6958055039530338, 1.7024257989028124, 1.7089033443341952, 1.7152446741199525, 1.7214558725085294, 1.7275426149377762, 1.7335102042888877, 1.7393636031812056, 1.7451074628179344, 1.7507461488175298, 1.756283764402699, 1.7617241712663239, 1.7670710083893508, 1.772327709048306, 1.7774975162184428, 1.7825834965515868, 1.787588553084794, 1.7925154368162697, 1.7973667572681356, 1.8021449921411106, 1.8068524961536296, 1.8114915091470825, 1.816064163529428, 1.8205724911212537, 1.8250184294612, 1.8294038276214208, 1.8337304515782835, 1.8379999891786971, 1.842214054738234, 1.846374193303476, 1.8504818846077247, 1.8545385467462907, 1.858545539595003, 1.862504167993262, 1.8664156847109283, 1.8702812932165127, 1.8741021502624924, 1.8778793683021375, 1.8816140177509133, 1.885307129104356, 1.8889596949232728, 1.8925726716961568, 1.896146981587868, 1.899683514082849, 1.9031831275304585, 1.906646650599365, 1.9100748836473804, 1.9134686000125973, 1.9168285472312125, 1.920155448187006, 1.9234500021970433, 1.9267128860378282, 1.9299447549157949, 1.9331462433857436, 1.936317966220552, 1.9394605192352445, 1.9425744800682794, 1.9456604089227023, 1.9487188492696303, 1.9517503285163462, 1.954755358641137, 1.9577344367968428, 1.9606880458849665, 1.9636166551020533], [0.0, 0.9843201517785073, 1.0921715911546193, 1.1606587895663523, 1.2118402558049293, 1.2530888829563018, 1.2878315603900414, 1.3179565184860822, 1.3446209528640376, 1.3685880791565488, 1.3903891703159095, 1.410409677449866, 1.4289385845742875, 1.4461984084749018, 1.4623643184249775, 1.4775768061674168, 1.4919503608007127, 1.5055795757874046, 1.5185435524680777, 1.5309091422105936, 1.5427333776762728, 1.5540653258832742, 1.564947521207427, 1.575417088068315, 1.5855066309034658, 1.595244947237459, 1.6046576045968546, 1.613767411445028, 1.622594804765656, 1.6311581714645929, 1.6394741167588731, 1.6475576897539956, 1.6554225741850779, 1.6630812506112247, 1.6705451350625604, 1.6778246981438694, 1.684929567824035, 1.6918686185328256, 1.6986500487064458, 1.70528144854132, 1.7117698594097053, 1.7181218261442928, 1.7243434431992484, 1.7304403955324035, 1.7364179949200076, 1.7422812123057023, 1.7480347066946218, 1.7536828510281115, 1.759229755411626, 1.7646792880156523, 1.7700350939251646, 1.7753006121756685, 1.7804790911821848, 1.7855736027405422, 1.7905870547573524, 1.7955222028453457, 1.800381660903857, 1.8051679107897016, 1.80988331117112, 1.814530105646612, 1.8191104302010392, 1.823626320063166, 1.8280797160216593, 1.8324724702503083, 1.83680635168773, 1.8410830510120277, 1.845304185246628, 1.8494713020297742, 1.8535858835768724, 1.8576493503619473, 1.8616630645418846, 1.8656283331448218, 1.8695464110420168, 1.8734185037206788, 1.8772457698736218, 1.8810293238201454, 1.8847702377712303, 1.8884695439509662, 1.8921282365850822, 1.8957472737664858, 1.8993275792068762, 1.9028700438827177, 1.9063755275831649, 1.9098448603668947, 1.91327884393424, 1.9166782529204909, 1.9200438361157617, 1.9233763176163974, 1.926676397912499, 1.9299447549157949, 1.9331820449317632, 1.936388903579606, 1.9395659466634219, 1.9427137709976552, 1.945832955189695, 1.9489240603822722, 1.951987630958122, 1.9550241952092011, 1.9580342659725882, 1.9610183412350484, 1.9639769047081035, 1.966910426375329], [0.0, 0.9859529910650362, 1.093983339779745, 1.1625841481668389, 1.2138505167704294, 1.2551675691986863, 1.2899678795159246, 1.3201428103926665, 1.3468514770622464, 1.370858361217405, 1.3926956171124667, 1.4127493352606704, 1.4313089790589621, 1.4485974344149954, 1.4647901611815524, 1.4800278841562347, 1.494425282357754, 1.5080771061649951, 1.521062588135787, 1.5334486905343694, 1.5452925406306814, 1.5566432868376952, 1.5675435340893809, 1.578030468389158, 1.588136748260419, 1.5978912189985113, 1.6073194905426813, 1.6164444091921193, 1.6252864458323883, 1.6338640178704578, 1.642193758068923, 1.6502907404974885, 1.658168671590533, 1.6658400526105348, 1.673316318525097, 1.6806079573081645, 1.6877246128999754, 1.6946751744516437, 1.7014678539993486, 1.7081102543305098, 1.714609428497964, 1.7209719321912964, 1.7272038699744567, 1.733310936235768, 1.7392984515629184, 1.7451713951455983, 1.7509344337175319, 1.7565919474741174, 1.762148053338857, 1.7676066258989513, 1.7729713162860234, 1.778245569240422, 1.7834326385658006, 1.7885356011536357, 1.7935573697343195, 1.7985007044917294, 1.8033682236612674, 1.808162413216776, 1.812885635739172, 1.8175401385487489, 1.8221280611736452, 1.8266514422187645, 1.8311122256922512, 1.8355122668403723, 1.8398533375361479, 1.8441371312622628, 1.8483652677245423, 1.852539297128529, 1.856660704148402, 1.8607309116145394, 1.8647512839434395, 1.868723130331404, 1.872647707731334, 1.8765262236301599, 1.8803598386427935, 1.8841496689370232, 1.8878967885024662, 1.8916022312755172, 1.8952669931311763, 1.8988920337516828, 1.9024782783810354, 1.9060266194736948, 1.909537918245076, 1.9130130061307988, 1.9164526861610967, 1.9198577342562633, 1.923228900448543, 1.9265669100354483, 1.9298724646690877, 1.9331462433857436, 1.936388903579606, 1.9396010819242744, 1.9427833952453732, 1.9459364413473723, 1.9490607997974843, 1.9521570326692907, 1.9552256852485763, 1.9582672867036548, 1.9612823507223245, 1.964271376117436, 1.9672348474029153, 1.9701732353419708], [0.0, 0.9875706491322975, 1.0957782437874222, 1.1644916058683674, 1.2158420874626406, 1.2572269289881277, 1.2920843363508014, 1.3223087753894984, 1.3490612631037886, 1.3731075354753992, 1.394980619866835, 1.4150672402519964, 1.4336573349518908, 1.4509741555642097, 1.4671934498196046, 1.4824561734035655, 1.4968771934892509, 1.5105514159129727, 1.5235582032298183, 1.5359646275693537, 1.5478279099305194, 1.5591972793643378, 1.5701154107069097, 1.580619550972919, 1.590742412268763, 1.6005128872164116, 1.6099566277734674, 1.6190965177231602, 1.6279530615377387, 1.6365447068417047, 1.6448881136871119, 1.6529983808757671, 1.6608892373302655, 1.6685732048239699, 1.6760617370858928, 1.6833653392976509, 1.6904936712223442, 1.6974556365955618, 1.704259460927012, 1.7109127594780469, 1.7174225968734824, 1.7237955395588567, 1.7300377021139088, 1.7361547882697732, 1.7421521273436535, 1.7480347066946218, 1.7538072007131358, 1.7594739967812028, 1.7650392185769816, 1.7705067470447284, 1.7758802393064959, 1.7811631457544361, 1.7863587255307345, 1.791470060575139, 1.7965000683969732, 1.8014515137087623, 1.8063270190416607, 1.8111290744482602, 1.8158600463857766, 1.8205221858616927, 1.825117635914482, 1.8296484384937974, 1.8341165407973274, 1.838523801115251, 1.8428719942277088, 1.8471628163958917, 1.8513978899830845, 1.8555787677382598, 1.8597069367715096, 1.863783822247656, 1.8678107908218033, 1.8717891538382578, 1.8757201703122095, 1.8796050497117194, 1.8834449545559253, 1.887241002843918, 1.8909942703274147, 1.894705792639195, 1.8983765672881965, 1.9020075555312135, 1.9055996841302973, 1.9091538470041634, 1.9126709067812266, 1.9161516962612484, 1.9195970197919974, 1.9230076545668235, 1.9263843518485533, 1.9297278381246983, 1.9330388161985708, 1.936317966220552, 1.9395659466634219, 1.9427833952453732, 1.9459709298040595, 1.9491291491247715, 1.9522586337256203, 1.955359946602385, 1.9584336339355033, 1.9614802257614978, 1.9645002366109772, 1.9674941661151968, 1.970462499583027, 1.9734057085500598], [0.0, 0.9891734298608728, 1.097556640354268, 1.1663815209910104, 1.217815342002443, 1.259267349179836, 1.2941813284756856, 1.3244548203578077, 1.3512507261017728, 1.3753360244428012, 1.3972446078217455, 1.4173638278473313, 1.4359840933968289, 1.4533290183947754, 1.4695746358021253, 1.4848621300688192, 1.4993065547920361, 1.513002969835798, 1.5260308665568878, 1.5384574259397839, 1.5503399618504174, 1.5617277832362462, 1.5726636341926232, 1.583184822184386, 1.5933241124081425, 1.6031104443772293, 1.6125695116811702, 1.6217242352424994, 1.6305951528112597, 1.6392007419515802, 1.6475576897539956, 1.6556811195249583, 1.663584782468459, 1.6712812206801102, 1.678781906477788, 1.6860973620925248, 1.693237262964762, 1.700210527280433, 1.7070253938988618, 1.713689490440611, 1.7202098929960505, 1.7265931786677513, 1.7328454719591277, 1.7389724858582014, 1.7449795583314076, 1.7508716848320671, 1.756653547336954, 1.7623295403485901, 1.7679037942376703, 1.7733801962470404, 1.7787624094340904, 1.7840538897907965, 1.7892579017487789, 1.7943775322496287, 1.7994157035376497, 1.8043751848123661, 1.8092586028611763, 1.814068451777911, 1.8188071018604346, 1.8234768077695094, 1.828079716021659, 1.8326178718805253, 1.8370932257040065, 1.841507638798199, 1.845862888823629, 1.8501606747944392, 1.8544026217069334, 1.8585902848301232, 1.8627251536876097, 1.8668086557571915, 1.8708421599119889, 1.8748269796245591, 1.878764375953414, 1.8826555603295245, 1.8865016971587427, 1.8903039062546187, 1.894063265114765, 1.8977808110527439, 1.901457543196403, 1.9050944243626116, 1.9086923828175122, 1.9122523139306078, 1.9157750817303194, 1.9192615203680026, 1.922712435496845, 1.9261286055715447, 1.9295107830741924, 1.9328596956713548, 1.9361760473069611, 1.9394605192352445, 1.9427137709976552, 1.9459364413473723, 1.9491291491247715, 1.9522924940869435, 1.955427057694153, 1.9585334038558948, 1.961612079639032, 1.964663615940311, 1.9676885281254002, 1.9706873166364323, 1.9736604675699119, 1.9766084532267103], [0.0, 0.9907616278608403, 1.0993188563706313, 1.1682542409235481, 1.2197706430973885, 1.2612892048272055, 1.2962592413425622, 1.326581339766073, 1.3534202685054253, 1.3775442377422735, 1.3994879971249945, 1.4196395201866718, 1.4382896820795321, 1.4556624557583668, 1.4719341568192965, 1.4872461963953223, 1.5017138128114857, 1.5154322185581137, 1.5284810326217964, 1.54092754385152, 1.552829158135266, 1.564235263589998, 1.575188672940174, 1.5857267535507853, 1.5958823232256152, 1.6056843679427308, 1.615158622544794, 1.6243280447557344, 1.6332132053006152, 1.6418326114107902, 1.6502029769692683, 1.6583394495641945, 1.6662558024782308, 1.6739645979443385, 1.6814773267001293, 1.688804527870929, 1.6959558924318814, 1.7029403528877893, 1.7097661613261321, 1.716440957614235, 1.7229718292037033, 1.7293653637571784, 1.7356276956114607, 1.7417645469272367, 1.7477812642414783, 1.7536828510281115, 1.7594739967812025, 1.7651591030590028, 1.7707423068638517, 1.776227501679878, 1.781618356445807, 1.7869183327024898, 1.792130700122855, 1.7972585506048289, 1.8023048110846152, 1.8072722552079117, 1.8121635139796366, 1.8169810854980901, 1.8217273438668418, 1.826404547366694, 1.831014845960577, 1.8355602881959683, 1.840042827562224, 1.844464328353918, 1.848826571085754, 1.8531312574997798, 1.8573800152013622, 1.861574401956623, 1.865715909680714, 1.869805968143365, 1.873845948415533, 1.8778371660786612, 1.8817808842159935, 1.8856783162035513, 1.8895306283167341, 1.893338942167044, 1.8971043369821023, 1.9008278517409625, 1.9045104871756529, 1.9081532076489234, 1.9117569429173225, 1.9153225897879416, 1.9188510136764694, 1.9223430500735588, 1.925799505925939, 1.9292211609381797, 1.932608768800543, 1.935963058347923, 1.939284734654488, 1.9425744800682794, 1.945832955189695, 1.9490607997974843, 1.9522586337256203, 1.955427057694153, 1.9585666540969286, 1.961677987748844, 1.9647616065951221, 1.9678180423849077, 1.97084781131133, 1.9738514146200221, 1.9768293391879561, 1.9797820580743204], [0.0, 0.9923355288497813, 1.1010652088600175, 1.1701101025691933, 1.2217083425070812, 1.2632928596630353, 1.2983184487689519, 1.3286887161761551, 1.355570280616464, 1.3797325726324465, 1.4017111913633924, 1.4218947266681599, 1.4405745157765095, 1.4579748874414842, 1.4742724373500795, 1.4896088012777493, 1.5040994006144706, 1.5178395991029288, 1.5309091422105934, 1.543375425679958, 1.5552959465926695, 1.5667201715225108, 1.5776909812052426, 1.588245802366788, 1.598417504944533, 1.6082351209629993, 1.6177244261466233, 1.6269084146894444, 1.6358076899947025, 1.6444407886939114, 1.6528244512213677, 1.660973849228324, 1.6689027778773602, 1.6766238193575105, 1.6841484826603061, 1.6914873236532837, 1.6986500487064455, 1.705645604514565, 1.7124822562741966, 1.7191676559891815, 1.7257089023700876, 1.7321125935445636, 1.738384873594276, 1.7445314737700028, 1.7505577491021016, 1.7564687110129005, 1.7622690564460877, 1.767963193952128, 1.7735552671053074, 1.7790491755748532, 1.7844485941278818, 1.7897569898041674, 1.7949776374707667, 1.8001136339373223, 1.8051679107897012, 1.810143246079751, 1.8150422749919433, 1.819867499592999, 1.824621297757934, 1.8293059313550033, 1.8339235537625183, 1.8384762167822317, 1.8429658770067676, 1.8473944016922752, 1.8517635741819425, 1.8560750989211654, 1.8603306061008869, 1.8645316559618599, 1.8686797427892583, 1.8727762986241108, 1.876822696715426, 1.8808202547345496, 1.88477023777123, 1.8886738611290295, 1.8925322929360664, 1.896346656585608, 1.9001180330197123, 1.9038474628679305, 1.9075359484520307, 1.9111844556667272, 1.9147939157455585, 1.9183652269202625, 1.9218992559813075, 1.9253968397465875, 1.9288587864447282, 1.9322858770189208, 1.9356788663567215, 1.939038484450835, 1.942365437495494, 1.9456604089227023, 1.9489240603822722, 1.9521570326692907, 1.955359946602385, 1.9585334038558948, 1.961677987748844, 1.9647942639933809, 1.967882781405182, 1.9709440725781162, 1.973978654525325, 1.9769870292887093, 1.979969684518682, 1.982927094025923], [0.0, 0.9938954100115739, 1.1027960053771964, 1.1719494327686637, 1.223628781484904, 1.265278666556294, 1.3003593134073368, 1.3307773207237037, 1.3577011410792255, 1.3819014145067827, 1.4039145820695742, 1.4241298444621913, 1.4428389968758841, 1.4602667206926052, 1.4765898891952614, 1.4919503608007132, 1.506463738333187, 1.5202255354404173, 1.5333156229440992, 1.5458015025280603, 1.5577407616552867, 1.5691829446575118, 1.5801709996759756, 1.590742412268763, 1.6009301040424737, 1.6107631526579151, 1.6202673743571372, 1.629465799479423, 1.6383790638151037, 1.647025733133964, 1.655422574185078, 1.6635847824684595, 1.6715261748317065, 1.6792593532421634, 1.6867958447826807, 1.694146221913871, 1.7013202062634631, 1.7083267585898005, 1.7151741570817414, 1.7218700657715351, 1.7284215945284194, 1.7348353518518327, 1.7411174914815022, 1.7472737536773266, 1.7533095018873914, 1.759229755411626, 1.7650392185769816, 1.770742306863852, 1.7763431703599277, 1.7818457148644407, 1.7872536209209804, 1.7925703610192627, 1.7977992151742024, 1.8029432850634082, 1.8080055068809924, 1.8129886630457028, 1.8178953928843347, 1.8227282023966809, 1.827489473195608, 1.8321814707048678, 1.83680635168773, 1.8413661711712341, 1.8458628888236293, 1.8502983748362591, 1.8546744153556012, 1.8589927175063181, 1.8632549140418981, 1.867462567655682, 1.8716171749817538, 1.8757201703122095, 1.879772929054708, 1.883776770951881, 1.887732963082108, 1.8916427226593227, 1.895507219647858, 1.899327579206876, 1.9031048839775988, 1.9068401762253737, 1.9105344598475478, 1.914188702257153, 1.9178038361515612, 1.9213807611744673, 1.9249203454788721, 1.9284234271980887, 1.931890815831221, 1.935323293549047, 1.9387216164257528, 1.9420865156015403, 1.9454186983807291, 1.9487188492696303, 1.951987630958122, 1.9552256852485763, 1.9584336339355033, 1.961612079639032, 1.9647616065951221, 1.967882781405182, 1.9709761537475872, 1.9740422570534064, 1.9770816091484895, 1.9800947128639113, 1.9830820566166367, 1.9860441149621424], [0.0, 0.995441540337139, 1.1045115443862819, 1.1737725487019706, 1.2255322911975268, 1.2672469679459046, 1.3023821871909744, 1.3328475135743993, 1.3598132173461364, 1.3840511373673456, 1.406098549203315, 1.4263452589996626, 1.4450835158720547, 1.4625383507228216, 1.4788869119836865, 1.4942712787502639, 1.5088072336816303, 1.5225904390091094, 1.5357008898035862, 1.5482061927563158, 1.560164024914885, 1.5716240076835162, 1.582629156014729, 1.5932170137801465, 1.6034205538001012, 1.613268898969389, 1.622787905690498, 1.6320006401293232, 1.6409277701777845, 1.6495878904870753, 1.657997793889074, 1.6661726995223207, 1.6741264457282723, 1.6818716540782308, 1.6894198695868858, 1.6967816811616527, 1.703966825553485, 1.710984277460322, 1.7178423279487935, 1.7245486529735239, 1.7311103734640532, 1.7375341082001787, 1.7438260204945502, 1.7499918595367683, 1.7560369971184422, 1.7619664603476586, 1.7677849608695453, 1.7734969210333364, 1.77910649738271, 1.7846176017928632, 1.7900339205329385, 1.7953589314945493, 1.8005959197950898, 1.8057479919372212, 1.8108180886826781, 1.8158089967786137, 1.8207233596576304, 1.8255636872179215, 1.8303323647772545, 1.835031661283535, 1.8396637368551514, 1.8442306497159981, 1.8487343625828374, 1.853176748556332, 1.857559596561537, 1.861884616378764, 1.866153443301456, 1.8703676424539213, 1.8745287127984487, 1.8786380908583566, 1.8826971541809254, 1.8867072245618137, 1.8906695710505022, 1.8945854127544548, 1.8984559214580325, 1.9022822240707253, 1.9060654049179409, 1.9098065078864022, 1.9135065384351462, 1.9171664654821383, 1.9207872231756795, 1.9243697125589745, 1.9279148031355462, 1.9314233343425302, 1.934896116938309, 1.9383339343104267, 1.9417375437092381, 1.9451076774123268, 1.9484450438243137, 1.9517503285163462, 1.9550241952092011, 1.9582672867036548, 1.9614802257614978, 1.964663615940311, 1.9678180423849077, 1.9709440725781162, 1.9740422570534064, 1.977113130071667, 1.9801572102642913, 1.9831750012445717, 1.9861669921892675, 1.9891336583920871], [0.0, 0.9969741809482233, 1.1062121156199922, 1.1755797582702063, 1.2274191931235288, 1.2691980962529366, 1.3043874117575176, 1.3348996443574839, 1.3619068661200142, 1.3861821042749836, 1.408263461608885, 1.42854134443591, 1.4473084518357315, 1.464790161181552, 1.4811638936532876, 1.4965719470999228, 1.5111302824463573, 1.524934709211138, 1.538065345630288, 1.5505899024863183, 1.5625661456298066, 1.5740437728650205, 1.5850658653728422, 1.595670024829658, 1.605889274822703, 1.615752783086102, 1.6252864458323883, 1.6345133647414893, 1.643454239526832, 1.6521276934690334, 1.6605505452552083, 1.6687380374561815, 1.6767040297197382, 1.6844611630500974, 1.6920210002373353, 1.6993941464921747, 1.7065903535568463, 1.7136186099472643, 1.7204872194954757, 1.7272038699744567, 1.7337756932775517, 1.740209318375223, 1.74651091806952, 1.7526862504018355, 1.7587406954345066, 1.7646792880156525, 1.7705067470447284, 1.7762275016798783, 1.7818457148644407, 1.7873653044965672, 1.7927899625209973, 1.7981231721841124, 1.8033682236612674, 1.8085282282380788, 1.8136061312040512, 1.8186047235969784, 1.8235266529194485, 1.828374432934042, 1.833150452631102, 1.8378569844519412, 1.8424961918407934, 1.8470701361905166, 1.851580783239787, 1.8560300089732045, 1.8604196050701585, 1.8647512839434393, 1.8690266834042848, 1.873247370986761, 1.8774148479610473, 1.8815305530622186, 1.8855958659585084, 1.8896121104806896, 1.893580557632147, 1.8975024283973543, 1.9013788963648206, 1.9052110901790926, 1.9090000958350695, 1.9127469588267039, 1.9164526861610967, 1.9201182482480168, 1.9237445806740352, 1.9273325858696557, 1.9308831346771407, 1.9343970678260722, 1.9378751973231245, 1.9413183077619913, 1.9447271575589353, 1.9481024801189972, 1.9514449849375, 1.954755358641137, 1.9580342659725882, 1.9612823507223245, 1.9645002366109772, 1.9676885281254002, 1.97084781131133, 1.973978654525325, 1.9770816091484895, 1.9801572102642913, 1.9832059773026394, 1.9862284146522189, 1.989225012242955, 1.9921962461003453], [0.0, 0.9984935854052241, 1.1078980004212042, 1.1773713604585165, 1.2292897994323768, 1.2711323742724834, 1.3063753188517566, 1.3369340525779219, 1.3639824337745694, 1.3882946677773274, 1.4104096774498658, 1.430718464091789, 1.4495141728608063, 1.4670225246088109, 1.4834212109084095, 1.4988527464727646, 1.5134332689530632, 1.5272587338830779, 1.5404093816002933, 1.5529530260795266, 1.5649475212074273, 1.5764426405285048, 1.587481530880044, 1.5981018512439817, 1.608336675536024, 1.6182152159423848, 1.6277634081418355, 1.6370043890216301, 1.645958889841887, 1.6546455622653988, 1.663081250611225, 1.6712812206801104, 1.6792593532421634, 1.6870283085666933, 1.694599667065652, 1.7019840501122718, 1.7091912243105931, 1.7162301918751706, 1.7231092692932228, 1.7298361560540143, 1.7364179949200076, 1.7428614249643213, 1.7491726283964528, 1.7553573720331417, 1.761421044136025, 1.7673686872264103, 1.7732050273954305, 1.7789345005513366, 1.784561275981859, 1.790089277556088, 1.7955222028453457, 1.800863540404536, 1.8061165854232928, 1.8112844539288817, 1.8163700956994753, 1.8213763060264532, 1.826305736447239, 1.8311609045554276, 1.8359442029822213, 1.840657907632169, 1.845304185246628, 1.8498851003600518, 1.8544026217069336, 1.8588586281309032, 1.8632549140418981, 1.8675931944624529, 1.8718751096998554, 1.8761022296771188, 1.8802760579523818, 1.8843980354533745, 1.8884695439509662, 1.8924919092934698, 1.8964664044212984, 1.9003942521797261, 1.9042766279458296, 1.908114662084227, 1.9119094422448915, 1.915662015515125, 1.919373390436723, 1.9230445388983746, 1.926676397912499, 1.9302698712849191, 1.9338258311850742, 1.9373451196238318, 1.940828549845377, 1.944276907639137, 1.9476909525772128, 1.951071419182366, 1.9544190180312015, 1.9577344367968428, 1.9610183412350484, 1.964271376117436, 1.9674941661151968, 1.9706873166364323, 1.9738514146200221, 1.9769870292887093, 1.9800947128639113, 1.9831750012445717, 1.9862284146522189, 1.9892554582442343, 1.9922566226972045, 1.9952323847620972], [0.0, 1.0, 1.109569472067845, 1.1791476456813665, 1.2311444133449163, 1.2730501155464236, 1.3083462307087164, 1.3389510680084606, 1.3660402567543957, 1.3903891703159095, 1.4125375446227544, 1.4328769708732305, 1.4517010364894254, 1.4692358028654147, 1.4856592296548252, 1.5011140465809572, 1.5157165665103982, 1.5295628897438156, 1.5427333776762726, 1.5552959465926697, 1.5673085376630798, 1.5788209995247275, 1.5898765441099831, 1.6005128872164116, 1.6107631526579151, 1.6206565966927626, 1.6302191941285546, 1.6394741167588731, 1.6484421271208254, 1.6571419050167306, 1.665590320178459, 1.6738026614380754, 1.681792830507429, 1.6895735067562174, 1.6971562880676128, 1.704551811839178, 1.7117698594097053, 1.7188194465752762, 1.7257089023700878, 1.7324459378995263, 1.7390377067022496, 1.7454908578676611, 1.7518115829322796, 1.7580056574131675, 1.764078477701164, 1.7700350939251646, 1.7758802393064959, 1.7816183564458072, 1.7872536209209804, 1.7927899625209973, 1.7982310843956588, 1.8035804803630076, 1.8088414505840882, 1.8140171157872769, 1.8191104302010392, 1.8241241933339754, 1.8290610607238498, 1.8339235537625185, 1.838714068690917, 1.8434348848472217, 1.8480881722417257, 1.8526759985236188, 1.8572003353975992, 1.8616630645418843, 1.866065983073615, 1.8704108086027587, 1.8746991839113138, 1.8789326812908167, 1.8831128065678049, 1.887241002843918, 1.8913186539746856, 1.8953470878087106, 1.899327579206876, 1.9032613528593463, 1.9071495859164749, 1.9109934104482469, 1.9147939157455585, 1.9185521504754397, 1.9222691247012598, 1.9259458117779844, 1.9295831501316911, 1.933182044931763, 1.9367433696634706, 1.9402679676080126, 1.9437566532365054, 1.947210213523886, 1.950629409188213, 1.9540149758604126, 1.9573676251891283, 1.9606880458849665, 1.9639769047081035, 1.9672348474029153, 1.970462499583027, 1.9736604675699119, 1.9768293391879561, 1.979969684518682, 1.9830820566166367, 1.9861669921892675, 1.989225012242955, 1.9922566226972045, 1.9952623149688797, 1.9982425665282177], [0.0, 1.001493664034538, 1.1112267960820938, 1.180908896111131, 1.2329833294764518, 1.2749516247181796, 1.310300460418249, 1.340951011062751, 1.3680806619556405, 1.3924659446136214, 1.4146474011505918, 1.4350172076705414, 1.453869390116531, 1.4714303475424102, 1.4878783054137399, 1.5033562066440747, 1.5179805378323479, 1.5318475428207898, 1.545037703037389, 1.5576190362111577, 1.5696495700568112, 1.5811792276686907, 1.5922512855232756, 1.602903515752861, 1.613169091647199, 1.6230773131635792, 1.6326541939072376, 1.6419229402826316, 1.6509043458391228, 1.6596171182803798, 1.668078152535984, 1.6763027602743792, 1.6843048639719016, 1.6920971619369674, 1.6996912693760893, 1.7070978395755287, 1.7143266684841116, 1.72138678536449, 1.7282865316916398, 1.7350336300887481, 1.7416352447794559, 1.7480980347846726, 1.7544282008889924, 1.7606315272361597, 1.7667134182774087, 1.7726789316848306, 1.7785328077495945, 1.7842794957081027, 1.7899231773751476, 1.7954677884094954, 1.8009170374922088, 1.8062744236599204, 1.811543252003007, 1.8167266479111646, 1.8218275700254833, 1.8268488220360888, 1.8317930634472266, 1.8366628194168655, 1.8414604897651194, 1.8461883572347304, 1.850848595077258, 1.855443274030265, 1.8599743687435142, 1.8644437637058182, 1.8688532587186066, 1.8732045739573795, 1.8774993546578997, 1.8817391754601784, 1.885925544439953, 1.890059906854371, 1.8941436486259782, 1.8981780995867368, 1.9021645365017432, 1.9061041858904384, 1.9099982266614421, 1.9138477925756723, 1.9176539745510597, 1.9214178228209902, 1.9251403489575287, 1.928822527769506, 1.9324652990846931, 1.9360695694244918, 1.9396362135788667, 1.9431660760885947, 1.9466599726413383, 1.9501186913875115, 1.9535429941814293, 1.9569336177528038, 1.9602912748132422, 1.9636166551020533, 1.966910426375329, 1.9701732353419708, 1.9734057085500598, 1.9766084532267103, 1.9797820580743204, 1.982927094025923, 1.9860441149621424, 1.9891336583920871, 1.9921962461003453, 1.9952323847620972, 1.9982425665282177, 2.0012272695821234]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 0.4\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.39810717055349726, 0.45730505192732634, 0.49593441964128315, 0.5253055608807534, 0.5492802716530588, 0.5696790520283512, 0.5875158777411962, 0.6034176336545163, 0.617800850567412, 0.6309573444801932, 0.6431000406460919, 0.6543893899412374, 0.6649495102097494, 0.6748785222959511, 0.6842554289186316, 0.6931448431551465, 0.7016003294277899, 0.7096668207625552, 0.7173824042013699, 0.7247796636776956, 0.7318867064175757, 0.7387279587886922, 0.7453247913878536, 0.7516960157530126, 0.7578582832551991, 0.7638264085340232, 0.7696136340726079, 0.775231848384189, 0.7806917672930106, 0.7860030855966228, 0.7911746047651192, 0.7962143411069945, 0.8011296179008336, 0.8059271442790802, 0.8106130830989491, 0.8151931096059227, 0.8196724623577651, 0.8240559876099317, 0.8283481781504691, 0.8325532074018731, 0.8366749594697069, 0.8407170557060673, 0.8446828782648351, 0.8485755910508883, 0.8523981584038259, 0.8561533618057355, 0.8598438148600782, 0.8634719767533109, 0.8670401643811235, 0.8705505632961241, 0.8740052376126373, 0.8774061389863257, 0.8807551147710713, 0.8840539154424948, 0.887304201366326, 0.8905075489802288, 0.8936654564494114, 0.8967793488492094, 0.8998505829216248, 0.9028804514474343, 0.9058701872707864, 0.908820967009122, 0.911733914477673, 0.9146101038546527, 0.9174505626104982, 0.9202562742220908, 0.923028180690743, 0.9257671848808375, 0.9284741526943301, 0.9311499150948378, 0.9337952699937012, 0.9364109840092412, 0.9389977941093632, 0.941556409146734, 0.944087511294902, 0.9465917573929856, 0.9490697802058682, 0.9515221896062347, 0.9539495736842316, 0.9563524997900371, 0.9587315155141827, 0.9610871496100634, 0.9634199128627018, 0.9657302989075099, 0.9680187850024814, 0.9702858327569769, 0.9725318888200211, 0.974757385530792, 0.976962741533791, 0.9791483623609769, 0.9813146409829907, 0.9834619583314299, 0.9855906837939876, 0.9877011756841472, 0.9897937816869886, 0.9918688392825663, 0.9939266761482028, 0.9959676105409554, 0.9979919516614258, 1.0, 1.0019920476665334], [0.0, 0.45730505192732634, 0.5253055608807534, 0.5696790520283512, 0.6034176336545163, 0.6309573444801932, 0.6543893899412374, 0.6748785222959512, 0.6931448431551464, 0.7096668207625552, 0.7247796636776955, 0.7387279587886922, 0.7516960157530127, 0.7638264085340233, 0.7752318483841889, 0.7860030855966227, 0.7962143411069946, 0.8059271442790802, 0.8151931096059227, 0.8240559876099317, 0.8325532074018732, 0.8407170557060671, 0.8485755910508882, 0.8561533618057356, 0.8634719767533109, 0.8705505632961242, 0.8774061389863256, 0.8840539154424948, 0.8905075489802288, 0.8967793488492094, 0.9028804514474343, 0.9088209670091218, 0.9146101038546527, 0.9202562742220908, 0.9257671848808375, 0.9311499150948377, 0.936410984009241, 0.9415564091467339, 0.9465917573929856, 0.9515221896062348, 0.9563524997900369, 0.9610871496100634, 0.96573029890751, 0.970285832756977, 0.9747573855307922, 0.9791483623609769, 0.9834619583314298, 0.9877011756841471, 0.9918688392825663, 0.9959676105409554, 1.0, 1.0039683787044291, 1.0078749885178921, 1.0117219514927545, 1.0155112783974816, 1.0192448764914566, 1.0229245566260303, 1.0265520397411134, 1.030128962818399, 1.0336568843451934, 1.0371372893366482, 1.0405715939588083, 1.043961149790193, 1.0473072477555103, 1.0506111217615068, 1.0538739520617835, 1.057096868374616, 1.0602809527753625, 1.063427242382854, 1.066536731857243, 1.069610375725069, 1.0726490905457766, 1.0756537569325701, 1.07862522143927, 1.0815642983237685, 1.0844717711976986, 1.0873483945710751, 1.0901948952998783, 1.0930119739438586, 1.0958003060411996, 1.0985605433061179, 1.101293314754956, 1.103999227765869, 1.1066788690767724, 1.1093328057258516, 1.111961585938579, 1.1145657399648676, 1.1171457808697174, 1.1197022052804315, 1.1222354940932593, 1.1247461131420948, 1.1272345138316675, 1.129701133737476, 1.1321463971745565, 1.1345707157370173, 1.136974488810138, 1.1393581040567025, 1.1417219378791112, 1.144066355858723, 1.1463917131737604, 1.148698354997035, 1.1509866168746574], [0.0, 0.49593441964128315, 0.5696790520283512, 0.617800850567412, 0.6543893899412373, 0.6842554289186317, 0.7096668207625552, 0.7318867064175758, 0.7516960157530126, 0.7696136340726079, 0.7860030855966228, 0.8011296179008336, 0.8151931096059228, 0.8283481781504691, 0.8407170557060671, 0.8523981584038258, 0.863471976753311, 0.8740052376126373, 0.8840539154424948, 0.8936654564494114, 0.9028804514474343, 0.9117339144776728, 0.9202562742220908, 0.9284741526943302, 0.9364109840092412, 0.9440875112949021, 0.9515221896062347, 0.9587315155141828, 0.96573029890751, 0.972531888820021, 0.9791483623609769, 0.9855906837939876, 0.9918688392825663, 0.9979919516614258, 1.0039683787044291, 1.0098057976734853, 1.0155112783974816, 1.0210913467099034, 1.0265520397411134, 1.0318989542961858, 1.0371372893366482, 1.042271883412973, 1.0473072477555103, 1.0522475956179929, 1.0570968683746162, 1.0618587587949346, 1.066536731857243, 1.0711340434082361, 1.0756537569325701, 1.0800987586588895, 1.0844717711976988, 1.088775365880074, 1.0930119739438588, 1.0971838966949394, 1.1012933147549562, 1.1053422964928696, 1.1093328057258518, 1.1132667087646555, 1.1171457808697174, 1.1209717121765268, 1.1247461131420948, 1.1284705195585214, 1.1321463971745567, 1.1357751459616052, 1.1393581040567025, 1.142896551411561, 1.1463917131737602, 1.149844762823481, 1.153256825086818, 1.156628978644629, 1.1599622586540015, 1.163257659097779, 1.1665161349761233, 1.1697386043527551, 1.1729259502673735, 1.1760790225246736, 1.1791986393694678, 1.1822855890565487, 1.1853406313231891, 1.18836449877148, 1.1913578981670918, 1.1943215116604917, 1.1972559979361437, 1.2001619932947534, 1.2030401126732269, 1.2058909506066127, 1.2087150821359736, 1.2115130636658187, 1.2142854337744386, 1.2170327139802413, 1.2197554094669347, 1.222454009770205, 1.2251289894283288, 1.2277808085989845, 1.2304099136443638, 1.2330167376865286, 1.235601701134824, 1.2381652121870288, 1.240707667305806, 1.243229451671912, 1.2457309396155174, 1.248212495026907], [0.0, 0.5253055608807534, 0.6034176336545163, 0.6543893899412373, 0.6931448431551464, 0.7247796636776955, 0.7516960157530126, 0.7752318483841889, 0.7962143411069945, 0.8151931096059227, 0.8325532074018731, 0.8485755910508882, 0.8634719767533109, 0.8774061389863257, 0.8905075489802287, 0.9028804514474342, 0.9146101038546527, 0.9257671848808375, 0.9364109840092412, 0.9465917573929855, 0.956352499790037, 0.9657302989075099, 0.9747573855307919, 0.9834619583314298, 0.9918688392825662, 1.0, 1.0078749885178921, 1.0155112783974816, 1.0229245566260303, 1.030128962818399, 1.0371372893366482, 1.0439611497901928, 1.0506111217615068, 1.057096868374616, 1.063427242382854, 1.0696103757250688, 1.0756537569325701, 1.0815642983237683, 1.0873483945710751, 1.0930119739438586, 1.0985605433061176, 1.103999227765869, 1.1093328057258516, 1.1145657399648676, 1.1197022052804315, 1.1247461131420948, 1.129701133737476, 1.134570715737017, 1.1393581040567025, 1.144066355858723, 1.148698354997035, 1.153256825086818, 1.1577443413531583, 1.162163341394117, 1.166516134976123, 1.1708049129648923, 1.1750317554823926, 1.1791986393694678, 1.1833074450242969, 1.1873599626786842, 1.1913578981670916, 1.1953028782371258, 1.199196455444808, 1.2030401126732269, 1.2068352673090326, 1.210583275107595, 1.2142854337744386, 1.2179429862877478, 1.2215571239842176, 1.2251289894283288, 1.2286596790831472, 1.2321502457989992, 1.235601701134824, 1.239015017525602, 1.2423911303080353, 1.2457309396155174, 1.2490353121524609, 1.2523050828571352, 1.2555410564613725, 1.2587440089547735, 1.2619146889603865, 1.2650538190282499, 1.2681620968526508, 1.2712401964184674, 1.2742887690815312, 1.2773084445875398, 1.2802998320336965, 1.2832635207769225, 1.2862000812921839, 1.2891100659842116, 1.2919940099556333, 1.2948524317343189, 1.2976858339625241, 1.3004947040502328, 1.3032795147949203, 1.3060407249698005, 1.3087787798824746, 1.3114941119057621, 1.3141871409823676, 1.3168582751049311, 1.3195079107728942, 1.3221364334275216], [0.0, 0.5492802716530588, 0.6309573444801932, 0.6842554289186317, 0.7247796636776955, 0.757858283255199, 0.7860030855966228, 0.8106130830989491, 0.8325532074018731, 0.8523981584038258, 0.8705505632961241, 0.8873042013663259, 0.9028804514474343, 0.9174505626104981, 0.9311499150948376, 0.9440875112949019, 0.956352499790037, 0.9680187850024815, 0.9791483623609768, 0.9897937816869885, 1.0, 1.0098057976734853, 1.0192448764914566, 1.0283467221002136, 1.0371372893366482, 1.0456395525912734, 1.0538739520617832, 1.0618587587949346, 1.069610375725069, 1.077143587792743, 1.0844717711976986, 1.0916070695892885, 1.0985605433061176, 1.1053422964928694, 1.111961585938579, 1.1184269147201447, 1.1247461131420948, 1.1309264089979596, 1.136974488810138, 1.1428965514115608, 1.1486983549970349, 1.1543852585822145, 1.1599622586540015, 1.1654340216704255, 1.1708049129648925, 1.1760790225246736, 1.1812601880431084, 1.1863520155864153, 1.1913578981670916, 1.1962810324748436, 1.2011244339814313, 1.2058909506066127, 1.2105832751075947, 1.2152039563333237, 1.2197554094669347, 1.2242399253642746, 1.2286596790831472, 1.2330167376865284, 1.2373130673931283, 1.2415505401401303, 1.2457309396155174, 1.2498559668109293, 1.2539272451403498, 1.2579463251649878, 1.2619146889603865, 1.2658337541579836, 1.2697048776900042, 1.2735293592636, 1.2773084445875398, 1.2810433283724363, 1.2847351571234393, 1.288385031742493, 1.2919940099556333, 1.295563108579339, 1.2990933056386604, 1.302585542348676, 1.3060407249698005, 1.309459726546512, 1.312843388538244, 1.3161925223504152, 1.3195079107728944, 1.3227903093325808, 1.3260404475662166, 1.3292590302190486, 1.3324467383744965, 1.3356042305195701, 1.3387321435503965, 1.3418310937218834, 1.3449016775452185, 1.3479444726366379, 1.3509600385206135, 1.3539489173903954, 1.356911634828607, 1.3598487004904058, 1.3627606087515323, 1.3656478393234044, 1.3685108578372633, 1.3713501163992303, 1.3741660541180074, 1.3769590976068362, 1.379729661461215, 1.3824781487137754], [0.0, 0.5696790520283512, 0.6543893899412374, 0.7096668207625552, 0.7516960157530126, 0.7860030855966228, 0.8151931096059228, 0.8407170557060673, 0.863471976753311, 0.8840539154424948, 0.9028804514474343, 0.9202562742220908, 0.9364109840092413, 0.9515221896062348, 0.9657302989075099, 0.9791483623609768, 0.9918688392825664, 1.0039683787044293, 1.0155112783974816, 1.0265520397411134, 1.0371372893366482, 1.0473072477555103, 1.057096868374616, 1.0665367318572432, 1.0756537569325701, 1.0844717711976988, 1.0930119739438586, 1.1012933147549562, 1.1093328057258518, 1.1171457808697174, 1.1247461131420948, 1.1321463971745565, 1.1393581040567025, 1.1463917131737604, 1.153256825086818, 1.1599622586540015, 1.1665161349761233, 1.1729259502673732, 1.179198639369468, 1.1853406313231893, 1.1913578981670916, 1.1972559979361435, 1.203040112673227, 1.2087150821359736, 1.2142854337744389, 1.2197554094669347, 1.2251289894283288, 1.2304099136443636, 1.235601701134824, 1.240707667305806, 1.2457309396155174, 1.250674471747736, 1.2555410564613727, 1.260333337262714, 1.26505381902825, 1.2697048776900042, 1.2742887690815314, 1.2788076370309231, 1.2832635207769225, 1.287658361775386, 1.2919940099556335, 1.296272229479523, 1.300494704050233, 1.3046630418126135, 1.3087787798824748, 1.3128433885382442, 1.3168582751049314, 1.3208247875572883, 1.3247442178663313, 1.3286178051109863, 1.3324467383744967, 1.3362321594433206, 1.339975165324572, 1.3436768105965373, 1.347338109605466, 1.3509600385206135, 1.3545435372584498, 1.3580895112859581, 1.3615988333120945, 1.3650723448756752, 1.3685108578372636, 1.371915155781979, 1.3752859953395817, 1.3786241074276457, 1.3819301984231833, 1.3852049512676268, 1.388449026509699, 1.3916630632903442, 1.3948476802735588, 1.3980034765266802, 1.401131032353403, 1.404230910082564, 1.4073036548155013, 1.410349795134583, 1.4133698437753246, 1.416364298264326, 1.4193336415251103, 1.4222783424537948, 1.425198856466388, 1.428095626019391, 1.4309690811052558, 1.4338196397241527], [0.0, 0.5875158777411962, 0.6748785222959512, 0.7318867064175758, 0.7752318483841889, 0.8106130830989491, 0.8407170557060673, 0.8670401643811234, 0.8905075489802288, 0.9117339144776729, 0.9311499150948377, 0.9490697802058681, 0.96573029890751, 0.9813146409829907, 0.9959676105409553, 1.0098057976734853, 1.0229245566260303, 1.035402936335429, 1.0473072477555103, 1.0586936987205566, 1.069610375725069, 1.0800987586588895, 1.0901948952998783, 1.0999303238012526, 1.1093328057258516, 1.1184269147201447, 1.1272345138316673, 1.1357751459616052, 1.144066355858723, 1.1521239576488447, 1.1599622586540015, 1.1675942478475403, 1.1750317554823924, 1.1822855890565487, 1.1893656497276068, 1.1962810324748434, 1.2030401126732269, 1.2096506212457105, 1.21611971016603, 1.222454009770205, 1.228659679083147, 1.2347424501636033, 1.240707667305806, 1.2465603218016819, 1.2523050828571352, 1.2579463251649878, 1.2634881535618547, 1.2689344251335783, 1.2742887690815312, 1.2795546046181907, 1.2847351571234393, 1.2898334727617995, 1.2948524317343189, 1.2997947603162765, 1.3046630418126133, 1.309459726546512, 1.3141871409823678, 1.3188474960721863, 1.3234428949039014, 1.3279753397209468, 1.3324467383744967, 1.3368589102628574, 1.34121359180647, 1.3455124415016924, 1.3497570445919025, 1.3539489173903954, 1.358089511285958, 1.3621802164588452, 1.3662223653320817, 1.3702172357805344, 1.3741660541180074, 1.3780699978806428, 1.3819301984231833, 1.3857477433430851, 1.3895236787460892, 1.39325901136561, 1.3969547105471898, 1.4006117101082607, 1.4042309100825638, 1.4078131783577537, 1.4113593522139962, 1.4148702397707018, 1.4183466213479397, 1.4217892507485372, 1.4251988564663878, 1.428576142826029, 1.4319217910581665, 1.435236460315444, 1.4385207886324167, 1.441775393833404, 1.445000874391587, 1.448197810242491, 1.4513667635547438, 1.4545082794607895, 1.45762288675005, 1.460711098526835, 1.4637734128351516, 1.4668103132523977, 1.4698222694537972, 1.4728097377493, 1.4757731615945522, 1.478712972077439], [0.0, 0.6034176336545163, 0.6931448431551464, 0.7516960157530126, 0.7962143411069945, 0.8325532074018731, 0.863471976753311, 0.8905075489802288, 0.9146101038546527, 0.9364109840092412, 0.956352499790037, 0.974757385530792, 0.9918688392825664, 1.0078749885178921, 1.0229245566260303, 1.0371372893366482, 1.050611121761507, 1.0634272423828541, 1.0756537569325701, 1.087348394571075, 1.0985605433061179, 1.1093328057258516, 1.1197022052804315, 1.129701133737476, 1.1393581040567025, 1.148698354997035, 1.1577443413531583, 1.1665161349761233, 1.1750317554823926, 1.1833074450242969, 1.1913578981670916, 1.1991964554448078, 1.2068352673090326, 1.2142854337744386, 1.2215571239842176, 1.2286596790831472, 1.235601701134824, 1.2423911303080353, 1.2490353121524609, 1.2555410564613727, 1.2619146889603865, 1.2681620968526508, 1.2742887690815312, 1.2802998320336965, 1.286200081292184, 1.2919940099556335, 1.2976858339625241, 1.3032795147949203, 1.3087787798824748, 1.3141871409823676, 1.3195079107728944, 1.3247442178663313, 1.3298990204194987, 1.3349751184972798, 1.339975165324572, 1.3449016775452187, 1.3497570445919025, 1.3545435372584496, 1.3592633155551541, 1.3639184359183454, 1.3685108578372633, 1.3730424499542075, 1.3775149956877262, 1.3819301984231835, 1.3862896863102927, 1.3905950167030172, 1.3948476802735588, 1.3990491048289124, 1.4032006588555799, 1.4073036548155011, 1.4113593522139962, 1.415368960458503, 1.4193336415251103, 1.4232545124482816, 1.4271326476477473, 1.4309690811052556, 1.43476480840274, 1.4385207886324167, 1.442237946188418, 1.4459171724487216, 1.4495593273553913, 1.4531652409004676, 1.4567357145242306, 1.4602715224320013, 1.4637734128351514, 1.4672421091215284, 1.4706783109600874, 1.4740826953441546, 1.4774559175773845, 1.4807986122061831, 1.484111393902059, 1.4873948582971226, 1.4906495827757071, 1.4938761272248584, 1.4970750347462591, 1.500246832331945, 1.5033920315060252, 1.5065111289344464, 1.5096046070047022, 1.5126729343772676, 1.5157165665103982, 1.518735946159841], [0.0, 0.617800850567412, 0.7096668207625552, 0.7696136340726079, 0.8151931096059227, 0.8523981584038258, 0.8840539154424948, 0.9117339144776729, 0.9364109840092412, 0.9587315155141827, 0.9791483623609768, 0.9979919516614257, 1.0155112783974816, 1.0318989542961858, 1.04730724775551, 1.0618587587949344, 1.0756537569325701, 1.088775365880074, 1.1012933147549562, 1.1132667087646555, 1.1247461131420948, 1.1357751459616052, 1.1463917131737602, 1.1566289786446293, 1.166516134976123, 1.1760790225246736, 1.1853406313231891, 1.194321511660492, 1.2030401126732269, 1.2115130636658185, 1.2197554094669347, 1.2277808085989843, 1.235601701134824, 1.243229451671912, 1.250674471747736, 1.2579463251649878, 1.2650538190282499, 1.272005082770202, 1.2788076370309231, 1.2854684539236574, 1.2919940099556333, 1.2983903326588777, 1.3046630418126133, 1.310817385997371, 1.3168582751049314, 1.3227903093325808, 1.3286178051109863, 1.3343448183491105, 1.339975165324572, 1.3455124415016924, 1.3509600385206135, 1.3563211595680134, 1.3615988333120945, 1.3667959265608016, 1.371915155781979, 1.3769590976068362, 1.3819301984231835, 1.3868307831520688, 1.391663063290344, 1.3964291442920798, 1.4011310323534027, 1.4057706406580477, 1.4103497951345831, 1.414870239770702, 1.4193336415251103, 1.4237415948732581, 1.428095626019391, 1.4323971968040765, 1.4366477083334102, 1.44084850435351, 1.445000874391587, 1.4491060566828236, 1.4531652409004676, 1.4571795707049016, 1.4611501461259986, 1.4650780257917608, 1.4689642290150668, 1.4728097377493, 1.476615498422687, 1.4803824236603191, 1.484111393902059, 1.4878032589238495, 1.491458839269306, 1.4950789275979053, 1.4986642899555767, 1.5022156669730249, 1.5057337749966935, 1.5092193071568942, 1.5126729343772676, 1.5160953063294291, 1.5194870523363548, 1.5228487822277943, 1.5261810871507613, 1.5294845403379125, 1.5327596978364408, 1.536007099199899, 1.5392272681452157, 1.5424207131769936, 1.5455879281810383, 1.5487293929889352, 1.5518455739153598, 1.5549369242696978], [0.0, 0.6309573444801932, 0.7247796636776955, 0.7860030855966228, 0.8325532074018731, 0.8705505632961241, 0.9028804514474343, 0.9311499150948377, 0.956352499790037, 0.9791483623609768, 1.0, 1.0192448764914566, 1.0371372893366482, 1.0538739520617835, 1.0696103757250688, 1.0844717711976986, 1.0985605433061179, 1.111961585938579, 1.1247461131420948, 1.136974488810138, 1.148698354997035, 1.1599622586540013, 1.1708049129648923, 1.1812601880431086, 1.1913578981670916, 1.2011244339814313, 1.2105832751075947, 1.2197554094669347, 1.2286596790831472, 1.2373130673931283, 1.2457309396155174, 1.2539272451403496, 1.2619146889603865, 1.2697048776900042, 1.2773084445875398, 1.2847351571234393, 1.2919940099556333, 1.2990933056386602, 1.3060407249698005, 1.3128433885382442, 1.3195079107728942, 1.3260404475662166, 1.3324467383744967, 1.3387321435503967, 1.3449016775452187, 1.3509600385206135, 1.356911634828607, 1.362760608751532, 1.3685108578372633, 1.3741660541180074, 1.379729661461215, 1.3852049512676268, 1.3905950167030172, 1.3959027856259776, 1.4011310323534027, 1.4062823883876352, 1.4113593522139962, 1.4163642982643259, 1.421299485130822, 1.426167063104648, 1.4309690811052556, 1.4357074930589433, 1.4403841637786836, 1.445000874391587, 1.449559327355391, 1.454061151100997, 1.4585079043342193, 1.4629010800265252, 1.4672421091215284, 1.4715323639813442, 1.4757731615945522, 1.4799657665654045, 1.484111393902059, 1.488211211619932, 1.4922663431747896, 1.4962778697388448, 1.500246832331945, 1.5041742338188457, 1.5080610407826143, 1.51190818528332, 1.5157165665103982, 1.5194870523363546, 1.5232204807788452, 1.5269176613775752, 1.5305793764919489, 1.534206382524911, 1.5377994110779951, 1.5413591700421998, 1.5448863446289454, 1.5483815983450517, 1.5518455739153598, 1.5552788941563636, 1.5586821628039584, 1.562055965298185, 1.5654008695276431, 1.5687174265360497, 1.5720061711932456, 1.5752676228327884, 1.5785022858581217, 1.5817106503191745, 1.5848931924611136, 1.5880503752468602], [0.0, 0.6431000406460919, 0.7387279587886922, 0.8011296179008336, 0.8485755910508882, 0.8873042013663259, 0.9202562742220908, 0.9490697802058681, 0.974757385530792, 0.9979919516614257, 1.0192448764914566, 1.0388601182540846, 1.057096868374616, 1.0741556261067757, 1.0901948952998781, 1.1053422964928694, 1.1197022052804315, 1.1333611493232112, 1.1463917131737602, 1.1588554224212262, 1.1708049129648923, 1.1822855890565485, 1.1933369089104922, 1.203993394466273, 1.2142854337744386, 1.2242399253642746, 1.2338808007196633, 1.243229451671912, 1.252305082857135, 1.2611250045563742, 1.2697048776900042, 1.278058920102348, 1.2862000812921839, 1.2941401912417483, 1.3018900878451214, 1.309459726546512, 1.3168582751049311, 1.3240941958565542, 1.3311753174146568, 1.338108897403288, 1.3449016775452185, 1.3515599322023042, 1.358089511285958, 1.364495878308167, 1.370784144222729, 1.3769590976068362, 1.383025231650704, 1.3889867683543775, 1.3948476802735588, 1.4006117101082607, 1.4062823883876352, 1.4118630494701263, 1.4173568460491017, 1.4227667623294298, 1.428095626019391, 1.4333461192642658, 1.4385207886324167, 1.4436220542513314, 1.4486522181795356, 1.4536134720902802, 1.4585079043342193, 1.4633375064407215, 1.4681041791108542, 1.4728097377493, 1.4774559175773845, 1.4820443783649608, 1.4865767088149444, 1.4910544306308542, 1.4954790022946365, 1.4998518225793462, 1.5041742338188457, 1.5084475249545395, 1.5126729343772676, 1.5168516525807585, 1.5209848246415458, 1.5250735525388686, 1.5291188973268721, 1.5331218811703207, 1.537083489254053, 1.5410046715755197, 1.5448863446289454, 1.5487293929889352, 1.552534670800691, 1.5563030031834104, 1.560035187552907, 1.5637319948690074, 1.5673941708128258, 1.5710224368986359, 1.5746174915246671, 1.5781800109668465, 1.5817106503191745, 1.585210044384172, 1.588678808516557, 1.5921175394230915, 1.5955268159213214, 1.5989071996597315, 1.6022592358016672, 1.6055834536751958, 1.608880367390943, 1.6121504764297885, 1.615394266202178, 1.6186122085806973], [0.0, 0.6543893899412374, 0.7516960157530127, 0.8151931096059228, 0.8634719767533109, 0.9028804514474343, 0.9364109840092413, 0.96573029890751, 0.9918688392825664, 1.0155112783974816, 1.0371372893366482, 1.057096868374616, 1.0756537569325704, 1.0930119739438588, 1.1093328057258516, 1.1247461131420948, 1.1393581040567025, 1.153256825086818, 1.1665161349761233, 1.1791986393694678, 1.1913578981670918, 1.2030401126732269, 1.2142854337744386, 1.225128989428329, 1.235601701134824, 1.2457309396155174, 1.2555410564613725, 1.26505381902825, 1.2742887690815314, 1.2832635207769225, 1.2919940099556335, 1.3004947040502328, 1.3087787798824748, 1.3168582751049314, 1.3247442178663313, 1.3324467383744967, 1.339975165324572, 1.347338109605466, 1.3545435372584498, 1.3615988333120945, 1.3685108578372633, 1.3752859953395817, 1.3819301984231835, 1.388449026509699, 1.394847680273559, 1.401131032353403, 1.4073036548155013, 1.4133698437753244, 1.4193336415251103, 1.425198856466388, 1.4309690811052556, 1.4366477083334102, 1.4422379461884183, 1.4477428312616027, 1.4531652409004676, 1.4585079043342195, 1.4637734128351518, 1.4689642290150668, 1.4740826953441544, 1.479131041969563, 1.484111393902059, 1.489025777631467, 1.4938761272248586, 1.4986642899555769, 1.5033920315060254, 1.5080610407826145, 1.5126729343772676, 1.5172292607063653, 1.5217315038548884, 1.5261810871507613, 1.530579376491949, 1.5349276834466783, 1.539227268145216, 1.543479341979905, 1.5476850701286136, 1.5518455739153598, 1.5559619330206462, 1.5600351875529073, 1.564066339991485, 1.5680563570106334, 1.5720061711932458, 1.5759166826422604, 1.5797887604970375, 1.5836232443613925, 1.587420945649437, 1.591182648854871, 1.5949091127489259, 1.598601071511753, 1.6022592358016672, 1.6058842937663336, 1.6094769119996515, 1.6130377364478306, 1.6165673932678817, 1.620066489641501, 1.6235356145471318, 1.626975339492761, 1.6303862192118457, 1.6337687923245836, 1.6371235819665952, 1.6404510963869356, 1.643751829517226, 1.6470262615135756], [0.0, 0.6649495102097494, 0.7638264085340233, 0.8283481781504691, 0.8774061389863257, 0.9174505626104981, 0.9515221896062348, 0.9813146409829907, 1.0078749885178921, 1.0318989542961858, 1.0538739520617835, 1.0741556261067757, 1.0930119739438588, 1.1106503068343223, 1.1272345138316673, 1.1428965514115608, 1.1577443413531585, 1.1718673511139788, 1.1853406313231893, 1.1982277979157663, 1.210583275107595, 1.222454009770205, 1.2338808007196636, 1.2448993427862365, 1.2555410564613725, 1.2658337541579838, 1.2758021804375381, 1.2854684539236574, 1.2948524317343189, 1.303972012271284, 1.3128433885382442, 1.321481261434005, 1.3298990204194987, 1.3381088974032882, 1.34612209849936, 1.3539489173903954, 1.3615988333120945, 1.3690805961104213, 1.3764023003775605, 1.383571450316983, 1.3905950167030172, 1.3974794870703848, 1.404230910082564, 1.4108549348755994, 1.417356846049102, 1.4237415948732581, 1.4300138271954397, 1.4361779084590989, 1.4422379461884183, 1.448197810242491, 1.454061151100997, 1.459831416407964, 1.4655118659702306, 1.4711055853817014, 1.4766154984226871, 1.482044378364961, 1.4873948582971228, 1.4926694405710397, 1.4978705054581976, 1.5030003190944423, 1.5080610407826145, 1.513054729714744, 1.5179833511686485, 1.5228487822277945, 1.5276528170680466, 1.532397171850314, 1.5370834892540532, 1.5417133426830054, 1.5462882401713718, 1.550809628015838, 1.5552788941563638, 1.5596973713264297, 1.5640663399914851, 1.568387031092553, 1.572660628610401, 1.5768882719642627, 1.5810710582578387, 1.5852100443841721, 1.58930624899998, 1.5933606543790917, 1.5973742081538305, 1.601347824952424, 1.6052823879398515, 1.6091787502689212, 1.6130377364478306, 1.6168601436299403, 1.6206467428310498, 1.6243982800790435, 1.628115477500389, 1.6317990343476407, 1.6354496279717667, 1.639067914742847, 1.6426545309224159, 1.6462100934904822, 1.6497352009300494, 1.6532304339717372, 1.6566963563009383, 1.6601335152297616, 1.6635424423358578, 1.666923654070082, 1.6702776523348106, 1.6736049250346068], [0.0, 0.6748785222959511, 0.7752318483841889, 0.8407170557060671, 0.8905075489802287, 0.9311499150948376, 0.9657302989075099, 0.9959676105409553, 1.0229245566260303, 1.04730724775551, 1.0696103757250688, 1.0901948952998781, 1.1093328057258516, 1.1272345138316673, 1.1440663558587227, 1.1599622586540013, 1.1750317554823924, 1.1893656497276068, 1.2030401126732269, 1.2161197101660297, 1.2286596790831472, 1.2407076673058057, 1.252305082857135, 1.2634881535618547, 1.274288769081531, 1.2847351571234393, 1.2948524317343186, 1.3046630418126133, 1.3141871409823676, 1.3234428949039012, 1.3324467383744965, 1.3412135918064698, 1.3497570445919023, 1.358089511285958, 1.3662223653320815, 1.3741660541180072, 1.381930198423183, 1.389523678746089, 1.3969547105471896, 1.4042309100825638, 1.411359352213996, 1.4183466213479394, 1.4251988564663878, 1.4319217910581665, 1.4385207886324167, 1.4450008743915868, 1.4513667635547436, 1.4576228867500496, 1.4637734128351514, 1.469822269453797, 1.475773161594552, 1.481629588381592, 1.4873948582971226, 1.4930721030090721, 1.4986642899555767, 1.5041742338188455, 1.5096046070047022, 1.5149579492300789, 1.5202366763086255, 1.5254430882140804, 1.5305793764919489, 1.535647631082073, 1.5406498466077567, 1.5455879281810383, 1.5504636967683778, 1.5552788941563636, 1.560035187552907, 1.5647341738557805, 1.5693773836171203, 1.5739662847296843, 1.5785022858581217, 1.5829867396362618, 1.5874209456494368, 1.5918061532190553, 1.5961435640050612, 1.6004343344404712, 1.6046795780109158, 1.608880367390943, 1.6130377364478303, 1.617152682122699, 1.6212261661978982, 1.6252591169588655, 1.6292524307579805, 1.6332069734873116, 1.637123581966595, 1.6410030652522687, 1.6448462058729238, 1.6486537609961176, 1.6524264635310943, 1.6561650231716334, 1.659870127382893, 1.6635424423358576, 1.6671826137927048, 1.6707912679461765, 1.6743690122158117, 1.6779164360036871, 1.6814341114121343, 1.6849225939257149, 1.6883824230595854, 1.6918141229762351, 1.6952182030724354, 1.6985951585381307], [0.0, 0.6842554289186316, 0.7860030855966227, 0.8523981584038258, 0.9028804514474342, 0.9440875112949019, 0.9791483623609768, 1.0098057976734853, 1.0371372893366482, 1.0618587587949344, 1.0844717711976986, 1.1053422964928694, 1.1247461131420948, 1.1428965514115608, 1.1599622586540013, 1.1760790225246733, 1.1913578981670916, 1.2058909506066127, 1.2197554094669347, 1.2330167376865284, 1.2457309396155174, 1.2579463251649876, 1.269704877690004, 1.2810433283724365, 1.2919940099556333, 1.302585542348676, 1.312843388538244, 1.3227903093325808, 1.3324467383744965, 1.3418310937218831, 1.3509600385206133, 1.3598487004904056, 1.3685108578372631, 1.376959097606836, 1.3852049512676268, 1.3932590113656098, 1.4011310323534025, 1.408830018117031, 1.4163642982643259, 1.4237415948732581, 1.4309690811052553, 1.4380534328519239, 1.4450008743915868, 1.4518172188753904, 1.4585079043342193, 1.4650780257917608, 1.4715323639813442, 1.4778754110912278, 1.484111393902059, 1.490244294629108, 1.4962778697388448, 1.5022156669730249, 1.5080610407826143, 1.5138171663476052, 1.5194870523363546, 1.5250735525388686, 1.5305793764919489, 1.5360070991998989, 1.5413591700421996, 1.5466379209489174, 1.5518455739153596, 1.5569842479194398, 1.562055965298185, 1.5670626576336675, 1.5720061711932454, 1.5768882719642627, 1.5817106503191742, 1.5864749253433919, 1.5911826488548708, 1.595835309141585, 1.6004343344404715, 1.6049810961791438, 1.609476911999651, 1.6139230485817406, 1.6183207242814768, 1.6226711115996042, 1.6269753394927609, 1.6312344955394649, 1.6354496279717665, 1.6396217475825003, 1.6437518295172258, 1.6478408149591766, 1.6518896127148441, 1.6558991007071868, 1.6598701273828929, 1.663803513039604, 1.6677000510785311, 1.671560509187479, 1.6753856304588906, 1.6791761344471818, 1.6829327181692992, 1.6866560570521496, 1.6903468058302684, 1.6940055993968532, 1.6976330536110606, 1.7012297660642455, 1.7047963168076516, 1.7083332690438622, 1.7118411697841731, 1.7153205504738986, 1.7187719275874789, 1.7221958031951323], [0.0, 0.6931448431551465, 0.7962143411069946, 0.863471976753311, 0.9146101038546527, 0.956352499790037, 0.9918688392825664, 1.0229245566260303, 1.050611121761507, 1.0756537569325701, 1.0985605433061179, 1.1197022052804315, 1.1393581040567025, 1.1577443413531585, 1.1750317554823924, 1.1913578981670916, 1.2068352673090328, 1.2215571239842178, 1.235601701134824, 1.2490353121524609, 1.2619146889603867, 1.2742887690815312, 1.286200081292184, 1.2976858339625243, 1.3087787798824748, 1.3195079107728944, 1.3298990204194987, 1.3399751653245722, 1.3497570445919027, 1.3592633155551543, 1.3685108578372636, 1.3775149956877262, 1.386289686310293, 1.394847680273559, 1.40320065885558, 1.4113593522139962, 1.4193336415251103, 1.4271326476477473, 1.43476480840274, 1.4422379461884183, 1.449559327355391, 1.4567357145242306, 1.4637734128351518, 1.4706783109600876, 1.4774559175773847, 1.4841113939020592, 1.4906495827757071, 1.497075034746259, 1.5033920315060254, 1.5096046070047024, 1.5157165665103982, 1.5217315038548886, 1.5276528170680466, 1.5334837225797973, 1.539227268145216, 1.5448863446289456, 1.5504636967683783, 1.5559619330206462, 1.5613835345860214, 1.5667308636895325, 1.5720061711932458, 1.577211603603497, 1.582349209530239, 1.5874209456494373, 1.5924286822139893, 1.5973742081538305, 1.6022592358016674, 1.607085405277046, 1.6118542885581606, 1.6165673932678815, 1.6212261661978986, 1.6258319965925458, 1.6303862192118457, 1.6348901171914485, 1.6393449247155305, 1.643751829517226, 1.6481119752198636, 1.6524264635310948, 1.6566963563009383, 1.6609226774538108, 1.6651064148037467, 1.6692485217612372, 1.6733499189394143, 1.677411495666656, 1.6814341114121345, 1.68541859713028, 1.6893657565296705, 1.693276367271426, 1.6971511821017766, 1.7009909299231352, 1.7047963168076519, 1.708568026956953, 1.7123067236114715, 1.7160130499125363, 1.7196876297201569, 1.7233310683892178, 1.726943953506622, 1.7305268555917248, 1.734080328762247, 1.7376049113677052, 1.7411011265922485, 1.744569483028675], [0.0, 0.7016003294277899, 0.8059271442790802, 0.8740052376126373, 0.9257671848808375, 0.9680187850024815, 1.0039683787044293, 1.035402936335429, 1.0634272423828541, 1.088775365880074, 1.111961585938579, 1.1333611493232112, 1.153256825086818, 1.1718673511139788, 1.1893656497276068, 1.2058909506066127, 1.2215571239842178, 1.2364585686030398, 1.250674471747736, 1.2642719557490263, 1.27730844458754, 1.2898334727617995, 1.3018900878451216, 1.313515952102519, 1.3247442178663311, 1.3356042305195703, 1.34612209849936, 1.3563211595680136, 1.366222365332082, 1.3758446007209908, 1.3852049512676268, 1.3943189281578565, 1.4032006588555799, 1.4118630494701265, 1.4203179237763002, 1.428576142826029, 1.4366477083334102, 1.4445418524201556, 1.452267115837791, 1.459831416407964, 1.4672421091215284, 1.4745060390944333, 1.4816295883815922, 1.4886187174892525, 1.4954790022946367, 1.502215666973025, 1.5088336134425278, 1.515337447761977, 1.5217315038548884, 1.5280198648800187, 1.5342063825249113, 1.5402946944615223, 1.5462882401713718, 1.5521902753207422, 1.558003884843448, 1.5637319948690076, 1.5693773836171208, 1.5749426913647824, 1.5804304295797547, 1.5858429893032098, 1.591182648854871, 1.596451580925724, 1.6016518591161588, 1.6067854639711023, 1.6118542885581604, 1.6168601436299403, 1.6218047624074317, 1.626689805017555, 1.6315168626146404, 1.6362874612126417, 1.6410030652522691, 1.6456650809248718, 1.6502748592728484, 1.6548336990844736, 1.6593428495994027, 1.6638035130396043, 1.6682168469791587, 1.6725839665651505, 1.6769059466008198, 1.6811838235011594, 1.68541859713028, 1.6896112325290695, 1.6937626615409695, 1.6978737843430347, 1.7019454708888688, 1.7059785622694903, 1.7099738719977002, 1.7139321872210962, 1.7178542698684562, 1.7217408577338755, 1.7255926655026879, 1.7294103857229093, 1.733194689725664, 1.7369462284977875, 1.7406656335095885, 1.744353517500512, 1.7480104752252745, 1.7516370841628426, 1.755233905190469, 1.7588014832248504, 1.7623403478323174, 1.7658510138098542], [0.0, 0.7096668207625552, 0.8151931096059227, 0.8840539154424948, 0.9364109840092412, 0.9791483623609768, 1.0155112783974816, 1.0473072477555103, 1.0756537569325701, 1.1012933147549562, 1.1247461131420948, 1.1463917131737602, 1.1665161349761233, 1.1853406313231893, 1.2030401126732269, 1.2197554094669347, 1.235601701134824, 1.250674471747736, 1.2650538190282499, 1.278807637030923, 1.2919940099556335, 1.3046630418126133, 1.3168582751049311, 1.3286178051109865, 1.339975165324572, 1.3509600385206135, 1.3615988333120943, 1.371915155781979, 1.3819301984231833, 1.391663063290344, 1.4011310323534027, 1.410349795134583, 1.4193336415251103, 1.428095626019391, 1.4366477083334102, 1.445000874391587, 1.4531652409004676, 1.4611501461259986, 1.4689642290150668, 1.4766154984226871, 1.484111393902059, 1.491458839269306, 1.4986642899555769, 1.5057337749966937, 1.5126729343772678, 1.5194870523363548, 1.5261810871507613, 1.5327596978364406, 1.539227268145216, 1.5455879281810383, 1.5518455739153598, 1.558003884843448, 1.5640663399914851, 1.5700362324570412, 1.5759166826422604, 1.5817106503191745, 1.587420945649437, 1.5930502392660313, 1.5986010715117527, 1.6040758609182295, 1.6094769119996513, 1.6148064224270275, 1.620066489641501, 1.625259116958866, 1.6303862192118455, 1.6354496279717667, 1.6404510963869354, 1.6453923036712068, 1.6502748592728484, 1.6551003067508152, 1.659870127382893, 1.6645857435277995, 1.6692485217612372, 1.6738597758040061, 1.678420769258612, 1.6829327181692995, 1.687396793419095, 1.6918141229762353, 1.6961857940012675, 1.7005128548251323, 1.7047963168076519, 1.7090371560850537, 1.7132363152144392, 1.7173947047224452, 1.7215132045647705, 1.7255926655026876, 1.7296339104021774, 1.7336377354608894, 1.737604911367705, 1.741536184399341, 1.7454322774580644, 1.7492938910543054, 1.7531217042376661, 1.7569163754795565, 1.7606785435104721, 1.7644088281146917, 1.7681078308849896, 1.7717761359397661, 1.7754143106048343, 1.7790229060619467, 1.7826024579660036, 1.7861534870327511], [0.0, 0.7173824042013699, 0.8240559876099317, 0.8936654564494114, 0.9465917573929855, 0.9897937816869885, 1.0265520397411134, 1.0586936987205566, 1.087348394571075, 1.1132667087646555, 1.136974488810138, 1.1588554224212262, 1.1791986393694678, 1.1982277979157663, 1.2161197101660297, 1.2330167376865284, 1.2490353121524609, 1.2642719557490263, 1.278807637030923, 1.2927109882050747, 1.3060407249698005, 1.3188474960721863, 1.3311753174146566, 1.343062698452081, 1.3545435372584496, 1.3656478393234044, 1.3764023003775603, 1.3868307831520688, 1.3969547105471896, 1.4067933922974059, 1.4163642982643259, 1.4256832885485538, 1.4347648084027398, 1.4436220542513314, 1.4522671158377907, 1.4607110985268348, 1.4689642290150666, 1.4770359470951882, 1.4849349856377612, 1.4926694405710397, 1.5002468323319447, 1.5076741600131658, 1.514957949230079, 1.5221042945669128, 1.5291188973268721, 1.536007099199899, 1.5427739123697841, 1.5494240465058657, 1.555961933020646, 1.562391746921066, 1.5687174265360497, 1.5749426913647822, 1.5810710582578384, 1.5871058561157436, 1.593050239266031, 1.5989071996597315, 1.604679578010916, 1.6103700739880118, 1.6159812555527289, 1.621515567531263, 1.6269753394927609, 1.632362793001577, 1.637680048302487, 1.6429291304915772, 1.6481119752198634, 1.6532304339717372, 1.6582862789559447, 1.6632812076429573, 1.6682168469791585, 1.6730947573052628, 1.6779164360036873, 1.682683320897205, 1.687396793419095, 1.6920581815730884, 1.6966687626997305, 1.7012297660642455, 1.705742375279642, 1.7102077305775631, 1.7146269309382975, 1.7190010360903663, 1.7233310683892176, 1.7276180145837503, 1.7318628274786603, 1.73606642749994, 1.7402297041702735, 1.7443535175005118, 1.7484386993029348, 1.7524860544315488, 1.756496361954258, 1.7604703762613898, 1.7644088281146915, 1.7683124256406282, 1.772181855271511, 1.7760177826377306, 1.7798208534141378, 1.7835916941233805, 1.7873309128988228, 1.791039100209471, 1.7947168295491724, 1.7983646580921944, 1.8019831273171425, 1.8055727636010468], [0.0, 0.7247796636776956, 0.8325532074018732, 0.9028804514474343, 0.956352499790037, 1.0, 1.0371372893366482, 1.069610375725069, 1.0985605433061179, 1.1247461131420948, 1.148698354997035, 1.1708049129648923, 1.1913578981670918, 1.210583275107595, 1.2286596790831472, 1.2457309396155174, 1.2619146889603867, 1.27730844458754, 1.2919940099556335, 1.3060407249698005, 1.3195079107728944, 1.3324467383744967, 1.3449016775452187, 1.3569116348286072, 1.3685108578372633, 1.3797296614612151, 1.3905950167030172, 1.401131032353403, 1.4113593522139962, 1.421299485130822, 1.4309690811052558, 1.4403841637786836, 1.4495593273553913, 1.4585079043342195, 1.4672421091215284, 1.4757731615945522, 1.484111393902059, 1.4922663431747896, 1.500246832331945, 1.5080610407826145, 1.5157165665103982, 1.5232204807788452, 1.530579376491949, 1.5377994110779953, 1.5448863446289456, 1.5518455739153598, 1.5586821628039584, 1.565400869527643, 1.5720061711932458, 1.578502285858122, 1.5848931924611136, 1.591182648854871, 1.5973742081538305, 1.6034712335843393, 1.6094769119996513, 1.615394266202178, 1.6212261661978986, 1.626975339492761, 1.6326443805279083, 1.6382357593392618, 1.643751829517226, 1.6491948355337254, 1.654566919496354, 1.6598701273828933, 1.6651064148037464, 1.6702776523348106, 1.6753856304588908, 1.6804320641498556, 1.68541859713028, 1.6903468058302684, 1.6952182030724356, 1.7000342415056062, 1.7047963168076519, 1.7095057706759604, 1.7141638936223218, 1.7187719275874789, 1.7233310683892178, 1.7278424680166338, 1.7323072367821057, 1.7367264453415023, 1.7411011265922485, 1.7454322774580644, 1.7497208605684524, 1.7539678058403405, 1.7581740119686893, 1.7623403478323172, 1.7664676538207023, 1.7705567430870701, 1.774608402732652, 1.7786233949266408, 1.7826024579660036, 1.7865463072790226, 1.790455636376128, 1.7943311177513308, 1.798173403737332, 1.8019831273171425, 1.8057609028948687, 1.809507327028114, 1.813222979124284, 1.8169084221029264, 1.8205642030260805, 1.8241908536984925], [0.0, 0.7318867064175757, 0.8407170557060671, 0.9117339144776728, 0.9657302989075099, 1.0098057976734853, 1.0473072477555103, 1.0800987586588895, 1.1093328057258516, 1.1357751459616052, 1.1599622586540013, 1.1822855890565485, 1.2030401126732269, 1.222454009770205, 1.2407076673058057, 1.2579463251649876, 1.2742887690815312, 1.2898334727617995, 1.3046630418126133, 1.3188474960721863, 1.3324467383744967, 1.3455124415016921, 1.358089511285958, 1.3702172357805344, 1.381930198423183, 1.3932590113656098, 1.4042309100825636, 1.4148702397707018, 1.4251988564663878, 1.4352364603154435, 1.4450008743915868, 1.4545082794607895, 1.4637734128351514, 1.4728097377492997, 1.4816295883815918, 1.490244294629108, 1.4986642899555767, 1.5068992050109131, 1.514957949230079, 1.5228487822277943, 1.5305793764919486, 1.5381568726254713, 1.5455879281810383, 1.5528787609654309, 1.5600351875529073, 1.5670626576336675, 1.5739662847296843, 1.5807508737321287, 1.5874209456494368, 1.5939807599003804, 1.6004343344404715, 1.6067854639711021, 1.6130377364478306, 1.6191945480761212, 1.6252591169588655, 1.6312344955394649, 1.6371235819665952, 1.642929130491577, 1.6486537609961174, 1.6542999677368109, 1.6598701273828929, 1.6653665064151257, 1.6707912679461767, 1.676146478016272, 1.6814341114121343, 1.6866560570521496, 1.691814122976235, 1.696910040974946, 1.7019454708888686, 1.7069220046062619, 1.7118411697841731, 1.716704433315807, 1.7215132045647705, 1.7262688383848641, 1.7309726379423758, 1.735625857356268, 1.7402297041702735, 1.7447853416696602, 1.7492938910543052, 1.7537564334787121, 1.7581740119686893, 1.7625476332235885, 1.766878269312263, 1.7711668592702177, 1.775414310604834, 1.7796215007149805, 1.7837892782308242, 1.787918464279207, 1.7920098536795153, 1.7960642160746187, 1.8000822970010757, 1.8040648189025128, 1.8080124820897834, 1.8119259656512388, 1.8158059283162225, 1.8196530092746486, 1.8234678289553456, 1.8272509897656406, 1.8310030767944907, 1.8347246584813188, 1.838416287252544, 1.8420785001276823], [0.0, 0.7387279587886922, 0.8485755910508882, 0.9202562742220908, 0.9747573855307919, 1.0192448764914566, 1.057096868374616, 1.0901948952998783, 1.1197022052804315, 1.1463917131737602, 1.1708049129648923, 1.1933369089104922, 1.2142854337744386, 1.2338808007196636, 1.252305082857135, 1.269704877690004, 1.286200081292184, 1.3018900878451216, 1.3168582751049311, 1.3311753174146566, 1.3449016775452187, 1.358089511285958, 1.370784144222729, 1.3830252316507041, 1.3948476802735588, 1.4062823883876352, 1.4173568460491017, 1.428095626019391, 1.4385207886324167, 1.4486522181795356, 1.4585079043342193, 1.4681041791108542, 1.4774559175773845, 1.4865767088149446, 1.4954790022946365, 1.5041742338188457, 1.5126729343772674, 1.5209848246415458, 1.5291188973268721, 1.5370834892540532, 1.5448863446289454, 1.552534670800691, 1.5600351875529073, 1.5673941708128258, 1.5746174915246676, 1.5817106503191745, 1.5886788085165569, 1.5955268159213212, 1.6022592358016672, 1.608880367390943, 1.615394266202178, 1.6218047624074317, 1.628115477500389, 1.6343298394322734, 1.6404510963869354, 1.6464823293402462, 1.6524264635310946, 1.6582862789559447, 1.6640644199856383, 1.6697634041916334, 1.6753856304588906, 1.6809333864539198, 1.686408855508911, 1.6918141229762353, 1.6971511821017764, 1.702421939460434, 1.7076282199926331, 1.7127717716767028, 1.717854269868456, 1.7228773213361999, 1.7278424680166335, 1.7327511905146284, 1.737604911367705, 1.7424049980940515, 1.7471527660411976, 1.7518494810508827, 1.7564963619542582, 1.7610945829103073, 1.7656452755992336, 1.7701495312815458, 1.774608402732652, 1.7790229060619465, 1.7833940224246172, 1.7877226996337288, 1.7920098536795153, 1.7962563701622607, 1.8004631056446347, 1.8046308889288964, 1.808760522263943, 1.8128527824868192, 1.8169084221029261, 1.820928170308875, 1.8249127339616187, 1.8288627984972323, 1.832779028802479, 1.8366620700420495, 1.8405125484441816, 1.8443310720471557, 1.8481182314090017, 1.8518746002825843, 1.8556007362580844, 1.8592971813747647], [0.0, 0.7453247913878536, 0.8561533618057356, 0.9284741526943302, 0.9834619583314298, 1.0283467221002136, 1.0665367318572432, 1.0999303238012526, 1.129701133737476, 1.1566289786446293, 1.1812601880431086, 1.203993394466273, 1.225128989428329, 1.2448993427862365, 1.2634881535618547, 1.2810433283724365, 1.2976858339625243, 1.313515952102519, 1.3286178051109865, 1.343062698452081, 1.3569116348286072, 1.3702172357805344, 1.3830252316507041, 1.3953756318556403, 1.4073036548155013, 1.418840474748078, 1.4300138271954397, 1.4408485043535102, 1.451366763554744, 1.4615886666570022, 1.4715323639813445, 1.4812143333868666, 1.4906495827757071, 1.4998518225793465, 1.5088336134425278, 1.5176064932892266, 1.5261810871507613, 1.5345672025042674, 1.5427739123697843, 1.5508096280158383, 1.5586821628039584, 1.566398788444837, 1.5739662847296847, 1.5813909836296955, 1.5886788085165573, 1.5958353091415851, 1.6028656929155223, 1.6097748529515759, 1.6165673932678817, 1.623247651489894, 1.6298197193463293, 1.636287461212642, 1.6426545309224159, 1.6489243870384414, 1.6551003067508154, 1.66118539854849, 1.667182613792705, 1.6730947573052632, 1.6789244970712083, 1.6846743731438842, 1.6903468058302684, 1.6959441032257074, 1.7014684681595236, 1.7069220046062623, 1.7123067236114713, 1.7176245487757429, 1.7228773213362, 1.7280668048805998, 1.733194689725664, 1.738262596988123, 1.7432720823741537, 1.748224639710413, 1.7531217042376661, 1.7579646556860233, 1.762754821149054, 1.7674934777724498, 1.7721818552715112, 1.7768211382904486, 1.781412468615357, 1.7859569472516899, 1.790455636376128, 1.794909561171911, 1.799319711555933, 1.8036870438052182, 1.8080124820897834, 1.8122969199183139, 1.8165412215025742, 1.8207462230460187, 1.8249127339616187, 1.829041538023565, 1.8331333944571238, 1.837189038970624, 1.8412091847332432, 1.8451945233019935, 1.8491457255010695, 1.8530634422564756, 1.8569483053886604, 1.8608009283656803, 1.8646219070192416, 1.8684118202258155, 1.8721712305548577, 1.8759006848860353], [0.0, 0.7516960157530126, 0.8634719767533109, 0.9364109840092412, 0.9918688392825662, 1.0371372893366482, 1.0756537569325701, 1.1093328057258516, 1.1393581040567025, 1.166516134976123, 1.1913578981670916, 1.2142854337744386, 1.235601701134824, 1.2555410564613725, 1.274288769081531, 1.2919940099556333, 1.3087787798824748, 1.3247442178663311, 1.339975165324572, 1.3545435372584496, 1.3685108578372633, 1.381930198423183, 1.3948476802735588, 1.4073036548155013, 1.41933364152511, 1.4309690811052556, 1.442237946188418, 1.4531652409004676, 1.4637734128351516, 1.4740826953441544, 1.484111393902059, 1.4938761272248584, 1.5033920315060252, 1.5126729343772676, 1.5217315038548884, 1.5305793764919489, 1.5392272681452157, 1.5476850701286133, 1.555961933020646, 1.564066339991485, 1.5720061711932454, 1.5797887604970373, 1.587420945649437, 1.5949091127489257, 1.6022592358016674, 1.6094769119996513, 1.6165673932678812, 1.6235356145471314, 1.6303862192118455, 1.6371235819665952, 1.6437518295172258, 1.6502748592728484, 1.6566963563009383, 1.663019808728953, 1.6692485217612372, 1.6753856304588906, 1.6814341114121345, 1.6873967934190948, 1.6932763672714255, 1.6990753947354873, 1.7047963168076516, 1.7104414613134469, 1.7160130499125363, 1.7215132045647705, 1.7269439535066218, 1.7323072367821057, 1.737604911367705, 1.7428387559267693, 1.7480104752252745, 1.753121704237666, 1.7581740119686893, 1.7631689050146089, 1.7681078308849896, 1.7729921811042229, 1.777823294110209, 1.7826024579660034, 1.7873309128988228, 1.7920098536795155, 1.796640431854452, 1.801223757840758, 1.8057609028948687, 1.8102529009635488, 1.8147007504257517, 1.8191054157329989, 1.8234678289553456, 1.827788891239415, 1.8320694741844714, 1.8363104211420478, 1.8405125484441816, 1.8446766465649627, 1.848803481219707, 1.8528937944057637, 1.8569483053886604, 1.860967711637013, 1.8649526897093904, 1.868903896096077, 1.8728219680184823, 1.8767075241887416, 1.8805611655318815, 1.8843834758727553, 1.888175022589804, 1.8919363572375605], [0.0, 0.7578582832551991, 0.8705505632961242, 0.9440875112949021, 1.0, 1.0456395525912734, 1.0844717711976988, 1.1184269147201447, 1.148698354997035, 1.1760790225246736, 1.2011244339814313, 1.2242399253642746, 1.2457309396155174, 1.2658337541579838, 1.2847351571234393, 1.302585542348676, 1.3195079107728944, 1.3356042305195703, 1.3509600385206135, 1.3656478393234044, 1.3797296614612151, 1.3932590113656098, 1.4062823883876352, 1.418840474748078, 1.4309690811052556, 1.4426999059072139, 1.454061151100997, 1.465078025791761, 1.4757731615945522, 1.4861669577303998, 1.496277869738845, 1.506122652573098, 1.5157165665103982, 1.5250735525388688, 1.534206382524911, 1.5431267884159363, 1.5518455739153598, 1.5603727114243022, 1.5687174265360497, 1.576888271964263, 1.5848931924611136, 1.5927395820194559, 1.6004343344404717, 1.6079838881747186, 1.6153942662021783, 1.6226711115996046, 1.6298197193463293, 1.6368450648388746, 1.643751829517226, 1.6505444239489886, 1.6572270086699936, 1.6638035130396043, 1.6702776523348106, 1.6766529432781057, 1.6829327181692995, 1.6891201377701537, 1.6952182030724359, 1.7012297660642455, 1.7071575395958585, 1.7130041064345305, 1.7187719275874789, 1.724463349963323, 1.7300806134344886, 1.7356258573562682, 1.7411011265922485, 1.7465083770905736, 1.7518494810508827, 1.7571262317176846, 1.7623403478323174, 1.7674934777724496, 1.772587203405244, 1.7776230436777665, 1.7826024579660036, 1.7875268492018108, 1.7923975667953596, 1.7972159093690119, 1.8019831273171425, 1.8067004252051142, 1.8113689640194657, 1.8159898632803209, 1.8205642030260805, 1.8250930256796174, 1.8295773378044142, 1.834018111758391, 1.8384162872525442, 1.842772772820933, 1.8470884472080353, 1.8513641606790259, 1.8556007362580844, 1.8597989708994642, 1.863959636595676, 1.8680834814268286, 1.8721712305548577, 1.8762235871661006, 1.8802412333654308, 1.8842248310249203, 1.8881750225898042, 1.8920924318443078, 1.895977664639732, 1.89983130958702, 1.9036539387158788, 1.9074461081023846], [0.0, 0.7638264085340232, 0.8774061389863256, 0.9515221896062347, 1.0078749885178921, 1.0538739520617832, 1.0930119739438586, 1.1272345138316673, 1.1577443413531583, 1.1853406313231891, 1.2105832751075947, 1.2338808007196633, 1.2555410564613725, 1.2758021804375381, 1.2948524317343186, 1.312843388538244, 1.3298990204194987, 1.34612209849936, 1.3615988333120943, 1.3764023003775603, 1.3905950167030172, 1.4042309100825636, 1.4173568460491017, 1.4300138271954397, 1.442237946188418, 1.454061151100997, 1.4655118659702302, 1.4766154984226871, 1.4873948582971226, 1.4978705054581973, 1.5080610407826143, 1.517983351168648, 1.5276528170680463, 1.5370834892540532, 1.5462882401713716, 1.5552788941563633, 1.564066339991485, 1.5726606286104008, 1.5810710582578384, 1.58930624899998, 1.59737420815383, 1.6052823879398512, 1.6130377364478306, 1.6206467428310498, 1.628115477500389, 1.6354496279717665, 1.6426545309224156, 1.649735200930049, 1.656696356300938, 1.6635424423358576, 1.6702776523348104, 1.6769059466008196, 1.683431069668639, 1.6898565659549105, 1.6961857940012675, 1.7024219394604339, 1.7085680269569528, 1.7146269309382978, 1.7206013856184086, 1.7264939941038042, 1.7323072367821055, 1.7380434790438097, 1.743704978400313, 1.7492938910543054, 1.7548122779726512, 1.7602621105065641, 1.7656452755992336, 1.7709635806169484, 1.7762187578361146, 1.7814124686153567, 1.7865463072790226, 1.7916218047358692, 1.796640431854452, 1.8016036026146989, 1.8065126770533706, 1.8113689640194657, 1.8161737237542004, 1.820928170308875, 1.825633473812785, 1.8302907626022618, 1.8349011252209961, 1.8394656123009292, 1.8439852383322193, 1.8484609833300942, 1.8528937944057637, 1.857284587247982, 1.8616342475213297, 1.8659436321868101, 1.8702135707499088, 1.8744448664408848, 1.878638297331681, 1.8827946173935286, 1.8869145574990052, 1.8909988263720319, 1.8950481114890507, 1.8990630799343686, 1.9030443792124694, 1.9069926380198723, 1.9109084669789496, 1.9147924593359495, 1.9186451916253062, 1.9224672243021887], [0.0, 0.7696136340726079, 0.8840539154424948, 0.9587315155141828, 1.0155112783974816, 1.0618587587949346, 1.1012933147549562, 1.1357751459616052, 1.1665161349761233, 1.194321511660492, 1.2197554094669347, 1.243229451671912, 1.26505381902825, 1.2854684539236574, 1.3046630418126133, 1.3227903093325808, 1.3399751653245722, 1.3563211595680136, 1.371915155781979, 1.3868307831520688, 1.401131032353403, 1.4148702397707018, 1.428095626019391, 1.4408485043535102, 1.4531652409004676, 1.465078025791761, 1.4766154984226871, 1.4878032589238497, 1.4986642899555769, 1.5092193071568942, 1.5194870523363548, 1.5294845403379125, 1.5392272681452157, 1.5487293929889354, 1.558003884843448, 1.5670626576336675, 1.5759166826422604, 1.5845760869550378, 1.5930502392660313, 1.6013478249524242, 1.609476911999651, 1.6174450090908479, 1.625259116958866, 1.6329257739228613, 1.6404510963869356, 1.6478408149591768, 1.6551003067508154, 1.6622346243331343, 1.6692485217612372, 1.676146478016272, 1.6829327181692995, 1.6896112325290695, 1.6961857940012677, 1.702659973857249, 1.7090371560850537, 1.7153205504738989, 1.7215132045647707, 1.7276180145837505, 1.7336377354608894, 1.7395749900254656, 1.7454322774580644, 1.7512119810708577, 1.7569163754795567, 1.762547633223589, 1.7681078308849896, 1.7735989547511593, 1.7790229060619465, 1.7843815058773753, 1.7896764995986587, 1.794909561171911, 1.800082297001076, 1.8051962495940308, 1.810252900963549, 1.815253675802753, 1.8201999444528907, 1.8250930256796174, 1.8299341892725232, 1.834724658481319, 1.8394656123009294, 1.8441581876166662, 1.8488034812197072, 1.853402551702236, 1.8579564212408215, 1.8624660772758987, 1.8669324740945827, 1.8713565343234575, 1.875739150337451, 1.880081185590438, 1.8843834758727553, 1.8886468305004354, 1.89287203344058, 1.8970598443769766, 1.9012109997197497, 1.9053262135625555, 1.909406178590586, 1.9134515669423955, 1.9174630310283656, 1.9214412043084128, 1.9253867020313657, 1.9293001219382762, 1.933182044931763, 1.9370330357133534], [0.0, 0.775231848384189, 0.8905075489802288, 0.96573029890751, 1.0229245566260303, 1.069610375725069, 1.1093328057258518, 1.144066355858723, 1.1750317554823926, 1.2030401126732269, 1.2286596790831472, 1.252305082857135, 1.2742887690815314, 1.2948524317343189, 1.3141871409823676, 1.3324467383744965, 1.3497570445919027, 1.366222365332082, 1.3819301984231833, 1.3969547105471896, 1.4113593522139962, 1.4251988564663878, 1.4385207886324167, 1.451366763554744, 1.4637734128351516, 1.4757731615945522, 1.4873948582971226, 1.4986642899555769, 1.5096046070047022, 1.5202366763086255, 1.530579376491949, 1.5406498466077567, 1.550463696768378, 1.5600351875529073, 1.5693773836171205, 1.5785022858581217, 1.5874209456494368, 1.5961435640050612, 1.604679578010916, 1.6130377364478308, 1.6212261661978982, 1.6292524307579805, 1.6371235819665952, 1.6448462058729243, 1.6524264635310948, 1.6598701273828933, 1.6671826137927048, 1.6743690122158117, 1.6814341114121345, 1.6883824230595856, 1.6952182030724356, 1.7019454708888688, 1.708568026956953, 1.7150894686184848, 1.7215132045647705, 1.7278424680166335, 1.734080328762247, 1.7402297041702737, 1.7462933692818783, 1.7522739660731113, 1.7581740119686893, 1.763995907679071, 1.7697419444247648, 1.7754143106048343, 1.7810150979604575, 1.7865463072790226, 1.7920098536795155, 1.79740757151578, 1.8027412189305372, 1.8080124820897834, 1.813222979124284, 1.8183742638022937, 1.823467828955346, 1.8285051096768874, 1.8334874863117185, 1.8384162872525442, 1.8432927915584756, 1.8481182314090019, 1.8528937944057637, 1.8576206257333876, 1.8622998301896756, 1.8669324740945827, 1.8715195870866133, 1.8760621638145611, 1.8805611655318815, 1.8850175216003735, 1.8894321309093423, 1.8938058632159154, 1.8981395604117364, 1.9024340377208817, 1.9066900848334485, 1.9109084669789498, 1.9150899259433374, 1.9192351810331836, 1.9233449299903136, 1.9274198498599235, 1.93146059781502, 1.935467811939806, 1.939442111974454, 1.943384100023553, 1.9472943612303366, 1.951173464418679], [0.0, 0.7806917672930106, 0.8967793488492094, 0.972531888820021, 1.030128962818399, 1.077143587792743, 1.1171457808697174, 1.1521239576488447, 1.1833074450242969, 1.2115130636658185, 1.2373130673931283, 1.2611250045563742, 1.2832635207769225, 1.303972012271284, 1.3234428949039012, 1.3418310937218831, 1.3592633155551543, 1.3758446007209908, 1.391663063290344, 1.4067933922974059, 1.421299485130822, 1.4352364603154435, 1.4486522181795356, 1.4615886666570022, 1.4740826953441544, 1.4861669577303998, 1.4978705054581973, 1.5092193071568942, 1.5202366763086255, 1.530943626741792, 1.5413591700421998, 1.551500565972421, 1.5613835345860212, 1.5710224368986359, 1.5804304295797544, 1.5896195980481953, 1.5986010715117525, 1.6073851228296494, 1.6159812555527289, 1.6243982800790435, 1.632644380527908, 1.6407271736655122, 1.6486537609961176, 1.6564307749541192, 1.6640644199856385, 1.671560509187479, 1.678924497071208, 1.6861615089368849, 1.6932763672714257, 1.7002736155282634, 1.7071575395958583, 1.713932187221096, 1.7206013856184088, 1.7271687574654908, 1.7336377354608892, 1.7400115755968395, 1.7462933692818783, 1.7524860544315486, 1.7585924256314913, 1.764615143465061, 1.77055674308707, 1.7764196421160596, 1.782206147909489, 1.787918464279207, 1.7935586976984188, 1.7991288630459576, 1.8046308889288962, 1.8100666226203401, 1.8154378346455213, 1.8207462230460183, 1.8259934173490102, 1.8311809822658631, 1.8363104211420478, 1.841383179178302, 1.8464006464411256, 1.8513641606790256, 1.856275009959463, 1.8611344351401047, 1.86594363218681, 1.870703754349683, 1.8754159142075613, 1.8800811855904378, 1.8847006053885085, 1.8892751752558297, 1.893805863215915, 1.8982936051760129, 1.9027393063562603, 1.9071438426394407, 1.9115080618465978, 1.9158327849433907, 1.9201188071816635, 1.9243668991804026, 1.9285778079499212, 1.9327522578628311, 1.9368909515751183, 1.9409945709003742, 1.945063777640042, 1.949099214372319, 1.9531015052021772, 1.9570712564747974, 1.961009057454548, 1.964915480971501], [0.0, 0.7860030855966228, 0.9028804514474343, 0.9791483623609769, 1.0371372893366482, 1.0844717711976986, 1.1247461131420948, 1.1599622586540015, 1.1913578981670916, 1.2197554094669347, 1.2457309396155174, 1.2697048776900042, 1.2919940099556335, 1.3128433885382442, 1.3324467383744965, 1.3509600385206133, 1.3685108578372636, 1.3852049512676268, 1.4011310323534027, 1.4163642982643259, 1.4309690811052558, 1.4450008743915868, 1.4585079043342193, 1.4715323639813445, 1.484111393902059, 1.496277869738845, 1.5080610407826143, 1.5194870523363548, 1.530579376491949, 1.5413591700421998, 1.5518455739153598, 1.562055965298185, 1.5720061711932456, 1.5817106503191745, 1.591182648854871, 1.6004343344404715, 1.6094769119996513, 1.6183207242814768, 1.626975339492761, 1.6354496279717667, 1.6437518295172258, 1.6518896127148444, 1.6598701273828933, 1.6677000510785314, 1.675385630458891, 1.6829327181692995, 1.6903468058302684, 1.6976330536110604, 1.7047963168076519, 1.7118411697841733, 1.7187719275874789, 1.7255926655026876, 1.7323072367821057, 1.7389192887497673, 1.7454322774580644, 1.7518494810508827, 1.7581740119686895, 1.7644088281146917, 1.7705567430870701, 1.776620435570056, 1.7826024579660036, 1.7885052443413563, 1.7943311177513308, 1.800082297001076, 1.8057609028948687, 1.811368964019466, 1.8169084221029261, 1.8223811369859984, 1.8277888912394151, 1.8331333944571235, 1.8384162872525442, 1.8436391449823208, 1.8488034812197072, 1.8539107509976454, 1.8589623538397428, 1.8639596365956759, 1.8689038960960773, 1.8737963816406016, 1.878638297331681, 1.883430804265382, 1.8881750225898042, 1.89287203344058, 1.897522880762231, 1.9021285730234152, 1.9066900848334483, 1.9112083584668813, 1.9156843053023802, 1.9201188071816635, 1.9245127176937982, 1.9288668633897579, 1.9331820449317632, 1.9374590381815897, 1.941698595231722, 1.945901445382932, 1.950068296071619, 1.9541998337499895, 1.9582967247219538, 1.962359615937392, 1.96638913574728, 1.9703858946219763, 1.9743504858348202, 1.978283486113046], [0.0, 0.7911746047651192, 0.9088209670091218, 0.9855906837939876, 1.0439611497901928, 1.0916070695892885, 1.1321463971745565, 1.1675942478475403, 1.1991964554448078, 1.2277808085989843, 1.2539272451403496, 1.278058920102348, 1.3004947040502328, 1.321481261434005, 1.3412135918064698, 1.3598487004904056, 1.3775149956877262, 1.3943189281578565, 1.410349795134583, 1.4256832885485538, 1.4403841637786836, 1.4545082794607895, 1.4681041791108542, 1.4812143333868666, 1.4938761272248584, 1.506122652573098, 1.517983351168648, 1.5294845403379125, 1.5406498466077567, 1.551500565972421, 1.562055965298185, 1.5723335361052664, 1.5823492095302385, 1.5921175394230915, 1.6016518591161586, 1.6109644163067485, 1.6200664896415007, 1.6289684899197554, 1.637680048302487, 1.6462100934904822, 1.6545669194963535, 1.6627582453613823, 1.6707912679461767, 1.678672708742984, 1.686408855508911, 1.6940055993968535, 1.7014684681595231, 1.7088026559175944, 1.7160130499125361, 1.7231042546055775, 1.7300806134344884, 1.7369462284977875, 1.743704978400313, 1.750360534463722, 1.7569163754795563, 1.7633758011602985, 1.7697419444247646, 1.7760177826377306, 1.782206147909489, 1.7883097365487142, 1.7943311177513306, 1.8002727415987583, 1.8061369464307908, 1.811925965651239, 1.8176419340182437, 1.823286893465679, 1.828862798497232, 1.8343715211905027, 1.8398148558446743, 1.845194523301993, 1.8505121749703208, 1.8557693965713833, 1.860967711637013, 1.8661085847735632, 1.8711934247128275, 1.8762235871661006, 1.8812003774965316, 1.8861250532235614, 1.8909988263720319, 1.8958228656774587, 1.900598298657973, 1.9053262135625553, 1.9100076612043762, 1.9146436566873282, 1.9192351810331834, 1.923783182716203, 1.9282885791114823, 1.9327522578628313, 1.9371750781755182, 1.941557872038822, 1.945901445382932, 1.9502065791744183, 1.9544740304541695, 1.9587045333214026, 1.9628987998671055, 1.9670575210600076, 1.9711813675879752, 1.9752709906575057, 1.979327022753819, 1.9833500783638733, 1.9873407546644581, 1.991299632177394], [0.0, 0.7962143411069945, 0.9146101038546527, 0.9918688392825663, 1.0506111217615068, 1.0985605433061176, 1.1393581040567025, 1.1750317554823924, 1.2068352673090326, 1.235601701134824, 1.2619146889603865, 1.2862000812921839, 1.3087787798824748, 1.3298990204194987, 1.3497570445919023, 1.3685108578372631, 1.386289686310293, 1.4032006588555799, 1.4193336415251103, 1.4347648084027398, 1.4495593273553913, 1.4637734128351514, 1.4774559175773845, 1.4906495827757071, 1.5033920315060252, 1.5157165665103982, 1.5276528170680463, 1.5392272681452157, 1.550463696768378, 1.5613835345860212, 1.5720061711932456, 1.5823492095302385, 1.592428682213989, 1.6022592358016672, 1.6118542885581604, 1.6212261661978982, 1.6303862192118455, 1.6393449247155303, 1.6481119752198634, 1.6566963563009383, 1.6651064148037462, 1.6733499189394139, 1.6814341114121345, 1.6893657565296702, 1.6971511821017766, 1.7047963168076519, 1.712306723611471, 1.7196876297201564, 1.7269439535066218, 1.734080328762247, 1.7411011265922482, 1.7480104752252745, 1.7548122779726514, 1.7615102295421425, 1.7681078308849896, 1.774608402732652, 1.7810150979604575, 1.7873309128988228, 1.7935586976984188, 1.7997011658432496, 1.8057609028948687, 1.8117403745415728, 1.817641934018244, 1.823467828955346, 1.8292202077093054, 1.8349011252209964, 1.8405125484441816, 1.846056361381486, 1.851534369761675, 1.8569483053886602, 1.8622998301896756, 1.8675905399874024, 1.8728219680184823, 1.8779955882187265, 1.883112818293468, 1.888175022589804, 1.8931835147859712, 1.8981395604117364, 1.9030443792124694, 1.9078991473684632, 1.9127049995800742, 1.9174630310283654, 1.9221742992201267, 1.9268398257254036, 1.9314605978150199, 1.9360375700049628, 1.9405716655139538, 1.9450637776400421, 1.949514771061584, 1.953925483067582, 1.9582967247219538, 1.9626292819659814, 1.9669239166628598, 1.9711813675879752, 1.9754023513682943, 1.9795875633739772, 1.9837376785651326, 1.9878533522964057, 1.9919352210819108, 1.9959839033228517, 2.0, 2.0039840953330668], [0.0, 0.8011296179008336, 0.9202562742220908, 0.9979919516614258, 1.057096868374616, 1.1053422964928694, 1.1463917131737604, 1.1822855890565487, 1.2142854337744386, 1.243229451671912, 1.2697048776900042, 1.2941401912417483, 1.3168582751049314, 1.3381088974032882, 1.358089511285958, 1.376959097606836, 1.394847680273559, 1.4118630494701265, 1.428095626019391, 1.4436220542513314, 1.4585079043342195, 1.4728097377492997, 1.4865767088149446, 1.4998518225793465, 1.5126729343772676, 1.5250735525388688, 1.5370834892540532, 1.5487293929889354, 1.5600351875529073, 1.5710224368986359, 1.5817106503191745, 1.5921175394230915, 1.6022592358016672, 1.6121504764297885, 1.6218047624074317, 1.6312344955394649, 1.6404510963869354, 1.6494651067438382, 1.658286278955945, 1.666923654070082, 1.6753856304588906, 1.6836800242890615, 1.6918141229762353, 1.6997947325863336, 1.7076282199926334, 1.7153205504738989, 1.7228773213362, 1.7303037920556197, 1.7376049113677052, 1.7447853416696602, 1.7518494810508827, 1.7588014832248502, 1.7656452755992338, 1.772384575690368, 1.7790229060619465, 1.7855636079453292, 1.7920098536795155, 1.7983646580921944, 1.8046308889288962, 1.8108112764247994, 1.8169084221029261, 1.8229248068730282, 1.8288627984972323, 1.834724658481319, 1.8405125484441816, 1.8462285360124782, 1.851874600282584, 1.8574526368876543, 1.862964462703774, 1.8684118202258153, 1.8737963816406016, 1.8791197526223202, 1.8843834758727553, 1.8895890344267787, 1.894737854741656, 1.8998313095870198, 1.9048707207508482, 1.9098573615754133, 1.9147924593359495, 1.9196771974736742, 1.9245127176937982, 1.9293001219382762, 1.934040474242213, 1.9387348024821214, 1.9433841000235528, 1.947989327275016, 1.9525514131545463, 1.9570712564747976, 1.9615497272520528, 1.965987667944157, 1.9703858946219763, 1.9747451980786506, 1.9790663448805912, 1.9833500783638733, 1.9875971195794222, 1.9918081681901332, 1.9959839033228517, 2.0001249843779294, 2.0042320517988785, 2.0083057278044842, 2.0123466170855586, 2.01635530746838], [0.0, 0.8059271442790802, 0.9257671848808375, 1.0039683787044291, 1.063427242382854, 1.111961585938579, 1.153256825086818, 1.1893656497276068, 1.2215571239842176, 1.250674471747736, 1.2773084445875398, 1.3018900878451214, 1.3247442178663313, 1.34612209849936, 1.3662223653320815, 1.3852049512676268, 1.40320065885558, 1.4203179237763002, 1.4366477083334102, 1.4522671158377907, 1.4672421091215284, 1.4816295883815918, 1.4954790022946365, 1.5088336134425278, 1.5217315038548884, 1.534206382524911, 1.5462882401713716, 1.558003884843448, 1.5693773836171205, 1.5804304295797544, 1.591182648854871, 1.6016518591161586, 1.6118542885581604, 1.6218047624074317, 1.6315168626146401, 1.641003065252269, 1.6502748592728484, 1.6593428495994025, 1.6682168469791587, 1.6769059466008198, 1.6854185971302797, 1.6937626615409693, 1.7019454708888688, 1.7099738719977002, 1.7178542698684562, 1.7255926655026876, 1.7331946897256638, 1.7406656335095883, 1.7480104752252745, 1.755233905190469, 1.7623403478323172, 1.7693339817386111, 1.7762187578361148, 1.7829984159033314, 1.7896764995986587, 1.796256370162261, 1.8027412189305372, 1.8091340787853283, 1.8154378346455213, 1.8216552330961775, 1.8277888912394151, 1.833841304841795, 1.8398148558446745, 1.845711819296753, 1.851534369761675, 1.8572845872479822, 1.8629644627037738, 1.868575903114113, 1.8741207362353607, 1.8796007149972362, 1.8850175216003735, 1.8903727713344627, 1.8956680161396844, 1.9009047479319934, 1.9060844017109264, 1.9112083584668813, 1.9162779479033, 1.9212944509878043, 1.9262591023451074, 1.9311730925034074, 1.936037570004963, 1.9408536433906547, 1.9456223830675112, 1.9503448230674343, 1.9550219627046976, 1.9596547681391703, 1.9642441738516687, 1.9687910840373435, 1.9732963739225282, 1.9777608910100868, 1.9821854562578862, 1.9865708651946936, 1.9909178889774666, 1.9952272753937126, 1.9994997498123361, 2.0037360160861297, 2.0079367574088582, 2.01210263712966, 2.0162342995273135, 2.020332370546731, 2.024397458499885, 2.028430154733226], [0.0, 0.8106130830989491, 0.9311499150948377, 1.0098057976734853, 1.0696103757250688, 1.1184269147201447, 1.1599622586540015, 1.1962810324748434, 1.2286596790831472, 1.2579463251649878, 1.2847351571234393, 1.309459726546512, 1.3324467383744967, 1.3539489173903954, 1.3741660541180072, 1.3932590113656098, 1.4113593522139962, 1.428576142826029, 1.445000874391587, 1.4607110985268348, 1.4757731615945522, 1.490244294629108, 1.5041742338188457, 1.5176064932892266, 1.5305793764919489, 1.5431267884159363, 1.5552788941563633, 1.5670626576336675, 1.5785022858581217, 1.5896195980481953, 1.6004343344404715, 1.6109644163067485, 1.6212261661978982, 1.6312344955394649, 1.641003065252269, 1.6505444239489884, 1.659870127382893, 1.6689908421376922, 1.6779164360036873, 1.6866560570521496, 1.6952182030724354, 1.7036107827560192, 1.7118411697841733, 1.7199162507904178, 1.7278424680166338, 1.7356258573562682, 1.7432720823741534, 1.7507864648060334, 1.7581740119686893, 1.7654394414509949, 1.7725872034052437, 1.7796215007149807, 1.7865463072790226, 1.7933653846202369, 1.8000822970010757, 1.806700425205114, 1.813222979124284, 1.8196530092746486, 1.82599341734901, 1.832246965902024, 1.838416287252544, 1.8445038916783807, 1.8505121749703208, 1.8564434254049826, 1.8622998301896754, 1.8680834814268286, 1.8737963816406014, 1.879440448903927, 1.8850175216003733, 1.8905293628517985, 1.8959776646397317, 1.9013640516457162, 1.9066900848334483, 1.9119572647933973, 1.9171670348686836, 1.9223207840792598, 1.9274198498599233, 1.9324655206262837, 1.9374590381815895, 1.9424015999761801, 1.9472943612303364, 1.9521384369303783, 1.9569349037070505, 1.9616848016044737, 1.9663891357472798, 1.9710488779129252, 1.9756649680156204, 1.9802383155078196, 1.9847698007047239, 1.9892602760368723, 1.9937105672354636, 1.9981214744547446, 2.0024937733354458, 2.0068282160129693, 2.0111255320737653, 2.0153864294630695, 2.0196115953469707, 2.023801696931549, 2.027957382241642, 2.032079280861622, 2.0361680046403983, 2.0402241483627117], [0.0, 0.8151931096059227, 0.936410984009241, 1.0155112783974816, 1.0756537569325701, 1.1247461131420948, 1.1665161349761233, 1.2030401126732269, 1.235601701134824, 1.2650538190282499, 1.2919940099556333, 1.3168582751049311, 1.339975165324572, 1.3615988333120945, 1.381930198423183, 1.4011310323534025, 1.4193336415251103, 1.4366477083334102, 1.4531652409004676, 1.4689642290150666, 1.484111393902059, 1.4986642899555767, 1.5126729343772674, 1.5261810871507613, 1.5392272681452157, 1.5518455739153598, 1.564066339991485, 1.5759166826422604, 1.5874209456494368, 1.5986010715117525, 1.6094769119996513, 1.6200664896415007, 1.6303862192118455, 1.6404510963869354, 1.6502748592728484, 1.659870127382893, 1.6692485217612372, 1.6784207692586117, 1.687396793419095, 1.6961857940012677, 1.7047963168076516, 1.713236315214439, 1.7215132045647705, 1.7296339104021776, 1.7376049113677052, 1.7454322774580644, 1.753121704237666, 1.7606785435104717, 1.7681078308849896, 1.7754143106048341, 1.7826024579660034, 1.7896764995986587, 1.796640431854452, 1.8034980375091456, 1.810252900963549, 1.8169084221029261, 1.823467828955346, 1.829934189272523, 1.8363104211420478, 1.8425993027272227, 1.848803481219707, 1.8549254810805738, 1.8609677116370131, 1.8669324740945827, 1.872821968018482, 1.8786382973316813, 1.8843834758727551, 1.8900594325518971, 1.8956680161396844, 1.9012109997197495, 1.9066900848334483, 1.9121069053418995, 1.9174630310283656, 1.9227599709617675, 1.9279991766402256, 1.933182044931763, 1.938309920827786, 1.9433841000235528, 1.9484058313385957, 1.9533763189889413, 1.9582967247219538, 1.963168169823712, 1.9679917370080078, 1.9727684721952912, 1.977499386189226, 1.982185456257886, 1.9868276276260703, 1.9914268148847085, 1.9959839033228515, 2.0004997501873363, 2.004975185874807, 2.009411015060443, 2.0138080177674054, 2.0181669503807194, 2.022488546609055, 2.0267735183975923, 2.031022556794963, 2.0352363327770124, 2.039415498029968, 2.0435606856954025, 2.0476725110792193, 2.051751572326739], [0.0, 0.8196724623577651, 0.9415564091467339, 1.0210913467099034, 1.0815642983237683, 1.1309264089979596, 1.1729259502673732, 1.2096506212457105, 1.2423911303080353, 1.272005082770202, 1.2990933056386602, 1.3240941958565542, 1.347338109605466, 1.3690805961104213, 1.389523678746089, 1.408830018117031, 1.4271326476477473, 1.4445418524201556, 1.4611501461259986, 1.4770359470951882, 1.4922663431747896, 1.5068992050109131, 1.5209848246415458, 1.5345672025042674, 1.5476850701286133, 1.5603727114243022, 1.5726606286104008, 1.5845760869550378, 1.5961435640050612, 1.6073851228296494, 1.6183207242814768, 1.6289684899197554, 1.6393449247155303, 1.6494651067438382, 1.6593428495994025, 1.6689908421376922, 1.6784207692586117, 1.6876434167551815, 1.6966687626997303, 1.7055060574020076, 1.7141638936223214, 1.7226502684393648, 1.730972637942376, 1.7391379657296142, 1.7471527660411976, 1.7550231422274756, 1.7627548211490536, 1.7703531840171807, 1.777823294110209, 1.7851699217405963, 1.7923975667953593, 1.7995104791293004, 1.8065126770533706, 1.8134079641290652, 1.8201999444528905, 1.8268920365919232, 1.8334874863117185, 1.8399893782207843, 1.8464006464411253, 1.8527240844015969, 1.8589623538397426, 1.8651179930881365, 1.8711934247128275, 1.8771909625641212, 1.8831128182934678, 1.8889611073845498, 1.8947378547416558, 1.9004449998740247, 1.9060844017109262, 1.9116578430787967, 1.9171670348686836, 1.922613619919505, 1.9279991766402256, 1.9333252223918531, 1.9385932166482527, 1.9438045639530086, 1.948960616688035, 1.9540626776682233, 1.9591120025751647, 1.9641098022418562, 1.9690572447992734, 1.9739554576947789, 1.9788055295914992, 1.9836085121570466, 1.9883654217492852, 1.9930772410062174, 1.9977449203464976, 2.002369379386583, 2.006951508280043, 2.0114921689841454, 2.0159921964584284, 2.0204523997996304, 2.0248735633170107, 2.0292564475518073, 2.033601790244299, 2.037910307251689, 2.042182693419807, 2.0464196234114014, 2.050621752493609, 2.054789717287011, 2.0589241364785176, 2.0630256115001586], [0.0, 0.8240559876099317, 0.9465917573929856, 1.0265520397411134, 1.0873483945710751, 1.136974488810138, 1.179198639369468, 1.21611971016603, 1.2490353121524609, 1.2788076370309231, 1.3060407249698005, 1.3311753174146568, 1.3545435372584498, 1.3764023003775605, 1.3969547105471896, 1.4163642982643259, 1.43476480840274, 1.452267115837791, 1.4689642290150668, 1.4849349856377612, 1.500246832331945, 1.514957949230079, 1.5291188973268721, 1.5427739123697843, 1.555961933020646, 1.5687174265360497, 1.5810710582578384, 1.5930502392660313, 1.604679578010916, 1.6159812555527289, 1.626975339492761, 1.637680048302487, 1.6481119752198634, 1.658286278955945, 1.6682168469791587, 1.6779164360036873, 1.687396793419095, 1.6966687626997303, 1.7057423752796421, 1.714626930938298, 1.7233310683892176, 1.7318628274786603, 1.7402297041702737, 1.748438699302935, 1.7564963619542584, 1.7644088281146917, 1.7721818552715112, 1.7798208534141375, 1.787330912898823, 1.7947168295491724, 1.8019831273171425, 1.8091340787853285, 1.8161737237542004, 1.8231058861263159, 1.8299341892725232, 1.8366620700420497, 1.8432927915584756, 1.8498294549264829, 1.856275009959463, 1.8626322650252456, 1.8689038960960773, 1.8750924550792771, 1.8812003774965318, 1.8872299895723839, 1.8931835147859712, 1.8990630799343688, 1.9048707207508482, 1.910608387116947, 1.9162779479033, 1.9218811954707191, 1.9274198498599235, 1.9328955626955673, 1.9383099208277863, 1.9436644497322813, 1.9489606166880353, 1.9541998337499895, 1.95938346053246, 1.9645128068176596, 1.9695891350024375, 1.9746136623952029, 1.9795875633739772, 1.9845119714155979, 1.989387981005251, 1.9942166494347606, 1.9989989984973702, 2.0037360160861297, 2.008428657702437, 2.0130778478807647, 2.0176844815351327, 2.0222494252324696, 2.026773518397593, 2.0312575744542065, 2.0357023819059785, 2.040108705361443, 2.0444772865062393, 2.0488088450259023, 2.053104079482227, 2.0573636681459893, 2.0615882697886287, 2.0657785244353093, 2.0699350540816144, 2.074058463375973], [0.0, 0.8283481781504691, 0.9515221896062348, 1.0318989542961858, 1.0930119739438586, 1.1428965514115608, 1.1853406313231893, 1.222454009770205, 1.2555410564613727, 1.2854684539236574, 1.3128433885382442, 1.338108897403288, 1.3615988333120945, 1.383571450316983, 1.4042309100825638, 1.4237415948732581, 1.4422379461884183, 1.459831416407964, 1.4766154984226871, 1.4926694405710397, 1.5080610407826145, 1.5228487822277943, 1.5370834892540532, 1.5508096280158383, 1.564066339991485, 1.576888271964263, 1.58930624899998, 1.6013478249524242, 1.6130377364478308, 1.6243982800790435, 1.6354496279717667, 1.6462100934904822, 1.6566963563009383, 1.666923654070082, 1.6769059466008198, 1.6866560570521496, 1.6961857940012677, 1.7055060574020076, 1.714626930938298, 1.7235577628285792, 1.7323072367821057, 1.7408834345216018, 1.7492938910543057, 1.75754564368377, 1.765645275599234, 1.7735989547511593, 1.781412468615357, 1.7890912553598017, 1.7966404318544522, 1.8040648189025132, 1.811368964019466, 1.8185571620421446, 1.8256334738127855, 1.8326017431511827, 1.8394656123009296, 1.8462285360124782, 1.8528937944057642, 1.85946450473793, 1.8659436321868104, 1.872333999747942, 1.8786382973316813, 1.8848590901372508, 1.8909988263720323, 1.8970598443769768, 1.9030443792124696, 1.908954568753253, 1.9147924593359498, 1.9205600109982806, 1.9262591023451077, 1.9318915350729609, 1.9374590381815897, 1.9429632718983258, 1.948405831338596, 1.9537882499237176, 1.9591120025751652, 1.9643785087027306, 1.9695891350024377, 1.9747451980786508, 1.9798479669035587, 1.9848986651260614, 1.9898984732410643, 1.9948485306292483, 1.9997499374765526, 2.0046037565818273, 2.009411015060443, 2.014172705951006, 2.0188897897317517, 2.0235631957526974, 2.0281938235891266, 2.0327825443215803, 2.0373302017471175, 2.0418376135262535, 2.046305572269668, 2.050734846568447, 2.055126181971385, 2.059480301912582, 2.0637979085923717, 2.068079683814383, 2.0723262897813406, 2.076538369852055, 2.0807165492618442, 2.0848614358085182], [0.0, 0.8325532074018731, 0.9563524997900369, 1.0371372893366482, 1.0985605433061176, 1.1486983549970349, 1.1913578981670916, 1.228659679083147, 1.2619146889603865, 1.2919940099556333, 1.3195079107728942, 1.3449016775452185, 1.3685108578372633, 1.3905950167030172, 1.411359352213996, 1.4309690811052553, 1.449559327355391, 1.4672421091215284, 1.484111393902059, 1.5002468323319447, 1.5157165665103982, 1.5305793764919486, 1.5448863446289454, 1.5586821628039584, 1.5720061711932454, 1.5848931924611136, 1.59737420815383, 1.609476911999651, 1.6212261661978982, 1.632644380527908, 1.6437518295172258, 1.6545669194963535, 1.6651064148037462, 1.6753856304588906, 1.6854185971302797, 1.6952182030724354, 1.7047963168076516, 1.7141638936223214, 1.7233310683892176, 1.7323072367821057, 1.741101126592248, 1.749720860568452, 1.7581740119686893, 1.7664676538207023, 1.774608402732652, 1.7826024579660034, 1.7904556363761275, 1.7981734037373316, 1.8057609028948687, 1.8132229791242838, 1.8205642030260802, 1.827788891239415, 1.8349011252209961, 1.8419047683033969, 1.848803481219707, 1.8556007362580842, 1.8622998301896754, 1.868903896096077, 1.8754159142075613, 1.8818387218503283, 1.888175022589804, 1.8944273946471957, 1.900598298657973, 1.9066900848334483, 1.9127049995800738, 1.9186451916253062, 1.924512717693798, 1.9303095477732108, 1.9360375700049628, 1.9416985952317216, 1.9472943612303364, 1.9528265366561217, 1.9582967247219536, 1.9637064666334139, 1.9690572447992734, 1.9743504858348198, 1.979587563373977, 1.984769800704724, 1.9898984732410638, 1.9949748108436314, 2.0, 2.0049751858748066, 2.0099014742389776, 2.0147799332865577, 2.0196115953469707, 2.024397458499885, 2.0291384880993126, 2.033835618213025, 2.038489752982913, 2.043101767911474, 2.0476725110792193, 2.0522028042974405, 2.056693444200427, 2.0611452032809443, 2.0655588308724924, 2.069935054081614, 2.0742745786732963, 2.078578089912276, 2.082846253362888, 2.0870797156498897, 2.0912791051825463, 2.0954450328440952], [0.0, 0.8366749594697069, 0.9610871496100634, 1.042271883412973, 1.103999227765869, 1.1543852585822145, 1.1972559979361435, 1.2347424501636033, 1.2681620968526508, 1.2983903326588777, 1.3260404475662166, 1.3515599322023042, 1.3752859953395817, 1.3974794870703848, 1.4183466213479394, 1.4380534328519239, 1.4567357145242306, 1.4745060390944333, 1.491458839269306, 1.5076741600131658, 1.5232204807788452, 1.5381568726254713, 1.552534670800691, 1.566398788444837, 1.5797887604970373, 1.5927395820194559, 1.6052823879398512, 1.6174450090908479, 1.6292524307579805, 1.6407271736655122, 1.6518896127148444, 1.6627582453613823, 1.6733499189394139, 1.6836800242890615, 1.6937626615409693, 1.7036107827560192, 1.713236315214439, 1.7226502684393648, 1.7318628274786603, 1.7408834345216018, 1.749720860568452, 1.758383268581612, 1.766878269312263, 1.7752129708048487, 1.7833940224246174, 1.7914276541239476, 1.7993197115559327, 1.8070756875544913, 1.8147007504257517, 1.8221997694329444, 1.829577337804414, 1.8368377935498632, 1.8439852383322195, 1.8510235546104, 1.8579564212408213, 1.864787327702028, 1.871519587086613, 1.878156347987237, 1.8847006053885085, 1.8911552106634841, 1.8975228807622309, 1.903806206670052, 1.9100076612043764, 1.9161296062117943, 1.9221742992201267, 1.9281438995946143, 1.9340404742422128, 1.939866002903475, 1.9456223830675112, 1.9513114345419946, 1.9569349037070505, 1.9624944674790679, 1.9679917370080078, 1.9734282611295562, 1.9788055295914995, 1.984124976071923, 1.989387981005251, 1.9945958742307133, 1.9997499374765524, 2.00485140669212, 2.0099014742389776, 2.0149012909511708, 2.0198519680740077, 2.0247545790898807, 2.0296101614390047, 2.034419718142279, 2.039184219332929, 2.043904603703051, 2.048581779870703, 2.053216627672766, 2.0578099993883763, 2.062362720897395, 2.0668755927780396, 2.071349391347484, 2.0757848696489805, 2.080182758388787, 2.084543766825946, 2.088868583617761, 2.0931578776235997, 2.09741229866949, 2.101632478275785, 2.1058190303500446], [0.0, 0.8407170557060673, 0.96573029890751, 1.0473072477555103, 1.1093328057258516, 1.1599622586540015, 1.203040112673227, 1.240707667305806, 1.2742887690815312, 1.3046630418126133, 1.3324467383744967, 1.358089511285958, 1.3819301984231835, 1.404230910082564, 1.4251988564663878, 1.4450008743915868, 1.4637734128351518, 1.4816295883815922, 1.4986642899555769, 1.514957949230079, 1.530579376491949, 1.5455879281810383, 1.5600351875529073, 1.5739662847296847, 1.587420945649437, 1.6004343344404717, 1.6130377364478306, 1.625259116958866, 1.6371235819665952, 1.6486537609961176, 1.6598701273828933, 1.6707912679461767, 1.6814341114121345, 1.6918141229762353, 1.7019454708888688, 1.7118411697841733, 1.7215132045647705, 1.730972637942376, 1.7402297041702737, 1.7492938910543057, 1.7581740119686893, 1.766878269312263, 1.7754143106048343, 1.7837892782308247, 1.7920098536795157, 1.800082297001076, 1.8080124820897834, 1.8158059283162225, 1.823467828955346, 1.8310030767944911, 1.8384162872525442, 1.845711819296753, 1.852893794405764, 1.8599661137952082, 1.866932474094583, 1.8737963816406016, 1.8805611655318817, 1.8872299895723839, 1.8938058632159154, 1.9002916516109232, 1.9066900848334483, 1.9130037663862143, 1.9192351810331838, 1.9253867020313657, 1.93146059781502, 1.9374590381815897, 1.943384100023553, 1.949237772645872, 1.9550219627046979, 1.9607384987994547, 1.96638913574728, 1.9719755585659848, 1.9774993861892263, 1.982962174935336, 1.9883654217492857, 1.9937105672354638, 1.9989989984973704, 2.0042320517988785, 2.009411015060443, 2.014537130202464, 2.019611595346971, 2.024635566887854, 2.029610161439005, 2.034536457668964, 2.039415498029968, 2.044248290388653, 2.0490358095650962, 2.0537789987863504, 2.0584787710601367, 2.0631360104739542, 2.0677515734244203, 2.0723262897813406, 2.0768609639906406, 2.0813563761199925, 2.085813282850709, 2.0902324184191934, 2.0946144955110206, 2.0989602061104957, 2.1032702223083417, 2.107545197069988, 2.111785764966754, 2.1159925428720743], [0.0, 0.8446828782648351, 0.970285832756977, 1.0522475956179929, 1.1145657399648676, 1.1654340216704255, 1.2087150821359736, 1.2465603218016819, 1.2802998320336965, 1.310817385997371, 1.3387321435503967, 1.364495878308167, 1.388449026509699, 1.4108549348755994, 1.4319217910581665, 1.4518172188753904, 1.4706783109600876, 1.4886187174892525, 1.5057337749966937, 1.5221042945669128, 1.5377994110779953, 1.5528787609654309, 1.5673941708128258, 1.5813909836296955, 1.5949091127489257, 1.6079838881747186, 1.6206467428310498, 1.6329257739228613, 1.6448462058729243, 1.6564307749541192, 1.6677000510785314, 1.678672708742984, 1.6893657565296702, 1.6997947325863336, 1.7099738719977002, 1.7199162507904178, 1.7296339104021776, 1.7391379657296142, 1.748438699302935, 1.75754564368377, 1.7664676538207023, 1.7752129708048487, 1.7837892782308247, 1.79220375217504, 1.8004631056446352, 1.8085736282196274, 1.8165412215025742, 1.824371430899982, 1.8320694741844719, 1.8396402672235905, 1.8470884472080353, 1.8544183936671328, 1.8616342475213299, 1.868739928389035, 1.8757391503374512, 1.8826354362433504, 1.8894321309093425, 1.8961324130636543, 1.9027393063562605, 1.9092556894510593, 1.9156843053023802, 1.9220277696941654, 1.9282885791114828, 1.9344691180064468, 1.940571665513954, 1.9465984016667952, 1.9525514131545463, 1.9584326986661005, 1.9642441738516687, 1.9699876759365276, 1.9756649680156209, 1.98127774305531, 1.9868276276260706, 1.9923161853876845, 1.9977449203464979, 2.003115279902505, 2.0084286577024373, 2.013686396313579, 2.0188897897317513, 2.0240400857357295, 2.0291384880993126, 2.034186158671322, 2.0391842193329293, 2.0441337538409603, 2.0490358095650962, 2.053891399126274, 2.058701501942982, 2.0634670656916545, 2.0681890076868448, 2.0728682161864604, 2.0775055516269054, 2.082101847792639, 2.086657912924312, 2.0911745307693232, 2.0956524615783967, 2.100092443051468, 2.1044951912359857, 2.1088614013804765, 2.1131917487460443, 2.1174868893782803, 2.121747460841898, 2.125974082920241], [0.0, 0.8485755910508883, 0.9747573855307922, 1.0570968683746162, 1.1197022052804315, 1.1708049129648925, 1.2142854337744389, 1.2523050828571352, 1.286200081292184, 1.3168582751049314, 1.3449016775452187, 1.370784144222729, 1.394847680273559, 1.417356846049102, 1.4385207886324167, 1.4585079043342193, 1.4774559175773847, 1.4954790022946367, 1.5126729343772678, 1.5291188973268721, 1.5448863446289456, 1.5600351875529073, 1.5746174915246676, 1.5886788085165573, 1.6022592358016674, 1.6153942662021783, 1.628115477500389, 1.6404510963869356, 1.6524264635310948, 1.6640644199856385, 1.675385630458891, 1.686408855508911, 1.6971511821017766, 1.7076282199926334, 1.7178542698684562, 1.7278424680166338, 1.7376049113677052, 1.7471527660411976, 1.7564963619542584, 1.765645275599234, 1.774608402732652, 1.7833940224246174, 1.7920098536795157, 1.8004631056446352, 1.8087605222639436, 1.8169084221029264, 1.8249127339616187, 1.832779028802479, 1.8405125484441818, 1.8481182314090019, 1.8556007362580846, 1.8629644627037742, 1.8702135707499092, 1.877351998078421, 1.8843834758727556, 1.8913115432448273, 1.8981395604117368, 1.9048707207508484, 1.9115080618465983, 1.9180544756291789, 1.9245127176937984, 1.9308854158792133, 1.9371750781755186, 1.9433841000235532, 1.9495147710615843, 1.9555692813690628, 1.9615497272520528, 1.967458116610386, 1.9732963739225284, 1.9790663448805912, 1.9847698007047243, 1.990408442163308, 1.995983903322852, 2.001497755049249, 2.0069515082800438, 2.0123466170855586, 2.017684481535133, 2.02296645038326, 2.0281938235891266, 2.0333678546818845, 2.0384897529829136, 2.043560685695403, 2.0485817798707036, 2.053554124260123, 2.058478771060137, 2.0633567375583346, 2.068189007686845, 2.0729765334894608, 2.0777202365081697, 2.082421009094407, 2.08707971564989, 2.091697193801566, 2.0962742555148535, 2.100811688149045, 2.1053102554584715, 2.109770698542752, 2.1141937367492325, 2.118580068530486, 2.12293037225955, 2.1272453070053965, 2.1315255132709487, 2.1357716136958165], [0.0, 0.8523981584038259, 0.9791483623609769, 1.0618587587949346, 1.1247461131420948, 1.1760790225246736, 1.2197554094669347, 1.2579463251649878, 1.2919940099556335, 1.3227903093325808, 1.3509600385206135, 1.3769590976068362, 1.401131032353403, 1.4237415948732581, 1.4450008743915868, 1.4650780257917608, 1.4841113939020592, 1.502215666973025, 1.5194870523363548, 1.536007099199899, 1.5518455739153598, 1.5670626576336675, 1.5817106503191745, 1.5958353091415851, 1.6094769119996513, 1.6226711115996046, 1.6354496279717665, 1.6478408149591768, 1.6598701273828933, 1.671560509187479, 1.6829327181692995, 1.6940055993968535, 1.7047963168076519, 1.7153205504738989, 1.7255926655026876, 1.7356258573562682, 1.7454322774580644, 1.7550231422274756, 1.7644088281146917, 1.7735989547511593, 1.7826024579660034, 1.7914276541239476, 1.800082297001076, 1.8085736282196274, 1.8169084221029264, 1.8250930256796176, 1.8331333944571235, 1.8410351244933445, 1.8488034812197072, 1.8564434254049829, 1.8639596365956759, 1.8713565343234577, 1.8786382973316813, 1.8858088810403024, 1.89287203344058, 1.89983130958702, 1.9066900848334485, 1.9134515669423955, 1.9201188071816635, 1.9266947105086853, 1.933182044931763, 1.9395834501272435, 1.9459014453829322, 1.9521384369303785, 1.9582967247219538, 1.9643785087027308, 1.970385894621976, 1.9763208994244816, 1.9821854562578862, 1.9879814191285663, 1.9937105672354638, 1.9993746090083881, 2.004975185874807, 2.0105138757768724, 2.015992196458429, 2.0214116085399314, 2.026773518397593, 2.0320792808616224, 2.037330201747117, 2.042527540229985, 2.0476725110792198, 2.052766286755895, 2.0578099993883763, 2.062804742632454, 2.06775157342442, 2.072651513634425, 2.077505551626905, 2.082314643734311, 2.0870797156498897, 2.0918016637448402, 2.096481356314738, 2.1011196347597783, 2.105717314703029, 2.1102751870505903, 2.1147940189972667, 2.1192745549810996, 2.1237175175898693, 2.128123608422459, 2.1324935089077646, 2.1368278810836565, 2.1411273683383243, 2.145392596116173], [0.0, 0.8561533618057355, 0.9834619583314298, 1.066536731857243, 1.129701133737476, 1.1812601880431084, 1.2251289894283288, 1.2634881535618547, 1.2976858339625241, 1.3286178051109863, 1.356911634828607, 1.383025231650704, 1.4073036548155013, 1.4300138271954397, 1.4513667635547436, 1.4715323639813442, 1.4906495827757071, 1.5088336134425278, 1.5261810871507613, 1.5427739123697841, 1.5586821628039584, 1.5739662847296843, 1.5886788085165569, 1.6028656929155223, 1.6165673932678812, 1.6298197193463293, 1.6426545309224156, 1.6551003067508154, 1.6671826137927048, 1.678924497071208, 1.6903468058302684, 1.7014684681595231, 1.712306723611471, 1.7228773213362, 1.7331946897256638, 1.7432720823741534, 1.753121704237666, 1.7627548211490536, 1.7721818552715112, 1.781412468615357, 1.7904556363761275, 1.7993197115559327, 1.8080124820897834, 1.8165412215025742, 1.8249127339616187, 1.8331333944571235, 1.8412091847332428, 1.849145725501069, 1.8569483053886604, 1.8646219070192414, 1.8721712305548577, 1.8796007149972362, 1.8869145574990052, 1.8941167309055518, 1.9012109997197495, 1.9082009346577442, 1.9150899259433374, 1.9218811954707191, 1.9285778079499212, 1.9351826811360409, 1.9416985952317218, 1.9481282015422916, 1.9544740304541697, 1.960738498799455, 1.9669239166628596, 1.97303249368122, 1.979066344880591, 1.9850274960913272, 1.9909178889774666, 1.9967393857131306, 2.0024937733354458, 2.0081827678006356, 2.0138080177674054, 2.019371108129464, 2.0248735633170107, 2.0303168503852014, 2.0357023819059785, 2.0410315186781975, 2.046305572269668, 2.051525807403542, 2.0566934442004277, 2.0618096602866243, 2.0668755927780396, 2.0718923401485188, 2.07686096399064, 2.08178249067636, 2.0866579129243115, 2.091488191280026, 2.096274255514853, 2.1010170059489157, 2.105717314703029, 2.1103760268841394, 2.114993961708508, 2.119571913566538, 2.124110653032877, 2.1286109278251564, 2.133073463714486, 2.1374989653906122, 2.141888117284437, 2.14624158435041, 2.1505600128111397, 2.1548440308664], [0.0, 0.8598438148600782, 0.9877011756841471, 1.0711340434082361, 1.134570715737017, 1.1863520155864153, 1.2304099136443636, 1.2689344251335783, 1.3032795147949203, 1.3343448183491105, 1.362760608751532, 1.3889867683543775, 1.4133698437753244, 1.4361779084590989, 1.4576228867500496, 1.4778754110912278, 1.497075034746259, 1.515337447761977, 1.5327596978364406, 1.5494240465058657, 1.565400869527643, 1.5807508737321287, 1.5955268159213212, 1.6097748529515759, 1.6235356145471314, 1.6368450648388746, 1.649735200930049, 1.6622346243331343, 1.6743690122158117, 1.6861615089368849, 1.6976330536110604, 1.7088026559175944, 1.7196876297201564, 1.7303037920556197, 1.7406656335095883, 1.7507864648060334, 1.7606785435104717, 1.7703531840171807, 1.7798208534141375, 1.7890912553598017, 1.7981734037373316, 1.8070756875544913, 1.8158059283162225, 1.824371430899982, 1.832779028802479, 1.8410351244933445, 1.849145725501069, 1.8571164767648463, 1.8649526897093902, 1.8726593684355466, 1.8802412333654304, 1.8877027426351074, 1.8950481114890505, 1.9022813298976164, 1.9094061785905856, 1.9164262436756923, 1.9233449299903134, 1.9301654733166291, 1.936890951575118, 1.9435242950978746, 1.9500682960716185, 1.9565256172301415, 1.9628987998671052, 1.9691902712323752, 1.9754023513682941, 1.9815372594363483, 1.987597119579422, 1.993583966360221, 1.999499749812336, 2.0053463401367977, 2.011125532073765, 2.0168390489760983, 2.0224885466090545, 2.0280756166980334, 2.033601790244299, 2.039068540626754, 2.044477286506239, 2.0498293945473396, 2.0551261819713846, 2.060368918953121, 2.0655588308724924, 2.0706971004319614, 2.0757848696489805, 2.08082324173237, 2.0858132828507085, 2.0907560238001337, 2.0956524615783962, 2.100503560871464, 2.1053102554584706, 2.110073449540373, 2.1147940189972663, 2.1194728125789357, 2.124110653032877, 2.1287083381737166, 2.1332666418976687, 2.1377863151454037, 2.1422680868164723, 2.1467126646381893, 2.151120735991699, 2.15549296869774, 2.159830011764466, 2.1641324960995103], [0.0, 0.8634719767533109, 0.9918688392825663, 1.0756537569325701, 1.1393581040567025, 1.1913578981670916, 1.235601701134824, 1.2742887690815312, 1.3087787798824748, 1.339975165324572, 1.3685108578372633, 1.3948476802735588, 1.4193336415251103, 1.4422379461884183, 1.4637734128351514, 1.484111393902059, 1.5033920315060254, 1.5217315038548884, 1.539227268145216, 1.555961933020646, 1.5720061711932458, 1.5874209456494368, 1.6022592358016672, 1.6165673932678817, 1.6303862192118455, 1.643751829517226, 1.656696356300938, 1.6692485217612372, 1.6814341114121345, 1.6932763672714257, 1.7047963168076519, 1.7160130499125361, 1.7269439535066218, 1.7376049113677052, 1.7480104752252745, 1.7581740119686893, 1.7681078308849896, 1.777823294110209, 1.787330912898823, 1.7966404318544522, 1.8057609028948687, 1.8147007504257517, 1.823467828955346, 1.8320694741844719, 1.8405125484441818, 1.8488034812197072, 1.8569483053886604, 1.8649526897093902, 1.8728219680184823, 1.8805611655318815, 1.8881750225898042, 1.8956680161396844, 1.9030443792124696, 1.9103081186144322, 1.9174630310283656, 1.9245127176937982, 1.9314605978150203, 1.938309920827786, 1.945063777640042, 1.9517251109485922, 1.9582967247219538, 1.9647812929294812, 1.9711813675879755, 1.9774993861892263, 1.9837376785651326, 1.989898473241064, 1.9959839033228517, 2.001996011958159, 2.0079367574088582, 2.0138080177674054, 2.0196115953469707, 2.025349220772205, 2.031022556794963, 2.0366332018570263, 2.0421826934198073, 2.0476725110792193, 2.053104079482227, 2.058478771060137, 2.0637979085923717, 2.0690627676132562, 2.0742745786732963, 2.0794345294654395, 2.0845437668259463, 2.0896033986186935, 2.0946144955110206, 2.0995780926485708, 2.1044951912359853, 2.109366760029783, 2.114193736749232, 2.11897702941062, 2.1237175175898693, 2.1284160536181154, 2.133073463714486, 2.1376905490600335, 2.1422680868164727, 2.1468068310931137, 2.1513075138651403, 2.155770845846166, 2.160197517317779, 2.1645881989186293, 2.1689435423953976, 2.173264181317869], [0.0, 0.8670401643811235, 0.9959676105409554, 1.0800987586588895, 1.144066355858723, 1.1962810324748436, 1.240707667305806, 1.2795546046181907, 1.3141871409823676, 1.3455124415016924, 1.3741660541180074, 1.4006117101082607, 1.425198856466388, 1.448197810242491, 1.469822269453797, 1.490244294629108, 1.5096046070047024, 1.5280198648800187, 1.5455879281810383, 1.562391746921066, 1.578502285858122, 1.5939807599003804, 1.608880367390943, 1.623247651489894, 1.6371235819665952, 1.6505444239489886, 1.6635424423358576, 1.676146478016272, 1.6883824230595856, 1.7002736155282634, 1.7118411697841733, 1.7231042546055775, 1.734080328762247, 1.7447853416696602, 1.755233905190469, 1.7654394414509949, 1.7754143106048341, 1.7851699217405963, 1.7947168295491724, 1.8040648189025132, 1.8132229791242838, 1.8221997694329444, 1.8310030767944911, 1.8396402672235905, 1.8481182314090019, 1.8564434254049829, 1.8646219070192414, 1.8726593684355466, 1.8805611655318815, 1.8883323442902544, 1.895977664639732, 1.9035016220281615, 1.9109084669789498, 1.9182022228559843, 1.9253867020313655, 1.9324655206262837, 1.9394421119744543, 1.9463197389395093, 1.9531015052021772, 1.9597903656195812, 1.96638913574728, 1.9729005006044646, 1.9793270227538193, 1.9856711497597574, 1.9919352210819108, 1.9981214744547449, 2.0042320517988785, 2.0102690047050213, 2.0162342995273135, 2.0221298221191875, 2.027957382241642, 2.0337187176709137, 2.039415498029968, 2.0450493283659408, 2.050621752493609, 2.0561342561231264, 2.0615882697886287, 2.0669851715928202, 2.0723262897813406, 2.0776129051594974, 2.0828462533628884, 2.0880275269924504, 2.0931578776235997, 2.0982384176983184, 2.1032702223083413, 2.1082543308769193, 2.1131917487460443, 2.1180834486754967, 2.12293037225955, 2.127733431266753, 2.1324935089077646, 2.1372114610358683, 2.141888117284437, 2.1465242821453017, 2.1511207359916993, 2.155678236049199, 2.160197517317779, 2.1646792934479864, 2.1691242575739103, 2.1735330831055273, 2.17790642448278, 2.1822449178935988], [0.0, 0.8705505632961241, 1.0, 1.0844717711976988, 1.148698354997035, 1.2011244339814313, 1.2457309396155174, 1.2847351571234393, 1.3195079107728944, 1.3509600385206135, 1.379729661461215, 1.4062823883876352, 1.4309690811052556, 1.454061151100997, 1.475773161594552, 1.4962778697388448, 1.5157165665103982, 1.5342063825249113, 1.5518455739153598, 1.5687174265360497, 1.5848931924611136, 1.6004343344404715, 1.615394266202178, 1.6298197193463293, 1.6437518295172258, 1.6572270086699936, 1.6702776523348104, 1.6829327181692995, 1.6952182030724356, 1.7071575395958583, 1.7187719275874789, 1.7300806134344884, 1.7411011265922482, 1.7518494810508827, 1.7623403478323172, 1.7725872034052437, 1.7826024579660034, 1.7923975667953593, 1.8019831273171425, 1.811368964019466, 1.8205642030260802, 1.829577337804414, 1.8384162872525442, 1.8470884472080353, 1.8556007362580846, 1.8639596365956759, 1.8721712305548577, 1.8802412333654304, 1.8881750225898042, 1.895977664639732, 1.9036539387158786, 1.9112083584668813, 1.9186451916253064, 1.925968477844497, 1.933182044931763, 1.9402895236489406, 1.9472943612303366, 1.9541998337499895, 1.9610090574545482, 1.967724999164511, 1.97435048583482, 1.9808882133555454, 1.9873407546644581, 1.9937105672354638, 2.0, 2.0062112997524832, 2.012346617085558, 2.018408011896243, 2.024397458499885, 2.0303168503852014, 2.0361680046403983, 2.041952666077473, 2.0476725110792193, 2.053329151191153, 2.0589241364785176, 2.064458958666684, 2.0699350540816144, 2.075353806405558, 2.080716549261844, 2.086024568641395, 2.091279105182547, 2.096481356314738, 2.101632478275785, 2.106733588011632, 2.111785764966754, 2.1167900527727306, 2.121747460841898, 2.1266589658724633, 2.1315255132709487, 2.136348018497393, 2.1411273683383243, 2.1458644221121324, 2.1505600128111397, 2.155214948184336, 2.1598300117644667, 2.164405963842892, 2.1689435423953976, 2.173443463961896, 2.17790642448278, 2.1823331000944726, 2.1867241478865562, 2.1910802066227055], [0.0, 0.8740052376126373, 1.0039683787044291, 1.088775365880074, 1.153256825086818, 1.2058909506066127, 1.250674471747736, 1.2898334727617995, 1.3247442178663313, 1.3563211595680134, 1.3852049512676268, 1.4118630494701263, 1.4366477083334102, 1.459831416407964, 1.481629588381592, 1.5022156669730249, 1.5217315038548886, 1.5402946944615223, 1.558003884843448, 1.5749426913647822, 1.591182648854871, 1.6067854639711021, 1.6218047624074317, 1.636287461212642, 1.6502748592728484, 1.6638035130396043, 1.6769059466008196, 1.6896112325290695, 1.7019454708888688, 1.713932187221096, 1.7255926655026876, 1.7369462284977875, 1.7480104752252745, 1.7588014832248502, 1.7693339817386111, 1.7796215007149807, 1.7896764995986587, 1.7995104791293004, 1.8091340787853285, 1.8185571620421446, 1.827788891239415, 1.8368377935498632, 1.845711819296753, 1.8544183936671328, 1.8629644627037742, 1.8713565343234577, 1.8796007149972362, 1.8877027426351074, 1.8956680161396844, 1.9035016220281615, 1.9112083584668813, 1.9187927570163483, 1.9262591023451077, 1.9336114501373767, 1.940853643390655, 1.947989327275016, 1.9550219627046979, 1.9619548387544419, 1.9687910840373435, 1.9755336771473682, 1.9821854562578862, 1.9887491279572802, 1.9952272753937128, 2.0016223657932763, 2.0079367574088582, 2.014172705951006, 2.020332370546731, 2.0264178192675013, 2.032431034263497, 2.0383739165375134, 2.044248290388653, 2.050055907552987, 2.055798451065831, 2.0614775388679236, 2.067094727175754, 2.072651513634425, 2.0781493402697833, 2.083589596255054, 2.0889736205058878, 2.094302704116507, 2.0995780926485708, 2.10480098828337, 2.109972551847111, 2.115093904718203, 2.1201661306247646, 2.125190277339901, 2.1301673582816796, 2.135098354024215, 2.1399842137257603, 2.1448258564792475, 2.1496241725903085, 2.154380024787434, 2.1590942493685765, 2.163767657288178, 2.1684010351883396, 2.1729951463775454, 2.177550731760148, 2.1820685107195628, 2.186549181957937, 2.190993424294858, 2.1954018974274905, 2.1997752426543635], [0.0, 0.8774061389863257, 1.0078749885178921, 1.0930119739438588, 1.1577443413531583, 1.2105832751075947, 1.2555410564613727, 1.2948524317343189, 1.3298990204194987, 1.3615988333120945, 1.3905950167030172, 1.4173568460491017, 1.4422379461884183, 1.4655118659702306, 1.4873948582971226, 1.5080610407826143, 1.5276528170680466, 1.5462882401713718, 1.5640663399914851, 1.5810710582578384, 1.5973742081538305, 1.6130377364478306, 1.628115477500389, 1.6426545309224159, 1.6566963563009383, 1.6702776523348106, 1.683431069668639, 1.6961857940012677, 1.708568026956953, 1.7206013856184088, 1.7323072367821057, 1.743704978400313, 1.7548122779726514, 1.7656452755992338, 1.7762187578361148, 1.7865463072790226, 1.796640431854452, 1.8065126770533706, 1.8161737237542004, 1.8256334738127855, 1.8349011252209961, 1.8439852383322195, 1.852893794405764, 1.8616342475213299, 1.8702135707499092, 1.8786382973316813, 1.8869145574990052, 1.8950481114890505, 1.9030443792124696, 1.9109084669789498, 1.9186451916253064, 1.9262591023451077, 1.9337545004792647, 1.9411354574933446, 1.948405831338596, 1.9555692813690626, 1.9626292819659816, 1.9695891350024375, 1.9764519812654853, 1.9832208109393008, 1.989898473241064, 1.9964876852909483, 2.00299104028858, 2.009411015060443, 2.0157499770357843, 2.0220101907024994, 2.028193823589126, 2.0343029518143476, 2.040339565241222, 2.046305572269668, 2.052202804297441, 2.058033019876912, 2.0637979085923717, 2.069499094680237, 2.075138140412497, 2.080716549261844, 2.0862357688652895, 2.091697193801566, 2.097102168196269, 2.102451988167487, 2.107747904123567, 2.1129911229236913, 2.118182809911036, 2.1233240908274813, 2.1284160536181154, 2.1334597501331043, 2.1384561977338947, 2.1434063808101818, 2.1483112522135515, 2.1531717346132817, 2.157988721779333, 2.1627630797972186, 2.1674956482190657, 2.172187241154877, 2.1768386483077107, 2.1814506359562125, 2.1860239478877177, 2.1905593062848836, 2.1950574125686257, 2.1995189481999327, 2.2039445754429607, 2.20833493809164], [0.0, 0.8807551147710713, 1.0117219514927545, 1.0971838966949394, 1.162163341394117, 1.2152039563333237, 1.260333337262714, 1.2997947603162765, 1.3349751184972798, 1.3667959265608016, 1.3959027856259776, 1.4227667623294298, 1.4477428312616027, 1.4711055853817014, 1.4930721030090721, 1.5138171663476052, 1.5334837225797973, 1.5521902753207422, 1.5700362324570412, 1.5871058561157436, 1.6034712335843393, 1.6191945480761212, 1.6343298394322734, 1.6489243870384414, 1.663019808728953, 1.6766529432781057, 1.6898565659549105, 1.702659973857249, 1.7150894686184848, 1.7271687574654908, 1.7389192887497673, 1.750360534463722, 1.7615102295421425, 1.772384575690368, 1.7829984159033314, 1.7933653846202369, 1.8034980375091456, 1.8134079641290652, 1.8231058861263159, 1.8326017431511827, 1.8419047683033969, 1.8510235546104, 1.8599661137952082, 1.868739928389035, 1.877351998078421, 1.8858088810403024, 1.8941167309055518, 1.9022813298976164, 1.9103081186144322, 1.9182022228559843, 1.925968477844497, 1.9336114501373767, 1.9411354574933446, 1.948544586918364, 1.9558427110891166, 1.963033503327053, 1.9701204512747925, 1.9771068694083553, 1.9839959105028822, 1.9907905761557974, 1.9974937264594717, 2.0041080889050678, 2.010636266590209, 2.0170807457951896, 2.023443902985509, 2.029728011292397, 2.0359352465176435, 2.042067692704278, 2.048127347310476, 2.054116126020338, 2.0600358672218912, 2.0658883361797336, 2.0716752289271367, 2.077398175900074, 2.0830587453335796, 2.088658446438957, 2.094198732378711, 2.099681003054547, 2.1051066077224623, 2.110476847447703, 2.1157929774113073, 2.121056209078923, 2.126267712241731, 2.1314286169384604, 2.1365400152667835, 2.1416029630916773, 2.1466184816577614, 2.1515875591120515, 2.1565111519430786, 2.1613901863418614, 2.166225559489795, 2.1710181407781577, 2.1757687729635693, 2.180478273263412, 2.1851474343949646, 2.189777025561687, 2.194367793389879, 2.1989204628187013, 2.203435737946325, 2.207914302834812, 2.212356822276117, 2.2167639425214714], [0.0, 0.8840539154424948, 1.0155112783974816, 1.1012933147549562, 1.166516134976123, 1.2197554094669347, 1.26505381902825, 1.3046630418126133, 1.339975165324572, 1.371915155781979, 1.4011310323534027, 1.428095626019391, 1.4531652409004676, 1.4766154984226871, 1.4986642899555767, 1.5194870523363546, 1.539227268145216, 1.558003884843448, 1.5759166826422604, 1.593050239266031, 1.6094769119996513, 1.6252591169588655, 1.6404510963869354, 1.6551003067508154, 1.6692485217612372, 1.6829327181692995, 1.6961857940012675, 1.7090371560850537, 1.7215132045647705, 1.7336377354608892, 1.7454322774580644, 1.7569163754795563, 1.7681078308849896, 1.7790229060619465, 1.7896764995986587, 1.8000822970010757, 1.810252900963549, 1.8201999444528905, 1.8299341892725232, 1.8394656123009296, 1.848803481219707, 1.8579564212408213, 1.866932474094583, 1.8757391503374512, 1.8843834758727556, 1.89287203344058, 1.9012109997197495, 1.9094061785905856, 1.9174630310283656, 1.9253867020313655, 1.933182044931763, 1.940853643390655, 1.948405831338596, 1.9558427110891166, 1.9631681698237122, 1.970385894621976, 1.9774993861892263, 1.9845119714155977, 1.9914268148847085, 1.9982469294362357, 2.0049751858748066, 2.011614321907193, 2.01816695038072, 2.024635566887854, 2.031022556794963, 2.037330201747117, 2.0435606856954025, 2.049716100488473, 2.055798451065831, 2.0618096602866243, 2.06775157342442, 2.07362596235548, 2.0794345294654395, 2.0851789112969437, 2.09086068195873, 2.096481356314738, 2.1020423929701804, 2.107545197069988, 2.1129911229236913, 2.118381476469578, 2.1237175175898693, 2.1290004622876655, 2.1342314847355097, 2.1394117192046056, 2.1445422618829917, 2.149624172590308, 2.154658476396166, 2.1596461651486116, 2.164588198918629, 2.1694855073662143, 2.174338991033087, 2.1791495225667643, 2.183917947880345, 2.188645087252037, 2.193331736368181, 2.1979786673132287, 2.2025866295099124, 2.2071563506125957, 2.211688537356596, 2.216183876366077, 2.2206430349229205, 2.225066661698842], [0.0, 0.887304201366326, 1.0192448764914566, 1.1053422964928696, 1.1708049129648923, 1.2242399253642746, 1.2697048776900042, 1.309459726546512, 1.3449016775452187, 1.3769590976068362, 1.4062823883876352, 1.4333461192642658, 1.4585079043342195, 1.482044378364961, 1.5041742338188455, 1.5250735525388686, 1.5448863446289456, 1.5637319948690076, 1.5817106503191745, 1.5989071996597315, 1.615394266202178, 1.6312344955394649, 1.6464823293402462, 1.66118539854849, 1.6753856304588906, 1.6891201377701537, 1.7024219394604339, 1.7153205504738989, 1.7278424680166335, 1.7400115755968395, 1.7518494810508827, 1.7633758011602985, 1.774608402732652, 1.7855636079453292, 1.796256370162261, 1.806700425205114, 1.8169084221029261, 1.8268920365919232, 1.8366620700420497, 1.8462285360124782, 1.8556007362580842, 1.864787327702028, 1.8737963816406016, 1.8826354362433504, 1.8913115432448273, 1.89983130958702, 1.9082009346577442, 1.9164262436756923, 1.9245127176937982, 1.9324655206262837, 1.9402895236489406, 1.947989327275016, 1.9555692813690626, 1.963033503327053, 1.970385894621976, 1.9776301558892317, 1.9847698007047243, 1.9918081681901332, 1.9987484345638886, 2.0055936237425835, 2.0123466170855586, 2.019010162364955, 2.025586882034414, 2.0320792808616224, 2.038489752982913, 2.044820588431984, 2.0510739791893706, 2.0572520247945527, 2.063356737558334, 2.069390047409388, 2.0753538064055586, 2.0812497929375344, 2.0870797156498897, 2.092845217102134, 2.0985478771903257, 2.1041892163479057, 2.1097706985427513, 2.1152937340859075, 2.120759682266118, 2.1261698538230425, 2.1315255132709487, 2.1368278810836565, 2.142078135750636, 2.1472774157133188, 2.1524268211899553, 2.157527415896686, 2.1625802286718616, 2.1675862550101277, 2.1725464585122367, 2.1774617722561436, 2.1823331000944726, 2.187161317883091, 2.1919472746451554, 2.1966917936746846, 2.201395673583415, 2.206059689294421, 2.2106845929857393, 2.215271114987006, 2.2198199646319012, 2.2243318310690086, 2.228807384033519, 2.233247274582035], [0.0, 0.8905075489802288, 1.0229245566260303, 1.1093328057258518, 1.1750317554823926, 1.2286596790831472, 1.2742887690815314, 1.3141871409823678, 1.3497570445919025, 1.3819301984231835, 1.4113593522139962, 1.4385207886324167, 1.4637734128351518, 1.4873948582971228, 1.5096046070047022, 1.5305793764919489, 1.5504636967683783, 1.5693773836171208, 1.587420945649437, 1.604679578010916, 1.6212261661978986, 1.6371235819665952, 1.6524264635310946, 1.667182613792705, 1.6814341114121345, 1.6952182030724359, 1.7085680269569528, 1.7215132045647707, 1.734080328762247, 1.7462933692818783, 1.7581740119686895, 1.7697419444247646, 1.7810150979604575, 1.7920098536795155, 1.8027412189305372, 1.813222979124284, 1.823467828955346, 1.8334874863117185, 1.8432927915584756, 1.8528937944057642, 1.8622998301896754, 1.871519587086613, 1.8805611655318817, 1.8894321309093425, 1.8981395604117368, 1.9066900848334485, 1.9150899259433374, 1.9233449299903134, 1.9314605978150203, 1.9394421119744543, 1.9472943612303366, 1.9550219627046979, 1.9626292819659816, 1.9701204512747925, 1.9774993861892263, 1.9847698007047243, 1.991935221081911, 1.9989989984973702, 2.0059643206363234, 2.0128342223323132, 2.019611595346971, 2.0262991973724507, 2.0328996603299814, 2.0394154980299684, 2.0458491132520606, 2.052202804297441, 2.058478771060137, 2.064679120659392, 2.070805872670858, 2.0768609639906406, 2.0828462533628884, 2.0887635255986394, 2.094614495511021, 2.1004008115895134, 2.10612405943392, 2.111785764966754, 2.1173873974411137, 2.12293037225955, 2.1284160536181154, 2.133845756988505, 2.139220751450138, 2.144542261882992, 2.1498114710311227, 2.1550295214459645, 2.160197517317779, 2.165316526202937, 2.170387580654104, 2.175411679759862, 2.1803897905997567, 2.1853228496203445, 2.1902117639373393, 2.1950574125686257, 2.1998606476025055, 2.204622295305255, 2.209343157171761, 2.2140240109227265, 2.2186656114517036, 2.223268691724966, 2.227833963637031, 2.2323621188244487, 2.2368538294402898, 2.2413097488916023], [0.0, 0.8936654564494114, 1.0265520397411134, 1.1132667087646555, 1.1791986393694678, 1.2330167376865284, 1.2788076370309231, 1.3188474960721863, 1.3545435372584496, 1.3868307831520688, 1.4163642982643259, 1.4436220542513314, 1.4689642290150668, 1.4926694405710397, 1.5149579492300789, 1.5360070991998989, 1.5559619330206462, 1.5749426913647824, 1.5930502392660313, 1.6103700739880118, 1.626975339492761, 1.642929130491577, 1.6582862789559447, 1.6730947573052632, 1.6873967934190948, 1.7012297660642455, 1.7146269309382978, 1.7276180145837505, 1.7402297041702737, 1.7524860544315486, 1.7644088281146917, 1.7760177826377306, 1.7873309128988228, 1.7983646580921944, 1.8091340787853283, 1.8196530092746486, 1.829934189272523, 1.8399893782207843, 1.8498294549264829, 1.85946450473793, 1.868903896096077, 1.878156347987237, 1.8872299895723839, 1.8961324130636543, 1.9048707207508484, 1.9134515669423955, 1.9218811954707191, 1.9301654733166291, 1.938309920827786, 1.9463197389395093, 1.9541998337499895, 1.9619548387544419, 1.9695891350024375, 1.9771068694083553, 1.9845119714155977, 1.9918081681901332, 1.9989989984973702, 2.0060878253977963, 2.0130778478807643, 2.019972111541909, 2.0267735183975923, 2.0334848359192645, 2.040108705361443, 2.0466476494489774, 2.053104079482227, 2.059480301912582, 2.065778524435309, 2.072000861641894, 2.078149340269783, 2.0842259040836812, 2.0902324184191934, 2.0961706744166344, 2.1020423929701804, 2.107849228415167, 2.1135927719742327, 2.119274554981099, 2.1248960518991127, 2.1304586831501093, 2.1359638177678364, 2.1414127758889, 2.1468068310931137, 2.1521472126041097, 2.157435107360178, 2.162671661964455, 2.1678579845228687, 2.1729951463775454, 2.178084183742778, 2.1831260992501043, 2.1881218634085156, 2.1930724159853843, 2.1979786673132287, 2.2028414995270946, 2.2076617677369503, 2.212440301139168, 2.2171779040708857, 2.2218753570107515, 2.226533417529311, 2.231152821192075, 2.235734282418073, 2.2402784952965282, 2.2447861343640922, 2.2492578553449185], [0.0, 0.8967793488492094, 1.030128962818399, 1.1171457808697174, 1.1833074450242969, 1.2373130673931283, 1.2832635207769225, 1.3234428949039014, 1.3592633155551541, 1.391663063290344, 1.421299485130822, 1.4486522181795356, 1.4740826953441544, 1.4978705054581976, 1.5202366763086255, 1.5413591700421996, 1.5613835345860214, 1.5804304295797547, 1.5986010715117527, 1.6159812555527289, 1.6326443805279083, 1.6486537609961174, 1.6640644199856383, 1.6789244970712083, 1.6932763672714255, 1.7071575395958585, 1.7206013856184086, 1.7336377354608894, 1.7462933692818783, 1.7585924256314913, 1.7705567430870701, 1.782206147909489, 1.7935586976984188, 1.8046308889288962, 1.8154378346455213, 1.82599341734901, 1.8363104211420478, 1.8464006464411253, 1.856275009959463, 1.8659436321868104, 1.8754159142075613, 1.8847006053885085, 1.8938058632159154, 1.9027393063562605, 1.9115080618465983, 1.9201188071816635, 1.9285778079499212, 1.936890951575118, 1.945063777640042, 1.9531015052021772, 1.9610090574545482, 1.9687910840373435, 1.9764519812654853, 1.9839959105028822, 1.9914268148847085, 1.9987484345638886, 2.0059643206363234, 2.0130778478807643, 2.02009222643314, 2.027010512501173, 2.033835618213025, 2.0405703206831394, 2.0472172703692326, 2.0537789987863504, 2.060257925636798, 2.0666563654085777, 2.0729765334894603, 2.0792205518390237, 2.08539045425669, 2.091488191280026, 2.0975156347442225, 2.1034745820306515, 2.109366760029783, 2.1151938288413263, 2.120957385232383, 2.1266589658724633, 2.13230005036254, 2.137882064073774, 2.1434063808101813, 2.1488743253082583, 2.154287175585486, 2.159646165148611, 2.1649524850716957, 2.1702072859531065, 2.1754116797598617, 2.180566741567077, 2.185673511199636, 2.1907329947826497, 2.195746166206758, 2.2007139685138615, 2.205637315208446, 2.210517091499274, 2.2153541554758625, 2.2201493392238394, 2.2249034498829805, 2.2296172706514357, 2.2342915617394348, 2.238927061275496, 2.243524486167974, 2.2480845329245804, 2.252607878432326, 2.2570951807001713], [0.0, 0.8998505829216248, 1.0336568843451934, 1.1209717121765268, 1.1873599626786842, 1.2415505401401303, 1.287658361775386, 1.3279753397209468, 1.3639184359183454, 1.3964291442920798, 1.426167063104648, 1.4536134720902802, 1.479131041969563, 1.5030003190944423, 1.5254430882140804, 1.5466379209489174, 1.5667308636895325, 1.5858429893032098, 1.6040758609182295, 1.621515567531263, 1.6382357593392618, 1.6542999677368109, 1.6697634041916334, 1.6846743731438842, 1.6990753947354873, 1.7130041064345305, 1.7264939941038042, 1.7395749900254656, 1.7522739660731113, 1.764615143465061, 1.776620435570056, 1.7883097365487142, 1.7997011658432496, 1.8108112764247994, 1.8216552330961775, 1.832246965902024, 1.8425993027272227, 1.8527240844015969, 1.8626322650252456, 1.872333999747942, 1.8818387218503283, 1.8911552106634841, 1.9002916516109232, 1.9092556894510593, 1.9180544756291789, 1.9266947105086853, 1.9351826811360409, 1.9435242950978746, 1.9517251109485922, 1.9597903656195812, 1.967724999164511, 1.9755336771473682, 1.9832208109393008, 1.9907905761557974, 1.9982469294362357, 2.0055936237425835, 2.0128342223323132, 2.019972111541909, 2.027010512501173, 2.033952491884537, 2.040800971793439, 2.0475587388532097, 2.0542284525986894, 2.0608126532146978, 2.067313768690387, 2.073734121440273, 2.080075934439248, 2.086341336914047, 2.0925323696293194, 2.0986509898027137, 2.1046990756799633, 2.1106784307980018, 2.1165907879614445, 2.122437812955408, 2.1282211080155022, 2.1339422150739273, 2.139602618798901, 2.145203749443107, 2.1507469855154797, 2.1562336562893902, 2.161665044159195, 2.1670423868560773, 2.1723668795332154, 2.177639676729474, 2.182861894220066, 2.1880346107619584, 2.1931588697411613, 2.1982356807285015, 2.203266020949938, 2.208250836677043, 2.2131910445428153, 2.2180875327876257, 2.222941162439722, 2.2277527684344083, 2.232523160675701, 2.2372531250439995, 2.2419434243530536, 2.2465947992592783, 2.2512079691262508, 2.2557836328470398, 2.260322469626816, 2.2648251397280488], [0.0, 0.9028804514474343, 1.0371372893366482, 1.1247461131420948, 1.1913578981670916, 1.2457309396155174, 1.2919940099556335, 1.3324467383744967, 1.3685108578372633, 1.4011310323534027, 1.4309690811052556, 1.4585079043342193, 1.484111393902059, 1.5080610407826145, 1.5305793764919489, 1.5518455739153596, 1.5720061711932458, 1.591182648854871, 1.6094769119996513, 1.6269753394927609, 1.643751829517226, 1.6598701273828929, 1.6753856304588906, 1.6903468058302684, 1.7047963168076516, 1.7187719275874789, 1.7323072367821055, 1.7454322774580644, 1.7581740119686893, 1.77055674308707, 1.7826024579660036, 1.7943311177513306, 1.8057609028948687, 1.8169084221029261, 1.8277888912394151, 1.838416287252544, 1.848803481219707, 1.8589623538397426, 1.8689038960960773, 1.8786382973316813, 1.888175022589804, 1.8975228807622309, 1.9066900848334483, 1.9156843053023802, 1.9245127176937984, 1.933182044931763, 1.9416985952317218, 1.9500682960716185, 1.9582967247219538, 1.96638913574728, 1.97435048583482, 1.9821854562578862, 1.989898473241064, 1.9974937264594717, 2.0049751858748066, 2.0123466170855586, 2.019611595346971, 2.0267735183975923, 2.033835618213025, 2.040800971793439, 2.0476725110792193, 2.054453032078486, 2.0611452032809447, 2.06775157342442, 2.0742745786732963, 2.080716549261844, 2.0870797156498897, 2.0933662142334426, 2.0995780926485708, 2.105717314703029, 2.111785764966754, 2.117785253049332, 2.1237175175898693, 2.129584229982313, 2.1353869978571285, 2.141127368338324, 2.1468068310931137, 2.1524268211899553, 2.1579887217793328, 2.163493866610387, 2.1689435423953976, 2.174338991033087, 2.17968141170081, 2.1849719628248545, 2.190211763937339, 2.19540189742749, 2.2005434101944816, 2.205637315208446, 2.2106845929857393, 2.2156861929841054, 2.2206430349229205, 2.2255560100333294, 2.230425982242733, 2.2352537892977264, 2.2400402438293394, 2.2447861343640922, 2.2494922262841897, 2.2541592627398956, 2.258787965516942, 2.2633790358616253, 2.267933155266055, 2.2724509862158557], [0.0, 0.9058701872707864, 1.0405715939588083, 1.1284705195585214, 1.1953028782371258, 1.2498559668109293, 1.296272229479523, 1.3368589102628574, 1.3730424499542075, 1.4057706406580477, 1.4357074930589433, 1.4633375064407215, 1.489025777631467, 1.513054729714744, 1.535647631082073, 1.5569842479194398, 1.577211603603497, 1.596451580925724, 1.6148064224270275, 1.632362793001577, 1.6491948355337254, 1.6653665064151257, 1.6809333864539198, 1.6959441032257074, 1.7104414613134469, 1.724463349963323, 1.7380434790438097, 1.7512119810708577, 1.763995907679071, 1.7764196421160596, 1.7885052443413563, 1.8002727415987583, 1.8117403745415728, 1.8229248068730282, 1.833841304841795, 1.8445038916783807, 1.8549254810805738, 1.8651179930881365, 1.8750924550792771, 1.8848590901372508, 1.8944273946471957, 1.903806206670052, 1.9130037663862143, 1.9220277696941654, 1.9308854158792133, 1.9395834501272435, 1.9481282015422916, 1.9565256172301415, 1.9647812929294812, 1.9729005006044646, 1.9808882133555454, 1.9887491279572802, 1.9964876852909483, 2.0041080889050678, 2.011614321907193, 2.019010162364955, 2.0262991973724507, 2.0334848359192645, 2.0405703206831394, 2.0475587388532097, 2.054453032078486, 2.0612560056255957, 2.0679703368204962, 2.0745985828407263, 2.0811431879176165, 2.087606490001614, 2.093990726938335, 2.1002980421981032, 2.106530490197386, 2.1126900412467564, 2.1187785861565853, 2.124797940528674, 2.130749848759339, 2.136635987777065, 2.142457970535714, 2.148217349282333, 2.1539156186169173, 2.159554218359912, 2.165134536241868, 2.1706579104284116, 2.176125631892553, 2.181538946645351, 2.186899057835034, 2.192207127723823, 2.1974642795509762, 2.20267159928987, 2.2078301373063076, 2.2129409099247, 2.218004900908218, 2.223023062858574, 2.2279963185406384, 2.2329255621367183, 2.237811660434963, 2.242655453956025, 2.2474577580218225, 2.252219363769949, 2.256941039117043, 2.261623529674184, 2.2662675596171753, 2.270873832514373, 2.2754430321145307, 2.2799758230969838], [0.0, 0.908820967009122, 1.043961149790193, 1.1321463971745567, 1.199196455444808, 1.2539272451403498, 1.300494704050233, 1.34121359180647, 1.3775149956877262, 1.4103497951345831, 1.4403841637786836, 1.4681041791108542, 1.4938761272248586, 1.5179833511686485, 1.5406498466077567, 1.562055965298185, 1.582349209530239, 1.6016518591161588, 1.620066489641501, 1.637680048302487, 1.654566919496354, 1.6707912679461767, 1.686408855508911, 1.7014684681595236, 1.7160130499125363, 1.7300806134344886, 1.743704978400313, 1.7569163754795567, 1.7697419444247648, 1.782206147909489, 1.7943311177513308, 1.8061369464307908, 1.817641934018244, 1.8288627984972323, 1.8398148558446745, 1.8505121749703208, 1.8609677116370131, 1.8711934247128275, 1.8812003774965318, 1.8909988263720323, 1.900598298657973, 1.9100076612043764, 1.9192351810331838, 1.9282885791114828, 1.9371750781755186, 1.9459014453829322, 1.9544740304541697, 1.9628987998671052, 1.9711813675879755, 1.9793270227538193, 1.9873407546644581, 1.9952272753937128, 2.00299104028858, 2.010636266590209, 2.01816695038072, 2.025586882034414, 2.0328996603299814, 2.040108705361443, 2.0472172703692326, 2.0542284525986894, 2.0611452032809447, 2.0679703368204962, 2.0747065392644175, 2.0813563761199925, 2.087922299580386, 2.09440665521168, 2.1008116881490446, 2.10713954884494, 2.113392298407885, 2.119571913566538, 2.125680291290393, 2.1317192530953886, 2.1376905490600335, 2.1435958615752373, 2.1494368088488933, 2.155214948184336, 2.1609317790500673, 2.1665887459566004, 2.172187241154877, 2.177728607169462, 2.1832141391785775, 2.188645087252037, 2.1940226584572016, 2.199348018842242, 2.2046222953052546, 2.2098465773570632, 2.21502191878493, 2.22014933922384, 2.225229825641471, 2.230264333742539, 2.235253789297727, 2.2401990894020494, 2.2451011036671296, 2.2499606753515304, 2.2547786224329984, 2.2595557386261764, 2.2642927943491133, 2.2689905376416406, 2.273649695038491, 2.278270972399822, 2.282855055701629, 2.2874026117883735], [0.0, 0.911733914477673, 1.0473072477555103, 1.1357751459616052, 1.2030401126732269, 1.2579463251649878, 1.3046630418126135, 1.3455124415016924, 1.3819301984231835, 1.414870239770702, 1.445000874391587, 1.4728097377493, 1.4986642899555769, 1.5228487822277945, 1.5455879281810383, 1.5670626576336675, 1.5874209456494373, 1.6067854639711023, 1.625259116958866, 1.6429291304915772, 1.6598701273828933, 1.676146478016272, 1.6918141229762353, 1.7069220046062623, 1.7215132045647705, 1.7356258573562682, 1.7492938910543054, 1.762547633223589, 1.7754143106048343, 1.787918464279207, 1.800082297001076, 1.811925965651239, 1.823467828955346, 1.834724658481319, 1.845711819296753, 1.8564434254049826, 1.8669324740945827, 1.8771909625641212, 1.8872299895723839, 1.8970598443769768, 1.9066900848334483, 1.9161296062117943, 1.9253867020313657, 1.9344691180064468, 1.9433841000235532, 1.9521384369303785, 1.960738498799455, 1.9691902712323752, 1.9774993861892263, 1.9856711497597574, 1.9937105672354638, 2.0016223657932763, 2.009411015060443, 2.0170807457951896, 2.024635566887854, 2.0320792808616224, 2.0394154980299684, 2.0466476494489774, 2.0537789987863504, 2.0608126532146978, 2.06775157342442, 2.0745985828407263, 2.0813563761199925, 2.088027526992451, 2.0946144955110206, 2.1011196347597783, 2.107545197069988, 2.113893339786726, 2.120166130624765, 2.1263655526485614, 2.1324935089077646, 2.1385518267566246, 2.144542261882992, 2.1504665020701648, 2.156326170712707, 2.1621228301054116, 2.167857984522869, 2.1735330831055273, 2.1791495225667643, 2.184708649734195, 2.1902117639373393, 2.1956601192527274, 2.201054926616605, 2.2063973558145533, 2.211688537356596, 2.21692956424565, 2.2221214936465703, 2.2272653484624696, 2.2323621188244487, 2.237412763500443, 2.2424182112284092, 2.2473793619787257, 2.2522970881502897, 2.2571722357044717, 2.262005625240795, 2.266798053017912, 2.2715502919232105, 2.276263092394136, 2.2809371832941046, 2.2855732727456926, 2.290172048923583, 2.2947341808096007], [0.0, 0.9146101038546527, 1.0506111217615068, 1.1393581040567025, 1.2068352673090326, 1.2619146889603865, 1.3087787798824748, 1.3497570445919025, 1.3862896863102927, 1.4193336415251103, 1.449559327355391, 1.4774559175773845, 1.5033920315060254, 1.5276528170680466, 1.5504636967683778, 1.5720061711932454, 1.5924286822139893, 1.6118542885581604, 1.6303862192118455, 1.6481119752198634, 1.6651064148037464, 1.6814341114121343, 1.6971511821017764, 1.7123067236114713, 1.7269439535066218, 1.7411011265922485, 1.7548122779726512, 1.7681078308849896, 1.7810150979604575, 1.7935586976984188, 1.8057609028948687, 1.8176419340182437, 1.8292202077093054, 1.8405125484441816, 1.851534369761675, 1.8622998301896754, 1.872821968018482, 1.8831128182934678, 1.8931835147859712, 1.9030443792124696, 1.9127049995800738, 1.9221742992201267, 1.93146059781502, 1.940571665513954, 1.9495147710615843, 1.9582967247219538, 1.9669239166628596, 1.9754023513682941, 1.9837376785651326, 1.9919352210819108, 2.0, 2.0079367574088582, 2.0157499770357843, 2.023443902985509, 2.031022556794963, 2.038489752982913, 2.0458491132520606, 2.053104079482227, 2.060257925636798, 2.067313768690387, 2.0742745786732963, 2.0811431879176165, 2.087922299580386, 2.0946144955110206, 2.1012222435230137, 2.107747904123567, 2.114193736749232, 2.120561905550725, 2.126854484765708, 2.133073463714486, 2.139220751450138, 2.1452981810915532, 2.1513075138651403, 2.15725044287854, 2.163128596647537, 2.168943542395397, 2.1746967891421503, 2.1803897905997567, 2.1860239478877173, 2.191600612082399, 2.1971210866122357, 2.202586629509912, 2.207998455531738, 2.2133577381535448, 2.218665611451703, 2.223923171877158, 2.2291314799297353, 2.2342915617394348, 2.239404410560863, 2.2444709881865186, 2.2494922262841897, 2.254469027663335, 2.259402267474952, 2.264292794349113, 2.2691414314740346, 2.273948977620276, 2.278716208113405, 2.2834438757582225, 2.288132711717446, 2.292783426347521, 2.29739670999407, 2.301973233749315], [0.0, 0.9174505626104982, 1.0538739520617835, 1.142896551411561, 1.210583275107595, 1.2658337541579836, 1.3128433885382442, 1.3539489173903954, 1.3905950167030172, 1.4237415948732581, 1.454061151100997, 1.4820443783649608, 1.5080610407826145, 1.532397171850314, 1.5552788941563636, 1.5768882719642627, 1.5973742081538305, 1.6168601436299403, 1.6354496279717667, 1.6532304339717372, 1.6702776523348106, 1.6866560570521496, 1.702421939460434, 1.7176245487757429, 1.7323072367821057, 1.7465083770905736, 1.7602621105065641, 1.7735989547511593, 1.7865463072790226, 1.7991288630459576, 1.811368964019466, 1.823286893465679, 1.8349011252209964, 1.8462285360124782, 1.8572845872479822, 1.8680834814268286, 1.8786382973316813, 1.8889611073845498, 1.8990630799343688, 1.908954568753253, 1.9186451916253062, 1.9281438995946143, 1.9374590381815897, 1.9465984016667952, 1.9555692813690628, 1.9643785087027308, 1.97303249368122, 1.9815372594363483, 1.989898473241064, 1.9981214744547449, 2.0062112997524832, 2.014172705951006, 2.0220101907024994, 2.029728011292397, 2.037330201747117, 2.044820588431984, 2.052202804297441, 2.059480301912582, 2.0666563654085777, 2.073734121440273, 2.080716549261844, 2.087606490001614, 2.09440665521168, 2.1011196347597783, 2.107747904123567, 2.1142938311411568, 2.120759682266118, 2.127147628370261, 2.1334597501331043, 2.1396980430530848, 2.1458644221121324, 2.1519607261221614, 2.157988721779333, 2.163950107449488, 2.16984651670601, 2.1756795216394123, 2.1814506359562125, 2.187161317883091, 2.192812972890936, 2.198406956252084, 2.2039445754429607, 2.209427092403261, 2.2148557256619017, 2.2202316523391197, 2.2255560100333294, 2.230829898600669, 2.236054381834505, 2.2412304890516386, 2.246359216591376, 2.2514415292332077, 2.2564783615383557, 2.2614706191200877, 2.2664191798473157, 2.271324894985658, 2.2761885902798666, 2.2810110669812023, 2.285793102823122, 2.2905354529483755, 2.295238850790416, 2.2999040089118057, 2.304531619802141, 2.30912235663782], [0.0, 0.9202562742220908, 1.057096868374616, 1.1463917131737602, 1.2142854337744386, 1.2697048776900042, 1.3168582751049314, 1.358089511285958, 1.3948476802735588, 1.428095626019391, 1.4585079043342193, 1.4865767088149444, 1.5126729343772676, 1.5370834892540532, 1.560035187552907, 1.5817106503191742, 1.6022592358016674, 1.6218047624074317, 1.6404510963869354, 1.6582862789559447, 1.6753856304588908, 1.691814122976235, 1.7076282199926331, 1.7228773213362, 1.737604911367705, 1.7518494810508827, 1.7656452755992336, 1.7790229060619465, 1.7920098536795155, 1.8046308889288962, 1.8169084221029261, 1.828862798497232, 1.8405125484441816, 1.851874600282584, 1.8629644627037738, 1.8737963816406014, 1.8843834758727551, 1.8947378547416558, 1.9048707207508482, 1.9147924593359498, 1.924512717693798, 1.9340404742422128, 1.943384100023553, 1.9525514131545463, 1.9615497272520528, 1.970385894621976, 1.979066344880591, 1.987597119579422, 1.9959839033228517, 2.0042320517988785, 2.012346617085558, 2.020332370546731, 2.028193823589126, 2.0359352465176435, 2.0435606856954025, 2.0510739791893706, 2.058478771060137, 2.065778524435309, 2.0729765334894603, 2.080075934439248, 2.0870797156498897, 2.093990726938335, 2.1008116881490446, 2.107545197069988, 2.114193736749232, 2.120759682266118, 2.127245307005396, 2.1336527884777534, 2.1399842137257603, 2.14624158435041, 2.1524268211899553, 2.1585417686796946, 2.164588198918629, 2.1705678154664763, 2.1764822568923514, 2.1823331000944726, 2.188121863408516, 2.193850009520655, 2.199518948199932, 2.2051300388633277, 2.2106845929857393, 2.2161838763660766, 2.2216291112597153, 2.2270214783867144, 2.2323621188244482, 2.2376521357925916, 2.242892596337763, 2.2480845329245804, 2.2532289449393157, 2.2583268001119103, 2.2633790358616253, 2.2683865605712397, 2.27335025479433, 2.2782709723998216, 2.2831495416577274, 2.2879867662696634, 2.2927834263475204, 2.2975402793433974, 2.302258060933704, 2.3069374858601344, 2.311579248730029, 2.316184024778469], [0.0, 0.923028180690743, 1.0602809527753625, 1.149844762823481, 1.2179429862877478, 1.2735293592636, 1.3208247875572883, 1.3621802164588452, 1.3990491048289124, 1.4323971968040765, 1.4629010800265252, 1.4910544306308542, 1.5172292607063653, 1.5417133426830054, 1.5647341738557805, 1.5864749253433919, 1.607085405277046, 1.626689805017555, 1.6453923036712068, 1.6632812076429573, 1.6804320641498556, 1.696910040974946, 1.7127717716767028, 1.7280668048805998, 1.7428387559267693, 1.7571262317176846, 1.7709635806169484, 1.7843815058773753, 1.79740757151578, 1.8100666226203401, 1.8223811369859984, 1.8343715211905027, 1.846056361381486, 1.8574526368876543, 1.868575903114113, 1.879440448903927, 1.8900594325518971, 1.9004449998740247, 1.910608387116947, 1.9205600109982806, 1.9303095477732108, 1.939866002903475, 1.949237772645872, 1.9584326986661005, 1.967458116610386, 1.9763208994244816, 1.9850274960913272, 1.993583966360221, 2.001996011958159, 2.0102690047050213, 2.018408011896243, 2.0264178192675013, 2.0343029518143476, 2.042067692704278, 2.049716100488473, 2.0572520247945527, 2.064679120659392, 2.072000861641894, 2.0792205518390237, 2.086341336914047, 2.0933662142334426, 2.1002980421981032, 2.10713954884494, 2.113893339786726, 2.120561905550725, 2.127147628370261, 2.1336527884777534, 2.140079569942774, 2.1464300660942808, 2.1527062845622944, 2.1589101519708302, 2.1650435183108145, 2.171108161018994, 2.177105788786382, 2.183038045117633, 2.1889065116607442, 2.1947127113247755, 2.2004581112016606, 2.206144125306812, 2.2117721171519125, 2.217343402162158, 2.2228592499491744, 2.228320886449896, 2.233729495940831, 2.2390862229363977, 2.2443921739792807, 2.2496484193301534, 2.2548559945635227, 2.260015902075915, 2.2651291125121733, 2.2701965661151626, 2.275219174003804, 2.280197819383991, 2.285133358696591, 2.290026622706451, 2.2948784175360184, 2.299689525646962, 2.304460706772903, 2.309192698806185, 2.313886218641378, 2.3185419629780504, 2.32316060908516], [0.0, 0.9257671848808375, 1.063427242382854, 1.153256825086818, 1.2215571239842176, 1.2773084445875398, 1.3247442178663313, 1.3662223653320817, 1.4032006588555799, 1.4366477083334102, 1.4672421091215284, 1.4954790022946365, 1.5217315038548884, 1.5462882401713718, 1.5693773836171203, 1.5911826488548708, 1.6118542885581606, 1.6315168626146404, 1.6502748592728484, 1.6682168469791585, 1.68541859713028, 1.7019454708888686, 1.717854269868456, 1.733194689725664, 1.7480104752252745, 1.7623403478323174, 1.7762187578361146, 1.7896764995986587, 1.8027412189305372, 1.8154378346455213, 1.8277888912394151, 1.8398148558446743, 1.851534369761675, 1.862964462703774, 1.8741207362353607, 1.8850175216003733, 1.8956680161396844, 1.9060844017109262, 1.9162779479033, 1.9262591023451077, 1.9360375700049628, 1.9456223830675112, 1.9550219627046979, 1.9642441738516687, 1.9732963739225284, 1.9821854562578862, 1.9909178889774666, 1.999499749812336, 2.0079367574088582, 2.0162342995273135, 2.024397458499885, 2.032431034263497, 2.040339565241222, 2.048127347310476, 2.055798451065831, 2.063356737558334, 2.070805872670858, 2.078149340269783, 2.08539045425669, 2.0925323696293194, 2.0995780926485708, 2.106530490197386, 2.113392298407885, 2.120166130624765, 2.126854484765708, 2.1334597501331043, 2.1399842137257603, 2.1464300660942808, 2.152799406779391, 2.159094249368576, 2.165316526202937, 2.171468092763084, 2.1775507317601486, 2.1835661569555342, 2.189516016730849, 2.19540189742749, 2.201225326473615, 2.206987775314622, 2.21269066216189, 2.218335354573201, 2.223923171877158, 2.2294553874528473, 2.2349332308750616, 2.240357889934545, 2.245730512541961, 2.2510522085235607, 2.256324051315922, 2.261547079566526, 2.2667222986464224, 2.271850682080757, 2.2769331729024813, 2.281970684934181, 2.2869641040025854, 2.291914289089974, 2.2968220734264135, 2.30168826552645, 2.306513650173636, 2.311298989356037, 2.3160450231556244, 2.32075247059429, 2.3254220304389968, 2.330054381968438], [0.0, 0.9284741526943301, 1.066536731857243, 1.156628978644629, 1.2251289894283288, 1.2810433283724363, 1.3286178051109863, 1.3702172357805344, 1.4073036548155011, 1.44084850435351, 1.4715323639813442, 1.4998518225793462, 1.5261810871507613, 1.550809628015838, 1.5739662847296843, 1.595835309141585, 1.6165673932678815, 1.6362874612126417, 1.6551003067508152, 1.6730947573052628, 1.6903468058302684, 1.7069220046062619, 1.7228773213361999, 1.738262596988123, 1.753121704237666, 1.7674934777724496, 1.7814124686153567, 1.794909561171911, 1.8080124820897834, 1.8207462230460183, 1.8331333944571235, 1.845194523301993, 1.8569483053886602, 1.8684118202258153, 1.8796007149972362, 1.8905293628517985, 1.9012109997197495, 1.9116578430787967, 1.9218811954707191, 1.9318915350729609, 1.9416985952317216, 1.9513114345419946, 1.9607384987994547, 1.9699876759365276, 1.9790663448805912, 1.9879814191285663, 1.9967393857131306, 2.0053463401367977, 2.0138080177674054, 2.0221298221191875, 2.0303168503852014, 2.0383739165375134, 2.046305572269668, 2.054116126020338, 2.0618096602866243, 2.069390047409388, 2.0768609639906406, 2.0842259040836812, 2.091488191280026, 2.0986509898027137, 2.105717314703029, 2.1126900412467564, 2.119571913566538, 2.1263655526485614, 2.133073463714486, 2.1396980430530848, 2.14624158435041, 2.1527062845622944, 2.159094249368576, 2.1654074982445235, 2.171647969181454, 2.177817523085452, 2.1839179478803445, 2.189950962338619, 2.195918219661794, 2.201821310829772, 2.2076617677369503, 2.2134410661312733, 2.219160628371007, 2.224821826012708, 2.230425982242733, 2.2359743741635603, 2.2414682349452937, 2.246908755851809, 2.2522970881502893, 2.257634344912149, 2.262921602712721, 2.268159903236521, 2.27335025479433, 2.2784936337579063, 2.2835909859176553, 2.2886432277682047, 2.2936512477264634, 2.2986159072863988, 2.3035380421144644, 2.308418463089324, 2.313257957289258, 2.318057288930406, 2.3228172002587573, 2.3275384123986442, 2.332221626160242, 2.336867522808473], [0.0, 0.9311499150948378, 1.069610375725069, 1.1599622586540015, 1.2286596790831472, 1.2847351571234393, 1.3324467383744967, 1.3741660541180074, 1.4113593522139962, 1.445000874391587, 1.4757731615945522, 1.5041742338188457, 1.530579376491949, 1.5552788941563638, 1.5785022858581217, 1.6004343344404715, 1.6212261661978986, 1.6410030652522691, 1.659870127382893, 1.6779164360036873, 1.6952182030724356, 1.7118411697841731, 1.7278424680166335, 1.7432720823741537, 1.7581740119686893, 1.772587203405244, 1.7865463072790226, 1.800082297001076, 1.813222979124284, 1.8259934173490102, 1.8384162872525442, 1.8505121749703208, 1.8622998301896756, 1.8737963816406016, 1.8850175216003735, 1.8959776646397317, 1.9066900848334483, 1.9171670348686836, 1.9274198498599235, 1.9374590381815897, 1.9472943612303364, 1.9569349037070505, 1.96638913574728, 1.9756649680156209, 1.9847698007047243, 1.9937105672354638, 2.0024937733354458, 2.011125532073765, 2.0196115953469707, 2.027957382241642, 2.0361680046403983, 2.044248290388653, 2.052202804297441, 2.0600358672218912, 2.06775157342442, 2.0753538064055586, 2.0828462533628884, 2.0902324184191934, 2.0975156347442225, 2.1046990756799633, 2.111785764966754, 2.1187785861565853, 2.125680291290393, 2.1324935089077646, 2.139220751450138, 2.1458644221121324, 2.1524268211899553, 2.1589101519708302, 2.165316526202937, 2.171647969181454, 2.17790642448278, 2.184093758375932, 2.1902117639373393, 2.196262164892806, 2.2022466192082, 2.2081667224484565, 2.2140240109227265, 2.2198199646319012, 2.2255560100333294, 2.231233522636247, 2.2368538294402898, 2.242418211228409, 2.24792790472457, 2.253384104625744, 2.258787965516942, 2.264140603677329, 2.269443098784813, 2.2746964955259323, 2.2799018051173094, 2.285060006744503, 2.290172048923583, 2.2952388507904153, 2.300261303322232, 2.3052402704957324, 2.310176590385671, 2.315071076207576, 2.319924517308003, 2.324737680105479, 2.329511308985068, 2.3342461271493034, 2.3389428374280206, 2.343602123049474], [0.0, 0.9337952699937012, 1.0726490905457766, 1.163257659097779, 1.2321502457989992, 1.288385031742493, 1.3362321594433206, 1.3780699978806428, 1.415368960458503, 1.4491060566828236, 1.4799657665654045, 1.5084475249545395, 1.5349276834466783, 1.5596973713264297, 1.5829867396362618, 1.6049810961791438, 1.6258319965925458, 1.6456650809248718, 1.6645857435277995, 1.682683320897205, 1.7000342415056062, 1.716704433315807, 1.7327511905146284, 1.748224639710413, 1.7631689050146089, 1.7776230436777665, 1.7916218047358692, 1.8051962495940308, 1.8183742638022937, 1.8311809822658631, 1.8436391449823208, 1.8557693965713833, 1.8675905399874024, 1.8791197526223202, 1.8903727713344627, 1.9013640516457162, 1.9121069053418995, 1.922613619919505, 1.9328955626955673, 1.9429632718983258, 1.9528265366561217, 1.9624944674790679, 1.9719755585659848, 1.98127774305531, 1.990408442163308, 1.9993746090083881, 2.0081827678006356, 2.0168390489760983, 2.025349220772205, 2.0337187176709137, 2.041952666077473, 2.050055907552987, 2.058033019876912, 2.0658883361797336, 2.07362596235548, 2.0812497929375344, 2.0887635255986394, 2.0961706744166344, 2.1034745820306515, 2.1106784307980018, 2.117785253049332, 2.124797940528674, 2.1317192530953886, 2.1385518267566246, 2.1452981810915532, 2.1519607261221614, 2.1585417686796946, 2.1650435183108145, 2.171468092763084, 2.177817523085452, 2.184093758375932, 2.190298670205525, 2.1964340567447116, 2.202501646616322, 2.2085031024964303, 2.2144400244829, 2.2203139532494665, 2.226126373001638, 2.2318787142492633, 2.237572356409338, 2.2432086302514445, 2.2487888201971797, 2.2543141664839874, 2.259785867202918, 2.265205080219106, 2.270572924983016, 2.2758904842398726, 2.28115880564412, 2.2863789032852027, 2.291551759130501, 2.2966783243907756, 2.301759520813117, 2.306796241905983, 2.311789354100591, 2.316739697852629, 2.3216480886879336, 2.326515318195558, 2.33134215497139, 2.3361293455152583, 2.3408776150842816, 2.345587668505003, 2.3502601909466976], [0.0, 0.9364109840092412, 1.0756537569325701, 1.1665161349761233, 1.235601701134824, 1.2919940099556333, 1.339975165324572, 1.3819301984231833, 1.4193336415251103, 1.4531652409004676, 1.484111393902059, 1.5126729343772676, 1.539227268145216, 1.5640663399914851, 1.5874209456494368, 1.609476911999651, 1.6303862192118457, 1.6502748592728484, 1.6692485217612372, 1.687396793419095, 1.7047963168076519, 1.7215132045647705, 1.737604911367705, 1.7531217042376661, 1.7681078308849896, 1.7826024579660036, 1.796640431854452, 1.810252900963549, 1.823467828955346, 1.8363104211420478, 1.8488034812197072, 1.860967711637013, 1.8728219680184823, 1.8843834758727553, 1.8956680161396844, 1.9066900848334483, 1.9174630310283656, 1.9279991766402256, 1.9383099208277863, 1.948405831338596, 1.9582967247219536, 1.9679917370080078, 1.9774993861892263, 1.9868276276260706, 1.995983903322852, 2.004975185874807, 2.0138080177674054, 2.0224885466090545, 2.031022556794963, 2.039415498029968, 2.0476725110792193, 2.055798451065831, 2.0637979085923717, 2.0716752289271367, 2.0794345294654395, 2.0870797156498897, 2.094614495511021, 2.1020423929701804, 2.109366760029783, 2.1165907879614445, 2.1237175175898693, 2.130749848759339, 2.1376905490600335, 2.144542261882992, 2.1513075138651403, 2.157988721779333, 2.164588198918629, 2.171108161018994, 2.1775507317601486, 2.1839179478803445, 2.1902117639373393, 2.1964340567447116, 2.2025866295099124, 2.208671215697929, 2.214689482642265, 2.2206430349229205, 2.226533417529311, 2.2323621188244487, 2.238130573325275, 2.2438401643127603, 2.24949222628419, 2.255088047259038, 2.2606288709488562, 2.266115898800745, 2.2715502919232105, 2.2769331729024813, 2.2822656275167286, 2.2875487063550497, 2.292783426347521, 2.2979707722121727, 2.3031116978242654, 2.3082071275128535, 2.3132579572892586, 2.3182650560117155, 2.3232292664901655, 2.3281514065348676, 2.3330322699522466, 2.3378726274911523, 2.342673227742483, 2.347434797994922, 2.3521580450493476, 2.3568436559943056], [0.0, 0.9389977941093632, 1.07862522143927, 1.1697386043527551, 1.239015017525602, 1.295563108579339, 1.3436768105965373, 1.3857477433430851, 1.4232545124482816, 1.4571795707049016, 1.488211211619932, 1.5168516525807585, 1.543479341979905, 1.568387031092553, 1.5918061532190553, 1.6139230485817406, 1.6348901171914485, 1.6548336990844736, 1.6738597758040061, 1.6920581815730884, 1.7095057706759604, 1.7262688383848641, 1.7424049980940515, 1.7579646556860233, 1.7729921811042229, 1.7875268492018108, 1.8016036026146989, 1.815253675802753, 1.8285051096768874, 1.841383179178302, 1.8539107509976454, 1.8661085847735632, 1.8779955882187265, 1.8895890344267787, 1.9009047479319934, 1.9119572647933973, 1.9227599709617675, 1.9333252223918531, 1.9436644497322813, 1.9537882499237176, 1.9637064666334139, 1.9734282611295562, 1.982962174935336, 1.9923161853876845, 2.001497755049249, 2.0105138757768724, 2.019371108129464, 2.0280756166980334, 2.0366332018570263, 2.0450493283659408, 2.053329151191153, 2.0614775388679236, 2.069499094680237, 2.077398175900074, 2.0851789112969437, 2.092845217102134, 2.1004008115895134, 2.107849228415167, 2.1151938288413263, 2.122437812955408, 2.129584229982313, 2.136635987777065, 2.1435958615752373, 2.1504665020701648, 2.15725044287854, 2.163950107449488, 2.1705678154664763, 2.177105788786382, 2.1835661569555342, 2.189950962338619, 2.196262164892806, 2.202501646616322, 2.208671215697929, 2.214772610391266, 2.220807502635799, 2.226777501444137, 2.2326841560736885, 2.2385289589990274, 2.24431334869991, 2.2500387122785823, 2.255706387918843, 2.261317667198285, 2.2668737972641804, 2.2723759828825942, 2.277825388369563, 2.2832231394124305, 2.2885703247888007, 2.2938679979899947, 2.2991171787553304, 2.304318854523096, 2.3094739818036065, 2.3145834874793496, 2.319648270036855, 2.324669200734554, 2.329647124710629, 2.3345828620345164, 2.3394772087055102, 2.344330937601634, 2.3491447993817474, 2.353919523343649, 2.358655818240736, 2.3633543730596176], [0.0, 0.941556409146734, 1.0815642983237685, 1.1729259502673735, 1.2423911303080353, 1.2990933056386604, 1.347338109605466, 1.3895236787460892, 1.4271326476477473, 1.4611501461259986, 1.4922663431747896, 1.5209848246415458, 1.5476850701286136, 1.572660628610401, 1.5961435640050612, 1.6183207242814768, 1.6393449247155305, 1.6593428495994027, 1.678420769258612, 1.6966687626997305, 1.7141638936223218, 1.7309726379423758, 1.7471527660411976, 1.762754821149054, 1.777823294110209, 1.7923975667953596, 1.8065126770533706, 1.8201999444528907, 1.8334874863117185, 1.8464006464411256, 1.8589623538397428, 1.8711934247128275, 1.883112818293468, 1.894737854741656, 1.9060844017109264, 1.9171670348686836, 1.9279991766402256, 1.9385932166482527, 1.9489606166880353, 1.9591120025751652, 1.9690572447992734, 1.9788055295914995, 1.9883654217492857, 1.9977449203464979, 2.0069515082800438, 2.015992196458429, 2.0248735633170107, 2.033601790244299, 2.0421826934198073, 2.050621752493609, 2.0589241364785176, 2.067094727175754, 2.075138140412497, 2.0830587453335796, 2.09086068195873, 2.0985478771903257, 2.10612405943392, 2.1135927719742327, 2.120957385232383, 2.1282211080155022, 2.1353869978571285, 2.142457970535714, 2.1494368088488933, 2.156326170712707, 2.163128596647537, 2.16984651670601, 2.1764822568923514, 2.183038045117633, 2.189516016730849, 2.195918219661794, 2.2022466192082, 2.2085031024964303, 2.214689482642265, 2.220807502635799, 2.226858838972259, 2.23284510504855, 2.238767854343553, 2.24462858339859, 2.250428734613039, 2.256169698868772, 2.2618528179959196, 2.267479387091412, 2.273050656700792, 2.278567834872916, 2.28403208909639, 2.2894445481258714, 2.294806303705705, 2.300118412197802, 2.305381896120104, 2.3105977456015063, 2.315766919758657, 2.320890347999647, 2.325968931259235, 2.3310035431698886, 2.335995031172652, 2.3409442175715176, 2.345851900534747, 2.350718855046329, 2.3555458338105457, 2.360333568112413, 2.365082768636564, 2.3697941262469846], [0.0, 0.944087511294902, 1.0844717711976986, 1.1760790225246736, 1.2457309396155174, 1.302585542348676, 1.3509600385206135, 1.39325901136561, 1.4309690811052556, 1.4650780257917608, 1.4962778697388448, 1.5250735525388686, 1.5518455739153598, 1.5768882719642627, 1.6004343344404712, 1.6226711115996042, 1.643751829517226, 1.6638035130396043, 1.6829327181692995, 1.7012297660642455, 1.7187719275874789, 1.735625857356268, 1.7518494810508827, 1.7674934777724498, 1.7826024579660034, 1.7972159093690119, 1.8113689640194657, 1.8250930256796174, 1.8384162872525442, 1.8513641606790256, 1.8639596365956759, 1.8762235871661006, 1.888175022589804, 1.8998313095870198, 1.9112083584668813, 1.9223207840792598, 1.933182044931763, 1.9438045639530086, 1.9541998337499895, 1.9643785087027306, 1.9743504858348198, 1.984124976071923, 1.9937105672354638, 2.003115279902505, 2.0123466170855586, 2.0214116085399314, 2.0303168503852014, 2.039068540626754, 2.0476725110792193, 2.0561342561231264, 2.064458958666684, 2.072651513634425, 2.080716549261844, 2.088658446438957, 2.096481356314738, 2.1041892163479057, 2.111785764966754, 2.119274554981099, 2.1266589658724633, 2.1339422150739273, 2.141127368338324, 2.148217349282333, 2.155214948184336, 2.1621228301054116, 2.168943542395397, 2.1756795216394123, 2.1823331000944726, 2.1889065116607442, 2.19540189742749, 2.201821310829772, 2.2081667224484565, 2.2144400244829, 2.2206430349229205, 2.226777501444137, 2.23284510504855, 2.2388474634702153, 2.2447861343640922, 2.2506626182945215, 2.2564783615383552, 2.2622347587164486, 2.267933155266055, 2.2735748497655974, 2.2791610961223494, 2.284693105632657, 2.2901720489235826, 2.295599057784113, 2.3009752268934327, 2.3063016154531764, 2.311579248730029, 2.3168091195145615, 2.3219921895017297, 2.32712939059807, 2.3322216261602424, 2.337269772169223, 2.342274678344157, 2.347237169199563, 2.352158045049347, 2.357038082960819, 2.3618780376616875, 2.366678642402817, 2.371440609779312, 2.3761646325123453], [0.0, 0.9465917573929856, 1.0873483945710751, 1.1791986393694678, 1.2490353121524609, 1.3060407249698005, 1.3545435372584498, 1.3969547105471898, 1.43476480840274, 1.4689642290150668, 1.500246832331945, 1.5291188973268721, 1.5559619330206462, 1.5810710582578387, 1.6046795780109158, 1.6269753394927609, 1.6481119752198636, 1.6682168469791587, 1.687396793419095, 1.705742375279642, 1.7233310683892178, 1.7402297041702735, 1.7564963619542582, 1.7721818552715112, 1.7873309128988228, 1.8019831273171425, 1.8161737237542004, 1.8299341892725232, 1.8432927915584756, 1.856275009959463, 1.8689038960960773, 1.8812003774965316, 1.8931835147859712, 1.9048707207508482, 1.9162779479033, 1.9274198498599233, 1.938309920827786, 1.948960616688035, 1.95938346053246, 1.9695891350024377, 1.979587563373977, 1.989387981005251, 1.9989989984973704, 2.0084286577024373, 2.017684481535133, 2.026773518397593, 2.0357023819059785, 2.044477286506239, 2.053104079482227, 2.0615882697886287, 2.0699350540816144, 2.0781493402697833, 2.0862357688652895, 2.094198732378711, 2.1020423929701804, 2.1097706985427513, 2.1173873974411137, 2.1248960518991127, 2.13230005036254, 2.139602618798901, 2.1468068310931137, 2.1539156186169173, 2.1609317790500673, 2.167857984522869, 2.1746967891421503, 2.1814506359562125, 2.188121863408516, 2.1947127113247755, 2.201225326473615, 2.2076617677369503, 2.2140240109227265, 2.2203139532494665, 2.226533417529311, 2.2326841560736885, 2.238767854343553, 2.2447861343640922, 2.2507405579220348, 2.2566326295620533, 2.262463799397333, 2.26823546574804, 2.2739489776202766, 2.27960563703702, 2.285206701231605, 2.2907533847134087, 2.2962468612146494, 2.30168826552645, 2.3070786952316924, 2.312419212341606, 2.317710844842453, 2.322954588158238, 2.3281514065348676, 2.3333022343508145, 2.3384079773589437, 2.34346951386382, 2.348487695838519, 2.353463349984629, 2.3583972787389356, 2.3632902612299636, 2.368143054187381, 2.372956392807042, 2.377730991574249, 2.3824675450476587], [0.0, 0.9490697802058682, 1.0901948952998783, 1.1822855890565487, 1.2523050828571352, 1.309459726546512, 1.3580895112859581, 1.4006117101082607, 1.4385207886324167, 1.4728097377493, 1.5041742338188457, 1.5331218811703207, 1.5600351875529073, 1.5852100443841721, 1.608880367390943, 1.6312344955394649, 1.6524264635310948, 1.6725839665651505, 1.6918141229762353, 1.7102077305775631, 1.7278424680166338, 1.7447853416696602, 1.7610945829103073, 1.7768211382904486, 1.7920098536795155, 1.8067004252051142, 1.820928170308875, 1.834724658481319, 1.8481182314090019, 1.8611344351401047, 1.8737963816406016, 1.8861250532235614, 1.8981395604117364, 1.9098573615754133, 1.9212944509878043, 1.9324655206262837, 1.9433841000235528, 1.9540626776682233, 1.9645128068176596, 1.9747451980786508, 1.984769800704724, 1.9945958742307133, 2.0042320517988785, 2.013686396313579, 2.02296645038326, 2.0320792808616224, 2.0410315186781975, 2.0498293945473396, 2.058478771060137, 2.0669851715928202, 2.075353806405558, 2.083589596255054, 2.091697193801566, 2.099681003054547, 2.107545197069988, 2.1152937340859075, 2.12293037225955, 2.1304586831501093, 2.137882064073774, 2.145203749443107, 2.1524268211899553, 2.159554218359912, 2.1665887459566004, 2.1735330831055273, 2.1803897905997567, 2.187161317883091, 2.193850009520655, 2.2004581112016606, 2.206987775314622, 2.2134410661312733, 2.2198199646319012, 2.226126373001638, 2.2323621188244487, 2.2385289589990274, 2.24462858339859, 2.2506626182945215, 2.2566326295620533, 2.2625401256845117, 2.26838656057124, 2.2741733362029795, 2.27990180511731, 2.2855732727456926, 2.2911889996126935, 2.296750203407078, 2.302258060933704, 2.307713709954391, 2.3131182509253154, 2.318472748637878, 2.323778233769441, 2.329035704349868, 2.3342461271493034, 2.3394104389922696, 2.3445295480027455, 2.349604334784555, 2.3546356535410977, 2.359624333138134, 2.3645711781130974, 2.3694769696341442, 2.374342466411937, 2.3791684055669524, 2.3839555034549, 2.3887044564526763], [0.0, 0.9515221896062347, 1.0930119739438586, 1.1853406313231891, 1.2555410564613725, 1.312843388538244, 1.3615988333120945, 1.4042309100825638, 1.442237946188418, 1.476615498422687, 1.5080610407826143, 1.537083489254053, 1.564066339991485, 1.58930624899998, 1.6130377364478303, 1.6354496279717665, 1.6566963563009383, 1.6769059466008198, 1.6961857940012675, 1.7146269309382975, 1.7323072367821057, 1.7492938910543052, 1.7656452755992336, 1.781412468615357, 1.796640431854452, 1.8113689640194657, 1.825633473812785, 1.8394656123009294, 1.8528937944057637, 1.86594363218681, 1.878638297331681, 1.8909988263720319, 1.9030443792124694, 1.9147924593359495, 1.9262591023451074, 1.9374590381815895, 1.9484058313385957, 1.9591120025751647, 1.9695891350024375, 1.9798479669035587, 1.9898984732410638, 1.9997499374765524, 2.009411015060443, 2.0188897897317513, 2.0281938235891266, 2.037330201747117, 2.046305572269668, 2.0551261819713846, 2.0637979085923717, 2.0723262897813406, 2.080716549261844, 2.0889736205058878, 2.097102168196269, 2.1051066077224623, 2.1129911229236913, 2.120759682266118, 2.1284160536181154, 2.1359638177678364, 2.1434063808101813, 2.1507469855154797, 2.1579887217793328, 2.165134536241868, 2.172187241154877, 2.1791495225667643, 2.1860239478877173, 2.192812972890936, 2.199518948199932, 2.206144125306812, 2.21269066216189, 2.219160628371007, 2.2255560100333294, 2.2318787142492633, 2.238130573325275, 2.24431334869991, 2.250428734613039, 2.2564783615383552, 2.262463799397333, 2.26838656057124, 2.2742481027263417, 2.2800498314661173, 2.2857931028231215, 2.2914792256020697, 2.2971094635847393, 2.3026850376064214, 2.308207127512853, 2.313676874005847, 2.3190953803851726, 2.324463714193666, 2.3297829087719757, 2.3350539647288864, 2.340277851332691, 2.345455507828679, 2.3505878446874338, 2.355675744788272, 2.3607200645418667, 2.3657216349557793, 2.3706812626463782, 2.37559973080037, 2.3804778000889346, 2.38531620953728, 2.390115677352187, 2.3948769017100013], [0.0, 0.9539495736842316, 1.0958003060411996, 1.18836449877148, 1.2587440089547735, 1.3161925223504152, 1.3650723448756752, 1.4078131783577537, 1.4459171724487216, 1.4803824236603191, 1.51190818528332, 1.5410046715755197, 1.5680563570106334, 1.5933606543790917, 1.617152682122699, 1.6396217475825003, 1.6609226774538108, 1.6811838235011594, 1.7005128548251323, 1.7190010360903663, 1.7367264453415023, 1.7537564334787121, 1.7701495312815458, 1.7859569472516899, 1.801223757840758, 1.8159898632803209, 1.8302907626022618, 1.8441581876166662, 1.8576206257333876, 1.870703754349683, 1.883430804265382, 1.8958228656774587, 1.9078991473684632, 1.9196771974736742, 1.9311730925034074, 1.9424015999761801, 1.9533763189889413, 1.9641098022418562, 1.9746136623952029, 1.9848986651260614, 1.9949748108436314, 2.00485140669212, 2.014537130202464, 2.0240400857357295, 2.0333678546818845, 2.042527540229985, 2.051525807403542, 2.060368918953121, 2.0690627676132562, 2.0776129051594974, 2.086024568641395, 2.094302704116507, 2.102451988167487, 2.110476847447703, 2.118381476469578, 2.1261698538230425, 2.133845756988505, 2.1414127758889, 2.1488743253082583, 2.1562336562893902, 2.163493866610387, 2.1706579104284116, 2.177728607169462, 2.184708649734195, 2.191600612082399, 2.198406956252084, 2.2051300388633277, 2.2117721171519125, 2.218335354573201, 2.224821826012708, 2.231233522636247, 2.237572356409338, 2.2438401643127603, 2.2500387122785823, 2.256169698868772, 2.2622347587164486, 2.26823546574804, 2.2741733362029795, 2.2800498314661173, 2.2858663607267022, 2.291624283476601, 2.2973249118593593, 2.30296951288073, 2.3085593104904207, 2.314095487544018, 2.3195791876533254, 2.32501151693269, 2.3303935456483065, 2.3357263097769305, 2.341010812479954, 2.346248025498324, 2.3514388904733963, 2.3565843201984134, 2.3616851998049637, 2.36674238788847, 2.3717567175764387, 2.37672899754296, 2.3816600129726906, 2.3865505264773255, 2.391401278967363, 2.39621299048177, 2.400986360977976], [0.0, 0.9563524997900371, 1.0985605433061179, 1.1913578981670918, 1.2619146889603865, 1.3195079107728944, 1.3685108578372636, 1.4113593522139962, 1.4495593273553913, 1.484111393902059, 1.5157165665103982, 1.5448863446289454, 1.5720061711932458, 1.5973742081538305, 1.6212261661978982, 1.6437518295172258, 1.6651064148037467, 1.68541859713028, 1.7047963168076519, 1.7233310683892176, 1.7411011265922485, 1.7581740119686893, 1.774608402732652, 1.790455636376128, 1.8057609028948687, 1.8205642030260805, 1.8349011252209961, 1.8488034812197072, 1.8622998301896756, 1.8754159142075613, 1.8881750225898042, 1.900598298657973, 1.9127049995800742, 1.9245127176937982, 1.936037570004963, 1.9472943612303364, 1.9582967247219538, 1.9690572447992734, 1.9795875633739772, 1.9898984732410643, 2.0, 2.0099014742389776, 2.019611595346971, 2.0291384880993126, 2.0384897529829136, 2.0476725110792198, 2.0566934442004277, 2.0655588308724924, 2.0742745786732963, 2.0828462533628884, 2.091279105182547, 2.0995780926485708, 2.107747904123567, 2.1157929774113073, 2.1237175175898693, 2.1315255132709487, 2.139220751450138, 2.1468068310931137, 2.154287175585486, 2.161665044159195, 2.1689435423953976, 2.176125631892553, 2.1832141391785775, 2.1902117639373393, 2.1971210866122357, 2.2039445754429607, 2.2106845929857393, 2.217343402162158, 2.223923171877158, 2.230425982242733, 2.2368538294402898, 2.2432086302514445, 2.24949222628419, 2.255706387918843, 2.2618528179959196, 2.267933155266055, 2.2739489776202766, 2.27990180511731, 2.2857931028231215, 2.291624283476601, 2.29739670999407, 2.303111697824265, 2.308770517164429, 2.314374395047305, 2.319924517308003, 2.3254220304389968, 2.330868043340851, 2.33626362897568, 2.3416098259297846, 2.346907639891444, 2.3521580450493476, 2.357361985416772, 2.3625203760862172, 2.3676341044188507, 2.372704031172831, 2.377730991574249, 2.3827157963341836, 2.387659232615111, 2.3925620649496873, 2.3974250361147083, 2.4022488679628626, 2.4070342622147205], [0.0, 0.9587315155141827, 1.101293314754956, 1.1943215116604917, 1.2650538190282499, 1.3227903093325808, 1.371915155781979, 1.4148702397707018, 1.4531652409004676, 1.4878032589238495, 1.5194870523363546, 1.5487293929889352, 1.5759166826422604, 1.601347824952424, 1.6252591169588655, 1.6478408149591766, 1.6692485217612372, 1.6896112325290695, 1.7090371560850537, 1.7276180145837503, 1.7454322774580644, 1.7625476332235885, 1.7790229060619465, 1.794909561171911, 1.8102529009635488, 1.8250930256796174, 1.8394656123009292, 1.853402551702236, 1.8669324740945827, 1.8800811855904378, 1.89287203344058, 1.9053262135625553, 1.9174630310283654, 1.9293001219382762, 1.9408536433906547, 1.9521384369303783, 1.963168169823712, 1.9739554576947789, 1.9845119714155979, 1.9948485306292483, 2.0049751858748066, 2.0149012909511708, 2.024635566887854, 2.034186158671322, 2.043560685695403, 2.052766286755895, 2.0618096602866243, 2.0706971004319614, 2.0794345294654395, 2.0880275269924504, 2.096481356314738, 2.10480098828337, 2.1129911229236913, 2.121056209078923, 2.1290004622876655, 2.1368278810836565, 2.144542261882992, 2.1521472126041097, 2.159646165148611, 2.1670423868560773, 2.174338991033087, 2.181538946645351, 2.188645087252037, 2.1956601192527274, 2.202586629509912, 2.209427092403261, 2.2161838763660766, 2.2228592499491744, 2.2294553874528473, 2.2359743741635603, 2.242418211228409, 2.2487888201971797, 2.255088047259038, 2.261317667198285, 2.267479387091412, 2.2735748497655974, 2.27960563703702, 2.2855732727456926, 2.2914792256020697, 2.2973249118593593, 2.303111697824265, 2.3088409022178236, 2.3145137983970123, 2.3201316164469317, 2.3256955451525667, 2.331206733858399, 2.336666294223485, 2.3420753018790323, 2.347434797994922, 2.352745790761176, 2.3580092567898685, 2.363226142442598, 2.368397365088241, 2.373523814295358, 2.378606352963325, 2.383645818395934, 2.3886430233209834, 2.39359875685909, 2.3985137854447554, 2.4033888537025008, 2.4082246852806923, 2.4130219836454936], [0.0, 0.9610871496100634, 1.103999227765869, 1.1972559979361437, 1.2681620968526508, 1.3260404475662166, 1.3752859953395817, 1.4183466213479397, 1.4567357145242306, 1.491458839269306, 1.5232204807788452, 1.552534670800691, 1.5797887604970375, 1.6052823879398515, 1.6292524307579805, 1.6518896127148441, 1.6733499189394143, 1.6937626615409695, 1.7132363152144392, 1.7318628274786603, 1.7497208605684524, 1.766878269312263, 1.7833940224246172, 1.799319711555933, 1.8147007504257517, 1.8295773378044142, 1.8439852383322193, 1.8579564212408215, 1.8715195870866133, 1.8847006053885085, 1.897522880762231, 1.9100076612043762, 1.9221742992201267, 1.934040474242213, 1.9456223830675112, 1.9569349037070505, 1.9679917370080078, 1.9788055295914992, 1.989387981005251, 1.9997499374765526, 2.0099014742389776, 2.0198519680740077, 2.029610161439005, 2.0391842193329293, 2.0485817798707036, 2.0578099993883763, 2.0668755927780396, 2.0757848696489805, 2.0845437668259463, 2.0931578776235997, 2.101632478275785, 2.109972551847111, 2.118182809911036, 2.126267712241731, 2.1342314847355097, 2.142078135750636, 2.1498114710311227, 2.157435107360178, 2.1649524850716957, 2.1723668795332154, 2.17968141170081, 2.186899057835034, 2.1940226584572016, 2.201054926616605, 2.207998455531738, 2.2148557256619017, 2.2216291112597153, 2.228320886449896, 2.2349332308750616, 2.2414682349452937, 2.24792790472457, 2.2543141664839874, 2.2606288709488562, 2.2668737972641804, 2.273050656700792, 2.2791610961223494, 2.285206701231605, 2.2911889996126935, 2.2971094635847393, 2.30296951288073, 2.308770517164429, 2.3145137983970123, 2.3202006330641365, 2.32583225427326, 2.3314098537302517, 2.336934583603568, 2.3424075582836488, 2.3478298560445614, 2.3532025206143747, 2.3585265626602663, 2.3638029611938776, 2.369032664902047, 2.374216593407656, 2.3793556384649643, 2.3844506650935187, 2.3895025126543943, 2.3945119958722874, 2.3994799058067087, 2.4044070107753144, 2.409294057232193, 2.4141417706037362, 2.418950856084548], [0.0, 0.9634199128627018, 1.1066788690767724, 1.2001619932947534, 1.2712401964184674, 1.3292590302190486, 1.3786241074276457, 1.4217892507485372, 1.4602715224320013, 1.4950789275979053, 1.5269176613775752, 1.5563030031834104, 1.5836232443613925, 1.6091787502689212, 1.6332069734873116, 1.6558991007071868, 1.677411495666656, 1.6978737843430347, 1.7173947047224452, 1.73606642749994, 1.7539678058403405, 1.7711668592702177, 1.7877226996337288, 1.8036870438052182, 1.8191054157329989, 1.834018111758391, 1.8484609833300942, 1.8624660772758987, 1.8760621638145611, 1.8892751752558297, 1.9021285730234152, 1.9146436566873282, 1.9268398257254036, 1.9387348024821214, 1.9503448230674343, 1.9616848016044737, 1.9727684721952912, 1.9836085121570466, 1.9942166494347606, 2.0046037565818273, 2.0147799332865577, 2.0247545790898807, 2.034536457668964, 2.0441337538409603, 2.053554124260123, 2.062804742632454, 2.0718923401485188, 2.08082324173237, 2.0896033986186935, 2.0982384176983184, 2.106733588011632, 2.115093904718203, 2.1233240908274813, 2.1314286169384604, 2.1394117192046056, 2.1472774157133188, 2.1550295214459645, 2.162671661964455, 2.1702072859531065, 2.177639676729474, 2.1849719628248545, 2.192207127723823, 2.199348018842242, 2.2063973558145533, 2.2133577381535448, 2.2202316523391197, 2.2270214783867144, 2.233729495940831, 2.240357889934545, 2.246908755851809, 2.253384104625744, 2.259785867202918, 2.266115898800745, 2.2723759828825942, 2.278567834872916, 2.284693105632657, 2.2907533847134087, 2.296750203407078, 2.3026850376064214, 2.3085593104904207, 2.314374395047305, 2.3201316164469317, 2.32583225427326, 2.3314775446267637, 2.337068682105834, 2.3426068216754867, 2.348093080431025, 2.353528539263716, 2.3589142444349798, 2.3642512090650984, 2.3695404145419823, 2.374782811855136, 2.3799793228595614, 2.385130841473995, 2.3902382348175717, 2.395302344288673, 2.4003239865895067, 2.4053039546996535, 2.4102430188016397, 2.4151419271613577, 2.4200014069659628, 2.4248221651217166], [0.0, 0.9657302989075099, 1.1093328057258516, 1.2030401126732269, 1.2742887690815312, 1.3324467383744965, 1.3819301984231833, 1.4251988564663878, 1.4637734128351514, 1.4986642899555767, 1.5305793764919489, 1.560035187552907, 1.587420945649437, 1.6130377364478306, 1.637123581966595, 1.6598701273828929, 1.6814341114121345, 1.7019454708888688, 1.7215132045647705, 1.7402297041702735, 1.7581740119686893, 1.775414310604834, 1.7920098536795153, 1.8080124820897834, 1.8234678289553456, 1.8384162872525442, 1.8528937944057637, 1.8669324740945827, 1.8805611655318815, 1.893805863215915, 1.9066900848334483, 1.9192351810331834, 1.9314605978150199, 1.9433841000235528, 1.9550219627046976, 1.9663891357472798, 1.977499386189226, 1.9883654217492852, 1.9989989984973702, 2.009411015060443, 2.0196115953469707, 2.0296101614390047, 2.039415498029968, 2.0490358095650962, 2.058478771060137, 2.06775157342442, 2.07686096399064, 2.0858132828507085, 2.0946144955110206, 2.1032702223083413, 2.111785764966754, 2.1201661306247646, 2.1284160536181154, 2.1365400152667835, 2.1445422618829917, 2.1524268211899553, 2.160197517317779, 2.1678579845228687, 2.1754116797598617, 2.182861894220066, 2.190211763937339, 2.1974642795509762, 2.2046222953052546, 2.211688537356596, 2.218665611451703, 2.2255560100333294, 2.2323621188244482, 2.2390862229363977, 2.245730512541961, 2.2522970881502893, 2.258787965516942, 2.265205080219106, 2.2715502919232105, 2.277825388369563, 2.28403208909639, 2.2901720489235826, 2.2962468612146494, 2.302258060933704, 2.308207127512853, 2.314095487544018, 2.319924517308003, 2.3256955451525667, 2.3314098537302517, 2.337068682105834, 2.342673227742483, 2.3482246483749467, 2.353724063777444, 2.3591725574333378, 2.3645711781130974, 2.3699209413665763, 2.375222830935162, 2.3804778000889346, 2.385686772893605, 2.390850645411625, 2.3959702868415746, 2.4010465405996015, 2.4060802253464537, 2.4110721359633636, 2.41602304447984, 2.420933700956197, 2.4258048343234657, 2.4306371531831448], [0.0, 0.9680187850024814, 1.111961585938579, 1.2058909506066127, 1.2773084445875398, 1.3356042305195701, 1.3852049512676268, 1.428576142826029, 1.4672421091215284, 1.5022156669730249, 1.534206382524911, 1.5637319948690074, 1.591182648854871, 1.6168601436299403, 1.6410030652522687, 1.663803513039604, 1.68541859713028, 1.7059785622694903, 1.7255926655026876, 1.7443535175005118, 1.7623403478323172, 1.7796215007149805, 1.7962563701622607, 1.8122969199183139, 1.827788891239415, 1.842772772820933, 1.857284587247982, 1.8713565343234575, 1.8850175216003735, 1.8982936051760129, 1.9112083584668813, 1.923783182716203, 1.9360375700049628, 1.947989327275016, 1.9596547681391703, 1.9710488779129252, 1.982185456257886, 1.9930772410062174, 2.0037360160861297, 2.014172705951006, 2.024397458499885, 2.034419718142279, 2.044248290388653, 2.053891399126274, 2.0633567375583346, 2.072651513634425, 2.08178249067636, 2.0907560238001337, 2.0995780926485708, 2.1082543308769193, 2.1167900527727306, 2.125190277339901, 2.1334597501331043, 2.1416029630916773, 2.149624172590308, 2.157527415896686, 2.165316526202937, 2.1729951463775454, 2.180566741567077, 2.1880346107619584, 2.19540189742749, 2.20267159928987, 2.2098465773570632, 2.21692956424565, 2.223923171877158, 2.230829898600669, 2.2376521357925916, 2.2443921739792807, 2.2510522085235607, 2.257634344912149, 2.264140603677329, 2.270572924983016, 2.2769331729024813, 2.2832231394124305, 2.2894445481258714, 2.295599057784113, 2.30168826552645, 2.307713709954391, 2.313676874005847, 2.3195791876533254, 2.3254220304389968, 2.331206733858399, 2.336934583603568, 2.3426068216754867, 2.3482246483749467, 2.3537892241801734, 2.3593016715189097, 2.3647630764420424, 2.3701744902053075, 2.3755369307651018, 2.3808513841939787, 2.3861188060209786, 2.3913401225015654, 2.3965162318215865, 2.4016480052393554, 2.4067362881696606, 2.4117819012132253, 2.4167856411349082, 2.421748281793692, 2.426670575027305, 2.4315532514941225, 2.436397021474813], [0.0, 0.9702858327569769, 1.1145657399648676, 1.2087150821359736, 1.2802998320336965, 1.3387321435503965, 1.388449026509699, 1.4319217910581665, 1.4706783109600874, 1.5057337749966935, 1.5377994110779951, 1.5673941708128258, 1.5949091127489259, 1.6206467428310498, 1.6448462058729238, 1.6677000510785311, 1.6893657565296705, 1.7099738719977002, 1.7296339104021774, 1.7484386993029348, 1.7664676538207023, 1.7837892782308242, 1.8004631056446347, 1.8165412215025742, 1.8320694741844714, 1.8470884472080353, 1.8616342475213297, 1.875739150337451, 1.8894321309093423, 1.9027393063562603, 1.9156843053023802, 1.9282885791114823, 1.9405716655139538, 1.9525514131545463, 1.9642441738516687, 1.9756649680156204, 1.9868276276260703, 1.9977449203464976, 2.008428657702437, 2.0188897897317517, 2.0291384880993126, 2.039184219332929, 2.0490358095650962, 2.058701501942982, 2.068189007686845, 2.077505551626905, 2.0866579129243115, 2.0956524615783962, 2.1044951912359853, 2.1131917487460443, 2.121747460841898, 2.1301673582816796, 2.1384561977338947, 2.1466184816577614, 2.154658476396166, 2.1625802286718616, 2.170387580654104, 2.178084183742778, 2.185673511199636, 2.1931588697411613, 2.2005434101944816, 2.2078301373063076, 2.21502191878493, 2.2221214936465703, 2.2291314799297353, 2.236054381834505, 2.242892596337763, 2.2496484193301534, 2.256324051315922, 2.262921602712721, 2.269443098784813, 2.2758904842398726, 2.2822656275167286, 2.2885703247888007, 2.294806303705705, 2.3009752268934327, 2.3070786952316924, 2.3131182509253154, 2.3190953803851726, 2.32501151693269, 2.330868043340851, 2.336666294223485, 2.3424075582836488, 2.348093080431025, 2.353724063777444, 2.3593016715189097, 2.3648270287118285, 2.370301223950562, 2.375725310952829, 2.381100310059025, 2.3864272096510337, 2.3917069674956912, 2.396940512017703, 2.402128743506418, 2.4072725352605913, 2.4123727346749253, 2.417430164271947, 2.4224456226824955, 2.427419885577889, 2.432353706556619, 2.437247817988224, 2.4421029318168106], [0.0, 0.9725318888200211, 1.1171457808697174, 1.2115130636658187, 1.2832635207769225, 1.3418310937218834, 1.3916630632903442, 1.435236460315444, 1.4740826953441546, 1.5092193071568942, 1.5413591700421998, 1.5710224368986359, 1.598601071511753, 1.6243982800790435, 1.6486537609961176, 1.671560509187479, 1.693276367271426, 1.7139321872210962, 1.7336377354608894, 1.7524860544315488, 1.7705567430870701, 1.787918464279207, 1.8046308889288964, 1.8207462230460187, 1.8363104211420478, 1.8513641606790259, 1.8659436321868101, 1.880081185590438, 1.8938058632159154, 1.9071438426394407, 1.9201188071816635, 1.9327522578628313, 1.9450637776400421, 1.9570712564747976, 1.9687910840373435, 1.9802383155078196, 1.9914268148847085, 2.002369379386583, 2.0130778478807647, 2.0235631957526974, 2.033835618213025, 2.043904603703051, 2.0537789987863504, 2.0634670656916545, 2.0729765334894608, 2.082314643734311, 2.091488191280026, 2.100503560871464, 2.109366760029783, 2.1180834486754967, 2.1266589658724633, 2.135098354024215, 2.1434063808101818, 2.1515875591120515, 2.1596461651486116, 2.1675862550101277, 2.175411679759862, 2.1831260992501043, 2.1907329947826497, 2.1982356807285015, 2.205637315208446, 2.2129409099247, 2.22014933922384, 2.2272653484624696, 2.2342915617394348, 2.2412304890516386, 2.2480845329245804, 2.2548559945635227, 2.261547079566526, 2.268159903236521, 2.2746964955259323, 2.28115880564412, 2.2875487063550497, 2.2938679979899947, 2.300118412197802, 2.3063016154531764, 2.312419212341606, 2.318472748637878, 2.324463714193666, 2.3303935456483065, 2.33626362897568, 2.3420753018790323, 2.3478298560445614, 2.353528539263716, 2.3591725574333378, 2.3647630764420424, 2.370301223950562, 2.375788091073179, 2.381224733966799, 2.386612175333744, 2.39195140584384, 2.3972433854810027, 2.4024890448190903, 2.4076892862314776, 2.412844985038466, 2.417956990596341, 2.4230261273316374, 2.428053195723896, 2.4330389732399897, 2.437984215222871, 2.4428896557373947, 2.4477560083757046], [0.0, 0.974757385530792, 1.1197022052804315, 1.2142854337744386, 1.2862000812921839, 1.3449016775452185, 1.3948476802735588, 1.4385207886324167, 1.4774559175773845, 1.5126729343772676, 1.5448863446289454, 1.5746174915246671, 1.6022592358016672, 1.628115477500389, 1.6524264635310943, 1.6753856304588906, 1.6971511821017766, 1.7178542698684562, 1.737604911367705, 1.756496361954258, 1.774608402732652, 1.7920098536795153, 1.808760522263943, 1.8249127339616187, 1.8405125484441816, 1.8556007362580844, 1.8702135707499088, 1.8843834758727553, 1.8981395604117364, 1.9115080618465978, 1.9245127176937982, 1.9371750781755182, 1.949514771061584, 1.9615497272520528, 1.9732963739225282, 1.9847698007047239, 1.9959839033228515, 2.006951508280043, 2.0176844815351327, 2.0281938235891266, 2.038489752982913, 2.048581779870703, 2.0584787710601367, 2.0681890076868448, 2.0777202365081697, 2.0870797156498897, 2.096274255514853, 2.1053102554584706, 2.114193736749232, 2.12293037225955, 2.1315255132709487, 2.1399842137257603, 2.1483112522135515, 2.1565111519430786, 2.164588198918629, 2.1725464585122367, 2.1803897905997567, 2.1881218634085156, 2.195746166206758, 2.203266020949938, 2.2106845929857393, 2.218004900908218, 2.225229825641471, 2.2323621188244487, 2.239404410560863, 2.246359216591376, 2.2532289449393157, 2.260015902075915, 2.2667222986464224, 2.27335025479433, 2.2799018051173094, 2.2863789032852027, 2.292783426347521, 2.2991171787553304, 2.305381896120104, 2.311579248730029, 2.317710844842453, 2.323778233769441, 2.3297829087719757, 2.3357263097769305, 2.3416098259297846, 2.347434797994922, 2.3532025206143747, 2.3589142444349798, 2.3645711781130974, 2.3701744902053075, 2.375725310952829, 2.381224733966799, 2.3866738178209848, 2.392073587558011, 2.3974250361147083, 2.402729125671773, 2.407986788932546, 2.413198930335352, 2.4183664272035332, 2.423490130837004, 2.4285708675488773, 2.433609439650475, 2.4386066263877884, 2.4435631848322616, 2.4484798507285492, 2.4533573393017467], [0.0, 0.976962741533791, 1.1222354940932593, 1.2170327139802413, 1.2891100659842116, 1.3479444726366379, 1.3980034765266802, 1.441775393833404, 1.4807986122061831, 1.5160953063294291, 1.5483815983450517, 1.5781800109668465, 1.6058842937663336, 1.6317990343476407, 1.6561650231716334, 1.6791761344471818, 1.7009909299231352, 1.7217408577338755, 1.741536184399341, 1.7604703762613898, 1.7786233949266408, 1.7960642160746187, 1.8128527824868192, 1.829041538023565, 1.8446766465649627, 1.8597989708994642, 1.8744448664408848, 1.8886468305004354, 1.9024340377208817, 1.9158327849433907, 1.9288668633897579, 1.941557872038822, 1.953925483067582, 1.965987667944157, 1.9777608910100868, 1.9892602760368723, 2.0004997501873363, 2.0114921689841454, 2.0222494252324696, 2.0327825443215803, 2.043101767911474, 2.053216627672766, 2.0631360104739542, 2.0728682161864604, 2.082421009094407, 2.0918016637448402, 2.1010170059489157, 2.110073449540373, 2.11897702941062, 2.127733431266753, 2.136348018497393, 2.1448258564792475, 2.1531717346132817, 2.1613901863418614, 2.1694855073662143, 2.1774617722561436, 2.1853228496203445, 2.1930724159853843, 2.2007139685138615, 2.208250836677043, 2.2156861929841054, 2.223023062858574, 2.230264333742539, 2.237412763500443, 2.2444709881865186, 2.2514415292332077, 2.2583268001119103, 2.2651291125121733, 2.271850682080757, 2.2784936337579063, 2.285060006744503, 2.291551759130501, 2.2979707722121727, 2.304318854523096, 2.3105977456015063, 2.3168091195145615, 2.322954588158238, 2.329035704349868, 2.3350539647288864, 2.341010812479954, 2.346907639891444, 2.352745790761176, 2.3585265626602663, 2.3642512090650984, 2.3699209413665763, 2.3755369307651018, 2.381100310059025, 2.386612175333744, 2.392073587558011, 2.397485574093577, 2.402849130123759, 2.408165220006155, 2.4134347785543153, 2.4186587122528262, 2.423837900409946, 2.4289731962516248, 2.4340654279604825, 2.4391153996630432, 2.4441238923683164, 2.4490916648605947, 2.454019454549131, 2.4589079782771925], [0.0, 0.9791483623609769, 1.1247461131420948, 1.2197554094669347, 1.2919940099556333, 1.3509600385206135, 1.401131032353403, 1.445000874391587, 1.484111393902059, 1.5194870523363548, 1.5518455739153598, 1.5817106503191745, 1.6094769119996515, 1.6354496279717667, 1.659870127382893, 1.6829327181692992, 1.7047963168076519, 1.7255926655026879, 1.7454322774580644, 1.7644088281146915, 1.7826024579660036, 1.8000822970010757, 1.8169084221029261, 1.8331333944571238, 1.848803481219707, 1.863959636595676, 1.878638297331681, 1.89287203344058, 1.9066900848334485, 1.9201188071816635, 1.9331820449317632, 1.945901445382932, 1.9582967247219538, 1.9703858946219763, 1.9821854562578862, 1.9937105672354636, 2.004975185874807, 2.0159921964584284, 2.026773518397593, 2.0373302017471175, 2.0476725110792193, 2.0578099993883763, 2.0677515734244203, 2.0775055516269054, 2.08707971564989, 2.096481356314738, 2.105717314703029, 2.1147940189972663, 2.1237175175898693, 2.1324935089077646, 2.1411273683383243, 2.1496241725903085, 2.157988721779333, 2.166225559489795, 2.174338991033087, 2.1823331000944726, 2.1902117639373393, 2.1979786673132287, 2.205637315208446, 2.2131910445428153, 2.2206430349229205, 2.2279963185406384, 2.235253789297727, 2.2424182112284092, 2.2494922262841897, 2.2564783615383557, 2.2633790358616253, 2.2701965661151626, 2.2769331729024813, 2.2835909859176553, 2.290172048923583, 2.2966783243907756, 2.3031116978242654, 2.3094739818036065, 2.315766919758657, 2.3219921895017297, 2.3281514065348676, 2.3342461271493034, 2.340277851332691, 2.346248025498324, 2.3521580450493476, 2.3580092567898685, 2.3638029611938776, 2.3695404145419823, 2.375222830935162, 2.3808513841939787, 2.3864272096510337, 2.39195140584384, 2.3974250361147083, 2.402849130123759, 2.4082246852806923, 2.4135526681005284, 2.418834015488143, 2.424069635956073, 2.4292604107797287, 2.4344071950938626, 2.4395108189338695, 2.4445720882252333, 2.449591785724204, 2.454570671912596, 2.4595094858493636, 2.464408945981466], [0.0, 0.9813146409829907, 1.1272345138316675, 1.222454009770205, 1.2948524317343189, 1.3539489173903954, 1.404230910082564, 1.448197810242491, 1.4873948582971226, 1.5228487822277943, 1.5552788941563636, 1.585210044384172, 1.6130377364478306, 1.639067914742847, 1.6635424423358576, 1.6866560570521496, 1.708568026956953, 1.7294103857229093, 1.7492938910543054, 1.7683124256406282, 1.7865463072790226, 1.8040648189025128, 1.820928170308875, 1.837189038970624, 1.8528937944057637, 1.8680834814268286, 1.8827946173935286, 1.8970598443769766, 1.9109084669789498, 1.9243668991804026, 1.9374590381815897, 1.9502065791744183, 1.9626292819659814, 1.9747451980786506, 1.9865708651946936, 1.9981214744547446, 2.009411015060443, 2.0204523997996304, 2.0312575744542065, 2.0418376135262535, 2.0522028042974405, 2.062362720897395, 2.0723262897813406, 2.082101847792639, 2.091697193801566, 2.1011196347597783, 2.1103760268841394, 2.1194728125789357, 2.1284160536181154, 2.1372114610358683, 2.1458644221121324, 2.154380024787434, 2.1627630797972186, 2.1710181407781577, 2.1791495225667643, 2.187161317883091, 2.1950574125686257, 2.2028414995270946, 2.210517091499274, 2.2180875327876257, 2.2255560100333294, 2.2329255621367183, 2.2401990894020494, 2.2473793619787257, 2.254469027663335, 2.2614706191200877, 2.2683865605712397, 2.275219174003804, 2.281970684934181, 2.2886432277682047, 2.2952388507904153, 2.301759520813117, 2.3082071275128535, 2.3145834874793496, 2.320890347999647, 2.32712939059807, 2.3333022343508145, 2.3394104389922696, 2.345455507828679, 2.3514388904733963, 2.357361985416772, 2.363226142442598, 2.369032664902047, 2.374782811855136, 2.3804778000889346, 2.3861188060209786, 2.3917069674956912, 2.3972433854810027, 2.402729125671773, 2.408165220006155, 2.4135526681005284, 2.4188924386082413, 2.4241854705069894, 2.429432674319312, 2.4346349332703627, 2.439793104386804, 2.44490801954041, 2.449980486439703, 2.4550112895727114, 2.4600011911037485, 2.4649509317268694, 2.469861231478535], [0.0, 0.9834619583314299, 1.129701133737476, 1.2251289894283288, 1.2976858339625241, 1.356911634828607, 1.4073036548155013, 1.4513667635547438, 1.4906495827757071, 1.5261810871507613, 1.5586821628039584, 1.588678808516557, 1.6165673932678817, 1.6426545309224159, 1.6671826137927048, 1.6903468058302684, 1.7123067236114715, 1.733194689725664, 1.7531217042376661, 1.772181855271511, 1.790455636376128, 1.8080124820897834, 1.8249127339616187, 1.8412091847332432, 1.8569483053886604, 1.8721712305548577, 1.8869145574990052, 1.9012109997197497, 1.9150899259433374, 1.9285778079499212, 1.941698595231722, 1.9544740304541695, 1.9669239166628598, 1.9790663448805912, 1.9909178889774666, 2.0024937733354458, 2.0138080177674054, 2.0248735633170107, 2.0357023819059785, 2.046305572269668, 2.056693444200427, 2.0668755927780396, 2.0768609639906406, 2.086657912924312, 2.0962742555148535, 2.105717314703029, 2.114993961708508, 2.124110653032877, 2.133073463714486, 2.141888117284437, 2.1505600128111397, 2.1590942493685765, 2.1674956482190657, 2.1757687729635693, 2.183917947880345, 2.1919472746451554, 2.1998606476025055, 2.2076617677369503, 2.2153541554758625, 2.222941162439722, 2.230425982242733, 2.237811660434963, 2.2451011036671296, 2.2522970881502897, 2.259402267474952, 2.2664191798473157, 2.27335025479433, 2.280197819383991, 2.2869641040025854, 2.2936512477264634, 2.300261303322232, 2.306796241905983, 2.3132579572892586, 2.319648270036855, 2.325968931259235, 2.3322216261602424, 2.3384079773589437, 2.3445295480027455, 2.3505878446874338, 2.3565843201984134, 2.3625203760862172, 2.368397365088241, 2.374216593407656, 2.3799793228595614, 2.385686772893605, 2.3913401225015654, 2.396940512017703, 2.4024890448190903, 2.407986788932546, 2.4134347785543153, 2.418834015488143, 2.4241854705069894, 2.4294900846432257, 2.4347487704118, 2.439962412970544, 2.4451318712214696, 2.4502579788566576, 2.455341545352061, 2.4603833569123292, 2.4653841773695464, 2.470344749038559, 2.4752657935314137], [0.0, 0.9855906837939876, 1.1321463971745565, 1.2277808085989845, 1.3004947040502328, 1.3598487004904058, 1.410349795134583, 1.4545082794607895, 1.4938761272248584, 1.5294845403379125, 1.562055965298185, 1.5921175394230915, 1.620066489641501, 1.6462100934904822, 1.6707912679461765, 1.6940055993968532, 1.7160130499125363, 1.7369462284977875, 1.7569163754795565, 1.7760177826377306, 1.7943311177513308, 1.8119259656512388, 1.8288627984972323, 1.8451945233019935, 1.860967711637013, 1.8762235871661006, 1.8909988263720319, 1.9053262135625555, 1.9192351810331836, 1.9327522578628311, 1.945901445382932, 1.9587045333214026, 1.9711813675879752, 1.9833500783638733, 1.9952272753937126, 2.0068282160129693, 2.0181669503807194, 2.0292564475518073, 2.040108705361443, 2.050734846568447, 2.0611452032809443, 2.071349391347484, 2.0813563761199925, 2.0911745307693232, 2.100811688149045, 2.1102751870505903, 2.119571913566538, 2.1287083381737166, 2.1376905490600335, 2.1465242821453017, 2.155214948184336, 2.163767657288178, 2.172187241154877, 2.180478273263412, 2.188645087252037, 2.1966917936746846, 2.204622295305255, 2.212440301139168, 2.2201493392238394, 2.2277527684344083, 2.2352537892977264, 2.242655453956025, 2.2499606753515304, 2.2571722357044717, 2.264292794349113, 2.271324894985658, 2.2782709723998216, 2.285133358696591, 2.291914289089974, 2.2986159072863988, 2.3052402704957324, 2.311789354100591, 2.3182650560117155, 2.324669200734554, 2.3310035431698886, 2.337269772169223, 2.34346951386382, 2.349604334784555, 2.355675744788272, 2.3616851998049637, 2.3676341044188507, 2.373523814295358, 2.3793556384649643, 2.385130841473995, 2.390850645411625, 2.3965162318215865, 2.402128743506418, 2.4076892862314776, 2.413198930335352, 2.4186587122528262, 2.424069635956073, 2.429432674319312, 2.4347487704118, 2.440018838723644, 2.4452437663286206, 2.4504244139878537, 2.455561617197969, 2.4606561871870483, 2.4657089118615, 2.470720556706738, 2.4756918656443667, 2.480623561848379], [0.0, 0.9877011756841472, 1.1345707157370173, 1.2304099136443638, 1.3032795147949203, 1.3627606087515323, 1.4133698437753246, 1.45762288675005, 1.4970750347462591, 1.5327596978364408, 1.5654008695276431, 1.5955268159213214, 1.6235356145471318, 1.6497352009300494, 1.6743690122158117, 1.6976330536110606, 1.7196876297201569, 1.7406656335095885, 1.7606785435104721, 1.7798208534141378, 1.798173403737332, 1.8158059283162225, 1.832779028802479, 1.8491457255010695, 1.8649526897093904, 1.8802412333654308, 1.8950481114890507, 1.909406178590586, 1.9233449299903136, 1.9368909515751183, 1.950068296071619, 1.9628987998671055, 1.9754023513682943, 1.9875971195794222, 1.9994997498123361, 2.0111255320737653, 2.022488546609055, 2.033601790244299, 2.0444772865062393, 2.055126181971385, 2.0655588308724924, 2.0757848696489805, 2.085813282850709, 2.0956524615783967, 2.1053102554584715, 2.1147940189972667, 2.124110653032877, 2.1332666418976687, 2.1422680868164727, 2.1511207359916993, 2.1598300117644667, 2.1684010351883396, 2.1768386483077107, 2.1851474343949646, 2.193331736368181, 2.201395673583415, 2.209343157171761, 2.2171779040708857, 2.2249034498829805, 2.232523160675701, 2.2400402438293394, 2.2474577580218225, 2.2547786224329984, 2.262005625240795, 2.2691414314740346, 2.2761885902798666, 2.2831495416577274, 2.290026622706451, 2.2968220734264135, 2.3035380421144644, 2.310176590385671, 2.316739697852629, 2.3232292664901655, 2.329647124710629, 2.335995031172652, 2.342274678344157, 2.348487695838519, 2.3546356535410977, 2.3607200645418667, 2.36674238788847, 2.372704031172831, 2.378606352963325, 2.3844506650935187, 2.3902382348175717, 2.3959702868415746, 2.4016480052393554, 2.4072725352605913, 2.412844985038466, 2.4183664272035332, 2.423837900409946, 2.4292604107797287, 2.4346349332703627, 2.439962412970544, 2.4452437663286206, 2.450479882317901, 2.455671623542699, 2.4608198272887276, 2.4659253065211906, 2.470988850833676, 2.4760112273507695, 2.4809931815870696, 2.485935438265135], [0.0, 0.9897937816869886, 1.136974488810138, 1.2330167376865286, 1.3060407249698005, 1.3656478393234044, 1.416364298264326, 1.460711098526835, 1.500246832331945, 1.536007099199899, 1.5687174265360497, 1.5989071996597315, 1.626975339492761, 1.6532304339717372, 1.6779164360036871, 1.7012297660642455, 1.7233310683892178, 1.744353517500512, 1.7644088281146917, 1.7835916941233805, 1.8019831273171425, 1.8196530092746486, 1.8366620700420495, 1.8530634422564756, 1.868903896096077, 1.8842248310249203, 1.8990630799343686, 1.9134515669423955, 1.9274198498599235, 1.9409945709003742, 1.9541998337499895, 1.9670575210600076, 1.9795875633739772, 1.9918081681901332, 2.0037360160861297, 2.0153864294630695, 2.0267735183975923, 2.037910307251689, 2.0488088450259023, 2.059480301912582, 2.069935054081614, 2.080182758388787, 2.0902324184191934, 2.100092443051468, 2.109770698542752, 2.1192745549810996, 2.1286109278251564, 2.1377863151454037, 2.1468068310931137, 2.155678236049199, 2.164405963842892, 2.1729951463775454, 2.1814506359562125, 2.189777025561687, 2.1979786673132287, 2.206059689294421, 2.2140240109227265, 2.2218753570107515, 2.2296172706514357, 2.2372531250439995, 2.2447861343640922, 2.252219363769949, 2.2595557386261764, 2.266798053017912, 2.273948977620276, 2.2810110669812023, 2.2879867662696634, 2.2948784175360184, 2.30168826552645, 2.308418463089324, 2.315071076207576, 2.3216480886879336, 2.3281514065348676, 2.3345828620345164, 2.3409442175715176, 2.347237169199563, 2.353463349984629, 2.359624333138134, 2.3657216349557793, 2.3717567175764387, 2.377730991574249, 2.383645818395934, 2.3895025126543943, 2.395302344288673, 2.4010465405996015, 2.4067362881696606, 2.4123727346749253, 2.417956990596341, 2.423490130837004, 2.4289731962516248, 2.4344071950938626, 2.439793104386804, 2.4451318712214696, 2.4504244139878537, 2.455671623542699, 2.4608743643178865, 2.4660334753730573, 2.4711497713958126, 2.4762240436526244, 2.481257060893357, 2.4862495702121024, 2.4912022978668626], [0.0, 0.9918688392825663, 1.1393581040567025, 1.235601701134824, 1.3087787798824746, 1.3685108578372633, 1.4193336415251103, 1.4637734128351516, 1.5033920315060252, 1.5392272681452157, 1.5720061711932456, 1.6022592358016672, 1.6303862192118457, 1.6566963563009383, 1.6814341114121343, 1.7047963168076516, 1.726943953506622, 1.7480104752252745, 1.7681078308849896, 1.7873309128988228, 1.8057609028948687, 1.8234678289553456, 1.8405125484441816, 1.8569483053886604, 1.8728219680184823, 1.8881750225898042, 1.9030443792124694, 1.9174630310283656, 1.93146059781502, 1.945063777640042, 1.9582967247219538, 1.9711813675879752, 1.9837376785651326, 1.9959839033228517, 2.0079367574088582, 2.0196115953469707, 2.031022556794963, 2.042182693419807, 2.053104079482227, 2.0637979085923717, 2.0742745786732963, 2.084543766825946, 2.0946144955110206, 2.1044951912359857, 2.1141937367492325, 2.1237175175898693, 2.133073463714486, 2.1422680868164723, 2.1513075138651403, 2.160197517317779, 2.1689435423953976, 2.177550731760148, 2.1860239478877177, 2.194367793389879, 2.2025866295099124, 2.2106845929857393, 2.2186656114517036, 2.226533417529311, 2.2342915617394348, 2.2419434243530536, 2.2494922262841897, 2.256941039117043, 2.2642927943491133, 2.2715502919232105, 2.278716208113405, 2.285793102823122, 2.2927834263475204, 2.299689525646962, 2.306513650173636, 2.313257957289258, 2.319924517308003, 2.326515318195558, 2.3330322699522466, 2.3394772087055102, 2.345851900534747, 2.352158045049347, 2.3583972787389356, 2.3645711781130974, 2.3706812626463782, 2.37672899754296, 2.3827157963341836, 2.3886430233209834, 2.3945119958722874, 2.4003239865895067, 2.4060802253464537, 2.4117819012132253, 2.417430164271947, 2.4230261273316374, 2.4285708675488773, 2.4340654279604825, 2.4395108189338695, 2.44490801954041, 2.4502579788566576, 2.455561617197969, 2.4608198272887276, 2.4660334753730573, 2.471203402269648, 2.4763304243740576, 2.481415334611612, 2.486458903343824, 2.491461879231035, 2.496424990053814], [0.0, 0.9939266761482028, 1.1417219378791112, 1.2381652121870288, 1.3114941119057621, 1.3713501163992303, 1.4222783424537948, 1.4668103132523977, 1.5065111289344464, 1.5424207131769936, 1.5752676228327884, 1.6055834536751958, 1.6337687923245836, 1.6601335152297616, 1.6849225939257149, 1.7083332690438622, 1.7305268555917248, 1.7516370841628426, 1.7717761359397661, 1.791039100209471, 1.809507327028114, 1.8272509897656406, 1.8443310720471557, 1.8608009283656803, 1.8767075241887416, 1.8920924318443078, 1.9069926380198723, 1.9214412043084128, 1.935467811939806, 1.949099214372319, 1.962359615937392, 1.9752709906575057, 1.9878533522964057, 2.0001249843779294, 2.01210263712966, 2.023801696931549, 2.0352363327770124, 2.0464196234114014, 2.0573636681459893, 2.068079683814383, 2.078578089912276, 2.088868583617761, 2.0989602061104957, 2.1088614013804765, 2.118580068530486, 2.128123608422459, 2.1374989653906122, 2.1467126646381893, 2.155770845846166, 2.1646792934479864, 2.173443463961896, 2.1820685107195628, 2.1905593062848836, 2.1989204628187013, 2.2071563506125957, 2.215271114987006, 2.223268691724966, 2.231152821192075, 2.238927061275496, 2.2465947992592783, 2.2541592627398956, 2.261623529674184, 2.2689905376416406, 2.276263092394136, 2.2834438757582225, 2.2905354529483755, 2.2975402793433974, 2.304460706772903, 2.311298989356037, 2.318057288930406, 2.324737680105479, 2.33134215497139, 2.3378726274911523, 2.344330937601634, 2.350718855046329, 2.357038082960819, 2.3632902612299636, 2.3694769696341442, 2.37559973080037, 2.3816600129726906, 2.387659232615111, 2.39359875685909, 2.3994799058067087, 2.4053039546996535, 2.4110721359633636, 2.4167856411349082, 2.4224456226824955, 2.428053195723896, 2.433609439650475, 2.4391153996630432, 2.4445720882252333, 2.449980486439703, 2.455341545352061, 2.4606561871870483, 2.4659253065211906, 2.4711497713958126, 2.4763304243740576, 2.481468083545264, 2.486563543479846, 2.49161757613759, 2.4966309317320876, 2.501604339553839], [0.0, 0.9959676105409554, 1.144066355858723, 1.240707667305806, 1.3141871409823676, 1.3741660541180074, 1.425198856466388, 1.4698222694537972, 1.5096046070047022, 1.5455879281810383, 1.5785022858581217, 1.608880367390943, 1.6371235819665952, 1.6635424423358578, 1.6883824230595854, 1.7118411697841731, 1.734080328762247, 1.755233905190469, 1.7754143106048343, 1.7947168295491724, 1.813222979124284, 1.8310030767944907, 1.8481182314090017, 1.8646219070192416, 1.8805611655318815, 1.895977664639732, 1.9109084669789496, 1.9253867020313657, 1.939442111974454, 1.9531015052021772, 1.96638913574728, 1.979327022753819, 1.9919352210819108, 2.0042320517988785, 2.0162342995273135, 2.027957382241642, 2.039415498029968, 2.050621752493609, 2.0615882697886287, 2.0723262897813406, 2.082846253362888, 2.0931578776235997, 2.1032702223083417, 2.1131917487460443, 2.12293037225955, 2.1324935089077646, 2.141888117284437, 2.151120735991699, 2.160197517317779, 2.1691242575739103, 2.17790642448278, 2.186549181957937, 2.1950574125686257, 2.203435737946325, 2.211688537356596, 2.2198199646319012, 2.227833963637031, 2.235734282418073, 2.243524486167974, 2.2512079691262508, 2.258787965516942, 2.2662675596171753, 2.273649695038491, 2.2809371832941046, 2.288132711717446, 2.295238850790416, 2.302258060933704, 2.309192698806185, 2.3160450231556244, 2.3228172002587573, 2.329511308985068, 2.3361293455152583, 2.342673227742483, 2.3491447993817474, 2.3555458338105457, 2.3618780376616875, 2.368143054187381, 2.374342466411937, 2.3804778000889346, 2.3865505264773255, 2.3925620649496873, 2.3985137854447554, 2.4044070107753144, 2.4102430188016397, 2.41602304447984, 2.421748281793692, 2.427419885577889, 2.4330389732399897, 2.4386066263877884, 2.4441238923683164, 2.449591785724204, 2.4550112895727114, 2.4603833569123292, 2.4657089118615, 2.470988850833676, 2.4762240436526244, 2.481415334611612, 2.486563543479846, 2.4916694664593155, 2.496733877094953, 2.501757527140844, 2.506741147385017], [0.0, 0.9979919516614258, 1.1463917131737604, 1.243229451671912, 1.3168582751049311, 1.3769590976068362, 1.428095626019391, 1.4728097377493, 1.5126729343772676, 1.5487293929889352, 1.5817106503191745, 1.6121504764297885, 1.6404510963869356, 1.666923654070082, 1.6918141229762351, 1.7153205504738986, 1.7376049113677052, 1.7588014832248504, 1.7790229060619467, 1.7983646580921944, 1.8169084221029264, 1.8347246584813188, 1.8518746002825843, 1.8684118202258155, 1.8843834758727553, 1.89983130958702, 1.9147924593359495, 1.9293001219382762, 1.943384100023553, 1.9570712564747974, 1.9703858946219763, 1.9833500783638733, 1.9959839033228517, 2.0083057278044842, 2.020332370546731, 2.032079280861622, 2.0435606856954025, 2.054789717287011, 2.0657785244353093, 2.076538369852055, 2.0870797156498897, 2.09741229866949, 2.107545197069988, 2.1174868893782803, 2.1272453070053965, 2.1368278810836565, 2.14624158435041, 2.15549296869774, 2.1645881989186293, 2.1735330831055273, 2.1823331000944726, 2.190993424294858, 2.1995189481999327, 2.207914302834812, 2.216183876366077, 2.2243318310690086, 2.2323621188244487, 2.2402784952965282, 2.2480845329245804, 2.2557836328470398, 2.2633790358616253, 2.270873832514373, 2.278270972399822, 2.2855732727456926, 2.292783426347521, 2.2999040089118057, 2.3069374858601344, 2.313886218641378, 2.32075247059429, 2.3275384123986442, 2.3342461271493034, 2.3408776150842816, 2.347434797994922, 2.353919523343649, 2.360333568112413, 2.366678642402817, 2.372956392807042, 2.3791684055669524, 2.38531620953728, 2.391401278967363, 2.3974250361147083, 2.4033888537025008, 2.409294057232193, 2.4151419271613577, 2.420933700956197, 2.426670575027305, 2.432353706556619, 2.437984215222871, 2.4435631848322616, 2.4490916648605947, 2.454570671912596, 2.4600011911037485, 2.4653841773695464, 2.470720556706738, 2.4760112273507695, 2.481257060893357, 2.486458903343824, 2.49161757613759, 2.496733877094953, 2.5018085813331057, 2.5068424421341007, 2.5118361917713203], [0.0, 1.0, 1.148698354997035, 1.2457309396155174, 1.3195079107728942, 1.379729661461215, 1.4309690811052558, 1.4757731615945522, 1.5157165665103982, 1.5518455739153598, 1.5848931924611136, 1.615394266202178, 1.643751829517226, 1.6702776523348106, 1.6952182030724354, 1.7187719275874789, 1.7411011265922485, 1.7623403478323174, 1.7826024579660036, 1.8019831273171425, 1.8205642030260805, 1.838416287252544, 1.8556007362580844, 1.8721712305548577, 1.888175022589804, 1.9036539387158788, 1.9186451916253062, 1.933182044931763, 1.9472943612303366, 1.961009057454548, 1.9743504858348202, 1.9873407546644581, 2.0, 2.0123466170855586, 2.024397458499885, 2.0361680046403983, 2.0476725110792193, 2.0589241364785176, 2.0699350540816144, 2.0807165492618442, 2.0912791051825463, 2.101632478275785, 2.111785764966754, 2.121747460841898, 2.1315255132709487, 2.1411273683383243, 2.1505600128111397, 2.159830011764466, 2.1689435423953976, 2.17790642448278, 2.1867241478865562, 2.1954018974274905, 2.2039445754429607, 2.212356822276117, 2.2206430349229205, 2.228807384033519, 2.2368538294402898, 2.2447861343640922, 2.252607878432326, 2.260322469626816, 2.267933155266055, 2.2754430321145307, 2.282855055701629, 2.290172048923583, 2.29739670999407, 2.304531619802141, 2.311579248730029, 2.3185419629780504, 2.3254220304389968, 2.332221626160242, 2.3389428374280206, 2.345587668505003, 2.3521580450493476, 2.358655818240736, 2.365082768636564, 2.371440609779312, 2.377730991574249, 2.3839555034549, 2.390115677352187, 2.39621299048177, 2.4022488679628626, 2.4082246852806923, 2.4141417706037362, 2.4200014069659628, 2.4258048343234657, 2.4315532514941225, 2.437247817988224, 2.4428896557373947, 2.4484798507285492, 2.454019454549131, 2.4595094858493636, 2.4649509317268694, 2.470344749038559, 2.4756918656443667, 2.4809931815870696, 2.4862495702121024, 2.491461879231035, 2.4966309317320876, 2.501757527140844, 2.5068424421341007, 2.5118864315095806, 2.5168902290140656], [0.0, 1.0019920476665334, 1.1509866168746574, 1.248212495026907, 1.3221364334275216, 1.3824781487137754, 1.4338196397241527, 1.478712972077439, 1.518735946159841, 1.5549369242696978, 1.5880503752468602, 1.6186122085806973, 1.6470262615135756, 1.6736049250346068, 1.6985951585381307, 1.7221958031951323, 1.744569483028675, 1.7658510138098542, 1.7861534870327511, 1.8055727636010468, 1.8241908536984925, 1.8420785001276823, 1.8592971813747647, 1.8759006848860353, 1.8919363572375605, 1.9074461081023846, 1.9224672243021887, 1.9370330357133534, 1.951173464418679, 1.964915480971501, 1.978283486113046, 1.991299632177394, 2.0039840953330668, 2.01635530746838, 2.028430154733226, 2.0402241483627117, 2.051751572326739, 2.0630256115001586, 2.074058463375973, 2.0848614358085182, 2.0954450328440952, 2.1058190303500446, 2.1159925428720743, 2.125974082920241, 2.1357716136958165, 2.145392596116173, 2.1548440308664, 2.1641324960995103, 2.173264181317869, 2.1822449178935988, 2.1910802066227055, 2.1997752426543635, 2.20833493809164, 2.2167639425214714, 2.225066661698842, 2.233247274582035, 2.2413097488916023, 2.2492578553449185, 2.2570951807001713, 2.2648251397280488, 2.2724509862158557, 2.2799758230969838, 2.2874026117883735, 2.2947341808096007, 2.301973233749315, 2.30912235663782, 2.316184024778469, 2.32316060908516, 2.330054381968438, 2.336867522808473, 2.343602123049474, 2.3502601909466976, 2.3568436559943056, 2.3633543730596176, 2.3697941262469846, 2.3761646325123453, 2.3824675450476587, 2.3887044564526763, 2.3948769017100013, 2.400986360977976, 2.4070342622147205, 2.4130219836454936, 2.418950856084548, 2.4248221651217166, 2.4306371531831448, 2.436397021474813, 2.4421029318168106, 2.4477560083757046, 2.4533573393017467, 2.4589079782771925, 2.464408945981466, 2.469861231478535, 2.4752657935314137, 2.480623561848379, 2.485935438265135, 2.4912022978668626, 2.496424990053814, 2.501604339553839, 2.506741147385017, 2.5118361917713203, 2.5168902290140656, 2.5219039943216934]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 0.5\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.31622776601683794, 0.3760603093086393, 0.4161791450287817, 0.4472135954999579, 0.47287080450158786, 0.4949232003839765, 0.5143686723610401, 0.5318295896944989, 0.5477225575051661, 0.5623413251903491, 0.575901449065324, 0.5885661912765424, 0.6004624280888846, 0.6116908849062523, 0.6223329772884783, 0.6324555320336759, 0.6421141351518171, 0.6513555624326306, 0.6602195804079635, 0.668740304976422, 0.6769472427712399, 0.6848661007688606, 0.6925194237934933, 0.6999271023161167, 0.7071067811865476, 0.7140741917751113, 0.7208434242404264, 0.727427152512826, 0.7338368215846426, 0.7400828044922851, 0.7461745347323253, 0.7521206186172786, 0.7579289311365565, 0.7636066981663598, 0.7691605673134586, 0.7745966692414834, 0.7799206709850829, 0.7851378224852613, 0.7902529973621358, 0.7952707287670507, 0.8001952410151443, 0.8050304775850329, 0.8097801259787746, 0.8144476398584993, 0.81903625881272, 0.8235490260528069, 0.827988804296353, 0.8323582900575635, 0.8366600265340756, 0.8408964152537145, 0.8450697266227711, 0.8491821094987799, 0.8532355998949246, 0.8572321289096398, 0.861173529963367, 0.8650615454144222, 0.8688978326173192, 0.8726839694794393, 0.8764214595654655, 0.8801117367933934, 0.8837561697610181, 0.8873560657375262, 0.8909126743510709, 0.8944271909999159, 0.8979007600118484, 0.9013344775740003, 0.904729394452974, 0.9080865185231703, 0.9114068171194505, 0.9146912192286943, 0.9179406175334197, 0.9211558703193814, 0.9243378032579611, 0.9274872110731568, 0.9306048591020996, 0.9336914847572161, 0.9367477988974472, 0.9397744871152784, 0.9427722109457612, 0.9457416090031757, 0.9486832980505138, 0.9515978740065268, 0.9544859128947005, 0.9573479717381596, 0.9601845894041878, 0.9629962874017586, 0.9657835706352026, 0.9685469281169012, 0.9712868336416696, 0.9740037464252967, 0.9766981117095218, 0.9793703613355592, 0.9820209142881303, 0.9846501772118187, 0.9872585449014338, 0.989846400767953, 0.9924141172814958, 0.9949620563926881, 0.997490569933681, 1.0, 1.0024906793143211], [0.0, 0.3760603093086393, 0.4472135954999579, 0.4949232003839765, 0.5318295896944988, 0.5623413251903491, 0.5885661912765423, 0.6116908849062525, 0.6324555320336759, 0.6513555624326306, 0.668740304976422, 0.6848661007688605, 0.6999271023161167, 0.7140741917751113, 0.7274271525128259, 0.7400828044922851, 0.7521206186172786, 0.7636066981663597, 0.7745966692414834, 0.7851378224852613, 0.7952707287670506, 0.8050304775850328, 0.8144476398584994, 0.823549026052807, 0.8323582900575635, 0.8408964152537146, 0.8491821094987798, 0.85723212890964, 0.8650615454144222, 0.8726839694794393, 0.8801117367933933, 0.8873560657375262, 0.8944271909999159, 0.9013344775740003, 0.9080865185231703, 0.9146912192286943, 0.9211558703193814, 0.9274872110731568, 0.9336914847572162, 0.9397744871152784, 0.9457416090031758, 0.9515978740065267, 0.9573479717381597, 0.9629962874017586, 0.9685469281169012, 0.9740037464252967, 0.9793703613355592, 0.9846501772118186, 0.989846400767953, 0.9949620563926881, 1.0, 1.0049629315732038, 1.0098534065489688, 1.0146738461686593, 1.0194265469082735, 1.0241136890844451, 1.0287373447220802, 1.0332994847589594, 1.0378019856537666, 1.0422466354563211, 1.0466351393921056, 1.0509691250073554, 1.0552501469158886, 1.0594796911843958, 1.0636591793889976, 1.0677899723724407, 1.0718733737282615, 1.07591063303558, 1.0799029488658045, 1.0838514715804344, 1.0877573059372772, 1.0916215135207343, 1.0954451150103321, 1.0992290923003527, 1.1029743904822287, 1.1066819197003215, 1.110352556890736, 1.1139871474119822, 1.1175865065755222, 1.1211514210835454, 1.1246826503806981, 1.128180927925918, 1.1316469623900245, 1.1350814387842454, 1.1384850195244434, 1.1418583454354265, 1.1452020366993765, 1.148516693752116, 1.1518028981306478, 1.1550612132751377, 1.158292185288269, 1.161496343654686, 1.164674201923033, 1.167826258352922, 1.1709529965289849, 1.1740548859440185, 1.1771323825530846, 1.1801859293002996, 1.1832159566199232, 1.1862228829132528, 1.189207115002721, 1.1921690485645018], [0.0, 0.4161791450287817, 0.4949232003839765, 0.5477225575051661, 0.5885661912765423, 0.6223329772884783, 0.6513555624326306, 0.6769472427712399, 0.6999271023161167, 0.7208434242404262, 0.7400828044922853, 0.7579289311365563, 0.7745966692414834, 0.7902529973621358, 0.8050304775850328, 0.8190362588127199, 0.8323582900575635, 0.8450697266227711, 0.8572321289096398, 0.8688978326173193, 0.8801117367933934, 0.8909126743510708, 0.9013344775740003, 0.9114068171194506, 0.9211558703193815, 0.9306048591020997, 0.9397744871152784, 0.9486832980505139, 0.9573479717381597, 0.9657835706352028, 0.9740037464252967, 0.9820209142881303, 0.989846400767953, 0.9974905699336811, 1.0049629315732038, 1.0122722344290391, 1.0194265469082735, 1.0264333272479387, 1.0332994847589596, 1.0400314334861216, 1.0466351393921056, 1.0531161619882878, 1.0594796911843958, 1.0657305800060608, 1.0718733737282615, 1.0779123358892526, 1.0838514715804344, 1.0896945483500373, 1.0954451150103321, 1.1011065185976396, 1.1066819197003215, 1.112174306341096, 1.1175865065755222, 1.1229211999476407, 1.128180927925918, 1.133368103427352, 1.1384850195244434, 1.1435338574183984, 1.148516693752116, 1.1534355073280027, 1.158292185288269, 1.1630885288089072, 1.167826258352922, 1.172507018523451, 1.1771323825530846, 1.1817038564618862, 1.1862228829132528, 1.190690844793804, 1.1951090685408468, 1.1994788272386536, 1.203801343502716, 1.2080777921692967, 1.212309302805974, 1.2164969620573964, 1.220641815839165, 1.224744871391589, 1.2288070992040003, 1.2328294348193778, 1.236812780528175, 1.2407580069594817, 1.2446659545769565, 1.2485374350863452, 1.2523732327608301, 1.2561741056899516, 1.259940786957369, 1.2636739857523107, 1.2673743884191842, 1.2710426594494582, 1.2746794424196195, 1.2782853608787121, 1.281861019188702, 1.2854070033206721, 1.288923881609622, 1.2924122054704554, 1.295872510077541, 1.2993053150100684, 1.3027111248652612, 1.3060904298413636, 1.309443706292189, 1.3127714172548886, 1.3160740129524924, 1.319351931272669], [0.0, 0.4472135954999579, 0.5318295896944988, 0.5885661912765423, 0.6324555320336758, 0.668740304976422, 0.6999271023161167, 0.7274271525128259, 0.7521206186172787, 0.7745966692414833, 0.7952707287670506, 0.8144476398584993, 0.8323582900575635, 0.8491821094987799, 0.865061545414422, 0.8801117367933933, 0.8944271909999159, 0.9080865185231702, 0.9211558703193814, 0.9336914847572161, 0.9457416090031757, 0.9573479717381596, 0.9685469281169012, 0.9793703613355593, 0.9898464007679532, 1.0, 1.0098534065489688, 1.0194265469082735, 1.0287373447220802, 1.0378019856537666, 1.0466351393921054, 1.0552501469158886, 1.0636591793889976, 1.0718733737282617, 1.0799029488658043, 1.087757305937277, 1.0954451150103321, 1.1029743904822287, 1.1103525568907362, 1.1175865065755222, 1.1246826503806981, 1.1316469623900245, 1.1384850195244434, 1.1452020366993765, 1.1518028981306478, 1.158292185288269, 1.164674201923033, 1.1709529965289847, 1.1771323825530846, 1.1832159566199232, 1.189207115002721, 1.1951090685408465, 1.2009248561777692, 1.206657357270946, 1.212309302805974, 1.2178832856309065, 1.223381769812505, 1.2288070992040003, 1.2341615053034112, 1.2394471144723045, 1.2446659545769567, 1.2498199611069312, 1.2549109828200413, 1.259940786957369, 1.2649110640673515, 1.2698234324738655, 1.2746794424196195, 1.2794805799129934, 1.2842282703036343, 1.288923881609622, 1.2935687276168015, 1.2981640707688962, 1.3027111248652612, 1.3072110575815623, 1.311664992827256, 1.3160740129524924, 1.320439160815927, 1.3247614417239144, 1.3290418252506462, 1.333281246947964, 1.337480609952844, 1.3416407864998738, 1.345762619345434, 1.34984692310975, 1.3538944855424797, 1.357906068717044, 1.3618824101585059, 1.3658242239094176, 1.369732201537721, 1.3736070130904692, 1.3774493079968595, 1.381259715923798, 1.3850388475869866, 1.3887872955203007, 1.3925056348060254, 1.3961944237683348, 1.3998542046322333, 1.4034855041500147, 1.4070888341971637, 1.4106646923394799, 1.414213562373095, 1.4177359148389301], [0.0, 0.47287080450158786, 0.5623413251903491, 0.6223329772884783, 0.668740304976422, 0.7071067811865475, 0.7400828044922853, 0.7691605673134586, 0.7952707287670506, 0.81903625881272, 0.8408964152537145, 0.861173529963367, 0.8801117367933934, 0.8979007600118484, 0.9146912192286943, 0.9306048591020994, 0.9457416090031757, 0.9601845894041878, 0.9740037464252967, 0.9872585449014338, 0.9999999999999999, 1.0122722344290394, 1.0241136890844451, 1.0355580763416221, 1.0466351393921056, 1.057371263440564, 1.0677899723724407, 1.0779123358892526, 1.0877573059372772, 1.0973419967718494, 1.1066819197003215, 1.1157911810902938, 1.1246826503806981, 1.133368103427352, 1.1418583454354265, 1.150163316895603, 1.158292185288269, 1.1662534248067802, 1.1740548859440185, 1.181703856461886, 1.189207115002721, 1.1965709783910168, 1.203801343502716, 1.210903724439527, 1.2178832856309065, 1.224744871391589, 1.2314930323839879, 1.238132049369367, 1.2446659545769565, 1.2510985509742438, 1.2574334296829353, 1.2636739857523107, 1.2698234324738655, 1.2758848143974324, 1.281861019188702, 1.287754788450697, 1.2935687276168015, 1.2993053150100684, 1.3049669101523764, 1.310555761397342, 1.3160740129524924, 1.3215237113488725, 1.3269068114098672, 1.332225181765412, 1.337480609952844, 1.342674807141325, 1.3478094125129467, 1.3528859973302676, 1.3579060687170441, 1.362871073176282, 1.3677823998673804, 1.3726413836620537, 1.3774493079968595, 1.3822074075384925, 1.386916870676514, 1.3915788418568702, 1.3961944237683348, 1.4007646793929587, 1.4052906339306293, 1.4097732766069795, 1.414213562373095, 1.4186124135047635, 1.4229707211083644, 1.4272893465399143, 1.4315691227432643, 1.4358108555129503, 1.4400153246867797, 1.4441832852728287, 1.4483154685151653, 1.452412582902289, 1.45647531512197, 1.460504330965901, 1.4645002761873147, 1.4684637773145044, 1.4723954424229517, 1.4762958618685946, 1.4801656089845705, 1.484005240743618, 1.4878152983881654, 1.4915963080299905, 1.4953487812212205, 1.4990732154983035], [0.0, 0.4949232003839765, 0.5885661912765423, 0.6513555624326306, 0.6999271023161167, 0.7400828044922853, 0.7745966692414834, 0.8050304775850328, 0.8323582900575635, 0.8572321289096398, 0.8801117367933934, 0.9013344775740003, 0.9211558703193815, 0.9397744871152784, 0.9573479717381596, 0.9740037464252966, 0.989846400767953, 1.0049629315732038, 1.0194265469082735, 1.0332994847589596, 1.0466351393921054, 1.0594796911843958, 1.0718733737282617, 1.0838514715804344, 1.0954451150103324, 1.1066819197003217, 1.1175865065755222, 1.128180927925918, 1.1384850195244434, 1.148516693752116, 1.158292185288269, 1.167826258352922, 1.1771323825530846, 1.1862228829132528, 1.1951090685408468, 1.2038013435027157, 1.2123093028059742, 1.220641815839165, 1.2288070992040003, 1.236812780528175, 1.2446659545769567, 1.25237323276083, 1.259940786957369, 1.2673743884191842, 1.2746794424196195, 1.281861019188702, 1.288923881609622, 1.2958725100775408, 1.3027111248652612, 1.309443706292189, 1.3160740129524924, 1.3226055982240474, 1.3290418252506462, 1.3353858805651275, 1.3416407864998738, 1.3478094125129467, 1.35389448554248, 1.3598985994884667, 1.3658242239094178, 1.3716737120112341, 1.3774493079968597, 1.3831531538375998, 1.3887872955203007, 1.3943536888187151, 1.3998542046322333, 1.4052906339306293, 1.41066469233948, 1.4159780243973923, 1.4212322075130495, 1.4264287556473265, 1.4315691227432643, 1.4366547059245063, 1.4416868484808525, 1.4466668426578508, 1.451595932265776, 1.4564753151219703, 1.4613061453392517, 1.4660895354719874, 1.4708265585304046, 1.4755182498728112, 1.4801656089845705, 1.4847696011519296, 1.489331159038138, 1.4938511841686706, 1.4983305483318308, 1.502770094900495, 1.507170640080316, 1.5115329740892762, 1.5158578622731127, 1.5201460461607854, 1.5243982444638442, 1.5286151540232695, 1.5327974507070874, 1.5369457902618242, 1.541060809120647, 1.5451431251708252, 1.5491933384829668, 1.553212032004312, 1.5571997722182047, 1.5611571097717192, 1.5650845800732873, 1.5689827038620388], [0.0, 0.5143686723610401, 0.6116908849062525, 0.6769472427712399, 0.7274271525128259, 0.7691605673134586, 0.8050304775850328, 0.8366600265340756, 0.8650615454144222, 0.8909126743510708, 0.9146912192286945, 0.9367477988974472, 0.9573479717381597, 0.9766981117095219, 0.9949620563926881, 1.0122722344290391, 1.0287373447220802, 1.04444780217279, 1.0594796911843958, 1.0738976950655401, 1.0877573059372772, 1.1011065185976396, 1.1139871474119825, 1.126435863262952, 1.1384850195244434, 1.1501633168956031, 1.161496343654686, 1.172507018523451, 1.1832159566199234, 1.1936417741003793, 1.203801343502716, 1.2137100091313509, 1.223381769812505, 1.2328294348193778, 1.2420647575928365, 1.2510985509742438, 1.259940786957369, 1.2686006834079462, 1.277086779756963, 1.2854070033206721, 1.2935687276168018, 1.3015788238173445, 1.309443706292189, 1.317169373045755, 1.3247614417239144, 1.3322251817654118, 1.3395655431865348, 1.3467871824166227, 1.3538944855424797, 1.3608915892697748, 1.3677823998673804, 1.3745706103249549, 1.381259715923798, 1.3878530283952342, 1.3943536888187151, 1.4007646793929587, 1.4070888341971637, 1.4133288490453373, 1.4194872905246418, 1.4255666042981499, 1.4315691227432645, 1.4374970719890816, 1.44335257840902, 1.449137674618944, 1.4548543050256517, 1.460504330965901, 1.4660895354719874, 1.4716116276962383, 1.4770722470235311, 1.4824729668980785, 1.4878152983881654, 1.493100693510252, 1.4983305483318308, 1.5035062058706188, 1.508628958806044, 1.5137000520175454, 1.5187206849628931, 1.5236920139085786, 1.5286151540232698, 1.533491181344376, 1.5383211346269172, 1.5431060170831203, 1.547846798020459, 1.5525444143852343, 1.5571997722182047, 1.561813748028264, 1.5663871900896853, 1.5709209196680185, 1.5754157321793416, 1.5798723982871963, 1.584291664941221, 1.588674256361194, 1.593020874969912, 1.5973322022781031, 1.6016088997243154, 1.6058516094725332, 1.6100609551700655, 1.6142375426680784, 1.618381960706977, 1.6224947815686916, 1.6265765616977856, 1.630627842293166], [0.0, 0.5318295896944989, 0.6324555320336759, 0.6999271023161167, 0.7521206186172787, 0.7952707287670506, 0.8323582900575635, 0.8650615454144222, 0.894427190999916, 0.9211558703193814, 0.9457416090031758, 0.9685469281169012, 0.9898464007679532, 1.0098534065489688, 1.0287373447220802, 1.0466351393921054, 1.0636591793889978, 1.0799029488658045, 1.0954451150103321, 1.1103525568907362, 1.1246826503806981, 1.1384850195244434, 1.151802898130648, 1.164674201923033, 1.1771323825530848, 1.1892071150027212, 1.2009248561777692, 1.2123093028059742, 1.223381769812505, 1.2341615053034112, 1.2446659545769565, 1.2549109828200413, 1.2649110640673518, 1.2746794424196195, 1.2842282703036343, 1.2935687276168015, 1.3027111248652612, 1.311664992827256, 1.3204391608159272, 1.3290418252506462, 1.3374806099528442, 1.345762619345434, 1.35389448554248, 1.3618824101585059, 1.369732201537721, 1.3774493079968597, 1.3850388475869866, 1.3925056348060254, 1.3998542046322333, 1.4070888341971637, 1.4142135623730951, 1.4212322075130495, 1.4281483835502227, 1.4349655146369895, 1.4416868484808525, 1.4483154685151653, 1.454854305025652, 1.4613061453392517, 1.4676736431692852, 1.4739593272000566, 1.4801656089845705, 1.4862947902207868, 1.4923490694646506, 1.498330548331831, 1.5042412372345575, 1.5100830606950983, 1.515857862273113, 1.5215674091403395, 1.5272133963327197, 1.5327974507070874, 1.5383211346269172, 1.5437859493992674, 1.5491933384829668, 1.5545446904862257, 1.5598413419701658, 1.5650845800732873, 1.5702756449705226, 1.5754157321793416, 1.5805059947242717, 1.5855475451702188, 1.5905414575341013, 1.5954887690834967, 1.6003904820302886, 1.6052475651266458, 1.6100609551700658, 1.6148315584236825, 1.6195602519575492, 1.624247884916149, 1.6288952797169989, 1.633503233184822, 1.63807251762544, 1.642603881843218, 1.6470980521056138, 1.6515557330581283, 1.6559776085927063, 1.6603643426724282, 1.664716580115127, 1.6690349473383785, 1.6733200530681511, 1.6775724890132342, 1.681792830507429, 1.6859816371213476], [0.0, 0.5477225575051661, 0.6513555624326306, 0.7208434242404262, 0.7745966692414833, 0.81903625881272, 0.8572321289096398, 0.8909126743510708, 0.9211558703193814, 0.9486832980505138, 0.9740037464252967, 0.997490569933681, 1.0194265469082735, 1.0400314334861216, 1.0594796911843956, 1.0779123358892526, 1.0954451150103321, 1.112174306341096, 1.128180927925918, 1.1435338574183984, 1.158292185288269, 1.172507018523451, 1.1862228829132528, 1.1994788272386536, 1.2123093028059742, 1.2247448713915892, 1.2368127805281748, 1.2485374350863452, 1.259940786957369, 1.2710426594494582, 1.281861019188702, 1.2924122054704554, 1.3027111248652612, 1.3127714172548886, 1.3226055982240474, 1.3322251817654118, 1.3416407864998738, 1.3508622280193734, 1.3598985994884667, 1.368758342264813, 1.3774493079968597, 1.385978813413053, 1.3943536888187151, 1.4025803211547638, 1.4106646923394799, 1.4186124135047637, 1.4264287556473265, 1.4341186771394874, 1.4416868484808525, 1.449137674618944, 1.4564753151219703, 1.463703702448981, 1.4708265585304046, 1.4778474098445196, 1.4847696011519296, 1.4915963080299905, 1.4983305483318308, 1.504975192679675, 1.5115329740892762, 1.5180064968110587, 1.5243982444638442, 1.5307105875285492, 1.5369457902618242, 1.5431060170831206, 1.5491933384829666, 1.5552097364952306, 1.5611571097717192, 1.5670372782935749, 1.5728519877504674, 1.5786029136155242, 1.584291664941221, 1.5899197878990334, 1.5954887690834965, 1.6010000385993937, 1.6064549729490671, 1.6118548977353129, 1.6172010901939202, 1.6224947815686916, 1.6277371593406456, 1.6329293693221016, 1.63807251762544, 1.6431676725154982, 1.6482158661538315, 1.653218096242383, 1.658175327573506, 1.6630884934927144, 1.6679584972800465, 1.6727862134554565, 1.6775724890132342, 1.6823181445900717, 1.6870239755710472, 1.6916907531374747, 1.6963192252602786, 1.7009101176422834, 1.7054641346125685, 1.709981959975803, 1.7144642578192797, 1.7189116732801692, 1.7233248332753461, 1.7277043471959719, 1.7320508075688772, 1.7363647906866422], [0.0, 0.5623413251903491, 0.668740304976422, 0.7400828044922853, 0.7952707287670506, 0.8408964152537145, 0.8801117367933934, 0.9146912192286945, 0.9457416090031758, 0.9740037464252967, 1.0, 1.0241136890844451, 1.0466351393921056, 1.0677899723724409, 1.0877573059372772, 1.1066819197003215, 1.1246826503806981, 1.1418583454354265, 1.158292185288269, 1.1740548859440185, 1.189207115002721, 1.203801343502716, 1.2178832856309068, 1.231493032383988, 1.2446659545769567, 1.2574334296829355, 1.2698234324738655, 1.2818610191887023, 1.2935687276168018, 1.3049669101523764, 1.3160740129524924, 1.3269068114098672, 1.337480609952844, 1.347809412512947, 1.3579060687170441, 1.3677823998673804, 1.3774493079968597, 1.386916870676514, 1.396194423768335, 1.4052906339306293, 1.4142135623730951, 1.4229707211083644, 1.4315691227432645, 1.44001532468678, 1.4483154685151653, 1.4564753151219703, 1.464500276187315, 1.4723954424229517, 1.4801656089845705, 1.4878152983881654, 1.4953487812212205, 1.5027700949004952, 1.5100830606950983, 1.5172912992053529, 1.5243982444638442, 1.531407156804393, 1.5383211346269174, 1.5451431251708252, 1.5518759343963227, 1.5585222360615276, 1.5650845800732873, 1.5715654001808814, 1.5779670210741878, 1.5842916649412213, 1.5905414575341013, 1.59671843378737, 1.602824543028034, 1.6088616538127065, 1.6148315584236828, 1.6207359770526288, 1.6265765616977856, 1.6323548997980941, 1.63807251762544, 1.643730883454241, 1.6493314105258192, 1.6548754598234365, 1.6603643426724282, 1.665799323178612, 1.6711816205169887, 1.6765124110817191, 1.681792830507429, 1.6870239755710472, 1.6922069059826197, 1.6973426460728507, 1.7024321863844938, 1.7074764851741444, 1.7124764698304722, 1.7174330382144525, 1.722347059926734, 1.7272193775068816, 1.7320508075688772, 1.7368421418769384, 1.741594148365405, 1.74630757210618, 1.7509831362269537, 1.7556215427832071, 1.7602234735867868, 1.7647895909936366, 1.7693205386531028, 1.7738169422210552, 1.7782794100389228, 1.78270853378059], [0.0, 0.575901449065324, 0.6848661007688605, 0.7579289311365563, 0.8144476398584993, 0.861173529963367, 0.9013344775740003, 0.9367477988974472, 0.9685469281169012, 0.997490569933681, 1.0241136890844451, 1.0488088481701514, 1.0718733737282617, 1.093538327773718, 1.1139871474119822, 1.133368103427352, 1.151802898130648, 1.1693927625557354, 1.1862228829132528, 1.2023656804317462, 1.2178832856309065, 1.2328294348193778, 1.247250944521753, 1.261188872476556, 1.2746794424196195, 1.2877547884506972, 1.3004435599166833, 1.3127714172548886, 1.3247614417239146, 1.33643447648928, 1.3478094125129467, 1.3589034297042373, 1.369732201537721, 1.3803100696313728, 1.3906501934639681, 1.4007646793929585, 1.41066469233948, 1.4203605528819792, 1.4298618220045207, 1.4391773753505153, 1.4483154685151656, 1.4572837946534403, 1.4660895354719874, 1.4747394065031132, 1.4832396974191324, 1.4915963080299908, 1.4998147805113797, 1.5079003283308927, 1.5158578622731127, 1.5236920139085786, 1.531407156804393, 1.5390074257343278, 1.5464967341123872, 1.5538787898449244, 1.5611571097717194, 1.568335032845268, 1.5754157321793418, 1.5824022260821624, 1.5892973881759884, 1.5961039566931094, 1.602824543028034, 1.6094616396167147, 1.6160176272058788, 1.6224947815686919, 1.6288952797169987, 1.635221205655121, 1.6414745557155297, 1.6476572435126322, 1.6537711045472614, 1.6598179004912503, 1.665799323178612, 1.671716998327296, 1.6775724890132342, 1.6833672989163568, 1.689102875356448, 1.694780612135097, 1.7004018521985302, 1.70596789013482, 1.7114799745177744, 1.716939310108757, 1.722347059926734, 1.7277043471959719, 1.7330122571800355, 1.7382718389100207, 1.7434841068143216, 1.748650042256635, 1.7537705949883924, 1.7588466845213098, 1.7638792014253155, 1.7688690085567114, 1.7738169422210552, 1.7787238132749206, 1.7835904081703773, 1.7884174899457608, 1.793205799166037, 1.7979560548158353, 1.8026689551480006, 1.8073451784903223, 1.8119853840129068, 1.816590212458495, 1.8211602868378718, 1.825696213092362], [0.0, 0.5885661912765424, 0.6999271023161167, 0.7745966692414834, 0.8323582900575635, 0.8801117367933934, 0.9211558703193815, 0.9573479717381597, 0.9898464007679532, 1.0194265469082735, 1.0466351393921056, 1.0718733737282617, 1.0954451150103324, 1.1175865065755222, 1.1384850195244434, 1.158292185288269, 1.1771323825530848, 1.1951090685408468, 1.2123093028059742, 1.2288070992040006, 1.2446659545769567, 1.259940786957369, 1.2746794424196197, 1.2889238816096222, 1.3027111248652612, 1.3160740129524926, 1.3290418252506462, 1.341640786499874, 1.35389448554248, 1.3658242239094178, 1.3774493079968597, 1.3887872955203007, 1.3998542046322333, 1.41066469233948, 1.4212322075130497, 1.4315691227432643, 1.4416868484808527, 1.451595932265776, 1.461306145339252, 1.4708265585304046, 1.4801656089845707, 1.489331159038138, 1.498330548331831, 1.5071706400803162, 1.515857862273113, 1.5243982444638442, 1.5327974507070876, 1.541060809120647, 1.5491933384829668, 1.5571997722182047, 1.5650845800732873, 1.5728519877504676, 1.5805059947242717, 1.5880503904422236, 1.5954887690834967, 1.602824543028034, 1.6100609551700658, 1.6172010901939202, 1.6242478849161492, 1.6312041377859532, 1.6380725176254403, 1.6448555716821271, 1.6515557330581283, 1.6581753275735063, 1.664716580115127, 1.6711816205169887, 1.6775724890132342, 1.6838911413008757, 1.6901394532455423, 1.6963192252602788, 1.7024321863844938, 1.708479998087565, 1.71446425781928, 1.7203865023272384, 1.726248210759469, 1.7320508075688774, 1.7377956652346387, 1.7434841068143216, 1.7491174083393235, 1.75469680106511, 1.7602234735867868, 1.7656985738296271, 1.771123210923403, 1.7764984569686235, 1.7818253487021418, 1.7871048890689831, 1.7923380487067173, 1.797525767348191, 1.8026689551480006, 1.8077684939376608, 1.8128252384140608, 1.8178400172654527, 1.822813634238901, 1.8277468691528413, 1.8326404788581239, 1.8374951981506855, 1.842311740638763, 1.847090799567362, 1.8518330486025056, 1.8565391425776128, 1.8612097182041993, 1.865845394748944], [0.0, 0.6004624280888846, 0.7140741917751113, 0.7902529973621358, 0.8491821094987799, 0.8979007600118484, 0.9397744871152784, 0.9766981117095219, 1.0098534065489688, 1.0400314334861216, 1.0677899723724409, 1.093538327773718, 1.1175865065755222, 1.140175425099138, 1.161496343654686, 1.181703856461886, 1.2009248561777692, 1.219264891125735, 1.236812780528175, 1.2536440342258928, 1.2698234324738655, 1.2854070033206724, 1.3004435599166835, 1.314975911026152, 1.3290418252506464, 1.3426748071413253, 1.355904727879147, 1.3687583422648133, 1.3812597159237983, 1.3934305809385557, 1.4052906339306293, 1.4168577874961457, 1.4281483835502227, 1.4391773753505155, 1.4499584835997423, 1.460504330965901, 1.4708265585304046, 1.480935927022547, 1.4908424051821465, 1.5005552471800365, 1.5100830606950986, 1.5194338669790928, 1.52861515402327, 1.5376339237631882, 1.5464967341123872, 1.5552097364952309, 1.563778709449485, 1.5722090887861115, 1.5805059947242717, 1.588674256361194, 1.59671843378737, 1.6046428381159301, 1.61245154965971, 1.6201484344594288, 1.6277371593406456, 1.635221205655121, 1.642603881843218, 1.6498883349376223, 1.6570775611145052, 1.6641744153859734, 1.6711816205169887, 1.6781017752406273, 1.68493736183743, 1.6916907531374752, 1.6983642189975598, 1.704959932300383, 1.7114799745177744, 1.7179263408757495, 1.72430094515537, 1.7306056241600476, 1.7368421418769384, 1.7430121933574254, 1.7491174083393233, 1.7551593546313318, 1.7611395412783635, 1.7670594215246977, 1.772920395590378, 1.7787238132749208, 1.7844709764011664, 1.790163141111003, 1.7958015200236968, 1.8013872842666538, 1.8069215653876352, 1.812405457156695, 1.8178400172654527, 1.8232262689306922, 1.828565202408735, 1.8338577764265274, 1.8391049195349223, 1.8443075313892177, 1.8494664839616353, 1.854582622690067, 1.8596567675671005, 1.8646897141730423, 1.8696822346563888, 1.8746350786649428, 1.879548974230557, 1.8844246286102666, 1.8892627290863888, 1.8940639437279883, 1.8988289221159418, 1.9035582960336908], [0.0, 0.6116908849062523, 0.7274271525128259, 0.8050304775850328, 0.865061545414422, 0.9146912192286943, 0.9573479717381596, 0.9949620563926881, 1.0287373447220802, 1.0594796911843956, 1.0877573059372772, 1.1139871474119822, 1.1384850195244434, 1.161496343654686, 1.1832159566199232, 1.2038013435027157, 1.2233817698125047, 1.2420647575928363, 1.2599407869573689, 1.2770867797569627, 1.2935687276168015, 1.309443706292189, 1.3247614417239146, 1.339565543186535, 1.35389448554248, 1.3677823998673806, 1.381259715923798, 1.3943536888187151, 1.4070888341971637, 1.4194872905246418, 1.4315691227432643, 1.4433525784090198, 1.4548543050256517, 1.4660895354719874, 1.4770722470235311, 1.4878152983881652, 1.4983305483318308, 1.508628958806044, 1.5187206849628931, 1.5286151540232695, 1.5383211346269174, 1.547846798020459, 1.5571997722182047, 1.5663871900896853, 1.5754157321793416, 1.584291664941221, 1.593020874969912, 1.6016088997243152, 1.6100609551700655, 1.618381960706977, 1.6265765616977856, 1.634649149872069, 1.642603881843218, 1.6504446959456858, 1.658175327573506, 1.665799323178612, 1.6733200530681511, 1.6807407231233218, 1.6880643855478386, 1.6952939487416283, 1.7024321863844938, 1.7094817458049945, 1.7164451557015292, 1.7233248332753464, 1.730123090828844, 1.7368421418769384, 1.7434841068143214, 1.7500510181771018, 1.75654482553344, 1.7629674000343882, 1.7693205386531026, 1.7756059681378888, 1.7818253487021416, 1.7879802774720857, 1.7940722917112943, 1.800102871839254, 1.8060734442596784, 1.8119853840129065, 1.8178400172654527, 1.8236386236486597, 1.8293824384573887, 1.8350726547187572, 1.8407104251401096, 1.8462968639446533, 1.8518330486025054, 1.8573200214642784, 1.8627587913037733, 1.8681503347758255, 1.8734955977948944, 1.8787954968395464, 1.884050920187607, 1.8892627290863886, 1.8944317588620794, 1.8995588199720859, 1.9046446990038355, 1.9096901596233076, 1.914695943476319, 1.9196627710453875, 1.9245913424647911, 1.9294823382962738, 1.9343364202676692, 1.939154231976568], [0.0, 0.6223329772884783, 0.7400828044922851, 0.8190362588127199, 0.8801117367933933, 0.9306048591020994, 0.9740037464252966, 1.0122722344290391, 1.0466351393921054, 1.0779123358892526, 1.1066819197003215, 1.133368103427352, 1.158292185288269, 1.181703856461886, 1.2038013435027157, 1.2247448713915887, 1.2446659545769565, 1.2636739857523107, 1.281861019188702, 1.2993053150100684, 1.3160740129524924, 1.3322251817654118, 1.347809412512947, 1.362871073176282, 1.3774493079968595, 1.3915788418568702, 1.405290633930629, 1.4186124135047637, 1.4315691227432645, 1.444183285272829, 1.45647531512197, 1.4684637773145044, 1.4801656089845703, 1.4915963080299905, 1.502770094900495, 1.5137000520175452, 1.5243982444638442, 1.5348758249050471, 1.5451431251708252, 1.5552097364952304, 1.5650845800732873, 1.5747759693135555, 1.584291664941221, 1.5936389239222475, 1.6028245430280337, 1.6118548977353127, 1.6207359770526286, 1.6294734147786363, 1.6380725176254398, 1.6465382905797215, 1.6548754598234363, 1.6630884934927144, 1.6711816205169885, 1.6791588477491748, 1.687023975571047, 1.6947806121350968, 1.7024321863844938, 1.709981959975803, 1.7174330382144525, 1.724788380100209, 1.7320508075688772, 1.7392230140067817, 1.7463075721061798, 1.7533069411223694, 1.7602234735867865, 1.7670594215246973, 1.773816942221055, 1.78049810357368, 1.7871048890689831, 1.7936392024119794, 1.8001028718392538, 1.8064976541407807, 1.8128252384140606, 1.8190872495718449, 1.8252852516227527, 1.831420750742353, 1.8374951981506853, 1.8435099928108025, 1.8494664839616353, 1.8553659734973313, 1.861209718204199, 1.8669989318654348, 1.872734787242987, 1.8784184179451258, 1.884050920187607, 1.8896333544556796, 1.8951667470736167, 1.900652091687926, 1.9060903506699227, 1.91148245644291, 1.9168293127388172, 1.9221317957887882, 1.9273907554518728, 1.932607016285675, 1.9377813785625346, 1.9429146192345597, 1.9480074928505933, 1.953060732427983, 1.9580750502818227, 1.9630511388141516, 1.9679896712654301, 1.9728913024304486], [0.0, 0.6324555320336759, 0.7521206186172786, 0.8323582900575635, 0.8944271909999159, 0.9457416090031757, 0.989846400767953, 1.0287373447220802, 1.0636591793889978, 1.0954451150103321, 1.1246826503806981, 1.151802898130648, 1.1771323825530848, 1.2009248561777692, 1.2233817698125047, 1.2446659545769565, 1.2649110640673518, 1.2842282703036343, 1.3027111248652612, 1.320439160815927, 1.337480609952844, 1.3538944855424797, 1.3697322015377211, 1.3850388475869866, 1.3998542046322333, 1.4142135623730951, 1.4281483835502227, 1.4416868484808527, 1.454854305025652, 1.4676736431692852, 1.4801656089845703, 1.4923490694646506, 1.5042412372345573, 1.515857862273113, 1.5272133963327197, 1.5383211346269172, 1.5491933384829668, 1.5598413419701658, 1.5702756449705226, 1.5805059947242717, 1.5905414575341015, 1.6003904820302886, 1.6100609551700658, 1.6195602519575492, 1.6288952797169987, 1.63807251762544, 1.6470980521056138, 1.655977608592706, 1.664716580115127, 1.6733200530681511, 1.681792830507429, 1.6901394532455423, 1.6983642189975598, 1.7064711997898492, 1.7144642578192797, 1.722347059926734, 1.7301230908288443, 1.7377956652346385, 1.7453679389588785, 1.752842919130931, 1.7602234735867868, 1.7675123395220362, 1.7747121314750525, 1.7818253487021418, 1.7888543819998317, 1.7958015200236968, 1.8026689551480006, 1.809458788905948, 1.8161730370463407, 1.822813634238901, 1.8293824384573887, 1.8358812350668394, 1.8423117406387628, 1.8486756065159222, 1.8549744221463136, 1.8612097182041991, 1.8673829695144322, 1.8734955977948944, 1.879548974230557, 1.8855444218915225, 1.8914832180063514, 1.8973665961010275, 1.9031957480130537, 1.908971825789401, 1.914695943476319, 1.9203691788083757, 1.9259925748035172, 1.9315671412704052, 1.9370938562338025, 1.9425736672833391, 1.9480074928505935, 1.9533962234190436, 1.9587407226711184, 1.9640418285762606, 1.9693003544236374, 1.9745170898028677, 1.979692801535906, 1.9848282345629915, 1.9899241127853762, 1.994981139867362, 2.0, 2.0049813586286422], [0.0, 0.6421141351518171, 0.7636066981663597, 0.8450697266227711, 0.9080865185231702, 0.9601845894041878, 1.0049629315732038, 1.04444780217279, 1.0799029488658045, 1.112174306341096, 1.1418583454354265, 1.1693927625557354, 1.1951090685408468, 1.219264891125735, 1.2420647575928363, 1.2636739857523107, 1.2842282703036343, 1.3038404810405297, 1.3226055982240474, 1.3406043695144154, 1.3579060687170441, 1.3745706103249549, 1.3906501934639681, 1.4061905963732368, 1.4212322075130495, 1.4358108555129505, 1.449958483599742, 1.4637037024489812, 1.4770722470235311, 1.4900873568745734, 1.502770094900495, 1.5151396162234685, 1.5272133963327195, 1.5390074257343278, 1.5505363768819687, 1.561813748028264, 1.5728519877504674, 1.5836626032071637, 1.5942562546302799, 1.60464283811593, 1.6148315584236828, 1.6248309932078528, 1.634649149872069, 1.644293516048505, 1.6537711045472614, 1.6630884934927144, 1.6722518622569726, 1.6812670237117344, 1.6901394532455423, 1.698874314931026, 1.7074764851741444, 1.7159505741329184, 1.7243009451553697, 1.732531732454193, 1.740646857208154, 1.748650042256635, 1.75654482553344, 1.7643345723684827, 1.7720224867708414, 1.7796116217935372, 1.7871048890689831, 1.7945050675941052, 1.801814811835441, 1.80903665921692, 1.8161730370463405, 1.8232262689306922, 1.8301985807252843, 1.837092106057081, 1.8439088914585777, 1.850650901144984, 1.8573200214642784, 1.8639180650468632, 1.8704467746790285, 1.8769078269221715, 1.8833028354976902, 1.8896333544556798, 1.8959008811439184, 1.9021068589921832, 1.9082526801256237, 1.9143396878197294, 1.9203691788083757, 1.9263424054554514, 1.9322605777997164, 1.938124865481734, 1.9439363995610137, 1.9496962742308461, 1.955405548437723, 1.9610652474116923, 1.966676364113512, 1.9722398606040152, 1.9777566693406925, 1.9832276944061233, 1.988653812672542, 1.9940358749065195, 1.9993747068174434, 2.004671110053224, 2.0099258631464076, 2.015139722413657, 2.0203134228113497, 2.025447678749862, 2.0305431848689306, 2.0356006167763194], [0.0, 0.6513555624326306, 0.7745966692414834, 0.8572321289096398, 0.9211558703193814, 0.9740037464252967, 1.0194265469082735, 1.0594796911843958, 1.0954451150103321, 1.128180927925918, 1.158292185288269, 1.1862228829132528, 1.2123093028059742, 1.236812780528175, 1.2599407869573689, 1.281861019188702, 1.3027111248652612, 1.3226055982240474, 1.3416407864998738, 1.3598985994884667, 1.3774493079968597, 1.3943536888187151, 1.41066469233948, 1.4264287556473267, 1.4416868484808527, 1.4564753151219703, 1.4708265585304046, 1.4847696011519298, 1.498330548331831, 1.5115329740892764, 1.5243982444638442, 1.5369457902618242, 1.5491933384829668, 1.5611571097717194, 1.5728519877504674, 1.584291664941221, 1.5954887690834967, 1.6064549729490671, 1.6172010901939204, 1.6277371593406456, 1.6380725176254403, 1.6482158661538315, 1.658175327573506, 1.6679584972800467, 1.6775724890132342, 1.6870239755710472, 1.6963192252602786, 1.7054641346125685, 1.7144642578192797, 1.7233248332753461, 1.7320508075688772, 1.740646857208154, 1.7491174083393233, 1.7574666546754452, 1.7656985738296271, 1.7738169422210552, 1.7818253487021418, 1.7897272070372605, 1.797525767348191, 1.8052241266280664, 1.8128252384140608, 1.8203319216989462, 1.8277468691528411, 1.8350726547187575, 1.8423117406387628, 1.8494664839616353, 1.8565391425776125, 1.8635318808212185, 1.8704467746790285, 1.8772858166356072, 1.8840509201876072, 1.8907439240531478, 1.8973665961010275, 1.9039206370220298, 1.9104076837625343, 1.9168293127388174, 1.9231870428487672, 1.9294823382962738, 1.9357166112422137, 1.9418912242947493, 1.9480074928505935, 1.9540666872978918, 1.960070035090509, 1.9660187227026953, 1.971913897472381, 1.9777566693406925, 1.983548112494678, 1.9892892669196895, 1.994981139867362, 2.0006247072446897, 2.006220914929266, 2.0117706800153967, 2.017274891995427, 2.0227344138803187, 2.028150083263225, 2.0335227133295235, 2.038853093816547, 2.04414199192601, 2.04939015319192, 2.0545983023065815, 2.0597671439071177, 2.0648973633247656], [0.0, 0.6602195804079635, 0.7851378224852613, 0.8688978326173193, 0.9336914847572161, 0.9872585449014338, 1.0332994847589596, 1.0738976950655401, 1.1103525568907362, 1.1435338574183984, 1.1740548859440185, 1.2023656804317462, 1.2288070992040006, 1.2536440342258928, 1.2770867797569627, 1.2993053150100684, 1.320439160815927, 1.3406043695144154, 1.3598985994884667, 1.3784048752090223, 1.396194423768335, 1.4133288490453375, 1.4298618220045207, 1.4458404116764367, 1.461306145339252, 1.4762958618685948, 1.4908424051821463, 1.5049751926796753, 1.5187206849628934, 1.5321027768596667, 1.5451431251708252, 1.5578614251281528, 1.5702756449705226, 1.5824022260821626, 1.5942562546302799, 1.6058516094725332, 1.6172010901939204, 1.6283165284159498, 1.6392088849530073, 1.6498883349376223, 1.6603643426724284, 1.6706457276725586, 1.680740723123322, 1.6906570277827762, 1.7004018521985302, 1.7099819599758033, 1.7194037047240815, 1.7286730632183713, 1.7377956652346387, 1.7467768204548835, 1.7556215427832071, 1.7643345723684827, 1.772920395590378, 1.7813832632323923, 1.7897272070372607, 1.7979560548158353, 1.8060734442596786, 1.8140828355896175, 1.8219875231569418, 1.8297906461004336, 1.8374951981506855, 1.8451040366629305, 1.8526198909506784, 1.8600453699846249, 1.8673829695144322, 1.8746350786649426, 1.881803986053052, 1.8888918854667822, 1.8959008811439186, 1.9028329926838916, 1.9096901596233076, 1.9164742457026112, 1.9231870428487672, 1.9298302748965297, 1.9364056010687778, 1.9429146192345599, 1.949358868961793, 1.9557398343800885, 1.9620589468678131, 1.9683175875762793, 1.9745170898028677, 1.9806587412238905, 1.986743785997105, 1.9927734267429793, 1.9987488264130728, 2.004671110053224, 2.0105413664686305, 2.0163606497973583, 2.0221299809982973, 2.0278503492591406, 2.0335227133295235, 2.039148002784094, 2.0447271192199157, 2.0502609373922973, 2.0557503062928357, 2.0611960501732, 2.066598969517919, 2.071959841969225, 2.077279423206778, 2.082558447784909, 2.087797629929844, 2.0929976642991988], [0.0, 0.668740304976422, 0.7952707287670506, 0.8801117367933934, 0.9457416090031757, 0.9999999999999999, 1.0466351393921054, 1.0877573059372772, 1.1246826503806981, 1.158292185288269, 1.189207115002721, 1.2178832856309065, 1.2446659545769567, 1.2698234324738655, 1.2935687276168015, 1.3160740129524924, 1.337480609952844, 1.3579060687170441, 1.3774493079968597, 1.396194423768335, 1.414213562373095, 1.4315691227432643, 1.4483154685151656, 1.464500276187315, 1.4801656089845705, 1.4953487812212205, 1.5100830606950981, 1.5243982444638442, 1.5383211346269174, 1.5518759343963227, 1.565084580073287, 1.5779670210741878, 1.5905414575341013, 1.602824543028034, 1.6148315584236828, 1.6265765616977856, 1.63807251762544, 1.6493314105258192, 1.6603643426724282, 1.6711816205169885, 1.6817928305074292, 1.6922069059826197, 1.7024321863844938, 1.7124764698304722, 1.722347059926734, 1.7320508075688772, 1.741594148365405, 1.7509831362269535, 1.7602234735867868, 1.7693205386531028, 1.7782794100389228, 1.7871048890689831, 1.7958015200236968, 1.8043736085467281, 1.8128252384140608, 1.8211602868378718, 1.829382438457389, 1.8374951981506853, 1.8455019027856028, 1.853405732014319, 1.8612097182041991, 1.8689167555872028, 1.8765296087010728, 1.8840509201876074, 1.8914832180063514, 1.8988289221159416, 1.906090350669923, 1.9132697257691151, 1.9203691788083757, 1.927390755451873, 1.9343364202676692, 1.9412080610494473, 1.9480074928505935, 1.954736461753492, 1.961396648394778, 1.9679896712654303, 1.9745170898028677, 1.9809804072907224, 1.9873810735805804, 1.993720487648747, 1.9999999999999998, 2.006220914929266, 2.0123844926512717, 2.0184919513073796, 2.0245444688580787, 2.0305431848689306, 2.03648920219714, 2.042383588585367, 2.0482273781688902, 2.0540215729017546, 2.0597671439071177, 2.0654650327566206, 2.0711161526832442, 2.0767213897317967, 2.082281603850872, 2.087797629929844, 2.093270278784211, 2.0987003380923746, 2.1040885732867167, 2.1094357284016496, 2.114742526881128, 2.1200096723479462], [0.0, 0.6769472427712399, 0.8050304775850328, 0.8909126743510708, 0.9573479717381596, 1.0122722344290394, 1.0594796911843958, 1.1011065185976396, 1.1384850195244434, 1.172507018523451, 1.203801343502716, 1.2328294348193778, 1.259940786957369, 1.2854070033206724, 1.309443706292189, 1.3322251817654118, 1.3538944855424797, 1.3745706103249549, 1.3943536888187151, 1.4133288490453375, 1.4315691227432643, 1.449137674618944, 1.4660895354719874, 1.4824729668980785, 1.498330548331831, 1.5137000520175456, 1.5286151540232695, 1.5431060170831206, 1.5571997722182047, 1.5709209196680187, 1.584291664941221, 1.5973322022781031, 1.6100609551700655, 1.6224947815686919, 1.634649149872069, 1.6465382905797215, 1.658175327573506, 1.66957239224697, 1.680740723123322, 1.691690753137475, 1.702432186384494, 1.7129740658352777, 1.7233248332753464, 1.7334923825224455, 1.7434841068143216, 1.7533069411223694, 1.7629674000343882, 1.772471611756025, 1.7818253487021416, 1.7910340550835677, 1.800102871839254, 1.80903665921692, 1.8178400172654527, 1.8265173044683851, 1.8350726547187572, 1.8435099928108027, 1.8518330486025056, 1.8600453699846247, 1.868150334775826, 1.876151161649724, 1.8840509201876072, 1.8918525401401285, 1.8995588199720859, 1.907172434756397, 1.914695943476319, 1.9221317957887885, 1.929482338296274, 1.9367498203697375, 1.943936399561014, 1.9510441466391415, 1.9580750502818227, 1.965031021450187, 1.971913897472381, 1.9787254458591215, 1.9854673678722108, 1.9921413018651277, 1.9987488264130728, 2.005291463248328, 2.011770680015397, 2.0181878928591512, 2.0245444688580787, 2.0308417283137197, 2.037080946906452, 2.0432633577269526, 2.04939015319192, 2.0554624868519302, 2.0614814750987107, 2.0674481987785094, 2.0733637047177553, 2.0792290071667088, 2.0850450891663783, 2.0908129038435934, 2.0965333756387428, 2.1022074014703853, 2.1078358518406057, 2.1134195718847355, 2.1189593823687916, 2.1244560806377484, 2.1299104415175543, 2.135323218173586, 2.1406951429280725, 2.146026928038831], [0.0, 0.6848661007688606, 0.8144476398584994, 0.9013344775740003, 0.9685469281169012, 1.0241136890844451, 1.0718733737282617, 1.1139871474119825, 1.151802898130648, 1.1862228829132528, 1.2178832856309068, 1.247250944521753, 1.2746794424196197, 1.3004435599166835, 1.3247614417239146, 1.347809412512947, 1.3697322015377211, 1.3906501934639681, 1.41066469233948, 1.4298618220045207, 1.4483154685151656, 1.4660895354719874, 1.4832396974191329, 1.4998147805113802, 1.515857862273113, 1.5314071568043932, 1.5464967341123872, 1.5611571097717196, 1.575415732179342, 1.5892973881759884, 1.602824543028034, 1.616017627205879, 1.6288952797169989, 1.64147455571553, 1.6537711045472616, 1.665799323178612, 1.6775724890132344, 1.6891028753564483, 1.7004018521985305, 1.7114799745177747, 1.7223470599267343, 1.7330122571800355, 1.7434841068143219, 1.7537705949883926, 1.7638792014253157, 1.7738169422210555, 1.7835904081703775, 1.793205799166037, 1.8026689551480006, 1.8119853840129068, 1.821160286837872, 1.8301985807252845, 1.8391049195349223, 1.8478837127354024, 1.8565391425776128, 1.8650751797676193, 1.8734955977948946, 1.881803986053052, 1.890003761874127, 1.898098181583441, 1.9060903506699232, 1.9139832331561426, 1.9217796602430461, 1.9294823382962742, 1.9370938562338025, 1.9446166923683978, 1.9520532207528385, 1.9594057170709935, 1.9666763641135123, 1.9738672568730735, 1.9809804072907224, 1.9880177486818125, 1.9949811398673623, 2.001872369034244, 2.0086931573454425, 2.0154451623197245, 2.0221299809982978, 2.0287491529145085, 2.0353041628812134, 2.0417964436091975, 2.0482273781688902, 2.0545983023065815, 2.0609105066254236, 2.0671652386406607, 2.0733637047177553, 2.079507071901399, 2.085596469642752, 2.091632991431688, 2.0976176963403033, 2.1035516104834504, 2.1094357284016496, 2.115271014371307, 2.12105840364682, 2.126798803638806, 2.132493095032392, 2.138142132849214, 2.1437467474565235, 2.149307745526554, 2.1548259109490866, 2.160302005699947, 2.1657367706679937, 2.1711309264429612], [0.0, 0.6925194237934933, 0.823549026052807, 0.9114068171194506, 0.9793703613355593, 1.0355580763416221, 1.0838514715804344, 1.126435863262952, 1.164674201923033, 1.1994788272386536, 1.231493032383988, 1.261188872476556, 1.2889238816096222, 1.314975911026152, 1.339565543186535, 1.362871073176282, 1.3850388475869866, 1.4061905963732368, 1.4264287556473267, 1.4458404116764367, 1.464500276187315, 1.4824729668980785, 1.4998147805113802, 1.5165750888103104, 1.5327974507070876, 1.5485205073412365, 1.563778709449485, 1.5786029136155246, 1.5930208749699124, 1.6070576573443134, 1.6207359770526288, 1.634076492874106, 1.647098052105614, 1.6598179004912506, 1.6722518622569729, 1.684414495254129, 1.6963192252602788, 1.7079784627339318, 1.7194037047240818, 1.7306056241600476, 1.7415941483654052, 1.75237852833137, 1.7629674000343885, 1.7733688388779358, 1.7835904081703775, 1.7936392024119798, 1.8035218860491045, 1.8132447282578046, 1.8228136342389012, 1.83223417343933, 1.8415116050578217, 1.8506509011449843, 1.8596567675671005, 1.868533663068241, 1.8772858166356075, 1.8859172433475835, 1.8944317588620798, 1.9028329926838916, 1.9111244003334624, 1.9193092745252844, 1.9273907554518732, 1.9353718402585094, 1.94325539178458, 1.951044146639142, 1.9587407226711187, 1.9663476258882207, 1.9738672568730735, 1.981301916740128, 1.9886538126725424, 1.9959250630743677, 2.003117702369927, 2.010233685479216, 2.017274891995427, 2.024243130088275, 2.0311401401546014, 2.0379675982358108, 2.0447271192199157, 2.0514202598444236, 2.058048521514854, 2.0646133529524175, 2.0711161526832442, 2.07755827138048, 2.0839410140696626, 2.090265642206917, 2.096533375638743, 2.102745394451461, 2.1089028407177555, 2.115006820147162, 2.12105840364682, 2.1270586287983337, 2.133008501256132, 2.138908996072332, 2.1447610589527217, 2.1505656074481596, 2.156323532085357, 2.1620356974407473, 2.1677029431608688, 2.1733260849324516, 2.178905915405181, 2.1844432050699005, 2.1899387030948425, 2.195393138122272], [0.0, 0.6999271023161167, 0.8323582900575635, 0.9211558703193815, 0.9898464007679532, 1.0466351393921056, 1.0954451150103324, 1.1384850195244434, 1.1771323825530848, 1.2123093028059742, 1.2446659545769567, 1.2746794424196195, 1.3027111248652612, 1.3290418252506464, 1.35389448554248, 1.3774493079968595, 1.3998542046322333, 1.4212322075130495, 1.4416868484808527, 1.461306145339252, 1.4801656089845705, 1.498330548331831, 1.515857862273113, 1.5327974507070876, 1.5491933384829668, 1.5650845800732875, 1.5805059947242717, 1.595488769083497, 1.610060955170066, 1.6242478849161492, 1.63807251762544, 1.6515557330581283, 1.664716580115127, 1.6775724890132344, 1.6901394532455423, 1.7024321863844938, 1.71446425781928, 1.726248210759469, 1.7377956652346387, 1.7491174083393233, 1.760223473586787, 1.771123210923403, 1.7818253487021418, 1.7923380487067173, 1.8026689551480006, 1.812825238414061, 1.8228136342389012, 1.8326404788581236, 1.842311740638763, 1.8518330486025056, 1.8612097182041993, 1.8704467746790288, 1.8795489742305571, 1.8885208232967414, 1.8973665961010278, 1.906090350669923, 1.9146959434763193, 1.9231870428487672, 1.9315671412704056, 1.9398395666769344, 1.9480074928505937, 1.9560739489962538, 1.9640418285762609, 1.9719138974723813, 1.9796928015359063, 1.9873810735805804, 1.9949811398673623, 2.0024953261250538, 2.0099258631464076, 2.017274891995427, 2.0245444688580787, 2.031736569565567, 2.038853093816547, 2.045895869122197, 2.0528666544958774, 2.0597671439071177, 2.066598969517919, 2.0733637047177553, 2.080062866972243, 2.086697920499143, 2.0932702787842112, 2.09978130694835, 2.1062323239765757, 2.1126246048184423, 2.1189593823687916, 2.1252378493369832, 2.1314611600121216, 2.1376304319311945, 2.1437467474565235, 2.1498111552684196, 2.1558246717785052, 2.1617882824687458, 2.1677029431608688, 2.1735695812205065, 2.1793890967000746, 2.18516236342413, 2.1908902300206647, 2.196573520901572, 2.2022130371952793, 2.207809557634348, 2.2133638394006434, 2.218876618930505], [0.0, 0.7071067811865476, 0.8408964152537146, 0.9306048591020997, 1.0, 1.057371263440564, 1.1066819197003217, 1.1501633168956031, 1.1892071150027212, 1.2247448713915892, 1.2574334296829355, 1.2877547884506972, 1.3160740129524926, 1.3426748071413253, 1.3677823998673806, 1.3915788418568702, 1.4142135623730951, 1.4358108555129505, 1.4564753151219703, 1.4762958618685948, 1.4953487812212205, 1.5137000520175456, 1.5314071568043932, 1.5485205073412365, 1.5650845800732875, 1.5811388300841898, 1.59671843378737, 1.611854897735313, 1.626576561697786, 1.6409090174556458, 1.6548754598234365, 1.6684969827407574, 1.6817928305074292, 1.6947806121350972, 1.7074764851741446, 1.7198953141251965, 1.7320508075688774, 1.7439556373798932, 1.7556215427832074, 1.7670594215246977, 1.778279410038923, 1.7892909541816906, 1.8001028718392544, 1.8107234085168835, 1.821160286837872, 1.8314207507423532, 1.8415116050578217, 1.8514392510154154, 1.8612097182041993, 1.8708286933869709, 1.880301546543197, 1.88963335445568, 1.898828922115942, 1.9078928021878638, 1.9168293127388176, 1.925642553421541, 1.9343364202676696, 1.9429146192345599, 1.9513806786303782, 1.9597379605279643, 1.9679896712654306, 1.9761388711204808, 1.984188483235881, 1.992141301865128, 2.0, 2.007767136435218, 2.0154451623197245, 2.023036427239071, 2.030543184868931, 2.0379675982358103, 2.0453117446175235, 2.052577620112862, 2.0597671439071177, 2.066882162257628, 2.0739244522212745, 2.080895725143909, 2.087797629929844, 2.0946317561079946, 2.101399636709763, 2.1081027509724937, 2.114742526881128, 2.121320343559643, 2.1278375335228743, 2.1342953847984933, 2.1406951429280725, 2.1470380128554885, 2.153325160710257, 2.1595577154927827, 2.1657367706679937, 2.171863385673303, 2.177938587346431, 2.1839633712781743, 2.1899387030948425, 2.1958655196747543, 2.201744730302841, 2.2075772177671347, 2.2133638394006434, 2.2191054280718734, 2.2248027931270298, 2.230456721286719, 2.23606797749979, 2.2416373057567642], [0.0, 0.7140741917751113, 0.8491821094987798, 0.9397744871152784, 1.0098534065489688, 1.0677899723724407, 1.1175865065755222, 1.161496343654686, 1.2009248561777692, 1.2368127805281748, 1.2698234324738655, 1.3004435599166833, 1.3290418252506462, 1.355904727879147, 1.381259715923798, 1.405290633930629, 1.4281483835502227, 1.449958483599742, 1.4708265585304046, 1.4908424051821463, 1.5100830606950981, 1.5286151540232695, 1.5464967341123872, 1.563778709449485, 1.5805059947242717, 1.59671843378737, 1.6124515496597098, 1.6277371593406456, 1.642603881843218, 1.6570775611145052, 1.6711816205169885, 1.6849373618374297, 1.6983642189975596, 1.7114799745177744, 1.7243009451553697, 1.7368421418769382, 1.7491174083393233, 1.7611395412783633, 1.772920395590378, 1.7844709764011661, 1.7958015200236968, 1.806921565387635, 1.8178400172654527, 1.8285652024087349, 1.839104919534922, 1.8494664839616353, 1.8596567675671003, 1.8696822346563884, 1.879548974230557, 1.8892627290863886, 1.8988289221159416, 1.9082526801256234, 1.9175388554524904, 1.9266920456196721, 1.9357166112422135, 1.9446166923683976, 1.9533962234190436, 1.962058946867813, 1.9706084257887257, 1.9790480553824932, 1.9873810735805801, 1.995610570814851, 2.003739499030986, 2.0117706800153967, 2.0197068130979376, 2.027550482286173, 2.035304162881213, 2.0429702276200308, 2.0505509523846825, 2.0580485215148534, 2.0654650327566206, 2.0728025018771485, 2.0800628669722427, 2.0872479924911636, 2.094359673000858, 2.101399636709763, 2.108369548769516, 2.115271014371307, 2.1221055816521197, 2.128874744424825, 2.1355799447448813, 2.142222575325334, 2.14880398181083, 2.1553254649205007, 2.1617882824687453, 2.1681936512722433, 2.1745427489508584, 2.1808367156294954, 2.187076655547436, 2.1932636385811617, 2.1993987016862424, 2.2054828502634343, 2.211517059453757, 2.217502275366972, 2.2234394162475644, 2.2293293735820354, 2.2351730131510443, 2.240971176029689, 2.2467246795389917, 2.252434318151437, 2.2581008643532257, 2.2637250694657207], [0.0, 0.7208434242404264, 0.85723212890964, 0.9486832980505139, 1.0194265469082735, 1.0779123358892526, 1.128180927925918, 1.172507018523451, 1.2123093028059742, 1.2485374350863452, 1.2818610191887023, 1.3127714172548886, 1.341640786499874, 1.3687583422648133, 1.3943536888187151, 1.4186124135047637, 1.4416868484808527, 1.4637037024489812, 1.4847696011519298, 1.5049751926796753, 1.5243982444638442, 1.5431060170831206, 1.5611571097717196, 1.5786029136155246, 1.595488769083497, 1.611854897735313, 1.6277371593406456, 1.6431676725154987, 1.6581753275735063, 1.672786213455457, 1.6870239755710472, 1.7009101176422836, 1.71446425781928, 1.7277043471959723, 1.7406468572081542, 1.7533069411223694, 1.7656985738296274, 1.777834673375402, 1.789727207037261, 1.801387284266654, 1.8128252384140613, 1.8240506988356506, 1.8350726547187575, 1.8458995117503458, 1.8565391425776128, 1.8669989318654352, 1.8772858166356075, 1.8874063224730853, 1.8973665961010278, 1.907172434756397, 1.9168293127388176, 1.9263424054554517, 1.9357166112422137, 1.944956571205524, 1.954066687297892, 1.963051138814152, 1.9719138974723813, 1.9806587412238905, 1.98928926691969, 1.9978089019460852, 2.0062209149292665, 2.0145284255975655, 2.022734413880319, 2.03084172831372, 2.038853093816547, 2.0467711188920665, 2.0545983023065815, 2.0623370392899774, 2.0699896272990626, 2.07755827138048, 2.0850450891663788, 2.092452115532857, 2.09978130694835, 2.1070345455365995, 2.1142136428765665, 2.121320343559643, 2.1283563285226585, 2.135323218173586, 2.1422225753253343, 2.149055907951721, 2.1558246717785052, 2.162530272721279, 2.1691740691810413, 2.175757374207393, 2.182281457538478, 2.188747547526072, 2.1951568329535602, 2.2015104647539276, 2.207809557634348, 2.2140551916134474, 2.2202484134768556, 2.226390238156261, 2.232481650036758, 2.2385236041969763, 2.244517027586113, 2.250462820141724, 2.256361855851836, 2.262214983764716, 2.26802302894937, 2.2737867934096694, 2.279507056954778, 2.285184578028384], [0.0, 0.727427152512826, 0.8650615454144222, 0.9573479717381597, 1.0287373447220802, 1.0877573059372772, 1.1384850195244434, 1.1832159566199234, 1.223381769812505, 1.259940786957369, 1.2935687276168018, 1.3247614417239146, 1.35389448554248, 1.3812597159237983, 1.4070888341971637, 1.4315691227432645, 1.454854305025652, 1.4770722470235311, 1.498330548331831, 1.5187206849628934, 1.5383211346269174, 1.5571997722182047, 1.575415732179342, 1.5930208749699124, 1.610060955170066, 1.626576561697786, 1.642603881843218, 1.6581753275735063, 1.6733200530681513, 1.6880643855478388, 1.7024321863844938, 1.7164451557015294, 1.7301230908288443, 1.7434841068143219, 1.7565448255334402, 1.7693205386531028, 1.7818253487021418, 1.7940722917112946, 1.8060734442596789, 1.8178400172654527, 1.8293824384573891, 1.8407104251401099, 1.8518330486025059, 1.8627587913037735, 1.8734955977948946, 1.8840509201876074, 1.8944317588620798, 1.9046446990038355, 1.9146959434763193, 1.9245913424647914, 1.9343364202676694, 1.943936399561014, 1.953396223419044, 1.9627205753371124, 1.9719138974723813, 1.9809804072907227, 1.9899241127853764, 1.998748826413073, 2.0074581778761864, 2.016055625864603, 2.0245444688580787, 2.0329278550785728, 2.0412087916722124, 2.04939015319192, 2.0574746894441605, 2.065465032756621, 2.0733637047177553, 2.0811731224339662, 2.08889560434558, 2.096533375638743, 2.1040885732867167, 2.1115632507508724, 2.1189593823687916, 2.126278867454344, 2.133523534132309, 2.1406951429280725, 2.1477953901310802, 2.1548259109490866, 2.1617882824687458, 2.1686840264367557, 2.1755146118745543, 2.182281457538478, 2.1889859342363023, 2.1956293670101927, 2.2022130371952797, 2.208738184362327, 2.2152060081523164, 2.2216176700101276, 2.227974294823965, 2.2342769724766613, 2.2405267593145264, 2.2467246795389917, 2.252871726525904, 2.2589688640769774, 2.2650170276075774, 2.2710171252747196, 2.2769700390488867, 2.2828766257330146, 2.2887377179317685, 2.2945541249740162, 2.3003266337912063, 2.306056009754172], [0.0, 0.7338368215846426, 0.8726839694794393, 0.9657835706352028, 1.0378019856537666, 1.0973419967718494, 1.148516693752116, 1.1936417741003793, 1.2341615053034112, 1.2710426594494582, 1.3049669101523764, 1.33643447648928, 1.3658242239094178, 1.3934305809385557, 1.4194872905246418, 1.444183285272829, 1.4676736431692852, 1.4900873568745734, 1.5115329740892764, 1.5321027768596667, 1.5518759343963227, 1.5709209196680187, 1.5892973881759884, 1.6070576573443134, 1.6242478849161492, 1.6409090174556458, 1.6570775611145052, 1.672786213455457, 1.6880643855478388, 1.7029386365926404, 1.7174330382144527, 1.7315694817456764, 1.7453679389588785, 1.75884668452131, 1.7720224867708416, 1.7849107721157376, 1.797525767348191, 1.8098806233649336, 1.8219875231569418, 1.8338577764265276, 1.845501902785603, 1.8569297051620812, 1.868150334775826, 1.8791723488285783, 1.8900037618741268, 1.9006520916879264, 1.9111244003334622, 1.9214273310211205, 1.9315671412704056, 1.9415497328150402, 1.951380678630378, 1.9610652474116927, 1.970608425788726, 1.9800149385250942, 1.9892892669196898, 1.9984356656002646, 2.0074581778761864, 2.0163606497973583, 2.0251467430490013, 2.033819946796984, 2.042383588585367, 2.050840844376428, 2.0591947478135326, 2.06744819877851, 2.075603971307533, 2.083664720922846, 2.091632991431688, 2.09951122123861, 2.1073017492127, 2.115006820147162, 2.1226285898450357, 2.1301691298616108, 2.1376304319311945, 2.145014412103317, 2.152322914611139, 2.159557715492783, 2.16672052598442, 2.173812995702313, 2.180836715629496, 2.1877932209214217, 2.194683993543699, 2.2015104647539276, 2.208274017438652, 2.2149759883155467, 2.2216176700101276, 2.228200313015543, 2.2347251275433204, 2.241193285272322, 2.24760592100262, 2.253964134220466, 2.260268990580086, 2.266521523307584, 2.272722734531862, 2.2788735965471, 2.2849750530110056, 2.29102802008275, 2.297033387504232, 2.302992019628042, 2.308904756395278, 2.3147724142661468, 2.320595787106084, 2.3263756470299297], [0.0, 0.7400828044922851, 0.8801117367933933, 0.9740037464252967, 1.0466351393921054, 1.1066819197003215, 1.158292185288269, 1.203801343502716, 1.2446659545769565, 1.281861019188702, 1.3160740129524924, 1.3478094125129467, 1.3774493079968597, 1.4052906339306293, 1.4315691227432643, 1.45647531512197, 1.4801656089845703, 1.502770094900495, 1.5243982444638442, 1.5451431251708252, 1.565084580073287, 1.584291664941221, 1.602824543028034, 1.6207359770526288, 1.63807251762544, 1.6548754598234365, 1.6711816205169885, 1.6870239755710472, 1.7024321863844938, 1.7174330382144527, 1.732050807568877, 1.74630757210618, 1.7602234735867865, 1.7738169422210552, 1.7871048890689831, 1.8001028718392538, 1.8128252384140608, 1.8252852516227527, 1.8374951981506853, 1.8494664839616353, 1.8612097182041991, 1.872734787242987, 1.8840509201876072, 1.8951667470736167, 1.9060903506699227, 1.9168293127388174, 1.927390755451873, 1.9377813785625346, 1.9480074928505935, 1.9580750502818227, 1.9679896712654303, 1.9777566693406925, 1.9873810735805801, 1.9968676489630897, 2.006220914929266, 2.015445162319724, 2.0245444688580787, 2.033522713329523, 2.042383588585367, 2.0511306134891862, 2.0597671439071177, 2.068296382833342, 2.0767213897317967, 2.0850450891663788, 2.093270278784211, 2.1013996367097625, 2.109435728401649, 2.1173810130186723, 2.1252378493369832, 2.133008501256132, 2.140695142928072, 2.1482998635399415, 2.1558246717785052, 2.1632715000015685, 2.1706422081393097, 2.177938587346431, 2.1851623634241295, 2.1923152000292214, 2.1993987016862424, 2.2064144166169766, 2.213363839400643, 2.2202484134768556, 2.2270695335024673, 2.2338285475724984, 2.2405267593145264, 2.247165429865153, 2.2537457797365072, 2.2602689905800855, 2.266736206854704, 2.2731485374047877, 2.2795070569547775, 2.2858128075249846, 2.2920667997738366, 2.2982700142711043, 2.3044234027063477, 2.3105278890365413, 2.316584370576538, 2.3225937190357833, 2.3285567815044543, 2.3344743813919835, 2.3403473193207156, 2.3461763739772747], [0.0, 0.7461745347323253, 0.8873560657375262, 0.9820209142881303, 1.0552501469158886, 1.1157911810902938, 1.167826258352922, 1.2137100091313509, 1.2549109828200413, 1.2924122054704554, 1.3269068114098672, 1.3589034297042373, 1.3887872955203007, 1.4168577874961457, 1.4433525784090198, 1.4684637773145044, 1.4923490694646506, 1.5151396162234685, 1.5369457902618242, 1.5578614251281528, 1.5779670210741878, 1.5973322022781031, 1.616017627205879, 1.634076492874106, 1.6515557330581283, 1.6684969827407574, 1.6849373618374297, 1.7009101176422836, 1.7164451557015294, 1.7315694817456764, 1.74630757210618, 1.760681686165901, 1.7747121314750525, 1.7884174899457608, 1.8018148118354411, 1.8149197829105617, 1.8277468691528413, 1.8403094425599245, 1.8526198909506784, 1.8646897141730423, 1.876529608701073, 1.8881495422754992, 1.8995588199720859, 1.9107661428614797, 1.921779660243046, 1.9326070162856752, 1.9432553917845798, 1.9537315416398595, 1.9640418285762606, 1.9741922535510608, 1.984188483235881, 1.9940358749065197, 2.003739499030986, 2.0133041598085097, 2.0227344138803187, 2.0320345874055676, 2.041208791672212, 2.050260937392297, 2.0591947478135326, 2.068013770763778, 2.0767213897317967, 2.0853208340760854, 2.0938151884434775, 2.1022074014703858, 2.110500293831777, 2.1186965656961565, 2.126798803638806, 2.134809487060224, 2.1427309941519956, 2.1505656074481596, 2.158315518996434, 2.1659828351803623, 2.173569581220506, 2.181077705380191, 2.1885090828989533, 2.195865519674754, 2.203148755714112, 2.210360468367647, 2.2175022753669724, 2.2245757376775126, 2.2315823621805877, 2.238523604196976, 2.245400869863155, 2.2522155183705133, 2.2589688640769774, 2.2656621784997513, 2.2722966921971777, 2.2788735965470996, 2.2853940454285424, 2.291859156812992, 2.2982700142711043, 2.3046276684002125, 2.3109331381776226, 2.3171874122443183, 2.3233914501233563, 2.3295461833769373, 2.335652516705844, 2.3417113289946903, 2.3477234743061772, 2.353689782827341, 2.359611061770567, 2.365488096231962], [0.0, 0.7521206186172786, 0.8944271909999159, 0.989846400767953, 1.0636591793889976, 1.1246826503806981, 1.1771323825530846, 1.223381769812505, 1.2649110640673518, 1.3027111248652612, 1.337480609952844, 1.369732201537721, 1.3998542046322333, 1.4281483835502227, 1.4548543050256517, 1.4801656089845703, 1.5042412372345573, 1.5272133963327195, 1.5491933384829668, 1.5702756449705226, 1.5905414575341013, 1.6100609551700655, 1.6288952797169989, 1.647098052105614, 1.664716580115127, 1.6817928305074292, 1.6983642189975596, 1.71446425781928, 1.7301230908288443, 1.7453679389588785, 1.7602234735867865, 1.7747121314750525, 1.7888543819998317, 1.8026689551480006, 1.8161730370463407, 1.8293824384573887, 1.8423117406387628, 1.8549744221463136, 1.8673829695144324, 1.879548974230557, 1.8914832180063517, 1.9031957480130535, 1.9146959434763193, 1.9259925748035172, 1.9370938562338025, 1.9480074928505935, 1.9587407226711184, 1.9693003544236372, 1.979692801535906, 1.9899241127853762, 2.0, 2.0099258631464076, 2.0197068130979376, 2.0293476923373186, 2.038853093816547, 2.0482273781688902, 2.0574746894441605, 2.0665989695179188, 2.075603971307533, 2.0844932709126422, 2.0932702787842112, 2.101938250014711, 2.110500293831777, 2.1189593823687916, 2.127318358777995, 2.1355799447448813, 2.143746747456523, 2.15182126607116, 2.159805897731609, 2.1677029431608688, 2.1755146118745543, 2.1832430270414687, 2.1908902300206643, 2.1984581846007054, 2.2059487809644573, 2.213363839400643, 2.220705113781472, 2.2279742948239645, 2.2351730131510443, 2.2423028421670907, 2.2493653007613963, 2.256361855851836, 2.263293924780049, 2.2701628775684908, 2.2769700390488867, 2.283716690870853, 2.290404073398753, 2.297033387504232, 2.3036057962612957, 2.3101224265502753, 2.316584370576538, 2.322992687309372, 2.329348403846066, 2.335652516705844, 2.3419059930579698, 2.348109771888037, 2.354264765106169, 2.3603718586005993, 2.3664319132398464, 2.3724457658265057, 2.378414230005442, 2.3843380971290036], [0.0, 0.7579289311365565, 0.9013344775740003, 0.9974905699336811, 1.0718733737282617, 1.133368103427352, 1.1862228829132528, 1.2328294348193778, 1.2746794424196195, 1.3127714172548886, 1.347809412512947, 1.3803100696313728, 1.41066469233948, 1.4391773753505155, 1.4660895354719874, 1.4915963080299905, 1.515857862273113, 1.5390074257343278, 1.5611571097717194, 1.5824022260821626, 1.602824543028034, 1.6224947815686919, 1.64147455571553, 1.6598179004912506, 1.6775724890132344, 1.6947806121350972, 1.7114799745177744, 1.7277043471959723, 1.7434841068143219, 1.75884668452131, 1.7738169422210552, 1.7884174899457608, 1.8026689551480006, 1.8165902124584952, 1.8301985807252845, 1.8435099928108025, 1.8565391425776128, 1.8692996126708072, 1.8818039860530522, 1.8940639437279883, 1.9060903506699232, 1.9178933316401892, 1.9294823382962742, 1.9408662087757294, 1.9520532207528385, 1.963051138814152, 1.9738672568730735, 1.9845084362388192, 1.9949811398673623, 2.005291463248328, 2.0154451623197245, 2.025447678749862, 2.0353041628812134, 2.0450194945929727, 2.0545983023065815, 2.0640449803306513, 2.0733637047177558, 2.082558447784909, 2.091632991431688, 2.100590939374452, 2.1094357284016496, 2.118170638743468, 2.126798803638806, 2.135323218173586, 2.1437467474565235, 2.152072134191548, 2.160302005699947, 2.168438880439912, 2.1764851740663906, 2.1844432050699005, 2.192315200029222, 2.2001032985094997, 2.207809557634348, 2.215435956357848, 2.2229843994599547, 2.230456721286719, 2.2378546892547706, 2.2451800071378294, 2.2524343181514372, 2.259619207850716, 2.266736206854704, 2.2737867934096694, 2.2807723958027863, 2.2876943946366195, 2.2945541249740162, 2.301352878362235, 2.308091904744454, 2.3147724142661468, 2.3213955789832528, 2.327962534478528, 2.3344743813919835, 2.340932186870885, 2.3473369859443625, 2.3536897828273413, 2.3599915521581276, 2.366243240173708, 2.3724457658265057, 2.3786000218460974, 2.384706875749129, 2.3907671708004723, 2.39678172692843, 2.402751341596634], [0.0, 0.7636066981663598, 0.9080865185231703, 1.0049629315732038, 1.0799029488658043, 1.1418583454354265, 1.1951090685408468, 1.2420647575928365, 1.2842282703036343, 1.3226055982240474, 1.3579060687170441, 1.3906501934639681, 1.4212322075130497, 1.4499584835997423, 1.4770722470235311, 1.502770094900495, 1.5272133963327197, 1.5505363768819687, 1.5728519877504674, 1.5942562546302799, 1.6148315584236828, 1.634649149872069, 1.6537711045472616, 1.6722518622569729, 1.6901394532455423, 1.7074764851741446, 1.7243009451553697, 1.7406468572081542, 1.7565448255334402, 1.7720224867708416, 1.7871048890689831, 1.8018148118354411, 1.8161730370463407, 1.8301985807252845, 1.8439088914585777, 1.8573200214642784, 1.8704467746790288, 1.8833028354976902, 1.8959008811439186, 1.9082526801256234, 1.9203691788083759, 1.9322605777997166, 1.943936399561014, 1.9554055484377233, 1.966676364113512, 1.9777566693406927, 1.9886538126725422, 1.9993747068174432, 2.0099258631464076, 2.0203134228113497, 2.0305431848689306, 2.040620631751871, 2.0505509523846825, 2.060339063202517, 2.069989627299062, 2.079507071901399, 2.08889560434558, 2.098159226705883, 2.1073017492127, 2.116326802578406, 2.1252378493369832, 2.134038194291349, 2.1427309941519956, 2.151319266441514, 2.1598058977316086, 2.1681936512722437, 2.17648517406639, 2.184683003438414, 2.1927895731393208, 2.2008072190278125, 2.2087381843623266, 2.2165846247358343, 2.224348612682192, 2.232032141980142, 2.2396371316786525, 2.2471654298651536, 2.254618817196276, 2.2619990102089815, 2.2693076644284034, 2.27654637728731, 2.283716690870853, 2.2908200944990793, 2.297858027158692, 2.3048318797945697, 2.31174299747073, 2.3185926814096187, 2.325382190917938, 2.332112745206556, 2.338785525111471, 2.34540167472227, 2.3519623029240355, 2.358468484858204, 2.3649212633074757, 2.371321650009509, 2.3776706269037833, 2.3839691473156965, 2.3902181370816935, 2.396418495618929, 2.402571096942758, 2.408676790635081, 2.414736402766418, 2.420750736774327], [0.0, 0.7691605673134586, 0.9146912192286943, 1.0122722344290391, 1.087757305937277, 1.150163316895603, 1.2038013435027157, 1.2510985509742438, 1.2935687276168015, 1.3322251817654118, 1.3677823998673804, 1.4007646793929585, 1.4315691227432643, 1.460504330965901, 1.4878152983881652, 1.5137000520175452, 1.5383211346269172, 1.561813748028264, 1.584291664941221, 1.6058516094725332, 1.6265765616977856, 1.6465382905797215, 1.665799323178612, 1.684414495254129, 1.7024321863844938, 1.7198953141251965, 1.7368421418769382, 1.7533069411223694, 1.7693205386531028, 1.7849107721157376, 1.8001028718392538, 1.8149197829105617, 1.8293824384573887, 1.8435099928108025, 1.8573200214642784, 1.8708286933869704, 1.8840509201876072, 1.8970004857904796, 1.9096901596233076, 1.9221317957887885, 1.9343364202676694, 1.9463143078586156, 1.9580750502818227, 1.9696276166458888, 1.9809804072907222, 1.9921413018651275, 2.003117702369927, 2.013916571791058, 2.0245444688580783, 2.0350075793887674, 2.0453117446175235, 2.0554624868519302, 2.0654650327566206, 2.075324334524993, 2.0850450891663783, 2.094631756107994, 2.1040885732867167, 2.1134195718847355, 2.1226285898450357, 2.131719284286912, 2.140695142928072, 2.149559494607946, 2.158315518996434, 2.1669662555631914, 2.175514611874554, 2.183963371278174, 2.1923152000292214, 2.2005726539065464, 2.2087381843623266, 2.2168141442444482, 2.2248027931270293, 2.232706302281114, 2.240526759314526, 2.248266172507171, 2.2559264748656567, 2.263509527918935, 2.271017125274719, 2.2784509959547, 2.2858128075249846, 2.293104169036802, 2.300326633791206, 2.3074817019403757, 2.3145708229370623, 2.3215953978427732, 2.3285567815044543, 2.3354562846086107, 2.342295175621143, 2.3490746826204902, 2.3557959950311154, 2.362460265263805, 2.3690686102687932, 2.37562211300724, 2.3821218238462203, 2.3885687618819693, 2.394963916195815, 2.401308247046888, 2.4076026870054315, 2.413848142030249, 2.4200454924935872, 2.426195594156533, 2.432299279097787, 2.438357356598474], [0.0, 0.7745966692414834, 0.9211558703193814, 1.0194265469082735, 1.0954451150103321, 1.158292185288269, 1.2123093028059742, 1.259940786957369, 1.3027111248652612, 1.3416407864998738, 1.3774493079968597, 1.41066469233948, 1.4416868484808527, 1.4708265585304046, 1.4983305483318308, 1.5243982444638442, 1.5491933384829668, 1.5728519877504674, 1.5954887690834967, 1.6172010901939204, 1.63807251762544, 1.658175327573506, 1.6775724890132344, 1.6963192252602788, 1.71446425781928, 1.7320508075688774, 1.7491174083393233, 1.7656985738296274, 1.7818253487021418, 1.797525767348191, 1.8128252384140608, 1.8277468691528413, 1.8423117406387628, 1.8565391425776128, 1.8704467746790288, 1.8840509201876072, 1.8973665961010278, 1.9104076837625343, 1.9231870428487674, 1.9357166112422135, 1.9480074928505937, 1.9600700350905091, 1.9719138974723813, 1.9835481124946783, 1.9949811398673623, 2.006220914929266, 2.017274891995427, 2.028150083263225, 2.038853093816547, 2.04939015319192, 2.0597671439071177, 2.069989627299062, 2.080062866972243, 2.0899918501200694, 2.09978130694835, 2.1094357284016496, 2.1189593823687916, 2.1283563285226585, 2.1376304319311945, 2.1467853755606696, 2.1558246717785052, 2.164751672950963, 2.173569581220506, 2.182281457538478, 2.1908902300206643, 2.1993987016862424, 2.207809557634348, 2.2161253717069958, 2.2243486126821925, 2.2324816500367577, 2.2405267593145264, 2.248486127132168, 2.256361855851836, 2.264155967947111, 2.271870410086274, 2.2795070569547775, 2.287067714836797, 2.2945541249740162, 2.301967966718197, 2.3093108604926607, 2.316584370576538, 2.32379000772445, 2.3309292316332666, 2.338003453266607, 2.345014037046902, 2.3519623029240355, 2.3588495283288893, 2.365676950019442, 2.3724457658265057, 2.3791571363056208, 2.385812186301152, 2.3924120064281724, 2.3989576544773072, 2.405450156747334, 2.4118905093099885, 2.418279679211108, 2.4246186056119483, 2.4309082008742458, 2.4371493515923475, 2.4433429195754983, 2.4494897427831783, 2.45559063621617], [0.0, 0.7799206709850829, 0.9274872110731568, 1.0264333272479387, 1.1029743904822287, 1.1662534248067802, 1.220641815839165, 1.2686006834079462, 1.311664992827256, 1.3508622280193734, 1.386916870676514, 1.4203605528819792, 1.451595932265776, 1.480935927022547, 1.508628958806044, 1.5348758249050471, 1.5598413419701658, 1.5836626032071637, 1.6064549729490671, 1.6283165284159498, 1.6493314105258192, 1.66957239224697, 1.6891028753564483, 1.7079784627339318, 1.726248210759469, 1.7439556373798932, 1.7611395412783633, 1.777834673375402, 1.7940722917112946, 1.8098806233649336, 1.8252852516227527, 1.8403094425599245, 1.8549744221463136, 1.8692996126708072, 1.8833028354976902, 1.8970004857904796, 1.9104076837625343, 1.9235384061671343, 1.936405601068778, 1.949021288402083, 1.9613966483947782, 1.9735420995839155, 1.9854673678722108, 1.9971815478408133, 2.0086931573454425, 2.0200101862665525, 2.0311401401546014, 2.0420900794036014, 2.0528666544958774, 2.0634761377851585, 2.0739244522212745, 2.0842171973656427, 2.094359673000858, 2.1043569005985905, 2.1142136428765665, 2.123934421646766, 2.133523534132309, 2.14298506790925, 2.152322914611139, 2.1615407825182174, 2.1706422081393097, 2.1796305668823517, 2.1885090828989533, 2.197280838179163, 2.2059487809644573, 2.214515733539884, 2.2229843994599543, 2.23135737025736, 2.2396371316786525, 2.2478260694866745, 2.2559264748656567, 2.2639405494614473, 2.271870410086274, 2.2797180931146976, 2.28748555859495, 2.295174694097678, 2.3027873183221113, 2.3103251844779353, 2.3177899834595275, 2.3251833468277954, 2.3325068496135604, 2.3397620129552488, 2.3469503065826007, 2.3540731511571518, 2.361131920479358, 2.3681279435714577, 2.375062506644442, 2.3819368549568463, 2.3887521945724806, 2.395509694023681, 2.402210485886156, 2.4088556682710576, 2.4154463062394758, 2.421983433144204, 2.4284680519032347, 2.4349011362091595, 2.44128363167833, 2.4476164569433796, 2.4539005046924456, 2.4601366426582087, 2.46632571455966, 2.4724685409992926], [0.0, 0.7851378224852613, 0.9336914847572162, 1.0332994847589596, 1.1103525568907362, 1.1740548859440185, 1.2288070992040003, 1.277086779756963, 1.3204391608159272, 1.3598985994884667, 1.396194423768335, 1.4298618220045207, 1.461306145339252, 1.4908424051821465, 1.5187206849628931, 1.5451431251708252, 1.5702756449705226, 1.5942562546302799, 1.6172010901939204, 1.6392088849530073, 1.6603643426724282, 1.680740723123322, 1.7004018521985305, 1.7194037047240818, 1.7377956652346387, 1.7556215427832074, 1.772920395590378, 1.789727207037261, 1.8060734442596789, 1.8219875231569418, 1.8374951981506853, 1.8526198909506784, 1.8673829695144324, 1.8818039860530522, 1.8959008811439186, 1.9096901596233076, 1.9231870428487674, 1.936405601068778, 1.9493588689617931, 1.9620589468678131, 1.9745170898028679, 1.986743785997105, 1.998748826413073, 2.0105413664686305, 2.0221299809982973, 2.0335227133295235, 2.0447271192199157, 2.0557503062928357, 2.066598969517919, 2.077279423206778, 2.087797629929844, 2.098159226705883, 2.1083695487695167, 2.118433651182726, 2.1283563285226585, 2.1381421328492136, 2.1477953901310802, 2.1573202152874846, 2.16672052598442, 2.1760000553080614, 2.18516236342413, 2.1942108483197984, 2.203148755714112, 2.2119791882135846, 2.2207051137814724, 2.2293293735820354, 2.2378546892547706, 2.2462836696680024, 2.254618817196276, 2.2628625335616044, 2.2710171252747196, 2.279084808709018, 2.2870677148367973, 2.29496789365461, 2.3027873183221113, 2.3105278890365413, 2.3181914366630214, 2.3257797261390447, 2.333294459669949, 2.340737279730703, 2.348109771888037, 2.355413467455784, 2.362649845995201, 2.3698203376711047, 2.376926325473765, 2.3839691473156965, 2.3909500980117886, 2.3978704311505283, 2.4047313608634924, 2.411534063499723, 2.418279679211108, 2.424969313454433, 2.431604038415341, 2.4381848943590683, 2.444712890912464, 2.4511890082814753, 2.4576141984080007, 2.463989386069716, 2.470315469926249, 2.476593323514836, 2.4828237961983883, 2.489007714068684], [0.0, 0.7902529973621358, 0.9397744871152784, 1.0400314334861216, 1.1175865065755222, 1.181703856461886, 1.236812780528175, 1.2854070033206721, 1.3290418252506462, 1.368758342264813, 1.4052906339306293, 1.4391773753505153, 1.4708265585304046, 1.5005552471800365, 1.5286151540232695, 1.5552097364952304, 1.5805059947242717, 1.60464283811593, 1.6277371593406456, 1.6498883349376223, 1.6711816205169885, 1.691690753137475, 1.7114799745177747, 1.7306056241600476, 1.7491174083393233, 1.7670594215246977, 1.7844709764011661, 1.801387284266654, 1.8178400172654527, 1.8338577764265276, 1.8494664839616353, 1.8646897141730423, 1.879548974230557, 1.8940639437279883, 1.9082526801256234, 1.9221317957887885, 1.9357166112422135, 1.949021288402083, 1.9620589468678131, 1.9748417658131499, 1.9873810735805804, 1.999687426731098, 2.011770680015397, 2.023640048498906, 2.035304162881213, 2.0467711188920665, 2.0580485215148534, 2.069143524679119, 2.080062866972243, 2.0908129038435934, 2.101399636709763, 2.1118287393147086, 2.1221055816521197, 2.1322352517177183, 2.142222575325334, 2.152072134191548, 2.1617882824687458, 2.1713751618848627, 2.180836715629496, 2.190176701109886, 2.1993987016862424, 2.208506137483634, 2.217502275366972, 2.226390238156261, 2.2351730131510443, 2.243853460025775, 2.252434318151437, 2.260918213393139, 2.269307664428403, 2.2776050886264665, 2.2858128075249846, 2.2939330519370325, 2.3019679667181965, 2.3099196152207635, 2.3177899834595275, 2.325580984011519, 2.333294459669949, 2.3409321868708846, 2.348495878909535, 2.355987188961597, 2.363407712923772, 2.370758992086407, 2.378042515650104, 2.385259723097208, 2.3924120064281724, 2.3995007122720162, 2.4065271438793503, 2.4134925630057946, 2.4203981916929957, 2.4272452139539125, 2.4340347773685256, 2.440767994595675, 2.447445944806294, 2.454069675042952, 2.460640201510217, 2.4671585108000826, 2.47362556105635, 2.4800422830816236, 2.4864095813903013, 2.492728335210717, 2.4989993994393833, 2.505223605550068], [0.0, 0.7952707287670507, 0.9457416090031758, 1.0466351393921056, 1.1246826503806981, 1.189207115002721, 1.2446659545769567, 1.2935687276168018, 1.3374806099528442, 1.3774493079968597, 1.4142135623730951, 1.4483154685151656, 1.4801656089845707, 1.5100830606950986, 1.5383211346269174, 1.5650845800732873, 1.5905414575341015, 1.6148315584236828, 1.6380725176254403, 1.6603643426724284, 1.6817928305074292, 1.702432186384494, 1.7223470599267343, 1.7415941483654052, 1.760223473586787, 1.778279410038923, 1.7958015200236968, 1.8128252384140613, 1.8293824384573891, 1.845501902785603, 1.8612097182041991, 1.876529608701073, 1.8914832180063517, 1.9060903506699232, 1.9203691788083759, 1.9343364202676694, 1.9480074928505937, 1.9613966483947782, 1.9745170898028679, 1.9873810735805804, 2.0000000000000004, 2.012384492651272, 2.0245444688580787, 2.0364892021971404, 2.0482273781688902, 2.0597671439071177, 2.0711161526832442, 2.082281603850872, 2.0932702787842112, 2.1040885732867167, 2.114742526881128, 2.1252378493369837, 2.1355799447448818, 2.145773933406904, 2.1558246717785057, 2.1657367706679937, 2.1755146118745547, 2.18516236342413, 2.1946839935436993, 2.204083283498255, 2.2133638394006434, 2.222529103092103, 2.231582362180588, 2.240526759314527, 2.2493653007613963, 2.2581008643532257, 2.2667362068547043, 2.275273970803937, 2.2837166908708535, 2.292066799773837, 2.300326633791206, 2.3084984379006395, 2.316584370576538, 2.324586508272497, 2.332506849613561, 2.340347319320716, 2.348109771888037, 2.3557959950311154, 2.3634077129237725, 2.370946589238585, 2.378414230005442, 2.3858121863011523, 2.393141956782034, 2.4004049900704616, 2.407602687005432, 2.414736402766418, 2.421807448879054, 2.428817095110509, 2.4357665712618135, 2.4426570688638467, 2.4494897427831783, 2.4562657127435017, 2.462986064767976, 2.4696518525473916, 2.4762640987387345, 2.4828237961983888, 2.4893319091539134, 2.4957893743180684, 2.502197101948488, 2.508555976856189, 2.514866859365871, 2.521130586230765], [0.0, 0.8001952410151443, 0.9515978740065267, 1.0531161619882878, 1.1316469623900245, 1.1965709783910168, 1.25237323276083, 1.3015788238173445, 1.345762619345434, 1.385978813413053, 1.4229707211083644, 1.4572837946534403, 1.489331159038138, 1.5194338669790928, 1.547846798020459, 1.5747759693135555, 1.6003904820302886, 1.6248309932078528, 1.6482158661538315, 1.6706457276725586, 1.6922069059826197, 1.7129740658352777, 1.7330122571800355, 1.75237852833137, 1.771123210923403, 1.7892909541816906, 1.806921565387635, 1.8240506988356506, 1.8407104251401099, 1.8569297051620812, 1.872734787242987, 1.8881495422754992, 1.9031957480130535, 1.9178933316401892, 1.9322605777997166, 1.9463143078586156, 1.9600700350905091, 1.9735420995839155, 1.986743785997105, 1.999687426731098, 2.012384492651272, 2.024845673131659, 2.037080946906452, 2.0490996449766428, 2.0609105066254236, 2.072521729435642, 2.0839410140696626, 2.095175604461257, 2.1062323239765757, 2.117117608023464, 2.127837533522874, 2.1383978456006427, 2.14880398181083, 2.159061094161688, 2.1691740691810413, 2.179147546228457, 2.1889859342363023, 2.1986934270399607, 2.208274017438652, 2.2177315101118924, 2.2270695335024673, 2.236291550764344, 2.245400869863155, 2.254400652907381, 2.263293924780049, 2.2720835811334323, 2.280772395802786, 2.2893630276894625, 2.297858027158692, 2.3062598419928486, 2.314570822937062, 2.322793228870466, 2.3309292316332666, 2.33898092053697, 2.3469503065826007, 2.3548393264094916, 2.362649845995201, 2.3703836641252947, 2.3780425156501046, 2.3856280745440763, 2.3931419567820336, 2.400585723045433, 2.407960881270643, 2.415268889050264, 2.4225111558976327, 2.4296890453838276, 2.436803877155773, 2.4438569288433487, 2.450849437862816, 2.4577826031233077, 2.46465758664261, 2.471475515078023, 2.478237481177628, 2.484944545156928, 2.491597736005454, 2.4981980527275995, 2.50474646552166, 2.5112439169007508, 2.5176913227590454, 2.524089573386529, 2.5304395344352426, 2.536742047839801], [0.0, 0.8050304775850329, 0.9573479717381597, 1.0594796911843958, 1.1384850195244434, 1.203801343502716, 1.259940786957369, 1.309443706292189, 1.35389448554248, 1.3943536888187151, 1.4315691227432645, 1.4660895354719874, 1.498330548331831, 1.52861515402327, 1.5571997722182047, 1.584291664941221, 1.6100609551700658, 1.634649149872069, 1.658175327573506, 1.680740723123322, 1.7024321863844938, 1.7233248332753464, 1.7434841068143219, 1.7629674000343885, 1.7818253487021418, 1.8001028718392544, 1.8178400172654527, 1.8350726547187575, 1.8518330486025059, 1.868150334775826, 1.8840509201876072, 1.8995588199720859, 1.9146959434763193, 1.9294823382962742, 1.943936399561014, 1.9580750502818227, 1.9719138974723813, 1.9854673678722108, 1.998748826413073, 2.011770680015397, 2.0245444688580787, 2.037080946906452, 2.04939015319192, 2.0614814750987107, 2.0733637047177553, 2.0850450891663788, 2.096533375638743, 2.1078358518406057, 2.1189593823687916, 2.1299104415175543, 2.1406951429280725, 2.151319266441514, 2.1617882824687458, 2.172107374149395, 2.182281457538478, 2.192315200029222, 2.2022130371952797, 2.211979188213584, 2.2216176700101276, 2.231132310254472, 2.2405267593145264, 2.249804501270612, 2.2589688640769774, 2.2680230289493704, 2.2769700390488867, 2.2858128075249846, 2.2945541249740162, 2.303196666363934, 2.31174299747073, 2.3201955808676797, 2.3285567815044543, 2.3368288719096273, 2.345014037046902, 2.3531143788525988, 2.361131920479358, 2.3690686102687937, 2.376926325473765, 2.384706875749129, 2.392412006428173, 2.4000434016004517, 2.407602687005432, 2.4150914327550987, 2.4225111558976327, 2.429863322833242, 2.4371493515923475, 2.4443706139855026, 2.4515284376336917, 2.4586241078869633, 2.4656588696387556, 2.472633929042694, 2.47955045513814, 2.4864095813903013, 2.4932124071502657, 2.499959999039964, 2.5066533922666703, 2.5132935918713324, 2.519881573914738, 2.526418286605205, 2.5329046513712625, 2.539341563882536, 2.5457298950218306, 2.5520704918112105], [0.0, 0.8097801259787746, 0.9629962874017586, 1.0657305800060608, 1.1452020366993765, 1.210903724439527, 1.2673743884191842, 1.317169373045755, 1.3618824101585059, 1.4025803211547638, 1.44001532468678, 1.4747394065031132, 1.5071706400803162, 1.5376339237631882, 1.5663871900896853, 1.5936389239222475, 1.6195602519575492, 1.644293516048505, 1.6679584972800467, 1.6906570277827762, 1.7124764698304722, 1.7334923825224455, 1.7537705949883926, 1.7733688388779358, 1.7923380487067173, 1.8107234085168835, 1.8285652024087349, 1.8458995117503458, 1.8627587913037735, 1.8791723488285783, 1.8951667470736167, 1.9107661428614797, 1.9259925748035172, 1.9408662087757294, 1.9554055484377233, 1.9696276166458888, 1.9835481124946783, 1.9971815478408133, 2.0105413664686305, 2.023640048498906, 2.0364892021971404, 2.0490996449766428, 2.0614814750987107, 2.0736441353327724, 2.0855964696427516, 2.097346773803644, 2.108902840717755, 2.120272001088022, 2.1314611600121216, 2.1424768299823924, 2.1533251607102564, 2.1640119661377195, 2.1745427489508584, 2.1849227228696226, 2.19515683295356, 2.2052497741333363, 2.2152060081523164, 2.225029779080412, 2.2347251275433204, 2.244295903793707, 2.2537457797365077, 2.263078260007981, 2.2722966921971777, 2.281404276288892, 2.290404073398753, 2.2992990138636866, 2.308091904744454, 2.316785436791214, 2.325382190917938, 2.3338846442269867, 2.342295175621143, 2.3506160710368085, 2.3588495283288893, 2.3669976618350463, 2.375062506644442, 2.38304602259383, 2.3909500980117886, 2.398776553230067, 2.4065271438793507, 2.414203563985258, 2.421807448879054, 2.429340377936324, 2.4368038771557736, 2.4441994215893144, 2.4515284376336917, 2.4587923051930876, 2.465992359721398, 2.4731298941521875, 2.480206160723717, 2.48722237270587, 2.494179706035296, 2.501079300864602, 2.5079222630310047, 2.5147096654494634, 2.521442549434933, 2.5281219259580654, 2.5347487768383683, 2.541324055878551, 2.547848689943536, 2.554323579987364, 2.5607496020310148, 2.5671276080939496], [0.0, 0.8144476398584993, 0.9685469281169012, 1.0718733737282615, 1.1518028981306478, 1.2178832856309065, 1.2746794424196195, 1.3247614417239144, 1.369732201537721, 1.4106646923394799, 1.4483154685151653, 1.4832396974191324, 1.515857862273113, 1.5464967341123872, 1.5754157321793416, 1.6028245430280337, 1.6288952797169987, 1.6537711045472614, 1.6775724890132342, 1.7004018521985302, 1.722347059926734, 1.7434841068143216, 1.7638792014253157, 1.7835904081703775, 1.8026689551480006, 1.821160286837872, 1.839104919534922, 1.8565391425776128, 1.8734955977948946, 1.8900037618741268, 1.9060903506699227, 1.921779660243046, 1.9370938562338025, 1.9520532207528385, 1.966676364113512, 1.9809804072907222, 1.9949811398673623, 2.0086931573454425, 2.0221299809982973, 2.035304162881213, 2.0482273781688902, 2.0609105066254236, 2.0733637047177553, 2.0855964696427516, 2.097617696340303, 2.1094357284016496, 2.12105840364682, 2.1324930950323915, 2.143746747456523, 2.154825910949086, 2.1657367706679933, 2.17648517406639, 2.187076655547436, 2.1975164588825846, 2.207809557634348, 2.217960673794632, 2.2279742948239645, 2.2378546892547706, 2.24760592100262, 2.2572318625127545, 2.266736206854704, 2.276122478865197, 2.285394045428542, 2.2945541249740162, 2.3036057962612957, 2.312552006517556, 2.3213955789832528, 2.3301392199178337, 2.338785525111471, 2.3473369859443625, 2.3557959950311154, 2.3641648514841025, 2.3724457658265057, 2.3806408645828756, 2.3887521945724806, 2.39678172692843, 2.4047313608634924, 2.4126029272016765, 2.4203981916929957, 2.4281188581273097, 2.435766571261813, 2.4433429195754983, 2.450849437862816, 2.4582876096777713, 2.4656588696387556, 2.4729646056036185, 2.480206160723717, 2.487384835384989, 2.4945018890435056, 2.5015585419623516, 2.5085559768561887, 2.515495340449381, 2.5223777449531117, 2.529204269466543, 2.535975961306694, 2.542693837271378, 2.549358884839239, 2.555972063310636, 2.5625343048928735, 2.569046515733026, 2.575509576901394, 2.5819243453284186], [0.0, 0.81903625881272, 0.9740037464252967, 1.0779123358892526, 1.158292185288269, 1.224744871391589, 1.281861019188702, 1.3322251817654118, 1.3774493079968597, 1.4186124135047637, 1.4564753151219703, 1.4915963080299908, 1.5243982444638442, 1.5552097364952309, 1.584291664941221, 1.6118548977353127, 1.63807251762544, 1.6630884934927144, 1.6870239755710472, 1.7099819599758033, 1.7320508075688772, 1.7533069411223694, 1.7738169422210555, 1.7936392024119798, 1.812825238414061, 1.8314207507423532, 1.8494664839616353, 1.8669989318654352, 1.8840509201876074, 1.9006520916879264, 1.9168293127388174, 1.9326070162856752, 1.9480074928505935, 1.963051138814152, 1.9777566693406927, 1.9921413018651275, 2.006220914929266, 2.0200101862665525, 2.0335227133295235, 2.0467711188920665, 2.0597671439071177, 2.072521729435642, 2.0850450891663788, 2.097346773803644, 2.1094357284016496, 2.1213203435596424, 2.133008501256132, 2.1445076159871213, 2.1558246717785052, 2.1669662555631914, 2.177938587346431, 2.188747547526072, 2.199398701686243, 2.20989732314194, 2.2202484134768556, 2.230456721286719, 2.2405267593145264, 2.2504628201417236, 2.260268990580086, 2.2699491648923114, 2.2795070569547775, 2.2889462114632346, 2.2982700142711043, 2.307481701940376, 2.316584370576538, 2.3255809840115185, 2.3344743813919835, 2.343267284224516, 2.3519623029240355, 2.3605619429072418, 2.3690686102687932, 2.3774846170743213, 2.385812186301152, 2.3940534564547304, 2.4022104858861564, 2.410285256833955, 2.418279679211108, 2.4261955941565336, 2.434034777368526, 2.441798942236141, 2.449489742783178, 2.45710877643816, 2.4646575866426104, 2.472137665308914, 2.47955045513814, 2.4868973518073663, 2.4941797060352964, 2.5013988255342774, 2.508555976856189, 2.5156523871391085, 2.5226892457611436, 2.5296677059073316, 2.5365888860550827, 2.5434538713832313, 2.5502637151094083, 2.5570194397600914, 2.563722038377404, 2.57037247566643, 2.576971689086552, 2.5835205898901012, 2.5900200641113513, 2.59647097350871], [0.0, 0.8235490260528069, 0.9793703613355592, 1.0838514715804344, 1.164674201923033, 1.2314930323839879, 1.288923881609622, 1.3395655431865348, 1.3850388475869866, 1.4264287556473265, 1.464500276187315, 1.4998147805113797, 1.5327974507070876, 1.563778709449485, 1.593020874969912, 1.6207359770526286, 1.6470980521056138, 1.6722518622569726, 1.6963192252602786, 1.7194037047240815, 1.741594148365405, 1.7629674000343882, 1.7835904081703775, 1.8035218860491045, 1.8228136342389012, 1.8415116050578217, 1.8596567675671003, 1.8772858166356075, 1.8944317588620798, 1.9111244003334622, 1.927390755451873, 1.9432553917845798, 1.9587407226711184, 1.9738672568730735, 1.9886538126725422, 2.003117702369927, 2.017274891995427, 2.0311401401546014, 2.0447271192199157, 2.0580485215148534, 2.0711161526832442, 2.0839410140696626, 2.096533375638743, 2.108902840717755, 2.12105840364682, 2.133008501256132, 2.1447610589527217, 2.1563235320853567, 2.1677029431608688, 2.1789059154051804, 2.189938703094842, 2.2008072190278125, 2.211517059453757, 2.2220735267428493, 2.2324816500367577, 2.242746204095264, 2.252871726525904, 2.2628625335616044, 2.272722734531862, 2.2824562451561787, 2.292066799773837, 2.301557962611329, 2.3109331381776226, 2.3201955808676797, 2.329348403846066, 2.3383945872749803, 2.3473369859443625, 2.356178336355889, 2.3649212633074757, 2.3735682860202925, 2.3821218238462203, 2.3905842015900256, 2.3989576544773072, 2.4072443327963553, 2.4154463062394758, 2.4235655679670325, 2.431604038415341, 2.4395635688677193, 2.4474459448062946, 2.455252889060639, 2.4629860647679758, 2.4706470781584207, 2.478237481177628, 2.4857587739581977, 2.4932124071502657, 2.50059978412088, 2.5079222630310047, 2.515181158798285, 2.5223777449531117, 2.5295132553949102, 2.5365888860550827, 2.543605796472544, 2.550565111287347, 2.5574679216575, 2.5643152866037044, 2.571108234286407, 2.577847763219244, 2.5845348434226794, 2.591170417521358, 2.597755401788474, 2.604290687140218, 2.610777140083157], [0.0, 0.827988804296353, 0.9846501772118186, 1.0896945483500373, 1.1709529965289847, 1.238132049369367, 1.2958725100775408, 1.3467871824166227, 1.3925056348060254, 1.4341186771394874, 1.4723954424229517, 1.5079003283308927, 1.541060809120647, 1.5722090887861115, 1.6016088997243152, 1.6294734147786363, 1.655977608592706, 1.6812670237117344, 1.7054641346125685, 1.7286730632183713, 1.7509831362269535, 1.772471611756025, 1.793205799166037, 1.8132447282578046, 1.8326404788581236, 1.8514392510154154, 1.8696822346563884, 1.8874063224730853, 1.9046446990038355, 1.9214273310211205, 1.9377813785625346, 1.9537315416398595, 1.9693003544236372, 1.9845084362388192, 1.9993747068174432, 2.013916571791058, 2.028150083263225, 2.0420900794036014, 2.0557503062928357, 2.069143524679119, 2.082281603850872, 2.095175604461257, 2.1078358518406057, 2.120272001088022, 2.1324930950323915, 2.1445076159871213, 2.1563235320853567, 2.16794833886788, 2.1793890967000746, 2.1906524645138785, 2.2017447303028406, 2.2126718387409956, 2.2234394162475644, 2.234052793777961, 2.2445170275861126, 2.254836918172679, 2.2650170276075774, 2.2750616953926794, 2.284975053011005, 2.294761037291821, 2.3044234027063477, 2.313965732695932, 2.323391450123356, 2.332703826928124, 2.3419059930579693, 2.351000944741237, 2.3599915521581276, 2.368880566562882, 2.377670626903783, 2.3863642659832003, 2.3949639161958145, 2.403471914879488, 2.411890509309988, 2.4202218613678763, 2.4284680519032347, 2.4366310848216144, 2.4447128909124634, 2.4527153314394257, 2.460640201510217, 2.4684892332422375, 2.476264098738734, 2.483966412889059, 2.4915977360054535, 2.4991595763077785, 2.50665339226667, 2.514080594814771, 2.5214425494349326, 2.528740578133563, 2.535975961306694, 2.5431499395057404, 2.550263715109408, 2.557318453907722, 2.5643152866037044, 2.5712553102378295, 2.578139589540013, 2.5849691582135454, 2.5917450201550816, 2.5984681506144955, 2.6051394972981505, 2.611759981418898, 2.6183304986958853, 2.624851920307043], [0.0, 0.8323582900575635, 0.989846400767953, 1.0954451150103321, 1.1771323825530846, 1.2446659545769565, 1.3027111248652612, 1.3538944855424797, 1.3998542046322333, 1.4416868484808525, 1.4801656089845705, 1.5158578622731127, 1.5491933384829668, 1.5805059947242717, 1.6100609551700655, 1.6380725176254398, 1.664716580115127, 1.6901394532455423, 1.7144642578192797, 1.7377956652346387, 1.7602234735867868, 1.7818253487021416, 1.8026689551480006, 1.8228136342389012, 1.842311740638763, 1.8612097182041993, 1.879548974230557, 1.8973665961010278, 1.9146959434763193, 1.9315671412704056, 1.9480074928505935, 1.9640418285762606, 1.979692801535906, 1.9949811398673623, 2.0099258631464076, 2.0245444688580783, 2.038853093816547, 2.0528666544958774, 2.066598969517919, 2.080062866972243, 2.0932702787842112, 2.1062323239765757, 2.1189593823687916, 2.1314611600121216, 2.143746747456523, 2.1558246717785052, 2.1677029431608688, 2.1793890967000746, 2.1908902300206643, 2.2022130371952793, 2.213363839400643, 2.224348612682192, 2.2351730131510443, 2.2458423998952814, 2.256361855851836, 2.266736206854704, 2.2769700390488867, 2.287067714836797, 2.297033387504232, 2.3068710146560054, 2.316584370576538, 2.3261770576178145, 2.335652516705844, 2.345014037046902, 2.354264765106169, 2.3634077129237725, 2.3724457658265057, 2.381381689587608, 2.3902181370816935, 2.3989576544773072, 2.407602687005432, 2.4161555843385933, 2.424618605611948, 2.432993924114793, 2.44128363167833, 2.449489742783178, 2.4576141984080007, 2.4656588696387556, 2.47362556105635, 2.4815160139189634, 2.489331909153913, 2.4970748701726904, 2.5047464655216602, 2.512348211379903, 2.519881573914738, 2.5273479715046214, 2.5347487768383683, 2.5420853188989163, 2.549358884839239, 2.5565707217574243, 2.563722038377404, 2.5708140066413443, 2.577847763219244, 2.584824410940911, 2.591745020155082, 2.598610630020137, 2.6054222497305224, 2.612180859682727, 2.618887412584378, 2.625542834509777, 2.6321480259049848, 2.638703862545338], [0.0, 0.8366600265340756, 0.9949620563926881, 1.1011065185976396, 1.1832159566199232, 1.2510985509742438, 1.309443706292189, 1.3608915892697748, 1.4070888341971637, 1.449137674618944, 1.4878152983881654, 1.5236920139085786, 1.5571997722182047, 1.588674256361194, 1.618381960706977, 1.6465382905797215, 1.6733200530681511, 1.698874314931026, 1.7233248332753461, 1.7467768204548835, 1.7693205386531028, 1.7910340550835677, 1.8119853840129068, 1.83223417343933, 1.8518330486025056, 1.8708286933869709, 1.8892627290863886, 1.907172434756397, 1.9245913424647914, 1.9415497328150402, 1.9580750502818227, 1.9741922535510608, 1.9899241127853762, 2.005291463248328, 2.0203134228113497, 2.0350075793887674, 2.04939015319192, 2.0634761377851585, 2.077279423206778, 2.0908129038435934, 2.1040885732867167, 2.117117608023464, 2.1299104415175543, 2.1424768299823924, 2.154825910949086, 2.1669662555631914, 2.1789059154051804, 2.1906524645138785, 2.2022130371952793, 2.2135943621178655, 2.2248027931270298, 2.2358443371531918, 2.2467246795389917, 2.257449207068979, 2.26802302894937, 2.2784509959547, 2.2887377179317685, 2.298887579828454, 2.3089047563952776, 2.3187932256904724, 2.3285567815044543, 2.3381990448066348, 2.3477234743061772, 2.3571333762084064, 2.3664319132398464, 2.3756221130072404, 2.384706875749129, 2.393688981532629, 2.402571096942758, 2.411355781306992, 2.4200454924935872, 2.4286425923184853, 2.4371493515923475, 2.4455679548363145, 2.4539005046924456, 2.4621490260524586, 2.470315469926249, 2.4784017170697905, 2.4864095813903013, 2.4943408131450107, 2.5021971019484877, 2.5099800796022267, 2.5176913227590454, 2.5253323554338367, 2.5329046513712625, 2.5404096362801454, 2.547848689943536, 2.555223148212729, 2.5625343048928735, 2.5697834135272224, 2.5769716890865517, 2.584100309569777, 2.591170417521358, 2.5981831214706688, 2.6051394972981505, 2.612040589532689, 2.618887412584378, 2.625680951916526, 2.6324221651604756, 2.6391119831766026, 2.6457513110645907, 2.652341029125897], [0.0, 0.8408964152537145, 1.0, 1.1066819197003215, 1.189207115002721, 1.2574334296829353, 1.3160740129524924, 1.3677823998673804, 1.4142135623730951, 1.4564753151219703, 1.4953487812212205, 1.531407156804393, 1.5650845800732873, 1.59671843378737, 1.6265765616977856, 1.6548754598234363, 1.681792830507429, 1.7074764851741444, 1.7320508075688772, 1.7556215427832071, 1.7782794100389228, 1.800102871839254, 1.821160286837872, 1.8415116050578217, 1.8612097182041993, 1.880301546543197, 1.8988289221159416, 1.9168293127388176, 1.9343364202676694, 1.951380678630378, 1.9679896712654303, 1.984188483235881, 2.0, 2.0154451623197245, 2.0305431848689306, 2.0453117446175235, 2.0597671439071177, 2.0739244522212745, 2.087797629929844, 2.101399636709763, 2.114742526881128, 2.127837533522874, 2.1406951429280725, 2.1533251607102564, 2.1657367706679933, 2.177938587346431, 2.189938703094842, 2.2017447303028406, 2.213363839400643, 2.2248027931270298, 2.2360679774997894, 2.2471654298651536, 2.2581008643532257, 2.2688796950242867, 2.2795070569547775, 2.2899878254809036, 2.3003266337912063, 2.3105278890365413, 2.320595787106084, 2.3305343262007767, 2.340347319320716, 2.350038405769921, 2.3596110617705666, 2.3690686102687937, 2.378414230005442, 2.3876509639174, 2.39678172692843, 2.4058093131823877, 2.414736402766418, 2.4235655679670325, 2.432299279097787, 2.4409399099335674, 2.449489742783178, 2.4579509732289795, 2.46632571455966, 2.4746160019198826, 2.4828237961983883, 2.4909509876742715, 2.4989993994393833, 2.5069707906132983, 2.5148668593658705, 2.5226892457611436, 2.5304395344352426, 2.5381192571198388, 2.5457298950218306, 2.5532728810690504, 2.5607496020310148, 2.5681614005230395, 2.575509576901394, 2.5827953910565906, 2.5900200641113513, 2.597184780029334, 2.604290687140218, 2.611338899586365, 2.6183304986958853, 2.6252665342865877, 2.6321480259049848, 2.638975964004231, 2.6457513110645907, 2.652475002659807, 2.6591479484724942, 2.665771033261474], [0.0, 0.8450697266227711, 1.0049629315732038, 1.112174306341096, 1.1951090685408465, 1.2636739857523107, 1.3226055982240474, 1.3745706103249549, 1.4212322075130495, 1.463703702448981, 1.5027700949004952, 1.5390074257343278, 1.5728519877504676, 1.6046428381159301, 1.634649149872069, 1.6630884934927144, 1.6901394532455423, 1.7159505741329184, 1.740646857208154, 1.7643345723684827, 1.7871048890689831, 1.80903665921692, 1.8301985807252845, 1.8506509011449843, 1.8704467746790288, 1.88963335445568, 1.9082526801256234, 1.9263424054554517, 1.943936399561014, 1.9610652474116927, 1.9777566693406925, 1.9940358749065197, 2.0099258631464076, 2.025447678749862, 2.040620631751871, 2.0554624868519302, 2.069989627299062, 2.0842171973656427, 2.098159226705883, 2.1118287393147086, 2.1252378493369837, 2.1383978456006427, 2.151319266441514, 2.1640119661377195, 2.17648517406639, 2.188747547526072, 2.2008072190278125, 2.2126718387409956, 2.224348612682192, 2.2358443371531918, 2.2471654298651536, 2.2583179581272432, 2.2693076644284034, 2.2801399896985237, 2.2908200944990793, 2.301352878362235, 2.31174299747073, 2.3219948808478086, 2.3321127452065564, 2.3421006085907137, 2.3519623029240355, 2.3617014855721576, 2.371321650009509, 2.3808261356737828, 2.390218137081693, 2.3995007122720162, 2.408676790635081, 2.4177491801818887, 2.4267205743006723, 2.435593558044026, 2.4443706139855026, 2.45305412768087, 2.4616463927658754, 2.4701496157194045, 2.478565920318253, 2.4868973518073663, 2.495145880807243, 2.5033134069783034, 2.5114017624602782, 2.519412715103133, 2.5273479715046214, 2.535209179868313, 2.542997932694775, 2.5507157693175553, 2.558364178294683, 2.565944599665513, 2.5734584270820036, 2.5809070098227784, 2.588291654697687, 2.595613627849991, 2.602874156462761, 2.610074430375586, 2.6172156036172267, 2.6242987958594575, 2.6313250937969457, 2.638295552457674, 2.645211196448095, 2.6520730211369132, 2.6588819937811183, 2.665639054597641, 2.6723451177837885, 2.67900107248938], [0.0, 0.8491821094987799, 1.0098534065489688, 1.1175865065755222, 1.2009248561777692, 1.2698234324738655, 1.3290418252506462, 1.381259715923798, 1.4281483835502227, 1.4708265585304046, 1.5100830606950983, 1.5464967341123872, 1.5805059947242717, 1.61245154965971, 1.642603881843218, 1.6711816205169885, 1.6983642189975598, 1.7243009451553697, 1.7491174083393233, 1.772920395590378, 1.7958015200236968, 1.8178400172654527, 1.8391049195349223, 1.8596567675671005, 1.8795489742305571, 1.898828922115942, 1.9175388554524904, 1.9357166112422137, 1.953396223419044, 1.970608425788726, 1.9873810735805801, 2.003739499030986, 2.0197068130979376, 2.0353041628812134, 2.0505509523846825, 2.0654650327566206, 2.080062866972243, 2.094359673000858, 2.1083695487695167, 2.1221055816521197, 2.1355799447448818, 2.14880398181083, 2.1617882824687458, 2.1745427489508584, 2.187076655547436, 2.199398701686243, 2.211517059453757, 2.2234394162475644, 2.2351730131510443, 2.2467246795389917, 2.2581008643532257, 2.2693076644284034, 2.280350850198276, 2.2912358890700615, 2.3019679667181965, 2.312552006517556, 2.322992687309372, 2.333294459669949, 2.3434615608322646, 2.3534980283931604, 2.3634077129237725, 2.3731942895876625, 2.3828612688596364, 2.392412006428173, 2.4018497123555385, 2.4111774595619155, 2.4203981916929957, 2.4295147304244695, 2.43852978225147, 2.4474459448062946, 2.4562657127435017, 2.4649914832277466, 2.47362556105635, 2.4821701634456383, 2.4906274245073927, 2.4989993994393833, 2.5072880684517855, 2.5154953404493816, 2.5236230564876885, 2.531672993019601, 2.539646864947731, 2.54754632849634, 2.5553729839156167, 2.5631283780300076, 2.5708140066413443, 2.5784313167966806, 2.585981708929937, 2.593466538885762, 2.6008871198333665, 2.6082447240774744, 2.615540584773027, 2.6227758975497575, 2.6299518220523037, 2.6370694834011266, 2.6441299735791004, 2.6511343527483158, 2.6580836505012924, 2.6649788670505217, 2.6718209743599775, 2.6786109172219916, 2.68534961428265, 2.6920379590186645], [0.0, 0.8532355998949246, 1.0146738461686593, 1.1229211999476407, 1.206657357270946, 1.2758848143974324, 1.3353858805651275, 1.3878530283952342, 1.4349655146369895, 1.4778474098445196, 1.5172912992053529, 1.5538787898449244, 1.5880503904422236, 1.6201484344594288, 1.6504446959456858, 1.6791588477491748, 1.7064711997898492, 1.732531732454193, 1.7574666546754452, 1.7813832632323923, 1.8043736085467281, 1.8265173044683851, 1.8478837127354024, 1.868533663068241, 1.8885208232967414, 1.9078928021878638, 1.9266920456196721, 1.944956571205524, 1.9627205753371124, 1.9800149385250942, 1.9968676489630897, 2.0133041598085097, 2.0293476923373186, 2.0450194945929727, 2.060339063202517, 2.075324334524993, 2.0899918501200694, 2.1043569005985905, 2.118433651182726, 2.1322352517177183, 2.145773933406904, 2.159061094161688, 2.172107374149395, 2.1849227228696226, 2.1975164588825846, 2.20989732314194, 2.2220735267428493, 2.234052793777961, 2.2458423998952814, 2.257449207068979, 2.2688796950242867, 2.2801399896985237, 2.2912358890700615, 2.302172886644268, 2.312956192848905, 2.323590754560113, 2.334081272953128, 2.3444322198486605, 2.3546478527057175, 2.364732228394227, 2.3746892158656623, 2.38452250782663, 2.394235631508855, 2.4038319586188774, 2.413314714541892, 2.422686986866375, 2.4319517332892318, 2.4411117889551543, 2.4501698732784742, 2.4591285962910403, 2.467990464555409, 2.476757886678874, 2.4854331784604873, 2.4940185677002478, 2.5025161986969175, 2.5109281364585576, 2.5192563706476903, 2.5275028192810733, 2.5356693322023287, 2.5437576943440803, 2.551769628794865, 2.5597067996847738, 2.5675708149026395, 2.575363228656527, 2.583085543888338, 2.590739214552467, 2.5983256477676733, 2.605846205850603, 2.6133022082387543, 2.620694933310077, 2.6280256201058623, 2.6352954699630677, 2.6425056480617855, 2.6496572848931312, 2.656751477652458, 2.6637892915624386, 2.670771761130255, 2.6776998913428183, 2.684574658803681, 2.691397012815051, 2.6981678764080854, 2.704888147324421], [0.0, 0.8572321289096398, 1.0194265469082735, 1.128180927925918, 1.212309302805974, 1.281861019188702, 1.3416407864998738, 1.3943536888187151, 1.4416868484808525, 1.4847696011519296, 1.5243982444638442, 1.5611571097717194, 1.5954887690834967, 1.6277371593406456, 1.658175327573506, 1.687023975571047, 1.7144642578192797, 1.740646857208154, 1.7656985738296271, 1.7897272070372607, 1.8128252384140608, 1.8350726547187572, 1.8565391425776128, 1.8772858166356075, 1.8973665961010278, 1.9168293127388176, 1.9357166112422135, 1.954066687297892, 1.9719138974723813, 1.9892892669196898, 2.006220914929266, 2.0227344138803187, 2.038853093816547, 2.0545983023065815, 2.069989627299062, 2.0850450891663783, 2.09978130694835, 2.1142136428765665, 2.1283563285226585, 2.142222575325334, 2.1558246717785057, 2.1691740691810413, 2.182281457538478, 2.19515683295356, 2.207809557634348, 2.2202484134768556, 2.2324816500367577, 2.2445170275861126, 2.256361855851836, 2.26802302894937, 2.2795070569547775, 2.2908200944990793, 2.3019679667181965, 2.312956192848905, 2.32379000772445, 2.3344743813919835, 2.345014037046902, 2.355413467455784, 2.365676950019442, 2.3758085606100576, 2.385812186301152, 2.3956915370958543, 2.405450156747334, 2.4150914327550987, 2.424618605611948, 2.434034777368526, 2.4433429195754983, 2.452545880657287, 2.461646392765876, 2.4706470781584207, 2.47955045513814, 2.488358943594169, 2.4970748701726904, 2.5057004731086487, 2.5142379067446345, 2.5226892457611436, 2.531056489140214, 2.5393415638825356, 2.54754632849634, 2.5556725762748194, 2.563722038377404, 2.5716963867289198, 2.579597236749499, 2.5874261499270697, 2.5951846362432662, 2.602874156462761, 2.610496124295213, 2.618051908438318, 2.625542834509777, 2.6329701868754243, 2.64033521038018, 2.647639111988028, 2.654883062336727, 2.662068197212579, 2.669195618950164, 2.676266397761627, 2.6832815729997477, 2.6902421543587653, 2.697149123016613, 2.7040034327220006, 2.7108060108295344, 2.717557759285845], [0.0, 0.861173529963367, 1.0241136890844451, 1.133368103427352, 1.2178832856309065, 1.287754788450697, 1.3478094125129467, 1.4007646793929587, 1.4483154685151653, 1.4915963080299905, 1.531407156804393, 1.568335032845268, 1.602824543028034, 1.635221205655121, 1.665799323178612, 1.6947806121350968, 1.722347059926734, 1.748650042256635, 1.7738169422210552, 1.7979560548158353, 1.8211602868378718, 1.8435099928108027, 1.8650751797676193, 1.8859172433475835, 1.906090350669923, 1.925642553421541, 1.9446166923683976, 1.963051138814152, 1.9809804072907227, 1.9984356656002646, 2.015445162319724, 2.0320345874055676, 2.0482273781688902, 2.0640449803306513, 2.079507071901399, 2.094631756107994, 2.1094357284016496, 2.123934421646766, 2.1381421328492136, 2.152072134191548, 2.1657367706679937, 2.179147546228457, 2.192315200029222, 2.2052497741333363, 2.217960673794632, 2.230456721286719, 2.242746204095264, 2.254836918172679, 2.266736206854704, 2.2784509959547, 2.2899878254809036, 2.301352878362235, 2.312552006517556, 2.323590754560113, 2.3344743813919835, 2.345207879911715, 2.3557959950311154, 2.366243240173708, 2.376553912407033, 2.386732106343409, 2.39678172692843, 2.406706501223162, 2.41650998927432, 2.4261955941565336, 2.435766571261813, 2.4452260369034797, 2.4545769762948617, 2.4638222509569303, 2.472964605603619, 2.482006674548756, 2.490950987674271, 2.499799975995519, 2.508555976856189, 2.5172212387822324, 2.5257979260215238, 2.5342881227935714, 2.542693837271378, 2.5510170053156402, 2.55925949397968, 2.567423104801933, 2.575509576901394, 2.5835205898901012, 2.5914577666156022, 2.5993226757452694, 2.607116834203364, 2.6148417094708947, 2.6224987217575073, 2.630089246053925, 2.637614614072805, 2.645076116085267, 2.652475002659807, 2.6598124863098143, 2.667089743055433, 2.674307913905108, 2.6814681062617582, 2.6885713952581733, 2.6956188250258935, 2.702611409901553, 2.709550135574365, 2.7164359601782087, 2.7232698153315003, 2.7300526071278615], [0.0, 0.8650615454144222, 1.0287373447220802, 1.1384850195244434, 1.223381769812505, 1.2935687276168015, 1.35389448554248, 1.4070888341971637, 1.454854305025652, 1.4983305483318308, 1.5383211346269174, 1.5754157321793418, 1.6100609551700658, 1.642603881843218, 1.6733200530681511, 1.7024321863844938, 1.7301230908288443, 1.75654482553344, 1.7818253487021418, 1.8060734442596786, 1.829382438457389, 1.8518330486025056, 1.8734955977948946, 1.8944317588620798, 1.9146959434763193, 1.9343364202676696, 1.9533962234190436, 1.9719138974723813, 1.9899241127853764, 2.0074581778761864, 2.0245444688580787, 2.041208791672212, 2.0574746894441605, 2.0733637047177558, 2.08889560434558, 2.1040885732867167, 2.1189593823687916, 2.133523534132309, 2.1477953901310802, 2.1617882824687458, 2.1755146118745547, 2.1889859342363023, 2.2022130371952797, 2.2152060081523164, 2.2279742948239645, 2.2405267593145264, 2.252871726525904, 2.2650170276075774, 2.2769700390488867, 2.2887377179317685, 2.3003266337912063, 2.31174299747073, 2.322992687309372, 2.334081272953128, 2.345014037046902, 2.3557959950311154, 2.366431913239847, 2.376926325473765, 2.3872835482007586, 2.3975076945194496, 2.407602687005432, 2.417572269546659, 2.4274200182627017, 2.4371493515923475, 2.44676353962501, 2.4562657127435017, 2.4656588696387556, 2.4749458847509014, 2.484129515185673, 2.4932124071502657, 2.5021971019484877, 2.5110860415712124, 2.519881573914738, 2.5285859576566336, 2.5372013668158924, 2.5457298950218306, 2.5541735595139254, 2.5625343048928735, 2.5708140066413447, 2.579014474431339, 2.587137455233603, 2.5951846362432662, 2.603157647634689, 2.611058065157442, 2.618887412584378, 2.626647164021871, 2.63433874609151, 2.6419635399918104, 2.649522883447829, 2.657018072555984, 2.6644503635308237, 2.6718209743599775, 2.6791310863730695, 2.686381845729956, 2.6935743648332457, 2.7007097236697226, 2.70778897108496, 2.7148131259951045, 2.7217831785395497, 2.728700091177943, 2.735564799734761, 2.7423782143944453], [0.0, 0.8688978326173192, 1.0332994847589594, 1.1435338574183984, 1.2288070992040003, 1.2993053150100684, 1.3598985994884667, 1.4133288490453373, 1.4613061453392517, 1.504975192679675, 1.5451431251708252, 1.5824022260821624, 1.6172010901939202, 1.6498883349376223, 1.6807407231233218, 1.709981959975803, 1.7377956652346385, 1.7643345723684827, 1.7897272070372605, 1.8140828355896175, 1.8374951981506853, 1.8600453699846247, 1.881803986053052, 1.9028329926838916, 1.9231870428487672, 1.9429146192345599, 1.962058946867813, 1.9806587412238905, 1.998748826413073, 2.0163606497973583, 2.033522713329523, 2.050260937392297, 2.0665989695179188, 2.082558447784909, 2.098159226705883, 2.1134195718847355, 2.1283563285226585, 2.14298506790925, 2.1573202152874846, 2.1713751618848627, 2.18516236342413, 2.1986934270399607, 2.211979188213584, 2.225029779080412, 2.2378546892547706, 2.2504628201417236, 2.2628625335616044, 2.2750616953926794, 2.287067714836797, 2.298887579828454, 2.3105278890365413, 2.3219948808478086, 2.333294459669949, 2.3444322198486605, 2.355413467455784, 2.366243240173708, 2.376926325473765, 2.3874672772626644, 2.3978704311505283, 2.4081399184763312, 2.418279679211108, 2.4282934738458257, 2.438184894359068, 2.4479573743493686, 2.4576141984080007, 2.467158510800082, 2.476593323514836, 2.4859215237396675, 2.495145880807243, 2.5042690526598896, 2.513293591871332, 2.5222219512619364, 2.531056489140214, 2.5397994742002874, 2.5484530901022695, 2.557019439760091, 2.5655005493590783, 2.573898372123646, 2.582214791853664, 2.5904516262464825, 2.598610630020137, 2.606693497851958, 2.6147018671456377, 2.6226373206387223, 2.6305013888615374, 2.6382955524576737, 2.6460212443753583, 2.6536798519383042, 2.6612727188039766, 2.66880114681659, 2.6762663977616263, 2.6836696950281222, 2.6910122251845436, 2.698295139473619, 2.705519555231128, 2.7126865572332703, 2.7197971989769334, 2.72685250389685, 2.733853466523383, 2.7408010535843985, 2.7476962050544724, 2.75453983515444], [0.0, 0.8726839694794393, 1.0378019856537666, 1.148516693752116, 1.2341615053034112, 1.3049669101523764, 1.3658242239094178, 1.4194872905246418, 1.4676736431692852, 1.5115329740892762, 1.5518759343963227, 1.5892973881759884, 1.6242478849161492, 1.6570775611145052, 1.6880643855478386, 1.7174330382144525, 1.7453679389588785, 1.7720224867708414, 1.797525767348191, 1.8219875231569418, 1.8455019027856028, 1.868150334775826, 1.890003761874127, 1.9111244003334624, 1.9315671412704056, 1.9513806786303782, 1.9706084257887257, 1.98928926691969, 2.0074581778761864, 2.0251467430490013, 2.042383588585367, 2.0591947478135326, 2.075603971307533, 2.091632991431688, 2.1073017492127, 2.1226285898450357, 2.1376304319311945, 2.152322914611139, 2.16672052598442, 2.180836715629496, 2.1946839935436993, 2.208274017438652, 2.2216176700101276, 2.2347251275433204, 2.24760592100262, 2.260268990580086, 2.272722734531862, 2.284975053011005, 2.297033387504232, 2.3089047563952776, 2.320595787106084, 2.3321127452065564, 2.3434615608322646, 2.3546478527057175, 2.365676950019442, 2.376553912407033, 2.3872835482007586, 2.3978704311505283, 2.4083189157584597, 2.4186331513654293, 2.4288170951105092, 2.438874523870636, 2.448809045276087, 2.4586241078869637, 2.4683230106068224, 2.4779089114016077, 2.487384835384989, 2.4967536823250067, 2.5060182336214227, 2.5151811587982853, 2.5242450215519088, 2.533212285390583, 2.5420853188989163, 2.550866400656643, 2.5595577238389606, 2.5681614005230395, 2.5766794657231107, 2.5851138811745704, 2.5934665388857625, 2.6017392644744746, 2.609933820304753, 2.618051908438318, 2.626095173413688, 2.6340652048650317, 2.641963539991811, 2.6497916658893743, 2.65755102174988, 2.665243000942169, 2.6728689529785594, 2.6804301853759265, 2.6879279654178565, 2.6953635218241843, 2.7027380463337307, 2.710052695205652, 2.717308590644407, 2.7245068221530033, 2.7316484478188356, 2.738734495536154, 2.7457659641688887, 2.752743824657328, 2.7596690210718946, 2.7665424716170515], [0.0, 0.8764214595654655, 1.0422466354563211, 1.1534355073280027, 1.2394471144723045, 1.310555761397342, 1.3716737120112341, 1.4255666042981499, 1.4739593272000566, 1.5180064968110587, 1.5585222360615276, 1.5961039566931094, 1.6312041377859532, 1.6641744153859734, 1.6952939487416283, 1.724788380100209, 1.752842919130931, 1.7796116217935372, 1.8052241266280664, 1.8297906461004336, 1.853405732014319, 1.876151161649724, 1.898098181583441, 1.9193092745252844, 1.9398395666769344, 1.9597379605279643, 1.9790480553824932, 1.9978089019460852, 2.016055625864603, 2.033819946796984, 2.0511306134891862, 2.068013770763778, 2.0844932709126422, 2.100590939374452, 2.116326802578406, 2.131719284286912, 2.1467853755606696, 2.1615407825182174, 2.1760000553080614, 2.190176701109886, 2.204083283498255, 2.2177315101118924, 2.231132310254472, 2.244295903793707, 2.2572318625127545, 2.2699491648923114, 2.2824562451561787, 2.294761037291821, 2.3068710146560054, 2.3187932256904724, 2.3305343262007767, 2.3421006085907137, 2.3534980283931604, 2.364732228394227, 2.3758085606100576, 2.386732106343409, 2.3975076945194496, 2.4081399184763312, 2.4186331513654293, 2.428991560298224, 2.439219119361237, 2.4493196216068367, 2.459296690115891, 2.4691537882178327, 2.478894228944609, 2.4885211837869523, 2.4980376908143476, 2.5074466622138267, 2.5167508912971996, 2.5259530590214276, 2.535055740062504, 2.5440614084793167, 2.5529724430005367, 2.561791131964494, 2.570519677939213, 2.579160202047371, 2.5877147480186613, 2.5961852859901096, 2.6045737160730646, 2.612881871703984, 2.621111522794684, 2.6292643786963965, 2.6373420909907916, 2.645346256120049, 2.6532784178670767, 2.6611400696960854, 2.6689326569629386, 2.6766575790039315, 2.6843161911110114, 2.691909806400825, 2.6994396975844213, 2.706907098643939, 2.7143132064221227, 2.721659182130101, 2.7289461527784584, 2.736175212536273, 2.7433474240224682, 2.750463819533511, 2.75752540221122, 2.7645331471541805, 2.771488002476036, 2.7783908903136925], [0.0, 0.8801117367933934, 1.0466351393921056, 1.158292185288269, 1.2446659545769567, 1.3160740129524924, 1.3774493079968597, 1.4315691227432645, 1.4801656089845705, 1.5243982444638442, 1.5650845800732873, 1.602824543028034, 1.6380725176254403, 1.6711816205169887, 1.7024321863844938, 1.7320508075688772, 1.7602234735867868, 1.7871048890689831, 1.8128252384140608, 1.8374951981506855, 1.8612097182041991, 1.8840509201876072, 1.9060903506699232, 1.9273907554518732, 1.9480074928505937, 1.9679896712654306, 1.9873810735805801, 2.0062209149292665, 2.0245444688580787, 2.042383588585367, 2.0597671439071177, 2.0767213897317967, 2.0932702787842112, 2.1094357284016496, 2.1252378493369832, 2.140695142928072, 2.1558246717785052, 2.1706422081393097, 2.18516236342413, 2.1993987016862424, 2.2133638394006434, 2.2270695335024673, 2.2405267593145264, 2.2537457797365077, 2.266736206854704, 2.2795070569547775, 2.292066799773837, 2.3044234027063477, 2.316584370576538, 2.3285567815044543, 2.340347319320716, 2.3519623029240355, 2.3634077129237725, 2.3746892158656623, 2.385812186301152, 2.39678172692843, 2.407602687005432, 2.418279679211108, 2.4288170951105092, 2.439219119361237, 2.4494897427831783, 2.4596327743998025, 2.4696518525473916, 2.4795504551381407, 2.4893319091539134, 2.4989993994393833, 2.508555976856189, 2.518004565853474, 2.527347971504622, 2.5365888860550827, 2.5457298950218306, 2.5547734828810733, 2.563722038377404, 2.5725778594844746, 2.5813431580444846, 2.5900200641113513, 2.598610630020137, 2.607116834203364, 2.615540584773027, 2.6238837228854868, 2.6321480259049848, 2.6403352103801803, 2.648446934846925, 2.65648480246941, 2.6644503635308237, 2.6723451177837885, 2.6801705166700103, 2.6879279654178565, 2.6956188250258935, 2.7032444141398027, 2.7108060108295344, 2.718304854273057, 2.725742146352564, 2.7331190531686027, 2.7404367064771695, 2.7476962050544724, 2.7548986159937194, 2.762044975937984, 2.769136292252934, 2.7761735441429227, 2.7831576837137404, 2.7900896369850603], [0.0, 0.8837561697610181, 1.0509691250073554, 1.1630885288089072, 1.2498199611069312, 1.3215237113488725, 1.3831531538375998, 1.4374970719890816, 1.4862947902207868, 1.5307105875285492, 1.5715654001808814, 1.6094616396167147, 1.6448555716821271, 1.6781017752406273, 1.7094817458049945, 1.7392230140067817, 1.7675123395220362, 1.7945050675941052, 1.8203319216989462, 1.8451040366629305, 1.8689167555872028, 1.8918525401401285, 1.9139832331561426, 1.9353718402585094, 1.9560739489962538, 1.9761388711204808, 1.995610570814851, 2.0145284255975655, 2.0329278550785728, 2.050840844376428, 2.068296382833342, 2.0853208340760854, 2.101938250014711, 2.118170638743468, 2.134038194291349, 2.149559494607946, 2.164751672950963, 2.1796305668823517, 2.1942108483197984, 2.208506137483634, 2.222529103092103, 2.236291550764344, 2.249804501270612, 2.263078260007981, 2.276122478865197, 2.2889462114632346, 2.301557962611329, 2.313965732695932, 2.3261770576178145, 2.3381990448066348, 2.350038405769921, 2.3617014855721576, 2.3731942895876625, 2.38452250782663, 2.3956915370958543, 2.406706501223162, 2.417572269546659, 2.4282934738458257, 2.438874523870636, 2.4493196216068367, 2.4596327743998025, 2.4698178070456938, 2.4798783729466893, 2.489817964416585, 2.4996399222138623, 2.5093474443712385, 2.5189435943835905, 2.5284313088098407, 2.537813404338831, 2.5470925843642664, 2.556271445109423, 2.5653524813384143, 2.5743380916873284, 2.583230583645438, 2.592032178213907, 2.600745014266939, 2.6093711526380607, 2.6179125799522365, 2.626371212222715, 2.6347488982298564, 2.643047422697745, 2.6512685092830544, 2.659413823389427, 2.6674849748195557, 2.6754835202761598, 2.683410965722149, 2.691268768609469, 2.699058339985363, 2.706781046484122, 2.714438212211775, 2.7220311205306014, 2.7295610157498498, 2.737029104728559, 2.7444365583959525, 2.751784513194487, 2.7590740724502676, 2.7663063076751997, 2.7734822598049687, 2.780602940376616, 2.7876693326492603, 2.794682392671241, 2.8016430502967653], [0.0, 0.8873560657375262, 1.0552501469158886, 1.167826258352922, 1.2549109828200413, 1.3269068114098672, 1.3887872955203007, 1.44335257840902, 1.4923490694646506, 1.5369457902618242, 1.5779670210741878, 1.6160176272058788, 1.6515557330581283, 1.68493736183743, 1.7164451557015292, 1.7463075721061798, 1.7747121314750525, 1.801814811835441, 1.8277468691528411, 1.8526198909506784, 1.8765296087010728, 1.8995588199720859, 1.9217796602430461, 1.94325539178458, 1.9640418285762609, 1.984188483235881, 2.003739499030986, 2.022734413880319, 2.0412087916722124, 2.0591947478135326, 2.0767213897317967, 2.0938151884434775, 2.110500293831777, 2.126798803638806, 2.1427309941519956, 2.158315518996434, 2.173569581220506, 2.1885090828989533, 2.203148755714112, 2.217502275366972, 2.231582362180588, 2.245400869863155, 2.2589688640769774, 2.2722966921971777, 2.285394045428542, 2.2982700142711043, 2.3109331381776226, 2.323391450123356, 2.335652516705844, 2.3477234743061772, 2.3596110617705666, 2.371321650009509, 2.3828612688596364, 2.394235631508855, 2.405450156747334, 2.41650998927432, 2.4274200182627017, 2.438184894359068, 2.448809045276087, 2.459296690115891, 2.4696518525473916, 2.4798783729466893, 2.4899799195977463, 2.499959999039964, 2.5098219656400826, 2.519569030457699, 2.529204269466543, 2.538730631187328, 2.548150943782407, 2.5574679216575, 2.5666841716113495, 2.575802198570253, 2.584824410940911, 2.593753125611932, 2.6025905726315153, 2.611338899586365, 2.6200001757046136, 2.6285763957035524, 2.6370694834011266, 2.6454812951085245, 2.6538136228197344, 2.662068197212579, 2.6702466904745625, 2.678350718965756, 2.686381845729956, 2.6943415828644692, 2.7022313937580313, 2.7100526952056514, 2.717806859408474, 2.725495215866147, 2.7331190531686027, 2.7406796206936646, 2.7481781302163952, 2.7556157574356863, 2.7629936434231848, 2.7703128959992873, 2.7775745910406013, 2.7847797737229634, 2.7919294597038142, 2.7990246362474833, 2.806066263296683, 2.8130552744932906], [0.0, 0.8909126743510709, 1.0594796911843958, 1.172507018523451, 1.259940786957369, 1.332225181765412, 1.3943536888187151, 1.449137674618944, 1.498330548331831, 1.5431060170831206, 1.5842916649412213, 1.6224947815686919, 1.6581753275735063, 1.6916907531374752, 1.7233248332753464, 1.7533069411223694, 1.7818253487021418, 1.80903665921692, 1.8350726547187575, 1.8600453699846249, 1.8840509201876074, 1.907172434756397, 1.9294823382962742, 1.951044146639142, 1.9719138974723813, 1.992141301865128, 2.0117706800153967, 2.03084172831372, 2.04939015319192, 2.06744819877851, 2.0850450891663788, 2.1022074014703858, 2.1189593823687916, 2.135323218173586, 2.151319266441514, 2.1669662555631914, 2.182281457538478, 2.197280838179163, 2.2119791882135846, 2.226390238156261, 2.240526759314527, 2.254400652907381, 2.2680230289493704, 2.281404276288892, 2.2945541249740162, 2.307481701940376, 2.3201955808676797, 2.332703826928124, 2.345014037046902, 2.3571333762084064, 2.3690686102687937, 2.3808261356737828, 2.392412006428173, 2.4038319586188774, 2.4150914327550987, 2.4261955941565336, 2.4371493515923475, 2.4479573743493686, 2.4586241078869637, 2.4691537882178327, 2.4795504551381407, 2.489817964416585, 2.499959999039964, 2.509980079602227, 2.519881573914738, 2.529667705907332, 2.539341563882536, 2.5489061081790196, 2.5583641782946835, 2.5677184995148465, 2.576971689086552, 2.586126261976083, 2.5951846362432667, 2.604149138063024, 2.613022006421803, 2.6218053975140414, 2.630501388861538, 2.6391119831766026, 2.6476391119880285, 2.656084639047278, 2.664450363530824, 2.6727380230532125, 2.680949296504237, 2.6890858067224945, 2.6971491230166134, 2.70514076354453, 2.713062197560384, 2.720914847537835, 2.728700091177943, 2.7364192633091173, 2.7440736576860836, 2.751664528694292, 2.759193092965716, 2.7666605309115617, 2.7740679881770016, 2.7814165770226826, 2.7887073776374303, 2.7959414393862456, 2.803119781997423, 2.810243396692342, 2.8173132472612576, 2.8243302710881744], [0.0, 0.8944271909999159, 1.0636591793889976, 1.1771323825530846, 1.2649110640673515, 1.337480609952844, 1.3998542046322333, 1.4548543050256517, 1.5042412372345575, 1.5491933384829666, 1.5905414575341013, 1.6288952797169987, 1.664716580115127, 1.6983642189975598, 1.730123090828844, 1.7602234735867865, 1.7888543819998317, 1.8161730370463405, 1.8423117406387628, 1.8673829695144322, 1.8914832180063514, 1.914695943476319, 1.9370938562338025, 1.9587407226711187, 1.9796928015359063, 2.0, 2.0197068130979376, 2.038853093816547, 2.0574746894441605, 2.075603971307533, 2.093270278784211, 2.110500293831777, 2.127318358777995, 2.1437467474565235, 2.1598058977316086, 2.175514611874554, 2.1908902300206643, 2.2059487809644573, 2.2207051137814724, 2.2351730131510443, 2.2493653007613963, 2.263293924780049, 2.2769700390488867, 2.290404073398753, 2.3036057962612957, 2.316584370576538, 2.329348403846066, 2.3419059930579693, 2.354264765106169, 2.3664319132398464, 2.378414230005442, 2.390218137081693, 2.4018497123555385, 2.413314714541892, 2.424618605611948, 2.435766571261813, 2.44676353962501, 2.4576141984080007, 2.4683230106068224, 2.478894228944609, 2.4893319091539134, 2.4996399222138623, 2.5098219656400826, 2.519881573914738, 2.529822128134703, 2.539646864947731, 2.549358884839239, 2.5589611598259867, 2.5684565406072686, 2.577847763219244, 2.587137455233603, 2.5963281415377923, 2.6054222497305224, 2.6144221151631246, 2.623329985654512, 2.6321480259049848, 2.640878321631854, 2.649522883447829, 2.6580836505012924, 2.666562493895928, 2.674961219905688, 2.6832815729997477, 2.691525238690868, 2.6996938462195, 2.7077889710849594, 2.715812137434088, 2.7237648203170117, 2.731648447818835, 2.739464403075442, 2.7472140261809384, 2.754898615993719, 2.762519431847596, 2.770077695173973, 2.7775745910406013, 2.785011269612051, 2.7923888475366696, 2.7997084092644666, 2.8069710083000294, 2.8141776683943274, 2.8213293846789598, 2.82842712474619, 2.8354718296778603], [0.0, 0.8979007600118484, 1.0677899723724407, 1.1817038564618862, 1.2698234324738655, 1.342674807141325, 1.4052906339306293, 1.460504330965901, 1.5100830606950983, 1.5552097364952306, 1.59671843378737, 1.635221205655121, 1.6711816205169887, 1.704959932300383, 1.7368421418769384, 1.7670594215246973, 1.7958015200236968, 1.8232262689306922, 1.8494664839616353, 1.8746350786649426, 1.8988289221159416, 1.9221317957887885, 1.9446166923683978, 1.9663476258882207, 1.9873810735805804, 2.007767136435218, 2.027550482286173, 2.0467711188920665, 2.065465032756621, 2.083664720922846, 2.1013996367097625, 2.1186965656961565, 2.1355799447448813, 2.152072134191548, 2.1681936512722437, 2.183963371278174, 2.1993987016862424, 2.214515733539884, 2.2293293735820354, 2.243853460025775, 2.2581008643532257, 2.2720835811334323, 2.2858128075249846, 2.2992990138636866, 2.312552006517556, 2.3255809840115185, 2.3383945872749803, 2.351000944741237, 2.3634077129237725, 2.3756221130072404, 2.3876509639174, 2.3995007122720162, 2.4111774595619155, 2.422686986866375, 2.434034777368526, 2.4452260369034797, 2.4562657127435017, 2.467158510800082, 2.4779089114016077, 2.4885211837869523, 2.4989993994393833, 2.5093474443712385, 2.519569030457699, 2.529667705907332, 2.539646864947731, 2.5495097567963922, 2.5592594939796793, 2.5688990600563826, 2.5784313167966806, 2.5878590108623167, 2.597184780029334, 2.606411158990752, 2.6155405847730266, 2.624575401796986, 2.6335178666111, 2.6423701523224317, 2.6511343527483158, 2.6598124863098143, 2.6684064996861254, 2.67691827124749, 2.68534961428265, 2.693702280035545, 2.70197796056474, 2.7101782914379524, 2.718304854273057, 2.7263591791360233, 2.734342746805436, 2.742256990912465, 2.7501032999644965, 2.7578830192599844, 2.765597452701527, 2.7732478645136465, 2.780835480871258, 2.788361491444405, 2.795827050864399, 2.803233280116169, 2.8105812678612585, 2.817872071695613, 2.8251067193460084, 2.8322862098087054, 2.839411514433677, 2.8464835779575224], [0.0, 0.9013344775740003, 1.0718733737282615, 1.1862228829132528, 1.2746794424196195, 1.3478094125129467, 1.41066469233948, 1.4660895354719874, 1.515857862273113, 1.5611571097717192, 1.602824543028034, 1.6414745557155297, 1.6775724890132342, 1.7114799745177744, 1.7434841068143214, 1.773816942221055, 1.8026689551480006, 1.8301985807252843, 1.8565391425776125, 1.881803986053052, 1.906090350669923, 1.929482338296274, 1.9520532207528385, 1.9738672568730735, 1.9949811398673623, 2.0154451623197245, 2.035304162881213, 2.0545983023065815, 2.0733637047177553, 2.091632991431688, 2.109435728401649, 2.126798803638806, 2.143746747456523, 2.160302005699947, 2.17648517406639, 2.1923152000292214, 2.207809557634348, 2.2229843994599543, 2.2378546892547706, 2.252434318151437, 2.2667362068547043, 2.280772395802786, 2.2945541249740162, 2.308091904744454, 2.3213955789832528, 2.3344743813919835, 2.3473369859443625, 2.3599915521581276, 2.3724457658265057, 2.384706875749129, 2.39678172692843, 2.408676790635081, 2.4203981916929957, 2.4319517332892318, 2.4433429195754983, 2.4545769762948617, 2.4656588696387556, 2.476593323514836, 2.487384835384989, 2.4980376908143476, 2.508555976856189, 2.5189435943835905, 2.529204269466543, 2.539341563882536, 2.549358884839239, 2.5592594939796793, 2.569046515733026, 2.5787229450676783, 2.588291654697687, 2.597755401788474, 2.6071168342033637, 2.616378496328452, 2.625542834509777, 2.6346122021336105, 2.6435888643778287, 2.652475002659807, 2.6612727188039766, 2.6699840389501666, 2.6786109172219916, 2.687155239172884, 2.6956188250258935, 2.7040034327220006, 2.7123107607904755, 2.720542451053711, 2.728700091177943, 2.7367852170803615, 2.7447993152022874, 2.7527438246573275, 2.760620139262745, 2.7684296094616325, 2.7761735441429227, 2.7838532123657354, 2.791469844994078, 2.7990246362474833, 2.8065187451727605, 2.813953297041666, 2.82132938467896, 2.8286480697250065, 2.835910383836774, 2.8431173298308474, 2.8502698827717983, 2.8573689910090505], [0.0, 0.904729394452974, 1.07591063303558, 1.190690844793804, 1.2794805799129934, 1.3528859973302676, 1.4159780243973923, 1.4716116276962383, 1.5215674091403395, 1.5670372782935749, 1.6088616538127065, 1.6476572435126322, 1.6838911413008757, 1.7179263408757495, 1.7500510181771018, 1.78049810357368, 1.809458788905948, 1.837092106057081, 1.8635318808212185, 1.8888918854667822, 1.9132697257691151, 1.9367498203697375, 1.9594057170709935, 1.981301916740128, 2.0024953261250538, 2.023036427239071, 2.0429702276200308, 2.0623370392899774, 2.0811731224339662, 2.09951122123861, 2.1173810130186723, 2.134809487060224, 2.15182126607116, 2.168438880439912, 2.184683003438414, 2.2005726539065464, 2.2161253717069958, 2.23135737025736, 2.2462836696680024, 2.260918213393139, 2.275273970803937, 2.2893630276894625, 2.303196666363934, 2.316785436791214, 2.3301392199178337, 2.343267284224516, 2.356178336355889, 2.368880566562882, 2.381381689587608, 2.393688981532629, 2.4058093131823877, 2.4177491801818887, 2.4295147304244695, 2.4411117889551543, 2.452545880657287, 2.4638222509569303, 2.4749458847509014, 2.4859215237396675, 2.4967536823250067, 2.5074466622138267, 2.518004565853474, 2.5284313088098407, 2.538730631187328, 2.5489061081790196, 2.5589611598259867, 2.5688990600563826, 2.5787229450676783, 2.5884358211089573, 2.5980405717144763, 2.607539964434645, 2.6169366571060855, 2.6262332036984364, 2.6354320597720093, 2.644535587577211, 2.6535460608238135, 2.6624656691455972, 2.67129652228361, 2.6800406540092285, 2.6887000258063614, 2.6972765303304627, 2.705771994660535, 2.714188183358922, 2.7225268013524806, 2.730789496647602, 2.7389778628905384, 2.7470934417835813, 2.755137725366799, 2.7631121581742852, 2.771018139273178, 2.778857024193075, 2.7866301267528977, 2.7943387207917345, 2.8019840418096975, 2.809567288524401, 2.8170896243482564, 2.824552178791406, 2.8319560487947846, 2.839302299997472, 2.84659196794222, 2.853826059222765, 2.861005552576305, 2.8681313999242652], [0.0, 0.9080865185231703, 1.0799029488658045, 1.1951090685408468, 1.2842282703036343, 1.3579060687170441, 1.4212322075130495, 1.4770722470235311, 1.5272133963327197, 1.5728519877504674, 1.6148315584236828, 1.6537711045472614, 1.6901394532455423, 1.72430094515537, 1.75654482553344, 1.7871048890689831, 1.8161730370463407, 1.8439088914585777, 1.8704467746790285, 1.8959008811439186, 1.9203691788083757, 1.943936399561014, 1.9666763641135123, 1.9886538126725424, 2.0099258631464076, 2.030543184868931, 2.0505509523846825, 2.0699896272990626, 2.08889560434558, 2.1073017492127, 2.1252378493369832, 2.1427309941519956, 2.159805897731609, 2.1764851740663906, 2.1927895731393208, 2.2087381843623266, 2.2243486126821925, 2.2396371316786525, 2.254618817196276, 2.269307664428403, 2.2837166908708535, 2.297858027158692, 2.31174299747073, 2.325382190917938, 2.338785525111471, 2.3519623029240355, 2.3649212633074757, 2.377670626903783, 2.3902181370816935, 2.402571096942758, 2.414736402766418, 2.4267205743006723, 2.43852978225147, 2.4501698732784742, 2.461646392765876, 2.472964605603619, 2.484129515185673, 2.495145880807243, 2.5060182336214227, 2.5167508912971996, 2.527347971504622, 2.537813404338831, 2.548150943782407, 2.5583641782946835, 2.5684565406072686, 2.5784313167966806, 2.588291654697687, 2.5980405717144763, 2.60768096208106, 2.6172156036172267, 2.626647164021871, 2.6359782067414907, 2.645211196448095, 2.6543485041575487, 2.6633924120165395, 2.6723451177837885, 2.681208739028831, 2.6899853170696337, 2.6986768206684646, 2.7072851495037384, 2.7158121374340882, 2.7242595555695113, 2.732629115163232, 2.7409224703367987, 2.7491412206499097, 2.7572869135255558, 2.765361046540228, 2.7733650695881646, 2.7813003869279362, 2.789168359119021, 2.7969703048554484, 2.8047075027030637, 2.8123811927464732, 2.8199925781513007, 2.827542826646959, 2.8350330719347965, 2.842464415026099, 2.849837925514148, 2.8571546427842196, 2.864415577165158, 2.8716217110259006, 2.8787739998201083], [0.0, 0.9114068171194505, 1.0838514715804344, 1.1994788272386536, 1.288923881609622, 1.362871073176282, 1.4264287556473265, 1.4824729668980785, 1.5327974507070874, 1.5786029136155242, 1.6207359770526288, 1.6598179004912503, 1.6963192252602788, 1.7306056241600476, 1.7629674000343882, 1.7936392024119794, 1.822813634238901, 1.850650901144984, 1.8772858166356072, 1.9028329926838916, 1.927390755451873, 1.9510441466391415, 1.9738672568730735, 1.9959250630743677, 2.017274891995427, 2.0379675982358103, 2.0580485215148534, 2.07755827138048, 2.096533375638743, 2.115006820147162, 2.133008501256132, 2.1505656074481596, 2.1677029431608688, 2.1844432050699005, 2.2008072190278125, 2.2168141442444482, 2.2324816500367577, 2.2478260694866745, 2.2628625335616044, 2.2776050886264665, 2.292066799773837, 2.3062598419928486, 2.3201955808676797, 2.3338846442269867, 2.3473369859443625, 2.3605619429072418, 2.3735682860202925, 2.3863642659832003, 2.3989576544773072, 2.411355781306992, 2.4235655679670325, 2.435593558044026, 2.4474459448062946, 2.4591285962910403, 2.4706470781584207, 2.482006674548756, 2.4932124071502657, 2.5042690526598896, 2.5151811587982853, 2.5259530590214276, 2.5365888860550827, 2.5470925843642664, 2.5574679216575, 2.5677184995148465, 2.577847763219244, 2.5878590108623167, 2.597755401788474, 2.607539964434645, 2.6172156036172267, 2.6267851073127395, 2.6362511529741663, 2.64561631342091, 2.654883062336727, 2.6640537794067902, 2.673130755122154, 2.682116195277356, 2.6910122251845436, 2.6998208936254953, 2.708544176560997, 2.7171839806153884, 2.725742146352564, 2.7342204513583517, 2.742620613142947, 2.750944291875976, 2.759193092965716, 2.7673685694931054, 2.775472224510327, 2.7835055132129654, 2.791469844994078, 2.7993665853878493, 2.807197057909939, 2.8149625458011003, 2.8226642936801456, 2.8303035091119138, 2.837881364095468, 2.845398996477385, 2.852857511294653, 2.860257982051381, 2.8676014519332202, 2.8748889349631486, 2.882121417102006, 2.889299857296944], [0.0, 0.9146912192286943, 1.0877573059372772, 1.203801343502716, 1.2935687276168015, 1.3677823998673804, 1.4315691227432643, 1.4878152983881654, 1.5383211346269172, 1.584291664941221, 1.6265765616977856, 1.665799323178612, 1.7024321863844938, 1.7368421418769384, 1.7693205386531026, 1.8001028718392538, 1.8293824384573887, 1.8573200214642784, 1.8840509201876072, 1.9096901596233076, 1.9343364202676692, 1.9580750502818227, 1.9809804072907224, 2.003117702369927, 2.0245444688580787, 2.0453117446175235, 2.0654650327566206, 2.0850450891663788, 2.1040885732867167, 2.1226285898450357, 2.140695142928072, 2.158315518996434, 2.1755146118745543, 2.192315200029222, 2.2087381843623266, 2.2248027931270293, 2.2405267593145264, 2.2559264748656567, 2.2710171252747196, 2.2858128075249846, 2.300326633791206, 2.314570822937062, 2.3285567815044543, 2.342295175621143, 2.3557959950311154, 2.3690686102687932, 2.3821218238462203, 2.3949639161958145, 2.407602687005432, 2.4200454924935872, 2.432299279097787, 2.4443706139855026, 2.4562657127435017, 2.467990464555409, 2.47955045513814, 2.490950987674271, 2.5021971019484877, 2.513293591871332, 2.5242450215519088, 2.535055740062504, 2.5457298950218306, 2.556271445109423, 2.5666841716113495, 2.576971689086552, 2.587137455233603, 2.597184780029334, 2.6071168342033637, 2.6169366571060855, 2.626647164021871, 2.6362511529741663, 2.6457513110645903, 2.6551502203841175, 2.6644503635308237, 2.673654128765463, 2.682763814833246, 2.6917816354776476, 2.700709723669722, 2.709550135574365, 2.718304854273057, 2.726975793260967, 2.7355647997347607, 2.744073657686083, 2.7525040908144573, 2.760857765272199, 2.7691362922529335, 2.77734123043438, 2.7854740882852114, 2.7935363262450457, 2.801529358785917, 2.809454556362933, 2.817313247261257, 2.825106719346008, 2.8328362217211835, 2.840502966303278, 2.8481081293148436, 2.855652852702871, 2.8631382454865286, 2.870565385038471, 2.877935318303638, 2.8852490629592036, 2.8925076085190775, 2.8997119173861328], [0.0, 0.9179406175334197, 1.0916215135207343, 1.2080777921692967, 1.2981640707688962, 1.3726413836620537, 1.4366547059245063, 1.493100693510252, 1.5437859493992674, 1.5899197878990334, 1.6323548997980941, 1.671716998327296, 1.708479998087565, 1.7430121933574254, 1.7756059681378888, 1.8064976541407807, 1.8358812350668394, 1.8639180650468632, 1.8907439240531478, 1.9164742457026112, 1.9412080610494473, 1.965031021450187, 1.9880177486818125, 2.010233685479216, 2.031736569565567, 2.052577620112862, 2.0728025018771485, 2.092452115532857, 2.1115632507508724, 2.1301691298616108, 2.1482998635399415, 2.1659828351803623, 2.1832430270414687, 2.2001032985094997, 2.2165846247358343, 2.232706302281114, 2.248486127132168, 2.2639405494614473, 2.279084808709018, 2.2939330519370325, 2.3084984379006395, 2.322793228870466, 2.3368288719096273, 2.3506160710368085, 2.3641648514841025, 2.3774846170743213, 2.3905842015900256, 2.403471914879488, 2.4161555843385933, 2.4286425923184853, 2.4409399099335674, 2.45305412768087, 2.4649914832277466, 2.476757886678874, 2.488358943594169, 2.499799975995519, 2.5110860415712124, 2.5222219512619364, 2.533212285390583, 2.5440614084793167, 2.5547734828810733, 2.5653524813384143, 2.575802198570253, 2.586126261976083, 2.5963281415377923, 2.606411158990752, 2.616378496328452, 2.6262332036984364, 2.6359782067414907, 2.64561631342091, 2.6551502203841175, 2.664582518894846, 2.673915700370487, 2.6831521615559804, 2.6922942093627227, 2.701344065398411, 2.71030387021138, 2.719175687270956, 2.7279615067034255, 2.7366632488015608, 2.7452827673241074, 2.753821852600259, 2.762282234452902, 2.77066558495328, 2.7789735210187105, 2.7872076068640426, 2.7953693563167143, 2.803460235004489, 2.8114816624242462, 2.819435013899572, 2.8273216224343027, 2.835142780468637, 2.8428997415439574, 2.8505937218820367, 2.8582259018839014, 2.8657974275532574, 2.8733094118490126, 2.8807629359711373, 2.8881590505837953, 2.8954987769794123, 2.9027831081870996, 2.910013010028622], [0.0, 0.9211558703193814, 1.0954451150103321, 1.212309302805974, 1.3027111248652612, 1.3774493079968595, 1.4416868484808525, 1.4983305483318308, 1.5491933384829668, 1.5954887690834965, 1.63807251762544, 1.6775724890132342, 1.71446425781928, 1.7491174083393233, 1.7818253487021416, 1.8128252384140606, 1.8423117406387628, 1.8704467746790285, 1.8973665961010275, 1.9231870428487672, 1.9480074928505935, 1.971913897472381, 1.9949811398673623, 2.017274891995427, 2.038853093816547, 2.0597671439071177, 2.0800628669722427, 2.09978130694835, 2.1189593823687916, 2.1376304319311945, 2.1558246717785052, 2.173569581220506, 2.1908902300206643, 2.207809557634348, 2.224348612682192, 2.240526759314526, 2.256361855851836, 2.271870410086274, 2.2870677148367973, 2.3019679667181965, 2.316584370576538, 2.3309292316332666, 2.345014037046902, 2.3588495283288893, 2.3724457658265057, 2.385812186301152, 2.3989576544773072, 2.411890509309988, 2.424618605611948, 2.4371493515923475, 2.449489742783178, 2.4616463927658754, 2.47362556105635, 2.4854331784604873, 2.4970748701726904, 2.508555976856189, 2.519881573914738, 2.531056489140214, 2.5420853188989163, 2.5529724430005367, 2.563722038377404, 2.5743380916873284, 2.584824410940911, 2.5951846362432667, 2.6054222497305224, 2.6155405847730266, 2.625542834509777, 2.6354320597720093, 2.645211196448095, 2.654883062336727, 2.6644503635308237, 2.673915700370487, 2.6832815729997477, 2.6925503865585774, 2.701724456038747, 2.7108060108295344, 2.7197971989769334, 2.728700091177943, 2.7375166845296266, 2.746248906050928, 2.754898615993719, 2.763467610958144, 2.771957626826106, 2.7803703415255807, 2.7887073776374303, 2.796970304855448, 2.8051606423095277, 2.8132798607610567, 2.8213293846789598, 2.8293105942041428, 2.837224827009527, 2.8450733800623182, 2.852857511294653, 2.86057844118834, 2.8682373542789747, 2.8758354005843474, 2.883373696961705, 2.890853328398117, 2.898275349237888, 2.9056407843507035, 2.9129506302439405, 2.920205856122328], [0.0, 0.9243378032579611, 1.0992290923003527, 1.2164969620573964, 1.3072110575815623, 1.3822074075384925, 1.4466668426578508, 1.5035062058706188, 1.5545446904862257, 1.6010000385993937, 1.643730883454241, 1.6833672989163568, 1.7203865023272384, 1.7551593546313318, 1.7879802774720857, 1.8190872495718449, 1.8486756065159222, 1.8769078269221715, 1.9039206370220298, 1.9298302748965297, 1.954736461753492, 1.9787254458591215, 2.001872369034244, 2.024243130088275, 2.045895869122197, 2.066882162257628, 2.0872479924911636, 2.1070345455365995, 2.126278867454344, 2.145014412103317, 2.1632715000015685, 2.181077705380191, 2.1984581846007054, 2.215435956357848, 2.232032141980142, 2.248266172507171, 2.264155967947111, 2.2797180931146976, 2.29496789365461, 2.3099196152207635, 2.324586508272497, 2.33898092053697, 2.3531143788525988, 2.3669976618350463, 2.3806408645828756, 2.3940534564547304, 2.4072443327963553, 2.4202218613678763, 2.432993924114793, 2.4455679548363145, 2.4579509732289795, 2.4701496157194045, 2.4821701634456383, 2.4940185677002478, 2.5057004731086487, 2.5172212387822324, 2.5285859576566336, 2.5397994742002874, 2.550866400656643, 2.561791131964494, 2.5725778594844746, 2.583230583645438, 2.593753125611932, 2.604149138063024, 2.6144221151631246, 2.624575401796986, 2.6346122021336105, 2.644535587577211, 2.6543485041575487, 2.6640537794067902, 2.673654128765463, 2.6831521615559804, 2.6925503865585774, 2.7018512172212596, 2.711056976532434, 2.7201699015823206, 2.7291921478368706, 2.7381257931458567, 2.74697284150488, 2.755735226589354, 2.764414815076985, 2.7730134097738834, 2.7815327525581792, 2.789974527153886, 2.798340361746719, 2.8066318314526386, 2.814850460649042, 2.822997725177743, 2.8310750544281853, 2.8390838333086705, 2.8470254041128222, 2.854901068287936, 2.8627120881114037, 2.870459688280922, 2.8781450574238083, 2.8857693495303387, 2.8933336853157017, 2.900839153514819, 2.908286812113998, 2.9156776895231156, 2.923012785691765, 2.930293073172584], [0.0, 0.9274872110731568, 1.1029743904822287, 1.220641815839165, 1.311664992827256, 1.386916870676514, 1.451595932265776, 1.508628958806044, 1.5598413419701658, 1.6064549729490671, 1.6493314105258192, 1.689102875356448, 1.726248210759469, 1.7611395412783635, 1.7940722917112943, 1.8252852516227527, 1.8549744221463136, 1.8833028354976902, 1.9104076837625343, 1.9364056010687778, 1.961396648394778, 1.9854673678722108, 2.0086931573454425, 2.0311401401546014, 2.0528666544958774, 2.0739244522212745, 2.094359673000858, 2.1142136428765665, 2.133523534132309, 2.152322914611139, 2.1706422081393097, 2.1885090828989533, 2.2059487809644573, 2.2229843994599547, 2.2396371316786525, 2.2559264748656567, 2.271870410086274, 2.28748555859495, 2.3027873183221113, 2.3177899834595275, 2.332506849613561, 2.3469503065826007, 2.361131920479358, 2.375062506644442, 2.3887521945724806, 2.4022104858861564, 2.4154463062394758, 2.4284680519032347, 2.44128363167833, 2.4539005046924456, 2.46632571455966, 2.478565920318253, 2.4906274245073927, 2.5025161986969175, 2.5142379067446345, 2.5257979260215238, 2.5372013668158924, 2.5484530901022695, 2.5595577238389606, 2.570519677939213, 2.5813431580444846, 2.592032178213907, 2.6025905726315153, 2.613022006421803, 2.623329985654512, 2.6335178666111, 2.6435888643778287, 2.6535460608238135, 2.6633924120165395, 2.673130755122154, 2.682763814833246, 2.6922942093627227, 2.701724456038747, 2.711056976532434, 2.7202941017470885, 2.7294380763951525, 2.738491063286691, 2.747455147351135, 2.7563323394121095, 2.765124579733454, 2.773833741353028, 2.7824616332194707, 2.7910100031458467, 2.799480540592961, 2.8078748792940913, 2.8161945997319395, 2.8244412314777683, 2.832616255401886, 2.840721105763958, 2.8487571721909526, 2.8567258015499606, 2.864628299722576, 2.8724659332870264, 2.8802399311138047, 2.8879514858801243, 2.895601755508142, 2.903191864531552, 2.9107229053948185, 2.9181959396890242, 2.9256119993280487, 2.932972087668518, 2.9402771805767554], [0.0, 0.9306048591020996, 1.1066819197003215, 1.224744871391589, 1.3160740129524924, 1.3915788418568702, 1.4564753151219703, 1.5137000520175454, 1.5650845800732873, 1.6118548977353129, 1.6548754598234365, 1.694780612135097, 1.7320508075688774, 1.7670594215246977, 1.800102871839254, 1.831420750742353, 1.8612097182041991, 1.8896333544556798, 1.9168293127388174, 1.9429146192345599, 1.9679896712654303, 1.9921413018651277, 2.0154451623197245, 2.0379675982358108, 2.0597671439071177, 2.080895725143909, 2.101399636709763, 2.121320343559643, 2.1406951429280725, 2.159557715492783, 2.177938587346431, 2.195865519674754, 2.213363839400643, 2.230456721286719, 2.2471654298651536, 2.263509527918935, 2.2795070569547775, 2.295174694097678, 2.3105278890365413, 2.325580984011519, 2.340347319320716, 2.3548393264094916, 2.3690686102687937, 2.38304602259383, 2.39678172692843, 2.410285256833955, 2.4235655679670325, 2.4366310848216144, 2.449489742783178, 2.4621490260524586, 2.4746160019198826, 2.4868973518073663, 2.4989993994393833, 2.5109281364585576, 2.5226892457611436, 2.5342881227935714, 2.5457298950218306, 2.557019439760091, 2.5681614005230395, 2.579160202047371, 2.5900200641113513, 2.600745014266939, 2.611338899586365, 2.6218053975140414, 2.6321480259049848, 2.6423701523224317, 2.652475002659807, 2.6624656691455972, 2.6723451177837885, 2.682116195277356, 2.6917816354776476, 2.701344065398411, 2.7108060108295344, 2.7201699015823206, 2.7294380763951525, 2.7386127875258306, 2.7476962050544724, 2.756690420918775, 2.7655974527015275, 2.774419247188558, 2.7831576837137404, 2.791814577306299, 2.8003916816543826, 2.808890691897737, 2.8173132472612576, 2.8256609335402674, 2.833935285447518, 2.8421377888311037, 2.8502698827717983, 2.8583329615676507, 2.8663283766131, 2.874257438179321, 2.882121417102006, 2.8899215463823635, 2.8976590227066628, 2.905335007889291, 2.9129506302439405, 2.920506985887209, 2.928005139978604, 2.9354461279006707, 2.9428309563827115, 2.9501606045713182], [0.0, 0.9336914847572161, 1.110352556890736, 1.2288070992040003, 1.320439160815927, 1.3961944237683348, 1.4613061453392517, 1.5187206849628931, 1.5702756449705226, 1.6172010901939202, 1.6603643426724282, 1.7004018521985302, 1.7377956652346387, 1.772920395590378, 1.8060734442596784, 1.8374951981506853, 1.8673829695144322, 1.8959008811439184, 1.9231870428487672, 1.949358868961793, 1.9745170898028677, 1.9987488264130728, 2.0221299809982978, 2.0447271192199157, 2.066598969517919, 2.087797629929844, 2.108369548769516, 2.1283563285226585, 2.1477953901310802, 2.16672052598442, 2.1851623634241295, 2.203148755714112, 2.220705113781472, 2.2378546892547706, 2.254618817196276, 2.271017125274719, 2.287067714836797, 2.3027873183221113, 2.3181914366630214, 2.333294459669949, 2.348109771888037, 2.362649845995201, 2.376926325473765, 2.3909500980117886, 2.4047313608634924, 2.418279679211108, 2.431604038415341, 2.4447128909124634, 2.4576141984080007, 2.470315469926249, 2.4828237961983883, 2.495145880807243, 2.5072880684517855, 2.5192563706476903, 2.531056489140214, 2.542693837271378, 2.5541735595139254, 2.5655005493590783, 2.5766794657231107, 2.5877147480186613, 2.598610630020137, 2.6093711526380607, 2.6200001757046136, 2.630501388861538, 2.640878321631854, 2.6511343527483158, 2.6612727188039766, 2.67129652228361, 2.681208739028831, 2.6910122251845436, 2.700709723669722, 2.71030387021138, 2.7197971989769334, 2.7291921478368706, 2.738491063286691, 2.7476962050544724, 2.7568097504180447, 2.765833798253632, 2.7747703728359334, 2.783621427407866, 2.7923888475366696, 2.801074454271648, 2.8096800071175756, 2.8182072068366284, 2.8266576980906746, 2.8350330719347965, 2.843334868172072, 2.8515645775788507, 2.859723644009041, 2.867813466385294, 2.875835400584347, 2.883790761223275, 2.891680823352873, 2.8995068240639617, 2.907269964011973, 2.914971408864794, 2.9226122906785035, 2.9301937092052928, 2.9377167331375857, 2.9451824012920786, 2.9525917237371893, 2.9599456828671373], [0.0, 0.9367477988974472, 1.1139871474119822, 1.2328294348193778, 1.3247614417239144, 1.4007646793929587, 1.4660895354719874, 1.5236920139085786, 1.5754157321793416, 1.6224947815686916, 1.665799323178612, 1.70596789013482, 1.7434841068143216, 1.7787238132749208, 1.8119853840129065, 1.8435099928108025, 1.8734955977948944, 1.9021068589921832, 1.9294823382962738, 1.9557398343800885, 1.9809804072907224, 2.005291463248328, 2.0287491529145085, 2.0514202598444236, 2.0733637047177553, 2.0946317561079946, 2.115271014371307, 2.135323218173586, 2.1548259109490866, 2.173812995702313, 2.1923152000292214, 2.210360468367647, 2.2279742948239645, 2.2451800071378294, 2.2619990102089815, 2.2784509959547, 2.2945541249740162, 2.3103251844779353, 2.3257797261390447, 2.3409321868708846, 2.3557959950311154, 2.3703836641252947, 2.384706875749129, 2.398776553230067, 2.4126029272016765, 2.4261955941565336, 2.4395635688677193, 2.4527153314394257, 2.4656588696387556, 2.4784017170697905, 2.4909509876742715, 2.5033134069783034, 2.5154953404493816, 2.5275028192810733, 2.5393415638825356, 2.5510170053156402, 2.5625343048928735, 2.573898372123646, 2.5851138811745704, 2.5961852859901096, 2.607116834203364, 2.6179125799522365, 2.6285763957035524, 2.6391119831766026, 2.649522883447829, 2.6598124863098143, 2.6699840389501666, 2.6800406540092285, 2.6899853170696337, 2.6998208936254953, 2.709550135574365, 2.719175687270956, 2.728700091177943, 2.7381257931458567, 2.747455147351135, 2.756690420918775, 2.765833798253632, 2.7748873851023217, 2.783853212365736, 2.7927332396804703, 2.8015293587859174, 2.8102433966923415, 2.818877118664021, 2.827432231030349, 2.835910383836774, 2.844313173346485, 2.8526421444028993, 2.8608987926622222, 2.869084566704626, 2.8772008700319467, 2.8852490629592036, 2.893230464406695, 2.9011463535989224, 2.90899797167616, 2.9167865232240224, 2.9245131777260567, 2.932179070943975, 2.9397853062298593, 2.9473329557743555, 2.9548230617945888, 2.962256637665299, 2.9696346689964424], [0.0, 0.9397744871152784, 1.1175865065755222, 1.236812780528175, 1.3290418252506462, 1.4052906339306293, 1.4708265585304046, 1.5286151540232698, 1.5805059947242717, 1.6277371593406456, 1.6711816205169887, 1.7114799745177744, 1.7491174083393235, 1.7844709764011664, 1.8178400172654527, 1.8494664839616353, 1.879548974230557, 1.9082526801256237, 1.9357166112422137, 1.9620589468678131, 1.9873810735805804, 2.011770680015397, 2.0353041628812134, 2.058048521514854, 2.080062866972243, 2.101399636709763, 2.1221055816521197, 2.1422225753253343, 2.1617882824687458, 2.180836715629496, 2.1993987016862424, 2.2175022753669724, 2.2351730131510443, 2.2524343181514372, 2.2693076644284034, 2.2858128075249846, 2.301967966718197, 2.3177899834595275, 2.333294459669949, 2.348495878909535, 2.3634077129237725, 2.3780425156501046, 2.392412006428173, 2.4065271438793507, 2.4203981916929957, 2.434034777368526, 2.4474459448062946, 2.460640201510217, 2.47362556105635, 2.4864095813903013, 2.4989993994393833, 2.5114017624602782, 2.5236230564876885, 2.5356693322023287, 2.54754632849634, 2.55925949397968, 2.5708140066413447, 2.582214791853664, 2.5934665388857625, 2.6045737160730646, 2.615540584773027, 2.626371212222715, 2.6370694834011266, 2.6476391119880285, 2.6580836505012924, 2.6684064996861254, 2.6786109172219916, 2.6887000258063614, 2.6986768206684646, 2.708544176560997, 2.718304854273057, 2.7279615067034255, 2.7375166845296266, 2.74697284150488, 2.7563323394121095, 2.7655974527015275, 2.7747703728359334, 2.783853212365736, 2.7928480087537886, 2.8017567279683915, 2.8105812678612585, 2.8193234613458356, 2.827985079390074, 2.8365678338366203, 2.8450733800623187, 2.8535033194879786, 2.8618592019485005, 2.8701425279326442, 2.8783547507010305, 2.8864972782902947, 2.8945714754107152, 2.9025786652440995, 2.910520131148202, 2.9183971182734942, 2.9262108350976797, 2.933962454882976, 2.941653117060809, 2.9492839285482595, 2.9568559650002837, 2.9643702720014726, 2.9718278662008415, 2.979229736392911], [0.0, 0.9427722109457612, 1.1211514210835454, 1.2407580069594817, 1.333281246947964, 1.4097732766069795, 1.4755182498728112, 1.533491181344376, 1.5855475451702188, 1.6329293693221016, 1.6765124110817191, 1.716939310108757, 1.75469680106511, 1.790163141111003, 1.8236386236486597, 1.8553659734973313, 1.8855444218915225, 1.9143396878197294, 1.9418912242947493, 1.9683175875762793, 1.993720487648747, 2.0181878928591512, 2.0417964436091975, 2.0646133529524175, 2.086697920499143, 2.1081027509724937, 2.128874744424825, 2.149055907951721, 2.1686840264367557, 2.1877932209214217, 2.2064144166169766, 2.2245757376775126, 2.2423028421670907, 2.259619207850716, 2.27654637728731, 2.293104169036802, 2.3093108604926607, 2.3251833468277954, 2.340737279730703, 2.355987188961597, 2.370946589238585, 2.3856280745440763, 2.4000434016004517, 2.414203563985258, 2.4281188581273097, 2.441798942236141, 2.455252889060639, 2.4684892332422375, 2.4815160139189634, 2.4943408131450107, 2.5069707906132983, 2.519412715103133, 2.531672993019601, 2.5437576943440803, 2.5556725762748194, 2.567423104801933, 2.579014474431339, 2.5904516262464825, 2.6017392644744746, 2.612881871703984, 2.6238837228854868, 2.6347488982298564, 2.6454812951085245, 2.656084639047278, 2.666562493895928, 2.67691827124749, 2.687155239172884, 2.6972765303304627, 2.7072851495037384, 2.7171839806153884, 2.726975793260967, 2.7366632488015608, 2.746248906050928, 2.755735226589354, 2.765124579733454, 2.774419247188558, 2.783621427407866, 2.7927332396804703, 2.8017567279683915, 2.8106938645110393, 2.819546553213959, 2.8283166328372835, 2.8370058799980575, 2.84561601199942, 2.85414868949859, 2.862605519024644, 2.8709880553561957, 2.879297803768314, 2.887536222157279, 2.895704723051128, 2.903804675513337, 2.9118374069464434, 2.919804204801898, 2.927706318201995, 2.93554495947928, 2.943321305638482, 2.9510364997456224, 2.9586916522486626, 2.9662878422337196, 2.973826118620624, 2.9813075013013313, 2.988732982224453], [0.0, 0.9457416090031757, 1.1246826503806981, 1.2446659545769565, 1.337480609952844, 1.414213562373095, 1.4801656089845705, 1.5383211346269172, 1.5905414575341013, 1.63807251762544, 1.681792830507429, 1.722347059926734, 1.7602234735867868, 1.7958015200236968, 1.8293824384573887, 1.861209718204199, 1.8914832180063514, 1.9203691788083757, 1.9480074928505935, 1.9745170898028677, 1.9999999999999998, 2.0245444688580787, 2.0482273781688902, 2.0711161526832442, 2.0932702787842112, 2.114742526881128, 2.1355799447448813, 2.1558246717785052, 2.1755146118745543, 2.194683993543699, 2.213363839400643, 2.2315823621805877, 2.2493653007613963, 2.266736206854704, 2.283716690870853, 2.300326633791206, 2.316584370576538, 2.3325068496135604, 2.348109771888037, 2.363407712923772, 2.378414230005442, 2.3931419567820336, 2.407602687005432, 2.421807448879054, 2.435766571261813, 2.449489742783178, 2.4629860647679758, 2.476264098738734, 2.489331909153913, 2.5021971019484877, 2.5148668593658705, 2.5273479715046214, 2.539646864947731, 2.551769628794865, 2.563722038377404, 2.575509576901394, 2.587137455233603, 2.598610630020137, 2.609933820304753, 2.621111522794684, 2.6321480259049848, 2.643047422697745, 2.6538136228197344, 2.664450363530824, 2.674961219905688, 2.68534961428265, 2.6956188250258935, 2.705771994660535, 2.7158121374340882, 2.725742146352564, 2.7355647997347607, 2.7452827673241074, 2.754898615993719, 2.764414815076985, 2.773833741353028, 2.7831576837137404, 2.7923888475366696, 2.8015293587859174, 2.8105812678612585, 2.819546553213959, 2.82842712474619, 2.837224827009527, 2.845941442216729, 2.8545786930798287, 2.8631382454865286, 2.8716217110259006, 2.8800306493735595, 2.8883665705456574, 2.8966309370303307, 2.904825165804578, 2.91295063024394, 2.921008661931802, 2.9290005523746294, 2.936927554629009, 2.9447908848459035, 2.9525917237371893, 2.960331217969141, 2.968010481487236, 2.975630596776331, 2.983192616059981, 2.990697562442441, 2.998146430996607], [0.0, 0.9486832980505138, 1.128180927925918, 1.2485374350863452, 1.3416407864998738, 1.4186124135047635, 1.4847696011519296, 1.5431060170831203, 1.5954887690834967, 1.6431676725154982, 1.6870239755710472, 1.7277043471959719, 1.7656985738296271, 1.8013872842666538, 1.8350726547187572, 1.8669989318654348, 1.8973665961010275, 1.9263424054554514, 1.9540666872978918, 1.9806587412238905, 2.006220914929266, 2.0308417283137197, 2.0545983023065815, 2.07755827138048, 2.09978130694835, 2.121320343559643, 2.142222575325334, 2.162530272721279, 2.182281457538478, 2.2015104647539276, 2.2202484134768556, 2.238523604196976, 2.256361855851836, 2.2737867934096694, 2.2908200944990793, 2.3074817019403757, 2.32379000772445, 2.3397620129552488, 2.355413467455784, 2.370758992086407, 2.3858121863011523, 2.400585723045433, 2.4150914327550987, 2.429340377936324, 2.4433429195754983, 2.45710877643816, 2.4706470781584207, 2.483966412889059, 2.4970748701726904, 2.5099800796022267, 2.5226892457611436, 2.535209179868313, 2.54754632849634, 2.5597067996847738, 2.5716963867289198, 2.5835205898901012, 2.5951846362432662, 2.606693497851958, 2.618051908438318, 2.6292643786963965, 2.6403352103801803, 2.6512685092830544, 2.662068197212579, 2.6727380230532125, 2.6832815729997477, 2.693702280035545, 2.7040034327220006, 2.714188183358922, 2.7242595555695113, 2.7342204513583517, 2.744073657686083, 2.753821852600259, 2.763467610958144, 2.7730134097738834, 2.7824616332194707, 2.791814577306299, 2.801074454271648, 2.8102433966923415, 2.8193234613458356, 2.8283166328372835, 2.837224827009527, 2.8460498941515415, 2.85479362201958, 2.8634577386841014, 2.8720439152144785, 2.8805537682125633, 2.8889888622052755, 2.8973507119056077, 2.9056407843507035, 2.9138605009250087, 2.92201123927589, 2.9300943351285653, 2.9381110840066778, 2.946062742864391, 2.953950531635456, 2.9617756347043014, 2.969539202303859, 2.9772423518444873, 2.9848861691780644, 2.9924717098010434, 3.0, 3.0074720379429634], [0.0, 0.9515978740065268, 1.1316469623900245, 1.2523732327608301, 1.345762619345434, 1.4229707211083644, 1.489331159038138, 1.547846798020459, 1.6003904820302886, 1.6482158661538315, 1.6922069059826197, 1.7330122571800355, 1.771123210923403, 1.8069215653876352, 1.8407104251401096, 1.872734787242987, 1.9031957480130537, 1.9322605777997164, 1.960070035090509, 1.986743785997105, 2.0123844926512717, 2.037080946906452, 2.0609105066254236, 2.0839410140696626, 2.1062323239765757, 2.1278375335228743, 2.14880398181083, 2.1691740691810413, 2.1889859342363023, 2.208274017438652, 2.2270695335024673, 2.245400869863155, 2.263293924780049, 2.2807723958027863, 2.297858027158692, 2.3145708229370623, 2.3309292316332666, 2.3469503065826007, 2.362649845995201, 2.378042515650104, 2.393141956782034, 2.407960881270643, 2.4225111558976327, 2.4368038771557736, 2.450849437862816, 2.4646575866426104, 2.478237481177628, 2.4915977360054535, 2.5047464655216602, 2.5176913227590454, 2.5304395344352426, 2.542997932694775, 2.5553729839156167, 2.5675708149026395, 2.579597236749499, 2.5914577666156022, 2.603157647634689, 2.6147018671456377, 2.626095173413688, 2.6373420909907916, 2.648446934846925, 2.659413823389427, 2.6702466904745625, 2.680949296504237, 2.691525238690868, 2.70197796056474, 2.7123107607904755, 2.7225268013524806, 2.732629115163232, 2.742620613142947, 2.7525040908144573, 2.762282234452902, 2.771957626826106, 2.7815327525581792, 2.7910100031458467, 2.8003916816543826, 2.8096800071175756, 2.818877118664021, 2.827985079390074, 2.8370058799980575, 2.845941442216729, 2.85479362201958, 2.8635642126552705, 2.8722549475032912, 2.8808675027669306, 2.8894035000146174, 2.8978645085798624, 2.906252047829209, 2.9145675893068805, 2.9228125587641465, 2.9309883380808275, 2.9390962670858003, 2.9471376452828575, 2.9551137334878192, 2.963025755382357, 2.9708748989896043, 2.978662318076276, 2.986389133485675, 2.9940564344056693, 3.0016652795754433, 3.009216698434564, 3.0167116922176644], [0.0, 0.9544859128947005, 1.1350814387842454, 1.2561741056899516, 1.34984692310975, 1.4272893465399143, 1.4938511841686706, 1.5525444143852343, 1.6052475651266458, 1.653218096242383, 1.6973426460728507, 1.7382718389100207, 1.7764984569686235, 1.812405457156695, 1.8462968639446533, 1.8784184179451258, 1.908971825789401, 1.938124865481734, 1.9660187227026953, 1.9927734267429793, 2.0184919513073796, 2.0432633577269526, 2.0671652386406607, 2.090265642206917, 2.1126246048184423, 2.1342953847984933, 2.1553254649205007, 2.175757374207393, 2.1956293670101927, 2.2149759883155467, 2.2338285475724984, 2.2522155183705133, 2.2701628775684908, 2.2876943946366195, 2.3048318797945697, 2.3215953978427732, 2.338003453266607, 2.3540731511571518, 2.3698203376711047, 2.385259723097208, 2.4004049900704616, 2.415268889050264, 2.429863322833242, 2.4441994215893144, 2.4582876096777713, 2.472137665308914, 2.4857587739581977, 2.4991595763077785, 2.512348211379903, 2.5253323554338367, 2.5381192571198388, 2.5507157693175553, 2.5631283780300076, 2.575363228656527, 2.5874261499270697, 2.5993226757452694, 2.611058065157442, 2.6226373206387223, 2.6340652048650317, 2.645346256120049, 2.65648480246941, 2.6674849748195557, 2.678350718965756, 2.6890858067224945, 2.6996938462195, 2.7101782914379524, 2.720542451053711, 2.730789496647602, 2.7409224703367987, 2.750944291875976, 2.760857765272199, 2.77066558495328, 2.7803703415255807, 2.789974527153886, 2.799480540592961, 2.808890691897737, 2.8182072068366284, 2.827432231030349, 2.8365678338366203, 2.84561601199942, 2.8545786930798287, 2.8634577386841014, 2.8722549475032912, 2.8809720581775866, 2.889610751997445, 2.898172655452653, 2.9066593426395477, 2.9150723375358543, 2.9234131161518375, 2.9316831085658324, 2.939883700851576, 2.94801623690424, 2.956082020171529, 2.964082315295759, 2.972018349672396, 2.9798913149301494, 2.987702368337341, 2.995452634138963, 3.003143204828499, 3.0107751423583387, 3.018349479292333, 3.0258672199037986], [0.0, 0.9573479717381596, 1.1384850195244434, 1.259940786957369, 1.3538944855424797, 1.4315691227432643, 1.4983305483318308, 1.5571997722182047, 1.6100609551700658, 1.658175327573506, 1.7024321863844938, 1.7434841068143216, 1.7818253487021418, 1.8178400172654527, 1.8518330486025054, 1.884050920187607, 1.914695943476319, 1.9439363995610137, 1.971913897472381, 1.9987488264130728, 2.0245444688580787, 2.04939015319192, 2.0733637047177553, 2.096533375638743, 2.1189593823687916, 2.1406951429280725, 2.1617882824687453, 2.182281457538478, 2.2022130371952797, 2.2216176700101276, 2.2405267593145264, 2.2589688640769774, 2.2769700390488867, 2.2945541249740162, 2.31174299747073, 2.3285567815044543, 2.345014037046902, 2.361131920479358, 2.376926325473765, 2.3924120064281724, 2.407602687005432, 2.4225111558976327, 2.4371493515923475, 2.4515284376336917, 2.4656588696387556, 2.47955045513814, 2.4932124071502657, 2.50665339226667, 2.519881573914738, 2.5329046513712625, 2.5457298950218306, 2.558364178294683, 2.5708140066413443, 2.583085543888338, 2.5951846362432662, 2.607116834203364, 2.618887412584378, 2.6305013888615374, 2.641963539991811, 2.6532784178670767, 2.6644503635308237, 2.6754835202761598, 2.686381845729956, 2.6971491230166134, 2.7077889710849594, 2.718304854273057, 2.728700091177943, 2.7389778628905384, 2.7491412206499097, 2.759193092965716, 2.7691362922529335, 2.7789735210187105, 2.7887073776374303, 2.798340361746719, 2.8078748792940913, 2.8173132472612576, 2.8266576980906746, 2.835910383836774, 2.8450733800623187, 2.85414868949859, 2.8631382454865286, 2.8720439152144785, 2.8808675027669306, 2.889610751997445, 2.898275349237888, 2.9068629258551293, 2.9153750606654905, 2.9238132822163942, 2.932179070943975, 2.9404738612147048, 2.948699043258512, 2.9568559650002832, 2.9649459337961566, 2.9729702180805213, 2.9809300489292307, 2.9888266215441335, 2.9966610966636615, 3.004434601903893, 3.012148233034192, 3.0198030551912485, 3.027400104035091, 3.034940386850385], [0.0, 0.9601845894041878, 1.1418583454354265, 1.2636739857523107, 1.357906068717044, 1.4358108555129503, 1.502770094900495, 1.561813748028264, 1.6148315584236825, 1.6630884934927144, 1.7074764851741444, 1.748650042256635, 1.7871048890689831, 1.8232262689306922, 1.8573200214642784, 1.8896333544556796, 1.9203691788083757, 1.9496962742308461, 1.9777566693406925, 2.004671110053224, 2.0305431848689306, 2.0554624868519302, 2.079507071901399, 2.102745394451461, 2.1252378493369832, 2.1470380128554885, 2.1681936512722433, 2.188747547526072, 2.208738184362327, 2.228200313015543, 2.247165429865153, 2.2656621784997513, 2.283716690870853, 2.301352878362235, 2.3185926814096187, 2.3354562846086107, 2.3519623029240355, 2.3681279435714577, 2.3839691473156965, 2.3995007122720162, 2.414736402766418, 2.4296890453838276, 2.4443706139855026, 2.4587923051930876, 2.4729646056036185, 2.4868973518073663, 2.50059978412088, 2.514080594814771, 2.5273479715046214, 2.5404096362801454, 2.5532728810690504, 2.565944599665513, 2.5784313167966806, 2.590739214552467, 2.602874156462761, 2.6148417094708947, 2.626647164021871, 2.6382955524576737, 2.6497916658893743, 2.6611400696960854, 2.6723451177837885, 2.683410965722149, 2.6943415828644692, 2.70514076354453, 2.715812137434088, 2.7263591791360233, 2.7367852170803615, 2.7470934417835813, 2.7572869135255558, 2.7673685694931054, 2.77734123043438, 2.7872076068640426, 2.796970304855448, 2.8066318314526386, 2.8161945997319395, 2.8256609335402674, 2.8350330719347965, 2.844313173346485, 2.8535033194879786, 2.862605519024644, 2.8716217110259006, 2.8805537682125633, 2.8894035000146174, 2.898172655452653, 2.9068629258551293, 2.9154759474226504, 2.9240133036495615, 2.932476527612365, 2.9408671041337215, 2.949186471830124, 2.957436025050745, 2.9656171157143674, 2.973731055050819, 2.981779115252854, 2.989762531043999, 2.9976825011674793, 3.00554018980099, 3.0133367279017307, 3.0210732144858237, 3.0287507178459556, 3.036370276710811, 3.0439329013496343], [0.0, 0.9629962874017586, 1.1452020366993765, 1.2673743884191842, 1.3618824101585059, 1.4400153246867797, 1.507170640080316, 1.5663871900896853, 1.6195602519575492, 1.6679584972800465, 1.7124764698304722, 1.7537705949883924, 1.7923380487067173, 1.828565202408735, 1.8627587913037733, 1.8951667470736167, 1.9259925748035172, 1.955405548437723, 1.983548112494678, 2.0105413664686305, 2.03648920219714, 2.0614814750987107, 2.085596469642752, 2.1089028407177555, 2.1314611600121216, 2.153325160710257, 2.1745427489508584, 2.1951568329535602, 2.2152060081523164, 2.2347251275433204, 2.2537457797365072, 2.2722966921971777, 2.290404073398753, 2.308091904744454, 2.325382190917938, 2.342295175621143, 2.3588495283288893, 2.375062506644442, 2.3909500980117886, 2.4065271438793503, 2.421807448879054, 2.436803877155773, 2.4515284376336917, 2.465992359721398, 2.480206160723717, 2.4941797060352964, 2.5079222630310047, 2.5214425494349326, 2.5347487768383683, 2.547848689943536, 2.5607496020310148, 2.5734584270820036, 2.585981708929937, 2.5983256477676733, 2.610496124295213, 2.6224987217575073, 2.63433874609151, 2.6460212443753583, 2.65755102174988, 2.6689326569629386, 2.6801705166700103, 2.691268768609469, 2.7022313937580313, 2.713062197560384, 2.7237648203170117, 2.734342746805436, 2.7447993152022874, 2.755137725366799, 2.765361046540228, 2.775472224510327, 2.7854740882852114, 2.7953693563167143, 2.8051606423095277, 2.814850460649042, 2.8244412314777683, 2.833935285447518, 2.843334868172072, 2.8526421444028993, 2.8618592019485005, 2.8709880553561957, 2.8800306493735595, 2.8889888622052755, 2.8978645085798624, 2.9066593426395477, 2.9153750606654905, 2.9240133036495615, 2.932575659723036, 2.9410636664517082, 2.9494788130062264, 2.9578225422157702, 2.9660962525125694, 2.9743012997742158, 2.9824389990701965, 2.990510626318614, 2.9985174198586226, 3.006460581943714, 3.014341280160632, 3.0221606487783457, 3.029919790031215, 3.0376197753401954, 3.045261646475669, 3.0528464166652416], [0.0, 0.9657835706352026, 1.148516693752116, 1.2710426594494582, 1.3658242239094176, 1.4441832852728287, 1.5115329740892762, 1.5709209196680185, 1.624247884916149, 1.6727862134554565, 1.7174330382144525, 1.7588466845213098, 1.797525767348191, 1.8338577764265274, 1.8681503347758255, 1.900652091687926, 1.9315671412704052, 1.9610652474116923, 1.9892892669196895, 2.0163606497973583, 2.042383588585367, 2.0674481987785094, 2.091632991431688, 2.115006820147162, 2.1376304319311945, 2.1595577154927827, 2.1808367156294954, 2.2015104647539276, 2.2216176700101276, 2.241193285272322, 2.2602689905800855, 2.2788735965470996, 2.297033387504232, 2.3147724142661468, 2.332112745206556, 2.3490746826204902, 2.365676950019442, 2.3819368549568463, 2.3978704311505283, 2.4134925630057946, 2.428817095110509, 2.4438569288433487, 2.4586241078869633, 2.4731298941521875, 2.487384835384989, 2.5013988255342774, 2.515181158798285, 2.528740578133563, 2.5420853188989163, 2.555223148212729, 2.5681614005230395, 2.5809070098227784, 2.593466538885762, 2.605846205850603, 2.618051908438318, 2.630089246053925, 2.6419635399918104, 2.6536798519383042, 2.665243000942169, 2.6766575790039315, 2.6879279654178565, 2.699058339985363, 2.7100526952056514, 2.720914847537835, 2.731648447818835, 2.742256990912465, 2.7527438246573275, 2.7631121581742852, 2.7733650695881646, 2.7835055132129654, 2.7935363262450457, 2.803460235004489, 2.8132798607610567, 2.822997725177743, 2.832616255401886, 2.8421377888311037, 2.8515645775788507, 2.8608987926622222, 2.8701425279326442, 2.879297803768314, 2.8883665705456574, 2.8973507119056077, 2.906252047829209, 2.9150723375358543, 2.9238132822163942, 2.932476527612365, 2.9410636664517082, 2.949576240750525, 2.9580157439897006, 2.966383623174519, 2.9746812807848126, 2.9829100766226073, 2.9910713295637095, 2.9991663192192206, 3.0071962875125275, 3.015162440176908, 3.0230659481785525, 3.030907949069442, 3.0386895482742298, 3.046411820314977, 3.054075809977351, 3.06168253342163], [0.0, 0.9685469281169012, 1.1518028981306478, 1.2746794424196195, 1.369732201537721, 1.4483154685151653, 1.5158578622731127, 1.5754157321793416, 1.6288952797169989, 1.6775724890132342, 1.722347059926734, 1.7638792014253155, 1.8026689551480006, 1.8391049195349223, 1.8734955977948944, 1.9060903506699227, 1.9370938562338025, 1.966676364113512, 1.994981139867362, 2.0221299809982973, 2.0482273781688902, 2.0733637047177553, 2.0976176963403033, 2.12105840364682, 2.1437467474565235, 2.1657367706679937, 2.187076655547436, 2.207809557634348, 2.227974294823965, 2.24760592100262, 2.266736206854704, 2.2853940454285424, 2.3036057962612957, 2.3213955789832528, 2.338785525111471, 2.3557959950311154, 2.3724457658265057, 2.3887521945724806, 2.4047313608634924, 2.4203981916929957, 2.4357665712618135, 2.450849437862816, 2.4656588696387556, 2.480206160723717, 2.4945018890435056, 2.508555976856189, 2.5223777449531117, 2.535975961306694, 2.549358884839239, 2.5625343048928735, 2.575509576901394, 2.588291654697687, 2.6008871198333665, 2.6133022082387543, 2.625542834509777, 2.637614614072805, 2.649522883447829, 2.6612727188039766, 2.6728689529785594, 2.6843161911110114, 2.6956188250258935, 2.706781046484122, 2.717806859408474, 2.728700091177943, 2.739464403075442, 2.7501032999644965, 2.760620139262745, 2.771018139273178, 2.7813003869279362, 2.791469844994078, 2.801529358785917, 2.8114816624242462, 2.8213293846789598, 2.8310750544281853, 2.840721105763958, 2.8502698827717983, 2.859723644009041, 2.869084566704626, 2.8783547507010305, 2.887536222157279, 2.8966309370303307, 2.9056407843507035, 2.9145675893068805, 2.9234131161518375, 2.932179070943975, 2.9408671041337215, 2.9494788130062264, 2.9580157439897006, 2.966479394838265, 2.974871216697461, 2.983192616059981, 2.9914449566185963, 2.9996295610227595, 3.0077477125448726, 3.015800656661786, 3.0237896025566937, 3.0317157245462254, 3.0395801634371935, 3.047384027817157, 3.0551283952826642, 3.062814313608786, 3.070442801863298], [0.0, 0.9712868336416696, 1.1550612132751377, 1.2782853608787121, 1.3736070130904692, 1.452412582902289, 1.5201460461607854, 1.5798723982871963, 1.633503233184822, 1.6823181445900717, 1.7272193775068816, 1.7688690085567114, 1.8077684939376608, 1.8443075313892177, 1.8787954968395464, 1.91148245644291, 1.9425736672833391, 1.9722398606040152, 2.0006247072446897, 2.0278503492591406, 2.0540215729017546, 2.0792290071667088, 2.1035516104834504, 2.1270586287983337, 2.1498111552684196, 2.171863385673303, 2.1932636385811617, 2.2140551916134474, 2.2342769724766613, 2.253964134220466, 2.2731485374047877, 2.291859156812992, 2.3101224265502753, 2.327962534478528, 2.34540167472227, 2.362460265263805, 2.3791571363056208, 2.395509694023681, 2.411534063499723, 2.4272452139539125, 2.4426570688638467, 2.4577826031233077, 2.472633929042694, 2.48722237270587, 2.5015585419623516, 2.5156523871391085, 2.5295132553949102, 2.5431499395057404, 2.5565707217574243, 2.5697834135272224, 2.5827953910565906, 2.595613627849991, 2.6082447240774744, 2.620694933310077, 2.6329701868754243, 2.645076116085267, 2.657018072555984, 2.66880114681659, 2.6804301853759265, 2.691909806400825, 2.7032444141398027, 2.714438212211775, 2.725495215866147, 2.7364192633091173, 2.7472140261809384, 2.7578830192599844, 2.7684296094616325, 2.778857024193075, 2.789168359119021, 2.7993665853878493, 2.809454556362933, 2.819435013899572, 2.8293105942041428, 2.8390838333086705, 2.8487571721909526, 2.8583329615676507, 2.867813466385294, 2.8772008700319467, 2.8864972782902947, 2.895704723051128, 2.904825165804578, 2.9138605009250087, 2.9228125587641465, 2.9316831085658324, 2.9404738612147048, 2.949186471830124, 2.9578225422157702, 2.966383623174519, 2.974871216697461, 2.9832867780352594, 2.991631717659408, 2.9999074031204045, 3.0081151608093224, 3.01625627762879, 3.024332002578966, 3.032343548263682, 3.040292092321571, 3.0481787787866534, 3.056004719382553, 3.0637709947542113, 3.0714786556407327, 3.0791287239927163], [0.0, 0.9740037464252967, 1.158292185288269, 1.281861019188702, 1.3774493079968595, 1.45647531512197, 1.5243982444638442, 1.584291664941221, 1.63807251762544, 1.6870239755710472, 1.7320508075688772, 1.7738169422210552, 1.8128252384140608, 1.8494664839616353, 1.884050920187607, 1.9168293127388172, 1.9480074928505935, 1.9777566693406925, 2.006220914929266, 2.0335227133295235, 2.0597671439071177, 2.0850450891663783, 2.1094357284016496, 2.133008501256132, 2.1558246717785052, 2.177938587346431, 2.1993987016862424, 2.2202484134768556, 2.2405267593145264, 2.260268990580086, 2.2795070569547775, 2.2982700142711043, 2.316584370576538, 2.3344743813919835, 2.3519623029240355, 2.3690686102687932, 2.385812186301152, 2.402210485886156, 2.418279679211108, 2.4340347773685256, 2.4494897427831783, 2.46465758664261, 2.47955045513814, 2.494179706035296, 2.5085559768561887, 2.5226892457611436, 2.5365888860550827, 2.550263715109408, 2.563722038377404, 2.5769716890865517, 2.5900200641113513, 2.602874156462761, 2.615540584773027, 2.6280256201058623, 2.64033521038018, 2.652475002659807, 2.6644503635308237, 2.6762663977616263, 2.6879279654178565, 2.6994396975844213, 2.7108060108295344, 2.7220311205306014, 2.7331190531686027, 2.7440736576860836, 2.754898615993719, 2.765597452701527, 2.7761735441429227, 2.7866301267528977, 2.7969703048554484, 2.807197057909939, 2.817313247261257, 2.8273216224343027, 2.837224827009527, 2.8470254041128222, 2.8567258015499606, 2.8663283766131, 2.875835400584347, 2.8852490629592036, 2.8945714754107152, 2.903804675513337, 2.91295063024394, 2.92201123927589, 2.9309883380808275, 2.939883700851576, 2.948699043258512, 2.957436025050745, 2.9660962525125694, 2.9746812807848126, 2.983192616059981, 2.991631717659408, 2.9999999999999996, 3.0082988344576096, 3.0165295511335306, 3.024693440530154, 3.0327917551413806, 3.040825710962972, 3.0487964889276884, 3.0567052362696767, 3.0645530678223074, 3.072341067253335, 3.0800702882410227, 3.0877417555945996], [0.0, 0.9766981117095218, 1.161496343654686, 1.2854070033206721, 1.381259715923798, 1.460504330965901, 1.5286151540232695, 1.588674256361194, 1.642603881843218, 1.6916907531374747, 1.7368421418769384, 1.7787238132749206, 1.8178400172654527, 1.854582622690067, 1.8892627290863886, 1.9221317957887882, 1.9533962234190436, 1.9832276944061233, 2.0117706800153967, 2.039148002784094, 2.0654650327566206, 2.0908129038435934, 2.115271014371307, 2.138908996072332, 2.1617882824687458, 2.1839633712781743, 2.2054828502634343, 2.226390238156261, 2.2467246795389917, 2.266521523307584, 2.2858128075249846, 2.3046276684002125, 2.322992687309372, 2.340932186870885, 2.358468484858204, 2.37562211300724, 2.3924120064281724, 2.4088556682710576, 2.424969313454433, 2.440767994595675, 2.4562657127435017, 2.471475515078023, 2.4864095813903013, 2.501079300864602, 2.515495340449381, 2.5296677059073316, 2.543605796472544, 2.557318453907722, 2.5708140066413443, 2.584100309569777, 2.597184780029334, 2.610074430375586, 2.6227758975497575, 2.6352954699630677, 2.647639111988028, 2.6598124863098143, 2.6718209743599775, 2.6836696950281222, 2.6953635218241843, 2.706907098643939, 2.718304854273057, 2.7295610157498498, 2.7406796206936646, 2.751664528694292, 2.762519431847596, 2.7732478645136465, 2.7838532123657354, 2.7943387207917345, 2.8047075027030637, 2.8149625458011003, 2.825106719346008, 2.835142780468637, 2.8450733800623182, 2.854901068287936, 2.864628299722576, 2.874257438179321, 2.883790761223275, 2.893230464406695, 2.9025786652440995, 2.9118374069464434, 2.921008661931802, 2.9300943351285653, 2.9390962670858003, 2.94801623690424, 2.9568559650002832, 2.9656171157143674, 2.9743012997742158, 2.9829100766226073, 2.9914449566185963, 2.9999074031204045, 3.0082988344576096, 3.0166206257996713, 3.0248741109273123, 3.033060583912814, 3.0411813007148214, 3.0492374806928804, 3.057230308046539, 3.065160933183514, 3.0730304740211136, 3.080840017224819, 3.088590619387661, 3.0962833081537764], [0.0, 0.9793703613355592, 1.164674201923033, 1.288923881609622, 1.3850388475869866, 1.4645002761873147, 1.5327974507070874, 1.593020874969912, 1.6470980521056138, 1.6963192252602786, 1.741594148365405, 1.7835904081703773, 1.822813634238901, 1.8596567675671005, 1.8944317588620794, 1.9273907554518728, 1.9587407226711184, 1.988653812672542, 2.017274891995427, 2.0447271192199157, 2.0711161526832442, 2.0965333756387428, 2.12105840364682, 2.1447610589527217, 2.1677029431608688, 2.1899387030948425, 2.211517059453757, 2.232481650036758, 2.252871726525904, 2.272722734531862, 2.2920667997738366, 2.3109331381776226, 2.329348403846066, 2.3473369859443625, 2.3649212633074757, 2.3821218238462203, 2.3989576544773072, 2.4154463062394758, 2.431604038415341, 2.447445944806294, 2.462986064767976, 2.478237481177628, 2.4932124071502657, 2.5079222630310047, 2.5223777449531117, 2.5365888860550827, 2.550565111287347, 2.5643152866037044, 2.577847763219244, 2.591170417521358, 2.604290687140218, 2.6172156036172267, 2.6299518220523037, 2.6425056480617855, 2.654883062336727, 2.667089743055433, 2.6791310863730695, 2.6910122251845436, 2.7027380463337307, 2.7143132064221227, 2.725742146352564, 2.737029104728559, 2.7481781302163952, 2.759193092965716, 2.770077695173973, 2.780835480871258, 2.791469844994078, 2.8019840418096975, 2.8123811927464732, 2.8226642936801456, 2.8328362217211835, 2.8428997415439574, 2.852857511294653, 2.8627120881114037, 2.8724659332870264, 2.882121417102006, 2.891680823352873, 2.9011463535989224, 2.910520131148202, 2.919804204801898, 2.9290005523746294, 2.9381110840066778, 2.9471376452828575, 2.956082020171529, 2.9649459337961566, 2.973731055050819, 2.9824389990701965, 2.9910713295637095, 2.9996295610227595, 3.0081151608093224, 3.0165295511335306, 3.0248741109273123, 3.03315017762062, 3.0413590488263207, 3.049501983939367, 3.057580205655478, 3.065594901414175, 3.073547224770694, 3.08143829670097, 3.089269206843605, 3.0970410146824725, 3.1047547506733464], [0.0, 0.9820209142881303, 1.167826258352922, 1.2924122054704554, 1.3887872955203007, 1.4684637773145044, 1.5369457902618242, 1.5973322022781031, 1.6515557330581283, 1.7009101176422834, 1.74630757210618, 1.7884174899457608, 1.8277468691528413, 1.8646897141730423, 1.8995588199720859, 1.932607016285675, 1.9640418285762606, 1.9940358749065195, 2.0227344138803187, 2.0502609373922973, 2.0767213897317967, 2.1022074014703853, 2.126798803638806, 2.1505656074481596, 2.1735695812205065, 2.1958655196747543, 2.217502275366972, 2.2385236041969763, 2.2589688640769774, 2.2788735965471, 2.2982700142711043, 2.3171874122443183, 2.335652516705844, 2.3536897828273413, 2.371321650009509, 2.3885687618819693, 2.405450156747334, 2.421983433144204, 2.4381848943590683, 2.454069675042952, 2.4696518525473916, 2.484944545156928, 2.499959999039964, 2.5147096654494634, 2.529204269466543, 2.5434538713832313, 2.5574679216575, 2.5712553102378295, 2.584824410940911, 2.5981831214706688, 2.611338899586365, 2.6242987958594575, 2.6370694834011266, 2.6496572848931312, 2.662068197212579, 2.674307913905108, 2.686381845729956, 2.698295139473619, 2.710052695205652, 2.721659182130101, 2.7331190531686027, 2.7444365583959525, 2.7556157574356863, 2.7666605309115617, 2.7775745910406013, 2.788361491444405, 2.7990246362474833, 2.809567288524401, 2.8199925781513007, 2.8303035091119138, 2.840502966303278, 2.8505937218820367, 2.86057844118834, 2.870459688280922, 2.8802399311138047, 2.8899215463823635, 2.8995068240639617, 2.90899797167616, 2.9183971182734942, 2.927706318201995, 2.936927554629009, 2.946062742864391, 2.9551137334878192, 2.964082315295759, 2.9729702180805213, 2.981779115252854, 2.990510626318614, 2.9991663192192206, 3.0077477125448726, 3.01625627762879, 3.024693440530154, 3.033060583912814, 3.0413590488263207, 3.049590136395381, 3.0577551094233564, 3.0658551939150485, 3.0738915805236484, 3.081865425926356, 3.0897778541328984, 3.097629957730859, 3.1054227990714813, 3.11315741139935], [0.0, 0.9846501772118187, 1.1709529965289849, 1.295872510077541, 1.3925056348060254, 1.4723954424229517, 1.541060809120647, 1.6016088997243154, 1.6559776085927063, 1.7054641346125685, 1.7509831362269537, 1.793205799166037, 1.8326404788581239, 1.8696822346563888, 1.9046446990038355, 1.9377813785625346, 1.9693003544236374, 1.9993747068174434, 2.028150083263225, 2.0557503062928357, 2.082281603850872, 2.1078358518406057, 2.132493095032392, 2.156323532085357, 2.1793890967000746, 2.201744730302841, 2.2234394162475644, 2.244517027586113, 2.2650170276075774, 2.2849750530110056, 2.3044234027063477, 2.3233914501233563, 2.3419059930579698, 2.3599915521581276, 2.3776706269037833, 2.394963916195815, 2.4118905093099885, 2.4284680519032347, 2.444712890912464, 2.460640201510217, 2.4762640987387345, 2.491597736005454, 2.5066533922666703, 2.521442549434933, 2.535975961306694, 2.5502637151094083, 2.5643152866037044, 2.578139589540013, 2.591745020155082, 2.6051394972981505, 2.6183304986958853, 2.6313250937969457, 2.6441299735791004, 2.656751477652458, 2.669195618950164, 2.6814681062617582, 2.6935743648332457, 2.705519555231128, 2.717308590644407, 2.7289461527784584, 2.7404367064771695, 2.751784513194487, 2.7629936434231848, 2.7740679881770016, 2.785011269612051, 2.795827050864399, 2.8065187451727605, 2.8170896243482564, 2.827542826646959, 2.837881364095468, 2.8481081293148436, 2.8582259018839014, 2.8682373542789747, 2.8781450574238083, 2.8879514858801243, 2.8976590227066628, 2.907269964011973, 2.9167865232240224, 2.9262108350976797, 2.93554495947928, 2.9447908848459035, 2.953950531635456, 2.963025755382357, 2.972018349672396, 2.9809300489292307, 2.989762531043999, 2.9985174198586226, 3.0071962875125275, 3.015800656661786, 3.024332002578966, 3.0327917551413806, 3.0411813007148214, 3.049501983939367, 3.0577551094233564, 3.0659419433511785, 3.074063715010143, 3.082121618241294, 3.090116812818721, 3.098050425761573, 3.1059235525827282, 3.11373725847777, 3.1214925794576915], [0.0, 0.9872585449014338, 1.1740548859440185, 1.2993053150100684, 1.3961944237683348, 1.4762958618685946, 1.5451431251708252, 1.6058516094725332, 1.6603643426724282, 1.709981959975803, 1.7556215427832071, 1.7979560548158353, 1.8374951981506855, 1.8746350786649428, 1.9096901596233076, 1.9429146192345597, 1.9745170898028677, 2.004671110053224, 2.0335227133295235, 2.0611960501732, 2.087797629929844, 2.1134195718847355, 2.138142132849214, 2.1620356974407473, 2.18516236342413, 2.2075772177671347, 2.2293293735820354, 2.250462820141724, 2.2710171252747196, 2.29102802008275, 2.3105278890365413, 2.3295461833769373, 2.348109771888037, 2.366243240173708, 2.3839691473156965, 2.401308247046888, 2.418279679211108, 2.4349011362091595, 2.4511890082814753, 2.4671585108000826, 2.4828237961983888, 2.4981980527275995, 2.5132935918713324, 2.5281219259580654, 2.542693837271378, 2.5570194397600914, 2.571108234286407, 2.5849691582135454, 2.598610630020137, 2.612040589532689, 2.6252665342865877, 2.638295552457674, 2.6511343527483158, 2.6637892915624386, 2.676266397761627, 2.6885713952581733, 2.7007097236697226, 2.7126865572332703, 2.7245068221530033, 2.736175212536273, 2.7476962050544724, 2.7590740724502676, 2.7703128959992873, 2.7814165770226826, 2.7923888475366696, 2.803233280116169, 2.813953297041666, 2.824552178791406, 2.8350330719347965, 2.845398996477385, 2.855652852702871, 2.8657974275532574, 2.8758354005843474, 2.8857693495303387, 2.895601755508142, 2.905335007889291, 2.914971408864794, 2.9245131777260567, 2.933962454882976, 2.943321305638482, 2.9525917237371893, 2.9617756347043014, 2.9708748989896043, 2.9798913149301494, 2.9888266215441335, 2.9976825011674793, 3.006460581943714, 3.015162440176908, 3.0237896025566937, 3.032343548263682, 3.040825710962972, 3.0492374806928804, 3.057580205655478, 3.0658551939150485, 3.074063715010143, 3.0822070014844885, 3.0902862503416504, 3.0983026244279936, 3.1062572537481756, 3.11415123671712, 3.121985641352145, 3.1297615064086686], [0.0, 0.989846400767953, 1.1771323825530846, 1.3027111248652612, 1.3998542046322333, 1.4801656089845705, 1.5491933384829668, 1.6100609551700655, 1.664716580115127, 1.7144642578192797, 1.7602234735867868, 1.8026689551480006, 1.842311740638763, 1.879548974230557, 1.914695943476319, 1.9480074928505933, 1.979692801535906, 2.0099258631464076, 2.038853093816547, 2.066598969517919, 2.093270278784211, 2.1189593823687916, 2.1437467474565235, 2.1677029431608688, 2.1908902300206647, 2.2133638394006434, 2.2351730131510443, 2.256361855851836, 2.2769700390488867, 2.297033387504232, 2.316584370576538, 2.335652516705844, 2.354264765106169, 2.3724457658265057, 2.3902181370816935, 2.4076026870054315, 2.4246186056119483, 2.44128363167833, 2.4576141984080007, 2.47362556105635, 2.4893319091539134, 2.50474646552166, 2.519881573914738, 2.5347487768383683, 2.549358884839239, 2.563722038377404, 2.577847763219244, 2.5917450201550816, 2.6054222497305224, 2.618887412584378, 2.6321480259049848, 2.645211196448095, 2.6580836505012924, 2.670771761130255, 2.6832815729997477, 2.6956188250258935, 2.70778897108496, 2.7197971989769334, 2.7316484478188356, 2.7433474240224682, 2.7548986159937194, 2.7663063076751997, 2.7775745910406013, 2.7887073776374303, 2.7997084092644666, 2.8105812678612585, 2.82132938467896, 2.8319560487947846, 2.842464415026099, 2.852857511294653, 2.8631382454865286, 2.8733094118490126, 2.883373696961705, 2.8933336853157017, 2.903191864531552, 2.9129506302439405, 2.9226122906785035, 2.932179070943975, 2.941653117060809, 2.9510364997456224, 2.960331217969141, 2.969539202303859, 2.978662318076276, 2.987702368337341, 2.9966610966636615, 3.00554018980099, 3.014341280160632, 3.0230659481785525, 3.0317157245462254, 3.040292092321571, 3.0487964889276884, 3.057230308046539, 3.065594901414175, 3.0738915805236484, 3.082121618241294, 3.0902862503416504, 3.0983866769659336, 3.106424064008624, 3.1143995444364094, 3.1223142195434384, 3.1301691601465746, 3.1379654077240775], [0.0, 0.9924141172814958, 1.1801859293002996, 1.3060904298413636, 1.4034855041500147, 1.484005240743618, 1.553212032004312, 1.6142375426680784, 1.6690349473383785, 1.7189116732801692, 1.7647895909936366, 1.8073451784903223, 1.847090799567362, 1.8844246286102666, 1.9196627710453875, 1.953060732427983, 1.9848282345629915, 2.015139722413657, 2.04414199192601, 2.071959841969225, 2.0987003380923746, 2.1244560806377484, 2.149307745526554, 2.1733260849324516, 2.196573520901572, 2.2191054280718734, 2.240971176029689, 2.262214983764716, 2.2828766257330146, 2.302992019628042, 2.3225937190357833, 2.3417113289946903, 2.3603718586005993, 2.3786000218460974, 2.396418495618929, 2.413848142030249, 2.4309082008742458, 2.4476164569433796, 2.463989386069716, 2.4800422830816236, 2.4957893743180684, 2.5112439169007508, 2.526418286605205, 2.541324055878551, 2.555972063310636, 2.57037247566643, 2.5845348434226794, 2.5984681506144955, 2.612180859682727, 2.625680951916526, 2.638975964004231, 2.6520730211369132, 2.6649788670505217, 2.6776998913428183, 2.6902421543587653, 2.702611409901553, 2.7148131259951045, 2.72685250389685, 2.738734495536154, 2.750463819533511, 2.762044975937984, 2.7734822598049687, 2.7847797737229634, 2.7959414393862456, 2.8069710083000294, 2.817872071695613, 2.8286480697250065, 2.839302299997472, 2.849837925514148, 2.860257982051381, 2.870565385038471, 2.8807629359711373, 2.890853328398117, 2.900839153514819, 2.9107229053948185, 2.920506985887209, 2.9301937092052928, 2.9397853062298593, 2.9492839285482595, 2.9586916522486626, 2.968010481487236, 2.9772423518444873, 2.986389133485675, 2.995452634138963, 3.004434601903893, 3.0133367279017307, 3.0221606487783457, 3.030907949069442, 3.0395801634371935, 3.0481787787866534, 3.0567052362696767, 3.065160933183514, 3.073547224770694, 3.081865425926356, 3.090116812818721, 3.0983026244279936, 3.106424064008624, 3.1144823004794873, 3.12247846974625, 3.130413675959879, 3.138288992714996, 3.1461054641915127], [0.0, 0.9949620563926881, 1.1832159566199232, 1.309443706292189, 1.4070888341971637, 1.4878152983881654, 1.5571997722182047, 1.618381960706977, 1.6733200530681511, 1.7233248332753461, 1.7693205386531028, 1.8119853840129068, 1.8518330486025056, 1.8892627290863888, 1.9245913424647911, 1.9580750502818227, 1.9899241127853762, 2.0203134228113497, 2.04939015319192, 2.077279423206778, 2.1040885732867167, 2.1299104415175543, 2.1548259109490866, 2.178905915405181, 2.2022130371952793, 2.2248027931270298, 2.2467246795389917, 2.26802302894937, 2.2887377179317685, 2.308904756395278, 2.3285567815044543, 2.3477234743061772, 2.3664319132398464, 2.384706875749129, 2.402571096942758, 2.4200454924935872, 2.4371493515923475, 2.4539005046924456, 2.470315469926249, 2.4864095813903013, 2.502197101948488, 2.5176913227590454, 2.5329046513712625, 2.547848689943536, 2.5625343048928735, 2.576971689086552, 2.591170417521358, 2.6051394972981505, 2.618887412584378, 2.6324221651604756, 2.6457513110645907, 2.6588819937811183, 2.6718209743599775, 2.684574658803681, 2.697149123016613, 2.709550135574365, 2.7217831785395497, 2.733853466523383, 2.7457659641688887, 2.75752540221122, 2.769136292252934, 2.780602940376616, 2.7919294597038142, 2.803119781997423, 2.8141776683943274, 2.8251067193460084, 2.835910383836774, 2.84659196794222, 2.8571546427842196, 2.8676014519332202, 2.877935318303638, 2.8881590505837953, 2.898275349237888, 2.908286812113998, 2.9181959396890242, 2.928005139978604, 2.9377167331375857, 2.9473329557743555, 2.9568559650002837, 2.9662878422337196, 2.975630596776331, 2.9848861691780644, 2.9940564344056693, 3.003143204828499, 3.012148233034192, 3.0210732144858237, 3.029919790031215, 3.0386895482742298, 3.047384027817157, 3.056004719382553, 3.0645530678223074, 3.0730304740211136, 3.08143829670097, 3.0897778541328984, 3.098050425761573, 3.1062572537481756, 3.1143995444364094, 3.12247846974625, 3.130495168499706, 3.1384507476825574, 3.1463462836457885, 3.1541828232501565], [0.0, 0.997490569933681, 1.1862228829132528, 1.3127714172548886, 1.4106646923394799, 1.4915963080299905, 1.5611571097717192, 1.6224947815686916, 1.6775724890132342, 1.7277043471959719, 1.7738169422210552, 1.816590212458495, 1.8565391425776128, 1.8940639437279883, 1.9294823382962738, 1.9630511388141516, 1.994981139867362, 2.025447678749862, 2.0545983023065815, 2.082558447784909, 2.1094357284016496, 2.135323218173586, 2.160302005699947, 2.1844432050699005, 2.207809557634348, 2.230456721286719, 2.252434318151437, 2.2737867934096694, 2.2945541249740162, 2.3147724142661468, 2.3344743813919835, 2.353689782827341, 2.3724457658265057, 2.3907671708004723, 2.408676790635081, 2.426195594156533, 2.4433429195754983, 2.4601366426582087, 2.476593323514836, 2.492728335210717, 2.508555976856189, 2.524089573386529, 2.539341563882536, 2.554323579987364, 2.569046515733026, 2.5835205898901012, 2.597755401788474, 2.611759981418898, 2.625542834509777, 2.6391119831766026, 2.652475002659807, 2.665639054597641, 2.6786109172219916, 2.691397012815051, 2.7040034327220006, 2.7164359601782087, 2.728700091177943, 2.7408010535843985, 2.752743824657328, 2.7645331471541805, 2.7761735441429227, 2.7876693326492603, 2.7990246362474833, 2.810243396692342, 2.8213293846789598, 2.8322862098087054, 2.8431173298308474, 2.853826059222765, 2.864415577165158, 2.8748889349631486, 2.8852490629592036, 2.8954987769794123, 2.9056407843507035, 2.9156776895231156, 2.9256119993280487, 2.9354461279006707, 2.9451824012920786, 2.9548230617945888, 2.9643702720014726, 2.973826118620624, 2.983192616059981, 2.9924717098010434, 3.0016652795754433, 3.0107751423583387, 3.0198030551912485, 3.0287507178459556, 3.0376197753401954, 3.046411820314977, 3.0551283952826642, 3.0637709947542113, 3.072341067253335, 3.080840017224819, 3.089269206843605, 3.097629957730859, 3.1059235525827282, 3.11415123671712, 3.1223142195434384, 3.130413675959879, 3.1384507476825574, 3.1464265445104544, 3.154342145529904, 3.162198600262067], [0.0, 1.0, 1.189207115002721, 1.3160740129524924, 1.414213562373095, 1.4953487812212205, 1.5650845800732873, 1.6265765616977856, 1.681792830507429, 1.7320508075688772, 1.7782794100389228, 1.8211602868378718, 1.8612097182041993, 1.8988289221159418, 1.9343364202676692, 1.9679896712654301, 2.0, 2.0305431848689306, 2.0597671439071177, 2.087797629929844, 2.114742526881128, 2.1406951429280725, 2.1657367706679937, 2.1899387030948425, 2.2133638394006434, 2.23606797749979, 2.2581008643532257, 2.279507056954778, 2.3003266337912063, 2.320595787106084, 2.3403473193207156, 2.359611061770567, 2.378414230005442, 2.39678172692843, 2.414736402766418, 2.432299279097787, 2.4494897427831783, 2.46632571455966, 2.4828237961983883, 2.4989993994393833, 2.514866859365871, 2.5304395344352426, 2.5457298950218306, 2.5607496020310148, 2.575509576901394, 2.5900200641113513, 2.604290687140218, 2.6183304986958853, 2.6321480259049848, 2.6457513110645907, 2.6591479484724942, 2.6723451177837885, 2.68534961428265, 2.6981678764080854, 2.7108060108295344, 2.7232698153315003, 2.735564799734761, 2.7476962050544724, 2.7596690210718946, 2.771488002476036, 2.7831576837137404, 2.794682392671241, 2.806066263296683, 2.8173132472612576, 2.82842712474619, 2.839411514433677, 2.8502698827717983, 2.861005552576305, 2.8716217110259006, 2.882121417102006, 2.8925076085190775, 2.9027831081870996, 2.9129506302439405, 2.923012785691765, 2.932972087668518, 2.9428309563827115, 2.9525917237371893, 2.962256637665299, 2.9718278662008415, 2.9813075013013313, 2.990697562442441, 3.0, 3.009216698434564, 3.018349479292333, 3.027400104035091, 3.036370276710811, 3.045261646475669, 3.054075809977351, 3.062814313608786, 3.0714786556407327, 3.0800702882410227, 3.088590619387661, 3.0970410146824725, 3.1054227990714813, 3.11373725847777, 3.121985641352145, 3.1301691601465746, 3.138288992714996, 3.1463462836457885, 3.154342145529904, 3.162277660168379, 3.1701538797227005], [0.0, 1.0024906793143211, 1.1921690485645018, 1.319351931272669, 1.4177359148389301, 1.4990732154983035, 1.5689827038620388, 1.630627842293166, 1.6859816371213476, 1.7363647906866422, 1.78270853378059, 1.825696213092362, 1.865845394748944, 1.9035582960336908, 1.939154231976568, 1.9728913024304486, 2.0049813586286422, 2.0356006167763194, 2.0648973633247656, 2.0929976642991988, 2.1200096723479462, 2.146026928038831, 2.1711309264429612, 2.195393138122272, 2.218876618930505, 2.2416373057567642, 2.2637250694657207, 2.285184578028384, 2.306056009754172, 2.3263756470299297, 2.3461763739772747, 2.365488096231962, 2.3843380971290036, 2.402751341596634, 2.420750736774327, 2.438357356598474, 2.45559063621617, 2.4724685409992926, 2.489007714068684, 2.505223605550068, 2.521130586230765, 2.536742047839801, 2.5520704918112105, 2.5671276080939496, 2.5819243453284186, 2.59647097350871, 2.610777140083157, 2.624851920307043, 2.638703862545338, 2.652341029125897, 2.665771033261474, 2.67900107248938, 2.6920379590186645, 2.704888147324421, 2.717557759285845, 2.7300526071278615, 2.7423782143944453, 2.75453983515444, 2.7665424716170515, 2.7783908903136925, 2.7900896369850603, 2.8016430502967653, 2.8130552744932906, 2.8243302710881744, 2.8354718296778603, 2.8464835779575224, 2.8573689910090505, 2.8681313999242652, 2.8787739998201083, 2.889299857296944, 2.8997119173861328, 2.910013010028622, 2.920205856122328, 2.930293073172584, 2.9402771805767554, 2.9501606045713182, 2.9599456828671373, 2.9696346689964424, 2.979229736392911, 2.988732982224453, 2.998146430996607, 3.0074720379429634, 3.0167116922176644, 3.0258672199037986, 3.034940386850385, 3.0439329013496343, 3.0528464166652416, 3.06168253342163, 3.070442801863298, 3.0791287239927163, 3.0877417555945996, 3.0962833081537764, 3.1047547506733464, 3.11315741139935, 3.1214925794576915, 3.1297615064086686, 3.1379654077240775, 3.1461054641915127, 3.1541828232501565, 3.162198600262067, 3.1701538797227005, 3.1780497164141406]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 0.6\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.25118864315095807, 0.3092494947109918, 0.3492499691434396, 0.38073078774317576, 0.40709053153690444, 0.42997714837183004, 0.45032847814030624, 0.46873458231841997, 0.48559337483020387, 0.5011872336272724, 0.5157245499507892, 0.5293639640839567, 0.5422293302128559, 0.5544193900325562, 0.5660142663870591, 0.5770799623628855, 0.5876715635211257, 0.5978355705795094, 0.607611633351008, 0.6170338627200097, 0.6261318390911265, 0.6349313984967353, 0.6434552531631887, 0.6517234870080822, 0.6597539553864472, 0.6675626106433133, 0.6751637695410696, 0.6825703346886778, 0.6897939792303888, 0.696845301935949, 0.7037339582560234, 0.710468771716361, 0.7170578291176235, 0.7235085623107059, 0.7298278187766998, 0.7360219228178334, 0.7420967288325538, 0.7480576678834732, 0.753909788555604, 0.7596577929323739, 0.7653060683794355, 0.7708587157144184, 0.7763195742492645, 0.7816922441165305, 0.7869801062288712, 0.7921863401692985, 0.7973139402667752, 0.8023657300756686, 0.8073443754472973, 0.8122523963562356, 0.8170921776223911, 0.8218659786514628, 0.8265759423006915, 0.8312241029633823, 0.8358123939541525, 0.8403426542669354, 0.8448166347692025, 0.8492360038884523, 0.853602352840574, 0.857917200444095, 0.8621819975594346, 0.8663981311880077, 0.8705669282622859, 0.8746896591546226, 0.8787675409297631, 0.8828017403633959, 0.8867933767468494, 0.8907435244960379, 0.8946532155809793, 0.8985234417906398, 0.9023551568464464, 0.9061492783765588, 0.909906689761875, 0.9136282418637358, 0.9173147546424019, 0.9209670186745648, 0.9245857965774334, 0.9281718243462789, 0.9317258126117351, 0.9352484478226214, 0.9387403933595695, 0.9422022905843045, 0.9456347598290342, 0.9490384013300432, 0.952413796109262, 0.9557615068072859, 0.9590820784710499, 0.9623760392991171, 0.965643901347317, 0.9688861611972635, 0.9721033005900913, 0.9752957870275873, 0.9784640743427232, 0.9816086032414625, 0.9847298018175752, 0.9878280860420744, 0.990903860228776, 0.9939575174773807, 0.9969894400953796, 1.0, 1.002989559101324], [0.0, 0.3092494947109918, 0.38073078774317576, 0.42997714837183004, 0.46873458231841997, 0.5011872336272724, 0.5293639640839567, 0.5544193900325562, 0.5770799623628855, 0.5978355705795094, 0.6170338627200097, 0.6349313984967353, 0.6517234870080822, 0.6675626106433133, 0.6825703346886778, 0.6968453019359491, 0.710468771716361, 0.7235085623107059, 0.7360219228178334, 0.7480576678834732, 0.759657792932374, 0.7708587157144184, 0.7816922441165305, 0.7921863401692986, 0.8023657300756686, 0.8122523963562357, 0.8218659786514628, 0.8312241029633823, 0.8403426542669353, 0.8492360038884523, 0.8579172004440949, 0.8663981311880077, 0.8746896591546225, 0.8828017403633958, 0.8907435244960378, 0.8985234417906398, 0.9061492783765587, 0.9136282418637358, 0.9209670186745648, 0.9281718243462789, 0.9352484478226214, 0.9422022905843045, 0.9490384013300432, 0.9557615068072859, 0.962376039299117, 0.9688861611972635, 0.9752957870275872, 0.9816086032414625, 0.9878280860420744, 0.9939575174773806, 1.0, 1.0059584696676387, 1.0118357081350007, 1.0176343535688062, 1.0233569106010076, 1.029005759421095, 1.034583164096176, 1.0400912801969562, 1.0455321617986297, 1.0509077679177485, 1.0562199684392584, 1.0614705495818582, 1.0666612189445914, 1.0717936101729577, 1.0768692872787826, 1.0818897486445278, 1.086856430739564, 1.0917707115731572, 1.0966339139064576, 1.1014473082435876, 1.1062121156199922, 1.110929510204478, 1.1156006217298278, 1.1202265377654983, 1.1248083058446763, 1.1293469354568555, 1.1338433999161135, 1.1382986381143665, 1.1427135561680801, 1.1470890289661901, 1.1514259016263249, 1.1557249908658431, 1.1599870862936499, 1.164212951628277, 1.1684033258472732, 1.172558924272542, 1.1766804395959092, 1.1807685428488637, 1.1848238843201155, 1.1888470944243388, 1.1928387845252129, 1.1967995477156448, 1.2007299595578473, 1.2046305787857485, 1.208501947972033, 1.2123445941619542, 1.2161590294759013, 1.2199457516825694, 1.2237052447444592, 1.2274379793373027, 1.2311444133449163, 1.2348249923308758], [0.0, 0.3492499691434396, 0.42997714837183004, 0.48559337483020387, 0.5293639640839567, 0.5660142663870591, 0.5978355705795093, 0.6261318390911265, 0.6517234870080822, 0.6751637695410695, 0.696845301935949, 0.7170578291176234, 0.7360219228178333, 0.7539097885556039, 0.7708587157144183, 0.7869801062288712, 0.8023657300756685, 0.8170921776223911, 0.8312241029633823, 0.8448166347692024, 0.8579172004440949, 0.8705669282622857, 0.8828017403633958, 0.8946532155809792, 0.9061492783765588, 0.9173147546424018, 0.9281718243462788, 0.9387403933595695, 0.9490384013300431, 0.9590820784710498, 0.9688861611972633, 0.978464074342723, 0.9878280860420743, 0.9969894400953795, 1.0059584696676387, 1.0147446954224053, 1.0233569106010076, 1.0318032550956446, 1.0400912801969562, 1.0482280054028688, 1.0562199684392581, 1.0640732694518138, 1.0717936101729575, 1.0793863287404348, 1.0868564307395638, 1.0942086169546863, 1.1014473082435876, 1.1085766678888298, 1.1156006217298275, 1.1225228763373836, 1.1293469354568555, 1.136076114916016, 1.1427135561680801, 1.1492622386185494, 1.1557249908658431, 1.162104500969668, 1.1684033258472732, 1.17462389988583, 1.1807685428488635, 1.1868394671457136, 1.1928387845252129, 1.1987685122479754, 1.2046305787857483, 1.2104268290910694, 1.216159029475901, 1.221828872133885, 1.2274379793373027, 1.2329879073366956, 1.238480149988315, 1.2439161421320981, 1.2492972627406829, 1.2546248378580127, 1.2599001433443435, 1.2651244074429089, 1.2702988131821025, 1.275424500625791, 1.2805025689832445, 1.2855340785891718, 1.2905200527634264, 1.2954614795591468, 1.3003593134073366, 1.305214476665242, 1.3100278610752603, 1.314800329140575, 1.3195327154232157, 1.3242258277697823, 1.3288804484696655, 1.3334973353502206, 1.3380772228130102, 1.342620822814914, 1.3471288257976295, 1.3516019015688139, 1.356040700137889, 1.360445852509303, 1.3648179714358555, 1.3691576521344881, 1.3734654729667923, 1.3777419960863195, 1.3819877680546362, 1.3862033204279376, 1.3903891703159093, 1.3945458209144095], [0.0, 0.38073078774317576, 0.46873458231841997, 0.5293639640839567, 0.5770799623628855, 0.6170338627200097, 0.6517234870080821, 0.6825703346886778, 0.710468771716361, 0.7360219228178333, 0.7596577929323739, 0.7816922441165304, 0.8023657300756685, 0.8218659786514627, 0.8403426542669353, 0.8579172004440949, 0.8746896591546225, 0.8907435244960379, 0.9061492783765587, 0.9209670186745647, 0.9352484478226214, 0.9490384013300431, 0.962376039299117, 0.9752957870275872, 0.9878280860420744, 1.0, 1.0118357081350005, 1.0233569106010076, 1.0345831640961758, 1.0455321617986295, 1.0562199684392581, 1.0666612189445914, 1.0768692872787824, 1.0868564307395638, 1.0966339139064574, 1.1062121156199922, 1.1156006217298275, 1.1248083058446763, 1.1338433999161135, 1.1427135561680801, 1.1514259016263246, 1.1599870862936499, 1.1684033258472732, 1.1766804395959092, 1.1848238843201153, 1.1928387845252129, 1.2007299595578471, 1.208501947972033, 1.216159029475901, 1.223705244744459, 1.2311444133449163, 1.2384801499883147, 1.2457158792933032, 1.252854849224101, 1.2599001433443433, 1.2668546920110242, 1.2737212826177138, 1.2805025689832445, 1.287201079970816, 1.2938192274127118, 1.3003593134073366, 1.3068235370478625, 1.3132140006353124, 1.319532715423216, 1.325781606935995, 1.331962519898846, 1.33807722281301, 1.3441274122068965, 1.350114716590505, 1.356040700137889, 1.361906866120014, 1.3677146601082473, 1.3734654729667926, 1.3791606436507111, 1.3848014618246332, 1.3903891703159095, 1.3959249674147287, 1.4014100090326287, 1.406845410729834, 1.4122322496209696, 1.4175715661678827, 1.422864365867587, 1.4281116208426743, 1.4333142713409486, 1.4384732271504903, 1.4435893689358648, 1.4486635495007438, 1.4536965949817957, 1.4586893059783335, 1.4636424586218608, 1.468556805589356, 1.4734330770638384, 1.478271981645511, 1.483074207216527, 1.487840421762217, 1.4925712741513997, 1.497267394878231, 1.5019293967678595, 1.5065578756480142, 1.5111534109884928, 1.515716566510398, 1.5202478907668366], [0.0, 0.40709053153690444, 0.5011872336272724, 0.5660142663870591, 0.6170338627200097, 0.6597539553864472, 0.696845301935949, 0.7298278187766998, 0.759657792932374, 0.7869801062288712, 0.8122523963562356, 0.8358123939541525, 0.8579172004440949, 0.8787675409297631, 0.8985234417906398, 0.9173147546424018, 0.9352484478226214, 0.952413796109262, 0.9688861611972635, 0.9847298018175752, 1.0, 1.0147446954224053, 1.029005759421095, 1.0428200007155333, 1.0562199684392584, 1.069234599991188, 1.0818897486445278, 1.0942086169546863, 1.1062121156199922, 1.1179191627986798, 1.1293469354568555, 1.1405110817643334, 1.1514259016263246, 1.162104500969668, 1.172558924272542, 1.1828002689503483, 1.1928387845252129, 1.2026839589665983, 1.2123445941619542, 1.221828872133885, 1.2311444133449163, 1.2402983282081343, 1.2492972627406829, 1.2581474391487872, 1.2668546920110242, 1.275424500625791, 1.2838620180052702, 1.292172096928448, 1.3003593134073366, 1.3084279878714606, 1.3163822043342375, 1.3242258277697823, 1.3319625198988463, 1.3395957535571519, 1.3471288257976295, 1.354564869859367, 1.3619068661200142, 1.3691576521344881, 1.3763199318508206, 1.383396284083539, 1.3903891703159095, 1.3973009418944407, 1.404133846672126, 1.4108900351508284, 1.417571566167883, 1.4241804121672976, 1.4307184640917887, 1.4371875359282316, 1.443589368935865, 1.4499256355837062, 1.4561979432210856, 1.4624078375029255, 1.4685568055893563, 1.4746462791374575, 1.4806776371012742, 1.4866522083548113, 1.4925712741514, 1.49843607043165, 1.5042477899911528, 1.510007584518133, 1.5157165665103982, 1.521375811080145, 1.526986357654484, 1.5325492115789003, 1.538065345630288, 1.543535701445671, 1.5489611908722425, 1.5543426972439125, 1.559681076589167, 1.5649771587746644, 1.570231748588672, 1.5754456267681387, 1.5806195509729188, 1.5857542567104117, 1.5908504582136447, 1.5959088492756097, 1.6009301040424735, 1.6059148777680887, 1.6108638075320787, 1.6157775129236005, 1.6206565966927624, 1.625501645371526], [0.0, 0.42997714837183004, 0.5293639640839567, 0.5978355705795093, 0.6517234870080821, 0.696845301935949, 0.7360219228178333, 0.7708587157144184, 0.8023657300756686, 0.8312241029633822, 0.8579172004440949, 0.8828017403633958, 0.9061492783765587, 0.9281718243462789, 0.9490384013300431, 0.9688861611972635, 0.9878280860420743, 1.0059584696676387, 1.0233569106010076, 1.0400912801969562, 1.0562199684392581, 1.0717936101729575, 1.086856430739564, 1.1014473082435876, 1.1156006217298275, 1.1293469354568555, 1.1427135561680801, 1.1557249908658431, 1.1684033258472732, 1.1807685428488635, 1.1928387845252126, 1.2046305787857483, 1.216159029475901, 1.2274379793373025, 1.2384801499883147, 1.2492972627406829, 1.2599001433443433, 1.2702988131821025, 1.2805025689832445, 1.2905200527634264, 1.3003593134073363, 1.3100278610752603, 1.3195327154232157, 1.3288804484696655, 1.33807722281301, 1.3471288257976295, 1.3560407001378887, 1.3648179714358555, 1.3734654729667926, 1.3819877680546362, 1.3903891703159093, 1.39867376201345, 1.406845410729834, 1.4149077845434992, 1.422864365867587, 1.4307184640917885, 1.4384732271504903, 1.4461316521258578, 1.4536965949817957, 1.4611707795137026, 1.468556805589356, 1.4758571567478918, 1.483074207216527, 1.4902102283982717, 1.4972673948782311, 1.5042477899911526, 1.511153410988493, 1.517986173839412, 1.5247479176966878, 1.5314404090554934, 1.5380653456302877, 1.5446243599726637, 1.5511190228508476, 1.5575508464096348, 1.563921287127823, 1.570231748588672, 1.5764835840775349, 1.5826780990195632, 1.588816553269279, 1.594900163262783, 1.6009301040424735, 1.6069075111633213, 1.6128334824889967, 1.618709079885476, 1.6245353308191393, 1.6303132298658147, 1.6360437401367156, 1.6417277946267566, 1.6473662974903183, 1.652960125249136, 1.6585101279366483, 1.6640171301828106, 1.6694819322430907, 1.6749053109750902, 1.6802880207659951, 1.6856307944138174, 1.6909343439651996, 1.6961993615123458, 1.7014265199514753, 1.7066164737050282, 1.711769859409705, 1.7168872965722752], [0.0, 0.45032847814030624, 0.5544193900325562, 0.6261318390911265, 0.6825703346886778, 0.7298278187766998, 0.7708587157144184, 0.8073443754472973, 0.8403426542669354, 0.8705669282622857, 0.8985234417906398, 0.9245857965774334, 0.9490384013300431, 0.9721033005900913, 0.9939575174773806, 1.0147446954224053, 1.0345831640961758, 1.0535716803396946, 1.0717936101729577, 1.0893200373826755, 1.1062121156199922, 1.1225228763373836, 1.1382986381143665, 1.1535801192023718, 1.1684033258472732, 1.1828002689503483, 1.1967995477156448, 1.2104268290910694, 1.2237052447444592, 1.236655722171658, 1.2492972627406829, 1.2616471766465691, 1.2737212826177138, 1.2855340785891718, 1.297098888308631, 1.3084279878714606, 1.3195327154232157, 1.3304235666706687, 1.3411102783683562, 1.3516019015688139, 1.361906866120014, 1.3720330376470597, 1.3819877680546362, 1.3917779404226553, 1.4014100090326287, 1.4108900351508282, 1.4202237191017624, 1.4294164290883402, 1.4384732271504903, 1.447398892599698, 1.4561979432210856, 1.4648746544958464, 1.4734330770638386, 1.4818770526180147, 1.4902102283982717, 1.49843607043165, 1.5065578756480145, 1.5145787829849935, 1.5225017835826598, 1.5303297301568874, 1.5380653456302877, 1.5457112310908572, 1.55326987314081, 1.560743650691363, 1.5681348412533196, 1.5754456267681387, 1.5826780990195635, 1.5898342646618526, 1.5969160498970727, 1.6039253048307134, 1.6108638075320785, 1.617733267823369, 1.6245353308191395, 1.6312715802357964, 1.6379435414890116, 1.6445526845953091, 1.6511004268926472, 1.6575881355935032, 1.6640171301828108, 1.6703886846720382, 1.6767040297197382, 1.6829643546280488, 1.689170809223833, 1.6953245056324464, 1.7014265199514753, 1.7074778938312043, 1.7134796359680458, 1.7194327235166733, 1.7253381034261697, 1.731196693705086, 1.7370093846199548, 1.7427770398314473, 1.7485004974720746, 1.7541805711690328, 1.75981805101555, 1.7654137044938396, 1.7709682773525588, 1.7764824944414586, 1.7819570605057367, 1.7873926609424253, 1.7927899625209973, 1.798149614070214], [0.0, 0.46873458231841997, 0.5770799623628855, 0.6517234870080822, 0.710468771716361, 0.759657792932374, 0.8023657300756686, 0.8403426542669354, 0.8746896591546226, 0.9061492783765587, 0.9352484478226214, 0.962376039299117, 0.9878280860420743, 1.0118357081350007, 1.034583164096176, 1.0562199684392584, 1.0768692872787824, 1.0966339139064576, 1.1156006217298278, 1.1338433999161135, 1.1514259016263249, 1.1684033258472732, 1.1848238843201155, 1.2007299595578473, 1.2161590294759013, 1.2311444133449165, 1.2457158792933032, 1.2599001433443435, 1.2737212826177138, 1.287201079970816, 1.3003593134073366, 1.3132140006353124, 1.3257816069359947, 1.33807722281301, 1.350114716590505, 1.3619068661200142, 1.3734654729667926, 1.3848014618246332, 1.395924967414729, 1.406845410729834, 1.4175715661678827, 1.4281116208426743, 1.4384732271504903, 1.4486635495007438, 1.4586893059783335, 1.4685568055893563, 1.478271981645511, 1.487840421762217, 1.4972673948782311, 1.5065578756480142, 1.5157165665103982, 1.5247479176966878, 1.5336561454070006, 1.5424452483543394, 1.5511190228508476, 1.559681076589167, 1.5681348412533196, 1.5764835840775349, 1.584730418457613, 1.592878313707396, 1.6009301040424735, 1.608888496864119, 1.6167560804084922, 1.6245353308191395, 1.6322286186946957, 1.6398382151582813, 1.6473662974903183, 1.65481495436228, 1.6621861907051554, 1.6694819322430907, 1.6767040297197382, 1.6838542628422097, 1.6909343439651998, 1.6979459215357517, 1.7048905833172705, 1.7117698594097053, 1.7185852250813278, 1.7253381034261694, 1.7320298678599693, 1.7386618444663802, 1.7452353142041923, 1.751751514985437, 1.7582116436334119, 1.7646168577289483, 1.7709682773525588, 1.7772669867295032, 1.7835140357842574, 1.7897104416103653, 1.7958571898611986, 1.801955236066722, 1.8080055068809922, 1.8140089012647542, 1.8199662916071895, 1.8258785247905682, 1.8317464232012974, 1.8375707856905992, 1.843352388487831, 1.8490919860692505, 1.854790311984838, 1.860448079645597, 1.8660659830736148, 1.8716446976169836], [0.0, 0.48559337483020387, 0.5978355705795094, 0.6751637695410695, 0.7360219228178333, 0.7869801062288712, 0.8312241029633822, 0.8705669282622857, 0.9061492783765587, 0.9387403933595694, 0.9688861611972633, 0.9969894400953795, 1.0233569106010074, 1.0482280054028688, 1.0717936101729575, 1.0942086169546863, 1.1156006217298275, 1.136076114916016, 1.1557249908658431, 1.1746238998858298, 1.1928387845252129, 1.2104268290910691, 1.2274379793373025, 1.2439161421320981, 1.2599001433443433, 1.275424500625791, 1.2905200527634264, 1.305214476665242, 1.3195327154232157, 1.3334973353502206, 1.3471288257976293, 1.3604458525093028, 1.3734654729667923, 1.3862033204279376, 1.39867376201345, 1.4108900351508282, 1.422864365867587, 1.434608071781688, 1.4461316521258578, 1.457444866733995, 1.468556805589356, 1.4794759502684445, 1.4902102283982714, 1.5007670620677482, 1.5111534109884928, 1.5213758110801447, 1.5314404090554932, 1.5413529934975254, 1.5511190228508476, 1.5607436506913628, 1.570231748588672, 1.579587926833801, 1.588816553269279, 1.5979217704282493, 1.6069075111633213, 1.6157775129236005, 1.6245353308191393, 1.633184349595497, 1.6417277946267566, 1.6501687420229045, 1.6585101279366483, 1.6667547571452994, 1.67490531097509, 1.6829643546280488, 1.6909343439651996, 1.6988176317942556, 1.7066164737050284, 1.7143330334914173, 1.721969388194976, 1.7295275328016144, 1.7370093846199546, 1.7444167873671343, 1.7517515149854368, 1.7590152752109522, 1.7662097129135477, 1.7733364132256764, 1.7803969044760037, 1.7873926609424253, 1.794325105437784, 1.8011956117404622, 1.8080055068809922, 1.8147560732948997, 1.8214485508511564, 1.8280841387648485, 1.8346639974019836, 1.8411892499837257, 1.8476609841967715, 1.8540802537160692, 1.860448079645597, 1.8667654518824914, 1.8730333304094111, 1.8792526465196684, 1.885424303979324, 1.8915491801301296, 1.8976281269369415, 1.9036619719829493, 1.9096515194158463, 1.9155975508478424, 1.9215008262122208, 1.9273620845789587, 1.9331820449317627, 1.9389614069087044], [0.0, 0.5011872336272724, 0.6170338627200097, 0.696845301935949, 0.7596577929323739, 0.8122523963562356, 0.8579172004440949, 0.8985234417906398, 0.9352484478226214, 0.9688861611972633, 1.0, 1.029005759421095, 1.0562199684392581, 1.0818897486445278, 1.1062121156199922, 1.1293469354568555, 1.1514259016263246, 1.172558924272542, 1.1928387845252129, 1.2123445941619542, 1.2311444133449163, 1.2492972627406829, 1.2668546920110242, 1.2838620180052702, 1.3003593134073366, 1.3163822043342375, 1.331962519898846, 1.3471288257976295, 1.361906866120014, 1.3763199318508206, 1.3903891703159093, 1.4041338466721258, 1.4175715661678827, 1.4307184640917885, 1.4435893689358648, 1.4561979432210856, 1.468556805589356, 1.480677637101274, 1.4925712741513997, 1.5042477899911526, 1.515716566510398, 1.526986357654484, 1.5380653456302877, 1.5489611908722423, 1.5596810765891669, 1.570231748588672, 1.5806195509729186, 1.5908504582136445, 1.6009301040424735, 1.6108638075320785, 1.6206565966927624, 1.6303132298658147, 1.6398382151582813, 1.6492358281324606, 1.6585101279366483, 1.6676649720406433, 1.6767040297197382, 1.6856307944138174, 1.6944485950733936, 1.7031606065915657, 1.711769859409705, 1.72027924837493, 1.728691540918895, 1.7370093846199548, 1.7452353142041923, 1.7533717580350285, 1.7614210441360247, 1.7693854057869884, 1.7772669867295032, 1.7850678460144567, 1.792789962520997, 1.8004352391735468, 1.8080055068809922, 1.8155025282199486, 1.8229280008819848, 1.8302835609029082, 1.8375707856905992, 1.8447911968664352, 1.8519462629340444, 1.859037401787951, 1.8660659830736148, 1.8730333304094111, 1.8799407234802201, 1.886789400011519, 1.8935805576321465, 1.9003153556332644, 1.9069949166304496, 1.9136203281353112, 1.9201926440425374, 1.926712886037828, 1.9331820449317627, 1.939601081924274, 1.945970929804059, 1.9522924940869435, 1.9585666540969286, 1.9647942639933809, 1.9709761537475867, 1.9771131300716664, 1.983205977302639, 1.9892554582442339, 1.9952623149688795, 2.0012272695821234], [0.0, 0.5157245499507892, 0.6349313984967353, 0.7170578291176234, 0.7816922441165304, 0.8358123939541525, 0.8828017403633958, 0.9245857965774334, 0.962376039299117, 0.9969894400953795, 1.029005759421095, 1.0588528529217847, 1.0868564307395638, 1.11327078241386, 1.1382986381143663, 1.162104500969668, 1.1848238843201153, 1.2065698863370495, 1.2274379793373027, 1.2475095697956808, 1.2668546920110242, 1.2855340785891718, 1.3036007744289815, 1.3211014108294128, 1.3380772228130102, 1.354564869859367, 1.3705971043089475, 1.3862033204279378, 1.4014100090326287, 1.4162411366805434, 1.4307184640917885, 1.4448618152237143, 1.4586893059783332, 1.4722175396605535, 1.4854617748740688, 1.49843607043165, 1.5111534109884928, 1.523625816423229, 1.5358644374482726, 1.54787963949735, 1.5596810765891669, 1.5712777565839042, 1.5826780990195632, 1.5938899865272955, 1.6049208106703468, 1.6157775129236005, 1.6264666214047183, 1.6369942838795284, 1.6473662974903183, 1.6575881355935032, 1.6676649720406433, 1.677601703192331, 1.6874029679166804, 1.6970731657919214, 1.7066164737050284, 1.7160368610146415, 1.7253381034261697, 1.734523795709374, 1.743597363373505, 1.752562073401847, 1.7614210441360247, 1.7701772543903955, 1.7788335518680707, 1.7873926609424255, 1.7958571898611984, 1.8042296374243352, 1.8125123991814884, 1.8207077731904424, 1.8288179653736338, 1.8368450945062844, 1.8447911968664352, 1.8526582305742765, 1.8604480796455973, 1.8681625577818863, 1.8758034119175455, 1.8833723255428432, 1.8908709218195734, 1.898300766504897, 1.9056633706975055, 1.91296019341903, 1.9201926440425374, 1.927362084578959, 1.9344698318314069, 1.9415171594265255, 1.9485052997312875, 1.9554354456629754, 1.9623087523994838, 1.969126338996521, 1.9758892899177918, 1.982598656483765, 1.989255458244234, 1.995860684279465, 2.0024152944344005, 2.008920220490039, 2.0153763672758434, 2.0217846137267204, 2.0281458138879045, 2.0344607978708136, 2.040730372762757, 2.0469553234931666, 2.053136413658844, 2.0592743863105576], [0.0, 0.5293639640839567, 0.6517234870080822, 0.7360219228178333, 0.8023657300756685, 0.8579172004440949, 0.9061492783765587, 0.9490384013300431, 0.9878280860420743, 1.0233569106010074, 1.0562199684392581, 1.0868564307395638, 1.1156006217298275, 1.1427135561680801, 1.1684033258472732, 1.1928387845252129, 1.216159029475901, 1.238480149988315, 1.2599001433443433, 1.2805025689832445, 1.3003593134073366, 1.3195327154232157, 1.33807722281301, 1.3560407001378887, 1.3734654729667923, 1.3903891703159093, 1.4068454107298338, 1.422864365867587, 1.43847322715049, 1.4536965949817957, 1.468556805589356, 1.4830742072165268, 1.497267394878231, 1.5111534109884928, 1.5247479176966876, 1.5380653456302877, 1.5511190228508474, 1.563921287127823, 1.5764835840775346, 1.588816553269279, 1.6009301040424733, 1.6128334824889967, 1.6245353308191393, 1.6360437401367154, 1.647366297490318, 1.6585101279366483, 1.6694819322430905, 1.680288020765995, 1.6909343439651996, 1.701426519951475, 1.711769859409705, 1.7219693881949758, 1.7320298678599693, 1.7419558143389613, 1.7517515149854366, 1.7614210441360245, 1.7709682773525588, 1.7803969044760037, 1.789710441610365, 1.7989122421411312, 1.808005506880992, 1.8169932934252793, 1.8258785247905678, 1.8346639974019838, 1.8433523884878307, 1.8519462629340444, 1.860448079645597, 1.868860197457217, 1.8771848806315714, 1.885424303979324, 1.8935805576321463, 1.9016556514968117, 1.9096515194158465, 1.9175700230578674, 1.92541295555861, 1.9331820449317627, 1.9408789572670275, 1.9485052997312875, 1.9560626233873983, 1.96355242584387, 1.9709761537475867, 1.9783352051307068, 1.9856309316219543, 1.9928646405316934, 2.0000375968194186, 2.0071510249516042, 2.014206110657239, 2.021204002587801, 2.0281458138879045, 2.035032623682387, 2.041865478485167, 2.0486453935348075, 2.055373354061357, 2.062050316488712, 2.068677209576441, 2.075254935504724, 2.0817843709058064, 2.0882663678451383, 2.094701754755141, 2.1010913373243465, 2.107435899344471, 2.113736203517813], [0.0, 0.5422293302128559, 0.6675626106433133, 0.7539097885556039, 0.8218659786514627, 0.8787675409297631, 0.9281718243462789, 0.9721033005900913, 1.0118357081350007, 1.0482280054028688, 1.0818897486445278, 1.11327078241386, 1.1427135561680801, 1.1704854282221195, 1.1967995477156448, 1.2218288721338852, 1.2457158792933032, 1.2685794798521184, 1.2905200527634266, 1.3116231882484286, 1.331962519898846, 1.351601901568814, 1.3705971043089475, 1.388997155953978, 1.406845410729834, 1.4241804121672976, 1.4410365958572944, 1.4574448667339952, 1.4734330770638384, 1.489026425124538, 1.5042477899911526, 1.51911801443938, 1.5336561454070003, 1.54787963949735, 1.5618045395039353, 1.5754456267681387, 1.588816553269279, 1.6019299566270706, 1.6147975606257003, 1.6274302634126145, 1.639838215158281, 1.6520308866664326, 1.6640171301828108, 1.6758052334528986, 1.6874029679166802, 1.6988176317942558, 1.7100560887047174, 1.7211248023677916, 1.7320298678599695, 1.7427770398314475, 1.7533717580350285, 1.7638191704713746, 1.7741241544152841, 1.7842913355537775, 1.794325105437784, 1.8042296374243352, 1.8140089012647544, 1.8236666764758407, 1.833206564615027, 1.8426320005666104, 1.8519462629340444, 1.8611524836227502, 1.8702536566886647, 1.8792526465196688, 1.8881521954099272, 1.8969549305809308, 1.9056633706975055, 1.9142799319221808, 1.9228069335469995, 1.9312466032380091, 1.939601081924274, 1.947872428360219, 1.9560626233873988, 1.9641735739193849, 1.972207116671282, 1.9801650216534588, 1.9880489954473297, 1.9958606842794653, 2.003601676908886, 2.0112735073411425, 2.018877657381617, 2.0264155590394606, 2.033888596792627, 2.0412981097236216, 2.048645393534808, 2.0559317024514088, 2.0631582510197095, 2.0703262158073708, 2.077436737012252, 2.0844909199856385, 2.091489836675339, 2.098434526993707, 2.1053260001152716, 2.1121652357083214, 2.11895318510448, 2.125690772410009, 2.1323788955623346, 2.139018427335031, 2.145610216294277, 2.1521550877096094, 2.15865384442158, 2.165107267668778], [0.0, 0.5544193900325562, 0.6825703346886778, 0.7708587157144183, 0.8403426542669353, 0.8985234417906398, 0.9490384013300431, 0.9939575174773806, 1.034583164096176, 1.0717936101729575, 1.1062121156199922, 1.1382986381143663, 1.1684033258472732, 1.1967995477156448, 1.223705244744459, 1.2492972627406829, 1.2737212826177136, 1.297098888308631, 1.3195327154232157, 1.3411102783683562, 1.361906866120014, 1.381987768054636, 1.4014100090326287, 1.4202237191017626, 1.4384732271504903, 1.4561979432210856, 1.4734330770638384, 1.4902102283982717, 1.5065578756480142, 1.5225017835826598, 1.5380653456302877, 1.55326987314081, 1.5681348412533194, 1.5826780990195632, 1.5969160498970725, 1.6108638075320785, 1.6245353308191393, 1.6379435414890113, 1.6511004268926472, 1.6640171301828106, 1.676704029719738, 1.689170809223833, 1.701426519951475, 1.7134796359680458, 1.7253381034261694, 1.7370093846199548, 1.7485004974720744, 1.7598180510155497, 1.7709682773525588, 1.7819570605057364, 1.792789962520997, 1.8034722471331257, 1.8140089012647544, 1.824404654594699, 1.8346639974019836, 1.8447911968664352, 1.854790311984838, 1.864665207242717, 1.8744195651654623, 1.884056897858285, 1.8935805576321465, 1.9029937468020015, 1.9122995267342753, 1.921500826212221, 1.9306004491805415, 1.939601081924274, 1.9485052997312877, 1.957315573082763, 1.9660342734116123, 1.9746636784648746, 1.9832059773026387, 1.991663274962956, 2.0000375968194186, 2.008330892655634, 2.0165450404785834, 2.024681850090899, 2.0327430664402892, 2.040730372762757, 2.0486453935348075, 2.056489697248543, 2.064264799022364, 2.0719721630589545, 2.079613204961233, 2.087189293916118, 2.094701754755141, 2.102151869900231, 2.1095408812023404, 2.1168699916799865, 2.124140367164242, 2.1313531378562067, 2.138509399802548, 2.1456102162942767, 2.1526566191935514, 2.159649610192949, 2.166590162011333, 2.1734792195301433, 2.180317700873673, 2.187106498436643, 2.1938464798621666, 2.200538488972971, 2.2071833466585673, 2.2137818517208614], [0.0, 0.5660142663870591, 0.6968453019359491, 0.7869801062288712, 0.8579172004440949, 0.9173147546424018, 0.9688861611972635, 1.0147446954224053, 1.0562199684392584, 1.0942086169546863, 1.1293469354568555, 1.162104500969668, 1.1928387845252129, 1.2218288721338852, 1.2492972627406829, 1.275424500625791, 1.3003593134073366, 1.3242258277697825, 1.3471288257976295, 1.3691576521344881, 1.3903891703159095, 1.4108900351508282, 1.4307184640917887, 1.4499256355837062, 1.4685568055893563, 1.4866522083548113, 1.5042477899911526, 1.521375811080145, 1.5380653456302877, 1.5543426972439125, 1.570231748588672, 1.5857542567104115, 1.6009301040424735, 1.6157775129236005, 1.6303132298658147, 1.6445526845953091, 1.6585101279366483, 1.6721987518598218, 1.6856307944138174, 1.6988176317942558, 1.711769859409705, 1.7244973635015173, 1.7370093846199548, 1.7493145740531681, 1.7614210441360247, 1.7733364132256764, 1.7850678460144567, 1.7966220897537137, 1.8080055068809922, 1.8192241044747146, 1.8302835609029082, 1.841189249983726, 1.8519462629340446, 1.8625594283470437, 1.8730333304094111, 1.8833723255428432, 1.8935805576321467, 1.9036619719829495, 1.9136203281353112, 1.9234592116450238, 1.9331820449317627, 1.94279209728225, 1.9522924940869433, 1.9616862253803444, 1.970976153747587, 1.9801650216534585, 1.989255458244234, 1.9982499856676201, 2.0071510249516042, 2.0159609014789965, 2.0246818500908987, 2.0333160198491758, 2.041865478485167, 2.0503322165593723, 2.0587181513545616, 2.0670251305227603, 2.0752549355047245, 2.0834092847388934, 2.091489836675339, 2.0994981926088974, 2.107435899344471, 2.1153044517064163, 2.1231052949029303, 2.130839826755488, 2.1385093998025484, 2.1461153232860317, 2.1536588650284, 2.161141253207556, 2.1685636780362363, 2.175927293352055, 2.1832332181239034, 2.19048253787998, 2.1976763060623417, 2.2048155453125107, 2.2119012486923535, 2.2189343808441326, 2.2259158790933773, 2.2328466544979477, 2.2397275928464535, 2.246559555608948, 2.2533433808426553, 2.2600798840552616], [0.0, 0.5770799623628855, 0.710468771716361, 0.8023657300756685, 0.8746896591546225, 0.9352484478226214, 0.9878280860420743, 1.0345831640961758, 1.0768692872787824, 1.1156006217298275, 1.1514259016263246, 1.1848238843201153, 1.216159029475901, 1.2457158792933032, 1.2737212826177136, 1.3003593134073366, 1.3257816069359947, 1.350114716590505, 1.3734654729667923, 1.3959249674147287, 1.4175715661678827, 1.43847322715049, 1.4586893059783332, 1.478271981645511, 1.497267394878231, 1.515716566510398, 1.5336561454070001, 1.5511190228508476, 1.5681348412533194, 1.5847304184576128, 1.6009301040424733, 1.616756080408492, 1.6322286186946955, 1.6473662974903178, 1.6621861907051552, 1.676704029719738, 1.6909343439651994, 1.7048905833172703, 1.7185852250813276, 1.732029867859969, 1.745235314204192, 1.7582116436334116, 1.7709682773525588, 1.7835140357842572, 1.7958571898611981, 1.8080055068809922, 1.8199662916071893, 1.8317464232012972, 1.8433523884878307, 1.8547903119848377, 1.8660659830736148, 1.8771848806315712, 1.888152195409927, 1.8989728504018566, 1.9096515194158463, 1.9201926440425372, 1.9306004491805413, 1.9408789572670275, 1.9510320013418414, 1.9610632370591314, 1.9709761537475865, 1.98077408460916, 1.9904602161363392, 2.0000375968194186, 2.009509145207664, 2.0188776573816165, 2.0281458138879045, 2.0373161861827436, 2.0463912426257194, 2.055373354061357, 2.064264799022364, 2.0730677685852084, 2.0817843709058064, 2.0904166354605263, 2.098966517015413, 2.107435899344471, 2.115826598715992, 2.124140367164242, 2.1323788955623346, 2.1405438165107515, 2.148636707054751, 2.1566590912428136, 2.1646124425372575, 2.1724981860872554, 2.180317700873673, 2.1880723217343814, 2.1957633412780333, 2.203392011693664, 2.210959546462915, 2.2184671219811642, 2.225915879093377, 2.233306924550052, 2.240641332388256, 2.247920145242365, 2.25514437558881, 2.2623150069288096, 2.2694329949128007, 2.2764992684100136, 2.283514730526407, 2.2904802595739544, 2.2973967099940698, 2.3042649132377844], [0.0, 0.5876715635211257, 0.7235085623107059, 0.8170921776223911, 0.8907435244960379, 0.952413796109262, 1.0059584696676387, 1.0535716803396946, 1.0966339139064576, 1.136076114916016, 1.172558924272542, 1.2065698863370495, 1.238480149988315, 1.2685794798521184, 1.297098888308631, 1.3242258277697825, 1.350114716590505, 1.374894430891181, 1.3986737620134502, 1.4215454731781725, 1.443589368935865, 1.4648746544958464, 1.485461774874069, 1.5054038667466347, 1.5247479176966878, 1.5435357014456712, 1.5618045395039353, 1.5795879268338011, 1.5969160498970725, 1.6138162187458565, 1.6303132298658147, 1.6464296727885344, 1.6621861907051552, 1.6776017031923312, 1.6926935975307154, 1.7074778938312045, 1.721969388194976, 1.7361817773538792, 1.7501277676190627, 1.7638191704713746, 1.7772669867295032, 1.790481480910189, 1.8034722471331257, 1.816248267709072, 1.8288179653736338, 1.8411892499837261, 1.8533695603729539, 1.8653659019614715, 1.8771848806315716, 1.888832733309385, 1.9003153556332646, 1.9116383270387534, 1.9228069335469997, 1.9338261885067332, 1.9447008515085125, 1.9554354456629757, 1.9660342734116125, 1.9765014310185363, 1.9868408218743787, 1.9970561687283763, 2.0071510249516042, 2.0171287849228854, 2.0269926936189027, 2.0367458554812843, 2.04639124262572, 2.0559317024514088, 2.065369964703155, 2.0747086480331265, 2.0839502661046487, 2.093097233276215, 2.1021518699002315, 2.111116407267711, 2.1199929922272083, 2.1287836915036635, 2.137490495740476, 2.1461153232860317, 2.154660023744019, 2.1631263813051627, 2.1715161178764975, 2.179830896022901, 2.1880723217343814, 2.196241947031476, 2.2043412724201112, 2.212371749206342, 2.22033478168055, 2.228231729179934, 2.236063908037406, 2.2438325934244094, 2.251539021094566, 2.2591843890345604, 2.2667698590281806, 2.2742965581389853, 2.281765580116686, 2.2891779867319446, 2.296534809043967, 2.3038370486049398, 2.3110856786051026, 2.3182816449619517, 2.3254258673568575, 2.3325192402221417, 2.3395626336814512, 2.346556894446091], [0.0, 0.5978355705795094, 0.7360219228178334, 0.8312241029633823, 0.9061492783765587, 0.9688861611972635, 1.0233569106010076, 1.0717936101729577, 1.1156006217298278, 1.1557249908658431, 1.1928387845252129, 1.2274379793373027, 1.2599001433443433, 1.2905200527634266, 1.3195327154232157, 1.3471288257976295, 1.3734654729667923, 1.3986737620134502, 1.4228643658675872, 1.4461316521258578, 1.4685568055893563, 1.4902102283982717, 1.511153410988493, 1.5314404090554934, 1.5511190228508476, 1.5702317485886723, 1.5888165532692793, 1.6069075111633215, 1.6245353308191393, 1.6417277946267566, 1.6585101279366483, 1.6749053109750902, 1.6909343439651996, 1.7066164737050284, 1.721969388194976, 1.7370093846199548, 1.7517515149854368, 1.766209712913548, 1.7803969044760037, 1.7943251054377842, 1.8080055068809922, 1.8214485508511566, 1.8346639974019838, 1.8476609841967717, 1.8604480796455973, 1.8730333304094113, 1.885424303979324, 1.8976281269369415, 1.9096515194158465, 1.9215008262122208, 1.9331820449317627, 1.9447008515085125, 1.9560626233873988, 1.9672724606249572, 1.9783352051307068, 1.989255458244234, 2.000037596819419, 2.010685787966847, 2.0212040025878015, 2.0315960278179075, 2.041865478485167, 2.0520158076754984, 2.062050316488712, 2.071972163058955, 2.081784370905807, 2.091489836675339, 2.101091337324347, 2.1105915367956016, 2.1199929922272083, 2.1292981597349243, 2.138509399802548, 2.1476289823121344, 2.156659091242814, 2.1656018290643346, 2.1744592208490428, 2.1832332181239034, 2.1919257024822145, 2.2005384889729713, 2.209073329284256, 2.217531914735649, 2.2259158790933773, 2.2342268012207733, 2.2424662075755952, 2.250635574564796, 2.2587363307665043, 2.2667698590281806, 2.274737498449225, 2.2826405462556636, 2.290480259573955, 2.2982578571104275, 2.305974520742369, 2.313631397026339, 2.321229598628872, 2.328770205684366, 2.3362542670845934, 2.3436828017039746, 2.3510567995644505, 2.358377222943526, 2.365645007428817, 2.372861062922197, 2.3800262745964407, 2.3871415038070505], [0.0, 0.607611633351008, 0.7480576678834732, 0.8448166347692024, 0.9209670186745647, 0.9847298018175752, 1.0400912801969562, 1.0893200373826755, 1.1338433999161135, 1.1746238998858298, 1.2123445941619542, 1.2475095697956808, 1.2805025689832445, 1.3116231882484286, 1.3411102783683562, 1.3691576521344881, 1.3959249674147287, 1.4215454731781725, 1.4461316521258578, 1.4697794149937133, 1.4925712741513997, 1.5145787829849935, 1.5358644374482726, 1.5564831771785468, 1.5764835840775349, 1.5959088492756097, 1.6147975606257003, 1.633184349595497, 1.6511004268926472, 1.6685740292166915, 1.6856307944138171, 1.702294078492782, 1.7185852250813276, 1.7345237957093738, 1.7501277676190625, 1.7654137044938394, 1.7803969044760037, 1.7950915290362253, 1.8095107156188694, 1.8236666764758405, 1.8375707856905992, 1.851233656061466, 1.864665207242717, 1.8778747263206257, 1.8908709218195734, 1.9036619719829493, 1.9162555680487132, 1.9286589531353797, 1.9408789572670275, 1.9529220289926579, 1.9647942639933809, 1.9765014310185358, 1.98804899544733, 1.9994421407346024, 2.0106857879668465, 2.0217846137267204, 2.0327430664402892, 2.0435653813605117, 2.0542555943225467, 2.0648175543908796, 2.075254935504724, 2.085571247216336, 2.095769844606521, 2.1058539374525846, 2.115826598715992, 2.125690772410009, 2.1354492809014145, 2.145104831694911, 2.154660023744019, 2.16411735332795, 2.1734792195301433, 2.1827479293507346, 2.1919257024822145, 2.2010146757748155, 2.2100169074157323, 2.2189343808441326, 2.227769008421933, 2.2365226348785843, 2.245197040546522, 2.2537939444025072, 2.2623150069288096, 2.2707618328070107, 2.279135973456158, 2.287438929426042, 2.2956721526555115, 2.3038370486049393, 2.311934978271252, 2.3199672600932693, 2.3279351717545196, 2.335839951890138, 2.3436828017039746, 2.3514648865015713, 2.3591873371442627, 2.366851251429265, 2.3744576954002774, 2.382007704592791, 2.3895022852180072, 2.3969424152890055, 2.4043290456925295, 2.411663101209558, 2.4189454814875875, 2.426177061967375], [0.0, 0.6170338627200097, 0.759657792932374, 0.8579172004440949, 0.9352484478226214, 1.0, 1.0562199684392581, 1.1062121156199922, 1.1514259016263249, 1.1928387845252129, 1.2311444133449163, 1.2668546920110242, 1.3003593134073366, 1.331962519898846, 1.361906866120014, 1.3903891703159095, 1.4175715661678827, 1.443589368935865, 1.4685568055893563, 1.4925712741513997, 1.5157165665103982, 1.5380653456302877, 1.559681076589167, 1.5806195509729188, 1.6009301040424735, 1.6206565966927626, 1.6398382151582813, 1.6585101279366485, 1.6767040297197382, 1.6944485950733936, 1.711769859409705, 1.728691540918895, 1.745235314204192, 1.7614210441360247, 1.7772669867295032, 1.7927899625209973, 1.8080055068809922, 1.8229280008819848, 1.8375707856905992, 1.8519462629340444, 1.8660659830736148, 1.8799407234802203, 1.8935805576321465, 1.9069949166304496, 1.9201926440425374, 1.933182044931763, 1.9459709298040588, 1.9585666540969286, 1.970976153747587, 1.983205977302639, 1.9952623149688795, 2.0071510249516042, 2.018877657381617, 2.0304474760935554, 2.041865478485167, 2.053136413658844, 2.0642647990223644, 2.0752549355047245, 2.086110921524751, 2.0968366658343447, 2.107435899344471, 2.117912186029987, 2.128268932998912, 2.1385093998025484, 2.148636707054751, 2.15865384442158, 2.1685636780362363, 2.1783689573886784, 2.1880723217343814, 2.1976763060623417, 2.2071833466585673, 2.2165957862978303, 2.2259158790933773, 2.235145795031561, 2.2442876242158722, 2.2533433808426553, 2.2623150069288096, 2.2712043758099933, 2.280013295426244, 2.2887435114104844, 2.29739670999407, 2.305974520742369, 2.314478519132273, 2.3229102289825883, 2.3312711247473685, 2.3395626336814512, 2.3477861378867324, 2.355942976247054, 2.3640344462589735, 2.3720618057651324, 2.3800262745964407, 2.387929036128825, 2.3957712387598797, 2.4035539973103535, 2.411278394355079, 2.4189454814875875, 2.426556280522392, 2.434111784638613, 2.441612959468389, 2.44906074413327, 2.4564560522315806, 2.4637997727795318], [0.0, 0.6261318390911265, 0.7708587157144184, 0.8705669282622857, 0.9490384013300431, 1.0147446954224053, 1.0717936101729575, 1.1225228763373836, 1.1684033258472732, 1.2104268290910691, 1.2492972627406829, 1.2855340785891718, 1.3195327154232157, 1.351601901568814, 1.381987768054636, 1.4108900351508282, 1.43847322715049, 1.4648746544958464, 1.4902102283982717, 1.5145787829849935, 1.5380653456302877, 1.5607436506913628, 1.5826780990195632, 1.6039253048307134, 1.6245353308191393, 1.6445526845953091, 1.6640171301828108, 1.6829643546280488, 1.701426519951475, 1.7194327235166733, 1.7370093846199546, 1.7541805711690326, 1.7709682773525586, 1.7873926609424253, 1.8034722471331257, 1.8192241044747146, 1.8346639974019838, 1.8498065190319637, 1.864665207242717, 1.8792526465196686, 1.8935805576321465, 1.9076598768601123, 1.9215008262122208, 1.9351129758482406, 1.9485052997312875, 1.9616862253803442, 1.9746636784648746, 1.987445122876067, 2.0000375968194186, 2.0124477453978598, 2.0246818500908987, 2.036745855481284, 2.048645393534808, 2.060385805699746, 2.0719721630589545, 2.083409284738893, 2.0947017547551416, 2.1058539374525846, 2.1168699916799865, 2.127753883822604, 2.138509399802548, 2.1491401561443992, 2.1596496101929485, 2.1700410695605874, 2.180317700873673, 2.19048253787998, 2.2005384889729713, 2.210488344182997, 2.22033478168055, 2.2300803738322674, 2.239727592846453, 2.249278816041379, 2.2587363307665043, 2.268102339003971, 2.277378961675209, 2.286568242675273, 2.2956721526555115, 2.3046925925733457, 2.3136313970263385, 2.3224903373862382, 2.3312711247473685, 2.3399754127025423, 2.348604799958578, 2.357160832802526, 2.3656450074288164, 2.3740587721367246, 2.3824035294068175, 2.3906806378643717, 2.3988914141371365, 2.4070371346142596, 2.415119037112687, 2.4231383224568623, 2.4310961559771527, 2.438993668931999, 2.446831959858471, 2.4546120958555253, 2.4623351138040195, 2.4700020215271965, 2.4776137988951477, 2.485171398876484, 2.4926757485402593, 2.5001277500109573], [0.0, 0.6349313984967353, 0.7816922441165305, 0.8828017403633958, 0.962376039299117, 1.029005759421095, 1.086856430739564, 1.1382986381143665, 1.1848238843201155, 1.2274379793373025, 1.2668546920110242, 1.3036007744289815, 1.33807722281301, 1.3705971043089475, 1.4014100090326287, 1.4307184640917887, 1.4586893059783332, 1.485461774874069, 1.511153410988493, 1.5358644374482726, 1.559681076589167, 1.5826780990195632, 1.604920810670347, 1.6264666214047185, 1.6473662974903183, 1.6676649720406436, 1.6874029679166802, 1.7066164737050287, 1.7253381034261694, 1.7435973633735051, 1.7614210441360247, 1.7788335518680707, 1.7958571898611984, 1.8125123991814882, 1.8288179653736336, 1.8447911968664354, 1.8604480796455973, 1.8758034119175455, 1.8908709218195734, 1.9056633706975055, 1.9201926440425372, 1.9344698318314069, 1.9485052997312877, 1.9623087523994838, 1.9758892899177916, 1.989255458244234, 2.0024152944344, 2.0153763672758434, 2.0281458138879045, 2.040730372762757, 2.0531364136588444, 2.0653699647031547, 2.077436737012252, 2.0893421471022946, 2.101091337324347, 2.1126891945321224, 2.1241403671642423, 2.1354492809014145, 2.146620153040217, 2.157657005708867, 2.1685636780362363, 2.1793438373729783, 2.1900009896528694, 2.2005384889729713, 2.2109595464629153, 2.221267238506294, 2.23146451437068, 2.2415542032970763, 2.251539021094566, 2.261421576281427, 2.2712043758099933, 2.280889830408998, 2.290480259573955, 2.299977896233319, 2.3093848911156187, 2.3187033168404945, 2.3279351717545196, 2.3370823835308765, 2.346146812550276, 2.3551302550790494, 2.3640344462589735, 2.3728610629221976, 2.3816117262435164, 2.390288004241258, 2.3988914141371365, 2.407423424584599, 2.415885457774457, 2.4242788914258946, 2.432605060670343, 2.440865259835124, 2.4490607441332704, 2.457192731265425, 2.4652624029393277, 2.473270906311949, 2.4812193553590265, 2.4891088321763615, 2.496940388216972, 2.504715045467893, 2.5124337975701567, 2.5200976108852475, 2.527707425511103, 2.535264156250524], [0.0, 0.6434552531631887, 0.7921863401692986, 0.8946532155809792, 0.9752957870275872, 1.0428200007155333, 1.1014473082435876, 1.1535801192023718, 1.2007299595578473, 1.2439161421320981, 1.2838620180052702, 1.3211014108294128, 1.3560407001378887, 1.388997155953978, 1.4202237191017626, 1.4499256355837062, 1.478271981645511, 1.5054038667466347, 1.5314404090554934, 1.5564831771785468, 1.5806195509729188, 1.6039253048307134, 1.6264666214047185, 1.6483016812765647, 1.6694819322430907, 1.69005311332278, 1.7100560887047174, 1.7295275328016146, 1.7485004974720746, 1.7670048851268705, 1.7850678460144567, 1.802714113937978, 1.8199662916071893, 1.8368450945062844, 1.8533695603729539, 1.869557229998947, 1.885424303979324, 1.9009857791841167, 1.9162555680487134, 1.9312466032380091, 1.9459709298040588, 1.9604397866048031, 1.9746636784648746, 1.9886524403250836, 2.0024152944344, 2.0159609014789965, 2.0292974064106755, 2.0424324796267785, 2.055373354061357, 2.0681268586697876, 2.0806994487235233, 2.093097233276215, 2.1053260001152716, 2.117391238472734, 2.1292981597349243, 2.1410517163608027, 2.1526566191935514, 2.1641173533279505, 2.175438192677122, 2.1866232133657277, 2.1976763060623417, 2.2086011873512272, 2.2194014102327726, 2.230080373832268, 2.240641332388256, 2.2510874035843003, 2.261421576281427, 2.271646717702757, 2.281765580116686, 2.2917808070604413, 2.3016949391418002, 2.311510419453151, 2.321229598628872, 2.3308547395741335, 2.340388021890658, 2.3498315460226795, 2.3591873371442627, 2.3684573488072993, 2.377643466367821, 2.386747510206753, 2.3957712387598797, 2.4047163513705585, 2.413584490977603, 2.422377246649742, 2.4310961559771527, 2.4397427073297258, 2.448318341990961, 2.456824456175708, 2.4652624029393277, 2.473633493985284, 2.481939001377648, 2.490180159164504, 2.4983581649178315, 2.5064741811950055, 2.5145293369267128, 2.5225247287357218, 2.5304614221906423, 2.538340452998526, 2.54616282813988, 2.5539295269494406, 2.5616415021458128, 2.569299680812882], [0.0, 0.6517234870080822, 0.8023657300756686, 0.9061492783765588, 0.9878280860420744, 1.0562199684392584, 1.1156006217298275, 1.1684033258472732, 1.2161590294759013, 1.2599001433443433, 1.3003593134073366, 1.3380772228130102, 1.3734654729667923, 1.406845410729834, 1.4384732271504903, 1.4685568055893563, 1.497267394878231, 1.5247479176966878, 1.5511190228508476, 1.5764835840775349, 1.6009301040424735, 1.6245353308191393, 1.6473662974903183, 1.6694819322430907, 1.6909343439651998, 1.7117698594097053, 1.7320298678599693, 1.751751514985437, 1.7709682773525588, 1.7897104416103653, 1.8080055068809922, 1.825878524790568, 1.8433523884878307, 1.860448079645597, 1.8771848806315714, 1.8935805576321467, 1.9096515194158465, 1.9254129555586101, 1.9408789572670275, 1.9560626233873986, 1.9709761537475867, 1.9856309316219545, 2.0000375968194186, 2.0142061106572395, 2.0281458138879045, 2.041865478485167, 2.055373354061357, 2.0686772095764416, 2.081784370905807, 2.0947017547551416, 2.1074358993444715, 2.1199929922272083, 2.132378895562335, 2.1445991691171065, 2.156659091242814, 2.1685636780362363, 2.1803177008736734, 2.191925702482215, 2.2033920116936643, 2.214720757009831, 2.2259158790933773, 2.236981142285713, 2.247920145242365, 2.2587363307665047, 2.2694329949128007, 2.280013295426244, 2.290480259573955, 2.30083679142213, 2.3110856786051026, 2.321229598628872, 2.3312711247473685, 2.341212731446087, 2.3510567995644505, 2.360805621085376, 2.3704614036179064, 2.3800262745964407, 2.3895022852180077, 2.3988914141371365, 2.4081955709361966, 2.417416599387539, 2.426556280522392, 2.4356163355202387, 2.4445984284312305, 2.4535041687432195, 2.4623351138040195, 2.4710927711086903, 2.4797786004608526, 2.4883940160163553, 2.4969403882169723, 2.5054190456212178, 2.5138312766388577, 2.522178331175176, 2.5304614221906427, 2.5386817271811943, 2.5468403895839864, 2.554938520113106, 2.562977198029445, 2.5709574723486224, 2.5788803629905854, 2.5867468618742686, 2.594557933960465, 2.6023145182458487], [0.0, 0.6597539553864472, 0.8122523963562357, 0.9173147546424018, 1.0, 1.069234599991188, 1.1293469354568555, 1.1828002689503483, 1.2311444133449165, 1.275424500625791, 1.3163822043342375, 1.354564869859367, 1.3903891703159093, 1.4241804121672976, 1.4561979432210856, 1.4866522083548113, 1.515716566510398, 1.5435357014456712, 1.5702317485886723, 1.5959088492756097, 1.6206565966927626, 1.6445526845953091, 1.6676649720406436, 1.69005311332278, 1.7117698594097053, 1.732862107887866, 1.7533717580350285, 1.7733364132256766, 1.7927899625209973, 1.8117630657589308, 1.8302835609029082, 1.8483768082625651, 1.8660659830736148, 1.8833723255428432, 1.9003153556332644, 1.9169130584443554, 1.9331820449317627, 1.9491376918357852, 1.964794263993381, 1.9801650216534585, 1.9952623149688795, 2.010097667477518, 2.024681850090899, 2.039024946868588, 2.0531364136588444, 2.0670251305227603, 2.0806994487235233, 2.094167232949409, 2.1074358993444715, 2.1205124498413204, 2.1334035032232417, 2.1461153232860317, 2.15865384442158, 2.17102469490401, 2.1832332181239034, 2.1952844919858565, 2.2071833466585677, 2.2189343808441326, 2.2305419767137655, 2.2420103136402423, 2.2533433808426553, 2.2645449890462355, 2.2756187812487645, 2.2865682426752736, 2.29739670999407, 2.308107379859548, 2.3187033168404945, 2.329187460786705, 2.3395626336814512, 2.3498315460226795, 2.3599968027716853, 2.3700609089043136, 2.3800262745964407, 2.389895220072557, 2.399669980143632, 2.409352708458088, 2.4189454814875875, 2.4284503022674344, 2.4378691039096707, 2.4472037529054163, 2.456456052231581, 2.4656277442758388, 2.4747205135925934, 2.483735989501637, 2.4926757485402598, 2.501541316778717, 2.510334172008177, 2.5190557458095677, 2.527707425511103, 2.5362905560416564, 2.5448064416866427, 2.553256347752548, 2.5616415021458128, 2.569963096871357, 2.578222289455647, 2.5864202042988724, 2.594557933960465, 2.602636540381904, 2.6106570560504836, 2.618620485107458, 2.6265278044037674, 2.634379964506303], [0.0, 0.6675626106433133, 0.8218659786514628, 0.9281718243462788, 1.0118357081350005, 1.0818897486445278, 1.1427135561680801, 1.1967995477156448, 1.2457158792933032, 1.2905200527634264, 1.331962519898846, 1.3705971043089475, 1.4068454107298338, 1.4410365958572944, 1.4734330770638384, 1.5042477899911526, 1.5336561454070001, 1.5618045395039353, 1.5888165532692793, 1.6147975606257003, 1.6398382151582813, 1.6640171301828108, 1.6874029679166802, 1.7100560887047174, 1.7320298678599693, 1.7533717580350285, 1.774124154415284, 1.7943251054377842, 1.8140089012647542, 1.833206564615027, 1.8519462629340444, 1.8702536566886647, 1.888152195409927, 1.9056633706975052, 1.9228069335469995, 1.939601081924274, 1.9560626233873986, 1.972207116671282, 1.9880489954473297, 2.003601676908886, 2.0188776573816165, 2.033888596792627, 2.048645393534808, 2.063158251019709, 2.0774367370122517, 2.091489836675339, 2.105326000115271, 2.1189531851044796, 2.1323788955623346, 2.145610216294277, 2.1586538444215795, 2.1715161178764975, 2.1842030412886504, 2.196720309546772, 2.2090733292842555, 2.221267238506294, 2.2333069245500523, 2.245197040546522, 2.2569420205330166, 2.268546093348149, 2.280013295426244, 2.2913474825951647, 2.3025523409701507, 2.313631397026339, 2.3245880269238706, 2.3354254651518063, 2.346146812550276, 2.3567550437642795, 2.3672530141772583, 2.377643466367821, 2.387929036128825, 2.398112258084279, 2.4081955709361966, 2.4181813223705686, 2.4280717736489343, 2.4378691039096707, 2.4475754142009527, 2.457192731265425, 2.4667230110948806, 2.476168142271683, 2.4855299491122493, 2.494810194626647, 2.5040105833071737, 2.513132763757775, 2.522178331175176, 2.531148829691755, 2.5400457545893835, 2.548870554392766, 2.557624632850126, 2.5663093508085235, 2.574926027990515, 2.583475944678384, 2.591960343311715, 2.600380430003648, 2.608737375980797, 2.617032318951422, 2.625266364406171, 2.6334405868553517, 2.6415560310064765, 2.6496137128855235, 2.6576146209051537, 2.665559716882892], [0.0, 0.6751637695410696, 0.8312241029633823, 0.9387403933595695, 1.0233569106010076, 1.0942086169546863, 1.1557249908658431, 1.2104268290910694, 1.2599001433443435, 1.305214476665242, 1.3471288257976295, 1.3862033204279378, 1.422864365867587, 1.4574448667339952, 1.4902102283982717, 1.521375811080145, 1.5511190228508476, 1.5795879268338011, 1.6069075111633215, 1.633184349595497, 1.6585101279366485, 1.6829643546280488, 1.7066164737050287, 1.7295275328016146, 1.751751514985437, 1.7733364132256766, 1.7943251054377842, 1.8147560732949, 1.8346639974019838, 1.8540802537160694, 1.8730333304094111, 1.8915491801301296, 1.9096515194158465, 1.927362084578959, 1.9447008515085125, 1.9616862253803442, 1.9783352051307068, 1.9946635266530477, 2.010685787966847, 2.0264155590394606, 2.041865478485167, 2.057047338996084, 2.0719721630589545, 2.0866502702658214, 2.101091337324347, 2.1153044517064163, 2.1292981597349243, 2.1430805097929677, 2.156659091242814, 2.1700410695605874, 2.1832332181239034, 2.196241947031476, 2.209073329284256, 2.221733124615463, 2.2342268012207733, 2.2465595556089486, 2.2587363307665047, 2.270761832807011, 2.2826405462556636, 2.2943767481024744, 2.305974520742369, 2.317437763907348, 2.328770205684366, 2.3399754127025427, 2.3510567995644505, 2.3620176375884534, 2.3728610629221976, 2.383590084081288, 2.3942075889618066, 2.4047163513705585, 2.415119037112687, 2.425418209672534, 2.4356163355202387, 2.4457157890735672, 2.4557188573417683, 2.4656277442758388, 2.4754445748474043, 2.4851713988764845, 2.4948101946266474, 2.5043628721844784, 2.5138312766388577, 2.5232171910742536, 2.532522339391055, 2.5417483889649315, 2.550896953156214, 2.559969593679444, 2.568967822842426, 2.5778931056633962, 2.586746861874269, 2.595530467817301, 2.6042452582419857, 2.6128925280084587, 2.6214735337032633, 2.6299894951728695, 2.6384415969799875, 2.646830989787321, 2.6551587916731147, 2.66342608938252, 2.671633939518544, 2.67978336967608, 2.6878753795222865, 2.695910941826362], [0.0, 0.6825703346886778, 0.8403426542669353, 0.9490384013300431, 1.0345831640961758, 1.1062121156199922, 1.1684033258472732, 1.2237052447444592, 1.2737212826177138, 1.3195327154232157, 1.361906866120014, 1.4014100090326287, 1.43847322715049, 1.4734330770638384, 1.5065578756480142, 1.5380653456302877, 1.5681348412533194, 1.5969160498970725, 1.6245353308191393, 1.6511004268926472, 1.6767040297197382, 1.701426519951475, 1.7253381034261694, 1.7485004974720746, 1.7709682773525588, 1.7927899625209973, 1.8140089012647542, 1.8346639974019838, 1.8547903119848377, 1.8744195651654623, 1.8935805576321463, 1.912299526734275, 1.9306004491805413, 1.9485052997312875, 1.9660342734116123, 1.983205977302639, 2.0000375968194186, 2.0165450404785834, 2.032743066440289, 2.0486453935348075, 2.064264799022364, 2.079613204961233, 2.094701754755141, 2.1095408812023404, 2.124140367164242, 2.138509399802548, 2.1526566191935514, 2.1665901620113326, 2.180317700873673, 2.193846479862166, 2.2071833466585673, 2.22033478168055, 2.2333069245500523, 2.2461055981847253, 2.2587363307665043, 2.2712043758099933, 2.2835147305264076, 2.2956721526555115, 2.307681175917866, 2.3195461242221813, 2.3312711247473685, 2.3428601200055943, 2.35431687898103, 2.365645007428817, 2.3768479574098094, 2.387929036128825, 2.3988914141371365, 2.4097381329538465, 2.420472112155338, 2.4310961559771522, 2.4416129594683884, 2.452025114234883, 2.4623351138040195, 2.4725453586409927, 2.4826581608436062, 2.4926757485402593, 2.5026002700135757, 2.5124337975701567, 2.522178331175176, 2.5318358018689215, 2.54140807498095, 2.550896953156214, 2.5603041792063386, 2.5696314387981496, 2.578880362990585, 2.588052530630239, 2.597149470614973, 2.6061726640343146, 2.615123546194676, 2.624003508536826, 2.632813900452497, 2.6415560310064765, 2.6502311705700956, 2.6588405523715752, 2.6673853739683095, 2.6758667986458047, 2.684285956747655, 2.6926439469406347, 2.7009418374187164, 2.709180667049537, 2.717361446466631, 2.725485159110502], [0.0, 0.6897939792303888, 0.8492360038884523, 0.9590820784710498, 1.0455321617986295, 1.1179191627986798, 1.1807685428488635, 1.236655722171658, 1.287201079970816, 1.3334973353502206, 1.3763199318508206, 1.4162411366805434, 1.4536965949817957, 1.489026425124538, 1.5225017835826598, 1.5543426972439125, 1.5847304184576128, 1.6138162187458565, 1.6417277946267566, 1.6685740292166915, 1.6944485950733936, 1.7194327235166733, 1.7435973633735051, 1.7670048851268705, 1.7897104416103653, 1.8117630657589308, 1.833206564615027, 1.8540802537160694, 1.8744195651654623, 1.8942565548098473, 1.9136203281353112, 1.9325374001612108, 1.9510320013418414, 1.969126338996521, 1.9868408218743785, 2.0041942539753497, 2.0212040025878015, 2.0378861445882595, 2.0542555943225467, 2.0703262158073708, 2.086110921524751, 2.101621759704152, 2.1168699916799865, 2.1318661606608504, 2.1466201530402165, 2.161141253207556, 2.175438192677122, 2.18951919423345, 2.2033920116936643, 2.2170639658035034, 2.2305419767137655, 2.2438325934244094, 2.256942020533017, 2.2698761425811997, 2.2826405462556636, 2.2952405406689786, 2.307681175917866, 2.3199672600932697, 2.332103374896132, 2.344093889995106, 2.355942976247054, 2.3676546178877644, 2.3792326237885835, 2.390680637864372, 2.402002148709159, 2.413200498527924, 2.4242788914258946, 2.4352404011105846, 2.446087978056263, 2.456824456175708, 2.467452559039734, 2.4779749056811515, 2.4883940160163553, 2.498712315914672, 2.508932141942846, 2.5190557458095677, 2.529085298532744, 2.539022894350206, 2.548870554392766, 2.5586302301369193, 2.568303806653012, 2.5778931056633962, 2.587399888423879, 2.5968258584407047, 2.6061726640343146, 2.615441900760242, 2.624635113696682, 2.6337537996075366, 2.642799408989072, 2.6517733480076813, 2.6606769803357135, 2.6695116288917946, 2.6782785774916005, 2.6869790724146108, 2.6956143238919745, 2.704185507520253, 2.712693765605471, 2.7211402084415983, 2.729525915527308, 2.737851936724577, 2.746119293362479, 2.754328979289272], [0.0, 0.696845301935949, 0.8579172004440949, 0.9688861611972633, 1.0562199684392581, 1.1293469354568555, 1.1928387845252126, 1.2492972627406829, 1.3003593134073366, 1.3471288257976293, 1.3903891703159093, 1.4307184640917885, 1.468556805589356, 1.5042477899911526, 1.5380653456302877, 1.570231748588672, 1.6009301040424733, 1.6303132298658147, 1.6585101279366483, 1.6856307944138171, 1.711769859409705, 1.7370093846199546, 1.7614210441360247, 1.7850678460144567, 1.8080055068809922, 1.8302835609029082, 1.8519462629340444, 1.8730333304094111, 1.8935805576321463, 1.9136203281353112, 1.9331820449317625, 1.952292494086943, 1.9709761537475865, 1.9892554582442339, 2.007151024951604, 2.0246818500908987, 2.0418654784851666, 2.058718151354561, 2.075254935504724, 2.091489836675339, 2.107435899344471, 2.1231052949029303, 2.138509399802548, 2.1536588650283996, 2.168563678036236, 2.1832332181239034, 2.197676306062341, 2.211901248692353, 2.225915879093377, 2.239727592846453, 2.2533433808426553, 2.26676985902818, 2.280013295426244, 2.293079634732363, 2.3059745207423687, 2.318703316840494, 2.3312711247473685, 2.3436828017039746, 2.3559429762470536, 2.368056062713588, 2.3800262745964402, 2.391857636859695, 2.403553997310353, 2.415119037112687, 2.426556280522392, 2.4378691039096707, 2.44906074413327, 2.4601343063212493, 2.4710927711086903, 2.4819390013776474, 2.4926757485402593, 2.5033056584020335, 2.5138312766388577, 2.52425505391817, 2.534579350691942, 2.5448064416866427, 2.554938520113106, 2.564977701617216, 2.574926027990515, 2.584785470658193, 2.594557933960465, 2.6042452582419853, 2.613849222762753, 2.623371548442868, 2.632813900452497, 2.6421778906575164, 2.6514650799304675, 2.6606769803357135, 2.669815057197016, 2.6788807310551066, 2.6878753795222865, 2.6968003390405313, 2.705656906549144, 2.7144463410675224, 2.7231698651982352, 2.7318286665552143, 2.740423899121549, 2.7489566845410347, 2.757428113347368, 2.765839246134594, 2.7741911146721807, 2.782484722967861], [0.0, 0.7037339582560234, 0.8663981311880077, 0.978464074342723, 1.0666612189445914, 1.1405110817643334, 1.2046305787857483, 1.2616471766465691, 1.3132140006353124, 1.3604458525093028, 1.4041338466721258, 1.4448618152237143, 1.4830742072165268, 1.51911801443938, 1.55326987314081, 1.5857542567104115, 1.616756080408492, 1.6464296727885344, 1.6749053109750902, 1.702294078492782, 1.728691540918895, 1.7541805711690326, 1.7788335518680707, 1.802714113937978, 1.825878524790568, 1.8483768082625651, 1.8702536566886647, 1.8915491801301296, 1.912299526734275, 1.9325374001612108, 1.952292494086943, 1.971591859370261, 1.9904602161363392, 2.0089202204900385, 2.026992693618902, 2.044696819531061, 2.062050316488712, 2.079069586264406, 2.095769844606521, 2.1121652357083214, 2.128268932998912, 2.144093228189249, 2.1596496101929485, 2.1749488352852784, 2.1900009896528694, 2.2048155453125107, 2.2194014102327726, 2.2337669733716385, 2.247920145242365, 2.261868394534924, 2.2756187812487645, 2.289177986731944, 2.3025523409701507, 2.3157478474251207, 2.3287702056843655, 2.341624832151792, 2.3543168789810305, 2.3668512514292646, 2.3792326237885835, 2.3914654540338462, 2.403553997310353, 2.415502318370924, 2.4273143030600126, 2.438993668931999, 2.4505439750815685, 2.4619686312559925, 2.473270906311949, 2.4844539360732045, 2.4955207306398752, 2.506474181195005, 2.517317066349784, 2.528052058064801, 2.5386817271811943, 2.5492085485924463, 2.55963490608475, 2.5699630968713567, 2.5801953358440617, 2.5903337595629425, 2.6003804300036477, 2.61033733807987, 2.620206406957157, 2.629989495172869, 2.639688399575861, 2.6493048580983665, 2.658840552371575, 2.6682971101954442, 2.6776761078725033, 2.6869790724146103, 2.696207483630968, 2.7053627761050487, 2.7144463410675224, 2.7234595281717477, 2.732403647177907, 2.7412799695514183, 2.7500897299808753, 2.758834127820354, 2.76751432846063, 2.776131464633496, 2.784686637653107, 2.7931809185979986, 2.8016153494371836, 2.809990944103502], [0.0, 0.710468771716361, 0.8746896591546225, 0.9878280860420743, 1.0768692872787824, 1.1514259016263246, 1.216159029475901, 1.2737212826177138, 1.3257816069359947, 1.3734654729667923, 1.4175715661678827, 1.4586893059783332, 1.497267394878231, 1.5336561454070003, 1.5681348412533194, 1.6009301040424735, 1.6322286186946955, 1.6621861907051552, 1.6909343439651996, 1.7185852250813276, 1.745235314204192, 1.7709682773525586, 1.7958571898611984, 1.8199662916071893, 1.8433523884878307, 1.8660659830736148, 1.888152195409927, 1.9096515194158465, 1.9306004491805413, 1.9510320013418414, 1.9709761537475865, 1.9904602161363392, 2.0095091452076637, 2.0281458138879045, 2.0463912426257194, 2.064264799022364, 2.0817843709058064, 2.098966517015413, 2.1158265987159917, 2.1323788955623346, 2.1486367070547505, 2.1646124425372575, 2.180317700873673, 2.1957633412780333, 2.210959546462915, 2.225915879093377, 2.2406413323882557, 2.25514437558881, 2.2694329949128007, 2.283514730526407, 2.2973967099940698, 2.311085678605102, 2.32458802692387, 2.3379098158659173, 2.35105679956445, 2.364034446258973, 2.3768479574098094, 2.3895022852180072, 2.402002148709159, 2.414352048521447, 2.426556280522392, 2.4386189483649576, 2.4505439750815685, 2.4623351138040195, 2.473995957687934, 2.4855299491122493, 2.496940388216972, 2.508230440836056, 2.5194031458766157, 2.5304614221906423, 2.5414080749809496, 2.552245801779091, 2.562977198029445, 2.573604762310503, 2.5841309012215627, 2.594557933960465, 2.6048880966157695, 2.6151235461946754, 2.625266364406171, 2.635318561217217, 2.645282078198274, 2.6551587916731143, 2.664950515686638, 2.674659004803289, 2.6842859567476545, 2.6938330148979235, 2.7033017706420175, 2.712693765605471, 2.7220104937594276, 2.7312534034164853, 2.740423899121549, 2.749523343444313, 2.758553058679511, 2.7675143284606305, 2.776408399292373, 2.7852364820067694, 2.7939997531475163, 2.802699356286777, 2.8113364032784083, 2.819911975451288, 2.82842712474619, 2.8368828747994064], [0.0, 0.7170578291176235, 0.8828017403633958, 0.9969894400953795, 1.0868564307395638, 1.162104500969668, 1.2274379793373025, 1.2855340785891718, 1.33807722281301, 1.3862033204279376, 1.4307184640917885, 1.4722175396605535, 1.5111534109884928, 1.54787963949735, 1.5826780990195632, 1.6157775129236005, 1.6473662974903178, 1.6776017031923312, 1.7066164737050284, 1.7345237957093738, 1.7614210441360247, 1.7873926609424253, 1.8125123991814882, 1.8368450945062844, 1.860448079645597, 1.8833723255428432, 1.9056633706975052, 1.927362084578959, 1.9485052997312875, 1.969126338996521, 1.9892554582442339, 2.0089202204900385, 2.0281458138879045, 2.046955323493166, 2.0653699647031547, 2.083409284738893, 2.101091337324347, 2.1184328347685932, 2.1354492809014145, 2.152155087709609, 2.168563678036236, 2.1846875763125375, 2.200538488972971, 2.216127375942522, 2.23146451437068, 2.246559555608948, 2.2614215762814265, 2.2760591241751436, 2.290480259573955, 2.3046925925733457, 2.318703316840494, 2.3325192402221413, 2.346146812550276, 2.359592150950823, 2.372861062922197, 2.3859590674176645, 2.3988914141371365, 2.411663101209558, 2.4242788914258946, 2.4367433271643235, 2.44906074413327, 2.461235284043956, 2.4732709063119485, 2.4851713988764845, 2.496940388216972, 2.508581348637795, 2.5200976108852475, 2.531492370153986, 2.542768693534676, 2.5539295269494406, 2.564977701617216, 2.575915940087109, 2.5867468618742686, 2.5974729887296037, 2.608096749571788, 2.618620485107458, 2.629046452163195, 2.6393768277507985, 2.6496137128855235, 2.6597591361752464, 2.6698150571970154, 2.67978336967608, 2.689665904481226, 2.699464432449148, 2.709180667049537, 2.7188162669016647, 2.728372838152365, 2.7378519367245766, 2.7472550704448895, 2.7565837010578984, 2.765839246134594, 2.775023080881468, 2.784136539856533, 2.793180918597999, 2.802157475170951, 2.8110674316369657, 2.819911975451288, 2.828692260791843, 2.837409409824086, 2.846064513905397, 2.854658634732502, 2.863192805435139], [0.0, 0.7235085623107059, 0.8907435244960378, 1.0059584696676387, 1.0966339139064574, 1.172558924272542, 1.2384801499883147, 1.297098888308631, 1.350114716590505, 1.39867376201345, 1.4435893689358648, 1.4854617748740688, 1.5247479176966876, 1.5618045395039353, 1.5969160498970725, 1.6303132298658147, 1.6621861907051552, 1.6926935975307154, 1.721969388194976, 1.7501277676190625, 1.7772669867295032, 1.8034722471331257, 1.8288179653736336, 1.8533695603729539, 1.8771848806315714, 1.9003153556332644, 1.9228069335469995, 1.9447008515085125, 1.9660342734116123, 1.9868408218743785, 2.007151024951604, 2.026992693618902, 2.0463912426257194, 2.0653699647031547, 2.0839502661046483, 2.102151869900231, 2.119992992227208, 2.1374904957404754, 2.1546600237440185, 2.171516117876497, 2.188072321734381, 2.2043412724201112, 2.22033478168055, 2.236063908037406, 2.2515390210945654, 2.2667698590281806, 2.2817655801166854, 2.2965348090439663, 2.3110856786051026, 2.3254258673568575, 2.3395626336814512, 2.353502846669783, 2.3672530141772583, 2.380819308360157, 2.3942075889618066, 2.4074234245845987, 2.420472112155338, 2.433358694766703, 2.446087978056263, 2.458664545265943, 2.47109277110869, 2.483376834555029, 2.4955207306398752, 2.5075282813791953, 2.5194031458766157, 2.531148829691755, 2.542768693534676, 2.5542659613443677, 2.5656437278033897, 2.576904965335713, 2.5880525306302387, 2.599089170728433, 2.6100175287108995, 2.620840149014503, 2.631559482408742, 2.642177890657517, 2.6526976508900733, 2.663120959702856, 2.6734499370120903, 2.683686629675238, 2.693833014897924, 2.7038910034415626, 2.713862442645644, 2.7237491192775076, 2.733552762221413, 2.7432750450177577, 2.7529175882624526, 2.7624819618756966, 2.771969687248656, 2.781382239275947, 2.790721048281188, 2.799987501842383, 2.8091829465233795, 2.8183086895171963, 2.8273660002066134, 2.8363561116470115, 2.845280221976117, 2.854139495754969, 2.8629350652441516, 2.871668031619018, 2.8803394661274373, 2.888950411193301], [0.0, 0.7298278187766998, 0.8985234417906398, 1.0147446954224053, 1.1062121156199922, 1.1828002689503483, 1.2492972627406829, 1.3084279878714606, 1.3619068661200142, 1.4108900351508282, 1.4561979432210856, 1.49843607043165, 1.5380653456302877, 1.5754456267681387, 1.6108638075320785, 1.6445526845953091, 1.676704029719738, 1.7074778938312045, 1.7370093846199548, 1.7654137044938394, 1.7927899625209973, 1.8192241044747146, 1.8447911968664354, 1.869557229998947, 1.8935805576321467, 1.9169130584443554, 1.939601081924274, 1.9616862253803442, 1.983205977302639, 2.0041942539753497, 2.0246818500908987, 2.044696819531061, 2.064264799022364, 2.083409284738893, 2.102151869900231, 2.1205124498413204, 2.138509399802548, 2.1561597297203323, 2.1734792195301433, 2.19048253787998, 2.2071833466585673, 2.2235943933431166, 2.239727592846453, 2.2555941002774427, 2.2712043758099933, 2.286568242675273, 2.3016949391418002, 2.3165931652230305, 2.3312711247473685, 2.3457365633374994, 2.3599968027716853, 2.3740587721367246, 2.3879290361288255, 2.401613820813013, 2.415119037112687, 2.428450302267434, 2.441612959468389, 2.4546120958555253, 2.467452559039734, 2.4801389722938145, 2.4926757485402593, 2.5050671032494884, 2.517317066349784, 2.5294294932393018, 2.54140807498095, 2.5532563477525474, 2.564977701617216, 2.5765753886724188, 2.588052530630239, 2.5994121258763454, 2.610657056050483, 2.621790092187282, 2.632813900452497, 2.64373104750657, 2.6545440055244716, 2.6652551568981795, 2.6758667986458047, 2.6863811465492677, 2.6968003390405313, 2.7071264408546853, 2.717361446466631, 2.7275072833267244, 2.7375658149094564, 2.7475388435881203, 2.7574281133473684, 2.7672353123446056, 2.7769620753303266, 2.7866099859366993, 2.796180578843001, 2.805675341825847, 2.815095717701565, 2.82444310616752, 2.8337188655486942, 2.8429243144553706, 2.852060733357351, 2.861129366079748, 2.870131421225042, 2.8790680735257634, 2.887940465131866, 2.8967497068365717, 2.9054968792442244, 2.9141830338834374], [0.0, 0.7360219228178334, 0.9061492783765587, 1.0233569106010076, 1.1156006217298275, 1.1928387845252129, 1.2599001433443433, 1.3195327154232157, 1.3734654729667926, 1.422864365867587, 1.468556805589356, 1.5111534109884928, 1.5511190228508474, 1.588816553269279, 1.6245353308191393, 1.6585101279366483, 1.6909343439651994, 1.721969388194976, 1.7517515149854368, 1.7803969044760037, 1.8080055068809922, 1.8346639974019838, 1.8604480796455973, 1.885424303979324, 1.9096515194158465, 1.9331820449317627, 1.9560626233873986, 1.9783352051307068, 2.0000375968194186, 2.0212040025878015, 2.0418654784851666, 2.062050316488712, 2.0817843709058064, 2.101091337324347, 2.119992992227208, 2.138509399802548, 2.1566590912428136, 2.1744592208490428, 2.1919257024822145, 2.2090733292842555, 2.225915879093377, 2.242466207575595, 2.2587363307665043, 2.274737498449225, 2.290480259573955, 2.305974520742369, 2.3212295986288716, 2.336254267084593, 2.3510567995644505, 2.3656450074288164, 2.3800262745964407, 2.3942075889618066, 2.4081955709361966, 2.4219964994257226, 2.4356163355202387, 2.44906074413327, 2.4623351138040195, 2.4754445748474043, 2.4883940160163553, 2.5011880998217397, 2.5138312766388577, 2.5263277977151457, 2.538681727181194, 2.5508969531562142, 2.562977198029445, 2.574926027990515, 2.5867468618742686, 2.5984429793789663, 2.6100175287109, 2.621473533703263, 2.632813900452497, 2.644041423511212, 2.6551587916731143, 2.6661685933820873, 2.6770733217946385, 2.6878753795222865, 2.6985770830781095, 2.709180667049537, 2.719688288017566, 2.7301020282408497, 2.740423899121549, 2.750655844468438, 2.760799743571455, 2.770857414100774, 2.7808306148423765, 2.790721048281188, 2.8005303630419536, 2.810260156197248, 2.8199119754512885, 2.8294873212075617, 2.8389876485276884, 2.8484143689883705, 2.857768852442798, 2.8670524286923986, 2.8762663890744187, 2.8854119879704094, 2.8944904442403514, 2.9035029425868197, 2.9124506348532804, 2.921334641260343, 2.930156051583521, 2.938915926275832], [0.0, 0.7420967288325538, 0.9136282418637358, 1.0318032550956446, 1.1248083058446763, 1.2026839589665983, 1.2702988131821025, 1.3304235666706687, 1.3848014618246332, 1.434608071781688, 1.480677637101274, 1.523625816423229, 1.563921287127823, 1.6019299566270706, 1.6379435414890113, 1.6721987518598218, 1.7048905833172703, 1.7361817773538792, 1.766209712913548, 1.7950915290362253, 1.8229280008819848, 1.8498065190319637, 1.8758034119175455, 1.9009857791841167, 1.9254129555586101, 1.9491376918357852, 1.972207116671282, 1.9946635266530477, 2.0165450404785834, 2.0378861445882595, 2.058718151354561, 2.079069586264406, 2.098966517015413, 2.1184328347685932, 2.1374904957404754, 2.1561597297203323, 2.1744592208490428, 2.192406265011812, 2.2100169074157323, 2.2273060632989132, 2.2442876242158722, 2.2609745519377222, 2.277378961675209, 2.293512196062287, 2.3093848911156187, 2.3250070352016765, 2.3403880218906576, 2.355536697449258, 2.3704614036179064, 2.3851700162285594, 2.399669980143632, 2.413968340932661, 2.4280717736489343, 2.4419866090219347, 2.455718857341768, 2.4692742302777018, 2.4826581608436062, 2.4958758216977945, 2.508932141942846, 2.521831822571972, 2.534579350691942, 2.5471790126381473, 2.55963490608475, 2.5719509512418126, 2.5841309012215627, 2.5961783516474126, 2.608096749571788, 2.619889401762157, 2.631559482408742, 2.6431100403021466, 2.6545440055244716, 2.6658641956933544, 2.6770733217946385, 2.6881739936361027, 2.6991687249516865, 2.710059938183024, 2.7208499689626877, 2.7315410703214247, 2.7421354166397154, 2.752635107362275, 2.763042170492506, 2.773358565882537, 2.783586188333152, 2.7937268705167866, 2.8037823857356794, 2.813754450526329, 2.823644727120515, 2.8334548257723573, 2.843186306960152, 2.8528406834710673, 2.8624194223761714, 2.8719239469027085, 2.881355638210043, 2.8907158370752084, 2.9000058454935886, 2.909226928199856, 2.918380314113934, 2.927467197716419, 2.936488740357594, 2.945446071503884, 2.9543402899253386, 2.9631724648274926], [0.0, 0.7480576678834732, 0.9209670186745648, 1.0400912801969562, 1.1338433999161135, 1.2123445941619542, 1.2805025689832445, 1.3411102783683562, 1.395924967414729, 1.4461316521258578, 1.4925712741513997, 1.5358644374482726, 1.5764835840775346, 1.6147975606257003, 1.6511004268926472, 1.6856307944138174, 1.7185852250813276, 1.7501277676190627, 1.7803969044760037, 1.8095107156188694, 1.8375707856905992, 1.864665207242717, 1.8908709218195734, 1.9162555680487134, 1.9408789572670275, 1.964794263993381, 1.9880489954473297, 2.010685787966847, 2.032743066440289, 2.0542555943225467, 2.075254935504724, 2.095769844606521, 2.1158265987159917, 2.1354492809014145, 2.1546600237440185, 2.1734792195301433, 2.1919257024822145, 2.2100169074157323, 2.227769008421933, 2.245197040546522, 2.2623150069288096, 2.279135973456158, 2.2956721526555115, 2.311934978271252, 2.3279351717545196, 2.3436828017039746, 2.359187337144262, 2.3744576954002774, 2.3895022852180077, 2.4043290456925295, 2.4189454814875875, 2.433358694766703, 2.447575414200953, 2.4616020213718057, 2.475444574847404, 2.4891088321763615, 2.502600270013576, 2.5159241025670673, 2.529085298532744, 2.542088596664844, 2.554938520113106, 2.5676393896431815, 2.5801953358440617, 2.592610310415145, 2.6048880966157695, 2.617032318951422, 2.629046452163195, 2.640933829580377, 2.6526976508900733, 2.664340989372492, 2.6758667986458047, 2.6872779189603406, 2.6985770830781095, 2.709766921770336, 2.7208499689626877, 2.7318286665552147, 2.742705368941606, 2.753482347250221, 2.7641617933273896, 2.7747458234817497, 2.7852364820067694, 2.7956357444972144, 2.8059455209739763, 2.816167658830548, 2.826303945613331, 2.8363561116470115, 2.8463258325153524, 2.856214731406941, 2.8660243813347153, 2.8757563072374013, 2.8854119879704094, 2.894992858193147, 2.904500310159228, 2.9139356954155633, 2.9233003264158963, 2.932595478053962, 2.9418223891210604, 2.9509822636925294, 2.960076272447272, 2.969105553924223, 2.9780712157193716, 2.9869743356267167], [0.0, 0.753909788555604, 0.9281718243462789, 1.0482280054028688, 1.1427135561680801, 1.221828872133885, 1.2905200527634264, 1.3516019015688139, 1.406845410729834, 1.457444866733995, 1.5042477899911526, 1.54787963949735, 1.588816553269279, 1.6274302634126145, 1.6640171301828106, 1.6988176317942558, 1.732029867859969, 1.7638191704713746, 1.7943251054377842, 1.8236666764758405, 1.8519462629340444, 1.8792526465196686, 1.9056633706975055, 1.9312466032380091, 1.9560626233873986, 1.9801650216534585, 2.003601676908886, 2.0264155590394606, 2.0486453935348075, 2.0703262158073708, 2.091489836675339, 2.1121652357083214, 2.1323788955623346, 2.152155087709609, 2.171516117876497, 2.19048253787998, 2.2090733292842555, 2.2273060632989132, 2.245197040546522, 2.2627614136932666, 2.280013295426244, 2.2969658538483975, 2.3136313970263385, 2.3300214481516344, 2.346146812550276, 2.362017637588453, 2.3776434663678208, 2.3930332859742873, 2.4081955709361966, 2.4231383224568623, 2.4378691039096707, 2.4523950730189896, 2.466723011094881, 2.4808593496424822, 2.494810194626647, 2.508581348637795, 2.522178331175176, 2.535606397238016, 2.548870554392766, 2.5619755784653537, 2.574926027990515, 2.5877262575356297, 2.600380430003648, 2.612892528008459, 2.625266364406171, 2.6375055920570936, 2.6496137128855235, 2.661594086297676, 2.6734499370120903, 2.6851843623515137, 2.6968003390405313, 2.708300729549, 2.719688288017566, 2.730965665798208, 2.7421354166397154, 2.753200001545337, 2.7641617933273896, 2.7750230808814687, 2.78578607320091, 2.7964529031504197, 2.8070256310161525, 2.817506247848125, 2.8278966786094895, 2.8381987851460604, 2.848414368988371, 2.858545173997589, 2.868592888865716, 2.878559149479686, 2.888445541158255, 2.8982536007698783, 2.9079848187391812, 2.9176406409490374, 2.927222470544784, 2.9367316696466, 2.946169560975671, 2.9555374293993366, 2.9648365234000695, 2.9740680564727944, 2.9832332084547386, 2.9923331267917264, 3.001368927744568, 3.0103416975389377], [0.0, 0.7596577929323739, 0.9352484478226214, 1.0562199684392581, 1.1514259016263246, 1.2311444133449163, 1.3003593134073363, 1.361906866120014, 1.4175715661678827, 1.468556805589356, 1.515716566510398, 1.5596810765891669, 1.6009301040424733, 1.639838215158281, 1.676704029719738, 1.711769859409705, 1.745235314204192, 1.7772669867295032, 1.8080055068809922, 1.8375707856905992, 1.8660659830736148, 1.8935805576321465, 1.9201926440425372, 1.9459709298040588, 1.9709761537475867, 1.9952623149688795, 2.0188776573816165, 2.041865478485167, 2.064264799022364, 2.086110921524751, 2.107435899344471, 2.128268932998912, 2.1486367070547505, 2.168563678036236, 2.188072321734381, 2.2071833466585673, 2.225915879093377, 2.2442876242158722, 2.2623150069288096, 2.280013295426244, 2.2973967099940698, 2.314478519132273, 2.331271124747368, 2.3477861378867324, 2.364034446258973, 2.3800262745964407, 2.3957712387598793, 2.4112783943550786, 2.426556280522392, 2.4416129594683884, 2.4564560522315806, 2.47109277110869, 2.4855299491122493, 2.499774066782866, 2.5138312766388573, 2.5277074255111027, 2.54140807498095, 2.554938520113106, 2.5683038066530117, 2.5815087468387348, 2.594557933960465, 2.6074557557859372, 2.620206406957157, 2.632813900452497, 2.645282078198274, 2.6576146209051537, 2.6698150571970154, 2.6818867720930615, 2.6938330148979235, 2.705656906549144, 2.7173614464666307, 2.7289495189444555, 2.740423899121549, 2.7517872585644874, 2.763042170492506, 2.774191114672181, 2.7852364820067694, 2.7961805788430008, 2.8070256310161525, 2.8177737876524445, 2.82842712474619, 2.8389876485276884, 2.849457298636513, 2.8598379511136733, 2.8701314212250417, 2.8803394661274373, 2.890463787387888, 2.900506033365755, 2.9104678014666776, 2.920350640276596, 2.930156051583521, 2.9398854922941138, 2.949540376251655, 2.9591220759614836, 2.968631924229555, 2.9780712157193716, 2.9874412084321627, 2.996743125114852, 3.0059781546000544, 3.0151474530820184, 3.0242521453322184, 3.033293325857995], [0.0, 0.7653060683794355, 0.9422022905843045, 1.0640732694518138, 1.1599870862936499, 1.2402983282081343, 1.3100278610752603, 1.3720330376470597, 1.4281116208426743, 1.4794759502684445, 1.526986357654484, 1.5712777565839042, 1.6128334824889967, 1.6520308866664326, 1.689170809223833, 1.7244973635015173, 1.7582116436334116, 1.790481480910189, 1.8214485508511566, 1.851233656061466, 1.8799407234802203, 1.9076598768601123, 1.9344698318314069, 1.9604397866048031, 1.9856309316219545, 2.010097667477518, 2.033888596792627, 2.057047338996084, 2.079613204961233, 2.101621759704152, 2.1231052949029303, 2.144093228189249, 2.1646124425372575, 2.1846875763125375, 2.2043412724201112, 2.2235943933431166, 2.242466207575595, 2.2609745519377222, 2.279135973456158, 2.2969658538483975, 2.314478519132273, 2.331687336462908, 2.348604799958578, 2.3652426069981574, 2.3816117262435164, 2.397722458450848, 2.413584490977603, 2.42920694676062, 2.4445984284312305, 2.459767058140842, 2.4747205135925934, 2.489466060708718, 2.504010583307174, 2.5183606101132625, 2.532522339391055, 2.546501661444309, 2.5603041792063386, 2.573935227112189, 2.587399888423879, 2.6007030111598564, 2.6138492227627537, 2.6268429436246277, 2.639688399575861, 2.6523896334324815, 2.6649505156866384, 2.6773747544161473, 2.6896659044812266, 2.7018273760696747, 2.7138624426456444, 2.7257742483517506, 2.7375658149094564, 2.749240048058394, 2.760799743571455, 2.7722475928790864, 2.783586188333152, 2.794818028138011, 2.8059455209739763, 2.816970990336134, 2.82789667860949, 2.838724750899639, 2.849457298636513, 2.8600963429673145, 2.8706438379533967, 2.881101673584679, 2.891471678624058, 2.9017556232933237, 2.9119552218111466, 2.9220721347929173, 2.932107971521447, 2.942064292096862, 2.951942609473399, 2.9617443913902433, 2.9714710622030096, 2.98112400462201, 2.990704561362999, 3.000214036715675, 3.009653698034872, 3.01902477715899, 3.028328471759958, 3.037565946628664, 3.046738334899583, 3.0558467392180346], [0.0, 0.7708587157144184, 0.9490384013300432, 1.0717936101729575, 1.1684033258472732, 1.2492972627406829, 1.3195327154232157, 1.3819877680546362, 1.4384732271504903, 1.4902102283982714, 1.5380653456302877, 1.5826780990195632, 1.6245353308191393, 1.6640171301828108, 1.701426519951475, 1.7370093846199548, 1.7709682773525588, 1.8034722471331257, 1.8346639974019838, 1.864665207242717, 1.8935805576321465, 1.9215008262122208, 1.9485052997312877, 1.9746636784648746, 2.0000375968194186, 2.024681850090899, 2.048645393534808, 2.0719721630589545, 2.094701754755141, 2.1168699916799865, 2.138509399802548, 2.1596496101929485, 2.180317700873673, 2.200538488972971, 2.22033478168055, 2.239727592846453, 2.2587363307665043, 2.277378961675209, 2.2956721526555115, 2.3136313970263385, 2.331271124747368, 2.348604799958578, 2.3656450074288164, 2.3824035294068175, 2.398891414137136, 2.415119037112687, 2.4310961559771522, 2.446831959858471, 2.4623351138040195, 2.4776137988951477, 2.4926757485402593, 2.5075282813791953, 2.522178331175176, 2.5366324740224067, 2.550896953156214, 2.564977701617216, 2.5788803629905854, 2.5926103104151443, 2.6061726640343146, 2.619572307041147, 2.632813900452497, 2.6459018967323984, 2.658840552371575, 2.671633939518544, 2.684285956747655, 2.6968003390405313, 2.7091806670495373, 2.7214303757049514, 2.7335527622214135, 2.7455509935537386, 2.757428113347368, 2.7691870484244108, 2.780830614842377, 2.7923615235592765, 2.8037823857356794, 2.815095717701565, 2.826303945613331, 2.837409409824086, 2.8484143689883705, 2.8593210039206167, 2.870131421225042, 2.8808476567132, 2.891471678624058, 2.9020053906602805, 2.9124506348532804, 2.92280919426862, 2.9330827955624144, 2.943273111398582, 2.9533817627360213, 2.963410320994101, 2.973360310104238, 2.9832332084547386, 2.9930304507355725, 3.002753429689251, 3.012403497773549, 3.021981968741386, 3.031490119142837, 3.0409291897538577, 3.050300386936036, 3.059604883931354, 3.0688438220956975, 3.0780183120745854], [0.0, 0.7763195742492645, 0.9557615068072859, 1.0793863287404348, 1.1766804395959092, 1.2581474391487872, 1.3288804484696655, 1.3917779404226553, 1.4486635495007438, 1.5007670620677482, 1.5489611908722423, 1.5938899865272955, 1.6360437401367154, 1.6758052334528986, 1.7134796359680458, 1.7493145740531681, 1.7835140357842572, 1.816248267709072, 1.8476609841967717, 1.8778747263206257, 1.9069949166304496, 1.9351129758482406, 1.9623087523994838, 1.9886524403250836, 2.0142061106572395, 2.039024946868588, 2.063158251019709, 2.0866502702658214, 2.1095408812023404, 2.1318661606608504, 2.1536588650283996, 2.1749488352852784, 2.1957633412780333, 2.216127375942522, 2.236063908037406, 2.2555941002774427, 2.274737498449225, 2.293512196062287, 2.311934978271252, 2.3300214481516344, 2.3477861378867324, 2.3652426069981574, 2.3824035294068175, 2.399280770828355, 2.415885457774457, 2.432228039239313, 2.448318341990961, 2.464165620254259, 2.4797786004608526, 2.4951655216478827, 2.5103341720081764, 2.525291922027724, 2.5400457545893835, 2.554602292373225, 2.5689678228424255, 2.5831483210679993, 2.597149470614973, 2.6109766826861502, 2.6246351136966815, 2.638129681432762, 2.6514650799304675, 2.6646457931956373, 2.6776761078725033, 2.690560124957186, 2.7033017706420175, 2.715904806367695, 2.728372838152365, 2.7407093252597794, 2.752917588262453, 2.7650008165503013, 2.776962075330326, 2.7888043121586072, 2.8005303630419536, 2.8121429581431383, 2.823644727120515, 2.835038204130057, 2.8463258325153524, 2.857509969208863, 2.868592888865716, 2.8795767877495035, 2.890463787387888, 2.9012559380143634, 2.9119552218111466, 2.922563555966966, 2.9330827955624144, 2.9435147362945098, 2.9538611170512135, 2.9641236223458027, 2.9743038846202485, 2.9844034864260487, 2.9944239624903397, 3.004366801674513, 3.01423344883206, 3.024025306571852, 3.0337437369326414, 3.043390062974138, 3.0529655702896537, 3.062471508444955, 3.071909092347645, 3.0812795035510967, 3.0905838914967028, 3.0998233746979316], [0.0, 0.7816922441165305, 0.962376039299117, 1.0868564307395638, 1.1848238843201153, 1.2668546920110242, 1.33807722281301, 1.4014100090326287, 1.4586893059783335, 1.5111534109884928, 1.5596810765891669, 1.6049208106703468, 1.647366297490318, 1.6874029679166802, 1.7253381034261694, 1.7614210441360247, 1.7958571898611981, 1.8288179653736338, 1.8604480796455973, 1.8908709218195734, 1.9201926440425374, 1.9485052997312875, 1.9758892899177916, 2.0024152944344, 2.0281458138879045, 2.0531364136588444, 2.0774367370122517, 2.101091337324347, 2.124140367164242, 2.1466201530402165, 2.168563678036236, 2.1900009896528694, 2.210959546462915, 2.23146451437068, 2.2515390210945654, 2.2712043758099933, 2.290480259573955, 2.3093848911156187, 2.3279351717545196, 2.346146812550276, 2.364034446258973, 2.3816117262435164, 2.398891414137136, 2.415885457774457, 2.4326050606703427, 2.44906074413327, 2.4652624029393273, 2.4812193553590265, 2.496940388216972, 2.5124337975701567, 2.5277074255111027, 2.5427686935346756, 2.557624632850126, 2.5722819119710625, 2.5867468618742686, 2.6010254989823935, 2.615123546194676, 2.629046452163195, 2.642799408989072, 2.6563873684929917, 2.6698150571970154, 2.683086990139414, 2.696207483630968, 2.7091806670495373, 2.7220104937594276, 2.7347007512331136, 2.7472550704448895, 2.75967693459901, 2.771969687248656, 2.784136539856533, 2.7961805788430008, 2.8081047721632717, 2.819911975451288, 2.831604937764444, 2.8431863069601517, 2.854658634732502, 2.866024381334715, 2.8772859200108596, 2.8884455411582546, 2.899505456240159, 2.9104678014666776, 2.921334641260343, 2.932107971521447, 2.942789722706994, 2.9533817627360213, 2.963885899733015, 2.974303884620248, 2.984637413568997, 2.9948881303188637, 3.0050576283737005, 3.015147453082019, 3.0251591036091643, 3.035094034808017, 3.0449536589944737, 3.0547393476335403, 3.0644524329414162, 3.0740942094086114, 3.0836659352487543, 3.0931688337774506, 3.102604094725243, 3.1119728754884552, 3.121276302321445], [0.0, 0.7869801062288712, 0.9688861611972635, 1.0942086169546863, 1.1928387845252129, 1.275424500625791, 1.3471288257976295, 1.4108900351508282, 1.4685568055893563, 1.5213758110801447, 1.570231748588672, 1.6157775129236005, 1.6585101279366483, 1.6988176317942558, 1.7370093846199548, 1.7733364132256764, 1.8080055068809922, 1.8411892499837261, 1.8730333304094113, 1.9036619719829493, 1.933182044931763, 1.9616862253803442, 1.989255458244234, 2.0159609014789965, 2.041865478485167, 2.0670251305227603, 2.091489836675339, 2.1153044517064163, 2.138509399802548, 2.161141253207556, 2.1832332181239034, 2.2048155453125107, 2.225915879093377, 2.246559555608948, 2.2667698590281806, 2.286568242675273, 2.305974520742369, 2.3250070352016765, 2.3436828017039746, 2.362017637588453, 2.3800262745964407, 2.397722458450848, 2.415119037112687, 2.432228039239313, 2.44906074413327, 2.4656277442758388, 2.481939001377648, 2.498003896743901, 2.5138312766388577, 2.5294294932393018, 2.5448064416866427, 2.559969593679444, 2.5749260279905153, 2.5896824582435203, 2.6042452582419857, 2.618620485107458, 2.6328139004524975, 2.646830989787321, 2.6606769803357135, 2.6743568574156176, 2.6878753795222865, 2.701237092236573, 2.7144463410675224, 2.727507283326725, 2.7404238991215495, 2.753200001545337, 2.7658392461345946, 2.77834513965618, 2.790721048281188, 2.802970205196695, 2.815095717701565, 2.8271005738281425, 2.838987648527689, 2.850759709453965, 2.8624194223761714, 2.873969356249675, 2.8854119879704094, 2.8967497068365717, 2.9079848187391812, 2.919119550101236, 2.9301560515835217, 2.941096401573634, 2.951942609473399, 2.962696618798659, 2.9733603101042383, 2.9839355037459248, 2.9944239624903397, 3.004827393982738, 3.0151474530820193, 3.0253857440715057, 3.035543822753427, 3.045623198434433, 3.055625335808952, 3.065551656746681, 3.0754035419900854, 3.0851823327673196, 3.0948893323256486, 3.1045258073900555, 3.114092989551429, 3.1235920765884035, 3.1330242337266654, 3.1423905948392714], [0.0, 0.7921863401692985, 0.9752957870275872, 1.1014473082435876, 1.2007299595578471, 1.2838620180052702, 1.3560407001378887, 1.4202237191017624, 1.478271981645511, 1.5314404090554932, 1.5806195509729186, 1.6264666214047183, 1.6694819322430905, 1.7100560887047174, 1.7485004974720744, 1.7850678460144567, 1.8199662916071893, 1.8533695603729539, 1.885424303979324, 1.9162555680487132, 1.9459709298040588, 1.9746636784648746, 2.0024152944344, 2.0292974064106755, 2.055373354061357, 2.0806994487235233, 2.105326000115271, 2.1292981597349243, 2.1526566191935514, 2.175438192677122, 2.197676306062341, 2.2194014102327726, 2.2406413323882557, 2.2614215762814265, 2.2817655801166854, 2.3016949391418002, 2.3212295986288716, 2.3403880218906576, 2.359187337144262, 2.3776434663678208, 2.3957712387598793, 2.413584490977603, 2.4310961559771522, 2.448318341990961, 2.4652624029393273, 2.481939001377648, 2.498358164917831, 2.5145293369267123, 2.5304614221906423, 2.54616282813988, 2.5616415021458128, 2.5769049653357126, 2.591960343311715, 2.6068143941111797, 2.621473533703263, 2.6359438592801467, 2.6502311705700956, 2.664340989372492, 2.6782785774916, 2.692048953225524, 2.705656906549144, 2.719107013114412, 2.7324036471779065, 2.7455509935537386, 2.758553058679511, 2.771413680873924, 2.784136539856533, 2.796725165593065, 2.8091829465233795, 2.8215131372235653, 2.8337188655486942, 2.8458031392983107, 2.8577688524427978, 2.8696187909452138, 2.881355638210043, 2.892981980187469, 2.904500310159228, 2.9159130332298178, 2.927222470544784, 2.9384308632559324, 2.949540376251655, 2.9605531016690336, 2.971471062203009, 2.98229621422667, 2.993030450735572, 3.0036756041279924, 3.0142334488320595, 3.024705703789885, 3.035094034808017, 3.0454000567828476, 3.0556253358089513, 3.065771391177733, 3.0758396972732447, 3.085831685371504, 3.095748745349219, 3.1055922273073837, 3.1153634431148407, 3.125063667876539, 3.1346941413309053, 3.1442560691804284, 3.1537506243592963, 3.1631789482416557], [0.0, 0.7973139402667752, 0.9816086032414625, 1.1085766678888298, 1.208501947972033, 1.292172096928448, 1.3648179714358555, 1.4294164290883402, 1.487840421762217, 1.5413529934975254, 1.5908504582136445, 1.6369942838795284, 1.680288020765995, 1.7211248023677916, 1.7598180510155497, 1.7966220897537137, 1.8317464232012972, 1.8653659019614715, 1.8976281269369415, 1.9286589531353797, 1.9585666540969286, 1.987445122876067, 2.0153763672758434, 2.0424324796267785, 2.0686772095764416, 2.094167232949409, 2.1189531851044796, 2.1430805097929677, 2.1665901620113326, 2.18951919423345, 2.211901248692353, 2.2337669733716385, 2.25514437558881, 2.2760591241751436, 2.2965348090439663, 2.3165931652230305, 2.336254267084593, 2.355536697449258, 2.3744576954002774, 2.3930332859742873, 2.4112783943550786, 2.42920694676062, 2.446831959858471, 2.464165620254259, 2.4812193553590265, 2.498003896743901, 2.5145293369267123, 2.5308051803985627, 2.5468403895839864, 2.562643426332183, 2.578222289455647, 2.593584548763798, 2.608737375980797, 2.6236875728868845, 2.638441596979987, 2.653005584917702, 2.6673853739683095, 2.681586521672251, 2.6956143238919745, 2.709473831407621, 2.7231698651982352, 2.7367070305326813, 2.7500897299808753, 2.763322175444056, 2.776408399292373, 2.7893522646888886, 2.802157475170951, 2.814827583552766, 2.8273660002066134, 2.839776000774542, 2.8520607333573507, 2.8642232252232294, 2.8762663890744187, 2.8881930289067355, 2.900005845493588, 2.9117074415232924, 2.9233003264158963, 2.9347869208434663, 2.946169560975671, 2.9574505024706648, 2.968631924229555, 2.9797159319312403, 2.9907045613629983, 3.0015997815609725, 3.0124034977735485, 3.023117554259603, 3.0337437369326414, 3.0442837758610044, 3.0547393476335403, 3.065112077599412, 3.075403541990085, 3.0856152699309116, 3.095748745349219, 3.105805408785273, 3.1157866591120635, 3.1256938551694105, 3.135528317317515, 3.1452913289147233, 3.154984137723942, 3.1646079572518326, 3.174163968024659, 3.1836533188043616], [0.0, 0.8023657300756686, 0.9878280860420744, 1.1156006217298275, 1.216159029475901, 1.3003593134073366, 1.3734654729667926, 1.4384732271504903, 1.4972673948782311, 1.5511190228508476, 1.6009301040424735, 1.6473662974903183, 1.6909343439651996, 1.7320298678599695, 1.7709682773525588, 1.8080055068809922, 1.8433523884878307, 1.8771848806315716, 1.9096515194158465, 1.9408789572670275, 1.970976153747587, 2.0000375968194186, 2.0281458138879045, 2.055373354061357, 2.081784370905807, 2.1074358993444715, 2.1323788955623346, 2.156659091242814, 2.180317700873673, 2.2033920116936643, 2.225915879093377, 2.247920145242365, 2.2694329949128007, 2.290480259573955, 2.3110856786051026, 2.3312711247473685, 2.3510567995644505, 2.3704614036179064, 2.3895022852180077, 2.4081955709361966, 2.426556280522392, 2.4445984284312305, 2.4623351138040195, 2.4797786004608526, 2.496940388216972, 2.5138312766388577, 2.5304614221906423, 2.5468403895839864, 2.562977198029445, 2.5788803629905854, 2.594557933960465, 2.6100175287109, 2.6252663644061713, 2.640311285922675, 2.6551587916731143, 2.669815057197016, 2.684285956747655, 2.69857708307811, 2.7126937656054713, 2.7266410871116773, 2.7404238991215495, 2.754046836082985, 2.7675143284606305, 2.780830614842377, 2.7939997531475167, 2.807025631016153, 2.8199119754512885, 2.8326623617777975, 2.845280221976117, 2.857768852442798, 2.870131421225042, 2.882370974771842, 2.894490444240352, 2.906492651392536, 2.918380314113934, 2.9301560515835217, 2.941822389121061, 2.9533817627360213, 2.9648365234000695, 2.976188941063234, 2.9874412084321627, 2.9985954445273593, 3.009653698034872, 3.0206179504666775, 3.031490119142837, 3.042272060007472, 3.0529655702896537, 3.063572391019456, 3.074094209408612, 3.0845326611045145, 3.0948893323256486, 3.105165761885922, 3.115363443114841, 3.1254838256799506, 3.1355283173175152, 3.1454982854769784, 3.1553950588843582, 3.1652199290293734, 3.174974151580769, 3.1846589477339995, 3.194275505495155, 3.203824980904744], [0.0, 0.8073443754472973, 0.9939575174773806, 1.1225228763373836, 1.223705244744459, 1.3084279878714606, 1.3819877680546362, 1.447398892599698, 1.5065578756480142, 1.5607436506913628, 1.6108638075320785, 1.6575881355935032, 1.701426519951475, 1.7427770398314475, 1.7819570605057364, 1.8192241044747146, 1.8547903119848377, 1.888832733309385, 1.9215008262122208, 1.9529220289926579, 1.983205977302639, 2.0124477453978598, 2.040730372762757, 2.0681268586697876, 2.0947017547551416, 2.1205124498413204, 2.145610216294277, 2.1700410695605874, 2.193846479862166, 2.2170639658035034, 2.239727592846453, 2.261868394534924, 2.283514730526407, 2.3046925925733457, 2.3254258673568575, 2.3457365633374994, 2.3656450074288164, 2.3851700162285594, 2.4043290456925295, 2.4231383224568623, 2.4416129594683884, 2.459767058140842, 2.4776137988951477, 2.4951655216478827, 2.5124337975701567, 2.5294294932393018, 2.54616282813988, 2.562643426332183, 2.5788803629905854, 2.594882206416745, 2.610657056050483, 2.626212576931567, 2.641556031006477, 2.656694305623776, 2.6716339395185438, 2.6863811465492677, 2.700941837418717, 2.715321639582764, 2.729525915527308, 2.743559779572734, 2.757428113347368, 2.771135580055662, 2.784686637653107, 2.798085551027853, 2.8113364032784087, 2.82444310616752, 2.837409409824086, 2.85023891175772, 2.8629350652441516, 2.8755011871339335, 2.887940465131866, 2.900255964590028, 2.9124506348532804, 2.9245273151925013, 2.936488740357594, 2.9483375457794296, 2.960076272447272, 2.971707371485926, 2.9832332084547386, 2.9946560673886813, 3.0059781546000544, 3.0172016022577934, 3.0283284717599575, 3.0393607569137213, 3.0503003869360357, 3.061149229287076, 3.0719090923476444, 3.0825817279508327, 3.093168833777451, 3.103672055624015, 3.114092989551429, 3.124433183921875, 3.1346941413309057, 3.1448773204411915, 3.154984137723942, 3.1650159691135653, 3.174974151580769, 3.1848599846289103, 3.1946747317181057, 3.2044196216212764, 3.2140958497160383, 3.2237045792160846], [0.0, 0.8122523963562356, 1.0, 1.1293469354568555, 1.2311444133449163, 1.3163822043342375, 1.3903891703159093, 1.4561979432210856, 1.5157165665103982, 1.570231748588672, 1.6206565966927624, 1.6676649720406433, 1.711769859409705, 1.7533717580350285, 1.792789962520997, 1.8302835609029082, 1.8660659830736148, 1.9003153556332646, 1.9331820449317627, 1.9647942639933809, 1.9952623149688795, 2.0246818500908987, 2.0531364136588444, 2.0806994487235233, 2.1074358993444715, 2.1334035032232417, 2.1586538444215795, 2.1832332181239034, 2.2071833466585673, 2.2305419767137655, 2.2533433808426553, 2.2756187812487645, 2.2973967099940698, 2.318703316840494, 2.3395626336814512, 2.3599968027716853, 2.3800262745964407, 2.399669980143632, 2.4189454814875875, 2.4378691039096707, 2.4564560522315806, 2.4747205135925934, 2.4926757485402593, 2.5103341720081764, 2.5277074255111027, 2.5448064416866427, 2.5616415021458128, 2.578222289455647, 2.594557933960465, 2.610657056050483, 2.626527804403767, 2.6421778906575164, 2.657614620905154, 2.6728449243649233, 2.6878753795222865, 2.7027122380111197, 2.717361446466631, 2.7318286665552147, 2.746119293362479, 2.7602384722998674, 2.774191114672181, 2.7879819120324973, 2.8016153494371836, 2.8150957177015656, 2.8284271247461903, 2.841613506114255, 2.854658634732502, 2.8675661299805832, 2.8803394661274377, 2.892981980187469, 2.9054968792442244, 2.91788724728472, 2.9301560515835217, 2.942306148672048, 2.9543402899253386, 2.9662611267956174, 2.978071215719372, 2.989773022722325, 3.001368927744568, 3.012861228706216, 3.0242521453322184, 3.0355438227534264, 3.046738334899583, 3.0578376876986475, 3.068843822095698, 3.079758616903603, 3.0905838914967028, 3.101321408357861, 3.1119728754884557, 3.1225399486901564, 3.1330242337266654, 3.1434272883729935, 3.1537506243592968, 3.163995709215771, 3.174163968024659, 3.1842567850849735, 3.194275505495155, 3.2042214366585218, 3.214095849716039, 3.2238999809106015, 3.2336350328867867, 3.2433021759297134], [0.0, 0.8170921776223911, 1.0059584696676387, 1.136076114916016, 1.2384801499883147, 1.3242258277697823, 1.39867376201345, 1.4648746544958464, 1.5247479176966878, 1.579587926833801, 1.6303132298658147, 1.677601703192331, 1.7219693881949758, 1.7638191704713746, 1.8034722471331257, 1.841189249983726, 1.8771848806315712, 1.9116383270387534, 1.9447008515085125, 1.9765014310185358, 2.0071510249516042, 2.036745855481284, 2.0653699647031547, 2.093097233276215, 2.1199929922272083, 2.1461153232860317, 2.1715161178764975, 2.196241947031476, 2.22033478168055, 2.2438325934244094, 2.26676985902818, 2.289177986731944, 2.311085678605102, 2.3325192402221413, 2.353502846669783, 2.3740587721367246, 2.3942075889618066, 2.413968340932661, 2.433358694766703, 2.4523950730189896, 2.47109277110869, 2.489466060708718, 2.5075282813791953, 2.525291922027724, 2.5427686935346756, 2.559969593679444, 2.5769049653357126, 2.593584548763798, 2.6100175287109, 2.626212576931567, 2.6421778906575164, 2.6579212274755046, 2.6734499370120903, 2.6887709897730536, 2.7038910034415626, 2.7188162669016647, 2.7335527622214135, 2.7481061848020696, 2.7624819618756966, 2.7766852695125155, 2.790721048281188, 2.8045940176892685, 2.818308689517196, 2.8318693801469896, 2.845280221976117, 2.858545173997589, 2.871668031619018, 2.88465243578602, 2.8975018814688607, 2.9102197255654416, 2.92280919426862, 2.9352733899412558, 2.94761529753833, 2.9598377906118167, 2.9719436369307415, 2.9839355037459248, 2.9958159627263035, 3.00758749459134, 3.019252493461927, 3.030813270950267, 3.0422720600074715, 3.0536310185460906, 3.0648922328533144, 3.0760577208093625, 3.087129434924375, 3.0981092652060718, 3.1089990418694784, 3.1198005378991596, 3.1305154714735677, 3.1411455082604167, 3.1516922635913027, 3.1621573045231917, 3.1725421517938384, 3.1828482816776718, 3.1930771277482455, 3.203230082552875, 3.2133084992047287, 3.223313692897249, 3.233246942345455, 3.2431094911583584, 3.2529025491464565, 3.262627293567977], [0.0, 0.8218659786514628, 1.0118357081350007, 1.1427135561680801, 1.2457158792933032, 1.3319625198988463, 1.406845410729834, 1.4734330770638386, 1.5336561454070006, 1.588816553269279, 1.6398382151582813, 1.6874029679166804, 1.7320298678599693, 1.7741241544152841, 1.8140089012647544, 1.8519462629340446, 1.888152195409927, 1.9228069335469997, 1.9560626233873988, 1.98804899544733, 2.018877657381617, 2.048645393534808, 2.077436737012252, 2.1053260001152716, 2.132378895562335, 2.15865384442158, 2.1842030412886504, 2.209073329284256, 2.2333069245500523, 2.256942020533017, 2.280013295426244, 2.3025523409701507, 2.32458802692387, 2.346146812550276, 2.3672530141772583, 2.3879290361288255, 2.4081955709361966, 2.4280717736489343, 2.447575414200953, 2.466723011094881, 2.4855299491122493, 2.504010583307174, 2.522178331175176, 2.5400457545893835, 2.557624632850126, 2.5749260279905153, 2.591960343311715, 2.608737375980797, 2.6252663644061713, 2.641556031006477, 2.657614620905154, 2.6734499370120903, 2.6890693718934977, 2.704479936779824, 2.7196882880175663, 2.7347007512331136, 2.7495233434443134, 2.76416179332739, 2.778621559822611, 2.7929078492410087, 2.807025631016153, 2.820979652228975, 2.8347744510196597, 2.8484143689883714, 2.861903562675805, 2.875246014205099, 2.888445541158255, 2.9015058057528464, 2.9144303233782454, 2.9272224705447845, 2.9398854922941138, 2.952422509114422, 2.96483652340007, 2.9771304254915476, 2.9893069993283676, 3.0013689277445685, 3.0133187974338727, 3.0251591036091647, 3.0368922543788126, 3.0485205748604423, 3.0600463110510203, 3.0714716334705403, 3.0827986405951724, 3.094029362094454, 3.1051657618859223, 3.116209741019527, 3.127163140403192, 3.1380277433800132, 3.1488052781667757, 3.159497420162733, 3.1701057941369384, 3.1806319763017727, 3.191077496279789, 3.2014438389704427, 3.2117324463228343, 3.2219447190201347, 3.232082018080977, 3.2421456663827244, 3.2521369501111943, 3.2620571201410935, 3.2719073933511478, 3.2816889538776297], [0.0, 0.8265759423006915, 1.0176343535688062, 1.1492622386185494, 1.252854849224101, 1.3395957535571519, 1.4149077845434992, 1.4818770526180147, 1.5424452483543394, 1.5979217704282493, 1.6492358281324606, 1.6970731657919214, 1.7419558143389613, 1.7842913355537775, 1.824404654594699, 1.8625594283470437, 1.8989728504018566, 1.9338261885067332, 1.9672724606249572, 1.9994421407346024, 2.0304474760935554, 2.060385805699746, 2.0893421471022946, 2.117391238472734, 2.1445991691171065, 2.17102469490401, 2.196720309546772, 2.221733124615463, 2.2461055981847253, 2.2698761425811997, 2.293079634732363, 2.3157478474251207, 2.3379098158659173, 2.359592150950823, 2.380819308360157, 2.401613820813013, 2.4219964994257226, 2.4419866090219347, 2.4616020213718057, 2.4808593496424822, 2.499774066782866, 2.5183606101132625, 2.5366324740224067, 2.554602292373225, 2.5722819119710625, 2.5896824582435203, 2.6068143941111797, 2.6236875728868845, 2.640311285922675, 2.656694305623776, 2.6728449243649233, 2.6887709897730536, 2.704479936779824, 2.7199788167957633, 2.7352743243136715, 2.7503728212109473, 2.7652803589878663, 2.7800026991506495, 2.7945453319237528, 2.8089134934546247, 2.8231121816557505, 2.837146170812715, 2.851020025072953, 2.864738110917547, 2.878304608707566, 2.8917235233869687, 2.90499869441562, 2.9181338049985937, 2.931132390671315, 2.94399784729428, 2.95673343850588, 2.969342302677249, 2.9818274594089225, 2.994191815605403, 3.0064381711604513, 3.018569224282937, 3.0305875764904515, 3.0424957372954884, 3.054296128606844, 3.0659910888669692, 3.0775828769442275, 3.089073675797466, 3.100465595928838, 3.111760678639546, 3.1229608991019795, 3.134068169260658, 3.1450843405734124, 3.156011206603351, 3.1668505054713534, 3.1776039221780805, 3.1882730908038392, 3.1988595965939965, 3.2093649779370916, 3.219790728242267, 3.2301382977221706, 3.240409095087032, 3.2506044891552333, 3.2607258103853063, 3.2707743523339636, 3.2807513730444464, 3.2906580963691905, 3.300495713230536], [0.0, 0.8312241029633823, 1.0233569106010076, 1.1557249908658431, 1.2599001433443433, 1.3471288257976295, 1.422864365867587, 1.4902102283982717, 1.5511190228508476, 1.6069075111633213, 1.6585101279366483, 1.7066164737050284, 1.7517515149854366, 1.794325105437784, 1.8346639974019836, 1.8730333304094111, 1.9096515194158463, 1.9447008515085125, 1.9783352051307068, 2.0106857879668465, 2.041865478485167, 2.0719721630589545, 2.101091337324347, 2.1292981597349243, 2.156659091242814, 2.1832332181239034, 2.2090733292842555, 2.2342268012207733, 2.2587363307665043, 2.2826405462556636, 2.3059745207423687, 2.3287702056843655, 2.35105679956445, 2.372861062922197, 2.3942075889618066, 2.415119037112687, 2.4356163355202387, 2.455718857341768, 2.475444574847404, 2.494810194626647, 2.5138312766388573, 2.532522339391055, 2.550896953156214, 2.5689678228424255, 2.5867468618742686, 2.6042452582419857, 2.621473533703263, 2.638441596979987, 2.6551587916731143, 2.6716339395185438, 2.6878753795222865, 2.7038910034415626, 2.7196882880175663, 2.7352743243136715, 2.7506558444684375, 2.7658392461345946, 2.780830614842377, 2.7956357444972144, 2.810260156197248, 2.824709115534837, 2.8389876485276884, 2.8531005563090663, 2.867052428692398, 2.8808476567132, 2.8944904442403514, 2.9079848187391812, 2.921334641260343, 2.9345436157210165, 2.94761529753833, 2.9605531016690336, 2.973360310104238, 2.986040078863369, 2.998595444527359, 3.0110293303473754, 3.023344551962079, 3.0355438227534264, 3.047629758868363, 3.059604883931354, 3.07147163347054, 3.083232359078349, 3.094889332325648, 3.106444748446919, 3.117900729812495, 3.1292593292026165, 3.140522532896841, 3.1516922635913027, 3.162770383155305, 3.173758695237866, 3.184658947734, 3.195472835119787, 3.206202000664609, 3.216848038528289, 3.2274124957503285, 3.237896874137895, 3.2483026320587505, 3.258631186144855, 3.268883912911993, 3.2790621503003865, 3.2891671991409255, 3.2992003245513204, 3.3091627572662095, 3.3190556949049568], [0.0, 0.8358123939541525, 1.029005759421095, 1.162104500969668, 1.2668546920110242, 1.354564869859367, 1.4307184640917885, 1.49843607043165, 1.559681076589167, 1.6157775129236005, 1.6676649720406433, 1.7160368610146415, 1.7614210441360245, 1.8042296374243352, 1.8447911968664352, 1.8833723255428432, 1.9201926440425372, 1.9554354456629757, 1.989255458244234, 2.0217846137267204, 2.053136413658844, 2.083409284738893, 2.1126891945321224, 2.1410517163608027, 2.1685636780362363, 2.1952844919858565, 2.221267238506294, 2.2465595556089486, 2.2712043758099933, 2.2952405406689786, 2.318703316840494, 2.341624832151792, 2.364034446258973, 2.3859590674176645, 2.4074234245845987, 2.428450302267434, 2.44906074413327, 2.4692742302777018, 2.4891088321763615, 2.508581348637795, 2.5277074255111027, 2.546501661444309, 2.564977701617216, 2.5831483210679993, 2.6010254989823935, 2.618620485107458, 2.6359438592801467, 2.653005584917702, 2.669815057197016, 2.6863811465492677, 2.7027122380111197, 2.7188162669016647, 2.7347007512331136, 2.7503728212109473, 2.7658392461345946, 2.78110645897132, 2.796180578843001, 2.811067431636966, 2.8257725689273783, 2.8403012853722487, 2.854658634732502, 2.868849444643277, 2.882878330253406, 2.896749706836572, 2.9104678014666776, 2.9240366638403397, 2.9374601763209043, 2.9507420632708805, 2.9638858997330155, 2.9768951195143503, 2.9897730227223245, 3.002522782797342, 3.015147453082019, 3.027649972963638, 3.040033173622961, 3.0522997834195977, 3.0644524329414162, 3.0764936597430887, 3.088425912796677, 3.1002515566752136, 3.1119728754884557, 3.1235920765884035, 3.135111294060708, 3.146532592016792, 3.1578579677003193, 3.169089354420553, 3.180228624324168, 3.1912775910161804, 3.2022380120398473, 3.2131115912246218, 3.223899980910602, 3.234604784057246, 3.245227556243591, 3.2557698075666606, 3.266233004444291, 3.2766185713281377, 3.286927892332244, 3.2971623127821545, 3.3073231406892423, 3.3174116481545677, 3.327429072706326, 3.3373766185746447], [0.0, 0.8403426542669354, 1.034583164096176, 1.1684033258472732, 1.2737212826177138, 1.3619068661200142, 1.4384732271504903, 1.5065578756480145, 1.5681348412533196, 1.6245353308191393, 1.6767040297197382, 1.7253381034261697, 1.7709682773525588, 1.8140089012647544, 1.854790311984838, 1.8935805576321467, 1.9306004491805413, 1.9660342734116125, 2.000037596819419, 2.0327430664402892, 2.0642647990223644, 2.0947017547551416, 2.1241403671642423, 2.1526566191935514, 2.1803177008736734, 2.2071833466585677, 2.2333069245500523, 2.2587363307665047, 2.2835147305264076, 2.307681175917866, 2.3312711247473685, 2.3543168789810305, 2.3768479574098094, 2.3988914141371365, 2.420472112155338, 2.441612959468389, 2.4623351138040195, 2.4826581608436062, 2.502600270013576, 2.522178331175176, 2.54140807498095, 2.5603041792063386, 2.5788803629905854, 2.597149470614973, 2.615123546194676, 2.6328139004524975, 2.6502311705700956, 2.6673853739683095, 2.684285956747655, 2.700941837418717, 2.717361446466631, 2.7335527622214135, 2.7495233434443134, 2.7652803589878663, 2.780830614842377, 2.796180578843001, 2.8113364032784087, 2.826303945613331, 2.841088787512508, 2.8556962523319918, 2.870131421225042, 2.884399147993488, 2.898504072801135, 2.912450634853281, 2.9262430841353626, 2.939885492294114, 2.9533817627360217, 2.9667356400103375, 2.9799507185372147, 2.9930304507355725, 3.0059781546000544, 3.0187970207717063, 3.031490119142837, 3.0440604050327607, 3.0565107249677705, 3.068843822095698, 3.081062341262693, 3.093168833777451, 3.1051657618859223, 3.1170555029775695, 3.1288403535424547, 3.1405225328968416, 3.152104186693525, 3.1635873902318012, 3.174974151580769, 3.1862664145285917, 3.197466061369331, 3.208574915538084, 3.219594744104321, 3.2305272601325727, 3.2413741249189307, 3.2521369501111943, 3.2628172997199316, 3.273416692027176, 3.283936601399025, 3.2943784600079287, 3.304743659470089, 3.315033552402968, 3.3252494539076065, 3.3353926429800915, 3.345464363856254, 3.3554658272933753], [0.0, 0.8448166347692025, 1.0400912801969562, 1.17462389988583, 1.2805025689832445, 1.3691576521344881, 1.4461316521258578, 1.5145787829849935, 1.5764835840775349, 1.633184349595497, 1.6856307944138174, 1.734523795709374, 1.7803969044760037, 1.8236666764758407, 1.864665207242717, 1.9036619719829495, 1.9408789572670275, 1.9765014310185363, 2.010685787966847, 2.0435653813605117, 2.0752549355047245, 2.1058539374525846, 2.1354492809014145, 2.1641173533279505, 2.191925702482215, 2.2189343808441326, 2.245197040546522, 2.270761832807011, 2.2956721526555115, 2.3199672600932697, 2.3436828017039746, 2.3668512514292646, 2.3895022852180072, 2.411663101209558, 2.433358694766703, 2.4546120958555253, 2.4754445748474043, 2.4958758216977945, 2.5159241025670673, 2.535606397238016, 2.554938520113106, 2.573935227112189, 2.5926103104151443, 2.6109766826861502, 2.629046452163195, 2.646830989787321, 2.664340989372492, 2.681586521672251, 2.69857708307811, 2.715321639582764, 2.7318286665552147, 2.7481061848020696, 2.76416179332739, 2.7800026991506495, 2.7956357444972144, 2.811067431636966, 2.826303945613331, 2.841351175076157, 2.8562147314069413, 2.8708999663032597, 2.8854119879704094, 2.899755676051838, 2.913935695415563, 2.9279565089011905, 2.941822389121061, 2.9555374293993366, 2.969105553924223, 2.982530527180936, 2.995815962726304, 3.0089653313599105, 3.021981968741386, 3.0348690824987368, 3.0476297588683634, 3.0602669689036857, 3.072783574285892, 3.0851823327673196, 3.097465903275267, 3.109636850701586, 3.1216976504012135, 3.1336506924208227, 3.1454982854769784, 3.1572426607015736, 3.16888597517085, 3.1804303152329867, 3.1918776996480345, 3.2032300825528752, 3.214489356262896, 3.2256573539211546, 3.236735852004991, 3.2477265726992828, 3.258631186144855, 3.2694513125699136, 3.2801885243118107, 3.2908443477359075, 3.301420265057818, 3.3119177160748743, 3.3223380998122347, 3.332682776088692, 3.3429530670068783, 3.35315025837225, 3.3632756010449447, 3.373330312228309], [0.0, 0.8492360038884523, 1.0455321617986297, 1.1807685428488635, 1.287201079970816, 1.3763199318508206, 1.4536965949817957, 1.5225017835826598, 1.584730418457613, 1.6417277946267566, 1.6944485950733936, 1.743597363373505, 1.789710441610365, 1.833206564615027, 1.8744195651654623, 1.9136203281353112, 1.9510320013418414, 1.9868408218743787, 2.0212040025878015, 2.0542555943225467, 2.086110921524751, 2.1168699916799865, 2.146620153040217, 2.175438192677122, 2.2033920116936643, 2.2305419767137655, 2.2569420205330166, 2.2826405462556636, 2.307681175917866, 2.332103374896132, 2.3559429762470536, 2.3792326237885835, 2.402002148709159, 2.4242788914258946, 2.446087978056263, 2.467452559039734, 2.4883940160163553, 2.508932141942846, 2.529085298532744, 2.548870554392766, 2.5683038066530117, 2.587399888423879, 2.6061726640343146, 2.6246351136966815, 2.642799408989072, 2.6606769803357135, 2.6782785774916, 2.6956143238919745, 2.7126937656054713, 2.729525915527308, 2.746119293362479, 2.7624819618756966, 2.778621559822611, 2.7945453319237528, 2.810260156197248, 2.8257725689273783, 2.841088787512508, 2.8562147314069413, 2.8711560413461976, 2.8859180970234273, 2.900506033365755, 2.9149247555428137, 2.9291789528252816, 2.9432731113985824, 2.9572115262257666, 2.9709983120438204, 2.984637413568997, 2.998132614979129, 3.0114875487341304, 3.024705703789885, 3.0377904332553856, 3.050744961538246, 3.063572391019456, 3.076275708294486, 3.0888577900144294, 3.101321408357861, 3.113669236161348, 3.1259038517340954, 3.1380277433800132, 3.1500433136484856, 3.161952883333338, 3.1737586952378662, 3.1854629177223184, 3.1970676480488898, 3.208574915538084, 3.2199866845491814, 3.2313048572965686, 3.2425312765127647, 3.2536677279681427, 3.264715942856601, 3.2756776000557353, 3.2865543282694203, 3.2973477080601534, 3.308059273777953, 3.318690515392138, 3.329242880231847, 3.3397177746407594, 3.350116565551095, 3.360440581981613, 3.370691116464022, 3.380869426401905, 3.3909767353659923], [0.0, 0.853602352840574, 1.0509077679177485, 1.1868394671457136, 1.2938192274127118, 1.383396284083539, 1.4611707795137026, 1.5303297301568874, 1.592878313707396, 1.6501687420229045, 1.7031606065915657, 1.752562073401847, 1.7989122421411312, 1.8426320005666104, 1.884056897858285, 1.9234592116450238, 1.9610632370591314, 1.9970561687283763, 2.0315960278179075, 2.0648175543908796, 2.0968366658343447, 2.127753883822604, 2.157657005708867, 2.1866232133657277, 2.214720757009831, 2.2420103136402423, 2.268546093348149, 2.2943767481024744, 2.3195461242221813, 2.344093889995106, 2.368056062713588, 2.3914654540338462, 2.414352048521447, 2.4367433271643235, 2.458664545265943, 2.4801389722938145, 2.5011880998217397, 2.521831822571972, 2.542088596664844, 2.5619755784653537, 2.5815087468387348, 2.6007030111598564, 2.619572307041147, 2.638129681432762, 2.6563873684929917, 2.6743568574156176, 2.692048953225524, 2.709473831407621, 2.7266410871116773, 2.743559779572734, 2.7602384722998674, 2.7766852695125155, 2.7929078492410087, 2.8089134934546247, 2.824709115534837, 2.8403012853722487, 2.8556962523319918, 2.8708999663032597, 2.8859180970234273, 2.9007560518453497, 2.9154189920973925, 2.9299118481691284, 2.9442393334411334, 2.9584059571645644, 2.972416036385034, 2.9862737069954592, 2.9999829339938606, 3.0135475210144307, 3.0269711191933846, 3.0402572354250816, 3.0534092400585315, 3.0664303740796486, 3.079323755820322, 3.0920923872316086, 3.1047391597549114, 3.117266859821968, 3.1296781740117408, 3.141975693889818, 3.1541619205537303, 3.1662392689055747, 3.1782100716715442, 3.190076583186313, 3.2018409829587586, 3.2135053790341552, 3.2250718111667616, 3.2365422538156174, 3.2479186189753486, 3.259202758852888, 3.2703964684001505, 3.281501487711973, 3.2925195042979043, 3.3034521552358034, 3.314301029214634, 3.325067668473279, 3.3357535706417383, 3.3463601904905955, 3.3568889415942507, 3.3673411979130083, 3.377718295298781, 3.3880215329288323, 3.3982521746716885, 3.408411450389072], [0.0, 0.857917200444095, 1.0562199684392584, 1.1928387845252129, 1.3003593134073366, 1.3903891703159095, 1.468556805589356, 1.5380653456302877, 1.6009301040424735, 1.6585101279366483, 1.711769859409705, 1.7614210441360247, 1.808005506880992, 1.8519462629340444, 1.8935805576321465, 1.9331820449317627, 1.9709761537475865, 2.0071510249516042, 2.041865478485167, 2.075254935504724, 2.107435899344471, 2.138509399802548, 2.1685636780362363, 2.1976763060623417, 2.2259158790933773, 2.2533433808426553, 2.280013295426244, 2.305974520742369, 2.3312711247473685, 2.355942976247054, 2.3800262745964402, 2.403553997310353, 2.426556280522392, 2.44906074413327, 2.47109277110869, 2.4926757485402593, 2.5138312766388577, 2.534579350691942, 2.554938520113106, 2.574926027990515, 2.594557933960465, 2.6138492227627537, 2.632813900452497, 2.6514650799304675, 2.6698150571970154, 2.6878753795222865, 2.705656906549144, 2.7231698651982352, 2.7404238991215495, 2.757428113347368, 2.774191114672181, 2.790721048281188, 2.807025631016153, 2.8231121816557505, 2.8389876485276884, 2.854658634732502, 2.870131421225042, 2.8854119879704094, 2.900506033365755, 2.9154189920973925, 2.930156051583521, 2.944722167136187, 2.959122075961483, 2.9733603101042383, 2.9874412084321627, 3.001368927744568, 3.015147453082019, 3.028780607305577, 3.042272060007472, 3.0556253358089513, 3.0688438220956975, 3.081930776236381, 3.0948893323256486, 3.1077225074890253, 3.12043320778377, 3.1330242337266654, 3.1454982854769784, 3.1578579677003193, 3.170105794136938, 3.1822441918959443, 3.194275505495155, 3.2062020006646095, 3.2180258679303155, 3.22974922599344, 3.2413741249189303, 3.2529025491464565, 3.264336420335527, 3.2756776000557353, 3.286927892332244, 3.29808904605584, 3.3091627572662095, 3.3201506713164264, 3.331054384926067, 3.3418754481298296, 3.352615366128036, 3.3632756010449443, 3.3738575736003877, 3.3843626646998586, 3.394792216947825, 3.4051475360887205, 3.4154298923797617, 3.4256405218994592], [0.0, 0.8621819975594346, 1.0614705495818582, 1.1987685122479754, 1.3068235370478625, 1.3973009418944407, 1.4758571567478918, 1.5457112310908572, 1.608888496864119, 1.6667547571452994, 1.72027924837493, 1.7701772543903955, 1.8169932934252793, 1.8611524836227502, 1.9029937468020015, 1.94279209728225, 1.98077408460916, 2.0171287849228854, 2.0520158076754984, 2.085571247216336, 2.117912186029987, 2.1491401561443992, 2.1793438373729783, 2.2086011873512272, 2.236981142285713, 2.2645449890462355, 2.2913474825951647, 2.317437763907348, 2.3428601200055943, 2.3676546178877644, 2.391857636859695, 2.415502318370924, 2.4386189483649576, 2.461235284043956, 2.483376834555029, 2.5050671032494884, 2.5263277977151457, 2.5471790126381473, 2.5676393896431815, 2.5877262575356297, 2.6074557557859372, 2.6268429436246277, 2.6459018967323984, 2.6646457931956373, 2.683086990139414, 2.701237092236573, 2.719107013114412, 2.7367070305326813, 2.754046836082985, 2.771135580055662, 2.7879819120324973, 2.8045940176892685, 2.820979652228975, 2.837146170812715, 2.8531005563090663, 2.868849444643277, 2.884399147993488, 2.899755676051838, 2.9149247555428137, 2.9299118481691284, 2.944722167136187, 2.9593606923894145, 2.9738321846840563, 2.9881411985942155, 3.002292094556573, 3.0162890500343287, 3.0301360698781052, 3.043836995952811, 3.0573955160926065, 3.070815172440005, 3.08409936921974, 3.0972513799932067, 3.1102743544349676, 3.1231713246689985, 3.135945211198875, 3.1485988284630455, 3.1611348900435536, 3.173556013554079, 3.1858647252309384, 3.198063464248659, 3.210154586779903, 3.2221403698178936, 3.2340230147779754, 3.2458046508936014, 3.25748733842081, 3.26907307166413, 3.280563781835842, 3.2919613397596, 3.303267558428566, 3.314484195427447, 3.325612955227123, 3.336655491359891, 3.3476134084827907, 3.3584882643359046, 3.369281571602066, 3.379994799673907, 3.390629376333809, 3.4011866893518916, 3.411668088006852, 3.422074884534118, 3.432408355505487, 3.442669743144149], [0.0, 0.8663981311880077, 1.0666612189445914, 1.2046305787857483, 1.3132140006353124, 1.404133846672126, 1.483074207216527, 1.55326987314081, 1.6167560804084922, 1.67490531097509, 1.728691540918895, 1.7788335518680707, 1.8258785247905678, 1.8702536566886647, 1.9122995267342753, 1.9522924940869433, 1.9904602161363392, 2.0269926936189027, 2.062050316488712, 2.095769844606521, 2.128268932998912, 2.1596496101929485, 2.1900009896528694, 2.2194014102327726, 2.247920145242365, 2.2756187812487645, 2.3025523409701507, 2.328770205684366, 2.35431687898103, 2.3792326237885835, 2.403553997310353, 2.4273143030600126, 2.4505439750815685, 2.4732709063119485, 2.4955207306398752, 2.517317066349784, 2.538681727181194, 2.55963490608475, 2.5801953358440617, 2.600380430003648, 2.620206406957157, 2.639688399575861, 2.658840552371575, 2.6776761078725033, 2.696207483630968, 2.7144463410675224, 2.7324036471779065, 2.7500897299808753, 2.7675143284606305, 2.784686637653107, 2.8016153494371836, 2.818308689517196, 2.8347744510196597, 2.851020025072953, 2.867052428692398, 2.882878330253406, 2.898504072801135, 2.913935695415563, 2.9291789528252816, 2.9442393334411334, 2.959122075961483, 2.9738321846840563, 2.9883744436445436, 3.002753429689251, 3.016973524577717, 3.031038926201245, 3.0449536589944737, 3.058721583609313, 3.0723464059137062, 3.0858316853715038, 3.0991808428543504, 3.1123971679315976, 3.12548382567995, 3.138443863050693, 3.151280214828879, 3.1639957092157704, 3.1765930730630263, 3.1890749367846505, 3.2014438389704423, 3.2137022307226717, 3.2258524797358596, 3.2378968741378946, 3.249837626109204, 3.2616768752953504, 3.2734166920271757, 3.285059080361506, 3.2966059809543915, 3.308059273777953, 3.319420780691021, 3.330692267873024, 3.341875448129829, 3.352971983079629, 3.3639834852263535, 3.3749115199275512, 3.385757607263184, 3.396523223811324, 3.4072098043363126, 3.4178187433945686, 3.428351396862862, 3.438809083393547, 3.449193085800954, 3.459504652382834], [0.0, 0.8705669282622859, 1.0717936101729577, 1.2104268290910694, 1.319532715423216, 1.4108900351508284, 1.4902102283982717, 1.560743650691363, 1.6245353308191395, 1.6829643546280488, 1.7370093846199548, 1.7873926609424255, 1.8346639974019838, 1.8792526465196688, 1.921500826212221, 1.9616862253803444, 2.0000375968194186, 2.0367458554812843, 2.071972163058955, 2.1058539374525846, 2.1385093998025484, 2.1700410695605874, 2.2005384889729713, 2.230080373832268, 2.2587363307665047, 2.2865682426752736, 2.313631397026339, 2.3399754127025427, 2.365645007428817, 2.390680637864372, 2.415119037112687, 2.438993668931999, 2.4623351138040195, 2.4851713988764845, 2.5075282813791953, 2.5294294932393018, 2.5508969531562142, 2.5719509512418126, 2.592610310415145, 2.612892528008459, 2.632813900452497, 2.6523896334324815, 2.671633939518544, 2.690560124957186, 2.7091806670495373, 2.727507283326725, 2.7455509935537386, 2.763322175444056, 2.780830614842377, 2.798085551027853, 2.8150957177015656, 2.8318693801469896, 2.8484143689883714, 2.864738110917547, 2.8808476567132, 2.896749706836572, 2.912450634853281, 2.9279565089011905, 2.9432731113985824, 2.9584059571645644, 2.9733603101042383, 2.9881411985942155, 3.002753429689251, 3.017201602257794, 3.0314901191428376, 3.0456231984344333, 3.0596048839313545, 3.073439054861586, 3.0871294349243756, 3.1006796007104396, 3.114092989551429, 3.1273729068449234, 3.1405225328968416, 3.153544929319305, 3.166443045018501, 3.1792197218039804, 3.1918776996480345, 3.2044196216212764, 3.2168480385282896, 3.2291654132651684, 3.2413741249189307, 3.2534764726271157, 3.26547467921437, 3.2773708946214626, 3.2891671991409255, 3.300865606472387, 3.312468066609639, 3.323976468570553, 3.335392642980092, 3.3467183645159047, 3.357955354225267, 3.3691052817214815, 3.3801697672672697, 3.3911503837521186, 3.4020486585700698, 3.4128660754039597, 3.423604075921701, 3.434264061389818, 3.4448473942090727, 3.4553553993767028, 3.4657893658794796, 3.4761505480215167], [0.0, 0.8746896591546226, 1.0768692872787826, 1.216159029475901, 1.325781606935995, 1.417571566167883, 1.4972673948782311, 1.5681348412533196, 1.6322286186946957, 1.6909343439651996, 1.7452353142041923, 1.7958571898611984, 1.8433523884878307, 1.8881521954099272, 1.9306004491805415, 1.970976153747587, 2.009509145207664, 2.04639124262572, 2.081784370905807, 2.115826598715992, 2.148636707054751, 2.180317700873673, 2.2109595464629153, 2.240641332388256, 2.2694329949128007, 2.29739670999407, 2.3245880269238706, 2.3510567995644505, 2.3768479574098094, 2.402002148709159, 2.426556280522392, 2.4505439750815685, 2.473995957687934, 2.496940388216972, 2.5194031458766157, 2.54140807498095, 2.562977198029445, 2.5841309012215627, 2.6048880966157695, 2.625266364406171, 2.645282078198274, 2.6649505156866384, 2.684285956747655, 2.7033017706420175, 2.7220104937594276, 2.7404238991215495, 2.758553058679511, 2.776408399292373, 2.7939997531475167, 2.8113364032784087, 2.8284271247461903, 2.845280221976117, 2.861903562675805, 2.878304608707566, 2.8944904442403514, 2.9104678014666776, 2.9262430841353626, 2.941822389121061, 2.9572115262257666, 2.972416036385034, 2.9874412084321627, 3.002292094556573, 3.016973524577717, 3.0314901191428376, 3.045846301945406, 3.06004631105102, 3.0740942094086114, 3.087993894616967, 3.1017491080096025, 3.115363443114841, 3.1288403535424547, 3.142183160343345, 3.1553950588843582, 3.1684791252764475, 3.181438322390891, 3.194275505495155, 3.2069934275371774, 3.219594744104321, 3.232082018080977, 3.24445772402674, 3.256724252295235, 3.2688839129119933, 3.2809389392282586, 3.292891491366243, 3.304743659470089, 3.3164974667756715, 3.32815487251134, 3.3397177746407594, 3.351188012458157, 3.362567369045495, 3.3738575736003877, 3.3850603036429017, 3.3961771871088113, 3.407209804336313, 3.4181596899527067, 3.4290283346670827, 3.43981718697464, 3.4505276547778587, 3.4611611069294033, 3.47171887470128, 3.4822022531844965, 3.492612502623155], [0.0, 0.8787675409297631, 1.0818897486445278, 1.221828872133885, 1.331962519898846, 1.4241804121672976, 1.5042477899911526, 1.5754456267681387, 1.6398382151582813, 1.6988176317942556, 1.7533717580350285, 1.8042296374243352, 1.8519462629340444, 1.8969549305809308, 1.939601081924274, 1.9801650216534585, 2.0188776573816165, 2.0559317024514088, 2.091489836675339, 2.125690772410009, 2.15865384442158, 2.19048253787998, 2.221267238506294, 2.2510874035843003, 2.280013295426244, 2.308107379859548, 2.3354254651518063, 2.3620176375884534, 2.387929036128825, 2.413200498527924, 2.4378691039096707, 2.4619686312559925, 2.4855299491122493, 2.508581348637795, 2.531148829691755, 2.5532563477525474, 2.574926027990515, 2.5961783516474126, 2.617032318951422, 2.6375055920570936, 2.6576146209051537, 2.6773747544161473, 2.6968003390405313, 2.715904806367695, 2.7347007512331136, 2.753200001545337, 2.771413680873924, 2.7893522646888886, 2.807025631016153, 2.82444310616752, 2.841613506114255, 2.858545173997589, 2.875246014205099, 2.8917235233869687, 2.9079848187391812, 2.9240366638403397, 2.939885492294114, 2.9555374293993366, 2.9709983120438204, 2.9862737069954592, 3.001368927744568, 3.0162890500343287, 3.031038926201245, 3.0456231984344333, 3.06004631105102, 3.074312521874847, 3.0884259127966773, 3.102390399586254, 3.1162097410195266, 3.1298875473781695, 3.1434272883729935, 3.1568323005379386, 3.170105794136938, 3.18325085962205, 3.1962704736777257, 3.209167504882944, 3.2219447190201347, 3.234604784057246, 3.247150274827067, 3.259583677425811, 3.2719073933511478, 3.284123743398154, 3.296234971330157, 3.308243247340054, 3.3201506713164264, 3.331959275927657, 3.343671029536194, 3.3552878389541787, 3.3668115520507937, 3.3782439602208902, 3.389586800723756, 3.400841758900208, 3.412010470275602, 3.4230945225558145, 3.4340954575227154, 3.445014772835214, 3.455853923741525, 3.466614324707896, 3.477297350968705, 3.4879043400024687, 3.4984365929380252, 3.5088953758948476], [0.0, 0.8828017403633959, 1.086856430739564, 1.2274379793373027, 1.33807722281301, 1.4307184640917887, 1.511153410988493, 1.5826780990195635, 1.6473662974903183, 1.7066164737050284, 1.7614210441360247, 1.8125123991814884, 1.860448079645597, 1.9056633706975055, 1.9485052997312877, 1.989255458244234, 2.0281458138879045, 2.065369964703155, 2.101091337324347, 2.1354492809014145, 2.1685636780362363, 2.2005384889729713, 2.23146451437068, 2.261421576281427, 2.290480259573955, 2.3187033168404945, 2.346146812550276, 2.3728610629221976, 2.3988914141371365, 2.4242788914258946, 2.44906074413327, 2.473270906311949, 2.496940388216972, 2.5200976108852475, 2.542768693534676, 2.564977701617216, 2.5867468618742686, 2.608096749571788, 2.629046452163195, 2.6496137128855235, 2.6698150571970154, 2.6896659044812266, 2.7091806670495373, 2.728372838152365, 2.7472550704448895, 2.7658392461345946, 2.784136539856533, 2.802157475170951, 2.8199119754512885, 2.837409409824086, 2.854658634732502, 2.871668031619018, 2.888445541158255, 2.90499869441562, 2.921334641260343, 2.9374601763209043, 2.9533817627360217, 2.969105553924223, 2.984637413568997, 2.9999829339938606, 3.015147453082019, 3.0301360698781052, 3.0449536589944737, 3.0596048839313545, 3.0740942094086114, 3.0884259127966773, 3.1026040947252436, 3.116632688940361, 3.130515471473568, 3.144256069180429, 3.1578579677003193, 3.171324518884362, 3.184658947734, 3.1978643588887747, 3.210943742698342, 3.223899980910602, 3.2367358520049905, 3.249454036197423, 3.2620571201410935, 3.274547601345255, 3.286927892332244, 3.299200324551321, 3.3113671520663632, 3.3234305550330734, 3.3353926429800915, 3.3472554579072655, 3.359020977213298, 3.3706911164640223, 3.3822677320117203, 3.3937526234750846, 3.405147536088721, 3.416454162930418, 3.427674147033817, 3.438809083393548, 3.4498605208694126, 3.460829963995693, 3.4717188747012804, 3.482528673945879, 3.4932607432772196, 3.503916426313845, 3.5144970301577456, 3.5250038267408295], [0.0, 0.8867933767468494, 1.0917707115731572, 1.2329879073366956, 1.3441274122068965, 1.4371875359282316, 1.517986173839412, 1.5898342646618526, 1.65481495436228, 1.7143330334914173, 1.7693854057869884, 1.8207077731904424, 1.868860197457217, 1.9142799319221808, 1.957315573082763, 1.9982499856676201, 2.0373161861827436, 2.0747086480331265, 2.1105915367956016, 2.145104831694911, 2.1783689573886784, 2.210488344182997, 2.2415542032970763, 2.271646717702757, 2.30083679142213, 2.329187460786705, 2.3567550437642795, 2.383590084081288, 2.4097381329538465, 2.4352404011105846, 2.4601343063212493, 2.4844539360732045, 2.508230440836056, 2.531492370153986, 2.5542659613443677, 2.5765753886724188, 2.5984429793789663, 2.619889401762157, 2.640933829580377, 2.661594086297676, 2.6818867720930615, 2.7018273760696747, 2.7214303757049514, 2.7407093252597794, 2.75967693459901, 2.77834513965618, 2.796725165593065, 2.814827583552766, 2.8326623617777975, 2.85023891175772, 2.8675661299805832, 2.88465243578602, 2.9015058057528464, 2.9181338049985937, 2.9345436157210165, 2.9507420632708805, 2.9667356400103375, 2.982530527180936, 2.998132614979129, 3.0135475210144307, 3.028780607305577, 3.043836995952811, 3.058721583609313, 3.073439054861586, 3.087993894616967, 3.102390399586254, 3.116632688940361, 3.130724714211986, 3.1446702685062005, 3.1584729950775947, 3.172136395326054, 3.1856638362582794, 3.199058557457734, 3.2123236776017574, 3.2254622005610343, 3.2384770211134466, 3.251370930301476, 3.2641466204597815, 3.276806689937251, 3.289353647535762, 3.3017899166860034, 3.3141178393790103, 3.326339679870534, 3.33845762817397, 3.3504738033563073, 3.362390256650409, 3.3742089743958923, 3.3859318808199275, 3.3975608406683953, 3.409097661697062, 3.420544097031707, 3.4319018474054634, 3.4431725632810384, 3.454357846864918, 3.4654592540201583, 3.4764782960838754, 3.4874164415951516, 3.4982751179386384, 3.5090557129088107, 3.5197595761994553, 3.5303880208226968, 3.540942324461552], [0.0, 0.8907435244960379, 1.0966339139064576, 1.238480149988315, 1.350114716590505, 1.443589368935865, 1.5247479176966878, 1.5969160498970727, 1.6621861907051554, 1.721969388194976, 1.7772669867295032, 1.8288179653736338, 1.8771848806315714, 1.9228069335469995, 1.9660342734116123, 2.0071510249516042, 2.0463912426257194, 2.0839502661046487, 2.1199929922272083, 2.154660023744019, 2.1880723217343814, 2.22033478168055, 2.251539021094566, 2.281765580116686, 2.3110856786051026, 2.3395626336814512, 2.3672530141772583, 2.3942075889618066, 2.420472112155338, 2.446087978056263, 2.4710927711086903, 2.4955207306398752, 2.5194031458766157, 2.542768693534676, 2.5656437278033897, 2.588052530630239, 2.6100175287109, 2.631559482408742, 2.6526976508900733, 2.6734499370120903, 2.6938330148979235, 2.7138624426456444, 2.7335527622214135, 2.752917588262453, 2.771969687248656, 2.790721048281188, 2.8091829465233795, 2.8273660002066134, 2.845280221976117, 2.8629350652441516, 2.8803394661274377, 2.8975018814688607, 2.9144303233782454, 2.931132390671315, 2.94761529753833, 2.9638858997330155, 2.9799507185372147, 2.995815962726304, 3.0114875487341304, 3.0269711191933846, 3.042272060007472, 3.0573955160926065, 3.0723464059137062, 3.0871294349243756, 3.1017491080096025, 3.1162097410195266, 3.130515471473568, 3.1446702685062005, 3.158677942118568, 3.1725421517938384, 3.1862664145285917, 3.199854112327582, 3.213308499204729, 3.226632707729263, 3.2398297551523623, 3.252902549146457, 3.265853893186497, 3.278686491599923, 3.2914029543097536, 3.3040058012931164, 3.3164974667756715, 3.32888030318066, 3.3411565848497733, 3.35332851155164, 3.3653982117924572, 3.377367745942136, 3.3892391091882796, 3.401014234329368, 3.412694994417638, 3.4242832052613554, 3.4357806277954532, 3.4471889703288388, 3.4585098906760696, 3.4697449981805284, 3.4808958556357337, 3.491963981110928, 3.5029508496866795, 3.513857895105807, 3.524686511344601, 3.5354380541089467, 3.5461138422596736, 3.5567151591711315], [0.0, 0.8946532155809793, 1.1014473082435876, 1.2439161421320981, 1.356040700137889, 1.4499256355837062, 1.5314404090554934, 1.6039253048307134, 1.6694819322430907, 1.7295275328016144, 1.7850678460144567, 1.8368450945062844, 1.885424303979324, 1.9312466032380091, 1.9746636784648746, 2.0159609014789965, 2.055373354061357, 2.093097233276215, 2.1292981597349243, 2.16411735332795, 2.1976763060623417, 2.2300803738322674, 2.261421576281427, 2.2917808070604413, 2.321229598628872, 2.3498315460226795, 2.377643466367821, 2.4047163513705585, 2.4310961559771522, 2.456824456175708, 2.4819390013776474, 2.506474181195005, 2.5304614221906423, 2.5539295269494406, 2.576904965335713, 2.5994121258763454, 2.621473533703263, 2.6431100403021466, 2.664340989372492, 2.6851843623515137, 2.705656906549144, 2.7257742483517506, 2.7455509935537386, 2.7650008165503013, 2.784136539856533, 2.802970205196695, 2.8215131372235653, 2.839776000774542, 2.857768852442798, 2.8755011871339335, 2.892981980187469, 2.9102197255654416, 2.9272224705447845, 2.94399784729428, 2.9605531016690336, 2.9768951195143503, 2.9930304507355725, 3.0089653313599105, 3.024705703789885, 3.0402572354250816, 3.0556253358089513, 3.070815172440005, 3.0858316853715038, 3.1006796007104396, 3.115363443114841, 3.1298875473781695, 3.144256069180429, 3.1584729950775947, 3.1725421517938384, 3.186467214874692, 3.200251716753695, 3.2138990542800463, 3.2274124957503285, 3.240795187483384, 3.2540501599738443, 3.267180333656624, 3.2801885243118107, 3.293077448136799, 3.305849726510197, 3.3185078904699297, 3.331054384926067, 3.3434915726272116, 3.355821737897696, 3.3680470901614714, 3.3801697672672697, 3.3921918386284675, 3.4041153081900353, 3.415942117233978, 3.427674147033817, 3.439313221367843, 3.450861108900164, 3.4623195254378736, 3.473690136072081, 3.4849745572099717, 3.496174358504546, 3.507291064688224, 3.5183261573160634, 3.52928107642393, 3.5401572221066173, 3.5509559560205357, 3.561678602815316, 3.5723264514983533], [0.0, 0.8985234417906398, 1.1062121156199922, 1.2492972627406829, 1.361906866120014, 1.4561979432210856, 1.5380653456302877, 1.6108638075320785, 1.6767040297197382, 1.7370093846199546, 1.792789962520997, 1.8447911968664352, 1.8935805576321463, 1.939601081924274, 1.9832059773026387, 2.0246818500908987, 2.064264799022364, 2.1021518699002315, 2.138509399802548, 2.1734792195301433, 2.2071833466585673, 2.239727592846453, 2.2712043758099933, 2.3016949391418002, 2.3312711247473685, 2.3599968027716853, 2.387929036128825, 2.415119037112687, 2.4416129594683884, 2.467452559039734, 2.4926757485402593, 2.517317066349784, 2.5414080749809496, 2.564977701617216, 2.5880525306302387, 2.610657056050483, 2.632813900452497, 2.6545440055244716, 2.6758667986458047, 2.6968003390405313, 2.7173614464666307, 2.7375658149094564, 2.757428113347368, 2.776962075330326, 2.7961805788430008, 2.815095717701565, 2.8337188655486942, 2.8520607333573507, 2.870131421225042, 2.887940465131866, 2.9054968792442244, 2.92280919426862, 2.9398854922941138, 2.95673343850588, 2.973360310104238, 2.9897730227223245, 3.0059781546000544, 3.021981968741386, 3.0377904332553856, 3.0534092400585315, 3.0688438220956975, 3.08409936921974, 3.0991808428543504, 3.114092989551429, 3.1288403535424547, 3.1434272883729935, 3.1578579677003193, 3.172136395326054, 3.1862664145285917, 3.200251716753695, 3.2140958497160383, 3.2278022249594254, 3.2413741249189303, 3.2548147095242173, 3.26812702237969, 3.281313996553922, 3.2943784600079287, 3.307323140689242, 3.320150671316426, 3.3328635938765525, 3.3454643638562533, 3.3579553542252665, 3.3703388591898, 3.382617097731666, 3.394792216947825, 3.406866295203835, 3.418841345113636, 3.430719316357123, 3.442502098346115, 3.45419152274848, 3.4657893658794796, 3.4772973509687044, 3.488717150310369, 3.5000503873041553, 3.5112986383933076, 3.522463434906163, 3.533546264806915, 3.544548574360954, 3.5554717697198153, 3.566317218430369, 3.5770862508726156, 3.5877801616301324], [0.0, 0.9023551568464464, 1.110929510204478, 1.2546248378580127, 1.3677146601082473, 1.4624078375029255, 1.5446243599726637, 1.617733267823369, 1.6838542628422097, 1.7444167873671343, 1.8004352391735468, 1.8526582305742765, 1.9016556514968117, 1.947872428360219, 1.991663274962956, 2.0333160198491758, 2.0730677685852084, 2.111116407267711, 2.1476289823121344, 2.1827479293507346, 2.2165957862978303, 2.249278816041379, 2.280889830408998, 2.311510419453151, 2.341212731446087, 2.3700609089043136, 2.398112258084279, 2.425418209672534, 2.452025114234883, 2.4779749056811515, 2.5033056584020335, 2.528052058064801, 2.552245801779091, 2.575915940087109, 2.599089170728433, 2.621790092187282, 2.644041423511212, 2.6658641956933544, 2.6872779189603406, 2.708300729549, 2.7289495189444555, 2.749240048058394, 2.7691870484244108, 2.7888043121586072, 2.8081047721632717, 2.8271005738281425, 2.8458031392983107, 2.8642232252232294, 2.882370974771842, 2.900255964590028, 2.91788724728472, 2.9352733899412558, 2.952422509114422, 2.969342302677249, 2.986040078863369, 3.002522782797342, 3.0187970207717063, 3.0348690824987368, 3.050744961538246, 3.0664303740796486, 3.081930776236381, 3.0972513799932067, 3.1123971679315976, 3.1273729068449234, 3.142183160343345, 3.1568323005379386, 3.171324518884362, 3.1856638362582794, 3.199854112327582, 3.2138990542800463, 3.2278022249594254, 3.2415670504579066, 3.2551968272083687, 3.268694728615862, 3.282063811264112, 3.295307020729638, 3.308427197033176, 3.3214270797554737, 3.3343093128422123, 3.3470764491206584, 3.3597309545487635, 3.3722752122156927, 3.3847115261112006, 3.397042124679852, 3.4092691641748116, 3.4213947318247397, 3.4334208488262816, 3.44534947317366, 3.457182502336011, 3.4689217757922712, 3.4805690774327243, 3.4921261378356, 3.50359463642654, 3.514976203528146, 3.526272422306337, 3.5374848306197353, 3.5486149227778934, 3.5596641512137404, 3.570633928075284, 3.5815256267412408, 3.592340583264959, 3.603080097750714], [0.0, 0.9061492783765588, 1.1156006217298278, 1.2599001433443435, 1.3734654729667926, 1.4685568055893563, 1.5511190228508476, 1.6245353308191395, 1.6909343439651998, 1.7517515149854368, 1.8080055068809922, 1.8604480796455973, 1.9096515194158465, 1.9560626233873988, 2.0000375968194186, 2.041865478485167, 2.0817843709058064, 2.1199929922272083, 2.156659091242814, 2.1919257024822145, 2.2259158790933773, 2.2587363307665043, 2.290480259573955, 2.321229598628872, 2.3510567995644505, 2.3800262745964407, 2.4081955709361966, 2.4356163355202387, 2.4623351138040195, 2.4883940160163553, 2.5138312766388577, 2.5386817271811943, 2.562977198029445, 2.5867468618742686, 2.6100175287108995, 2.632813900452497, 2.6551587916731143, 2.6770733217946385, 2.6985770830781095, 2.719688288017566, 2.740423899121549, 2.760799743571455, 2.780830614842377, 2.8005303630419536, 2.819911975451288, 2.838987648527689, 2.8577688524427978, 2.8762663890744187, 2.894490444240352, 2.9124506348532804, 2.9301560515835217, 2.94761529753833, 2.96483652340007, 2.9818274594089225, 2.998595444527359, 3.015147453082019, 3.031490119142837, 3.0476297588683634, 3.063572391019456, 3.079323755820322, 3.0948893323256486, 3.1102743544349676, 3.12548382567995, 3.1405225328968416, 3.1553950588843582, 3.170105794136938, 3.184658947734, 3.199058557457734, 3.213308499204729, 3.2274124957503285, 3.2413741249189303, 3.2551968272083687, 3.2688839129119933, 3.282438568778031, 3.2958638642421865, 3.30916275726621, 3.3223380998122347, 3.3353926429800915, 3.348329041832426, 3.361149859930347, 3.3738575736003877, 3.38645457595186, 3.3989431806620747, 3.4113256255455098, 3.423604075921701, 3.435780627795453, 3.4478573108619113, 3.459836091348054, 3.4717188747012804, 3.4835075081349625, 3.4952037830400844, 3.506809437271418, 3.5183261573160634, 3.5297555803516207, 3.541099296200726, 3.5523588491882183, 3.563535739906754, 3.574631426896288, 3.5856473282424712, 3.5965848230986466, 3.6074452531358507, 3.6182299239248907], [0.0, 0.909906689761875, 1.1202265377654983, 1.2651244074429089, 1.3791606436507111, 1.4746462791374575, 1.5575508464096348, 1.6312715802357964, 1.6979459215357517, 1.7590152752109522, 1.8155025282199486, 1.8681625577818863, 1.9175700230578674, 1.9641735739193849, 2.008330892655634, 2.0503322165593723, 2.0904166354605263, 2.1287836915036635, 2.1656018290643346, 2.2010146757748155, 2.235145795031561, 2.268102339003971, 2.299977896233319, 2.3308547395741335, 2.360805621085376, 2.389895220072557, 2.4181813223705686, 2.4457157890735672, 2.4725453586409927, 2.498712315914672, 2.52425505391817, 2.5492085485924463, 2.573604762310503, 2.5974729887296037, 2.620840149014503, 2.64373104750657, 2.6661685933820873, 2.6881739936361027, 2.709766921770336, 2.730965665798208, 2.7517872585644874, 2.7722475928790864, 2.7923615235592765, 2.8121429581431383, 2.831604937764444, 2.850759709453965, 2.8696187909452138, 2.8881930289067355, 2.906492651392536, 2.9245273151925013, 2.942306148672048, 2.9598377906118167, 2.9771304254915476, 2.994191815605403, 3.0110293303473754, 3.027649972963638, 3.0440604050327607, 3.0602669689036857, 3.076275708294486, 3.0920923872316086, 3.1077225074890253, 3.1231713246689985, 3.138443863050693, 3.153544929319305, 3.1684791252764475, 3.18325085962205, 3.1978643588887747, 3.2123236776017574, 3.226632707729263, 3.240795187483384, 3.2548147095242173, 3.268694728615862, 3.282438568778031, 3.296049429973025, 3.30953039436418, 3.32288443217864, 3.3361144072044002, 3.349223081948918, 3.3622131224842433, 3.3750871030014693, 3.3878475100953915, 3.4004967467985163, 3.413037136381979, 3.425470925939513, 3.437800289769302, 3.450027332567382, 3.4621540924451715, 3.4741825437827454, 3.4861145999285745, 3.4979521157556306, 3.5096968900830254, 3.521350667971667, 3.5329151429017935, 3.544391958839675, 3.5557827122002594, 3.567088953712036, 3.578312190189974, 3.5894538862219667, 3.600515465773855, 3.611498313717739, 3.622403777287988, 3.63323316746905], [0.0, 0.9136282418637358, 1.1248083058446763, 1.2702988131821025, 1.3848014618246332, 1.4806776371012742, 1.563921287127823, 1.6379435414890116, 1.7048905833172705, 1.7662097129135477, 1.8229280008819848, 1.8758034119175455, 1.92541295555861, 1.972207116671282, 2.0165450404785834, 2.0587181513545616, 2.098966517015413, 2.137490495740476, 2.1744592208490428, 2.2100169074157323, 2.2442876242158722, 2.277378961675209, 2.3093848911156187, 2.340388021890658, 2.3704614036179064, 2.399669980143632, 2.4280717736489343, 2.4557188573417683, 2.4826581608436062, 2.508932141942846, 2.534579350691942, 2.55963490608475, 2.5841309012215627, 2.608096749571788, 2.631559482408742, 2.6545440055244716, 2.6770733217946385, 2.6991687249516865, 2.7208499689626877, 2.7421354166397154, 2.763042170492506, 2.783586188333152, 2.8037823857356794, 2.823644727120515, 2.8431863069601517, 2.8624194223761714, 2.881355638210043, 2.900005845493588, 2.918380314113934, 2.936488740357594, 2.9543402899253386, 2.9719436369307415, 2.9893069993283676, 3.0064381711604513, 3.023344551962079, 3.040033173622961, 3.0565107249677705, 3.072783574285892, 3.0888577900144294, 3.1047391597549114, 3.12043320778377, 3.135945211198875, 3.151280214828879, 3.166443045018501, 3.181438322390891, 3.1962704736777257, 3.210943742698342, 3.2254622005610343, 3.2398297551523623, 3.2540501599738443, 3.26812702237969, 3.282063811264112, 3.2958638642421865, 3.30953039436418, 3.3230664963995897, 3.336475152723899, 3.349759238838102, 3.362921528548415, 3.37596469883122, 3.3888913344061486, 3.4017039320382603, 3.414404904588554, 3.42699658483043, 3.439481229048318, 3.4518610204333626, 3.4641380722898845, 3.4763144310652527, 3.488392079214831, 3.5003729379127555, 3.5122588696184973, 3.5240516805084057, 3.5357531227807515, 3.5473648968421707, 3.558888653382816, 3.570325995347032, 3.5816784798058445, 3.592947619737152, 3.6041348857190667, 3.6152417075415024, 3.626269475740738, 3.6372195430613807, 3.648093225849853], [0.0, 0.9173147546424019, 1.1293469354568555, 1.275424500625791, 1.3903891703159095, 1.4866522083548113, 1.570231748588672, 1.6445526845953091, 1.7117698594097053, 1.7733364132256764, 1.8302835609029082, 1.8833723255428432, 1.9331820449317627, 1.9801650216534588, 2.024681850090899, 2.0670251305227603, 2.107435899344471, 2.1461153232860317, 2.1832332181239034, 2.2189343808441326, 2.2533433808426553, 2.286568242675273, 2.3187033168404945, 2.3498315460226795, 2.3800262745964407, 2.409352708458088, 2.4378691039096707, 2.4656277442758388, 2.4926757485402593, 2.5190557458095677, 2.5448064416866427, 2.5699630968713567, 2.594557933960465, 2.618620485107458, 2.642177890657517, 2.6652551568981795, 2.6878753795222865, 2.710059938183024, 2.7318286665552147, 2.753200001545337, 2.774191114672181, 2.794818028138011, 2.815095717701565, 2.835038204130057, 2.854658634732502, 2.873969356249675, 2.892981980187469, 2.9117074415232924, 2.9301560515835217, 2.9483375457794296, 2.9662611267956174, 2.9839355037459248, 3.0013689277445685, 3.018569224282937, 3.0355438227534264, 3.0522997834195977, 3.068843822095698, 3.0851823327673196, 3.101321408357861, 3.117266859821968, 3.1330242337266654, 3.1485988284630455, 3.1639957092157704, 3.1792197218039804, 3.194275505495155, 3.209167504882944, 3.223899980910602, 3.2384770211134466, 3.252902549146457, 3.267180333656624, 3.281313996553922, 3.295307020729638, 3.30916275726621, 3.32288443217864, 3.336475152723899, 3.3499379133114298, 3.3632756010449447, 3.376491000923037, 3.389586800723756, 3.4025655955961414, 3.4154298923797617, 3.4281821136715704, 3.440824601657767, 3.453359621726945, 3.4657893658794796, 3.4781159559469277, 3.490341446634124, 3.502467828395689, 3.514497030157746, 3.526430921894835, 3.5382713170712727, 3.5500199749554935, 3.5616786028153165, 3.5732488580014707, 3.584732349926221, 3.596130641943414, 3.6074452531358507, 3.6186776600154644, 3.629829298141406, 3.640901563660803, 3.651895814776621, 3.662813373146773], [0.0, 0.9209670186745648, 1.1338433999161135, 1.2805025689832445, 1.3959249674147287, 1.4925712741514, 1.5764835840775349, 1.6511004268926472, 1.7185852250813278, 1.7803969044760037, 1.8375707856905992, 1.8908709218195734, 1.9408789572670275, 1.9880489954473297, 2.0327430664402892, 2.0752549355047245, 2.115826598715992, 2.154660023744019, 2.1919257024822145, 2.227769008421933, 2.2623150069288096, 2.2956721526555115, 2.3279351717545196, 2.3591873371442627, 2.3895022852180077, 2.4189454814875875, 2.4475754142009527, 2.4754445748474043, 2.5026002700135757, 2.529085298532744, 2.554938520113106, 2.5801953358440617, 2.6048880966157695, 2.629046452163195, 2.6526976508900733, 2.6758667986458047, 2.6985770830781095, 2.7208499689626877, 2.742705368941606, 2.7641617933273896, 2.7852364820067694, 2.8059455209739763, 2.826303945613331, 2.8463258325153524, 2.866024381334715, 2.8854119879704094, 2.904500310159228, 2.9233003264158963, 2.941822389121061, 2.960076272447272, 2.978071215719372, 2.9958159627263035, 3.0133187974338727, 3.0305875764904515, 3.047629758868363, 3.0644524329414162, 3.081062341262693, 3.097465903275267, 3.113669236161348, 3.1296781740117408, 3.1454982854769784, 3.1611348900435536, 3.1765930730630263, 3.1918776996480345, 3.2069934275371774, 3.2219447190201347, 3.2367358520049905, 3.251370930301476, 3.265853893186497, 3.2801885243118107, 3.2943784600079287, 3.308427197033176, 3.3223380998122347, 3.3361144072044002, 3.349759238838102, 3.3632756010449447, 3.376666392423566, 3.389934409060956, 3.403082349436481, 3.416112819031695, 3.4290283346670827, 3.4418313285851014, 3.4545241522973016, 3.4671090802118614, 3.479588313056546, 3.491963981110928, 3.504238147260594, 3.516412809885106, 3.5284899055905545, 3.5404713117967335, 3.5523588491882183, 3.564154284037924, 3.575859330411111, 3.587475652257204, 3.599004865396301, 3.610448539406699, 3.6218081994193883, 3.633085327824992, 3.6442813658983026, 3.6553977153451696, 3.6664357397762077, 3.677396766111475], [0.0, 0.9245857965774334, 1.1382986381143665, 1.2855340785891718, 1.4014100090326287, 1.49843607043165, 1.5826780990195632, 1.6575881355935032, 1.7253381034261694, 1.7873926609424253, 1.8447911968664352, 1.898300766504897, 1.9485052997312875, 1.9958606842794653, 2.040730372762757, 2.0834092847388934, 2.124140367164242, 2.1631263813051627, 2.2005384889729713, 2.2365226348785843, 2.2712043758099933, 2.3046925925733457, 2.3370823835308765, 2.3684573488072993, 2.3988914141371365, 2.4284503022674344, 2.457192731265425, 2.4851713988764845, 2.5124337975701567, 2.539022894350206, 2.564977701617216, 2.5903337595629425, 2.6151235461946754, 2.6393768277507985, 2.663120959702856, 2.6863811465492677, 2.709180667049537, 2.7315410703214247, 2.753482347250221, 2.7750230808814687, 2.7961805788430008, 2.816970990336134, 2.837409409824086, 2.857509969208863, 2.8772859200108596, 2.8967497068365717, 2.9159130332298178, 2.9347869208434663, 2.9533817627360213, 2.971707371485926, 2.989773022722325, 3.00758749459134, 3.0251591036091647, 3.0424957372954884, 3.059604883931354, 3.0764936597430887, 3.093168833777451, 3.109636850701586, 3.1259038517340954, 3.141975693889818, 3.1578579677003193, 3.173556013554079, 3.1890749367846505, 3.2044196216212764, 3.219594744104321, 3.234604784057246, 3.249454036197423, 3.2641466204597815, 3.278686491599923, 3.293077448136799, 3.307323140689242, 3.3214270797554737, 3.3353926429800915, 3.349223081948918, 3.362921528548415, 3.376491000923037, 3.389934409060956, 3.4032545600358945, 3.416454162930418, 3.429535833463862, 3.442502098346115, 3.4553553993767028, 3.4680980973070272, 3.4807324754821534, 3.4932607432772196, 3.5056850393423553, 3.518007434668895, 3.5302299354886815, 3.5423544860173575, 3.5543829710517083, 3.566317218430369, 3.578159001366514, 3.58991004066052, 3.6015720068000103, 3.6131465219541625, 3.624635161868656, 3.6360394576672137, 3.6473608975652536, 3.6586009285008037, 3.6697609576874695, 3.6808423540939335, 3.6918464498541534], [0.0, 0.9281718243462789, 1.1427135561680801, 1.2905200527634264, 1.406845410729834, 1.5042477899911528, 1.588816553269279, 1.6640171301828108, 1.7320298678599693, 1.794325105437784, 1.8519462629340444, 1.9056633706975055, 1.9560626233873983, 2.003601676908886, 2.0486453935348075, 2.091489836675339, 2.1323788955623346, 2.1715161178764975, 2.209073329284256, 2.245197040546522, 2.280013295426244, 2.3136313970263385, 2.346146812550276, 2.377643466367821, 2.4081955709361966, 2.4378691039096707, 2.4667230110948806, 2.4948101946266474, 2.522178331175176, 2.548870554392766, 2.574926027990515, 2.6003804300036477, 2.625266364406171, 2.6496137128855235, 2.6734499370120903, 2.6968003390405313, 2.719688288017566, 2.7421354166397154, 2.7641617933273896, 2.78578607320091, 2.8070256310161525, 2.82789667860949, 2.8484143689883705, 2.868592888865716, 2.8884455411582546, 2.9079848187391812, 2.927222470544784, 2.946169560975671, 2.9648365234000695, 2.9832332084547386, 3.001368927744568, 3.019252493461927, 3.0368922543788126, 3.054296128606844, 3.07147163347054, 3.088425912796677, 3.1051657618859223, 3.1216976504012135, 3.1380277433800132, 3.1541619205537303, 3.170105794136938, 3.1858647252309384, 3.2014438389704423, 3.2168480385282896, 3.232082018080977, 3.247150274827067, 3.2620571201410935, 3.276806689937251, 3.2914029543097536, 3.305849726510197, 3.320150671316426, 3.3343093128422123, 3.348329041832426, 3.3622131224842433, 3.37596469883122, 3.389586800723756, 3.403082349436481, 3.416454162930418, 3.4297049607953727, 3.4428373688958116, 3.455853923741525, 3.4687570766026163, 3.4815491973867174, 3.4942325782949006, 3.506809437271418, 3.5192819212612036, 3.5316521092879807, 3.5439220153648097, 3.556093591248019, 3.568168729044623, 3.580149263682572, 3.5920369752524883, 3.603833591228915, 3.6155407885785, 3.627160195762042, 3.638693394636788, 3.6501419222649596, 3.661507272634054, 3.6727908982940813, 3.683994211916559, 3.6951185877797466, 3.706165363184315], [0.0, 0.9317258126117351, 1.1470890289661901, 1.2954614795591468, 1.4122322496209696, 1.510007584518133, 1.594900163262783, 1.6703886846720382, 1.7386618444663802, 1.8011956117404622, 1.859037401787951, 1.91296019341903, 1.96355242584387, 2.0112735073411425, 2.056489697248543, 2.0994981926088974, 2.1405438165107515, 2.179830896022901, 2.217531914735649, 2.2537939444025072, 2.2887435114104844, 2.3224903373862382, 2.3551302550790494, 2.386747510206753, 2.417416599387539, 2.4472037529054163, 2.476168142271683, 2.5043628721844784, 2.5318358018689215, 2.5586302301369193, 2.584785470658193, 2.61033733807987, 2.635318561217217, 2.6597591361752464, 2.683686629675238, 2.7071264408546853, 2.7301020282408497, 2.752635107362275, 2.7747458234817497, 2.7964529031504197, 2.8177737876524445, 2.838724750899639, 2.8593210039206167, 2.8795767877495035, 2.899505456240159, 2.919119550101236, 2.9384308632559324, 2.9574505024706648, 2.976188941063234, 2.9946560673886813, 3.012861228706216, 3.030813270950267, 3.0485205748604423, 3.0659910888669692, 3.083232359078349, 3.1002515566752136, 3.1170555029775695, 3.1336506924208227, 3.1500433136484856, 3.1662392689055747, 3.1822441918959443, 3.198063464248659, 3.2137022307226717, 3.2291654132651684, 3.24445772402674, 3.259583677425811, 3.274547601345255, 3.289353647535762, 3.3040058012931164, 3.3185078904699297, 3.3328635938765525, 3.3470764491206584, 3.361149859930347, 3.3750871030014693, 3.3888913344061486, 3.4025655955961414, 3.416112819031695, 3.429535833463862, 3.4428373688958116, 3.4560200612464955, 3.4690864567380513, 3.4820390160265444, 3.494880118094029, 3.507612063918461, 3.520237079936645, 3.5327573213142096, 3.545174875035501, 3.557491762825275, 3.5697099439131748, 3.5818313176511283, 3.593857725993062, 3.6057909558456007, 3.617632741297821, 3.6293847657375102, 3.641048663860875, 3.652626023582124, 3.6641183878489225, 3.675527256369274, 3.686854087255032, 3.6981002985868603, 3.709267269905158, 3.720356343631146], [0.0, 0.9352484478226214, 1.1514259016263249, 1.3003593134073366, 1.4175715661678827, 1.5157165665103982, 1.6009301040424735, 1.6767040297197382, 1.7452353142041923, 1.8080055068809922, 1.8660659830736148, 1.9201926440425374, 1.9709761537475867, 2.018877657381617, 2.064264799022364, 2.107435899344471, 2.148636707054751, 2.1880723217343814, 2.2259158790933773, 2.2623150069288096, 2.29739670999407, 2.3312711247473685, 2.3640344462589735, 2.3957712387598797, 2.426556280522392, 2.456456052231581, 2.4855299491122493, 2.5138312766388577, 2.54140807498095, 2.568303806653012, 2.594557933960465, 2.620206406957157, 2.645282078198274, 2.6698150571970154, 2.693833014897924, 2.717361446466631, 2.740423899121549, 2.763042170492506, 2.7852364820067694, 2.8070256310161525, 2.82842712474619, 2.849457298636513, 2.870131421225042, 2.890463787387888, 2.9104678014666776, 2.9301560515835217, 2.949540376251655, 2.968631924229555, 2.9874412084321627, 3.0059781546000544, 3.0242521453322184, 3.0422720600074715, 3.0600463110510203, 3.0775828769442275, 3.094889332325648, 3.1119728754884557, 3.1288403535424547, 3.1454982854769784, 3.161952883333338, 3.1782100716715442, 3.194275505495155, 3.210154586779903, 3.2258524797358596, 3.2413741249189307, 3.256724252295235, 3.2719073933511478, 3.286927892332244, 3.3017899166860034, 3.3164974667756715, 3.331054384926067, 3.3454643638562533, 3.3597309545487635, 3.3738575736003877, 3.3878475100953915, 3.4017039320382603, 3.4154298923797617, 3.4290283346670827, 3.442502098346115, 3.455853923741525, 3.4690864567380513, 3.4822022531844965, 3.4952037830400844, 3.5080934342812395, 3.5208735165853713, 3.5335462648069154, 3.5461138422596736, 3.558578343818386, 3.570941798851473, 3.5832061739959613, 3.595373375784781, 3.6074452531358507, 3.6194235997116673, 3.631310156157488, 3.6431066122255915, 3.6548146087925857, 3.6664357397762077, 3.6779715539576427, 3.689423556714936, 3.700793211672718, 3.7120819422730804, 3.723291133272139, 3.734422132166491], [0.0, 0.9387403933595695, 1.1557249908658431, 1.305214476665242, 1.422864365867587, 1.521375811080145, 1.6069075111633213, 1.6829643546280488, 1.751751514985437, 1.8147560732948997, 1.8730333304094111, 1.927362084578959, 1.9783352051307068, 2.0264155590394606, 2.0719721630589545, 2.1153044517064163, 2.1566590912428136, 2.196241947031476, 2.2342268012207733, 2.2707618328070107, 2.305974520742369, 2.3399754127025423, 2.3728610629221976, 2.4047163513705585, 2.4356163355202387, 2.4656277442758388, 2.494810194626647, 2.5232171910742536, 2.550896953156214, 2.5778931056633962, 2.6042452582419853, 2.629989495172869, 2.6551587916731143, 2.67978336967608, 2.7038910034415626, 2.7275072833267244, 2.750655844468438, 2.773358565882537, 2.7956357444972144, 2.817506247848125, 2.8389876485276884, 2.8600963429673145, 2.8808476567132, 2.9012559380143634, 2.921334641260343, 2.941096401573634, 2.9605531016690336, 2.9797159319312403, 2.9985954445273593, 3.0172016022577934, 3.0355438227534264, 3.0536310185460906, 3.0714716334705403, 3.089073675797466, 3.106444748446919, 3.1235920765884035, 3.1405225328968416, 3.1572426607015736, 3.1737586952378662, 3.190076583186313, 3.2062020006646095, 3.2221403698178936, 3.2378968741378946, 3.2534764726271157, 3.2688839129119933, 3.284123743398154, 3.299200324551321, 3.3141178393790103, 3.32888030318066, 3.3434915726272116, 3.3579553542252665, 3.3722752122156927, 3.38645457595186, 3.4004967467985163, 3.414404904588554, 3.4281821136715704, 3.4418313285851014, 3.4553553993767028, 3.4687570766026163, 3.4820390160265444, 3.4952037830400844, 3.5082538568245702, 3.5211916342724345, 3.53401943368475, 3.546739498260249, 3.5593539993899177, 3.5718650397701484, 3.584274656346432, 3.5965848230986466, 3.6087974536781613, 3.6209144039062156, 3.6329374741423197, 3.644868411530795, 3.6567089121329635, 3.6684606229519874, 3.68012514385683, 3.691704029411374, 3.7031987906143087, 3.714610896555013, 3.7259417759902966, 3.7371928188465517, 3.748365377651537], [0.0, 0.9422022905843045, 1.1599870862936499, 1.3100278610752603, 1.4281116208426743, 1.526986357654484, 1.6128334824889967, 1.689170809223833, 1.7582116436334119, 1.8214485508511564, 1.8799407234802201, 1.9344698318314069, 1.9856309316219543, 2.033888596792627, 2.079613204961233, 2.1231052949029303, 2.1646124425372575, 2.2043412724201112, 2.2424662075755952, 2.279135973456158, 2.314478519132273, 2.348604799958578, 2.3816117262435164, 2.413584490977603, 2.4445984284312305, 2.4747205135925934, 2.5040105833071737, 2.532522339391055, 2.5603041792063386, 2.587399888423879, 2.613849222762753, 2.639688399575861, 2.664950515686638, 2.689665904481226, 2.713862442645644, 2.7375658149094564, 2.760799743571455, 2.783586188333152, 2.8059455209739763, 2.8278966786094895, 2.849457298636513, 2.8706438379533967, 2.891471678624058, 2.9119552218111466, 2.932107971521447, 2.951942609473399, 2.971471062203009, 2.9907045613629983, 3.009653698034872, 3.0283284717599575, 3.046738334899583, 3.0648922328533144, 3.0827986405951724, 3.100465595928838, 3.117900729812495, 3.135111294060708, 3.152104186693525, 3.16888597517085, 3.1854629177223184, 3.2018409829587586, 3.2180258679303155, 3.2340230147779754, 3.249837626109204, 3.26547467921437, 3.2809389392282586, 3.296234971330157, 3.3113671520663632, 3.326339679870534, 3.3411565848497733, 3.355821737897696, 3.3703388591898, 3.3847115261112006, 3.3989431806620747, 3.413037136381979, 3.42699658483043, 3.440824601657767, 3.4545241522973016, 3.4680980973070272, 3.4815491973867174, 3.494880118094029, 3.5080934342812395, 3.5211916342724345, 3.5341771237993336, 3.547052229712466, 3.5598192034830562, 3.572480224509771, 3.5850374032433496, 3.5974927841411533, 3.6098483484627244, 3.622106016916617, 3.6342676521679893, 3.646335061215737, 3.6583099976473195, 3.670194163778812, 3.6819892126872142, 3.6936967501415032, 3.7053183364385, 3.716855488149171, 3.72830967978062, 3.739682345358642, 3.750974879935414, 3.7621886410265626], [0.0, 0.9456347598290342, 1.164212951628277, 1.314800329140575, 1.4333142713409486, 1.5325492115789003, 1.618709079885476, 1.6953245056324464, 1.7646168577289483, 1.8280841387648485, 1.886789400011519, 1.9415171594265255, 1.9928646405316934, 2.0412981097236216, 2.087189293916118, 2.130839826755488, 2.1724981860872554, 2.212371749206342, 2.250635574564796, 2.287438929426042, 2.3229102289825883, 2.357160832802526, 2.390288004241258, 2.422377246649742, 2.4535041687432195, 2.483735989501637, 2.513132763757775, 2.5417483889649315, 2.5696314387981496, 2.5968258584407047, 2.623371548442868, 2.6493048580983665, 2.674659004803289, 2.699464432449148, 2.7237491192775076, 2.7475388435881203, 2.770857414100774, 2.7937268705167866, 2.816167658830548, 2.8381987851460604, 2.8598379511136733, 2.881101673584679, 2.9020053906602805, 2.922563555966966, 2.942789722706994, 2.962696618798659, 2.98229621422667, 3.0015997815609725, 3.0206179504666775, 3.0393607569137213, 3.0578376876986475, 3.0760577208093625, 3.094029362094454, 3.111760678639546, 3.1292593292026165, 3.146532592016792, 3.1635873902318012, 3.1804303152329867, 3.1970676480488898, 3.2135053790341552, 3.22974922599344, 3.2458046508936014, 3.2616768752953504, 3.2773708946214626, 3.292891491366243, 3.308243247340054, 3.3234305550330734, 3.33845762817397, 3.35332851155164, 3.3680470901614714, 3.382617097731666, 3.397042124679852, 3.4113256255455098, 3.425470925939513, 3.439481229048318, 3.453359621726945, 3.4671090802118614, 3.4807324754821534, 3.4942325782949006, 3.507612063918461, 3.5208735165853713, 3.53401943368475, 3.547052229712466, 3.559974239995828, 3.5727877242082355, 3.585494869687963, 3.598097794574183, 3.61059855077227, 3.6229991267595514, 3.635301450241776, 3.647507390669842, 3.659618761625594, 3.6716373230848585, 3.6835647835652963, 3.6954028021661123, 3.7071529905061453, 3.7188169145664207, 3.730396096442816, 3.7418920160141043, 3.7533061125302773, 3.7646397861257266, 3.7758943992615452], [0.0, 0.9490384013300432, 1.1684033258472732, 1.3195327154232157, 1.4384732271504903, 1.538065345630288, 1.6245353308191393, 1.7014265199514753, 1.7709682773525588, 1.8346639974019836, 1.8935805576321465, 1.9485052997312875, 2.0000375968194186, 2.048645393534808, 2.094701754755141, 2.1385093998025484, 2.180317700873673, 2.22033478168055, 2.2587363307665043, 2.2956721526555115, 2.3312711247473685, 2.3656450074288164, 2.3988914141371365, 2.4310961559771527, 2.4623351138040195, 2.4926757485402598, 2.522178331175176, 2.550896953156214, 2.578880362990585, 2.6061726640343146, 2.632813900452497, 2.658840552371575, 2.6842859567476545, 2.709180667049537, 2.733552762221413, 2.7574281133473684, 2.7808306148423765, 2.8037823857356794, 2.826303945613331, 2.848414368988371, 2.8701314212250417, 2.891471678624058, 2.9124506348532804, 2.9330827955624144, 2.9533817627360213, 2.9733603101042383, 2.993030450735572, 3.0124034977735485, 3.031490119142837, 3.0503003869360357, 3.068843822095698, 3.087129434924375, 3.1051657618859223, 3.1229608991019795, 3.140522532896841, 3.1578579677003193, 3.174974151580769, 3.1918776996480345, 3.208574915538084, 3.2250718111667616, 3.2413741249189303, 3.25748733842081, 3.2734166920271757, 3.2891671991409255, 3.304743659470089, 3.3201506713164264, 3.3353926429800915, 3.3504738033563073, 3.3653982117924572, 3.3801697672672697, 3.394792216947825, 3.4092691641748116, 3.423604075921701, 3.437800289769302, 3.4518610204333626, 3.4657893658794796, 3.479588313056546, 3.4932607432772196, 3.506809437271418, 3.520237079936645, 3.5335462648069154, 3.546739498260249, 3.5598192034830562, 3.5727877242082355, 3.585647328242471, 3.5984002107969677, 3.6110484976347554, 3.6235942480466736, 3.6360394576672137, 3.6483860611405525, 3.6606359346463404, 3.6727908982940813, 3.6848527183943167, 3.6968231096142086, 3.7087037370245897, 3.720496218045029, 3.7322021242930186, 3.7438229833429446, 3.755360280400137, 3.7668154598949077, 3.7781899270011783, 3.789485049083975], [0.0, 0.952413796109262, 1.172558924272542, 1.3242258277697823, 1.4435893689358648, 1.543535701445671, 1.6303132298658147, 1.7074778938312043, 1.7772669867295032, 1.8411892499837257, 1.9003153556332644, 1.9554354456629754, 2.0071510249516042, 2.0559317024514088, 2.102151869900231, 2.1461153232860317, 2.1880723217343814, 2.228231729179934, 2.2667698590281806, 2.3038370486049393, 2.3395626336814512, 2.3740587721367246, 2.407423424584599, 2.4397427073297258, 2.4710927711086903, 2.501541316778717, 2.531148829691755, 2.559969593679444, 2.588052530630239, 2.615441900760242, 2.6421778906575164, 2.6682971101954442, 2.6938330148979235, 2.7188162669016647, 2.7432750450177577, 2.7672353123446056, 2.790721048281188, 2.813754450526329, 2.8363561116470115, 2.858545173997589, 2.8803394661274373, 2.9017556232933237, 2.92280919426862, 2.9435147362945098, 2.963885899733015, 2.9839355037459248, 3.0036756041279924, 3.023117554259603, 3.042272060007472, 3.061149229287076, 3.079758616903603, 3.0981092652060718, 3.116209741019527, 3.134068169260658, 3.1516922635913027, 3.169089354420553, 3.1862664145285917, 3.2032300825528752, 3.2199866845491814, 3.2365422538156174, 3.2529025491464565, 3.26907307166413, 3.285059080361506, 3.300865606472387, 3.3164974667756715, 3.331959275927657, 3.3472554579072655, 3.362390256650409, 3.377367745942136, 3.3921918386284675, 3.406866295203835, 3.4213947318247397, 3.435780627795453, 3.450027332567382, 3.4641380722898845, 3.4781159559469277, 3.491963981110928, 3.5056850393423553, 3.5192819212612036, 3.5327573213142096, 3.5461138422596736, 3.5593539993899177, 3.572480224509771, 3.585494869687963, 3.5984002107969677, 3.61119845085558, 3.62389172318742, 3.6364820944074983, 3.648971567248073, 3.6613620832341685, 3.673655525218344, 3.6858537197835908, 3.6979584395225946, 3.709971405200983, 3.7218942878116574, 3.7337287105267793, 3.7454762505535286, 3.757138440899335, 3.7687167720518797, 3.7802126935788034, 3.791627615651737, 3.8029629104989393], [0.0, 0.9557615068072859, 1.1766804395959092, 1.3288804484696655, 1.4486635495007438, 1.5489611908722425, 1.6360437401367156, 1.7134796359680458, 1.7835140357842574, 1.8476609841967715, 1.9069949166304496, 1.9623087523994838, 2.014206110657239, 2.0631582510197095, 2.1095408812023404, 2.1536588650284, 2.1957633412780333, 2.236063908037406, 2.274737498449225, 2.311934978271252, 2.3477861378867324, 2.3824035294068175, 2.415885457774457, 2.448318341990961, 2.4797786004608526, 2.510334172008177, 2.5400457545893835, 2.568967822842426, 2.597149470614973, 2.624635113696682, 2.6514650799304675, 2.6776761078725033, 2.7033017706420175, 2.728372838152365, 2.7529175882624526, 2.7769620753303266, 2.8005303630419536, 2.823644727120515, 2.8463258325153524, 2.868592888865716, 2.890463787387888, 2.9119552218111466, 2.9330827955624144, 2.9538611170512135, 2.974303884620248, 2.9944239624903397, 3.0142334488320595, 3.0337437369326414, 3.0529655702896537, 3.0719090923476444, 3.0905838914967028, 3.1089990418694784, 3.127163140403192, 3.1450843405734124, 3.162770383155305, 3.180228624324168, 3.197466061369331, 3.214489356262896, 3.2313048572965686, 3.2479186189753486, 3.264336420335527, 3.280563781835842, 3.2966059809543915, 3.312468066609639, 3.32815487251134, 3.343671029536194, 3.359020977213298, 3.3742089743958923, 3.3892391091882796, 3.4041153081900353, 3.418841345113636, 3.4334208488262816, 3.4478573108619113, 3.4621540924451715, 3.4763144310652527, 3.490341446634124, 3.504238147260594, 3.518007434668895, 3.5316521092879807, 3.545174875035501, 3.558578343818386, 3.5718650397701484, 3.5850374032433496, 3.598097794574183, 3.6110484976347554, 3.62389172318742, 3.6366296120543753, 3.6492642381147316, 3.6617976111403014, 3.6742316794805205, 3.686568332606129, 3.6988094035205106, 3.7109566710469704, 3.7230118619995833, 3.7349766532447513, 3.746852673660043, 3.7586415059964833, 3.7703446886499847, 3.781963717347255, 3.7935000467511295, 3.804955091989956, 3.816330230115344], [0.0, 0.9590820784710499, 1.1807685428488637, 1.3334973353502206, 1.4536965949817957, 1.5543426972439125, 1.6417277946267566, 1.7194327235166733, 1.7897104416103653, 1.8540802537160692, 1.9136203281353112, 1.969126338996521, 2.021204002587801, 2.0703262158073708, 2.1168699916799865, 2.161141253207556, 2.203392011693664, 2.2438325934244094, 2.2826405462556636, 2.3199672600932693, 2.355942976247054, 2.3906806378643717, 2.4242788914258946, 2.456824456175708, 2.4883940160163553, 2.5190557458095677, 2.548870554392766, 2.5778931056633962, 2.6061726640343146, 2.6337537996075366, 2.6606769803357135, 2.6869790724146103, 2.712693765605471, 2.7378519367245766, 2.7624819618756966, 2.7866099859366993, 2.810260156197248, 2.8334548257723573, 2.856214731406941, 2.878559149479686, 2.900506033365755, 2.9220721347929173, 2.943273111398582, 2.9641236223458027, 2.984637413568997, 3.004827393982738, 3.024705703789885, 3.0442837758610044, 3.063572391019456, 3.0825817279508327, 3.101321408357861, 3.1198005378991596, 3.1380277433800132, 3.156011206603351, 3.173758695237866, 3.1912775910161804, 3.208574915538084, 3.2256573539211546, 3.2425312765127647, 3.259202758852888, 3.2756776000557353, 3.2919613397596, 3.308059273777953, 3.323976468570553, 3.3397177746407594, 3.3552878389541787, 3.3706911164640223, 3.3859318808199275, 3.401014234329368, 3.415942117233978, 3.430719316357123, 3.44534947317366, 3.459836091348054, 3.4741825437827454, 3.488392079214831, 3.502467828395689, 3.516412809885106, 3.5302299354886815, 3.5439220153648097, 3.557491762825275, 3.570941798851473, 3.584274656346432, 3.5974927841411533, 3.61059855077227, 3.6235942480466736, 3.6364820944074983, 3.6492642381147316, 3.661942760252696, 3.674519677575691, 3.686996945202241, 3.699376459167612, 3.711660058843534, 3.72384952923342, 3.735946603150762, 3.7479529632878434, 3.759870244181391, 3.7717000340813307, 3.7834438767283745, 3.7951032730457865, 3.80667968275029, 3.818174525886768, 3.829589184291076], [0.0, 0.9623760392991171, 1.1848238843201155, 1.3380772228130102, 1.4586893059783335, 1.559681076589167, 1.6473662974903183, 1.7253381034261697, 1.7958571898611986, 1.860448079645597, 1.9201926440425374, 1.9758892899177918, 2.0281458138879045, 2.077436737012252, 2.124140367164242, 2.1685636780362363, 2.210959546462915, 2.251539021094566, 2.290480259573955, 2.3279351717545196, 2.3640344462589735, 2.3988914141371365, 2.432605060670343, 2.4652624029393277, 2.4969403882169723, 2.527707425511103, 2.557624632850126, 2.586746861874269, 2.615123546194676, 2.642799408989072, 2.669815057197016, 2.696207483630968, 2.7220104937594276, 2.7472550704448895, 2.771969687248656, 2.796180578843001, 2.8199119754512885, 2.843186306960152, 2.8660243813347153, 2.888445541158255, 2.9104678014666776, 2.932107971521447, 2.9533817627360213, 2.9743038846202485, 2.9948881303188637, 3.0151474530820193, 3.035094034808017, 3.0547393476335403, 3.074094209408612, 3.093168833777451, 3.1119728754884557, 3.1305154714735677, 3.1488052781667757, 3.1668505054713534, 3.184658947734, 3.2022380120398473, 3.219594744104321, 3.236735852004991, 3.2536677279681427, 3.2703964684001505, 3.286927892332244, 3.303267558428566, 3.319420780691021, 3.335392642980092, 3.351188012458157, 3.3668115520507937, 3.3822677320117203, 3.3975608406683953, 3.412694994417638, 3.427674147033817, 3.442502098346115, 3.457182502336011, 3.4717188747012804, 3.4861145999285745, 3.5003729379127555, 3.514497030157746, 3.5284899055905545, 3.5423544860173575, 3.556093591248019, 3.5697099439131748, 3.5832061739959613, 3.5965848230986466, 3.6098483484627244, 3.6229991267595514, 3.6360394576672137, 3.648971567248073, 3.6617976111403014, 3.674519677575691, 3.687139790235071, 3.699659910951805, 3.712081942273081, 3.724407729887938, 3.736639064930371, 3.748777686165208, 3.7608252820639274, 3.7727834927770614, 3.7846539120093694, 3.7964380888035305, 3.808137529237719, 3.819753698042045, 3.8312880201385267, 3.842741882108925], [0.0, 0.965643901347317, 1.1888470944243388, 1.342620822814914, 1.4636424586218608, 1.5649771587746644, 1.652960125249136, 1.731196693705086, 1.801955236066722, 1.8667654518824914, 1.926712886037828, 1.982598656483765, 2.035032623682387, 2.0844909199856385, 2.1313531378562067, 2.175927293352055, 2.2184671219811642, 2.2591843890345604, 2.2982578571104275, 2.335839951890138, 2.3720618057651324, 2.4070371346142596, 2.440865259835124, 2.473633493985284, 2.5054190456212178, 2.5362905560416564, 2.5663093508085235, 2.595530467817301, 2.624003508536826, 2.6517733480076813, 2.6788807310551066, 2.7053627761050487, 2.7312534034164853, 2.7565837010578984, 2.781382239275947, 2.805675341825847, 2.8294873212075617, 2.8528406834710673, 2.8757563072374013, 2.8982536007698783, 2.920350640276596, 2.942064292096862, 2.963410320994101, 2.9844034864260487, 3.0050576283737005, 3.0253857440715057, 3.0454000567828476, 3.065112077599412, 3.0845326611045145, 3.103672055624015, 3.1225399486901564, 3.1411455082604167, 3.159497420162733, 3.1776039221780805, 3.195472835119787, 3.2131115912246218, 3.2305272601325727, 3.2477265726992828, 3.264715942856601, 3.281501487711973, 3.29808904605584, 3.314484195427447, 3.330692267873024, 3.3467183645159047, 3.362567369045495, 3.3782439602208902, 3.3937526234750846, 3.409097661697062, 3.4242832052613554, 3.439313221367843, 3.45419152274848, 3.4689217757922712, 3.4835075081349625, 3.4979521157556306, 3.5122588696184973, 3.526430921894835, 3.5404713117967335, 3.5543829710517083, 3.568168729044623, 3.5818313176511283, 3.595373375784781, 3.6087974536781613, 3.622106016916617, 3.635301450241776, 3.6483860611405525, 3.6613620832341685, 3.6742316794805205, 3.686996945202241, 3.699659910951805, 3.712222545224216, 3.7246867570269866, 3.7370543983164115, 3.749327266308494, 3.7615071056722442, 3.7735956106125457, 3.785594426849257, 3.7975051534987507, 3.8093293448636643, 3.8210685121362387, 3.83272412502025, 3.8442976132762077, 3.8557903681941754], [0.0, 0.9688861611972635, 1.1928387845252129, 1.3471288257976295, 1.468556805589356, 1.570231748588672, 1.6585101279366483, 1.7370093846199548, 1.8080055068809922, 1.8730333304094111, 1.9331820449317627, 1.989255458244234, 2.041865478485167, 2.091489836675339, 2.138509399802548, 2.1832332181239034, 2.225915879093377, 2.2667698590281806, 2.305974520742369, 2.3436828017039746, 2.3800262745964407, 2.415119037112687, 2.4490607441332704, 2.481939001377648, 2.5138312766388577, 2.5448064416866427, 2.574926027990515, 2.6042452582419857, 2.632813900452497, 2.6606769803357135, 2.6878753795222865, 2.7144463410675224, 2.740423899121549, 2.765839246134594, 2.790721048281188, 2.815095717701565, 2.8389876485276884, 2.8624194223761714, 2.8854119879704094, 2.9079848187391812, 2.930156051583521, 2.951942609473399, 2.973360310104238, 2.9944239624903397, 3.015147453082019, 3.035543822753427, 3.0556253358089513, 3.075403541990085, 3.0948893323256486, 3.114092989551429, 3.1330242337266654, 3.1516922635913027, 3.1701057941369384, 3.1882730908038392, 3.206202000664609, 3.223899980910602, 3.2413741249189307, 3.258631186144855, 3.2756776000557353, 3.2925195042979043, 3.3091627572662095, 3.325612955227123, 3.341875448129829, 3.357955354225267, 3.3738575736003877, 3.389586800723756, 3.405147536088721, 3.420544097031707, 3.4357806277954532, 3.450861108900164, 3.4657893658794796, 3.4805690774327243, 3.4952037830400844, 3.5096968900830254, 3.5240516805084057, 3.5382713170712727, 3.5523588491882183, 3.566317218430369, 3.580149263682572, 3.593857725993062, 3.6074452531358507, 3.6209144039062156, 3.6342676521679893, 3.647507390669842, 3.6606359346463404, 3.673655525218344, 3.686568332606129, 3.699376459167612, 3.712081942273081, 3.7246867570269866, 3.7371928188465517, 3.7496019859062275, 3.7619160614563745, 3.7741367960239285, 3.786265889502261, 3.7983049931369215, 3.8102557114135, 3.8221196038533822, 3.8338981867228106, 3.845592934660259, 3.8572052822268215, 3.8687366253839772], [0.0, 0.9721033005900913, 1.1967995477156448, 1.3516019015688139, 1.4734330770638384, 1.5754456267681387, 1.6640171301828106, 1.7427770398314473, 1.8140089012647542, 1.8792526465196684, 1.939601081924274, 1.995860684279465, 2.0486453935348075, 2.098434526993707, 2.1456102162942767, 2.19048253787998, 2.233306924550052, 2.2742965581389853, 2.313631397026339, 2.3514648865015713, 2.387929036128825, 2.4231383224568623, 2.457192731265425, 2.490180159164504, 2.522178331175176, 2.553256347752548, 2.583475944678384, 2.6128925280084587, 2.6415560310064765, 2.6695116288917946, 2.6968003390405313, 2.7234595281717477, 2.749523343444313, 2.775023080881468, 2.799987501842383, 2.82444310616752, 2.8484143689883705, 2.8719239469027085, 2.894992858193147, 2.9176406409490374, 2.9398854922941138, 2.9617443913902433, 2.9832332084547386, 3.004366801674513, 3.0251591036091643, 3.045623198434433, 3.065771391177733, 3.0856152699309116, 3.105165761885922, 3.124433183921875, 3.1434272883729935, 3.1621573045231917, 3.1806319763017727, 3.1988595965939965, 3.216848038528289, 3.234604784057246, 3.2521369501111943, 3.2694513125699136, 3.2865543282694203, 3.3034521552358034, 3.3201506713164264, 3.336655491359891, 3.352971983079629, 3.3691052817214815, 3.3850603036429017, 3.400841758900208, 3.416454162930418, 3.4319018474054634, 3.4471889703288388, 3.4623195254378736, 3.4772973509687044, 3.4921261378356, 3.506809437271418, 3.521350667971667, 3.5357531227807515, 3.5500199749554935, 3.564154284037924, 3.578159001366514, 3.5920369752524883, 3.6057909558456007, 3.6194235997116673, 3.6329374741423197, 3.646335061215737, 3.659618761625594, 3.6727908982940813, 3.6858537197835908, 3.6988094035205106, 3.711660058843534, 3.724407729887938, 3.7370543983164115, 3.7496019859062275, 3.762052357001814, 3.774407320841138, 3.7866686337636746, 3.798838001307208, 3.810917080200169, 3.8229074802557634, 3.834810766173692, 3.8466284592548856, 3.8583620390342834, 3.87001294483637, 3.881582577257847], [0.0, 0.9752957870275873, 1.2007299595578473, 1.356040700137889, 1.478271981645511, 1.5806195509729188, 1.6694819322430907, 1.7485004974720746, 1.8199662916071895, 1.885424303979324, 1.945970929804059, 2.0024152944344005, 2.055373354061357, 2.1053260001152716, 2.1526566191935514, 2.1976763060623417, 2.240641332388256, 2.281765580116686, 2.321229598628872, 2.3591873371442627, 2.3957712387598797, 2.4310961559771527, 2.4652624029393277, 2.4983581649178315, 2.5304614221906427, 2.5616415021458128, 2.591960343311715, 2.6214735337032633, 2.6502311705700956, 2.6782785774916005, 2.705656906549144, 2.732403647177907, 2.758553058679511, 2.784136539856533, 2.8091829465233795, 2.8337188655486942, 2.857768852442798, 2.881355638210043, 2.904500310159228, 2.927222470544784, 2.949540376251655, 2.9714710622030096, 2.9930304507355725, 3.01423344883206, 3.035094034808017, 3.055625335808952, 3.0758396972732447, 3.095748745349219, 3.115363443114841, 3.1346941413309057, 3.1537506243592968, 3.1725421517938384, 3.191077496279789, 3.2093649779370916, 3.2274124957503285, 3.245227556243591, 3.2628172997199316, 3.2801885243118107, 3.2973477080601534, 3.314301029214634, 3.331054384926067, 3.3476134084827907, 3.3639834852263535, 3.3801697672672697, 3.3961771871088113, 3.412010470275602, 3.427674147033817, 3.4431725632810384, 3.4585098906760696, 3.473690136072081, 3.488717150310369, 3.50359463642654, 3.5183261573160634, 3.5329151429017935, 3.5473648968421707, 3.5616786028153165, 3.575859330411111, 3.58991004066052, 3.603833591228915, 3.617632741297821, 3.631310156157488, 3.644868411530795, 3.6583099976473195, 3.6716373230848585, 3.6848527183943167, 3.6979584395225946, 3.7109566710469704, 3.72384952923342, 3.736639064930371, 3.749327266308494, 3.7619160614563745, 3.774407320841138, 3.7868028596424743, 3.799104439967855, 3.811313772956225, 3.823432520776881, 3.8354622985298192, 3.847404676053374, 3.8592611796445837, 3.8710332936973315, 3.88272246226299, 3.894330090537963], [0.0, 0.9784640743427232, 1.2046305787857485, 1.360445852509303, 1.483074207216527, 1.5857542567104117, 1.6749053109750902, 1.7541805711690328, 1.8258785247905682, 1.8915491801301296, 1.9522924940869435, 2.008920220490039, 2.062050316488712, 2.1121652357083214, 2.159649610192949, 2.2048155453125107, 2.247920145242365, 2.2891779867319446, 2.328770205684366, 2.366851251429265, 2.4035539973103535, 2.438993668931999, 2.473270906311949, 2.5064741811950055, 2.5386817271811943, 2.569963096871357, 2.600380430003648, 2.6299894951728695, 2.6588405523715752, 2.6869790724146108, 2.7144463410675224, 2.7412799695514183, 2.7675143284606305, 2.793180918597999, 2.8183086895171963, 2.8429243144553706, 2.8670524286923986, 2.8907158370752084, 2.9139356954155633, 2.9367316696466, 2.9591220759614836, 2.98112400462201, 3.002753429689251, 3.024025306571852, 3.0449536589944737, 3.065551656746681, 3.085831685371504, 3.105805408785273, 3.1254838256799506, 3.1448773204411915, 3.163995709215771, 3.1828482816776718, 3.2014438389704427, 3.219790728242267, 3.237896874137895, 3.2557698075666606, 3.273416692027176, 3.2908443477359075, 3.308059273777953, 3.325067668473279, 3.3418754481298296, 3.3584882643359046, 3.3749115199275512, 3.3911503837521186, 3.407209804336313, 3.4230945225558145, 3.438809083393548, 3.454357846864918, 3.4697449981805284, 3.4849745572099717, 3.5000503873041553, 3.514976203528146, 3.5297555803516207, 3.544391958839675, 3.558888653382816, 3.5732488580014707, 3.587475652257204, 3.6015720068000103, 3.6155407885785, 3.6293847657375102, 3.6431066122255915, 3.6567089121329635, 3.670194163778812, 3.6835647835652963, 3.6968231096142086, 3.709971405200983, 3.7230118619995833, 3.735946603150762, 3.748777686165208, 3.7615071056722442, 3.7741367960239285, 3.7866686337636746, 3.799104439967855, 3.8114459824682183, 3.823694977962413, 3.835853094019358, 3.847921950985767, 3.8599031237996573, 3.8717981437163034, 3.883608499951701, 3.8953356412482822, 3.906980977367288], [0.0, 0.9816086032414625, 1.208501947972033, 1.3648179714358555, 1.487840421762217, 1.5908504582136447, 1.6802880207659951, 1.75981805101555, 1.8317464232012974, 1.8976281269369415, 1.9585666540969286, 2.0153763672758434, 2.068677209576441, 2.11895318510448, 2.166590162011333, 2.2119012486923535, 2.25514437558881, 2.296534809043967, 2.3362542670845934, 2.3744576954002774, 2.411278394355079, 2.446831959858471, 2.4812193553590265, 2.5145293369267128, 2.5468403895839864, 2.578222289455647, 2.608737375980797, 2.6384415969799875, 2.6673853739683095, 2.6956143238919745, 2.7231698651982352, 2.7500897299808753, 2.776408399292373, 2.802157475170951, 2.8273660002066134, 2.852060733357351, 2.8762663890744187, 2.9000058454935886, 2.9233003264158963, 2.946169560975671, 2.968631924229555, 2.990704561362999, 3.012403497773549, 3.0337437369326414, 3.0547393476335403, 3.0754035419900854, 3.095748745349219, 3.1157866591120635, 3.1355283173175152, 3.154984137723942, 3.174163968024659, 3.1930771277482455, 3.2117324463228343, 3.2301382977221706, 3.2483026320587505, 3.266233004444291, 3.283936601399025, 3.301420265057818, 3.318690515392138, 3.3357535706417383, 3.352615366128036, 3.369281571602066, 3.385757607263184, 3.4020486585700698, 3.4181596899527067, 3.4340954575227154, 3.4498605208694126, 3.4654592540201583, 3.4808958556357337, 3.496174358504546, 3.5112986383933076, 3.526272422306337, 3.541099296200726, 3.5557827122002594, 3.570325995347032, 3.584732349926221, 3.599004865396301, 3.6131465219541625, 3.627160195762042, 3.641048663860875, 3.6548146087925857, 3.6684606229519874, 3.6819892126872142, 3.6954028021661123, 3.7087037370245897, 3.7218942878116574, 3.7349766532447513, 3.7479529632878434, 3.7608252820639274, 3.7735956106125457, 3.786265889502261, 3.798838001307208, 3.811313772956225, 3.823694977962413, 3.835983338540438, 3.8481805276183536, 3.8602881707502443, 3.8723078479355695, 3.8842410953506588, 3.896089406997462, 3.9078542362742907, 3.9195369974729917], [0.0, 0.9847298018175752, 1.2123445941619542, 1.3691576521344881, 1.4925712741513997, 1.5959088492756097, 1.6856307944138174, 1.7654137044938396, 1.8375707856905992, 1.9036619719829493, 1.9647942639933809, 2.0217846137267204, 2.075254935504724, 2.125690772410009, 2.1734792195301433, 2.2189343808441326, 2.2623150069288096, 2.3038370486049398, 2.3436828017039746, 2.382007704592791, 2.4189454814875875, 2.4546120958555253, 2.4891088321763615, 2.5225247287357218, 2.554938520113106, 2.5864202042988724, 2.617032318951422, 2.646830989787321, 2.6758667986458047, 2.704185507520253, 2.7318286665552143, 2.758834127820354, 2.7852364820067694, 2.8110674316369657, 2.8363561116470115, 2.861129366079748, 2.8854119879704094, 2.909226928199856, 2.932595478053962, 2.9555374293993366, 2.9780712157193716, 3.000214036715675, 3.021981968741386, 3.043390062974138, 3.0644524329414162, 3.0851823327673196, 3.1055922273073837, 3.1256938551694105, 3.1454982854769784, 3.1650159691135653, 3.1842567850849735, 3.203230082552875, 3.2219447190201347, 3.240409095087032, 3.258631186144855, 3.2766185713281377, 3.2943784600079287, 3.3119177160748743, 3.329242880231847, 3.3463601904905955, 3.3632756010449443, 3.379994799673907, 3.396523223811324, 3.4128660754039597, 3.4290283346670827, 3.445014772835214, 3.460829963995693, 3.4764782960838754, 3.491963981110928, 3.507291064688224, 3.522463434906163, 3.5374848306197353, 3.5523588491882183, 3.567088953712036, 3.5816784798058445, 3.596130641943414, 3.610448539406699, 3.624635161868656, 3.638693394636788, 3.652626023582124, 3.6664357397762077, 3.68012514385683, 3.6936967501415032, 3.7071529905061453, 3.720496218045029, 3.7337287105267793, 3.746852673660043, 3.759870244181391, 3.7727834927770614, 3.785594426849257, 3.7983049931369215, 3.810917080200169, 3.823432520776881, 3.835853094019358, 3.8481805276183536, 3.8604164998212913, 3.8725626413509944, 3.8846205372308096, 3.896591728521612, 3.908477713975795, 3.9202799516130087, 3.931999860222091], [0.0, 0.9878280860420744, 1.2161590294759013, 1.3734654729667923, 1.497267394878231, 1.6009301040424735, 1.6909343439651996, 1.7709682773525588, 1.843352388487831, 1.9096515194158463, 1.9709761537475867, 2.0281458138879045, 2.0817843709058064, 2.1323788955623346, 2.180317700873673, 2.2259158790933773, 2.2694329949128007, 2.3110856786051026, 2.3510567995644505, 2.3895022852180072, 2.426556280522392, 2.4623351138040195, 2.496940388216972, 2.5304614221906423, 2.562977198029445, 2.594557933960465, 2.625266364406171, 2.6551587916731147, 2.684285956747655, 2.712693765605471, 2.740423899121549, 2.76751432846063, 2.7939997531475163, 2.819911975451288, 2.845280221976117, 2.870131421225042, 2.8944904442403514, 2.918380314113934, 2.9418223891210604, 2.9648365234000695, 2.9874412084321627, 3.009653698034872, 3.031490119142837, 3.0529655702896537, 3.0740942094086114, 3.0948893323256486, 3.1153634431148407, 3.135528317317515, 3.1553950588843582, 3.174974151580769, 3.194275505495155, 3.2133084992047287, 3.232082018080977, 3.2506044891552333, 3.268883912911993, 3.286927892332244, 3.304743659470089, 3.3223380998122347, 3.3397177746407594, 3.3568889415942507, 3.3738575736003877, 3.390629376333809, 3.4072098043363126, 3.423604075921701, 3.43981718697464, 3.455853923741525, 3.4717188747012804, 3.4874164415951516, 3.5029508496866795, 3.5183261573160634, 3.533546264806915, 3.5486149227778934, 3.563535739906754, 3.578312190189974, 3.592947619737152, 3.6074452531358507, 3.6218081994193883, 3.6360394576672137, 3.6501419222649596, 3.6641183878489225, 3.6779715539576427, 3.691704029411374, 3.7053183364385, 3.7188169145664207, 3.7322021242930186, 3.7454762505535286, 3.7586415059964833, 3.7717000340813307, 3.7846539120093694, 3.7975051534987507, 3.8102557114135, 3.8229074802557634, 3.8354622985298192, 3.847921950985767, 3.8602881707502443, 3.8725626413509944, 3.8847469986416305, 3.896842832632505, 3.908851689233179, 3.920775071911613, 3.932614443274868, 3.9443712265757584], [0.0, 0.990903860228776, 1.2199457516825694, 1.3777419960863195, 1.5019293967678595, 1.6059148777680887, 1.6961993615123458, 1.7764824944414586, 1.8490919860692505, 1.9155975508478424, 1.9771131300716664, 2.0344607978708136, 2.0882663678451383, 2.139018427335031, 2.187106498436643, 2.2328466544979477, 2.2764992684100136, 2.3182816449619517, 2.358377222943526, 2.3969424152890055, 2.434111784638613, 2.4700020215271965, 2.504715045467893, 2.538340452998526, 2.5709574723486224, 2.602636540381904, 2.6334405868553517, 2.66342608938252, 2.6926439469406347, 2.7211402084415983, 2.7489566845410347, 2.776131464633496, 2.802699356286777, 2.828692260791843, 2.854139495754969, 2.8790680735257634, 2.9035029425868197, 2.927467197716419, 2.9509822636925294, 2.9740680564727944, 2.996743125114852, 3.01902477715899, 3.0409291897538577, 3.062471508444955, 3.0836659352487543, 3.1045258073900555, 3.125063667876539, 3.1452913289147233, 3.1652199290293734, 3.1848599846289103, 3.2042214366585218, 3.223313692897249, 3.2421456663827244, 3.2607258103853063, 3.2790621503003865, 3.2971623127821545, 3.315033552402968, 3.332682776088692, 3.350116565551095, 3.3673411979130083, 3.3843626646998586, 3.4011866893518916, 3.4178187433945686, 3.434264061389818, 3.4505276547778587, 3.466614324707896, 3.482528673945879, 3.4982751179386384, 3.513857895105807, 3.52928107642393, 3.544548574360954, 3.5596641512137404, 3.574631426896288, 3.5894538862219667, 3.6041348857190667, 3.6186776600154644, 3.633085327824992, 3.6473608975652536, 3.661507272634054, 3.675527256369274, 3.689423556714936, 3.7031987906143087, 3.716855488149171, 3.730396096442816, 3.7438229833429446, 3.757138440899335, 3.7703446886499847, 3.7834438767283745, 3.7964380888035305, 3.8093293448636643, 3.8221196038533822, 3.834810766173692, 3.847404676053374, 3.8599031237996573, 3.8723078479355695, 3.8846205372308096, 3.896842832632505, 3.9089763291017823, 3.9210225773616587, 3.9329830855614043, 3.9448593208621605, 3.9566527109482865], [0.0, 0.9939575174773807, 1.2237052447444592, 1.3819877680546362, 1.5065578756480142, 1.6108638075320787, 1.7014265199514753, 1.7819570605057367, 1.854790311984838, 1.9215008262122208, 1.983205977302639, 2.040730372762757, 2.094701754755141, 2.145610216294277, 2.1938464798621666, 2.2397275928464535, 2.283514730526407, 2.3254258673568575, 2.365645007428817, 2.4043290456925295, 2.441612959468389, 2.4776137988951477, 2.5124337975701567, 2.54616282813988, 2.5788803629905854, 2.6106570560504836, 2.6415560310064765, 2.671633939518544, 2.7009418374187164, 2.729525915527308, 2.757428113347368, 2.784686637653107, 2.8113364032784083, 2.837409409824086, 2.8629350652441516, 2.887940465131866, 2.9124506348532804, 2.936488740357594, 2.960076272447272, 2.9832332084547386, 3.0059781546000544, 3.028328471759958, 3.050300386936036, 3.071909092347645, 3.0931688337774506, 3.114092989551429, 3.1346941413309053, 3.154984137723942, 3.174974151580769, 3.1946747317181057, 3.214095849716039, 3.233246942345455, 3.2521369501111943, 3.2707743523339636, 3.2891671991409255, 3.3073231406892423, 3.3252494539076065, 3.3429530670068783, 3.360440581981613, 3.377718295298781, 3.394792216947825, 3.411668088006852, 3.428351396862862, 3.4448473942090727, 3.4611611069294033, 3.477297350968705, 3.4932607432772196, 3.5090557129088107, 3.524686511344601, 3.5401572221066173, 3.5554717697198153, 3.570633928075284, 3.5856473282424712, 3.600515465773855, 3.6152417075415024, 3.629829298141406, 3.6442813658983026, 3.6586009285008037, 3.6727908982940813, 3.686854087255032, 3.700793211672718, 3.714610896555013, 3.72830967978062, 3.7418920160141043, 3.755360280400137, 3.7687167720518797, 3.781963717347255, 3.7951032730457865, 3.808137529237719, 3.8210685121362387, 3.8338981867228106, 3.8466284592548856, 3.8592611796445837, 3.8717981437163034, 3.8842410953506588, 3.896591728521612, 3.908851689233179, 3.9210225773616587, 3.9331059484089153, 3.9451033151718646, 3.9570161493329823, 3.9688458829763067], [0.0, 0.9969894400953796, 1.2274379793373027, 1.3862033204279376, 1.5111534109884928, 1.6157775129236005, 1.7066164737050282, 1.7873926609424253, 1.860448079645597, 1.9273620845789587, 1.9892554582442339, 2.0469553234931666, 2.1010913373243465, 2.1521550877096094, 2.200538488972971, 2.246559555608948, 2.2904802595739544, 2.3325192402221417, 2.372861062922197, 2.411663101209558, 2.44906074413327, 2.485171398876484, 2.5200976108852475, 2.5539295269494406, 2.5867468618742686, 2.618620485107458, 2.6496137128855235, 2.67978336967608, 2.709180667049537, 2.737851936724577, 2.765839246134594, 2.7931809185979986, 2.819911975451288, 2.846064513905397, 2.871668031619018, 2.8967497068365717, 2.921334641260343, 2.945446071503884, 2.969105553924223, 2.9923331267917264, 3.0151474530820184, 3.037565946628664, 3.059604883931354, 3.0812795035510967, 3.102604094725243, 3.1235920765884035, 3.1442560691804284, 3.1646079572518326, 3.1846589477339995, 3.2044196216212764, 3.2238999809106015, 3.2431094911583584, 3.2620571201410935, 3.2807513730444464, 3.2992003245513204, 3.3174116481545677, 3.3353926429800915, 3.35315025837225, 3.370691116464022, 3.3880215329288323, 3.4051475360887205, 3.422074884534118, 3.438809083393547, 3.4553553993767028, 3.47171887470128, 3.4879043400024687, 3.503916426313845, 3.5197595761994553, 3.5354380541089467, 3.5509559560205357, 3.566317218430369, 3.5815256267412408, 3.5965848230986466, 3.611498313717739, 3.626269475740738, 3.640901563660803, 3.6553977153451696, 3.6697609576874695, 3.683994211916559, 3.6981002985868603, 3.7120819422730804, 3.7259417759902966, 3.739682345358642, 3.7533061125302773, 3.7668154598949077, 3.7802126935788034, 3.7935000467511295, 3.80667968275029, 3.819753698042045, 3.83272412502025, 3.845592934660259, 3.8583620390342834, 3.8710332936973315, 3.883608499951701, 3.896089406997462, 3.908477713975795, 3.920775071911613, 3.9329830855614043, 3.9451033151718646, 3.957137278154477, 3.9690864506808694, 3.980952269203444], [0.0, 1.0, 1.2311444133449163, 1.3903891703159093, 1.515716566510398, 1.6206565966927624, 1.711769859409705, 1.7927899625209973, 1.8660659830736148, 1.9331820449317627, 1.9952623149688795, 2.053136413658844, 2.107435899344471, 2.15865384442158, 2.2071833466585673, 2.2533433808426553, 2.2973967099940698, 2.3395626336814512, 2.3800262745964407, 2.4189454814875875, 2.4564560522315806, 2.4926757485402593, 2.527707425511103, 2.5616415021458128, 2.594557933960465, 2.6265278044037674, 2.6576146209051537, 2.6878753795222865, 2.717361446466631, 2.746119293362479, 2.7741911146721807, 2.8016153494371836, 2.82842712474619, 2.854658634732502, 2.8803394661274373, 2.9054968792442244, 2.930156051583521, 2.9543402899253386, 2.9780712157193716, 3.001368927744568, 3.0242521453322184, 3.046738334899583, 3.0688438220956975, 3.0905838914967028, 3.1119728754884552, 3.1330242337266654, 3.1537506243592963, 3.174163968024659, 3.194275505495155, 3.2140958497160383, 3.2336350328867867, 3.2529025491464565, 3.2719073933511478, 3.2906580963691905, 3.3091627572662095, 3.327429072706326, 3.345464363856254, 3.3632756010449447, 3.380869426401905, 3.3982521746716885, 3.4154298923797617, 3.432408355505487, 3.449193085800954, 3.4657893658794796, 3.4822022531844965, 3.4984365929380252, 3.5144970301577456, 3.5303880208226968, 3.5461138422596736, 3.561678602815316, 3.5770862508726156, 3.592340583264959, 3.6074452531358507, 3.622403777287988, 3.6372195430613807, 3.651895814776621, 3.6664357397762077, 3.6808423540939335, 3.6951185877797466, 3.709267269905158, 3.723291133272139, 3.7371928188465517, 3.750974879935414, 3.7646397861257266, 3.7781899270011783, 3.791627615651737, 3.804955091989956, 3.818174525886768, 3.8312880201385267, 3.8442976132762077, 3.8572052822268215, 3.87001294483637, 3.88272246226299, 3.8953356412482822, 3.9078542362742907, 3.9202799516130087, 3.932614443274868, 3.9448593208621605, 3.9570161493329823, 3.9690864506808694, 3.9810717055349722, 3.9929733546852773], [0.0, 1.002989559101324, 1.2348249923308758, 1.3945458209144095, 1.5202478907668366, 1.625501645371526, 1.7168872965722752, 1.798149614070214, 1.8716446976169836, 1.9389614069087044, 2.0012272695821234, 2.0592743863105576, 2.113736203517813, 2.165107267668778, 2.2137818517208614, 2.2600798840552616, 2.3042649132377844, 2.346556894446091, 2.3871415038070505, 2.426177061967375, 2.4637997727795318, 2.5001277500109573, 2.535264156250524, 2.569299680812882, 2.6023145182458487, 2.634379964506303, 2.665559716882892, 2.695910941826362, 2.725485159110502, 2.754328979289272, 2.782484722967861, 2.809990944103502, 2.8368828747994064, 2.863192805435139, 2.888950411193301, 2.9141830338834374, 2.938915926275832, 2.9631724648274926, 2.9869743356267167, 3.0103416975389377, 3.033293325857995, 3.0558467392180346, 3.0780183120745854, 3.0998233746979316, 3.121276302321445, 3.1423905948392714, 3.1631789482416557, 3.1836533188043616, 3.203824980904744, 3.2237045792160846, 3.2433021759297134, 3.262627293567977, 3.2816889538776297, 3.300495713230536, 3.3190556949049568, 3.3373766185746447, 3.3554658272933753, 3.373330312228309, 3.3909767353659923, 3.408411450389072, 3.4256405218994592, 3.442669743144149, 3.459504652382834, 3.4761505480215167, 3.492612502623155, 3.5088953758948476, 3.5250038267408295, 3.540942324461552, 3.5567151591711315, 3.5723264514983533, 3.5877801616301324, 3.603080097750714, 3.6182299239248907, 3.63323316746905, 3.648093225849853, 3.662813373146773, 3.677396766111475, 3.6918464498541534, 3.706165363184315, 3.720356343631146, 3.734422132166491, 3.748365377651537, 3.7621886410265626, 3.7758943992615452, 3.789485049083975, 3.8029629104989393, 3.816330230115344, 3.829589184291076, 3.842741882108925, 3.8557903681941754, 3.8687366253839772, 3.881582577257847, 3.894330090537963, 3.906980977367288, 3.9195369974729917, 3.931999860222091, 3.9443712265757584, 3.9566527109482865, 3.9688458829763067, 3.980952269203444, 3.9929733546852773, 4.004910584519121]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 0.7000000000000001\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.19952623149688795, 0.2543082787833218, 0.29308422203197615, 0.32413131933855244, 0.3504608431930435, 0.37355360989045344, 0.39426144927002865, 0.4131250177099655, 0.4305116202499342, 0.4466835921509631, 0.4618356349920818, 0.47611672335935123, 0.4896437025691147, 0.5025101201094091, 0.5147921795009975, 0.526552881733695, 0.537844983726624, 0.5487131607739881, 0.5591956190625977, 0.569325319425153, 0.5791309206293913, 0.5886375166538975, 0.5978672201788909, 0.6068396296020863, 0.615572206672458, 0.6240805847094171, 0.6323788223236478, 0.6404796139209262, 0.6483944656184197, 0.6561338432438416, 0.6637072976235352, 0.6711235712592635, 0.6783906896492914, 0.6855160398591242, 0.6925064384421088, 0.6993681904144294, 0.7061071406767596, 0.7127287190266077, 0.7192379797067615, 0.7256396362752623, 0.7319380924527448, 0.7381374694973788, 0.7442416305711558, 0.7502542024900443, 0.756178595191623, 0.7620180192048306, 0.7677755013655932, 0.7734538989878239, 0.7790559126704492, 0.7845840978967508, 0.7900408755616531, 0.7954285415450065, 0.8007492754339072, 0.8060051484842448, 0.8111981309006187, 0.8163300985042546, 0.8214028388503244, 0.8264180568489509, 0.8313773799379874, 0.8362823628502692, 0.841134492013326, 0.8459351896154252, 0.8506858173682023, 0.8553876799929504, 0.8600420284548512, 0.8646500629669478, 0.8692129357834798, 0.8737317538002617, 0.8782075809780603, 0.8826414406034021, 0.8870343173998728, 0.8913871595017524, 0.8957008803007452, 0.8999763601755812, 0.9042144481133959, 0.9084159632310074, 0.9125816962034995, 0.9167124106068887, 0.9208088441810696, 0.9248717100187196, 0.9289016976853711, 0.9328994742754345, 0.9368656854085666, 0.9408009561704318, 0.9447058920015806, 0.9485810795378828, 0.952427087405685, 0.9562444669746236, 0.960033753070801, 0.9637954646528334, 0.9675301054530917, 0.9712381645862905, 0.9749201171274217, 0.9785764246608916, 0.9822075358025828, 0.98581388669645, 0.9893959014871396, 0.992953992770028, 0.996488562019974, 1.0, 1.003488687151026], [0.0, 0.2543082787833218, 0.32413131933855244, 0.37355360989045344, 0.4131250177099655, 0.4466835921509631, 0.4761167233593513, 0.5025101201094091, 0.526552881733695, 0.5487131607739881, 0.569325319425153, 0.5886375166538976, 0.6068396296020863, 0.6240805847094171, 0.6404796139209262, 0.6561338432438416, 0.6711235712592635, 0.6855160398591242, 0.6993681904144294, 0.7127287190266077, 0.7256396362752623, 0.7381374694973787, 0.7502542024900443, 0.7620180192048306, 0.7734538989878238, 0.7845840978967507, 0.7954285415450065, 0.8060051484842448, 0.8163300985042546, 0.8264180568489509, 0.8362823628502692, 0.8459351896154252, 0.8553876799929504, 0.8646500629669477, 0.8737317538002618, 0.8826414406034022, 0.8913871595017524, 0.8999763601755811, 0.9084159632310074, 0.9167124106068887, 0.9248717100187196, 0.9328994742754344, 0.9408009561704319, 0.9485810795378828, 0.9562444669746236, 0.9637954646528334, 0.9712381645862904, 0.9785764246608915, 0.98581388669645, 0.9929539927700279, 1.0, 1.00695499396372, 1.0138219008992493, 1.0206034988224855, 1.027302427674634, 1.0339211986009056, 1.0404622024491779, 1.0469277175668923, 1.0533199169653644, 1.059640874912806, 1.065892573010474, 1.0720769058003736, 1.0781956859476753, 1.0842506490364152, 1.0902434580129832, 1.096175707308346, 1.1020489266667923, 1.1078645847062096, 1.1136240922324208, 1.1193288053279282, 1.1249800282334494, 1.1305790160388953, 1.1361269771988889, 1.1416250758865332, 1.1470744341978951, 1.1524761342185503, 1.1578312199625447, 1.1631406991932087, 1.168405545134469, 1.1736266980805488, 1.178805066911298, 1.1839415305197942, 1.1890369391583078, 1.1940921157082331, 1.1991078568791471, 1.2040849343417377, 1.2090240957989868, 1.2139260659996476, 1.2187915476977498, 1.2236212225615857, 1.2284157520353751, 1.2331757781565644, 1.2379019243315112, 1.242594796072095, 1.2472549816956267, 1.2518830529902465, 1.2564795658478674, 1.2610450608665555, 1.265580063924133, 1.2700850867246476, 1.2745606273192622, 1.2790071706029946], [0.0, 0.29308422203197615, 0.37355360989045344, 0.4305116202499343, 0.4761167233593513, 0.5147921795009976, 0.5487131607739882, 0.5791309206293913, 0.6068396296020864, 0.6323788223236477, 0.6561338432438417, 0.6783906896492915, 0.6993681904144294, 0.7192379797067616, 0.7381374694973788, 0.756178595191623, 0.7734538989878239, 0.7900408755616534, 0.8060051484842448, 0.8214028388503244, 0.8362823628502694, 0.8506858173682023, 0.8646500629669478, 0.8782075809780604, 0.8913871595017524, 0.904214448113396, 0.9167124106068888, 0.9289016976853711, 0.9408009561704319, 0.9524270874056852, 0.9637954646528334, 0.9749201171274218, 0.98581388669645, 0.9964885620199742, 1.00695499396372, 1.0172231953677013, 1.027302427674634, 1.0372012764632357, 1.0469277175668923, 1.0564891751663956, 1.0658925730104742, 1.0751443797274707, 1.0842506490364152, 1.0932170555386787, 1.1020489266667925, 1.110751271280469, 1.1193288053279282, 1.127785974930595, 1.1361269771988889, 1.1443557790444765, 1.1524761342185506, 1.1604915987753717, 1.1684055451344693, 1.1762211748928648, 1.1839415305197942, 1.1915695060501819, 1.1991078568791473, 1.2065592087477424, 1.2139260659996478, 1.221210819179473, 1.2284157520353751, 1.2355430479817997, 1.2425947960720953, 1.249572996525442, 1.2564795658478674, 1.2633163415830078, 1.2700850867246478, 1.2767874938198522, 1.2834251887886627, 1.2899997344837992, 1.2965126340115616, 1.3029653338331186, 1.3093592266635825, 1.315695654184671, 1.3219759095853212, 1.3282012399433343, 1.3343728484599815, 1.3404918965584511, 1.346559505856091, 1.3525767600195528, 1.3585447065111724, 1.3644643582342464, 1.3703366950842244, 1.3761626654122747, 1.3819431874071704, 1.3876791504009631, 1.393371416103495, 1.3990208197704068, 1.4046281713089468, 1.410194256325553, 1.4157198371189026, 1.4212056536218303, 1.4266524242952847, 1.4320608469772562, 1.4374315996894047, 1.442765341403916, 1.4480627127729528, 1.4533243368228845, 1.4585508196153507, 1.4637427508770544, 1.468900704600074, 1.4740252396143452], [0.0, 0.32413131933855244, 0.4131250177099655, 0.4761167233593513, 0.526552881733695, 0.569325319425153, 0.6068396296020864, 0.6404796139209263, 0.6711235712592635, 0.6993681904144294, 0.7256396362752623, 0.7502542024900444, 0.7734538989878238, 0.7954285415450065, 0.8163300985042545, 0.8362823628502692, 0.8553876799929505, 0.8737317538002618, 0.8913871595017524, 0.9084159632310074, 0.9248717100187196, 0.9408009561704318, 0.9562444669746236, 0.9712381645862905, 0.98581388669645, 1.0, 1.0138219008992493, 1.027302427674634, 1.0404622024491779, 1.0533199169653644, 1.065892573010474, 1.0781956859476753, 1.0902434580129832, 1.1020489266667925, 1.1136240922324208, 1.1249800282334497, 1.1361269771988887, 1.147074434197895, 1.1578312199625445, 1.168405545134469, 1.178805066911298, 1.1890369391583075, 1.1991078568791473, 1.2090240957989868, 1.2187915476977498, 1.2284157520353751, 1.2379019243315112, 1.2472549816956267, 1.2564795658478674, 1.265580063924133, 1.2745606273192622, 1.2834251887886625, 1.292177478000154, 1.300821035703421, 1.3093592266635825, 1.3177952514874536, 1.3261321574556053, 1.3343728484599815, 1.342520094135248, 1.3505765382619976, 1.3585447065111722, 1.3664270135914178, 1.3742257698543914, 1.3819431874071706, 1.3895813857757495, 1.3971423971590613, 1.4046281713089466, 1.4120405800679403, 1.419381421593598, 1.4266524242952845, 1.4338552505068667, 1.4409914999165285, 1.4480627127729528, 1.45507037288534, 1.462015910433157, 1.4689007046000737, 1.4757260860452874, 1.4824933392242612, 1.4892037045698934, 1.4958583805441785, 1.5024585255695886, 1.5090052598486363, 1.515499667079388, 1.5219427960740708, 1.5283356622873419, 1.5346792492602779, 1.5409745099856604, 1.547222368199715, 1.5534237196050584, 1.5595794330292572, 1.565690351523071, 1.57175729340215, 1.5777810532356928, 1.5837624027853001, 1.5897020918970528, 1.5956008493496017, 1.6014593836608921, 1.6072783838559341, 1.6130585201978949, 1.6188004448846063, 1.6245047927124712, 1.6301721817095873], [0.0, 0.3504608431930435, 0.4466835921509631, 0.5147921795009976, 0.569325319425153, 0.6155722066724582, 0.6561338432438418, 0.6925064384421088, 0.7256396362752623, 0.756178595191623, 0.7845840978967508, 0.8111981309006188, 0.8362823628502694, 0.8600420284548513, 0.8826414406034021, 0.904214448113396, 0.9248717100187196, 0.9447058920015808, 0.9637954646528335, 0.9822075358025828, 1.0, 1.0172231953677013, 1.0339211986009056, 1.0501328498485833, 1.065892573010474, 1.0812310390375761, 1.096175707308346, 1.110751271280469, 1.1249800282334497, 1.1388821882594347, 1.1524761342185503, 1.1657786418030374, 1.178805066911298, 1.1915695060501816, 1.204084934341738, 1.2163633248233745, 1.2284157520353751, 1.24025248234123, 1.2518830529902465, 1.2633163415830078, 1.2745606273192622, 1.2856236451801963, 1.2965126340115618, 1.3072343793222048, 1.3177952514874536, 1.3282012399433343, 1.3384579838715749, 1.3485707998035554, 1.3585447065111724, 1.3683844475019324, 1.378094511392791, 1.3876791504009631, 1.3971423971590613, 1.4064880800355457, 1.4157198371189026, 1.4248411290045635, 1.433855250506867, 1.442765341403916, 1.4515743963106789, 1.4602852737647927, 1.468900704600074, 1.477423299674461, 1.4858555570118768, 1.494199868411155, 1.5024585255695888, 1.5106337257637419, 1.5187275771258228, 1.526742103550081, 1.534679249260278, 1.5425408830662677, 1.5503288023350237, 1.5580447366990637, 1.5656903515230711, 1.5732672511476096, 1.5807769819271102, 1.5882210350777657, 1.595600849349602, 1.602917813535734, 1.6101732688307135, 1.6173685110488483, 1.6245047927124712, 1.6315833250193088, 1.6386052796973478, 1.6455717907549217, 1.6524839561331248, 1.6593428392670977, 1.6661494705622155, 1.6729048487907572, 1.679609942414194, 1.686265690835858, 1.6928730055883978, 1.6994327714600954, 1.7059458475638296, 1.7124130683521985, 1.718835244582059, 1.7252131642315092, 1.7315475933721427, 1.7378392769991882, 1.7440889398219852, 1.7502972870170737, 1.7564650049460278, 1.7625927618400097], [0.0, 0.37355360989045344, 0.4761167233593513, 0.5487131607739882, 0.6068396296020864, 0.6561338432438418, 0.6993681904144295, 0.7381374694973789, 0.7734538989878239, 0.8060051484842448, 0.8362823628502694, 0.8646500629669479, 0.8913871595017524, 0.9167124106068889, 0.9408009561704318, 0.9637954646528334, 0.9858138866964501, 1.0069549939637201, 1.027302427674634, 1.0469277175668923, 1.0658925730104742, 1.0842506490364152, 1.1020489266667925, 1.1193288053279284, 1.1361269771988889, 1.1524761342185506, 1.1684055451344693, 1.1839415305197942, 1.1991078568791473, 1.2139260659996478, 1.2284157520353751, 1.2425947960720953, 1.2564795658478674, 1.2700850867246478, 1.283425188788663, 1.2965126340115618, 1.3093592266635825, 1.3219759095853212, 1.3343728484599815, 1.346559505856091, 1.3585447065111724, 1.3703366950842242, 1.3819431874071706, 1.393371416103495, 1.4046281713089468, 1.4157198371189026, 1.4266524242952847, 1.4374315996894047, 1.4480627127729528, 1.458550819615351, 1.468900704600074, 1.4791169001338713, 1.4892037045698936, 1.4991651985376495, 1.5090052598486363, 1.518727577125823, 1.528335662287342, 1.537832861999355, 1.5472223681997153, 1.5565072277824594, 1.5656903515230711, 1.574774522315636, 1.5837624027853003, 1.5926565423326777, 1.6014593836608921, 1.6101732688307138, 1.6188004448846067, 1.6273430690764195, 1.6358032137398206, 1.644182870825353, 1.652483956133125, 1.6607083132655918, 1.6688577173225998, 1.6769338783588414, 1.6849384446220192, 1.692873005588398, 1.7007390948109449, 1.708538192593927, 1.716271728506655, 1.7239410837479763, 1.7315475933721427, 1.7390925483858157, 1.7465771977251534, 1.7540027501212168, 1.761370375861264, 1.7686812084529122, 1.7759363461975992, 1.7831368536792782, 1.7902837631738393, 1.7973780759843172, 1.804420763706592, 1.811412769429922, 1.8183550088763443, 1.8252483714826857, 1.8320937214286583, 1.8388918986142648, 1.8456437195895274, 1.8523499784393265, 1.8590114476259656, 1.8656288787918809, 1.8722030035247765, 1.8787345340872856], [0.0, 0.39426144927002865, 0.5025101201094091, 0.5791309206293913, 0.6404796139209263, 0.6925064384421088, 0.7381374694973789, 0.7790559126704492, 0.8163300985042546, 0.8506858173682023, 0.8826414406034022, 0.9125816962034996, 0.9408009561704319, 0.9675301054530919, 0.9929539927700279, 1.0172231953677011, 1.0404622024491779, 1.0627752610562444, 1.0842506490364152, 1.1049638613582964, 1.1249800282334497, 1.1443557790444763, 1.1631406991932087, 1.1813784830715321, 1.1991078568791473, 1.2163633248233745, 1.2331757781565647, 1.249572996525442, 1.265580063924133, 1.2812197163026715, 1.2965126340115616, 1.3114776893695335, 1.3261321574556053, 1.340491896558451, 1.3545715034312396, 1.3683844475019324, 1.3819431874071706, 1.3952592726008426, 1.4083434322979447, 1.4212056536218303, 1.433855250506867, 1.4463009246524074, 1.4585508196153507, 1.4706125689576297, 1.4824933392242614, 1.4941998684111548, 1.5057385004851305, 1.5171152164378094, 1.528335662287342, 1.5394051743849373, 1.5503288023350237, 1.5611113297970447, 1.5717572934021502, 1.5822709999883986, 1.5926565423326777, 1.602917813535734, 1.6130585201978949, 1.62308219450682, 1.63299220534454, 1.6427917685088071, 1.652483956133125, 1.6620717053805314, 1.6715578264780488, 1.6809450101515977, 1.690235834514863, 1.6994327714600954, 1.7085381925939267, 1.7175543747569664, 1.7264835051621168, 1.73532768618314, 1.744088939821985, 1.7527692118806901, 1.761370375861264, 1.7698942366147994, 1.7783425337591476, 1.7867169448827431, 1.7950190885506312, 1.8032505271273294, 1.8114127694299218, 1.8195072732236257, 1.82753544757105, 1.8354986550454475, 1.8433982138174017, 1.8512353996236397, 1.8590114476259652, 1.866727554167672, 1.8743848784342283, 1.8819845440245007, 1.8895276404383023, 1.8970152244856207, 1.9044483216224806, 1.9118279272180274, 1.919155007757093, 1.9264305019821841, 1.9336553219785728, 1.940830354205882, 1.947956460479355, 1.9550344789037442, 1.9620652247625838, 1.9690494913653978, 1.9759880508552483, 1.982881654978848], [0.0, 0.4131250177099655, 0.526552881733695, 0.6068396296020864, 0.6711235712592635, 0.7256396362752623, 0.7734538989878239, 0.8163300985042546, 0.8553876799929503, 0.8913871595017523, 0.9248717100187195, 0.9562444669746236, 0.9858138866964499, 1.0138219008992493, 1.0404622024491776, 1.065892573010474, 1.0902434580129832, 1.1136240922324208, 1.1361269771988887, 1.1578312199625445, 1.178805066911298, 1.1991078568791471, 1.2187915476977498, 1.237901924331511, 1.2564795658478671, 1.274560627319262, 1.292177478000154, 1.3093592266635825, 1.326132157455605, 1.342520094135248, 1.3585447065111722, 1.3742257698543912, 1.3895813857757493, 1.4046281713089463, 1.419381421593598, 1.4338552505068667, 1.4480627127729526, 1.4620159104331567, 1.4757260860452872, 1.4892037045698934, 1.5024585255695886, 1.5154996670793879, 1.528335662287342, 1.5409745099856604, 1.5534237196050582, 1.5656903515230707, 1.5777810532356926, 1.5897020918970526, 1.601459383660892, 1.6130585201978949, 1.6245047927124712, 1.6358032137398202, 1.6469585369676982, 1.6579752752962442, 1.6688577173225996, 1.6796099424141937, 1.6902358345148627, 1.7007390948109447, 1.7111232533697365, 1.7213916798498892, 1.7315475933721425, 1.7415940716290634, 1.751534059303909, 1.7613703758612638, 1.771105722765509, 1.7807426901773908, 1.7902837631738389, 1.7997313275316487, 1.8090876751116423, 1.818355008876344, 1.8275354475710497, 1.8366310300953352, 1.8456437195895272, 1.8545754072584115, 1.8634279159524265, 1.872203003524776, 1.880902365981281, 1.8895276404383021, 1.8980804079027724, 1.9065621958871637, 1.9149744808711486, 1.923318690620744, 1.9315962063748378, 1.9398083649081994, 1.9479564604793544, 1.956041746671034, 1.964065438130316, 1.972028712215023, 1.9799327105524447, 1.9877785405159891, 1.9955672766249613, 2.00329996187227, 2.010977608984531, 2.018601201618694, 2.026171695499051, 2.033690019498176, 2.0411570766651455, 2.0485737452041093, 2.0559408794061094, 2.0632593105368247, 2.070529847682755, 2.077753278558182], [0.0, 0.4305116202499342, 0.5487131607739881, 0.6323788223236477, 0.6993681904144294, 0.756178595191623, 0.8060051484842448, 0.8506858173682023, 0.8913871595017523, 0.928901697685371, 0.9637954646528334, 0.9964885620199743, 1.0273024276746339, 1.0564891751663956, 1.084250649036415, 1.1107512712804688, 1.1361269771988887, 1.1604915987753717, 1.1839415305197942, 1.2065592087477424, 1.2284157520353751, 1.2495729965254418, 1.2700850867246478, 1.289999734483799, 1.3093592266635823, 1.328201239943334, 1.346559505856091, 1.3644643582342464, 1.3819431874071704, 1.3990208197704068, 1.4157198371189024, 1.4320608469772562, 1.4480627127729526, 1.4637427508770542, 1.4791169001338713, 1.4941998684111548, 1.509005259848636, 1.5235456858089427, 1.5378328619993549, 1.551877693804269, 1.565690351523071, 1.579280336928491, 1.5926565423326775, 1.6058273031615828, 1.6188004448846065, 1.6315833250193086, 1.6441828708253525, 1.6566056132136318, 1.6688577173225996, 1.6809450101515977, 1.6928730055883978, 1.7046469271236093, 1.7162717285066549, 1.7277521125656556, 1.7390925483858155, 1.7502972870170737, 1.7613703758612638, 1.772315671871266, 1.7831368536792782, 1.7938374327579614, 1.804420763706592, 1.8148900537441883, 1.8252483714826855, 1.8354986550454473, 1.845643719589527, 1.8556862642840675, 1.8656288787918809, 1.8754740492965432, 1.8852241641131493, 1.8948815189171606, 1.9044483216224803, 1.9139266969369382, 1.923318690620744, 1.9326262734711182, 1.9418513450542014, 1.9509957372034552, 1.9600612173020744, 1.9690494913653978, 1.977962206937939, 1.9868009558184059, 1.9955672766249613, 2.0042626572119717, 2.0128885369485534, 2.0214463088684056, 2.029937321699664, 2.038362881782806, 2.046724254884026, 2.055022667910923, 2.0632593105368247, 2.0714353367395817, 2.0795518662602572, 2.0876099859867145, 2.095610751266747, 2.1035551871550697, 2.1114442895981775, 2.119279026560778, 2.1270603390972846, 2.13478914237157, 2.142466326628004, 2.150092758116555, 2.157669279974593, 2.1651967130678043], [0.0, 0.4466835921509631, 0.569325319425153, 0.6561338432438417, 0.7256396362752623, 0.7845840978967508, 0.8362823628502694, 0.8826414406034022, 0.9248717100187195, 0.9637954646528334, 1.0, 1.0339211986009056, 1.065892573010474, 1.096175707308346, 1.1249800282334494, 1.1524761342185503, 1.178805066911298, 1.204084934341738, 1.2284157520353751, 1.2518830529902465, 1.2745606273192622, 1.2965126340115616, 1.3177952514874536, 1.3384579838715749, 1.3585447065111722, 1.3780945113927907, 1.3971423971590613, 1.4157198371189026, 1.4338552505068667, 1.4515743963106789, 1.4689007046000737, 1.4858555570118765, 1.5024585255695886, 1.5187275771258228, 1.534679249260278, 1.5503288023350237, 1.565690351523071, 1.58077698192711, 1.5956008493496017, 1.6101732688307135, 1.6245047927124712, 1.6386052796973474, 1.652483956133125, 1.6661494705622155, 1.6796099424141937, 1.6928730055883978, 1.7059458475638294, 1.7188352445820587, 1.7315475933721427, 1.744088939821985, 1.7564650049460275, 1.7686812084529122, 1.7807426901773908, 1.7926543296071697, 1.804420763706592, 1.8160464032143422, 1.82753544757105, 1.8388918986142646, 1.8501195731623181, 1.8612221145947345, 1.8722030035247763, 1.8830655676491752, 1.8938129908508692, 1.9044483216224806, 1.9149744808711486, 1.925394269159069, 1.935710373428552, 1.945925373255521, 1.9560417466710343, 1.9660618755865507, 1.975988050855248, 1.9858224769986332, 1.9955672766249615, 2.0052244945635485, 2.0147961017368674, 2.0242839987903647, 2.033690019498176, 2.043015933961325, 2.052263451613581, 2.061434224048841, 2.070529847682755, 2.0795518662602577, 2.0885017732197064, 2.0973810139234743, 2.1061909877640517, 2.1149330501539976, 2.123608514407434, 2.132218653520183, 2.1407647018551046, 2.1492478567387, 2.157669279974593, 2.1660300992790913, 2.174331409643645, 2.1825742746286805, 2.190759727592966, 2.1988887728623614, 2.206962386841557, 2.214981519072138, 2.222947093240096, 2.230860008135684, 2.23872113856834, 2.2465313362391934], [0.0, 0.4618356349920818, 0.5886375166538976, 0.6783906896492915, 0.7502542024900444, 0.8111981309006188, 0.8646500629669479, 0.9125816962034996, 0.9562444669746236, 0.9964885620199743, 1.0339211986009056, 1.0689930449163332, 1.1020489266667925, 1.1333593011774405, 1.1631406991932087, 1.1915695060501816, 1.2187915476977498, 1.2449289385319025, 1.2700850867246478, 1.2943484266558367, 1.3177952514874538, 1.340491896558451, 1.3624964459284898, 1.3838600829614502, 1.4046281713089466, 1.4248411290045635, 1.444535141886839, 1.4637427508770546, 1.4824933392242614, 1.500813539691923, 1.518727577125823, 1.5362575584535356, 1.5534237196050584, 1.5702446368901801, 1.5867374088631248, 1.602917813535734, 1.6188004448846067, 1.6343988318747997, 1.6497255426481632, 1.6647922760645895, 1.679609942414194, 1.6941887348184534, 1.708538192593927, 1.7226672576519502, 1.7365843248428812, 1.7502972870170739, 1.7638135754614324, 1.777140196275763, 1.7902837631738393, 1.8032505271273294, 1.8160464032143424, 1.8286769949865331, 1.841147616628009, 1.853463313144548, 1.865628878791881, 1.8776488739262363, 1.8895276404383023, 1.9012693159127554, 1.9128778466389798, 1.9243569995843, 1.9357103734285521, 1.94694140874793, 1.9580533974264964, 1.969049491365398, 1.979932710552445, 1.9907059505482594, 2.001371989439455, 2.011933494304263, 2.0223930272315247, 2.032753050929991, 2.043015933961325, 2.053183955627046, 2.063259310536825, 2.0732441128830392, 2.083140400444214, 2.092950138337968, 2.102675222542253, 2.112317483202042, 2.1218786877371456, 2.1313605437655054, 2.1407647018551046, 2.1500927581165556, 2.1593462566474355, 2.168526691838541, 2.1776355105514336, 2.1866741141758905, 2.1956438605752227, 2.2045460659267966, 2.21338200646454, 2.222152920129704, 2.2308600081356844, 2.2395044364522767, 2.2480873372143537, 2.2566098100595875, 2.2650729233995133, 2.2734777156279273, 2.2818251962703378, 2.2901163470779196, 2.2983521230691992, 2.3065334535224724, 2.314661242921762, 2.322736371858921], [0.0, 0.47611672335935123, 0.6068396296020863, 0.6993681904144294, 0.7734538989878238, 0.8362823628502694, 0.8913871595017524, 0.9408009561704319, 0.9858138866964499, 1.0273024276746339, 1.065892573010474, 1.1020489266667925, 1.1361269771988887, 1.1684055451344693, 1.1991078568791471, 1.2284157520353751, 1.2564795658478674, 1.2834251887886627, 1.3093592266635825, 1.3343728484599815, 1.3585447065111722, 1.3819431874071704, 1.4046281713089466, 1.4266524242952845, 1.4480627127729526, 1.4689007046000737, 1.4892037045698934, 1.5090052598486363, 1.5283356622873419, 1.547222368199715, 1.565690351523071, 1.5837624027853001, 1.601459383660892, 1.6188004448846065, 1.6358032137398204, 1.652483956133125, 1.6688577173225996, 1.6849384446220188, 1.7007390948109447, 1.7162717285066549, 1.7315475933721427, 1.746577197725153, 1.761370375861264, 1.775936346197599, 1.790283763173839, 1.8044207637065919, 1.818355008876344, 1.832093721428658, 1.8456437195895272, 1.8590114476259654, 1.8722030035247763, 1.885224164113149, 1.8980804079027724, 1.9107769359033526, 1.923318690620744, 1.935710373428552, 1.9479564604793547, 1.9600612173020742, 1.9720287122150233, 1.983862828669377, 1.9955672766249615, 2.007145603049008, 2.018601201618694, 2.0299373216996646, 2.0411570766651455, 2.052263451613581, 2.0632593105368247, 2.0741474029856946, 2.0849303702750905, 2.095610751266747, 2.1061909877640517, 2.116673429550106, 2.1270603390972846, 2.137353895973968, 2.1475562009717826, 2.157669279974593, 2.167695087588632, 2.1776355105514336, 2.1874923709357565, 2.197267429163269, 2.206962386841557, 2.2165788894368794, 2.2261185287940903, 2.235582845514209, 2.2449733311992968, 2.2542914305735344, 2.26353854348869, 2.272716026821556, 2.2818251962703378, 2.2908673280564593, 2.299843660537776, 2.3087553957387232, 2.3176037008025556, 2.3263897093704333, 2.335114522891792, 2.343779211870106, 2.3523848170478843, 2.3609323505344495, 2.36942279687984, 2.3778571140979112, 2.3862362346415456, 2.394561066332652], [0.0, 0.4896437025691147, 0.6240805847094171, 0.7192379797067616, 0.7954285415450065, 0.8600420284548513, 0.9167124106068889, 0.9675301054530919, 1.0138219008992493, 1.0564891751663956, 1.096175707308346, 1.1333593011774405, 1.1684055451344693, 1.2016011812929526, 1.2331757781565644, 1.2633163415830078, 1.2921774780001543, 1.319888654561378, 1.346559505856091, 1.372283791078915, 1.3971423971590615, 1.4212056536218303, 1.444535141886839, 1.4671851271729264, 1.4892037045698936, 1.5106337257637419, 1.5315135554163122, 1.5518776938042695, 1.5717572934021502, 1.5911805905865437, 1.6101732688307135, 1.6287587661655303, 1.6469585369676984, 1.6647922760645895, 1.6822781115493268, 1.6994327714600956, 1.716271728506655, 1.7328093262607023, 1.7490588896175974, 1.765032821849499, 1.780742690177391, 1.79619930147143, 1.8114127694299222, 1.826392574374963, 1.8411476166280092, 1.8556862642840675, 1.8700163960830165, 1.884145439976252, 1.8980804079027729, 1.9118279272180276, 1.9253942691590693, 1.9387853746788513, 1.9520068779393682, 1.9650641277165082, 1.9779622069379394, 1.9907059505482594, 2.0032999618722704, 2.0157486276270786, 2.028056131716219, 2.0402264679238185, 2.0522634516135816, 2.064170730525827, 2.0759517947556856, 2.087609985986715, 2.099148506046364, 2.1105704248428787, 2.1218786877371456, 2.133076122397628, 2.1441654451817738, 2.1551492670830608, 2.1660300992790917, 2.1768103583127885, 2.187492370935757, 2.1980783786402185, 2.208570541903509, 2.218970944166995, 2.2292815955693372, 2.2395044364522767, 2.249641340655585, 2.2596941186163697, 2.269664520286686, 2.279554237882229, 2.2893649084738468, 2.2990981164326603, 2.3087553957387232, 2.318338232162356, 2.3278480653265947, 2.3372862906585357, 2.34665426123676, 2.355953289541491, 2.3651846491136395, 2.374349576128425, 2.3834492708888755, 2.392484899244094, 2.401457593936859, 2.41036845588478, 2.419218555398959, 2.4280089333438157, 2.436740602241494, 2.445414547324036, 2.4540317275362957, 2.4625930764923614], [0.0, 0.5025101201094091, 0.6404796139209262, 0.7381374694973788, 0.8163300985042545, 0.8826414406034021, 0.9408009561704318, 0.9929539927700279, 1.0404622024491776, 1.084250649036415, 1.1249800282334494, 1.1631406991932087, 1.1991078568791471, 1.2331757781565644, 1.2655800639241328, 1.2965126340115614, 1.3261321574556053, 1.3545715034312393, 1.3819431874071704, 1.4083434322979445, 1.4338552505068667, 1.4585508196153505, 1.4824933392242612, 1.5057385004851302, 1.5283356622873419, 1.5503288023350235, 1.57175729340215, 1.5926565423326775, 1.6130585201978946, 1.6329922053445398, 1.6524839561331248, 1.6715578264780486, 1.6902358345148627, 1.7085381925939265, 1.7264835051621166, 1.7440889398219848, 1.7613703758612638, 1.7783425337591472, 1.7950190885506307, 1.8114127694299218, 1.8275354475710497, 1.8433982138174012, 1.8590114476259652, 1.874384878434228, 1.8895276404383021, 1.9044483216224801, 1.9191550077570927, 1.9336553219785724, 1.9479564604793544, 1.9620652247625836, 1.9759880508552479, 1.9897310358213287, 2.00329996187227, 2.0167003183342893, 2.0299373216996646, 2.043015933961325, 2.0559408794061094, 2.068716660021337, 2.081347569651402, 2.093837707025505, 2.1061909877640517, 2.118411155459406, 2.1305017919162843, 2.1424663266280035, 2.15430804555676, 2.1660300992790913, 2.177635510551433, 2.1891271813451816, 2.200507899395786, 2.2117803443060664, 2.2229470932400957, 2.234010626240541, 2.2449733311992968, 2.255837508508505, 2.266605375416585, 2.2772790701117045, 2.287860655553142, 2.298352123069199, 2.308755395738723, 2.319072331571864, 2.3293047265043456, 2.339454317218387, 2.3495227838023145, 2.359511752259931, 2.3694227968798396, 2.3792574424740995, 2.3890171664948685, 2.398703401037023, 2.4083175347341275, 2.4178609145545833, 2.427334847504264, 2.4367406022414935, 2.4460794106097836, 2.4553524690933735, 2.464560940200239, 2.473705953776914, 2.4827886082591757, 2.4918099718623425, 2.5007710837147075, 2.509672954937355, 2.518516569673431, 2.527302886069697], [0.0, 0.5147921795009975, 0.6561338432438416, 0.756178595191623, 0.8362823628502692, 0.904214448113396, 0.9637954646528334, 1.0172231953677011, 1.065892573010474, 1.1107512712804688, 1.1524761342185503, 1.1915695060501816, 1.2284157520353751, 1.2633163415830078, 1.2965126340115614, 1.328201239943334, 1.3585447065111722, 1.3876791504009631, 1.4157198371189024, 1.4427653414039159, 1.4689007046000737, 1.4941998684111546, 1.5187275771258228, 1.5425408830662675, 1.5656903515230707, 1.5882210350777655, 1.6101732688307135, 1.6315833250193086, 1.6524839561331248, 1.6729048487907572, 1.6928730055883976, 1.7124130683521983, 1.7315475933721425, 1.7502972870170737, 1.7686812084529122, 1.7867169448827431, 1.8044207637065919, 1.821807745193023, 1.8388918986142644, 1.8556862642840672, 1.8722030035247763, 1.8884534782557054, 1.9044483216224803, 1.9201975008638266, 1.935710373428552, 1.950995737203455, 1.9660618755865504, 1.9809165980345276, 1.9955672766249613, 2.010020879099371, 2.0242839987903647, 2.038362881782806, 2.052263451613581, 2.065991331775818, 2.0795518662602577, 2.092950138337968, 2.1061909877640517, 2.119279026560778, 2.132218653520183, 2.1450140675502154, 2.157669279974593, 2.1701881258843816, 2.1825742746286805, 2.194831239522483, 2.2069623868415564, 2.218970944166995, 2.230860008135684, 2.2426325516473127, 2.2542914305735344, 2.2658393900104605, 2.2772790701117045, 2.288613011535691, 2.299843660537776, 2.310973373734945, 2.32200442256831, 2.332938997486388, 2.343779211870106, 2.354527105718649, 2.365184649113639, 2.3757537454776254, 2.3862362346415456, 2.3966338957345936, 2.406948449908835, 2.417181562909909, 2.427334847504264, 2.4374098657725267, 2.447408131277878, 2.457331111117623, 2.4671802278654984, 2.4769568614117214, 2.486662350707242, 2.49629799541819, 2.505865057496079, 2.515364762668918, 2.5247983018580262, 2.534166832524986, 2.543471479952902, 2.55271333846579, 2.561893472589709, 2.571012918158977, 2.580072683370592, 2.58907374978978], [0.0, 0.526552881733695, 0.6711235712592635, 0.7734538989878239, 0.8553876799929505, 0.9248717100187196, 0.9858138866964501, 1.0404622024491779, 1.0902434580129832, 1.1361269771988887, 1.178805066911298, 1.2187915476977498, 1.2564795658478674, 1.2921774780001543, 1.3261321574556053, 1.3585447065111722, 1.3895813857757495, 1.419381421593598, 1.4480627127729528, 1.4757260860452874, 1.5024585255695888, 1.528335662287342, 1.5534237196050584, 1.5777810532356928, 1.601459383660892, 1.6245047927124712, 1.6469585369676984, 1.6688577173225998, 1.690235834514863, 1.7111232533697367, 1.7315475933721425, 1.751534059303909, 1.771105722765509, 1.790283763173839, 1.8090876751116427, 1.82753544757105, 1.8456437195895272, 1.8634279159524265, 1.880902365981281, 1.8980804079027727, 1.9149744808711489, 1.9315962063748375, 1.947956460479355, 1.9640654381303162, 1.979932710552445, 1.9955672766249613, 2.010977608984531, 2.026171695499051, 2.0411570766651455, 2.05594087940611, 2.070529847682755, 2.0849303702750905, 2.099148506046364, 2.113190006961408, 2.1270603390972846, 2.1407647018551046, 2.1543080455567605, 2.167695087588632, 2.1809303272355085, 2.1940180593316336, 2.206962386841557, 2.2197672324710473, 2.232436349397444, 2.244973331199297, 2.2573816210567426, 2.269664520286686, 2.2818251962703378, 2.293866689824867, 2.3057919220658407, 2.3176037008025556, 2.329304726504346, 2.3408975978723334, 2.3523848170478843, 2.363768794486157, 2.3750518535205503, 2.3862362346415456, 2.397324099511386, 2.408317534734128, 2.4192185553989587, 2.430029108413134, 2.44075107563951, 2.4513862768524377, 2.4619364725246204, 2.4724033664565472, 2.4827886082591757, 2.4930937956996986, 2.5033204769194572, 2.513470152532377, 2.5235442776116512, 2.5335442635718266, 2.543471479952902, 2.5533272561125746, 2.5631128828323133, 2.572829613842539, 2.582478667271803, 2.5920612270245176, 2.601578444091479, 2.61103143779712, 2.6204212969871667, 2.6297490811601234, 2.639015821545789, 2.64822252213377], [0.0, 0.537844983726624, 0.6855160398591242, 0.7900408755616534, 0.8737317538002618, 0.9447058920015808, 1.0069549939637201, 1.0627752610562444, 1.1136240922324208, 1.1604915987753717, 1.204084934341738, 1.2449289385319025, 1.2834251887886627, 1.319888654561378, 1.3545715034312393, 1.3876791504009631, 1.419381421593598, 1.4498205291087474, 1.4791169001338713, 1.5073735236632952, 1.534679249260278, 1.5611113297970447, 1.5867374088631245, 1.61161709362918, 1.6358032137398204, 1.6593428392670977, 1.6822781115493266, 1.7046469271236098, 1.7264835051621168, 1.7478188616738917, 1.7686812084529122, 1.7890962908059518, 1.8090876751116425, 1.8286769949865331, 1.8478841630811895, 1.8667275541676722, 1.8852241641131493, 1.903389748492635, 1.9212389439247364, 1.9387853746788513, 1.9560417466710345, 1.9730199306164056, 1.9897310358213292, 2.0061854758654265, 2.0223930272315247, 2.0383628817828066, 2.054103693854454, 2.069623622616853, 2.0849303702750905, 2.100031216591706, 2.114933050153998, 2.1296423967514904, 2.1441654451817733, 2.158508070762481, 2.1726758567925204, 2.1866741141758905, 2.2005078993957863, 2.2141820310045106, 2.227701104775514, 2.2410695076471914, 2.254291430573535, 2.2673708803840444, 2.280311690744199, 2.2931175322980373, 2.3057919220658407, 2.3183382321623562, 2.330759697894339, 2.343059425290296, 2.3552403981100904, 2.3673054843774257, 2.3792574424741, 2.391098926831247, 2.4028324932494876, 2.4144606038769947, 2.4259856318718254, 2.4374098657725267, 2.448735513598909, 2.4599647067029466, 2.4710995033880874, 2.4821418923136602, 2.493093795699699, 2.503957072346221, 2.5147335204798535, 2.525424880439654, 2.536032837213038, 2.5465590228318478, 2.5570050186378306, 2.5673723574260783, 2.577662525474314, 2.5878769644653383, 2.598017073309393, 2.608084209872693, 2.6180796926179464, 2.628004802162241, 2.6378607827573, 2.647648843696761, 2.6573701606548012, 2.667025876960138, 2.676617104809158, 2.686144926421664, 2.6956103951425203, 2.705014536492226], [0.0, 0.5487131607739881, 0.6993681904144294, 0.8060051484842448, 0.8913871595017524, 0.9637954646528335, 1.027302427674634, 1.0842506490364152, 1.1361269771988887, 1.1839415305197942, 1.2284157520353751, 1.2700850867246478, 1.3093592266635825, 1.346559505856091, 1.3819431874071704, 1.4157198371189024, 1.4480627127729528, 1.4791169001338713, 1.5090052598486363, 1.537832861999355, 1.565690351523071, 1.5926565423326775, 1.6188004448846065, 1.6441828708253527, 1.6688577173225996, 1.6928730055883978, 1.716271728506655, 1.7390925483858155, 1.7613703758612638, 1.7831368536792782, 1.8044207637065919, 1.8252483714826855, 1.845643719589527, 1.8656288787918809, 1.8852241641131495, 1.9044483216224806, 1.923318690620744, 1.9418513450542014, 1.9600612173020742, 1.9779622069379392, 1.9955672766249615, 2.012888536948553, 2.0299373216996646, 2.046724254884026, 2.0632593105368247, 2.0795518662602577, 2.095610751266747, 2.1114442895981775, 2.1270603390972846, 2.142466326628004, 2.157669279974593, 2.1726758567925204, 2.1874923709357565, 2.2021248164438627, 2.2165788894368794, 2.2308600081356844, 2.244973331199297, 2.2589237745480006, 2.272716026821556, 2.2863545636047617, 2.299843660537776, 2.313187405415682, 2.3263897093704333, 2.3394543172183875, 2.3523848170478843, 2.3651846491136395, 2.3778571140979112, 2.390405380792399, 2.402832493249487, 2.4151413774467327, 2.4273348475042646, 2.4394156114910275, 2.4513862768524377, 2.4632493554890362, 2.475007268513036, 2.4866623507072423, 2.4982168547086885, 2.5096729549373555, 2.521032751288612, 2.532298272606417, 2.5434714799529026, 2.554554269688662, 2.5655484763769003, 2.5764558755235223, 2.587278186164307, 2.598017073309393, 2.608674150254534, 2.61925098076785, 2.629749081160124, 2.640169922246088, 2.6505149312036163, 2.6607854933371833, 2.670982953751535, 2.681108618941054, 2.6911637582999273, 2.7011496055578608, 2.7110673601457576, 2.720918188495458, 2.730703225277384, 2.7404235745796393, 2.7500803110319185, 2.759674480877305], [0.0, 0.5591956190625977, 0.7127287190266077, 0.8214028388503244, 0.9084159632310074, 0.9822075358025828, 1.0469277175668923, 1.1049638613582964, 1.1578312199625445, 1.2065592087477424, 1.2518830529902465, 1.2943484266558367, 1.3343728484599815, 1.372283791078915, 1.4083434322979445, 1.4427653414039159, 1.4757260860452874, 1.5073735236632952, 1.537832861999355, 1.5672111783641802, 1.5956008493496017, 1.62308219450682, 1.649725542648163, 1.6755928671483173, 1.7007390948109447, 1.725213164231509, 1.7490588896175971, 1.7723156718712663, 1.795019088550631, 1.8172013868958867, 1.8388918986142644, 1.8601173910145512, 1.880902365981281, 1.9012693159127552, 1.9212389439247364, 1.9408303542058818, 1.9600612173020742, 1.9789479142316182, 1.9975056626376098, 2.0157486276270786, 2.033690019498176, 2.051342180193452, 2.068716660021337, 2.085824285945509, 2.1026752225422527, 2.119279026560778, 2.1356446958842406, 2.1517807135746247, 2.167695087588632, 2.183395386670869, 2.1988887728623614, 2.21418203100451, 2.229281595569337, 2.2441935751048074, 2.2589237745480006, 2.273477715627927, 2.2878606555531427, 2.3020776041562563, 2.3161333396474544, 2.3300324231118186, 2.343779211870106, 2.357377871809461, 2.3708323887789757, 2.3841465791349017, 2.397324099511386, 2.4103684558847798, 2.4232830119926256, 2.4360709971623065, 2.448735513598909, 2.4612795431770214, 2.4737059537769146, 2.4860175052017026, 2.4982168547086885, 2.510306562185039, 2.522289094995197, 2.534166832524986, 2.5459420704451703, 2.5576170247152237, 2.569193835346311, 2.580674569940843, 2.5920612270245176, 2.603355739185456, 2.6145599760338296, 2.6256757469942977, 2.636704803942604, 2.6476488436967607, 2.6585095103724603, 2.669288397611599, 2.679987050692123, 2.6906069685267875, 2.7011496055578608, 2.7116163735542753, 2.7220086433172725, 2.732327746300125, 2.7425749761471634, 2.7527515901569095, 2.7628588106738494, 2.772897826413002, 2.7828697937212055, 2.792775837778746, 2.802617053744734, 2.8123945078493793], [0.0, 0.569325319425153, 0.7256396362752623, 0.8362823628502694, 0.9248717100187196, 1.0, 1.0658925730104742, 1.1249800282334497, 1.178805066911298, 1.2284157520353751, 1.2745606273192622, 1.3177952514874538, 1.3585447065111722, 1.3971423971590615, 1.4338552505068667, 1.4689007046000737, 1.5024585255695888, 1.534679249260278, 1.565690351523071, 1.5956008493496017, 1.6245047927124712, 1.652483956133125, 1.6796099424141937, 1.7059458475638294, 1.7315475933721427, 1.7564650049460275, 1.780742690177391, 1.8044207637065923, 1.82753544757105, 1.8501195731623181, 1.8722030035247763, 1.8938129908508692, 1.9149744808711486, 1.935710373428552, 1.9560417466710345, 1.9759880508552483, 1.9955672766249615, 2.0147961017368674, 2.033690019498176, 2.052263451613581, 2.070529847682755, 2.0885017732197064, 2.106190987764052, 2.123608514407434, 2.1407647018551046, 2.157669279974593, 2.174331409643645, 2.190759727592966, 2.206962386841557, 2.222947093240096, 2.23872113856834, 2.2542914305735344, 2.269664520286686, 2.284846626910706, 2.299843660537776, 2.314661242921762, 2.329304726504346, 2.3437792118701064, 2.35808956378541, 2.3722404259583487, 2.386236234641546, 2.400081231186235, 2.413779473644252, 2.427334847504265, 2.44075107563951, 2.4540317275362957, 2.4671802278654984, 2.4801998644530263, 2.493093795699699, 2.5058650574960795, 2.518516569673431, 2.531051142028069, 2.5434714799529026, 2.555780189706867, 2.567979783350146, 2.580072683370592, 2.5920612270245176, 2.603947670412995, 2.6157341923130004, 2.6274228977810874, 2.639015821545789, 2.6505149312036167, 2.6619221302323006, 2.673239260833814, 2.684468106618726, 2.69561039514252, 2.7066678003036655, 2.7176419446125166, 2.7285344013393753, 2.739346696549457, 2.750080311031918, 2.7607366821295622, 2.7713172054753796, 2.781823236641615, 2.792256092706667, 2.802617053744734, 2.812907364242791, 2.8231282344491566, 2.8332808416576274, 2.8433663314308717, 2.853385818766556, 2.863340389209407], [0.0, 0.5791309206293913, 0.7381374694973787, 0.8506858173682023, 0.9408009561704318, 1.0172231953677013, 1.0842506490364152, 1.1443557790444763, 1.1991078568791471, 1.2495729965254418, 1.2965126340115616, 1.340491896558451, 1.3819431874071704, 1.4212056536218303, 1.4585508196153505, 1.4941998684111546, 1.528335662287342, 1.5611113297970447, 1.5926565423326775, 1.62308219450682, 1.652483956133125, 1.6809450101515975, 1.7085381925939267, 1.7353276861831397, 1.7613703758612638, 1.7867169448827431, 1.8114127694299218, 1.8354986550454473, 1.8590114476259652, 1.8819845440245007, 1.9044483216224803, 1.9264305019821841, 1.9479564604793544, 1.9690494913653975, 1.989731035821329, 2.010020879099371, 2.0299373216996646, 2.049497328623164, 2.068716660021337, 2.0876099859867145, 2.1061909877640517, 2.1244724472856595, 2.1424663266280035, 2.1601838387355867, 2.1776355105514336, 2.1948312395224825, 2.2117803443060664, 2.2284916103849914, 2.244973331199297, 2.2612333453190336, 2.2772790701117045, 2.293117532298037, 2.3087553957387232, 2.3241989867512216, 2.3394543172183875, 2.3545271057186494, 2.36942279687984, 2.3841465791349017, 2.398703401037023, 2.4130979862737876, 2.4273348475042646, 2.4414182991293085, 2.455352469093374, 2.46914130980566, 2.4827886082591757, 2.4962979954181903, 2.509672954937355, 2.5229168312694465, 2.536032837213038, 2.54902406094643, 2.561893472589709, 2.5746439303328614, 2.5872781861643075, 2.5997988912310883, 2.612208600859092, 2.6245097792591525, 2.636704803942604, 2.648795969867788, 2.660785493337183, 2.6726755156631423, 2.684468106618726, 2.6961652676887455, 2.7077689351348986, 2.7192809828877635, 2.7307032252773835, 2.7420374196132653, 2.7532852686237614, 2.7644484227640373, 2.775528482401137, 2.786526999883995, 2.7974454815056893, 2.808285389364659, 2.8190481431311536, 2.829735121724704, 2.8403476649080077, 2.8508870748022304, 2.8613546173283897, 2.8717515235791478, 2.8820789911250615, 2.8923381852590495, 2.9025302401826005, 2.91265626013699], [0.0, 0.5886375166538975, 0.7502542024900443, 0.8646500629669478, 0.9562444669746236, 1.0339211986009056, 1.1020489266667925, 1.1631406991932087, 1.2187915476977498, 1.2700850867246478, 1.3177952514874536, 1.3624964459284898, 1.4046281713089466, 1.444535141886839, 1.4824933392242612, 1.5187275771258228, 1.5534237196050584, 1.5867374088631245, 1.6188004448846065, 1.649725542648163, 1.6796099424141937, 1.7085381925939267, 1.736584324842881, 1.7638135754614321, 1.790283763173839, 1.8160464032143422, 1.841147616628009, 1.865628878791881, 1.8895276404383021, 1.9128778466389798, 1.935710373428552, 1.9580533974264962, 1.9799327105524447, 2.0013719894394546, 2.0223930272315247, 2.043015933961325, 2.0632593105368247, 2.083140400444214, 2.1026752225422527, 2.121878687737145, 2.1407647018551046, 2.159346256647435, 2.1776355105514336, 2.1956438605752227, 2.2133820064645398, 2.230860008135684, 2.2480873372143537, 2.265072923399513, 2.2818251962703378, 2.298352123069199, 2.314661242921762, 2.330759697894339, 2.3466542612367594, 2.362351363114753, 2.3778571140979117, 2.3931773266367298, 2.408317534734128, 2.4232830119926256, 2.438078788197297, 2.4527096645763784, 2.4671802278654984, 2.4814948632876095, 2.495657766548528, 2.5096729549373555, 2.5235442776116512, 2.5372754251389775, 2.5508699383591513, 2.5643312166250762, 2.5776625254743135, 2.5908670037784733, 2.6039476704129947, 2.6169074304858517, 2.629749081160124, 2.6424753171021735, 2.6550887355842763, 2.667591841267977, 2.679987050692123, 2.6922766964874394, 2.7044630313376286, 2.716548231705286, 2.7285344013393753, 2.7404235745796397, 2.7522177194720556, 2.763918740708295, 2.775528482401137, 2.7870487307068146, 2.798481216304442, 2.809827616741869, 2.821089558656611, 2.8322686198798457, 2.8433663314308717, 2.8543841794088842, 2.8653236067884165, 2.8761860151243486, 2.8869727661719584, 2.8976851834270936, 2.9083245535912203, 2.91889212796573, 2.9293891237796363, 2.9398167254544663, 2.950176085809944, 2.960468327213773], [0.0, 0.5978672201788909, 0.7620180192048306, 0.8782075809780604, 0.9712381645862905, 1.0501328498485833, 1.1193288053279284, 1.1813784830715321, 1.237901924331511, 1.289999734483799, 1.3384579838715749, 1.3838600829614502, 1.4266524242952845, 1.4671851271729264, 1.5057385004851302, 1.5425408830662675, 1.5777810532356928, 1.61161709362918, 1.6441828708253527, 1.6755928671483173, 1.7059458475638294, 1.7353276861831397, 1.7638135754614321, 1.791469774589561, 1.818355008876344, 1.8445216013032777, 1.8700163960830163, 1.8948815189171608, 1.9191550077570927, 1.9428713399255897, 1.9660618755865504, 1.9887552331624923, 2.0109776089845304, 2.0327530509299905, 2.054103693854454, 2.0750499631113692, 2.095610751266747, 2.1158035721807527, 2.1356446958842406, 2.1551492670830603, 2.174331409643645, 2.1932043190250297, 2.2117803443060664, 2.230071061197395, 2.2480873372143537, 2.26583939001046, 2.283336839724368, 2.3005887560707077, 2.3176037008025556, 2.3343897660868467, 2.3509546092610356, 2.3673054843774257, 2.383449270888875, 2.3993924997846623, 2.4151413774467327, 2.4307018074634934, 2.4460794106097836, 2.461279543177021, 2.476307313816175, 2.4911675990376576, 2.505865057496079, 2.520404143173698, 2.534789117564052, 2.54902406094643, 2.5631128828323133, 2.577059331656532, 2.590867003778473, 2.6045393518521265, 2.6180796926179464, 2.631491214164342, 2.644776982702038, 2.6579399488904474, 2.6709829537515355, 2.683908734203425, 2.696719928243036, 2.709419079804441, 2.7220086433172725, 2.7344909879873778, 2.7468684018200333, 2.759143095404276, 2.7713172054753796, 2.7833927982710756, 2.795371872695857, 2.807256363306533, 2.8190481431311536, 2.83074902633248, 2.8423607707262843, 2.853885080163988, 2.8653236067884165, 2.8766779531707836, 2.8879496743364266, 2.8991402796862396, 2.9102512348202723, 2.9212839632694685, 2.9322398481411223, 2.9431202336831976, 2.953926426772349, 2.964659698330092, 2.975321284671317, 2.985912388789013, 2.9964341815788567, 3.006887803007026], [0.0, 0.6068396296020863, 0.7734538989878238, 0.8913871595017524, 0.98581388669645, 1.065892573010474, 1.1361269771988889, 1.1991078568791473, 1.2564795658478671, 1.3093592266635823, 1.3585447065111722, 1.4046281713089466, 1.4480627127729526, 1.4892037045698936, 1.5283356622873419, 1.5656903515230707, 1.601459383660892, 1.6358032137398204, 1.6688577173225996, 1.7007390948109447, 1.7315475933721427, 1.7613703758612638, 1.790283763173839, 1.818355008876344, 1.845643719589527, 1.872203003524776, 1.8980804079027724, 1.923318690620744, 1.9479564604793544, 1.9720287122150233, 1.9955672766249613, 2.018601201618694, 2.0411570766651455, 2.0632593105368247, 2.0849303702750905, 2.1061909877640517, 2.127060339097284, 2.147556200971782, 2.1676950875886316, 2.1874923709357565, 2.206962386841557, 2.22611852879409, 2.244973331199297, 2.26353854348869, 2.2818251962703378, 2.299843660537776, 2.3176037008025556, 2.335114522891792, 2.3523848170478843, 2.36942279687984, 2.3862362346415456, 2.402832493249487, 2.4192185553989587, 2.4354010500921546, 2.4513862768524373, 2.4671802278654984, 2.4827886082591757, 2.4982168547086885, 2.513470152532377, 2.528553451424207, 2.543471479952902, 2.5582287589432426, 2.5728296138425395, 2.5872781861643075, 2.601578444091479, 2.6157341923130004, 2.6297490811601234, 2.643626615102065, 2.657370160654801, 2.670982953751535, 2.684468106618726, 2.6978286141973973, 2.7110673601457576, 2.7241871224558496, 2.7371905787139665, 2.750080311031918, 2.7628588106738494, 2.775528482401137, 2.788091648555978, 2.8005505529025188, 2.8129073642427906, 2.825164179823302, 2.837323028546829, 2.8493858740027713, 2.8613546173283892, 2.873231099912241, 2.885017105950274, 2.8967143648642235, 2.9083245535912203, 2.919849298752843, 2.9312901787112557, 2.9426487255194784, 2.9539264267723486, 2.9651247273642554, 2.976245031159282, 2.9872887025790082, 2.998257068112859, 3.009151417755528, 3.0199730063757295, 3.030723055020204, 3.0414027521566824, 3.0520132548592267], [0.0, 0.615572206672458, 0.7845840978967507, 0.904214448113396, 1.0, 1.0812310390375761, 1.1524761342185506, 1.2163633248233745, 1.274560627319262, 1.328201239943334, 1.3780945113927907, 1.4248411290045635, 1.4689007046000737, 1.5106337257637419, 1.5503288023350235, 1.5882210350777655, 1.6245047927124712, 1.6593428392670977, 1.6928730055883978, 1.725213164231509, 1.7564650049460275, 1.7867169448827431, 1.8160464032143422, 1.8445216013032777, 1.872203003524776, 1.8991444823309345, 1.9253942691590689, 1.9509957372034554, 1.9759880508552479, 2.00040670843405, 2.0242839987903647, 2.047649387840545, 2.0705298476827547, 2.092950138337968, 2.114933050153998, 2.136499613352055, 2.157669279974593, 2.178460082529811, 2.198888772862361, 2.218970944166995, 2.23872113856834, 2.258152942290163, 2.277279070111705, 2.2961114405417935, 2.3146612429217615, 2.332938997486388, 2.3509546092610356, 2.36871741654702, 2.3862362346415456, 2.403519395349549, 2.4205747827696316, 2.4374098657725267, 2.4540317275362953, 2.4704470924561632, 2.4866623507072423, 2.502683580704304, 2.518516569673431, 2.534166832524986, 2.5496396291953634, 2.5649399806058875, 2.580072683370592, 2.595042323370078, 2.609853288295948, 2.6245097792591525, 2.6390158215457884, 2.6533752745952466, 2.667591841267977, 2.6816690764634012, 2.69561039514252, 2.7094190798044413, 2.723098287461356, 2.736651056152253, 2.750080311031918, 2.763388870068409, 2.7765794493791676, 2.7896546682332524, 2.8026170537447337, 2.8154690452801185, 2.8282129986007, 2.8408511897589643, 2.8533858187665557, 2.865819013049896, 2.8781528307081885, 2.8903892635873865, 2.9025302401826, 2.914577628380438, 2.9265332380518827, 2.9383988235054903, 2.9501760858099435, 2.9618666749943214, 2.9734721921338214, 2.9849941913280973, 2.9964341815788567, 3.007793628572886, 3.019073956376232, 3.030276549044849, 3.0414027521566824, 3.0524538742697795, 3.0634311883107346, 3.0743359328974624, 3.0851693136000486, 3.0959325041431445], [0.0, 0.6240805847094171, 0.7954285415450065, 0.9167124106068888, 1.0138219008992493, 1.096175707308346, 1.1684055451344693, 1.2331757781565647, 1.292177478000154, 1.346559505856091, 1.3971423971590613, 1.444535141886839, 1.4892037045698934, 1.5315135554163122, 1.57175729340215, 1.6101732688307135, 1.6469585369676984, 1.6822781115493266, 1.716271728506655, 1.7490588896175971, 1.780742690177391, 1.8114127694299218, 1.841147616628009, 1.8700163960830163, 1.8980804079027724, 1.9253942691590689, 1.9520068779393682, 1.9779622069379394, 2.00329996187227, 2.028056131716219, 2.052263451613581, 2.0759517947556856, 2.099148506046364, 2.121878687737145, 2.1441654451817733, 2.1660300992790913, 2.1874923709357565, 2.2085705419035087, 2.229281595569337, 2.2496413406555846, 2.269664520286686, 2.289364908473846, 2.3087553957387232, 2.3278480653265947, 2.3466542612367594, 2.365184649113639, 2.383449270888875, 2.401457593936859, 2.419218555398959, 2.436740602241494, 2.4540317275362953, 2.4710995033880874, 2.4879511108779155, 2.504593367344931, 2.521032751288612, 2.537275425138977, 2.5533272561125746, 2.569193835346311, 2.5848804954789006, 2.6003923268303444, 2.6157341923130004, 2.6309107411930572, 2.6459264218083547, 2.6607854933371833, 2.6754920367027455, 2.6900499646892206, 2.7044630313376286, 2.7187348406828598, 2.7328688548871662, 2.7468684018200333, 2.7607366821295622, 2.774476775846215, 2.7880916485559784, 2.8015841571765834, 2.814957055367379, 2.8282129986007005, 2.8413545489201395, 2.8543841794088842, 2.867304278389328, 2.880117153373327, 2.892825034780871, 2.905430079443456, 2.917934373907131, 2.9303399375489456, 2.9426487255194784, 2.9548626315230813, 2.9669834904465953, 2.979013080846454, 2.990953127303344, 3.002805302652882, 3.014571230100169, 3.026252485225469, 3.0378505978877626, 3.049367054032414, 3.060803297408769, 3.0721607312030663, 3.0834407195916964, 3.094644589219466, 3.105773630607235, 3.1168290994929726, 3.1278122181100336, 3.1387241764061757], [0.0, 0.6323788223236478, 0.8060051484842448, 0.9289016976853711, 1.027302427674634, 1.110751271280469, 1.1839415305197942, 1.249572996525442, 1.3093592266635825, 1.3644643582342464, 1.4157198371189026, 1.4637427508770546, 1.5090052598486363, 1.5518776938042695, 1.5926565423326775, 1.6315833250193086, 1.6688577173225998, 1.7046469271236098, 1.7390925483858155, 1.7723156718712663, 1.8044207637065923, 1.8354986550454473, 1.865628878791881, 1.8948815189171608, 1.923318690620744, 1.9509957372034554, 1.9779622069379394, 2.004262657211972, 2.0299373216996646, 2.0550226679109236, 2.0795518662602577, 2.10355518715507, 2.1270603390972846, 2.1500927581165556, 2.172675856792521, 2.194831239522483, 2.2165788894368794, 2.2379373313751585, 2.2589237745480006, 2.2795542378822287, 2.299843660537776, 2.3198059996753027, 2.3394543172183875, 2.3588008570800856, 2.3778571140979117, 2.3966338957345936, 2.4151413774467327, 2.433389152493941, 2.4513862768524377, 2.4691413098056603, 2.4866623507072427, 2.503957072346221, 2.521032751288612, 2.537896295521958, 2.5545542696886625, 2.5710129181589774, 2.5872781861643075, 2.603355739185456, 2.6192509807678506, 2.634969068916157, 2.6505149312036167, 2.665893278716504, 2.6811086189410545, 2.6961652676887455, 2.7110673601457576, 2.7258188611235457, 2.7404235745796397, 2.754885152470846, 2.76920710299489, 2.7833927982710756, 2.7974454815056897, 2.8113682736835606, 2.8251641798233025, 2.8388360948303406, 2.852386808978718, 2.865819013049896, 2.8791353031542957, 2.89233818525905, 2.9054300794434558, 2.9184133239017567, 2.931290178711256, 2.9440628293822817, 2.956733390205142, 2.96930390740802, 2.981776362138624, 2.9941526732814014, 3.006434700121207, 3.018624244863479, 3.030723055020205, 3.042732825670263, 3.054655201602091, 3.0664917793460353, 3.0782441091032147, 3.0899136965772227, 3.1015020047145656, 3.113010455359286, 3.1244404308268736, 3.135793275402187, 3.147070296765807, 3.158272767352924, 3.1694019256486143, 3.1804589774230614], [0.0, 0.6404796139209262, 0.8163300985042546, 0.9408009561704319, 1.0404622024491779, 1.1249800282334497, 1.1991078568791473, 1.265580063924133, 1.326132157455605, 1.3819431874071704, 1.4338552505068667, 1.4824933392242614, 1.5283356622873419, 1.5717572934021502, 1.6130585201978946, 1.6524839561331248, 1.690235834514863, 1.7264835051621168, 1.7613703758612638, 1.795019088550631, 1.82753544757105, 1.8590114476259652, 1.8895276404383021, 1.9191550077570927, 1.9479564604793544, 1.9759880508552479, 2.00329996187227, 2.0299373216996646, 2.0559408794061094, 2.081347569651402, 2.1061909877640517, 2.1305017919162843, 2.15430804555676, 2.1776355105514336, 2.2005078993957863, 2.222947093240096, 2.244973331199297, 2.266605375416585, 2.287860655553142, 2.3087553957387232, 2.329304726504346, 2.3495227838023145, 2.36942279687984, 2.389017166494869, 2.4083175347341275, 2.4273348475042646, 2.4460794106097836, 2.464560940200239, 2.4827886082591757, 2.500771083714708, 2.518516569673431, 2.536032837213038, 2.5533272561125746, 2.5704068228511074, 2.5872781861643075, 2.6039476704129947, 2.6204212969871663, 2.636704803942604, 2.652803664044313, 2.668723101371153, 2.684468106618726, 2.7000434512224634, 2.7154537004096313, 2.7307032252773835, 2.7457962139837577, 2.7607366821295627, 2.775528482401137, 2.790175313536963, 2.8046807286748847, 2.8190481431311536, 2.833280841657627, 2.847381985219042, 2.8613546173283897, 2.875201669974922, 2.8889259691761744, 2.9025302401826, 2.916017112360872, 2.9293891237796363, 2.9426487255194784, 2.955798285726979, 2.9688400934311012, 2.981776362138624, 2.9946092332239775, 3.0073407791275892, 3.019973006375729, 3.032507858433812, 3.0449472184041864, 3.0572929115785956, 3.069546707854709, 3.0817103240254147, 3.093785425948941, 3.1057736306072345, 3.117676508059537, 3.1294955832975493, 3.1412323380081677, 3.152888212249298, 3.164464606043933, 3.1759628808972606, 3.187384361241289, 3.198730335811142, 3.210002058956925, 3.2212007518947745], [0.0, 0.6483944656184197, 0.8264180568489509, 0.9524270874056852, 1.0533199169653644, 1.1388821882594347, 1.2139260659996478, 1.2812197163026715, 1.342520094135248, 1.3990208197704068, 1.4515743963106789, 1.500813539691923, 1.547222368199715, 1.5911805905865437, 1.6329922053445398, 1.6729048487907572, 1.7111232533697367, 1.7478188616738917, 1.7831368536792782, 1.8172013868958867, 1.8501195731623181, 1.8819845440245007, 1.9128778466389798, 1.9428713399255897, 1.9720287122150233, 2.00040670843405, 2.028056131716219, 2.0550226679109236, 2.081347569651402, 2.107068228024712, 2.132218653520183, 2.156829883174382, 2.180930327235508, 2.204546065926796, 2.227701104775514, 2.25041759533252, 2.272716026821556, 2.294615393242662, 2.3161333396474544, 2.337286290658535, 2.35808956378541, 2.378557469668168, 2.3987034010370234, 2.418539911894705, 2.438078788197297, 2.457331111117623, 2.476307313816175, 2.49501723251172, 2.513470152532377, 2.53167484993423, 2.5496396291953634, 2.567372357426078, 2.5848804954789, 2.602171126293252, 2.6192509807678506, 2.6361264614180384, 2.652803664044313, 2.669288397611599, 2.6855862025156627, 2.701702367392937, 2.717641944612517, 2.733409764573777, 2.749010448919672, 2.764448422764038, 2.779727926020893, 2.7948530239146163, 2.809827616741869, 2.824655448949015, 2.839340117582492, 2.8538850801639883, 2.868293662037322, 2.882569063229468, 2.896714364864224, 2.910732535163469, 2.9246264350678026, 2.9383988235054908, 2.9520523623361177, 2.965589620993008, 2.979013080846454, 2.992325139307869, 3.0055281136933374, 3.0186242448634792, 3.031615700655178, 3.044504579119447, 3.0572929115785956, 3.0699826655147917, 3.0825757473011883, 3.095074004785928, 3.107479229738534, 3.119793160167499, 3.132017482517217, 3.144153833751807, 3.1562038033328212, 3.1681689350973445, 3.1800507290425073, 3.1918506430220117, 3.203570094359908, 3.2152104613864494, 3.2267730849005707, 3.2382592695631915, 3.2496702852252937, 3.26100736819443], [0.0, 0.6561338432438416, 0.8362823628502692, 0.9637954646528334, 1.065892573010474, 1.1524761342185503, 1.2284157520353751, 1.2965126340115616, 1.3585447065111722, 1.4157198371189024, 1.4689007046000737, 1.518727577125823, 1.565690351523071, 1.6101732688307135, 1.6524839561331248, 1.6928730055883976, 1.7315475933721425, 1.7686812084529122, 1.8044207637065919, 1.8388918986142644, 1.8722030035247763, 1.9044483216224803, 1.935710373428552, 1.9660618755865504, 1.9955672766249613, 2.0242839987903647, 2.052263451613581, 2.0795518662602577, 2.1061909877640517, 2.132218653520183, 2.157669279974593, 2.1825742746286805, 2.2069623868415564, 2.230860008135684, 2.254291430573535, 2.2772790701117045, 2.299843660537776, 2.32200442256831, 2.343779211870106, 2.365184649113639, 2.3862362346415456, 2.4069484499088345, 2.4273348475042646, 2.447408131277878, 2.4671802278654984, 2.4866623507072423, 2.505865057496079, 2.5247983018580262, 2.543471479952902, 2.561893472589709, 2.5800726833705916, 2.598017073309393, 2.615734192313, 2.6332312078643443, 2.6505149312036163, 2.667591841267977, 2.684468106618726, 2.7011496055578608, 2.7176419446125166, 2.733950475545445, 2.750080311031918, 2.766036339128011, 2.781823236641615, 2.7974454815056897, 2.8129073642427906, 2.8282129986007005, 2.8433663314308717, 2.8583711518741963, 2.8732310999122412, 2.8879496743364266, 2.9025302401826, 2.9169760356739562, 2.931290178711256, 2.945475672945723, 2.9595354134667664, 2.9734721921338214, 2.9872887025790082, 3.000987544904968, 3.014571230100169, 3.028042184192049, 3.0414027521566824, 3.054655201602091, 3.0678017262409303, 3.0808444491670084, 3.0937854259489406, 3.10662664755319, 3.1193700431077955, 3.132017482517217, 3.14457077893793, 3.1570316911236747, 3.1694019256486134, 3.181683139016025, 3.193876939659621, 3.2059848898440637, 3.2180085074707736, 3.229949267794714, 3.2418086050574235, 3.253587914041205, 3.265288551549063, 3.2769118378146325, 3.2884590578461137, 3.2999314627078964], [0.0, 0.6637072976235352, 0.8459351896154252, 0.9749201171274218, 1.0781956859476753, 1.1657786418030374, 1.2425947960720953, 1.3114776893695335, 1.3742257698543912, 1.4320608469772562, 1.4858555570118765, 1.5362575584535356, 1.5837624027853001, 1.6287587661655303, 1.6715578264780486, 1.7124130683521983, 1.751534059303909, 1.7890962908059518, 1.8252483714826855, 1.8601173910145512, 1.8938129908508692, 1.9264305019821841, 1.9580533974264962, 1.9887552331624923, 2.018601201618694, 2.047649387840545, 2.0759517947556856, 2.10355518715507, 2.1305017919162843, 2.156829883174382, 2.1825742746286805, 2.207766736303074, 2.2324363493974437, 2.256609810059587, 2.280311690744199, 2.303564666145062, 2.3263897093704333, 2.348806262992859, 2.3708323887789757, 2.392484899244094, 2.4137794736442517, 2.434730760587304, 2.455352469093374, 2.475657449647264, 2.495657766548528, 2.5153647626689186, 2.5347891175640513, 2.55394089975012, 2.5728296138425395, 2.5914642431574486, 2.609853288295948, 2.628004802162241, 2.6459264218083547, 2.663625397448213, 2.681108618941054, 2.6983826400074613, 2.7154537004096313, 2.7323277463001254, 2.7490104489196714, 2.765507221803982, 2.781823236641615, 2.797963437909251, 2.813932556397046, 2.8297351217247044, 2.8453754739383297, 2.8608577742688235, 2.8761860151243486, 2.891364029382126, 2.9063954990383736, 2.921283963269469, 2.9360328259523367, 2.9506453626875087, 2.965124727364256, 2.97947395830358, 2.9936959840115906, 3.007793628572886, 3.0217696167109565, 3.035626578540244, 3.049367054032414, 3.062993497217436, 3.076508280138376, 3.0899136965772227, 3.1032119655676587, 3.1164052347093985, 3.1294955832975493, 3.142485025279395, 3.1553755120500213, 3.1681689350973445, 3.1808671285062804, 3.1934718713310626, 3.2059848898440637, 3.2184078596688246, 3.2307424078044766, 3.2429901145481903, 3.255152515321834, 3.267231102408566, 3.279227326604722, 3.2911425987919443, 3.302978291434195, 3.3147357400039663, 3.326416244341723, 3.338021069952322], [0.0, 0.6711235712592635, 0.8553876799929504, 0.98581388669645, 1.0902434580129832, 1.178805066911298, 1.2564795658478674, 1.3261321574556053, 1.3895813857757493, 1.4480627127729526, 1.5024585255695886, 1.5534237196050584, 1.601459383660892, 1.6469585369676984, 1.6902358345148627, 1.7315475933721425, 1.771105722765509, 1.8090876751116425, 1.845643719589527, 1.880902365981281, 1.9149744808711486, 1.9479564604793544, 1.9799327105524447, 2.0109776089845304, 2.0411570766651455, 2.0705298476827547, 2.099148506046364, 2.1270603390972846, 2.15430804555676, 2.180930327235508, 2.2069623868415564, 2.2324363493974437, 2.257381621056742, 2.2818251962703373, 2.3057919220658407, 2.3293047265043456, 2.352384817047884, 2.37505185352055, 2.3973240995113856, 2.4192185553989587, 2.4407510756395094, 2.46193647252462, 2.4827886082591757, 2.503320476919457, 2.5235442776116512, 2.543471479952902, 2.5631128828323133, 2.582478667271803, 2.601578444091479, 2.6204212969871663, 2.639015821545789, 2.657370160654801, 2.6754920367027455, 2.6933887809175276, 2.7110673601457576, 2.7285344013393753, 2.7457962139837577, 2.7628588106738494, 2.779727926020893, 2.796409034051517, 2.8129073642427906, 2.8292279163210403, 2.8453754739383297, 2.8613546173283897, 2.8771697350330543, 2.8928250347808704, 2.90832455359122, 2.9236721671699417, 2.9388715986559246, 2.9539264267723486, 2.9688400934311012, 2.9836159108343145, 2.998257068112859, 3.0127666375379727, 3.0271475803389287, 3.041402752156682, 3.0555349081608174, 3.0695467078547085, 3.083440719591696, 3.0972194248231104, 3.110885222097257, 3.124440430826873, 3.1378872948411516, 3.151227985737112, 3.1644646060439325, 3.1775991922127678, 3.1906337174436175, 3.2035700943599075, 3.21641017754064, 3.2291557659192254, 3.241808605057423, 3.254370389302213, 3.2668427638328357, 3.2792273266047216, 3.2915256301965616, 3.3037391835663055, 3.3158694537215054, 3.327917867309012, 3.3398858121287174, 3.3517746385757, 3.3635856610148585, 3.375320159091816], [0.0, 0.6783906896492914, 0.8646500629669477, 0.9964885620199742, 1.1020489266667925, 1.1915695060501816, 1.2700850867246478, 1.340491896558451, 1.4046281713089463, 1.4637427508770542, 1.5187275771258228, 1.5702446368901801, 1.6188004448846065, 1.6647922760645895, 1.7085381925939265, 1.7502972870170737, 1.790283763173839, 1.8286769949865331, 1.8656288787918809, 1.9012693159127552, 1.935710373428552, 1.9690494913653975, 2.0013719894394546, 2.0327530509299905, 2.0632593105368247, 2.092950138337968, 2.121878687737145, 2.1500927581165556, 2.1776355105514336, 2.204546065926796, 2.230860008135684, 2.256609810059587, 2.2818251962703373, 2.306533453522472, 2.330759697894339, 2.3545271057186494, 2.3778571140979112, 2.4007695957384305, 2.4232830119926256, 2.445414547324036, 2.4671802278654984, 2.4885950263003336, 2.5096729549373555, 2.5304271485564263, 2.5508699383591513, 2.571012918158977, 2.590867003778473, 2.6104424864825813, 2.629749081160124, 2.648795969867788, 2.667591841267977, 2.686144926421664, 2.7044630313376286, 2.722553566628413, 2.7404235745796397, 2.758079753901783, 2.775528482401137, 2.792775837778746, 2.809827616741869, 2.826689352591462, 2.8433663314308717, 2.859863607124894, 2.8761860151243486, 2.8923381852590495, 2.90832455359122, 2.9241493734118973, 2.9398167254544663, 2.95533052739202, 2.9706945426786624, 2.985912388789013, 3.000987544904968, 3.0159233590941343, 3.0307230550202044, 3.045389738221851, 3.0599264019933856, 3.074335932897463, 3.0886211159374324, 3.1027846394145335, 3.1168290994929726, 3.130757004493947, 3.1445707789379296, 3.1582727673529245, 3.1718652378649494, 3.1853503855857, 3.198730335811142, 3.2120071470437073, 3.22518281384977, 3.2382592695631915, 3.2512383888448877, 3.2641219901076335, 3.2769118378146325, 3.28960964465974, 3.3022170736366676, 3.3147357400039663, 3.327167213152093, 3.339513018378428, 3.3517746385757006, 3.3639535158389027, 3.3760510529954217, 3.3880686150628008, 3.4000075306382582, 3.4118690932237876], [0.0, 0.6855160398591242, 0.8737317538002618, 1.00695499396372, 1.1136240922324208, 1.204084934341738, 1.283425188788663, 1.3545715034312396, 1.419381421593598, 1.4791169001338713, 1.534679249260278, 1.5867374088631248, 1.6358032137398204, 1.6822781115493268, 1.7264835051621166, 1.7686812084529122, 1.8090876751116427, 1.8478841630811895, 1.8852241641131495, 1.9212389439247364, 1.9560417466710345, 1.989731035821329, 2.0223930272315247, 2.054103693854454, 2.0849303702750905, 2.114933050153998, 2.1441654451817733, 2.172675856792521, 2.2005078993957863, 2.227701104775514, 2.254291430573535, 2.280311690744199, 2.3057919220658407, 2.330759697894339, 2.355240398110091, 2.3792574424741004, 2.4028324932494876, 2.4259856318718254, 2.448735513598909, 2.4710995033880874, 2.493093795699699, 2.514733520479853, 2.5360328372130385, 2.5570050186378306, 2.5776625254743135, 2.598017073309393, 2.6180796926179464, 2.6378607827573, 2.6573701606548012, 2.6766171048091585, 2.6956103951425203, 2.714358349169277, 2.7328688548871662, 2.7511494007447186, 2.7692071029948906, 2.787048730706815, 2.804680728674885, 2.822109238436147, 2.8393401175824926, 2.8563789575328746, 2.8732310999122417, 2.889901651667716, 2.906395499038374, 2.922717320482585, 2.938871598655925, 2.954862631523082, 2.9706945426786624, 2.9863712909443096, 3.001896679302866, 3.0172743632244217, 3.0325078584338123, 3.047600548164448, 3.0625556899391735, 3.077376421915107, 3.0920657688260706, 3.1066266475531905, 3.121061872351581, 3.1353741597585523, 3.149566133206638, 3.163640327362719, 3.1775991922127687, 3.1914450969101025, 3.2051803334035784, 3.2188071198608386, 3.2323276039004982, 3.2457438656460873, 3.259057920613535, 3.272271722443115, 3.285387165485895, 3.2984060872540097, 3.3113302707433734, 3.3241614466368015, 3.336901295394951, 3.3495514492419396, 3.362113494052025, 3.374588971143263, 3.386979378983672, 3.399286174815019, 3.411510776199028, 3.4236545624904493, 3.435718876241175, 3.4477050245392546], [0.0, 0.6925064384421088, 0.8826414406034022, 1.0172231953677013, 1.1249800282334497, 1.2163633248233745, 1.2965126340115618, 1.3683844475019324, 1.4338552505068667, 1.4941998684111548, 1.5503288023350237, 1.602917813535734, 1.652483956133125, 1.6994327714600956, 1.7440889398219848, 1.7867169448827431, 1.82753544757105, 1.8667275541676722, 1.9044483216224806, 1.9408303542058818, 1.9759880508552483, 2.010020879099371, 2.043015933961325, 2.0750499631113692, 2.1061909877640517, 2.136499613352055, 2.1660300992790913, 2.194831239522483, 2.222947093240096, 2.25041759533252, 2.2772790701117045, 2.303564666145062, 2.3293047265043456, 2.3545271057186494, 2.3792574424741004, 2.403519395349549, 2.4273348475042646, 2.45072408514983, 2.4737059537769146, 2.4962979954181903, 2.5185165696734315, 2.540376960773035, 2.5618934725897096, 2.5830795132078532, 2.603947670412995, 2.6245097792591525, 2.6447769827020386, 2.664759786144131, 2.6844681066187266, 2.7039113172399794, 2.7230982874613563, 2.7420374196132657, 2.7607366821295627, 2.779203639820578, 2.7974454815056897, 2.8154690452801185, 2.8332808416576274, 2.850887074802231, 2.868293662037322, 2.885506251799115, 2.9025302401826005, 2.9193707862118674, 2.936032825952337, 2.952521085569926, 2.9688400934311017, 2.9849941913280977, 3.000987544904968, 3.016824153352566, 3.0325078584338123, 3.0480423528946474, 3.0634311883107346, 3.0786777824152614, 3.0937854259489415, 3.108757289069559, 3.1235964273549923, 3.138305787430619, 3.152888212249298, 3.1673464460496312, 3.181683139016025, 3.1959008516620684, 3.210002058956925, 3.2239891542128287, 3.237864452750281, 3.2516301953561975, 3.265288551549063, 3.2788416226640056, 3.292291444769736, 3.305639991428342, 3.3188891763081183, 3.3320408556588252, 3.345096830658084, 3.358058849636966, 3.3709286101922555, 3.383707761192315, 3.396397904683006, 3.4090005976996345, 3.421517353990516, 3.4339496456573193, 3.4462989047170405, 3.458566524590096, 3.4707538615187548, 3.482862235919809], [0.0, 0.6993681904144294, 0.8913871595017524, 1.027302427674634, 1.1361269771988887, 1.2284157520353751, 1.3093592266635825, 1.3819431874071706, 1.4480627127729526, 1.509005259848636, 1.565690351523071, 1.6188004448846067, 1.6688577173225996, 1.716271728506655, 1.7613703758612638, 1.8044207637065919, 1.8456437195895272, 1.8852241641131493, 1.923318690620744, 1.9600612173020742, 1.9955672766249615, 2.0299373216996646, 2.0632593105368247, 2.095610751266747, 2.127060339097284, 2.157669279974593, 2.1874923709357565, 2.2165788894368794, 2.244973331199297, 2.272716026821556, 2.299843660537776, 2.3263897093704333, 2.352384817047884, 2.3778571140979112, 2.4028324932494876, 2.4273348475042646, 2.4513862768524373, 2.475007268513036, 2.4982168547086885, 2.521032751288612, 2.5434714799529026, 2.5655484763769, 2.5872781861643075, 2.608674150254534, 2.629749081160124, 2.6505149312036163, 2.670982953751535, 2.6911637582999273, 2.7110673601457576, 2.7307032252773835, 2.7500803110319185, 2.76920710299489, 2.788091648555978, 2.8067415874820045, 2.825164179823302, 2.843366331430872, 2.8613546173283897, 2.8791353031542952, 2.896714364864224, 2.914097506862343, 2.931290178711256, 2.9482975905536284, 2.965124727364256, 2.981776362138624, 2.998257068112859, 3.0145712301001693, 3.0307230550202044, 3.0467165816900996, 3.062555689939173, 3.0782441091032147, 3.093785425948941, 3.1091830920744052, 3.124440430826873, 3.1395606437758743, 3.1545468167757087, 3.169401925648614, 3.18412884151706, 3.1987303358111423, 3.2132090849748187, 3.2275676748927187, 3.2418086050574235, 3.255934292495481, 3.2699470754689193, 3.2838492169676594, 3.297642908007022, 3.311330270743373, 3.3249133614199615, 3.338394173154064, 3.3517746385757006, 3.3650566323274216, 3.378241973433952, 3.3913324275498327, 3.4043297090926123, 3.4172354832685903, 3.4300513679976183, 3.4427789357430045, 3.4554197152521526, 3.4679751932131615, 3.4804468158322748, 3.4928359903367197, 3.5051440864071934, 3.517372437543937], [0.0, 0.7061071406767596, 0.8999763601755811, 1.0372012764632357, 1.147074434197895, 1.24025248234123, 1.3219759095853212, 1.3952592726008426, 1.4620159104331567, 1.5235456858089427, 1.58077698192711, 1.6343988318747997, 1.6849384446220188, 1.7328093262607023, 1.7783425337591472, 1.821807745193023, 1.8634279159524265, 1.903389748492635, 1.9418513450542014, 1.9789479142316182, 2.0147961017368674, 2.049497328623164, 2.083140400444214, 2.1158035721807527, 2.147556200971782, 2.178460082529811, 2.2085705419035087, 2.2379373313751585, 2.266605375416585, 2.294615393242662, 2.32200442256831, 2.348806262992859, 2.37505185352055, 2.4007695957384305, 2.4259856318718254, 2.45072408514983, 2.475007268513036, 2.4988558665905827, 2.522289094995197, 2.5453248402819244, 2.567979783350146, 2.5902695086098007, 2.612208600859092, 2.6338107315147914, 2.6550887355842763, 2.6760546805599033, 2.696719928243036, 2.717095190360373, 2.7371905787139665, 2.7570156505042505, 2.7765794493791676, 2.7958905426893885, 2.814957055367379, 2.8337867007949886, 2.8523868089787174, 2.8707643523127513, 2.8889259691761744, 2.90687798558167, 2.924626435067802, 2.9421770770050584, 2.9595354134667664, 2.9767067047993234, 2.9936959840115906, 3.010508070090535, 3.0271475803389287, 3.043618941821027, 3.059926401993385, 3.0760740385902476, 3.09206576882607, 3.107905357971661, 3.123596427354992, 3.1391424618329173, 3.1545468167757087, 3.169812724602481, 3.1849433009021118, 3.1999415501711743, 3.214810371197612, 3.2295525621163796, 3.2441708251610306, 3.258667771133181, 3.2730459236099447, 3.287307722907779, 3.3014555298196653, 3.315491629141172, 3.3294182329997364, 3.3432374840003334, 3.3569514581996973, 3.370562167920321, 3.3840715644146018, 3.397481540388712, 3.410793932395078, 3.4240105231016806, 3.4371330434457996, 3.450163174679277, 3.463102550311867, 3.4759527579587703, 3.488715341098047, 3.5013918007431797, 3.513983597035721, 3.5264921507626146, 3.5389188448024838, 3.5512650255048697], [0.0, 0.7127287190266077, 0.9084159632310074, 1.0469277175668923, 1.1578312199625445, 1.2518830529902465, 1.3343728484599815, 1.4083434322979447, 1.4757260860452872, 1.5378328619993549, 1.5956008493496017, 1.6497255426481632, 1.7007390948109447, 1.7490588896175974, 1.7950190885506307, 1.8388918986142644, 1.880902365981281, 1.9212389439247364, 1.9600612173020742, 1.9975056626376098, 2.033690019498176, 2.068716660021337, 2.1026752225422527, 2.1356446958842406, 2.1676950875886316, 2.198888772862361, 2.229281595569337, 2.2589237745480006, 2.287860655553142, 2.3161333396474544, 2.343779211870106, 2.3708323887789757, 2.3973240995113856, 2.4232830119926256, 2.448735513598909, 2.4737059537769146, 2.4982168547086885, 2.522289094995197, 2.5459420704451703, 2.569193835346311, 2.5920612270245176, 2.614559976033829, 2.6367048039426044, 2.6585095103724603, 2.679987050692123, 2.7011496055578603, 2.722008643317272, 2.7425749761471634, 2.7628588106738494, 2.7828697937212055, 2.8026170537447337, 2.8221092384361466, 2.8413545489201395, 2.860360770911441, 2.8791353031542952, 2.8976851834270936, 2.916017112360872, 2.9341374752910223, 2.9520523623361172, 2.96976758687562, 2.9872887025790082, 3.004621019122014, 3.0217696167109565, 3.0387393595232535, 3.0555349081608174, 3.0721607312030663, 3.088621115937432, 3.10492017833745, 3.121061872351581, 3.137049998559771, 3.1528882122492976, 3.168580030956549, 3.18412884151706, 3.199537906662224, 3.214810371197612, 3.229949267794714, 3.2449575224250977, 3.2598379594634603, 3.274593306483775, 3.2892261987706677, 3.3037391835663055, 3.3181347240714163, 3.3324152032175127, 3.346582927226024, 3.3606401289687975, 3.3745889711432624, 3.3884315492745474, 3.402169894555868, 3.415805976537652, 3.4293417056750806, 3.442778935743004, 3.45611946612652, 3.4693650439949164, 3.4825173663661135, 3.495578082068239, 3.5085487936044872, 3.5214310589270124, 3.5342263931251745, 3.5469362700331253, 3.559562123761357, 3.5721053501565505, 3.5845673081937526], [0.0, 0.7192379797067615, 0.9167124106068887, 1.0564891751663956, 1.168405545134469, 1.2633163415830078, 1.346559505856091, 1.4212056536218303, 1.4892037045698934, 1.551877693804269, 1.6101732688307135, 1.6647922760645895, 1.7162717285066549, 1.765032821849499, 1.8114127694299218, 1.8556862642840672, 1.8980804079027727, 1.9387853746788513, 1.9779622069379392, 2.0157486276270786, 2.052263451613581, 2.0876099859867145, 2.121878687737145, 2.1551492670830603, 2.1874923709357565, 2.218970944166995, 2.2496413406555846, 2.2795542378822287, 2.3087553957387232, 2.337286290658535, 2.365184649113639, 2.392484899244094, 2.4192185553989587, 2.445414547324036, 2.4710995033880874, 2.4962979954181903, 2.521032751288612, 2.5453248402819244, 2.569193835346311, 2.592657955656985, 2.6157341923130004, 2.6384384195335433, 2.6607854933371833, 2.6827893393757254, 2.704463031337629, 2.725818861123545, 2.7468684018200333, 2.7676225643501327, 2.7880916485559784, 2.8082853893646593, 2.8282129986007005, 2.8478832029340824, 2.867304278389328, 2.886484081787108, 2.9054300794434558, 2.9241493734118973, 2.9426487255194784, 2.9609345794180477, 2.979013080846454, 2.9968900962770166, 3.014571230100169, 3.0320618404842357, 3.0493670540324143, 3.066491779346036, 3.083440719591696, 3.100218384159781, 3.1168290994929726, 3.133277019155469, 3.149566133206638, 3.16570027693664, 3.181683139016025, 3.1975182691063937, 3.213209084974819, 3.228758879150804, 3.2441708251610306, 3.2594479833739896, 3.2745933064837756, 3.2896096446597403, 3.304499750386443, 3.319266283016228, 3.3339118130549013, 3.34843882619929, 3.3628497271439164, 3.377146843172637, 3.3913324275498327, 3.405408662724574, 3.4193776633601534, 3.4332414792004156, 3.4470020977834417, 3.4606614470123573, 3.4742213975923026, 3.4876837653419295, 3.501050313387201, 3.5143227542446858, 3.52750275180105, 3.540591923194945, 3.5535918406071034, 3.566504032964004, 3.5793299875601385, 3.5920711516035464, 3.6047289336890005, 3.617304705202893], [0.0, 0.7256396362752623, 0.9248717100187196, 1.0658925730104742, 1.178805066911298, 1.2745606273192622, 1.3585447065111724, 1.433855250506867, 1.5024585255695886, 1.565690351523071, 1.6245047927124712, 1.679609942414194, 1.7315475933721427, 1.780742690177391, 1.8275354475710497, 1.8722030035247763, 1.9149744808711489, 1.9560417466710345, 1.9955672766249615, 2.033690019498176, 2.070529847682755, 2.1061909877640517, 2.1407647018551046, 2.174331409643645, 2.206962386841557, 2.23872113856834, 2.269664520286686, 2.299843660537776, 2.329304726504346, 2.35808956378541, 2.3862362346415456, 2.4137794736442517, 2.4407510756395094, 2.4671802278654984, 2.493093795699699, 2.5185165696734315, 2.5434714799529026, 2.567979783350146, 2.5920612270245176, 2.6157341923130004, 2.639015821545789, 2.6619221302323, 2.6844681066187266, 2.7066678003036655, 2.7285344013393753, 2.750080311031918, 2.7713172054753796, 2.792256092706667, 2.812907364242791, 2.8332808416576274, 2.853385818766556, 2.8732310999122412, 2.8928250347808704, 2.9121755501236093, 2.931290178711256, 2.950176085809944, 2.9688400934311017, 2.9872887025790087, 3.0055281136933374, 3.0235642454615865, 3.041402752156683, 3.059049039637915, 3.0765082801383765, 3.0937854259489415, 3.1108852220972576, 3.1278122181100336, 3.14457077893793, 3.161165095114398, 3.1775991922127687, 3.1938769396596216, 3.210002058956925, 3.2259781313604305, 3.2418086050574235, 3.257496801882927, 3.2730459236099447, 3.2884590578461137, 3.303739183566306, 3.3188891763081183, 3.3339118130549013, 3.3488097768288565, 3.363585661014859, 3.3782419734339526, 3.392781140183908, 3.4072055092628264, 3.4215173539905157, 3.4357188762411743, 3.4498122094998873, 3.463799421754469, 3.4776825182333018, 3.4914634439990246, 3.5051440864071934, 3.5187262774383536, 3.5322117959113646, 3.545602369585237, 3.5588996771562416, 3.5721053501565505, 3.585220974760264, 3.5982480935022383, 3.6111882069147927, 3.624042775087001, 3.6368132191509885, 3.6495009226993216], [0.0, 0.7319380924527448, 0.9328994742754344, 1.0751443797274707, 1.1890369391583075, 1.2856236451801963, 1.3703366950842242, 1.4463009246524074, 1.5154996670793879, 1.579280336928491, 1.6386052796973474, 1.6941887348184534, 1.746577197725153, 1.79619930147143, 1.8433982138174012, 1.8884534782557054, 1.9315962063748375, 1.9730199306164056, 2.012888536948553, 2.051342180193452, 2.0885017732197064, 2.1244724472856595, 2.159346256647435, 2.1932043190250297, 2.22611852879409, 2.258152942290163, 2.289364908473846, 2.3198059996753027, 2.3495227838023145, 2.378557469668168, 2.4069484499088345, 2.434730760587304, 2.46193647252462, 2.4885950263003336, 2.514733520479853, 2.540376960773035, 2.5655484763769, 2.5902695086098007, 2.614559976033829, 2.6384384195335433, 2.6619221302323, 2.685027262652022, 2.7077689351348986, 2.7301613192281864, 2.752217719472055, 2.7739506448142657, 2.795371872695857, 2.8164925067020428, 2.8373230285468285, 2.857873345054054, 2.878152830708188, 2.8981703662724265, 2.9179343739071304, 2.937452849166617, 2.9567333902051414, 2.9757832244823987, 2.994609233223977, 3.0132179738620133, 3.0316157006551774, 3.049808383664393, 3.06780172624093, 3.0856011811662207, 3.1032119655676587, 3.1206390747213484, 3.137887294841151, 3.154961214943066, 3.171865237864949, 3.1886035905135284, 3.205180333403578, 3.2215993695477914, 3.23786445275028, 3.2539791953516244, 3.269947075468919, 3.285771443770275, 3.301455529819665, 3.31700244802475, 3.3324152032175123, 3.3476966958948347, 3.3628497271439155, 3.3778770032752354, 3.392781140183907, 3.40756466745853, 3.422230032255083, 3.436779602951981, 3.4512156726011463, 3.465540462188755, 3.4797561237182615, 3.4938647431273404, 3.507868343049492, 3.521768885430242, 3.5355682740071424, 3.5492683566620884, 3.562870927653852, 3.576377729738164, 3.5897904561821568, 3.6031107526794868, 3.616340219172035, 3.629480411583656, 3.642532843471093, 3.655498987596799, 3.6683802774281387, 3.681178108567079], [0.0, 0.7381374694973788, 0.9408009561704319, 1.0842506490364152, 1.1991078568791473, 1.2965126340115618, 1.3819431874071706, 1.4585508196153507, 1.528335662287342, 1.5926565423326775, 1.652483956133125, 1.708538192593927, 1.761370375861264, 1.8114127694299222, 1.8590114476259652, 1.9044483216224803, 1.947956460479355, 1.9897310358213292, 2.0299373216996646, 2.068716660021337, 2.106190987764052, 2.1424663266280035, 2.1776355105514336, 2.2117803443060664, 2.244973331199297, 2.277279070111705, 2.3087553957387232, 2.3394543172183875, 2.36942279687984, 2.3987034010370234, 2.4273348475042646, 2.455352469093374, 2.4827886082591757, 2.5096729549373555, 2.5360328372130385, 2.5618934725897096, 2.5872781861643075, 2.612208600859092, 2.6367048039426044, 2.6607854933371833, 2.6844681066187266, 2.7077689351348986, 2.730703225277384, 2.753285268623762, 2.7755284824011373, 2.7974454815056897, 2.819048143131154, 2.840347664908008, 2.86135461732839, 2.8820789911250615, 2.9025302401826005, 2.922717320482585, 2.9426487255194784, 2.962332518568431, 2.981776362138624, 3.0009875449049686, 3.01997300637573, 3.0387393595232535, 3.057292911578596, 3.0756396831679673, 3.0937854259489415, 3.111735638886978, 3.12949558329755, 3.147070296765807, 3.164464606043933, 3.1816831390160254, 3.1987303358111423, 3.2156104591371113, 3.2323276039004987, 3.2488857061717753, 3.265288551549063, 3.281539782968783, 3.2976429080070226, 3.3136013057114186, 3.329418232999737, 3.345096830658084, 3.360640128968798, 3.376051052995422, 3.3913324275498327, 3.4064869818644476, 3.421517353990516, 3.436426094941774, 3.451215672601147, 3.465888475406768, 3.4804468158322743, 3.494892933675175, 3.509228999165985, 3.523457115909877, 3.537579323671673, 3.551597601014207, 3.565513867799327, 3.5793299875601385, 3.5930477697524448, 3.6066689718927876, 3.620195301589952, 3.6336284184763077, 3.64696993604494, 3.6602214233980854, 3.673384406912025, 3.6864603718232307, 3.6994507637402645, 3.712356990085578], [0.0, 0.7442416305711558, 0.9485810795378828, 1.0932170555386787, 1.2090240957989868, 1.3072343793222048, 1.393371416103495, 1.4706125689576297, 1.5409745099856604, 1.6058273031615828, 1.6661494705622155, 1.7226672576519502, 1.775936346197599, 1.826392574374963, 1.874384878434228, 1.9201975008638266, 1.9640654381303162, 2.0061854758654265, 2.046724254884026, 2.085824285945509, 2.123608514407434, 2.1601838387355867, 2.1956438605752227, 2.230071061197395, 2.26353854348869, 2.2961114405417935, 2.3278480653265947, 2.3588008570800856, 2.389017166494869, 2.418539911894705, 2.447408131277878, 2.475657449647264, 2.503320476919457, 2.5304271485564263, 2.5570050186378306, 2.5830795132078532, 2.608674150254534, 2.6338107315147914, 2.6585095103724603, 2.6827893393757254, 2.7066678003036655, 2.7301613192281864, 2.753285268623762, 2.776054058254751, 2.798481216304442, 2.8205794619901754, 2.8423607707262843, 2.8638364327440735, 2.885017105950274, 2.905912863697816, 2.926533238051883, 2.946887259057159, 2.9669834904465953, 2.986830062176049, 3.006434700121207, 3.025804753231992, 3.0449472184041864, 3.0638687632973043, 3.0825757473011883, 3.101074240830704, 3.119370043107796, 3.137468698572611, 3.1553755120500218, 3.173095562784396, 3.190633717443618, 3.2079946421829066, 3.2251828138497705, 3.2422025304032682, 3.259057920613535, 3.2757529531010876, 3.292291444769736, 3.30867706868182, 3.324913361419962, 3.3410037299754425, 3.3569514581996973, 3.3727597128521305, 3.388431549274548, 3.403969916719832, 3.4193776633601534, 3.434657540997808, 3.4498122094998873, 3.4648442409761957, 3.4797561237182624, 3.4945502659158394, 3.5092289991659844, 3.5237945817886147, 3.538249201961359, 3.552594980685533, 3.5668339745941617, 3.5809681786121614, 3.594999528478025, 3.608929903135681, 3.6227611270045545, 3.6364949721352877, 3.650133160258044, 3.663677364729823, 3.6771292123867836, 3.690490285307135, 3.703762122489802, 3.7169462214536897, 3.7300440397620798, 3.743056996476359], [0.0, 0.7502542024900443, 0.9562444669746236, 1.1020489266667925, 1.2187915476977498, 1.3177952514874536, 1.4046281713089468, 1.4824933392242614, 1.5534237196050582, 1.6188004448846065, 1.6796099424141937, 1.7365843248428812, 1.790283763173839, 1.8411476166280092, 1.8895276404383021, 1.935710373428552, 1.979932710552445, 2.0223930272315247, 2.0632593105368247, 2.1026752225422527, 2.1407647018551046, 2.1776355105514336, 2.2133820064645398, 2.2480873372143537, 2.2818251962703378, 2.3146612429217615, 2.3466542612367594, 2.3778571140979117, 2.4083175347341275, 2.438078788197297, 2.4671802278654984, 2.495657766548528, 2.5235442776116512, 2.5508699383591513, 2.5776625254743135, 2.603947670412995, 2.629749081160124, 2.6550887355842763, 2.679987050692123, 2.704463031337629, 2.7285344013393753, 2.752217719472055, 2.7755284824011373, 2.798481216304442, 2.821089558656611, 2.8433663314308717, 2.8653236067884165, 2.886972766171958, 2.9083245535912203, 2.9293891237796363, 2.950176085809944, 2.9706945426786624, 2.9909531273033436, 3.0109600353200534, 3.0307230550202044, 3.050249594724345, 3.069546707854709, 3.0886211159374324, 3.1074792297385336, 3.126127168714486, 3.14457077893793, 3.162815649641382, 3.1808671285062804, 3.1987303358111423, 3.2164101775406406, 3.2339113575468827, 3.2512383888448873, 3.2683956041160243, 3.285387165485895, 3.302217073636668, 3.3188891763081183, 3.335407176236486, 3.351774638575701, 3.367994997841412, 3.3840715644146018, 3.4000075306382582, 3.415805976537652, 3.4314698751920614, 3.4470020977834412, 3.462405418345322, 3.4776825182333018, 3.4928359903367205, 3.5078683430494926, 3.52278200401663, 3.5375793236716726, 3.5522625785790307, 3.5668339745941617, 3.581295649853504, 3.595649677605191, 3.609898068890717, 3.624042775087001, 3.6380856903175647, 3.6520286537409348, 3.6658734517237788, 3.6796218199057567, 3.693275445162568, 3.7068359674732387, 3.720304981697257, 3.733684039266797, 3.746974649798904, 3.7601782826322077, 3.7732963682923932], [0.0, 0.756178595191623, 0.9637954646528334, 1.110751271280469, 1.2284157520353751, 1.3282012399433343, 1.4157198371189026, 1.4941998684111548, 1.5656903515230707, 1.6315833250193086, 1.6928730055883978, 1.7502972870170739, 1.8044207637065919, 1.8556862642840675, 1.9044483216224801, 1.950995737203455, 1.9955672766249613, 2.0383628817828066, 2.0795518662602577, 2.119279026560778, 2.157669279974593, 2.1948312395224825, 2.230860008135684, 2.26583939001046, 2.299843660537776, 2.332938997486388, 2.365184649113639, 2.3966338957345936, 2.4273348475042646, 2.457331111117623, 2.4866623507072423, 2.5153647626689186, 2.543471479952902, 2.571012918158977, 2.598017073309393, 2.6245097792591525, 2.6505149312036163, 2.6760546805599033, 2.7011496055578603, 2.725818861123545, 2.750080311031918, 2.7739506448142657, 2.7974454815056897, 2.8205794619901754, 2.8433663314308717, 2.8658190130498955, 2.8879496743364266, 2.9097697866068986, 2.931290178711256, 2.952521085569926, 2.973472192133822, 2.994152673281401, 3.014571230100169, 3.0347361229431438, 3.054655201602091, 3.074335932897463, 3.093785425948941, 3.1130104553592854, 3.132017482517217, 3.1508126752015815, 3.169401925648614, 3.1877908672262816, 3.2059848898440637, 3.2239891542128283, 3.241808605057423, 3.25944798337399, 3.2769118378146325, 3.2942045352737988, 3.3113302707433734, 3.3282930764969665, 3.3450968306580835, 3.361745265201673, 3.378241973433952, 3.39459041699127, 3.410793932395078, 3.426855737196745, 3.4427789357430045, 3.458566524590096, 3.4742213975923026, 3.4897463506883484, 3.5051440864071934, 3.5204172181129643, 3.535568274007143, 3.550599700904673, 3.5655138677993268, 3.5803130692324356, 3.594999528478025, 3.6095754005563583, 3.6240427750870015, 3.638403678991665, 3.6526600790563437, 3.666813884361531, 3.6808669485886947, 3.6948210722105714, 3.708678004572324, 3.7224394458700893, 3.7361070490330106, 3.7496824215144056, 3.7631671269973537, 3.776562687019613, 3.7898705825224654, 3.803092255327763], [0.0, 0.7620180192048306, 0.9712381645862904, 1.1193288053279282, 1.2379019243315112, 1.3384579838715749, 1.4266524242952847, 1.5057385004851305, 1.5777810532356926, 1.6441828708253525, 1.7059458475638294, 1.7638135754614324, 1.818355008876344, 1.8700163960830165, 1.9191550077570927, 1.9660618755865504, 2.010977608984531, 2.054103693854454, 2.095610751266747, 2.1356446958842406, 2.174331409643645, 2.2117803443060664, 2.2480873372143537, 2.283336839724368, 2.3176037008025556, 2.3509546092610356, 2.383449270888875, 2.4151413774467327, 2.4460794106097836, 2.476307313816175, 2.505865057496079, 2.5347891175640513, 2.5631128828323133, 2.590867003778473, 2.6180796926179464, 2.6447769827020386, 2.670982953751535, 2.696719928243036, 2.722008643317272, 2.7468684018200333, 2.7713172054753796, 2.795371872695857, 2.819048143131154, 2.8423607707262843, 2.8653236067884165, 2.8879496743364266, 2.9102512348202723, 2.9322398481411223, 2.953926426772349, 2.975321284671317, 2.9964341815788567, 3.017274363224421, 3.0378505978877626, 3.0581712097106717, 3.0782441091032147, 3.098076820546735, 3.117676508059537, 3.137049998559771, 3.1562038033328212, 3.175144137786857, 3.1938769396596216, 3.212407885821536, 3.2307424078044766, 3.248885706171775, 3.2668427638328357, 3.284618358395108, 3.3022170736366676, 3.3196433101743508, 3.336901295394951, 3.3539950927104303, 3.3709286101922555, 3.3877056086347364, 3.404329709092613, 3.420804399933964, 3.4371330434457996, 3.4533188820263265, 3.4693650439949164, 3.485274549048061, 3.501050313387201, 3.5166951545420853, 3.532211795911364, 3.5476028710402985, 3.5628709276538526, 3.5780184314619654, 3.5930477697524443, 3.6079612547857165, 3.6227611270045545, 3.6374495580708954, 3.6520286537409348, 3.666500456588845, 3.6808669485886947, 3.695130053563435, 3.7092916395091837, 3.7233535208024344, 3.737317460297287, 3.75118517131927, 3.7649583195619116, 3.7786385248917367, 3.7922273630670267, 3.805726367375281, 3.8191370301940277, 3.832460804479273], [0.0, 0.7677755013655932, 0.9785764246608915, 1.127785974930595, 1.2472549816956267, 1.3485707998035554, 1.4374315996894047, 1.5171152164378094, 1.5897020918970526, 1.6566056132136318, 1.7188352445820587, 1.777140196275763, 1.832093721428658, 1.884145439976252, 1.9336553219785724, 1.9809165980345276, 2.026171695499051, 2.069623622616853, 2.1114442895981775, 2.1517807135746247, 2.190759727592966, 2.2284916103849914, 2.265072923399513, 2.3005887560707077, 2.335114522891792, 2.36871741654702, 2.401457593936859, 2.433389152493941, 2.464560940200239, 2.49501723251172, 2.5247983018580262, 2.55394089975012, 2.582478667271803, 2.6104424864825813, 2.6378607827573, 2.664759786144131, 2.6911637582999273, 2.717095190360373, 2.7425749761471634, 2.7676225643501327, 2.792256092706667, 2.8164925067020428, 2.840347664908008, 2.8638364327440735, 2.886972766171958, 2.9097697866068986, 2.9322398481411223, 2.9543945980174655, 2.976245031159282, 2.997801539451785, 3.019073956376232, 3.0400715975188524, 3.0608032974087687, 3.0812774430814263, 3.1015020047145656, 3.121484563641292, 3.1412323380081677, 3.1607522063146156, 3.1800507290425073, 3.199134168560977, 3.218008507470774, 3.236679465534323, 3.255152515321834, 3.273432896689868, 3.2915256301965616, 3.309435529546923, 3.327167213152093, 3.3447251148780874, 3.3621134940520245, 3.37933644478727, 3.3963979046830057, 3.4133016629484954, 3.4300513679976183, 3.4466505345550718, 3.463102550311867, 3.479410682164384, 3.495578082068239, 3.5116077925354574, 3.52750275180105, 3.543265798682816, 3.558899677156241, 3.5744070406645267, 3.5897904561821576, 3.6050524080489215, 3.6201953015899515, 3.6352214665361258, 3.650133160258044, 3.6649325708257914, 3.6796218199057567, 3.6942029655049287, 3.708678004572324, 3.723048875466478, 3.7373174602972865, 3.7514855871498973, 3.7655550321977804, 3.77952752171162, 3.7934047339702115, 3.807188301079098, 3.820879810702317, 3.834480807712232, 3.8479927957621376, 3.861417238785953], [0.0, 0.7734538989878239, 0.98581388669645, 1.1361269771988889, 1.2564795658478674, 1.3585447065111724, 1.4480627127729528, 1.528335662287342, 1.601459383660892, 1.6688577173225996, 1.7315475933721427, 1.7902837631738393, 1.8456437195895272, 1.8980804079027729, 1.9479564604793544, 1.9955672766249613, 2.0411570766651455, 2.0849303702750905, 2.1270603390972846, 2.167695087588632, 2.206962386841557, 2.244973331199297, 2.2818251962703378, 2.3176037008025556, 2.3523848170478843, 2.3862362346415456, 2.419218555398959, 2.4513862768524377, 2.4827886082591757, 2.513470152532377, 2.543471479952902, 2.5728296138425395, 2.601578444091479, 2.629749081160124, 2.6573701606548012, 2.6844681066187266, 2.7110673601457576, 2.7371905787139665, 2.7628588106738494, 2.7880916485559784, 2.812907364242791, 2.8373230285468285, 2.86135461732839, 2.885017105950274, 2.9083245535912203, 2.931290178711256, 2.953926426772349, 2.976245031159282, 2.998257068112859, 3.01997300637573, 3.041402752156683, 3.062555689939173, 3.0834407195916964, 3.1040662901794467, 3.124440430826873, 3.14457077893793, 3.164464606043933, 3.1841288415170603, 3.203570094359908, 3.222794673257523, 3.2418086050574235, 3.260617651824877, 3.279227326604722, 3.2976429080070226, 3.315869453721506, 3.3339118130549017, 3.3517746385757006, 3.369462396942386, 3.3869793789836717, 3.404329709092613, 3.421517353990516, 3.438546130911291, 3.455419715252153, 3.4721416477323834, 3.4887153410980476, 3.5051440864071934, 3.5214310589270124, 3.537579323671673, 3.5535918406071034, 3.569471469546741, 3.5852209747602637, 3.600843029315497, 3.6163402191720353, 3.6317150470436164, 3.6469699360449397, 3.66210723313736, 3.6771292123867836, 3.692038078046063, 3.7068359674732387, 3.7215249538961315, 3.7361070490330106, 3.750584205578334, 3.7649583195619116, 3.779231232589242, 3.7934047339702115, 3.807480562742846, 3.8214604095983375, 3.8353459187131334, 3.8491386894934885, 3.862840278237502, 3.876452199719352, 3.8899759287000792], [0.0, 0.7790559126704492, 0.9929539927700279, 1.1443557790444765, 1.265580063924133, 1.3683844475019324, 1.458550819615351, 1.5394051743849373, 1.6130585201978949, 1.6809450101515977, 1.744088939821985, 1.8032505271273294, 1.8590114476259654, 1.9118279272180276, 1.9620652247625836, 2.010020879099371, 2.05594087940611, 2.100031216591706, 2.142466326628004, 2.183395386670869, 2.222947093240096, 2.2612333453190336, 2.298352123069199, 2.3343897660868467, 2.36942279687984, 2.403519395349549, 2.436740602241494, 2.4691413098056603, 2.500771083714708, 2.53167484993423, 2.561893472589709, 2.5914642431574486, 2.6204212969871663, 2.648795969867788, 2.6766171048091585, 2.7039113172399794, 2.7307032252773835, 2.7570156505042505, 2.7828697937212055, 2.8082853893646593, 2.8332808416576274, 2.857873345054054, 2.8820789911250615, 2.905912863697816, 2.9293891237796363, 2.952521085569926, 2.975321284671317, 2.997801539451785, 3.01997300637573, 3.0418462300093756, 3.0634311883107346, 3.084737333733707, 3.105773630607235, 3.12654858919186, 3.147070296765807, 3.1673464460496312, 3.187384361241289, 3.20719102190139, 3.2267730849005707, 3.2461369046167636, 3.2652885515490633, 3.2842338294965345, 3.302978291434195, 3.3215272542043106, 3.339885812128718, 3.3580588496369663, 3.3760510529954217, 3.393866921213922, 3.411510776199028, 3.4289867722161707, 3.44629890471704, 3.4634510185832146, 3.4804468158322748, 3.497289862828415, 3.5139835970357214, 3.5305313333488955, 3.5469362700331257, 3.5632014943020303, 3.5793299875601385, 3.5953246303340993, 3.6111882069147927, 3.6269234097306833, 3.6425328434710935, 3.658019028976552, 3.673384406912024, 3.6886313412375626, 3.703762122489802, 3.718778970886676, 3.733684039266797, 3.7484794158740726, 3.7631671269973537, 3.7777491394741793, 3.7922273630670267, 3.806603652719873, 3.820879810702317, 3.8350575886479814, 3.8491386894934885, 3.863124769323815, 3.8770174391294825, 3.89081826648063, 3.904528777122723, 3.918150456498282], [0.0, 0.7845840978967508, 1.0, 1.1524761342185506, 1.2745606273192622, 1.378094511392791, 1.468900704600074, 1.5503288023350237, 1.6245047927124712, 1.6928730055883978, 1.7564650049460275, 1.8160464032143424, 1.8722030035247763, 1.9253942691590693, 1.9759880508552479, 2.0242839987903647, 2.070529847682755, 2.114933050153998, 2.157669279974593, 2.1988887728623614, 2.23872113856834, 2.2772790701117045, 2.314661242921762, 2.3509546092610356, 2.3862362346415456, 2.4205747827696316, 2.4540317275362953, 2.4866623507072427, 2.518516569673431, 2.5496396291953634, 2.5800726833705916, 2.609853288295948, 2.639015821545789, 2.667591841267977, 2.6956103951425203, 2.7230982874613563, 2.7500803110319185, 2.7765794493791676, 2.8026170537447337, 2.8282129986007005, 2.853385818766556, 2.878152830708188, 2.9025302401826005, 2.926533238051883, 2.950176085809944, 2.973472192133822, 2.9964341815788567, 3.019073956376232, 3.041402752156683, 3.0634311883107346, 3.0851693136000486, 3.1066266475531905, 3.127812218110033, 3.1487345959199753, 3.169401925648614, 3.189821954604095, 3.210002058956925, 3.2299492677947144, 3.249670285225293, 3.269171510717296, 3.2884590578461137, 3.3075387715946025, 3.3264162443417233, 3.345096830658084, 3.3635856610148585, 3.3818876545015373, 3.4000075306382582, 3.4179498203598593, 3.4357188762411743, 3.453318882026327, 3.4707538615187548, 3.488027686883337, 3.5051440864071934, 3.5221066517614585, 3.5389188448024838, 3.5555840039474824, 3.5721053501565505, 3.588485992550192, 3.6047289336890005, 3.620837074539858, 3.636813219150988, 3.652660079056344, 3.668380277428139, 3.6839763529947995, 3.6994507637402636, 3.7148058903992585, 3.7300440397620798, 3.74516744780134, 3.760178282632207, 3.7750786473167794, 3.7898705825224654, 3.8045560690434934, 3.8191370301940277, 3.8336153340807377, 3.847992795762137, 3.862271179301452, 3.8764521997193517, 3.8905375248524026, 3.904528777122723, 3.9184275352239393, 3.9322353357282154, 3.9459536746187807], [0.0, 0.7900408755616531, 1.00695499396372, 1.1604915987753717, 1.2834251887886625, 1.3876791504009631, 1.4791169001338713, 1.5611113297970447, 1.6358032137398202, 1.7046469271236093, 1.7686812084529122, 1.8286769949865331, 1.885224164113149, 1.9387853746788513, 1.9897310358213287, 2.038362881782806, 2.0849303702750905, 2.1296423967514904, 2.1726758567925204, 2.21418203100451, 2.2542914305735344, 2.293117532298037, 2.330759697894339, 2.3673054843774257, 2.402832493249487, 2.4374098657725267, 2.4710995033880874, 2.503957072346221, 2.536032837213038, 2.567372357426078, 2.598017073309393, 2.628004802162241, 2.657370160654801, 2.686144926421664, 2.714358349169277, 2.7420374196132657, 2.76920710299489, 2.7958905426893885, 2.8221092384361466, 2.8478832029340824, 2.8732310999122412, 2.8981703662724265, 2.922717320482585, 2.946887259057159, 2.9706945426786624, 2.994152673281401, 3.017274363224421, 3.0400715975188524, 3.062555689939173, 3.084737333733707, 3.1066266475531905, 3.128233217134454, 3.1495661332066374, 3.170634026027954, 3.191445096910102, 3.2120071470437073, 3.2323276039004982, 3.2524135454553478, 3.272271722443115, 3.2919085788406997, 3.3113302707433734, 3.3305426837858123, 3.349551449241939, 3.3683619589233693, 3.3869793789836713, 3.405408662724574, 3.4236545624904493, 3.441721640728759, 3.4596142802864702, 3.4773366940056194, 3.4948929336751746, 3.512286898390898, 3.529522342370124, 3.546602882264037, 3.5635320040061793, 3.5803130692324356, 3.5969493213046606, 3.6134438909672717, 3.6297998016636535, 3.6460199745368955, 3.66210723313736, 3.6780643078577016, 3.6938938401142805, 3.709598386292365, 3.7251804214711557, 3.740642342943376, 3.7559864735430337, 3.7712150647939184, 3.786330299890425, 3.801334296521435, 3.8162291095471885, 3.8310167335383247, 3.8456991051856457, 3.8602781055884927, 3.8747555624291, 3.8891332520397426, 3.903412901369048, 3.917596189853376, 3.9316847511987816, 3.945680175078695, 3.959584008752131, 3.9733977586068723], [0.0, 0.7954285415450065, 1.0138219008992493, 1.1684055451344693, 1.292177478000154, 1.3971423971590613, 1.4892037045698936, 1.5717572934021502, 1.6469585369676982, 1.7162717285066549, 1.7807426901773908, 1.841147616628009, 1.8980804079027724, 1.9520068779393682, 2.00329996187227, 2.052263451613581, 2.099148506046364, 2.1441654451817733, 2.1874923709357565, 2.229281595569337, 2.269664520286686, 2.3087553957387232, 2.3466542612367594, 2.383449270888875, 2.4192185553989587, 2.4540317275362953, 2.4879511108779155, 2.521032751288612, 2.5533272561125746, 2.5848804954789, 2.615734192313, 2.6459264218083547, 2.6754920367027455, 2.7044630313376286, 2.7328688548871662, 2.7607366821295627, 2.788091648555978, 2.814957055367379, 2.8413545489201395, 2.867304278389328, 2.8928250347808704, 2.9179343739071304, 2.9426487255194784, 2.9669834904465953, 2.9909531273033436, 3.014571230100169, 3.0378505978877626, 3.0608032974087687, 3.0834407195916964, 3.105773630607235, 3.127812218110033, 3.1495661332066374, 3.171044528620211, 3.1922560934628184, 3.2132090849748187, 3.2339113575468823, 3.2543703893022133, 3.2745933064837756, 3.2945869058629125, 3.3143576753610797, 3.3339118130549013, 3.3532552447160078, 3.3723936400206673, 3.391332427549833, 3.4100768086875415, 3.428631770514452, 3.4470020977834412, 3.46519238405548, 3.48320704206626, 3.501050313387201, 3.5187262774383536, 3.536238859905276, 3.5535918406071034, 3.570788860858692, 3.5878334303658295, 3.604728933689, 3.621478636308092, 3.6380856903175647, 3.654553139779106, 3.6708839257564754, 3.6870808910551727, 3.703146784687705, 3.7190842660835113, 3.734895909061071, 3.7505842055783334, 3.766151569276304, 3.7816003388295063, 3.7969327811159443, 3.812151094218259, 3.827257410266864, 3.842253798135071, 3.85714226599545, 3.8719247637460223, 3.886603185314244, 3.9011793708461866, 3.9156551087877833, 3.9300321378645493, 3.944312148965723, 3.95849678693838, 3.972587652296694, 3.986586302851177, 4.00049425526239], [0.0, 0.8007492754339072, 1.0206034988224855, 1.1762211748928648, 1.300821035703421, 1.4064880800355457, 1.4991651985376495, 1.5822709999883986, 1.6579752752962442, 1.7277521125656556, 1.7926543296071697, 1.853463313144548, 1.9107769359033526, 1.9650641277165082, 2.0167003183342893, 2.065991331775818, 2.113190006961408, 2.158508070762481, 2.2021248164438627, 2.2441935751048074, 2.284846626910706, 2.3241989867512216, 2.362351363114753, 2.3993924997846623, 2.4354010500921546, 2.4704470924561632, 2.504593367344931, 2.537896295521958, 2.5704068228511074, 2.602171126293252, 2.6332312078643443, 2.663625397448213, 2.6933887809175276, 2.722553566628413, 2.7511494007447186, 2.779203639820578, 2.8067415874820045, 2.8337867007949886, 2.860360770911441, 2.886484081787108, 2.9121755501236093, 2.937452849166617, 2.962332518568431, 2.986830062176049, 3.0109600353200534, 3.0347361229431438, 3.0581712097106717, 3.0812774430814263, 3.1040662901794467, 3.12654858919186, 3.1487345959199753, 3.170634026027954, 3.1922560934628184, 3.2136095454593314, 3.2347026944916983, 3.2555434474897185, 3.2761393325988193, 3.29649752373041, 3.3166248631203983, 3.3365278820888626, 3.3562128201722374, 3.3756856427804767, 3.394952057515114, 3.4140175292696475, 3.4328872942209068, 3.4515663728088377, 3.470059581792205, 3.488371545458958, 3.5065067060622, 3.524469333545823, 3.542263534617693, 3.5598932612228342, 3.5773623184641257, 3.5946743720136936, 3.611832955054243, 3.628841474786062, 3.6457032185322946, 3.662421359472205, 3.6789989620296404, 3.6954389869415514, 3.711744296029365, 3.727917656694121, 3.7439617461545582, 3.759879155445792, 3.775672393194829, 3.791343889187861, 3.806895997743136, 3.8223310009021256, 3.837651111450755, 3.8528584757815603, 3.8679551766068387, 3.8829432355321107, 3.8978246154985405, 3.912601223102332, 3.9272749107985545, 3.9418474789963085, 3.95632067805169, 3.970696210164534, 3.984975731184531, 3.99916085233192, 4.013253141837627, 4.027254126507371], [0.0, 0.8060051484842448, 1.027302427674634, 1.1839415305197942, 1.3093592266635825, 1.4157198371189026, 1.5090052598486363, 1.5926565423326777, 1.6688577173225996, 1.7390925483858155, 1.804420763706592, 1.865628878791881, 1.923318690620744, 1.9779622069379394, 2.0299373216996646, 2.0795518662602577, 2.1270603390972846, 2.1726758567925204, 2.2165788894368794, 2.2589237745480006, 2.299843660537776, 2.3394543172183875, 2.3778571140979117, 2.4151413774467327, 2.4513862768524373, 2.4866623507072423, 2.521032751288612, 2.5545542696886625, 2.5872781861643075, 2.6192509807678506, 2.6505149312036163, 2.681108618941054, 2.7110673601457576, 2.7404235745796397, 2.7692071029948906, 2.7974454815056897, 2.825164179823302, 2.8523868089787174, 2.8791353031542952, 2.9054300794434558, 2.931290178711256, 2.9567333902051414, 2.981776362138624, 3.006434700121207, 3.0307230550202044, 3.054655201602091, 3.0782441091032147, 3.1015020047145656, 3.124440430826873, 3.147070296765807, 3.169401925648614, 3.191445096910102, 3.2132090849748187, 3.2347026944916983, 3.255934292495481, 3.276911837814633, 3.2976429080070226, 3.3181347240714163, 3.338394173154064, 3.3584278294446293, 3.3782419734339526, 3.397842609687112, 3.4172354832685907, 3.436426094941774, 3.4554197152521526, 3.474221397592303, 3.49283599033672, 3.5112681481257626, 3.529522342370124, 3.5476028710402985, 3.565513867799327, 3.58325931053159, 3.600843029315497, 3.6182687138835234, 3.635539920609103, 3.652660079056344, 3.669632498125373, 3.6864603718232307, 3.703146784687705, 3.7196947168891157, 3.736107049033011, 3.752386566684803, 3.7685359646356744, 3.784557850927502, 3.800454750653152, 3.8162291095471885, 3.8318832973808834, 3.8474196111743297, 3.8628402782375026, 3.8781474590512013, 3.893343249998008, 3.9084296859526435, 3.9234087427404165, 3.938282339471845, 3.9530523407609457, 3.967720558834153, 3.9822887555363655, 3.996758644240135, 4.011131891663643, 4.025410119602685, 4.039594906581575, 4.053687789427516], [0.0, 0.8111981309006187, 1.0339211986009056, 1.1915695060501819, 1.3177952514874536, 1.4248411290045635, 1.518727577125823, 1.602917813535734, 1.6796099424141937, 1.7502972870170737, 1.8160464032143422, 1.8776488739262363, 1.935710373428552, 1.9907059505482594, 2.043015933961325, 2.092950138337968, 2.1407647018551046, 2.1866741141758905, 2.2308600081356844, 2.273477715627927, 2.314661242921762, 2.3545271057186494, 2.3931773266367298, 2.4307018074634934, 2.4671802278654984, 2.502683580704304, 2.537275425138977, 2.5710129181589774, 2.6039476704129947, 2.6361264614180384, 2.667591841267977, 2.6983826400074613, 2.7285344013393753, 2.758079753901783, 2.787048730706815, 2.8154690452801185, 2.843366331430872, 2.8707643523127513, 2.8976851834270936, 2.9241493734118973, 2.950176085809944, 2.9757832244823987, 3.0009875449049686, 3.025804753231992, 3.050249594724345, 3.074335932897463, 3.098076820546735, 3.121484563641292, 3.14457077893793, 3.1673464460496312, 3.189821954604095, 3.2120071470437073, 3.2339113575468823, 3.2555434474897185, 3.276911837814633, 3.298024538627749, 3.3188891763081183, 3.339513018378428, 3.359902996357882, 3.38006572679276, 3.4000075306382582, 3.4197344511460583, 3.439252270395317, 3.4585665245900965, 3.4776825182333018, 3.4966053372758346, 3.515339861329613, 3.5338907750242154, 3.552262578579031, 3.5704595976557987, 3.588485992550192, 3.6063457667755636, 3.6240427750870015, 3.6415807309894292, 3.658963213769516, 3.6761936750875877, 3.693275445162568, 3.7102117385800546, 3.727005659751095, 3.743660208046846, 3.760178282632207, 3.776562687019614, 3.7928161333624235, 3.8089412465057757, 3.824940567811369, 3.8408165587713055, 3.856571604424973, 3.8722080165918555, 3.8877280369321863, 3.9031338398464497, 3.9184275352239393, 3.9336111710497983, 3.9486867358793116, 3.963656161187567, 3.9785213236020383, 3.99328404702509, 4.007946104652949, 4.022509220897196, 4.036975073214453, 4.051345293849527, 4.065621471496951, 4.0798051528854975], [0.0, 0.8163300985042546, 1.0404622024491779, 1.1991078568791473, 1.3261321574556053, 1.433855250506867, 1.528335662287342, 1.6130585201978949, 1.6902358345148627, 1.7613703758612638, 1.82753544757105, 1.8895276404383023, 1.9479564604793547, 2.0032999618722704, 2.0559408794061094, 2.1061909877640517, 2.1543080455567605, 2.2005078993957863, 2.244973331199297, 2.2878606555531427, 2.329304726504346, 2.36942279687984, 2.408317534734128, 2.4460794106097836, 2.4827886082591757, 2.518516569673431, 2.5533272561125746, 2.5872781861643075, 2.6204212969871663, 2.652803664044313, 2.684468106618726, 2.7154537004096313, 2.7457962139837577, 2.775528482401137, 2.804680728674885, 2.8332808416576274, 2.8613546173283897, 2.8889259691761744, 2.916017112360872, 2.9426487255194784, 2.9688400934311017, 2.994609233223977, 3.01997300637573, 3.0449472184041864, 3.069546707854709, 3.093785425948941, 3.117676508059537, 3.1412323380081677, 3.164464606043933, 3.187384361241289, 3.210002058956925, 3.2323276039004982, 3.2543703893022133, 3.2761393325988193, 3.2976429080070226, 3.3188891763081183, 3.339885812128718, 3.360640128968798, 3.381159102199157, 3.4014493902250242, 3.421517353990516, 3.4413690749793684, 3.461010371850512, 3.4804468158322748, 3.4996837449859934, 3.5187262774383536, 3.5375793236716726, 3.556247597952391, 3.5747356289701067, 3.5930477697524448, 3.6111882069147923, 3.629160969298348, 3.64696993604494, 3.664618844152627, 3.6821112955520925, 3.6994507637402636, 3.7166406000043763, 3.733684039266797, 3.750584205578334, 3.7673441172853788, 3.783966691894122, 3.8004547506531523, 3.8168110228740075, 3.833038150007659, 3.849138689493488, 3.8651151183959915, 3.880969836843282, 3.896705171280349, 3.912323377549074, 3.9278266438060796, 3.943217093288673, 3.9584967869383796, 3.9736677258908903, 3.9887318538405854, 4.003691059287243, 4.018547177671972, 4.033301993408958, 4.047957241819104, 4.062514610971303, 4.076975743436603, 4.091342237960261, 4.105615651056283], [0.0, 0.8214028388503244, 1.0469277175668923, 1.2065592087477424, 1.3343728484599815, 1.442765341403916, 1.537832861999355, 1.62308219450682, 1.7007390948109447, 1.772315671871266, 1.8388918986142646, 1.9012693159127554, 1.9600612173020742, 2.0157486276270786, 2.068716660021337, 2.119279026560778, 2.167695087588632, 2.2141820310045106, 2.2589237745480006, 2.3020776041562563, 2.3437792118701064, 2.3841465791349017, 2.4232830119926256, 2.461279543177021, 2.4982168547086885, 2.534166832524986, 2.569193835346311, 2.603355739185456, 2.636704803942604, 2.669288397611599, 2.7011496055578608, 2.7323277463001254, 2.7628588106738494, 2.792775837778746, 2.822109238436147, 2.850887074802231, 2.8791353031542952, 2.90687798558167, 2.9341374752910223, 2.9609345794180477, 2.9872887025790087, 3.0132179738620133, 3.0387393595232535, 3.0638687632973043, 3.0886211159374324, 3.1130104553592854, 3.137049998559771, 3.1607522063146156, 3.1841288415170603, 3.20719102190139, 3.2299492677947144, 3.2524135454553478, 3.2745933064837756, 3.29649752373041, 3.3181347240714163, 3.339513018378428, 3.360640128968798, 3.3815234147891746, 3.402169894555868, 3.422586268049968, 3.4427789357430045, 3.46275401690954, 3.482517366366114, 3.5020745899611128, 3.5214310589270124, 3.540591923194945, 3.559562123761357, 3.5783464041875166, 3.5969493213046606, 3.6153752551904743, 3.6336284184763072, 3.6517128650388986, 3.669632498125373, 3.687391077955793, 3.704992228843527, 3.7224394458700893, 3.739736101147882, 3.756885449701336, 3.773890634994362, 3.7907546941295966, 3.8074805627428456, 3.8240710796141624, 3.840528991015244, 3.8568569548112492, 3.8730575443336903, 3.889133252039742, 3.905086492972104, 3.92091960803248, 3.936634867080733, 3.9522344718708666, 3.9677205588341526, 3.9830952017189722, 3.9983604140962323, 4.013518151738586, 4.028570314881099, 4.043518750370458, 4.05836525370934, 4.073111571002072, 4.087759400807341, 4.102310395903261, 4.116766164969823, 4.1311282741933315], [0.0, 0.8264180568489509, 1.0533199169653644, 1.2139260659996478, 1.342520094135248, 1.4515743963106789, 1.5472223681997153, 1.63299220534454, 1.7111232533697365, 1.7831368536792782, 1.8501195731623181, 1.9128778466389798, 1.9720287122150233, 2.028056131716219, 2.081347569651402, 2.132218653520183, 2.1809303272355085, 2.227701104775514, 2.272716026821556, 2.3161333396474544, 2.35808956378541, 2.398703401037023, 2.438078788197297, 2.476307313816175, 2.513470152532377, 2.5496396291953634, 2.5848804954789006, 2.6192509807678506, 2.652803664044313, 2.6855862025156627, 2.7176419446125166, 2.7490104489196714, 2.779727926020893, 2.809827616741869, 2.8393401175824926, 2.868293662037322, 2.896714364864224, 2.924626435067802, 2.9520523623361172, 2.979013080846454, 3.0055281136933374, 3.0316157006551774, 3.057292911578596, 3.0825757473011883, 3.1074792297385336, 3.132017482517217, 3.1562038033328212, 3.1800507290425073, 3.203570094359908, 3.2267730849005707, 3.249670285225293, 3.272271722443115, 3.2945869058629125, 3.3166248631203983, 3.338394173154064, 3.359902996357882, 3.381159102199157, 3.402169894555868, 3.422942434998318, 3.4434834642142773, 3.463799421754469, 3.4838964642557504, 3.5037804822822634, 3.523457115909877, 3.5429317691660613, 3.5622096234257503, 3.581295649853504, 3.6001946209732294, 3.618911121438689, 3.637449558070896, 3.6558141692221526, 3.6740090335208486, 3.6920380780460635, 3.7099050859765375, 3.7276137037545154, 3.74516744780134, 3.7625697108184317, 3.779823767704342, 3.7969327811159443, 3.8138998066994363, 3.8307277980146583, 3.84741961117433, 3.8639780092179876, 3.880405666238848, 3.8967051712803484, 3.9128790320177935, 3.928929678239346, 3.9448594651394933, 3.960670676437123, 3.9763655273294303, 3.9919461672920407, 4.007414682734966, 4.022773099523322, 4.03802338537107, 4.053167452115495, 4.068207157879526, 4.083144309128592, 4.097980662628167, 4.1127179273077825, 4.127357766036877, 4.141901797317516, 4.156351596898629], [0.0, 0.8313773799379874, 1.059640874912806, 1.221210819179473, 1.3505765382619976, 1.4602852737647927, 1.5565072277824594, 1.6427917685088071, 1.7213916798498892, 1.7938374327579614, 1.8612221145947345, 1.9243569995843, 1.983862828669377, 2.0402264679238185, 2.093837707025505, 2.1450140675502154, 2.1940180593316336, 2.2410695076471914, 2.2863545636047617, 2.3300324231118186, 2.3722404259583487, 2.4130979862737876, 2.4527096645763784, 2.4911675990376576, 2.528553451424207, 2.5649399806058875, 2.6003923268303444, 2.634969068916157, 2.668723101371153, 2.701702367392937, 2.733950475545445, 2.765507221803982, 2.796409034051517, 2.826689352591462, 2.8563789575328746, 2.885506251799115, 2.914097506862343, 2.9421770770050584, 2.96976758687562, 2.9968900962770166, 3.0235642454615865, 3.049808383664393, 3.0756396831679673, 3.101074240830704, 3.126127168714486, 3.1508126752015815, 3.175144137786857, 3.199134168560977, 3.222794673257523, 3.2461369046167636, 3.269171510717296, 3.2919085788406997, 3.3143576753610797, 3.3365278820888626, 3.3584278294446293, 3.38006572679276, 3.4014493902250242, 3.422586268049968, 3.4434834642142773, 3.464147759856495, 3.4845856331709975, 3.504803277740532, 3.5248066194784333, 3.5446013323065864, 3.5641928526819533, 3.583586393072826, 3.602786954475653, 3.621799338054189, 3.6406281559746403, 3.6592778415032896, 3.6777526584267326, 3.6960567098491497, 3.7141939464159663, 3.7321681740087254, 3.7499830609519202, 3.7676421447688875, 3.785148838520602, 3.802506436758234, 3.819718121117718, 3.8367869655821396, 3.853715941435611, 3.8705079219303435, 3.8871656866868345, 3.9036919258454974, 3.9200892439865807, 3.936360163833915, 3.952507129756787, 3.9685325110831724, 3.9844386052365244, 4.000227640707404, 4.01590177987041, 4.031463121656073, 4.046913704086695, 4.062255506684462, 4.077490452759565, 4.092620411585505, 4.107647200468285, 4.122572586715702, 4.13739828951255, 4.152125981707124, 4.166757291514097, 4.181293804138446], [0.0, 0.8362823628502692, 1.065892573010474, 1.2284157520353751, 1.3585447065111722, 1.468900704600074, 1.5656903515230711, 1.652483956133125, 1.7315475933721425, 1.804420763706592, 1.8722030035247763, 1.9357103734285521, 1.9955672766249615, 2.0522634516135816, 2.1061909877640517, 2.157669279974593, 2.206962386841557, 2.254291430573535, 2.299843660537776, 2.343779211870106, 2.386236234641546, 2.4273348475042646, 2.4671802278654984, 2.505865057496079, 2.543471479952902, 2.580072683370592, 2.6157341923130004, 2.6505149312036167, 2.684468106618726, 2.717641944612517, 2.750080311031918, 2.781823236641615, 2.8129073642427906, 2.8433663314308717, 2.8732310999122417, 2.9025302401826005, 2.931290178711256, 2.9595354134667664, 2.9872887025790082, 3.014571230100169, 3.041402752156683, 3.06780172624093, 3.0937854259489415, 3.119370043107796, 3.14457077893793, 3.169401925648614, 3.1938769396596216, 3.218008507470774, 3.2418086050574235, 3.2652885515490633, 3.2884590578461137, 3.3113302707433734, 3.3339118130549013, 3.3562128201722374, 3.3782419734339526, 3.4000075306382582, 3.421517353990516, 3.4427789357430045, 3.463799421754469, 3.4845856331709975, 3.5051440864071934, 3.5254810115868738, 3.5456023695852372, 3.565513867799327, 3.5852209747602637, 3.604728933689001, 3.624042775087001, 3.6431673284440578, 3.66210723313736, 3.680866948588695, 3.699450763740264, 3.7178628059038523, 3.736107049033011, 3.754187321463327, 3.772107313161774, 3.7898705825224654, 3.807480562742846, 3.8249405678113693, 3.842253798135071, 3.8594233458330067, 3.8764521997193517, 3.8933432499980083, 3.9100992926887557, 3.9267230338033694, 3.943217093288673, 3.9595840087521306, 3.975826238984386, 3.9919461672920407, 4.007946104652949, 4.023828292705382, 4.039594906581574, 4.055248057595384, 4.070789795793092, 4.086222112375726, 4.101546942000672, 4.116766164969823, 4.131881609310972, 4.146895052758729, 4.161808224640779, 4.176622807674934, 4.191340439682053, 4.205962715219547], [0.0, 0.841134492013326, 1.0720769058003736, 1.2355430479817997, 1.3664270135914178, 1.477423299674461, 1.574774522315636, 1.6620717053805314, 1.7415940716290634, 1.8148900537441883, 1.8830655676491752, 1.94694140874793, 2.007145603049008, 2.064170730525827, 2.118411155459406, 2.1701881258843816, 2.2197672324710473, 2.2673708803840444, 2.313187405415682, 2.357377871809461, 2.400081231186235, 2.4414182991293085, 2.4814948632876095, 2.520404143173698, 2.5582287589432426, 2.595042323370078, 2.6309107411930572, 2.665893278716504, 2.7000434512224634, 2.733409764573777, 2.766036339128011, 2.797963437909251, 2.8292279163210403, 2.859863607124894, 2.889901651667716, 2.9193707862118674, 2.9482975905536284, 2.9767067047993234, 3.004621019122014, 3.0320618404842357, 3.059049039637915, 3.0856011811662207, 3.111735638886978, 3.137468698572611, 3.162815649641382, 3.1877908672262816, 3.212407885821536, 3.236679465534323, 3.260617651824877, 3.2842338294965345, 3.3075387715946025, 3.3305426837858123, 3.3532552447160078, 3.3756856427804767, 3.397842609687112, 3.4197344511460583, 3.4413690749793684, 3.46275401690954, 3.4838964642557504, 3.504803277740532, 3.5254810115868738, 3.5459359320659103, 3.5661740346379744, 3.5862010598145555, 3.606022507855314, 3.6256436524024913, 3.645069553144633, 3.6643050675923408, 3.6833548620405754, 3.7022234217847902, 3.720915060651725, 3.7394339298999224, 3.757784026539902, 3.775969201119339, 3.79399316501448, 3.8118594972653206, 3.829571650988795, 3.8471329594011925, 3.864546641478384, 3.881815807279968, 3.8989434629612876, 3.9159325154952738, 3.9327857771242756, 3.94950596956041, 3.966095727951491, 3.982557604628239, 3.998894072647256, 4.015107529143143, 4.0312002985021, 4.0471746353684335, 4.063032727494544, 4.078776698444181, 4.094408610158041, 4.109930465390143, 4.125344210022801, 4.140651735267461, 4.1558548797581745, 4.170955431544008, 4.185955129986246, 4.2008556675658655, 4.215658691606399, 4.230365805916917], [0.0, 0.8459351896154252, 1.0781956859476753, 1.2425947960720953, 1.3742257698543914, 1.4858555570118768, 1.5837624027853003, 1.6715578264780488, 1.751534059303909, 1.8252483714826855, 1.8938129908508692, 1.9580533974264964, 2.018601201618694, 2.0759517947556856, 2.1305017919162843, 2.1825742746286805, 2.232436349397444, 2.280311690744199, 2.3263897093704333, 2.3708323887789757, 2.413779473644252, 2.455352469093374, 2.495657766548528, 2.534789117564052, 2.5728296138425395, 2.609853288295948, 2.6459264218083547, 2.6811086189410545, 2.7154537004096313, 2.749010448919672, 2.781823236641615, 2.813932556397046, 2.8453754739383297, 2.8761860151243486, 2.906395499038374, 2.936032825952337, 2.965124727364256, 2.9936959840115906, 3.0217696167109565, 3.0493670540324143, 3.0765082801383765, 3.1032119655676587, 3.12949558329755, 3.1553755120500218, 3.1808671285062804, 3.2059848898440637, 3.2307424078044766, 3.255152515321834, 3.279227326604722, 3.302978291434195, 3.3264162443417233, 3.349551449241939, 3.3723936400206673, 3.394952057515114, 3.4172354832685907, 3.439252270395317, 3.461010371850512, 3.482517366366114, 3.5037804822822634, 3.5248066194784333, 3.5456023695852372, 3.5661740346379744, 3.5865276443155145, 3.606668971892788, 3.6266035490216804, 3.64633667944326, 3.6658734517237788, 3.6852187510976324, 3.7043772704922295, 3.723353520802435, 3.7421518404757568, 3.760776404463663, 3.779231232589242, 3.7975201973768162, 3.815647031384969, 3.8336153340807377, 3.851428578289403, 3.869090116251279, 3.886603185314244, 3.9039709132882763, 3.921196323486073, 3.9382823394718454, 3.955231789538556, 3.9720474109322432, 3.988731853840585, 4.005287685161494, 4.021717392066313, 4.038023385371071, 4.054208002728185, 4.070273511650138, 4.086222112375726, 4.102055940588741, 4.117777069998217, 4.133387514788708, 4.148889231948471, 4.164284123482866, 4.179574038519782, 4.194760775313407, 4.209846083152272, 4.224831664177034, 4.239719175113171, 4.254510228923347], [0.0, 0.8506858173682023, 1.0842506490364152, 1.249572996525442, 1.3819431874071706, 1.494199868411155, 1.5926565423326777, 1.6809450101515977, 1.7613703758612638, 1.8354986550454473, 1.9044483216224806, 1.969049491365398, 2.0299373216996646, 2.087609985986715, 2.1424663266280035, 2.194831239522483, 2.244973331199297, 2.2931175322980373, 2.3394543172183875, 2.3841465791349017, 2.427334847504265, 2.46914130980566, 2.5096729549373555, 2.54902406094643, 2.5872781861643075, 2.6245097792591525, 2.6607854933371833, 2.6961652676887455, 2.7307032252773835, 2.764448422764038, 2.7974454815056897, 2.8297351217247044, 2.8613546173283897, 2.8923381852590495, 2.922717320482585, 2.952521085569926, 2.981776362138624, 3.010508070090535, 3.0387393595232535, 3.066491779346036, 3.0937854259489415, 3.1206390747213484, 3.147070296765807, 3.173095562784396, 3.1987303358111423, 3.2239891542128283, 3.248885706171775, 3.273432896689868, 3.2976429080070226, 3.3215272542043106, 3.345096830658084, 3.3683619589233693, 3.391332427549833, 3.4140175292696475, 3.436426094941774, 3.4585665245900965, 3.4804468158322748, 3.5020745899611128, 3.523457115909877, 3.5446013323065864, 3.565513867799327, 3.5862010598145555, 3.606668971892788, 3.6269234097306833, 3.64696993604494, 3.666813884361532, 3.6864603718232307, 3.705914311099076, 3.7251804214711566, 3.7442632391667527, 3.763167126997354, 3.7818962833602443, 3.8004547506531523, 3.818846423147837, 3.8370750543642935, 3.8551442639835534, 3.873057544333691, 3.8908182664806303, 3.9084296859526435, 3.925894948124956, 3.9432170932886734, 3.9603990614262448, 3.9774436967138445, 3.994353751769417, 4.011131891663643, 4.027780697709694, 4.044302671046447, 4.060700236028658, 4.076975743436604, 4.09313147351673, 4.1091696388639996, 4.12509238715584, 4.140901803746882, 4.156599914132993, 4.1721886862925475, 4.18767003291224, 4.203045813504347, 4.218317836421746, 4.233487860776672, 4.248557598268716, 4.263528714927244, 4.278402832773041], [0.0, 0.8553876799929504, 1.0902434580129832, 1.2564795658478674, 1.3895813857757495, 1.5024585255695888, 1.6014593836608921, 1.690235834514863, 1.771105722765509, 1.845643719589527, 1.9149744808711486, 1.979932710552445, 2.0411570766651455, 2.099148506046364, 2.15430804555676, 2.2069623868415564, 2.2573816210567426, 2.3057919220658407, 2.3523848170478843, 2.397324099511386, 2.44075107563951, 2.4827886082591757, 2.5235442776116512, 2.5631128828323133, 2.601578444091479, 2.6390158215457884, 2.6754920367027455, 2.7110673601457576, 2.7457962139837577, 2.779727926020893, 2.8129073642427906, 2.8453754739383297, 2.8771697350330543, 2.90832455359122, 2.938871598655925, 2.9688400934311017, 2.998257068112859, 3.0271475803389287, 3.0555349081608174, 3.083440719591696, 3.1108852220972576, 3.137887294841151, 3.164464606043933, 3.190633717443618, 3.2164101775406406, 3.241808605057423, 3.2668427638328357, 3.2915256301965616, 3.315869453721506, 3.339885812128718, 3.3635856610148585, 3.3869793789836713, 3.4100768086875415, 3.4328872942209068, 3.4554197152521526, 3.4776825182333018, 3.4996837449859934, 3.5214310589270124, 3.5429317691660613, 3.5641928526819533, 3.5852209747602637, 3.606022507855314, 3.6266035490216804, 3.64696993604494, 3.667127262387725, 3.687080891055173, 3.7068359674732383, 3.7263974314639876, 3.745770028393659, 3.7649583195619116, 3.7839666918941215, 3.802799366992716, 3.8214604095983375, 3.8399537355069424, 3.8582831189847715, 3.8764521997193513, 3.8944644893413556, 3.9123233775490736, 3.9300321378645493, 3.9475939330479486, 3.9650118201945026, 3.982288755536365, 3.9994275989698806, 4.016431118327109, 4.033301993408957, 4.050042819795887, 4.066656112450927, 4.083144309128592, 4.099509773602258, 4.11575479872162, 4.131881609310971, 4.147892364918261, 4.163789162424171, 4.179574038519781, 4.195248972060759, 4.210815886305498, 4.226276651044062, 4.241633084624356, 4.256886955881482, 4.272039985975838, 4.287093850145173, 4.302050179375417], [0.0, 0.8600420284548512, 1.096175707308346, 1.2633163415830078, 1.3971423971590613, 1.5106337257637419, 1.6101732688307138, 1.6994327714600954, 1.7807426901773908, 1.8556862642840675, 1.925394269159069, 1.9907059505482594, 2.052263451613581, 2.1105704248428787, 2.1660300992790913, 2.218970944166995, 2.269664520286686, 2.3183382321623562, 2.3651846491136395, 2.4103684558847798, 2.4540317275362957, 2.4962979954181903, 2.5372754251389775, 2.577059331656532, 2.6157341923130004, 2.6533752745952466, 2.6900499646892206, 2.7258188611235457, 2.7607366821295627, 2.7948530239146163, 2.8282129986007005, 2.8608577742688235, 2.8928250347808704, 2.9241493734118973, 2.954862631523082, 2.9849941913280977, 3.0145712301001693, 3.043618941821027, 3.0721607312030663, 3.100218384159781, 3.1278122181100336, 3.154961214943066, 3.1816831390160254, 3.2079946421829066, 3.2339113575468827, 3.25944798337399, 3.284618358395108, 3.309435529546923, 3.3339118130549017, 3.3580588496369663, 3.3818876545015373, 3.405408662724574, 3.428631770514452, 3.4515663728088377, 3.474221397592303, 3.4966053372758346, 3.5187262774383536, 3.540591923194945, 3.5622096234257503, 3.583586393072826, 3.604728933689001, 3.6256436524024913, 3.64633667944326, 3.666813884361532, 3.687080891055173, 3.7071430917105856, 3.727005659751095, 3.7466735618774027, 3.766151569276305, 3.7854442680664753, 3.804556069043494, 3.8234912167804356, 3.8422537981350717, 3.860847750210047, 3.8792768678081972, 3.897544810421372, 3.9156551087877833, 3.9336111710497987, 3.9514162885413997, 3.969073641232011, 3.986586302851177, 4.003957245716547, 4.0211893452857765, 4.038285384451295, 4.055248057595384, 4.072079974421617, 4.088783663577478, 4.105361576081827, 4.121816088569841, 4.138149506367105, 4.154364066403657, 4.170461939978011, 4.186445235380434, 4.202316000384074, 4.2180762246119805, 4.233727841787409, 4.249272731874354, 4.2647127231147435, 4.280049593968291, 4.2952850749606, 4.310420850444748, 4.325458560281208], [0.0, 0.8646500629669478, 1.1020489266667923, 1.2700850867246478, 1.4046281713089466, 1.5187275771258228, 1.6188004448846067, 1.7085381925939267, 1.7902837631738389, 1.8656288787918809, 1.935710373428552, 2.001371989439455, 2.0632593105368247, 2.1218786877371456, 2.177635510551433, 2.230860008135684, 2.2818251962703378, 2.330759697894339, 2.3778571140979112, 2.4232830119926256, 2.4671802278654984, 2.509672954937355, 2.5508699383591513, 2.590867003778473, 2.6297490811601234, 2.667591841267977, 2.7044630313376286, 2.7404235745796397, 2.775528482401137, 2.809827616741869, 2.8433663314308717, 2.8761860151243486, 2.90832455359122, 2.9398167254544663, 2.9706945426786624, 3.000987544904968, 3.0307230550202044, 3.059926401993385, 3.088621115937432, 3.1168290994929726, 3.14457077893793, 3.171865237864949, 3.1987303358111423, 3.2251828138497705, 3.2512383888448873, 3.2769118378146325, 3.3022170736366676, 3.327167213152093, 3.3517746385757006, 3.3760510529954217, 3.4000075306382582, 3.4236545624904493, 3.4470020977834412, 3.470059581792205, 3.49283599033672, 3.515339861329613, 3.5375793236716726, 3.559562123761357, 3.581295649853504, 3.602786954475653, 3.624042775087001, 3.645069553144633, 3.6658734517237788, 3.6864603718232307, 3.7068359674732383, 3.727005659751095, 3.746974649798904, 3.7667479309285388, 3.7863302998904245, 3.8057263673752812, 3.824940567811369, 3.8439771685138364, 3.8628402782375026, 3.8815338551796854, 3.9000617144754623, 3.9184275352239393, 3.936634867080733, 3.9546871364487584, 3.972587652296694, 3.9903396116319794, 4.007946104652949, 4.025410119602685, 4.042734547345311, 4.059922185683763, 4.076975743436603, 4.093897844289981, 4.110691030439666, 4.127357766036877, 4.143900440450607, 4.160321371358184, 4.176622807674934, 4.1928069323330135, 4.2088758649187294, 4.224831664177034, 4.240676330391214, 4.256411807645252, 4.272039985975838, 4.28756270342047, 4.3029817479677, 4.3182988594151475, 4.333515731140514, 4.348634011790513], [0.0, 0.8692129357834798, 1.1078645847062096, 1.2767874938198522, 1.4120405800679403, 1.526742103550081, 1.6273430690764195, 1.7175543747569664, 1.7997313275316487, 1.8754740492965432, 1.945925373255521, 2.011933494304263, 2.0741474029856946, 2.133076122397628, 2.1891271813451816, 2.2426325516473127, 2.293866689824867, 2.343059425290296, 2.390405380792399, 2.4360709971623065, 2.4801998644530263, 2.5229168312694465, 2.5643312166250762, 2.6045393518521265, 2.643626615102065, 2.6816690764634012, 2.7187348406828598, 2.754885152470846, 2.790175313536963, 2.824655448949015, 2.8583711518741963, 2.891364029382126, 2.9236721671699417, 2.95533052739202, 2.9863712909443096, 3.016824153352566, 3.0467165816900996, 3.0760740385902476, 3.10492017833745, 3.133277019155469, 3.161165095114398, 3.1886035905135284, 3.2156104591371113, 3.2422025304032682, 3.2683956041160243, 3.2942045352737988, 3.3196433101743508, 3.3447251148780874, 3.369462396942386, 3.393866921213922, 3.4179498203598593, 3.441721640728759, 3.46519238405548, 3.488371545458958, 3.5112681481257626, 3.5338907750242154, 3.556247597952391, 3.5783464041875166, 3.6001946209732294, 3.621799338054189, 3.6431673284440578, 3.6643050675923408, 3.6852187510976324, 3.705914311099076, 3.7263974314639876, 3.7466735618774027, 3.7667479309285388, 3.786625558279639, 3.8063112659942138, 3.8258096890942084, 3.8451252854089484, 3.8642623447727686, 3.8832249976229316, 3.9020172230446866, 3.9206428563060824, 3.939105595921319, 3.957409010278016, 3.9755565438606686, 3.9935515230998218, 4.011397161873947, 4.029096566688763, 4.0466527415567075, 4.0640685925973745, 4.0813469323780796, 4.098490484012177, 4.115501885031355, 4.132383691046888, 4.149138379213646, 4.165768351509639, 4.182275937842883, 4.198663398996532, 4.214932929422359, 4.2310866598920125, 4.247126660014713, 4.263054940629506, 4.278873456079565, 4.294584106375552, 4.3101887392545315, 4.32568915214051, 4.341087094012246, 4.356384267183622, 4.371582329001477], [0.0, 0.8737317538002617, 1.1136240922324208, 1.2834251887886627, 1.419381421593598, 1.534679249260278, 1.6358032137398206, 1.7264835051621168, 1.8090876751116423, 1.8852241641131493, 1.9560417466710343, 2.0223930272315247, 2.0849303702750905, 2.1441654451817738, 2.200507899395786, 2.2542914305735344, 2.3057919220658407, 2.3552403981100904, 2.402832493249487, 2.448735513598909, 2.493093795699699, 2.536032837213038, 2.5776625254743135, 2.6180796926179464, 2.657370160654801, 2.69561039514252, 2.7328688548871662, 2.76920710299489, 2.8046807286748847, 2.839340117582492, 2.8732310999122412, 2.9063954990383736, 2.9388715986559246, 2.9706945426786624, 3.001896679302866, 3.0325078584338123, 3.062555689939173, 3.09206576882607, 3.121061872351581, 3.149566133206638, 3.1775991922127687, 3.205180333403578, 3.2323276039004987, 3.259057920613535, 3.285387165485895, 3.3113302707433734, 3.336901295394951, 3.3621134940520245, 3.3869793789836717, 3.411510776199028, 3.4357188762411743, 3.4596142802864702, 3.48320704206626, 3.5065067060622, 3.529522342370124, 3.552262578579031, 3.5747356289701067, 3.5969493213046606, 3.618911121438689, 3.6406281559746403, 3.66210723313736, 3.6833548620405754, 3.7043772704922295, 3.7251804214711566, 3.745770028393659, 3.766151569276305, 3.7863302998904245, 3.8063112659942138, 3.8260993147198707, 3.845699105185646, 3.865115118395992, 3.884351666487006, 3.9034129013690486, 3.922302822813625, 3.941025286027373, 3.9595840087521306, 3.977982577926662, 3.996224455942465, 4.014312986523355, 4.0322514002559435, 4.050042819795887, 4.0676902647727236, 4.085196656414227, 4.102564821909538, 4.119797498528786, 4.136897337515523, 4.153866907766997, 4.1707086993161795, 4.187425126628355, 4.204018531724143, 4.2204911871399355, 4.236845298735908, 4.253083008361047, 4.26920639638395, 4.285217484097505, 4.301118236005021, 4.316910561994834, 4.332596319409926, 4.348177315018656, 4.363655306892281, 4.379032006194582, 4.394309078888525], [0.0, 0.8782075809780603, 1.1193288053279282, 1.2899997344837992, 1.4266524242952845, 1.5425408830662677, 1.644182870825353, 1.73532768618314, 1.818355008876344, 1.8948815189171606, 1.9660618755865507, 2.032753050929991, 2.095610751266747, 2.1551492670830608, 2.2117803443060664, 2.2658393900104605, 2.3176037008025556, 2.3673054843774257, 2.4151413774467327, 2.4612795431770214, 2.5058650574960795, 2.54902406094643, 2.5908670037784733, 2.631491214164342, 2.670982953751535, 2.7094190798044413, 2.7468684018200333, 2.7833927982710756, 2.8190481431311536, 2.8538850801639883, 2.8879496743364266, 2.921283963269469, 2.9539264267723486, 2.985912388789013, 3.0172743632244217, 3.0480423528946474, 3.0782441091032147, 3.107905357971661, 3.137049998559771, 3.16570027693664, 3.1938769396596216, 3.2215993695477914, 3.2488857061717753, 3.2757529531010876, 3.302217073636668, 3.3282930764969665, 3.3539950927104303, 3.37933644478727, 3.404329709092613, 3.4289867722161707, 3.453318882026327, 3.4773366940056194, 3.501050313387201, 3.524469333545823, 3.5476028710402985, 3.5704595976557987, 3.5930477697524448, 3.6153752551904743, 3.637449558070896, 3.6592778415032896, 3.680866948588695, 3.7022234217847902, 3.723353520802435, 3.7442632391667527, 3.7649583195619116, 3.7854442680664753, 3.8057263673752812, 3.8258096890942084, 3.845699105185646, 3.8653992986349053, 3.8849147734010816, 3.904249863709863, 3.9234087427404165, 3.9423954307537032, 3.9612138027052564, 3.979867595381627, 3.9983604140962328, 4.016695738977211, 4.034876930877125, 4.0529072369317705, 4.070789795793092, 4.088527642559154, 4.106123713422173, 4.123580850054007, 4.140901803746881, 4.1580892393257525, 4.175145738847448, 4.19207380510052, 4.2088758649187294, 4.225554272320062, 4.242111311482331, 4.258549199565572, 4.274870089390733, 4.291076071983419, 4.307169178990908, 4.323151384979983, 4.339024609622681, 4.354790719776515, 4.370451531465294, 4.3860088117662706, 4.401464280608929, 4.4168196124903885], [0.0, 0.8826414406034021, 1.1249800282334494, 1.2965126340115616, 1.4338552505068667, 1.5503288023350237, 1.652483956133125, 1.744088939821985, 1.8275354475710497, 1.9044483216224803, 1.975988050855248, 2.043015933961325, 2.1061909877640517, 2.1660300992790917, 2.2229470932400957, 2.2772790701117045, 2.329304726504346, 2.3792574424741, 2.4273348475042646, 2.4737059537769146, 2.518516569673431, 2.561893472589709, 2.6039476704129947, 2.644776982702038, 2.684468106618726, 2.723098287461356, 2.7607366821295622, 2.7974454815056897, 2.833280841657627, 2.868293662037322, 2.9025302401826, 2.9360328259523367, 2.9688400934311012, 3.000987544904968, 3.0325078584338123, 3.0634311883107346, 3.093785425948941, 3.123596427354992, 3.1528882122492976, 3.181683139016025, 3.210002058956925, 3.23786445275028, 3.265288551549063, 3.292291444769736, 3.3188891763081183, 3.3450968306580835, 3.3709286101922555, 3.3963979046830057, 3.421517353990516, 3.44629890471704, 3.4707538615187548, 3.4948929336751746, 3.5187262774383536, 3.542263534617693, 3.565513867799327, 3.588485992550192, 3.6111882069147923, 3.6336284184763072, 3.6558141692221526, 3.6777526584267326, 3.699450763740264, 3.720915060651725, 3.7421518404757568, 3.763167126997354, 3.7839666918941215, 3.804556069043494, 3.824940567811369, 3.8451252854089484, 3.865115118395992, 3.8849147734010816, 3.9045287771227226, 3.92396148566907, 3.9432170932886734, 3.9622996405398263, 3.9812130219417847, 3.99996099314724, 4.018547177671972, 4.036975073214453, 4.055248057595384, 4.07336939434457, 4.091342237960261, 4.109169638864, 4.126854548072137, 4.14439982160345, 4.161808224640778, 4.179082435463142, 4.196225049163554, 4.213238581166547, 4.230125470558384, 4.246888083241923, 4.263528714927243, 4.280049593968291, 4.29645288405509, 4.312740686770334, 4.3289150440186, 4.344977940335786, 4.360931305085894, 4.376777014551751, 4.392516893925837, 4.408152719206953, 4.423686219008096, 4.4391190762805195], [0.0, 0.8870343173998728, 1.1305790160388953, 1.3029653338331186, 1.4409914999165285, 1.5580447366990637, 1.6607083132655918, 1.7527692118806901, 1.8366310300953352, 1.9139266969369382, 1.9858224769986332, 2.053183955627046, 2.116673429550106, 2.1768103583127885, 2.234010626240541, 2.288613011535691, 2.3408975978723334, 2.391098926831247, 2.4394156114910275, 2.4860175052017026, 2.531051142028069, 2.5746439303328614, 2.6169074304858517, 2.6579399488904474, 2.6978286141973973, 2.736651056152253, 2.774476775846215, 2.8113682736835606, 2.847381985219042, 2.882569063229468, 2.9169760356739562, 2.9506453626875087, 2.9836159108343145, 3.0159233590941343, 3.047600548164448, 3.0786777824152614, 3.1091830920744052, 3.1391424618329173, 3.168580030956549, 3.1975182691063937, 3.2259781313604305, 3.2539791953516244, 3.281539782968783, 3.30867706868182, 3.335407176236486, 3.361745265201673, 3.3877056086347364, 3.4133016629484954, 3.438546130911291, 3.4634510185832146, 3.488027686883337, 3.512286898390898, 3.536238859905276, 3.5598932612228342, 3.58325931053159, 3.6063457667755636, 3.629160969298348, 3.6517128650388986, 3.6740090335208486, 3.6960567098491497, 3.7178628059038523, 3.7394339298999224, 3.760776404463663, 3.7818962833602443, 3.802799366992716, 3.8234912167804356, 3.8439771685138364, 3.8642623447727686, 3.884351666487006, 3.904249863709863, 3.92396148566907, 3.9434909101529874, 3.9628423522847975, 3.982019872732518, 4.001027385398296, 4.01986866462658, 4.038547351967266, 4.057066962526755, 4.075430890937047, 4.093642416970425, 4.111704710824972, 4.129620838104075, 4.147393764511195, 4.165026360279419, 4.182521404353807, 4.199881588343086, 4.217109520255958, 4.23420772803614, 4.251178662909145, 4.268024702552848, 4.284748154103004, 4.301351257004001, 4.317836185714473, 4.334205052276621, 4.350459908757515, 4.36660274957002, 4.382635513680516, 4.398560086710028, 4.414378302934959, 4.430091947193195, 4.445702756700981, 4.4612124227855645], [0.0, 0.8913871595017524, 1.1361269771988889, 1.3093592266635825, 1.4480627127729528, 1.5656903515230711, 1.6688577173225998, 1.761370375861264, 1.8456437195895272, 1.923318690620744, 1.9955672766249615, 2.063259310536825, 2.1270603390972846, 2.187492370935757, 2.2449733311992968, 2.299843660537776, 2.3523848170478843, 2.4028324932494876, 2.4513862768524377, 2.4982168547086885, 2.5434714799529026, 2.5872781861643075, 2.629749081160124, 2.6709829537515355, 2.7110673601457576, 2.750080311031918, 2.7880916485559784, 2.8251641798233025, 2.8613546173283897, 2.896714364864224, 2.931290178711256, 2.965124727364256, 2.998257068112859, 3.0307230550202044, 3.0625556899391735, 3.0937854259489415, 3.124440430826873, 3.1545468167757087, 3.18412884151706, 3.213209084974819, 3.2418086050574235, 3.269947075468919, 3.2976429080070226, 3.324913361419962, 3.351774638575701, 3.378241973433952, 3.404329709092613, 3.4300513679976183, 3.455419715252153, 3.4804468158322748, 3.5051440864071934, 3.529522342370124, 3.5535918406071034, 3.5773623184641257, 3.600843029315497, 3.6240427750870015, 3.64696993604494, 3.669632498125373, 3.6920380780460635, 3.7141939464159663, 3.736107049033011, 3.757784026539902, 3.779231232589242, 3.8004547506531523, 3.8214604095983375, 3.8422537981350717, 3.8628402782375026, 3.8832249976229316, 3.9034129013690486, 3.9234087427404165, 3.9432170932886734, 3.9628423522847975, 3.9822887555363655, 4.0015603836378455, 4.020661169697629, 4.039594906581575, 4.05836525370934, 4.076975743436604, 4.095429787053457, 4.113730680426636, 4.131881609310972, 4.149885654353339, 4.167745795810452, 4.185464918000168, 4.203045813504346, 4.220491187139936, 4.237803659713623, 4.254985771574214, 4.272039985975839, 4.288968692264083, 4.30577420889624, 4.322458786306071, 4.339024609622681, 4.355473801252456, 4.371808423332338, 4.388030480062146, 4.404141919923131, 4.420144637789407, 4.436040476938513, 4.451831230966866, 4.467518645615555, 4.4831044205114825], [0.0, 0.8957008803007452, 1.1416250758865332, 1.315695654184671, 1.45507037288534, 1.5732672511476096, 1.6769338783588414, 1.7698942366147994, 1.8545754072584115, 1.9326262734711182, 2.0052244945635485, 2.0732441128830392, 2.137353895973968, 2.1980783786402185, 2.255837508508505, 2.310973373734945, 2.363768794486157, 2.4144606038769947, 2.4632493554890362, 2.510306562185039, 2.555780189706867, 2.5997988912310883, 2.6424753171021735, 2.683908734203425, 2.7241871224558496, 2.763388870068409, 2.8015841571765834, 2.8388360948303406, 2.875201669974922, 2.910732535163469, 2.945475672945723, 2.97947395830358, 3.0127666375379727, 3.045389738221851, 3.077376421915107, 3.108757289069559, 3.1395606437758743, 3.169812724602481, 3.199537906662224, 3.228758879150804, 3.257496801882927, 3.285771443770275, 3.3136013057114186, 3.3410037299754425, 3.367994997841412, 3.39459041699127, 3.420804399933964, 3.4466505345550718, 3.4721416477323834, 3.497289862828415, 3.5221066517614585, 3.546602882264037, 3.570788860858692, 3.5946743720136936, 3.6182687138835234, 3.6415807309894292, 3.664618844152627, 3.687391077955793, 3.7099050859765375, 3.7321681740087254, 3.754187321463327, 3.775969201119339, 3.7975201973768162, 3.818846423147837, 3.8399537355069424, 3.860847750210047, 3.8815338551796854, 3.9020172230446866, 3.922302822813625, 3.9423954307537032, 3.9622996405398263, 3.982019872732518, 4.0015603836378455, 4.020925273597638, 4.0401184947539175, 4.059143858327488, 4.078005041447163, 4.0967055935628744, 4.1152489424730865, 4.133638399994338, 4.151877167298394, 4.169968339940409, 4.1879149125995605, 4.205719783551881, 4.223385758893471, 4.240915556530793, 4.2583118099534945, 4.275577071803978, 4.292713817256888, 4.309724447220649, 4.326611291372349, 4.343376611036349, 4.3600226019163255, 4.376551396689699, 4.392965067472783, 4.40926562816439, 4.425455036675124, 4.441535197049029, 4.457507961483881, 4.47337513225591, 4.489138463554431, 4.50479966323141], [0.0, 0.8999763601755812, 1.1470744341978951, 1.3219759095853212, 1.462015910433157, 1.5807769819271102, 1.6849384446220192, 1.7783425337591476, 1.8634279159524265, 1.9418513450542014, 2.0147961017368674, 2.083140400444214, 2.1475562009717826, 2.208570541903509, 2.266605375416585, 2.32200442256831, 2.3750518535205503, 2.4259856318718254, 2.475007268513036, 2.522289094995197, 2.567979783350146, 2.612208600859092, 2.6550887355842763, 2.696719928243036, 2.7371905787139665, 2.7765794493791676, 2.814957055367379, 2.852386808978718, 2.8889259691761744, 2.9246264350678026, 2.9595354134667664, 2.9936959840115906, 3.0271475803389287, 3.0599264019933856, 3.0920657688260706, 3.1235964273549923, 3.1545468167757087, 3.1849433009021118, 3.214810371197612, 3.2441708251610306, 3.2730459236099447, 3.301455529819665, 3.329418232999737, 3.3569514581996973, 3.3840715644146018, 3.410793932395078, 3.4371330434457996, 3.463102550311867, 3.4887153410980476, 3.5139835970357214, 3.5389188448024838, 3.5635320040061793, 3.5878334303658295, 3.611832955054243, 3.635539920609103, 3.658963213769516, 3.6821112955520925, 3.704992228843527, 3.7276137037545154, 3.7499830609519202, 3.772107313161774, 3.79399316501448, 3.815647031384969, 3.8370750543642935, 3.8582831189847715, 3.8792768678081972, 3.9000617144754623, 3.9206428563060824, 3.941025286027373, 3.9612138027052564, 3.9812130219417847, 4.001027385398296, 4.020661169697629, 4.0401184947539175, 4.059403331574077, 4.078519509571144, 4.097470723426099, 4.116260539531583, 4.1348924020480915, 4.153369638600569, 4.1716954656410445, 4.189872993500795, 4.2079052311536, 4.225795090709934, 4.243545391660334, 4.261158864884737, 4.278638156443318, 4.2959858311630965, 4.313204376033552, 4.33029620342345, 4.347263654130204, 4.364109000272233, 4.380834448034043, 4.397442140273037, 4.41393415899643, 4.43031252771605, 4.446579213688262, 4.462736130045749, 4.478785137827447, 4.494728047912452, 4.510566622863412, 4.526302578684443], [0.0, 0.9042144481133959, 1.1524761342185503, 1.3282012399433343, 1.4689007046000737, 1.5882210350777657, 1.692873005588398, 1.7867169448827431, 1.872203003524776, 1.9509957372034552, 2.0242839987903647, 2.092950138337968, 2.157669279974593, 2.218970944166995, 2.2772790701117045, 2.332938997486388, 2.3862362346415456, 2.4374098657725267, 2.4866623507072423, 2.534166832524986, 2.580072683370592, 2.6245097792591525, 2.667591841267977, 2.709419079804441, 2.750080311031918, 2.7896546682332524, 2.8282129986007005, 2.865819013049896, 2.9025302401826, 2.9383988235054908, 2.9734721921338214, 3.007793628572886, 3.041402752156682, 3.074335932897463, 3.1066266475531905, 3.138305787430619, 3.169401925648614, 3.1999415501711743, 3.229949267794714, 3.2594479833739896, 3.2884590578461137, 3.31700244802475, 3.345096830658084, 3.3727597128521305, 3.4000075306382582, 3.426855737196745, 3.4533188820263265, 3.479410682164384, 3.5051440864071934, 3.5305313333488955, 3.5555840039474824, 3.5803130692324356, 3.604728933689, 3.628841474786062, 3.652660079056344, 3.6761936750875877, 3.6994507637402636, 3.7224394458700893, 3.74516744780134, 3.7676421447688875, 3.7898705825224654, 3.8118594972653206, 3.8336153340807377, 3.8551442639835534, 3.8764521997193513, 3.897544810421372, 3.9184275352239393, 3.939105595921319, 3.9595840087521306, 3.979867595381627, 3.99996099314724, 4.01986866462658, 4.039594906581575, 4.059143858327488, 4.078519509571144, 4.097725707758709, 4.116766164969822, 4.135644464391663, 4.154364066403656, 4.172928314300901, 4.191340439682052, 4.20960356752528, 4.227720720973955, 4.245694825852, 4.263528714927243, 4.281225131939637, 4.298786735409946, 4.316216102243243, 4.333515731140514, 4.350688045830636, 4.367735398134096, 4.38466007086897, 4.401464280608928, 4.418150180302325, 4.4347198617607795, 4.451175358025059, 4.467518645615555, 4.483751646674104, 4.499876231003479, 4.515894218010408, 4.531807378557637, 4.547617436730135], [0.0, 0.9084159632310074, 1.1578312199625447, 1.3343728484599815, 1.4757260860452874, 1.595600849349602, 1.7007390948109449, 1.7950190885506312, 1.880902365981281, 1.9600612173020744, 2.033690019498176, 2.102675222542253, 2.167695087588632, 2.2292815955693372, 2.287860655553142, 2.343779211870106, 2.397324099511386, 2.448735513598909, 2.4982168547086885, 2.5459420704451703, 2.5920612270245176, 2.636704803942604, 2.679987050692123, 2.7220086433172725, 2.7628588106738494, 2.8026170537447337, 2.8413545489201395, 2.8791353031542957, 2.916017112360872, 2.9520523623361177, 2.9872887025790082, 3.0217696167109565, 3.0555349081608174, 3.0886211159374324, 3.121061872351581, 3.152888212249298, 3.18412884151706, 3.214810371197612, 3.2449575224250977, 3.2745933064837756, 3.303739183566306, 3.3324152032175123, 3.360640128968798, 3.388431549274548, 3.415805976537652, 3.4427789357430045, 3.4693650439949164, 3.495578082068239, 3.5214310589270124, 3.5469362700331257, 3.5721053501565505, 3.5969493213046606, 3.621478636308092, 3.6457032185322946, 3.669632498125373, 3.693275445162568, 3.7166406000043763, 3.739736101147882, 3.7625697108184317, 3.785148838520602, 3.807480562742846, 3.829571650988795, 3.851428578289403, 3.873057544333691, 3.8944644893413556, 3.9156551087877833, 3.936634867080733, 3.957409010278016, 3.977982577926662, 3.9983604140962328, 4.018547177671972, 4.038547351967266, 4.05836525370934, 4.078005041447163, 4.097470723426099, 4.116766164969822, 4.135895095406491, 4.154861114572892, 4.173667698927418, 4.192318207300095, 4.210815886305498, 4.229163875442292, 4.24736521190116, 4.265422835101135, 4.283339590972757, 4.30111823600502, 4.3187614410717465, 4.336271795051835, 4.353651808256714, 4.3709039156773395, 4.388030480062145, 4.405033794836531, 4.42191608687368, 4.438679519125818, 4.455326193124358, 4.471858151356776, 4.488277379527546, 4.5045858087099155, 4.520785317394864, 4.53687773344316, 4.552864835946026, 4.568748356999548], [0.0, 0.9125816962034995, 1.1631406991932087, 1.3404918965584511, 1.4824933392242612, 1.602917813535734, 1.708538192593927, 1.8032505271273294, 1.8895276404383021, 1.9690494913653978, 2.043015933961325, 2.112317483202042, 2.1776355105514336, 2.2395044364522767, 2.298352123069199, 2.354527105718649, 2.408317534734128, 2.4599647067029466, 2.5096729549373555, 2.5576170247152237, 2.603947670412995, 2.648795969867788, 2.6922766964874394, 2.7344909879873778, 2.775528482401137, 2.8154690452801185, 2.8543841794088842, 2.89233818525905, 2.9293891237796363, 2.965589620993008, 3.000987544904968, 3.035626578540244, 3.0695467078547085, 3.1027846394145335, 3.1353741597585523, 3.1673464460496312, 3.1987303358111423, 3.2295525621163796, 3.2598379594634603, 3.2896096446597403, 3.3188891763081183, 3.3476966958948347, 3.376051052995422, 3.403969916719832, 3.4314698751920614, 3.458566524590096, 3.485274549048061, 3.5116077925354574, 3.537579323671673, 3.5632014943020303, 3.588485992550192, 3.6134438909672717, 3.6380856903175647, 3.662421359472205, 3.6864603718232307, 3.7102117385800546, 3.733684039266797, 3.756885449701336, 3.779823767704342, 3.802506436758234, 3.8249405678113693, 3.8471329594011925, 3.869090116251279, 3.8908182664806303, 3.9123233775490736, 3.9336111710497987, 3.9546871364487584, 3.9755565438606686, 3.996224455942465, 4.016695738977211, 4.036975073214453, 4.057066962526755, 4.076975743436604, 4.0967055935628744, 4.116260539531583, 4.135644464391663, 4.154861114572892, 4.173914106419866, 4.1928069323330135, 4.211542966544982, 4.230125470558384, 4.248557598268717, 4.266842400794342, 4.284982831033618, 4.3029817479677, 4.320841920726044, 4.338566032430326, 4.356156683831296, 4.373616396751944, 4.390947617349392, 4.408152719206954, 4.425234006267015, 4.442193715614556, 4.459034020120476, 4.475757030953202, 4.492364799966469, 4.508859321970619, 4.525242536894239, 4.541516331842528, 4.557682543058294, 4.573742957791159, 4.589699316080099], [0.0, 0.9167124106068887, 1.168405545134469, 1.346559505856091, 1.4892037045698934, 1.6101732688307135, 1.716271728506655, 1.8114127694299218, 1.8980804079027724, 1.977962206937939, 2.052263451613581, 2.1218786877371456, 2.1874923709357565, 2.249641340655585, 2.308755395738723, 2.365184649113639, 2.4192185553989587, 2.4710995033880874, 2.521032751288612, 2.569193835346311, 2.6157341923130004, 2.660785493337183, 2.7044630313376286, 2.7468684018200333, 2.788091648555978, 2.8282129986007, 2.867304278389328, 2.9054300794434558, 2.9426487255194784, 2.979013080846454, 3.014571230100169, 3.049367054032414, 3.083440719591696, 3.1168290994929726, 3.149566133206638, 3.181683139016025, 3.2132090849748187, 3.2441708251610306, 3.274593306483775, 3.304499750386443, 3.3339118130549013, 3.3628497271439155, 3.3913324275498327, 3.4193776633601534, 3.4470020977834412, 3.4742213975923026, 3.501050313387201, 3.52750275180105, 3.5535918406071034, 3.5793299875601385, 3.6047289336890005, 3.6297998016636535, 3.654553139779106, 3.6789989620296404, 3.703146784687705, 3.727005659751095, 3.750584205578334, 3.773890634994362, 3.7969327811159443, 3.819718121117718, 3.842253798135071, 3.864546641478384, 3.886603185314244, 3.9084296859526435, 3.9300321378645493, 3.9514162885413997, 3.972587652296694, 3.9935515230998218, 4.014312986523355, 4.034876930877125, 4.055248057595384, 4.075430890937047, 4.095429787053457, 4.1152489424730865, 4.1348924020480915, 4.154364066403656, 4.173667698927418, 4.1928069323330135, 4.211785274828889, 4.230606115920839, 4.2492727318743535, 4.26778829086074, 4.28615585780896, 4.304378398983382, 4.32245878630607, 4.340399801440682, 4.35820413965379, 4.375874413468193, 4.393413156121676, 4.410822824843656, 4.428105803961249, 4.445264407845416, 4.46230088370709, 4.479217414252464, 4.49601612020597, 4.512699062708862, 4.529268245600801, 4.5457256175912795, 4.562073074327297, 4.57831246036324, 4.5944455710385474, 4.610474154268318], [0.0, 0.9208088441810696, 1.1736266980805488, 1.3525767600195528, 1.4958583805441785, 1.6173685110488483, 1.7239410837479763, 1.8195072732236257, 1.9065621958871637, 1.9868009558184059, 2.061434224048841, 2.1313605437655054, 2.197267429163269, 2.2596941186163697, 2.319072331571864, 2.3757537454776254, 2.430029108413134, 2.4821418923136602, 2.532298272606417, 2.580674569940843, 2.6274228977810874, 2.6726755156631423, 2.716548231705286, 2.759143095404276, 2.8005505529025188, 2.8408511897589643, 2.880117153373327, 2.9184133239017567, 2.955798285726979, 2.992325139307869, 3.028042184192049, 3.062993497217436, 3.0972194248231104, 3.130757004493947, 3.163640327362719, 3.1959008516620684, 3.2275676748927187, 3.258667771133181, 3.2892261987706677, 3.319266283016228, 3.3488097768288565, 3.3778770032752354, 3.4064869818644476, 3.434657540997808, 3.462405418345322, 3.4897463506883484, 3.5166951545420853, 3.543265798682816, 3.569471469546741, 3.5953246303340993, 3.620837074539858, 3.6460199745368955, 3.6708839257564754, 3.6954389869415514, 3.7196947168891157, 3.743660208046846, 3.7673441172853788, 3.7907546941295966, 3.8138998066994363, 3.8367869655821396, 3.8594233458330067, 3.881815807279968, 3.9039709132882763, 3.925894948124956, 3.9475939330479486, 3.969073641232011, 3.9903396116319794, 4.011397161873947, 4.0322514002559435, 4.0529072369317705, 4.07336939434457, 4.093642416970425, 4.113730680426636, 4.133638399994338, 4.153369638600569, 4.172928314300901, 4.192318207300095, 4.211542966544982, 4.230606115920839, 4.249511060079847, 4.268261089927865, 4.286859387793534, 4.305309032301794, 4.323613002972109, 4.34177418456005, 4.359795371159454, 4.377679270081001, 4.395428505521843, 4.413045622039826, 4.430533087844776, 4.447893297918447, 4.465128576973828, 4.4822411822637696, 4.4992333062481356, 4.516107079128057, 4.53286457125523, 4.549507795423703, 4.566038709050996, 4.582459216255024, 4.598771169832775, 4.614976373146364, 4.631076581921648], [0.0, 0.9248717100187196, 1.178805066911298, 1.3585447065111724, 1.5024585255695886, 1.6245047927124712, 1.7315475933721427, 1.82753544757105, 1.9149744808711486, 1.9955672766249613, 2.070529847682755, 2.1407647018551046, 2.206962386841557, 2.269664520286686, 2.3293047265043456, 2.3862362346415456, 2.44075107563951, 2.493093795699699, 2.5434714799529026, 2.5920612270245176, 2.639015821545789, 2.684468106618726, 2.7285344013393753, 2.7713172054753796, 2.8129073642427906, 2.8533858187665557, 2.892825034780871, 2.931290178711256, 2.9688400934311012, 3.0055281136933374, 3.0414027521566824, 3.076508280138376, 3.110885222097257, 3.1445707789379296, 3.1775991922127687, 3.210002058956925, 3.2418086050574235, 3.2730459236099447, 3.3037391835663055, 3.3339118130549013, 3.363585661014859, 3.392781140183907, 3.421517353990516, 3.4498122094998873, 3.4776825182333018, 3.5051440864071934, 3.532211795911364, 3.558899677156241, 3.5852209747602637, 3.6111882069147927, 3.636813219150988, 3.66210723313736, 3.6870808910551727, 3.711744296029365, 3.736107049033011, 3.760178282632207, 3.783966691894122, 3.8074805627428456, 3.8307277980146583, 3.853715941435611, 3.8764521997193517, 3.8989434629612876, 3.921196323486073, 3.9432170932886734, 3.9650118201945026, 3.986586302851177, 4.007946104652949, 4.029096566688763, 4.050042819795887, 4.070789795793092, 4.091342237960261, 4.111704710824972, 4.131881609310972, 4.151877167298394, 4.1716954656410445, 4.191340439682052, 4.210815886305498, 4.230125470558384, 4.2492727318743535, 4.268261089927865, 4.287093850145173, 4.30577420889624, 4.324305258389763, 4.342689991291674, 4.360931305085893, 4.379032006194581, 4.396994813873826, 4.414822363899473, 4.432517212056668, 4.450081837445668, 4.467518645615554, 4.4848299715366, 4.502018082421286, 4.519085180403222, 4.536033405082579, 4.552864835946026, 4.569581494668618, 4.586185347304552, 4.60267830637324, 4.619062232846727, 4.635338938044069, 4.651510185437874], [0.0, 0.9289016976853711, 1.1839415305197942, 1.3644643582342464, 1.5090052598486363, 1.6315833250193088, 1.7390925483858157, 1.8354986550454475, 1.923318690620744, 2.0042626572119717, 2.0795518662602577, 2.1500927581165556, 2.2165788894368794, 2.279554237882229, 2.339454317218387, 2.3966338957345936, 2.4513862768524377, 2.503957072346221, 2.554554269688662, 2.603355739185456, 2.6505149312036167, 2.6961652676887455, 2.7404235745796397, 2.7833927982710756, 2.825164179823302, 2.865819013049896, 2.905430079443456, 2.9440628293822817, 2.981776362138624, 3.0186242448634792, 3.054655201602091, 3.0899136965772227, 3.124440430826873, 3.1582727673529245, 3.1914450969101025, 3.2239891542128287, 3.255934292495481, 3.287307722907779, 3.3181347240714163, 3.34843882619929, 3.3782419734339526, 3.40756466745853, 3.436426094941774, 3.4648442409761957, 3.4928359903367205, 3.5204172181129643, 3.5476028710402985, 3.5744070406645267, 3.600843029315497, 3.6269234097306833, 3.652660079056344, 3.6780643078577016, 3.703146784687705, 3.727917656694121, 3.752386566684803, 3.776562687019614, 3.8004547506531523, 3.8240710796141624, 3.84741961117433, 3.8705079219303435, 3.8933432499980083, 3.9159325154952738, 3.9382823394718454, 3.9603990614262448, 3.982288755536365, 4.003957245716547, 4.025410119602685, 4.0466527415567075, 4.0676902647727236, 4.088527642559154, 4.109169638864, 4.129620838104075, 4.149885654353339, 4.169968339940409, 4.189872993500795, 4.20960356752528, 4.229163875442292, 4.248557598268717, 4.26778829086074, 4.286859387793534, 4.30577420889624, 4.324535964466521, 4.3431477601868975, 4.361612601763393, 4.379933399305269, 4.398112971463245, 4.416154049342152, 4.43405928020283, 4.451831230966867, 4.469472391536822, 4.486985177943591, 4.504371935331726, 4.5216349407927385, 4.5387764060557005, 4.555798480043767, 4.5727032513046515, 4.589492750322552, 4.606168951718445, 4.622733776345257, 4.639189093283935, 4.65553672174608, 4.671778432888365], [0.0, 0.9328994742754345, 1.1890369391583078, 1.3703366950842244, 1.515499667079388, 1.6386052796973478, 1.7465771977251534, 1.8433982138174017, 1.9315962063748378, 2.0128885369485534, 2.0885017732197064, 2.1593462566474355, 2.2261185287940903, 2.2893649084738468, 2.3495227838023145, 2.406948449908835, 2.4619364725246204, 2.5147335204798535, 2.5655484763769003, 2.6145599760338296, 2.6619221302323006, 2.7077689351348986, 2.7522177194720556, 2.795371872695857, 2.837323028546829, 2.8781528307081885, 2.917934373907131, 2.956733390205142, 2.9946092332239775, 3.031615700655178, 3.0678017262409303, 3.1032119655676587, 3.1378872948411516, 3.1718652378649494, 3.2051803334035784, 3.237864452750281, 3.2699470754689193, 3.3014555298196653, 3.3324152032175127, 3.3628497271439164, 3.392781140183908, 3.422230032255083, 3.451215672601147, 3.4797561237182624, 3.5078683430494926, 3.535568274007143, 3.5628709276538526, 3.5897904561821576, 3.6163402191720353, 3.6425328434710935, 3.668380277428139, 3.6938938401142805, 3.7190842660835113, 3.7439617461545582, 3.7685359646356744, 3.7928161333624235, 3.8168110228740075, 3.840528991015244, 3.8639780092179876, 3.8871656866868345, 3.9100992926887557, 3.9327857771242756, 3.955231789538556, 3.9774436967138445, 3.9994275989698806, 4.0211893452857765, 4.042734547345311, 4.0640685925973745, 4.085196656414227, 4.106123713422173, 4.126854548072137, 4.147393764511195, 4.167745795810452, 4.1879149125995605, 4.2079052311536, 4.227720720973955, 4.24736521190116, 4.266842400794342, 4.28615585780896, 4.305309032301794, 4.324305258389763, 4.3431477601868975, 4.361839656741858, 4.380383966696522, 4.3987836126845865, 4.417041425487586, 4.4351601479643925, 4.453142438769037, 4.470990875870542, 4.488707959887428, 4.506296117248625, 4.523757703191639, 4.541095004608056, 4.558310242745714, 4.575405575776231, 4.592383101235946, 4.609244858347787, 4.62599283023104, 4.642628946005533, 4.659155082796305, 4.675573067644418, 4.691884679329192], [0.0, 0.9368656854085666, 1.1940921157082331, 1.3761626654122747, 1.5219427960740708, 1.6455717907549217, 1.7540027501212168, 1.8512353996236397, 1.9398083649081994, 2.0214463088684056, 2.0973810139234743, 2.168526691838541, 2.235582845514209, 2.2990981164326603, 2.359511752259931, 2.417181562909909, 2.4724033664565472, 2.525424880439654, 2.5764558755235223, 2.6256757469942977, 2.673239260833814, 2.7192809828877635, 2.763918740708295, 2.807256363306533, 2.8493858740027713, 2.8903892635873865, 2.9303399375489456, 2.96930390740802, 3.0073407791275892, 3.044504579119447, 3.0808444491670084, 3.1164052347093985, 3.151227985737112, 3.1853503855857, 3.2188071198608386, 3.2516301953561975, 3.2838492169676594, 3.315491629141172, 3.346582927226024, 3.377146843172637, 3.4072055092628264, 3.436779602951981, 3.465888475406768, 3.4945502659158394, 3.52278200401663, 3.550599700904673, 3.5780184314619654, 3.6050524080489215, 3.6317150470436164, 3.658019028976552, 3.6839763529947995, 3.709598386292365, 3.734895909061071, 3.759879155445792, 3.784557850927502, 3.8089412465057757, 3.833038150007659, 3.8568569548112492, 3.880405666238848, 3.9036919258454974, 3.9267230338033694, 3.94950596956041, 3.9720474109322432, 3.994353751769417, 4.016431118327109, 4.038285384451295, 4.059922185683763, 4.0813469323780796, 4.102564821909538, 4.123580850054007, 4.14439982160345, 4.165026360279419, 4.185464918000168, 4.205719783551881, 4.225795090709934, 4.245694825852, 4.265422835101135, 4.284982831033618, 4.304378398983382, 4.323613002972109, 4.342689991291674, 4.361612601763393, 4.380383966696522, 4.399007117566661, 4.417484989433051, 4.435820425112258, 4.454016179124387, 4.472074921426707, 4.4899992409484435, 4.5077916489394685, 4.525454582144645, 4.542990405814744, 4.560401416564045, 4.577689845083993, 4.5948578587216495, 4.611907563931004, 4.628841008604716, 4.645660184293278, 4.662367028318153, 4.678963425784951, 4.695451211502379, 4.711832171812217], [0.0, 0.9408009561704318, 1.1991078568791471, 1.3819431874071704, 1.5283356622873419, 1.6524839561331248, 1.761370375861264, 1.8590114476259652, 1.9479564604793544, 2.029937321699664, 2.1061909877640517, 2.1776355105514336, 2.2449733311992968, 2.3087553957387232, 2.3694227968798396, 2.427334847504264, 2.4827886082591757, 2.536032837213038, 2.587278186164307, 2.636704803942604, 2.684468106618726, 2.7307032252773835, 2.775528482401137, 2.8190481431311536, 2.8613546173283892, 2.9025302401826, 2.9426487255194784, 2.981776362138624, 3.019973006375729, 3.0572929115785956, 3.0937854259489406, 3.1294955832975493, 3.1644646060439325, 3.198730335811142, 3.2323276039004982, 3.265288551549063, 3.297642908007022, 3.3294182329997364, 3.3606401289687975, 3.3913324275498327, 3.4215173539905157, 3.4512156726011463, 3.4804468158322743, 3.5092289991659844, 3.5375793236716726, 3.5655138677993268, 3.5930477697524443, 3.6201953015899515, 3.6469699360449397, 3.673384406912024, 3.6994507637402636, 3.7251804214711557, 3.7505842055783334, 3.775672393194829, 3.800454750653152, 3.824940567811369, 3.849138689493488, 3.8730575443336903, 3.8967051712803484, 3.9200892439865807, 3.943217093288673, 3.966095727951491, 3.988731853840585, 4.011131891663643, 4.033301993408957, 4.055248057595384, 4.076975743436603, 4.098490484012177, 4.119797498528786, 4.140901803746881, 4.161808224640778, 4.182521404353807, 4.203045813504346, 4.223385758893471, 4.243545391660334, 4.263528714927243, 4.283339590972757, 4.3029817479677, 4.32245878630607, 4.34177418456005, 4.360931305085893, 4.379933399305269, 4.3987836126845865, 4.417484989433051, 4.436040476938512, 4.454452929958687, 4.472725114583944, 4.4908597119866105, 4.508859321970618, 4.526726466334253, 4.544463592057839, 4.562073074327296, 4.5795572194037515, 4.596918267348589, 4.614158394612734, 4.63127971649826, 4.6482842894999274, 4.665174113533666, 4.681951134058585, 4.6986172440986165, 4.715174286169514, 4.731624054116522], [0.0, 0.9447058920015806, 1.2040849343417377, 1.3876791504009631, 1.5346792492602779, 1.6593428392670977, 1.7686812084529122, 1.866727554167672, 1.956041746671034, 2.038362881782806, 2.1149330501539976, 2.1866741141758905, 2.2542914305735344, 2.318338232162356, 2.3792574424740995, 2.4374098657725267, 2.4930937956996986, 2.5465590228318478, 2.598017073309393, 2.6476488436967607, 2.69561039514252, 2.7420374196132653, 2.7870487307068146, 2.83074902633248, 2.873231099912241, 2.914577628380438, 2.9548626315230813, 2.9941526732814014, 3.032507858433812, 3.0699826655147917, 3.10662664755319, 3.142485025279395, 3.1775991922127678, 3.2120071470437073, 3.2457438656460873, 3.2788416226640056, 3.311330270743373, 3.3432374840003334, 3.3745889711432624, 3.405408662724574, 3.4357188762411743, 3.465540462188755, 3.494892933675175, 3.5237945817886147, 3.5522625785790307, 3.5803130692324356, 3.6079612547857165, 3.6352214665361258, 3.66210723313736, 3.6886313412375626, 3.7148058903992585, 3.740642342943376, 3.766151569276304, 3.791343889187861, 3.8162291095471885, 3.8408165587713055, 3.8651151183959915, 3.889133252039742, 3.9128790320177935, 3.936360163833915, 3.9595840087521306, 3.982557604628239, 4.005287685161494, 4.027780697709694, 4.050042819795887, 4.072079974421617, 4.093897844289981, 4.115501885031355, 4.136897337515523, 4.1580892393257525, 4.179082435463142, 4.199881588343086, 4.220491187139936, 4.240915556530793, 4.261158864884737, 4.281225131939637, 4.30111823600502, 4.320841920726044, 4.340399801440682, 4.359795371159454, 4.379032006194581, 4.398112971463245, 4.417041425487586, 4.435820425112258, 4.454452929958687, 4.472941806633692, 4.491289832708714, 4.50949970048469, 4.52757402055643, 4.545515325189321, 4.563326071520246, 4.581008644593695, 4.598565360243275, 4.615998467828084, 4.633310152832733, 4.650502539339175, 4.667577692377961, 4.684537620165972, 4.701384276237239, 4.718119561472974, 4.7347453260365695, 4.751263371218894], [0.0, 0.9485810795378828, 1.2090240957989868, 1.393371416103495, 1.5409745099856604, 1.6661494705622155, 1.7759363461975992, 1.8743848784342283, 1.964065438130316, 2.046724254884026, 2.123608514407434, 2.1956438605752227, 2.26353854348869, 2.3278480653265947, 2.3890171664948685, 2.447408131277878, 2.5033204769194572, 2.5570050186378306, 2.608674150254534, 2.6585095103724603, 2.7066678003036655, 2.7532852686237614, 2.798481216304442, 2.8423607707262843, 2.885017105950274, 2.9265332380518827, 2.9669834904465953, 3.006434700121207, 3.0449472184041864, 3.0825757473011883, 3.1193700431077955, 3.1553755120500213, 3.1906337174436175, 3.22518281384977, 3.259057920613535, 3.292291444769736, 3.3249133614199615, 3.3569514581996973, 3.3884315492745474, 3.4193776633601534, 3.4498122094998873, 3.4797561237182615, 3.509228999165985, 3.538249201961359, 3.5668339745941617, 3.594999528478025, 3.6227611270045545, 3.650133160258044, 3.6771292123867836, 3.703762122489802, 3.7300440397620798, 3.7559864735430337, 3.7816003388295063, 3.806895997743136, 3.8318832973808834, 3.856571604424973, 3.880969836843282, 3.905086492972104, 3.928929678239346, 3.952507129756787, 3.975826238984386, 3.998894072647256, 4.021717392066313, 4.044302671046447, 4.066656112450927, 4.088783663577478, 4.110691030439666, 4.132383691046888, 4.153866907766997, 4.175145738847448, 4.196225049163554, 4.217109520255958, 4.237803659713623, 4.2583118099534945, 4.278638156443318, 4.298786735409946, 4.3187614410717465, 4.338566032430326, 4.35820413965379, 4.377679270081001, 4.396994813873826, 4.416154049342152, 4.4351601479643925, 4.454016179124387, 4.472725114583944, 4.491289832708714, 4.509713122463748, 4.527997687193815, 4.546146148202392, 4.564161048142232, 4.582044854229403, 4.599799961291858, 4.617428694662762, 4.634933312928095, 4.652316010537334, 4.669578920285424, 4.686724115673683, 4.703753613156704, 4.720669374281924, 4.737473307727976, 4.754167271247631, 4.770753073520661], [0.0, 0.952427087405685, 1.2139260659996476, 1.3990208197704068, 1.547222368199715, 1.6729048487907572, 1.7831368536792782, 1.8819845440245007, 1.972028712215023, 2.055022667910923, 2.132218653520183, 2.2045460659267966, 2.272716026821556, 2.3372862906585357, 2.398703401037023, 2.457331111117623, 2.513470152532377, 2.5673723574260783, 2.61925098076785, 2.669288397611599, 2.7176419446125166, 2.7644484227640373, 2.809827616741869, 2.853885080163988, 2.8967143648642235, 2.9383988235054903, 2.979013080846454, 3.018624244863479, 3.0572929115785956, 3.095074004785928, 3.132017482517217, 3.1681689350973445, 3.2035700943599075, 3.2382592695631915, 3.272271722443115, 3.305639991428342, 3.338394173154064, 3.370562167920321, 3.402169894555868, 3.4332414792004156, 3.463799421754469, 3.4938647431273404, 3.523457115909877, 3.552594980685533, 3.581295649853504, 3.6095754005563583, 3.6374495580708954, 3.6649325708257914, 3.692038078046063, 3.718778970886676, 3.74516744780134, 3.7712150647939184, 3.7969327811159443, 3.8223310009021256, 3.8474196111743297, 3.8722080165918555, 3.896705171280349, 3.92091960803248, 3.9448594651394933, 3.9685325110831724, 3.9919461672920407, 4.015107529143143, 4.038023385371071, 4.060700236028658, 4.083144309128592, 4.105361576081827, 4.127357766036877, 4.149138379213646, 4.1707086993161795, 4.19207380510052, 4.213238581166547, 4.23420772803614, 4.254985771574214, 4.275577071803978, 4.2959858311630965, 4.316216102243243, 4.336271795051835, 4.356156683831296, 4.375874413468193, 4.395428505521843, 4.414822363899473, 4.43405928020283, 4.453142438769037, 4.472074921426707, 4.4908597119866105, 4.50949970048469, 4.527997687193815, 4.546356386419421, 4.564578430093027, 4.582666371176529, 4.600622686889289, 4.618449781769052, 4.636149990577013, 4.6537255810565545, 4.671178756554517, 4.688511658513232, 4.705726368840994, 4.722824912168083, 4.7398092579950015, 4.756681322739092, 4.773442971685356, 4.79009602084683], [0.0, 0.9562444669746236, 1.2187915476977498, 1.4046281713089468, 1.5534237196050584, 1.679609942414194, 1.7902837631738393, 1.8895276404383023, 1.9799327105524447, 2.0632593105368247, 2.1407647018551046, 2.21338200646454, 2.2818251962703378, 2.34665426123676, 2.4083175347341275, 2.4671802278654984, 2.5235442776116512, 2.577662525474314, 2.629749081160124, 2.679987050692123, 2.7285344013393753, 2.775528482401137, 2.821089558656611, 2.8653236067884165, 2.9083245535912203, 2.9501760858099435, 2.990953127303344, 3.030723055020205, 3.069546707854709, 3.107479229738534, 3.14457077893793, 3.1808671285062804, 3.21641017754064, 3.2512383888448877, 3.285387165485895, 3.3188891763081183, 3.3517746385757006, 3.3840715644146018, 3.415805976537652, 3.4470020977834417, 3.4776825182333018, 3.507868343049492, 3.537579323671673, 3.5668339745941617, 3.595649677605191, 3.6240427750870015, 3.6520286537409348, 3.6796218199057567, 3.7068359674732387, 3.733684039266797, 3.760178282632207, 3.786330299890425, 3.812151094218259, 3.837651111450755, 3.8628402782375026, 3.8877280369321863, 3.912323377549074, 3.936634867080733, 3.960670676437123, 3.9844386052365244, 4.007946104652949, 4.0312002985021, 4.054208002728185, 4.076975743436604, 4.099509773602258, 4.121816088569841, 4.143900440450607, 4.165768351509639, 4.187425126628355, 4.2088758649187294, 4.230125470558384, 4.251178662909145, 4.272039985975839, 4.292713817256888, 4.313204376033552, 4.333515731140514, 4.353651808256714, 4.373616396751944, 4.393413156121676, 4.413045622039826, 4.432517212056668, 4.451831230966867, 4.470990875870542, 4.4899992409484435, 4.508859321970618, 4.52757402055643, 4.546146148202392, 4.564578430093027, 4.582873508708775, 4.601033947243946, 4.619062232846728, 4.636960779692386, 4.654731931899967, 4.672377966302088, 4.689901095076727, 4.70730346824923, 4.724587176072296, 4.741754251291032, 4.758806671299806, 4.775746360197064, 4.792575190743972, 4.8092949862322465], [0.0, 0.960033753070801, 1.2236212225615857, 1.410194256325553, 1.5595794330292572, 1.686265690835858, 1.7973780759843172, 1.8970152244856207, 1.9877785405159891, 2.0714353367395817, 2.1492478567387, 2.222152920129704, 2.2908673280564593, 2.355953289541491, 2.4178609145545833, 2.4769568614117214, 2.5335442635718266, 2.5878769644653383, 2.640169922246088, 2.6906069685267875, 2.739346696549457, 2.786526999883995, 2.8322686198798457, 2.8766779531707836, 2.919849298752843, 2.9618666749943214, 3.002805302652882, 3.042732825670263, 3.0817103240254147, 3.119793160167499, 3.1570316911236747, 3.1934718713310626, 3.2291557659192254, 3.2641219901076335, 3.2984060872540097, 3.3320408556588252, 3.3650566323274216, 3.397481540388712, 3.4293417056750806, 3.4606614470123573, 3.4914634439990246, 3.521768885430242, 3.551597601014207, 3.5809681786121614, 3.609898068890717, 3.638403678991665, 3.666500456588845, 3.6942029655049287, 3.7215249538961315, 3.7484794158740726, 3.7750786473167794, 3.801334296521435, 3.827257410266864, 3.8528584757815603, 3.8781474590512013, 3.9031338398464497, 3.9278266438060796, 3.9522344718708666, 3.9763655273294303, 4.000227640707404, 4.023828292705382, 4.0471746353684335, 4.070273511650138, 4.09313147351673, 4.11575479872162, 4.138149506367105, 4.160321371358184, 4.182275937842883, 4.204018531724143, 4.225554272320062, 4.246888083241923, 4.268024702552848, 4.288968692264083, 4.309724447220649, 4.33029620342345, 4.350688045830636, 4.3709039156773395, 4.390947617349392, 4.410822824843656, 4.430533087844776, 4.450081837445668, 4.469472391536822, 4.488707959887428, 4.5077916489394685, 4.526726466334253, 4.545515325189321, 4.564161048142232, 4.582666371176529, 4.601033947243946, 4.619266349695895, 4.637366075536328, 4.6553355485071, 4.67317712201624, 4.6908930819187145, 4.708485649158641, 4.72595698228122, 4.743309179822141, 4.760544282581622, 4.7776642757898, 4.794671091169698, 4.811566608903626, 4.828352659508414], [0.0, 0.9637954646528334, 1.2284157520353751, 1.4157198371189026, 1.565690351523071, 1.6928730055883978, 1.804420763706592, 1.9044483216224806, 1.9955672766249613, 2.0795518662602572, 2.157669279974593, 2.2308600081356844, 2.299843660537776, 2.3651846491136395, 2.427334847504264, 2.486662350707242, 2.543471479952902, 2.598017073309393, 2.6505149312036163, 2.7011496055578608, 2.750080311031918, 2.7974454815056893, 2.8433663314308717, 2.8879496743364266, 2.9312901787112557, 2.9734721921338214, 3.014571230100169, 3.054655201602091, 3.093785425948941, 3.132017482517217, 3.1694019256486134, 3.2059848898440637, 3.241808605057423, 3.2769118378146325, 3.3113302707433734, 3.345096830658084, 3.378241973433952, 3.410793932395078, 3.442778935743004, 3.4742213975923026, 3.5051440864071934, 3.5355682740071424, 3.565513867799327, 3.594999528478025, 3.624042775087001, 3.6526600790563437, 3.6808669485886947, 3.708678004572324, 3.7361070490330106, 3.7631671269973537, 3.7898705825224654, 3.8162291095471885, 3.842253798135071, 3.8679551766068387, 3.893343249998008, 3.9184275352239393, 3.943217093288673, 3.9677205588341526, 3.9919461672920407, 4.01590177987041, 4.039594906581574, 4.063032727494544, 4.086222112375726, 4.1091696388639996, 4.131881609310971, 4.154364066403657, 4.176622807674934, 4.198663398996532, 4.2204911871399355, 4.242111311482331, 4.263528714927243, 4.284748154103004, 4.30577420889624, 4.326611291372349, 4.347263654130204, 4.367735398134096, 4.388030480062145, 4.408152719206954, 4.428105803961249, 4.447893297918447, 4.467518645615554, 4.486985177943591, 4.506296117248625, 4.525454582144645, 4.544463592057839, 4.563326071520246, 4.582044854229403, 4.600622686889289, 4.619062232846728, 4.637366075536328, 4.6555367217460795, 4.673576604714813, 4.691488087071945, 4.709273463629135, 4.726934964032851, 4.744474755286148, 4.761894944147431, 4.7791975794134105, 4.796384654092972, 4.813458107478236, 4.830419827118651, 4.847271650703581], [0.0, 0.9675301054530917, 1.2331757781565644, 1.4212056536218303, 1.57175729340215, 1.6994327714600954, 1.811412769429922, 1.9118279272180274, 2.00329996187227, 2.0876099859867145, 2.1660300992790913, 2.2395044364522767, 2.3087553957387232, 2.374349576128425, 2.4367406022414935, 2.49629799541819, 2.5533272561125746, 2.608084209872693, 2.6607854933371833, 2.7116163735542753, 2.7607366821295622, 2.808285389364659, 2.8543841794088842, 2.8991402796862396, 2.9426487255194784, 2.9849941913280973, 3.026252485225469, 3.0664917793460353, 3.1057736306072345, 3.144153833751807, 3.181683139016025, 3.2184078596688246, 3.254370389302213, 3.28960964465974, 3.3241614466368015, 3.358058849636966, 3.3913324275498327, 3.4240105231016806, 3.45611946612652, 3.4876837653419295, 3.5187262774383536, 3.5492683566620884, 3.5793299875601385, 3.608929903135681, 3.6380856903175647, 3.666813884361531, 3.695130053563435, 3.723048875466478, 3.750584205578334, 3.7777491394741793, 3.8045560690434934, 3.8310167335383247, 3.85714226599545, 3.8829432355321107, 3.9084296859526435, 3.9336111710497983, 3.9584967869383796, 3.9830952017189722, 4.007414682734966, 4.031463121656073, 4.055248057595384, 4.078776698444181, 4.102055940588741, 4.12509238715584, 4.147892364918261, 4.170461939978011, 4.1928069323330135, 4.214932929422359, 4.236845298735908, 4.258549199565572, 4.280049593968291, 4.301351257004001, 4.322458786306071, 4.343376611036349, 4.364109000272233, 4.38466007086897, 4.405033794836531, 4.425234006267015, 4.445264407845416, 4.465128576973828, 4.4848299715366, 4.504371935331726, 4.523757703191639, 4.542990405814744, 4.562073074327296, 4.581008644593695, 4.599799961291858, 4.618449781769052, 4.636960779692386, 4.6553355485071, 4.673576604714813, 4.69168639098299, 4.70966727909607, 4.727521572757952, 4.745251510254827, 4.76285926698674, 4.780346957875638, 4.7977166396571755, 4.814970313063013, 4.83210992489989, 4.849137370031381, 4.86605449326777], [0.0, 0.9712381645862905, 1.2379019243315112, 1.4266524242952847, 1.5777810532356928, 1.7059458475638296, 1.8183550088763443, 1.919155007757093, 2.010977608984531, 2.095610751266747, 2.174331409643645, 2.2480873372143537, 2.3176037008025556, 2.3834492708888755, 2.4460794106097836, 2.505865057496079, 2.5631128828323133, 2.6180796926179464, 2.670982953751535, 2.7220086433172725, 2.7713172054753796, 2.8190481431311536, 2.8653236067884165, 2.9102512348202723, 2.9539264267723486, 2.9964341815788567, 3.0378505978877626, 3.0782441091032147, 3.117676508059537, 3.1562038033328212, 3.193876939659621, 3.2307424078044766, 3.2668427638328357, 3.3022170736366676, 3.336901295394951, 3.3709286101922555, 3.4043297090926123, 3.4371330434457996, 3.4693650439949164, 3.501050313387201, 3.5322117959113646, 3.562870927653852, 3.5930477697524448, 3.6227611270045545, 3.6520286537409348, 3.6808669485886947, 3.7092916395091837, 3.7373174602972865, 3.7649583195619116, 3.7922273630670267, 3.8191370301940277, 3.8456991051856457, 3.8719247637460223, 3.8978246154985405, 3.9234087427404165, 3.9486867358793116, 3.9736677258908903, 3.9983604140962323, 4.022773099523322, 4.046913704086695, 4.070789795793092, 4.094408610158041, 4.117777069998217, 4.140901803746882, 4.163789162424171, 4.186445235380434, 4.2088758649187294, 4.2310866598920125, 4.253083008361047, 4.274870089390733, 4.29645288405509, 4.317836185714473, 4.339024609622681, 4.3600226019163255, 4.380834448034043, 4.401464280608928, 4.42191608687368, 4.442193715614556, 4.46230088370709, 4.4822411822637696, 4.502018082421286, 4.5216349407927385, 4.541095004608056, 4.560401416564045, 4.5795572194037515, 4.598565360243275, 4.617428694662762, 4.636149990577013, 4.654731931899967, 4.67317712201624, 4.691488087071945, 4.70966727909607, 4.727717078962919, 4.7456397992053345, 4.763437686687742, 4.7811129251474025, 4.798667637611706, 4.816103888698744, 4.833423686807981, 4.850628986207295, 4.867721689022324, 4.884703647133587], [0.0, 0.9749201171274217, 1.242594796072095, 1.4320608469772562, 1.5837624027853001, 1.7124130683521985, 1.8252483714826857, 1.9264305019821841, 2.018601201618694, 2.1035551871550697, 2.1825742746286805, 2.2566098100595875, 2.3263897093704333, 2.392484899244094, 2.4553524690933735, 2.515364762668918, 2.572829613842539, 2.628004802162241, 2.681108618941054, 2.732327746300125, 2.781823236641615, 2.829735121724704, 2.8761860151243486, 2.9212839632694685, 2.9651247273642554, 3.007793628572886, 3.049367054032414, 3.0899136965772227, 3.1294955832975493, 3.1681689350973445, 3.2059848898440637, 3.2429901145481903, 3.2792273266047216, 3.3147357400039663, 3.3495514492419396, 3.383707761192315, 3.4172354832685903, 3.450163174679277, 3.4825173663661135, 3.5143227542446858, 3.545602369585237, 3.576377729738164, 3.6066689718927876, 3.6364949721352877, 3.6658734517237788, 3.6948210722105714, 3.7233535208024344, 3.7514855871498973, 3.779231232589242, 3.806603652719873, 3.8336153340807377, 3.8602781055884927, 3.886603185314244, 3.912601223102332, 3.938282339471845, 3.963656161187567, 3.9887318538405854, 4.013518151738586, 4.03802338537107, 4.062255506684462, 4.086222112375726, 4.109930465390143, 4.133387514788708, 4.156599914132993, 4.179574038519781, 4.202316000384074, 4.224831664177034, 4.247126660014713, 4.26920639638395, 4.291076071983419, 4.312740686770334, 4.334205052276621, 4.355473801252456, 4.376551396689699, 4.397442140273037, 4.418150180302325, 4.438679519125818, 4.459034020120476, 4.479217414252464, 4.4992333062481356, 4.519085180403222, 4.5387764060557005, 4.558310242745714, 4.577689845083993, 4.596918267348589, 4.615998467828084, 4.634933312928095, 4.6537255810565545, 4.672377966302088, 4.6908930819187145, 4.709273463629135, 4.727521572757952, 4.7456397992053345, 4.763630464270911, 4.781495823336944, 4.799238068419218, 4.816859330593492, 4.834361682304804, 4.851747139566436, 4.869017664054873, 4.886175165106688, 4.903221501622858], [0.0, 0.9785764246608916, 1.2472549816956267, 1.4374315996894047, 1.5897020918970528, 1.718835244582059, 1.8320937214286583, 1.9336553219785728, 2.026171695499051, 2.1114442895981775, 2.190759727592966, 2.2650729233995133, 2.335114522891792, 2.401457593936859, 2.464560940200239, 2.5247983018580262, 2.582478667271803, 2.6378607827573, 2.6911637582999273, 2.7425749761471634, 2.792256092706667, 2.8403476649080077, 2.8869727661719584, 2.9322398481411223, 2.976245031159282, 3.019073956376232, 3.060803297408769, 3.1015020047145656, 3.1412323380081677, 3.1800507290425073, 3.2180085074707736, 3.255152515321834, 3.2915256301965616, 3.327167213152093, 3.362113494052025, 3.396397904683006, 3.4300513679976183, 3.463102550311867, 3.495578082068239, 3.52750275180105, 3.5588996771562416, 3.5897904561821568, 3.620195301589952, 3.650133160258044, 3.6796218199057567, 3.708678004572324, 3.737317460297287, 3.7655550321977804, 3.7934047339702115, 3.820879810702317, 3.847992795762137, 3.8747555624291, 3.9011793708461866, 3.9272749107985545, 3.9530523407609457, 3.9785213236020383, 4.003691059287243, 4.028570314881099, 4.053167452115495, 4.077490452759565, 4.101546942000672, 4.125344210022801, 4.148889231948471, 4.1721886862925475, 4.195248972060759, 4.2180762246119805, 4.240676330391214, 4.263054940629506, 4.285217484097505, 4.307169178990908, 4.3289150440186, 4.350459908757515, 4.371808423332338, 4.392965067472783, 4.41393415899643, 4.4347198617607795, 4.455326193124358, 4.475757030953202, 4.49601612020597, 4.516107079128057, 4.536033405082579, 4.555798480043767, 4.575405575776231, 4.5948578587216495, 4.614158394612734, 4.633310152832733, 4.652316010537334, 4.671178756554517, 4.689901095076727, 4.708485649158641, 4.726934964032851, 4.745251510254827, 4.763437686687742, 4.781495823336944, 4.799428184043207, 4.817236969043178, 4.834924317404932, 4.852492309345932, 4.869942968440249, 4.887278263721374, 4.904500111686591, 4.921610378208438], [0.0, 0.9822075358025828, 1.2518830529902465, 1.442765341403916, 1.5956008493496017, 1.7252131642315092, 1.8388918986142648, 1.940830354205882, 2.033690019498176, 2.119279026560778, 2.1988887728623614, 2.2734777156279273, 2.343779211870106, 2.41036845588478, 2.473705953776914, 2.534166832524986, 2.5920612270245176, 2.647648843696761, 2.7011496055578608, 2.7527515901569095, 2.802617053744734, 2.8508870748022304, 2.8976851834270936, 2.9431202336831976, 2.9872887025790082, 3.030276549044849, 3.0721607312030663, 3.113010455359286, 3.152888212249298, 3.1918506430220117, 3.229949267794714, 3.267231102408566, 3.3037391835663055, 3.339513018378428, 3.374588971143263, 3.4090005976996345, 3.4427789357430045, 3.4759527579587703, 3.5085487936044872, 3.540591923194945, 3.5721053501565505, 3.6031107526794868, 3.6336284184763077, 3.663677364729823, 3.693275445162568, 3.7224394458700893, 3.75118517131927, 3.77952752171162, 3.807480562742846, 3.8350575886479814, 3.862271179301452, 3.8891332520397426, 3.9156551087877833, 3.9418474789963085, 3.967720558834153, 3.99328404702509, 4.018547177671972, 4.043518750370458, 4.068207157879526, 4.092620411585505, 4.116766164969823, 4.140651735267461, 4.164284123482866, 4.18767003291224, 4.210815886305498, 4.233727841787409, 4.256411807645252, 4.278873456079565, 4.301118236005021, 4.323151384979983, 4.344977940335786, 4.36660274957002, 4.388030480062146, 4.40926562816439, 4.43031252771605, 4.451175358025059, 4.471858151356776, 4.492364799966469, 4.512699062708862, 4.53286457125523, 4.552864835946026, 4.5727032513046515, 4.592383101235946, 4.611907563931004, 4.63127971649826, 4.650502539339175, 4.669578920285424, 4.688511658513232, 4.70730346824923, 4.72595698228122, 4.744474755286148, 4.76285926698674, 4.7811129251474025, 4.799238068419218, 4.817236969043178, 4.8351118354201414, 4.852864814555419, 4.870497994385342, 4.888013405992668, 4.905413025717191, 4.922698777167565, 4.939872533139841], [0.0, 0.98581388669645, 1.2564795658478674, 1.4480627127729528, 1.6014593836608921, 1.7315475933721427, 1.8456437195895274, 1.947956460479355, 2.0411570766651455, 2.1270603390972846, 2.206962386841557, 2.2818251962703378, 2.3523848170478843, 2.419218555398959, 2.4827886082591757, 2.543471479952902, 2.601578444091479, 2.6573701606548012, 2.7110673601457576, 2.7628588106738494, 2.812907364242791, 2.8613546173283897, 2.9083245535912203, 2.953926426772349, 2.998257068112859, 3.0414027521566824, 3.0834407195916964, 3.1244404308268736, 3.164464606043933, 3.203570094359908, 3.2418086050574235, 3.279227326604722, 3.3158694537215054, 3.3517746385757006, 3.386979378983672, 3.421517353990516, 3.4554197152521526, 3.488715341098047, 3.5214310589270124, 3.5535918406071034, 3.585220974760264, 3.616340219172035, 3.64696993604494, 3.6771292123867836, 3.7068359674732387, 3.7361070490330106, 3.7649583195619116, 3.7934047339702115, 3.8214604095983375, 3.8491386894934885, 3.8764521997193517, 3.903412901369048, 3.9300321378645493, 3.95632067805169, 3.9822887555363655, 4.007946104652949, 4.033301993408958, 4.05836525370934, 4.083144309128592, 4.107647200468285, 4.131881609310972, 4.1558548797581745, 4.179574038519782, 4.203045813504347, 4.226276651044062, 4.249272731874354, 4.272039985975838, 4.294584106375552, 4.316910561994834, 4.339024609622681, 4.360931305085894, 4.382635513680516, 4.404141919923131, 4.425455036675124, 4.446579213688262, 4.467518645615555, 4.488277379527546, 4.508859321970619, 4.529268245600801, 4.549507795423703, 4.569581494668618, 4.589492750322552, 4.609244858347787, 4.628841008604716, 4.6482842894999274, 4.667577692377961, 4.686724115673683, 4.705726368840994, 4.724587176072296, 4.743309179822141, 4.761894944147431, 4.780346957875638, 4.798667637611706, 4.816859330593492, 4.834924317404932, 4.852864814555419, 4.870682976933382, 4.888380900141383, 4.905960622719664, 4.923424128264504, 4.940773347447431, 4.958010159940803], [0.0, 0.9893959014871396, 1.2610450608665555, 1.4533243368228845, 1.6072783838559341, 1.7378392769991882, 1.8523499784393265, 1.9550344789037442, 2.0485737452041093, 2.13478914237157, 2.214981519072138, 2.2901163470779196, 2.3609323505344495, 2.4280089333438157, 2.4918099718623425, 2.55271333846579, 2.61103143779712, 2.667025876960138, 2.720918188495458, 2.772897826413002, 2.8231282344491566, 2.8717515235791478, 2.91889212796573, 2.964659698330092, 3.009151417755528, 3.0524538742697795, 3.094644589219466, 3.135793275402187, 3.1759628808972606, 3.2152104613864494, 3.253587914041205, 3.2911425987919443, 3.327917867309012, 3.3639535158389027, 3.399286174815019, 3.4339496456573193, 3.4679751932131615, 3.5013918007431797, 3.5342263931251745, 3.566504032964004, 3.5982480935022383, 3.629480411583656, 3.6602214233980854, 3.690490285307135, 3.720304981697257, 3.7496824215144056, 3.7786385248917367, 3.807188301079098, 3.8353459187131334, 3.863124769323815, 3.8905375248524026, 3.917596189853376, 3.944312148965723, 3.970696210164534, 3.996758644240135, 4.022509220897196, 4.047957241819104, 4.073111571002072, 4.097980662628167, 4.122572586715702, 4.146895052758729, 4.170955431544008, 4.194760775313407, 4.218317836421746, 4.241633084624356, 4.2647127231147435, 4.28756270342047, 4.3101887392545315, 4.332596319409926, 4.354790719776515, 4.376777014551751, 4.398560086710028, 4.420144637789407, 4.441535197049029, 4.462736130045749, 4.483751646674104, 4.5045858087099155, 4.525242536894239, 4.5457256175912795, 4.566038709050996, 4.586185347304552, 4.606168951718445, 4.62599283023104, 4.645660184293278, 4.665174113533666, 4.684537620165972, 4.703753613156704, 4.722824912168083, 4.741754251291032, 4.760544282581622, 4.7791975794134105, 4.7977166396571755, 4.816103888698744, 4.834361682304804, 4.852492309345932, 4.870497994385342, 4.888380900141383, 4.906143129831116, 4.923786729401941, 4.941313689657659, 4.958725948285008, 4.976025391786249], [0.0, 0.992953992770028, 1.265580063924133, 1.4585508196153507, 1.6130585201978949, 1.7440889398219852, 1.8590114476259656, 1.9620652247625838, 2.0559408794061094, 2.142466326628004, 2.222947093240096, 2.2983521230691992, 2.36942279687984, 2.436740602241494, 2.5007710837147075, 2.561893472589709, 2.6204212969871667, 2.676617104809158, 2.730703225277384, 2.7828697937212055, 2.8332808416576274, 2.8820789911250615, 2.9293891237796363, 2.975321284671317, 3.0199730063757295, 3.0634311883107346, 3.105773630607235, 3.147070296765807, 3.187384361241289, 3.2267730849005707, 3.265288551549063, 3.302978291434195, 3.3398858121287174, 3.3760510529954217, 3.411510776199028, 3.4462989047170405, 3.4804468158322748, 3.513983597035721, 3.5469362700331253, 3.5793299875601385, 3.6111882069147927, 3.642532843471093, 3.673384406912025, 3.703762122489802, 3.733684039266797, 3.7631671269973537, 3.7922273630670267, 3.820879810702317, 3.8491386894934885, 3.8770174391294825, 3.904528777122723, 3.9316847511987816, 3.95849678693838, 3.984975731184531, 4.011131891663643, 4.036975073214453, 4.062514610971303, 4.087759400807341, 4.1127179273077825, 4.13739828951255, 4.161808224640779, 4.185955129986246, 4.209846083152272, 4.233487860776672, 4.256886955881482, 4.280049593968291, 4.3029817479677, 4.32568915214051, 4.348177315018656, 4.370451531465294, 4.392516893925837, 4.414378302934959, 4.436040476938513, 4.457507961483881, 4.478785137827447, 4.499876231003479, 4.520785317394864, 4.541516331842528, 4.562073074327297, 4.582459216255024, 4.60267830637324, 4.622733776345257, 4.642628946005533, 4.662367028318153, 4.681951134058585, 4.701384276237239, 4.720669374281924, 4.7398092579950015, 4.758806671299806, 4.7776642757898, 4.796384654092972, 4.814970313063013, 4.833423686807981, 4.851747139566436, 4.869942968440249, 4.888013405992668, 4.905960622719664, 4.923786729401941, 4.941493779344593, 4.959083770510796, 4.97655864755565, 4.993920303765704], [0.0, 0.996488562019974, 1.2700850867246476, 1.4637427508770544, 1.6188004448846063, 1.7502972870170737, 1.8656288787918809, 1.9690494913653978, 2.0632593105368247, 2.150092758116555, 2.230860008135684, 2.3065334535224724, 2.3778571140979112, 2.445414547324036, 2.509672954937355, 2.571012918158977, 2.6297490811601234, 2.686144926421664, 2.7404235745796393, 2.792775837778746, 2.8433663314308717, 2.8923381852590495, 2.9398167254544663, 2.985912388789013, 3.030723055020204, 3.0743359328974624, 3.1168290994929726, 3.158272767352924, 3.198730335811142, 3.2382592695631915, 3.2769118378146325, 3.3147357400039663, 3.3517746385757, 3.3880686150628008, 3.4236545624904493, 3.458566524590096, 3.4928359903367197, 3.5264921507626146, 3.559562123761357, 3.5920711516035464, 3.624042775087001, 3.655498987596799, 3.6864603718232307, 3.7169462214536897, 3.746974649798904, 3.776562687019613, 3.805726367375281, 3.834480807712232, 3.862840278237502, 3.89081826648063, 3.9184275352239393, 3.945680175078695, 3.972587652296694, 3.99916085233192, 4.025410119602685, 4.051345293849527, 4.076975743436603, 4.102310395903261, 4.127357766036877, 4.152125981707124, 4.176622807674934, 4.2008556675658655, 4.224831664177034, 4.248557598268716, 4.272039985975838, 4.2952850749606, 4.3182988594151475, 4.341087094012246, 4.363655306892281, 4.3860088117662706, 4.408152719206953, 4.430091947193195, 4.451831230966866, 4.47337513225591, 4.494728047912452, 4.515894218010408, 4.53687773344316, 4.557682543058294, 4.57831246036324, 4.598771169832775, 4.619062232846727, 4.639189093283935, 4.659155082796305, 4.678963425784951, 4.6986172440986165, 4.718119561472974, 4.737473307727976, 4.756681322739092, 4.775746360197064, 4.794671091169698, 4.813458107478236, 4.83210992489989, 4.850628986207295, 4.869017664054873, 4.887278263721374, 4.905413025717191, 4.923424128264504, 4.941313689657659, 4.959083770510796, 4.976736375899144, 4.994273457400094, 5.011696915039636], [0.0, 1.0, 1.2745606273192622, 1.468900704600074, 1.6245047927124712, 1.7564650049460278, 1.8722030035247765, 1.9759880508552483, 2.070529847682755, 2.157669279974593, 2.23872113856834, 2.314661242921762, 2.3862362346415456, 2.4540317275362957, 2.518516569673431, 2.580072683370592, 2.639015821545789, 2.6956103951425203, 2.7500803110319185, 2.802617053744734, 2.853385818766556, 2.9025302401826005, 2.950176085809944, 2.9964341815788567, 3.0414027521566824, 3.0851693136000486, 3.1278122181100336, 3.1694019256486143, 3.210002058956925, 3.2496702852252937, 3.2884590578461137, 3.326416244341723, 3.3635856610148585, 3.4000075306382582, 3.435718876241175, 3.4707538615187548, 3.5051440864071934, 3.5389188448024838, 3.5721053501565505, 3.6047289336890005, 3.6368132191509885, 3.6683802774281387, 3.6994507637402645, 3.7300440397620798, 3.7601782826322077, 3.7898705825224654, 3.8191370301940277, 3.8479927957621376, 3.876452199719352, 3.904528777122723, 3.9322353357282154, 3.959584008752131, 3.986586302851177, 4.013253141837627, 4.039594906581575, 4.065621471496951, 4.091342237960261, 4.116766164969823, 4.141901797317516, 4.166757291514097, 4.191340439682053, 4.215658691606399, 4.239719175113171, 4.263528714927244, 4.287093850145173, 4.310420850444748, 4.333515731140514, 4.356384267183622, 4.379032006194582, 4.401464280608929, 4.423686219008096, 4.445702756700981, 4.467518645615555, 4.489138463554431, 4.510566622863412, 4.531807378557637, 4.552864835946026, 4.573742957791159, 4.5944455710385474, 4.614976373146364, 4.635338938044069, 4.65553672174608, 4.675573067644418, 4.695451211502379, 4.715174286169514, 4.7347453260365695, 4.754167271247631, 4.773442971685356, 4.792575190743972, 4.811566608903626, 4.830419827118651, 4.849137370031381, 4.867721689022324, 4.886175165106688, 4.904500111686591, 4.922698777167565, 4.940773347447431, 4.958725948285008, 4.97655864755565, 4.994273457400094, 5.011872336272724, 5.029357190894861], [0.0, 1.003488687151026, 1.2790071706029946, 1.4740252396143452, 1.6301721817095873, 1.7625927618400097, 1.8787345340872856, 1.982881654978848, 2.077753278558182, 2.1651967130678043, 2.2465313362391934, 2.322736371858921, 2.394561066332652, 2.4625930764923614, 2.527302886069697, 2.58907374978978, 2.64822252213377, 2.705014536492226, 2.759674480877305, 2.8123945078493793, 2.863340389209407, 2.91265626013699, 2.960468327213773, 3.006887803007026, 3.0520132548592267, 3.0959325041431445, 3.1387241764061757, 3.1804589774230614, 3.2212007518947745, 3.26100736819443, 3.2999314627078964, 3.338021069952322, 3.375320159091816, 3.4118690932237876, 3.4477050245392546, 3.482862235919809, 3.517372437543937, 3.5512650255048697, 3.5845673081937526, 3.617304705202893, 3.6495009226993216, 3.681178108567079, 3.712356990085578, 3.743056996476359, 3.7732963682923932, 3.803092255327763, 3.832460804479273, 3.861417238785953, 3.8899759287000792, 3.918150456498282, 3.9459536746187807, 3.9733977586068723, 4.00049425526239, 4.027254126507371, 4.053687789427516, 4.0798051528854975, 4.105615651056283, 4.1311282741933315, 4.156351596898629, 4.181293804138446, 4.205962715219547, 4.230365805916917, 4.254510228923347, 4.278402832773041, 4.302050179375417, 4.325458560281208, 4.348634011790513, 4.371582329001477, 4.394309078888525, 4.4168196124903885, 4.4391190762805195, 4.4612124227855645, 4.4831044205114825, 4.50479966323141, 4.526302578684443, 4.547617436730135, 4.568748356999548, 4.589699316080099, 4.610474154268318, 4.631076581921648, 4.651510185437874, 4.671778432888365, 4.691884679329192, 4.711832171812217, 4.731624054116522, 4.751263371218894, 4.770753073520661, 4.79009602084683, 4.8092949862322465, 4.828352659508414, 4.847271650703581, 4.86605449326777, 4.884703647133587, 4.903221501622858, 4.921610378208438, 4.939872533139841, 4.958010159940803, 4.976025391786249, 4.993920303765704, 5.011696915039636, 5.029357190894861, 5.046903044704656]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 0.8\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.15848931924611134, 0.20912791051825463, 0.24595094858493635, 0.27594593229224296, 0.30170881682725814, 0.3245342223199209, 0.3451749065980082, 0.36411284060521604, 0.38167789096181765, 0.39810717055349726, 0.4135776622790052, 0.4282254736676648, 0.4421578511281855, 0.4554610198563667, 0.4682054920046206, 0.48044977359257246, 0.4922430222531834, 0.5036269964912325, 0.5146375138577377, 0.5253055608807534, 0.5356581510307667, 0.5457189970961078, 0.5555090446573473, 0.5650469000989534, 0.5743491774985175, 0.5834307823739845, 0.592305145750446, 0.6009844187491662, 0.6094796355190844, 0.617800850567412, 0.6259572552252428, 0.6339572769844454, 0.6418086646779356, 0.6495185618858333, 0.6570935704911838, 0.664539805948974, 0.6718629455476419, 0.6790682707157799, 0.6861607042452014, 0.6931448431551464, 0.7000249878036359, 0.7068051677550784, 0.7134891648337663, 0.7200805337273644, 0.7265826204502338, 0.7329985789312627, 0.7393313859531326, 0.7455838546382704, 0.7517586466500457, 0.7578582832551991, 0.7638851553743226, 0.7698415327308915, 0.775729572195403, 0.7815513254092057, 0.7873087457623338, 0.7930036947907745, 0.7986379480509349, 0.804213200522412, 0.8097310715843881, 0.8151931096059227, 0.8206007961860093, 0.8259555500753956, 0.8312587308087808, 0.8365116420730188, 0.8417155348343195, 0.846871610245124, 0.851981022349263, 0.8570448806021908, 0.8620642522214543, 0.8670401643811235, 0.8719736062626094, 0.8768655309731553, 0.88171685734225, 0.8865284716052917, 0.8913012289830018, 0.8960359551643409, 0.9007334477000151, 0.9053944773130435, 0.9100197891323273, 0.9146101038546528, 0.9191661188401216, 0.9236885091455963, 0.9281779285003758, 0.9326350102279887, 0.9370603681176803, 0.9414545972489002, 0.9458182747718377, 0.9501519606468252, 0.954456198345221, 0.9587315155141828, 0.9629784246075759, 0.967197423485091, 0.9713889959815001, 0.9755536124478466, 0.97969173026623, 0.9838037943397454, 0.9878902375590144, 0.9919514812466601, 0.9959879355809818, 1.0, 1.0039880635869725], [0.0, 0.20912791051825463, 0.27594593229224296, 0.32453422231992085, 0.36411284060521604, 0.3981071705534972, 0.4282254736676648, 0.45546101985636667, 0.48044977359257246, 0.5036269964912324, 0.5253055608807534, 0.5457189970961077, 0.5650469000989534, 0.5834307823739845, 0.6009844187491661, 0.6178008505674119, 0.6339572769844454, 0.6495185618858332, 0.6645398059489739, 0.6790682707157799, 0.6931448431551464, 0.7068051677550784, 0.7200805337273642, 0.7329985789312627, 0.7455838546382703, 0.757858283255199, 0.7698415327308914, 0.7815513254092056, 0.7930036947907745, 0.804213200522412, 0.8151931096059227, 0.8259555500753955, 0.8365116420730185, 0.8468716102451239, 0.8570448806021906, 0.8670401643811234, 0.8768655309731552, 0.8865284716052917, 0.8960359551643409, 0.9053944773130433, 0.9146101038546526, 0.9236885091455962, 0.9326350102279886, 0.9414545972489002, 0.9501519606468252, 0.9587315155141827, 0.9671974234850909, 0.9755536124478463, 0.9838037943397453, 0.9919514812466601, 1.0, 1.0079525054384, 1.0158119924799414, 1.023581307132307, 1.0312631565524872, 1.0388601182540846, 1.0463746485485608, 1.0538090902966404, 1.0611656800373104, 1.0684465545542128, 1.0756537569325701, 1.0827892421539749, 1.0898548822712617, 1.096852471201222, 1.103783729168972, 1.110650306834322, 1.1174537891274203, 1.1241956988182304, 1.1308774998420013, 1.1375006004007284, 1.144066355858723, 1.150576071448682, 1.1570310048031527, 1.1634323683249144, 1.1697813314085854, 1.1760790225246736, 1.182326531176294, 1.1885249097379127, 1.1946751751846505, 1.200778310719987, 1.2068352673090326, 1.2128469651239586, 1.218814294907635, 1.2247381192610436, 1.23061927385959, 1.2364585686030394, 1.2422567887034328, 1.2480146957150107, 1.2537330285098616, 1.2594125042027418, 1.2650538190282499, 1.2706576491733155, 1.2762246515677385, 1.2817554646353284, 1.2872507090080076, 1.292710988205075, 1.2981368892796834, 1.3035289834344332, 1.308887826607858, 1.314213960033469, 1.3195079107728942, 1.3247701922245698], [0.0, 0.24595094858493635, 0.32453422231992085, 0.3816778909618177, 0.4282254736676648, 0.4682054920046206, 0.5036269964912327, 0.5356581510307667, 0.5650469000989534, 0.592305145750446, 0.617800850567412, 0.6418086646779356, 0.664539805948974, 0.6861607042452013, 0.7068051677550785, 0.7265826204502338, 0.7455838546382703, 0.7638851553743226, 0.7815513254092056, 0.7986379480509349, 0.8151931096059227, 0.8312587308087807, 0.8468716102451239, 0.8620642522214543, 0.8768655309731553, 0.8913012289830018, 0.9053944773130433, 0.9191661188401217, 0.9326350102279887, 0.9458182747718377, 0.9587315155141829, 0.9713889959815003, 0.9838037943397454, 0.9959879355809818, 1.0079525054384, 1.019707749014984, 1.0312631565524875, 1.0426275383258443, 1.0538090902966404, 1.0648154518775619, 1.0756537569325701, 1.0863306789532259, 1.0968524712012218, 1.107225002483847, 1.1174537891274203, 1.127544023629519, 1.1375006004007286, 1.1473281389480776, 1.1570310048031527, 1.1666133284564741, 1.1760790225246738, 1.1854317973472892, 1.1946751751846505, 1.2038125031666915, 1.2128469651239588, 1.2217815924161308, 1.2306192738595902, 1.2393627648436885, 1.2480146957150107, 1.256577579499974, 1.26505381902825, 1.2734457135126789, 1.2817554646353289, 1.289985182184106, 1.2981368892796838, 1.3062125272284384, 1.3142139600334692, 1.322142978592587, 1.3300013046093278, 1.3377905942405182, 1.3455124415016926, 1.3531683814496451, 1.360759893159633, 1.3682884025131314, 1.3757552848106207, 1.3831618672225918, 1.3905094310908042, 1.3977992140907904, 1.405032412265657, 1.4122101819403912, 1.4193336415251105, 1.4264038732150022, 1.433421924594071, 1.4403888101492355, 1.4473055127008105, 1.4541729847549199, 1.4609921497829734, 1.467763903432938, 1.474489114676777, 1.481168626898112, 1.4878032589238497, 1.4943938060032524, 1.5009410407376782, 1.507445713963976, 1.5139085555943308, 1.5203302754151296, 1.5267115638472708, 1.5330530926701498, 1.5393555157114145, 1.545619469504443, 1.5518455739153598, 1.558034432741296], [0.0, 0.27594593229224296, 0.36411284060521604, 0.4282254736676648, 0.48044977359257246, 0.5253055608807534, 0.5650469000989534, 0.6009844187491661, 0.6339572769844454, 0.6645398059489739, 0.6931448431551464, 0.7200805337273642, 0.7455838546382703, 0.7698415327308914, 0.7930036947907744, 0.8151931096059227, 0.8365116420730185, 0.8570448806021906, 0.8768655309731551, 0.8960359551643409, 0.9146101038546526, 0.9326350102279886, 0.9501519606468251, 0.9671974234850909, 0.9838037943397453, 1.0, 1.0158119924799411, 1.0312631565524872, 1.0463746485485608, 1.0611656800373104, 1.0756537569325701, 1.0898548822712617, 1.1037837291689718, 1.11745378912742, 1.1308774998420013, 1.144066355858723, 1.1570310048031527, 1.1697813314085856, 1.1823265311762943, 1.1946751751846505, 1.2068352673090326, 1.218814294907635, 1.23061927385959, 1.2422567887034328, 1.2537330285098613, 1.2650538190282499, 1.2762246515677385, 1.2872507090080074, 1.2981368892796834, 1.3088878266078583, 1.3195079107728942, 1.3300013046093275, 1.3403719599352584, 1.3506236320803386, 1.3607598931596327, 1.370784144222729, 1.3806996263920328, 1.3905094310908042, 1.400216509449929, 1.4098236809723264, 1.41933364152511, 1.4287489707219567, 1.438072138751391, 1.4473055127008105, 1.4564513624208644, 1.4655118659702302, 1.4744891146767767, 1.483385117847517, 1.492201807156593, 1.500941040737678, 1.5096046070047022, 1.5181942282225347, 1.5267115638472706, 1.535158213653968, 1.5435357206680773, 1.5518455739153596, 1.5600892110037952, 1.568268020549816, 1.5763833444601396, 1.5844364800795352, 1.592428682213989, 1.6003611650379599, 1.608235103893712, 1.6160516369900635, 1.6238118670073238, 1.63151686261464, 1.6391676599055114, 1.6467652637567831, 1.6543106491160209, 1.6618047622218186, 1.6692485217612372, 1.6766428199682786, 1.6839885236670116, 1.6912864752627026, 1.698537493684083, 1.705742375279642, 1.7129018946706591, 1.7200168055634837, 1.7270878415234092, 1.7341157167123347, 1.7411011265922482, 1.7480447485964477], [0.0, 0.30170881682725814, 0.3981071705534972, 0.4682054920046206, 0.5253055608807534, 0.5743491774985174, 0.617800850567412, 0.6570935704911838, 0.6931448431551464, 0.7265826204502337, 0.757858283255199, 0.7873087457623336, 0.8151931096059227, 0.8417155348343194, 0.8670401643811234, 0.8913012289830016, 0.9146101038546526, 0.9370603681176802, 0.9587315155141827, 0.9796917302662299, 0.9999999999999999, 1.019707749014984, 1.0388601182540846, 1.057496980854254, 1.0756537569325701, 1.0933620739432781, 1.110650306834322, 1.1275440236295189, 1.144066355858723, 1.1602383087230228, 1.1760790225246736, 1.1916059943773138, 1.2068352673090326, 1.2217815924161306, 1.2364585686030396, 1.2508787635704217, 1.2650538190282499, 1.2789945425690201, 1.2927109882050747, 1.3062125272284384, 1.3195079107728942, 1.332605325231926, 1.3455124415016921, 1.358236458866902, 1.370784144222729, 1.3831618672225916, 1.3953756318556398, 1.4074311048859502, 1.4193336415251103, 1.4310883086590775, 1.4426999059072136, 1.4541729847549199, 1.4655118659702304, 1.476720655488162, 1.4878032589238495, 1.4987633948559247, 1.5096046070047022, 1.5203302754151293, 1.530943626741792, 1.5414477437222491, 1.5518455739153596, 1.5621399377728824, 1.5723335361052666, 1.5824289569960974, 1.5924286822139893, 1.6023350931656943, 1.6121504764297885, 1.6218770289063553, 1.6315168626146401, 1.64107200916753, 1.6505444239489884, 1.659935990018105, 1.6692485217612372, 1.6784837683117606, 1.6876434167551813, 1.6967290951357943, 1.7057423752796417, 1.7146847754472663, 1.7235577628285792, 1.732362755891148, 1.7411011265922482, 1.7497742024641845, 1.758383268581612, 1.7669295694188853, 1.7754143106048341, 1.7838386605817729, 1.7922037521750398, 1.8005106840788656, 1.8087605222639431, 1.8169543013116636, 1.8250930256796174, 1.8331776709026233, 1.8412091847332428, 1.8491884882254452, 1.8571164767648465, 1.8649940210486826, 1.8728219680184823, 1.8806011417481825, 1.8883323442902542, 1.8960163564822323, 1.9036539387158784, 1.911245831671068], [0.0, 0.3245342223199209, 0.4282254736676648, 0.5036269964912327, 0.5650469000989534, 0.617800850567412, 0.6645398059489741, 0.7068051677550785, 0.7455838546382704, 0.7815513254092056, 0.8151931096059228, 0.846871610245124, 0.8768655309731553, 0.9053944773130433, 0.9326350102279887, 0.9587315155141828, 0.9838037943397454, 1.0079525054384002, 1.0312631565524875, 1.0538090902966404, 1.0756537569325701, 1.096852471201222, 1.1174537891274203, 1.1375006004007286, 1.157031004803153, 1.1760790225246738, 1.1946751751846505, 1.2128469651239588, 1.2306192738595902, 1.248014695715011, 1.26505381902825, 1.2817554646353289, 1.2981368892796836, 1.3142139600334692, 1.3300013046093278, 1.3455124415016924, 1.360759893159633, 1.3757552848106207, 1.3905094310908044, 1.4050324122656572, 1.4193336415251103, 1.433421924594071, 1.4473055127008105, 1.4609921497829736, 1.474489114676777, 1.4878032589238497, 1.5009410407376782, 1.5139085555943308, 1.5267115638472708, 1.5393555157114145, 1.55184557391536, 1.5641866342814787, 1.5763833444601398, 1.5884401210157693, 1.6003611650379603, 1.6121504764297887, 1.6238118670073243, 1.6353489725286132, 1.6467652637567831, 1.658064056650071, 1.6692485217612374, 1.6803216929198126, 1.6912864752627033, 1.7021456526717411, 1.7129018946706596, 1.7235577628285792, 1.734115716712335, 1.744578119425756, 1.7549472427702777, 1.7652252720579351, 1.7754143106048346, 1.7855163839305601, 1.7955334436866142, 1.805467371334883, 1.8153199815952303, 1.8250930256796176, 1.8347881943286328, 1.8444071206649326, 1.853951382876857, 1.8634225067443746, 1.8728219680184826, 1.882151194664292, 1.8914115689771838, 1.900604429580673, 1.909731073313939, 1.918792757016348, 1.9277906992157308, 1.936726081726664, 1.9456000511645284, 1.9544137203806844, 1.9631681698237125, 1.9718644488313057, 1.9805035768570676, 1.98908654463616, 1.9976143152934855, 2.0060878253977967, 2.0145079859649306, 2.0228756834131136, 2.0311917804730997, 2.0394571170557168, 2.0476725110792193, 2.055838759258699], [0.0, 0.3451749065980082, 0.45546101985636667, 0.5356581510307667, 0.6009844187491661, 0.6570935704911838, 0.7068051677550785, 0.7517586466500455, 0.7930036947907744, 0.8312587308087805, 0.8670401643811234, 0.9007334477000148, 0.9326350102279886, 0.9629784246075758, 0.99195148124666, 1.019707749014984, 1.0463746485485605, 1.072059240572028, 1.0968524712012218, 1.1208323477106126, 1.144066355858723, 1.1666133284564741, 1.1885249097379127, 1.209846717217528, 1.2306192738595902, 1.2508787635704217, 1.2706576491733155, 1.2899851821841055, 1.3088878266078583, 1.3273896137884367, 1.3455124415016924, 1.3632763276066635, 1.3806996263920328, 1.3977992140907902, 1.4145906487519724, 1.4310883086590775, 1.4473055127008103, 1.4632546254801333, 1.4789471494543087, 1.4943938060032527, 1.509604607004702, 1.524588918236018, 1.5393555157114143, 1.5539126358903128, 1.5682680205498158, 1.5824289569960974, 1.596402314191145, 1.6101945752890852, 1.623811867007324, 1.6372599861996144, 1.6505444239489884, 1.6636703874567635, 1.6766428199682788, 1.6894664189456463, 1.7021456526717407, 1.7146847754472663, 1.7270878415234094, 1.7393587178958756, 1.751501096071619, 1.7635185029069644, 1.7754143106048341, 1.787191745949194, 1.7988538988464122, 1.810403730235845, 1.8218440794254671, 1.8331776709026233, 1.8444071206649324, 1.8555349421118665, 1.866563551533588, 1.877495273230049, 1.8883323442902544, 1.8990769190587549, 1.909731073313939, 1.920296808180453, 1.9307760537960645, 1.9411706727514768, 1.951482463319982, 1.9617131624923867, 1.9718644488313057, 1.9819379451577603, 1.9919352210819108, 2.001857795388803, 2.011707138289115, 2.021484673544087, 2.0311917804730997, 2.0408297958516943, 2.0504000157072277, 2.0599036970188043, 2.06934205932763, 2.078716286263467, 2.088027526992451, 2.0972768975911458, 2.1064654823513713, 2.115594335019986, 2.124664479977549, 2.133676913359473, 2.142632604123067, 2.1515324950635972, 2.1603775037823105, 2.169168523609161, 2.1779064244827797, 2.1865920537900934], [0.0, 0.36411284060521604, 0.48044977359257246, 0.5650469000989534, 0.6339572769844454, 0.6931448431551464, 0.7455838546382704, 0.7930036947907744, 0.8365116420730185, 0.8768655309731552, 0.9146101038546527, 0.9501519606468252, 0.9838037943397453, 1.0158119924799411, 1.0463746485485605, 1.0756537569325701, 1.1037837291689718, 1.1308774998420013, 1.1570310048031527, 1.1823265311762943, 1.2068352673090326, 1.2306192738595902, 1.2537330285098616, 1.2762246515677387, 1.2981368892796836, 1.3195079107728944, 1.3403719599352584, 1.3607598931596327, 1.3806996263920328, 1.4002165094499293, 1.4193336415251103, 1.4380721387513913, 1.4564513624208641, 1.4744891146767767, 1.4922018071565932, 1.5096046070047022, 1.5267115638472706, 1.5435357206680775, 1.5600892110037952, 1.5763833444601396, 1.592428682213989, 1.608235103893712, 1.623811867007324, 1.6391676599055116, 1.6543106491160209, 1.6692485217612372, 1.6839885236670116, 1.698537493684083, 1.7129018946706591, 1.7270878415234094, 1.7411011265922485, 1.7549472427702775, 1.7686314045127423, 1.782158567006826, 1.795533443686614, 1.8087605222639431, 1.821844079425467, 1.8347881943286328, 1.8475967610139905, 1.860273499837946, 1.8728219680184823, 1.8852455693762522, 1.897547563344556, 1.9097310733139392, 1.9217990943702903, 1.9337545004792644, 1.9456000511645282, 1.957338397722581, 1.9689720890127336, 1.9805035768570673, 1.9919352210819108, 2.0032692942293835, 2.01450798596493, 2.025653407204396, 2.0367075939820687, 2.0476725110792193, 2.058550055430951, 2.06934205932763, 2.0800502934257867, 2.0906764695821063, 2.101222243523014, 2.1116892173613135, 2.1220789419704205, 2.132392919225875, 2.142632604123067, 2.152799406779391, 2.1628946943284157, 2.172919792713087, 2.1828759883844313, 2.1927645299117584, 2.2025866295099124, 2.2123434644887174, 2.222036178629389, 2.231665883492341, 2.2412336596605127, 2.2507405579220348, 2.2601876003958137, 2.26957578160334, 2.278906069489821, 2.288179406397533, 2.29739670999407, 2.306558874158028], [0.0, 0.38167789096181765, 0.5036269964912324, 0.592305145750446, 0.6645398059489739, 0.7265826204502337, 0.7815513254092056, 0.8312587308087805, 0.8768655309731552, 0.9191661188401214, 0.9587315155141827, 0.9959879355809816, 1.0312631565524872, 1.0648154518775617, 1.0968524712012218, 1.1275440236295189, 1.1570310048031525, 1.1854317973472892, 1.2128469651239586, 1.2393627648436882, 1.2650538190282499, 1.2899851821841055, 1.314213960033469, 1.337790594240518, 1.3607598931596327, 1.3831618672225916, 1.4050324122656568, 1.4264038732150022, 1.4473055127008103, 1.4677639034329377, 1.4878032589238495, 1.507445713963976, 1.5267115638472706, 1.5456194695044427, 1.5641866342814785, 1.5824289569960972, 1.60036116503796, 1.6179969305932285, 1.6353489725286128, 1.652429146032878, 1.669248521761237, 1.6858174559420311, 1.7021456526717405, 1.7182422194329807, 1.7341157167123347, 1.7497742024641847, 1.7652252720579347, 1.7804760942551208, 1.7955334436866137, 1.810403730235845, 1.8250930256796174, 1.8396070878919204, 1.8539513828768568, 1.8681311048631999, 1.882151194664292, 1.8960163564822325, 1.9097310733139388, 1.9232996210981803, 1.9367260817266636, 1.9500143550283104, 1.963168169823712, 1.9761910941361376, 1.98908654463616, 2.0018577953888035, 2.01450798596493, 2.0270401289722484, 2.0394571170557168, 2.051761729412176, 2.063956637859639, 2.076044412497747, 2.088027526992451, 2.0999083635148423, 2.111689217361314, 2.123372301279721, 2.1349597495240267, 2.146453621657883, 2.157855906125829, 2.1691685236091613, 2.180393330182081, 2.1915321202824005, 2.2025866295099124, 2.2135585372644266, 2.2244494692345453, 2.235260999747302, 2.2459946539880526, 2.25665191009921, 2.2672342011657936, 2.2777429170951358, 2.288179406397533, 2.2985449778741254, 2.3088409022178236, 2.319068413532676, 2.3292287107766794, 2.339322959132675, 2.349352291311657, 2.3593178087924884, 2.369220583001784, 2.3790616564374254, 2.388842043738954, 2.398562732707876, 2.408224685280692, 2.417828838457308], [0.0, 0.39810717055349726, 0.5253055608807534, 0.617800850567412, 0.6931448431551464, 0.757858283255199, 0.8151931096059228, 0.8670401643811234, 0.9146101038546527, 0.9587315155141827, 1.0, 1.0388601182540846, 1.0756537569325701, 1.110650306834322, 1.144066355858723, 1.1760790225246736, 1.2068352673090326, 1.2364585686030396, 1.2650538190282499, 1.292710988205075, 1.3195079107728942, 1.3455124415016924, 1.370784144222729, 1.39537563185564, 1.4193336415251103, 1.4426999059072136, 1.4655118659702304, 1.4878032589238495, 1.5096046070047022, 1.5309436267417922, 1.5518455739153598, 1.5723335361052666, 1.592428682213989, 1.6121504764297885, 1.6315168626146401, 1.6505444239489884, 1.6692485217612372, 1.6876434167551815, 1.705742375279642, 1.7235577628285792, 1.7411011265922482, 1.758383268581612, 1.7754143106048341, 1.79220375217504, 1.8087605222639431, 1.8250930256796174, 1.8412091847332428, 1.8571164767648465, 1.8728219680184823, 1.8883323442902544, 1.9036539387158786, 1.918792757016348, 1.9337545004792647, 1.9485445869183637, 1.9631681698237122, 1.9776301558892317, 1.9919352210819108, 2.0060878253977963, 2.02009222643314, 2.033952491884537, 2.0476725110792193, 2.0612560056255953, 2.0747065392644175, 2.088027526992451, 2.101222243523014, 2.1142938311411563, 2.1272453070053965, 2.140079569942774, 2.152799406779391, 2.1654074982445235, 2.17790642448278, 2.1902986702055256, 2.2025866295099124, 2.214772610391266, 2.2268588389722583, 2.2388474634702153, 2.2507405579220343, 2.2625401256845117, 2.274248102726342, 2.2858663607267022, 2.29739670999407, 2.3088409022178236, 2.320200633064136, 2.3314775446267633, 2.342673227742483, 2.3537892241801734, 2.364827028711829, 2.375788091073179, 2.3866738178209848, 2.397485574093577, 2.4082246852806923, 2.418892438608241, 2.4294900846432252, 2.440018838723644, 2.450479882317901, 2.4608743643178865, 2.471203402269648, 2.481468083545264, 2.491669466459315, 2.5018085813331057, 2.51188643150958, 2.521903994321694], [0.0, 0.4135776622790052, 0.5457189970961077, 0.6418086646779356, 0.7200805337273642, 0.7873087457623336, 0.846871610245124, 0.9007334477000148, 0.9501519606468252, 0.9959879355809816, 1.0388601182540846, 1.0792303452988907, 1.1174537891274203, 1.1538103090968392, 1.1885249097379127, 1.2217815924161306, 1.2537330285098613, 1.28450749479523, 1.314213960033469, 1.3429458900750788, 1.370784144222729, 1.3977992140907902, 1.4240529781680487, 1.4496000939184184, 1.4744891146767767, 1.4987633948559247, 1.5224618303845978, 1.5456194695044427, 1.5682680205498158, 1.5904362771173155, 1.6121504764297885, 1.6334346032531804, 1.6543106491160209, 1.674798834587229, 1.6949178008293782, 1.714684775447266, 1.7341157167123349, 1.7532254395010154, 1.772027725694012, 1.7905354213098434, 1.808760522263943, 1.8267142503346974, 1.8444071206649322, 1.8618490019199763, 1.8790491700524399, 1.8960163564822325, 1.9127587913824833, 1.9292842426635375, 1.9456000511645282, 1.9617131624923867, 1.9776301558892317, 1.9933572704590845, 2.0089004290422574, 2.024265259989368, 2.0394571170557168, 2.0544810976099313, 2.06934205932763, 2.084044635520834, 2.098593249236489, 2.11299212624236, 2.127245307005396, 2.1413566577561483, 2.1553298807227557, 2.1691685236091613, 2.1828759883844313, 2.1964555394431833, 2.2099103111910727, 2.223243315103901, 2.2364574463041613, 2.249555489694587, 2.2625401256845117, 2.2754139355414766, 2.2881794063975334, 2.3008389359369783, 2.313394836789874, 2.325849340653525, 2.338204602162149, 2.3504627025232234, 2.362625652937415, 2.3746953978175758, 2.3866738178209848, 2.398562732707876, 2.4103639040382103, 2.4220790377177024, 2.433709786403234, 2.4452577517770053, 2.4567244866980262, 2.4681114972389286, 2.479420244615436, 2.490652147015316, 2.5018085813331057, 2.512890884816468, 2.523900356629587, 2.534838259338639, 2.54570582032403, 2.556504233123725, 2.5672346587117425, 2.5778982267155697, 2.588496036576016, 2.599029158652794, 2.609498635278873, 2.6199054817664833], [0.0, 0.4282254736676648, 0.5650469000989534, 0.664539805948974, 0.7455838546382703, 0.8151931096059227, 0.8768655309731553, 0.9326350102279886, 0.9838037943397453, 1.0312631565524872, 1.0756537569325701, 1.1174537891274203, 1.1570310048031527, 1.1946751751846503, 1.23061927385959, 1.2650538190282499, 1.2981368892796834, 1.3300013046093275, 1.3607598931596327, 1.3905094310908042, 1.41933364152511, 1.4473055127008103, 1.4744891146767767, 1.5009410407376782, 1.5267115638472706, 1.5518455739153598, 1.5763833444601396, 1.60036116503796, 1.623811867007324, 1.6467652637567831, 1.6692485217612372, 1.691286475262703, 1.7129018946706591, 1.7341157167123349, 1.7549472427702775, 1.7754143106048341, 1.795533443686614, 1.8153199815952301, 1.8347881943286328, 1.853951382876857, 1.8728219680184823, 1.8914115689771835, 1.9097310733139388, 1.9277906992157308, 1.9456000511645282, 1.9631681698237122, 1.9805035768570671, 1.9976143152934853, 2.01450798596493, 2.0311917804730997, 2.0476725110792193, 2.063956637859639, 2.0800502934257867, 2.095959305469361, 2.111689217361314, 2.1272453070053965, 2.142632604123067, 2.1578559061258296, 2.172919792713087, 2.187828639317965, 2.2025866295099124, 2.2171977664509948, 2.2316658834923415, 2.245994653988053, 2.260187600395814, 2.2742481027263417, 2.2881794063975334, 2.301984629543584, 2.3156667698244604, 2.3292287107766794, 2.3426732277424835, 2.356002993410986, 2.369220583001784, 2.3823284791187205, 2.395329076299011, 2.4082246852806923, 2.4210175370093454, 2.4337097864032344, 2.4463035158943596, 2.4588007387614588, 2.471203402269648, 2.4835133906301867, 2.4957325277927658, 2.507862580081702, 2.5199052586865527, 2.531862222016803, 2.5437350779295658, 2.555525385838524, 2.567234658711743, 2.578864364965396, 2.590415930259933, 2.6018907392047406, 2.613290136976913, 2.624615430859335, 2.6358678917029326, 2.647048755317585, 2.658159223795896, 2.669200466773728, 2.680173622631135, 2.6910797996370985, 2.701920077041227, 2.7126955061153852], [0.0, 0.4421578511281855, 0.5834307823739845, 0.6861607042452013, 0.7698415327308914, 0.8417155348343194, 0.9053944773130433, 0.9629784246075758, 1.0158119924799411, 1.0648154518775617, 1.110650306834322, 1.1538103090968392, 1.1946751751846503, 1.2335441040711739, 1.2706576491733155, 1.3062125272284384, 1.3403719599352582, 1.3732730886068927, 1.4050324122656568, 1.4357498556980661, 1.4655118659702302, 1.4943938060032524, 1.5224618303845976, 1.5497743736696028, 1.5763833444601394, 1.6023350931656943, 1.6276712036091763, 1.6524291460328777, 1.6766428199682788, 1.7003430087868214, 1.723557762828579, 1.746312724321209, 1.768631404512742, 1.7905354213098432, 1.8120447040683205, 1.8331776709026233, 1.8539513828768566, 1.874381678646066, 1.8944832924846398, 1.9142699581322393, 1.9337545004792644, 1.9529489167825056, 1.9718644488313055, 1.9905116472628315, 2.008900429042257, 2.0270401289722484, 2.044939545970148, 2.062606984745952, 2.0800502934257863, 2.0972768975911458, 2.1142938311411563, 2.131107764331682, 2.1477250292995467, 2.164151643341238, 2.1803933301820804, 2.1964555394431833, 2.2123434644887174, 2.2280620588146602, 2.2436160511215957, 2.259009959197995, 2.2742481027263417, 2.2893346151121565, 2.3042734544252, 2.3190684135326762, 2.3337231294959384, 2.3482410922948396, 2.362625652937415, 2.376880031006806, 2.3910073216922774, 2.405010502346622, 2.4188924386082413, 2.4326558901225748, 2.4463035158943596, 2.459837879299312, 2.473261452781261, 2.4865766222584385, 2.4997856912605605, 2.5128908848164686, 2.525894353110387, 2.5387981749233672, 2.5516043608750762, 2.5643148564798586, 2.576931545029871, 2.5894562503170464, 2.6018907392047406, 2.6142367240590305, 2.626495865048891, 2.6386697723237544, 2.6507600080763196, 2.6627680884978924, 2.6746954856329896, 2.6865436291394644, 2.698313907959941, 2.7100076719099415, 2.72162623318771, 2.733170867810378, 2.744642816980805, 2.7560432883891246, 2.76737345745275, 2.7786344684983537, 2.7898274358890855, 2.8009534451000917], [0.0, 0.4554610198563667, 0.6009844187491661, 0.7068051677550785, 0.7930036947907744, 0.8670401643811234, 0.9326350102279887, 0.99195148124666, 1.0463746485485605, 1.0968524712012218, 1.144066355858723, 1.1885249097379127, 1.23061927385959, 1.2706576491733155, 1.308887826607858, 1.3455124415016921, 1.3806996263920328, 1.4145906487519724, 1.4473055127008103, 1.4789471494543087, 1.509604607004702, 1.5393555157114143, 1.5682680205498158, 1.5964023141911452, 1.623811867007324, 1.6505444239489884, 1.6766428199682788, 1.7021456526717405, 1.7270878415234092, 1.751501096071619, 1.7754143106048341, 1.7988538988464122, 1.821844079425467, 1.8444071206649322, 1.866563551533588, 1.8883323442902542, 1.9097310733139388, 1.9307760537960645, 1.951482463319982, 1.9718644488313057, 1.9919352210819106, 2.011707138289115, 2.0311917804730997, 2.0504000157072277, 2.06934205932763, 2.0880275269924504, 2.1064654823513713, 2.1246644799775485, 2.142632604123067, 2.160377503782311, 2.17790642448278, 2.1952262371678053, 2.2123434644887174, 2.229264304783933, 2.245994653988053, 2.2625401256845117, 2.2789060694898216, 2.2950975879354067, 2.3111195519938965, 2.326976615380111, 2.342673227742483, 2.358213646847982, 2.3736019498525045, 2.3888420437389546, 2.4039376749966648, 2.418892438608241, 2.4337097864032344, 2.4483930348321326, 2.4629453722089183, 2.477369865465766, 2.4916694664593155, 2.5058470178642427, 2.5199052586865527, 2.533846829426047, 2.5476742769147784, 2.5613900588559146, 2.5749965480852905, 2.588496036576016, 2.601890739204741, 2.6151827972966393, 2.628374281964735, 2.6414671972579113, 2.654463483130788, 2.667365018247584, 2.680173622631135, 2.6928910601673417, 2.7055190409745538, 2.7180592236466437, 2.73051321737788, 2.742882583977097, 2.7551688397781016, 2.76737345745275, 2.779497867732675, 2.7915434610451926, 2.8035115890685534, 2.815403566211316, 2.827220671020314, 2.8389641475213594, 2.850635206496557, 2.862235026701848, 2.873764756028137, 2.885225512609178], [0.0, 0.4682054920046206, 0.6178008505674119, 0.7265826204502338, 0.8151931096059227, 0.8913012289830016, 0.9587315155141828, 1.019707749014984, 1.0756537569325701, 1.1275440236295189, 1.1760790225246736, 1.2217815924161306, 1.2650538190282499, 1.3062125272284384, 1.3455124415016921, 1.3831618672225916, 1.41933364152511, 1.4541729847549199, 1.4878032589238495, 1.5203302754151293, 1.5518455739153596, 1.5824289569960974, 1.6121504764297885, 1.64107200916753, 1.6692485217612372, 1.6967290951357943, 1.723557762828579, 1.7497742024641847, 1.7754143106048341, 1.8005106840788656, 1.8250930256796174, 1.8491884882254455, 1.8728219680184823, 1.8960163564822323, 1.918792757016348, 1.9411706727514766, 1.963168169823712, 1.9848020199476342, 2.0060878253977963, 2.0270401289722484, 2.0476725110792193, 2.0679976757372027, 2.0880275269924504, 2.1077732370230735, 2.1272453070053965, 2.1464536216578836, 2.1654074982445235, 2.1841157307080663, 2.2025866295099124, 2.220828057674608, 2.2388474634702153, 2.25665191009921, 2.274248102726342, 2.291642413128693, 2.308840902217824, 2.3258493406535257, 2.342673227742483, 2.3593178087924884, 2.375788091073179, 2.39208885851719, 2.408224685280692, 2.4241999482692633, 2.4400188387236446, 2.455685372949893, 2.471203402269648, 2.4865766222584385, 2.5018085813331057, 2.5169026887433215, 2.531862222016803, 2.546690333903018, 2.5613900588559146, 2.575964319092407, 2.590415930259933, 2.6047476067433797, 2.6189619666389232, 2.6330615364198957, 2.6470487553175843, 2.6609259794378928, 2.6746954856329896, 2.688359475145493, 2.701920077041227, 2.7153793514453235, 2.728739292595198, 2.74200183172287, 2.7551688397781016, 2.7682421300029283, 2.781223460367336, 2.7941145358751043, 2.8069170107481347, 2.8196324904969803, 2.8322625338847063, 2.844808654790704, 2.857272323980591, 2.8696549707878924, 2.8819579847128143, 2.8941827169430074, 2.9063304818009352, 2.918402558122089, 2.9304001905680463, 2.942324590878079, 2.9541769390627772, 2.965958384542928], [0.0, 0.48044977359257246, 0.6339572769844454, 0.7455838546382703, 0.8365116420730185, 0.9146101038546526, 0.9838037943397454, 1.0463746485485605, 1.1037837291689718, 1.1570310048031525, 1.2068352673090326, 1.2537330285098613, 1.2981368892796834, 1.3403719599352582, 1.3806996263920328, 1.41933364152511, 1.4564513624208641, 1.492201807156593, 1.5267115638472704, 1.5600892110037952, 1.5924286822139888, 1.623811867007324, 1.6543106491160207, 1.6839885236670116, 1.7129018946706591, 1.7411011265922482, 1.768631404512742, 1.7955334436866137, 1.821844079425467, 1.8475967610139905, 1.8728219680184823, 1.8975475633445558, 1.9217990943702898, 1.945600051164528, 1.9689720890127334, 1.9919352210819106, 2.01450798596493, 2.0367075939820687, 2.058550055430951, 2.0800502934257867, 2.1012222435230137, 2.12207894197042, 2.1426326041230666, 2.1628946943284157, 2.1828759883844313, 2.202586629509912, 2.222036178629389, 2.2412336596605122, 2.2601876003958137, 2.278906069489821, 2.29739670999407, 2.31566676982446, 2.333723129495938, 2.351572327417192, 2.369220583001784, 2.3866738178209848, 2.4039376749966648, 2.4210175370093454, 2.437918542076337, 2.454645599237348, 2.4712034022696474, 2.487596442541514, 2.5038290209009713, 2.5199052586865527, 2.535829107937782, 2.551604360875076, 2.5672346587117425, 2.5827234998544872, 2.598074247543333, 2.613290136976913, 2.6283742819647355, 2.6433296811441043, 2.658159223795896, 2.6728656952902674, 2.6874517821905672, 2.701920077041227, 2.716273082863119, 2.73051321737788, 2.7446428169808055, 2.7586641404803354, 2.772579372620586, 2.786390627402075, 2.800099951214543, 2.8137093257946466, 2.8272206710203136, 2.8406358475526, 2.8539566593350654, 2.867184855959916, 2.8803221349094574, 2.8933701436807717, 2.9063304818009352, 2.919204702739574, 2.931994315725051, 2.9447007874701243, 2.9573255438125305, 2.9698699712755223, 2.982335418553081, 2.9947231979241815, 3.007034586600182, 3.0192708280091702, 3.031433133020796, 3.0435226811149385], [0.0, 0.4922430222531834, 0.6495185618858332, 0.7638851553743226, 0.8570448806021906, 0.9370603681176802, 1.0079525054384002, 1.072059240572028, 1.1308774998420013, 1.1854317973472892, 1.2364585686030396, 1.28450749479523, 1.3300013046093275, 1.3732730886068927, 1.4145906487519724, 1.4541729847549199, 1.492201807156593, 1.5288297918718776, 1.5641866342814785, 1.5983835780934676, 1.6315168626146401, 1.6636703874567635, 1.6949178008293782, 1.7253241564277866, 1.7549472427702777, 1.7838386605817733, 1.8120447040683207, 1.8396070878919204, 1.8665635515335883, 1.8929483653331025, 1.9187927570163483, 1.9441252734192735, 1.9689720890127336, 1.9933572704590845, 2.01730300460022, 2.0408297958516948, 2.063956637859639, 2.086701163393455, 2.109079775743815, 2.131107764331682, 2.152799406779391, 2.1741680593259542, 2.1952262371678057, 2.2159856860593465, 2.2364574463041613, 2.2566519100992104, 2.276578873054035, 2.296247580589782, 2.3156667698244604, 2.3348447074679504, 2.353789224180174, 2.3725077457863137, 2.3910073216922774, 2.4092946508002813, 2.427376105187276, 2.4452577517770053, 2.4629453722089187, 2.4804444810833437, 2.4977603427416475, 2.51489798672214, 2.5318622220168034, 2.5486576502402425, 2.5652886778102477, 2.5817595272288303, 2.5980742475433334, 2.614236724059031, 2.6302506873674263, 2.6461197217480508, 2.6618472729959186, 2.6774366557217126, 2.692891060167342, 2.708213558575465, 2.7234071111480196, 2.738474571625602, 2.7534186925166653, 2.7682421300029283, 2.782947448545085, 2.7975371252108125, 2.8120135537451914, 2.8263790484019777, 2.8406358475526003, 2.8547861170884006, 2.868831953630348, 2.882775387559337, 2.8966183858791332, 2.9103628549230764, 2.924010642914807, 2.9375635423924904, 2.9510232925052864, 2.9643915811901813, 2.9776700472366704, 2.9908602822462615, 3.00396383249324, 3.016982200692688, 3.0299168476813367, 3.042769194016409, 3.05554062149729, 3.068232474614505, 3.0808460619301843, 3.093382657393933, 3.1058435015977324, 3.1182298029732896], [0.0, 0.5036269964912325, 0.6645398059489739, 0.7815513254092056, 0.8768655309731551, 0.9587315155141827, 1.0312631565524875, 1.0968524712012218, 1.1570310048031527, 1.2128469651239586, 1.2650538190282499, 1.314213960033469, 1.3607598931596327, 1.4050324122656568, 1.4473055127008103, 1.4878032589238495, 1.5267115638472704, 1.5641866342814785, 1.6003611650379599, 1.6353489725286128, 1.669248521761237, 1.7021456526717407, 1.7341157167123347, 1.7652252720579347, 1.7955334436866137, 1.8250930256796174, 1.8539513828768566, 1.882151194664292, 1.9097310733139388, 1.9367260817266636, 1.9631681698237122, 1.98908654463616, 2.01450798596493, 2.0394571170557163, 2.063956637859639, 2.0880275269924504, 2.1116892173613135, 2.1349597495240267, 2.157855906125829, 2.180393330182081, 2.202586629509912, 2.2244494692345453, 2.2459946539880526, 2.2672342011657936, 2.288179406397533, 2.3088409022178236, 2.3292287107766794, 2.349352291311657, 2.369220583001784, 2.388842043738954, 2.4082246852806923, 2.427376105187276, 2.4463035158943596, 2.4650137712278997, 2.483513390630187, 2.5018085813331057, 2.5199052586865527, 2.537809064825559, 2.5555253858385236, 2.5730593675805586, 2.5904159302599328, 2.607599781911575, 2.624615430859335, 2.6414671972579122, 2.6581592237958964, 2.6746954856329896, 2.6910797996370985, 2.7073158329804405, 2.723407111148019, 2.7393570254066426, 2.7551688397781016, 2.7708456975559974, 2.7863906274020755, 2.801806549054637, 2.8170962786786697, 2.8322625338847063, 2.8473079384410434, 2.862235026701848, 2.8770462477717107, 2.8917439694255216, 2.9063304818009352, 2.920808000879288, 2.9351786717695485, 2.949444571808694, 2.963607713490865, 2.97767004723667, 2.9916334640131277, 3.00549979781396, 3.0192708280091702, 3.032948281572216, 3.046533835192445, 3.0600291172799117, 3.073435709869178, 3.086755150428221, 3.099988933578157, 3.113138512729059, 3.1262053016368223, 3.1391906758856485, 3.152095974300438, 3.1649225002930934, 3.1776715231464365, 3.1903442792392567], [0.0, 0.5146375138577377, 0.6790682707157799, 0.7986379480509349, 0.8960359551643409, 0.9796917302662299, 1.0538090902966404, 1.1208323477106126, 1.1823265311762943, 1.2393627648436882, 1.292710988205075, 1.3429458900750788, 1.3905094310908042, 1.4357498556980661, 1.4789471494543087, 1.5203302754151293, 1.5600892110037952, 1.5983835780934676, 1.6353489725286128, 1.6711016990261414, 1.705742375279642, 1.7393587178958758, 1.772027725694012, 1.8038174119733852, 1.8347881943286328, 1.8649940210486828, 1.8944832924846398, 1.9232996210981803, 1.9514824633199823, 1.9790676486116434, 2.0060878253977963, 2.032572839246619, 2.058550055430951, 2.084044635520834, 2.109079775743815, 2.133676913359473, 2.1578559061258296, 2.18163518901138, 2.2050319115710177, 2.2280620588146607, 2.2507405579220343, 2.273081372771405, 2.2950975879354067, 2.3168014835390394, 2.338204602162149, 2.3593178087924884, 2.3801513446887705, 2.400714875890612, 2.4210175370093454, 2.4410679708470604, 2.4608743643178865, 2.4804444810833437, 2.4997856912605614, 2.5189049985168874, 2.5378090648255593, 2.556504233123725, 2.5749965480852914, 2.593291775196155, 2.611395418297774, 2.6293127357462343, 2.6470487553175848, 2.6646082879759088, 2.681995940608036, 2.69921612781781, 2.71627308286312, 2.733170867810378, 2.749913382973554, 2.766504375698215, 2.7829474485450856, 2.799246066922357, 2.815403566211316, 2.8314231584256464, 2.847307938441044, 2.863060889828427, 2.878684890321034, 2.8941827169430074, 2.9095570508246347, 2.9248104817272593, 2.9399455122988867, 2.9549645620797533, 2.9698699712755223, 2.9846640043142996, 2.9993488532023798, 3.0139266406924046, 3.0283994232765576, 3.0427691940164086, 3.0570378852201396, 3.0712073709770573, 3.085279469558544, 3.0992559456939195, 3.1131385127290594, 3.1269288346750423, 3.1406285281535746, 3.1542391642454413, 3.1677622702478296, 3.1811993313459106, 3.1945517922037396, 3.2078210584791518, 3.221008498267033, 3.2341154434750554, 3.2471431911356685, 3.2600930046579224], [0.0, 0.5253055608807534, 0.6931448431551464, 0.8151931096059227, 0.9146101038546526, 0.9999999999999999, 1.0756537569325701, 1.144066355858723, 1.2068352673090326, 1.2650538190282499, 1.3195079107728942, 1.370784144222729, 1.41933364152511, 1.4655118659702302, 1.509604607004702, 1.5518455739153596, 1.5924286822139888, 1.6315168626146401, 1.669248521761237, 1.705742375279642, 1.741101126592248, 1.7754143106048341, 1.808760522263943, 1.8412091847332428, 1.8728219680184823, 1.9036539387158786, 1.9337545004792644, 1.963168169823712, 1.9919352210819106, 2.02009222643314, 2.0476725110792193, 2.0747065392644175, 2.1012222435230137, 2.127245307005396, 2.152799406779391, 2.1779064244827797, 2.202586629509912, 2.2268588389722583, 2.2507405579220343, 2.274248102726342, 2.2973967099940698, 2.320200633064136, 2.342673227742483, 2.364827028711829, 2.3866738178209848, 2.408224685280692, 2.429490084643225, 2.4504798823179006, 2.471203402269648, 2.491669466459315, 2.51188643150958, 2.531862222016803, 2.5516043608750762, 2.5711199969324823, 2.5904159302599328, 2.6094986352788734, 2.628374281964735, 2.6470487553175848, 2.6655276732693567, 2.6838164031778873, 2.7019200770412266, 2.71984360555111, 2.7375916910916533, 2.755168839778102, 2.772579372620586, 2.7898274358890855, 2.8069170107481347, 2.8238519222229437, 2.8406358475526003, 2.857272323980591, 2.8737647560281374, 2.8901164222915416, 2.9063304818009352, 2.9224099799744083, 2.9383578541984376, 2.9541769390627772, 2.969869971275522, 2.9854395942818113, 3.0008883626076543, 3.01621874594853, 3.0314331330207964, 3.0465338351924447, 3.0615230899084045, 3.076403063924378, 3.0911758563620766, 3.1058435015977324, 3.1204079719948163, 3.1348711804910927, 3.1492349830493347, 3.163501180980369, 3.177671523146437, 3.1917477080523113, 3.205731385831044, 3.219624160130739, 3.233427589908301, 3.2471431911356685, 3.260772438423691, 3.274316766568429, 3.2877775720243427, 3.3011562143085444, 3.314454017339987, 3.327672270717235], [0.0, 0.5356581510307667, 0.7068051677550784, 0.8312587308087807, 0.9326350102279886, 1.019707749014984, 1.096852471201222, 1.1666133284564741, 1.2306192738595902, 1.2899851821841055, 1.3455124415016924, 1.3977992140907902, 1.4473055127008103, 1.4943938060032524, 1.5393555157114143, 1.5824289569960974, 1.623811867007324, 1.6636703874567635, 1.7021456526717407, 1.7393587178958758, 1.7754143106048341, 1.810403730235845, 1.8444071206649322, 1.877495273230049, 1.909731073313939, 1.9411706727514768, 1.9718644488313057, 2.001857795388803, 2.0311917804730997, 2.0599036970188043, 2.088027526992451, 2.1155943350199866, 2.142632604123067, 2.1691685236091613, 2.1952262371678057, 2.220828057674608, 2.245994653988053, 2.270745214062522, 2.2950975879354067, 2.3190684135326762, 2.342673227742483, 2.3659265648049708, 2.388842043738954, 2.4114324462575323, 2.4337097864032344, 2.455685372949893, 2.477369865465766, 2.4987733248048896, 2.5199052586865527, 2.5407746629325945, 2.561390058855915, 2.5817595272288303, 2.601890739204741, 2.6217909845194343, 2.6414671972579122, 2.6609259794378928, 2.680173622631135, 2.6992161278178095, 2.7180592236466437, 2.7367083832540144, 2.7551688397781016, 2.7734456006893207, 2.791543461045193, 2.8094670157663533, 2.8272206710203145, 2.8448086547907043, 2.862235026701848, 2.8795036871615936, 2.8966183858791332, 2.9135827298090606, 2.930400190568047, 2.9470741113661467, 2.9636077134908656, 2.980004102378629, 2.9962662733051872, 3.0123971167236805, 3.0283994232765576, 3.044275888505313, 3.060029117279912, 3.0756616279679734, 3.091175856362077, 3.106574159382074, 3.121858818567898, 3.1370320433771273, 3.1520959743004386, 3.1670526858070396, 3.1819041891312456, 3.1966524349105176, 3.2112993156844785, 3.2258466682637357, 3.240296275976669, 3.2546498708017566, 3.2689091353924593, 3.2830757050011745, 3.297151169308339, 3.3111370741622848, 3.3250349232351226, 3.3388461795995137, 3.3525722672308924, 3.366214572439392, 3.379774445235429, 3.3932532006326523], [0.0, 0.5457189970961078, 0.7200805337273642, 0.8468716102451239, 0.9501519606468251, 1.0388601182540846, 1.1174537891274203, 1.1885249097379127, 1.2537330285098616, 1.314213960033469, 1.370784144222729, 1.4240529781680487, 1.4744891146767767, 1.5224618303845976, 1.5682680205498158, 1.6121504764297885, 1.6543106491160207, 1.6949178008293782, 1.7341157167123347, 1.772027725694012, 1.808760522263943, 1.8444071206649322, 1.8790491700524397, 1.9127587913824835, 1.9456000511645282, 1.9776301558892317, 2.008900429042257, 2.0394571170557163, 2.06934205932763, 2.098593249236489, 2.1272453070053965, 2.155329880722755, 2.1828759883844313, 2.2099103111910727, 2.2364574463041613, 2.2625401256845112, 2.288179406397533, 2.313394836789874, 2.338204602162149, 2.362625652937415, 2.3866738178209843, 2.4103639040382103, 2.433709786403234, 2.4567244866980262, 2.4794202446154356, 2.5018085813331057, 2.523900356629587, 2.54570582032403, 2.5672346587117425, 2.588496036576016, 2.6094986352788734, 2.630250687367426, 2.6507600080763196, 2.6710340240587205, 2.6910797996370985, 2.710904060829683, 2.73051321737788, 2.7499133829735536, 2.769110393862139, 2.788109825977632, 2.8069170107481343, 2.8255370496954426, 2.8439748279388746, 2.862235026701848, 2.880322134909458, 2.8982404599562255, 2.915994137715209, 2.9335871418525516, 2.9510232925052864, 2.9683062643746, 2.9854395942818117, 3.002426688229863, 3.0192708280091707, 3.0359751773831314, 3.0525427878854074, 3.0689766042582467, 3.0852794695585435, 3.1014541299560294, 3.1175032392458943, 3.1334293630962766, 3.1492349830493347, 3.164922500293093, 3.180494239219856, 3.1959524507857076, 3.211299315684478, 3.2265369473485004, 3.2416673947875236, 3.2566926452762988, 3.2716146269005324, 3.2864352109702026, 3.301156214308545, 3.315779401424428, 3.330306486575269, 3.344739135727128, 3.359078968418158, 3.3733275595311465, 3.3874864409804957, 3.4015571033186105, 3.415540997266336, 3.429439535171781, 3.4432540924015447, 3.4569860086681454], [0.0, 0.5555090446573473, 0.7329985789312627, 0.8620642522214543, 0.9671974234850909, 1.057496980854254, 1.1375006004007286, 1.209846717217528, 1.2762246515677387, 1.337790594240518, 1.39537563185564, 1.4496000939184184, 1.5009410407376782, 1.5497743736696028, 1.5964023141911452, 1.64107200916753, 1.6839885236670116, 1.7253241564277866, 1.7652252720579347, 1.8038174119733852, 1.8412091847332428, 1.877495273230049, 1.9127587913824835, 1.9470731539765267, 1.9805035768570673, 2.013108292783351, 2.0449395459701485, 2.076044412497747, 2.1064654823513718, 2.1362414305001933, 2.1654074982445235, 2.193995901430699, 2.222036178629389, 2.249555489694587, 2.276578873054035, 2.303129468473623, 2.3292287107766794, 2.3548964990017724, 2.3801513446887705, 2.405010502346622, 2.4294900846432252, 2.4536051644414525, 2.477369865465766, 2.5007974431052955, 2.523900356629587, 2.546690333903018, 2.5691784295255564, 2.5913750771952677, 2.613290136976913, 2.6349329380674558, 2.656312317570147, 2.677436655721712, 2.6983139079599416, 2.7189516341700988, 2.739357025406643, 2.7595369283507045, 2.779497867732675, 2.799246066922357, 2.818787466865809, 2.8381277435277394, 2.857272323980591, 2.876226401266048, 2.894994948141115, 2.9135827298090606, 2.9319943157250514, 2.950234090557073, 2.9683062643746, 2.9862148821302448, 3.00396383249324, 3.021556856087893, 3.038997553185117, 3.0562893908906035, 3.0734357098691785, 3.090439730641278, 3.107304559484232, 3.124033193968149, 3.1406285281535746, 3.1570933574757647, 3.1734303833382604, 3.1896422174365746, 3.2057313858310446, 3.221700332786342, 3.237551424393725, 3.253286951990806, 3.2689091353924593, 3.2844201259454064, 3.2998220094180644, 3.3151168087363416, 3.330306486575269, 3.3453929478156073, 3.360378041873896, 3.375263564913804, 3.390051261946053, 3.40474282882367, 3.4193399141388756, 3.4338441210274175, 3.4482570088858173, 3.4625800950065773, 3.4768148561360723, 3.490962729959545, 3.5050251165172894, 3.519003379555896], [0.0, 0.5650469000989534, 0.7455838546382703, 0.8768655309731553, 0.9838037943397453, 1.0756537569325701, 1.157031004803153, 1.2306192738595902, 1.2981368892796836, 1.3607598931596327, 1.4193336415251103, 1.4744891146767767, 1.5267115638472706, 1.5763833444601394, 1.623811867007324, 1.6692485217612372, 1.7129018946706591, 1.7549472427702777, 1.7955334436866137, 1.8347881943286328, 1.8728219680184823, 1.909731073313939, 1.9456000511645282, 1.9805035768570673, 2.01450798596493, 2.0476725110792198, 2.0800502934257867, 2.111689217361314, 2.142632604123067, 2.172919792713087, 2.2025866295099124, 2.2316658834923415, 2.2601876003958137, 2.2881794063975334, 2.3156667698244604, 2.342673227742483, 2.369220583001784, 2.395329076299011, 2.4210175370093454, 2.4463035158943596, 2.471203402269648, 2.4957325277927658, 2.5199052586865527, 2.5437350779295658, 2.567234658711743, 2.590415930259933, 2.613290136976913, 2.6358678917029326, 2.6581592237958964, 2.680173622631135, 2.701920077041227, 2.7234071111480196, 2.7446428169808055, 2.765634884224883, 2.7863906274020755, 2.8069170107481347, 2.827220671020314, 2.847307938441044, 2.8671848559599162, 2.8868571969955523, 2.9063304818009352, 2.9256099925800796, 2.9447007874701248, 2.963607713490866, 2.982335418553082, 3.000888362607654, 3.0192708280091707, 3.0374869291603694, 3.05554062149729, 3.0734357098691785, 3.091175856362077, 3.1087645876104153, 3.1262053016368228, 3.14350127425671, 3.1606556650808746, 3.177671523146437, 3.1945517922037396, 3.211299315684479, 3.2279168413741526, 3.2444070258099815, 3.2607724384236914, 3.277015565446945, 3.2931388135957866, 3.3091445135491266, 3.3250349232351226, 3.34081223093821, 3.3564785582385666, 3.3720359627948855, 3.387486440980496, 3.4028319303821566, 3.418074312170108, 3.433215413347389, 3.4482570088858173, 3.4632008237555008, 3.4780485348542904, 3.492801772843097, 3.5074621238926214, 3.5220311313466364, 3.5365102973066285, 3.550901084142287, 3.565204915932007, 3.579423179837331], [0.0, 0.5743491774985175, 0.757858283255199, 0.8913012289830018, 1.0, 1.0933620739432781, 1.1760790225246738, 1.2508787635704217, 1.3195079107728944, 1.3831618672225916, 1.4426999059072136, 1.4987633948559247, 1.5518455739153598, 1.6023350931656943, 1.6505444239489884, 1.6967290951357943, 1.7411011265922482, 1.7838386605817733, 1.8250930256796174, 1.8649940210486828, 1.9036539387158786, 1.9411706727514768, 1.9776301558892317, 2.013108292783351, 2.0476725110792198, 2.081383018504683, 2.1142938311411563, 2.1464536216578836, 2.17790642448278, 2.208692226249632, 2.2388474634702153, 2.2684054445938244, 2.29739670999407, 2.3258493406535257, 2.353789224180174, 2.3812402851268817, 2.4082246852806923, 2.4347629985576287, 2.4608743643178865, 2.486576622258439, 2.51188643150958, 2.5368193761315103, 2.5613900588559146, 2.5856121846294853, 2.6094986352788734, 2.6330615364198957, 2.656312317570147, 2.67926176628738, 2.701920077041227, 2.7242968954290983, 2.746401358265295, 2.7682421300029283, 2.789827435889086, 2.811165092203134, 2.8322625338847063, 2.853126839820663, 2.8737647560281374, 2.8941827169430074, 2.9143868649989844, 2.934383068661564, 2.9541769390627777, 2.9737738453667255, 2.993178928981856, 3.012397116723681, 3.031433133020797, 3.0502915112475484, 3.068976604258247, 3.0874925941903903, 3.105843501597733, 3.124033193968149, 3.142065393676023, 3.159943685414207, 3.1776715231464374, 3.1952522366173532, 3.212689037453924, 3.229985024889084, 3.2471431911356685, 3.2641664264363404, 3.281057523812953, 3.297819183536878, 3.3144540173399872, 3.3309645523843803, 3.3473532350074864, 3.3636224342578127, 3.379774445235429, 3.3958114922501497, 3.411735731809391, 3.427549255446754, 3.443254092401545, 3.458852212158706, 3.474345526857884, 3.4897358935797795, 3.5050251165172894, 3.5202149490384302, 3.5353070956475556, 3.550303213850889, 3.565204915932007, 3.5800137706425064, 3.594731304812731, 3.609359004887131, 3.623898318388478, 3.638350655314934], [0.0, 0.5834307823739845, 0.7698415327308914, 0.9053944773130433, 1.0158119924799411, 1.110650306834322, 1.1946751751846505, 1.2706576491733155, 1.3403719599352584, 1.4050324122656568, 1.4655118659702304, 1.5224618303845978, 1.5763833444601396, 1.6276712036091763, 1.6766428199682788, 1.723557762828579, 1.768631404512742, 1.8120447040683207, 1.8539513828768566, 1.8944832924846398, 1.9337545004792644, 1.9718644488313057, 2.008900429042257, 2.0449395459701485, 2.0800502934257867, 2.1142938311411563, 2.1477250292995467, 2.1803933301820804, 2.2123434644887174, 2.2436160511215957, 2.274248102726342, 2.3042734544252, 2.333723129495938, 2.362625652937415, 2.3910073216922774, 2.418892438608241, 2.4463035158943596, 2.4732614527812613, 2.499785691260561, 2.525894353110387, 2.5516043608750762, 2.576931545029871, 2.6018907392047406, 2.6264958650488914, 2.6507600080763196, 2.6746954856329896, 2.698313907959941, 2.72162623318771, 2.744642816980805, 2.7673734574527504, 2.789827435889086, 2.8120135537451914, 2.833940166325698, 2.855615213500923, 2.8770462477717107, 2.8982404599562255, 2.9192047027395747, 2.9399455122988862, 2.960469128191988, 2.9807815116765077, 3.000888362607654, 3.02079513504671, 3.0405070516980355, 3.060029117279912, 3.0793661309235665, 3.098522697685023, 3.1175032392458943, 3.136312003871603, 3.15495307568887, 3.17343038333826, 3.191747708052312, 3.209908691205014, 3.227916841374152, 3.2457755409542624, 3.263488052354535, 3.2810575238129527, 3.298486994855198, 3.3157794014244284, 3.332937580705738, 3.349964275667169, 3.366862139337278, 3.383633738837633, 3.400281559187132, 3.416808006893659, 3.433215413347389, 3.449506038028907, 3.465682071544308, 3.481745638498506, 3.497698800217125, 3.5135435573265874, 3.529281852201278, 3.5449155712860443, 3.560446547301666, 3.575876561340402, 3.591207344858218, 3.6064405815698106, 3.6215779092521734, 3.6366209214619913, 3.6515711691718393, 3.6664301623298146, 3.6811993713469082, 3.695880228516163], [0.0, 0.592305145750446, 0.7815513254092056, 0.9191661188401217, 1.0312631565524872, 1.1275440236295189, 1.2128469651239588, 1.2899851821841055, 1.3607598931596327, 1.4264038732150022, 1.4878032589238495, 1.5456194695044427, 1.60036116503796, 1.6524291460328777, 1.7021456526717405, 1.7497742024641847, 1.7955334436866137, 1.8396070878919204, 1.882151194664292, 1.9232996210981803, 1.963168169823712, 2.001857795388803, 2.0394571170557163, 2.076044412497747, 2.111689217361314, 2.1464536216578836, 2.1803933301820804, 2.213558537264427, 2.245994653988053, 2.2777429170951358, 2.308840902217824, 2.3393229591326756, 2.369220583001784, 2.398562732707876, 2.427376105187276, 2.4556853729498926, 2.4835133906301867, 2.510881375349739, 2.537809064825559, 2.5643148564798595, 2.5904159302599328, 2.616128357432893, 2.641467197257912, 2.6664465831415756, 2.6910797996370985, 2.7153793514453235, 2.7393570254066426, 2.763023946331916, 2.7863906274020755, 2.8094670157663533, 2.8322625338847063, 2.8547861170884006, 2.8770462477717107, 2.899050986575568, 2.9208080008792883, 2.9423245908780795, 2.9636077134908656, 2.9846640043142996, 3.00549979781396, 3.0261211459220982, 3.0465338351924447, 3.066743402646117, 3.086755150428222, 3.1065741593820744, 3.1262053016368228, 3.1456532522944034, 3.1649225002930934, 3.184017358517209, 3.2029419732157076, 3.221700332786342, 3.240296275976669, 3.2587334995483546, 3.277015565446945, 3.2951459075154066, 3.313127837786306, 3.3309645523843803, 3.348659137068486, 3.3662145724393926, 3.3836337388376334, 3.400919420953587, 3.4180743121701074, 3.4351010186563586, 3.45200206323, 3.468779889003473, 3.48543686282892, 3.5019752785551015, 3.5183973601086627, 3.5347052644111465, 3.550901084142287, 3.5669868503593403, 3.5829645349814756, 3.5988360531475982, 3.6146032654553695, 3.6302679800886244, 3.6458319548399043, 3.661296899034308, 3.6766644753604867, 3.691936301614163, 3.7071139523592183, 3.7221989605110473, 3.737192818846552, 3.7520969814448892], [0.0, 0.6009844187491662, 0.7930036947907745, 0.9326350102279887, 1.0463746485485608, 1.144066355858723, 1.2306192738595902, 1.3088878266078583, 1.3806996263920328, 1.4473055127008103, 1.5096046070047022, 1.5682680205498158, 1.623811867007324, 1.6766428199682788, 1.7270878415234092, 1.7754143106048341, 1.821844079425467, 1.8665635515335883, 1.9097310733139388, 1.9514824633199823, 1.9919352210819106, 2.0311917804730997, 2.06934205932763, 2.1064654823513718, 2.142632604123067, 2.17790642448278, 2.2123434644887174, 2.245994653988053, 2.2789060694898216, 2.3111195519938965, 2.3426732277424835, 2.373601949852505, 2.4039376749966648, 2.4337097864032344, 2.4629453722089187, 2.491669466459315, 2.5199052586865527, 2.5476742769147784, 2.574996548085291, 2.601890739204741, 2.628374281964735, 2.6544634831307885, 2.680173622631135, 2.705519040974554, 2.73051321737788, 2.7551688397781016, 2.779497867732675, 2.8035115890685534, 2.827220671020314, 2.8506352064965577, 2.8737647560281374, 2.8966183858791332, 2.9192047027395747, 2.9415318853660364, 2.9636077134908656, 2.9854395942818117, 3.0070345866001826, 3.028399423276558, 3.049540531597854, 3.070464052177591, 3.0911758563620766, 3.111681562308509, 3.1319865498563466, 3.152095974300439, 3.1720147791630984, 3.1917477080523113, 3.211299315684479, 3.2306739781422533, 3.2498759024311585, 3.2689091353924593, 3.2877775720243436, 3.3064849632585345, 3.325034923235123, 3.3434309361144856, 3.3616763624616635, 3.379774445235429, 3.397728315411437, 3.4155409972663366, 3.4332154133473893, 3.4507543891501022, 3.468160657524494, 3.48543686282892, 3.502585564848846, 3.519609242496573, 3.5365102973066285, 3.553291056740414, 3.569953777312618, 3.5865006475509777, 3.60293379080006, 3.6192552678789776, 3.6354670796021824, 3.6515711691718393, 3.6675694244496566, 3.6834636801154765, 3.699255719719444, 3.7149472776340495, 3.7305400409119547, 3.74603565105506, 3.7614357056999306, 3.7767417602243545, 3.7919553292794634, 3.8070778882515897], [0.0, 0.6094796355190844, 0.804213200522412, 0.9458182747718377, 1.0611656800373104, 1.1602383087230228, 1.248014695715011, 1.3273896137884367, 1.4002165094499293, 1.4677639034329377, 1.5309436267417922, 1.5904362771173155, 1.6467652637567831, 1.7003430087868214, 1.751501096071619, 1.8005106840788656, 1.8475967610139905, 1.8929483653331025, 1.9367260817266636, 1.9790676486116434, 2.02009222643314, 2.0599036970188043, 2.098593249236489, 2.1362414305001933, 2.172919792713087, 2.208692226249632, 2.2436160511215957, 2.2777429170951358, 2.3111195519938965, 2.343788388261312, 2.375788091073179, 2.4071540062127434, 2.4379185420763374, 2.4681114972389286, 2.4977603427416475, 2.5268904664989065, 2.555525385838524, 2.5836869330940875, 2.611395418297774, 2.638669772323755, 2.6655276732693567, 2.69198565840442, 2.7180592236466437, 2.7437629122151037, 2.7691103938621393, 2.7941145358751043, 2.818787466865809, 2.843140634220313, 2.8671848559599162, 2.8909303676615528, 2.914386864998985, 2.9375635423924904, 2.9604691281919884, 2.983111916764887, 3.0054997978139606, 3.0276402832109963, 3.049540531597854, 3.0712073709770573, 3.0926473194884525, 3.1138666045462187, 3.1348711804910927, 3.1556667448957487, 3.1762587536463798, 3.196652434910518, 3.2168528020896483, 3.23686466584504, 3.2566926452762988, 3.276341178324205, 3.2958145314624194, 3.3151168087363416, 3.3342519602019167, 3.353223789812172, 3.3720359627948855, 3.390692012560791, 3.4091953471782057, 3.4275492554467535, 3.445756912600004, 3.4638213856642768, 3.481745638498506, 3.4995325365379992, 3.517184851262983, 3.5347052644111465, 3.552096371951811, 3.569360687837946, 3.5865006475509777, 3.6035186114521442, 3.6204168679531037, 3.6371976365175316, 3.6538630705045376, 3.670415259863949, 3.686856233692734, 3.703187962661198, 3.7194123613169228, 3.735531290273872, 3.7515465582935676, 3.7674599242647275, 3.7832730990873507, 3.798987747466791, 3.81460548962301, 3.830127902919843, 3.845556523418775, 3.860892847361466], [0.0, 0.617800850567412, 0.8151931096059227, 0.9587315155141829, 1.0756537569325701, 1.1760790225246736, 1.26505381902825, 1.3455124415016924, 1.4193336415251103, 1.4878032589238495, 1.5518455739153598, 1.6121504764297885, 1.6692485217612372, 1.723557762828579, 1.7754143106048341, 1.8250930256796174, 1.8728219680184823, 1.9187927570163483, 1.9631681698237122, 2.0060878253977963, 2.0476725110792193, 2.088027526992451, 2.1272453070053965, 2.1654074982445235, 2.2025866295099124, 2.2388474634702153, 2.274248102726342, 2.308840902217824, 2.3426732277424835, 2.375788091073179, 2.4082246852806923, 2.4400188387236446, 2.471203402269648, 2.5018085813331057, 2.5318622220168034, 2.5613900588559146, 2.590415930259933, 2.6189619666389232, 2.6470487553175848, 2.67469548563299, 2.701920077041227, 2.7287392925951983, 2.7551688397781016, 2.7812234603673365, 2.8069170107481347, 2.8322625338847063, 2.857272323980591, 2.8819579847128143, 2.9063304818009352, 2.930400190568047, 2.9541769390627777, 2.9776700472366704, 3.0008883626076543, 3.0238402927859958, 3.046533835192445, 3.068976604258247, 3.091175856362077, 3.1131385127290594, 3.1348711804910927, 3.1563801720851354, 3.177671523146437, 3.1987510090365343, 3.21962416013074, 3.2402962759766694, 3.260772438423692, 3.2810575238129527, 3.3011562143085453, 3.3210730084423803, 3.34081223093821, 3.360378041873896, 3.3797744452354292, 3.3990052969111435, 3.418074312170108, 3.436985072664654, 3.455741032993396, 3.474345526857884, 3.4928017728430967, 3.5111128798494113, 3.5292818522012785, 3.5473115944557443, 3.565204915932007, 3.5829645349814756, 3.600593083016195, 3.6180931083120935, 3.635467079602182, 3.6527173894736706, 3.6698463575818634, 3.686856233692734, 3.703749200565169, 3.720527376683043, 3.7371928188465526, 3.75374752463153, 3.770193434724842, 3.7865324351433833, 3.8027663593436665, 3.818896990228487, 3.8349260620567316, 3.8508552622619483, 3.866686233184934, 3.8824205737252457, 3.8980598409161895, 3.913605551427587], [0.0, 0.6259572552252428, 0.8259555500753955, 0.9713889959815003, 1.0898548822712617, 1.1916059943773138, 1.2817554646353289, 1.3632763276066635, 1.4380721387513913, 1.507445713963976, 1.5723335361052666, 1.6334346032531804, 1.691286475262703, 1.746312724321209, 1.7988538988464122, 1.8491884882254455, 1.8975475633445558, 1.9441252734192735, 1.98908654463616, 2.032572839246619, 2.0747065392644175, 2.1155943350199866, 2.155329880722755, 2.193995901430699, 2.2316658834923415, 2.2684054445938244, 2.3042734544252, 2.3393229591326756, 2.373601949852505, 2.4071540062127434, 2.4400188387236446, 2.4722327487612916, 2.5038290209009713, 2.5348382593386396, 2.5652886778102477, 2.595206350606543, 2.6246154308593352, 2.6535383411514486, 2.681995940608036, 2.7100076719099424, 2.7375916910916533, 2.7647649825172627, 2.791543461045193, 2.8179420630785077, 2.8439748279388746, 2.869654970787893, 2.8949949481411146, 2.9200065168710254, 2.9447007874701248, 2.9690882722398433, 2.993178928981856, 3.0169822006926883, 3.0405070516980355, 3.063762000608127, 3.086755150428222, 3.1094942161177253, 3.1319865498563466, 3.1542391642454417, 3.1762587536463798, 3.1980517138349325, 3.21962416013074, 3.2409819441435097, 3.2621306692623415, 3.2830757050011754, 3.3038222003015822, 3.3243750958837257, 3.3447391357271283, 3.36491887775476, 3.38491870378676, 3.4047428288236707, 3.4243953097133875, 3.443880053250917, 3.463200823755501, 3.482361250165591, 3.5013648326885196, 3.5202149490384302, 3.538914860293093, 3.5574677163975825, 3.575876561340403, 3.5941443380254925, 3.612273892861582, 3.6302679800886244, 3.6481292658594113, 3.665860332093023, 3.683463680115477, 3.700941734101684, 3.718296844331781, 3.7355312902738724, 3.752647283504326, 3.7696469704759195, 3.786532435143384, 3.8033057014551868, 3.819968735719766, 3.8365234488538134, 3.852971698519723, 3.8693152911587427, 3.885555983926001, 3.901695486533084, 3.9177354630034977, 3.9336775333459824, 3.9495232751502978, 3.965274225109825], [0.0, 0.6339572769844454, 0.8365116420730185, 0.9838037943397454, 1.1037837291689718, 1.2068352673090326, 1.2981368892796836, 1.3806996263920328, 1.4564513624208641, 1.5267115638472706, 1.592428682213989, 1.6543106491160209, 1.7129018946706591, 1.768631404512742, 1.821844079425467, 1.8728219680184823, 1.9217990943702898, 1.9689720890127336, 2.01450798596493, 2.058550055430951, 2.1012222435230137, 2.142632604123067, 2.1828759883844313, 2.222036178629389, 2.2601876003958137, 2.29739670999407, 2.333723129495938, 2.369220583001784, 2.4039376749966648, 2.4379185420763374, 2.471203402269648, 2.5038290209009713, 2.5358291079377815, 2.5672346587117425, 2.5980742475433334, 2.628374281964735, 2.658159223795896, 2.6874517821905677, 2.7162730828631196, 2.7446428169808055, 2.7725793726205854, 2.8000999512145435, 2.8272206710203136, 2.8539566593350654, 2.8803221349094574, 2.9063304818009352, 2.931994315725051, 2.9573255438125305, 2.9823354185530815, 3.0070345866001826, 3.0314331330207964, 3.05554062149729, 3.079366130923566, 3.102918288781612, 3.1262053016368228, 3.149234983049335, 3.172014779163098, 3.1945517922037396, 3.216852802089648, 3.2389242863375522, 3.260772438423691, 3.2824031847440374, 3.3038222003015822, 3.325034923235123, 3.346046568292075, 3.366862139337278, 3.387486440980496, 3.407924089397052, 3.428179522408763, 3.4482570088858173, 3.468160657524494, 3.487894425050438, 3.5074621238926214, 3.526867429369, 3.5461138864211668, 3.565204915932007, 3.5841438206573635, 3.6029337908000603, 3.621577909252174, 3.640079156529309, 3.658440415418611, 3.6766644753604862, 3.694754036582385, 3.7127117140015033, 3.7305400409119547, 3.7482414724707214, 3.765818388995601, 3.7832730990873507, 3.8006078425873007, 3.817824793380884, 3.834926062056731, 3.8519136984303035, 3.868789693940364, 3.8855559839260003, 3.902214449791386, 3.91876692106492, 3.9352151773589816, 3.9515609502360576, 3.9678059249866404, 3.983951742323927, 4.0, 4.01595225434789], [0.0, 0.6418086646779356, 0.8468716102451239, 0.9959879355809818, 1.11745378912742, 1.2217815924161306, 1.3142139600334692, 1.3977992140907902, 1.4744891146767767, 1.5456194695044427, 1.6121504764297885, 1.674798834587229, 1.7341157167123349, 1.7905354213098432, 1.8444071206649322, 1.8960163564822323, 1.945600051164528, 1.9933572704590845, 2.0394571170557163, 2.084044635520834, 2.127245307005396, 2.1691685236091613, 2.2099103111910727, 2.249555489694587, 2.2881794063975334, 2.3258493406535257, 2.362625652937415, 2.398562732707876, 2.4337097864032344, 2.4681114972389286, 2.5018085813331057, 2.5348382593386396, 2.5672346587117425, 2.599029158652794, 2.630250687367426, 2.6609259794378923, 2.6910797996370985, 2.720735138365462, 2.7499133829735536, 2.778634468498354, 2.8069170107481343, 2.8347784241900147, 2.862235026701848, 2.889302132928245, 2.915994137715209, 2.9423245908780795, 2.9683062643745997, 2.9939512128020573, 3.0192708280091702, 3.044275888505313, 3.068976604258247, 3.093382657393933, 3.1175032392458943, 3.1413470841451256, 3.1649225002930934, 3.188237398018742, 3.2112993156844785, 3.2341154434750554, 3.2566926452762983, 3.2790374788272114, 3.301156214308545, 3.3230548515130662, 3.3447391357271283, 3.3662145724393926, 3.387486440980496, 3.4085598071867778, 3.4294395351717815, 3.4501302982808997, 3.470636589297161, 3.490962729959545, 3.5111128798494113, 3.53109104469537, 3.550901084142287, 3.5705467190259257, 3.590031538191012, 3.609359004887131, 3.6285324627738555, 3.647555141563799, 3.666430162329815, 3.68516054250038, 3.7037492005651687, 3.722198960511047, 3.740512556007044, 3.75869263435539, 3.7767417602243545, 3.794662419177369, 3.812457021011816, 3.830127902919843, 3.847677332482603, 3.8651075105085053, 3.8824205737252457, 3.8996185973346886, 3.9167035974390227, 3.933677533345982, 3.950542309760416, 3.9672997788689335, 3.983951742323927, 4.000499953132811, 4.016946117457942, 4.033291896332299, 4.049538907295691, 4.065688725955906], [0.0, 0.6495185618858333, 0.8570448806021906, 1.0079525054384, 1.1308774998420013, 1.2364585686030396, 1.3300013046093278, 1.4145906487519724, 1.4922018071565932, 1.5641866342814785, 1.6315168626146401, 1.6949178008293782, 1.7549472427702775, 1.8120447040683205, 1.866563551533588, 1.918792757016348, 1.9689720890127334, 2.01730300460022, 2.063956637859639, 2.109079775743815, 2.152799406779391, 2.1952262371678057, 2.2364574463041613, 2.276578873054035, 2.3156667698244604, 2.353789224180174, 2.3910073216922774, 2.427376105187276, 2.4629453722089187, 2.4977603427416475, 2.5318622220168034, 2.5652886778102477, 2.5980742475433334, 2.630250687367426, 2.6618472729959186, 2.692891060167342, 2.7234071111480196, 2.7534186925166653, 2.7829474485450856, 2.8120135537451914, 2.8406358475526003, 2.8688319536303477, 2.8966183858791332, 2.924010642914807, 2.9510232925052864, 2.9776700472366704, 3.00396383249324, 3.0299168476813367, 3.05554062149729, 3.0808460619301843, 3.105843501597733, 3.1305427389350076, 3.1549530756888706, 3.1790833511137886, 3.202941973215708, 3.226536947348501, 3.2498759024311585, 3.2729661150224385, 3.2958145314624194, 3.318427788266689, 3.34081223093821, 3.362973931343856, 3.3849187037867603, 3.4066521198917292, 3.4281795224087634, 3.449506038028907, 3.4706365892971616, 3.491575905698723, 3.5123285339873704, 3.532898847818122, 3.5532910567404143, 3.5735092146027374, 3.593557227414967, 3.613438860710395, 3.633157746445699, 3.652717389473671, 3.672121173620482, 3.691372367396528, 3.7104741293673795, 3.7294295132091744, 3.748241472470722, 3.766912865062779, 3.785446457493301, 3.8038449288659413, 3.8221108746577284, 3.8402468102905845, 3.8582551745102247, 3.8761383325849375, 3.893898579335798, 3.9115381420090123, 3.9290591830002843, 3.9464638024403933, 3.963754040650491, 3.9809318804750173, 3.9979992494995944, 4.014958022160715, 4.0318100217536, 4.0485570223441325, 4.065200750590396, 4.081742887478972, 4.0981850699807945, 4.114528892631059], [0.0, 0.6570935704911838, 0.8670401643811234, 1.019707749014984, 1.144066355858723, 1.2508787635704217, 1.3455124415016924, 1.4310883086590775, 1.5096046070047022, 1.5824289569960972, 1.6505444239489884, 1.714684775447266, 1.7754143106048341, 1.8331776709026233, 1.8883323442902542, 1.9411706727514766, 1.9919352210819106, 2.0408297958516948, 2.0880275269924504, 2.133676913359473, 2.1779064244827797, 2.220828057674608, 2.2625401256845112, 2.303129468473623, 2.342673227742483, 2.3812402851268817, 2.418892438608241, 2.4556853729498926, 2.491669466459315, 2.5268904664989065, 2.5613900588559146, 2.595206350606543, 2.628374281964735, 2.6609259794378923, 2.692891060167342, 2.724296895429098, 2.7551688397781016, 2.7855304311394837, 2.8154035662113155, 2.8448086547907043, 2.873764756028137, 2.9022896991225764, 2.9304001905680463, 2.958111909732967, 2.9854395942818113, 3.0123971167236805, 3.0389975531851166, 3.0652532453480084, 3.0911758563620766, 3.1167764214308007, 3.1420653936760226, 3.1670526858070396, 3.191747708052312, 3.2161594027540903, 3.240296275976669, 3.26416642643634, 3.287777572024343, 3.3111370741622843, 3.3342519602019163, 3.3571289440571723, 3.3797744452354284, 3.402194606416691, 3.424395309713387, 3.4463821917293855, 3.468160657524494, 3.4897358935797795, 3.511112879849411, 3.5322964009761946, 3.553291056740414, 3.5741012718048273, 3.5947313048127314, 3.6151852568906144, 3.635467079602182, 3.6555805823962495, 3.675529439587179, 3.6953171969031002, 3.7149472776340486, 3.7344229884094142, 3.75374752463153, 3.7729239755900252, 3.791955329279464, 3.8108444769409804, 3.8295942173469224, 3.848207260845983, 3.866686233184934, 3.8850336791218005, 3.9032520658441636, 3.9213437862052465, 3.9393111617894703, 3.9571564458182933, 3.9748818259063543, 3.992489426677203, 4.009981312247231, 4.027359488585796, 4.044625905758985, 4.061782460063899, 4.078830996059936, 4.095773308503018, 4.1126111441883735, 4.129346203707087, 4.14598014312126, 4.162514575562353], [0.0, 0.664539805948974, 0.8768655309731552, 1.0312631565524875, 1.1570310048031527, 1.2650538190282499, 1.360759893159633, 1.4473055127008103, 1.5267115638472706, 1.60036116503796, 1.6692485217612372, 1.7341157167123349, 1.795533443686614, 1.8539513828768566, 1.9097310733139388, 1.963168169823712, 2.01450798596493, 2.063956637859639, 2.1116892173613135, 2.1578559061258296, 2.202586629509912, 2.245994653988053, 2.288179406397533, 2.3292287107766794, 2.369220583001784, 2.4082246852806923, 2.4463035158943596, 2.4835133906301867, 2.5199052586865527, 2.555525385838524, 2.590415930259933, 2.6246154308593352, 2.658159223795896, 2.6910797996370985, 2.7234071111480196, 2.7551688397781016, 2.7863906274020755, 2.81709627867867, 2.847307938441044, 2.8770462477717107, 2.9063304818009352, 2.9351786717695485, 2.963607713490865, 2.991633464013128, 3.0192708280091702, 3.046533835192445, 3.073435709869178, 3.0999889335781567, 3.1262053016368228, 3.1520959743004386, 3.177671523146437, 3.2029419732157076, 3.227916841374152, 3.252605171299339, 3.277015565446945, 3.301156214308545, 3.3250349232351226, 3.3486591370684864, 3.372035962794885, 3.395172190410848, 3.4180743121701074, 3.4407485403619975, 3.463200823755501, 3.4854368628289203, 3.507462123892622, 3.529281852201278, 3.5509010841422874, 3.5723246585783994, 3.5935572274149665, 3.6146032654553695, 3.6354670796021824, 3.656152817456177, 3.676664475360487, 3.697005905932897, 3.717180825125387, 3.737192818846552, 3.757045349179418, 3.776741760224355, 3.7962852835942447, 3.8156790435867864, 3.834926062056731, 3.854029263008983, 3.8729914769317957, 3.8918154448877433, 3.910503822378766, 3.929059183000284, 3.947484021898239, 3.9657807590418552, 3.983951742323927, 4.001999250499595, 4.019925495973716, 4.03773262744624, 4.055422732424287, 4.072997839609013, 4.090459921164807, 4.1078108948777565, 4.12505262620995, 4.1421869302556225, 4.159215573604822, 4.176140276119865, 4.192962712629476, 4.209684514545247], [0.0, 0.6718629455476419, 0.8865284716052917, 1.0426275383258443, 1.1697813314085856, 1.2789945425690201, 1.3757552848106207, 1.4632546254801333, 1.5435357206680775, 1.6179969305932285, 1.6876434167551815, 1.7532254395010154, 1.8153199815952301, 1.874381678646066, 1.9307760537960645, 1.9848020199476342, 2.0367075939820687, 2.086701163393455, 2.1349597495240267, 2.18163518901138, 2.2268588389722583, 2.270745214062522, 2.313394836789874, 2.3548964990017724, 2.395329076299011, 2.4347629985576287, 2.4732614527812613, 2.510881375349739, 2.5476742769147784, 2.5836869330940875, 2.6189619666389232, 2.6535383411514486, 2.6874517821905677, 2.720735138365462, 2.7534186925166653, 2.7855304311394837, 2.81709627867867, 2.8481403021171032, 2.878684890321034, 2.90875091183494, 2.9383578541984376, 2.967523947354216, 2.9962662733051872, 3.024600863842141, 3.0525427878854074, 3.080106229754002, 3.107304559484232, 3.1341503961597703, 3.1606556650808746, 3.186831649487327, 3.212689037453924, 3.2382379644961645, 3.2634880523545355, 3.288448444366721, 3.3131278377863063, 3.3375345133629852, 3.361676362461664, 3.385560911965309, 3.4091953471782057, 3.4325865329217353, 3.4557410329933957, 3.478665128141117, 3.5013648326885196, 3.5238459099324118, 3.5461138864211676, 3.5681740652114637, 3.5900315381910124, 3.6116911975461825, 3.633157746445699, 3.654435709004677, 3.6755294395871796, 3.6964431314999837, 3.7171808251253875, 3.7377464155365083, 3.7581436596346185, 3.7783761828445455, 3.7984474854010055, 3.818360948255907, 3.838119838634073, 3.8577273152625438, 3.8771864332965054, 3.896500148963004, 3.9156713239418934, 3.934702729501892, 3.9535970504082134, 3.9723568886169556, 3.9909847667702345, 4.00948313150501, 4.02785435658754, 4.046100745884543, 4.064224536181279, 4.082227899856084, 4.100112947420127, 4.1178817299305805, 4.135536241284817, 4.153078420402673, 4.170510153303377, 4.187833275083261, 4.205049571799958, 4.2221607822684355, 4.239168599773808, 4.256074673705603], [0.0, 0.6790682707157799, 0.8960359551643409, 1.0538090902966404, 1.1823265311762943, 1.2927109882050747, 1.3905094310908044, 1.4789471494543087, 1.5600892110037952, 1.6353489725286128, 1.705742375279642, 1.772027725694012, 1.8347881943286328, 1.8944832924846398, 1.951482463319982, 2.0060878253977963, 2.058550055430951, 2.109079775743815, 2.157855906125829, 2.2050319115710177, 2.2507405579220343, 2.2950975879354067, 2.338204602162149, 2.3801513446887705, 2.4210175370093454, 2.4608743643178865, 2.499785691260561, 2.537809064825559, 2.574996548085291, 2.611395418297774, 2.6470487553175848, 2.681995940608036, 2.7162730828631196, 2.7499133829735536, 2.7829474485450856, 2.8154035662113155, 2.847307938441044, 2.878684890321034, 2.9095570508246347, 2.9399455122988862, 2.969869971275522, 2.9993488532023793, 3.0283994232765576, 3.0570378852201396, 3.085279469558544, 3.113138512729059, 3.1406285281535746, 3.167762270247829, 3.1945517922037396, 3.2210084982670333, 3.2471431911356685, 3.2729661150224385, 3.2984869948551983, 3.3237150720284183, 3.3486591370684864, 3.3733275595311465, 3.3977283154114373, 3.4218690123136084, 3.4457569126000043, 3.4693989547130766, 3.4928017728430962, 3.5159717150952297, 3.5389148602930933, 3.5616370335413796, 3.5841438206573644, 3.60644058156981, 3.628532462773856, 3.6504244089216216, 3.672121173620482, 3.6936273295039603, 3.7149472776340495, 3.7360852562882143, 3.7570453491794185, 3.7778314931530907, 3.7984474854010055, 3.8188969902284864, 3.839183545408157, 3.8593105681505984, 3.87928136071965, 3.899099115717796, 3.91876692106492, 3.9382877646918217, 3.957664538968148, 3.9769000448828025, 3.9959969959934885, 4.014958022160714, 4.033785673080413, 4.05248242162825, 4.071050667027698, 4.089492737853054, 4.1078108948777565, 4.126007333777586, 4.144084187697673, 4.162043529691542, 4.179887375039914, 4.197617683456371, 4.2152363611865615, 4.23274526300712, 4.25014619413007, 4.267440912018123, 4.284631128115855, 4.3017185095015025], [0.0, 0.6861607042452014, 0.9053944773130433, 1.0648154518775619, 1.1946751751846505, 1.3062125272284384, 1.4050324122656572, 1.4943938060032527, 1.5763833444601396, 1.652429146032878, 1.7235577628285792, 1.7905354213098434, 1.853951382876857, 1.9142699581322393, 1.9718644488313057, 2.0270401289722484, 2.0800502934257867, 2.131107764331682, 2.180393330182081, 2.2280620588146607, 2.274248102726342, 2.3190684135326762, 2.362625652937415, 2.405010502346622, 2.4463035158943596, 2.486576622258439, 2.525894353110387, 2.5643148564798595, 2.601890739204741, 2.638669772323755, 2.67469548563299, 2.7100076719099424, 2.7446428169808055, 2.778634468498354, 2.8120135537451914, 2.8448086547907043, 2.8770462477717107, 2.90875091183494, 2.9399455122988862, 2.970651361806657, 3.0008883626076543, 3.0306751325917283, 3.060029117279912, 3.0889666896317975, 3.1175032392458943, 3.145653252294404, 3.17343038333826, 3.200847520004912, 3.227916841374152, 3.2546498708017575, 3.281057523812953, 3.3071501516147785, 3.332937580705738, 3.358429149000753, 3.383633738837634, 3.4085598071867786, 3.4332154133473893, 3.457608244380275, 3.481745638498506, 3.5056346066121264, 3.529281852201278, 3.5526937896730244, 3.575876561340403, 3.5988360531475996, 3.6215779092521743, 3.644107545563917, 3.6664301623298154, 3.688550755845715, 3.7104741293673795, 3.7322049032865614, 3.7537475246315304, 3.7751062759458476, 3.796285283594245, 3.8172885255399827, 3.8381198386340727, 3.8587829254531636, 3.8792813607196495, 3.8996185973346895, 3.919797972052155, 3.9398227108192208, 3.959695933807118, 3.9794206601536706, 3.9989998124374755, 4.018436220901973, 4.037732627446241, 4.056891689397997, 4.075915983083116, 4.094808007204869, 4.113570186045081, 4.132204872498518, 4.150714350950949, 4.169100840010586, 4.187366495101893, 4.205513410930112, 4.223543623824281, 4.241459113965939, 4.2592618075102475, 4.276953578605797, 4.294536251318896, 4.312011601467829, 4.329381358372115, 4.346647206521556], [0.0, 0.6931448431551464, 0.9146101038546526, 1.0756537569325701, 1.2068352673090326, 1.3195079107728942, 1.4193336415251103, 1.509604607004702, 1.592428682213989, 1.669248521761237, 1.7411011265922482, 1.808760522263943, 1.8728219680184823, 1.9337545004792644, 1.9919352210819106, 2.0476725110792193, 2.1012222435230137, 2.152799406779391, 2.202586629509912, 2.2507405579220343, 2.2973967099940698, 2.342673227742483, 2.3866738178209843, 2.4294900846432252, 2.471203402269648, 2.51188643150958, 2.5516043608750762, 2.5904159302599328, 2.628374281964735, 2.6655276732693567, 2.701920077041227, 2.7375916910916533, 2.7725793726205854, 2.8069170107481343, 2.8406358475526003, 2.873764756028137, 2.9063304818009352, 2.9383578541984376, 2.969869971275522, 3.0008883626076543, 3.031433133020796, 3.0615230899084045, 3.0911758563620766, 3.120407971994817, 3.1492349830493347, 3.177671523146437, 3.205731385831044, 3.233427589908301, 3.260772438423691, 3.287777572024343, 3.314454017339987, 3.3408122309382096, 3.366862139337278, 3.39261317549879, 3.4180743121701074, 3.443254092401545, 3.468160657524494, 3.4928017728430967, 3.5171848512629826, 3.541316975055278, 3.5652049159320067, 3.5888551535897615, 3.6122738928615816, 3.6354670796021824, 3.658440415418611, 3.681199371346908, 3.7037492005651687, 3.7260949502244176, 3.7482414724707214, 3.770193434724842, 3.791955329279464, 3.8135314822683437, 3.834926062056731, 3.8561430870978874, 3.877186433296505, 3.8980598409161895, 3.918766921064919, 3.9393111617894703, 3.9596959338071174, 3.9799244959005837, 4.0, 4.019925495973715, 4.0397039361480145, 4.059338179574186, 4.078830996059936, 4.098185069980794, 4.117403003885964, 4.136487321911958, 4.155440473016339, 4.17426483404299, 4.192962712629476, 4.211536349966279, 4.229987923417016, 4.248319549008046, 4.266533283795337, 4.284631128115855, 4.302615027730281, 4.3204868758633665, 4.33824851514782, 4.355901739477225, 4.3734482957731124, 4.390889885670992], [0.0, 0.7000249878036359, 0.9236885091455962, 1.0863306789532259, 1.218814294907635, 1.332605325231926, 1.433421924594071, 1.524588918236018, 1.608235103893712, 1.6858174559420311, 1.758383268581612, 1.8267142503346974, 1.8914115689771835, 1.9529489167825056, 2.011707138289115, 2.0679976757372027, 2.12207894197042, 2.1741680593259542, 2.2244494692345453, 2.273081372771405, 2.320200633064136, 2.3659265648049708, 2.4103639040382103, 2.4536051644414525, 2.4957325277927658, 2.5368193761315103, 2.576931545029871, 2.616128357432893, 2.6544634831307885, 2.69198565840442, 2.7287392925951983, 2.7647649825172627, 2.8000999512145435, 2.8347784241900147, 2.8688319536303477, 2.9022896991225764, 2.9351786717695485, 2.967523947354216, 2.9993488532023793, 3.0306751325917283, 3.0615230899084045, 3.091911719227754, 3.121858818567898, 3.1513810917137763, 3.180494239219856, 3.2092130399600296, 3.237551424393725, 3.2655225405505384, 3.293138813595786, 3.320411999721476, 3.3473532350074864, 3.3739730798131293, 3.400281559187132, 3.4262881997225194, 3.4520020632300006, 3.4774317775580705, 3.502585564848846, 3.5274712674847555, 3.5520963719518104, 3.5764680308196466, 3.600593083016195, 3.624478072555412, 3.6481292658594113, 3.671552667801366, 3.6947540365823857, 3.7177388975439256, 3.740512556007044, 3.7630801092207053, 3.785446457493301, 3.8076163145743367, 3.829594217346923, 3.8513845348859506, 3.872991476931796, 3.8944191018248233, 3.9156713239418934, 3.9367519206724086, 3.9576645389681477, 3.978412701498183, 3.9989998124374755, 4.019429162915373, 4.039703936148015, 4.059827212276695, 4.079801972932441, 4.0996311055454395, 4.119317407416463, 4.13886358956611, 4.158272280376448, 4.177546029038525, 4.196687308818218, 4.215698520151927, 4.234581993582788, 4.253339992547305, 4.271974716021572, 4.290488301035591, 4.308882825063635, 4.327160308297982, 4.3453227158129035, 4.363371959625271, 4.381309900657732, 4.399138350610032, 4.416859073743617, 4.434473788584404], [0.0, 0.7068051677550784, 0.9326350102279886, 1.0968524712012218, 1.23061927385959, 1.3455124415016921, 1.4473055127008105, 1.5393555157114143, 1.623811867007324, 1.7021456526717405, 1.7754143106048341, 1.8444071206649322, 1.9097310733139388, 1.9718644488313055, 2.0311917804730997, 2.0880275269924504, 2.1426326041230666, 2.1952262371678057, 2.2459946539880526, 2.2950975879354067, 2.342673227742483, 2.388842043738954, 2.433709786403234, 2.477369865465766, 2.5199052586865527, 2.5613900588559146, 2.6018907392047406, 2.641467197257912, 2.680173622631135, 2.7180592236466437, 2.7551688397781016, 2.791543461045193, 2.8272206710203136, 2.862235026701848, 2.8966183858791332, 2.9304001905680463, 2.963607713490865, 2.9962662733051872, 3.0283994232765576, 3.060029117279912, 3.0911758563620766, 3.121858818567898, 3.152095974300438, 3.1819041891312456, 3.2112993156844785, 3.240296275976669, 3.268909135392459, 3.2971511693083384, 3.3250349232351226, 3.3525722672308924, 3.379774445235429, 3.406652119891729, 3.433215413347389, 3.459473944466448, 3.48543686282892, 3.511112879849411, 3.5365102973066285, 3.561637033541379, 3.5865006475509773, 3.6111083611821693, 3.635467079602182, 3.65958341020784, 3.683463680115477, 3.7071139523592187, 3.730540040911955, 3.7537475246315295, 3.776741760224355, 3.7995278943094397, 3.8221108746577284, 3.8444954606743393, 3.8666862331849345, 3.8886876035816282, 3.9105038223787663, 3.9321389872242785, 3.9535970504082134, 3.974881825906354, 3.9959969959934885, 4.016946117457942, 4.037732627446241, 4.058359848964379, 4.078830996059936, 4.0991491787073, 4.119317407416463, 4.139338597584176, 4.159215573604822, 4.17895107275693, 4.19854774888009, 4.2180081758558625, 4.237334850905251, 4.256530197714383, 4.275596569399164, 4.294536251318896, 4.313351463748132, 4.332044364415347, 4.350617050916451, 4.36907156301055, 4.387409884804887, 4.4056339468354135, 4.42374562804898, 4.441746757692774, 4.459639117116218, 4.477424441490228], [0.0, 0.7134891648337663, 0.9414545972489002, 1.107225002483847, 1.2422567887034328, 1.358236458866902, 1.4609921497829736, 1.5539126358903128, 1.6391676599055116, 1.7182422194329807, 1.79220375217504, 1.8618490019199763, 1.9277906992157308, 1.9905116472628315, 2.0504000157072277, 2.1077732370230735, 2.1628946943284157, 2.2159856860593465, 2.2672342011657936, 2.3168014835390394, 2.364827028711829, 2.4114324462575323, 2.4567244866980262, 2.5007974431052955, 2.5437350779295658, 2.5856121846294853, 2.6264958650488914, 2.6664465831415756, 2.705519040974554, 2.7437629122151037, 2.7812234603673365, 2.8179420630785077, 2.8539566593350654, 2.889302132928245, 2.924010642914807, 2.958111909732967, 2.991633464013128, 3.024600863842141, 3.0570378852201396, 3.0889666896317975, 3.120407971994817, 3.1513810917137763, 3.1819041891312456, 3.2119942893102924, 3.241667394787524, 3.270938568691507, 3.2998220094180644, 3.3283311178840482, 3.356478558238567, 3.3842763127904836, 3.4117357318093915, 3.438867578770989, 3.4656820715443084, 3.492188919955455, 3.518397360108663, 3.5443161857991905, 3.569953777312618, 3.595318127870597, 3.6204168679531037, 3.6452572877012397, 3.669846357581863, 3.694190747475527, 3.718296844331781, 3.7421707685206402, 3.7658183889956014, 3.789245337371721, 3.8124570210118165, 3.8354586352045854, 3.8582551745102247, 3.8808514433418013, 3.903252065844164, 3.9254614951263433, 3.9474840218982394, 3.9693237825577348, 3.9909847667702345, 4.012470824578891, 4.033785673080413, 4.0549329026983685, 4.075915983083116, 4.096738268665099, 4.117403003885965, 4.137913328129988, 4.158272280376448, 4.178482803591934, 4.19854774888009, 4.218469879404883, 4.238251874102291, 4.257896331194127, 4.277405771516697, 4.296782641676039, 4.316029317040612, 4.335148104581522, 4.354141245569644, 4.373010918138299, 4.391759239719593, 4.410388269361882, 4.428900009935388, 4.447296410232428, 4.465579366968364, 4.483750726688906, 4.501812287589042, 4.51976580124856], [0.0, 0.7200805337273644, 0.9501519606468252, 1.1174537891274203, 1.2537330285098613, 1.370784144222729, 1.474489114676777, 1.5682680205498158, 1.6543106491160209, 1.7341157167123347, 1.8087605222639431, 1.8790491700524399, 1.9456000511645282, 2.008900429042257, 2.06934205932763, 2.1272453070053965, 2.1828759883844313, 2.2364574463041613, 2.288179406397533, 2.338204602162149, 2.3866738178209848, 2.4337097864032344, 2.4794202446154356, 2.523900356629587, 2.567234658711743, 2.6094986352788734, 2.6507600080763196, 2.6910797996370985, 2.73051321737788, 2.7691103938621393, 2.8069170107481347, 2.8439748279388746, 2.8803221349094574, 2.915994137715209, 2.9510232925052864, 2.9854395942818113, 3.0192708280091702, 3.0525427878854074, 3.085279469558544, 3.1175032392458943, 3.1492349830493347, 3.180494239219856, 3.2112993156844785, 3.241667394787524, 3.2716146269005324, 3.301156214308545, 3.330306486575269, 3.359078968418158, 3.3874864409804957, 3.4155409972663366, 3.443254092401545, 3.470636589297161, 3.497698800217125, 3.5244505246890387, 3.550901084142287, 3.57705935361113, 3.60293379080006, 3.628532462773856, 3.6538630705045376, 3.6789329714811236, 3.7037492005651687, 3.728318489255041, 3.752647283504326, 3.776741760224355, 3.800607842587301, 3.824251214234311, 3.847677332482603, 3.8708914406160866, 3.893898579335798, 3.9167035974390227, 3.9393111617894703, 3.9617257666349666, 3.9839517423239275, 4.005993263467182, 4.02785435658754, 4.049538907295691, 4.071050667027698, 4.092393259376244, 4.11357018604508, 4.1345848324536085, 4.1554404730163395, 4.176140276119864, 4.196687308818218, 4.21708454126576, 4.237334850905251, 4.257441026427372, 4.277405771516697, 4.297231708397979, 4.316921381195564, 4.3364772591177685, 4.3559017394772255, 4.375197150557344, 4.394365754334351, 4.413409749063638, 4.4323312717386125, 4.45113240042957, 4.469815156509681, 4.488381506774638, 4.506833365462072, 4.525172596176483, 4.5434010137249805, 4.561520385868831], [0.0, 0.7265826204502338, 0.9587315155141827, 1.127544023629519, 1.2650538190282499, 1.3831618672225916, 1.4878032589238497, 1.5824289569960974, 1.6692485217612372, 1.7497742024641847, 1.8250930256796174, 1.8960163564822325, 1.9631681698237122, 2.0270401289722484, 2.0880275269924504, 2.1464536216578836, 2.202586629509912, 2.2566519100992104, 2.3088409022178236, 2.3593178087924884, 2.408224685280692, 2.455685372949893, 2.5018085813331057, 2.546690333903018, 2.590415930259933, 2.6330615364198957, 2.6746954856329896, 2.7153793514453235, 2.7551688397781016, 2.7941145358751043, 2.8322625338847063, 2.869654970787893, 2.9063304818009352, 2.9423245908780795, 2.9776700472366704, 3.0123971167236805, 3.046533835192445, 3.080106229754002, 3.113138512729059, 3.145653252294404, 3.177671523146437, 3.2092130399600296, 3.240296275976669, 3.270938568691507, 3.301156214308545, 3.3309645523843807, 3.3603780418738958, 3.3894103296182245, 3.4180743121701074, 3.4463821917293855, 3.474345526857884, 3.5019752785551015, 3.529281852201278, 3.5562751358104765, 3.582964534981476, 3.6093590048871316, 3.635467079602182, 3.661296899034308, 3.6868562336927337, 3.7121525075021466, 3.737192818846552, 3.7619839600075, 3.786532435143384, 3.8108444769409813, 3.8349260620567316, 3.858782925453163, 3.8824205737252457, 3.9058442975019916, 3.929059183000284, 3.952070122800428, 3.9748818259063543, 3.997498827147445, 4.019925495973716, 4.04216604469134, 4.064224536181279, 4.086104891139992, 4.107810894877756, 4.129346203707088, 4.150714350950949, 4.171918752597953, 4.192962712629476, 4.213849428041585, 4.234581993582788, 4.255163406226945, 4.2755965693991635, 4.295884296971072, 4.316029317040611, 4.33603427551035, 4.355901739477225, 4.375634200445681, 4.395234077375283, 4.414703719573063, 4.434045409440134, 4.453261365081402, 4.472353742786611, 4.491324639390337, 4.510176094518076, 4.528910092725027, 4.547528565533749, 4.566033393376469, 4.584426407447396, 4.602709391470093], [0.0, 0.7329985789312627, 0.9671974234850909, 1.1375006004007286, 1.2762246515677385, 1.3953756318556398, 1.5009410407376782, 1.596402314191145, 1.6839885236670116, 1.7652252720579347, 1.8412091847332428, 1.9127587913824833, 1.9805035768570671, 2.044939545970148, 2.1064654823513713, 2.1654074982445235, 2.222036178629389, 2.276578873054035, 2.3292287107766794, 2.3801513446887705, 2.429490084643225, 2.477369865465766, 2.523900356629587, 2.5691784295255564, 2.613290136976913, 2.656312317570147, 2.698313907959941, 2.7393570254066426, 2.779497867732675, 2.818787466865809, 2.857272323980591, 2.8949949481411146, 2.931994315725051, 2.9683062643745997, 3.00396383249324, 3.0389975531851166, 3.073435709869178, 3.107304559484232, 3.1406285281535746, 3.17343038333826, 3.205731385831044, 3.237551424393725, 3.268909135392459, 3.2998220094180644, 3.330306486575269, 3.3603780418738958, 3.3900512619460526, 3.419339914138875, 3.4482570088858173, 3.4768148561360723, 3.5050251165172894, 3.5328988478181214, 3.560446547301666, 3.5876781902963337, 3.6146032654553695, 3.641230807028688, 3.6675694244496566, 3.6936273295039603, 3.7194123613169228, 3.744932009368876, 3.7701934347248414, 3.7952034896444027, 3.819968735719766, 3.84449546067434, 3.8687896939403643, 3.892857221121933, 3.9167035974390227, 3.9403341602386037, 3.963754040650491, 3.98696817445805, 4.009981312247231, 4.032798028891421, 4.055422732424287, 4.077859672348019, 4.100112947420127, 4.122186512958084, 4.144084187697673, 4.165809660237828, 4.187366495101893, 4.208758138442756, 4.229987923417016, 4.251059075251244, 4.271974716021572, 4.292737869166105, 4.313351463748131, 4.333818338486669, 4.354141245569643, 4.374322854263795, 4.394365754334351, 4.414272459286546, 4.434045409440134, 4.453686974847285, 4.4731994580634495, 4.492585096780115, 4.511846066327755, 4.530984482056673, 4.550002401602915, 4.568901827045938, 4.58768470696427, 4.606352938394958, 4.624908368702249, 4.643352797360555], [0.0, 0.7393313859531326, 0.9755536124478463, 1.1473281389480776, 1.2872507090080074, 1.4074311048859502, 1.5139085555943308, 1.6101945752890852, 1.698537493684083, 1.7804760942551208, 1.8571164767648465, 1.9292842426635375, 1.9976143152934853, 2.062606984745952, 2.1246644799775485, 2.1841157307080663, 2.2412336596605122, 2.296247580589782, 2.349352291311657, 2.400714875890612, 2.4504798823179006, 2.4987733248048896, 2.54570582032403, 2.5913750771952677, 2.6358678917029326, 2.67926176628738, 2.72162623318771, 2.763023946331916, 2.8035115890685534, 2.843140634220313, 2.8819579847128143, 2.9200065168710254, 2.9573255438125305, 2.9939512128020573, 3.0299168476813367, 3.0652532453480084, 3.0999889335781567, 3.1341503961597703, 3.167762270247829, 3.200847520004912, 3.233427589908301, 3.2655225405505384, 3.2971511693083384, 3.3283311178840482, 3.359078968418158, 3.3894103296182245, 3.419339914138875, 3.4488816082714764, 3.47804853485429, 3.5068531101894203, 3.5353070956475556, 3.5634216445521067, 3.591207344858218, 3.618674258077045, 3.6458319548399043, 3.672689547448924, 3.6992557197194436, 3.725538754383608, 3.751546558293567, 3.777286685635691, 3.802766359343666, 3.827992490877786, 3.8529716985197227, 3.8777103243162356, 3.902214449791386, 3.9264899105345137, 3.950542309760416, 3.974377030928552, 3.997999249499594, 4.02141394390005, 4.044625905758985, 4.067639749474814, 4.090459921164807, 4.11309070704511, 4.135536241284817, 4.1578005133737195, 4.179887375039913, 4.201800546750313, 4.223543623824281, 4.245120082188055, 4.266533283795337, 4.287786481737334, 4.308882825063635, 4.32982536333361, 4.350617050916451, 4.371260751056545, 4.391759239719592, 4.412115209233702, 4.4323312717386125, 4.452409962455209, 4.472353742786611, 4.492165003261264, 4.511846066327755, 4.5313991890103065, 4.550826565433356, 4.570130329222964, 4.5893125557923105, 4.6083752645179965, 4.627320420813468, 4.646149938105396, 4.664865679718495, 4.683469460673898], [0.0, 0.7455838546382704, 0.9838037943397453, 1.1570310048031527, 1.2981368892796834, 1.4193336415251103, 1.5267115638472708, 1.623811867007324, 1.7129018946706591, 1.7955334436866137, 1.8728219680184823, 1.9456000511645282, 2.01450798596493, 2.0800502934257863, 2.142632604123067, 2.2025866295099124, 2.2601876003958137, 2.3156667698244604, 2.369220583001784, 2.4210175370093454, 2.471203402269648, 2.5199052586865527, 2.5672346587117425, 2.613290136976913, 2.6581592237958964, 2.701920077041227, 2.744642816980805, 2.7863906274020755, 2.827220671020314, 2.8671848559599162, 2.9063304818009352, 2.9447007874701248, 2.9823354185530815, 3.0192708280091702, 3.05554062149729, 3.0911758563620766, 3.1262053016368228, 3.1606556650808746, 3.1945517922037396, 3.227916841374152, 3.260772438423691, 3.293138813595786, 3.3250349232351226, 3.356478558238567, 3.3874864409804957, 3.4180743121701074, 3.4482570088858173, 3.47804853485429, 3.5074621238926214, 3.5365102973066285, 3.565204915932007, 3.5935572274149665, 3.621577909252174, 3.6492771080442106, 3.6766644753604867, 3.703749200565169, 3.7305400409119547, 3.7570453491794185, 3.7832730990873507, 3.8092309087072946, 3.834926062056731, 3.860365529045643, 3.885555983926001, 3.9105038223787667, 3.935215177358982, 3.959695933807117, 3.9839517423239275, 4.007988031896373, 4.0318100217536, 4.055422732424287, 4.078830996059937, 4.102039466082577, 4.12505262620995, 4.147874798906402, 4.170510153303377, 4.192962712629476, 4.2152363611865615, 4.237334850905252, 4.2592618075102475, 4.281020736323429, 4.3026150277302815, 4.324047962333153, 4.3453227158129035, 4.366442363518794, 4.387409884804887, 4.408228167129809, 4.428900009935387, 4.449428128318544, 4.469815156509681, 4.490063651169854, 4.510176094518076, 4.530154897299312, 4.550002401602915, 4.569720883540587, 4.5893125557923105, 4.608779570028056, 4.628124019212611, 4.6473479398002935, 4.666453313825897, 4.685442070897794, 4.704316090098694, 4.723077201799226], [0.0, 0.7517586466500457, 0.9919514812466601, 1.1666133284564741, 1.3088878266078583, 1.4310883086590775, 1.5393555157114145, 1.6372599861996144, 1.7270878415234094, 1.810403730235845, 1.8883323442902544, 1.9617131624923867, 2.0311917804730997, 2.0972768975911458, 2.160377503782311, 2.220828057674608, 2.278906069489821, 2.3348447074679504, 2.388842043738954, 2.4410679708470604, 2.491669466459315, 2.5407746629325945, 2.588496036576016, 2.6349329380674558, 2.680173622631135, 2.7242968954290983, 2.7673734574527504, 2.8094670157663533, 2.8506352064965577, 2.8909303676615528, 2.930400190568047, 2.9690882722398433, 3.0070345866001826, 3.044275888505313, 3.0808460619301843, 3.1167764214308007, 3.1520959743004386, 3.186831649487327, 3.2210084982670333, 3.2546498708017575, 3.287777572024343, 3.320411999721476, 3.3525722672308924, 3.3842763127904836, 3.4155409972663366, 3.4463821917293855, 3.4768148561360723, 3.5068531101894203, 3.5365102973066285, 3.565799042492728, 3.5947313048127314, 3.6233184250638413, 3.6515711691718398, 3.6794997677696393, 3.7071139523592187, 3.7344229884094142, 3.761435705699931, 3.788160526185559, 3.8146054896230104, 3.8407782771753323, 3.866686233184934, 3.892336385285346, 3.917735463003498, 3.9428899149882373, 3.9678059249866413, 3.992489426677203, 4.016946117457942, 4.041181471277718, 4.065200750590396, 4.089009017503776, 4.112611144188374, 4.136011822605027, 4.159215573604823, 4.182226755449985, 4.205049571799959, 4.227688079203001, 4.25014619413007, 4.2724276995846004, 4.294536251318897, 4.316475383685286, 4.3382485151478205, 4.359858953478209, 4.381309900657732, 4.402604457505142, 4.42374562804898, 4.444736323661286, 4.465579366968365, 4.486277495553084, 4.506833365462072, 4.527249554530191, 4.54752856553375, 4.56767282918307, 4.5876847069642706, 4.607566493839403, 4.627320420813469, 4.646948657376185, 4.666453313825897, 4.685836443482473, 4.705100044795566, 4.724246063354219, 4.743276393803367, 4.762192881672441], [0.0, 0.7578582832551991, 1.0, 1.1760790225246738, 1.3195079107728942, 1.4426999059072136, 1.55184557391536, 1.6505444239489884, 1.7411011265922485, 1.8250930256796174, 1.9036539387158786, 1.9776301558892317, 2.0476725110792193, 2.1142938311411563, 2.17790642448278, 2.2388474634702153, 2.29739670999407, 2.353789224180174, 2.4082246852806923, 2.4608743643178865, 2.51188643150958, 2.561390058855915, 2.6094986352788734, 2.656312317570147, 2.701920077041227, 2.746401358265295, 2.789827435889086, 2.8322625338847063, 2.8737647560281374, 2.914386864998985, 2.9541769390627777, 2.993178928981856, 3.0314331330207964, 3.068976604258247, 3.105843501597733, 3.1420653936760226, 3.177671523146437, 3.212689037453924, 3.2471431911356685, 3.281057523812953, 3.314454017339987, 3.3473532350074864, 3.379774445235429, 3.4117357318093915, 3.443254092401545, 3.474345526857884, 3.5050251165172894, 3.5353070956475556, 3.565204915932007, 3.5947313048127314, 3.6238983183884783, 3.652717389473671, 3.6811993713469087, 3.709354577650648, 3.7371928188465526, 3.764723435581833, 3.791955329279464, 3.818896990228487, 3.845556523418775, 3.8719416723369746, 3.8980598409161895, 3.923918113810924, 3.949523275150298, 3.9748818259063547, 4.000000000000001, 4.024883779254547, 4.049538907295691, 4.073970902486945, 4.0981850699807945, 4.122186512958084, 4.14598014312126, 4.1695706905009, 4.192962712629476, 4.216160603131382, 4.239168599773808, 4.261990792019129, 4.284631128115855, 4.30709342176204, 4.329381358372116, 4.351498500975518, 4.3734482957731124, 4.3952340773752825, 4.416859073743618, 4.438326410856363, 4.459639117116218, 4.480800127517579, 4.501812287589042, 4.522678357125735, 4.543401013724981, 4.563982856137738, 4.584426407447397, 4.604734118086634, 4.624908368702249, 4.644951472877209, 4.664865679718495, 4.684653176318679, 4.704316090098695, 4.723856491038685, 4.743276393803367, 4.762577759767951, 4.781762498950186, 4.800832471853799], [0.0, 0.7638851553743226, 1.0079525054384, 1.1854317973472892, 1.3300013046093275, 1.4541729847549199, 1.5641866342814787, 1.6636703874567635, 1.7549472427702775, 1.8396070878919204, 1.918792757016348, 1.9933572704590845, 2.063956637859639, 2.131107764331682, 2.1952262371678053, 2.25665191009921, 2.31566676982446, 2.3725077457863137, 2.427376105187276, 2.4804444810833437, 2.531862222016803, 2.5817595272288303, 2.630250687367426, 2.677436655721712, 2.7234071111480196, 2.7682421300029283, 2.8120135537451914, 2.8547861170884006, 2.8966183858791332, 2.9375635423924904, 2.9776700472366704, 3.0169822006926883, 3.05554062149729, 3.093382657393933, 3.1305427389350076, 3.1670526858070396, 3.2029419732157076, 3.2382379644961645, 3.2729661150224385, 3.3071501516147785, 3.3408122309382096, 3.3739730798131293, 3.406652119891729, 3.438867578770989, 3.470636589297161, 3.5019752785551015, 3.5328988478181214, 3.5634216445521067, 3.5935572274149665, 3.6233184250638413, 3.652717389473671, 3.681765644378398, 3.710474129367379, 3.7388532401023684, 3.7669128650627792, 3.7946624191773695, 3.8221108746577284, 3.849266789311968, 3.8761383325849375, 3.902733309543402, 3.929059183000284, 3.9551230939508413, 3.980931880475018, 4.006492095243872, 4.031810021753601, 4.056891689397997, 4.081742887478972, 4.106369178244856, 4.130775909037387, 4.154968223620482, 4.178951072756931, 4.202729224092901, 4.2263072714046706, 4.249689643256952, 4.272880611117803, 4.295884296971072, 4.318704680463734, 4.3413456056222985, 4.363810787169477, 4.386103816469715, 4.40822816712981, 4.430187200278651, 4.45198416954821, 4.473622225776093, 4.495104421448386, 4.516433714900046, 4.5376129742887485, 4.558644981356911, 4.5795324349954605, 4.600277954621937, 4.620884083384567, 4.641353291203104, 4.661687977656455, 4.681890474726369, 4.701963049405862, 4.721907906180371, 4.741727189389157, 4.7614229854738905, 4.780997325120922, 4.800452185303309, 4.8197894912282235, 4.839011118195064], [0.0, 0.7698415327308915, 1.0158119924799414, 1.1946751751846505, 1.3403719599352584, 1.4655118659702304, 1.5763833444601398, 1.6766428199682788, 1.7686314045127423, 1.8539513828768568, 1.9337545004792647, 2.0089004290422574, 2.0800502934257867, 2.1477250292995467, 2.2123434644887174, 2.274248102726342, 2.333723129495938, 2.3910073216922774, 2.4463035158943596, 2.4997856912605614, 2.5516043608750762, 2.601890739204741, 2.6507600080763196, 2.6983139079599416, 2.7446428169808055, 2.789827435889086, 2.833940166325698, 2.8770462477717107, 2.9192047027395747, 2.9604691281919884, 3.0008883626076543, 3.0405070516980355, 3.079366130923566, 3.1175032392458943, 3.1549530756888706, 3.191747708052312, 3.227916841374152, 3.2634880523545355, 3.2984869948551983, 3.332937580705738, 3.366862139337278, 3.400281559187132, 3.433215413347389, 3.4656820715443084, 3.497698800217125, 3.529281852201278, 3.560446547301666, 3.591207344858218, 3.621577909252174, 3.6515711691718398, 3.6811993713469087, 3.710474129367379, 3.7394064681238106, 3.7680068643378957, 3.7962852835942447, 3.8242512142343115, 3.851913698430304, 3.87928136071965, 3.906362434248262, 3.933164784942738, 3.9596959338071174, 3.9859630775184076, 4.011973107476328, 4.037732627446241, 4.063247969919766, 4.088525211304757, 4.113570186045081, 4.138388499760568, 4.162985541488738, 4.187366495101893, 4.21153634996628, 4.235499910903684, 4.2592618075102475, 4.28282650288232, 4.306198301794635, 4.329381358372115, 4.352379683292945, 4.375197150557345, 4.397837503853493, 4.420304362549419, 4.442601227337289, 4.4647314855543225, 4.4866984162026124, 4.508505194688349, 4.530154897299312, 4.551650505438007, 4.572994909626506, 4.5941909132978, 4.615241236387358, 4.636148518737569, 4.6569153233268, 4.677544139333949, 4.698037385048586, 4.718397410636036, 4.73862650076614, 4.758726877113762, 4.778700700738602, 4.7985500743513105, 4.8182770444724685, 4.837883603490537, 4.857371691624451, 4.876743198796209], [0.0, 0.775729572195403, 1.023581307132307, 1.2038125031666915, 1.3506236320803386, 1.476720655488162, 1.5884401210157693, 1.6894664189456463, 1.782158567006826, 1.8681311048631999, 1.9485445869183637, 2.024265259989368, 2.095959305469361, 2.164151643341238, 2.229264304783933, 2.291642413128693, 2.351572327417192, 2.4092946508002813, 2.4650137712278997, 2.5189049985168874, 2.5711199969324823, 2.6217909845194343, 2.6710340240587205, 2.7189516341700988, 2.765634884224883, 2.811165092203134, 2.855615213500923, 2.899050986575568, 2.9415318853660364, 2.983111916764887, 3.0238402927859958, 3.063762000608127, 3.102918288781612, 3.1413470841451256, 3.1790833511137886, 3.2161594027540903, 3.252605171299339, 3.288448444366721, 3.3237150720284183, 3.358429149000753, 3.39261317549879, 3.4262881997225194, 3.459473944466448, 3.492188919955455, 3.5244505246890387, 3.5562751358104765, 3.5876781902963337, 3.618674258077045, 3.6492771080442106, 3.6794997677696393, 3.709354577650648, 3.7388532401023684, 3.7680068643378957, 3.796826007208857, 3.8253207105204257, 3.8535005351844824, 3.8813745925311913, 3.9089515730617075, 3.93623977289216, 3.9632471181107314, 3.989981187244946, 4.016449232014722, 4.042658196527812, 4.068614735057678, 4.094325228529229, 4.119795799824989, 4.145032328012858, 4.170040461586572, 4.194825630801047, 4.219393059176802, 4.243747774240649, 4.267894617563467, 4.291838254150303, 4.315583181232955, 4.339133736510706, 4.362494105880797, 4.385668330696598, 4.4086603145881496, 4.431473829876773, 4.454112523612795, 4.476579923263003, 4.498879442072251, 4.521014384121683, 4.542987949104197, 4.564803236836187, 4.586463251523052, 4.607970905794672, 4.629329024525755, 4.650540348454865, 4.671607537614905, 4.692533174586873, 4.713319767587849, 4.733969753403394, 4.7544855001737885, 4.774869310042895, 4.795123421677787, 4.815250012666766, 4.83525120180281, 4.855129051259066, 4.874885568662534, 4.894522709071677, 4.914042376863336], [0.0, 0.7815513254092057, 1.0312631565524872, 1.2128469651239588, 1.3607598931596327, 1.4878032589238495, 1.6003611650379603, 1.7021456526717407, 1.795533443686614, 1.882151194664292, 1.9631681698237122, 2.0394571170557168, 2.111689217361314, 2.1803933301820804, 2.245994653988053, 2.308840902217824, 2.369220583001784, 2.427376105187276, 2.483513390630187, 2.5378090648255593, 2.5904159302599328, 2.6414671972579122, 2.6910797996370985, 2.739357025406643, 2.7863906274020755, 2.8322625338847063, 2.8770462477717107, 2.9208080008792883, 2.9636077134908656, 3.0054997978139606, 3.046533835192445, 3.086755150428222, 3.1262053016368228, 3.1649225002930934, 3.202941973215708, 3.240296275976669, 3.277015565446945, 3.3131278377863063, 3.3486591370684864, 3.383633738837634, 3.4180743121701074, 3.4520020632300006, 3.48543686282892, 3.518397360108663, 3.550901084142287, 3.582964534981476, 3.6146032654553695, 3.6458319548399043, 3.6766644753604867, 3.7071139523592187, 3.7371928188465526, 3.7669128650627792, 3.7962852835942447, 3.8253207105204257, 3.8540292630089836, 3.8824205737252457, 3.9105038223787663, 3.9382877646918226, 3.9657807590418552, 3.992990791001345, 4.019925495973716, 4.046592180102135, 4.072997839609014, 4.099149178707302, 4.12505262620995, 4.150714350950949, 4.176140276119865, 4.2013360926016725, 4.2263072714046706, 4.251059075251245, 4.275596569399164, 4.299924631754692, 4.324047962333154, 4.347971092117508, 4.371698391360925, 4.395234077375283, 4.418582221843801, 4.4417467576927745, 4.464731485554323, 4.487540079849429, 4.510176094518076, 4.532642968421094, 4.554944030436339, 4.577082504270005, 4.599061513002219, 4.620884083384567, 4.642553149905849, 4.664071558641103, 4.685442070897794, 4.70666736667204, 4.727750047926782, 4.748692641702957, 4.769497603073896, 4.790167317952476, 4.81070410575986, 4.831110221964036, 4.851387860495835, 4.8715391560495105, 4.891566186274559, 4.911470973864971, 4.9312554885516775, 4.95092164900363], [0.0, 0.7873087457623338, 1.0388601182540846, 1.2217815924161308, 1.370784144222729, 1.4987633948559247, 1.6121504764297887, 1.7146847754472663, 1.8087605222639431, 1.8960163564822325, 1.9776301558892317, 2.0544810976099313, 2.1272453070053965, 2.1964555394431833, 2.2625401256845117, 2.3258493406535257, 2.3866738178209848, 2.4452577517770053, 2.5018085813331057, 2.556504233123725, 2.6094986352788734, 2.6609259794378928, 2.710904060829683, 2.7595369283507045, 2.8069170107481347, 2.853126839820663, 2.8982404599562255, 2.9423245908780795, 2.9854395942818117, 3.0276402832109963, 3.068976604258247, 3.1094942161177253, 3.149234983049335, 3.188237398018742, 3.226536947348501, 3.26416642643634, 3.301156214308545, 3.3375345133629852, 3.3733275595311465, 3.4085598071867786, 3.443254092401545, 3.4774317775580705, 3.511112879849411, 3.5443161857991905, 3.57705935361113, 3.6093590048871316, 3.641230807028688, 3.672689547448924, 3.703749200565169, 3.7344229884094142, 3.764723435581833, 3.7946624191773695, 3.8242512142343115, 3.8535005351844824, 3.8824205737252457, 3.911021033482467, 3.9393111617894707, 3.967299778868934, 3.9949953046715954, 4.022405783596908, 4.049538907295691, 4.076402035732961, 4.103002216669898, 4.129346203707088, 4.1554404730163395, 4.181291238875326, 4.206904468107719, 4.232285893521288, 4.257441026427372, 4.282375168317028, 4.30709342176204, 4.3316007006025306, 4.3559017394772255, 4.38000110274728, 4.403903192860021, 4.427612258194813, 4.451132400429569, 4.474467581463103, 4.497621629925486, 4.520598247305899, 4.543401013724981, 4.566033393376469, 4.588498739660921, 4.610800300032469, 4.632941220577896, 4.6549245503458305, 4.676753245442443, 4.6984301729088305, 4.719958114394062, 4.741339769636865, 4.762577759767952, 4.783674630444099, 4.804632854824324, 4.825454836397703, 4.846142911671777, 4.866699352729796, 4.887126369664523, 4.907426112895774, 4.9276006753783745, 4.9476520947068074, 4.967582355122337, 4.987393389428088], [0.0, 0.7930036947907745, 1.0463746485485608, 1.2306192738595902, 1.3806996263920328, 1.5096046070047022, 1.6238118670073243, 1.7270878415234094, 1.821844079425467, 1.9097310733139388, 1.9919352210819108, 2.06934205932763, 2.142632604123067, 2.2123434644887174, 2.2789060694898216, 2.342673227742483, 2.4039376749966648, 2.4629453722089187, 2.5199052586865527, 2.5749965480852914, 2.628374281964735, 2.680173622631135, 2.73051321737788, 2.779497867732675, 2.827220671020314, 2.8737647560281374, 2.9192047027395747, 2.9636077134908656, 3.0070345866001826, 3.049540531597854, 3.091175856362077, 3.1319865498563466, 3.172014779163098, 3.2112993156844785, 3.2498759024311585, 3.287777572024343, 3.3250349232351226, 3.361676362461664, 3.3977283154114373, 3.4332154133473893, 3.468160657524494, 3.502585564848846, 3.5365102973066285, 3.569953777312618, 3.60293379080006, 3.635467079602182, 3.6675694244496566, 3.6992557197194436, 3.7305400409119547, 3.761435705699931, 3.791955329279464, 3.8221108746577284, 3.851913698430304, 3.8813745925311913, 3.9105038223787663, 3.9393111617894707, 3.967805924986641, 3.995996995993489, 4.023892855665946, 4.0515016065921285, 4.078830996059936, 4.105888437272236, 4.1326810289697535, 4.159215573604823, 4.185498594194244, 4.21153634996628, 4.237334850905252, 4.26289987128684, 4.288236962288113, 4.313351463748132, 4.3382485151478205, 4.362933065871259, 4.387409884804888, 4.411683569325887, 4.435758553726412, 4.459639117116218, 4.48332939084245, 4.506833365462072, 4.530154897299313, 4.553297714617846, 4.576265423434893, 4.599061513002218, 4.621689360976999, 4.644152238303622, 4.666453313825897, 4.688595658647553, 4.710582250257575, 4.7324159764356235, 4.754099638951652, 4.775635957072781, 4.797027570889511, 4.8182770444724685, 4.839386868870113, 4.86035946495701, 4.881197186141683, 4.901902320942356, 4.922477095438361, 4.942923675604441, 4.963244169534683, 4.983440629562382, 5.003515054281688, 5.023469390476537], [0.0, 0.7986379480509349, 1.0538090902966404, 1.2393627648436885, 1.3905094310908042, 1.5203302754151293, 1.6353489725286132, 1.7393587178958756, 1.8347881943286328, 1.9232996210981803, 2.0060878253977963, 2.084044635520834, 2.1578559061258296, 2.2280620588146602, 2.2950975879354067, 2.3593178087924884, 2.4210175370093454, 2.4804444810833437, 2.537809064825559, 2.593291775196155, 2.6470487553175848, 2.6992161278178095, 2.7499133829735536, 2.799246066922357, 2.847307938441044, 2.8941827169430074, 2.9399455122988862, 2.9846640043142996, 3.028399423276558, 3.0712073709770573, 3.1131385127290594, 3.1542391642454417, 3.1945517922037396, 3.2341154434750554, 3.2729661150224385, 3.3111370741622843, 3.3486591370684864, 3.385560911965309, 3.4218690123136084, 3.457608244380275, 3.4928017728430967, 3.5274712674847555, 3.561637033541379, 3.595318127870597, 3.628532462773856, 3.661296899034308, 3.6936273295039603, 3.725538754383608, 3.7570453491794185, 3.788160526185559, 3.818896990228487, 3.849266789311968, 3.87928136071965, 3.9089515730617075, 3.9382877646918226, 3.967299778868934, 3.995996995993489, 4.024388363209259, 4.05248242162825, 4.08028733140708, 4.107810894877756, 4.135060577913598, 4.162043529691543, 4.188766600995024, 4.215236361186562, 4.241459113965938, 4.267440912018124, 4.293187570644751, 4.318704680463735, 4.343997619253439, 4.36907156301055, 4.393931496284288, 4.418582221843802, 4.443028369730415, 4.467274405741719, 4.491324639390337, 4.515183231376437, 4.538854200609698, 4.562341430813352, 4.585648676740204, 4.608779570028056, 4.63173762471964, 4.654526242470223, 4.677148717464097, 4.699608241059554, 4.721907906180371, 4.744050711470445, 4.766039565226975, 4.787877289126356, 4.809566621755971, 4.831110221964036, 4.852510672038778, 4.873770480727436, 4.894892086104772, 4.915877858300166, 4.936730102091653, 4.957451059374754, 4.978042911513356, 4.9985077815794545, 5.018847736488076, 5.039064789033284, 5.0591608998308235], [0.0, 0.804213200522412, 1.0611656800373104, 1.2480146957150107, 1.400216509449929, 1.530943626741792, 1.6467652637567831, 1.751501096071619, 1.8475967610139905, 1.9367260817266636, 2.02009222643314, 2.098593249236489, 2.172919792713087, 2.2436160511215957, 2.3111195519938965, 2.375788091073179, 2.437918542076337, 2.4977603427416475, 2.5555253858385236, 2.611395418297774, 2.6655276732693567, 2.7180592236466437, 2.769110393862139, 2.818787466865809, 2.8671848559599162, 2.9143868649989844, 2.960469128191988, 3.00549979781396, 3.049540531597854, 3.0926473194884525, 3.1348711804910927, 3.1762587536463798, 3.216852802089648, 3.2566926452762983, 3.2958145314624194, 3.3342519602019163, 3.372035962794885, 3.4091953471782057, 3.4457569126000043, 3.481745638498506, 3.5171848512629826, 3.5520963719518104, 3.5865006475509773, 3.6204168679531037, 3.6538630705045376, 3.6868562336927337, 3.7194123613169228, 3.751546558293567, 3.7832730990873507, 3.8146054896230104, 3.845556523418775, 3.8761383325849375, 3.906362434248262, 3.93623977289216, 3.9657807590418552, 3.9949953046715954, 4.023892855665946, 4.05248242162825, 4.0807726032956, 4.108771617790267, 4.136487321911958, 4.163927233652889, 4.191098552098052, 4.218008175855863, 4.244662720149242, 4.271068532683791, 4.297231708397979, 4.323158103189774, 4.348853346704923, 4.374322854263795, 4.399571837996458, 4.424605317249026, 4.449428128318544, 4.474044933568429, 4.498460229971786, 4.522678357125735, 4.546703504776089, 4.570539719888341, 4.5941909132978, 4.617660865969023, 4.640953234892091, 4.664071558641102, 4.687019262618111, 4.709799664003948, 4.732415976435623, 4.75487131442846, 4.777168697559745, 4.7993110544293565, 4.821301226411675, 4.843141971212029, 4.864835966239921, 4.886385811810408, 4.90779403418417, 4.929063088456051, 4.950195361301187, 4.971193173587157, 4.992058782860043, 5.012794385711729, 5.033402120035271, 5.053884067174728, 5.074242253975382, 5.094478654739939], [0.0, 0.8097310715843881, 1.0684465545542128, 1.256577579499974, 1.4098236809723264, 1.5414477437222491, 1.658064056650071, 1.7635185029069644, 1.860273499837946, 1.9500143550283104, 2.033952491884537, 2.11299212624236, 2.187828639317965, 2.259009959197995, 2.326976615380111, 2.39208885851719, 2.454645599237348, 2.51489798672214, 2.5730593675805586, 2.6293127357462343, 2.6838164031778873, 2.7367083832540144, 2.788109825977632, 2.8381277435277394, 2.8868571969955523, 2.934383068661564, 2.9807815116765077, 3.0261211459220982, 3.070464052177591, 3.1138666045462187, 3.1563801720851354, 3.1980517138349325, 3.2389242863375522, 3.2790374788272114, 3.318427788266689, 3.3571289440571723, 3.395172190410848, 3.4325865329217353, 3.4693989547130766, 3.5056346066121264, 3.541316975055278, 3.5764680308196466, 3.6111083611821693, 3.6452572877012397, 3.6789329714811236, 3.7121525075021466, 3.744932009368876, 3.777286685635691, 3.8092309087072946, 3.8407782771753323, 3.8719416723369746, 3.902733309543402, 3.933164784942738, 3.9632471181107314, 3.992990791001345, 4.022405783596908, 4.0515016065921285, 4.08028733140708, 4.108771617790267, 4.136962739243317, 4.164868606473045, 4.192496789054147, 4.2198545354660055, 4.246948791649802, 4.273786218216852, 4.300373206425659, 4.326715893033313, 4.352820174116293, 4.378691717946495, 4.404335976999909, 4.429758199168092, 4.454963438235916, 4.479956563683249, 4.504742269862936, 4.529325084602731, 4.553709377274619, 4.577899366371114, 4.601899126624766, 4.625712595703924, 4.649343580515113, 4.672795763139776, 4.6960727064308845, 4.71917785929288, 4.742114561666447, 4.764886049238014, 4.787495457892234, 4.80994582792433, 4.832240108027899, 4.854381159072573, 4.87637175768486, 4.898214599644518, 4.919912303107895, 4.941467411668862, 4.96288239726717, 4.984159662953421, 5.005301545519141, 5.026310317999896, 5.047188192058836, 5.067937320257538, 5.088559798220588, 5.109057666699868, 5.129432913544176], [0.0, 0.8151931096059227, 1.0756537569325701, 1.26505381902825, 1.41933364152511, 1.5518455739153596, 1.6692485217612374, 1.7754143106048341, 1.8728219680184823, 1.963168169823712, 2.0476725110792193, 2.127245307005396, 2.2025866295099124, 2.2742481027263417, 2.342673227742483, 2.408224685280692, 2.4712034022696474, 2.5318622220168034, 2.5904159302599328, 2.6470487553175848, 2.7019200770412266, 2.7551688397781016, 2.8069170107481343, 2.857272323980591, 2.9063304818009352, 2.9541769390627777, 3.000888362607654, 3.0465338351924447, 3.0911758563620766, 3.1348711804910927, 3.177671523146437, 3.21962416013074, 3.260772438423691, 3.301156214308545, 3.34081223093821, 3.3797744452354284, 3.4180743121701074, 3.4557410329933957, 3.4928017728430962, 3.529281852201278, 3.5652049159320067, 3.600593083016195, 3.635467079602182, 3.669846357581863, 3.7037492005651687, 3.737192818846552, 3.7701934347248414, 3.802766359343666, 3.834926062056731, 3.866686233184934, 3.8980598409161895, 3.929059183000284, 3.9596959338071174, 3.989981187244946, 4.019925495973716, 4.049538907295691, 4.078830996059936, 4.107810894877756, 4.136487321911958, 4.164868606473045, 4.192962712629476, 4.220777261016484, 4.2483195490080465, 4.275596569399164, 4.3026150277302815, 4.329381358372115, 4.3559017394772255, 4.382182106894056, 4.408228167129809, 4.434045409440134, 4.459639117116218, 4.485014378033224, 4.510176094518076, 4.535128992589361, 4.5598776306172795, 4.584426407447396, 4.608779570028055, 4.632941220577896, 4.6569153233268, 4.680705710860763, 4.704316090098695, 4.727750047926781, 4.7510110565140335, 4.774102478330697, 4.79702757088951, 4.8197894912282235, 4.84239130015036, 4.864835966239921, 4.887126369664523, 4.909265305780399, 4.931255488551678, 4.953099553795473, 4.9748000622634585, 4.996359502569845, 5.017780293975006, 5.039064789033285, 5.060215276113, 5.0812339817960686, 5.102123073164164, 5.1228846599779, 5.143520796755041, 5.164033484753416], [0.0, 0.8206007961860093, 1.0827892421539749, 1.2734457135126789, 1.4287489707219567, 1.5621399377728824, 1.6803216929198126, 1.787191745949194, 1.8852455693762522, 1.9761910941361376, 2.0612560056255953, 2.1413566577561483, 2.2171977664509948, 2.2893346151121565, 2.358213646847982, 2.4241999482692633, 2.487596442541514, 2.5486576502402425, 2.607599781911575, 2.6646082879759088, 2.71984360555111, 2.7734456006893207, 2.8255370496954426, 2.876226401266048, 2.9256099925800796, 2.9737738453667255, 3.02079513504671, 3.066743402646117, 3.111681562308509, 3.1556667448957487, 3.1987510090365343, 3.2409819441435097, 3.2824031847440374, 3.3230548515130662, 3.362973931343856, 3.402194606416691, 3.4407485403619975, 3.478665128141117, 3.5159717150952297, 3.5526937896730244, 3.5888551535897615, 3.624478072555412, 3.65958341020784, 3.694190747475527, 3.728318489255041, 3.7619839600075, 3.7952034896444027, 3.827992490877786, 3.860365529045643, 3.892336385285346, 3.923918113810924, 3.9551230939508413, 3.9859630775184076, 4.016449232014722, 4.046592180102135, 4.076402035732961, 4.105888437272236, 4.135060577913598, 4.163927233652889, 4.192496789054147, 4.220777261016484, 4.248776320727584, 4.276501313969476, 4.303959279924749, 4.3311569686159, 4.358100857096857, 4.384797164503737, 4.411251866061184, 4.437470706131238, 4.46345921038322, 4.489222697155697, 4.514766288074894, 4.540094917987945, 4.565213344264073, 4.590126155512008, 4.614837779757612, 4.639352492121896, 4.663674422036089, 4.687807560027289, 4.711755764105439, 4.735522765779761, 4.759112175730507, 4.782527489159759, 4.805772090843132, 4.8288492599024915, 4.851762174318194, 4.87451391519799, 4.897107470818359, 4.919545740452873, 4.941831538001114, 4.963967595430637, 4.985956566043578, 5.007801027578684, 5.029503485158703, 5.051066374092476, 5.072492062540313, 5.0937828540507155, 5.114940989975912, 5.135968651773186, 5.156867963198515, 5.177640992398568, 5.198289753906769], [0.0, 0.8259555500753956, 1.0898548822712617, 1.2817554646353289, 1.438072138751391, 1.5723335361052666, 1.6912864752627033, 1.7988538988464122, 1.897547563344556, 1.98908654463616, 2.0747065392644175, 2.1553298807227557, 2.2316658834923415, 2.3042734544252, 2.3736019498525045, 2.4400188387236446, 2.5038290209009713, 2.5652886778102477, 2.624615430859335, 2.681995940608036, 2.7375916910916533, 2.791543461045193, 2.8439748279388746, 2.894994948141115, 2.9447007874701248, 2.993178928981856, 3.0405070516980355, 3.086755150428222, 3.1319865498563466, 3.1762587536463798, 3.21962416013074, 3.2621306692623415, 3.3038222003015822, 3.3447391357271283, 3.3849187037867603, 3.424395309713387, 3.463200823755501, 3.5013648326885196, 3.5389148602930933, 3.575876561340403, 3.6122738928615816, 3.6481292658594113, 3.683463680115477, 3.718296844331781, 3.752647283504326, 3.786532435143384, 3.819968735719766, 3.8529716985197227, 3.885555983926001, 3.917735463003498, 3.949523275150298, 3.980931880475018, 4.011973107476328, 4.042658196527812, 4.072997839609014, 4.103002216669898, 4.1326810289697535, 4.162043529691543, 4.191098552098052, 4.2198545354660055, 4.2483195490080465, 4.276501313969476, 4.304407224066536, 4.3320443644153475, 4.359419529085048, 4.386539237394975, 4.413409749063639, 4.440037078306456, 4.466427006969761, 4.4925850967801155, 4.518516700780411, 4.544226974017562, 4.569720883540588, 4.595003217762484, 4.620078595234513, 4.64495147287721, 4.669626153708488, 4.694106794105793, 4.718397410636037, 4.742501886484245, 4.766423977509256, 4.790167317952476, 4.813735425823604, 4.837131707985294, 4.86035946495701, 4.883421895456726, 4.906322100697674, 4.929063088456052, 4.9516477769243705, 4.9740789983640505, 4.996359502569846, 5.018491960157771, 5.040478965687362, 5.062323040628314, 5.08402663618085, 5.105592135958486, 5.127021858541315, 5.148318059907301, 5.169482935748623, 5.19051862367963, 5.211427205342488, 5.232210708416273], [0.0, 0.8312587308087808, 1.096852471201222, 1.289985182184106, 1.4473055127008105, 1.5824289569960974, 1.7021456526717411, 1.810403730235845, 1.9097310733139392, 2.0018577953888035, 2.088027526992451, 2.1691685236091613, 2.245994653988053, 2.3190684135326762, 2.3888420437389546, 2.455685372949893, 2.5199052586865527, 2.5817595272288303, 2.6414671972579122, 2.69921612781781, 2.755168839778102, 2.8094670157663533, 2.862235026701848, 2.9135827298090606, 2.963607713490866, 3.012397116723681, 3.060029117279912, 3.1065741593820744, 3.152095974300439, 3.196652434910518, 3.2402962759766694, 3.2830757050011754, 3.325034923235123, 3.3662145724393926, 3.4066521198917292, 3.4463821917293855, 3.4854368628289203, 3.5238459099324118, 3.5616370335413796, 3.5988360531475996, 3.6354670796021824, 3.671552667801366, 3.7071139523592187, 3.7421707685206402, 3.776741760224355, 3.8108444769409813, 3.84449546067434, 3.8777103243162356, 3.9105038223787667, 3.9428899149882373, 3.9748818259063547, 4.006492095243872, 4.037732627446241, 4.068614735057678, 4.099149178707302, 4.129346203707088, 4.159215573604823, 4.188766600995024, 4.218008175855863, 4.246948791649802, 4.275596569399164, 4.303959279924749, 4.3320443644153475, 4.35985895347821, 4.387409884804889, 4.414703719573063, 4.441746757692775, 4.468545051994678, 4.495104421448387, 4.5214304634904225, 4.54752856553375, 4.573403915724097, 4.59906151300222, 4.62450617652589, 4.649742554500525, 4.6747751324630356, 4.699608241059554, 4.72424606335422, 4.748692641702958, 4.77295188422341, 4.797027570889512, 4.820923359276901, 4.844642789983227, 4.868189291745452, 4.891566186274559, 4.914776692826407, 4.937823932526066, 4.960710932461645, 4.983440629562382, 5.006015874274689, 5.028439434048817, 5.050713996647904, 5.072842173290273, 5.094826501635122, 5.116669448620999, 5.138373413165796, 5.159940728736424, 5.181373665795714, 5.202674434133643, 5.2238451850894565, 5.244888013670841, 5.2658049605759105], [0.0, 0.8365116420730188, 1.103783729168972, 1.2981368892796838, 1.4564513624208644, 1.5924286822139893, 1.7129018946706596, 1.8218440794254671, 1.9217990943702903, 2.01450798596493, 2.101222243523014, 2.1828759883844313, 2.260187600395814, 2.3337231294959384, 2.4039376749966648, 2.471203402269648, 2.535829107937782, 2.5980742475433334, 2.6581592237958964, 2.71627308286312, 2.772579372620586, 2.8272206710203145, 2.880322134909458, 2.9319943157250514, 2.982335418553082, 3.031433133020797, 3.0793661309235665, 3.1262053016368228, 3.1720147791630984, 3.2168528020896483, 3.260772438423692, 3.3038222003015822, 3.346046568292075, 3.387486440980496, 3.4281795224087634, 3.468160657524494, 3.507462123892622, 3.5461138864211676, 3.5841438206573644, 3.6215779092521743, 3.658440415418611, 3.6947540365823857, 3.730540040911955, 3.7658183889956014, 3.800607842587301, 3.8349260620567316, 3.8687896939403643, 3.902214449791386, 3.935215177358982, 3.9678059249866413, 4.000000000000001, 4.031810021753601, 4.063247969919766, 4.094325228529229, 4.12505262620995, 4.1554404730163395, 4.185498594194244, 4.215236361186562, 4.244662720149242, 4.273786218216852, 4.3026150277302815, 4.3311569686159, 4.359419529085048, 4.387409884804889, 4.415134916675889, 4.442601227337289, 4.469815156509682, 4.496782795272923, 4.523509999368006, 4.550002401602915, 4.576265423434894, 4.6023042857947285, 4.628124019212612, 4.653729473299658, 4.6791253256343435, 4.704316090098695, 4.729306124705177, 4.754099638951652, 4.778700700738603, 4.803113242879949, 4.827341069236132, 4.851387860495835, 4.875257179630542, 4.898952477044176, 4.922477095438361, 4.945834274412159, 4.969027154813732, 4.992058782860044, 5.014932114039447, 5.037650016810968, 5.060215276113001, 5.082630596693263, 5.104898606270956, 5.127021858541315, 5.1490028360320315, 5.1708439528203005, 5.192547557118735, 5.214115933737734, 5.235551306431434, 5.256855840133878, 5.278031643091578, 5.29908076889828], [0.0, 0.8417155348343195, 1.110650306834322, 1.3062125272284384, 1.4655118659702302, 1.6023350931656943, 1.7235577628285792, 1.8331776709026233, 1.9337545004792644, 2.0270401289722484, 2.1142938311411563, 2.1964555394431833, 2.2742481027263417, 2.3482410922948396, 2.418892438608241, 2.4865766222584385, 2.551604360875076, 2.614236724059031, 2.6746954856329896, 2.733170867810378, 2.7898274358890855, 2.8448086547907043, 2.8982404599562255, 2.950234090557073, 3.000888362607654, 3.0502915112475484, 3.098522697685023, 3.1456532522944034, 3.1917477080523113, 3.23686466584504, 3.2810575238129527, 3.3243750958837257, 3.366862139337278, 3.4085598071867778, 3.449506038028907, 3.4897358935797795, 3.529281852201278, 3.5681740652114637, 3.60644058156981, 3.644107545563917, 3.681199371346908, 3.7177388975439256, 3.7537475246315295, 3.789245337371721, 3.824251214234311, 3.858782925453163, 3.892857221121933, 3.9264899105345137, 3.959695933807117, 3.992489426677203, 4.024883779254547, 4.056891689397997, 4.088525211304757, 4.119795799824989, 4.150714350950949, 4.181291238875326, 4.21153634996628, 4.241459113965938, 4.271068532683791, 4.300373206425659, 4.329381358372115, 4.358100857096857, 4.386539237394975, 4.414703719573063, 4.442601227337289, 4.470238404401549, 4.497621629925485, 4.524757032881226, 4.551650505438007, 4.5783077154452005, 4.604734118086634, 4.63093496677222, 4.6569153233268, 4.682680067530649, 4.708233906061204, 4.733581380881102, 4.758726877113761, 4.783674630444099, 4.808428734078784, 4.832993145297552, 4.857371691624451, 4.881568076645526, 4.905585885497309, 4.929428590048496, 4.953099553795473, 4.976602036490669, 4.99993919852129, 5.0231141050546455, 5.04612972996502, 5.068988959555964, 5.091694596090821, 5.114249361143392, 5.136655898779777, 5.158916778581609, 5.181034498520245, 5.203011487690722, 5.224850108913754, 5.2465526612134195, 5.268121382177706, 5.2895584502085935, 5.310865986667878, 5.332046057924599], [0.0, 0.846871610245124, 1.1174537891274203, 1.3142139600334692, 1.4744891146767767, 1.6121504764297885, 1.734115716712335, 1.8444071206649324, 1.9456000511645282, 2.0394571170557168, 2.1272453070053965, 2.2099103111910727, 2.2881794063975334, 2.362625652937415, 2.4337097864032344, 2.5018085813331057, 2.5672346587117425, 2.6302506873674263, 2.6910797996370985, 2.749913382973554, 2.8069170107481347, 2.862235026701848, 2.915994137715209, 2.9683062643746, 3.0192708280091707, 3.068976604258247, 3.1175032392458943, 3.1649225002930934, 3.211299315684479, 3.2566926452762988, 3.3011562143085453, 3.3447391357271283, 3.387486440980496, 3.4294395351717815, 3.4706365892971616, 3.511112879849411, 3.5509010841422874, 3.5900315381910124, 3.628532462773856, 3.6664301623298154, 3.7037492005651687, 3.740512556007044, 3.776741760224355, 3.8124570210118165, 3.847677332482603, 3.8824205737252457, 3.9167035974390227, 3.950542309760416, 3.9839517423239275, 4.016946117457942, 4.049538907295691, 4.081742887478972, 4.113570186045081, 4.145032328012858, 4.176140276119865, 4.206904468107719, 4.237334850905252, 4.267440912018124, 4.297231708397979, 4.326715893033313, 4.3559017394772255, 4.384797164503737, 4.413409749063639, 4.441746757692775, 4.469815156509682, 4.497621629925485, 4.525172596176484, 4.552474221778893, 4.579532434995461, 4.606352938394959, 4.632941220577897, 4.659302567134865, 4.685442070897795, 4.711364641538912, 4.737075014567223, 4.762577759767951, 4.787877289126356, 4.812977864273777, 4.837883603490538, 4.862598488297382, 4.887126369664523, 4.9114709738649704, 4.935635907996633, 4.959624665195747, 4.983440629562382, 5.007087080817147, 5.030567198706754, 5.053884067174729, 5.0770406783123425, 5.100039936103701, 5.122884659977901, 5.1455775881802195, 5.168121380973444, 5.19051862367963, 5.212771829571891, 5.2348834426251125, 5.256855840133877, 5.278691335205338, 5.300392179134218, 5.321960563666678, 5.3433986231592865, 5.364708436638987], [0.0, 0.851981022349263, 1.1241956988182304, 1.322142978592587, 1.483385117847517, 1.6218770289063553, 1.744578119425756, 1.8555349421118665, 1.957338397722581, 2.051761729412176, 2.140079569942774, 2.223243315103901, 2.301984629543584, 2.376880031006806, 2.4483930348321326, 2.5169026887433215, 2.5827234998544872, 2.6461197217480508, 2.7073158329804405, 2.766504375698215, 2.8238519222229437, 2.8795036871615936, 2.9335871418525516, 2.9862148821302448, 3.0374869291603694, 3.0874925941903903, 3.136312003871603, 3.184017358517209, 3.2306739781422533, 3.276341178324205, 3.3210730084423803, 3.36491887775476, 3.407924089397052, 3.4501302982808997, 3.491575905698723, 3.5322964009761946, 3.5723246585783994, 3.6116911975461825, 3.6504244089216216, 3.688550755845715, 3.7260949502244176, 3.7630801092207053, 3.7995278943094397, 3.8354586352045854, 3.8708914406160866, 3.9058442975019916, 3.9403341602386037, 3.974377030928552, 4.007988031896373, 4.041181471277718, 4.073970902486945, 4.106369178244856, 4.138388499760568, 4.170040461586572, 4.2013360926016725, 4.232285893521288, 4.26289987128684, 4.293187570644751, 4.323158103189774, 4.352820174116293, 4.382182106894056, 4.411251866061184, 4.440037078306456, 4.468545051994678, 4.496782795272923, 4.524757032881226, 4.552474221778893, 4.5799405656864485, 4.607162028633498, 4.634144347593998, 4.660893044282712, 4.68741343617967, 4.7137106468432775, 4.739789615567175, 4.765655106431016, 4.791311716790808, 4.8167638852505466, 4.842015899153179, 4.86707190162576, 4.891935898210654, 4.916611763112053, 4.941103245084606, 4.9654139729888485, 4.989547461036078, 5.013507113743583, 5.037296230619441, 5.0609180105946585, 5.084375556219053, 5.107671877636012, 5.130809896350187, 5.1537924488010765, 5.176622289754552, 5.199302095523507, 5.221834467027963, 5.244221932704313, 5.26646695127262, 5.288571914370348, 5.3105391490602685, 5.332370920219792, 5.354069432818494, 5.375636834090112, 5.397075215604934], [0.0, 0.8570448806021908, 1.1308774998420013, 1.3300013046093278, 1.492201807156593, 1.6315168626146401, 1.7549472427702777, 1.866563551533588, 1.9689720890127336, 2.063956637859639, 2.152799406779391, 2.2364574463041613, 2.3156667698244604, 2.3910073216922774, 2.4629453722089183, 2.531862222016803, 2.598074247543333, 2.6618472729959186, 2.723407111148019, 2.7829474485450856, 2.8406358475526003, 2.8966183858791332, 2.9510232925052864, 3.00396383249324, 3.05554062149729, 3.105843501597733, 3.15495307568887, 3.2029419732157076, 3.2498759024311585, 3.2958145314624194, 3.34081223093821, 3.38491870378676, 3.428179522408763, 3.470636589297161, 3.5123285339873704, 3.553291056740414, 3.5935572274149665, 3.633157746445699, 3.672121173620482, 3.7104741293673795, 3.7482414724707214, 3.785446457493301, 3.8221108746577284, 3.8582551745102247, 3.893898579335798, 3.929059183000284, 3.963754040650491, 3.997999249499594, 4.0318100217536, 4.065200750590396, 4.0981850699807945, 4.130775909037387, 4.162985541488738, 4.194825630801047, 4.2263072714046706, 4.257441026427372, 4.288236962288113, 4.318704680463735, 4.348853346704923, 4.378691717946495, 4.408228167129809, 4.437470706131238, 4.466427006969761, 4.495104421448387, 4.523509999368006, 4.551650505438007, 4.579532434995461, 4.607162028633498, 4.634545285829698, 4.661687977656455, 4.688595658647554, 4.7152736778881446, 4.741727189389158, 4.76796116180156, 4.7939803875209215, 4.8197894912282235, 4.845392937908871, 4.8707950403881854, 4.895999966418425, 4.92101174534941, 4.945834274412158, 4.970471324642524, 4.99492654646964, 5.019203474991967, 5.043305534961979, 5.067236045498801, 5.090998224546695, 5.114595193095881, 5.13802997918092, 5.1613055216708, 5.18442467386376, 5.2073902068989755, 5.230204812996348, 5.2528711085348, 5.275391636978809, 5.297768871662157, 5.320005218437311, 5.3421030181982365, 5.364064549283935, 5.3858920297695, 5.407587619651025, 5.4291534229303196], [0.0, 0.8620642522214543, 1.1375006004007284, 1.3377905942405182, 1.500941040737678, 1.64107200916753, 1.7652252720579351, 1.877495273230049, 1.9805035768570673, 2.076044412497747, 2.1654074982445235, 2.249555489694587, 2.3292287107766794, 2.405010502346622, 2.477369865465766, 2.546690333903018, 2.613290136976913, 2.6774366557217126, 2.7393570254066426, 2.799246066922357, 2.857272323980591, 2.9135827298090606, 2.9683062643746, 3.021556856087893, 3.0734357098691785, 3.124033193968149, 3.17343038333826, 3.221700332786342, 3.2689091353924593, 3.3151168087363416, 3.360378041873896, 3.4047428288236707, 3.4482570088858173, 3.490962729959545, 3.532898847818122, 3.5741012718048273, 3.6146032654553695, 3.654435709004677, 3.6936273295039603, 3.7322049032865614, 3.770193434724842, 3.8076163145743367, 3.8444954606743393, 3.8808514433418013, 3.9167035974390227, 3.952070122800428, 3.98696817445805, 4.02141394390005, 4.055422732424287, 4.089009017503776, 4.122186512958084, 4.154968223620482, 4.187366495101893, 4.219393059176802, 4.251059075251245, 4.282375168317028, 4.313351463748132, 4.343997619253439, 4.374322854263795, 4.404335976999909, 4.434045409440134, 4.46345921038322, 4.4925850967801155, 4.5214304634904225, 4.550002401602915, 4.5783077154452005, 4.606352938394959, 4.634144347593998, 4.661687977656455, 4.688989633453606, 4.716054902049932, 4.742889163858054, 4.769497603073896, 4.795885217447844, 4.822056827442622, 4.848017084824137, 4.873770480727435, 4.899321353236348, 4.9246738945120025, 4.949832157502522, 4.9748000622634585, 4.999581401916126, 5.02417984826877, 5.048598957123524, 5.072842173290273, 5.096912835326907, 5.1208141800239115, 5.144549346649904, 5.168121380973444, 5.191533239075309, 5.214787790964369, 5.237887824009266, 5.260836046197162, 5.283635089230073, 5.306287511468541, 5.328795800731677, 5.351162376962073, 5.373389594763382, 5.395479745817932, 5.417435061191201, 5.439257713529524, 5.46094981915701], [0.0, 0.8670401643811235, 1.144066355858723, 1.3455124415016926, 1.5096046070047022, 1.6505444239489884, 1.7754143106048346, 1.8883323442902544, 1.9919352210819108, 2.088027526992451, 2.17790642448278, 2.2625401256845117, 2.3426732277424835, 2.4188924386082413, 2.4916694664593155, 2.5613900588559146, 2.6283742819647355, 2.692891060167342, 2.7551688397781016, 2.815403566211316, 2.8737647560281374, 2.930400190568047, 2.9854395942818117, 3.038997553185117, 3.091175856362077, 3.142065393676023, 3.191747708052312, 3.240296275976669, 3.2877775720243436, 3.3342519602019167, 3.3797744452354292, 3.4243953097133875, 3.468160657524494, 3.5111128798494113, 3.5532910567404143, 3.5947313048127314, 3.6354670796021824, 3.6755294395871796, 3.7149472776340495, 3.7537475246315304, 3.791955329279464, 3.829594217346923, 3.8666862331849345, 3.903252065844164, 3.9393111617894703, 3.9748818259063543, 4.009981312247231, 4.044625905758985, 4.078830996059937, 4.112611144188374, 4.14598014312126, 4.178951072756931, 4.21153634996628, 4.243747774240649, 4.275596569399164, 4.30709342176204, 4.3382485151478205, 4.36907156301055, 4.399571837996458, 4.429758199168092, 4.459639117116218, 4.489222697155697, 4.518516700780411, 4.54752856553375, 4.576265423434894, 4.604734118086634, 4.632941220577897, 4.660893044282712, 4.688595658647554, 4.716054902049932, 4.7432763938033675, 4.770265545376704, 4.797027570889512, 4.823567496939636, 4.849890171813946, 4.876000274128758, 4.901902320942355, 4.9276006753783745, 4.953099553795474, 4.978403032535757, 5.003515054281688, 5.028439434048816, 5.053179864839396, 5.077739922979966, 5.102123073164165, 5.126332673220339, 5.150371978622016, 5.174244146757957, 5.197952240977167, 5.221499234423188, 5.244888013670841, 5.268121382177707, 5.291202063561694, 5.314132704715237, 5.336915878765963, 5.359554087892903, 5.38204976600677, 5.4044052813022025, 5.426622938689324, 5.448704982111521, 5.47065359675584, 5.492470911162002], [0.0, 0.8719736062626094, 1.150576071448682, 1.3531683814496451, 1.5181942282225347, 1.659935990018105, 1.7855163839305601, 1.8990769190587549, 2.0032692942293835, 2.0999083635148423, 2.1902986702055256, 2.2754139355414766, 2.356002993410986, 2.4326558901225748, 2.5058470178642427, 2.575964319092407, 2.6433296811441043, 2.708213558575465, 2.7708456975559974, 2.8314231584256464, 2.8901164222915416, 2.9470741113661467, 3.002426688229863, 3.0562893908906035, 3.1087645876104153, 3.159943685414207, 3.209908691205014, 3.2587334995483546, 3.3064849632585345, 3.353223789812172, 3.3990052969111435, 3.443880053250917, 3.487894425050438, 3.53109104469537, 3.5735092146027374, 3.6151852568906144, 3.656152817456177, 3.6964431314999837, 3.7360852562882143, 3.7751062759458476, 3.8135314822683437, 3.8513845348859506, 3.8886876035816282, 3.9254614951263433, 3.9617257666349666, 3.997498827147445, 4.032798028891421, 4.067639749474814, 4.102039466082577, 4.136011822605027, 4.1695706905009, 4.202729224092901, 4.235499910903684, 4.267894617563467, 4.299924631754692, 4.3316007006025306, 4.362933065871259, 4.393931496284288, 4.424605317249026, 4.454963438235916, 4.485014378033224, 4.514766288074894, 4.544226974017562, 4.573403915724097, 4.6023042857947285, 4.63093496677222, 4.659302567134865, 4.68741343617967, 4.7152736778881446, 4.742889163858054, 4.770265545376704, 4.797408264704094, 4.824322565628032, 4.851013503347611, 4.877485953736358, 4.903744622031827, 4.929794050994275, 4.955638628573428, 4.981282595118947, 5.00673005016724, 5.0319849588345615, 5.057051157843825, 5.081932361210396, 5.106632165610043, 5.131154055450447, 5.15550140766593, 5.179677496253603, 5.203685496567708, 5.227528489387648, 5.251209464774093, 5.274731325726421, 5.298096891653831, 5.321308901671566, 5.344370017732828, 5.367282827606291, 5.390049847708335, 5.4126735257985805, 5.435156243546646, 5.45750031897755, 5.479708008802674, 5.501781510642736, 5.523722965148809], [0.0, 0.8768655309731553, 1.1570310048031527, 1.360759893159633, 1.5267115638472706, 1.6692485217612372, 1.7955334436866142, 1.909731073313939, 2.01450798596493, 2.111689217361314, 2.2025866295099124, 2.2881794063975334, 2.369220583001784, 2.4463035158943596, 2.5199052586865527, 2.590415930259933, 2.658159223795896, 2.7234071111480196, 2.7863906274020755, 2.847307938441044, 2.9063304818009352, 2.9636077134908656, 3.0192708280091707, 3.0734357098691785, 3.1262053016368228, 3.1776715231464374, 3.227916841374152, 3.277015565446945, 3.325034923235123, 3.3720359627948855, 3.418074312170108, 3.463200823755501, 3.5074621238926214, 3.550901084142287, 3.593557227414967, 3.635467079602182, 3.676664475360487, 3.7171808251253875, 3.7570453491794185, 3.796285283594245, 3.834926062056731, 3.872991476931796, 3.9105038223787663, 3.9474840218982394, 3.9839517423239275, 4.019925495973716, 4.055422732424287, 4.090459921164807, 4.12505262620995, 4.159215573604823, 4.192962712629476, 4.2263072714046706, 4.2592618075102475, 4.291838254150303, 4.324047962333154, 4.3559017394772255, 4.387409884804888, 4.418582221843802, 4.449428128318544, 4.479956563683249, 4.510176094518076, 4.540094917987945, 4.569720883540588, 4.59906151300222, 4.628124019212612, 4.6569153233268, 4.685442070897795, 4.7137106468432775, 4.741727189389158, 4.769497603073896, 4.797027570889512, 4.824322565628032, 4.851387860495836, 4.878228539052569, 4.904849504526263, 4.931255488551678, 4.957451059374753, 4.983440629562382, 5.009228463253327, 5.034818682983117, 5.060215276113, 5.0854221008905816, 5.110442892167501, 5.1352812667975085, 5.159940728736423, 5.184424673863759, 5.208736394544328, 5.232879083946662, 5.256855840133877, 5.2806696699414095, 5.304323492654969, 5.327820143501138, 5.3511623769620735, 5.374352869925001, 5.397394224676432, 5.420288971750282, 5.443039572638532, 5.465648422372385, 5.488117851981384, 5.5104501308374605, 5.532647468890367, 5.554712018800605], [0.0, 0.88171685734225, 1.1634323683249144, 1.3682884025131314, 1.535158213653968, 1.6784837683117606, 1.805467371334883, 1.920296808180453, 2.025653407204396, 2.123372301279721, 2.214772610391266, 2.3008389359369783, 2.3823284791187205, 2.459837879299312, 2.533846829426047, 2.6047476067433797, 2.6728656952902674, 2.738474571625602, 2.801806549054637, 2.863060889828427, 2.9224099799744083, 2.980004102378629, 3.0359751773831314, 3.090439730641278, 3.14350127425671, 3.1952522366173532, 3.2457755409542624, 3.2951459075154066, 3.3434309361144856, 3.390692012560791, 3.436985072664654, 3.482361250165591, 3.526867429369, 3.5705467190259257, 3.613438860710395, 3.6555805823962495, 3.697005905932897, 3.7377464155365083, 3.7778314931530907, 3.8172885255399827, 3.8561430870978874, 3.8944191018248233, 3.9321389872242785, 3.9693237825577348, 4.005993263467182, 4.04216604469134, 4.077859672348019, 4.11309070704511, 4.147874798906402, 4.182226755449985, 4.216160603131382, 4.249689643256952, 4.28282650288232, 4.315583181232955, 4.347971092117508, 4.38000110274728, 4.411683569325887, 4.443028369730415, 4.474044933568429, 4.504742269862936, 4.535128992589361, 4.565213344264073, 4.595003217762484, 4.62450617652589, 4.653729473299658, 4.682680067530649, 4.711364641538912, 4.739789615567175, 4.76796116180156, 4.795885217447844, 4.823567496939636, 4.851013503347611, 4.878228539052569, 4.905217715739342, 4.931985963763452, 4.9585380409377935, 4.9848785407824785, 5.011011900277269, 5.036942407152605, 5.062674206752262, 5.088211308497873, 5.113557591983095, 5.138716812722924, 5.163692607581636, 5.188488499900952, 5.213107904348355, 5.237554131503918, 5.261830392202627, 5.285939801647871, 5.309885383310635, 5.333670072627804, 5.3572967205120685, 5.380768096684974, 5.40408689284383, 5.4272557256725, 5.450277139705273, 5.473153610052526, 5.495887544996156, 5.5184812884623105, 5.540937122378392, 5.563257268920875, 5.5854438926600185], [0.0, 0.8865284716052917, 1.1697813314085854, 1.3757552848106207, 1.5435357206680773, 1.6876434167551813, 1.8153199815952303, 1.9307760537960645, 2.0367075939820687, 2.1349597495240267, 2.2268588389722583, 2.313394836789874, 2.395329076299011, 2.473261452781261, 2.5476742769147784, 2.6189619666389232, 2.6874517821905672, 2.7534186925166653, 2.8170962786786697, 2.878684890321034, 2.9383578541984376, 2.9962662733051872, 3.0525427878854074, 3.107304559484232, 3.1606556650808746, 3.212689037453924, 3.263488052354535, 3.313127837786306, 3.3616763624616635, 3.4091953471782057, 3.455741032993396, 3.5013648326885196, 3.5461138864211668, 3.590031538191012, 3.633157746445699, 3.675529439587179, 3.717180825125387, 3.7581436596346185, 3.7984474854010055, 3.8381198386340727, 3.877186433296505, 3.9156713239418934, 3.9535970504082134, 3.9909847667702345, 4.02785435658754, 4.064224536181279, 4.100112947420127, 4.135536241284817, 4.170510153303377, 4.205049571799959, 4.239168599773808, 4.272880611117803, 4.306198301794635, 4.339133736510706, 4.371698391360925, 4.403903192860021, 4.435758553726412, 4.467274405741719, 4.498460229971786, 4.529325084602731, 4.5598776306172795, 4.590126155512008, 4.620078595234513, 4.649742554500525, 4.6791253256343435, 4.708233906061204, 4.737075014567223, 4.765655106431016, 4.7939803875209215, 4.822056827442622, 4.849890171813946, 4.877485953736358, 4.904849504526263, 4.931985963763452, 4.9589002887088744, 4.985597263139269, 5.012081505642034, 5.038357477409959, 5.064429489572044, 5.090301710093605, 5.115978170276081, 5.141462770884444, 5.166759287927901, 5.191871378117446, 5.216802584022019, 5.2415563389432736, 5.266135971527439, 5.2905447101313365, 5.314785686958325, 5.338861941978761, 5.3627764266484945, 5.386532007437922, 5.410131469183226, 5.433577518270572, 5.456872785663317, 5.480019829781523, 5.503021139242483, 5.525879135470322, 5.548596175182217, 5.571174552758272, 5.593616502501593, 5.615924200794708], [0.0, 0.8913012289830018, 1.1760790225246736, 1.3831618672225918, 1.5518455739153596, 1.6967290951357943, 1.8250930256796176, 1.9411706727514768, 2.0476725110792193, 2.146453621657883, 2.2388474634702153, 2.325849340653525, 2.4082246852806923, 2.4865766222584385, 2.5613900588559146, 2.6330615364198957, 2.701920077041227, 2.7682421300029283, 2.8322625338847063, 2.8941827169430074, 2.9541769390627772, 3.0123971167236805, 3.0689766042582467, 3.124033193968149, 3.177671523146437, 3.229985024889084, 3.2810575238129527, 3.3309645523843803, 3.379774445235429, 3.4275492554467535, 3.474345526857884, 3.5202149490384302, 3.565204915932007, 3.609359004887131, 3.652717389473671, 3.6953171969031002, 3.737192818846552, 3.7783761828445455, 3.8188969902284864, 3.8587829254531636, 3.8980598409161895, 3.9367519206724086, 3.974881825906354, 4.012470824578891, 4.049538907295691, 4.086104891139992, 4.122186512958084, 4.1578005133737195, 4.192962712629476, 4.227688079203001, 4.261990792019129, 4.295884296971072, 4.329381358372115, 4.362494105880797, 4.395234077375283, 4.427612258194813, 4.459639117116218, 4.491324639390337, 4.522678357125735, 4.553709377274619, 4.584426407447396, 4.614837779757612, 4.64495147287721, 4.6747751324630356, 4.704316090098695, 4.733581380881102, 4.762577759767951, 4.791311716790808, 4.8197894912282235, 4.848017084824137, 4.876000274128758, 4.903744622031827, 4.931255488551678, 4.9585380409377935, 4.985597263139269, 5.012437964687018, 5.039064789033284, 5.0654822213883515, 5.091694596090821, 5.11770610354487, 5.143520796755042, 5.169142597486657, 5.194575302077629, 5.219822586925395, 5.24488801367084, 5.2697750340993075, 5.294486994777285, 5.319027141441931, 5.3433986231592865, 5.367604496265838, 5.391647728107036, 5.4155312005853435, 5.439257713529524, 5.462829987895971, 5.486250668812224, 5.509522328471979, 5.532647468890367, 5.555628524527611, 5.578467864788623, 5.601167796405641, 5.623730565710474, 5.646158360802529], [0.0, 0.8960359551643409, 1.182326531176294, 1.3905094310908042, 1.5600892110037952, 1.7057423752796417, 1.8347881943286328, 1.951482463319982, 2.058550055430951, 2.157855906125829, 2.2507405579220343, 2.338204602162149, 2.4210175370093454, 2.4997856912605605, 2.5749965480852905, 2.6470487553175843, 2.716273082863119, 2.782947448545085, 2.8473079384410434, 2.9095570508246347, 2.969869971275522, 3.0283994232765576, 3.0852794695585435, 3.1406285281535746, 3.1945517922037396, 3.2471431911356685, 3.298486994855198, 3.348659137068486, 3.397728315411437, 3.445756912600004, 3.4928017728430967, 3.538914860293093, 3.5841438206573635, 3.6285324627738555, 3.672121173620482, 3.7149472776340486, 3.757045349179418, 3.7984474854010055, 3.839183545408157, 3.8792813607196495, 3.918766921064919, 3.9576645389681477, 3.9959969959934885, 4.033785673080413, 4.071050667027698, 4.107810894877756, 4.144084187697673, 4.179887375039913, 4.2152363611865615, 4.25014619413007, 4.284631128115855, 4.318704680463734, 4.352379683292945, 4.385668330696598, 4.418582221843801, 4.451132400429569, 4.48332939084245, 4.515183231376437, 4.546703504776089, 4.577899366371114, 4.608779570028055, 4.639352492121896, 4.669626153708488, 4.699608241059554, 4.729306124705177, 4.758726877113761, 4.787877289126356, 4.8167638852505466, 4.845392937908871, 4.873770480727435, 4.901902320942355, 4.929794050994275, 4.957451059374753, 4.9848785407824785, 5.012081505642034, 5.039064789033284, 5.0658330590751905, 5.092390824804148, 5.1187424435834155, 5.1448921280772275, 5.1708439528203, 5.196601860410957, 5.222169667353831, 5.247551069575936, 5.272749647638129, 5.297768871662156, 5.322612105991968, 5.347282613606572, 5.371783560300315, 5.3961180186454065, 5.420288971750281, 5.444299316826502, 5.468151868575943, 5.491849362409129, 5.515394457504914, 5.538789739720872, 5.562037724363217, 5.5851408588243885, 5.608101525095936, 5.6309220421638075, 5.65360466829266, 5.676151603205416], [0.0, 0.9007334477000151, 1.1885249097379127, 1.3977992140907904, 1.568268020549816, 1.7146847754472663, 1.8444071206649326, 1.9617131624923867, 2.06934205932763, 2.1691685236091613, 2.2625401256845117, 2.3504627025232234, 2.4337097864032344, 2.5128908848164686, 2.588496036576016, 2.6609259794378928, 2.73051321737788, 2.7975371252108125, 2.862235026701848, 2.9248104817272593, 2.9854395942818113, 3.044275888505313, 3.1014541299560294, 3.1570933574757647, 3.211299315684479, 3.2641664264363404, 3.3157794014244284, 3.3662145724393926, 3.4155409972663366, 3.4638213856642768, 3.5111128798494113, 3.5574677163975825, 3.6029337908000603, 3.647555141563799, 3.691372367396528, 3.7344229884094142, 3.776741760224355, 3.818360948255907, 3.8593105681505984, 3.8996185973346895, 3.9393111617894703, 3.978412701498183, 4.016946117457942, 4.0549329026983685, 4.092393259376244, 4.129346203707088, 4.165809660237828, 4.201800546750313, 4.237334850905252, 4.2724276995846004, 4.30709342176204, 4.3413456056222985, 4.375197150557345, 4.4086603145881496, 4.4417467576927745, 4.474467581463103, 4.506833365462072, 4.538854200609698, 4.570539719888341, 4.601899126624766, 4.632941220577896, 4.663674422036089, 4.694106794105793, 4.72424606335422, 4.754099638951652, 4.783674630444099, 4.812977864273777, 4.842015899153179, 4.8707950403881854, 4.899321353236348, 4.9276006753783745, 4.955638628573428, 4.983440629562382, 5.011011900277269, 5.038357477409959, 5.0654822213883515, 5.092390824804148, 5.119087820332486, 5.14557758818022, 5.17186436309659, 5.197952240977167, 5.223845185089456, 5.249547031946214, 5.275061496850453, 5.300392179134218, 5.325542567111459, 5.3505160427637914, 5.375315886176476, 5.399945279740624, 5.424407312136486, 5.448704982111521, 5.472841202066005, 5.496818801457958, 5.52064053003837, 5.544309060926911, 5.567826993537584, 5.591196856363162, 5.614421109626606, 5.637502147807119, 5.660442302047994, 5.683243842452905, 5.705908980276877], [0.0, 0.9053944773130435, 1.1946751751846505, 1.405032412265657, 1.5763833444601396, 1.7235577628285792, 1.853951382876857, 1.9718644488313057, 2.0800502934257867, 2.180393330182081, 2.274248102726342, 2.362625652937415, 2.4463035158943596, 2.525894353110387, 2.601890739204741, 2.6746954856329896, 2.7446428169808055, 2.8120135537451914, 2.8770462477717107, 2.9399455122988867, 3.0008883626076543, 3.060029117279912, 3.1175032392458943, 3.1734303833382604, 3.2279168413741526, 3.281057523812953, 3.332937580705738, 3.3836337388376334, 3.4332154133473893, 3.481745638498506, 3.5292818522012785, 3.575876561340403, 3.621577909252174, 3.666430162329815, 3.7104741293673795, 3.75374752463153, 3.7962852835942447, 3.838119838634073, 3.87928136071965, 3.919797972052155, 3.9596959338071174, 3.9989998124374755, 4.037732627446241, 4.075915983083116, 4.11357018604508, 4.150714350950949, 4.187366495101893, 4.223543623824281, 4.2592618075102475, 4.294536251318897, 4.329381358372116, 4.363810787169477, 4.397837503853493, 4.431473829876773, 4.464731485554323, 4.497621629925486, 4.530154897299313, 4.562341430813352, 4.5941909132978, 4.625712595703924, 4.6569153233268, 4.687807560027289, 4.718397410636037, 4.748692641702958, 4.778700700738603, 4.808428734078784, 4.837883603490538, 4.86707190162576, 4.895999966418425, 4.9246738945120025, 4.953099553795474, 4.981282595118947, 5.009228463253327, 5.036942407152605, 5.064429489572044, 5.091694596090821, 5.1187424435834155, 5.14557758818022, 5.172204432754367, 5.198627233968671, 5.2248501089137545, 5.250877041365861, 5.27671188769057, 5.302358382416487, 5.327820143501138, 5.3531006773094685, 5.37820338332385, 5.403131558603015, 5.42788840200601, 5.4524770181960935, 5.476900421438357, 5.501161539203887, 5.525263215592315, 5.54920821458378, 5.572999223130557, 5.596638854097847, 5.620129649062628, 5.643474080978789, 5.666674556716255, 5.689733419481297, 5.712652951124705, 5.735435374344096], [0.0, 0.9100197891323273, 1.200778310719987, 1.4122101819403912, 1.5844364800795352, 1.732362755891148, 1.8634225067443746, 1.9819379451577603, 2.0906764695821063, 2.1915321202824005, 2.2858663607267022, 2.3746953978175758, 2.4588007387614588, 2.5387981749233672, 2.6151827972966393, 2.688359475145493, 2.7586641404803354, 2.8263790484019777, 2.8917439694255216, 2.9549645620797533, 3.01621874594853, 3.0756616279679734, 3.1334293630962766, 3.1896422174365746, 3.2444070258099815, 3.297819183536878, 3.349964275667169, 3.400919420953587, 3.4507543891501022, 3.4995325365379992, 3.5473115944557443, 3.5941443380254925, 3.640079156529309, 3.68516054250038, 3.7294295132091744, 3.7729239755900252, 3.8156790435867864, 3.8577273152625438, 3.899099115717796, 3.9398227108192208, 3.9799244959005837, 4.019429162915373, 4.058359848964379, 4.096738268665099, 4.1345848324536085, 4.171918752597953, 4.208758138442756, 4.245120082188055, 4.281020736323429, 4.316475383685286, 4.351498500975518, 4.386103816469715, 4.420304362549419, 4.454112523612795, 4.487540079849429, 4.520598247305899, 4.553297714617846, 4.585648676740204, 4.617660865969023, 4.649343580515113, 4.680705710860763, 4.711755764105439, 4.742501886484245, 4.77295188422341, 4.803113242879949, 4.832993145297552, 4.862598488297382, 4.891935898210654, 4.92101174534941, 4.949832157502522, 4.978403032535757, 5.00673005016724, 5.034818682983117, 5.062674206752262, 5.090301710093605, 5.11770610354487, 5.1448921280772275, 5.17186436309659, 5.198627233968671, 5.225185019101938, 5.251541856619644, 5.277701750649612, 5.303668577258107, 5.329446090052007, 5.355037925471587, 5.380447607794461, 5.405678553869649, 5.430734077599286, 5.455617394184158, 5.480331624148054, 5.504879797154784, 5.529264855630758, 5.5534896582050175, 5.577556982977811, 5.601469530628018, 5.625229927368964, 5.648840727761565, 5.672304417393077, 5.695623415429198, 5.71880007704674, 5.7418366957535865, 5.764735505602264], [0.0, 0.9146101038546528, 1.2068352673090326, 1.4193336415251105, 1.592428682213989, 1.7411011265922482, 1.8728219680184826, 1.9919352210819108, 2.101222243523014, 2.2025866295099124, 2.29739670999407, 2.3866738178209848, 2.471203402269648, 2.5516043608750762, 2.628374281964735, 2.701920077041227, 2.772579372620586, 2.8406358475526003, 2.9063304818009352, 2.9698699712755223, 3.0314331330207964, 3.091175856362077, 3.1492349830493347, 3.2057313858310446, 3.2607724384236914, 3.3144540173399872, 3.366862139337278, 3.4180743121701074, 3.468160657524494, 3.517184851262983, 3.565204915932007, 3.612273892861582, 3.658440415418611, 3.7037492005651687, 3.748241472470722, 3.791955329279464, 3.834926062056731, 3.8771864332965054, 3.91876692106492, 3.959695933807118, 4.0, 4.039703936148015, 4.078830996059936, 4.117403003885965, 4.1554404730163395, 4.192962712629476, 4.229987923417016, 4.266533283795337, 4.3026150277302815, 4.3382485151478205, 4.3734482957731124, 4.40822816712981, 4.442601227337289, 4.476579923263003, 4.510176094518076, 4.543401013724981, 4.576265423434893, 4.608779570028056, 4.640953234892091, 4.672795763139776, 4.704316090098695, 4.735522765779761, 4.766423977509256, 4.797027570889512, 4.827341069236132, 4.857371691624451, 4.887126369664523, 4.916611763112053, 4.945834274412158, 4.9748000622634585, 5.003515054281688, 5.0319849588345615, 5.060215276113, 5.088211308497873, 5.115978170276081, 5.143520796755042, 5.1708439528203, 5.197952240977167, 5.2248501089137545, 5.251541856619644, 5.278031643091578, 5.3043234926549685, 5.330421300927705, 5.356328840450579, 5.382049766006769, 5.407587619651025, 5.432945835467608, 5.458127744074614, 5.483136576890917, 5.507975470180829, 5.532647468890367, 5.557155530288106, 5.581502527422561, 5.605691252407252, 5.629724419543802, 5.653604668292662, 5.677334566100442, 5.70091661109218, 5.724353234636311, 5.74764680378961, 5.770799623628855, 5.793813939475564], [0.0, 0.9191661188401216, 1.2128469651239586, 1.4264038732150022, 1.6003611650379599, 1.7497742024641845, 1.882151194664292, 2.001857795388803, 2.1116892173613135, 2.2135585372644266, 2.3088409022178236, 2.398562732707876, 2.4835133906301867, 2.5643148564798586, 2.6414671972579113, 2.7153793514453235, 2.786390627402075, 2.8547861170884006, 2.920808000879288, 2.9846640043142996, 3.0465338351924447, 3.106574159382074, 3.164922500293093, 3.221700332786342, 3.277015565446945, 3.3309645523843803, 3.383633738837633, 3.4351010186563586, 3.48543686282892, 3.5347052644111465, 3.5829645349814756, 3.6302679800886244, 3.6766644753604862, 3.722198960511047, 3.766912865062779, 3.8108444769409804, 3.854029263008983, 3.896500148963004, 3.9382877646918217, 3.9794206601536706, 4.019925495973715, 4.059827212276695, 4.0991491787073, 4.137913328129988, 4.176140276119864, 4.213849428041585, 4.251059075251244, 4.287786481737334, 4.324047962333153, 4.359858953478209, 4.3952340773752825, 4.430187200278651, 4.4647314855543225, 4.498879442072251, 4.532642968421094, 4.566033393376469, 4.599061513002218, 4.63173762471964, 4.664071558641102, 4.6960727064308845, 4.727750047926781, 4.759112175730507, 4.790167317952476, 4.820923359276901, 4.851387860495835, 4.881568076645526, 4.9114709738649704, 4.941103245084606, 4.970471324642524, 4.999581401916126, 5.028439434048816, 5.057051157843825, 5.0854221008905816, 5.113557591983095, 5.141462770884444, 5.169142597486657, 5.196601860410957, 5.223845185089456, 5.250877041365861, 5.277701750649612, 5.3043234926549685, 5.330746311754013, 5.356974122970165, 5.383010717636652, 5.408859768742496, 5.434524835986743, 5.4600093705601145, 5.485316719671759, 5.51045013083746, 5.5354127559444315, 5.560207655106708, 5.584837800324122, 5.609306078956921, 5.633615297027185, 5.657768182357489, 5.681767387556422, 5.705615492860009, 5.729315008837381, 5.752868378968528, 5.776277982101421, 5.799546134795288, 5.822675093556433], [0.0, 0.9236885091455963, 1.218814294907635, 1.433421924594071, 1.608235103893712, 1.758383268581612, 1.8914115689771838, 2.011707138289115, 2.1220789419704205, 2.2244494692345453, 2.320200633064136, 2.4103639040382103, 2.4957325277927658, 2.576931545029871, 2.654463483130788, 2.728739292595198, 2.800099951214543, 2.868831953630348, 2.9351786717695485, 2.9993488532023798, 3.0615230899084045, 3.121858818567898, 3.180494239219856, 3.237551424393725, 3.2931388135957866, 3.3473532350074864, 3.400281559187132, 3.45200206323, 3.502585564848846, 3.552096371951811, 3.600593083016195, 3.6481292658594113, 3.694754036582385, 3.740512556007044, 3.785446457493301, 3.8295942173469224, 3.8729914769317957, 3.9156713239418934, 3.957664538968148, 3.9989998124374755, 4.0397039361480145, 4.079801972932441, 4.119317407416463, 4.158272280376448, 4.196687308818218, 4.234581993582788, 4.271974716021572, 4.308882825063635, 4.3453227158129035, 4.381309900657732, 4.416859073743618, 4.45198416954821, 4.4866984162026124, 4.521014384121683, 4.554944030436339, 4.588498739660921, 4.621689360976999, 4.654526242470223, 4.687019262618111, 4.71917785929288, 4.7510110565140335, 4.782527489159759, 4.813735425823604, 4.844642789983227, 4.875257179630542, 4.905585885497309, 4.935635907996633, 4.9654139729888485, 4.99492654646964, 5.02417984826877, 5.053179864839396, 5.081932361210396, 5.110442892167501, 5.138716812722924, 5.166759287927901, 5.194575302077629, 5.222169667353831, 5.249547031946214, 5.27671188769057, 5.303668577258107, 5.330421300927705, 5.356974122970165, 5.383330977671218, 5.409495675017833, 5.435471906070513, 5.46126324804238, 5.486873169104365, 5.512305032934225, 5.537562103025848, 5.562647546774051, 5.5875644393489425, 5.612315767372892, 5.636904432412253, 5.661333254295017, 5.6856049742649235, 5.709722257981664, 5.733687698376284, 5.75750381837017, 5.781173073465481, 5.80469785421436, 5.828080488573741, 5.851323244152168], [0.0, 0.9281779285003758, 1.2247381192610436, 1.4403888101492355, 1.6160516369900635, 1.7669295694188853, 1.900604429580673, 2.021484673544087, 2.132392919225875, 2.235260999747302, 2.3314775446267633, 2.4220790377177024, 2.507862580081702, 2.5894562503170464, 2.667365018247584, 2.74200183172287, 2.8137093257946466, 2.882775387559337, 2.949444571808694, 3.0139266406924046, 3.076403063924378, 3.1370320433771273, 3.1959524507857076, 3.253286951990806, 3.3091445135491266, 3.3636224342578127, 3.416808006893659, 3.468779889003473, 3.519609242496573, 3.569360687837946, 3.6180931083120935, 3.665860332093023, 3.7127117140015033, 3.75869263435539, 3.8038449288659413, 3.848207260845983, 3.8918154448877433, 3.934702729501892, 3.9769000448828025, 4.018436220901973, 4.059338179574186, 4.0996311055454395, 4.139338597584176, 4.178482803591934, 4.21708454126576, 4.255163406226945, 4.292737869166105, 4.32982536333361, 4.366442363518794, 4.402604457505142, 4.438326410856363, 4.473622225776093, 4.508505194688349, 4.542987949104197, 4.577082504270005, 4.610800300032469, 4.644152238303622, 4.677148717464097, 4.709799664003948, 4.742114561666447, 4.774102478330697, 4.805772090843132, 4.837131707985294, 4.868189291745452, 4.898952477044176, 4.929428590048496, 4.959624665195747, 4.989547461036078, 5.019203474991967, 5.048598957123524, 5.077739922979966, 5.106632165610043, 5.1352812667975085, 5.163692607581636, 5.191871378117446, 5.219822586925395, 5.247551069575936, 5.275061496850453, 5.302358382416487, 5.329446090052007, 5.356328840450579, 5.383010717636652, 5.409495675017833, 5.435787541098841, 5.4618900248798985, 5.487806720960525, 5.513541114368059, 5.5390965851288, 5.564476412598252, 5.589683779565779, 5.614721776147788, 5.639593403482585, 5.664301577239054, 5.688849130950448, 5.71323881918382, 5.737473320554813, 5.761555240596942, 5.785487114493792, 5.809271409682041, 5.832910528332675, 5.856406809717238, 5.87976253246557], [0.0, 0.9326350102279887, 1.23061927385959, 1.4473055127008105, 1.6238118670073238, 1.7754143106048341, 1.909731073313939, 2.0311917804730997, 2.142632604123067, 2.2459946539880526, 2.342673227742483, 2.433709786403234, 2.5199052586865527, 2.6018907392047406, 2.680173622631135, 2.7551688397781016, 2.8272206710203136, 2.8966183858791332, 2.963607713490865, 3.0283994232765576, 3.0911758563620766, 3.1520959743004386, 3.211299315684478, 3.2689091353924593, 3.3250349232351226, 3.379774445235429, 3.433215413347389, 3.48543686282892, 3.5365102973066285, 3.5865006475509777, 3.635467079602182, 3.683463680115477, 3.7305400409119547, 3.7767417602243545, 3.8221108746577284, 3.866686233184934, 3.910503822378766, 3.9535970504082134, 3.9959969959934885, 4.037732627446241, 4.078830996059936, 4.119317407416463, 4.159215573604822, 4.19854774888009, 4.237334850905251, 4.2755965693991635, 4.313351463748131, 4.350617050916451, 4.387409884804887, 4.42374562804898, 4.459639117116218, 4.495104421448386, 4.530154897299312, 4.564803236836187, 4.599061513002219, 4.632941220577896, 4.666453313825897, 4.699608241059554, 4.732415976435623, 4.764886049238014, 4.79702757088951, 4.8288492599024915, 4.86035946495701, 4.891566186274559, 4.922477095438361, 4.953099553795473, 4.983440629562382, 5.013507113743583, 5.043305534961979, 5.072842173290273, 5.102123073164165, 5.131154055450447, 5.159940728736423, 5.188488499900952, 5.216802584022019, 5.24488801367084, 5.272749647638129, 5.300392179134218, 5.327820143501138, 5.355037925471587, 5.382049766006769, 5.408859768742496, 5.435471906070513, 5.4618900248798985, 5.488117851981384, 5.514158999235642, 5.5400169684050065, 5.565695155746556, 5.591196856363162, 5.616525268327841, 5.641683496595645, 5.666674556716254, 5.6915013783595025, 5.716166808665185, 5.740673615427697, 5.765024490125315, 5.789222050803242, 5.813268844818937, 5.8371673514576345, 5.860919984425469, 5.884529094227096, 5.907996970434263], [0.0, 0.9370603681176803, 1.2364585686030394, 1.4541729847549199, 1.63151686261464, 1.7838386605817729, 1.918792757016348, 2.0408297958516943, 2.152799406779391, 2.25665191009921, 2.3537892241801734, 2.4452577517770053, 2.531862222016803, 2.6142367240590305, 2.6928910601673417, 2.7682421300029283, 2.8406358475526, 2.9103628549230764, 2.97767004723667, 3.0427691940164086, 3.1058435015977324, 3.1670526858070396, 3.2265369473485004, 3.2844201259454064, 3.34081223093821, 3.3958114922501497, 3.449506038028907, 3.5019752785551015, 3.553291056740414, 3.6035186114521442, 3.6527173894736706, 3.700941734101684, 3.7482414724707214, 3.794662419177369, 3.8402468102905845, 3.8850336791218005, 3.929059183000284, 3.9723568886169556, 4.014958022160714, 4.056891689397997, 4.098185069980794, 4.13886358956611, 4.17895107275693, 4.218469879404883, 4.257441026427372, 4.295884296971072, 4.333818338486669, 4.371260751056545, 4.408228167129809, 4.444736323661286, 4.480800127517579, 4.516433714900046, 4.551650505438007, 4.586463251523052, 4.620884083384567, 4.6549245503458305, 4.688595658647553, 4.721907906180371, 4.75487131442846, 4.787495457892234, 4.8197894912282235, 4.851762174318194, 4.883421895456726, 4.914776692826407, 4.945834274412159, 4.976602036490669, 5.007087080817147, 5.037296230619441, 5.067236045498801, 5.096912835326907, 5.126332673220339, 5.15550140766593, 5.184424673863759, 5.213107904348355, 5.2415563389432736, 5.2697750340993075, 5.297768871662156, 5.325542567111459, 5.3531006773094685, 5.380447607794461, 5.407587619651025, 5.434524835986743, 5.46126324804238, 5.487806720960525, 5.514158999235642, 5.540323711866702, 5.566304377231921, 5.592104407703633, 5.6177271140199885, 5.643175709428879, 5.668453313618383, 5.693562956446979, 5.718507581485801, 5.743290049384334, 5.767913141070175, 5.792379560792676, 5.816691939019679, 5.840852835195869, 5.864864740370698, 5.888730079703351, 5.912451214851639, 5.9360304462513405], [0.0, 0.9414545972489002, 1.2422567887034328, 1.4609921497829734, 1.6391676599055114, 1.7922037521750398, 1.9277906992157308, 2.0504000157072277, 2.1628946943284157, 2.2672342011657936, 2.364827028711829, 2.4567244866980262, 2.5437350779295658, 2.626495865048891, 2.7055190409745538, 2.781223460367336, 2.8539566593350654, 2.924010642914807, 2.9916334640131277, 3.0570378852201396, 3.1204079719948163, 3.1819041891312456, 3.2416673947875236, 3.2998220094180644, 3.3564785582385666, 3.411735731809391, 3.465682071544308, 3.5183973601086627, 3.569953777312618, 3.6204168679531037, 3.6698463575818634, 3.718296844331781, 3.765818388995601, 3.812457021011816, 3.8582551745102247, 3.9032520658441636, 3.947484021898239, 3.9909847667702345, 4.033785673080413, 4.075915983083116, 4.117403003885964, 4.158272280376448, 4.19854774888009, 4.238251874102291, 4.277405771516697, 4.316029317040611, 4.354141245569643, 4.391759239719592, 4.428900009935387, 4.465579366968365, 4.501812287589042, 4.5376129742887485, 4.572994909626506, 4.607970905794672, 4.642553149905849, 4.676753245442443, 4.710582250257575, 4.744050711470445, 4.777168697559745, 4.80994582792433, 4.84239130015036, 4.87451391519799, 4.906322100697674, 4.937823932526066, 4.969027154813732, 4.99993919852129, 5.030567198706754, 5.0609180105946585, 5.090998224546695, 5.1208141800239115, 5.150371978622016, 5.179677496253603, 5.208736394544328, 5.237554131503918, 5.266135971527439, 5.294486994777285, 5.322612105991968, 5.3505160427637914, 5.37820338332385, 5.405678553869649, 5.432945835467608, 5.4600093705601145, 5.486873169104365, 5.513541114368059, 5.5400169684050065, 5.566304377231921, 5.5924068757260175, 5.618327892261534, 5.644070753101916, 5.669638686563188, 5.695034826962819, 5.720262218367436, 5.745323818151688, 5.770222500379723, 5.794961059019954, 5.819542211002978, 5.843968599131894, 5.868242794853583, 5.89236730089897, 5.916344553799724, 5.940176926288359, 5.963866729588265], [0.0, 0.9458182747718377, 1.2480146957150107, 1.467763903432938, 1.6467652637567831, 1.8005106840788656, 1.936726081726664, 2.0599036970188043, 2.172919792713087, 2.2777429170951358, 2.375788091073179, 2.4681114972389286, 2.555525385838524, 2.6386697723237544, 2.7180592236466437, 2.7941145358751043, 2.867184855959916, 2.9375635423924904, 3.00549979781396, 3.0712073709770573, 3.1348711804910927, 3.1966524349105176, 3.2566926452762988, 3.3151168087363416, 3.3720359627948855, 3.427549255446754, 3.481745638498506, 3.5347052644111465, 3.5865006475509777, 3.6371976365175316, 3.686856233692734, 3.7355312902738724, 3.7832730990873507, 3.830127902919843, 3.8761383325849375, 3.9213437862052465, 3.9657807590418552, 4.00948313150501, 4.05248242162825, 4.094808007204869, 4.136487321911958, 4.177546029038525, 4.2180081758558625, 4.257896331194127, 4.297231708397979, 4.33603427551035, 4.374322854263795, 4.412115209233702, 4.449428128318544, 4.486277495553084, 4.522678357125735, 4.558644981356911, 4.5941909132978, 4.629329024525755, 4.664071558641103, 4.6984301729088305, 4.7324159764356235, 4.766039565226975, 4.7993110544293565, 4.832240108027899, 4.864835966239921, 4.897107470818359, 4.929063088456052, 4.960710932461645, 4.992058782860044, 5.0231141050546455, 5.053884067174729, 5.084375556219053, 5.114595193095881, 5.144549346649904, 5.174244146757957, 5.203685496567708, 5.232879083946662, 5.261830392202627, 5.2905447101313365, 5.319027141441931, 5.347282613606572, 5.375315886176476, 5.403131558603015, 5.430734077599286, 5.458127744074614, 5.485316719671759, 5.512305032934225, 5.5390965851288, 5.565695155746556, 5.592104407703633, 5.618327892261534, 5.644369053685139, 5.670231233655253, 5.695917675451264, 5.721431527918323, 5.746775849232419, 5.771953610475744, 5.796967699033841, 5.821820921825274, 5.8465160083737135, 5.871055613731752, 5.895442321265022, 5.919678645304702, 5.9437670336758766, 5.967709870108765, 5.9915094765393615], [0.0, 0.9501519606468252, 1.2537330285098616, 1.474489114676777, 1.6543106491160209, 1.8087605222639431, 1.9456000511645284, 2.06934205932763, 2.1828759883844313, 2.288179406397533, 2.3866738178209848, 2.479420244615436, 2.567234658711743, 2.6507600080763196, 2.73051321737788, 2.8069170107481347, 2.8803221349094574, 2.9510232925052864, 3.0192708280091702, 3.085279469558544, 3.1492349830493347, 3.2112993156844785, 3.2716146269005324, 3.330306486575269, 3.387486440980496, 3.443254092401545, 3.497698800217125, 3.550901084142287, 3.60293379080006, 3.6538630705045376, 3.703749200565169, 3.752647283504326, 3.8006078425873007, 3.847677332482603, 3.893898579335798, 3.9393111617894703, 3.983951742323927, 4.02785435658754, 4.071050667027698, 4.113570186045081, 4.155440473016339, 4.196687308818218, 4.237334850905251, 4.277405771516697, 4.316921381195564, 4.355901739477225, 4.394365754334351, 4.4323312717386125, 4.469815156509681, 4.506833365462072, 4.543401013724981, 4.5795324349954605, 4.615241236387358, 4.650540348454865, 4.685442070897794, 4.719958114394062, 4.754099638951652, 4.787877289126356, 4.821301226411675, 4.854381159072573, 4.887126369664523, 4.919545740452873, 4.9516477769243705, 4.983440629562382, 5.014932114039447, 5.04612972996502, 5.0770406783123425, 5.107671877636012, 5.13802997918092, 5.168121380973444, 5.197952240977167, 5.227528489387648, 5.256855840133877, 5.285939801647871, 5.314785686958325, 5.3433986231592865, 5.371783560300315, 5.399945279740624, 5.42788840200601, 5.455617394184158, 5.483136576890917, 5.51045013083746, 5.537562103025848, 5.564476412598252, 5.591196856363162, 5.6177271140199885, 5.644070753101916, 5.670231233655253, 5.6962119126721955, 5.722016048292653, 5.74764680378961, 5.773107251351442, 5.7984003756736735, 5.823529077371686, 5.848496176225182, 5.873304414264359, 5.897956458707108, 5.922454904755898, 5.94680227826243, 5.971001038267585, 5.995053579423699, 6.018962234305748], [0.0, 0.954456198345221, 1.2594125042027418, 1.481168626898112, 1.6618047622218186, 1.8169543013116636, 1.9544137203806844, 2.078716286263467, 2.1927645299117584, 2.2985449778741254, 2.397485574093577, 2.490652147015316, 2.578864364965396, 2.6627680884978924, 2.742882583977097, 2.8196324904969803, 2.8933701436807717, 2.9643915811901813, 3.032948281572216, 3.0992559456939195, 3.163501180980369, 3.2258466682637357, 3.2864352109702026, 3.3453929478156073, 3.4028319303821566, 3.458852212158706, 3.5135435573265874, 3.5669868503593403, 3.6192552678789776, 3.670415259863949, 3.720527376683043, 3.7696469704759195, 3.817824793380884, 3.8651075105085053, 3.9115381420090123, 3.9571564458182933, 4.001999250499595, 4.046100745884543, 4.089492737853054, 4.132204872498518, 4.17426483404299, 4.215698520151927, 4.256530197714383, 4.296782641676039, 4.3364772591177685, 4.375634200445681, 4.414272459286546, 4.452409962455209, 4.490063651169854, 4.527249554530191, 4.563982856137738, 4.600277954621937, 4.636148518737569, 4.671607537614905, 4.70666736667204, 4.741339769636865, 4.775635957072781, 4.809566621755971, 4.843141971212029, 4.87637175768486, 4.909265305780399, 4.941831538001114, 4.9740789983640505, 5.006015874274689, 5.037650016810968, 5.068988959555964, 5.100039936103701, 5.130809896350187, 5.1613055216708, 5.191533239075309, 5.221499234423188, 5.251209464774093, 5.2806696699414095, 5.309885383310635, 5.338861941978761, 5.367604496265838, 5.3961180186454065, 5.424407312136486, 5.4524770181960935, 5.480331624148054, 5.507975470180829, 5.5354127559444315, 5.562647546774051, 5.589683779565779, 5.616525268327841, 5.643175709428879, 5.669638686563188, 5.695917675451264, 5.722016048292653, 5.747937077986809, 5.773683942136505, 5.799259726847291, 5.824667430335516, 5.849909966356499, 5.874990167463695, 5.899910788108835, 5.924674507592448, 5.949283932873406, 5.973741601245648, 5.998049982889639, 6.022211483305613, 6.046228445635232], [0.0, 0.9587315155141828, 1.2650538190282499, 1.4878032589238497, 1.6692485217612372, 1.8250930256796174, 1.9631681698237125, 2.088027526992451, 2.2025866295099124, 2.3088409022178236, 2.4082246852806923, 2.5018085813331057, 2.590415930259933, 2.6746954856329896, 2.7551688397781016, 2.8322625338847063, 2.9063304818009352, 2.9776700472366704, 3.046533835192445, 3.1131385127290594, 3.177671523146437, 3.240296275976669, 3.301156214308545, 3.360378041873896, 3.418074312170108, 3.474345526857884, 3.529281852201278, 3.5829645349814756, 3.6354670796021824, 3.686856233692734, 3.7371928188465526, 3.786532435143384, 3.834926062056731, 3.8824205737252457, 3.9290591830002843, 3.9748818259063543, 4.019925495973716, 4.064224536181279, 4.1078108948777565, 4.150714350950949, 4.192962712629476, 4.234581993582788, 4.275596569399164, 4.316029317040612, 4.3559017394772255, 4.395234077375283, 4.434045409440134, 4.472353742786611, 4.510176094518076, 4.54752856553375, 4.584426407447397, 4.620884083384567, 4.6569153233268, 4.692533174586873, 4.727750047926782, 4.762577759767952, 4.797027570889511, 4.831110221964036, 4.864835966239921, 4.898214599644518, 4.931255488551678, 4.963967595430637, 4.996359502569846, 5.028439434048817, 5.060215276113001, 5.091694596090821, 5.122884659977901, 5.1537924488010765, 5.18442467386376, 5.214787790964369, 5.244888013670841, 5.274731325726421, 5.304323492654969, 5.333670072627804, 5.3627764266484945, 5.391647728107036, 5.420288971750281, 5.448704982111521, 5.476900421438357, 5.504879797154784, 5.532647468890367, 5.560207655106708, 5.5875644393489425, 5.614721776147788, 5.641683496595645, 5.668453313618383, 5.695034826962819, 5.721431527918323, 5.74764680378961, 5.773683942136505, 5.79954613479529, 5.825236481695177, 5.8507579944824935, 5.876113599964208, 5.901306143381695, 5.926338391524766, 5.951213035695399, 5.9759326945298765, 6.000499916687494, 6.024917183413454, 6.049186910983, 6.073311453033482], [0.0, 0.9629784246075759, 1.2706576491733155, 1.4943938060032524, 1.6766428199682786, 1.8331776709026233, 1.9718644488313057, 2.0972768975911458, 2.2123434644887174, 2.319068413532676, 2.418892438608241, 2.512890884816468, 2.6018907392047406, 2.6865436291394644, 2.76737345745275, 2.844808654790704, 2.919204702739574, 2.9908602822462615, 3.0600291172799117, 3.1269288346750423, 3.1917477080523113, 3.2546498708017566, 3.315779401424428, 3.375263564913804, 3.433215413347389, 3.4897358935797795, 3.5449155712860443, 3.5988360531475982, 3.6515711691718393, 3.703187962661198, 3.75374752463153, 3.8033057014551868, 3.8519136984303035, 3.8996185973346886, 3.9464638024403933, 3.992489426677203, 4.03773262744624, 4.082227899856084, 4.126007333777586, 4.169100840010586, 4.211536349966279, 4.253339992547305, 4.294536251318896, 4.335148104581522, 4.375197150557344, 4.414703719573063, 4.453686974847285, 4.492165003261264, 4.530154897299312, 4.56767282918307, 4.604734118086634, 4.641353291203104, 4.677544139333949, 4.713319767587849, 4.748692641702957, 4.783674630444099, 4.8182770444724685, 4.852510672038778, 4.886385811810408, 4.919912303107895, 4.953099553795473, 4.985956566043578, 5.018491960157771, 5.050713996647904, 5.082630596693263, 5.114249361143392, 5.1455775881802195, 5.176622289754552, 5.2073902068989755, 5.237887824009266, 5.268121382177707, 5.298096891653831, 5.327820143501138, 5.3572967205120685, 5.386532007437922, 5.4155312005853435, 5.444299316826502, 5.472841202066005, 5.501161539203887, 5.529264855630758, 5.557155530288106, 5.584837800324122, 5.612315767372892, 5.639593403482585, 5.666674556716254, 5.693562956446979, 5.720262218367436, 5.746775849232419, 5.773107251351442, 5.799259726847291, 5.825236481695177, 5.851040629556122, 5.876675195417192, 5.902143119050283, 5.927447258300383, 5.952590392213398, 5.97757522401301, 6.002404383935322, 6.027080431929467, 6.051605860231859, 6.075983095821161, 6.100214502760665], [0.0, 0.967197423485091, 1.2762246515677385, 1.5009410407376782, 1.6839885236670116, 1.8412091847332428, 1.9805035768570676, 2.1064654823513713, 2.222036178629389, 2.3292287107766794, 2.4294900846432252, 2.523900356629587, 2.613290136976913, 2.698313907959941, 2.779497867732675, 2.857272323980591, 2.931994315725051, 3.00396383249324, 3.073435709869178, 3.1406285281535746, 3.205731385831044, 3.2689091353924593, 3.330306486575269, 3.390051261946053, 3.4482570088858173, 3.5050251165172894, 3.560446547301666, 3.6146032654553695, 3.6675694244496566, 3.7194123613169228, 3.770193434724842, 3.819968735719766, 3.868789693940364, 3.9167035974390227, 3.963754040650491, 4.009981312247231, 4.055422732424287, 4.100112947420127, 4.144084187697673, 4.187366495101893, 4.229987923417016, 4.271974716021572, 4.313351463748132, 4.354141245569644, 4.394365754334351, 4.434045409440134, 4.4731994580634495, 4.511846066327755, 4.550002401602915, 4.5876847069642706, 4.624908368702249, 4.661687977656455, 4.698037385048586, 4.733969753403394, 4.769497603073896, 4.804632854824324, 4.839386868870113, 4.873770480727436, 4.90779403418417, 4.941467411668862, 4.9748000622634585, 5.007801027578684, 5.040478965687362, 5.072842173290273, 5.104898606270956, 5.136655898779777, 5.168121380973444, 5.199302095523507, 5.230204812996348, 5.260836046197162, 5.291202063561694, 5.321308901671566, 5.3511623769620735, 5.380768096684974, 5.410131469183226, 5.439257713529524, 5.468151868575943, 5.496818801457958, 5.525263215592315, 5.5534896582050175, 5.581502527422561, 5.609306078956921, 5.636904432412253, 5.664301577239054, 5.6915013783595025, 5.718507581485801, 5.745323818151688, 5.771953610475744, 5.7984003756736735, 5.824667430335516, 5.8507579944824935, 5.876675195417192, 5.902422071379746, 5.928001575021771, 5.953416576709038, 5.9786698676630055, 6.003764162950713, 6.028702104331845, 6.053486262971181, 6.078119142024114, 6.1026031791023785, 6.1269407486267], [0.0, 0.9713889959815001, 1.2817554646353284, 1.507445713963976, 1.6912864752627026, 1.8491884882254452, 1.98908654463616, 2.115594335019986, 2.231665883492341, 2.339322959132675, 2.440018838723644, 2.534838259338639, 2.624615430859335, 2.7100076719099415, 2.7915434610451926, 2.8696549707878924, 2.9447007874701243, 3.016982200692688, 3.086755150428221, 3.1542391642454413, 3.219624160130739, 3.2830757050011745, 3.344739135727128, 3.40474282882367, 3.4632008237555008, 3.5202149490384302, 3.575876561340402, 3.6302679800886244, 3.6834636801154765, 3.735531290273872, 3.7865324351433833, 3.8365234488538134, 3.8855559839260003, 3.933677533345982, 3.9809318804750173, 4.027359488585796, 4.072997839609013, 4.1178817299305805, 4.162043529691542, 4.205513410930112, 4.248319549008046, 4.290488301035591, 4.332044364415347, 4.373010918138299, 4.413409749063638, 4.453261365081402, 4.492585096780115, 4.5313991890103065, 4.569720883540587, 4.607566493839403, 4.644951472877209, 4.681890474726369, 4.718397410636036, 4.7544855001737885, 4.790167317952476, 4.825454836397703, 4.86035946495701, 4.894892086104772, 4.929063088456051, 4.96288239726717, 4.996359502569845, 5.029503485158703, 5.062323040628314, 5.094826501635122, 5.127021858541315, 5.158916778581609, 5.19051862367963, 5.221834467027963, 5.2528711085348, 5.283635089230073, 5.314132704715237, 5.344370017732828, 5.374352869925001, 5.40408689284383, 5.433577518270572, 5.462829987895971, 5.491849362409129, 5.52064053003837, 5.54920821458378, 5.577556982977811, 5.605691252407252, 5.633615297027185, 5.661333254295017, 5.688849130950448, 5.716166808665185, 5.743290049384334, 5.770222500379723, 5.796967699033841, 5.823529077371686, 5.849909966356499, 5.876113599964208, 5.902143119050283, 5.928001575021771, 5.953691933326281, 5.979217076768977, 6.004579808667716, 6.029782855855904, 6.054828871541902, 6.0797204380332195, 6.1044600693332525, 6.129050213617684, 6.153493255597339], [0.0, 0.9755536124478466, 1.2872507090080076, 1.5139085555943308, 1.698537493684083, 1.8571164767648465, 1.9976143152934855, 2.124664479977549, 2.2412336596605127, 2.349352291311657, 2.450479882317901, 2.54570582032403, 2.6358678917029326, 2.72162623318771, 2.8035115890685534, 2.8819579847128143, 2.9573255438125305, 3.0299168476813367, 3.099988933578157, 3.1677622702478296, 3.233427589908301, 3.297151169308339, 3.359078968418158, 3.4193399141388756, 3.4780485348542904, 3.5353070956475556, 3.591207344858218, 3.6458319548399043, 3.699255719719444, 3.7515465582935676, 3.8027663593436665, 3.852971698519723, 3.902214449791386, 3.950542309760416, 3.9979992494995944, 4.044625905758985, 4.090459921164807, 4.135536241284817, 4.179887375039914, 4.223543623824281, 4.266533283795337, 4.308882825063635, 4.350617050916451, 4.391759239719593, 4.4323312717386125, 4.472353742786611, 4.511846066327755, 4.550826565433356, 4.5893125557923105, 4.627320420813469, 4.664865679718495, 4.701963049405862, 4.73862650076614, 4.774869310042895, 4.81070410575986, 4.846142911671777, 4.881197186141683, 4.915877858300166, 4.950195361301187, 4.984159662953421, 5.017780293975006, 5.051066374092476, 5.08402663618085, 5.116669448620999, 5.1490028360320315, 5.181034498520245, 5.212771829571891, 5.244221932704313, 5.275391636978809, 5.306287511468541, 5.336915878765963, 5.367282827606291, 5.397394224676432, 5.4272557256725, 5.456872785663317, 5.486250668812224, 5.515394457504914, 5.544309060926911, 5.572999223130557, 5.601469530628018, 5.629724419543802, 5.657768182357489, 5.6856049742649235, 5.71323881918382, 5.740673615427697, 5.767913141070175, 5.794961059019954, 5.821820921825274, 5.848496176225182, 5.874990167463695, 5.901306143381695, 5.927447258300383, 5.953416576709038, 5.979217076768977, 6.004851653644754, 6.030323122672834, 6.055634222377323, 6.080787617341626, 6.10578590094433, 6.130631597967064, 6.155327167081528, 6.179875003222469], [0.0, 0.97969173026623, 1.292710988205075, 1.5203302754151296, 1.705742375279642, 1.8649940210486826, 2.0060878253977967, 2.133676913359473, 2.2507405579220348, 2.3593178087924884, 2.4608743643178865, 2.556504233123725, 2.647048755317585, 2.733170867810378, 2.815403566211316, 2.8941827169430074, 2.9698699712755223, 3.042769194016409, 3.113138512729059, 3.1811993313459106, 3.2471431911356685, 3.3111370741622848, 3.3733275595311465, 3.4338441210274175, 3.492801772843097, 3.550303213850889, 3.6064405815698106, 3.661296899034308, 3.7149472776340495, 3.7674599242647275, 3.818896990228487, 3.8693152911587427, 3.91876692106492, 3.9672997788689335, 4.014958022160715, 4.061782460063899, 4.1078108948777565, 4.153078420402673, 4.197617683456371, 4.241459113965939, 4.284631128115855, 4.327160308297982, 4.36907156301055, 4.410388269361882, 4.45113240042957, 4.491324639390337, 4.530984482056673, 4.570130329222964, 4.608779570028056, 4.646948657376185, 4.684653176318679, 4.721907906180371, 4.758726877113762, 4.795123421677787, 4.831110221964036, 4.866699352729796, 4.901902320942356, 4.936730102091653, 4.971193173587157, 5.005301545519141, 5.039064789033285, 5.072492062540313, 5.105592135958486, 5.138373413165796, 5.1708439528203005, 5.203011487690722, 5.2348834426251125, 5.26646695127262, 5.297768871662157, 5.328795800731677, 5.359554087892903, 5.390049847708335, 5.420288971750282, 5.450277139705273, 5.480019829781523, 5.509522328471979, 5.538789739720872, 5.567826993537584, 5.596638854097847, 5.625229927368964, 5.653604668292662, 5.681767387556422, 5.709722257981664, 5.737473320554813, 5.765024490125315, 5.792379560792676, 5.819542211002978, 5.8465160083737135, 5.873304414264359, 5.899910788108835, 5.926338391524766, 5.952590392213398, 5.9786698676630055, 6.004579808667716, 6.030323122672834, 6.055902636956962, 6.081321101660518, 6.106581192669576, 6.131685514363355, 6.15663660223314, 6.181436925379862, 6.2060888888971375], [0.0, 0.9838037943397454, 1.2981368892796834, 1.5267115638472708, 1.7129018946706591, 1.8728219680184823, 2.0145079859649306, 2.142632604123067, 2.2601876003958137, 2.369220583001784, 2.471203402269648, 2.5672346587117425, 2.658159223795896, 2.744642816980805, 2.827220671020314, 2.9063304818009352, 2.982335418553081, 3.05554062149729, 3.1262053016368223, 3.1945517922037396, 3.260772438423691, 3.3250349232351226, 3.3874864409804957, 3.4482570088858173, 3.5074621238926214, 3.565204915932007, 3.6215779092521734, 3.6766644753604867, 3.7305400409119547, 3.7832730990873507, 3.8349260620567316, 3.885555983926001, 3.9352151773589816, 3.983951742323927, 4.0318100217536, 4.078830996059936, 4.12505262620995, 4.170510153303377, 4.2152363611865615, 4.2592618075102475, 4.302615027730281, 4.3453227158129035, 4.387409884804887, 4.428900009935388, 4.469815156509681, 4.510176094518076, 4.550002401602915, 4.5893125557923105, 4.628124019212611, 4.666453313825897, 4.704316090098695, 4.741727189389157, 4.778700700738602, 4.815250012666766, 4.851387860495835, 4.887126369664523, 4.922477095438361, 4.957451059374754, 4.992058782860043, 5.026310317999896, 5.060215276113, 5.0937828540507155, 5.127021858541315, 5.159940728736424, 5.192547557118735, 5.224850108913754, 5.256855840133877, 5.288571914370348, 5.320005218437311, 5.351162376962073, 5.38204976600677, 5.4126735257985805, 5.443039572638532, 5.473153610052526, 5.503021139242483, 5.532647468890367, 5.562037724363217, 5.591196856363162, 5.620129649062628, 5.648840727761565, 5.677334566100442, 5.705615492860009, 5.733687698376284, 5.761555240596942, 5.789222050803242, 5.816691939019679, 5.843968599131894, 5.871055613731752, 5.897956458707108, 5.924674507592448, 5.951213035695399, 5.97757522401301, 6.003764162950713, 6.029782855855904, 6.055634222377323, 6.081321101660518, 6.106846255389083, 6.132212370680599, 6.157422062845658, 6.182477878017772, 6.207382295661439, 6.232137730965184], [0.0, 0.9878902375590144, 1.3035289834344332, 1.5330530926701498, 1.7200168055634837, 1.8806011417481825, 2.0228756834131136, 2.1515324950635972, 2.26957578160334, 2.3790616564374254, 2.481468083545264, 2.5778982267155697, 2.669200466773728, 2.7560432883891246, 2.8389641475213594, 2.918402558122089, 2.9947231979241815, 3.068232474614505, 3.1391906758856485, 3.2078210584791518, 3.274316766568429, 3.3388461795995137, 3.4015571033186105, 3.4625800950065773, 3.5220311313466364, 3.5800137706425064, 3.6366209214619913, 3.691936301614163, 3.74603565105506, 3.798987747466791, 3.8508552622619483, 3.901695486533084, 3.9515609502360576, 4.000499953132811, 4.0485570223441325, 4.095773308503018, 4.1421869302556225, 4.187833275083261, 4.23274526300712, 4.276953578605797, 4.3204868758633665, 4.363371959625271, 4.4056339468354135, 4.447296410232428, 4.488381506774638, 4.528910092725027, 4.568901827045938, 4.6083752645179965, 4.6473479398002935, 4.685836443482473, 4.723856491038685, 4.7614229854738905, 4.7985500743513105, 4.83525120180281, 4.8715391560495105, 4.907426112895774, 4.942923675604441, 4.978042911513356, 5.012794385711729, 5.047188192058836, 5.0812339817960686, 5.114940989975912, 5.148318059907301, 5.181373665795714, 5.214115933737734, 5.2465526612134195, 5.278691335205338, 5.3105391490602685, 5.3421030181982365, 5.373389594763382, 5.4044052813022025, 5.435156243546646, 5.465648422372385, 5.495887544996156, 5.525879135470322, 5.555628524527611, 5.5851408588243885, 5.614421109626606, 5.643474080978789, 5.672304417393077, 5.70091661109218, 5.729315008837381, 5.75750381837017, 5.785487114493792, 5.813268844818937, 5.840852835195869, 5.868242794853583, 5.895442321265022, 5.922454904755898, 5.949283932873406, 5.9759326945298765, 6.002404383935322, 6.028702104331845, 6.054828871541902, 6.080787617341626, 6.106581192669576, 6.132212370680599, 6.1576838496538056, 6.182998255763048, 6.208158145717758, 6.23316600928143, 6.2580242716746], [0.0, 0.9919514812466601, 1.308887826607858, 1.5393555157114145, 1.7270878415234092, 1.8883323442902542, 2.0311917804730997, 2.1603775037823105, 2.278906069489821, 2.388842043738954, 2.491669466459315, 2.588496036576016, 2.680173622631135, 2.76737345745275, 2.850635206496557, 2.9304001905680463, 3.007034586600182, 3.0808460619301843, 3.152095974300438, 3.221008498267033, 3.2877775720243427, 3.3525722672308924, 3.415540997266336, 3.4768148561360723, 3.5365102973066285, 3.594731304812731, 3.6515711691718393, 3.7071139523592183, 3.7614357056999306, 3.81460548962301, 3.866686233184934, 3.9177354630034977, 3.9678059249866404, 4.016946117457942, 4.065200750590396, 4.1126111441883735, 4.159215573604822, 4.205049571799958, 4.25014619413007, 4.294536251318896, 4.33824851514782, 4.381309900657732, 4.42374562804898, 4.465579366968364, 4.506833365462072, 4.547528565533749, 4.58768470696427, 4.627320420813468, 4.666453313825897, 4.705100044795566, 4.743276393803367, 4.780997325120922, 4.8182770444724685, 4.855129051259066, 4.891566186274559, 4.9276006753783745, 4.963244169534683, 4.9985077815794545, 5.033402120035271, 5.067937320257538, 5.102123073164164, 5.135968651773186, 5.169482935748623, 5.202674434133643, 5.235551306431434, 5.268121382177706, 5.300392179134218, 5.332370920219792, 5.364064549283935, 5.395479745817932, 5.426622938689324, 5.45750031897755, 5.488117851981384, 5.5184812884623105, 5.548596175182217, 5.578467864788623, 5.608101525095936, 5.637502147807119, 5.666674556716255, 5.695623415429198, 5.724353234636311, 5.752868378968528, 5.781173073465481, 5.809271409682041, 5.8371673514576345, 5.864864740370698, 5.89236730089897, 5.919678645304702, 5.94680227826243, 5.973741601245648, 6.000499916687494, 6.027080431929467, 6.053486262971181, 6.0797204380332195, 6.10578590094433, 6.131685514363355, 6.157422062845658, 6.182998255763048, 6.208416730085648, 6.233680053033596, 6.258790724605868, 6.283751179993151], [0.0, 0.9959879355809818, 1.314213960033469, 1.545619469504443, 1.7341157167123347, 1.8960163564822323, 2.0394571170557168, 2.169168523609161, 2.288179406397533, 2.398562732707876, 2.5018085813331057, 2.599029158652794, 2.6910797996370985, 2.7786344684983537, 2.862235026701848, 2.942324590878079, 3.0192708280091702, 3.093382657393933, 3.1649225002930934, 3.2341154434750554, 3.3011562143085444, 3.366214572439392, 3.429439535171781, 3.490962729959545, 3.550901084142287, 3.609359004887131, 3.6664301623298146, 3.7221989605110473, 3.7767417602243545, 3.830127902919843, 3.8824205737252457, 3.9336775333459824, 3.983951742323927, 4.033291896332299, 4.081742887478972, 4.129346203707087, 4.176140276119865, 4.2221607822684355, 4.267440912018123, 4.312011601467829, 4.355901739477225, 4.399138350610032, 4.441746757692774, 4.483750726688906, 4.525172596176483, 4.566033393376469, 4.606352938394958, 4.646149938105396, 4.685442070897794, 4.724246063354219, 4.762577759767951, 4.800452185303309, 4.837883603490537, 4.874885568662534, 4.911470973864971, 4.9476520947068074, 4.983440629562382, 5.018847736488076, 5.053884067174728, 5.088559798220588, 5.1228846599779, 5.156867963198515, 5.19051862367963, 5.2238451850894565, 5.256855840133878, 5.2895584502085935, 5.321960563666678, 5.354069432818494, 5.3858920297695, 5.417435061191201, 5.448704982111521, 5.479708008802674, 5.5104501308374605, 5.540937122378392, 5.571174552758272, 5.601167796405641, 5.6309220421638075, 5.660442302047994, 5.689733419481297, 5.71880007704674, 5.74764680378961, 5.776277982101421, 5.80469785421436, 5.832910528332675, 5.860919984425469, 5.888730079703351, 5.916344553799724, 5.9437670336758766, 5.971001038267585, 5.998049982889639, 6.024917183413454, 6.051605860231859, 6.078119142024114, 6.1044600693332525, 6.130631597967064, 6.15663660223314, 6.182477878017772, 6.208158145717758, 6.233680053033596, 6.259046177631967, 6.28425902968486, 6.3093210542922495], [0.0, 1.0, 1.3195079107728942, 1.5518455739153598, 1.7411011265922482, 1.9036539387158784, 2.0476725110792193, 2.1779064244827797, 2.29739670999407, 2.408224685280692, 2.51188643150958, 2.609498635278873, 2.701920077041227, 2.7898274358890855, 2.873764756028137, 2.9541769390627772, 3.031433133020796, 3.1058435015977324, 3.1776715231464365, 3.2471431911356685, 3.314454017339987, 3.379774445235429, 3.4432540924015447, 3.5050251165172894, 3.565204915932007, 3.623898318388478, 3.6811993713469082, 3.737192818846552, 3.7919553292794634, 3.845556523418775, 3.8980598409161895, 3.9495232751502978, 4.0, 4.049538907295691, 4.0981850699807945, 4.14598014312126, 4.192962712629476, 4.239168599773808, 4.284631128115855, 4.329381358372115, 4.3734482957731124, 4.416859073743617, 4.459639117116218, 4.501812287589042, 4.5434010137249805, 4.584426407447396, 4.624908368702249, 4.664865679718495, 4.704316090098694, 4.743276393803367, 4.781762498950186, 4.8197894912282235, 4.857371691624451, 4.894522709071677, 4.9312554885516775, 4.967582355122337, 5.003515054281688, 5.039064789033284, 5.074242253975382, 5.109057666699868, 5.143520796755041, 5.177640992398568, 5.211427205342488, 5.244888013670841, 5.278031643091578, 5.310865986667878, 5.3433986231592865, 5.375636834090112, 5.407587619651025, 5.439257713529524, 5.47065359675584, 5.501781510642736, 5.532647468890367, 5.563257268920875, 5.593616502501593, 5.623730565710474, 5.65360466829266, 5.683243842452905, 5.712652951124705, 5.7418366957535865, 5.770799623628855, 5.799546134795288, 5.828080488573741, 5.856406809717238, 5.884529094227096, 5.912451214851639, 5.940176926288359, 5.967709870108765, 5.995053579423699, 6.022211483305613, 6.049186910983, 6.075983095821161, 6.1026031791023785, 6.129050213617684, 6.155327167081528, 6.181436925379862, 6.207382295661439, 6.23316600928143, 6.258790724605868, 6.28425902968486, 6.3095734448019325, 6.334736424906476], [0.0, 1.0039880635869725, 1.3247701922245698, 1.558034432741296, 1.7480447485964477, 1.911245831671068, 2.055838759258699, 2.1865920537900934, 2.306558874158028, 2.417828838457308, 2.521903994321694, 2.6199054817664833, 2.7126955061153852, 2.8009534451000917, 2.885225512609178, 2.965958384542928, 3.0435226811149385, 3.1182298029732896, 3.1903442792392567, 3.2600930046579224, 3.327672270717235, 3.3932532006326523, 3.4569860086681454, 3.519003379555896, 3.579423179837331, 3.638350655314934, 3.695880228516163, 3.7520969814448892, 3.8070778882515897, 3.860892847361466, 3.913605551427587, 3.965274225109825, 4.01595225434789, 4.065688725955906, 4.114528892631059, 4.162514575562353, 4.209684514545247, 4.256074673705603, 4.3017185095015025, 4.346647206521556, 4.390889885670992, 4.434473788584404, 4.477424441490228, 4.51976580124856, 4.561520385868831, 4.602709391470093, 4.643352797360555, 4.683469460673898, 4.723077201799226, 4.762192881672441, 4.800832471853799, 4.839011118195064, 4.876743198796209, 4.914042376863336, 4.95092164900363, 4.987393389428088, 5.023469390476537, 5.0591608998308235, 5.094478654739939, 5.129432913544176, 5.164033484753416, 5.198289753906769, 5.232210708416273, 5.2658049605759105, 5.29908076889828, 5.332046057924599, 5.364708436638987, 5.397075215604934, 5.4291534229303196, 5.46094981915701, 5.492470911162002, 5.523722965148809, 5.554712018800605, 5.5854438926600185, 5.615924200794708, 5.646158360802529, 5.676151603205416, 5.705908980276877, 5.735435374344096, 5.764735505602264, 5.793813939475564, 5.822675093556433, 5.851323244152168, 5.87976253246557, 5.907996970434263, 5.9360304462513405, 5.963866729588265, 5.9915094765393615, 6.018962234305748, 6.046228445635232, 6.073311453033482, 6.100214502760665, 6.1269407486267, 6.153493255597339, 6.179875003222469, 6.2060888888971375, 6.232137730965184, 6.2580242716746, 6.283751179993151, 6.3093210542922495, 6.334736424906476, 6.359999756575714]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 0.9\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.12589254117941673, 0.17197427927619374, 0.20639756275665427, 0.2349237886176038, 0.25973860395343273, 0.2819473796215815, 0.3021997620247703, 0.32091535252090686, 0.3383834619016498, 0.35481338923357547, 0.37036224530205325, 0.3851514708494942, 0.39927719745706064, 0.4128170405074344, 0.4258347183047368, 0.4383832905540869, 0.4505074887527553, 0.46224543117757094, 0.47362990989388454, 0.4846893733285307, 0.4954486879303019, 0.5059297366645512, 0.516151895070922, 0.5261324141285761, 0.5358867312681466, 0.5454287253304186, 0.5547709273270172, 0.5639246960073655, 0.5729003651476003, 0.5817073679279383, 0.5903543426026443, 0.5988492227853417, 0.6071993149974168, 0.6154113656055918, 0.6234916188680996, 0.6314458674893553, 0.6392794968300634, 0.6469975237180032, 0.6546046306428728, 0.6621051959878331, 0.6695033208441983, 0.6768028528689379, 0.6840074075734122, 0.6911203873729271, 0.6981449986779219, 0.70508426726695, 0.7119410521476109, 0.7187180580830101, 0.72541784693722, 0.7320428479728127, 0.7385953672161816, 0.7450775959915877, 0.7514916187122181, 0.7578394200056725, 0.7641228912419654, 0.770343836524046, 0.7765039781938609, 0.7826049619009149, 0.7886483612750054, 0.7946356822402045, 0.8005683670031263, 0.8064477977449888, 0.8122753000438742, 0.8180521460508584, 0.8237795574412642, 0.8294587081601642, 0.8350907269793663, 0.8406766998814359, 0.8462176722848183, 0.8517146511227925, 0.8571686067878046, 0.8625804749516609, 0.86795115827112, 0.8732815279875605, 0.8785724254286442, 0.8838246634191993, 0.8890390276079311, 0.8942162777160061, 0.8993571487130495, 0.9044623519256391, 0.9095325760829622, 0.9145684883039291, 0.9195707350296888, 0.9245399429051914, 0.9294767196131484, 0.9343816546634924, 0.939255320141198, 0.9440982714151108, 0.9489110478102408, 0.9536941732457854, 0.9584481568409944, 0.9631734934908293, 0.9678706644132354, 0.9725401376697171, 0.9771823686607838, 0.9817978005977357, 0.9863868649521498, 0.9909499818843408, 0.9954875606519825, 1.0, 1.0044876885327707], [0.0, 0.17197427927619374, 0.2349237886176038, 0.28194737962158145, 0.3209153525209068, 0.35481338923357547, 0.3851514708494942, 0.4128170405074344, 0.4383832905540869, 0.4622454311775709, 0.4846893733285307, 0.5059297366645512, 0.5261324141285761, 0.5454287253304186, 0.5639246960073654, 0.5817073679279383, 0.5988492227853417, 0.6154113656055918, 0.6314458674893553, 0.6469975237180032, 0.6621051959878331, 0.6768028528689379, 0.6911203873729271, 0.70508426726695, 0.71871805808301, 0.7320428479728127, 0.7450775959915877, 0.7578394200056725, 0.7703438365240459, 0.7826049619009149, 0.7946356822402044, 0.8064477977449885, 0.8180521460508583, 0.8294587081601642, 0.8406766998814358, 0.8517146511227923, 0.8625804749516609, 0.8732815279875604, 0.8838246634191993, 0.8942162777160061, 0.904462351925639, 0.914568488303929, 0.9245399429051914, 0.9343816546634924, 0.9440982714151107, 0.9536941732457854, 0.963173493490829, 0.9725401376697169, 0.9817978005977357, 0.9909499818843407, 1.0, 1.0089510050695996, 1.0178059905302963, 1.0265678037744148, 1.035239155883151, 1.0438226305440854, 1.0523206922344739, 1.0607356937427512, 1.0690698830923897, 1.0773254099250416, 1.0855043313936132, 1.0936086176103978, 1.1016401566905811, 1.1096007594271875, 1.1174921636297988, 1.125316038156087, 1.1330739866622799, 1.1407675510961082, 1.1483982149534746, 1.1559674063180598, 1.1634765007012597, 1.17092682369822, 1.1783196534742952, 1.1856562230949557, 1.1929377227109978, 1.200165301609877, 1.2073400701430301, 1.2144631015382161, 1.2215354336051327, 1.228558070341875, 1.2355319834491842, 1.2424581137588564, 1.2493373725821786, 1.2561706429837842, 1.2629587809859018, 1.2697026167075784, 1.276402955443114, 1.283060578683614, 1.2896762450852788, 1.2962506913877838, 1.3027846332858437, 1.309278766256849, 1.3157337663472404, 1.3221502909201035, 1.3285289793662953, 1.3348704537812455, 1.3411753196094316, 1.3474441662583978, 1.3536775676840485, 1.359876082948841, 1.3660402567543954, 1.3721706199499353], [0.0, 0.20639756275665427, 0.28194737962158145, 0.3383834619016498, 0.38515147084949414, 0.4258347183047368, 0.46224543117757094, 0.49544868793030183, 0.526132414128576, 0.554770927327017, 0.5817073679279383, 0.6071993149974168, 0.6314458674893553, 0.6546046306428726, 0.6768028528689379, 0.6981449986779218, 0.71871805808301, 0.7385953672161814, 0.7578394200056725, 0.776503978193861, 0.7946356822402044, 0.812275300043874, 0.8294587081601642, 0.8462176722848181, 0.8625804749516609, 0.8785724254286441, 0.894216277716006, 0.9095325760829622, 0.9245399429051914, 0.9392553201411978, 0.9536941732457853, 0.9678706644132353, 0.9817978005977356, 0.9954875606519824, 1.0089510050695996, 1.0221983711503373, 1.035239155883151, 1.0480821884275249, 1.0607356937427512, 1.073207348649492, 1.0855043313936132, 1.0976333656081743, 1.1096007594271875, 1.1214124403879462, 1.1330739866622799, 1.1445906550771103, 1.1559674063180598, 1.1672089276540871, 1.1783196534742952, 1.1893037838885219, 1.200165301609877, 1.2109079873089446, 1.2215354336051327, 1.2320510578399095, 1.2424581137588564, 1.2527597022141574, 1.2629587809859018, 1.273058173809131, 1.2830605786836138, 1.2929685755346718, 1.3027846332858437, 1.3125111163975436, 1.3221502909201035, 1.331704330104479, 1.3411753196094316, 1.350565262340032, 1.359876082948841, 1.3691096320280216, 1.3782676900178812, 1.3873519708549016, 1.3963641253801318, 1.4053057445268695, 1.4141783623048232, 1.4229834585963852, 1.4317224617792446, 1.440396751188327, 1.4490076594288999, 1.45755647455168, 1.466044442099856, 1.474472767037105, 1.48284261556494, 1.4911551168370367, 1.4994113645775817, 1.5076124186101065, 1.5157593063027874, 1.5238530239357009, 1.5318945379951234, 1.5398847863995628, 1.5478246796618673, 1.5557151019914313, 1.5635569123402175, 1.571350945396059, 1.5790980125264353, 1.5867989026757126, 1.594454383218612, 1.6020652007724818, 1.6096320819707768, 1.6171557341999794, 1.6246368463020506, 1.6320760892443538, 1.639474116758873, 1.6468315659524262], [0.0, 0.2349237886176038, 0.3209153525209068, 0.38515147084949414, 0.4383832905540869, 0.4846893733285307, 0.5261324141285761, 0.5639246960073654, 0.5988492227853417, 0.6314458674893553, 0.6621051959878331, 0.6911203873729272, 0.71871805808301, 0.7450775959915877, 0.7703438365240458, 0.7946356822402044, 0.8180521460508583, 0.8406766998814358, 0.8625804749516609, 0.8838246634191993, 0.9044623519256388, 0.9245399429051914, 0.9440982714151107, 0.9631734934908291, 0.9817978005977356, 1.0, 1.0178059905302963, 1.035239155883151, 1.0523206922344739, 1.0690698830923897, 1.0855043313936132, 1.1016401566905811, 1.1174921636297988, 1.1330739866622799, 1.1483982149534746, 1.1634765007012597, 1.1783196534742952, 1.192937722710998, 1.2073400701430301, 1.2215354336051327, 1.2355319834491842, 1.2493373725821786, 1.2629587809859018, 1.276402955443114, 1.2896762450852788, 1.3027846332858437, 1.3157337663472404, 1.3285289793662953, 1.3411753196094316, 1.3536775676840485, 1.3660402567543954, 1.3782676900178812, 1.3903639566301678, 1.4023329462437975, 1.4141783623048232, 1.425903734234491, 1.437512428607944, 1.4490076594288999, 1.4603924975879197, 1.4716698795820382, 1.4828426155649397, 1.4939133967893272, 1.504884802496554, 1.5157593063027874, 1.5265392821258752, 1.53722700969258, 1.5478246796618673, 1.5583343983964106, 1.5687581924113339, 1.5790980125264353, 1.5893557377456546, 1.5995331788853253, 1.6096320819707766, 1.6196541314190802, 1.6296009530241355, 1.6394741167588731, 1.6492751394080547, 1.6590054870440043, 1.6686665773565474, 1.6782597818474998, 1.6877864278991914, 1.6972478007257301, 1.706645145215021, 1.7159796676689025, 1.7252525374481997, 1.7344648885289482, 1.7436178209755808, 1.7527124023364073, 1.761749668966339, 1.770730627281431, 1.7796562549494748, 1.7885275020205844, 1.7973452920014121, 1.8061105228763967, 1.8148240680791892, 1.823486777417189, 1.8320994779519266, 1.8406629748378343, 1.849178052121783, 1.8576454735055963, 1.8660659830736148, 1.8744403059872479], [0.0, 0.25973860395343273, 0.35481338923357547, 0.4258347183047368, 0.4846893733285307, 0.5358867312681466, 0.5817073679279383, 0.6234916188680996, 0.6621051959878331, 0.6981449986779218, 0.7320428479728127, 0.7641228912419654, 0.7946356822402045, 0.8237795574412641, 0.8517146511227924, 0.8785724254286441, 0.904462351925639, 0.9294767196131484, 0.9536941732457854, 0.9771823686607838, 1.0, 1.0221983711503373, 1.0438226305440854, 1.06491275335031, 1.0855043313936132, 1.1056292148268607, 1.1253160381560867, 1.1445906550771106, 1.16347650070126, 1.1819948954384827, 1.200165301609877, 1.218005541463547, 1.2355319834491842, 1.2527597022141574, 1.2697026167075784, 1.2863736099398373, 1.3027846332858437, 1.318946797698304, 1.3348704537812455, 1.350565262340032, 1.3660402567543954, 1.3813038983018873, 1.3963641253801318, 1.4112283974292548, 1.425903734234491, 1.440396751188327, 1.4547136910076877, 1.4688604523314879, 1.48284261556494, 1.4966654662872492, 1.5103340164972456, 1.523853023935701, 1.53722700969258, 1.550460274281368, 1.5635569123402175, 1.576520826100369, 1.5893557377456546, 1.6020652007724818, 1.6146526104471697, 1.6271212134466295, 1.639474116758873, 1.6517142959115125, 1.6638446025891405, 1.6758677716940582, 1.6877864278991912, 1.6996030917370504, 1.7113201852641877, 1.722940037336712, 1.7344648885289486, 1.7458968957242589, 1.7572381364042942, 1.768490612660495, 1.7796562549494748, 1.7907369256119587, 1.801734422173179, 1.812650480441074, 1.823486777417189, 1.8342449340339164, 1.8449265177305447, 1.85553304487955, 1.866065983073615, 1.8765267532830054, 1.8869167318921576, 1.8972372526236263, 1.9074896083569022, 1.9176750528490196, 1.9277948023633533, 1.937850037212503, 1.9478419032207352, 1.9577715131110431, 1.9676399478214994, 1.9774482577552652, 1.9871974639682761, 1.9968885592983616, 2.0065225094392836, 2.016100253962929, 2.02562270729269, 2.0350907596308287, 2.044505277842471, 2.0538671062986644, 2.063177067680795, 2.0724359637485015], [0.0, 0.2819473796215815, 0.3851514708494942, 0.46224543117757094, 0.5261324141285761, 0.5817073679279383, 0.6314458674893553, 0.6768028528689379, 0.71871805808301, 0.7578394200056725, 0.7946356822402045, 0.8294587081601643, 0.8625804749516609, 0.894216277716006, 0.9245399429051914, 0.9536941732457854, 0.9817978005977356, 1.0089510050695996, 1.035239155883151, 1.0607356937427515, 1.0855043313936132, 1.1096007594271875, 1.1330739866622799, 1.15596740631806, 1.1783196534742955, 1.2001653016098772, 1.2215354336051327, 1.2424581137588566, 1.262958780985902, 1.2830605786836138, 1.3027846332858437, 1.3221502909201035, 1.3411753196094316, 1.359876082948841, 1.3782676900178812, 1.3963641253801318, 1.4141783623048234, 1.4317224617792448, 1.4490076594289, 1.4660444420998562, 1.48284261556494, 1.4994113645775817, 1.5157593063027874, 1.5318945379951234, 1.5478246796618673, 1.5635569123402178, 1.5790980125264351, 1.594454383218612, 1.6096320819707768, 1.6246368463020506, 1.6394741167588731, 1.654149057889459, 1.6686665773565474, 1.6830313433861548, 1.6972478007257303, 1.711320185264188, 1.7252525374482, 1.7390487146135076, 1.7527124023364073, 1.7662471248987484, 1.779656254949475, 1.7929430224366991, 1.806110522876397, 1.819161725016863, 1.8320994779519264, 1.8449265177305447, 1.8576454735055965, 1.8702588732604746, 1.8827691491483143, 1.8951786424753467, 1.9074896083569022, 1.9197042200719119, 1.9318245731393915, 1.943852689138264, 1.9557905192899547, 1.9676399478214996, 1.9794027951253401, 1.9910808207306085, 2.002675726099442, 2.014189157260731, 2.02562270729269, 2.0369779186646966, 2.0482562854480184, 2.059459255404265, 2.070588231959724, 2.0816445760730873, 2.0926296080035147, 2.1035446089854464, 2.1143908228160875, 2.1251694573610656, 2.1358816859833407, 2.1465286489000945, 2.1571114544719676, 2.1676311804287236, 2.178088875035124, 2.1884855582005236, 2.198822222535472, 2.209099834358383, 2.219319334655105, 2.229481639994067, 2.2395876433994766, 2.2496382151848957], [0.0, 0.3021997620247703, 0.4128170405074344, 0.49544868793030183, 0.5639246960073654, 0.6234916188680996, 0.6768028528689379, 0.72541784693722, 0.7703438365240459, 0.812275300043874, 0.8517146511227924, 0.8890390276079312, 0.9245399429051914, 0.9584481568409944, 0.9909499818843408, 1.0221983711503373, 1.0523206922344737, 1.0814243212187917, 1.1096007594271875, 1.136928722836417, 1.1634765007012597, 1.189303783888522, 1.2144631015382163, 1.2390009638201624, 1.2629587809859018, 1.2863736099398373, 1.3092787662568492, 1.331704330104479, 1.3536775676840487, 1.3752232847915171, 1.3963641253801318, 1.4171208252167509, 1.4375124286079437, 1.4575564745516802, 1.4772691574181664, 1.4966654662872492, 1.5157593063027874, 1.5345636047971551, 1.553090404454906, 1.5713509453960592, 1.5893557377456546, 1.6071146260012887, 1.6246368463020509, 1.6419310775312361, 1.6590054870440045, 1.675867771694058, 1.692525194735838, 1.708984619097109, 1.7252525374481997, 1.741335099436308, 1.757238136404294, 1.7729671838717427, 1.7885275020205844, 1.8039240943972017, 1.8191617250168628, 1.8342449340339166, 1.8491780521217835, 1.8639652136900282, 1.8786103690512275, 1.8931172956376723, 1.907489608356902, 1.9217307691653716, 1.9358440959310914, 1.9498327706486205, 1.96369984706323, 1.9774482577552657, 1.9910808207306088, 2.0046002455586156, 2.0180091390948616, 2.031310010822453, 2.0445052778424713, 2.0575972695412594, 2.070588231959724, 2.083480331887534, 2.0962756607030566, 2.108976237978038, 2.121584014864368, 2.134100877278794, 2.146528648900095, 2.158869093992012, 2.171123920064146, 2.1832947803820075, 2.195383276336545, 2.2073909596826087, 2.219319334655105, 2.2311698599708807, 2.242943950723791, 2.254642980179809, 2.266268281478543, 2.277821149247047, 2.2893028411313674, 2.300714579250899, 2.3120575515802275, 2.323332913262838, 2.334541787860728, 2.34568526854371, 2.356764419221911, 2.367780275624745, 2.378733846329415, 2.3896261137417927, 2.4004580350323375, 2.4112305430295495], [0.0, 0.32091535252090686, 0.4383832905540869, 0.526132414128576, 0.5988492227853417, 0.6621051959878331, 0.71871805808301, 0.7703438365240459, 0.8180521460508584, 0.8625804749516609, 0.904462351925639, 0.9440982714151108, 0.9817978005977356, 1.0178059905302963, 1.0523206922344737, 1.0855043313936132, 1.1174921636297988, 1.1483982149534744, 1.1783196534742952, 1.2073400701430301, 1.2355319834491842, 1.2629587809859018, 1.2896762450852788, 1.3157337663472404, 1.3411753196094316, 1.3660402567543957, 1.3903639566301678, 1.4141783623048234, 1.4375124286079437, 1.4603924975879197, 1.4828426155649397, 1.5048848024965538, 1.5265392821258754, 1.5478246796618673, 1.5687581924113339, 1.5893557377456544, 1.6096320819707768, 1.6296009530241355, 1.649275139408055, 1.6686665773565474, 1.6877864278991912, 1.706645145215021, 1.7252525374481997, 1.7436178209755808, 1.761749668966339, 1.779656254949475, 1.797345292001412, 1.8148240680791892, 1.8320994779519266, 1.849178052121783, 1.8660659830736148, 1.8827691491483143, 1.8992931362971317, 1.915643257942025, 1.9318245731393915, 1.9478419032207355, 1.9636998470632303, 1.97940279512534, 1.9949549423671948, 2.010360300161958, 2.0256227072926896, 2.040745840118924, 2.0557332219881803, 2.070588231959724, 2.0853141129009014, 2.099913979010244, 2.1143908228160875, 2.1287475216946397, 2.1429868439471402, 2.157111454471967, 2.171123920064146, 2.185026714371684, 2.1988222225354717, 2.2125127455370377, 2.226100504276298, 2.2395876433994766, 2.2529762348956206, 2.266268281478543, 2.2794657197696164, 2.2925704232955346, 2.305584205313995, 2.3185088214792096, 2.33134597235817, 2.34409730580775, 2.356764419221911, 2.3693488616575684, 2.381852135847022, 2.3942757001042394, 2.4066209701317494, 2.4188893207343978, 2.4310820874457466, 2.4432005680724966, 2.455246024161913, 2.467219682396889, 2.479122735922952, 2.490956345611222, 2.5027216412610436, 2.5144197227457847, 2.5260516611050337, 2.5376184995862254, 2.549121254638524, 2.5605609168616077], [0.0, 0.3383834619016498, 0.4622454311775709, 0.554770927327017, 0.6314458674893553, 0.6981449986779218, 0.7578394200056725, 0.812275300043874, 0.8625804749516609, 0.9095325760829622, 0.9536941732457854, 0.9954875606519825, 1.035239155883151, 1.0732073486494917, 1.1096007594271875, 1.1445906550771103, 1.1783196534742952, 1.2109079873089443, 1.2424581137588564, 1.2730581738091313, 1.3027846332858437, 1.331704330104479, 1.359876082948841, 1.3873519708549016, 1.4141783623048234, 1.440396751188327, 1.466044442099856, 1.491155116837037, 1.5157593063027874, 1.5398847863995628, 1.5635569123402175, 1.5867989026757126, 1.6096320819707766, 1.6320760892443538, 1.6541490578894589, 1.6758677716940578, 1.6972478007257303, 1.718303620162923, 1.7390487146135076, 1.7594956700262578, 1.779656254949475, 1.7995414926055306, 1.8191617250168628, 1.8385266702274405, 1.8576454735055963, 1.8765267532830054, 1.8951786424753463, 1.9136088257387558, 1.9318245731393917, 1.94983277064862, 1.9676399478214994, 1.9852523029695965, 2.002675726099442, 2.019915819853921, 2.0369779186646966, 2.0538671062986644, 2.070588231959724, 2.087145925088389, 2.1035446089854464, 2.1197885133716845, 2.1358816859833407, 2.1518280032920654, 2.1676311804287236, 2.1832947803820075, 2.1988222225354717, 2.214216790600139, 2.229481639994067, 2.244619804715206, 2.259634203749358, 2.2745276470510216, 2.289302841131368, 2.3039623942843597, 2.3185088214792096, 2.332944548944795, 2.3472719184693664, 2.361493191436833, 2.375610552619037, 2.3896261137417922, 2.4035419168409162, 2.417359937423169, 2.431082087445747, 2.444710218126875, 2.4582461225990473, 2.4716915384155125, 2.4850481499198045, 2.498317590487321, 2.5115014446472967, 2.524601250092849, 2.5376184995862254, 2.550554642765842, 2.563411087861209, 2.576189203321424, 2.588890319362469, 2.6015157294382125, 2.6140666916396476, 2.626544430026591, 2.638950135895785, 2.651284968989058, 2.6635500586449754, 2.6757465048971625, 2.6878753795222865, 2.6999377270404854], [0.0, 0.35481338923357547, 0.4846893733285307, 0.5817073679279383, 0.6621051959878331, 0.7320428479728127, 0.7946356822402045, 0.8517146511227924, 0.904462351925639, 0.9536941732457854, 1.0, 1.0438226305440854, 1.0855043313936132, 1.1253160381560867, 1.1634765007012597, 1.200165301609877, 1.2355319834491842, 1.2697026167075784, 1.3027846332858437, 1.3348704537812455, 1.3660402567543954, 1.3963641253801318, 1.425903734234491, 1.4547136910076877, 1.48284261556494, 1.5103340164972456, 1.53722700969258, 1.5635569123402178, 1.5893557377456546, 1.6146526104471697, 1.639474116758873, 1.6638446025891402, 1.6877864278991912, 1.7113201852641877, 1.7344648885289484, 1.757238136404294, 1.779656254949475, 1.801734422173179, 1.823486777417189, 1.8449265177305447, 1.8660659830736148, 1.8869167318921576, 1.9074896083569022, 1.9277948023633533, 1.9478419032207352, 1.9676399478214996, 1.987197463968276, 2.006522509439283, 2.02562270729269, 2.044505277842471, 2.063177067680795, 2.0816445760730873, 2.0999139790102435, 2.1179911511668106, 2.1358816859833407, 2.1535909140647997, 2.171123920064146, 2.188485558200523, 2.2056804665444067, 2.2227130801871575, 2.2395876433994766, 2.256308220871868, 2.2728787081202846, 2.289302841131368, 2.305584205313995, 2.3217262438170447, 2.3377322652672707, 2.35360545097587, 2.369348861657569, 2.384965443701869, 2.4004580350323375, 2.4158293705864806, 2.4310820874457466, 2.446218729642537, 2.461241752668682, 2.476153527707703, 2.490956345611222, 2.5056524206381403, 2.520243893973626, 2.5347328370435256, 2.5491212546385245, 2.563411087861209, 2.577604216908128, 2.5917024636979824, 2.605707594356204, 2.619621321565374, 2.6334453067902244, 2.6471811623852823, 2.6608304535926237, 2.674394700436651, 2.6878753795222865, 2.7012739257425347, 2.7145917339009076, 2.727830160253849, 2.7409905239779127, 2.754074108566122, 2.76708216315764, 2.780015903804595, 2.7928765146796457, 2.805665149227635, 2.8183829312644537, 2.831030956026046], [0.0, 0.37036224530205325, 0.5059297366645512, 0.6071993149974168, 0.6911203873729272, 0.7641228912419654, 0.8294587081601643, 0.8890390276079312, 0.9440982714151108, 0.9954875606519825, 1.0438226305440854, 1.0895656840359742, 1.13307398666228, 1.174630347141535, 1.2144631015382163, 1.2527597022141574, 1.289676245085279, 1.3253443253804131, 1.359876082948841, 1.3933679885015167, 1.425903734234491, 1.4575564745516802, 1.4883905867712808, 1.5184630716361405, 1.5478246796618675, 1.5765208261003691, 1.604592341000727, 1.632076089244354, 1.6590054870440047, 1.6854109352518392, 1.7113201852641877, 1.7367586498911747, 1.7617496689663392, 1.786314737485656, 1.8104737025306408, 1.8342449340339164, 1.8576454735055965, 1.8806911640946355, 1.9033967647659673, 1.9257760508980364, 1.9478419032207355, 1.9696063867013207, 1.991080820730609, 2.012275841752131, 2.0332014593038656, 2.053867106298665, 2.0742816842499012, 2.094453604048832, 2.1143908228160875, 2.134100877278794, 2.1535909140647997, 2.1728677172544373, 2.19193773348677, 2.210807094880036, 2.229481639994067, 2.2479669330349608, 2.2662682814785433, 2.284390752268611, 2.3023391867280885, 2.3201182143057055, 2.3377322652672707, 2.3551855824287187, 2.372482232017758, 2.3896261137417927, 2.4066209701317494, 2.423470395224346, 2.4401778426390663, 2.456746633100531, 2.473179961452038, 2.4894809032016267, 2.5056524206381408, 2.5216973685512425, 2.5376184995862254, 2.553418469261684, 2.5690998406755585, 2.5846650889228715, 2.6001166052463875, 2.6154567009396588, 2.6306876110202193, 2.6458114976892455, 2.660830453592624, 2.6757465048971625, 2.6905616141945696, 2.705277683244815, 2.7198965555695938, 2.734420018905742, 2.748849807527748, 2.7631876044477552, 2.7774350435008643, 2.791593711322946, 2.805665149227635, 2.819650854988721, 2.8335522845336754, 2.8473708535536666, 2.861107939035036, 2.8747648807168464, 2.888342982478826, 2.9018435136637053, 2.9152677103377047, 2.928616776492654, 2.9418918851930123, 2.9550941796708443], [0.0, 0.3851514708494942, 0.5261324141285761, 0.6314458674893553, 0.71871805808301, 0.7946356822402045, 0.8625804749516609, 0.9245399429051914, 0.9817978005977356, 1.035239155883151, 1.0855043313936132, 1.13307398666228, 1.1783196534742952, 1.2215354336051327, 1.2629587809859018, 1.3027846332858437, 1.3411753196094316, 1.3782676900178812, 1.4141783623048234, 1.4490076594288999, 1.4828426155649397, 1.5157593063027874, 1.5478246796618675, 1.5790980125264353, 1.6096320819707768, 1.6394741167588731, 1.6686665773565474, 1.6972478007257303, 1.7252525374481997, 1.7527124023364071, 1.779656254949475, 1.8061105228763967, 1.8320994779519264, 1.8576454735055965, 1.882769149148314, 1.907489608356902, 1.9318245731393915, 1.9557905192899547, 1.9794027951253401, 2.002675726099442, 2.02562270729269, 2.0482562854480184, 2.070588231959724, 2.0926296080035147, 2.1143908228160875, 2.135881685983341, 2.157111454471967, 2.178088875035124, 2.198822222535472, 2.2193193346551046, 2.2395876433994766, 2.259634203749358, 2.2794657197696164, 2.299088568444918, 2.3185088214792096, 2.3377322652672707, 2.3567644192219115, 2.375610552619037, 2.394275700104239, 2.412764675988399, 2.4310820874457466, 2.4492323467154304, 2.467219682396889, 2.4850481499198045, 2.5027216412610436, 2.520243893973626, 2.5376184995862254, 2.554848911425925, 2.571938451911818, 2.588890319362469, 2.605707594356204, 2.622393245679531, 2.6389501358957848, 2.6553810265631563, 2.6716885831286623, 2.687875379522287, 2.703943902473388, 2.719896555569593, 2.735735663076677, 2.7514634735363686, 2.76708216315764, 2.7825938390157563, 2.7980005420722156, 2.8133042500276586, 2.8285068800188915, 2.8436102911702745, 2.8586162870089713, 2.873526617752804, 2.8883429824788256, 2.9030670311801092, 2.917700366717694, 2.932244546674151, 2.946701085114734, 2.961071454261687, 2.975357086086874, 2.9895593738275297, 3.003679673429627, 3.017719304923018, 3.031679553732254, 3.045561671926706, 3.0593668794133926, 3.0730963650756746], [0.0, 0.39927719745706064, 0.5454287253304186, 0.6546046306428726, 0.7450775959915877, 0.8237795574412641, 0.894216277716006, 0.9584481568409944, 1.0178059905302963, 1.0732073486494917, 1.1253160381560867, 1.174630347141535, 1.2215354336051327, 1.2663361857313111, 1.309278766256849, 1.3505652623400317, 1.3903639566301678, 1.4288167182697884, 1.466044442099856, 1.502151130500729, 1.5372270096925797, 1.571350945396059, 1.604592341000727, 1.6370126474161888, 1.6686665773565474, 1.6996030917370502, 1.7298662082937823, 1.7594956700262576, 1.7885275020205844, 1.8169944785867922, 1.8449265177305443, 1.872351016293, 1.8992931362971315, 1.9257760508980362, 1.9518211566802348, 1.9774482577552652, 2.002675726099442, 2.027520641769368, 2.051998915993121, 2.0761253996216418, 2.0999139790102435, 2.1233776610633135, 2.1465286489000945, 2.169378409373425, 2.1919377334867693, 2.214216790600139, 2.2362251771866033, 2.257971960793223, 2.2794657197696164, 2.3007145792508985, 2.3217262438170443, 2.3425080271956733, 2.363066879328391, 2.3834094110806845, 2.403541916840916, 2.4234703952243457, 2.443200568072497, 2.462737897916025, 2.4820876040500206, 2.5012546773539244, 2.5202438939736256, 2.539059827970539, 2.5577068630312434, 2.576189203321424, 2.594510883559195, 2.6126757783752095, 2.630687611020219, 2.648549961474736, 2.6662662740101295, 2.6838398642457606, 2.7012739257425347, 2.718571536169491, 2.7357356630766767, 2.752769169304555, 2.769674818057464, 2.78645527766625, 2.8031131260629842, 2.8196508549887205, 2.8360708739534695, 2.852375513965958, 2.8685670310492974, 2.88464760955736, 2.900619365305477, 2.9164843485279826, 2.932244546674151, 2.9479018870531584, 2.9634582393379154, 2.9789154179368302, 2.9942751842419146, 3.009539248761006, 3.0247092731413074, 3.0397868720909282, 3.054773615204631, 3.069671028699544, 3.084480597066201, 3.0992037646398845, 3.1138419370969297, 3.1283964828802993, 3.1428687345584785, 3.157259990121448, 3.1715715142172534, 3.1858045393324685], [0.0, 0.4128170405074344, 0.5639246960073654, 0.6768028528689379, 0.7703438365240458, 0.8517146511227924, 0.9245399429051914, 0.9909499818843408, 1.0523206922344737, 1.1096007594271875, 1.1634765007012597, 1.2144631015382163, 1.2629587809859018, 1.309278766256849, 1.3536775676840485, 1.3963641253801318, 1.4375124286079437, 1.4772691574181662, 1.5157593063027874, 1.553090404454906, 1.5893557377456544, 1.6246368463020509, 1.6590054870440045, 1.692525194735838, 1.7252525374481997, 1.7572381364042942, 1.7885275020205844, 1.8191617250168628, 1.8491780521217833, 1.8786103690512272, 1.907489608356902, 1.935844095931091, 1.96369984706323, 1.9910808207306085, 2.0180091390948616, 2.044505277842471, 2.070588231959724, 2.0962756607030566, 2.121584014864368, 2.146528648900095, 2.1711239200641455, 2.195383276336545, 2.219319334655105, 2.2429439507237907, 2.266268281478543, 2.289302841131368, 2.3120575515802275, 2.3345417878607275, 2.356764419221911, 2.3787338463294145, 2.4004580350323375, 2.421944547073273, 2.4432005680724966, 2.4642329330757935, 2.485048149919804, 2.5056524206381408, 2.526051661105034, 2.546251519090388, 2.5662573908802084, 2.5860744365990724, 2.6057075943562036, 2.625161593323486, 2.644440965842189, 2.663550058644976, 2.682493043270822, 2.701273925742535, 2.7198965555695933, 2.7383646341328154, 2.7566817225018614, 2.7748512487316774, 2.792876514679646, 2.8107607023812853, 2.828506880018891, 2.84611800751438, 2.8635969417747935, 2.880946441616438, 2.8981691723913423, 2.9152677103377043, 2.932244546674151, 2.949102091455978, 2.9658426772100355, 2.982468562363569, 2.9989819344810797, 3.0153849133221624, 3.031679553732254, 3.0478678483772907, 3.0639517303324455, 3.0799330755343215, 3.0958137051052916, 3.1115953875580282, 3.1272798408876605, 3.142868734558479, 3.1583636913915933, 3.1737662893595044, 3.189078063293134, 3.204300506506453, 3.2194350723435234, 3.2344831756524197, 3.2494461941902046, 3.2643254699628463, 3.2791223105037255, 3.293837990094126], [0.0, 0.4258347183047368, 0.5817073679279383, 0.6981449986779218, 0.7946356822402044, 0.8785724254286441, 0.9536941732457854, 1.0221983711503373, 1.0855043313936132, 1.1445906550771103, 1.200165301609877, 1.2527597022141574, 1.3027846332858437, 1.3505652623400317, 1.3963641253801318, 1.440396751188327, 1.4828426155649397, 1.5238530239357009, 1.5635569123402175, 1.6020652007724818, 1.639474116758873, 1.675867771694058, 1.7113201852641877, 1.7458968957242589, 1.779656254949475, 1.8126504804410737, 1.8449265177305445, 1.8765267532830054, 1.9074896083569022, 1.9378500372125027, 1.9676399478214994, 1.9968885592983614, 2.0256227072926896, 2.0538671062986644, 2.0816445760730873, 2.1089762379780375, 2.1358816859833407, 2.162379136208371, 2.188485558200523, 2.214216790600139, 2.2395876433994766, 2.2646119886440745, 2.289302841131368, 2.3136724304203673, 2.3377322652672707, 2.361493191436833, 2.3849654437018684, 2.4081586927282044, 2.431082087445747, 2.453744293424794, 2.4761535277077025, 2.4983175904873214, 2.5202438939736256, 2.541939488747166, 2.563411087861209, 2.584665088922871, 2.605707594356204, 2.6265444300265908, 2.6471811623852823, 2.6676231142750386, 2.6878753795222865, 2.7079428364275304, 2.727830160253849, 2.7475418348027763, 2.7670821631576397, 2.78645527766625, 2.805665149227635, 2.8247155959411057, 2.843610291170275, 2.8623527710695873, 2.880946441616438, 2.899394585187923, 2.917700366717694, 2.9358668394651657, 2.9538969504264307, 2.9717935454136764, 2.9895593738275292, 3.007197093144692, 3.024709273141308, 3.042098399870802, 3.0593668794133926, 3.0765170414130507, 3.0935511424164344, 3.11047136902715, 3.1272798408876605, 3.1439786135001717, 3.1605696808970047, 3.177054978170117, 3.193436383868737, 3.2097157222734096, 3.2258947655541275, 3.2419752358196856, 3.2579588070648615, 3.2738471070215795, 3.2896417189197664, 3.305344183163213, 3.3209559989254, 3.3364786256698964, 3.3519134845996392, 3.367261960039105, 3.3825254007531322, 3.397705121205898], [0.0, 0.4383832905540869, 0.5988492227853417, 0.71871805808301, 0.8180521460508583, 0.904462351925639, 0.9817978005977356, 1.0523206922344737, 1.1174921636297988, 1.1783196534742952, 1.2355319834491842, 1.289676245085279, 1.3411753196094316, 1.3903639566301678, 1.4375124286079437, 1.4828426155649397, 1.5265392821258752, 1.5687581924113339, 1.6096320819707766, 1.649275139408055, 1.6877864278991912, 1.7252525374481995, 1.761749668966339, 1.7973452920014121, 1.8320994779519264, 1.8660659830736148, 1.8992931362971317, 1.9318245731393915, 1.96369984706323, 1.9949549423671946, 2.0256227072926896, 2.0557332219881803, 2.0853141129009014, 2.1143908228160875, 2.14298684394714, 2.1711239200641455, 2.198822222535472, 2.226100504276298, 2.2529762348956206, 2.2794657197696164, 2.305584205313995, 2.33134597235817, 2.356764419221911, 2.381852135847022, 2.406620970131749, 2.431082087445747, 2.4552460241619127, 2.479122735922952, 2.5027216412610436, 2.5260516611050337, 2.549121254638524, 2.571938451911818, 2.594510883559195, 2.6168458079289505, 2.6389501358957848, 2.6608304535926237, 2.6824930432708225, 2.7039439024733873, 2.725188761684733, 2.7462331006020846, 2.7670821631576397, 2.787740971406519, 2.8082143383832747, 2.8285068800188915, 2.8486230262007117, 2.8685670310492974, 2.8883429824788256, 2.9079548111010283, 2.9274062985268428, 2.946701085114734, 2.9658426772100355, 2.984834453915509, 3.0036796734296263, 3.0223814789857877, 3.0409429044226832, 3.0593668794133926, 3.077656234378365, 3.095813705105291, 3.1138419370969297, 3.131743489666165, 3.149520839796009, 3.1671763857807904, 3.1847124506634805, 3.202131285482906, 3.219435072343523, 3.2366259273194395, 3.2537059032034716, 3.270676992111205, 3.2875411279492868, 3.304300188756482, 3.3209559989253994, 3.3375103313122385, 3.3539649092413484, 3.370321408410944, 3.3865814587058494, 3.4027466459227447, 3.4188185134130182, 3.4347985636479677, 3.4506882597107875, 3.4664890267194712, 3.4822022531844965, 3.497829292304901], [0.0, 0.4505074887527553, 0.6154113656055918, 0.7385953672161814, 0.8406766998814358, 0.9294767196131484, 1.0089510050695996, 1.0814243212187917, 1.1483982149534744, 1.2109079873089443, 1.2697026167075784, 1.3253443253804131, 1.3782676900178812, 1.4288167182697884, 1.4772691574181662, 1.5238530239357009, 1.5687581924113339, 1.6121447348740718, 1.6541490578894587, 1.69488850813168, 1.7344648885289482, 1.7729671838717425, 1.8104737025306405, 1.8470537800328009, 1.882769149148314, 1.9176750528490198, 1.9518211566802348, 1.9852523029695963, 2.0180091390948616, 2.0501286445584936, 2.081644576073087, 2.1125878457022123, 2.14298684394714, 2.1728677172544373, 2.202254607552624, 2.2311698599708807, 2.259634203749358, 2.2876669104454024, 2.3152859328182744, 2.3425080271956733, 2.3693488616575684, 2.395823111992785, 2.421944547073273, 2.447726105036019, 2.473179961452037, 2.4983175904873214, 2.523149819915184, 2.5476868807177144, 2.5719384519118176, 2.59591370114904, 2.619621321565374, 2.6430695652951366, 2.666266274010129, 2.689218906799996, 2.711934565670842, 2.734420018905742, 2.7566817225018614, 2.7787258398739496, 2.8005582599922256, 2.8221846141037954, 2.8436102911702745, 2.864840452139832, 2.8858800431592657, 2.9067338078205913, 2.9274062985268423, 2.947901887053159, 2.9682247743715884, 2.988378999801282, 3.0083684495397374, 3.028196864625414, 3.0478678483772907, 3.0673848733526765, 3.0867512878607863, 3.105970322066218, 3.125045093713372, 3.1439786135001717, 3.162773790126916, 3.1814334350439246, 3.19996026691961, 3.2183569158487884, 3.23662592731944, 3.254769765954597, 3.272790819044739, 3.290691399884806, 3.3084737509288815, 3.32614004677452, 3.3436923969878394, 3.361132848779602, 3.3784633895417673, 3.395685949253296, 3.412802402763323, 3.429814571959249, 3.4467242278267447, 3.463533092408165, 3.4802428406654324, 3.496855102252997, 3.513371463206122, 3.5297934675493776, 3.5461226188298878, 3.5623603815795866, 3.578508182710452, 3.5945674128464282], [0.0, 0.46224543117757094, 0.6314458674893553, 0.7578394200056725, 0.8625804749516609, 0.9536941732457854, 1.035239155883151, 1.1096007594271875, 1.1783196534742952, 1.2424581137588564, 1.3027846332858437, 1.359876082948841, 1.4141783623048234, 1.466044442099856, 1.5157593063027874, 1.5635569123402175, 1.6096320819707766, 1.6541490578894587, 1.6972478007257303, 1.7390487146135076, 1.7796562549494748, 1.8191617250168628, 1.8576454735055963, 1.8951786424753465, 1.9318245731393915, 1.9676399478214996, 2.002675726099442, 2.0369779186646966, 2.070588231959724, 2.1035446089854464, 2.1358816859833407, 2.1676311804287236, 2.198822222535472, 2.229481639994067, 2.259634203749358, 2.2893028411313674, 2.3185088214792096, 2.3472719184693664, 2.3756105526190376, 2.4035419168409162, 2.4310820874457466, 2.4582461225990473, 2.4850481499198045, 2.5115014446472967, 2.5376184995862254, 2.563411087861209, 2.588890319362469, 2.614066691639647, 2.638950135895785, 2.6635500586449754, 2.6878753795222865, 2.7119345656708425, 2.7357356630766767, 2.7592863251755153, 2.7825938390157563, 2.805665149227635, 2.828506880018892, 2.8511253553916336, 2.8735266177528036, 2.8957164450712742, 2.917700366717694, 2.9394836781083913, 2.961071454261687, 2.9824685623635694, 3.0036796734296267, 3.024709273141308, 3.045561671926706, 3.0662410143491616, 3.0867512878607872, 3.107096330972549, 3.1272798408876605, 3.1473053806406788, 3.1671763857807904, 3.186896170634315, 3.206467934178276, 3.225894765554128, 3.2451796492481613, 3.2643254699628463, 3.283335017201317, 3.3022109895853355, 3.3209559989254, 3.3395725740601305, 3.3580631644806997, 3.376430143754794, 3.3946758127634853, 3.412802402763323, 3.4308120782850287, 3.4487069398793033, 3.4664890267194717, 3.484160319069966, 3.50172274062899, 3.5191781607530994, 3.5365283965708767, 3.553775214992375, 3.5709203346205376, 3.587965427570352, 3.6049121212011253, 3.6217619997668824, 3.6385166059895675, 3.6551774425593964, 3.6717459735664426, 3.688223625867264], [0.0, 0.47362990989388454, 0.6469975237180032, 0.776503978193861, 0.8838246634191993, 0.9771823686607838, 1.0607356937427515, 1.136928722836417, 1.2073400701430301, 1.2730581738091313, 1.3348704537812455, 1.3933679885015167, 1.4490076594288999, 1.502151130500729, 1.553090404454906, 1.6020652007724818, 1.649275139408055, 1.69488850813168, 1.7390487146135076, 1.781879128378148, 1.823486777417189, 1.8639652136900284, 1.9033967647659673, 1.9418543248372224, 1.9794027951253403, 2.0161002539629296, 2.051998915993121, 2.0871459250883895, 2.1215840148643683, 2.155352062806686, 2.188485558200523, 2.221016999679642, 2.2529762348956206, 2.2843907522686115, 2.315285932818275, 2.34568526854371, 2.3756105526190376, 2.4050820457196016, 2.434118622034984, 2.4627378979160253, 2.490956345611222, 2.518789394148309, 2.5462515190903883, 2.573356322627896, 2.6001166052463875, 2.626544430026591, 2.6526511804802726, 2.678447612697499, 2.7039439024733882, 2.7291496879917303, 2.754074108566122, 2.7787258398739505, 2.8031131260629842, 2.827243809062703, 2.8511253553916336, 2.8747648807168464, 2.8981691723913428, 2.921344710168835, 2.9442976852725615, 2.9670340179749406, 2.9895593738275297, 3.0118791786655854, 3.033998632498255, 3.0559227223837233, 3.077656234378365, 3.099203764639885, 3.120569729756381, 3.1417583763661723, 3.1627737901269164, 3.183619904086903, 3.204300506506453, 3.224819248172836, 3.2451796492481613, 3.265385105686115, 3.2854388952501914, 3.3053441831632133, 3.3251040274153247, 3.3447213837553105, 3.3641991103879874, 3.383539972398515, 3.402746645922745, 3.4218217220811677, 3.4407677106926045, 3.4595870437824976, 3.4782820788995035, 3.496855102252997, 3.515308331683158, 3.5336439194744065, 3.5518639550221427, 3.56997046736203, 3.587965427570352, 3.6058507510433837, 3.6236282996631224, 3.641299883856223, 3.65886726455249, 3.6763321550488386, 3.6936962227842294, 3.7109610910307187, 3.728128340505402, 3.7451995109077187, 3.7621761023862983, 3.7790595769392414], [0.0, 0.4846893733285307, 0.6621051959878331, 0.7946356822402044, 0.9044623519256388, 1.0, 1.0855043313936132, 1.1634765007012597, 1.2355319834491842, 1.3027846332858437, 1.3660402567543954, 1.425903734234491, 1.4828426155649397, 1.5372270096925797, 1.5893557377456544, 1.639474116758873, 1.6877864278991912, 1.7344648885289482, 1.7796562549494748, 1.823486777417189, 1.8660659830736146, 1.907489608356902, 1.9478419032207352, 1.987197463968276, 2.02562270729269, 2.063177067680795, 2.0999139790102435, 2.1358816859833407, 2.1711239200641455, 2.2056804665444063, 2.2395876433994766, 2.272878708120284, 2.305584205313995, 2.3377322652672707, 2.3693488616575684, 2.400458035032337, 2.4310820874457466, 2.461241752668682, 2.490956345611222, 2.520243893973626, 2.549121254638524, 2.577604216908128, 2.605707594356204, 2.6334453067902244, 2.6608304535926233, 2.6878753795222865, 2.714591733900907, 2.740990523977912, 2.7670821631576397, 2.7928765146796453, 2.8183829312644537, 2.843610291170275, 2.868567031049297, 2.8932611759434477, 2.917700366717694, 2.9418918851930123, 2.9658426772100355, 2.9895593738275292, 3.013048310836476, 3.0363155467502176, 3.0593668794133926, 3.08220786135686, 3.104843814012232, 3.1272798408876605, 3.1495208397960086, 3.171571514217254, 3.193436383868737, 3.215119794549622, 3.23662592731944, 3.2579588070648615, 3.279122310503726, 3.3001201736707655, 3.3209559989253994, 3.3416332615183024, 3.3621553157501642, 3.3825254007531327, 3.4027466459227442, 3.4228220760257977, 3.4427546160074294, 3.462547095518735, 3.4822022531844965, 3.5017227406289897, 3.5211111262763914, 3.540369898940991, 3.559501471221227, 3.578508182710452, 3.5973923030363757, 3.61615603474019, 3.634801516005582, 3.653330823247077, 3.671745973566442, 3.690048927085286, 3.7082415891613554, 3.7263258124955514, 3.7443033991361525, 3.762176102386298, 3.7799456286203705, 3.7976136390145316, 3.815181751196304, 3.832651540817778, 3.8500245430567, 3.8673022540494615], [0.0, 0.4954486879303019, 0.6768028528689379, 0.812275300043874, 0.9245399429051914, 1.0221983711503373, 1.1096007594271875, 1.189303783888522, 1.2629587809859018, 1.331704330104479, 1.3963641253801318, 1.4575564745516802, 1.5157593063027874, 1.571350945396059, 1.6246368463020509, 1.675867771694058, 1.7252525374481995, 1.7729671838717425, 1.8191617250168628, 1.8639652136900284, 1.907489608356902, 1.9498327706486203, 1.9910808207306088, 2.031310010822453, 2.070588231959724, 2.108976237978038, 2.146528648900095, 2.1832947803820075, 2.219319334655105, 2.254642980179809, 2.2893028411313674, 2.3233329132628375, 2.356764419221911, 2.3896261137417927, 2.421944547073273, 2.4537442934247946, 2.4850481499198045, 2.5158773105851284, 2.5462515190903883, 2.5761892033214244, 2.605707594356204, 2.6348228319937292, 2.663550058644976, 2.691903503114468, 2.7198965555695933, 2.7475418348027763, 2.7748512487316774, 2.801836048948732, 2.828506880018892, 2.854873824129565, 2.880946441616438, 2.9067338078205918, 2.932244546674151, 2.957486861361902, 2.982468562363569, 3.0071970931446925, 3.0316795537322543, 3.055922722383723, 3.0799330755343215, 3.103716806186519, 3.1272798408876605, 3.150627855425747, 3.173766289359505, 3.196700359486653, 3.219435072343523, 3.241975235819686, 3.264325469962847, 3.2864902170418313, 3.308473750928882, 3.330280185856598, 3.3519134845996397, 3.3733774661266254, 3.394675812763485, 3.4158120769057985, 3.4367896873142665, 3.4576119550244946, 3.4782820788995035, 3.498803150850987, 3.5191781607531, 3.5394100010705825, 3.5595014712212274, 3.579455281691049, 3.5992740579190574, 3.618960343967166, 3.638516605989568, 3.657945235514778, 3.6772485525525442, 3.6964288085368855, 3.7154881891156832, 3.7344288167964836, 3.7532527534574274, 3.7719620027316294, 3.790558512272676, 3.80904417590841, 3.8274208356896473, 3.845690283839999, 3.863854264612581, 3.8819144760589595, 3.8998725717153544, 3.917730162210763, 3.935488816801381, 3.953150064835388], [0.0, 0.5059297366645512, 0.6911203873729271, 0.8294587081601642, 0.9440982714151107, 1.0438226305440854, 1.1330739866622799, 1.2144631015382163, 1.2896762450852788, 1.359876082948841, 1.425903734234491, 1.4883905867712808, 1.5478246796618675, 1.604592341000727, 1.6590054870440045, 1.7113201852641877, 1.761749668966339, 1.8104737025306405, 1.8576454735055963, 1.9033967647659673, 1.9478419032207352, 1.9910808207306088, 2.0332014593038656, 2.0742816842499012, 2.1143908228160875, 2.1535909140647997, 2.19193773348677, 2.229481639994067, 2.2662682814785433, 2.302339186728088, 2.3377322652672707, 2.3724822320177577, 2.406620970131749, 2.440177842639066, 2.4731799614520376, 2.5056524206381403, 2.5376184995862254, 2.5690998406755585, 2.6001166052463875, 2.6306876110202193, 2.6608304535926237, 2.690561614194569, 2.7198965555695933, 2.7488498075277477, 2.7774350435008643, 2.805665149227635, 2.833552284533675, 2.861107939035035, 2.8883429824788256, 2.9152677103377047, 2.9418918851930123, 2.968224774371589, 2.9942751842419146, 3.0200514915243635, 3.045561671926706, 3.0708133263784685, 3.095813705105292, 3.1205697297563804, 3.145088013773744, 3.1693748811707154, 3.193436383868737, 3.217278317725177, 3.2409062373707793, 3.264325469962847, 3.2875411279492868, 3.3105581209289423, 3.333381166685057, 3.356014801461146, 3.3784633895417677, 3.4007311321947142, 3.4228220760257986, 3.4447401207926225, 3.4664890267194712, 3.4880724213516463, 3.5094938059841168, 3.5307565616963217, 3.5518639550221427, 3.5728191432816154, 3.593625179598668, 3.6142850176271484, 3.6348015160055827, 3.6551774425593964, 3.6754154782678703, 3.695518221011683, 3.7154881891156832, 3.7353278247003585, 3.7550394968544754, 3.7746255046403743, 3.7940880799425765, 3.8134293901695533, 3.832651540817778, 3.851756577906543, 3.8707464902913857, 3.889623211863433, 3.9083886236414593, 3.92704455576296, 3.945592789380132, 3.964035058466245, 3.982373051537517, 4.000608413295255, 4.018742746192735, 4.0367776119309795], [0.0, 0.516151895070922, 0.70508426726695, 0.8462176722848181, 0.9631734934908291, 1.06491275335031, 1.15596740631806, 1.2390009638201624, 1.3157337663472404, 1.3873519708549016, 1.4547136910076877, 1.5184630716361405, 1.5790980125264353, 1.6370126474161888, 1.692525194735838, 1.7458968957242589, 1.7973452920014121, 1.8470537800328009, 1.8951786424753465, 1.9418543248372224, 1.987197463968276, 2.031310010822453, 2.0742816842499012, 2.11619192280521, 2.157111454471967, 2.197103571793174, 2.2362251771866033, 2.2745276470510216, 2.3120575515802275, 2.3488572586388003, 2.384965443701869, 2.4204175230956673, 2.4552460241619127, 2.4894809032016263, 2.5231498199151843, 2.556278375388161, 2.588890319362469, 2.6210077314951485, 2.6526511804802726, 2.683839864245761, 2.7145917339009076, 2.7449236036750038, 2.774851248731678, 2.8043894924514294, 2.833552284533675, 2.8623527710695877, 2.890803357570407, 2.9189157657964273, 2.946701085114734, 2.974169819014919, 3.001331927328347, 3.0281968646254143, 3.054773615204631, 3.0810707250354925, 3.1070963309725483, 3.1328581875198247, 3.1583636913915933, 3.183619904086903, 3.2086335726703723, 3.2334111489301263, 3.2579588070648615, 3.2822824600355043, 3.306387774702444, 3.3302801858565982, 3.3539649092413484, 3.3774469536525076, 3.4007311321947142, 3.423822072764921, 3.446724227826745, 3.469441883533333, 3.491979168250953, 3.514340060530638, 3.5365283965708763, 3.5585478772104318, 3.5804020744868885, 3.602094437793379, 3.623628299663122, 3.645006881208856, 3.666233297241961, 3.687310561093975, 3.7082415891613554, 3.729029205192611, 3.749676144335403, 3.7701850569598094, 3.790558512272676, 3.8107990017368016, 3.83090894230768, 3.850890679499515, 3.8707464902913853, 3.8904785858835993, 3.9100891143135548, 3.929580162939749, 3.948953760801948, 3.9682118808649687, 3.987356442153005, 4.00638931178093, 4.025312306888587, 4.044127196483655, 4.0628357031983136, 4.0814395049645675, 4.099940236612779, 4.1183394913976725], [0.0, 0.5261324141285761, 0.71871805808301, 0.8625804749516609, 0.9817978005977356, 1.0855043313936132, 1.1783196534742955, 1.2629587809859018, 1.3411753196094316, 1.4141783623048234, 1.48284261556494, 1.5478246796618675, 1.6096320819707768, 1.6686665773565474, 1.7252525374481997, 1.779656254949475, 1.8320994779519264, 1.882769149148314, 1.9318245731393915, 1.9794027951253403, 2.02562270729269, 2.070588231959724, 2.1143908228160875, 2.157111454471967, 2.198822222535472, 2.239587643399477, 2.2794657197696164, 2.31850882147921, 2.356764419221911, 2.394275700104239, 2.4310820874457466, 2.467219682396889, 2.5027216412610436, 2.5376184995862254, 2.571938451911818, 2.605707594356204, 2.638950135895785, 2.6716885831286623, 2.703943902473388, 2.7357356630766776, 2.7670821631576397, 2.7980005420722156, 2.8285068800188915, 2.8586162870089713, 2.8883429824788256, 2.9177003667176944, 2.9467010851147335, 2.9753570860868734, 3.003679673429627, 3.0316795537322534, 3.0593668794133926, 3.0867512878607872, 3.1138419370969297, 3.1406475383395915, 3.1671763857807904, 3.1934363838687374, 3.2194350723435234, 3.2451796492481613, 3.270676992111205, 3.2959336774751287, 3.3209559989254, 3.345749983758317, 3.3703214084109443, 3.3946758127634857, 3.4188185134130182, 3.44275461600743, 3.4664890267194717, 3.490026462932959, 3.513371463206122, 3.5365283965708767, 3.5595014712212274, 3.5822947426390592, 3.604912121201125, 3.6273573793070844, 3.649634158064865, 3.671745973566443, 3.693696222784229, 3.715488189115683, 3.737125047601421, 3.758609869839962, 3.779945628620371, 3.801135202292283, 3.8221813788912673, 3.843086860036015, 3.863854264612581, 3.8844861322596835, 3.904984926668032, 3.92535303870563, 3.9455927893801315, 3.9657064326484974, 3.985696158083433, 4.005564093405433, 4.025312306888587, 4.044942809647746, 4.064457557814123, 4.083858454605869, 4.103147352299767, 4.1223260541097355, 4.141396315977459, 4.160359848280104, 4.179218317459765, 4.197973347578975], [0.0, 0.5358867312681466, 0.7320428479728127, 0.8785724254286441, 1.0, 1.1056292148268607, 1.2001653016098772, 1.2863736099398373, 1.3660402567543957, 1.440396751188327, 1.5103340164972456, 1.5765208261003691, 1.6394741167588731, 1.6996030917370502, 1.7572381364042942, 1.8126504804410737, 1.8660659830736148, 1.9176750528490198, 1.9676399478214996, 2.0161002539629296, 2.063177067680795, 2.108976237978038, 2.1535909140647997, 2.197103571793174, 2.239587643399477, 2.2811088413887024, 2.3217262438170447, 2.361493191436833, 2.4004580350323375, 2.438664762384436, 2.476153527707703, 2.5129611014557196, 2.5491212546385245, 2.584665088922871, 2.6196213215653743, 2.654016532497632, 2.687875379522287, 2.7212207865021614, 2.754074108566122, 2.7864552776662506, 2.8183829312644537, 2.849874526474539, 2.8809464416164383, 2.9116140668359574, 2.9418918851930123, 2.9717935454136764, 3.0013319273283465, 3.030519200873565, 3.059366879413393, 3.087885868033636, 3.1160865073753445, 3.143978613500172, 3.171571514217254, 3.198874082247394, 3.225894765554128, 3.2526416151314637, 3.2791223105037264, 3.305344183163213, 3.3313142381455325, 3.357039173920034, 3.3825254007531327, 3.407779057685163, 3.43280602824638, 3.4576119550244946, 3.4822022531844965, 3.5065821230312606, 3.5307565616963217, 3.554730374022197, 3.578508182710453, 3.602094437793379, 3.625493425483476, 3.648709276449892, 3.6717459735664426, 3.694607359171803, 3.7172971418788108, 3.739818902966599, 3.7621761023862983, 3.7843720844084485, 3.806410082937845, 3.8282932265194063, 3.850024543056701, 3.8716069642629933, 3.89304332986309, 3.914336391562781, 3.935488816801381, 3.956503192301654, 3.9773820274303007, 3.998127757381211, 4.018742746192736, 4.039229289609435, 4.059589617797953, 4.079825897926005, 4.09994023661278, 4.1199346822585206, 4.13981122726045, 4.159571810121743, 4.179218317459766, 4.198752585919414, 4.218176403996938, 4.237491513779318, 4.256699612603923, 4.275802354642855], [0.0, 0.5454287253304186, 0.7450775959915877, 0.894216277716006, 1.0178059905302963, 1.1253160381560867, 1.2215354336051327, 1.3092787662568492, 1.3903639566301678, 1.466044442099856, 1.53722700969258, 1.604592341000727, 1.6686665773565474, 1.7298662082937823, 1.7885275020205844, 1.8449265177305445, 1.8992931362971317, 1.9518211566802348, 2.002675726099442, 2.051998915993121, 2.0999139790102435, 2.146528648900095, 2.19193773348677, 2.2362251771866033, 2.2794657197696164, 2.3217262438170447, 2.3630668793283913, 2.4035419168409162, 2.443200568072497, 2.482087604050021, 2.520243893973626, 2.557706863031243, 2.594510883559195, 2.6306876110202193, 2.6662662740101295, 2.7012739257425347, 2.735735663076677, 2.7696748180574646, 2.8031131260629847, 2.83607087395347, 2.8685670310492974, 2.9006193653054773, 2.932244546674151, 2.963458239337916, 2.9942751842419146, 3.024709273141308, 3.054773615204631, 3.0844805970662006, 3.11384193709693, 3.142868734558479, 3.171571514217254, 3.1999602669196103, 3.2280444865655635, 3.255833203863501, 3.283335017201317, 3.310558120928942, 3.337510331312239, 3.364199110387987, 3.390631587923393, 3.416814581660688, 3.4427546160074294, 3.468457939315647, 3.493930539877679, 3.5191781607531, 3.5442063135292763, 3.5690202911076616, 3.593625179598668, 3.618025869399793, 3.642227065524383, 3.666233297241961, 3.6900489270852863, 3.713678159274163, 3.7371250476014204, 3.760393502822379, 3.7834872995854023, 3.806410082937845, 3.8291653744386958, 3.851756577906543, 3.874186984829061, 3.8964597794580085, 3.9185780436117765, 3.9405447612056896, 3.962362822528666, 3.984035028283342, 4.005564093405433, 4.026952650676864, 4.048203254146095, 4.069318382368055, 4.09030044147514, 4.111151768089916, 4.131874632089353, 4.152471239229733, 4.172943733640688, 4.193294200196255, 4.213524666770264, 4.233637106382858, 4.253633439244495, 4.273515534703352, 4.293285213101627, 4.312944247545883, 4.332494365596264, 4.351937250879045], [0.0, 0.5547709273270172, 0.7578394200056725, 0.9095325760829622, 1.035239155883151, 1.1445906550771106, 1.2424581137588566, 1.331704330104479, 1.4141783623048234, 1.491155116837037, 1.5635569123402178, 1.632076089244354, 1.6972478007257303, 1.7594956700262576, 1.8191617250168628, 1.8765267532830054, 1.9318245731393915, 1.9852523029695963, 2.0369779186646966, 2.0871459250883895, 2.1358816859833407, 2.1832947803820075, 2.229481639994067, 2.2745276470510216, 2.31850882147921, 2.361493191436833, 2.4035419168409162, 2.4447102181268754, 2.4850481499198045, 2.524601250092849, 2.563411087861209, 2.601515729438213, 2.6389501358957848, 2.675746504897163, 2.7119345656708425, 2.7475418348027763, 2.7825938390157563, 2.817114309990182, 2.851125355391634, 2.8846476095573603, 2.9177003667176944, 2.9503016991603963, 2.9824685623635694, 3.014216888808765, 3.045561671926706, 3.076517041413051, 3.107096330972549, 3.137312139400031, 3.1671763857807913, 3.1967003594866528, 3.225894765554128, 3.254769765954598, 3.283335017201317, 3.3115997046822816, 3.339572574060131, 3.3672619600391056, 3.3946758127634857, 3.4218217220811677, 3.4487069398793038, 3.4753384006756467, 3.50172274062899, 3.5278663151142684, 3.5537752149923754, 3.5794552816910494, 3.6049121212011253, 3.63015111708183, 3.655177442559397, 3.679996071794937, 3.704611790390118, 3.7290292051926115, 3.753252753457428, 3.7772867114150093, 3.801135202292283, 3.8248022038286953, 3.84829155532547, 3.8716069642629938, 3.8947520125181545, 3.917730162210763, 3.9405447612056896, 3.9631990482951354, 3.9856961580834334, 4.008039125594951, 4.030230890623997, 4.052274301844153, 4.074172120693043, 4.095927025047357, 4.117541612701761, 4.139018404664321, 4.160359848280104, 4.1815683201937714, 4.202646129161157, 4.2235955187191365, 4.244418669722381, 4.265117702755029, 4.285694680424701, 4.3061516095457835, 4.32649044321845, 4.346713082809412, 4.366821379840015, 4.386817137786918, 4.406702113800222, 4.42647802034366], [0.0, 0.5639246960073655, 0.7703438365240459, 0.9245399429051914, 1.0523206922344739, 1.16347650070126, 1.262958780985902, 1.3536775676840487, 1.4375124286079437, 1.5157593063027874, 1.5893557377456546, 1.6590054870440047, 1.7252525374481997, 1.7885275020205844, 1.8491780521217833, 1.9074896083569022, 1.96369984706323, 2.0180091390948616, 2.070588231959724, 2.1215840148643683, 2.1711239200641455, 2.219319334655105, 2.2662682814785433, 2.3120575515802275, 2.356764419221911, 2.4004580350323375, 2.443200568072497, 2.4850481499198045, 2.526051661105034, 2.5662573908802084, 2.605707594356204, 2.6444409658421884, 2.682493043270822, 2.7198965555695933, 2.7566817225018614, 2.7928765146796457, 2.8285068800188915, 2.8635969417747935, 2.8981691723913428, 2.9322445466741516, 2.9658426772100355, 2.9989819344810797, 3.0316795537322543, 3.063951730332446, 3.0958137051052916, 3.127279840887661, 3.158363691391593, 3.189078063293134, 3.2194350723435234, 3.2494461941902046, 3.279122310503726, 3.308473750928882, 3.3375103313122385, 3.3662413886014946, 3.3946758127634853, 3.4228220760257986, 3.4506882597107884, 3.4782820788995035, 3.5056109051358653, 3.532681787357776, 3.5595014712212274, 3.5860764169653936, 3.6124128159509055, 3.6385166059895684, 3.6643934855715536, 3.6900489270852868, 3.7154881891156837, 3.740716327897948, 3.765738207996592, 3.790558512272676, 3.815181751196305, 3.8396122715560965, 3.8638542646125806, 3.8879117737382525, 3.911788701583141, 3.9354888168013815, 3.9590157603711438, 3.982373051537517, 4.005564093405434, 4.0285921782074485, 4.051460492269141, 4.074172120693043, 4.0967300517803285, 4.119137181207938, 4.14139631597746, 4.163510178150782, 4.1854814083864085, 4.20731256928926, 4.2290061485858095, 4.250564562135562, 4.271990156789025, 4.293285213101627, 4.314451947912333, 4.335492516795103, 4.356409016390764, 4.377203486626315, 4.397877912828253, 4.418434227736005, 4.438874313421181, 4.45920000311796, 4.479413082969576, 4.499515293695563], [0.0, 0.5729003651476003, 0.7826049619009149, 0.9392553201411978, 1.0690698830923897, 1.1819948954384827, 1.2830605786836138, 1.3752232847915171, 1.4603924975879197, 1.5398847863995628, 1.6146526104471697, 1.6854109352518392, 1.7527124023364071, 1.8169944785867922, 1.8786103690512272, 1.9378500372125027, 1.9949549423671946, 2.0501286445584936, 2.1035446089854464, 2.155352062806686, 2.2056804665444063, 2.254642980179809, 2.302339186728088, 2.3488572586388003, 2.394275700104239, 2.438664762384436, 2.482087604050021, 2.524601250092849, 2.5662573908802084, 2.6071030524238594, 2.647181162385282, 2.6865310309489887, 2.725188761684733, 2.763187604447755, 2.8005582599922256, 2.837329144122513, 2.8735266177528036, 2.9091751880944465, 2.944297685272561, 2.9789154179368307, 3.013048310836476, 3.0467150268461145, 3.0799330755343215, 3.112718910042474, 3.1450880137737434, 3.177054978170117, 3.2086335726703723, 3.2398368077871442, 3.270676992111205, 3.3011657839413613, 3.331314238145532, 3.361132848779602, 3.3906315879233926, 3.4198199411354966, 3.448706939879303, 3.477301191230035, 3.5056109051358653, 3.533643919474406, 3.5614077231182573, 3.588909477199263, 3.61615603474019, 3.643153958804171, 3.6699095392962082, 3.696428808536885, 3.7227175557160055, 3.748781340322893, 3.774625504640374, 3.8002551853808764, 3.8256753245354234, 3.8508906794995146, 3.875905832533847, 3.900725199612404, 3.9253530387056292, 3.9497934575420817, 3.9740504208880543, 3.9981277573812104, 4.022029165951102, 4.045758221856643, 4.069318382368055, 4.092712992118489, 4.115945288148458, 4.13901840466432, 4.161935377530341, 4.184699148512308, 4.207312569289259, 4.229778405248595, 4.252099339078684, 4.274277974171969, 4.296316837850656, 4.318218384426115, 4.339984998102337, 4.361618995733058, 4.383122629441409, 4.404498089110398, 4.425747504751892, 4.446872948761251, 4.467876438064285, 4.488759936162737, 4.509525355084083, 4.530174557241049, 4.550709357205896, 4.571131523404202], [0.0, 0.5817073679279383, 0.7946356822402044, 0.9536941732457853, 1.0855043313936132, 1.200165301609877, 1.3027846332858437, 1.3963641253801318, 1.4828426155649397, 1.5635569123402175, 1.639474116758873, 1.7113201852641877, 1.779656254949475, 1.8449265177305443, 1.907489608356902, 1.9676399478214994, 2.0256227072926896, 2.081644576073087, 2.1358816859833407, 2.188485558200523, 2.2395876433994766, 2.2893028411313674, 2.3377322652672707, 2.384965443701869, 2.4310820874457466, 2.476153527707703, 2.520243893973626, 2.563411087861209, 2.605707594356204, 2.647181162385282, 2.6878753795222865, 2.7278301602538484, 2.7670821631576397, 2.805665149227635, 2.8436102911702745, 2.8809464416164374, 2.917700366717694, 2.9538969504264307, 2.9895593738275292, 3.024709273141308, 3.0593668794133926, 3.093551142416434, 3.1272798408876605, 3.1605696808970047, 3.193436383868737, 3.225894765554128, 3.257958807064861, 3.289641718919766, 3.3209559989254, 3.351913484599639, 3.3825254007531322, 3.4128024027633233, 3.4427546160074294, 3.472391671862315, 3.5017227406289897, 3.5307565616963212, 3.5595014712212274, 3.5879654275703516, 3.61615603474019, 3.644080563948234, 3.6717459735664426, 3.6991589275496897, 3.726325812495552, 3.7532527534574274, 3.77994562862037, 3.806410082937845, 3.832651540817778, 3.858675217937533, 3.8844861322596835, 3.9100891143135548, 3.935488816801381, 3.9606897235824143, 3.9856961580834325, 4.010512291179711, 4.035142148586547, 4.059589617797953, 4.083858454605868, 4.107952289230447, 4.131874632089353, 4.155628879231646, 4.179218317459765, 4.202646129161157, 4.225915396869399, 4.249029107573045, 4.271990156789025, 4.294801352416103, 4.317465418382702, 4.339984998102337, 4.362362657748878, 4.384600889362988, 4.406702113800221, 4.428668683530515, 4.450502885298127, 4.472206942650393, 4.493783018343128, 4.515233216629923, 4.536559585442103, 4.557764118465657, 4.578848757121011, 4.599815392451128, 4.620665866923074, 4.641401976147829], [0.0, 0.5903543426026443, 0.8064477977449885, 0.9678706644132353, 1.1016401566905811, 1.218005541463547, 1.3221502909201035, 1.4171208252167509, 1.5048848024965538, 1.5867989026757126, 1.6638446025891402, 1.7367586498911747, 1.8061105228763967, 1.872351016293, 1.935844095931091, 1.9968885592983614, 2.0557332219881803, 2.1125878457022123, 2.1676311804287236, 2.221016999679642, 2.272878708120284, 2.3233329132628375, 2.3724822320177577, 2.4204175230956673, 2.467219682396889, 2.5129611014557196, 2.557706863031243, 2.601515729438213, 2.6444409658421884, 2.6865310309489887, 2.7278301602538484, 2.7683788615650142, 2.8082143383832743, 2.847370853553666, 2.8858800431592657, 2.923771188720084, 2.961071454261687, 2.9978060936319073, 3.033998632498255, 3.0696710286995446, 3.104843814012232, 3.1395362198939063, 3.173766289359505, 3.207550976811664, 3.240906237370779, 3.2738471070215795, 3.3063877747024435, 3.3385416473041682, 3.3703214084109443, 3.4017390715032056, 3.4328060282463797, 3.463533092408165, 3.4939305398776788, 3.5240081452004577, 3.5537752149923745, 3.58324061855173, 3.612412815950905, 3.641299883856222, 3.669909539296208, 3.6982491615736848, 3.7263258124955514, 3.7541462550751636, 3.7817169708457135, 3.8090441759084106, 3.836133835826463, 3.8629916794645482, 3.889623211863433, 3.9160337262305807, 3.9422283151196695, 3.9682118808649682, 3.993989145330288, 4.019564659026636, 4.044942809647746, 4.0701278300681984, 4.095123805844822, 4.1199346822585206, 4.144564270930401, 4.169016256043184, 4.193294200196255, 4.217401549920329, 4.241341640875566, 4.265117702755028, 4.288732863913596, 4.312190155740865, 4.335492516795103, 4.358642796713978, 4.381643759916617, 4.404498089110398, 4.4272083886149005, 4.449777187514522, 4.472206942650393, 4.494500041461494, 4.516658804684121, 4.538685488918236, 4.56058228906863, 4.58235134066824, 4.603994722090523, 4.625514456657245, 4.646912514647698, 4.668190815214855, 4.689351228213721, 4.71039557594671], [0.0, 0.5988492227853417, 0.8180521460508583, 0.9817978005977356, 1.1174921636297988, 1.2355319834491842, 1.3411753196094316, 1.4375124286079437, 1.5265392821258754, 1.6096320819707766, 1.6877864278991912, 1.7617496689663392, 1.8320994779519264, 1.8992931362971315, 1.96369984706323, 2.0256227072926896, 2.0853141129009014, 2.14298684394714, 2.198822222535472, 2.2529762348956206, 2.305584205313995, 2.356764419221911, 2.406620970131749, 2.4552460241619127, 2.5027216412610436, 2.5491212546385245, 2.594510883559195, 2.6389501358957848, 2.682493043270822, 2.725188761684733, 2.7670821631576397, 2.8082143383832743, 2.8486230262007117, 2.8883429824788256, 2.9274062985268428, 2.965842677210035, 3.0036796734296267, 3.0409429044226832, 3.077656234378365, 3.11384193709693, 3.149520839796009, 3.1847124506634805, 3.219435072343523, 3.253705903203471, 3.2875411279492868, 3.3209559989254, 3.353964909241348, 3.386581458705849, 3.4188185134130182, 3.450688259710787, 3.4822022531844965, 3.513371463206122, 3.544206313529276, 3.574716719349927, 3.604912121201125, 3.634801516005582, 3.664393485571554, 3.6936962227842285, 3.722717555716006, 3.7514649698538913, 3.77994562862037, 3.8081663923449094, 3.8361338358264634, 3.863854264612581, 3.8913337301077036, 3.9185780436117765, 3.9455927893801315, 3.9723833367866286, 3.998954851664043, 4.025312306888587, 4.051460492269141, 4.077404023796108, 4.103147352299766, 4.128694771563475, 4.154050425933019, 4.179218317459765, 4.204202312611987, 4.229006148585809, 4.253633439244494, 4.278087680712475, 4.30237225664826, 4.326490443218449, 4.3504454137932616, 4.374240243382351, 4.397877912828252, 4.421361312773381, 4.444693247415363, 4.467876438064285, 4.490913526514479, 4.513807078242502, 4.536559585442102, 4.559173469906217, 4.581651085765285, 4.603994722090522, 4.626206605370213, 4.648288901866464, 4.670243719859401, 4.692073111785299, 4.713779076274702, 4.735363560096161, 4.756828460010884, 4.778175624543232], [0.0, 0.6071993149974168, 0.8294587081601642, 0.9954875606519824, 1.1330739866622799, 1.2527597022141574, 1.359876082948841, 1.4575564745516802, 1.5478246796618673, 1.6320760892443538, 1.7113201852641877, 1.786314737485656, 1.8576454735055965, 1.9257760508980362, 1.9910808207306085, 2.0538671062986644, 2.1143908228160875, 2.1728677172544373, 2.229481639994067, 2.2843907522686115, 2.3377322652672707, 2.3896261137417927, 2.440177842639066, 2.4894809032016263, 2.5376184995862254, 2.584665088922871, 2.6306876110202193, 2.675746504897163, 2.7198965555695933, 2.763187604447755, 2.805665149227635, 2.847370853553666, 2.8883429824788256, 2.9286167764926536, 2.968224774371589, 3.007197093144692, 3.045561671926706, 3.083344485150269, 3.1205697297563804, 3.1572599901214486, 3.193436383868737, 3.229118691199783, 3.264325469962847, 3.2990741583317917, 3.3333811666850566, 3.3672619600391056, 3.400731132194714, 3.433802472590397, 3.4664890267194717, 3.498803150850987, 3.5307565616963212, 3.5623603815795875, 3.5936251795986673, 3.6245610092026963, 3.6551774425593964, 3.6854836020406445, 3.7154881891156837, 3.7451995109077187, 3.7746255046403743, 3.80377376017502, 3.832651540817778, 3.8612658025555553, 3.889623211863433, 3.9177301622107636, 3.9455927893801315, 3.9732169857017117, 4.000608413295255, 4.027772516402828, 4.054714532887323, 4.0814395049645675, 4.107952289230448, 4.134257566038722, 4.160359848280104, 4.186263489608592, 4.211972692156922, 4.237491513779318, 4.262823874856401, 4.287973564694123, 4.312944247545883, 4.337739468284546, 4.3623626577488785, 4.386817137786917, 4.411106126016969, 4.435232740325283, 4.45920000311796, 4.483010845343272, 4.506668110299352, 4.5301745572410494, 4.553532864798721, 4.576745634220811, 4.599815392451128, 4.622744595051034, 4.645535628975933, 4.668190815214856, 4.690712411301265, 4.713102613702678, 4.735363560096162, 4.757497331536268, 4.779505954521571, 4.801391402965511, 4.82315560007691, 4.844800420155144], [0.0, 0.6154113656055918, 0.8406766998814358, 1.0089510050695996, 1.1483982149534746, 1.2697026167075784, 1.3782676900178812, 1.4772691574181664, 1.5687581924113339, 1.6541490578894589, 1.7344648885289484, 1.8104737025306408, 1.882769149148314, 1.9518211566802348, 2.0180091390948616, 2.0816445760730873, 2.14298684394714, 2.202254607552624, 2.259634203749358, 2.315285932818275, 2.3693488616575684, 2.421944547073273, 2.4731799614520376, 2.5231498199151843, 2.571938451911818, 2.6196213215653743, 2.6662662740101295, 2.7119345656708425, 2.7566817225018614, 2.8005582599922256, 2.8436102911702745, 2.8858800431592657, 2.9274062985268428, 2.968224774371589, 3.0083684495397374, 3.0478678483772907, 3.086751287860787, 3.1250450937133722, 3.162773790126916, 3.1999602669196103, 3.23662592731944, 3.272790819044739, 3.308473750928882, 3.34369239698784, 3.3784633895417673, 3.4128024027633233, 3.4467242278267447, 3.480242840665432, 3.513371463206122, 3.5461226188298878, 3.5785081827104523, 3.6105394275954974, 3.6422270655243825, 3.6735812859138415, 3.7046117903901177, 3.735327824700359, 3.765738207996592, 3.795851359751484, 3.8256753245354234, 3.8552177948586537, 3.8844861322596835, 3.913487386801475, 3.9422283151196695, 3.9707153971519227, 3.9989548516640427, 4.026952650676865, 4.054714532887322, 4.082246016167987, 4.109552409221086, 4.1366388224557555, 4.163510178150782, 4.19017121995924, 4.21662652180631, 4.242880496226869, 4.268937402185279, 4.294801352416103, 4.320476320321045, 4.345966146454422, 4.371274544626728, 4.396405107653364, 4.4213613127733815, 4.446146526761062, 4.470764010751304, 4.495216924798122, 4.519508332184068, 4.543641203496943, 4.567618420488989, 4.591442779732521, 4.615116996084962, 4.638643705975266, 4.662025470522828, 4.68526477849918, 4.708364049142043, 4.731325634830595, 4.754151823630254, 4.776844841714602, 4.799406855671657, 4.82183997470114, 4.84414625270895, 4.866327690304665, 4.8883862367074915, 4.910323791565718], [0.0, 0.6234916188680996, 0.8517146511227923, 1.0221983711503373, 1.1634765007012597, 1.2863736099398373, 1.3963641253801318, 1.4966654662872492, 1.5893557377456544, 1.6758677716940578, 1.757238136404294, 1.8342449340339164, 1.907489608356902, 1.9774482577552652, 2.044505277842471, 2.1089762379780375, 2.1711239200641455, 2.2311698599708807, 2.2893028411313674, 2.34568526854371, 2.400458035032337, 2.4537442934247946, 2.5056524206381403, 2.556278375388161, 2.605707594356204, 2.654016532497632, 2.7012739257425347, 2.7475418348027763, 2.7928765146796457, 2.837329144122513, 2.8809464416164374, 2.923771188720084, 2.965842677210035, 3.007197093144692, 3.0478678483772907, 3.087885868033636, 3.1272798408876605, 3.1660764383150646, 3.2043005065064527, 3.241975235819686, 3.2791223105037255, 3.3157620415002556, 3.3519134845996392, 3.387594545874863, 3.4228220760257977, 3.457611955024494, 3.491979168250952, 3.525937875140353, 3.559501471221227, 3.5926826443046465, 3.6254934254834756, 3.6579452355147786, 3.690048927085286, 3.7218148233971515, 3.753252753457427, 3.7843720844084485, 3.815181751196305, 3.8456902838399984, 3.875905832533847, 3.9058361907895285, 3.9354888168013806, 3.9648708531985695, 3.993989145330288, 4.02285025821474, 4.05146049226914, 4.079825897926005, 4.107952289230448, 4.135845256503825, 4.163510178150782, 4.1909522316793115, 4.218176403996938, 4.245187501040146, 4.271990156789024, 4.298588841714331, 4.324987870699952, 4.351191410480002, 4.377203486626314, 4.403027990119074, 4.428668683530516, 4.454129206849133, 4.479413082969576, 4.504523722871334, 4.529464430507488, 4.5542384074230595, 4.578848757121012, 4.6032984891924915, 4.627590523226688, 4.651727692514466, 4.675712747558895, 4.699548359404821, 4.723237122798727, 4.746781559189323, 4.7701841195785315, 4.7934471872319, 4.816573080256776, 4.83956405405605, 4.862422303664694, 4.885149965975885, 4.90774912186298, 4.930221798203244, 4.9525699698088195, 4.974795561270076], [0.0, 0.6314458674893553, 0.8625804749516609, 1.035239155883151, 1.1783196534742952, 1.3027846332858437, 1.4141783623048234, 1.5157593063027874, 1.6096320819707768, 1.6972478007257303, 1.779656254949475, 1.8576454735055965, 1.9318245731393915, 2.002675726099442, 2.070588231959724, 2.1358816859833407, 2.198822222535472, 2.259634203749358, 2.3185088214792096, 2.3756105526190376, 2.4310820874457466, 2.4850481499198045, 2.5376184995862254, 2.588890319362469, 2.638950135895785, 2.687875379522287, 2.735735663076677, 2.7825938390157563, 2.8285068800188915, 2.8735266177528036, 2.917700366717694, 2.961071454261687, 3.0036796734296267, 3.045561671926706, 3.086751287860787, 3.1272798408876605, 3.167176385780791, 3.206467934178276, 3.2451796492481613, 3.2833350172013174, 3.3209559989254, 3.3580631644806997, 3.3946758127634853, 3.4308120782850287, 3.4664890267194712, 3.5017227406289906, 3.5365283965708763, 3.570920334620537, 3.6049121212011253, 3.6385166059895675, 3.6717459735664426, 3.704611790390118, 3.7371250476014204, 3.7692962001016537, 3.801135202292283, 3.832651540817778, 3.863854264612581, 3.8947520125181545, 3.9253530387056297, 3.955665236113089, 3.985696158083433, 4.015453038368542, 4.044942809647747, 4.074172120693043, 4.103147352299766, 4.131874632089353, 4.160359848280104, 4.188608662512387, 4.216626521806311, 4.244418669722381, 4.271990156789025, 4.299345850254883, 4.326490443218449, 4.3534284631829, 4.3801642800796285, 4.406702113800222, 4.433046041273098, 4.459200003117959, 4.485167809908385, 4.510953148070339, 4.536559585442103, 4.5619905765190385, 4.5872494674046935, 4.612339500488079, 4.637263818865367, 4.662025470522828, 4.686627412296562, 4.71107251362339, 4.735363560096162, 4.759503256835813, 4.783494231691531, 4.8073390382796255, 4.831040158870891, 4.854600007135591, 4.8780209307545315, 4.901305213904099, 4.924455079622618, 4.947472692064865, 4.970360158651121, 4.9931195321167126, 5.015752812467621, 5.038261948847345], [0.0, 0.6392794968300634, 0.8732815279875604, 1.0480821884275249, 1.192937722710998, 1.318946797698304, 1.4317224617792448, 1.5345636047971551, 1.6296009530241355, 1.718303620162923, 1.801734422173179, 1.8806911640946355, 1.9557905192899547, 2.027520641769368, 2.0962756607030566, 2.162379136208371, 2.226100504276298, 2.2876669104454024, 2.3472719184693664, 2.4050820457196016, 2.461241752668682, 2.5158773105851284, 2.5690998406755585, 2.6210077314951485, 2.6716885831286623, 2.7212207865021614, 2.7696748180574646, 2.817114309990182, 2.8635969417747935, 2.9091751880944465, 2.9538969504264307, 2.9978060936319073, 3.0409429044226832, 3.083344485150269, 3.1250450937133722, 3.1660764383150646, 3.206467934178276, 3.2462469280437194, 3.2854388952501914, 3.3240676133752185, 3.3621553157501647, 3.39972282762462, 3.436789687314267, 3.4733742543045945, 3.5094938059841168, 3.545164624433034, 3.5804020744868885, 3.615220674122064, 3.6496341580648655, 3.683655535403519, 3.7172971418788108, 3.7505706874409763, 3.7834872995854023, 3.81605756291544, 3.8482915553254697, 3.8801988811499504, 3.9117887015831414, 3.9430697626387667, 3.9740504208880547, 4.004738667187775, 4.035142148586548, 4.065268188577169, 4.095123805844823, 4.124715731645242, 4.154050425933019, 4.183134092348008, 4.211972692156923, 4.240571957237654, 4.268937402185279, 4.297074335611186, 4.324987870699953, 4.352682935082627, 4.3801642800796285, 4.407436489361705, 4.43450398707301, 4.4613710454565165, 4.488041792018449, 4.514520216265287, 4.540810176044054, 4.566915403513999, 4.592839510775511, 4.618585995179935, 4.644158244342115, 4.669559540875689, 4.694793066869639, 4.719861908123129, 4.744769058154355, 4.769517421997971, 4.794109819804504, 4.818548990254241, 4.8428375937971015, 4.8669782157292, 4.89097336911604, 4.914825497571539, 4.938536977901504, 4.962110122619495, 4.985547182342541, 5.0088503480736195, 5.032021753377373, 5.0550634764550795, 5.077977542124511, 5.100765923709971], [0.0, 0.6469975237180032, 0.8838246634191993, 1.0607356937427512, 1.2073400701430301, 1.3348704537812455, 1.4490076594289, 1.553090404454906, 1.649275139408055, 1.7390487146135076, 1.823486777417189, 1.9033967647659673, 1.9794027951253401, 2.051998915993121, 2.121584014864368, 2.188485558200523, 2.2529762348956206, 2.3152859328182744, 2.3756105526190376, 2.434118622034984, 2.490956345611222, 2.5462515190903883, 2.6001166052463875, 2.6526511804802726, 2.703943902473388, 2.754074108566122, 2.8031131260629847, 2.851125355391634, 2.8981691723913428, 2.944297685272561, 2.9895593738275292, 3.033998632498255, 3.077656234378365, 3.1205697297563804, 3.162773790126916, 3.2043005065064527, 3.2451796492481613, 3.2854388952501914, 3.325104027415325, 3.3641991103879874, 3.4027466459227447, 3.4407677106926045, 3.4782820788995035, 3.515308331683158, 3.5518639550221427, 3.5879654275703525, 3.623628299663122, 3.6588672645524896, 3.6936962227842294, 3.728128340505402, 3.7621761023862983, 3.7958513597514845, 3.8291653744386953, 3.8621288588392897, 3.8947520125181545, 3.92704455576296, 3.959015760371144, 3.99067447794713, 4.0220291659511025, 4.053087911713514, 4.083858454605868, 4.114348206537554, 4.144564270930402, 4.174513460306653, 4.204202312611987, 4.233637106382858, 4.262823874856401, 4.291768419111519, 4.3204763203210454, 4.348952951187277, 4.377203486626315, 4.405232913760537, 4.433046041273097, 4.46064750817344, 4.488041792018449, 4.515233216629923, 4.5422259593455045, 4.569024057837021, 4.595631416527315, 4.6220518126340275, 4.648288901866465, 4.674346223799526, 4.700227206946759, 4.725935173552823, 4.751473344124091, 4.776844841714602, 4.802052695983327, 4.827099847037427, 4.851989149075131, 4.876723373840837, 4.901305213904098, 4.925737285773334, 4.950022132854305, 4.974162228262705, 4.998159977499537, 5.022017720997355, 5.045737736544909, 5.069322241597175, 5.092773395477337, 5.116093301476817, 5.13928400885903, 5.162347514772239], [0.0, 0.6546046306428728, 0.8942162777160061, 1.073207348649492, 1.2215354336051327, 1.350565262340032, 1.4660444420998562, 1.5713509453960592, 1.6686665773565474, 1.7594956700262578, 1.8449265177305447, 1.9257760508980364, 2.002675726099442, 2.0761253996216418, 2.146528648900095, 2.214216790600139, 2.2794657197696164, 2.3425080271956733, 2.4035419168409162, 2.4627378979160253, 2.520243893973626, 2.5761892033214244, 2.6306876110202193, 2.683839864245761, 2.7357356630766776, 2.7864552776662506, 2.83607087395347, 2.8846476095573603, 2.9322445466741516, 2.9789154179368307, 3.024709273141308, 3.0696710286995446, 3.11384193709693, 3.1572599901214486, 3.1999602669196103, 3.241975235819686, 3.2833350172013174, 3.3240676133752185, 3.3641991103879874, 3.403753855825354, 3.44275461600743, 3.481222715417298, 3.5191781607531003, 3.556639751623265, 3.593625179598668, 3.63015111708183, 3.666233297241961, 3.7018865860877708, 3.737125047601421, 3.7719620027316294, 3.806410082937845, 3.840481278887197, 3.8741869848290604, 3.9075380391062917, 3.9405447612056896, 3.9732169857017117, 4.005564093405434, 4.037595039994478, 4.069318382368055, 4.100742302943826, 4.131874632089353, 4.1627228688599365, 4.193294200196256, 4.2235955187191365, 4.253633439244495, 4.283414314128998, 4.312944247545884, 4.34222910878054, 4.371274544626728, 4.400085990956573, 4.428668683530517, 4.45702766810729, 4.4851678099083845, 4.513093802486643, 4.540810176044054, 4.5683213052399765, 4.595631416527315, 4.622744595051034, 4.64966479114043, 4.676395826423976, 4.70294139959317, 4.729305091839647, 4.7554903719878805, 4.781500601343992, 4.807339038279626, 4.833008842568293, 4.858513079490335, 4.883854723721375, 4.909036663018025, 4.934061701713613, 4.9589325640357185, 4.983651897256492, 5.008222274685923, 5.0326461985174875, 5.056926102534992, 5.08106435468875, 5.105063259548728, 5.128925060641744, 5.15265194267934, 5.17624603368249, 5.199709407008934, 5.223044083288508], [0.0, 0.6621051959878331, 0.904462351925639, 1.0855043313936132, 1.2355319834491842, 1.3660402567543954, 1.48284261556494, 1.5893557377456546, 1.6877864278991912, 1.779656254949475, 1.8660659830736148, 1.9478419032207355, 2.02562270729269, 2.0999139790102435, 2.1711239200641455, 2.2395876433994766, 2.305584205313995, 2.3693488616575684, 2.4310820874457466, 2.490956345611222, 2.549121254638524, 2.605707594356204, 2.6608304535926237, 2.7145917339009076, 2.7670821631576397, 2.8183829312644537, 2.8685670310492974, 2.9177003667176944, 2.9658426772100355, 3.013048310836476, 3.0593668794133926, 3.104843814012232, 3.149520839796009, 3.193436383868737, 3.23662592731944, 3.2791223105037255, 3.3209559989254, 3.3621553157501647, 3.4027466459227447, 3.44275461600743, 3.4822022531844965, 3.5211111262763914, 3.5595014712212274, 3.5973923030363757, 3.634801516005582, 3.671745973566443, 3.708241589161355, 3.7443033991361525, 3.7799456286203705, 3.815181751196304, 3.8500245430567004, 3.884486132259684, 3.918578043611776, 3.9523112396433113, 3.9856961580834325, 4.018742746192736, 4.051460492269141, 4.083858454605868, 4.115945288148458, 4.14772926907003, 4.179218317459765, 4.210420018298342, 4.241341640875566, 4.271990156789025, 4.302372256648259, 4.332494365596265, 4.362362657748878, 4.391983069642706, 4.4213613127733815, 4.450502885298127, 4.479413082969576, 4.508097009361573, 4.536559585442102, 4.56480555854349, 4.5928395107755104, 4.620665866923074, 4.648288901866464, 4.675712747558894, 4.702941399593169, 4.7299787233865995, 4.756828460010885, 4.783494231691531, 4.809979546999361, 4.8362878057548855, 4.862422303664694, 4.8883862367074915, 4.914182705286097, 4.939814718160446, 4.9652851961755315, 4.990596975797184, 5.015752812467621, 5.040755383791866, 5.065607292565305, 5.090311069651955, 5.114869176722306, 5.13928400885903, 5.163557897038227, 5.187693110493405, 5.2116918589688845, 5.2355562948688465, 5.259288515307899, 5.2828905640685795], [0.0, 0.6695033208441983, 0.914568488303929, 1.0976333656081743, 1.2493373725821786, 1.3813038983018873, 1.4994113645775817, 1.6071146260012887, 1.706645145215021, 1.7995414926055306, 1.8869167318921576, 1.9696063867013207, 2.0482562854480184, 2.1233776610633135, 2.195383276336545, 2.2646119886440745, 2.33134597235817, 2.395823111992785, 2.4582461225990473, 2.518789394148309, 2.577604216908128, 2.6348228319937292, 2.690561614194569, 2.7449236036750038, 2.7980005420722156, 2.849874526474539, 2.9006193653054773, 2.9503016991603963, 2.9989819344810797, 3.0467150268461145, 3.093551142416434, 3.1395362198939063, 3.1847124506634805, 3.229118691199783, 3.272790819044739, 3.3157620415002556, 3.3580631644806997, 3.39972282762462, 3.4407677106926045, 3.481222715417298, 3.5211111262763914, 3.5604547530945805, 3.5992740579190574, 3.6375882682341465, 3.67541547826787, 3.7127727398837997, 3.7496761443354027, 3.786140895979223, 3.8221813788912673, 3.8578112172027827, 3.89304332986309, 3.9278899804448657, 3.9623628225286653, 3.996472941136187, 4.030230890623997, 4.063646729399796, 4.0967300517803285, 4.129490017272915, 4.161935377530342, 4.194074501200703, 4.225915396869399, 4.257465734268954, 4.288732863913596, 4.3197238352990315, 4.3504454137932616, 4.380904096331513, 4.411106126016969, 4.441057505718956, 4.470764010751304, 4.5002312007056595, 4.529464430507488, 4.55846886075613, 4.587249467404693, 4.615811050830481, 4.644158244342115, 4.672295522165456, 4.700227206946759, 4.727957476808194, 4.75549037198788, 4.782829801093906, 4.809979546999361, 4.836943272403192, 4.8637245250797285, 4.89032674283785, 4.916753258209185, 4.94300730288315, 4.96909201190535, 4.9950104276545195, 5.020765503612121, 5.046360107937631, 5.071797026861586, 5.097078967907602, 5.122208562953766, 5.147188371143053, 5.172020881651775, 5.196708516324394, 5.2212536321824965, 5.245658523815189, 5.269925425657677, 5.294056514164332, 5.318053909882162, 5.341919679430197], [0.0, 0.6768028528689379, 0.9245399429051914, 1.1096007594271875, 1.2629587809859018, 1.3963641253801318, 1.5157593063027874, 1.6246368463020509, 1.7252525374481997, 1.8191617250168628, 1.9074896083569022, 1.991080820730609, 2.070588231959724, 2.1465286489000945, 2.219319334655105, 2.289302841131368, 2.356764419221911, 2.421944547073273, 2.4850481499198045, 2.5462515190903883, 2.605707594356204, 2.663550058644976, 2.7198965555695933, 2.774851248731678, 2.8285068800188915, 2.8809464416164383, 2.932244546674151, 2.9824685623635694, 3.0316795537322543, 3.0799330755343215, 3.1272798408876605, 3.173766289359505, 3.219435072343523, 3.264325469962847, 3.308473750928882, 3.3519134845996392, 3.3946758127634853, 3.436789687314267, 3.4782820788995035, 3.5191781607531003, 3.5595014712212274, 3.5992740579190574, 3.638516605989568, 3.6772485525525447, 3.7154881891156832, 3.753252753457428, 3.7905585122726757, 3.827420835689647, 3.863854264612581, 3.899872571715354, 3.935488816801381, 3.970715397151923, 4.005564093405433, 4.040046111442564, 4.074172120693042, 4.107952289230448, 4.14139631597746, 4.1745134603066525, 4.20731256928926, 4.239802102815965, 4.271990156789025, 4.303884484563339, 4.335492516795103, 4.366821379840016, 4.397877912828252, 4.428668683530516, 4.45920000311796, 4.489477939908633, 4.519508332184068, 4.549296800151623, 4.578848757121012, 4.6081694199571075, 4.637263818865367, 4.666136806561162, 4.694793066869639, 4.723237122798728, 4.75147334412409, 4.779505954521571, 4.807339038279626, 4.834976546621534, 4.862422303664694, 4.889680012042118, 4.916753258209185, 4.943645517456883, 4.970360158651121, 4.996900448716126, 5.023269556878607, 5.049470558688071, 5.075506439827512, 5.101380099727682, 5.127094354997126, 5.152651942679339, 5.178055523347526, 5.20330768404676, 5.2284109410926085, 5.253367742734676, 5.278180471692937, 5.302851447574186, 5.327382929175467, 5.351777116680831, 5.37603615375741, 5.400162129556389], [0.0, 0.6840074075734122, 0.9343816546634924, 1.1214124403879462, 1.276402955443114, 1.4112283974292548, 1.5318945379951234, 1.6419310775312361, 1.7436178209755808, 1.8385266702274405, 1.9277948023633533, 2.012275841752131, 2.0926296080035147, 2.169378409373425, 2.2429439507237907, 2.3136724304203673, 2.381852135847022, 2.447726105036019, 2.5115014446472967, 2.573356322627896, 2.6334453067902244, 2.691903503114468, 2.7488498075277477, 2.8043894924514294, 2.8586162870089713, 2.9116140668359574, 2.963458239337916, 3.014216888808765, 3.063951730332446, 3.112718910042474, 3.1605696808970047, 3.207550976811664, 3.253705903203471, 3.2990741583317917, 3.34369239698784, 3.387594545874863, 3.4308120782850287, 3.4733742543045945, 3.515308331683158, 3.556639751623265, 3.5973923030363757, 3.6375882682341465, 3.6772485525525447, 3.7163928000191606, 3.7550394968544754, 3.7932060643327867, 3.8309089423076794, 3.8681636645221227, 3.904984926668032, 3.941386648029159, 3.9773820274303007, 4.012983594121564, 4.048203254146095, 4.0830523326709525, 4.117541612701761, 4.1516813705510645, 4.185481408386409, 4.21895108414623, 4.252099339078684, 4.284934723129842, 4.317465418382702, 4.349699260726492, 4.381643759916618, 4.413306118168708, 4.444693247415363, 4.47581178534109, 4.506668110299352, 4.537268355205338, 4.567618420488989, 4.597723986184671, 4.627590523226688, 4.657223304013349, 4.686627412296562, 4.715807752448768, 4.744769058154355, 4.773515900568591, 4.802052695983327, 4.830383713035362, 4.858513079490335, 4.886444788632225, 4.914182705286097, 4.941730571499428, 4.96909201190535, 4.996270538789268, 5.023269556878607, 5.050092367873947, 5.076742174738361, 5.103222085760527, 5.129535118405983, 5.155684202969873, 5.18167218604349, 5.207501833806109, 5.233175835152693, 5.258696804667363, 5.284067285451824, 5.309289751817255, 5.334366611847643, 5.359300209841958, 5.384092828642099, 5.408746691853037, 5.433263965961206, 5.457646762356767], [0.0, 0.6911203873729271, 0.9440982714151107, 1.1330739866622799, 1.2896762450852788, 1.425903734234491, 1.5478246796618673, 1.6590054870440045, 1.761749668966339, 1.8576454735055963, 1.9478419032207352, 2.0332014593038656, 2.1143908228160875, 2.1919377334867693, 2.266268281478543, 2.3377322652672707, 2.406620970131749, 2.473179961452037, 2.5376184995862254, 2.6001166052463875, 2.6608304535926233, 2.7198965555695933, 2.7774350435008643, 2.833552284533675, 2.8883429824788256, 2.9418918851930123, 2.9942751842419146, 3.045561671926706, 3.0958137051052916, 3.1450880137737434, 3.193436383868737, 3.240906237370779, 3.2875411279492868, 3.3333811666850566, 3.3784633895417673, 3.4228220760257977, 3.4664890267194712, 3.5094938059841168, 3.5518639550221427, 3.593625179598668, 3.634801516005582, 3.67541547826787, 3.7154881891156832, 3.7550394968544754, 3.794088079942576, 3.832651540817778, 3.870746490291385, 3.908388623641459, 3.9455927893801315, 3.9823730515375164, 4.018742746192735, 4.054714532887323, 4.09030044147514, 4.125511914893436, 4.160359848280103, 4.194854624810862, 4.2290061485858095, 4.2628238748564, 4.296316837850656, 4.3294936764253755, 4.362362657748878, 4.39493169919565, 4.427208388614901, 4.45920000311796, 4.490913526514479, 4.522355665514121, 4.553532864798721, 4.584451321059535, 4.615116996084962, 4.645535628975933, 4.675712747558895, 4.705653679059721, 4.735363560096161, 4.764847346041129, 4.794109819804503, 4.82315560007691, 4.851989149075131, 4.880614779825438, 4.909036663018025, 4.937258833462955, 4.9652851961755315, 4.9931195321167126, 5.020765503612121, 5.0482266594713465, 5.075506439827512, 5.1026081807155155, 5.129535118405983, 5.156290393510626, 5.182877054873549, 5.209298063261974, 5.2355562948688465, 5.261654544638886, 5.2875955294288195, 5.3133818910117805, 5.339016198935138, 5.364500953240385, 5.389838587053127, 5.415031469050654, 5.440081905814095, 5.464992144071645, 5.489764372838988, 5.5144007254625915], [0.0, 0.6981449986779219, 0.9536941732457854, 1.1445906550771103, 1.3027846332858437, 1.440396751188327, 1.5635569123402178, 1.675867771694058, 1.779656254949475, 1.8765267532830054, 1.9676399478214996, 2.053867106298665, 2.135881685983341, 2.214216790600139, 2.289302841131368, 2.361493191436833, 2.431082087445747, 2.4983175904873214, 2.563411087861209, 2.626544430026591, 2.6878753795222865, 2.7475418348027763, 2.805665149227635, 2.8623527710695877, 2.9177003667176944, 2.9717935454136764, 3.024709273141308, 3.076517041413051, 3.127279840887661, 3.177054978170117, 3.225894765554128, 3.2738471070215795, 3.3209559989254, 3.3672619600391056, 3.4128024027633233, 3.457611955024494, 3.5017227406289906, 3.545164624433034, 3.5879654275703525, 3.63015111708183, 3.671745973566443, 3.7127727398837997, 3.753252753457428, 3.7932060643327867, 3.832651540817778, 3.8716069642629938, 3.9100891143135548, 3.9481138457757754, 3.9856961580834334, 4.02285025821474, 4.059589617797954, 4.095927025047358, 4.131874632089353, 4.167443998168261, 4.202646129161157, 4.237491513779318, 4.271990156789026, 4.306151609545783, 4.339984998102337, 4.373499049121623, 4.406702113800222, 4.439602189985544, 4.472206942650394, 4.504523722871335, 4.536559585442103, 4.5683213052399765, 4.599815392451129, 4.631048106750558, 4.662025470522829, 4.692753281201625, 4.723237122798728, 4.753482376686429, 4.783494231691531, 4.813277693553816, 4.8428375937971015, 4.872178598056807, 4.901305213904099, 4.930221798203244, 4.9589325640357185, 4.987441587221764, 5.015752812467622, 5.043870059164282, 5.071797026861586, 5.09953730043955, 5.127094354997126, 5.15447156047698, 5.18167218604349, 5.208699404229834, 5.235556294868847, 5.262245848821267, 5.288770971513926, 5.315134486299619, 5.341339137649456, 5.367387594187796, 5.393282451579125, 5.419026235275587, 5.444621403133302, 5.470070347905012, 5.49537539961615, 5.520538827830864, 5.545562843814195, 5.570449602596139], [0.0, 0.70508426726695, 0.963173493490829, 1.1559674063180598, 1.3157337663472404, 1.4547136910076877, 1.5790980125264351, 1.692525194735838, 1.797345292001412, 1.8951786424753463, 1.987197463968276, 2.0742816842499012, 2.157111454471967, 2.2362251771866033, 2.3120575515802275, 2.3849654437018684, 2.4552460241619127, 2.523149819915184, 2.588890319362469, 2.6526511804802726, 2.714591733900907, 2.7748512487316774, 2.833552284533675, 2.890803357570407, 2.9467010851147335, 3.0013319273283465, 3.054773615204631, 3.107096330972549, 3.158363691391593, 3.2086335726703723, 3.257958807064861, 3.3063877747024435, 3.353964909241348, 3.400731132194714, 3.4467242278267447, 3.491979168250952, 3.5365283965708763, 3.5804020744868885, 3.623628299663122, 3.666233297241961, 3.708241589161355, 3.7496761443354027, 3.7905585122726757, 3.8309089423076794, 3.870746490291385, 3.9100891143135548, 3.948953760801947, 3.9873564421530046, 4.025312306888587, 4.0628357031983136, 4.099940236612779, 4.1366388224557555, 4.172943733640687, 4.208866644305935, 4.24441866972238, 4.279610402854691, 4.314451947912333, 4.348952951187276, 4.3831226294414085, 4.416969796077034, 4.450502885298127, 4.483729974447349, 4.516658804684121, 4.549296800151623, 4.581651085765284, 4.6137285037418225, 4.645535628975933, 4.677078783361159, 4.708364049142042, 4.739397281376328, 4.7701841195785315, 4.800729998609531, 4.8310401588708904, 4.8611196558573475, 4.890973369116039, 4.920606010656847, 4.950022132854305, 4.9792261358780845, 5.008222274685922, 5.037014665610007, 5.065607292565305, 5.094004012905954, 5.122208562953766, 5.150224563220963, 5.178055523347526, 5.205704846771934, 5.233175835152692, 5.260471692556626, 5.2875955294288195, 5.31455036635791, 5.341339137649455, 5.367964694719194, 5.394429809317129, 5.420737176592624, 5.446889418009984, 5.472889084123288, 5.498738657218714, 5.524440553831965, 5.549997127147949, 5.57541066928933, 5.600683413500198, 5.625817536230643], [0.0, 0.7119410521476109, 0.9725401376697169, 1.1672089276540871, 1.3285289793662953, 1.4688604523314879, 1.594454383218612, 1.708984619097109, 1.8148240680791892, 1.9136088257387558, 2.006522509439283, 2.094453604048832, 2.178088875035124, 2.257971960793223, 2.3345417878607275, 2.4081586927282044, 2.479122735922952, 2.5476868807177144, 2.614066691639647, 2.678447612697499, 2.740990523977912, 2.801836048948732, 2.861107939035035, 2.9189157657964273, 2.9753570860868734, 3.030519200873565, 3.0844805970662006, 3.137312139400031, 3.189078063293134, 3.2398368077871442, 3.289641718919766, 3.3385416473041682, 3.386581458705849, 3.433802472590397, 3.480242840665432, 3.525937875140353, 3.570920334620537, 3.615220674122064, 3.6588672645524896, 3.7018865860877708, 3.7443033991361525, 3.786140895979223, 3.827420835689647, 3.8681636645221227, 3.908388623641459, 3.9481138457757754, 3.9873564421530046, 4.026132580886518, 4.064457557814123, 4.102345860658334, 4.13981122726045, 4.1768666985428435, 4.2135246667702635, 4.249796919609425, 4.2856946804247, 4.3212286451949415, 4.356409016390764, 4.391245534112144, 4.425747504751892, 4.459923827420654, 4.493783018343128, 4.527333233412305, 4.56058228906863, 4.593537681653393, 4.626206605370213, 4.658595968974818, 4.690712411301264, 4.722562315722078, 4.754151823630254, 4.785486847022647, 4.816573080256776, 4.847416011046309, 4.878020930754531, 4.9083929440397185, 4.938536977901503, 4.968457790172994, 4.998159977499536, 5.027647982841455, 5.056926102534991, 5.085998492942728, 5.114869176722306, 5.143542048739755, 5.172020881651775, 5.200309331179248, 5.2284109410926085, 5.256329147928005, 5.284067285451824, 5.3116285888897155, 5.339016198935138, 5.366233165551268, 5.393282451579124, 5.420166936163814, 5.446889418009984, 5.473452618476714, 5.499859184521457, 5.5261116915018516, 5.552212645843748, 5.578164487583113, 5.603969592789041, 5.629630275874575, 5.655148791801595, 5.680527338185675], [0.0, 0.7187180580830101, 0.9817978005977357, 1.1783196534742952, 1.3411753196094316, 1.48284261556494, 1.6096320819707768, 1.7252525374481997, 1.8320994779519266, 1.9318245731393917, 2.02562270729269, 2.1143908228160875, 2.198822222535472, 2.2794657197696164, 2.356764419221911, 2.431082087445747, 2.5027216412610436, 2.5719384519118176, 2.638950135895785, 2.7039439024733882, 2.7670821631576397, 2.828506880018892, 2.8883429824788256, 2.946701085114734, 3.003679673429627, 3.059366879413393, 3.11384193709693, 3.1671763857807913, 3.2194350723435234, 3.270676992111205, 3.3209559989254, 3.3703214084109443, 3.4188185134130182, 3.4664890267194717, 3.513371463206122, 3.559501471221227, 3.6049121212011253, 3.6496341580648655, 3.6936962227842294, 3.737125047601421, 3.7799456286203705, 3.8221813788912673, 3.863854264612581, 3.904984926668032, 3.9455927893801315, 3.9856961580834334, 4.025312306888587, 4.064457557814123, 4.103147352299767, 4.141396315977459, 4.179218317459765, 4.216626521806311, 4.253633439244495, 4.290250969648476, 4.32649044321845, 4.3623626577488785, 4.397877912828253, 4.433046041273098, 4.467876438064285, 4.502378087023584, 4.536559585442103, 4.570429166849226, 4.603994722090523, 4.637263818865368, 4.6702437198594, 4.70294139959317, 4.735363560096162, 4.767516645504574, 4.799406855671658, 4.831040158870891, 4.862422303664695, 4.893558830004582, 4.924455079622617, 4.955116205768601, 4.985547182342541, 5.015752812467622, 5.045737736544909, 5.075506439827512, 5.105063259548728, 5.134412391635787, 5.163557897038227, 5.192503707697521, 5.2212536321824965, 5.249811361013042, 5.278180471692936, 5.3063644334709075, 5.334366611847643, 5.362190272845086, 5.389838587053127, 5.417314633467711, 5.444621403133301, 5.471761802601746, 5.498738657218714, 5.525554714248054, 5.552212645843748, 5.57871505187841, 5.605064462636692, 5.6312633413813975, 5.657314086799556, 5.683219035335231, 5.70898046341541, 5.7346005895748915], [0.0, 0.72541784693722, 0.9909499818843407, 1.1893037838885219, 1.3536775676840485, 1.4966654662872492, 1.6246368463020506, 1.741335099436308, 1.849178052121783, 1.94983277064862, 2.044505277842471, 2.134100877278794, 2.2193193346551046, 2.3007145792508985, 2.3787338463294145, 2.453744293424794, 2.5260516611050337, 2.59591370114904, 2.6635500586449754, 2.7291496879917303, 2.7928765146796453, 2.854873824129565, 2.9152677103377047, 2.974169819014919, 3.0316795537322534, 3.087885868033636, 3.142868734558479, 3.1967003594866528, 3.2494461941902046, 3.3011657839413613, 3.351913484599639, 3.4017390715032056, 3.450688259710787, 3.498803150850987, 3.5461226188298878, 3.5926826443046465, 3.6385166059895675, 3.683655535403519, 3.728128340505402, 3.7719620027316294, 3.815181751196304, 3.8578112172027827, 3.899872571715354, 3.941386648029159, 3.9823730515375164, 4.02285025821474, 4.0628357031983136, 4.102345860658334, 4.141396315977459, 4.180001831125719, 4.218176403996938, 4.25593332237358, 4.293285213101626, 4.3302440869841945, 4.366821379840015, 4.4030279901190745, 4.438874313421181, 4.474370274222996, 4.509525355084083, 4.544348623572138, 4.578848757121011, 4.61303406601189, 4.646912514647698, 4.680491741272845, 4.713779076274702, 4.746781559189323, 4.77950595452157, 4.811958766478975, 4.84414625270895, 4.876074437120381, 4.907749121862981, 4.939175898530914, 4.97036015865112, 5.001307103511271, 5.032021753377373, 5.062508956146652, 5.092773395477337, 5.12281959843344, 5.152651942679339, 5.182274663256107, 5.2116918589688845, 5.2409074984121515, 5.269925425657677, 5.2987493656278595, 5.327382929175467, 5.355829617889075, 5.384092828642099, 5.412175857901876, 5.440081905814095, 5.467814080076666, 5.495375399616149, 5.522768798078863, 5.549997127147949, 5.577063159696867, 5.603969592789042, 5.6307190505327345, 5.657314086799556, 5.683757187814501, 5.710050774624821, 5.736197205454583, 5.762198777951309, 5.788057731330667], [0.0, 0.7320428479728127, 1.0, 1.200165301609877, 1.3660402567543954, 1.5103340164972456, 1.6394741167588731, 1.757238136404294, 1.8660659830736148, 1.9676399478214994, 2.063177067680795, 2.1535909140647997, 2.2395876433994766, 2.3217262438170443, 2.4004580350323375, 2.4761535277077025, 2.549121254638524, 2.619621321565374, 2.6878753795222865, 2.754074108566122, 2.8183829312644537, 2.880946441616438, 2.9418918851930123, 3.001331927328347, 3.0593668794133926, 3.1160865073753445, 3.171571514217254, 3.225894765554128, 3.279122310503726, 3.331314238145532, 3.3825254007531322, 3.4328060282463797, 3.4822022531844965, 3.5307565616963212, 3.5785081827104523, 3.6254934254834756, 3.6717459735664426, 3.7172971418788108, 3.7621761023862983, 3.806410082937845, 3.8500245430567004, 3.89304332986309, 3.935488816801381, 3.9773820274303007, 4.018742746192735, 4.059589617797954, 4.099940236612779, 4.13981122726045, 4.179218317459765, 4.218176403996938, 4.2566996126039225, 4.294801352416103, 4.332494365596264, 4.369790772638211, 4.406702113800221, 4.443239387064216, 4.479413082969577, 4.515233216629922, 4.550709357205896, 4.585850655076287, 4.620665866923074, 4.6551633789224915, 4.689351228213722, 4.723237122798728, 4.756828460010884, 4.790132343675996, 4.82315560007691, 4.85590479282193, 4.888386236707492, 4.920606010656847, 4.95256996980882, 4.984283756823755, 5.015752812467621, 5.046982385529729, 5.077977542124511, 5.108743174423434, 5.13928400885903, 5.169604613839484, 5.199709407008934, 5.229602662085683, 5.259288515307899, 5.288770971513925, 5.318053909882162, 5.347141089353495, 5.376036153757411, 5.404742636661337, 5.433263965961206, 5.461603468229905, 5.489764372838988, 5.517749815867947, 5.545562843814195, 5.573206417116071, 5.600683413500199, 5.627996631163769, 5.6551487918015955, 5.682142543487051, 5.70898046341541, 5.7356650605175385, 5.762198777951309, 5.788583995477672, 5.814823031727799, 5.8409181463673745], [0.0, 0.7385953672161816, 1.0089510050695996, 1.2109079873089446, 1.3782676900178812, 1.523853023935701, 1.654149057889459, 1.7729671838717427, 1.8827691491483143, 1.9852523029695965, 2.0816445760730873, 2.1728677172544373, 2.259634203749358, 2.3425080271956733, 2.421944547073273, 2.4983175904873214, 2.571938451911818, 2.6430695652951366, 2.7119345656708425, 2.7787258398739505, 2.843610291170275, 2.9067338078205918, 2.968224774371589, 3.0281968646254143, 3.0867512878607872, 3.143978613500172, 3.1999602669196103, 3.254769765954598, 3.308473750928882, 3.361132848779602, 3.4128024027633233, 3.463533092408165, 3.513371463206122, 3.5623603815795875, 3.6105394275954974, 3.6579452355147786, 3.704611790390118, 3.7505706874409763, 3.7958513597514845, 3.840481278887197, 3.884486132259684, 3.9278899804448657, 3.970715397151923, 4.012983594121564, 4.054714532887323, 4.095927025047358, 4.1366388224557555, 4.1768666985428435, 4.216626521806311, 4.25593332237358, 4.294801352416103, 4.333244141094503, 4.371274544626728, 4.408904791997186, 4.446146526761062, 4.483010845343273, 4.519508332184069, 4.555649092042402, 4.591442779732521, 4.626898627538302, 4.662025470522828, 4.696831769927042, 4.731325634830596, 4.765514842229821, 4.799406855671657, 4.833008842568294, 4.866327690304666, 4.899370021239972, 4.932142206694422, 4.964650380003739, 4.996900448716127, 5.028898105999407, 5.060648841319877, 5.092157950448785, 5.1234305448473805, 5.15447156047698, 5.185285766076439, 5.215877770945786, 5.246252032271515, 5.276412862026004, 5.3063644334709075, 5.336110787291898, 5.365655837389922, 5.395003376352163, 5.4241570806240444, 5.453120515401974, 5.481897139264998, 5.510490308562174, 5.538903281571177, 5.567139222442563, 5.595201204942959, 5.623092216009603, 5.650815159127662, 5.678372857541005, 5.705768057306352, 5.73300343019999, 5.760081576485687, 5.787005027551756, 5.813776248424793, 5.840397640166995, 5.866871542163619, 5.893200234306626], [0.0, 0.7450775959915877, 1.0178059905302963, 1.2215354336051327, 1.3903639566301678, 1.53722700969258, 1.6686665773565474, 1.7885275020205844, 1.8992931362971317, 2.002675726099442, 2.0999139790102435, 2.19193773348677, 2.2794657197696164, 2.363066879328391, 2.4432005680724966, 2.5202438939736256, 2.594510883559195, 2.666266274010129, 2.7357356630766767, 2.8031131260629842, 2.868567031049297, 2.932244546674151, 2.9942751842419146, 3.054773615204631, 3.1138419370969297, 3.171571514217254, 3.2280444865655635, 3.283335017201317, 3.3375103313122385, 3.3906315879233926, 3.4427546160074294, 3.4939305398776788, 3.544206313529276, 3.5936251795986673, 3.6422270655243825, 3.690048927085286, 3.7371250476014204, 3.7834872995854023, 3.8291653744386953, 3.8741869848290604, 3.918578043611776, 3.9623628225286653, 4.005564093405433, 4.048203254146095, 4.09030044147514, 4.131874632089353, 4.172943733640687, 4.2135246667702635, 4.253633439244495, 4.293285213101626, 4.332494365596264, 4.371274544626728, 4.409638719242634, 4.447599225755183, 4.4851678099083845, 4.522355665514121, 4.559173469906218, 4.595631416527314, 4.631739244926435, 4.667506268413928, 4.702941399593169, 4.738053173964568, 4.772849771776529, 4.8073390382796255, 4.841528502524082, 4.875425394826357, 4.909036663018025, 4.942368987578938, 4.975428795746736, 5.008222274685922, 5.040755383791866, 5.0730338661980685, 5.105063259548726, 5.136848906093043, 5.168395962152637, 5.199709407008934, 5.230794051253277, 5.261654544638885, 5.292295383470427, 5.322720917563993, 5.352935356807568, 5.382942777349608, 5.412747127441129, 5.442352232954681, 5.471761802601746, 5.500979432868417, 5.530008612687712, 5.55885272786544, 5.587515065275317, 5.615998816837836, 5.6443070832963125, 5.672442877802627, 5.7004091293241705, 5.72820868588281, 5.75584431763583, 5.783318719808174, 5.810634515484632, 5.837794258270065, 5.864800434825195, 5.891655467284972, 5.918361715566093, 5.944921479569828], [0.0, 0.7514916187122181, 1.0265678037744148, 1.2320510578399095, 1.4023329462437975, 1.550460274281368, 1.6830313433861548, 1.8039240943972017, 1.915643257942025, 2.019915819853921, 2.1179911511668106, 2.210807094880036, 2.299088568444918, 2.3834094110806845, 2.4642329330757935, 2.541939488747166, 2.6168458079289505, 2.689218906799996, 2.7592863251755153, 2.827243809062703, 2.8932611759434477, 2.957486861361902, 3.0200514915243635, 3.0810707250354925, 3.1406475383395915, 3.198874082247394, 3.255833203863501, 3.3115997046822816, 3.3662413886014946, 3.4198199411354966, 3.472391671862315, 3.5240081452004577, 3.574716719349927, 3.6245610092026963, 3.6735812859138415, 3.7218148233971515, 3.7692962001016537, 3.81605756291544, 3.8621288588392897, 3.9075380391062917, 3.9523112396433113, 3.996472941136187, 4.040046111442564, 4.0830523326709525, 4.125511914893436, 4.167443998168261, 4.208866644305935, 4.249796919609425, 4.290250969648476, 4.3302440869841945, 4.369790772638211, 4.408904791997186, 4.447599225755183, 4.485886516420911, 4.523778510851964, 4.561286499222489, 4.598421250782459, 4.635193046725066, 4.671611710442536, 4.707686635419125, 4.743426810982622, 4.778840846111546, 4.813936991474215, 4.8487231598572755, 4.883206945125005, 4.917395639836258, 4.951296251633223, 4.984915518504863, 5.018259923017887, 5.051335705599184, 5.08414887694576, 5.116705229631052, 5.14901034897023, 5.18106962320141, 5.21288825303456, 5.244471260615397, 5.275823497947384, 5.30694965481128, 5.337854266218326, 5.368541719430133, 5.399016260575633, 5.429282000892928, 5.459342922621671, 5.489202884569549, 5.5188656273745975, 5.548334778483368, 5.577613856863462, 5.6067062774675, 5.635615355464348, 5.66434431025224, 5.692896269267336, 5.72127427160032, 5.749481271432692, 5.777520141303595, 5.8053936752172985, 5.8331045916006685, 5.860655536119398, 5.8880490843611355, 5.915287744393092, 5.94237395920124, 5.96931010901769, 5.996098513542481], [0.0, 0.7578394200056725, 1.035239155883151, 1.2424581137588564, 1.4141783623048232, 1.5635569123402175, 1.6972478007257303, 1.8191617250168628, 1.9318245731393915, 2.0369779186646966, 2.1358816859833407, 2.229481639994067, 2.3185088214792096, 2.403541916840916, 2.485048149919804, 2.563411087861209, 2.6389501358957848, 2.711934565670842, 2.7825938390157563, 2.8511253553916336, 2.917700366717694, 2.982468562363569, 3.045561671926706, 3.1070963309725483, 3.1671763857807904, 3.225894765554128, 3.283335017201317, 3.339572574060131, 3.3946758127634853, 3.448706939879303, 3.5017227406289897, 3.5537752149923745, 3.604912121201125, 3.6551774425593964, 3.7046117903901177, 3.753252753457427, 3.801135202292283, 3.8482915553254697, 3.8947520125181545, 3.9405447612056896, 3.9856961580834325, 4.030230890623997, 4.074172120693042, 4.117541612701761, 4.160359848280103, 4.202646129161157, 4.24441866972238, 4.2856946804247, 4.32649044321845, 4.366821379840015, 4.406702113800221, 4.446146526761062, 4.4851678099083845, 4.523778510851964, 4.5619905765190385, 4.599815392451128, 4.637263818865367, 4.674346223799526, 4.711072513623389, 4.74745216116737, 4.783494231691531, 4.819207406893877, 4.85460000713559, 4.889680012042118, 4.924455079622617, 4.9589325640357185, 4.9931195321167126, 5.027022778769922, 5.060648841319877, 5.094004012905954, 5.127094354997126, 5.159925709096325, 5.1925037076975205, 5.224833784552928, 5.256921184302577, 5.288770971513925, 5.320388039174998, 5.35177711668083, 5.382942777349609, 5.413889445501862, 5.444621403133301, 5.475142796209388, 5.505457640607501, 5.535569827730424, 5.565483129813124, 5.595201204942958, 5.624727601812021, 5.654065764218816, 5.68321903533523, 5.712190661753545, 5.740983797327173, 5.769601506817803, 5.7980467693607105, 5.826322481759197, 5.854431461618304, 5.882376450327275, 5.91016011589957, 5.937785055678659, 5.965253798917238, 5.992568809237023, 6.0197324869757916, 6.04674717142794], [0.0, 0.7641228912419654, 1.0438226305440854, 1.2527597022141574, 1.425903734234491, 1.576520826100369, 1.711320185264188, 1.8342449340339166, 1.9478419032207355, 2.0538671062986644, 2.1535909140647997, 2.2479669330349608, 2.3377322652672707, 2.4234703952243457, 2.5056524206381408, 2.584665088922871, 2.6608304535926237, 2.734420018905742, 2.805665149227635, 2.8747648807168464, 2.9418918851930123, 3.0071970931446925, 3.0708133263784685, 3.1328581875198247, 3.1934363838687374, 3.2526416151314637, 3.310558120928942, 3.3672619600391056, 3.4228220760257986, 3.477301191230035, 3.5307565616963212, 3.58324061855173, 3.634801516005582, 3.6854836020406445, 3.735327824700359, 3.7843720844084485, 3.832651540817778, 3.8801988811499504, 3.92704455576296, 3.9732169857017117, 4.018742746192736, 4.063646729399796, 4.107952289230448, 4.1516813705510645, 4.194854624810862, 4.237491513779318, 4.279610402854691, 4.3212286451949415, 4.3623626577488785, 4.4030279901190745, 4.443239387064216, 4.483010845343273, 4.522355665514121, 4.561286499222489, 4.599815392451128, 4.63795382514246, 4.6757127475588955, 4.713102613702678, 4.750133412080243, 4.786814694064047, 4.82315560007691, 4.859164883799369, 4.894850934579185, 4.930221798203245, 4.9652851961755315, 5.000048543630183, 5.034518965995717, 5.068703314515019, 5.102608180715516, 5.136239909914869, 5.169604613839485, 5.202708182425929, 5.2355562948688465, 5.268154429973305, 5.300507875864196, 5.33262173910081, 5.364500953240385, 5.39615028689077, 5.427574351288891, 5.45877760743863, 5.489764372838989, 5.520538827830864, 5.551105021588458, 5.581466877779332, 5.611628199915168, 5.641592676413612, 5.671363885390016, 5.700945299196439, 5.730340288723994, 5.759552127483423, 5.788583995477672, 5.817438982879275, 5.846120093524405, 5.874630248234616, 5.902972287976548, 5.931148976869113, 5.959163005047065, 5.9870169913892175, 6.01471348611905, 6.042254973284895, 6.069643873126444, 6.0968825443338766], [0.0, 0.770343836524046, 1.0523206922344739, 1.2629587809859018, 1.437512428607944, 1.5893557377456546, 1.7252525374482, 1.8491780521217835, 1.9636998470632303, 2.070588231959724, 2.171123920064146, 2.2662682814785433, 2.3567644192219115, 2.443200568072497, 2.526051661105034, 2.605707594356204, 2.6824930432708225, 2.7566817225018614, 2.828506880018892, 2.8981691723913428, 2.9658426772100355, 3.0316795537322543, 3.095813705105292, 3.1583636913915933, 3.2194350723435234, 3.2791223105037264, 3.337510331312239, 3.3946758127634857, 3.4506882597107884, 3.5056109051358653, 3.5595014712212274, 3.612412815950905, 3.664393485571554, 3.7154881891156837, 3.765738207996592, 3.815181751196305, 3.863854264612581, 3.9117887015831414, 3.959015760371144, 4.005564093405434, 4.051460492269141, 4.0967300517803285, 4.14139631597746, 4.185481408386409, 4.2290061485858095, 4.271990156789026, 4.314451947912333, 4.356409016390764, 4.397877912828253, 4.438874313421181, 4.479413082969577, 4.519508332184069, 4.559173469906218, 4.598421250782459, 4.637263818865367, 4.6757127475588955, 4.713779076274704, 4.75147334412409, 4.7888056209328065, 4.825785535833794, 4.862422303664694, 4.898724749372289, 4.934701330604444, 4.970360158651122, 5.0057090178793, 5.0407553837918675, 5.075506439827513, 5.109969093007073, 5.1441499885215025, 5.178055523347527, 5.211691858968885, 5.245064933273818, 5.278180471692936, 5.31104399763584, 5.3436608422795775, 5.376036153757411, 5.408174905792095, 5.440081905814095, 5.471761802601747, 5.503219093477253, 5.534458131089627, 5.565483129813124, 5.596298171787447, 5.626907212623868, 5.657314086799557, 5.687522512760633, 5.7175360977529195, 5.747358342397897, 5.776992645030076, 5.806442305810799, 5.835710530632331, 5.864800434825196, 5.893715046680665, 5.922457310799544, 5.951030091277603, 5.979436174737247, 6.007678273214392, 6.035759026908901, 6.063681006806362, 6.09144671717846, 6.119058597968759, 6.146519027070216], [0.0, 0.7765039781938609, 1.0607356937427512, 1.273058173809131, 1.4490076594288999, 1.6020652007724818, 1.7390487146135076, 1.8639652136900282, 1.97940279512534, 2.087145925088389, 2.188485558200523, 2.284390752268611, 2.375610552619037, 2.462737897916025, 2.546251519090388, 2.6265444300265908, 2.7039439024733873, 2.7787258398739496, 2.8511253553916336, 2.921344710168835, 2.9895593738275292, 3.055922722383723, 3.1205697297563804, 3.183619904086903, 3.2451796492481613, 3.305344183163213, 3.364199110387987, 3.4218217220811677, 3.4782820788995035, 3.533643919474406, 3.5879654275703516, 3.641299883856222, 3.6936962227842285, 3.7451995109077187, 3.795851359751484, 3.8456902838399984, 3.8947520125181545, 3.9430697626387667, 3.99067447794713, 4.037595039994478, 4.083858454605868, 4.129490017272915, 4.1745134603066525, 4.21895108414623, 4.2628238748564, 4.306151609545783, 4.348952951187276, 4.391245534112144, 4.433046041273098, 4.474370274222996, 4.515233216629922, 4.555649092042402, 4.595631416527314, 4.635193046725066, 4.674346223799526, 4.713102613702678, 4.75147334412409, 4.789469038452255, 4.8270998470374264, 4.864375476012996, 4.901305213904098, 4.937897956227199, 4.974162228262705, 5.010106206163425, 5.0457377365449085, 5.081064354688749, 5.116093301476816, 5.150831539162721, 5.185285766076439, 5.219462430348843, 5.253367742734676, 5.287007688605173, 5.320388039174998, 5.353514362022322, 5.386392030955554, 5.419026235275587, 5.451421988478111, 5.483584136436752, 5.515517365104331, 5.547226207766395, 5.578715051878409, 5.609988145515348, 5.641049603460207, 5.67190341295575, 5.70255343914198, 5.7330034301999895, 5.763257022221352, 5.793317743820665, 5.823189020507605, 5.852874178833625, 5.882376450327274, 5.91169897523117, 5.940844806052653, 5.969816910939367, 5.9986181768901465, 6.027251412810938, 6.0557193524247594, 6.0840246570441305, 6.112169918213816, 6.1401576602311945, 6.167990342551114, 6.195670362081622], [0.0, 0.7826049619009149, 1.0690698830923897, 1.2830605786836138, 1.4603924975879197, 1.6146526104471697, 1.7527124023364073, 1.8786103690512275, 1.9949549423671948, 2.1035446089854464, 2.2056804665444067, 2.3023391867280885, 2.394275700104239, 2.4820876040500206, 2.5662573908802084, 2.6471811623852823, 2.725188761684733, 2.8005582599922256, 2.8735266177528036, 2.9442976852725615, 3.013048310836476, 3.0799330755343215, 3.145088013773744, 3.2086335726703723, 3.270676992111205, 3.3313142381455325, 3.390631587923393, 3.4487069398793038, 3.5056109051358653, 3.5614077231182573, 3.61615603474019, 3.669909539296208, 3.722717555716006, 3.7746255046403743, 3.8256753245354234, 3.875905832533847, 3.9253530387056297, 3.9740504208880547, 4.0220291659511025, 4.069318382368055, 4.115945288148458, 4.161935377530342, 4.20731256928926, 4.252099339078684, 4.296316837850656, 4.339984998102337, 4.3831226294414085, 4.425747504751892, 4.467876438064285, 4.509525355084083, 4.550709357205896, 4.591442779732521, 4.631739244926435, 4.671611710442536, 4.711072513623389, 4.750133412080243, 4.7888056209328065, 4.8270998470374264, 4.865026320495552, 4.902594823701565, 4.939814718160446, 4.976694969280643, 5.013244169325597, 5.049470558688071, 5.085382045634388, 5.120986224650772, 5.156290393510626, 5.191301569169916, 5.226026502587326, 5.260471692556626, 5.294643398630396, 5.328547653206869, 5.362190272845084, 5.395576868867617, 5.4287128573048316, 5.461603468229905, 5.4942537545295105, 5.526668600151256, 5.55885272786544, 5.590810706575591, 5.622546958209364, 5.654065764218816, 5.6853712717167495, 5.716467499273654, 5.747358342397896, 5.778047578719989, 5.8085388729002405, 5.838835781277535, 5.868941756275744, 5.898860150583001, 5.928594221117941, 5.958147132796035, 5.9875219621081435, 6.016721700522613, 6.0457492577214005, 6.074607464679995, 6.1032990766002495, 6.13182677570459, 6.1601931738995175, 6.188400815315792, 6.216452178732173, 6.244349679889187], [0.0, 0.7886483612750054, 1.0773254099250416, 1.2929685755346718, 1.4716698795820382, 1.6271212134466295, 1.7662471248987484, 1.8931172956376723, 2.010360300161958, 2.1197885133716845, 2.2227130801871575, 2.3201182143057055, 2.412764675988399, 2.5012546773539244, 2.5860744365990724, 2.6676231142750386, 2.7462331006020846, 2.8221846141037954, 2.8957164450712742, 2.9670340179749406, 3.0363155467502176, 3.103716806186519, 3.1693748811707154, 3.2334111489301263, 3.2959336774751287, 3.357039173920034, 3.416814581660688, 3.4753384006756467, 3.532681787357776, 3.588909477199263, 3.644080563948234, 3.6982491615736848, 3.7514649698538913, 3.80377376017502, 3.8552177948586537, 3.9058361907895285, 3.955665236113089, 4.004738667187775, 4.053087911713514, 4.100742302943826, 4.14772926907003, 4.194074501200703, 4.239802102815965, 4.284934723129842, 4.3294936764253755, 4.373499049121623, 4.416969796077034, 4.459923827420654, 4.502378087023584, 4.544348623572138, 4.585850655076287, 4.626898627538302, 4.667506268413928, 4.707686635419125, 4.74745216116737, 4.786814694064047, 4.825785535833794, 4.864375476012996, 4.902594823701565, 4.940453436835082, 4.977960749209548, 5.015125795465715, 5.051957234217845, 5.088463369492313, 5.12465217062433, 5.160531290745943, 5.196108083985116, 5.23138962148386, 5.266382706332831, 5.301093887510512, 5.335529472906739, 5.369695541502878, 5.4035979547743604, 5.437242367375279, 5.470634237159444, 5.503778834587484, 5.536681251565265, 5.569346409755008, 5.601779068396994, 5.633983831676547, 5.665965155668146, 5.6977273548859, 5.729274608467271, 5.760610966014787, 5.791740353118547, 5.8226665765805246, 5.853393329360114, 5.883924195258811, 5.914262653360652, 5.944412082243758, 5.974375763977206, 6.004156887916444, 6.033758554309483, 6.06318377772526, 6.092435490314757, 6.121516544914705, 6.150429718003061, 6.179177712514796, 6.207763160525968, 6.236188625813518, 6.264456606297724, 6.292569536373846], [0.0, 0.7946356822402045, 1.0855043313936132, 1.3027846332858437, 1.4828426155649397, 1.639474116758873, 1.779656254949475, 1.907489608356902, 2.0256227072926896, 2.1358816859833407, 2.2395876433994766, 2.3377322652672707, 2.4310820874457466, 2.5202438939736256, 2.6057075943562036, 2.6878753795222865, 2.7670821631576397, 2.8436102911702745, 2.917700366717694, 2.9895593738275297, 3.0593668794133926, 3.1272798408876605, 3.193436383868737, 3.2579588070648615, 3.3209559989254, 3.3825254007531327, 3.4427546160074294, 3.50172274062899, 3.5595014712212274, 3.61615603474019, 3.6717459735664426, 3.7263258124955514, 3.77994562862037, 3.832651540817778, 3.8844861322596835, 3.9354888168013806, 3.985696158083433, 4.035142148586548, 4.083858454605868, 4.131874632089353, 4.179218317459765, 4.225915396869399, 4.271990156789025, 4.317465418382702, 4.362362657748878, 4.406702113800222, 4.450502885298127, 4.493783018343128, 4.536559585442103, 4.578848757121011, 4.620665866923074, 4.662025470522828, 4.702941399593169, 4.743426810982622, 4.783494231691531, 4.82315560007691, 4.862422303664694, 4.901305213904098, 4.939814718160446, 4.977960749209548, 5.015752812467621, 5.053200011165293, 5.090311069651955, 5.127094354997126, 5.163557897038226, 5.199709407008934, 5.2355562948688465, 5.271105685443211, 5.3063644334709075, 5.341339137649455, 5.37603615375741, 5.410461606927017, 5.4446214031333, 5.4785212399597905, 5.512166616695651, 5.545562843814195, 5.578715051878409, 5.611628199915167, 5.644307083296313, 5.676756341161579, 5.70898046341541, 5.740983797327173, 5.772770553761827, 5.804344813065982, 5.83571053063233, 5.866871542163618, 5.8978315686557305, 5.928594221117941, 5.959163005047064, 5.989541324670968, 6.0197324869757916, 6.049739705530176, 6.0795661041188325, 6.109214720196934, 6.13868850817599, 6.167990342551115, 6.197123020878945, 6.226089266614799, 6.254891731817131, 6.28353299972676, 6.312015587227867, 6.34034194719734], [0.0, 0.8005683670031263, 1.0936086176103978, 1.3125111163975436, 1.4939133967893272, 1.6517142959115125, 1.7929430224366991, 1.9217307691653716, 2.040745840118924, 2.1518280032920654, 2.256308220871868, 2.3551855824287187, 2.4492323467154304, 2.539059827970539, 2.625161593323486, 2.7079428364275304, 2.787740971406519, 2.864840452139832, 2.9394836781083913, 3.0118791786655854, 3.08220786135686, 3.150627855425747, 3.217278317725177, 3.2822824600355043, 3.345749983758317, 3.407779057685163, 3.468457939315647, 3.5278663151142684, 3.5860764169653936, 3.643153958804171, 3.6991589275496897, 3.7541462550751636, 3.8081663923449094, 3.8612658025555553, 3.913487386801475, 3.9648708531985695, 4.015453038368542, 4.065268188577169, 4.114348206537554, 4.1627228688599365, 4.210420018298342, 4.257465734268954, 4.303884484563339, 4.349699260726492, 4.39493169919565, 4.439602189985544, 4.483729974447349, 4.527333233412305, 4.570429166849226, 4.61303406601189, 4.6551633789224915, 4.696831769927042, 4.738053173964568, 4.778840846111546, 4.819207406893877, 4.859164883799369, 4.898724749372289, 4.937897956227199, 4.976694969280643, 5.015125795465715, 5.053200011165293, 5.0909267875739745, 5.128314914176429, 5.165372820510029, 5.202108596362301, 5.238530010538361, 5.274644528319958, 5.310459327725696, 5.345981314671375, 5.381217137119849, 5.416173198301394, 5.4508556690779875, 5.48527049951818, 5.5194234297431946, 5.553320000099432, 5.5869655607077675, 5.620365280435546, 5.653524155333332, 5.686447016574821, 5.71913853793518, 5.751603242840114, 5.783845511015344, 5.815869584763803, 5.847679574895632, 5.879279466334162, 5.910673123419181, 5.941864294927222, 5.97285661882706, 6.0036536267872584, 6.034258748451372, 6.0646753154952275, 6.094906565479705, 6.124955645511436, 6.154825615722984, 6.184519452583253, 6.2140400520481025, 6.243390232560495, 6.272572737908844, 6.301590239951655, 6.330445341216009, 6.35914057737694, 6.3876784196243115], [0.0, 0.8064477977449888, 1.1016401566905811, 1.3221502909201035, 1.504884802496554, 1.6638446025891405, 1.806110522876397, 1.9358440959310914, 2.0557332219881803, 2.1676311804287236, 2.2728787081202846, 2.372482232017758, 2.467219682396889, 2.5577068630312434, 2.644440965842189, 2.727830160253849, 2.8082143383832747, 2.8858800431592657, 2.961071454261687, 3.033998632498255, 3.104843814012232, 3.173766289359505, 3.2409062373707793, 3.306387774702444, 3.3703214084109443, 3.43280602824638, 3.493930539877679, 3.5537752149923754, 3.6124128159509055, 3.6699095392962082, 3.726325812495552, 3.7817169708457135, 3.8361338358264634, 3.889623211863433, 3.9422283151196695, 3.993989145330288, 4.044942809647747, 4.095123805844823, 4.144564270930402, 4.193294200196256, 4.241341640875566, 4.288732863913596, 4.335492516795103, 4.381643759916618, 4.427208388614901, 4.472206942650394, 4.516658804684121, 4.56058228906863, 4.603994722090523, 4.646912514647698, 4.689351228213722, 4.731325634830596, 4.772849771776529, 4.813936991474215, 4.85460000713559, 4.894850934579185, 4.934701330604444, 4.974162228262705, 5.013244169325597, 5.051957234217845, 5.090311069651955, 5.128314914176429, 5.165977621826534, 5.20330768404676, 5.240313250036606, 5.277002145655845, 5.3133818910117805, 5.349459716838895, 5.385242579770522, 5.420737176592625, 5.455949957561256, 5.49088713885764, 5.525554714248053, 5.559958466009573, 5.5941039751772985, 5.627996631163769, 5.6616416407968595, 5.69504403681848, 5.7282086858828105, 5.761140296089552, 5.793843424084768, 5.826322481759198, 5.858581742571544, 5.890625347522029, 5.922457310799544, 5.9540815251238595, 5.985501766802792, 6.016721700522614, 6.047744883888713, 6.078574771732191, 6.109214720196934, 6.139667990620702, 6.169937753222698, 6.200027090609317, 6.2299390011088605, 6.259676401945292, 6.289242132260419, 6.318638955993233, 6.347869564624556, 6.376936579794613, 6.4058425558006125, 6.434589981981014], [0.0, 0.8122753000438742, 1.1096007594271875, 1.331704330104479, 1.5157593063027874, 1.6758677716940582, 1.819161725016863, 1.9498327706486205, 2.070588231959724, 2.1832947803820075, 2.289302841131368, 2.3896261137417927, 2.4850481499198045, 2.576189203321424, 2.663550058644976, 2.7475418348027763, 2.8285068800188915, 2.9067338078205913, 2.9824685623635694, 3.0559227223837233, 3.1272798408876605, 3.196700359486653, 3.264325469962847, 3.3302801858565982, 3.3946758127634857, 3.4576119550244946, 3.5191781607531, 3.5794552816910494, 3.6385166059895684, 3.696428808536885, 3.7532527534574274, 3.8090441759084106, 3.863854264612581, 3.9177301622107636, 3.9707153971519227, 4.02285025821474, 4.074172120693043, 4.124715731645242, 4.174513460306653, 4.2235955187191365, 4.271990156789025, 4.3197238352990315, 4.366821379840016, 4.413306118168708, 4.45920000311796, 4.504523722871335, 4.549296800151623, 4.593537681653393, 4.637263818865368, 4.680491741272845, 4.723237122798728, 4.765514842229821, 4.8073390382796255, 4.8487231598572755, 4.889680012042118, 4.930221798203245, 4.970360158651122, 5.010106206163425, 5.049470558688071, 5.088463369492313, 5.127094354997126, 5.165372820510029, 5.20330768404676, 5.240907498412152, 5.278180471692936, 5.31513448629962, 5.3517771166808314, 5.388115645821333, 5.4241570806240444, 5.459908166266821, 5.495375399616151, 5.530565041772234, 5.565483129813124, 5.600135487799426, 5.634527737095561, 5.668665306058704, 5.70255343914198, 5.736197205454584, 5.7696015068178035, 5.802771085352716, 5.835710530632331, 5.868424286428316, 5.900916657079971, 5.933191813510957, 5.96525379891724, 5.997106534147919, 6.028753822798928, 6.060199356038064, 6.09144671717846, 6.122499386016298, 6.153360742947424, 6.184034072876468, 6.2145225689310735, 6.2448293359929705, 6.274957394056792, 6.3049096814267624, 6.334689057760716, 6.364298306970246, 6.393740139985185, 6.423017197390088, 6.452132051939866, 6.48108721096128], [0.0, 0.8180521460508584, 1.1174921636297988, 1.3411753196094316, 1.5265392821258752, 1.6877864278991912, 1.8320994779519264, 1.96369984706323, 2.0853141129009014, 2.1988222225354717, 2.305584205313995, 2.4066209701317494, 2.5027216412610436, 2.594510883559195, 2.682493043270822, 2.7670821631576397, 2.8486230262007117, 2.9274062985268423, 3.0036796734296267, 3.077656234378365, 3.1495208397960086, 3.219435072343523, 3.2875411279492868, 3.3539649092413484, 3.4188185134130182, 3.4822022531844965, 3.5442063135292763, 3.6049121212011253, 3.6643934855715536, 3.7227175557160055, 3.77994562862037, 3.836133835826463, 3.8913337301077036, 3.9455927893801315, 3.9989548516640427, 4.05146049226914, 4.103147352299766, 4.154050425933019, 4.204202312611987, 4.253633439244495, 4.302372256648259, 4.3504454137932616, 4.397877912828252, 4.444693247415363, 4.490913526514479, 4.536559585442103, 4.581651085765284, 4.626206605370213, 4.6702437198594, 4.713779076274702, 4.756828460010884, 4.799406855671657, 4.841528502524082, 4.883206945125005, 4.924455079622617, 4.9652851961755315, 5.0057090178793, 5.0457377365449085, 5.085382045634388, 5.12465217062433, 5.163557897038226, 5.202108596362301, 5.240313250036606, 5.278180471692936, 5.315718527793367, 5.352935356807568, 5.389838587053126, 5.426435553310888, 5.462733312316385, 5.498738657218714, 5.534458131089626, 5.56989803955784, 5.60506446263669, 5.6399632658071, 5.674600110412247, 5.70898046341541, 5.743109606567903, 5.7769926450300755, 5.810634515484631, 5.844039993778286, 5.877213702124777, 5.910160115899569, 5.942883570054129, 5.975388265175436, 6.007678273214391, 6.0397575429049, 6.071629904893809, 6.1032990766002495, 6.134768666821627, 6.166042180102196, 6.197123020878944, 6.228014497418518, 6.258719825557864, 6.289242132260418, 6.319584458998807, 6.3497497649742725, 6.379740930182338, 6.409560758333585, 6.439211979637792, 6.468697253459169, 6.498019170849884, 6.527180256968632], [0.0, 0.8237795574412642, 1.125316038156087, 1.350565262340032, 1.53722700969258, 1.6996030917370504, 1.8449265177305447, 1.9774482577552657, 2.099913979010244, 2.214216790600139, 2.3217262438170447, 2.423470395224346, 2.520243893973626, 2.6126757783752095, 2.701273925742535, 2.78645527766625, 2.8685670310492974, 2.947901887053159, 3.024709273141308, 3.099203764639885, 3.171571514217254, 3.241975235819686, 3.3105581209289423, 3.3774469536525076, 3.44275461600743, 3.5065821230312606, 3.5690202911076616, 3.63015111708183, 3.6900489270852868, 3.748781340322893, 3.806410082937845, 3.8629916794645482, 3.9185780436117765, 3.9732169857017117, 4.026952650676865, 4.079825897926005, 4.131874632089353, 4.183134092348008, 4.233637106382858, 4.283414314128998, 4.332494365596265, 4.380904096331513, 4.428668683530516, 4.47581178534109, 4.522355665514121, 4.5683213052399765, 4.6137285037418225, 4.658595968974818, 4.70294139959317, 4.746781559189323, 4.790132343675996, 4.833008842568294, 4.875425394826357, 4.917395639836258, 4.9589325640357185, 5.000048543630183, 5.0407553837918675, 5.081064354688749, 5.120986224650772, 5.160531290745943, 5.199709407008934, 5.238530010538361, 5.277002145655845, 5.31513448629962, 5.352935356807568, 5.390412751228803, 5.427574351288892, 5.464427543121528, 5.5009794328684185, 5.537236861239391, 5.573206417116073, 5.608894450274645, 5.644307083296313, 5.67945022272787, 5.714329569549139, 5.74895062899913, 5.783318719808175, 5.817438982879275, 5.851316389458229, 5.884955748828786, 5.9183617155660935, 5.951538796378969, 5.984491356569083, 6.017223626132897, 6.049739705530177, 6.082043571141019, 6.114139080431693, 6.14602997684802, 6.177719894453606, 6.209212362328996, 6.240510808746592, 6.271618565135138, 6.302538869846553, 6.333274871737015, 6.363829633573353, 6.394206135274998, 6.424407277001131, 6.454435882091889, 6.484294699872013, 6.513986408324666, 6.543513616642692, 6.572878867664129], [0.0, 0.8294587081601642, 1.1330739866622799, 1.359876082948841, 1.5478246796618673, 1.7113201852641877, 1.8576454735055965, 1.9910808207306088, 2.1143908228160875, 2.229481639994067, 2.3377322652672707, 2.4401778426390663, 2.5376184995862254, 2.630687611020219, 2.7198965555695933, 2.805665149227635, 2.8883429824788256, 2.9682247743715884, 3.045561671926706, 3.120569729756381, 3.193436383868737, 3.264325469962847, 3.333381166685057, 3.4007311321947142, 3.4664890267194717, 3.5307565616963217, 3.593625179598668, 3.655177442559397, 3.7154881891156837, 3.774625504640374, 3.832651540817778, 3.889623211863433, 3.9455927893801315, 4.000608413295255, 4.054714532887322, 4.107952289230448, 4.160359848280104, 4.211972692156923, 4.262823874856401, 4.312944247545884, 4.362362657748878, 4.411106126016969, 4.45920000311796, 4.506668110299352, 4.553532864798721, 4.599815392451129, 4.645535628975933, 4.690712411301264, 4.735363560096162, 4.77950595452157, 4.82315560007691, 4.866327690304666, 4.909036663018025, 4.951296251633223, 4.9931195321167126, 5.034518965995717, 5.075506439827513, 5.116093301476816, 5.156290393510626, 5.196108083985116, 5.2355562948688465, 5.274644528319958, 5.3133818910117805, 5.3517771166808314, 5.389838587053126, 5.427574351288892, 5.464992144071645, 5.502099402455217, 5.538903281571177, 5.575410669289331, 5.611628199915168, 5.647562267000338, 5.68321903533523, 5.718604452186473, 5.753724257836545, 5.788583995477672, 5.823189020507605, 5.85754450927082, 5.891655467284972, 5.925526736989097, 5.959163005047065, 5.992568809237023, 6.025748544955107, 6.058706471359451, 6.091446717178459, 6.123973286205463, 6.156290062500174, 6.188400815315793, 6.220309203769224, 6.252018781270555, 6.28353299972676, 6.314855213533509, 6.345988683367977, 6.376936579794612, 6.407701986695009, 6.43828790453222, 6.46869725345917, 6.498932876280154, 6.528997541273808, 6.558893944885354, 6.588624714295462, 6.6181924098725355], [0.0, 0.8350907269793663, 1.1407675510961082, 1.3691096320280216, 1.5583343983964106, 1.722940037336712, 1.8702588732604746, 2.0046002455586156, 2.1287475216946397, 2.244619804715206, 2.35360545097587, 2.456746633100531, 2.554848911425925, 2.648549961474736, 2.7383646341328154, 2.8247155959411057, 2.9079548111010283, 2.988378999801282, 3.0662410143491616, 3.1417583763661723, 3.215119794549622, 3.2864902170418313, 3.356014801461146, 3.423822072764921, 3.490026462932959, 3.554730374022197, 3.618025869399793, 3.679996071794937, 3.740716327897948, 3.8002551853808764, 3.858675217937533, 3.9160337262305807, 3.9723833367866286, 4.027772516402828, 4.082246016167987, 4.135845256503825, 4.188608662512387, 4.240571957237654, 4.291768419111519, 4.34222910878054, 4.391983069642706, 4.441057505718956, 4.489477939908633, 4.537268355205338, 4.584451321059535, 4.631048106750558, 4.677078783361159, 4.722562315722078, 4.767516645504574, 4.811958766478975, 4.85590479282193, 4.899370021239972, 4.942368987578938, 4.984915518504863, 5.027022778769922, 5.068703314515019, 5.109969093007073, 5.150831539162721, 5.191301569169916, 5.23138962148386, 5.271105685443211, 5.310459327725696, 5.349459716838895, 5.388115645821333, 5.426435553310888, 5.464427543121528, 5.502099402455217, 5.539458618863328, 5.576512396060727, 5.613267668685802, 5.649731116090935, 5.685909175239946, 5.721808052782106, 5.757433736365943, 5.792792005250414, 5.827888440265979, 5.862728433173505, 5.897317195464811, 5.931659766644978, 5.965761022033173, 5.999625680115679, 6.033258309482126, 6.066663335373359, 6.099845045867163, 6.132807597725983, 6.165555021928876, 6.198091228908294, 6.23042001351064, 6.262545059698196, 6.2944699450086805, 6.326198144787488, 6.357733036206617, 6.389077902083215, 6.420235934509839, 6.451210238307621, 6.482003834312734, 6.512619662505923, 6.543060584994104, 6.573329388852503, 6.603428788835189, 6.633361429961369, 6.66312988998433], [0.0, 0.8406766998814359, 1.1483982149534746, 1.3782676900178812, 1.5687581924113339, 1.7344648885289486, 1.8827691491483143, 2.0180091390948616, 2.1429868439471402, 2.259634203749358, 2.369348861657569, 2.473179961452038, 2.571938451911818, 2.6662662740101295, 2.7566817225018614, 2.843610291170275, 2.9274062985268428, 3.0083684495397374, 3.0867512878607872, 3.1627737901269164, 3.23662592731944, 3.308473750928882, 3.3784633895417677, 3.446724227826745, 3.513371463206122, 3.578508182710453, 3.642227065524383, 3.704611790390118, 3.765738207996592, 3.8256753245354234, 3.8844861322596835, 3.9422283151196695, 3.998954851664043, 4.054714532887323, 4.109552409221086, 4.163510178150782, 4.216626521806311, 4.268937402185279, 4.3204763203210454, 4.371274544626728, 4.4213613127733815, 4.470764010751304, 4.519508332184068, 4.567618420488989, 4.615116996084962, 4.662025470522829, 4.708364049142042, 4.754151823630254, 4.799406855671658, 4.84414625270895, 4.888386236707492, 4.932142206694422, 4.975428795746736, 5.018259923017887, 5.060648841319877, 5.102608180715516, 5.1441499885215025, 5.185285766076439, 5.226026502587326, 5.266382706332831, 5.3063644334709075, 5.345981314671375, 5.385242579770522, 5.4241570806240444, 5.462733312316385, 5.5009794328684185, 5.538903281571177, 5.576512396060727, 5.613814028238018, 5.650815159127662, 5.6875225127606335, 5.723942569157999, 5.760081576485686, 5.795945562443969, 5.831540344949621, 5.8668715421636195, 5.901944581912646, 5.93676471054851, 5.97133700128585, 6.005666362055138, 6.039757542904901, 6.0736151429843455, 6.107243617135022, 6.140647282117931, 6.173830322500354, 6.206796796224815, 6.2395506398808855, 6.272095673698929, 6.304435606283476, 6.336574039102613, 6.3685144707485355, 6.400260300983347, 6.431814834583162, 6.463181284992641, 6.494362777801251, 6.525362354051725, 6.556182973390518, 6.586827517069354, 6.617298790806377, 6.64759952751481, 6.677732389906556, 6.707699972977651], [0.0, 0.8462176722848183, 1.1559674063180598, 1.3873519708549016, 1.5790980125264353, 1.7458968957242589, 1.8951786424753467, 2.031310010822453, 2.157111454471967, 2.2745276470510216, 2.384965443701869, 2.4894809032016267, 2.588890319362469, 2.6838398642457606, 2.7748512487316774, 2.8623527710695873, 2.946701085114734, 3.028196864625414, 3.107096330972549, 3.183619904086903, 3.2579588070648615, 3.330280185856598, 3.4007311321947142, 3.469441883533333, 3.5365283965708767, 3.602094437793379, 3.666233297241961, 3.7290292051926115, 3.790558512272676, 3.8508906794995146, 3.9100891143135548, 3.9682118808649682, 4.025312306888587, 4.0814395049645675, 4.1366388224557555, 4.1909522316793115, 4.244418669722381, 4.297074335611186, 4.348952951187277, 4.400085990956573, 4.450502885298127, 4.5002312007056595, 4.549296800151623, 4.597723986184671, 4.645535628975933, 4.692753281201625, 4.739397281376328, 4.785486847022647, 4.831040158870891, 4.876074437120381, 4.920606010656847, 4.964650380003739, 5.008222274685922, 5.051335705599184, 5.094004012905954, 5.136239909914869, 5.178055523347527, 5.219462430348843, 5.260471692556626, 5.301093887510512, 5.341339137649455, 5.381217137119849, 5.420737176592625, 5.459908166266821, 5.498738657218714, 5.537236861239391, 5.575410669289331, 5.613267668685802, 5.650815159127662, 5.688060167652052, 5.7250094626086145, 5.761669566728792, 5.7980467693607105, 5.834147137933735, 5.869976528711028, 5.905540596883349, 5.940844806052654, 5.975894437149904, 6.010694596827735, 6.0452502253652085, 6.079566104118833, 6.113646862551199, 6.147496984866101, 6.181120816276685, 6.2145225689310735, 6.247706327518038, 6.280676054573552, 6.3134355955074435, 6.345988683367977, 6.3783389433608235, 6.410489897137699, 6.442444966868833, 6.474207479112404, 6.50578066849316, 6.5371676812016, 6.56837157832423, 6.599395339014788, 6.630241863515577, 6.66091397603747, 6.691414427506556, 6.721745898184902, 6.7519110001723845], [0.0, 0.8517146511227925, 1.1634765007012597, 1.3963641253801318, 1.5893557377456546, 1.7572381364042942, 1.9074896083569022, 2.0445052778424713, 2.171123920064146, 2.289302841131368, 2.4004580350323375, 2.5056524206381408, 2.605707594356204, 2.7012739257425347, 2.792876514679646, 2.880946441616438, 2.9658426772100355, 3.0478678483772907, 3.1272798408876605, 3.204300506506453, 3.279122310503726, 3.3519134845996397, 3.4228220760257986, 3.491979168250953, 3.5595014712212274, 3.625493425483476, 3.6900489270852863, 3.753252753457428, 3.815181751196305, 3.875905832533847, 3.935488816801381, 3.993989145330288, 4.051460492269141, 4.107952289230448, 4.163510178150782, 4.218176403996938, 4.271990156789025, 4.324987870699953, 4.377203486626315, 4.428668683530517, 4.479413082969576, 4.529464430507488, 4.578848757121012, 4.627590523226688, 4.675712747558895, 4.723237122798728, 4.7701841195785315, 4.816573080256776, 4.862422303664695, 4.907749121862981, 4.95256996980882, 4.996900448716127, 5.040755383791866, 5.08414887694576, 5.127094354997126, 5.169604613839485, 5.211691858968885, 5.253367742734676, 5.294643398630396, 5.335529472906739, 5.37603615375741, 5.416173198301394, 5.455949957561256, 5.495375399616151, 5.534458131089626, 5.573206417116073, 5.611628199915168, 5.649731116090935, 5.6875225127606335, 5.7250094626086145, 5.762198777951311, 5.799097023891432, 5.83571053063233, 5.872045405017025, 5.90810754135061, 5.943902631559623, 5.979436174737246, 6.01471348611905, 6.049739705530177, 6.0845198053414435, 6.119058597968759, 6.153360742947424, 6.187430753610352, 6.221273003396926, 6.254891731817133, 6.288291050093632, 6.321474946502793, 6.354447291433994, 6.3872118421851525, 6.41977224751106, 6.452132051939866, 6.484294699872013, 6.5162635394747985, 6.5480418263849005, 6.579632727230277, 6.611039322982069, 6.642264612146419, 6.673311513805426, 6.704182870515866, 6.7348814510736785, 6.7654099531517495, 6.795771005818002], [0.0, 0.8571686067878046, 1.17092682369822, 1.4053057445268695, 1.5995331788853253, 1.768490612660495, 1.9197042200719119, 2.0575972695412594, 2.185026714371684, 2.3039623942843597, 2.4158293705864806, 2.5216973685512425, 2.622393245679531, 2.718571536169491, 2.8107607023812853, 2.899394585187923, 2.984834453915509, 3.0673848733526765, 3.1473053806406788, 3.224819248172836, 3.3001201736707655, 3.3733774661266254, 3.4447401207926225, 3.514340060530638, 3.5822947426390592, 3.648709276449892, 3.713678159274163, 3.7772867114150093, 3.8396122715560965, 3.900725199612404, 3.9606897235824143, 4.019564659026636, 4.077404023796108, 4.134257566038722, 4.19017121995924, 4.245187501040146, 4.299345850254883, 4.352682935082627, 4.405232913760537, 4.45702766810729, 4.508097009361573, 4.55846886075613, 4.6081694199571075, 4.657223304013349, 4.705653679059721, 4.753482376686429, 4.800729998609531, 4.847416011046309, 4.893558830004582, 4.939175898530914, 4.984283756823755, 5.028898105999407, 5.0730338661980685, 5.116705229631052, 5.159925709096325, 5.202708182425929, 5.245064933273818, 5.287007688605173, 5.328547653206869, 5.369695541502878, 5.410461606927017, 5.4508556690779875, 5.49088713885764, 5.530565041772234, 5.56989803955784, 5.608894450274645, 5.647562267000338, 5.685909175239946, 5.723942569157999, 5.761669566728792, 5.799097023891432, 5.836231547788271, 5.873079509158125, 5.9096470539491905, 5.945940114210748, 5.9819644183175935, 6.017725500576359, 6.05322871025873, 6.088479220102726, 6.1234820343197445, 6.1582419961420065, 6.19276379494215, 6.227051972954221, 6.261110931622928, 6.294944937605961, 6.328558128452202, 6.361954517976949, 6.395138001353625, 6.428112359940008, 6.460881265855694, 6.493448286326223, 6.525816887808259, 6.5579904399090925, 6.589972219112874, 6.621765412325068, 6.653373120245817, 6.684798360582199, 6.71604407110866, 6.747113112584292, 6.778008271535022, 6.808732262908285, 6.839287732607246], [0.0, 0.8625804749516609, 1.1783196534742952, 1.4141783623048232, 1.6096320819707766, 1.7796562549494748, 1.9318245731393915, 2.070588231959724, 2.1988222225354717, 2.3185088214792096, 2.4310820874457466, 2.5376184995862254, 2.6389501358957848, 2.7357356630766767, 2.828506880018891, 2.917700366717694, 3.0036796734296263, 3.0867512878607863, 3.1671763857807904, 3.2451796492481613, 3.3209559989253994, 3.394675812763485, 3.4664890267194712, 3.5365283965708763, 3.604912121201125, 3.6717459735664426, 3.7371250476014204, 3.801135202292283, 3.8638542646125806, 3.9253530387056292, 3.9856961580834325, 4.044942809647746, 4.103147352299766, 4.160359848280104, 4.21662652180631, 4.271990156789024, 4.326490443218449, 4.3801642800796285, 4.433046041273097, 4.4851678099083845, 4.536559585442102, 4.587249467404693, 4.637263818865367, 4.686627412296562, 4.735363560096161, 4.783494231691531, 4.8310401588708904, 4.878020930754531, 4.924455079622617, 4.97036015865112, 5.015752812467621, 5.060648841319877, 5.105063259548726, 5.14901034897023, 5.1925037076975205, 5.2355562948688465, 5.278180471692936, 5.320388039174998, 5.362190272845084, 5.4035979547743604, 5.4446214031333, 5.48527049951818, 5.525554714248053, 5.565483129813124, 5.60506446263669, 5.644307083296313, 5.68321903533523, 5.721808052782106, 5.760081576485686, 5.7980467693607105, 5.83571053063233, 5.873079509158125, 5.9101601158995685, 5.946958535608261, 5.983480737786407, 6.0197324869757916, 6.055719352424759, 6.091446717178458, 6.1269197866338, 6.162143596597054, 6.197123020878944, 6.2318627784592, 6.2663674402499705, 6.300641435485176, 6.334689057760715, 6.368514470748535, 6.4021217136057835, 6.43551470609867, 6.468697253459168, 6.501673050991375, 6.534445688443069, 6.567018654156928, 6.599395339014787, 6.631579040187392, 6.663572964701235, 6.6953802328332115, 6.727003881343168, 6.758446866553649, 6.789712067285595, 6.820802287658101, 6.85172025975985, 6.882468646199328], [0.0, 0.86795115827112, 1.1856562230949557, 1.4229834585963852, 1.6196541314190802, 1.7907369256119587, 1.943852689138264, 2.083480331887534, 2.2125127455370377, 2.332944548944795, 2.446218729642537, 2.553418469261684, 2.6553810265631563, 2.752769169304555, 2.84611800751438, 2.9358668394651657, 3.0223814789857877, 3.105970322066218, 3.186896170634315, 3.265385105686115, 3.3416332615183024, 3.4158120769057985, 3.4880724213516463, 3.5585478772104318, 3.6273573793070844, 3.694607359171803, 3.760393502822379, 3.8248022038286953, 3.8879117737382525, 3.9497934575420817, 4.010512291179711, 4.0701278300681984, 4.128694771563475, 4.186263489608592, 4.242880496226869, 4.298588841714331, 4.3534284631829, 4.407436489361705, 4.46064750817344, 4.513093802486643, 4.56480555854349, 4.615811050830481, 4.666136806561162, 4.715807752448768, 4.764847346041129, 4.813277693553816, 4.8611196558573475, 4.9083929440397185, 4.955116205768601, 5.001307103511271, 5.046982385529729, 5.092157950448785, 5.136848906093043, 5.18106962320141, 5.224833784552928, 5.268154429973305, 5.31104399763584, 5.353514362022322, 5.395576868867617, 5.437242367375279, 5.4785212399597905, 5.5194234297431946, 5.559958466009573, 5.600135487799426, 5.6399632658071, 5.67945022272787, 5.718604452186473, 5.757433736365943, 5.795945562443969, 5.834147137933735, 5.872045405017025, 5.9096470539491905, 5.946958535608261, 5.983986073253948, 6.020735673556354, 6.057213136949024, 6.0934240673561, 6.12937388133918, 6.165067816705524, 6.200510940615837, 6.235708157226641, 6.2706642148994405, 6.305383713006247, 6.339871108358712, 6.374130721285945, 6.408166741384153, 6.441983232959484, 6.47558414018378, 6.5089732919815235, 6.542154406664878, 6.57513109633246, 6.607906871046412, 6.64048514280121, 6.672869229296769, 6.705062357527481, 6.737067667198022, 6.768888213976006, 6.800526972590926, 6.83198683978812, 6.863270637145964, 6.8943811137639415, 6.925320948828731], [0.0, 0.8732815279875605, 1.1929377227109978, 1.4317224617792446, 1.6296009530241355, 1.801734422173179, 1.9557905192899547, 2.0962756607030566, 2.226100504276298, 2.3472719184693664, 2.461241752668682, 2.5690998406755585, 2.6716885831286623, 2.769674818057464, 2.8635969417747935, 2.9538969504264307, 3.0409429044226832, 3.125045093713372, 3.206467934178276, 3.2854388952501914, 3.3621553157501642, 3.4367896873142665, 3.5094938059841168, 3.5804020744868885, 3.649634158064865, 3.7172971418788108, 3.7834872995854023, 3.84829155532547, 3.911788701583141, 3.9740504208880543, 4.035142148586547, 4.095123805844822, 4.154050425933019, 4.211972692156922, 4.268937402185279, 4.324987870699952, 4.3801642800796285, 4.43450398707301, 4.488041792018449, 4.540810176044054, 4.5928395107755104, 4.644158244342115, 4.694793066869639, 4.744769058154355, 4.794109819804503, 4.8428375937971015, 4.890973369116039, 4.938536977901503, 4.985547182342541, 5.032021753377373, 5.077977542124511, 5.1234305448473805, 5.168395962152637, 5.21288825303456, 5.256921184302577, 5.300507875864196, 5.3436608422795775, 5.386392030955554, 5.4287128573048316, 5.470634237159444, 5.512166616695651, 5.553320000099432, 5.5941039751772985, 5.634527737095561, 5.674600110412247, 5.714329569549139, 5.753724257836545, 5.792792005250414, 5.831540344949621, 5.869976528711028, 5.90810754135061, 5.945940114210748, 5.983480737786407, 6.020735673556354, 6.057710965079605, 6.094412448412046, 6.1308457618933385, 6.167016355349942, 6.202929498756191, 6.238590290391867, 6.274003664531511, 6.309174398697854, 6.344107120509146, 6.378806314147763, 6.4132763264753585, 6.44752137281781, 6.481545542441486, 6.5153528037406705, 6.548947009154513, 6.582331899830537, 6.615511110050431, 6.648488171432767, 6.681266516926185, 6.713849484605674, 6.746240321283646, 6.778442185946719, 6.810458153028358, 6.8422912155268305, 6.873944287977331, 6.905420209286463, 6.936721745436821, 6.96785159206884], [0.0, 0.8785724254286442, 1.200165301609877, 1.440396751188327, 1.6394741167588731, 1.812650480441074, 1.9676399478214996, 2.108976237978038, 2.2395876433994766, 2.361493191436833, 2.476153527707703, 2.5846650889228715, 2.687875379522287, 2.78645527766625, 2.880946441616438, 2.9717935454136764, 3.0593668794133926, 3.1439786135001717, 3.225894765554128, 3.3053441831632133, 3.3825254007531327, 3.4576119550244946, 3.5307565616963217, 3.602094437793379, 3.671745973566443, 3.739818902966599, 3.806410082937845, 3.8716069642629938, 3.9354888168013815, 3.9981277573812104, 4.059589617797953, 4.1199346822585206, 4.179218317459765, 4.237491513779318, 4.294801352416103, 4.351191410480002, 4.406702113800222, 4.4613710454565165, 4.515233216629923, 4.5683213052399765, 4.620665866923074, 4.672295522165456, 4.723237122798728, 4.773515900568591, 4.82315560007691, 4.872178598056807, 4.920606010656847, 4.968457790172994, 5.015752812467622, 5.062508956146652, 5.108743174423434, 5.15447156047698, 5.199709407008934, 5.244471260615397, 5.288770971513925, 5.33262173910081, 5.376036153757411, 5.419026235275587, 5.461603468229905, 5.503778834587484, 5.545562843814195, 5.5869655607077675, 5.627996631163769, 5.668665306058704, 5.70898046341541, 5.74895062899913, 5.788583995477672, 5.827888440265979, 5.8668715421636195, 5.905540596883349, 5.943902631559623, 5.9819644183175935, 6.0197324869757916, 6.057213136949024, 6.094412448412046, 6.131336292779302, 6.167990342551115, 6.204380080572476, 6.240510808746592, 6.27638765624188, 6.312015587227868, 6.347399408172572, 6.382543774731312, 6.4174531982545036, 6.452132051939866, 6.486584576652415, 6.520814886433908, 6.554826973721695, 6.588624714295462, 6.622211871968998, 6.655592103042791, 6.6887689605322125, 6.721745898184902, 6.754526274300036, 6.787113355361294, 6.819510319494451, 6.851720259759852, 6.883746187289265, 6.915591034275999, 6.947257656826567, 6.978748837681653, 7.010067288813604], [0.0, 0.8838246634191993, 1.2073400701430301, 1.4490076594288999, 1.6492751394080547, 1.823486777417189, 1.9794027951253401, 2.121584014864368, 2.2529762348956206, 2.375610552619037, 2.490956345611222, 2.6001166052463875, 2.703943902473388, 2.8031131260629842, 2.8981691723913423, 2.9895593738275292, 3.077656234378365, 3.162773790126916, 3.2451796492481613, 3.3251040274153247, 3.4027466459227442, 3.4782820788995035, 3.5518639550221427, 3.623628299663122, 3.693696222784229, 3.7621761023862983, 3.8291653744386958, 3.8947520125181545, 3.9590157603711438, 4.022029165951102, 4.083858454605868, 4.144564270930401, 4.204202312611987, 4.262823874856401, 4.320476320321045, 4.377203486626314, 4.433046041273098, 4.488041792018449, 4.5422259593455045, 4.595631416527315, 4.648288901866464, 4.700227206946759, 4.75147334412409, 4.802052695983327, 4.851989149075131, 4.901305213904099, 4.950022132854305, 4.998159977499536, 5.045737736544909, 5.092773395477337, 5.13928400885903, 5.185285766076439, 5.230794051253277, 5.275823497947384, 5.320388039174998, 5.364500953240385, 5.408174905792095, 5.451421988478111, 5.4942537545295105, 5.536681251565265, 5.578715051878409, 5.620365280435546, 5.6616416407968595, 5.70255343914198, 5.743109606567903, 5.783318719808175, 5.823189020507605, 5.862728433173505, 5.901944581912646, 5.940844806052654, 5.979436174737246, 6.017725500576359, 6.055719352424759, 6.0934240673561, 6.1308457618933385, 6.167990342551115, 6.204863515740814, 6.241470797084695, 6.277817520181539, 6.313908844862706, 6.3497497649742725, 6.385345115718044, 6.420699580581546, 6.4558176978847275, 6.490703866968938, 6.525362354051723, 6.559797297769201, 6.59401271442611, 6.628012502972132, 6.6618004497216985, 6.6953802328332115, 6.728755426562504, 6.761929505304235, 6.794905847434001, 6.82768773896301, 6.860278377016352, 6.89268087314515, 6.924898256482172, 6.956933476749817, 6.9887894071288335, 7.020468846995548, 7.0519745245348835], [0.0, 0.8890390276079311, 1.2144631015382161, 1.45755647455168, 1.6590054870440043, 1.8342449340339164, 1.9910808207306085, 2.134100877278794, 2.266268281478543, 2.3896261137417922, 2.5056524206381403, 2.6154567009396588, 2.719896555569593, 2.8196508549887205, 2.9152677103377043, 3.007197093144692, 3.095813705105291, 3.1814334350439246, 3.2643254699628463, 3.3447213837553105, 3.4228220760257977, 3.498803150850987, 3.5728191432816154, 3.645006881208856, 3.715488189115683, 3.7843720844084485, 3.851756577906543, 3.917730162210763, 3.982373051537517, 4.045758221856643, 4.107952289230447, 4.169016256043184, 4.229006148585809, 4.287973564694123, 4.345966146454422, 4.403027990119074, 4.459200003117959, 4.514520216265287, 4.569024057837021, 4.622744595051034, 4.675712747558894, 4.727957476808194, 4.779505954521571, 4.830383713035362, 4.880614779825438, 4.930221798203244, 4.9792261358780845, 5.027647982841455, 5.075506439827512, 5.12281959843344, 5.169604613839484, 5.215877770945786, 5.261654544638885, 5.30694965481128, 5.35177711668083, 5.39615028689077, 5.440081905814095, 5.483584136436752, 5.526668600151256, 5.569346409755008, 5.611628199915167, 5.653524155333332, 5.69504403681848, 5.736197205454584, 5.7769926450300755, 5.817438982879275, 5.85754450927082, 5.897317195464811, 5.93676471054851, 5.975894437149904, 6.01471348611905, 6.05322871025873, 6.091446717178458, 6.12937388133918, 6.167016355349942, 6.204380080572476, 6.241470797084695, 6.278294053049772, 6.314855213533509, 6.351159468809091, 6.3872118421851525, 6.423017197390086, 6.458580245542929, 6.493905551738681, 6.528997541273808, 6.563860505535563, 6.598498607577076, 6.632915887398369, 6.667116266952038, 6.701103554890908, 6.734881451073678, 6.768453550843474, 6.8018233490930955, 6.834994244129782, 6.867969541351461, 6.900752456745532, 6.933346120220563, 6.965753578780511, 6.997977799550467, 7.030021672662293, 7.061888014007996, 7.093579567868171], [0.0, 0.8942162777160061, 1.2215354336051327, 1.466044442099856, 1.6686665773565474, 1.8449265177305447, 2.002675726099442, 2.146528648900095, 2.2794657197696164, 2.4035419168409162, 2.520243893973626, 2.6306876110202193, 2.735735663076677, 2.8360708739534695, 2.932244546674151, 3.024709273141308, 3.1138419370969297, 3.19996026691961, 3.283335017201317, 3.3641991103879874, 3.4427546160074294, 3.5191781607531, 3.593625179598668, 3.666233297241961, 3.737125047601421, 3.806410082937845, 3.874186984829061, 3.9405447612056896, 4.005564093405434, 4.069318382368055, 4.131874632089353, 4.193294200196255, 4.253633439244494, 4.312944247545883, 4.371274544626728, 4.428668683530516, 4.485167809908385, 4.540810176044054, 4.595631416527315, 4.64966479114043, 4.702941399593169, 4.75549037198788, 4.807339038279626, 4.858513079490335, 4.909036663018025, 4.9589325640357185, 5.008222274685922, 5.056926102534991, 5.105063259548728, 5.152651942679339, 5.199709407008934, 5.246252032271515, 5.292295383470427, 5.337854266218326, 5.382942777349609, 5.427574351288891, 5.471761802601747, 5.515517365104331, 5.55885272786544, 5.601779068396994, 5.644307083296313, 5.686447016574821, 5.7282086858828105, 5.7696015068178035, 5.810634515484631, 5.851316389458229, 5.891655467284972, 5.931659766644978, 5.97133700128585, 6.010694596827735, 6.049739705530177, 6.088479220102726, 6.1269197866338, 6.165067816705524, 6.202929498756191, 6.240510808746592, 6.277817520181539, 6.314855213533509, 6.351629285111345, 6.388144955413392, 6.42440727700113, 6.460421141926502, 6.496191288743379, 6.5317223091312435, 6.5670186541569295, 6.602084640198254, 6.636924454551565, 6.671542160743513, 6.705941703565884, 6.740126913850894, 6.774101513003085, 6.807869117302789, 6.84143324199504, 6.874797305176861, 6.907964631494904, 6.940938455664626, 6.973721925821375, 7.006318106713102, 7.038729982743719, 7.07096046087555, 7.103012373398729, 7.1348884805749595], [0.0, 0.8993571487130495, 1.228558070341875, 1.474472767037105, 1.6782597818474998, 1.85553304487955, 2.014189157260731, 2.158869093992012, 2.2925704232955346, 2.417359937423169, 2.5347328370435256, 2.6458114976892455, 2.7514634735363686, 2.852375513965958, 2.949102091455978, 3.042098399870802, 3.131743489666165, 3.2183569158487884, 3.3022109895853355, 3.383539972398515, 3.462547095518735, 3.5394100010705825, 3.6142850176271484, 3.687310561093975, 3.758609869839962, 3.8282932265194063, 3.8964597794580085, 3.9631990482951354, 4.0285921782074485, 4.092712992118489, 4.155628879231646, 4.217401549920329, 4.278087680712475, 4.337739468284546, 4.396405107653364, 4.454129206849133, 4.510953148070339, 4.566915403513999, 4.6220518126340275, 4.676395826423976, 4.7299787233865995, 4.782829801093906, 4.834976546621534, 4.886444788632225, 4.937258833462955, 4.987441587221764, 5.037014665610007, 5.085998492942728, 5.134412391635787, 5.182274663256107, 5.229602662085683, 5.276412862026004, 5.322720917563993, 5.368541719430133, 5.413889445501862, 5.45877760743863, 5.503219093477253, 5.547226207766395, 5.590810706575591, 5.633983831676547, 5.676756341161579, 5.71913853793518, 5.761140296089552, 5.802771085352716, 5.844039993778286, 5.884955748828786, 5.925526736989097, 5.965761022033173, 6.005666362055138, 6.0452502253652085, 6.0845198053414435, 6.1234820343197445, 6.162143596597054, 6.200510940615837, 6.238590290391867, 6.27638765624188, 6.313908844862706, 6.351159468809091, 6.388144955413392, 6.42487055518672, 6.461341349737858, 6.4975622592432725, 6.533538049498894, 6.569273338581882, 6.604772603148361, 6.64004018439111, 6.675080293679343, 6.709897017901024, 6.744494324526642, 6.778876066411962, 6.813045986355968, 6.847007721429077, 6.8807648070855505, 6.914320681073133, 6.947678687151955, 6.980842078633925, 7.013814021753101, 7.046597598876741, 7.079195811566172, 7.11161158349591, 7.1438477632389965, 7.175907126925944], [0.0, 0.9044623519256391, 1.2355319834491842, 1.48284261556494, 1.6877864278991914, 1.866065983073615, 2.02562270729269, 2.171123920064146, 2.305584205313995, 2.431082087445747, 2.5491212546385245, 2.660830453592624, 2.76708216315764, 2.8685670310492974, 2.9658426772100355, 3.0593668794133926, 3.149520839796009, 3.23662592731944, 3.3209559989254, 3.402746645922745, 3.4822022531844965, 3.5595014712212274, 3.6348015160055827, 3.7082415891613554, 3.779945628620371, 3.850024543056701, 3.9185780436117765, 3.9856961580834334, 4.051460492269141, 4.115945288148458, 4.179218317459765, 4.241341640875566, 4.30237225664826, 4.3623626577488785, 4.4213613127733815, 4.479413082969576, 4.536559585442103, 4.592839510775511, 4.648288901866465, 4.70294139959317, 4.756828460010885, 4.809979546999361, 4.862422303664694, 4.914182705286097, 4.9652851961755315, 5.015752812467622, 5.065607292565305, 5.114869176722306, 5.163557897038227, 5.2116918589688845, 5.259288515307899, 5.3063644334709075, 5.352935356807568, 5.399016260575633, 5.444621403133301, 5.489764372838989, 5.534458131089627, 5.578715051878409, 5.622546958209364, 5.665965155668146, 5.70898046341541, 5.751603242840114, 5.793843424084768, 5.835710530632331, 5.877213702124777, 5.9183617155660935, 5.959163005047065, 5.999625680115679, 6.039757542904901, 6.079566104118833, 6.119058597968759, 6.1582419961420065, 6.197123020878944, 6.235708157226641, 6.274003664531511, 6.312015587227868, 6.3497497649742725, 6.3872118421851525, 6.42440727700113, 6.461341349737858, 6.498019170849885, 6.5344456884430695, 6.570625695366398, 6.6065638359115555, 6.642264612146418, 6.677732389906556, 6.712971404467031, 6.747985765915039, 6.782779464242423, 6.817356374175696, 6.851720259759851, 6.885874778711142, 6.919823486552849, 6.9535698405470985, 6.987117203434884, 7.0204688469955485, 7.053627955436286, 7.08659762862142, 7.1193808851506475, 7.151980665294732, 7.184399833796647, 7.216641182545616], [0.0, 0.9095325760829622, 1.2424581137588564, 1.4911551168370367, 1.6972478007257301, 1.8765267532830054, 2.0369779186646966, 2.1832947803820075, 2.3185088214792096, 2.444710218126875, 2.563411087861209, 2.6757465048971625, 2.7825938390157563, 2.88464760955736, 2.982468562363569, 3.0765170414130507, 3.1671763857807904, 3.254769765954597, 3.3395725740601305, 3.4218217220811677, 3.5017227406289897, 3.579455281691049, 3.6551774425593964, 3.729029205192611, 3.801135202292283, 3.8716069642629933, 3.9405447612056896, 4.008039125594951, 4.074172120693043, 4.13901840466432, 4.202646129161157, 4.265117702755028, 4.326490443218449, 4.386817137786917, 4.446146526761062, 4.504523722871334, 4.5619905765190385, 4.618585995179935, 4.674346223799526, 4.729305091839647, 4.783494231691531, 4.836943272403192, 4.889680012042118, 4.941730571499428, 4.9931195321167126, 5.043870059164282, 5.094004012905954, 5.143542048739755, 5.192503707697521, 5.2409074984121515, 5.288770971513925, 5.336110787291898, 5.382942777349608, 5.429282000892928, 5.475142796209388, 5.520538827830864, 5.565483129813124, 5.609988145515348, 5.654065764218816, 5.6977273548859, 5.740983797327173, 5.783845511015344, 5.826322481759198, 5.868424286428316, 5.910160115899569, 5.951538796378969, 5.992568809237023, 6.033258309482126, 6.0736151429843455, 6.113646862551199, 6.153360742947424, 6.19276379494215, 6.2318627784592, 6.2706642148994405, 6.309174398697854, 6.347399408172572, 6.385345115718044, 6.423017197390086, 6.460421141926502, 6.4975622592432725, 6.5344456884430695, 6.571076405369786, 6.607459229740104, 6.64359883188062, 6.67949973909685, 6.715166341698312, 6.750602898702124, 6.785813543235756, 6.820802287658101, 6.855573028416567, 6.890129550656584, 6.924475532598789, 6.9586145496979706, 6.992550078596934, 7.026285500887486, 7.059824106689872, 7.093169098061273, 7.126323592243199, 7.159290624756972, 7.192073152355893, 7.224674055842076, 7.2570961427554845], [0.0, 0.9145684883039291, 1.2493373725821786, 1.4994113645775817, 1.706645145215021, 1.8869167318921576, 2.0482562854480184, 2.195383276336545, 2.33134597235817, 2.4582461225990473, 2.577604216908128, 2.6905616141945696, 2.7980005420722156, 2.900619365305477, 2.9989819344810797, 3.0935511424164344, 3.1847124506634805, 3.272790819044739, 3.3580631644806997, 3.4407677106926045, 3.5211111262763914, 3.5992740579190574, 3.6754154782678703, 3.749676144335403, 3.8221813788912673, 3.89304332986309, 3.962362822528666, 4.030230890623997, 4.0967300517803285, 4.161935377530341, 4.225915396869399, 4.288732863913596, 4.3504454137932616, 4.411106126016969, 4.470764010751304, 4.529464430507488, 4.5872494674046935, 4.644158244342115, 4.700227206946759, 4.7554903719878805, 4.809979546999361, 4.8637245250797285, 4.916753258209185, 4.96909201190535, 5.020765503612121, 5.071797026861586, 5.122208562953766, 5.172020881651775, 5.2212536321824965, 5.269925425657677, 5.318053909882162, 5.365655837389922, 5.412747127441129, 5.459342922621671, 5.505457640607501, 5.551105021588458, 5.596298171787447, 5.641049603460207, 5.6853712717167495, 5.729274608467271, 5.772770553761827, 5.815869584763803, 5.858581742571544, 5.900916657079971, 5.942883570054129, 5.984491356569083, 6.025748544955107, 6.066663335373359, 6.107243617135022, 6.147496984866101, 6.187430753610352, 6.227051972954221, 6.2663674402499705, 6.305383713006247, 6.344107120509146, 6.382543774731312, 6.420699580581546, 6.458580245542929, 6.496191288743379, 6.533538049498894, 6.570625695366398, 6.607459229740104, 6.644043499022564, 6.680383199399103, 6.716482883242085, 6.752346965169351, 6.787979727779401, 6.823385327084064, 6.858567797657914, 6.893531057522261, 6.92827891278018, 6.96281506201793, 6.997143100486926, 7.031266524079495, 7.065188733110687, 7.098913035917529, 7.1324426522863975, 7.165780716718384, 7.19893028154193, 7.231894319881324, 7.264675728489146, 7.297277330450185], [0.0, 0.9195707350296888, 1.2561706429837842, 1.5076124186101065, 1.7159796676689025, 1.8972372526236263, 2.059459255404265, 2.2073909596826087, 2.34409730580775, 2.4716915384155125, 2.5917024636979824, 2.705277683244815, 2.8133042500276586, 2.9164843485279826, 3.0153849133221624, 3.11047136902715, 3.202131285482906, 3.290691399884806, 3.376430143754794, 3.4595870437824976, 3.540369898940991, 3.618960343967166, 3.695518221011683, 3.7701850569598094, 3.843086860036015, 3.914336391562781, 3.984035028283342, 4.052274301844153, 4.119137181207938, 4.184699148512308, 4.249029107573045, 4.312190155740865, 4.374240243382351, 4.435232740325283, 4.495216924798122, 4.5542384074230595, 4.612339500488079, 4.669559540875689, 4.725935173552823, 4.781500601343992, 4.8362878057548855, 4.89032674283785, 4.943645517456883, 4.996270538789268, 5.0482266594713465, 5.09953730043955, 5.150224563220963, 5.200309331179248, 5.249811361013042, 5.2987493656278595, 5.347141089353495, 5.395003376352163, 5.442352232954681, 5.489202884569549, 5.535569827730424, 5.581466877779332, 5.626907212623868, 5.67190341295575, 5.716467499273654, 5.760610966014787, 5.804344813065982, 5.847679574895632, 5.890625347522029, 5.933191813510957, 5.975388265175436, 6.017223626132897, 6.058706471359451, 6.099845045867163, 6.140647282117931, 6.181120816276685, 6.221273003396926, 6.261110931622928, 6.300641435485176, 6.339871108358712, 6.378806314147763, 6.4174531982545036, 6.4558176978847275, 6.493905551738681, 6.5317223091312435, 6.569273338581882, 6.6065638359115555, 6.64359883188062, 6.680383199399103, 6.716921660338191, 6.753218791969517, 6.789279033056744, 6.825106689622114, 6.860705940408825, 6.896080842058623, 6.931235334022496, 6.96617324322106, 7.000898288470048, 7.03541408468516, 7.069724146879563, 7.10383189396638, 7.137740652377643, 7.171453659510399, 7.204974067009942, 7.238304943899472, 7.271449279564829, 7.304409986602426, 7.337189903537958], [0.0, 0.9245399429051914, 1.2629587809859018, 1.5157593063027874, 1.7252525374481997, 1.9074896083569022, 2.070588231959724, 2.219319334655105, 2.356764419221911, 2.4850481499198045, 2.605707594356204, 2.7198965555695938, 2.8285068800188915, 2.932244546674151, 3.031679553732254, 3.1272798408876605, 3.219435072343523, 3.3084737509288815, 3.3946758127634853, 3.4782820788995035, 3.559501471221227, 3.638516605989568, 3.7154881891156832, 3.790558512272676, 3.863854264612581, 3.935488816801381, 4.005564093405433, 4.074172120693043, 4.14139631597746, 4.207312569289259, 4.271990156789025, 4.335492516795103, 4.397877912828252, 4.45920000311796, 4.519508332184068, 4.578848757121012, 4.637263818865367, 4.694793066869639, 4.751473344124091, 4.807339038279626, 4.862422303664694, 4.916753258209185, 4.970360158651121, 5.023269556878607, 5.075506439827512, 5.127094354997126, 5.178055523347526, 5.2284109410926085, 5.278180471692936, 5.327382929175467, 5.376036153757411, 5.4241570806240444, 5.471761802601746, 5.5188656273745975, 5.565483129813124, 5.611628199915168, 5.657314086799557, 5.70255343914198, 5.747358342397896, 5.791740353118547, 5.83571053063233, 5.879279466334162, 5.922457310799544, 5.96525379891724, 6.007678273214391, 6.049739705530177, 6.091446717178459, 6.132807597725983, 6.173830322500354, 6.2145225689310735, 6.254891731817133, 6.294944937605961, 6.334689057760715, 6.374130721285945, 6.4132763264753585, 6.452132051939866, 6.490703866968938, 6.528997541273808, 6.5670186541569295, 6.604772603148361, 6.642264612146418, 6.67949973909685, 6.716482883242085, 6.753218791969517, 6.7897120672855955, 6.82596717194033, 6.861988435224991, 6.897780058464014, 6.933346120220563, 6.9686905812337665, 7.003817289104286, 7.038729982743719, 7.073432296602171, 7.107927764687355, 7.142219824387638, 7.176311820110537, 7.2102070067474555, 7.243908552974659, 7.277419544399839, 7.310742986562981, 7.343881807799686, 7.376838861974573], [0.0, 0.9294767196131484, 1.2697026167075784, 1.5238530239357009, 1.7344648885289482, 1.9176750528490196, 2.0816445760730873, 2.2311698599708807, 2.3693488616575684, 2.498317590487321, 2.619621321565374, 2.734420018905742, 2.8436102911702745, 2.9479018870531584, 3.0478678483772907, 3.1439786135001717, 3.2366259273194395, 3.32614004677452, 3.412802402763323, 3.496855102252997, 3.578508182710452, 3.657945235514778, 3.7353278247003585, 3.8107990017368016, 3.8844861322596835, 3.956503192301654, 4.026952650676864, 4.095927025047357, 4.163510178150782, 4.229778405248595, 4.294801352416103, 4.358642796713978, 4.421361312773381, 4.483010845343272, 4.543641203496943, 4.6032984891924915, 4.662025470522828, 4.719861908123129, 4.776844841714602, 4.833008842568293, 4.8883862367074915, 4.94300730288315, 4.996900448716126, 5.050092367873947, 5.1026081807155155, 5.15447156047698, 5.205704846771934, 5.256329147928005, 5.3063644334709075, 5.355829617889075, 5.404742636661337, 5.453120515401974, 5.500979432868417, 5.548334778483368, 5.595201204942958, 5.641592676413612, 5.687522512760633, 5.7330034301999895, 5.778047578719989, 5.8226665765805246, 5.866871542163618, 5.910673123419181, 5.9540815251238595, 5.997106534147919, 6.0397575429049, 6.082043571141019, 6.123973286205463, 6.165555021928876, 6.206796796224815, 6.247706327518038, 6.288291050093632, 6.328558128452202, 6.368514470748535, 6.408166741384153, 6.44752137281781, 6.486584576652415, 6.525362354051723, 6.563860505535563, 6.602084640198254, 6.64004018439111, 6.677732389906556, 6.715166341698312, 6.752346965169351, 6.789279033056744, 6.82596717194033, 6.862415868399916, 6.898629474843939, 6.934612215030696, 6.970368189301702, 7.005901379545292, 7.041215653907203, 7.076314771263744, 7.111202385471935, 7.145882049410073, 7.180357218821186, 7.214631255970963, 7.24870743313099, 7.28258893589735, 7.316278866353989, 7.349780246089609, 7.38309601907628, 7.4162290544174345], [0.0, 0.9343816546634924, 1.276402955443114, 1.5318945379951234, 1.7436178209755808, 1.9277948023633533, 2.0926296080035147, 2.242943950723791, 2.381852135847022, 2.5115014446472967, 2.6334453067902244, 2.748849807527748, 2.8586162870089713, 2.9634582393379154, 3.0639517303324455, 3.1605696808970047, 3.2537059032034716, 3.3436923969878394, 3.4308120782850287, 3.515308331683158, 3.5973923030363757, 3.6772485525525442, 3.7550394968544754, 3.83090894230768, 3.904984926668032, 3.9773820274303007, 4.048203254146095, 4.117541612701761, 4.1854814083864085, 4.252099339078684, 4.317465418382702, 4.381643759916617, 4.444693247415363, 4.506668110299352, 4.567618420488989, 4.627590523226688, 4.686627412296562, 4.744769058154355, 4.802052695983327, 4.858513079490335, 4.914182705286097, 4.96909201190535, 5.023269556878607, 5.076742174738361, 5.129535118405983, 5.18167218604349, 5.233175835152692, 5.284067285451824, 5.334366611847643, 5.384092828642099, 5.433263965961206, 5.481897139264998, 5.530008612687712, 5.577613856863462, 5.624727601812021, 5.671363885390016, 5.7175360977529195, 5.763257022221352, 5.8085388729002405, 5.853393329360114, 5.8978315686557305, 5.941864294927222, 5.985501766802792, 6.028753822798928, 6.071629904893809, 6.114139080431693, 6.156290062500174, 6.198091228908294, 6.2395506398808855, 6.280676054573552, 6.321474946502793, 6.361954517976949, 6.4021217136057835, 6.441983232959484, 6.481545542441486, 6.520814886433908, 6.559797297769201, 6.598498607577076, 6.636924454551565, 6.675080293679343, 6.712971404467031, 6.750602898702124, 6.787979727779401, 6.825106689622114, 6.861988435224991, 6.898629474843939, 6.935034183855459, 6.971206808307013, 7.007151470177999, 7.042872172369546, 7.078372803439959, 7.113657142101483, 7.148728861492883, 7.183591533241324, 7.218248631326112, 7.252703535755925, 7.286959536070429, 7.321019834676394, 7.354887550027752, 7.38856571965841, 7.422057303076051, 7.455365184524633], [0.0, 0.939255320141198, 1.283060578683614, 1.5398847863995628, 1.7527124023364073, 1.937850037212503, 2.1035446089854464, 2.254642980179809, 2.3942757001042394, 2.524601250092849, 2.6471811623852823, 2.7631876044477552, 2.873526617752804, 2.9789154179368302, 3.0799330755343215, 3.177054978170117, 3.270676992111205, 3.361132848779602, 3.4487069398793033, 3.5336439194744065, 3.61615603474019, 3.6964288085368855, 3.7746255046403743, 3.850890679499515, 3.92535303870563, 3.998127757381211, 4.069318382368055, 4.139018404664321, 4.20731256928926, 4.274277974171969, 4.339984998102337, 4.404498089110398, 4.467876438064285, 4.5301745572410494, 4.591442779732521, 4.651727692514466, 4.71107251362339, 4.769517421997971, 4.827099847037427, 4.883854723721375, 4.939814718160446, 4.9950104276545195, 5.049470558688071, 5.103222085760527, 5.156290393510626, 5.208699404229834, 5.260471692556626, 5.3116285888897155, 5.362190272845086, 5.412175857901876, 5.461603468229905, 5.510490308562174, 5.55885272786544, 5.6067062774675, 5.654065764218816, 5.700945299196439, 5.747358342397897, 5.793317743820665, 5.838835781277535, 5.883924195258811, 5.928594221117941, 5.97285661882706, 6.016721700522614, 6.060199356038064, 6.1032990766002495, 6.14602997684802, 6.188400815315793, 6.23042001351064, 6.272095673698929, 6.3134355955074435, 6.354447291433994, 6.395138001353625, 6.43551470609867, 6.47558414018378, 6.5153528037406705, 6.554826973721695, 6.59401271442611, 6.632915887398369, 6.671542160743513, 6.709897017901024, 6.747985765915039, 6.785813543235756, 6.823385327084064, 6.860705940408825, 6.897780058464014, 6.934612215030696, 6.971206808307013, 7.007568106487494, 7.04370025305148, 7.079607271778932, 7.115293071510588, 7.150761450668178, 7.186016101549283, 7.221060614410415, 7.255898481350895, 7.290533100009277, 7.3249677770832236, 7.359205731683018, 7.39325009852822, 7.427103930996288, 7.460770204031476, 7.494251816921746], [0.0, 0.9440982714151108, 1.2896762450852788, 1.5478246796618673, 1.761749668966339, 1.9478419032207352, 2.1143908228160875, 2.266268281478543, 2.4066209701317494, 2.5376184995862254, 2.6608304535926237, 2.7774350435008643, 2.8883429824788256, 2.9942751842419146, 3.0958137051052916, 3.193436383868737, 3.2875411279492868, 3.3784633895417673, 3.4664890267194717, 3.5518639550221427, 3.634801516005582, 3.7154881891156832, 3.7940880799425765, 3.8707464902913853, 3.9455927893801315, 4.018742746192736, 4.09030044147514, 4.160359848280104, 4.2290061485858095, 4.296316837850656, 4.362362657748878, 4.4272083886149005, 4.490913526514479, 4.553532864798721, 4.615116996084962, 4.675712747558895, 4.735363560096162, 4.794109819804504, 4.851989149075131, 4.909036663018025, 4.9652851961755315, 5.020765503612121, 5.075506439827512, 5.129535118405983, 5.182877054873549, 5.235556294868847, 5.2875955294288195, 5.339016198935138, 5.389838587053127, 5.440081905814095, 5.489764372838988, 5.538903281571177, 5.587515065275317, 5.635615355464348, 5.68321903533523, 5.730340288723994, 5.776992645030076, 5.823189020507605, 5.868941756275744, 5.914262653360652, 5.959163005047064, 6.0036536267872584, 6.047744883888713, 6.09144671717846, 6.134768666821627, 6.177719894453606, 6.220309203769224, 6.262545059698196, 6.304435606283476, 6.345988683367977, 6.3872118421851525, 6.428112359940008, 6.468697253459168, 6.5089732919815235, 6.548947009154513, 6.588624714295462, 6.628012502972132, 6.667116266952038, 6.705941703565884, 6.744494324526642, 6.782779464242423, 6.820802287658101, 6.858567797657914, 6.896080842058623, 6.933346120220563, 6.970368189301702, 7.007151470177999, 7.04370025305148, 7.080018702765928, 7.116110863848562, 7.151980665294731, 7.187631925111436, 7.223068354634338, 7.258293562631888, 7.293311059209232, 7.328124259523695, 7.362736487322802, 7.3971509783150875, 7.431370883383227, 7.465399271648384, 7.499239133394105, 7.5328933828575435], [0.0, 0.9489110478102408, 1.2962506913877838, 1.5557151019914313, 1.770730627281431, 1.9577715131110431, 2.1251694573610656, 2.277821149247047, 2.4188893207343978, 2.550554642765842, 2.674394700436651, 2.791593711322946, 2.9030670311801092, 3.009539248761006, 3.1115953875580282, 3.2097157222734096, 3.304300188756482, 3.395685949253296, 3.484160319069966, 3.56997046736203, 3.653330823247077, 3.7344288167964836, 3.8134293901695533, 3.8904785858835993, 3.9657064326484974, 4.039229289609435, 4.111151768089916, 4.1815683201937714, 4.250564562135562, 4.318218384426115, 4.384600889362988, 4.449777187514522, 4.513807078242502, 4.576745634220811, 4.638643705975266, 4.699548359404821, 4.759503256835813, 4.818548990254241, 4.876723373840837, 4.934061701713613, 4.990596975797184, 5.046360107937631, 5.101380099727682, 5.155684202969873, 5.209298063261974, 5.262245848821267, 5.31455036635791, 5.366233165551268, 5.417314633467711, 5.467814080076666, 5.517749815867947, 5.567139222442563, 5.615998816837836, 5.66434431025224, 5.712190661753545, 5.759552127483423, 5.806442305810799, 5.852874178833625, 5.898860150583001, 5.944412082243758, 5.989541324670968, 6.034258748451372, 6.078574771732191, 6.122499386016298, 6.166042180102196, 6.209212362328996, 6.252018781270555, 6.2944699450086805, 6.336574039102613, 6.3783389433608235, 6.41977224751106, 6.460881265855694, 6.501673050991375, 6.542154406664878, 6.582331899830537, 6.622211871968998, 6.6618004497216985, 6.701103554890908, 6.740126913850894, 6.778876066411962, 6.817356374175696, 6.855573028416567, 6.893531057522261, 6.931235334022496, 6.9686905812337665, 7.005901379545292, 7.042872172369546, 7.079607271778932, 7.116110863848562, 7.152387013723644, 7.188439670428554, 7.224272671433542, 7.259889746993727, 7.295294524274153, 7.330490531273608, 7.36548120055903, 7.4002698728215766, 7.434859800264615, 7.469254149833229, 7.503456006294192, 7.537468375174768, 7.571294185568163], [0.0, 0.9536941732457854, 1.3027846332858437, 1.5635569123402175, 1.7796562549494748, 1.9676399478214994, 2.1358816859833407, 2.2893028411313674, 2.4310820874457466, 2.563411087861209, 2.6878753795222865, 2.805665149227635, 2.917700366717694, 3.0247092731413074, 3.1272798408876605, 3.2258947655541275, 3.3209559989253994, 3.412802402763323, 3.50172274062899, 3.587965427570352, 3.671745973566442, 3.7532527534574274, 3.832651540817778, 3.9100891143135548, 3.985696158083433, 4.059589617797953, 4.131874632089353, 4.202646129161157, 4.271990156789025, 4.339984998102337, 4.406702113800221, 4.472206942650393, 4.536559585442102, 4.599815392451128, 4.662025470522828, 4.723237122798727, 4.783494231691531, 4.8428375937971015, 4.901305213904098, 4.9589325640357185, 5.015752812467621, 5.071797026861586, 5.127094354997126, 5.18167218604349, 5.2355562948688465, 5.288770971513926, 5.341339137649455, 5.393282451579124, 5.444621403133301, 5.495375399616149, 5.545562843814195, 5.595201204942959, 5.6443070832963125, 5.692896269267336, 5.740983797327173, 5.788583995477672, 5.835710530632331, 5.882376450327274, 5.928594221117941, 5.974375763977206, 6.0197324869757916, 6.0646753154952275, 6.109214720196934, 6.153360742947424, 6.197123020878944, 6.240510808746592, 6.28353299972676, 6.326198144787488, 6.3685144707485355, 6.410489897137699, 6.452132051939866, 6.493448286326223, 6.534445688443069, 6.57513109633246, 6.615511110050431, 6.655592103042791, 6.6953802328332115, 6.734881451073678, 6.774101513003085, 6.813045986355968, 6.851720259759851, 6.890129550656584, 6.92827891278018, 6.96617324322106, 7.003817289104286, 7.041215653907203, 7.078372803439959, 7.115293071510588, 7.151980665294731, 7.188439670428554, 7.224674055842076, 7.260687678348872, 7.2964842870069635, 7.332067527264654, 7.367440944904123, 7.402607989794668, 7.437572019466692, 7.4723363025167675, 7.506904021853433, 7.541278277792682, 7.575462091011578, 7.6094584053678505], [0.0, 0.9584481568409944, 1.309278766256849, 1.571350945396059, 1.7885275020205844, 1.9774482577552652, 2.1465286489000945, 2.300714579250899, 2.4432005680724966, 2.576189203321424, 2.7012739257425347, 2.819650854988721, 2.932244546674151, 3.0397868720909282, 3.142868734558479, 3.2419752358196856, 3.3375103313122385, 3.429814571959249, 3.5191781607530994, 3.6058507510433837, 3.690048927085286, 3.7719620027316294, 3.851756577906543, 3.929580162939749, 4.005564093405433, 4.079825897926005, 4.152471239229733, 4.2235955187191365, 4.293285213101627, 4.361618995733058, 4.428668683530515, 4.494500041461494, 4.559173469906217, 4.622744595051034, 4.68526477849918, 4.746781559189323, 4.8073390382796255, 4.8669782157292, 4.925737285773334, 4.983651897256492, 5.040755383791866, 5.097078967907602, 5.152651942679339, 5.207501833806109, 5.261654544638886, 5.315134486299619, 5.367964694719194, 5.420166936163814, 5.471761802601746, 5.522768798078863, 5.573206417116071, 5.623092216009603, 5.672442877802627, 5.72127427160032, 5.769601506817803, 5.817438982879275, 5.864800434825196, 5.91169897523117, 5.958147132796035, 6.004156887916444, 6.049739705530176, 6.094906565479705, 6.139667990620702, 6.184034072876468, 6.228014497418518, 6.271618565135138, 6.314855213533509, 6.357733036206617, 6.400260300983347, 6.442444966868833, 6.484294699872013, 6.525816887808259, 6.567018654156928, 6.607906871046412, 6.648488171432767, 6.6887689605322125, 6.728755426562504, 6.768453550843474, 6.807869117302789, 6.847007721429077, 6.885874778711142, 6.924475532598789, 6.96281506201793, 7.000898288470048, 7.038729982743719, 7.076314771263744, 7.113657142101483, 7.150761450668178, 7.187631925111436, 7.224272671433542, 7.260687678348872, 7.296880821896485, 7.332855869822739, 7.368616485747801, 7.404166233128903, 7.43950857903228, 7.474646897724983, 7.509584474096918, 7.544324506922814, 7.578870111973148, 7.613224324982483, 7.647390104483119], [0.0, 0.9631734934908293, 1.3157337663472404, 1.5790980125264353, 1.7973452920014121, 1.9871974639682761, 2.1571114544719676, 2.3120575515802275, 2.455246024161913, 2.588890319362469, 2.7145917339009076, 2.8335522845336754, 2.946701085114734, 3.054773615204631, 3.1583636913915933, 3.2579588070648615, 3.3539649092413484, 3.4467242278267447, 3.5365283965708767, 3.6236282996631224, 3.7082415891613554, 3.790558512272676, 3.8707464902913857, 3.948953760801948, 4.025312306888587, 4.09994023661278, 4.172943733640688, 4.244418669722381, 4.314451947912333, 4.383122629441409, 4.450502885298127, 4.516658804684121, 4.581651085765285, 4.645535628975933, 4.708364049142043, 4.7701841195785315, 4.831040158870891, 4.89097336911604, 4.950022132854305, 5.008222274685923, 5.065607292565305, 5.122208562953766, 5.178055523347526, 5.233175835152693, 5.2875955294288195, 5.341339137649456, 5.394429809317129, 5.446889418009984, 5.498738657218714, 5.549997127147949, 5.600683413500199, 5.650815159127662, 5.7004091293241705, 5.749481271432692, 5.7980467693607105, 5.846120093524405, 5.893715046680665, 5.940844806052653, 5.9875219621081435, 6.033758554309483, 6.0795661041188325, 6.124955645511436, 6.169937753222698, 6.2145225689310735, 6.258719825557864, 6.302538869846553, 6.345988683367977, 6.389077902083215, 6.431814834583162, 6.474207479112404, 6.5162635394747985, 6.5579904399090925, 6.599395339014787, 6.64048514280121, 6.681266516926185, 6.721745898184902, 6.761929505304235, 6.8018233490930955, 6.84143324199504, 6.8807648070855505, 6.919823486552849, 6.9586145496979706, 6.997143100486926, 7.03541408468516, 7.073432296602171, 7.111202385471935, 7.148728861492883, 7.186016101549283, 7.223068354634338, 7.259889746993727, 7.2964842870069635, 7.332855869822739, 7.3690082817631355, 7.404945204510686, 7.440670219091159, 7.476186809664106, 7.511498367132372, 7.546608192581014, 7.581519500555343, 7.616235422187194, 7.650759008177896, 7.685093231645888], [0.0, 0.9678706644132354, 1.3221502909201035, 1.5867989026757126, 1.8061105228763967, 1.9968885592983616, 2.1676311804287236, 2.323332913262838, 2.467219682396889, 2.6015157294382125, 2.727830160253849, 2.8473708535536666, 2.961071454261687, 3.069671028699544, 3.1737662893595044, 3.2738471070215795, 3.370321408410944, 3.463533092408165, 3.553775214992375, 3.641299883856223, 3.7263258124955514, 3.80904417590841, 3.889623211863433, 3.9682118808649687, 4.044942809647746, 4.1199346822585206, 4.193294200196255, 4.265117702755029, 4.335492516795103, 4.404498089110398, 4.472206942650393, 4.538685488918236, 4.603994722090522, 4.668190815214856, 4.731325634830595, 4.7934471872319, 4.854600007135591, 4.914825497571539, 4.974162228262705, 5.0326461985174875, 5.090311069651955, 5.147188371143053, 5.20330768404676, 5.258696804667363, 5.3133818910117805, 5.367387594187796, 5.420737176592624, 5.473452618476714, 5.525554714248054, 5.577063159696867, 5.627996631163769, 5.678372857541005, 5.72820868588281, 5.777520141303595, 5.826322481759197, 5.874630248234616, 5.922457310799544, 5.969816910939367, 6.016721700522613, 6.06318377772526, 6.109214720196934, 6.154825615722984, 6.200027090609317, 6.2448293359929705, 6.289242132260418, 6.333274871737015, 6.376936579794612, 6.420235934509839, 6.463181284992641, 6.50578066849316, 6.5480418263849005, 6.589972219112874, 6.631579040187392, 6.672869229296769, 6.713849484605674, 6.754526274300036, 6.794905847434001, 6.834994244129782, 6.874797305176861, 6.914320681073133, 6.9535698405470985, 6.992550078596934, 7.031266524079495, 7.069724146879563, 7.107927764687355, 7.145882049410073, 7.183591533241324, 7.221060614410415, 7.258293562631888, 7.295294524274153, 7.332067527264654, 7.368616485747801, 7.404945204510686, 7.441057383190539, 7.47695662027695, 7.512646416920901, 7.548130180561872, 7.583411228383536, 7.618492790607789, 7.653378013636258, 7.688069963047827, 7.722571626460136], [0.0, 0.9725401376697171, 1.3285289793662953, 1.594454383218612, 1.8148240680791892, 2.0065225094392836, 2.178088875035124, 2.334541787860728, 2.479122735922952, 2.6140666916396476, 2.7409905239779127, 2.861107939035036, 2.975357086086874, 3.084480597066201, 3.189078063293134, 3.2896417189197664, 3.3865814587058494, 3.4802428406654324, 3.5709203346205376, 3.65886726455249, 3.7443033991361525, 3.8274208356896473, 3.9083886236414593, 3.987356442153005, 4.064457557814123, 4.13981122726045, 4.213524666770264, 4.285694680424701, 4.356409016390764, 4.425747504751892, 4.493783018343128, 4.56058228906863, 4.626206605370213, 4.690712411301265, 4.754151823630254, 4.816573080256776, 4.8780209307545315, 4.938536977901504, 4.998159977499537, 5.056926102534992, 5.114869176722306, 5.172020881651775, 5.2284109410926085, 5.284067285451824, 5.339016198935138, 5.393282451579125, 5.446889418009984, 5.499859184521457, 5.552212645843748, 5.603969592789042, 5.6551487918015955, 5.705768057306352, 5.75584431763583, 5.8053936752172985, 5.854431461618304, 5.902972287976548, 5.951030091277603, 5.9986181768901465, 6.0457492577214005, 6.092435490314757, 6.13868850817599, 6.184519452583253, 6.2299390011088605, 6.274957394056792, 6.319584458998807, 6.363829633573353, 6.407701986695009, 6.451210238307621, 6.494362777801251, 6.5371676812016, 6.579632727230277, 6.621765412325068, 6.663572964701235, 6.705062357527481, 6.746240321283646, 6.787113355361294, 6.82768773896301, 6.867969541351461, 6.907964631494904, 6.947678687151955, 6.987117203434884, 7.026285500887486, 7.065188733110687, 7.10383189396638, 7.142219824387638, 7.180357218821186, 7.218248631326112, 7.255898481350895, 7.293311059209232, 7.330490531273608, 7.367440944904123, 7.404166233128903, 7.440670219091159, 7.47695662027695, 7.513029052536712, 7.548891033912658, 7.584545988283396, 7.619997248836287, 7.655248061377368, 7.690301587488023, 7.72516090753696, 7.759829023555523], [0.0, 0.9771823686607838, 1.3348704537812455, 1.6020652007724818, 1.823486777417189, 2.016100253962929, 2.1884855582005236, 2.34568526854371, 2.490956345611222, 2.626544430026591, 2.754074108566122, 2.8747648807168464, 2.9895593738275297, 3.0992037646398845, 3.204300506506453, 3.305344183163213, 3.4027466459227447, 3.496855102252997, 3.587965427570352, 3.6763321550488386, 3.762176102386298, 3.845690283839999, 3.92704455576296, 4.00638931178093, 4.083858454605869, 4.159571810121743, 4.233637106382858, 4.3061516095457835, 4.377203486626315, 4.446872948761251, 4.515233216629923, 4.58235134066824, 4.648288901866464, 4.713102613702678, 4.776844841714602, 4.83956405405605, 4.901305213904099, 4.962110122619495, 5.022017720997355, 5.08106435468875, 5.13928400885903, 5.196708516324394, 5.253367742734676, 5.309289751817255, 5.364500953240385, 5.419026235275587, 5.472889084123288, 5.5261116915018516, 5.57871505187841, 5.6307190505327345, 5.682142543487051, 5.73300343019999, 5.783318719808174, 5.8331045916006685, 5.882376450327275, 5.931148976869113, 5.979436174737247, 6.027251412810938, 6.074607464679995, 6.121516544914705, 6.167990342551115, 6.2140400520481025, 6.259676401945292, 6.3049096814267624, 6.3497497649742725, 6.394206135274998, 6.43828790453222, 6.482003834312734, 6.525362354051725, 6.56837157832423, 6.611039322982069, 6.653373120245817, 6.6953802328332115, 6.737067667198022, 6.778442185946719, 6.819510319494451, 6.860278377016352, 6.900752456745532, 6.940938455664626, 6.980842078633925, 7.0204688469955485, 7.059824106689872, 7.098913035917529, 7.137740652377643, 7.176311820110537, 7.214631255970963, 7.252703535755925, 7.290533100009277, 7.328124259523695, 7.36548120055903, 7.402607989794668, 7.43950857903228, 7.476186809664106, 7.512646416920901, 7.548891033912658, 7.584924195474279, 7.620749341827595, 7.656369822070282, 7.691788897501603, 7.727009744794135, 7.762035459020124, 7.796869056540529], [0.0, 0.9817978005977357, 1.3411753196094316, 1.6096320819707768, 1.8320994779519266, 2.02562270729269, 2.198822222535472, 2.356764419221911, 2.5027216412610436, 2.638950135895785, 2.76708216315764, 2.888342982478826, 3.003679673429627, 3.1138419370969297, 3.2194350723435234, 3.3209559989254, 3.4188185134130182, 3.513371463206122, 3.6049121212011253, 3.6936962227842294, 3.7799456286203705, 3.863854264612581, 3.945592789380132, 4.025312306888587, 4.103147352299767, 4.179218317459766, 4.253633439244495, 4.32649044321845, 4.397877912828253, 4.467876438064285, 4.536559585442103, 4.603994722090523, 4.670243719859401, 4.735363560096162, 4.799406855671657, 4.862422303664694, 4.924455079622618, 4.985547182342541, 5.045737736544909, 5.105063259548728, 5.163557897038227, 5.2212536321824965, 5.278180471692937, 5.334366611847643, 5.389838587053127, 5.444621403133302, 5.498738657218714, 5.552212645843748, 5.605064462636692, 5.657314086799556, 5.70898046341541, 5.760081576485687, 5.810634515484632, 5.860655536119398, 5.91016011589957, 5.959163005047065, 6.007678273214392, 6.0557193524247594, 6.1032990766002495, 6.150429718003061, 6.197123020878945, 6.243390232560495, 6.289242132260419, 6.334689057760716, 6.379740930182338, 6.424407277001131, 6.46869725345917, 6.512619662505923, 6.556182973390518, 6.599395339014788, 6.642264612146419, 6.684798360582199, 6.727003881343168, 6.768888213976006, 6.810458153028358, 6.851720259759852, 6.89268087314515, 6.933346120220563, 6.973721925821375, 7.013814021753101, 7.053627955436286, 7.093169098061273, 7.1324426522863975, 7.171453659510399, 7.2102070067474555, 7.24870743313099, 7.286959536070429, 7.3249677770832236, 7.362736487322802, 7.4002698728215766, 7.437572019466692, 7.474646897724983, 7.511498367132372, 7.548130180561872, 7.584545988283396, 7.620749341827595, 7.656743697665164, 7.6925324207122605, 7.728118787671924, 7.763505990220807, 7.798697138049815, 7.833695261766794], [0.0, 0.9863868649521498, 1.3474441662583978, 1.6171557341999794, 1.8406629748378343, 2.0350907596308287, 2.209099834358383, 2.367780275624745, 2.5144197227457847, 2.651284968989058, 2.780015903804595, 2.9018435136637053, 3.017719304923018, 3.1283964828802993, 3.2344831756524197, 3.3364786256698964, 3.4347985636479677, 3.5297934675493776, 3.6217619997668824, 3.7109610910307187, 3.7976136390145316, 3.8819144760589595, 3.964035058466245, 4.044127196483655, 4.1223260541097355, 4.198752585919414, 4.273515534703352, 4.346713082809412, 4.418434227736005, 4.488759936162737, 4.557764118465657, 4.625514456657245, 4.692073111785299, 4.757497331536268, 4.82183997470114, 4.885149965975885, 4.947472692064865, 5.0088503480736195, 5.069322241597175, 5.128925060641744, 5.187693110493405, 5.245658523815189, 5.302851447574186, 5.359300209841958, 5.415031469050654, 5.470070347905012, 5.524440553831965, 5.578164487583113, 5.6312633413813975, 5.683757187814501, 5.7356650605175385, 5.787005027551756, 5.837794258270065, 5.8880490843611355, 5.937785055678659, 5.9870169913892175, 6.035759026908901, 6.0840246570441305, 6.13182677570459, 6.179177712514796, 6.226089266614799, 6.272572737908844, 6.318638955993233, 6.364298306970246, 6.409560758333585, 6.454435882091889, 6.498932876280154, 6.543060584994104, 6.586827517069354, 6.630241863515577, 6.673311513805426, 6.71604407110866, 6.758446866553649, 6.800526972590926, 6.8422912155268305, 6.883746187289265, 6.924898256482172, 6.965753578780511, 7.006318106713102, 7.046597598876741, 7.08659762862142, 7.126323592243199, 7.165780716718384, 7.204974067009942, 7.243908552974659, 7.28258893589735, 7.321019834676394, 7.359205731683018, 7.3971509783150875, 7.434859800264615, 7.4723363025167675, 7.509584474096918, 7.546608192581014, 7.583411228383536, 7.619997248836287, 7.656369822070282, 7.6925324207122605, 7.7284884254064785, 7.764241128171762, 7.799793735603117, 7.835149371926594, 7.870311081915535], [0.0, 0.9909499818843408, 1.3536775676840485, 1.6246368463020506, 1.849178052121783, 2.044505277842471, 2.219319334655105, 2.378733846329415, 2.5260516611050337, 2.6635500586449754, 2.7928765146796457, 2.9152677103377047, 3.031679553732254, 3.1428687345584785, 3.2494461941902046, 3.3519134845996392, 3.4506882597107875, 3.5461226188298878, 3.6385166059895675, 3.728128340505402, 3.815181751196304, 3.8998725717153544, 3.982373051537517, 4.0628357031983136, 4.141396315977459, 4.218176403996938, 4.293285213101627, 4.366821379840015, 4.438874313421181, 4.509525355084083, 4.578848757121011, 4.646912514647698, 4.713779076274702, 4.779505954521571, 4.84414625270895, 4.90774912186298, 4.970360158651121, 5.032021753377373, 5.092773395477337, 5.15265194267934, 5.2116918589688845, 5.269925425657677, 5.327382929175467, 5.384092828642099, 5.440081905814095, 5.49537539961615, 5.549997127147949, 5.603969592789041, 5.657314086799556, 5.710050774624821, 5.762198777951309, 5.813776248424793, 5.864800434825195, 5.915287744393092, 5.965253798917238, 6.01471348611905, 6.063681006806362, 6.112169918213816, 6.1601931738995175, 6.207763160525968, 6.254891731817131, 6.301590239951655, 6.347869564624556, 6.393740139985185, 6.439211979637792, 6.484294699872013, 6.528997541273808, 6.573329388852503, 6.617298790806377, 6.66091397603747, 6.704182870515866, 6.747113112584292, 6.789712067285595, 6.83198683978812, 6.873944287977331, 6.915591034275999, 6.956933476749817, 6.997977799550467, 7.038729982743719, 7.079195811566172, 7.1193808851506475, 7.159290624756972, 7.19893028154193, 7.238304943899472, 7.277419544399839, 7.316278866353989, 7.354887550027752, 7.39325009852822, 7.431370883383227, 7.469254149833229, 7.506904021853433, 7.544324506922814, 7.581519500555343, 7.618492790607789, 7.655248061377368, 7.691788897501603, 7.728118787671924, 7.764241128171762, 7.800159226249125, 7.835876303333025, 7.871395498102471, 7.906719869416209], [0.0, 0.9954875606519825, 1.359876082948841, 1.6320760892443538, 1.8576454735055963, 2.0538671062986644, 2.229481639994067, 2.3896261137417927, 2.5376184995862254, 2.6757465048971625, 2.805665149227635, 2.928616776492654, 3.045561671926706, 3.157259990121448, 3.2643254699628463, 3.367261960039105, 3.4664890267194712, 3.5623603815795866, 3.6551774425593964, 3.7451995109077187, 3.832651540817778, 3.917730162210763, 4.000608413295255, 4.0814395049645675, 4.160359848280104, 4.237491513779318, 4.312944247545883, 4.386817137786918, 4.45920000311796, 4.530174557241049, 4.599815392451128, 4.668190815214855, 4.735363560096161, 4.801391402965511, 4.866327690304665, 4.930221798203244, 4.9931195321167126, 5.0550634764550795, 5.116093301476817, 5.17624603368249, 5.2355562948688465, 5.294056514164332, 5.351777116680831, 5.408746691853037, 5.464992144071645, 5.520538827830864, 5.57541066928933, 5.629630275874575, 5.683219035335231, 5.736197205454583, 5.788583995477672, 5.840397640166995, 5.891655467284972, 5.94237395920124, 5.992568809237023, 6.042254973284895, 6.09144671717846, 6.1401576602311945, 6.188400815315792, 6.236188625813518, 6.28353299972676, 6.330445341216009, 6.376936579794613, 6.423017197390088, 6.468697253459169, 6.513986408324666, 6.558893944885354, 6.603428788835189, 6.64759952751481, 6.691414427506556, 6.7348814510736785, 6.778008271535022, 6.820802287658101, 6.863270637145964, 6.905420209286463, 6.947257656826567, 6.9887894071288335, 7.030021672662293, 7.07096046087555, 7.11161158349591, 7.151980665294732, 7.192073152355893, 7.231894319881324, 7.271449279564829, 7.310742986562981, 7.349780246089609, 7.38856571965841, 7.427103930996288, 7.465399271648384, 7.503456006294192, 7.541278277792682, 7.578870111973148, 7.616235422187194, 7.653378013636258, 7.690301587488023, 7.727009744794135, 7.763505990220807, 7.799793735603117, 7.835876303333025, 7.871756929590528, 7.907438767426703, 7.9429248897068705], [0.0, 1.0, 1.3660402567543954, 1.639474116758873, 1.8660659830736148, 2.063177067680795, 2.2395876433994766, 2.4004580350323375, 2.549121254638524, 2.6878753795222865, 2.8183829312644537, 2.9418918851930123, 3.0593668794133926, 3.1715715142172534, 3.2791223105037255, 3.3825254007531322, 3.4822022531844965, 3.578508182710452, 3.6717459735664426, 3.7621761023862983, 3.8500245430567, 3.935488816801381, 4.018742746192735, 4.099940236612779, 4.179218317459765, 4.256699612603923, 4.332494365596264, 4.406702113800222, 4.479413082969576, 4.550709357205896, 4.620665866923074, 4.689351228213721, 4.756828460010884, 4.82315560007691, 4.8883862367074915, 4.9525699698088195, 5.015752812467621, 5.077977542124511, 5.13928400885903, 5.199709407008934, 5.259288515307899, 5.318053909882162, 5.37603615375741, 5.433263965961206, 5.489764372838988, 5.545562843814195, 5.600683413500198, 5.655148791801595, 5.70898046341541, 5.762198777951309, 5.814823031727799, 5.866871542163619, 5.918361715566093, 5.96931010901769, 6.0197324869757916, 6.069643873126444, 6.119058597968759, 6.167990342551114, 6.216452178732173, 6.264456606297724, 6.312015587227867, 6.35914057737694, 6.4058425558006125, 6.452132051939866, 6.498019170849884, 6.543513616642692, 6.588624714295462, 6.633361429961369, 6.677732389906556, 6.721745898184902, 6.7654099531517495, 6.808732262908285, 6.85172025975985, 6.8943811137639415, 6.936721745436821, 6.978748837681653, 7.020468846995548, 7.061888014007996, 7.103012373398729, 7.1438477632389965, 7.184399833796647, 7.224674055842076, 7.264675728489146, 7.304409986602426, 7.343881807799686, 7.38309601907628, 7.422057303076051, 7.460770204031476, 7.499239133394105, 7.537468375174768, 7.575462091011578, 7.613224324982483, 7.650759008177896, 7.688069963047827, 7.72516090753696, 7.762035459020124, 7.798697138049815, 7.835149371926594, 7.871395498102471, 7.907438767426703, 7.943282347242814, 7.9789293243450965], [0.0, 1.0044876885327707, 1.3721706199499353, 1.6468315659524262, 1.8744403059872479, 2.0724359637485015, 2.2496382151848957, 2.4112305430295495, 2.5605609168616077, 2.6999377270404854, 2.831030956026046, 2.9550941796708443, 3.0730963650756746, 3.1858045393324685, 3.293837990094126, 3.397705121205898, 3.497829292304901, 3.5945674128464282, 3.688223625867264, 3.7790595769392414, 3.8673022540494615, 3.953150064835388, 4.0367776119309795, 4.1183394913976725, 4.197973347578975, 4.275802354642855, 4.351937250879045, 4.42647802034366, 4.499515293695563, 4.571131523404202, 4.641401976147829, 4.71039557594671, 4.778175624543232, 4.844800420155144, 4.910323791565718, 4.974795561270076, 5.038261948847345, 5.100765923709971, 5.162347514772239, 5.223044083288508, 5.2828905640685795, 5.341919679430197, 5.400162129556389, 5.457646762356767, 5.5144007254625915, 5.570449602596139, 5.625817536230643, 5.680527338185675, 5.7346005895748915, 5.788057731330667, 5.8409181463673745, 5.893200234306626, 5.944921479569828, 5.996098513542481, 6.04674717142794, 6.0968825443338766, 6.146519027070216, 6.195670362081622, 6.244349679889187, 6.292569536373846, 6.34034194719734, 6.3876784196243115, 6.434589981981014, 6.48108721096128, 6.527180256968632, 6.572878867664129, 6.6181924098725355, 6.66312988998433, 6.707699972977651, 6.7519110001723845, 6.795771005818002, 6.839287732607246, 6.882468646199328, 6.925320948828731, 6.96785159206884, 7.010067288813604, 7.0519745245348835, 7.093579567868171, 7.1348884805749595, 7.175907126925944, 7.216641182545616, 7.2570961427554845, 7.297277330450185, 7.337189903537958, 7.376838861974573, 7.4162290544174345, 7.455365184524633, 7.494251816921746, 7.5328933828575435, 7.571294185568163, 7.6094584053678505, 7.647390104483119, 7.685093231645888, 7.722571626460136, 7.759829023555523, 7.796869056540529, 7.833695261766794, 7.870311081915535, 7.906719869416209, 7.9429248897068705, 7.9789293243450965, 8.014736273977748]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 1.0\", \"showscale\": false, \"type\": \"surface\", \"visible\": true, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.1, 0.1414213562373095, 0.17320508075688776, 0.2, 0.223606797749979, 0.24494897427831783, 0.2645751311064591, 0.282842712474619, 0.3, 0.31622776601683794, 0.33166247903554, 0.3464101615137755, 0.36055512754639896, 0.37416573867739417, 0.38729833462074165, 0.4, 0.41231056256176607, 0.4242640687119285, 0.43588989435406744, 0.447213595499958, 0.45825756949558405, 0.469041575982343, 0.479583152331272, 0.48989794855663565, 0.5, 0.5099019513592785, 0.5196152422706632, 0.5291502622129182, 0.5385164807134505, 0.5477225575051661, 0.5567764362830022, 0.565685424949238, 0.574456264653803, 0.5830951894845301, 0.5916079783099616, 0.6, 0.608276253029822, 0.6164414002968976, 0.6244997998398399, 0.6324555320336759, 0.6403124237432849, 0.6480740698407861, 0.6557438524302001, 0.66332495807108, 0.6708203932499369, 0.6782329983125268, 0.6855654600401044, 0.692820323027551, 0.7000000000000001, 0.7071067811865476, 0.7141428428542851, 0.7211102550927979, 0.7280109889280519, 0.7348469228349535, 0.7416198487095663, 0.7483314773547883, 0.754983443527075, 0.7615773105863909, 0.7681145747868608, 0.7745966692414833, 0.7810249675906654, 0.787400787401181, 0.7937253933193772, 0.8, 0.8062257748298549, 0.812403840463596, 0.8185352771872451, 0.8246211251235321, 0.8306623862918076, 0.8366600265340756, 0.8426149773176359, 0.848528137423857, 0.8544003745317531, 0.8602325267042626, 0.8660254037844387, 0.8717797887081349, 0.8774964387392122, 0.8831760866327848, 0.8888194417315589, 0.894427190999916, 0.9, 0.9055385138137417, 0.9110433579144299, 0.9165151389911681, 0.9219544457292888, 0.9273618495495705, 0.9327379053088816, 0.938083151964686, 0.9433981132056604, 0.9486832980505138, 0.9539392014169457, 0.959166304662544, 0.9643650760992956, 0.9695359714832659, 0.9746794344808963, 0.9797958971132713, 0.9848857801796106, 0.9899494936611666, 0.9949874371066201, 1.0, 1.0049875621120892], [0.0, 0.1414213562373095, 0.19999999999999998, 0.24494897427831783, 0.282842712474619, 0.31622776601683794, 0.34641016151377546, 0.3741657386773941, 0.39999999999999997, 0.4242640687119285, 0.4472135954999579, 0.469041575982343, 0.48989794855663565, 0.5099019513592785, 0.529150262212918, 0.5477225575051661, 0.565685424949238, 0.58309518948453, 0.6, 0.6164414002968976, 0.6324555320336759, 0.6480740698407861, 0.6633249580710799, 0.6782329983125268, 0.6928203230275509, 0.7071067811865476, 0.7211102550927979, 0.7348469228349535, 0.7483314773547882, 0.7615773105863909, 0.7745966692414833, 0.7874007874011811, 0.7999999999999999, 0.812403840463596, 0.8246211251235321, 0.8366600265340756, 0.848528137423857, 0.8602325267042626, 0.8717797887081348, 0.8831760866327847, 0.8944271909999159, 0.9055385138137417, 0.9165151389911681, 0.9273618495495702, 0.938083151964686, 0.9486832980505137, 0.9591663046625439, 0.9695359714832658, 0.9797958971132713, 0.9899494936611665, 1.0, 1.0099504938362078, 1.019803902718557, 1.0295630140987002, 1.0392304845413265, 1.0488088481701516, 1.058300524425836, 1.0677078252031311, 1.0770329614269007, 1.0862780491200215, 1.0954451150103321, 1.104536101718726, 1.1135528725660042, 1.1224972160321824, 1.131370849898476, 1.1401754250991378, 1.1489125293076057, 1.1575836902790224, 1.16619037896906, 1.174734012447073, 1.1832159566199232, 1.1916375287812984, 1.2, 1.2083045973594573, 1.2165525060596438, 1.224744871391589, 1.2328828005937953, 1.2409673645990857, 1.2489995996796797, 1.2569805089976536, 1.2649110640673518, 1.2727922061357855, 1.2806248474865698, 1.2884098726725124, 1.2961481396815722, 1.3038404810405297, 1.3114877048604001, 1.3190905958272918, 1.3266499161421599, 1.3341664064126333, 1.3416407864998738, 1.349073756323204, 1.3564659966250536, 1.3638181696985856, 1.3711309200802089, 1.378404875209022, 1.3856406460551018, 1.392838827718412, 1.4, 1.407124727947029, 1.4142135623730951, 1.4212670403551897], [0.0, 0.17320508075688776, 0.24494897427831783, 0.3000000000000001, 0.3464101615137755, 0.38729833462074176, 0.42426406871192857, 0.45825756949558405, 0.48989794855663565, 0.5196152422706632, 0.5477225575051662, 0.574456264653803, 0.6000000000000002, 0.6244997998398399, 0.6480740698407861, 0.6708203932499369, 0.692820323027551, 0.7141428428542851, 0.7348469228349536, 0.7549834435270751, 0.7745966692414835, 0.7937253933193773, 0.8124038404635961, 0.8306623862918077, 0.8485281374238571, 0.8660254037844388, 0.8831760866327849, 0.9000000000000001, 0.9165151389911681, 0.9327379053088817, 0.9486832980505139, 0.9643650760992957, 0.9797958971132713, 0.9949874371066202, 1.009950493836208, 1.02469507659596, 1.0392304845413265, 1.053565375285274, 1.0677078252031313, 1.081665382639197, 1.0954451150103324, 1.1090536506409419, 1.1224972160321827, 1.1357816691600549, 1.148912529307606, 1.161895003862225, 1.1747340124470733, 1.187434208703792, 1.2000000000000004, 1.2124355652982142, 1.2247448713915892, 1.2369316876852985, 1.2489995996796799, 1.2609520212918495, 1.2727922061357857, 1.2845232578665131, 1.2961481396815722, 1.3076696830622023, 1.3190905958272923, 1.3304134695650072, 1.3416407864998738, 1.3527749258468684, 1.3638181696985856, 1.3747727084867523, 1.385640646055102, 1.3964240043768943, 1.4071247279470291, 1.4177446878757827, 1.4282856857085702, 1.4387494569938162, 1.4491376746189442, 1.4594519519326425, 1.4696938456699071, 1.4798648586948744, 1.489966442575134, 1.5000000000000002, 1.5099668870541503, 1.5198684153570665, 1.5297058540778359, 1.5394804318340656, 1.549193338482967, 1.5588457268119897, 1.5684387141358125, 1.5779733838059502, 1.5874507866387546, 1.5968719422671316, 1.6062378404209012, 1.6155494421403516, 1.6248076809271923, 1.6340134638368193, 1.6431676725154984, 1.6522711641858308, 1.6613247725836153, 1.670329308849007, 1.6792855623746668, 1.6881943016134133, 1.6970562748477143, 1.7058722109231985, 1.7146428199482249, 1.7233687939614089, 1.7320508075688776, 1.7406895185529214], [0.0, 0.2, 0.282842712474619, 0.3464101615137755, 0.4, 0.447213595499958, 0.48989794855663565, 0.5291502622129182, 0.565685424949238, 0.6, 0.6324555320336759, 0.66332495807108, 0.692820323027551, 0.7211102550927979, 0.7483314773547883, 0.7745966692414833, 0.8, 0.8246211251235321, 0.848528137423857, 0.8717797887081349, 0.894427190999916, 0.9165151389911681, 0.938083151964686, 0.959166304662544, 0.9797958971132713, 1.0, 1.019803902718557, 1.0392304845413265, 1.0583005244258363, 1.077032961426901, 1.0954451150103321, 1.1135528725660044, 1.131370849898476, 1.148912529307606, 1.1661903789690602, 1.1832159566199232, 1.2, 1.216552506059644, 1.2328828005937953, 1.2489995996796799, 1.2649110640673518, 1.2806248474865698, 1.2961481396815722, 1.3114877048604001, 1.32664991614216, 1.3416407864998738, 1.3564659966250536, 1.3711309200802089, 1.385640646055102, 1.4000000000000001, 1.4142135623730951, 1.4282856857085702, 1.4422205101855958, 1.4560219778561039, 1.469693845669907, 1.4832396974191326, 1.4966629547095767, 1.50996688705415, 1.5231546211727818, 1.5362291495737217, 1.5491933384829666, 1.5620499351813308, 1.574801574802362, 1.5874507866387544, 1.6, 1.6124515496597098, 1.624807680927192, 1.6370705543744901, 1.6492422502470643, 1.661324772583615, 1.6733200530681511, 1.6852299546352718, 1.697056274847714, 1.7088007490635062, 1.7204650534085253, 1.7320508075688774, 1.7435595774162698, 1.7549928774784245, 1.7663521732655696, 1.7776388834631178, 1.788854381999832, 1.8, 1.8110770276274835, 1.8220867158288598, 1.8330302779823362, 1.8439088914585775, 1.854723699099141, 1.8654758106177631, 1.876166303929372, 1.8867962264113207, 1.8973665961010275, 1.9078784028338913, 1.918332609325088, 1.9287301521985911, 1.9390719429665317, 1.9493588689617927, 1.9595917942265426, 1.9697715603592212, 1.9798989873223332, 1.9899748742132402, 2.0, 2.0099751242241783], [0.0, 0.223606797749979, 0.31622776601683794, 0.38729833462074176, 0.447213595499958, 0.5000000000000001, 0.5477225575051662, 0.5916079783099617, 0.6324555320336759, 0.6708203932499369, 0.7071067811865476, 0.7416198487095664, 0.7745966692414835, 0.806225774829855, 0.8366600265340756, 0.8660254037844386, 0.894427190999916, 0.9219544457292888, 0.9486832980505139, 0.9746794344808966, 1.0000000000000002, 1.02469507659596, 1.0488088481701516, 1.072380529476361, 1.0954451150103324, 1.118033988749895, 1.140175425099138, 1.1618950038622253, 1.1832159566199234, 1.2041594578792296, 1.2247448713915892, 1.2449899597988734, 1.2649110640673518, 1.2845232578665131, 1.30384048104053, 1.3228756555322954, 1.3416407864998738, 1.3601470508735445, 1.3784048752090223, 1.3964240043768943, 1.4142135623730951, 1.4317821063276355, 1.4491376746189442, 1.466287829861518, 1.4832396974191329, 1.5, 1.5165750888103102, 1.5329709716755893, 1.549193338482967, 1.565247584249853, 1.5811388300841898, 1.5968719422671316, 1.61245154965971, 1.627882059609971, 1.6431676725154984, 1.6583123951777001, 1.6733200530681511, 1.6881943016134133, 1.7029386365926404, 1.7175564037317668, 1.7320508075688772, 1.746424919657298, 1.760681686165901, 1.7748239349298849, 1.788854381999832, 1.8027756377319946, 1.8165902124584952, 1.8303005217723127, 1.8439088914585775, 1.8574175621006712, 1.8708286933869709, 1.8841443681416774, 1.8973665961010278, 1.91049731745428, 1.9235384061671346, 1.9364916731037085, 1.9493588689617931, 1.9621416870348585, 1.9748417658131503, 1.9874606914351793, 2.0000000000000004, 2.012461179749811, 2.024845673131659, 2.0371548787463363, 2.04939015319192, 2.0615528128088303, 2.0736441353327724, 2.0856653614614213, 2.0976176963403033, 2.1095023109728985, 2.121320343559643, 2.1330729007701543, 2.144761058952722, 2.1563858652847827, 2.1679483388678804, 2.179449471770337, 2.1908902300206647, 2.2022715545545246, 2.2135943621178655, 2.224859546128699, 2.23606797749979, 2.2472205054244236], [0.0, 0.24494897427831783, 0.34641016151377546, 0.42426406871192857, 0.48989794855663565, 0.5477225575051662, 0.6000000000000001, 0.6480740698407861, 0.6928203230275509, 0.7348469228349535, 0.7745966692414834, 0.8124038404635961, 0.8485281374238571, 0.8831760866327848, 0.916515138991168, 0.9486832980505138, 0.9797958971132713, 1.0099504938362078, 1.0392304845413265, 1.0677078252031313, 1.0954451150103324, 1.1224972160321824, 1.148912529307606, 1.174734012447073, 1.2000000000000002, 1.2247448713915892, 1.2489995996796799, 1.2727922061357857, 1.2961481396815722, 1.319090595827292, 1.3416407864998738, 1.3638181696985856, 1.3856406460551018, 1.4071247279470291, 1.4282856857085702, 1.449137674618944, 1.469693845669907, 1.489966442575134, 1.50996688705415, 1.5297058540778357, 1.5491933384829668, 1.5684387141358125, 1.5874507866387546, 1.606237840420901, 1.6248076809271923, 1.6431676725154982, 1.661324772583615, 1.6792855623746665, 1.6970562748477143, 1.7146428199482247, 1.7320508075688774, 1.7492855684535904, 1.7663521732655696, 1.7832554500127011, 1.8, 1.8165902124584952, 1.833030277982336, 1.849324200890693, 1.8654758106177631, 1.8814887722226779, 1.8973665961010275, 1.9131126469708992, 1.928730152198591, 1.9442222095223582, 1.9595917942265426, 1.9748417658131499, 1.98997487421324, 2.004993765576342, 2.0199009876724157, 2.0346989949375804, 2.04939015319192, 2.0639767440550294, 2.078460969082653, 2.092844953645635, 2.1071307505705477, 2.121320343559643, 2.1354156504062627, 2.149418526020468, 2.1633307652783937, 2.177154105707724, 2.1908902300206647, 2.2045407685048604, 2.2181073012818837, 2.2315913604421396, 2.244994432064365, 2.2583179581272432, 2.2715633383201097, 2.2847319317591728, 2.297825058615212, 2.3108440016582685, 2.32379000772445, 2.3366642891095846, 2.349468024894146, 2.3622023622035435, 2.374868417407584, 2.3874672772626644, 2.4000000000000004, 2.412467616362964, 2.4248711305964283, 2.4372115213907883, 2.4494897427831783, 2.4617067250182347], [0.0, 0.2645751311064591, 0.3741657386773941, 0.45825756949558405, 0.5291502622129182, 0.5916079783099617, 0.6480740698407861, 0.7000000000000001, 0.7483314773547882, 0.7937253933193772, 0.8366600265340756, 0.8774964387392122, 0.9165151389911681, 0.9539392014169458, 0.9899494936611666, 1.0246950765959597, 1.0583005244258363, 1.0908712114635715, 1.1224972160321824, 1.1532562594670797, 1.1832159566199234, 1.2124355652982142, 1.2409673645990857, 1.2688577540449522, 1.2961481396815722, 1.3228756555322954, 1.3490737563232043, 1.374772708486752, 1.4000000000000001, 1.4247806848775009, 1.4491376746189437, 1.4730919862656235, 1.4966629547095764, 1.5198684153570665, 1.5427248620541514, 1.5652475842498528, 1.5874507866387544, 1.6093476939431082, 1.6309506430300091, 1.6522711641858308, 1.6733200530681511, 1.6941074346097418, 1.7146428199482249, 1.7349351572897471, 1.7549928774784245, 1.7748239349298847, 1.7944358444926363, 1.8138357147217055, 1.8330302779823362, 1.8520259177452134, 1.8708286933869709, 1.8894443627691186, 1.9078784028338915, 1.9261360284258224, 1.9442222095223582, 1.9621416870348585, 1.9798989873223332, 1.997498435543818, 2.0149441679609885, 2.0322401432901573, 2.0493901531919194, 2.0663978319771825, 2.083266665599966, 2.1, 2.1166010488516727, 2.133072900770154, 2.149418526020468, 2.1656407827707715, 2.181742422927143, 2.1977260975835913, 2.2135943621178655, 2.2293496809607953, 2.244994432064365, 2.260530911091463, 2.2759613353482084, 2.29128784747792, 2.3065125189341593, 2.32163735324878, 2.336664289109585, 2.3515952032609695, 2.366431913239847, 2.3811761799581315, 2.395829710142188, 2.41039415863879, 2.4248711305964283, 2.4392621835300936, 2.4535688292770597, 2.4677925358506134, 2.4819347291981715, 2.495996794869737, 2.5099800796022267, 2.5238858928247927, 2.5377155080899043, 2.551470164434615, 2.5651510676761324, 2.578759391645525, 2.5922962793631443, 2.6057628441590768, 2.619160170741759, 2.632489316217637, 2.6457513110645907, 2.6589471600616665], [0.0, 0.282842712474619, 0.39999999999999997, 0.48989794855663565, 0.565685424949238, 0.6324555320336759, 0.6928203230275509, 0.7483314773547882, 0.7999999999999999, 0.848528137423857, 0.8944271909999159, 0.938083151964686, 0.9797958971132713, 1.019803902718557, 1.058300524425836, 1.0954451150103321, 1.131370849898476, 1.16619037896906, 1.2, 1.2328828005937953, 1.2649110640673518, 1.2961481396815722, 1.3266499161421599, 1.3564659966250536, 1.3856406460551018, 1.4142135623730951, 1.4422205101855958, 1.469693845669907, 1.4966629547095764, 1.5231546211727818, 1.5491933384829666, 1.5748015748023623, 1.5999999999999999, 1.624807680927192, 1.6492422502470643, 1.6733200530681511, 1.697056274847714, 1.7204650534085253, 1.7435595774162695, 1.7663521732655694, 1.7888543819998317, 1.8110770276274835, 1.8330302779823362, 1.8547236990991405, 1.876166303929372, 1.8973665961010273, 1.9183326093250879, 1.9390719429665315, 1.9595917942265426, 1.979898987322333, 2.0, 2.0199009876724157, 2.039607805437114, 2.0591260281974004, 2.078460969082653, 2.0976176963403033, 2.116601048851672, 2.1354156504062622, 2.1540659228538015, 2.172556098240043, 2.1908902300206643, 2.209072203437452, 2.2271057451320084, 2.244994432064365, 2.262741699796952, 2.2803508501982757, 2.2978250586152114, 2.315167380558045, 2.33238075793812, 2.349468024894146, 2.3664319132398464, 2.3832750575625967, 2.4, 2.4166091947189146, 2.4331050121192876, 2.449489742783178, 2.4657656011875906, 2.4819347291981715, 2.4979991993593593, 2.513961017995307, 2.5298221281347035, 2.545584412271571, 2.5612496949731396, 2.576819745345025, 2.5922962793631443, 2.6076809620810595, 2.6229754097208002, 2.6381811916545836, 2.6532998322843198, 2.6683328128252666, 2.6832815729997477, 2.698147512646408, 2.7129319932501073, 2.727636339397171, 2.7422618401604177, 2.756809750418044, 2.7712812921102037, 2.785677655436824, 2.8, 2.814249455894058, 2.8284271247461903, 2.8425340807103794], [0.0, 0.3, 0.4242640687119285, 0.5196152422706632, 0.6, 0.6708203932499369, 0.7348469228349535, 0.7937253933193772, 0.848528137423857, 0.8999999999999999, 0.9486832980505138, 0.99498743710662, 1.0392304845413265, 1.0816653826391969, 1.1224972160321824, 1.1618950038622249, 1.2, 1.236931687685298, 1.2727922061357855, 1.307669683062202, 1.3416407864998738, 1.374772708486752, 1.407124727947029, 1.438749456993816, 1.469693845669907, 1.5, 1.5297058540778354, 1.5588457268119895, 1.5874507866387544, 1.6155494421403513, 1.6431676725154982, 1.6703293088490065, 1.697056274847714, 1.7233687939614086, 1.7492855684535902, 1.7748239349298847, 1.7999999999999998, 1.8248287590894658, 1.849324200890693, 1.8734993995195195, 1.8973665961010275, 1.9209372712298547, 1.9442222095223582, 1.9672315572906, 1.98997487421324, 2.0124611797498106, 2.0346989949375804, 2.056696380120313, 2.078460969082653, 2.1, 2.1213203435596424, 2.142428528562855, 2.1633307652783937, 2.1840329667841556, 2.2045407685048604, 2.224859546128699, 2.244994432064365, 2.264950330581225, 2.2847319317591723, 2.3043437243605824, 2.3237900077244498, 2.3430749027719964, 2.362202362203543, 2.3811761799581315, 2.4, 2.4186773244895647, 2.437211521390788, 2.455605831561735, 2.473863375370596, 2.4919871588754225, 2.5099800796022267, 2.5278449319529073, 2.545584412271571, 2.563201123595259, 2.580697580112788, 2.598076211353316, 2.615339366124404, 2.6324893162176366, 2.6495282598983545, 2.6664583251946765, 2.6832815729997477, 2.7, 2.716615541441225, 2.7331300737432893, 2.749545416973504, 2.765863337187866, 2.7820855486487113, 2.7982137159266447, 2.814249455894058, 2.830194339616981, 2.846049894151541, 2.8618176042508368, 2.877498913987632, 2.8930952282978866, 2.9086079144497976, 2.9240383034426887, 2.939387691339814, 2.9546573405388314, 2.9698484809834995, 2.98496231131986, 3.0, 3.0149626863362675], [0.0, 0.31622776601683794, 0.4472135954999579, 0.5477225575051662, 0.6324555320336759, 0.7071067811865476, 0.7745966692414834, 0.8366600265340756, 0.8944271909999159, 0.9486832980505138, 1.0, 1.0488088481701516, 1.0954451150103324, 1.140175425099138, 1.1832159566199232, 1.224744871391589, 1.2649110640673518, 1.3038404810405297, 1.3416407864998738, 1.3784048752090223, 1.4142135623730951, 1.449137674618944, 1.4832396974191326, 1.5165750888103102, 1.5491933384829668, 1.5811388300841898, 1.61245154965971, 1.6431676725154984, 1.6733200530681511, 1.7029386365926402, 1.7320508075688772, 1.760681686165901, 1.7888543819998317, 1.8165902124584952, 1.8439088914585775, 1.8708286933869707, 1.8973665961010275, 1.9235384061671346, 1.949358868961793, 1.97484176581315, 2.0, 2.024845673131659, 2.04939015319192, 2.073644135332772, 2.0976176963403033, 2.1213203435596424, 2.1447610589527217, 2.16794833886788, 2.1908902300206647, 2.2135943621178655, 2.23606797749979, 2.2583179581272432, 2.280350850198276, 2.302172886644268, 2.32379000772445, 2.345207879911715, 2.3664319132398464, 2.3874672772626644, 2.4083189157584592, 2.4289915602982237, 2.449489742783178, 2.4698178070456938, 2.4899799195977463, 2.5099800796022267, 2.5298221281347035, 2.5495097567963922, 2.569046515733026, 2.588435821108957, 2.6076809620810595, 2.6267851073127395, 2.6457513110645907, 2.6645825188948455, 2.6832815729997477, 2.701851217221259, 2.7202941017470885, 2.7386127875258306, 2.7568097504180447, 2.7748873851023217, 2.7928480087537886, 2.8106938645110393, 2.8284271247461903, 2.8460498941515415, 2.863564212655271, 2.8809720581775866, 2.898275349237888, 2.9154759474226504, 2.932575659723036, 2.9495762407505253, 2.9664793948382653, 2.9832867780352594, 3.0, 3.0166206257996713, 3.0331501776206204, 3.0495901363953815, 3.0659419433511785, 3.082207001484488, 3.0983866769659336, 3.1144823004794877, 3.1304951684997055, 3.146426544510455, 3.1622776601683795, 3.178049716414141], [0.0, 0.33166247903554, 0.469041575982343, 0.574456264653803, 0.66332495807108, 0.7416198487095664, 0.8124038404635961, 0.8774964387392122, 0.938083151964686, 0.99498743710662, 1.0488088481701516, 1.1, 1.148912529307606, 1.1958260743101399, 1.2409673645990857, 1.284523257866513, 1.32664991614216, 1.3674794331177345, 1.407124727947029, 1.4456832294800963, 1.4832396974191329, 1.5198684153570665, 1.5556349186104048, 1.5905973720586868, 1.6248076809271923, 1.6583123951777001, 1.6911534525287766, 1.7233687939614089, 1.7549928774784245, 1.7860571099491753, 1.816590212458495, 1.846618531261939, 1.876166303929372, 1.9052558883257653, 1.9339079605813718, 1.9621416870348585, 1.98997487421324, 2.017424100183202, 2.0445048300260877, 2.0712315177207983, 2.0976176963403033, 2.1236760581595306, 2.149418526020468, 2.1748563170931545, 2.2, 2.224859546128699, 2.249444375840399, 2.273763400180415, 2.297825058615212, 2.32163735324878, 2.345207879911715, 2.368543856465403, 2.3916521486202797, 2.4145392935299275, 2.4372115213907883, 2.459674775249769, 2.4819347291981715, 2.503996805109783, 2.525866188063018, 2.5475478405713994, 2.569046515733026, 2.5903667693977237, 2.6115129714401193, 2.632489316217637, 2.65329983228432, 2.6739483914241875, 2.6944387170614963, 2.714774392099646, 2.734958866235469, 2.7549954627911823, 2.774887385102322, 2.7946377224964243, 2.814249455894058, 2.833725463060951, 2.8530685235374214, 2.8722813232690148, 2.8913664589601926, 2.91032644217105, 2.9291637031753623, 2.9478805945967355, 2.9664793948382657, 2.9849623113198605, 3.003331483536242, 3.0215889859476257, 3.039736830714133, 3.0577769702841313, 3.07571129984594, 3.093541659651604, 3.1112698372208096, 3.1288975694324033, 3.146426544510455, 3.1638584039112754, 3.1811947441173736, 3.1984371183438958, 3.2155870381627056, 3.2326459750489227, 3.2496153618543846, 3.2664965942122155, 3.283291031876401, 3.3000000000000007, 3.3166247903554003, 3.333166662499792], [0.0, 0.3464101615137755, 0.48989794855663565, 0.6000000000000002, 0.692820323027551, 0.7745966692414835, 0.8485281374238571, 0.9165151389911681, 0.9797958971132713, 1.0392304845413265, 1.0954451150103324, 1.148912529307606, 1.2000000000000004, 1.2489995996796799, 1.2961481396815722, 1.3416407864998738, 1.385640646055102, 1.4282856857085702, 1.4696938456699071, 1.5099668870541503, 1.549193338482967, 1.5874507866387546, 1.6248076809271923, 1.6613247725836153, 1.6970562748477143, 1.7320508075688776, 1.7663521732655698, 1.8000000000000003, 1.8330302779823362, 1.8654758106177634, 1.8973665961010278, 1.9287301521985913, 1.9595917942265426, 1.9899748742132404, 2.019900987672416, 2.04939015319192, 2.078460969082653, 2.107130750570548, 2.1354156504062627, 2.163330765278394, 2.1908902300206647, 2.2181073012818837, 2.2449944320643653, 2.2715633383201097, 2.297825058615212, 2.32379000772445, 2.3494680248941466, 2.374868417407584, 2.400000000000001, 2.4248711305964283, 2.4494897427831783, 2.473863375370597, 2.4979991993593598, 2.521904042583699, 2.5455844122715714, 2.5690465157330262, 2.5922962793631443, 2.6153393661244047, 2.6381811916545845, 2.6608269391300143, 2.6832815729997477, 2.705549851693737, 2.727636339397171, 2.7495454169735045, 2.771281292110204, 2.7928480087537886, 2.8142494558940583, 2.8354893757515653, 2.8565713714171403, 2.8774989139876324, 2.8982753492378883, 2.918903903865285, 2.9393876913398143, 2.9597297173897488, 2.979932885150268, 3.0000000000000004, 3.0199337741083006, 3.039736830714133, 3.0594117081556718, 3.078960863668131, 3.098386676965934, 3.1176914536239795, 3.136877428271625, 3.1559467676119004, 3.174901573277509, 3.193743884534263, 3.2124756808418025, 3.231098884280703, 3.2496153618543846, 3.2680269276736387, 3.286335345030997, 3.3045423283716615, 3.3226495451672307, 3.340658617698014, 3.3585711247493335, 3.3763886032268267, 3.3941125496954285, 3.411744421846397, 3.4292856398964497, 3.4467375879228177, 3.4641016151377553, 3.481379037105843], [0.0, 0.36055512754639896, 0.5099019513592785, 0.6244997998398399, 0.7211102550927979, 0.806225774829855, 0.8831760866327848, 0.9539392014169458, 1.019803902718557, 1.0816653826391969, 1.140175425099138, 1.1958260743101399, 1.2489995996796799, 1.3000000000000003, 1.3490737563232043, 1.396424004376894, 1.4422205101855958, 1.4866068747318506, 1.5297058540778357, 1.5716233645501714, 1.61245154965971, 1.6522711641858308, 1.6911534525287764, 1.7291616465790585, 1.7663521732655696, 1.8027756377319948, 1.8384776310850237, 1.8734993995195197, 1.9078784028338915, 1.94164878389476, 1.9748417658131499, 2.0074859899884734, 2.039607805437114, 2.0712315177207983, 2.102379604162864, 2.1330729007701543, 2.1633307652783937, 2.193171219946131, 2.222611077089287, 2.2516660498395407, 2.280350850198276, 2.3086792761230397, 2.336664289109585, 2.364318083507378, 2.3916521486202797, 2.4186773244895647, 2.445403852127497, 2.471841418861655, 2.4979991993593598, 2.5238858928247927, 2.5495097567963927, 2.574878637916747, 2.6000000000000005, 2.624880949681338, 2.6495282598983545, 2.673948391424188, 2.6981475126464085, 2.72213151776324, 2.7459060435491964, 2.7694764848252458, 2.792848008753788, 2.816025568065745, 2.839013913315678, 2.861817604250837, 2.8844410203711917, 2.9068883707497264, 2.9291637031753623, 2.951270912674741, 2.973213749463701, 2.994995826374388, 3.0166206257996717, 3.0380915061926625, 3.0594117081556713, 3.0805843601498726, 3.1016124838541645, 3.122498999199199, 3.1432467291003428, 3.1638584039112754, 3.1843366656181322, 3.204684071792413, 3.22490309931942, 3.2449961479175906, 3.264965543462902, 3.2848135411313684, 3.3045423283716615, 3.3241540277189325, 3.343650699460098, 3.363034344160048, 3.3823069050575527, 3.4014702703389896, 3.420526275297414, 3.439476704383968, 3.458323293158117, 3.4770677301427426, 3.4957116585897072, 3.5142566781611158, 3.532704346531139, 3.5510561809129415, 3.5693136595149495, 3.58747822293042, 3.6055512754639896, 3.6235341863986883], [0.0, 0.37416573867739417, 0.529150262212918, 0.6480740698407861, 0.7483314773547883, 0.8366600265340756, 0.916515138991168, 0.9899494936611666, 1.058300524425836, 1.1224972160321824, 1.1832159566199232, 1.2409673645990857, 1.2961481396815722, 1.3490737563232043, 1.4, 1.4491376746189437, 1.4966629547095767, 1.5427248620541512, 1.5874507866387544, 1.6309506430300091, 1.6733200530681511, 1.7146428199482247, 1.7549928774784245, 1.7944358444926363, 1.833030277982336, 1.8708286933869707, 1.9078784028338913, 1.9442222095223582, 1.9798989873223332, 2.0149441679609885, 2.0493901531919194, 2.083266665599966, 2.116601048851672, 2.149418526020468, 2.181742422927143, 2.2135943621178655, 2.244994432064365, 2.2759613353482084, 2.3065125189341593, 2.3366642891095846, 2.3664319132398464, 2.395829710142188, 2.4248711305964283, 2.453568829277059, 2.4819347291981715, 2.5099800796022262, 2.5377155080899043, 2.565151067676132, 2.5922962793631443, 2.619160170741759, 2.6457513110645907, 2.672077843177478, 2.6981475126464085, 2.7239676943752476, 2.749545416973504, 2.7748873851023217, 2.8, 2.824889378365107, 2.8495613697550017, 2.8740215726399825, 2.8982753492378874, 2.9223278392404914, 2.9461839725312466, 2.9698484809834995, 2.9933259094191533, 3.016620625799671, 3.0397368307141326, 3.062678566222711, 3.0854497241083023, 3.1080540535840107, 3.1304951684997055, 3.152776554086889, 3.1749015732775088, 3.196873472629156, 3.218695387886216, 3.24037034920393, 3.2619012860600183, 3.283291031876401, 3.3045423283716615, 3.3256578296631782, 3.3466401061363023, 3.3674916480965473, 3.3882148692194836, 3.408812109811862, 3.4292856398964493, 3.449637662132068, 3.4698703145794947, 3.4899856733230297, 3.509985754956849, 3.529872518944558, 3.5496478698597693, 3.5693136595149495, 3.5888716889852725, 3.6083237105337433, 3.627671429443411, 3.6469165057620936, 3.666060555964672, 3.685105154537656, 3.704051835490427, 3.722902093797257, 3.7416573867739413, 3.7603191353926335], [0.0, 0.38729833462074165, 0.5477225575051661, 0.6708203932499369, 0.7745966692414833, 0.8660254037844386, 0.9486832980505138, 1.0246950765959597, 1.0954451150103321, 1.1618950038622249, 1.224744871391589, 1.284523257866513, 1.3416407864998738, 1.396424004376894, 1.4491376746189437, 1.4999999999999998, 1.5491933384829666, 1.5968719422671311, 1.6431676725154982, 1.6881943016134133, 1.7320508075688772, 1.7748239349298847, 1.816590212458495, 1.857417562100671, 1.8973665961010275, 1.9364916731037083, 1.9748417658131499, 2.0124611797498106, 2.0493901531919194, 2.085665361461421, 2.1213203435596424, 2.1563858652847823, 2.1908902300206643, 2.224859546128699, 2.258317958127243, 2.29128784747792, 2.3237900077244498, 2.355843797877949, 2.3874672772626644, 2.4186773244895647, 2.449489742783178, 2.479919353527449, 2.5099800796022267, 2.5396850198400585, 2.569046515733026, 2.5980762113533156, 2.626785107312739, 2.6551836094703507, 2.6832815729997477, 2.7110883423451915, 2.7386127875258306, 2.765863337187866, 2.792848008753788, 2.819574435974337, 2.846049894151541, 2.8722813232690143, 2.8982753492378874, 2.924038303442689, 2.9495762407505253, 2.974894956128703, 2.9999999999999996, 3.0248966924508345, 3.049590136395381, 3.074085229787879, 3.098386676965933, 3.1224989991991987, 3.1464265445104544, 3.1701734968294715, 3.1937438845342623, 3.217141588429082, 3.24037034920393, 3.2634337744161437, 3.2863353450309964, 3.309078421554859, 3.3316662497915357, 3.3541019662496843, 3.3763886032268267, 3.3985290935932855, 3.420526275297414, 3.442382895611701, 3.4641016151377544, 3.485685011586675, 3.5071355833500366, 3.5284557528754696, 3.5496478698597693, 3.5707142142714248, 3.591656999213594, 3.6124783736376886, 3.63318042491699, 3.6537651812890215, 3.674234614174767, 3.694590640382233, 3.714835124201342, 3.7349698793966195, 3.7549966711037173, 3.7749172176353745, 3.794733192202055, 3.8144462245521304, 3.8340579025361623, 3.853569773599539, 3.8729833462074166, 3.892300091205713], [0.0, 0.4, 0.565685424949238, 0.692820323027551, 0.8, 0.894427190999916, 0.9797958971132713, 1.0583005244258363, 1.131370849898476, 1.2, 1.2649110640673518, 1.32664991614216, 1.385640646055102, 1.4422205101855958, 1.4966629547095767, 1.5491933384829666, 1.6, 1.6492422502470643, 1.697056274847714, 1.7435595774162698, 1.788854381999832, 1.8330302779823362, 1.876166303929372, 1.918332609325088, 1.9595917942265426, 2.0, 2.039607805437114, 2.078460969082653, 2.1166010488516727, 2.154065922853802, 2.1908902300206643, 2.227105745132009, 2.262741699796952, 2.297825058615212, 2.3323807579381204, 2.3664319132398464, 2.4, 2.433105012119288, 2.4657656011875906, 2.4979991993593598, 2.5298221281347035, 2.5612496949731396, 2.5922962793631443, 2.6229754097208002, 2.65329983228432, 2.6832815729997477, 2.7129319932501073, 2.7422618401604177, 2.771281292110204, 2.8000000000000003, 2.8284271247461903, 2.8565713714171403, 2.8844410203711917, 2.9120439557122078, 2.939387691339814, 2.9664793948382653, 2.9933259094191533, 3.0199337741083, 3.0463092423455636, 3.0724582991474434, 3.098386676965933, 3.1240998703626617, 3.149603149604724, 3.1749015732775088, 3.2, 3.2249030993194197, 3.249615361854384, 3.2741411087489802, 3.2984845004941286, 3.32264954516723, 3.3466401061363023, 3.3704599092705436, 3.394112549695428, 3.4176014981270124, 3.4409301068170506, 3.464101615137755, 3.4871191548325395, 3.509985754956849, 3.532704346531139, 3.5552777669262356, 3.577708763999664, 3.6, 3.622154055254967, 3.6441734316577197, 3.6660605559646724, 3.687817782917155, 3.709447398198282, 3.7309516212355263, 3.752332607858744, 3.7735924528226414, 3.794733192202055, 3.8157568056677826, 3.836665218650176, 3.8574603043971822, 3.8781438859330635, 3.8987177379235853, 3.9191835884530852, 3.9395431207184424, 3.9597979746446663, 3.9799497484264803, 4.0, 4.019950248448357], [0.0, 0.41231056256176607, 0.58309518948453, 0.7141428428542851, 0.8246211251235321, 0.9219544457292888, 1.0099504938362078, 1.0908712114635715, 1.16619037896906, 1.236931687685298, 1.3038404810405297, 1.3674794331177345, 1.4282856857085702, 1.4866068747318506, 1.5427248620541512, 1.5968719422671311, 1.6492422502470643, 1.7, 1.7492855684535902, 1.797220075561143, 1.8439088914585775, 1.8894443627691184, 1.9339079605813716, 1.977371993328519, 2.0199009876724157, 2.0615528128088303, 2.102379604162864, 2.142428528562855, 2.181742422927143, 2.220360331117452, 2.258317958127243, 2.2956480566497994, 2.33238075793812, 2.3685438564654024, 2.4041630560342617, 2.4392621835300936, 2.473863375370596, 2.5079872407968904, 2.541653005427767, 2.574878637916747, 2.6076809620810595, 2.6400757564888173, 2.672077843177478, 2.7037011669191546, 2.734958866235469, 2.765863337187866, 2.7964262908219126, 2.826658805020514, 2.8565713714171403, 2.8861739379323623, 2.9154759474226504, 2.944486372867092, 2.973213749463701, 3.001666203960727, 3.0298514815086235, 3.0577769702841313, 3.0854497241083023, 3.1128764832546763, 3.1400636936215167, 3.167017524422623, 3.1937438845342623, 3.2202484376209237, 3.246536616149585, 3.2726136343907144, 3.2984845004941286, 3.324154027718932, 3.3496268448888453, 3.374907406137241, 3.4, 3.424908757908742, 3.4496376621320683, 3.4741905532080417, 3.4985711369071804, 3.522782990761707, 3.5468295701936396, 3.570714214271425, 3.594440151122286, 3.6180105030251086, 3.6414282912066254, 3.664696440361739, 3.687817782917155, 3.710795063055895, 3.733630940518894, 3.7563279941985894, 3.778888725538237, 3.8013155617496426, 3.8236108588610325, 3.845776904605882, 3.867815921162743, 3.8897300677553446, 3.9115214431215892, 3.9331920878594273, 3.954743986657038, 3.976179070414209, 3.9974992182613374, 4.018706259482023, 4.039801975344831, 4.060788100849391, 4.08166632639171, 4.102438299353203, 4.123105625617661, 4.1436698710201325], [0.0, 0.4242640687119285, 0.6, 0.7348469228349536, 0.848528137423857, 0.9486832980505139, 1.0392304845413265, 1.1224972160321824, 1.2, 1.2727922061357855, 1.3416407864998738, 1.407124727947029, 1.4696938456699071, 1.5297058540778357, 1.5874507866387544, 1.6431676725154982, 1.697056274847714, 1.7492855684535902, 1.8, 1.8493242008906932, 1.8973665961010278, 1.9442222095223582, 1.98997487421324, 2.0346989949375804, 2.078460969082653, 2.121320343559643, 2.1633307652783937, 2.2045407685048604, 2.244994432064365, 2.2847319317591728, 2.32379000772445, 2.3622023622035435, 2.4, 2.4372115213907883, 2.4738633753705965, 2.5099800796022267, 2.545584412271571, 2.5806975801127883, 2.615339366124404, 2.6495282598983545, 2.6832815729997477, 2.716615541441225, 2.749545416973504, 2.782085548648711, 2.814249455894058, 2.846049894151541, 2.877498913987632, 2.9086079144497976, 2.9393876913398143, 2.9698484809834995, 3.0, 3.029851481508624, 3.0594117081556713, 3.0886890422961004, 3.1176914536239795, 3.146426544510455, 3.1749015732775088, 3.2031234756093934, 3.2310988842807027, 3.2588341473600644, 3.2863353450309964, 3.3136083051561784, 3.340658617698013, 3.3674916480965473, 3.394112549695428, 3.420526275297414, 3.4467375879228173, 3.4727510708370675, 3.4985711369071804, 3.5242020373412193, 3.5496478698597698, 3.5749125863438955, 3.6, 3.6249137920783716, 3.6496575181789317, 3.6742346141747673, 3.6986484017813863, 3.722902093797257, 3.7469987990390394, 3.7709415269929605, 3.7947331922020555, 3.8183766184073566, 3.84187454245971, 3.8652296180175374, 3.8884444190447165, 3.9115214431215897, 3.9344631145812006, 3.957271787481876, 3.97994974842648, 4.0024992192379, 4.024922359499621, 4.047221268969612, 4.069397989875161, 4.091454509095757, 4.113392760240627, 4.135214625627066, 4.156921938165306, 4.178516483155236, 4.2, 4.221374183841087, 4.242640687119286, 4.263801121065569], [0.0, 0.43588989435406744, 0.6164414002968976, 0.7549834435270751, 0.8717797887081349, 0.9746794344808966, 1.0677078252031313, 1.1532562594670797, 1.2328828005937953, 1.307669683062202, 1.3784048752090223, 1.4456832294800963, 1.5099668870541503, 1.5716233645501714, 1.6309506430300091, 1.6881943016134133, 1.7435595774162698, 1.797220075561143, 1.8493242008906932, 1.9000000000000004, 1.9493588689617931, 1.9974984355438181, 2.0445048300260877, 2.0904544960366875, 2.1354156504062627, 2.179449471770337, 2.2226110770892875, 2.2649503305812253, 2.3065125189341593, 2.3473389188611007, 2.3874672772626644, 2.4269322199023198, 2.4657656011875906, 2.503996805109783, 2.5416530054277673, 2.5787593916455256, 2.615339366124404, 2.651414716712571, 2.687005768508881, 2.7221315177632404, 2.7568097504180447, 2.791057147390573, 2.8248893783651075, 2.8583211855912904, 2.8913664589601926, 2.924038303442689, 2.956349099818897, 2.9883105594967874, 3.0199337741083006, 3.051229260478472, 3.082207001484489, 3.1128764832546767, 3.1432467291003428, 3.1733263305244868, 3.203123475609394, 3.232645975048923, 3.2619012860600183, 3.290896534380867, 3.319638534539567, 3.3481338085566414, 3.3763886032268267, 3.4044089061098406, 3.432200460346103, 3.4597687784012394, 3.4871191548325395, 3.5142566781611158, 3.541186241925155, 3.567912554982255, 3.594440151122286, 3.6207733980463352, 3.6469165057620945, 3.672873534441392, 3.6986484017813863, 3.7242448899072147, 3.749666651850535, 3.7749172176353754, 3.8000000000000007, 3.824918299781056, 3.8496753109840323, 3.874274125562104, 3.8987177379235862, 3.9230090491866068, 3.947150871198111, 3.9711459303329564, 3.9949968710876362, 4.018706259482024, 4.042276586281548, 4.065710270051225, 4.0890096600521755, 4.112177038990418, 4.135214625627067, 4.158124577258358, 4.180908992073375, 4.203569911396741, 4.226109321823088, 4.2485291572496005, 4.270831300812525, 4.293017586733137, 4.315089802078284, 4.337049688440289, 4.358898943540674, 4.380639222761903], [0.0, 0.447213595499958, 0.6324555320336759, 0.7745966692414835, 0.894427190999916, 1.0000000000000002, 1.0954451150103324, 1.1832159566199234, 1.2649110640673518, 1.3416407864998738, 1.4142135623730951, 1.4832396974191329, 1.549193338482967, 1.61245154965971, 1.6733200530681511, 1.7320508075688772, 1.788854381999832, 1.8439088914585775, 1.8973665961010278, 1.9493588689617931, 2.0000000000000004, 2.04939015319192, 2.0976176963403033, 2.144761058952722, 2.1908902300206647, 2.23606797749979, 2.280350850198276, 2.3237900077244507, 2.366431913239847, 2.4083189157584592, 2.4494897427831783, 2.489979919597747, 2.5298221281347035, 2.5690465157330262, 2.60768096208106, 2.6457513110645907, 2.6832815729997477, 2.720294101747089, 2.7568097504180447, 2.7928480087537886, 2.8284271247461903, 2.863564212655271, 2.8982753492378883, 2.932575659723036, 2.9664793948382657, 3.0, 3.0331501776206204, 3.0659419433511785, 3.098386676965934, 3.130495168499706, 3.1622776601683795, 3.193743884534263, 3.22490309931942, 3.255764119219942, 3.286335345030997, 3.3166247903554003, 3.3466401061363023, 3.3763886032268267, 3.405877273185281, 3.4351128074635335, 3.4641016151377544, 3.492849839314596, 3.521363372331802, 3.5496478698597698, 3.577708763999664, 3.605551275463989, 3.6331804249169903, 3.6606010435446255, 3.687817782917155, 3.7148351242013424, 3.7416573867739418, 3.768288736283355, 3.7947331922020555, 3.82099463490856, 3.847076812334269, 3.872983346207417, 3.8987177379235862, 3.924283374069717, 3.9496835316263006, 3.9749213828703587, 4.000000000000001, 4.024922359499622, 4.049691346263318, 4.0743097574926725, 4.09878030638384, 4.123105625617661, 4.147288270665545, 4.171330722922843, 4.1952353926806065, 4.219004621945797, 4.242640687119286, 4.266145801540309, 4.289522117905444, 4.312771730569565, 4.335896677735761, 4.358898943540674, 4.3817804600413295, 4.404543109109049, 4.427188724235731, 4.449719092257398, 4.47213595499958, 4.494441010848847], [0.0, 0.45825756949558405, 0.6480740698407861, 0.7937253933193773, 0.9165151389911681, 1.02469507659596, 1.1224972160321824, 1.2124355652982142, 1.2961481396815722, 1.374772708486752, 1.449137674618944, 1.5198684153570665, 1.5874507866387546, 1.6522711641858308, 1.7146428199482247, 1.7748239349298847, 1.8330302779823362, 1.8894443627691184, 1.9442222095223582, 1.9974984355438181, 2.04939015319192, 2.1, 2.149418526020468, 2.1977260975835913, 2.244994432064365, 2.2912878474779204, 2.336664289109585, 2.381176179958132, 2.4248711305964283, 2.4677925358506134, 2.5099800796022267, 2.551470164434615, 2.5922962793631443, 2.632489316217637, 2.672077843177478, 2.711088342345192, 2.749545416973504, 2.787471972953271, 2.824889378365107, 2.861817604250837, 2.898275349237888, 2.934280150224242, 2.9698484809835, 3.004995840263344, 3.039736830714133, 3.0740852297878796, 3.108054053584011, 3.1416556144810017, 3.174901573277509, 3.2078029864690882, 3.2403703492039306, 3.272613634390715, 3.3045423283716615, 3.336165463522456, 3.3674916480965478, 3.398529093593286, 3.4292856398964493, 3.459768778401239, 3.48998567332303, 3.5199431813596083, 3.5496478698597693, 3.5791060336346563, 3.608323710533743, 3.6373066958946425, 3.6660605559646724, 3.6945906403822333, 3.722902093797257, 3.7509998667022106, 3.778888725538237, 3.8065732621348563, 3.834057902536163, 3.861346915261565, 3.8884444190447165, 3.915354390090379, 3.9420806688854046, 3.968626966596886, 3.9949968710876362, 4.02119385257662, 4.047221268969613, 4.07308237088326, 4.09878030638384, 4.124318125460256, 4.149698784249287, 4.174925149029621, 4.2, 4.224926034855522, 4.249705872175156, 4.274342054632503, 4.298837052040936, 4.323193264243457, 4.347413023856832, 4.371498598878879, 4.3954521951671826, 4.419275958796871, 4.442971978304612, 4.466542286825459, 4.48998886412873, 4.513313638558704, 4.536518488885503, 4.559605246071199, 4.582575694955841, 4.605431575867782], [0.0, 0.469041575982343, 0.6633249580710799, 0.8124038404635961, 0.938083151964686, 1.0488088481701516, 1.148912529307606, 1.2409673645990857, 1.3266499161421599, 1.407124727947029, 1.4832396974191326, 1.5556349186104048, 1.6248076809271923, 1.6911534525287764, 1.7549928774784245, 1.816590212458495, 1.876166303929372, 1.9339079605813716, 1.98997487421324, 2.0445048300260877, 2.0976176963403033, 2.149418526020468, 2.2, 2.249444375840399, 2.297825058615212, 2.345207879911715, 2.3916521486202797, 2.4372115213907883, 2.4819347291981715, 2.5258661880630178, 2.569046515733026, 2.6115129714401193, 2.6532998322843198, 2.6944387170614963, 2.734958866235469, 2.7748873851023217, 2.814249455894058, 2.8530685235374214, 2.891366458960192, 2.9291637031753623, 2.9664793948382653, 3.0033314835362415, 3.039736830714133, 3.0757112998459397, 3.1112698372208096, 3.1464265445104544, 3.1811947441173736, 3.2155870381627056, 3.2496153618543846, 3.283291031876401, 3.3166247903554003, 3.3496268448888458, 3.3823069050575527, 3.414674215792775, 3.4467375879228173, 3.4785054261852175, 3.509985754956849, 3.5411862419251547, 3.5721142198983507, 3.602776706930364, 3.63318042491699, 3.6633318168028404, 3.6932370625238775, 3.722902093797257, 3.752332607858744, 3.7815340802378072, 3.81051177665153, 3.8392707640904935, 3.867815921162743, 3.8961519477556315, 3.924283374069717, 3.952214569073901, 3.97994974842648, 4.007492981902776, 4.034848200366403, 4.06201920231798, 4.0890096600521755, 4.115823125451336, 4.1424630354415966, 4.168932717135166, 4.1952353926806065, 4.221374183841087, 4.247352116319061, 4.273172123844299, 4.298837052040936, 4.324349662087931, 4.349712634186309, 4.374928570845472, 4.4, 4.424929377967517, 4.449719092257398, 4.474371464239419, 4.498888751680798, 4.523273151159457, 4.54752680036083, 4.571651780264984, 4.595650117230424, 4.61952378498044, 4.64327470649756, 4.666904755831214, 4.69041575982343, 4.713809499757071], [0.0, 0.479583152331272, 0.6782329983125268, 0.8306623862918077, 0.959166304662544, 1.072380529476361, 1.174734012447073, 1.2688577540449522, 1.3564659966250536, 1.438749456993816, 1.5165750888103102, 1.5905973720586868, 1.6613247725836153, 1.7291616465790585, 1.7944358444926363, 1.857417562100671, 1.918332609325088, 1.977371993328519, 2.0346989949375804, 2.0904544960366875, 2.144761058952722, 2.1977260975835913, 2.249444375840399, 2.3000000000000003, 2.349468024894146, 2.39791576165636, 2.4454038521274972, 2.491987158875423, 2.5377155080899043, 2.582634314028992, 2.6267851073127395, 2.670205984563738, 2.7129319932501073, 2.754995462791183, 2.7964262908219126, 2.8372521918222215, 2.877498913987632, 2.917190429162965, 2.956349099818897, 2.994995826374388, 3.0331501776206204, 3.0708305065568178, 3.108054053584011, 3.1448370387032774, 3.1811947441173736, 3.2171415884290826, 3.252691193458119, 3.2878564445547194, 3.3226495451672307, 3.357082066318904, 3.3911649915626345, 3.4249087579087423, 3.458323293158117, 3.491418050019219, 3.5242020373412197, 3.5566838487557484, 3.5888716889852725, 3.620773398046335, 3.6523964735499352, 3.6837480912787726, 3.714835124201342, 3.745664160065609, 3.7762415176998414, 3.8065732621348563, 3.836665218650176, 3.866522985836241, 3.8961519477556315, 3.9255572852781047, 3.954743986657038, 3.9837168574084183, 4.012480529547776, 4.041039470235351, 4.069397989875161, 4.097560249709576, 4.125530268947254, 4.153311931459037, 4.180908992073375, 4.2083250825001635, 4.235563716909475, 4.262628297189424, 4.289522117905444, 4.316248370981448, 4.342810150121694, 4.369210454990696, 4.3954521951671826, 4.421538193886829, 4.447471191587417, 4.473253849269009, 4.498888751680798, 4.524378410345448, 4.549725266430931, 4.57493169347915, 4.6000000000000005, 4.624932431938872, 4.649731175025068, 4.674398357008098, 4.698936049788292, 4.723346271447818, 4.747630988187688, 4.77179211617606, 4.79583152331272, 4.819751030914357], [0.0, 0.48989794855663565, 0.6928203230275509, 0.8485281374238571, 0.9797958971132713, 1.0954451150103324, 1.2000000000000002, 1.2961481396815722, 1.3856406460551018, 1.469693845669907, 1.5491933384829668, 1.6248076809271923, 1.6970562748477143, 1.7663521732655696, 1.833030277982336, 1.8973665961010275, 1.9595917942265426, 2.0199009876724157, 2.078460969082653, 2.1354156504062627, 2.1908902300206647, 2.244994432064365, 2.297825058615212, 2.349468024894146, 2.4000000000000004, 2.4494897427831783, 2.4979991993593598, 2.5455844122715714, 2.5922962793631443, 2.638181191654584, 2.6832815729997477, 2.727636339397171, 2.7712812921102037, 2.8142494558940583, 2.8565713714171403, 2.898275349237888, 2.939387691339814, 2.979932885150268, 3.0199337741083, 3.0594117081556713, 3.0983866769659336, 3.136877428271625, 3.174901573277509, 3.212475680841802, 3.2496153618543846, 3.2863353450309964, 3.32264954516723, 3.358571124749333, 3.3941125496954285, 3.4292856398964493, 3.464101615137755, 3.498571136907181, 3.532704346531139, 3.5665109000254023, 3.6, 3.6331804249169903, 3.666060555964672, 3.698648401781386, 3.7309516212355263, 3.7629775444453557, 3.794733192202055, 3.8262252939417984, 3.857460304397182, 3.8884444190447165, 3.9191835884530852, 3.9496835316262997, 3.97994974842648, 4.009987531152684, 4.039801975344831, 4.069397989875161, 4.09878030638384, 4.127953488110059, 4.156921938165306, 4.18568990729127, 4.214261501141095, 4.242640687119286, 4.270831300812525, 4.298837052040936, 4.3266615305567875, 4.354308211415448, 4.3817804600413295, 4.409081537009721, 4.436214602563767, 4.463182720884279, 4.48998886412873, 4.5166359162544865, 4.543126676640219, 4.5694638635183455, 4.595650117230424, 4.621688003316537, 4.6475800154489, 4.673328578219169, 4.698936049788292, 4.724404724407087, 4.749736834815168, 4.774934554525329, 4.800000000000001, 4.824935232725928, 4.849742261192857, 4.874423042781577, 4.898979485566357, 4.9234134500364695], [0.0, 0.5, 0.7071067811865476, 0.8660254037844388, 1.0, 1.118033988749895, 1.2247448713915892, 1.3228756555322954, 1.4142135623730951, 1.5, 1.5811388300841898, 1.6583123951777001, 1.7320508075688776, 1.8027756377319948, 1.8708286933869707, 1.9364916731037083, 2.0, 2.0615528128088303, 2.121320343559643, 2.179449471770337, 2.23606797749979, 2.2912878474779204, 2.345207879911715, 2.39791576165636, 2.4494897427831783, 2.5000000000000004, 2.5495097567963927, 2.5980762113533165, 2.6457513110645907, 2.6925824035672523, 2.7386127875258306, 2.783882181415011, 2.8284271247461903, 2.8722813232690148, 2.9154759474226504, 2.958039891549808, 3.0, 3.04138126514911, 3.0822070014844885, 3.1224989991991996, 3.1622776601683795, 3.2015621187164247, 3.2403703492039306, 3.278719262151, 3.3166247903554003, 3.3541019662496843, 3.3911649915626345, 3.4278273002005224, 3.4641016151377553, 3.5, 3.535533905932738, 3.5707142142714257, 3.6055512754639896, 3.64005494464026, 3.6742346141747677, 3.708099243547832, 3.7416573867739413, 3.774917217635375, 3.8078865529319548, 3.840572873934304, 3.8729833462074166, 3.9051248379533274, 3.9370039370059056, 3.968626966596886, 4.0, 4.031128874149275, 4.06201920231798, 4.092676385936225, 4.123105625617661, 4.153311931459037, 4.183300132670378, 4.2130748865881795, 4.242640687119286, 4.272001872658766, 4.301162633521313, 4.330127018922194, 4.358898943540674, 4.387482193696061, 4.415880433163924, 4.444097208657795, 4.47213595499958, 4.500000000000001, 4.527692569068709, 4.55521678957215, 4.582575694955841, 4.609772228646444, 4.636809247747852, 4.663689526544408, 4.69041575982343, 4.716990566028302, 4.743416490252569, 4.769696007084729, 4.79583152331272, 4.821825380496478, 4.847679857416329, 4.873397172404482, 4.898979485566357, 4.924428900898053, 4.949747468305833, 4.974937185533101, 5.000000000000001, 5.024937810560446], [0.0, 0.5099019513592785, 0.7211102550927979, 0.8831760866327849, 1.019803902718557, 1.140175425099138, 1.2489995996796799, 1.3490737563232043, 1.4422205101855958, 1.5297058540778354, 1.61245154965971, 1.6911534525287766, 1.7663521732655698, 1.8384776310850237, 1.9078784028338913, 1.9748417658131499, 2.039607805437114, 2.102379604162864, 2.1633307652783937, 2.2226110770892875, 2.280350850198276, 2.336664289109585, 2.3916521486202797, 2.4454038521274972, 2.4979991993593598, 2.5495097567963927, 2.6000000000000005, 2.6495282598983545, 2.6981475126464085, 2.7459060435491964, 2.792848008753788, 2.839013913315678, 2.8844410203711917, 2.9291637031753623, 2.973213749463701, 3.0166206257996713, 3.059411708155671, 3.101612483854165, 3.1432467291003428, 3.1843366656181322, 3.22490309931942, 3.264965543462902, 3.304542328371662, 3.3436506994600976, 3.382306905057553, 3.420526275297414, 3.458323293158117, 3.4957116585897072, 3.5327043465311396, 3.5693136595149495, 3.6055512754639896, 3.6414282912066254, 3.6769552621700474, 3.712142238654118, 3.7469987990390394, 3.7815340802378077, 3.8157568056677826, 3.849675310984032, 3.8832975677895205, 3.916631205513228, 3.9496835316262997, 3.9824615503479754, 4.014971979976946, 4.047221268969613, 4.079215610874228, 4.110960958218893, 4.142463035441596, 4.173727350941841, 4.204759208325728, 4.235563716909475, 4.266145801540309, 4.296510211788167, 4.3266615305567875, 4.356604182158393, 4.386342439892262, 4.415880433163924, 4.445222154178575, 4.474371464239419, 4.503332099679082, 4.532107677449864, 4.560701700396552, 4.589117562233507, 4.617358552246079, 4.645427859734774, 4.67332857821917, 4.701063709417264, 4.7286361670147565, 4.756048780237647, 4.7833042972405595, 4.810405388322278, 4.83735464897913, 4.864154602806124, 4.8908077042549944, 4.917316341257699, 4.943682837723311, 4.969909455915671, 4.9959983987187195, 5.021951811795889, 5.047771785649585, 5.073460357586329, 5.099019513592785, 5.1244511901275835], [0.0, 0.5196152422706632, 0.7348469228349535, 0.9000000000000001, 1.0392304845413265, 1.1618950038622253, 1.2727922061357857, 1.374772708486752, 1.469693845669907, 1.5588457268119895, 1.6431676725154984, 1.7233687939614089, 1.8000000000000003, 1.8734993995195197, 1.9442222095223582, 2.0124611797498106, 2.078460969082653, 2.142428528562855, 2.2045407685048604, 2.2649503305812253, 2.3237900077244507, 2.381176179958132, 2.4372115213907883, 2.491987158875423, 2.5455844122715714, 2.5980762113533165, 2.6495282598983545, 2.7, 2.749545416973504, 2.7982137159266447, 2.8460498941515415, 2.8930952282978866, 2.939387691339814, 2.9849623113198605, 3.0298514815086235, 3.0740852297878796, 3.117691453623979, 3.160696125855822, 3.203123475609394, 3.244996147917591, 3.286335345030997, 3.3271609519228256, 3.3674916480965478, 3.407345007480164, 3.4467375879228177, 3.4856850115866753, 3.5242020373412197, 3.5623026261113755, 3.6000000000000005, 3.6373066958946425, 3.6742346141747677, 3.7107950630558952, 3.7469987990390394, 3.782856063875548, 3.818376618407357, 3.853569773599539, 3.8884444190447165, 3.9230090491866063, 3.957271787481876, 3.9912404086950213, 4.024922359499621, 4.058324777540605, 4.091454509095756, 4.124318125460256, 4.156921938165306, 4.189272013130682, 4.221374183841087, 4.253234063627348, 4.28485705712571, 4.316248370981448, 4.3474130238568325, 4.378355855797928, 4.409081537009721, 4.439594576084623, 4.469899327725402, 4.5, 4.529900661162451, 4.559605246071199, 4.589117562233508, 4.618441295502196, 4.647580015448901, 4.676537180435969, 4.705316142407438, 4.73392015141785, 4.762352359916264, 4.790615826801394, 4.818713521262704, 4.846648326421054, 4.874423042781577, 4.902040391510457, 4.929503017546495, 4.956813492557492, 4.983974317750846, 5.0109879265470205, 5.037856687124, 5.06458290484024, 5.091168824543143, 5.117616632769595, 5.143928459844674, 5.170106381884226, 5.196152422706633, 5.222068555658764], [0.0, 0.5291502622129182, 0.7483314773547882, 0.9165151389911681, 1.0583005244258363, 1.1832159566199234, 1.2961481396815722, 1.4000000000000001, 1.4966629547095764, 1.5874507866387544, 1.6733200530681511, 1.7549928774784245, 1.8330302779823362, 1.9078784028338915, 1.9798989873223332, 2.0493901531919194, 2.1166010488516727, 2.181742422927143, 2.244994432064365, 2.3065125189341593, 2.366431913239847, 2.4248711305964283, 2.4819347291981715, 2.5377155080899043, 2.5922962793631443, 2.6457513110645907, 2.6981475126464085, 2.749545416973504, 2.8000000000000003, 2.8495613697550017, 2.8982753492378874, 2.946183972531247, 2.993325909419153, 3.039736830714133, 3.0854497241083028, 3.1304951684997055, 3.1749015732775088, 3.2186953878862163, 3.2619012860600183, 3.3045423283716615, 3.3466401061363023, 3.3882148692194836, 3.4292856398964497, 3.4698703145794942, 3.509985754956849, 3.5496478698597693, 3.5888716889852725, 3.627671429443411, 3.6660605559646724, 3.704051835490427, 3.7416573867739418, 3.7788887255382373, 3.815756805667783, 3.852272056851645, 3.8884444190447165, 3.924283374069717, 3.9597979746446663, 3.994996871087636, 4.029888335921977, 4.064480286580315, 4.098780306383839, 4.132795663954365, 4.166533331199932, 4.2, 4.233202097703345, 4.266145801540308, 4.298837052040936, 4.331281565541543, 4.363484845854286, 4.3954521951671826, 4.427188724235731, 4.458699361921591, 4.48998886412873, 4.521061822182926, 4.551922670696417, 4.58257569495584, 4.613025037868319, 4.64327470649756, 4.67332857821917, 4.703190406521939, 4.732863826479694, 4.762352359916263, 4.791659420284376, 4.82078831727758, 4.849742261192857, 4.878524367060187, 4.907137658554119, 4.935585071701227, 4.963869458396343, 4.991993589739474, 5.019960159204453, 5.047771785649585, 5.075431016179809, 5.10294032886923, 5.130302135352265, 5.15751878329105, 5.184592558726289, 5.2115256883181535, 5.238320341483518, 5.264978632435274, 5.291502622129181, 5.317894320123333], [0.0, 0.5385164807134505, 0.7615773105863909, 0.9327379053088817, 1.077032961426901, 1.2041594578792296, 1.319090595827292, 1.4247806848775009, 1.5231546211727818, 1.6155494421403513, 1.7029386365926402, 1.7860571099491753, 1.8654758106177634, 1.94164878389476, 2.0149441679609885, 2.085665361461421, 2.154065922853802, 2.220360331117452, 2.2847319317591728, 2.3473389188611007, 2.4083189157584592, 2.4677925358506134, 2.5258661880630178, 2.582634314028992, 2.638181191654584, 2.6925824035672523, 2.7459060435491964, 2.7982137159266447, 2.8495613697550017, 2.9000000000000004, 2.9495762407505253, 2.99833287011299, 3.0463092423455636, 3.0935416596516045, 3.1400636936215167, 3.1859064644147983, 3.2310988842807027, 3.2756678708318403, 3.3196385345395667, 3.363034344160048, 3.4058772731852804, 3.448187929913334, 3.48998567332303, 3.531288716601915, 3.5721142198983507, 3.6124783736376886, 3.6523964735499352, 3.691882988394947, 3.7309516212355267, 3.769615364994153, 3.8078865529319548, 3.845776904605883, 3.88329756778952, 3.9204591567825324, 3.957271787481876, 3.993745109543172, 4.029888335921977, 4.065710270051224, 4.101219330881976, 4.136423575989287, 4.171330722922842, 4.205948168962618, 4.240283009422838, 4.274342054632503, 4.308131845707604, 4.341658669218482, 4.374928570845472, 4.407947368106838, 4.440720662234904, 4.473253849269009, 4.505552130427525, 4.537620521815371, 4.5694638635183455, 4.601086828130937, 4.632493928760188, 4.663689526544408, 4.694677837722201, 4.725462940284264, 4.756048780237647, 4.786439177509728, 4.8166378315169185, 4.846648326421054, 4.876474136094644, 4.906118628814432, 4.935585071701227, 4.964876634922565, 4.993996395673509, 5.022947341949744, 5.0517323761260355, 5.0803543183522155, 5.10881590977792, 5.137119815616529, 5.165268628057984, 5.193264869039514, 5.221110992882646, 5.2488093888042835, 5.276362383309168, 5.3037722424704485, 5.331041174104736, 5.358171329847527, 5.385164807134505, 5.412023651093924], [0.0, 0.5477225575051661, 0.7745966692414833, 0.9486832980505139, 1.0954451150103321, 1.2247448713915892, 1.3416407864998738, 1.4491376746189437, 1.5491933384829666, 1.6431676725154982, 1.7320508075688772, 1.816590212458495, 1.8973665961010278, 1.9748417658131499, 2.0493901531919194, 2.1213203435596424, 2.1908902300206643, 2.258317958127243, 2.32379000772445, 2.3874672772626644, 2.4494897427831783, 2.5099800796022267, 2.569046515733026, 2.6267851073127395, 2.6832815729997477, 2.7386127875258306, 2.792848008753788, 2.8460498941515415, 2.8982753492378874, 2.9495762407505253, 2.9999999999999996, 3.049590136395381, 3.098386676965933, 3.146426544510455, 3.1937438845342623, 3.2403703492039297, 3.2863353450309964, 3.331666249791536, 3.376388603226826, 3.420526275297414, 3.4641016151377544, 3.5071355833500366, 3.5496478698597698, 3.5916569992135936, 3.63318042491699, 3.674234614174767, 3.714835124201342, 3.7549966711037173, 3.7947331922020555, 3.8340579025361627, 3.872983346207417, 3.9115214431215892, 3.9496835316262997, 3.9874804074753776, 4.024922359499621, 4.06201920231798, 4.098780306383839, 4.135214625627066, 4.171330722922842, 4.207136793592525, 4.242640687119285, 4.277849927241487, 4.3127717305695645, 4.347413023856832, 4.381780460041329, 4.415880433163923, 4.449719092257397, 4.483302354291978, 4.516635916254486, 4.54972526643093, 4.58257569495584, 4.61519230368573, 4.6475800154489, 4.679743582719036, 4.711687595755898, 4.743416490252569, 4.774934554525329, 4.806245936279166, 4.83735464897913, 4.868264577855234, 4.898979485566357, 4.929503017546495, 4.959838707054898, 4.9899899799498595, 5.019960159204453, 5.049752469181039, 5.079370039680118, 5.10881590977792, 5.138093031466052, 5.167204273105525, 5.196152422706632, 5.224940191045253, 5.253570214625479, 5.282045058497703, 5.310367218940701, 5.338539126015655, 5.366563145999495, 5.394441583704471, 5.422176684690383, 5.449770637375485, 5.477225575051661, 5.504543577809154], [0.0, 0.5567764362830022, 0.7874007874011811, 0.9643650760992957, 1.1135528725660044, 1.2449899597988734, 1.3638181696985856, 1.4730919862656235, 1.5748015748023623, 1.6703293088490065, 1.760681686165901, 1.846618531261939, 1.9287301521985913, 2.0074859899884734, 2.083266665599966, 2.1563858652847823, 2.227105745132009, 2.2956480566497994, 2.3622023622035435, 2.4269322199023198, 2.489979919597747, 2.551470164434615, 2.6115129714401193, 2.670205984563738, 2.727636339397171, 2.783882181415011, 2.839013913315678, 2.8930952282978866, 2.946183972531247, 2.99833287011299, 3.049590136395381, 3.1, 3.1496031496047245, 3.1984371183438953, 3.2465366161495854, 3.2939338184001206, 3.340658617698013, 3.38673884437522, 3.432200460346103, 3.477067730142742, 3.521363372331802, 3.5651086939951777, 3.6083237105337433, 3.6510272527057364, 3.693237062523878, 3.7349698793966195, 3.7762415176998414, 3.817066936798463, 3.8574603043971827, 3.8974350539810154, 3.9370039370059056, 3.9761790704142093, 4.014971979976947, 4.053393639902249, 4.091454509095757, 4.129164564412516, 4.166533331199932, 4.20356991139674, 4.240283009422838, 4.276680956068619, 4.3127717305695645, 4.34856298103178, 4.384062043356595, 4.419275958796871, 4.454211490264018, 4.488875137492688, 4.523273151159456, 4.557411546042337, 4.591296113299599, 4.624932431938872, 4.658325879540847, 4.69148164229596, 4.724404724407087, 4.757099956906519, 4.789572005931219, 4.8218253804964775, 4.8538644398046396, 4.8856934001224435, 4.917316341257699, 4.948737212663449, 4.979959839195494, 5.01098792654702, 5.041825066382213, 5.072474741188959, 5.10294032886923, 5.13322510708424, 5.163332257370235, 5.193264869039514, 5.223025942880239, 5.252618394667558, 5.282045058497703, 5.3113086899558, 5.340411969127476, 5.36935750346352, 5.398147830506312, 5.426785420486054, 5.455272678794342, 5.483611948342078, 5.511805511808268, 5.539855593785817, 5.567764362830022, 5.595533933415113], [0.0, 0.565685424949238, 0.7999999999999999, 0.9797958971132713, 1.131370849898476, 1.2649110640673518, 1.3856406460551018, 1.4966629547095764, 1.5999999999999999, 1.697056274847714, 1.7888543819998317, 1.876166303929372, 1.9595917942265426, 2.039607805437114, 2.116601048851672, 2.1908902300206643, 2.262741699796952, 2.33238075793812, 2.4, 2.4657656011875906, 2.5298221281347035, 2.5922962793631443, 2.6532998322843198, 2.7129319932501073, 2.7712812921102037, 2.8284271247461903, 2.8844410203711917, 2.939387691339814, 2.993325909419153, 3.0463092423455636, 3.098386676965933, 3.1496031496047245, 3.1999999999999997, 3.249615361854384, 3.2984845004941286, 3.3466401061363023, 3.394112549695428, 3.4409301068170506, 3.487119154832539, 3.5327043465311387, 3.5777087639996634, 3.622154055254967, 3.6660605559646724, 3.709447398198281, 3.752332607858744, 3.7947331922020546, 3.8366652186501757, 3.878143885933063, 3.9191835884530852, 3.959797974644666, 4.0, 4.039801975344831, 4.079215610874228, 4.118252056394801, 4.156921938165306, 4.1952353926806065, 4.233202097703344, 4.2708313008125245, 4.308131845707603, 4.345112196480086, 4.381780460041329, 4.418144406874904, 4.454211490264017, 4.48998886412873, 4.525483399593904, 4.560701700396551, 4.595650117230423, 4.63033476111609, 4.66476151587624, 4.698936049788292, 4.732863826479693, 4.766550115125193, 4.8, 4.833218389437829, 4.866210024238575, 4.898979485566356, 4.931531202375181, 4.963869458396343, 4.995998398718719, 5.027922035990614, 5.059644256269407, 5.091168824543142, 5.122499389946279, 5.15363949069005, 5.184592558726289, 5.215361924162119, 5.2459508194416005, 5.276362383309167, 5.3065996645686395, 5.336665625650533, 5.366563145999495, 5.396295025292816, 5.4258639865002145, 5.455272678794342, 5.4845236803208355, 5.513619500836088, 5.542562584220407, 5.571355310873648, 5.6, 5.628498911788116, 5.656854249492381, 5.685068161420759], [0.0, 0.574456264653803, 0.812403840463596, 0.9949874371066202, 1.148912529307606, 1.2845232578665131, 1.4071247279470291, 1.5198684153570665, 1.624807680927192, 1.7233687939614086, 1.8165902124584952, 1.9052558883257653, 1.9899748742132404, 2.0712315177207983, 2.149418526020468, 2.224859546128699, 2.297825058615212, 2.3685438564654024, 2.4372115213907883, 2.503996805109783, 2.5690465157330262, 2.632489316217637, 2.6944387170614963, 2.754995462791183, 2.8142494558940583, 2.8722813232690148, 2.9291637031753623, 2.9849623113198605, 3.039736830714133, 3.0935416596516045, 3.146426544510455, 3.1984371183438953, 3.249615361854384, 3.3000000000000007, 3.3496268448888458, 3.398529093593286, 3.4467375879228173, 3.49428104193123, 3.541186241925155, 3.58747822293042, 3.6331804249169903, 3.678314831549905, 3.7229020937972575, 3.7669616403674726, 3.8105117766515306, 3.853569773599539, 3.896151947755632, 3.9382737335030438, 3.9799497484264807, 4.02119385257662, 4.06201920231798, 4.102438299353204, 4.1424630354415966, 4.182104733265298, 4.221374183841087, 4.260281680828159, 4.298837052040936, 4.337049688440288, 4.374928570845472, 4.412482294582042, 4.449719092257398, 4.486646854834912, 4.523273151159457, 4.559605246071199, 4.595650117230424, 4.631414470763764, 4.666904755831214, 4.702127178203499, 4.737087712930805, 4.77179211617606, 4.806245936279167, 4.8404545241123795, 4.874423042781577, 4.908156476723211, 4.941659640242335, 4.974937185533101, 5.007993610219566, 5.040833264451424, 5.07346035758633, 5.105878964487898, 5.1380930314660525, 5.170106381884226, 5.201922721455982, 5.23354564325181, 5.264978632435274, 5.296225070746145, 5.327288240746882, 5.358171329847526, 5.388877434122993, 5.419409561935692, 5.449770637375486, 5.479963503528103, 5.509990925582366, 5.539855593785817, 5.569560126257729, 5.599107071667768, 5.628498911788117, 5.657738063926256, 5.686826883245173, 5.715767664977296, 5.7445626465380295, 5.773214009544425], [0.0, 0.5830951894845301, 0.8246211251235321, 1.009950493836208, 1.1661903789690602, 1.30384048104053, 1.4282856857085702, 1.5427248620541514, 1.6492422502470643, 1.7492855684535902, 1.8439088914585775, 1.9339079605813718, 2.019900987672416, 2.102379604162864, 2.181742422927143, 2.258317958127243, 2.3323807579381204, 2.4041630560342617, 2.4738633753705965, 2.5416530054277673, 2.60768096208106, 2.672077843177478, 2.734958866235469, 2.7964262908219126, 2.8565713714171403, 2.9154759474226504, 2.973213749463701, 3.0298514815086235, 3.0854497241083028, 3.1400636936215167, 3.1937438845342623, 3.2465366161495854, 3.2984845004941286, 3.3496268448888458, 3.4000000000000004, 3.449637662132068, 3.4985711369071804, 3.54682957019364, 3.594440151122286, 3.6414282912066254, 3.687817782917155, 3.733630940518894, 3.7788887255382373, 3.823610858861032, 3.8678159211627436, 3.911521443121589, 3.954743986657038, 3.997499218261337, 4.039801975344832, 4.08166632639171, 4.123105625617661, 4.164132562731403, 4.204759208325728, 4.244997055358225, 4.28485705712571, 4.324349662087931, 4.363484845854286, 4.402272140611028, 4.440720662234904, 4.4788391353117385, 4.516635916254486, 4.5541190146942805, 4.591296113299598, 4.628174586162454, 4.664761515876241, 4.701063709417263, 4.737087712930805, 4.77283982551269, 4.8083261120685235, 4.843552415324934, 4.878524367060187, 4.913247398615299, 4.947726750741193, 4.98196748283246, 5.015974481593781, 5.049752469181039, 5.083306010855535, 5.1166395221864125, 5.149757275833494, 5.182663407939976, 5.21536192416212, 5.247856705360771, 5.280151512977635, 5.31224999411737, 5.344155686354956, 5.375872022286245, 5.40740233383831, 5.4387498563548595, 5.469917732470938, 5.500909015790026, 5.531726674375733, 5.562373594069352, 5.592852581643825, 5.62316636780382, 5.653317610041029, 5.683308895353129, 5.713142742834281, 5.742821606144492, 5.772347875864725, 5.801723881744115, 5.830951894845301, 5.860034129593445], [0.0, 0.5916079783099616, 0.8366600265340756, 1.02469507659596, 1.1832159566199232, 1.3228756555322954, 1.449137674618944, 1.5652475842498528, 1.6733200530681511, 1.7748239349298847, 1.8708286933869707, 1.9621416870348585, 2.04939015319192, 2.1330729007701543, 2.2135943621178655, 2.29128784747792, 2.3664319132398464, 2.4392621835300936, 2.5099800796022267, 2.5787593916455256, 2.6457513110645907, 2.711088342345192, 2.7748873851023217, 2.8372521918222215, 2.898275349237888, 2.958039891549808, 3.0166206257996713, 3.0740852297878796, 3.1304951684997055, 3.1859064644147983, 3.2403703492039297, 3.2939338184001206, 3.3466401061363023, 3.398529093593286, 3.449637662132068, 3.5, 3.5496478698597693, 3.5986108430893164, 3.646916505762094, 3.6945906403822333, 3.7416573867739413, 3.7881393849751626, 3.834057902536163, 3.879432948254164, 3.924283374069717, 3.9686269665968856, 4.012480529547776, 4.05585995813465, 4.09878030638384, 4.141255848169731, 4.183300132670378, 4.224926034855522, 4.266145801540309, 4.306971093471606, 4.347413023856832, 4.387482193696061, 4.427188724235731, 4.466542286825459, 4.505552130427525, 4.544227107000705, 4.58257569495584, 4.620606020859168, 4.658325879540846, 4.695742752749559, 4.732863826479693, 4.769696007084728, 4.806245936279166, 4.8425200051213, 4.878524367060187, 4.914264950122246, 4.949747468305833, 4.984977432245807, 5.019960159204453, 5.054700782440045, 5.089204259999788, 5.123475382979799, 5.157518783291051, 5.191338940966964, 5.2249401910452535, 5.2583267300539625, 5.291502622129181, 5.324471804789654, 5.35723809439155, 5.389805191284746, 5.422176684690384, 5.454356057317858, 5.486346689738081, 5.518151864528558, 5.549774770204643, 5.58121850495033, 5.612486080160912, 5.643580423808984, 5.674504383644443, 5.705260730238365, 5.735852159879995, 5.766281297335397, 5.796550698475776, 5.826662852782887, 5.856620185738529, 5.886425061104576, 5.916079783099616, 5.9455865984779], [0.0, 0.6, 0.848528137423857, 1.0392304845413265, 1.2, 1.3416407864998738, 1.469693845669907, 1.5874507866387544, 1.697056274847714, 1.7999999999999998, 1.8973665961010275, 1.98997487421324, 2.078460969082653, 2.1633307652783937, 2.244994432064365, 2.3237900077244498, 2.4, 2.473863375370596, 2.545584412271571, 2.615339366124404, 2.6832815729997477, 2.749545416973504, 2.814249455894058, 2.877498913987632, 2.939387691339814, 3.0, 3.059411708155671, 3.117691453623979, 3.1749015732775088, 3.2310988842807027, 3.2863353450309964, 3.340658617698013, 3.394112549695428, 3.4467375879228173, 3.4985711369071804, 3.5496478698597693, 3.5999999999999996, 3.6496575181789317, 3.698648401781386, 3.746998799039039, 3.794733192202055, 3.8418745424597094, 3.8884444190447165, 3.9344631145812, 3.97994974842648, 4.024922359499621, 4.069397989875161, 4.113392760240626, 4.156921938165306, 4.2, 4.242640687119285, 4.28485705712571, 4.3266615305567875, 4.368065933568311, 4.409081537009721, 4.449719092257398, 4.48998886412873, 4.52990066116245, 4.569463863518345, 4.608687448721165, 4.6475800154488995, 4.686149805543993, 4.724404724407086, 4.762352359916263, 4.8, 4.8373546489791295, 4.874423042781576, 4.91121166312347, 4.947726750741192, 4.983974317750845, 5.019960159204453, 5.0556898639058145, 5.091168824543142, 5.126402247190518, 5.161395160225576, 5.196152422706632, 5.230678732248808, 5.264978632435273, 5.299056519796709, 5.332916650389353, 5.366563145999495, 5.4, 5.43323108288245, 5.466260147486579, 5.499090833947008, 5.531726674375732, 5.5641710972974225, 5.596427431853289, 5.628498911788116, 5.660388679233962, 5.692099788303082, 5.7236352085016735, 5.754997827975264, 5.786190456595773, 5.817215828899595, 5.848076606885377, 5.878775382679628, 5.909314681077663, 5.939696961966999, 5.96992462263972, 6.0, 6.029925372672535], [0.0, 0.608276253029822, 0.8602325267042626, 1.053565375285274, 1.216552506059644, 1.3601470508735445, 1.489966442575134, 1.6093476939431082, 1.7204650534085253, 1.8248287590894658, 1.9235384061671346, 2.017424100183202, 2.107130750570548, 2.193171219946131, 2.2759613353482084, 2.355843797877949, 2.433105012119288, 2.5079872407968904, 2.5806975801127883, 2.651414716712571, 2.720294101747089, 2.787471972953271, 2.8530685235374214, 2.917190429162965, 2.979932885150268, 3.04138126514911, 3.101612483854165, 3.160696125855822, 3.2186953878862163, 3.2756678708318403, 3.331666249791536, 3.38673884437522, 3.4409301068170506, 3.49428104193123, 3.54682957019364, 3.5986108430893164, 3.6496575181789317, 3.7, 3.7496666518505353, 3.7986839826445165, 3.847076812334269, 3.89486841883009, 3.942080668885405, 3.988734135035826, 4.034848200366404, 4.080441152620633, 4.125530268947254, 4.170131892398609, 4.214261501141096, 4.257933771208754, 4.301162633521314, 4.343961325794695, 4.386342439892262, 4.428317965096906, 4.469899327725402, 4.511097427455985, 4.551922670696417, 4.592385001282014, 4.632493928760188, 4.672258554489466, 4.711687595755898, 4.750789408087881, 4.789572005931219, 4.828043081829325, 4.866210024238576, 4.904079934095691, 4.941659640242335, 4.978955713801841, 5.015974481593781, 5.052722038663912, 5.089204259999789, 5.1254268114957995, 5.1613951602255765, 5.197114584074513, 5.232590180780452, 5.26782687642637, 5.302829433425142, 5.3376024580330075, 5.372150407425318, 5.406477596365309, 5.440588203494178, 5.474486277268398, 5.508175741568166, 5.541660400998964, 5.574943945906542, 5.608029957123981, 5.640921910468182, 5.673623181001714, 5.706137047074843, 5.7384666941614295, 5.770615218501404, 5.8025856305616035, 5.83438085832593, 5.866003750424986, 5.897457079114693, 5.928743543112655, 5.959865770300536, 5.990826320300065, 6.021627686929839, 6.052272300549605, 6.08276253029822, 6.113100686231171], [0.0, 0.6164414002968976, 0.8717797887081348, 1.0677078252031313, 1.2328828005937953, 1.3784048752090223, 1.50996688705415, 1.6309506430300091, 1.7435595774162695, 1.849324200890693, 1.949358868961793, 2.0445048300260877, 2.1354156504062627, 2.222611077089287, 2.3065125189341593, 2.3874672772626644, 2.4657656011875906, 2.541653005427767, 2.615339366124404, 2.687005768508881, 2.7568097504180447, 2.824889378365107, 2.891366458960192, 2.956349099818897, 3.0199337741083, 3.0822070014844885, 3.1432467291003428, 3.203123475609394, 3.2619012860600183, 3.3196385345395667, 3.376388603226826, 3.432200460346103, 3.487119154832539, 3.541186241925155, 3.594440151122286, 3.646916505762094, 3.698648401781386, 3.7496666518505353, 3.8000000000000003, 3.8496753109840323, 3.898717737923586, 3.9471508711981107, 3.9949968710876362, 4.042276586281547, 4.0890096600521755, 4.135214625627066, 4.180908992073375, 4.226109321823088, 4.270831300812525, 4.315089802078284, 4.358898943540674, 4.402272140611029, 4.445222154178574, 4.487761134463376, 4.529900661162451, 4.571651780264984, 4.613025037868319, 4.654030511288038, 4.694677837722201, 4.734976240700686, 4.774934554525329, 4.814561246884289, 4.853864439804639, 4.892851929090027, 4.931531202375181, 4.969909455915671, 5.007993610219566, 5.045790324617146, 5.083306010855534, 5.120546845796843, 5.157518783291051, 5.194227565288221, 5.230678732248808, 5.266877632905477, 5.302829433425141, 5.338539126015656, 5.374011537017762, 5.409251334519409, 5.444263035526481, 5.47905101272109, 5.513619500836089, 5.547972602672079, 5.582114294781146, 5.616048432839589, 5.649778756730214, 5.68330889535313, 5.716642371182581, 5.749782604586021, 5.782732917920384, 5.815496539419485, 5.848076606885378, 5.880476171195663, 5.912698199637794, 5.944745579080741, 5.976621118993575, 6.008327554319921, 6.0398675482166, 6.071243694664217, 6.102458520956943, 6.133514490078262, 6.164414002968977, 6.1951594006934165], [0.0, 0.6244997998398399, 0.8831760866327847, 1.081665382639197, 1.2489995996796799, 1.3964240043768943, 1.5297058540778357, 1.6522711641858308, 1.7663521732655694, 1.8734993995195195, 1.97484176581315, 2.0712315177207983, 2.163330765278394, 2.2516660498395407, 2.3366642891095846, 2.4186773244895647, 2.4979991993593598, 2.574878637916747, 2.6495282598983545, 2.7221315177632404, 2.7928480087537886, 2.861817604250837, 2.9291637031753623, 2.994995826374388, 3.0594117081556713, 3.1224989991991996, 3.1843366656181322, 3.244996147917591, 3.3045423283716615, 3.363034344160048, 3.420526275297414, 3.477067730142742, 3.5327043465311387, 3.58747822293042, 3.6414282912066254, 3.6945906403822333, 3.746998799039039, 3.7986839826445165, 3.8496753109840323, 3.900000000000001, 3.9496835316263, 3.9987498046264416, 4.047221268969613, 4.095119045888654, 4.1424630354415966, 4.189272013130682, 4.235563716909475, 4.281354925721529, 4.326661530556788, 4.371498598878879, 4.415880433163924, 4.459820624195553, 4.503332099679081, 4.546427168667723, 4.589117562233507, 4.631414470763765, 4.673328578219169, 4.7148700936505135, 4.756048780237647, 4.796873982084583, 4.8373546489791295, 4.87749935930288, 4.917316341257699, 4.956813492557492, 4.9959983987187195, 5.034878350069642, 5.073460357586329, 5.111751167652823, 5.149757275833494, 5.187484939737176, 5.2249401910452535, 5.262128846769148, 5.299056519796709, 5.335728628781641, 5.372150407425317, 5.408326913195984, 5.444263035526481, 5.479963503528103, 5.515432893255072, 5.550675634551168, 5.585696017507577, 5.620498198558559, 5.655086206239478, 5.68946394662977, 5.723635208501674, 5.757603668193913, 5.791372894228104, 5.8249463516842805, 5.858327406350725, 5.8915193286621745, 5.92452529743945, 5.957348403442593, 5.989991652748776, 6.02245796996542, 6.054750201288242, 6.08687111741328, 6.118823416311343, 6.150609725872713, 6.182232606429493, 6.213694553162394, 6.244997998398399, 6.276145313805283], [0.0, 0.6324555320336759, 0.8944271909999159, 1.0954451150103324, 1.2649110640673518, 1.4142135623730951, 1.5491933384829668, 1.6733200530681511, 1.7888543819998317, 1.8973665961010275, 2.0, 2.0976176963403033, 2.1908902300206647, 2.280350850198276, 2.3664319132398464, 2.449489742783178, 2.5298221281347035, 2.6076809620810595, 2.6832815729997477, 2.7568097504180447, 2.8284271247461903, 2.898275349237888, 2.9664793948382653, 3.0331501776206204, 3.0983866769659336, 3.1622776601683795, 3.22490309931942, 3.286335345030997, 3.3466401061363023, 3.4058772731852804, 3.4641016151377544, 3.521363372331802, 3.5777087639996634, 3.6331804249169903, 3.687817782917155, 3.7416573867739413, 3.794733192202055, 3.847076812334269, 3.898717737923586, 3.9496835316263, 4.0, 4.049691346263318, 4.09878030638384, 4.147288270665544, 4.1952353926806065, 4.242640687119285, 4.2895221179054435, 4.33589667773576, 4.3817804600413295, 4.427188724235731, 4.47213595499958, 4.5166359162544865, 4.560701700396552, 4.604345773288536, 4.6475800154489, 4.69041575982343, 4.732863826479693, 4.774934554525329, 4.8166378315169185, 4.857983120596447, 4.898979485566356, 4.9396356140913875, 4.979959839195493, 5.019960159204453, 5.059644256269407, 5.0990195135927845, 5.138093031466052, 5.176871642217914, 5.215361924162119, 5.253570214625479, 5.291502622129181, 5.329165037789691, 5.366563145999495, 5.403702434442518, 5.440588203494177, 5.477225575051661, 5.513619500836089, 5.549774770204643, 5.585696017507577, 5.621387729022079, 5.656854249492381, 5.692099788303083, 5.727128425310542, 5.761944116355173, 5.796550698475776, 5.830951894845301, 5.865151319446072, 5.8991524815010505, 5.932958789676531, 5.966573556070519, 6.0, 6.0332412515993425, 6.066300355241241, 6.099180272790763, 6.131883886702357, 6.164414002968976, 6.196773353931867, 6.228964600958975, 6.260990336999411, 6.29285308902091, 6.324555320336759, 6.356099432828282], [0.0, 0.6403124237432849, 0.9055385138137417, 1.1090536506409419, 1.2806248474865698, 1.4317821063276355, 1.5684387141358125, 1.6941074346097418, 1.8110770276274835, 1.9209372712298547, 2.024845673131659, 2.1236760581595306, 2.2181073012818837, 2.3086792761230397, 2.395829710142188, 2.479919353527449, 2.5612496949731396, 2.6400757564888173, 2.716615541441225, 2.791057147390573, 2.863564212655271, 2.934280150224242, 3.0033314835362415, 3.0708305065568178, 3.136877428271625, 3.2015621187164247, 3.264965543462902, 3.3271609519228256, 3.3882148692194836, 3.448187929913334, 3.5071355833500366, 3.5651086939951777, 3.622154055254967, 3.678314831549905, 3.733630940518894, 3.7881393849751626, 3.8418745424597094, 3.89486841883009, 3.9471508711981107, 3.9987498046264416, 4.049691346263318, 4.1000000000000005, 4.149698784249287, 4.198809355043403, 4.247352116319061, 4.295346318982906, 4.342810150121693, 4.389760813529594, 4.436214602563767, 4.4821869662029945, 4.527692569068709, 4.572745346069471, 4.617358552246079, 4.661544808322667, 4.705316142407437, 4.748684028233507, 4.791659420284376, 4.8342527861087286, 4.876474136094644, 4.9183330509431755, 4.959838707054898, 5.000999900019996, 5.041825066382213, 5.082322303829225, 5.122499389946279, 5.162363799656123, 5.201922721455982, 5.241183072551464, 5.280151512977635, 5.3188344587888805, 5.35723809439155, 5.395368384086485, 5.43323108288245, 5.470831746635972, 5.508175741568165, 5.545268253204709, 5.582114294781146, 5.61871871515206, 5.655086206239478, 5.691221310052879, 5.727128425310542, 5.762811813689565, 5.798275605729691, 5.833523806414096, 5.868560300448484, 5.903388857258177, 5.93801313572141, 5.9724366886556455, 6.006662967072483, 6.040695324215583, 6.074537019394977, 6.1081912216301815, 6.1416610131136355, 6.174949392505174, 6.208059278067504, 6.24099351065197, 6.27375485654325, 6.306346010171025, 6.338769596696192, 6.3710281744785915, 6.403124237432849, 6.435060217278469], [0.0, 0.6480740698407861, 0.9165151389911681, 1.1224972160321827, 1.2961481396815722, 1.4491376746189442, 1.5874507866387546, 1.7146428199482249, 1.8330302779823362, 1.9442222095223582, 2.04939015319192, 2.149418526020468, 2.2449944320643653, 2.336664289109585, 2.4248711305964283, 2.5099800796022267, 2.5922962793631443, 2.672077843177478, 2.749545416973504, 2.8248893783651075, 2.8982753492378883, 2.9698484809835, 3.039736830714133, 3.108054053584011, 3.174901573277509, 3.2403703492039306, 3.304542328371662, 3.3674916480965478, 3.4292856398964497, 3.48998567332303, 3.5496478698597698, 3.6083237105337433, 3.6660605559646724, 3.7229020937972575, 3.7788887255382373, 3.834057902536163, 3.8884444190447165, 3.942080668885405, 3.9949968710876362, 4.047221268969613, 4.09878030638384, 4.149698784249287, 4.200000000000001, 4.249705872175156, 4.298837052040936, 4.347413023856832, 4.3954521951671826, 4.442971978304612, 4.489988864128731, 4.536518488885503, 4.582575694955841, 4.628174586162455, 4.67332857821917, 4.718050444834181, 4.762352359916264, 4.806245936279167, 4.849742261192857, 4.892851929090027, 4.935585071701227, 4.9779513858614575, 5.019960159204453, 5.061620293937506, 5.10294032886923, 5.143928459844674, 5.184592558726289, 5.224940191045253, 5.264978632435274, 5.304714883949938, 5.344155686354956, 5.383307533477909, 5.422176684690385, 5.46076917659042, 5.499090833947008, 5.537147279962851, 5.574943945906542, 5.612486080160912, 5.649778756730215, 5.686826883245173, 5.723635208501675, 5.760208329565868, 5.796550698475777, 5.832666628567075, 5.868560300448485, 5.904235767650205, 5.939696961967, 5.974947698515863, 6.009991680526689, 6.044832503882966, 6.079473661428266, 6.113918547053109, 6.148170459575759, 6.182232606429493, 6.216108107168022, 6.249799996799899, 6.283311228962004, 6.316644678941503, 6.349803146555018, 6.38278935889318, 6.4156059729381765, 6.448255578061405, 6.480740698407861, 6.5130637951735135], [0.0, 0.6557438524302001, 0.9273618495495702, 1.1357816691600549, 1.3114877048604001, 1.466287829861518, 1.606237840420901, 1.7349351572897471, 1.8547236990991405, 1.9672315572906, 2.073644135332772, 2.1748563170931545, 2.2715633383201097, 2.364318083507378, 2.453568829277059, 2.5396850198400585, 2.6229754097208002, 2.7037011669191546, 2.782085548648711, 2.8583211855912904, 2.932575659723036, 3.004995840263344, 3.0757112998459397, 3.1448370387032774, 3.212475680841802, 3.278719262151, 3.3436506994600976, 3.407345007480164, 3.4698703145794942, 3.531288716601915, 3.5916569992135936, 3.6510272527057364, 3.709447398198281, 3.7669616403674726, 3.823610858861032, 3.879432948254164, 3.9344631145812, 3.988734135035826, 4.042276586281547, 4.095119045888654, 4.147288270665544, 4.198809355043403, 4.249705872175156, 4.299999999999999, 4.349712634186309, 4.398863489584553, 4.447471191587417, 4.495553358597804, 4.543126676640219, 4.5902069670114, 4.636809247747852, 4.682947789587239, 4.728636167014756, 4.773887304912004, 4.818713521262703, 4.863126566315131, 4.907137658554118, 4.950757517794625, 4.993996395673509, 5.03686410378521, 5.079370039680117, 5.121523210920751, 5.163332257370234, 5.204805471869242, 5.2459508194416005, 5.28677595515452, 5.3272882407468805, 5.367494760127856, 5.407402333838309, 5.447017532558529, 5.486346689738081, 5.525395913416522, 5.564171097297422, 5.602677931132575, 5.6409219104681805, 5.678908345800274, 5.716642371182581, 5.754128952326321, 5.791372894228104, 5.8283788483591215, 5.865151319446072, 5.9016946718718, 5.938013135721409, 5.974110812497538, 6.009991680526688, 6.0456596000767355, 6.081118318204308, 6.1163714733492105, 6.151422599691879, 6.186275131288617, 6.220932405998315, 6.255397669213365, 6.289674077406555, 6.323764701504951, 6.357672530100933, 6.3914004725099165, 6.424951361683604, 6.458327956987009, 6.491532946846992, 6.524568951279464, 6.557438524302, 6.590144156238162], [0.0, 0.66332495807108, 0.938083151964686, 1.148912529307606, 1.32664991614216, 1.4832396974191329, 1.6248076809271923, 1.7549928774784245, 1.876166303929372, 1.98997487421324, 2.0976176963403033, 2.2, 2.297825058615212, 2.3916521486202797, 2.4819347291981715, 2.569046515733026, 2.65329983228432, 2.734958866235469, 2.814249455894058, 2.8913664589601926, 2.9664793948382657, 3.039736830714133, 3.1112698372208096, 3.1811947441173736, 3.2496153618543846, 3.3166247903554003, 3.382306905057553, 3.4467375879228177, 3.509985754956849, 3.5721142198983507, 3.63318042491699, 3.693237062523878, 3.752332607858744, 3.8105117766515306, 3.8678159211627436, 3.924283374069717, 3.97994974842648, 4.034848200366404, 4.0890096600521755, 4.1424630354415966, 4.1952353926806065, 4.247352116319061, 4.298837052040936, 4.349712634186309, 4.4, 4.449719092257398, 4.498888751680798, 4.54752680036083, 4.595650117230424, 4.64327470649756, 4.69041575982343, 4.737087712930806, 4.7833042972405595, 4.829078587059855, 4.874423042781577, 4.919349550499538, 4.963869458396343, 5.007993610219566, 5.051732376126036, 5.095095681142799, 5.138093031466052, 5.180733538795447, 5.223025942880239, 5.264978632435274, 5.30659966456864, 5.347896782848375, 5.388877434122993, 5.429548784199292, 5.469917732470938, 5.509990925582365, 5.549774770204644, 5.589275444992849, 5.628498911788116, 5.667450926121902, 5.706137047074843, 5.7445626465380295, 5.782732917920385, 5.8206528843421, 5.858327406350725, 5.895761189193471, 5.9329587896765315, 5.969924622639721, 6.006662967072484, 6.043177971895251, 6.079473661428266, 6.115553940568263, 6.15142259969188, 6.187083319303208, 6.222539674441619, 6.2577951388648065, 6.29285308902091, 6.327716807822551, 6.362389488234747, 6.3968742366877915, 6.431174076325411, 6.465291950097845, 6.499230723708769, 6.532993188424431, 6.566582063752802, 6.600000000000001, 6.6332495807108005, 6.666333324999584], [0.0, 0.6708203932499369, 0.9486832980505137, 1.161895003862225, 1.3416407864998738, 1.5, 1.6431676725154982, 1.7748239349298847, 1.8973665961010273, 2.0124611797498106, 2.1213203435596424, 2.224859546128699, 2.32379000772445, 2.4186773244895647, 2.5099800796022262, 2.5980762113533156, 2.6832815729997477, 2.765863337187866, 2.846049894151541, 2.924038303442689, 3.0, 3.0740852297878796, 3.1464265445104544, 3.2171415884290826, 3.2863353450309964, 3.3541019662496843, 3.420526275297414, 3.4856850115866753, 3.5496478698597693, 3.6124783736376886, 3.674234614174767, 3.7349698793966195, 3.7947331922020546, 3.853569773599539, 3.911521443121589, 3.9686269665968856, 4.024922359499621, 4.080441152620633, 4.135214625627066, 4.189272013130682, 4.242640687119285, 4.295346318982906, 4.347413023856832, 4.398863489584553, 4.449719092257398, 4.499999999999999, 4.54972526643093, 4.598912915026768, 4.6475800154489, 4.695742752749558, 4.743416490252569, 4.790615826801393, 4.8373546489791295, 4.883646178829912, 4.9295030175464944, 4.9749371855331, 5.0199601592044525, 5.064582904840239, 5.10881590977792, 5.1526692111953, 5.196152422706631, 5.239274758971893, 5.282045058497702, 5.324471804789654, 5.366563145999495, 5.4083269131959835, 5.449770637375485, 5.490901565316937, 5.531726674375732, 5.572252686302012, 5.612486080160912, 5.652433104425031, 5.692099788303082, 5.731491952362839, 5.770615218501403, 5.809475019311125, 5.848076606885378, 5.886425061104575, 5.92452529743945, 5.962382074305537, 6.0, 6.037383539249432, 6.074537019394977, 6.111464636239008, 6.148170459575759, 6.18465843842649, 6.220932405998316, 6.256996084384263, 6.292853089020909, 6.328506932918695, 6.363961030678928, 6.399218702310462, 6.434283176858165, 6.469157595854347, 6.5038450166036395, 6.53834841531101, 6.572670690061993, 6.606814663663572, 6.640783086353596, 6.674578638386096, 6.7082039324993685, 6.74166151627327], [0.0, 0.6782329983125268, 0.9591663046625439, 1.1747340124470733, 1.3564659966250536, 1.5165750888103102, 1.661324772583615, 1.7944358444926363, 1.9183326093250879, 2.0346989949375804, 2.1447610589527217, 2.249444375840399, 2.3494680248941466, 2.445403852127497, 2.5377155080899043, 2.626785107312739, 2.7129319932501073, 2.7964262908219126, 2.877498913987632, 2.956349099818897, 3.0331501776206204, 3.108054053584011, 3.1811947441173736, 3.252691193458119, 3.32264954516723, 3.3911649915626345, 3.458323293158117, 3.5242020373412197, 3.5888716889852725, 3.6523964735499352, 3.714835124201342, 3.7762415176998414, 3.8366652186501757, 3.896151947755632, 3.954743986657038, 4.012480529547776, 4.069397989875161, 4.125530268947254, 4.180908992073375, 4.235563716909475, 4.2895221179054435, 4.342810150121693, 4.3954521951671826, 4.447471191587417, 4.498888751680798, 4.54972526643093, 4.6000000000000005, 4.649731175025068, 4.698936049788293, 4.747630988187688, 4.79583152331272, 4.843552415324934, 4.890807704254994, 4.937610758251404, 4.983974317750845, 5.029910535983717, 5.075431016179809, 5.120546845796843, 5.165268628057984, 5.209606511052442, 5.253570214625478, 5.297169055259611, 5.340411969127476, 5.383307533477908, 5.4258639865002145, 5.468089245796926, 5.509990925582365, 5.551576352712804, 5.592852581643825, 5.63382640840131, 5.674504383644443, 5.71489282489182, 5.754997827975264, 5.794825277780168, 5.834380858325929, 5.873670062235366, 5.912698199637794, 5.951470406546605, 5.989991652748776, 6.028266749240615, 6.066300355241241, 6.104096984812742, 6.1416610131136355, 6.178996682310163, 6.216108107168022, 6.252999280345393, 6.289674077406556, 6.326136261573884, 6.362389488234747, 6.398437309218556, 6.434283176858165, 6.469930447848725, 6.505382386916238, 6.540642170307134, 6.57571288910944, 6.6105975524153635, 6.64529909033446, 6.679820356865895, 6.714164132637808, 6.748333127521196, 6.782329983125269, 6.81615727518079], [0.0, 0.6855654600401044, 0.9695359714832658, 1.187434208703792, 1.3711309200802089, 1.5329709716755893, 1.6792855623746665, 1.8138357147217055, 1.9390719429665315, 2.056696380120313, 2.16794833886788, 2.273763400180415, 2.374868417407584, 2.471841418861655, 2.565151067676132, 2.6551836094703507, 2.7422618401604177, 2.826658805020514, 2.9086079144497976, 2.9883105594967874, 3.0659419433511785, 3.1416556144810017, 3.2155870381627056, 3.2878564445547194, 3.358571124749333, 3.4278273002005224, 3.4957116585897072, 3.5623026261113755, 3.627671429443411, 3.691882988394947, 3.7549966711037173, 3.817066936798463, 3.878143885933063, 3.9382737335030438, 3.997499218261337, 4.05585995813465, 4.113392760240626, 4.170131892398609, 4.226109321823088, 4.281354925721529, 4.33589667773576, 4.389760813529594, 4.442971978304612, 4.495553358597804, 4.54752680036083, 4.598912915026768, 4.649731175025068, 4.7, 4.749736834815168, 4.798958220280731, 4.847679857416329, 4.89591666595746, 4.94368283772331, 4.990991885387113, 5.037856687124, 5.084289527554465, 5.130302135352264, 5.175905717843014, 5.221110992882646, 5.265928218272634, 5.310367218940701, 5.354437412091022, 5.3981478305063115, 5.441507144165117, 5.4845236803208355, 5.527205442174191, 5.569560126257728, 5.61159513863928, 5.653317610041028, 5.69473440996154, 5.735852159879995, 5.776677245614472, 5.817215828899595, 5.857473858242988, 5.897457079114692, 5.937171043518958, 5.976621118993575, 6.015812497078014, 6.054750201288242, 6.09343909463285, 6.131883886702357, 6.17008914036094, 6.208059278067503, 6.245798587850876, 6.2833112289620034, 6.320601237224193, 6.357672530100934, 6.394528911499267, 6.431174076325411, 6.4676116148080505, 6.5038450166036395, 6.539877674696982, 6.575712889109439, 6.611353870426239, 6.646803743153547, 6.682065548915245, 6.717142249498666, 6.7520367297579185, 6.786751800382861, 6.821290200541244, 6.855654600401045, 6.889847603539574], [0.0, 0.692820323027551, 0.9797958971132713, 1.2000000000000004, 1.385640646055102, 1.549193338482967, 1.6970562748477143, 1.8330302779823362, 1.9595917942265426, 2.078460969082653, 2.1908902300206647, 2.297825058615212, 2.400000000000001, 2.4979991993593598, 2.5922962793631443, 2.6832815729997477, 2.771281292110204, 2.8565713714171403, 2.9393876913398143, 3.0199337741083006, 3.098386676965934, 3.174901573277509, 3.2496153618543846, 3.3226495451672307, 3.3941125496954285, 3.4641016151377553, 3.5327043465311396, 3.6000000000000005, 3.6660605559646724, 3.7309516212355267, 3.7947331922020555, 3.8574603043971827, 3.9191835884530852, 3.9799497484264807, 4.039801975344832, 4.09878030638384, 4.156921938165306, 4.214261501141096, 4.270831300812525, 4.326661530556788, 4.3817804600413295, 4.436214602563767, 4.489988864128731, 4.543126676640219, 4.595650117230424, 4.6475800154489, 4.698936049788293, 4.749736834815168, 4.800000000000002, 4.849742261192857, 4.898979485566357, 4.947726750741194, 4.9959983987187195, 5.043808085167398, 5.091168824543143, 5.1380930314660525, 5.184592558726289, 5.230678732248809, 5.276362383309169, 5.321653878260029, 5.366563145999495, 5.411099703387474, 5.455272678794342, 5.499090833947009, 5.542562584220408, 5.585696017507577, 5.628498911788117, 5.670978751503131, 5.713142742834281, 5.754997827975265, 5.796550698475777, 5.83780780773057, 5.8787753826796285, 5.9194594347794975, 5.959865770300536, 6.000000000000001, 6.039867548216601, 6.079473661428266, 6.1188234163113435, 6.157921727336262, 6.196773353931868, 6.235382907247959, 6.27375485654325, 6.311893535223801, 6.349803146555018, 6.387487769068526, 6.424951361683605, 6.462197768561406, 6.499230723708769, 6.536053855347277, 6.572670690061994, 6.609084656743323, 6.645299090334461, 6.681317235396028, 6.717142249498667, 6.752777206453653, 6.788225099390857, 6.823488843692794, 6.8585712797928995, 6.893475175845635, 6.9282032302755105, 6.962758074211686], [0.0, 0.7000000000000001, 0.9899494936611665, 1.2124355652982142, 1.4000000000000001, 1.565247584249853, 1.7146428199482247, 1.8520259177452134, 1.979898987322333, 2.1, 2.2135943621178655, 2.32163735324878, 2.4248711305964283, 2.5238858928247927, 2.619160170741759, 2.7110883423451915, 2.8000000000000003, 2.8861739379323623, 2.9698484809834995, 3.051229260478472, 3.130495168499706, 3.2078029864690882, 3.283291031876401, 3.357082066318904, 3.4292856398964493, 3.5, 3.5693136595149495, 3.6373066958946425, 3.704051835490427, 3.769615364994153, 3.8340579025361627, 3.8974350539810154, 3.959797974644666, 4.02119385257662, 4.08166632639171, 4.141255848169731, 4.2, 4.257933771208754, 4.315089802078284, 4.371498598878879, 4.427188724235731, 4.4821869662029945, 4.536518488885503, 4.5902069670114, 4.64327470649756, 4.695742752749558, 4.747630988187688, 4.798958220280731, 4.849742261192857, 4.9, 4.949747468305833, 4.998999899979996, 5.047771785649585, 5.096076922496363, 5.143928459844674, 5.191338940966964, 5.238320341483518, 5.2848841046895245, 5.331041174104736, 5.376802023508025, 5.422176684690383, 5.467174773134658, 5.511805511808268, 5.55607775323564, 5.6000000000000005, 5.643580423808984, 5.686826883245172, 5.729746940310715, 5.772347875864725, 5.814636704042653, 5.856620185738529, 5.898304841223451, 5.939696961966999, 5.980802621722272, 6.021627686929839, 6.06217782649107, 6.102458520956944, 6.142475071174486, 6.182232606429493, 6.221736092120913, 6.260990336999412, 6.300000000000001, 6.338769596696192, 6.377303505401009, 6.4156059729381765, 6.4536811201050215, 6.491532946846993, 6.529165337162171, 6.566582063752802, 6.603786792439623, 6.640783086353597, 6.67757440991862, 6.714164132637808, 6.750555532695069, 6.786751800382861, 6.822756041366274, 6.858571279792899, 6.894200461257274, 6.929646455628165, 6.96491205974634, 7.0, 7.034912934784624], [0.0, 0.7071067811865476, 1.0, 1.2247448713915892, 1.4142135623730951, 1.5811388300841898, 1.7320508075688774, 1.8708286933869709, 2.0, 2.1213203435596424, 2.23606797749979, 2.345207879911715, 2.4494897427831783, 2.5495097567963927, 2.6457513110645907, 2.7386127875258306, 2.8284271247461903, 2.9154759474226504, 3.0, 3.082207001484489, 3.1622776601683795, 3.2403703492039306, 3.3166247903554003, 3.3911649915626345, 3.464101615137755, 3.535533905932738, 3.6055512754639896, 3.6742346141747677, 3.7416573867739418, 3.8078865529319548, 3.872983346207417, 3.9370039370059056, 4.0, 4.06201920231798, 4.123105625617661, 4.183300132670378, 4.242640687119285, 4.301162633521314, 4.358898943540674, 4.415880433163924, 4.47213595499958, 4.527692569068709, 4.582575694955841, 4.636809247747852, 4.69041575982343, 4.743416490252569, 4.79583152331272, 4.847679857416329, 4.898979485566357, 4.949747468305833, 5.000000000000001, 5.04975246918104, 5.099019513592785, 5.147815070493501, 5.196152422706632, 5.244044240850759, 5.291502622129181, 5.338539126015656, 5.385164807134505, 5.431390245600108, 5.477225575051661, 5.522680508593631, 5.5677643628300215, 5.612486080160912, 5.656854249492381, 5.70087712549569, 5.744562646538029, 5.787918451395113, 5.830951894845301, 5.873670062235366, 5.916079783099617, 5.958187643906493, 6.0, 6.041522986797286, 6.082762530298219, 6.123724356957946, 6.164414002968978, 6.2048368229954285, 6.244997998398399, 6.284902544988268, 6.324555320336759, 6.3639610306789285, 6.403124237432849, 6.442049363362563, 6.480740698407861, 6.519202405202649, 6.557438524302001, 6.59545297913646, 6.6332495807108005, 6.670832032063167, 6.708203932499369, 6.745368781616021, 6.782329983125269, 6.8190908484929285, 6.855654600401045, 6.892024376045111, 6.92820323027551, 6.9641941385920605, 7.0, 7.035623639735145, 7.071067811865476, 7.1063352017759485], [0.0, 0.7141428428542851, 1.0099504938362078, 1.2369316876852985, 1.4282856857085702, 1.5968719422671316, 1.7492855684535904, 1.8894443627691186, 2.0199009876724157, 2.142428528562855, 2.2583179581272432, 2.368543856465403, 2.473863375370597, 2.574878637916747, 2.672077843177478, 2.765863337187866, 2.8565713714171403, 2.944486372867092, 3.029851481508624, 3.1128764832546767, 3.193743884534263, 3.272613634390715, 3.3496268448888458, 3.4249087579087423, 3.498571136907181, 3.5707142142714257, 3.6414282912066254, 3.7107950630558952, 3.7788887255382373, 3.845776904605883, 3.9115214431215892, 3.9761790704142093, 4.039801975344831, 4.102438299353204, 4.164132562731403, 4.224926034855522, 4.28485705712571, 4.343961325794695, 4.402272140611029, 4.459820624195553, 4.5166359162544865, 4.572745346069471, 4.628174586162455, 4.682947789587239, 4.737087712930806, 4.790615826801393, 4.843552415324934, 4.89591666595746, 4.947726750741194, 4.998999899979996, 5.04975246918104, 5.100000000000001, 5.149757275833494, 5.199038372622384, 5.247856705360771, 5.296225070746145, 5.344155686354956, 5.391660226683429, 5.43874985635486, 5.485435260760991, 5.531726674375732, 5.577633906953737, 5.62316636780382, 5.668333088307356, 5.713142742834281, 5.757603668193913, 5.801723881744115, 5.845511098270194, 5.888972745734184, 5.932115979985557, 5.974947698515863, 6.017474553332154, 6.059702963017248, 6.101639124038721, 6.143289021363068, 6.184658438426491, 6.225752966509353, 6.266578013557321, 6.307138812488593, 6.347440429023341, 6.387487769068526, 6.427285585688566, 6.466838485689898, 6.506150935845249, 6.54522726878143, 6.584071688552609, 6.62268827591938, 6.661080993352356, 6.6992536897776915, 6.73721010508059, 6.77495387438173, 6.81248853210044, 6.8498175158174845, 6.886944169949399, 6.923871749245506, 6.960603422117942, 6.997142273814362, 7.033491309442276, 7.069653456853455, 7.105631569396208, 7.141428428542851, 7.177046746399247], [0.0, 0.7211102550927979, 1.019803902718557, 1.2489995996796799, 1.4422205101855958, 1.61245154965971, 1.7663521732655696, 1.9078784028338915, 2.039607805437114, 2.1633307652783937, 2.280350850198276, 2.3916521486202797, 2.4979991993593598, 2.6000000000000005, 2.6981475126464085, 2.792848008753788, 2.8844410203711917, 2.973213749463701, 3.0594117081556713, 3.1432467291003428, 3.22490309931942, 3.3045423283716615, 3.3823069050575527, 3.458323293158117, 3.532704346531139, 3.6055512754639896, 3.6769552621700474, 3.7469987990390394, 3.815756805667783, 3.88329756778952, 3.9496835316262997, 4.014971979976947, 4.079215610874228, 4.1424630354415966, 4.204759208325728, 4.266145801540309, 4.3266615305567875, 4.386342439892262, 4.445222154178574, 4.503332099679081, 4.560701700396552, 4.617358552246079, 4.67332857821917, 4.728636167014756, 4.7833042972405595, 4.8373546489791295, 4.890807704254994, 4.94368283772331, 4.9959983987187195, 5.047771785649585, 5.099019513592785, 5.149757275833494, 5.200000000000001, 5.249761899362676, 5.299056519796709, 5.347896782848376, 5.396295025292817, 5.44426303552648, 5.491812087098393, 5.5389529696504916, 5.585696017507576, 5.63205113613149, 5.678027826631356, 5.723635208501674, 5.768882040742383, 5.813776741499453, 5.858327406350725, 5.902541825349482, 5.946427498927402, 5.989991652748776, 6.033241251599343, 6.076183012385325, 6.118823416311343, 6.161168720299745, 6.203224967708329, 6.244997998398398, 6.2864934582006855, 6.327716807822551, 6.3686733312362644, 6.409368143584826, 6.44980619863884, 6.489992295835181, 6.529931086925804, 6.569627082262737, 6.609084656743323, 6.648308055437865, 6.687301398920196, 6.726068688320096, 6.764613810115105, 6.802940540677979, 6.841052550594828, 6.878953408767936, 6.916646586316234, 6.954135460285485, 6.9914233171794145, 7.0285133563222315, 7.065408693062278, 7.102112361825883, 7.138627319029899, 7.17495644586084, 7.211102550927979, 7.247068372797377], [0.0, 0.7280109889280519, 1.0295630140987002, 1.2609520212918495, 1.4560219778561039, 1.627882059609971, 1.7832554500127011, 1.9261360284258224, 2.0591260281974004, 2.1840329667841556, 2.302172886644268, 2.4145392935299275, 2.521904042583699, 2.624880949681338, 2.7239676943752476, 2.819574435974337, 2.9120439557122078, 3.001666203960727, 3.0886890422961004, 3.1733263305244868, 3.255764119219942, 3.336165463522456, 3.414674215792775, 3.491418050019219, 3.5665109000254023, 3.64005494464026, 3.712142238654118, 3.782856063875548, 3.852272056851645, 3.9204591567825324, 3.9874804074753776, 4.053393639902249, 4.118252056394801, 4.182104733265298, 4.244997055358225, 4.306971093471606, 4.368065933568311, 4.428317965096906, 4.487761134463376, 4.546427168667723, 4.604345773288536, 4.661544808322667, 4.718050444834181, 4.773887304912004, 4.829078587059855, 4.883646178829912, 4.937610758251404, 4.990991885387113, 5.043808085167398, 5.096076922496363, 5.147815070493501, 5.199038372622384, 5.249761899362676, 5.300000000000001, 5.349766350038103, 5.399073994677236, 5.447935388750495, 5.496362433464519, 5.5443665102516455, 5.591958512006326, 5.639148871948674, 5.6859475903318, 5.732364259186606, 5.7784080852774675, 5.8240879114244155, 5.869412236331676, 5.914389233048499, 5.959026766175833, 6.003332407921454, 6.047313453096343, 6.090976933136425, 6.134329629226001, 6.177378084592201, 6.220128616033596, 6.262587324740471, 6.304760106459247, 6.3466526610489735, 6.388270501473776, 6.429618962271405, 6.470703207534712, 6.511528238439884, 6.552098900352467, 6.592419889539805, 6.632495759516172, 6.672330927044912, 6.711929677819935, 6.751296171847301, 6.790434448545985, 6.82934843158555, 6.868041933477111, 6.906518659932804, 6.944782214007867, 6.982836100038438, 7.020683727387242, 7.058328414008519, 7.095773389842717, 7.1330218000508046, 7.170076708097342, 7.206941098690901, 7.243617880589783, 7.28010988928052, 7.31641988953614], [0.0, 0.7348469228349535, 1.0392304845413265, 1.2727922061357857, 1.469693845669907, 1.6431676725154984, 1.8, 1.9442222095223582, 2.078460969082653, 2.2045407685048604, 2.32379000772445, 2.4372115213907883, 2.5455844122715714, 2.6495282598983545, 2.749545416973504, 2.846049894151541, 2.939387691339814, 3.0298514815086235, 3.1176914536239795, 3.203123475609394, 3.286335345030997, 3.3674916480965478, 3.4467375879228173, 3.5242020373412197, 3.6, 3.6742346141747677, 3.7469987990390394, 3.818376618407357, 3.8884444190447165, 3.957271787481876, 4.024922359499621, 4.091454509095757, 4.156921938165306, 4.221374183841087, 4.28485705712571, 4.347413023856832, 4.409081537009721, 4.469899327725402, 4.529900661162451, 4.589117562233507, 4.6475800154489, 4.705316142407437, 4.762352359916264, 4.818713521262703, 4.874423042781577, 4.9295030175464944, 4.983974317750845, 5.037856687124, 5.091168824543143, 5.143928459844674, 5.196152422706632, 5.247856705360771, 5.299056519796709, 5.349766350038103, 5.4, 5.449770637375486, 5.499090833947008, 5.547972602672079, 5.596427431853289, 5.644466316668034, 5.692099788303082, 5.739337940912697, 5.786190456595773, 5.8326666285670745, 5.878775382679628, 5.924525297439449, 5.96992462263972, 6.014981296729027, 6.059702963017247, 6.104096984812742, 6.148170459575759, 6.191930232165088, 6.235382907247959, 6.278534860936905, 6.321392251711643, 6.363961030678928, 6.406246951218788, 6.448255578061404, 6.489992295835182, 6.5314623171231725, 6.572670690061994, 6.613622305514581, 6.654321903845651, 6.694774081326419, 6.7349832961930955, 6.77495387438173, 6.814690014960329, 6.854195795277518, 6.8934751758456345, 6.932532004974806, 6.971370023173351, 7.009992867328754, 7.0484040746824395, 7.0866070866106305, 7.124605252222751, 7.162401831787993, 7.2, 7.237402849088892, 7.274613391789285, 7.3116345641723655, 7.348469228349535, 7.385120175054704], [0.0, 0.7416198487095663, 1.0488088481701516, 1.2845232578665131, 1.4832396974191326, 1.6583123951777001, 1.8165902124584952, 1.9621416870348585, 2.0976176963403033, 2.224859546128699, 2.345207879911715, 2.459674775249769, 2.5690465157330262, 2.673948391424188, 2.7748873851023217, 2.8722813232690143, 2.9664793948382653, 3.0577769702841313, 3.146426544510455, 3.232645975048923, 3.3166247903554003, 3.398529093593286, 3.4785054261852175, 3.5566838487557484, 3.6331804249169903, 3.708099243547832, 3.7815340802378077, 3.853569773599539, 3.924283374069717, 3.993745109543172, 4.06201920231798, 4.129164564412516, 4.1952353926806065, 4.260281680828159, 4.324349662087931, 4.387482193696061, 4.449719092257398, 4.511097427455985, 4.571651780264984, 4.631414470763765, 4.69041575982343, 4.748684028233507, 4.806245936279167, 4.863126566315131, 4.919349550499538, 4.9749371855331, 5.029910535983717, 5.084289527554465, 5.1380930314660525, 5.191338940966964, 5.244044240850759, 5.296225070746145, 5.347896782848376, 5.399073994677236, 5.449770637375486, 5.5, 5.549774770204643, 5.599107071667768, 5.648008498577176, 5.6964901474504455, 5.744562646538029, 5.792236183029832, 5.839520528262573, 5.886425061104576, 5.932958789676531, 5.979130371550699, 6.024948132556827, 6.070420084310475, 6.115553940568263, 6.1603571325045765, 6.2048368229954285, 6.248999919987198, 6.29285308902091, 6.336402764976356, 6.3796551630946325, 6.422616289332565, 6.465291950097846, 6.507687761409578, 6.549809157525127, 6.591661399070799, 6.6332495807108005, 6.674578638386097, 6.715653356152327, 6.756478372643548, 6.797058187186572, 6.837397165588672, 6.87749954561976, 6.917369442208505, 6.957010852370435, 6.996427659884722, 7.035623639735144, 7.074602462329597, 7.113367697511497, 7.15192281837549, 7.1902712048990205, 7.2284161474004796, 7.266360849833981, 7.30410843293006, 7.341661937191061, 7.379024325749307, 7.416198487095664, 7.4531872376856345], [0.0, 0.7483314773547883, 1.058300524425836, 1.2961481396815722, 1.4966629547095767, 1.6733200530681511, 1.833030277982336, 1.9798989873223332, 2.116601048851672, 2.244994432064365, 2.3664319132398464, 2.4819347291981715, 2.5922962793631443, 2.6981475126464085, 2.8, 2.8982753492378874, 2.9933259094191533, 3.0854497241083023, 3.1749015732775088, 3.2619012860600183, 3.3466401061363023, 3.4292856398964493, 3.509985754956849, 3.5888716889852725, 3.666060555964672, 3.7416573867739413, 3.8157568056677826, 3.8884444190447165, 3.9597979746446663, 4.029888335921977, 4.098780306383839, 4.166533331199932, 4.233202097703344, 4.298837052040936, 4.363484845854286, 4.427188724235731, 4.48998886412873, 4.551922670696417, 4.613025037868319, 4.673328578219169, 4.732863826479693, 4.791659420284376, 4.849742261192857, 4.907137658554118, 4.963869458396343, 5.0199601592044525, 5.075431016179809, 5.130302135352264, 5.184592558726289, 5.238320341483518, 5.291502622129181, 5.344155686354956, 5.396295025292817, 5.447935388750495, 5.499090833947008, 5.549774770204643, 5.6, 5.649778756730214, 5.6991227395100035, 5.748043145279965, 5.796550698475775, 5.844655678480983, 5.892367945062493, 5.939696961966999, 5.986651818838307, 6.033241251599342, 6.079473661428265, 6.125357132445422, 6.170899448216605, 6.216108107168021, 6.260990336999411, 6.305553108173778, 6.3498031465550175, 6.393746945258312, 6.437390775772432, 6.48074069840786, 6.523802572120037, 6.566582063752802, 6.609084656743323, 6.6513156593263565, 6.6932802122726045, 6.734983296193095, 6.776429738438967, 6.817624219623724, 6.858571279792899, 6.899275324264136, 6.939740629158989, 6.979971346646059, 7.019971509913698, 7.059745037889116, 7.099295739719539, 7.138627319029899, 7.177743377970545, 7.216647421067487, 7.255342858886822, 7.293833011524187, 7.332121111929344, 7.370210309075312, 7.408103670980854, 7.445804187594514, 7.483314773547883, 7.520638270785267], [0.0, 0.754983443527075, 1.0677078252031311, 1.3076696830622023, 1.50996688705415, 1.6881943016134133, 1.849324200890693, 1.997498435543818, 2.1354156504062622, 2.264950330581225, 2.3874672772626644, 2.503996805109783, 2.6153393661244047, 2.72213151776324, 2.824889378365107, 2.924038303442689, 3.0199337741083, 3.1128764832546763, 3.2031234756093934, 3.290896534380867, 3.3763886032268267, 3.459768778401239, 3.5411862419251547, 3.620773398046335, 3.698648401781386, 3.774917217635375, 3.849675310984032, 3.9230090491866063, 3.994996871087636, 4.065710270051224, 4.135214625627066, 4.20356991139674, 4.2708313008125245, 4.337049688440288, 4.402272140611028, 4.466542286825459, 4.52990066116245, 4.592385001282014, 4.654030511288038, 4.7148700936505135, 4.774934554525329, 4.8342527861087286, 4.892851929090027, 4.950757517794625, 5.007993610219566, 5.064582904840239, 5.120546845796843, 5.175905717843014, 5.230678732248809, 5.2848841046895245, 5.338539126015656, 5.391660226683429, 5.44426303552648, 5.496362433464519, 5.547972602672079, 5.599107071667768, 5.649778756730214, 5.7, 5.749782604586021, 5.799137866959191, 5.848076606885378, 5.8966091951222275, 5.944745579080739, 5.9924953066314535, 6.0398675482166, 6.08687111741328, 6.133514490078261, 6.17980582219215, 6.2257529665093525, 6.271363488110062, 6.316644678941503, 6.361603571427569, 6.406246951218787, 6.450581369148055, 6.494613152451807, 6.5383484153110105, 6.581793068761734, 6.624952830020755, 6.667833231267862, 6.710439627923047, 6.752777206453653, 6.794850991743675, 6.836665854054885, 6.878226515607057, 6.919537556802478, 6.960603422117942, 7.001428425685718, 7.042016756583302, 7.0823724838503095, 7.122499561249548, 7.162401831787993, 7.202083032012336, 7.24154679609267, 7.280796659706959, 7.31983606373804, 7.358668357794092, 7.397296803562772, 7.4357245780085215, 7.473954776421918, 7.5119904153293495, 7.54983443527075, 7.587489703452652], [0.0, 0.7615773105863909, 1.0770329614269007, 1.3190905958272923, 1.5231546211727818, 1.7029386365926404, 1.8654758106177631, 2.0149441679609885, 2.1540659228538015, 2.2847319317591723, 2.4083189157584592, 2.525866188063018, 2.6381811916545845, 2.7459060435491964, 2.8495613697550017, 2.9495762407505253, 3.0463092423455636, 3.1400636936215167, 3.2310988842807027, 3.319638534539567, 3.405877273185281, 3.48998567332303, 3.5721142198983507, 3.6523964735499352, 3.7309516212355263, 3.8078865529319548, 3.8832975677895205, 3.957271787481876, 4.029888335921977, 4.101219330881976, 4.171330722922842, 4.240283009422838, 4.308131845707603, 4.374928570845472, 4.440720662234904, 4.505552130427525, 4.569463863518345, 4.632493928760188, 4.694677837722201, 4.756048780237647, 4.8166378315169185, 4.876474136094644, 4.935585071701227, 4.993996395673509, 5.051732376126036, 5.10881590977792, 5.165268628057984, 5.221110992882646, 5.276362383309169, 5.331041174104736, 5.385164807134505, 5.43874985635486, 5.491812087098393, 5.5443665102516455, 5.596427431853289, 5.648008498577176, 5.6991227395100035, 5.749782604586021, 5.800000000000001, 5.849786320883866, 5.8991524815010505, 5.948108943185221, 5.99666574022598, 6.044832503882966, 6.092618484691127, 6.1400325732035, 6.187083319303208, 6.23377895020348, 6.280127387243033, 6.326136261573885, 6.3718129288295975, 6.417164482853779, 6.462197768561405, 6.5069193939989765, 6.55133574166368, 6.59545297913646, 6.639277069079134, 6.682813778641449, 6.726068688320096, 6.76904720030818, 6.811754546370562, 6.854195795277518, 6.8963758598266685, 6.938299503480662, 6.97997134664606, 7.021395872616784, 7.062577433203831, 7.103520254071217, 7.144228439796701, 7.184705978674423, 7.224956747275378, 7.264984514780469, 7.3047929470998705, 7.3443856107914165, 7.383765976789894, 7.4229374239582535, 7.4619032424710525, 7.5006666370396715, 7.539230729988306, 7.577598564189055, 7.6157731058639095, 7.653757247260983], [0.0, 0.7681145747868608, 1.0862780491200215, 1.3304134695650072, 1.5362291495737217, 1.7175564037317668, 1.8814887722226779, 2.0322401432901573, 2.172556098240043, 2.3043437243605824, 2.4289915602982237, 2.5475478405713994, 2.6608269391300143, 2.7694764848252458, 2.8740215726399825, 2.974894956128703, 3.0724582991474434, 3.167017524422623, 3.2588341473600644, 3.3481338085566414, 3.4351128074635335, 3.5199431813596083, 3.602776706930364, 3.6837480912787726, 3.7629775444453557, 3.840572873934304, 3.916631205513228, 3.9912404086950213, 4.064480286580315, 4.136423575989287, 4.207136793592525, 4.276680956068619, 4.345112196480086, 4.412482294582042, 4.4788391353117385, 4.544227107000705, 4.608687448721165, 4.672258554489466, 4.734976240700686, 4.796873982084583, 4.857983120596447, 4.9183330509431755, 4.9779513858614575, 5.03686410378521, 5.095095681142799, 5.1526692111953, 5.209606511052442, 5.265928218272634, 5.321653878260029, 5.376802023508025, 5.431390245600108, 5.485435260760991, 5.5389529696504916, 5.591958512006326, 5.644466316668034, 5.6964901474504455, 5.748043145279965, 5.799137866959191, 5.849786320883866, 5.8999999999999995, 5.949789912257406, 5.999166608788257, 6.048140210014975, 6.096720429870472, 6.144916598294887, 6.192737682156413, 6.240192304729077, 6.287288763847259, 6.334035048845246, 6.380438856379708, 6.4265076052238514, 6.472248450113762, 6.517668294720129, 6.562773803811921, 6.607571414672716, 6.652067347825035, 6.696267617113283, 6.740178039191546, 6.783804242458652, 6.827151675479314, 6.870225614927067, 6.913031173081747, 6.955573304911681, 6.997856814768361, 7.0398863627192165, 7.0816664705420855, 7.123201527403251, 7.164495795239188, 7.205553413860728, 7.246378405796926, 7.286974680894671, 7.327346040688948, 7.367496182557545, 7.407428703673091, 7.447147104764348, 7.486654793697916, 7.525955088890711, 7.565051222562872, 7.603946343840151, 7.642643521714199, 7.681145747868608, 7.719455939378112], [0.0, 0.7745966692414833, 1.0954451150103321, 1.3416407864998738, 1.5491933384829666, 1.7320508075688772, 1.8973665961010275, 2.0493901531919194, 2.1908902300206643, 2.3237900077244498, 2.449489742783178, 2.569046515733026, 2.6832815729997477, 2.792848008753788, 2.8982753492378874, 2.9999999999999996, 3.098386676965933, 3.1937438845342623, 3.2863353450309964, 3.3763886032268267, 3.4641016151377544, 3.5496478698597693, 3.63318042491699, 3.714835124201342, 3.794733192202055, 3.8729833462074166, 3.9496835316262997, 4.024922359499621, 4.098780306383839, 4.171330722922842, 4.242640687119285, 4.3127717305695645, 4.381780460041329, 4.449719092257398, 4.516635916254486, 4.58257569495584, 4.6475800154488995, 4.711687595755898, 4.774934554525329, 4.8373546489791295, 4.898979485566356, 4.959838707054898, 5.019960159204453, 5.079370039680117, 5.138093031466052, 5.196152422706631, 5.253570214625478, 5.310367218940701, 5.366563145999495, 5.422176684690383, 5.477225575051661, 5.531726674375732, 5.585696017507576, 5.639148871948674, 5.692099788303082, 5.744562646538029, 5.796550698475775, 5.848076606885378, 5.8991524815010505, 5.949789912257406, 5.999999999999999, 6.049793384901669, 6.099180272790762, 6.148170459575758, 6.196773353931866, 6.244997998398397, 6.292853089020909, 6.340346993658943, 6.387487769068525, 6.434283176858164, 6.48074069840786, 6.526867548832287, 6.572670690061993, 6.618156843109718, 6.663332499583071, 6.7082039324993685, 6.752777206453653, 6.797058187186571, 6.841052550594828, 6.884765791223402, 6.928203230275509, 6.97137002317335, 7.014271166700073, 7.056911505750939, 7.099295739719539, 7.1414284285428495, 7.183313998427188, 7.224956747275377, 7.26636084983398, 7.307530362578043, 7.348469228349534, 7.389181280764466, 7.429670248402684, 7.469939758793239, 7.5099933422074345, 7.549834435270749, 7.58946638440411, 7.628892449104261, 7.668115805072325, 7.707139547199078, 7.745966692414833, 7.784600182411426], [0.0, 0.7810249675906654, 1.104536101718726, 1.3527749258468684, 1.5620499351813308, 1.746424919657298, 1.9131126469708992, 2.0663978319771825, 2.209072203437452, 2.3430749027719964, 2.4698178070456938, 2.5903667693977237, 2.705549851693737, 2.816025568065745, 2.9223278392404914, 3.0248966924508345, 3.1240998703626617, 3.2202484376209237, 3.3136083051561784, 3.4044089061098406, 3.492849839314596, 3.5791060336346563, 3.6633318168028404, 3.745664160065609, 3.8262252939417984, 3.9051248379533274, 3.9824615503479754, 4.058324777540605, 4.132795663954365, 4.205948168962618, 4.277849927241487, 4.34856298103178, 4.418144406874904, 4.486646854834912, 4.5541190146942805, 4.620606020859168, 4.686149805543993, 4.750789408087881, 4.814561246884289, 4.87749935930288, 4.9396356140913875, 5.000999900019996, 5.061620293937506, 5.121523210920751, 5.180733538795447, 5.239274758971893, 5.297169055259611, 5.354437412091022, 5.411099703387474, 5.467174773134658, 5.522680508593631, 5.577633906953737, 5.63205113613149, 5.6859475903318, 5.739337940912697, 5.792236183029832, 5.844655678480983, 5.8966091951222275, 5.948108943185221, 5.999166608788257, 6.049793384901669, 6.1, 6.149796744608719, 6.199193495931548, 6.248199740725323, 6.296824596572465, 6.345076831686122, 6.392964883369843, 6.440496875241847, 6.487680633323437, 6.534523701081817, 6.5810333535091585, 6.627216610312357, 6.673080248281149, 6.71863081289633, 6.7638746292343415, 6.808817812219681, 6.853466276272176, 6.897825744392215, 6.941901756723442, 6.985699678629192, 7.029224708315989, 7.07248188403477, 7.115476090888086, 7.158212067269313, 7.200694410957877, 7.242927584892728, 7.284915922644544, 7.326663633605681, 7.368174807915458, 7.409453421137082, 7.450503338701353, 7.491328320131218, 7.531932023060219, 7.572318007057021, 7.6124897372673015, 7.652450587883597, 7.692203845452876, 7.731752712031082, 7.771100308193172, 7.810249675906655, 7.849203781276163], [0.0, 0.787400787401181, 1.1135528725660042, 1.3638181696985856, 1.574801574802362, 1.760681686165901, 1.928730152198591, 2.083266665599966, 2.2271057451320084, 2.362202362203543, 2.4899799195977463, 2.6115129714401193, 2.727636339397171, 2.839013913315678, 2.9461839725312466, 3.049590136395381, 3.149603149604724, 3.246536616149585, 3.340658617698013, 3.432200460346103, 3.521363372331802, 3.608323710533743, 3.6932370625238775, 3.7762415176998414, 3.857460304397182, 3.9370039370059056, 4.014971979976946, 4.091454509095756, 4.166533331199932, 4.240283009422838, 4.3127717305695645, 4.384062043356595, 4.454211490264017, 4.523273151159457, 4.591296113299598, 4.658325879540846, 4.724404724407086, 4.789572005931219, 4.853864439804639, 4.917316341257699, 4.979959839195493, 5.041825066382213, 5.10294032886923, 5.163332257370234, 5.223025942880239, 5.282045058497702, 5.340411969127476, 5.3981478305063115, 5.455272678794342, 5.511805511808268, 5.5677643628300215, 5.62316636780382, 5.678027826631356, 5.732364259186606, 5.786190456595773, 5.839520528262573, 5.892367945062493, 5.944745579080739, 5.99666574022598, 6.048140210014975, 6.099180272790762, 6.149796744608719, 6.199999999999999, 6.249799996799897, 6.299206299209448, 6.348228099241551, 6.39687423668779, 6.445153217728807, 6.49307323229917, 6.540642170307133, 6.587867636800241, 6.6347569661593475, 6.681317235396026, 6.727555276621664, 6.773477688750439, 6.819090848492928, 6.864400920692206, 6.90941386804988, 6.954135460285484, 6.998571282769077, 7.042726744663604, 7.08660708661063, 7.130217387990355, 7.173562573784381, 7.216647421067486, 7.259476565152615, 7.302054505411474, 7.344385610791416, 7.386474125047755, 7.428324171709255, 7.469939758793239, 7.511324783285569, 7.552483035399683, 7.593418202627852, 7.634133873596926, 7.674633541739956, 7.714920608794364, 7.754998388136519, 7.79487010796203, 7.834538914320357, 7.874007874011811, 7.913279977354524], [0.0, 0.7937253933193772, 1.1224972160321824, 1.3747727084867523, 1.5874507866387544, 1.7748239349298849, 1.9442222095223582, 2.1, 2.244994432064365, 2.3811761799581315, 2.5099800796022267, 2.632489316217637, 2.7495454169735045, 2.861817604250837, 2.9698484809834995, 3.074085229787879, 3.1749015732775088, 3.2726136343907144, 3.3674916480965473, 3.4597687784012394, 3.5496478698597698, 3.6373066958946425, 3.722902093797257, 3.8065732621348563, 3.8884444190447165, 3.968626966596886, 4.047221268969613, 4.124318125460256, 4.2, 4.274342054632503, 4.347413023856832, 4.419275958796871, 4.48998886412873, 4.559605246071199, 4.628174586162454, 4.695742752749559, 4.762352359916263, 4.828043081829325, 4.892851929090027, 4.956813492557492, 5.019960159204453, 5.082322303829225, 5.143928459844674, 5.204805471869242, 5.264978632435274, 5.324471804789654, 5.383307533477908, 5.441507144165117, 5.499090833947009, 5.55607775323564, 5.612486080160912, 5.668333088307356, 5.723635208501674, 5.7784080852774675, 5.8326666285670745, 5.886425061104576, 5.939696961966999, 5.9924953066314535, 6.044832503882966, 6.096720429870472, 6.148170459575758, 6.199193495931548, 6.249799996799897, 6.3, 6.3498031465550175, 6.3992187023104625, 6.448255578061403, 6.496922348312315, 6.545227268781429, 6.593178292750774, 6.640783086353597, 6.688049042882386, 6.734983296193095, 6.7815927332743895, 6.827884006044625, 6.87386354243376, 6.919537556802479, 6.96491205974634, 7.009992867328754, 7.0547856097829085, 7.0992957397195395, 7.143528539874395, 7.187489130426565, 7.23118247591637, 7.274613391789285, 7.317786550590281, 7.3607064878311785, 7.40337760755184, 7.445804187594514, 7.487990384609211, 7.52994023880668, 7.571657678474378, 7.6131465242697125, 7.654410493303845, 7.695453203028396, 7.736278174936576, 7.776888838089433, 7.817288532477231, 7.857480512225277, 7.897467948652911, 7.937253933193772, 7.976841480185], [0.0, 0.8, 1.131370849898476, 1.385640646055102, 1.6, 1.788854381999832, 1.9595917942265426, 2.1166010488516727, 2.262741699796952, 2.4, 2.5298221281347035, 2.65329983228432, 2.771281292110204, 2.8844410203711917, 2.9933259094191533, 3.098386676965933, 3.2, 3.2984845004941286, 3.394112549695428, 3.4871191548325395, 3.577708763999664, 3.6660605559646724, 3.752332607858744, 3.836665218650176, 3.9191835884530852, 4.0, 4.079215610874228, 4.156921938165306, 4.233202097703345, 4.308131845707604, 4.381780460041329, 4.454211490264018, 4.525483399593904, 4.595650117230424, 4.664761515876241, 4.732863826479693, 4.8, 4.866210024238576, 4.931531202375181, 4.9959983987187195, 5.059644256269407, 5.122499389946279, 5.184592558726289, 5.2459508194416005, 5.30659966456864, 5.366563145999495, 5.4258639865002145, 5.4845236803208355, 5.542562584220408, 5.6000000000000005, 5.656854249492381, 5.713142742834281, 5.768882040742383, 5.8240879114244155, 5.878775382679628, 5.932958789676531, 5.986651818838307, 6.0398675482166, 6.092618484691127, 6.144916598294887, 6.196773353931866, 6.248199740725323, 6.299206299209448, 6.3498031465550175, 6.4, 6.449806198638839, 6.499230723708768, 6.5482822174979605, 6.596969000988257, 6.64529909033446, 6.6932802122726045, 6.740919818541087, 6.788225099390856, 6.835202996254025, 6.881860213634101, 6.92820323027551, 6.974238309665079, 7.019971509913698, 7.065408693062278, 7.110555533852471, 7.155417527999328, 7.2, 7.244308110509934, 7.288346863315439, 7.332121111929345, 7.37563556583431, 7.418894796396564, 7.4619032424710525, 7.504665215717488, 7.547184905645283, 7.58946638440411, 7.631513611335565, 7.673330437300352, 7.7149206087943645, 7.756287771866127, 7.797435475847171, 7.8383671769061705, 7.879086241436885, 7.919595949289333, 7.959899496852961, 8.0, 8.039900496896713], [0.0, 0.8062257748298549, 1.1401754250991378, 1.3964240043768943, 1.6124515496597098, 1.8027756377319946, 1.9748417658131499, 2.133072900770154, 2.2803508501982757, 2.4186773244895647, 2.5495097567963922, 2.6739483914241875, 2.7928480087537886, 2.9068883707497264, 3.016620625799671, 3.1224989991991987, 3.2249030993194197, 3.324154027718932, 3.420526275297414, 3.5142566781611158, 3.605551275463989, 3.6945906403822333, 3.7815340802378072, 3.866522985836241, 3.9496835316262997, 4.031128874149275, 4.110960958218893, 4.189272013130682, 4.266145801540308, 4.341658669218482, 4.415880433163923, 4.488875137492688, 4.560701700396551, 4.631414470763764, 4.701063709417263, 4.769696007084728, 4.8373546489791295, 4.904079934095691, 4.969909455915671, 5.034878350069642, 5.0990195135927845, 5.162363799656123, 5.224940191045253, 5.28677595515452, 5.347896782848375, 5.4083269131959835, 5.468089245796926, 5.527205442174191, 5.585696017507577, 5.643580423808984, 5.70087712549569, 5.757603668193913, 5.813776741499453, 5.869412236331676, 5.924525297439449, 5.979130371550699, 6.033241251599342, 6.08687111741328, 6.1400325732035, 6.192737682156413, 6.244997998398397, 6.296824596572465, 6.348228099241551, 6.3992187023104625, 6.449806198638839, 6.499999999999999, 6.549809157525125, 6.599242380758566, 6.648308055437864, 6.697014260101287, 6.745368781616021, 6.793379129711516, 6.841052550594828, 6.888396039717809, 6.93541635375988, 6.98212002188447, 7.0285133563222315, 7.074602462329597, 7.12039324756716, 7.165891430938652, 7.211102550927978, 7.256031973468694, 7.300684899377592, 7.345066371381541, 7.389181280764467, 7.433034373659253, 7.476630257007497, 7.519973404208288, 7.5630681604756145, 7.6059187479225665, 7.648529270389177, 7.6909037180295, 7.733045971672482, 7.774959806970066, 7.816648898345122, 7.858116822750854, 7.899367063252599, 7.940403012442127, 7.981227975693965, 8.021845174272563, 8.06225774829855, 8.10246875958186], [0.0, 0.812403840463596, 1.1489125293076057, 1.4071247279470291, 1.624807680927192, 1.8165902124584952, 1.98997487421324, 2.149418526020468, 2.2978250586152114, 2.437211521390788, 2.569046515733026, 2.6944387170614963, 2.8142494558940583, 2.9291637031753623, 3.0397368307141326, 3.1464265445104544, 3.249615361854384, 3.3496268448888453, 3.4467375879228173, 3.541186241925155, 3.6331804249169903, 3.722902093797257, 3.81051177665153, 3.8961519477556315, 3.97994974842648, 4.06201920231798, 4.142463035441596, 4.221374183841087, 4.298837052040936, 4.374928570845472, 4.449719092257397, 4.523273151159456, 4.595650117230423, 4.666904755831214, 4.737087712930805, 4.806245936279166, 4.874423042781576, 4.941659640242335, 5.007993610219566, 5.073460357586329, 5.138093031466052, 5.201922721455982, 5.264978632435274, 5.3272882407468805, 5.388877434122993, 5.449770637375485, 5.509990925582365, 5.569560126257728, 5.628498911788117, 5.686826883245172, 5.744562646538029, 5.801723881744115, 5.858327406350725, 5.914389233048499, 5.96992462263972, 6.024948132556827, 6.079473661428265, 6.133514490078261, 6.187083319303208, 6.240192304729077, 6.292853089020909, 6.345076831686122, 6.39687423668779, 6.448255578061403, 6.499230723708768, 6.549809157525125, 6.6, 6.649812027418519, 6.699253689777691, 6.748333127521196, 6.797058187186572, 6.8454364360499325, 6.8934751758456345, 6.941181455631311, 6.988562083862459, 7.035623639735144, 7.08237248385031, 7.128814768248646, 7.17495644586084, 7.2208032794142785, 7.266360849833981, 7.311634564172365, 7.356629663099809, 7.401351227985333, 7.445804187594514, 7.489993324429602, 7.533923280734945, 7.577598564189054, 7.62102355330306, 7.664202502543888, 7.707139547199077, 7.749838707999025, 7.792303895511263, 7.834538914320357, 7.8765474670060875, 7.918333157931661, 7.95989949685296, 8.001249902359007, 8.04238770515324, 8.083316151184489, 8.12403840463596, 8.16455755078008], [0.0, 0.8185352771872451, 1.1575836902790224, 1.4177446878757827, 1.6370705543744901, 1.8303005217723127, 2.004993765576342, 2.1656407827707715, 2.315167380558045, 2.455605831561735, 2.588435821108957, 2.714774392099646, 2.8354893757515653, 2.951270912674741, 3.062678566222711, 3.1701734968294715, 3.2741411087489802, 3.374907406137241, 3.4727510708370675, 3.567912554982255, 3.6606010435446255, 3.7509998667022106, 3.8392707640904935, 3.9255572852781047, 4.009987531152684, 4.092676385936225, 4.173727350941841, 4.253234063627348, 4.331281565541543, 4.407947368106838, 4.483302354291978, 4.557411546042337, 4.63033476111609, 4.702127178203499, 4.77283982551269, 4.8425200051213, 4.91121166312347, 4.978955713801841, 5.045790324617146, 5.111751167652823, 5.176871642217914, 5.241183072551464, 5.304714883949938, 5.367494760127856, 5.429548784199292, 5.490901565316937, 5.551576352712804, 5.61159513863928, 5.670978751503131, 5.729746940310715, 5.787918451395113, 5.845511098270194, 5.902541825349482, 5.959026766175833, 6.014981296729027, 6.070420084310475, 6.125357132445422, 6.17980582219215, 6.23377895020348, 6.287288763847259, 6.340346993658943, 6.392964883369843, 6.445153217728807, 6.496922348312315, 6.5482822174979605, 6.599242380758566, 6.649812027418519, 6.7, 6.749814812274482, 6.79926466612383, 6.848357467305573, 6.897100840208152, 6.945502141674135, 6.993568473962345, 7.041306696913577, 7.088723439378913, 7.13582510996451, 7.182617907142214, 7.229107828771128, 7.275300681071539, 7.321202087089251, 7.366817494685205, 7.4121521840825695, 7.457211275000863, 7.501999733404421, 7.546522377890362, 7.590783885739338, 7.634788798650556, 7.678541528180987, 7.722046360907191, 7.76530746332687, 7.808328886515987, 7.851114570556209, 7.893668348746355, 7.935993951610599, 7.978095010715276, 8.019975062305368, 8.061637550770936, 8.103085831953157, 8.144323176298936, 8.18535277187245, 8.226177727231525], [0.0, 0.8246211251235321, 1.16619037896906, 1.4282856857085702, 1.6492422502470643, 1.8439088914585775, 2.0199009876724157, 2.181742422927143, 2.33238075793812, 2.473863375370596, 2.6076809620810595, 2.734958866235469, 2.8565713714171403, 2.973213749463701, 3.0854497241083023, 3.1937438845342623, 3.2984845004941286, 3.4, 3.4985711369071804, 3.594440151122286, 3.687817782917155, 3.778888725538237, 3.867815921162743, 3.954743986657038, 4.039801975344831, 4.123105625617661, 4.204759208325728, 4.28485705712571, 4.363484845854286, 4.440720662234904, 4.516635916254486, 4.591296113299599, 4.66476151587624, 4.737087712930805, 4.8083261120685235, 4.878524367060187, 4.947726750741192, 5.015974481593781, 5.083306010855534, 5.149757275833494, 5.215361924162119, 5.280151512977635, 5.344155686354956, 5.407402333838309, 5.469917732470938, 5.531726674375732, 5.592852581643825, 5.653317610041028, 5.713142742834281, 5.772347875864725, 5.830951894845301, 5.888972745734184, 5.946427498927402, 6.003332407921454, 6.059702963017247, 6.115553940568263, 6.170899448216605, 6.2257529665093525, 6.280127387243033, 6.334035048845246, 6.387487769068525, 6.440496875241847, 6.49307323229917, 6.545227268781429, 6.596969000988257, 6.648308055437864, 6.699253689777691, 6.749814812274482, 6.8, 6.849817515817484, 6.899275324264137, 6.948381106416083, 6.997142273814361, 7.045565981523414, 7.093659140387279, 7.14142842854285, 7.188880302244572, 7.236021006050217, 7.282856582413251, 7.329392880723478, 7.37563556583431, 7.42159012611179, 7.467261881037788, 7.512655988397179, 7.557777451076474, 7.602631123499285, 7.647221717722065, 7.691553809211764, 7.735631842325486, 7.779460135510689, 7.8230428862431785, 7.866384175718855, 7.909487973314076, 7.952358140828418, 7.994998436522675, 8.037412518964047, 8.079603950689663, 8.121576201698781, 8.16333265278342, 8.204876598706406, 8.246211251235321, 8.287339742040265], [0.0, 0.8306623862918076, 1.174734012447073, 1.4387494569938162, 1.661324772583615, 1.8574175621006712, 2.0346989949375804, 2.1977260975835913, 2.349468024894146, 2.4919871588754225, 2.6267851073127395, 2.7549954627911823, 2.8774989139876324, 2.994995826374388, 3.1080540535840107, 3.217141588429082, 3.32264954516723, 3.424908757908742, 3.5242020373412193, 3.6207733980463352, 3.7148351242013424, 3.8065732621348563, 3.8961519477556315, 3.9837168574084183, 4.069397989875161, 4.153311931459037, 4.235563716909475, 4.316248370981448, 4.3954521951671826, 4.473253849269009, 4.54972526643093, 4.624932431938872, 4.698936049788292, 4.77179211617606, 4.843552415324934, 4.914264950122246, 4.983974317750845, 5.052722038663912, 5.120546845796843, 5.187484939737176, 5.253570214625479, 5.3188344587888805, 5.383307533477909, 5.447017532558529, 5.509990925582365, 5.572252686302012, 5.63382640840131, 5.69473440996154, 5.754997827975265, 5.814636704042653, 5.873670062235366, 5.932115979985557, 5.989991652748776, 6.047313453096343, 6.104096984812742, 6.1603571325045765, 6.216108107168021, 6.271363488110062, 6.326136261573885, 6.380438856379708, 6.434283176858164, 6.487680633323437, 6.540642170307133, 6.593178292750774, 6.64529909033446, 6.697014260101287, 6.748333127521196, 6.79926466612383, 6.849817515817484, 6.9, 6.949820141557622, 6.999285677838847, 7.048404074682439, 7.097182539571601, 7.145628033979938, 7.19374728496908, 7.2415467960926705, 7.289032857656769, 7.336211556382492, 7.383088784512889, 7.429670248402685, 7.475961476626268, 7.521967827636597, 7.567694497005016, 7.6131465242697125, 7.658328799418317, 7.703246069028303, 7.747902942086975, 7.792303895511263, 7.836453279386026, 7.880355321938218, 7.924014134263013, 7.967433714816837, 8.010617953691215, 8.053570636680355, 8.096295449154509, 8.138795979750322, 8.18107572388864, 8.223138087129511, 8.264986388373547, 8.306623862918075, 8.34805366537614], [0.0, 0.8366600265340756, 1.1832159566199232, 1.4491376746189442, 1.6733200530681511, 1.8708286933869709, 2.04939015319192, 2.2135943621178655, 2.3664319132398464, 2.5099800796022267, 2.6457513110645907, 2.774887385102322, 2.8982753492378883, 3.0166206257996717, 3.1304951684997055, 3.24037034920393, 3.3466401061363023, 3.4496376621320683, 3.5496478698597698, 3.6469165057620945, 3.7416573867739418, 3.834057902536163, 3.924283374069717, 4.012480529547776, 4.09878030638384, 4.183300132670378, 4.266145801540309, 4.3474130238568325, 4.427188724235731, 4.505552130427525, 4.58257569495584, 4.658325879540847, 4.732863826479693, 4.806245936279167, 4.878524367060187, 4.949747468305833, 5.019960159204453, 5.089204259999789, 5.157518783291051, 5.2249401910452535, 5.291502622129181, 5.35723809439155, 5.422176684690385, 5.486346689738081, 5.549774770204644, 5.612486080160912, 5.674504383644443, 5.735852159879995, 5.796550698475777, 5.856620185738529, 5.916079783099617, 5.974947698515863, 6.033241251599343, 6.090976933136425, 6.148170459575759, 6.2048368229954285, 6.260990336999411, 6.316644678941503, 6.3718129288295975, 6.4265076052238514, 6.48074069840786, 6.534523701081817, 6.587867636800241, 6.640783086353597, 6.6932802122726045, 6.745368781616021, 6.797058187186572, 6.848357467305573, 6.899275324264137, 6.949820141557622, 7.000000000000001, 7.049822692805827, 7.0992957397195395, 7.148426400264607, 7.197221686178633, 7.24568837309472, 7.293833011524189, 7.341661937191062, 7.3891812807644675, 7.436396977031284, 7.4833147735478835, 7.529940238806681, 7.576278769950325, 7.622335600063802, 7.668115805072326, 7.713624310270757, 7.75886589650833, 7.803845206050669, 7.848566748139434, 7.893034904268446, 7.937253933193772, 7.981227975693966, 8.024961059095553, 8.068457101577724, 8.1117199162693, 8.154753215150045, 8.19756061276768, 8.240145629781066, 8.282511696339462, 8.324662155306966, 8.366600265340756, 8.408329203831164], [0.0, 0.8426149773176359, 1.1916375287812984, 1.4594519519326425, 1.6852299546352718, 1.8841443681416774, 2.0639767440550294, 2.2293496809607953, 2.3832750575625967, 2.5278449319529073, 2.6645825188948455, 2.7946377224964243, 2.918903903865285, 3.0380915061926625, 3.152776554086889, 3.2634337744161437, 3.3704599092705436, 3.4741905532080417, 3.5749125863438955, 3.672873534441392, 3.768288736283355, 3.861346915261565, 3.952214569073901, 4.041039470235351, 4.127953488110059, 4.2130748865881795, 4.296510211788167, 4.378355855797928, 4.458699361921591, 4.537620521815371, 4.61519230368573, 4.69148164229596, 4.766550115125193, 4.8404545241123795, 4.913247398615299, 4.984977432245807, 5.0556898639058145, 5.1254268114957995, 5.194227565288221, 5.262128846769148, 5.329165037789691, 5.395368384086485, 5.46076917659042, 5.525395913416522, 5.589275444992849, 5.652433104425031, 5.71489282489182, 5.776677245614472, 5.83780780773057, 5.898304841223451, 5.958187643906493, 6.017474553332154, 6.076183012385325, 6.134329629226001, 6.191930232165088, 6.248999919987198, 6.305553108173778, 6.361603571427569, 6.417164482853779, 6.472248450113762, 6.526867548832287, 6.5810333535091585, 6.6347569661593475, 6.688049042882386, 6.740919818541087, 6.793379129711516, 6.8454364360499325, 6.897100840208152, 6.948381106416083, 6.999285677838847, 7.049822692805827, 7.1, 7.149825172687791, 7.199305522062527, 7.248448109768049, 7.297259759663212, 7.345747068882784, 7.3939164182454755, 7.441773982055624, 7.489325737341113, 7.53657747256671, 7.583534795858723, 7.630203142774117, 7.676587783644501, 7.72269383052313, 7.768526243760782, 7.814089838234521, 7.859389289251424, 7.904429138147802, 7.949213797602879, 7.993747556684537, 8.038034585643434, 8.082078940470701, 8.125884567233282, 8.16945530620004, 8.212794895770866, 8.255906976220118, 8.298795093265047, 8.341462701469089, 8.383913167489272, 8.426149773176359, 8.468175718535841], [0.0, 0.848528137423857, 1.2, 1.4696938456699071, 1.697056274847714, 1.8973665961010278, 2.078460969082653, 2.244994432064365, 2.4, 2.545584412271571, 2.6832815729997477, 2.814249455894058, 2.9393876913398143, 3.0594117081556713, 3.1749015732775088, 3.2863353450309964, 3.394112549695428, 3.4985711369071804, 3.6, 3.6986484017813863, 3.7947331922020555, 3.8884444190447165, 3.97994974842648, 4.069397989875161, 4.156921938165306, 4.242640687119286, 4.3266615305567875, 4.409081537009721, 4.48998886412873, 4.5694638635183455, 4.6475800154489, 4.724404724407087, 4.8, 4.874423042781577, 4.947726750741193, 5.019960159204453, 5.091168824543142, 5.1613951602255765, 5.230678732248808, 5.299056519796709, 5.366563145999495, 5.43323108288245, 5.499090833947008, 5.564171097297422, 5.628498911788116, 5.692099788303082, 5.754997827975264, 5.817215828899595, 5.8787753826796285, 5.939696961966999, 6.0, 6.059702963017248, 6.118823416311343, 6.177378084592201, 6.235382907247959, 6.29285308902091, 6.3498031465550175, 6.406246951218787, 6.462197768561405, 6.517668294720129, 6.572670690061993, 6.627216610312357, 6.681317235396026, 6.734983296193095, 6.788225099390856, 6.841052550594828, 6.8934751758456345, 6.945502141674135, 6.997142273814361, 7.048404074682439, 7.0992957397195395, 7.149825172687791, 7.2, 7.249827584156743, 7.299315036357863, 7.3484692283495345, 7.397296803562773, 7.445804187594514, 7.493997598078079, 7.541883053985921, 7.589466384404111, 7.636753236814713, 7.68374908491942, 7.730459236035075, 7.776888838089433, 7.823042886243179, 7.868926229162401, 7.914543574963752, 7.95989949685296, 8.0049984384758, 8.049844718999243, 8.094442537939225, 8.138795979750322, 8.182909018191515, 8.226785520481254, 8.270429251254132, 8.313843876330612, 8.357032966310472, 8.4, 8.442748367682174, 8.485281374238571, 8.527602242131138], [0.0, 0.8544003745317531, 1.2083045973594573, 1.4798648586948744, 1.7088007490635062, 1.91049731745428, 2.092844953645635, 2.260530911091463, 2.4166091947189146, 2.563201123595259, 2.701851217221259, 2.833725463060951, 2.9597297173897488, 3.0805843601498726, 3.196873472629156, 3.309078421554859, 3.4176014981270124, 3.522782990761707, 3.6249137920783716, 3.7242448899072147, 3.82099463490856, 3.915354390090379, 4.007492981902776, 4.097560249709576, 4.18568990729127, 4.272001872658766, 4.356604182158393, 4.439594576084623, 4.521061822182926, 4.601086828130937, 4.679743582719036, 4.757099956906519, 4.833218389437829, 4.908156476723211, 4.98196748283246, 5.054700782440045, 5.126402247190518, 5.197114584074513, 5.266877632905477, 5.335728628781641, 5.403702434442518, 5.470831746635972, 5.537147279962851, 5.602677931132575, 5.667450926121902, 5.731491952362839, 5.794825277780168, 5.857473858242988, 5.9194594347794975, 5.980802621722272, 6.041522986797286, 6.101639124038721, 6.161168720299745, 6.220128616033596, 6.278534860936905, 6.336402764976356, 6.393746945258312, 6.450581369148055, 6.5069193939989765, 6.562773803811921, 6.618156843109718, 6.673080248281149, 6.727555276621664, 6.7815927332743895, 6.835202996254025, 6.888396039717809, 6.941181455631311, 6.993568473962345, 7.045565981523414, 7.097182539571601, 7.148426400264607, 7.199305522062527, 7.249827584156743, 7.3, 7.349829930005183, 7.399324293474371, 7.448489779814429, 7.4973328590906245, 7.545859791965394, 7.594076639065476, 7.64198926981712, 7.689603370785778, 7.736924453553881, 7.783957862167549, 7.830708780180758, 7.877182237323192, 7.923383115816122, 7.969316156358713, 8.014985963805552, 8.060397012554654, 8.105553651663778, 8.150460109711599, 8.195120499419152, 8.239538822045807, 8.283718971573094, 8.327664738688751, 8.37137981458254, 8.414867794564572, 8.4581321815162, 8.501176389182852, 8.544003745317532, 8.586617494683225], [0.0, 0.8602325267042626, 1.2165525060596438, 1.489966442575134, 1.7204650534085253, 1.9235384061671346, 2.1071307505705477, 2.2759613353482084, 2.4331050121192876, 2.580697580112788, 2.7202941017470885, 2.8530685235374214, 2.979932885150268, 3.1016124838541645, 3.218695387886216, 3.3316662497915357, 3.4409301068170506, 3.5468295701936396, 3.6496575181789317, 3.749666651850535, 3.847076812334269, 3.9420806688854046, 4.034848200366403, 4.125530268947254, 4.214261501141095, 4.301162633521313, 4.386342439892262, 4.469899327725402, 4.551922670696417, 4.632493928760188, 4.711687595755898, 4.789572005931219, 4.866210024238575, 4.941659640242335, 5.015974481593781, 5.089204259999788, 5.161395160225576, 5.232590180780452, 5.302829433425141, 5.372150407425317, 5.440588203494177, 5.508175741568165, 5.574943945906542, 5.6409219104681805, 5.706137047074843, 5.770615218501403, 5.834380858325929, 5.897457079114692, 5.959865770300536, 6.021627686929839, 6.082762530298219, 6.143289021363068, 6.203224967708329, 6.262587324740471, 6.321392251711643, 6.3796551630946325, 6.437390775772432, 6.494613152451807, 6.55133574166368, 6.607571414672716, 6.663332499583071, 6.71863081289633, 6.773477688750439, 6.827884006044625, 6.881860213634101, 6.93541635375988, 6.988562083862459, 7.041306696913577, 7.093659140387279, 7.145628033979938, 7.197221686178633, 7.248448109768049, 7.299315036357863, 7.349829930005183, 7.3999999999999995, 7.44983221287567, 7.49933330370107, 7.548509786706248, 7.597367965289032, 7.645913941446111, 7.694153624668538, 7.742092740338364, 7.789736837660179, 7.837091297158659, 7.884161337770809, 7.930952023559341, 7.977468270071652, 8.023714850367003, 8.069696400732806, 8.115417426109392, 8.160882305241266, 8.206095295571457, 8.251060537894508, 8.295782060782456, 8.340263784797218, 8.384509526501832, 8.42852300228219, 8.472307831990054, 8.515867542417507, 8.559205570612264, 8.602325267042627, 8.645229898620395], [0.0, 0.8660254037844387, 1.224744871391589, 1.5000000000000002, 1.7320508075688774, 1.9364916731037085, 2.121320343559643, 2.29128784747792, 2.449489742783178, 2.598076211353316, 2.7386127875258306, 2.8722813232690148, 3.0000000000000004, 3.122498999199199, 3.24037034920393, 3.3541019662496843, 3.464101615137755, 3.570714214271425, 3.6742346141747673, 3.7749172176353754, 3.872983346207417, 3.968626966596886, 4.06201920231798, 4.153311931459037, 4.242640687119286, 4.330127018922194, 4.415880433163924, 4.5, 4.58257569495584, 4.663689526544408, 4.743416490252569, 4.8218253804964775, 4.898979485566356, 4.974937185533101, 5.049752469181039, 5.123475382979799, 5.196152422706632, 5.26782687642637, 5.338539126015656, 5.408326913195984, 5.477225575051661, 5.545268253204709, 5.612486080160912, 5.678908345800274, 5.7445626465380295, 5.809475019311125, 5.873670062235366, 5.937171043518958, 6.000000000000001, 6.06217782649107, 6.123724356957946, 6.184658438426491, 6.244997998398398, 6.304760106459247, 6.363961030678928, 6.422616289332565, 6.48074069840786, 6.5383484153110105, 6.59545297913646, 6.652067347825035, 6.7082039324993685, 6.7638746292343415, 6.819090848492928, 6.87386354243376, 6.92820323027551, 6.98212002188447, 7.035623639735144, 7.088723439378913, 7.14142842854285, 7.19374728496908, 7.24568837309472, 7.297259759663212, 7.3484692283495345, 7.399324293474371, 7.44983221287567, 7.5, 7.549834435270751, 7.599342076785332, 7.6485292703891785, 7.697402159170327, 7.745966692414834, 7.794228634059948, 7.842193570679062, 7.88986691902975, 7.937253933193772, 7.984359711335657, 8.031189202104505, 8.077747210701757, 8.12403840463596, 8.170067319184096, 8.215838362577491, 8.261355820929154, 8.306623862918075, 8.351646544245034, 8.396427811873334, 8.440971508067065, 8.485281374238571, 8.529361054615991, 8.573214099741124, 8.616843969807043, 8.660254037844387, 8.703447592764606], [0.0, 0.8717797887081349, 1.2328828005937953, 1.5099668870541503, 1.7435595774162698, 1.9493588689617931, 2.1354156504062627, 2.3065125189341593, 2.4657656011875906, 2.615339366124404, 2.7568097504180447, 2.8913664589601926, 3.0199337741083006, 3.1432467291003428, 3.2619012860600183, 3.3763886032268267, 3.4871191548325395, 3.594440151122286, 3.6986484017813863, 3.8000000000000007, 3.8987177379235862, 3.9949968710876362, 4.0890096600521755, 4.180908992073375, 4.270831300812525, 4.358898943540674, 4.445222154178575, 4.529900661162451, 4.613025037868319, 4.694677837722201, 4.774934554525329, 4.8538644398046396, 4.931531202375181, 5.007993610219566, 5.083306010855535, 5.157518783291051, 5.230678732248808, 5.302829433425142, 5.374011537017762, 5.444263035526481, 5.513619500836089, 5.582114294781146, 5.649778756730215, 5.716642371182581, 5.782732917920385, 5.848076606885378, 5.912698199637794, 5.976621118993575, 6.039867548216601, 6.102458520956944, 6.164414002968978, 6.225752966509353, 6.2864934582006855, 6.3466526610489735, 6.406246951218788, 6.465291950097846, 6.523802572120037, 6.581793068761734, 6.639277069079134, 6.696267617113283, 6.752777206453653, 6.808817812219681, 6.864400920692206, 6.919537556802479, 6.974238309665079, 7.0285133563222315, 7.08237248385031, 7.13582510996451, 7.188880302244572, 7.2415467960926705, 7.293833011524189, 7.345747068882784, 7.397296803562773, 7.448489779814429, 7.49933330370107, 7.549834435270751, 7.600000000000001, 7.649836599562112, 7.6993506219680645, 7.748548251124208, 7.7974354758471724, 7.8460180983732135, 7.894301742396222, 7.942291860665913, 7.9899937421752725, 8.037412518964048, 8.084553172563096, 8.13142054010245, 8.178019320104351, 8.224354077980836, 8.270429251254134, 8.316249154516717, 8.36181798414675, 8.407139822793482, 8.452218643646177, 8.497058314499201, 8.54166260162505, 8.586035173466273, 8.630179604156568, 8.674099376880578, 8.717797887081348, 8.761278445523805], [0.0, 0.8774964387392122, 1.2409673645990857, 1.5198684153570665, 1.7549928774784245, 1.9621416870348585, 2.149418526020468, 2.32163735324878, 2.4819347291981715, 2.6324893162176366, 2.7748873851023217, 2.91032644217105, 3.039736830714133, 3.1638584039112754, 3.283291031876401, 3.3985290935932855, 3.509985754956849, 3.6180105030251086, 3.722902093797257, 3.824918299781056, 3.924283374069717, 4.02119385257662, 4.115823125451336, 4.2083250825001635, 4.298837052040936, 4.387482193696061, 4.474371464239419, 4.559605246071199, 4.64327470649756, 4.725462940284264, 4.806245936279166, 4.8856934001224435, 4.963869458396343, 5.040833264451424, 5.1166395221864125, 5.191338940966964, 5.264978632435273, 5.3376024580330075, 5.409251334519409, 5.479963503528103, 5.549774770204643, 5.61871871515206, 5.686826883245173, 5.754128952326321, 5.8206528843421, 5.886425061104575, 5.951470406546605, 6.015812497078014, 6.079473661428266, 6.142475071174486, 6.2048368229954285, 6.266578013557321, 6.327716807822551, 6.388270501473776, 6.448255578061404, 6.507687761409578, 6.566582063752802, 6.624952830020755, 6.682813778641449, 6.740178039191546, 6.797058187186571, 6.853466276272176, 6.90941386804988, 6.96491205974634, 7.019971509913698, 7.074602462329597, 7.128814768248646, 7.182617907142214, 7.236021006050217, 7.289032857656769, 7.341661937191062, 7.3939164182454755, 7.445804187594514, 7.4973328590906245, 7.548509786706248, 7.599342076785332, 7.649836599562112, 7.7, 7.749838707999026, 7.799358948016177, 7.848566748139434, 7.897467948652911, 7.9460682101275735, 7.994373021069257, 8.04238770515324, 8.090117428072352, 8.137567204023572, 8.184741901856162, 8.231646250902672, 8.278284846512591, 8.324662155306966, 8.370782520170978, 8.416650165000327, 8.462269199216012, 8.507643622061282, 8.55277732669336, 8.597674104081872, 8.64233764672499, 8.6867715521936, 8.73097932651315, 8.774964387392123, 8.81873006730561], [0.0, 0.8831760866327848, 1.2489995996796797, 1.5297058540778359, 1.7663521732655696, 1.9748417658131503, 2.1633307652783937, 2.336664289109585, 2.4979991993593593, 2.6495282598983545, 2.7928480087537886, 2.9291637031753623, 3.0594117081556718, 3.1843366656181322, 3.3045423283716615, 3.420526275297414, 3.532704346531139, 3.6414282912066254, 3.7469987990390394, 3.8496753109840323, 3.9496835316263006, 4.047221268969613, 4.1424630354415966, 4.235563716909475, 4.3266615305567875, 4.415880433163924, 4.503332099679082, 4.589117562233508, 4.67332857821917, 4.756048780237647, 4.83735464897913, 4.917316341257699, 4.995998398718719, 5.07346035758633, 5.149757275833494, 5.2249401910452535, 5.299056519796709, 5.372150407425318, 5.444263035526481, 5.515432893255072, 5.585696017507577, 5.655086206239478, 5.723635208501675, 5.791372894228104, 5.858327406350725, 5.92452529743945, 5.989991652748776, 6.054750201288242, 6.1188234163113435, 6.182232606429493, 6.244997998398399, 6.307138812488593, 6.3686733312362644, 6.429618962271405, 6.489992295835182, 6.549809157525127, 6.609084656743323, 6.667833231267862, 6.726068688320096, 6.783804242458652, 6.841052550594828, 6.897825744392215, 6.954135460285484, 7.009992867328754, 7.065408693062278, 7.12039324756716, 7.17495644586084, 7.229107828771128, 7.282856582413251, 7.336211556382492, 7.3891812807644675, 7.441773982055624, 7.493997598078079, 7.545859791965394, 7.597367965289032, 7.6485292703891785, 7.6993506219680645, 7.749838707999026, 7.800000000000002, 7.849840762716147, 7.899367063252601, 7.9485847796950635, 7.997499609252884, 8.046117075956577, 8.094442537939226, 8.142481194328914, 8.19023809177731, 8.23771813064759, 8.284926070883193, 8.33186653757728, 8.378544026261366, 8.424962907930219, 8.47112743381895, 8.517041739947036, 8.56270985144306, 8.608135686662937, 8.653323061113575, 8.698275691193055, 8.742997197757758, 8.787491109526087, 8.831760866327848, 8.875809822207776], [0.0, 0.8888194417315589, 1.2569805089976536, 1.5394804318340656, 1.7776388834631178, 1.9874606914351793, 2.177154105707724, 2.3515952032609695, 2.513961017995307, 2.6664583251946765, 2.8106938645110393, 2.9478805945967355, 3.078960863668131, 3.204684071792413, 3.3256578296631782, 3.442382895611701, 3.5552777669262356, 3.664696440361739, 3.7709415269929605, 3.874274125562104, 3.9749213828703587, 4.07308237088326, 4.168932717135166, 4.262628297189424, 4.354308211415448, 4.444097208657795, 4.532107677449864, 4.618441295502196, 4.703190406521939, 4.786439177509728, 4.868264577855234, 4.948737212663449, 5.027922035990614, 5.105878964487898, 5.182663407939976, 5.2583267300539625, 5.332916650389353, 5.406477596365309, 5.47905101272109, 5.550675634551168, 5.621387729022079, 5.691221310052879, 5.760208329565868, 5.8283788483591215, 5.895761189193471, 5.962382074305537, 6.028266749240615, 6.09343909463285, 6.157921727336262, 6.221736092120913, 6.284902544988268, 6.347440429023341, 6.409368143584826, 6.470703207534712, 6.5314623171231725, 6.591661399070799, 6.6513156593263565, 6.710439627923047, 6.76904720030818, 6.827151675479314, 6.884765791223402, 6.941901756723442, 6.998571282769077, 7.0547856097829085, 7.110555533852471, 7.165891430938652, 7.2208032794142785, 7.275300681071539, 7.329392880723478, 7.383088784512889, 7.436396977031284, 7.489325737341113, 7.541883053985921, 7.594076639065476, 7.645913941446111, 7.697402159170327, 7.748548251124208, 7.799358948016177, 7.849840762716147, 7.9, 7.949842765740717, 7.999374975584031, 8.048602363143555, 8.097530487747484, 8.14616474176652, 8.194510357550353, 8.242572413997951, 8.290355842785038, 8.337865434270332, 8.385105843100611, 8.432081593533118, 8.478797084492587, 8.525256594378847, 8.571464285639882, 8.61742420912421, 8.663140308225419, 8.708616422830897, 8.753856293085923, 8.798863562983575, 8.843641783790206, 8.88819441731559, 8.932524839036274], [0.0, 0.894427190999916, 1.2649110640673518, 1.549193338482967, 1.788854381999832, 2.0000000000000004, 2.1908902300206647, 2.366431913239847, 2.5298221281347035, 2.6832815729997477, 2.8284271247461903, 2.9664793948382657, 3.098386676965934, 3.22490309931942, 3.3466401061363023, 3.4641016151377544, 3.577708763999664, 3.687817782917155, 3.7947331922020555, 3.8987177379235862, 4.000000000000001, 4.09878030638384, 4.1952353926806065, 4.289522117905444, 4.3817804600413295, 4.47213595499958, 4.560701700396552, 4.647580015448901, 4.732863826479694, 4.8166378315169185, 4.898979485566357, 4.979959839195494, 5.059644256269407, 5.1380930314660525, 5.21536192416212, 5.291502622129181, 5.366563145999495, 5.440588203494178, 5.513619500836089, 5.585696017507577, 5.656854249492381, 5.727128425310542, 5.796550698475777, 5.865151319446072, 5.9329587896765315, 6.0, 6.066300355241241, 6.131883886702357, 6.196773353931868, 6.260990336999412, 6.324555320336759, 6.387487769068526, 6.44980619863884, 6.511528238439884, 6.572670690061994, 6.6332495807108005, 6.6932802122726045, 6.752777206453653, 6.811754546370562, 6.870225614927067, 6.928203230275509, 6.985699678629192, 7.042726744663604, 7.0992957397195395, 7.155417527999328, 7.211102550927978, 7.266360849833981, 7.321202087089251, 7.37563556583431, 7.429670248402685, 7.4833147735478835, 7.53657747256671, 7.589466384404111, 7.64198926981712, 7.694153624668538, 7.745966692414834, 7.7974354758471724, 7.848566748139434, 7.899367063252601, 7.949842765740717, 8.000000000000002, 8.049844718999244, 8.099382692526635, 8.148619514985345, 8.19756061276768, 8.246211251235321, 8.29457654133109, 8.342661445845685, 8.390470785361213, 8.438009243891594, 8.485281374238571, 8.532291603080617, 8.579044235810889, 8.62554346113913, 8.671793355471522, 8.717797887081348, 8.763560920082659, 8.809086218218098, 8.854377448471462, 8.899438184514796, 8.94427190999916, 8.988882021697695], [0.0, 0.9, 1.2727922061357855, 1.5588457268119897, 1.8, 2.012461179749811, 2.2045407685048604, 2.3811761799581315, 2.545584412271571, 2.7, 2.8460498941515415, 2.9849623113198605, 3.1176914536239795, 3.2449961479175906, 3.3674916480965473, 3.485685011586675, 3.6, 3.710795063055895, 3.8183766184073566, 3.9230090491866068, 4.024922359499622, 4.124318125460256, 4.221374183841087, 4.316248370981448, 4.409081537009721, 4.500000000000001, 4.589117562233507, 4.676537180435969, 4.762352359916263, 4.846648326421054, 4.929503017546495, 5.01098792654702, 5.091168824543142, 5.170106381884226, 5.247856705360771, 5.324471804789654, 5.4, 5.474486277268398, 5.547972602672079, 5.620498198558559, 5.692099788303083, 5.762811813689565, 5.832666628567075, 5.9016946718718, 5.969924622639721, 6.037383539249432, 6.104096984812742, 6.17008914036094, 6.235382907247959, 6.300000000000001, 6.3639610306789285, 6.427285585688566, 6.489992295835181, 6.552098900352467, 6.613622305514581, 6.674578638386097, 6.734983296193095, 6.794850991743675, 6.854195795277518, 6.913031173081747, 6.97137002317335, 7.029224708315989, 7.08660708661063, 7.143528539874395, 7.2, 7.256031973468694, 7.311634564172365, 7.366817494685205, 7.42159012611179, 7.475961476626268, 7.529940238806681, 7.583534795858723, 7.636753236814713, 7.689603370785778, 7.742092740338364, 7.794228634059948, 7.8460180983732135, 7.897467948652911, 7.9485847796950635, 7.999374975584031, 8.049844718999244, 8.100000000000001, 8.149846624323676, 8.19939022122987, 8.248636250920512, 8.2975900115636, 8.346256645946134, 8.394641147779934, 8.442748367682174, 8.490583018850943, 8.538149682454625, 8.58545281275251, 8.632496741962896, 8.67928568489366, 8.725823743349393, 8.772114910328067, 8.818163074019441, 8.863972021616496, 8.909545442950499, 8.95488693395958, 9.000000000000002, 9.044888059008803], [0.0, 0.9055385138137417, 1.2806248474865698, 1.5684387141358125, 1.8110770276274835, 2.024845673131659, 2.2181073012818837, 2.395829710142188, 2.5612496949731396, 2.716615541441225, 2.863564212655271, 3.003331483536242, 3.136877428271625, 3.264965543462902, 3.3882148692194836, 3.5071355833500366, 3.622154055254967, 3.733630940518894, 3.84187454245971, 3.947150871198111, 4.049691346263318, 4.149698784249287, 4.247352116319061, 4.342810150121694, 4.436214602563767, 4.527692569068709, 4.617358552246079, 4.705316142407438, 4.791659420284376, 4.876474136094644, 4.959838707054898, 5.041825066382213, 5.122499389946279, 5.201922721455982, 5.280151512977635, 5.35723809439155, 5.43323108288245, 5.508175741568166, 5.582114294781146, 5.655086206239478, 5.727128425310542, 5.798275605729691, 5.868560300448485, 5.938013135721409, 6.006662967072484, 6.074537019394977, 6.1416610131136355, 6.208059278067503, 6.27375485654325, 6.338769596696192, 6.403124237432849, 6.466838485689898, 6.529931086925804, 6.592419889539805, 6.654321903845651, 6.715653356152327, 6.776429738438967, 6.836665854054885, 6.8963758598266685, 6.955573304911681, 7.014271166700073, 7.07248188403477, 7.130217387990355, 7.187489130426565, 7.244308110509934, 7.300684899377592, 7.356629663099809, 7.4121521840825695, 7.467261881037788, 7.521967827636597, 7.576278769950325, 7.630203142774117, 7.68374908491942, 7.736924453553881, 7.789736837660179, 7.842193570679062, 7.894301742396222, 7.9460682101275735, 7.997499609252884, 8.048602363143555, 8.099382692526635, 8.149846624323676, 8.200000000000001, 8.249848483457136, 8.299397568498573, 8.348652585896723, 8.397618710086808, 8.446300965511472, 8.494704232638123, 8.542833253669418, 8.590692637965812, 8.638286867197687, 8.685620300243388, 8.732697177848321, 8.77952162705919, 8.826097665446492, 8.872429205127535, 8.918520056601322, 8.964373932405989, 9.009994450608726, 9.055385138137417, 9.100549433962767], [0.0, 0.9110433579144299, 1.2884098726725124, 1.5779733838059502, 1.8220867158288598, 2.0371548787463363, 2.2315913604421396, 2.41039415863879, 2.576819745345025, 2.7331300737432893, 2.8809720581775866, 3.0215889859476257, 3.1559467676119004, 3.2848135411313684, 3.408812109811862, 3.5284557528754696, 3.6441734316577197, 3.7563279941985894, 3.8652296180175374, 3.9711459303329564, 4.0743097574926725, 4.174925149029621, 4.273172123844299, 4.369210454990696, 4.463182720884279, 4.55521678957215, 4.645427859734774, 4.73392015141785, 4.82078831727758, 4.906118628814432, 4.9899899799498595, 5.072474741188959, 5.15363949069005, 5.23354564325181, 5.31224999411737, 5.389805191284746, 5.466260147486579, 5.541660400998964, 5.616048432839589, 5.68946394662977, 5.761944116355173, 5.833523806414096, 5.904235767650205, 5.974110812497538, 6.043177971895251, 6.111464636239008, 6.178996682310163, 6.245798587850876, 6.311893535223801, 6.377303505401009, 6.442049363362563, 6.506150935845249, 6.569627082262737, 6.632495759516172, 6.694774081326419, 6.756478372643548, 6.817624219623724, 6.878226515607057, 6.938299503480662, 6.997856814768361, 7.056911505750939, 7.115476090888086, 7.173562573784381, 7.23118247591637, 7.288346863315439, 7.345066371381541, 7.401351227985333, 7.457211275000863, 7.512655988397179, 7.567694497005016, 7.622335600063802, 7.676587783644501, 7.730459236035075, 7.783957862167549, 7.837091297158659, 7.88986691902975, 7.942291860665913, 7.994373021069257, 8.046117075956577, 8.097530487747484, 8.148619514985345, 8.19939022122987, 8.249848483457136, 8.299999999999999, 8.349850298059241, 8.399404740813482, 8.44866853415377, 8.49764673306675, 8.546344247688598, 8.594765849050223, 8.64291617453276, 8.690799733051039, 8.738420909981391, 8.78578397184907, 8.832893070789435, 8.879752248796134, 8.926365441768558, 8.972736483370054, 9.018869108707587, 9.064766957842878, 9.1104335791443, 9.155872432488342], [0.0, 0.9165151389911681, 1.2961481396815722, 1.5874507866387546, 1.8330302779823362, 2.04939015319192, 2.244994432064365, 2.4248711305964283, 2.5922962793631443, 2.749545416973504, 2.898275349237888, 3.039736830714133, 3.174901573277509, 3.3045423283716615, 3.4292856398964493, 3.5496478698597693, 3.6660605559646724, 3.778888725538237, 3.8884444190447165, 3.9949968710876362, 4.09878030638384, 4.2, 4.298837052040936, 4.3954521951671826, 4.48998886412873, 4.582575694955841, 4.67332857821917, 4.762352359916264, 4.849742261192857, 4.935585071701227, 5.019960159204453, 5.10294032886923, 5.184592558726289, 5.264978632435274, 5.344155686354956, 5.422176684690384, 5.499090833947008, 5.574943945906542, 5.649778756730214, 5.723635208501674, 5.796550698475776, 5.868560300448484, 5.939696961967, 6.009991680526688, 6.079473661428266, 6.148170459575759, 6.216108107168022, 6.2833112289620034, 6.349803146555018, 6.4156059729381765, 6.480740698407861, 6.54522726878143, 6.609084656743323, 6.672330927044912, 6.7349832961930955, 6.797058187186572, 6.858571279792899, 6.919537556802478, 6.97997134664606, 7.0398863627192165, 7.099295739719539, 7.158212067269313, 7.216647421067486, 7.274613391789285, 7.332121111929345, 7.389181280764467, 7.445804187594514, 7.501999733404421, 7.557777451076474, 7.6131465242697125, 7.668115805072326, 7.72269383052313, 7.776888838089433, 7.830708780180758, 7.884161337770809, 7.937253933193772, 7.9899937421752725, 8.04238770515324, 8.094442537939226, 8.14616474176652, 8.19756061276768, 8.248636250920512, 8.299397568498573, 8.349850298059241, 8.4, 8.449852069711044, 8.499411744350311, 8.548684109265006, 8.597674104081872, 8.646386528486914, 8.694826047713663, 8.742997197757758, 8.790904390334365, 8.838551917593742, 8.885943956609225, 8.933084573650918, 8.97997772825746, 9.026627277117408, 9.073036977771006, 9.119210492142399, 9.165151389911681, 9.210863151735564], [0.0, 0.9219544457292888, 1.3038404810405297, 1.5968719422671316, 1.8439088914585775, 2.0615528128088303, 2.2583179581272432, 2.4392621835300936, 2.6076809620810595, 2.765863337187866, 2.9154759474226504, 3.0577769702841313, 3.193743884534263, 3.3241540277189325, 3.449637662132068, 3.5707142142714248, 3.687817782917155, 3.8013155617496426, 3.9115214431215897, 4.018706259482024, 4.123105625617661, 4.224926034855522, 4.324349662087931, 4.421538193886829, 4.5166359162544865, 4.609772228646444, 4.701063709417264, 4.790615826801394, 4.878524367060187, 4.964876634922565, 5.049752469181039, 5.13322510708424, 5.215361924162119, 5.296225070746145, 5.375872022286245, 5.454356057317858, 5.531726674375732, 5.608029957123981, 5.68330889535313, 5.757603668193913, 5.830951894845301, 5.903388857258177, 5.974947698515863, 6.0456596000767355, 6.115553940568263, 6.18465843842649, 6.252999280345393, 6.320601237224193, 6.387487769068526, 6.4536811201050215, 6.519202405202649, 6.584071688552609, 6.648308055437865, 6.711929677819935, 6.77495387438173, 6.837397165588672, 6.899275324264136, 6.960603422117942, 7.021395872616784, 7.0816664705420855, 7.1414284285428495, 7.200694410957877, 7.259476565152615, 7.317786550590281, 7.37563556583431, 7.433034373659253, 7.489993324429602, 7.546522377890362, 7.602631123499285, 7.658328799418317, 7.713624310270757, 7.768526243760782, 7.823042886243179, 7.877182237323192, 7.930952023559341, 7.984359711335657, 8.037412518964048, 8.090117428072352, 8.142481194328914, 8.194510357550353, 8.246211251235321, 8.2975900115636, 8.348652585896723, 8.399404740813482, 8.449852069711044, 8.5, 8.549853799919623, 8.599418584997478, 8.648699324175862, 8.697700845625814, 8.746427842267952, 8.794884877018005, 8.843076387773658, 8.891006692158093, 8.938679992034618, 8.986100377805714, 9.033271832508973, 9.080198235721511, 9.126883367283709, 9.173330910852394, 9.219544457292889, 9.265527507918803], [0.0, 0.9273618495495705, 1.3114877048604001, 1.6062378404209012, 1.854723699099141, 2.0736441353327724, 2.2715633383201097, 2.4535688292770597, 2.6229754097208002, 2.7820855486487113, 2.932575659723036, 3.07571129984594, 3.2124756808418025, 3.343650699460098, 3.4698703145794947, 3.591656999213594, 3.709447398198282, 3.8236108588610325, 3.9344631145812006, 4.042276586281548, 4.147288270665545, 4.249705872175156, 4.349712634186309, 4.447471191587417, 4.543126676640219, 4.636809247747852, 4.7286361670147565, 4.818713521262704, 4.907137658554119, 4.993996395673509, 5.079370039680118, 5.163332257370235, 5.2459508194416005, 5.327288240746882, 5.40740233383831, 5.486346689738081, 5.5641710972974225, 5.640921910468182, 5.716642371182581, 5.791372894228104, 5.865151319446072, 5.93801313572141, 6.009991680526689, 6.081118318204308, 6.15142259969188, 6.220932405998316, 6.289674077406556, 6.357672530100934, 6.424951361683605, 6.491532946846993, 6.557438524302001, 6.62268827591938, 6.687301398920196, 6.751296171847301, 6.814690014960329, 6.87749954561976, 6.939740629158989, 7.001428425685718, 7.062577433203831, 7.123201527403251, 7.183313998427188, 7.242927584892728, 7.302054505411474, 7.3607064878311785, 7.418894796396564, 7.476630257007497, 7.533923280734945, 7.590783885739338, 7.647221717722065, 7.703246069028303, 7.75886589650833, 7.814089838234521, 7.868926229162401, 7.923383115816122, 7.977468270071652, 8.031189202104505, 8.084553172563096, 8.137567204023572, 8.19023809177731, 8.242572413997951, 8.29457654133109, 8.346256645946134, 8.397618710086808, 8.44866853415377, 8.499411744350311, 8.549853799919623, 8.600000000000001, 8.649855490122365, 8.699425268372618, 8.748714191239761, 8.79772697916911, 8.84646822183859, 8.894942383174834, 8.943153806124549, 8.99110671719561, 9.038805230781334, 9.086253353280439, 9.133454987024352, 9.180413934022802, 9.22713389953782, 9.273618495495704, 9.319871243745807], [0.0, 0.9327379053088816, 1.3190905958272918, 1.6155494421403516, 1.8654758106177631, 2.0856653614614213, 2.2847319317591728, 2.4677925358506134, 2.6381811916545836, 2.7982137159266447, 2.9495762407505253, 3.093541659651604, 3.231098884280703, 3.363034344160048, 3.4899856733230297, 3.6124783736376886, 3.7309516212355263, 3.845776904605882, 3.957271787481876, 4.065710270051225, 4.171330722922843, 4.274342054632503, 4.374928570845472, 4.473253849269009, 4.5694638635183455, 4.663689526544408, 4.756048780237647, 4.846648326421054, 4.935585071701227, 5.022947341949744, 5.10881590977792, 5.193264869039514, 5.276362383309167, 5.358171329847526, 5.4387498563548595, 5.518151864528558, 5.596427431853289, 5.673623181001714, 5.749782604586021, 5.8249463516842805, 5.8991524815010505, 5.9724366886556455, 6.044832503882966, 6.1163714733492105, 6.187083319303208, 6.256996084384263, 6.326136261573884, 6.394528911499267, 6.462197768561406, 6.529165337162171, 6.59545297913646, 6.661080993352356, 6.726068688320096, 6.790434448545985, 6.854195795277518, 6.917369442208505, 6.979971346646059, 7.042016756583302, 7.103520254071217, 7.164495795239188, 7.224956747275377, 7.284915922644544, 7.344385610791416, 7.40337760755184, 7.4619032424710525, 7.519973404208288, 7.577598564189054, 7.634788798650556, 7.691553809211764, 7.747902942086975, 7.803845206050669, 7.859389289251424, 7.914543574963752, 7.969316156358713, 8.023714850367003, 8.077747210701757, 8.13142054010245, 8.184741901856162, 8.23771813064759, 8.290355842785038, 8.342661445845685, 8.394641147779934, 8.446300965511472, 8.49764673306675, 8.548684109265006, 8.599418584997478, 8.649855490122365, 8.700000000000001, 8.749857141690944, 8.799431799837988, 8.848728722251575, 8.897752525216692, 8.946507698538017, 8.994998610338971, 9.043229511629129, 9.091204540653564, 9.138927727036691, 9.186402995732335, 9.233634170791044, 9.280624978954814, 9.327379053088816, 9.373899935459095], [0.0, 0.938083151964686, 1.3266499161421599, 1.6248076809271923, 1.876166303929372, 2.0976176963403033, 2.297825058615212, 2.4819347291981715, 2.6532998322843198, 2.814249455894058, 2.9664793948382653, 3.1112698372208096, 3.2496153618543846, 3.3823069050575527, 3.509985754956849, 3.63318042491699, 3.752332607858744, 3.867815921162743, 3.97994974842648, 4.0890096600521755, 4.1952353926806065, 4.298837052040936, 4.4, 4.498888751680798, 4.595650117230424, 4.69041575982343, 4.7833042972405595, 4.874423042781577, 4.963869458396343, 5.0517323761260355, 5.138093031466052, 5.223025942880239, 5.3065996645686395, 5.388877434122993, 5.469917732470938, 5.549774770204643, 5.628498911788116, 5.706137047074843, 5.782732917920384, 5.858327406350725, 5.932958789676531, 6.006662967072483, 6.079473661428266, 6.151422599691879, 6.222539674441619, 6.292853089020909, 6.362389488234747, 6.431174076325411, 6.499230723708769, 6.566582063752802, 6.6332495807108005, 6.6992536897776915, 6.764613810115105, 6.82934843158555, 6.8934751758456345, 6.957010852370435, 7.019971509913698, 7.0823724838503095, 7.144228439796701, 7.205553413860728, 7.26636084983398, 7.326663633605681, 7.386474125047755, 7.445804187594514, 7.504665215717488, 7.5630681604756145, 7.62102355330306, 7.678541528180987, 7.735631842325486, 7.792303895511263, 7.848566748139434, 7.904429138147802, 7.95989949685296, 8.014985963805552, 8.069696400732806, 8.12403840463596, 8.178019320104351, 8.231646250902672, 8.284926070883193, 8.337865434270332, 8.390470785361213, 8.442748367682174, 8.494704232638123, 8.546344247688598, 8.597674104081872, 8.648699324175862, 8.699425268372618, 8.749857141690944, 8.8, 8.849858755935035, 8.899438184514796, 8.948742928478838, 8.997777503361595, 9.046546302318914, 9.09505360072166, 9.143303560529969, 9.191300234460847, 9.23904756996088, 9.28654941299512, 9.333809511662428, 9.38083151964686, 9.427618999514142], [0.0, 0.9433981132056604, 1.3341664064126333, 1.6340134638368193, 1.8867962264113207, 2.1095023109728985, 2.3108440016582685, 2.495996794869737, 2.6683328128252666, 2.830194339616981, 2.9832867780352594, 3.1288975694324033, 3.2680269276736387, 3.4014702703389896, 3.529872518944558, 3.6537651812890215, 3.7735924528226414, 3.8897300677553446, 4.0024992192379, 4.112177038990418, 4.219004621945797, 4.323193264243457, 4.424929377967517, 4.524378410345448, 4.621688003316537, 4.716990566028302, 4.810405388322278, 4.902040391510457, 4.991993589739474, 5.0803543183522155, 5.167204273105525, 5.252618394667558, 5.336665625650533, 5.419409561935692, 5.500909015790026, 5.58121850495033, 5.660388679233962, 5.7384666941614295, 5.815496539419485, 5.8915193286621745, 5.966573556070519, 6.040695324215583, 6.113918547053109, 6.186275131288617, 6.2577951388648065, 6.328506932918695, 6.398437309218556, 6.4676116148080505, 6.536053855347277, 6.603786792439623, 6.670832032063167, 6.73721010508059, 6.802940540677979, 6.868041933477111, 6.932532004974806, 6.996427659884722, 7.059745037889116, 7.122499561249548, 7.184705978674423, 7.246378405796926, 7.307530362578043, 7.368174807915458, 7.428324171709255, 7.487990384609211, 7.547184905645283, 7.6059187479225665, 7.664202502543888, 7.722046360907191, 7.779460135510689, 7.836453279386026, 7.893034904268446, 7.949213797602879, 8.0049984384758, 8.060397012554654, 8.115417426109392, 8.170067319184096, 8.224354077980836, 8.278284846512591, 8.33186653757728, 8.385105843100611, 8.438009243891594, 8.490583018850943, 8.542833253669418, 8.594765849050223, 8.646386528486914, 8.697700845625814, 8.748714191239761, 8.799431799837988, 8.849858755935035, 8.899999999999999, 8.949860334105779, 8.99944442729661, 9.048756820690896, 9.097801932335084, 9.1465840618233, 9.195107394696377, 9.243376006633074, 9.291393867445294, 9.339164844888433, 9.38669270829721, 9.433981132056603, 9.481033698917013], [0.0, 0.9486832980505138, 1.3416407864998738, 1.6431676725154984, 1.8973665961010275, 2.121320343559643, 2.32379000772445, 2.5099800796022267, 2.6832815729997477, 2.846049894151541, 3.0, 3.146426544510455, 3.286335345030997, 3.420526275297414, 3.5496478698597693, 3.674234614174767, 3.794733192202055, 3.9115214431215892, 4.024922359499621, 4.135214625627067, 4.242640687119286, 4.347413023856832, 4.449719092257398, 4.549725266430931, 4.6475800154489, 4.743416490252569, 4.83735464897913, 4.929503017546495, 5.019960159204453, 5.10881590977792, 5.196152422706632, 5.282045058497703, 5.366563145999495, 5.449770637375486, 5.531726674375733, 5.612486080160912, 5.692099788303082, 5.770615218501404, 5.848076606885378, 5.92452529743945, 6.0, 6.074537019394977, 6.148170459575759, 6.220932405998315, 6.29285308902091, 6.363961030678928, 6.434283176858165, 6.5038450166036395, 6.572670690061994, 6.640783086353597, 6.708203932499369, 6.77495387438173, 6.841052550594828, 6.906518659932804, 6.971370023173351, 7.035623639735144, 7.099295739719539, 7.162401831787993, 7.224956747275378, 7.286974680894671, 7.348469228349534, 7.409453421137082, 7.469939758793239, 7.52994023880668, 7.58946638440411, 7.648529270389177, 7.707139547199077, 7.76530746332687, 7.8230428862431785, 7.880355321938218, 7.937253933193772, 7.993747556684537, 8.049844718999243, 8.105553651663778, 8.160882305241266, 8.215838362577491, 8.270429251254134, 8.324662155306966, 8.378544026261366, 8.432081593533118, 8.485281374238571, 8.538149682454625, 8.590692637965812, 8.64291617453276, 8.694826047713663, 8.746427842267952, 8.79772697916911, 8.848728722251575, 8.899438184514796, 8.949860334105779, 9.0, 9.049861877399014, 9.099450532861862, 9.148770409186145, 9.197825830053535, 9.246621004453464, 9.2951600308978, 9.343446901438464, 9.391485505499116, 9.439279633531365, 9.486832980505138, 9.534149149242424], [0.0, 0.9539392014169457, 1.349073756323204, 1.6522711641858308, 1.9078784028338913, 2.1330729007701543, 2.3366642891095846, 2.5238858928247927, 2.698147512646408, 2.8618176042508368, 3.0166206257996713, 3.1638584039112754, 3.3045423283716615, 3.439476704383968, 3.5693136595149495, 3.694590640382233, 3.8157568056677826, 3.9331920878594273, 4.047221268969612, 4.158124577258358, 4.266145801540309, 4.371498598878879, 4.474371464239419, 4.57493169347915, 4.673328578219169, 4.769696007084729, 4.864154602806124, 4.956813492557492, 5.047771785649585, 5.137119815616529, 5.224940191045253, 5.3113086899558, 5.396295025292816, 5.479963503528103, 5.562373594069352, 5.643580423808984, 5.7236352085016735, 5.8025856305616035, 5.880476171195663, 5.957348403442593, 6.0332412515993425, 6.1081912216301815, 6.182232606429493, 6.255397669213365, 6.327716807822551, 6.399218702310462, 6.469930447848725, 6.539877674696982, 6.609084656743323, 6.67757440991862, 6.745368781616021, 6.81248853210044, 6.878953408767936, 6.944782214007867, 7.009992867328754, 7.074602462329597, 7.138627319029899, 7.202083032012336, 7.264984514780469, 7.327346040688948, 7.389181280764466, 7.450503338701353, 7.511324783285569, 7.571657678474378, 7.631513611335565, 7.6909037180295, 7.749838707999025, 7.808328886515987, 7.866384175718855, 7.924014134263013, 7.981227975693966, 8.038034585643434, 8.094442537939225, 8.150460109711599, 8.206095295571457, 8.261355820929154, 8.316249154516717, 8.370782520170978, 8.424962907930219, 8.478797084492587, 8.532291603080617, 8.58545281275251, 8.638286867197687, 8.690799733051039, 8.742997197757758, 8.794884877018005, 8.84646822183859, 8.897752525216692, 8.948742928478838, 8.99944442729661, 9.049861877399014, 9.1, 9.1498633869583, 9.199456505685541, 9.248783703817493, 9.297849213662264, 9.346657156438338, 9.395211546314432, 9.443516294262428, 9.491575211733826, 9.539392014169458, 9.586970324351693], [0.0, 0.959166304662544, 1.3564659966250536, 1.6613247725836153, 1.918332609325088, 2.144761058952722, 2.349468024894146, 2.5377155080899043, 2.7129319932501073, 2.877498913987632, 3.0331501776206204, 3.1811947441173736, 3.3226495451672307, 3.458323293158117, 3.5888716889852725, 3.714835124201342, 3.836665218650176, 3.954743986657038, 4.069397989875161, 4.180908992073375, 4.289522117905444, 4.3954521951671826, 4.498888751680798, 4.6000000000000005, 4.698936049788292, 4.79583152331272, 4.8908077042549944, 4.983974317750846, 5.075431016179809, 5.165268628057984, 5.253570214625479, 5.340411969127476, 5.4258639865002145, 5.509990925582366, 5.592852581643825, 5.674504383644443, 5.754997827975264, 5.83438085832593, 5.912698199637794, 5.989991652748776, 6.066300355241241, 6.1416610131136355, 6.216108107168022, 6.289674077406555, 6.362389488234747, 6.434283176858165, 6.505382386916238, 6.575712889109439, 6.645299090334461, 6.714164132637808, 6.782329983125269, 6.8498175158174845, 6.916646586316234, 6.982836100038438, 7.0484040746824395, 7.113367697511497, 7.177743377970545, 7.24154679609267, 7.3047929470998705, 7.367496182557545, 7.429670248402684, 7.491328320131218, 7.552483035399683, 7.6131465242697125, 7.673330437300352, 7.733045971672482, 7.792303895511263, 7.851114570556209, 7.909487973314076, 7.967433714816837, 8.024961059095553, 8.082078940470701, 8.138795979750322, 8.195120499419152, 8.251060537894508, 8.306623862918075, 8.36181798414675, 8.416650165000327, 8.47112743381895, 8.525256594378847, 8.579044235810889, 8.632496741962896, 8.685620300243388, 8.738420909981391, 8.790904390334365, 8.843076387773658, 8.894942383174834, 8.946507698538017, 8.997777503361595, 9.048756820690896, 9.099450532861862, 9.1498633869583, 9.200000000000001, 9.249864863877743, 9.299462350050137, 9.348796714016196, 9.397872099576585, 9.446692542895637, 9.495261976375376, 9.54358423235212, 9.59166304662544, 9.639502061828715], [0.0, 0.9643650760992956, 1.3638181696985856, 1.670329308849007, 1.9287301521985911, 2.1563858652847827, 2.3622023622035435, 2.551470164434615, 2.727636339397171, 2.8930952282978866, 3.0495901363953815, 3.1984371183438958, 3.340658617698014, 3.4770677301427426, 3.6083237105337433, 3.7349698793966195, 3.8574603043971822, 3.976179070414209, 4.091454509095757, 4.203569911396741, 4.312771730569565, 4.419275958796871, 4.523273151159457, 4.624932431938872, 4.724404724407087, 4.821825380496478, 4.917316341257699, 5.0109879265470205, 5.10294032886923, 5.193264869039514, 5.282045058497703, 5.36935750346352, 5.455272678794342, 5.539855593785817, 5.62316636780382, 5.705260730238365, 5.786190456595773, 5.866003750424986, 5.944745579080741, 6.02245796996542, 6.099180272790763, 6.174949392505174, 6.249799996799899, 6.323764701504951, 6.3968742366877915, 6.469157595854347, 6.540642170307134, 6.611353870426239, 6.681317235396028, 6.750555532695069, 6.8190908484929285, 6.886944169949399, 6.954135460285485, 7.020683727387242, 7.0866070866106305, 7.15192281837549, 7.216647421067487, 7.280796659706959, 7.3443856107914165, 7.407428703673091, 7.469939758793239, 7.531932023060219, 7.593418202627852, 7.654410493303845, 7.7149206087943645, 7.774959806970066, 7.834538914320357, 7.893668348746355, 7.952358140828418, 8.010617953691215, 8.068457101577724, 8.125884567233282, 8.182909018191515, 8.239538822045807, 8.295782060782456, 8.351646544245034, 8.407139822793482, 8.462269199216012, 8.517041739947036, 8.571464285639882, 8.62554346113913, 8.67928568489366, 8.732697177848321, 8.78578397184907, 8.838551917593742, 8.891006692158093, 8.943153806124549, 8.994998610338971, 9.046546302318914, 9.097801932335084, 9.148770409186145, 9.199456505685541, 9.249864863877743, 9.3, 9.349866309204641, 9.39946807005588, 9.448809448814174, 9.497894503520243, 9.5467271878901, 9.595311355031686, 9.643650760992957, 9.691749068150704], [0.0, 0.9695359714832659, 1.3711309200802089, 1.6792855623746668, 1.9390719429665317, 2.1679483388678804, 2.374868417407584, 2.5651510676761324, 2.7422618401604177, 2.9086079144497976, 3.0659419433511785, 3.2155870381627056, 3.3585711247493335, 3.4957116585897072, 3.627671429443411, 3.7549966711037173, 3.8781438859330635, 3.9974992182613374, 4.113392760240627, 4.226109321823088, 4.335896677735761, 4.442971978304612, 4.54752680036083, 4.649731175025068, 4.749736834815168, 4.847679857416329, 4.943682837723311, 5.037856687124, 5.130302135352265, 5.221110992882646, 5.310367218940701, 5.398147830506312, 5.4845236803208355, 5.569560126257729, 5.653317610041029, 5.735852159879995, 5.817215828899595, 5.897457079114693, 5.976621118993575, 6.054750201288242, 6.131883886702357, 6.208059278067504, 6.283311228962004, 6.357672530100933, 6.431174076325411, 6.5038450166036395, 6.57571288910944, 6.646803743153547, 6.717142249498667, 6.786751800382861, 6.855654600401045, 6.923871749245506, 6.9914233171794145, 7.058328414008519, 7.124605252222751, 7.1902712048990205, 7.255342858886822, 7.31983606373804, 7.383765976789894, 7.447147104764348, 7.5099933422074345, 7.572318007057021, 7.634133873596926, 7.695453203028396, 7.756287771866127, 7.816648898345122, 7.8765474670060875, 7.935993951610599, 7.994998436522675, 8.053570636680355, 8.1117199162693, 8.16945530620004, 8.226785520481254, 8.283718971573094, 8.340263784797218, 8.396427811873334, 8.452218643646177, 8.507643622061282, 8.56270985144306, 8.61742420912421, 8.671793355471522, 8.725823743349393, 8.77952162705919, 8.832893070789435, 8.885943956609225, 8.938679992034618, 8.99110671719561, 9.043229511629129, 9.09505360072166, 9.1465840618233, 9.197825830053535, 9.248783703817493, 9.299462350050137, 9.349866309204641, 9.4, 9.44986772394196, 9.499473669630335, 9.548821916864929, 9.597916440561463, 9.646761114488118, 9.695359714832659, 9.743715923609434], [0.0, 0.9746794344808963, 1.378404875209022, 1.6881943016134133, 1.9493588689617927, 2.179449471770337, 2.3874672772626644, 2.578759391645525, 2.756809750418044, 2.9240383034426887, 3.082207001484488, 3.2326459750489227, 3.3763886032268267, 3.5142566781611158, 3.6469165057620936, 3.7749172176353745, 3.8987177379235853, 4.018706259482023, 4.135214625627066, 4.2485291572496005, 4.358898943540674, 4.466542286825459, 4.571651780264984, 4.674398357008098, 4.774934554525329, 4.873397172404482, 4.969909455915671, 5.06458290484024, 5.15751878329105, 5.2488093888042835, 5.338539126015655, 5.426785420486054, 5.513619500836088, 5.599107071667768, 5.683308895353129, 5.766281297335397, 5.848076606885377, 5.928743543112655, 6.008327554319921, 6.08687111741328, 6.164414002968976, 6.24099351065197, 6.316644678941503, 6.3914004725099165, 6.465291950097845, 6.53834841531101, 6.6105975524153635, 6.682065548915245, 6.752777206453653, 6.822756041366274, 6.892024376045111, 6.960603422117942, 7.0285133563222315, 7.095773389842717, 7.162401831787993, 7.2284161474004796, 7.293833011524187, 7.358668357794092, 7.4229374239582535, 7.486654793697916, 7.549834435270749, 7.6124897372673015, 7.674633541739956, 7.736278174936576, 7.797435475847171, 7.858116822750854, 7.918333157931661, 7.978095010715276, 8.037412518964047, 8.096295449154509, 8.154753215150045, 8.212794895770866, 8.270429251254132, 8.327664738688751, 8.384509526501832, 8.440971508067065, 8.497058314499201, 8.55277732669336, 8.608135686662937, 8.663140308225419, 8.717797887081348, 8.772114910328067, 8.826097665446492, 8.879752248796134, 8.933084573650918, 8.986100377805714, 9.038805230781334, 9.091204540653564, 9.143303560529969, 9.195107394696377, 9.246621004453464, 9.297849213662264, 9.348796714016196, 9.39946807005588, 9.44986772394196, 9.499999999999998, 9.549869109050658, 9.599479152537391, 9.648834126463154, 9.697937925146768, 9.746794344808963, 9.795407086997457], [0.0, 0.9797958971132713, 1.3856406460551018, 1.6970562748477143, 1.9595917942265426, 2.1908902300206647, 2.4000000000000004, 2.5922962793631443, 2.7712812921102037, 2.939387691339814, 3.0983866769659336, 3.2496153618543846, 3.3941125496954285, 3.532704346531139, 3.666060555964672, 3.794733192202055, 3.9191835884530852, 4.039801975344831, 4.156921938165306, 4.270831300812525, 4.3817804600413295, 4.48998886412873, 4.595650117230424, 4.698936049788292, 4.800000000000001, 4.898979485566357, 4.9959983987187195, 5.091168824543143, 5.184592558726289, 5.276362383309168, 5.366563145999495, 5.455272678794342, 5.542562584220407, 5.628498911788117, 5.713142742834281, 5.796550698475776, 5.878775382679628, 5.959865770300536, 6.0398675482166, 6.118823416311343, 6.196773353931867, 6.27375485654325, 6.349803146555018, 6.424951361683604, 6.499230723708769, 6.572670690061993, 6.64529909033446, 6.717142249498666, 6.788225099390857, 6.858571279792899, 6.92820323027551, 6.997142273814362, 7.065408693062278, 7.1330218000508046, 7.2, 7.266360849833981, 7.332121111929344, 7.397296803562772, 7.4619032424710525, 7.525955088890711, 7.58946638440411, 7.652450587883597, 7.714920608794364, 7.776888838089433, 7.8383671769061705, 7.899367063252599, 7.95989949685296, 8.019975062305368, 8.079603950689663, 8.138795979750322, 8.19756061276768, 8.255906976220118, 8.313843876330612, 8.37137981458254, 8.42852300228219, 8.485281374238571, 8.54166260162505, 8.597674104081872, 8.653323061113575, 8.708616422830897, 8.763560920082659, 8.818163074019441, 8.872429205127535, 8.926365441768558, 8.97997772825746, 9.033271832508973, 9.086253353280439, 9.138927727036691, 9.191300234460847, 9.243376006633074, 9.2951600308978, 9.346657156438338, 9.397872099576585, 9.448809448814174, 9.499473669630335, 9.549869109050658, 9.600000000000001, 9.649870465451857, 9.699484522385713, 9.748846085563153, 9.797958971132713, 9.846826900072939], [0.0, 0.9848857801796106, 1.392838827718412, 1.7058722109231985, 1.9697715603592212, 2.2022715545545246, 2.412467616362964, 2.6057628441590768, 2.785677655436824, 2.9546573405388314, 3.1144823004794877, 3.2664965942122155, 3.411744421846397, 3.5510561809129415, 3.685105154537656, 3.8144462245521304, 3.9395431207184424, 4.060788100849391, 4.178516483155236, 4.293017586733137, 4.404543109109049, 4.513313638558704, 4.61952378498044, 4.723346271447818, 4.824935232725928, 4.924428900898053, 5.021951811795889, 5.117616632769595, 5.2115256883181535, 5.3037722424704485, 5.394441583704471, 5.483611948342078, 5.571355310873648, 5.657738063926256, 5.742821606144492, 5.826662852782887, 5.909314681077663, 5.990826320300065, 6.071243694664217, 6.150609725872713, 6.228964600958975, 6.306346010171025, 6.38278935889318, 6.458327956987009, 6.532993188424431, 6.606814663663572, 6.679820356865895, 6.7520367297579185, 6.823488843692794, 6.894200461257274, 6.9641941385920605, 7.033491309442276, 7.102112361825883, 7.170076708097342, 7.237402849088892, 7.30410843293006, 7.370210309075312, 7.4357245780085215, 7.5006666370396715, 7.565051222562872, 7.628892449104261, 7.692203845452876, 7.754998388136519, 7.817288532477231, 7.879086241436885, 7.940403012442127, 8.001249902359007, 8.061637550770936, 8.121576201698781, 8.18107572388864, 8.240145629781066, 8.298795093265047, 8.357032966310472, 8.414867794564572, 8.472307831990054, 8.529361054615991, 8.586035173466273, 8.64233764672499, 8.698275691193055, 8.753856293085923, 8.809086218218098, 8.863972021616496, 8.918520056601322, 8.972736483370054, 9.026627277117408, 9.080198235721511, 9.133454987024352, 9.186402995732335, 9.23904756996088, 9.291393867445294, 9.343446901438464, 9.395211546314432, 9.446692542895637, 9.497894503520243, 9.548821916864929, 9.599479152537391, 9.649870465451857, 9.700000000000003, 9.749871794028884, 9.799489782636646, 9.848857801796106, 9.897979591815698], [0.0, 0.9899494936611666, 1.4, 1.7146428199482249, 1.9798989873223332, 2.2135943621178655, 2.4248711305964283, 2.619160170741759, 2.8, 2.9698484809834995, 3.1304951684997055, 3.283291031876401, 3.4292856398964497, 3.5693136595149495, 3.704051835490427, 3.8340579025361623, 3.9597979746446663, 4.08166632639171, 4.2, 4.315089802078284, 4.427188724235731, 4.536518488885503, 4.64327470649756, 4.747630988187688, 4.849742261192857, 4.949747468305833, 5.047771785649585, 5.143928459844674, 5.238320341483518, 5.331041174104736, 5.422176684690383, 5.511805511808268, 5.6, 5.686826883245173, 5.772347875864725, 5.856620185738529, 5.939696961966999, 6.021627686929839, 6.102458520956943, 6.182232606429493, 6.260990336999411, 6.338769596696192, 6.4156059729381765, 6.491532946846992, 6.566582063752802, 6.640783086353596, 6.714164132637808, 6.786751800382861, 6.8585712797928995, 6.929646455628165, 7.0, 7.069653456853455, 7.138627319029899, 7.206941098690901, 7.274613391789285, 7.341661937191061, 7.408103670980854, 7.473954776421918, 7.539230729988306, 7.603946343840151, 7.668115805072325, 7.731752712031082, 7.79487010796203, 7.857480512225277, 7.919595949289333, 7.981227975693965, 8.04238770515324, 8.103085831953157, 8.16333265278342, 8.223138087129511, 8.282511696339462, 8.341462701469089, 8.4, 8.4581321815162, 8.515867542417507, 8.573214099741124, 8.630179604156568, 8.6867715521936, 8.742997197757758, 8.798863562983575, 8.854377448471462, 8.909545442950499, 8.964373932405989, 9.018869108707587, 9.073036977771006, 9.126883367283709, 9.180413934022802, 9.233634170791044, 9.28654941299512, 9.339164844888433, 9.391485505499116, 9.443516294262428, 9.495261976375376, 9.5467271878901, 9.597916440561463, 9.648834126463154, 9.699484522385713, 9.749871794028884, 9.8, 9.849873095629203, 9.899494936611665, 9.948869282486328], [0.0, 0.9949874371066201, 1.407124727947029, 1.7233687939614089, 1.9899748742132402, 2.224859546128699, 2.4372115213907883, 2.632489316217637, 2.814249455894058, 2.98496231131986, 3.146426544510455, 3.3000000000000007, 3.4467375879228177, 3.58747822293042, 3.722902093797257, 3.853569773599539, 3.9799497484264803, 4.102438299353203, 4.221374183841087, 4.337049688440289, 4.449719092257398, 4.559605246071199, 4.666904755831214, 4.77179211617606, 4.874423042781577, 4.974937185533101, 5.073460357586329, 5.170106381884226, 5.264978632435274, 5.358171329847527, 5.449770637375485, 5.539855593785817, 5.628498911788116, 5.715767664977296, 5.801723881744115, 5.886425061104576, 5.96992462263972, 6.052272300549605, 6.133514490078262, 6.213694553162394, 6.29285308902091, 6.3710281744785915, 6.448255578061405, 6.524568951279464, 6.600000000000001, 6.674578638386096, 6.748333127521196, 6.821290200541244, 6.893475175845635, 6.96491205974634, 7.035623639735145, 7.105631569396208, 7.17495644586084, 7.243617880589783, 7.3116345641723655, 7.379024325749307, 7.445804187594514, 7.5119904153293495, 7.577598564189055, 7.642643521714199, 7.707139547199078, 7.771100308193172, 7.834538914320357, 7.897467948652911, 7.959899496852961, 8.021845174272563, 8.083316151184489, 8.144323176298936, 8.204876598706406, 8.264986388373547, 8.324662155306966, 8.383913167489272, 8.442748367682174, 8.501176389182852, 8.559205570612264, 8.616843969807043, 8.674099376880578, 8.73097932651315, 8.787491109526087, 8.843641783790206, 8.899438184514796, 8.95488693395958, 9.009994450608726, 9.064766957842878, 9.119210492142399, 9.173330910852394, 9.22713389953782, 9.280624978954814, 9.333809511662428, 9.38669270829721, 9.439279633531365, 9.491575211733826, 9.54358423235212, 9.595311355031686, 9.646761114488118, 9.697937925146768, 9.748846085563153, 9.799489782636646, 9.849873095629203, 9.900000000000002, 9.949874371066201, 9.999499987499377], [0.0, 1.0, 1.4142135623730951, 1.7320508075688776, 2.0, 2.23606797749979, 2.4494897427831783, 2.6457513110645907, 2.8284271247461903, 3.0, 3.1622776601683795, 3.3166247903554003, 3.4641016151377553, 3.6055512754639896, 3.7416573867739413, 3.8729833462074166, 4.0, 4.123105625617661, 4.242640687119286, 4.358898943540674, 4.47213595499958, 4.582575694955841, 4.69041575982343, 4.79583152331272, 4.898979485566357, 5.000000000000001, 5.099019513592785, 5.196152422706633, 5.291502622129181, 5.385164807134505, 5.477225575051661, 5.567764362830022, 5.656854249492381, 5.7445626465380295, 5.830951894845301, 5.916079783099616, 6.0, 6.08276253029822, 6.164414002968977, 6.244997998398399, 6.324555320336759, 6.403124237432849, 6.480740698407861, 6.557438524302, 6.6332495807108005, 6.7082039324993685, 6.782329983125269, 6.855654600401045, 6.9282032302755105, 7.0, 7.071067811865476, 7.141428428542851, 7.211102550927979, 7.28010988928052, 7.348469228349535, 7.416198487095664, 7.483314773547883, 7.54983443527075, 7.6157731058639095, 7.681145747868608, 7.745966692414833, 7.810249675906655, 7.874007874011811, 7.937253933193772, 8.0, 8.06225774829855, 8.12403840463596, 8.18535277187245, 8.246211251235321, 8.306623862918075, 8.366600265340756, 8.426149773176359, 8.485281374238571, 8.544003745317532, 8.602325267042627, 8.660254037844387, 8.717797887081348, 8.774964387392123, 8.831760866327848, 8.88819441731559, 8.94427190999916, 9.000000000000002, 9.055385138137417, 9.1104335791443, 9.165151389911681, 9.219544457292889, 9.273618495495704, 9.327379053088816, 9.38083151964686, 9.433981132056603, 9.486832980505138, 9.539392014169458, 9.59166304662544, 9.643650760992957, 9.695359714832659, 9.746794344808963, 9.797958971132713, 9.848857801796106, 9.899494936611665, 9.949874371066201, 10.000000000000002, 10.049875621120892], [0.0, 1.0049875621120892, 1.4212670403551897, 1.7406895185529214, 2.0099751242241783, 2.2472205054244236, 2.4617067250182347, 2.6589471600616665, 2.8425340807103794, 3.0149626863362675, 3.178049716414141, 3.333166662499792, 3.481379037105843, 3.6235341863986883, 3.7603191353926335, 3.892300091205713, 4.019950248448357, 4.1436698710201325, 4.263801121065569, 4.380639222761903, 4.494441010848847, 4.605431575867782, 4.713809499757071, 4.819751030914357, 4.9234134500364695, 5.024937810560446, 5.1244511901275835, 5.222068555658764, 5.317894320123333, 5.412023651093924, 5.504543577809154, 5.595533933415113, 5.685068161420759, 5.773214009544425, 5.860034129593445, 5.9455865984779, 6.029925372672535, 6.113100686231171, 6.1951594006934165, 6.276145313805283, 6.356099432828282, 6.435060217278469, 6.5130637951735135, 6.590144156238162, 6.666333324999584, 6.74166151627327, 6.81615727518079, 6.889847603539574, 6.962758074211686, 7.034912934784624, 7.1063352017759485, 7.177046746399247, 7.247068372797377, 7.31641988953614, 7.385120175054704, 7.4531872376856345, 7.520638270785267, 7.587489703452652, 7.653757247260983, 7.719455939378112, 7.784600182411426, 7.849203781276163, 7.913279977354524, 7.976841480185, 8.039900496896713, 8.10246875958186, 8.16455755078008, 8.226177727231525, 8.287339742040265, 8.34805366537614, 8.408329203831164, 8.468175718535841, 8.527602242131138, 8.586617494683225, 8.645229898620395, 8.703447592764606, 8.761278445523805, 8.81873006730561, 8.875809822207776, 8.932524839036274, 8.988882021697695, 9.044888059008803, 9.100549433962767, 9.155872432488342, 9.210863151735564, 9.265527507918803, 9.319871243745807, 9.373899935459095, 9.427618999514142, 9.481033698917013, 9.534149149242424, 9.586970324351693, 9.639502061828715, 9.691749068150704, 9.743715923609434, 9.795407086997457, 9.846826900072939, 9.897979591815698, 9.948869282486328, 9.999499987499377, 10.049875621120892, 10.100000000000001]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 1.1\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.07943282347242814, 0.11629646063455597, 0.14535055355944507, 0.17026798450415692, 0.192501227152835, 0.21280566636416204, 0.23163486142739698, 0.24928692059002755, 0.265970445169564, 0.28183829312644537, 0.29700651563522157, 0.3115657321399467, 0.32558834020062105, 0.33913328729819897, 0.3522493435884123, 0.36497741462219235, 0.3773522177636837, 0.38940352431704894, 0.4011570976219998, 0.41263541353615896, 0.4238582220840237, 0.4348429911441786, 0.44560526115746774, 0.45615893177292227, 0.46651649576840376, 0.47668923165440724, 0.48668736355905856, 0.4965201949523114, 0.5061962212666513, 0.5157232253540304, 0.5251083588770259, 0.5343582120915676, 0.5434788739862199, 0.5524759843611681, 0.5613547791314304, 0.5701201299034059, 0.5787765786869205, 0.5873283684554328, 0.5957794701467201, 0.6041336065988983, 0.6123942738372349, 0.6205647600621632, 0.6286481626353579, 0.6366474033164021, 0.6445652419657316, 0.6524042888987633, 0.6601670160503009, 0.6678557670865719, 0.6754727665838725, 0.6830201283771978, 0.6904998631689586, 0.6979138854765283, 0.7052640199876431, 0.7125520073843059, 0.7197795096886299, 0.7269481151778124, 0.7340593429100174, 0.7411146468982311, 0.7481154199650512, 0.7550629973077783, 0.7619586598000293, 0.7688036370533357, 0.7755991102597499, 0.7823462148343429, 0.7890460428745772, 0.7956996454518596, 0.8023080347490851, 0.8088721860566652, 0.8153930396383419, 0.8218715024770432, 0.8283084499100927, 0.8347047271622384, 0.8410611507842146, 0.847378510003868, 0.8536575679962694, 0.859899063078681, 0.8661037098357537, 0.8722722001798766, 0.8784052043512015, 0.8845033718614886, 0.890567332385593, 0.8965976966041039, 0.9025950570003767, 0.9085599886149424, 0.9144930497600555, 0.9203947826969269, 0.9262657142780022, 0.93210635655647, 0.9379172073650243, 0.9436987508657586, 0.949451458072936, 0.9551757873502568, 0.9608721848841302, 0.9665410851343517, 0.9721829112634965, 0.9777980755462433, 0.9833869797597674, 0.9889500155562657, 0.9944875648186018, 1.0, 1.0054876844486578], [0.0, 0.11629646063455597, 0.17026798450415692, 0.212805666364162, 0.24928692059002755, 0.28183829312644537, 0.31156573213994676, 0.339133287298199, 0.36497741462219235, 0.3894035243170489, 0.41263541353615896, 0.4348429911441786, 0.4561589317729222, 0.4766892316544073, 0.4965201949523114, 0.5157232253540304, 0.5343582120915676, 0.5524759843611681, 0.5701201299034059, 0.5873283684554328, 0.6041336065988983, 0.6205647600621632, 0.6366474033164021, 0.6524042888987633, 0.667855767086572, 0.6830201283771978, 0.6979138854765283, 0.7125520073843059, 0.7269481151778124, 0.741114646898231, 0.7550629973077783, 0.7688036370533357, 0.7823462148343429, 0.7956996454518596, 0.8088721860566652, 0.8218715024770431, 0.8347047271622384, 0.8473785100038679, 0.859899063078681, 0.8722722001798766, 0.8845033718614885, 0.896597696604104, 0.9085599886149424, 0.9203947826969268, 0.9321063565564699, 0.9436987508657586, 0.9551757873502568, 0.9665410851343518, 0.9777980755462432, 0.9889500155562658, 1.0000000000000002, 1.010950972718084, 1.0218057367280184, 1.032566963529018, 1.043237201628704, 1.0538188843698788, 1.0643143371264683, 1.0747257839298014, 1.0850553535794931, 1.0953050852871857, 1.1054769338961483, 1.115572774715122, 1.125594408000761, 1.135543563119454, 1.1454219024161645, 1.1552310248151674, 1.1649724691750734, 1.1746477174183814, 1.1842581974538322, 1.1938052859081207, 1.2032903106819786, 1.2127145533442603, 1.2220792513764291, 1.2313856002787356, 1.24063475554838, 1.249827834539068, 1.258965918210542, 1.2680500527759675, 1.2770812512543765, 1.2860604949347882, 1.29498873475808, 1.3038668926222001, 1.3126958626158642, 1.321476512185478, 1.3302096832396575, 1.3388961931953884, 1.3475368359695528, 1.3561323829192806, 1.3646835837343207, 1.373191167284399, 1.3816558424243117, 1.3900782987593032, 1.3984592073731115, 1.4067992215208753, 1.4150989772889673, 1.4233590942236607, 1.4315801759304148, 1.4397628106454459, 1.4479075717811325, 1.4560150184467129, 1.4640856959456257, 1.4721201362507685], [0.0, 0.14535055355944507, 0.212805666364162, 0.265970445169564, 0.3115657321399467, 0.3522493435884123, 0.38940352431704894, 0.4238582220840237, 0.4561589317729222, 0.4866873635590585, 0.5157232253540304, 0.5434788739862199, 0.5701201299034059, 0.5957794701467201, 0.6205647600621632, 0.6445652419657316, 0.6678557670865719, 0.6904998631689587, 0.7125520073843059, 0.7340593429100174, 0.7550629973077781, 0.7755991102597498, 0.7956996454518596, 0.8153930396383419, 0.8347047271622384, 0.8536575679962694, 0.8722722001798765, 0.890567332385593, 0.9085599886149424, 0.9262657142780021, 0.9436987508657586, 0.9608721848841301, 0.9777980755462432, 0.9944875648186018, 1.010950972718084, 1.027197880210253, 1.043237201628704, 1.0590772481930761, 1.0747257839298012, 1.0901900750794435, 1.1054769338961483, 1.1205927575994237, 1.1355435631194537, 1.150335018179156, 1.1649724691750731, 1.1794609662517745, 1.1938052859081207, 1.208009951426508, 1.2220792513764291, 1.2360172564100653, 1.249827834539068, 1.2635146650574074, 1.2770812512543763, 1.2905309320440532, 1.3038668926222001, 1.3170921742483819, 1.3302096832396575, 1.343222199252286, 1.3561323829192806, 1.3689427829041125, 1.3816558424243115, 1.3942739052929405, 1.406799221520875, 1.4192339525183644, 1.4315801759304145, 1.4438398901370888, 1.4560150184467129, 1.4681074130072747, 1.4801188584588632, 1.4920510753478395, 1.5039057233214996, 1.51568440412027, 1.527388664382928, 1.5390199982789623, 1.550579849980938, 1.562069615988616, 1.5734906473155712, 1.5848442515481382, 1.5961316947857007, 1.6073542034705883, 1.6185129661151785, 1.6296091349331878, 1.6406438273815795, 1.651618127619016, 1.6625330878863205, 1.673389729813994, 1.6841890456614534, 1.6949319994923107, 1.7056195282896809, 1.7162525430152356, 1.726831929615429, 1.7373585499780915, 1.7478332428423573, 1.7582568246646821, 1.7686300904435197, 1.778953814505047, 1.7892287512521683, 1.7994556358788798, 1.809635185051933, 1.8197680975616164, 1.8298550549433454, 1.8398967220716558], [0.0, 0.17026798450415692, 0.24928692059002755, 0.3115657321399467, 0.36497741462219235, 0.41263541353615896, 0.45615893177292227, 0.4965201949523115, 0.5343582120915676, 0.5701201299034059, 0.6041336065988983, 0.6366474033164022, 0.6678557670865719, 0.6979138854765284, 0.7269481151778124, 0.7550629973077783, 0.7823462148343429, 0.8088721860566652, 0.8347047271622383, 0.859899063078681, 0.8845033718614886, 0.9085599886149424, 0.93210635655647, 0.9551757873502568, 0.9777980755462433, 1.0000000000000002, 1.0218057367280184, 1.043237201628704, 1.0643143371264683, 1.0850553535794931, 1.1054769338961483, 1.125594408000761, 1.1454219024161647, 1.1649724691750731, 1.1842581974538322, 1.2032903106819786, 1.2220792513764291, 1.24063475554838, 1.258965918210542, 1.2770812512543765, 1.29498873475808, 1.3126958626158645, 1.3302096832396575, 1.3475368359695528, 1.3646835837343205, 1.3816558424243117, 1.3984592073731115, 1.4150989772889675, 1.4315801759304148, 1.4479075717811327, 1.4640856959456257, 1.480118858458863, 1.4960111631786737, 1.5117665214088436, 1.527388664382928, 1.5428811547233166, 1.5582473969767123, 1.5734906473155712, 1.588614022484959, 1.6036205080654722, 1.6185129661151787, 1.633294142246782, 1.6479666721902984, 1.662533087886321, 1.6769958231503326, 1.6913572189444923, 1.7056195282896809, 1.7197849208474312, 1.733855487198506, 1.7478332428423575, 1.7617201319394524, 1.7755180308164198, 1.7892287512521683, 1.8028540435615141, 1.8163955994913812, 1.8298550549433454, 1.843233992535105, 1.8565339440123894, 1.869756392521874, 1.8829027747547749, 1.8959744829700285, 1.908972866905234, 1.9218992355828908, 1.9347548590188732, 1.9475409698395438, 1.9602587648134189, 1.972909406302849, 1.9854940236407743, 1.9980137144372332, 2.0104695458199653, 2.0228625556131377, 2.0351937534579254, 2.0474641218784297, 2.059674617296155, 2.0718261709960606, 2.0839196900469834, 2.095956058179042, 2.1079361366204674, 2.11986076489612, 2.1317307615898384, 2.1435469250725867, 2.1553100341982754], [0.0, 0.192501227152835, 0.28183829312644537, 0.3522493435884123, 0.41263541353615896, 0.46651649576840365, 0.5157232253540304, 0.5613547791314304, 0.6041336065988983, 0.6445652419657315, 0.6830201283771977, 0.7197795096886299, 0.7550629973077781, 0.7890460428745774, 0.8218715024770431, 0.8536575679962694, 0.8845033718614886, 0.9144930497600555, 0.9436987508657585, 0.9721829112634964, 1.0, 1.027197880210253, 1.0538188843698788, 1.0799006739115464, 1.1054769338961483, 1.1305779399070488, 1.1552310248151672, 1.1794609662517743, 1.2032903106819786, 1.2267396463350175, 1.249827834539068, 1.2725722069683942, 1.29498873475808, 1.3170921742483819, 1.3388961931953884, 1.3604134805609438, 1.3816558424243115, 1.4026342861049723, 1.4233590942236605, 1.443839890137089, 1.4640856959456252, 1.48410498408075, 1.5039057233214996, 1.5234954199593194, 1.5428811547233163, 1.562069615988616, 1.5810671297159364, 1.599879686507932, 1.6185129661151785, 1.63697235968013, 1.655262989969583, 1.6733897298139937, 1.6913572189444923, 1.7091698793948553, 1.726831929615429, 1.7443473974284955, 1.7617201319394524, 1.7789538145050467, 1.7960519688484946, 1.813017970401356, 1.8298550549433454, 1.8465663266036165, 1.863154765280382, 1.8796232335298209, 1.8959744829700282, 1.912211160241179, 1.9283358125589793, 1.9443508928948954, 1.9602587648134189, 1.9760617069937687, 1.99176191746088, 2.0073615175482473, 2.0228625556131377, 2.038267010522869, 2.053576794929194, 2.068793758346347, 2.083919690046983, 2.0989563217890352, 2.1139053303854154, 2.128768340127519, 2.1435469250725863, 2.1582426112041717, 2.1728568784742364, 2.18739116273471, 2.201846857565767, 2.216225316007491, 2.230527852201113, 2.2447557429455434, 2.2589102291744774, 2.272992517358996, 2.287003780840209, 2.300945161096155, 2.3148177689469094, 2.3286226857015255, 2.3423609642502345, 2.3560336301050535, 2.3696416823917597, 2.383186094795991, 2.3966678164660355, 2.410087772874723, 2.423446866642654, 2.436745978324877], [0.0, 0.21280566636416204, 0.31156573213994676, 0.38940352431704894, 0.45615893177292227, 0.5157232253540304, 0.570120129903406, 0.6205647600621633, 0.667855767086572, 0.7125520073843059, 0.7550629973077783, 0.7956996454518597, 0.8347047271622384, 0.8722722001798766, 0.9085599886149425, 0.9436987508657587, 0.9777980755462433, 1.010950972718084, 1.043237201628704, 1.0747257839298014, 1.1054769338961485, 1.1355435631194537, 1.1649724691750734, 1.1938052859081207, 1.2220792513764294, 1.2498278345390683, 1.2770812512543765, 1.3038668926222003, 1.3302096832396575, 1.3561323829192806, 1.3816558424243117, 1.4067992215208753, 1.431580175930415, 1.456015018446713, 1.4801188584588632, 1.5039057233214996, 1.527388664382928, 1.550579849980938, 1.5734906473155712, 1.596131694785701, 1.6185129661151785, 1.6406438273815798, 1.6625330878863207, 1.6841890456614534, 1.7056195282896809, 1.7268319296154293, 1.7478332428423575, 1.7686300904435202, 1.7892287512521683, 1.8096351850519334, 1.8298550549433459, 1.8498937477280781, 1.869756392521874, 1.8894478777810746, 1.9089728669052344, 1.9283358125589796, 1.947540969839544, 1.9665924084018969, 1.9854940236407748, 2.0042495470179094, 2.0228625556131377, 2.04133648096964, 2.059674617296155, 2.0778801290825104, 2.095956058179042, 2.1139053303854154, 2.1317307615898384, 2.149435063495688, 2.1670208489689893, 2.1844906370370607, 2.201846857565767, 2.219091855640356, 2.2362278956725383, 2.25325716525449, 2.270181778778605, 2.287003780840209, 2.303725149438951, 2.3203477989932804, 2.3368735831811938, 2.353304297619363, 2.3696416823917597, 2.385887424438005, 2.4020431598108547, 2.418110475811498, 2.4340909130106736, 2.449985967162984, 2.465797091021248, 2.4815256960572105, 2.497173154094447, 2.512740798858911, 2.528229927452133, 2.543641801751757, 2.558977649743752, 2.574238666790337, 2.5894260168373755, 2.604540833564747, 2.6195842214829534, 2.634557256979008, 2.6494609893144503, 2.6642964415781463, 2.679064611596349, 2.6937664728023556], [0.0, 0.23163486142739698, 0.339133287298199, 0.4238582220840237, 0.4965201949523115, 0.5613547791314304, 0.6205647600621633, 0.6754727665838725, 0.7269481151778125, 0.7755991102597498, 0.8218715024770432, 0.8661037098357538, 0.9085599886149424, 0.949451458072936, 0.9889500155562658, 1.0271978802102533, 1.0643143371264683, 1.1004006259622874, 1.1355435631194537, 1.1698182773339632, 1.2032903106819786, 1.2360172564100653, 1.2680500527759675, 1.299434017416703, 1.3302096832396577, 1.360413480560944, 1.3900782987593032, 1.4192339525183644, 1.4479075717811325, 1.4761239301643638, 1.5039057233214999, 1.5312738062882505, 1.5582473969767126, 1.5848442515481382, 1.6110808162809975, 1.63697235968013, 1.662533087886321, 1.6877762459004475, 1.7127142067004082, 1.7373585499780917, 1.7617201319394524, 1.7858091473791988, 1.8096351850519332, 1.833207277205421, 1.8565339440123894, 1.8796232335298209, 1.9024827577249535, 1.9251197250319163, 1.9475409698395438, 1.9697529792573154, 1.9917619174608805, 2.013573647879913, 2.0351937534579254, 2.0566275551853157, 2.0778801290825104, 2.0989563217890352, 2.1198607648961203, 2.140597888144669, 2.1611719315966846, 2.181586956876258, 2.201846857565767, 2.221955368833746, 2.24191607636284, 2.2617324246391632, 2.2814077246581093, 2.300945161096155, 2.32034779899328, 2.3396185899862814, 2.3587603781294106, 2.377775905335293, 2.396667816466036, 2.415438664101679, 2.4340909130106736, 2.452626944344891, 2.471049059579652, 2.489359484217514, 2.507560371272927, 2.525653804553431, 2.543641801751757, 2.561526317362002, 2.5793092454319924, 2.596992422162953, 2.614577628366738, 2.6320665917900636, 2.6494609893144503, 2.6667624490399198, 2.6839725522598843, 2.701092835334099, 2.7181247914660562, 2.735069872390719, 2.7519294899780746, 2.768705017757588, 2.785397792368291, 2.802009114938892, 2.8185402524020042, 2.8349924387463, 2.851366876210147, 2.8676647364200396, 2.8838871614769155, 2.9000352649932637, 2.9161101330837065, 2.932112825311603], [0.0, 0.24928692059002755, 0.36497741462219235, 0.4561589317729222, 0.5343582120915676, 0.6041336065988983, 0.667855767086572, 0.7269481151778125, 0.7823462148343429, 0.8347047271622383, 0.8845033718614886, 0.93210635655647, 0.9777980755462432, 1.0218057367280187, 1.0643143371264683, 1.1054769338961485, 1.1454219024161647, 1.1842581974538322, 1.2220792513764291, 1.258965918210542, 1.29498873475808, 1.3302096832396575, 1.3646835837343207, 1.3984592073731115, 1.431580175930415, 1.4640856959456257, 1.4960111631786734, 1.5273886643829278, 1.5582473969767123, 1.5886140224849588, 1.6185129661151787, 1.6479666721902984, 1.6769958231503328, 1.7056195282896807, 1.733855487198506, 1.7617201319394524, 1.7892287512521683, 1.816395599491381, 1.8432339925351047, 1.869756392521874, 1.8959744829700282, 1.921899235582891, 1.9475409698395438, 1.9729094063028487, 1.998013714437233, 2.0228625556131377, 2.0474641218784297, 2.0718261709960606, 2.095956058179042, 2.1198607648961203, 2.1435469250725867, 2.1670208489689893, 2.190288544984873, 2.213355739604164, 2.2362278956725383, 2.258910229174477, 2.2814077246581093, 2.3037251494389506, 2.3258670666988706, 2.347837847583714, 2.3696416823917597, 2.391282590935293, 2.412764432148929, 2.4340909130106736, 2.4552655968349617, 2.4762919109910047, 2.4971731540944466, 2.5179125027157037, 2.5385130176441657, 2.558977649743752, 2.5793092454319924, 2.599510551811864, 2.6195842214829534, 2.6395328170561445, 2.6593588153939103, 2.6790646115963486, 2.698652522751393, 2.718124791466056, 2.73748358919417, 2.7567310193747936, 2.7758691203943213, 2.7948998683842654, 2.8138251798657423, 2.8326469142508275, 2.8513668762101467, 2.8699868179153665, 2.888508441164577, 2.906933399397983, 2.925263299610741, 2.943499704169309, 2.961644132537207, 2.9796980629156367, 2.9976629338040794, 3.0155401454855806, 3.0333310614411277, 3.0510370096972297, 3.068659284110513, 3.08619914559291, 3.103657823280762, 3.1210365156509567, 3.1383363915870035, 3.1555585913977717], [0.0, 0.265970445169564, 0.3894035243170489, 0.4866873635590585, 0.5701201299034059, 0.6445652419657315, 0.7125520073843059, 0.7755991102597498, 0.8347047271622383, 0.8905673323855929, 0.9436987508657585, 0.9944875648186018, 1.043237201628704, 1.0901900750794435, 1.1355435631194537, 1.1794609662517745, 1.2220792513764291, 1.2635146650574074, 1.3038668926222001, 1.343222199252286, 1.3816558424243115, 1.4192339525183642, 1.4560150184467129, 1.4920510753478393, 1.5273886643829278, 1.562069615988616, 1.5961316947857005, 1.6296091349331878, 1.6625330878863205, 1.6949319994923107, 1.7268319296154289, 1.7582568246646821, 1.789228751252168, 1.8197680975616162, 1.8498937477280781, 1.8796232335298204, 1.908972866905234, 1.9379578561815884, 1.9665924084018964, 1.994889819733185, 2.022862555613137, 2.050522322026208, 2.07788012908251, 2.1049463478934736, 2.131730761589838, 2.158242611204172, 2.1844906370370603, 2.2104831160396605, 2.236227895672538, 2.2617324246391632, 2.287003780840209, 2.3120486968503444, 2.3368735831811933, 2.361484549561558, 2.385887424438005, 2.410087772874723, 2.434090913010673, 2.4579019312139128, 2.48152569605721, 2.504966871225301, 2.5282299274521325, 2.551319153575886, 2.5742386667903365, 2.596992422162953, 2.619584221482953, 2.642017721496196, 2.664296441578146, 2.686423770891159, 2.7084029750679246, 2.7302372024588983, 2.751929489978074, 2.773482768578268, 2.7948998683842654, 2.816183523509658, 2.837336376580913, 2.8583609829901793, 2.8792598148964745, 2.9000352649932637, 2.9206896500589035, 2.9412252143050903, 2.9616441325372067, 2.9819485131393457, 3.0021404008957804, 3.02222177965972, 3.0421945748793524, 3.0620606559904155, 3.0818218386838194, 3.1014798870562363, 3.1210365156509567, 3.1404933913958, 3.159852135444364, 3.1791143249264513, 3.198281494613107, 3.217355138501304, 3.2363367113229806, 3.2552276299828065, 3.2740292749287496, 3.2927429914592596, 3.3113700909706156, 3.3299118521477586, 3.348369522101714, 3.3667443174565106], [0.0, 0.28183829312644537, 0.41263541353615896, 0.5157232253540304, 0.6041336065988983, 0.6830201283771977, 0.7550629973077783, 0.8218715024770432, 0.8845033718614886, 0.9436987508657585, 1.0, 1.0538188843698788, 1.1054769338961483, 1.1552310248151674, 1.2032903106819786, 1.249827834539068, 1.29498873475808, 1.3388961931953884, 1.3816558424243115, 1.4233590942236605, 1.4640856959456254, 1.5039057233214996, 1.5428811547233166, 1.5810671297159364, 1.6185129661151787, 1.655262989969583, 1.6913572189444923, 1.726831929615429, 1.7617201319394524, 1.7960519688484946, 1.8298550549433454, 1.8631547652803822, 1.8959744829700285, 1.9283358125589793, 1.9602587648134189, 1.99176191746088, 2.0228625556131377, 2.053576794929194, 2.083919690046983, 2.1139053303854154, 2.1435469250725863, 2.1728568784742364, 2.201846857565767, 2.230527852201113, 2.258910229174477, 2.287003780840209, 2.3148177689469094, 2.342360964250235, 2.3696416823917597, 2.396667816466036, 2.423446866642654, 2.4499859671629833, 2.4762919109910047, 2.5023711723631177, 2.528229927452133, 2.5538740733350394, 2.5793092454319924, 2.6045408335647466, 2.629573996766059, 2.654413676956995, 2.6790646115963486, 2.7035313453952132, 2.7278182411799365, 2.7519294899780746, 2.7758691203943213, 2.7996410073366986, 2.8232488801472866, 2.8466963301865214, 2.8699868179153665, 2.8931236795154724, 2.916110133083706, 2.9389492844340928, 2.961644132537207, 2.9841975746243845, 3.0066124109816963, 3.0288913494564773, 3.0510370096972292, 3.0730519271459698, 3.094938556800498, 3.1166992767626125, 3.138336391587003, 3.159852135444364, 3.1812486751111915, 3.2025281127977587, 3.2236924888248644, 3.244743784159141, 3.265683922815968, 3.286514774138366, 3.307238154959607, 3.327855831656745, 3.348369522101714, 3.3687808975161837, 3.3890915842359357, 3.4093031653900896, 3.4294171825001714, 3.449435137003656, 3.4693584917063025, 3.4891886721673258, 3.5089270680211584, 3.528575034239332, 3.548133892335755, 3.5676049315184812], [0.0, 0.29700651563522157, 0.4348429911441786, 0.5434788739862199, 0.6366474033164022, 0.7197795096886299, 0.7956996454518597, 0.8661037098357538, 0.93210635655647, 0.9944875648186018, 1.0538188843698788, 1.110534241054576, 1.1649724691750734, 1.2174042697601914, 1.2680500527759675, 1.3170921742483823, 1.3646835837343207, 1.410954092600242, 1.456015018446713, 1.4999626927324992, 1.5428811547233166, 1.5848442515481385, 1.6259172971858358, 1.6661583987511346, 1.705619528289681, 1.7443473974284958, 1.7823841775390257, 1.8197680975616166, 1.8565339440123894, 1.8927134820822449, 1.9283358125589796, 1.9634276761561957, 1.9980137144372332, 2.0321166946813873, 2.0657577046119537, 2.0989563217890352, 2.1317307615898384, 2.1640980070001548, 2.196073922881735, 2.2276733569302984, 2.258910229174477, 2.289797611569137, 2.32034779899328, 2.350572372762519, 2.3804822576003546, 2.4100877728747236, 2.439398678791204, 2.468424218137736, 2.4971731540944466, 2.5256538045534316, 2.55387407333504, 2.5818414786375534, 2.6095631790146956, 2.6370459971390465, 2.6642964415781463, 2.6913207267830894, 2.7181247914660562, 2.7447143155229954, 2.7710947356400517, 2.797271259706968, 2.8232488801472866, 2.849032386263381, 2.8746263756840458, 2.900035264993264, 2.9252632996107404, 2.950314562987723, 2.9751929851753234, 2.999902350816988, 3.02444630661183, 3.048828368291074, 3.0730519271459698, 3.0971202561419893, 3.121036515650957, 3.144803758829967, 3.168424936673363, 3.1919029027618016, 3.215240417730345, 3.238440153475672, 3.2615046971208237, 3.2844365547543846, 3.307238154959607, 3.329911852147759, 3.352459929708831, 3.3748846029917074, 3.3971880221249764, 3.4193722746886848, 3.441439388246573, 3.4633913327476167, 3.485230022805029, 3.506957319860306, 3.5285750342393323, 3.5500849271070636, 3.571488712326859, 3.5927880582300804, 3.6139845893012237, 3.6350798877834527, 3.6560754952091012, 3.67697291385939, 3.697773608157327, 3.7184790059974997, 3.739090500016221, 3.759609448805284], [0.0, 0.3115657321399467, 0.4561589317729222, 0.5701201299034059, 0.6678557670865719, 0.7550629973077781, 0.8347047271622384, 0.9085599886149424, 0.9777980755462432, 1.043237201628704, 1.1054769338961483, 1.1649724691750734, 1.2220792513764291, 1.2770812512543765, 1.3302096832396575, 1.3816558424243115, 1.4315801759304148, 1.4801188584588632, 1.5273886643829278, 1.573490647315571, 1.6185129661151785, 1.6625330878863205, 1.7056195282896809, 1.7478332428423573, 1.7892287512521683, 1.8298550549433454, 1.8697563925218739, 1.908972866905234, 1.9475409698395438, 1.9854940236407743, 2.0228625556131377, 2.059674617296155, 2.095956058179042, 2.1317307615898384, 2.1670208489689893, 2.201846857565767, 2.2362278956725383, 2.2701817787786047, 2.3037251494389506, 2.3368735831811933, 2.3696416823917597, 2.4020431598108547, 2.434090913010673, 2.4657970910212477, 2.4971731540944466, 2.528229927452133, 2.558977649743752, 2.589426016837375, 2.619584221482953, 2.6494609893144503, 2.679064611596349, 2.708402975067924, 2.7374835891941696, 2.7663136110940894, 2.7948998683842654, 2.823248880147286, 2.8513668762101467, 2.8792598148964745, 2.906933399397983, 2.9343930928944197, 2.9616441325372067, 2.988691542399629, 3.01554014548558, 3.0421945748793533, 3.0686592841105127, 3.0949385568004977, 3.1210365156509567, 3.146957130828013, 3.1727042277914426, 3.1982814946131075, 3.2236924888248644, 3.24894064383248, 3.2740292749287496, 3.298961584936087, 3.3237406695061518, 3.348369522101714, 3.372851038683766, 3.3971880221249764, 3.421383186368785, 3.4454391603518757, 3.469358491706302, 3.4931436502562323, 3.516797031323104, 3.5403209588518845, 3.5637176883701542, 3.586989409790833, 3.6101382500685424, 3.633166275718873, 3.656075495209101, 3.6788678612283148, 3.701545272844314, 3.7241095775541053, 3.746562573234382, 3.7689060099978695, 3.791141591961057, 3.8132709789284416, 3.835295787998049, 3.8572175950927083, 3.8790379364212315, 3.9007583098733933, 3.9223801763523367, 3.9439049610478287], [0.0, 0.32558834020062105, 0.4766892316544073, 0.5957794701467201, 0.6979138854765284, 0.7890460428745774, 0.8722722001798766, 0.949451458072936, 1.0218057367280187, 1.0901900750794435, 1.1552310248151674, 1.2174042697601914, 1.2770812512543765, 1.3345587206955019, 1.3900782987593032, 1.443839890137089, 1.4960111631786737, 1.5467344213862348, 1.5961316947857007, 1.6443085850999877, 1.6913572189444923, 1.7373585499780915, 1.782384177539026, 1.8264978005633163, 1.869756392521874, 1.9122111602411795, 1.9539083333697773, 1.994889819733185, 2.0351937534579254, 2.0748549565941454, 2.1139053303854154, 2.1523741888841186, 2.190288544984873, 2.227673356930298, 2.26455174177832, 2.300945161096155, 2.3368735831811933, 2.3723556253426996, 2.4074086791654823, 2.4420490211833883, 2.4762919109910047, 2.5101516784964777, 2.543641801751757, 2.5767749765770662, 2.6095631790146956, 2.642017721496197, 2.6741493034808976, 2.7059680572178424, 2.73748358919417, 2.768705017757588, 2.799641007336699, 2.8302997996284724, 2.8606892420756473, 2.890816813916976, 2.920689650058904, 2.950314562987723, 2.9796980629156367, 3.0088463763319524, 3.03776546311137, 3.0664610323144257, 3.094938556800498, 3.1232032867608406, 3.1512602622678054, 3.179114324926452, 3.206770128705909, 3.234232150020142, 3.2615046971208237, 3.288591918858951, 3.31549781286639, 3.342226233203687, 3.3687808975161837, 3.3951653937365998, 3.4213831863687854, 3.4474376223842644, 3.473331936760386, 3.4990692576864015, 3.524652611461534, 3.5500849271070636, 3.5753690407126144, 3.600507699535164, 3.625503565867788, 3.6503592206937876, 3.675077167140595, 3.699659833746739, 3.7241095775541058, 3.7484286870368084, 3.772619384877107, 3.796683830598053, 3.82062412306181, 3.8444423028419523, 3.868140354477435, 3.8917202086153804, 3.9151837440493393, 3.9385327896591873, 3.961769126258417, 3.9848944883541804, 4.0079105658250755, 4.030819005521333, 4.053621412791763, 4.076319352941518, 4.098914352624463, 4.12140790117374], [0.0, 0.33913328729819897, 0.4965201949523114, 0.6205647600621632, 0.7269481151778124, 0.8218715024770431, 0.9085599886149425, 0.9889500155562658, 1.0643143371264683, 1.1355435631194537, 1.2032903106819786, 1.2680500527759675, 1.3302096832396575, 1.3900782987593032, 1.4479075717811325, 1.5039057233214996, 1.5582473969767123, 1.6110808162809973, 1.6625330878863207, 1.712714206700408, 1.7617201319394524, 1.809635185051933, 1.8565339440123894, 1.9024827577249532, 1.947540969839544, 1.9917619174608803, 2.0351937534579254, 2.0778801290825104, 2.11986076489612, 2.161171931596684, 2.201846857565767, 2.24191607636284, 2.2814077246581093, 2.32034779899328, 2.35876037812941, 2.3966678164660355, 2.4340909130106736, 2.4710490595796517, 2.5075603712729264, 2.543641801751757, 2.5793092454319924, 2.614577628366738, 2.64946098931445, 2.683972552259884, 2.718124791466056, 2.7519294899780746, 2.785397792368291, 2.8185402524020042, 2.8513668762101467, 2.8838871614769155, 2.9161101330837065, 2.948044375594034, 2.979698062915636, 3.011078985434443, 3.0421945748793533, 3.0730519271459698, 3.103657823280762, 3.1340187488040234, 3.1641409115298833, 3.194030258024075, 3.2236924888248644, 3.2531330725390735, 3.282357258913374, 3.311370090970616, 3.3401764162917935, 3.3687808975161837, 3.3971880221249764, 3.4254021115673874, 3.4534273297825644, 3.481267691165562, 3.5089270680211584, 3.536409197545278, 3.5637176883701547, 3.5908560267061826, 3.6178275821104577, 3.644635612909442, 3.6712832713007937, 3.697773608157327, 3.7241095775541058, 3.7502940410379817, 3.7763297716572843, 3.802219457767962, 3.8279657066311783, 3.8535710478161858, 3.879037936421232, 3.9043687561242715, 3.9295658220743688, 3.954631383633867, 3.979567626980639, 4.004376677579079, 4.0290606025278395, 4.053621412791763, 4.078061065324938, 4.102381465091294, 4.126584466988747, 4.150671877682462, 4.174645457352438, 4.198506921360262, 4.222257941839584, 4.245900149214519, 4.2694351336499485, 4.292864446437432], [0.0, 0.3522493435884123, 0.5157232253540304, 0.6445652419657316, 0.7550629973077783, 0.8536575679962694, 0.9436987508657587, 1.0271978802102533, 1.1054769338961485, 1.1794609662517745, 1.249827834539068, 1.3170921742483823, 1.3816558424243115, 1.443839890137089, 1.5039057233214996, 1.5620696159886163, 1.6185129661151787, 1.6733897298139941, 1.726831929615429, 1.778953814505047, 1.8298550549433454, 1.8796232335298209, 1.9283358125589796, 1.9760617069937687, 2.022862555613138, 2.068793758346347, 2.1139053303854154, 2.158242611204172, 2.201846857565767, 2.244755742945544, 2.287003780840209, 2.3286226857015255, 2.36964168239176, 2.4100877728747236, 2.449985967162984, 2.489359484217514, 2.528229927452133, 2.5666174386660345, 2.6045408335647466, 2.642017721496197, 2.6790646115963486, 2.715697007186774, 2.7519294899780746, 2.787775795395596, 2.8232488801472866, 2.8583609829901797, 2.8931236795154724, 2.9275479316577147, 2.961644132537207, 2.9954221471632225, 3.0288913494564778, 3.062060655990416, 3.094938556800498, 3.1275331435675846, 3.1598521354443645, 3.1919029027618016, 3.223692488824865, 3.2552276299828065, 3.2865147741383662, 3.3175600978420463, 3.348369522101714, 3.3789487270237926, 3.4093031653900896, 3.439438075263499, 3.4693584917063025, 3.499069257686401, 3.5285750342393323, 3.557880309947332, 3.5869894097908332, 3.615906503422524, 3.644635612909442, 3.673180619984406, 3.7015452728443146, 3.7297331925295336, 3.75774787891554, 3.7855927163453047, 3.8132709789284416, 3.840785835530957, 3.8681403544774353, 3.895337507985696, 3.9223801763523367, 3.9492711519060797, 3.9760131427445, 4.002608776268511, 4.0290606025278395, 4.05537109738972, 4.0815426655421305, 4.107577643342008, 4.133478301518148, 4.159246847737759, 4.184885429044999, 4.21039613417923, 4.235780995780179, 4.261041992486686, 4.286181050935261, 4.3112000476642525, 4.336100810929016, 4.360885122433135, 4.385554718980406, 4.410111294051962, 4.434556499312672, 4.4588919460506435], [0.0, 0.36497741462219235, 0.5343582120915676, 0.6678557670865719, 0.7823462148343429, 0.8845033718614886, 0.9777980755462433, 1.0643143371264683, 1.1454219024161647, 1.2220792513764291, 1.29498873475808, 1.3646835837343207, 1.4315801759304148, 1.4960111631786737, 1.5582473969767123, 1.6185129661151787, 1.6769958231503328, 1.733855487198506, 1.7892287512521683, 1.843233992535105, 1.8959744829700285, 1.9475409698395438, 1.9980137144372332, 2.0474641218784297, 2.0959560581790426, 2.1435469250725867, 2.190288544984873, 2.2362278956725383, 2.2814077246581093, 2.3258670666988706, 2.3696416823917597, 2.4127644321489297, 2.455265596834962, 2.4971731540944466, 2.538513017644166, 2.5793092454319924, 2.6195842214829534, 2.6593588153939103, 2.6986525227513924, 2.73748358919417, 2.7758691203943213, 2.8138251798657423, 2.851366876210147, 2.888508441164577, 2.9252632996107404, 2.961644132537207, 2.9976629338040794, 3.033331061441128, 3.0686592841105127, 3.1036578232807623, 3.1383363915870035, 3.1727042277914426, 3.206770128705909, 3.240542478393607, 3.27402927492875, 3.3072381549596064, 3.3401764162917935, 3.3728510386837662, 3.4052687030248263, 3.4374358090470816, 3.4693584917063025, 3.5010426363521567, 3.532493892795617, 3.563717688370155, 3.5947192400734664, 3.625503565867788, 3.656075495209101, 3.686439678868713, 3.7166005981045886, 3.7465625732343826, 3.776329771657285, 3.8059062153674703, 3.8352957879980494, 3.8645022414309627, 3.8935292020051273, 3.922380176352337, 3.9510585568878906, 3.979567626980639, 4.007910565825075, 4.0360904530362385, 4.0641102729864915, 4.091972918901714, 4.11968119673306, 4.147237828819152, 4.174645457352437, 4.2019066476623905, 4.2290238913272535, 4.255999609125179, 4.282836153834788, 4.309535812894466, 4.336100810929016, 4.362533312151672, 4.388835422648951, 4.415009192555229, 4.4410566181235165, 4.466979643698428, 4.4927801635969455, 4.518460023902191, 4.544021024175099, 4.569464919088541, 4.594793419988141, 4.620008196383805], [0.0, 0.3773522177636837, 0.5524759843611681, 0.6904998631689587, 0.8088721860566652, 0.9144930497600555, 1.010950972718084, 1.1004006259622874, 1.1842581974538322, 1.2635146650574074, 1.3388961931953884, 1.410954092600242, 1.4801188584588632, 1.5467344213862348, 1.6110808162809973, 1.6733897298139941, 1.733855487198506, 1.7926430161531028, 1.8498937477280781, 1.9057300728060953, 1.9602587648134189, 2.013573647879913, 2.0657577046119537, 2.1168847611630266, 2.1670208489689893, 2.216225316007491, 2.26455174177832, 2.312048696850345, 2.35876037812941, 2.4047271438723317, 2.449985967162984, 2.494570822567751, 2.538513017644166, 2.5818414786375534, 2.6245829978865807, 2.6667624490399198, 2.7084029750679246, 2.749526153165085, 2.790152139928819, 2.8302997996284724, 2.8699868179153665, 2.90922980294757, 2.948044375594034, 2.9864452501283565, 3.0244463066118294, 3.062060655990416, 3.099300698784059, 3.136178178124119, 3.1727042277914426, 3.2088894158202796, 3.2447437841591413, 3.28027688481664, 3.31549781286639, 3.3504152366388595, 3.385037425388314, 3.4193722746886843, 3.4534273297825644, 3.487209807081783, 3.5207266139956594, 3.553984367243494, 3.586989409790833, 3.619747826534058, 3.652265458844757, 3.684547918073771, 3.716600598104588, 3.7484286870368084, 3.7800371780723454, 3.811430879670016, 3.8426144250278305, 3.873592280946701, 3.9043687561242715, 3.9349480089231177, 3.965334054653525, 3.9955307724074993, 4.025541911477402, 4.05537109738972, 4.085021837581862, 4.114497526747491, 4.143801451873816, 4.172936796992282, 4.2019066476623905, 4.230713995206778, 4.2593617407142474, 4.28785269882613, 4.316189601320178, 4.344375100505073, 4.372411772437682, 4.40030211997426, 4.428048575665958, 4.455653504508289, 4.483119206553447, 4.510447919393762, 4.537641820524023, 4.564703029589778, 4.591633610528334, 4.618435573608608, 4.645110877375663, 4.671661430505305, 4.698089093573785, 4.724395680747329, 4.750582961395879, 4.776652661635189], [0.0, 0.38940352431704894, 0.5701201299034059, 0.7125520073843059, 0.8347047271622383, 0.9436987508657585, 1.043237201628704, 1.1355435631194537, 1.2220792513764291, 1.3038668926222001, 1.3816558424243115, 1.456015018446713, 1.5273886643829278, 1.5961316947857007, 1.6625330878863207, 1.726831929615429, 1.7892287512521683, 1.8498937477280781, 1.908972866905234, 1.9665924084018966, 2.0228625556131377, 2.07788012908251, 2.1317307615898384, 2.1844906370370603, 2.2362278956725383, 2.287003780840209, 2.3368735831811933, 2.385887424438005, 2.434090913010673, 2.48152569605721, 2.528229927452133, 2.574238666790337, 2.619584221482953, 2.664296441578146, 2.7084029750679246, 2.751929489978074, 2.7948998683842654, 2.837336376580913, 2.8792598148964745, 2.9206896500589035, 2.9616441325372067, 3.002140400895781, 3.042194574879353, 3.081821838683819, 3.1210365156509563, 3.159852135444364, 3.1982814946131075, 3.236336711322981, 3.2740292749287496, 3.311370090970616, 3.348369522101714, 3.385037425388313, 3.421383186368785, 3.4574157502096754, 3.4931436502562327, 3.528575034239332, 3.5637176883701547, 3.5985790595274185, 3.633166275718873, 3.667486164978631, 3.7015452728443137, 3.7353498785425554, 3.768906009997869, 3.8022194577679627, 3.8352957879980485, 3.8681403544774344, 3.9007583098733933, 3.933154616210054, 3.9653340546535247, 3.997301234658674, 4.029060602527839, 4.060616449427114, 4.091972918901714, 4.123134013928241, 4.154103603538306, 4.184885429044999, 4.215483109900977, 4.245900149214519, 4.276139938947675, 4.3062057648186896, 4.336100810929015, 4.365828164133642, 4.395390818171978, 4.4247916775751275, 4.454033561364243, 4.483119206553446, 4.512051271469827, 4.5408323389020895, 4.569464919088541, 4.597951452554358, 4.626294312807333, 4.654495808900651, 4.682558187870646, 4.710483637056916, 4.738274286311683, 4.765932210104807, 4.79345942953041, 4.820857914220711, 4.848129584172243, 4.875276311489338, 4.902299922049409, 4.929202197094296], [0.0, 0.4011570976219998, 0.5873283684554328, 0.7340593429100174, 0.859899063078681, 0.9721829112634964, 1.0747257839298014, 1.1698182773339632, 1.258965918210542, 1.343222199252286, 1.4233590942236605, 1.4999626927324992, 1.573490647315571, 1.6443085850999877, 1.712714206700408, 1.778953814505047, 1.843233992535105, 1.9057300728060953, 1.9665924084018966, 2.0259511111091992, 2.083919690046983, 2.1405978881446686, 2.196073922881735, 2.250426277659278, 2.303725149438951, 2.3560336301050535, 2.407408679165482, 2.4579019312139128, 2.5075603712729264, 2.5564269035588154, 2.6045408335647466, 2.6519382791079815, 2.698652522751393, 2.744714315522995, 2.790152139928819, 2.8349924387462995, 2.8792598148964745, 2.9229772067491453, 2.966166042460125, 3.0088463763319524, 3.051037009697229, 3.0927555984227393, 3.1340187488040234, 3.174842103349623, 3.2152404177303446, 3.2552276299828065, 3.2948169229011075, 3.3340207804200745, 3.372851038683766, 3.411318932400095, 3.449435137003656, 3.4872098070817827, 3.5246526114615335, 3.5617727653061664, 3.598579059527419, 3.635079887783452, 3.6712832713007937, 3.7071968817312553, 3.7428280622310286, 3.778183846928404, 3.8132709789284416, 3.8480959269870048, 3.882664900972653, 3.9169838662225724, 3.95105855688789, 3.98489448835418, 4.018496968814405, 4.051871110064106, 4.085021837581862, 4.117953899952167, 4.150671877682462, 4.1831801914613855, 4.215483109900978, 4.247584756801809, 4.2794891179765235, 4.3112000476642525, 4.3427212745655135, 4.374056407524762, 4.40520894088544, 4.43618225954037, 4.466979643698427, 4.49760427338679, 4.528059232706485, 4.558347513857627, 4.588472020949377, 4.618435573608608, 4.648240910400107, 4.677890692070262, 4.707387504625236, 4.736733862253871, 4.765932210104806, 4.794984926926605, 4.823894327579092, 4.852662665423496, 4.881292134598501, 4.909784872188792, 4.9381429602922475, 4.966368427991541, 4.99446325323548, 5.0224293646351175, 5.050268643179291, 5.07798292387401], [0.0, 0.41263541353615896, 0.6041336065988983, 0.7550629973077781, 0.8845033718614886, 1.0, 1.1054769338961485, 1.2032903106819786, 1.29498873475808, 1.3816558424243115, 1.4640856959456254, 1.5428811547233166, 1.6185129661151785, 1.6913572189444923, 1.7617201319394524, 1.8298550549433454, 1.8959744829700285, 1.9602587648134189, 2.0228625556131377, 2.083919690046983, 2.1435469250725863, 2.201846857565767, 2.258910229174477, 2.3148177689469094, 2.36964168239176, 2.423446866642654, 2.4762919109910047, 2.528229927452133, 2.5793092454319924, 2.629573996766059, 2.6790646115963486, 2.7278182411799365, 2.7758691203943213, 2.8232488801472866, 2.8699868179153665, 2.916110133083706, 2.961644132537207, 3.006612410981696, 3.0510370096972292, 3.094938556800498, 3.138336391587003, 3.1812486751111915, 3.2236924888248644, 3.2656839228159678, 3.3072381549596064, 3.348369522101714, 3.3890915842359357, 3.4294171825001714, 3.469358491706302, 3.508927068021159, 3.548133892335755, 3.586989409790833, 3.625503565867788, 3.663685839403526, 3.701545272844314, 3.7390905000162205, 3.7763297716572843, 3.8132709789284416, 3.8499216750957554, 3.8862890955551683, 3.9223801763523367, 3.9582015713337637, 3.993759668051099, 4.0290606025278395, 4.064110272986491, 4.098914352624463, 4.1334783015181475, 4.167807377726991, 4.2019066476623905, 4.235780995780179, 4.2694351336499485, 4.302873608449587, 4.336100810929015, 4.36912098288319, 4.401938224170892, 4.434556499312671, 4.466979643698428, 4.499211369432553, 4.531255270842207, 4.563114829672217, 4.59479341998814, 4.626294312807333, 4.657620680476268, 4.688775600810937, 4.719762061015837, 4.750582961395878, 4.781241118874457, 4.811739270329949, 4.842080075761962, 4.872266121297874, 4.902299922049409, 4.93218392482831, 4.9619205107295326, 4.9915119975897735, 5.0209606423286495, 5.050268643179291, 5.079438141814688, 5.108471225375692, 5.1373699284062, 5.166136234700652, 5.194772079068655, 5.223279349021281], [0.0, 0.4238582220840237, 0.6205647600621632, 0.7755991102597498, 0.9085599886149424, 1.027197880210253, 1.1355435631194537, 1.2360172564100653, 1.3302096832396575, 1.4192339525183642, 1.5039057233214996, 1.5848442515481385, 1.6625330878863205, 1.7373585499780915, 1.809635185051933, 1.8796232335298209, 1.9475409698395438, 2.013573647879913, 2.07788012908251, 2.1405978881446686, 2.201846857565767, 2.261732424639163, 2.32034779899328, 2.3777759053352927, 2.4340909130106736, 2.489359484217514, 2.5436418017517566, 2.596992422162953, 2.64946098931445, 2.701092835334099, 2.751929489978074, 2.802009114938892, 2.8513668762101467, 2.9000352649932637, 2.948044375594034, 2.9954221471632216, 3.042194574879353, 3.0883858951742367, 3.1340187488040234, 3.1791143249264517, 3.2236924888248644, 3.2677718954958923, 3.3113700909706156, 3.354503602953266, 3.3971880221249764, 3.4394380752634985, 3.4812676911655616, 3.522690060220795, 3.5637176883701547, 3.604362446083713, 3.6446356129094424, 3.68454791807377, 3.7241095775541053, 3.7633303279916235, 3.8022194577679627, 3.8407858355309568, 3.879037936421232, 3.916983866222572, 3.954631383633867, 3.9919879208384907, 4.0290606025278395, 4.065856263518935, 4.102381465091294, 4.1386425101552415, 4.174645457352437, 4.21039613417923, 4.245900149214519, 4.281162903525819, 4.316189601320178, 4.350985259900275, 4.385554718980406, 4.419902649412058, 4.454033561364244, 4.48795181199975, 4.5216616126848255, 4.555167035766576, 4.588472020949377, 4.621580381298988, 4.654495808900651, 4.687221880195271, 4.719762061015837, 4.7521197113444416, 4.784298089808659, 4.8163003579345505, 4.848129584172243, 4.879788747708792, 4.911280742081941, 4.942608378607354, 4.973774389630989, 5.004781431617408, 5.035632088084042, 5.066328872390727, 5.096874230393152, 5.127270542968261, 5.157520128419099, 5.187625244766079, 5.2175880919311535, 5.247410813820985, 5.277095500314749, 5.306644189161887, 5.336058867794732, 5.36534147506065], [0.0, 0.4348429911441786, 0.6366474033164021, 0.7956996454518596, 0.93210635655647, 1.0538188843698788, 1.1649724691750734, 1.2680500527759675, 1.3646835837343207, 1.4560150184467129, 1.5428811547233166, 1.6259172971858358, 1.7056195282896809, 1.782384177539026, 1.8565339440123894, 1.9283358125589796, 1.9980137144372332, 2.0657577046119537, 2.1317307615898384, 2.196073922881735, 2.258910229174477, 2.32034779899328, 2.3804822576003546, 2.439398678791204, 2.497173154094447, 2.55387407333504, 2.6095631790146956, 2.6642964415781463, 2.718124791466056, 2.7710947356400517, 2.8232488801472866, 2.8746263756840458, 2.9252632996107404, 2.975192985175323, 3.02444630661183, 3.0730519271459698, 3.121036515650957, 3.1684249366733623, 3.215240417730345, 3.2615046971208237, 3.3072381549596064, 3.352459929708831, 3.3971880221249764, 3.4414393882465726, 3.4852300228050286, 3.5285750342393323, 3.571488712326859, 3.6139845893012237, 3.656075495209101, 3.6977736081573274, 3.739090500016221, 3.7800371780723454, 3.8206241230618097, 3.8608613239619465, 3.900758309873394, 3.9403241792851054, 3.979567626980639, 4.018496968814405, 4.057120164560824, 4.095444839016773, 4.1334783015181475, 4.171227564014048, 4.208699357827027, 4.24590014921452, 4.282836153834787, 4.319513350210395, 4.355937492272956, 4.392114121064807, 4.428048575665957, 4.463746003408202, 4.499211369432553, 4.534449465640938, 4.569464919088541, 4.604262199858991, 4.638845628460895, 4.673219382780874, 4.707387504625236, 4.741353905879687, 4.775122374314067, 4.808696579056825, 4.842080075761962, 4.875276311489338, 4.908288629317576, 4.941120272707289, 4.973774389630989, 5.006254036484759, 5.038562181795672, 5.0707017097378415, 5.102675423469089, 5.134486048299282, 5.166136234700652, 5.19762856116962, 5.228965536949015, 5.26014960461892, 5.291183142563847, 5.3220684673233825, 5.352807835832964, 5.383403447561039, 5.413857446548386, 5.4441719233550465, 5.474348916919926, 5.504390416337833], [0.0, 0.44560526115746774, 0.6524042888987633, 0.8153930396383419, 0.9551757873502568, 1.0799006739115464, 1.1938052859081207, 1.299434017416703, 1.3984592073731115, 1.4920510753478393, 1.5810671297159364, 1.6661583987511346, 1.7478332428423573, 1.8264978005633163, 1.9024827577249532, 1.9760617069937687, 2.0474641218784297, 2.1168847611630266, 2.1844906370370603, 2.250426277659278, 2.3148177689469094, 2.3777759053352927, 2.439398678791204, 2.4997732686681897, 2.558977649743752, 2.6170819044762275, 2.674149303480897, 2.7302372024588983, 2.785397792368291, 2.839678731207946, 2.8931236795154724, 2.945772756958423, 2.9976629338040794, 3.0488283682910735, 3.099300698784059, 3.1491092979173834, 3.1982814946131075, 3.246842768809953, 3.294816922901107, 3.342226233203687, 3.3890915842359353, 3.43543258813279, 3.4812676911655616, 3.5266142690310667, 3.5714887123268584, 3.6159065034225235, 3.6598822857643376, 3.7034299265057724, 3.746562573234382, 3.789292705462516, 3.8316321814617806, 3.8735922809467005, 3.915183744049339, 3.956416806972057, 3.997301234658674, 4.037846350783778, 4.078061065324938, 4.117953899952166, 4.157533011442577, 4.196806213305121, 4.235780995780179, 4.274464544361074, 4.312863756969136, 4.350985259900275, 4.388835422648951, 4.426420371704867, 4.463746003408202, 4.500817995940893, 4.537641820524023, 4.5742227518847365, 4.610565878050212, 4.646676109520916, 4.682558187870646, 4.718216693816634, 4.753656054799142, 4.788880552106582, 4.823894327579092, 4.858701389920705, 4.893305620647746, 4.927710779698799, 4.961920510729532, 4.995938346113793, 5.029767711670677, 5.0634119311357475, 5.096874230393152, 5.130157741484119, 5.163265506406122, 5.196200480715965, 5.228965536949015, 5.26156346786597, 5.293996989537678, 5.3262687442777885, 5.358381303432346, 5.3903371700347655, 5.42213878133406, 5.453788511203668, 5.485288672437695, 5.516641518940953, 5.547849247818769, 5.578914001372093, 5.609837869003126, 5.6406228890363455], [0.0, 0.45615893177292227, 0.667855767086572, 0.8347047271622384, 0.9777980755462433, 1.1054769338961483, 1.2220792513764294, 1.3302096832396577, 1.431580175930415, 1.5273886643829278, 1.6185129661151787, 1.705619528289681, 1.7892287512521683, 1.869756392521874, 1.947540969839544, 2.022862555613138, 2.0959560581790426, 2.1670208489689893, 2.2362278956725383, 2.303725149438951, 2.36964168239176, 2.4340909130106736, 2.497173154094447, 2.558977649743752, 2.6195842214829534, 2.679064611596349, 2.73748358919417, 2.7948998683842654, 2.851366876210147, 2.9069333993979836, 2.961644132537207, 3.015540145485581, 3.068659284110513, 3.1210365156509567, 3.172704227791443, 3.223692488824865, 3.27402927492875, 3.323740669506152, 3.3728510386837662, 3.4213831863687854, 3.4693584917063025, 3.5167970313231045, 3.563717688370155, 3.6101382500685424, 3.656075495209101, 3.7015452728443146, 3.7465625732343826, 3.791141591961058, 3.835295787998049, 3.879037936421233, 3.9223801763523376, 3.965334054653525, 4.007910565825075, 4.050120188502547, 4.091972918901715, 4.1334783015181475, 4.174645457352438, 4.215483109900978, 4.25599960912518, 4.296202953588363, 4.336100810929016, 4.3757005368209665, 4.415009192555229, 4.454033561364245, 4.492780163596945, 4.531255270842207, 4.569464919088541, 4.607414920999381, 4.645110877375663, 4.682558187870647, 4.719762061015838, 4.756727523611506, 4.793459429530411, 4.829962467979035, 4.866241171256694, 4.9022999220494095, 4.9381429602922475, 4.973774389630989, 5.009198183511405, 5.044418190922088, 5.079438141814688, 5.114261652223439, 5.148892229104197, 5.183333274911546, 5.2175880919311535, 5.251659886383201, 5.285551772311525, 5.319266775272043, 5.352807835832964, 5.3861778128984525, 5.419379486866508, 5.452415562631073, 5.485288672437695, 5.518001378601381, 5.5505561760947115, 5.582955495013705, 5.6152017029284504, 5.64729710712502, 5.679243956744762, 5.711044444826669, 5.742700710258137, 5.774214839639116], [0.0, 0.46651649576840376, 0.6830201283771978, 0.8536575679962694, 1.0000000000000002, 1.1305779399070488, 1.2498278345390683, 1.360413480560944, 1.4640856959456257, 1.562069615988616, 1.655262989969583, 1.7443473974284958, 1.8298550549433454, 1.9122111602411795, 1.9917619174608803, 2.068793758346347, 2.1435469250725867, 2.216225316007491, 2.287003780840209, 2.3560336301050535, 2.423446866642654, 2.489359484217514, 2.55387407333504, 2.6170819044762275, 2.679064611596349, 2.7398955659630437, 2.799641007336699, 2.8583609829901797, 2.9161101330837065, 2.9729383520969157, 3.0288913494564773, 3.084011127554082, 3.1383363915870035, 3.1919029027618016, 3.2447437841591413, 3.2968897868038463, 3.3483695221017142, 3.399209665706651, 3.449435137003656, 3.499069257686402, 3.5481338923357546, 3.5966495734392394, 3.644635612909442, 3.6921102018448466, 3.7390905000162205, 3.785592716345305, 3.8316321814617806, 3.8772234132728793, 3.922380176352337, 3.9671155358474426, 4.011441906511337, 4.05537109738972, 4.098914352624463, 4.142082388779465, 4.184885429044999, 4.227333234634355, 4.2694351336499485, 4.3112000476642525, 4.352636516233254, 4.39375271953599, 4.434556499312672, 4.47505537825537, 4.515256577989071, 4.555167035766577, 4.59479341998814, 4.634142144645599, 4.673219382780874, 4.71203107903998, 4.750582961395879, 4.7888805521065825, 4.826929177968734, 4.8647339799213425, 4.9022999220494095, 4.939631800032736, 4.976734249081219, 5.0136117513943335, 5.050268643179291, 5.086709121259427, 5.122937249301739, 5.158956963690119, 5.194772079068655, 5.23038629357741, 5.265803193801325, 5.301026259451264, 5.336058867794732, 5.370904297852479, 5.405565734375957, 5.44004627161948, 5.474348916919926, 5.508476594095857, 5.542432146677107, 5.576218340975053, 5.609837869003126, 5.643293351256363, 5.676587339358297, 5.709722318582809, 5.742700710258137, 5.775524874059687, 5.808197110197905, 5.84071966150702, 5.8730947154400965, 5.90532440597551], [0.0, 0.47668923165440724, 0.6979138854765283, 0.8722722001798765, 1.0218057367280184, 1.1552310248151672, 1.2770812512543765, 1.3900782987593032, 1.4960111631786734, 1.5961316947857005, 1.6913572189444923, 1.7823841775390257, 1.8697563925218739, 1.9539083333697773, 2.0351937534579254, 2.1139053303854154, 2.190288544984873, 2.26455174177832, 2.3368735831811933, 2.407408679165482, 2.4762919109910047, 2.5436418017517566, 2.6095631790146956, 2.674149303480897, 2.73748358919417, 2.799641007336699, 2.8606892420756473, 2.9206896500589035, 2.979698062915636, 3.03776546311137, 3.094938556800498, 3.1512602622678054, 3.206770128705909, 3.2615046971208232, 3.31549781286639, 3.3687808975161837, 3.421383186368785, 3.4733319367603857, 3.5246526114615335, 3.5753690407126144, 3.6255035658677874, 3.675077167140595, 3.7241095775541053, 3.7726193848771064, 3.820624123061809, 3.868140354477435, 3.915183744049339, 3.961769126258417, 4.007910565825075, 4.053621412791763, 4.098914352624463, 4.1438014518738155, 4.188294199868488, 4.232403546854951, 4.276139938947675, 4.319513350210395, 4.362533312151672, 4.40520894088544, 4.447548962178995, 4.489561734586207, 4.531255270842206, 4.572637257676909, 4.613715074188154, 4.654495808900651, 4.694986275624033, 4.735193028211955, 4.7751223743140665, 4.814780388203767, 4.854172922756687, 4.893305620647746, 4.93218392482831, 4.970813088339352, 5.009198183511404, 5.0473441105975985, 5.085255605881997, 5.122937249301738, 5.160393471618225, 5.19762856116962, 5.234646670234171, 5.271451821031523, 5.308047911386887, 5.344438720080995, 5.380627911906916, 5.416619042453171, 5.452415562631072, 5.488020822962833, 5.523438077645756, 5.558670488406652, 5.593721128159594, 5.6285929844791625, 5.663288962900453, 5.697811890056303, 5.732164516661475, 5.766349520352836, 5.800369508393946, 5.834227020251917, 5.8679245300538305, 5.901464448929554, 5.934849127247318, 5.968080856748003, 6.001161872583699, 6.034094355265754], [0.0, 0.48668736355905856, 0.7125520073843059, 0.890567332385593, 1.043237201628704, 1.1794609662517743, 1.3038668926222003, 1.4192339525183644, 1.5273886643829278, 1.6296091349331878, 1.726831929615429, 1.8197680975616166, 1.908972866905234, 1.994889819733185, 2.0778801290825104, 2.158242611204172, 2.2362278956725383, 2.312048696850345, 2.385887424438005, 2.4579019312139128, 2.528229927452133, 2.596992422162953, 2.6642964415781463, 2.7302372024588983, 2.7948998683842654, 2.8583609829901797, 2.9206896500589035, 2.981948513139346, 3.042194574879353, 3.1014798870562363, 3.159852135444364, 3.217355138501304, 3.2740292749287496, 3.3299118521477586, 3.3850374253883135, 3.4394380752634985, 3.4931436502562327, 3.5461819794010485, 3.5985790595274185, 3.650359220693788, 3.7015452728443137, 3.7521586362338235, 3.802219457767962, 3.851746715077407, 3.9007583098733933, 3.9492711519060797, 3.997301234658674, 4.044863703752091, 4.091972918901714, 4.1386425101552415, 4.184885429044999, 4.230713995206778, 4.276139938947675, 4.321174440185826, 4.365828164133643, 4.410111294051962, 4.454033561364244, 4.49760427338679, 4.54083233890209, 4.583726291777234, 4.626294312807333, 4.668544249944613, 4.710483637056916, 4.752119711344442, 4.79345942953041, 4.834509482929715, 4.875276311489338, 4.915766116885151, 4.955984874751637, 4.995938346113793, 5.035632088084042, 5.075071463881209, 5.114261652223439, 5.1532076561423095, 5.19191431126122, 5.23038629357741, 5.268628126783555, 5.306644189161888, 5.344438720080995, 5.382015826122994, 5.419379486866507, 5.456533560348825, 5.493481788228786, 5.530227800670212, 5.566775120964206, 5.603127169907198, 5.639287269950382, 5.67525864913497, 5.711044444826669, 5.746647707261775, 5.782071402916395, 5.817318417709468, 5.852391560049552, 5.887293563734559, 5.922027090713079, 5.956594733715285, 5.990999018760869, 6.025242407551, 6.0593272997507865, 6.093256035168334, 6.127030895836055, 6.16065410799958], [0.0, 0.4965201949523114, 0.7269481151778124, 0.9085599886149424, 1.0643143371264683, 1.2032903106819786, 1.3302096832396575, 1.4479075717811325, 1.5582473969767123, 1.6625330878863205, 1.7617201319394524, 1.8565339440123894, 1.9475409698395438, 2.0351937534579254, 2.11986076489612, 2.201846857565767, 2.2814077246581093, 2.35876037812941, 2.434090913010673, 2.5075603712729264, 2.5793092454319924, 2.64946098931445, 2.718124791466056, 2.785397792368291, 2.851366876210147, 2.9161101330837065, 2.979698062915636, 3.042194574879353, 3.1036578232807615, 3.1641409115298833, 3.2236924888248644, 3.2823572589133745, 3.3401764162917935, 3.3971880221249764, 3.4534273297825644, 3.5089270680211584, 3.5637176883701547, 3.6178275821104577, 3.6712832713007937, 3.7241095775541058, 3.7763297716572843, 3.8279657066311783, 3.879037936421232, 3.9295658220743683, 3.9795676269806384, 4.0290606025278395, 4.078061065324938, 4.126584466988747, 4.174645457352437, 4.222257941839584, 4.2694351336499485, 4.316189601320178, 4.362533312151672, 4.4084776719370335, 4.454033561364244, 4.499211369432552, 4.544021024175099, 4.588472020949377, 4.632573448527255, 4.676334013190564, 4.719762061015837, 4.7628655985121, 4.8056523117583625, 4.848129584172244, 4.890304513027735, 4.93218392482831, 4.973774389630989, 5.015082234407753, 5.056113555522349, 5.096874230393152, 5.1373699284062, 5.17760612113659, 5.2175880919311535, 5.257320944900664, 5.296809613365469, 5.336058867794732, 5.375073323275955, 5.413857446548386, 5.452415562631072, 5.490751861073826, 5.5288704018570405, 5.566775120964206, 5.6044698356490965, 5.641958249417873, 5.679243956744762, 5.71633044753856, 5.753221111375896, 5.789919241516001, 5.826428038710629, 5.862750614821796, 5.898889996259072, 5.934849127247318, 5.97063087293502, 6.006238022352622, 6.041673291229627, 6.076939324678664, 6.112038699754087, 6.146973927892264, 6.181747457240151, 6.216361674878374, 6.25081890894459, 6.2851214306625796], [0.0, 0.5061962212666513, 0.741114646898231, 0.9262657142780021, 1.0850553535794931, 1.2267396463350175, 1.3561323829192806, 1.4761239301643638, 1.5886140224849588, 1.6949319994923107, 1.7960519688484946, 1.8927134820822449, 1.9854940236407743, 2.0748549565941454, 2.161171931596684, 2.244755742945544, 2.3258670666988706, 2.4047271438723317, 2.48152569605721, 2.5564269035588154, 2.629573996766059, 2.701092835334099, 2.7710947356400517, 2.839678731207946, 2.9069333993979836, 2.9729383520969157, 3.03776546311137, 3.1014798870562363, 3.1641409115298833, 3.225802674804554, 3.286514774138366, 3.346322784451285, 3.4052687030248263, 3.4633913327476167, 3.520726613995659, 3.5773079133330663, 3.633166275718873, 3.6883306457141605, 3.7428280622310286, 3.796683830598053, 3.849921675095755, 3.9025638746096463, 3.954631383633867, 4.006143940517213, 4.057120164560823, 4.107577643342008, 4.157533011442577, 4.207002021595493, 4.255999609125179, 4.304539950439646, 4.352636516233254, 4.40030211997426, 4.447548962178995, 4.494388670912493, 4.54083233890209, 4.586890557604522, 4.632573448527255, 4.677890692070262, 4.722851554124485, 4.767464910636982, 4.81173927032995, 4.855682795740692, 4.899303322732063, 4.942608378607354, 4.98560519894996, 5.02830074329606, 5.0707017097378415, 5.112814548545286, 5.15464547488612, 5.196200480715966, 5.237485345904036, 5.278505648653726, 5.319266775272043, 5.359773929337028, 5.400032140307995, 5.4400462716194795, 5.479821028296332, 5.519360964124179, 5.558670488406653, 5.59775387233817, 5.636615255018717, 5.67525864913497, 5.71368794633012, 5.7519069222830685, 5.789919241516001, 5.82772846194794, 5.865338039210495, 5.902751330740878, 5.939971599666064, 5.977002018491041, 6.013845672603076, 6.05050556360314, 6.086984612474816, 6.123285662600275, 6.15941148263229, 6.195364769230593, 6.231148149670348, 6.26676418432999, 6.302215369065177, 6.337504137475197, 6.372632863067706, 6.407603861327367], [0.0, 0.5157232253540304, 0.7550629973077783, 0.9436987508657586, 1.1054769338961483, 1.249827834539068, 1.3816558424243117, 1.5039057233214999, 1.6185129661151787, 1.7268319296154289, 1.8298550549433454, 1.9283358125589796, 2.0228625556131377, 2.1139053303854154, 2.201846857565767, 2.287003780840209, 2.3696416823917597, 2.449985967162984, 2.528229927452133, 2.6045408335647466, 2.6790646115963486, 2.751929489978074, 2.8232488801472866, 2.8931236795154724, 2.961644132537207, 3.0288913494564773, 3.094938556800498, 3.159852135444364, 3.2236924888248644, 3.286514774138366, 3.348369522101714, 3.4093031653900896, 3.4693584917063025, 3.528575034239332, 3.5869894097908332, 3.644635612909442, 3.701545272844314, 3.7577478789155396, 3.8132709789284416, 3.868140354477435, 3.9223801763523367, 3.9760131427445, 4.0290606025278395, 4.0815426655421305, 4.1334783015181475, 4.184885429044999, 4.235780995780179, 4.286181050935261, 4.336100810929015, 4.385554718980406, 4.434556499312672, 4.483119206553446, 4.531255270842206, 4.578976539093157, 4.626294312807333, 4.673219382780874, 4.719762061015837, 4.765932210104806, 4.81173927032995, 4.857192284690509, 4.902299922049409, 4.947070498569214, 4.991511997589773, 5.035632088084042, 5.079438141814687, 5.122937249301738, 5.166136234700652, 5.209041669680476, 5.2516598863832, 5.293996989537678, 5.336058867794732, 5.377851204343853, 5.419379486866508, 5.4606490168761015, 5.501664918490256, 5.542432146677106, 5.582955495013704, 5.623239602991442, 5.663288962900454, 5.703107926322335, 5.742700710258136, 5.782071402916394, 5.821223969184034, 5.860162255801151, 5.898889996259072, 5.937410815439604, 5.9757282340120135, 6.013845672603076, 6.05176645575434, 6.089493815679785, 6.127030895836055, 6.164380754316569, 6.201546367080078, 6.238530631023404, 6.275336366907504, 6.311966322145331, 6.348423173459398, 6.38470952941644, 6.4208279328460485, 6.45678086314973, 6.492570738506389, 6.528199917979901], [0.0, 0.5251083588770259, 0.7688036370533357, 0.9608721848841301, 1.125594408000761, 1.2725722069683942, 1.4067992215208753, 1.5312738062882505, 1.6479666721902984, 1.7582568246646821, 1.8631547652803822, 1.9634276761561957, 2.059674617296155, 2.1523741888841186, 2.24191607636284, 2.3286226857015255, 2.4127644321489297, 2.494570822567751, 2.574238666790337, 2.6519382791079815, 2.7278182411799365, 2.802009114938892, 2.8746263756840458, 2.945772756958423, 3.015540145485581, 3.084011127554082, 3.1512602622678054, 3.217355138501304, 3.2823572589133745, 3.346322784451285, 3.4093031653900896, 3.471345679386996, 3.532493892795617, 3.59278805823008, 3.652265458844757, 3.7109607078212297, 3.7689060099978695, 3.826131391341542, 3.8826649009726535, 3.9385327896591873, 3.993759668051099, 4.04836864740153, 4.102381465091294, 4.1558185969191195, 4.208699357827027, 4.261041992486686, 4.312863756969137, 4.364180992549576, 4.415009192555229, 4.465363063042823, 4.515256577989072, 4.564703029589778, 4.613715074188154, 4.662304774288599, 4.7104836370569165, 4.758262649660199, 4.805652311758363, 4.852662665423496, 4.899303322732063, 4.945583491247846, 4.991511997589773, 5.037097309257974, 5.08234755487315, 5.127270542968262, 5.171873779457343, 5.216164483893739, 5.26014960461892, 5.303835832893194, 5.347229616090895, 5.3903371700347655, 5.433164490537316, 5.475717364210749, 5.518001378601381, 5.5600219316995805, 5.6017842408716865, 5.6432933512563626, 5.6845541436642, 5.725571342016075, 5.766349520352836, 5.806893109446182, 5.8472064030381645, 5.887293563734558, 5.927158628575318, 5.966805514303533, 6.006238022352621, 6.045459843570003, 6.084474562694103, 6.123285662600275, 6.16189652833009, 6.200310450917374, 6.238530631023404, 6.2765601823928, 6.314402135140823, 6.352059438882036, 6.3895349657096165, 6.4268315130339495, 6.463951806288557, 6.500898501510882, 6.5376741878049405, 6.574281389692398, 6.610722569358193, 6.64700012879645], [0.0, 0.5343582120915676, 0.7823462148343429, 0.9777980755462432, 1.1454219024161647, 1.29498873475808, 1.431580175930415, 1.5582473969767126, 1.6769958231503328, 1.789228751252168, 1.8959744829700285, 1.9980137144372332, 2.095956058179042, 2.190288544984873, 2.2814077246581093, 2.36964168239176, 2.455265596834962, 2.538513017644166, 2.619584221482953, 2.698652522751393, 2.7758691203943213, 2.8513668762101467, 2.9252632996107404, 2.9976629338040794, 3.068659284110513, 3.1383363915870035, 3.206770128705909, 3.2740292749287496, 3.3401764162917935, 3.4052687030248263, 3.4693584917063025, 3.532493892795617, 3.594719240073467, 3.656075495209101, 3.7166005981045886, 3.7763297716572843, 3.835295787998049, 3.893529202005127, 3.9510585568878906, 4.0079105658250755, 4.0641102729864915, 4.11968119673306, 4.174645457352437, 4.2290238913272535, 4.282836153834787, 4.336100810929016, 4.388835422648952, 4.4410566181235165, 4.492780163596945, 4.5440210241751, 4.594793419988141, 4.645110877375663, 4.694986275624034, 4.744431889720266, 4.793459429530411, 4.842080075761962, 4.890304513027736, 4.9381429602922475, 4.98560519894996, 5.032700598757111, 5.079438141814687, 5.125826444778955, 5.171873779457343, 5.217588091931154, 5.262977020332091, 5.308047911386887, 5.352807835832963, 5.397263602798067, 5.4414217732278845, 5.485288672437695, 5.5288704018570405, 5.572172850030064, 5.61520170292845, 5.657962453628881, 5.700460411402292, 5.742700710258136, 5.784688316983126, 5.826428038710629, 5.8679245300538305, 5.909182299833056, 5.9502057174251926, 5.990999018760869, 6.031566311993029, 6.071911582858712, 6.112038699754087, 6.151951418541341, 6.19165338710454, 6.231148149670348, 6.270439150908292, 6.309529739824191, 6.348423173459398, 6.387122620407554, 6.425631164159803, 6.463951806288557, 6.502087469479294, 6.540041000419156, 6.577815172550535, 6.615412688697326, 6.652836183570954, 6.690088226162867, 6.727171322029718, 6.764087915477076], [0.0, 0.5434788739862199, 0.7956996454518596, 0.9944875648186018, 1.1649724691750731, 1.3170921742483819, 1.456015018446713, 1.5848442515481382, 1.7056195282896807, 1.8197680975616162, 1.9283358125589793, 2.0321166946813873, 2.1317307615898384, 2.227673356930298, 2.32034779899328, 2.4100877728747236, 2.4971731540944466, 2.5818414786375534, 2.664296441578146, 2.744714315522995, 2.8232488801472866, 2.9000352649932637, 2.975192985175323, 3.0488283682910735, 3.1210365156509567, 3.1919029027618016, 3.2615046971208232, 3.3299118521477586, 3.3971880221249764, 3.4633913327476167, 3.528575034239332, 3.59278805823008, 3.656075495209101, 3.7184790059974993, 3.7800371780723454, 3.8407858355309568, 3.9007583098733933, 3.959985677502052, 4.018496968814405, 4.076319352941518, 4.1334783015181475, 4.189997734326984, 4.245900149214519, 4.301206738309668, 4.355937492272955, 4.410111294051962, 4.463746003408202, 4.516858533303911, 4.56946491908854, 4.621580381298989, 4.673219382780874, 4.724395680747328, 4.7751223743140665, 4.825411947982999, 4.875276311489338, 4.924726836377833, 4.9737743896309885, 5.0224293646351175, 5.0707017097378415, 5.118600954622535, 5.166136234700652, 5.213316313701349, 5.260149604618919, 5.306644189161888, 5.352807835832963, 5.398648016756052, 5.4441719233550465, 5.48938648097889, 5.5342983625583875, 5.578914001372093, 5.6232396029914415, 5.667281156468847, 5.711044444826669, 5.754535054899848, 5.797758386580301, 5.84071966150702, 5.883423931242025, 5.925876084968961, 5.968080856748004, 6.010042832358016, 6.051766455754339, 6.093256035168334, 6.134515748872716, 6.17554965063484, 6.216361674878374, 6.2569556415722145, 6.297335260864125, 6.337504137475196, 6.377465774870093, 6.417223579216947, 6.45678086314973, 6.496140849345037, 6.535306673924402, 6.574281389692398, 6.613067969220194, 6.651669307783439, 6.690088226162868, 6.728327473315367, 6.7663897289227775, 6.80427760582523, 6.841993652345322, 6.879540354509112], [0.0, 0.5524759843611681, 0.8088721860566652, 1.010950972718084, 1.1842581974538322, 1.3388961931953884, 1.4801188584588632, 1.6110808162809975, 1.733855487198506, 1.8498937477280781, 1.9602587648134189, 2.0657577046119537, 2.1670208489689893, 2.26455174177832, 2.35876037812941, 2.449985967162984, 2.538513017644166, 2.6245829978865807, 2.7084029750679246, 2.790152139928819, 2.8699868179153665, 2.948044375594034, 3.02444630661183, 3.099300698784059, 3.172704227791443, 3.2447437841591413, 3.31549781286639, 3.3850374253883135, 3.4534273297825644, 3.520726613995659, 3.5869894097908332, 3.652265458844757, 3.7166005981045886, 3.7800371780723454, 3.8426144250278305, 3.9043687561242715, 3.965334054653525, 4.025541911477402, 4.085021837581862, 4.143801451873816, 4.2019066476623905, 4.2593617407142474, 4.316189601320178, 4.372411772437682, 4.428048575665957, 4.483119206553447, 4.537641820524023, 4.591633610528334, 4.645110877375663, 4.698089093573786, 4.750582961395879, 4.802606465801119, 4.854172922756687, 4.905295023441232, 4.955984874751637, 5.0062540364847585, 5.056113555522349, 5.105573997309743, 5.15464547488612, 5.203337675695564, 5.2516598863832, 5.299621015758781, 5.347229616090895, 5.394493902878042, 5.441421773227884, 5.488020822962833, 5.534298362558388, 5.580261432010323, 5.625916814717571, 5.6712710504594535, 5.71633044753856, 5.761101094154056, 5.805588869064295, 5.849799451592396, 5.893738331023675, 5.937410815439604, 5.980822040029118, 6.023976974914655, 6.06688043252717, 6.109537074561555, 6.151951418541341, 6.194127844019213, 6.23607059843779, 6.277783802673184, 6.319271456282125, 6.360537442471816, 6.40158553281027, 6.442419391693525, 6.48304258058493, 6.523458562040584, 6.563670703534003, 6.603682281092115, 6.643496482753888, 6.6831164118620565, 6.722545090197701, 6.7617854609667924, 6.800840391647142, 6.839712676703695, 6.878405040179527, 6.91692013816946, 6.955260561182715, 6.99342883640068], [0.0, 0.5613547791314304, 0.8218715024770431, 1.027197880210253, 1.2032903106819786, 1.3604134805609438, 1.5039057233214996, 1.63697235968013, 1.7617201319394524, 1.8796232335298204, 1.99176191746088, 2.0989563217890352, 2.201846857565767, 2.300945161096155, 2.3966678164660355, 2.489359484217514, 2.5793092454319924, 2.6667624490399198, 2.751929489978074, 2.8349924387462995, 2.916110133083706, 2.9954221471632216, 3.0730519271459698, 3.1491092979173834, 3.223692488824865, 3.2968897868038463, 3.3687808975161837, 3.4394380752634985, 3.5089270680211584, 3.5773079133330663, 3.644635612909442, 3.7109607078212297, 3.7763297716572843, 3.8407858355309568, 3.9043687561242715, 3.9671155358474417, 4.0290606025278395, 4.09023605472134, 4.150671877682462, 4.21039613417923, 4.269435133649948, 4.327813582637908, 4.385554718980406, 4.442680431849988, 4.499211369432552, 4.555167035766576, 4.610565878050212, 4.665425365540564, 4.719762061015837, 4.773591685641172, 4.826929177968734, 4.879788747708792, 4.93218392482831, 4.984127604464794, 5.035632088084042, 5.086709121259426, 5.1373699284062, 5.187625244766078, 5.2374853459040365, 5.286960074950249, 5.336058867794731, 5.384790776419963, 5.433164490537315, 5.4811883576758715, 5.52887040185704, 5.5762183409750525, 5.6232396029914415, 5.669941341041156, 5.71633044753856, 5.762413567363214, 5.808197110197905, 5.85368726208473, 5.898889996259072, 5.943811083315972, 5.988456100758583, 6.032830441974106, 6.076939324678663, 6.1207877988691095, 6.164380754316569, 6.207722927633639, 6.250818908944589, 6.293673148185523, 6.336289961059351, 6.378673534668438, 6.4208279328460485, 6.4627571012060825, 6.504464871929102, 6.545954968301342, 6.58723100902213, 6.62829651229401, 6.66915489970888, 6.709809499942419, 6.750263552268299, 6.790520209902812, 6.83058254318983, 6.870453542635335, 6.910136121800131, 6.949633120058775, 6.988947305232206, 7.028081376101122, 7.067037964806599, 7.1058196391441415], [0.0, 0.5701201299034059, 0.8347047271622384, 1.043237201628704, 1.2220792513764291, 1.3816558424243115, 1.527388664382928, 1.662533087886321, 1.7892287512521683, 1.908972866905234, 2.0228625556131377, 2.1317307615898384, 2.2362278956725383, 2.3368735831811933, 2.4340909130106736, 2.528229927452133, 2.6195842214829534, 2.7084029750679246, 2.7948998683842654, 2.8792598148964745, 2.961644132537207, 3.042194574879353, 3.121036515650957, 3.1982814946131075, 3.27402927492875, 3.3483695221017142, 3.421383186368785, 3.4931436502562327, 3.5637176883701547, 3.633166275718873, 3.701545272844314, 3.7689060099978695, 3.835295787998049, 3.9007583098733933, 3.965334054653525, 4.0290606025278395, 4.091972918901715, 4.154103603538306, 4.215483109900978, 4.276139938947676, 4.336100810929015, 4.395390818171979, 4.454033561364244, 4.512051271469827, 4.569464919088541, 4.626294312807333, 4.682558187870646, 4.738274286311683, 4.79345942953041, 4.848129584172244, 4.9022999220494095, 4.955984874751637, 5.009198183511404, 5.061952944819099, 5.11426165222344, 5.166136234700652, 5.2175880919311535, 5.268628126783555, 5.319266775272043, 5.369514034223692, 5.419379486866507, 5.468872326526386, 5.51800137860138, 5.5667751209642065, 5.61520170292845, 5.663288962900453, 5.711044444826669, 5.758475413535647, 5.805588869064295, 5.852391560049552, 5.898889996259072, 5.9450904603277515, 5.990999018760869, 6.036621532259209, 6.081963665416612, 6.127030895836055, 6.171828522706402, 6.216361674878374, 6.260635318475091, 6.304654264069636, 6.348423173459397, 6.391946566064616, 6.435228824976333, 6.478274202676993, 6.521086826455141, 6.563670703534003, 6.606029725932246, 6.648167675073869, 6.690088226162868, 6.731794952337246, 6.773291328615813, 6.814580735650307, 6.855666463294482, 6.896551714000957, 6.937239606055903, 6.977733176660969, 7.018035384871152, 7.058149114396807, 7.098077176277394, 7.137822311434089, 7.1773871931078945, 7.216774429189508], [0.0, 0.5787765786869205, 0.8473785100038679, 1.0590772481930761, 1.24063475554838, 1.4026342861049723, 1.550579849980938, 1.6877762459004475, 1.816395599491381, 1.9379578561815884, 2.053576794929194, 2.1640980070001548, 2.2701817787786047, 2.3723556253426996, 2.4710490595796517, 2.5666174386660345, 2.6593588153939103, 2.749526153165085, 2.837336376580913, 2.9229772067491453, 3.006612410981696, 3.0883858951742367, 3.1684249366733623, 3.246842768809953, 3.323740669506152, 3.399209665706651, 3.4733319367603857, 3.5461819794010485, 3.6178275821104577, 3.6883306457141605, 3.7577478789155396, 3.826131391341542, 3.893529202005127, 3.959985677502052, 4.025541911477402, 4.09023605472134, 4.154103603538306, 4.217177652671661, 4.279489117976523, 4.34106693315662, 4.401938224170891, 4.462128464336976, 4.5216616126848255, 4.5805602377234615, 4.638845628460894, 4.696537894248785, 4.7536560547991416, 4.810218121532254, 4.866241171256693, 4.921741413048272, 4.976734249081219, 5.031234330068061, 5.085255605881996, 5.138811371864661, 5.19191431126122, 5.244576534172135, 5.296809613365469, 5.348624617254104, 5.400032140307995, 5.451042331141562, 5.501664918490255, 5.551909235267314, 5.601784240871686, 5.651298541900307, 5.700460411402291, 5.749277806798838, 5.797758386580301, 5.845909525881136, 5.893738331023675, 5.941251653113141, 5.988456100758583, 6.035358051987613, 6.081963665416612, 6.128278890732618, 6.174309478538129, 6.220060989605594, 6.265538803584389, 6.310748127199404, 6.355694001977152, 6.400381311532303, 6.44481478844489, 6.488999020756006, 6.532938458107585, 6.576637417549862, 6.6201000890382815, 6.6633305406399534, 6.706332723468214, 6.749110476362509, 6.791667530329491, 6.834007512760086, 6.876133951436235, 6.918050278339979, 6.959759833276737, 7.0012658673237365, 7.042571546113809, 7.083679952964113, 7.1245940918586115, 7.165316890292627, 7.205851201987184, 7.246199809480379, 7.286365426602506, 7.32635070084131], [0.0, 0.5873283684554328, 0.859899063078681, 1.0747257839298012, 1.258965918210542, 1.4233590942236605, 1.5734906473155712, 1.7127142067004082, 1.8432339925351047, 1.9665924084018964, 2.083919690046983, 2.196073922881735, 2.3037251494389506, 2.4074086791654823, 2.5075603712729264, 2.6045408335647466, 2.6986525227513924, 2.790152139928819, 2.8792598148964745, 2.966166042460125, 3.0510370096972292, 3.1340187488040234, 3.215240417730345, 3.294816922901107, 3.3728510386837662, 3.449435137003656, 3.5246526114615335, 3.5985790595274185, 3.6712832713007937, 3.7428280622310286, 3.8132709789284416, 3.8826649009726535, 3.9510585568878906, 4.018496968814405, 4.085021837581862, 4.150671877682462, 4.215483109900978, 4.279489117976523, 4.3427212745655135, 4.40520894088544, 4.466979643698427, 4.528059232706486, 4.588472020949377, 4.648240910400107, 4.707387504625236, 4.765932210104806, 4.823894327579092, 4.881292134598501, 4.938142960292247, 4.994463253235481, 5.050268643179291, 5.105573997309742, 5.160393471618225, 5.214740557893453, 5.268628126783555, 5.322068467323381, 5.375073323275955, 5.427653926596958, 5.479821028296333, 5.531584926940693, 5.582955495013704, 5.633942203328296, 5.6845541436642, 5.734800049786261, 5.784688316983125, 5.834227020251916, 5.883423931242025, 5.93228653406018, 5.980822040029118, 6.02903740148347, 6.076939324678663, 6.124534281881697, 6.171828522706402, 6.218828084750205, 6.265538803584389, 6.31196632214533, 6.358116099570124, 6.403993419516313, 6.449603398002151, 6.494950990800799, 6.540041000419154, 6.584878082689516, 6.62946675300009, 6.673811392188255, 6.717916252118698, 6.761785460966792, 6.805423028226068, 6.848832849457254, 6.8920187107949795, 6.934984293227169, 6.977733176660968, 7.020268843788123, 7.062594683761789, 7.1047139956959136, 7.146629991997555, 7.18834580154183, 7.229864472698466, 7.271188976218378, 7.312322207988121, 7.3532669916595506, 7.394026081161522, 7.434602163100081], [0.0, 0.5957794701467201, 0.8722722001798766, 1.0901900750794435, 1.2770812512543765, 1.443839890137089, 1.596131694785701, 1.7373585499780917, 1.869756392521874, 1.994889819733185, 2.1139053303854154, 2.2276733569302984, 2.3368735831811933, 2.4420490211833883, 2.543641801751757, 2.642017721496197, 2.73748358919417, 2.8302997996284724, 2.9206896500589035, 3.0088463763319524, 3.094938556800498, 3.1791143249264517, 3.2615046971208237, 3.342226233203687, 3.4213831863687854, 3.499069257686402, 3.5753690407126144, 3.650359220693788, 3.7241095775541058, 3.796683830598053, 3.868140354477435, 3.9385327896591873, 4.0079105658250755, 4.076319352941518, 4.143801451873816, 4.21039613417923, 4.276139938947676, 4.34106693315662, 4.40520894088544, 4.468595745831872, 4.531255270842207, 4.593213737571303, 4.654495808900651, 4.715124716341065, 4.775122374314067, 4.8345094829297155, 4.893305620647746, 4.951529328015293, 5.009198183511404, 5.066328872390728, 5.122937249301739, 5.179038395355298, 5.234646670234171, 5.289775759861196, 5.344438720080996, 5.398648016756053, 5.452415562631073, 5.505752751278991, 5.558670488406654, 5.611179220767341, 5.663288962900454, 5.715009321894994, 5.766349520352836, 5.81731841770947, 5.8679245300538305, 5.918176048574641, 5.968080856748004, 6.017646546369888, 6.06688043252717, 6.1157895675920235, 6.16438075431657, 6.212660558097631, 6.260635318475092, 6.308311159921715, 6.355694001977153, 6.402789568774321, 6.449603398002151, 6.496140849345038, 6.542407112435917, 6.588407214356856, 6.634146026718296, 6.679628272345579, 6.7248585315990885, 6.769841248352327, 6.814580735650307, 6.859081181068952, 6.903346651794629, 6.947381099441511, 6.991188364623139, 7.034772181293382, 7.078136180870879, 7.121283896160024, 7.1642187650806965, 7.20694413421798, 7.249463262202445, 7.291779322930774, 7.333895408635858, 7.375814532814919, 7.417539633023594, 7.4590735735434235, 7.500419147929704, 7.541579081446212], [0.0, 0.6041336065988983, 0.8845033718614885, 1.1054769338961483, 1.29498873475808, 1.4640856959456252, 1.6185129661151785, 1.7617201319394524, 1.8959744829700282, 2.022862555613137, 2.1435469250725863, 2.258910229174477, 2.3696416823917597, 2.4762919109910047, 2.5793092454319924, 2.6790646115963486, 2.7758691203943213, 2.8699868179153665, 2.9616441325372067, 3.051037009697229, 3.138336391587003, 3.2236924888248644, 3.3072381549596064, 3.3890915842359353, 3.4693584917063025, 3.5481338923357546, 3.6255035658677874, 3.7015452728443137, 3.7763297716572843, 3.849921675095755, 3.9223801763523367, 3.993759668051099, 4.0641102729864915, 4.1334783015181475, 4.2019066476623905, 4.269435133649948, 4.336100810929015, 4.401938224170891, 4.466979643698427, 4.531255270842207, 4.5947934199881395, 4.657620680476268, 4.719762061015837, 4.781241118874457, 4.842080075761961, 4.902299922049409, 4.961920510729532, 5.0209606423286495, 5.079438141814687, 5.137369928406201, 5.194772079068655, 5.251659886383199, 5.308047911386886, 5.363950031909243, 5.419379486866507, 5.474348916919924, 5.52887040185704, 5.582955495013703, 5.636615255018717, 5.6898602751117835, 5.742700710258136, 5.795146302259261, 5.847206403038164, 5.898889996259072, 5.9502057174251926, 6.001161872583698, 6.051766455754339, 6.102027165186733, 6.151951418541341, 6.201546367080078, 6.250818908944589, 6.299775701592977, 6.348423173459397, 6.39676753489517, 6.44481478844489, 6.492570738506388, 6.540041000419154, 6.587231009022129, 6.6341460267182955, 6.680791151080451, 6.727171322029716, 6.773291328615812, 6.819155815425834, 6.864769288646149, 6.9101361218001305, 6.955260561182714, 7.000146731011149, 7.04479863830992, 7.089220177546399, 7.133415135032689, 7.177387193107894, 7.221139934114083, 7.26467684417832, 7.308001316812161, 7.351116656339335, 7.394026081161521, 7.436732726871511, 7.479239649222372, 7.52154982696072, 7.563666164531615, 7.605591494662135, 7.647328580830235], [0.0, 0.6123942738372349, 0.896597696604104, 1.1205927575994237, 1.3126958626158645, 1.48410498408075, 1.6406438273815798, 1.7858091473791988, 1.921899235582891, 2.050522322026208, 2.1728568784742364, 2.289797611569137, 2.4020431598108547, 2.5101516784964777, 2.614577628366738, 2.715697007186774, 2.8138251798657423, 2.90922980294757, 3.002140400895781, 3.0927555984227393, 3.1812486751111915, 3.2677718954958923, 3.352459929708831, 3.43543258813279, 3.5167970313231045, 3.5966495734392394, 3.675077167140595, 3.7521586362338235, 3.8279657066311783, 3.9025638746096463, 3.9760131427445, 4.04836864740153, 4.11968119673306, 4.189997734326984, 4.2593617407142474, 4.327813582637908, 4.395390818171979, 4.462128464336976, 4.528059232706486, 4.593213737571303, 4.657620680476268, 4.721307014332802, 4.784298089808659, 4.846617786283554, 4.908288629317576, 4.969331896295233, 5.029767711670678, 5.089615133040668, 5.148892229104197, 5.207616150426055, 5.265803193801326, 5.323468860915443, 5.380627911906916, 5.437294414364839, 5.493481788228786, 5.549202847003056, 5.6044698356490965, 5.659294465478181, 5.713687946330121, 5.767661016292096, 5.821223969184034, 5.874386680012695, 5.927158628575318, 5.979548921374956, 6.031566311993029, 6.083219220050085, 6.134515748872716, 6.185463701973148, 6.23607059843779, 6.286343687311886, 6.336289961059351, 6.385916168169554, 6.435228824976334, 6.484234226748727, 6.532938458107586, 6.581347402817618, 6.62946675300009, 6.677302017807628, 6.7248585315990885, 6.77214146164932, 6.819155815425834, 6.865906447461791, 6.912398065852404, 6.958635238399725, 7.004622398428837, 7.050363850296712, 7.095863774613404, 7.1411262331937495, 7.186155173756424, 7.230954434385958, 7.2755277477722, 7.3198787452406515, 7.364010960586199, 7.4079278337218435, 7.451632714153233, 7.495128864289113, 7.538419462597041, 7.581507606613161, 7.6243963158142085, 7.667088534359396, 7.709587133709311, 7.751894915128539], [0.0, 0.6205647600621632, 0.9085599886149424, 1.1355435631194537, 1.3302096832396575, 1.5039057233214996, 1.6625330878863207, 1.8096351850519332, 1.9475409698395438, 2.07788012908251, 2.201846857565767, 2.32034779899328, 2.434090913010673, 2.543641801751757, 2.64946098931445, 2.7519294899780746, 2.851366876210147, 2.948044375594034, 3.042194574879353, 3.1340187488040234, 3.2236924888248644, 3.3113700909706156, 3.3971880221249764, 3.4812676911655616, 3.563717688370155, 3.644635612909442, 3.7241095775541053, 3.802219457767962, 3.879037936421232, 3.954631383633867, 4.0290606025278395, 4.102381465091294, 4.174645457352437, 4.245900149214519, 4.316189601320178, 4.385554718980406, 4.454033561364244, 4.5216616126848255, 4.588472020949377, 4.654495808900651, 4.719762061015837, 4.784298089808659, 4.848129584172243, 4.91128074208194, 4.9737743896309885, 5.035632088084042, 5.096874230393152, 5.1575201284191, 5.2175880919311535, 5.27709550031475, 5.336058867794732, 5.394493902878041, 5.452415562631072, 5.509838102330895, 5.5667751209642065, 5.6232396029914415, 5.679243956744762, 5.734800049786261, 5.789919241516002, 5.8446124132873525, 5.898889996259072, 5.9527619971890005, 6.006238022352621, 6.059327299750787, 6.112038699754086, 6.164380754316569, 6.216361674878374, 6.2679893690651936, 6.319271456282125, 6.3702152822902525, 6.4208279328460485, 6.471116246476367, 6.521086826455142, 6.570746052042084, 6.620100089038282, 6.6691548997088805, 6.717916252118699, 6.766389728922778, 6.814580735650307, 6.8624945085172575, 6.910136121800131, 6.957510494800651, 7.004622398428837, 7.051476461429772, 7.098077176277394, 7.14442890475686, 7.190535883255387, 7.236402227780028, 7.282031938719416, 7.327428905365315, 7.372596910208648, 7.417539633023593, 7.462260654752482, 7.5067634612031915, 7.551051446570049, 7.5951279167884405, 7.638996092732631, 7.682659113265697, 7.7261200381498485, 7.7693818508248915, 7.812447461062076, 7.855319707500102], [0.0, 0.6286481626353579, 0.9203947826969268, 1.150335018179156, 1.3475368359695528, 1.5234954199593194, 1.6841890456614534, 1.833207277205421, 1.9729094063028487, 2.1049463478934736, 2.230527852201113, 2.350572372762519, 2.4657970910212477, 2.5767749765770662, 2.683972552259884, 2.787775795395596, 2.888508441164577, 2.9864452501283565, 3.081821838683819, 3.174842103349623, 3.2656839228159678, 3.354503602953266, 3.4414393882465726, 3.5266142690310667, 3.6101382500685424, 3.6921102018448466, 3.7726193848771064, 3.851746715077407, 3.9295658220743683, 4.006143940517213, 4.0815426655421305, 4.1558185969191195, 4.2290238913272535, 4.301206738309668, 4.372411772437682, 4.442680431849988, 4.512051271469827, 4.5805602377234615, 4.648240910400107, 4.715124716341065, 4.781241118874457, 4.846617786283554, 4.91128074208194, 4.975254499444911, 5.038562181795671, 5.101225631253336, 5.163265506406122, 5.2247013706688055, 5.285551772311524, 5.345834317101519, 5.405565734375956, 5.464761937258916, 5.523438077645756, 5.581608596501086, 5.639287269950382, 5.696487251588113, 5.753221111375896, 5.809500871461271, 5.865338039210495, 5.920743637716145, 5.975728234012013, 6.030301965202771, 6.084474562694102, 6.1382553746897, 6.191653387104539, 6.244677243028887, 6.297335260864125, 6.349635451239732, 6.4015855328102695, 6.4531929470218286, 6.504464871929101, 6.555408235136776, 6.606029725932245, 6.6563358066706995, 6.706332723468214, 6.756026516253687, 6.805423028226068, 6.854527914759392, 6.903346651794628, 6.951884543754073, 7.000146731011149, 7.048138196945819, 7.095863774613402, 7.143328153052469, 7.190535883255386, 7.237491383823401, 7.284198946326407, 7.330662740386075, 7.376886818499624, 7.422875120620268, 7.468631478509203, 7.5141596198729115, 7.55946317229865, 7.604545667000013, 7.6494105423837, 7.694061147447817, 7.738500745021352, 7.782732514853839, 7.826759556563584, 7.870584892452326, 7.9142114701936475, 7.957642165402017], [0.0, 0.6366474033164021, 0.9321063565564699, 1.1649724691750731, 1.3646835837343205, 1.5428811547233163, 1.7056195282896809, 1.8565339440123894, 1.998013714437233, 2.131730761589838, 2.258910229174477, 2.3804822576003546, 2.4971731540944466, 2.6095631790146956, 2.718124791466056, 2.8232488801472866, 2.9252632996107404, 3.0244463066118294, 3.1210365156509563, 3.2152404177303446, 3.3072381549596064, 3.3971880221249764, 3.4852300228050286, 3.5714887123268584, 3.656075495209101, 3.7390905000162205, 3.820624123061809, 3.9007583098733933, 3.9795676269806384, 4.057120164560823, 4.1334783015181475, 4.208699357827027, 4.282836153834787, 4.355937492272955, 4.428048575665957, 4.499211369432552, 4.569464919088541, 4.638845628460894, 4.707387504625236, 4.775122374314067, 4.842080075761961, 4.908288629317576, 4.9737743896309885, 5.038562181795671, 5.102675423469088, 5.166136234700652, 5.228965536949015, 5.291183142563847, 5.352807835832963, 5.413857446548387, 5.474348916919925, 5.5342983625583875, 5.5937211281595935, 5.652631838442375, 5.711044444826669, 5.768972268280009, 5.826428038710629, 5.883423931242025, 5.939971599666064, 5.996082207338791, 6.051766455754339, 6.107034611007083, 6.161896528330089, 6.216361674878374, 6.27043915090829, 6.3241377094892055, 6.3774657748700925, 6.4304314596117775, 6.483042580584928, 6.535306673924402, 6.587231009022129, 6.638822601633182, 6.690088226162867, 6.741034427196687, 6.79166753032949, 6.841993652345322, 6.892018710794979, 6.941748433014371, 6.991188364623138, 7.040343877539759, 7.089220177546398, 7.137822311434089, 7.186155173756423, 7.234223513217691, 7.282031938719414, 7.329584925087384, 7.3768868184996235, 7.4239418416342, 7.47075409855438, 7.517327579347357, 7.563666164531616, 7.609773629246883, 7.6556536472396886, 7.701309794656597, 7.746745553656351, 7.791964315851422, 7.836969385588701, 7.881763983078483, 7.9263512473802, 7.970734239252907, 8.01491594387789, 8.058899273460407], [0.0, 0.6445652419657316, 0.9436987508657586, 1.1794609662517745, 1.3816558424243117, 1.562069615988616, 1.7268319296154293, 1.8796232335298209, 2.0228625556131377, 2.158242611204172, 2.287003780840209, 2.4100877728747236, 2.528229927452133, 2.642017721496197, 2.7519294899780746, 2.8583609829901797, 2.961644132537207, 3.062060655990416, 3.159852135444364, 3.2552276299828065, 3.348369522101714, 3.4394380752634985, 3.5285750342393323, 3.6159065034225235, 3.7015452728443146, 3.785592716345305, 3.868140354477435, 3.9492711519060797, 4.0290606025278395, 4.107577643342008, 4.184885429044999, 4.261041992486686, 4.336100810929016, 4.410111294051962, 4.483119206553447, 4.555167035766576, 4.626294312807333, 4.696537894248785, 4.765932210104806, 4.8345094829297155, 4.902299922049409, 4.969331896295233, 5.035632088084042, 5.101225631253336, 5.166136234700652, 5.23038629357741, 5.293996989537678, 5.356988381332805, 5.419379486866507, 5.481188357675872, 5.542432146677107, 5.603127169907198, 5.663288962900453, 5.722932332259996, 5.782071402916395, 5.84071966150702, 5.898889996259073, 5.956594733715285, 6.013845672603076, 6.070654115114608, 6.127030895836055, 6.182986408538869, 6.238530631023403, 6.293673148185524, 6.348423173459397, 6.40278956877432, 6.45678086314973, 6.510405270040522, 6.563670703534003, 6.616584793490222, 6.6691548997088805, 6.721388125198397, 6.773291328615813, 6.824871135940149, 6.876133951436235, 6.927085967961165, 6.977733176660968, 7.028081376101123, 7.078136180870879, 7.1279030296980395, 7.1773871931078945, 7.226593780657268, 7.2755277477722, 7.324193902215533, 7.372596910208648, 7.420741302229722, 7.468631478509204, 7.516271714241648, 7.563666164531617, 7.610818869090113, 7.657733756696743, 7.704414649441784, 7.750865266761318, 7.797089229277627, 7.843090062456269, 7.888871200090424, 7.934435987622398, 7.979787685311502, 8.024929471256938, 8.069864444283722, 8.114595626699158, 8.159125966926942], [0.0, 0.6524042888987633, 0.9551757873502568, 1.1938052859081207, 1.3984592073731115, 1.5810671297159364, 1.7478332428423575, 1.9024827577249535, 2.0474641218784297, 2.1844906370370603, 2.3148177689469094, 2.439398678791204, 2.558977649743752, 2.6741493034808976, 2.785397792368291, 2.8931236795154724, 2.9976629338040794, 3.099300698784059, 3.1982814946131075, 3.2948169229011075, 3.3890915842359357, 3.4812676911655616, 3.571488712326859, 3.6598822857643376, 3.7465625732343826, 3.8316321814617806, 3.915183744049339, 3.997301234658674, 4.078061065324938, 4.157533011442577, 4.235780995780179, 4.312863756969137, 4.388835422648952, 4.463746003408202, 4.537641820524023, 4.610565878050212, 4.682558187870646, 4.7536560547991416, 4.823894327579092, 4.893305620647746, 4.961920510729532, 5.029767711670678, 5.096874230393152, 5.163265506406122, 5.228965536949015, 5.293996989537678, 5.358381303432347, 5.42213878133406, 5.485288672437694, 5.54784924781877, 5.609837869003126, 5.6712710504594535, 5.732164516661476, 5.792533254286654, 5.852391560049553, 5.911753084608772, 5.970630872935021, 6.02903740148347, 6.086984612474817, 6.144483945555753, 6.201546367080078, 6.2581823972257835, 6.314402135140823, 6.370215282290253, 6.425631164159802, 6.480658750455414, 6.535306673924402, 6.589583247911718, 6.643496482753888, 6.697054101103479, 6.750263552268299, 6.803132025641842, 6.855666463294483, 6.907873571788796, 6.959759833276738, 7.011331515931436, 7.06259468376179, 7.113555205854034, 7.1642187650806965, 7.214590866314077, 7.264676844178321, 7.31448187037145, 7.364010960586199, 7.413268981056264, 7.462260654752482, 7.510990567251614, 7.559463172298651, 7.6076827970820275, 7.65565364723969, 7.703379811612628, 7.750865266761318, 7.798113881259379, 7.845129419777775, 7.891915546971923, 7.938475831183243, 7.984813747965879, 8.030932683448597, 8.076835937541198, 8.122526726994158, 8.168008188319655, 8.213283380581567, 8.258355288061603], [0.0, 0.6601670160503009, 0.9665410851343518, 1.208009951426508, 1.4150989772889675, 1.599879686507932, 1.7686300904435202, 1.9251197250319163, 2.0718261709960606, 2.2104831160396605, 2.342360964250235, 2.468424218137736, 2.589426016837375, 2.7059680572178424, 2.8185402524020042, 2.9275479316577147, 3.033331061441128, 3.136178178124119, 3.236336711322981, 3.3340207804200745, 3.4294171825001714, 3.522690060220795, 3.6139845893012237, 3.7034299265057724, 3.791141591961058, 3.8772234132728793, 3.961769126258417, 4.044863703752091, 4.126584466988747, 4.207002021595493, 4.286181050935261, 4.364180992549576, 4.4410566181235165, 4.516858533303911, 4.591633610528334, 4.665425365540564, 4.738274286311683, 4.810218121532254, 4.881292134598501, 4.951529328015293, 5.0209606423286495, 5.089615133040668, 5.1575201284191, 5.2247013706688055, 5.291183142563847, 5.356988381332805, 5.42213878133406, 5.486654886843291, 5.5505561760947115, 5.613861137564889, 5.6765873393582975, 5.738751492443431, 5.800369508393946, 5.861456552208463, 5.92202709071308, 5.982094936990738, 6.041673291229627, 6.100774778337831, 6.159411482632291, 6.217594979875998, 6.275336366907505, 6.3326462890806665, 6.3895349657096165, 6.446012213693701, 6.502087469479294, 6.557769809499689, 6.613067969220194, 6.667990360903305, 6.722545090197701, 6.77673997164505, 6.830582543189831, 6.884080079769579, 6.937239606055903, 6.990067908410386, 7.04257154611381, 7.09475686192207, 7.146629991997555, 7.198196875260677, 7.249463262202445, 7.300434723195683, 7.351116656339336, 7.401514294867625, 7.451632714153233, 7.501476838331444, 7.55105144657005, 7.600361179007962, 7.649410542383701, 7.698203915373385, 7.7467455536563525, 7.79503959472526, 7.843090062456269, 7.8909008714537805, 7.938475831183243, 7.985818649904509, 8.032932938417426, 8.079822213630525, 8.126489901962916, 8.172939342588855, 8.219173790533791, 8.265196419630147, 8.311010325340519, 8.356618527455524], [0.0, 0.6678557670865719, 0.9777980755462432, 1.2220792513764291, 1.4315801759304148, 1.6185129661151785, 1.7892287512521683, 1.9475409698395438, 2.095956058179042, 2.236227895672538, 2.3696416823917597, 2.4971731540944466, 2.619584221482953, 2.73748358919417, 2.8513668762101467, 2.961644132537207, 3.0686592841105127, 3.1727042277914426, 3.2740292749287496, 3.372851038683766, 3.469358491706302, 3.5637176883701547, 3.656075495209101, 3.746562573234382, 3.835295787998049, 3.922380176352337, 4.007910565825075, 4.091972918901714, 4.174645457352437, 4.255999609125179, 4.336100810929015, 4.415009192555229, 4.492780163596945, 4.56946491908854, 4.645110877375663, 4.719762061015837, 4.79345942953041, 4.866241171256693, 4.938142960292247, 5.009198183511404, 5.079438141814687, 5.148892229104197, 5.2175880919311535, 5.285551772311524, 5.352807835832963, 5.419379486866507, 5.485288672437694, 5.5505561760947115, 5.61520170292845, 5.679243956744763, 5.742700710258137, 5.8055888690642945, 5.86792453005383, 5.9297230348471786, 5.990999018760869, 6.051766455754339, 6.112038699754087, 6.171828522706402, 6.231148149670348, 6.29000929122807, 6.348423173459397, 6.406400565701171, 6.463951806288556, 6.521086826455142, 6.577815172550533, 6.6341460267182955, 6.690088226162867, 6.745650281121637, 6.800840391647141, 6.855666463294482, 6.910136121800131, 6.964256726830461, 7.018035384871151, 7.071478961322335, 7.1245940918586115, 7.1773871931078945, 7.229864472698466, 7.282031938719415, 7.333895408635857, 7.385460517696938, 7.43673272687151, 7.487717330343577, 7.53841946259704, 7.588844105116988, 7.63899609273263, 7.688880119625071, 7.738500745021352, 7.787862398594611, 7.836969385588702, 7.885825891684317, 7.934435987622397, 7.982803633599471, 8.030932683448597, 8.078826888618524, 8.126489901962914, 8.173925281350593, 8.22113649310706, 8.268126915296852, 8.314899840855642, 8.36145848058045, 8.407805965985721, 8.453945352032592], [0.0, 0.6754727665838725, 0.9889500155562658, 1.2360172564100653, 1.4479075717811327, 1.63697235968013, 1.8096351850519334, 1.9697529792573154, 2.1198607648961203, 2.2617324246391632, 2.396667816466036, 2.5256538045534316, 2.6494609893144503, 2.768705017757588, 2.8838871614769155, 2.9954221471632225, 3.1036578232807623, 3.2088894158202796, 3.311370090970616, 3.411318932400095, 3.508927068021159, 3.604362446083713, 3.6977736081573274, 3.789292705462516, 3.879037936421233, 3.9671155358474426, 4.053621412791763, 4.1386425101552415, 4.222257941839584, 4.304539950439646, 4.385554718980406, 4.465363063042823, 4.5440210241751, 4.621580381298989, 4.698089093573786, 4.773591685641172, 4.848129584172244, 4.921741413048272, 4.994463253235481, 5.066328872390728, 5.137369928406201, 5.207616150426055, 5.27709550031475, 5.345834317101519, 5.413857446548387, 5.481188357675872, 5.54784924781877, 5.613861137564889, 5.679243956744763, 5.744016622484077, 5.808197110197906, 5.871802518292936, 5.934849127247318, 5.9973524536550675, 6.059327299750788, 6.1207877988691095, 6.181747457240152, 6.2422191924762505, 6.302215369065178, 6.361747831150103, 6.420827932846049, 6.47946656631583, 6.537674187804941, 6.595460841814244, 6.652836183570954, 6.709809499942419, 6.766389728922778, 6.822585477810008, 6.878405040179528, 6.933856411750531, 6.988947305232207, 7.043685164229076, 7.098077176277395, 7.152130285078264, 7.205851201987186, 7.259246416814721, 7.312322207988123, 7.365084652119675, 7.417539633023595, 7.469692850219924, 7.5215498269607215, 7.573115917810985, 7.624396315814209, 7.675396059270099, 7.7261200381498485, 7.776573000172431, 7.8267595565635855, 7.876684187517564, 7.926351247380203, 7.975764969570535, 8.02492947125694, 8.073848757802605, 8.122526726994158, 8.170967173066211, 8.219173790533791, 8.267150177843773, 8.314899840855643, 8.362426196161293, 8.409732574252839, 8.456822222546947, 8.50369830827347, 8.55036392123586], [0.0, 0.6830201283771978, 1.0000000000000002, 1.249827834539068, 1.4640856959456257, 1.655262989969583, 1.8298550549433459, 1.9917619174608805, 2.1435469250725867, 2.287003780840209, 2.423446866642654, 2.55387407333504, 2.679064611596349, 2.799641007336699, 2.9161101330837065, 3.0288913494564778, 3.1383363915870035, 3.2447437841591413, 3.348369522101714, 3.449435137003656, 3.548133892335755, 3.6446356129094424, 3.739090500016221, 3.8316321814617806, 3.9223801763523376, 4.011441906511337, 4.098914352624463, 4.184885429044999, 4.2694351336499485, 4.352636516233254, 4.434556499312672, 4.515256577989072, 4.594793419988141, 4.673219382780874, 4.750582961395879, 4.826929177968734, 4.9022999220494095, 4.976734249081219, 5.050268643179291, 5.122937249301739, 5.194772079068655, 5.265803193801326, 5.336058867794732, 5.405565734375956, 5.474348916919925, 5.542432146677107, 5.609837869003126, 5.6765873393582975, 5.742700710258137, 5.808197110197906, 5.8730947154400965, 5.937410815439604, 6.0011618725837, 6.064363576840302, 6.1270308958360555, 6.189178120823712, 6.25081890894459, 6.311966322145331, 6.3726328630677065, 6.432830508194835, 6.492570738506389, 6.551864567868228, 6.610722569358193, 6.669154899708881, 6.727171322029718, 6.784781226954405, 6.841993652345323, 6.898817301673667, 6.955260561182715, 7.011331515931437, 7.0670379648066, 7.122387434583472, 7.177387193107895, 7.232044261666072, 7.286365426602507, 7.34035725024134, 7.394026081161522, 7.447378063872069, 7.500419147929704, 7.553155096537779, 7.605591494662136, 7.657733756696743, 7.709587133709311, 7.76115672029474, 7.812447461062076, 7.863464156778697, 7.914211470193648, 7.9646939315604115, 8.014915943877892, 8.064881787867021, 8.114595626699158, 8.164061510491223, 8.213283380581567, 8.262265073599494, 8.311010325340519, 8.359522774458583, 8.407805965985723, 8.455863354688947, 8.50369830827347, 8.551314110440805, 8.598713963809688, 8.645900992707343], [0.0, 0.6904998631689586, 1.010950972718084, 1.2635146650574074, 1.480118858458863, 1.6733897298139937, 1.8498937477280781, 2.013573647879913, 2.1670208489689893, 2.3120486968503444, 2.4499859671629833, 2.5818414786375534, 2.708402975067924, 2.8302997996284724, 2.948044375594034, 3.062060655990416, 3.1727042277914426, 3.28027688481664, 3.385037425388313, 3.4872098070817827, 3.586989409790833, 3.68454791807377, 3.7800371780723454, 3.8735922809467005, 3.965334054653525, 4.05537109738972, 4.1438014518738155, 4.230713995206778, 4.316189601320178, 4.40030211997426, 4.483119206553446, 4.564703029589778, 4.645110877375663, 4.724395680747328, 4.802606465801119, 4.879788747708792, 4.955984874751637, 5.031234330068061, 5.105573997309742, 5.179038395355298, 5.251659886383199, 5.323468860915443, 5.394493902878041, 5.464761937258916, 5.5342983625583875, 5.603127169907198, 5.6712710504594535, 5.738751492443431, 5.8055888690642945, 5.871802518292936, 5.937410815439604, 6.002431239295539, 6.066880432527169, 6.130774256922821, 6.194127844019213, 6.2569556415722145, 6.319271456282125, 6.381088493136609, 6.442419391693525, 6.503276259590134, 6.563670703534003, 6.623613858003533, 6.683116411862055, 6.7421886330682685, 6.800840391647141, 6.859081181068951, 6.916920138169459, 6.97436606173134, 7.031427429835392, 7.088112416079844, 7.144428904756859, 7.200384505067219, 7.2559865644467445, 7.3112421810715515, 7.36615821560322, 7.420741302229722, 7.474997859053123, 7.528934097870788, 7.582556033392876, 7.63586949193542, 7.688880119625071, 7.741593390148679, 7.794014612078252, 7.8461489357994605, 7.89800136006963, 7.9495767382292115, 8.000879784088886, 8.051915077512819, 8.102687069717033, 8.153200088300524, 8.203458342025424, 8.25346592536137, 8.303226822808206, 8.35274491301006, 8.402023972673035, 8.45106768029788, 8.499879619738175, 8.54846328359399, 8.59682207645019, 8.644959317968006, 8.692878245837976, 8.740582018601735], [0.0, 0.6979138854765283, 1.0218057367280184, 1.2770812512543763, 1.4960111631786737, 1.6913572189444923, 1.869756392521874, 2.0351937534579254, 2.190288544984873, 2.3368735831811933, 2.4762919109910047, 2.6095631790146956, 2.7374835891941696, 2.8606892420756473, 2.979698062915636, 3.094938556800498, 3.206770128705909, 3.31549781286639, 3.421383186368785, 3.5246526114615335, 3.625503565867788, 3.7241095775541053, 3.8206241230618097, 3.915183744049339, 4.007910565825075, 4.098914352624463, 4.188294199868488, 4.276139938947675, 4.362533312151672, 4.447548962178995, 4.531255270842206, 4.613715074188154, 4.694986275624034, 4.7751223743140665, 4.854172922756687, 4.93218392482831, 5.009198183511404, 5.085255605881996, 5.160393471618225, 5.234646670234171, 5.308047911386886, 5.380627911906916, 5.452415562631072, 5.523438077645756, 5.5937211281595935, 5.663288962900453, 5.732164516661476, 5.800369508393946, 5.86792453005383, 5.934849127247318, 6.0011618725837, 6.066880432527169, 6.132021628439482, 6.196601492419865, 6.260635318475091, 6.3241377094892055, 6.387122620407554, 6.449603398002151, 6.511592817544079, 6.573103116672496, 6.6341460267182955, 6.694732801712794, 6.754874245287586, 6.814580735650307, 6.8738622488021734, 6.932728380146575, 6.991188364623138, 7.049251095488661, 7.106925141854635, 7.1642187650806965, 7.221139934114083, 7.277696339856945, 7.333895408635857, 7.389744314841338, 7.445249992799137, 7.500419147929703, 7.555258267247432, 7.609773629246883, 7.663971313219247, 7.7178572080387715, 7.771437020455593, 7.824716282928531, 7.877700361028694, 7.930394460442377, 7.982803633599471, 8.034932785951623, 8.086786681922554, 8.138369950551263, 8.18968709084729, 8.24074247687584, 8.29154036258929, 8.342084886420343, 8.392380075651136, 8.442429850571505, 8.492238028438736, 8.541808327250301, 8.59114436934027, 8.640249684809394, 8.689127714798177, 8.737781814611665, 8.78621525670406, 8.834431233530832], [0.0, 0.7052640199876431, 1.032566963529018, 1.2905309320440532, 1.5117665214088436, 1.7091698793948553, 1.8894478777810746, 2.0566275551853157, 2.213355739604164, 2.361484549561558, 2.5023711723631177, 2.6370459971390465, 2.7663136110940894, 2.890816813916976, 3.011078985434443, 3.1275331435675846, 3.240542478393607, 3.3504152366388595, 3.4574157502096754, 3.5617727653061664, 3.663685839403526, 3.7633303279916235, 3.8608613239619465, 3.956416806972057, 4.050120188502547, 4.142082388779465, 4.232403546854951, 4.321174440185826, 4.4084776719370335, 4.494388670912493, 4.578976539093157, 4.662304774288599, 4.744431889720266, 4.825411947982999, 4.905295023441232, 4.984127604464794, 5.061952944819099, 5.138811371864661, 5.214740557893453, 5.289775759861196, 5.363950031909243, 5.437294414364839, 5.509838102330895, 5.581608596501086, 5.652631838442375, 5.722932332259996, 5.792533254286654, 5.861456552208463, 5.9297230348471786, 5.9973524536550675, 6.064363576840302, 6.130774256922821, 6.196601492419865, 6.261861484273964, 6.326569687561914, 6.390740858959173, 6.454389100378683, 6.517527899155027, 6.580170165103053, 6.642328264743569, 6.704014052956896, 6.765238902297057, 6.826013730174935, 6.886349024097071, 6.946254865127714, 7.005740949724994, 7.064816610087025, 7.123490833130631, 7.181772278213569, 7.239669293700629, 7.297189932464641, 7.354341966405086, 7.41113290005948, 7.467569983375993, 7.523660223709767, 7.5794103970999105, 7.634827058879316, 7.6899165536649985, 7.744685024772678, 7.79913842309574, 7.853282515485406, 7.907122892666014, 7.960664976716607, 8.013914028147571, 8.066875152598852, 8.119553307184248, 8.17195330650438, 8.22407982834933, 8.275937419110306, 8.327530498918327, 8.378863366526598, 8.429940203952048, 8.480765080890455, 8.531341958918487, 8.581674695495174, 8.63176704777437, 8.681622676239037, 8.73124514816746, 8.780637940940784, 8.829804445200704, 8.878747967865536, 8.927471735012341], [0.0, 0.7125520073843059, 1.043237201628704, 1.3038668926222001, 1.527388664382928, 1.726831929615429, 1.9089728669052344, 2.0778801290825104, 2.2362278956725383, 2.385887424438005, 2.528229927452133, 2.6642964415781463, 2.7948998683842654, 2.920689650058904, 3.0421945748793533, 3.1598521354443645, 3.27402927492875, 3.385037425388314, 3.4931436502562327, 3.598579059527419, 3.701545272844314, 3.8022194577679627, 3.900758309873394, 3.997301234658674, 4.091972918901715, 4.184885429044999, 4.276139938947675, 4.365828164133643, 4.454033561364244, 4.54083233890209, 4.626294312807333, 4.7104836370569165, 4.793459429530411, 4.875276311489338, 4.955984874751637, 5.035632088084042, 5.11426165222344, 5.19191431126122, 5.268628126783555, 5.344438720080996, 5.419379486866507, 5.493481788228786, 5.5667751209642065, 5.639287269950382, 5.711044444826669, 5.782071402916395, 5.852391560049553, 5.92202709071308, 5.990999018760869, 6.059327299750788, 6.1270308958360555, 6.194127844019213, 6.260635318475091, 6.326569687561914, 6.391946566064617, 6.45678086314973, 6.521086826455142, 6.584878082689517, 6.648167675073869, 6.710968097920932, 6.773291328615813, 6.835148857233107, 6.896551714000956, 6.957510494800653, 7.018035384871151, 7.078136180870878, 7.13782231143409, 7.1971028563457216, 7.2559865644467445, 7.314481870371451, 7.372596910208648, 7.430339536170305, 7.487717330343578, 7.544737617595438, 7.601407477692937, 7.657733756696743, 7.713723077680599, 7.769381850824892, 7.824716282928533, 7.879732386379655, 7.934435987622398, 7.988832735153972, 8.042928107083561, 8.096727418282093, 8.150235827149674, 8.203458342025424, 8.256399827262612, 8.309065008990203, 8.361458480580453, 8.41358470784069, 8.46544803394615, 8.517052684129473, 8.568402770141454, 8.619502294496513, 8.670355154515507, 8.72096514617759, 8.771335967792066, 8.821471223500401, 8.871374426617958, 8.921049002824313, 8.97049829321048, 9.019725557190842], [0.0, 0.7197795096886299, 1.0538188843698788, 1.3170921742483819, 1.5428811547233166, 1.7443473974284955, 1.9283358125589796, 2.0989563217890352, 2.258910229174477, 2.410087772874723, 2.5538740733350394, 2.6913207267830894, 2.823248880147286, 2.950314562987723, 3.0730519271459698, 3.1919029027618016, 3.3072381549596064, 3.4193722746886843, 3.528575034239332, 3.635079887783452, 3.7390905000162205, 3.8407858355309568, 3.9403241792851054, 4.037846350783778, 4.1334783015181475, 4.227333234634355, 4.319513350210395, 4.410111294051962, 4.499211369432552, 4.586890557604522, 4.673219382780874, 4.758262649660199, 4.842080075761962, 4.924726836377833, 5.0062540364847585, 5.086709121259426, 5.166136234700652, 5.244576534172135, 5.322068467323381, 5.398648016756053, 5.474348916919924, 5.549202847003056, 5.6232396029914415, 5.696487251588113, 5.768972268280009, 5.84071966150702, 5.911753084608772, 5.982094936990738, 6.051766455754339, 6.1207877988691095, 6.189178120823712, 6.2569556415722145, 6.3241377094892055, 6.390740858959173, 6.45678086314973, 6.522272782452906, 6.587231009022129, 6.651669307783438, 6.715600854256835, 6.779038269486399, 6.841993652345322, 6.904478609453433, 6.966504282919828, 7.028081376101123, 7.089220177546398, 7.149930583282788, 7.210222117580339, 7.270103952321359, 7.329584925087385, 7.388673556066236, 7.447378063872068, 7.5057063803627955, 7.563666164531616, 7.6212648155425216, 7.6785094849735085, 7.735407088325678, 7.791964315851421, 7.8481876427503705, 7.904083338777756, 7.959657477306104, 8.014915943877888, 8.06986444428372, 8.124508512197917, 8.178853516400789, 8.232904667614728, 8.286667024979055, 8.340145502186767, 8.393344873304535, 8.44626977829575, 8.498924728264976, 8.551314110440803, 8.603442192912926, 8.655313129138131, 8.706930962228832, 8.758299629036888, 8.809422964044536, 8.860304703073483, 8.910948486822445, 8.961357864242773, 9.011536295761129, 9.061487156357623, 9.111213738507278], [0.0, 0.7269481151778124, 1.0643143371264683, 1.3302096832396575, 1.5582473969767123, 1.7617201319394524, 1.947540969839544, 2.1198607648961203, 2.2814077246581093, 2.434090913010673, 2.5793092454319924, 2.7181247914660562, 2.8513668762101467, 2.9796980629156367, 3.103657823280762, 3.223692488824865, 3.3401764162917935, 3.4534273297825644, 3.5637176883701547, 3.6712832713007937, 3.7763297716572843, 3.879037936421232, 3.979567626980639, 4.078061065324938, 4.174645457352438, 4.2694351336499485, 4.362533312151672, 4.454033561364244, 4.544021024175099, 4.632573448527255, 4.719762061015837, 4.805652311758363, 4.890304513027736, 4.9737743896309885, 5.056113555522349, 5.1373699284062, 5.2175880919311535, 5.296809613365469, 5.375073323275955, 5.452415562631073, 5.52887040185704, 5.6044698356490965, 5.679243956744762, 5.753221111375896, 5.826428038710629, 5.898889996259073, 5.970630872935021, 6.041673291229627, 6.112038699754087, 6.181747457240152, 6.25081890894459, 6.319271456282125, 6.387122620407554, 6.454389100378683, 6.521086826455142, 6.587231009022129, 6.652836183570954, 6.717916252118699, 6.782484521406253, 6.846553738176307, 6.910136121800131, 6.973243394493067, 7.035886809333447, 7.098077176277395, 7.159824886342245, 7.221139934114083, 7.282031938719415, 7.342510163387418, 7.402583533717049, 7.462260654752482, 7.521549826960721, 7.580459061196594, 7.638996092732631, 7.697168394424403, 7.754983189075662, 7.812447461062075, 7.869567967267242, 7.926351247380201, 7.982803633599472, 8.038931259785011, 8.094740070096034, 8.150235827149672, 8.205424119732573, 8.26031037009513, 8.314899840855642, 8.36919764153966, 8.423208734777845, 8.476937942183923, 8.530389949932758, 8.583569314057014, 8.636480465479652, 8.689127714798177, 8.741515256835507, 8.793647174971214, 8.845527445266026, 8.8971599403915, 8.948548433376057, 8.99969660117776, 9.050608028093547, 9.101286209014017, 9.151734552532215, 9.20195638391439], [0.0, 0.7340593429100174, 1.0747257839298014, 1.343222199252286, 1.5734906473155712, 1.7789538145050467, 1.9665924084018969, 2.140597888144669, 2.3037251494389506, 2.4579019312139128, 2.6045408335647466, 2.7447143155229954, 2.8792598148964745, 3.0088463763319524, 3.1340187488040234, 3.2552276299828065, 3.3728510386837662, 3.487209807081783, 3.5985790595274185, 3.7071968817312553, 3.8132709789284416, 3.916983866222572, 4.018496968814405, 4.117953899952166, 4.215483109900978, 4.3112000476642525, 4.40520894088544, 4.49760427338679, 4.588472020949377, 4.677890692070262, 4.765932210104806, 4.852662665423496, 4.9381429602922475, 5.0224293646351175, 5.105573997309743, 5.187625244766078, 5.268628126783555, 5.348624617254104, 5.427653926596958, 5.505752751278991, 5.582955495013703, 5.659294465478181, 5.734800049786261, 5.809500871461271, 5.883423931242025, 5.956594733715285, 6.02903740148347, 6.100774778337831, 6.171828522706402, 6.2422191924762505, 6.311966322145331, 6.381088493136609, 6.449603398002151, 6.517527899155027, 6.584878082689517, 6.651669307783438, 6.717916252118699, 6.783632953706145, 6.848832849457255, 6.913528810807235, 6.977733176660968, 7.04145778390407, 7.104713995695913, 7.167512727738902, 7.229864472698465, 7.291779322930772, 7.353266991659551, 7.414336832729708, 7.474997859053123, 7.535258759851136, 7.59512791678844, 7.6546134190844874, 7.713723077680599, 7.772464438534089, 7.83084479510438, 7.888871200090423, 7.946550476473713, 8.003889227916515, 8.060893848560843, 8.117570532269937, 8.173925281350591, 8.22996391479161, 8.285692076050848, 8.341115240420809, 8.396238722000325, 8.451067680297879, 8.505607126490094, 8.559861929357194, 8.61383682091563, 8.667536401766561, 8.72096514617759, 8.774127406913797, 8.827027419833131, 8.879669308260032, 8.93205708715026, 8.984194667059027, 9.036085857923664, 9.087734372671358, 9.13914383066173, 9.190317760973464, 9.241259605543496, 9.291972722166847], [0.0, 0.7411146468982311, 1.0850553535794931, 1.3561323829192806, 1.588614022484959, 1.7960519688484946, 1.9854940236407748, 2.1611719315966846, 2.3258670666988706, 2.48152569605721, 2.629573996766059, 2.7710947356400517, 2.906933399397983, 3.03776546311137, 3.1641409115298833, 3.2865147741383662, 3.4052687030248263, 3.5207266139956594, 3.633166275718873, 3.7428280622310286, 3.8499216750957554, 3.954631383633867, 4.057120164560824, 4.157533011442577, 4.25599960912518, 4.352636516233254, 4.447548962178995, 4.54083233890209, 4.632573448527255, 4.722851554124485, 4.81173927032995, 4.899303322732063, 4.98560519894996, 5.0707017097378415, 5.15464547488612, 5.2374853459040365, 5.319266775272043, 5.400032140307995, 5.479821028296333, 5.558670488406654, 5.636615255018717, 5.713687946330121, 5.789919241516002, 5.865338039210495, 5.939971599666064, 6.013845672603076, 6.086984612474817, 6.159411482632291, 6.231148149670348, 6.302215369065178, 6.3726328630677065, 6.442419391693525, 6.511592817544079, 6.580170165103053, 6.648167675073869, 6.715600854256835, 6.782484521406253, 6.848832849457255, 6.914659404468226, 6.979977181586296, 7.044798638309921, 7.109135725293212, 7.172999914910887, 7.236402227780029, 7.299353257414781, 7.3618631931725185, 7.423941841634202, 7.485598646547844, 7.5468427074516145, 7.607682797082028, 7.668127377662926, 7.728184616162107, 7.787862398594612, 7.847168343444623, 7.906109814271576, 7.9646939315604115, 8.02292758387071, 8.080817438334869, 8.138369950551265, 8.19559137391455, 8.252487768421808, 8.309065008990203, 8.365328793318866, 8.421284649325267, 8.476937942183923, 8.53229388099318, 8.587357525093848, 8.642133790061726, 8.69662745339434, 8.750843159910865, 8.804785426882663, 8.858458648910783, 8.911867102565505, 8.965014950801995, 9.017906247165174, 9.070544939795981, 9.122934875250408, 9.175079802141894, 9.226983374617006, 9.278649155673653, 9.330080620330445, 9.381281158655355], [0.0, 0.7481154199650512, 1.0953050852871857, 1.3689427829041125, 1.6036205080654722, 1.813017970401356, 2.0042495470179094, 2.181586956876258, 2.347837847583714, 2.504966871225301, 2.654413676956995, 2.797271259706968, 2.9343930928944197, 3.0664610323144257, 3.194030258024075, 3.3175600978420463, 3.4374358090470816, 3.553984367243494, 3.667486164978631, 3.778183846928404, 3.8862890955551683, 3.9919879208384907, 4.095444839016773, 4.196806213305121, 4.296202953588363, 4.39375271953599, 4.489561734586207, 4.583726291777234, 4.676334013190564, 4.767464910636982, 4.857192284690509, 4.945583491247846, 5.032700598757111, 5.118600954622535, 5.203337675695564, 5.286960074950249, 5.369514034223692, 5.451042331141562, 5.531584926940693, 5.611179220767341, 5.6898602751117835, 5.767661016292096, 5.8446124132873525, 5.920743637716145, 5.996082207338791, 6.070654115114608, 6.144483945555753, 6.217594979875998, 6.29000929122807, 6.361747831150103, 6.432830508194835, 6.503276259590134, 6.573103116672496, 6.642328264743569, 6.710968097920932, 6.779038269486399, 6.846553738176307, 6.913528810807235, 6.979977181586296, 7.045911968416354, 7.111345746472827, 7.176290579298999, 7.240758047640798, 7.304759276219088, 7.368304958617269, 7.4314053804441915, 7.494070440916477, 7.556309672990388, 7.618132262160833, 7.679547064034016, 7.740562620770271, 7.801187176484829, 7.861428691686197, 7.921294856824859, 7.98079310501846, 8.039930624014001, 8.098714367442296, 8.157151065415313, 8.215247234512786, 8.273009187200653, 8.330443040720404, 8.387554725485286, 8.444349993016466, 8.500834423449644, 8.557013432640254, 8.612892278893218, 8.668476069341278, 8.723769765994106, 8.778778191478798, 8.833506034490759, 8.887957854972745, 8.942138089038417, 8.996051053655718, 9.04970095110423, 9.103091873219777, 9.15622780543853, 9.2091126306521, 9.261750132884366, 9.31414400079997, 9.36629783105388, 9.418215131490685, 9.46989932420188], [0.0, 0.7550629973077783, 1.1054769338961483, 1.3816558424243115, 1.6185129661151787, 1.8298550549433454, 2.0228625556131377, 2.201846857565767, 2.3696416823917597, 2.5282299274521325, 2.6790646115963486, 2.8232488801472866, 2.9616441325372067, 3.094938556800498, 3.2236924888248644, 3.348369522101714, 3.4693584917063025, 3.586989409790833, 3.7015452728443137, 3.8132709789284416, 3.9223801763523367, 4.0290606025278395, 4.1334783015181475, 4.235780995780179, 4.336100810929016, 4.434556499312672, 4.531255270842206, 4.626294312807333, 4.719762061015837, 4.81173927032995, 4.902299922049409, 4.991511997589773, 5.079438141814687, 5.166136234700652, 5.2516598863832, 5.336058867794731, 5.419379486866507, 5.501664918490255, 5.582955495013704, 5.663288962900454, 5.742700710258136, 5.821223969184034, 5.898889996259072, 5.975728234012013, 6.051766455754339, 6.127030895836055, 6.201546367080078, 6.275336366907505, 6.348423173459397, 6.420827932846049, 6.492570738506389, 6.563670703534003, 6.6341460267182955, 6.704014052956896, 6.773291328615813, 6.841993652345322, 6.910136121800131, 6.977733176660968, 7.044798638309921, 7.111345746472827, 7.177387193107894, 7.242935153789781, 7.308001316812161, 7.372596910208648, 7.43673272687151, 7.500419147929702, 7.563666164531616, 7.626483398163904, 7.688880119625072, 7.750865266761318, 7.812447461062075, 7.873635023203789, 7.934435987622398, 7.994858116187842, 8.05490891104744, 8.114595626699158, 8.173925281350591, 8.232904667614728, 8.29154036258929, 8.34983873736265, 8.40780596598572, 8.465448033946148, 8.522770746178162, 8.579779734638915, 8.636480465479652, 8.692878245837974, 8.748978230275402, 8.804785426882662, 8.860304703073483, 8.915540791086121, 8.970498293210479, 9.025181686757394, 9.079595328785501, 9.133743460600002, 9.187630212036666, 9.241259605543496, 9.294635560071638, 9.347761894786336, 9.400642332608019, 9.453280503592968, 9.50567994816233, 9.557844120187777], [0.0, 0.7619586598000293, 1.115572774715122, 1.3942739052929405, 1.633294142246782, 1.8465663266036165, 2.04133648096964, 2.221955368833746, 2.391282590935293, 2.551319153575886, 2.7035313453952132, 2.849032386263381, 2.988691542399629, 3.1232032867608406, 3.2531330725390735, 3.3789487270237926, 3.5010426363521567, 3.619747826534058, 3.7353498785425554, 3.8480959269870048, 3.9582015713337637, 4.065856263518935, 4.171227564014048, 4.274464544361074, 4.3757005368209665, 4.47505537825537, 4.572637257676909, 4.668544249944613, 4.7628655985121, 4.855682795740692, 4.947070498569214, 5.037097309257974, 5.125826444778955, 5.213316313701349, 5.299621015758781, 5.384790776419963, 5.468872326526386, 5.551909235267314, 5.633942203328296, 5.715009321894994, 5.795146302259261, 5.874386680012695, 5.9527619971890005, 6.030301965202771, 6.107034611007083, 6.182986408538869, 6.2581823972257835, 6.3326462890806665, 6.406400565701171, 6.47946656631583, 6.551864567868228, 6.623613858003533, 6.694732801712794, 6.765238902297057, 6.835148857233107, 6.904478609453433, 6.973243394493067, 7.04145778390407, 7.109135725293212, 7.176290579298999, 7.242935153789781, 7.309081735534452, 7.374742119570798, 7.439927636473187, 7.504649177700687, 7.568917219188595, 7.632741843330122, 7.696132759480782, 7.759099323105257, 7.821650553675215, 7.883795151416406, 7.945541512994402, 8.006897746220154, 8.067871683849395, 8.128470896543291, 8.188702705051993, 8.248574191677339, 8.308092211066297, 8.36726340038237, 8.426094188898313, 8.484590807049969, 8.542759294987839, 8.600605510660099, 8.658135137458117, 8.71535369145313, 8.772266528250517, 8.828878849486172, 8.885195708987542, 8.941222018620328, 8.996962553840266, 9.052421958967974, 9.107604752203622, 9.162515330396975, 9.217157973587229, 9.27153684932615, 9.325656016797016, 9.379519430741048, 9.433130945202267, 9.486494317100924, 9.53961320964502, 9.592491195588838, 9.645131760346757], [0.0, 0.7688036370533357, 1.125594408000761, 1.406799221520875, 1.6479666721902984, 1.863154765280382, 2.059674617296155, 2.24191607636284, 2.412764432148929, 2.5742386667903365, 2.7278182411799365, 2.8746263756840458, 3.01554014548558, 3.1512602622678054, 3.282357258913374, 3.4093031653900896, 3.532493892795617, 3.652265458844757, 3.768906009997869, 3.882664900972653, 3.993759668051099, 4.102381465091294, 4.208699357827027, 4.312863756969136, 4.415009192555229, 4.515256577989071, 4.613715074188154, 4.710483637056916, 4.8056523117583625, 4.899303322732063, 4.991511997589773, 5.08234755487315, 5.171873779457343, 5.260149604618919, 5.347229616090895, 5.433164490537315, 5.51800137860138, 5.601784240871686, 5.6845541436642, 5.766349520352836, 5.847206403038164, 5.927158628575318, 6.006238022352621, 6.084474562694102, 6.161896528330089, 6.238530631023403, 6.314402135140823, 6.3895349657096165, 6.463951806288556, 6.537674187804941, 6.610722569358193, 6.683116411862055, 6.754874245287586, 6.826013730174935, 6.896551714000956, 6.966504282919828, 7.035886809333447, 7.104713995695913, 7.172999914910887, 7.240758047640798, 7.308001316812161, 7.374742119570798, 7.440992356914003, 7.5067634612031915, 7.572066421739735, 7.636911808568419, 7.701309794656597, 7.765270176582777, 7.828802393855498, 7.891915546971923, 7.9546184143153855, 8.01691946798204, 8.078826888618524, 8.140348579345321, 8.20149217883386, 8.262265073599492, 8.322674409567188, 8.382727102961933, 8.442429850571505, 8.50178913942537, 8.560811255929847, 8.619502294496511, 8.677868165697813, 8.735914603981284, 8.793647174971214, 8.851071282384519, 8.90819217458545, 8.965014950801994, 9.021544567025094, 9.077785841610297, 9.133743460600002, 9.189421982783164, 9.244825844508195, 9.299959364263584, 9.354826747039871, 9.409432088485586, 9.463779378868963, 9.517872506856433, 9.571715263118147, 9.625311343770168, 9.678664353662242, 9.731777809519611], [0.0, 0.7755991102597499, 1.135543563119454, 1.4192339525183644, 1.662533087886321, 1.8796232335298209, 2.0778801290825104, 2.2617324246391632, 2.4340909130106736, 2.596992422162953, 2.7519294899780746, 2.900035264993264, 3.0421945748793533, 3.179114324926452, 3.311370090970616, 3.439438075263499, 3.563717688370155, 3.684547918073771, 3.8022194577679627, 3.9169838662225724, 4.0290606025278395, 4.1386425101552415, 4.24590014921452, 4.350985259900275, 4.454033561364245, 4.555167035766577, 4.654495808900651, 4.752119711344442, 4.848129584172244, 4.942608378607354, 5.035632088084042, 5.127270542968262, 5.217588091931154, 5.306644189161888, 5.394493902878042, 5.4811883576758715, 5.5667751209642065, 5.651298541900307, 5.734800049786261, 5.81731841770947, 5.898889996259072, 5.979548921374956, 6.059327299750787, 6.1382553746897, 6.216361674878374, 6.293673148185524, 6.370215282290253, 6.446012213693701, 6.521086826455142, 6.595460841814244, 6.669154899708881, 6.7421886330682685, 6.814580735650307, 6.886349024097071, 6.957510494800653, 7.028081376101123, 7.098077176277395, 7.167512727738902, 7.236402227780029, 7.304759276219088, 7.372596910208648, 7.439927636473187, 7.5067634612031915, 7.573115917810986, 7.638996092732631, 7.704414649441784, 7.769381850824892, 7.83390758005265, 7.898001360069632, 7.961672371812504, 8.024929471256938, 8.08778120538414, 8.150235827149674, 8.21230130952989, 8.273985358714608, 8.335295426508766, 8.396238722000327, 8.456822222546949, 8.517052684129473, 8.57693665111637, 8.636480465479652, 8.695690275499539, 8.754572043992166, 8.813131556091982, 8.871374426617958, 8.929306107050593, 8.986931892144545, 9.0442569262, 9.101286209014019, 9.158024601531707, 9.2144768312155, 9.270647497149591, 9.326541074895383, 9.382161921112585, 9.437514277959743, 9.49260227728692, 9.547429944632427, 9.602001203034705, 9.656319876669727, 9.710389694323611, 9.764214292709456, 9.817797219636917], [0.0, 0.7823462148343429, 1.1454219024161645, 1.4315801759304145, 1.6769958231503326, 1.8959744829700282, 2.095956058179042, 2.2814077246581093, 2.4552655968349617, 2.619584221482953, 2.7758691203943213, 2.9252632996107404, 3.0686592841105127, 3.206770128705909, 3.3401764162917935, 3.4693584917063025, 3.5947192400734664, 3.716600598104588, 3.8352957879980485, 3.95105855688789, 4.064110272986491, 4.174645457352437, 4.282836153834787, 4.388835422648951, 4.492780163596945, 4.59479341998814, 4.694986275624033, 4.79345942953041, 4.890304513027735, 4.98560519894996, 5.079438141814687, 5.171873779457343, 5.262977020332091, 5.352807835832963, 5.441421773227884, 5.52887040185704, 5.61520170292845, 5.700460411402291, 5.784688316983125, 5.8679245300538305, 5.9502057174251926, 6.031566311993029, 6.112038699754086, 6.191653387104539, 6.27043915090829, 6.348423173459397, 6.425631164159802, 6.502087469479294, 6.577815172550533, 6.652836183570954, 6.727171322029718, 6.800840391647141, 6.8738622488021734, 6.946254865127714, 7.018035384871151, 7.089220177546398, 7.159824886342245, 7.229864472698465, 7.299353257414781, 7.368304958617269, 7.43673272687151, 7.504649177700687, 7.572066421739735, 7.638996092732631, 7.705449373558743, 7.771437020455593, 7.836969385588701, 7.9020564381046015, 7.966707783790025, 8.030932683448597, 8.094740070096034, 8.158138565065585, 8.22113649310706, 8.283741896555457, 8.345962548638411, 8.407805965985721, 8.469279420398768, 8.530389949932758, 8.591144369340268, 8.651549279920651, 8.711611078816103, 8.771335967792064, 8.830729961536504, 8.889798895510001, 8.948548433376057, 9.006984074038776, 9.065111158313039, 9.122934875250406, 9.180460268142262, 9.23769224022012, 9.294635560071638, 9.351294866789441, 9.407674674868804, 9.463779378868963, 9.519613257851923, 9.575180479611603, 9.630485104705343, 9.685531090298944, 9.740322293835717, 9.794862476539297, 9.849155306759332, 9.90320436316865], [0.0, 0.7890460428745772, 1.1552310248151674, 1.4438398901370888, 1.6913572189444923, 1.912211160241179, 2.1139053303854154, 2.300945161096155, 2.4762919109910047, 2.642017721496196, 2.7996410073366986, 2.950314562987723, 3.0949385568004977, 3.234232150020142, 3.3687808975161837, 3.499069257686401, 3.625503565867788, 3.7484286870368084, 3.8681403544774344, 3.98489448835418, 4.098914352624463, 4.21039613417923, 4.319513350210395, 4.426420371704867, 4.531255270842207, 4.634142144645599, 4.735193028211955, 4.834509482929715, 4.93218392482831, 5.02830074329606, 5.122937249301738, 5.216164483893739, 5.308047911386887, 5.398648016756052, 5.488020822962833, 5.5762183409750525, 5.663288962900453, 5.749277806798838, 5.834227020251916, 5.918176048574641, 6.001161872583698, 6.083219220050085, 6.164380754316569, 6.244677243028887, 6.3241377094892055, 6.40278956877432, 6.480658750455414, 6.557769809499689, 6.6341460267182955, 6.709809499942419, 6.784781226954405, 6.859081181068951, 6.932728380146575, 7.005740949724994, 7.078136180870878, 7.149930583282788, 7.221139934114083, 7.291779322930772, 7.3618631931725185, 7.4314053804441915, 7.500419147929702, 7.568917219188595, 7.636911808568419, 7.704414649441784, 7.771437020455593, 7.837989769961244, 7.904083338777756, 7.9697277814250755, 8.034932785951623, 8.099707692468353, 8.164061510491221, 8.228002935184533, 8.29154036258929, 8.354681903913145, 8.417435398951817, 8.479808428705745, 8.5418083272503, 8.603442192912926, 8.664716898806136, 8.72563910276124, 8.786215256704057, 8.846451615510478, 8.906354245376834, 8.965929031737213, 9.025181686757392, 9.08411775643279, 9.142742627315759, 9.201061532895677, 9.259079559653479, 9.316801652810796, 9.374232621792341, 9.431377145418836, 9.488239776846623, 9.544824948268905, 9.601136975392562, 9.657180061703517, 9.712958302532762, 9.76847568893433, 9.823736111385765, 9.878743363320929, 9.933501144504355, 9.988013064255775], [0.0, 0.7956996454518596, 1.1649724691750734, 1.4560150184467129, 1.7056195282896809, 1.9283358125589793, 2.1317307615898384, 2.32034779899328, 2.4971731540944466, 2.664296441578146, 2.8232488801472866, 2.9751929851753234, 3.1210365156509567, 3.2615046971208237, 3.3971880221249764, 3.5285750342393323, 3.656075495209101, 3.7800371780723454, 3.9007583098733933, 4.018496968814405, 4.1334783015181475, 4.245900149214519, 4.355937492272956, 4.463746003408202, 4.569464919088541, 4.673219382780874, 4.7751223743140665, 4.875276311489338, 4.973774389630989, 5.0707017097378415, 5.166136234700652, 5.26014960461892, 5.352807835832963, 5.4441719233550465, 5.534298362558388, 5.6232396029914415, 5.711044444826669, 5.797758386580301, 5.883423931242025, 5.968080856748004, 6.051766455754339, 6.134515748872716, 6.216361674878374, 6.297335260864125, 6.3774657748700925, 6.45678086314973, 6.535306673924402, 6.613067969220194, 6.690088226162867, 6.766389728922778, 6.841993652345323, 6.916920138169459, 6.991188364623138, 7.064816610087025, 7.13782231143409, 7.210222117580339, 7.282031938719415, 7.353266991659551, 7.423941841634202, 7.494070440916477, 7.563666164531616, 7.632741843330122, 7.701309794656597, 7.769381850824892, 7.836969385588701, 7.904083338777756, 7.9707342392529075, 8.036932226318486, 8.102687069717033, 8.168008188319655, 8.232904667614728, 8.297385276088221, 8.361458480580453, 8.425132460696542, 8.488415122341008, 8.551314110440803, 8.613836820915628, 8.67599041194932, 8.737781814611665, 8.799217742875904, 8.860304703073483, 8.921049002824313, 8.98145675947771, 9.041533908096476, 9.101286209014017, 9.160719254992163, 9.21983847800518, 9.278649155673653, 9.337156417370089, 9.395365250016521, 9.45328050359297, 9.510906896374136, 9.568249019910699, 9.62531134377017, 9.682098220051472, 9.738613887686274, 9.794862476539297, 9.850848011319, 9.906574415309237, 9.962045513931868, 10.017265038149553, 10.072236627717489], [0.0, 0.8023080347490851, 1.1746477174183814, 1.4681074130072747, 1.7197849208474312, 1.9443508928948954, 2.149435063495688, 2.3396185899862814, 2.5179125027157037, 2.686423770891159, 2.8466963301865214, 2.999902350816988, 3.146957130828013, 3.288591918858951, 3.4254021115673874, 3.557880309947332, 3.686439678868713, 3.811430879670016, 3.933154616210054, 4.051871110064106, 4.167807377726991, 4.281162903525819, 4.392114121064807, 4.500817995940893, 4.607414920999381, 4.71203107903998, 4.814780388203767, 4.915766116885151, 5.015082234407753, 5.112814548545286, 5.209041669680476, 5.303835832893194, 5.397263602798067, 5.48938648097889, 5.580261432010323, 5.669941341041156, 5.758475413535647, 5.845909525881136, 5.93228653406018, 6.017646546369888, 6.102027165186733, 6.185463701973148, 6.2679893690651936, 6.349635451239732, 6.4304314596117775, 6.510405270040522, 6.589583247911718, 6.667990360903305, 6.745650281121637, 6.822585477810008, 6.898817301673667, 6.97436606173134, 7.049251095488661, 7.123490833130631, 7.1971028563457216, 7.270103952321359, 7.342510163387418, 7.414336832729708, 7.485598646547844, 7.556309672990388, 7.626483398163904, 7.696132759480782, 7.765270176582777, 7.83390758005265, 7.9020564381046015, 7.9697277814250755, 8.036932226318486, 8.103679996297409, 8.169980942243367, 8.23584456125242, 8.301280014269114, 8.366296142602835, 8.43090148341211, 8.495104284234753, 8.558912516634845, 8.622333889031454, 8.68537585876836, 8.748045643479049, 8.810350231796747, 8.872296393455114, 8.933890688821531, 8.995139477901514, 9.056048928849762, 9.116625026020545, 9.176873577587594, 9.236800222761353, 9.296410438629339, 9.35570954664347, 9.414702718776354, 9.47339498336707, 9.531791230675346, 9.589896218161776, 9.647714575510461, 9.705250809409259, 9.762509308101837, 9.819494345724747, 9.876210086441777, 9.932660588387108, 9.988849807427982, 10.044781600756885, 10.100459730322612, 10.155887866108996], [0.0, 0.8088721860566652, 1.1842581974538322, 1.4801188584588632, 1.733855487198506, 1.9602587648134189, 2.1670208489689893, 2.3587603781294106, 2.5385130176441657, 2.7084029750679246, 2.8699868179153665, 3.02444630661183, 3.1727042277914426, 3.31549781286639, 3.4534273297825644, 3.5869894097908332, 3.7166005981045886, 3.8426144250278305, 3.9653340546535247, 4.085021837581862, 4.2019066476623905, 4.316189601320178, 4.428048575665957, 4.537641820524023, 4.645110877375663, 4.750582961395879, 4.854172922756687, 4.955984874751637, 5.056113555522349, 5.15464547488612, 5.2516598863832, 5.347229616090895, 5.4414217732278845, 5.5342983625583875, 5.625916814717571, 5.71633044753856, 5.805588869064295, 5.893738331023675, 5.980822040029118, 6.06688043252717, 6.151951418541341, 6.23607059843779, 6.319271456282125, 6.4015855328102695, 6.483042580584928, 6.563670703534003, 6.643496482753888, 6.722545090197701, 6.800840391647141, 6.878405040179528, 6.955260561182715, 7.031427429835392, 7.106925141854635, 7.181772278213569, 7.2559865644467445, 7.329584925087385, 7.402583533717049, 7.474997859053123, 7.5468427074516145, 7.618132262160833, 7.688880119625072, 7.759099323105257, 7.828802393855498, 7.898001360069632, 7.966707783790025, 8.034932785951623, 8.102687069717033, 8.169980942243367, 8.23682433500797, 8.303226822808208, 8.369197641539662, 8.434745704847645, 8.499879619738175, 8.564607701226992, 8.628937986098206, 8.692878245837976, 8.756435998802965, 8.819618521678347, 8.882432860275438, 8.944885839715054, 9.006984074038776, 9.068733975287046, 9.130141762079845, 9.191213467732943, 9.25195494794014, 9.312371888049558, 9.372469809959972, 9.432254078661208, 9.49172990844081, 9.550902368777637, 9.609776389941494, 9.668356768316544, 9.726648171465042, 9.78465514294669, 9.842382106907948, 9.899833372454578, 9.957013137819827, 10.013925494339846, 10.070574430247142, 10.126963834292145, 10.183097499202358, 10.238979124987894], [0.0, 0.8153930396383419, 1.1938052859081207, 1.4920510753478395, 1.7478332428423575, 1.9760617069937687, 2.1844906370370607, 2.377775905335293, 2.558977649743752, 2.7302372024588983, 2.8931236795154724, 3.048828368291074, 3.1982814946131075, 3.342226233203687, 3.481267691165562, 3.615906503422524, 3.7465625732343826, 3.873592280946701, 3.997301234658674, 4.117953899952167, 4.235780995780179, 4.350985259900275, 4.463746003408202, 4.5742227518847365, 4.682558187870647, 4.7888805521065825, 4.893305620647746, 4.995938346113793, 5.096874230393152, 5.196200480715966, 5.293996989537678, 5.3903371700347655, 5.485288672437695, 5.578914001372093, 5.6712710504594535, 5.762413567363214, 5.852391560049552, 5.941251653113141, 6.02903740148347, 6.1157895675920235, 6.201546367080078, 6.286343687311886, 6.3702152822902525, 6.4531929470218286, 6.535306673924402, 6.616584793490222, 6.697054101103479, 6.77673997164505, 6.855666463294482, 6.933856411750531, 7.011331515931437, 7.088112416079844, 7.1642187650806965, 7.239669293700629, 7.314481870371451, 7.388673556066236, 7.462260654752482, 7.535258759851136, 7.607682797082028, 7.679547064034016, 7.750865266761318, 7.821650553675215, 7.891915546971923, 7.961672371812504, 8.030932683448597, 8.099707692468353, 8.168008188319655, 8.23584456125242, 8.303226822808208, 8.370164624973146, 8.436667278099486, 8.502743767691328, 8.568402770141454, 8.633652667498447, 8.69850156133625, 8.762957285792108, 8.827027419833133, 8.890719298806662, 8.954040025324963, 9.016996479530661, 9.079595328785501, 9.141843036821621, 9.203745872391412, 9.265309917449194, 9.326541074895383, 9.387445075911451, 9.448027486911856, 9.508293716137151, 9.5682490199107, 9.627898508579785, 9.687247152160374, 9.746299785703457, 9.805061114399592, 9.863535718437124, 9.92172805762848, 9.979642475817974, 10.037283205083588, 10.09465436974444, 10.151759990184813, 10.20860398650493, 10.265190182007975, 10.321522306532293], [0.0, 0.8218715024770432, 1.2032903106819786, 1.5039057233214996, 1.7617201319394524, 1.99176191746088, 2.201846857565767, 2.396667816466036, 2.5793092454319924, 2.751929489978074, 2.916110133083706, 3.0730519271459698, 3.2236924888248644, 3.3687808975161837, 3.5089270680211584, 3.644635612909442, 3.776329771657285, 3.9043687561242715, 4.029060602527839, 4.150671877682462, 4.2694351336499485, 4.385554718980406, 4.499211369432553, 4.610565878050212, 4.719762061015838, 4.826929177968734, 4.93218392482831, 5.035632088084042, 5.1373699284062, 5.237485345904036, 5.336058867794732, 5.433164490537316, 5.5288704018570405, 5.6232396029914415, 5.71633044753856, 5.808197110197905, 5.898889996259072, 5.988456100758583, 6.076939324678663, 6.16438075431657, 6.250818908944589, 6.336289961059351, 6.4208279328460485, 6.504464871929101, 6.587231009022129, 6.6691548997088805, 6.750263552268299, 6.830582543189831, 6.910136121800131, 6.988947305232207, 7.0670379648066, 7.144428904756859, 7.221139934114083, 7.297189932464641, 7.372596910208648, 7.447378063872068, 7.521549826960721, 7.59512791678844, 7.668127377662926, 7.740562620770271, 7.812447461062075, 7.883795151416406, 7.9546184143153855, 8.024929471256938, 8.094740070096034, 8.164061510491221, 8.232904667614728, 8.301280014269114, 8.369197641539662, 8.436667278099486, 8.503698308273469, 8.570299788957366, 8.636480465479652, 8.702248786485987, 8.767612917918957, 8.832580756159613, 8.8971599403915, 8.961357864242773, 9.025181686757394, 9.088638342742112, 9.151734552532213, 9.214476831215498, 9.27687149735086, 9.338924681214982, 9.400642332608019, 9.46203022824684, 9.523093978772192, 9.583839035394195, 9.64427069619877, 9.704394112135937, 9.764214292709454, 9.823736111385765, 9.882964310739123, 9.941903507348394, 10.000558196460123, 10.058932756431343, 10.117031452964751, 10.17485844314802, 10.232417779308198, 10.289713412691501, 10.346749196978026, 10.403528891640445], [0.0, 0.8283084499100927, 1.2127145533442603, 1.51568440412027, 1.7755180308164198, 2.0073615175482473, 2.219091855640356, 2.415438664101679, 2.599510551811864, 2.773482768578268, 2.9389492844340928, 3.0971202561419893, 3.24894064383248, 3.3951653937365998, 3.536409197545278, 3.673180619984406, 3.8059062153674703, 3.9349480089231177, 4.060616449427114, 4.1831801914613855, 4.302873608449587, 4.419902649412058, 4.534449465640938, 4.646676109520916, 4.756727523611506, 4.8647339799213425, 4.970813088339352, 5.075071463881209, 5.17760612113659, 5.278505648653726, 5.377851204343853, 5.475717364210749, 5.572172850030064, 5.667281156468847, 5.761101094154056, 5.85368726208473, 5.9450904603277515, 6.035358051987613, 6.124534281881697, 6.212660558097631, 6.299775701592977, 6.385916168169554, 6.471116246476367, 6.555408235136776, 6.638822601633182, 6.721388125198397, 6.803132025641842, 6.884080079769579, 6.964256726830461, 7.043685164229076, 7.122387434583472, 7.200384505067219, 7.277696339856945, 7.354341966405086, 7.430339536170305, 7.5057063803627955, 7.580459061196594, 7.6546134190844874, 7.728184616162107, 7.801187176484829, 7.873635023203789, 7.945541512994402, 8.01691946798204, 8.08778120538414, 8.158138565065585, 8.228002935184533, 8.297385276088221, 8.366296142602835, 8.434745704847645, 8.502743767691328, 8.570299788957366, 8.637422896475666, 8.704121904068653, 8.77040532655229, 8.836281393825319, 8.901758064113727, 8.966843036431605, 9.031543762314458, 9.095867456876308, 9.159821109237734, 9.223411492368095, 9.286645172381753, 9.349528517324941, 9.412067705487038, 9.474268733267394, 9.536137422626478, 9.597679428147911, 9.658900243736024, 9.719805208971666, 9.780399515147414, 9.840688211001757, 9.90067620817043, 9.960368286371809, 10.019769098342092, 10.07888317453486, 10.137714927598712, 10.19626865664558, 10.254548551321705, 10.312558695692202, 10.370303071949689, 10.427785563956519, 10.485009960629782], [0.0, 0.8347047271622384, 1.2220792513764291, 1.527388664382928, 1.7892287512521683, 2.0228625556131377, 2.2362278956725383, 2.4340909130106736, 2.6195842214829534, 2.7948998683842654, 2.961644132537207, 3.121036515650957, 3.2740292749287496, 3.4213831863687854, 3.5637176883701547, 3.7015452728443146, 3.8352957879980494, 3.965334054653525, 4.091972918901714, 4.215483109900978, 4.336100810929015, 4.454033561364244, 4.569464919088541, 4.682558187870646, 4.793459429530411, 4.9022999220494095, 5.009198183511404, 5.114261652223439, 5.2175880919311535, 5.319266775272043, 5.419379486866508, 5.518001378601381, 5.61520170292845, 5.711044444826669, 5.805588869064295, 5.898889996259072, 5.990999018760869, 6.081963665416612, 6.171828522706402, 6.260635318475092, 6.348423173459397, 6.435228824976334, 6.521086826455142, 6.606029725932245, 6.690088226162867, 6.773291328615813, 6.855666463294483, 6.937239606055903, 7.018035384871151, 7.098077176277395, 7.177387193107895, 7.2559865644467445, 7.333895408635857, 7.41113290005948, 7.487717330343578, 7.563666164531616, 7.638996092732631, 7.713723077680599, 7.787862398594612, 7.861428691686197, 7.934435987622398, 8.006897746220154, 8.078826888618524, 8.150235827149674, 8.22113649310706, 8.29154036258929, 8.361458480580453, 8.43090148341211, 8.499879619738175, 8.568402770141454, 8.636480465479652, 8.704121904068653, 8.771335967792066, 8.838131237218073, 8.904516005797486, 8.970498293210479, 9.036085857923664, 9.101286209014019, 9.166106617311367, 9.230554125906949, 9.294635560071638, 9.358357536623965, 9.421726472784824, 9.484748594552936, 9.547429944632427, 9.609776389941494, 9.671793628729002, 9.733487197323736, 9.794862476539299, 9.855924697755926, 9.916678948698953, 9.977130178932232, 10.037283205083586, 10.097142715818086, 10.156713276573914, 10.215999334074555, 10.275005220630106, 10.33373515823965, 10.392193262505849, 10.450383546372192, 10.508309923692591, 10.565976212642514], [0.0, 0.8410611507842146, 1.2313856002787356, 1.5390199982789623, 1.8028540435615141, 2.038267010522869, 2.25325716525449, 2.452626944344891, 2.6395328170561445, 2.816183523509658, 2.9841975746243845, 3.144803758829967, 3.298961584936087, 3.4474376223842644, 3.5908560267061826, 3.7297331925295336, 3.8645022414309627, 3.9955307724074993, 4.123134013928241, 4.247584756801809, 4.36912098288319, 4.48795181199975, 4.604262199858991, 4.718216693816634, 4.829962467979035, 4.939631800032736, 5.0473441105975985, 5.1532076561423095, 5.257320944900664, 5.359773929337028, 5.4606490168761015, 5.5600219316995805, 5.657962453628881, 5.754535054899848, 5.849799451592396, 5.943811083315972, 6.036621532259209, 6.128278890732618, 6.218828084750205, 6.308311159921715, 6.39676753489517, 6.484234226748727, 6.570746052042084, 6.6563358066706995, 6.741034427196687, 6.824871135940149, 6.907873571788796, 6.990067908410386, 7.071478961322335, 7.152130285078264, 7.232044261666072, 7.3112421810715515, 7.389744314841338, 7.467569983375993, 7.544737617595438, 7.6212648155425216, 7.697168394424403, 7.772464438534089, 7.847168343444623, 7.921294856824859, 7.994858116187842, 8.067871683849395, 8.140348579345321, 8.21230130952989, 8.283741896555457, 8.354681903913145, 8.425132460696542, 8.495104284234753, 8.564607701226992, 8.633652667498447, 8.702248786485987, 8.77040532655229, 8.838131237218073, 8.905435164394058, 8.97232546468715, 9.038810218848798, 9.104897244427706, 9.170594107683794, 9.235908134815539, 9.300846422548561, 9.365415848129377, 9.429623078764754, 9.493474580543854, 9.556976626877479, 9.620135306486006, 9.682956530965255, 9.745446041957258, 9.807609417950918, 9.869452080735684, 9.930979301529671, 9.992196206802143, 10.053107783808752, 10.113718885856793, 10.174034237316341, 10.234058438392202, 10.293795969670441, 10.353251196452462, 10.412428372888611, 10.471331645922593, 10.529965059057169, 10.588332555950938, 10.646437983855446], [0.0, 0.847378510003868, 1.24063475554838, 1.550579849980938, 1.8163955994913812, 2.053576794929194, 2.270181778778605, 2.471049059579652, 2.6593588153939103, 2.837336376580913, 3.0066124109816963, 3.168424936673363, 3.3237406695061518, 3.473331936760386, 3.6178275821104577, 3.75774787891554, 3.8935292020051273, 4.025541911477402, 4.154103603538306, 4.2794891179765235, 4.401938224170892, 4.5216616126848255, 4.638845628460895, 4.753656054799142, 4.866241171256694, 4.976734249081219, 5.085255605881997, 5.19191431126122, 5.296809613365469, 5.400032140307995, 5.501664918490256, 5.6017842408716865, 5.700460411402292, 5.797758386580301, 5.893738331023675, 5.988456100758583, 6.081963665416612, 6.174309478538129, 6.265538803584389, 6.355694001977153, 6.44481478844489, 6.532938458107586, 6.620100089038282, 6.706332723468214, 6.79166753032949, 6.876133951436235, 6.959759833276738, 7.04257154611381, 7.1245940918586115, 7.205851201987186, 7.286365426602507, 7.36615821560322, 7.445249992799137, 7.523660223709767, 7.601407477692937, 7.6785094849735085, 7.754983189075662, 7.83084479510438, 7.906109814271576, 7.98079310501846, 8.05490891104744, 8.128470896543291, 8.20149217883386, 8.273985358714608, 8.345962548638411, 8.417435398951817, 8.488415122341008, 8.558912516634845, 8.628937986098206, 8.69850156133625, 8.767612917918957, 8.836281393825319, 8.904516005797486, 8.97232546468715, 9.039718189869168, 9.106702322790943, 9.173285739720171, 9.239476063748292, 9.305280676102157, 9.370706726812147, 9.435761144780995, 9.500450647294041, 9.564781749008386, 9.628760770455532, 9.69239384608931, 9.755686931908587, 9.818645812681883, 9.881276108799117, 9.94358328277376, 10.005572645416983, 10.067249361703864, 10.128618456350216, 10.189684819117383, 10.250453209861027, 10.310928263338896, 10.37111449379154, 10.431016299308908, 10.490637965995028, 10.54998367194203, 10.609057491024139, 10.667863396521476, 10.72640526458297], [0.0, 0.8536575679962694, 1.249827834539068, 1.562069615988616, 1.8298550549433454, 2.068793758346347, 2.287003780840209, 2.489359484217514, 2.6790646115963486, 2.8583609829901793, 3.0288913494564773, 3.1919029027618016, 3.348369522101714, 3.4990692576864015, 3.644635612909442, 3.7855927163453047, 3.922380176352337, 4.05537109738972, 4.184885429044999, 4.3112000476642525, 4.434556499312671, 4.555167035766576, 4.673219382780874, 4.788880552106582, 4.9022999220494095, 5.0136117513943335, 5.122937249301738, 5.23038629357741, 5.336058867794732, 5.4400462716194795, 5.542432146677106, 5.6432933512563626, 5.742700710258136, 5.84071966150702, 5.937410815439604, 6.032830441974106, 6.127030895836055, 6.220060989605594, 6.31196632214533, 6.402789568774321, 6.492570738506388, 6.581347402817618, 6.6691548997088805, 6.756026516253687, 6.841993652345322, 6.927085967961165, 7.011331515931436, 7.09475686192207, 7.1773871931078945, 7.259246416814721, 7.34035725024134, 7.420741302229722, 7.500419147929703, 7.5794103970999105, 7.657733756696743, 7.735407088325678, 7.812447461062075, 7.888871200090423, 7.9646939315604115, 8.039930624014001, 8.114595626699158, 8.188702705051993, 8.262265073599492, 8.335295426508766, 8.407805965985721, 8.479808428705745, 8.551314110440803, 8.622333889031454, 8.692878245837976, 8.762957285792108, 8.832580756159613, 8.901758064113727, 8.970498293210479, 9.038810218848798, 9.106702322790943, 9.174182806812281, 9.241259605543496, 9.307940398562984, 9.374232621792343, 9.440143478243536, 9.50567994816233, 9.570848798609012, 9.635656592514167, 9.70010969724431, 9.764214292709454, 9.827976379042298, 9.89140178387638, 9.954496169248605, 10.017265038149553, 10.079713740743406, 10.1418474802776, 10.203671318700996, 10.265190182007974, 10.326408865324629, 10.387332037752174, 10.447964246981591, 10.508309923692591, 10.568373385749146, 10.628158842202966, 10.687670397115605, 10.746912053209108, 10.805887715354595], [0.0, 0.859899063078681, 1.258965918210542, 1.5734906473155712, 1.843233992535105, 2.083919690046983, 2.303725149438951, 2.507560371272927, 2.698652522751393, 2.8792598148964745, 3.0510370096972292, 3.215240417730345, 3.372851038683766, 3.524652611461534, 3.6712832713007937, 3.8132709789284416, 3.9510585568878906, 4.085021837581862, 4.215483109900977, 4.3427212745655135, 4.466979643698428, 4.588472020949377, 4.707387504625236, 4.823894327579092, 4.9381429602922475, 5.050268643179291, 5.160393471618225, 5.268628126783555, 5.375073323275955, 5.479821028296332, 5.582955495013704, 5.6845541436642, 5.784688316983126, 5.883423931242025, 5.980822040029118, 6.076939324678663, 6.171828522706402, 6.265538803584389, 6.358116099570124, 6.449603398002151, 6.540041000419154, 6.62946675300009, 6.717916252118699, 6.805423028226068, 6.892018710794979, 6.977733176660968, 7.06259468376179, 7.146629991997555, 7.229864472698466, 7.312322207988123, 7.394026081161522, 7.474997859053123, 7.555258267247432, 7.634827058879316, 7.713723077680599, 7.791964315851421, 7.869567967267242, 7.946550476473713, 8.02292758387071, 8.098714367442296, 8.173925281350591, 8.248574191677339, 8.322674409567188, 8.396238722000327, 8.469279420398768, 8.5418083272503, 8.613836820915628, 8.68537585876836, 8.756435998802965, 8.827027419833133, 8.8971599403915, 8.966843036431605, 9.036085857923664, 9.104897244427706, 9.173285739720171, 9.241259605543496, 9.308826834542211, 9.375995162443747, 9.44277207953725, 9.509164841499318, 9.575180479611603, 9.640825810411577, 9.706107444814522, 9.771031796741784, 9.835605091287633, 9.899833372454577, 9.963722510484748, 10.027278208812884, 10.09050601066454, 10.15341130532148, 10.215999334074553, 10.278275195882925, 10.340243852757254, 10.401910134883076, 10.46327874549962, 10.524354265548187, 10.585141158103287, 10.645643772598843, 10.70586634886094, 10.76581302095787, 10.825487820877473, 10.884894682041235], [0.0, 0.8661037098357537, 1.2680500527759675, 1.5848442515481382, 1.8565339440123894, 2.0989563217890352, 2.3203477989932804, 2.525653804553431, 2.718124791466056, 2.9000352649932637, 3.0730519271459698, 3.238440153475672, 3.3971880221249764, 3.5500849271070636, 3.697773608157327, 3.840785835530957, 3.979567626980639, 4.114497526747491, 4.245900149214519, 4.374056407524762, 4.499211369432553, 4.621580381298988, 4.741353905879687, 4.858701389920705, 4.973774389630989, 5.086709121259427, 5.19762856116962, 5.306644189161888, 5.413857446548386, 5.519360964124179, 5.623239602991442, 5.725571342016075, 5.826428038710629, 5.925876084968961, 6.023976974914655, 6.1207877988691095, 6.216361674878374, 6.310748127199404, 6.403993419516313, 6.496140849345038, 6.587231009022129, 6.677302017807628, 6.766389728922778, 6.854527914759392, 6.941748433014371, 7.028081376101123, 7.113555205854034, 7.198196875260677, 7.282031938719415, 7.365084652119675, 7.447378063872069, 7.528934097870788, 7.609773629246883, 7.6899165536649985, 7.769381850824892, 7.8481876427503705, 7.926351247380201, 8.003889227916515, 8.080817438334869, 8.157151065415313, 8.232904667614728, 8.308092211066297, 8.382727102961933, 8.456822222546949, 8.530389949932758, 8.603442192912926, 8.67599041194932, 8.748045643479049, 8.819618521678347, 8.890719298806662, 8.961357864242773, 9.031543762314458, 9.101286209014019, 9.170594107683794, 9.239476063748292, 9.307940398562984, 9.375995162443747, 9.443648146935558, 9.510906896374138, 9.577778718789796, 9.644270696198769, 9.710389694323611, 9.77614237178101, 9.841535188772298, 9.906574415309237, 9.971266139005154, 10.03561627245922, 10.099630560259607, 10.163314585629301, 10.226673776736714, 10.289713412691501, 10.352438629244638, 10.41485442421043, 10.47696566262687, 10.538777081669654, 10.600293295334106, 10.661518798898287, 10.722457973179688, 10.783115088597079, 10.843494309048335, 10.903599695614323, 10.963435210098334], [0.0, 0.8722722001798766, 1.2770812512543765, 1.5961316947857007, 1.869756392521874, 2.1139053303854154, 2.3368735831811938, 2.543641801751757, 2.73748358919417, 2.9206896500589035, 3.094938556800498, 3.2615046971208237, 3.421383186368785, 3.5753690407126144, 3.7241095775541058, 3.8681403544774353, 4.007910565825075, 4.143801451873816, 4.276139938947675, 4.40520894088544, 4.531255270842207, 4.654495808900651, 4.775122374314067, 4.893305620647746, 5.009198183511405, 5.122937249301739, 5.234646670234171, 5.344438720080995, 5.452415562631072, 5.558670488406653, 5.663288962900454, 5.766349520352836, 5.8679245300538305, 5.968080856748004, 6.06688043252717, 6.164380754316569, 6.260635318475091, 6.355694001977152, 6.449603398002151, 6.542407112435917, 6.6341460267182955, 6.7248585315990885, 6.814580735650307, 6.903346651794628, 6.991188364623138, 7.078136180870879, 7.1642187650806965, 7.249463262202445, 7.333895408635857, 7.417539633023595, 7.500419147929704, 7.582556033392876, 7.663971313219247, 7.744685024772678, 7.824716282928533, 7.904083338777756, 7.982803633599472, 8.060893848560843, 8.138369950551265, 8.215247234512786, 8.29154036258929, 8.36726340038237, 8.442429850571505, 8.517052684129473, 8.591144369340268, 8.664716898806136, 8.737781814611665, 8.810350231796747, 8.882432860275438, 8.954040025324963, 9.025181686757394, 9.095867456876308, 9.166106617311367, 9.235908134815539, 9.305280676102157, 9.374232621792343, 9.44277207953725, 9.510906896374138, 9.57864467037035, 9.645992761604836, 9.712958302532762, 9.779548207775152, 9.845769183372127, 9.911627735535319, 9.977130178932232, 10.042282644532879, 10.107091087046642, 10.171561291975308, 10.235698882306227, 10.299509324867847, 10.362997936368252, 10.426169889135824, 10.48903021657988, 10.551583818387774, 10.61383546547391, 10.675789804695023, 10.737451363345057, 10.79882455344219, 10.859913675819607, 10.920722924030946, 10.981256388080556, 11.041518057988148], [0.0, 0.8784052043512015, 1.2860604949347882, 1.6073542034705883, 1.8829027747547749, 2.128768340127519, 2.353304297619363, 2.561526317362002, 2.7567310193747936, 2.9412252143050903, 3.1166992767626125, 3.2844365547543846, 3.4454391603518757, 3.600507699535164, 3.7502940410379817, 3.895337507985696, 4.0360904530362385, 4.172936796992282, 4.3062057648186896, 4.43618225954037, 4.563114829672217, 4.687221880195271, 4.808696579056825, 4.927710779698799, 5.044418190922088, 5.158956963690119, 5.271451821031523, 5.382015826122994, 5.490751861073826, 5.59775387233817, 5.703107926322335, 5.806893109446182, 5.909182299833056, 6.010042832358016, 6.109537074561555, 6.207722927633639, 6.304654264069636, 6.400381311532303, 6.494950990800799, 6.588407214356856, 6.680791151080451, 6.77214146164932, 6.8624945085172575, 6.951884543754073, 7.040343877539759, 7.1279030296980395, 7.214590866314077, 7.300434723195683, 7.385460517696938, 7.469692850219924, 7.553155096537779, 7.63586949193542, 7.7178572080387715, 7.79913842309574, 7.879732386379655, 7.959657477306104, 8.038931259785011, 8.117570532269937, 8.19559137391455, 8.273009187200653, 8.34983873736265, 8.426094188898313, 8.50178913942537, 8.57693665111637, 8.651549279920651, 8.72563910276124, 8.799217742875904, 8.872296393455114, 8.944885839715054, 9.016996479530661, 9.088638342742112, 9.159821109237734, 9.230554125906949, 9.300846422548561, 9.370706726812147, 9.440143478243536, 9.509164841499318, 9.577778718789796, 9.645992761604836, 9.713814381772591, 9.781250761896999, 9.848308865216246, 9.91499544492107, 9.98131705296871, 10.04728004842552, 10.112890605368777, 10.178154720375819, 10.243078219626685, 10.307666765644324, 10.37192586369482, 10.435860867868385, 10.499476986860394, 10.562779289470397, 10.625772709835777, 10.688462052415561, 10.750851996738836, 10.812947101931261, 10.874751811032205, 10.936270455114299, 10.997507257216336, 11.05846633609976, 11.11915170983838], [0.0, 0.8845033718614886, 1.29498873475808, 1.6185129661151785, 1.8959744829700285, 2.1435469250725863, 2.3696416823917597, 2.5793092454319924, 2.7758691203943213, 2.9616441325372067, 3.138336391587003, 3.307238154959607, 3.469358491706302, 3.625503565867788, 3.7763297716572843, 3.9223801763523367, 4.0641102729864915, 4.2019066476623905, 4.336100810929015, 4.466979643698427, 4.59479341998814, 4.719762061015837, 4.842080075761962, 4.961920510729532, 5.079438141814688, 5.194772079068655, 5.308047911386887, 5.419379486866507, 5.5288704018570405, 5.636615255018717, 5.742700710258136, 5.8472064030381645, 5.9502057174251926, 6.051766455754339, 6.151951418541341, 6.250818908944589, 6.348423173459397, 6.44481478844489, 6.540041000419154, 6.634146026718296, 6.727171322029716, 6.819155815425834, 6.910136121800131, 7.000146731011149, 7.089220177546398, 7.1773871931078945, 7.264676844178321, 7.351116656339336, 7.43673272687151, 7.5215498269607215, 7.605591494662136, 7.688880119625071, 7.771437020455593, 7.853282515485406, 7.934435987622398, 8.014915943877888, 8.094740070096034, 8.173925281350591, 8.252487768421808, 8.330443040720404, 8.40780596598572, 8.484590807049969, 8.560811255929847, 8.636480465479652, 8.711611078816103, 8.786215256704057, 8.860304703073483, 8.933890688821531, 9.006984074038776, 9.079595328785501, 9.151734552532213, 9.223411492368095, 9.294635560071638, 9.365415848129377, 9.435761144780995, 9.50567994816233, 9.575180479611603, 9.644270696198769, 9.712958302532762, 9.781250761896999, 9.84915530675933, 9.916678948698952, 9.98382848778939, 10.050610521473653, 10.11703145296475, 10.183097499202356, 10.248814698393955, 10.314188917166772, 10.37922585735479, 10.443931062443394, 10.50830992369259, 10.572367685958165, 10.636109453228887, 10.699540193896482, 10.762664745774055, 10.825487820877473, 10.888014009983285, 10.950247786975853, 11.012193512995484, 11.07385544039865, 11.13523771654054, 11.196344387389708], [0.0, 0.890567332385593, 1.3038668926222001, 1.6296091349331878, 1.908972866905234, 2.1582426112041717, 2.385887424438005, 2.596992422162953, 2.7948998683842654, 2.9819485131393457, 3.159852135444364, 3.329911852147759, 3.4931436502562323, 3.6503592206937876, 3.802219457767962, 3.9492711519060797, 4.091972918901714, 4.230713995206778, 4.365828164133642, 4.49760427338679, 4.626294312807333, 4.7521197113444416, 4.875276311489338, 4.995938346113793, 5.114261652223439, 5.23038629357741, 5.344438720080995, 5.456533560348825, 5.566775120964206, 5.67525864913497, 5.782071402916394, 5.887293563734558, 5.990999018760869, 6.093256035168334, 6.194127844019213, 6.293673148185523, 6.391946566064616, 6.488999020756006, 6.584878082689516, 6.679628272345579, 6.773291328615812, 6.865906447461791, 6.957510494800651, 7.048138196945819, 7.137822311434089, 7.226593780657268, 7.31448187037145, 7.401514294867625, 7.487717330343577, 7.573115917810985, 7.657733756696743, 7.741593390148679, 7.824716282928531, 7.907122892666014, 7.988832735153972, 8.06986444428372, 8.150235827149672, 8.22996391479161, 8.309065008990203, 8.387554725485286, 8.465448033946148, 8.542759294987839, 8.619502294496511, 8.695690275499539, 8.771335967792064, 8.846451615510478, 8.921049002824313, 8.995139477901514, 9.068733975287046, 9.141843036821621, 9.214476831215498, 9.286645172381753, 9.358357536623965, 9.429623078764754, 9.500450647294041, 9.570848798609012, 9.640825810411577, 9.710389694323611, 9.779548207775152, 9.848308865216246, 9.916678948698952, 9.984665517872308, 10.052275419429652, 10.119515296044607, 10.186391594829205, 10.252910575345089, 10.319078317196364, 10.384900727230567, 10.450383546372192, 10.515532356111546, 10.580352584669924, 10.644849512860695, 10.709028279664444, 10.772893887535105, 10.836451207452761, 10.899704983737823, 10.962659838640198, 11.02532027671621, 11.08769068900519, 11.149775357016823, 11.211578456539659, 11.273104061280517], [0.0, 0.8965976966041039, 1.3126958626158642, 1.6406438273815795, 1.9218992355828908, 2.1728568784742364, 2.4020431598108547, 2.614577628366738, 2.8138251798657423, 3.0021404008957804, 3.1812486751111915, 3.352459929708831, 3.516797031323104, 3.675077167140595, 3.8279657066311783, 3.9760131427445, 4.11968119673306, 4.2593617407142474, 4.395390818171978, 4.528059232706485, 4.657620680476268, 4.784298089808659, 4.908288629317576, 5.029767711670677, 5.148892229104197, 5.265803193801325, 5.380627911906916, 5.493481788228786, 5.6044698356490965, 5.71368794633012, 5.821223969184034, 5.927158628575318, 6.031566311993029, 6.134515748872716, 6.23607059843779, 6.336289961059351, 6.435228824976333, 6.532938458107585, 6.62946675300009, 6.7248585315990885, 6.819155815425834, 6.912398065852404, 7.004622398428837, 7.095863774613402, 7.186155173756423, 7.2755277477722, 7.364010960586199, 7.451632714153233, 7.53841946259704, 7.624396315814209, 7.709587133709311, 7.794014612078252, 7.877700361028694, 7.960664976716607, 8.042928107083561, 8.124508512197917, 8.205424119732573, 8.285692076050848, 8.365328793318866, 8.444349993016466, 8.522770746178162, 8.600605510660099, 8.677868165697813, 8.754572043992166, 8.830729961536504, 8.906354245376834, 8.98145675947771, 9.056048928849762, 9.130141762079845, 9.203745872391412, 9.27687149735086, 9.349528517324941, 9.421726472784824, 9.493474580543854, 9.564781749008386, 9.635656592514167, 9.706107444814522, 9.77614237178101, 9.845769183372127, 9.91499544492107, 9.98382848778939, 10.052275419429652, 10.12034313289671, 10.188038315844214, 10.255367459039999, 10.322336864431541, 10.388952652790218, 10.455220770961033, 10.52114699874243, 10.586736955419072, 10.65199610596877, 10.71692976696325, 10.78154311218106, 10.845841177949614, 10.909828868232225, 10.97351095947487, 11.036892105226437, 11.099976840545283, 11.162769586204108, 11.225274652704302, 11.287496244110235, 11.349438461713321], [0.0, 0.9025950570003767, 1.321476512185478, 1.651618127619016, 1.9347548590188732, 2.18739116273471, 2.418110475811498, 2.6320665917900636, 2.8326469142508275, 3.02222177965972, 3.2025281127977587, 3.3748846029917074, 3.5403209588518845, 3.699659833746739, 3.8535710478161858, 4.002608776268511, 4.147237828819152, 4.28785269882613, 4.4247916775751275, 4.558347513857627, 4.688775600810937, 4.8163003579345505, 4.941120272707289, 5.0634119311357475, 5.183333274911546, 5.301026259451264, 5.416619042453171, 5.530227800670212, 5.641958249417873, 5.7519069222830685, 5.860162255801151, 5.966805514303533, 6.071911582858712, 6.17554965063484, 6.277783802673184, 6.378673534668438, 6.478274202676993, 6.576637417549862, 6.673811392188255, 6.769841248352327, 6.864769288646149, 6.958635238399725, 7.051476461429772, 7.143328153052469, 7.234223513217691, 7.324193902215533, 7.413268981056264, 7.501476838331444, 7.588844105116988, 7.675396059270099, 7.76115672029474, 7.8461489357994605, 7.930394460442377, 8.013914028147571, 8.096727418282093, 8.178853516400789, 8.26031037009513, 8.341115240420809, 8.421284649325267, 8.500834423449644, 8.579779734638915, 8.658135137458117, 8.735914603981284, 8.813131556091982, 8.889798895510001, 8.965929031737213, 9.041533908096476, 9.116625026020545, 9.191213467732943, 9.265309917449194, 9.338924681214982, 9.412067705487038, 9.484748594552936, 9.556976626877479, 9.628760770455532, 9.70010969724431, 9.771031796741784, 9.841535188772298, 9.911627735535319, 9.98131705296871, 10.050610521473653, 10.119515296044607, 10.188038315844214, 10.256186313259974, 10.323965822476604, 10.391383187595432, 10.458444570329805, 10.525155957303292, 10.59152316697553, 10.65755185621869, 10.723247526565935, 10.788615530151644, 10.853661075361877, 10.91838923221215, 10.982804937468481, 11.046912999526596, 11.110718103063064, 11.174224813471344, 11.237437581094774, 11.300360745267774, 11.362998538175791, 11.425355088543858], [0.0, 0.9085599886149424, 1.3302096832396575, 1.6625330878863205, 1.9475409698395438, 2.201846857565767, 2.4340909130106736, 2.6494609893144503, 2.8513668762101467, 3.0421945748793524, 3.2236924888248644, 3.3971880221249764, 3.5637176883701542, 3.7241095775541058, 3.879037936421232, 4.0290606025278395, 4.174645457352437, 4.316189601320178, 4.454033561364243, 4.588472020949377, 4.719762061015837, 4.848129584172243, 4.973774389630989, 5.096874230393152, 5.2175880919311535, 5.336058867794732, 5.452415562631072, 5.566775120964206, 5.679243956744762, 5.789919241516001, 5.898889996259072, 6.006238022352621, 6.112038699754087, 6.216361674878374, 6.319271456282125, 6.4208279328460485, 6.521086826455141, 6.6201000890382815, 6.717916252118698, 6.814580735650307, 6.9101361218001305, 7.004622398428837, 7.098077176277394, 7.190535883255386, 7.282031938719414, 7.372596910208648, 7.462260654752482, 7.55105144657005, 7.63899609273263, 7.7261200381498485, 7.812447461062076, 7.89800136006963, 7.982803633599471, 8.066875152598852, 8.150235827149674, 8.232904667614728, 8.314899840855642, 8.396238722000325, 8.476937942183923, 8.557013432640254, 8.636480465479652, 8.71535369145313, 8.793647174971214, 8.871374426617958, 8.948548433376057, 9.025181686757392, 9.101286209014017, 9.176873577587594, 9.25195494794014, 9.326541074895383, 9.400642332608019, 9.474268733267394, 9.547429944632427, 9.620135306486006, 9.69239384608931, 9.764214292709454, 9.835605091287633, 9.906574415309237, 9.977130178932232, 10.04728004842552, 10.11703145296475, 10.186391594829205, 10.255367459039999, 10.323965822476604, 10.392193262505849, 10.46005616515499, 10.527560732857955, 10.594712991801796, 10.661518798898287, 10.72798384840387, 10.794113678209396, 10.859913675819607, 10.925389084040946, 10.990545006394866, 11.055386412272732, 11.119918141847252, 11.184144910754368, 11.24807131455861, 11.311701833014062, 11.375040834132273, 11.438092578067703, 11.500861220830673], [0.0, 0.9144930497600555, 1.3388961931953884, 1.673389729813994, 1.9602587648134189, 2.216225316007491, 2.449985967162984, 2.6667624490399198, 2.8699868179153665, 3.0620606559904155, 3.244743784159141, 3.4193722746886848, 3.586989409790833, 3.7484286870368084, 3.9043687561242715, 4.05537109738972, 4.2019066476623905, 4.344375100505073, 4.483119206553446, 4.618435573608608, 4.750582961395878, 4.879788747708792, 5.006254036484759, 5.130157741484119, 5.251659886383201, 5.370904297852479, 5.488020822962833, 5.603127169907198, 5.71633044753856, 5.82772846194794, 5.937410815439604, 6.045459843570003, 6.151951418541341, 6.2569556415722145, 6.360537442471816, 6.4627571012060825, 6.563670703534003, 6.6633305406399534, 6.761785460966792, 6.859081181068952, 6.955260561182714, 7.050363850296712, 7.14442890475686, 7.237491383823401, 7.329584925087384, 7.420741302229722, 7.510990567251614, 7.600361179007962, 7.688880119625071, 7.776573000172431, 7.863464156778697, 7.9495767382292115, 8.034932785951623, 8.119553307184248, 8.203458342025424, 8.286667024979055, 8.36919764153966, 8.451067680297879, 8.53229388099318, 8.612892278893218, 8.692878245837974, 8.772266528250517, 8.851071282384519, 8.929306107050593, 9.006984074038776, 9.08411775643279, 9.160719254992163, 9.236800222761353, 9.312371888049558, 9.387445075911451, 9.46203022824684, 9.536137422626478, 9.609776389941494, 9.682956530965255, 9.755686931908587, 9.827976379042298, 9.899833372454577, 9.971266139005154, 10.042282644532879, 10.112890605368777, 10.183097499202356, 10.252910575345089, 10.322336864431541, 10.391383187595432, 10.46005616515499, 10.528362224839382, 10.596307609585553, 10.663898384932645, 10.731140446039129, 10.79803952434597, 10.864601193907449, 10.930830877409688, 10.996733851895607, 11.062315254213576, 11.127580086205985, 11.192533219652747, 11.257179400983757, 11.321523255773416, 11.385569293029413, 11.4493219092872, 11.51278539252082, 11.575963925880089], [0.0, 0.9203947826969269, 1.3475368359695528, 1.6841890456614534, 1.972909406302849, 2.230527852201113, 2.465797091021248, 2.6839725522598843, 2.888508441164577, 3.0818218386838194, 3.265683922815968, 3.441439388246573, 3.6101382500685424, 3.772619384877107, 3.9295658220743688, 4.0815426655421305, 4.2290238913272535, 4.372411772437682, 4.512051271469827, 4.648240910400107, 4.781241118874457, 4.911280742081941, 5.038562181795672, 5.163265506406122, 5.285551772311525, 5.405565734375957, 5.523438077645756, 5.639287269950382, 5.753221111375896, 5.865338039210495, 5.9757282340120135, 6.084474562694103, 6.19165338710454, 6.297335260864125, 6.40158553281027, 6.504464871929102, 6.606029725932246, 6.706332723468214, 6.805423028226068, 6.903346651794629, 7.000146731011149, 7.095863774613404, 7.190535883255387, 7.284198946326407, 7.3768868184996235, 7.468631478509204, 7.559463172298651, 7.649410542383701, 7.738500745021352, 7.8267595565635855, 7.914211470193648, 8.000879784088886, 8.086786681922554, 8.17195330650438, 8.256399827262612, 8.340145502186767, 8.423208734777845, 8.505607126490094, 8.587357525093848, 8.668476069341278, 8.748978230275402, 8.828878849486172, 8.90819217458545, 8.986931892144545, 9.065111158313039, 9.142742627315759, 9.21983847800518, 9.296410438629339, 9.372469809959972, 9.448027486911856, 9.523093978772192, 9.597679428147911, 9.671793628729002, 9.745446041957258, 9.818645812681883, 9.89140178387638, 9.963722510484748, 10.03561627245922, 10.107091087046642, 10.178154720375819, 10.248814698393955, 10.319078317196364, 10.388952652790218, 10.458444570329805, 10.527560732857955, 10.596307609585553, 10.664691483738691, 10.732718460000815, 10.800394471575133, 10.867725286890794, 10.934716515974554, 11.001373616508149, 11.067701899590196, 11.133706535220005, 11.199392557519644, 11.264764869709335, 11.329828248850328, 11.39458735036843, 11.459046712370471, 11.52321075976519, 11.587083808199319, 11.650670067818867], [0.0, 0.9262657142780022, 1.3561323829192806, 1.6949319994923107, 1.9854940236407743, 2.2447557429455434, 2.4815256960572105, 2.701092835334099, 2.906933399397983, 3.1014798870562363, 3.286514774138366, 3.4633913327476167, 3.633166275718873, 3.796683830598053, 3.954631383633867, 4.107577643342008, 4.255999609125179, 4.40030211997426, 4.5408323389020895, 4.677890692070262, 4.811739270329949, 4.942608378607354, 5.0707017097378415, 5.196200480715965, 5.319266775272043, 5.44004627161948, 5.558670488406652, 5.67525864913497, 5.789919241516001, 5.902751330740878, 6.013845672603076, 6.123285662600275, 6.231148149670348, 6.337504137475196, 6.442419391693525, 6.545954968301342, 6.648167675073869, 6.749110476362509, 6.848832849457254, 6.947381099441511, 7.04479863830992, 7.1411262331937495, 7.236402227780028, 7.330662740386075, 7.4239418416342, 7.516271714241648, 7.6076827970820275, 7.698203915373385, 7.787862398594611, 7.876684187517564, 7.9646939315604115, 8.051915077512819, 8.138369950551263, 8.22407982834933, 8.309065008990203, 8.393344873304535, 8.476937942183923, 8.559861929357194, 8.642133790061726, 8.723769765994106, 8.804785426882662, 8.885195708987542, 8.965014950801994, 9.0442569262, 9.122934875250406, 9.201061532895677, 9.278649155673653, 9.35570954664347, 9.432254078661208, 9.508293716137151, 9.583839035394195, 9.658900243736024, 9.733487197323736, 9.807609417950918, 9.881276108799117, 9.954496169248605, 10.027278208812884, 10.099630560259607, 10.171561291975308, 10.243078219626685, 10.314188917166772, 10.384900727230567, 10.455220770961033, 10.525155957303292, 10.594712991801796, 10.663898384932645, 10.732718460000815, 10.801179360629753, 10.869287057868858, 10.93704735694241, 11.004465903661902, 11.071548190522043, 11.138299562499402, 11.204725222571225, 11.270830236970781, 11.336619540194512, 11.40209793977516, 11.467270120834144, 11.532140650425555, 11.596713981683354, 11.660994457782525, 11.724986315724381], [0.0, 0.93210635655647, 1.3646835837343207, 1.7056195282896809, 1.9980137144372332, 2.2589102291744774, 2.497173154094447, 2.7181247914660562, 2.925263299610741, 3.1210365156509567, 3.307238154959607, 3.485230022805029, 3.656075495209101, 3.82062412306181, 3.979567626980639, 4.133478301518148, 4.282836153834788, 4.428048575665958, 4.569464919088541, 4.707387504625236, 4.842080075761962, 4.973774389630989, 5.102675423469089, 5.228965536949015, 5.352807835832964, 5.474348916919926, 5.593721128159594, 5.711044444826669, 5.826428038710629, 5.939971599666064, 6.05176645575434, 6.16189652833009, 6.270439150908292, 6.377465774870093, 6.48304258058493, 6.58723100902213, 6.690088226162868, 6.791667530329491, 6.8920187107949795, 6.991188364623139, 7.089220177546399, 7.186155173756424, 7.282031938719416, 7.376886818499624, 7.47075409855438, 7.563666164531617, 7.65565364723969, 7.7467455536563525, 7.836969385588702, 7.926351247380203, 8.014915943877892, 8.102687069717033, 8.18968709084729, 8.275937419110306, 8.361458480580453, 8.44626977829575, 8.530389949932758, 8.61383682091563, 8.69662745339434, 8.778778191478798, 8.860304703073483, 8.941222018620328, 9.021544567025094, 9.101286209014019, 9.180460268142262, 9.259079559653479, 9.337156417370089, 9.414702718776354, 9.49172990844081, 9.5682490199107, 9.64427069619877, 9.719805208971666, 9.794862476539299, 9.869452080735684, 9.94358328277376, 10.017265038149553, 10.09050601066454, 10.163314585629301, 10.235698882306227, 10.307666765644324, 10.37922585735479, 10.450383546372192, 10.52114699874243, 10.59152316697553, 10.661518798898287, 10.731140446039129, 10.800394471575133, 10.869287057868858, 10.937824213620624, 11.006011780660021, 11.073855440398653, 11.141360719964592, 11.208532998037587, 11.275377510402667, 11.34189935523864, 11.408103498156809, 11.473994777004195, 11.539577906444627, 11.604857482330118, 11.669837985874219, 11.734523787638151, 11.798919151339977], [0.0, 0.9379172073650243, 1.373191167284399, 1.7162525430152356, 2.0104695458199653, 2.272992517358996, 2.512740798858911, 2.735069872390719, 2.943499704169309, 3.1404933913958, 3.327855831656745, 3.506957319860306, 3.6788678612283148, 3.8444423028419523, 4.004376677579079, 4.159246847737759, 4.309535812894466, 4.455653504508289, 4.597951452554358, 4.736733862253871, 4.872266121297874, 5.004781431617408, 5.134486048299282, 5.26156346786597, 5.3861778128984525, 5.508476594095857, 5.6285929844791625, 5.746647707261775, 5.862750614821796, 5.977002018491041, 6.089493815679785, 6.200310450917374, 6.309529739824191, 6.417223579216947, 6.523458562040584, 6.62829651229401, 6.731794952337246, 6.834007512760086, 6.934984293227169, 7.034772181293382, 7.133415135032689, 7.230954434385958, 7.327428905365315, 7.422875120620268, 7.517327579347357, 7.610818869090113, 7.703379811612628, 7.79503959472526, 7.885825891684317, 7.975764969570535, 8.064881787867021, 8.153200088300524, 8.24074247687584, 8.327530498918327, 8.41358470784069, 8.498924728264976, 8.583569314057014, 8.667536401766561, 8.750843159910865, 8.833506034490759, 8.915540791086121, 8.996962553840266, 9.077785841610297, 9.158024601531707, 9.23769224022012, 9.316801652810796, 9.395365250016521, 9.47339498336707, 9.550902368777637, 9.627898508579785, 9.704394112135937, 9.780399515147414, 9.855924697755926, 9.930979301529671, 10.005572645416983, 10.079713740743406, 10.15341130532148, 10.226673776736714, 10.299509324867847, 10.37192586369482, 10.443931062443394, 10.515532356111546, 10.586736955419072, 10.65755185621869, 10.72798384840387, 10.79803952434597, 10.867725286890794, 10.93704735694241, 11.006011780660021, 11.074624436291804, 11.142891040667896, 11.210817155373075, 11.278408192618354, 11.345669420829209, 11.412605969967037, 11.479222836599298, 11.545524888732666, 11.611516870422689, 11.677203406172415, 11.742589005131759, 11.807678065108487, 11.872474876401139], [0.0, 0.9436987508657586, 1.3816558424243117, 1.726831929615429, 2.0228625556131377, 2.287003780840209, 2.528229927452133, 2.7519294899780746, 2.961644132537207, 3.159852135444364, 3.348369522101714, 3.5285750342393323, 3.701545272844314, 3.868140354477435, 4.0290606025278395, 4.184885429044999, 4.336100810929016, 4.483119206553447, 4.626294312807333, 4.765932210104806, 4.902299922049409, 5.035632088084042, 5.166136234700652, 5.293996989537678, 5.419379486866508, 5.542432146677107, 5.663288962900453, 5.782071402916395, 5.898889996259072, 6.013845672603076, 6.127030895836055, 6.238530631023404, 6.348423173459398, 6.45678086314973, 6.563670703534003, 6.66915489970888, 6.773291328615813, 6.876133951436235, 6.977733176660968, 7.078136180870879, 7.177387193107894, 7.2755277477722, 7.372596910208648, 7.468631478509203, 7.563666164531616, 7.657733756696743, 7.750865266761318, 7.843090062456269, 7.934435987622397, 8.02492947125694, 8.114595626699158, 8.203458342025424, 8.29154036258929, 8.378863366526598, 8.46544803394615, 8.551314110440803, 8.636480465479652, 8.72096514617759, 8.804785426882663, 8.887957854972745, 8.970498293210479, 9.052421958967974, 9.133743460600002, 9.2144768312155, 9.294635560071638, 9.374232621792341, 9.45328050359297, 9.531791230675346, 9.609776389941494, 9.687247152160374, 9.764214292709454, 9.840688211001757, 9.916678948698953, 9.992196206802143, 10.067249361703864, 10.1418474802776, 10.215999334074553, 10.289713412691501, 10.362997936368252, 10.435860867868385, 10.50830992369259, 10.580352584669924, 10.65199610596877, 10.723247526565935, 10.794113678209396, 10.864601193907449, 10.934716515974554, 11.004465903661902, 11.073855440398653, 11.142891040667896, 11.211578456539659, 11.279923283881647, 11.34793096826702, 11.415606810597074, 11.482955972455505, 11.549983481209791, 11.616694234874155, 11.683093006747622, 11.749184449839774, 11.81497310109599, 11.880463385433165, 11.945659619596254], [0.0, 0.949451458072936, 1.3900782987593032, 1.7373585499780915, 2.0351937534579254, 2.300945161096155, 2.543641801751757, 2.768705017757588, 2.9796980629156367, 3.1791143249264513, 3.3687808975161837, 3.5500849271070636, 3.7241095775541053, 3.8917202086153804, 4.053621412791763, 4.21039613417923, 4.362533312151672, 4.510447919393762, 4.654495808900651, 4.794984926926605, 4.93218392482831, 5.066328872390727, 5.19762856116962, 5.3262687442777885, 5.452415562631073, 5.576218340975053, 5.697811890056303, 5.817318417709468, 5.934849127247318, 6.05050556360314, 6.164380754316569, 6.2765601823928, 6.387122620407554, 6.496140849345037, 6.603682281092115, 6.709809499942419, 6.814580735650307, 6.918050278339979, 7.020268843788123, 7.121283896160024, 7.221139934114083, 7.3198787452406515, 7.417539633023593, 7.5141596198729115, 7.609773629246883, 7.704414649441784, 7.798113881259379, 7.8909008714537805, 7.982803633599471, 8.073848757802605, 8.164061510491223, 8.25346592536137, 8.342084886420343, 8.429940203952048, 8.517052684129473, 8.603442192912926, 8.689127714798177, 8.774127406913797, 8.858458648910783, 8.942138089038417, 9.025181686757394, 9.107604752203622, 9.189421982783164, 9.270647497149591, 9.351294866789441, 9.431377145418836, 9.510906896374136, 9.589896218161776, 9.668356768316544, 9.746299785703457, 9.823736111385765, 9.90067620817043, 9.977130178932232, 10.053107783808752, 10.128618456350216, 10.203671318700996, 10.278275195882925, 10.352438629244638, 10.426169889135824, 10.499476986860394, 10.572367685958165, 10.644849512860695, 10.71692976696325, 10.788615530151644, 10.859913675819607, 10.930830877409688, 11.001373616508149, 11.071548190522043, 11.141360719964592, 11.210817155373075, 11.279923283881647, 11.348684735469945, 11.41710698890688, 11.485195377407592, 11.55295509402035, 11.620391196759035, 11.687508613495751, 11.754312146627145, 11.82080647752715, 11.886996170797975, 11.952885678330436, 12.018479343183992], [0.0, 0.9551757873502568, 1.3984592073731115, 1.7478332428423573, 2.0474641218784297, 2.3148177689469094, 2.558977649743752, 2.785397792368291, 2.9976629338040794, 3.198281494613107, 3.3890915842359357, 3.571488712326859, 3.746562573234382, 3.9151837440493393, 4.078061065324938, 4.235780995780179, 4.388835422648951, 4.537641820524023, 4.682558187870646, 4.823894327579092, 4.9619205107295326, 5.096874230393152, 5.228965536949015, 5.358381303432346, 5.485288672437695, 5.609837869003126, 5.732164516661475, 5.852391560049552, 5.97063087293502, 6.086984612474816, 6.201546367080078, 6.314402135140823, 6.425631164159803, 6.535306673924402, 6.643496482753888, 6.750263552268299, 6.855666463294482, 6.959759833276737, 7.062594683761789, 7.1642187650806965, 7.26467684417832, 7.364010960586199, 7.462260654752482, 7.55946317229865, 7.6556536472396886, 7.750865266761318, 7.845129419777775, 7.938475831183243, 8.030932683448597, 8.122526726994158, 8.213283380581567, 8.303226822808206, 8.392380075651136, 8.480765080890455, 8.568402770141454, 8.655313129138131, 8.741515256835507, 8.827027419833131, 8.911867102565505, 8.996051053655718, 9.079595328785501, 9.162515330396975, 9.244825844508195, 9.326541074895383, 9.407674674868804, 9.488239776846623, 9.568249019910699, 9.647714575510461, 9.726648171465042, 9.805061114399592, 9.882964310739123, 9.960368286371809, 10.037283205083586, 10.113718885856793, 10.189684819117383, 10.265190182007974, 10.340243852757254, 10.41485442421043, 10.48903021657988, 10.562779289470397, 10.636109453228887, 10.709028279664444, 10.78154311218106, 10.853661075361877, 10.925389084040946, 10.996733851895607, 11.067701899590196, 11.138299562499402, 11.208532998037587, 11.278408192618354, 11.34793096826702, 11.41710698890688, 11.485941766338845, 11.55444066593249, 11.622608912045445, 11.690451593186822, 11.757973666939309, 11.825179964653643, 11.892075195928184, 11.958663952885548, 12.0249507142574, 12.090939849287906], [0.0, 0.9608721848841302, 1.4067992215208753, 1.7582568246646821, 2.059674617296155, 2.3286226857015255, 2.574238666790337, 2.802009114938892, 3.0155401454855806, 3.217355138501304, 3.4093031653900896, 3.5927880582300804, 3.7689060099978695, 3.9385327896591873, 4.102381465091294, 4.261041992486686, 4.415009192555229, 4.564703029589778, 4.710483637056916, 4.852662665423496, 4.9915119975897735, 5.127270542968261, 5.26014960461892, 5.3903371700347655, 5.518001378601381, 5.643293351256363, 5.766349520352836, 5.887293563734559, 6.006238022352622, 6.123285662600275, 6.238530631023404, 6.352059438882036, 6.463951806288557, 6.574281389692398, 6.6831164118620565, 6.790520209902812, 6.896551714000957, 7.0012658673237365, 7.1047139956959136, 7.20694413421798, 7.308001316812161, 7.4079278337218435, 7.5067634612031915, 7.604545667000013, 7.701309794656597, 7.797089229277627, 7.891915546971923, 7.985818649904509, 8.078826888618524, 8.170967173066211, 8.262265073599494, 8.35274491301006, 8.442429850571505, 8.531341958918487, 8.619502294496513, 8.706930962228832, 8.793647174971214, 8.879669308260032, 8.965014950801995, 9.04970095110423, 9.133743460600002, 9.217157973587229, 9.299959364263584, 9.382161921112585, 9.463779378868963, 9.544824948268905, 9.62531134377017, 9.705250809409259, 9.78465514294669, 9.863535718437124, 9.941903507348394, 10.019769098342092, 10.097142715818086, 10.174034237316341, 10.250453209861027, 10.326408865324629, 10.401910134883076, 10.47696566262687, 10.551583818387774, 10.625772709835777, 10.699540193896482, 10.772893887535105, 10.845841177949614, 10.91838923221215, 10.990545006394866, 11.062315254213576, 11.133706535220005, 11.204725222571225, 11.275377510402667, 11.345669420829209, 11.415606810597074, 11.485195377407592, 11.55444066593249, 11.623348073538885, 11.691922855740996, 11.76017013139436, 11.828094887647284, 11.895701984663308, 11.962996160127501, 12.029982033548597, 12.096664110368149, 12.163046785887252], [0.0, 0.9665410851343517, 1.4150989772889673, 1.7686300904435197, 2.0718261709960606, 2.3423609642502345, 2.5894260168373755, 2.8185402524020042, 3.0333310614411277, 3.2363367113229806, 3.4294171825001714, 3.6139845893012237, 3.791141591961057, 3.961769126258417, 4.126584466988747, 4.286181050935261, 4.4410566181235165, 4.591633610528334, 4.738274286311683, 4.881292134598501, 5.0209606423286495, 5.157520128419099, 5.291183142563847, 5.42213878133406, 5.5505561760947115, 5.676587339358297, 5.800369508393946, 5.922027090713079, 6.041673291229627, 6.15941148263229, 6.275336366907504, 6.3895349657096165, 6.502087469479294, 6.613067969220194, 6.722545090197701, 6.83058254318983, 6.937239606055903, 7.042571546113809, 7.146629991997555, 7.249463262202445, 7.351116656339335, 7.451632714153233, 7.551051446570049, 7.6494105423837, 7.746745553656351, 7.843090062456269, 7.938475831183243, 8.032932938417426, 8.126489901962914, 8.219173790533791, 8.311010325340519, 8.402023972673035, 8.492238028438736, 8.581674695495174, 8.670355154515507, 8.758299629036888, 8.845527445266026, 8.93205708715026, 9.017906247165174, 9.103091873219777, 9.187630212036666, 9.27153684932615, 9.354826747039871, 9.437514277959743, 9.519613257851923, 9.601136975392562, 9.682098220051472, 9.762509308101837, 9.842382106907948, 9.92172805762848, 10.000558196460123, 10.07888317453486, 10.156713276573914, 10.234058438392202, 10.310928263338896, 10.387332037752174, 10.46327874549962, 10.538777081669654, 10.61383546547391, 10.688462052415561, 10.762664745774055, 10.836451207452761, 10.909828868232225, 10.982804937468481, 11.055386412272732, 11.127580086205985, 11.199392557519644, 11.270830236970781, 11.34189935523864, 11.412605969967037, 11.482955972455505, 11.55295509402035, 11.622608912045445, 11.691922855740996, 11.760902211627414, 11.82955212876017, 11.897877623710473, 11.965883585315584, 12.033574779211708, 12.100955852161494, 12.168031336187452, 12.234805652521827], [0.0, 0.9721829112634965, 1.4233590942236607, 1.778953814505047, 2.0839196900469834, 2.3560336301050535, 2.604540833564747, 2.8349924387463, 3.0510370096972297, 3.2552276299828065, 3.449435137003656, 3.6350798877834527, 3.8132709789284416, 3.9848944883541804, 4.150671877682462, 4.3112000476642525, 4.466979643698428, 4.618435573608608, 4.765932210104807, 4.909784872188792, 5.050268643179291, 5.187625244766079, 5.3220684673233825, 5.453788511203668, 5.582955495013705, 5.709722318582809, 5.834227020251917, 5.956594733715285, 6.076939324678664, 6.195364769230593, 6.311966322145331, 6.4268315130339495, 6.540041000419156, 6.651669307783439, 6.7617854609667924, 6.870453542635335, 6.977733176660969, 7.083679952964113, 7.18834580154183, 7.291779322930774, 7.394026081161521, 7.495128864289113, 7.5951279167884405, 7.694061147447817, 7.791964315851422, 7.888871200090424, 7.984813747965879, 8.079822213630525, 8.173925281350593, 8.267150177843773, 8.359522774458583, 8.45106768029788, 8.541808327250301, 8.63176704777437, 8.72096514617759, 8.809422964044536, 8.8971599403915, 8.984194667059027, 9.070544939795981, 9.15622780543853, 9.241259605543496, 9.325656016797016, 9.409432088485586, 9.49260227728692, 9.575180479611603, 9.657180061703517, 9.738613887686274, 9.819494345724747, 9.899833372454578, 9.979642475817974, 10.058932756431343, 10.137714927598712, 10.215999334074555, 10.293795969670441, 10.37111449379154, 10.447964246981591, 10.524354265548187, 10.600293295334106, 10.675789804695023, 10.750851996738836, 10.825487820877473, 10.899704983737823, 10.97351095947487, 11.046912999526596, 11.119918141847252, 11.192533219652747, 11.264764869709335, 11.336619540194512, 11.408103498156809, 11.479222836599298, 11.549983481209791, 11.620391196759035, 11.690451593186822, 11.76017013139436, 11.82955212876017, 11.898602764395429, 11.967327084153727, 12.035730005409103, 12.103816321615401, 12.171590706659028, 12.2390577190165, 12.30622180572737], [0.0, 0.9777980755462433, 1.4315801759304148, 1.7892287512521683, 2.095956058179042, 2.3696416823917597, 2.6195842214829534, 2.851366876210147, 3.068659284110513, 3.2740292749287496, 3.4693584917063025, 3.6560754952091012, 3.835295787998049, 4.0079105658250755, 4.174645457352438, 4.336100810929016, 4.4927801635969455, 4.645110877375663, 4.79345942953041, 4.9381429602922475, 5.079438141814688, 5.2175880919311535, 5.352807835832964, 5.485288672437695, 5.6152017029284504, 5.742700710258137, 5.8679245300538305, 5.990999018760869, 6.112038699754087, 6.231148149670348, 6.348423173459398, 6.463951806288557, 6.577815172550535, 6.690088226162868, 6.800840391647142, 6.910136121800131, 7.018035384871152, 7.1245940918586115, 7.229864472698466, 7.333895408635858, 7.436732726871511, 7.538419462597041, 7.638996092732631, 7.738500745021352, 7.836969385588701, 7.934435987622398, 8.030932683448597, 8.126489901962916, 8.22113649310706, 8.314899840855643, 8.407805965985723, 8.499879619738175, 8.59114436934027, 8.681622676239037, 8.771335967792066, 8.860304703073483, 8.948548433376057, 9.036085857923664, 9.122934875250408, 9.2091126306521, 9.294635560071638, 9.379519430741048, 9.463779378868963, 9.547429944632427, 9.630485104705343, 9.712958302532762, 9.794862476539297, 9.876210086441777, 9.957013137819827, 10.037283205083588, 10.117031452964751, 10.19626865664558, 10.275005220630106, 10.353251196452462, 10.431016299308908, 10.508309923692591, 10.585141158103287, 10.661518798898287, 10.737451363345057, 10.812947101931261, 10.888014009983285, 10.962659838640198, 11.036892105226437, 11.110718103063064, 11.184144910754368, 11.257179400983757, 11.329828248850328, 11.40209793977516, 11.473994777004195, 11.545524888732666, 11.616694234874155, 11.687508613495751, 11.757973666939309, 11.828094887647284, 11.897877623710473, 11.967327084153727, 12.03644834397463, 12.10524634894915, 12.173725920217304, 12.241891758661083, 12.309748449085987, 12.377300464216924], [0.0, 0.9833869797597674, 1.4397628106454459, 1.7994556358788798, 2.1079361366204674, 2.383186094795991, 2.634557256979008, 2.8676647364200396, 3.08619914559291, 3.2927429914592596, 3.4891886721673258, 3.67697291385939, 3.8572175950927083, 4.030819005521333, 4.198506921360262, 4.360885122433135, 4.518460023902191, 4.671661430505305, 4.820857914220711, 4.966368427991541, 5.108471225375692, 5.247410813820985, 5.383403447561039, 5.516641518940953, 5.64729710712502, 5.775524874059687, 5.901464448929554, 6.025242407551, 6.146973927892264, 6.26676418432999, 6.38470952941644, 6.500898501510882, 6.615412688697326, 6.728327473315367, 6.839712676703695, 6.949633120058775, 7.058149114396807, 7.165316890292627, 7.271188976218378, 7.375814532814919, 7.479239649222372, 7.581507606613161, 7.682659113265697, 7.782732514853839, 7.881763983078483, 7.979787685311502, 8.076835937541198, 8.172939342588855, 8.268126915296852, 8.362426196161293, 8.455863354688947, 8.54846328359399, 8.640249684809394, 8.73124514816746, 8.821471223500401, 8.910948486822445, 8.99969660117776, 9.087734372671358, 9.175079802141894, 9.261750132884366, 9.347761894786336, 9.433130945202267, 9.517872506856433, 9.602001203034705, 9.685531090298944, 9.76847568893433, 9.850848011319, 9.932660588387108, 10.013925494339846, 10.09465436974444, 10.17485844314802, 10.254548551321705, 10.33373515823965, 10.412428372888611, 10.490637965995028, 10.568373385749146, 10.645643772598843, 10.722457973179688, 10.79882455344219, 10.874751811032205, 10.950247786975853, 11.02532027671621, 11.099976840545283, 11.174224813471344, 11.24807131455861, 11.321523255773416, 11.39458735036843, 11.467270120834144, 11.539577906444627, 11.611516870422689, 11.683093006747622, 11.754312146627145, 11.825179964653643, 11.895701984663308, 11.965883585315584, 12.035730005409103, 12.10524634894915, 12.174437589980785, 12.243308577200732, 12.31186403836031, 12.380108584470879, 12.448046713822572], [0.0, 0.9889500155562657, 1.4479075717811325, 1.809635185051933, 2.11986076489612, 2.3966678164660355, 2.6494609893144503, 2.8838871614769155, 3.103657823280762, 3.3113700909706156, 3.5089270680211584, 3.697773608157327, 3.8790379364212315, 4.053621412791763, 4.222257941839584, 4.385554718980406, 4.544021024175099, 4.698089093573785, 4.848129584172243, 4.99446325323548, 5.1373699284062, 5.277095500314749, 5.413857446548386, 5.547849247818769, 5.679243956744762, 5.808197110197905, 5.934849127247318, 6.0593272997507865, 6.181747457240151, 6.302215369065177, 6.4208279328460485, 6.5376741878049405, 6.652836183570954, 6.7663897289227775, 6.878405040179527, 6.988947305232206, 7.098077176277394, 7.205851201987184, 7.312322207988121, 7.417539633023594, 7.52154982696072, 7.6243963158142085, 7.7261200381498485, 7.826759556563584, 7.9263512473802, 8.024929471256938, 8.122526726994158, 8.219173790533791, 8.314899840855642, 8.409732574252839, 8.50369830827347, 8.59682207645019, 8.689127714798177, 8.780637940940784, 8.871374426617958, 8.961357864242773, 9.050608028093547, 9.13914383066173, 9.226983374617006, 9.31414400079997, 9.400642332608019, 9.486494317100924, 9.571715263118147, 9.656319876669727, 9.740322293835717, 9.823736111385765, 9.906574415309237, 9.988849807427982, 10.070574430247142, 10.151759990184813, 10.232417779308198, 10.312558695692202, 10.392193262505849, 10.471331645922593, 10.54998367194203, 10.628158842202966, 10.70586634886094, 10.783115088597079, 10.859913675819607, 10.936270455114299, 11.012193512995484, 11.08769068900519, 11.162769586204108, 11.237437581094774, 11.311701833014062, 11.385569293029413, 11.459046712370471, 11.532140650425555, 11.604857482330118, 11.677203406172415, 11.749184449839774, 11.82080647752715, 11.892075195928184, 11.962996160127501, 12.033574779211708, 12.103816321615401, 12.173725920217304, 12.243308577200732, 12.312569168691564, 12.381512449186078, 12.4501430557802, 12.51846551221097], [0.0, 0.9944875648186018, 1.4560150184467129, 1.8197680975616164, 2.1317307615898384, 2.410087772874723, 2.6642964415781463, 2.9000352649932637, 3.1210365156509567, 3.3299118521477586, 3.528575034239332, 3.7184790059974997, 3.9007583098733933, 4.076319352941518, 4.245900149214519, 4.410111294051962, 4.569464919088541, 4.724395680747329, 4.875276311489338, 5.0224293646351175, 5.166136234700652, 5.306644189161887, 5.4441719233550465, 5.578914001372093, 5.711044444826669, 5.84071966150702, 5.968080856748003, 6.093256035168334, 6.216361674878374, 6.337504137475197, 6.45678086314973, 6.574281389692398, 6.690088226162867, 6.80427760582523, 6.91692013816946, 7.028081376101122, 7.137822311434089, 7.246199809480379, 7.3532669916595506, 7.4590735735434235, 7.563666164531615, 7.667088534359396, 7.7693818508248915, 7.870584892452326, 7.970734239252907, 8.069864444283722, 8.168008188319655, 8.265196419630147, 8.36145848058045, 8.456822222546947, 8.551314110440805, 8.644959317968006, 8.737781814611665, 8.829804445200704, 8.921049002824313, 9.011536295761129, 9.101286209014017, 9.190317760973464, 9.278649155673653, 9.36629783105388, 9.453280503592968, 9.53961320964502, 9.625311343770168, 9.710389694323611, 9.794862476539297, 9.878743363320929, 9.962045513931868, 10.044781600756885, 10.126963834292145, 10.20860398650493, 10.289713412691501, 10.370303071949689, 10.450383546372192, 10.529965059057169, 10.609057491024139, 10.687670397115605, 10.76581302095787, 10.843494309048335, 10.920722924030946, 10.997507257216336, 11.07385544039865, 11.149775357016823, 11.225274652704302, 11.300360745267774, 11.375040834132273, 11.4493219092872, 11.52321075976519, 11.596713981683354, 11.669837985874219, 11.742589005131759, 11.81497310109599, 11.886996170797975, 11.958663952885548, 12.029982033548597, 12.100955852161494, 12.171590706659028, 12.241891758661083, 12.31186403836031, 12.381512449186078, 12.450841772257101, 12.51985667063437, 12.588561693385234], [0.0, 1.0, 1.4640856959456257, 1.8298550549433454, 2.1435469250725867, 2.423446866642654, 2.679064611596349, 2.9161101330837065, 3.1383363915870035, 3.348369522101714, 3.548133892335755, 3.739090500016221, 3.9223801763523367, 4.098914352624463, 4.2694351336499485, 4.434556499312672, 4.594793419988141, 4.750582961395879, 4.902299922049409, 5.050268643179291, 5.194772079068655, 5.336058867794732, 5.474348916919926, 5.609837869003126, 5.742700710258137, 5.8730947154400965, 6.001161872583699, 6.127030895836055, 6.25081890894459, 6.372632863067706, 6.492570738506389, 6.610722569358193, 6.727171322029718, 6.841993652345322, 6.955260561182715, 7.067037964806599, 7.1773871931078945, 7.286365426602506, 7.394026081161522, 7.500419147929704, 7.605591494662135, 7.709587133709311, 7.812447461062076, 7.9142114701936475, 8.01491594387789, 8.114595626699158, 8.213283380581567, 8.311010325340519, 8.407805965985721, 8.50369830827347, 8.598713963809688, 8.692878245837976, 8.78621525670406, 8.878747967865536, 8.97049829321048, 9.061487156357623, 9.151734552532215, 9.241259605543496, 9.330080620330445, 9.418215131490685, 9.50567994816233, 9.592491195588838, 9.678664353662242, 9.764214292709456, 9.849155306759332, 9.933501144504355, 10.017265038149553, 10.100459730322612, 10.183097499202358, 10.265190182007975, 10.346749196978026, 10.427785563956519, 10.508309923692591, 10.588332555950938, 10.667863396521476, 10.746912053209108, 10.825487820877473, 10.903599695614323, 10.981256388080556, 11.05846633609976, 11.13523771654054, 11.211578456539659, 11.287496244110235, 11.362998538175791, 11.438092578067703, 11.51278539252082, 11.587083808199319, 11.660994457782525, 11.734523787638151, 11.807678065108487, 11.880463385433165, 11.952885678330436, 12.0249507142574, 12.096664110368149, 12.168031336187452, 12.2390577190165, 12.309748449085987, 12.380108584470879, 12.4501430557802, 12.51985667063437, 12.589254117941675, 12.658339971984903], [0.0, 1.0054876844486578, 1.4721201362507685, 1.8398967220716558, 2.1553100341982754, 2.436745978324877, 2.6937664728023556, 2.932112825311603, 3.1555585913977717, 3.3667443174565106, 3.5676049315184812, 3.759609448805284, 3.9439049610478287, 4.12140790117374, 4.292864446437432, 4.4588919460506435, 4.620008196383805, 4.776652661635189, 4.929202197094296, 5.07798292387401, 5.223279349021281, 5.36534147506065, 5.504390416337833, 5.6406228890363455, 5.774214839639116, 5.90532440597551, 6.034094355265754, 6.16065410799958, 6.2851214306625796, 6.407603861327367, 6.528199917979901, 6.64700012879645, 6.764087915477076, 6.879540354509112, 6.99342883640068, 7.1058196391441415, 7.216774429189508, 7.32635070084131, 7.434602163100081, 7.541579081446212, 7.647328580830235, 7.751894915128539, 7.855319707500102, 7.957642165402017, 8.058899273460407, 8.159125966926942, 8.258355288061603, 8.356618527455524, 8.453945352032592, 8.55036392123586, 8.645900992707343, 8.740582018601735, 8.834431233530832, 8.927471735012341, 9.019725557190842, 9.111213738507278, 9.20195638391439, 9.291972722166847, 9.381281158655355, 9.46989932420188, 9.557844120187777, 9.645131760346757, 9.731777809519611, 9.817797219636917, 9.90320436316865, 9.988013064255775, 10.072236627717489, 10.155887866108996, 10.238979124987894, 10.321522306532293, 10.403528891640445, 10.485009960629782, 10.565976212642514, 10.646437983855446, 10.72640526458297, 10.805887715354595, 10.884894682041235, 10.963435210098334, 11.041518057988148, 11.11915170983838, 11.196344387389708, 11.273104061280517, 11.349438461713321, 11.425355088543858, 11.500861220830673, 11.575963925880089, 11.650670067818867, 11.724986315724381, 11.798919151339977, 11.872474876401139, 11.945659619596254, 12.018479343183992, 12.090939849287906, 12.163046785887252, 12.234805652521827, 12.30622180572737, 12.377300464216924, 12.448046713822572, 12.51846551221097, 12.588561693385234, 12.658339971984903, 12.727804947394986]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 1.2000000000000002\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0630957344480193, 0.09563524997900366, 0.12197554094669344, 0.14495593273553906, 0.1657227008669993, 0.18488034812197066, 0.20279573822416416, 0.2197121086612235, 0.23580092567898678, 0.25118864315095796, 0.2659718114219439, 0.2802262064706805, 0.2940126465430822, 0.3073808600440716, 0.32037214975368056, 0.33302128296074923, 0.3453578665713643, 0.35740736945012747, 0.36919189698347965, 0.38073078774317565, 0.3920410799236362, 0.40313788079701995, 0.41403466282330303, 0.4247435035179738, 0.435275281648062, 0.44563983912891586, 0.45584611570090633, 0.4659022617970135, 0.4758157337824938, 0.48559337483020376, 0.4952414840026903, 0.5047658755841546, 0.5141719302988788, 0.5234646397369045, 0.532648645060355, 0.5417282708684605, 0.5507075549439766, 0.5595902744792605, 0.5683799692799553, 0.5770799623628854, 0.585693378298389, 0.5942231595928824, 0.6026720813625591, 0.6110427645119373, 0.6193376876000052, 0.6275591975508273, 0.6357095193437304, 0.6437907647998604, 0.6518049405663864, 0.659753955386447, 0.6676396267317009, 0.6754636868647266, 0.6832277883902761, 0.6909335093472795, 0.6985823578873713, 0.706175776580398, 0.7137151463827599, 0.7212017903004272, 0.7286369767749634, 0.7360219228178333, 0.7433577969155766, 0.750645721726072, 0.7578867765840317, 0.7650819998320295, 0.7722323909917427, 0.7793389127886403, 0.7864024930420794, 0.7934240264316235, 0.800404376149386, 0.8073443754472972, 0.8142448290873745, 0.821106514702358, 0.8279301840734127, 0.8347165643310208, 0.8414663590846496, 0.8481802494863159, 0.854858895232727, 0.8615029355102994, 0.8681129898869979, 0.8746896591546225, 0.881233526124879, 0.88774515638231, 0.894225098996915, 0.900673887199084, 0.9070920390192546, 0.9134800578945333, 0.9198384332443488, 0.9261676410170553, 0.9324681442092668, 0.9387403933595694, 0.9449848270181492, 0.9512018721937607, 0.9573919447793617, 0.9635554499576546, 0.9696927825876808, 0.9758043275735478, 0.9818904602162896, 0.9879515465497973, 0.9939879436616984, 1.0, 1.0059880556662684], [0.0, 0.09563524997900366, 0.14495593273553906, 0.18488034812197066, 0.2197121086612235, 0.25118864315095796, 0.2802262064706805, 0.3073808600440716, 0.33302128296074923, 0.3574073694501274, 0.38073078774317565, 0.40313788079701995, 0.42474350351797374, 0.44563983912891586, 0.4659022617970135, 0.4855933748302038, 0.5047658755841546, 0.5234646397369045, 0.5417282708684605, 0.5595902744792605, 0.5770799623628854, 0.5942231595928824, 0.6110427645119373, 0.6275591975508273, 0.6437907647998604, 0.6597539553864471, 0.6754636868647266, 0.6909335093472795, 0.706175776580398, 0.7212017903004272, 0.7360219228178333, 0.750645721726072, 0.7650819998320296, 0.7793389127886402, 0.7934240264316235, 0.8073443754472971, 0.821106514702358, 0.8347165643310207, 0.848180249486316, 0.8615029355102994, 0.8746896591546224, 0.8877451563823099, 0.900673887199084, 0.9134800578945335, 0.9261676410170553, 0.9387403933595695, 0.9512018721937607, 0.9635554499576547, 0.9758043275735478, 0.9879515465497972, 0.9999999999999999, 1.0119524426960576, 1.023811500257058, 1.035579677563402, 1.0472593664748386, 1.0588528529217847, 1.070362323431255, 1.081789871141743, 1.0931375013553157, 1.1044071366698645, 1.1156006217298275, 1.1267197276296117, 1.1377661560003618, 1.1487415428075818, 1.159647461884313, 1.1704854282221195, 1.1812569010399445, 1.191963286648958, 1.2026059411297958, 1.2131861728370446, 1.2237052447444592, 1.2341643766431614, 1.2445647472039778, 1.2549074959140751, 1.2651937248971707, 1.275424500625791, 1.2856008555333316, 1.2957237895330211, 1.3057942714503001, 1.3158132403745966, 1.325781606935995, 1.335700254511853, 1.3455700403680315, 1.355391796739025, 1.3651663318509693, 1.3748944308911808, 1.384576856927622, 1.3942143517814285, 1.4038076368554062, 1.4133574139211929, 1.422864365867587, 1.4323291574123718, 1.4417524357797895, 1.4511348313456869, 1.4604769582521981, 1.4697794149937136, 1.4790427849757657, 1.4882676370483492, 1.4974545260150967, 1.5066039931196407, 1.5157165665103982, 1.5247927616849475], [0.0, 0.12197554094669344, 0.18488034812197066, 0.23580092567898683, 0.28022620647068053, 0.32037214975368056, 0.35740736945012747, 0.3920410799236362, 0.4247435035179738, 0.45584611570090633, 0.4855933748302038, 0.5141719302988789, 0.5417282708684605, 0.5683799692799553, 0.5942231595928825, 0.6193376876000052, 0.6437907647998605, 0.6676396267317011, 0.6909335093472796, 0.71371514638276, 0.7360219228178334, 0.7578867765840317, 0.7793389127886404, 0.8004043761493861, 0.8211065147023581, 0.8414663590846496, 0.8615029355102994, 0.8812335261248792, 0.9006738871990841, 0.9198384332443488, 0.9387403933595695, 0.9573919447793618, 0.975804327573548, 0.9939879436616983, 1.0119524426960578, 1.0297067968879101, 1.0472593664748386, 1.064617957225968, 1.0817898711417433, 1.0987819513108767, 1.1156006217298275, 1.1322519227618724, 1.1487415428075818, 1.165074846671754, 1.1812569010399445, 1.1972924974178876, 1.2131861728370448, 1.2289422285875011, 1.244564747203978, 1.260057607900753, 1.275424500625791, 1.2906689388826686, 1.3057942714503001, 1.3208036931145197, 1.3357002545118533, 1.3504868711739613, 1.3651663318509695, 1.3797413061829964, 1.3942143517814285, 1.4085879207747214, 1.4228643658675872, 1.4370459459572247, 1.451134831345687, 1.4651331085834607, 1.4790427849757657, 1.4928657927799618, 1.5066039931196407, 1.5202591796385239, 1.5338330819150792, 1.547327368656802, 1.560743650691363, 1.5740834837702447, 1.5873483711990972, 1.6005397663077712, 1.6136590747718584, 1.6267076567965482, 1.6396868291726892, 1.652597867214111, 1.6654420065845175, 1.6782204450215736, 1.6909343439652, 1.703584830096522, 1.7161729967934218, 1.7286999055081644, 1.7411665870721653, 1.7535740429325655, 1.7659232463249395, 1.7782151433861393, 1.7904506542109782, 1.8026306738561966, 1.8147560732949, 1.826827700324434, 1.838846380430456, 1.8508129176097643, 1.862728095154284, 1.8745926763984242, 1.8864074054318951, 1.8981730077799166, 1.9098901910526351, 1.9215596455654402, 1.933182044931763, 1.944758046629845], [0.0, 0.14495593273553906, 0.2197121086612235, 0.28022620647068053, 0.33302128296074923, 0.38073078774317565, 0.4247435035179738, 0.4659022617970135, 0.5047658755841546, 0.5417282708684605, 0.5770799623628854, 0.6110427645119373, 0.6437907647998604, 0.6754636868647266, 0.706175776580398, 0.7360219228178333, 0.7650819998320296, 0.7934240264316235, 0.8211065147023581, 0.848180249486316, 0.8746896591546225, 0.9006738871990841, 0.9261676410170553, 0.9512018721937607, 0.9758043275735478, 1.0, 1.023811500257058, 1.0472593664748386, 1.070362323431255, 1.0931375013553157, 1.1156006217298275, 1.1377661560003618, 1.1596474618843131, 1.1812569010399445, 1.2026059411297956, 1.223705244744459, 1.2445647472039778, 1.2651937248971707, 1.2856008555333318, 1.3057942714503001, 1.3257816069359947, 1.3455700403680313, 1.3651663318509695, 1.384576856927622, 1.4038076368554062, 1.4228643658675872, 1.4417524357797895, 1.4604769582521981, 1.4790427849757657, 1.4974545260150967, 1.5157165665103982, 1.533833081915079, 1.5518080519234878, 1.569645273224345, 1.5873483711990972, 1.604920810670347, 1.622365905793314, 1.639686829172689, 1.656886620278035, 1.673968193222827, 1.6909343439651998, 1.707787756982286, 1.7245310114646024, 1.7411665870721655, 1.7576968692897885, 1.7741241544152841, 1.790450654210978, 1.8066785002460082, 1.82280974795426, 1.8388463804304556, 1.8547903119848381, 1.8706433914750185, 1.886407405431895, 1.9020840809950434, 1.917675088671641, 1.933182044931763, 1.948606514651812, 1.9639500134168326, 1.9792140096915958, 1.9943999268695047, 2.0095091452076645, 2.024543003655771, 2.0395028015858903, 2.0543898004296346, 2.069205225228746, 2.0839502661046487, 2.0986260796520937, 2.1132337902616674, 2.1277744913755523, 2.142249246680646, 2.156659091242814, 2.1710050325858115, 2.185288051718146, 2.1995091041109305, 2.213669120629572, 2.2277690084219333, 2.241809651765445, 2.255791912875467, 2.269716632677058, 2.283584631542157, 2.29739670999407, 2.3111536493810165], [0.0, 0.1657227008669993, 0.25118864315095796, 0.32037214975368056, 0.38073078774317565, 0.435275281648062, 0.4855933748302038, 0.5326486450603551, 0.5770799623628854, 0.6193376876000052, 0.6597539553864471, 0.6985823578873713, 0.7360219228178333, 0.7722323909917427, 0.8073443754472972, 0.8414663590846496, 0.8746896591546225, 0.9070920390192548, 0.9387403933595695, 0.9696927825876808, 1.0, 1.0297067968879101, 1.0588528529217847, 1.0874735538923443, 1.1156006217298275, 1.143262629818316, 1.1704854282221195, 1.1972924974178873, 1.2237052447444592, 1.2497432545525011, 1.275424500625791, 1.3007655276272498, 1.325781606935995, 1.350486871173961, 1.374894430891181, 1.399016476229016, 1.422864365867587, 1.4464487051555701, 1.4697794149937136, 1.492865792779962, 1.5157165665103982, 1.538339942955893, 1.560743650691363, 1.5829349786366513, 1.604920810670347, 1.6267076567965482, 1.6483016812765647, 1.6697087280804628, 1.6909343439651998, 1.711983799445359, 1.732862107887866, 1.7535740429325655, 1.7741241544152844, 1.7945167829483537, 1.8147560732949, 1.8348459866571243, 1.8547903119848381, 1.874592676398424, 1.8942565548098476, 1.9137852788161438, 1.933182044931763, 1.9524499222190912, 1.9715918593702615, 1.9906106912879056, 2.009509145207664, 2.0282898464010137, 2.0469553234931666, 2.065508013427462, 2.0839502661046487, 2.1022843487228142, 2.1205124498413204, 2.138636683189983, 2.156659091242814, 2.1745816485739478, 2.192406265011812, 2.210134788606237, 2.2277690084219333, 2.245310657170645, 2.2627614136932674, 2.280122905302287, 2.2973967099940706, 2.314584358539769, 2.331687336462908, 2.348707085911109, 2.365645007428817, 2.3825024616373796, 2.3992807708283554, 2.415981220475481, 2.432605060670343, 2.4491535074864217, 2.4656277442758388, 2.4820289229028534, 2.4983581649178315, 2.51461656267519, 2.530805180398563, 2.5469250551962013, 2.5629771980294453, 2.578962594636896, 2.5948822064167456, 2.6107369712695765, 2.6265278044037674, 2.642255599105539], [0.0, 0.18488034812197066, 0.2802262064706805, 0.35740736945012747, 0.4247435035179738, 0.4855933748302038, 0.5417282708684605, 0.5942231595928824, 0.6437907647998604, 0.6909335093472795, 0.7360219228178333, 0.7793389127886404, 0.821106514702358, 0.8615029355102994, 0.9006738871990841, 0.9387403933595695, 0.9758043275735478, 1.0119524426960578, 1.0472593664748386, 1.0817898711417433, 1.1156006217298275, 1.1487415428075818, 1.1812569010399445, 1.2131861728370446, 1.2445647472039778, 1.275424500625791, 1.3057942714503001, 1.335700254511853, 1.3651663318509695, 1.3942143517814285, 1.4228643658675872, 1.451134831345687, 1.479042784975766, 1.5066039931196404, 1.533833081915079, 1.560743650691363, 1.587348371199097, 1.6136590747718582, 1.6396868291726892, 1.6654420065845175, 1.6909343439651996, 1.7161729967934216, 1.7411665870721653, 1.7659232463249395, 1.790450654210978, 1.8147560732949002, 1.8388463804304558, 1.862728095154284, 1.8864074054318951, 1.909890191052635, 1.933182044931763, 1.9562882925448573, 1.9792140096915958, 2.0019640387617934, 2.0245430036557712, 2.046955323493167, 2.0692052252287465, 2.091296755280263, 2.1132337902616674, 2.1350200469046814, 2.156659091242814, 2.1781543471239715, 2.1995091041109305, 2.220726524822829, 2.2418096517654447, 2.2627614136932674, 2.283584631542157, 2.304282023967618, 2.3248562125203858, 2.345309726488057, 2.365645007428817, 2.3858644134209612, 2.4059702230497684, 2.4259646391513696, 2.445849792331547, 2.465627744275839, 2.48530049086595, 2.504869965116179, 2.5243380399424726, 2.543706530775652, 2.5629771980294453, 2.5821517494331, 2.6012318422375857, 2.6202190853036846, 2.6391150410796507, 2.6579212274755055, 2.6766391196405332, 2.695270151650034, 2.7138157181069595, 2.7322771756636395, 2.7506558444684384, 2.7689530095418378, 2.787169922086124, 2.8053078007325642, 2.8233678327297054, 2.841351175076157, 2.8592589556010206, 2.87709227399489, 2.8948522027941883, 2.9125397883213866, 2.930156051583522, 2.9477019891312572], [0.0, 0.20279573822416416, 0.3073808600440716, 0.3920410799236362, 0.4659022617970135, 0.5326486450603551, 0.5942231595928824, 0.6518049405663864, 0.706175776580398, 0.7578867765840317, 0.8073443754472972, 0.8548588952327271, 0.900673887199084, 0.9449848270181493, 0.9879515465497973, 1.0297067968879101, 1.070362323431255, 1.1100132856138076, 1.1487415428075818, 1.1866181438433936, 1.2237052447444592, 1.260057607900753, 1.2957237895330211, 1.330747091418958, 1.3651663318509695, 1.3990164762290163, 1.4323291574123718, 1.4651331085834605, 1.4974545260150967, 1.5293173751799052, 1.560743650691363, 1.591753598340259, 1.622365905793314, 1.6525978672141108, 1.6824655260514865, 1.7119837994453588, 1.7411665870721653, 1.770026866752703, 1.7985767787452502, 1.8268277003244342, 1.854790311984838, 1.8824746563950183, 1.909890191052635, 1.9370458354471285, 1.9639500134168326, 1.9906106912879056, 2.017035412299242, 2.0432313277476624, 2.0692052252287465, 2.094963554298832, 2.1205124498413204, 2.1458577533843255, 2.171005032585812, 2.1959595990758545, 2.220726524822829, 2.245310657170645, 2.269716632677058, 2.2939488898683043, 2.3180116810123805, 2.341909083002052, 2.365645007428817, 2.3892232099204134, 2.4126472988068692, 2.4359207431734036, 2.459046880352574, 2.482028922902854, 2.504869965116179, 2.527572989092894, 2.55014087041887, 2.572576383476297, 2.5948822064167456, 2.6170609258224764, 2.6391150410796507, 2.6610469684849924, 2.682859045105565, 2.704553532409639, 2.7261326196850826, 2.747598427260346, 2.768953009541838, 2.790198357880382, 2.811336403278409, 2.832369018948605, 2.853298022733899, 2.874125179397899, 2.8948522027941883, 2.915480757922246, 2.936012462877187, 2.9564488906999657, 2.976791571134212, 2.9970419922954217, 3.0172016022577943, 3.0372718105636625, 3.0572539896600928, 3.0771494762669143, 3.0969595726801686, 3.1166855480146625, 3.136328639389091, 3.155890053056948, 3.175370965486246, 3.194772524390845, 3.2140958497160392, 3.2333420345808612], [0.0, 0.2197121086612235, 0.33302128296074923, 0.4247435035179738, 0.5047658755841546, 0.5770799623628854, 0.6437907647998604, 0.706175776580398, 0.7650819998320296, 0.821106514702358, 0.8746896591546225, 0.9261676410170554, 0.9758043275735478, 1.023811500257058, 1.070362323431255, 1.1156006217298278, 1.1596474618843131, 1.2026059411297958, 1.244564747203978, 1.2856008555333318, 1.325781606935995, 1.3651663318509695, 1.4038076368554062, 1.4417524357797895, 1.479042784975766, 1.5157165665103982, 1.5518080519234878, 1.5873483711990972, 1.622365905793314, 1.656886620278035, 1.6909343439651998, 1.7245310114646024, 1.757696869289789, 1.790450654210978, 1.82280974795426, 1.8547903119848381, 1.886407405431895, 1.917675088671641, 1.9486065146518121, 1.9792140096915958, 2.0095091452076645, 2.0395028015858903, 2.069205225228746, 2.098626079652094, 2.1277744913755523, 2.1566590912428145, 2.185288051718146, 2.213669120629572, 2.241809651765445, 2.269716632677058, 2.29739670999407, 2.3248562125203858, 2.3521011723446588, 2.3791373441708803, 2.405970223049769, 2.432605060670343, 2.4590468803525742, 2.4853004908659497, 2.5113704991848413, 2.5372613222793183, 2.5629771980294453, 2.588522195341685, 2.6139002235378315, 2.639115041079651, 2.6641702636859947, 2.689069371893498, 2.7138157181069595, 2.738412533181035, 2.7628629325709153, 2.787169922086124, 2.811336403278409, 2.8353651784918816, 2.8592589556010206, 2.8830203524598934, 2.906651901083903, 2.930156051583522, 2.953535175867838, 2.976791571134212, 2.9999274631590236, 3.022945009403235, 3.0458463019454065, 3.0686333702537736, 3.091308183808104, 3.1138726545811877, 3.1363286393890903, 3.158677942118569, 3.1809223158394495, 3.2030634648091696, 3.225103046376161, 3.2470426727882757, 3.2688839129119938, 3.2906282938677616, 3.312277302586426, 3.3338323872913813, 3.3552949589107475, 3.3766663924235667, 3.3979480281437917, 3.4191411729455266, 3.440247101432813, 3.4612670570569914, 3.4822022531844974, 3.5030538741177715], [0.0, 0.23580092567898678, 0.3574073694501274, 0.45584611570090633, 0.5417282708684605, 0.6193376876000052, 0.6909335093472795, 0.7578867765840317, 0.821106514702358, 0.881233526124879, 0.9387403933595694, 0.9939879436616984, 1.0472593664748384, 1.0987819513108765, 1.1487415428075818, 1.1972924974178873, 1.2445647472039778, 1.2906689388826686, 1.335700254511853, 1.3797413061829964, 1.422864365867587, 1.4651331085834605, 1.5066039931196404, 1.5473273686568019, 1.587348371199097, 1.626707656796548, 1.6654420065845172, 1.703584830096522, 1.7411665870721653, 1.778215143386139, 1.8147560732949, 1.850812917609764, 1.8864074054318951, 1.9215596455654398, 1.9562882925448573, 1.9906106912879051, 2.024543003655771, 2.0581003196211727, 2.0912967552802635, 2.124145539569273, 2.156659091242814, 2.188849087422717, 2.220726524822829, 2.2523017745874614, 2.283584631542157, 2.314584358539769, 2.345309726488057, 2.375769050563783, 2.4059702230497684, 2.435920743173403, 2.4656277442758388, 2.4950980185991054, 2.5243380399424726, 2.5533539844085515, 2.5821517494331, 2.6107369712695765, 2.6391150410796507, 2.667291119763666, 2.695270151650034, 2.723056877149456, 2.7506558444684384, 2.778071420466487, 2.805307800732564, 2.832369018948605, 2.85925895560102, 2.885981346095044, 2.912539788321386, 2.9389377497198854, 2.9651785738805807, 2.99126548671884, 3.017201602257794, 3.0429899280482746, 3.068633370253773, 3.0941347384254625, 3.1194967499901574, 3.144722034472107, 3.169813137467737, 3.194772524390845, 3.219602584004316, 3.2443056317530985, 3.2688839129119938, 3.293339605560724, 3.3176748233977786, 3.3418916184036185, 3.3659919833630267, 3.3899778542556356, 3.413851112522983, 3.4376135872198446, 3.461267057056991, 3.4848132523420436, 3.5082538568245707, 3.531590509451179, 3.554824806035919, 3.577958300850966, 3.600992508142206, 3.623928903574012, 3.646768925607252, 3.6695139768142537, 3.692165425134248, 3.7147246050725506, 3.7371928188465526, 3.759571337481384], [0.0, 0.25118864315095796, 0.38073078774317565, 0.4855933748302038, 0.5770799623628854, 0.6597539553864471, 0.7360219228178333, 0.8073443754472972, 0.8746896591546225, 0.9387403933595694, 1.0, 1.0588528529217847, 1.1156006217298275, 1.1704854282221195, 1.2237052447444592, 1.275424500625791, 1.325781606935995, 1.374894430891181, 1.4228643658675872, 1.4697794149937136, 1.5157165665103982, 1.560743650691363, 1.604920810670347, 1.6483016812765647, 1.6909343439651998, 1.732862107887866, 1.7741241544152841, 1.8147560732949, 1.8547903119848381, 1.8942565548098476, 1.933182044931763, 1.9715918593702615, 2.0095091452076645, 2.0469553234931666, 2.0839502661046487, 2.1205124498413204, 2.156659091242814, 2.192406265011812, 2.2277690084219333, 2.2627614136932674, 2.29739670999407, 2.331687336462908, 2.365645007428817, 2.3992807708283554, 2.432605060670343, 2.465627744275839, 2.4983581649178315, 2.530805180398563, 2.5629771980294453, 2.5948822064167456, 2.6265278044037674, 2.6579212274755055, 2.689069371893498, 2.719978816795764, 2.7506558444684384, 2.7811064589713204, 2.811336403278409, 2.841351175076157, 2.871156041346198, 2.9007560518453506, 2.930156051583522, 2.959360692389415, 2.9883744436445445, 3.0172016022577943, 3.045846301945406, 3.0743125218748473, 3.102604094725244, 3.1307247142119863, 3.158677942118569, 3.186467214874692, 3.2140958497160392, 3.241567050457907, 3.2688839129119938, 3.2960494299730256, 3.32306649639959, 3.34993791331143, 3.3766663924235667, 3.4032545600358954, 3.429704960795374, 3.456020061246496, 3.4822022531844974, 3.5082538568245707, 3.5341771237993345, 3.559974239995829, 3.5856473282424717, 3.6111984508555808, 3.636629612054376, 3.6619427602526975, 3.6871397902350713, 3.7122225452242175, 3.7371928188465526, 3.762052357001815, 3.7868028596424748, 3.8114459824682188, 3.835983338540439, 3.860416499821292, 3.884746998641632, 3.9089763291017836, 3.933105948408916, 3.9571372781544785, 3.981071705534973, 4.004910584519123], [0.0, 0.2659718114219439, 0.40313788079701995, 0.5141719302988789, 0.6110427645119373, 0.6985823578873713, 0.7793389127886404, 0.8548588952327271, 0.9261676410170554, 0.9939879436616984, 1.0588528529217847, 1.1211693641406026, 1.1812569010399445, 1.239371834976368, 1.2957237895330214, 1.3504868711739613, 1.4038076368554062, 1.4558108906154006, 1.5066039931196407, 1.5562801267318054, 1.6049208106703472, 1.652597867214111, 1.6993749790918402, 1.7453089376954647, 1.7904506542109782, 1.8348459866571245, 1.8785364223400725, 1.9215596455654402, 1.9639500134168328, 2.005738957226198, 2.046955323493167, 2.087625665091567, 2.1277744913755523, 2.167424484084174, 2.2065966846120197, 2.245310657170645, 2.283584631542157, 2.3214356284713515, 2.358879570218299, 2.395931378370447, 2.432605060670343, 2.4689137883353474, 2.504869965116179, 2.5404852891519827, 2.5757708085227637, 2.610736971269577, 2.6453936705436805, 2.6797502854542503, 2.71381571810696, 2.747598427260346, 2.7811064589713204, 2.8143474745538106, 2.847328776134022, 2.8800573300510153, 2.9125397883213866, 2.944782508360985, 2.9767915711342123, 3.0085727978820542, 3.0401317655630393, 3.071473821126582, 3.1026040947252445, 3.13352751196112, 3.164248805251577, 3.1947725243908454, 3.225103046376161, 3.2552445845603484, 3.2852011971866357, 3.3149767953561007, 3.3445751504733585, 3.373999901211801, 3.403254560035896, 3.4323425193146098, 3.4612670570569914, 3.49003134229816, 3.5186384401615056, 3.547091316620658, 3.575392842982804, 3.603545800113081, 3.6315528824181795, 3.6594167016057733, 3.6871397902350718, 3.714724605072551, 3.7421735302658328, 3.7694888803476454, 3.796672903080916, 3.823727782155161, 3.850655639743619, 3.8774585389298437, 3.9041384860118358, 3.9306974326912316, 3.9571372781544785, 3.983459871052496, 4.009667011384807, 4.035760452293748, 4.061741901773976, 4.087613024302105, 4.113375442391032, 4.139030738073148, 4.164580454316423, 4.190026096377015, 4.215369133091901, 4.240610998114725], [0.0, 0.2802262064706805, 0.42474350351797374, 0.5417282708684605, 0.6437907647998604, 0.7360219228178333, 0.821106514702358, 0.900673887199084, 0.9758043275735478, 1.0472593664748384, 1.1156006217298275, 1.1812569010399445, 1.2445647472039778, 1.3057942714503, 1.3651663318509695, 1.4228643658675872, 1.4790427849757657, 1.533833081915079, 1.5873483711990972, 1.6396868291726892, 1.6909343439651998, 1.7411665870721653, 1.790450654210978, 1.8388463804304556, 1.886407405431895, 1.933182044931763, 1.9792140096915956, 2.024543003655771, 2.069205225228746, 2.113233790261667, 2.156659091242814, 2.1995091041109305, 2.2418096517654447, 2.283584631542157, 2.3248562125203858, 2.365645007428817, 2.4059702230497684, 2.4458497923315465, 2.48530049086595, 2.5243380399424726, 2.562977198029445, 2.6012318422375857, 2.6391150410796507, 2.6766391196405332, 2.7138157181069595, 2.7506558444684384, 2.787169922086124, 2.8233678327297054, 2.8592589556010206, 2.8948522027941883, 2.9301560515835217, 2.9651785738805803, 2.9999274631590236, 3.034410059109315, 3.0686333702537736, 3.102604094725244, 3.1363286393890903, 3.1698131374677367, 3.203063464809169, 3.236085254925233, 3.2688839129119938, 3.301464628352444, 3.3338323872913813, 3.365991983363027, 3.3979480281437913, 3.4297049607953736, 3.461267057056991, 3.4926384376398287, 3.5238230760717677, 3.5548248060359184, 3.5856473282424717, 3.6162942168697643, 3.6467689256072515, 3.677074793330151, 3.7072150494329423, 3.7371928188465526, 3.767011126761945, 3.796672903080916, 3.8261809866131933, 3.8555381290373476, 3.8847469986416314, 3.9138101838595563, 3.942730196613871, 3.971509475481517, 4.000150388691196, 4.028655236964276, 4.057026256208964, 4.08526562007695, 4.113375442391032, 4.14135777945162, 4.169214632229461, 4.196947948451388, 4.224559624585433, 4.252051507731198, 4.279425397420973, 4.306683047336718, 4.333826166947686, 4.360856423073129, 4.38777544137427, 4.414584807779414, 4.441286069845841, 4.467880738061901], [0.0, 0.2940126465430822, 0.44563983912891586, 0.5683799692799553, 0.6754636868647266, 0.7722323909917427, 0.8615029355102994, 0.9449848270181493, 1.023811500257058, 1.0987819513108765, 1.1704854282221195, 1.239371834976368, 1.3057942714503, 1.3700361376803185, 1.432329157412372, 1.4928657927799618, 1.5518080519234878, 1.6092938967018713, 1.6654420065845175, 1.7203553879509732, 1.7741241544152841, 1.8268277003244342, 1.8785364223400722, 1.9293130992482395, 1.9792140096915958, 2.0282898464010137, 2.0765864705999797, 2.124145539569273, 2.171005032585812, 2.2171996947191612, 2.2627614136932674, 2.3077195417942455, 2.3521011723446588, 2.395931378370446, 2.4392334196150998, 2.482028922902854, 2.524338039942472, 2.5661795859392087, 2.607571161802713, 2.6485292622712526, 2.6890693718934977, 2.72920605049988, 2.7689530095418378, 2.8083231804681246, 2.8473287761340216, 2.8859813460950443, 2.9242918265160767, 2.962270585325571, 2.9999274631590236, 3.037271810563663, 3.0743125218748473, 3.111058066122329, 3.1475165152797473, 3.183695570132284, 3.219602584004316, 3.2552445845603484, 3.290628293867762, 3.325760146888438, 3.36064630854763, 3.39529268951211, 3.429704960795374, 3.4638885672951325, 3.497848740357323, 3.5315905094511795, 3.5651187130313278, 3.5984380086553047, 3.6315528824181786, 3.6644676577599897, 3.6971865036964164, 3.729713442518349, 3.7620523570018154, 3.7942069971659365, 3.826180986613193, 3.85797782848325, 3.889600911048853, 3.9210535129798427, 3.952338808299138, 3.983459871052496, 4.014419679712101, 4.04522112133234, 4.075866995474686, 4.10636001791721, 4.136702824163083, 4.166897972761232, 4.196947948451388, 4.226855165144749, 4.256621968750707, 4.2862506398592695, 4.315743396288114, 4.3451023955025745, 4.374329736916237, 4.403427464079304, 4.432397566761369, 4.46124198293479, 4.4899626006644215, 4.518561259909061, 4.547039754239644, 4.57539983247883, 4.603643200266376, 4.631771521554358, 4.659786420036067, 4.687689480512164], [0.0, 0.3073808600440716, 0.4659022617970135, 0.5942231595928825, 0.706175776580398, 0.8073443754472972, 0.9006738871990841, 0.9879515465497973, 1.070362323431255, 1.1487415428075818, 1.2237052447444592, 1.2957237895330214, 1.3651663318509695, 1.432329157412372, 1.4974545260150967, 1.5607436506913632, 1.622365905793314, 1.6824655260514867, 1.7411665870721655, 1.7985767787452502, 1.8547903119848381, 1.9098901910526351, 1.9639500134168328, 2.017035412299242, 2.0692052252287465, 2.120512449841321, 2.171005032585812, 2.220726524822829, 2.269716632677058, 2.3180116810123805, 2.365645007428817, 2.4126472988068692, 2.4590468803525742, 2.504869965116179, 2.55014087041887, 2.5948822064167456, 2.6391150410796507, 2.682859045105565, 2.726132619685083, 2.768953009541838, 2.811336403278409, 2.853298022733899, 2.8948522027941883, 2.9360124628771875, 2.9767915711342123, 3.0172016022577948, 3.0572539896600928, 3.096959572680169, 3.136328639389091, 3.175370965486246, 3.2140958497160392, 3.2525121461794066, 3.2906282938677625, 3.328452343706805, 3.3659919833630276, 3.403254560035896, 3.440247101432813, 3.4769763351015257, 3.513448706275082, 3.5496703943673857, 3.585647328242472, 3.6213852003675213, 3.6568894799481346, 3.6921654251342484, 3.727218094376109, 3.7620523570018154, 3.796672903080916, 3.831084252632306, 3.865290764229128, 3.8992966430484306, 3.933105948408916, 3.966722600836168, 4.000150388691197, 4.033392974394976, 4.066453900278773, 4.099336594087506, 4.132044374161071, 4.164580454316422, 4.196947948451389, 4.229149874889404, 4.261189160482843, 4.293068644491204, 4.324791082249133, 4.356359148638066, 4.38777544137427, 4.419042484125041, 4.450162729463948, 4.481138561675228, 4.511972299416642, 4.5426661982495, 4.573222453043856, 4.603643200266376, 4.633930520157812, 4.6640864388065575, 4.694112930124295, 4.724011917729363, 4.753785276743061, 4.783434835503796, 4.812962377203621, 4.842369641451449, 4.871658325766916, 4.900830087008648], [0.0, 0.32037214975368056, 0.4855933748302038, 0.6193376876000052, 0.7360219228178333, 0.8414663590846496, 0.9387403933595695, 1.0297067968879101, 1.1156006217298278, 1.1972924974178873, 1.275424500625791, 1.3504868711739613, 1.4228643658675872, 1.4928657927799618, 1.5607436506913632, 1.6267076567965482, 1.6909343439652, 1.7535740429325655, 1.8147560732949002, 1.8745926763984242, 1.9331820449317632, 1.9906106912879056, 2.046955323493167, 2.1022843487228142, 2.1566590912428145, 2.2101347886062372, 2.2627614136932674, 2.314584358539769, 2.3656450074288173, 2.415981220475481, 2.465627744275839, 2.51461656267519, 2.5629771980294453, 2.6107369712695765, 2.6579212274755055, 2.7045535324096384, 2.7506558444684384, 2.7962486657215457, 2.8413511750761575, 2.8859813460950443, 2.930156051583522, 2.9738911567236848, 3.0172016022577943, 3.060101478994818, 3.102604094725244, 3.1447220344721076, 3.1864672148746926, 3.2278509333910024, 3.268883912911994, 3.3095763423018285, 3.34993791331143, 3.389977854255636, 3.429704960795374, 3.469127624124467, 3.508253856824571, 3.547091316620658, 3.585647328242472, 3.623928903574012, 3.6619427602526975, 3.6996953388620972, 3.737192818846553, 3.774441133262364, 3.811445982468219, 3.8482128468469834, 3.8847469986416314, 3.921053512979843, 3.9571372781544785, 3.9930030052206447, 4.028655236964276, 4.064098356292009, 4.099336594087506, 4.134374036575294, 4.169214632229461, 4.203862198261269, 4.238320426716744, 4.272592890212635, 4.306683047336718, 4.340594247736227, 4.374329736916238, 4.407892660768027, 4.441286069845842, 4.474512923408983, 4.50757609324486, 4.54047836728736, 4.573222453043856, 4.605810980843109, 4.638246506915417, 4.670531516315527, 4.702668425698049, 4.7346595859544, 4.766507284719657, 4.79821374875712, 4.829781146227821, 4.861211588851705, 4.892507133966793, 4.923669786492136, 4.954701500800043, 4.98560418250268, 5.01637969015777, 5.047029836897877, 5.077556391987409, 5.107961082311246], [0.0, 0.33302128296074923, 0.5047658755841546, 0.6437907647998605, 0.7650819998320296, 0.8746896591546225, 0.9758043275735478, 1.070362323431255, 1.1596474618843131, 1.2445647472039778, 1.325781606935995, 1.4038076368554062, 1.4790427849757657, 1.5518080519234878, 1.622365905793314, 1.6909343439652, 1.757696869289789, 1.8228097479542602, 1.8864074054318951, 1.9486065146518121, 2.0095091452076645, 2.0692052252287465, 2.1277744913755523, 2.185288051718146, 2.241809651765445, 2.2973967099940706, 2.3521011723446588, 2.405970223049769, 2.459046880352574, 2.5113704991848413, 2.5629771980294453, 2.6139002235378315, 2.664170263685995, 2.7138157181069595, 2.7628629325709153, 2.811336403278409, 2.8592589556010206, 2.906651901083903, 2.9535351758678385, 2.9999274631590236, 3.045846301945406, 3.0913081838081036, 3.1363286393890903, 3.1809223158394495, 3.225103046376161, 3.268883912911994, 3.312277302586426, 3.3552949589107475, 3.3979480281437917, 3.440247101432813, 3.4822022531844974, 3.5238230760717677, 3.5651187130313287, 3.6060978865633544, 3.6467689256072524, 3.6871397902350718, 3.7272180943761093, 3.767011126761945, 3.8065258702599523, 3.845769019744841, 3.884746998641632, 3.923465974259257, 3.9619318720215237, 4.000150388691197, 4.038127004673238, 4.075866995474686, 4.113375442391032, 4.1506572424822, 4.187717117895238, 4.224559624585433, 4.261189160482842, 4.297609973146857, 4.333826166947686, 4.369841709810108, 4.4056604395518155, 4.441286069845842, 4.476722195834085, 4.511972299416642, 4.547039754239644, 4.581927830402415, 4.616639698903085, 4.651178435840281, 4.685547026387114, 4.719748368552417, 4.753785276743061, 4.787660485140087, 4.821376650900475, 4.854936357195454, 4.8883421160955, 4.921596371311392, 4.954701500800043, 4.9876598192432136, 5.0204735804066205, 5.053144979386457, 5.085676154749845, 5.1180691905753015, 5.150326118398886, 5.182448919071329, 5.214439524531093, 5.246299819497973, 5.278031643091579, 5.309636790378737], [0.0, 0.3453578665713643, 0.5234646397369045, 0.6676396267317011, 0.7934240264316235, 0.9070920390192548, 1.0119524426960578, 1.1100132856138076, 1.2026059411297958, 1.2906689388826686, 1.374894430891181, 1.4558108906154006, 1.533833081915079, 1.6092938967018713, 1.6824655260514867, 1.7535740429325655, 1.8228097479542602, 1.8903346960955845, 1.9562882925448575, 2.0207915323133547, 2.0839502661046487, 2.145857753384326, 2.2065966846120197, 2.2662408020157194, 2.3248562125203858, 2.38250246163738, 2.4392334196150998, 2.495098018599106, 2.55014087041887, 2.6044027878871745, 2.6579212274755055, 2.710730667438561, 2.7628629325709158, 2.8143474745538106, 2.8652116151214764, 2.9154807579222464, 2.9651785738805807, 3.014327164015675, 3.0629472029912845, 3.1110580661223293, 3.158677942118569, 3.2058239334823435, 3.252512146179407, 3.298757769956206, 3.344575150473358, 3.3899778542556365, 3.4349787273170374, 3.4795899482005352, 3.523823076071768, 3.5676890944210036, 3.611198450855581, 3.6543610934035247, 3.697186503696417, 3.73968372735448, 3.7818614018579346, 3.823727782155161, 3.8652907642291283, 3.9065579068183216, 3.947536451466457, 3.9882333410560626, 4.028655236964276, 4.068808534964476, 4.108699379984416, 4.1483336798201895, 4.187717117895238, 4.22685516514475, 4.2657530910979125, 4.304415974223444, 4.342848711597637, 4.381056027948547, 4.419042484125041, 4.456812485034928, 4.494370287092472, 4.531720005211965, 4.568865619380865, 4.605810980843109, 4.642559817920577, 4.679115741498369, 4.715482250197416, 4.751662735256006, 4.787660485140088, 4.823478689900609, 4.8591204452947165, 4.89458875668633, 4.929886542740417, 4.965016638924198, 4.999981800827518, 5.034784707313713, 5.069427963511477, 5.103914103657462, 5.138245593798639, 5.172424834362837, 5.206454162605237, 5.24033585493812, 5.27407212915061, 5.30766514652472, 5.34111701385361, 5.374429785367495, 5.407605464572396, 5.440646006006479, 5.4735533169184905, 5.506329258872486], [0.0, 0.35740736945012747, 0.5417282708684605, 0.6909335093472796, 0.8211065147023581, 0.9387403933595695, 1.0472593664748386, 1.1487415428075818, 1.244564747203978, 1.335700254511853, 1.4228643658675872, 1.5066039931196407, 1.5873483711990972, 1.6654420065845175, 1.7411665870721655, 1.8147560732949002, 1.8864074054318951, 1.9562882925448575, 2.0245430036557712, 2.0912967552802635, 2.1566590912428145, 2.220726524822829, 2.2835846315421575, 2.345309726488057, 2.405970223049769, 2.465627744275839, 2.5243380399424726, 2.5821517494331006, 2.639115041079651, 2.695270151650034, 2.7506558444684384, 2.8053078007325642, 2.859258955601021, 2.912539788321386, 2.9651785738805807, 3.0172016022577943, 3.0686333702537736, 3.1194967499901574, 3.1698131374677376, 3.219602584004316, 3.2688839129119938, 3.317674823397779, 3.365991983363027, 3.413851112522984, 3.4612670570569914, 3.5082538568245716, 3.5548248060359193, 3.6009925081422063, 3.6467689256072524, 3.6921654251342484, 3.7371928188465526, 3.781861401857934, 3.8261809866131933, 3.8701609343333754, 3.913810183859557, 3.957137278154479, 4.000150388691197, 4.04285733793186, 4.08526562007695, 4.1273824202455005, 4.169214632229462, 4.210768874950129, 4.252051507731199, 4.293068644491204, 4.333826166947686, 4.374329736916238, 4.414584807779414, 4.454596635193221, 4.494370287092473, 4.533910653050536, 4.573222453043856, 4.6123102456670555, 4.651178435840281, 4.689831282046791, 4.728272903135427, 4.766507284719657, 4.804538285202152, 4.842369641451449, 4.880004974155028, 4.9174477928711555, 4.954701500800043, 4.99176939929321, 5.028654692118473, 5.065360489496611, 5.101889811924533, 5.138245593798639, 5.17443068685104, 5.210447863410357, 5.246299819497973, 5.281989177769817, 5.317518490313001, 5.352890241306049, 5.388106849550756, 5.423170670883205, 5.458084000470972, 5.492849075002994, 5.5274680747782385, 5.561943125698819, 5.596276301172888, 5.630469623932262, 5.6645250677694134, 5.698444559198189], [0.0, 0.36919189698347965, 0.5595902744792605, 0.71371514638276, 0.848180249486316, 0.9696927825876808, 1.0817898711417433, 1.1866181438433936, 1.2856008555333318, 1.3797413061829964, 1.4697794149937136, 1.5562801267318054, 1.6396868291726892, 1.7203553879509732, 1.7985767787452502, 1.8745926763984242, 1.9486065146518121, 2.0207915323133547, 2.0912967552802635, 2.1602515287392627, 2.2277690084219333, 2.2939488898683043, 2.358879570218299, 2.422639880839824, 2.48530049086595, 2.5469250551962013, 2.607571161802713, 2.6672911197636666, 2.726132619685083, 2.784139290976425, 2.8413511750761575, 2.8978051296715908, 2.9535351758678385, 3.0085727978820542, 3.0629472029912845, 3.116685548014662, 3.169813137467737, 3.2223535976176136, 3.2743290299395142, 3.325760146888439, 3.3766663924235667, 3.427066049334703, 3.4769763351015257, 3.5264134877537665, 3.575392842982804, 3.6239289035740123, 3.672035402077698, 3.71972535750926, 3.7670111267619455, 3.813904451324801, 3.860416499821292, 3.9065579068183216, 3.9523388082991384, 3.9977688741453714, 4.042857337931861, 4.087613024302105, 4.132044374161071, 4.176159467895134, 4.219966046805482, 4.263471532920733, 4.306683047336719, 4.349607427215505, 4.392251241562043, 4.434620805884556, 4.476722195834085, 4.518561259909061, 4.5601436313023695, 4.601474738960854, 4.642559817920577, 4.683403918975173, 4.724011917729363, 4.764388523084921, 4.804538285202152, 4.844465602976117, 4.884174731063399, 4.923669786492136, 4.962954754885243, 5.0020334963242465, 5.040909750878862, 5.079587143825413, 5.1180691905753015, 5.156359301333056, 5.194460785501951, 5.23237685585376, 5.270110632477992, 5.30766514652472, 5.345043343754097, 5.382248087904674, 5.419282163891747, 5.456148280846125, 5.492849075002994, 5.529387112449849, 5.565764891741838, 5.601984846392279, 5.638049347245599, 5.673960704739418, 5.709721171062082, 5.745332942211493, 5.780798159960752, 5.816118913735705, 5.851297242409219, 5.886335136016648], [0.0, 0.38073078774317565, 0.5770799623628854, 0.7360219228178334, 0.8746896591546225, 1.0, 1.1156006217298275, 1.2237052447444592, 1.325781606935995, 1.422864365867587, 1.5157165665103982, 1.6049208106703472, 1.6909343439651998, 1.7741241544152841, 1.8547903119848381, 1.9331820449317632, 2.0095091452076645, 2.0839502661046487, 2.1566590912428145, 2.2277690084219333, 2.29739670999407, 2.365645007428817, 2.432605060670343, 2.4983581649178315, 2.5629771980294453, 2.6265278044037674, 2.689069371893498, 2.7506558444684384, 2.811336403278409, 2.871156041346198, 2.930156051583522, 2.9883744436445445, 3.0458463019454065, 3.102604094725244, 3.158677942118569, 3.2140958497160392, 3.2688839129119938, 3.32306649639959, 3.376666392423567, 3.429704960795374, 3.482202253184497, 3.5341771237993345, 3.5856473282424717, 3.6366296120543766, 3.6871397902350713, 3.737192818846553, 3.7868028596424748, 3.835983338540439, 3.884746998641632, 3.933105948408916, 3.981071705534973, 4.028655236964276, 4.075866995474686, 4.122716953174691, 4.169214632229461, 4.215369133091901, 4.261189160482843, 4.306683047336718, 4.351858776904846, 4.396724003187294, 4.441286069845841, 4.485552027734319, 4.529528651168331, 4.573222453043856, 4.616639698903085, 4.659786420036067, 4.702668425698049, 4.745291314514639, 4.787660485140088, 4.82978114622782, 4.871658325766916, 4.913296879833298, 4.954701500800042, 4.995876725047269, 5.036826940208526, 5.077556391987409, 5.1180691905753015, 5.158369316698463, 5.198460627320444, 5.238346861023595, 5.278031643091579, 5.317518490313001, 5.356810815524722, 5.395911931911942, 5.434825057080862, 5.47355331691849, 5.5120997492531005, 5.550467307327829, 5.588658863098972, 5.626677210369742, 5.6645250677694134, 5.702205081587142, 5.739719828469049, 5.77707181798658, 5.814263495083608, 5.851297242409219, 5.888175382542669, 5.924900180116576, 5.961473843843986, 5.997898528454609, 6.034176336545165, 6.070309320348477], [0.0, 0.3920410799236362, 0.5942231595928824, 0.7578867765840317, 0.9006738871990841, 1.0297067968879101, 1.1487415428075818, 1.260057607900753, 1.3651663318509695, 1.4651331085834605, 1.560743650691363, 1.652597867214111, 1.7411665870721653, 1.8268277003244342, 1.9098901910526351, 1.9906106912879056, 2.0692052252287465, 2.145857753384326, 2.220726524822829, 2.2939488898683043, 2.365645007428817, 2.435920743173403, 2.504869965116179, 2.572576383476297, 2.6391150410796507, 2.704553532409639, 2.768953009541838, 2.832369018948605, 2.8948522027941883, 2.9564488906999653, 3.0172016022577943, 3.0771494762669143, 3.136328639389091, 3.194772524390845, 3.2525121461794066, 3.309576342301828, 3.365991983363027, 3.4217841578531516, 3.476976335101526, 3.53159050945118, 3.5856473282424717, 3.6391662057819394, 3.6921654251342484, 3.744662229296235, 3.796672903080916, 3.848212846846984, 3.8992966430484306, 3.949938116443867, 4.000150388691197, 4.04994592795693, 4.099336594087506, 4.1483336798201895, 4.196947948451389, 4.245189668328995, 4.293068644491204, 4.340594247736228, 4.38777544137427, 4.434620805884555, 4.481138561675227, 4.527336590122177, 4.573222453043856, 4.618803410752375, 4.6640864388065575, 4.709078243579659, 4.75378527674306, 4.79821374875712, 4.842369641451449, 4.88625871976889, 4.929886542740417, 4.973258473751867, 5.01637969015777, 5.0592551922925075, 5.101889811924533, 5.144288220195286, 5.186454935080853, 5.228394328411088, 5.2701106324779925, 5.311607946262452, 5.35289024130605, 5.3939613672524445, 5.434825057080863, 5.475484932052435, 5.5159445063884744, 5.5562071916983005, 5.596276301172887, 5.636155053559333, 5.675846576930062, 5.7153539122596015, 5.754680016820871, 5.793827767412028, 5.832799963424114, 5.87159932975906, 5.910228519606889, 5.9486901170903765, 5.986986639784847, 6.025120541120257, 6.063094212672256, 6.100909986348441, 6.138570136475647, 6.176076881793704, 6.213432387360744, 6.250638766374856], [0.0, 0.40313788079701995, 0.6110427645119373, 0.7793389127886404, 0.9261676410170553, 1.0588528529217847, 1.1812569010399445, 1.2957237895330211, 1.4038076368554062, 1.5066039931196404, 1.604920810670347, 1.6993749790918402, 1.790450654210978, 1.8785364223400722, 1.9639500134168328, 2.046955323493167, 2.1277744913755523, 2.2065966846120197, 2.2835846315421575, 2.358879570218299, 2.432605060670343, 2.504869965116179, 2.5757708085227637, 2.64539367054368, 2.71381571810696, 2.7811064589713204, 2.8473287761340216, 2.9125397883213866, 2.9767915711342123, 3.040131765563039, 3.102604094725244, 3.1642488052515767, 3.225103046376161, 3.2852011971866353, 3.344575150473358, 3.4032545600358954, 3.461267057056991, 3.518638440161505, 3.5753928429828044, 3.631552882418179, 3.6871397902350713, 3.7421735302658323, 3.796672903080916, 3.850655639743619, 3.9041384860118358, 3.957137278154479, 4.009667011384806, 4.061741901773976, 4.113375442391032, 4.164580454316422, 4.215369133091901, 4.2657530910979125, 4.315743396288114, 4.365350607658029, 4.414584807779414, 4.463455632692789, 4.511972299416642, 4.560143631302369, 4.607978081438405, 4.655483754284555, 4.702668425698049, 4.749539561495579, 4.79610433468055, 4.842369641451449, 4.888342116095499, 4.9340281448613785, 4.979433878895577, 5.024565246318791, 5.069427963511477, 5.114027545671174, 5.158369316698463, 5.2024584184631895, 5.246299819497973, 5.289898323161843, 5.3332585753131, 5.376385071527111, 5.419282163891746, 5.461954067410364, 5.504404866039822, 5.546638518388709, 5.588658863098972, 5.630469623932261, 5.6720744145806234, 5.713476743219658, 5.754680016820871, 5.79568754523864, 5.836502545086099, 5.8771281434131675, 5.917567381198964, 5.95782321666999, 5.997898528454608, 6.037796118583643, 6.077518715346189, 6.117068976009131, 6.156449489408265, 6.195662778418372, 6.234711302309125, 6.2735974589932315, 6.312323587172801, 6.3508919683895355, 6.38930482898397, 6.427564341968684], [0.0, 0.41403466282330303, 0.6275591975508273, 0.8004043761493861, 0.9512018721937607, 1.0874735538923443, 1.2131861728370446, 1.330747091418958, 1.4417524357797895, 1.5473273686568019, 1.6483016812765647, 1.7453089376954647, 1.8388463804304556, 1.9293130992482395, 2.017035412299242, 2.1022843487228142, 2.185288051718146, 2.2662408020157194, 2.345309726488057, 2.422639880839824, 2.4983581649178315, 2.572576383476297, 2.64539367054368, 2.71689843249915, 2.787169922086124, 2.8562795258520217, 2.9242918265160767, 2.99126548671884, 3.0572539896600928, 3.122306264062225, 3.186467214874692, 3.2497781765911906, 3.312277302586426, 3.3739999012118007, 3.434978727317037, 3.4952442362413354, 3.554824806035919, 3.6137469326602436, 3.672035402077698, 3.7297134425183494, 3.7868028596424743, 3.843324156903086, 3.89929664304843, 3.9547385284109104, 4.009667011384806, 4.06409835629201, 4.118047963665094, 4.171530433834391, 4.224559624585433, 4.277148703551363, 4.329310195918374, 4.381056027948547, 4.432397566761369, 4.4833456567611, 4.533910653050536, 4.584102452131541, 4.633930520157812, 4.683403918975173, 4.732531330158304, 4.781321077229861, 4.82978114622782, 4.877919204769252, 4.925742619743222, 4.9732584737518675, 5.02047358040662, 5.067394498575906, 5.114027545671174, 5.16037881004971, 5.206454162605237, 5.252259267610608, 5.297799592870977, 5.343080419240483, 5.388106849550755, 5.432883816995201, 5.477416093009268, 5.521708294683338, 5.565764891741837, 5.6095902131193025, 5.653188453161589, 5.696563677478135, 5.739719828469049, 5.782660730548932, 5.8253900950876165, 5.867911525086385, 5.910228519606888, 5.9523444779685795, 5.99426270372937, 6.0359864084630654, 6.077518715346188, 6.118862662565846, 6.160021206559477, 6.200997225096555, 6.241793520211594, 6.282412820997173, 6.322857786265096, 6.363131007083227, 6.4032350091950905, 6.443172255328764, 6.482945147401274, 6.522556028624196, 6.562007185515857, 6.601300849825179], [0.0, 0.4247435035179738, 0.6437907647998604, 0.8211065147023581, 0.9758043275735478, 1.1156006217298275, 1.2445647472039778, 1.3651663318509695, 1.479042784975766, 1.587348371199097, 1.6909343439651998, 1.7904506542109782, 1.886407405431895, 1.9792140096915958, 2.0692052252287465, 2.1566590912428145, 2.241809651765445, 2.3248562125203858, 2.405970223049769, 2.48530049086595, 2.5629771980294453, 2.6391150410796507, 2.71381571810696, 2.787169922086124, 2.8592589556010206, 2.930156051583522, 2.999927463159023, 3.0686333702537736, 3.1363286393890903, 3.203063464809169, 3.268883912911994, 3.3338323872913818, 3.3979480281437917, 3.461267057056991, 3.5238230760717677, 3.5856473282424717, 3.646768925607252, 3.7072150494329423, 3.7670111267619455, 3.8261809866131933, 3.8847469986416314, 3.942730196613871, 4.000150388691197, 4.057026256208964, 4.113375442391032, 4.169214632229462, 4.224559624585434, 4.279425397420973, 4.333826166947686, 4.38777544137427, 4.441286069845841, 4.494370287092472, 4.547039754239644, 4.599305596177786, 4.651178435840282, 4.702668425698049, 4.753785276743061, 4.804538285202152, 4.854936357195453, 4.904988031530201, 4.954701500800043, 5.004084630941895, 5.053144979386457, 5.101889811924533, 5.150326118398885, 5.1984606273204435, 5.246299819497973, 5.293849940761683, 5.3411170138536095, 5.388106849550755, 5.434825057080862, 5.481277053885249, 5.527468074778238, 5.573403180548309, 5.619087266042176, 5.6645250677694134, 5.709721171062082, 5.754680016820871, 5.799405907876717, 5.843903014994414, 5.888175382542669, 5.932226933853038, 5.976061476288445, 6.019682706040358, 6.063094212672255, 6.1062994834256275, 6.1493019073035855, 6.192104778946008, 6.234711302309125, 6.277124594161537, 6.319347687407752, 6.3613835342495975, 6.4032350091950905, 6.444904911923694, 6.486395970016314, 6.52771084155775, 6.568852117618866, 6.6098223246252195, 6.650623926618455, 6.69125932741638, 6.731730872677199, 6.772040851873127], [0.0, 0.435275281648062, 0.6597539553864471, 0.8414663590846496, 1.0, 1.143262629818316, 1.275424500625791, 1.3990164762290163, 1.5157165665103982, 1.626707656796548, 1.732862107887866, 1.8348459866571245, 1.933182044931763, 2.0282898464010137, 2.120512449841321, 2.2101347886062372, 2.2973967099940706, 2.38250246163738, 2.465627744275839, 2.5469250551962013, 2.6265278044037674, 2.704553532409639, 2.7811064589713204, 2.8562795258520217, 2.930156051583522, 3.0028110849535783, 3.0743125218748473, 3.144722034472107, 3.2140958497160392, 3.2824854064481994, 3.34993791331143, 3.4164968253229087, 3.4822022531844974, 3.5470913166206572, 3.611198450855581, 3.6745556736344933, 3.7371928188465526, 3.799137741734932, 3.8604164998212926, 3.921053512979843, 3.981071705534973, 4.040492632798559, 4.099336594087506, 4.157622733952448, 4.215369133091901, 4.2725928902126356, 4.329310195918374, 4.385536399558985, 4.441286069845842, 4.496573049932039, 4.551410507565201, 4.605810980843109, 4.659786420036068, 4.713348225883052, 4.766507284719657, 4.819274000753602, 4.871658325766916, 4.923669786492135, 4.975317509882154, 5.026610246469218, 5.077556391987409, 5.128164007414417, 5.178440837572115, 5.228394328411088, 5.278031643091579, 5.327359676962109, 5.376385071527111, 5.42511422748602, 5.4735533169184905, 5.521708294683337, 5.569584909092578, 5.6171887119163415, 5.6645250677694134, 5.711599162925657, 5.75841601360254, 5.804980473754324, 5.851297242409219, 5.897370870582794, 5.943205767797343, 5.988806208234355, 6.034176336545165, 6.0793201733427615, 6.12424162039599, 6.168944465545676, 6.213432387360744, 6.257708959550999, 6.301777655151979, 6.3456418504962, 6.3893048289839705, 6.432769784666097, 6.476039825649833, 6.51911797733868, 6.562007185515858, 6.604710319280616, 6.6472301738459185, 6.689569473205422, 6.7317308726772, 6.77371696133109, 6.8155302643061795, 6.8571732450244225, 6.898648307306075, 6.939957797392233], [0.0, 0.44563983912891586, 0.6754636868647266, 0.8615029355102994, 1.023811500257058, 1.1704854282221195, 1.3057942714503001, 1.4323291574123718, 1.5518080519234878, 1.6654420065845172, 1.7741241544152841, 1.8785364223400725, 1.9792140096915956, 2.0765864705999797, 2.171005032585812, 2.2627614136932674, 2.3521011723446588, 2.4392334196150998, 2.5243380399424726, 2.607571161802713, 2.689069371893498, 2.768953009541838, 2.8473287761340216, 2.9242918265160767, 2.999927463159023, 3.0743125218748473, 3.147516515279747, 3.2196025840043156, 3.290628293867762, 3.36064630854763, 3.4297049607953736, 3.497848740357323, 3.565118713031328, 3.6315528824181786, 3.6971865036964164, 3.762052357001815, 3.826180986613193, 3.8896009110488525, 3.9523388082991384, 4.014419679712101, 4.075866995474685, 4.136702824163082, 4.196947948451388, 4.256621968750707, 4.315743396288114, 4.374329736916238, 4.432397566761368, 4.4899626006644215, 4.547039754239644, 4.603643200266376, 4.659786420036067, 4.715482250197415, 4.7707429255745915, 4.82558011837527, 4.880004974155027, 4.9340281448613785, 4.9876598192432136, 5.040909750878861, 5.093787284047658, 5.146301377645151, 5.1984606273204435, 5.250273285995201, 5.301747282907122, 5.35289024130605, 5.4037094949178135, 5.454212103279533, 5.504404866039821, 5.554294336308372, 5.603886833131316, 5.653188453161589, 5.702205081587143, 5.750942402374081, 5.799405907876716, 5.847600907861874, 5.895532537990684, 5.943205767797343, 5.990625408200969, 6.037796118583643, 6.084722413464998, 6.131408668801198, 6.177859127933943, 6.224077907213051, 6.270069001314336, 6.315836288272794, 6.3613835342495975, 6.4067143980499415, 6.451832435407553, 6.496741103050488, 6.541443762561744, 6.585943684047269, 6.630244049623013, 6.6743479567318715, 6.718258421300585, 6.76197838074596, 6.805510696839175, 6.848858158436261, 6.892023484082398, 6.935009324497063, 6.977818264946692, 7.020452827511013, 7.0629154732488475, 7.105208604268809], [0.0, 0.45584611570090633, 0.6909335093472795, 0.8812335261248792, 1.0472593664748386, 1.1972924974178873, 1.335700254511853, 1.4651331085834605, 1.5873483711990972, 1.703584830096522, 1.8147560732949, 1.9215596455654402, 2.024543003655771, 2.124145539569273, 2.220726524822829, 2.314584358539769, 2.405970223049769, 2.495098018599106, 2.5821517494331006, 2.6672911197636666, 2.7506558444684384, 2.832369018948605, 2.9125397883213866, 2.99126548671884, 3.0686333702537736, 3.144722034472107, 3.2196025840043156, 3.2933396055607242, 3.365991983363027, 3.4376135872198446, 3.508253856824571, 3.5779583008509666, 3.6467689256072524, 3.7147246050725506, 3.781861401857934, 3.848212846846983, 3.9138101838595567, 3.978682584559974, 4.042857337931861, 4.10636001791721, 4.169214632229461, 4.231443754870871, 4.293068644491204, 4.354109350400427, 4.414584807779414, 4.474512923408984, 4.533910653050536, 4.592794071454487, 4.651178435840282, 4.709078243579659, 4.766507284719656, 4.823478689900609, 4.880004974155027, 4.936098077013589, 4.991769399293211, 5.047029836897877, 5.101889811924533, 5.156359301333056, 5.210447863410356, 5.264164662233286, 5.317518490313001, 5.370517789583891, 5.423170670883205, 5.475484932052435, 5.527468074778238, 5.579127320278939, 5.630469623932262, 5.681501688930642, 5.73222997904231, 5.782660730548932, 5.832799963424114, 5.882653491811122, 5.932226933853038, 5.981525720923742, 6.030555106303961, 6.079320173342762, 6.127825843141448, 6.176076881793704, 6.224077907213052, 6.271833395576091, 6.319347687407752, 6.366624993332646, 6.413669399514744, 6.460484872805826, 6.5070752656216575, 6.553444320563299, 6.5995956747997555, 6.6455328642268725, 6.691259327416379, 6.7367784093679, 6.782093365075868, 6.827207362922437, 6.872123487906675, 6.916844744719647, 6.9613740606743075, 7.00571428849853, 7.049868208999036, 7.093838533603465, 7.137627906787378, 7.18123890839249, 7.224674055842078, 7.267935806259105], [0.0, 0.4659022617970135, 0.706175776580398, 0.9006738871990841, 1.070362323431255, 1.2237052447444592, 1.3651663318509695, 1.4974545260150967, 1.622365905793314, 1.7411665870721653, 1.8547903119848381, 1.9639500134168328, 2.069205225228746, 2.171005032585812, 2.269716632677058, 2.3656450074288173, 2.459046880352574, 2.55014087041887, 2.639115041079651, 2.726132619685083, 2.811336403278409, 2.8948522027941883, 2.9767915711342123, 3.0572539896600928, 3.1363286393890903, 3.2140958497160392, 3.290628293867762, 3.365991983363027, 3.440247101432813, 3.513448706275082, 3.585647328242472, 3.6568894799481346, 3.7272180943761093, 3.7966729030809154, 3.865290764229128, 3.933105948408916, 4.000150388691196, 4.0664539002787725, 4.1320443741610715, 4.196947948451389, 4.261189160482842, 4.324791082249133, 4.38777544137427, 4.4501627294639485, 4.511972299416642, 4.573222453043856, 4.633930520157812, 4.694112930124295, 4.753785276743061, 4.812962377203621, 4.871658325766916, 4.929886542740417, 4.987659819243214, 5.044990358196766, 5.101889811924533, 5.158369316698463, 5.214439524531093, 5.270110632477992, 5.3253924096856675, 5.380294222394145, 5.434825057080863, 5.488993541912629, 5.542807966654982, 5.596276301172888, 5.649406212643185, 5.702205081587143, 5.754680016820871, 5.806837869411893, 5.858685245721727, 5.910228519606888, 5.961473843843986, 6.012427160838593, 6.063094212672255, 6.113480550537116, 6.163591543603359, 6.213432387360745, 6.2630081114720255, 6.312323587172801, 6.361383534249598, 6.410192527625248, 6.45875500357838, 6.5070752656216575, 6.555157490061445, 6.6030057312598505, 6.650623926618455, 6.698015901301587, 6.745185372715637, 6.79213595475972, 6.838871161861818, 6.885394412813576, 6.931709034415894, 6.977818264946692, 7.023725257461343, 7.069433082935586, 7.114944733260062, 7.160263124094952, 7.205391097592676, 7.250331424996045, 7.295086809118796, 7.339659886714978, 7.384053230743224, 7.428269352531604], [0.0, 0.4758157337824938, 0.7212017903004272, 0.9198384332443488, 1.0931375013553157, 1.2497432545525011, 1.3942143517814285, 1.5293173751799052, 1.656886620278035, 1.778215143386139, 1.8942565548098476, 2.005738957226198, 2.113233790261667, 2.2171996947191612, 2.3180116810123805, 2.415981220475481, 2.5113704991848413, 2.6044027878871745, 2.695270151650034, 2.784139290976425, 2.871156041346198, 2.9564488906999653, 3.040131765563039, 3.122306264062225, 3.203063464809169, 3.2824854064481994, 3.36064630854763, 3.4376135872198446, 3.513448706275082, 3.588207895440073, 3.661942760252697, 3.734700803021853, 3.8065258702599523, 3.877458538929843, 3.947536451466457, 4.016794607667809, 4.0852656200769495, 4.152979938304801, 4.219966046805482, 4.286250639859269, 4.351858776904846, 4.4168140208619775, 4.481138561675227, 4.544853326970836, 4.607978081438405, 4.670531516315527, 4.732531330158304, 4.793994301916697, 4.854936357195453, 4.91537262846436, 4.975317509882154, 5.034784707313713, 5.093787284047658, 5.15233770265931, 5.210447863410356, 5.268129139530428, 5.3253924096856675, 5.3822480879046735, 5.438706151201929, 5.494776165112389, 5.550467307327828, 5.605788389605258, 5.66074787809991, 5.7153539122596015, 5.769614322403419, 5.823536646095422, 5.877128143413167, 5.930395811201242, 5.983346396391379, 6.035986408463065, 6.088322131111734, 6.140359633185514, 6.192104778946007, 6.243563237703666, 6.294740492873919, 6.345641850496199, 6.3962724472544625, 6.446637258034499, 6.496741103050488, 6.546588654570506, 6.5961844432683545, 6.645532864226872, 6.694638182615903, 6.743504539066304, 6.792135954759719, 6.8405363362523515, 6.888709480049595, 6.936659076947138, 6.98438871615299, 7.03190188920387, 7.079201993688374, 7.1262923367885245, 7.173176138650433, 7.219856535594083, 7.266336583171589, 7.312619259082571, 7.358707465954793, 7.40460403399759, 7.450311723535192, 7.49583322742652, 7.541171173377642, 7.5863281261526865], [0.0, 0.48559337483020376, 0.7360219228178333, 0.9387403933595695, 1.1156006217298275, 1.275424500625791, 1.4228643658675872, 1.560743650691363, 1.6909343439651998, 1.8147560732949, 1.933182044931763, 2.046955323493167, 2.156659091242814, 2.2627614136932674, 2.365645007428817, 2.465627744275839, 2.5629771980294453, 2.6579212274755055, 2.7506558444684384, 2.8413511750761575, 2.930156051583522, 3.0172016022577943, 3.102604094725244, 3.186467214874692, 3.268883912911994, 3.34993791331143, 3.4297049607953736, 3.508253856824571, 3.585647328242472, 3.661942760252697, 3.7371928188465526, 3.8114459824682188, 3.884746998641632, 3.957137278154478, 4.028655236964276, 4.099336594087506, 4.169214632229461, 4.238320426716744, 4.306683047336719, 4.374329736916238, 4.441286069845841, 4.50757609324486, 4.573222453043856, 4.638246506915417, 4.702668425698049, 4.766507284719657, 4.82978114622782, 4.892507133966793, 4.954701500800043, 5.016379690157769, 5.077556391987408, 5.138245593798639, 5.198460627320444, 5.258214211224312, 5.317518490313001, 5.376385071527111, 5.434825057080863, 5.492849075002993, 5.550467307327828, 5.607689516154582, 5.6645250677694134, 5.720982955004047, 5.77707181798658, 5.832799963424114, 5.888175382542668, 5.943205767797342, 5.997898528454608, 6.0522608051387365, 6.1062994834256275, 6.160021206559477, 6.213432387360745, 6.2665392193876395, 6.319347687407751, 6.371863577231426, 6.424092484953989, 6.476039825649833, 6.52771084155775, 6.579110609793539, 6.630244049623013, 6.681115929325697, 6.731730872677199, 6.782093365075868, 6.832207759337454, 6.882078281179536, 6.931709034415894, 6.9811040058794065, 7.030267070090683, 7.0792019936883746, 7.127912439635907, 7.176401971218347, 7.224674055842078, 7.272732068649128, 7.320579295957087, 7.368218938534864, 7.415654114723777, 7.462887863412845, 7.509923146876559, 7.556762853482842, 7.603409800278429, 7.649866735458385, 7.69613634072608, 7.7422212335495395], [0.0, 0.4952414840026903, 0.750645721726072, 0.9573919447793618, 1.1377661560003618, 1.3007655276272498, 1.451134831345687, 1.591753598340259, 1.7245310114646024, 1.850812917609764, 1.9715918593702615, 2.087625665091567, 2.1995091041109305, 2.3077195417942455, 2.4126472988068692, 2.51461656267519, 2.6139002235378315, 2.710730667438561, 2.8053078007325642, 2.8978051296715908, 2.9883744436445445, 3.0771494762669143, 3.1642488052515767, 3.2497781765911906, 3.3338323872913818, 3.4164968253229087, 3.497848740357323, 3.5779583008509666, 3.6568894799481346, 3.734700803021853, 3.8114459824682188, 3.887174459935085, 3.961931872021524, 4.035760452293747, 4.108699379984416, 4.180785083800437, 4.252051507731198, 4.322530344529649, 4.392251241562043, 4.461241982934791, 4.52952865116833, 4.597135771166997, 4.6640864388065575, 4.7304024361087915, 4.79610433468055, 4.861211588851705, 4.925742619743222, 4.989714891325893, 5.053144979386457, 5.116048634195998, 5.178440837572114, 5.240335854938119, 5.301747282907123, 5.362688092854085, 5.423170670883205, 5.483206854549909, 5.542807966654982, 5.601984846392278, 5.66074787809991, 5.719107017837313, 5.77707181798658, 5.834651450055311, 5.8918547258397185, 5.9486901170903765, 6.005165773808578, 6.061289541288508, 6.117068976009131, 6.172511360469641, 6.227623717053381, 6.282412820997173, 6.336885212535886, 6.391047208285679, 6.444904911923694, 6.498464224216808, 6.551730852447489, 6.604710319280617, 6.657407971111453, 6.709828985931492, 6.761978380745961, 6.813861018573904, 6.865481615059338, 6.916844744719646, 6.967954846855372, 7.01881623114361, 7.069433082935585, 7.119809468277363, 7.16994933867124, 7.219856535594084, 7.26953479478764, 7.31898775033482, 7.368218938534864, 7.417231801589483, 7.46602969111113, 7.514615871463828, 7.562993522946288, 7.611165744826298, 7.6591355582348974, 7.706905908928125, 7.754479669923771, 7.801859644019964, 7.849048566202036, 7.896049105943698], [0.0, 0.5047658755841546, 0.7650819998320296, 0.975804327573548, 1.1596474618843131, 1.325781606935995, 1.479042784975766, 1.622365905793314, 1.757696869289789, 1.8864074054318951, 2.0095091452076645, 2.1277744913755523, 2.2418096517654447, 2.3521011723446588, 2.4590468803525742, 2.5629771980294453, 2.664170263685995, 2.7628629325709158, 2.859258955601021, 2.9535351758678385, 3.0458463019454065, 3.136328639389091, 3.225103046376161, 3.312277302586426, 3.3979480281437917, 3.4822022531844974, 3.565118713031328, 3.6467689256072524, 3.7272180943761093, 3.8065258702599523, 3.884746998641632, 3.961931872021524, 4.038127004673239, 4.113375442391032, 4.187717117895238, 4.261189160482842, 4.333826166947686, 4.405660439551815, 4.4767221958340855, 4.547039754239645, 4.616639698903085, 4.685547026387114, 4.753785276743061, 4.821376650900475, 4.8883421160955, 4.954701500800044, 5.0204735804066205, 5.085676154749846, 5.150326118398886, 5.214439524531093, 5.278031643091579, 5.3411170138536095, 5.403709494917815, 5.4658223071222105, 5.5274680747782385, 5.588658863098972, 5.6494062126431865, 5.709721171062082, 5.76961432240342, 5.82909581419971, 5.888175382542669, 5.946862375324615, 6.005165773808579, 6.063094212672256, 6.120655998656239, 6.177859127933944, 6.234711302309125, 6.291219944336638, 6.34739221145299, 6.4032350091950905, 6.45875500357838, 6.5139586326989996, 6.568852117618866, 6.623441472587305, 6.677732514648169, 6.7317308726772, 6.78544199589053, 6.838871161861818, 6.892023484082399, 6.944903919095987, 6.997517273236983, 7.049868208999035, 7.101961251058483, 7.153800791975324, 7.205391097592676, 7.2567363121540405, 7.30784046315627, 7.358707465954794, 7.409341128136446, 7.459745153674138, 7.509923146876559, 7.5598786161451965, 7.609614977550089, 7.6591355582348974, 7.708443599661241, 7.757542260701449, 7.806434620588386, 7.855123681730319, 7.903612372398382, 7.95190354929359, 8.000000000000004, 8.04790444533015], [0.0, 0.5141719302988788, 0.7793389127886402, 0.9939879436616983, 1.1812569010399445, 1.350486871173961, 1.5066039931196404, 1.6525978672141108, 1.790450654210978, 1.9215596455654398, 2.0469553234931666, 2.167424484084174, 2.283584631542157, 2.395931378370446, 2.504869965116179, 2.6107369712695765, 2.7138157181069595, 2.8143474745538106, 2.912539788321386, 3.0085727978820542, 3.102604094725244, 3.194772524390845, 3.2852011971866353, 3.3739999012118007, 3.461267057056991, 3.5470913166206572, 3.6315528824181786, 3.7147246050725506, 3.7966729030809154, 3.877458538929843, 3.957137278154478, 4.035760452293747, 4.113375442391032, 4.190026096377014, 4.265753091097912, 4.340594247736227, 4.414584807779413, 4.487757675425699, 4.5601436313023695, 4.631771521554358, 4.702668425698048, 4.772859806094352, 4.842369641451448, 4.91122054640189, 4.979433878895576, 5.0470298368978765, 5.114027545671173, 5.180445136740922, 5.246299819497973, 5.311607946262451, 5.37638507152711, 5.440646006006478, 5.504404866039822, 5.567675118828734, 5.630469623932261, 5.692800671392574, 5.754680016820871, 5.816118913735704, 5.877128143413167, 5.93771804247986, 5.997898528454608, 6.057679123422936, 6.11706897600913, 6.176076881793704, 6.234711302309123, 6.292980382733421, 6.350891968389535, 6.4084536201478475, 6.465672628820045, 6.522556028624195, 6.579110609793539, 6.635342930394855, 6.691259327416378, 6.746865927179902, 6.802168655126927, 6.857173245024422, 6.9118852476318855, 6.966310038867871, 7.020452827511013, 7.074318662467695, 7.127912439635907, 7.181238908392488, 7.234302677728816, 7.287108222058002, 7.339659886714977, 7.391961893169107, 7.444018343967595, 7.49583322742652, 7.547410422085156, 7.598753700938064, 7.649866735458384, 7.70075309942488, 7.7514162725643105, 7.801859644019963, 7.852086515656441, 7.902100105210051, 7.951903549293589, 8.001499906263673, 8.05089215895827, 8.10008321731157, 8.149075920852834, 8.197873041095548], [0.0, 0.5234646397369045, 0.7934240264316235, 1.0119524426960578, 1.2026059411297956, 1.374894430891181, 1.533833081915079, 1.6824655260514865, 1.82280974795426, 1.9562882925448573, 2.0839502661046487, 2.2065966846120197, 2.3248562125203858, 2.4392334196150998, 2.55014087041887, 2.6579212274755055, 2.7628629325709153, 2.8652116151214764, 2.9651785738805807, 3.0629472029912845, 3.158677942118569, 3.2525121461794066, 3.344575150473358, 3.434978727317037, 3.5238230760717677, 3.611198450855581, 3.6971865036964164, 3.781861401857934, 3.865290764229128, 3.947536451466457, 4.028655236964276, 4.108699379984416, 4.187717117895238, 4.265753091097912, 4.342848711597636, 4.41904248412504, 4.494370287092472, 4.5688656193808646, 4.642559817920577, 4.715482250197415, 4.787660485140087, 4.8591204452947165, 4.929886542740417, 4.999981800827518, 5.069427963511477, 5.13824559379864, 5.206454162605237, 5.27407212915061, 5.3411170138536095, 5.407605464572395, 5.47355331691849, 5.538975649282774, 5.603886833131316, 5.66830057906054, 5.73222997904231, 5.79568754523864, 5.858685245721727, 5.921234537396714, 5.983346396391379, 6.0450313461477885, 6.1062994834256275, 6.167160502404559, 6.227623717053381, 6.287698081916503, 6.3473922114529895, 6.4067143980499415, 6.4656726288200455, 6.524274601282469, 6.582527738016876, 6.640439200371854, 6.698015901301587, 6.7552645173978165, 6.812191500178155, 6.868803086686363, 6.925105309455368, 6.9811040058794065, 7.036804827037716, 7.092213246008663, 7.147334565709953, 7.20217392629764, 7.2567363121540405, 7.311026558492224, 7.365049357602585, 7.418809264765002, 7.472310703848321, 7.525557972617182, 7.578555247764763, 7.6313065896886005, 7.6838159470254155, 7.736087160959684, 7.788123969319655, 7.839930010473553, 7.8915088270377804, 7.942863869408138, 7.993998499124347, 8.044915992077359, 8.095619541568464, 8.146112261228435, 8.196397187804537, 8.246477283822651, 8.296355440131295, 8.34603447833395], [0.0, 0.532648645060355, 0.8073443754472971, 1.0297067968879101, 1.223705244744459, 1.399016476229016, 1.560743650691363, 1.7119837994453588, 1.8547903119848381, 1.9906106912879051, 2.1205124498413204, 2.245310657170645, 2.365645007428817, 2.482028922902854, 2.5948822064167456, 2.7045535324096384, 2.811336403278409, 2.9154807579222464, 3.0172016022577943, 3.116685548014662, 3.2140958497160392, 3.309576342301828, 3.4032545600358954, 3.4952442362413354, 3.5856473282424717, 3.6745556736344933, 3.762052357001815, 3.848212846846983, 3.933105948408916, 4.016794607667809, 4.099336594087506, 4.180785083800437, 4.261189160482842, 4.340594247736227, 4.41904248412504, 4.496573049932039, 4.573222453043855, 4.6490247800676565, 4.724011917729363, 4.79821374875712, 4.871658325766915, 4.944372026106944, 5.016379690157769, 5.087704745206407, 5.158369316698463, 5.228394328411088, 5.297799592870977, 5.366603893158062, 5.434825057080862, 5.502480024578424, 5.569584909092577, 5.636155053559333, 5.702205081587143, 5.767748944320082, 5.832799963424114, 5.897370870582794, 5.961473843843986, 6.025120541120256, 6.088322131111734, 6.151089321890621, 6.213432387360744, 6.2753611917827845, 6.336885212535885, 6.398013561268833, 6.458755003578379, 6.51911797733868, 6.579110609793539, 6.638740733512426, 6.698015901301587, 6.7569434001529824, 6.815530264306179, 6.873783287491399, 6.931709034415893, 6.989313851550188, 7.046603877265908, 7.103585051372342, 7.160263124094951, 7.216643664535361, 7.272732068649129, 7.328533566774557, 7.384053230743224, 7.439295980600331, 7.494266590960878, 7.548969697025548, 7.6034098002784285, 7.657591273886949, 7.711518367822916, 7.7651952137221345, 7.818625829498783, 7.871814123729587, 7.924763899821693, 7.977478859977232, 8.029962608966581, 8.08221865772154, 8.134250426758873, 8.186061249443904, 8.237654375103283, 8.289032971995354, 8.34020013014606, 8.391158864057768, 8.44191211529793, 8.49246275497408], [0.0, 0.5417282708684605, 0.821106514702358, 1.0472593664748386, 1.2445647472039778, 1.422864365867587, 1.587348371199097, 1.7411665870721653, 1.886407405431895, 2.024543003655771, 2.156659091242814, 2.283584631542157, 2.4059702230497684, 2.524338039942472, 2.6391150410796507, 2.7506558444684384, 2.8592589556010206, 2.9651785738805807, 3.0686333702537736, 3.169813137467737, 3.2688839129119938, 3.365991983363027, 3.461267057056991, 3.554824806035919, 3.646768925607252, 3.7371928188465526, 3.826180986613193, 3.9138101838595567, 4.000150388691196, 4.0852656200769495, 4.169214632229461, 4.252051507731198, 4.333826166947686, 4.414584807779413, 4.494370287092472, 4.573222453043855, 4.651178435840281, 4.728272903135427, 4.804538285202152, 4.880004974155027, 4.954701500800042, 5.028654692118472, 5.101889811924532, 5.174430686851039, 5.246299819497973, 5.317518490313001, 5.388106849550755, 5.458084000470971, 5.527468074778238, 5.596276301172887, 5.664525067769413, 5.732229979042309, 5.799405907876716, 5.866067043230458, 5.932226933853038, 5.997898528454608, 6.063094212672255, 6.127825843141447, 6.192104778946007, 6.255941910689887, 6.319347687407751, 6.382332141508261, 6.444904911923693, 6.5070752656216575, 6.5688521176188654, 6.630244049623012, 6.691259327416379, 6.751905917083842, 6.812191500178155, 6.872123487906674, 6.931709034415894, 6.990955049243199, 7.049868208999035, 7.10845496833702, 7.166721570264582, 7.224674055842078, 7.2823182733143605, 7.339659886714977, 7.396704383979922, 7.4534570846048025, 7.509923146876558, 7.566107574708377, 7.622015224104215, 7.677650809277232, 7.733018908444633, 7.7881239693196544, 7.842970314319898, 7.897562145509784, 7.951903549293589, 8.005998500874346, 8.059850868492777, 8.11346441745942, 8.166842813992229, 8.219989628870984, 8.2729083409192, 8.325602340323353, 8.37807493179871, 8.430329337610324, 8.482368700457279, 8.5341960862277, 8.585814486631534, 8.637226821717737], [0.0, 0.5507075549439766, 0.8347165643310207, 1.064617957225968, 1.2651937248971707, 1.4464487051555701, 1.6136590747718582, 1.770026866752703, 1.917675088671641, 2.0581003196211727, 2.192406265011812, 2.3214356284713515, 2.4458497923315465, 2.5661795859392087, 2.682859045105565, 2.7962486657215457, 2.906651901083903, 3.014327164015675, 3.1194967499901574, 3.2223535976176136, 3.32306649639959, 3.4217841578531516, 3.518638440161505, 3.6137469326602436, 3.7072150494329423, 3.799137741734932, 3.8896009110488525, 3.978682584559974, 4.0664539002787725, 4.152979938304801, 4.238320426716744, 4.322530344529649, 4.405660439551815, 4.487757675425699, 4.5688656193808646, 4.6490247800676565, 4.728272903135427, 4.806645230863044, 4.884174731063399, 4.960892299608104, 5.036826940208525, 5.112005924509984, 5.186454935080853, 5.260198193486456, 5.333258575313099, 5.405657713737292, 5.477416093009268, 5.548553133030159, 5.619087266042176, 5.689036006315748, 5.758416013602539, 5.8272431510251845, 5.895532537990684, 5.963298598642449, 6.030555106303961, 6.097315224313539, 6.163591543603359, 6.229396117335641, 6.294740492873919, 6.3596357413366755, 6.424092484953988, 6.4881209224242475, 6.551730852447488, 6.614931695593666, 6.677732514648168, 6.7401420335626785, 6.802168655126927, 6.863820477465674, 6.925105309455368, 6.986030685146015, 7.046603877265908, 7.1068319098797765, 7.166721570264582, 7.2262794200614735, 7.285511805757314, 7.344424868544577, 7.403024553604261, 7.461316618852716, 7.51930664318987, 7.577000034283325, 7.6344020359199405, 7.691517734954042, 7.748352067879088, 7.80490982704752, 7.8611956665616605, 7.917214107856726, 7.9729695449954905, 8.028466249692663, 8.08370837608571, 8.13869996526767, 8.193444949596337, 8.247947156793234, 8.302210313844807, 8.356238050717424, 8.410033903896986, 8.463601319763173, 8.516943657807747, 8.570064193705626, 8.622966122246932, 8.675652560137669, 8.728126548676135, 8.780391056311842], [0.0, 0.5595902744792605, 0.848180249486316, 1.0817898711417433, 1.2856008555333318, 1.4697794149937136, 1.6396868291726892, 1.7985767787452502, 1.9486065146518121, 2.0912967552802635, 2.2277690084219333, 2.358879570218299, 2.48530049086595, 2.607571161802713, 2.726132619685083, 2.8413511750761575, 2.9535351758678385, 3.0629472029912845, 3.1698131374677376, 3.2743290299395142, 3.376666392423567, 3.476976335101526, 3.5753928429828044, 3.672035402077698, 3.7670111267619455, 3.8604164998212926, 3.9523388082991384, 4.042857337931861, 4.1320443741610715, 4.219966046805482, 4.306683047336719, 4.392251241562043, 4.4767221958340855, 4.5601436313023695, 4.642559817920577, 4.724011917729363, 4.804538285202152, 4.884174731063399, 4.962954754885244, 5.040909750878862, 5.1180691905753015, 5.194460785501951, 5.2701106324779925, 5.345043343754097, 5.419282163891747, 5.492849075002995, 5.565764891741838, 5.638049347245599, 5.709721171062083, 5.780798159960752, 5.851297242409219, 5.921234537396715, 5.99062540820097, 6.059484511621763, 6.127825843141449, 6.195662778418372, 6.2630081114720255, 6.329874089877905, 6.3962724472544625, 6.462214433293439, 6.5277108415577505, 6.592772035247212, 6.6574079711114535, 6.7216282216709144, 6.78544199589053, 6.848858158436261, 6.911885247631886, 6.974531492222077, 7.036804827037717, 7.098712907650392, 7.160263124094952, 7.2214626137318225, 7.282318273314361, 7.342836770320686, 7.403024553604263, 7.4628878634128455, 7.522432740821116, 7.581665036618589, 7.640590419690896, 7.699214384929415, 7.75754226070145, 7.815579215910497, 7.873330266673923, 7.930800282643133, 7.987993992989486, 8.044915992077359, 8.101570744844217, 8.15796259190603, 8.21409575440504, 8.2699743386157, 8.325602340323353, 8.38098364898933, 8.436122051715058, 8.491021237016986, 8.545684798423292, 8.60011623790255, 8.65431896913395, 8.70829632062789, 8.762051538705338, 8.81558779034367, 8.868908165896261, 8.92201568169267], [0.0, 0.5683799692799553, 0.8615029355102994, 1.0987819513108767, 1.3057942714503001, 1.492865792779962, 1.6654420065845175, 1.8268277003244342, 1.9792140096915958, 2.124145539569273, 2.2627614136932674, 2.395931378370447, 2.5243380399424726, 2.6485292622712526, 2.768953009541838, 2.8859813460950443, 2.9999274631590236, 3.1110580661223293, 3.219602584004316, 3.325760146888439, 3.429704960795374, 3.53159050945118, 3.631552882418179, 3.7297134425183494, 3.8261809866131933, 3.921053512979843, 4.014419679712101, 4.10636001791721, 4.196947948451389, 4.286250639859269, 4.374329736916238, 4.461241982934791, 4.547039754239645, 4.631771521554358, 4.715482250197415, 4.79821374875712, 4.880004974155027, 4.960892299608104, 5.040909750878862, 5.120089215299155, 5.1984606273204435, 5.276052133745499, 5.35289024130605, 5.428999948846642, 5.504404866039822, 5.57912732027894, 5.65318845316159, 5.726608307780897, 5.799405907876717, 5.871599329759061, 5.943205767797343, 6.014241594167819, 6.084722413464998, 6.1546631127085245, 6.224077907213052, 6.292980382733422, 6.361383534249599, 6.429299801714352, 6.496741103050488, 6.563718864652887, 6.6302440496230135, 6.696327183939359, 6.761978380745961, 6.827207362922438, 6.892023484082398, 6.956435748132444, 7.020452827511013, 7.084083080214765, 7.147334565709953, 7.2102150598171075, 7.272732068649129, 7.334892841675649, 7.396704383979923, 7.458173467768652, 7.51930664318987, 7.580110248509246, 7.640590419690895, 7.700753099424881, 7.760604045640153, 7.8201488395384136, 7.879392893181635, 7.938341456663223, 7.996999624890588, 8.055372344004578, 8.113464417459422, 8.17128051178491, 8.22882516205096, 8.28610277705322, 8.343117644237008, 8.39987393437557, 8.456375706017553, 8.512626909717516, 8.568631392062313, 8.624392899505311, 8.679915082019583, 8.735201496580443, 8.790255610487016, 8.845080804531872, 8.899680376027158, 8.954057541695157, 9.008215440430583, 9.06215713594162], [0.0, 0.5770799623628854, 0.8746896591546224, 1.1156006217298275, 1.3257816069359947, 1.5157165665103982, 1.6909343439651996, 1.854790311984838, 2.0095091452076645, 2.156659091242814, 2.29739670999407, 2.432605060670343, 2.562977198029445, 2.6890693718934977, 2.811336403278409, 2.930156051583522, 3.045846301945406, 3.158677942118569, 3.2688839129119938, 3.3766663924235667, 3.482202253184497, 3.5856473282424717, 3.6871397902350713, 3.7868028596424743, 3.8847469986416314, 3.981071705534973, 4.075866995474685, 4.169214632229461, 4.261189160482842, 4.351858776904846, 4.441286069845841, 4.52952865116833, 4.616639698903085, 4.702668425698048, 4.787660485140087, 4.871658325766915, 4.954701500800042, 5.036826940208525, 5.1180691905753015, 5.1984606273204435, 5.278031643091578, 5.356810815524721, 5.434825057080862, 5.5120997492531005, 5.5886588630989715, 5.6645250677694134, 5.739719828469049, 5.814263495083608, 5.888175382542668, 5.961473843843985, 6.034176336545164, 6.1062994834256275, 6.177859127933943, 6.248870384960152, 6.319347687407751, 6.38930482898397, 6.458755003578379, 6.527710841557749, 6.596184443268354, 6.664187410004897, 6.731730872677199, 6.798825518381215, 6.865481615059337, 6.931709034415894, 6.997517273236981, 7.0629154732488475, 7.127912439635906, 7.192516658327743, 7.2567363121540405, 7.320579295957086, 7.384053230743224, 7.447165476947178, 7.509923146876557, 7.57233311639786, 7.6344020359199405, 7.69613634072608, 7.757542260701448, 7.818625829498783, 7.879392893181634, 7.939849118381205, 8.000000000000002, 8.059850868492777, 8.119406896752897, 8.178673106630058, 8.237654375103283, 8.296355440131295, 8.354780906200736, 8.412935249591152, 8.470822823374279, 8.528447862163931, 8.585814486631536, 8.642926707801406, 8.699788431138758, 8.756403460442602, 8.812775501554874, 8.868908165896261, 8.924804973838624, 8.980469357923136, 9.035904665932751, 9.091114163826989, 9.14610103854653, 9.200868400694661], [0.0, 0.585693378298389, 0.8877451563823099, 1.1322519227618724, 1.3455700403680313, 1.538339942955893, 1.7161729967934216, 1.8824746563950183, 2.0395028015858903, 2.188849087422717, 2.331687336462908, 2.4689137883353474, 2.6012318422375857, 2.72920605049988, 2.853298022733899, 2.9738911567236848, 3.0913081838081036, 3.2058239334823435, 3.317674823397779, 3.427066049334703, 3.5341771237993345, 3.6391662057819394, 3.7421735302658323, 3.843324156903086, 3.942730196613871, 4.040492632798559, 4.136702824163082, 4.231443754870871, 4.324791082249133, 4.4168140208619775, 4.50757609324486, 4.597135771166997, 4.685547026387114, 4.772859806094352, 4.8591204452947165, 4.944372026106944, 5.028654692118472, 5.112005924509984, 5.194460785501951, 5.276052133745499, 5.356810815524721, 5.43676583502149, 5.515944506388474, 5.59437258995944, 5.672074414580623, 5.749072987759579, 5.8253900950876165, 5.9010463901900545, 5.976061476288444, 6.050453980314855, 6.12424162039599, 6.197441267420584, 6.270069001314336, 6.342140162570047, 6.413669399514744, 6.4846707117386275, 6.555157490061445, 6.625142553369078, 6.694638182615903, 6.763656152255946, 6.832207759337454, 6.900303850470501, 6.967954846855372, 7.0351707675400945, 7.101961251058482, 7.168335575584928, 7.234302677728816, 7.299871170079545, 7.365049357602585, 7.429845252977551, 7.494266590960878, 7.558320841848122, 7.6220152241042145, 7.68535671622389, 7.748352067879088, 7.81100781040524, 7.873330266673922, 7.935325560395342, 7.996999624890587, 8.058358211370217, 8.119406896752897, 8.180151091055007, 8.24059604437981, 8.30074685353244, 8.360608468285031, 8.420185697314428, 8.479483213833205, 8.53850556093324, 8.597257156659618, 8.655742298831411, 8.713965169624625, 8.771929839931566, 8.829640273509884, 8.887100330933572, 8.944313773357448, 9.00128426610577, 9.058015382094982, 9.114510605099893, 9.170773332872004, 9.226806880118097, 9.282614481346688, 9.3381992935895], [0.0, 0.5942231595928824, 0.900673887199084, 1.1487415428075818, 1.3651663318509695, 1.560743650691363, 1.7411665870721653, 1.909890191052635, 2.069205225228746, 2.220726524822829, 2.365645007428817, 2.504869965116179, 2.6391150410796507, 2.7689530095418378, 2.8948522027941883, 3.0172016022577943, 3.1363286393890903, 3.252512146179407, 3.365991983363027, 3.4769763351015257, 3.5856473282424717, 3.6921654251342484, 3.796672903080916, 3.89929664304843, 4.000150388691197, 4.099336594087506, 4.196947948451388, 4.293068644491204, 4.38777544137427, 4.481138561675227, 4.573222453043856, 4.6640864388065575, 4.753785276743061, 4.842369641451448, 4.929886542740417, 5.016379690157769, 5.101889811924532, 5.186454935080853, 5.2701106324779925, 5.35289024130605, 5.434825057080862, 5.515944506388474, 5.596276301172887, 5.675846576930063, 5.754680016820871, 5.832799963424114, 5.910228519606889, 5.986986639784847, 6.063094212672255, 6.138570136475647, 6.213432387360744, 6.287698081916503, 6.361383534249598, 6.43450430826504, 6.5070752656216575, 6.57911060979354, 6.650623926618455, 6.721628221670914, 6.792135954759719, 6.86215907181688, 6.931709034415894, 7.000796847132106, 7.069433082935585, 7.137627906787378, 7.205391097592675, 7.272732068649128, 7.339659886714977, 7.4061832898095945, 7.472310703848322, 7.538050258203922, 7.603409800278429, 7.668396909161504, 7.733018908444634, 7.797282878254286, 7.861195666561661, 7.924763899821694, 7.987993992989485, 8.050892158958272, 8.113464417459422, 8.175716603461607, 8.237654375103283, 8.299283221189937, 8.360608468285031, 8.42163528742133, 8.482368700457279, 8.542813586101182, 8.60297468562423, 8.662856608281896, 8.722463836461731, 8.781800730574366, 8.840871533703174, 8.899680376027156, 8.958231279030388, 9.016528159510564, 9.074574833398314, 9.132375019398069, 9.189932342460658, 9.247250337097059, 9.304332450542134, 9.3611820457766, 9.417802404414934, 9.474196729466486], [0.0, 0.6026720813625591, 0.9134800578945335, 1.165074846671754, 1.384576856927622, 1.5829349786366513, 1.7659232463249395, 1.9370458354471285, 2.098626079652094, 2.2523017745874614, 2.3992807708283554, 2.5404852891519827, 2.6766391196405332, 2.8083231804681246, 2.9360124628771875, 3.060101478994818, 3.1809223158394495, 3.298757769956206, 3.413851112522984, 3.5264134877537665, 3.6366296120543766, 3.744662229296235, 3.850655639743619, 3.9547385284109104, 4.057026256208964, 4.157622733952448, 4.256621968750707, 4.354109350400427, 4.4501627294639485, 4.544853326970836, 4.638246506915417, 4.7304024361087915, 4.821376650900475, 4.91122054640189, 4.999981800827518, 5.087704745206407, 5.174430686851039, 5.260198193486456, 5.345043343754097, 5.428999948846642, 5.5120997492531005, 5.59437258995944, 5.675846576930063, 5.756548217266707, 5.836502545086099, 5.915733234861915, 5.99426270372937, 6.0721122040430595, 6.149301907303586, 6.225850980420353, 6.301777655151979, 6.37709929145848, 6.451832435407554, 6.52599287219854, 6.5995956747997555, 6.672655248636428, 6.745185372715638, 6.817199237530776, 6.888709480049596, 6.95972821605653, 7.030267070090684, 7.100337203195211, 7.16994933867124, 7.2391137860096295, 7.3078404631562695, 7.376138917251149, 7.4440183439675955, 7.511487605565917, 7.578555247764763, 7.645229515523835, 7.711518367822917, 7.777429491514446, 7.842970314319899, 7.908148017034042, 7.972969544995491, 8.037441618876981, 8.101570744844217, 8.165363224128038, 8.22882516205096, 8.291962476545754, 8.354780906200737, 8.417286017863606, 8.479483213833207, 8.54137773866628, 8.60297468562423, 8.66427900278294, 8.725295498827046, 8.786028848548408, 8.846483598067103, 8.90666416979196, 8.966574867136352, 9.026219879003946, 9.085603284058017, 9.144729054786987, 9.203601061378032, 9.262223075409732, 9.320598773374035, 9.378731740037123, 9.436625471648135, 9.494283379004097, 9.551708790378907, 9.60890495432368], [0.0, 0.6110427645119373, 0.9261676410170553, 1.1812569010399445, 1.4038076368554062, 1.604920810670347, 1.790450654210978, 1.9639500134168326, 2.1277744913755523, 2.283584631542157, 2.432605060670343, 2.5757708085227637, 2.7138157181069595, 2.8473287761340216, 2.9767915711342123, 3.102604094725244, 3.225103046376161, 3.344575150473358, 3.4612670570569914, 3.575392842982804, 3.6871397902350713, 3.796672903080916, 3.9041384860118358, 4.009667011384806, 4.113375442391032, 4.215369133091901, 4.315743396288114, 4.414584807779414, 4.511972299416642, 4.607978081438405, 4.702668425698049, 4.79610433468055, 4.8883421160955, 4.979433878895576, 5.069427963511477, 5.158369316698463, 5.246299819497973, 5.333258575313099, 5.419282163891747, 5.504404866039822, 5.5886588630989715, 5.672074414580623, 5.754680016820871, 5.836502545086099, 5.917567381198964, 5.997898528454609, 6.077518715346188, 6.156449489408265, 6.234711302309125, 6.312323587172801, 6.38930482898397, 6.465672628820045, 6.5414437625617445, 6.616634234653508, 6.691259327416379, 6.765333646356612, 6.838871161861818, 6.9118852476318855, 6.98438871615299, 7.056393851489124, 7.127912439635907, 7.198955796655381, 7.26953479478764, 7.339659886714978, 7.409341128136445, 7.4785881987949585, 7.547410422085157, 7.615816783357792, 7.6838159470254155, 7.75141627256431, 7.818625829498783, 7.885452411446142, 7.951903549293589, 8.017986523571981, 8.08370837608571, 8.149075920852834, 8.214095754405038, 8.278774265492741, 8.343117644237008, 8.407131890766456, 8.470822823374279, 8.5341960862277, 8.59725715665962, 8.660011352069912, 8.722463836461731, 8.78461962663619, 8.846483598067103, 8.908060490475837, 8.969354913124821, 9.030371349846973, 9.091114163826989, 9.151587602149407, 9.211795800127211, 9.271742785423836, 9.33143248198059, 9.390868713760568, 9.45005520831956, 9.508995600213579, 9.567693434252158, 9.626152168605852, 9.68437517777589, 9.74236575543344], [0.0, 0.6193376876000052, 0.9387403933595695, 1.1972924974178876, 1.4228643658675872, 1.6267076567965482, 1.8147560732949002, 1.9906106912879056, 2.1566590912428145, 2.314584358539769, 2.465627744275839, 2.610736971269577, 2.7506558444684384, 2.8859813460950443, 3.0172016022577948, 3.1447220344721076, 3.268883912911994, 3.3899778542556365, 3.5082538568245716, 3.6239289035740123, 3.737192818846553, 3.848212846846984, 3.957137278154479, 4.06409835629201, 4.169214632229462, 4.2725928902126356, 4.374329736916238, 4.474512923408984, 4.573222453043856, 4.670531516315527, 4.766507284719657, 4.861211588851705, 4.954701500800044, 5.0470298368978765, 5.13824559379864, 5.228394328411088, 5.317518490313001, 5.405657713737292, 5.492849075002995, 5.57912732027894, 5.6645250677694134, 5.749072987759579, 5.832799963424114, 5.915733234861915, 5.997898528454609, 6.079320173342763, 6.1600212065594775, 6.240023468147718, 6.3193476874077525, 6.398013561268833, 6.476039825649834, 6.5534443205633, 6.6302440496230135, 6.706455234534206, 6.78209336507587, 6.857173245024423, 6.931709034415895, 7.00571428849853, 7.0792019936883746, 7.152184600805941, 7.224674055842079, 7.296681828474699, 7.368218938534865, 7.439295980600333, 7.509923146876559, 7.580110248509246, 7.649866735458385, 7.719201715051121, 7.788123969319657, 7.856641971220403, 7.924763899821694, 7.992497654539415, 8.059850868492777, 8.126830921046057, 8.193444949596337, 8.259699860662174, 8.325602340323355, 8.391158864057768, 8.456375706017553, 8.521258947783245, 8.585814486631538, 8.65004804334938, 8.713965169624627, 8.77757125504101, 8.840871533703176, 8.90387109051545, 8.966574867136352, 9.0289876676291, 9.09111416382699, 9.152958900431102, 9.214526299856491, 9.27582066684199, 9.336846192837573, 9.397606960182324, 9.458106946085165, 9.518350026419604, 9.578339979343104, 9.638080488750882, 9.69757514757336, 9.75682746092586, 9.815840849118564, 9.874618650534316], [0.0, 0.6275591975508273, 0.9512018721937607, 1.2131861728370448, 1.4417524357797895, 1.6483016812765647, 1.8388463804304558, 2.017035412299242, 2.185288051718146, 2.345309726488057, 2.4983581649178315, 2.6453936705436805, 2.787169922086124, 2.9242918265160767, 3.0572539896600928, 3.1864672148746926, 3.312277302586426, 3.4349787273170374, 3.5548248060359193, 3.672035402077698, 3.7868028596424748, 3.8992966430484306, 4.009667011384806, 4.118047963665094, 4.224559624585434, 4.329310195918374, 4.432397566761368, 4.533910653050536, 4.633930520157812, 4.732531330158304, 4.82978114622782, 4.925742619743222, 5.0204735804066205, 5.114027545671173, 5.206454162605237, 5.297799592870977, 5.388106849550755, 5.477416093009268, 5.565764891741838, 5.65318845316159, 5.739719828469049, 5.8253900950876165, 5.910228519606889, 5.99426270372937, 6.077518715346188, 6.1600212065594775, 6.241793520211594, 6.322857786265096, 6.4032350091950905, 6.482945147401274, 6.562007185515857, 6.640439200371854, 6.718258421300586, 6.7954812853452395, 6.872123487906676, 6.948200029276716, 7.023725257461343, 7.098712907650392, 7.173176138650433, 7.247127566562644, 7.320579295957087, 7.393542948767982, 7.46602969111113, 7.538050258203924, 7.609614977550088, 7.680733790535154, 7.7514162725643105, 7.8216716518615605, 7.8915088270377804, 7.960936383525169, 8.029962608966581, 8.098595507640125, 8.166842813992229, 8.234712005345873, 8.302210313844808, 8.369344737689415, 8.436122051715056, 8.502548817359521, 8.568631392062313, 8.634375938135006, 8.699788431138758, 8.76487466780214, 8.829640273509884, 8.894090709390731, 8.958231279030386, 9.022067134833664, 9.085603284058017, 9.148844594539067, 9.211795800127211, 9.274461505852978, 9.336846192837571, 9.398954222963857, 9.46078984332197, 9.52235719044274, 9.583660294331267, 9.644703082312041, 9.705489382696362, 9.766022928281973, 9.826307359694306, 9.886346228577965, 9.946143000646657, 10.005701058599195], [0.0, 0.6357095193437304, 0.9635554499576547, 1.2289422285875011, 1.4604769582521981, 1.6697087280804628, 1.862728095154284, 2.0432313277476624, 2.213669120629572, 2.375769050563783, 2.530805180398563, 2.6797502854542503, 2.8233678327297054, 2.962270585325571, 3.096959572680169, 3.2278509333910024, 3.3552949589107475, 3.4795899482005352, 3.6009925081422063, 3.71972535750926, 3.835983338540439, 3.949938116443867, 4.061741901773976, 4.171530433834391, 4.279425397420973, 4.385536399558985, 4.4899626006644215, 4.592794071454487, 4.694112930124295, 4.793994301916697, 4.892507133966793, 4.989714891325893, 5.085676154749846, 5.180445136740922, 5.27407212915061, 5.366603893158062, 5.458084000470971, 5.548553133030159, 5.638049347245599, 5.726608307780897, 5.814263495083608, 5.9010463901900545, 5.986986639784847, 6.0721122040430595, 6.156449489408265, 6.240023468147718, 6.322857786265096, 6.404974861132204, 6.486395970016314, 6.567141330523554, 6.6472301738459185, 6.726680811586317, 6.805510696839176, 6.883736480121074, 6.961374060674308, 7.038438633604522, 7.114944733260062, 7.190906273214283, 7.266336583171589, 7.341248443082696, 7.415654114723777, 7.48956537096701, 7.562993522946288, 7.635949445300871, 7.70844359966124, 7.780486056525034, 7.852086515656442, 7.9232543251295064, 7.993998499124347, 8.064327734575052, 8.134250426758873, 8.203774683908161, 8.2729083409192, 8.341658972225465, 8.410033903896986, 8.47804022502212, 8.54568479842329, 8.612974270753877, 8.679915082019583, 8.746513474563992, 8.812775501554874, 8.878707035004863, 8.94431377335745, 9.009601248666883, 9.074574833398314, 9.13923974687257, 9.203601061378032, 9.26766370797054, 9.33143248198059, 9.39491204824579, 9.458106946085165, 9.521021594030818, 9.583660294331269, 9.64602723723986, 9.708126505100719, 9.769962076243814, 9.831537828700013, 9.892857543746153, 9.95392490928969, 10.014743523101624, 10.075316895906052, 10.135648454334033], [0.0, 0.6437907647998604, 0.9758043275735478, 1.244564747203978, 1.4790427849757657, 1.6909343439651998, 1.8864074054318951, 2.0692052252287465, 2.241809651765445, 2.4059702230497684, 2.5629771980294453, 2.71381571810696, 2.8592589556010206, 2.9999274631590236, 3.136328639389091, 3.268883912911994, 3.3979480281437917, 3.523823076071768, 3.6467689256072524, 3.7670111267619455, 3.884746998641632, 4.000150388691197, 4.113375442391032, 4.224559624585433, 4.333826166947686, 4.441286069845842, 4.547039754239644, 4.651178435840282, 4.753785276743061, 4.854936357195453, 4.954701500800043, 5.053144979386457, 5.150326118398886, 5.246299819497973, 5.3411170138536095, 5.434825057080862, 5.527468074778238, 5.619087266042176, 5.709721171062083, 5.799405907876717, 5.888175382542668, 5.976061476288444, 6.063094212672255, 6.149301907303586, 6.234711302309125, 6.3193476874077525, 6.4032350091950905, 6.486395970016314, 6.568852117618866, 6.650623926618455, 6.731730872677199, 6.812191500178155, 6.892023484082398, 6.971243686570654, 7.049868208999036, 7.1279124396359075, 7.205391097592676, 7.282318273314361, 7.358707465954793, 7.434571617925553, 7.509923146876559, 7.584773975338702, 7.6591355582348974, 7.733018908444635, 7.8064346205883846, 7.879392893181634, 7.95190354929359, 8.023976055832573, 8.095619541568464, 8.166842813992229, 8.237654375103283, 8.30806243620718, 8.37807493179871, 8.447699532598815, 8.516943657807747, 8.585814486631536, 8.654318969133948, 8.722463836461731, 8.790255610487016, 8.857700612907097, 8.924804973838624, 8.991574639940232, 9.058015382094982, 9.124132802681514, 9.189932342460658, 9.25541928710211, 9.320598773374034, 9.38547579501667, 9.45005520831956, 9.514341737420501, 9.578339979343102, 9.642054408788582, 9.705489382696362, 9.768649144586982, 9.83153782870001, 9.894159463938614, 9.956517977631828, 10.018617199124716, 10.080460863206028, 10.142052613382232, 10.203396005006331, 10.264494508269289], [0.0, 0.6518049405663864, 0.9879515465497972, 1.260057607900753, 1.4974545260150967, 1.711983799445359, 1.909890191052635, 2.094963554298832, 2.269716632677058, 2.435920743173403, 2.5948822064167456, 2.747598427260346, 2.8948522027941883, 3.037271810563663, 3.175370965486246, 3.3095763423018285, 3.440247101432813, 3.5676890944210036, 3.6921654251342484, 3.813904451324801, 3.933105948408916, 4.04994592795693, 4.164580454316422, 4.277148703551363, 4.38777544137427, 4.496573049932039, 4.603643200266376, 4.709078243579659, 4.812962377203621, 4.91537262846436, 5.016379690157769, 5.116048634195998, 5.214439524531093, 5.311607946262451, 5.407605464572395, 5.502480024578424, 5.596276301172887, 5.689036006315748, 5.780798159960752, 5.871599329759061, 5.961473843843985, 6.050453980314855, 6.138570136475647, 6.225850980420353, 6.312323587172801, 6.398013561268833, 6.482945147401274, 6.567141330523554, 6.650623926618455, 6.733413665178238, 6.815530264306179, 6.896992499233544, 6.977818264946693, 7.058024633533802, 7.137627906787378, 7.216643664535362, 7.295086809118796, 7.3729716063864315, 7.450311723535191, 7.527120264089191, 7.603409800278429, 7.679192403050433, 7.754479669923771, 7.829282750870846, 7.90361237239838, 7.977478859977233, 8.050892158958272, 8.123861854097834, 8.196397187804537, 8.268507077208664, 8.34020013014606, 8.411484660140037, 8.482368700457279, 8.552860017307061, 8.622966122246932, 8.692694283852672, 8.762051538705338, 8.831044701743796, 8.899680376027158, 8.967964961947844, 9.035904665932751, 9.103505508667, 9.170773332872004, 9.237713810667154, 9.304332450542134, 9.370634603964863, 9.436625471648133, 9.502310109496348, 9.567693434252158, 9.632780228861405, 9.69757514757336, 9.762082720792188, 9.826307359694306, 9.890253360625373, 9.953924909289688, 10.017326084743885, 10.080460863206028, 10.143333121690468, 10.205946641478155, 10.268305111431449, 10.330412131161868, 10.39227121405876], [0.0, 0.659753955386447, 0.9999999999999999, 1.275424500625791, 1.5157165665103982, 1.732862107887866, 1.933182044931763, 2.1205124498413204, 2.29739670999407, 2.4656277442758388, 2.6265278044037674, 2.7811064589713204, 2.9301560515835217, 3.0743125218748473, 3.2140958497160392, 3.34993791331143, 3.4822022531844974, 3.611198450855581, 3.7371928188465526, 3.860416499821292, 3.981071705534973, 4.099336594087506, 4.215369133091901, 4.329310195918374, 4.441286069845841, 4.551410507565201, 4.659786420036067, 4.766507284719656, 4.871658325766916, 4.975317509882154, 5.077556391987408, 5.178440837572114, 5.278031643091579, 5.37638507152711, 5.47355331691849, 5.569584909092577, 5.664525067769413, 5.758416013602539, 5.851297242409219, 5.943205767797343, 6.034176336545164, 6.12424162039599, 6.213432387360744, 6.301777655151979, 6.38930482898397, 6.476039825649834, 6.562007185515857, 6.6472301738459185, 6.731730872677199, 6.815530264306179, 6.898648307306075, 6.981104005879406, 7.0629154732488475, 7.144099989703336, 7.224674055842078, 7.304653441495079, 7.384053230743224, 7.462887863412844, 7.541171173377642, 7.6189164239643095, 7.69613634072608, 7.772843141820383, 7.849048566202035, 7.924763899821694, 8.000000000000002, 8.074767318130952, 8.149075920852834, 8.22293550981182, 8.296355440131295, 8.369344737689413, 8.44191211529793, 8.514065987866802, 8.585814486631534, 8.65716547251334, 8.728126548676135, 8.798705072338809, 8.868908165896261, 8.93874272739819, 9.008215440430583, 9.077332783441133, 9.14610103854653, 9.21452629985649, 9.282614481346688, 9.350371324310215, 9.417802404414934, 9.484913138391995, 9.551708790378905, 9.61819447793879, 9.68437517777589, 9.750255731165929, 9.815840849118562, 9.881135117287995, 9.946143000646657, 10.01086884793581, 10.075316895906052, 10.139491273359695, 10.203396005006331, 10.267035015142007, 10.330412131161868, 10.393531086915383, 10.456395525912734, 10.51900900439042], [0.0, 0.6676396267317009, 1.0119524426960576, 1.2906689388826686, 1.533833081915079, 1.7535740429325655, 1.9562882925448573, 2.1458577533843255, 2.3248562125203858, 2.4950980185991054, 2.6579212274755055, 2.8143474745538106, 2.9651785738805803, 3.111058066122329, 3.2525121461794066, 3.389977854255636, 3.5238230760717677, 3.6543610934035247, 3.781861401857934, 3.9065579068183216, 4.028655236964276, 4.1483336798201895, 4.2657530910979125, 4.381056027948547, 4.494370287092472, 4.605810980843109, 4.715482250197415, 4.823478689900609, 4.929886542740417, 5.034784707313713, 5.138245593798639, 5.240335854938119, 5.3411170138536095, 5.440646006006478, 5.538975649282774, 5.636155053559333, 5.732229979042309, 5.8272431510251845, 5.921234537396715, 6.014241594167819, 6.1062994834256275, 6.197441267420584, 6.287698081916503, 6.37709929145848, 6.465672628820045, 6.5534443205633, 6.640439200371854, 6.726680811586317, 6.812191500178155, 6.896992499233544, 6.981104005879406, 7.064545251464898, 7.147334565709953, 7.229489435445171, 7.311026558492225, 7.391961893169109, 7.472310703848322, 7.552087602947389, 7.6313065896886, 7.7099810859277955, 7.788123969319655, 7.865747604058436, 7.942863869408138, 8.019484186214099, 8.095619541568462, 8.17128051178491, 8.24647728382265, 8.321219675286224, 8.395517153115591, 8.469378851070198, 8.542813586101182, 8.615829873697233, 8.68843594228198, 8.760639746733844, 8.832448981093126, 8.90387109051545, 8.974913282525733, 9.045582537622218, 9.11588561927607, 9.185829083368258, 9.25541928710211, 9.32466239742684, 9.393564399004578, 9.462131101750893, 9.530368147976498, 9.59828101915571, 9.66587504234534, 9.73315539627589, 9.800127117135379, 9.866795104064597, 9.933164124381273, 9.999238818549383, 10.06502370490868, 10.130523184178513, 10.19574154374899, 10.260682961771703, 10.325351511061353, 10.389751162818909, 10.453885790186238, 10.517759171641432, 10.58137499424352, 10.644736856734712], [0.0, 0.6754636868647266, 1.023811500257058, 1.3057942714503001, 1.5518080519234878, 1.7741241544152844, 1.9792140096915958, 2.171005032585812, 2.3521011723446588, 2.5243380399424726, 2.689069371893498, 2.847328776134022, 2.9999274631590236, 3.1475165152797473, 3.2906282938677625, 3.429704960795374, 3.5651187130313287, 3.697186503696417, 3.8261809866131933, 3.9523388082991384, 4.075866995474686, 4.196947948451389, 4.315743396288114, 4.432397566761369, 4.547039754239644, 4.659786420036068, 4.7707429255745915, 4.880004974155027, 4.987659819243214, 5.093787284047658, 5.198460627320444, 5.301747282907123, 5.403709494917815, 5.504404866039822, 5.603886833131316, 5.702205081587143, 5.799405907876716, 5.895532537990684, 5.99062540820097, 6.084722413464998, 6.177859127933943, 6.270069001314336, 6.361383534249598, 6.451832435407554, 6.5414437625617445, 6.6302440496230135, 6.718258421300586, 6.805510696839176, 6.892023484082398, 6.977818264946693, 7.0629154732488475, 7.147334565709953, 7.231094086855693, 7.314211728444605, 7.396704383979923, 7.478588198794959, 7.559878616145198, 7.640590419690895, 7.720737772711043, 7.80033425435204, 7.879392893181635, 7.957926198289912, 8.035946188153817, 8.113464417459424, 8.190492002056468, 8.267039642202311, 8.343117644237008, 8.418735940817477, 8.493904109826627, 8.568631392062313, 8.64292670780141, 8.716798672325504, 8.790255610487016, 8.863305570387487, 8.935956336233573, 9.008215440430584, 9.080090174968324, 9.151587602149409, 9.222714564706031, 9.293477695347445, 9.36388342577696, 9.43393799521419, 9.503647458455447, 9.573017693502617, 9.642054408788583, 9.71076315002499, 9.779149306696358, 9.847218118222663, 9.914974679810948, 9.98242394801497, 10.04957074602059, 10.116419768673325, 10.182975587263293, 10.24924265408181, 10.315225306762862, 10.380927772421739, 10.446354171602405, 10.511508522044286, 10.576394742278545, 10.64101665506321, 10.705377990665907, 10.769482390002459], [0.0, 0.6832277883902761, 1.035579677563402, 1.3208036931145197, 1.569645273224345, 1.7945167829483537, 2.0019640387617934, 2.1959595990758545, 2.3791373441708803, 2.5533539844085515, 2.719978816795764, 2.8800573300510153, 3.034410059109315, 3.183695570132284, 3.328452343706805, 3.469127624124467, 3.6060978865633544, 3.73968372735448, 3.8701609343333754, 3.9977688741453714, 4.122716953174691, 4.245189668328995, 4.365350607658029, 4.4833456567611, 4.599305596177786, 4.713348225883052, 4.82558011837527, 4.936098077013589, 5.044990358196766, 5.15233770265931, 5.258214211224312, 5.362688092854085, 5.4658223071222105, 5.567675118828734, 5.66830057906054, 5.767748944320082, 5.866067043230458, 5.963298598642449, 6.059484511621763, 6.1546631127085245, 6.248870384960152, 6.342140162570047, 6.43450430826504, 6.52599287219854, 6.616634234653508, 6.706455234534206, 6.7954812853452395, 6.883736480121074, 6.971243686570654, 7.058024633533802, 7.144099989703336, 7.229489435445171, 7.314211728444605, 7.398284763817685, 7.481725629249617, 7.56455065565587, 7.646775463804067, 7.7284150072849, 7.809483612176842, 7.889995013711469, 7.969962390213096, 8.049398394557254, 8.128315183366988, 8.20672444414344, 8.28463742050722, 8.36206493570955, 8.439017414556462, 8.515504903875575, 8.591537091642545, 8.667123324873359, 8.742272626378808, 8.816993710468633, 8.891294997685073, 8.965184628638383, 9.038670477010603, 9.111760161788094, 9.184461058778274, 9.256780311461224, 9.328724841222764, 9.400301357011669, 9.471516364460314, 9.542376174504872, 9.61288691153837, 9.683054521127255, 9.752884777319851, 9.822383289572858, 9.891555509320101, 9.960406736205947, 10.028942124004171, 10.097166686241527, 10.165085301543872, 10.232702718721512, 10.300023561609155, 10.367052333674874, 10.433793422411489, 10.500251103522764, 10.566429544916161, 10.632332810512919, 10.697964863885666, 10.76332957173303, 10.828430707200111, 10.893271953053155], [0.0, 0.6909335093472795, 1.0472593664748386, 1.3357002545118533, 1.5873483711990972, 1.8147560732949, 2.0245430036557712, 2.220726524822829, 2.405970223049769, 2.5821517494331, 2.7506558444684384, 2.9125397883213866, 3.0686333702537736, 3.219602584004316, 3.3659919833630276, 3.508253856824571, 3.6467689256072524, 3.7818614018579346, 3.913810183859557, 4.042857337931861, 4.169214632229461, 4.293068644491204, 4.414584807779414, 4.533910653050536, 4.651178435840282, 4.766507284719657, 4.880004974155027, 4.991769399293211, 5.101889811924533, 5.210447863410356, 5.317518490313001, 5.423170670883205, 5.5274680747782385, 5.630469623932261, 5.73222997904231, 5.832799963424114, 5.932226933853038, 6.030555106303961, 6.127825843141449, 6.224077907213052, 6.319347687407751, 6.413669399514744, 6.5070752656216575, 6.5995956747997555, 6.691259327416379, 6.78209336507587, 6.872123487906676, 6.961374060674308, 7.049868208999036, 7.137627906787378, 7.224674055842078, 7.311026558492225, 7.396704383979923, 7.481725629249617, 7.5661075747083775, 7.649866735458385, 7.733018908444635, 7.815579215910496, 7.897562145509785, 7.978981587385606, 8.059850868492777, 8.140182784411108, 8.219989628870984, 8.299283221189938, 8.37807493179871, 8.456375706017553, 8.5341960862277, 8.611546232568982, 8.68843594228198, 8.76487466780214, 8.840871533703174, 8.91643535257836, 8.991574639940234, 9.066297628212167, 9.14061227987879, 9.214526299856491, 9.288047147140041, 9.3611820457766, 9.433937995214192, 9.506321780067845, 9.578339979343102, 9.649998975153446, 9.721304960965295, 9.792263949401613, 9.862881779632795, 9.933164124381275, 10.00311649656436, 10.072744255597968, 10.14205261338223, 10.211046639988496, 10.279731269065747, 10.348111302983305, 10.416191417725368, 10.483976167551955, 10.551469989439811, 10.61867720731583, 10.68560203609483, 10.752248585532604, 10.818620863904565, 10.884722781519544, 10.950558154077708, 11.016130705881034], [0.0, 0.6985823578873713, 1.0588528529217847, 1.3504868711739613, 1.604920810670347, 1.8348459866571243, 2.046955323493167, 2.245310657170645, 2.432605060670343, 2.6107369712695765, 2.7811064589713204, 2.944782508360985, 3.102604094725244, 3.2552445845603484, 3.403254560035896, 3.547091316620658, 3.6871397902350718, 3.823727782155161, 3.957137278154479, 4.087613024302105, 4.215369133091901, 4.340594247736228, 4.463455632692789, 4.584102452131541, 4.702668425698049, 4.819274000753602, 4.9340281448613785, 5.047029836897877, 5.158369316698463, 5.268129139530428, 5.376385071527111, 5.483206854549909, 5.588658863098972, 5.692800671392574, 5.79568754523864, 5.897370870582794, 5.997898528454608, 6.097315224313539, 6.195662778418372, 6.292980382733422, 6.38930482898397, 6.4846707117386275, 6.57911060979354, 6.672655248636428, 6.765333646356612, 6.857173245024423, 6.948200029276716, 7.038438633604522, 7.1279124396359075, 7.216643664535362, 7.304653441495079, 7.391961893169109, 7.478588198794959, 7.56455065565587, 7.649866735458385, 7.734553136131996, 7.818625829498784, 7.902100105210051, 7.984990611302439, 8.06731139168725, 8.149075920852834, 8.23029713603004, 8.310987467044669, 8.391158864057768, 8.470822823374279, 8.549990411482547, 8.628672287471243, 8.706878723956097, 8.784619626636191, 8.86190455258836, 8.938742727398191, 9.015143061217097, 9.091114163826989, 9.16666435878672, 9.241801696728096, 9.316533967863325, 9.390868713760568, 9.464813238439428, 9.538374618833993, 9.611559714667088, 9.684375177775891, 9.756827460925859, 9.828922826147013, 9.900667352623918, 9.972066944168397, 10.043127336301682, 10.113854102970793, 10.184252662922042, 10.254328285752916, 10.324086097662025, 10.393531086915383, 10.462668109046026, 10.531501891802753, 10.600037039862652, 10.668278039321184, 10.736229261972452, 10.803894969391694, 10.871279316830972, 10.938386356938558, 11.00522004331161, 11.071784233891284, 11.138082694208737], [0.0, 0.706175776580398, 1.070362323431255, 1.3651663318509695, 1.622365905793314, 1.8547903119848381, 2.0692052252287465, 2.269716632677058, 2.4590468803525742, 2.6391150410796507, 2.811336403278409, 2.9767915711342123, 3.1363286393890903, 3.290628293867762, 3.440247101432813, 3.585647328242472, 3.7272180943761093, 3.8652907642291283, 4.000150388691197, 4.132044374161071, 4.261189160482843, 4.38777544137427, 4.511972299416642, 4.633930520157812, 4.753785276743061, 4.871658325766916, 4.9876598192432136, 5.101889811924533, 5.214439524531093, 5.3253924096856675, 5.434825057080863, 5.542807966654982, 5.6494062126431865, 5.754680016820871, 5.858685245721727, 5.961473843843986, 6.063094212672255, 6.163591543603359, 6.2630081114720255, 6.361383534249599, 6.458755003578379, 6.555157490061445, 6.650623926618455, 6.745185372715638, 6.838871161861818, 6.931709034415895, 7.023725257461343, 7.114944733260062, 7.205391097592676, 7.295086809118796, 7.384053230743224, 7.472310703848322, 7.559878616145198, 7.646775463804067, 7.733018908444635, 7.818625829498784, 7.903612372398382, 7.987993992989485, 8.071785498529296, 8.155001085582986, 8.237654375103284, 8.31975844494556, 8.401325860044771, 8.48236870045728, 8.562898587450041, 8.64292670780141, 8.722463836461733, 8.80152035770755, 8.880106284910465, 8.958231279030388, 9.035904665932753, 9.113135452620133, 9.189932342460658, 9.266303749488216, 9.342257811843009, 9.417802404414935, 9.49294515074715, 9.56769343425216, 9.642054408788583, 9.716035008642752, 9.789641957955677, 9.862881779632795, 9.935760803770854, 10.008285175633661, 10.080460863206028, 10.152293664352891, 10.223789213608706, 10.294952988620228, 10.365790316264173, 10.436306378459673, 10.506506217693966, 10.576394742278545, 10.64597673135167, 10.715256839642144, 10.784239602008181, 10.852929437764217, 10.921330654807761, 10.989447453557448, 11.057283930712838, 11.124844082845724, 11.192131809832134, 11.25915091813362], [0.0, 0.7137151463827599, 1.081789871141743, 1.3797413061829964, 1.639686829172689, 1.874592676398424, 2.091296755280263, 2.2939488898683043, 2.4853004908659497, 2.667291119763666, 2.841351175076157, 3.0085727978820542, 3.1698131374677367, 3.325760146888438, 3.4769763351015257, 3.623928903574012, 3.767011126761945, 3.9065579068183216, 4.04285733793186, 4.176159467895134, 4.306683047336718, 4.434620805884555, 4.560143631302369, 4.683403918975173, 4.804538285202152, 4.923669786492135, 5.040909750878861, 5.156359301333056, 5.270110632477992, 5.3822480879046735, 5.492849075002993, 5.601984846392278, 5.709721171062082, 5.816118913735704, 5.921234537396714, 6.025120541120256, 6.127825843141447, 6.229396117335641, 6.329874089877905, 6.429299801714352, 6.527710841557749, 6.625142553369078, 6.721628221670914, 6.817199237530776, 6.9118852476318855, 7.00571428849853, 7.098712907650392, 7.190906273214283, 7.282318273314361, 7.3729716063864315, 7.462887863412844, 7.552087602947389, 7.640590419690895, 7.7284150072849, 7.815579215910496, 7.902100105210051, 7.987993992989485, 8.073276500106658, 8.157962591906028, 8.242066616520061, 8.325602340323353, 8.408582980794854, 8.491021237016984, 8.572929318016849, 8.654318969133946, 8.73520149658044, 8.815587790343669, 8.895488345566193, 8.974913282525733, 9.053872365325857, 9.132375019398067, 9.210430347906726, 9.28804714714004, 9.365233920962954, 9.441998894401184, 9.518350026419602, 9.594295021952869, 9.66984134324128, 9.744996220520461, 9.819766662109505, 9.894159463938614, 9.968181218553955, 10.041838323634511, 10.115136990052997, 10.18808324951043, 10.260682961771703, 10.33294182152745, 10.404865364905628, 10.476458975654475, 10.547727891017033, 10.618677207315828, 10.689311885265134, 10.759636755026898, 10.829656521025372, 10.899375766534437, 10.968798958050614, 11.037930449463975, 11.106774486038235, 11.175335208210697, 11.243616655221894, 11.311622768584236, 11.379357395398348], [0.0, 0.7212017903004272, 1.0931375013553157, 1.3942143517814285, 1.656886620278035, 1.8942565548098476, 2.1132337902616674, 2.3180116810123805, 2.5113704991848413, 2.695270151650034, 2.871156041346198, 3.0401317655630393, 3.203063464809169, 3.36064630854763, 3.513448706275082, 3.6619427602526975, 3.8065258702599523, 3.947536451466457, 4.08526562007695, 4.219966046805482, 4.351858776904846, 4.481138561675227, 4.607978081438405, 4.732531330158304, 4.854936357195453, 4.975317509882154, 5.093787284047658, 5.210447863410356, 5.3253924096856675, 5.438706151201929, 5.550467307327828, 5.66074787809991, 5.76961432240342, 5.877128143413167, 5.983346396391379, 6.088322131111734, 6.192104778946007, 6.294740492873919, 6.3962724472544625, 6.496741103050488, 6.596184443268354, 6.694638182615903, 6.792135954759719, 6.888709480049596, 6.98438871615299, 7.0792019936883746, 7.173176138650433, 7.266336583171589, 7.358707465954793, 7.450311723535191, 7.541171173377642, 7.6313065896886, 7.720737772711043, 7.809483612176842, 7.897562145509785, 7.984990611302439, 8.071785498529296, 8.157962591906028, 8.243537013758772, 8.328523262727323, 8.412935249591152, 8.496786330476336, 8.580089337674618, 8.662856608281896, 8.74510001084253, 8.826830970167233, 8.908060490475837, 8.988799177001594, 9.069057256180706, 9.148844594539066, 9.228170716377948, 9.307044820350995, 9.38547579501667, 9.463472233442745, 9.541042446932828, 9.61819447793879, 9.694936112217595, 9.771274890286058, 9.847218118222663, 9.922772877861535, 9.997946036420013, 10.072744255597966, 10.14717400018399, 10.221241546200865, 10.294952988620226, 10.368314248674032, 10.441331080788403, 10.514009079163504, 10.586353684021379, 10.658370187542072, 10.730063739506907, 10.801439352666465, 10.87250190784955, 10.943256158828321, 11.01370673695374, 11.083858155574447, 11.153714814251432, 11.22328100277987, 11.292560905028928, 11.361558602609481, 11.43027807837915, 11.498723219793412], [0.0, 0.7286369767749634, 1.1044071366698645, 1.4085879207747214, 1.673968193222827, 1.9137852788161438, 2.1350200469046814, 2.341909083002052, 2.5372613222793183, 2.723056877149456, 2.9007560518453506, 3.071473821126582, 3.236085254925233, 3.39529268951211, 3.5496703943673857, 3.6996953388620972, 3.845769019744841, 3.9882333410560626, 4.1273824202455005, 4.263471532920733, 4.396724003187294, 4.527336590122177, 4.655483754284555, 4.781321077229861, 4.904988031530201, 5.026610246469218, 5.146301377645151, 5.264164662233286, 5.380294222394145, 5.494776165112389, 5.607689516154582, 5.719107017837313, 5.82909581419971, 5.93771804247986, 6.0450313461477885, 6.151089321890621, 6.255941910689887, 6.3596357413366755, 6.462214433293439, 6.563718864652887, 6.664187410004897, 6.763656152255946, 6.86215907181688, 6.95972821605653, 7.056393851489124, 7.152184600805941, 7.247127566562644, 7.341248443082696, 7.434571617925553, 7.527120264089191, 7.6189164239643095, 7.7099810859277955, 7.80033425435204, 7.889995013711469, 7.978981587385606, 8.06731139168725, 8.155001085582986, 8.242066616520061, 8.328523262727323, 8.414385672317426, 8.499667899482178, 8.584383438041842, 8.668545252581895, 8.752165807386785, 8.835257093358917, 8.917830653092405, 8.999897604254416, 9.081468661412226, 9.162554156430856, 9.243164057554562, 9.323307987274825, 9.402995239078257, 9.482234793159376, 9.561035331175672, 9.639405250115637, 9.717352675344317, 9.794885472885468, 9.872011260994409, 9.948737421071202, 10.025071107959713, 10.101019259674446, 10.176588606593665, 10.251785680154315, 10.326616821081453, 10.401088187182461, 10.47520576073388, 10.548975355486741, 10.62240262331428, 10.69549306052418, 10.7682520138559, 10.840684686182122, 10.91279614193208, 10.984591312253189, 11.056074999926334, 11.12725188404911, 11.198126524500259, 11.268703366197775, 11.338986743162222, 11.408980882396111, 11.478689907589441, 11.548117842660865, 11.617268615143345], [0.0, 0.7360219228178333, 1.1156006217298275, 1.4228643658675872, 1.6909343439651998, 1.933182044931763, 2.156659091242814, 2.365645007428817, 2.5629771980294453, 2.7506558444684384, 2.930156051583522, 3.1026040947252445, 3.2688839129119938, 3.429704960795374, 3.585647328242472, 3.737192818846553, 3.884746998641632, 4.028655236964276, 4.169214632229462, 4.306683047336719, 4.441286069845841, 4.573222453043856, 4.702668425698049, 4.82978114622782, 4.954701500800043, 5.077556391987409, 5.1984606273204435, 5.317518490313001, 5.434825057080863, 5.550467307327828, 5.6645250677694134, 5.77707181798658, 5.888175382542669, 5.997898528454608, 6.1062994834256275, 6.213432387360744, 6.319347687407751, 6.424092484953988, 6.5277108415577505, 6.6302440496230135, 6.731730872677199, 6.832207759337454, 6.931709034415894, 7.030267070090684, 7.127912439635907, 7.224674055842079, 7.320579295957087, 7.415654114723777, 7.509923146876559, 7.603409800278429, 7.69613634072608, 7.788123969319655, 7.879392893181635, 7.969962390213096, 8.059850868492777, 8.149075920852834, 8.237654375103284, 8.325602340323353, 8.412935249591152, 8.499667899482178, 8.585814486631536, 8.671388641623246, 8.756403460442604, 8.840871533703176, 8.924804973838624, 9.008215440430583, 9.091114163826989, 9.173511967190345, 9.25541928710211, 9.336846192837571, 9.417802404414935, 9.498297309512985, 9.578339979343102, 9.65793918355388, 9.737103404239711, 9.815840849118564, 9.894159463938614, 9.972066944168397, 10.049570746020592, 10.126678096855475, 10.203396005006331, 10.279731269065747, 10.355690486668667, 10.431280062805229, 10.506506217693966, 10.58137499424352, 10.655892265128967, 10.730063739506909, 10.803894969391692, 10.877391355713526, 10.950558154077708, 11.023400480242922, 11.095923315335185, 11.168131510812954, 11.240029793197829, 11.311622768584238, 11.382914926940702, 11.453910646214332, 11.524614196249534, 11.595029742531093, 11.665161349761235, 11.735012985279608], [0.0, 0.7433577969155766, 1.1267197276296117, 1.4370459459572247, 1.707787756982286, 1.9524499222190912, 2.1781543471239715, 2.3892232099204134, 2.588522195341685, 2.778071420466487, 2.959360692389415, 3.13352751196112, 3.301464628352444, 3.4638885672951325, 3.6213852003675213, 3.774441133262364, 3.923465974259257, 4.068808534964476, 4.210768874950129, 4.349607427215505, 4.485552027734319, 4.618803410752375, 4.749539561495579, 4.877919204769252, 5.004084630941895, 5.128164007414417, 5.250273285995201, 5.370517789583891, 5.488993541912629, 5.605788389605258, 5.720982955004047, 5.834651450055311, 5.946862375324615, 6.057679123422936, 6.167160502404559, 6.2753611917827845, 6.382332141508261, 6.4881209224242475, 6.592772035247212, 6.696327183939359, 6.798825518381215, 6.900303850470501, 7.000796847132106, 7.100337203195211, 7.198955796655381, 7.296681828474699, 7.393542948767982, 7.48956537096701, 7.584773975338702, 7.679192403050433, 7.772843141820383, 7.865747604058436, 7.957926198289912, 8.049398394557254, 8.140182784411108, 8.23029713603004, 8.31975844494556, 8.408582980794854, 8.496786330476336, 8.584383438041842, 8.671388641623246, 8.757815707659557, 8.843677862662751, 8.928987822736078, 9.013757821036895, 9.097999633356997, 9.181724601976333, 9.264943657931036, 9.34766734182318, 9.42990582328774, 9.511668919221602, 9.592966110869826, 9.673806559855858, 9.75419912323471, 9.834152367641158, 9.913674582598865, 9.992773793050674, 10.071457771165262, 10.14973404747081, 10.227609921362138, 10.305092471024055, 10.382188562810196, 10.458904860113629, 10.535247831762538, 10.611223759971896, 10.686838747879554, 10.762098726693088, 10.837009462471828, 10.911576562566623, 10.985805481738335, 11.059701527974482, 11.133269868022122, 11.206515532653771, 11.279443421682002, 11.352058308737293, 11.42436484582266, 11.496367567657801, 11.568070895824487, 11.639479142724337, 11.710596515359201, 11.781427118943887, 11.851974960360208], [0.0, 0.750645721726072, 1.1377661560003618, 1.451134831345687, 1.7245310114646024, 1.9715918593702615, 2.1995091041109305, 2.4126472988068692, 2.6139002235378315, 2.805307800732564, 2.9883744436445445, 3.164248805251577, 3.3338323872913813, 3.497848740357323, 3.6568894799481346, 3.811445982468219, 3.9619318720215237, 4.108699379984416, 4.252051507731199, 4.392251241562043, 4.529528651168331, 4.6640864388065575, 4.79610433468055, 4.925742619743222, 5.053144979386457, 5.178440837572115, 5.301747282907122, 5.423170670883205, 5.542807966654982, 5.66074787809991, 5.77707181798658, 5.8918547258397185, 6.005165773808579, 6.11706897600913, 6.227623717053381, 6.336885212535885, 6.444904911923693, 6.551730852447488, 6.6574079711114535, 6.761978380745961, 6.865481615059337, 6.967954846855372, 7.069433082935585, 7.16994933867124, 7.26953479478764, 7.368218938534865, 7.46602969111113, 7.562993522946288, 7.6591355582348974, 7.754479669923771, 7.849048566202035, 7.942863869408138, 8.035946188153817, 8.128315183366988, 8.219989628870984, 8.310987467044669, 8.401325860044771, 8.491021237016984, 8.580089337674618, 8.668545252581895, 8.756403460442604, 8.843677862662751, 8.930381815427841, 9.016528159510564, 9.102129248002896, 9.187196972147204, 9.271742785423836, 9.35577772603747, 9.439312437930873, 9.52235719044274, 9.604921896715409, 9.687016130948635, 9.76864914458698, 9.84982988152056, 9.93056699237195, 10.01086884793581, 10.090743551832007, 10.170198952428029, 10.24924265408181, 10.327882027751881, 10.406124221018002, 10.483976167551955, 10.561444596075113, 10.638536038836445, 10.715256839642144, 10.791613161465587, 10.867610993664272, 10.943256158828323, 11.018554319283394, 11.093510983269155, 11.168131510812954, 11.242421119316946, 11.316384888875652, 11.390027767339697, 11.463354575140526, 11.536370009889675, 11.6090786507655, 11.681484962699237, 11.753593300371543, 11.825407912029977, 11.896932943137113, 11.968172439858481], [0.0, 0.7578867765840317, 1.1487415428075818, 1.4651331085834607, 1.7411665870721655, 1.9906106912879056, 2.220726524822829, 2.4359207431734036, 2.639115041079651, 2.832369018948605, 3.0172016022577943, 3.1947725243908454, 3.365991983363027, 3.5315905094511795, 3.6921654251342484, 3.8482128468469834, 4.000150388691197, 4.1483336798201895, 4.293068644491204, 4.434620805884556, 4.573222453043856, 4.709078243579659, 4.842369641451449, 4.9732584737518675, 5.101889811924533, 5.228394328411088, 5.35289024130605, 5.475484932052435, 5.596276301172888, 5.7153539122596015, 5.832799963424114, 5.9486901170903765, 6.063094212672256, 6.176076881793704, 6.287698081916503, 6.398013561268833, 6.5070752656216575, 6.614931695593666, 6.7216282216709144, 6.827207362922438, 6.931709034415894, 7.0351707675400945, 7.137627906787378, 7.2391137860096295, 7.339659886714978, 7.439295980600333, 7.538050258203924, 7.635949445300871, 7.733018908444635, 7.829282750870846, 7.924763899821694, 8.019484186214099, 8.113464417459424, 8.20672444414344, 8.299283221189938, 8.391158864057768, 8.48236870045728, 8.572929318016849, 8.662856608281896, 8.752165807386785, 8.840871533703176, 8.928987822736078, 9.016528159510564, 9.103505508667002, 9.189932342460656, 9.27582066684199, 9.3611820457766, 9.44602762394848, 9.530368147976498, 9.614213986261852, 9.69757514757336, 9.780461298467669, 9.862881779632795, 9.944845621235503, 10.02636155734604, 10.107438039507379, 10.18808324951043, 10.268305111431449, 10.348111302983309, 10.427509266228007, 10.506506217693968, 10.58510915793818, 10.663324880590196, 10.741159980911888, 10.818620863904565, 10.895713751992323, 10.972444692308605, 11.048819563610769, 11.124844082845724, 11.200523811388017, 11.27586416097014, 11.350870399323588, 11.425547655547673, 11.499900925222143, 11.573935075278415, 11.64765484864323, 11.721064868667689, 11.794169643353692, 11.866973569389044, 11.93948093600174, 12.011695928643292, 12.083622632510297], [0.0, 0.7650819998320295, 1.159647461884313, 1.4790427849757657, 1.7576968692897885, 2.009509145207664, 2.2418096517654447, 2.459046880352574, 2.6641702636859947, 2.85925895560102, 3.045846301945406, 3.225103046376161, 3.3979480281437913, 3.5651187130313278, 3.727218094376109, 3.8847469986416314, 4.038127004673238, 4.187717117895238, 4.333826166947686, 4.476722195834085, 4.616639698903085, 4.75378527674306, 4.888342116095499, 5.02047358040662, 5.150326118398885, 5.278031643091579, 5.4037094949178135, 5.527468074778238, 5.649406212643185, 5.769614322403419, 5.888175382542668, 6.005165773808578, 6.120655998656239, 6.234711302309123, 6.3473922114529895, 6.458755003578379, 6.5688521176188654, 6.677732514648168, 6.78544199589053, 6.892023484082398, 6.997517273236981, 7.101961251058482, 7.205391097592675, 7.3078404631562695, 7.409341128136445, 7.509923146876559, 7.609614977550088, 7.70844359966124, 7.8064346205883846, 7.90361237239838, 8.000000000000002, 8.095619541568462, 8.190492002056468, 8.28463742050722, 8.37807493179871, 8.470822823374279, 8.562898587450041, 8.654318969133946, 8.74510001084253, 8.835257093358917, 8.924804973838624, 9.013757821036895, 9.102129248002896, 9.189932342460656, 9.277179695074505, 9.363883425776958, 9.45005520831956, 9.535706293191666, 9.620847529038368, 9.705489382696358, 9.789641957955675, 9.873315013145294, 9.956517977631824, 10.039259967312605, 10.12154979917737, 10.20339600500633, 10.284806844266656, 10.365790316264173, 10.446354171602405, 10.526505922996776, 10.606252855487963, 10.685602036094826, 10.764560322944254, 10.843134373912203, 10.921330654807758, 10.99915544712945, 11.076614855420978, 11.153714814251432, 11.230461094843252, 11.306859311369546, 11.3829149269407, 11.458633259298976, 11.53401948623832, 11.609078650765499, 11.683815666017589, 11.758235319949712, 11.832342279806129, 11.906141096386797, 11.979636208120777, 12.052831944957127, 12.12573253208319, 12.198342093479583], [0.0, 0.7722323909917427, 1.1704854282221195, 1.4928657927799618, 1.7741241544152841, 2.0282898464010137, 2.2627614136932674, 2.482028922902854, 2.689069371893498, 2.885981346095044, 3.0743125218748473, 3.2552445845603484, 3.4297049607953736, 3.5984380086553047, 3.7620523570018154, 3.921053512979843, 4.075866995474686, 4.22685516514475, 4.374329736916238, 4.518561259909061, 4.659786420036067, 4.79821374875712, 4.9340281448613785, 5.067394498575906, 5.1984606273204435, 5.327359676962109, 5.454212103279533, 5.579127320278939, 5.702205081587143, 5.823536646095422, 5.943205767797342, 6.061289541288508, 6.177859127933944, 6.292980382733421, 6.4067143980499415, 6.51911797733868, 6.630244049623012, 6.7401420335626785, 6.848858158436261, 6.956435748132444, 7.0629154732488475, 7.168335575584928, 7.272732068649128, 7.376138917251149, 7.4785881987949585, 7.580110248509246, 7.680733790535154, 7.780486056525034, 7.879392893181634, 7.977478859977233, 8.074767318130952, 8.17128051178491, 8.267039642202311, 8.36206493570955, 8.456375706017553, 8.549990411482547, 8.64292670780141, 8.73520149658044, 8.826830970167233, 8.917830653092405, 9.008215440430583, 9.097999633356997, 9.187196972147204, 9.27582066684199, 9.363883425776958, 9.451397482156484, 9.538374618833993, 9.624826191444962, 9.71076315002499, 9.796196059232935, 9.881135117287997, 9.965590173719658, 10.04957074602059, 10.133086035284526, 10.216144940904037, 10.298756074396627, 10.380927772421739, 10.462668109046028, 10.5439849073095, 10.624885750140779, 10.705377990665907, 10.785468761951506, 10.865164986219927, 10.94447338357107, 11.023400480242922, 11.101952616440363, 11.180135953759637, 11.25795648223381, 11.335420027022678, 11.412532254768928, 11.489298679640715, 11.565724669079463, 11.64181544927034, 11.717576110351624, 11.793011611378153, 11.868126785052867, 11.9429263422397, 12.017414876269987, 12.091596867053978, 12.165476685008064, 12.239058594807823, 12.312346758976252], [0.0, 0.7793389127886403, 1.1812569010399445, 1.5066039931196407, 1.790450654210978, 2.0469553234931666, 2.283584631542157, 2.504869965116179, 2.7138157181069595, 2.912539788321386, 3.102604094725244, 3.2852011971866357, 3.461267057056991, 3.6315528824181786, 3.796672903080916, 3.9571372781544785, 4.113375442391032, 4.2657530910979125, 4.414584807779414, 4.5601436313023695, 4.702668425698049, 4.842369641451449, 4.979433878895577, 5.114027545671174, 5.246299819497973, 5.376385071527111, 5.504404866039821, 5.630469623932262, 5.754680016820871, 5.877128143413167, 5.997898528454608, 6.117068976009131, 6.234711302309125, 6.350891968389535, 6.4656726288200455, 6.579110609793539, 6.691259327416379, 6.802168655126927, 6.911885247631886, 7.020452827511013, 7.127912439635906, 7.234302677728816, 7.339659886714977, 7.4440183439675955, 7.547410422085157, 7.649866735458385, 7.7514162725643105, 7.852086515656442, 7.95190354929359, 8.050892158958272, 8.149075920852834, 8.24647728382265, 8.343117644237008, 8.439017414556462, 8.5341960862277, 8.628672287471243, 8.722463836461733, 8.815587790343669, 8.908060490475837, 8.999897604254416, 9.091114163826989, 9.181724601976333, 9.271742785423836, 9.3611820457766, 9.45005520831956, 9.538374618833993, 9.62615216860585, 9.713399317771628, 9.800127117135379, 9.886346228577963, 9.972066944168397, 10.057299204077134, 10.14205261338223, 10.226336457851115, 10.310159718773638, 10.393531086915383, 10.476458975654475, 10.558951533359728, 10.64101665506321, 10.722661993475967, 10.803894969391692, 10.884722781519542, 10.9651524157841, 11.045190654127447, 11.124844082845724, 11.204119100489983, 11.283021925358984, 11.361558602609481, 11.43973501100771, 11.517556869344025, 11.595029742531091, 11.672159047404586, 11.748950058244006, 11.825407912029975, 11.901537613453378, 11.977344039690436, 12.052831944957129, 12.128005964855246, 12.202870620521718, 12.277430322591991, 12.351689374987618, 12.4256519785375], [0.0, 0.7864024930420794, 1.191963286648958, 1.5202591796385239, 1.8066785002460082, 2.065508013427462, 2.304282023967618, 2.527572989092894, 2.738412533181035, 2.9389377497198854, 3.1307247142119863, 3.3149767953561007, 3.4926384376398287, 3.6644676577599897, 3.831084252632306, 3.9930030052206447, 4.1506572424822, 4.304415974223444, 4.454596635193221, 4.601474738960854, 4.745291314514639, 4.88625871976889, 5.024565246318791, 5.16037881004971, 5.293849940761683, 5.42511422748602, 5.554294336308372, 5.681501688930642, 5.806837869411893, 5.930395811201242, 6.0522608051387365, 6.172511360469641, 6.291219944336638, 6.4084536201478475, 6.524274601282469, 6.638740733512426, 6.751905917083842, 6.863820477465674, 6.974531492222077, 7.084083080214765, 7.192516658327743, 7.299871170079545, 7.4061832898095945, 7.511487605565917, 7.615816783357792, 7.719201715051121, 7.8216716518615605, 7.9232543251295064, 8.023976055832573, 8.123861854097834, 8.22293550981182, 8.321219675286224, 8.418735940817477, 8.515504903875575, 8.611546232568982, 8.706878723956097, 8.80152035770755, 8.895488345566193, 8.988799177001594, 9.081468661412226, 9.173511967190345, 9.264943657931036, 9.35577772603747, 9.44602762394848, 9.535706293191666, 9.624826191444962, 9.713399317771628, 9.801437236177723, 9.888951097626862, 9.975951660634435, 10.062449310552179, 10.148454077643823, 10.233975654043562, 10.31902340968088, 10.403606407248034, 10.487733416279825, 10.57141292640949, 10.654653159859018, 10.73746208321753, 10.819847418556828, 10.90181665392937, 10.983377053290203, 11.06453566588121, 11.145299335112975, 11.225674706976884, 11.305668238017606, 11.385286202893784, 11.464534701552779, 11.543419666043336, 11.621946866988381, 11.70012191973846, 11.777950290225036, 11.85543730053132, 11.932588134197237, 12.009407841273957, 12.085901343142252, 12.162073437108194, 12.2379288007886, 12.313471996297967, 12.388707474247777, 12.463639577568404, 12.538272545163188], [0.0, 0.7934240264316235, 1.2026059411297958, 1.5338330819150792, 1.82280974795426, 2.0839502661046487, 2.3248562125203858, 2.55014087041887, 2.7628629325709153, 2.9651785738805807, 3.158677942118569, 3.3445751504733585, 3.5238230760717677, 3.6971865036964164, 3.865290764229128, 4.028655236964276, 4.187717117895238, 4.342848711597637, 4.494370287092473, 4.642559817920577, 4.787660485140088, 4.929886542740417, 5.069427963511477, 5.206454162605237, 5.3411170138536095, 5.4735533169184905, 5.603886833131316, 5.73222997904231, 5.858685245721727, 5.983346396391379, 6.1062994834256275, 6.227623717053381, 6.34739221145299, 6.465672628820045, 6.582527738016876, 6.698015901301587, 6.812191500178155, 6.925105309455368, 7.036804827037717, 7.147334565709953, 7.2567363121540405, 7.365049357602585, 7.472310703848322, 7.578555247764763, 7.6838159470254155, 7.788123969319657, 7.8915088270377804, 7.993998499124347, 8.095619541568464, 8.196397187804537, 8.296355440131295, 8.395517153115591, 8.493904109826627, 8.591537091642545, 8.68843594228198, 8.784619626636191, 8.880106284910465, 8.974913282525733, 9.069057256180706, 9.162554156430856, 9.25541928710211, 9.34766734182318, 9.439312437930873, 9.530368147976498, 9.620847529038368, 9.71076315002499, 9.800127117135379, 9.888951097626862, 9.977246342026397, 10.06502370490868, 10.152293664352891, 10.239066340179741, 10.325351511061351, 10.411158630588279, 10.49649684237062, 10.581374994243522, 10.665801651641404, 10.749785110199818, 10.833333407638978, 10.916454334978573, 10.999155447129452, 11.081444072904167, 11.163327324485005, 11.244812106385142, 11.325905123935875, 11.40661289133027, 11.486941739251366, 11.566897822110983, 11.646487124923206, 11.725715469834988, 11.804588522334523, 11.883111797156804, 11.961290663904204, 12.0391303523988, 12.116635957782032, 12.193812445376087, 12.270664655320637, 12.347197306997419, 12.423415003254577, 12.499322234441664, 12.57492338226567, 12.650222723477738], [0.0, 0.800404376149386, 1.2131861728370446, 1.547327368656802, 1.8388463804304556, 2.1022843487228142, 2.345309726488057, 2.572576383476297, 2.787169922086124, 2.99126548671884, 3.186467214874692, 3.373999901211801, 3.5548248060359184, 3.729713442518349, 3.8992966430484306, 4.064098356292009, 4.224559624585433, 4.381056027948547, 4.533910653050536, 4.683403918975173, 4.82978114622782, 4.973258473751867, 5.114027545671174, 5.252259267610608, 5.388106849550755, 5.521708294683337, 5.653188453161589, 5.782660730548932, 5.910228519606888, 6.035986408463065, 6.160021206559477, 6.282412820997173, 6.4032350091950905, 6.522556028624195, 6.640439200371854, 6.7569434001529824, 6.872123487906674, 6.986030685146015, 7.098712907650392, 7.2102150598171075, 7.320579295957086, 7.429845252977551, 7.538050258203922, 7.645229515523835, 7.75141627256431, 7.856641971220403, 7.960936383525169, 8.064327734575052, 8.166842813992229, 8.268507077208664, 8.369344737689413, 8.469378851070198, 8.568631392062313, 8.667123324873359, 8.76487466780214, 8.86190455258836, 8.958231279030388, 9.053872365325857, 9.148844594539066, 9.243164057554562, 9.336846192837571, 9.42990582328774, 9.52235719044274, 9.614213986261852, 9.705489382696358, 9.796196059232935, 9.886346228577963, 9.975951660634435, 10.06502370490868, 10.153573311471277, 10.241611050584975, 10.329147131102179, 10.416191417725367, 10.502753447215463, 10.588842443625804, 10.674467332632611, 10.759636755026897, 10.844359079427175, 10.92864241426755, 11.012494619111186, 11.095923315335183, 11.178935896229188, 11.261539536546715, 11.343741201545159, 11.42554765554767, 11.506965470057585, 11.588001031453741, 11.668660548292955, 11.748950058244004, 11.828875434675654, 11.908442392919675, 11.987656496228345, 12.066523161444476, 12.14504766440084, 12.223235145064676, 12.301090612441861, 12.37861894925442, 12.455824916404058, 12.532713157233644, 12.609288201597721, 12.685554469752466, 12.761516276074824], [0.0, 0.8073443754472972, 1.2237052447444592, 1.560743650691363, 1.8547903119848381, 2.1205124498413204, 2.365645007428817, 2.5948822064167456, 2.811336403278409, 3.017201602257794, 3.2140958497160392, 3.403254560035896, 3.5856473282424717, 3.7620523570018154, 3.933105948408916, 4.099336594087506, 4.261189160482842, 4.419042484125041, 4.573222453043856, 4.724011917729363, 4.871658325766916, 5.01637969015777, 5.158369316698463, 5.297799592870977, 5.434825057080862, 5.569584909092578, 5.702205081587143, 5.832799963424114, 5.961473843843986, 6.088322131111734, 6.213432387360745, 6.336885212535886, 6.45875500357838, 6.579110609793539, 6.698015901301587, 6.815530264306179, 6.931709034415894, 7.046603877265908, 7.160263124094952, 7.272732068649129, 7.384053230743224, 7.494266590960878, 7.603409800278429, 7.711518367822917, 7.818625829498783, 7.924763899821694, 8.029962608966581, 8.134250426758873, 8.237654375103283, 8.34020013014606, 8.44191211529793, 8.542813586101182, 8.64292670780141, 8.742272626378808, 8.840871533703174, 8.938742727398191, 9.035904665932753, 9.132375019398067, 9.228170716377948, 9.323307987274825, 9.417802404414935, 9.511668919221602, 9.604921896715409, 9.69757514757336, 9.789641957955675, 9.881135117287997, 9.972066944168397, 10.062449310552179, 10.152293664352891, 10.241611050584975, 10.330412131161868, 10.418707203453021, 10.506506217693966, 10.593818793335219, 10.680654234408342, 10.767021543980677, 10.852929437764216, 10.938386356938556, 11.023400480242923, 11.107979735387735, 11.192131809832134, 11.27586416097014, 11.35918402576481, 11.442098429866604, 11.524614196249534, 11.606737953395912, 11.68847614305842, 11.769835027625891, 11.85082069711741, 11.93143907582747, 12.01169592864329, 12.091596867053976, 12.171147354869706, 12.250352713667974, 12.329218127982701, 12.407748650250934, 12.48594920553091, 12.563824596004281, 12.641379505274564, 12.718618502472934, 12.795546046181911, 12.87216648818675], [0.0, 0.8142448290873745, 1.2341643766431614, 1.5740834837702447, 1.8706433914750185, 2.138636683189983, 2.3858644134209612, 2.6170609258224764, 2.8353651784918816, 3.0429899280482746, 3.241567050457907, 3.4323425193146098, 3.6162942168697643, 3.7942069971659365, 3.966722600836168, 4.134374036575294, 4.297609973146857, 4.456812485034928, 4.6123102456670555, 4.764388523084921, 4.913296879833298, 5.0592551922925075, 5.2024584184631895, 5.343080419240483, 5.481277053885249, 5.6171887119163415, 5.750942402374081, 5.882653491811122, 6.012427160838593, 6.140359633185514, 6.2665392193876395, 6.391047208285679, 6.5139586326989996, 6.635342930394855, 6.7552645173978165, 6.873783287491399, 6.990955049243199, 7.1068319098797765, 7.2214626137318225, 7.334892841675649, 7.447165476947178, 7.558320841848122, 7.668396909161504, 7.777429491514446, 7.885452411446142, 7.992497654539415, 8.098595507640125, 8.203774683908161, 8.30806243620718, 8.411484660140037, 8.514065987866802, 8.615829873697233, 8.716798672325504, 8.816993710468633, 8.91643535257836, 9.015143061217097, 9.113135452620133, 9.210430347906726, 9.307044820350995, 9.402995239078257, 9.498297309512985, 9.592966110869826, 9.687016130948635, 9.780461298467669, 9.873315013145294, 9.965590173719658, 10.057299204077134, 10.148454077643823, 10.239066340179741, 10.329147131102179, 10.418707203453021, 10.507756942614375, 10.596306383867434, 10.684365228881127, 10.77194286120951, 10.859048360870048, 10.945690518068803, 11.03187784613298, 11.117618593706313, 11.202920756258159, 11.28779208695315, 11.3722401069244, 11.456272114990018, 11.53989519684941, 11.623116233793224, 11.705941910958089, 11.788378725154987, 11.870432992298023, 11.952110854458287, 12.03341828656581, 12.11436110278089, 12.19494496255459, 12.275175376396824, 12.355057711369144, 12.434597196318206, 12.513798926864744, 12.592667870161963, 12.671208869436246, 12.74942664832234, 12.827325815004244, 12.904910866172433, 12.982186190807305], [0.0, 0.821106514702358, 1.2445647472039778, 1.5873483711990972, 1.886407405431895, 2.156659091242814, 2.4059702230497684, 2.6391150410796507, 2.8592589556010206, 3.068633370253773, 3.2688839129119938, 3.4612670570569914, 3.6467689256072515, 3.826180986613193, 4.000150388691197, 4.169214632229461, 4.333826166947686, 4.494370287092472, 4.651178435840281, 4.804538285202152, 4.954701500800042, 5.101889811924533, 5.246299819497973, 5.388106849550755, 5.527468074778238, 5.6645250677694134, 5.799405907876716, 5.932226933853038, 6.063094212672255, 6.192104778946007, 6.319347687407751, 6.444904911923694, 6.568852117618866, 6.691259327416378, 6.812191500178155, 6.931709034415893, 7.049868208999035, 7.166721570264582, 7.282318273314361, 7.396704383979923, 7.509923146876557, 7.6220152241042145, 7.733018908444634, 7.842970314319899, 7.951903549293589, 8.059850868492777, 8.166842813992229, 8.2729083409192, 8.37807493179871, 8.482368700457279, 8.585814486631534, 8.68843594228198, 8.790255610487016, 8.891294997685073, 8.991574639940234, 9.091114163826989, 9.189932342460658, 9.28804714714004, 9.38547579501667, 9.482234793159376, 9.578339979343102, 9.673806559855858, 9.76864914458698, 9.862881779632795, 9.956517977631824, 10.04957074602059, 10.14205261338223, 10.233975654043562, 10.325351511061351, 10.416191417725367, 10.506506217693966, 10.596306383867434, 10.685602036094828, 10.77440295780157, 10.862718611617442, 10.950558154077708, 11.037930449463975, 11.124844082845724, 11.211307372378458, 11.297328380909795, 11.382914926940702, 11.468074594985296, 11.552814745369224, 11.637142523503467, 11.721064868667687, 11.804588522334521, 11.887720036063936, 11.970465778994585, 12.052831944957127, 12.13482455923266, 12.216449484977723, 12.297712429335881, 12.37861894925442, 12.459174457023408, 12.539384225553283, 12.619253393405849, 12.698786969592781, 12.7779898381546, 12.856866762532377, 12.935422389743529, 13.013661254372387, 13.09158778238553], [0.0, 0.8279301840734127, 1.2549074959140751, 1.6005397663077712, 1.9020840809950434, 2.1745816485739478, 2.4259646391513696, 2.6610469684849924, 2.8830203524598934, 3.0941347384254625, 3.2960494299730256, 3.49003134229816, 3.677074793330151, 3.85797782848325, 4.033392974394976, 4.203862198261269, 4.369841709810108, 4.531720005211965, 4.689831282046791, 4.844465602976117, 4.995876725047269, 5.144288220195286, 5.289898323161843, 5.432883816995201, 5.573403180548309, 5.711599162925657, 5.847600907861874, 5.981525720923742, 6.113480550537116, 6.243563237703666, 6.371863577231426, 6.498464224216808, 6.623441472587305, 6.746865927179902, 6.868803086686363, 6.989313851550188, 7.10845496833702, 7.2262794200614735, 7.342836770320686, 7.458173467768652, 7.57233311639786, 7.68535671622389, 7.797282878254286, 7.908148017034042, 8.017986523571981, 8.126830921046057, 8.234712005345873, 8.341658972225465, 8.447699532598815, 8.552860017307061, 8.65716547251334, 8.760639746733844, 8.863305570387487, 8.965184628638383, 9.066297628212167, 9.16666435878672, 9.266303749488216, 9.365233920962954, 9.463472233442745, 9.561035331175672, 9.65793918355388, 9.75419912323471, 9.84982988152056, 9.944845621235503, 10.039259967312605, 10.133086035284526, 10.226336457851115, 10.31902340968088, 10.411158630588279, 10.502753447215463, 10.593818793335219, 10.684365228881127, 10.77440295780157, 10.863941844825508, 10.952991431220328, 11.041560949615166, 11.12965933795677, 11.217295252659413, 11.30447708100525, 11.391212952846853, 11.477510751659548, 11.563378124987295, 11.648822494322504, 11.733851064456907, 11.818470832337901, 11.90268859546201, 11.986510959834852, 12.069944347524752, 12.152995003835168, 12.235669004119297, 12.317972260258465, 12.39991052682451, 12.481489406944803, 12.562714357887351, 12.643590696382237, 12.724123603694434, 12.804318130462173, 12.884179201313984, 12.963711619276724, 13.04292006998608, 13.12180912571029, 13.200383249197191], [0.0, 0.8347165643310208, 1.2651937248971707, 1.6136590747718584, 1.917675088671641, 2.192406265011812, 2.445849792331547, 2.682859045105565, 2.906651901083903, 3.1194967499901574, 3.32306649639959, 3.5186384401615056, 3.7072150494329423, 3.889600911048853, 4.066453900278773, 4.238320426716744, 4.4056604395518155, 4.568865619380865, 4.728272903135427, 4.884174731063399, 5.036826940208526, 5.186454935080853, 5.3332585753131, 5.477416093009268, 5.619087266042176, 5.75841601360254, 5.895532537990684, 6.030555106303961, 6.163591543603359, 6.294740492873919, 6.424092484953989, 6.551730852447489, 6.677732514648169, 6.802168655126927, 6.925105309455368, 7.046603877265908, 7.166721570264582, 7.285511805757314, 7.403024553604263, 7.51930664318987, 7.6344020359199405, 7.748352067879088, 7.861195666561661, 7.972969544995491, 8.08370837608571, 8.193444949596337, 8.302210313844808, 8.410033903896986, 8.516943657807747, 8.622966122246932, 8.728126548676135, 8.832448981093126, 8.935956336233573, 9.038670477010603, 9.14061227987879, 9.241801696728096, 9.342257811843009, 9.441998894401184, 9.541042446932828, 9.639405250115637, 9.737103404239711, 9.834152367641158, 9.93056699237195, 10.02636155734604, 10.12154979917737, 10.216144940904037, 10.310159718773638, 10.403606407248034, 10.49649684237062, 10.588842443625804, 10.680654234408342, 10.77194286120951, 10.862718611617442, 10.952991431220328, 11.042770939493447, 11.132066444743968, 11.220886958181225, 11.309241207174411, 11.397137647754578, 11.48458447641309, 11.571589641244566, 11.658160852478376, 11.744305592439435, 11.830031124975733, 11.915344504387262, 12.000252583888283, 12.084762023632537, 12.168879298328775, 12.252610704471978, 12.33596236721381, 12.418940246894122, 12.501550145253841, 12.583797711348067, 12.665688447176958, 12.74722771305078, 12.828420732704311, 12.909272598174871, 12.989788274457196, 13.069972603947605, 13.149830310689014, 13.229366004427645, 13.308584184491595], [0.0, 0.8414663590846496, 1.275424500625791, 1.6267076567965482, 1.933182044931763, 2.210134788606237, 2.465627744275839, 2.704553532409639, 2.930156051583522, 3.144722034472107, 3.34993791331143, 3.547091316620658, 3.7371928188465526, 3.9210535129798427, 4.099336594087506, 4.272592890212635, 4.441286069845842, 4.605810980843109, 4.766507284719657, 4.923669786492136, 5.077556391987409, 5.228394328411088, 5.376385071527111, 5.521708294683338, 5.6645250677694134, 5.804980473754324, 5.943205767797343, 6.079320173342762, 6.213432387360745, 6.345641850496199, 6.476039825649833, 6.604710319280617, 6.7317308726772, 6.857173245024422, 6.9811040058794065, 7.103585051372342, 7.224674055842078, 7.344424868544577, 7.4628878634128455, 7.580110248509246, 7.69613634072608, 7.81100781040524, 7.924763899821694, 8.037441618876981, 8.149075920852834, 8.259699860662174, 8.369344737689415, 8.47804022502212, 8.585814486631536, 8.692694283852672, 8.798705072338809, 8.90387109051545, 9.008215440430584, 9.111760161788094, 9.214526299856491, 9.316533967863325, 9.417802404414935, 9.518350026419602, 9.61819447793879, 9.717352675344317, 9.815840849118564, 9.913674582598865, 10.01086884793581, 10.107438039507379, 10.20339600500633, 10.298756074396627, 10.393531086915383, 10.487733416279825, 10.581374994243522, 10.674467332632611, 10.767021543980677, 10.859048360870048, 10.950558154077708, 11.041560949615166, 11.132066444743968, 11.22208402304134, 11.311622768584238, 11.400691479314258, 11.489298679640715, 11.577452632334527, 11.665161349761236, 11.75243260449768, 11.839273939373335, 11.925692676974071, 12.01169592864329, 12.097290603012613, 12.182483414091992, 12.26728088894682, 12.35168937498762, 12.435715046896062, 12.519363913209283, 12.602641822583008, 12.685554469752468, 12.76810740120882, 12.850306020607572, 12.932155593924355, 13.013661254372389, 13.094828007095003, 13.175660733645739, 13.256164196267687, 13.336343041983005, 13.41620180650285], [0.0, 0.8481802494863159, 1.2856008555333316, 1.6396868291726892, 1.948606514651812, 2.2277690084219333, 2.48530049086595, 2.7261326196850826, 2.953535175867838, 3.169813137467737, 3.3766663924235667, 3.575392842982804, 3.767011126761945, 3.952338808299138, 4.132044374161071, 4.306683047336718, 4.476722195834085, 4.642559817920577, 4.804538285202152, 4.962954754885243, 5.1180691905753015, 5.2701106324779925, 5.419282163891746, 5.565764891741837, 5.709721171062082, 5.851297242409219, 5.990625408200969, 6.127825843141448, 6.2630081114720255, 6.3962724472544625, 6.52771084155775, 6.657407971111453, 6.78544199589053, 6.9118852476318855, 7.036804827037716, 7.160263124094951, 7.2823182733143605, 7.403024553604261, 7.522432740821116, 7.640590419690895, 7.757542260701448, 7.873330266673922, 7.987993992989485, 8.101570744844217, 8.214095754405038, 8.325602340323355, 8.436122051715056, 8.54568479842329, 8.654318969133948, 8.762051538705338, 8.868908165896261, 8.974913282525733, 9.080090174968324, 9.184461058778274, 9.288047147140041, 9.390868713760568, 9.49294515074715, 9.594295021952869, 9.694936112217595, 9.794885472885468, 9.894159463938614, 9.992773793050674, 10.090743551832007, 10.18808324951043, 10.284806844266656, 10.380927772421739, 10.476458975654475, 10.57141292640949, 10.665801651641404, 10.759636755026897, 10.852929437764216, 10.945690518068803, 11.037930449463975, 11.12965933795677, 11.220886958181225, 11.311622768584238, 11.401875925722784, 11.49165529773546, 11.580969477046127, 11.66982679235268, 11.758235319949712, 11.846202894429886, 11.933737118805396, 12.020845374087544, 12.107534828359707, 12.193812445376087, 12.279684992716366, 12.365159049524074, 12.450241013854445, 12.534937109655688, 12.619253393405849, 12.703195760425894, 12.786769950888202, 12.869981555538256, 12.952836021146254, 13.035338655703976, 13.117494633381517, 13.199308999257237, 13.280786673833605, 13.361932457350695, 13.442751033908314, 13.523246975407144], [0.0, 0.854858895232727, 1.2957237895330211, 1.652597867214111, 1.9639500134168326, 2.245310657170645, 2.504869965116179, 2.747598427260346, 2.976791571134212, 3.194772524390845, 3.4032545600358954, 3.603545800113081, 3.796672903080916, 3.983459871052496, 4.164580454316422, 4.340594247736227, 4.511972299416642, 4.679115741498369, 4.842369641451449, 5.0020334963242465, 5.158369316698463, 5.311607946262452, 5.461954067410364, 5.6095902131193025, 5.754680016820871, 5.897370870582794, 6.037796118583643, 6.176076881793704, 6.312323587172801, 6.446637258034499, 6.579110609793539, 6.709828985931492, 6.838871161861818, 6.966310038867871, 7.092213246008663, 7.216643664535361, 7.339659886714977, 7.461316618852716, 7.581665036618589, 7.700753099424881, 7.818625829498783, 7.935325560395342, 8.050892158958272, 8.165363224128038, 8.278774265492741, 8.391158864057768, 8.502548817359521, 8.612974270753877, 8.722463836461731, 8.831044701743796, 8.93874272739819, 9.045582537622218, 9.151587602149409, 9.256780311461224, 9.3611820457766, 9.464813238439428, 9.56769343425216, 9.66984134324128, 9.771274890286058, 9.872011260994409, 9.972066944168397, 10.071457771165262, 10.170198952428029, 10.268305111431449, 10.365790316264173, 10.462668109046028, 10.558951533359728, 10.654653159859018, 10.749785110199818, 10.844359079427175, 10.938386356938556, 11.03187784613298, 11.124844082845724, 11.217295252659413, 11.309241207174411, 11.400691479314258, 11.49165529773546, 11.582141600405116, 11.67215904740459, 11.761716033012672, 11.85082069711741, 11.939480936001738, 12.02770441254463, 12.115498565876127, 12.202870620521717, 12.289827595068816, 12.376376310385625, 12.462523397420426, 12.548275304607301, 12.633638304902377, 12.718618502472932, 12.803221839060216, 12.887454100035221, 12.971320920165459, 13.054827789109467, 13.137980056654623, 13.220782937712892, 13.30324151708802, 13.38536075402695, 13.46714548656726, 13.548600435691776, 13.629730209300728], [0.0, 0.8615029355102994, 1.3057942714503001, 1.6654420065845175, 1.9792140096915958, 2.2627614136932674, 2.5243380399424726, 2.768953009541838, 2.9999274631590236, 3.219602584004316, 3.429704960795374, 3.6315528824181795, 3.8261809866131933, 4.014419679712101, 4.196947948451389, 4.374329736916238, 4.547039754239644, 4.715482250197416, 4.880004974155028, 5.040909750878862, 5.198460627320444, 5.35289024130605, 5.504404866039822, 5.653188453161589, 5.799405907876717, 5.943205767797343, 6.084722413464998, 6.224077907213052, 6.361383534249598, 6.496741103050488, 6.630244049623013, 6.761978380745961, 6.892023484082399, 7.020452827511013, 7.147334565709953, 7.272732068649129, 7.396704383979922, 7.51930664318987, 7.640590419690896, 7.760604045640153, 7.879392893181634, 7.996999624890587, 8.113464417459422, 8.22882516205096, 8.343117644237008, 8.456375706017553, 8.568631392062313, 8.679915082019583, 8.790255610487016, 8.899680376027158, 9.008215440430583, 9.11588561927607, 9.222714564706031, 9.328724841222764, 9.433937995214192, 9.538374618833993, 9.642054408788583, 9.744996220520461, 9.847218118222663, 9.948737421071202, 10.049570746020592, 10.14973404747081, 10.24924265408181, 10.348111302983309, 10.446354171602405, 10.5439849073095, 10.64101665506321, 10.73746208321753, 10.833333407638978, 10.92864241426755, 11.023400480242923, 11.117618593706313, 11.211307372378458, 11.30447708100525, 11.397137647754578, 11.489298679640715, 11.580969477046127, 11.67215904740459, 11.762876118104398, 11.85312914866544, 11.9429263422397, 12.032275656480733, 12.121184813824105, 12.209661311217436, 12.297712429335883, 12.385345241315955, 12.47256662103825, 12.559383250987382, 12.645801629715239, 12.731828078931928, 12.817468750246869, 12.902729631581055, 12.987616553269904, 13.072135193874848, 13.156291085720545, 13.2400896201734, 13.323536052676145, 13.406635507552078, 13.489392982591854, 13.571813353434719, 13.653901377755398, 13.735661699267135], [0.0, 0.8681129898869979, 1.3158132403745966, 1.6782204450215736, 1.9943999268695047, 2.280122905302287, 2.543706530775652, 2.790198357880382, 3.022945009403235, 3.2443056317530985, 3.456020061246496, 3.6594167016057733, 3.8555381290373476, 4.04522112133234, 4.229149874889404, 4.407892660768027, 4.581927830402415, 4.751662735256006, 4.9174477928711555, 5.079587143825413, 5.238346861023595, 5.3939613672524445, 5.546638518388709, 5.696563677478135, 5.843903014994414, 5.988806208234355, 6.131408668801198, 6.271833395576091, 6.410192527625248, 6.546588654570506, 6.681115929325697, 6.813861018573904, 6.944903919095987, 7.074318662467695, 7.20217392629764, 7.328533566774557, 7.4534570846048025, 7.577000034283325, 7.699214384929415, 7.8201488395384136, 7.939849118381205, 8.058358211370217, 8.175716603461607, 8.291962476545754, 8.407131890766456, 8.521258947783245, 8.634375938135006, 8.746513474563992, 8.857700612907097, 8.967964961947844, 9.077332783441133, 9.185829083368258, 9.293477695347445, 9.400301357011669, 9.506321780067845, 9.611559714667088, 9.716035008642752, 9.819766662109505, 9.922772877861535, 10.025071107959713, 10.126678096855475, 10.227609921362138, 10.327882027751881, 10.427509266228007, 10.526505922996776, 10.624885750140779, 10.722661993475967, 10.819847418556828, 10.916454334978573, 11.012494619111186, 11.107979735387735, 11.202920756258159, 11.297328380909795, 11.391212952846853, 11.48458447641309, 11.577452632334527, 11.66982679235268, 11.761716033012672, 11.85312914866544, 11.944074663738233, 12.034560844323373, 12.124595709131109, 12.214187039848941, 12.303342390946332, 12.392069098960881, 12.480374291299155, 12.568264894582986, 12.65574764256969, 12.742829083672603, 12.829515588106423, 12.915813354680028, 13.001728417257937, 13.087266650909992, 13.172433777767525, 13.257235372603066, 13.341676868149365, 13.425763560172594, 13.509500612313449, 13.59289306070914, 13.675945818408232, 13.75866367958967, 13.841051323596519], [0.0, 0.8746896591546225, 1.325781606935995, 1.6909343439652, 2.0095091452076645, 2.2973967099940706, 2.5629771980294453, 2.811336403278409, 3.0458463019454065, 3.2688839129119938, 3.4822022531844974, 3.6871397902350718, 3.8847469986416314, 4.075866995474686, 4.261189160482843, 4.441286069845842, 4.616639698903085, 4.787660485140088, 4.954701500800043, 5.1180691905753015, 5.278031643091579, 5.434825057080863, 5.588658863098972, 5.739719828469049, 5.888175382542669, 6.034176336545165, 6.177859127933943, 6.319347687407752, 6.45875500357838, 6.5961844432683545, 6.731730872677199, 6.865481615059338, 6.997517273236983, 7.127912439635907, 7.2567363121540405, 7.384053230743224, 7.509923146876558, 7.6344020359199405, 7.75754226070145, 7.879392893181635, 8.000000000000002, 8.119406896752897, 8.237654375103283, 8.354780906200737, 8.470822823374279, 8.585814486631538, 8.699788431138758, 8.812775501554874, 8.924804973838624, 9.035904665932751, 9.14610103854653, 9.25541928710211, 9.36388342577696, 9.471516364460314, 9.578339979343102, 9.684375177775891, 9.789641957955677, 9.894159463938614, 9.997946036420013, 10.101019259674446, 10.203396005006331, 10.305092471024055, 10.406124221018002, 10.506506217693968, 10.606252855487963, 10.705377990665907, 10.803894969391692, 10.90181665392937, 10.999155447129452, 11.095923315335183, 11.192131809832134, 11.28779208695315, 11.382914926940702, 11.477510751659548, 11.571589641244566, 11.665161349761236, 11.758235319949712, 11.85082069711741, 11.9429263422397, 12.034560844323373, 12.125732532083191, 12.216449484977723, 12.30671954364715, 12.396550319792244, 12.485949205530908, 12.57492338226567, 12.663479829093214, 12.7516253307846, 12.839366485362781, 12.92670971130206, 13.013661254372389, 13.100227194149769, 13.186413450212523, 13.272225788041832, 13.357669824643708, 13.442751033908314, 13.527474751721604, 13.611846180843097, 13.695870395562878, 13.779552346149893, 13.862896863102934, 13.945908661214931], [0.0, 0.881233526124879, 1.335700254511853, 1.703584830096522, 2.024543003655771, 2.314584358539769, 2.5821517494331, 2.832369018948605, 3.0686333702537736, 3.293339605560724, 3.5082538568245707, 3.714724605072551, 3.9138101838595563, 4.10636001791721, 4.293068644491204, 4.474512923408983, 4.651178435840281, 4.823478689900609, 4.99176939929321, 5.156359301333056, 5.317518490313001, 5.475484932052435, 5.630469623932261, 5.782660730548932, 5.932226933853038, 6.0793201733427615, 6.224077907213051, 6.366624993332646, 6.5070752656216575, 6.645532864226872, 6.782093365075868, 6.916844744719646, 7.049868208999035, 7.181238908392488, 7.311026558492224, 7.439295980600331, 7.566107574708377, 7.691517734954042, 7.815579215910497, 7.938341456663223, 8.059850868492777, 8.180151091055007, 8.299283221189937, 8.417286017863606, 8.5341960862277, 8.65004804334938, 8.76487466780214, 8.878707035004863, 8.991574639940232, 9.103505508667, 9.21452629985649, 9.32466239742684, 9.43393799521419, 9.542376174504872, 9.649998975153446, 9.756827460925859, 9.862881779632795, 9.968181218553955, 10.072744255597966, 10.176588606593665, 10.279731269065747, 10.382188562810196, 10.483976167551955, 10.58510915793818, 10.685602036094826, 10.785468761951506, 10.884722781519542, 10.983377053290203, 11.081444072904167, 11.178935896229188, 11.27586416097014, 11.3722401069244, 11.468074594985296, 11.563378124987295, 11.658160852478376, 11.75243260449768, 11.846202894429886, 11.939480936001738, 12.032275656480733, 12.124595709131109, 12.216449484977723, 12.307845123924475, 12.398790525270183, 12.489293357661486, 12.579361068519368, 12.669000892973006, 12.758219862332208, 12.84702481212734, 12.935422389743527, 13.023419061673986, 13.111021120415508, 13.198234691027585, 13.285065737375026, 13.371520068072643, 13.457603342149287, 13.543321074447258, 13.628678640772181, 13.713681282807284, 13.798334112805241, 13.882642118069732, 13.966610165238242, 14.050243004376759], [0.0, 0.88774515638231, 1.3455700403680315, 1.7161729967934218, 2.0395028015858903, 2.331687336462908, 2.6012318422375857, 2.853298022733899, 3.091308183808104, 3.3176748233977786, 3.5341771237993345, 3.7421735302658328, 3.942730196613871, 4.136702824163083, 4.324791082249133, 4.50757609324486, 4.685547026387114, 4.8591204452947165, 5.028654692118473, 5.194460785501951, 5.356810815524722, 5.5159445063884744, 5.6720744145806234, 5.8253900950876165, 5.976061476288445, 6.12424162039599, 6.270069001314336, 6.413669399514744, 6.555157490061445, 6.694638182615903, 6.832207759337454, 6.967954846855372, 7.101961251058483, 7.234302677728816, 7.365049357602585, 7.494266590960878, 7.622015224104215, 7.748352067879088, 7.873330266673923, 7.996999624890588, 8.119406896752897, 8.24059604437981, 8.360608468285031, 8.479483213833207, 8.59725715665962, 8.713965169624627, 8.829640273509884, 8.94431377335745, 9.058015382094982, 9.170773332872004, 9.282614481346688, 9.393564399004578, 9.503647458455447, 9.61288691153837, 9.721304960965295, 9.828922826147013, 9.935760803770854, 10.041838323634511, 10.14717400018399, 10.251785680154315, 10.355690486668667, 10.458904860113629, 10.561444596075113, 10.663324880590196, 10.764560322944254, 10.865164986219927, 10.9651524157841, 11.06453566588121, 11.163327324485005, 11.261539536546715, 11.35918402576481, 11.456272114990018, 11.552814745369224, 11.648822494322504, 11.744305592439435, 11.839273939373335, 11.933737118805396, 12.02770441254463, 12.121184813824105, 12.214187039848941, 12.30671954364715, 12.398790525270183, 12.490407942386536, 12.58157952030818, 12.672312761486747, 12.762614954513388, 12.852493182653825, 12.941954331947674, 13.031005098899065, 13.119651997783569, 13.207901367594637, 13.295759378651182, 13.383232038886336, 13.470325199836058, 13.557044562345018, 13.643395682005908, 13.72938397434738, 13.815014719784623, 13.900293068345876, 13.985224044187122, 14.069812549906503, 14.154063370669304], [0.0, 0.894225098996915, 1.355391796739025, 1.7286999055081644, 2.0543898004296346, 2.348707085911109, 2.6202190853036846, 2.874125179397899, 3.1138726545811877, 3.3418916184036185, 3.559974239995829, 3.7694888803476454, 3.971509475481517, 4.166897972761232, 4.356359148638066, 4.54047836728736, 4.719748368552417, 4.89458875668633, 5.065360489496611, 5.23237685585376, 5.395911931911942, 5.5562071916983005, 5.713476743219658, 5.867911525086385, 6.019682706040358, 6.168944465545676, 6.315836288272794, 6.460484872805826, 6.6030057312598505, 6.743504539066304, 6.882078281179536, 7.01881623114361, 7.153800791975324, 7.287108222058002, 7.418809264765002, 7.548969697025548, 7.677650809277232, 7.80490982704752, 7.930800282643133, 8.055372344004578, 8.178673106630058, 8.30074685353244, 8.42163528742133, 8.54137773866628, 8.660011352069912, 8.77757125504101, 8.894090709390731, 9.009601248666883, 9.124132802681514, 9.237713810667154, 9.350371324310215, 9.462131101750893, 9.573017693502617, 9.683054521127255, 9.792263949401613, 9.900667352623918, 10.008285175633661, 10.115136990052997, 10.221241546200865, 10.326616821081453, 10.431280062805229, 10.535247831762538, 10.638536038836445, 10.741159980911888, 10.843134373912203, 10.94447338357107, 11.045190654127447, 11.145299335112975, 11.244812106385142, 11.343741201545159, 11.442098429866604, 11.53989519684941, 11.637142523503467, 11.733851064456907, 11.830031124975733, 11.925692676974071, 12.020845374087544, 12.115498565876127, 12.209661311217436, 12.303342390946332, 12.396550319792244, 12.489293357661486, 12.58157952030818, 12.67341658943388, 12.764812122253067, 12.85577346055871, 12.946307739319604, 13.036421894838824, 13.126122672500479, 13.215416634129966, 13.304310164991126, 13.392809480442054, 13.48092063226975, 13.568649514722452, 13.656001870257162, 13.742983295018663, 13.82959924406532, 13.915855036355808, 14.001755859510105, 14.087306774357153, 14.172512719280764, 14.257378514374714], [0.0, 0.900673887199084, 1.3651663318509693, 1.7411665870721653, 2.069205225228746, 2.365645007428817, 2.6391150410796507, 2.8948522027941883, 3.1363286393890903, 3.3659919833630267, 3.5856473282424717, 3.796672903080916, 4.000150388691196, 4.196947948451388, 4.38777544137427, 4.573222453043856, 4.753785276743061, 4.929886542740417, 5.101889811924533, 5.270110632477992, 5.434825057080862, 5.596276301172887, 5.754680016820871, 5.910228519606888, 6.063094212672255, 6.213432387360744, 6.3613835342495975, 6.5070752656216575, 6.650623926618455, 6.792135954759719, 6.931709034415894, 7.069433082935585, 7.205391097592676, 7.339659886714977, 7.472310703848321, 7.6034098002784285, 7.733018908444633, 7.8611956665616605, 7.987993992989486, 8.113464417459422, 8.237654375103283, 8.360608468285031, 8.482368700457279, 8.60297468562423, 8.722463836461731, 8.840871533703176, 8.958231279030386, 9.074574833398314, 9.189932342460658, 9.304332450542134, 9.417802404414934, 9.530368147976498, 9.642054408788583, 9.752884777319851, 9.862881779632795, 9.972066944168397, 10.080460863206028, 10.18808324951043, 10.294952988620226, 10.401088187182461, 10.506506217693966, 10.611223759971896, 10.715256839642144, 10.818620863904565, 10.921330654807758, 11.023400480242922, 11.124844082845724, 11.225674706976884, 11.325905123935875, 11.42554765554767, 11.524614196249534, 11.623116233793224, 11.721064868667687, 11.818470832337901, 11.915344504387262, 12.01169592864329, 12.107534828359707, 12.202870620521717, 12.297712429335883, 12.392069098960881, 12.485949205530908, 12.579361068519368, 12.672312761486747, 12.764812122253067, 12.856866762532375, 12.948484077063666, 13.03967125227023, 13.130435274476946, 13.22078293771289, 13.310720851124684, 13.400255446024094, 13.48939298259185, 13.578139556257991, 13.666501103777671, 13.754483409020162, 13.842092108487371, 13.929332696577328, 14.016210530606875, 14.102730835607003, 14.188898708903292, 14.274719124493176, 14.360196937230988], [0.0, 0.9070920390192546, 1.3748944308911808, 1.7535740429325655, 2.0839502661046487, 2.3825024616373796, 2.6579212274755055, 2.915480757922246, 3.158677942118569, 3.3899778542556356, 3.6111984508555808, 3.823727782155161, 4.028655236964276, 4.226855165144749, 4.419042484125041, 4.605810980843109, 4.787660485140087, 4.965016638924198, 5.138245593798639, 5.30766514652472, 5.47355331691849, 5.636155053559333, 5.79568754523864, 5.9523444779685795, 6.1062994834256275, 6.257708959550999, 6.4067143980499415, 6.553444320563299, 6.698015901301587, 6.8405363362523515, 6.9811040058794065, 7.119809468277363, 7.2567363121540405, 7.391961893169107, 7.525557972617182, 7.657591273886949, 7.7881239693196544, 7.917214107856726, 8.044915992077359, 8.17128051178491, 8.296355440131295, 8.420185697314428, 8.542813586101182, 8.66427900278294, 8.78461962663619, 8.90387109051545, 9.022067134833664, 9.13923974687257, 9.25541928710211, 9.370634603964863, 9.484913138391995, 9.59828101915571, 9.71076315002499, 9.822383289572858, 9.933164124381275, 10.043127336301682, 10.152293664352891, 10.260682961771703, 10.368314248674032, 10.47520576073388, 10.58137499424352, 10.686838747879554, 10.791613161465587, 10.895713751992323, 10.99915544712945, 11.101952616440363, 11.204119100489983, 11.305668238017606, 11.40661289133027, 11.506965470057585, 11.606737953395912, 11.705941910958089, 11.804588522334521, 11.90268859546201, 12.000252583888283, 12.097290603012613, 12.193812445376087, 12.289827595068816, 12.385345241315955, 12.480374291299155, 12.57492338226567, 12.669000892973006, 12.762614954513388, 12.85577346055871, 12.948484077063666, 13.040754251461747, 13.132591221386296, 13.224002022946351, 13.31499349858486, 13.405572304544854, 13.495744917967272, 13.585517643642541, 13.674896620436389, 13.763887827408958, 13.852497089645052, 13.940730083811975, 14.028592343460527, 14.116089264083495, 14.203226107945147, 14.290008008694322, 14.37643997577288, 14.462526898630575], [0.0, 0.9134800578945333, 1.384576856927622, 1.7659232463249395, 2.0986260796520937, 2.3992807708283554, 2.6766391196405332, 2.936012462877187, 3.1809223158394495, 3.413851112522983, 3.636629612054376, 3.850655639743619, 4.057026256208964, 4.256621968750707, 4.450162729463948, 4.638246506915417, 4.821376650900475, 4.999981800827518, 5.17443068685104, 5.345043343754097, 5.5120997492531005, 5.675846576930062, 5.836502545086099, 5.99426270372937, 6.1493019073035855, 6.301777655151979, 6.451832435407553, 6.5995956747997555, 6.745185372715637, 6.888709480049595, 7.030267070090683, 7.16994933867124, 7.30784046315627, 7.444018343967595, 7.578555247764763, 7.711518367822916, 7.842970314319898, 7.9729695449954905, 8.101570744844217, 8.22882516205096, 8.354780906200736, 8.479483213833205, 8.60297468562423, 8.725295498827046, 8.846483598067103, 8.966574867136352, 9.085603284058017, 9.203601061378032, 9.320598773374034, 9.436625471648133, 9.551708790378905, 9.66587504234534, 9.779149306696358, 9.891555509320101, 10.00311649656436, 10.113854102970793, 10.223789213608706, 10.33294182152745, 10.441331080788403, 10.548975355486741, 10.655892265128967, 10.762098726693088, 10.867610993664272, 10.972444692308605, 11.076614855420978, 11.180135953759637, 11.283021925358984, 11.385286202893784, 11.486941739251366, 11.588001031453741, 11.68847614305842, 11.788378725154987, 11.887720036063936, 11.986510959834852, 12.084762023632537, 12.182483414091992, 12.279684992716366, 12.376376310385625, 12.47256662103825, 12.568264894582986, 12.663479829093214, 12.758219862332208, 12.852493182653825, 12.946307739319604, 13.03967125227023, 13.132591221386296, 13.225074935270763, 13.317129479583098, 13.408761744952821, 13.499978434498255, 13.590786070974339, 13.681191003571762, 13.771199414388015, 13.86081732458961, 13.950050600283367, 14.038904958113418, 14.12738597059952, 14.215499071231159, 14.303249559331077, 14.390642604700831, 14.477683252060302, 14.564376425292242], [0.0, 0.9198384332443488, 1.3942143517814285, 1.7782151433861393, 2.1132337902616674, 2.415981220475481, 2.695270151650034, 2.9564488906999657, 3.2030634648091696, 3.4376135872198446, 3.6619427602526975, 3.8774585389298437, 4.08526562007695, 4.2862506398592695, 4.481138561675228, 4.670531516315527, 4.854936357195454, 5.034784707313713, 5.210447863410357, 5.382248087904674, 5.550467307327829, 5.7153539122596015, 5.8771281434131675, 6.0359864084630654, 6.192104778946008, 6.3456418504962, 6.496741103050488, 6.6455328642268725, 6.79213595475972, 6.936659076947138, 7.0792019936883746, 7.219856535594084, 7.358707465954794, 7.49583322742652, 7.6313065896886005, 7.7651952137221345, 7.897562145509784, 8.028466249692663, 8.15796259190603, 8.28610277705322, 8.412935249591152, 8.53850556093324, 8.662856608281896, 8.786028848548408, 8.908060490475837, 9.0289876676291, 9.148844594539067, 9.26766370797054, 9.38547579501667, 9.502310109496348, 9.61819447793879, 9.73315539627589, 9.847218118222663, 9.960406736205947, 10.072744255597968, 10.184252662922042, 10.294952988620228, 10.404865364905628, 10.514009079163504, 10.62240262331428, 10.730063739506909, 10.837009462471828, 10.943256158828323, 11.048819563610769, 11.153714814251432, 11.25795648223381, 11.361558602609481, 11.464534701552779, 11.566897822110983, 11.668660548292955, 11.769835027625891, 11.870432992298023, 11.970465778994585, 12.069944347524752, 12.168879298328775, 12.26728088894682, 12.365159049524074, 12.462523397420426, 12.559383250987382, 12.65574764256969, 12.7516253307846, 12.84702481212734, 12.941954331947674, 13.036421894838824, 13.130435274476946, 13.224002022946351, 13.317129479583098, 13.409824779367145, 13.502094860890969, 13.593946473930664, 13.685386186643504, 13.776420392414392, 13.867055316371973, 13.957297021593723, 14.047151415018133, 14.13662425308064, 14.22572114708912, 14.314447568353442, 14.40280885308285, 14.490810207063857, 14.578456710130654, 14.6657533204392], [0.0, 0.9261676410170553, 1.4038076368554062, 1.7904506542109782, 2.1277744913755523, 2.432605060670343, 2.7138157181069595, 2.976791571134212, 3.225103046376161, 3.461267057056991, 3.6871397902350713, 3.9041384860118358, 4.113375442391032, 4.315743396288114, 4.511972299416642, 4.702668425698049, 4.8883421160955, 5.069427963511477, 5.246299819497973, 5.419282163891747, 5.588658863098972, 5.754680016820871, 5.917567381198964, 6.077518715346188, 6.234711302309125, 6.3893048289839705, 6.541443762561744, 6.691259327416379, 6.838871161861818, 6.98438871615299, 7.127912439635907, 7.26953479478764, 7.409341128136446, 7.547410422085156, 7.6838159470254155, 7.818625829498783, 7.951903549293589, 8.08370837608571, 8.21409575440504, 8.343117644237008, 8.470822823374279, 8.597257156659618, 8.722463836461731, 8.846483598067103, 8.969354913124821, 9.09111416382699, 9.211795800127211, 9.33143248198059, 9.45005520831956, 9.567693434252158, 9.68437517777589, 9.800127117135379, 9.914974679810948, 10.028942124004171, 10.14205261338223, 10.254328285752916, 10.365790316264173, 10.476458975654475, 10.586353684021379, 10.69549306052418, 10.803894969391692, 10.911576562566623, 11.018554319283394, 11.124844082845724, 11.230461094843252, 11.335420027022678, 11.43973501100771, 11.543419666043336, 11.646487124923206, 11.748950058244004, 11.85082069711741, 11.952110854458287, 12.052831944957127, 12.152995003835168, 12.252610704471978, 12.35168937498762, 12.450241013854445, 12.548275304607301, 12.645801629715239, 12.742829083672603, 12.839366485362781, 12.935422389743527, 13.031005098899065, 13.126122672500479, 13.22078293771289, 13.31499349858486, 13.408761744952821, 13.502094860890969, 13.594999832734725, 13.687483456703923, 13.779552346149893, 13.871212938449027, 13.962471501563723, 14.053334140290174, 14.143806802211223, 14.233895283371087, 14.323605233687829, 14.41294216211821, 14.501911441588762, 14.590518313705886, 14.678767893256998, 14.766665172514054], [0.0, 0.9324681442092668, 1.4133574139211929, 1.8026306738561966, 2.142249246680646, 2.4491535074864217, 2.7322771756636395, 2.9970419922954217, 3.2470426727882757, 3.4848132523420436, 3.7122225452242175, 3.9306974326912316, 4.14135777945162, 4.3451023955025745, 4.5426661982495, 4.7346595859544, 4.921596371311392, 5.103914103657462, 5.281989177769817, 5.456148280846125, 5.626677210369742, 5.793827767412028, 5.95782321666999, 6.118862662565846, 6.277124594161537, 6.432769784666097, 6.585943684047269, 6.7367784093679, 6.885394412813576, 7.03190188920387, 7.176401971218347, 7.31898775033482, 7.459745153674138, 7.598753700938064, 7.736087160959684, 7.871814123729587, 8.005998500874346, 8.13869996526767, 8.2699743386157, 8.39987393437557, 8.528447862163931, 8.655742298831411, 8.781800730574366, 8.90666416979196, 9.030371349846973, 9.152958900431102, 9.274461505852978, 9.39491204824579, 9.514341737420501, 9.632780228861405, 9.750255731165929, 9.866795104064597, 9.98242394801497, 10.097166686241527, 10.211046639988496, 10.324086097662025, 10.436306378459673, 10.547727891017033, 10.658370187542072, 10.7682520138559, 10.877391355713526, 10.985805481738335, 11.093510983269155, 11.200523811388017, 11.306859311369546, 11.412532254768928, 11.517556869344025, 11.621946866988381, 11.725715469834988, 11.828875434675654, 11.93143907582747, 12.03341828656581, 12.13482455923266, 12.235669004119297, 12.33596236721381, 12.435715046896062, 12.534937109655688, 12.633638304902377, 12.731828078931928, 12.829515588106423, 12.92670971130206, 13.023419061673986, 13.119651997783569, 13.215416634129966, 13.310720851124684, 13.405572304544854, 13.499978434498255, 13.593946473930664, 13.687483456703923, 13.780596225270967, 13.873291437972217, 13.965575575976043, 14.057454949884333, 14.148935706022788, 14.240023832434279, 14.330725164592161, 14.421045390849578, 14.510990057639441, 14.600564574439057, 14.68977421851225, 14.778624139441154, 14.867119363458986], [0.0, 0.9387403933595694, 1.422864365867587, 1.8147560732949, 2.156659091242814, 2.4656277442758388, 2.7506558444684384, 3.0172016022577943, 3.2688839129119938, 3.5082538568245707, 3.7371928188465526, 3.9571372781544785, 4.169214632229461, 4.374329736916237, 4.573222453043856, 4.766507284719657, 4.954701500800043, 5.138245593798639, 5.317518490313001, 5.492849075002994, 5.6645250677694134, 5.832799963424114, 5.997898528454608, 6.160021206559477, 6.319347687407752, 6.476039825649833, 6.630244049623013, 6.782093365075868, 6.931709034415894, 7.079201993688374, 7.224674055842078, 7.368218938534864, 7.509923146876559, 7.649866735458384, 7.788123969319655, 7.924763899821693, 8.059850868492777, 8.193444949596337, 8.325602340323353, 8.456375706017553, 8.585814486631536, 8.713965169624625, 8.840871533703174, 8.966574867136352, 9.091114163826989, 9.214526299856491, 9.336846192837571, 9.458106946085165, 9.578339979343102, 9.69757514757336, 9.815840849118562, 9.933164124381273, 10.04957074602059, 10.165085301543872, 10.279731269065747, 10.393531086915383, 10.506506217693966, 10.618677207315828, 10.730063739506907, 10.840684686182122, 10.950558154077708, 11.059701527974482, 11.168131510812954, 11.27586416097014, 11.3829149269407, 11.489298679640715, 11.595029742531091, 11.70012191973846, 11.804588522334523, 11.908442392919675, 12.01169592864329, 12.11436110278089, 12.216449484977723, 12.317972260258465, 12.418940246894122, 12.519363913209283, 12.619253393405849, 12.718618502472932, 12.817468750246869, 12.915813354680028, 13.013661254372389, 13.111021120415508, 13.207901367594637, 13.304310164991126, 13.400255446024094, 13.495744917967272, 13.590786070974339, 13.685386186643504, 13.779552346149893, 13.873291437972217, 13.966610165238242, 14.05951505271193, 14.152012453443447, 14.244108555101771, 14.335809386008354, 14.427120820888877, 14.518048586359205, 14.608598266160344, 14.698775306156461, 14.78858501910891, 14.878032589238499, 14.967123076587415], [0.0, 0.9449848270181492, 1.4323291574123718, 1.826827700324434, 2.1710050325858115, 2.4820289229028534, 2.7689530095418378, 3.0372718105636625, 3.2906282938677616, 3.531590509451179, 3.762052357001815, 3.983459871052496, 4.196947948451388, 4.403427464079304, 4.603643200266376, 4.79821374875712, 4.9876598192432136, 5.172424834362837, 5.352890241306049, 5.529387112449849, 5.702205081587142, 5.87159932975906, 6.037796118583643, 6.200997225096555, 6.3613835342495975, 6.51911797733868, 6.6743479567318715, 6.827207362922437, 6.977818264946692, 7.1262923367885245, 7.272732068649128, 7.417231801589483, 7.5598786161451965, 7.70075309942488, 7.839930010473553, 7.977478859977232, 8.11346441745942, 8.247947156793234, 8.38098364898933, 8.512626909717516, 8.642926707801406, 8.771929839931566, 8.899680376027156, 9.026219879003946, 9.151587602149407, 9.27582066684199, 9.398954222963857, 9.521021594030818, 9.642054408788582, 9.762082720792188, 9.881135117287995, 9.999238818549383, 10.116419768673325, 10.232702718721512, 10.348111302983305, 10.462668109046026, 10.576394742278545, 10.689311885265134, 10.801439352666465, 10.91279614193208, 11.023400480242922, 11.133269868022122, 11.242421119316946, 11.350870399323588, 11.458633259298976, 11.565724669079463, 11.672159047404586, 11.777950290225036, 11.883111797156804, 11.987656496228345, 12.091596867053976, 12.19494496255459, 12.297712429335881, 12.39991052682451, 12.501550145253841, 12.602641822583008, 12.703195760425894, 12.803221839060216, 12.902729631581055, 13.001728417257937, 13.100227194149769, 13.198234691027585, 13.295759378651182, 13.392809480442054, 13.48939298259185, 13.585517643642541, 13.681191003571762, 13.776420392414392, 13.871212938449027, 13.965575575976043, 14.05951505271193, 14.153037936822912, 14.246150623619185, 14.33885934192966, 14.43117016017575, 14.523088992161389, 14.614621602595477, 14.705773612361668, 14.796550503549621, 14.886957624260802, 14.97700019320108, 15.066683304071681], [0.0, 0.9512018721937607, 1.4417524357797895, 1.838846380430456, 2.185288051718146, 2.4983581649178315, 2.787169922086124, 3.0572539896600928, 3.312277302586426, 3.554824806035919, 3.7868028596424748, 4.009667011384807, 4.224559624585433, 4.432397566761369, 4.633930520157812, 4.829781146227821, 5.0204735804066205, 5.206454162605237, 5.388106849550756, 5.565764891741838, 5.739719828469049, 5.910228519606889, 6.077518715346189, 6.241793520211594, 6.4032350091950905, 6.562007185515858, 6.718258421300585, 6.872123487906675, 7.023725257461343, 7.173176138650433, 7.320579295957087, 7.46602969111113, 7.609614977550089, 7.7514162725643105, 7.8915088270377804, 8.029962608966581, 8.166842813992229, 8.302210313844807, 8.436122051715058, 8.568631392062313, 8.699788431138758, 8.829640273509884, 8.958231279030388, 9.085603284058017, 9.211795800127211, 9.336846192837573, 9.46078984332197, 9.583660294331269, 9.705489382696362, 9.826307359694306, 9.946143000646657, 10.06502370490868, 10.182975587263293, 10.300023561609155, 10.416191417725368, 10.531501891802753, 10.64597673135167, 10.759636755026898, 10.87250190784955, 10.984591312253189, 11.095923315335185, 11.206515532653771, 11.316384888875652, 11.425547655547673, 11.53401948623832, 11.64181544927034, 11.748950058244006, 11.85543730053132, 11.961290663904204, 12.066523161444476, 12.171147354869706, 12.275175376396824, 12.37861894925442, 12.481489406944803, 12.583797711348067, 12.685554469752468, 12.786769950888202, 12.887454100035221, 12.987616553269904, 13.087266650909992, 13.186413450212523, 13.285065737375026, 13.383232038886336, 13.48092063226975, 13.578139556257991, 13.674896620436389, 13.771199414388015, 13.867055316371973, 13.962471501563723, 14.057454949884333, 14.152012453443447, 14.246150623619185, 14.339875897796425, 14.433194545783472, 14.526112675925821, 14.618636240934263, 14.710771043443653, 14.802522741317377, 14.89389685271171, 14.984898760913218, 15.07553371896158, 15.165806854069428], [0.0, 0.9573919447793617, 1.4511348313456869, 1.8508129176097643, 2.1995091041109305, 2.51461656267519, 2.8053078007325642, 3.0771494762669143, 3.3338323872913813, 3.577958300850966, 3.8114459824682188, 4.035760452293748, 4.252051507731198, 4.46124198293479, 4.6640864388065575, 4.861211588851705, 5.053144979386457, 5.24033585493812, 5.423170670883205, 5.601984846392279, 5.77707181798658, 5.9486901170903765, 6.117068976009131, 6.282412820997173, 6.444904911923694, 6.604710319280616, 6.76197838074596, 6.916844744719647, 7.069433082935586, 7.219856535594083, 7.368218938534864, 7.514615871463828, 7.6591355582348974, 7.801859644019963, 7.942863869408138, 8.08221865772154, 8.219989628870984, 8.356238050717424, 8.491021237016986, 8.624392899505311, 8.756403460442602, 8.887100330933572, 9.016528159510564, 9.144729054786987, 9.271742785423836, 9.397606960182324, 9.52235719044274, 9.64602723723986, 9.768649144586982, 9.890253360625373, 10.01086884793581, 10.130523184178513, 10.24924265408181, 10.367052333674874, 10.483976167551955, 10.600037039862652, 10.715256839642144, 10.829656521025372, 10.943256158828321, 11.056074999926334, 11.168131510812954, 11.279443421682002, 11.390027767339697, 11.499900925222143, 11.609078650765499, 11.717576110351624, 11.825407912029975, 11.932588134197237, 12.0391303523988, 12.14504766440084, 12.250352713667974, 12.355057711369144, 12.459174457023408, 12.562714357887351, 12.665688447176958, 12.76810740120882, 12.869981555538256, 12.971320920165459, 13.072135193874848, 13.172433777767525, 13.272225788041832, 13.371520068072643, 13.470325199836058, 13.568649514722452, 13.666501103777671, 13.763887827408958, 13.86081732458961, 13.957297021593723, 14.053334140290174, 14.148935706022788, 14.244108555101771, 14.33885934192966, 14.433194545783472, 14.527120477273126, 14.620643284494982, 14.713768958897887, 14.806503340878118, 14.898852125118358, 14.990820865685016, 15.08241498089711, 15.173639757979172, 15.264500357509856], [0.0, 0.9635554499576546, 1.4604769582521981, 1.862728095154284, 2.213669120629572, 2.530805180398563, 2.8233678327297054, 3.0969595726801686, 3.3552949589107475, 3.600992508142206, 3.835983338540439, 4.061741901773976, 4.279425397420973, 4.4899626006644215, 4.694112930124295, 4.892507133966793, 5.085676154749845, 5.27407212915061, 5.458084000470972, 5.638049347245599, 5.814263495083608, 5.986986639784847, 6.156449489408265, 6.322857786265096, 6.486395970016314, 6.6472301738459185, 6.805510696839175, 6.9613740606743075, 7.114944733260062, 7.266336583171589, 7.415654114723777, 7.562993522946288, 7.708443599661241, 7.852086515656441, 7.993998499124347, 8.134250426758873, 8.2729083409192, 8.410033903896986, 8.545684798423292, 8.679915082019583, 8.812775501554874, 8.944313773357448, 9.074574833398314, 9.203601061378032, 9.33143248198059, 9.458106946085165, 9.583660294331267, 9.708126505100719, 9.83153782870001, 9.953924909289688, 10.075316895906052, 10.19574154374899, 10.315225306762862, 10.433793422411489, 10.551469989439811, 10.668278039321184, 10.784239602008181, 10.899375766534437, 11.01370673695374, 11.12725188404911, 11.240029793197829, 11.352058308737293, 11.463354575140526, 11.573935075278415, 11.683815666017589, 11.793011611378153, 11.901537613453378, 12.009407841273957, 12.116635957782032, 12.223235145064676, 12.329218127982701, 12.434597196318206, 12.539384225553283, 12.643590696382237, 12.74722771305078, 12.850306020607572, 12.952836021146254, 13.054827789109467, 13.156291085720545, 13.257235372603066, 13.357669824643708, 13.457603342149287, 13.557044562345018, 13.656001870257162, 13.754483409020162, 13.852497089645052, 13.950050600283367, 14.047151415018133, 14.143806802211223, 14.240023832434279, 14.335809386008354, 14.43117016017575, 14.526112675925821, 14.620643284494982, 14.714768173559852, 14.808493373141076, 14.901824761234277, 14.99476806918341, 15.087328886810894, 15.179512667317843, 15.271324731966926, 15.362770274559605], [0.0, 0.9696927825876808, 1.4697794149937136, 1.8745926763984242, 2.2277690084219333, 2.5469250551962013, 2.841351175076157, 3.1166855480146625, 3.3766663924235667, 3.623928903574012, 3.860416499821292, 4.087613024302105, 4.306683047336718, 4.518561259909061, 4.724011917729363, 4.923669786492136, 5.1180691905753015, 5.30766514652472, 5.492849075002994, 5.673960704739418, 5.851297242409219, 6.025120541120257, 6.195662778418372, 6.363131007083227, 6.52771084155775, 6.689569473205422, 6.848858158436261, 7.00571428849853, 7.160263124094952, 7.312619259082571, 7.462887863412845, 7.611165744826298, 7.757542260701449, 7.902100105210051, 8.044915992077359, 8.186061249443904, 8.325602340323353, 8.463601319763173, 8.60011623790255, 8.735201496580443, 8.868908165896261, 9.00128426610577, 9.132375019398069, 9.262223075409732, 9.390868713760568, 9.518350026419604, 9.644703082312041, 9.769962076243814, 9.894159463938614, 10.017326084743885, 10.139491273359695, 10.260682961771703, 10.380927772421739, 10.500251103522764, 10.61867720731583, 10.736229261972452, 10.852929437764217, 10.968798958050614, 11.083858155574447, 11.198126524500259, 11.311622768584238, 11.42436484582266, 11.536370009889675, 11.64765484864323, 11.758235319949712, 11.868126785052867, 11.977344039690436, 12.085901343142252, 12.193812445376087, 12.301090612441861, 12.407748650250934, 12.513798926864744, 12.619253393405849, 12.724123603694434, 12.828420732704311, 12.932155593924355, 13.035338655703976, 13.137980056654623, 13.2400896201734, 13.341676868149365, 13.442751033908314, 13.543321074447258, 13.643395682005908, 13.742983295018663, 13.842092108487371, 13.940730083811975, 14.038904958113418, 14.13662425308064, 14.233895283371087, 14.330725164592161, 14.427120820888877, 14.523088992161389, 14.618636240934263, 14.713768958897887, 14.808493373141076, 14.902815552092477, 14.996741411187399, 15.09027671827539, 15.183427098783051, 15.276198040645466, 15.368594899018904, 15.460622900786557], [0.0, 0.9758043275735478, 1.4790427849757657, 1.8864074054318951, 2.241809651765445, 2.5629771980294453, 2.8592589556010206, 3.136328639389091, 3.3979480281437917, 3.646768925607252, 3.884746998641632, 4.113375442391032, 4.333826166947686, 4.547039754239644, 4.753785276743061, 4.954701500800043, 5.150326118398886, 5.34111701385361, 5.5274680747782385, 5.709721171062082, 5.888175382542669, 6.063094212672256, 6.234711302309125, 6.4032350091950905, 6.568852117618866, 6.7317308726772, 6.892023484082398, 7.049868208999036, 7.205391097592676, 7.358707465954793, 7.509923146876559, 7.6591355582348974, 7.806434620588386, 7.951903549293589, 8.095619541568464, 8.237654375103283, 8.37807493179871, 8.516943657807747, 8.65431896913395, 8.790255610487016, 8.924804973838624, 9.058015382094982, 9.189932342460658, 9.320598773374035, 9.45005520831956, 9.578339979343104, 9.705489382696362, 9.831537828700013, 9.956517977631828, 10.080460863206028, 10.203396005006331, 10.325351511061353, 10.446354171602405, 10.566429544916161, 10.68560203609483, 10.803894969391694, 10.921330654807761, 11.037930449463975, 11.153714814251432, 11.268703366197775, 11.382914926940702, 11.496367567657801, 11.6090786507655, 11.721064868667689, 11.832342279806129, 11.9429263422397, 12.052831944957129, 12.162073437108194, 12.270664655320637, 12.37861894925442, 12.48594920553091, 12.592667870161963, 12.698786969592781, 12.804318130462173, 12.909272598174871, 13.013661254372389, 13.117494633381517, 13.220782937712892, 13.323536052676145, 13.425763560172594, 13.527474751721604, 13.628678640772181, 13.72938397434738, 13.82959924406532, 13.929332696577328, 14.028592343460527, 14.12738597059952, 14.22572114708912, 14.323605233687829, 14.421045390849578, 14.518048586359205, 14.614621602595477, 14.710771043443653, 14.806503340878118, 14.901824761234277, 14.996741411187399, 15.091259243455166, 15.185384062239338, 15.279121528421086, 15.372477164523527, 15.465456359454109, 15.558064373038766], [0.0, 0.9818904602162896, 1.4882676370483492, 1.8981730077799166, 2.255791912875467, 2.578962594636896, 2.87709227399489, 3.155890053056948, 3.4191411729455266, 3.6695139768142537, 3.9089763291017836, 4.139030738073148, 4.360856423073129, 4.57539983247883, 4.783434835503796, 4.98560418250268, 5.182448919071329, 5.374429785367495, 5.561943125698819, 5.745332942211493, 5.924900180116576, 6.100909986348441, 6.2735974589932315, 6.443172255328764, 6.6098223246252195, 6.77371696133109, 6.935009324497063, 7.093838533603465, 7.250331424996045, 7.40460403399759, 7.556762853482842, 7.706905908928125, 7.855123681730319, 8.001499906263673, 8.146112261228435, 8.289032971995354, 8.430329337610324, 8.570064193705626, 8.70829632062789, 8.845080804531872, 8.980469357923136, 9.114510605099893, 9.247250337097059, 9.378731740037123, 9.508995600213579, 9.638080488750882, 9.766022928281973, 9.892857543746153, 10.018617199124716, 10.143333121690468, 10.267035015142007, 10.389751162818909, 10.511508522044286, 10.632332810512919, 10.752248585532604, 10.871279316830972, 10.989447453557448, 11.106774486038235, 11.22328100277987, 11.338986743162222, 11.453910646214332, 11.568070895824487, 11.681484962699237, 11.794169643353692, 11.906141096386797, 12.017414876269987, 12.128005964855246, 12.2379288007886, 12.347197306997419, 12.455824916404058, 12.563824596004281, 12.671208869436246, 12.7779898381546, 12.884179201313984, 12.989788274457196, 13.094828007095003, 13.199308999257237, 13.30324151708802, 13.406635507552078, 13.509500612313449, 13.611846180843097, 13.713681282807284, 13.815014719784623, 13.915855036355808, 14.016210530606875, 14.116089264083495, 14.215499071231159, 14.314447568353442, 14.41294216211821, 14.510990057639441, 14.608598266160344, 14.705773612361668, 14.802522741317377, 14.898852125118358, 14.99476806918341, 15.09027671827539, 15.185384062239338, 15.280095941478056, 15.374418052179875, 15.468355951312116, 15.561915061393076, 15.655100675054438], [0.0, 0.9879515465497973, 1.4974545260150967, 1.9098901910526351, 2.269716632677058, 2.5948822064167456, 2.8948522027941883, 3.175370965486246, 3.440247101432813, 3.692165425134248, 3.933105948408916, 4.164580454316423, 4.38777544137427, 4.603643200266376, 4.812962377203621, 5.01637969015777, 5.214439524531093, 5.407605464572396, 5.596276301172888, 5.780798159960752, 5.961473843843986, 6.138570136475647, 6.312323587172801, 6.482945147401274, 6.650623926618455, 6.8155302643061795, 6.977818264946692, 7.137627906787378, 7.295086809118796, 7.450311723535192, 7.603409800278429, 7.754479669923771, 7.903612372398382, 8.05089215895827, 8.196397187804537, 8.34020013014606, 8.482368700457279, 8.622966122246932, 8.762051538705338, 8.899680376027158, 9.035904665932751, 9.170773332872004, 9.304332450542134, 9.436625471648135, 9.567693434252158, 9.69757514757336, 9.826307359694306, 9.95392490928969, 10.080460863206028, 10.205946641478155, 10.330412131161868, 10.453885790186238, 10.576394742278545, 10.697964863885666, 10.818620863904565, 10.938386356938558, 11.057283930712838, 11.175335208210697, 11.292560905028928, 11.408980882396111, 11.524614196249534, 11.639479142724337, 11.753593300371543, 11.866973569389044, 11.979636208120777, 12.091596867053978, 12.202870620521718, 12.313471996297967, 12.423415003254577, 12.532713157233644, 12.641379505274564, 12.74942664832234, 12.856866762532377, 12.963711619276724, 13.069972603947605, 13.175660733645739, 13.280786673833605, 13.38536075402695, 13.489392982591854, 13.59289306070914, 13.695870395562878, 13.798334112805241, 13.900293068345876, 14.001755859510105, 14.102730835607003, 14.203226107945147, 14.303249559331077, 14.40280885308285, 14.501911441588762, 14.600564574439057, 14.698775306156461, 14.796550503549621, 14.89389685271171, 14.990820865685016, 15.087328886810894, 15.183427098783051, 15.279121528421086, 15.374418052179875, 15.469322401409599, 15.563840167380047, 15.657976806082031, 15.751737642817991], [0.0, 0.9939879436616984, 1.5066039931196407, 1.9215596455654402, 2.283584631542157, 2.6107369712695765, 2.9125397883213866, 3.194772524390845, 3.4612670570569914, 3.7147246050725506, 3.9571372781544785, 4.190026096377015, 4.414584807779414, 4.631771521554358, 4.842369641451449, 5.047029836897877, 5.246299819497973, 5.440646006006479, 5.630469623932262, 5.816118913735705, 5.997898528454609, 6.176076881793704, 6.3508919683895355, 6.522556028624196, 6.69125932741638, 6.8571732450244225, 7.020452827511013, 7.18123890839249, 7.339659886714978, 7.49583322742652, 7.649866735458385, 7.801859644019964, 7.95190354929359, 8.10008321731157, 8.246477283822651, 8.391158864057768, 8.5341960862277, 8.675652560137669, 8.81558779034367, 8.954057541695157, 9.091114163826989, 9.226806880118097, 9.3611820457766, 9.494283379004097, 9.626152168605852, 9.75682746092586, 9.886346228577965, 10.014743523101624, 10.142052613382232, 10.268305111431449, 10.393531086915383, 10.517759171641432, 10.64101665506321, 10.76332957173303, 10.884722781519544, 11.00522004331161, 11.124844082845724, 11.243616655221894, 11.361558602609481, 11.478689907589441, 11.595029742531093, 11.710596515359201, 11.825407912029977, 11.93948093600174, 12.052831944957127, 12.165476685008064, 12.277430322591991, 12.388707474247777, 12.499322234441664, 12.609288201597721, 12.718618502472934, 12.827325815004244, 12.935422389743529, 13.04292006998608, 13.149830310689014, 13.256164196267687, 13.361932457350695, 13.46714548656726, 13.571813353434719, 13.675945818408232, 13.779552346149893, 13.882642118069732, 13.985224044187122, 14.087306774357153, 14.188898708903292, 14.290008008694322, 14.390642604700831, 14.490810207063857, 14.590518313705886, 14.68977421851225, 14.78858501910891, 14.886957624260802, 14.984898760913218, 15.08241498089711, 15.179512667317843, 15.276198040645466, 15.372477164523527, 15.468355951312116, 15.563840167380047, 15.658935438159835, 15.753647252978471, 15.847980969676062], [0.0, 1.0, 1.5157165665103982, 1.933182044931763, 2.29739670999407, 2.6265278044037674, 2.930156051583522, 3.2140958497160392, 3.4822022531844974, 3.7371928188465526, 3.981071705534973, 4.215369133091901, 4.441286069845841, 4.659786420036067, 4.871658325766916, 5.077556391987409, 5.278031643091579, 5.4735533169184905, 5.6645250677694134, 5.851297242409219, 6.034176336545165, 6.213432387360744, 6.38930482898397, 6.562007185515857, 6.731730872677199, 6.898648307306075, 7.0629154732488475, 7.224674055842078, 7.384053230743224, 7.541171173377642, 7.69613634072608, 7.849048566202036, 8.000000000000004, 8.149075920852834, 8.296355440131295, 8.44191211529793, 8.585814486631534, 8.728126548676135, 8.868908165896261, 9.008215440430583, 9.14610103854653, 9.282614481346688, 9.417802404414934, 9.551708790378907, 9.68437517777589, 9.815840849118564, 9.946143000646657, 10.075316895906052, 10.203396005006331, 10.330412131161868, 10.456395525912734, 10.58137499424352, 10.705377990665907, 10.828430707200111, 10.950558154077708, 11.071784233891284, 11.192131809832134, 11.311622768584236, 11.43027807837915, 11.548117842660865, 11.665161349761235, 11.781427118943887, 11.896932943137113, 12.011695928643292, 12.12573253208319, 12.239058594807823, 12.351689374987618, 12.463639577568404, 12.57492338226567, 12.685554469752466, 12.795546046181911, 12.904910866172433, 13.013661254372387, 13.12180912571029, 13.229366004427645, 13.336343041983005, 13.442751033908314, 13.548600435691776, 13.653901377755398, 13.75866367958967, 13.862896863102934, 13.966610165238242, 14.069812549906503, 14.172512719280764, 14.274719124493176, 14.37643997577288, 14.477683252060302, 14.578456710130654, 14.678767893256998, 14.778624139441154, 14.878032589238499, 14.97700019320108, 15.07553371896158, 15.173639757979172, 15.271324731966926, 15.368594899018904, 15.465456359454109, 15.561915061393076, 15.657976806082031, 15.753647252978471, 15.84893192461114, 15.94383621122661], [0.0, 1.0059880556662684, 1.5247927616849475, 1.944758046629845, 2.3111536493810165, 2.642255599105539, 2.9477019891312572, 3.2333420345808612, 3.5030538741177715, 3.759571337481384, 4.004910584519123, 4.240610998114725, 4.467880738061901, 4.687689480512164, 4.900830087008648, 5.107961082311246, 5.309636790378737, 5.506329258872486, 5.698444559198189, 5.886335136016648, 6.070309320348477, 6.250638766374856, 6.427564341968684, 6.601300849825179, 6.772040851873127, 6.939957797392233, 7.105208604268809, 7.267935806259105, 7.428269352531604, 7.5863281261526865, 7.7422212335495395, 7.896049105943698, 8.04790444533015, 8.197873041095548, 8.34603447833395, 8.49246275497408, 8.637226821717737, 8.780391056311842, 8.92201568169267, 9.06215713594162, 9.200868400694661, 9.3381992935895, 9.474196729466486, 9.60890495432368, 9.74236575543344, 9.874618650534316, 10.005701058599195, 10.135648454334033, 10.264494508269289, 10.39227121405876, 10.51900900439042, 10.644736856734712, 10.769482390002459, 10.893271953053155, 11.016130705881034, 11.138082694208737, 11.25915091813362, 11.379357395398348, 11.498723219793412, 11.617268615143345, 11.735012985279608, 11.851974960360208, 11.968172439858481, 12.083622632510297, 12.198342093479583, 12.312346758976252, 12.4256519785375, 12.538272545163188, 12.650222723477738, 12.761516276074824, 12.87216648818675, 12.982186190807305, 13.09158778238553, 13.200383249197191, 13.308584184491595, 13.41620180650285, 13.523246975407144, 13.629730209300728, 13.735661699267135, 13.841051323596519, 13.945908661214931, 14.050243004376759, 14.154063370669304, 14.257378514374714, 14.360196937230988, 14.462526898630575, 14.564376425292242, 14.6657533204392, 14.766665172514054, 14.867119363458986, 14.967123076587415, 15.066683304071681, 15.165806854069428, 15.264500357509856, 15.362770274559605, 15.460622900786557, 15.558064373038766, 15.655100675054438, 15.751737642817991, 15.847980969676062, 15.94383621122661, 16.0393087899933]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 1.3000000000000003\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0501187233627272, 0.07864470671456425, 0.1023596555010966, 0.12340677254400187, 0.14266929093832773, 0.16061951594470014, 0.17754715843916347, 0.19364598262157046, 0.2090535905807846, 0.2238721138568339, 0.23817997500752824, 0.2520390360441707, 0.2654991768869938, 0.2786013542762451, 0.2913797178220523, 0.30386311717294945, 0.3160762025186194, 0.32804024555580313, 0.339773763461353, 0.3512930009892054, 0.36261230840821784, 0.3737444416567044, 0.38470080351818003, 0.39549163945896465, 0.4061261981781177, 0.4166128643804238, 0.4269592694579762, 0.43717238443528167, 0.44725859854989114, 0.45722378610564934, 0.4670733636800189, 0.4768123393424665, 0.4864453552135282, 0.49597672443940344, 0.505410463457025, 0.514750320266457, 0.523999799301531, 0.5331621833886192, 0.5422405532018842, 0.5512378045571162, 0.5601566638321537, 0.56899970175744, 0.5777693457835779, 0.5864678912023005, 0.5950975111719019, 0.6036602657769329, 0.6121581102340997, 0.6205929023412377, 0.6289664092534478, 0.637280313659631, 0.6455362194233716, 0.6537356567441923, 0.6618800868883777, 0.669970906532684, 0.6780094517591799, 0.685997001735054, 0.6939347821074004, 0.7018239681396626, 0.7096656876134977, 0.7174610235172757, 0.7252110165401895, 0.7329166673889772, 0.7405789389425276, 0.7481987582580971, 0.7557770184415148, 0.7633145803925411, 0.7708122744354743, 0.7782709018441495, 0.7856912362696148, 0.7930740250780174, 0.8004199906055426, 0.8077298313366432, 0.8150042230112483, 0.8222438196661404, 0.8294492546152544, 0.8366211413732437, 0.8437600745262979, 0.8508666305538709, 0.8579413686046796, 0.864984831230061, 0.871997545077537, 0.8789800215472077, 0.8859327574133933, 0.8928562354137626, 0.8997509248080118, 0.9066172819080086, 0.9134557505811726, 0.9202667627287333, 0.927050738740395, 0.9338080879268165, 0.9405392089312294, 0.9472444901214154, 0.9539243099631818, 0.9605790373764018, 0.9672090320746062, 0.9738146448890527, 0.9803962180781365, 0.98695408562295, 0.9934885735097438, 1.0, 1.0064886758887739], [0.0, 0.07864470671456425, 0.12340677254400187, 0.16061951594470014, 0.19364598262157046, 0.2238721138568339, 0.2520390360441707, 0.2786013542762451, 0.3038631171729495, 0.32804024555580313, 0.3512930009892054, 0.3737444416567044, 0.39549163945896465, 0.4166128643804238, 0.43717238443528167, 0.4572237861056494, 0.4768123393424665, 0.49597672443940344, 0.5147503202664568, 0.5331621833886192, 0.5512378045571162, 0.56899970175744, 0.5864678912023004, 0.6036602657769329, 0.6205929023412375, 0.637280313659631, 0.6537356567441924, 0.669970906532684, 0.6859970017350541, 0.7018239681396627, 0.7174610235172757, 0.7329166673889773, 0.748198758258097, 0.7633145803925411, 0.7782709018441494, 0.7930740250780175, 0.8077298313366433, 0.8222438196661404, 0.8366211413732437, 0.8508666305538709, 0.864984831230061, 0.8789800215472076, 0.8928562354137625, 0.9066172819080087, 0.9202667627287333, 0.9338080879268164, 0.9472444901214154, 0.9605790373764017, 0.9738146448890526, 0.9869540856229498, 0.9999999999999999, 1.01295490475193, 1.025821201019164, 1.0386011817742817, 1.0512970386380283, 1.0639108681478935, 1.0764446775323462, 1.0889003900378262, 1.1012798498503504, 1.113584826649027, 1.1258170198247626, 1.1379780623939404, 1.1500695246337473, 1.1620929174631118, 1.1740496955907964, 1.1859412604500639, 1.1977689629374375, 1.2095341059713987, 1.2212379468853654, 1.2328816996679572, 1.2444665370623629, 1.2559935925355508, 1.2674639621271098, 1.2788787061866451, 1.2902388510078748, 1.3015453903668834, 1.312799286971353, 1.3240014738270212, 1.3351528555271135, 1.3462543094700126, 1.3573066870100212, 1.3683108145456813, 1.3792674945497652, 1.3901775065447362, 1.4010416080271917, 1.4118605353445224, 1.4226350045267984, 1.4333657120766574, 1.444053335719773, 1.4546985351182984, 1.4653019525495021, 1.4758642135516644, 1.4863859275391569, 1.496867688388487, 1.507310074996987, 1.5177136518156886, 1.5280789693578443, 1.5384065646844416, 1.5486969618679896, 1.5589506724357443, 1.5691681957935018, 1.5793500196309778], [0.0, 0.1023596555010966, 0.16061951594470014, 0.20905359058078463, 0.25203903604417066, 0.2913797178220523, 0.3280402455558032, 0.3626123084082179, 0.39549163945896465, 0.4269592694579762, 0.4572237861056494, 0.48644535521352833, 0.514750320266457, 0.5422405532018842, 0.56899970175744, 0.595097511171902, 0.6205929023412375, 0.6455362194233717, 0.669970906532684, 0.6939347821074004, 0.7174610235172757, 0.7405789389425276, 0.7633145803925412, 0.7856912362696148, 0.8077298313366433, 0.8294492546152545, 0.8508666305538709, 0.8719975450775371, 0.8928562354137627, 0.9134557505811727, 0.9338080879268165, 0.9539243099631819, 0.9738146448890524, 0.9934885735097438, 1.01295490475193, 1.032221841560004, 1.0512970386380285, 1.0701876532441241, 1.0889003900378262, 1.107441540814393, 1.1258170198247626, 1.144032395269352, 1.1620929174631116, 1.1800035440943222, 1.1977689629374375, 1.2153936123284614, 1.2328816996679575, 1.250237218180314, 1.2674639621271102, 1.284565540646313, 1.3015453903668837, 1.3184067869294, 1.3351528555271135, 1.3517865805679143, 1.3683108145456813, 1.3847282861991201, 1.401041608027192, 1.4172532832224345, 1.4333657120766574, 1.4493811979075462, 1.4653019525495021, 1.4811301014474711, 1.4968676883884868, 1.5125166799021166, 1.528078969357844, 1.5435563807846724, 1.5589506724357445, 1.5742635401186036, 1.5894966203097645, 1.6046514930705182, 1.619729684779357, 1.6347326706949878, 1.649661877362686, 1.6645186848755922, 1.6793044290015637, 1.6940204031852835, 1.708667860434496, 1.7232480150985197, 1.7377620445464963, 1.752211090752247, 1.7665962617920397, 1.7809186332610873, 1.7951792496141277, 1.8093791254350295, 1.8235192466399976, 1.8376005716185837, 1.851624032316425, 1.8655905352633193, 1.8795009625499923, 1.8933561727566797, 1.9071570018363986, 1.9209042639556149, 1.9345987522947943, 1.9482412398111681, 1.96183247996589, 1.9753732074175991, 1.9888641386842805, 2.002305972775188, 2.015699391794479, 2.0290450615180964, 2.042343631945352, 2.0555957378265464], [0.0, 0.12340677254400187, 0.19364598262157046, 0.25203903604417066, 0.3038631171729495, 0.3512930009892054, 0.39549163945896465, 0.4371723844352817, 0.47681233934246653, 0.5147503202664568, 0.5512378045571162, 0.5864678912023005, 0.6205929023412377, 0.6537356567441924, 0.6859970017350541, 0.7174610235172758, 0.748198758258097, 0.7782709018441495, 0.8077298313366432, 0.8366211413732437, 0.8649848312300609, 0.8928562354137626, 0.9202667627287333, 0.9472444901214154, 0.9738146448890526, 1.0, 1.0258212010191643, 1.0512970386380285, 1.0764446775323464, 1.1012798498503507, 1.1258170198247626, 1.1500695246337473, 1.1740496955907964, 1.1977689629374375, 1.2212379468853654, 1.2444665370623629, 1.26746396212711, 1.2902388510078748, 1.312799286971353, 1.3351528555271137, 1.3573066870100212, 1.379267494549765, 1.4010416080271917, 1.4226350045267986, 1.444053335719773, 1.4653019525495021, 1.4863859275391569, 1.507310074996987, 1.528078969357844, 1.5486969618679893, 1.5691681957935015, 1.5894966203097642, 1.609686003209965, 1.6297399425537484, 1.649661877362686, 1.6694550974567282, 1.6891227525149495, 1.708667860434496, 1.7280933150534128, 1.7474018932958728, 1.7665962617920394, 1.7856789830192843, 1.8046525210066273, 1.8235192466399979, 1.84228144260212, 1.860941307977498, 1.8795009625499923, 1.8979624508178456, 1.916327745748669, 1.934598752294794, 1.9527773106875348, 1.9708651995272086, 1.98886413868428, 2.0067757920256257, 2.0246017699787076, 2.0423436319453514, 2.0600028885758332, 2.077581003913084, 2.0950793974160224, 2.112499445870286, 2.12984248519397, 2.1471098121453833, 2.1643026859392784, 2.1814223297775124, 2.1984699322996546, 2.2154466489586113, 2.232353603325996, 2.2491918883315964, 2.265962567440984, 2.2826666757750305, 2.2993052211747975, 2.3158791852150604, 2.332389524169469, 2.3488371699301513, 2.3652230308843896, 2.381547992750791, 2.397812919377242, 2.4140186535027643, 2.4301660174852704, 2.446255813997063, 2.462288826689833, 2.4782658208307726], [0.0, 0.14266929093832773, 0.2238721138568339, 0.2913797178220523, 0.3512930009892054, 0.4061261981781177, 0.4572237861056494, 0.505410463457025, 0.5512378045571162, 0.5950975111719019, 0.637280313659631, 0.67800945175918, 0.7174610235172758, 0.7557770184415149, 0.7930740250780174, 0.8294492546152545, 0.864984831230061, 0.8997509248080119, 0.9338080879268165, 0.9672090320746061, 0.9999999999999999, 1.0322218415600037, 1.0639108681478935, 1.0950995392305045, 1.1258170198247626, 1.1560896375233995, 1.1859412604500639, 1.2153936123284617, 1.2444665370623629, 1.2731782224253154, 1.3015453903668834, 1.3295834598605374, 1.3573066870100212, 1.3847282861991201, 1.4118605353445226, 1.4387148677424273, 1.4653019525495021, 1.4916317655803013, 1.5177136518156886, 1.5435563807846724, 1.5691681957935015, 1.594556857821845, 1.6197296847793567, 1.6446935867114862, 1.6694550974567282, 1.6940204031852832, 1.7183953681886257, 1.7425855582386345, 1.7665962617920399, 1.7904325092795537, 1.8140990906881558, 1.8376005716185837, 1.8609413079774977, 1.8841254594443688, 1.9071570018363984, 1.9300397384803403, 1.9527773106875346, 1.975373207417599, 1.9978307742067096, 2.0201532214281275, 2.0423436319453514, 2.064404968211917, 2.0863400788662405, 2.1081517048649774, 2.1298424851939703, 2.1514149621920264, 2.172871586519301, 2.194214721799026, 2.2154466489586118, 2.2365695702937094, 2.257585613276671, 2.2784968341288927, 2.299305221174797, 2.320012697993638, 2.3406211263839167, 2.3611323091539242, 2.3815479927507908, 2.4018698697393774, 2.422099581141431, 2.4422387186445613, 2.462288826689833, 2.4822514044460906, 2.5021279076784597, 2.521919750517934, 2.5416283071384003, 2.561254913346991, 2.5808008680932053, 2.6002674349018453, 2.6196558432344386, 2.6389672897834977, 2.658202939703631, 2.677363927783265, 2.696451359560456, 2.7154663123860363, 2.73440983643713, 2.7532829556838414, 2.7720866688117596, 2.7908219501027354, 2.8094897502762293, 2.8280909972933728, 2.846626597125766, 2.865097434490878], [0.0, 0.16061951594470014, 0.2520390360441707, 0.3280402455558032, 0.39549163945896465, 0.4572237861056494, 0.514750320266457, 0.5689997017574401, 0.6205929023412377, 0.669970906532684, 0.7174610235172758, 0.7633145803925413, 0.8077298313366436, 0.850866630553871, 0.8928562354137627, 0.9338080879268167, 0.9738146448890526, 1.0129549047519302, 1.0512970386380285, 1.0889003900378262, 1.1258170198247626, 1.1620929174631118, 1.1977689629374375, 1.2328816996679575, 1.26746396212711, 1.3015453903668837, 1.3351528555271137, 1.3683108145456815, 1.401041608027192, 1.4333657120766576, 1.4653019525495024, 1.4968676883884873, 1.528078969357844, 1.5589506724357445, 1.5894966203097645, 1.6197296847793572, 1.6496618773626865, 1.679304429001564, 1.708667860434496, 1.7377620445464965, 1.7665962617920399, 1.7951792496141274, 1.8235192466399976, 1.8516240323164253, 1.8795009625499925, 1.9071570018363986, 1.9345987522947945, 1.9618324799658902, 1.9888641386842807, 2.015699391794479, 2.0423436319453514, 2.0688019991679143, 2.0950793974160224, 2.1211805097276213, 2.1471098121453838, 2.172871586519301, 2.198469932299655, 2.2239087774165642, 2.2491918883315964, 2.2743228793376087, 2.2993052211747975, 2.324142249023774, 2.3488371699301513, 2.3733930697095817, 2.397812919377242, 2.4220995811414316, 2.4462558139970634, 2.4702842789514, 2.4941875439113415, 2.517968088258814, 2.5416283071384007, 2.5651705154791467, 2.588596951770527, 2.6119097816108052, 2.6351111010444206, 2.6582029397036315, 2.681187263768341, 2.7040659787568773, 2.7268409321594524, 2.749513915925067, 2.7720866688117596, 2.7945608786093294, 2.816938184242933, 2.8392201777653097, 2.8614084062448106, 2.8835043735558403, 2.905509542077853, 2.927425334308576, 2.9492531343967214, 2.9709942895990884, 2.9926501116665656, 3.014221878163277, 3.035710833722782, 3.0571181912449856, 3.078445133037167, 3.0996928119022966, 3.120862352177609, 3.1419548507261945, 3.1629713778842015, 3.1839129783660662, 3.204780672130035, 3.225575455206094], [0.0, 0.17754715843916347, 0.2786013542762451, 0.3626123084082179, 0.4371723844352817, 0.505410463457025, 0.5689997017574401, 0.6289664092534479, 0.6859970017350541, 0.7405789389425276, 0.7930740250780175, 0.843760074526298, 0.8928562354137628, 0.9405392089312297, 0.98695408562295, 1.032221841560004, 1.0764446775323464, 1.1197099176144851, 1.1620929174631118, 1.203659274761325, 1.2444665370623629, 1.284565540646313, 1.3240014738270214, 1.3628147313247752, 1.4010416080271921, 1.4387148677424273, 1.4758642135516649, 1.5125166799021166, 1.5486969618679896, 1.5844276935248474, 1.619729684779357, 1.654622124028038, 1.6891227525149497, 1.7232480150985197, 1.7570131912352118, 1.790432509279554, 1.8235192466399979, 1.8562858178839359, 1.8887438525273428, 1.9209042639556155, 1.952777310687535, 1.9843726510025943, 2.0156993917944788, 2.0467661323835205, 2.0775810039130844, 2.1081517048649774, 2.138485533153703, 2.1685894151961183, 2.1984699322996555, 2.2281333446670035, 2.257585613276671, 2.2868324198659975, 2.315879185215061, 2.3447310859057673, 2.3733930697095813, 2.401869869739378, 2.4301660174852704, 2.458285854840752, 2.4862335452136435, 2.514013083806039, 2.5416283071384007, 2.5690829018850216, 2.596380413081088, 2.623524251755435, 2.650517702037637, 2.6773639277832655, 2.704065978756877, 2.7306267964084903, 2.7570492192759404, 2.7833359880424697, 2.8094897502762293, 2.8355130648759403, 2.8614084062448106, 2.887178168212853, 2.9128246677260003, 2.938350148318845, 2.9637567833863985, 2.9890466792689923, 3.014221878163277, 3.03928436087122, 3.0642360493980454, 3.089078809409213, 3.113814452555709, 3.1384447386762315, 3.162971377884201, 3.1873960325468924, 3.2117203191634918, 3.235945810148333, 3.2600740355251463, 3.284106484537719, 3.308044607181971, 3.3318898156641263, 3.355643485789301, 3.3793069582845554, 3.4028815400601777, 3.4263685054126976, 3.4497690971729122, 3.473084527801982, 3.496315980438462, 3.5194646098989284, 3.54253154363472, 3.565517882647123], [0.0, 0.19364598262157046, 0.3038631171729495, 0.39549163945896465, 0.47681233934246653, 0.5512378045571162, 0.6205929023412377, 0.6859970017350541, 0.7481987582580971, 0.8077298313366433, 0.864984831230061, 0.9202667627287335, 0.9738146448890527, 1.0258212010191643, 1.0764446775323464, 1.1258170198247628, 1.1740496955907964, 1.2212379468853654, 1.26746396212711, 1.312799286971353, 1.3573066870100212, 1.4010416080271917, 1.444053335719773, 1.4863859275391569, 1.528078969357844, 1.5691681957935018, 1.609686003209965, 1.6496618773626863, 1.6891227525149497, 1.728093315053413, 1.7665962617920397, 1.8046525210066275, 1.8422814426021197, 1.8795009625499923, 1.916327745748669, 1.952777310687535, 1.9888641386842802, 2.0246017699787076, 2.0600028885758332, 2.0950793974160224, 2.12984248519397, 2.164302685939278, 2.1984699322996546, 2.2323536033259965, 2.265962567440984, 2.299305221174797, 2.332389524169469, 2.3652230308843896, 2.397812919377242, 2.4301660174852704, 2.462288826689833, 2.4941875439113415, 2.525868081451033, 2.5573360852696703, 2.588596951770527, 2.6196558432344386, 2.6505177020376367, 2.681187263768341, 2.711669069345175, 2.7419674762292336, 2.772086668811759, 2.802030668050745, 2.8318033404221636, 2.8614084062448106, 2.890849447431818, 2.9201299147166493, 2.949253134396721, 2.9782223146336517, 3.007040551345467, 3.0357108337227814, 3.064236049398045, 3.0926189892943095, 3.120862352177608, 3.1489687489349265, 3.1769407065978186, 3.2047806721300347, 3.2324910159959424, 3.260074035525146, 3.2875319580874365, 3.3148669440910488, 3.34208108981617, 3.369176430094696, 3.3961549408463667, 3.4230185414806362, 3.449769097172911, 3.4764084210231436, 3.5029382761041754, 3.52936037740667, 3.5556763936869795, 3.5818879492238542, 3.607996625489435, 3.634003962739641, 3.65991146152867, 3.68572058415201, 3.7114327560220954, 3.737049366980394, 3.762571772549536, 3.7880012951287907, 3.813339225136041, 3.8385868220991353, 3.8637453156993837, 3.888815906769725], [0.0, 0.2090535905807846, 0.32804024555580313, 0.4269592694579762, 0.5147503202664568, 0.5950975111719019, 0.669970906532684, 0.7405789389425276, 0.8077298313366433, 0.871997545077537, 0.9338080879268165, 0.993488573509744, 1.0512970386380285, 1.1074415408143927, 1.1620929174631118, 1.2153936123284617, 1.2674639621271098, 1.3184067869294, 1.3683108145456813, 1.4172532832224343, 1.4653019525495021, 1.5125166799021164, 1.5589506724357443, 1.6046514930705182, 1.6496618773626863, 1.6940204031852835, 1.7377620445464963, 1.7809186332610873, 1.8235192466399976, 1.865590535263319, 1.9071570018363984, 1.948241239811168, 1.98886413868428, 2.0290450615180964, 2.0688019991679143, 2.1081517048649774, 2.1471098121453833, 2.185690938589677, 2.223908777416564, 2.2617761786340234, 2.2993052211747975, 2.3365072772175486, 2.373393069709581, 2.4099727239539845, 2.446255813997063, 2.48225140444609, 2.517968088258814, 2.5534140209716356, 2.588596951770527, 2.623524251755435, 2.658202939703631, 2.692639705598792, 2.726840932159452, 2.7608127145720616, 2.794560878609329, 2.828090997293373, 2.86140840624481, 2.8945182178429802, 2.927425334308575, 2.960134459807802, 2.992650111666565, 3.0249766307738146, 3.0571181912449847, 3.089078809409213, 3.1208623521776087, 3.1524725448441893, 3.183912978366066, 3.215187116164975, 3.2462983004883053, 3.277249758364173, 3.3080446071819707, 3.3386858599269256, 3.3691764300946954, 3.3995191363097166, 3.429716706668968, 3.45977178283096, 3.4896869238680814, 3.5194646098989284, 3.5491072455158705, 3.5786171630218697, 3.607996625489435, 3.6372478296536004, 3.6663729086498478, 3.695373934607082, 3.7242529211049837, 3.753011825504352, 3.781652551158424, 3.8101769495125595, 3.8385868220991353, 3.866883922434027, 3.895069957820557, 3.9231465910664225, 3.9511154421186956, 3.978978089621655, 4.006736072401892, 4.034390890884797, 4.061944008446316, 4.089396852703548, 4.116750816747572, 4.144007260321648, 4.171167510947729, 4.198232865004053], [0.0, 0.2238721138568339, 0.3512930009892054, 0.4572237861056494, 0.5512378045571162, 0.637280313659631, 0.7174610235172758, 0.7930740250780175, 0.864984831230061, 0.9338080879268165, 1.0, 1.0639108681478937, 1.1258170198247628, 1.1859412604500639, 1.2444665370623629, 1.3015453903668837, 1.3573066870100212, 1.4118605353445226, 1.4653019525495021, 1.5177136518156886, 1.5691681957935015, 1.6197296847793567, 1.6694550974567282, 1.7183953681886257, 1.7665962617920397, 1.814099090688156, 1.860941307977498, 1.9071570018363986, 1.9527773106875348, 1.9978307742067098, 2.0423436319453514, 2.086340078866241, 2.12984248519397, 2.172871586519301, 2.2154466489586118, 2.257585613276671, 2.2993052211747975, 2.3406211263839167, 2.3815479927507908, 2.4220995811414316, 2.462288826689833, 2.5021279076784597, 2.5416283071384003, 2.5808008680932057, 2.6196558432344386, 2.658202939703631, 2.696451359560456, 2.73440983643713, 2.7720866688117596, 2.8094897502762293, 2.8466265971257654, 2.8835043735558403, 2.9201299147166493, 2.9565097478449225, 2.992650111666565, 3.0285569742409573, 3.064236049398045, 3.099692811902296, 3.134932511462677, 3.169960185694805, 3.2047806721300343, 3.2393986193562347, 3.2738184973662108, 3.308044607181971, 3.34208108981617, 3.3759319346260064, 3.409600987109455, 3.4430919561889177, 3.476408421023144, 3.509553837384427, 3.5425315436347193, 3.57534476633124, 3.607996625489435, 3.6404901395286915, 3.6728282299240043, 3.705013725584808, 3.737049366980394, 3.768937810029712, 3.800681629771896, 3.8322833238325194, 3.8637453156993833, 3.8950699578205574, 3.926259534536378, 3.957316264856224, 3.9882423050900555, 4.019039751343939, 4.049710641888118, 4.080256959405525, 4.110680633128088, 4.140983540867638, 4.171167510947729, 4.201234324042269, 4.231185714926415, 4.26102337414483, 4.290748949602055, 4.320364048079413, 4.349870236682567, 4.379269044223611, 4.408561962541286, 4.437750447762687, 4.466835921509633, 4.495819772052641], [0.0, 0.23817997500752824, 0.3737444416567044, 0.48644535521352833, 0.5864678912023005, 0.67800945175918, 0.7633145803925413, 0.843760074526298, 0.9202667627287335, 0.993488573509744, 1.0639108681478937, 1.1319063353632048, 1.1977689629374377, 1.2617357959778348, 1.3240014738270214, 1.3847282861991204, 1.4440533357197731, 1.502093767862141, 1.5589506724357445, 1.6147120489031395, 1.6694550974567282, 1.7232480150985197, 1.7761514220691141, 1.8282195079908803, 1.8795009625499925, 1.9300397384803407, 1.9798756825426167, 2.029045061518097, 2.0775810039130844, 2.1255138733988392, 2.172871586519301, 2.2196798845583277, 2.265962567440984, 2.3117416959876405, 2.3570377676288987, 2.401869869739378, 2.4462558139970634, 2.490212254576414, 2.5337547925033674, 2.5768980681128304, 2.619655843234439, 2.6620410744752627, 2.704065978756877, 2.74574209208988, 2.787080322424254, 2.828090997293373, 2.868783906868533, 2.909168342955967, 2.949253134396722, 2.9890466792689923, 3.0285569742409577, 3.0677916413780424, 3.1067579526708253, 3.1454628525174018, 3.1839129783660662, 3.222114679700055, 3.2600740355251463, 3.297796870502758, 3.3352887698553135, 3.3725550931568185, 3.4096009871094553, 3.44643139739638, 3.4830510796915184, 3.519464609898929, 3.55567639368698, 3.5916906753761526, 3.6275115462335354, 3.663142952221981, 3.6985887012473815, 3.7338524699434377, 3.7689378100297124, 3.8038481542754976, 3.8385868220991357, 3.873157024829817, 3.907561870656539, 3.941804369286795, 3.9758874363356473, 4.009813897464132, 4.043586492284369, 4.077207878047352, 4.110680633128089, 4.144007260321649, 4.177190189962543, 4.2102317828789655, 4.2431343331925175, 4.2759000709732256, 4.308531164758952, 4.341029723947617, 4.373397801070038, 4.405637393950628, 4.437750447762688, 4.46973885698454, 4.501604467262329, 4.5333490771848926, 4.564974439975786, 4.596482265107117, 4.627874219839634, 4.659151930693139, 4.690316984851082, 4.721370931502904, 4.75231528312751, 4.7831515167209915], [0.0, 0.2520390360441707, 0.39549163945896465, 0.514750320266457, 0.6205929023412377, 0.7174610235172758, 0.8077298313366436, 0.8928562354137628, 0.9738146448890527, 1.0512970386380285, 1.1258170198247628, 1.1977689629374377, 1.2674639621271104, 1.3351528555271137, 1.4010416080271921, 1.4653019525495026, 1.5280789693578443, 1.5894966203097647, 1.6496618773626865, 1.7086678604344963, 1.7665962617920399, 1.8235192466399979, 1.8795009625499925, 1.9345987522947945, 1.9888641386842805, 2.042343631945352, 2.095079397416023, 2.1471098121453838, 2.1984699322996555, 2.2491918883315964, 2.2993052211747975, 2.348837169930152, 2.3978129193772415, 2.4462558139970634, 2.494187543911342, 2.541628307138401, 2.5885969517705276, 2.6351111010444206, 2.681187263768341, 2.726840932159453, 2.7720866688117596, 2.816938184242933, 2.8614084062448106, 2.9055095420778536, 2.9492531343967214, 2.9926501116665656, 3.0357108337227823, 3.078445133037167, 3.1208623521776095, 3.1629713778842015, 3.2047806721300347, 3.2462983004883057, 3.287531958087437, 3.3284889934016317, 3.369176430094696, 3.4096009871094553, 3.4497690971729114, 3.489686923868082, 3.5293603774066704, 3.568795129222077, 3.6079966254894353, 3.646970099668087, 3.6857205841520106, 3.7242529211049846, 3.762571772549536, 3.8006816297718964, 3.8385868220991357, 3.8762915250992203, 3.9137997682499854, 3.951115442118696, 3.9882423050900564, 4.0251839896771, 4.061944008446316, 4.098525759585626, 4.134932532141301, 4.17116751094773, 4.207233781271883, 4.243134333192518, 4.278872065732518, 4.314449790761263, 4.349870236682567, 4.385136051922505, 4.420249808230306, 4.455214003804496, 4.490031066255528, 4.52470335541529, 4.559233166003108, 4.593622730157176, 4.627874219839633, 4.6619897491229985, 4.695971376365046, 4.729821106278769, 4.763540891903565, 4.797132636483387, 4.830598195257218, 4.863939377166813, 4.897157946486403, 4.930255624378663, 4.963234090381039, 4.996094983826195, 5.028839905200173, 5.061470417441549], [0.0, 0.2654991768869938, 0.4166128643804238, 0.5422405532018842, 0.6537356567441924, 0.7557770184415149, 0.850866630553871, 0.9405392089312297, 1.0258212010191643, 1.1074415408143927, 1.1859412604500639, 1.2617357959778348, 1.3351528555271137, 1.4064566732378863, 1.4758642135516649, 1.5435563807846724, 1.609686003209965, 1.674383662866185, 1.7377620445464963, 1.7999192412365672, 1.860941307977498, 1.920904263955615, 1.9798756825426165, 2.0379159689011703, 2.0950793974160224, 2.1514149621920264, 2.2069670804064243, 2.2617761786340234, 2.315879185215061, 2.3693099465286322, 2.422099581141431, 2.4742767828581154, 2.525868081451033, 2.5768980681128295, 2.627389591325846, 2.6773639277832655, 2.7268409321594524, 2.7758391688597905, 2.8243760283451924, 2.872467830194441, 2.9201299147166493, 2.9673767246394736, 3.0142218781632764, 3.0606782344770753, 3.106757952670825, 3.1524725448441893, 3.197832924099415, 3.2428494480113033, 3.287531958087437, 3.3318898156641263, 3.3759319346260064, 3.419666811288085, 3.4631025517370007, 3.5062468968921077, 3.5491072455158705, 3.5916906753761526, 3.6340039627396417, 3.676053600355412, 3.7178458140699315, 3.7593865781994156, 3.8006816297718955, 3.8417364817395296, 3.8825564352512183, 3.9231465910664234, 3.9635118601829116, 4.003656973743989, 4.043586492284369, 4.083304814368161, 4.122816184667403, 4.1621247015250455, 4.20123432404227, 4.24014887872641, 4.278872065732518, 4.317407464728685, 4.35575854041265, 4.3939286477048345, 4.4319210366408415, 4.46973885698454, 4.507385162581086, 4.544862915467698, 4.582174989758556, 4.619324175318889, 4.656313181242154, 4.693144639143129, 4.729821106278768, 4.766345068507743, 4.8027189430988315, 4.838945081397534, 4.875025771359591, 4.9109632399595355, 4.9467596554817055, 4.98241712970076, 5.017937719958137, 5.0533234311405035, 5.0885762175658495, 5.1236979847824395, 5.158690591285541, 5.193555850156496, 5.2282955306284205, 5.2629113595825165, 5.297405022978756, 5.331778167224428], [0.0, 0.2786013542762451, 0.43717238443528167, 0.56899970175744, 0.6859970017350541, 0.7930740250780174, 0.8928562354137627, 0.98695408562295, 1.0764446775323464, 1.1620929174631118, 1.2444665370623629, 1.3240014738270214, 1.4010416080271921, 1.4758642135516649, 1.5486969618679893, 1.619729684779357, 1.6891227525149495, 1.7570131912352118, 1.8235192466399976, 1.8887438525273428, 1.9527773106875346, 2.0156993917944788, 2.077581003913084, 2.138485533153703, 2.198469932299655, 2.257585613276671, 2.315879185215061, 2.3733930697095813, 2.4301660174852704, 2.4862335452136435, 2.5416283071384003, 2.596380413081088, 2.6505177020376367, 2.704065978756877, 2.75704921927594, 2.8094897502762293, 2.8614084062448106, 2.912824667726, 2.963756783386398, 3.0142218781632772, 3.064236049398045, 3.1138144525557085, 3.1629713778842006, 3.2117203191634918, 3.260074035525146, 3.3080446071819707, 3.3556434857893005, 3.4028815400601773, 3.449769097172912, 3.4963159804384616, 3.5425315436347193, 3.5884247023632145, 3.6340039627396417, 3.6792774476916903, 3.7242529211049837, 3.768937810029712, 3.8133392251360405, 3.8574639795851486, 3.901318606464174, 3.9449093749171786, 3.9882423050900555, 4.0313231819948525, 4.074157568388037, 4.116750816747572, 4.159108080425137, 4.20123432404227, 4.2431343331925175, 4.284812723505699, 4.326273949125109, 4.367522310643725, 4.408561962541286, 4.449396920160281, 4.490031066255528, 4.530468157148949, 4.570711828518413, 4.610765600847049, 4.6506328845571865, 4.690316984851082, 4.729821106278769, 4.769148357051697, 4.808301753119338, 4.847284222024593, 4.886098606552571, 4.92474766818619, 4.963234090381037, 5.001560481670972, 5.039729378615105, 5.077743248596, 5.115604492478233, 5.153315447135792, 5.190878387856156, 5.22829553062842, 5.265569034322214, 5.302701002763801, 5.339693486715241, 5.376548485762119, 5.413267950114995, 5.449853782329361, 5.486307838948609, 5.522631932074181, 5.5588278308668615, 5.594897262982852], [0.0, 0.2913797178220523, 0.4572237861056494, 0.595097511171902, 0.7174610235172758, 0.8294492546152545, 0.9338080879268167, 1.032221841560004, 1.1258170198247628, 1.2153936123284617, 1.3015453903668837, 1.3847282861991204, 1.4653019525495026, 1.5435563807846724, 1.619729684779357, 1.6940204031852835, 1.7665962617920397, 1.837600571618584, 1.9071570018363986, 1.975373207417599, 2.0423436319453514, 2.1081517048649774, 2.172871586519301, 2.2365695702937094, 2.2993052211747975, 2.3611323091539247, 2.4220995811414316, 2.482251404446091, 2.5416283071384007, 2.6002674349018458, 2.6582029397036315, 2.7154663123860363, 2.772086668811759, 2.828090997293373, 2.8835043735558408, 2.938350148318845, 2.9926501116665656, 3.04642463764033, 3.099692811902296, 3.15247254484419, 3.2047806721300347, 3.2566330443472347, 3.3080446071819707, 3.3590294733215638, 3.4096009871094553, 3.4597717828309604, 3.5095538373844275, 3.558958517988611, 3.607996625489436, 3.656678433755033, 3.705013725584808, 3.7530118255043523, 3.800681629771896, 3.8480316338823166, 3.8950699578205574, 3.941804369286795, 3.988242305090056, 4.034390890884797, 4.080256959405525, 4.125847067337624, 4.171167510947729, 4.216224340583954, 4.26102337414483, 4.305570209605723, 4.349870236682567, 4.3939286477048345, 4.437750447762687, 4.481340464186982, 4.52470335541529, 4.567843619292109, 4.61076560084705, 4.653473499590788, 4.695971376365046, 4.738263159779661, 4.780352652266949, 4.822243535780941, 4.863939377166813, 4.905443633223629, 4.9467596554817055, 4.987890694714094, 5.028839905200172, 5.0696103487578785, 5.110204998559849, 5.150626742747512, 5.190878387856157, 5.230962662062971, 5.270882218269193, 5.310639637026658, 5.350237429318286, 5.38967803920141, 5.428963846322125, 5.468097168308345, 5.507080263048683, 5.545915330863748, 5.584604516576103, 5.623149911484569, 5.6615535552483, 5.699817437685629, 5.737943500492394, 5.775933638884099, 5.813789703166074, 5.851513500235409], [0.0, 0.30386311717294945, 0.4768123393424665, 0.6205929023412375, 0.748198758258097, 0.864984831230061, 0.9738146448890526, 1.0764446775323464, 1.1740496955907964, 1.2674639621271098, 1.3573066870100212, 1.4440533357197731, 1.5280789693578443, 1.609686003209965, 1.6891227525149495, 1.7665962617920397, 1.8422814426021197, 1.916327745748669, 1.98886413868428, 2.0600028885758332, 2.12984248519397, 2.1984699322996546, 2.265962567440984, 2.332389524169469, 2.3978129193772415, 2.462288826689833, 2.525868081451033, 2.588596951770527, 2.6505177020376367, 2.711669069345175, 2.772086668811759, 2.831803340422164, 2.8908494474318176, 2.949253134396721, 3.007040551345467, 3.0642360493980454, 3.1208623521776087, 3.176940706597818, 3.232491015995942, 3.2875319580874365, 3.3420810898161695, 3.3961549408463663, 3.449769097172911, 3.502938276104176, 3.5556763936869795, 3.607996625489435, 3.6599114615286696, 3.711432756022095, 3.7625717725495353, 3.8133392251360405, 3.863745315699383, 3.913799768249984, 3.963511860182911, 4.012890450960225, 4.061944008446315, 4.110680633128088, 4.159108080425136, 4.207233781271882, 4.255064861133412, 4.302608157599088, 4.349870236682566, 4.396857407943248, 4.443575738532258, 4.490031066255528, 4.536229011737227, 4.582174989758556, 4.627874219839632, 4.6733317361256335, 4.718552396632663, 4.763540891903563, 4.808301753119338, 4.852839359707674, 4.897157946486401, 4.941261610376338, 4.985154316715031, 5.028839905200171, 5.0723220954890555, 5.115604492478233, 5.1586905912855405, 5.201583781954869, 5.244287353902418, 5.286804500121684, 5.32913832116308, 5.371291828902873, 5.413267950114993, 5.455069529858222, 5.496699334690388, 5.538160055720296, 5.579454311507342, 5.62058465081808, 5.6615535552482985, 5.702363441718598, 5.7430166648509005, 5.783515519232781, 5.823862241576094, 5.864059012775872, 5.904107959875112, 5.944011157940692, 5.983770631855311, 6.023388358030011, 6.062866266041595, 6.102206240198919], [0.0, 0.3160762025186194, 0.49597672443940344, 0.6455362194233717, 0.7782709018441495, 0.8997509248080119, 1.0129549047519302, 1.1197099176144851, 1.2212379468853654, 1.3184067869294, 1.4118605353445226, 1.502093767862141, 1.5894966203097647, 1.674383662866185, 1.7570131912352118, 1.837600571618584, 1.916327745748669, 1.993350171263322, 2.0688019991679143, 2.1428000089521886, 2.2154466489586118, 2.2868324198659975, 2.3570377676288983, 2.426134604464341, 2.4941875439113415, 2.5612549133469917, 2.6273895913258465, 2.6926397055987925, 2.75704921927594, 2.8206584263992474, 2.8835043735558403, 2.9456212206588246, 3.007040551345467, 3.0677916413780424, 3.1279016918259344, 3.187396032546893, 3.2462983004883057, 3.3046305965350964, 3.3624136239938047, 3.4196668112880855, 3.476408421023144, 3.5326556472353805, 3.5884247023632145, 3.643730895243682, 3.698588701247381, 3.7530118255043523, 3.807013260039491, 3.860605335523455, 3.9137997682499854, 3.966607702869946, 4.01903975134394, 4.071106028516821, 4.122816184667403, 4.174179435343632, 4.225204588756402, 4.2759000709732256, 4.326273949125109, 4.376333952815944, 4.426087493902644, 4.47554168479589, 4.524703355415289, 4.573579068918601, 4.622175136312259, 4.670497630039499, 4.7185523966326635, 4.766345068507743, 4.813881074971568, 4.861165652505305, 4.908203854381942, 4.955000559670001, 5.001560481670973, 5.047888175833662, 5.0939880471847445, 5.139864357311434, 5.18552123092898, 5.2309626620629714, 5.276192519873848, 5.321214554148762, 5.366032400483841, 5.410649585178067, 5.455069529858223, 5.499295555852899, 5.543330888332067, 5.5871786602274955, 5.6308419159481184, 5.674323614903371, 5.717626634846568, 5.760753775049499, 5.803707759318583, 5.8464912388622405, 5.889106795018341, 5.9315569418501015, 5.973844128618105, 6.015970742135643, 6.057939109014106, 6.099751497804629, 6.141410121041854, 6.182917137195243, 6.2242746525330395, 6.265484722903622, 6.306549355438734, 6.347470510182732], [0.0, 0.32804024555580313, 0.5147503202664568, 0.669970906532684, 0.8077298313366432, 0.9338080879268165, 1.0512970386380285, 1.1620929174631118, 1.26746396212711, 1.3683108145456813, 1.4653019525495021, 1.5589506724357445, 1.6496618773626865, 1.7377620445464963, 1.8235192466399976, 1.9071570018363986, 1.98886413868428, 2.0688019991679143, 2.1471098121453833, 2.223908777416564, 2.299305221174797, 2.373393069709581, 2.446255813997063, 2.517968088258814, 2.588596951770527, 2.6582029397036315, 2.726840932159452, 2.7945608786093294, 2.8614084062448106, 2.9274253343085754, 2.992650111666565, 3.057118191244985, 3.120862352177608, 3.1839129783660662, 3.2462983004883053, 3.308044607181971, 3.369176430094696, 3.429716706668968, 3.4896869238680814, 3.549107245515871, 3.607996625489435, 3.6663729086498473, 3.7242529211049837, 3.7816525511584245, 3.8385868220991353, 3.895069957820557, 3.9511154421186956, 4.006736072401892, 4.061944008446316, 4.1167508167475715, 4.171167510947729, 4.225204588756402, 4.278872065732517, 4.332179506248801, 4.385136051922504, 4.437750447762687, 4.490031066255528, 4.541985929584091, 4.5936227301571755, 4.64494884960278, 4.695971376365045, 4.746697122028852, 4.7971326364833855, 4.847284222024593, 4.897157946486402, 4.9467596554817055, 4.996094983826194, 5.045169366211106, 5.0939880471847445, 5.142556090496999, 5.190878387856156, 5.23895966714281, 5.286804500121684, 5.334417309688601, 5.381802376686575, 5.428963846322124, 5.475905734210252, 5.522631932074181, 5.569146213123783, 5.615452237134686, 5.6615535552482985, 5.70745361451137, 5.753155762172255, 5.798663249749728, 5.843979236888986, 5.88910679501834, 5.934048910819157, 5.978808489520611, 6.023388358030011, 6.067791267908701, 6.112019898202754, 6.156076858137125, 6.199964689681237, 6.243685869993486, 6.287242813751617, 6.330637875375435, 6.37387335114793, 6.416951481240449, 6.459874451647212, 6.502644396034093, 6.54526339750632, 6.587733490299393], [0.0, 0.339773763461353, 0.5331621833886192, 0.6939347821074004, 0.8366211413732437, 0.9672090320746061, 1.0889003900378262, 1.203659274761325, 1.312799286971353, 1.4172532832224343, 1.5177136518156886, 1.6147120489031395, 1.7086678604344963, 1.7999192412365672, 1.8887438525273428, 1.975373207417599, 2.0600028885758332, 2.1428000089521886, 2.223908777416564, 2.303454728907713, 2.3815479927507908, 2.4582858548407516, 2.5337547925033674, 2.608032109516724, 2.681187263768341, 2.7532829556838414, 2.8243760283451924, 2.8945182178429802, 2.963756783386398, 3.03213504003103, 3.099692811902296, 3.1664668200255144, 3.232491015995942, 3.2977968705027574, 3.3624136239938047, 3.426368505412697, 3.4896869238680814, 3.5523926372410846, 3.614507901052126, 3.676053600355412, 3.737049366980394, 3.7975136840726234, 3.857463979585148, 3.916916710122839, 3.975887436335647, 4.034390890884796, 4.092441039861878, 4.1500511384197365, 4.207233781271883, 4.264000948630483, 4.320364048079412, 4.376333952815944, 4.4319210366408415, 4.487135206030398, 4.541985929584091, 4.596482265107116, 4.650632884557186, 4.7044460970590745, 4.7579298701677475, 4.811091849541201, 4.863939377166812, 4.916479508269851, 4.968719027019422, 5.020664461135344, 5.0723220954890555, 5.123697984782439, 5.174797965380267, 5.225627666364705, 5.276192519873848, 5.326497770780482, 5.376548485762118, 5.4263495618086965, 5.475905734210252, 5.525221584063096, 5.574301545329712, 5.623149911484568, 5.671770841775321, 5.720168367126418, 5.768346395709907, 5.816308718206218, 5.864059012775872, 5.9116008497614185, 5.958937696137372, 6.006072919724561, 6.053009793184048, 6.099751497804627, 6.146301127096872, 6.192661690205737, 6.238836115152858, 6.284827251918884, 6.330637875375435, 6.376270688075608, 6.421728322911345, 6.4670133456453565, 6.512128257324866, 6.557075496583817, 6.601857441839873, 6.646476413392017, 6.690934675424275, 6.735234437920615, 6.779377858495882, 6.823367044147191], [0.0, 0.3512930009892054, 0.5512378045571162, 0.7174610235172757, 0.8649848312300609, 0.9999999999999999, 1.1258170198247626, 1.2444665370623629, 1.3573066870100212, 1.4653019525495021, 1.5691681957935015, 1.6694550974567282, 1.7665962617920399, 1.860941307977498, 1.9527773106875346, 2.0423436319453514, 2.12984248519397, 2.2154466489586118, 2.299305221174797, 2.3815479927507908, 2.4622888266898326, 2.5416283071384003, 2.6196558432344386, 2.696451359560456, 2.772086668811759, 2.8466265971257654, 2.9201299147166493, 2.992650111666565, 3.064236049398045, 3.134932511462677, 3.2047806721300343, 3.273818497366211, 3.3420810898161695, 3.409600987109455, 3.4764084210231436, 3.5425315436347193, 3.607996625489435, 3.672828229924004, 3.7370493669803935, 3.800681629771896, 3.8637453156993833, 3.9262595345363778, 3.988242305090055, 4.049710641888118, 4.110680633128088, 4.171167510947729, 4.231185714926415, 4.290748949602055, 4.349870236682567, 4.4085619625412855, 4.466835921509632, 4.524703355415289, 4.582174989758556, 4.639261066871717, 4.695971376365045, 4.752315283127509, 4.808301753119337, 4.863939377166812, 4.91923639294628, 4.97420070532395, 5.028839905200171, 5.083161286991182, 5.137171864867529, 5.190878387856156, 5.244287353902418, 5.297405022978755, 5.350237429318285, 5.402790392844082, 5.455069529858222, 5.507080263048682, 5.558827830866861, 5.61031729632373, 5.6615535552482985, 5.71254134404827, 5.763285247009289, 5.813789703166073, 5.864059012775872, 5.914097343422234, 5.9639087357746705, 6.0134971090277975, 6.062866266041595, 6.112019898202754, 6.160961590025481, 6.20969482350872, 6.258222982265478, 6.306549355438732, 6.354677141417321, 6.402609451364246, 6.450349312568891, 6.497899671633857, 6.545263397506319, 6.592443284363138, 6.6394420543583195, 6.6862623602407805, 6.732906787849919, 6.779377858495881, 6.8256780312310354, 6.871809705018696, 6.917775220804769, 6.963576863497579, 7.009216863860873, 7.054697400324595], [0.0, 0.36261230840821784, 0.56899970175744, 0.7405789389425276, 0.8928562354137626, 1.0322218415600037, 1.1620929174631118, 1.284565540646313, 1.4010416080271917, 1.5125166799021164, 1.6197296847793567, 1.7232480150985197, 1.8235192466399979, 1.920904263955615, 2.0156993917944788, 2.1081517048649774, 2.1984699322996546, 2.2868324198659975, 2.373393069709581, 2.4582858548407516, 2.5416283071384003, 2.6235242517554345, 2.7040659787568764, 2.7833359880424693, 2.86140840624481, 2.9383501483188446, 3.0142218781632764, 3.0890788094092128, 3.1629713778842006, 3.2359458101483325, 3.3080446071819707, 3.379306958284555, 3.4497690971729105, 3.519464609898928, 3.5884247023632145, 3.656678433755033, 3.7242529211049837, 3.7911735192257243, 3.857463979585148, 3.923146591066423, 3.9882423050900555, 4.052770847181663, 4.1167508167475715, 4.180199776554899, 4.2431343331925175, 4.305570209605722, 4.367522310643725, 4.429004782429885, 4.490031066255528, 4.5506139476057506, 4.610765600847049, 4.670497630039498, 4.729821106278768, 4.788746601923952, 4.847284222024593, 4.905443633223628, 4.963234090381037, 5.020664461135344, 5.077743248596, 5.134478612338557, 5.190878387856156, 5.246950104604558, 5.3027010027638, 5.3581380488269055, 5.413267950114994, 5.468097168308345, 5.522631932074181, 5.576878248864214, 5.6308419159481184, 5.68452853074286, 5.737943500492392, 5.791092051347222, 5.843979236888985, 5.896609946141164, 5.94898891110353, 6.001120713844671, 6.0530097931840485, 6.104660450992425, 6.156076858137125, 6.207263060096432, 6.258222982265479, 6.308960434974234, 6.3594791182365515, 6.409782626247793, 6.45987445164721, 6.509757989560023, 6.5594365414330476, 6.608913318676688, 6.658191446125165, 6.707273965326044, 6.756163837669259, 6.804863947365198, 6.853377104280679, 6.901706046641076, 6.949853443606293, 6.997821897727733, 7.04561394729296, 7.093232068564305, 7.14067867791726, 7.187956133884106, 7.235066739107905, 7.2820127422116245], [0.0, 0.3737444416567044, 0.5864678912023004, 0.7633145803925412, 0.9202667627287333, 1.0639108681478935, 1.1977689629374375, 1.3240014738270214, 1.444053335719773, 1.5589506724357443, 1.6694550974567282, 1.7761514220691141, 1.8795009625499925, 1.9798756825426165, 2.077581003913084, 2.172871586519301, 2.265962567440984, 2.3570377676288983, 2.446255813997063, 2.5337547925033674, 2.6196558432344386, 2.7040659787568764, 2.7870803224242535, 2.8687839068685324, 2.949253134396721, 3.0285569742409573, 3.106757952670825, 3.1839129783660662, 3.260074035525146, 3.3352887698553135, 3.409600987109455, 3.4830510796915184, 3.555676393686979, 3.627511546233535, 3.698588701247381, 3.768937810029712, 3.8385868220991353, 3.9075618706565387, 3.975887436335647, 4.043586492284369, 4.110680633128088, 4.177190189962542, 4.243134333192517, 4.308531164758952, 4.373397801070037, 4.437750447762687, 4.501604467262328, 4.564974439975785, 4.627874219839633, 4.690316984851081, 4.752315283127509, 4.813881074971567, 4.875025771359591, 4.935760269220212, 4.996094983826194, 5.056039878584691, 5.115604492478233, 5.174797965380267, 5.233629061444189, 5.292106190743069, 5.350237429318285, 5.408030537778553, 5.465492978576147, 5.522631932074182, 5.579454311507342, 5.63596677692834, 5.692175748223371, 5.748087417271846, 5.803707759318583, 5.859042543620253, 5.914097343422234, 5.968877545316923, 6.023388358030011, 6.07763482067713, 6.131621810529601, 6.185354050324701, 6.238836115152858, 6.2920724389515, 6.345067320632837, 6.3978249298706125, 6.450349312568891, 6.502644396034093, 6.5547139938698376, 6.606561810612643, 6.658191446125165, 6.709606399762361, 6.760810074324877, 6.811805779812844, 6.862596736992337, 6.91318608078589, 6.963576863497579, 7.013772057882537, 7.063774560069994, 7.113587192348353, 7.1632127058202535, 7.212653782934961, 7.261913039905016, 7.310993029013562, 7.359896240818388, 7.408625106258295, 7.457181998667078, 7.505569235700028], [0.0, 0.38470080351818003, 0.6036602657769329, 0.7856912362696148, 0.9472444901214154, 1.0950995392305045, 1.2328816996679575, 1.3628147313247752, 1.4863859275391569, 1.6046514930705182, 1.7183953681886257, 1.8282195079908803, 1.9345987522947945, 2.0379159689011703, 2.138485533153703, 2.2365695702937094, 2.332389524169469, 2.426134604464341, 2.517968088258814, 2.608032109516724, 2.696451359560456, 2.7833359880424693, 2.8687839068685324, 2.9528826414121223, 3.035710833722782, 3.117339474873725, 3.197832924099415, 3.2772497583641735, 3.3556434857893005, 3.4330631488215064, 3.509553837384427, 3.5851571279900405, 3.6599114615286696, 3.7338524699434372, 3.807013260039491, 3.879424661143909, 3.9511154421186956, 4.022112502262567, 4.092441039861877, 4.162124701525046, 4.231185714926415, 4.299645007170162, 4.367522310643725, 4.434836257948549, 4.501604467262328, 4.567843619292108, 4.63356952681461, 4.698797197662982, 4.763540891903564, 4.827814173848091, 4.891629959463464, 4.955000559670001, 5.0179377199581365, 5.080452656701237, 5.142556090496999, 5.20425827683102, 5.265569034322214, 5.326497770780483, 5.3870535072814, 5.4472449004403085, 5.507080263048682, 5.566567583218383, 5.625714542164343, 5.684528530742861, 5.7430166648509005, 5.801185799781396, 5.859042543620253, 5.916593269762551, 5.973844128618104, 6.030801058570017, 6.0874697962440045, 6.143855886141047, 6.199964689681236, 6.255801393702467, 6.311371018453838, 6.3666784251202175, 6.421728322911345, 6.47652527574604, 6.5310737085596235, 6.585377913260312, 6.6394420543583195, 6.693270174289512, 6.746866198453742, 6.800233939986448, 6.853377104280679, 6.906299293275391, 6.959004009524728, 7.01149466006186, 7.0637745600699935, 7.115846936372284, 7.1677149307514565, 7.219381603109307, 7.2708499344754305, 7.322122829873945, 7.373203121056383, 7.424093569108324, 7.4747968669368845, 7.525315641645683, 7.575652456803504, 7.625809814612401, 7.675790157980725, 7.725595872506102], [0.0, 0.39549163945896465, 0.6205929023412375, 0.8077298313366433, 0.9738146448890526, 1.1258170198247626, 1.26746396212711, 1.4010416080271921, 1.528078969357844, 1.6496618773626863, 1.7665962617920397, 1.8795009625499925, 1.9888641386842805, 2.0950793974160224, 2.198469932299655, 2.2993052211747975, 2.3978129193772415, 2.4941875439113415, 2.588596951770527, 2.681187263768341, 2.772086668811759, 2.86140840624481, 2.949253134396721, 3.035710833722782, 3.1208623521776087, 3.2047806721300347, 3.2875319580874365, 3.369176430094696, 3.4497690971729114, 3.52936037740667, 3.607996625489435, 3.6857205841520106, 3.762571772549535, 3.8385868220991353, 3.9137997682499845, 3.9882423050900564, 4.061944008446316, 4.134932532141301, 4.207233781271882, 4.278872065732518, 4.349870236682566, 4.420249808230305, 4.490031066255528, 4.559233166003108, 4.627874219839633, 4.695971376365045, 4.763540891903564, 4.830598195257217, 4.897157946486402, 4.963234090381038, 5.028839905200171, 5.0939880471847445, 5.1586905912855405, 5.222959068494566, 5.286804500121684, 5.350237429318286, 5.413267950114994, 5.475905734210253, 5.538160055720296, 5.600039814078042, 5.6615535552482985, 5.722709491409018, 5.783515519232781, 5.843979236888987, 5.904107959875112, 5.963908735774671, 6.023388358030012, 6.082553378809584, 6.1414101210418535, 6.199964689681237, 6.258222982265479, 6.316190698818502, 6.373873351147929, 6.431276271582167, 6.48840462118802, 6.54526339750632, 6.601857441839872, 6.658191446125166, 6.714269959416709, 6.770097394010501, 6.825678031231035, 6.881016026904274, 6.936115416537319, 6.990980120223843, 7.045613947292959, 7.100020600717812, 7.15420368129899, 7.208166691636754, 7.261913039905015, 7.315446043439134, 7.368768932148665, 7.421884851765479, 7.474796866936884, 7.527507964172759, 7.580021054655112, 7.632338976917815, 7.6844644994038775, 7.73640032290703, 7.788149082904014, 7.839713351783512, 7.891095640977317, 7.9422984029989365], [0.0, 0.4061261981781177, 0.637280313659631, 0.8294492546152545, 1.0, 1.1560896375233995, 1.3015453903668837, 1.4387148677424273, 1.5691681957935018, 1.6940204031852835, 1.814099090688156, 1.9300397384803407, 2.042343631945352, 2.1514149621920264, 2.257585613276671, 2.3611323091539247, 2.462288826689833, 2.5612549133469917, 2.6582029397036315, 2.7532829556838414, 2.8466265971257654, 2.9383501483188446, 3.0285569742409573, 3.117339474873725, 3.2047806721300347, 3.2909555108355946, 3.375931934626007, 3.4597717828309604, 3.54253154363472, 3.6242629908372073, 3.705013725584808, 3.7848276399375034, 3.8637453156993833, 3.941804369286795, 4.01903975134394, 4.095484008195871, 4.17116751094773, 4.246118657018551, 4.320364048079413, 4.3939286477048345, 4.466835921509633, 4.539107962104952, 4.610765600847049, 4.681828508055088, 4.752315283127509, 4.82224353578094, 4.891629959463465, 4.960490397849347, 5.028839905200172, 5.096692801273802, 5.164062721374571, 5.230962662062971, 5.297405022978756, 5.363401645176143, 5.428963846322124, 5.494102453067794, 5.558827830866861, 5.623149911484568, 5.68707821841318, 5.750621890386604, 5.813789703166073, 5.876590089750613, 5.939031159150108, 6.001120713844672, 6.0628662660415955, 6.1242750528301455, 6.185354050324701, 6.24610998687802, 6.306549355438734, 6.3666784251202175, 6.426503252041854, 6.48602968949816, 6.545263397506319, 6.604209851778197, 6.6628743521589255, 6.7212620305705375, 6.779377858495882, 6.837226654035111, 6.8948130885643755, 6.9521416930239575, 7.009216863860874, 7.066042868649028, 7.122623851408147, 7.178963837641126, 7.235066739107905, 7.290936358352593, 7.346576392999383, 7.401990439831583, 7.457181998667078, 7.5121544760426024, 7.5669111887182545, 7.62145536701295, 7.675790157980725, 7.7299186284371135, 7.78384376784425, 7.8375684910626635, 7.891095640977318, 7.944427991004844, 7.99756824748854, 8.050519051987248, 8.103282983463815, 8.15586256037853], [0.0, 0.4166128643804238, 0.6537356567441924, 0.8508666305538709, 1.0258212010191643, 1.1859412604500639, 1.3351528555271137, 1.4758642135516649, 1.609686003209965, 1.7377620445464963, 1.860941307977498, 1.9798756825426167, 2.095079397416023, 2.2069670804064243, 2.315879185215061, 2.4220995811414316, 2.525868081451033, 2.6273895913258465, 2.726840932159452, 2.8243760283451924, 2.9201299147166493, 3.0142218781632764, 3.106757952670825, 3.197832924099415, 3.2875319580874365, 3.375931934626007, 3.4631025517370007, 3.549107245515871, 3.6340039627396417, 3.717845814069932, 3.800681629771896, 3.8825564352512187, 3.963511860182911, 4.043586492284369, 4.122816184667403, 4.20123432404227, 4.278872065732518, 4.35575854041265, 4.4319210366408415, 4.507385162581086, 4.582174989758556, 4.656313181242153, 4.729821106278768, 4.802718943098832, 4.875025771359591, 4.9467596554817055, 5.017937719958137, 5.088576217565849, 5.1586905912855405, 5.2282955306284205, 5.297405022978756, 5.366032400483841, 5.434190382957021, 5.501891117202753, 5.5691462131237826, 5.63596677692834, 5.702363441718599, 5.768346395709908, 5.8339254083025365, 5.899109854203482, 5.9639087357746705, 6.028330703765293, 6.092384076569603, 6.1560768581371255, 6.219416754649365, 6.282411190065925, 6.345067320632837, 6.407392048437006, 6.469392034082798, 6.531073708559623, 6.5924432843631395, 6.653506765926959, 6.714269959416708, 6.774738481933707, 6.8349177701714545, 6.894813088564375, 6.954429536964975, 7.013772057882539, 7.072845443313761, 7.131654341193242, 7.190203261489541, 7.248496581970445, 7.30653855365925, 7.364333306002168, 7.421884851765479, 7.4791970916795485, 7.536273818845666, 7.593118722920407, 7.649735394091153, 7.706127326855513, 7.762297923616312, 7.818250498103179, 7.8739882786308675, 7.929514411203771, 7.984831962475524, 8.03994392257186, 8.094853207784444, 8.149562663142854, 8.204075064871427, 8.258393122737221, 8.312519482295007, 8.36645672703474], [0.0, 0.4269592694579762, 0.669970906532684, 0.8719975450775371, 1.0512970386380285, 1.2153936123284617, 1.3683108145456815, 1.5125166799021166, 1.6496618773626863, 1.7809186332610873, 1.9071570018363986, 2.029045061518097, 2.1471098121453838, 2.2617761786340234, 2.3733930697095813, 2.482251404446091, 2.588596951770527, 2.6926397055987925, 2.7945608786093294, 2.8945182178429802, 2.992650111666565, 3.0890788094092128, 3.1839129783660662, 3.2772497583641735, 3.369176430094696, 3.4597717828309604, 3.549107245515871, 3.637247829653601, 3.724252921104984, 3.81017694951256, 3.8950699578205574, 3.9789780896216556, 4.061944008446316, 4.144007260321649, 4.2252045887564025, 4.305570209605723, 4.385136051922504, 4.463931969829285, 4.541985929584091, 4.61932417531889, 4.695971376365046, 4.771950758619233, 4.847284222024593, 4.921992445929413, 4.996094983826194, 5.069610348757878, 5.142556090497, 5.214948865451394, 5.286804500121685, 5.3581380488269055, 5.428963846322124, 5.499295555852899, 5.569146213123783, 5.638528266600009, 5.70745361451137, 5.775933638884099, 5.843979236888986, 5.9116008497614185, 5.978808489520611, 6.045611763690458, 6.112019898202754, 6.178041758644405, 6.243685869993486, 6.308960434974235, 6.37387335114793, 6.438432226845087, 6.502644396034093, 6.566516932212277, 6.630056661397308, 6.693270174289512, 6.75616383766926, 6.818743805087747, 6.881016026904274, 6.942986259718512, 7.004660075241951, 7.066042868649028, 7.1271398664449395, 7.187956133884107, 7.248496581970446, 7.308765974068056, 7.368768932148665, 7.428509942700082, 7.487993362317973, 7.547223423001612, 7.606204237172637, 7.664939802434412, 7.7234340060883, 7.7816906294219415, 7.839713351783513, 7.897505754454999, 7.955071324336465, 8.012413457452622, 8.06953546229206, 8.126440562988869, 8.183131902355733, 8.2396125447769, 8.29588547896891, 8.351953620616454, 8.40781981489023, 8.463486838853221, 8.518957403761437, 8.574234157264716], [0.0, 0.43717238443528167, 0.6859970017350541, 0.8928562354137627, 1.0764446775323464, 1.2444665370623629, 1.401041608027192, 1.5486969618679896, 1.6891227525149497, 1.8235192466399976, 1.9527773106875348, 2.0775810039130844, 2.1984699322996555, 2.315879185215061, 2.4301660174852704, 2.5416283071384007, 2.6505177020376367, 2.75704921927594, 2.8614084062448106, 2.963756783386398, 3.064236049398045, 3.1629713778842006, 3.260074035525146, 3.3556434857893005, 3.4497690971729114, 3.54253154363472, 3.6340039627396417, 3.724252921104984, 3.813339225136041, 3.9013186064641743, 3.9882423050900555, 4.0741575683880376, 4.159108080425137, 4.2431343331925175, 4.326273949125109, 4.408561962541286, 4.490031066255528, 4.570711828518413, 4.650632884557186, 4.729821106278769, 4.808301753119338, 4.886098606552571, 4.963234090381037, 5.039729378615106, 5.115604492478234, 5.190878387856156, 5.265569034322214, 5.339693486715241, 5.413267950114995, 5.486307838948608, 5.558827830866861, 5.6308419159481184, 5.702363441718599, 5.773405154418089, 5.843979236888986, 5.914097343422234, 5.98377063185531, 6.0530097931840485, 6.121825078921006, 6.19022632640766, 6.258222982265479, 6.3258241241513815, 6.393038480965895, 6.459874451647212, 6.526340122670886, 6.5924432843631395, 6.658191446125165, 6.7235918506564785, 6.7886514872570745, 6.853377104280679, 6.917775220804769, 6.9818521375770715, 7.045613947292959, 7.109066544253326, 7.172215633448256, 7.235066739107905, 7.297625212758528, 7.3598962408183874, 7.42188485176548, 7.483595922906354, 7.545034186773002, 7.606204237172638, 7.667110534913241, 7.727757413225977, 7.788149082904013, 7.848289637175716, 7.908183056328969, 7.967833212102019, 8.0272438718552, 8.086418702536852, 8.145361274455725, 8.204075064871425, 8.262563461413519, 8.320829765339266, 8.378877194639266, 8.436708886999627, 8.494327902628733, 8.551737226956154, 8.608939773210734, 8.665938384884424, 8.722735838088056, 8.779334843804802], [0.0, 0.44725859854989114, 0.7018239681396627, 0.9134557505811727, 1.1012798498503507, 1.2731782224253154, 1.4333657120766576, 1.5844276935248474, 1.728093315053413, 1.865590535263319, 1.9978307742067098, 2.1255138733988392, 2.2491918883315964, 2.3693099465286322, 2.4862335452136435, 2.6002674349018458, 2.711669069345175, 2.8206584263992474, 2.9274253343085754, 3.03213504003103, 3.134932511462677, 3.2359458101483325, 3.3352887698553135, 3.4330631488215064, 3.52936037740667, 3.6242629908372073, 3.717845814069932, 3.81017694951256, 3.9013186064641743, 3.9913278023673815, 4.080256959405525, 4.16815441501983, 4.255064861133412, 4.341029723947617, 4.426087493902644, 4.510274013610461, 4.593622730157176, 4.676164917048162, 4.757929870167748, 4.838945081397534, 4.919236392946281, 4.998828134961472, 5.077743248596, 5.156003396375998, 5.23362906144419, 5.310639637026657, 5.387053507281401, 5.4628881205276345, 5.538160055720297, 5.612885082920175, 5.68707821841318, 5.760753775049499, 5.833925408302537, 5.906606158486706, 5.978808489520611, 6.050544324576943, 6.121825078921006, 6.192661690205738, 6.263064646461266, 6.333044011991098, 6.402609451364246, 6.471770251672614, 6.540535343205384, 6.608913318676689, 6.676912451129043, 6.74454071062303, 6.811805779812844, 6.878715068497801, 6.945275727231394, 7.011494660061859, 7.077378536471442, 7.14293380257545, 7.208166691636754, 7.273083233946499, 7.337689266117333, 7.401990439831583, 7.465992230083136, 7.529699942948601, 7.593118722920407, 7.656253559831786, 7.719109295401248, 7.781690629421941, 7.844002125619289, 7.906048217198515, 7.967833212102018, 8.029361297995004, 8.09063654699649, 8.151662920171455, 8.212444271798816, 8.272984353428836, 8.333286817742577, 8.39335522222517, 8.45319303266381, 8.512803626480652, 8.5721902959101, 8.63135625102933, 8.690304622650258, 8.749038465080735, 8.80756075876211, 8.865874412789902, 8.923982267323932, 8.981887095893763], [0.0, 0.45722378610564934, 0.7174610235172757, 0.9338080879268165, 1.1258170198247626, 1.3015453903668834, 1.4653019525495024, 1.619729684779357, 1.7665962617920397, 1.9071570018363984, 2.0423436319453514, 2.172871586519301, 2.2993052211747975, 2.422099581141431, 2.5416283071384003, 2.6582029397036315, 2.772086668811759, 2.8835043735558403, 2.992650111666565, 3.099692811902296, 3.2047806721300343, 3.3080446071819707, 3.409600987109455, 3.509553837384427, 3.607996625489435, 3.705013725584808, 3.800681629771896, 3.8950699578205574, 3.9882423050900555, 4.080256959405525, 4.171167510947729, 4.26102337414483, 4.349870236682566, 4.437750447762687, 4.524703355415289, 4.61076560084705, 4.695971376365045, 4.780352652266948, 4.863939377166812, 4.9467596554817055, 5.028839905200171, 5.1102049985598486, 5.190878387856156, 5.270882218269193, 5.350237429318286, 5.428963846322124, 5.507080263048682, 5.5846045165761025, 5.661553555248299, 5.737943500492392, 5.813789703166072, 5.88910679501834, 5.9639087357746705, 6.038208856295434, 6.112019898202754, 6.185354050324701, 6.258222982265479, 6.330637875375435, 6.402609451364246, 6.474147998774089, 6.545263397506319, 6.61596514157477, 6.68626236024078, 6.75616383766926, 6.825678031231035, 6.894813088564375, 6.963576863497579, 7.031976930924699, 7.100020600717812, 7.167714930751456, 7.235066739107904, 7.302082615525749, 7.368768932148664, 7.435131853626267, 7.501177346614407, 7.5669111887182545, 7.632338976917814, 7.697466135512241, 7.762297923616312, 7.826839442239711, 7.8910956409773165, 7.955071324336464, 8.01877115772509, 8.082199673122872, 8.145361274455723, 8.208260242692523, 8.270900740681519, 8.333286817742577, 8.395422414030236, 8.457311364681534, 8.518957403761437, 8.580364168017962, 8.641535200458103, 8.702473953754987, 8.763183793495964, 8.823668001280629, 8.88392977767726, 8.943972245045497, 9.003798450232697, 9.063411367150755, 9.122813899239944, 9.182008881825713], [0.0, 0.4670733636800189, 0.7329166673889773, 0.9539243099631819, 1.1500695246337473, 1.3295834598605374, 1.4968676883884873, 1.654622124028038, 1.8046525210066275, 1.948241239811168, 2.086340078866241, 2.2196798845583277, 2.348837169930152, 2.4742767828581154, 2.596380413081088, 2.7154663123860363, 2.831803340422164, 2.9456212206588246, 3.057118191244985, 3.1664668200255144, 3.273818497366211, 3.379306958284555, 3.4830510796915184, 3.5851571279900405, 3.6857205841520106, 3.7848276399375034, 3.8825564352512187, 3.9789780896216556, 4.0741575683880376, 4.16815441501983, 4.26102337414483, 4.352814924683592, 4.443575738532258, 4.5333490771848926, 4.62217513631226, 4.710091346450941, 4.797132636483386, 4.8833316654158105, 4.968719027019422, 5.0533234311405035, 5.13717186486753, 5.2202897362393, 5.302701002763801, 5.384428286675642, 5.4654929785761475, 5.545915330863747, 5.625714542164344, 5.7049088338048675, 5.783515519232782, 5.861551067165204, 5.939031159150108, 6.015970742135643, 6.092384076569603, 6.1682847804875856, 6.243685869993486, 6.318599796488783, 6.393038480965895, 6.4670133456453565, 6.540535343205384, 6.613614983825343, 6.6862623602407805, 6.758487170986879, 6.830298741988779, 6.901706046641077, 6.972717724504441, 7.0433420987346835, 7.113587192348353, 7.183460743418906, 7.252970219288691, 7.322122829873944, 7.390925540133007, 7.459385081761521, 7.5275079641727585, 7.595300484816063, 7.6627687388818035, 7.7299186284371135, 7.796755871032911, 7.8632860078193465, 7.929514411203771, 7.9954462920825184, 8.06108670667532, 8.126440562988867, 8.191512626933958, 8.256307528118793, 8.320829765339266, 8.385083711785471, 8.449073619982311, 8.512803626480652, 8.576277756314385, 8.639499927237594, 8.702473953754987, 8.765203550957906, 8.827692338177288, 8.88994384246422, 8.951961501907993, 9.013748668800874, 9.07530861265822, 9.136644523101976, 9.197759512615097, 9.2586566191739, 9.319338808764964, 9.379808977792713], [0.0, 0.4768123393424665, 0.748198758258097, 0.9738146448890524, 1.1740496955907964, 1.3573066870100212, 1.528078969357844, 1.6891227525149497, 1.8422814426021197, 1.98886413868428, 2.12984248519397, 2.265962567440984, 2.3978129193772415, 2.525868081451033, 2.6505177020376367, 2.772086668811759, 2.8908494474318176, 3.007040551345467, 3.120862352177608, 3.232491015995942, 3.3420810898161695, 3.4497690971729105, 3.555676393686979, 3.6599114615286696, 3.762571772549535, 3.8637453156993833, 3.963511860182911, 4.061944008446316, 4.159108080425137, 4.255064861133412, 4.349870236682566, 4.443575738532258, 4.536229011737226, 4.627874219839632, 4.718552396632663, 4.808301753119338, 4.897157946486401, 4.985154316715031, 5.072322095489055, 5.1586905912855405, 5.244287353902418, 5.329138321163079, 5.413267950114993, 5.496699334690388, 5.579454311507342, 5.6615535552482985, 5.7430166648509005, 5.823862241576094, 5.904107959875112, 5.98377063185531, 6.062866266041594, 6.141410121041853, 6.219416754649363, 6.296900068850227, 6.373873351147929, 6.45034931256889, 6.526340122670884, 6.601857441839871, 6.676912451129041, 6.751515879866162, 6.825678031231034, 6.899408805983598, 6.972717724504439, 7.045613947292959, 7.118106294053843, 7.190203261489541, 7.261913039905014, 7.333243528720772, 7.404202350981178, 7.474796866936882, 7.545034186773001, 7.614921182548182, 7.684464499403875, 7.753670566097931, 7.822545604911911, 7.8910956409773165, 7.959326511062074, 8.0272438718552, 8.094853207784443, 8.16215983839886, 8.229168925345734, 8.295885478968907, 8.362314364553479, 8.428460308239899, 8.494327902628731, 8.55992161209573, 8.625245777835456, 8.690304622650254, 8.75510225550025, 8.819642675828856, 8.883929777677256, 8.947967353600394, 9.0117590983961, 9.075308612658219, 9.138619406163858, 9.201694901104137, 9.26453843516728, 9.327153264482238, 9.389542566430539, 9.451709442333534, 9.513656920021774, 9.575387956292785], [0.0, 0.4864453552135282, 0.7633145803925411, 0.9934885735097438, 1.1977689629374375, 1.3847282861991201, 1.5589506724357445, 1.7232480150985197, 1.8795009625499923, 2.0290450615180964, 2.172871586519301, 2.3117416959876405, 2.4462558139970634, 2.5768980681128295, 2.704065978756877, 2.828090997293373, 2.949253134396721, 3.0677916413780424, 3.1839129783660662, 3.2977968705027574, 3.409600987109455, 3.519464609898928, 3.627511546233535, 3.7338524699434372, 3.8385868220991353, 3.941804369286795, 4.043586492284369, 4.144007260321649, 4.2431343331925175, 4.341029723947617, 4.437750447762687, 4.5333490771848926, 4.627874219839632, 4.7213709315029035, 4.813881074971567, 4.905443633223629, 4.996094983826194, 5.085869140326414, 5.174797965380267, 5.2629113595825165, 5.350237429318286, 5.436802636431514, 5.522631932074181, 5.607748876744073, 5.692175748223372, 5.775933638884099, 5.859042543620253, 5.941521439493129, 6.023388358030012, 6.104660450992425, 6.1853540503247, 6.265484722903621, 6.345067320632837, 6.424116026359575, 6.502644396034093, 6.580665397483043, 6.658191446125165, 6.7352344379206155, 6.811805779812844, 6.887916417893688, 6.963576863497579, 7.038797217409015, 7.113587192348352, 7.187956133884107, 7.261913039905015, 7.3354665787719835, 7.408625106258295, 7.481396681376057, 7.553789081177617, 7.625809814612401, 7.697466135512241, 7.768765054771641, 7.839713351783512, 7.910317585185579, 7.980584102967847, 8.050519051987248, 8.120128386931638, 8.18941787877184, 8.258393122737221, 8.327059545847426, 8.395422414030236, 8.463486838853221, 8.531257783894592, 8.598740070776778, 8.665938384884422, 8.732857280786842, 8.799501187383532, 8.865874412789902, 8.931981148979194, 8.997825476195377, 9.063411367150756, 9.128742691021067, 9.193823217249962, 9.2586566191739, 9.323246477477841, 9.387596283491263, 9.451709442333536, 9.515589275917021, 9.579239025815728, 9.642661856006848, 9.70586085549204, 9.768839040804865], [0.0, 0.49597672443940344, 0.7782709018441494, 1.01295490475193, 1.2212379468853654, 1.4118605353445226, 1.5894966203097645, 1.7570131912352118, 1.916327745748669, 2.0688019991679143, 2.2154466489586118, 2.3570377676288987, 2.494187543911342, 2.627389591325846, 2.75704921927594, 2.8835043735558408, 3.007040551345467, 3.1279016918259344, 3.2462983004883053, 3.3624136239938047, 3.4764084210231436, 3.5884247023632145, 3.698588701247381, 3.807013260039491, 3.9137997682499845, 4.01903975134394, 4.122816184667403, 4.2252045887564025, 4.326273949125109, 4.426087493902644, 4.524703355415289, 4.62217513631226, 4.718552396632663, 4.813881074971567, 4.908203854381942, 5.001560481670973, 5.0939880471847445, 5.1855212309289795, 5.276192519873848, 5.366032400483842, 5.455069529858223, 5.543330888332067, 5.6308419159481184, 5.717626634846569, 5.803707759318583, 5.88910679501834, 5.973844128618104, 6.0579391090141055, 6.1414101210418535, 6.2242746525330395, 6.306549355438733, 6.388250101651788, 6.469392034082797, 6.549989613476503, 6.630056661397307, 6.709606399762362, 6.788651487257074, 6.867204052930038, 6.945275727231393, 7.022877670729774, 7.100020600717812, 7.176714815893924, 7.25297021928869, 7.328796339586905, 7.404202350981179, 7.479197091679549, 7.553789081177617, 7.627986536395089, 7.701797386767224, 7.775229288373166, 7.848289637175717, 7.920985581440257, 7.993324033394548, 8.065311680185708, 8.136954994185725, 8.208260242692525, 8.279233497069615, 8.349880641363734, 8.420207380436702, 8.490219247644726, 8.559921612095732, 8.629319685512915, 8.698418528730418, 8.767223057845133, 8.835738050046732, 8.903968149146383, 8.97191787082306, 9.039591607605026, 9.106993633602688, 9.174128109007976, 9.24099908437418, 9.307610504689343, 9.373966213255274, 9.44006995538348, 9.505925381918557, 9.571536052598798, 9.636905439263197, 9.702036928913381, 9.766933826638494, 9.831599358410424, 9.896036673756468, 9.960248848315894], [0.0, 0.505410463457025, 0.7930740250780175, 1.032221841560004, 1.2444665370623629, 1.4387148677424273, 1.6197296847793572, 1.790432509279554, 1.952777310687535, 2.1081517048649774, 2.257585613276671, 2.401869869739378, 2.541628307138401, 2.6773639277832655, 2.8094897502762293, 2.938350148318845, 3.0642360493980454, 3.187396032546893, 3.308044607181971, 3.426368505412697, 3.5425315436347193, 3.656678433755033, 3.768937810029712, 3.879424661143909, 3.9882423050900564, 4.095484008195871, 4.20123432404227, 4.305570209605723, 4.408561962541286, 4.510274013610461, 4.61076560084705, 4.710091346450941, 4.808301753119338, 4.905443633223629, 5.001560481670973, 5.096692801273803, 5.190878387856157, 5.284152581055767, 5.376548485762119, 5.468097168308347, 5.5588278308668615, 5.648767966952949, 5.737943500492392, 5.826378910539165, 5.914097343422235, 6.001120713844672, 6.0874697962440045, 6.17316430754268, 6.2582229822654805, 6.342663640871883, 6.426503252041854, 6.509757989560025, 6.5924432843631395, 6.674573872246935, 6.75616383766926, 6.837226654035111, 6.917775220804769, 6.997821897727734, 7.077378536471442, 7.156456509884436, 7.235066739107905, 7.3132197187269465, 7.390925540133006, 7.468193913251494, 7.545034186773003, 7.621455367012951, 7.697466135512241, 7.773074865480731, 7.848289637175718, 7.923118252299016, 7.99756824748854, 8.071646906973449, 8.145361274455725, 8.218718164275554, 8.291724171912852, 8.364385683872863, 8.436708886999627, 8.50869977725756, 8.580364168017963, 8.651707697884397, 8.722735838088056, 8.79345389948186, 8.863867039159686, 8.933980266725184, 9.003798450232697, 9.073326321821126, 9.142568483060048, 9.211529410025927, 9.280213458125008, 9.348624866678268, 9.416767763282653, 9.484646167961966, 9.55226399711964, 9.619625067304986, 9.686733098803588, 9.753591719061843, 9.820204465954951, 9.886574790907103, 9.952706061871973, 10.018601566181147, 10.084264513267588, 10.149698037270845], [0.0, 0.514750320266457, 0.8077298313366433, 1.0512970386380285, 1.26746396212711, 1.4653019525495021, 1.6496618773626865, 1.8235192466399979, 1.9888641386842802, 2.1471098121453833, 2.2993052211747975, 2.4462558139970634, 2.5885969517705276, 2.7268409321594524, 2.8614084062448106, 2.9926501116665656, 3.1208623521776087, 3.2462983004883057, 3.369176430094696, 3.4896869238680814, 3.607996625489435, 3.7242529211049837, 3.8385868220991353, 3.9511154421186956, 4.061944008446316, 4.17116751094773, 4.278872065732518, 4.385136051922504, 4.490031066255528, 4.593622730157176, 4.695971376365045, 4.797132636483386, 4.897157946486401, 4.996094983826194, 5.0939880471847445, 5.190878387856157, 5.286804500121685, 5.381802376686576, 5.475905734210252, 5.569146213123784, 5.661553555248299, 5.753155762172254, 5.843979236888986, 5.934048910819158, 6.023388358030012, 6.112019898202754, 6.199964689681237, 6.287242813751617, 6.373873351147931, 6.459874451647212, 6.545263397506319, 6.630056661397307, 6.714269959416708, 6.797918299674015, 6.881016026904274, 6.96357686349758, 7.045613947292959, 7.1271398664449395, 7.208166691636754, 7.288706005884296, 7.368768932148664, 7.448366158952221, 7.5275079641727585, 7.606204237172638, 7.684464499403877, 7.762297923616312, 7.839713351783513, 7.916719311850126, 7.993324033394549, 8.069535462292059, 8.145361274455725, 8.220808888725406, 8.295885478968907, 8.370597985453687, 8.444953125542453, 8.518957403761437, 8.592617121285992, 8.665938384884424, 8.73892711535766, 8.811589055509218, 8.883929777677258, 8.955954690857906, 9.027669047446825, 9.099077949623863, 9.170186355403775, 9.24099908437418, 9.31152082314049, 9.381756130495928, 9.451709442333534, 9.52138507631586, 9.590787236316798, 9.65992001664916, 9.728787406090524, 9.79739329171906, 9.865741462570284, 9.933835613124879, 10.00167934663708, 10.069276178312515, 10.136629538343792, 10.203742774811541, 10.270619156458237, 10.337261875341527], [0.0, 0.523999799301531, 0.8222438196661404, 1.0701876532441241, 1.2902388510078748, 1.4916317655803013, 1.679304429001564, 1.8562858178839359, 2.0246017699787076, 2.185690938589677, 2.3406211263839167, 2.490212254576414, 2.6351111010444206, 2.7758391688597905, 2.912824667726, 3.04642463764033, 3.176940706597818, 3.3046305965350964, 3.429716706668968, 3.5523926372410846, 3.672828229924004, 3.7911735192257243, 3.9075618706565387, 4.022112502262567, 4.134932532141301, 4.246118657018551, 4.35575854041265, 4.463931969829285, 4.570711828518413, 4.676164917048162, 4.780352652266948, 4.8833316654158105, 4.985154316715031, 5.085869140326414, 5.1855212309289795, 5.284152581055767, 5.381802376686576, 5.478507257274715, 5.574301545329712, 5.669217449825271, 5.76328524700929, 5.856533441626989, 5.9489889111035295, 6.040677034848909, 6.131621810529601, 6.221845958886152, 6.311371018453838, 6.400217431356737, 6.48840462118802, 6.575951063855617, 6.662874352158925, 6.749191254765221, 6.8349177701714545, 6.920069176165812, 7.00466007524195, 7.088704436365736, 7.172215633448255, 7.255206480838883, 7.337689266117333, 7.419675780433145, 7.501177346614407, 7.582204845244095, 7.662768738881802, 7.742879094590506, 7.8225456049119115, 7.901777607419758, 7.980584102967846, 8.058973772738307, 8.136954994185725, 8.214535855963735, 8.291724171912852, 8.368527494181068, 8.444953125542451, 8.521008130973188, 8.59669934853937, 8.672033399646185, 8.747016698693953, 8.821655462182676, 8.895955717303355, 8.969923310051172, 9.043563912892873, 9.116883032018109, 9.18988601420213, 9.26257805330517, 9.334964196431875, 9.407049349772388, 9.478838284145102, 9.550335640259576, 9.621545933716817, 9.69247355976287, 9.763122797810471, 9.833497815742588, 9.903602674010603, 9.97344132953907, 10.04301763944817, 10.112335364604213, 10.181398173007825, 10.250209643028887, 10.318773266496676, 10.38709245165303, 10.455170525976017, 10.523010738880938], [0.0, 0.5331621833886192, 0.8366211413732437, 1.0889003900378262, 1.312799286971353, 1.5177136518156886, 1.708667860434496, 1.8887438525273428, 2.0600028885758332, 2.223908777416564, 2.3815479927507908, 2.5337547925033674, 2.681187263768341, 2.8243760283451924, 2.963756783386398, 3.099692811902296, 3.232491015995942, 3.3624136239938047, 3.4896869238680814, 3.614507901052126, 3.7370493669803935, 3.857463979585148, 3.975887436335647, 4.092441039861877, 4.207233781271882, 4.320364048079413, 4.4319210366408415, 4.541985929584091, 4.650632884557186, 4.757929870167748, 4.863939377166812, 4.968719027019422, 5.072322095489055, 5.174797965380267, 5.276192519873848, 5.376548485762119, 5.475905734210252, 5.574301545329712, 5.671770841775321, 5.768346395709908, 5.864059012775872, 5.9589376961373715, 6.053009793184048, 6.146301127096873, 6.238836115152857, 6.330637875375434, 6.421728322911345, 6.512128257324865, 6.601857441839872, 6.690934675424274, 6.779377858495881, 6.867204052930038, 6.954429536964974, 7.041069855528222, 7.127139866444938, 7.21265378293496, 7.297625212758527, 7.382067194329968, 7.465992230083134, 7.549412317341387, 7.632338976917813, 7.7147832796475235, 7.796755871032909, 7.878266994164301, 7.959326511062074, 8.03994392257186, 8.120128386931636, 8.19988873711811, 8.279233497069615, 8.358170896873718, 8.436708886999627, 8.51485515164821, 8.59261712128599, 8.670001984423601, 8.747016698693953, 8.823668001280629, 8.89996241874277, 8.975906276278822, 9.051505706468063, 9.126766657525666, 9.201694901104137, 9.276296039671456, 9.350575513493766, 9.424538607248397, 9.498190456291008, 9.571536052598796, 9.644580250410163, 9.717327771579674, 9.789783210665748, 9.861951039767385, 9.933835613124876, 10.00544117149859, 10.076771846338824, 10.14783166375882, 10.218624548322339, 10.289154326656208, 10.359424730897775, 10.429439401986416, 10.499201892807687, 10.56871567119815, 10.637984122818395, 10.707010553901286], [0.0, 0.5422405532018842, 0.8508666305538709, 1.107441540814393, 1.3351528555271137, 1.5435563807846724, 1.7377620445464965, 1.9209042639556155, 2.0950793974160224, 2.2617761786340234, 2.4220995811414316, 2.5768980681128304, 2.726840932159453, 2.872467830194441, 3.0142218781632772, 3.15247254484419, 3.2875319580874365, 3.4196668112880855, 3.549107245515871, 3.676053600355412, 3.800681629771896, 3.923146591066423, 4.043586492284369, 4.162124701525046, 4.278872065732518, 4.3939286477048345, 4.507385162581086, 4.61932417531889, 4.729821106278769, 4.838945081397534, 4.9467596554817055, 5.0533234311405035, 5.1586905912855405, 5.2629113595825165, 5.366032400483842, 5.468097168308347, 5.569146213123784, 5.669217449825271, 5.768346395709908, 5.866566380965499, 5.963908735774672, 6.060402957150284, 6.1560768581371255, 6.250956701617997, 6.345067320632838, 6.438432226845087, 6.5310737085596235, 6.623012919503384, 6.7142699594167095, 6.804863947365201, 6.8948130885643755, 6.9841347354090875, 7.072845443313761, 7.160961021895746, 7.248496581970446, 7.335466578771984, 7.42188485176548, 7.507764661375658, 7.593118722920407, 7.677959238006402, 7.762297923616312, 7.846146039092869, 7.92951441120377, 8.012413457452624, 8.094853207784444, 8.176843324819632, 8.258393122737223, 8.33951158491661, 8.420207380436702, 8.500488879522125, 8.580364168017963, 8.659841060967107, 8.73892711535766, 8.817629642101956, 8.895955717303357, 8.973912192862219, 9.051505706468065, 9.12874269102107, 9.205629383522442, 9.282171833470038, 9.358375910792645, 9.434247313353746, 9.509791574053114, 9.585014067552436, 9.659920016649162, 9.73451449832092, 9.808802449461208, 9.882788672325534, 9.956477839705737, 10.029874499849068, 10.102983081137243, 10.175807896539785, 10.248353147854878, 10.32062292975004, 10.392621233614177, 10.464351951231647, 10.535818878288426, 10.607025717719647, 10.677976082907298, 10.748673500736205, 10.819121414515982, 10.88932318677607], [0.0, 0.5512378045571162, 0.864984831230061, 1.1258170198247626, 1.3573066870100212, 1.5691681957935015, 1.7665962617920399, 1.952777310687535, 2.12984248519397, 2.2993052211747975, 2.462288826689833, 2.619655843234439, 2.7720866688117596, 2.9201299147166493, 3.064236049398045, 3.2047806721300347, 3.3420810898161695, 3.476408421023144, 3.607996625489435, 3.737049366980394, 3.8637453156993833, 3.9882423050900555, 4.110680633128088, 4.231185714926415, 4.349870236682566, 4.466835921509633, 4.582174989758556, 4.695971376365046, 4.808301753119338, 4.919236392946281, 5.028839905200171, 5.13717186486753, 5.244287353902418, 5.350237429318286, 5.455069529858223, 5.5588278308668615, 5.661553555248299, 5.76328524700929, 5.864059012775872, 5.963908735774672, 6.062866266041595, 6.160961590025481, 6.258222982265479, 6.354677141417322, 6.450349312568891, 6.545263397506319, 6.6394420543583195, 6.732906787849919, 6.8256780312310354, 6.917775220804769, 7.009216863860873, 7.100020600717812, 7.190203261489541, 7.279780918118129, 7.368768932148664, 7.457181998667077, 7.545034186773002, 7.632338976917814, 7.719109295401247, 7.805357546287946, 7.8910956409773165, 7.976335025635328, 8.061086706675319, 8.145361274455725, 8.229168925345736, 8.312519482295007, 8.395422414030236, 8.477886852989613, 8.559921612095733, 8.641535200458103, 8.722735838088056, 8.803531469701385, 8.883929777677258, 8.96393819423601, 9.043563912892873, 9.122813899239944, 9.201694901104137, 9.280213458125008, 9.358375910792644, 9.436188408982588, 9.513656920021774, 9.590787236316798, 9.667584982573349, 9.744055622633425, 9.820204465954948, 9.896036673756466, 9.971557264848025, 10.046771121167657, 10.12168299304158, 10.196297504184887, 10.270619156458235, 10.344652334395093, 10.418401309512944, 10.491870244421026, 10.56506319673628, 10.637984122818395, 10.710636881334144, 10.783025236660462, 10.855152862135212, 10.927023343163867, 10.998640180189954, 11.070006791536452], [0.0, 0.5601566638321537, 0.8789800215472076, 1.144032395269352, 1.379267494549765, 1.594556857821845, 1.7951792496141274, 1.9843726510025943, 2.164302685939278, 2.3365072772175486, 2.5021279076784597, 2.6620410744752627, 2.816938184242933, 2.9673767246394736, 3.1138144525557085, 3.2566330443472347, 3.3961549408463663, 3.5326556472353805, 3.6663729086498473, 3.7975136840726234, 3.9262595345363778, 4.052770847181663, 4.177190189962542, 4.299645007170162, 4.420249808230305, 4.539107962104952, 4.656313181242153, 4.771950758619233, 4.886098606552571, 4.998828134961472, 5.1102049985598486, 5.2202897362393, 5.329138321163079, 5.436802636431514, 5.543330888332067, 5.648767966952949, 5.753155762172254, 5.856533441626989, 5.9589376961373715, 6.060402957150284, 6.160961590025481, 6.260644066383387, 6.359479118236551, 6.457493876216805, 6.554713993869837, 6.651163759705377, 6.746866198453741, 6.841843162779836, 6.936115416537319, 7.02970271050274, 7.122623851408145, 7.214896764986962, 7.306538553659249, 7.3975655494061865, 7.4879933623179715, 7.577836925242533, 7.667110534913239, 7.755827889891053, 7.844002125619287, 7.931645846856564, 8.01877115772509, 8.105389689586307, 8.191512626933957, 8.277150731475238, 8.36231436455348, 8.447013508050665, 8.53125778389459, 8.615056472283511, 8.698418528730418, 8.781352600019606, 8.863867039159684, 8.945969919409517, 9.027669047446823, 9.108971975742989, 9.189886014202129, 9.27041824111749, 9.350575513493766, 9.430364476779879, 9.509791574053112, 9.588863054692114, 9.667584982573347, 9.745963243822779, 9.824003554152112, 9.901711465806642, 9.979092374149698, 10.056151523906768, 10.13289401509071, 10.209324808627821, 10.285448731703148, 10.361270482842082, 10.43679463674401, 10.51202564888281, 10.58696785988782, 10.661625499718014, 10.736002691641339, 10.810103456030182, 10.883931713983358, 10.957491290784272, 11.030785919204273, 11.103819242659599, 11.176594818229882, 11.249116119545524], [0.0, 0.56899970175744, 0.8928562354137625, 1.1620929174631116, 1.4010416080271917, 1.6197296847793567, 1.8235192466399976, 2.0156993917944788, 2.1984699322996546, 2.373393069709581, 2.5416283071384003, 2.704065978756877, 2.8614084062448106, 3.0142218781632764, 3.1629713778842006, 3.3080446071819707, 3.449769097172911, 3.5884247023632145, 3.7242529211049837, 3.857463979585148, 3.988242305090055, 4.1167508167475715, 4.243134333192517, 4.367522310643725, 4.490031066255528, 4.610765600847049, 4.729821106278768, 4.847284222024593, 4.963234090381037, 5.077743248596, 5.190878387856156, 5.302701002763801, 5.413267950114993, 5.522631932074181, 5.6308419159481184, 5.737943500492392, 5.843979236888986, 5.9489889111035295, 6.053009793184048, 6.1560768581371255, 6.258222982265479, 6.359479118236551, 6.45987445164721, 6.559436541433048, 6.658191446125165, 6.756163837669259, 6.853377104280679, 6.949853443606293, 7.04561394729296, 7.1406786779172595, 7.235066739107904, 7.328796339586904, 7.421884851765478, 7.514348865453269, 7.606204237172636, 7.69746613551224, 7.788149082904012, 7.878266994164301, 7.9678332121020174, 8.056860540463616, 8.145361274455723, 8.233347229060858, 8.320829765339264, 8.407819814890228, 8.494327902628731, 8.580364168017962, 8.665938384884422, 8.751059979930282, 8.835738050046732, 8.919981378522458, 9.003798450232695, 9.087197465886609, 9.170186355403773, 9.252772790484347, 9.334964196431875, 9.416767763282653, 9.49819045629101, 9.579239025815726, 9.65992001664916, 9.740239776827169, 9.820204465954948, 9.899820063081103, 9.979092374149698, 10.058027039057782, 10.136629538343788, 10.214905199530234, 10.292859203142461, 10.370496588423542, 10.44782225876395, 10.524840986863394, 10.601557419640772, 10.677976082907293, 10.754101385816606, 10.829937625104877, 10.905488989132941, 10.980759561741685, 11.055753325931224, 11.130474167373658, 11.204925877768554, 11.279112158049756, 11.353036621451524, 11.426702796441504], [0.0, 0.5777693457835779, 0.9066172819080087, 1.1800035440943222, 1.4226350045267986, 1.6446935867114862, 1.8516240323164253, 2.0467661323835205, 2.2323536033259965, 2.4099727239539845, 2.5808008680932057, 2.74574209208988, 2.9055095420778536, 3.0606782344770753, 3.2117203191634918, 3.3590294733215638, 3.502938276104176, 3.643730895243682, 3.7816525511584245, 3.916916710122839, 4.049710641888118, 4.180199776554899, 4.308531164758952, 4.434836257948549, 4.559233166003108, 4.681828508055088, 4.802718943098832, 4.921992445929413, 5.039729378615106, 5.156003396375998, 5.270882218269193, 5.384428286675642, 5.496699334690388, 5.607748876744073, 5.717626634846569, 5.826378910539165, 5.934048910819158, 6.040677034848909, 6.146301127096873, 6.250956701617997, 6.354677141417322, 6.457493876216805, 6.559436541433048, 6.660533120750644, 6.760810074324878, 6.860292454355043, 6.959004009524729, 7.056967279599546, 7.154203681298992, 7.250733586411856, 7.346576392999384, 7.441750590423468, 7.536273818845667, 7.630162923764201, 7.723434006088301, 7.816102468190795, 7.90818305632897, 7.999689899779716, 8.09063654699649, 8.181035999062052, 8.270900740681519, 8.360242768934503, 8.449073619982311, 8.537404393906279, 8.625245777835458, 8.712608067506373, 8.799501187383532, 8.885934709457093, 8.971917870823061, 9.05745959014157, 9.142568483060048, 9.227252876680165, 9.31152082314049, 9.395380112380403, 9.478838284145102, 9.561902639286515, 9.644580250410165, 9.726877971913986, 9.80880244946121, 9.890360128926082, 9.971557264848025, 10.05239992842706, 10.132894015090711, 10.213045251660306, 10.292859203142463, 10.37234127916954, 10.451496740111148, 10.530330702877123, 10.608848146430898, 10.687053917030877, 10.764952733216075, 10.84254919055126, 10.919847766145663, 10.996852822958417, 11.073568613902996, 11.149999285762025, 11.226148882923168, 11.302021350946, 11.37762053996924, 11.452950207966955, 11.528014023861974, 11.602815570504056], [0.0, 0.5864678912023005, 0.9202667627287333, 1.1977689629374375, 1.444053335719773, 1.6694550974567282, 1.8795009625499925, 2.0775810039130844, 2.265962567440984, 2.446255813997063, 2.6196558432344386, 2.787080322424254, 2.9492531343967214, 3.106757952670825, 3.260074035525146, 3.4096009871094553, 3.5556763936869795, 3.698588701247381, 3.8385868220991353, 3.975887436335647, 4.110680633128088, 4.2431343331925175, 4.373397801070037, 4.501604467262328, 4.627874219839633, 4.752315283127509, 4.875025771359591, 4.996094983826194, 5.115604492478234, 5.23362906144419, 5.350237429318286, 5.4654929785761475, 5.579454311507342, 5.692175748223372, 5.803707759318583, 5.914097343422235, 6.023388358030012, 6.131621810529601, 6.238836115152857, 6.345067320632838, 6.450349312568891, 6.554713993869837, 6.658191446125165, 6.760810074324878, 6.862596736992337, 6.963576863497579, 7.063774560069994, 7.1632127058202535, 7.261913039905016, 7.3598962408183874, 7.457181998667077, 7.553789081177617, 7.649735394091153, 7.745038036521528, 7.839713351783512, 7.933776974138735, 8.0272438718552, 8.120128386931638, 8.212444271798816, 8.304204723275921, 8.395422414030236, 8.486109521762133, 8.576277756314383, 8.665938384884424, 8.75510225550025, 8.84377981890476, 8.931981148979192, 9.019715961823792, 9.106993633602688, 9.19382321724996, 9.280213458125008, 9.366172808697302, 9.451709442333534, 9.536831266253694, 9.621545933716817, 9.70586085549204, 9.789783210665748, 9.873319956831544, 9.956477839705736, 10.039263402207755, 10.12168299304158, 10.203742774811541, 10.28544873170315, 10.36680667675729, 10.447822258763951, 10.528500968799635, 10.608848146430898, 10.688868985604667, 10.768568540244637, 10.847951729571543, 10.927023343163867, 11.005788045774416, 11.084250381917068, 11.162414780237025, 11.240285557677055, 11.317866923451227, 11.395162982837057, 11.472177740796079, 11.548915105432364, 11.62537889129777, 11.701572822552198, 11.777500535986624], [0.0, 0.5950975111719019, 0.9338080879268164, 1.2153936123284614, 1.4653019525495021, 1.6940204031852832, 1.9071570018363986, 2.1081517048649774, 2.299305221174797, 2.48225140444609, 2.658202939703631, 2.828090997293373, 2.9926501116665656, 3.1524725448441893, 3.3080446071819707, 3.4597717828309604, 3.607996625489435, 3.7530118255043523, 3.895069957820557, 4.034390890884796, 4.171167510947729, 4.305570209605722, 4.437750447762687, 4.567843619292108, 4.695971376365045, 4.82224353578094, 4.9467596554817055, 5.069610348757878, 5.190878387856156, 5.310639637026657, 5.428963846322124, 5.545915330863747, 5.6615535552482985, 5.775933638884099, 5.88910679501834, 6.001120713844672, 6.112019898202754, 6.221845958886152, 6.330637875375434, 6.438432226845087, 6.545263397506319, 6.651163759705377, 6.756163837669259, 6.860292454355043, 6.963576863497579, 7.066042868649026, 7.1677149307514565, 7.268616265571704, 7.368768932148665, 7.468193913251493, 7.566911188718254, 7.664939802434412, 7.762297923616311, 7.859002902983814, 7.955071324336464, 8.050519051987246, 8.145361274455723, 8.239612544776898, 8.333286817742575, 8.426397484357398, 8.518957403761435, 8.610978932844628, 8.702473953754986, 8.79345389948186, 8.883929777677258, 8.973912192862217, 9.063411367150755, 9.152437159611306, 9.24099908437418, 9.329106327583442, 9.416767763282653, 9.503991968315695, 9.590787236316796, 9.67716159085725, 9.763122797810473, 9.848678376991838, 9.933835613124877, 10.018601566181145, 10.102983081137241, 10.186986797188805, 10.270619156458235, 10.353886412229905, 10.436794636744011, 10.519349728577808, 10.601557419640772, 10.68342328180821, 10.764952733216074, 10.846151044237967, 10.927023343163867, 11.007574621598707, 11.087809739597532, 11.167733430552957, 11.247350305849405, 11.32666485929767, 11.40568147136245, 11.484404413194575, 11.56283785047893, 11.640985847108315, 11.718852368692856, 11.796441285913879, 11.873756377730684, 11.95080133444804], [0.0, 0.6036602657769329, 0.9472444901214154, 1.2328816996679575, 1.4863859275391569, 1.7183953681886257, 1.9345987522947945, 2.138485533153703, 2.332389524169469, 2.517968088258814, 2.696451359560456, 2.868783906868533, 3.0357108337227823, 3.197832924099415, 3.3556434857893005, 3.5095538373844275, 3.6599114615286696, 3.807013260039491, 3.9511154421186956, 4.092441039861878, 4.231185714926415, 4.367522310643725, 4.501604467262328, 4.63356952681461, 4.763540891903564, 4.891629959463465, 5.017937719958137, 5.142556090497, 5.265569034322214, 5.387053507281401, 5.507080263048682, 5.625714542164344, 5.7430166648509005, 5.859042543620253, 5.973844128618104, 6.0874697962440045, 6.199964689681237, 6.311371018453838, 6.421728322911345, 6.5310737085596235, 6.6394420543583195, 6.746866198453741, 6.853377104280679, 6.959004009524729, 7.063774560069994, 7.1677149307514565, 7.2708499344754305, 7.373203121056383, 7.474796866936884, 7.575652456803504, 7.675790157980724, 7.775229288373166, 7.873988278630867, 7.972084729130182, 8.069535462292059, 8.16635657069833, 8.262563461413519, 8.358170896873718, 8.45319303266381, 8.547643452469272, 8.641535200458103, 8.734880811321382, 8.827692338177288, 8.91998137852246, 9.011759098396102, 9.103036254905854, 9.193823217249962, 9.284129986357277, 9.373966213255274, 9.463341216265853, 9.552263997119638, 9.640743256071232, 9.728787406090524, 9.816404586198573, 9.903602674010603, 9.990389297543304, 10.076771846338824, 10.162757481953424, 10.248353147854878, 10.33356557876906, 10.418401309512944, 10.50286668334833, 10.58696785988782, 10.67071082258227, 10.754101385816606, 10.837145201638881, 10.919847766145661, 11.00221442554504, 11.084250381917068, 11.165960698690013, 11.247350305849407, 11.328424004895828, 11.40918647356611, 11.489642270331707, 11.56979583868706, 11.649651511239847, 11.729213513614269, 11.808485968177774, 11.887472897600963, 11.966178228259718, 12.044605793488131, 12.122759336690123], [0.0, 0.6121581102340997, 0.9605790373764017, 1.250237218180314, 1.507310074996987, 1.7425855582386345, 1.9618324799658902, 2.1685894151961183, 2.3652230308843896, 2.5534140209716356, 2.73440983643713, 2.909168342955967, 3.078445133037167, 3.2428494480113033, 3.4028815400601773, 3.558958517988611, 3.711432756022095, 3.860605335523455, 4.006736072401892, 4.1500511384197365, 4.290748949602055, 4.429004782429885, 4.564974439975785, 4.698797197662982, 4.830598195257217, 4.960490397849347, 5.088576217565849, 5.214948865451394, 5.339693486715241, 5.4628881205276345, 5.5846045165761025, 5.7049088338048675, 5.823862241576094, 5.941521439493129, 6.0579391090141055, 6.17316430754268, 6.287242813751617, 6.400217431356737, 6.512128257324865, 6.623012919503384, 6.732906787849919, 6.841843162779836, 6.949853443606293, 7.056967279599546, 7.1632127058202535, 7.268616265571704, 7.373203121056383, 7.476997153604133, 7.580021054655112, 7.682296408524618, 7.783843767844249, 7.884682722460575, 7.984831962475524, 8.084309336029415, 8.183131902355731, 8.281315980574746, 8.378877194639266, 8.475830514799105, 8.5721902959101, 8.667970312877946, 8.763183793495962, 8.857843448908547, 8.951961501907991, 9.045549713251184, 9.138619406163858, 9.231181489183582, 9.323246477477841, 9.414824512760537, 9.505925381918557, 9.596558534449654, 9.686733098803586, 9.776457897710156, 9.865741462570282, 9.954592046979634, 10.04301763944817, 10.131025975373676, 10.218624548322339, 10.30582062066506, 10.392621233614175, 10.479033216701621, 10.565063196736277, 10.65071760627529, 10.73600269164134, 10.820924520515502, 10.905488989132941, 10.989701829106705, 11.073568613902994, 11.157094764989523, 11.240285557677053, 11.323146126672727, 11.40568147136245, 11.487896460838478, 11.56979583868706, 11.651384227550151, 11.732666133474144, 11.813645950057685, 11.894327962409918, 11.974716350929672, 12.054815194915472, 12.13462847601557, 12.214160081526652, 12.293413807549278], [0.0, 0.6205929023412377, 0.9738146448890526, 1.2674639621271102, 1.528078969357844, 1.7665962617920399, 1.9888641386842807, 2.1984699322996555, 2.397812919377242, 2.588596951770527, 2.7720866688117596, 2.949253134396722, 3.1208623521776095, 3.287531958087437, 3.449769097172912, 3.607996625489436, 3.7625717725495353, 3.9137997682499854, 4.061944008446316, 4.207233781271883, 4.349870236682567, 4.490031066255528, 4.627874219839633, 4.763540891903564, 4.897157946486402, 5.028839905200172, 5.1586905912855405, 5.286804500121685, 5.413267950114995, 5.538160055720297, 5.661553555248299, 5.783515519232782, 5.904107959875112, 6.023388358030012, 6.1414101210418535, 6.2582229822654805, 6.373873351147931, 6.48840462118802, 6.601857441839872, 6.7142699594167095, 6.8256780312310354, 6.936115416537319, 7.04561394729296, 7.154203681298992, 7.261913039905016, 7.368768932148665, 7.474796866936884, 7.580021054655112, 7.684464499403878, 7.788149082904015, 7.891095640977317, 7.993324033394549, 8.094853207784444, 8.195701258212926, 8.29588547896891, 8.395422414030238, 8.494327902628733, 8.592617121285992, 8.690304622650256, 8.787404371428618, 8.883929777677258, 8.979893727684638, 9.075308612658219, 9.170186355403777, 9.264538435167282, 9.358375910792645, 9.451709442333536, 9.544549311244301, 9.636905439263197, 9.728787406090524, 9.82020446595495, 9.911165563152727, 10.001679346637077, 10.091754183728149, 10.181398173007825, 10.270619156458237, 10.359424730897775, 10.447822258763953, 10.535818878288424, 10.623421513105747, 10.710636881334144, 10.79747150416355, 10.883931713983358, 10.970023662079885, 11.055753325931226, 11.141126516125063, 11.226148882923166, 11.31082592249446, 11.395162982837057, 11.479165269408096, 11.562837850478928, 11.646185662231957, 11.729213513614269, 11.811926090962185, 11.894327962409918, 11.976423582094549, 12.058217294168797, 12.139713336632289, 12.220915844991309, 12.30182885575636, 12.382456309786344, 12.462802055487451], [0.0, 0.6289664092534478, 0.9869540856229498, 1.284565540646313, 1.5486969618679893, 1.7904325092795537, 2.015699391794479, 2.2281333446670035, 2.4301660174852704, 2.623524251755435, 2.8094897502762293, 2.9890466792689923, 3.1629713778842015, 3.3318898156641263, 3.4963159804384616, 3.656678433755033, 3.8133392251360405, 3.966607702869946, 4.1167508167475715, 4.264000948630483, 4.4085619625412855, 4.5506139476057506, 4.690316984851081, 4.827814173848091, 4.963234090381038, 5.096692801273802, 5.2282955306284205, 5.3581380488269055, 5.486307838948608, 5.612885082920175, 5.737943500492392, 5.861551067165204, 5.98377063185531, 6.104660450992425, 6.2242746525330395, 6.342663640871883, 6.459874451647212, 6.575951063855617, 6.690934675424274, 6.804863947365201, 6.917775220804769, 7.02970271050274, 7.1406786779172595, 7.250733586411856, 7.3598962408183874, 7.468193913251493, 7.575652456803504, 7.682296408524618, 7.788149082904015, 7.893232656907189, 7.997568247488539, 8.101175982381813, 8.204075064871425, 8.30628383316207, 8.407819814890228, 8.50869977725756, 8.608939773210732, 8.708555184044405, 8.80756075876211, 8.905970650493288, 9.003798450232695, 9.10105721814031, 9.197759512615095, 9.293917417334303, 9.389542566430539, 9.484646167961966, 9.579239025815728, 9.673331560171297, 9.766933826638494, 9.860055534174156, 9.952706061871973, 10.044894474711379, 10.13662953834379, 10.227919732987539, 10.318773266496676, 10.409198086663263, 10.499201892807688, 10.588792146707014, 10.677976082907296, 10.766760718461983, 10.855152862135212, 10.94315912310572, 11.030785919204273, 11.118039484714973, 11.204925877768552, 11.291450987353523, 11.377620539969236, 11.463440105943075, 11.548915105432364, 11.634050814130196, 11.718852368692856, 11.803324771905437, 11.887472897600961, 11.971301495347333, 12.054815194915472, 12.138018510541029, 12.220915844991307, 12.303511493448214, 12.385809647217402, 12.467814397273015, 12.549529737646989, 12.63095956867111], [0.0, 0.637280313659631, 0.9999999999999999, 1.3015453903668837, 1.5691681957935015, 1.8140990906881558, 2.0423436319453514, 2.257585613276671, 2.462288826689833, 2.658202939703631, 2.8466265971257654, 3.0285569742409577, 3.2047806721300347, 3.3759319346260064, 3.5425315436347193, 3.705013725584808, 3.863745315699383, 4.01903975134394, 4.171167510947729, 4.320364048079412, 4.466835921509632, 4.610765600847049, 4.752315283127509, 4.891629959463464, 5.028839905200171, 5.164062721374571, 5.297405022978756, 5.428963846322124, 5.558827830866861, 5.68707821841318, 5.813789703166072, 5.939031159150108, 6.062866266041594, 6.1853540503247, 6.306549355438733, 6.426503252041854, 6.545263397506319, 6.662874352158925, 6.779377858495881, 6.8948130885643755, 7.009216863860873, 7.122623851408145, 7.235066739107904, 7.346576392999384, 7.457181998667077, 7.566911188718254, 7.675790157980724, 7.783843767844249, 7.891095640977317, 7.997568247488539, 8.103282983463815, 8.208260242692523, 8.312519482295007, 8.416079282876947, 8.518957403761435, 8.62117083378504, 8.722735838088056, 8.823668001280629, 8.92398226732393, 9.023692976428562, 9.122813899239942, 9.22135826855194, 9.319338808764963, 9.416767763282653, 9.513656920021774, 9.61001763519263, 9.705860855492038, 9.801197138837153, 9.896036673756468, 9.990389297543304, 10.084264513267586, 10.177671505732913, 10.270619156458235, 10.363116057756462, 10.455170525976017, 10.546790613965737, 10.637984122818395, 10.728758612943514, 10.81912141451598, 10.909079637343183, 10.998640180189952, 11.087809739597532, 11.176594818229882, 11.265001732778117, 11.353036621451523, 11.44070545108138, 11.528014023861973, 11.614967983751272, 11.701572822552196, 11.787833885693848, 11.873756377730682, 11.95934536757641, 12.04460579348813, 12.129542467815243, 12.214160081526652, 12.298463208528796, 12.382456309786344, 12.466143737256461, 12.549529737646989, 12.63261845600804, 12.715413939166098, 12.797920139008944], [0.0, 0.6455362194233716, 1.01295490475193, 1.3184067869294, 1.5894966203097642, 1.8376005716185837, 2.0688019991679143, 2.2868324198659975, 2.4941875439113415, 2.692639705598792, 2.8835043735558403, 3.0677916413780424, 3.2462983004883057, 3.419666811288085, 3.5884247023632145, 3.7530118255043523, 3.913799768249984, 4.071106028516821, 4.225204588756402, 4.376333952815944, 4.524703355415289, 4.670497630039498, 4.813881074971567, 4.955000559670001, 5.0939880471847445, 5.230962662062971, 5.366032400483841, 5.499295555852899, 5.6308419159481184, 5.760753775049499, 5.88910679501834, 6.015970742135643, 6.141410121041853, 6.265484722903621, 6.388250101651788, 6.509757989560025, 6.630056661397307, 6.749191254765221, 6.867204052930038, 6.9841347354090875, 7.100020600717812, 7.214896764986962, 7.328796339586904, 7.441750590423468, 7.553789081177617, 7.664939802434412, 7.775229288373166, 7.884682722460575, 7.993324033394549, 8.101175982381813, 8.208260242692523, 8.31459747231566, 8.4202073804367, 8.525108788371309, 8.629319685512915, 8.732857280786842, 8.835738050046732, 8.937977779799871, 9.039591607605024, 9.140594059448853, 9.24099908437418, 9.340820086604454, 9.440069955383478, 9.538761092727025, 9.636905439263195, 9.734514498320918, 9.831599358410424, 9.928170714225677, 10.02423888628659, 10.119813839327678, 10.214905199530236, 10.309522270686115, 10.4036740493735, 10.497369239217893, 10.590616264305222, 10.683423281808212, 10.77579819388205, 10.867748658880645, 10.959282101940602, 11.050405724976182, 11.141126516125063, 11.23145125868154, 11.321386539550964, 11.410938757256584, 11.500114129527601, 11.588918700495025, 11.677358347520018, 11.765438787677487, 11.853165583916132, 11.940544150914585, 12.027579760651806, 12.114277547708797, 12.200642514317313, 12.286679535170279, 12.372393362007655, 12.457788627990402, 12.54286985187456, 12.627641441996488, 12.712107700079718, 12.796272824873096, 12.880140915629358, 12.963715975432612], [0.0, 0.6537356567441923, 1.025821201019164, 1.3351528555271135, 1.609686003209965, 1.8609413079774977, 2.0950793974160224, 2.315879185215061, 2.525868081451033, 2.726840932159452, 2.9201299147166493, 3.1067579526708253, 3.287531958087437, 3.4631025517370007, 3.6340039627396417, 3.800681629771896, 3.963511860182911, 4.122816184667403, 4.278872065732517, 4.4319210366408415, 4.582174989758556, 4.729821106278768, 4.875025771359591, 5.0179377199581365, 5.1586905912855405, 5.297405022978756, 5.434190382957021, 5.569146213123783, 5.702363441718599, 5.833925408302537, 5.9639087357746705, 6.092384076569603, 6.219416754649363, 6.345067320632837, 6.469392034082797, 6.5924432843631395, 6.714269959416708, 6.8349177701714545, 6.954429536964974, 7.072845443313761, 7.190203261489541, 7.306538553659249, 7.421884851765478, 7.536273818845667, 7.649735394091153, 7.762297923616311, 7.873988278630867, 7.984831962475524, 8.094853207784444, 8.204075064871425, 8.312519482295007, 8.4202073804367, 8.527158718823065, 8.633392557833336, 8.738927115357658, 8.84377981890476, 8.947967353600395, 9.051505706468063, 9.154410207339959, 9.256695566708144, 9.358375910792644, 9.459464814073954, 9.559975329511783, 9.659920016649162, 9.759310967781019, 9.858159832348653, 9.956477839705736, 10.054275820387526, 10.151564226002556, 10.248353147854877, 10.344652334395093, 10.440471207589463, 10.535818878288422, 10.63070416066872, 10.725135585816885, 10.81912141451598, 10.912669649292367, 11.005788045774418, 11.098484123410943, 11.190765175593093, 11.282638279220093, 11.374110303745928, 11.465187919741146, 11.555877607001415, 11.646185662231957, 11.736118206334801, 11.825681191323858, 11.914880406890871, 12.003721486643705, 12.092209914036864, 12.18035102801265, 12.26815002837021, 12.355611980878377, 12.442741822147191, 12.529544364272002, 12.616024299263014, 12.702186203272355, 12.788034540629956, 12.87357366769875, 12.958807836559027, 13.043741198531189, 13.128377807545505], [0.0, 0.6618800868883777, 1.0386011817742817, 1.3517865805679143, 1.6297399425537484, 1.8841254594443688, 2.1211805097276213, 2.3447310859057673, 2.5573360852696703, 2.7608127145720616, 2.9565097478449225, 3.1454628525174018, 3.3284889934016317, 3.5062468968921077, 3.6792774476916903, 3.8480316338823166, 4.012890450960225, 4.174179435343632, 4.332179506248801, 4.487135206030398, 4.639261066871717, 4.788746601923952, 4.935760269220212, 5.080452656701237, 5.222959068494566, 5.363401645176143, 5.501891117202753, 5.638528266600009, 5.773405154418089, 5.906606158486706, 6.038208856295434, 6.1682847804875856, 6.296900068850227, 6.424116026359575, 6.549989613476503, 6.674573872246935, 6.797918299674015, 6.920069176165812, 7.041069855528222, 7.160961021895746, 7.279780918118129, 7.3975655494061865, 7.514348865453269, 7.630162923764201, 7.745038036521528, 7.859002902983814, 7.972084729130182, 8.084309336029415, 8.195701258212926, 8.30628383316207, 8.416079282876947, 8.525108788371309, 8.633392557833336, 8.740949889102048, 8.847799227031395, 8.953958216247115, 9.059443749743135, 9.164272013713976, 9.26845852897537, 9.372018189286992, 9.474965296857448, 9.577313595282092, 9.679076300138219, 9.780266127439326, 9.880895320129689, 9.980975672782755, 10.080518554650773, 10.179534931198978, 10.2780353842451, 10.376030130813612, 10.473529040804168, 10.570541653564637, 10.6670771934511, 10.763144584449899, 10.858752463930331, 10.953909195590716, 11.048622881655232, 11.142901374374137, 11.236752286875737, 11.330183003414383, 11.423200689055385, 11.515812298834389, 11.60802458642587, 11.699844112352686, 11.791277251766253, 11.88233020182459, 11.973008988693538, 12.06331947419452, 12.15326736212053, 12.242858204240555, 12.332097406011004, 12.420990232011642, 12.509541811122133, 12.59775714145425, 12.685641095053839, 12.773198422385533, 12.86043375661251, 12.947351617682624, 13.033956416231655, 13.120252457313553, 13.206243943967086, 13.291934980627572], [0.0, 0.669970906532684, 1.0512970386380283, 1.3683108145456813, 1.649661877362686, 1.9071570018363984, 2.1471098121453838, 2.3733930697095813, 2.588596951770527, 2.794560878609329, 2.992650111666565, 3.1839129783660662, 3.369176430094696, 3.5491072455158705, 3.7242529211049837, 3.8950699578205574, 4.061944008446315, 4.225204588756402, 4.385136051922504, 4.541985929584091, 4.695971376365045, 4.847284222024593, 4.996094983826194, 5.142556090496999, 5.286804500121684, 5.428963846322124, 5.5691462131237826, 5.70745361451137, 5.843979236888986, 5.978808489520611, 6.112019898202754, 6.243685869993486, 6.373873351147929, 6.502644396034093, 6.630056661397307, 6.75616383766926, 6.881016026904274, 7.00466007524195, 7.127139866444938, 7.248496581970446, 7.368768932148664, 7.4879933623179715, 7.606204237172636, 7.723434006088301, 7.839713351783512, 7.955071324336464, 8.069535462292059, 8.183131902355731, 8.29588547896891, 8.407819814890228, 8.518957403761435, 8.629319685512915, 8.738927115357658, 8.847799227031395, 8.955954690857904, 9.063411367150755, 9.170186355403773, 9.276296039671456, 9.381756130495926, 9.486581703698123, 9.590787236316796, 9.694386639948952, 9.797393291719057, 9.899820063081105, 10.001679346637077, 10.102983081137241, 10.203742774811541, 10.303969527167016, 10.4036740493735, 10.502866683348328, 10.601557419640772, 10.699755914207655, 10.797471504163548, 10.894713222581569, 10.991489812414184, 11.087809739597532, 11.183681205397342, 11.279112158049758, 11.374110303745928, 11.468683117005304, 11.562837850478928, 11.656581544220774, 11.749921034462208, 11.842862961921893, 11.935413779681074, 12.027579760651804, 12.119367004663752, 12.210781445193224, 12.301828855756359, 12.392514855986946, 12.48284491741767, 12.572824368982502, 12.662458402256512, 12.75175207644837, 12.840710323159788, 12.929337950925069, 13.017639649543153, 13.105619994213722, 13.193283449488153, 13.280634373045354, 13.367677019302027, 13.454415542866089], [0.0, 0.6780094517591799, 1.0639108681478935, 1.3847282861991201, 1.6694550974567282, 1.9300397384803403, 2.172871586519301, 2.401869869739378, 2.6196558432344386, 2.828090997293373, 3.0285569742409573, 3.222114679700055, 3.4096009871094553, 3.5916906753761526, 3.768937810029712, 3.941804369286795, 4.110680633128088, 4.2759000709732256, 4.437750447762687, 4.596482265107116, 4.752315283127509, 4.905443633223628, 5.056039878584691, 5.20425827683102, 5.350237429318286, 5.494102453067794, 5.63596677692834, 5.775933638884099, 5.914097343422234, 6.050544324576943, 6.185354050324701, 6.318599796488783, 6.45034931256889, 6.580665397483043, 6.709606399762362, 6.837226654035111, 6.96357686349758, 7.088704436365736, 7.21265378293496, 7.335466578771984, 7.457181998667077, 7.577836925242533, 7.69746613551224, 7.816102468190795, 7.933776974138735, 8.050519051987246, 8.16635657069833, 8.281315980574746, 8.395422414030238, 8.50869977725756, 8.62117083378504, 8.732857280786842, 8.84377981890476, 8.953958216247115, 9.063411367150755, 9.172157346223543, 9.280213458125008, 9.387596283491263, 9.49432172136501, 9.600405028452162, 9.705860855492038, 9.810703280997853, 9.914945842597488, 10.018601566181147, 10.121682993041581, 10.22420220517436, 10.326170848889191, 10.427600156868888, 10.528500968799637, 10.628883750684722, 10.728758612943514, 10.828135327388383, 10.927023343163867, 11.025431801725054, 11.123369550925414, 11.220845158278342, 11.317866923451227, 11.414442890045924, 11.510580856715164, 11.606288387660294, 11.701572822552196, 11.79644128591388, 11.890900696000203, 11.984957773207492, 12.078619048043318, 12.17189086868433, 12.264779408148083, 12.357290671102806, 12.449430500337305, 12.5412045829117, 12.63261845600804, 12.723677512498707, 12.814387006249104, 12.90475205717006, 12.994777656034367, 13.0844686690708, 13.173829842348152, 13.26286580596095, 13.351581078027815, 13.439980068512616, 13.528067082878032, 13.615846325580417], [0.0, 0.685997001735054, 1.0764446775323462, 1.401041608027192, 1.6891227525149495, 1.9527773106875346, 2.198469932299655, 2.4301660174852704, 2.6505177020376367, 2.86140840624481, 3.064236049398045, 3.2600740355251463, 3.4497690971729114, 3.6340039627396417, 3.8133392251360405, 3.988242305090056, 4.159108080425136, 4.326273949125109, 4.490031066255528, 4.650632884557186, 4.808301753119337, 4.963234090381037, 5.115604492478233, 5.265569034322214, 5.413267950114994, 5.558827830866861, 5.702363441718599, 5.843979236888986, 5.98377063185531, 6.121825078921006, 6.258222982265479, 6.393038480965895, 6.526340122670884, 6.658191446125165, 6.788651487257074, 6.917775220804769, 7.045613947292959, 7.172215633448255, 7.297625212758527, 7.42188485176548, 7.545034186773002, 7.667110534913239, 7.788149082904012, 7.90818305632897, 8.0272438718552, 8.145361274455723, 8.262563461413519, 8.378877194639266, 8.494327902628733, 8.608939773210732, 8.722735838088056, 8.835738050046732, 8.947967353600395, 9.059443749743135, 9.170186355403773, 9.280213458125008, 9.389542566430539, 9.49819045629101, 9.606173214053886, 9.713506276162542, 9.820204465954948, 9.92628202780163, 10.031752658815682, 10.13662953834379, 10.240925355426214, 10.344652334395093, 10.44782225876395, 10.550446493546517, 10.652536006130054, 10.754101385816606, 10.85515286213521, 10.955700322018815, 11.055753325931223, 11.155321123021935, 11.254412665379945, 11.353036621451524, 11.451201388681467, 11.548915105432364, 11.646185662231957, 11.743020712394568, 11.839427682058881, 11.935413779681074, 12.030986005019159, 12.126151157641663, 12.220915844991303, 12.315286490031854, 12.409269338504467, 12.502870465817665, 12.596095783593467, 12.68895104589058, 12.781441855123946, 12.873573667698748, 12.96535179937556, 13.05678143038228, 13.147867610287413, 13.238615262648205, 13.329029189446327, 13.419114075322911, 13.508874491624002, 13.59831490026674, 13.687439657435952, 13.776253017120204], [0.0, 0.6939347821074004, 1.0889003900378262, 1.4172532832224345, 1.708667860434496, 1.975373207417599, 2.2239087774165642, 2.458285854840752, 2.681187263768341, 2.8945182178429802, 3.099692811902296, 3.297796870502758, 3.489686923868082, 3.676053600355412, 3.8574639795851486, 4.034390890884797, 4.207233781271882, 4.376333952815944, 4.541985929584091, 4.7044460970590745, 4.863939377166812, 5.020664461135344, 5.174797965380267, 5.326497770780483, 5.475905734210253, 5.623149911484568, 5.768346395709908, 5.9116008497614185, 6.0530097931840485, 6.192661690205738, 6.330637875375435, 6.4670133456453565, 6.601857441839871, 6.7352344379206155, 6.867204052930038, 6.997821897727734, 7.1271398664449395, 7.255206480838883, 7.382067194329968, 7.507764661375658, 7.632338976917814, 7.755827889891053, 7.878266994164301, 7.999689899779716, 8.120128386931638, 8.239612544776898, 8.358170896873718, 8.475830514799105, 8.592617121285992, 8.708555184044405, 8.823668001280629, 8.937977779799871, 9.051505706468063, 9.164272013713976, 9.276296039671456, 9.387596283491263, 9.49819045629101, 9.608095528158763, 9.717327771579672, 9.825902801614655, 9.933835613124877, 10.041140615304743, 10.14783166375882, 10.253922090334111, 10.359424730897775, 10.464351951231645, 10.56871567119815, 10.672527387317404, 10.775798193882052, 10.878538802724629, 10.980759561741685, 11.08247047226944, 11.183681205397342, 11.284401117298271, 11.38463926364727, 11.484404413194575, 11.583705060553154, 11.68254943825588, 11.78094552813305, 11.8789010720567, 11.976423582094547, 12.073520350112961, 12.170198456865267, 12.26646478059888, 12.362326005212289, 12.4577886279904, 12.552858966944832, 12.647543167783626, 12.741847210533114, 12.835776915833137, 12.929337950925069, 13.022535835351023, 13.115375946381086, 13.207863524184397, 13.300003676758818, 13.391801384632863, 13.483261505352692, 13.574388777766167, 13.665187826115105, 13.755663163946197, 13.845819197850378, 13.935660231039792], [0.0, 0.7018239681396626, 1.1012798498503504, 1.4333657120766574, 1.7280933150534128, 1.9978307742067096, 2.2491918883315964, 2.4862335452136435, 2.711669069345175, 2.927425334308575, 3.134932511462677, 3.3352887698553135, 3.5293603774066704, 3.7178458140699315, 3.901318606464174, 4.080256959405525, 4.255064861133412, 4.426087493902644, 4.5936227301571755, 4.7579298701677475, 4.91923639294628, 5.077743248596, 5.233629061444189, 5.3870535072814, 5.538160055720296, 5.68707821841318, 5.8339254083025365, 5.978808489520611, 6.121825078921006, 6.263064646461266, 6.402609451364246, 6.540535343205384, 6.676912451129041, 6.811805779812844, 6.945275727231393, 7.077378536471442, 7.208166691636754, 7.337689266117333, 7.465992230083134, 7.593118722920407, 7.719109295401247, 7.844002125619287, 7.9678332121020174, 8.09063654699649, 8.212444271798816, 8.333286817742575, 8.45319303266381, 8.5721902959101, 8.690304622650256, 8.80756075876211, 8.92398226732393, 9.039591607605024, 9.154410207339959, 9.26845852897537, 9.381756130495926, 9.49432172136501, 9.606173214053886, 9.717327771579672, 9.827801851425688, 9.937611246176909, 10.046771121167655, 10.15529604940717, 10.263200044021223, 10.370496588423542, 10.477198664409327, 10.583318778344161, 10.688868985604666, 10.793860913412265, 10.898305782188086, 11.002214425545038, 11.105597309022546, 11.208464547659734, 11.310825922494459, 11.412690896067792, 11.514068627006678, 11.614967983751272, 11.715397557487854, 11.815365674343088, 11.914880406890871, 12.013949585018816, 12.112580806197622, 12.210781445193224, 12.30855866325841, 12.405919416837824, 12.502870465817665, 12.59941838134899, 12.695569553271447, 12.79133019716223, 12.886706361033225, 12.981703931697794, 13.076328640826889, 13.170586070713034, 13.26448165975927, 13.358020707709022, 13.451208380631815, 13.544049715678653, 13.63654962562003, 13.728712903178684, 13.820544225168383, 13.9120481564493, 14.003229153709894, 14.094091569084547], [0.0, 0.7096656876134977, 1.113584826649027, 1.4493811979075462, 1.7474018932958728, 2.0201532214281275, 2.2743228793376087, 2.514013083806039, 2.7419674762292336, 2.960134459807802, 3.169960185694805, 3.3725550931568185, 3.568795129222077, 3.7593865781994156, 3.9449093749171786, 4.125847067337624, 4.302608157599088, 4.47554168479589, 4.64494884960278, 4.811091849541201, 4.97420070532395, 5.134478612338557, 5.292106190743069, 5.4472449004403085, 5.600039814078042, 5.750621890386604, 5.899109854203482, 6.045611763690458, 6.19022632640766, 6.333044011991098, 6.474147998774089, 6.613614983825343, 6.751515879866162, 6.887916417893688, 7.022877670729774, 7.156456509884436, 7.288706005884296, 7.419675780433145, 7.549412317341387, 7.677959238006402, 7.805357546287946, 7.931645846856564, 8.056860540463616, 8.181035999062052, 8.304204723275921, 8.426397484357398, 8.547643452469272, 8.667970312877946, 8.787404371428618, 8.905970650493288, 9.023692976428562, 9.140594059448853, 9.256695566708144, 9.372018189286992, 9.486581703698123, 9.600405028452162, 9.713506276162542, 9.825902801614655, 9.937611246176909, 10.048647578890243, 10.159027134536446, 10.268764648953985, 10.377874291842081, 10.486369697269259, 10.594263992080762, 10.701569822380078, 10.808299378242678, 10.914464416804911, 11.02007628385751, 11.125145934061054, 11.229683949890019, 11.333700559402327, 11.437205652922719, 11.540208798720478, 11.642719257755019, 11.744745997556619, 11.846297705303822, 11.947382800153957, 12.048009444878554, 12.148185556851237, 12.24791881843185, 12.34721668678711, 12.446086403184935, 12.544535001796708, 12.642569318039149, 12.740195996485037, 12.837421498369887, 12.934252108719658, 13.030693943122753, 13.126752954167909, 13.222434937568, 13.317745537988419, 13.412690254597344, 13.507274446354048, 13.601503337050321, 13.695382020118975, 13.788915463222576, 13.88210851263459, 13.97496589742443, 14.06749223345701, 14.1596920272169, 14.251569679466368], [0.0, 0.7174610235172757, 1.1258170198247626, 1.4653019525495021, 1.7665962617920394, 2.0423436319453514, 2.2993052211747975, 2.5416283071384007, 2.772086668811759, 2.992650111666565, 3.2047806721300343, 3.4096009871094553, 3.6079966254894353, 3.8006816297718955, 3.9882423050900555, 4.171167510947729, 4.349870236682566, 4.524703355415289, 4.695971376365045, 4.863939377166812, 5.028839905200171, 5.190878387856156, 5.350237429318285, 5.507080263048682, 5.6615535552482985, 5.813789703166073, 5.9639087357746705, 6.112019898202754, 6.258222982265479, 6.402609451364246, 6.545263397506319, 6.6862623602407805, 6.825678031231034, 6.963576863497579, 7.100020600717812, 7.235066739107905, 7.368768932148664, 7.501177346614407, 7.632338976917813, 7.762297923616312, 7.8910956409773165, 8.01877115772509, 8.145361274455723, 8.270900740681519, 8.395422414030236, 8.518957403761435, 8.641535200458103, 8.763183793495962, 8.883929777677258, 9.003798450232695, 9.122813899239942, 9.24099908437418, 9.358375910792644, 9.474965296857448, 9.590787236316796, 9.705860855492038, 9.820204465954948, 9.933835613124877, 10.046771121167655, 10.159027134536446, 10.270619156458235, 10.38156208463758, 10.491870244421024, 10.601557419640773, 10.710636881334143, 10.81912141451598, 10.927023343163867, 11.034354553560634, 11.141126516125063, 11.247350305849405, 11.353036621451524, 11.458195803339631, 11.562837850478926, 11.666972436241522, 11.770608923314015, 11.873756377730682, 11.976423582094545, 12.07861904804332, 12.18035102801265, 12.281627526344703, 12.382456309786342, 12.48284491741767, 12.58280067004845, 12.682330679117047, 12.781441855123946, 12.880140915629356, 12.978434392842354, 13.076328640826889, 13.173829842348148, 13.270944015381199, 13.367677019302025, 13.464034560779952, 13.560022199388875, 13.655645352953654, 13.750909302646914, 13.845819197850377, 13.940380060793988, 14.034596790985198, 14.128474169439967, 14.222016862726264, 14.315229426830221, 14.40811631085436], [0.0, 0.7252110165401895, 1.1379780623939404, 1.4811301014474711, 1.7856789830192843, 2.064404968211917, 2.324142249023774, 2.5690829018850216, 2.802030668050745, 3.0249766307738146, 3.2393986193562347, 3.44643139739638, 3.646970099668087, 3.8417364817395296, 4.0313231819948525, 4.216224340583954, 4.396857407943248, 4.573579068918601, 4.746697122028852, 4.916479508269851, 5.083161286991182, 5.246950104604558, 5.408030537778553, 5.566567583218383, 5.722709491409018, 5.876590089750613, 6.028330703765293, 6.178041758644405, 6.3258241241513815, 6.471770251672614, 6.61596514157477, 6.758487170986879, 6.899408805983598, 7.038797217409015, 7.176714815893924, 7.3132197187269465, 7.448366158952221, 7.582204845244095, 7.7147832796475235, 7.846146039092869, 7.976335025635328, 8.105389689586307, 8.233347229060858, 8.360242768934503, 8.486109521762133, 8.610978932844628, 8.734880811321382, 8.857843448908547, 8.979893727684638, 9.10105721814031, 9.22135826855194, 9.340820086604454, 9.459464814073954, 9.577313595282092, 9.694386639948952, 9.810703280997853, 9.92628202780163, 10.041140615304743, 10.15529604940717, 10.268764648953985, 10.38156208463758, 10.49370341508708, 10.605203120391007, 10.716075133274115, 10.826332868127082, 10.935989248068108, 11.045056730198024, 11.153547329194938, 11.261472639380761, 11.368843855379488, 11.475671791476222, 11.581966899775958, 11.687739287252429, 11.792998731769229, 11.897754697148423, 12.002016347355326, 12.10579255986238, 12.20909193824976, 12.311922824095683, 12.414293308204986, 12.516211241220702, 12.61768424365986, 12.718719715411396, 12.819324844731224, 12.919506616766853, 13.019271821641382, 13.11862706212462, 13.217578760916927, 13.316133167569541, 13.41429636506352, 13.512074276067656, 13.60947266889455, 13.706497163172452, 13.803153235249406, 13.899446223345112, 13.995381332464763, 14.090963639088285, 14.186198095647464, 14.281089534802655, 14.37564267352996, 14.46986211702914, 14.563752362461788], [0.0, 0.7329166673889772, 1.1500695246337473, 1.4968676883884868, 1.8046525210066273, 2.0863400788662405, 2.3488371699301513, 2.596380413081088, 2.8318033404221636, 3.0571181912449847, 3.2738184973662108, 3.4830510796915184, 3.6857205841520106, 3.8825564352512183, 4.074157568388037, 4.26102337414483, 4.443575738532258, 4.622175136312259, 4.7971326364833855, 4.968719027019422, 5.137171864867529, 5.3027010027638, 5.465492978576147, 5.625714542164343, 5.783515519232781, 5.939031159150108, 6.092384076569603, 6.243685869993486, 6.393038480965895, 6.540535343205384, 6.68626236024078, 6.830298741988779, 6.972717724504439, 7.113587192348352, 7.25297021928869, 7.390925540133006, 7.5275079641727585, 7.662768738881802, 7.796755871032909, 7.92951441120377, 8.061086706675319, 8.191512626933957, 8.320829765339264, 8.449073619982311, 8.576277756314383, 8.702473953754986, 8.827692338177288, 8.951961501907991, 9.075308612658219, 9.197759512615095, 9.319338808764963, 9.440069955383478, 9.559975329511783, 9.679076300138219, 9.797393291719057, 9.914945842597488, 10.031752658815682, 10.14783166375882, 10.263200044021223, 10.377874291842081, 10.491870244421024, 10.605203120391007, 10.717887553697155, 10.829937625104877, 10.941366891538001, 11.052188413427917, 11.162414780237023, 11.272058134304089, 11.38113019314523, 11.489642270331704, 11.59760529505462, 11.705029830476686, 11.811926090962181, 11.918303958268329, 12.024172996774004, 12.129542467815241, 12.234421343191102, 12.338818317898168, 12.44274182214719, 12.546200032710967, 12.64920088364869, 12.751752076448367, 12.853861089625644, 12.955535187814469, 13.056781430382278, 13.157606679599885, 13.25801760839411, 13.35802070770902, 13.457622293499782, 13.556828513381502, 13.655645352953652, 13.75407864181941, 13.852134059317772, 13.949817139985127, 14.047133278761848, 14.144087735958344, 14.240685641994125, 14.336932001922506, 14.432831699752747, 14.528389502580668, 14.623610064538079, 14.71849793057068], [0.0, 0.7405789389425276, 1.1620929174631118, 1.5125166799021166, 1.8235192466399979, 2.1081517048649774, 2.3733930697095817, 2.623524251755435, 2.8614084062448106, 3.089078809409213, 3.308044607181971, 3.519464609898929, 3.7242529211049846, 3.9231465910664234, 4.116750816747572, 4.305570209605723, 4.490031066255528, 4.670497630039499, 4.847284222024593, 5.020664461135344, 5.190878387856156, 5.3581380488269055, 5.522631932074182, 5.684528530742861, 5.843979236888987, 6.001120713844672, 6.1560768581371255, 6.308960434974235, 6.459874451647212, 6.608913318676689, 6.75616383766926, 6.901706046641077, 7.045613947292959, 7.187956133884107, 7.328796339586905, 7.468193913251494, 7.606204237172638, 7.742879094590506, 7.878266994164301, 8.012413457452624, 8.145361274455725, 8.277150731475238, 8.407819814890228, 8.537404393906279, 8.665938384884424, 8.79345389948186, 8.91998137852246, 9.045549713251184, 9.170186355403777, 9.293917417334303, 9.416767763282653, 9.538761092727025, 9.659920016649162, 9.780266127439326, 9.899820063081105, 10.018601566181147, 10.13662953834379, 10.253922090334111, 10.370496588423542, 10.486369697269259, 10.601557419640773, 10.716075133274115, 10.829937625104877, 10.94315912310572, 11.055753325931226, 11.167733430552959, 11.279112158049758, 11.389901777702374, 11.500114129527603, 11.609760645374346, 11.718852368692858, 11.827399973078343, 11.935413779681076, 12.04290377356703, 12.149879619105807, 12.256350674456007, 12.36232600521229, 12.467814397273017, 12.572824368982506, 12.677364182597564, 12.781441855123948, 12.885065168564802, 12.988241679619861, 13.090978728871134, 13.193283449488153, 13.29516277548329, 13.396623449545427, 13.497672030478155, 13.598314900266743, 13.698558270796493, 13.798408190243281, 13.897870549155822, 13.99695108624772, 14.09565539391613, 14.193988923502786, 14.291956990311972, 14.38956477839913, 14.486817345142862, 14.58371962561227, 14.680276436740733, 14.776492481316652, 14.872372351800818], [0.0, 0.7481987582580971, 1.1740496955907964, 1.528078969357844, 1.84228144260212, 2.1298424851939703, 2.397812919377242, 2.650517702037637, 2.890849447431818, 3.1208623521776087, 3.34208108981617, 3.55567639368698, 3.762571772549536, 3.9635118601829116, 4.159108080425137, 4.349870236682567, 4.536229011737227, 4.7185523966326635, 4.897157946486402, 5.0723220954890555, 5.244287353902418, 5.413267950114994, 5.579454311507342, 5.7430166648509005, 5.904107959875112, 6.0628662660415955, 6.219416754649365, 6.37387335114793, 6.526340122670886, 6.676912451129043, 6.825678031231035, 6.972717724504441, 7.118106294053843, 7.261913039905015, 7.404202350981179, 7.545034186773003, 7.684464499403877, 7.8225456049119115, 7.959326511062074, 8.094853207784444, 8.229168925345736, 8.36231436455348, 8.494327902628731, 8.625245777835458, 8.75510225550025, 8.883929777677258, 9.011759098396102, 9.138619406163858, 9.264538435167282, 9.389542566430539, 9.513656920021774, 9.636905439263195, 9.759310967781019, 9.880895320129689, 10.001679346637077, 10.121682993041581, 10.240925355426214, 10.359424730897775, 10.477198664409327, 10.594263992080762, 10.710636881334143, 10.826332868127082, 10.941366891538001, 11.055753325931226, 11.169506010906838, 11.282638279220095, 11.395162982837055, 11.507092517277146, 11.61843884437914, 11.729213513614267, 11.839427682058881, 11.94909213312885, 12.058217294168793, 12.16681325298107, 12.27488977337201, 12.382456309786342, 12.489522021094663, 12.59609578359347, 12.702186203272355, 12.80780162739852, 12.912950155464717, 13.01763964954315, 13.121877744084466, 13.225671855197945, 13.329029189446326, 13.43195675218606, 13.534461355481582, 13.63654962562003, 13.738228010250944, 13.839502785173739, 13.940380060793988, 14.040865788268286, 14.140965765355883, 14.240685641994126, 14.340030925613624, 14.439006986207843, 14.537619061170995, 14.635872259917063, 14.733771568292095, 14.831321852790916, 14.92852786458893, 15.025394243398777], [0.0, 0.7557770184415148, 1.1859412604500639, 1.5435563807846724, 1.860941307977498, 2.1514149621920264, 2.4220995811414316, 2.6773639277832655, 2.9201299147166493, 3.1524725448441893, 3.3759319346260064, 3.5916906753761526, 3.8006816297718964, 4.003656973743989, 4.20123432404227, 4.3939286477048345, 4.582174989758556, 4.766345068507743, 4.9467596554817055, 5.123697984782439, 5.297405022978755, 5.468097168308345, 5.63596677692834, 5.801185799781396, 5.963908735774671, 6.1242750528301455, 6.282411190065925, 6.438432226845087, 6.5924432843631395, 6.74454071062303, 6.894813088564375, 7.0433420987346835, 7.190203261489541, 7.3354665787719835, 7.479197091679549, 7.621455367012951, 7.762297923616312, 7.901777607419758, 8.03994392257186, 8.176843324819632, 8.312519482295007, 8.447013508050665, 8.580364168017962, 8.712608067506373, 8.84377981890476, 8.973912192862217, 9.103036254905854, 9.231181489183582, 9.358375910792645, 9.484646167961966, 9.61001763519263, 9.734514498320918, 9.858159832348653, 9.980975672782755, 10.102983081137241, 10.22420220517436, 10.344652334395093, 10.464351951231645, 10.583318778344161, 10.701569822380078, 10.81912141451598, 10.935989248068108, 11.052188413427917, 11.167733430552959, 11.282638279220095, 11.39691642722769, 11.510580856715162, 11.623644088752094, 11.736118206334803, 11.848014875915334, 11.959345367576411, 12.07012057395559, 12.18035102801265, 12.290046919725995, 12.399218111796355, 12.507874154429429, 12.616024299263014, 12.723677512498709, 12.83084248729336, 12.9375276554609, 13.043741198531189, 13.149491058208792, 13.254784946271199, 13.359630353943034, 13.464034560779954, 13.568004643093369, 13.67154748194488, 13.774669770737122, 13.877378022425763, 13.979678576375736, 14.081577604882911, 14.1830811193812, 14.284194976353454, 14.384924882963388, 14.485276402424573, 14.585254959121377, 14.684865843495862, 14.784114216713599, 14.883005115120628, 14.981543454502914, 15.079734034158955, 15.177581540795524], [0.0, 0.7633145803925411, 1.1977689629374375, 1.5589506724357445, 1.8795009625499923, 2.172871586519301, 2.4462558139970634, 2.704065978756877, 2.949253134396721, 3.183912978366066, 3.409600987109455, 3.6275115462335354, 3.8385868220991357, 4.043586492284369, 4.2431343331925175, 4.437750447762687, 4.627874219839632, 4.813881074971568, 4.996094983826194, 5.174797965380267, 5.350237429318285, 5.522631932074181, 5.692175748223371, 5.859042543620253, 6.023388358030012, 6.185354050324701, 6.345067320632837, 6.502644396034093, 6.658191446125165, 6.811805779812844, 6.963576863497579, 7.113587192348353, 7.261913039905014, 7.408625106258295, 7.553789081177617, 7.697466135512241, 7.839713351783513, 7.980584102967846, 8.120128386931636, 8.258393122737223, 8.395422414030236, 8.53125778389459, 8.665938384884422, 8.799501187383532, 8.931981148979192, 9.063411367150755, 9.193823217249962, 9.323246477477841, 9.451709442333536, 9.579239025815728, 9.705860855492038, 9.831599358410424, 9.956477839705736, 10.080518554650773, 10.203742774811541, 10.326170848889191, 10.44782225876395, 10.56871567119815, 10.688868985604666, 10.808299378242678, 10.927023343163867, 11.045056730198024, 11.162414780237023, 11.279112158049758, 11.395162982837055, 11.510580856715162, 11.62537889129777, 11.739569732530358, 11.853165583916134, 11.966178228259718, 12.07861904804332, 12.190499044539619, 12.301828855756359, 12.412618773299263, 12.522878758232357, 12.63261845600804, 12.741847210533114, 12.850574077431453, 12.958807836559028, 13.06655700382246, 13.17382984234815, 13.280634373045356, 13.386978384603143, 13.492869442958083, 13.598314900266741, 13.703321903414434, 13.80789740208939, 13.912048156449302, 14.015780744405248, 14.119101568546304, 14.222016862726266, 14.324532698332643, 14.426654990256528, 14.528389502580671, 14.629741854002024, 14.730717523003767, 14.831321852790918, 14.931560056002704, 15.031437219213965, 15.130958307237082, 15.230128167235215, 15.328951532656891], [0.0, 0.7708122744354743, 1.2095341059713987, 1.5742635401186036, 1.8979624508178456, 2.194214721799026, 2.4702842789514, 2.7306267964084903, 2.9782223146336517, 3.215187116164975, 3.4430919561889177, 3.663142952221981, 3.8762915250992203, 4.083304814368161, 4.284812723505699, 4.481340464186982, 4.6733317361256335, 4.861165652505305, 5.045169366211106, 5.225627666364705, 5.402790392844082, 5.576878248864214, 5.748087417271846, 5.916593269762551, 6.082553378809584, 6.24610998687802, 6.407392048437006, 6.566516932212277, 6.7235918506564785, 6.878715068497801, 7.031976930924699, 7.183460743418906, 7.333243528720772, 7.481396681376057, 7.627986536395089, 7.773074865480731, 7.916719311850126, 8.058973772738307, 8.19988873711811, 8.33951158491661, 8.477886852989613, 8.615056472283511, 8.751059979930282, 8.885934709457093, 9.019715961823792, 9.152437159611306, 9.284129986357277, 9.414824512760537, 9.544549311244301, 9.673331560171297, 9.801197138837153, 9.928170714225677, 10.054275820387526, 10.179534931198978, 10.303969527167016, 10.427600156868888, 10.550446493546517, 10.672527387317404, 10.793860913412265, 10.914464416804911, 11.034354553560634, 11.153547329194938, 11.272058134304089, 11.389901777702374, 11.507092517277146, 11.623644088752094, 11.739569732530358, 11.854882218772827, 11.969593870852204, 12.08371658731027, 12.197261862434212, 12.310240805557239, 12.422664159179432, 12.534542315996308, 12.64588533491492, 12.756702956130587, 12.867004615331082, 12.976799457089577, 13.0860963475026, 13.194903886124676, 13.303230417247157, 13.411084040565068, 13.518472621272249, 13.625403799622038, 13.731884999987917, 13.837923439455826, 13.943526135977638, 14.048699916113016, 14.153451422384888, 14.257787120272067, 14.361713304860675, 14.465236107174722, 14.568361500204594, 14.671095304651024, 14.773443194400885, 14.875410701750017, 14.97700322238733, 15.078226020153446, 15.179084231586332, 15.279582870265475, 15.379726830965529, 15.479520893629543], [0.0, 0.7782709018441495, 1.2212379468853654, 1.5894966203097645, 1.916327745748669, 2.2154466489586118, 2.4941875439113415, 2.7570492192759404, 3.007040551345467, 3.2462983004883053, 3.476408421023144, 3.6985887012473815, 3.9137997682499854, 4.122816184667403, 4.326273949125109, 4.52470335541529, 4.718552396632663, 4.908203854381942, 5.0939880471847445, 5.276192519873848, 5.455069529858222, 5.6308419159481184, 5.803707759318583, 5.973844128618104, 6.1414101210418535, 6.306549355438734, 6.469392034082798, 6.630056661397308, 6.7886514872570745, 6.945275727231394, 7.100020600717812, 7.252970219288691, 7.404202350981178, 7.553789081177617, 7.701797386767224, 7.848289637175718, 7.993324033394549, 8.136954994185725, 8.279233497069615, 8.420207380436702, 8.559921612095733, 8.698418528730418, 8.835738050046732, 8.971917870823061, 9.106993633602688, 9.24099908437418, 9.373966213255274, 9.505925381918557, 9.636905439263197, 9.766933826638494, 9.896036673756468, 10.02423888628659, 10.151564226002556, 10.2780353842451, 10.4036740493735, 10.528500968799637, 10.652536006130054, 10.775798193882052, 10.898305782188086, 11.02007628385751, 11.141126516125063, 11.261472639380761, 11.38113019314523, 11.500114129527603, 11.61843884437914, 11.736118206334803, 11.853165583916134, 11.969593870852204, 12.08541550976063, 12.200642514317313, 12.315286490031855, 12.429358653734948, 12.542869851874558, 12.655830577709263, 12.768250987479338, 12.880140915629358, 12.991509889149851, 13.102367141099817, 13.212721623366987, 13.322582018717934, 13.431956752186062, 13.540854001841648, 13.649281708984676, 13.757247587798032, 13.864759134495824, 13.971823635998833, 14.078448178166894, 14.184639653615656, 14.290404769143235, 14.395750052790493, 14.500681860556833, 14.60520638279202, 14.70932965028302, 14.813057540053537, 14.916395780892795, 15.019349958628911, 15.121925521161213, 15.224127783264938, 15.325961931180847, 15.427433027001433, 15.528546012864762, 15.629305714966154], [0.0, 0.7856912362696148, 1.2328816996679572, 1.6046514930705182, 1.934598752294794, 2.2365695702937094, 2.517968088258814, 2.7833359880424697, 3.0357108337227814, 3.277249758364173, 3.509553837384427, 3.7338524699434377, 3.951115442118696, 4.1621247015250455, 4.367522310643725, 4.567843619292109, 4.763540891903563, 4.955000559670001, 5.142556090496999, 5.326497770780482, 5.507080263048682, 5.68452853074286, 5.859042543620253, 6.030801058570017, 6.199964689681237, 6.3666784251202175, 6.531073708559623, 6.693270174289512, 6.853377104280679, 7.011494660061859, 7.167714930751456, 7.322122829873944, 7.474796866936882, 7.625809814612401, 7.775229288373166, 7.923118252299016, 8.069535462292059, 8.214535855963735, 8.358170896873718, 8.500488879522125, 8.641535200458103, 8.781352600019606, 8.919981378522458, 9.05745959014157, 9.19382321724996, 9.329106327583442, 9.463341216265853, 9.596558534449654, 9.728787406090524, 9.860055534174156, 9.990389297543304, 10.119813839327678, 10.248353147854877, 10.376030130813612, 10.502866683348328, 10.628883750684722, 10.754101385816606, 10.878538802724629, 11.002214425545038, 11.125145934061054, 11.247350305849405, 11.368843855379488, 11.489642270331704, 11.609760645374346, 11.729213513614267, 11.848014875915334, 11.966178228259718, 12.08371658731027, 12.200642514317313, 12.316968137499757, 12.432705173018608, 12.547864944650131, 12.66245840225651, 12.776496139143088, 12.889988408383642, 13.002945138188135, 13.115375946381086, 13.227290154053035, 13.338696798442456, 13.449604645100765, 13.560022199388875, 13.669957717349936, 13.77941921599934, 13.888414483069969, 13.996951086247718, 14.105036381929676, 14.212677523534996, 14.319881469396176, 14.426654990256528, 14.533004676397772, 14.638936944419852, 14.744458043693715, 14.84957406250617, 14.954290933914725, 15.058614441329093, 15.16255022383482, 15.266103781273609, 15.369280479093808, 15.472085552983792, 15.574524113299997, 15.676601149300735, 15.778321533196127], [0.0, 0.7930740250780174, 1.2444665370623629, 1.619729684779357, 1.9527773106875348, 2.257585613276671, 2.5416283071384007, 2.8094897502762293, 3.064236049398045, 3.3080446071819707, 3.5425315436347193, 3.7689378100297124, 3.9882423050900564, 4.20123432404227, 4.408561962541286, 4.61076560084705, 4.808301753119338, 5.001560481670973, 5.190878387856156, 5.376548485762118, 5.558827830866861, 5.737943500492392, 5.914097343422234, 6.0874697962440045, 6.258222982265479, 6.426503252041854, 6.5924432843631395, 6.75616383766926, 6.917775220804769, 7.077378536471442, 7.235066739107904, 7.390925540133007, 7.545034186773001, 7.697466135512241, 7.848289637175717, 7.99756824748854, 8.145361274455725, 8.291724171912852, 8.436708886999627, 8.580364168017963, 8.722735838088056, 8.863867039159684, 9.003798450232695, 9.142568483060048, 9.280213458125008, 9.416767763282653, 9.552263997119638, 9.686733098803586, 9.82020446595495, 9.952706061871973, 10.084264513267586, 10.214905199530236, 10.344652334395093, 10.473529040804168, 10.601557419640772, 10.728758612943514, 10.85515286213521, 10.980759561741685, 11.105597309022546, 11.229683949890019, 11.353036621451524, 11.475671791476222, 11.59760529505462, 11.718852368692858, 11.839427682058881, 11.959345367576411, 12.07861904804332, 12.197261862434212, 12.315286490031855, 12.432705173018608, 12.549529737646987, 12.665771614097723, 12.781441855123946, 12.89655115357155, 13.011109858857857, 13.125127992483772, 13.238615262648205, 13.351581078027815, 13.464034560779956, 13.575984558822007, 13.687439657435952, 13.798408190243281, 13.90889824959169, 14.0189176963919, 14.128474169439965, 14.237575094257744, 14.346227691481864, 14.454438984829162, 14.562215808664591, 14.6695648151958, 14.776492481316648, 14.883005115120625, 14.989108862103446, 15.094809711072903, 15.20011349978282, 15.305025920306708, 15.409552524165816, 15.513698727225211, 15.617469814370692, 15.720870943978417, 15.823907152188534, 15.926583356993136], [0.0, 0.8004199906055426, 1.2559935925355508, 1.6347326706949878, 1.9708651995272086, 2.2784968341288927, 2.5651705154791467, 2.8355130648759403, 3.0926189892943095, 3.3386858599269256, 3.57534476633124, 3.8038481542754976, 4.0251839896771, 4.24014887872641, 4.449396920160281, 4.653473499590788, 4.852839359707674, 5.047888175833662, 5.23895966714281, 5.4263495618086965, 5.61031729632373, 5.791092051347222, 5.968877545316923, 6.143855886141047, 6.316190698818502, 6.48602968949816, 6.653506765926959, 6.818743805087747, 6.9818521375770715, 7.14293380257545, 7.302082615525749, 7.459385081761521, 7.614921182548182, 7.768765054771641, 7.920985581440257, 8.071646906973449, 8.220808888725406, 8.368527494181068, 8.51485515164821, 8.659841060967107, 8.803531469701385, 8.945969919409517, 9.087197465886609, 9.227252876680165, 9.366172808697302, 9.503991968315695, 9.640743256071232, 9.776457897710156, 9.911165563152727, 10.044894474711379, 10.177671505732913, 10.309522270686115, 10.440471207589463, 10.570541653564637, 10.699755914207655, 10.828135327388383, 10.955700322018815, 11.08247047226944, 11.208464547659734, 11.333700559402327, 11.458195803339631, 11.581966899775958, 11.705029830476686, 11.827399973078343, 11.94909213312885, 12.07012057395559, 12.190499044539619, 12.310240805557239, 12.429358653734948, 12.547864944650131, 12.665771614097723, 12.78309019813219, 12.899831851884427, 13.016007367244393, 13.131627189492422, 13.246701432955053, 13.361239895754824, 13.475252073717657, 13.588747173496236, 13.701734124963087, 13.814221592922635, 13.926217988187775, 14.03773147806277, 14.148769996271193, 14.259341252364571, 14.369452740644762, 14.47911174863061, 14.588325365097164, 14.697100487713698, 14.805443830304917, 14.913361929757869, 15.02086115259569, 15.127947701237664, 15.234627619963797, 15.340906800600974, 15.446790987946379, 15.552285784943049, 15.6573966576213, 15.762128939818968, 15.86648783769244, 15.970478434029847, 16.07410569237692], [0.0, 0.8077298313366432, 1.2674639621271098, 1.649661877362686, 1.98886413868428, 2.299305221174797, 2.588596951770527, 2.8614084062448106, 3.120862352177608, 3.3691764300946954, 3.607996625489435, 3.8385868220991357, 4.061944008446316, 4.278872065732518, 4.490031066255528, 4.695971376365046, 4.897157946486401, 5.0939880471847445, 5.286804500121684, 5.475905734210252, 5.6615535552482985, 5.843979236888985, 6.023388358030011, 6.199964689681236, 6.373873351147929, 6.545263397506319, 6.714269959416708, 6.881016026904274, 7.045613947292959, 7.208166691636754, 7.368768932148664, 7.5275079641727585, 7.684464499403875, 7.839713351783512, 7.993324033394548, 8.145361274455725, 8.295885478968907, 8.444953125542451, 8.59261712128599, 8.73892711535766, 8.883929777677258, 9.027669047446823, 9.170186355403773, 9.31152082314049, 9.451709442333534, 9.590787236316796, 9.728787406090524, 9.865741462570282, 10.001679346637077, 10.13662953834379, 10.270619156458235, 10.4036740493735, 10.535818878288422, 10.6670771934511, 10.797471504163548, 10.927023343163867, 11.055753325931223, 11.183681205397342, 11.310825922494459, 11.437205652922719, 11.562837850478926, 11.687739287252429, 11.811926090962181, 11.935413779681076, 12.058217294168793, 12.18035102801265, 12.301828855756359, 12.422664159179432, 12.542869851874558, 12.66245840225651, 12.781441855123946, 12.899831851884427, 13.017639649543149, 13.134876138547082, 13.251551859568142, 13.367677019302025, 13.48326150535269, 13.598314900266741, 13.712846494776686, 13.826865300307166, 13.940380060793986, 14.053399263861847, 14.165931151402972, 14.27798372959571, 14.389564778399125, 14.500681860556831, 14.611342330140983, 14.721553340664917, 14.831321852790916, 14.94065464165773, 15.049558303850572, 15.158039264034894, 15.266103781273607, 15.37375795504615, 15.481007730986553, 15.587858906356397, 15.694317135267632, 15.800387933669132, 15.906076684110042, 16.011388640292, 16.116328931421744, 16.220902566374612], [0.0, 0.8150042230112483, 1.2788787061866451, 1.6645186848755922, 2.0067757920256257, 2.320012697993638, 2.6119097816108052, 2.887178168212853, 3.1489687489349265, 3.3995191363097166, 3.6404901395286915, 3.873157024829817, 4.098525759585626, 4.317407464728685, 4.530468157148949, 4.738263159779661, 4.941261610376338, 5.139864357311434, 5.334417309688601, 5.525221584063096, 5.71254134404827, 5.896609946141164, 6.07763482067713, 6.255801393702467, 6.431276271582167, 6.604209851778197, 6.774738481933707, 6.942986259718512, 7.109066544253326, 7.273083233946499, 7.435131853626267, 7.595300484816063, 7.753670566097931, 7.910317585185579, 8.065311680185708, 8.218718164275554, 8.370597985453687, 8.521008130973188, 8.670001984423601, 8.817629642101956, 8.96393819423601, 9.108971975742989, 9.252772790484347, 9.395380112380403, 9.536831266253694, 9.67716159085725, 9.816404586198573, 9.954592046979634, 10.091754183728149, 10.227919732987539, 10.363116057756462, 10.497369239217893, 10.63070416066872, 10.763144584449899, 10.894713222581569, 11.025431801725054, 11.155321123021935, 11.284401117298271, 11.412690896067792, 11.540208798720478, 11.666972436241522, 11.792998731769229, 11.918303958268329, 12.04290377356703, 12.16681325298107, 12.290046919725995, 12.412618773299263, 12.534542315996308, 12.655830577709263, 12.776496139143088, 12.89655115357155, 13.016007367244393, 13.134876138547082, 13.253168456005632, 13.370894955220955, 13.488065934809955, 13.604691371424062, 13.720780933910026, 13.836343996672424, 13.951389652292526, 14.065926723453776, 14.179963774220175, 14.293509120710194, 14.406570841205596, 14.519156785731527, 14.631274585141455, 14.742931659738101, 14.854135227459135, 14.964892311654364, 15.075209748479242, 15.185094193927643, 15.294552130525368, 15.40358987370427, 15.512213577875526, 15.620429242219373, 15.728242716207365, 15.83565970487222, 15.942685773839294, 16.04932635413281, 16.155586746769096, 16.261472127148373, 16.36698754925577], [0.0, 0.8222438196661404, 1.2902388510078748, 1.6793044290015637, 2.0246017699787076, 2.3406211263839167, 2.6351111010444206, 2.9128246677260003, 3.1769407065978186, 3.429716706668968, 3.6728282299240043, 3.907561870656539, 4.134932532141301, 4.35575854041265, 4.570711828518413, 4.780352652266949, 4.985154316715031, 5.18552123092898, 5.381802376686575, 5.574301545329712, 5.763285247009289, 5.94898891110353, 6.131621810529601, 6.311371018453838, 6.48840462118802, 6.6628743521589255, 6.8349177701714545, 7.004660075241951, 7.172215633448256, 7.337689266117333, 7.501177346614407, 7.6627687388818035, 7.822545604911911, 7.980584102967847, 8.136954994185725, 8.291724171912852, 8.444953125542453, 8.59669934853937, 8.747016698693953, 8.895955717303357, 9.043563912892873, 9.189886014202129, 9.334964196431875, 9.478838284145102, 9.621545933716817, 9.763122797810473, 9.903602674010603, 10.04301763944817, 10.181398173007825, 10.318773266496676, 10.455170525976017, 10.590616264305222, 10.725135585816885, 10.858752463930331, 10.991489812414184, 11.123369550925414, 11.254412665379945, 11.38463926364727, 11.514068627006678, 11.642719257755019, 11.770608923314015, 11.897754697148423, 12.024172996774004, 12.149879619105807, 12.27488977337201, 12.399218111796355, 12.522878758232357, 12.64588533491492, 12.768250987479338, 12.889988408383642, 13.011109858857857, 13.131627189492422, 13.251551859568142, 13.370894955220955, 13.489667206526695, 13.60787900358379, 13.725540411665222, 13.84266118550508, 13.959250782779792, 14.075318376839071, 14.19087286873733, 14.305922898612243, 14.42047685645349, 14.534542892301358, 14.648128925911939, 14.761242655922771, 14.87389156855034, 14.986082945848494, 15.09782387355472, 15.209121248549323, 15.319981785950663, 15.430412025868137, 15.540418339832916, 15.650006936925163, 15.759183869615198, 15.867955039334817, 15.976326201793942, 16.084302972056793, 16.191890829390807, 16.299095121900685, 16.405921070959185, 16.512373775445443], [0.0, 0.8294492546152544, 1.3015453903668834, 1.6940204031852835, 2.0423436319453514, 2.3611323091539242, 2.6582029397036315, 2.938350148318845, 3.2047806721300347, 3.45977178283096, 3.705013725584808, 3.941804369286795, 4.17116751094773, 4.3939286477048345, 4.610765600847049, 4.822243535780941, 5.028839905200171, 5.2309626620629714, 5.428963846322124, 5.623149911484568, 5.813789703166073, 6.001120713844671, 6.185354050324701, 6.3666784251202175, 6.54526339750632, 6.7212620305705375, 6.894813088564375, 7.066042868649028, 7.235066739107905, 7.401990439831583, 7.5669111887182545, 7.7299186284371135, 7.8910956409773165, 8.050519051987248, 8.208260242692525, 8.364385683872863, 8.518957403761437, 8.672033399646185, 8.823668001280629, 8.973912192862219, 9.122813899239944, 9.27041824111749, 9.416767763282653, 9.561902639286515, 9.70586085549204, 9.848678376991838, 9.990389297543304, 10.131025975373676, 10.270619156458237, 10.409198086663263, 10.546790613965737, 10.683423281808212, 10.81912141451598, 10.953909195590716, 11.087809739597532, 11.220845158278342, 11.353036621451524, 11.484404413194575, 11.614967983751272, 11.744745997556619, 11.873756377730682, 12.002016347355326, 12.129542467815241, 12.256350674456007, 12.382456309786342, 12.507874154429429, 12.63261845600804, 12.756702956130587, 12.880140915629358, 13.002945138188135, 13.125127992483772, 13.246701432955053, 13.367677019302025, 13.488065934809955, 13.60787900358379, 13.727126706771818, 13.845819197850377, 13.96396631703563, 14.081577604882911, 14.198662315129253, 14.315229426830221, 14.431287655838204, 14.5468454656655, 14.661911077772315, 14.776492481316648, 14.89059744240025, 15.00423351284234, 15.117408038510405, 15.230128167235215, 15.342400856335377, 15.454232879774755, 15.56563083497462, 15.676601149300735, 15.787150086244283, 15.897283751314212, 16.00700809765737, 16.116328931421748, 16.22525191687714, 16.333782581306565, 16.44192631968088, 16.549688399128453, 16.6570739632106], [0.0, 0.8366211413732437, 1.312799286971353, 1.708667860434496, 2.0600028885758332, 2.3815479927507908, 2.681187263768341, 2.9637567833863985, 3.2324910159959424, 3.4896869238680814, 3.737049366980394, 3.9758874363356473, 4.207233781271883, 4.4319210366408415, 4.6506328845571865, 4.863939377166813, 5.0723220954890555, 5.276192519873848, 5.475905734210252, 5.671770841775321, 5.864059012775872, 6.0530097931840485, 6.238836115152858, 6.421728322911345, 6.601857441839872, 6.779377858495882, 6.954429536964975, 7.1271398664449395, 7.297625212758528, 7.465992230083136, 7.632338976917814, 7.796755871032911, 7.959326511062074, 8.120128386931638, 8.279233497069615, 8.436708886999627, 8.592617121285992, 8.747016698693953, 8.89996241874277, 9.051505706468065, 9.201694901104137, 9.350575513493766, 9.49819045629101, 9.644580250410165, 9.789783210665748, 9.933835613124877, 10.076771846338824, 10.218624548322339, 10.359424730897775, 10.499201892807688, 10.637984122818395, 10.77579819388205, 10.912669649292367, 11.048622881655232, 11.183681205397342, 11.317866923451227, 11.451201388681467, 11.583705060553154, 11.715397557487854, 11.846297705303822, 11.976423582094545, 12.10579255986238, 12.234421343191102, 12.36232600521229, 12.489522021094663, 12.616024299263014, 12.741847210533114, 12.867004615331082, 12.991509889149851, 13.115375946381086, 13.238615262648205, 13.361239895754824, 13.48326150535269, 13.604691371424062, 13.725540411665222, 13.845819197850377, 13.965537971248564, 14.084706657160007, 14.203334878633076, 14.321431969417837, 14.439006986207843, 14.556068720217663, 14.672625708139908, 14.78868624252217, 14.904258381601219, 15.019349958628908, 15.133968590721755, 15.248121687263765, 15.361816457889887, 15.475059920075637, 15.587858906356397, 15.700220071198464, 15.812149897542245, 15.923654703036597, 16.03474064598215, 16.145413731000023, 16.255679814441443, 16.365544609552682, 16.47501369140876, 16.584092501628508, 16.69278635288286, 16.801100433207264], [0.0, 0.8437600745262979, 1.3240014738270212, 1.7232480150985197, 2.077581003913084, 2.4018698697393774, 2.7040659787568773, 2.9890466792689923, 3.260074035525146, 3.5194646098989284, 3.768937810029712, 4.009813897464132, 4.243134333192518, 4.46973885698454, 4.690316984851082, 4.905443633223629, 5.115604492478233, 5.321214554148762, 5.522631932074181, 5.720168367126418, 5.914097343422234, 6.104660450992425, 6.2920724389515, 6.47652527574604, 6.658191446125166, 6.837226654035111, 7.013772057882539, 7.187956133884107, 7.3598962408183874, 7.529699942948601, 7.697466135512241, 7.8632860078193465, 8.0272438718552, 8.18941787877184, 8.349880641363734, 8.50869977725756, 8.665938384884424, 8.821655462182676, 8.975906276278822, 9.12874269102107, 9.280213458125008, 9.430364476779879, 9.579239025815726, 9.726877971913986, 9.873319956831544, 10.018601566181145, 10.162757481953424, 10.30582062066506, 10.447822258763953, 10.588792146707014, 10.728758612943514, 10.867748658880645, 11.005788045774418, 11.142901374374137, 11.279112158049758, 11.414442890045924, 11.548915105432364, 11.68254943825588, 11.815365674343088, 11.947382800153957, 12.07861904804332, 12.20909193824976, 12.338818317898168, 12.467814397273017, 12.59609578359347, 12.723677512498709, 12.850574077431453, 12.976799457089577, 13.102367141099817, 13.227290154053035, 13.351581078027815, 13.475252073717657, 13.598314900266741, 13.720780933910026, 13.84266118550508, 13.96396631703563, 14.084706657160007, 14.204892215871562, 14.324532698332646, 14.44363751793872, 14.562215808664591, 14.680276436740733, 14.797828011703814, 14.914878896862177, 15.031437219213965, 15.147510878852584, 15.263107557891821, 15.37823472894035, 15.492899663153326, 15.607109437886757, 15.720870943978419, 15.834190892677526, 15.947075822243763, 16.05953210423483, 16.171565949500458, 16.283183413899526, 16.394390403755818, 16.505192681067047, 16.615595868480646, 16.725605454049074, 16.835226795776567, 16.94446512596836], [0.0, 0.8508666305538709, 1.3351528555271135, 1.7377620445464963, 2.0950793974160224, 2.422099581141431, 2.7268409321594524, 3.014221878163277, 3.2875319580874365, 3.5491072455158705, 3.800681629771896, 4.043586492284369, 4.278872065732518, 4.507385162581086, 4.729821106278769, 4.9467596554817055, 5.1586905912855405, 5.366032400483841, 5.569146213123783, 5.768346395709907, 5.9639087357746705, 6.156076858137125, 6.345067320632837, 6.5310737085596235, 6.714269959416709, 6.8948130885643755, 7.072845443313761, 7.248496581970446, 7.42188485176548, 7.593118722920407, 7.762297923616312, 7.929514411203771, 8.094853207784443, 8.258393122737221, 8.420207380436702, 8.580364168017963, 8.73892711535766, 8.895955717303355, 9.051505706468063, 9.205629383522442, 9.358375910792644, 9.509791574053112, 9.65992001664916, 9.80880244946121, 9.956477839705736, 10.102983081137241, 10.248353147854878, 10.392621233614175, 10.535818878288424, 10.677976082907296, 10.81912141451598, 10.959282101940602, 11.098484123410943, 11.236752286875737, 11.374110303745928, 11.510580856715164, 11.646185662231957, 11.78094552813305, 11.914880406890871, 12.048009444878554, 12.18035102801265, 12.311922824095683, 12.44274182214719, 12.572824368982506, 12.702186203272355, 12.83084248729336, 12.958807836559028, 13.0860963475026, 13.212721623366987, 13.338696798442456, 13.464034560779956, 13.588747173496236, 13.712846494776686, 13.836343996672424, 13.959250782779792, 14.081577604882911, 14.203334878633076, 14.324532698332646, 14.445180850885555, 14.565288828971438, 14.68486584349586, 14.803920835364986, 14.922462486629167, 15.040499231036586, 15.158039264034896, 15.275090552255918, 15.391660842515924, 15.507757670361512, 15.623388368189032, 15.738560072963411, 15.853279733560397, 15.9675541177546, 16.08138981887409, 16.194793262140912, 16.30777071071559, 16.42032827146237, 16.53247190045096, 16.644207408209407, 16.755540464741806, 16.86647660432365, 16.97702123008688, 17.087179618405745], [0.0, 0.8579413686046796, 1.3462543094700126, 1.752211090752247, 2.112499445870286, 2.4422387186445613, 2.749513915925067, 3.03928436087122, 3.3148669440910488, 3.5786171630218697, 3.8322833238325194, 4.077207878047352, 4.314449790761263, 4.544862915467698, 4.769148357051697, 4.987890694714094, 5.201583781954869, 5.410649585178067, 5.615452237134686, 5.816308718206218, 6.0134971090277975, 6.207263060096432, 6.3978249298706125, 6.585377913260312, 6.770097394010501, 6.9521416930239575, 7.131654341193242, 7.308765974068056, 7.483595922906354, 7.656253559831786, 7.826839442239711, 7.9954462920825184, 8.16215983839886, 8.327059545847426, 8.490219247644726, 8.651707697884397, 8.811589055509218, 8.969923310051172, 9.126766657525666, 9.282171833470038, 9.436188408982588, 9.588863054692114, 9.740239776827169, 9.890360128926082, 10.039263402207755, 10.186986797188805, 10.33356557876906, 10.479033216701621, 10.623421513105747, 10.766760718461983, 10.909079637343183, 11.050405724976182, 11.190765175593093, 11.330183003414383, 11.468683117005304, 11.606288387660294, 11.743020712394568, 11.8789010720567, 12.013949585018816, 12.148185556851237, 12.281627526344703, 12.414293308204986, 12.546200032710967, 12.677364182597564, 12.80780162739852, 12.9375276554609, 13.06655700382246, 13.194903886124676, 13.322582018717934, 13.449604645100765, 13.575984558822007, 13.701734124963087, 13.826865300307166, 13.951389652292526, 14.075318376839071, 14.198662315129253, 14.321431969417837, 14.44363751793872, 14.565288828971438, 14.686395474124822, 14.80696674089076, 14.927011644516757, 15.046538939242192, 15.165557128939701, 15.284074477199987, 15.402099016895374, 15.519638559254922, 15.636700702481376, 15.753292839938075, 15.869422167931987, 15.98509569311698, 16.100320239539975, 16.215102455350877, 16.329448819195804, 16.443365646311857, 16.55685909434029, 16.669935168874016, 16.78259972875412, 16.894858491129337, 17.006717036291242, 17.118180812297428, 17.229255139393857], [0.0, 0.864984831230061, 1.3573066870100212, 1.7665962617920397, 2.12984248519397, 2.462288826689833, 2.7720866688117596, 3.0642360493980454, 3.34208108981617, 3.607996625489435, 3.8637453156993833, 4.110680633128089, 4.349870236682567, 4.582174989758556, 4.808301753119338, 5.028839905200172, 5.244287353902418, 5.455069529858223, 5.6615535552482985, 5.864059012775872, 6.062866266041595, 6.258222982265479, 6.450349312568891, 6.6394420543583195, 6.825678031231035, 7.009216863860874, 7.190203261489541, 7.368768932148665, 7.545034186773002, 7.719109295401248, 7.8910956409773165, 8.06108670667532, 8.229168925345734, 8.395422414030236, 8.559921612095732, 8.722735838088056, 8.883929777677258, 9.043563912892873, 9.201694901104137, 9.358375910792645, 9.513656920021774, 9.667584982573347, 9.820204465954948, 9.971557264848025, 10.12168299304158, 10.270619156458235, 10.418401309512944, 10.565063196736277, 10.710636881334144, 10.855152862135212, 10.998640180189952, 11.141126516125063, 11.282638279220093, 11.423200689055385, 11.562837850478928, 11.701572822552196, 11.839427682058881, 11.976423582094547, 12.112580806197622, 12.24791881843185, 12.382456309786342, 12.516211241220702, 12.64920088364869, 12.781441855123948, 12.912950155464717, 13.043741198531189, 13.17382984234815, 13.303230417247157, 13.431956752186062, 13.560022199388875, 13.687439657435952, 13.814221592922635, 13.940380060793986, 14.065926723453776, 14.19087286873733, 14.315229426830221, 14.439006986207843, 14.562215808664591, 14.68486584349586, 14.80696674089076, 14.928527864588927, 15.049558303850572, 15.170066884784973, 15.290062181079216, 15.409552524165813, 15.52854601286476, 15.647050522533158, 15.765073713752907, 15.882623040584825, 15.999705758415582, 16.116328931421744, 16.23249943967378, 16.348223985901083, 16.463509101937667, 16.57836115486699, 16.69278635288286, 16.806790750882435, 16.920380255806293, 17.033560631739377, 17.146337504785922, 17.25871636773058, 17.370702584497064], [0.0, 0.871997545077537, 1.3683108145456813, 1.7809186332610873, 2.1471098121453833, 2.4822514044460906, 2.7945608786093294, 3.089078809409213, 3.369176430094696, 3.6372478296536004, 3.8950699578205574, 4.144007260321649, 4.385136051922505, 4.619324175318889, 4.847284222024593, 5.0696103487578785, 5.286804500121684, 5.499295555852899, 5.70745361451137, 5.9116008497614185, 6.112019898202754, 6.308960434974234, 6.502644396034093, 6.693270174289512, 6.881016026904274, 7.066042868649028, 7.248496581970445, 7.428509942700082, 7.606204237172638, 7.781690629421941, 7.955071324336464, 8.126440562988867, 8.295885478968907, 8.463486838853221, 8.629319685512915, 8.79345389948186, 8.955954690857906, 9.116883032018109, 9.276296039671456, 9.434247313353746, 9.590787236316798, 9.745963243822779, 9.899820063081103, 10.05239992842706, 10.203742774811541, 10.353886412229905, 10.50286668334833, 10.65071760627529, 10.79747150416355, 10.94315912310572, 11.087809739597532, 11.23145125868154, 11.374110303745928, 11.515812298834389, 11.656581544220774, 11.79644128591388, 11.935413779681074, 12.073520350112961, 12.210781445193224, 12.34721668678711, 12.48284491741767, 12.61768424365986, 12.751752076448367, 12.885065168564802, 13.01763964954315, 13.149491058208792, 13.280634373045356, 13.411084040565068, 13.540854001841648, 13.669957717349936, 13.798408190243281, 13.926217988187775, 14.053399263861847, 14.179963774220175, 14.305922898612243, 14.431287655838204, 14.556068720217663, 14.680276436740733, 14.803920835364986, 14.927011644516757, 15.049558303850572, 15.171569976316238, 15.293055559579171, 15.41402369683614, 15.534482787065285, 15.65444099474638, 15.773906259084614, 15.892886302768714, 16.011388640292004, 16.129420585862935, 16.246989260929652, 16.3641016013416, 16.480764364169374, 16.59698413420271, 16.71276733014508, 16.828120210522133, 16.943048879320063, 17.057559291368936, 17.171657257485002, 17.285348449385168, 17.398638404385874, 17.51153252989791], [0.0, 0.8789800215472077, 1.3792674945497652, 1.7951792496141277, 2.1643026859392784, 2.5021279076784597, 2.816938184242933, 3.113814452555709, 3.3961549408463667, 3.6663729086498478, 3.926259534536378, 4.177190189962543, 4.420249808230306, 4.656313181242154, 4.886098606552571, 5.110204998559849, 5.32913832116308, 5.543330888332067, 5.753155762172255, 5.958937696137372, 6.160961590025481, 6.3594791182365515, 6.5547139938698376, 6.746866198453742, 6.936115416537319, 7.122623851408147, 7.30653855365925, 7.487993362317973, 7.667110534913241, 7.844002125619289, 8.01877115772509, 8.191512626933958, 8.362314364553479, 8.531257783894592, 8.698418528730418, 8.863867039159686, 9.027669047446825, 9.18988601420213, 9.350575513493766, 9.509791574053114, 9.667584982573349, 9.824003554152112, 9.979092374149698, 10.132894015090711, 10.28544873170315, 10.436794636744011, 10.58696785988782, 10.73600269164134, 10.883931713983358, 11.030785919204273, 11.176594818229882, 11.321386539550964, 11.465187919741146, 11.60802458642587, 11.749921034462208, 11.890900696000203, 12.030986005019159, 12.170198456865267, 12.30855866325841, 12.446086403184935, 12.58280067004845, 12.718719715411396, 12.853861089625644, 12.988241679619861, 13.121877744084466, 13.254784946271199, 13.386978384603143, 13.518472621272249, 13.649281708984676, 13.77941921599934, 13.90889824959169, 14.03773147806277, 14.165931151402972, 14.293509120710194, 14.42047685645349, 14.5468454656655, 14.672625708139908, 14.797828011703814, 14.922462486629167, 15.046538939242192, 15.170066884784973, 15.293055559579171, 15.415513932537817, 15.537450716067637, 15.658874376401174, 15.779793143394857, 15.900215019826659, 16.020147790224353, 16.13959902925319, 16.258576109689777, 16.377086210006894, 16.495136321592454, 16.612733255623958, 16.729883649618507, 16.84659397367702, 16.96287053643998, 17.07871949077094, 17.194146839182967, 17.309158439022134, 17.42376000742133, 17.537957126036783, 17.65175524557885], [0.0, 0.8859327574133933, 1.3901775065447362, 1.8093791254350295, 2.1814223297775124, 2.521919750517934, 2.8392201777653097, 3.1384447386762315, 3.4230185414806362, 3.695373934607082, 3.957316264856224, 4.2102317828789655, 4.455214003804496, 4.693144639143129, 4.92474766818619, 5.150626742747512, 5.371291828902873, 5.5871786602274955, 5.798663249749728, 6.006072919724561, 6.20969482350872, 6.409782626247793, 6.606561810612643, 6.800233939986448, 6.990980120223843, 7.178963837641126, 7.364333306002168, 7.547223423001612, 7.727757413225977, 7.906048217198515, 8.082199673122872, 8.256307528118793, 8.428460308239899, 8.598740070776778, 8.767223057845133, 8.933980266725184, 9.099077949623863, 9.26257805330517, 9.424538607248397, 9.585014067552436, 9.744055622633425, 9.901711465806642, 10.058027039057782, 10.213045251660306, 10.36680667675729, 10.519349728577808, 10.67071082258227, 10.820924520515502, 10.970023662079885, 11.118039484714973, 11.265001732778117, 11.410938757256584, 11.555877607001415, 11.699844112352686, 11.842862961921893, 11.984957773207492, 12.126151157641663, 12.26646478059888, 12.405919416837824, 12.544535001796708, 12.682330679117047, 12.819324844731224, 12.955535187814469, 13.090978728871134, 13.225671855197945, 13.359630353943034, 13.492869442958083, 13.625403799622038, 13.757247587798032, 13.888414483069969, 14.0189176963919, 14.148769996271193, 14.27798372959571, 14.406570841205596, 14.534542892301358, 14.661911077772315, 14.78868624252217, 14.914878896862177, 15.040499231036586, 15.165557128939701, 15.290062181079216, 15.41402369683614, 15.537450716067637, 15.660352020095617, 15.782736142120555, 15.904611377097085, 16.02598579110519, 16.146867230248287, 16.267263329107266, 16.387181518777425, 16.5066290345133, 16.625612923004716, 16.744140049305614, 16.86221710343588, 16.979850606674972, 17.09704691756474, 17.213812237637917, 17.330152616887467, 17.446073958991107, 17.561582026304272, 17.67668244463411, 17.79138070780612], [0.0, 0.8928562354137626, 1.4010416080271917, 1.8235192466399976, 2.1984699322996546, 2.5416283071384003, 2.8614084062448106, 3.162971377884201, 3.449769097172911, 3.7242529211049837, 3.9882423050900555, 4.2431343331925175, 4.490031066255528, 4.729821106278768, 4.963234090381037, 5.190878387856157, 5.413267950114993, 5.6308419159481184, 5.843979236888986, 6.053009793184048, 6.258222982265478, 6.45987445164721, 6.658191446125165, 6.853377104280679, 7.045613947292959, 7.235066739107905, 7.421884851765479, 7.606204237172637, 7.788149082904013, 7.967833212102018, 8.145361274455723, 8.320829765339266, 8.494327902628731, 8.665938384884422, 8.835738050046732, 9.003798450232697, 9.170186355403775, 9.334964196431875, 9.498190456291008, 9.659920016649162, 9.820204465954948, 9.979092374149698, 10.136629538343788, 10.292859203142463, 10.447822258763951, 10.601557419640772, 10.754101385816606, 10.905488989132941, 11.055753325931226, 11.204925877768552, 11.353036621451523, 11.500114129527601, 11.646185662231957, 11.791277251766253, 11.935413779681074, 12.078619048043318, 12.220915844991303, 12.362326005212289, 12.502870465817665, 12.642569318039149, 12.781441855123946, 12.919506616766853, 13.056781430382278, 13.193283449488153, 13.329029189446326, 13.464034560779954, 13.598314900266741, 13.731884999987917, 13.864759134495824, 13.996951086247718, 14.128474169439965, 14.259341252364571, 14.389564778399125, 14.519156785731527, 14.648128925911939, 14.776492481316648, 14.904258381601219, 15.031437219213965, 15.158039264034896, 15.284074477199987, 15.409552524165813, 15.534482787065285, 15.658874376401174, 15.782736142120555, 15.906076684110038, 16.028904362148516, 16.151227305351597, 16.27305342113923, 16.394390403755814, 16.515245742369927, 16.63562672877892, 16.7555404647418, 16.87499386896224, 16.99399368374198, 17.112546481323637, 17.230658669940443, 17.348336499589507, 17.4655860675439, 17.582413323618, 17.698824075199482, 17.81482399206064, 17.930418610960675], [0.0, 0.8997509248080118, 1.4118605353445224, 1.8376005716185837, 2.2154466489586113, 2.561254913346991, 2.8835043735558403, 3.1873960325468924, 3.4764084210231436, 3.753011825504352, 4.019039751343939, 4.2759000709732256, 4.52470335541529, 4.766345068507743, 5.001560481670972, 5.230962662062971, 5.455069529858222, 5.674323614903371, 5.88910679501834, 6.099751497804627, 6.306549355438732, 6.509757989560023, 6.709606399762361, 6.906299293275391, 7.100020600717812, 7.290936358352593, 7.4791970916795485, 7.664939802434412, 7.848289637175716, 8.029361297995004, 8.208260242692523, 8.385083711785471, 8.55992161209573, 8.732857280786842, 8.903968149146383, 9.073326321821126, 9.24099908437418, 9.407049349772388, 9.571536052598796, 9.73451449832092, 9.896036673756466, 10.056151523906768, 10.214905199530234, 10.37234127916954, 10.528500968799635, 10.68342328180821, 10.837145201638881, 10.989701829106705, 11.141126516125063, 11.291450987353523, 11.44070545108138, 11.588918700495025, 11.736118206334801, 11.88233020182459, 12.027579760651804, 12.17189086868433, 12.315286490031854, 12.4577886279904, 12.59941838134899, 12.740195996485037, 12.880140915629356, 13.019271821641382, 13.157606679599885, 13.29516277548329, 13.43195675218606, 13.568004643093369, 13.703321903414434, 13.837923439455826, 13.971823635998833, 14.105036381929676, 14.237575094257744, 14.369452740644762, 14.500681860556831, 14.631274585141455, 14.761242655922771, 14.89059744240025, 15.019349958628908, 15.147510878852584, 15.275090552255918, 15.402099016895374, 15.52854601286476, 15.65444099474638, 15.779793143394857, 15.904611377097085, 16.028904362148516, 16.152680522882754, 16.275948051188927, 16.39871491554856, 16.52098886962146, 16.642777460408016, 16.76408803601328, 16.884927753036465, 17.005303583607887, 17.125222322093748, 17.244690591487913, 17.36371484950838, 17.482301394415106, 17.600456370564675, 17.718185773716282, 17.835495456102603, 17.95239113127825, 18.068878378757613], [0.0, 0.9066172819080086, 1.4226350045267984, 1.851624032316425, 2.232353603325996, 2.5808008680932053, 2.905509542077853, 3.2117203191634918, 3.5029382761041754, 3.781652551158424, 4.049710641888118, 4.308531164758952, 4.559233166003108, 4.8027189430988315, 5.039729378615105, 5.270882218269193, 5.496699334690388, 5.717626634846568, 5.934048910819157, 6.146301127096872, 6.354677141417321, 6.5594365414330476, 6.760810074324877, 6.959004009524728, 7.15420368129899, 7.346576392999383, 7.536273818845666, 7.7234340060883, 7.908183056328969, 8.09063654699649, 8.270900740681519, 8.449073619982311, 8.625245777835456, 8.799501187383532, 8.97191787082306, 9.142568483060048, 9.31152082314049, 9.478838284145102, 9.644580250410163, 9.808802449461208, 9.971557264848025, 10.13289401509071, 10.292859203142461, 10.451496740111148, 10.608848146430898, 10.764952733216074, 10.919847766145661, 11.073568613902994, 11.226148882923166, 11.377620539969236, 11.528014023861973, 11.677358347520018, 11.825681191323858, 11.973008988693538, 12.119367004663752, 12.264779408148083, 12.409269338504467, 12.552858966944832, 12.695569553271447, 12.837421498369887, 12.978434392842354, 13.11862706212462, 13.25801760839411, 13.396623449545427, 13.534461355481582, 13.67154748194488, 13.80789740208939, 13.943526135977638, 14.078448178166894, 14.212677523534996, 14.346227691481864, 14.47911174863061, 14.611342330140983, 14.742931659738101, 14.87389156855034, 15.00423351284234, 15.133968590721755, 15.263107557891821, 15.391660842515924, 15.519638559254922, 15.647050522533158, 15.773906259084614, 15.900215019826659, 16.02598579110519, 16.151227305351597, 16.275948051188927, 16.40015628302187, 16.52386003014261, 16.647067105382206, 16.769785113335214, 16.89202145818299, 17.01378335113961, 17.135077817542488, 17.25591170360833, 17.376291682873706, 17.49622426233803, 17.61571578832578, 17.734772452083565, 17.853400295126615, 17.971605214348312, 18.089392966905677, 18.206769174892596], [0.0, 0.9134557505811726, 1.4333657120766574, 1.8655905352633193, 2.2491918883315964, 2.6002674349018453, 2.927425334308576, 3.235945810148333, 3.52936037740667, 3.8101769495125595, 4.080256959405525, 4.341029723947617, 4.593622730157176, 4.838945081397534, 5.077743248596, 5.310639637026658, 5.538160055720296, 5.760753775049499, 5.978808489520611, 6.192661690205737, 6.402609451364246, 6.608913318676688, 6.811805779812844, 7.01149466006186, 7.208166691636754, 7.401990439831583, 7.593118722920407, 7.7816906294219415, 7.967833212102019, 8.151662920171455, 8.333286817742577, 8.512803626480652, 8.690304622650254, 8.865874412789902, 9.039591607605026, 9.211529410025927, 9.381756130495928, 9.550335640259576, 9.717327771579674, 9.882788672325534, 10.046771121167657, 10.209324808627821, 10.370496588423542, 10.530330702877123, 10.688868985604667, 10.846151044237967, 11.00221442554504, 11.157094764989523, 11.31082592249446, 11.463440105943075, 11.614967983751272, 11.765438787677487, 11.914880406890871, 12.06331947419452, 12.210781445193224, 12.357290671102806, 12.502870465817665, 12.647543167783626, 12.79133019716223, 12.934252108719658, 13.076328640826889, 13.217578760916927, 13.35802070770902, 13.497672030478155, 13.63654962562003, 13.774669770737122, 13.912048156449302, 14.048699916113016, 14.184639653615656, 14.319881469396176, 14.454438984829162, 14.588325365097164, 14.721553340664917, 14.854135227459135, 14.986082945848494, 15.117408038510405, 15.248121687263765, 15.37823472894035, 15.507757670361512, 15.636700702481376, 15.765073713752907, 15.892886302768714, 16.020147790224353, 16.146867230248287, 16.27305342113923, 16.39871491554856, 16.52386003014261, 16.64849685477722, 16.77263326121439, 16.896276911408915, 17.019435265390694, 17.142115588766835, 17.264324959865746, 17.386070276544054, 17.507358262675734, 17.628195474341453, 17.748588305735, 17.86854299480257, 17.988065628629563, 18.10716214858869, 18.225838355262272, 18.344099913150753], [0.0, 0.9202667627287333, 1.444053335719773, 1.8795009625499923, 2.265962567440984, 2.6196558432344386, 2.9492531343967214, 3.2600740355251463, 3.5556763936869795, 3.8385868220991353, 4.110680633128088, 4.373397801070038, 4.627874219839633, 4.875025771359591, 5.115604492478233, 5.350237429318286, 5.579454311507342, 5.803707759318583, 6.023388358030011, 6.238836115152858, 6.450349312568891, 6.658191446125165, 6.862596736992337, 7.0637745600699935, 7.261913039905015, 7.457181998667078, 7.649735394091153, 7.839713351783513, 8.0272438718552, 8.212444271798816, 8.395422414030236, 8.576277756314385, 8.75510225550025, 8.931981148979194, 9.106993633602688, 9.280213458125008, 9.451709442333534, 9.621545933716817, 9.789783210665748, 9.956477839705737, 10.12168299304158, 10.285448731703148, 10.44782225876395, 10.608848146430898, 10.768568540244637, 10.927023343163867, 11.084250381917068, 11.240285557677053, 11.395162982837057, 11.548915105432364, 11.701572822552196, 11.853165583916132, 12.003721486643705, 12.15326736212053, 12.301828855756359, 12.449430500337305, 12.596095783593467, 12.741847210533114, 12.886706361033225, 13.030693943122753, 13.173829842348148, 13.316133167569541, 13.457622293499782, 13.598314900266743, 13.738228010250944, 13.877378022425763, 14.015780744405248, 14.153451422384888, 14.290404769143235, 14.426654990256528, 14.562215808664591, 14.697100487713698, 14.831321852790916, 14.964892311654364, 15.09782387355472, 15.230128167235215, 15.361816457889887, 15.492899663153326, 15.623388368189032, 15.753292839938075, 15.882623040584825, 16.011388640292004, 16.13959902925319, 16.267263329107266, 16.394390403755814, 16.52098886962146, 16.647067105382206, 16.77263326121439, 16.89769526757434, 17.022260843546775, 17.146337504785922, 17.26993257107353, 17.393053173516236, 17.51570626140325, 17.637898608743857, 17.759636820502912, 17.88092733855132, 18.00177644734735, 18.122190279363622, 18.24217482027358, 18.361735913910504, 18.48087926701113], [0.0, 0.927050738740395, 1.4546985351182984, 1.8933561727566797, 2.2826666757750305, 2.6389672897834977, 2.9709942895990884, 3.284106484537719, 3.5818879492238542, 3.866883922434027, 4.140983540867638, 4.405637393950628, 4.6619897491229985, 4.9109632399595355, 5.153315447135792, 5.38967803920141, 5.62058465081808, 5.8464912388622405, 6.067791267908701, 6.284827251918884, 6.497899671633857, 6.707273965326044, 6.91318608078589, 7.115846936372284, 7.315446043439134, 7.5121544760426024, 7.706127326855513, 7.897505754454999, 8.086418702536852, 8.272984353428836, 8.457311364681534, 8.639499927237594, 8.819642675828856, 8.997825476195377, 9.174128109007976, 9.348624866678268, 9.52138507631586, 9.69247355976287, 9.861951039767385, 10.029874499849068, 10.196297504184887, 10.361270482842082, 10.524840986863394, 10.687053917030877, 10.847951729571543, 11.007574621598707, 11.165960698690013, 11.323146126672727, 11.479165269408096, 11.634050814130196, 11.787833885693848, 11.940544150914585, 12.092209914036864, 12.242858204240555, 12.392514855986946, 12.5412045829117, 12.68895104589058, 12.835776915833137, 12.981703931697794, 13.126752954167909, 13.270944015381199, 13.41429636506352, 13.556828513381502, 13.698558270796493, 13.839502785173739, 13.979678576375736, 14.119101568546304, 14.257787120272067, 14.395750052790493, 14.533004676397772, 14.6695648151958, 14.805443830304917, 14.94065464165773, 15.075209748479242, 15.209121248549323, 15.342400856335377, 15.475059920075637, 15.607109437886757, 15.738560072963411, 15.869422167931987, 15.999705758415582, 16.129420585862935, 16.258576109689777, 16.387181518777425, 16.515245742369927, 16.642777460408016, 16.769785113335214, 16.896276911408915, 17.022260843546775, 17.147744685736683, 17.27273600903638, 17.397242187187214, 17.521270403864555, 17.644827659586028, 17.767920778297217, 17.89055641365313, 18.012741055012526, 18.134481033161126, 18.2557825257786, 18.376651562663277, 18.49709403072772, 18.617115678777285], [0.0, 0.9338080879268165, 1.4653019525495021, 1.9071570018363986, 2.2993052211747975, 2.658202939703631, 2.9926501116665656, 3.308044607181971, 3.607996625489435, 3.895069957820557, 4.171167510947729, 4.437750447762688, 4.695971376365046, 4.9467596554817055, 5.190878387856156, 5.428963846322125, 5.6615535552482985, 5.889106795018341, 6.112019898202754, 6.330637875375435, 6.545263397506319, 6.756163837669259, 6.963576863497579, 7.1677149307514565, 7.368768932148665, 7.5669111887182545, 7.762297923616312, 7.955071324336465, 8.145361274455725, 8.333286817742577, 8.518957403761437, 8.702473953754987, 8.883929777677256, 9.063411367150756, 9.24099908437418, 9.416767763282653, 9.590787236316798, 9.763122797810471, 9.933835613124876, 10.102983081137243, 10.270619156458235, 10.43679463674401, 10.601557419640772, 10.764952733216075, 10.927023343163867, 11.087809739597532, 11.247350305849407, 11.40568147136245, 11.562837850478928, 11.718852368692856, 11.873756377730682, 12.027579760651806, 12.18035102801265, 12.332097406011004, 12.48284491741767, 12.63261845600804, 12.781441855123946, 12.929337950925069, 13.076328640826889, 13.222434937568, 13.367677019302025, 13.512074276067656, 13.655645352953652, 13.798408190243281, 13.940380060793988, 14.081577604882911, 14.222016862726266, 14.361713304860675, 14.500681860556833, 14.638936944419852, 14.776492481316648, 14.913361929757869, 15.049558303850572, 15.185094193927643, 15.319981785950663, 15.454232879774755, 15.587858906356397, 15.720870943978419, 15.853279733560397, 15.98509569311698, 16.116328931421744, 16.246989260929652, 16.377086210006894, 16.5066290345133, 16.63562672877892, 16.76408803601328, 16.89202145818299, 17.019435265390694, 17.146337504785922, 17.27273600903638, 17.398638404385874, 17.524052118323556, 17.6489843868872, 17.77344226162178, 17.897432616213187, 18.02096215281546, 18.14403740808883, 18.26666475896464, 18.388850428152175, 18.510600489401458, 18.63192087253524, 18.752817368262402], [0.0, 0.9405392089312294, 1.4758642135516644, 1.9209042639556149, 2.3158791852150604, 2.677363927783265, 3.014221878163277, 3.3318898156641263, 3.634003962739641, 3.9231465910664225, 4.201234324042269, 4.46973885698454, 4.729821106278769, 4.98241712970076, 5.22829553062842, 5.468097168308345, 5.702363441718598, 5.9315569418501015, 6.156076858137125, 6.376270688075608, 6.592443284363138, 6.804863947365198, 7.013772057882537, 7.219381603109307, 7.421884851765479, 7.62145536701295, 7.818250498103179, 8.012413457452622, 8.204075064871425, 8.39335522222517, 8.580364168017962, 8.765203550957906, 8.947967353600394, 9.128742691021067, 9.307610504689343, 9.484646167961966, 9.65992001664916, 9.833497815742588, 10.00544117149859, 10.175807896539785, 10.344652334395093, 10.51202564888281, 10.677976082907293, 10.84254919055126, 11.005788045774416, 11.167733430552957, 11.328424004895828, 11.487896460838478, 11.646185662231957, 11.803324771905437, 11.95934536757641, 12.114277547708797, 12.26815002837021, 12.420990232011642, 12.572824368982502, 12.723677512498707, 12.873573667698748, 13.022535835351023, 13.170586070713034, 13.317745537988419, 13.464034560779952, 13.60947266889455, 13.75407864181941, 13.897870549155822, 14.040865788268286, 14.1830811193812, 14.324532698332643, 14.465236107174722, 14.60520638279202, 14.744458043693715, 14.883005115120625, 15.02086115259569, 15.158039264034894, 15.294552130525368, 15.430412025868137, 15.56563083497462, 15.700220071198464, 15.834190892677526, 15.9675541177546, 16.100320239539975, 16.23249943967378, 16.3641016013416, 16.495136321592454, 16.625612923004716, 16.7555404647418, 16.884927753036465, 17.01378335113961, 17.142115588766835, 17.26993257107353, 17.397242187187214, 17.524052118323556, 17.6503698455109, 17.776202656946182, 17.90155765500366, 18.026441762916466, 18.150861731149433, 18.274824143480668, 18.398335422808017, 18.5214018366956, 18.64402950267455, 18.766224393311248, 18.887992341055448], [0.0, 0.9472444901214154, 1.4863859275391569, 1.9345987522947943, 2.332389524169469, 2.696451359560456, 3.035710833722782, 3.355643485789301, 3.65991146152867, 3.9511154421186956, 4.231185714926415, 4.501604467262329, 4.763540891903565, 5.017937719958137, 5.265569034322214, 5.507080263048683, 5.7430166648509005, 5.973844128618105, 6.199964689681237, 6.421728322911345, 6.6394420543583195, 6.853377104280679, 7.063774560069994, 7.2708499344754305, 7.474796866936884, 7.675790157980725, 7.8739882786308675, 8.06953546229206, 8.262563461413519, 8.45319303266381, 8.641535200458103, 8.827692338177288, 9.0117590983961, 9.193823217249962, 9.373966213255274, 9.55226399711964, 9.728787406090524, 9.903602674010603, 10.076771846338824, 10.248353147854878, 10.418401309512944, 10.58696785988782, 10.754101385816606, 10.919847766145663, 11.084250381917068, 11.247350305849405, 11.40918647356611, 11.56979583868706, 11.729213513614269, 11.887472897600961, 12.04460579348813, 12.200642514317313, 12.355611980878377, 12.509541811122133, 12.662458402256512, 12.814387006249104, 12.96535179937556, 13.115375946381086, 13.26448165975927, 13.412690254597344, 13.560022199388875, 13.706497163172452, 13.852134059317772, 13.99695108624772, 14.140965765355883, 14.284194976353454, 14.426654990256528, 14.568361500204594, 14.70932965028302, 14.84957406250617, 14.989108862103446, 15.127947701237664, 15.266103781273607, 15.40358987370427, 15.540418339832916, 15.676601149300735, 15.812149897542245, 15.947075822243763, 16.08138981887409, 16.215102455350877, 16.348223985901083, 16.480764364169374, 16.612733255623958, 16.744140049305614, 16.87499386896224, 17.005303583607887, 17.135077817542488, 17.264324959865746, 17.393053173516236, 17.521270403864555, 17.6489843868872, 17.776202656946182, 17.902932554197356, 18.029181231649154, 18.154955661891737, 18.28026264351527, 18.40510880723486, 18.5295006217384, 18.65344439927265, 18.77694630098178, 18.900012342011728, 19.022648396392867], [0.0, 0.9539243099631818, 1.496867688388487, 1.9482412398111681, 2.3488371699301513, 2.7154663123860363, 3.0571181912449856, 3.3793069582845554, 3.68572058415201, 3.978978089621655, 4.26102337414483, 4.5333490771848926, 4.797132636483387, 5.0533234311405035, 5.302701002763801, 5.545915330863748, 5.783515519232781, 6.015970742135643, 6.243685869993486, 6.4670133456453565, 6.6862623602407805, 6.901706046641076, 7.113587192348353, 7.322122829873945, 7.527507964172759, 7.7299186284371135, 7.929514411203771, 8.126440562988869, 8.320829765339266, 8.512803626480652, 8.702473953754987, 8.88994384246422, 9.075308612658219, 9.2586566191739, 9.44006995538348, 9.619625067304986, 9.79739329171906, 9.97344132953907, 10.14783166375882, 10.32062292975004, 10.491870244421026, 10.661625499718014, 10.829937625104877, 10.996852822958417, 11.162414780237025, 11.32666485929767, 11.489642270331707, 11.651384227550151, 11.811926090962185, 11.971301495347333, 12.129542467815243, 12.286679535170279, 12.442741822147191, 12.59775714145425, 12.75175207644837, 12.90475205717006, 13.05678143038228, 13.207863524184397, 13.358020707709022, 13.507274446354048, 13.655645352953654, 13.803153235249406, 13.949817139985127, 14.09565539391613, 14.240685641994126, 14.384924882963388, 14.528389502580671, 14.671095304651024, 14.813057540053537, 14.954290933914725, 15.094809711072903, 15.234627619963797, 15.37375795504615, 15.512213577875526, 15.650006936925163, 15.787150086244283, 15.923654703036597, 16.05953210423483, 16.194793262140912, 16.329448819195804, 16.463509101937667, 16.59698413420271, 16.729883649618507, 16.86221710343588, 16.99399368374198, 17.125222322093748, 17.25591170360833, 17.386070276544054, 17.51570626140325, 17.644827659586028, 17.77344226162178, 17.90155765500366, 18.029181231649154, 18.15632019500859, 18.282981566841734, 18.409172193681353, 18.53489875300132, 18.660167759105693, 18.784985568754223, 18.909358386538493, 19.033292270022304, 19.156793134658784], [0.0, 0.9605790373764018, 1.507310074996987, 1.96183247996589, 2.3652230308843896, 2.73440983643713, 3.078445133037167, 3.4028815400601777, 3.7114327560220954, 4.006736072401892, 4.290748949602055, 4.564974439975786, 4.830598195257218, 5.0885762175658495, 5.339693486715241, 5.584604516576103, 5.823862241576094, 6.057939109014106, 6.287242813751617, 6.512128257324866, 6.732906787849919, 6.949853443606293, 7.1632127058202535, 7.373203121056383, 7.580021054655112, 7.78384376784425, 7.984831962475524, 8.183131902355733, 8.378877194639266, 8.5721902959101, 8.763183793495964, 8.951961501907993, 9.138619406163858, 9.323246477477841, 9.505925381918557, 9.686733098803588, 9.865741462570284, 10.04301763944817, 10.218624548322339, 10.392621233614177, 10.56506319673628, 10.736002691641339, 10.905488989132941, 11.073568613902996, 11.240285557677055, 11.40568147136245, 11.56979583868706, 11.732666133474144, 11.894327962409918, 12.054815194915472, 12.214160081526652, 12.372393362007655, 12.529544364272002, 12.685641095053839, 12.840710323159788, 12.994777656034367, 13.147867610287413, 13.300003676758818, 13.451208380631815, 13.601503337050321, 13.750909302646914, 13.899446223345112, 14.047133278761848, 14.193988923502786, 14.340030925613624, 14.485276402424573, 14.629741854002024, 14.773443194400885, 14.916395780892795, 15.058614441329093, 15.20011349978282, 15.340906800600974, 15.481007730986553, 15.620429242219373, 15.759183869615198, 15.897283751314212, 16.03474064598215, 16.171565949500458, 16.30777071071559, 16.443365646311857, 16.57836115486699, 16.71276733014508, 16.84659397367702, 16.979850606674972, 17.112546481323637, 17.244690591487913, 17.376291682873706, 17.507358262675734, 17.637898608743857, 17.767920778297217, 17.897432616213187, 18.026441762916466, 18.154955661891737, 18.282981566841734, 18.410526548511143, 18.537597501195226, 18.66420114895097, 18.790344051527256, 18.9160326100296, 19.041273072333798, 19.166071538262187, 19.290433964535023], [0.0, 0.9672090320746062, 1.5177136518156886, 1.9753732074175991, 2.381547992750791, 2.7532829556838414, 3.0996928119022966, 3.4263685054126976, 3.737049366980394, 4.034390890884797, 4.320364048079413, 4.596482265107117, 4.863939377166813, 5.1236979847824395, 5.376548485762119, 5.623149911484569, 5.864059012775872, 6.099751497804629, 6.330637875375435, 6.557075496583817, 6.779377858495881, 6.997821897727733, 7.212653782934961, 7.424093569108324, 7.632338976917815, 7.8375684910626635, 8.03994392257186, 8.2396125447769, 8.436708886999627, 8.63135625102933, 8.823668001280629, 9.013748668800874, 9.201694901104137, 9.387596283491263, 9.571536052598798, 9.753591719061843, 9.933835613124879, 10.112335364604213, 10.289154326656208, 10.464351951231647, 10.637984122818395, 10.810103456030182, 10.980759561741685, 11.149999285762025, 11.317866923451227, 11.484404413194575, 11.649651511239847, 11.813645950057685, 11.976423582094549, 12.138018510541029, 12.298463208528796, 12.457788627990402, 12.616024299263014, 12.773198422385533, 12.929337950925069, 13.0844686690708, 13.238615262648205, 13.391801384632863, 13.544049715678653, 13.695382020118975, 13.845819197850377, 13.995381332464763, 14.144087735958344, 14.291956990311972, 14.439006986207843, 14.585254959121377, 14.730717523003767, 14.875410701750017, 15.019349958628911, 15.16255022383482, 15.305025920306708, 15.446790987946379, 15.587858906356397, 15.728242716207365, 15.867955039334817, 16.00700809765737, 16.145413731000023, 16.283183413899526, 16.42032827146237, 16.55685909434029, 16.69278635288286, 16.828120210522133, 16.96287053643998, 17.09704691756474, 17.230658669940443, 17.36371484950838, 17.49622426233803, 17.628195474341453, 17.759636820502912, 17.89055641365313, 18.02096215281546, 18.150861731149433, 18.28026264351527, 18.409172193681353, 18.537597501195226, 18.665545507937132, 18.793022984374048, 18.920036535530784, 19.046592606693793, 19.17269748886223, 19.29835732395989, 19.423578109820813], [0.0, 0.9738146448890527, 1.5280789693578443, 1.9888641386842805, 2.397812919377242, 2.7720866688117596, 3.120862352177609, 3.4497690971729122, 3.762571772549536, 4.061944008446316, 4.349870236682567, 4.627874219839634, 4.897157946486403, 5.158690591285541, 5.413267950114995, 5.6615535552483, 5.904107959875112, 6.141410121041854, 6.37387335114793, 6.601857441839873, 6.8256780312310354, 7.04561394729296, 7.261913039905016, 7.4747968669368845, 7.6844644994038775, 7.891095640977318, 8.094853207784444, 8.29588547896891, 8.494327902628733, 8.690304622650258, 8.88392977767726, 9.07530861265822, 9.26453843516728, 9.451709442333536, 9.636905439263197, 9.820204465954951, 10.00167934663708, 10.181398173007825, 10.359424730897775, 10.535818878288426, 10.710636881334144, 10.883931713983358, 11.055753325931224, 11.226148882923168, 11.395162982837057, 11.56283785047893, 11.729213513614269, 11.894327962409918, 12.058217294168797, 12.220915844991307, 12.382456309786344, 12.54286985187456, 12.702186203272355, 12.86043375661251, 13.017639649543153, 13.173829842348152, 13.329029189446327, 13.483261505352692, 13.63654962562003, 13.788915463222576, 13.940380060793988, 14.090963639088285, 14.240685641994125, 14.38956477839913, 14.537619061170995, 14.684865843495862, 14.831321852790918, 14.97700322238733, 15.121925521161213, 15.266103781273609, 15.409552524165816, 15.552285784943049, 15.694317135267632, 15.83565970487222, 15.976326201793942, 16.116328931421748, 16.255679814441443, 16.394390403755818, 16.53247190045096, 16.669935168874016, 16.806790750882435, 16.943048879320063, 17.07871949077094, 17.213812237637917, 17.348336499589507, 17.482301394415106, 17.61571578832578, 17.748588305735, 17.88092733855132, 18.012741055012526, 18.14403740808883, 18.274824143480668, 18.40510880723486, 18.53489875300132, 18.66420114895097, 18.793022984374048, 18.92137107597685, 19.049252073893598, 19.176672467429228, 19.303638590547646, 19.4301566271193, 19.556232615940786], [0.0, 0.9803962180781365, 1.5384065646844416, 2.002305972775188, 2.4140186535027643, 2.7908219501027354, 3.1419548507261945, 3.473084527801982, 3.7880012951287907, 4.089396852703548, 4.379269044223611, 4.659151930693139, 4.930255624378663, 5.193555850156496, 5.449853782329361, 5.699817437685629, 5.944011157940692, 6.182917137195243, 6.416951481240449, 6.646476413392017, 6.871809705018696, 7.093232068564305, 7.310993029013562, 7.525315641645683, 7.73640032290703, 7.944427991004844, 8.149562663142854, 8.351953620616454, 8.551737226956154, 8.749038465080735, 8.943972245045497, 9.136644523101976, 9.327153264482238, 9.515589275917021, 9.702036928913381, 9.886574790907103, 10.069276178312515, 10.250209643028887, 10.429439401986416, 10.607025717719647, 10.783025236660462, 10.957491290784272, 11.130474167373658, 11.302021350946, 11.472177740796079, 11.640985847108315, 11.808485968177774, 11.974716350929672, 12.139713336632289, 12.303511493448214, 12.466143737256461, 12.627641441996488, 12.788034540629956, 12.947351617682624, 13.105619994213722, 13.26286580596095, 13.419114075322911, 13.574388777766167, 13.728712903178684, 13.88210851263459, 14.034596790985198, 14.186198095647464, 14.336932001922506, 14.486817345142862, 14.635872259917063, 14.784114216713599, 14.931560056002704, 15.078226020153446, 15.224127783264938, 15.369280479093808, 15.513698727225211, 15.6573966576213, 15.800387933669132, 15.942685773839294, 16.084302972056793, 16.22525191687714, 16.365544609552682, 16.505192681067047, 16.644207408209407, 16.78259972875412, 16.920380255806293, 17.057559291368936, 17.194146839182967, 17.330152616887467, 17.4655860675439, 17.600456370564675, 17.734772452083565, 17.86854299480257, 18.00177644734735, 18.134481033161126, 18.26666475896464, 18.398335422808017, 18.5295006217384, 18.660167759105693, 18.790344051527256, 18.920036535530784, 19.049252073893598, 19.177997361695184, 19.30627893209875, 19.434103161876603, 19.561476276693185, 19.688404356158586], [0.0, 0.98695408562295, 1.5486969618679896, 2.015699391794479, 2.4301660174852704, 2.8094897502762293, 3.1629713778842015, 3.496315980438462, 3.813339225136041, 4.116750816747572, 4.408561962541286, 4.690316984851082, 4.963234090381039, 5.2282955306284205, 5.486307838948609, 5.737943500492394, 5.983770631855311, 6.2242746525330395, 6.459874451647212, 6.690934675424275, 6.917775220804769, 7.14067867791726, 7.359896240818388, 7.575652456803504, 7.788149082904014, 7.99756824748854, 8.204075064871427, 8.40781981489023, 8.608939773210734, 8.80756075876211, 9.003798450232697, 9.197759512615097, 9.389542566430539, 9.579239025815728, 9.766933826638494, 9.952706061871973, 10.136629538343792, 10.318773266496676, 10.499201892807687, 10.677976082907298, 10.855152862135212, 11.030785919204273, 11.204925877768554, 11.37762053996924, 11.548915105432364, 11.718852368692856, 11.887472897600963, 12.054815194915472, 12.220915844991309, 12.385809647217402, 12.549529737646989, 12.712107700079718, 12.87357366769875, 13.033956416231655, 13.193283449488153, 13.351581078027815, 13.508874491624002, 13.665187826115105, 13.820544225168383, 13.97496589742443, 14.128474169439967, 14.281089534802655, 14.432831699752747, 14.58371962561227, 14.733771568292095, 14.883005115120628, 15.031437219213965, 15.179084231586332, 15.325961931180847, 15.472085552983792, 15.617469814370692, 15.762128939818968, 15.906076684110042, 16.04932635413281, 16.191890829390807, 16.333782581306565, 16.47501369140876, 16.615595868480646, 16.755540464741806, 16.894858491129337, 17.033560631739377, 17.171657257485002, 17.309158439022134, 17.446073958991107, 17.582413323618, 17.718185773716282, 17.853400295126615, 17.988065628629563, 18.122190279363622, 18.2557825257786, 18.388850428152175, 18.5214018366956, 18.65344439927265, 18.784985568754223, 18.9160326100296, 19.046592606693793, 19.176672467429228, 19.30627893209875, 19.43541857756588, 19.564097823257143, 19.692322936480423, 19.82010003751231], [0.0, 0.9934885735097438, 1.5589506724357443, 2.0290450615180964, 2.446255813997063, 2.8280909972933728, 3.1839129783660662, 3.5194646098989284, 3.8385868220991353, 4.144007260321648, 4.437750447762687, 4.721370931502904, 4.996094983826195, 5.2629113595825165, 5.522631932074181, 5.775933638884099, 6.023388358030011, 6.265484722903622, 6.502644396034093, 6.735234437920615, 6.963576863497579, 7.187956133884106, 7.408625106258295, 7.625809814612401, 7.839713351783512, 8.050519051987248, 8.258393122737221, 8.463486838853221, 8.665938384884424, 8.865874412789902, 9.063411367150755, 9.2586566191739, 9.451709442333534, 9.642661856006848, 9.831599358410424, 10.018601566181147, 10.203742774811541, 10.38709245165303, 10.56871567119815, 10.748673500736205, 10.927023343163867, 11.103819242659599, 11.279112158049756, 11.452950207966955, 11.62537889129777, 11.796441285913879, 11.966178228259718, 12.13462847601557, 12.30182885575636, 12.467814397273015, 12.63261845600804, 12.796272824873096, 12.958807836559027, 13.120252457313553, 13.280634373045354, 13.439980068512616, 13.59831490026674, 13.755663163946197, 13.9120481564493, 14.06749223345701, 14.222016862726264, 14.37564267352996, 14.528389502580668, 14.680276436740733, 14.831321852790916, 14.981543454502914, 15.130958307237082, 15.279582870265475, 15.427433027001433, 15.574524113299997, 15.720870943978417, 15.86648783769244, 16.011388640292, 16.155586746769096, 16.299095121900685, 16.44192631968088, 16.584092501628508, 16.725605454049074, 16.86647660432365, 17.006717036291242, 17.146337504785922, 17.285348449385168, 17.42376000742133, 17.561582026304272, 17.698824075199482, 17.835495456102603, 17.971605214348312, 18.10716214858869, 18.24217482027358, 18.376651562663277, 18.510600489401458, 18.64402950267455, 18.77694630098178, 18.909358386538493, 19.041273072333798, 19.17269748886223, 19.303638590547646, 19.434103161876603, 19.564097823257143, 19.693629036617928, 19.822703110761825, 19.95132620648695], [0.0, 1.0, 1.5691681957935018, 2.042343631945352, 2.462288826689833, 2.846626597125766, 3.204780672130035, 3.54253154363472, 3.8637453156993837, 4.171167510947729, 4.466835921509633, 4.75231528312751, 5.028839905200173, 5.297405022978756, 5.5588278308668615, 5.813789703166074, 6.062866266041595, 6.306549355438734, 6.54526339750632, 6.779377858495882, 7.009216863860873, 7.235066739107905, 7.457181998667078, 7.675790157980725, 7.891095640977317, 8.103282983463815, 8.312519482295007, 8.518957403761437, 8.722735838088056, 8.923982267323932, 9.122813899239944, 9.319338808764964, 9.513656920021774, 9.70586085549204, 9.896036673756468, 10.084264513267588, 10.270619156458237, 10.455170525976017, 10.637984122818395, 10.819121414515982, 10.998640180189954, 11.176594818229882, 11.353036621451524, 11.528014023861974, 11.701572822552198, 11.873756377730684, 12.044605793488131, 12.214160081526652, 12.382456309786344, 12.549529737646989, 12.715413939166098, 12.880140915629358, 13.043741198531189, 13.206243943967086, 13.367677019302027, 13.528067082878032, 13.687439657435952, 13.845819197850378, 14.003229153709894, 14.1596920272169, 14.315229426830221, 14.46986211702914, 14.623610064538079, 14.776492481316652, 14.92852786458893, 15.079734034158955, 15.230128167235215, 15.379726830965529, 15.528546012864762, 15.676601149300735, 15.823907152188534, 15.970478434029847, 16.116328931421744, 16.261472127148373, 16.405921070959185, 16.549688399128453, 16.69278635288286, 16.835226795776567, 16.97702123008688, 17.118180812297428, 17.25871636773058, 17.398638404385874, 17.537957126036783, 17.67668244463411, 17.81482399206064, 17.95239113127825, 18.089392966905677, 18.225838355262272, 18.361735913910504, 18.49709403072772, 18.63192087253524, 18.766224393311248, 18.900012342011728, 19.033292270022304, 19.166071538262187, 19.29835732395989, 19.4301566271193, 19.561476276693185, 19.692322936480423, 19.822703110761825, 19.952623149688808, 20.08208925443799], [0.0, 1.0064886758887739, 1.5793500196309778, 2.0555957378265464, 2.4782658208307726, 2.865097434490878, 3.225575455206094, 3.565517882647123, 3.888815906769725, 4.198232865004053, 4.495819772052641, 4.7831515167209915, 5.061470417441549, 5.331778167224428, 5.594897262982852, 5.851513500235409, 6.102206240198919, 6.347470510182732, 6.587733490299393, 6.823367044147191, 7.054697400324595, 7.2820127422116245, 7.505569235700028, 7.725595872506102, 7.9422984029989365, 8.15586256037853, 8.36645672703474, 8.574234157264716, 8.779334843804802, 8.981887095893763, 9.182008881825713, 9.379808977792713, 9.575387956292785, 9.768839040804865, 9.960248848315894, 10.149698037270845, 10.337261875341527, 10.523010738880938, 10.707010553901286, 10.88932318677607, 11.070006791536452, 11.249116119545524, 11.426702796441504, 11.602815570504056, 11.777500535986624, 11.95080133444804, 12.122759336690123, 12.293413807549278, 12.462802055487451, 12.63095956867111, 12.797920139008944, 12.963715975432612, 13.128377807545505, 13.291934980627572, 13.454415542866089, 13.615846325580417, 13.776253017120204, 13.935660231039792, 14.094091569084547, 14.251569679466368, 14.40811631085436, 14.563752362461788, 14.71849793057068, 14.872372351800818, 15.025394243398777, 15.177581540795524, 15.328951532656891, 15.479520893629543, 15.629305714966154, 15.778321533196127, 15.926583356993136, 16.07410569237692, 16.220902566374612, 16.36698754925577, 16.512373775445443, 16.6570739632106, 16.801100433207264, 16.94446512596836, 17.087179618405745, 17.229255139393857, 17.370702584497064, 17.51153252989791, 17.65175524557885, 17.79138070780612, 17.930418610960675, 18.068878378757613, 18.206769174892596, 18.344099913150753, 18.48087926701113, 18.617115678777285, 18.752817368262402, 18.887992341055448, 19.022648396392867, 19.156793134658784, 19.290433964535023, 19.423578109820813, 19.556232615940786, 19.688404356158586, 19.82010003751231, 19.95132620648695, 20.08208925443799, 20.212395422779466]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 1.4000000000000001\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.03981071705534972, 0.06467270065773573, 0.08589836120408868, 0.10506111217615068, 0.12282280261157903, 0.13954229946218907, 0.15544209038050336, 0.17067228025785933, 0.18534025517022357, 0.19952623149688795, 0.21329215374853938, 0.22668713426244505, 0.23975095546559166, 0.2525164208123728, 0.2650109880753873, 0.27725793726205855, 0.28927722651989246, 0.30108613280658053, 0.312699740378802, 0.3241313193385525, 0.3353926232290463, 0.34649412601246754, 0.35744521296443443, 0.3682543360555974, 0.37892914162759955, 0.38947657621124787, 0.3999029749234436, 0.41021413584829874, 0.4204153830445961, 0.4305116202499342, 0.4405073769187359, 0.4504068478997878, 0.46021392780284126, 0.46993224090413643, 0.47956516728377424, 0.48911586576355365, 0.49858729411470915, 0.5079822269253093, 0.517303271452664, 0.526552881733695, 0.5357333711833627, 0.5448469238759938, 0.5538956046752127, 0.5628813683539724, 0.5718060678259764, 0.5806714615928537, 0.5894792204971879, 0.5982309338594668, 0.6069281150667865, 0.6155722066724582, 0.6241645850582237, 0.6327065647044162, 0.6411994021079274, 0.6496442993831094, 0.6580424075766573, 0.6663948297239661, 0.6747026236713719, 0.6829668046859958, 0.6911883478725528, 0.6993681904144294, 0.707507233654516, 0.7156063450296855, 0.7236663598714064, 0.7316880830837222, 0.7396722907087352, 0.7476197313887468, 0.7555311277333359, 0.7634071775988812, 0.7712485552873364, 0.7790559126704492, 0.7868298802450583, 0.7945710681246025, 0.80228006697153, 0.8099574488748875, 0.8176037681770134, 0.825219562252919, 0.8328053522456563, 0.840361643760693, 0.8478889275220775, 0.8553876799929505, 0.8628583639627645, 0.870301429103382, 0.8777173124960633, 0.8851064391311988, 0.8924692223825023, 0.8998060644572552, 0.9071173568240766, 0.9144034806195821, 0.9216648070352077, 0.928901697685371, 0.9361145049580709, 0.9433035723489465, 0.9504692347797457, 0.9576118189020935, 0.9647316433873819, 0.9718290192035612, 0.9789042498795497, 0.9859576317579407, 0.9929894542366359, 1.0000000000000002, 1.0069895452400897], [0.0, 0.06467270065773573, 0.10506111217615066, 0.13954229946218905, 0.17067228025785933, 0.19952623149688795, 0.22668713426244502, 0.2525164208123728, 0.2772579372620585, 0.3010861328065805, 0.32413131933855244, 0.34649412601246743, 0.3682543360555973, 0.38947657621124787, 0.41021413584829874, 0.43051162024993417, 0.4504068478997877, 0.4699322409041364, 0.4891158657635536, 0.5079822269253091, 0.526552881733695, 0.5448469238759938, 0.5628813683539723, 0.5806714615928535, 0.5982309338594668, 0.6155722066724582, 0.6327065647044161, 0.6496442993831093, 0.6663948297239659, 0.6829668046859956, 0.6993681904144293, 0.7156063450296853, 0.7316880830837222, 0.7476197313887467, 0.7634071775988811, 0.779055912670449, 0.7945710681246024, 0.8099574488748873, 0.8252195622529188, 0.8403616437606929, 0.8553876799929504, 0.8703014291033819, 0.8851064391311987, 0.8998060644572552, 0.9144034806195819, 0.928901697685371, 0.9433035723489462, 0.9576118189020932, 0.9718290192035611, 0.9859576317579406, 1.0, 1.013958359868475, 1.0278348467429672, 1.0416315018086988, 1.0553502779061965, 1.068993044916333, 1.082561594725394, 1.0960576458098223, 1.1094828474759222, 1.1228387837859766, 1.1361269771988887, 1.149348891950503, 1.1625059371961781, 1.1755994699358874, 1.1886307977401074, 1.2016011812929523, 1.2145118367674292, 1.2273639380462622, 1.240158618800483, 1.252896974436847, 1.2655800639241328, 1.2782089115074768, 1.290784508319084, 1.3033078138929326, 1.3157797575904209, 1.3282012399433343, 1.3405731339199543, 1.3528962861196663, 1.3651715179009758, 1.3773996264474517, 1.3895813857757495, 1.4017175476895525, 1.413808842682957, 1.4258559807965643, 1.4378596524293012, 1.449820529108747, 1.4617392642225575, 1.473616493713381, 1.4854528367394761, 1.4972488963031096, 1.509005259848636, 1.5207224998320483, 1.5324011742636585, 1.5440418272254517, 1.5556449893645576, 1.5672111783641802, 1.5787408993932452, 1.5902346455359349, 1.6016928982022123, 1.6131161275203558, 1.6245047927124712, 1.6358593424538772], [0.0, 0.08589836120408868, 0.13954229946218905, 0.18534025517022357, 0.22668713426244502, 0.2650109880753873, 0.3010861328065806, 0.33539262322904634, 0.3682543360555973, 0.3999029749234436, 0.4305116202499342, 0.4602139278028412, 0.48911586576355376, 0.517303271452664, 0.5448469238759939, 0.5718060678259765, 0.5982309338594668, 0.6241645850582237, 0.6496442993831093, 0.6747026236713719, 0.6993681904144295, 0.7236663598714064, 0.7476197313887468, 0.7712485552873364, 0.7945710681246027, 0.8176037681770134, 0.840361643760693, 0.8628583639627645, 0.8851064391311988, 0.9071173568240765, 0.928901697685371, 0.9504692347797457, 0.9718290192035612, 0.992989454236636, 1.0139583598684752, 1.0347430291940765, 1.0553502779061965, 1.0757864878969652, 1.0960576458098223, 1.1161693772437709, 1.1361269771988889, 1.1559354372595678, 1.1755994699358876, 1.1951235305206582, 1.2145118367674295, 1.2337683866511782, 1.2528969744368472, 1.271901205250152, 1.2907845083190843, 1.3095501490324901, 1.3282012399433343, 1.346740750828218, 1.365171517900976, 1.3834962522663514, 1.4017175476895527, 1.419837887748674, 1.4378596524293017, 1.4557851242139779, 1.473616493713381, 1.4913558648809997, 1.5090052598486363, 1.5265666234161557, 1.5440418272254517, 1.5614326736455724, 1.5787408993932452, 1.5959681789106748, 1.613116127520356, 1.6301863043747793, 1.6471802152172144, 1.6640993149682723, 1.6809450101515977, 1.6977186611708504, 1.7144215844490547, 1.7310550544404295, 1.747620305523937, 1.7641185337870107, 1.7805508987072047, 1.7969185247388728, 1.8132225028114, 1.8294638917449908, 1.8456437195895272, 1.8617629848915935, 1.8778226578943538, 1.893823681674616, 1.9097669732210898, 1.9256534244575387, 1.9414839032142583, 1.9572592541510614, 1.9729802996347157, 1.988647840573579, 2.0042626572119717, 2.0198255098866538, 2.0353371397476128, 2.0507982694452167, 2.066209603785641, 2.081571830356358, 2.096885620123363, 2.112151628001677, 2.127370493400611, 2.1425428407451266, 2.1576692799745936, 2.1727504070201276], [0.0, 0.10506111217615068, 0.17067228025785933, 0.22668713426244502, 0.27725793726205855, 0.3241313193385525, 0.3682543360555974, 0.4102141358482988, 0.45040684789978774, 0.48911586576355365, 0.526552881733695, 0.5628813683539723, 0.5982309338594669, 0.6327065647044162, 0.6663948297239661, 0.6993681904144295, 0.7316880830837222, 0.7634071775988812, 0.7945710681246025, 0.8252195622529189, 0.8553876799929505, 0.8851064391311988, 0.914403480619582, 0.9433035723489464, 0.9718290192035612, 1.0000000000000002, 1.0278348467429672, 1.0553502779061965, 1.082561594725394, 1.1094828474759222, 1.1361269771988887, 1.1625059371961781, 1.1886307977401076, 1.2145118367674295, 1.2401586188004832, 1.265580063924133, 1.2907845083190843, 1.3157797575904209, 1.3405731339199543, 1.365171517900976, 1.3895813857757495, 1.413808842682957, 1.4378596524293015, 1.461739264222558, 1.4854528367394761, 1.5090052598486363, 1.5324011742636585, 1.5556449893645576, 1.5787408993932452, 1.6016928982022125, 1.6245047927124714, 1.6471802152172144, 1.6697226346508387, 1.6921353669285206, 1.714421584449055, 1.736584324842881, 1.7586264990378586, 1.7805508987072045, 1.8023602031569153, 1.8240569857037612, 1.8456437195895272, 1.8671227834723607, 1.8884964665318944, 1.90976697322109, 1.9309364276944525, 1.9520068779393682, 1.9729802996347157, 1.9938585997586056, 2.0146436199650632, 2.0353371397476123, 2.05594087940611, 2.0764565028316873, 2.0968856201233628, 2.1172297900486825, 2.1374905223596925, 2.1576692799745936, 2.177767481034543, 2.1977865008443005, 2.2177276737046947, 2.237592294644253, 2.2573816210567426, 2.27709687425085, 2.2967392409177356, 2.3163098745217603, 2.335809896619288, 2.3552403981100904, 2.374602440425546, 2.3938970566575346, 2.413125252631615, 2.4322880079278595, 2.4513862768524373, 2.470420989362853, 2.4893930519495324, 2.5083033484762676, 2.5271527409818653, 2.5459420704451707, 2.5646721575155245, 2.583343803210544, 2.601957789583022, 2.6205148803586, 2.639015821545789, 2.6574613420197957], [0.0, 0.12282280261157903, 0.19952623149688795, 0.2650109880753873, 0.3241313193385525, 0.37892914162759955, 0.4305116202499343, 0.47956516728377424, 0.526552881733695, 0.5718060678259764, 0.6155722066724582, 0.6580424075766572, 0.6993681904144295, 0.7396722907087353, 0.7790559126704493, 0.8176037681770133, 0.8553876799929505, 0.8924692223825024, 0.928901697685371, 0.9647316433873818, 1.0, 1.0347430291940765, 1.0689930449163332, 1.1027790023311073, 1.1361269771988889, 1.1690605597782768, 1.2016011812929526, 1.233768386651178, 1.265580063924133, 1.297052638734598, 1.3282012399433343, 1.3590398416841343, 1.3895813857757497, 1.4198378877486741, 1.4498205291087471, 1.479539737975374, 1.5090052598486363, 1.5382262199535828, 1.5672111783641804, 1.5959681789106748, 1.6245047927124712, 1.6528281570464152, 1.6809450101515977, 1.7088617224819098, 1.7365843248428812, 1.7641185337870107, 1.7914697745895611, 1.818643202082801, 1.8456437195895274, 1.8724759961651687, 1.899144482330935, 1.925653424457539, 1.9520068779393684, 1.9782087192820759, 2.004262657211972, 2.030172242902999, 2.05594087940611, 2.081571830356358, 2.107068228024712, 2.132433080774315, 2.1576692799745936, 2.182779606420972, 2.207766736303074, 2.2326332467599124, 2.2573816210567426, 2.282014253414844, 2.3065334535224724, 2.3309414507525266, 2.3552403981100904, 2.3794323759308607, 2.403519395349549, 2.4275034015556547, 2.4513862768524377, 2.475169843533556, 2.498855866590583, 2.5224460562634894, 2.5459420704451707, 2.569345516950178, 2.5926579556569855, 2.615880900532369, 2.639015821545789, 2.662064146481063, 2.6850272626520226, 2.707906518528359, 2.7307032252773835, 2.7534186582269933, 2.776054058254751, 2.7986106331076264, 2.8210895586566114, 2.843491980090133, 2.865819013049896, 2.888071744712541, 2.9102512348202727, 2.9323585166633914, 2.9543945980174655, 2.9763604620376958, 2.9982570681128595, 3.0200853526810607, 3.0418462300093756, 3.0635405929393285, 3.0851693136000486, 3.1067332440907927], [0.0, 0.13954229946218907, 0.22668713426244502, 0.3010861328065806, 0.3682543360555974, 0.4305116202499343, 0.48911586576355376, 0.5448469238759939, 0.5982309338594669, 0.6496442993831094, 0.6993681904144295, 0.7476197313887468, 0.7945710681246028, 0.8403616437606931, 0.885106439131199, 0.9289016976853712, 0.9718290192035612, 1.0139583598684754, 1.0553502779061967, 1.0960576458098226, 1.1361269771988889, 1.1755994699358876, 1.2145118367674295, 1.2528969744368474, 1.2907845083190845, 1.3282012399433345, 1.3651715179009762, 1.4017175476895527, 1.4378596524293017, 1.473616493713381, 1.5090052598486363, 1.544041827225452, 1.5787408993932455, 1.6131161275203563, 1.6471802152172146, 1.680945010151598, 1.714421584449055, 1.747620305523937, 1.780550898707205, 1.8132225028114004, 1.8456437195895274, 1.877822657894354, 1.90976697322109, 1.9414839032142586, 1.9729802996347157, 2.004262657211972, 2.0353371397476128, 2.0662096037856403, 2.096885620123363, 2.1273704934006115, 2.1576692799745936, 2.1877868042616324, 2.217727673704695, 2.24749629250643, 2.2770968742508506, 2.306533453522473, 2.335809896619289, 2.3649299114451274, 2.393897056657535, 2.4227147501390367, 2.4513862768524377, 2.479914796134439, 2.508303348476268, 2.5365548618350804, 2.5646721575155245, 2.592657955656986, 2.6205148803586007, 2.6482454644710605, 2.6758521540815248, 2.7033373127154987, 2.730703225277384, 2.7579521017494466, 2.7850860806671984, 2.8121072323876257, 2.8390175621652687, 2.8658190130498964, 2.8925134686183522, 2.9191027555521223, 2.9455886460712217, 2.9719728602341475, 2.9982570681128595, 3.02444289185107, 3.050531907613449, 3.076525647432791, 3.10242560096165, 3.1282332171344542, 3.1539499057456784, 3.1795770389492364, 3.2051159526838835, 3.2305679480290856, 3.255934292495481, 3.28121622125378, 3.30641493830569, 3.3315316176001963, 3.3565674040983096, 3.3815234147891755, 3.406400739660266, 3.431200442624174, 3.455923562404388, 3.480571113382251, 3.5051440864071943, 3.52964344957217], [0.0, 0.15544209038050336, 0.2525164208123728, 0.33539262322904634, 0.4102141358482988, 0.47956516728377424, 0.5448469238759939, 0.6069281150667865, 0.6663948297239661, 0.7236663598714064, 0.7790559126704492, 0.8328053522456562, 0.8851064391311989, 0.936114504958071, 0.9859576317579408, 1.0347430291940765, 1.0825615947253941, 1.1294912555131684, 1.1755994699358874, 1.2209451349078364, 1.265580063924133, 1.3095501490324901, 1.3528962861196663, 1.3956551202643943, 1.4378596524293017, 1.4795397379753743, 1.5207224998320485, 1.5614326736455721, 1.6016928982022123, 1.6415239614426977, 1.6809450101515975, 1.71997372971405, 1.7586264990378586, 1.7969185247388728, 1.8348639579079686, 1.872475996165169, 1.9097669732210898, 1.9467484377786326, 1.983431223296755, 2.0198255098866538, 2.05594087940611, 2.091786364650409, 2.127370493400611, 2.1627013279761593, 2.1977865008443005, 2.2326332467599124, 2.2672484318432087, 2.301638579947141, 2.3358098966192884, 2.3697682909231186, 2.4035193953495493, 2.4370685840206976, 2.470420989362853, 2.5035815174042866, 2.53655486183508, 2.569345516950178, 2.6019577895830226, 2.634395810125074, 2.6666635427160243, 2.6987647946802933, 2.730703225277384, 2.7624823538265475, 2.794105567260019, 2.8255761271535547, 2.8568971762781548, 2.888071744712541, 2.919102755552122, 2.9499930302467936, 2.980745293596869, 3.0113621784337297, 3.0418462300093756, 3.072199910116856, 3.10242560096165, 3.132525608802284, 3.1625021673769047, 3.192357441131124, 3.2220935282611385, 3.2517124635849908, 3.2812162212537794, 3.3106067173136737, 3.339885812128718, 3.369055312673646, 3.3981169747051863, 3.4270725048196966, 3.455923562404387, 3.4846717614888187, 3.5133186725028964, 3.541865823947108, 3.5703147039803382, 3.5986667619302297, 3.626923409730683, 3.6550860232907794, 3.6831559437991275, 3.7111344789673306, 3.739022904216057, 3.7668224638069288, 3.794534371923256, 3.8221598137024344, 3.849699946222648, 3.8771558994463318, 3.904528777122723, 3.931819657651654], [0.0, 0.17067228025785933, 0.2772579372620585, 0.3682543360555973, 0.45040684789978774, 0.526552881733695, 0.5982309338594669, 0.6663948297239661, 0.7316880830837221, 0.7945710681246025, 0.8553876799929504, 0.9144034806195819, 0.9718290192035612, 1.0278348467429672, 1.082561594725394, 1.1361269771988887, 1.1886307977401074, 1.240158618800483, 1.290784508319084, 1.340573133919954, 1.3895813857757495, 1.4378596524293015, 1.4854528367394761, 1.5324011742636585, 1.5787408993932452, 1.6245047927124712, 1.6697226346508385, 1.7144215844490545, 1.7586264990378582, 1.802360203156915, 1.845643719589527, 1.8884964665318944, 1.9309364276944525, 1.9729802996347154, 2.0146436199650632, 2.0559408794061094, 2.0968856201233628, 2.137490522359692, 2.177767481034543, 2.2177276737046947, 2.257381621056742, 2.2967392409177356, 2.335809896619288, 2.374602440425546, 2.4131252526316147, 2.4513862768524373, 2.489393051949532, 2.527152740981865, 2.564672157515524, 2.601957789583022, 2.639015821545789, 2.6758521540815243, 2.7124724224907815, 2.7488820134936574, 2.785086080667198, 2.821089558656611, 2.8568971762781548, 2.8925134686183513, 2.927942788222632, 2.9631893154564235, 2.998257068112859, 3.033149910333499, 3.0678715609016294, 3.10242560096165, 3.136815481212736, 3.1710445286202114, 3.2051159526838826, 3.2390328512988313, 3.2727982162408473, 3.306414938305689, 3.3398858121287174, 3.3732135407090524, 3.406400739660265, 3.4394499412077035, 3.4723635979508036, 3.5051440864071934, 3.5377937103539807, 3.570314703980338, 3.6027092348643555, 3.6349794067860843, 3.667127262387725, 3.6991547856910927, 3.7310639044816645, 3.762856492567822, 3.794534371923255, 3.82609931471987, 3.8575530452580296, 3.888897241800443, 3.920133538315551, 3.951263526135876, 3.9822887555363646, 4.013210737237439, 4.04403094383714, 4.074750811176436, 4.105371739641498, 4.135895095406491, 4.166322211620202, 4.196654389539591, 4.2268928996131665, 4.257038982516893, 4.287093850145173, 4.317058686559273], [0.0, 0.18534025517022357, 0.3010861328065805, 0.3999029749234436, 0.48911586576355365, 0.5718060678259764, 0.6496442993831094, 0.7236663598714064, 0.7945710681246025, 0.8628583639627644, 0.928901697685371, 0.9929894542366358, 1.0553502779061967, 1.1161693772437709, 1.1755994699358876, 1.233768386651178, 1.290784508319084, 1.346740750828218, 1.4017175476895525, 1.4557851242139779, 1.509005259848636, 1.5614326736455721, 1.6131161275203558, 1.6640993149682723, 1.7144215844490547, 1.7641185337870104, 1.8132225028114, 1.8617629848915933, 1.9097669732210896, 1.957259254151061, 2.0042626572119717, 2.0507982694452163, 2.096885620123363, 2.1425428407451266, 2.187786804261632, 2.2326332467599124, 2.2770968742508497, 2.3211914567470413, 2.364929911445127, 2.4083243765272573, 2.4513862768524373, 2.494126382608968, 2.5365548618350795, 2.578681327579202, 2.6205148803586, 2.662064146481063, 2.7033373127154983, 2.7443421577309124, 2.785086080667198, 2.825576127153554, 2.865819013049896, 2.9058211461519643, 2.9455886460712213, 2.9851273624750863, 3.0244428918510695, 3.0635405929393285, 3.10242560096165, 3.1411028407604973, 3.1795770389492355, 3.2178527351636728, 3.2559342924954806, 3.2938259071795826, 3.3315316176001954, 3.3690553126736456, 3.4064007396602647, 3.443571511452558, 3.4805711133822506, 3.5174029095847725, 3.554070148956122, 3.5905759707338056, 3.626923409730683, 3.6631154012479388, 3.699154785691093, 3.7350443129108615, 3.770786646288811, 3.806384366586054, 3.8418399755716894, 3.8771558994463318, 3.912334492074803, 3.9473780380409313, 3.982288755536365, 4.017068799094393, 4.051720262178887, 4.086245179637701, 4.120645530029207, 4.154923237829907, 4.189080175530571, 4.22311816562773, 4.257038982516894, 4.290844354293424, 4.32453596446652, 4.358115453591451, 4.391584420824779, 4.424944425407002, 4.458196988076752, 4.4913435924203995, 4.524385686160655, 4.557324682387544, 4.590161960734892, 4.622898868505256, 4.6555367217460795, 4.688076806279622], [0.0, 0.19952623149688795, 0.32413131933855244, 0.4305116202499342, 0.526552881733695, 0.6155722066724582, 0.6993681904144295, 0.7790559126704492, 0.8553876799929504, 0.928901697685371, 1.0, 1.068993044916333, 1.1361269771988889, 1.2016011812929526, 1.265580063924133, 1.3282012399433343, 1.3895813857757495, 1.4498205291087471, 1.509005259848636, 1.5672111783641802, 1.6245047927124712, 1.6809450101515975, 1.736584324842881, 1.7914697745895611, 1.8456437195895272, 1.899144482330935, 1.9520068779393682, 2.0042626572119717, 2.0559408794061094, 2.1070682280247115, 2.157669279974593, 2.207766736303074, 2.2573816210567426, 2.3065334535224724, 2.3552403981100904, 2.403519395349549, 2.4513862768524373, 2.4988558665905827, 2.5459420704451703, 2.5926579556569855, 2.639015821545789, 2.685027262652022, 2.7307032252773835, 2.776054058254751, 2.821089558656611, 2.865819013049896, 2.9102512348202723, 2.954394598017465, 2.998257068112859, 3.041846230009375, 3.0851693136000486, 3.1282332171344542, 3.1710445286202114, 3.2136095454593314, 3.255934292495481, 3.298024538627749, 3.339885812128718, 3.3815234147891746, 3.422942434998318, 3.4641477598564947, 3.5051440864071934, 3.5459359320659103, 3.586527644315514, 3.626923409730683, 3.667127262387725, 3.7071430917105856, 3.7469746497989043, 3.7866255582796393, 3.8260993147198703, 3.865399298634905, 3.9045287771227226, 3.9434909101529874, 3.982288755536365, 4.020925273597639, 4.059403331574077, 4.09772570775871, 4.135895095406491, 4.173914106419866, 4.21178527482889, 4.249511060079848, 4.287093850145173, 4.32453596446652, 4.361839656741857, 4.3990071175666605, 4.436040476938512, 4.472941806633692, 4.509713122463748, 4.546356386419422, 4.582873508708775, 4.619266349695895, 4.6555367217460795, 4.691686390982991, 4.72771707896292, 4.7636304642709115, 4.799428184043207, 4.8351118354201414, 4.870682976933382, 4.906143129831117, 4.941493779344592, 4.9767363758991445, 5.011872336272724, 5.0469030447046554], [0.0, 0.21329215374853938, 0.34649412601246743, 0.4602139278028412, 0.5628813683539723, 0.6580424075766572, 0.7476197313887468, 0.8328053522456562, 0.9144034806195819, 0.9929894542366358, 1.068993044916333, 1.142746130079493, 1.2145118367674295, 1.284503305565416, 1.3528962861196663, 1.419837887748674, 1.485452836739476, 1.5498480619941686, 1.6131161275203558, 1.6753378495864393, 1.736584324842881, 1.7969185247388724, 1.8563965651677656, 1.9150687292140716, 1.9729802996347152, 2.030172242902999, 2.08668177614603, 2.142542840745126, 2.1977865008443, 2.2524412809225987, 2.306533453522472, 2.360087285905618, 2.4131252526316147, 2.4656682196823727, 2.517735604685662, 2.5693455169501775, 2.6205148803586, 2.671259541633709, 2.7215943660657755, 2.771533322444316, 2.821089558656611, 2.8702754691857515, 2.9191027555521214, 2.9675824805860893, 3.0157251172900046, 3.0635405929393285, 3.111038328982041, 3.1582272772190554, 3.205115952683882, 3.25171246358499, 3.298024538627749, 3.3440595519929763, 3.3898245462149976, 3.4353262531727635, 3.4805711133822506, 3.5255652937564617, 3.570314703980338, 3.6148250116313556, 3.6591016561621794, 3.703149861849088, 3.746974649798904, 3.7905808490973727, 3.833973107173444, 3.8771558994463313, 3.9201335383155507, 3.9629101815482475, 4.005489840112841, 4.047876385503361, 4.090073556594689, 4.132084966065185, 4.173914106419865, 4.215564355644323, 4.257038982516893, 4.298341151604179, 4.339473927962879, 4.3804402815689185, 4.421243091493112, 4.461885149841007, 4.50236916547311, 4.542697767520391, 4.582873508708774, 4.622898868505255, 4.66277625609729, 4.702508013216206, 4.742096416814602, 4.781543681606914, 4.820851962481665, 4.860023356793315, 4.899059906540992, 4.937963600440969, 4.9767363758991445, 5.015380120889429, 5.053896675743523, 5.092287834857166, 5.130555348317614, 5.168700923456776, 5.2067262263341645, 5.244632883153513, 5.282422481616694, 5.3200965722183025, 5.357656669484115, 5.395104253156341], [0.0, 0.22668713426244505, 0.3682543360555973, 0.48911586576355376, 0.5982309338594669, 0.6993681904144295, 0.7945710681246028, 0.8851064391311989, 0.9718290192035612, 1.0553502779061967, 1.1361269771988889, 1.2145118367674295, 1.2907845083190845, 1.3651715179009762, 1.437859652429302, 1.5090052598486365, 1.5787408993932455, 1.6471802152172146, 1.7144215844490547, 1.7805508987072047, 1.8456437195895274, 1.90976697322109, 1.9729802996347157, 2.0353371397476128, 2.096885620123363, 2.1576692799745936, 2.2177276737046947, 2.27709687425085, 2.3358098966192884, 2.3938970566575346, 2.4513862768524377, 2.508303348476268, 2.5646721575155245, 2.6205148803586003, 2.6758521540815248, 2.730703225277384, 2.785086080667198, 2.8390175621652687, 2.892513468618352, 2.9455886460712217, 2.9982570681128595, 3.050531907613449, 3.1024256009616504, 3.1539499057456784, 3.205115952683883, 3.2559342924954815, 3.3064149383056898, 3.356567404098309, 3.4064007396602656, 3.4559235624043874, 3.5051440864071943, 3.554070148956123, 3.6027092348643563, 3.6510684987802056, 3.699154785691094, 3.7469746497989047, 3.7945343719232563, 3.8418399755716894, 3.8888972418004433, 3.9357117229760616, 3.9822887555363655, 4.028633471838967, 4.074750811176437, 4.120645530029208, 4.166322211620203, 4.211785274828891, 4.257038982516894, 4.302087449312301, 4.346934648895426, 4.391584420824779, 4.436040476938513, 4.4803064073634085, 4.524385686160655, 4.568281676635101, 4.611997636332355, 4.65553672174608, 4.6989019927558875, 4.742096416814603, 4.7851228729021384, 4.827984155261763, 4.870682976933383, 4.913221973097229, 4.955603704240366, 4.997830659157407, 5.039905257796069, 5.081829853957274, 5.123606737858901, 5.165238138571562, 5.206726226334166, 5.248073114756543, 5.289280862915798, 5.33035147735267, 5.3712869139737025, 5.412089079864651, 5.452759835020162, 5.493300993994457, 5.5337143274774085, 5.574001563800122, 5.614164390373884, 5.654204455066048, 5.694123367516263, 5.733922700396169], [0.0, 0.23975095546559166, 0.38947657621124787, 0.517303271452664, 0.6327065647044162, 0.7396722907087353, 0.8403616437606931, 0.936114504958071, 1.0278348467429672, 1.1161693772437709, 1.2016011812929526, 1.284503305565416, 1.3651715179009762, 1.4438453988846192, 1.5207224998320488, 1.5959681789106748, 1.6697226346508387, 1.7421060604398442, 1.8132225028114, 1.883162803257919, 1.9520068779393684, 2.0198255098866538, 2.08668177614603, 2.1526321973974363, 2.2177276737046947, 2.2820142534148444, 2.345533770423913, 2.4083243765272573, 2.470420989362853, 2.5318556718593417, 2.5926579556569855, 2.6528551183610602, 2.712472422490782, 2.7715333224443164, 2.8300596445979687, 2.888071744712541, 2.9455886460712213, 3.002628161176069, 3.059206999350342, 3.1153408622060055, 3.171044528620212, 3.226331930606453, 3.2812162212537794, 3.3357098357320036, 3.389824546214998, 3.4435715114525585, 3.496961321619313, 3.5500040389833036, 3.602709234864356, 3.6550860232907794, 3.707143091710586, 3.7588887290686137, 3.8103308515226, 3.861477026038241, 3.912334492074804, 3.962910181548248, 4.01321073723744, 4.063242529780451, 4.113011673391755, 4.1625240404168995, 4.211785274828891, 4.2608008047595245, 4.309575854149352, 4.358115453591452, 4.406424450436682, 4.454507518221448, 4.502369165473111, 4.550013743942901, 4.5974454563115525, 4.644668363408652, 4.691686390982991, 4.738503336057851, 4.7851228729021384, 4.831548558645611, 4.877783838563959, 4.923832051057366, 4.969696432344168, 5.0153801208894295, 5.060886161586657, 5.1062175097094125, 5.151377034648193, 5.1963675234468285, 5.241191684151462, 5.285852148984206, 5.330351477352669, 5.3746921587056775, 5.41887661524477, 5.462907204500337, 5.506786221780642, 5.550515902501372, 5.594098424402809, 5.6375359096612305, 5.6808304269007115, 5.723983993111023, 5.7669985754770074, 5.8098760931243785, 5.852618418786626, 5.895227380397373, 5.937704762612238, 5.980052308264019, 6.022271719754775, 6.064364660388113], [0.0, 0.2525164208123728, 0.41021413584829874, 0.5448469238759939, 0.6663948297239661, 0.7790559126704493, 0.885106439131199, 0.9859576317579408, 1.082561594725394, 1.1755994699358876, 1.265580063924133, 1.3528962861196663, 1.437859652429302, 1.5207224998320488, 1.6016928982022127, 1.6809450101515977, 1.7586264990378584, 1.8348639579079686, 1.9097669732210898, 1.983431223296755, 2.05594087940611, 2.127370493400611, 2.1977865008443005, 2.267248431843209, 2.3358098966192884, 2.4035193953495493, 2.470420989362853, 2.53655486183508, 2.601957789583022, 2.666663542716024, 2.7307032252773835, 2.794105567260019, 2.856897176278155, 2.919102755552122, 2.980745293596869, 3.0418462300093756, 3.10242560096165, 3.1625021673769043, 3.222093528261138, 3.28121622125378, 3.339885812128718, 3.3981169747051863, 3.4559235624043874, 3.513318672502897, 3.570314703980338, 3.6269234097306833, 3.683155943799127, 3.7390229042160565, 3.794534371923256, 3.849699946222648, 3.904528777122723, 3.9590295949106187, 4.013210737237439, 4.067080173969624, 4.120645530029208, 4.173914106419866, 4.226892899613167, 4.279588619449836, 4.332007705693799, 4.384156343361825, 4.436040476938513, 4.487665823574855, 4.539037885358499, 4.590161960734892, 4.641043155150588, 4.691686390982992, 4.742096416814603, 4.792277816104302, 4.842235015303255, 4.891972291458662, 4.941493779344592, 4.990803478155655, 5.039905257796069, 5.088802864793862, 5.137499927867359, 5.185999963168832, 5.234306379228055, 5.2824224816166945, 5.330351477352669, 5.378096479062164, 5.425660508915486, 5.4730465023517505, 5.520257311606178, 5.56729570905273, 5.614164390373883, 5.6608659775683945, 5.707403021807172, 5.753778006146582, 5.799993348107867, 5.846051402130727, 5.8919544619085515, 5.937704762612238, 5.983304483009108, 6.028755747482927, 6.074060627960688, 6.119221145751355, 6.164239273301535, 6.20911693587261, 6.2538560131436345, 6.298458340743998, 6.342925711719627, 6.387259877936219], [0.0, 0.2650109880753873, 0.43051162024993417, 0.5718060678259765, 0.6993681904144295, 0.8176037681770133, 0.9289016976853712, 1.0347430291940765, 1.1361269771988887, 1.233768386651178, 1.3282012399433343, 1.419837887748674, 1.5090052598486365, 1.5959681789106748, 1.6809450101515977, 1.7641185337870107, 1.8456437195895272, 1.925653424457539, 2.0042626572119717, 2.081571830356358, 2.1576692799745936, 2.2326332467599124, 2.3065334535224724, 2.3794323759308607, 2.4513862768524377, 2.5224460562634894, 2.5926579556569855, 2.662064146481063, 2.7307032252773835, 2.798610633107626, 2.865819013049896, 2.932358516663391, 2.9982570681128595, 3.063540592939329, 3.1282332171344542, 3.192357441131124, 3.255934292495481, 3.318983460445287, 3.381523414789175, 3.4435715114525585, 3.505144086407194, 3.5662565395360724, 3.626923409730683, 3.6871584423236854, 3.7469746497989043, 3.8063843665860544, 3.8653992986349053, 3.9240305683686856, 3.9822887555363655, 4.040183934415409, 4.09772570775871, 4.154923237829908, 4.211785274828891, 4.268320182972819, 4.324535964466521, 4.380440281568919, 4.436040476938513, 4.4913435924203995, 4.546356386419422, 4.60108534998832, 4.65553672174608, 4.709716501729565, 4.7636304642709115, 4.8172841699837985, 4.870682976933382, 4.923832051057365, 4.976736375899145, 5.029400761708137, 5.081829853957274, 5.134028141322975, 5.185999963168831, 5.2377495165704655, 5.289280862915798, 5.340597934111875, 5.391704538426792, 5.442604365992795, 5.493300993994456, 5.54379789156384, 5.594098424402809, 5.644205859150967, 5.694123367516262, 5.743854030183975, 5.793400840518542, 5.842766708071592, 5.8919544619085515, 5.940966853765247, 5.989806561045076, 6.038476189666573, 6.086978276770454, 6.135315293294608, 6.183489646424868, 6.231503681928875, 6.279359686379829, 6.327059889276466, 6.374606465065173, 6.422001535069723, 6.4692471693338085, 6.51634538838116, 6.56329816489776, 6.610107425340339, 6.656775051475127, 6.7033028818505125], [0.0, 0.27725793726205855, 0.4504068478997877, 0.5982309338594668, 0.7316880830837222, 0.8553876799929505, 0.9718290192035612, 1.0825615947253941, 1.1886307977401074, 1.290784508319084, 1.3895813857757495, 1.485452836739476, 1.5787408993932455, 1.6697226346508387, 1.7586264990378584, 1.8456437195895272, 1.9309364276944525, 2.0146436199650632, 2.0968856201233628, 2.177767481034543, 2.2573816210567426, 2.335809896619288, 2.4131252526316147, 2.489393051949532, 2.564672157515524, 2.639015821545789, 2.7124724224907815, 2.7850860806671975, 2.8568971762781548, 2.9279427882226314, 2.9982570681128586, 3.0678715609016294, 3.1368154812127362, 3.2051159526838826, 3.2727982162408473, 3.339885812128718, 3.406400739660265, 3.472363597950803, 3.5377937103539807, 3.602709234864356, 3.6671272623877256, 3.7310639044816645, 3.7945343719232554, 3.8575530452580304, 3.920133538315551, 3.982288755536365, 4.04403094383714, 4.105371739641497, 4.166322211620202, 4.2268928996131665, 4.287093850145173, 4.346934648895426, 4.406424450436682, 4.465572005521555, 4.524385686160655, 4.582873508708774, 4.641043155150588, 4.698901992755886, 4.756457092255581, 4.813715244673347, 4.870682976933382, 4.9273665663521715, 4.983772054110987, 5.039905257796069, 5.095771783084766, 5.151377034648192, 5.206726226334165, 5.261824390688092, 5.316676387864083, 5.371286913973702, 5.4256605089154855, 5.47980156372446, 5.533714327477407, 5.5874029137865415, 5.640871306911401, 5.694123367516262, 5.7471628380980775, 5.799993348107866, 5.8526184187866255, 5.9050414677351295, 5.9572658132354235, 6.009294678340455, 6.061131194746969, 6.112778406465666, 6.1642392733015345, 6.21551667415633, 6.266613410164258, 6.317532207671129, 6.368275721066511, 6.41884653547771, 6.469247169333807, 6.519480076807369, 6.569547650140973, 6.61945222186515, 6.6691960669139485, 6.718781404643848, 6.768210400761442, 6.817485169164896, 6.866607773703904, 6.915580229862515, 6.964404506368995, 7.013082526736545], [0.0, 0.28927722651989246, 0.4699322409041364, 0.6241645850582237, 0.7634071775988812, 0.8924692223825024, 1.0139583598684754, 1.1294912555131684, 1.240158618800483, 1.346740750828218, 1.4498205291087471, 1.5498480619941686, 1.6471802152172146, 1.7421060604398442, 1.8348639579079686, 1.925653424457539, 2.0146436199650632, 2.1019795666251677, 2.187786804261632, 2.272174939841099, 2.3552403981100904, 2.4370685840206976, 2.517735604685662, 2.5973096564777656, 2.6758521540815243, 2.7534186582269937, 2.8300596445979687, 2.9058211461519643, 2.9807452935968684, 3.0548707732230174, 3.1282332171344542, 3.2008655377756146, 3.2727982162408478, 3.3440595519929768, 3.4146758801662678, 3.4846717614888187, 3.5540701489561224, 3.6228925346668555, 3.691159079653036, 3.7588887290686133, 3.8260993147198707, 3.892807646609566, 3.9590295949106187, 4.0247801635733875, 4.09007355659469, 4.154923237829908, 4.219341985106512, 4.283341939293705, 4.346934648895426, 4.41013111065964, 4.472941806633693, 4.535376738041433, 4.5974454563115525, 4.659157091546768, 4.720520378689113, 4.781543681606915, 4.842235015303255, 4.902602066423259, 4.962652212218045, 5.022392538106025, 5.081829853957274, 5.140970709213517, 5.199821406944667, 5.25838801693264, 5.316676387864083, 5.374692158705678, 5.43244076932851, 5.489927470441692, 5.547157332889777, 5.6041352563634375, 5.660865977568395, 5.717354077893539, 5.773603990615547, 5.8296200076740625, 5.885406286048539, 5.940966853765248, 5.9963056155605114, 6.051426358224114, 6.106332755644852, 6.161028373578438, 6.215516674156332, 6.269801020152657, 6.323884679024995, 6.377770826743641, 6.431462551422812, 6.484962856766295, 6.538274665339052, 6.591400821675538, 6.644344095234617, 6.697107183210334, 6.749692713207103, 6.802103245787268, 6.854341276898481, 6.9064092401877994, 6.958309509208956, 7.010044399528795, 7.061616170738523, 7.113027028374995, 7.164279125756959, 7.215374565740847, 7.266315402400413, 7.31710364263425], [0.0, 0.30108613280658053, 0.4891158657635536, 0.6496442993831093, 0.7945710681246025, 0.928901697685371, 1.0553502779061967, 1.1755994699358874, 1.290784508319084, 1.4017175476895525, 1.509005259848636, 1.6131161275203558, 1.7144215844490547, 1.8132225028114, 1.9097669732210898, 2.0042626572119717, 2.0968856201233628, 2.187786804261632, 2.2770968742508497, 2.364929911445127, 2.4513862768524373, 2.5365548618350795, 2.6205148803586, 2.7033373127154983, 2.785086080667198, 2.865819013049896, 2.9455886460712213, 3.024442891851069, 3.1024256009616495, 3.179577038949235, 3.2559342924954806, 3.3315316176001954, 3.406400739660265, 3.4805711133822506, 3.554070148956122, 3.626923409730683, 3.6991547856910927, 3.770786646288811, 3.841839975571689, 3.912334492074803, 3.982288755536365, 4.051720262178887, 4.120645530029207, 4.189080175530571, 4.257038982516893, 4.32453596446652, 4.391584420824779, 4.458196988076752, 4.524385686160655, 4.590161960734891, 4.6555367217460795, 4.720520378689112, 4.785122872902138, 4.849353707197916, 4.913221973097229, 4.9767363758991445, 5.039905257796069, 5.102736619218185, 5.16523813857156, 5.22741719051632, 5.289280862915797, 5.3508359725737344, 5.412089079864649, 5.4730465023517505, 5.533714327477407, 5.594098424402809, 5.654204455066048, 5.714037884521254, 5.7736039906155465, 5.832907873055301, 5.8919544619085515, 5.950748525586143, 6.009294678340455, 6.067597387317154, 6.125660979192359, 6.183489646424868, 6.241087453150572, 6.298458340743998, 6.355606133069829, 6.412534541445444, 6.469247169333808, 6.525747516784573, 6.582038984639832, 6.638124878519678, 6.694008412601667, 6.749692713207102, 6.8051808222062125, 6.860475700253346, 6.915580229862515, 6.970497218332914, 7.02522940053331, 7.0797794415535975, 7.134149939231276, 7.188343426560006, 7.242362373986987, 7.296209191605386, 7.3498862312476865, 7.403395788485405, 7.456740104540304, 7.509921368111848, 7.562941717125413, 7.6158032404054214], [0.0, 0.312699740378802, 0.5079822269253091, 0.6747026236713719, 0.8252195622529189, 0.9647316433873818, 1.0960576458098226, 1.2209451349078364, 1.340573133919954, 1.4557851242139779, 1.5672111783641802, 1.6753378495864393, 1.7805508987072047, 1.883162803257919, 1.983431223296755, 2.081571830356358, 2.177767481034543, 2.272174939841099, 2.364929911445127, 2.4561508775896423, 2.5459420704451703, 2.634395810125074, 2.721594366065776, 2.8076114564383183, 2.892513468618352, 2.9763604620376958, 3.0592069993503417, 3.1411028407604973, 3.2220935282611376, 3.3022208805363333, 3.381523414789174, 3.4600367083547807, 3.5377937103539807, 3.614825011631356, 3.691159079653036, 3.7668224638069283, 3.8418399755716885, 3.9162348472416717, 3.990028872269316, 4.06324252978045, 4.135895095406491, 4.208004740240825, 4.279588619449836, 4.350662951840093, 4.421243091493112, 4.4913435924203995, 4.5609782670584895, 4.63016023931172, 4.698901992755886, 4.767215414535632, 4.8351118354201414, 4.902602066423259, 4.9696964323441675, 5.036404802541696, 5.102736619218186, 5.168700923456776, 5.234306379228055, 5.299561295557809, 5.364473647026471, 5.429051092752332, 5.493300993994455, 5.557230430496903, 5.620846215683424, 5.684154910800654, 5.747162838098077, 5.809876093124378, 5.8723005562120525, 5.9344419032153555, 5.996305615560511, 6.0578969896616846, 6.119221145751354, 6.180283036169297, 6.241087453150572, 6.301639036149269, 6.361942278731688, 6.422001535069723, 6.481821026062641, 6.541404845113152, 6.600756963581488, 6.659881235939355, 6.718781404643847, 6.777461104749851, 6.835923868278018, 6.894173128354062, 6.952212223134006, 7.010044399528794, 7.067672816740817, 7.125100549623899, 7.182330591877464, 7.239365859084909, 7.296209191605386, 7.3528633573276405, 7.409331054293938, 7.465614913201522, 7.521717499788612, 7.577641317111394, 7.633388807718118, 7.688962355725952, 7.7443642888059046, 7.799596880080778, 7.854662349940813, 7.909562867781352], [0.0, 0.3241313193385525, 0.526552881733695, 0.6993681904144295, 0.8553876799929505, 1.0, 1.1361269771988889, 1.265580063924133, 1.3895813857757495, 1.509005259848636, 1.6245047927124712, 1.736584324842881, 1.8456437195895274, 1.9520068779393684, 2.05594087940611, 2.1576692799745936, 2.2573816210567426, 2.3552403981100904, 2.4513862768524373, 2.5459420704451703, 2.639015821545789, 2.7307032252773835, 2.821089558656611, 2.9102512348202723, 2.998257068112859, 3.0851693136000486, 3.1710445286202114, 3.2559342924954806, 3.3398858121287174, 3.4229424349983177, 3.5051440864071934, 3.586527644315514, 3.6671272623877256, 3.7469746497989043, 3.8260993147198707, 3.904528777122723, 3.982288755536365, 4.059403331574077, 4.135895095406491, 4.21178527482889, 4.287093850145173, 4.361839656741857, 4.436040476938512, 4.509713122463749, 4.582873508708775, 4.65553672174608, 4.72771707896292, 4.799428184043206, 4.870682976933382, 4.941493779344592, 5.011872336272724, 5.081829853957274, 5.151377034648192, 5.22052410850523, 5.289280862915798, 5.357656669484115, 5.425660508915486, 5.493300993994456, 5.560586390833664, 5.627524638551046, 5.694123367516262, 5.760389916292435, 5.826331347386322, 5.891954461908552, 5.9572658132354235, 6.022271719754775, 6.086978276770453, 6.151391367632811, 6.215516674156331, 6.279359686379827, 6.342925711719627, 6.406219883561593, 6.469247169333808, 6.532012378098068, 6.5945201676950616, 6.656775051475127, 6.718781404643848, 6.780543470249263, 6.842065364835345, 6.903351083784367, 6.964404506368995, 7.025229400533311, 7.085829427420467, 7.146208145663313, 7.206369015453129, 7.266315402400412, 7.326050581200683, 7.385577739117303, 7.4448999792924235, 7.504020323896423, 7.562941717125413, 7.621667028055745, 7.680199053363868, 7.73854051991923, 7.796694087257502, 7.854662349940813, 7.912447839811326, 7.9700530281440125, 8.027480327704152, 8.084732094714655, 8.141810630738089, 8.198718184477876], [0.0, 0.3353926232290463, 0.5448469238759938, 0.7236663598714064, 0.8851064391311988, 1.0347430291940765, 1.1755994699358876, 1.3095501490324901, 1.4378596524293015, 1.5614326736455721, 1.6809450101515975, 1.7969185247388724, 1.90976697322109, 2.0198255098866538, 2.127370493400611, 2.2326332467599124, 2.335809896619288, 2.4370685840206976, 2.5365548618350795, 2.634395810125074, 2.7307032252773835, 2.825576127153554, 2.9191027555521214, 3.0113621784337297, 3.10242560096165, 3.1923574411311235, 3.2812162212537794, 3.3690553126736456, 3.455923562404387, 3.541865823947107, 3.6269234097306824, 3.7111344789673297, 3.794534371923256, 3.8771558994463318, 3.9590295949106187, 4.040183934415409, 4.120645530029207, 4.200439300033486, 4.279588619449836, 4.358115453591451, 4.436040476938512, 4.51338317927592, 4.590161960734892, 4.666394217134416, 4.7420964168146025, 4.8172841699837985, 4.891972291458662, 4.966174857556292, 5.039905257796069, 5.113176241982708, 5.185999963168831, 5.258388016932639, 5.330351477352669, 5.401900930015406, 5.4730465023517505, 5.543797891563839, 5.614164390373884, 5.684154910800654, 5.7537780061465815, 5.823041891358609, 5.8919544619085515, 5.9605233113234455, 6.0287557474829265, 6.096658807788809, 6.1642392733015345, 6.231503681928875, 6.298458340743998, 6.365109337502667, 6.431462551422812, 6.497523663283828, 6.563298164897759, 6.628791367999845, 6.694008412601668, 6.758954274846398, 6.823633774402216, 6.888051581426927, 6.952212223134007, 7.016120089987837, 7.0797794415535975, 7.143194412025245, 7.20636901545313, 7.269307150691123, 7.332012606081581, 7.39448906389504, 7.456740104540304, 7.518769210559376, 7.580579770420617, 7.642175082122575, 7.703558356619959, 7.764732721082499, 7.8257012219965985, 7.886466828119015, 7.947032433291207, 8.007400859122326, 8.067574857548372, 8.127557113274419, 8.187350246106496, 8.246956813179157, 8.30637931108445, 8.365620177907612, 8.424681795174465, 8.483566489715196], [0.0, 0.34649412601246754, 0.5628813683539723, 0.7476197313887468, 0.914403480619582, 1.0689930449163332, 1.2145118367674295, 1.3528962861196663, 1.4854528367394761, 1.6131161275203558, 1.736584324842881, 1.8563965651677656, 1.9729802996347157, 2.08668177614603, 2.1977865008443005, 2.3065334535224724, 2.4131252526316147, 2.517735604685662, 2.6205148803586, 2.721594366065776, 2.821089558656611, 2.9191027555521214, 3.0157251172900046, 3.1110383289820414, 3.2051159526838826, 3.2980245386277494, 3.3898245462149976, 3.4805711133822506, 3.5703147039803373, 3.659101656162179, 3.746974649798904, 3.8339731071734446, 3.9201335383155516, 4.005489840112841, 4.09007355659469, 4.173914106419866, 4.257038982516893, 4.339473927962879, 4.421243091493112, 4.502369165473111, 4.582873508708775, 4.662776256097291, 4.7420964168146025, 4.820851962481666, 4.899059906540992, 4.9767363758991445, 5.053896675743523, 5.130555348317614, 5.206726226334165, 5.282422481616694, 5.357656669484115, 5.43244076932851, 5.506786221780642, 5.580703962810131, 5.654204455066048, 5.727297716728123, 5.799993348107867, 5.8723005562120525, 5.944228177457601, 6.015784698706369, 6.086978276770453, 6.157816756522791, 6.228307687733985, 6.298458340743998, 6.36827572106651, 6.437766583014177, 6.50693744242442, 6.575794588557844, 6.644344095234615, 6.712591831268042, 6.780543470249262, 6.848204499732064, 6.915580229862515, 6.982675801494232, 7.049496193826511, 7.1160462315994755, 7.182330591877465, 7.248353810449319, 7.3141202878719165, 7.379634295181118, 7.444899979292423, 7.509921368111849, 7.574702375375962, 7.639246805238527, 7.703558356619958, 7.767640627334466, 7.831497118008788, 7.895131235805292, 7.958546297961353, 8.021745535156086, 8.084732094714655, 8.14750904365973, 8.21007937161898, 8.27244599359688, 8.334611752618567, 8.396579422252909, 8.45835170902157, 8.519931254700309, 8.581320638518424, 8.642522379261822, 8.70353893728488, 8.764372716435915], [0.0, 0.35744521296443443, 0.5806714615928535, 0.7712485552873364, 0.9433035723489464, 1.1027790023311073, 1.2528969744368474, 1.3956551202643943, 1.5324011742636585, 1.6640993149682723, 1.7914697745895611, 1.9150687292140716, 2.0353371397476128, 2.1526321973974363, 2.267248431843209, 2.3794323759308607, 2.489393051949532, 2.5973096564777656, 2.7033373127154983, 2.8076114564383183, 2.9102512348202723, 3.0113621784337297, 3.1110383289820414, 3.209363953267973, 3.3064149383056893, 3.4022599376744087, 3.496961321619313, 3.5905759707338056, 3.683155943799127, 3.774749043504256, 3.865399298634905, 3.955147377431199, 4.044030943837141, 4.132084966065186, 4.219341985106512, 4.305832349408495, 4.391584420824779, 4.476624756052834, 4.5609782670584895, 4.644668363408652, 4.72771707896292, 4.810145184990045, 4.891972291458662, 4.973216937990076, 5.053896675743523, 5.134028141322975, 5.213627123642465, 5.292708624558966, 5.3712869139737025, 5.449375580011002, 5.52698757480571, 5.604135256363438, 5.6808304269007115, 5.75708436802289, 5.8329078730553015, 5.908311276806295, 5.983304483009108, 6.057896989661685, 6.13209791245948, 6.205916006495047, 6.279359686379828, 6.352437044927142, 6.425155870521143, 6.497523663283829, 6.569547650140972, 6.641234798878012, 6.712591831268043, 6.783625235346297, 6.854341276898481, 6.924746010224121, 6.994845288230499, 7.064644771907756, 7.134149939231276, 7.203366093533432, 7.272298371383125, 7.340951750008346, 7.409331054293938, 7.477440963384186, 7.545286016917345, 7.612870620917092, 7.680199053363868, 7.7472754694672865, 7.814103906659144, 7.88068828932502, 7.947032433291206, 8.013140050082285, 8.079014750963717, 8.144660050782614, 8.21007937161898, 8.275276046258849, 8.340253321499873, 8.40501436129921, 8.46956224977292, 8.533899994055377, 8.59803052702667, 8.66195670991544, 8.725681334784058, 8.789207126902674, 8.852536747018174, 8.91567279352371, 8.978617804534153, 9.041374259872418], [0.0, 0.3682543360555974, 0.5982309338594668, 0.7945710681246027, 0.9718290192035612, 1.1361269771988889, 1.2907845083190845, 1.4378596524293017, 1.5787408993932452, 1.7144215844490547, 1.8456437195895272, 1.9729802996347152, 2.096885620123363, 2.2177276737046947, 2.3358098966192884, 2.4513862768524377, 2.564672157515524, 2.6758521540815243, 2.785086080667198, 2.892513468618352, 2.998257068112859, 3.10242560096165, 3.2051159526838826, 3.3064149383056893, 3.4064007396602656, 3.505144086407194, 3.602709234864356, 3.699154785691093, 3.7945343719232554, 3.888897241800443, 3.982288755536365, 4.074750811176436, 4.166322211620203, 4.257038982516894, 4.346934648895426, 4.436040476938513, 4.524385686160655, 4.6119976363323545, 4.698901992755887, 4.7851228729021384, 4.870682976933382, 4.955603704240365, 5.039905257796069, 5.123606737858901, 5.206726226334165, 5.289280862915798, 5.371286913973702, 5.45275983502016, 5.533714327477408, 5.614164390373884, 5.694123367516262, 5.773603990615547, 5.8526184187866255, 5.93117827478997, 6.0092946783404555, 6.086978276770453, 6.164239273301535, 6.241087453150572, 6.317532207671129, 6.393582556709269, 6.469247169333808, 6.544534383084284, 6.61945222186515, 6.694008412601669, 6.768210400761441, 6.842065364835345, 6.915580229862516, 6.988761680076004, 7.061616170738523, 7.134149939231276, 7.20636901545313, 7.27827923158225, 7.3498862312476865, 7.421195478154283, 7.492212264200499, 7.562941717125414, 7.633388807718119, 7.703558356619959, 7.773455040747592, 7.843083399362605, 7.912447839811325, 7.981552642956672, 8.050401968322149, 8.118999858966536, 8.187350246106496, 8.255456953502907, 8.323323701625693, 8.390954111610744, 8.45835170902157, 8.52551992742747, 8.592462111809068, 8.659181521801411, 8.725681334784058, 8.791964648826951, 8.858034485500315, 8.923893792556175, 8.989545446488718, 9.054992254980107, 9.120236959238063, 9.185282236231, 9.250130700826244, 9.31478490783641], [0.0, 0.37892914162759955, 0.6155722066724582, 0.8176037681770134, 1.0000000000000002, 1.1690605597782768, 1.3282012399433345, 1.4795397379753743, 1.6245047927124712, 1.7641185337870104, 1.899144482330935, 2.030172242902999, 2.1576692799745936, 2.2820142534148444, 2.4035193953495493, 2.5224460562634894, 2.639015821545789, 2.7534186582269937, 2.865819013049896, 2.9763604620376958, 3.0851693136000486, 3.1923574411311235, 3.2980245386277494, 3.4022599376744087, 3.505144086407194, 3.606749764768035, 3.707143091710586, 3.806384366586054, 3.9045287771227226, 4.001626999147951, 4.09772570775871, 4.192868015523759, 4.287093850145174, 4.380440281568919, 4.472941806633693, 4.564630597853481, 4.6555367217460795, 4.745688331175792, 4.8351118354201414, 4.923832051057365, 5.011872336272724, 5.099254710773722, 5.185999963168831, 5.27212774738691, 5.357656669484115, 5.442604365992795, 5.52698757480571, 5.610822199453189, 5.694123367516262, 5.77690548382146, 5.85918227898025, 5.940966853765248, 6.022271719754775, 6.103108836625113, 6.183489646424869, 6.263425105126917, 6.342925711719628, 6.422001535069723, 6.5006622387634705, 6.5789171041105305, 6.656775051475127, 6.734244660081974, 6.811334186429175, 6.888051581426927, 6.964404506368995, 7.040400347833402, 7.116046231599476, 7.191349035660073, 7.266315402400413, 7.340951750008346, 7.415264283174971, 7.489259003139242, 7.562941717125413, 7.63631804721796, 7.709393438714724, 7.7821731679955795, 7.8546623499408135, 7.926865944930543, 7.998788765453967, 8.070435482354926, 8.14181063073809, 8.21291861555828, 8.283763716913557, 8.354350095061234, 8.424681795174465, 8.49476275185574, 8.564596793422439, 8.634187645978454, 8.70353893728488, 8.772654200441918, 8.841536877393116, 8.910190322262483, 8.978617804534155, 9.04682251208365, 9.114807554069236, 9.18257596369116, 9.250130700826244, 9.317474654544588, 9.38461064551492, 9.451541428304514, 9.518269693579395, 9.584798070210041], [0.0, 0.38947657621124787, 0.6327065647044161, 0.840361643760693, 1.0278348467429672, 1.2016011812929526, 1.3651715179009762, 1.5207224998320485, 1.6697226346508385, 1.8132225028114, 1.9520068779393682, 2.08668177614603, 2.2177276737046947, 2.345533770423913, 2.470420989362853, 2.5926579556569855, 2.7124724224907815, 2.8300596445979687, 2.9455886460712213, 3.0592069993503417, 3.1710445286202114, 3.2812162212537794, 3.3898245462149976, 3.496961321619313, 3.602709234864356, 3.707143091710586, 3.8103308515225995, 3.912334492074803, 4.013210737237439, 4.113011673391754, 4.21178527482889, 4.309575854149352, 4.406424450436682, 4.502369165473111, 4.5974454563115525, 4.691686390982991, 4.785122872902138, 4.877783838563958, 4.969696432344168, 5.060886161586657, 5.151377034648192, 5.241191684151461, 5.330351477352669, 5.41887661524477, 5.506786221780641, 5.594098424402809, 5.680830426900711, 5.766998575477007, 5.8526184187866255, 5.9377047626122375, 6.022271719754775, 6.106332755644852, 6.189900730118654, 6.272987935748222, 6.35560613306983, 6.437766583014177, 6.51948007680737, 6.600756963581488, 6.681607175907246, 6.7620402534381325, 6.842065364835345, 6.921691328125001, 7.000926629623564, 7.079779441553598, 7.158257638459806, 7.236368812524478, 7.3141202878719165, 7.391519133942856, 7.46857217801229, 7.545286016917344, 7.621667028055745, 7.697721379710011, 7.773455040747592, 7.848873789742827, 7.923983223562584, 7.998788765453967, 8.07329567266917, 8.14750904365973, 8.221433824869745, 8.295074817155278, 8.368436681854945, 8.441523946534806, 8.514341010428797, 8.586892149594357, 8.659181521801411, 8.731213171171511, 8.80299103258266, 8.874518935854285, 8.945800609725653, 9.016839685640266, 9.087639701347646, 9.158204104333329, 9.22853625508704, 9.298639430218325, 9.368516825428392, 9.43817155834616, 9.507606671236159, 9.576825133585318, 9.645829844575246, 9.714623635446175, 9.783209271758407, 9.851589455556626], [0.0, 0.3999029749234436, 0.6496442993831093, 0.8628583639627645, 1.0553502779061965, 1.233768386651178, 1.4017175476895527, 1.5614326736455721, 1.7144215844490545, 1.8617629848915933, 2.0042626572119717, 2.142542840745126, 2.27709687425085, 2.4083243765272573, 2.53655486183508, 2.662064146481063, 2.7850860806671975, 2.9058211461519643, 3.024442891851069, 3.1411028407604973, 3.2559342924954806, 3.3690553126736456, 3.4805711133822506, 3.5905759707338056, 3.699154785691093, 3.806384366586054, 3.912334492074803, 4.017068799094393, 4.120645530029207, 4.223118165627729, 4.32453596446652, 4.424944425407001, 4.524385686160655, 4.622898868505256, 4.720520378689112, 4.8172841699837985, 4.913221973097228, 5.008363499162566, 5.102736619218186, 5.1963675234468285, 5.289280862915797, 5.381499876129529, 5.4730465023517505, 5.563941483361745, 5.654204455066048, 5.743854030183975, 5.832907873055301, 5.92138276747518, 6.009294678340455, 6.096658807788809, 6.183489646424868, 6.269801020152656, 6.355606133069829, 6.440917606824076, 6.525747516784574, 6.610107425340339, 6.694008412601669, 6.777461104749851, 6.860475700253346, 6.943061994144878, 7.025229400533311, 7.106986973505831, 7.188343426560006, 7.269307150691123, 7.349886231247686, 7.430088463656863, 7.509921368111849, 7.589392203304316, 7.668507979277352, 7.7472754694672865, 7.8257012219965985, 7.903791570274484, 7.981552642956671, 8.058990373311579, 8.13611050803579, 8.21291861555828, 8.289420093869376, 8.365620177907612, 8.441523946534806, 8.517136329127299, 8.592462111809068, 8.667505943350404, 8.742272340753988, 8.81676569454853, 8.890990273808644, 8.964950230918161, 9.03864960609289, 9.112092331677609, 9.185282236231002, 9.25822304841134, 9.33091840067471, 9.403371832796815, 9.475586795228644, 9.547566652295515, 9.619314685248467, 9.690834095176227, 9.762128005785616, 9.833199466057573, 9.90405145278562, 9.974686873003098, 10.045108566305142, 10.115319307070942], [0.0, 0.41021413584829874, 0.6663948297239659, 0.8851064391311988, 1.082561594725394, 1.265580063924133, 1.4378596524293017, 1.6016928982022123, 1.7586264990378582, 1.9097669732210896, 2.0559408794061094, 2.1977865008443, 2.3358098966192884, 2.470420989362853, 2.601957789583022, 2.7307032252773835, 2.8568971762781548, 2.9807452935968684, 3.1024256009616495, 3.2220935282611376, 3.3398858121287174, 3.455923562404387, 3.5703147039803373, 3.683155943799127, 3.7945343719232554, 3.9045287771227226, 4.013210737237439, 4.120645530029207, 4.2268928996131665, 4.332007705693798, 4.436040476938512, 4.539037885358498, 4.641043155150588, 4.7420964168146025, 4.842235015303254, 4.941493779344592, 5.039905257796068, 5.137499927867358, 5.234306379228054, 5.330351477352669, 5.4256605089154855, 5.520257311606177, 5.614164390373883, 5.707403021807171, 5.799993348107866, 5.8919544619085515, 5.983304483009106, 6.074060627960686, 6.1642392733015345, 6.253856013143634, 6.3429257117196265, 6.431462551422812, 6.519480076807369, 6.6069912349595254, 6.694008412601668, 6.780543470249262, 6.866607773703904, 6.952212223134006, 7.037367279966932, 7.122082991792065, 7.206369015453129, 7.290234638489309, 7.3736887990683595, 7.456740104540305, 7.539396848727538, 7.621667028055745, 7.703558356619958, 7.785078280271091, 7.866233989800283, 7.947032433291205, 8.02748032770415, 8.10758416974993, 8.187350246106496, 8.26678464302658, 8.3458932553805, 8.424681795174465, 8.503155799581437, 8.581320638518424, 8.659181521801411, 8.736743505906551, 8.814011500363991, 8.890990273808644, 8.967684459710297, 9.044098561803734, 9.120236959238062, 9.196103911462824, 9.27170356286739, 9.347039947188728, 9.42211699170168, 9.496938521204827, 9.57150826181407, 9.645829844575246, 9.719906808906309, 9.79374260587887, 9.867340601348257, 9.940704078940573, 10.013836242904784, 10.086740220837228, 10.159419066285539, 10.231875761238461, 10.304113218507696, 10.37613428400746], [0.0, 0.4204153830445961, 0.6829668046859956, 0.9071173568240765, 1.1094828474759222, 1.297052638734598, 1.473616493713381, 1.6415239614426977, 1.802360203156915, 1.957259254151061, 2.1070682280247115, 2.2524412809225987, 2.3938970566575346, 2.5318556718593417, 2.666663542716024, 2.798610633107626, 2.9279427882226314, 3.0548707732230174, 3.179577038949235, 3.3022208805363333, 3.4229424349983177, 3.541865823947107, 3.659101656162179, 3.774749043504256, 3.888897241800443, 4.001626999147951, 4.113011673391754, 4.223118165627729, 4.332007705693798, 4.439736517551197, 4.546356386419421, 4.651915144954018, 4.756457092255581, 4.860023356793314, 4.962652212218044, 5.0643793533822, 5.16523813857156, 5.265259802906174, 5.36447364702647, 5.462907204500335, 5.560586390833664, 5.657535636514238, 5.753778006146581, 5.849335305427648, 5.9442281774576005, 6.0384761896665715, 6.132097912459479, 6.22511099053044, 6.317532207671129, 6.4093775457895035, 6.50066223876347, 6.591400821675537, 6.681607175907245, 6.771294570514292, 6.860475700253346, 6.9491627205883875, 7.037367279966932, 7.125100549623897, 7.212373251142497, 7.299195681976598, 7.385577739117301, 7.471528941067271, 7.557058448269533, 7.6421750821225745, 7.726887342700415, 7.811203425284674, 7.895131235805291, 7.978678405277363, 8.06185230331336, 8.144660050782612, 8.227108531683468, 8.309204404287613, 8.390954111610743, 8.472363891259155, 8.553439784697401, 8.634187645978452, 8.71461314997425, 8.794721800141453, 8.874518935854283, 8.954009739333857, 9.033199242201029, 9.112092331677607, 9.19069375645898, 9.269008132279277, 9.347039947188726, 9.424793566561306, 9.502273237849478, 9.579483095101603, 9.65642716325639, 9.733109362227907, 9.809533510793486, 9.885703330296185, 9.961622448172564, 10.037294401315844, 10.11272263928378, 10.187910527360028, 10.262861349477147, 10.337578311008864, 10.412064541438744, 10.486323096911935, 10.56035696267624, 10.63416905541836], [0.0, 0.4305116202499342, 0.6993681904144293, 0.928901697685371, 1.1361269771988887, 1.3282012399433343, 1.5090052598486363, 1.6809450101515975, 1.845643719589527, 2.0042626572119717, 2.157669279974593, 2.306533453522472, 2.4513862768524377, 2.5926579556569855, 2.7307032252773835, 2.865819013049896, 2.9982570681128586, 3.1282332171344542, 3.2559342924954806, 3.381523414789174, 3.5051440864071934, 3.6269234097306824, 3.746974649798904, 3.865399298634905, 3.982288755536365, 4.09772570775871, 4.21178527482889, 4.32453596446652, 4.436040476938512, 4.546356386419421, 4.6555367217460795, 4.763630464270911, 4.870682976933382, 4.9767363758991445, 5.081829853957273, 5.185999963168831, 5.289280862915797, 5.39170453842679, 5.493300993994455, 5.594098424402809, 5.694123367516261, 5.793400840518541, 5.8919544619085515, 5.989806561045076, 6.086978276770452, 6.183489646424868, 6.279359686379827, 6.374606465065171, 6.469247169333808, 6.563298164897759, 6.656775051475127, 6.749692713207103, 6.842065364835345, 6.933906594070715, 7.025229400533311, 7.116046231599475, 7.20636901545313, 7.296209191605386, 7.385577739117302, 7.4744852027351625, 7.562941717125412, 7.65095702937669, 7.738540519919229, 7.8257012219965985, 7.912447839811324, 7.998788765453966, 8.084732094714655, 8.170285641866622, 8.255456953502907, 8.340253321499873, 8.424681795174463, 8.508749192696149, 8.592462111809068, 8.675826939915062, 8.758849863563904, 8.841536877393116, 8.923893792556175, 9.005926244674749, 9.087639701347646, 9.169039469246556, 9.250130700826242, 9.330918400674708, 9.411407431526829, 9.491602519963166, 9.57150826181407, 9.651129127287573, 9.730469465838329, 9.809533510793488, 9.8883253837503, 9.966849098759209, 10.04510856630514, 10.123107597098867, 10.20084990568951, 10.278339113908455, 10.355578754154276, 10.43257227252761, 10.509323031824357, 10.585834314395003, 10.662109324877376, 10.738151192809672, 10.81396297513015, 10.889547658569475], [0.0, 0.4405073769187359, 0.7156063450296853, 0.9504692347797457, 1.1625059371961781, 1.3590398416841343, 1.544041827225452, 1.71997372971405, 1.8884964665318944, 2.0507982694452163, 2.207766736303074, 2.360087285905618, 2.508303348476268, 2.6528551183610602, 2.794105567260019, 2.932358516663391, 3.0678715609016294, 3.2008655377756146, 3.3315316176001954, 3.4600367083547807, 3.586527644315514, 3.7111344789673297, 3.8339731071734446, 3.955147377431199, 4.074750811176436, 4.192868015523759, 4.309575854149352, 4.424944425407001, 4.539037885358498, 4.651915144954018, 4.763630464270911, 4.874233961926327, 4.983772054110987, 5.092287834857167, 5.199821406944667, 5.306410171112011, 5.412089079864649, 5.51689086107448, 5.620846215683424, 5.723983993111023, 5.826331347386322, 5.927913876550032, 6.0287557474829265, 6.128879807993996, 6.228307687733985, 6.327059889276465, 6.425155870521143, 6.522614119416451, 6.61945222186515, 6.715686923563608, 6.811334186429174, 6.9064092401877994, 7.000926629623564, 7.094900257931153, 7.188343426560007, 7.281268871893636, 7.373688799068361, 7.465614913201522, 7.557058448269534, 7.648030193849978, 7.738540519919229, 7.828599399876953, 7.9182164319512145, 8.007400859122326, 8.096161587689775, 8.184507204594366, 8.27244599359688, 8.359985950404845, 8.447134796830516, 8.533899994055375, 8.620288755069666, 8.7063080563493, 8.791964648826951, 8.877265068209203, 8.962215644687126, 9.04682251208365, 9.13109161647748, 9.215028724339948, 9.298639430218325, 9.381929163996302, 9.46490319775999, 9.547566652295515, 9.62992450324229, 9.71198158692414, 9.79374260587887, 9.875212134105242, 9.956394622044934, 10.037294401315844, 10.11791568921179, 10.19826259298272, 10.278339113908453, 10.358149151178065, 10.437696505586269, 10.516984883057287, 10.59601789800606, 10.674799076545892, 10.753331859551153, 10.831619605582993, 10.909665593685553, 10.987473026059643, 11.065045030620494, 11.142384663445645], [0.0, 0.4504068478997878, 0.7316880830837222, 0.9718290192035612, 1.1886307977401076, 1.3895813857757497, 1.5787408993932455, 1.7586264990378586, 1.9309364276944525, 2.096885620123363, 2.2573816210567426, 2.4131252526316147, 2.5646721575155245, 2.712472422490782, 2.856897176278155, 2.9982570681128595, 3.1368154812127362, 3.2727982162408478, 3.406400739660265, 3.5377937103539807, 3.6671272623877256, 3.794534371923256, 3.9201335383155516, 4.044030943837141, 4.166322211620203, 4.287093850145174, 4.406424450436682, 4.524385686160655, 4.641043155150588, 4.756457092255581, 4.870682976933382, 4.983772054110987, 5.095771783084767, 5.206726226334165, 5.316676387864083, 5.425660508915486, 5.533714327477408, 5.640871306911401, 5.747162838098078, 5.852618418786626, 5.957265813235424, 6.06113119474697, 6.164239273301535, 6.2666134101642585, 6.368275721066511, 6.4692471693338085, 6.569547650140973, 6.6691960669139485, 6.768210400761442, 6.866607773703905, 6.964404506368996, 7.061616170738524, 7.158257638459807, 7.254343125172407, 7.349886231247687, 7.4448999792924235, 7.53939684872754, 7.633388807718118, 7.726887342700417, 7.819903485724938, 7.912447839811326, 8.004530602490297, 8.096161587689775, 8.187350246106497, 8.278105684190178, 8.368436681854947, 8.45835170902157, 8.547858941084185, 8.636966273386433, 8.725681334784058, 8.814011500363993, 8.90196390338368, 8.989545446488718, 9.076762812261864, 9.163622473151833, 9.250130700826244, 9.336293574989336, 9.422116991701682, 9.507606671236157, 9.592768165501603, 9.677606865063103, 9.762128005785616, 9.846336675125519, 9.930237818092778, 10.013836242904784, 10.097136626351238, 10.18014351888808, 10.262861349477149, 10.345294430187016, 10.427446960569382, 10.509323031824358, 10.590926630767042, 10.672261643606964, 10.753331859551153, 10.834140974240873, 10.914692593031361, 10.994990234123359, 11.075037331554567, 11.154837238058704, 11.234393227799268, 11.313708498984765, 11.392786176371605], [0.0, 0.46021392780284126, 0.7476197313887467, 0.992989454236636, 1.2145118367674295, 1.4198378877486741, 1.6131161275203563, 1.7969185247388728, 1.9729802996347154, 2.1425428407451266, 2.3065334535224724, 2.4656682196823727, 2.6205148803586003, 2.7715333224443164, 2.919102755552122, 3.063540592939329, 3.2051159526838826, 3.3440595519929768, 3.4805711133822506, 3.614825011631356, 3.7469746497989043, 3.8771558994463318, 4.005489840112841, 4.132084966065186, 4.257038982516894, 4.380440281568919, 4.502369165473111, 4.622898868505256, 4.7420964168146025, 4.860023356793314, 4.9767363758991445, 5.092287834857167, 5.206726226334165, 5.320096572218303, 5.43244076932851, 5.543797891563839, 5.654204455066048, 5.7636946518220675, 5.8723005562120525, 5.98005230826402, 6.086978276770453, 6.193105204926759, 6.298458340743998, 6.403061554151406, 6.50693744242442, 6.61010742534034, 6.712591831268043, 6.81440997523336, 6.915580229862516, 7.016120089987837, 7.1160462315994755, 7.215374565740847, 7.3141202878719165, 7.412297923161095, 7.50992136811185, 7.6070039288829205, 7.703558356619959, 7.799596880080779, 7.895131235805292, 7.990172696053937, 8.084732094714655, 8.178819851357412, 8.27244599359688, 8.365620177907614, 8.458351709021569, 8.550649558025192, 8.642522379261823, 8.733978526135196, 8.825026065900788, 8.91567279352371, 9.005926244674749, 9.095793707929648, 9.185282236231002, 9.274398657666953, 9.363149585616187, 9.451541428304514, 9.53958039781459, 9.627272518586777, 9.714623635446175, 9.801639421187915, 9.8883253837503, 9.974686873003098, 10.060729087176071, 10.146457078950966, 10.231875761238461, 10.316989912659857, 10.401804182751922, 10.486323096911939, 10.570551061098701, 10.654492366304217, 10.738151192809674, 10.821531614238383, 10.90463760141752, 10.987473026059645, 11.070041664274267, 11.152347199919, 11.23439322779927, 11.316183256724917, 11.397720712431497, 11.479008940373568, 11.560051208396867, 11.64085070929571], [0.0, 0.46993224090413643, 0.7634071775988811, 1.0139583598684752, 1.2401586188004832, 1.4498205291087471, 1.6471802152172146, 1.8348639579079686, 2.0146436199650632, 2.187786804261632, 2.3552403981100904, 2.517735604685662, 2.6758521540815248, 2.8300596445979687, 2.980745293596869, 3.1282332171344542, 3.2727982162408473, 3.4146758801662678, 3.554070148956122, 3.691159079653036, 3.8260993147198707, 3.9590295949106187, 4.09007355659469, 4.219341985106512, 4.346934648895426, 4.472941806633693, 4.5974454563115525, 4.720520378689112, 4.842235015303254, 4.962652212218044, 5.081829853957273, 5.199821406944667, 5.316676387864083, 5.43244076932851, 5.547157332889777, 5.660865977568395, 5.7736039906155465, 5.885406286048539, 5.996305615560511, 6.106332755644852, 6.215516674156331, 6.323884679024995, 6.431462551422813, 6.538274665339052, 6.644344095234616, 6.749692713207104, 6.85434127689848, 6.958309509208955, 7.061616170738523, 7.164279125756958, 7.266315402400413, 7.367741247704961, 7.468572178012291, 7.568823025218022, 7.6685079792773525, 7.767640627334467, 7.866233989800284, 7.964300553666648, 8.061852303313362, 8.158900749036588, 8.255456953502907, 8.35153155631179, 8.447134796830516, 8.5422765354489, 8.636966273386431, 8.731213171171511, 8.825026065900788, 8.918413487376382, 9.011383673209572, 9.103944582971337, 9.196103911462826, 9.287869101172245, 9.379247353978805, 9.470245642159027, 9.560870718745957, 9.651129127287577, 9.741027211046754, 9.830571121681647, 9.919766827442212, 10.008620120915694, 10.097136626351238, 10.185321806591531, 10.273180969637071, 10.360719274866822, 10.447941738937137, 10.534853241379203, 10.621458529913816, 10.707762225500831, 10.793768827139441, 10.879482716434303, 10.964908161941382, 11.050049323306473, 11.134910255208501, 11.219494911118776, 11.303807146886712, 11.387850724161744, 11.471629313660618, 11.555146498288524, 11.638405776122092, 11.72141056326167, 11.804164196559919, 11.88666993623322], [0.0, 0.47956516728377424, 0.779055912670449, 1.0347430291940765, 1.265580063924133, 1.479539737975374, 1.680945010151598, 1.872475996165169, 2.0559408794061094, 2.2326332467599124, 2.403519395349549, 2.5693455169501775, 2.730703225277384, 2.888071744712541, 3.0418462300093756, 3.192357441131124, 3.339885812128718, 3.4846717614888187, 3.626923409730683, 3.7668224638069283, 3.904528777122723, 4.040183934415409, 4.173914106419866, 4.305832349408495, 4.436040476938513, 4.564630597853481, 4.691686390982991, 4.8172841699837985, 4.941493779344592, 5.0643793533822, 5.185999963168831, 5.306410171112011, 5.425660508915486, 5.543797891563839, 5.660865977568395, 5.77690548382146, 5.8919544619085515, 6.00604854153347, 6.119221145751355, 6.231503681928875, 6.342925711719627, 6.453515102826443, 6.56329816489776, 6.672299771554121, 6.780543470249263, 6.888051581426927, 6.994845288230499, 7.100944717850911, 7.20636901545313, 7.311136411498438, 7.415264283174971, 7.518769210559378, 7.621667028055746, 7.7239728715919505, 7.825701221996599, 7.926865944930542, 8.027480327704152, 8.127557113274419, 8.22710853168347, 8.326146329171776, 8.424681795174465, 8.522725787387296, 8.620288755069666, 8.717380760735015, 8.814011500363991, 8.910190322262483, 9.00592624467475, 9.101227972251426, 9.196103911462826, 9.290562185039537, 9.38461064551492, 9.47825688793735, 9.571508261814072, 9.664371882343117, 9.75685464098487, 9.848963215420516, 9.940704078940575, 10.032083509303227, 10.123107597098867, 10.213782253654337, 10.304113218507696, 10.394106066481948, 10.483766214383872, 10.57309892735218, 10.662109324877376, 10.75080238651393, 10.839182957303994, 10.92725575293037, 11.01502536461518, 11.102496263779596, 11.189672806478757, 11.276559237625145, 11.363159695012692, 11.449478213153112, 11.535518726935113, 11.621285075116466, 11.706781003658262, 11.792010168910029, 11.87697614065387, 11.961682405015218, 12.046132367247347, 12.13032935439633], [0.0, 0.48911586576355365, 0.7945710681246024, 1.0553502779061965, 1.2907845083190843, 1.5090052598486363, 1.714421584449055, 1.9097669732210898, 2.0968856201233628, 2.2770968742508497, 2.4513862768524373, 2.6205148803586, 2.785086080667198, 2.9455886460712213, 3.10242560096165, 3.255934292495481, 3.406400739660265, 3.5540701489561224, 3.6991547856910927, 3.8418399755716885, 3.982288755536365, 4.120645530029207, 4.257038982516893, 4.391584420824779, 4.524385686160655, 4.6555367217460795, 4.785122872902138, 4.913221973097228, 5.039905257796068, 5.16523813857156, 5.289280862915797, 5.412089079864649, 5.533714327477408, 5.654204455066048, 5.7736039906155465, 5.8919544619085515, 6.009294678340455, 6.125660979192359, 6.241087453150572, 6.355606133069829, 6.469247169333808, 6.582038984639832, 6.694008412601668, 6.805180822206213, 6.915580229862515, 7.025229400533311, 7.134149939231276, 7.242362373986987, 7.349886231247686, 7.456740104540304, 7.562941717125413, 7.668507979277352, 7.773455040747592, 7.877798338901004, 7.981552642956672, 8.084732094714655, 8.187350246106496, 8.289420093869374, 8.390954111610743, 8.491964279501323, 8.592462111809068, 8.692458682464329, 8.79196464882695, 8.890990273808645, 8.989545446488716, 9.087639701347646, 9.185282236231, 9.282481929145407, 9.379247353978805, 9.475586795228642, 9.57150826181407, 9.667019500041361, 9.762128005785616, 9.856841035946383, 9.951165619229757, 10.045108566305142, 10.138676479380774, 10.231875761238463, 10.324712623764713, 10.417193096012392, 10.509323031824357, 10.601108117048046, 10.692553876367734, 10.783665679779107, 10.874448748729009, 10.96490816194138, 11.055048860948986, 11.144875655349008, 11.23439322779927, 11.323606138770769, 11.412518831070923, 11.501135634151042, 11.589460768210593, 11.677498348109918, 11.765252387102331, 11.852726800395734, 11.939925408553268, 12.026851940741865, 12.113510037837019, 12.199903255391495, 12.28603506647532, 12.371908864393776], [0.0, 0.49858729411470915, 0.8099574488748873, 1.0757864878969652, 1.3157797575904209, 1.5382262199535828, 1.747620305523937, 1.9467484377786326, 2.137490522359692, 2.3211914567470413, 2.4988558665905827, 2.671259541633709, 2.8390175621652687, 3.002628161176069, 3.1625021673769043, 3.318983460445287, 3.472363597950803, 3.6228925346668555, 3.770786646288811, 3.9162348472416717, 4.059403331574077, 4.200439300033486, 4.339473927962879, 4.476624756052834, 4.6119976363323545, 4.745688331175792, 4.877783838563958, 5.008363499162566, 5.137499927867358, 5.265259802906174, 5.39170453842679, 5.51689086107448, 5.640871306911401, 5.7636946518220675, 5.885406286048539, 6.00604854153347, 6.125660979192359, 6.244280641994172, 6.361942278731688, 6.478678542556205, 6.594520167695061, 6.709496127233659, 6.823633774402215, 6.93695896944248, 7.04949619382651, 7.161268653346566, 7.272298371383124, 7.382606273479468, 7.492212264200498, 7.601135297125374, 7.709393438714723, 7.817003926699963, 7.923983223562584, 8.030347065602546, 8.136110508035792, 8.24128796650965, 8.3458932553805, 8.449939623059349, 8.553439784697401, 8.656405952454026, 8.758849863563903, 8.860782806397246, 8.962215644687126, 9.063158840080236, 9.16362247315183, 9.263616263011748, 9.363149585616187, 9.462231490888916, 9.560870718745957, 9.659075714108955, 9.75685464098487, 9.854215395682429, 9.951165619229757, 10.047712709051803, 10.143863829961239, 10.2396259245119, 10.335005722759728, 10.430009751472472, 10.524644342826003, 10.618915642622094, 10.712829618059676, 10.806392065089128, 10.899608615376843, 10.992484742905178, 11.085025770231088, 11.17723687442488, 11.269123092709071, 11.360689327815734, 11.45194035307949, 11.542880817282054, 11.63351524926308, 11.723848062311044, 11.813883558346985, 11.903625931912988, 11.993079273976555, 12.08224757556118, 12.171134731212865, 12.25974454231157, 12.348080720236103, 12.436146889390333, 12.523946590098145, 12.611483281374102], [0.0, 0.5079822269253093, 0.8252195622529188, 1.0960576458098223, 1.3405731339199543, 1.5672111783641804, 1.780550898707205, 1.983431223296755, 2.177767481034543, 2.364929911445127, 2.5459420704451703, 2.7215943660657755, 2.892513468618352, 3.059206999350342, 3.222093528261138, 3.381523414789175, 3.5377937103539807, 3.691159079653036, 3.841839975571689, 3.990028872269316, 4.135895095406491, 4.279588619449836, 4.421243091493112, 4.5609782670584895, 4.698901992755887, 4.8351118354201414, 4.969696432344168, 5.102736619218186, 5.234306379228054, 5.36447364702647, 5.493300993994455, 5.620846215683424, 5.747162838098078, 5.8723005562120525, 5.996305615560511, 6.119221145751355, 6.241087453150572, 6.361942278731688, 6.48182102606264, 6.600756963581488, 6.718781404643848, 6.835923868278018, 6.952212223134006, 7.067672816740818, 7.182330591877464, 7.296209191605387, 7.409331054293937, 7.521717499788612, 7.633388807718118, 7.7443642888059046, 7.854662349940813, 7.964300553666648, 8.07329567266917, 8.181663739769093, 8.289420093869376, 8.396579422252909, 8.503155799581437, 8.609162723907174, 8.714613149974252, 8.819519520057042, 8.923893792556175, 9.027747468549808, 9.131091616477478, 9.233936895115791, 9.336293574989334, 9.438171558346157, 9.53958039781459, 9.640529313847063, 9.741027211046754, 9.841082693463859, 9.940704078940573, 10.039899412576606, 10.138676479380774, 10.237042816168486, 10.335005722759728, 10.432572272527612, 10.529749322343227, 10.626543521958896, 10.722961322868345, 10.819008986679338, 10.91469259303136, 11.010018047088494, 11.104991086635215, 11.199617288800704, 11.293902076435415, 11.387850724161742, 11.48146836411911, 11.574759991422287, 11.66773046935034, 11.76038453428247, 11.852726800395734, 11.944761764138663, 12.03649380849385, 12.127927207041573, 12.219066127835866, 12.309914637103502, 12.40047670277582, 12.49075619786258, 12.5807569036765, 12.670482512916461, 12.759936632617052, 12.849122786971405], [0.0, 0.517303271452664, 0.8403616437606929, 1.1161693772437709, 1.365171517900976, 1.5959681789106748, 1.8132225028114004, 2.0198255098866538, 2.2177276737046947, 2.4083243765272573, 2.5926579556569855, 2.771533322444316, 2.9455886460712217, 3.1153408622060055, 3.28121622125378, 3.4435715114525585, 3.602709234864356, 3.7588887290686133, 3.912334492074803, 4.06324252978045, 4.21178527482889, 4.358115453591451, 4.502369165473111, 4.644668363408652, 4.7851228729021384, 4.923832051057365, 5.060886161586657, 5.1963675234468285, 5.330351477352669, 5.462907204500335, 5.594098424402809, 5.723983993111023, 5.852618418786626, 5.98005230826402, 6.106332755644852, 6.231503681928875, 6.355606133069829, 6.478678542556205, 6.600756963581488, 6.72187527503146, 6.842065364835345, 6.961357293670663, 7.079779441553598, 7.197358639468041, 7.3141202878719165, 7.430088463656864, 7.545286016917345, 7.659734658700002, 7.773455040747592, 7.886466828119016, 7.998788765453967, 8.11043873755409, 8.221433824869747, 8.331790354410364, 8.441523946534808, 8.550649558025192, 8.659181521801413, 8.76713358359353, 8.874518935854283, 8.981350249163265, 9.087639701347646, 9.19339900452065, 9.298639430218325, 9.403371832796816, 9.507606671236157, 9.611354029482284, 9.714623635446177, 9.817424878767781, 9.919766827442212, 10.021658243396718, 10.123107597098867, 10.22412308126915, 10.324712623764713, 10.424883899695159, 10.524644342826003, 10.624001156320771, 10.722961322868347, 10.821531614238383, 10.919718600304066, 11.017528657568368, 11.114967977227021, 11.212042572798879, 11.30875828735191, 11.405120800350907, 11.501135634151042, 11.59680816015957, 11.692143604686342, 11.78714705450226, 11.881823462123448, 11.976177650837665, 12.070214319488215, 12.163938047029662, 12.257353296868619, 12.35046442100196, 12.44327566396398, 12.53579116659328, 12.628014969629382, 12.719951017148507, 12.81160315984726, 12.90297515818243, 12.99407068537464, 13.084893330282988], [0.0, 0.526552881733695, 0.8553876799929504, 1.1361269771988889, 1.3895813857757495, 1.6245047927124712, 1.8456437195895274, 2.05594087940611, 2.257381621056742, 2.4513862768524373, 2.639015821545789, 2.821089558656611, 2.9982570681128595, 3.171044528620212, 3.339885812128718, 3.505144086407194, 3.6671272623877256, 3.8260993147198707, 3.982288755536365, 4.135895095406491, 4.287093850145173, 4.436040476938512, 4.582873508708775, 4.72771707896292, 4.870682976933382, 5.011872336272724, 5.151377034648192, 5.289280862915797, 5.4256605089154855, 5.560586390833664, 5.694123367516261, 5.826331347386322, 5.957265813235424, 6.086978276770453, 6.215516674156331, 6.342925711719627, 6.469247169333808, 6.594520167695061, 6.718781404643848, 6.842065364835345, 6.964404506368995, 7.0858294274204665, 7.20636901545313, 7.326050581200683, 7.444899979292423, 7.562941717125413, 7.680199053363867, 7.796694087257501, 7.912447839811325, 8.027480327704152, 8.14181063073809, 8.255456953502907, 8.368436681854945, 8.480766434737747, 8.592462111809068, 8.70353893728488, 8.814011500363993, 8.923893792556175, 9.033199242201029, 9.141940746433692, 9.250130700826244, 9.35778102690965, 9.46490319775999, 9.571508261814072, 9.677606865063103, 9.783209271758407, 9.8883253837503, 9.992964758569624, 10.097136626351238, 10.200849905689509, 10.304113218507696, 10.406934904015737, 10.509323031824357, 10.611285414277498, 10.712829618059676, 10.813962975130151, 10.91469259303136, 11.015025364615179, 11.11496797722702, 11.214526921384536, 11.313708498984763, 11.412518831070924, 11.510963865187614, 11.609049382350953, 11.70678100365826, 11.804164196559917, 11.901204280814493, 11.997906434146595, 12.09427569762552, 12.19031698078153, 12.286035066475318, 12.381434615535174, 12.476520171175387, 12.571296163208448, 12.665766912062798, 12.759936632617052, 12.853809437860937, 12.947389342392492, 13.040680265760473, 13.133686035660293, 13.226410390991374, 13.3188569847832], [0.0, 0.5357333711833627, 0.8703014291033819, 1.1559354372595678, 1.413808842682957, 1.6528281570464152, 1.877822657894354, 2.091786364650409, 2.2967392409177356, 2.494126382608968, 2.685027262652022, 2.8702754691857515, 3.050531907613449, 3.226331930606453, 3.3981169747051863, 3.5662565395360724, 3.7310639044816645, 3.892807646609566, 4.051720262178887, 4.208004740240825, 4.361839656741857, 4.51338317927592, 4.662776256097291, 4.810145184990045, 4.955603704240365, 5.099254710773722, 5.241191684151461, 5.381499876129529, 5.520257311606177, 5.657535636514238, 5.793400840518541, 5.927913876550032, 6.06113119474697, 6.193105204926759, 6.323884679024995, 6.453515102826443, 6.582038984639832, 6.709496127233659, 6.835923868278018, 6.961357293670663, 7.0858294274204665, 7.209371401184612, 7.332012606081581, 7.4537808290097916, 7.574702375375962, 7.694802179865482, 7.814103906659143, 7.932630040308756, 8.050401968322147, 8.167440056370445, 8.283763716913557, 8.399391471939653, 8.514341010428797, 8.628629241077078, 8.74227234075399, 8.855285799110863, 8.967684459710297, 9.079482558005097, 9.190693756458982, 9.301331177069619, 9.411407431526829, 9.520934649214379, 9.62992450324229, 9.738388234677714, 9.846336675125517, 9.953780267795029, 10.060729087176071, 10.167192857435765, 10.273180969637071, 10.378702497870725, 10.483766214383872, 10.588380603781207, 10.692553876367734, 10.796293980696202, 10.899608615376843, 11.00250524020219, 11.104991086635215, 11.207073167705193, 11.30875828735191, 11.410053049255687, 11.510963865187614, 11.611496962911763, 11.711658393668625, 11.811454039266772, 11.910889618807785, 12.009970695067452, 12.10870268055474, 12.20709084326828, 12.30514031216879, 12.402856082384568, 12.500243020165845, 12.597305867602804, 12.694049247121024, 12.790477665767106, 12.886595519296499, 12.982407096074537, 13.07791658080124, 13.173128058069468, 13.268045515765605, 13.362672848321225, 13.457013859823746, 13.551072266993497], [0.0, 0.5448469238759938, 0.8851064391311987, 1.1755994699358876, 1.4378596524293015, 1.6809450101515977, 1.90976697322109, 2.127370493400611, 2.335809896619288, 2.5365548618350795, 2.7307032252773835, 2.9191027555521214, 3.1024256009616504, 3.2812162212537794, 3.4559235624043874, 3.626923409730683, 3.7945343719232554, 3.9590295949106187, 4.120645530029207, 4.279588619449836, 4.436040476938512, 4.590161960734892, 4.7420964168146025, 4.891972291458662, 5.039905257796069, 5.185999963168831, 5.330351477352669, 5.4730465023517505, 5.614164390373883, 5.753778006146581, 5.8919544619085515, 6.0287557474829265, 6.164239273301535, 6.298458340743998, 6.431462551422813, 6.56329816489776, 6.694008412601668, 6.823633774402215, 6.952212223134006, 7.079779441553598, 7.20636901545313, 7.332012606081581, 7.456740104540304, 7.580579770420618, 7.703558356619958, 7.825701221996599, 7.947032433291206, 8.06757485754837, 8.187350246106496, 8.30637931108445, 8.424681795174465, 8.5422765354489, 8.659181521801411, 8.775413950567982, 8.890990273808645, 9.005926244674749, 9.120236959238063, 9.233936895115791, 9.347039947188728, 9.459559460677553, 9.57150826181407, 9.682898686319346, 9.79374260587887, 9.904051452785621, 10.013836242904782, 10.123107597098867, 10.231875761238463, 10.340150624911985, 10.447941738937137, 10.55525833176727, 10.662109324877378, 10.768503347206806, 10.87444874872901, 10.979953613212418, 11.085025770231088, 11.189672806478757, 11.293902076435417, 11.397720712431495, 11.501135634151042, 11.604153557611953, 11.70678100365826, 11.809024305996767, 11.910889618807785, 12.012382923957446, 12.113510037837017, 12.214276617852668, 12.314688168587496, 12.414750047655946, 12.514467471269331, 12.613845519529866, 12.712889141469317, 12.81160315984726, 12.909992275723017, 13.008061072814177, 13.105814021653961, 13.20325548355863, 13.300389714415633, 13.397220868302307, 13.493753000944404, 13.58999007302307, 13.685935953338422, 13.78159442183725], [0.0, 0.5538956046752127, 0.8998060644572552, 1.1951235305206582, 1.461739264222558, 1.7088617224819098, 1.9414839032142586, 2.1627013279761593, 2.374602440425546, 2.578681327579202, 2.776054058254751, 2.9675824805860893, 3.1539499057456784, 3.3357098357320036, 3.513318672502897, 3.6871584423236854, 3.8575530452580304, 4.0247801635733875, 4.189080175530571, 4.350662951840093, 4.509713122463749, 4.666394217134416, 4.820851962481666, 4.973216937990076, 5.123606737858901, 5.27212774738691, 5.41887661524477, 5.563941483361745, 5.707403021807171, 5.849335305427648, 5.989806561045076, 6.128879807993996, 6.2666134101642585, 6.403061554151406, 6.538274665339052, 6.672299771554121, 6.805180822206213, 6.93695896944248, 7.067672816740818, 7.197358639468041, 7.326050581200683, 7.4537808290097916, 7.580579770420618, 7.706476134352672, 7.831497118008789, 7.955668501400789, 8.079014750963717, 8.201559113512298, 8.323323701625695, 8.44432957140444, 8.56459679342244, 8.684144517593417, 8.802991032582662, 8.921153820318583, 9.038649606092891, 9.155494404681315, 9.271703562867392, 9.387291798708953, 9.502273237849481, 9.616661447143727, 9.73046946583833, 9.843709834522913, 9.956394622044936, 10.068535450562022, 10.18014351888808, 10.291229624274235, 10.401804182751922, 10.511877248153356, 10.621458529913818, 10.730557409750496, 10.839182957303995, 10.947343944820922, 11.055048860948988, 11.16230592370982, 11.269123092709073, 11.375508080638388, 11.481468364119111, 11.587011193933622, 11.692143604686343, 11.796872423933111, 11.901204280814493, 12.005145614225906, 12.108702680554742, 12.211881561012463, 12.314688168587498, 12.417128254642797, 12.519207415180192, 12.620931096792042, 12.722304602319184, 12.823333096232899, 12.924021609757224, 13.024375045746918, 13.12439818333531, 13.224095682365228, 13.323472087615375, 13.422531832833661, 13.521279244588246, 13.619718545946338, 13.71785385999016, 13.815689213178862, 13.913228538564615, 14.010475678870618], [0.0, 0.5628813683539724, 0.9144034806195819, 1.2145118367674295, 1.4854528367394761, 1.7365843248428812, 1.9729802996347157, 2.1977865008443005, 2.4131252526316147, 2.6205148803586, 2.821089558656611, 3.0157251172900046, 3.205115952683883, 3.389824546214998, 3.570314703980338, 3.7469746497989043, 3.920133538315551, 4.09007355659469, 4.257038982516893, 4.421243091493112, 4.582873508708775, 4.7420964168146025, 4.899059906540992, 5.053896675743523, 5.206726226334165, 5.357656669484115, 5.506786221780641, 5.654204455066048, 5.799993348107866, 5.9442281774576005, 6.086978276770452, 6.228307687733985, 6.368275721066511, 6.50693744242442, 6.644344095234616, 6.780543470249263, 6.915580229862515, 7.04949619382651, 7.182330591877464, 7.3141202878719165, 7.444899979292423, 7.574702375375962, 7.703558356619958, 7.831497118008789, 7.958546297961352, 8.084732094714655, 8.21007937161898, 8.334611752618565, 8.45835170902157, 8.581320638518424, 8.70353893728488, 8.825026065900788, 8.945800609725653, 9.065880334294537, 9.185282236231002, 9.304022590116029, 9.422116991701682, 9.53958039781459, 9.65642716325639, 9.772671074974847, 9.8883253837503, 10.003402833616438, 10.117915689211788, 10.231875761238463, 10.345294430187014, 10.45818266847072, 10.5705510610987, 10.682409825004951, 10.79376882713944, 10.904637601417518, 11.015025364615179, 11.124941031289849, 11.234393227799268, 11.343390305484775, 11.45194035307949, 11.560051208396867, 11.66773046935034, 11.77498550435062, 11.881823462123446, 11.988251280987045, 12.094275697625518, 12.199903255391495, 12.305140312168788, 12.40999304782342, 12.51446747126933, 12.618569427172945, 12.722304602319182, 12.825678531659632, 12.928696604062312, 13.031364067780927, 13.133686035660293, 13.235667490093434, 13.337313287744825, 13.438628164053213, 13.53961673752655, 13.640283513840762, 13.740632889753261, 13.840669156841429, 13.940396505075624, 14.03981902623562, 14.138940717178896, 14.237765482968562], [0.0, 0.5718060678259764, 0.928901697685371, 1.2337683866511782, 1.5090052598486363, 1.7641185337870107, 2.004262657211972, 2.2326332467599124, 2.4513862768524373, 2.662064146481063, 2.865819013049896, 3.0635405929393285, 3.2559342924954815, 3.4435715114525585, 3.6269234097306833, 3.8063843665860544, 3.982288755536365, 4.154923237829908, 4.32453596446652, 4.4913435924203995, 4.65553672174608, 4.8172841699837985, 4.9767363758991445, 5.134028141322975, 5.289280862915798, 5.442604365992795, 5.594098424402809, 5.743854030183975, 5.8919544619085515, 6.0384761896665715, 6.183489646424868, 6.327059889276465, 6.4692471693338085, 6.61010742534034, 6.749692713207104, 6.888051581426927, 7.025229400533311, 7.161268653346566, 7.296209191605387, 7.430088463656864, 7.562941717125413, 7.694802179865482, 7.825701221996599, 7.955668501400789, 8.084732094714655, 8.21291861555828, 8.340253321499874, 8.466760211050357, 8.592462111809068, 8.717380760735015, 8.841536877393116, 8.964950230918163, 9.087639701347646, 9.209623335895985, 9.33091840067471, 9.451541428304514, 9.571508261814072, 9.690834095176227, 9.809533510793488, 9.927620514210947, 10.045108566305142, 10.16201061317129, 10.278339113908455, 10.39410606648195, 10.509323031824357, 10.624001156320771, 10.738151192809676, 10.851783520218467, 10.964908161941382, 11.077534803057643, 11.189672806478757, 11.30133122810587, 11.412518831070924, 11.523244099128968, 11.633515249263082, 11.743340243558253, 11.852726800395736, 11.961682405015218, 12.070214319488215, 12.178329592142646, 12.28603506647532, 12.393337389586222, 12.500243020165845, 12.606758236064355, 12.712889141469317, 12.818641673716586, 12.924021609757224, 13.0290345723016, 13.133686035660295, 13.237981331300086, 13.341925653131897, 13.445524062546502, 13.548781493212653, 13.65170275565128, 13.754292541598558, 13.85655542816962, 13.958495881834153, 14.060118262214138, 14.16142682571352, 14.262425728988802, 14.363119032269173, 14.46351070253401], [0.0, 0.5806714615928537, 0.9433035723489462, 1.2528969744368472, 1.5324011742636585, 1.7914697745895611, 2.0353371397476128, 2.2672484318432087, 2.489393051949532, 2.7033373127154983, 2.9102512348202723, 3.111038328982041, 3.3064149383056898, 3.496961321619313, 3.683155943799127, 3.8653992986349053, 4.04403094383714, 4.219341985106512, 4.391584420824779, 4.5609782670584895, 4.72771707896292, 4.891972291458662, 5.053896675743523, 5.213627123642465, 5.371286913973702, 5.52698757480571, 5.680830426900711, 5.832907873055301, 5.983304483009106, 6.132097912459479, 6.279359686379827, 6.425155870521143, 6.569547650140973, 6.712591831268043, 6.85434127689848, 6.994845288230499, 7.134149939231276, 7.272298371383124, 7.409331054293937, 7.545286016917345, 7.680199053363867, 7.814103906659143, 7.947032433291206, 8.079014750963717, 8.21007937161898, 8.340253321499874, 8.469562249772919, 8.598030527026669, 8.725681334784058, 8.852536747018174, 8.978617804534153, 9.103944582971339, 9.228536255087038, 9.352411147903233, 9.475586795228644, 9.598079986008965, 9.719906808906309, 9.841082693463859, 9.961622448172564, 10.081540295722244, 10.200849905689509, 10.319564424888389, 10.437696505586267, 10.555258331767272, 10.672261643606962, 10.788717760306174, 10.904637601417518, 11.020031706785323, 11.1349102552085, 11.249283081925647, 11.36315969501269, 11.476549290775251, 11.589460768210591, 11.701902742607569, 11.813883558346985, 11.92541130095956, 12.03649380849385, 12.147138682242167, 12.257353296868617, 12.36714480997978, 12.476520171175386, 12.585486130613367, 12.694049247121022, 12.80221589588154, 12.909992275723013, 13.017384416034922, 13.124398183335309, 13.231039287510153, 13.337313287744825, 13.44322559816621, 13.54878149321265, 13.653986112747715, 13.758844466932729, 13.863361440871888, 13.96754179904296, 14.07139018952558, 14.174911148038454, 14.278109101796003, 14.380988373194292, 14.483553183335452, 14.585807655399257, 14.687755817869915], [0.0, 0.5894792204971879, 0.9576118189020932, 1.271901205250152, 1.5556449893645576, 1.818643202082801, 2.0662096037856403, 2.301638579947141, 2.527152740981865, 2.7443421577309124, 2.954394598017465, 3.1582272772190554, 3.356567404098309, 3.5500040389833036, 3.7390229042160565, 3.9240305683686856, 4.105371739641497, 4.283341939293705, 4.458196988076752, 4.63016023931172, 4.799428184043206, 4.966174857556292, 5.130555348317614, 5.292708624558966, 5.45275983502016, 5.610822199453189, 5.766998575477007, 5.92138276747518, 6.074060627960686, 6.22511099053044, 6.374606465065171, 6.522614119416451, 6.6691960669139485, 6.81440997523336, 6.958309509208955, 7.100944717850911, 7.242362373986987, 7.382606273479468, 7.521717499788612, 7.659734658700002, 7.796694087257501, 7.932630040308756, 8.06757485754837, 8.201559113512298, 8.334611752618565, 8.466760211050357, 8.598030527026669, 8.72844744079478, 8.858034485500314, 8.98681406993949, 9.114807554069234, 9.242035318040827, 9.368516825428392, 9.49427068124241, 9.619314685248467, 9.743665881050864, 9.867340601348259, 9.99035450972271, 10.11272263928378, 10.23445942845433, 10.355578754154275, 10.47609396261155, 10.596017898006059, 10.715362929131414, 10.83414097424087, 10.952363524227518, 11.070041664274266, 11.187186094096234, 11.30380714688671, 11.41991480706746, 11.535518726935111, 11.650628242286963, 11.765252387102331, 11.879399907348763, 11.993079273976555, 12.106298695159627, 12.219066127835866, 12.331389288595746, 12.443275663963977, 12.554732520115374, 12.665766912062796, 12.776385692352134, 12.886595519296497, 12.996402864779322, 13.10581402165396, 13.21483511076506, 13.323472087615372, 13.431730748699744, 13.53961673752655, 13.647135550345407, 13.754292541598556, 13.861092929112203, 13.96754179904296, 14.07364411059341, 14.179404700510023, 14.284828287375577, 14.389919475707607, 14.49468275987355, 14.59912252783257, 14.70324306471345, 14.807048556237307, 14.91054309199333], [0.0, 0.5982309338594668, 0.9718290192035611, 1.2907845083190843, 1.5787408993932452, 1.8456437195895274, 2.096885620123363, 2.3358098966192884, 2.564672157515524, 2.785086080667198, 2.998257068112859, 3.205115952683882, 3.4064007396602656, 3.602709234864356, 3.794534371923256, 3.9822887555363655, 4.166322211620202, 4.346934648895426, 4.524385686160655, 4.698901992755886, 4.870682976933382, 5.039905257796069, 5.206726226334165, 5.3712869139737025, 5.533714327477408, 5.694123367516262, 5.8526184187866255, 6.009294678340455, 6.1642392733015345, 6.317532207671129, 6.469247169333808, 6.61945222186515, 6.768210400761442, 6.915580229862516, 7.061616170738523, 7.20636901545313, 7.349886231247686, 7.492212264200498, 7.633388807718118, 7.773455040747592, 7.912447839811325, 8.050401968322147, 8.187350246106496, 8.323323701625695, 8.45835170902157, 8.592462111809068, 8.725681334784058, 8.858034485500314, 8.989545446488718, 9.120236959238063, 9.250130700826244, 9.379247353978805, 9.507606671236157, 9.635227533828393, 9.762128005785618, 9.8883253837503, 10.013836242904786, 10.138676479380774, 10.262861349477149, 10.386405505977063, 10.509323031824358, 10.631627471391974, 10.753331859551153, 10.87444874872901, 10.994990234123357, 11.114967977227021, 11.23439322779927, 11.353276844408729, 11.471629313660618, 11.589460768210591, 11.70678100365826, 11.823599494405006, 11.939925408553268, 12.055767621917752, 12.171134731212865, 12.28603506647532, 12.400476702775821, 12.514467471269331, 12.628014969629382, 12.741126571908172, 12.853809437860937, 12.966070521770003, 13.07791658080124, 13.189354182923015, 13.300389714415632, 13.411029386996969, 13.521279244588245, 13.63114516974207, 13.740632889753263, 13.849747982471603, 13.958495881834152, 14.066881883133663, 14.174911148038454, 14.282588709378, 14.38991947570761, 14.496908235664579, 14.603559662127493, 14.70987831618949, 14.815868650955647, 14.921535015173985, 15.026881656709001, 15.131912725866043], [0.0, 0.6069281150667865, 0.9859576317579406, 1.3095501490324901, 1.6016928982022125, 1.8724759961651687, 2.1273704934006115, 2.3697682909231186, 2.601957789583022, 2.825576127153554, 3.041846230009375, 3.25171246358499, 3.4559235624043874, 3.6550860232907794, 3.849699946222648, 4.040183934415409, 4.2268928996131665, 4.41013111065964, 4.590161960734891, 4.767215414535632, 4.941493779344592, 5.113176241982708, 5.282422481616694, 5.449375580011002, 5.614164390373884, 5.77690548382146, 5.9377047626122375, 6.096658807788809, 6.253856013143634, 6.4093775457895035, 6.563298164897759, 6.715686923563608, 6.866607773703905, 7.016120089987837, 7.164279125756958, 7.311136411498438, 7.456740104540304, 7.601135297125374, 7.7443642888059046, 7.886466828119016, 8.027480327704152, 8.167440056370445, 8.30637931108445, 8.44432957140444, 8.581320638518424, 8.717380760735015, 8.852536747018174, 8.98681406993949, 9.120236959238063, 9.25282848702225, 9.38461064551492, 9.515604418130538, 9.645829844575246, 9.775306080577609, 9.904051452785621, 10.032083509303227, 10.15941906628554, 10.28607425096488, 10.412064541438745, 10.537404803514901, 10.662109324877378, 10.78619184680947, 10.909665593685551, 11.032543300422025, 11.154837238058702, 11.276559237625145, 11.397720712431497, 11.518332678910067, 11.638405776122092, 11.757950284033468, 11.87697614065387, 11.995492958125103, 12.113510037837019, 12.231036384642392, 12.348080720236105, 12.46465149575833, 12.5807569036765, 12.696404888996218, 12.811603159847259, 12.926359197487029, 13.040680265760473, 13.154573420052442, 13.268045515765605, 13.381103216354555, 13.493753000944404, 13.606001171560019, 13.717853859990159, 13.829317034308964, 13.940396505075624, 14.051097931231626, 14.161426825713518, 14.271388560797902, 14.380988373194294, 14.490231368900282, 14.599122527832572, 14.707666708246467, 14.815868650955647, 14.923732983363179, 15.031264223314126, 15.138466782779334, 15.245344971379463, 15.351902999757693], [0.0, 0.6155722066724582, 1.0, 1.3282012399433343, 1.6245047927124714, 1.899144482330935, 2.1576692799745936, 2.4035193953495493, 2.639015821545789, 2.865819013049896, 3.0851693136000486, 3.298024538627749, 3.5051440864071943, 3.707143091710586, 3.904528777122723, 4.09772570775871, 4.287093850145173, 4.472941806633693, 4.6555367217460795, 4.8351118354201414, 5.011872336272724, 5.185999963168831, 5.357656669484115, 5.52698757480571, 5.694123367516262, 5.85918227898025, 6.022271719754775, 6.183489646424868, 6.3429257117196265, 6.50066223876347, 6.656775051475127, 6.811334186429174, 6.964404506368996, 7.1160462315994755, 7.266315402400413, 7.415264283174971, 7.562941717125413, 7.709393438714723, 7.854662349940813, 7.998788765453967, 8.14181063073809, 8.283763716913557, 8.424681795174465, 8.56459679342244, 8.70353893728488, 8.841536877393116, 8.978617804534153, 9.114807554069234, 9.250130700826244, 9.38461064551492, 9.518269693579395, 9.651129127287577, 9.783209271758407, 9.91452955554333, 10.045108566305144, 10.17496410207429, 10.304113218507698, 10.43257227252761, 10.56035696267624, 10.687482366485607, 10.813962975130151, 10.939812725601533, 11.065045030620494, 11.18967280647876, 11.313708498984763, 11.43716410766991, 11.560051208396867, 11.682380974497995, 11.804164196559919, 11.925411300959558, 12.046132367247347, 12.166337144464723, 12.28603506647532, 12.405235266382315, 12.523946590098147, 12.642177609127213, 12.759936632617052, 12.877231718728938, 12.99407068537464, 13.110461120362359, 13.226410390991374, 13.341925653131899, 13.457013859823746, 13.571681769424863, 13.685935953338422, 13.799782803345028, 13.913228538564614, 14.026279212070806, 14.138940717178897, 14.251218793427087, 14.363119032269173, 14.474646882495684, 14.58580765539926, 14.696606529698968, 14.807048556237309, 14.917138662462628, 15.026881656709003, 15.13628223228466, 15.245344971379465, 15.354074348801158, 15.462474735549591, 15.570550402237458], [0.0, 0.6241645850582237, 1.013958359868475, 1.346740750828218, 1.6471802152172144, 1.925653424457539, 2.1877868042616324, 2.4370685840206976, 2.6758521540815243, 2.9058211461519643, 3.1282332171344542, 3.3440595519929763, 3.554070148956123, 3.7588887290686137, 3.9590295949106187, 4.154923237829908, 4.346934648895426, 4.535376738041433, 4.720520378689112, 4.902602066423259, 5.081829853957274, 5.258388016932639, 5.43244076932851, 5.604135256363438, 5.773603990615547, 5.940966853765248, 6.106332755644852, 6.269801020152656, 6.431462551422812, 6.591400821675537, 6.749692713207103, 6.9064092401877994, 7.061616170738524, 7.215374565740847, 7.367741247704961, 7.518769210559378, 7.668507979277352, 7.817003926699963, 7.964300553666648, 8.11043873755409, 8.255456953502907, 8.399391471939653, 8.5422765354489, 8.684144517593417, 8.825026065900788, 8.964950230918163, 9.103944582971339, 9.242035318040827, 9.379247353978805, 9.515604418130538, 9.651129127287577, 9.785843060783378, 9.919766827442213, 10.052920127006235, 10.185321806591531, 10.316989912659857, 10.44794173893714, 10.578193870661424, 10.707762225500831, 10.836662091444996, 10.964908161941382, 11.092514568519203, 11.219494911118776, 11.345862286322077, 11.471629313660618, 11.596808160159572, 11.72141056326167, 11.845447852260666, 11.96893096836207, 12.091870483477932, 12.21427661785267, 12.336159256608356, 12.457527965289886, 12.578392004483577, 12.698760343576296, 12.818641673716588, 12.938044420034059, 13.056976753168698, 13.175446600157501, 13.293461654722027, 13.411029386996969, 13.528157052736752, 13.644851702034224, 13.761120187582916, 13.87696917251202, 13.992405137820912, 14.107434389438236, 14.222063064928602, 14.336297139868314, 14.450142433910116, 14.56360461655533, 14.676689212650658, 14.78940160762568, 14.901747052485888, 15.013730668575253, 15.125357452121225, 15.236632278574334, 15.347559906753695, 15.458144982809026, 15.568392044009045, 15.678305522365596, 15.787889748102117], [0.0, 0.6327065647044162, 1.0278348467429672, 1.365171517900976, 1.6697226346508387, 1.9520068779393684, 2.217727673704695, 2.470420989362853, 2.7124724224907815, 2.9455886460712213, 3.1710445286202114, 3.3898245462149976, 3.6027092348643563, 3.8103308515226, 4.013210737237439, 4.211785274828891, 4.406424450436682, 4.5974454563115525, 4.785122872902138, 4.9696964323441675, 5.151377034648192, 5.330351477352669, 5.506786221780642, 5.6808304269007115, 5.8526184187866255, 6.022271719754775, 6.189900730118654, 6.355606133069829, 6.519480076807369, 6.681607175907245, 6.842065364835345, 7.000926629623564, 7.158257638459807, 7.3141202878719165, 7.468572178012291, 7.621667028055746, 7.773455040747592, 7.923983223562584, 8.07329567266917, 8.221433824869747, 8.368436681854945, 8.514341010428797, 8.659181521801411, 8.802991032582662, 8.945800609725653, 9.087639701347646, 9.228536255087038, 9.368516825428392, 9.507606671236157, 9.645829844575246, 9.783209271758407, 9.919766827442213, 10.05552340249218, 10.190498966250498, 10.324712623764714, 10.45818266847072, 10.590926630767042, 10.722961322868345, 10.85430288028336, 10.9849668002249, 11.11496797722702, 11.244320736215414, 11.373038863251846, 11.501135634151042, 11.62862384114861, 11.755515817781067, 11.881823462123448, 12.007558258516104, 12.132731297899985, 12.257353296868617, 12.381434615535174, 12.504985274304168, 12.628014969629382, 12.750533088832519, 12.872548724050635, 12.99407068537464, 13.115107513235921, 13.235667490093434, 13.355758651469326, 13.475388796377276, 13.594565497184208, 13.713296108942886, 13.831587778229927, 13.949447451521126, 14.06688188313366, 14.183897642762371, 14.300501122635438, 14.416698544312863, 14.53249596514947, 14.647899284442623, 14.76291424928338, 14.877546460128519, 14.991801376109695, 15.10568432009483, 15.219200483515849, 15.332354930975868, 15.445152604648204, 15.557598328478601, 15.669696812201478, 15.781452655180162, 15.892870350080617, 16.003954286387383], [0.0, 0.6411994021079274, 1.0416315018086988, 1.3834962522663514, 1.6921353669285206, 1.9782087192820759, 2.24749629250643, 2.5035815174042866, 2.7488820134936574, 2.9851273624750863, 3.2136095454593314, 3.4353262531727635, 3.6510684987802056, 3.861477026038241, 4.067080173969624, 4.268320182972819, 4.465572005521555, 4.659157091546768, 4.849353707197916, 5.036404802541696, 5.22052410850523, 5.401900930015406, 5.580703962810131, 5.75708436802289, 5.93117827478997, 6.103108836625113, 6.272987935748222, 6.440917606824076, 6.6069912349595254, 6.771294570514292, 6.933906594070715, 7.094900257931153, 7.254343125172407, 7.412297923161095, 7.568823025218022, 7.7239728715919505, 7.877798338901004, 8.030347065602546, 8.181663739769093, 8.331790354410364, 8.480766434737747, 8.628629241077078, 8.775413950567982, 8.921153820318583, 9.065880334294537, 9.209623335895985, 9.352411147903233, 9.49427068124241, 9.635227533828393, 9.775306080577609, 9.91452955554333, 10.052920127006235, 10.190498966250498, 10.327286310667331, 10.463301521751852, 10.598563138493242, 10.733088926601038, 10.866895923960726, 11.000000482668403, 11.13241830795639, 11.264164494288485, 11.395253558874241, 11.525699472826107, 11.655515690160428, 11.78471517482334, 11.913310425904756, 12.041313501187894, 12.168736039167719, 12.295589279659183, 12.421884083104935, 12.547630948682231, 12.672840031299748, 12.797521157567024, 12.921683840812046, 13.045337295215866, 13.168490449127486, 13.291151957616732, 13.413330214318236, 13.535033362615176, 13.656269306207601, 13.777045719106527, 13.897370055091784, 14.017249556668686, 14.13669126355576, 14.255702020733567, 14.37428848608214, 14.492457137632707, 14.610214280457447, 14.727566053219217, 14.84451843440181, 14.961077248239643, 15.07724817036458, 15.193036733186347, 15.308448331021868, 15.423488224987794, 15.538161547669555, 15.652473307579388, 15.766428393414996, 15.880031578129687, 15.99328752282417, 16.106200780469585, 16.218775799470645], [0.0, 0.6496442993831094, 1.0553502779061965, 1.4017175476895527, 1.714421584449055, 2.004262657211972, 2.2770968742508506, 2.53655486183508, 2.785086080667198, 3.0244428918510695, 3.255934292495481, 3.4805711133822506, 3.699154785691094, 3.912334492074804, 4.120645530029208, 4.324535964466521, 4.524385686160655, 4.720520378689113, 4.913221973097229, 5.102736619218186, 5.289280862915798, 5.4730465023517505, 5.654204455066048, 5.8329078730553015, 6.0092946783404555, 6.183489646424869, 6.35560613306983, 6.525747516784574, 6.694008412601668, 6.860475700253346, 7.025229400533311, 7.188343426560007, 7.349886231247687, 7.50992136811185, 7.6685079792773525, 7.825701221996599, 7.981552642956672, 8.136110508035792, 8.289420093869376, 8.441523946534808, 8.592462111809068, 8.74227234075399, 8.890990273808645, 9.038649606092891, 9.185282236231002, 9.33091840067471, 9.475586795228644, 9.619314685248467, 9.762128005785618, 9.904051452785621, 10.045108566305144, 10.185321806591531, 10.324712623764714, 10.463301521751852, 10.60110811704805, 10.738151192809674, 10.874448748729012, 11.010018047088494, 11.144875655349008, 11.279037485588162, 11.412518831070924, 11.545334400205324, 11.677498348109918, 11.809024305996768, 11.939925408553268, 12.070214319488215, 12.199903255391499, 12.329004008042522, 12.457527965289886, 12.585486130613367, 12.712889141469317, 12.839747286511328, 12.966070521770005, 13.091868485868327, 13.21715051434244, 13.3419256531319, 13.466202671297864, 13.589990073023074, 13.713296108942888, 13.8361287868528, 13.958495881834153, 14.08040494583656, 14.201863316752531, 14.32287812701699, 14.44345631176211, 14.56360461655533, 14.683329604746591, 14.802637664448833, 14.921535015173987, 15.040027714145287, 15.158121662305053, 15.275822610035881, 15.393136162611937, 15.51006778539583, 15.626622808795592, 15.742806432995206, 15.858623732471374, 15.974079660308242, 16.089179052321153, 16.203926630999707, 16.318327009279805, 16.432384694153743], [0.0, 0.6580424075766573, 1.068993044916333, 1.419837887748674, 1.736584324842881, 2.030172242902999, 2.306533453522473, 2.569345516950178, 2.821089558656611, 3.0635405929393285, 3.298024538627749, 3.5255652937564617, 3.7469746497989047, 3.962910181548248, 4.173914106419866, 4.380440281568919, 4.582873508708774, 4.781543681606915, 4.9767363758991445, 5.168700923456776, 5.357656669484115, 5.543797891563839, 5.727297716728123, 5.908311276806295, 6.086978276770453, 6.263425105126917, 6.437766583014177, 6.610107425340339, 6.780543470249262, 6.9491627205883875, 7.116046231599475, 7.281268871893636, 7.4448999792924235, 7.6070039288829205, 7.767640627334467, 7.926865944930542, 8.084732094714655, 8.24128796650965, 8.396579422252909, 8.550649558025192, 8.70353893728488, 8.855285799110863, 9.005926244674749, 9.155494404681315, 9.304022590116029, 9.451541428304514, 9.598079986008965, 9.743665881050864, 9.8883253837503, 10.032083509303227, 10.17496410207429, 10.316989912659857, 10.45818266847072, 10.598563138493242, 10.738151192809674, 10.876965857390775, 11.015025364615179, 11.152347199918998, 11.288948144934672, 11.424844317439065, 11.560051208396867, 11.69458371635523, 11.82845617941934, 11.961682405015218, 12.094275697625518, 12.226248884665852, 12.357614340652903, 12.48838400980125, 12.618569427172947, 12.748181738492406, 12.877231718728936, 13.005729789540029, 13.133686035660293, 13.261110220313508, 13.388011799718543, 13.514399936753986, 13.640283513840762, 13.765671145097231, 13.890571187816697, 14.014991753313357, 14.138940717178896, 14.262425728988802, 14.385454221494282, 14.50803341933297, 14.630170347289155, 14.751871838131851, 14.873144540057007, 14.993994923758235, 15.11442928914859, 15.23445377175449, 15.354074348801156, 15.473296845007766, 15.592126938109212, 15.710570164120162, 15.828631922356113, 15.94631748022508, 16.063631977802746, 16.18058043220297, 16.29716774175484, 16.41339868999671, 16.52927794949703, 16.644810085511054], [0.0, 0.6663948297239661, 1.082561594725394, 1.4378596524293017, 1.7586264990378586, 2.05594087940611, 2.335809896619289, 2.6019577895830226, 2.8568971762781548, 3.10242560096165, 3.339885812128718, 3.570314703980338, 3.7945343719232563, 4.01321073723744, 4.226892899613167, 4.436040476938513, 4.641043155150588, 4.842235015303255, 5.039905257796069, 5.234306379228055, 5.425660508915486, 5.614164390373884, 5.799993348107867, 5.983304483009108, 6.164239273301535, 6.342925711719628, 6.51948007680737, 6.694008412601669, 6.866607773703904, 7.037367279966932, 7.20636901545313, 7.373688799068361, 7.53939684872754, 7.703558356619959, 7.866233989800284, 8.027480327704152, 8.187350246106496, 8.3458932553805, 8.503155799581437, 8.659181521801413, 8.814011500363993, 8.967684459710297, 9.120236959238063, 9.271703562867392, 9.422116991701682, 9.571508261814072, 9.719906808906309, 9.867340601348259, 10.013836242904786, 10.15941906628554, 10.304113218507698, 10.44794173893714, 10.590926630767042, 10.733088926601038, 10.874448748729012, 11.015025364615179, 11.154837238058706, 11.293902076435417, 11.432236874384209, 11.569857954262188, 11.706781003658262, 11.843021110224354, 11.978592794056818, 12.11351003783702, 12.247786314919189, 12.381434615535175, 12.514467471269331, 12.646896977942152, 12.778734817028305, 12.909992275723015, 13.040680265760473, 13.170809341078527, 13.300389714415633, 13.429431272918537, 13.55794359283231, 13.685935953338424, 13.81341734960089, 13.940396505075626, 14.066881883133663, 14.19288169804475, 14.318403925364144, 14.44345631176211, 14.568046384332526, 14.692181459414137, 14.815868650955647, 14.939114878453262, 15.061926874487371, 15.184311191883014, 15.306274210516992, 15.427822143792932, 15.548961044803972, 15.66969681220148, 15.790035195786881, 15.909981801842555, 16.029542098216606, 16.148721419175374, 16.267524970036668, 16.38595783159573, 16.50402496435532, 16.621731212570445, 16.73908130811768, 16.856079874198308], [0.0, 0.6747026236713719, 1.0960576458098223, 1.4557851242139779, 1.7805508987072045, 2.081571830356358, 2.3649299114451274, 2.634395810125074, 2.8925134686183513, 3.1411028407604973, 3.3815234147891746, 3.6148250116313556, 3.8418399755716894, 4.063242529780451, 4.279588619449836, 4.4913435924203995, 4.698901992755886, 4.902602066423259, 5.102736619218185, 5.299561295557809, 5.493300993994456, 5.684154910800654, 5.8723005562120525, 6.057896989661685, 6.241087453150572, 6.422001535069723, 6.600756963581488, 6.777461104749851, 6.952212223134006, 7.125100549623897, 7.296209191605386, 7.465614913201522, 7.633388807718118, 7.799596880080779, 7.964300553666648, 8.127557113274419, 8.289420093869374, 8.449939623059349, 8.609162723907174, 8.76713358359353, 8.923893792556175, 9.079482558005097, 9.233936895115791, 9.387291798708953, 9.53958039781459, 9.690834095176227, 9.841082693463859, 9.99035450972271, 10.138676479380774, 10.28607425096488, 10.43257227252761, 10.578193870661424, 10.722961322868345, 10.866895923960726, 11.010018047088494, 11.152347199918998, 11.293902076435417, 11.43470060476744, 11.574759991422285, 11.714096762244203, 11.852726800395734, 11.990665381623153, 12.127927207041571, 12.264526433651294, 12.400476702775817, 12.535791166593278, 12.670482512916463, 12.804562988361731, 12.938044420034057, 13.070938235843585, 13.203255483558628, 13.3350068486906, 13.466202671297863, 13.596852961787985, 13.726967415790925, 13.85655542816962, 13.985626106228757, 14.114188282177611, 14.242250524898152, 14.369821151065572, 14.496908235664577, 14.623519621941423, 14.749662930828565, 14.875345569875899, 15.000574741720117, 15.125357452121222, 15.249700517593165, 15.373610572653577, 15.497094076715742, 15.620157320644388, 15.742806432995202, 15.865047385956702, 15.986886001011795, 16.108327954335113, 16.229378781941193, 16.350043884597472, 16.47032853251527, 16.59023786983097, 16.70977691888879, 16.828950584335978, 16.94776365704034, 17.066220817839568], [0.0, 0.6829668046859958, 1.1094828474759222, 1.473616493713381, 1.8023602031569153, 2.107068228024712, 2.393897056657535, 2.6666635427160243, 2.927942788222632, 3.1795770389492355, 3.422942434998318, 3.6591016561621794, 3.8888972418004433, 4.113011673391755, 4.332007705693799, 4.546356386419422, 4.756457092255581, 4.962652212218045, 5.16523813857156, 5.364473647026471, 5.560586390833664, 5.7537780061465815, 5.944228177457601, 6.13209791245948, 6.317532207671129, 6.5006622387634705, 6.681607175907246, 6.860475700253346, 7.037367279966932, 7.212373251142497, 7.385577739117302, 7.557058448269534, 7.726887342700417, 7.895131235805292, 8.061852303313362, 8.22710853168347, 8.390954111610743, 8.553439784697401, 8.714613149974252, 8.874518935854283, 9.033199242201029, 9.190693756458982, 9.347039947188728, 9.502273237849481, 9.65642716325639, 9.809533510793488, 9.961622448172564, 10.11272263928378, 10.262861349477149, 10.412064541438745, 10.56035696267624, 10.707762225500831, 10.85430288028336, 11.000000482668403, 11.144875655349008, 11.288948144934672, 11.432236874384209, 11.574759991422285, 11.716534913312216, 11.857578368317158, 11.997906434146595, 12.137534573653719, 12.276477668022128, 12.414750047655946, 12.552365520966156, 12.689337401227025, 12.825678531659632, 12.961401308884575, 13.09651770487263, 13.231039287510152, 13.364977239885457, 13.4983423783928, 13.631145169742068, 13.763395746954581, 13.895103924418457, 14.026279212070806, 14.156930828768296, 14.287067714902644, 14.416698544312862, 14.545831735541999, 14.674475462482235, 14.802637664448831, 14.9303260557202, 15.057548134578559, 15.184311191883012, 15.310622319204505, 15.436488416549931, 15.56191619970065, 15.6869122071889, 15.81148280693386, 15.935634202557614, 16.05937243939979, 16.18270341024847, 16.305632860803644, 16.42816639488841, 16.550309479422207, 16.672067449169205, 16.793445511274392, 16.91444874959882, 17.03508212886492, 17.155350498622067, 17.27525859704178], [0.0, 0.6911883478725528, 1.1228387837859766, 1.4913558648809997, 1.8240569857037612, 2.132433080774315, 2.4227147501390367, 2.6987647946802933, 2.9631893154564235, 3.2178527351636728, 3.4641477598564947, 3.703149861849088, 3.9357117229760616, 4.1625240404168995, 4.384156343361825, 4.60108534998832, 4.813715244673347, 5.022392538106025, 5.22741719051632, 5.429051092752332, 5.627524638551046, 5.823041891358609, 6.015784698706369, 6.205916006495047, 6.393582556709269, 6.5789171041105305, 6.7620402534381325, 6.943061994144878, 7.122082991792065, 7.299195681976598, 7.4744852027351625, 7.648030193849978, 7.819903485724938, 7.990172696053937, 8.158900749036588, 8.326146329171776, 8.491964279501323, 8.656405952454026, 8.819519520057042, 8.981350249163265, 9.141940746433692, 9.301331177069619, 9.459559460677553, 9.616661447143727, 9.772671074974847, 9.927620514210947, 10.081540295722244, 10.23445942845433, 10.386405505977063, 10.537404803514901, 10.687482366485607, 10.836662091444996, 10.9849668002249, 11.13241830795639, 11.279037485588162, 11.424844317439065, 11.569857954262188, 11.714096762244203, 11.857578368317158, 12.000319702118771, 12.142337034901718, 12.283646015660775, 12.42426170471898, 12.564198604989624, 12.703470691109118, 12.842091436616705, 12.980073839339948, 13.117430445129761, 13.254173370075309, 13.390314321316971, 13.525864616564899, 13.660835202420921, 13.795236671593008, 13.929079279083624, 14.06237295742633, 14.195127331038703, 14.32735172975386, 14.4590552015878, 14.59024652479507, 14.720934219261002, 14.851126557274958, 14.98083157372554, 15.110057075755526, 15.238810651911322, 15.367099680819283, 15.494931339418565, 15.62231261077823, 15.74925029152411, 15.875750998899177, 16.00182117747952, 16.127467105566332, 16.25269490127293, 16.377510528324688, 16.501919801588233, 16.6259283923454, 16.749541833326308, 16.872765523514936, 16.995604732739796, 17.11806460606137, 17.24015016796735, 17.361866326385893, 17.483217876526556], [0.0, 0.6993681904144294, 1.1361269771988887, 1.5090052598486363, 1.8456437195895272, 2.1576692799745936, 2.4513862768524377, 2.730703225277384, 2.998257068112859, 3.2559342924954806, 3.5051440864071934, 3.746974649798904, 3.9822887555363655, 4.211785274828891, 4.436040476938513, 4.65553672174608, 4.870682976933382, 5.081829853957274, 5.289280862915797, 5.493300993994455, 5.694123367516262, 5.8919544619085515, 6.086978276770453, 6.279359686379828, 6.469247169333808, 6.656775051475127, 6.842065364835345, 7.025229400533311, 7.206369015453129, 7.385577739117301, 7.562941717125412, 7.738540519919229, 7.912447839811326, 8.084732094714655, 8.255456953502907, 8.424681795174465, 8.592462111809068, 8.758849863563903, 8.923893792556175, 9.087639701347646, 9.250130700826244, 9.411407431526829, 9.57150826181407, 9.73046946583833, 9.8883253837503, 10.045108566305142, 10.200849905689509, 10.355578754154275, 10.509323031824358, 10.662109324877378, 10.813962975130151, 10.964908161941382, 11.11496797722702, 11.264164494288485, 11.412518831070924, 11.560051208396867, 11.706781003658262, 11.852726800395734, 11.997906434146595, 12.142337034901718, 12.28603506647532, 12.429016363059604, 12.571296163208446, 12.712889141469317, 12.853809437860935, 12.99407068537464, 13.133686035660293, 13.272668183042216, 13.411029386996969, 13.54878149321265, 13.685935953338422, 13.822503843523265, 13.958495881834152, 14.09392244463599, 14.228793582008537, 14.363119032269173, 14.496908235664577, 14.630170347289157, 14.76291424928338, 14.895148562360843, 15.026881656709001, 15.158121662305051, 15.288876478685102, 15.419153784201933, 15.54896104480397, 15.678305522365592, 15.807194282596726, 15.935634202557614, 16.063631977802746, 16.19119412917631, 16.318327009279802, 16.445036808631137, 16.57132956153317, 16.697211151668338, 16.82268731743506, 16.94776365704034, 17.07244563336223, 17.196738578594818, 17.32064769868763, 17.444178077590454, 17.567334681314144, 17.690122361816982], [0.0, 0.707507233654516, 1.149348891950503, 1.5265666234161557, 1.8671227834723607, 2.182779606420972, 2.479914796134439, 2.7624823538265475, 3.033149910333499, 3.2938259071795826, 3.5459359320659103, 3.7905808490973727, 4.028633471838967, 4.2608008047595245, 4.487665823574855, 4.709716501729565, 4.9273665663521715, 5.140970709213517, 5.3508359725737344, 5.557230430496903, 5.760389916292435, 5.9605233113234455, 6.157816756522791, 6.352437044927142, 6.544534383084284, 6.734244660081974, 6.921691328125001, 7.106986973505831, 7.290234638489309, 7.471528941067271, 7.65095702937669, 7.828599399876953, 8.004530602490297, 8.178819851357412, 8.35153155631179, 8.522725787387296, 8.692458682464329, 8.860782806397246, 9.027747468549808, 9.19339900452065, 9.35778102690965, 9.520934649214379, 9.682898686319346, 9.843709834522913, 10.003402833616438, 10.16201061317129, 10.319564424888389, 10.47609396261155, 10.631627471391974, 10.78619184680947, 10.939812725601533, 11.092514568519203, 11.244320736215414, 11.395253558874241, 11.545334400205324, 11.69458371635523, 11.843021110224354, 11.990665381623153, 12.137534573653719, 12.283646015660775, 12.429016363059604, 12.573661634316135, 12.717597245326086, 12.860838041415038, 13.003398327159129, 13.145291894206476, 13.286532047262016, 13.427131628382911, 13.567103039717944, 13.706458264811877, 13.84520888858483, 13.983366116086778, 14.120940790118434, 14.257943407801818, 14.394384136176587, 14.530272826891823, 14.665619030057044, 14.800432007310977, 14.934720744161856, 15.06849396164863, 15.201760127368557, 15.33452746591314, 15.466803968750988, 15.59859740359331, 15.729915323275067, 15.860765074182217, 15.991153804253358, 16.121088470581956, 16.250575846643418, 16.37962252916961, 16.508234944691758, 16.636419355771217, 16.764181866936305, 16.89152843034204, 17.01846485116865, 17.144996792773433, 17.271129781609833, 17.396869211926465, 17.522220350258163, 17.647188339720252, 17.771778204116572, 17.895994851871084], [0.0, 0.7156063450296855, 1.1625059371961781, 1.5440418272254517, 1.8884964665318944, 2.207766736303074, 2.508303348476268, 2.794105567260019, 3.0678715609016294, 3.3315316176001954, 3.586527644315514, 3.833973107173444, 4.074750811176437, 4.309575854149352, 4.539037885358499, 4.7636304642709115, 4.983772054110987, 5.199821406944667, 5.412089079864649, 5.620846215683424, 5.826331347386322, 6.0287557474829265, 6.228307687733985, 6.425155870521143, 6.61945222186515, 6.811334186429175, 7.000926629623564, 7.188343426560006, 7.3736887990683595, 7.557058448269533, 7.738540519919229, 7.9182164319512145, 8.096161587689775, 8.27244599359688, 8.447134796830516, 8.620288755069666, 8.79196464882695, 8.962215644687126, 9.131091616477478, 9.298639430218325, 9.46490319775999, 9.62992450324229, 9.79374260587887, 9.956394622044936, 10.117915689211788, 10.278339113908455, 10.437696505586267, 10.596017898006059, 10.753331859551153, 10.909665593685551, 11.065045030620494, 11.219494911118776, 11.373038863251846, 11.525699472826107, 11.677498348109918, 11.82845617941934, 11.978592794056818, 12.127927207041571, 12.276477668022128, 12.42426170471898, 12.571296163208446, 12.717597245326086, 12.863180543439391, 13.008061072814177, 13.152253301776648, 13.295771179853299, 13.438628164053213, 13.580837243441593, 13.72241096213946, 13.863361440871886, 14.003700397176093, 14.143439164370637, 14.282588709378, 14.421159649484853, 14.559162268116925, 14.696606529698968, 14.83350209366433, 14.969858327673334, 15.105684320094829, 15.2409888918009, 15.375780607320696, 15.510067785395828, 15.643858508976363, 15.777160634693535, 15.909981801842552, 16.042329440906315, 16.174210781648668, 16.305632860803644, 16.436602529385258, 16.567126459640743, 16.697211151668338, 16.82686293971938, 16.956087998203106, 17.08489234741117, 17.213281858977968, 17.34126226109146, 17.468839143468557, 17.59601796210794, 17.722804043832525, 17.84920259063289, 17.975218683822305, 18.100857288013383], [0.0, 0.7236663598714064, 1.1755994699358874, 1.5614326736455724, 1.90976697322109, 2.2326332467599124, 2.5365548618350804, 2.8255761271535547, 3.10242560096165, 3.3690553126736456, 3.626923409730683, 3.8771558994463313, 4.120645530029208, 4.358115453591452, 4.590161960734892, 4.8172841699837985, 5.039905257796069, 5.25838801693264, 5.4730465023517505, 5.684154910800654, 5.891954461908552, 6.096658807788809, 6.298458340743998, 6.497523663283829, 6.694008412601669, 6.888051581426927, 7.079779441553598, 7.269307150691123, 7.456740104540305, 7.6421750821225745, 7.8257012219965985, 8.007400859122326, 8.187350246106497, 8.365620177907614, 8.5422765354489, 8.717380760735015, 8.890990273808645, 9.063158840080236, 9.233936895115791, 9.403371832796816, 9.571508261814072, 9.738388234677714, 9.904051452785621, 10.068535450562022, 10.231875761238463, 10.39410606648195, 10.555258331767272, 10.715362929131414, 10.87444874872901, 11.032543300422025, 11.18967280647876, 11.345862286322077, 11.501135634151042, 11.655515690160428, 11.809024305996768, 11.961682405015218, 12.11351003783702, 12.264526433651294, 12.414750047655946, 12.564198604989624, 12.712889141469317, 12.860838041415038, 13.008061072814177, 13.154573420052442, 13.300389714415632, 13.445524062546502, 13.589990073023072, 13.73380088120894, 13.876969172512021, 14.019507204175499, 14.161426825713518, 14.302739498094027, 14.44345631176211, 14.583588003589027, 14.723144972824747, 14.862137296125296, 15.000574741720119, 15.138466782779336, 15.27582261003588, 15.41265114371305, 15.548961044803974, 15.684760725745878, 15.820058360528687, 15.954861894274416, 16.089179052321153, 16.22301734884279, 16.356384095033423, 16.489286406883195, 16.62173121257045, 16.75372525949324, 16.885275120961694, 17.01638720257107, 17.14706774827418, 17.27732284617041, 17.40715843402753, 17.5365803045512, 17.665594110416414, 17.794205369073836, 17.922419467343445, 18.050241665806848, 18.177677103009152, 18.304730799480375], [0.0, 0.7316880830837222, 1.1886307977401074, 1.5787408993932452, 1.9309364276944525, 2.2573816210567426, 2.5646721575155245, 2.8568971762781548, 3.136815481212736, 3.4064007396602647, 3.667127262387725, 3.9201335383155507, 4.166322211620203, 4.406424450436682, 4.641043155150588, 4.870682976933382, 5.095771783084766, 5.316676387864083, 5.533714327477407, 5.747162838098077, 5.9572658132354235, 6.1642392733015345, 6.36827572106651, 6.569547650140972, 6.768210400761441, 6.964404506368995, 7.158257638459806, 7.349886231247686, 7.539396848727538, 7.726887342700415, 7.912447839811324, 8.096161587689775, 8.278105684190178, 8.458351709021569, 8.636966273386431, 8.814011500363991, 8.989545446488716, 9.16362247315183, 9.336293574989334, 9.507606671236157, 9.677606865063103, 9.846336675125517, 10.013836242904782, 10.18014351888808, 10.345294430187014, 10.509323031824357, 10.672261643606962, 10.83414097424087, 10.994990234123357, 11.154837238058702, 11.313708498984763, 11.471629313660618, 11.62862384114861, 11.78471517482334, 11.939925408553268, 12.094275697625518, 12.247786314919189, 12.400476702775817, 12.552365520966156, 12.703470691109118, 12.853809437860935, 13.003398327159129, 13.152253301776648, 13.300389714415632, 13.447822358547292, 13.594565497184208, 13.740632889753261, 13.886037817221405, 14.03079310561223, 14.17491114803845, 14.318403925364143, 14.461283025600203, 14.603559662127491, 14.745244690833724, 14.886348626242857, 15.026881656709001, 15.166853658740825, 15.30627421051699, 15.4451526046482, 15.583497860236973, 15.721318734282121, 15.85862373247137, 15.995421119401982, 16.131718928266345, 16.267524970036664, 16.402846842180217, 16.537691936934486, 16.672067449169205, 16.805980383860437, 16.93943756320005, 17.072445633362225, 17.2050110709472, 17.337140189120984, 17.468839143468557, 17.600113937576857, 17.730970428362753, 17.86141433116021, 17.99145122457993, 18.121086555153905, 18.25032564177644, 18.379173679952565, 18.507635745864057], [0.0, 0.7396722907087352, 1.2016011812929523, 1.5959681789106748, 1.9520068779393682, 2.282014253414844, 2.592657955656986, 2.888071744712541, 3.1710445286202114, 3.443571511452558, 3.7071430917105856, 3.9629101815482475, 4.211785274828891, 4.454507518221448, 4.691686390982992, 4.923832051057365, 5.151377034648192, 5.374692158705678, 5.594098424402809, 5.809876093124378, 6.022271719754775, 6.231503681928875, 6.437766583014177, 6.641234798878012, 6.842065364835345, 7.040400347833402, 7.236368812524478, 7.430088463656863, 7.621667028055745, 7.811203425284674, 7.998788765453966, 8.184507204594366, 8.368436681854947, 8.550649558025192, 8.731213171171511, 8.910190322262483, 9.087639701347646, 9.263616263011748, 9.438171558346157, 9.611354029482284, 9.783209271758407, 9.953780267795029, 10.123107597098867, 10.291229624274235, 10.45818266847072, 10.624001156320771, 10.788717760306174, 10.952363524227518, 11.114967977227021, 11.276559237625145, 11.43716410766991, 11.596808160159572, 11.755515817781067, 11.913310425904756, 12.070214319488215, 12.226248884665852, 12.381434615535175, 12.535791166593278, 12.689337401227025, 12.842091436616705, 12.99407068537464, 13.145291894206476, 13.295771179853299, 13.445524062546502, 13.594565497184208, 13.74290990241752, 13.890571187816699, 14.037562779271104, 14.183897642762373, 14.32958830663733, 14.474646882495682, 14.619085084797137, 14.762914249283382, 14.906145350301983, 15.048789017111776, 15.190855549242572, 15.332354930975868, 15.473296845007768, 15.61369068535029, 15.753545569522736, 15.892870350080615, 16.031673625526036, 16.169963750639848, 16.30774884627294, 16.445036808631137, 16.581835318085556, 16.718151847538056, 16.85399367036906, 16.989367867993188, 17.124281337046313, 17.258740796225926, 17.392752792805165, 17.526323708839538, 17.659459767083998, 17.792167036636858, 17.924451438325868, 18.056318749850934, 18.187774610696774, 18.318824526828138, 18.44947387517929, 18.579727907948822, 18.709591756709983], [0.0, 0.7476197313887468, 1.2145118367674292, 1.613116127520356, 1.9729802996347157, 2.3065334535224724, 2.6205148803586007, 2.919102755552122, 3.2051159526838826, 3.4805711133822506, 3.7469746497989043, 4.005489840112841, 4.257038982516894, 4.502369165473111, 4.742096416814603, 4.976736375899145, 5.206726226334165, 5.43244076932851, 5.654204455066048, 5.8723005562120525, 6.086978276770453, 6.298458340743998, 6.50693744242442, 6.712591831268043, 6.915580229862516, 7.116046231599476, 7.3141202878719165, 7.509921368111849, 7.703558356619958, 7.895131235805291, 8.084732094714655, 8.27244599359688, 8.45835170902157, 8.642522379261823, 8.825026065900788, 9.00592624467475, 9.185282236231, 9.363149585616187, 9.53958039781459, 9.714623635446177, 9.8883253837503, 10.060729087176071, 10.231875761238463, 10.401804182751922, 10.5705510610987, 10.738151192809676, 10.904637601417518, 11.070041664274266, 11.23439322779927, 11.397720712431497, 11.560051208396867, 11.72141056326167, 11.881823462123448, 12.041313501187894, 12.199903255391499, 12.357614340652903, 12.514467471269331, 12.670482512916463, 12.825678531659632, 12.980073839339948, 13.133686035660293, 13.286532047262016, 13.438628164053213, 13.589990073023072, 13.740632889753261, 13.890571187816699, 14.039819026235621, 14.188389975154433, 14.336297139868314, 14.483553183335452, 14.630170347289157, 14.776160472055652, 14.921535015173985, 15.066305068906075, 15.210481376717283, 15.35407434880116, 15.497094076715744, 15.639550347193282, 15.781452655180162, 15.922810216159258, 16.063631977802746, 16.203926630999707, 16.343702620299293, 16.482968153807224, 16.621731212570445, 16.759999559482157, 16.897780747737126, 17.035082128864925, 17.171910860366737, 17.30827391297964, 17.444178077590454, 17.579629971819777, 17.714636046295386, 17.849202590632892, 17.983335739140287, 18.11704147626192, 18.250325641776442, 18.38319393576225, 18.515651923343167, 18.647705039226164, 18.779358592042307, 18.91061776850125], [0.0, 0.7555311277333359, 1.2273639380462622, 1.6301863043747793, 1.9938585997586056, 2.3309414507525266, 2.6482454644710605, 2.9499930302467936, 3.2390328512988313, 3.5174029095847725, 3.7866255582796393, 4.047876385503361, 4.302087449312301, 4.550013743942901, 4.792277816104302, 5.029400761708137, 5.261824390688092, 5.489927470441692, 5.714037884521254, 5.9344419032153555, 6.151391367632811, 6.365109337502667, 6.575794588557844, 6.783625235346297, 6.988761680076004, 7.191349035660073, 7.391519133942856, 7.589392203304316, 7.785078280271091, 7.978678405277363, 8.170285641866622, 8.359985950404845, 8.547858941084185, 8.733978526135196, 8.918413487376382, 9.101227972251426, 9.282481929145407, 9.462231490888916, 9.640529313847063, 9.817424878767781, 9.992964758569624, 10.167192857435765, 10.340150624911985, 10.511877248153356, 10.682409825004951, 10.851783520218467, 11.020031706785323, 11.187186094096234, 11.353276844408729, 11.518332678910067, 11.682380974497995, 11.845447852260666, 12.007558258516104, 12.168736039167719, 12.329004008042522, 12.48838400980125, 12.646896977942152, 12.804562988361731, 12.961401308884575, 13.117430445129761, 13.272668183042216, 13.427131628382911, 13.580837243441593, 13.73380088120894, 13.886037817221405, 14.037562779271104, 14.188389975154433, 14.33853311861659, 14.488005453634475, 14.636819777167123, 14.784988460491247, 14.93252346922874, 15.07943638216362, 15.22573840893737, 15.371440406703918, 15.516552895818656, 15.661086074629628, 15.805049833433387, 15.94845376765291, 16.091307190290355, 16.233619143703176, 16.375398410748414, 16.516653525336405, 16.657392782431963, 16.79762424753837, 16.93735576569664, 17.076594970030307, 17.21534928986365, 17.353625958439334, 17.49143202025957, 17.62877433807311, 17.765659599528952, 17.902094323516152, 18.038084866207736, 18.173637426825646, 18.308758053142284, 18.4434526467335, 18.57772696799657, 18.71158664094608, 18.845037157799688, 18.978083883364985, 19.11073205923798], [0.0, 0.7634071775988812, 1.240158618800483, 1.6471802152172144, 2.0146436199650632, 2.3552403981100904, 2.6758521540815248, 2.980745293596869, 3.2727982162408473, 3.554070148956122, 3.8260993147198703, 4.090073556594689, 4.346934648895426, 4.5974454563115525, 4.842235015303255, 5.081829853957274, 5.316676387864083, 5.547157332889777, 5.7736039906155465, 5.996305615560511, 6.215516674156331, 6.431462551422812, 6.644344095234615, 6.854341276898481, 7.061616170738523, 7.266315402400413, 7.46857217801229, 7.668507979277352, 7.866233989800283, 8.06185230331336, 8.255456953502907, 8.447134796830516, 8.636966273386433, 8.825026065900788, 9.011383673209572, 9.196103911462826, 9.379247353978805, 9.560870718745957, 9.741027211046754, 9.919766827442212, 10.097136626351238, 10.273180969637071, 10.447941738937137, 10.621458529913818, 10.79376882713944, 10.964908161941382, 11.1349102552085, 11.30380714688671, 11.471629313660618, 11.638405776122092, 11.804164196559919, 11.96893096836207, 12.132731297899985, 12.295589279659183, 12.457527965289886, 12.618569427172947, 12.778734817028305, 12.938044420034057, 13.09651770487263, 13.254173370075309, 13.411029386996969, 13.567103039717944, 13.72241096213946, 13.876969172512021, 14.03079310561223, 14.183897642762373, 14.336297139868314, 14.488005453634475, 14.639035966099861, 14.789401607625678, 14.939114878453262, 15.088187868940382, 15.236632278574332, 15.384459433851733, 15.531680305107136, 15.678305522365596, 15.824345390288048, 15.969809902272647, 16.114708753770056, 16.259051354866017, 16.402846842180217, 16.546104090126786, 16.688831721577973, 16.83103811796963, 16.972731428884046, 17.113919581143026, 17.254610287441754, 17.394811054551656, 17.53452919111849, 17.67377181508002, 17.812545860725866, 17.950858085420563, 18.088715076009453, 18.226123254925632, 18.363088886014946, 18.499618080094937, 18.63571680026255, 18.771390866964435, 18.906645962842845, 19.04148763736917, 19.175921311276543, 19.309952280802108], [0.0, 0.7712485552873364, 1.252896974436847, 1.6640993149682723, 2.0353371397476123, 2.3794323759308607, 2.7033373127154987, 3.0113621784337297, 3.306414938305689, 3.5905759707338056, 3.865399298634905, 4.132084966065185, 4.391584420824779, 4.644668363408652, 4.891972291458662, 5.134028141322975, 5.371286913973702, 5.6041352563634375, 5.832907873055301, 6.0578969896616846, 6.279359686379827, 6.497523663283828, 6.712591831268042, 6.924746010224121, 7.134149939231276, 7.340951750008346, 7.545286016917344, 7.7472754694672865, 7.947032433291205, 8.144660050782612, 8.340253321499873, 8.533899994055375, 8.725681334784058, 8.91567279352371, 9.103944582971337, 9.290562185039537, 9.475586795228642, 9.659075714108955, 9.841082693463859, 10.021658243396718, 10.200849905689509, 10.378702497870725, 10.55525833176727, 10.730557409750496, 10.904637601417518, 11.077534803057643, 11.249283081925647, 11.41991480706746, 11.589460768210591, 11.757950284033468, 11.925411300959558, 12.091870483477932, 12.257353296868617, 12.421884083104935, 12.585486130613367, 12.748181738492406, 12.909992275723015, 13.070938235843585, 13.231039287510152, 13.390314321316971, 13.54878149321265, 13.706458264811877, 13.863361440871886, 14.019507204175499, 14.17491114803845, 14.32958830663733, 14.483553183335452, 14.636819777167123, 14.789401607625678, 14.941311737887213, 15.092562796589975, 15.243166998278479, 15.393136162611933, 15.542481732427676, 15.691214790742634, 15.839346076768736, 15.986886001011793, 16.133844659517685, 16.280231847324412, 16.426057071173915, 16.57132956153317, 16.71605828397031, 16.86025194992789, 17.003919026932124, 17.14706774827417, 17.289706122196616, 17.431841940616, 17.573482787409954, 17.714636046295382, 17.85530890832233, 17.99550837900634, 18.13524128512058, 18.27451428116753, 18.413333855548647, 18.551706336449207, 18.689637897454343, 18.827134562911265, 18.964202213051657, 19.10084658888733, 19.23707329689137, 19.372887813476268, 19.508295489279742], [0.0, 0.7790559126704492, 1.2655800639241328, 1.6809450101515977, 2.05594087940611, 2.403519395349549, 2.730703225277384, 3.0418462300093756, 3.3398858121287174, 3.626923409730683, 3.9045287771227226, 4.173914106419865, 4.436040476938513, 4.691686390982991, 4.941493779344592, 5.185999963168831, 5.4256605089154855, 5.660865977568395, 5.8919544619085515, 6.119221145751354, 6.342925711719627, 6.563298164897759, 6.780543470249262, 6.994845288230499, 7.20636901545313, 7.415264283174971, 7.621667028055745, 7.8257012219965985, 8.02748032770415, 8.227108531683468, 8.424681795174463, 8.620288755069666, 8.814011500363993, 9.005926244674749, 9.196103911462826, 9.38461064551492, 9.57150826181407, 9.75685464098487, 9.940704078940573, 10.123107597098867, 10.304113218507696, 10.483766214383872, 10.662109324877378, 10.839182957303995, 11.015025364615179, 11.189672806478757, 11.36315969501269, 11.535518726935111, 11.70678100365826, 11.87697614065387, 12.046132367247347, 12.21427661785267, 12.381434615535174, 12.547630948682231, 12.712889141469317, 12.877231718728936, 13.040680265760473, 13.203255483558628, 13.364977239885457, 13.525864616564899, 13.685935953338422, 13.84520888858483, 14.003700397176093, 14.161426825713518, 14.318403925364143, 14.474646882495682, 14.630170347289157, 14.784988460491247, 14.939114878453262, 15.092562796589975, 15.245344971379463, 15.397473741014217, 15.548961044803972, 15.699818441422037, 15.850057126078838, 15.999687946699458, 16.148721419175374, 16.29716774175484, 16.445036808631137, 16.592338222783052, 16.73908130811768, 16.885275120961694, 17.03092846094368, 17.176049881306707, 17.320647698687626, 17.46473000239655, 17.608304663227674, 17.751379341830305, 17.893961496666794, 18.036058391582255, 18.17767710300915, 18.318824526828138, 18.4595073849053, 18.59973223132425, 18.73950545833055, 18.878833302004608, 19.01772184767816, 19.156177035108538, 19.29420466342388, 19.431810395851656, 19.56899976424214, 19.705778173397615], [0.0, 0.7868298802450583, 1.2782089115074768, 1.6977186611708504, 2.0764565028316873, 2.4275034015556547, 2.7579521017494466, 3.072199910116856, 3.3732135407090524, 3.6631154012479388, 3.9434909101529874, 4.215564355644323, 4.4803064073634085, 4.738503336057851, 4.990803478155655, 5.2377495165704655, 5.47980156372446, 5.717354077893539, 5.950748525586143, 6.180283036169297, 6.406219883561593, 6.628791367999845, 6.848204499732064, 7.064644771907756, 7.27827923158225, 7.489259003139242, 7.697721379710011, 7.903791570274484, 8.10758416974993, 8.309204404287613, 8.508749192696149, 8.7063080563493, 8.90196390338368, 9.095793707929648, 9.287869101172245, 9.47825688793735, 9.667019500041361, 9.854215395682429, 10.039899412576606, 10.22412308126915, 10.406934904015737, 10.588380603781207, 10.768503347206806, 10.947343944820922, 11.124941031289849, 11.30133122810587, 11.476549290775251, 11.650628242286963, 11.823599494405006, 11.995492958125103, 12.166337144464723, 12.336159256608356, 12.504985274304168, 12.672840031299748, 12.839747286511328, 13.005729789540029, 13.170809341078527, 13.3350068486906, 13.4983423783928, 13.660835202420921, 13.822503843523265, 13.983366116086778, 14.143439164370637, 14.302739498094027, 14.461283025600203, 14.619085084797137, 14.776160472055652, 14.93252346922874, 15.088187868940382, 15.243166998278479, 15.397473741014217, 15.551120558459237, 15.704119509062108, 15.856482266836702, 16.008220138707127, 16.15934408084669, 16.309864714081822, 16.45979233842607, 16.60913694680393, 16.757908238019464, 16.906115629020263, 17.053768266503404, 17.20087503790634, 17.34744458182242, 17.493485297877744, 17.639005356103244, 17.784012705833437, 17.928515084160974, 18.072520023973983, 18.216034861601333, 18.3590667440891, 18.5016226361299, 18.64370932666531, 18.785333435180195, 18.926501417706447, 19.067219572552453, 19.207494045773682, 19.347330836398537, 19.48673580142293, 19.625714660586, 19.7642730009387, 19.902416281216244], [0.0, 0.7945710681246025, 1.290784508319084, 1.7144215844490547, 2.0968856201233628, 2.4513862768524377, 2.7850860806671984, 3.10242560096165, 3.406400739660265, 3.699154785691093, 3.982288755536365, 4.257038982516893, 4.524385686160655, 4.7851228729021384, 5.039905257796069, 5.289280862915798, 5.533714327477407, 5.773603990615547, 6.009294678340455, 6.241087453150572, 6.469247169333808, 6.694008412601668, 6.915580229862515, 7.134149939231276, 7.3498862312476865, 7.562941717125413, 7.773455040747592, 7.981552642956671, 8.187350246106496, 8.390954111610743, 8.592462111809068, 8.791964648826951, 8.989545446488718, 9.185282236231002, 9.379247353978805, 9.571508261814072, 9.762128005785616, 9.951165619229757, 10.138676479380774, 10.324712623764713, 10.509323031824357, 10.692553876367734, 10.87444874872901, 11.055048860948988, 11.234393227799268, 11.412518831070924, 11.589460768210591, 11.765252387102331, 11.939925408553268, 12.113510037837019, 12.28603506647532, 12.457527965289886, 12.628014969629382, 12.797521157567024, 12.966070521770005, 13.133686035660293, 13.300389714415633, 13.466202671297863, 13.631145169742068, 13.795236671593008, 13.958495881834152, 14.120940790118434, 14.282588709378, 14.44345631176211, 14.603559662127491, 14.762914249283382, 14.921535015173985, 15.07943638216362, 15.236632278574332, 15.393136162611933, 15.548961044803972, 15.704119509062108, 15.858623732471372, 16.01248550389986, 16.165716241514307, 16.318327009279805, 16.47032853251527, 16.621731212570445, 16.772545140684727, 16.922780111083398, 17.072445633362225, 17.22155094420763, 17.370105018495696, 17.518116579810147, 17.66559411041641, 17.812545860725866, 17.958979858282174, 18.104903916299005, 18.250325641776442, 18.395252443221473, 18.539691537996042, 18.683649959314554, 18.827134562911265, 18.970152033396527, 19.11270889031958, 19.254811493954424, 19.396466050824195, 19.537678618978443, 19.678455113036865, 19.818801309011963, 19.95872284892264, 20.098225245209594], [0.0, 0.80228006697153, 1.3033078138929326, 1.7310550544404295, 2.1172297900486825, 2.475169843533556, 2.8121072323876257, 3.132525608802284, 3.4394499412077035, 3.7350443129108615, 4.020925273597639, 4.298341151604179, 4.568281676635101, 4.831548558645611, 5.088802864793862, 5.340597934111875, 5.5874029137865415, 5.8296200076740625, 6.067597387317154, 6.301639036149269, 6.532012378098068, 6.758954274846398, 6.982675801494232, 7.203366093533432, 7.421195478154283, 7.63631804721796, 7.848873789742827, 8.058990373311579, 8.26678464302658, 8.472363891259155, 8.675826939915062, 8.877265068209203, 9.076762812261864, 9.274398657666953, 9.470245642159027, 9.664371882343117, 9.856841035946383, 10.047712709051803, 10.237042816168486, 10.424883899695159, 10.611285414277498, 10.796293980696202, 10.979953613212418, 11.16230592370982, 11.343390305484775, 11.523244099128968, 11.701902742607569, 11.879399907348763, 12.055767621917752, 12.231036384642392, 12.405235266382315, 12.578392004483577, 12.750533088832519, 12.921683840812046, 13.091868485868327, 13.261110220313508, 13.429431272918537, 13.596852961787985, 13.763395746954581, 13.929079279083624, 14.09392244463599, 14.257943407801818, 14.421159649484853, 14.583588003589027, 14.745244690833724, 14.906145350301983, 15.066305068906075, 15.22573840893737, 15.384459433851733, 15.542481732427676, 15.699818441422037, 15.856482266836702, 16.01248550389986, 16.167840055856246, 16.322557451652663, 16.47664886259777, 16.630125118068477, 16.782996720329344, 16.93527385852586, 17.086966421907753, 17.238084012333736, 17.38863595610537, 17.538631315173784, 17.688078897759684, 17.83698726842419, 17.985364757624893, 18.13321947078941, 18.280559296935888, 18.427391916868203, 18.573724810971335, 18.71956526663071, 18.8649203852976, 19.00979708922121, 19.15420212786656, 19.29814208403615, 19.441623379711913, 19.58465228163322, 19.72723490662536, 19.869377226692183, 20.01108507388559, 20.15236414496384, 20.29322000584982], [0.0, 0.8099574488748875, 1.3157797575904209, 1.747620305523937, 2.1374905223596925, 2.498855866590583, 2.8390175621652687, 3.1625021673769047, 3.4723635979508036, 3.770786646288811, 4.059403331574077, 4.339473927962879, 4.611997636332355, 4.877783838563959, 5.137499927867359, 5.391704538426792, 5.640871306911401, 5.885406286048539, 6.125660979192359, 6.361942278731688, 6.5945201676950616, 6.823633774402216, 7.049496193826511, 7.272298371383125, 7.492212264200499, 7.709393438714724, 7.923983223562584, 8.13611050803579, 8.3458932553805, 8.553439784697401, 8.758849863563904, 8.962215644687126, 9.163622473151833, 9.363149585616187, 9.560870718745957, 9.75685464098487, 9.951165619229757, 10.143863829961239, 10.335005722759728, 10.524644342826003, 10.712829618059676, 10.899608615376843, 11.085025770231088, 11.269123092709073, 11.45194035307949, 11.633515249263082, 11.813883558346985, 11.993079273976555, 12.171134731212865, 12.348080720236105, 12.523946590098147, 12.698760343576296, 12.872548724050635, 13.045337295215866, 13.21715051434244, 13.388011799718543, 13.55794359283231, 13.726967415790925, 13.895103924418457, 14.06237295742633, 14.228793582008537, 14.394384136176587, 14.559162268116925, 14.723144972824747, 14.886348626242857, 15.048789017111776, 15.210481376717283, 15.371440406703918, 15.531680305107136, 15.691214790742634, 15.850057126078838, 16.008220138707127, 16.165716241514307, 16.322557451652663, 16.47875540839472, 16.63432138995245, 16.789266329333998, 16.94360082930484, 17.09733517651504, 17.250479354849023, 17.403043058050056, 17.555035701667308, 17.706466434369823, 17.85734414866818, 18.007677491081655, 18.15747487178578, 18.306744473772675, 18.455494261554083, 18.60373198943498, 18.751465209383543, 18.898701278521493, 19.04544736625711, 19.19171046108174, 19.337497377049107, 19.482814759955517, 19.627669093237774, 19.772066703604512, 19.916013766415706, 20.059516310824016, 20.202580224690887, 20.34521125928945, 20.487415033805433], [0.0, 0.8176037681770134, 1.3282012399433343, 1.7641185337870107, 2.1576692799745936, 2.5224460562634894, 2.8658190130498964, 3.192357441131124, 3.5051440864071934, 3.806384366586054, 4.09772570775871, 4.3804402815689185, 4.65553672174608, 4.923832051057366, 5.185999963168832, 5.442604365992795, 5.694123367516262, 5.940966853765248, 6.183489646424868, 6.422001535069723, 6.656775051475127, 6.888051581426927, 7.1160462315994755, 7.340951750008346, 7.562941717125414, 7.7821731679955795, 7.998788765453967, 8.21291861555828, 8.424681795174465, 8.634187645978452, 8.841536877393116, 9.04682251208365, 9.250130700826244, 9.451541428304514, 9.651129127287577, 9.848963215420516, 10.045108566305142, 10.2396259245119, 10.432572272527612, 10.624001156320771, 10.813962975130151, 11.00250524020219, 11.189672806478757, 11.375508080638388, 11.560051208396867, 11.743340243558253, 11.92541130095956, 12.106298695159627, 12.28603506647532, 12.46465149575833, 12.642177609127213, 12.818641673716588, 12.99407068537464, 13.168490449127486, 13.3419256531319, 13.514399936753986, 13.685935953338424, 13.85655542816962, 14.026279212070806, 14.195127331038703, 14.363119032269173, 14.530272826891823, 14.696606529698968, 14.862137296125296, 15.026881656709001, 15.190855549242572, 15.35407434880116, 15.516552895818656, 15.678305522365596, 15.839346076768736, 15.999687946699458, 16.15934408084669, 16.318327009279805, 16.47664886259777, 16.63432138995245, 16.79135597602662, 16.94776365704034, 17.10355513585341, 17.258740796225926, 17.41333071629416, 17.567334681314144, 17.720762195721566, 17.873622494552535, 18.025924554266446, 18.17767710300915, 18.328888630351567, 18.479567396536503, 18.629721441263857, 18.779358592042307, 18.928486472133603, 19.07711250811362, 19.225243937072683, 19.37288781347627, 19.520051015705473, 19.66674025229555, 19.812962067889515, 19.95872284892264, 20.104028829052744, 20.24888609435008, 20.393300588259837, 20.537278116349444, 20.68082435085197], [0.0, 0.825219562252919, 1.3405731339199543, 1.7805508987072047, 2.177767481034543, 2.5459420704451707, 2.8925134686183522, 3.2220935282611385, 3.5377937103539807, 3.8418399755716894, 4.135895095406491, 4.421243091493112, 4.6989019927558875, 4.969696432344168, 5.234306379228055, 5.493300993994456, 5.7471628380980775, 5.9963056155605114, 6.241087453150572, 6.481821026062641, 6.718781404643848, 6.952212223134007, 7.182330591877465, 7.409331054293938, 7.633388807718119, 7.8546623499408135, 8.07329567266917, 8.289420093869376, 8.503155799581437, 8.71461314997425, 8.923893792556175, 9.13109161647748, 9.336293574989336, 9.53958039781459, 9.741027211046754, 9.940704078940575, 10.138676479380774, 10.335005722759728, 10.529749322343227, 10.722961322868347, 10.91469259303136, 11.104991086635215, 11.293902076435417, 11.481468364119111, 11.66773046935034, 11.852726800395736, 12.03649380849385, 12.219066127835866, 12.400476702775821, 12.5807569036765, 12.759936632617052, 12.938044420034059, 13.115107513235921, 13.291151957616732, 13.466202671297864, 13.640283513840762, 13.81341734960089, 13.985626106228757, 14.156930828768296, 14.32735172975386, 14.496908235664577, 14.665619030057044, 14.83350209366433, 15.000574741720119, 15.166853658740825, 15.332354930975868, 15.497094076715744, 15.661086074629628, 15.824345390288048, 15.986886001011793, 16.148721419175374, 16.309864714081822, 16.47032853251527, 16.630125118068477, 16.789266329333998, 16.94776365704034, 17.10562824020747, 17.26287088138989, 17.419502061070087, 17.575531951259883, 17.730970428362753, 17.88582708534606, 18.040111243268182, 18.193831962202196, 18.346998051594664, 18.499618080094937, 18.65170038488811, 18.803253080562065, 18.95428406753696, 19.104801040083498, 19.254811493954424, 19.404322733651934, 19.553341879352242, 19.70187587350701, 19.849931487139983, 19.997515325856043, 20.144633835578663, 20.291293308030767, 20.437499885972983, 20.58325956821235, 20.72857821439383, 20.87346154958607], [0.0, 0.8328053522456563, 1.3528962861196663, 1.7969185247388728, 2.1977865008443005, 2.569345516950178, 2.9191027555521223, 3.2517124635849908, 3.570314703980338, 3.8771558994463318, 4.173914106419866, 4.461885149841007, 4.742096416814603, 5.0153801208894295, 5.2824224816166945, 5.54379789156384, 5.799993348107866, 6.051426358224114, 6.298458340743998, 6.541404845113152, 6.780543470249263, 7.016120089987837, 7.248353810449319, 7.477440963384186, 7.703558356619959, 7.926865944930543, 8.14750904365973, 8.365620177907612, 8.581320638518424, 8.794721800141453, 9.005926244674749, 9.215028724339948, 9.422116991701682, 9.627272518586777, 9.830571121681647, 10.032083509303227, 10.231875761238463, 10.430009751472472, 10.626543521958896, 10.821531614238383, 11.015025364615179, 11.207073167705193, 11.397720712431495, 11.587011193933622, 11.77498550435062, 11.961682405015218, 12.147138682242167, 12.331389288595746, 12.514467471269331, 12.696404888996218, 12.877231718728938, 13.056976753168698, 13.235667490093434, 13.413330214318236, 13.589990073023074, 13.765671145097231, 13.940396505075626, 14.114188282177611, 14.287067714902644, 14.4590552015878, 14.630170347289157, 14.800432007310977, 14.969858327673334, 15.138466782779336, 15.30627421051699, 15.473296845007768, 15.639550347193282, 15.805049833433387, 15.969809902272647, 16.133844659517685, 16.29716774175484, 16.45979233842607, 16.621731212570445, 16.782996720329344, 16.94360082930484, 17.10355513585341, 17.26287088138989, 17.421558967770746, 17.579629971819777, 17.737094159054514, 17.893961496666794, 18.050241665806848, 18.205944073216422, 18.361077862252877, 18.515651923343164, 18.669674903903527, 18.823155217758217, 18.976101054088073, 19.12852038593746, 19.280420978306296, 19.43181039585166, 19.582696010222016, 19.733085007045453, 19.882984392591773, 20.03240100012702, 20.181341495977776, 20.329812385321347, 20.477820017717008, 20.625370592392407, 20.77247016329832, 20.919124643944212, 21.06533981202613], [0.0, 0.840361643760693, 1.3651715179009758, 1.8132225028114, 2.2177276737046947, 2.5926579556569855, 2.9455886460712217, 3.2812162212537794, 3.6027092348643555, 3.912334492074803, 4.21178527482889, 4.50236916547311, 4.7851228729021384, 5.060886161586657, 5.330351477352669, 5.594098424402809, 5.8526184187866255, 6.106332755644852, 6.355606133069829, 6.600756963581488, 6.842065364835345, 7.0797794415535975, 7.3141202878719165, 7.545286016917345, 7.773455040747592, 7.998788765453967, 8.221433824869745, 8.441523946534806, 8.659181521801411, 8.874518935854283, 9.087639701347646, 9.298639430218325, 9.507606671236157, 9.714623635446175, 9.919766827442212, 10.123107597098867, 10.324712623764713, 10.524644342826003, 10.722961322868345, 10.919718600304066, 11.11496797722702, 11.30875828735191, 11.501135634151042, 11.692143604686343, 11.881823462123446, 12.070214319488215, 12.257353296868617, 12.443275663963977, 12.628014969629382, 12.811603159847259, 12.99407068537464, 13.175446600157501, 13.355758651469326, 13.535033362615176, 13.713296108942888, 13.890571187816697, 14.066881883133663, 14.242250524898152, 14.416698544312862, 14.59024652479507, 14.76291424928338, 14.934720744161856, 15.105684320094829, 15.27582261003588, 15.4451526046482, 15.61369068535029, 15.781452655180162, 15.94845376765291, 16.114708753770056, 16.280231847324412, 16.445036808631137, 16.60913694680393, 16.772545140684727, 16.93527385852586, 17.09733517651504, 17.258740796225926, 17.419502061070087, 17.579629971819777, 17.73913520126547, 17.89802810806681, 18.056318749850934, 18.21401689560804, 18.371132037430055, 18.52767340163474, 18.68364995931455, 18.839070436346315, 18.99394332289543, 19.148276882445607, 19.302079160383027, 19.45535799216177, 19.6081210110753, 19.76037565565726, 19.912129176733078, 20.063388644142535, 20.21416095315194, 20.36445283057344, 20.51427084060776, 20.66362139042562, 20.812510735502112, 20.96094498471731, 21.108930105235725, 21.25647192717616], [0.0, 0.8478889275220775, 1.3773996264474517, 1.8294638917449908, 2.237592294644253, 2.615880900532369, 2.9719728602341475, 3.3106067173136737, 3.6349794067860843, 3.9473780380409313, 4.249511060079848, 4.542697767520391, 4.827984155261763, 5.1062175097094125, 5.378096479062164, 5.644205859150967, 5.9050414677351295, 6.161028373578438, 6.412534541445444, 6.659881235939355, 6.903351083784367, 7.143194412025245, 7.379634295181118, 7.612870620917092, 7.843083399362605, 8.070435482354926, 8.295074817155278, 8.517136329127299, 8.736743505906551, 8.954009739333857, 9.169039469246556, 9.381929163996302, 9.592768165501603, 9.801639421187915, 10.008620120915694, 10.213782253654337, 10.417193096012392, 10.618915642622094, 10.819008986679338, 11.017528657568368, 11.214526921384536, 11.410053049255687, 11.604153557611953, 11.796872423933111, 11.988251280987045, 12.178329592142646, 12.36714480997978, 12.554732520115374, 12.741126571908172, 12.926359197487029, 13.110461120362359, 13.293461654722027, 13.475388796377276, 13.656269306207601, 13.8361287868528, 14.014991753313357, 14.19288169804475, 14.369821151065572, 14.545831735541999, 14.720934219261002, 14.895148562360843, 15.06849396164863, 15.2409888918009, 15.41265114371305, 15.583497860236973, 15.753545569522736, 15.922810216159258, 16.091307190290355, 16.259051354866017, 16.426057071173915, 16.592338222783052, 16.757908238019464, 16.922780111083398, 17.086966421907753, 17.250479354849023, 17.41333071629416, 17.575531951259883, 17.737094159054514, 17.89802810806681, 18.05834424974095, 18.218052731792213, 18.37716341071355, 18.53568586361941, 18.693629399469494, 18.85100306971209, 19.00781567838341, 19.164075791696924, 19.319791747153985, 19.474971662204876, 19.62962344248737, 19.783754789667842, 19.937373208908323, 20.09048601598132, 20.24310034405254, 20.39522315015055, 20.546861221340865, 20.698021180621044, 20.84870949255209, 20.99893246864061, 21.148696272485115, 21.298006924699166, 21.44687030762309], [0.0, 0.8553876799929505, 1.3895813857757495, 1.8456437195895272, 2.2573816210567426, 2.639015821545789, 2.9982570681128595, 3.339885812128718, 3.667127262387725, 3.982288755536365, 4.287093850145173, 4.582873508708774, 4.870682976933383, 5.151377034648193, 5.425660508915486, 5.694123367516262, 5.9572658132354235, 6.215516674156332, 6.469247169333808, 6.718781404643847, 6.964404506368995, 7.20636901545313, 7.444899979292423, 7.680199053363868, 7.912447839811325, 8.14181063073809, 8.368436681854945, 8.592462111809068, 8.814011500363991, 9.033199242201029, 9.250130700826242, 9.46490319775999, 9.677606865063103, 9.8883253837503, 10.097136626351238, 10.304113218507696, 10.509323031824357, 10.712829618059676, 10.91469259303136, 11.114967977227021, 11.313708498984763, 11.510963865187614, 11.70678100365826, 11.901204280814493, 12.094275697625518, 12.28603506647532, 12.476520171175386, 12.665766912062796, 12.853809437860937, 13.040680265760473, 13.226410390991374, 13.411029386996969, 13.594565497184208, 13.777045719106527, 13.958495881834153, 14.138940717178896, 14.318403925364144, 14.496908235664577, 14.674475462482235, 14.851126557274958, 15.026881656709001, 15.201760127368557, 15.375780607320696, 15.548961044803974, 15.721318734282121, 15.892870350080615, 16.063631977802746, 16.233619143703176, 16.402846842180217, 16.57132956153317, 16.73908130811768, 16.906115629020263, 17.072445633362225, 17.238084012333736, 17.403043058050056, 17.567334681314144, 17.730970428362753, 17.893961496666794, 18.056318749850934, 18.218052731792213, 18.379173679952565, 18.539691537996045, 18.69961596773735, 18.858956360464877, 19.017721847678157, 19.175921311276543, 19.333563393233323, 19.490656504786937, 19.64720883517862, 19.803228359963814, 19.958722848922637, 20.11369987359298, 20.268166814448236, 20.422130867740023, 20.57559905202505, 20.72857821439383, 20.881075036417887, 21.033096039830973, 21.184647591958832, 21.335735910911, 21.486367070547516, 21.63654700523228], [0.0, 0.8628583639627645, 1.4017175476895525, 1.8617629848915935, 2.27709687425085, 2.662064146481063, 3.02444289185107, 3.369055312673646, 3.6991547856910927, 4.017068799094393, 4.32453596446652, 4.622898868505255, 4.913221973097229, 5.1963675234468285, 5.4730465023517505, 5.743854030183975, 6.009294678340455, 6.269801020152657, 6.525747516784573, 6.777461104749851, 7.025229400533311, 7.269307150691123, 7.509921368111849, 7.7472754694672865, 7.981552642956672, 8.21291861555828, 8.441523946534806, 8.667505943350404, 8.890990273808644, 9.112092331677607, 9.330918400674708, 9.547566652295515, 9.762128005785616, 9.974686873003098, 10.185321806591531, 10.394106066481948, 10.601108117048046, 10.806392065089128, 11.010018047088494, 11.212042572798879, 11.412518831070924, 11.611496962911763, 11.809024305996767, 12.005145614225906, 12.199903255391495, 12.393337389586222, 12.585486130613367, 12.776385692352134, 12.966070521770003, 13.154573420052442, 13.341925653131899, 13.528157052736752, 13.713296108942886, 13.897370055091784, 14.08040494583656, 14.262425728988802, 14.44345631176211, 14.623519621941423, 14.802637664448831, 14.98083157372554, 15.158121662305051, 15.33452746591314, 15.510067785395828, 15.684760725745878, 15.85862373247137, 16.031673625526036, 16.203926630999707, 16.375398410748414, 16.546104090126786, 16.71605828397031, 16.885275120961694, 17.053768266503404, 17.22155094420763, 17.38863595610537, 17.555035701667308, 17.720762195721566, 17.88582708534606, 18.050241665806848, 18.21401689560804, 18.37716341071355, 18.539691537996045, 18.701611307964374, 18.86293246681646, 19.023664487861225, 19.18381658234981, 19.34339770975325, 19.502416587521086, 19.66088170035284, 19.818801309011967, 19.97618345870988, 20.13303598708548, 20.289366531804074, 20.44518253779775, 20.600491264167903, 20.75529979076909, 20.909615024492126, 21.063443705263264, 21.216792411775, 21.369667566963273, 21.52207544324462, 21.674022167526235, 21.825513726000864], [0.0, 0.870301429103382, 1.413808842682957, 1.8778226578943538, 2.2967392409177356, 2.6850272626520226, 3.050531907613449, 3.3981169747051863, 3.7310639044816645, 4.051720262178887, 4.361839656741857, 4.66277625609729, 4.955603704240366, 5.241191684151462, 5.520257311606178, 5.793400840518542, 6.061131194746969, 6.323884679024995, 6.582038984639832, 6.835923868278018, 7.085829427420467, 7.332012606081581, 7.574702375375962, 7.814103906659144, 8.050401968322149, 8.283763716913557, 8.514341010428797, 8.742272340753988, 8.967684459710297, 9.19069375645898, 9.411407431526829, 9.62992450324229, 9.846336675125519, 10.060729087176071, 10.273180969637071, 10.483766214383872, 10.692553876367734, 10.899608615376843, 11.104991086635215, 11.30875828735191, 11.510963865187614, 11.711658393668625, 11.910889618807785, 12.108702680554742, 12.305140312168788, 12.500243020165845, 12.694049247121022, 12.886595519296497, 13.07791658080124, 13.268045515765605, 13.457013859823746, 13.644851702034224, 13.831587778229927, 14.017249556668686, 14.201863316752531, 14.385454221494282, 14.568046384332526, 14.749662930828565, 14.9303260557202, 15.110057075755526, 15.288876478685102, 15.466803968750988, 15.643858508976363, 15.820058360528687, 15.995421119401982, 16.169963750639848, 16.343702620299293, 16.516653525336405, 16.688831721577973, 16.86025194992789, 17.03092846094368, 17.20087503790634, 17.370105018495696, 17.538631315173784, 17.706466434369823, 17.873622494552535, 18.040111243268182, 18.205944073216422, 18.371132037430055, 18.53568586361941, 18.69961596773735, 18.86293246681646, 19.02564519112592, 19.18776369569195, 19.349297271222465, 19.510254954473407, 19.670645538091524, 19.83047757996584, 19.989759412117632, 20.148499149156756, 20.30670469633003, 20.46438375718569, 20.62154384087624, 20.778192269120485, 20.934336182844216, 21.08998254851748, 21.245138164205507, 21.39980966534898, 21.554003530288437, 21.70772608554664, 21.860983510881827, 22.013781844123987], [0.0, 0.8777173124960633, 1.4258559807965643, 1.893823681674616, 2.3163098745217603, 2.707906518528359, 3.076525647432791, 3.4270725048196966, 3.762856492567822, 4.086245179637701, 4.3990071175666605, 4.702508013216206, 4.997830659157407, 5.285852148984206, 5.56729570905273, 5.842766708071592, 6.112778406465666, 6.377770826743641, 6.638124878519678, 6.894173128354062, 7.146208145663313, 7.39448906389504, 7.639246805238527, 7.88068828932502, 8.118999858966536, 8.354350095061234, 8.586892149594357, 8.81676569454853, 9.044098561803734, 9.269008132279277, 9.491602519963166, 9.71198158692414, 9.930237818092778, 10.146457078950966, 10.360719274866822, 10.57309892735218, 10.783665679779107, 10.992484742905178, 11.199617288800704, 11.405120800350907, 11.609049382350953, 11.811454039266772, 12.012382923957446, 12.211881561012463, 12.40999304782342, 12.606758236064355, 12.80221589588154, 12.996402864779322, 13.189354182923015, 13.381103216354555, 13.571681769424863, 13.761120187582916, 13.949447451521126, 14.13669126355576, 14.32287812701699, 14.50803341933297, 14.692181459414137, 14.875345569875899, 15.057548134578559, 15.238810651911322, 15.419153784201933, 15.59859740359331, 15.777160634693535, 15.954861894274416, 16.131718928266345, 16.30774884627294, 16.482968153807224, 16.657392782431963, 16.83103811796963, 17.003919026932124, 17.176049881306707, 17.34744458182242, 17.518116579810147, 17.688078897759684, 17.85734414866818, 18.025924554266446, 18.193831962202196, 18.361077862252877, 18.52767340163474, 18.693629399469494, 18.858956360464877, 19.023664487861225, 19.18776369569195, 19.35126362040214, 19.514173631866317, 19.67650284384309, 19.838260123901797, 19.99945410285368, 20.160093183717596, 20.320185550248407, 20.47973917505396, 20.638761827324814, 20.797261080199345, 20.955244317785116, 21.1127187418561, 21.269691378244, 21.426169082940717, 21.582158547927854, 21.73766630674824, 21.892698739833243, 22.04726207959916, 22.201362415324628], [0.0, 0.8851064391311988, 1.4378596524293012, 1.9097669732210898, 2.335809896619288, 2.7307032252773835, 3.10242560096165, 3.455923562404387, 3.794534371923255, 4.120645530029207, 4.436040476938512, 4.742096416814602, 5.039905257796069, 5.330351477352669, 5.614164390373883, 5.8919544619085515, 6.1642392733015345, 6.431462551422812, 6.694008412601667, 6.952212223134006, 7.206369015453129, 7.456740104540304, 7.703558356619958, 7.947032433291206, 8.187350246106496, 8.424681795174465, 8.659181521801411, 8.890990273808644, 9.120236959238062, 9.347039947188726, 9.57150826181407, 9.79374260587887, 10.013836242904784, 10.231875761238461, 10.447941738937137, 10.662109324877376, 10.874448748729009, 11.085025770231088, 11.293902076435415, 11.501135634151042, 11.70678100365826, 11.910889618807785, 12.113510037837017, 12.314688168587498, 12.51446747126933, 12.712889141469317, 12.909992275723013, 13.10581402165396, 13.300389714415632, 13.493753000944404, 13.685935953338422, 13.87696917251202, 14.06688188313366, 14.255702020733567, 14.44345631176211, 14.630170347289155, 14.815868650955647, 15.000574741720117, 15.184311191883012, 15.367099680819283, 15.54896104480397, 15.729915323275067, 15.909981801842552, 16.089179052321153, 16.267524970036664, 16.445036808631137, 16.621731212570445, 16.79762424753837, 16.972731428884046, 17.14706774827417, 17.320647698687626, 17.493485297877744, 17.66559411041641, 17.83698726842419, 18.007677491081655, 18.17767710300915, 18.346998051594664, 18.515651923343164, 18.68364995931455, 18.85100306971209, 19.017721847678157, 19.18381658234981, 19.349297271222465, 19.514173631866317, 19.67845511303686, 19.842150905217533, 20.005269950629952, 20.167820952744464, 20.329812385321347, 20.491252501010997, 20.652149339539235, 20.812510735502112, 20.97234432579302, 21.13165755668316, 21.290457690575167, 21.448751812448208, 21.60654683601185, 21.76384950958463, 21.920666421712472, 22.077004006540882, 22.232868548954187, 22.388266189494068], [0.0, 0.8924692223825023, 1.449820529108747, 1.9256534244575387, 2.3552403981100904, 2.7534186582269933, 3.1282332171344542, 3.4846717614888187, 3.82609931471987, 4.154923237829907, 4.472941806633692, 4.781543681606914, 5.081829853957274, 5.3746921587056775, 5.6608659775683945, 5.940966853765247, 6.21551667415633, 6.484962856766295, 6.749692713207102, 7.010044399528794, 7.266315402400412, 7.518769210559376, 7.767640627334466, 8.013140050082285, 8.255456953502907, 8.49476275185574, 8.731213171171511, 8.964950230918161, 9.196103911462824, 9.424793566561306, 9.651129127287573, 9.875212134105242, 10.097136626351238, 10.316989912659857, 10.534853241379203, 10.75080238651393, 10.96490816194138, 11.17723687442488, 11.387850724161742, 11.59680816015957, 11.804164196559917, 12.009970695067452, 12.214276617852668, 12.417128254642797, 12.618569427172945, 12.818641673716586, 13.017384416034922, 13.21483511076506, 13.411029386996969, 13.606001171560019, 13.799782803345028, 13.992405137820912, 14.183897642762371, 14.37428848608214, 14.56360461655533, 14.751871838131851, 14.939114878453262, 15.125357452121222, 15.310622319204505, 15.494931339418565, 15.678305522365592, 15.860765074182217, 16.042329440906315, 16.22301734884279, 16.402846842180217, 16.581835318085556, 16.759999559482157, 16.93735576569664, 17.113919581143026, 17.289706122196616, 17.46473000239655, 17.639005356103244, 17.812545860725866, 17.985364757624893, 18.15747487178578, 18.328888630351567, 18.499618080094937, 18.669674903903527, 18.839070436346315, 19.00781567838341, 19.175921311276543, 19.34339770975325, 19.510254954473407, 19.67650284384309, 19.842150905217533, 20.007208405531475, 20.171684361392664, 20.335587548671512, 20.498926511617515, 20.661709571530977, 20.823944835016405, 20.985640201842163, 21.146803372429364, 21.307441854991225, 21.467562972342883, 21.627173868400114, 21.78628151438437, 21.94489271475027, 22.103014112850747, 22.26065219635393, 22.417813302425138, 22.574503622686322], [0.0, 0.8998060644572552, 1.4617392642225575, 1.9414839032142583, 2.374602440425546, 2.776054058254751, 3.1539499057456784, 3.5133186725028964, 3.8575530452580296, 4.189080175530571, 4.509713122463748, 4.820851962481665, 5.123606737858901, 5.41887661524477, 5.707403021807172, 5.989806561045076, 6.266613410164258, 6.538274665339052, 6.8051808222062125, 7.067672816740817, 7.326050581200683, 7.580579770420617, 7.831497118008788, 8.079014750963717, 8.323323701625693, 8.564596793422439, 8.80299103258266, 9.03864960609289, 9.27170356286739, 9.502273237849478, 9.730469465838329, 9.956394622044934, 10.18014351888808, 10.401804182751922, 10.621458529913816, 10.839182957303994, 11.055048860948986, 11.269123092709071, 11.48146836411911, 11.692143604686342, 11.901204280814493, 12.10870268055474, 12.314688168587496, 12.519207415180192, 12.722304602319182, 12.924021609757224, 13.124398183335309, 13.323472087615372, 13.521279244588245, 13.717853859990159, 13.913228538564614, 14.107434389438236, 14.300501122635438, 14.492457137632707, 14.683329604746591, 14.873144540057007, 15.061926874487371, 15.249700517593165, 15.436488416549931, 15.62231261077823, 15.807194282596726, 15.991153804253358, 16.174210781648668, 16.356384095033423, 16.537691936934486, 16.718151847538056, 16.897780747737126, 17.076594970030307, 17.254610287441754, 17.431841940616, 17.608304663227674, 17.784012705833437, 17.958979858282174, 18.13321947078941, 18.306744473772675, 18.479567396536503, 18.65170038488811, 18.823155217758217, 18.99394332289543, 19.164075791696924, 19.333563393233323, 19.502416587521086, 19.670645538091524, 19.838260123901797, 20.005269950629952, 20.171684361392664, 20.33751244692173, 20.502763055232535, 20.667444800815442, 20.831566073378795, 20.995135046170155, 21.158159683900575, 21.32064775029506, 21.482606815290605, 21.644044261902007, 21.80496729277399, 21.965382936437265, 22.12529805328475, 22.28471934128329, 22.44365334143505, 22.602106443002146, 22.760084888506828], [0.0, 0.9071173568240766, 1.473616493713381, 1.9572592541510614, 2.3938970566575346, 2.7986106331076264, 3.1795770389492364, 3.541865823947108, 3.888897241800443, 4.22311816562773, 4.546356386419422, 4.860023356793315, 5.165238138571562, 5.462907204500337, 5.753778006146582, 6.038476189666573, 6.317532207671129, 6.591400821675538, 6.860475700253346, 7.125100549623899, 7.385577739117303, 7.642175082122575, 7.895131235805292, 8.144660050782614, 8.390954111610744, 8.634187645978454, 8.874518935854285, 9.112092331677609, 9.347039947188728, 9.579483095101603, 9.809533510793488, 10.037294401315844, 10.262861349477149, 10.486323096911939, 10.707762225500831, 10.92725575293037, 11.144875655349008, 11.360689327815734, 11.574759991422287, 11.78714705450226, 11.997906434146595, 12.20709084326828, 12.414750047655946, 12.620931096792042, 12.825678531659632, 13.0290345723016, 13.231039287510153, 13.431730748699744, 13.63114516974207, 13.829317034308964, 14.026279212070806, 14.222063064928602, 14.416698544312863, 14.610214280457447, 14.802637664448833, 14.993994923758235, 15.184311191883014, 15.373610572653577, 15.56191619970065, 15.74925029152411, 15.935634202557614, 16.121088470581956, 16.305632860803644, 16.489286406883195, 16.672067449169205, 16.85399367036906, 17.035082128864925, 17.21534928986365, 17.394811054551656, 17.573482787409954, 17.751379341830305, 17.928515084160974, 18.104903916299005, 18.280559296935888, 18.455494261554083, 18.629721441263857, 18.803253080562065, 18.976101054088073, 19.148276882445607, 19.319791747153985, 19.490656504786937, 19.66088170035284, 19.83047757996584, 19.99945410285368, 20.167820952744464, 20.335587548671512, 20.502763055232535, 20.669356392336667, 20.835376244470524, 21.000831069512262, 21.165729107120427, 21.330078386722608, 21.493886735127248, 21.657161783780175, 21.819910975686206, 21.982141572014495, 22.143860658405444, 22.30507515099547, 22.465791802175133, 22.626017206094925, 22.785757803932327, 22.945019888932638], [0.0, 0.9144034806195821, 1.4854528367394761, 1.9729802996347157, 2.413125252631615, 2.8210895586566114, 3.2051159526838835, 3.5703147039803382, 3.920133538315551, 4.257038982516894, 4.582873508708775, 4.899059906540992, 5.206726226334166, 5.506786221780642, 5.799993348107867, 6.086978276770454, 6.368275721066511, 6.644344095234617, 6.915580229862515, 7.182330591877464, 7.4448999792924235, 7.703558356619959, 7.958546297961353, 8.21007937161898, 8.45835170902157, 8.70353893728488, 8.945800609725653, 9.185282236231002, 9.42211699170168, 9.65642716325639, 9.8883253837503, 10.11791568921179, 10.345294430187016, 10.570551061098701, 10.793768827139441, 11.01502536461518, 11.23439322779927, 11.45194035307949, 11.66773046935034, 11.881823462123448, 12.09427569762552, 12.30514031216879, 12.514467471269331, 12.722304602319184, 12.928696604062312, 13.133686035660295, 13.337313287744825, 13.53961673752655, 13.740632889753263, 13.940396505075624, 14.138940717178897, 14.336297139868314, 14.53249596514947, 14.727566053219217, 14.921535015173987, 15.11442928914859, 15.306274210516992, 15.497094076715742, 15.6869122071889, 15.875750998899177, 16.063631977802746, 16.250575846643418, 16.436602529385258, 16.62173121257045, 16.805980383860437, 16.989367867993188, 17.171910860366737, 17.353625958439334, 17.53452919111849, 17.714636046295382, 17.893961496666794, 18.072520023973983, 18.250325641776442, 18.427391916868203, 18.60373198943498, 18.779358592042307, 18.95428406753696, 19.12852038593746, 19.302079160383027, 19.474971662204876, 19.64720883517862, 19.818801309011967, 19.989759412117632, 20.160093183717596, 20.329812385321347, 20.498926511617515, 20.667444800815442, 20.835376244470524, 21.002729596824675, 21.1695133836912, 21.335735910911, 21.501405272405428, 21.666529357849196, 21.831115859985243, 21.995172281601878, 22.15870594219123, 22.32172398430679, 22.48423337963658, 22.646240934807533, 22.807753296935505, 22.968776958934622, 23.129318264598624], [0.0, 0.9216648070352077, 1.4972488963031096, 1.988647840573579, 2.4322880079278595, 2.843491980090133, 3.2305679480290856, 3.5986667619302297, 3.951263526135876, 4.290844354293424, 4.619266349695895, 4.937963600440969, 5.248073114756543, 5.550515902501372, 5.846051402130727, 6.135315293294608, 6.41884653547771, 6.697107183210334, 6.970497218332914, 7.239365859084909, 7.504020323896423, 7.764732721082499, 8.021745535156086, 8.275276046258849, 8.52551992742747, 8.772654200441918, 9.016839685640266, 9.25822304841134, 9.496938521204827, 9.733109362227907, 9.966849098759209, 10.19826259298272, 10.427446960569382, 10.654492366304217, 10.879482716434303, 11.102496263779596, 11.323606138770769, 11.542880817282054, 11.76038453428247, 11.976177650837665, 12.19031698078153, 12.402856082384568, 12.613845519529866, 12.823333096232899, 13.031364067780927, 13.237981331300086, 13.44322559816621, 13.647135550345407, 13.849747982471603, 14.051097931231626, 14.251218793427087, 14.450142433910116, 14.647899284442623, 14.84451843440181, 15.040027714145287, 15.23445377175449, 15.427822143792932, 15.620157320644388, 15.81148280693386, 16.00182117747952, 16.19119412917631, 16.37962252916961, 16.567126459640743, 16.75372525949324, 16.93943756320005, 17.124281337046313, 17.30827391297964, 17.49143202025957, 17.67377181508002, 17.85530890832233, 18.036058391582255, 18.216034861601333, 18.395252443221473, 18.573724810971335, 18.751465209383543, 18.928486472133603, 19.104801040083498, 19.280420978306296, 19.45535799216177, 19.62962344248737, 19.803228359963814, 19.97618345870988, 20.148499149156756, 20.320185550248407, 20.491252501010997, 20.661709571530977, 20.831566073378795, 21.000831069512262, 21.1695133836912, 21.337621609432837, 21.505164118535205, 21.672149069193907, 21.838584413735987, 22.004477905992854, 22.169837108332864, 22.334669398372615, 22.498981975384996, 22.662781866420577, 22.826075932158066, 22.98887087249842, 23.151173231916342, 23.312989404581973], [0.0, 0.928901697685371, 1.509005259848636, 2.0042626572119717, 2.4513862768524373, 2.865819013049896, 3.255934292495481, 3.626923409730683, 3.9822887555363646, 4.32453596446652, 4.6555367217460795, 4.9767363758991445, 5.289280862915798, 5.594098424402809, 5.8919544619085515, 6.183489646424868, 6.469247169333807, 6.749692713207103, 7.02522940053331, 7.296209191605386, 7.562941717125413, 7.8257012219965985, 8.084732094714655, 8.340253321499873, 8.592462111809068, 8.841536877393116, 9.087639701347646, 9.33091840067471, 9.57150826181407, 9.809533510793486, 10.04510856630514, 10.278339113908453, 10.509323031824358, 10.738151192809674, 10.964908161941382, 11.189672806478757, 11.412518831070923, 11.63351524926308, 11.852726800395734, 12.070214319488215, 12.286035066475318, 12.500243020165845, 12.712889141469317, 12.924021609757224, 13.133686035660293, 13.341925653131897, 13.54878149321265, 13.754292541598556, 13.958495881834152, 14.161426825713518, 14.363119032269173, 14.56360461655533, 14.76291424928338, 14.961077248239643, 15.158121662305053, 15.354074348801156, 15.548961044803972, 15.742806432995202, 15.935634202557614, 16.127467105566332, 16.318327009279802, 16.508234944691758, 16.697211151668338, 16.885275120961694, 17.072445633362225, 17.258740796225926, 17.444178077590454, 17.62877433807311, 17.812545860725866, 17.99550837900634, 18.17767710300915, 18.3590667440891, 18.539691537996042, 18.71956526663071, 18.898701278521493, 19.07711250811362, 19.254811493954424, 19.43181039585166, 19.6081210110753, 19.783754789667842, 19.958722848922637, 20.13303598708548, 20.30670469633003, 20.47973917505396, 20.652149339539235, 20.823944835016405, 20.995135046170155, 21.165729107120427, 21.335735910911, 21.505164118535205, 21.674022167526232, 21.842318280137647, 22.010060471137983, 22.177256555241556, 22.343914154196252, 22.510040703547556, 22.67564345909687, 22.840729503071007, 23.005305750018564, 23.169378952447968, 23.332955706220982, 23.49604245571462], [0.0, 0.9361145049580709, 1.5207224998320483, 2.0198255098866538, 2.470420989362853, 2.888071744712541, 3.28121622125378, 3.6550860232907794, 4.013210737237439, 4.358115453591451, 4.691686390982991, 5.015380120889429, 5.33035147735267, 5.6375359096612305, 5.937704762612238, 6.231503681928875, 6.519480076807369, 6.802103245787268, 7.0797794415535975, 7.3528633573276405, 7.621667028055745, 7.886466828119015, 8.14750904365973, 8.40501436129921, 8.659181521801411, 8.910190322262483, 9.158204104333329, 9.403371832796815, 9.645829844575246, 9.885703330296185, 10.123107597098867, 10.358149151178065, 10.590926630767042, 10.821531614238383, 11.050049323306473, 11.276559237625145, 11.501135634151042, 11.723848062311044, 11.944761764138663, 12.163938047029662, 12.381434615535174, 12.597305867602804, 12.81160315984726, 13.024375045746918, 13.235667490093434, 13.445524062546502, 13.653986112747715, 13.861092929112203, 14.066881883133663, 14.271388560797902, 14.474646882495684, 14.676689212650658, 14.877546460128519, 15.07724817036458, 15.275822610035881, 15.473296845007766, 15.66969681220148, 15.865047385956702, 16.05937243939979, 16.25269490127293, 16.445036808631137, 16.636419355771217, 16.82686293971938, 17.01638720257107, 17.2050110709472, 17.392752792805165, 17.579629971819777, 17.765659599528952, 17.950858085420563, 18.13524128512058, 18.318824526828138, 18.5016226361299, 18.683649959314554, 18.8649203852976, 19.04544736625711, 19.225243937072683, 19.404322733651934, 19.582696010222016, 19.76037565565726, 19.937373208908323, 20.11369987359298, 20.289366531804074, 20.46438375718569, 20.638761827324814, 20.812510735502112, 20.985640201842163, 21.158159683900575, 21.330078386722608, 21.501405272405428, 21.672149069193907, 21.842318280137647, 22.011921191335, 22.18096587978819, 22.34946022089182, 22.517411895575723, 22.684828397121468, 22.851717037670866, 23.018084954443346, 23.18393911567813, 23.349286326316026, 23.514133233434865, 23.678486331451452], [0.0, 0.9433035723489465, 1.5324011742636585, 2.0353371397476128, 2.4893930519495324, 2.9102512348202727, 3.30641493830569, 3.6831559437991275, 4.04403094383714, 4.391584420824779, 4.72771707896292, 5.053896675743523, 5.3712869139737025, 5.6808304269007115, 5.983304483009108, 6.279359686379829, 6.569547650140973, 6.854341276898481, 7.134149939231276, 7.409331054293938, 7.680199053363868, 7.947032433291207, 8.21007937161898, 8.46956224977292, 8.725681334784058, 8.978617804534155, 9.22853625508704, 9.475586795228644, 9.719906808906309, 9.961622448172564, 10.20084990568951, 10.437696505586269, 10.672261643606964, 10.90463760141752, 11.134910255208501, 11.363159695012692, 11.589460768210593, 11.813883558346985, 12.03649380849385, 12.257353296868619, 12.476520171175387, 12.694049247121024, 12.909992275723017, 13.12439818333531, 13.337313287744825, 13.548781493212653, 13.758844466932729, 13.96754179904296, 14.174911148038454, 14.380988373194294, 14.58580765539926, 14.78940160762568, 14.991801376109695, 15.193036733186347, 15.393136162611937, 15.592126938109212, 15.790035195786881, 15.986886001011795, 16.18270341024847, 16.377510528324688, 16.57132956153317, 16.764181866936305, 16.956087998203106, 17.14706774827418, 17.337140189120984, 17.526323708839538, 17.714636046295386, 17.902094323516152, 18.088715076009453, 18.27451428116753, 18.4595073849053, 18.64370932666531, 18.827134562911265, 19.00979708922121, 19.19171046108174, 19.37288781347627, 19.553341879352242, 19.733085007045453, 19.912129176733078, 20.09048601598132, 20.268166814448236, 20.44518253779775, 20.62154384087624, 20.797261080199345, 20.97234432579302, 21.146803372429364, 21.32064775029506, 21.493886735127248, 21.666529357849196, 21.838584413735987, 22.010060471137983, 22.18096587978819, 22.351308778717684, 22.52109710380165, 22.690338594957062, 22.859040803011553, 23.027211096261908, 23.194856666739163, 23.361984536196452, 23.52860156183441, 23.69471444177835, 23.86032972032016], [0.0, 0.9504692347797457, 1.5440418272254517, 2.0507982694452167, 2.5083033484762676, 2.9323585166633914, 3.3315316176001963, 3.7111344789673306, 4.074750811176436, 4.424944425407002, 4.7636304642709115, 5.092287834857166, 5.412089079864651, 5.723983993111023, 6.028755747482927, 6.327059889276466, 6.61945222186515, 6.9064092401877994, 7.188343426560006, 7.465614913201522, 7.73854051991923, 8.007400859122326, 8.27244599359688, 8.533899994055377, 8.791964648826951, 9.04682251208365, 9.298639430218325, 9.547566652295515, 9.79374260587887, 10.037294401315844, 10.278339113908455, 10.516984883057287, 10.753331859551153, 10.987473026059645, 11.219494911118776, 11.449478213153112, 11.677498348109918, 11.903625931912988, 12.127927207041573, 12.35046442100196, 12.571296163208448, 12.790477665767106, 13.008061072814177, 13.224095682365228, 13.438628164053213, 13.65170275565128, 13.863361440871888, 14.07364411059341, 14.282588709378, 14.490231368900282, 14.696606529698968, 14.901747052485888, 15.10568432009483, 15.308448331021868, 15.51006778539583, 15.710570164120162, 15.909981801842555, 16.108327954335113, 16.305632860803644, 16.501919801588233, 16.697211151668338, 16.89152843034204, 17.08489234741117, 17.27732284617041, 17.468839143468557, 17.659459767083998, 17.849202590632892, 18.038084866207736, 18.226123254925632, 18.413333855548647, 18.59973223132425, 18.785333435180195, 18.970152033396527, 19.15420212786656, 19.337497377049107, 19.520051015705473, 19.70187587350701, 19.882984392591773, 20.063388644142535, 20.24310034405254, 20.422130867740023, 20.600491264167903, 20.778192269120485, 20.955244317785116, 21.13165755668316, 21.307441854991225, 21.482606815290605, 21.657161783780175, 21.831115859985243, 22.004477905992854, 22.177256555241556, 22.34946022089182, 22.52109710380165, 22.6921752001299, 22.86270230858864, 23.03268603736423, 23.20213381072559, 23.371052875336947, 23.539450306291098, 23.707333012878376, 23.874707744105372, 24.041581093976713], [0.0, 0.9576118189020935, 1.5556449893645576, 2.066209603785641, 2.5271527409818653, 2.9543945980174655, 3.3565674040983096, 3.739022904216057, 4.105371739641498, 4.458196988076752, 4.799428184043207, 5.130555348317614, 5.452759835020162, 5.7669985754770074, 6.074060627960688, 6.374606465065173, 6.6691960669139485, 6.958309509208956, 7.242362373986987, 7.521717499788612, 7.796694087257502, 8.067574857548372, 8.334611752618567, 8.59803052702667, 8.858034485500315, 9.114807554069236, 9.368516825428392, 9.619314685248467, 9.867340601348257, 10.11272263928378, 10.355578754154276, 10.59601789800606, 10.834140974240873, 11.070041664274267, 11.303807146886712, 11.535518726935113, 11.765252387102331, 11.993079273976555, 12.219066127835866, 12.44327566396398, 12.665766912062798, 12.886595519296499, 13.105814021653961, 13.323472087615375, 13.53961673752655, 13.754292541598558, 13.96754179904296, 14.179404700510023, 14.38991947570761, 14.599122527832572, 14.807048556237309, 15.013730668575253, 15.219200483515849, 15.423488224987794, 15.626622808795592, 15.828631922356113, 16.029542098216606, 16.229378781941193, 16.42816639488841, 16.6259283923454, 16.82268731743506, 17.01846485116865, 17.213281858977968, 17.40715843402753, 17.600113937576857, 17.792167036636858, 17.983335739140287, 18.173637426825646, 18.363088886014946, 18.551706336449207, 18.73950545833055, 18.926501417706447, 19.11270889031958, 19.29814208403615, 19.482814759955517, 19.66674025229555, 19.849931487139983, 20.03240100012702, 20.21416095315194, 20.39522315015055, 20.57559905202505, 20.75529979076909, 20.934336182844216, 21.1127187418561, 21.290457690575167, 21.467562972342883, 21.644044261902007, 21.819910975686206, 21.995172281601878, 22.169837108332864, 22.343914154196252, 22.517411895575723, 22.690338594957062, 22.86270230858864, 23.034510893788276, 23.205772015916306, 23.376493155033543, 23.546681612261413, 23.71634451586062, 23.885488827043403, 24.054121345533783, 24.222248714888998], [0.0, 0.9647316433873819, 1.5672111783641802, 2.081571830356358, 2.5459420704451707, 2.9763604620376958, 3.3815234147891755, 3.7668224638069288, 4.135895095406491, 4.4913435924203995, 4.8351118354201414, 5.168700923456776, 5.493300993994457, 5.8098760931243785, 6.119221145751355, 6.422001535069723, 6.718781404643848, 7.010044399528795, 7.296209191605386, 7.577641317111394, 7.854662349940813, 8.127557113274419, 8.396579422252909, 8.66195670991544, 8.923893792556175, 9.18257596369116, 9.43817155834616, 9.690834095176227, 9.940704078940573, 10.187910527360028, 10.43257227252761, 10.674799076545892, 10.914692593031361, 11.152347199919, 11.387850724161744, 11.621285075116466, 11.852726800395734, 12.08224757556118, 12.309914637103502, 12.53579116659328, 12.759936632617052, 12.982407096074537, 13.20325548355863, 13.422531832833661, 13.640283513840762, 13.85655542816962, 14.07139018952558, 14.284828287375577, 14.496908235664579, 14.707666708246467, 14.917138662462628, 15.125357452121225, 15.332354930975868, 15.538161547669555, 15.742806432995206, 15.94631748022508, 16.148721419175374, 16.350043884597472, 16.550309479422207, 16.749541833326308, 16.94776365704034, 17.144996792773433, 17.34126226109146, 17.5365803045512, 17.730970428362753, 17.924451438325868, 18.11704147626192, 18.308758053142284, 18.499618080094937, 18.689637897454343, 18.878833302004608, 19.067219572552453, 19.254811493954424, 19.441623379711913, 19.627669093237774, 19.812962067889515, 19.997515325856043, 20.181341495977776, 20.36445283057344, 20.546861221340865, 20.72857821439383, 20.909615024492126, 21.08998254851748, 21.269691378244, 21.448751812448208, 21.627173868400114, 21.80496729277399, 21.982141572014495, 22.15870594219123, 22.334669398372615, 22.510040703547556, 22.684828397121468, 22.859040803011553, 23.03268603736423, 23.205772015916306, 23.37830646101993, 23.550296908350003, 23.721750713311646, 23.89267505716404, 24.063076952875896, 24.232963250727042, 24.402340643669426], [0.0, 0.9718290192035612, 1.5787408993932452, 2.096885620123363, 2.5646721575155245, 2.9982570681128595, 3.406400739660266, 3.794534371923256, 4.166322211620202, 4.524385686160655, 4.870682976933382, 5.2067262263341645, 5.5337143274774085, 5.852618418786626, 6.164239273301535, 6.4692471693338085, 6.768210400761442, 7.061616170738523, 7.3498862312476865, 7.633388807718118, 7.912447839811326, 8.187350246106496, 8.45835170902157, 8.725681334784058, 8.989545446488718, 9.250130700826244, 9.507606671236159, 9.762128005785616, 10.013836242904784, 10.262861349477147, 10.509323031824357, 10.753331859551153, 10.994990234123359, 11.23439322779927, 11.471629313660618, 11.706781003658262, 11.939925408553268, 12.171134731212865, 12.40047670277582, 12.628014969629382, 12.853809437860937, 13.07791658080124, 13.300389714415633, 13.521279244588246, 13.740632889753261, 13.958495881834153, 14.174911148038454, 14.389919475707607, 14.603559662127493, 14.815868650955647, 15.026881656709003, 15.236632278574334, 15.445152604648204, 15.652473307579388, 15.858623732471374, 16.063631977802746, 16.267524970036668, 16.47032853251527, 16.672067449169205, 16.872765523514936, 17.07244563336223, 17.271129781609833, 17.468839143468557, 17.665594110416414, 17.86141433116021, 18.056318749850934, 18.250325641776442, 18.4434526467335, 18.63571680026255, 18.827134562911265, 19.01772184767816, 19.207494045773682, 19.396466050824195, 19.58465228163322, 19.772066703604512, 19.95872284892264, 20.144633835578663, 20.329812385321347, 20.51427084060776, 20.698021180621044, 20.881075036417887, 21.063443705263264, 21.245138164205507, 21.426169082940717, 21.60654683601185, 21.78628151438437, 21.965382936437265, 22.143860658405444, 22.32172398430679, 22.498981975384996, 22.67564345909687, 22.851717037670866, 23.027211096261908, 23.20213381072559, 23.376493155033543, 23.550296908350003, 23.72355266178863, 23.89626782486708, 24.068449631675904, 24.240105146777093, 24.411241270846894, 24.58186474607622], [0.0, 0.9789042498795497, 1.5902346455359349, 2.112151628001677, 2.583343803210544, 3.0200853526810607, 3.431200442624174, 3.8221598137024344, 4.196654389539591, 4.557324682387544, 4.906143129831117, 5.244632883153513, 5.574001563800122, 5.895227380397373, 6.20911693587261, 6.51634538838116, 6.817485169164896, 7.113027028374995, 7.403395788485405, 7.688962355725952, 7.9700530281440125, 8.246956813179157, 8.519931254700309, 8.789207126902674, 9.054992254980107, 9.317474654544588, 9.576825133585318, 9.833199466057573, 10.086740220837228, 10.337578311008864, 10.585834314395003, 10.831619605582993, 11.075037331554567, 11.316183256724917, 11.555146498288524, 11.792010168910029, 12.026851940741865, 12.25974454231157, 12.49075619786258, 12.719951017148507, 12.947389342392492, 13.173128058069468, 13.397220868302307, 13.619718545946338, 13.840669156841429, 14.060118262214138, 14.278109101796003, 14.49468275987355, 14.70987831618949, 14.923732983363179, 15.13628223228466, 15.347559906753695, 15.557598328478601, 15.766428393414996, 15.974079660308242, 16.18058043220297, 16.38595783159573, 16.59023786983097, 16.793445511274392, 16.995604732739796, 17.196738578594818, 17.396869211926465, 17.59601796210794, 17.794205369073836, 17.99145122457993, 18.187774610696774, 18.38319393576225, 18.57772696799657, 18.771390866964435, 18.964202213051657, 19.156177035108538, 19.347330836398537, 19.537678618978443, 19.72723490662536, 19.916013766415706, 20.104028829052744, 20.291293308030767, 20.477820017717008, 20.66362139042562, 20.84870949255209, 21.033096039830973, 21.216792411775, 21.39980966534898, 21.582158547927854, 21.76384950958463, 21.94489271475027, 22.12529805328475, 22.30507515099547, 22.48423337963658, 22.662781866420577, 22.840729503071007, 23.018084954443346, 23.194856666739163, 23.371052875336947, 23.546681612261413, 23.721750713311646, 23.89626782486708, 24.070240410389065, 24.24367575663467, 24.416580979598198, 24.588963030195053, 24.76082869970149], [0.0, 0.9859576317579407, 1.6016928982022123, 2.127370493400611, 2.601957789583022, 3.0418462300093756, 3.455923562404388, 3.849699946222648, 4.2268928996131665, 4.590161960734892, 4.941493779344592, 5.282422481616694, 5.614164390373884, 5.937704762612238, 6.2538560131436345, 6.56329816489776, 6.866607773703904, 7.164279125756959, 7.456740104540304, 7.7443642888059046, 8.027480327704152, 8.30637931108445, 8.581320638518424, 8.852536747018174, 9.120236959238063, 9.38461064551492, 9.645829844575246, 9.90405145278562, 10.159419066285539, 10.412064541438744, 10.662109324877376, 10.909665593685553, 11.154837238058704, 11.397720712431497, 11.638405776122092, 11.87697614065387, 12.113510037837019, 12.348080720236103, 12.5807569036765, 12.81160315984726, 13.040680265760473, 13.268045515765605, 13.493753000944404, 13.71785385999016, 13.940396505075624, 14.16142682571352, 14.380988373194292, 14.59912252783257, 14.815868650955647, 15.031264223314126, 15.245344971379465, 15.458144982809026, 15.669696812201478, 15.880031578129687, 16.089179052321153, 16.29716774175484, 16.50402496435532, 16.70977691888879, 16.91444874959882, 17.11806460606137, 17.32064769868763, 17.522220350258163, 17.722804043832525, 17.922419467343445, 18.121086555153905, 18.318824526828138, 18.515651923343167, 18.71158664094608, 18.906645962842845, 19.10084658888733, 19.29420466342388, 19.48673580142293, 19.678455113036865, 19.869377226692183, 20.059516310824016, 20.24888609435008, 20.437499885972983, 20.625370592392407, 20.812510735502112, 20.99893246864061, 21.184647591958832, 21.369667566963273, 21.554003530288437, 21.73766630674824, 21.920666421712472, 22.103014112850747, 22.28471934128329, 22.465791802175133, 22.646240934807533, 22.826075932158066, 23.005305750018564, 23.18393911567813, 23.361984536196452, 23.539450306291098, 23.71634451586062, 23.89267505716404, 24.068449631675904, 24.24367575663467, 24.4183607713013, 24.592511842943573, 24.76613597256091, 24.939240000363334], [0.0, 0.9929894542366359, 1.6131161275203558, 2.1425428407451266, 2.6205148803586, 3.0635405929393285, 3.480571113382251, 3.8771558994463318, 4.257038982516893, 4.622898868505256, 4.9767363758991445, 5.3200965722183025, 5.654204455066048, 5.980052308264019, 6.298458340743998, 6.610107425340339, 6.915580229862515, 7.215374565740847, 7.509921368111848, 7.799596880080778, 8.084732094714655, 8.365620177907612, 8.642522379261822, 8.91567279352371, 9.185282236231, 9.451541428304514, 9.714623635446175, 9.974686873003098, 10.231875761238461, 10.486323096911935, 10.738151192809672, 10.987473026059643, 11.234393227799268, 11.479008940373568, 11.72141056326167, 11.961682405015218, 12.199903255391495, 12.436146889390333, 12.670482512916461, 12.90297515818243, 13.133686035660293, 13.362672848321225, 13.58999007302307, 13.815689213178862, 14.03981902623562, 14.262425728988802, 14.483553183335452, 14.70324306471345, 14.921535015173985, 15.138466782779334, 15.354074348801158, 15.568392044009045, 15.781452655180162, 15.99328752282417, 16.203926630999707, 16.41339868999671, 16.621731212570445, 16.828950584335978, 17.03508212886492, 17.24015016796735, 17.444178077590454, 17.647188339720252, 17.84920259063289, 18.050241665806848, 18.25032564177644, 18.44947387517929, 18.647705039226164, 18.845037157799688, 19.04148763736917, 19.23707329689137, 19.431810395851656, 19.625714660586, 19.818801309011963, 20.01108507388559, 20.202580224690887, 20.393300588259837, 20.58325956821235, 20.77247016329832, 20.96094498471731, 21.148696272485115, 21.335735910911, 21.52207544324462, 21.70772608554664, 21.892698739833243, 22.077004006540882, 22.26065219635393, 22.44365334143505, 22.626017206094925, 22.807753296935505, 22.98887087249842, 23.169378952447968, 23.349286326316026, 23.52860156183441, 23.707333012878376, 23.885488827043403, 24.063076952875896, 24.240105146777093, 24.416580979598198, 24.592511842943573, 24.76790495519775, 24.942767367291093, 25.117105968217807], [0.0, 1.0000000000000002, 1.6245047927124712, 2.1576692799745936, 2.639015821545789, 3.0851693136000486, 3.5051440864071943, 3.904528777122723, 4.287093850145173, 4.6555367217460795, 5.011872336272724, 5.357656669484115, 5.694123367516263, 6.022271719754775, 6.342925711719627, 6.656775051475127, 6.964404506368995, 7.266315402400413, 7.562941717125413, 7.854662349940813, 8.141810630738089, 8.424681795174465, 8.70353893728488, 8.978617804534153, 9.250130700826244, 9.518269693579395, 9.783209271758407, 10.045108566305142, 10.304113218507696, 10.56035696267624, 10.81396297513015, 11.065045030620494, 11.313708498984765, 11.560051208396867, 11.804164196559919, 12.046132367247347, 12.28603506647532, 12.523946590098145, 12.759936632617052, 12.99407068537464, 13.226410390991374, 13.457013859823746, 13.685935953338422, 13.913228538564615, 14.138940717178896, 14.363119032269173, 14.585807655399257, 14.807048556237307, 15.026881656709001, 15.245344971379463, 15.462474735549591, 15.678305522365596, 15.892870350080617, 16.106200780469585, 16.318327009279805, 16.52927794949703, 16.73908130811768, 16.94776365704034, 17.155350498622067, 17.361866326385893, 17.567334681314144, 17.771778204116572, 17.975218683822305, 18.177677103009152, 18.379173679952565, 18.579727907948822, 18.779358592042307, 18.978083883364985, 19.175921311276543, 19.372887813476268, 19.56899976424214, 19.7642730009387, 19.95872284892264, 20.15236414496384, 20.34521125928945, 20.537278116349444, 20.72857821439383, 20.919124643944212, 21.108930105235725, 21.298006924699166, 21.486367070547516, 21.674022167526235, 21.860983510881827, 22.04726207959916, 22.232868548954187, 22.417813302425138, 22.602106443002146, 22.785757803932327, 22.968776958934622, 23.151173231916342, 23.332955706220982, 23.514133233434865, 23.69471444177835, 23.874707744105372, 24.054121345533783, 24.232963250727042, 24.411241270846894, 24.588963030195053, 24.76613597256091, 24.942767367291093, 25.11886431509581, 25.294433753605844], [0.0, 1.0069895452400897, 1.6358593424538772, 2.1727504070201276, 2.6574613420197957, 3.1067332440907927, 3.52964344957217, 3.931819657651654, 4.317058686559273, 4.688076806279622, 5.0469030447046554, 5.395104253156341, 5.733922700396169, 6.064364660388113, 6.387259877936219, 6.7033028818505125, 7.013082526736545, 7.31710364263425, 7.6158032404054214, 7.909562867781352, 8.198718184477876, 8.483566489715196, 8.764372716435915, 9.041374259872418, 9.31478490783641, 9.584798070210041, 9.851589455556626, 10.115319307070942, 10.37613428400746, 10.63416905541836, 10.889547658569475, 11.142384663445645, 11.392786176371605, 11.64085070929571, 11.88666993623322, 12.13032935439633, 12.371908864393776, 12.611483281374102, 12.849122786971405, 13.084893330282988, 13.3188569847832, 13.551072266993497, 13.78159442183725, 14.010475678870618, 14.237765482968562, 14.46351070253401, 14.687755817869915, 14.91054309199333, 15.131912725866043, 15.351902999757693, 15.570550402237458, 15.787889748102117, 16.003954286387383, 16.218775799470645, 16.432384694153743, 16.644810085511054, 16.856079874198308, 17.066220817839568, 17.27525859704178, 17.483217876526556, 17.690122361816982, 17.895994851871084, 18.100857288013383, 18.304730799480375, 18.507635745864057, 18.709591756709983, 18.91061776850125, 19.11073205923798, 19.309952280802108, 19.508295489279742, 19.705778173397615, 19.902416281216244, 20.098225245209594, 20.29322000584982, 20.487415033805433, 20.68082435085197, 20.87346154958607, 21.06533981202613, 21.25647192717616, 21.44687030762309, 21.63654700523228, 21.825513726000864, 22.013781844123987, 22.201362415324628, 22.388266189494068, 22.574503622686322, 22.760084888506828, 22.945019888932638, 23.129318264598624, 23.312989404581973, 23.49604245571462, 23.678486331451452, 23.86032972032016, 24.041581093976713, 24.222248714888998, 24.402340643669426, 24.58186474607622, 24.76082869970149, 24.939240000363334, 25.117105968217807, 25.294433753605844, 25.471230342649122]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 1.5000000000000002\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.03162277660168378, 0.05318295896944987, 0.07208434242404262, 0.08944271909999156, 0.10573712634405638, 0.12123093028059738, 0.13608915892697745, 0.1504241237234557, 0.16431676725154978, 0.17782794100389224, 0.19100490227716507, 0.2038853093816547, 0.21649980734640814, 0.22887377179317678, 0.24102852568339544, 0.2529822128134703, 0.2647504402933076, 0.2763467610958144, 0.2877830431545138, 0.29906975624424403, 0.3102161981490854, 0.3212306752415084, 0.33212064831351956, 0.3428928515638559, 0.3535533905932737, 0.3641078238014289, 0.37456123052590357, 0.3849182684929582, 0.3951832225777059, 0.40536004644211027, 0.4154523982933913, 0.425463671755599, 0.43539702265375557, 0.4452553923589698, 0.45504152822405836, 0.46475800154489, 0.47440722340731084, 0.4839914587188715, 0.49351283867548723, 0.5029733718731741, 0.5123749542422491, 0.5217193779544038, 0.5310083394307343, 0.5402434465602292, 0.5494262252227059, 0.5585581251971565, 0.5676405255254853, 0.576674739392341, 0.5856620185738529, 0.5946035575013605, 0.6035004969804791, 0.6123539276009053, 0.6211648928681237, 0.629934392084505, 0.6386633830041154, 0.6473527842827907, 0.6560034777426357, 0.6646163104680073, 0.6731920967482075, 0.6817316198804996, 0.6902356338456498, 0.6987048648669425, 0.7071400128625219, 0.7155417527999327, 0.7239107359608681, 0.7322475911233669, 0.7405529256680133, 0.7488273266140879, 0.7570713615910638, 0.7652855797503654, 0.7734705126218592, 0.7816266749191567, 0.7897545652974599, 0.7978546670673515, 0.8059274488676564, 0.8139733653002305, 0.8219928575293057, 0.829986353847804, 0.837954270212839, 0.8458970107524513, 0.8538149682454624, 0.8617085245761866, 0.8695780511656082, 0.8774239093805122, 0.8852464509219427, 0.8930460181942644, 0.9008229446560112, 0.9085775551536168, 0.9163101662390513, 0.9240210864723069, 0.9317106167096201, 0.9393790503782489, 0.9470266737385726, 0.9546537661342305, 0.9622606002309622, 0.9698474422447794, 0.9774145521600455, 0.9849621839380147, 0.9924905857163351, 1.0, 1.0074906638441918], [0.0, 0.05318295896944987, 0.08944271909999157, 0.1212309302805974, 0.15042412372345573, 0.17782794100389226, 0.2038853093816547, 0.2288737717931768, 0.25298221281347033, 0.2763467610958144, 0.2990697562442441, 0.3212306752415084, 0.34289285156385596, 0.3641078238014289, 0.38491826849295824, 0.40536004644211027, 0.42546367175559907, 0.44525539235896994, 0.46475800154489005, 0.4839914587188715, 0.5029733718731741, 0.5217193779544039, 0.5402434465602292, 0.5585581251971565, 0.576674739392341, 0.5946035575013605, 0.6123539276009055, 0.6299343920845051, 0.6473527842827909, 0.6646163104680074, 0.6817316198804997, 0.6987048648669425, 0.7155417527999327, 0.7322475911233669, 0.7488273266140879, 0.7652855797503654, 0.7816266749191568, 0.7978546670673516, 0.8139733653002306, 0.8299863538478041, 0.8458970107524514, 0.8617085245761867, 0.8774239093805123, 0.8930460181942645, 0.908577555153617, 0.924021086472307, 0.939379050378249, 0.9546537661342306, 0.9698474422447795, 0.9849621839380147, 1.0000000000000002, 1.0149628090294405, 1.0298524451722681, 1.0446706633885259, 1.0594191442977765, 1.0740994986439416, 1.08871327141582, 1.1032619456555046, 1.1177469459833944, 1.132169641865399, 1.1465313506452404, 1.160833340362365, 1.175076832373886, 1.1892630037971208, 1.203392989787646, 1.2174678856663448, 1.231488748907614, 1.245456600999766, 1.2593724291876183, 1.2732371881063487, 1.2870518013148862, 1.300817162736349, 1.314534138012399, 1.3282035657777795, 1.3418262588607637, 1.3554030054147674, 1.3689345699859323, 1.3824216945211012, 1.395865099320239, 1.4092654839370378, 1.4226235280311383, 1.4359398921751472, 1.4492152186193656, 1.4624501320169423, 1.4756452401119458, 1.4888011343926701, 1.5019183907123212, 1.5149975698790703, 1.5280392182173212, 1.5410438681019072, 1.554012038466811, 1.5669442352898946, 1.5798409520550163, 1.59270267019283, 1.6055298595014649, 1.6183229785482078, 1.6310824750532382, 1.6438087862563944, 1.656502339267893, 1.6691635514038516, 1.6817928305074294, 1.6943905752563322], [0.0, 0.07208434242404262, 0.1212309302805974, 0.16431676725154984, 0.2038853093816547, 0.2410285256833955, 0.27634676109581446, 0.3102161981490854, 0.34289285156385596, 0.37456123052590357, 0.4053600464421103, 0.43539702265375557, 0.4647580015448901, 0.4935128386754873, 0.5217193779544039, 0.5494262252227059, 0.576674739392341, 0.6035004969804793, 0.6299343920845051, 0.6560034777426358, 0.6817316198804997, 0.7071400128625219, 0.7322475911233669, 0.7570713615910638, 0.7816266749191568, 0.8059274488676565, 0.8299863538478042, 0.8538149682454627, 0.8774239093805123, 0.9008229446560114, 0.924021086472307, 0.9470266737385727, 0.9698474422447794, 0.9924905857163352, 1.0149628090294405, 1.0372703747942278, 1.0594191442977765, 1.081414613627287, 1.1032619456555048, 1.124965998458558, 1.1465313506452404, 1.1679623240020884, 1.1892630037971208, 1.2104372570341972, 1.231488748907614, 1.2524209576711836, 1.273237188106349, 1.2939405837488624, 1.3145341380123992, 1.335020704329478, 1.3554030054147677, 1.375683641742718, 1.395865099320239, 1.4159497568254467, 1.4359398921751474, 1.4558376885764934, 1.4756452401119458, 1.4953645569012148, 1.5149975698790705, 1.5345461352237226, 1.5540120384668112, 1.573396998312813, 1.59270267019283, 1.6119306495752115, 1.631082475053238, 1.650159631228126, 1.6691635514038519, 1.6880956201087438, 1.706957175457394, 1.7257495113651926, 1.7444738796266865, 1.7631314918679577, 1.7817235213823162, 1.8002511048578131, 1.8187153440043329, 1.8371173070873839, 1.855458030375105, 1.873738519504476, 1.8919597507722348, 1.9101226723555578, 1.9282282054671644, 1.9462772454491515, 1.9642706628095072, 1.9822093042049869, 2.0000939933737274, 2.01792553202074, 2.035704700659191, 2.053432259410161, 2.071108948763389, 2.0887354903013233, 2.106312587388645, 2.1238409258292674, 2.1413211744926963, 2.1587539859114866, 2.1761399968514348, 2.193479828856019, 2.210774088766516, 2.228023369219118, 2.2452282491202946, 2.262389294101567, 2.279507056954778, 2.2965820780488895], [0.0, 0.08944271909999156, 0.15042412372345573, 0.2038853093816547, 0.25298221281347033, 0.2990697562442441, 0.34289285156385596, 0.3849182684929582, 0.42546367175559907, 0.46475800154489, 0.5029733718731741, 0.5402434465602292, 0.5766747393923412, 0.6123539276009053, 0.6473527842827907, 0.6817316198804996, 0.7155417527999327, 0.748827326614088, 0.7816266749191567, 0.8139733653002305, 0.8458970107524514, 0.8774239093805122, 0.9085775551536169, 0.9393790503782489, 0.9698474422447794, 1.0, 1.0298524451722681, 1.0594191442977765, 1.0887132714158199, 1.1177469459833946, 1.1465313506452404, 1.175076832373886, 1.203392989787646, 1.2314887489076138, 1.259372429187618, 1.287051801314886, 1.314534138012399, 1.341826258860764, 1.3689345699859323, 1.395865099320239, 1.4226235280311386, 1.4492152186193656, 1.4756452401119458, 1.5019183907123212, 1.5280392182173215, 1.554012038466811, 1.5798409520550163, 1.6055298595014649, 1.631082475053238, 1.6565023392678928, 1.6817928305074294, 1.7069571754573938, 1.7319984587712658, 1.7569196319282625, 1.7817235213823162, 1.8064128360710052, 1.830990174345415, 1.8554580303751047, 1.8798188000764475, 1.9040747866073917, 1.9282282054671644, 1.952281189235416, 1.9762357919817817, 2.0000939933737274, 2.023857702507763, 2.047528761486697, 2.071108948763389, 2.0945999822695587, 2.1180035223464615, 2.1413211744926963, 2.1645544919430475, 2.1877049780910074, 2.210774088766516, 2.2337632343794724, 2.256673781938638, 2.279507056954778, 2.302264345236112, 2.3249468945835194, 2.3475559163923188, 2.370092587166893, 2.392558049953953, 2.4149534156997734, 2.4372797645363056, 2.4595381470007367, 2.481729585192684, 2.50385507387292, 2.5259155815072374, 2.5479120512587983, 2.569845401932068, 2.5917165288712236, 2.6135263048157182, 2.635275580715491, 2.6569651865081574, 2.6785959318603396, 2.7001686068751636, 2.721683982767804, 2.7431428125108486, 2.764545831451123, 2.7858937578995273, 2.8071872936953164, 2.8284271247461907, 2.8496139215454583], [0.0, 0.10573712634405638, 0.17782794100389226, 0.2410285256833955, 0.2990697562442441, 0.35355339059327373, 0.4053600464421103, 0.4550415282240584, 0.5029733718731741, 0.5494262252227059, 0.5946035575013605, 0.6386633830041154, 0.6817316198804997, 0.7239107359608681, 0.7652855797503654, 0.8059274488676564, 0.8458970107524513, 0.8852464509219428, 0.924021086472307, 0.9622606002309622, 1.0, 1.0372703747942278, 1.0740994986439416, 1.1105123182107506, 1.1465313506452404, 1.1821770112539698, 1.2174678856663448, 1.2524209576711836, 1.287051801314886, 1.3213747439409018, 1.3554030054147674, 1.3891488176895426, 1.4226235280311383, 1.4558376885764934, 1.48880113439267, 1.52152305180747, 1.5540120384668112, 1.5862761563221133, 1.6183229785482078, 1.6501596312281257, 1.6817928305074294, 1.71322891581121, 1.7444738796266865, 1.775533394279664, 1.8064128360710054, 1.8371173070873839, 1.8676516549570252, 1.8980204907844478, 1.9282282054671647, 1.958278984570927, 1.988176821917627, 2.01792553202074, 2.047528761486697, 2.0769899994863783, 2.106312587388645, 2.135499727637228, 2.1645544919430475, 2.1934798288560184, 2.2222785707733985, 2.2509534404355667, 2.279507056954778, 2.3079419414176696, 2.3362605220981445, 2.36446513931357, 2.392558049953953, 2.4205414317108858, 2.4484173870304544, 2.4761879468120447, 2.50385507387292, 2.531420666196616, 2.558886559981587, 2.5862545325050585, 2.6135263048157182, 2.6407035442677254, 2.667787866907412, 2.694780839723132, 2.721683982767804, 2.748498771162943, 2.775226636992245, 2.801868971092146, 2.8284271247461903, 2.854902411289524, 2.881296107629309, 2.9076094556864582, 2.9338436637636414, 2.959999907844176, 2.9860793328260593, 3.0120830536950978, 3.038012156640809, 3.063867700118496, 3.089650715860677, 3.1153622098408085, 3.14100316319206, 3.1665745330836983, 3.192077253557476, 3.217512236326243, 3.242880371536884, 3.2681825284995094, 3.293419556384754, 3.318592284890849, 3.343701524882111, 3.368748069000314], [0.0, 0.12123093028059738, 0.2038853093816547, 0.27634676109581446, 0.34289285156385596, 0.4053600464421103, 0.4647580015448901, 0.5217193779544039, 0.576674739392341, 0.629934392084505, 0.6817316198804997, 0.7322475911233669, 0.7816266749191569, 0.8299863538478041, 0.8774239093805122, 0.924021086472307, 0.9698474422447794, 1.0149628090294405, 1.0594191442977765, 1.1032619456555046, 1.1465313506452404, 1.1892630037971206, 1.2314887489076138, 1.2732371881063487, 1.314534138012399, 1.3554030054147674, 1.3958650993202393, 1.4359398921751474, 1.4756452401119458, 1.5149975698790705, 1.5540120384668112, 1.59270267019283, 1.631082475053238, 1.6691635514038516, 1.706957175457394, 1.7444738796266865, 1.7817235213823162, 1.818715344004333, 1.8554580303751051, 1.8919597507722348, 1.9282282054671647, 1.9642706628095072, 2.0000939933737274, 2.035704700659191, 2.071108948763389, 2.106312587388645, 2.1413211744926963, 2.1761399968514348, 2.210774088766516, 2.2452282491202946, 2.2795070569547784, 2.313614885729254, 2.3475559163923188, 2.381334149387774, 2.414953415699774, 2.448417387030454, 2.481729585192684, 2.5148933907913817, 2.5479120512587987, 2.5807886883021407, 2.6135263048157182, 2.646127791304399, 2.67859593186034, 2.710933409730774, 2.7431428125108486, 2.7752266369922456, 2.807187293695317, 2.839027111109878, 2.870748339667457, 2.90235315546568, 2.933843663763642, 2.965221902265399, 2.9964898442072294, 3.0276494012629485, 3.0587024262803397, 3.0896507158606776, 3.1204960127922874, 3.1512400083482324, 3.1818843444573672, 3.212430615757268, 3.2428803715368835, 3.273235117576131, 3.3034963178891052, 3.3336653963770666, 3.363743738396908, 3.3937326922503703, 3.4236335705989, 3.4534476518086805, 3.483176181230046, 3.5128203724151854, 3.542381408277776, 3.5718604421979228, 3.601258599075565, 3.630576976335274, 3.6598166448852028, 3.6889786500327153, 3.718064012359122, 3.747073728555719, 3.77600877222326, 3.804870094636779, 3.833658625477636, 3.862375273534475], [0.0, 0.13608915892697745, 0.2288737717931768, 0.3102161981490854, 0.3849182684929582, 0.4550415282240584, 0.5217193779544039, 0.5856620185738528, 0.6473527842827907, 0.7071400128625218, 0.7652855797503654, 0.8219928575293056, 0.8774239093805122, 0.9317106167096201, 0.9849621839380146, 1.0372703747942278, 1.0887132714158199, 1.1393580392666962, 1.1892630037971206, 1.2384792388616033, 1.287051801314886, 1.3350207043294777, 1.382421694521101, 1.4292868795355163, 1.4756452401119455, 1.52152305180747, 1.5669442352898946, 1.6119306495752113, 1.6565023392678926, 1.7006777444011336, 1.7444738796266863, 1.7879064881017699, 1.8309901743454147, 1.8737385195044758, 1.9161641818197315, 1.9582789845709268, 2.000093993373727, 2.0416195843772296, 2.0828655046497424, 2.123840925829267, 2.1645544919430475, 2.2050143621595666, 2.245228249120294, 2.285203453402375, 2.3249468945835194, 2.3644651393135696, 2.403764426741167, 2.442850691596687, 2.481729585192684, 2.520406494569097, 2.558886559981587, 2.5971746909065927, 2.6352755807154904, 2.673193720151947, 2.7109334097307736, 2.748498771162943, 2.785893757899527, 2.8231221648770064, 2.8601876375373725, 2.8970936801885356, 2.9338436637636414, 2.9704408330317866, 3.006888313307273, 3.043189116699783, 3.0793461479436663, 3.1153622098408085, 3.1512400083482324, 3.186982157338651, 3.2225911830595586, 3.258069528314083, 3.2934195563847535, 3.3286435547194233, 3.363743738396908, 3.3987222533883794, 3.4335811796291815, 3.468322533914498, 3.502948272631175, 3.5374602943370164, 3.5718604421979223, 3.606150506292433, 3.6403322257924677, 3.6744072910283925, 3.7083773454458715, 3.7422439874614506, 3.776008772223259, 3.809673213282743, 3.843238784182932, 3.876706919968318, 3.910079018621074, 3.943356442428007, 3.9765405192823113, 4.009632543923936, 4.042633779122095, 4.0755454568032174, 4.1083687791274235, 4.141104919516378, 4.173755023635232, 4.206320210331132, 4.23880157253067, 4.27120017809845, 4.3035170706588515, 4.335753270382898], [0.0, 0.1504241237234557, 0.25298221281347033, 0.34289285156385596, 0.42546367175559907, 0.5029733718731741, 0.576674739392341, 0.6473527842827907, 0.7155417527999327, 0.7816266749191566, 0.8458970107524513, 0.9085775551536168, 0.9698474422447794, 1.029852445172268, 1.0887132714158199, 1.1465313506452401, 1.203392989787646, 1.259372429187618, 1.3145341380123987, 1.368934569985932, 1.4226235280311383, 1.4756452401119455, 1.528039218217321, 1.579840952055016, 1.6310824750532378, 1.6817928305074292, 1.7319984587712658, 1.781723521382316, 1.8309901743454147, 1.8798188000764475, 1.9282282054671644, 1.9762357919817815, 2.023857702507763, 2.0711089487633885, 2.118003522346461, 2.164554491943047, 2.2107740887665157, 2.2566737819386384, 2.302264345236112, 2.3475559163923183, 2.392558049953953, 2.4372797645363056, 2.481729585192684, 2.525915581507238, 2.569845401932068, 2.6135263048157182, 2.6569651865081574, 2.7001686068751636, 2.743142812510848, 2.7858937578995273, 2.8284271247461907, 2.8707483396674567, 2.912862590411432, 2.954774840754703, 2.9964898442072294, 3.0380121566408085, 3.0793461479436663, 3.1204960127922865, 3.1614657806216475, 3.2022593248662745, 3.242880371536883, 3.28333250719064, 3.3236191863471314, 3.363743738396908, 3.4037093740447935, 3.4435191913260828, 3.483176181230046, 3.5226832329619318, 3.56204313887176, 3.601258599075564, 3.640332225792468, 3.679266547418868, 3.7180640123591213, 3.7567269926304827, 3.795257787258487, 3.8336586254776357, 3.871931669750973, 3.910079018621074, 3.948102709403899, 3.9860047207360845, 4.023786974985394, 4.0614513405333055, 4.098999633937994, 4.136433621985367, 4.173755023635232, 4.2109655118691265, 4.2480667154458756, 4.285060220570524, 4.321947572481834, 4.358730276963224, 4.395409801781648, 4.431987578058614, 4.468465001577253, 4.504843434029086, 4.541124204203883, 4.577308609125798, 4.61339791513873, 4.649393358943698, 4.685296148590824, 4.721107464428336, 4.756828460010885, 4.792460262969311], [0.0, 0.16431676725154978, 0.2763467610958144, 0.37456123052590357, 0.46475800154489, 0.5494262252227059, 0.629934392084505, 0.7071400128625218, 0.7816266749191566, 0.8538149682454623, 0.9240210864723069, 0.992490585716335, 1.0594191442977765, 1.124965998458558, 1.1892630037971206, 1.252420957671183, 1.3145341380123987, 1.375683641742718, 1.435939892175147, 1.4953645569012146, 1.554012038466811, 1.611930649575211, 1.6691635514038514, 1.7257495113651922, 1.781723521382316, 1.8371173070873836, 1.8919597507722345, 1.9462772454491513, 2.000093993373727, 2.053432259410161, 2.106312587388645, 2.158753985911486, 2.2107740887665157, 2.262389294101567, 2.313614885729254, 2.3644651393135696, 2.4149534156997734, 2.465092243257425, 2.5148933907913817, 2.5643679323204607, 2.6135263048157182, 2.662378359820063, 2.710933409730773, 2.7592002694104365, 2.8071872936953164, 2.8549024112895234, 2.9023531554656796, 2.9495466919357165, 2.996489844207229, 3.0431891166997826, 3.089650715860677, 3.135880569489774, 3.1818843444573663, 3.227667462977007, 3.2732351175761307, 3.3185922848908485, 3.3637437383969075, 3.408694060176373, 3.45344765180868, 3.498008744465156, 3.5423814082777754, 3.586569561045522, 3.6305769763352735, 3.674407291028393, 3.718064012359121, 3.7615505244864065, 3.804870094636779, 3.8480258788523325, 3.891020927374724, 3.9338581896932157, 3.9765405192823113, 4.0190706780522145, 4.061451340533306, 4.1036850978140205, 4.145774461249813, 4.187721865959449, 4.229529674123464, 4.27120017809845, 4.3127356033597115, 4.354138111283812, 4.395409801781648, 4.436552715791846, 4.47756883764351, 4.518460097296687, 4.559228372468273, 4.599875490650501, 4.640403231028639, 4.680813326304055, 4.721107464428336, 4.7612872902537635, 4.801354407105093, 4.841310378277184, 4.881156728462794, 4.9208949451144886, 4.960526479744393, 5.000052749165253, 5.0394751366760415, 5.078794993195139, 5.118013638343931, 5.15713236148346, 5.196152422706633, 5.235075053788311], [0.0, 0.17782794100389224, 0.2990697562442441, 0.4053600464421103, 0.5029733718731741, 0.5946035575013605, 0.6817316198804997, 0.7652855797503654, 0.8458970107524513, 0.9240210864723069, 1.0, 1.0740994986439416, 1.1465313506452404, 1.2174678856663446, 1.287051801314886, 1.3554030054147672, 1.4226235280311383, 1.4888011343926701, 1.554012038466811, 1.6183229785482076, 1.6817928305074292, 1.7444738796266863, 1.8064128360710052, 1.867651654957025, 1.9282282054671644, 1.9881768219176268, 2.047528761486697, 2.106312587388645, 2.1645544919430475, 2.2222785707733985, 2.279507056954778, 2.3362605220981445, 2.392558049953953, 2.448417387030454, 2.50385507387292, 2.5588865599815867, 2.6135263048157182, 2.667787866907412, 2.721683982767804, 2.775226636992245, 2.8284271247461907, 2.881296107629309, 2.9338436637636414, 2.9860793328260593, 3.038012156640809, 3.089650715860677, 3.14100316319206, 3.192077253557476, 3.2428803715368835, 3.2934195563847535, 3.343701524882111, 3.39373269225037, 3.4435191913260828, 3.4930668901718196, 3.542381408277776, 3.591468131490858, 3.640332225792468, 3.688978650032715, 3.737412167716998, 3.7856373579305673, 3.8336586254776357, 3.881480210303634, 3.929106196262203, 3.976540519282312, 4.023786974985394, 4.070849225797556, 4.117730807597551, 4.164435135937408, 4.2109655118691265, 4.2573251274078086, 4.3035170706588515, 4.34954433063435, 4.395409801781649, 4.441116288245018, 4.486666507879593, 4.532063096035153, 4.577308609125798, 4.622405528000317, 4.667356261126802, 4.712163147603999, 4.756828460010885, 4.801354407105093, 4.845743136379934, 4.889996736489094, 4.934117239547341, 4.978106623314987, 5.0219668132732735, 5.065699684597339, 5.109307064032925, 5.152790731682573, 5.196152422706633, 5.239393828944053, 5.282516600457563, 5.325522347007574, 5.368412639458809, 5.411189011123401, 5.453852959043999, 5.496405945220117, 5.538849397780837, 5.5811847121066975, 5.623413251903492, 5.665536350230474], [0.0, 0.19100490227716507, 0.3212306752415084, 0.43539702265375557, 0.5402434465602292, 0.6386633830041154, 0.7322475911233669, 0.8219928575293056, 0.9085775551536168, 0.992490585716335, 1.0740994986439416, 1.1536897329871667, 1.2314887489076138, 1.3076816456093203, 1.382421694521101, 1.4558376885764932, 1.528039218217321, 1.5991205520316985, 1.6691635514038514, 1.7382398999026, 1.8064128360710052, 1.8737385195044756, 1.9402671215678473, 2.0060437062308685, 2.0711089487633885, 2.135499727637228, 2.199249616171912, 2.262389294101567, 2.324946894583519, 2.3869482987148825, 2.448417387030454, 2.50937625548725, 2.5698454019320676, 2.6298438878805204, 2.6893894795239928, 2.7484987711629425, 2.8071872936953164, 2.865469610333642, 2.9233594013581445, 2.9808695394166826, 3.038012156640809, 3.094798704649381, 3.151240008348232, 3.207346314299506, 3.2631273343220926, 3.3185922848908485, 3.373749922823626, 3.428608577678815, 3.4831761812300455, 3.5374602943370164, 3.5914681314908585, 3.6452065832776763, 3.6986822369741366, 3.7519013954633036, 3.8048700946367786, 3.8575941194300243, 3.910079018621074, 3.9623301185083437, 4.014352535570595, 4.066151188200998, 4.1177308075975505, 4.169095947883514, 4.220250995524037, 4.27120017809845, 4.321947572481834, 4.372497112484233, 4.422852595991243, 4.473017691645585, 4.522995945105558, 4.572790784912982, 4.622405528000317, 4.671843384863954, 4.721107464428336, 4.770200778623417, 4.819126246696035, 4.8678866992740675, 4.916484882200617, 4.964923460154124, 5.01320502006896, 5.061332074369913, 5.109307064032924, 5.15713236148346, 5.204810273343008, 5.252343043033446, 5.299732853248228, 5.346981828298712, 5.394092036343336, 5.441065491506775, 5.4879041558957145, 5.534609941517401, 5.581184712106697, 5.627630284866968, 5.673948432129767, 5.720140882937943, 5.766209324556506, 5.812155403915251, 5.857980728986937, 5.903686870104507, 5.949275361220694, 5.9947477011130355, 6.040105354537238, 6.085349753331579], [0.0, 0.2038853093816547, 0.34289285156385596, 0.4647580015448901, 0.5766747393923412, 0.6817316198804997, 0.7816266749191569, 0.8774239093805122, 0.9698474422447794, 1.0594191442977765, 1.1465313506452404, 1.2314887489076138, 1.3145341380123992, 1.395865099320239, 1.4756452401119458, 1.554012038466811, 1.631082475053238, 1.7069571754573942, 1.7817235213823162, 1.855458030375105, 1.9282282054671647, 2.000093993373727, 2.071108948763389, 2.1413211744926963, 2.210774088766516, 2.279507056954778, 2.347555916392319, 2.414953415699774, 2.481729585192684, 2.547912051258799, 2.6135263048157182, 2.67859593186034, 2.7431428125108486, 2.807187293695317, 2.870748339667457, 2.9338436637636414, 2.9964898442072294, 3.05870242628034, 3.1204960127922874, 3.1818843444573672, 3.242880371536884, 3.3034963178891052, 3.363743738396908, 3.4236335705989, 3.4831761812300464, 3.542381408277776, 3.601258599075565, 3.6598166448852028, 3.7180640123591218, 3.7760087722232596, 3.8336586254776366, 3.8910209273747243, 3.9481027094038996, 4.004910699482866, 4.061451340533307, 4.117730807597551, 4.173755023635232, 4.229529674123464, 4.285060220570525, 4.3403519130412125, 4.395409801781649, 4.450238748022197, 4.504843434029087, 4.559228372468274, 4.61339791513873, 4.667356261126803, 4.721107464428337, 4.774655441080812, 4.828003975843836, 4.881156728462795, 4.934117239547342, 4.986888936093549, 5.039475136676042, 5.091879056334137, 5.144103811173954, 5.196152422706634, 5.248027821941088, 5.299732853248229, 5.351270278012231, 5.402642778083139, 5.453852959043998, 5.504903353304679, 5.555796423033589, 5.606534562937658, 5.657120102900177, 5.707555310485349, 5.75784239331778, 5.807983501344555, 5.857980728986937, 5.907836117188296, 5.957551655364374, 6.007129283261563, 6.056570892728513, 6.105878329406004, 6.155053394339688, 6.204097845519995, 6.253013399353257, 6.30180173206775, 6.350464481058239, 6.399003246172259, 6.447419590941254, 6.495715043759451], [0.0, 0.21649980734640814, 0.3641078238014289, 0.4935128386754873, 0.6123539276009053, 0.7239107359608681, 0.8299863538478041, 0.9317106167096201, 1.029852445172268, 1.124965998458558, 1.2174678856663446, 1.3076816456093203, 1.395865099320239, 1.4822280526288794, 1.5669442352898943, 1.6501596312281257, 1.7319984587712656, 1.8125675692666994, 1.8919597507722345, 1.9702562550183473, 2.047528761486697, 2.123840925829267, 2.1992496161719117, 2.2738059115217784, 2.3475559163923183, 2.4205414317108858, 2.4928005120882384, 2.564367932320461, 2.635275580715491, 2.7055527929211154, 2.775226636992245, 2.8443221582045783, 2.912862590411432, 2.9808695394166826, 3.0483631428030127, 3.115362209840808, 3.181884344457367, 3.2479460537300944, 3.3135628439522744, 3.3787493059838685, 3.443519191326083, 3.507885480134123, 3.5718604421979223, 3.6354556917677114, 3.6986822369741374, 3.7615505244864065, 3.8240704799627374, 3.8862515447722528, 3.9481027094038996, 4.009632543923936, 4.070849225797556, 4.131760565350809, 4.192374029115246, 4.252696761268599, 4.3127356033597115, 4.372497112484232, 4.431987578058615, 4.491213037323615, 4.550179289694083, 4.6088919100592545, 4.667356261126802, 4.725577504894123, 4.783560613321877, 4.841310378277184, 4.8988314208072445, 4.956128199798226, 5.01320502006896, 5.0700660399443525, 5.126715278349201, 5.183156621459386, 5.239393828944053, 5.295430539829438, 5.3512702780122305, 5.406916457448026, 5.46237238703817, 5.517641275236385, 5.572726234394742, 5.627630284866969, 5.682356358885623, 5.736907304228307, 5.791285887686946, 5.845494798353022, 5.8995366507306795, 5.953413987688702, 6.007129283261562, 6.060684945308923, 6.114083318042362, 6.167326684427391, 6.2204172684682835, 6.273357237382719, 6.326148703672699, 6.3787937270978095, 6.431294316556436, 6.48365243188018, 6.535869985546396, 6.587948844313365, 6.639890830782434, 6.691697724891061, 6.743371265340541, 6.794913150961867, 6.8463250420230475, 6.897608561480914], [0.0, 0.22887377179317678, 0.38491826849295824, 0.5217193779544039, 0.6473527842827907, 0.7652855797503654, 0.8774239093805122, 0.9849621839380146, 1.0887132714158199, 1.1892630037971206, 1.287051801314886, 1.382421694521101, 1.4756452401119458, 1.5669442352898943, 1.6565023392678926, 1.7444738796266863, 1.8309901743454147, 1.9161641818197317, 2.000093993373727, 2.082865504649742, 2.1645544919430475, 2.245228249120294, 2.324946894583519, 2.403764426741167, 2.481729585192684, 2.5588865599815867, 2.635275580715491, 2.7109334097307736, 2.785893757899527, 2.860187637537373, 2.9338436637636414, 3.0068883133072726, 3.0793461479436663, 3.151240008348232, 3.2225911830595586, 3.293419556384753, 3.363743738396908, 3.433581179629182, 3.5029482726311754, 3.5718604421979223, 3.6403322257924686, 3.7083773454458715, 3.776008772223259, 3.8432387841829323, 3.9100790186210745, 3.9765405192823113, 4.042633779122095, 4.1083687791274235, 4.173755023635232, 4.23880157253067, 4.3035170706588515, 4.367909774742056, 4.431987578058614, 4.495758033109027, 4.559228372468274, 4.622405528000317, 4.685296148590824, 4.747906616536762, 4.810243062716335, 4.872311380649462, 4.934117239547341, 4.995666096439375, 5.056963207456748, 5.118013638343931, 5.178822274262328, 5.239393828944053, 5.299732853248228, 5.359843743167243, 5.41973074732602, 5.479397974013346, 5.538849397780836, 5.59808886564189, 5.657120102900177, 5.715946718634631, 5.774572210865599, 5.832999971424763, 5.8912332905494935, 5.949275361220694, 6.007129283261562, 6.064798067213349, 6.122284638002925, 6.179591838415775, 6.2367224323870385, 6.293679108122202, 6.350464481058237, 6.407081096675118, 6.463531433166944, 6.519817903981255, 6.575942860234448, 6.631908593010705, 6.68771733555128, 6.74337126534054, 6.798872506094694, 6.854223129658777, 6.909425157817061, 6.96448056402169, 7.0193912750441, 7.074159172553399, 7.128786094625697, 7.183273837188028, 7.23762415540039, 7.291838764979096], [0.0, 0.24102852568339544, 0.40536004644211027, 0.5494262252227059, 0.6817316198804996, 0.8059274488676564, 0.924021086472307, 1.0372703747942278, 1.1465313506452401, 1.252420957671183, 1.3554030054147672, 1.4558376885764932, 1.554012038466811, 1.6501596312281257, 1.7444738796266863, 1.8371173070873834, 1.9282282054671642, 2.01792553202074, 2.1063125873886444, 2.1934798288560184, 2.279507056954778, 2.3644651393135696, 2.4484173870304535, 2.5314206661966154, 2.613526304815718, 2.6947808397231316, 2.775226636992245, 2.854902411289524, 2.933843663763641, 3.0120830536950978, 3.089650715860677, 3.1665745330836983, 3.242880371536883, 3.3185922848908485, 3.39373269225037, 3.4683225339144976, 3.5423814082777754, 3.6159276926153576, 3.6889786500327153, 3.761550524486406, 3.8336586254776357, 3.9053174037706357, 3.9765405192823113, 4.047340902119363, 4.117730807597551, 4.187721865959449, 4.2573251274078086, 4.326551102987919, 4.395409801781649, 4.463910764815664, 4.532063096035153, 4.599875490650501, 4.667356261126802, 4.734513361053699, 4.801354407105093, 4.8678866992740675, 4.934117239547341, 5.000052749165253, 5.065699684597339, 5.13106425234951, 5.196152422706633, 5.260969942503488, 5.325522347007574, 5.389814970988844, 5.4538529590439975, 5.517641275236385, 5.5811847121066975, 5.644487899104417, 5.707555310485348, 5.770391272716351, 5.832999971424762, 5.89538545792656, 5.957551655364373, 6.019502364483773, 6.081241269073779, 6.142771941095401, 6.204097845519994, 6.265222344897463, 6.326148703672698, 6.38688009226717, 6.447419590941252, 6.50777019345168, 6.567934810517342, 6.627916273105721, 6.68771733555128, 6.7473406785162915, 6.806788911803816, 6.866064577031872, 6.925170150177127, 6.984108043995916, 7.042880610329794, 7.101490142302354, 7.15993887641358, 7.21822899453757, 7.276362625829092, 7.33434184854402, 7.3921686917784575, 7.44984513713094, 7.50737312029192, 7.56475453256437, 7.621991222319223, 7.679084996388996], [0.0, 0.2529822128134703, 0.42546367175559907, 0.576674739392341, 0.7155417527999327, 0.8458970107524513, 0.9698474422447794, 1.0887132714158199, 1.203392989787646, 1.3145341380123987, 1.4226235280311383, 1.528039218217321, 1.631082475053238, 1.7319984587712656, 1.8309901743454147, 1.9282282054671642, 2.023857702507763, 2.1180035223464615, 2.2107740887665157, 2.3022643452361113, 2.392558049953953, 2.4817295851926837, 2.569845401932068, 2.6569651865081574, 2.743142812510848, 2.8284271247461903, 2.9128625904114323, 2.9964898442072294, 3.0793461479436663, 3.161465780621648, 3.242880371536883, 3.3236191863471314, 3.4037093740447935, 3.4831761812300455, 3.56204313887176, 3.6403322257924677, 3.7180640123591213, 3.7952577872584876, 3.8719316697509734, 3.948102709403899, 4.023786974985394, 4.098999633937994, 4.173755023635232, 4.248066715445876, 4.321947572481835, 4.395409801781649, 4.468465001577253, 4.541124204203883, 4.61339791513873, 4.685296148590824, 4.756828460010886, 4.828003975843835, 4.8988314208072445, 4.9693191429449906, 5.0394751366760415, 5.109307064032925, 5.178822274262328, 5.248027821941087, 5.31693048374406, 5.3855367739856606, 5.453852959043998, 5.5218850707652, 5.589638918935542, 5.657120102900177, 5.724334022399463, 5.791285887686946, 5.857980728986937, 5.9244234053441085, 5.990618612912705, 6.056570892728512, 6.122284638002925, 6.187764100974875, 6.2530133993532555, 6.318036522379682, 6.382837336538814, 6.447419590941253, 6.511786922401845, 6.575942860234448, 6.639890830782433, 6.703634161702714, 6.767176086019612, 6.830519745963701, 6.893668196609495, 6.956624409324867, 7.019391275044099, 7.081971607375543, 7.144368145554117, 7.206583557248091, 7.268620441228937, 7.330481329912413, 7.392168691778457, 7.453684933676962, 7.515032403025994, 7.576213389908583, 7.637230129073846, 7.6980848018477, 7.758779537958238, 7.819316417280366, 7.8796974715041195, 7.939924685730683, 8.000000000000002, 8.059925310753536], [0.0, 0.2647504402933076, 0.44525539235896994, 0.6035004969804793, 0.748827326614088, 0.8852464509219428, 1.0149628090294405, 1.1393580392666962, 1.259372429187618, 1.375683641742718, 1.4888011343926701, 1.5991205520316985, 1.7069571754573942, 1.8125675692666994, 1.9161641818197317, 2.01792553202074, 2.1180035223464615, 2.2165288177689013, 2.313614885729254, 2.4093610862762964, 2.5038550738729204, 2.5971746909065927, 2.689389479523993, 2.7805619025503665, 2.870748339667457, 2.9599999078441765, 3.0483631428030136, 3.1358805694897747, 3.222591183059559, 3.3085308571039573, 3.3937326922503703, 3.4782273155365293, 3.5620431388717604, 3.645206583277677, 3.7277422743368462, 3.8096732132827436, 3.8910209273747247, 3.971805602570757, 4.052046201003067, 4.13176056535081, 4.210965511869127, 4.2896769135597, 4.367909774742057, 4.445678298097945, 4.522995945105559, 4.5998754906505015, 4.676329072491304, 4.75236823616541, 4.828003975843836, 4.903246771576625, 4.9781066233149875, 5.052593082047841, 5.126715278349202, 5.2004819485972815, 5.273901459095457, 5.346981828298713, 5.41973074732602, 5.492155598919047, 5.564263474990035, 5.6360611928863, 5.707555310485349, 5.77875214022275, 5.849657762144437, 5.920278036065923, 5.990618612912705, 6.060684945308924, 6.13048229747488, 6.200015754488307, 6.269290230959166, 6.338310479163164, 6.407081096675119, 6.475606533539628, 6.54389109901318, 6.611938967908948, 6.679754186572738, 6.747340678516292, 6.814702249731823, 6.8818425937098215, 6.948765296180314, 7.015473839596169, 7.081971607375544, 7.1482618879193085, 7.21434787841794, 7.2802326884614175, 7.345919343464511, 7.411410787919017, 7.476709888483592, 7.54181943692111, 7.606742152892702, 7.671480686617051, 7.736037621402857, 7.800415476061861, 7.864616707209331, 7.928643711458392, 7.992498827514223, 8.05618433817367, 8.119702472235527, 8.183055406326327, 8.246245266646268, 8.30927413063948, 8.372144028592693, 8.434856945166038], [0.0, 0.2763467610958144, 0.46475800154489005, 0.6299343920845051, 0.7816266749191567, 0.924021086472307, 1.0594191442977765, 1.1892630037971206, 1.3145341380123987, 1.435939892175147, 1.554012038466811, 1.6691635514038514, 1.7817235213823162, 1.8919597507722345, 2.000093993373727, 2.1063125873886444, 2.2107740887665157, 2.313614885729254, 2.4149534156997734, 2.5148933907913813, 2.6135263048157182, 2.710933409730773, 2.807187293695316, 2.9023531554656796, 2.996489844207229, 3.089650715860677, 3.181884344457367, 3.2732351175761307, 3.3637437383969075, 3.4534476518086805, 3.5423814082777754, 3.6305769763352735, 3.718064012359121, 3.8048700946367786, 3.891020927374724, 3.9765405192823113, 4.061451340533306, 4.145774461249813, 4.229529674123464, 4.3127356033597115, 4.395409801781649, 4.477568837643511, 4.559228372468273, 4.64040323102864, 4.721107464428337, 4.801354407105093, 4.881156728462795, 4.960526479744393, 5.0394751366760415, 5.118013638343931, 5.196152422706634, 5.273901459095456, 5.3512702780122305, 5.428267998496834, 5.504903353304679, 5.5811847121066975, 5.657120102900177, 5.732717231797884, 5.807983501344555, 5.882926027493793, 5.957551655364373, 6.031866973882536, 6.105878329406004, 6.179591838415776, 6.2530133993532555, 6.326148703672699, 6.399003246172259, 6.471582334660903, 6.543891099013179, 6.615934499658985, 6.687717335551281, 6.7592442516508475, 6.830519745963702, 6.901548176163798, 6.972333765830735, 7.042880610329795, 7.113192682359265, 7.183273837188028, 7.253127817604494, 7.3227582585962745, 7.392168691778457, 7.461362549586992, 7.530343169252339, 7.59911379656747, 7.667677589463198, 7.736037621402856, 7.8041968846074745, 7.872158293121792, 7.939924685730683, 8.007498828734926, 8.074883418594593, 8.142081084447778, 8.209094390511826, 8.275925838373796, 8.342577869176377, 8.409052865705084, 8.475353154382214, 8.541481007172612, 8.607438643406066, 8.673228231520731, 8.738851890731825, 8.804311692629476], [0.0, 0.2877830431545138, 0.4839914587188715, 0.6560034777426358, 0.8139733653002305, 0.9622606002309622, 1.1032619456555046, 1.2384792388616033, 1.368934569985932, 1.4953645569012146, 1.6183229785482076, 1.7382398999026, 1.855458030375105, 1.9702562550183473, 2.082865504649742, 2.1934798288560184, 2.3022643452361113, 2.4093610862762964, 2.5148933907913813, 2.6189692628971426, 2.7216839827678037, 2.8231221648770064, 2.923359401358144, 3.0224635891405423, 3.120496012792287, 3.217512236326243, 3.313562843952274, 3.4086940601763733, 3.502948272631175, 3.59636447581786, 3.688978650032715, 3.7808240867864598, 3.871931669750973, 3.9623301185083437, 4.0520462010030665, 4.141104919516378, 4.229529674123464, 4.317342406908373, 4.404563729659741, 4.491213037323615, 4.577308609125798, 4.66286769897802, 4.7479066165367625, 4.832440800080313, 4.916484882200618, 5.000052749165253, 5.083157594686316, 5.165811968733117, 5.248027821941087, 5.329816546097491, 5.411189011123401, 5.492155598919046, 5.572726234394741, 5.652910413970984, 5.732717231797884, 5.812155403915251, 5.8912332905494935, 5.969958916721689, 6.048339991322085, 6.126383924789563, 6.204097845519995, 6.2814886151145, 6.358562842567267, 6.435326897482587, 6.511786922401845, 6.587948844313365, 6.663818385410986, 6.739401073161036, 6.814702249731822, 6.889727080834732, 6.96448056402169, 7.038967536479651, 7.113192682359265, 7.187160539671638, 7.260875506784188, 7.33434184854402, 7.407563702054815, 7.480545082131173, 7.553289886452352, 7.625801900435601, 7.698084801847699, 7.770142165171877, 7.841977465745908, 7.9135940836860446, 7.984995307610313, 8.056184338173669, 8.127164291426654, 8.197938202008283, 8.26850902618316, 8.33887964473214, 8.409052865705084, 8.479031427043838, 8.548817999082836, 8.618415186934339, 8.687825532764824, 8.757051517968552, 8.82609556524404, 8.894960040578695, 8.963647255146629, 9.032159467124231, 9.100498883427921, 9.168667661378123], [0.0, 0.29906975624424403, 0.5029733718731741, 0.6817316198804997, 0.8458970107524514, 1.0, 1.1465313506452404, 1.287051801314886, 1.4226235280311383, 1.554012038466811, 1.6817928305074292, 1.8064128360710052, 1.9282282054671647, 2.047528761486697, 2.1645544919430475, 2.279507056954778, 2.392558049953953, 2.5038550738729204, 2.6135263048157182, 2.7216839827678037, 2.8284271247461907, 2.9338436637636414, 3.0380121566408085, 3.14100316319206, 3.2428803715368835, 3.3437015248821105, 3.443519191326083, 3.542381408277776, 3.640332225792468, 3.7374121677169985, 3.8336586254776357, 3.929106196262203, 4.023786974985394, 4.117730807597551, 4.2109655118691265, 4.3035170706588515, 4.395409801781649, 4.486666507879594, 4.577308609125798, 4.667356261126802, 4.756828460010886, 4.845743136379934, 4.934117239547341, 5.021966813273274, 5.109307064032926, 5.196152422706633, 5.282516600457563, 5.368412639458809, 5.453852959043999, 5.538849397780837, 5.623413251903493, 5.707555310485348, 5.791285887686946, 5.874614852373848, 5.957551655364374, 6.040105354537238, 6.122284638002925, 6.204097845519994, 6.285552988317677, 6.366657767468714, 6.447419590941253, 6.52784558944512, 6.607942631176089, 6.687717335551282, 6.767176086019612, 6.846325042023048, 6.925170150177128, 7.003717154732764, 7.081971607375544, 7.15993887641358, 7.23762415540039, 7.315032471235085, 7.3921686917784575, 7.469037533020237, 7.545643565829704, 7.621991222319223, 7.6980848018477, 7.773928476688841, 7.849526297387016, 7.924882197821726, 8.000000000000002, 8.074883418594593, 8.149536065244357, 8.223961452632084, 8.298162998353826, 8.372144028592691, 8.445907781609233, 8.51945741105955, 8.592795989151536, 8.665926509648882, 8.738851890731825, 8.811574977722977, 8.884098545686008, 8.956425301904435, 9.028557888247288, 9.100498883427921, 9.172250805161926, 9.243816112229602, 9.315197206448204, 9.386396434558714, 9.457416090031762, 9.52825841479684], [0.0, 0.3102161981490854, 0.5217193779544039, 0.7071400128625219, 0.8774239093805122, 1.0372703747942278, 1.1892630037971206, 1.3350207043294777, 1.4756452401119455, 1.611930649575211, 1.7444738796266863, 1.8737385195044756, 2.000093993373727, 2.123840925829267, 2.245228249120294, 2.3644651393135696, 2.4817295851926837, 2.5971746909065927, 2.710933409730773, 2.8231221648770064, 2.9338436637636414, 3.0431891166997826, 3.151240008348232, 3.2580695283140826, 3.3637437383969075, 3.4683225339144976, 3.5718604421979223, 3.674407291028393, 3.776008772223259, 3.876706919968318, 3.9765405192823113, 4.0755454568032174, 4.173755023635231, 4.27120017809845, 4.367909774742056, 4.4639107648156635, 4.559228372468273, 4.653886250204975, 4.7479066165367625, 4.841310378277183, 4.934117239547341, 5.026345799229371, 5.118013638343931, 5.209137398608143, 5.299732853248228, 5.389814970988844, 5.479397974013346, 5.568495390581508, 5.657120102900177, 5.745284390764911, 5.832999971424763, 5.9202780360659215, 6.007129283261561, 6.093563949693558, 6.179591838415776, 6.265222344897463, 6.350464481058237, 6.435326897482586, 6.519817903981255, 6.603945488648855, 6.687717335551281, 6.771140841162587, 6.854223129658777, 6.936971067165132, 7.019391275044098, 7.101490142302354, 7.183273837188029, 7.264748318042417, 7.3459193434645105, 7.426792481841276, 7.507373120291919, 7.587666473069963, 7.667677589463198, 7.747411361228056, 7.826872529591831, 7.906065691853375, 7.984995307610313, 8.063665704638554, 8.142081084447778, 8.220245527534646, 8.298162998353824, 8.375837350025309, 8.453272328795089, 8.530471578264963, 8.607438643406065, 8.684176974369597, 8.760689930107294, 8.836980781813201, 8.913052716197551, 8.988908838602729, 9.064552175970645, 9.13998567967015, 9.215212228192579, 9.290234629722919, 9.365055624593648, 9.439677887627731, 9.514104030376968, 9.58833660326132, 9.66237809761467, 9.736230947641921, 9.809897532292204, 9.883380177052572], [0.0, 0.3212306752415084, 0.5402434465602292, 0.7322475911233669, 0.9085775551536169, 1.0740994986439416, 1.2314887489076138, 1.382421694521101, 1.528039218217321, 1.6691635514038514, 1.8064128360710052, 1.9402671215678473, 2.071108948763389, 2.1992496161719117, 2.324946894583519, 2.4484173870304535, 2.569845401932068, 2.689389479523993, 2.807187293695316, 2.923359401358144, 3.0380121566408085, 3.151240008348232, 3.2631273343220926, 3.373749922823626, 3.4831761812300455, 3.591468131490858, 3.698682236974137, 3.804870094636779, 3.910079018621074, 4.014352535570595, 4.1177308075975505, 4.220250995524037, 4.321947572481834, 4.422852595991243, 4.522995945105557, 4.622405528000316, 4.721107464428336, 4.819126246696036, 4.916484882200618, 5.01320502006896, 5.109307064032925, 5.204810273343008, 5.299732853248228, 5.394092036343337, 5.4879041558957145, 5.5811847121066975, 5.673948432129767, 5.766209324556506, 5.857980728986937, 5.949275361220694, 6.040105354537239, 6.130482297474878, 6.2204172684682835, 6.3099208676610035, 6.399003246172258, 6.487674133065035, 6.575942860234448, 6.663818385410985, 6.751309313451946, 6.838423916075703, 6.925170150177127, 7.011555674848069, 7.097587867214165, 7.183273837188029, 7.268620441228936, 7.353634295190418, 7.438321786329244, 7.522689084542436, 7.606742152892701, 7.690486757477093, 7.77392847668884, 7.857072709917758, 7.939924685730683, 8.02248946956982, 8.104771971003569, 8.186776950561601, 8.268509026183162, 8.349972679305345, 8.43117226061583, 8.512111995492614, 8.592795989151535, 8.67322823152073, 8.753412601859685, 8.833352873139225, 8.913052716197551, 8.99251570368628, 9.071745313819443, 9.150744933937476, 9.229517863897337, 9.308067319299106, 9.386396434558714, 9.46450826583575, 9.542405793824711, 9.620091926417468, 9.697569501244217, 9.774841288099681, 9.851909991260914, 9.928778251702605, 10.005448649215461, 10.081923704432796, 10.15820588077026, 10.234297586283203], [0.0, 0.33212064831351956, 0.5585581251971565, 0.7570713615910638, 0.9393790503782489, 1.1105123182107506, 1.2732371881063487, 1.4292868795355163, 1.579840952055016, 1.7257495113651922, 1.867651654957025, 2.0060437062308685, 2.1413211744926963, 2.2738059115217784, 2.403764426741167, 2.5314206661966154, 2.6569651865081574, 2.7805619025503665, 2.9023531554656796, 3.0224635891405423, 3.14100316319206, 3.2580695283140826, 3.373749922823626, 3.488122704263714, 3.6012585990755643, 3.7132217318016543, 3.8240704799627374, 3.9338581896932157, 4.042633779122095, 4.15044225048047, 4.2573251274078086, 4.363320830507363, 4.468465001577253, 4.572790784912982, 4.676329072491303, 4.779108718596899, 4.881156728462795, 4.9824984247039, 5.083157594686316, 5.183156621459386, 5.282516600457563, 5.381257443835113, 5.479397974013346, 5.576956007785559, 5.673948432129768, 5.770391272716351, 5.866299755960901, 5.961688365357295, 6.056570892728512, 6.150960484949816, 6.244869686628403, 6.338310479163163, 6.431294316556435, 6.523832158304987, 6.615934499658985, 6.707611399504316, 6.7988725060946935, 6.8897270808347315, 6.980184020293174, 7.0702518766061635, 7.15993887641358, 7.249252938456523, 7.3382016899510045, 7.426792481841277, 7.515032403025993, 7.6029282936413285, 7.690486757477094, 7.777714173594684, 7.86461670720933, 7.951200319893321, 8.037470779151812, 8.123433667418189, 8.209094390511826, 8.294458185597408, 8.379530128681578, 8.464315141679712, 8.548817999082836, 8.633043334252292, 8.716995645367504, 8.800679301050112, 8.884098545686006, 8.967257504465032, 9.050160188156628, 9.132810497638307, 9.215212228192579, 9.297369073586763, 9.379284629949087, 9.4609623994535, 9.542405793824711, 9.623618137674177, 9.704602671676998, 9.785362555598985, 9.865900871182525, 9.946220624899317, 10.026324750577455, 10.106216111909887, 10.185897504850793, 10.265371659905982, 10.344641244323102, 10.42370886418692, 10.502577066424823, 10.581248340727129], [0.0, 0.3428928515638559, 0.576674739392341, 0.7816266749191568, 0.9698474422447794, 1.1465313506452404, 1.314534138012399, 1.4756452401119455, 1.6310824750532378, 1.781723521382316, 1.9282282054671644, 2.0711089487633885, 2.210774088766516, 2.3475559163923183, 2.481729585192684, 2.613526304815718, 2.743142812510848, 2.870748339667457, 2.996489844207229, 3.120496012792287, 3.2428803715368835, 3.3637437383969075, 3.4831761812300455, 3.6012585990755643, 3.7180640123591213, 3.8336586254776357, 3.9481027094038996, 4.061451340533306, 4.173755023635232, 4.285060220570525, 4.395409801781649, 4.504843434029086, 4.613397915138729, 4.721107464428336, 4.828003975843835, 4.934117239547341, 5.0394751366760415, 5.144103811173954, 5.248027821941088, 5.3512702780122305, 5.453852959043999, 5.555796423033589, 5.657120102900177, 5.75784239331778, 5.857980728986937, 5.957551655364374, 6.056570892728512, 6.155053394339687, 6.253013399353256, 6.350464481058238, 6.447419590941254, 6.543891099013179, 6.639890830782434, 6.735430101212777, 6.830519745963702, 6.925170150177127, 7.019391275044099, 7.113192682359265, 7.206583557248092, 7.299572729231915, 7.3921686917784575, 7.484379620470088, 7.576213389908584, 7.6676775894631986, 7.758779537958237, 7.849526297387016, 7.939924685730684, 8.029981288952996, 8.119702472235526, 8.209094390511826, 8.298162998353826, 8.386914059258952, 8.475353154382214, 8.563485690753685, 8.651316909018297, 8.738851890731825, 8.82609556524404, 8.913052716197551, 8.999727987668468, 9.086125889972964, 9.172250805161925, 9.258106992224114, 9.34369859201671, 9.429029631940656, 9.514104030376968, 9.598925600898863, 9.683498056273578, 9.767825012266709, 9.851909991260914, 9.935756425700124, 10.01936766136947, 10.102746960520527, 10.185897504850793, 10.268822398345696, 10.351524669990903, 10.434007276362117, 10.516273104099195, 10.59832497227084, 10.680165634635827, 10.761797781806271, 10.843224043318141, 10.924446989613896], [0.0, 0.3535533905932737, 0.5946035575013605, 0.8059274488676565, 1.0, 1.1821770112539698, 1.3554030054147674, 1.52152305180747, 1.6817928305074292, 1.8371173070873836, 1.9881768219176268, 2.135499727637228, 2.279507056954778, 2.4205414317108858, 2.5588865599815867, 2.6947808397231316, 2.8284271247461903, 2.9599999078441765, 3.089650715860677, 3.217512236326243, 3.3437015248821105, 3.4683225339144976, 3.591468131490858, 3.7132217318016543, 3.8336586254776357, 3.9528470752104745, 4.070849225797556, 4.18772186595945, 4.3035170706588515, 4.418282746255901, 4.532063096035153, 4.644899019996704, 4.756828460010885, 4.867886699274068, 4.978106623314987, 5.08751894847192, 5.196152422706634, 5.304034002778383, 5.411189011123402, 5.517641275236385, 5.623413251903492, 5.728526138270068, 5.832999971424763, 5.9368537179320215, 6.040105354537239, 6.142771941095401, 6.244869686628403, 6.34641400929345, 6.447419590941254, 6.547900426854399, 6.647869871181237, 6.7473406785162915, 6.8463250420230475, 6.944834628447496, 7.042880610329796, 7.140473695685931, 7.23762415540039, 7.33434184854402, 7.430636245807849, 7.526516451223037, 7.621991222319223, 7.7170689888576405, 7.811757870261442, 7.906065691853376, 8.000000000000002, 8.093568076252016, 8.186776950561603, 8.279633413650137, 8.372144028592693, 8.464315141679712, 8.55615289261077, 8.647663224070433, 8.738851890731825, 8.829724467729587, 8.920286358640306, 9.01054280300533, 9.100498883427923, 9.190159532274139, 9.279529538004422, 9.36861355116068, 9.45741609003176, 9.545941546018394, 9.634194188717009, 9.722178170740452, 9.809897532292206, 9.897356205509478, 9.984558018589448, 10.071506699711863, 10.15820588077026, 10.24465910092326, 10.33086980997645, 10.416841371604812, 10.502577066424823, 10.58808009492482, 10.673353580261633, 10.75840057093091, 10.843224043318143, 10.92782690413688, 11.012211992760264, 11.09638208345154, 11.180339887498953, 11.264088055260014], [0.0, 0.3641078238014289, 0.6123539276009055, 0.8299863538478042, 1.0298524451722681, 1.2174678856663448, 1.3958650993202393, 1.5669442352898946, 1.7319984587712658, 1.8919597507722345, 2.047528761486697, 2.199249616171912, 2.347555916392319, 2.4928005120882384, 2.635275580715491, 2.775226636992245, 2.9128625904114323, 3.0483631428030136, 3.181884344457367, 3.313562843952274, 3.443519191326083, 3.5718604421979223, 3.698682236974137, 3.8240704799627374, 3.9481027094038996, 4.070849225797556, 4.192374029115247, 4.312735603359712, 4.431987578058615, 4.550179289694084, 4.667356261126803, 4.783560613321878, 4.8988314208072445, 5.01320502006896, 5.126715278349202, 5.239393828944053, 5.351270278012231, 5.4623723870381715, 5.572726234394743, 5.682356358885623, 5.791285887686947, 5.8995366507306795, 6.007129283261563, 6.114083318042364, 6.220417268468285, 6.3261487036726995, 6.4312943165564365, 6.535869985546396, 6.639890830782435, 6.743371265340541, 6.846325042023049, 6.948765296180314, 7.050704584971567, 7.152154923423694, 7.253127817604496, 7.353634295190418, 7.453684933676963, 7.553289886452352, 7.652458906930897, 7.751201370921347, 7.849526297387016, 7.947442367738124, 8.044957943782455, 8.14208108444778, 8.238819561378147, 8.335180873496348, 8.431172260615831, 8.526800716177606, 8.622072999180588, 8.716995645367504, 8.811574977722977, 8.905817116335236, 8.999727987668468, 9.09331333328872, 9.186578718082547, 9.279529538004423, 9.372171027385741, 9.46450826583575, 9.55654618476214, 9.648289573536871, 9.73974308533076, 9.830911242638585, 9.92179844251467, 10.012408961537504, 10.102746960520527, 10.192816488984858, 10.28262148940872, 10.372165801267142, 10.461453164874568, 10.550487225042149, 10.639271534560612, 10.72780955751886, 10.816104672467791, 10.904160175438147, 10.991979282820624, 11.079565134115922, 11.166920794561918, 11.254049257644663, 11.340953447499535, 11.427636221208314, 11.514100370997836, 11.600348626345266], [0.0, 0.37456123052590357, 0.6299343920845051, 0.8538149682454627, 1.0594191442977765, 1.2524209576711836, 1.4359398921751474, 1.6119306495752113, 1.781723521382316, 1.9462772454491513, 2.106312587388645, 2.262389294101567, 2.414953415699774, 2.564367932320461, 2.7109334097307736, 2.854902411289524, 2.9964898442072294, 3.1358805694897747, 3.2732351175761307, 3.4086940601763733, 3.542381408277776, 3.674407291028393, 3.804870094636779, 3.9338581896932157, 4.061451340533306, 4.18772186595945, 4.312735603359712, 4.436552715791848, 4.559228372468274, 4.680813326304056, 4.8013544071050935, 4.9208949451144886, 5.0394751366760415, 5.157132361483461, 5.273901459095456, 5.389814970988844, 5.504903353304679, 5.619195164549785, 5.732717231797885, 5.845494798353023, 5.957551655364374, 6.068910259493521, 6.179591838415777, 6.2896164856726156, 6.399003246172259, 6.507770193451681, 6.6159344996589855, 6.7235124990850865, 6.830519745963703, 6.936971067165133, 7.042880610329796, 7.148261887919308, 7.253127817604495, 7.357490759359412, 7.461362549586993, 7.564754532564371, 7.667677589463198, 7.770142165171878, 7.872158293121794, 7.973735618297846, 8.074883418594595, 8.175610624662468, 8.275925838373798, 8.37583735002531, 8.475353154382214, 8.574480965658712, 8.673228231520733, 8.771602146188505, 8.86960966270941, 8.967257504465033, 9.064552175970647, 9.16149997302005, 9.258106992224116, 9.354379139987218, 9.450322140961841, 9.545941546018396, 9.64124273976408, 9.736230947641923, 9.830911242638585, 9.9252885516272, 10.01936766136947, 10.1131532241994, 10.206649763409185, 10.299861678356372, 10.392793249309877, 10.48544864205114, 10.577831912245536, 10.669947009598063, 10.761797781806271, 10.853387978322548, 10.944721253936983, 11.035801172191245, 11.126631208633237, 11.217214753921573, 11.307555116788388, 11.397655526868332, 11.487519137401183, 11.577149027814913, 11.666548206195792, 11.755719611651406, 11.844666116572437, 11.93339052879837], [0.0, 0.3849182684929582, 0.6473527842827909, 0.8774239093805123, 1.0887132714158199, 1.287051801314886, 1.4756452401119458, 1.6565023392678926, 1.8309901743454147, 2.000093993373727, 2.1645544919430475, 2.324946894583519, 2.481729585192684, 2.635275580715491, 2.785893757899527, 2.933843663763641, 3.0793461479436663, 3.222591183059559, 3.3637437383969075, 3.502948272631175, 3.640332225792468, 3.776008772223259, 3.910079018621074, 4.042633779122095, 4.173755023635232, 4.3035170706588515, 4.431987578058615, 4.559228372468274, 4.685296148590824, 4.810243062716335, 4.934117239547341, 5.056963207456748, 5.178822274262328, 5.299732853248228, 5.41973074732602, 5.538849397780836, 5.657120102900177, 5.7745722108656, 5.891233290549494, 6.007129283261562, 6.122284638002926, 6.236722432387039, 6.350464481058238, 6.463531433166945, 6.5759428602344485, 6.687717335551281, 6.798872506094694, 6.909425157817061, 7.0193912750441, 7.128786094625697, 7.237624155400391, 7.3459193434645105, 7.453684933676962, 7.560933627778944, 7.6676775894631986, 7.77392847668884, 7.8796974715041195, 7.984995307610312, 8.08983229587443, 8.19421834797602, 8.298162998353826, 8.401675424600775, 8.504764466440612, 8.607438643406066, 8.709706171326562, 8.811574977722977, 8.913052716197553, 9.014146779898772, 9.114864314133571, 9.215212228192579, 9.315197206448202, 9.414825718779998, 9.514104030376968, 9.613038210962188, 9.7116341434812, 9.809897532292206, 9.90783391089283, 10.00544864921546, 10.102746960520527, 10.199733907914725, 10.29641441051909, 10.392793249309875, 10.488875072653377, 10.58466440155431, 10.680165634635825, 10.775383052867891, 10.870320824059576, 10.96498300712965, 11.059373556168811, 11.153496324306015, 11.24735506739039, 11.340953447499531, 11.434295036284135, 11.527383318158325, 11.620221693344396, 11.712813480780015, 11.80516192089557, 11.897270178268675, 11.989141344162553, 12.080778438954416, 12.172184414459764, 12.263362156157992], [0.0, 0.3951832225777059, 0.6646163104680074, 0.9008229446560114, 1.1177469459833946, 1.3213747439409018, 1.5149975698790705, 1.7006777444011336, 1.8798188000764475, 2.053432259410161, 2.2222785707733985, 2.3869482987148825, 2.547912051258799, 2.7055527929211154, 2.860187637537373, 3.0120830536950978, 3.161465780621648, 3.3085308571039573, 3.4534476518086805, 3.59636447581786, 3.7374121677169985, 3.876706919968318, 4.014352535570595, 4.15044225048047, 4.285060220570525, 4.418282746255901, 4.550179289694084, 4.680813326304056, 4.810243062716335, 4.938522046118659, 5.06569968459734, 5.191821694002578, 5.31693048374406, 5.441065491506776, 5.564263474990034, 5.6865587672871385, 5.807983501344556, 5.928567807997617, 6.048339991322087, 6.167326684427392, 6.2855529883176775, 6.403042596037417, 6.519817903981256, 6.635900111968678, 6.751309313451947, 6.866064577031874, 6.980184020293175, 7.093684876833984, 7.206583557248093, 7.31889570471987, 7.43063624580785, 7.54181943692111, 7.652458906930896, 7.7625676963069115, 7.872158293121794, 7.981242666227712, 8.08983229587443, 8.197938202008283, 8.30557097046524, 8.412740777248326, 8.519457411059552, 8.62573029423879, 8.731568502246473, 8.836980781813203, 8.941975567867159, 9.046560999339388, 9.150744933937478, 9.254534961969506, 9.357938419292594, 9.460962399453502, 9.563613765082675, 9.665899158597641, 9.76782501226671, 9.8693975576796, 9.970622834667537, 10.071506699711863, 10.172054833876851, 10.272272750299601, 10.372165801267142, 10.471739184908493, 10.570997951527216, 10.669947009598063, 10.768591131449405, 10.866934958651566, 10.96498300712965, 11.062739672018017, 11.160209232272368, 11.25739585505423, 11.354303599901517, 11.450936422697962, 11.547298179453229, 11.643392629904753, 11.739223440951585, 11.834794189929786, 11.93010836773837, 12.025169381824032, 12.11998055903257, 12.214545148334171, 12.308866323429497, 12.402947185242814, 12.496790764308281, 12.590400023054915], [0.0, 0.40536004644211027, 0.6817316198804997, 0.924021086472307, 1.1465313506452404, 1.3554030054147674, 1.5540120384668112, 1.7444738796266863, 1.9282282054671644, 2.106312587388645, 2.279507056954778, 2.448417387030454, 2.6135263048157182, 2.775226636992245, 2.9338436637636414, 3.089650715860677, 3.242880371536883, 3.3937326922503703, 3.5423814082777754, 3.688978650032715, 3.8336586254776357, 3.9765405192823113, 4.1177308075975505, 4.2573251274078086, 4.395409801781649, 4.532063096035153, 4.667356261126803, 4.8013544071050935, 4.934117239547341, 5.06569968459734, 5.196152422706633, 5.325522347007574, 5.453852959043998, 5.5811847121066975, 5.707555310485348, 5.832999971424763, 5.957551655364374, 6.0812412690737805, 6.204097845519995, 6.326148703672699, 6.447419590941254, 6.567934810517343, 6.687717335551281, 6.806788911803817, 6.925170150177128, 7.042880610329795, 7.15993887641358, 7.276362625829093, 7.392168691778458, 7.50737312029192, 7.621991222319224, 7.736037621402856, 7.8495262973870155, 7.962470626561743, 8.074883418594595, 8.186776950561601, 8.298162998353826, 8.409052865705084, 8.519457411059552, 8.629387072474369, 8.738851890731825, 8.847861530817449, 8.956425301904437, 9.064552175970647, 9.172250805161925, 9.279529538004423, 9.386396434558716, 9.492859280599752, 9.598925600898863, 9.704602671676998, 9.809897532292206, 9.914816996218647, 10.01936766136947, 10.123555919811329, 10.227387966914183, 10.33086980997645, 10.434007276362117, 10.536806021183498, 10.639271534560612, 10.741409148485554, 10.843224043318141, 10.944721253936983, 11.045905675568237, 11.146782069312723, 11.247355067390393, 11.347629178119833, 11.447608790649126, 11.547298179453227, 11.646701508611951, 11.745822835881599, 11.844666116572435, 11.943235207243283, 12.041533869223779, 12.139565771974137, 12.23733449629158, 12.33484353737194, 12.432096307734493, 12.529096140017453, 12.62584628965114, 12.722349937415338, 12.818610191887027, 12.914630091784183], [0.0, 0.4154523982933913, 0.6987048648669425, 0.9470266737385727, 1.175076832373886, 1.3891488176895426, 1.59270267019283, 1.7879064881017699, 1.9762357919817815, 2.158753985911486, 2.3362605220981445, 2.50937625548725, 2.67859593186034, 2.8443221582045783, 3.0068883133072726, 3.1665745330836983, 3.3236191863471314, 3.4782273155365293, 3.6305769763352735, 3.7808240867864598, 3.929106196262203, 4.0755454568032174, 4.220250995524037, 4.363320830507363, 4.504843434029086, 4.644899019996704, 4.783560613321878, 4.9208949451144886, 5.056963207456748, 5.191821694002578, 5.325522347007574, 5.4581132271142945, 5.589638918935541, 5.720140882937943, 5.849657762144436, 5.978225650612506, 6.105878329406004, 6.232647474788206, 6.358562842567268, 6.483652431880181, 6.60794263117609, 6.731458348729401, 6.854223129658778, 6.976259261134689, 7.097587867214166, 7.218228994537571, 7.338201689951005, 7.4575240709738, 7.576213389908585, 7.694286092287683, 7.8117578702614425, 7.928643711458391, 8.044957943782455, 8.160714276556558, 8.275925838373796, 8.39060521197568, 8.504764466440612, 8.618415186934339, 8.731568502246471, 8.844235110313107, 8.956425301904437, 9.068148982637583, 9.179415693458589, 9.29023462972292, 9.40061465899109, 9.510564337644626, 9.62009192641747, 9.729205404928987, 9.837912485296645, 9.946220624899317, 10.054137038355726, 10.161668708776832, 10.268822398345698, 10.375604658273879, 10.482021838179037, 10.58808009492482, 10.69378540096057, 10.79914355219537, 10.904160175438145, 11.008840735432955, 11.113190541516342, 11.21721475392157, 11.320918389752483, 11.424306328648234, 11.527383318158325, 11.630153978846101, 11.732622809137373, 11.834794189929786, 11.9366723889773, 12.038261565063207, 12.139565771974137, 12.24058896228663, 12.341334990977101, 12.441807618865251, 12.542010515900314, 12.6419472642989, 12.741621361542643, 12.841036223243295, 12.94019518588245, 13.039101509432575, 13.137758379865677, 13.236168911555463], [0.0, 0.425463671755599, 0.7155417527999327, 0.9698474422447794, 1.203392989787646, 1.4226235280311383, 1.631082475053238, 1.8309901743454147, 2.023857702507763, 2.2107740887665157, 2.392558049953953, 2.5698454019320676, 2.7431428125108486, 2.912862590411432, 3.0793461479436663, 3.242880371536883, 3.4037093740447935, 3.5620431388717604, 3.718064012359121, 3.871931669750973, 4.023786974985394, 4.173755023635231, 4.321947572481834, 4.468465001577253, 4.613397915138729, 4.756828460010885, 4.8988314208072445, 5.0394751366760415, 5.178822274262328, 5.31693048374406, 5.453852959043998, 5.589638918935541, 5.724334022399463, 5.857980728986936, 5.990618612912705, 6.122284638002925, 6.2530133993532555, 6.382837336538815, 6.511786922401846, 6.639890830782433, 6.767176086019613, 6.893668196609495, 7.019391275044099, 7.144368145554118, 7.268620441228937, 7.3921686917784575, 7.515032403025994, 7.637230129073846, 7.758779537958237, 7.8796974715041195, 8.000000000000004, 8.119702472235524, 8.238819561378147, 8.357365307108209, 8.475353154382214, 8.592795989151535, 8.709706171326562, 8.826095565244039, 8.941975567867157, 9.057357134923194, 9.172250805161925, 9.286666722898921, 9.40061465899109, 9.514104030376968, 9.62714391830117, 9.73974308533076, 9.851909991260914, 9.96365280799813, 10.074979433500948, 10.185897504850791, 10.296414410519091, 10.406537301890793, 10.516273104099193, 10.62562852622224, 10.734610070886111, 10.843224043318141, 10.951476559887462, 11.059373556168811, 11.166920794561914, 11.274123871496306, 11.380988224249108, 11.48751913740118, 11.593721748954927, 11.69960105613554, 11.805161920895568, 11.910409075141363, 12.015347125698572, 12.119980559032566, 12.224313745738574, 12.32835094481526, 12.432096307734492, 12.535553882319158, 12.638727616440132, 12.741621361542641, 12.844238876011723, 12.946583828385664, 13.048659800425908, 13.150470290051157, 13.252018714143146, 13.353308411230815, 13.454342644059437, 13.555124602050661], [0.0, 0.43539702265375557, 0.7322475911233669, 0.9924905857163352, 1.2314887489076138, 1.4558376885764934, 1.6691635514038516, 1.8737385195044758, 2.0711089487633885, 2.262389294101567, 2.448417387030454, 2.6298438878805204, 2.807187293695317, 2.9808695394166826, 3.151240008348232, 3.3185922848908485, 3.4831761812300455, 3.645206583277677, 3.8048700946367786, 3.9623301185083437, 4.117730807597551, 4.27120017809845, 4.422852595991243, 4.572790784912982, 4.721107464428336, 4.867886699274068, 5.01320502006896, 5.157132361483461, 5.299732853248228, 5.441065491506776, 5.5811847121066975, 5.720140882937943, 5.857980728986936, 5.9947477011130355, 6.130482297474879, 6.265222344897463, 6.399003246172259, 6.531858198244994, 6.663818385410986, 6.794913150961867, 6.925170150177128, 7.05461548710277, 7.183273837188029, 7.311168557543621, 7.438321786329244, 7.564754532564371, 7.690486757477093, 7.815537448354544, 7.939924685730684, 8.063665704638556, 8.186776950561603, 8.309274130639478, 8.43117226061583, 8.55248570795708, 8.673228231520731, 8.793413018107994, 8.913052716197551, 9.032159467124231, 9.150744933937476, 9.26882032814923, 9.386396434558714, 9.50348363432204, 9.62009192641747, 9.736230947641923, 9.851909991260912, 9.967138024422198, 10.081923704432798, 10.196275393989682, 10.310201175445965, 10.42370886418692, 10.536806021183498, 10.64949996478488, 10.761797781806271, 10.873706337963256, 10.985232287699604, 11.09638208345154, 11.207161984387788, 11.317578064661662, 11.427636221208314, 11.537342181117781, 11.64670150861195, 11.755719611651406, 11.864401748196114, 11.972753032142075, 12.080778438954416, 12.188482811015875, 12.295870862708204, 12.402947185242812, 12.509716251255735, 12.616182419180985, 12.722349937415338, 12.828222948286683, 12.933805491837303, 13.039101509432575, 13.144114847205, 13.248849259342665, 13.353308411230818, 13.45749588245449, 13.56141516966976, 13.665069689350597, 13.768462780417977, 13.871597706757353], [0.0, 0.4452553923589698, 0.7488273266140879, 1.0149628090294405, 1.259372429187618, 1.48880113439267, 1.706957175457394, 1.9161641818197315, 2.118003522346461, 2.313614885729254, 2.50385507387292, 2.6893894795239928, 2.870748339667457, 3.0483631428030127, 3.2225911830595586, 3.39373269225037, 3.56204313887176, 3.7277422743368462, 3.891020927374724, 4.0520462010030665, 4.2109655118691265, 4.367909774742056, 4.522995945105557, 4.676329072491303, 4.828003975843835, 4.978106623314987, 5.126715278349202, 5.273901459095456, 5.41973074732602, 5.564263474990034, 5.707555310485348, 5.849657762144436, 5.990618612912705, 6.130482297474879, 6.269290230959165, 6.4070810966751175, 6.543891099013179, 6.679754186572739, 6.814702249731823, 6.948765296180313, 7.081971607375544, 7.21434787841794, 7.3459193434645105, 7.476709888483592, 7.606742152892702, 7.736037621402856, 7.86461670720933, 7.992498827514222, 8.119702472235526, 8.246245266646266, 8.372144028592693, 8.497414820859493, 8.622072999180586, 8.746133256334213, 8.869609662709408, 8.99251570368628, 9.114864314133571, 9.236667910293288, 9.357938419292594, 9.478687306497326, 9.598925600898863, 9.718663918706081, 9.837912485296645, 9.956681155666272, 10.074979433500946, 10.192816488984858, 10.310201175445965, 10.427142044931543, 10.54364736279739, 10.659725121386717, 10.775383052867891, 10.890628641294011, 11.005469133941746, 11.119911551981957, 11.233962700530014, 11.347629178119833, 11.460917385641828, 11.573833534781826, 11.686383655994884, 11.798573606045261, 11.910409075141363, 12.021895593692191, 12.133038538709775, 12.243843139880237, 12.354314485324455, 12.464457527067617, 12.574277086235705, 12.683777857995498, 12.792964416253591, 12.901841218128766, 13.010412608211068, 13.118682822620032, 13.226655992873598, 13.334336149578535, 13.441727225952453, 13.548833061186716, 13.655657403659156, 13.76220391400467, 13.868476168051515, 13.974477659630326, 14.080211803262776, 14.185681936736037], [0.0, 0.45504152822405836, 0.7652855797503654, 1.0372703747942278, 1.287051801314886, 1.52152305180747, 1.7444738796266865, 1.9582789845709268, 2.164554491943047, 2.3644651393135696, 2.5588865599815867, 2.7484987711629425, 2.9338436637636414, 3.115362209840808, 3.293419556384753, 3.4683225339144976, 3.6403322257924677, 3.8096732132827436, 3.9765405192823113, 4.141104919516378, 4.3035170706588515, 4.4639107648156635, 4.622405528000316, 4.779108718596899, 4.934117239547341, 5.08751894847192, 5.239393828944053, 5.389814970988844, 5.538849397780836, 5.6865587672871385, 5.832999971424763, 5.978225650612506, 6.122284638002925, 6.265222344897463, 6.4070810966751175, 6.547900426854398, 6.687717335551281, 6.826566517511323, 6.96448056402169, 7.101490142302354, 7.23762415540039, 7.372909885139897, 7.507373120291919, 7.641038271807386, 7.773928476688841, 7.9060656918533745, 8.037470779151812, 8.168163582551161, 8.298162998353826, 8.427487039213466, 8.55615289261077, 8.684176974369597, 8.811574977722975, 8.938361918377346, 9.064552175970647, 9.190159532274139, 9.315197206448202, 9.439677887627731, 9.563613765082675, 9.687016556172733, 9.809897532292204, 9.93226754298047, 10.054137038355725, 10.175516090013707, 10.29641441051909, 10.416841371604812, 10.5368060211835, 10.656317099265326, 10.775383052867891, 10.894012049995737, 11.012211992760264, 11.129990529704346, 11.24735506739039, 11.364312781305488, 11.48087062613261, 11.597035345432893, 11.712813480780015, 11.8282113803846, 11.943235207243282, 12.057890946844402, 12.172184414459762, 12.286121262049582, 12.399706984805633, 12.512946927355761, 12.625846289651138, 12.738410132556039, 12.850643383158538, 12.962550839819095, 13.074137176972831, 13.185406949700221, 13.296364598079764, 13.407014451335401, 13.517360731790479, 13.627407558639277, 13.737158951546421, 13.846618834083724, 13.955791037013496, 14.064679301426645, 14.173287281743487, 14.281618548584529, 14.389676591518194, 14.497464821691892], [0.0, 0.46475800154489, 0.7816266749191568, 1.0594191442977765, 1.314534138012399, 1.5540120384668112, 1.7817235213823162, 2.000093993373727, 2.2107740887665157, 2.4149534156997734, 2.6135263048157182, 2.8071872936953164, 2.9964898442072294, 3.181884344457367, 3.363743738396908, 3.5423814082777754, 3.7180640123591213, 3.8910209273747247, 4.061451340533306, 4.229529674123464, 4.395409801781649, 4.559228372468273, 4.721107464428336, 4.881156728462795, 5.0394751366760415, 5.196152422706634, 5.351270278012231, 5.504903353304679, 5.657120102900177, 5.807983501344556, 5.957551655364374, 6.105878329406004, 6.2530133993532555, 6.399003246172259, 6.543891099013179, 6.687717335551281, 6.830519745963702, 6.9723337658307365, 7.113192682359266, 7.253127817604495, 7.392168691778458, 7.5303431692523395, 7.6676775894631986, 7.804196884607476, 7.939924685730684, 8.074883418594593, 8.209094390511826, 8.342577869176377, 8.475353154382214, 8.607438643406066, 8.738851890731826, 8.869609662709408, 8.999727987668468, 9.129222201944888, 9.258106992224116, 9.386396434558714, 9.514104030376968, 9.641242739764078, 9.767825012266709, 9.893862815444614, 10.01936766136947, 10.144350631250193, 10.268822398345698, 10.392793249309877, 10.516273104099193, 10.639271534560613, 10.761797781806271, 10.883860772471238, 11.005469133941748, 11.126631208633237, 11.247355067390393, 11.36764852207495, 11.487519137401181, 11.6069742420739, 11.726020939278996, 11.844666116572437, 11.962916455209722, 12.080778438954416, 12.198258362401237, 12.315362338846283, 12.432096307734492, 12.548466041712036, 12.664477153309177, 12.780135101277262, 12.895445196601694, 13.01041260821107, 13.125042368401267, 13.239339377991833, 13.353308411230817, 13.466954120463035, 13.580281040575708, 13.693293593234428, 13.805996090921544, 13.918392740788237, 14.030487648330777, 14.142284820900763, 14.253788171058535, 14.365001519778277, 14.475928599512915, 14.586573057126195, 14.696938456699076, 14.807028282216983], [0.0, 0.47440722340731084, 0.7978546670673516, 1.081414613627287, 1.341826258860764, 1.5862761563221133, 1.818715344004333, 2.0416195843772296, 2.2566737819386384, 2.465092243257425, 2.667787866907412, 2.865469610333642, 3.05870242628034, 3.2479460537300944, 3.433581179629182, 3.6159276926153576, 3.7952577872584876, 3.971805602570757, 4.145774461249813, 4.317342406908373, 4.486666507879594, 4.653886250204975, 4.819126246696036, 4.9824984247039, 5.144103811173954, 5.304034002778383, 5.4623723870381715, 5.619195164549785, 5.7745722108656, 5.928567807997617, 6.0812412690737805, 6.232647474788206, 6.382837336538815, 6.531858198244994, 6.679754186572739, 6.826566517511323, 6.9723337658307365, 7.1170921028184, 7.26087550678419, 7.4037159500861724, 7.545643565829705, 7.686686796901023, 7.8268725295918316, 7.966226213736341, 8.10477197100357, 8.242532692754915, 8.37953012868158, 8.51578496727177, 8.651316909018298, 8.786144733158837, 8.920286358640308, 9.053758899912564, 9.186578718082547, 9.318761467896387, 9.450322140961843, 9.581275105575946, 9.7116341434812, 9.841412483837761, 9.970622834667537, 10.0992774119986, 10.227387966914183, 10.354965810689265, 10.482021838179039, 10.608566549607051, 10.734610070886113, 10.860162172592151, 10.985232287699608, 11.109829528176737, 11.233962700530016, 11.357640320378604, 11.480870626132612, 11.60366159184224, 11.726020939278996, 11.847956149304942, 11.969474472581028, 12.090582939661424, 12.211288370516646, 12.331597383524995, 12.451516403968425, 12.571051672066188, 12.69020925057691, 12.808995031997398, 12.927414745384256, 13.045473962822447, 13.16317810556309, 13.28053244985115, 13.397542132462121, 13.514212155965486, 13.63054739373137, 13.746552594695734, 13.86223238789831, 13.977591286806513, 14.092633693437676, 14.20736390229109, 14.321786104100607, 14.435904389417727, 14.549722752034668, 14.663245092255993, 14.776475220027143, 14.889416857927387, 15.00207364403449, 15.114449134667762], [0.0, 0.4839914587188715, 0.8139733653002306, 1.1032619456555048, 1.3689345699859323, 1.6183229785482078, 1.8554580303751051, 2.0828655046497424, 2.302264345236112, 2.5148933907913817, 2.721683982767804, 2.9233594013581445, 3.1204960127922874, 3.3135628439522744, 3.5029482726311754, 3.6889786500327153, 3.8719316697509734, 4.052046201003067, 4.229529674123464, 4.404563729659741, 4.577308609125798, 4.7479066165367625, 4.916484882200618, 5.083157594686316, 5.248027821941088, 5.411189011123402, 5.572726234394743, 5.732717231797885, 5.891233290549494, 6.048339991322087, 6.204097845519995, 6.358562842567268, 6.511786922401846, 6.663818385410986, 6.814702249731823, 6.96448056402169, 7.113192682359266, 7.26087550678419, 7.407563702054817, 7.553289886452353, 7.698084801847701, 7.841977465745909, 7.984995307610314, 8.127164291426656, 8.268509026183162, 8.409052865705085, 8.548817999082836, 8.687825532764826, 8.82609556524404, 8.96364725514663, 9.100498883427923, 9.236667910293288, 9.372171027385741, 9.507024205717185, 9.64124273976408, 9.774841288099681, 9.90783391089283, 10.040234104566437, 10.172054833876851, 10.303308561647054, 10.434007276362117, 10.564162517813608, 10.69378540096057, 10.822886638157835, 10.951476559887462, 11.079565134115922, 11.20716198438779, 11.334276406756306, 11.46091738564183, 11.587093608700734, 11.712813480780015, 11.83808513702602, 11.962916455209722, 12.087315067325669, 12.211288370516646, 12.33484353737194, 12.45798752564286, 12.580727087415816, 12.70306877777984, 12.825018963022522, 12.946583828385666, 13.067769385409537, 13.188581478892289, 13.309025793489202, 13.42910785997449, 13.548833061186718, 13.66820663767734, 13.787233693080495, 13.905919199220808, 14.024268000974851, 14.142284820900763, 14.259974263649504, 14.377340820170382, 14.494388871722517, 14.61112269370327, 14.727546459303714, 14.843664243000845, 14.959480023895324, 15.074997688903201, 15.190221035809337, 15.305153776189945, 15.419799538211047], [0.0, 0.49351283867548723, 0.8299863538478041, 1.124965998458558, 1.395865099320239, 1.6501596312281257, 1.8919597507722348, 2.123840925829267, 2.3475559163923183, 2.5643679323204607, 2.775226636992245, 2.9808695394166826, 3.1818843444573672, 3.3787493059838685, 3.5718604421979223, 3.761550524486406, 3.948102709403899, 4.13176056535081, 4.3127356033597115, 4.491213037323615, 4.667356261126802, 4.841310378277183, 5.01320502006896, 5.183156621459386, 5.3512702780122305, 5.517641275236385, 5.682356358885623, 5.845494798353023, 6.007129283261562, 6.167326684427392, 6.326148703672699, 6.483652431880181, 6.639890830782433, 6.794913150961867, 6.948765296180313, 7.101490142302354, 7.253127817604495, 7.4037159500861724, 7.553289886452353, 7.701882886671287, 7.849526297387016, 7.9962497069549325, 8.142081084447778, 8.287046904630913, 8.43117226061583, 8.57448096565871, 8.716995645367504, 8.858737821409758, 8.999727987668468, 9.13998567967015, 9.279529538004423, 9.418377366364632, 9.55654618476214, 9.694052278400498, 9.830911242638585, 9.967138024422196, 10.102746960520525, 10.237751812866483, 10.37216580126714, 10.506001633721857, 10.639271534560612, 10.771987270592906, 10.904160175438145, 11.035801172191245, 11.166920794561914, 11.297529206612635, 11.427636221208314, 11.557251317279917, 11.686383655994884, 11.815042095918555, 11.943235207243283, 12.070971285155053, 12.198258362401237, 12.325104221117703, 12.451516403968423, 12.5775022246463, 12.70306877777984, 12.828222948286683, 12.952971420211634, 13.077320685083837, 13.20127704982501, 13.32484664423816, 13.448035428103937, 13.570849197909682, 13.693293593234426, 13.81537410281127, 13.93709607028705, 14.058464699697751, 14.179485060676816, 14.300162093412236, 14.420500613367237, 14.540505315778326, 14.66018077994355, 14.779531473312879, 14.898561755391931, 15.01727588146939, 15.135678006177884, 15.253772186897407, 15.371562387009833, 15.489052479012402, 15.606246247497753, 15.723147392007437], [0.0, 0.5029733718731741, 0.8458970107524514, 1.1465313506452404, 1.4226235280311386, 1.6817928305074294, 1.9282282054671647, 2.1645544919430475, 2.392558049953953, 2.6135263048157182, 2.8284271247461907, 3.038012156640809, 3.242880371536884, 3.443519191326083, 3.6403322257924686, 3.8336586254776357, 4.023786974985394, 4.210965511869127, 4.395409801781649, 4.577308609125798, 4.756828460010886, 4.934117239547341, 5.109307064032925, 5.282516600457563, 5.453852959043999, 5.623413251903492, 5.791285887686947, 5.957551655364374, 6.122284638002926, 6.2855529883176775, 6.447419590941254, 6.60794263117609, 6.767176086019613, 6.925170150177128, 7.081971607375544, 7.23762415540039, 7.392168691778458, 7.545643565829705, 7.698084801847701, 7.849526297387016, 8.000000000000004, 8.149536065244357, 8.298162998353826, 8.445907781609234, 8.592795989151536, 8.738851890731825, 8.884098545686008, 9.02855788824729, 9.172250805161926, 9.315197206448204, 9.457416090031762, 9.598925600898863, 9.73974308533076, 9.879885140714798, 10.019367661369472, 10.158205880770263, 10.296414410519091, 10.434007276362117, 10.570997951527216, 10.70739938762332, 10.843224043318143, 10.978483910988347, 11.113190541516344, 11.247355067390393, 11.38098822424911, 11.514100370997838, 11.646701508611953, 11.778801297731455, 11.910409075141365, 12.041533869223779, 12.172184414459764, 12.302369165052209, 12.432096307734493, 12.561373773824332, 12.69020925057691, 12.818610191887027, 12.946583828385666, 13.074137176972833, 13.201277049825011, 13.328010062912538, 13.454342644059437, 13.58028104057571, 13.705831326489685, 13.830999409406104, 13.955791037013496, 14.080211803262776, 14.204267154237316, 14.327962393733337, 14.451302688568047, 14.57429307363176, 14.696938456699074, 14.819243623013161, 14.941213239656207, 15.062851859718219, 15.184163926275588, 15.305153776189945, 15.425825643737323, 15.546183664076803, 15.666231876567421, 15.785974227941344, 15.90541457534102, 16.024556689227406], [0.0, 0.5123749542422491, 0.8617085245761867, 1.1679623240020884, 1.4492152186193656, 1.71322891581121, 1.9642706628095072, 2.2050143621595666, 2.4372797645363056, 2.662378359820063, 2.881296107629309, 3.094798704649381, 3.3034963178891052, 3.507885480134123, 3.7083773454458715, 3.9053174037706357, 4.098999633937994, 4.2896769135597, 4.477568837643511, 4.66286769897802, 4.845743136379934, 5.026345799229371, 5.204810273343008, 5.381257443835113, 5.555796423033589, 5.728526138270068, 5.8995366507306795, 6.068910259493521, 6.236722432387039, 6.403042596037417, 6.567934810517343, 6.731458348729401, 6.893668196609495, 7.05461548710277, 7.21434787841794, 7.372909885139897, 7.5303431692523395, 7.686686796901023, 7.841977465745909, 7.9962497069549325, 8.149536065244357, 8.301867259839806, 8.45327232879509, 8.603778758744049, 8.753412601859685, 8.902198581543477, 9.05016018815663, 9.19731976592721, 9.34369859201671, 9.489316948601635, 9.63419418871701, 9.778348796515326, 9.921798442514667, 10.064560034340879, 10.206649763409185, 10.348083147939317, 10.488875072653377, 10.629039825466883, 10.768591131449405, 10.907542184301445, 11.045905675568239, 11.18369382178805, 11.320918389752485, 11.457590720038356, 11.593721748954927, 11.729322029036283, 11.864401748196116, 11.998970747651185, 12.133038538709775, 12.26661431851257, 12.399706984805634, 12.532325149817881, 12.664477153309177, 12.796171074849495, 12.927414745384256, 13.058215758136521, 13.188581478892289, 13.318519055711514, 13.448035428103939, 13.577137335705673, 13.705831326489683, 13.834123764540731, 13.962020837422942, 14.089528563166049, 14.216652796894422, 14.343399237121153, 14.469773431727848, 14.595780783649332, 14.721426556281, 14.846715878625375, 14.971653750193225, 15.09624504567352, 15.220494519385586, 15.344406809525825, 15.46798644222065, 15.591237835396345, 15.714165302476063, 15.836773055913314, 15.959065210570866, 16.081045786953233, 16.202718714300605, 16.324087833551427], [0.0, 0.5217193779544038, 0.8774239093805123, 1.1892630037971208, 1.4756452401119458, 1.7444738796266865, 2.0000939933737274, 2.245228249120294, 2.481729585192684, 2.710933409730773, 2.9338436637636414, 3.151240008348232, 3.363743738396908, 3.5718604421979223, 3.776008772223259, 3.9765405192823113, 4.173755023635232, 4.367909774742057, 4.559228372468273, 4.7479066165367625, 4.934117239547341, 5.118013638343931, 5.299732853248228, 5.479397974013346, 5.657120102900177, 5.832999971424763, 6.007129283261563, 6.179591838415777, 6.350464481058238, 6.519817903981256, 6.687717335551281, 6.854223129658778, 7.019391275044099, 7.183273837188029, 7.3459193434645105, 7.507373120291919, 7.6676775894631986, 7.8268725295918316, 7.984995307610314, 8.142081084447778, 8.298162998353826, 8.45327232879509, 8.607438643406066, 8.760689930107295, 8.913052716197553, 9.064552175970647, 9.215212228192579, 9.365055624593648, 9.514104030376968, 9.662378097614672, 9.809897532292206, 9.956681155666272, 10.102746960520527, 10.248112162833161, 10.392793249309877, 10.536806021183498, 10.680165634635825, 10.822886638157831, 10.96498300712965, 11.106468175871527, 11.247355067390393, 11.387656121023282, 11.527383318158327, 11.66654820619579, 11.805161920895568, 11.943235207243283, 12.080778438954418, 12.217801636724642, 12.354314485324455, 12.490326349627136, 12.625846289651138, 12.760883074690657, 12.895445196601694, 13.029540882305149, 13.163178105563087, 13.296364598079766, 13.42910785997449, 13.56141516966976, 13.693293593234428, 13.824749993218528, 13.955791037013494, 14.086423204768911, 14.216652796894422, 14.346485941173412, 14.475928599512915, 14.60498657435249, 14.73366551475308, 14.86197092218538, 14.98990815603581, 15.117482438846933, 15.244698861307949, 15.371562387009833, 15.498077856978671, 15.624249993999847, 15.750083406744873, 15.875582593711835, 16.000751946989823, 16.125595755856846, 16.250118210220368, 16.374323403908736, 16.498215337821552, 16.621797922946264], [0.0, 0.5310083394307343, 0.8930460181942645, 1.2104372570341972, 1.5019183907123212, 1.775533394279664, 2.035704700659191, 2.285203453402375, 2.525915581507238, 2.7592002694104365, 2.9860793328260593, 3.207346314299506, 3.4236335705989, 3.6354556917677114, 3.8432387841829323, 4.047340902119363, 4.248066715445876, 4.445678298097945, 4.64040323102864, 4.832440800080313, 5.021966813273274, 5.209137398608143, 5.394092036343337, 5.576956007785559, 5.75784239331778, 5.9368537179320215, 6.114083318042364, 6.2896164856726156, 6.463531433166945, 6.635900111968678, 6.806788911803817, 6.976259261134689, 7.144368145554118, 7.311168557543621, 7.476709888483592, 7.641038271807386, 7.804196884607476, 7.966226213736341, 8.127164291426656, 8.287046904630913, 8.445907781609234, 8.603778758744049, 8.760689930107295, 8.916669781930924, 9.071745313819445, 9.225942148282808, 9.379284629949089, 9.531795915632149, 9.68349805627358, 9.83441207164568, 9.984558018589452, 10.133955053464971, 10.28262148940872, 10.430574848921065, 10.577831912245538, 10.724408761948276, 10.870320824059577, 11.015582906099267, 11.16020923227237, 11.304213476090714, 11.447608790649126, 11.590407836761027, 11.732622809137375, 11.874265460774318, 12.015347125698574, 12.155878740205045, 12.295870862708206, 12.435333692317375, 12.574277086235707, 12.712710576073526, 12.850643383158541, 12.988084432917988, 13.125042368401267, 13.261525563005629, 13.397542132462121, 13.533099946134255, 13.668206637677342, 13.802869615102674, 13.937096070287051, 14.070892987964893, 14.204267154237314, 14.337225164629835, 14.469773431727848, 14.60191819241696, 14.733665514753081, 14.865021304485403, 14.995991311253668, 15.126581134479602, 15.25679622897091, 15.386641910255, 15.516123359658334, 15.64524562914623, 15.774013645936902, 15.902432216902646, 16.030506032770145, 16.15823967213107, 16.285637605273536, 16.41270419784407, 16.53944371434942, 16.665860321506567, 16.7919580914492, 16.917741004798003], [0.0, 0.5402434465602292, 0.908577555153617, 1.231488748907614, 1.5280392182173215, 1.8064128360710054, 2.071108948763389, 2.3249468945835194, 2.569845401932068, 2.8071872936953164, 3.038012156640809, 3.2631273343220926, 3.4831761812300464, 3.6986822369741374, 3.9100790186210745, 4.117730807597551, 4.321947572481835, 4.522995945105559, 4.721107464428337, 4.916484882200618, 5.109307064032926, 5.299732853248228, 5.4879041558957145, 5.673948432129768, 5.857980728986937, 6.040105354537239, 6.220417268468285, 6.399003246172259, 6.5759428602344485, 6.751309313451947, 6.925170150177128, 7.097587867214166, 7.268620441228937, 7.438321786329244, 7.606742152892702, 7.773928476688841, 7.939924685730684, 8.10477197100357, 8.268509026183162, 8.43117226061583, 8.592795989151536, 8.753412601859685, 8.913052716197553, 9.071745313819445, 9.229517863897339, 9.386396434558716, 9.542405793824713, 9.69756950124422, 9.851909991260914, 10.005448649215461, 10.158205880770263, 10.310201175445965, 10.461453164874566, 10.611979676301493, 10.761797781806271, 10.910923843657278, 11.059373556168813, 11.207161984387788, 11.354303599901518, 11.500812314026657, 11.646701508611951, 11.791984064663163, 11.9366723889773, 12.080778438954418, 12.224313745738574, 12.3672894358248, 12.509716251255737, 12.651604568519966, 12.792964416253593, 12.933805491837303, 13.074137176972833, 13.213968552315265, 13.353308411230818, 13.492165272743872, 13.63054739373137, 13.768462780417977, 13.905919199220808, 14.042924186988639, 14.179485060676818, 14.315608926495766, 14.451302688568047, 14.586573057126195, 14.721426556281, 14.855869531387748, 14.989908156035812, 15.123548438685058, 15.256796228970908, 15.389657223698228, 15.522136972542786, 15.654240883477744, 15.785974227941342, 15.917342145760868, 16.048349649846955, 16.1790016306713, 16.309302860540033, 16.43925799767405, 16.56887159010712, 16.69814807941153, 16.827091804260807, 16.95570700383798, 17.08399782109783, 17.21196830589058], [0.0, 0.5494262252227059, 0.924021086472307, 1.2524209576711836, 1.554012038466811, 1.8371173070873839, 2.106312587388645, 2.3644651393135696, 2.6135263048157182, 2.8549024112895234, 3.089650715860677, 3.3185922848908485, 3.542381408277776, 3.7615505244864065, 3.9765405192823113, 4.187721865959449, 4.395409801781649, 4.5998754906505015, 4.801354407105093, 5.000052749165253, 5.196152422706633, 5.389814970988844, 5.5811847121066975, 5.770391272716351, 5.957551655364374, 6.142771941095401, 6.3261487036726995, 6.507770193451681, 6.687717335551281, 6.866064577031874, 7.042880610329795, 7.218228994537571, 7.3921686917784575, 7.564754532564371, 7.736037621402856, 7.9060656918533745, 8.074883418594593, 8.242532692754915, 8.409052865705085, 8.57448096565871, 8.738851890731825, 8.902198581543477, 9.064552175970647, 9.225942148282808, 9.386396434558716, 9.545941546018396, 9.704602671677, 9.86240377153644, 10.01936766136947, 10.175516090013707, 10.330869809976452, 10.48544864205114, 10.639271534560612, 10.792356617768592, 10.944721253936985, 11.09638208345154, 11.24735506739039, 11.397655526868332, 11.547298179453229, 11.6962971729191, 11.844666116572437, 11.992418110363674, 12.139565771974137, 12.286121262049583, 12.432096307734492, 12.5775022246463, 12.72234993741534, 12.86664999890437, 13.01041260821107, 13.153647627547185, 13.296364598079766, 13.438572754812169, 13.58028104057571, 13.721498119196735, 13.86223238789831, 14.002491988990768, 14.142284820900763, 14.28161854858453, 14.420500613367237, 14.558938242246997, 14.696938456699073, 14.834508081013066, 14.971653750193225, 15.108381917449904, 15.244698861307949, 15.380610692355926, 15.516123359658334, 15.651242656851375, 15.785974227941342, 15.920323572823323, 16.054296052536742, 16.187896894273006, 16.32113119614962, 16.454003931763985, 16.586519954539416, 16.718684001874845, 16.850500699109165, 16.981974563310214, 17.113110006898044, 17.243911341111126, 17.374382779324044, 17.504528440224274], [0.0, 0.5585581251971565, 0.939379050378249, 1.273237188106349, 1.5798409520550163, 1.8676516549570252, 2.1413211744926963, 2.403764426741167, 2.6569651865081574, 2.9023531554656796, 3.14100316319206, 3.373749922823626, 3.601258599075565, 3.8240704799627374, 4.042633779122095, 4.2573251274078086, 4.468465001577253, 4.676329072491304, 4.881156728462795, 5.083157594686316, 5.282516600457563, 5.479397974013346, 5.673948432129767, 5.866299755960901, 6.056570892728512, 6.244869686628403, 6.4312943165564365, 6.6159344996589855, 6.798872506094694, 6.980184020293175, 7.15993887641358, 7.338201689951005, 7.515032403025994, 7.690486757477093, 7.86461670720933, 8.037470779151812, 8.209094390511826, 8.37953012868158, 8.548817999082836, 8.716995645367504, 8.884098545686008, 9.05016018815663, 9.215212228192579, 9.379284629949089, 9.542405793824713, 9.704602671677, 9.865900871182525, 10.026324750577455, 10.185897504850793, 10.344641244323102, 10.502577066424825, 10.659725121386717, 10.81610467246779, 10.971734151271137, 11.126631208633237, 11.280812761516263, 11.434295036284134, 11.587093608700732, 11.739223440951584, 11.890698915957945, 12.041533869223779, 12.191741618431095, 12.341334990977101, 12.490326349627138, 12.638727616440132, 12.78655029510807, 12.933805491837305, 13.080503934887554, 13.226655992873598, 13.372271691924967, 13.51736073179048, 13.661932500966584, 13.805996090921544, 13.949560309481383, 14.092633693437675, 14.235224520432416, 14.37734082017038, 14.51899038500546, 14.66018077994355, 14.800919352101213, 14.941213239656205, 15.081069380323234, 15.220494519385586, 15.359495217311093, 15.498077856978671, 15.636248650539716, 15.7740136459369, 15.911378733101262, 16.048349649846955, 16.18493198748169, 16.32113119614962, 16.456952589922228, 16.592401351651773, 16.727482537600793, 16.862201081860352, 16.996561800568717, 17.130569395941578, 17.26422846012403, 17.397543478874045, 17.5305188350863, 17.663158812165015, 17.795467597253516], [0.0, 0.5676405255254853, 0.9546537661342306, 1.2939405837488624, 1.6055298595014649, 1.8980204907844478, 2.1761399968514348, 2.442850691596687, 2.7001686068751636, 2.9495466919357165, 3.192077253557476, 3.428608577678815, 3.6598166448852028, 3.8862515447722528, 4.1083687791274235, 4.326551102987919, 4.541124204203883, 4.75236823616541, 4.960526479744393, 5.165811968733117, 5.368412639458809, 5.568495390581508, 5.766209324556506, 5.961688365357295, 6.155053394339687, 6.34641400929345, 6.535869985546396, 6.7235124990850865, 6.909425157817061, 7.093684876833984, 7.276362625829093, 7.4575240709738, 7.637230129073846, 7.815537448354544, 7.992498827514222, 8.168163582551161, 8.342577869176377, 8.51578496727177, 8.687825532764826, 8.858737821409758, 9.02855788824729, 9.19731976592721, 9.365055624593648, 9.531795915632149, 9.69756950124422, 9.86240377153644, 10.026324750577455, 10.18935719267904, 10.351524669990903, 10.512849652357126, 10.673353580261633, 10.83305693158678, 10.991979282820624, 11.150139365272215, 11.307555116788388, 11.464243729408539, 11.620221693344396, 11.775504837628594, 11.930108367738368, 12.084046900467586, 12.23733449629158, 12.389984689443718, 12.542010515900314, 12.693424539450701, 12.844238876011723, 12.99446521633044, 13.144114847205, 13.293198671341337, 13.441727225952453, 13.58971070019715, 13.737158951546421, 13.884081521157787, 14.030487648330777, 14.17638628411053, 14.321786104100605, 14.466695520541084, 14.611122693703269, 14.755075542648147, 14.898561755391933, 15.041588798518525, 15.184163926275584, 15.326294189188108, 15.46798644222065, 15.609247352517128, 15.75008340674487, 15.890500918067584, 16.03050603277014, 16.170104736556446, 16.309302860540033, 16.448106086945725, 16.586519954539416, 16.72454986380172, 16.862201081860352, 16.999478747194903, 17.136387874126918, 17.27293335710718, 17.409119974811485, 17.544952394055215, 17.680435173536733, 17.81557276741852, 17.950369528754816, 18.08482971277374], [0.0, 0.576674739392341, 0.9698474422447795, 1.3145341380123992, 1.631082475053238, 1.9282282054671647, 2.210774088766516, 2.481729585192684, 2.743142812510848, 2.996489844207229, 3.2428803715368835, 3.4831761812300455, 3.7180640123591218, 3.9481027094038996, 4.173755023635232, 4.395409801781649, 4.61339791513873, 4.828003975843836, 5.0394751366760415, 5.248027821941087, 5.453852959043999, 5.657120102900177, 5.857980728986937, 6.056570892728512, 6.253013399353256, 6.447419590941254, 6.639890830782435, 6.830519745963703, 7.0193912750441, 7.206583557248093, 7.392168691778458, 7.576213389908585, 7.758779537958237, 7.939924685730684, 8.119702472235526, 8.298162998353826, 8.475353154382214, 8.651316909018298, 8.82609556524404, 8.999727987668468, 9.172250805161926, 9.34369859201671, 9.514104030376968, 9.68349805627358, 9.851909991260914, 10.01936766136947, 10.185897504850793, 10.351524669990903, 10.516273104099195, 10.680165634635827, 10.843224043318143, 11.005469133941748, 11.166920794561916, 11.327598054603577, 11.487519137401183, 11.646701508611951, 11.80516192089557, 11.96291645520972, 12.119980559032568, 12.276369081789785, 12.432096307734493, 12.587175986502508, 12.741621361542643, 12.895445196601695, 13.048659800425908, 13.201277049825013, 13.353308411230818, 13.504764960869954, 13.655657403659156, 13.805996090921544, 13.955791037013496, 14.105051934943665, 14.253788171058533, 14.402008838862509, 14.549722752034667, 14.696938456699076, 14.843664243000843, 14.989908156035812, 15.135678006177882, 15.280981378844466, 15.42582564373732, 15.570217963593215, 15.714165302476063, 15.8576744336399, 16.000751946989823, 16.143404256165923, 16.285637605273532, 16.427458075281294, 16.568871590107115, 16.70988392241059, 16.850500699109162, 16.990727406634143, 17.130569395941578, 17.270031887291896, 17.40911997481148, 17.547838630848155, 17.686192710132136, 17.824186953752946, 17.961825992962364, 18.099114352812542, 18.23605645563823, 18.37265662439112], [0.0, 0.5856620185738529, 0.9849621839380147, 1.335020704329478, 1.6565023392678928, 1.958278984570927, 2.2452282491202946, 2.520406494569097, 2.7858937578995273, 3.0431891166997826, 3.2934195563847535, 3.5374602943370164, 3.7760087722232596, 4.009632543923936, 4.23880157253067, 4.463910764815664, 4.685296148590824, 4.903246771576625, 5.118013638343931, 5.329816546097491, 5.538849397780837, 5.745284390764911, 5.949275361220694, 6.150960484949816, 6.350464481058238, 6.547900426854399, 6.743371265340541, 6.936971067165133, 7.128786094625697, 7.31889570471987, 7.50737312029192, 7.694286092287683, 7.8796974715041195, 8.063665704638556, 8.246245266646266, 8.427487039213466, 8.607438643406066, 8.786144733158837, 8.96364725514663, 9.13998567967015, 9.315197206448204, 9.489316948601635, 9.662378097614672, 9.83441207164568, 10.005448649215461, 10.175516090013707, 10.344641244323102, 10.512849652357126, 10.680165634635827, 10.846612374377546, 11.012211992760266, 11.176985617799648, 11.340953447499533, 11.504134807851944, 11.66654820619579, 11.828211380384602, 11.989141344162553, 12.149354429103571, 12.308866323429495, 12.467692107989238, 12.625846289651138, 12.783342832334393, 12.94019518588245, 13.096416312960748, 13.252018714143146, 13.407014451335403, 13.561415169669761, 13.715232117992059, 13.868476168051515, 14.021157832493088, 14.17328728174349, 14.3248743598736, 14.475928599512915, 14.62645923588501, 14.776475220027141, 14.925985231251806, 15.0749976889032, 15.223520763457236, 15.371562387009833, 15.519130263194546, 15.66623187656742, 15.812874501494035, 15.959065210570865, 16.104810882610803, 16.250118210220368, 16.394993706994047, 16.539443714349417, 16.683474408024953, 16.827091804260803, 16.970301765681487, 17.11311000689804, 17.255522099845937, 17.39754347887404, 17.539179445598776, 17.680435173536733, 17.821315712528083, 17.961825992962364, 18.101970829817358, 18.24175492652132, 18.38118287864781, 18.520259177452143, 18.658988213257743], [0.0, 0.5946035575013605, 1.0000000000000002, 1.3554030054147677, 1.6817928305074294, 1.988176821917627, 2.2795070569547784, 2.558886559981587, 2.8284271247461907, 3.089650715860677, 3.343701524882111, 3.5914681314908585, 3.8336586254776366, 4.070849225797556, 4.3035170706588515, 4.532063096035153, 4.756828460010886, 4.9781066233149875, 5.196152422706634, 5.411189011123401, 5.623413251903493, 5.832999971424763, 6.040105354537239, 6.244869686628403, 6.447419590941254, 6.647869871181237, 6.846325042023049, 7.042880610329796, 7.237624155400391, 7.43063624580785, 7.621991222319224, 7.8117578702614425, 8.000000000000004, 8.186776950561603, 8.372144028592693, 8.55615289261077, 8.738851890731826, 8.920286358640308, 9.100498883427923, 9.279529538004423, 9.457416090031762, 9.63419418871701, 9.809897532292206, 9.984558018589452, 10.158205880770263, 10.330869809976452, 10.502577066424825, 10.673353580261633, 10.843224043318143, 11.012211992760266, 11.180339887498954, 11.347629178119833, 11.514100370997836, 11.679773087182726, 11.844666116572439, 12.008797467831489, 12.172184414459764, 12.33484353737194, 12.496790764308281, 12.658041406363123, 12.818610191887029, 12.978511297991997, 13.137758379865678, 13.296364598079768, 13.45434264405944, 13.611704763864447, 13.768462780417979, 13.924628114306552, 14.080211803262777, 14.235224520432416, 14.389676591518196, 14.543578010884417, 14.696938456699076, 14.849767305183647, 15.00207364403449, 15.153866285074683, 15.305153776189945, 15.455944412598159, 15.606246247497754, 15.756067102136777, 15.90541457534102, 16.054296052536742, 16.20271871430061, 16.35068954446713, 16.498215337821556, 16.645302707404056, 16.7919580914492, 16.938187759982952, 17.08399782109783, 17.229394226925425, 17.374382779324044, 17.51896913529815, 17.66315881216502, 17.806957192482983, 17.950369528754816, 18.09340094791864, 18.236056455638234, 18.378340940403604, 18.520259177452147, 18.66181583251989, 18.803015465431976, 18.943862533540667], [0.0, 0.6035004969804791, 1.0149628090294405, 1.375683641742718, 1.7069571754573938, 2.01792553202074, 2.313614885729254, 2.5971746909065927, 2.8707483396674567, 3.135880569489774, 3.39373269225037, 3.6452065832776763, 3.8910209273747243, 4.131760565350809, 4.367909774742056, 4.599875490650501, 4.828003975843835, 5.052593082047841, 5.273901459095456, 5.492155598919046, 5.707555310485348, 5.9202780360659215, 6.130482297474878, 6.338310479163163, 6.543891099013179, 6.7473406785162915, 6.948765296180314, 7.148261887919308, 7.3459193434645105, 7.54181943692111, 7.736037621402856, 7.928643711458391, 8.119702472235524, 8.309274130639478, 8.497414820859493, 8.684176974369597, 8.869609662709408, 9.053758899912564, 9.236667910293288, 9.418377366364632, 9.598925600898863, 9.778348796515326, 9.956681155666272, 10.133955053464971, 10.310201175445965, 10.48544864205114, 10.659725121386717, 10.83305693158678, 11.005469133941748, 11.176985617799648, 11.347629178119833, 11.517421586448943, 11.686383655994883, 11.854535301393437, 12.021895593692193, 12.188482811015875, 12.354314485324455, 12.51940744562966, 12.683777857995498, 12.847441262613282, 13.01041260821107, 13.172706284030284, 13.334336149578537, 13.495315562346644, 13.655657403659154, 13.815374102811273, 13.974477659630328, 14.132979665586895, 14.290891323569067, 14.448223466422851, 14.60498657435249, 14.761190791266046, 14.9168459401441, 15.071961537502736, 15.226546807015778, 15.380610692355926, 15.53416186930929, 15.687208757213508, 15.839759529765482, 15.991822125241095, 16.143404256165923, 16.294513418472945, 16.445156900180425, 16.595341789620655, 16.74507498324796, 16.89436319305217, 17.043212953601916, 17.191630628740377, 17.339622417954292, 17.48719436243585, 17.634352350855462, 17.781102124862272, 17.927449284328116, 18.073399292349524, 18.21895748002146, 18.364129050995437, 18.508919085834037, 18.653332546172805, 18.797374278700097, 18.941049018964467, 19.084361395018846, 19.227315930910002], [0.0, 0.6123539276009053, 1.0298524451722681, 1.395865099320239, 1.7319984587712658, 2.047528761486697, 2.3475559163923188, 2.6352755807154904, 2.912862590411432, 3.1818843444573663, 3.4435191913260828, 3.6986822369741366, 3.9481027094038996, 4.192374029115246, 4.431987578058614, 4.667356261126802, 4.8988314208072445, 5.126715278349202, 5.3512702780122305, 5.572726234394741, 5.791285887686946, 6.007129283261561, 6.2204172684682835, 6.431294316556435, 6.639890830782434, 6.8463250420230475, 7.050704584971567, 7.253127817604495, 7.453684933676962, 7.652458906930896, 7.8495262973870155, 8.044957943782455, 8.238819561378147, 8.43117226061583, 8.622072999180586, 8.811574977722975, 8.999727987668468, 9.186578718082547, 9.372171027385741, 9.55654618476214, 9.73974308533076, 9.921798442514667, 10.102746960520527, 10.28262148940872, 10.461453164874566, 10.639271534560612, 10.81610467246779, 10.991979282820624, 11.166920794561916, 11.340953447499533, 11.514100370997836, 11.686383655994883, 11.857824421031038, 12.028442872892379, 12.198258362401237, 12.367289435824796, 12.535553882319158, 12.703068777779839, 12.869850525429099, 13.035914893434876, 13.20127704982501, 13.365951594932962, 13.529952591587122, 13.693293593234428, 13.855987670170128, 14.018047434028809, 14.179485060676818, 14.34031231163311, 14.500540554133599, 14.660180779943548, 14.819243623013161, 14.977739376062944, 15.135678006177882, 15.293069169482578, 15.449922224963355, 15.606246247497753, 15.762050040146786, 15.917342145760866, 16.072130857946092, 16.22642423143389, 16.38023009189358, 16.53355604522445, 16.686409486360944, 16.83879760762211, 16.990727406634143, 17.142205693852638, 17.293239099709208, 17.443834081405424, 17.5939969293753, 17.74373377343611, 17.89305058864581, 18.041953200884294, 18.190447292174234, 18.338538405756506, 18.48623195093392, 18.63353320769624, 18.780447331138557, 18.92697935568425, 19.073134199123228, 19.218916666475153, 19.36433145368709, 19.50938315117417], [0.0, 0.6211648928681237, 1.0446706633885259, 1.4159497568254467, 1.7569196319282625, 2.0769899994863783, 2.381334149387774, 2.673193720151947, 2.954774840754703, 3.227667462977007, 3.4930668901718196, 3.7519013954633036, 4.004910699482866, 4.252696761268599, 4.495758033109027, 4.734513361053699, 4.9693191429449906, 5.2004819485972815, 5.428267998496834, 5.652910413970984, 5.874614852373848, 6.093563949693558, 6.3099208676610035, 6.523832158304987, 6.735430101212777, 6.944834628447496, 7.152154923423694, 7.357490759359412, 7.560933627778944, 7.7625676963069115, 7.962470626561743, 8.160714276556558, 8.357365307108209, 8.55248570795708, 8.746133256334213, 8.938361918377346, 9.129222201944888, 9.318761467896387, 9.507024205717185, 9.694052278400498, 9.879885140714798, 10.064560034340879, 10.248112162833161, 10.430574848921065, 10.611979676301493, 10.792356617768592, 10.971734151271137, 11.150139365272215, 11.327598054603577, 11.504134807851944, 11.679773087182726, 11.854535301393437, 12.028442872892379, 12.201516299214626, 12.37377520961532, 12.545238417217968, 12.715923967141155, 12.885849180980012, 13.055030697977534, 13.22348451318479, 13.391226012877537, 13.558270007468774, 13.72463076213244, 13.890322025331697, 14.055357055426104, 14.219748645515027, 14.383509146659474, 14.54665048961114, 14.709184205165474, 14.87112144324474, 15.032472990807653, 15.193249288673398, 15.353460447340158, 15.51311626187144, 15.672226225917028, 15.830799544929981, 15.988845148635749, 16.146371702805094, 16.303387620378167, 16.459901071983353, 16.615919995891026, 16.771452107439348, 16.926504907966095, 17.081085693278304, 17.235201561688793, 17.388859421646618, 17.54206599898656, 17.694827843820796, 17.8471513370944, 17.99904269682462, 18.150507984042623, 18.301553108455025, 18.45218383384131, 18.602405783202276, 18.75222444367347, 18.901645171216742, 19.0506731951022, 19.199313622191934, 19.34757144103636, 19.495451525793044, 19.64295863997753, 19.790097440054964], [0.0, 0.629934392084505, 1.0594191442977765, 1.4359398921751474, 1.7817235213823162, 2.106312587388645, 2.414953415699774, 2.7109334097307736, 2.9964898442072294, 3.2732351175761307, 3.542381408277776, 3.8048700946367786, 4.061451340533307, 4.3127356033597115, 4.559228372468274, 4.801354407105093, 5.0394751366760415, 5.273901459095457, 5.504903353304679, 5.732717231797884, 5.957551655364374, 6.179591838415776, 6.399003246172258, 6.615934499658985, 6.830519745963702, 7.042880610329796, 7.253127817604496, 7.461362549586993, 7.6676775894631986, 7.872158293121794, 8.074883418594595, 8.275925838373796, 8.475353154382214, 8.673228231520731, 8.869609662709408, 9.064552175970647, 9.258106992224116, 9.450322140961843, 9.64124273976408, 9.830911242638585, 10.019367661369472, 10.206649763409185, 10.392793249309877, 10.577831912245538, 10.761797781806271, 10.944721253936985, 11.126631208633237, 11.307555116788388, 11.487519137401183, 11.66654820619579, 11.844666116572439, 12.021895593692193, 12.198258362401237, 12.37377520961532, 12.548466041712038, 12.722349937415338, 12.895445196601694, 13.067769385409537, 13.239339377991834, 13.410171395215041, 13.58028104057571, 13.749683333577703, 13.918392740788237, 14.086423204768913, 14.253788171058531, 14.420500613367238, 14.586573057126197, 14.752017601523406, 14.916845940144102, 15.081069380323234, 15.24469886130795, 15.407744971319124, 15.570217963593217, 15.732127771478757, 15.893484022655244, 16.054296052536742, 16.21457291691703, 16.37432340390874, 16.533556045224454, 16.692279126844088, 16.850500699109162, 17.008228586281643, 17.165470395601915, 17.322233525877962, 17.47852517563536, 17.634352350855465, 17.78972187232723, 17.94464038263621, 18.099114352812542, 18.253150088658384, 18.4067537367735, 18.55993129029672, 18.71268859437959, 18.865031351407456, 19.016965125982306, 19.168495349680537, 19.319627325598198, 19.470366232695177, 19.62071712994939, 19.770684960330914, 19.9202745546058, 20.069490634978358], [0.0, 0.6386633830041154, 1.0740994986439416, 1.4558376885764934, 1.8064128360710052, 2.135499727637228, 2.448417387030454, 2.748498771162943, 3.0380121566408085, 3.3185922848908485, 3.591468131490858, 3.8575941194300243, 4.117730807597551, 4.372497112484232, 4.622405528000317, 4.8678866992740675, 5.109307064032925, 5.346981828298713, 5.5811847121066975, 5.812155403915251, 6.040105354537238, 6.265222344897463, 6.487674133065035, 6.707611399504316, 6.925170150177127, 7.140473695685931, 7.353634295190418, 7.564754532564371, 7.77392847668884, 7.981242666227712, 8.186776950561601, 8.39060521197568, 8.592795989151535, 8.793413018107994, 8.99251570368628, 9.190159532274139, 9.386396434558714, 9.581275105575946, 9.774841288099681, 9.967138024422196, 10.158205880770263, 10.348083147939317, 10.536806021183498, 10.724408761948276, 10.910923843657278, 11.09638208345154, 11.280812761516263, 11.464243729408539, 11.646701508611951, 11.828211380384602, 12.008797467831489, 12.188482811015875, 12.367289435824796, 12.545238417217968, 12.722349937415338, 12.898643339514436, 13.074137176972831, 13.248849259342663, 13.422796694601765, 13.595995928388882, 13.768462780417975, 13.940212478317935, 14.111259689118967, 14.28161854858453, 14.451302688568045, 14.620325262556154, 14.78869896954472, 14.956436076380001, 15.123548438685056, 15.290047520480401, 15.455944412598157, 15.621249849980003, 15.785974227941342, 15.95012761747695, 16.113719779676934, 16.276760179316046, 16.439257997674048, 16.60122214464031, 16.76266127015123, 16.923583775005415, 17.083997821097828, 17.243911341111122, 17.40333204769909, 17.56226744219488, 17.72072482287392, 17.87871129279934, 18.03623376727566, 18.193298980934635, 18.34991349447537, 18.506083701079422, 18.661815832519885, 18.81711596498243, 18.971990024614765, 19.1264437928201, 19.280482911309033, 19.434112886923227, 19.58733909624364, 19.740166789994937, 19.892601097257206, 20.044647029495184, 20.196309484414765, 20.347593249655777], [0.0, 0.6473527842827907, 1.08871327141582, 1.4756452401119458, 1.830990174345415, 2.1645544919430475, 2.481729585192684, 2.785893757899527, 3.0793461479436663, 3.3637437383969075, 3.640332225792468, 3.910079018621074, 4.173755023635232, 4.431987578058615, 4.685296148590824, 4.934117239547341, 5.178822274262328, 5.41973074732602, 5.657120102900177, 5.8912332905494935, 6.122284638002925, 6.350464481058237, 6.575942860234448, 6.7988725060946935, 7.019391275044099, 7.23762415540039, 7.453684933676963, 7.667677589463198, 7.8796974715041195, 8.08983229587443, 8.298162998353826, 8.504764466440612, 8.709706171326562, 8.913052716197551, 9.114864314133571, 9.315197206448202, 9.514104030376968, 9.7116341434812, 9.90783391089283, 10.102746960520525, 10.296414410519091, 10.488875072653377, 10.680165634635825, 10.870320824059577, 11.059373556168813, 11.24735506739039, 11.434295036284134, 11.620221693344396, 11.80516192089557, 11.989141344162553, 12.172184414459764, 12.354314485324455, 12.535553882319158, 12.715923967141155, 12.895445196601694, 13.074137176972831, 13.252018714143146, 13.429107859974488, 13.605421955209072, 13.780977669238501, 13.955791037013496, 14.129877493344045, 14.303251904814163, 14.475928599512915, 14.647921394763323, 14.819243623013161, 14.989908156035812, 15.159927427575385, 15.329313454557857, 15.498077856978671, 15.66623187656742, 15.833786394321155, 16.000751946989823, 16.167138742590172, 16.33295667501784, 16.498215337821552, 16.662924037197943, 16.827091804260803, 16.990727406634143, 17.15383935941451, 17.316435935544384, 17.478525175635358, 17.64011489727654, 17.80121270386125, 17.96182599296236, 18.121961964284473, 18.281627627219006, 18.440829808026436, 18.59957515666816, 18.757870153308822, 18.915721114508564, 19.073134199123224, 19.230115413929344, 19.386670618989612, 19.542805532773503, 19.698525737046594, 19.85383668154148, 20.0087436884221, 20.163251956552784, 20.31736656558227, 20.4710924798527, 20.624434552142638], [0.0, 0.6560034777426357, 1.1032619456555046, 1.4953645569012148, 1.8554580303751047, 2.1934798288560184, 2.5148933907913817, 2.8231221648770064, 3.1204960127922865, 3.408694060176373, 3.688978650032715, 3.9623301185083437, 4.229529674123464, 4.491213037323615, 4.747906616536762, 5.000052749165253, 5.248027821941087, 5.492155598919047, 5.732717231797884, 5.969958916721689, 6.204097845519994, 6.435326897482586, 6.663818385410985, 6.8897270808347315, 7.113192682359265, 7.33434184854402, 7.553289886452352, 7.770142165171878, 7.984995307610312, 8.197938202008283, 8.409052865705084, 8.618415186934339, 8.826095565244039, 9.032159467124231, 9.236667910293288, 9.439677887627731, 9.641242739764078, 9.841412483837761, 10.040234104566437, 10.237751812866483, 10.434007276362117, 10.629039825466883, 10.822886638157831, 11.015582906099267, 11.207161984387788, 11.397655526868332, 11.587093608700732, 11.775504837628594, 11.96291645520972, 12.149354429103571, 12.33484353737194, 12.51940744562966, 12.703068777779839, 12.885849180980012, 13.067769385409537, 13.248849259342663, 13.429107859974488, 13.60856348039719, 13.787233693080493, 13.965135390172117, 14.142284820900763, 14.318697626334597, 14.494388871722517, 14.669373076622453, 14.843664243000841, 15.01727588146939, 15.190221035809335, 15.362512305919186, 15.53416186930929, 15.705181501255213, 15.875582593711833, 16.045376173080953, 16.21457291691703, 16.383183169648408, 16.551216957384657, 16.718684001874845, 16.88559373367601, 17.051955304586368, 17.217777599393287, 17.383069246982107, 17.54783863084815, 17.71209389905117, 17.87584297364814, 18.03909355963792, 18.201853153448493, 18.364129050995437, 18.525928355337935, 18.687257983957043, 18.848124675678793, 19.008534997263464, 19.168495349680537, 19.32801197408777, 19.487090957531347, 19.645738238383057, 19.80395961152932, 19.961760733325864, 20.11914712633106, 20.276124183829893, 20.432697174160065, 20.58887124485059, 20.744651426583022, 20.90004263698449], [0.0, 0.6646163104680073, 1.1177469459833944, 1.5149975698790705, 1.8798188000764475, 2.2222785707733985, 2.5479120512587987, 2.8601876375373725, 3.1614657806216475, 3.45344765180868, 3.737412167716998, 4.014352535570595, 4.285060220570525, 4.550179289694083, 4.810243062716335, 5.065699684597339, 5.31693048374406, 5.564263474990035, 5.807983501344555, 6.048339991322085, 6.285552988317677, 6.519817903981255, 6.751309313451946, 6.980184020293174, 7.206583557248092, 7.430636245807849, 7.652458906930897, 7.872158293121794, 8.08983229587443, 8.30557097046524, 8.519457411059552, 8.731568502246471, 8.941975567867157, 9.150744933937476, 9.357938419292594, 9.563613765082675, 9.767825012266709, 9.970622834667537, 10.172054833876851, 10.37216580126714, 10.570997951527216, 10.768591131449405, 10.96498300712965, 11.16020923227237, 11.354303599901518, 11.547298179453229, 11.739223440951584, 11.930108367738368, 12.119980559032568, 12.308866323429495, 12.496790764308281, 12.683777857995498, 12.869850525429099, 13.055030697977534, 13.239339377991834, 13.422796694601765, 13.605421955209072, 13.787233693080493, 13.96824971139907, 14.14848712409373, 14.327962393733337, 14.506691366741533, 14.684689306162609, 14.861970922185382, 15.038550400611584, 15.214441429437105, 15.38965722369823, 15.56421054872066, 15.73811374189631, 15.911378733101262, 16.084017063858205, 16.256039905337307, 16.427458075281294, 16.598282053933083, 16.768521999037524, 16.938187759982952, 17.107288891142527, 17.2758346644707, 17.443834081405424, 17.611295884122814, 17.77822856618719, 17.944640382636205, 18.110539359537494, 18.27593330305075, 18.440829808026436, 18.60523626617001, 18.76915987379849, 18.932607639214254, 19.095586389719067, 19.25810277828982, 19.420163289935928, 19.581774247756854, 19.742941818717128, 19.903672019154893, 20.063970720039077, 20.22384365198911, 20.383296410070397, 20.542334458377713, 20.700963134418064, 20.85918765330366, 21.017013111765124, 21.174444491994326], [0.0, 0.6731920967482075, 1.132169641865399, 1.5345461352237226, 1.9040747866073917, 2.2509534404355667, 2.5807886883021407, 2.8970936801885356, 3.2022593248662745, 3.498008744465156, 3.7856373579305673, 4.066151188200998, 4.3403519130412125, 4.6088919100592545, 4.872311380649462, 5.13106425234951, 5.3855367739856606, 5.6360611928863, 5.882926027493793, 6.126383924789563, 6.366657767468714, 6.603945488648855, 6.838423916075703, 7.0702518766061635, 7.299572729231915, 7.526516451223037, 7.751201370921347, 7.973735618297846, 8.19421834797602, 8.412740777248326, 8.629387072474369, 8.844235110313107, 9.057357134923194, 9.26882032814923, 9.478687306497326, 9.687016556172733, 9.893862815444614, 10.0992774119986, 10.303308561647054, 10.506001633721857, 10.70739938762332, 10.907542184301445, 11.106468175871527, 11.304213476090714, 11.500812314026657, 11.6962971729191, 11.890698915957945, 12.084046900467586, 12.276369081789785, 12.467692107989238, 12.658041406363123, 12.847441262613282, 13.035914893434876, 13.22348451318479, 13.410171395215041, 13.595995928388882, 13.780977669238501, 13.965135390172117, 14.14848712409373, 14.331050205759526, 14.512841310160887, 14.69387648819363, 14.874171199846668, 15.053740345119737, 15.232598292859137, 15.410758907681954, 15.588235575142896, 15.765041225283312, 15.941188354688979, 16.116689047171512, 16.291554993178067, 16.465797508024497, 16.6394275490388, 16.81245573169428, 16.98489234480487, 17.156747364849146, 17.328030469483828, 17.49875105030277, 17.668918224892757, 17.838540848233386, 18.007627523484537, 18.176186612201608, 18.344226244015513, 18.51175432581167, 18.67877855043966, 18.845306404982804, 19.011345178614825, 19.17690197006878, 19.341983694741586, 19.50659709145593, 19.670748728899653, 19.83444501176148, 19.99769218658053, 20.160496347325946, 20.322863440721907, 20.48479927133211, 20.646309506417133, 20.807399680576946, 20.96807520019036, 21.128341347662072, 21.288203285487675, 21.447666060146084], [0.0, 0.6817316198804996, 1.1465313506452404, 1.5540120384668112, 1.9282282054671644, 2.279507056954778, 2.6135263048157182, 2.9338436637636414, 3.242880371536883, 3.5423814082777754, 3.8336586254776357, 4.1177308075975505, 4.395409801781649, 4.667356261126802, 4.934117239547341, 5.196152422706633, 5.453852959043998, 5.707555310485349, 5.957551655364373, 6.204097845519995, 6.447419590941253, 6.687717335551281, 6.925170150177127, 7.15993887641358, 7.3921686917784575, 7.621991222319223, 7.849526297387016, 8.074883418594595, 8.298162998353826, 8.519457411059552, 8.738851890731825, 8.956425301904437, 9.172250805161925, 9.386396434558714, 9.598925600898863, 9.809897532292204, 10.01936766136947, 10.227387966914183, 10.434007276362117, 10.639271534560612, 10.843224043318143, 11.045905675568239, 11.247355067390393, 11.447608790649126, 11.646701508611951, 11.844666116572437, 12.041533869223779, 12.23733449629158, 12.432096307734493, 12.625846289651138, 12.818610191887029, 13.01041260821107, 13.20127704982501, 13.391226012877537, 13.58028104057571, 13.768462780417975, 13.955791037013496, 14.142284820900763, 14.327962393733337, 14.512841310160887, 14.696938456699074, 14.880270087851274, 15.062851859718219, 15.24469886130795, 15.42582564373732, 15.606246247497754, 15.785974227941344, 15.965022679128575, 16.143404256165923, 16.32113119614962, 16.498215337821552, 16.674668140033724, 16.850500699109162, 17.025723765179734, 17.200347757574225, 17.374382779324044, 17.547838630848155, 17.72072482287392, 17.893050588645814, 18.064824895469915, 18.236056455638227, 18.4067537367735, 18.576924971631986, 18.746578167398905, 18.915721114508564, 19.084361395018846, 19.252506390567522, 19.420163289935928, 19.58733909624364, 19.754040633796112, 19.920274554605797, 20.086047344605664, 20.251365329572934, 20.41623468077949, 20.580661420384423, 20.744651426583026, 20.908210438525753, 21.07134406101966, 21.234057769024112, 21.396356911951756, 21.558246717785064, 21.71973229701814], [0.0, 0.6902356338456498, 1.160833340362365, 1.573396998312813, 1.952281189235416, 2.3079419414176696, 2.646127791304399, 2.9704408330317866, 3.28333250719064, 3.586569561045522, 3.881480210303634, 4.169095947883514, 4.450238748022197, 4.725577504894123, 4.995666096439375, 5.260969942503488, 5.5218850707652, 5.77875214022275, 6.031866973882536, 6.2814886151145, 6.52784558944512, 6.771140841162587, 7.011555674848069, 7.249252938456523, 7.484379620470088, 7.7170689888576405, 7.947442367738124, 8.175610624662468, 8.401675424600775, 8.62573029423879, 8.847861530817449, 9.068148982637583, 9.286666722898921, 9.50348363432204, 9.718663918706081, 9.93226754298047, 10.144350631250193, 10.354965810689265, 10.564162517813608, 10.771987270592906, 10.978483910988347, 11.18369382178805, 11.387656121023282, 11.590407836761027, 11.791984064663163, 11.992418110363674, 12.191741618431095, 12.389984689443718, 12.587175986502508, 12.783342832334393, 12.978511297991997, 13.172706284030284, 13.365951594932962, 13.558270007468774, 13.749683333577703, 13.940212478317935, 14.129877493344045, 14.318697626334597, 14.506691366741533, 14.69387648819363, 14.880270087851274, 15.065888622978742, 15.250747944973126, 15.434863331064829, 15.61824951388333, 15.800920709063082, 15.982890641047495, 16.16417256723417, 16.344779300591128, 16.524723230861806, 16.704016344466197, 16.882670243195594, 17.060696161790087, 17.238104984480167, 17.414907260566753, 17.591113219107864, 17.766732782774238, 17.94177558093135, 18.11625096200044, 18.290168005147002, 18.46353553134136, 18.636362113832554, 18.808656088073377, 18.98042556113177, 19.151678420620996, 19.322422343178566, 19.492664802521816, 19.66241307710593, 19.83167425740836, 20.000455252861887, 20.168762798457077, 20.336603461033324, 20.50398364527646, 20.67090959943966, 20.837387420803264, 21.00342306088797, 21.169022330435197, 21.334190904167123, 21.498934325338517, 21.66325801009133, 21.82716725162261, 21.990667224175464], [0.0, 0.6987048648669425, 1.175076832373886, 1.59270267019283, 1.9762357919817817, 2.3362605220981445, 2.67859593186034, 3.006888313307273, 3.3236191863471314, 3.6305769763352735, 3.929106196262203, 4.220250995524037, 4.504843434029087, 4.783560613321877, 5.056963207456748, 5.325522347007574, 5.589638918935542, 5.849657762144437, 6.105878329406004, 6.358562842567267, 6.607942631176089, 6.854223129658777, 7.097587867214165, 7.3382016899510045, 7.576213389908584, 7.811757870261442, 8.044957943782455, 8.275925838373798, 8.504764466440612, 8.731568502246473, 8.956425301904437, 9.179415693458589, 9.40061465899109, 9.62009192641747, 9.837912485296645, 10.054137038355725, 10.268822398345698, 10.482021838179039, 10.69378540096057, 10.904160175438145, 11.113190541516344, 11.320918389752485, 11.527383318158327, 11.732622809137375, 11.9366723889773, 12.139565771974137, 12.341334990977101, 12.542010515900314, 12.741621361542643, 12.94019518588245, 13.137758379865678, 13.334336149578537, 13.529952591587122, 13.72463076213244, 13.918392740788237, 14.111259689118967, 14.303251904814163, 14.494388871722517, 14.684689306162609, 14.874171199846668, 15.062851859718219, 15.250747944973126, 15.437875501506037, 15.624249993999848, 15.809886335854257, 15.994798917130367, 16.179001630671305, 16.3625078965437, 16.545330684931425, 16.727482537600793, 16.90897558804586, 17.08982158041256, 17.2700318872919, 17.449617526464497, 17.62858917667181, 17.806957192482983, 17.9847316183205, 18.161922201702705, 18.338538405756506, 18.514589421049276, 18.69008417678516, 18.865031351407456, 19.039439382645437, 19.21331647704125, 19.386670618989612, 19.559509579320824, 19.73184092345517, 19.903672019154893, 20.07501004389801, 20.245861991896447, 20.41623468077949, 20.586134757962025, 20.75556870671576, 20.92454285196029, 21.093063365789934, 21.261136272750896, 21.428767454882728, 21.59596265653677, 21.762727488983856, 21.929067434822304, 22.094987852196994, 22.260493978839303], [0.0, 0.7071400128625219, 1.1892630037971208, 1.6119306495752115, 2.0000939933737274, 2.36446513931357, 2.710933409730774, 3.043189116699783, 3.363743738396908, 3.674407291028393, 3.976540519282312, 4.27120017809845, 4.559228372468274, 4.841310378277184, 5.118013638343931, 5.389814970988844, 5.657120102900177, 5.920278036065923, 6.179591838415776, 6.435326897482587, 6.687717335551282, 6.936971067165132, 7.183273837188029, 7.426792481841277, 7.6676775894631986, 7.906065691853376, 8.14208108444778, 8.37583735002531, 8.607438643406066, 8.836980781813203, 9.064552175970647, 9.29023462972292, 9.514104030376968, 9.736230947641923, 9.956681155666272, 10.175516090013707, 10.392793249309877, 10.608566549607051, 10.822886638157835, 11.035801172191245, 11.247355067390393, 11.457590720038356, 11.66654820619579, 11.874265460774318, 12.080778438954418, 12.286121262049583, 12.490326349627138, 12.693424539450701, 12.895445196601695, 13.096416312960748, 13.296364598079768, 13.495315562346644, 13.693293593234428, 13.890322025331697, 14.086423204768913, 14.28161854858453, 14.475928599512915, 14.669373076622453, 14.861970922185382, 15.053740345119737, 15.24469886130795, 15.434863331064829, 15.624249993999848, 15.812874501494038, 16.000751946989823, 16.18789689427301, 16.37432340390874, 16.560045057978044, 16.745074983247964, 16.92942587289588, 17.113110006898044, 17.296139271182152, 17.47852517563536, 17.660278871050977, 17.841411165090072, 18.021932537327828, 18.201853153448496, 18.38118287864781, 18.55993129029672, 18.738107689916177, 18.915721114508564, 19.0927803472881, 19.26929392784896, 19.44527016180715, 19.62071712994939, 19.795642696919693, 19.97005451947224, 20.143960054316945, 20.317366565582272, 20.490281131918103, 20.662710653259875, 20.834661857273723, 21.00614130550095, 21.177155399219053, 21.347710385035256, 21.51781236022739, 21.6874672778462, 21.85668095159199, 22.025459060477928, 22.193807153291267, 22.361730652863347, 22.529234860158304], [0.0, 0.7155417527999327, 1.203392989787646, 1.631082475053238, 2.023857702507763, 2.392558049953953, 2.7431428125108486, 3.0793461479436663, 3.4037093740447935, 3.718064012359121, 4.023786974985394, 4.321947572481834, 4.61339791513873, 4.8988314208072445, 5.178822274262328, 5.4538529590439975, 5.724334022399463, 5.990618612912705, 6.2530133993532555, 6.511786922401845, 6.767176086019612, 7.019391275044098, 7.268620441228936, 7.515032403025993, 7.758779537958237, 8.000000000000002, 8.238819561378147, 8.475353154382214, 8.709706171326562, 8.941975567867159, 9.172250805161925, 9.40061465899109, 9.62714391830117, 9.851909991260912, 10.074979433500946, 10.29641441051909, 10.516273104099193, 10.734610070886113, 10.951476559887462, 11.166920794561914, 11.38098822424911, 11.593721748954927, 11.805161920895568, 12.015347125698574, 12.224313745738574, 12.432096307734492, 12.638727616440132, 12.844238876011723, 13.048659800425908, 13.252018714143146, 13.45434264405944, 13.655657403659154, 13.855987670170128, 14.055357055426104, 14.253788171058531, 14.451302688568045, 14.647921394763323, 14.843664243000841, 15.038550400611584, 15.232598292859137, 15.42582564373732, 15.61824951388333, 15.809886335854257, 16.000751946989823, 16.19086162006211, 16.38023009189358, 16.568871590107115, 16.756799858156473, 16.944028178771696, 17.130569395941574, 17.316435935544384, 17.501639824728063, 17.686192710132133, 17.870105875035783, 18.05339025550911, 18.236056455638227, 18.418114761888898, 18.59957515666816, 18.780447331138554, 18.960740697335147, 19.14046439963163, 19.31962732559819, 19.498238116290448, 19.6763051760059, 19.853836681541477, 20.030840590983363, 20.207324652057906, 20.383296410070393, 20.558763215456548, 20.733732230969796, 20.90821043852575, 21.08220464572393, 21.255721492065266, 21.428767454882724, 21.601348855001316, 21.773471862142436, 21.945142500086796, 22.11636665160899, 22.287150063196226, 22.457498349562535, 22.62741699796953, 22.79691137236367], [0.0, 0.7239107359608681, 1.2174678856663448, 1.650159631228126, 2.047528761486697, 2.4205414317108858, 2.7752266369922456, 3.1153622098408085, 3.4435191913260828, 3.7615505244864065, 4.070849225797556, 4.372497112484233, 4.667356261126803, 4.956128199798226, 5.239393828944053, 5.517641275236385, 5.791285887686946, 6.060684945308924, 6.326148703672699, 6.587948844313365, 6.846325042023048, 7.101490142302354, 7.353634295190418, 7.6029282936413285, 7.849526297387016, 8.093568076252016, 8.335180873496348, 8.574480965658712, 8.811574977722977, 9.046560999339388, 9.279529538004423, 9.510564337644626, 9.73974308533076, 9.967138024422198, 10.192816488984858, 10.416841371604812, 10.639271534560613, 10.860162172592151, 11.079565134115922, 11.297529206612635, 11.514100370997838, 11.729322029036283, 11.943235207243283, 12.155878740205045, 12.3672894358248, 12.5775022246463, 12.78655029510807, 12.99446521633044, 13.201277049825013, 13.407014451335403, 13.611704763864447, 13.815374102811273, 14.018047434028809, 14.219748645515027, 14.420500613367238, 14.620325262556154, 14.819243623013161, 15.01727588146939, 15.214441429437105, 15.410758907681954, 15.606246247497754, 15.800920709063082, 15.994798917130367, 16.18789689427301, 16.38023009189358, 16.571813419176557, 16.762661270151234, 16.952787549014936, 17.14220569385264, 17.33092869887656, 17.51896913529815, 17.706339170934992, 17.893050588645814, 18.079114803679147, 18.264542880013465, 18.449345545760377, 18.633533207696242, 18.81711596498243, 19.000103622129416, 19.18250570125551, 19.36433145368709, 19.54558987094345, 19.726289695146072, 19.9064394288892, 20.086047344605664, 20.265121493459496, 20.443669713794524, 20.621699639166, 20.799218705980415, 20.976234160766822, 21.15275306710139, 21.328782312205387, 21.504328613235405, 21.679398523283364, 21.853998437102703, 22.02813459657594, 22.201813095937972, 22.375039886768395, 22.547820782765378, 22.720161464312703, 22.892067482851047, 23.063544265063637], [0.0, 0.7322475911233669, 1.231488748907614, 1.6691635514038519, 2.071108948763389, 2.4484173870304544, 2.807187293695317, 3.1512400083482324, 3.483176181230046, 3.804870094636779, 4.117730807597551, 4.422852595991243, 4.721107464428337, 5.01320502006896, 5.299732853248228, 5.5811847121066975, 5.857980728986937, 6.13048229747488, 6.399003246172259, 6.663818385410986, 6.925170150177128, 7.183273837188029, 7.438321786329244, 7.690486757477094, 7.939924685730684, 8.186776950561603, 8.431172260615831, 8.673228231520733, 8.913052716197553, 9.150744933937478, 9.386396434558716, 9.62009192641747, 9.851909991260914, 10.081923704432798, 10.310201175445965, 10.5368060211835, 10.761797781806271, 10.985232287699608, 11.20716198438779, 11.427636221208314, 11.646701508611953, 11.864401748196116, 12.080778438954418, 12.295870862708206, 12.509716251255737, 12.72234993741534, 12.933805491837305, 13.144114847205, 13.353308411230818, 13.561415169669761, 13.768462780417979, 13.974477659630328, 14.179485060676818, 14.383509146659474, 14.586573057126197, 14.78869896954472, 14.989908156035812, 15.190221035809335, 15.38965722369823, 15.588235575142896, 15.785974227941344, 15.982890641047495, 16.179001630671305, 16.37432340390874, 16.568871590107115, 16.762661270151234, 16.955707003837983, 17.148022855491163, 17.339622417954295, 17.530518835086305, 17.720724822873922, 17.910252689264333, 18.099114352812542, 18.287321360229797, 18.474884902911924, 18.66181583251989, 18.848124675678797, 19.03382164785613, 19.218916666475153, 19.403419363314832, 19.58733909624364, 19.770684960330914, 19.953465798376037, 20.135690210892626, 20.317366565582272, 20.49850300632954, 20.679107461747858, 20.859187653303664, 21.03875110304417, 21.217805140952457, 21.396356911951756, 21.574413382579422, 21.75198134734959, 21.929067434822304, 22.105678113395623, 22.28181969683616, 22.45749834956254, 22.632720091695212, 22.807490803885294, 22.981816231934218, 23.155701991215338, 23.329153570907813], [0.0, 0.7405529256680133, 1.245456600999766, 1.6880956201087438, 2.0945999822695587, 2.4761879468120447, 2.839027111109878, 3.186982157338651, 3.5226832329619318, 3.8480258788523325, 4.164435135937408, 4.473017691645585, 4.774655441080812, 5.0700660399443525, 5.359843743167243, 5.644487899104417, 5.9244234053441085, 6.200015754488307, 6.471582334660903, 6.739401073161036, 7.003717154732764, 7.264748318042417, 7.522689084542436, 7.777714173594684, 8.029981288952996, 8.279633413650137, 8.526800716177606, 8.771602146188505, 9.014146779898772, 9.254534961969506, 9.492859280599752, 9.729205404928987, 9.96365280799813, 10.196275393989682, 10.427142044931543, 10.656317099265326, 10.883860772471238, 11.109829528176737, 11.334276406756306, 11.557251317279917, 11.778801297731455, 11.998970747651185, 12.217801636724642, 12.435333692317375, 12.651604568519966, 12.86664999890437, 13.080503934887554, 13.293198671341337, 13.504764960869954, 13.715232117992059, 13.924628114306552, 14.132979665586895, 14.34031231163311, 14.54665048961114, 14.752017601523406, 14.956436076380001, 15.159927427575385, 15.362512305919186, 15.56421054872066, 15.765041225283312, 15.965022679128575, 16.16417256723417, 16.3625078965437, 16.560045057978044, 16.756799858156473, 16.952787549014936, 17.148022855491163, 17.342520001430017, 17.536292733848445, 17.729354345686282, 17.92171769715815, 18.11339523581104, 18.304399015383176, 18.49474071355148, 18.68443164864737, 18.873482795414063, 19.061904799872263, 19.249707993355827, 19.436902405773907, 19.623497778151503, 19.80950357449636, 19.99492899303637, 20.179782976868132, 20.36407422405444, 20.547811197205437, 20.731002132575657, 20.913655048706836, 21.095777754644207, 21.277377857751915, 21.45846277115153, 21.63903972080579, 21.819115752268242, 21.998697737118107, 22.177792379098193, 22.356406219972744, 22.53454564512069, 22.712216888879034, 22.889426039649916, 23.06617904478427, 23.242481715253838, 23.41833973012294, 23.593758640830373], [0.0, 0.7488273266140879, 1.2593724291876183, 1.706957175457394, 2.1180035223464615, 2.50385507387292, 2.870748339667457, 3.2225911830595586, 3.56204313887176, 3.891020927374724, 4.2109655118691265, 4.522995945105558, 4.828003975843836, 5.126715278349201, 5.41973074732602, 5.707555310485348, 5.990618612912705, 6.269290230959166, 6.543891099013179, 6.814702249731822, 7.081971607375544, 7.3459193434645105, 7.606742152892701, 7.86461670720933, 8.119702472235526, 8.372144028592693, 8.622072999180588, 8.86960966270941, 9.114864314133571, 9.357938419292594, 9.598925600898863, 9.837912485296645, 10.074979433500948, 10.310201175445965, 10.54364736279739, 10.775383052867891, 11.005469133941748, 11.233962700530016, 11.46091738564183, 11.686383655994884, 11.910409075141365, 12.133038538709775, 12.354314485324455, 12.574277086235707, 12.792964416253593, 13.01041260821107, 13.226655992873598, 13.441727225952453, 13.655657403659156, 13.868476168051515, 14.080211803262777, 14.290891323569067, 14.500540554133599, 14.709184205165474, 14.916845940144102, 15.123548438685056, 15.329313454557857, 15.53416186930929, 15.73811374189631, 15.941188354688979, 16.143404256165923, 16.344779300591128, 16.545330684931425, 16.745074983247964, 16.944028178771696, 17.14220569385264, 17.339622417954295, 17.536292733848445, 17.732230542151214, 17.927449284328116, 18.121961964284473, 18.31578116864713, 18.508919085834037, 18.701387523999998, 18.89319792793926, 19.084361395018846, 19.274888690210375, 19.464790260282534, 19.654076247211396, 19.842756500861107, 20.030840590983367, 20.218337818580384, 20.405257226672433, 20.591607610508156, 20.77739752725275, 20.96263530518668, 21.147329052445055, 21.331486665325706, 21.51511583619195, 21.698224060994196, 21.88081864643284, 22.062906716783335, 22.24449522040294, 22.425590935937223, 22.606200478243352, 22.786330304045844, 22.965986717339664, 23.145175874554337, 23.323903789492185, 23.50217633805252, 23.679999262753416, 23.857378177061413], [0.0, 0.7570713615910638, 1.2732371881063487, 1.7257495113651926, 2.1413211744926963, 2.531420666196616, 2.90235315546568, 3.258069528314083, 3.601258599075564, 3.9338581896932157, 4.2573251274078086, 4.572790784912982, 4.881156728462795, 5.183156621459386, 5.479397974013346, 5.770391272716351, 6.056570892728512, 6.338310479163164, 6.615934499658985, 6.889727080834732, 7.15993887641358, 7.426792481841276, 7.690486757477093, 7.951200319893321, 8.209094390511826, 8.464315141679712, 8.716995645367504, 8.967257504465033, 9.215212228192579, 9.460962399453502, 9.704602671676998, 9.946220624899317, 10.185897504850791, 10.42370886418692, 10.659725121386717, 10.894012049995737, 11.126631208633237, 11.357640320378604, 11.587093608700734, 11.815042095918555, 12.041533869223779, 12.26661431851257, 12.490326349627136, 12.712710576073526, 12.933805491837303, 13.153647627547185, 13.372271691924967, 13.58971070019715, 13.805996090921544, 14.021157832493088, 14.235224520432416, 14.448223466422851, 14.660180779943548, 14.87112144324474, 15.081069380323234, 15.290047520480401, 15.498077856978671, 15.705181501255213, 15.911378733101262, 16.116689047171512, 16.32113119614962, 16.524723230861806, 16.727482537600793, 16.92942587289588, 17.130569395941574, 17.33092869887656, 17.530518835086305, 17.729354345686282, 17.927449284328116, 18.124817240457915, 18.321471361144376, 18.517424371583797, 18.71268859437959, 18.907275967685617, 19.101198062294838, 19.294466097748085, 19.487090957531347, 19.679083203424508, 19.870453089059293, 20.061210572739572, 20.25136532957293, 20.440926762958732, 20.629904015474214, 20.8183059791972, 21.006141305500947, 21.19341841435413, 21.380145503156424, 21.566330555138062, 21.751981347349588, 21.937105458266284, 22.12171027502991, 22.305803000348924, 22.489390659076857, 22.672480104487153, 22.855078024261662, 23.037190946208668, 23.218825243725448, 23.39998714101927, 23.580682718099965, 23.76091791555616, 23.940698539126792, 24.120030264078526], [0.0, 0.7652855797503654, 1.2870518013148862, 1.7444738796266865, 2.1645544919430475, 2.558886559981587, 2.933843663763642, 3.2934195563847535, 3.640332225792468, 3.9765405192823113, 4.3035170706588515, 4.622405528000317, 4.934117239547342, 5.239393828944053, 5.538849397780836, 5.832999971424762, 6.122284638002925, 6.407081096675119, 6.687717335551281, 6.96448056402169, 7.23762415540039, 7.507373120291919, 7.77392847668884, 8.037470779151812, 8.298162998353826, 8.55615289261077, 8.811574977722977, 9.064552175970647, 9.315197206448202, 9.563613765082675, 9.809897532292206, 10.054137038355726, 10.296414410519091, 10.536806021183498, 10.775383052867891, 11.012211992760264, 11.247355067390393, 11.480870626132612, 11.712813480780015, 11.943235207243283, 12.172184414459764, 12.399706984805634, 12.625846289651138, 12.850643383158541, 13.074137176972833, 13.296364598079766, 13.51736073179048, 13.737158951546421, 13.955791037013496, 14.17328728174349, 14.389676591518196, 14.60498657435249, 14.819243623013161, 15.032472990807653, 15.24469886130795, 15.455944412598157, 15.66623187656742, 15.875582593711833, 16.084017063858205, 16.291554993178067, 16.498215337821552, 16.704016344466197, 16.90897558804586, 17.113110006898044, 17.316435935544384, 17.51896913529815, 17.720724822873922, 17.92171769715815, 18.121961964284473, 18.321471361144376, 18.520259177452143, 18.718338276472352, 18.915721114508564, 19.11241975924351, 19.308445907013166, 19.503810899090286, 19.698525737046598, 19.892601097257206, 20.086047344605664, 20.278874545443355, 20.4710924798527, 20.662710653259875, 20.85373830743901, 21.04418443094689, 21.234057769024112, 21.42336683299594, 21.612119909203766, 21.80032506749581, 21.98799016930355, 22.175122875328665, 22.361730652863343, 22.547820782765374, 22.733400366107887, 22.918476330522285, 23.103055436251726, 23.287144281931145, 23.47074931010914, 23.65387681252557, 23.83653293515833, 24.01872368305138, 24.200454924935883, 24.381732397655092], [0.0, 0.7734705126218592, 1.300817162736349, 1.7631314918679577, 2.1877049780910074, 2.5862545325050585, 2.965221902265399, 3.3286435547194233, 3.679266547418868, 4.0190706780522145, 4.34954433063435, 4.671843384863954, 4.986888936093549, 5.295430539829438, 5.59808886564189, 5.89538545792656, 6.187764100974875, 6.475606533539628, 6.7592442516508475, 7.038967536479651, 7.315032471235085, 7.587666473069963, 7.857072709917758, 8.123433667418189, 8.386914059258952, 8.647663224070433, 8.905817116335236, 9.16149997302005, 9.414825718779998, 9.665899158597641, 9.914816996218647, 10.161668708776832, 10.406537301890793, 10.64949996478488, 10.890628641294011, 11.129990529704346, 11.36764852207495, 11.60366159184224, 11.83808513702602, 12.070971285155053, 12.302369165052209, 12.532325149817881, 12.760883074690657, 12.988084432917988, 13.213968552315265, 13.438572754812169, 13.661932500966584, 13.884081521157787, 14.105051934943665, 14.3248743598736, 14.543578010884417, 14.761190791266046, 14.977739376062944, 15.193249288673398, 15.407744971319124, 15.621249849980003, 15.833786394321155, 16.045376173080953, 16.256039905337307, 16.465797508024497, 16.674668140033724, 16.882670243195594, 17.08982158041256, 17.296139271182152, 17.501639824728063, 17.706339170934992, 17.910252689264333, 18.11339523581104, 18.31578116864713, 18.517424371583797, 18.718338276472352, 18.918535884153414, 19.11802978415402, 19.316832173223986, 19.5149548727947, 19.71240934543686, 19.90920671038692, 20.105357758206658, 20.300872964634816, 20.495762503685086, 20.690036260040472, 20.883703840790208, 21.076774586551654, 21.26925758201661, 21.461161665958343, 21.65249544073301, 21.84326728130662, 22.03348534383657, 22.223157573834445, 22.412291713935158, 22.600895311295577, 22.788975724644203, 22.976540131002032, 23.163595532093332, 23.35014876046385, 23.536206485322683, 23.721775218123202, 23.906861317897093, 24.09147099635512, 24.27561032276679, 24.459285228630907, 24.642501512147785], [0.0, 0.7816266749191567, 1.314534138012399, 1.7817235213823162, 2.210774088766516, 2.6135263048157182, 2.9964898442072294, 3.363743738396908, 3.7180640123591213, 4.061451340533306, 4.395409801781649, 4.721107464428336, 5.039475136676042, 5.3512702780122305, 5.657120102900177, 5.957551655364373, 6.2530133993532555, 6.54389109901318, 6.830519745963702, 7.113192682359265, 7.3921686917784575, 7.667677589463198, 7.939924685730683, 8.209094390511826, 8.475353154382214, 8.738851890731825, 8.999727987668468, 9.258106992224116, 9.514104030376968, 9.76782501226671, 10.01936766136947, 10.268822398345698, 10.516273104099193, 10.761797781806271, 11.005469133941746, 11.24735506739039, 11.487519137401181, 11.726020939278996, 11.962916455209722, 12.198258362401237, 12.432096307734493, 12.664477153309177, 12.895445196601694, 13.125042368401267, 13.353308411230818, 13.58028104057571, 13.805996090921544, 14.030487648330777, 14.253788171058533, 14.475928599512915, 14.696938456699076, 14.9168459401441, 15.135678006177882, 15.353460447340158, 15.570217963593217, 15.785974227941342, 16.000751946989823, 16.21457291691703, 16.427458075281294, 16.6394275490388, 16.850500699109162, 17.060696161790087, 17.2700318872919, 17.47852517563536, 17.686192710132133, 17.893050588645814, 18.099114352812542, 18.304399015383176, 18.508919085834037, 18.71268859437959, 18.915721114508564, 19.11802978415402, 19.319627325598194, 19.520526064204287, 19.720737946059405, 19.9202745546058, 20.11914712633106, 20.317366565582272, 20.514943458563693, 20.711888086572884, 20.90821043852575, 21.10392022281724, 21.29902687856051, 21.493539586244438, 21.687467277846192, 21.88081864643284, 22.0736021552835, 22.26582604656135, 22.457498349562538, 22.648626888567215, 22.839219290316198, 23.029282991134973, 23.218825243725448, 23.407853123644305, 23.596373535485743, 23.784393218784945, 23.971918753657846, 24.15895656619143, 24.345512933598272, 24.53159398914767, 24.717205726885425, 24.902354006153256], [0.0, 0.7897545652974599, 1.3282035657777795, 1.8002511048578131, 2.2337632343794724, 2.6407035442677254, 3.0276494012629485, 3.3987222533883794, 3.7567269926304827, 4.1036850978140205, 4.441116288245018, 4.770200778623417, 5.091879056334137, 5.406916457448026, 5.715946718634631, 6.019502364483773, 6.318036522379682, 6.611938967908948, 6.901548176163798, 7.187160539671638, 7.469037533020237, 7.747411361228056, 8.02248946956982, 8.294458185597408, 8.563485690753685, 8.829724467729587, 9.09331333328872, 9.354379139987218, 9.613038210962188, 9.8693975576796, 10.123555919811329, 10.375604658273879, 10.62562852622224, 10.873706337963256, 11.119911551981957, 11.364312781305488, 11.6069742420739, 11.847956149304942, 12.087315067325669, 12.325104221117703, 12.561373773824332, 12.796171074849495, 13.029540882305149, 13.261525563005629, 13.492165272743872, 13.721498119196735, 13.949560309481383, 14.17638628411053, 14.402008838862509, 14.62645923588501, 14.849767305183647, 15.071961537502736, 15.293069169482578, 15.51311626187144, 15.732127771478757, 15.95012761747695, 16.167138742590172, 16.383183169648408, 16.598282053933083, 16.81245573169428, 17.025723765179734, 17.238104984480167, 17.449617526464497, 17.660278871050977, 17.870105875035783, 18.079114803679147, 18.287321360229797, 18.49474071355148, 18.701387523999998, 18.907275967685617, 19.11241975924351, 19.316832173223986, 19.520526064204287, 19.723513885715207, 19.925807708067456, 20.127419235155866, 20.32835982031273, 20.52864048127602, 20.72827191433261, 20.927264507692033, 21.125628354141806, 21.323373263031428, 21.520508771628425, 21.717044155886697, 21.91298844066424, 22.108350409424595, 22.303138613453864, 22.497361380622895, 22.691026823721955, 22.884142848393438, 23.07671716068624, 23.268757274253865, 23.460270517216784, 23.651264038708174, 23.841744815120947, 24.03171965607259, 24.221195210103595, 24.410177970123815, 24.59867427862058, 24.786690332641136, 24.974232188561484, 25.16130576665279], [0.0, 0.7978546670673515, 1.3418262588607637, 1.8187153440043329, 2.256673781938638, 2.667787866907412, 3.0587024262803397, 3.4335811796291815, 3.795257787258487, 4.145774461249813, 4.486666507879593, 4.819126246696035, 5.144103811173954, 5.46237238703817, 5.774572210865599, 6.081241269073779, 6.382837336538814, 6.679754186572738, 6.972333765830735, 7.260875506784188, 7.545643565829704, 7.826872529591831, 8.104771971003569, 8.379530128681578, 8.651316909018297, 8.920286358640306, 9.186578718082547, 9.450322140961841, 9.7116341434812, 9.970622834667537, 10.227387966914183, 10.482021838179037, 10.734610070886111, 10.985232287699604, 11.233962700530014, 11.48087062613261, 11.726020939278996, 11.969474472581028, 12.211288370516646, 12.451516403968423, 12.69020925057691, 12.927414745384256, 13.163178105563087, 13.397542132462121, 13.63054739373137, 13.86223238789831, 14.092633693437675, 14.321786104100605, 14.549722752034667, 14.776475220027141, 15.00207364403449, 15.226546807015778, 15.449922224963355, 15.672226225917028, 15.893484022655244, 16.113719779676934, 16.33295667501784, 16.551216957384657, 16.768521999037524, 16.98489234480487, 17.200347757574225, 17.414907260566753, 17.62858917667181, 17.841411165090072, 18.05339025550911, 18.264542880013465, 18.474884902911924, 18.68443164864737, 18.89319792793926, 19.101198062294838, 19.308445907013166, 19.5149548727947, 19.720737946059405, 19.925807708067456, 20.130176352928462, 20.333855704578017, 20.536857232793643, 20.73919206831651, 20.94087101713974, 21.141904574019346, 21.3423029352593, 21.5420760108185, 21.741233435783265, 21.93978458124613, 22.137738564628364, 22.335104259480925, 22.531890304796008, 22.7281051138591, 22.92375688266914, 23.118853597952583, 23.313403044795255, 23.507412813914303, 23.700890308590914, 23.893842751283206, 24.086277189937324, 24.27820050401346, 24.469619410242725, 24.660540468129376, 24.850970085212335, 25.040914522098728, 25.23037989728167, 25.419372191753457], [0.0, 0.8059274488676564, 1.3554030054147674, 1.8371173070873839, 2.279507056954778, 2.694780839723132, 3.0896507158606776, 3.468322533914498, 3.8336586254776357, 4.187721865959449, 4.532063096035153, 4.8678866992740675, 5.196152422706634, 5.517641275236385, 5.832999971424763, 6.142771941095401, 6.447419590941253, 6.747340678516292, 7.042880610329795, 7.33434184854402, 7.621991222319223, 7.906065691853375, 8.186776950561601, 8.464315141679712, 8.738851890731825, 9.01054280300533, 9.279529538004423, 9.545941546018396, 9.809897532292206, 10.071506699711863, 10.33086980997645, 10.58808009492482, 10.843224043318141, 11.09638208345154, 11.347629178119833, 11.597035345432893, 11.844666116572437, 12.090582939661424, 12.33484353737194, 12.5775022246463, 12.818610191887027, 13.058215758136521, 13.296364598079766, 13.533099946134255, 13.768462780417977, 14.002491988990768, 14.235224520432416, 14.466695520541084, 14.696938456699076, 14.925985231251806, 15.153866285074683, 15.380610692355926, 15.606246247497753, 15.830799544929981, 16.054296052536742, 16.276760179316046, 16.498215337821552, 16.718684001874845, 16.938187759982952, 17.156747364849146, 17.374382779324044, 17.591113219107864, 17.806957192482983, 18.021932537327828, 18.236056455638227, 18.449345545760377, 18.66181583251989, 18.873482795414063, 19.084361395018846, 19.294466097748085, 19.503810899090286, 19.71240934543686, 19.9202745546058, 20.127419235155866, 20.333855704578017, 20.539595906443736, 20.744651426583026, 20.949033508359122, 21.15275306710139, 21.35582070375293, 21.55824671778506, 21.760041119426734, 21.961213641253135, 22.161773749174557, 22.361730652863343, 22.56109331565402, 22.759870463949063, 22.958070596160514, 23.155701991215338, 23.352772716650563, 23.549290636322386, 23.74526341775166, 23.940698539126796, 24.13560329598354, 24.329984807579937, 24.52385002298332, 24.717205726885428, 24.910058545160304, 25.10241495017906, 25.294281265894345, 25.48566367270685, 25.676568212125225], [0.0, 0.8139733653002305, 1.3689345699859323, 1.855458030375105, 2.302264345236112, 2.721683982767804, 3.1204960127922874, 3.502948272631175, 3.871931669750973, 4.229529674123464, 4.577308609125798, 4.916484882200617, 5.248027821941088, 5.572726234394742, 5.8912332905494935, 6.204097845519994, 6.511786922401845, 6.814702249731823, 7.113192682359265, 7.407563702054815, 7.6980848018477, 7.984995307610313, 8.268509026183162, 8.548817999082836, 8.82609556524404, 9.100498883427923, 9.372171027385741, 9.64124273976408, 9.90783391089283, 10.172054833876851, 10.434007276362117, 10.69378540096057, 10.951476559887462, 11.207161984387788, 11.460917385641828, 11.712813480780015, 11.962916455209722, 12.211288370516646, 12.45798752564286, 12.70306877777984, 12.946583828385666, 13.188581478892289, 13.42910785997449, 13.668206637677342, 13.905919199220808, 14.142284820900763, 14.37734082017038, 14.611122693703269, 14.843664243000843, 15.0749976889032, 15.305153776189945, 15.53416186930929, 15.762050040146786, 15.988845148635749, 16.21457291691703, 16.439257997674048, 16.662924037197943, 16.88559373367601, 17.107288891142527, 17.328030469483828, 17.547838630848155, 17.766732782774238, 17.9847316183205, 18.201853153448496, 18.418114761888898, 18.633533207696242, 18.848124675678797, 19.061904799872263, 19.274888690210375, 19.487090957531347, 19.698525737046598, 19.90920671038692, 20.11914712633106, 20.32835982031273, 20.536857232793643, 20.744651426583026, 20.951754103177148, 21.15817661818653, 21.36392999591291, 21.5690249431331, 21.773471862142436, 21.977280863106234, 22.18046177576412, 22.383024160528585, 22.584977319016062, 22.786330304045844, 22.987091929139805, 23.18727077755324, 23.386875210865163, 23.58591337715426, 23.784393218784945, 23.98232247982619, 24.17970871312435, 24.376559287049595, 24.572881391934555, 24.768682046222057, 24.963968102338306, 25.15874625230626, 25.353023033113466, 25.546804831847275, 25.740097890609956, 25.932908311225102], [0.0, 0.8219928575293057, 1.3824216945211012, 1.873738519504476, 2.3249468945835194, 2.748498771162943, 3.1512400083482324, 3.5374602943370164, 3.910079018621074, 4.27120017809845, 4.622405528000317, 4.964923460154124, 5.299732853248229, 5.627630284866969, 5.949275361220694, 6.265222344897463, 6.575942860234448, 6.8818425937098215, 7.183273837188028, 7.480545082131173, 7.773928476688841, 8.063665704638554, 8.349972679305345, 8.633043334252292, 8.913052716197551, 9.190159532274139, 9.46450826583575, 9.736230947641923, 10.00544864921546, 10.272272750299601, 10.536806021183498, 10.79914355219537, 11.059373556168811, 11.317578064661662, 11.573833534781826, 11.8282113803846, 12.080778438954416, 12.331597383524995, 12.580727087415816, 12.828222948286683, 13.074137176972833, 13.318519055711514, 13.56141516966976, 13.802869615102674, 14.042924186988639, 14.28161854858453, 14.51899038500546, 14.755075542648147, 14.989908156035812, 15.223520763457236, 15.455944412598159, 15.687208757213508, 15.917342145760866, 16.146371702805094, 16.37432340390874, 16.60122214464031, 16.827091804260803, 17.051955304586368, 17.2758346644707, 17.49875105030277, 17.72072482287392, 17.94177558093135, 18.161922201702705, 18.38118287864781, 18.59957515666816, 18.81711596498243, 19.03382164785613, 19.249707993355827, 19.464790260282534, 19.679083203424508, 19.892601097257206, 20.105357758206658, 20.317366565582272, 20.52864048127602, 20.73919206831651, 20.949033508359122, 21.15817661818653, 21.366632865287887, 21.57441338257942, 21.781528982324097, 21.98799016930355, 22.193807153291264, 22.3989898608722, 22.603547946650696, 22.80749080388529, 23.010827574586184, 23.213567159108514, 23.4157182252722, 23.617289217036863, 23.81828836275832, 24.01872368305138, 24.218602998281735, 24.41793393570848, 24.61672393629703, 24.81498026122117, 25.012709998071376, 25.20992006678587, 25.406617225319273, 25.602808075063365, 25.798499066032857, 25.99369650182894, 26.188406544392084], [0.0, 0.829986353847804, 1.395865099320239, 1.8919597507722348, 2.3475559163923188, 2.775226636992245, 3.1818843444573672, 3.5718604421979223, 3.948102709403899, 4.3127356033597115, 4.667356261126802, 5.01320502006896, 5.351270278012231, 5.682356358885623, 6.007129283261562, 6.326148703672698, 6.639890830782433, 6.948765296180314, 7.253127817604494, 7.553289886452352, 7.849526297387016, 8.142081084447778, 8.43117226061583, 8.716995645367504, 8.999727987668468, 9.279529538004422, 9.55654618476214, 9.830911242638585, 10.102746960520527, 10.372165801267142, 10.639271534560612, 10.904160175438145, 11.166920794561914, 11.427636221208314, 11.686383655994884, 11.943235207243282, 12.198258362401237, 12.451516403968425, 12.70306877777984, 12.952971420211634, 13.201277049825011, 13.448035428103939, 13.693293593234428, 13.937096070287051, 14.179485060676818, 14.420500613367237, 14.66018077994355, 14.898561755391933, 15.135678006177882, 15.371562387009833, 15.606246247497754, 15.839759529765482, 16.072130857946092, 16.303387620378167, 16.533556045224454, 16.76266127015123, 16.990727406634143, 17.217777599393287, 17.443834081405424, 17.668918224892757, 17.893050588645814, 18.11625096200044, 18.338538405756506, 18.55993129029672, 18.780447331138554, 19.000103622129416, 19.218916666475153, 19.436902405773907, 19.654076247211396, 19.870453089059293, 20.086047344605664, 20.300872964634816, 20.514943458563693, 20.72827191433261, 20.94087101713974, 21.15275306710139, 21.36392999591291, 21.57441338257942, 21.784214468279558, 21.9933441704205, 22.20181309593797, 22.40963155389072, 22.61680956739511, 22.823356884941997, 23.029282991134973, 23.234597116886004, 23.439308249102027, 23.643425139893456, 23.84695631533347, 24.04991008379481, 24.252294543889004, 24.454117592031153, 24.655386929651876, 24.8561100700765, 25.056294345090333, 25.255946911207353, 25.455074755658945, 25.653684702117687, 25.851783416170804, 26.04937741055638, 26.246473050175194, 26.443076556889693], [0.0, 0.837954270212839, 1.4092654839370378, 1.9101226723555578, 2.370092587166893, 2.801868971092146, 3.212430615757268, 3.606150506292433, 3.9860047207360845, 4.354138111283812, 4.712163147603999, 5.061332074369913, 5.402642778083139, 5.736907304228307, 6.064798067213349, 6.38688009226717, 6.703634161702714, 7.015473839596169, 7.3227582585962745, 7.625801900435601, 7.924882197821726, 8.220245527534646, 8.512111995492614, 8.800679301050112, 9.086125889972964, 9.36861355116068, 9.648289573536871, 9.9252885516272, 10.199733907914725, 10.471739184908493, 10.741409148485554, 11.008840735432955, 11.274123871496306, 11.537342181117781, 11.798573606045261, 12.057890946844402, 12.315362338846283, 12.571051672066188, 12.825018963022522, 13.077320685083837, 13.328010062912538, 13.577137335705673, 13.824749993218528, 14.070892987964893, 14.315608926495766, 14.558938242246997, 14.800919352101213, 15.041588798518525, 15.280981378844466, 15.519130263194546, 15.756067102136777, 15.991822125241095, 16.22642423143389, 16.459901071983353, 16.692279126844088, 16.923583775005415, 17.15383935941451, 17.383069246982107, 17.611295884122814, 17.838540848233386, 18.064824895469915, 18.290168005147002, 18.514589421049276, 18.738107689916177, 18.960740697335147, 19.18250570125551, 19.403419363314832, 19.623497778151503, 19.842756500861107, 20.061210572739572, 20.278874545443355, 20.495762503685086, 20.711888086572884, 20.927264507692033, 21.141904574019346, 21.35582070375293, 21.5690249431331, 21.781528982324097, 21.9933441704205, 22.204481529637224, 22.414951768737172, 22.624765295746663, 22.833932230004542, 23.042462413587728, 23.25036542215255, 23.45765057522826, 23.66432694599661, 23.870403370588782, 24.075888456928734, 24.280790593150062, 24.485117955611432, 24.688878516533975, 24.892080051282484, 25.094730145310645, 25.29683620078931, 25.498405442935415, 25.699444926058153, 25.899961539337756, 26.099962012351458, 26.299452920360014, 26.498440689367598, 26.696931600966902], [0.0, 0.8458970107524513, 1.4226235280311383, 1.9282282054671644, 2.392558049953953, 2.8284271247461903, 3.2428803715368835, 3.6403322257924677, 4.023786974985394, 4.395409801781648, 4.756828460010885, 5.109307064032924, 5.453852959043998, 5.791285887686946, 6.122284638002925, 6.447419590941252, 6.767176086019612, 7.081971607375544, 7.392168691778457, 7.698084801847699, 8.000000000000002, 8.298162998353824, 8.592795989151535, 8.884098545686006, 9.172250805161925, 9.45741609003176, 9.73974308533076, 10.01936766136947, 10.29641441051909, 10.570997951527216, 10.843224043318141, 11.113190541516342, 11.380988224249108, 11.64670150861195, 11.910409075141363, 12.172184414459762, 12.432096307734492, 12.69020925057691, 12.946583828385666, 13.20127704982501, 13.454342644059437, 13.705831326489683, 13.955791037013494, 14.204267154237314, 14.451302688568047, 14.696938456699073, 14.941213239656205, 15.184163926275584, 15.42582564373732, 15.66623187656742, 15.90541457534102, 16.143404256165923, 16.38023009189358, 16.615919995891026, 16.850500699109162, 17.083997821097828, 17.316435935544384, 17.54783863084815, 17.77822856618719, 18.007627523484537, 18.236056455638227, 18.46353553134136, 18.69008417678516, 18.915721114508564, 19.14046439963163, 19.36433145368709, 19.58733909624364, 19.80950357449636, 20.030840590983367, 20.25136532957293, 20.4710924798527, 20.690036260040472, 20.90821043852575, 21.125628354141806, 21.3423029352593, 21.55824671778506, 21.773471862142436, 21.98799016930355, 22.20181309593797, 22.414951768737172, 22.62741699796953, 22.839219290316194, 23.050368861034475, 23.26087564549167, 23.470749310109134, 23.679999262753416, 23.888634662608478, 24.096664429560786, 24.304097253126475, 24.510941600947973, 24.71720572688542, 24.92289767872647, 25.128025305536486, 25.332596264669593, 25.536618028459817, 25.740097890609952, 25.943042972295075, 26.14546022799608, 26.347356451078035, 26.5487382791268, 26.74961219905689, 26.949984552002515], [0.0, 0.8538149682454624, 1.4359398921751472, 1.9462772454491515, 2.4149534156997734, 2.854902411289524, 3.273235117576131, 3.6744072910283925, 4.0614513405333055, 4.436552715791846, 4.801354407105093, 5.15713236148346, 5.504903353304679, 5.845494798353022, 6.179591838415775, 6.50777019345168, 6.830519745963701, 7.1482618879193085, 7.461362549586992, 7.770142165171877, 8.074883418594593, 8.375837350025309, 8.67322823152073, 8.967257504465032, 9.258106992224114, 9.545941546018394, 9.830911242638585, 10.1131532241994, 10.392793249309875, 10.669947009598063, 10.944721253936983, 11.21721475392157, 11.48751913740118, 11.755719611651406, 12.021895593692191, 12.286121262049582, 12.548466041712036, 12.808995031997398, 13.067769385409537, 13.32484664423816, 13.58028104057571, 13.834123764540731, 14.086423204768911, 14.337225164629835, 14.586573057126195, 14.834508081013066, 15.081069380323234, 15.326294189188108, 15.570217963593215, 15.812874501494035, 16.054296052536742, 16.294513418472945, 16.53355604522445, 16.771452107439348, 17.008228586281643, 17.243911341111122, 17.478525175635358, 17.71209389905117, 17.944640382636205, 18.176186612201608, 18.4067537367735, 18.636362113832554, 18.865031351407456, 19.0927803472881, 19.31962732559819, 19.54558987094345, 19.770684960330914, 19.99492899303637, 20.218337818580384, 20.440926762958732, 20.662710653259875, 20.883703840790208, 21.10392022281724, 21.323373263031428, 21.5420760108185, 21.760041119426734, 21.977280863106234, 22.193807153291264, 22.40963155389072, 22.624765295746663, 22.839219290316194, 23.053004142627497, 23.266130163557047, 23.47860738147143, 23.69044555327384, 23.901654174892464, 24.11224249124515, 24.32221950571231, 24.531593989147666, 24.740374488454396, 24.948569334752296, 25.156186651159754, 25.363234360212733, 25.56972019094147, 25.775651685624233, 25.98103620623599, 26.185880940609056, 26.39019290832124, 26.593978966326407, 26.79724581434106, 27.00000000000001, 27.20224792379319], [0.0, 0.8617085245761866, 1.4492152186193656, 1.9642706628095072, 2.4372797645363056, 2.881296107629309, 3.3034963178891052, 3.7083773454458715, 4.098999633937994, 4.47756883764351, 4.845743136379934, 5.204810273343008, 5.555796423033589, 5.8995366507306795, 6.2367224323870385, 6.567934810517342, 6.893668196609495, 7.21434787841794, 7.530343169252339, 7.841977465745908, 8.149536065244357, 8.453272328795089, 8.753412601859685, 9.050160188156628, 9.34369859201671, 9.634194188717009, 9.92179844251467, 10.206649763409185, 10.488875072653377, 10.768591131449405, 11.045905675568237, 11.320918389752483, 11.593721748954927, 11.864401748196114, 12.133038538709775, 12.399706984805633, 12.664477153309177, 12.927414745384256, 13.188581478892289, 13.448035428103937, 13.705831326489685, 13.962020837422942, 14.216652796894422, 14.469773431727848, 14.721426556281, 14.971653750193225, 15.220494519385586, 15.46798644222065, 15.714165302476063, 15.959065210570865, 16.20271871430061, 16.445156900180425, 16.686409486360944, 16.926504907966095, 17.165470395601915, 17.40333204769909, 17.64011489727654, 17.87584297364814, 18.110539359537494, 18.344226244015513, 18.576924971631986, 18.808656088073377, 19.039439382645437, 19.26929392784896, 19.498238116290448, 19.726289695146072, 19.953465798376037, 20.179782976868132, 20.405257226672433, 20.629904015474214, 20.85373830743901, 21.076774586551654, 21.29902687856051, 21.520508771628425, 21.741233435783265, 21.961213641253135, 22.18046177576412, 22.3989898608722, 22.61680956739511, 22.833932230004542, 23.050368861034475, 23.266130163557047, 23.481226543773236, 23.695668122762303, 23.90946474763043, 24.122626002096084, 24.335161216546773, 24.547079477599553, 24.758389637195055, 24.969100321252963, 25.17921993791463, 25.388756685397023, 25.597718559480295, 25.806113360649906, 26.013948700912806, 26.22123201030574, 26.427970543112853, 26.63417138380824, 26.839841452738618, 27.044987511559647, 27.24961616843931, 27.453733883040343], [0.0, 0.8695780511656082, 1.4624501320169423, 1.9822093042049869, 2.4595381470007367, 2.9076094556864582, 3.3336653963770666, 3.7422439874614506, 4.136433621985367, 4.518460097296687, 4.889996736489094, 5.252343043033446, 5.606534562937658, 5.953413987688702, 6.293679108122202, 6.627916273105721, 6.956624409324867, 7.2802326884614175, 7.59911379656747, 7.9135940836860446, 8.223961452632084, 8.530471578264963, 8.833352873139225, 9.132810497638307, 9.429029631940656, 9.722178170740452, 10.012408961537504, 10.299861678356372, 10.58466440155431, 10.866934958651566, 11.146782069312723, 11.424306328648234, 11.69960105613554, 11.972753032142075, 12.243843139880237, 12.512946927355761, 12.780135101277262, 13.045473962822447, 13.309025793489202, 13.570849197909682, 13.830999409406104, 14.089528563166049, 14.346485941173412, 14.60191819241696, 14.855869531387748, 15.108381917449904, 15.359495217311093, 15.609247352517128, 15.8576744336399, 16.104810882610803, 16.35068954446713, 16.595341789620655, 16.83879760762211, 17.081085693278304, 17.322233525877962, 17.56226744219488, 17.80121270386125, 18.03909355963792, 18.27593330305075, 18.51175432581167, 18.746578167398905, 18.98042556113177, 19.21331647704125, 19.44527016180715, 19.6763051760059, 19.9064394288892, 20.135690210892626, 20.36407422405444, 20.591607610508156, 20.8183059791972, 21.04418443094689, 21.26925758201661, 21.493539586244438, 21.717044155886697, 21.93978458124613, 22.161773749174557, 22.383024160528585, 22.603547946650696, 22.823356884941997, 23.042462413587728, 23.26087564549167, 23.47860738147143, 23.695668122762303, 23.912068082873986, 24.127817198841072, 24.342925141905027, 24.55740132766284, 24.77125492571482, 24.984494868841676, 25.19712986173903, 25.40916838933533, 25.620618724717513, 25.831488936686945, 26.041786896966777, 26.251520287080375, 26.46069660491908, 26.669323171016543, 26.877407134545624, 27.084955479052873, 27.291975027944574, 27.498472449737598, 27.70445426308735], [0.0, 0.8774239093805122, 1.4756452401119458, 2.0000939933737274, 2.481729585192684, 2.9338436637636414, 3.363743738396908, 3.776008772223259, 4.173755023635232, 4.559228372468273, 4.934117239547341, 5.299732853248228, 5.657120102900177, 6.007129283261562, 6.350464481058237, 6.68771733555128, 7.019391275044099, 7.345919343464511, 7.667677589463198, 7.984995307610313, 8.298162998353826, 8.607438643406065, 8.913052716197551, 9.215212228192579, 9.514104030376968, 9.809897532292206, 10.102746960520527, 10.392793249309877, 10.680165634635825, 10.96498300712965, 11.247355067390393, 11.527383318158325, 11.805161920895568, 12.080778438954416, 12.354314485324455, 12.625846289651138, 12.895445196601694, 13.16317810556309, 13.42910785997449, 13.693293593234426, 13.955791037013496, 14.216652796894422, 14.475928599512915, 14.733665514753081, 14.989908156035812, 15.244698861307949, 15.498077856978671, 15.75008340674487, 16.000751946989823, 16.250118210220368, 16.498215337821556, 16.74507498324796, 16.990727406634143, 17.235201561688793, 17.47852517563536, 17.72072482287392, 17.96182599296236, 18.201853153448493, 18.440829808026436, 18.67877855043966, 18.915721114508564, 19.151678420620996, 19.386670618989612, 19.62071712994939, 19.853836681541477, 20.086047344605664, 20.317366565582272, 20.547811197205437, 20.77739752725275, 21.006141305500947, 21.234057769024112, 21.461161665958343, 21.687467277846192, 21.91298844066424, 22.137738564628364, 22.361730652863343, 22.584977319016062, 22.80749080388529, 23.029282991134973, 23.25036542215255, 23.470749310109134, 23.69044555327384, 23.90946474763043, 24.127817198841072, 24.34551293359827, 24.562561710403276, 24.77897302980628, 24.99475614414126, 25.209920066785863, 25.424473580974738, 25.63842524819248, 25.8517834161708, 26.064556226512675, 26.276751621964685, 26.48837735335755, 26.6994409862331, 26.909949907175275, 27.119911329861075, 27.329332300846833, 27.538219705103717, 27.74658027131599, 27.954420576954302], [0.0, 0.8852464509219427, 1.4888011343926701, 2.01792553202074, 2.50385507387292, 2.959999907844176, 3.3937326922503703, 3.809673213282743, 4.2109655118691265, 4.599875490650501, 4.978106623314987, 5.346981828298712, 5.707555310485349, 6.060684945308923, 6.407081096675118, 6.7473406785162915, 7.081971607375543, 7.411410787919017, 7.736037621402856, 8.056184338173669, 8.372144028592691, 8.684176974369597, 8.99251570368628, 9.297369073586763, 9.598925600898863, 9.897356205509478, 10.192816488984858, 10.48544864205114, 10.775383052867891, 11.062739672018017, 11.347629178119833, 11.630153978846101, 11.910409075141363, 12.188482811015875, 12.464457527067617, 12.738410132556039, 13.01041260821107, 13.28053244985115, 13.548833061186718, 13.81537410281127, 14.080211803262776, 14.343399237121153, 14.60498657435249, 14.865021304485403, 15.123548438685058, 15.380610692355926, 15.636248650539716, 15.890500918067584, 16.143404256165923, 16.394993706994047, 16.645302707404056, 16.89436319305217, 17.142205693852638, 17.388859421646618, 17.634352350855465, 17.87871129279934, 18.121961964284473, 18.364129050995437, 18.60523626617001, 18.845306404982804, 19.084361395018846, 19.322422343178566, 19.559509579320824, 19.795642696919693, 20.030840590983363, 20.265121493459496, 20.49850300632954, 20.731002132575657, 20.96263530518668, 21.19341841435413, 21.42336683299594, 21.65249544073301, 21.88081864643284, 22.108350409424595, 22.335104259480925, 22.56109331565402, 22.786330304045844, 23.010827574586184, 23.234597116886004, 23.45765057522826, 23.679999262753416, 23.901654174892464, 24.122626002096084, 24.342925141905027, 24.562561710403276, 24.78154555309254, 24.99988625522374, 25.217593151618654, 25.434675336012354, 25.65114166994509, 25.867000791230105, 26.082261122022057, 26.296930876509162, 26.511018068250376, 26.724530517177786, 26.937475856282678, 27.14986153800297, 27.36169484032813, 27.57298287263701, 27.7837325812827, 27.99395075493804, 28.20364402971414], [0.0, 0.8930460181942644, 1.5019183907123212, 2.035704700659191, 2.5259155815072374, 2.9860793328260593, 3.4236335705989, 3.843238784182932, 4.2480667154458756, 4.640403231028639, 5.0219668132732735, 5.394092036343336, 5.75784239331778, 6.114083318042362, 6.463531433166944, 6.806788911803816, 7.144368145554117, 7.476709888483592, 7.8041968846074745, 8.127164291426654, 8.445907781609233, 8.760689930107294, 9.071745313819443, 9.379284629949087, 9.683498056273578, 9.984558018589448, 10.28262148940872, 10.577831912245536, 10.870320824059576, 11.160209232272368, 11.447608790649126, 11.732622809137373, 12.015347125698572, 12.295870862708204, 12.574277086235705, 12.850643383158538, 13.125042368401267, 13.397542132462121, 13.66820663767734, 13.93709607028705, 14.204267154237316, 14.469773431727848, 14.73366551475308, 14.995991311253668, 15.256796228970908, 15.516123359658334, 15.7740136459369, 16.03050603277014, 16.285637605273532, 16.539443714349417, 16.7919580914492, 17.043212953601916, 17.293239099709208, 17.54206599898656, 17.78972187232723, 18.03623376727566, 18.281627627219006, 18.525928355337935, 18.76915987379849, 19.011345178614825, 19.252506390567522, 19.492664802521816, 19.73184092345517, 19.97005451947224, 20.207324652057906, 20.443669713794524, 20.679107461747858, 20.913655048706836, 21.147329052445055, 21.380145503156424, 21.612119909203766, 21.84326728130662, 22.0736021552835, 22.303138613453864, 22.531890304796008, 22.759870463949063, 22.987091929139805, 23.213567159108514, 23.439308249102027, 23.66432694599661, 23.888634662608478, 24.11224249124515, 24.335161216546773, 24.55740132766284, 24.77897302980628, 24.99988625522374, 25.220150673618118, 25.439775702056725, 25.658770514396053, 25.87714405025199, 26.09490502354223, 26.31206193062582, 26.528623058063033, 26.74459649001723, 26.959990115318917, 27.174811634210744, 27.389068564791206, 27.602768249173344, 27.815917859374018, 28.028524402947983, 28.240594728380476, 28.45213553025083], [0.0, 0.9008229446560112, 1.5149975698790703, 2.053432259410161, 2.5479120512587983, 3.0120830536950978, 3.4534476518086805, 3.876706919968318, 4.285060220570524, 4.680813326304055, 5.065699684597339, 5.441065491506775, 5.807983501344555, 6.167326684427391, 6.519817903981255, 6.866064577031872, 7.206583557248091, 7.54181943692111, 7.872158293121792, 8.197938202008283, 8.51945741105955, 8.836980781813201, 9.150744933937476, 9.4609623994535, 9.767825012266709, 10.071506699711863, 10.372165801267142, 10.669947009598063, 10.96498300712965, 11.25739585505423, 11.547298179453227, 11.834794189929786, 12.119980559032566, 12.402947185242812, 12.683777857995498, 12.962550839819095, 13.239339377991833, 13.514212155965486, 13.787233693080495, 14.058464699697751, 14.327962393733337, 14.595780783649332, 14.86197092218538, 15.126581134479602, 15.389657223698228, 15.651242656851375, 15.911378733101262, 16.170104736556446, 16.427458075281294, 16.683474408024953, 16.938187759982952, 17.191630628740377, 17.443834081405424, 17.694827843820796, 17.94464038263621, 18.193298980934635, 18.440829808026436, 18.687257983957043, 18.932607639214254, 19.17690197006878, 19.420163289935928, 19.66241307710593, 19.903672019154893, 20.143960054316945, 20.383296410070393, 20.621699639166, 20.859187653303664, 21.095777754644207, 21.331486665325706, 21.566330555138062, 21.80032506749581, 22.03348534383657, 22.26582604656135, 22.497361380622895, 22.7281051138591, 22.958070596160514, 23.18727077755324, 23.4157182252722, 23.643425139893456, 23.870403370588782, 24.096664429560786, 24.32221950571231, 24.547079477599553, 24.77125492571482, 24.99475614414126, 25.217593151618654, 25.439775702056725, 25.66131329452958, 25.882215182782545, 26.1024903842805, 26.32214768882469, 26.541195666763134, 26.759642676818086, 26.97749687355235, 27.194766214494855, 27.4114584669444, 27.62758121446945, 27.843141863120486, 28.058147647370546, 28.27260563579839, 28.486522736528016, 28.699905702437274], [0.0, 0.9085775551536168, 1.5280392182173212, 2.071108948763389, 2.569845401932068, 3.038012156640809, 3.483176181230046, 3.910079018621074, 4.321947572481834, 4.721107464428336, 5.109307064032925, 5.4879041558957145, 5.857980728986937, 6.2204172684682835, 6.575942860234448, 6.925170150177127, 7.268620441228937, 7.606742152892702, 7.939924685730683, 8.26850902618316, 8.592795989151536, 8.913052716197551, 9.229517863897337, 9.542405793824711, 9.851909991260914, 10.15820588077026, 10.461453164874568, 10.761797781806271, 11.059373556168811, 11.354303599901517, 11.646701508611951, 11.9366723889773, 12.224313745738574, 12.509716251255735, 12.792964416253591, 13.074137176972831, 13.353308411230817, 13.63054739373137, 13.905919199220808, 14.179485060676816, 14.451302688568047, 14.721426556281, 14.98990815603581, 15.25679622897091, 15.522136972542786, 15.785974227941342, 16.048349649846955, 16.309302860540033, 16.568871590107115, 16.827091804260803, 17.08399782109783, 17.339622417954292, 17.5939969293753, 17.8471513370944, 18.099114352812542, 18.34991349447537, 18.59957515666816, 18.848124675678793, 19.095586389719067, 19.341983694741586, 19.58733909624364, 19.83167425740836, 20.07501004389801, 20.317366565582272, 20.558763215456548, 20.799218705980415, 21.03875110304417, 21.277377857751915, 21.51511583619195, 21.751981347349588, 21.98799016930355, 22.223157573834445, 22.457498349562538, 22.691026823721955, 22.92375688266914, 23.155701991215338, 23.386875210865163, 23.617289217036863, 23.84695631533347, 24.075888456928734, 24.304097253126475, 24.531593989147666, 24.758389637195055, 24.984494868841676, 25.209920066785863, 25.434675336012354, 25.658770514396053, 25.882215182782545, 26.105018674576748, 26.32719008486915, 26.5487382791268, 26.769671901474364, 26.98999938258902, 27.209728947231, 27.42886862143053, 27.647426239350132, 27.865409449840378, 28.082825722705707, 28.29968235469614, 28.515986475239316, 28.731745051926875, 28.946964895767877], [0.0, 0.9163101662390513, 1.5410438681019072, 2.0887354903013233, 2.5917165288712236, 3.063867700118496, 3.5128203724151854, 3.943356442428007, 4.358730276963224, 4.7612872902537635, 5.152790731682573, 5.534609941517401, 5.907836117188296, 6.273357237382719, 6.631908593010705, 6.984108043995916, 7.330481329912413, 7.671480686617051, 8.007498828734926, 8.33887964473214, 8.665926509648882, 8.988908838602729, 9.308067319299106, 9.623618137674177, 9.935756425700124, 10.24465910092326, 10.550487225042149, 10.853387978322548, 11.153496324306015, 11.450936422697962, 11.745822835881599, 12.038261565063207, 12.32835094481526, 12.616182419180985, 12.901841218128766, 13.185406949700221, 13.466954120463035, 13.746552594695734, 14.024268000974851, 14.300162093412236, 14.57429307363176, 14.846715878625375, 15.117482438846933, 15.386641910255, 15.654240883477744, 15.920323572823323, 16.18493198748169, 16.448106086945725, 16.70988392241059, 16.970301765681487, 17.229394226925425, 17.48719436243585, 17.74373377343611, 17.99904269682462, 18.253150088658384, 18.506083701079422, 18.757870153308822, 19.008534997263464, 19.25810277828982, 19.50659709145593, 19.754040633796112, 20.000455252861887, 20.245861991896447, 20.490281131918103, 20.733732230969796, 20.976234160766822, 21.217805140952457, 21.45846277115153, 21.698224060994196, 21.937105458266284, 22.175122875328665, 22.412291713935158, 22.648626888567215, 22.884142848393438, 23.118853597952583, 23.352772716650563, 23.58591337715426, 23.81828836275832, 24.04991008379481, 24.280790593150062, 24.510941600947973, 24.740374488454396, 24.969100321252963, 25.19712986173903, 25.424473580974738, 25.65114166994509, 25.87714405025199, 26.1024903842805, 26.32719008486915, 26.551252324513822, 26.774686044132682, 26.99749996141778, 27.21970257879706, 27.44130219102905, 27.66230689245093, 27.882724583899247, 28.102562979321494, 28.321829612095208, 28.540531841070695, 28.758676856351858, 28.97627168482927, 29.1933231954783], [0.0, 0.9240210864723069, 1.554012038466811, 2.106312587388645, 2.6135263048157182, 3.089650715860677, 3.542381408277776, 3.9765405192823113, 4.395409801781648, 4.801354407105093, 5.196152422706633, 5.581184712106697, 5.957551655364374, 6.326148703672699, 6.68771733555128, 7.042880610329794, 7.392168691778457, 7.736037621402857, 8.074883418594593, 8.409052865705084, 8.738851890731825, 9.064552175970645, 9.386396434558714, 9.704602671676998, 10.01936766136947, 10.33086980997645, 10.639271534560612, 10.944721253936983, 11.24735506739039, 11.547298179453229, 11.844666116572435, 12.139565771974137, 12.432096307734492, 12.722349937415338, 13.010412608211068, 13.296364598079764, 13.580281040575708, 13.86223238789831, 14.142284820900763, 14.420500613367237, 14.696938456699074, 14.971653750193225, 15.244698861307949, 15.516123359658334, 15.785974227941342, 16.054296052536742, 16.32113119614962, 16.586519954539416, 16.850500699109162, 17.11311000689804, 17.374382779324044, 17.634352350855462, 17.89305058864581, 18.150507984042623, 18.4067537367735, 18.661815832519885, 18.915721114508564, 19.168495349680537, 19.420163289935928, 19.670748728899653, 19.920274554605797, 20.168762798457077, 20.41623468077949, 20.662710653259875, 20.90821043852575, 21.15275306710139, 21.396356911951756, 21.63903972080579, 21.88081864643284, 22.12171027502991, 22.361730652863343, 22.600895311295577, 22.839219290316198, 23.07671716068624, 23.313403044795255, 23.549290636322386, 23.784393218784945, 24.01872368305138, 24.252294543889004, 24.485117955611432, 24.71720572688542, 24.948569334752296, 25.17921993791463, 25.40916838933533, 25.63842524819248, 25.867000791230105, 26.09490502354223, 26.32214768882469, 26.5487382791268, 26.774686044132682, 27.00000000000001, 27.22468893778182, 27.448761431455573, 27.67222584558172, 27.8950903426128, 28.11736288987237, 28.339051266222217, 28.56016306843465, 28.780705717286068, 29.000686463386437, 29.220112392758914, 29.438990432182575], [0.0, 0.9317106167096201, 1.5669442352898946, 2.1238409258292674, 2.635275580715491, 3.1153622098408085, 3.5718604421979228, 4.009632543923936, 4.431987578058614, 4.841310378277184, 5.239393828944053, 5.627630284866968, 6.007129283261563, 6.3787937270978095, 6.74337126534054, 7.101490142302354, 7.453684933676962, 7.800415476061861, 8.142081084447778, 8.479031427043838, 8.811574977722977, 9.13998567967015, 9.46450826583575, 9.785362555598985, 10.102746960520527, 10.416841371604812, 10.72780955751886, 11.035801172191245, 11.340953447499531, 11.643392629904753, 11.943235207243283, 12.24058896228663, 12.535553882319158, 12.828222948286683, 13.118682822620032, 13.407014451335401, 13.693293593234428, 13.977591286806513, 14.259974263649504, 14.540505315778326, 14.819243623013161, 15.09624504567352, 15.371562387009833, 15.64524562914623, 15.917342145760868, 16.187896894273006, 16.456952589922228, 16.72454986380172, 16.990727406634143, 17.255522099845937, 17.51896913529815, 17.781102124862272, 18.041953200884294, 18.301553108455025, 18.55993129029672, 18.81711596498243, 19.073134199123224, 19.32801197408777, 19.581774247756854, 19.83444501176148, 20.086047344605664, 20.336603461033324, 20.586134757962025, 20.834661857273723, 21.08220464572393, 21.328782312205387, 21.574413382579422, 21.819115752268242, 22.062906716783335, 22.305803000348924, 22.547820782765374, 22.788975724644203, 23.029282991134973, 23.268757274253865, 23.507412813914303, 23.74526341775166, 23.98232247982619, 24.218602998281735, 24.454117592031153, 24.688878516533975, 24.92289767872647, 25.156186651159754, 25.388756685397023, 25.620618724717513, 25.8517834161708, 26.082261122022057, 26.31206193062582, 26.541195666763134, 26.769671901474364, 26.99749996141778, 27.22468893778182, 27.45124769477702, 27.67718487773187, 27.90250892081513, 28.127228054405737, 28.351350312129817, 28.574883537583393, 28.797835390757683, 29.020213354183397, 29.24202473880872, 29.463276689625364, 29.68397619105576], [0.0, 0.9393790503782489, 1.5798409520550163, 2.1413211744926963, 2.6569651865081574, 3.14100316319206, 3.601258599075565, 4.042633779122095, 4.468465001577253, 4.881156728462794, 5.282516600457563, 5.673948432129767, 6.056570892728513, 6.431294316556436, 6.798872506094694, 7.15993887641358, 7.515032403025994, 7.864616707209331, 8.209094390511826, 8.548817999082836, 8.884098545686008, 9.215212228192579, 9.542405793824711, 9.865900871182525, 10.185897504850793, 10.502577066424823, 10.816104672467791, 11.126631208633237, 11.434295036284135, 11.739223440951585, 12.041533869223779, 12.341334990977101, 12.638727616440132, 12.933805491837303, 13.226655992873598, 13.517360731790479, 13.805996090921544, 14.092633693437676, 14.377340820170382, 14.66018077994355, 14.941213239656207, 15.220494519385586, 15.498077856978671, 15.774013645936902, 16.048349649846955, 16.32113119614962, 16.592401351651773, 16.862201081860352, 17.130569395941578, 17.39754347887404, 17.66315881216502, 17.927449284328116, 18.190447292174234, 18.45218383384131, 18.71268859437959, 18.971990024614765, 19.230115413929344, 19.487090957531347, 19.742941818717128, 19.99769218658053, 20.251365329572934, 20.50398364527646, 20.75556870671576, 21.00614130550095, 21.255721492065266, 21.504328613235405, 21.75198134734959, 21.998697737118107, 22.24449522040294, 22.489390659076857, 22.733400366107887, 22.976540131002032, 23.218825243725448, 23.460270517216784, 23.700890308590914, 23.940698539126796, 24.17970871312435, 24.41793393570848, 24.655386929651876, 24.892080051282484, 25.128025305536486, 25.363234360212733, 25.597718559480295, 25.831488936686945, 26.064556226512675, 26.296930876509162, 26.528623058063033, 26.759642676818086, 26.98999938258902, 27.21970257879706, 27.448761431455573, 27.67718487773187, 27.904981634109728, 28.132160204175232, 28.35872888604736, 28.58469577947291, 28.81006879260453, 29.03485564847891, 29.259063891211646, 29.482700891923596, 29.705773854413245, 29.928289820588233], [0.0, 0.9470266737385726, 1.59270267019283, 2.1587539859114866, 2.6785959318603396, 3.1665745330836983, 3.630576976335274, 4.0755454568032174, 4.504843434029086, 4.9208949451144886, 5.325522347007574, 5.720140882937943, 6.105878329406004, 6.48365243188018, 6.854223129658777, 7.21822899453757, 7.576213389908583, 7.928643711458392, 8.275925838373796, 8.618415186934339, 8.956425301904435, 9.290234629722919, 9.620091926417468, 9.946220624899317, 10.268822398345696, 10.58808009492482, 10.904160175438147, 11.217214753921573, 11.527383318158325, 11.834794189929786, 12.139565771974137, 12.441807618865251, 12.741621361542641, 13.039101509432575, 13.334336149578535, 13.627407558639277, 13.918392740788237, 14.20736390229109, 14.494388871722517, 14.779531473312879, 15.062851859718219, 15.344406809525825, 15.624249993999847, 15.902432216902646, 16.1790016306713, 16.454003931763985, 16.727482537600793, 16.999478747194903, 17.270031887291896, 17.539179445598776, 17.806957192482983, 18.073399292349524, 18.338538405756506, 18.602405783202276, 18.865031351407456, 19.1264437928201, 19.386670618989612, 19.645738238383057, 19.903672019154893, 20.160496347325946, 20.41623468077949, 20.67090959943966, 20.92454285196029, 21.177155399219053, 21.428767454882724, 21.679398523283364, 21.929067434822304, 22.177792379098193, 22.425590935937223, 22.672480104487153, 22.918476330522285, 23.163595532093332, 23.407853123644305, 23.651264038708174, 23.893842751283206, 24.13560329598354, 24.376559287049595, 24.61672393629703, 24.8561100700765, 25.094730145310645, 25.332596264669593, 25.56972019094147, 25.806113360649906, 26.041786896966777, 26.276751621964685, 26.511018068250376, 26.74459649001723, 26.97749687355235, 27.209728947231, 27.44130219102905, 27.67222584558172, 27.90250892081513, 28.132160204175232, 28.36118826847706, 28.5896014793958, 28.81740800261949, 29.044615810682203, 29.27123268949502, 29.49726624459129, 29.72272390710125, 29.94761293947058, 30.171940440936122], [0.0, 0.9546537661342305, 1.6055298595014649, 2.1761399968514348, 2.7001686068751636, 3.192077253557476, 3.6598166448852028, 4.1083687791274235, 4.541124204203883, 4.960526479744393, 5.368412639458809, 5.766209324556506, 6.155053394339688, 6.535869985546396, 6.909425157817061, 7.276362625829092, 7.637230129073846, 7.992498827514223, 8.342577869176377, 8.687825532764824, 9.028557888247288, 9.365055624593648, 9.697569501244217, 10.026324750577455, 10.351524669990903, 10.673353580261633, 10.991979282820624, 11.307555116788388, 11.620221693344396, 11.93010836773837, 12.23733449629158, 12.542010515900314, 12.844238876011723, 13.144114847205, 13.441727225952453, 13.737158951546421, 14.030487648330777, 14.321786104100607, 14.61112269370327, 14.898561755391931, 15.184163926275588, 15.46798644222065, 15.750083406744873, 16.030506032770145, 16.309302860540033, 16.586519954539416, 16.862201081860352, 17.136387874126918, 17.40911997481148, 17.680435173536733, 17.950369528754816, 18.21895748002146, 18.48623195093392, 18.75222444367347, 19.016965125982306, 19.280482911309033, 19.542805532773503, 19.80395961152932, 20.063970720039077, 20.322863440721907, 20.580661420384423, 20.837387420803264, 21.093063365789934, 21.347710385035256, 21.601348855001316, 21.853998437102703, 22.105678113395623, 22.356406219972744, 22.606200478243352, 22.855078024261662, 23.103055436251726, 23.35014876046385, 23.596373535485743, 23.841744815120947, 24.086277189937324, 24.329984807579937, 24.572881391934555, 24.81498026122117, 25.056294345090333, 25.29683620078931, 25.536618028459817, 25.775651685624233, 26.013948700912806, 26.251520287080375, 26.48837735335755, 26.724530517177786, 26.959990115318917, 27.194766214494855, 27.42886862143053, 27.66230689245093, 27.8950903426128, 28.127228054405737, 28.35872888604736, 28.5896014793958, 28.819854267501093, 29.04949548181548, 29.27853315908163, 29.506975147916215, 29.734829115105455, 29.96210255162787, 30.188802778418868, 30.414936951890606], [0.0, 0.9622606002309622, 1.6183229785482078, 2.193479828856019, 2.721683982767804, 3.217512236326243, 3.6889786500327153, 4.141104919516378, 4.577308609125798, 5.000052749165253, 5.411189011123401, 5.812155403915251, 6.204097845519995, 6.587948844313365, 6.96448056402169, 7.33434184854402, 7.6980848018477, 8.05618433817367, 8.409052865705084, 8.757051517968552, 9.100498883427921, 9.439677887627731, 9.774841288099681, 10.106216111909887, 10.434007276362117, 10.75840057093091, 11.079565134115922, 11.397655526868332, 11.712813480780015, 12.025169381824032, 12.33484353737194, 12.6419472642989, 12.946583828385664, 13.248849259342665, 13.548833061186716, 13.846618834083724, 14.142284820900763, 14.435904389417727, 14.727546459303714, 15.01727588146939, 15.305153776189945, 15.591237835396345, 15.875582593711835, 16.15823967213107, 16.43925799767405, 16.718684001874845, 16.996561800568717, 17.27293335710718, 17.547838630848155, 17.821315712528083, 18.09340094791864, 18.364129050995437, 18.63353320769624, 18.901645171216742, 19.168495349680537, 19.434112886923227, 19.698525737046594, 19.961760733325864, 20.22384365198911, 20.48479927133211, 20.744651426583026, 21.00342306088797, 21.261136272750896, 21.51781236022739, 21.773471862142436, 22.02813459657594, 22.28181969683616, 22.53454564512069, 22.786330304045844, 23.037190946208668, 23.287144281931145, 23.536206485322683, 23.784393218784945, 24.03171965607259, 24.27820050401346, 24.52385002298332, 24.768682046222057, 25.012709998071376, 25.255946911207353, 25.498405442935415, 25.740097890609952, 25.98103620623599, 26.22123201030574, 26.46069660491908, 26.6994409862331, 26.937475856282678, 27.174811634210744, 27.4114584669444, 27.647426239350132, 27.882724583899247, 28.11736288987237, 28.351350312129817, 28.58469577947291, 28.81740800261949, 29.04949548181548, 29.28096651410265, 29.511829200261733, 29.742091451448424, 29.97176099553913, 30.200845383201685, 30.429351993705886, 30.657288040487323], [0.0, 0.9698474422447794, 1.6310824750532382, 2.210774088766516, 2.7431428125108486, 3.242880371536884, 3.718064012359122, 4.173755023635232, 4.61339791513873, 5.0394751366760415, 5.453852959043999, 5.857980728986937, 6.253013399353257, 6.639890830782434, 7.0193912750441, 7.3921686917784575, 7.758779537958238, 8.119702472235527, 8.475353154382214, 8.82609556524404, 9.172250805161926, 9.514104030376968, 9.851909991260914, 10.185897504850793, 10.516273104099195, 10.843224043318143, 11.166920794561918, 11.487519137401183, 11.80516192089557, 12.11998055903257, 12.432096307734493, 12.741621361542643, 13.048659800425908, 13.353308411230818, 13.655657403659156, 13.955791037013496, 14.253788171058535, 14.549722752034668, 14.843664243000845, 15.135678006177884, 15.425825643737323, 15.714165302476063, 16.000751946989823, 16.285637605273536, 16.56887159010712, 16.850500699109165, 17.130569395941578, 17.409119974811485, 17.686192710132136, 17.961825992962364, 18.236056455638234, 18.508919085834037, 18.780447331138557, 19.0506731951022, 19.319627325598198, 19.58733909624364, 19.85383668154148, 20.11914712633106, 20.383296410070397, 20.646309506417133, 20.908210438525753, 21.169022330435197, 21.428767454882728, 21.6874672778462, 21.945142500086796, 22.201813095937972, 22.45749834956254, 22.712216888879034, 22.965986717339664, 23.218825243725448, 23.47074931010914, 23.721775218123202, 23.971918753657846, 24.221195210103595, 24.469619410242725, 24.717205726885428, 24.963968102338306, 25.20992006678587, 25.455074755658945, 25.699444926058153, 25.943042972295075, 26.185880940609056, 26.427970543112853, 26.669323171016543, 26.909949907175275, 27.14986153800297, 27.389068564791206, 27.62758121446945, 27.865409449840378, 28.102562979321494, 28.339051266222217, 28.574883537583393, 28.81006879260453, 29.044615810682203, 29.27853315908163, 29.511829200261733, 29.74451209887299, 29.976589828445764, 30.208070177786087, 30.438960757094243, 30.6692690038211, 30.899002188275812], [0.0, 0.9774145521600455, 1.6438087862563944, 2.228023369219118, 2.764545831451123, 3.2681825284995094, 3.747073728555719, 4.206320210331132, 4.649393358943698, 5.078794993195139, 5.496405945220117, 5.903686870104507, 6.30180173206775, 6.691697724891061, 7.074159172553399, 7.44984513713094, 7.819316417280366, 8.183055406326327, 8.541481007172612, 8.894960040578695, 9.243816112229602, 9.58833660326132, 9.928778251702605, 10.265371659905982, 10.59832497227084, 10.92782690413688, 11.254049257644663, 11.577149027814913, 11.897270178268675, 12.214545148334171, 12.529096140017453, 12.841036223243295, 13.150470290051157, 13.45749588245449, 13.76220391400467, 14.064679301426645, 14.365001519778277, 14.663245092255993, 14.959480023895324, 15.253772186897407, 15.546183664076803, 15.836773055913314, 16.125595755856846, 16.41270419784407, 16.69814807941153, 16.981974563310214, 17.26422846012403, 17.544952394055215, 17.824186953752946, 18.101970829817358, 18.378340940403604, 18.653332546172805, 18.92697935568425, 19.199313622191934, 19.470366232695177, 19.740166789994937, 20.0087436884221, 20.276124183829893, 20.542334458377713, 20.807399680576946, 21.07134406101966, 21.334190904167123, 21.59596265653677, 21.85668095159199, 22.11636665160899, 22.375039886768395, 22.632720091695212, 22.889426039649916, 23.145175874554337, 23.39998714101927, 23.65387681252557, 23.906861317897093, 24.15895656619143, 24.410177970123815, 24.660540468129376, 24.910058545160304, 25.15874625230626, 25.406617225319273, 25.653684702117687, 25.899961539337756, 26.14546022799608, 26.39019290832124, 26.63417138380824, 26.877407134545624, 27.119911329861075, 27.36169484032813, 27.602768249173344, 27.843141863120486, 28.082825722705707, 28.321829612095208, 28.56016306843465, 28.797835390757683, 29.03485564847891, 29.27123268949502, 29.506975147916215, 29.742091451448424, 29.976589828445764, 30.210478314651045, 30.443764759641454, 30.676456832994877, 30.90856203019194, 31.14008767826746], [0.0, 0.9849621839380147, 1.656502339267893, 2.2452282491202946, 2.7858937578995273, 3.293419556384754, 3.77600877222326, 4.23880157253067, 4.685296148590824, 5.118013638343931, 5.538849397780837, 5.949275361220694, 6.350464481058239, 6.743371265340541, 7.128786094625697, 7.50737312029192, 7.8796974715041195, 8.246245266646268, 8.607438643406066, 8.963647255146629, 9.315197206448204, 9.66237809761467, 10.005448649215461, 10.344641244323102, 10.680165634635827, 11.012211992760264, 11.340953447499535, 11.666548206195792, 11.989141344162553, 12.308866323429497, 12.62584628965114, 12.94019518588245, 13.252018714143146, 13.56141516966976, 13.868476168051515, 14.173287281743487, 14.475928599512915, 14.776475220027143, 15.074997688903201, 15.371562387009833, 15.666231876567421, 15.959065210570866, 16.250118210220368, 16.53944371434942, 16.827091804260807, 17.113110006898044, 17.397543478874045, 17.680435173536733, 17.961825992962364, 18.24175492652132, 18.520259177452147, 18.797374278700097, 19.073134199123228, 19.34757144103636, 19.62071712994939, 19.892601097257206, 20.163251956552784, 20.432697174160065, 20.700963134418064, 20.96807520019036, 21.234057769024112, 21.498934325338517, 21.762727488983856, 22.025459060477928, 22.287150063196226, 22.547820782765378, 22.807490803885294, 23.06617904478427, 23.323903789492185, 23.580682718099965, 23.83653293515833, 24.09147099635512, 24.345512933598272, 24.59867427862058, 24.850970085212335, 25.10241495017906, 25.353023033113466, 25.602808075063365, 25.851783416170804, 26.099962012351458, 26.347356451078035, 26.593978966326407, 26.839841452738618, 27.084955479052873, 27.329332300846833, 27.57298287263701, 27.815917859374018, 28.058147647370546, 28.29968235469614, 28.540531841070695, 28.780705717286068, 29.020213354183397, 29.259063891211646, 29.49726624459129, 29.734829115105455, 29.97176099553913, 30.208070177786087, 30.443764759641454, 30.678852651297138, 30.913341581555795, 31.147239103778432, 31.380552601579502], [0.0, 0.9924905857163351, 1.6691635514038516, 2.262389294101567, 2.8071872936953164, 3.318592284890849, 3.804870094636779, 4.27120017809845, 4.721107464428336, 5.15713236148346, 5.5811847121066975, 5.9947477011130355, 6.399003246172259, 6.794913150961867, 7.183273837188028, 7.56475453256437, 7.939924685730683, 8.30927413063948, 8.673228231520731, 9.032159467124231, 9.386396434558714, 9.736230947641921, 10.081923704432796, 10.42370886418692, 10.761797781806271, 11.09638208345154, 11.427636221208314, 11.755719611651406, 12.080778438954416, 12.402947185242814, 12.722349937415338, 13.039101509432575, 13.353308411230815, 13.665069689350597, 13.974477659630326, 14.281618548584529, 14.586573057126195, 14.889416857927387, 15.190221035809337, 15.489052479012402, 15.785974227941344, 16.081045786953233, 16.374323403908736, 16.665860321506567, 16.95570700383798, 17.243911341111126, 17.5305188350863, 17.81557276741852, 18.099114352812542, 18.38118287864781, 18.66181583251989, 18.941049018964467, 19.218916666475153, 19.495451525793044, 19.770684960330914, 20.044647029495184, 20.31736656558227, 20.58887124485059, 20.85918765330366, 21.128341347662072, 21.396356911951756, 21.66325801009133, 21.929067434822304, 22.193807153291267, 22.457498349562535, 22.720161464312703, 22.981816231934218, 23.242481715253838, 23.50217633805252, 23.76091791555616, 24.01872368305138, 24.27561032276679, 24.53159398914767, 24.786690332641136, 25.040914522098728, 25.294281265894345, 25.546804831847275, 25.798499066032857, 26.04937741055638, 26.299452920360014, 26.5487382791268, 26.79724581434106, 27.044987511559647, 27.291975027944574, 27.538219705103717, 27.7837325812827, 28.028524402947983, 28.27260563579839, 28.515986475239316, 28.758676856351858, 29.000686463386437, 29.24202473880872, 29.482700891923596, 29.72272390710125, 29.96210255162787, 30.200845383201685, 30.438960757094243, 30.676456832994877, 30.913341581555795, 31.14962279065352, 31.385308071381978, 31.620404863791098], [0.0, 1.0, 1.6817928305074294, 2.279507056954778, 2.8284271247461907, 3.343701524882111, 3.833658625477636, 4.3035170706588515, 4.756828460010885, 5.196152422706633, 5.623413251903492, 6.040105354537238, 6.447419590941254, 6.8463250420230475, 7.23762415540039, 7.621991222319223, 8.000000000000002, 8.372144028592693, 8.738851890731825, 9.100498883427921, 9.457416090031762, 9.809897532292204, 10.15820588077026, 10.502577066424823, 10.843224043318141, 11.180339887498953, 11.514100370997836, 11.844666116572437, 12.172184414459764, 12.496790764308281, 12.818610191887027, 13.137758379865677, 13.454342644059437, 13.768462780417977, 14.080211803262776, 14.389676591518194, 14.696938456699076, 15.00207364403449, 15.305153776189945, 15.606246247497753, 15.90541457534102, 16.202718714300605, 16.498215337821552, 16.7919580914492, 17.08399782109783, 17.374382779324044, 17.663158812165015, 17.950369528754816, 18.23605645563823, 18.520259177452143, 18.803015465431976, 19.084361395018846, 19.36433145368709, 19.64295863997753, 19.9202745546058, 20.196309484414765, 20.4710924798527, 20.744651426583022, 21.017013111765124, 21.288203285487675, 21.558246717785064, 21.82716725162261, 22.094987852196994, 22.361730652863347, 22.62741699796953, 22.892067482851047, 23.155701991215338, 23.41833973012294, 23.679999262753416, 23.940698539126792, 24.200454924935883, 24.459285228630907, 24.717205726885425, 24.974232188561484, 25.23037989728167, 25.48566367270685, 25.740097890609956, 25.99369650182894, 26.246473050175194, 26.498440689367598, 26.74961219905689, 27.00000000000001, 27.24961616843931, 27.498472449737598, 27.74658027131599, 27.99395075493804, 28.240594728380476, 28.486522736528016, 28.731745051926875, 28.97627168482927, 29.220112392758914, 29.463276689625364, 29.705773854413245, 29.94761293947058, 30.188802778418868, 30.429351993705886, 30.6692690038211, 30.90856203019194, 31.147239103778432, 31.385308071381978, 31.622776601683807, 31.859652191026992], [0.0, 1.0074906638441918, 1.6943905752563322, 2.2965820780488895, 2.8496139215454583, 3.368748069000314, 3.862375273534475, 4.335753270382898, 4.792460262969311, 5.235075053788311, 5.665536350230474, 6.085349753331579, 6.495715043759451, 6.897608561480914, 7.291838764979096, 7.679084996388996, 8.059925310753536, 8.434856945166038, 8.804311692629476, 9.168667661378123, 9.52825841479684, 9.883380177052572, 10.234297586283203, 10.581248340727129, 10.924446989613896, 11.264088055260014, 11.600348626345266, 11.93339052879837, 12.263362156157992, 12.590400023054915, 12.914630091784183, 13.236168911555463, 13.555124602050661, 13.871597706757353, 14.185681936736037, 14.497464821691892, 14.807028282216983, 15.114449134667762, 15.419799538211047, 15.723147392007437, 16.024556689227406, 16.324087833551427, 16.621797922946264, 16.917741004798003, 17.21196830589058, 17.504528440224274, 17.795467597253516, 18.08482971277374, 18.37265662439112, 18.658988213257743, 18.943862533540667, 19.227315930910002, 19.50938315117417, 19.790097440054964, 20.069490634978358, 20.347593249655777, 20.624434552142638, 20.90004263698449, 21.174444491994326, 21.447666060146084, 21.71973229701814, 21.990667224175464, 22.260493978839303, 22.529234860158304, 22.79691137236367, 23.063544265063637, 23.329153570907813, 23.593758640830373, 23.857378177061413, 24.120030264078526, 24.381732397655092, 24.642501512147785, 24.902354006153256, 25.16130576665279, 25.419372191753457, 25.676568212125225, 25.932908311225102, 26.188406544392084, 26.443076556889693, 26.696931600966902, 26.949984552002515, 27.20224792379319, 27.453733883040343, 27.70445426308735, 27.954420576954302, 28.20364402971414, 28.45213553025083, 28.699905702437274, 28.946964895767877, 29.1933231954783, 29.438990432182575, 29.68397619105576, 29.928289820588233, 30.171940440936122, 30.414936951890606, 30.657288040487323, 30.899002188275812, 31.14008767826746, 31.380552601579502, 31.620404863791098, 31.859652191026992, 32.098302135782845]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 1.6\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.025118864315095798, 0.04373448295773112, 0.06049186910982999, 0.07614615754863514, 0.091028210151304, 0.10532246145679582, 0.11914571614494368, 0.13257816069359948, 0.14567801244906114, 0.15848931924611134, 0.1710464827361669, 0.18337705629789586, 0.19550356531429472, 0.20744474060860169, 0.21921638274328878, 0.2308319849451542, 0.24230319295694794, 0.25364015159477993, 0.26485177066967314, 0.27594593229224296, 0.2869296547656997, 0.29780922379158176, 0.30859029869611865, 0.31927799931143663, 0.32987697769322355, 0.3403914778215197, 0.350825385682457, 0.36118227157927313, 0.37146542611247585, 0.38167789096181765, 0.39182248536911973, 0.4019018290415329, 0.4119183620556749, 0.42187436223424096, 0.4317719603808523, 0.44161315369070003, 0.45139981759995357, 0.4611337162929197, 0.47081651205027064, 0.4804497735925725, 0.49003498354948044, 0.49957354516528457, 0.5090667883351854, 0.5185159750530859, 0.5279223043403284, 0.5372869167152506, 0.5466108982553799, 0.5558952842972614, 0.565141062813108, 0.5743491774985175, 0.5835205306012528, 0.5926559855174482, 0.6017563691784628, 0.6108224742488859, 0.6198550611538589, 0.6288548599518199, 0.6378225720670078, 0.6467588718945013, 0.6556644082892014, 0.664539805948974, 0.6733856667011124, 0.6822025707003491, 0.6909910775458248, 0.6997517273236981, 0.7084850415814244, 0.7171915242391691, 0.7258716624432953, 0.7345259273664232, 0.7431547749581351, 0.7517586466500455, 0.7603379700186202, 0.7688931594088335, 0.7774246165214936, 0.7859327309668146, 0.7944178807866091, 0.8028804329472728, 0.8113207438055555, 0.819739159548959, 0.8281360166124454, 0.8365116420730186, 0.8448663540236125, 0.8532004619276143, 0.8615142669552488, 0.8698080623029604, 0.8780821334968424, 0.8863367586810889, 0.8945722088923754, 0.9027887483210061, 0.9109866345596118, 0.9191661188401217, 0.9273274462596887, 0.9354708559961984, 0.943596581513947, 0.9517048507600429, 0.9597958863520394, 0.96786990575728, 0.9759271214644057, 0.983967741147443, 0.9919919678228658, 1.0, 1.0079920318251188], [0.0, 0.04373448295773112, 0.07614615754863513, 0.10532246145679582, 0.13257816069359948, 0.15848931924611132, 0.18337705629789586, 0.20744474060860166, 0.23083198494515417, 0.25364015159477993, 0.27594593229224296, 0.29780922379158176, 0.31927799931143663, 0.3403914778215197, 0.36118227157927313, 0.3816778909618176, 0.4019018290415328, 0.42187436223424096, 0.4416131536907, 0.4611337162929197, 0.48044977359257246, 0.49957354516528457, 0.518515975053086, 0.5372869167152505, 0.5558952842972613, 0.5743491774985174, 0.5926559855174482, 0.6108224742488859, 0.6288548599518198, 0.6467588718945012, 0.664539805948974, 0.6822025707003491, 0.6997517273236981, 0.7171915242391691, 0.7345259273664232, 0.7517586466500455, 0.7688931594088335, 0.7859327309668146, 0.8028804329472727, 0.819739159548959, 0.8365116420730186, 0.8532004619276143, 0.8698080623029605, 0.8863367586810889, 0.902788748321006, 0.9191661188401216, 0.9354708559961983, 0.9517048507600429, 0.9678699057572799, 0.983967741147443, 1.0, 1.0159682532195478, 1.0318740040660683, 1.0477186923106825, 1.0635036980625998, 1.0792303452988907, 1.094899905125124, 1.1105135987918326, 1.1260726004890478, 1.1415780399387683, 1.1570310048031527, 1.1724325429243792, 1.1877836644105055, 1.2030853435802271, 1.2183385207781623, 1.233544104071174, 1.248702970835229, 1.2638159692414097, 1.2788839196488953, 1.2939076159120178, 1.308887826607858, 1.3238252961902828, 1.3387207460757933, 1.353574875666119, 1.3683883633120433, 1.3831618672225916, 1.3978960263233688, 1.4125914610675134, 1.4272487742024753, 1.4418685514955454, 1.4564513624208644, 1.470997760810397, 1.4855082854711958, 1.4999834607710785, 1.5144237971947048, 1.5288297918718772, 1.5432019290797656, 1.557540680720631, 1.5718465067765095, 1.586119855742221, 1.60036116503796, 1.6145708614026566, 1.628749361269196, 1.6428970711225273, 1.6570143878416181, 1.6711016990261414, 1.6851593833087335, 1.6991878106536067, 1.7131873426422428, 1.727158332746853, 1.7411011265922485, 1.7550160622067237], [0.0, 0.06049186910982999, 0.10532246145679582, 0.14567801244906117, 0.18337705629789586, 0.21921638274328878, 0.25364015159477993, 0.2869296547656997, 0.31927799931143663, 0.350825385682457, 0.38167789096181765, 0.4119183620556749, 0.44161315369070003, 0.47081651205027064, 0.4995735451652846, 0.5279223043403284, 0.5558952842972614, 0.5835205306012528, 0.610822474248886, 0.6378225720670077, 0.664539805948974, 0.6909910775458248, 0.7171915242391692, 0.7431547749581351, 0.7688931594088335, 0.7944178807866092, 0.8197391595489589, 0.8448663540236125, 0.8698080623029605, 0.8945722088923753, 0.9191661188401217, 0.943596581513947, 0.96786990575728, 0.9919919678228659, 1.0159682532195478, 1.0398038934012055, 1.0635036980626, 1.08707218367541, 1.1105135987918326, 1.1338319465572162, 1.1570310048031527, 1.1801143440349768, 1.2030853435802271, 1.2259472061253547, 1.248702970835229, 1.2713555252226452, 1.293907615912018, 1.3163618584220589, 1.3387207460757933, 1.3609866581322931, 1.3831618672225918, 1.4052485461620245, 1.4272487742024753, 1.4491645427804556, 1.470997760810397, 1.4927502595668962, 1.5144237971947052, 1.5360200628809915, 1.557540680720631, 1.578987213302013, 1.6003611650379603, 1.6216639852638157, 1.6428970711225273, 1.6640617702545604, 1.6851593833087335, 1.706191166288504, 1.727158332746853, 1.7480620558416777, 1.768903470262513, 1.7896836740383986, 1.8104037302358449, 1.831064668555052, 1.8516674868318153, 1.8722131524519368, 1.8927026036843522, 1.9131367509386863, 1.933516477952472, 1.953842642912831, 1.974116079517051, 1.9943375979761124, 2.01450798596493, 2.03462800952276, 2.05469841390697, 2.07471992440313, 2.0946932470941557, 2.114619069591032, 2.134498061727474, 2.1543308762206945, 2.174118149300305, 2.1938605013072383, 2.213558537264427, 2.2332128474208868, 2.2528240077707045, 2.272392580548362, 2.291919114701712, 2.3114041463438433, 2.3308481991849788, 2.3502517849455105, 2.3696154037511548, 2.3889395445111954, 2.4082246852806923, 2.4274712936074923], [0.0, 0.07614615754863514, 0.13257816069359948, 0.18337705629789586, 0.2308319849451542, 0.27594593229224296, 0.31927799931143663, 0.36118227157927313, 0.4019018290415329, 0.44161315369070003, 0.4804497735925725, 0.518515975053086, 0.5558952842972614, 0.5926559855174484, 0.6288548599518198, 0.664539805948974, 0.6997517273236981, 0.7345259273664233, 0.7688931594088335, 0.8028804329472727, 0.8365116420730186, 0.8698080623029605, 0.9027887483210061, 0.9354708559961983, 0.9678699057572799, 1.0, 1.0318740040660683, 1.0635036980626, 1.094899905125124, 1.1260726004890478, 1.157031004803153, 1.1877836644105058, 1.2183385207781625, 1.2487029708352293, 1.2788839196488955, 1.3088878266078583, 1.3387207460757933, 1.3683883633120433, 1.3978960263233686, 1.4272487742024755, 1.4564513624208644, 1.485508285471196, 1.514423797194705, 1.5432019290797656, 1.5718465067765095, 1.60036116503796, 1.628749361269196, 1.6570143878416181, 1.6851593833087335, 1.7131873426422428, 1.7411011265922485, 1.7689034702625133, 1.796596990980686, 1.8241841955338864, 1.851667486831815, 1.8790491700524399, 1.9063314583190993, 1.933516477952472, 1.960606273336144, 1.98760281143036, 2.0145079859649306, 2.041323621339051, 2.0680514762530007, 2.0946932470941557, 2.121250571097592, 2.1477250292995467, 2.1741181493003046, 2.2004314078514926, 2.226666233281402, 2.2528240077707045, 2.278906069489821, 2.3049137146082184, 2.3308481991849788, 2.3567107409492425, 2.3825025209783215, 2.4082246852806923, 2.4338783462904447, 2.459464584279238, 2.484984448691335, 2.5104389594068275, 2.535829107937782, 2.561155858561657, 2.5864201493960186, 2.6116228934182644, 2.6367649794338113, 2.661847272995918, 2.686870617280111, 2.711835833915948, 2.736743723778671, 2.7615950677431154, 2.7863906274020755, 2.8111311457511823, 2.8358173478422017, 2.8604499414065376, 2.885029617450606, 2.909557050824635, 2.934032900766334, 2.9584578114208107, 2.9828324123379892, 3.0071573189487353, 3.031433133020797, 3.055660443095618], [0.0, 0.091028210151304, 0.15848931924611132, 0.21921638274328878, 0.27594593229224296, 0.3298769776932235, 0.3816778909618176, 0.43177196038085225, 0.48044977359257246, 0.5279223043403284, 0.5743491774985174, 0.619855061153859, 0.6645398059489739, 0.7084850415814244, 0.7517586466500455, 0.794417880786609, 0.8365116420730185, 0.8780821334968424, 0.9191661188401216, 0.9597958863520392, 0.9999999999999999, 1.0398038934012055, 1.0792303452988907, 1.1182998645158624, 1.1570310048031525, 1.1954406247375462, 1.2335441040711739, 1.2713555252226452, 1.3088878266078583, 1.3461529330284603, 1.3831618672225916, 1.4199248458359468, 1.4564513624208641, 1.4927502595668962, 1.5288297918718772, 1.5646976811514668, 1.60036116503796, 1.6358270399213373, 1.671101699026141, 1.706191166288504, 1.7411011265922482, 1.7758369528364875, 1.8104037302358449, 1.8448062781953012, 1.8790491700524399, 1.913136750938686, 1.9470731539765267, 1.9808623150004865, 2.01450798596493, 2.048013747180699, 2.081383018504683, 2.114619069591032, 2.1477250292995467, 2.180703894345387, 2.2135585372644266, 2.246291713760056, 2.2789060694898216, 2.311404146343843, 2.343788388261312, 2.3760611466264128, 2.408224685280692, 2.440281185185065, 2.472232748761291, 2.5040814039397565, 2.5358291079377815, 2.5674777507903146, 2.599029158652794, 2.6304850968941063, 2.6618472729959177, 2.693117339273153, 2.7242968954290974, 2.755387490957386, 2.786390627402075, 2.8173077604860475, 2.8481403021171032, 2.878889622280331, 2.9095570508246347, 2.940143879150641, 2.9706513618066563, 3.001080717998773, 3.031433133020796, 3.0617097596091734, 3.0919117192277534, 3.1220401032868077, 3.152095974300438, 3.1820803669861735, 3.211994289310292, 3.241838723482145, 3.2716146269005324, 3.3013229330549554, 3.3309645523843803, 3.360540373095967, 3.390051261946053, 3.4194980649855085, 3.448881608271476, 3.4782026985473338, 3.507462123892621, 3.5366606543445673, 3.5657990424927273, 3.59487802404816, 3.623898318388478, 3.6528606290800325], [0.0, 0.10532246145679582, 0.18337705629789586, 0.25364015159477993, 0.31927799931143663, 0.3816778909618176, 0.44161315369070003, 0.49957354516528457, 0.5558952842972614, 0.6108224742488859, 0.664539805948974, 0.7171915242391692, 0.7688931594088335, 0.819739159548959, 0.8698080623029605, 0.9191661188401216, 0.96786990575728, 1.0159682532195478, 1.0635036980626, 1.1105135987918326, 1.1570310048031527, 1.2030853435802271, 1.248702970835229, 1.2939076159120178, 1.338720746075793, 1.3831618672225916, 1.4272487742024753, 1.470997760810397, 1.514423797194705, 1.5575406807206307, 1.6003611650379603, 1.6428970711225273, 1.6851593833087335, 1.7271583327468532, 1.768903470262513, 1.8104037302358449, 1.8516674868318153, 1.892702603684352, 1.9335164779524718, 1.974116079517051, 2.01450798596493, 2.05469841390697, 2.0946932470941557, 2.134498061727474, 2.1741181493003046, 2.213558537264427, 2.2528240077707045, 2.291919114701712, 2.3308481991849788, 2.3696154037511548, 2.4082246852806923, 2.4466798268648198, 2.4849844486913355, 2.5231420180525914, 2.5611558585616567, 2.599029158652794, 2.6367649794338117, 2.6743662619503903, 2.711835833915948, 2.7491764159548895, 2.7863906274020755, 2.8234809916969046, 2.860449941406537, 2.897299822909306, 2.934032900766334, 2.9706513618066563, 3.007157318948735, 3.0435528147791064, 3.079839824906999, 3.1160202611120096, 3.152095974300438, 3.1880687572844626, 3.2239403473971104, 3.259712428954892, 3.295386635578907, 3.3309645523843803, 3.3664477180477252, 3.4018376267595056, 3.43713573007101, 3.4723434386414875, 3.5074621238926214, 3.5424931195762213, 3.5774377232607315, 3.612297197741674, 3.6470727723808087, 3.6817656443783977, 3.7163769799826754, 3.7509079156403162, 3.7853595590914146, 3.819732990412267, 3.8540292630089836, 3.888249404564789, 3.9223944179436376, 3.956465282052619, 3.99046295266546, 4.024388363209259, 4.05824242551648, 4.09202603054407, 4.125740049061481, 4.159385332309215, 4.192962712629476, 4.226473004070347], [0.0, 0.11914571614494368, 0.20744474060860166, 0.2869296547656997, 0.36118227157927313, 0.43177196038085225, 0.49957354516528457, 0.565141062813108, 0.6288548599518198, 0.6909910775458247, 0.7517586466500455, 0.8113207438055556, 0.8698080623029604, 0.9273274462596888, 0.983967741147443, 1.0398038934012055, 1.094899905125124, 1.1493110152958734, 1.2030853435802271, 1.2562651516744836, 1.308887826607858, 1.3609866581322931, 1.4125914610675137, 1.4637290791620294, 1.5144237971947048, 1.564697681151467, 1.6145708614026566, 1.6640617702545601, 1.7131873426422428, 1.7619631867934153, 1.810403730235845, 1.8585223454127107, 1.9063314583190991, 1.953842642912831, 2.0010667035365257, 2.048013747180699, 2.0946932470941557, 2.1411140989890054, 2.1872846708790252, 2.233212847420887, 2.2789060694898216, 2.324371369608072, 2.3696154037511543, 2.41464447997958, 2.459464584279238, 2.5040814039397565, 2.548500348754844, 2.5927265702903974, 2.6367649794338113, 2.680620262410361, 2.724296895429098, 2.7677991581005377, 2.8111311457511827, 2.854296780745026, 2.8972998229093054, 2.9401438791506416, 2.9828324123379892, 3.0253687495203847, 3.067756089540084, 3.109997510095221, 3.1520959743004386, 3.1940543367889287, 3.235875349394938, 3.2775616664518625, 3.3191158497376274, 3.3605403730959673, 3.4018376267595056, 3.4430099213980885, 3.4840594919136816, 3.5249885010011757, 3.5657990424927273, 3.6064931445016932, 3.647072772380809, 3.6875398315080354, 3.727896169912304, 3.7681435807504204, 3.808283804645426, 3.8483185318958806, 3.888249404564789, 3.9280780184561648, 3.967805924986641, 4.00743463295892, 4.046965610243381, 4.086400285373643, 4.125740049061481, 4.1649862556360695, 4.204140224412201, 4.243203240991739, 4.282176558502317, 4.3210613987769815, 4.359858953478209, 4.398570385169542, 4.437196828337797, 4.475739390368659, 4.514199152478268, 4.552577170603207, 4.590874476251195, 4.629092077314587, 4.667230958848688, 4.705292083816748, 4.7432763938033675, 4.781184809697978], [0.0, 0.13257816069359948, 0.23083198494515417, 0.31927799931143663, 0.4019018290415329, 0.48044977359257246, 0.5558952842972614, 0.6288548599518198, 0.6997517273236981, 0.7688931594088335, 0.8365116420730186, 0.9027887483210062, 0.9678699057572799, 1.0318740040660686, 1.094899905125124, 1.1570310048031527, 1.2183385207781625, 1.2788839196488955, 1.3387207460757933, 1.3978960263233686, 1.4564513624208644, 1.514423797194705, 1.5718465067765095, 1.628749361269196, 1.6851593833087333, 1.7411011265922485, 1.7965969909806858, 1.851667486831815, 1.9063314583190993, 1.9606062733361438, 2.0145079859649306, 2.0680514762530007, 2.121250571097592, 2.174118149300305, 2.2266662332814025, 2.2789060694898216, 2.3308481991849788, 2.3825025209783215, 2.4338783462904443, 2.4849844486913355, 2.535829107937782, 2.5864201493960186, 2.6367649794338117, 2.686870617280111, 2.7367437237786705, 2.7863906274020755, 2.8358173478422017, 2.885029617450606, 2.934032900766334, 2.9828324123379892, 3.0314331330207964, 3.0798398249069994, 3.128057045028716, 3.1760891579558237, 3.2239403473971104, 3.2716146269005324, 3.3191158497376274, 3.3664477180477252, 3.41361379130939, 3.46061749419932, 3.5074621238926214, 3.55415085685279, 3.6006867551548614, 3.6470727723808096, 3.6933117591224676, 3.7394064681238106, 3.7853595590914146, 3.831173603199201, 3.8768510873111675, 3.922394417943637, 3.9678059249866404, 4.0130878652022925, 4.05824242551648, 4.103271726118779, 4.148177823384228, 4.192962712629476, 4.237628330714772, 4.282176558502317, 4.326609223180701, 4.370928100464299, 4.415134916675888, 4.459231350720038, 4.5032190359543, 4.5470995619646475, 4.590874476251195, 4.634545285829697, 4.6781134587540105, 4.721580425564286, 4.764947580665309, 4.808216283639134, 4.851387860495835, 4.894463604865941, 4.937444779137899, 4.980332615543653, 5.023128317195254, 5.065833059075191, 5.108447988982987, 5.150974228440411, 5.193412873557547, 5.235764995861768, 5.278031643091579, 5.32021383995715], [0.0, 0.14567801244906114, 0.25364015159477993, 0.350825385682457, 0.44161315369070003, 0.5279223043403284, 0.6108224742488859, 0.6909910775458247, 0.7688931594088335, 0.8448663540236124, 0.9191661188401216, 0.9919919678228658, 1.0635036980625998, 1.1338319465572162, 1.2030853435802271, 1.2713555252226452, 1.3387207460757933, 1.4052485461620243, 1.470997760810397, 1.536020062880991, 1.6003611650379599, 1.6640617702545601, 1.727158332746853, 1.7896836740383983, 1.851667486831815, 1.9131367509386863, 1.9741160795170507, 2.03462800952276, 2.0946932470941557, 2.154330876220694, 2.213558537264427, 2.272392580548362, 2.3308481991849788, 2.3889395445111954, 2.4466798268648198, 2.5040814039397565, 2.561155858561657, 2.617914067409109, 2.67436626195039, 2.7305220826589465, 2.7863906274020755, 2.8419804947588623, 2.897299822909306, 2.9523563246419755, 3.007157318948735, 3.061709759609174, 3.11602026111201, 3.1700951222139695, 3.2239403473971104, 3.277561666451862, 3.3309645523843803, 3.3841542378221914, 3.43713573007101, 3.4899138249574, 3.5424931195762213, 3.59487802404816, 3.647072772380809, 3.699081432516404, 3.7509079156403162, 3.802555984816477, 3.854029263008983, 3.9053312405429854, 3.9564652820526187, 4.00743463295892, 4.05824242551648, 4.1088916844638295, 4.159385332309214, 4.209726194280444, 4.2599170029648645, 4.309960402663115, 4.359858953478208, 4.4096151351595845, 4.459231350720038, 4.508709929841937, 4.558053132087696, 4.607263149928244, 4.6563421116021235, 4.705292083816747, 4.754115074302503, 4.802813034229475, 4.851387860495835, 4.89984139789623, 4.948175441177851, 4.996391736991309, 5.044491985742914, 5.092477843354413, 5.140350922935894, 5.188112796377059, 5.235764995861768, 5.283309015310365, 5.330746311754014, 5.378078306644963, 5.425306387106392, 5.472431907125259, 5.519456188691334, 5.566380522885388, 5.613206170919313, 5.659934365130786, 5.706566309934904, 5.753103182735074, 5.799546134795289, 5.8458962920758175], [0.0, 0.15848931924611134, 0.27594593229224296, 0.38167789096181765, 0.4804497735925725, 0.5743491774985174, 0.664539805948974, 0.7517586466500455, 0.8365116420730186, 0.9191661188401216, 1.0, 1.079230345298891, 1.1570310048031527, 1.233544104071174, 1.3088878266078583, 1.3831618672225916, 1.4564513624208644, 1.5288297918718774, 1.60036116503796, 1.6711016990261411, 1.7411011265922482, 1.810403730235845, 1.87904917005244, 1.9470731539765267, 2.01450798596493, 2.081383018504683, 2.1477250292995467, 2.213558537264427, 2.2789060694898216, 2.343788388261312, 2.4082246852806923, 2.4722327487612916, 2.535829107937782, 2.5990291586527943, 2.661847272995918, 2.724296895429098, 2.7863906274020755, 2.8481403021171032, 2.9095570508246347, 2.970651361806657, 3.0314331330207964, 3.091911719227754, 3.1520959743004386, 3.211994289310292, 3.2716146269005324, 3.3309645523843803, 3.390051261946053, 3.4488816082714764, 3.5074621238926214, 3.5657990424927277, 3.623898318388478, 3.681765644378398, 3.7394064681238106, 3.796826007208857, 3.854029263008983, 3.9110210334824664, 3.967805924986641, 4.024388363209259, 4.080772603295601, 4.136962739243317, 4.192962712629476, 4.248776320727584, 4.304407224066535, 4.359858953478209, 4.415134916675888, 4.470238404401549, 4.525172596176483, 4.5799405656864485, 4.634545285829697, 4.688989633453605, 4.743276393803367, 4.797408264704094, 4.851387860495835, 4.905217715739342, 4.958900288708875, 5.012437964687017, 5.065833059075191, 5.119087820332485, 5.172204432754366, 5.2251850191019376, 5.278031643091578, 5.330746311754014, 5.383330977671218, 5.435787541098841, 5.488117851981384, 5.540323711866702, 5.5924068757260175, 5.644369053685139, 5.6962119126721955, 5.747937077986809, 5.799546134795289, 5.851040629556123, 5.902422071379746, 5.953691933326282, 6.004851653644753, 6.0559026369569615, 6.106846255389083, 6.157683849653805, 6.2084167300856485, 6.2590461776319675, 6.309573444801933, 6.359999756575714], [0.0, 0.1710464827361669, 0.29780922379158176, 0.4119183620556749, 0.518515975053086, 0.619855061153859, 0.7171915242391692, 0.8113207438055556, 0.9027887483210062, 0.9919919678228658, 1.079230345298891, 1.1647381382139634, 1.2487029708352293, 1.3312782293781442, 1.4125914610675139, 1.4927502595668962, 1.5718465067765097, 1.6499595041851178, 1.7271583327468532, 1.8035036636695456, 1.87904917005244, 1.9538426429128313, 2.0279268846292893, 2.1013404322882874, 2.174118149300305, 2.2462917137600567, 2.3178900249780203, 2.3889395445111954, 2.4594645842792384, 2.529487551570787, 2.5990291586527947, 2.668108603104875, 2.736743723778671, 2.8049511363347412, 2.872746351568296, 2.940143879150642, 3.0071573189487353, 3.073799441713529, 3.140082260628293, 3.206017094965219, 3.271614626900533, 3.3368849523758564, 3.4018376267595065, 3.4664817059504123, 3.530825783474764, 3.5948780240481604, 3.65864619401098, 3.72213768898982, 3.785359559091415, 3.8483185318958815, 3.9110210334824673, 3.9734732076920922, 4.035680933806167, 4.097649842799824, 4.159385332309215, 4.220892580436508, 4.282176558502318, 4.343242042843167, 4.404093625740965, 4.46473572556221, 4.525172596176484, 4.585408335716583, 4.645446894736367, 4.705292083816749, 4.764947580665309, 4.824416936750647, 4.883703583508624, 4.942810838154184, 5.001741909129331, 5.060499901215055, 5.119087820332486, 5.177508578056353, 5.235764995861768, 5.2938598091236075, 5.35179567088605, 5.409575155418439, 5.467200761572256, 5.524674915952775, 5.581999975917949, 5.6391782324159765, 5.696211912672196, 5.7531031827350745, 5.809854149890325, 5.866466864951511, 5.922943324434876, 5.979285472625534, 6.035495203541681, 6.091574362802987, 6.14752474940887, 6.203348117432003, 6.259046177631968, 6.314620598993695, 6.370073010194958, 6.425405001006945, 6.480618123631643, 6.535713893979525, 6.590693792890799, 6.6455592673032795, 6.700311731369746, 6.754952567527452, 6.809483127522303, 6.86390473339007], [0.0, 0.18337705629789586, 0.31927799931143663, 0.44161315369070003, 0.5558952842972614, 0.6645398059489739, 0.7688931594088335, 0.8698080623029604, 0.9678699057572799, 1.0635036980625998, 1.1570310048031527, 1.2487029708352293, 1.338720746075793, 1.4272487742024753, 1.514423797194705, 1.60036116503796, 1.6851593833087335, 1.768903470262513, 1.851667486831815, 1.9335164779524716, 2.01450798596493, 2.0946932470941557, 2.174118149300305, 2.2528240077707045, 2.3308481991849788, 2.4082246852806923, 2.484984448691335, 2.561155858561657, 2.6367649794338117, 2.7118358339159476, 2.7863906274020755, 2.860449941406537, 2.934032900766334, 3.0071573189487353, 3.079839824906999, 3.152095974300438, 3.2239403473971104, 3.295386635578907, 3.366447718047725, 3.43713573007101, 3.5074621238926214, 3.5774377232607315, 3.647072772380809, 3.7163769799826754, 3.7853595590914146, 3.854029263008983, 3.9223944179436376, 3.9904629526654594, 4.05824242551648, 4.125740049061481, 4.192962712629476, 4.2599170029648645, 4.326609223180701, 4.393045410183606, 4.459231350720038, 4.525172596176483, 4.590874476251196, 4.656342111602124, 4.721580425564286, 4.786594155019897, 4.851387860495835, 4.915965935555279, 4.980332615543652, 5.044491985742914, 5.108447988982987, 5.172204432754366, 5.235764995861767, 5.299133234654911, 5.362312588869249, 5.425306387106391, 5.488117851981384, 5.550750104961527, 5.613206170919313, 5.6754889824201165, 5.737601383763474, 5.799546134795288, 5.861325914506797, 5.9229433244348755, 5.9844008918771046, 6.045701072933896, 6.106846255389083, 6.167838761439447, 6.228680850282867, 6.289374720574051, 6.349922512756141, 6.410326311275863, 6.470588146689334, 6.530709997665137, 6.590693792890798, 6.6505414128883755, 6.710254691744433, 6.769835418759392, 6.829285340020814, 6.888606159904933, 6.947799542510461, 7.006867113028375, 7.065810459051201, 7.124631131825087, 7.1833306474477014, 7.241910488014847, 7.3003721027184705, 7.3587169088986055], [0.0, 0.19550356531429472, 0.3403914778215197, 0.47081651205027064, 0.5926559855174484, 0.7084850415814244, 0.819739159548959, 0.9273274462596888, 1.0318740040660686, 1.1338319465572162, 1.233544104071174, 1.3312782293781442, 1.4272487742024753, 1.5216310566887556, 1.6145708614026568, 1.706191166288504, 1.796596990980686, 1.8858789758919146, 1.974116079517051, 2.061377648137018, 2.1477250292995467, 2.233212847420887, 2.3178900249780203, 2.40180060928301, 2.484984448691335, 2.567477750790315, 2.6493135470585454, 2.7305220826589465, 2.8111311457511827, 2.891166347530221, 2.970651361806657, 3.0496081311261634, 3.128057045028716, 3.2060170949652185, 3.2835060095420476, 3.3605403730959673, 3.43713573007101, 3.5133066772440453, 3.5890669455034416, 3.6644294726076057, 3.7394064681238106, 3.8140094715619632, 3.8882494045647893, 3.9621366178889916, 4.035680933806166, 4.1088916844638295, 4.181777746672597, 4.2543475735227885, 4.326609223180701, 4.398570385169542, 4.47023840440155, 4.54162030319478, 4.612722801479739, 4.683552335376582, 4.754115074302503, 4.824416936750646, 4.894463604865942, 4.964260537929424, 5.0338129848504645, 5.103125995755727, 5.172204432754366, 5.2410529799507275, 5.309676152768644, 5.378078306644964, 5.446263645144317, 5.514236227542064, 5.581999975917949, 5.649558681798917, 5.716916012386077, 5.784075516397551, 5.851040629556123, 5.917814679748058, 5.984400891877105, 6.050802392435738, 6.1170222138136765, 6.183063298362185, 6.248928502231042, 6.314620598993694, 6.38014228307494, 6.44549617299422, 6.510684814436707, 6.575710683163321, 6.64057618777004, 6.70528367230602, 6.769835418759393, 6.834233649418893, 6.898480529118924, 6.962578167375096, 7.026528620416772, 7.090333893122721, 7.153995940865496, 7.217516671269847, 7.280897945890053, 7.344141581810745, 7.407249353175525, 7.470222992647336, 7.533064192804331, 7.595774607474741, 7.6583558530139895, 7.7208095095271325, 7.783137122039473, 7.845340201618074], [0.0, 0.20744474060860169, 0.36118227157927313, 0.4995735451652846, 0.6288548599518198, 0.7517586466500455, 0.8698080623029605, 0.983967741147443, 1.094899905125124, 1.2030853435802271, 1.3088878266078583, 1.4125914610675139, 1.514423797194705, 1.6145708614026568, 1.7131873426422428, 1.8104037302358449, 1.9063314583190993, 2.001066703536526, 2.0946932470941557, 2.1872846708790252, 2.2789060694898216, 2.3696154037511548, 2.4594645842792384, 2.548500348754844, 2.6367649794338113, 2.7242968954290983, 2.8111311457511823, 2.897299822909306, 2.9828324123379892, 3.067756089540084, 3.152095974300439, 3.2358753493949384, 3.3191158497376274, 3.4018376267595065, 3.4840594919136816, 3.5657990424927277, 3.647072772380809, 3.727896169912304, 3.808283804645426, 3.8882494045647893, 3.967805924986641, 4.046965610243381, 4.125740049061481, 4.204140224412201, 4.282176558502317, 4.359858953478209, 4.437196828337797, 4.514199152478268, 4.590874476251196, 4.667230958848688, 4.7432763938033675, 4.819018232349922, 4.894463604865942, 4.969619340583793, 5.044491985742914, 5.119087820332485, 5.1934128735575475, 5.267472938146923, 5.341273583608471, 5.4148201685258766, 5.488117851981385, 5.5611716041800605, 5.633986216343612, 5.706566309934905, 5.778916345268371, 5.851040629556124, 5.922943324434876, 5.9946284530145, 6.066099906485327, 6.137361450317868, 6.2084167300856485, 6.279269276939119, 6.349922512756142, 6.420379754992431, 6.490644221253241, 6.560719033605906, 6.630607222651165, 6.7003117313697445, 6.769835418759393, 6.839181063276276, 6.908351366093639, 6.977348954189568, 7.046176383274837, 7.114836140570936, 7.1833306474477014, 7.25166226192919, 7.31983328107587, 7.387845943250595, 7.455702430275301, 7.523404869484879, 7.590955335684211, 7.658355853013989, 7.725608396730489, 7.792714894904176, 7.859677230041685, 7.9264972406353955, 7.993176722644555, 8.059717430911679, 8.12612108051767, 8.19238934807893, 8.25852387298946, 8.324526258610895], [0.0, 0.21921638274328878, 0.3816778909618176, 0.5279223043403284, 0.664539805948974, 0.794417880786609, 0.9191661188401216, 1.0398038934012055, 1.1570310048031527, 1.2713555252226452, 1.3831618672225916, 1.4927502595668962, 1.60036116503796, 1.706191166288504, 1.8104037302358449, 1.913136750938686, 2.01450798596493, 2.114619069591032, 2.213558537264427, 2.311404146343843, 2.408224685280692, 2.5040814039397565, 2.5990291586527943, 2.693117339273153, 2.786390627402075, 2.8788896222803313, 2.9706513618066563, 3.061709759609174, 3.1520959743004386, 3.241838723482145, 3.3309645523843803, 3.4194980649855085, 3.5074621238926214, 3.5948780240481604, 3.6817656443783977, 3.7681435807504204, 3.854029263008983, 3.9394390583882086, 4.024388363209258, 4.10889168446383, 4.192962712629476, 4.276614386854473, 4.359858953478208, 4.442708018710724, 4.525172596176483, 4.607263149928244, 4.688989633453605, 4.77036152512643, 4.851387860495835, 4.93207726175477, 5.012437964687017, 5.092477843354414, 5.172204432754366, 5.251624949650299, 5.330746311754014, 5.409575155418438, 5.488117851981384, 5.566380522885388, 5.644369053685139, 5.722089107042073, 5.799546134795289, 5.876745389188699, 5.953691933326281, 6.030390650920054, 6.106846255389083, 6.1830632983621845, 6.259046177631967, 6.334799144603361, 6.410326311275863, 6.485631656795064, 6.560719033605905, 6.635592173237208, 6.710254691744433, 6.784710094835364, 6.858961782701217, 6.933013054573901, 7.006867113028375, 7.080527068047506, 7.153995940865495, 7.227276667604549, 7.30037210271847, 7.373285022255626, 7.446018126952941, 7.518574045171572, 7.590955335684209, 7.6631644903231475, 7.735203936497658, 7.80707603958855, 7.878783105227244, 7.950327381466202, 8.021711060847016, 8.092936282372095, 8.164005133385446, 8.234919651367662, 8.305681825649943, 8.376293599051607, 8.446756869445256, 8.517073491253553, 8.587245276881243, 8.657273998085858, 8.727161387290321, 8.796909138840492], [0.0, 0.2308319849451542, 0.4019018290415328, 0.5558952842972614, 0.6997517273236981, 0.8365116420730185, 0.96786990575728, 1.094899905125124, 1.2183385207781625, 1.3387207460757933, 1.4564513624208644, 1.5718465067765097, 1.6851593833087335, 1.796596990980686, 1.9063314583190993, 2.01450798596493, 2.121250571097592, 2.2266662332814025, 2.3308481991849788, 2.4338783462904443, 2.535829107937782, 2.6367649794338117, 2.736743723778671, 2.8358173478422017, 2.934032900766334, 3.0314331330207964, 3.1280570450287155, 3.2239403473971104, 3.3191158497376274, 3.41361379130939, 3.507462123892622, 3.600686755154862, 3.6933117591224676, 3.785359559091415, 3.8768510873111675, 3.9678059249866404, 4.05824242551648, 4.148177823384227, 4.237628330714771, 4.326609223180701, 4.415134916675888, 4.5032190359543, 4.590874476251196, 4.6781134587540105, 4.764947580665308, 4.851387860495835, 4.937444779137899, 5.023128317195254, 5.108447988982987, 5.193412873557547, 5.278031643091578, 5.3623125888692496, 5.446263645144317, 5.52989241107431, 5.613206170919313, 5.6962119126721955, 5.778916345268371, 5.861325914506798, 5.943446817799615, 6.02528501785528, 6.106846255389083, 6.188136060945197, 6.269159765905917, 6.349922512756142, 6.430429264664527, 6.510684814436707, 6.590693792890798, 6.670460676700612, 6.749989795747856, 6.829285340020813, 6.908351366093638, 6.987191803217392, 7.065810459051201, 7.1442110250595245, 7.222397081599259, 7.30037210271847, 7.378139460686718, 7.4557024302753, 7.533064192804331, 7.610227839972107, 7.687196377481162, 7.763972728474132, 7.840559736791689, 7.916960170063767, 7.993176722644554, 8.06921201840088, 8.145068613362968, 8.220748998245886, 8.296255600849376, 8.37159078834329, 8.446756869445256, 8.521756096496848, 8.596590667444012, 8.671262727727173, 8.74577437208608, 8.820127646284071, 8.894324548756185, 8.968367032185236, 9.04225700500973, 9.115996332867182, 9.189586839976283, 9.263030310461065], [0.0, 0.24230319295694794, 0.42187436223424096, 0.5835205306012528, 0.7345259273664233, 0.8780821334968424, 1.0159682532195478, 1.1493110152958734, 1.2788839196488955, 1.4052485461620243, 1.5288297918718774, 1.6499595041851178, 1.768903470262513, 1.8858789758919146, 2.001066703536526, 2.114619069591032, 2.2266662332814025, 2.337320532515008, 2.4466798268648198, 2.5548300627188762, 2.661847272995918, 2.7677991581005377, 2.872746351568296, 2.9767434447532533, 3.079839824906999, 3.1820803669861744, 3.2835060095420476, 3.3841542378221914, 3.484059491913682, 3.5832535138172648, 3.681765644378398, 3.779623078747565, 3.876851087311168, 3.9734732076920922, 4.069511412369074, 4.1649862556360695, 4.259917002964865, 4.354321745307597, 4.448217500451579, 4.54162030319478, 4.634545285829698, 4.727006750193185, 4.819018232349922, 4.910592560819913, 5.001741909129331, 5.092477843354414, 5.182811365235979, 5.272752951364427, 5.3623125888692496, 5.451499807991096, 5.540323711866703, 5.628793003816055, 5.716916012386077, 5.804700714374848, 5.892154756034149, 5.979285472625534, 6.066099906485328, 6.152604823736817, 6.238806729772873, 6.324711883619072, 6.410326311275864, 6.495655818128114, 6.580706000501447, 6.665482256436832, 6.749989795747857, 6.834233649418893, 6.918218678396816, 7.001949581823982, 7.085430904755806, 7.168667045402266, 7.25166226192919, 7.334420678851985, 7.4169462930516, 7.499242979440024, 7.581314496300183, 7.663164490323148, 7.744796501363601, 7.826213966932776, 7.90742022644666, 7.988418525245667, 8.06921201840088, 8.149803774320668, 8.230196778170518, 8.310393935117885, 8.390398073413035, 8.470211947315997, 8.549838239879064, 8.629279565593517, 8.70853847290874, 8.78761744663122, 8.866518910210432, 8.945245227918186, 9.023798706927472, 9.102181599296495, 9.180396103863206, 9.258444368055265, 9.336328489620046, 9.414050518279048, 9.491612457310724, 9.569016265065551, 9.646263856416864, 9.72335710415084], [0.0, 0.25364015159477993, 0.4416131536907, 0.610822474248886, 0.7688931594088335, 0.9191661188401216, 1.0635036980626, 1.2030853435802271, 1.3387207460757933, 1.470997760810397, 1.60036116503796, 1.7271583327468532, 1.851667486831815, 1.974116079517051, 2.0946932470941557, 2.213558537264427, 2.3308481991849788, 2.4466798268648198, 2.561155858561657, 2.67436626195039, 2.786390627402075, 2.897299822909306, 3.0071573189487353, 3.1160202611120096, 3.2239403473971104, 3.3309645523843803, 3.4371357300710095, 3.5424931195762213, 3.647072772380809, 3.7509079156403162, 3.8540292630089836, 3.956465282052619, 4.05824242551648, 4.159385332309215, 4.2599170029648645, 4.359858953478208, 4.459231350720038, 4.558053132087695, 4.6563421116021235, 4.754115074302504, 4.851387860495835, 4.948175441177851, 5.044491985742914, 5.140350922935894, 5.235764995861767, 5.330746311754014, 5.425306387106392, 5.519456188691334, 5.613206170919313, 5.706566309934904, 5.799546134795289, 5.89215475603415, 5.984400891877105, 6.076292892343193, 6.167838761439447, 6.259046177631967, 6.349922512756142, 6.440474849510779, 6.530709997665137, 6.6206345090940655, 6.710254691744433, 6.7995766226252945, 6.888606159904932, 6.977348954189568, 7.065810459051201, 7.153995940865495, 7.241910488014847, 7.329559019506579, 7.416946293051599, 7.504076912644729, 7.59095533568421, 7.677585879664583, 7.763972728474132, 7.850119938325455, 7.936031443345213, 8.021711060847016, 8.107162496309387, 8.192389348078928, 8.27739511181728, 8.362183184708872, 8.446756869445256, 8.531119378000463, 8.61527383521085, 8.699223282171769, 8.782970679462554, 8.86651891021043, 8.949870783003188, 9.033029034659759, 9.115996332867182, 9.198775278691858, 9.281368408972387, 9.363778198600876, 9.44600706269906, 9.528057358695154, 9.609931388307038, 9.691631399436897, 9.773159587982176, 9.854518099567395, 9.935709031201032, 10.016734432861487, 10.097596309015797, 10.178296620074653], [0.0, 0.26485177066967314, 0.4611337162929197, 0.6378225720670077, 0.8028804329472727, 0.9597958863520392, 1.1105135987918326, 1.2562651516744836, 1.3978960263233686, 1.536020062880991, 1.6711016990261411, 1.8035036636695456, 1.9335164779524716, 2.061377648137018, 2.1872846708790252, 2.311404146343843, 2.4338783462904443, 2.5548300627188762, 2.67436626195039, 2.7925808884880556, 2.9095570508246347, 3.0253687495203843, 3.140082260628293, 3.253757255738361, 3.3664477180477244, 3.4782026985473338, 3.589066945503441, 3.6990814325164036, 3.808283804645426, 3.9167087577812194, 4.024388363209259, 4.1313523468430615, 4.237628330714771, 4.343242042843166, 4.448217500451579, 4.5525771706032065, 4.6563421116021235, 4.759532097932718, 4.862165731046535, 4.964260537929424, 5.065833059075191, 5.166898927240337, 5.2674729381469225, 5.367569114128692, 5.467200761572254, 5.566380522885388, 5.665120423623763, 5.7634319153224745, 5.861325914506797, 5.958812838295384, 6.0559026369569615, 6.152604823736817, 6.248928502231042, 6.3448823915533605, 6.440474849510778, 6.5357138939795245, 6.630607222651165, 6.7251622313000246, 6.819386030706608, 6.913285462357345, 7.006867113028375, 7.100137328349903, 7.1931022254379835, 7.285767704671769, 7.378139460686717, 7.470222992647335, 7.562023613857055, 7.65354646075737, 7.7447965013635995, 7.835778543180282, 7.926497240635394, 8.016957102069064, 8.107162496309387, 8.19711765886514, 8.286826697762624, 8.376293599051607, 8.465522232003346, 8.554516354021642, 8.64327961528636, 8.731815563147187, 8.820127646284071, 8.908219218649469, 8.99609354320643, 9.083753795475403, 9.171203066901787, 9.258444368055263, 9.345480631671222, 9.432314715543809, 9.518949405279452, 9.60538741691911, 9.691631399436897, 9.77768393712222, 9.86354755185209, 9.94922470525978, 10.03471780080568, 10.120029185755667, 10.205161153072124, 10.290115943222302, 10.374895745908447, 10.459502701723855, 10.543938903738733, 10.62820639901952], [0.0, 0.27594593229224296, 0.48044977359257246, 0.664539805948974, 0.8365116420730186, 0.9999999999999999, 1.1570310048031527, 1.308887826607858, 1.4564513624208644, 1.6003611650379599, 1.7411011265922482, 1.87904917005244, 2.01450798596493, 2.1477250292995467, 2.2789060694898216, 2.408224685280692, 2.535829107937782, 2.661847272995918, 2.786390627402075, 2.9095570508246347, 3.031433133020796, 3.1520959743004386, 3.2716146269005324, 3.3900512619460526, 3.507462123892621, 3.623898318388478, 3.73940646812381, 3.854029263008983, 3.967805924986641, 4.0807726032956, 4.192962712629476, 4.304407224066535, 4.415134916675888, 4.525172596176483, 4.634545285829697, 4.743276393803367, 4.851387860495835, 4.9589002887088744, 5.0658330590751905, 5.172204432754366, 5.278031643091578, 5.383330977671218, 5.488117851981384, 5.5924068757260175, 5.696211912672195, 5.799546134795288, 5.902422071379746, 6.004851653644753, 6.106846255389083, 6.2084167300856485, 6.3095734448019325, 6.410326311275864, 6.510684814436707, 6.610658038626088, 6.710254691744433, 6.809483127522301, 6.908351366093638, 7.006867113028375, 7.105037776964752, 7.2028704859666925, 7.30037210271847, 7.397549238657264, 7.494408267134057, 7.59095533568421, 7.687196377481161, 7.783137122039471, 7.878783105227243, 7.9741396786422145, 8.06921201840088, 8.164005133385446, 8.258523872989459, 8.35277293439926, 8.446756869445256, 8.540480091054024, 8.633946879329647, 8.727161387290321, 8.820127646284071, 8.912849571105546, 9.005330964834048, 9.097575523411322, 9.18958683997628, 9.281368408972385, 9.372923630042306, 9.464255811723298, 9.555368174955817, 9.646263856416862, 9.736945911688805, 9.827417318273618, 9.917680978461744, 10.007739722064189, 10.097596309015797, 10.187253431857183, 10.276713718102227, 10.36597973249757, 10.455053979180205, 10.543938903738733, 10.632636895183586, 10.721150287831131, 10.809481363106284, 10.897632351267923, 10.98560543306118, 11.0734027413004], [0.0, 0.2869296547656997, 0.49957354516528457, 0.6909910775458248, 0.8698080623029605, 1.0398038934012055, 1.2030853435802271, 1.3609866581322931, 1.514423797194705, 1.6640617702545601, 1.810403730235845, 1.9538426429128313, 2.0946932470941557, 2.233212847420887, 2.3696154037511548, 2.5040814039397565, 2.6367649794338117, 2.7677991581005377, 2.897299822909306, 3.0253687495203843, 3.1520959743004386, 3.2775616664518625, 3.4018376267595065, 3.524988501001176, 3.647072772380809, 3.768143580750421, 3.888249404564789, 4.00743463295892, 4.125740049061481, 4.243203240991739, 4.359858953478209, 4.475739390368659, 4.590874476251196, 4.705292083816749, 4.819018232349922, 4.93207726175477, 5.044491985742915, 5.156283827187851, 5.267472938146923, 5.378078306644965, 5.488117851981385, 5.5976085100498505, 5.706566309934905, 5.815006442863585, 5.922943324434876, 6.030390650920054, 6.137361450317869, 6.243868128756482, 6.349922512756142, 6.455535887800239, 6.560719033605906, 6.665482256436832, 6.769835418759394, 6.873787966507384, 6.977348954189568, 7.080527068047507, 7.183330647447702, 7.28576770467177, 7.387845943250596, 7.4895727749728005, 7.590955335684211, 7.6920004999829485, 7.792714894904175, 7.893104912679098, 7.993176722644555, 8.092936282372097, 8.192389348078928, 8.291541484377213, 8.390398073413035, 8.488964323441616, 8.587245276881243, 8.685245817884564, 8.782970679462556, 8.880424450193455, 8.977611580546156, 9.074536388845143, 9.17120306690179, 9.267615685334812, 9.363778198600878, 9.459694449754604, 9.555368174955818, 9.650803007740441, 9.746002483070152, 9.840970041174874, 9.935709031201032, 10.030222714677581, 10.12451426881097, 10.218586789619343, 10.312443294915601, 10.406086727148244, 10.49951995610827, 10.592745781509892, 10.685766935452277, 10.778586084768962, 10.871205833271343, 10.963628723891974, 11.055857240733198, 11.147893811026266, 11.239740807005687, 11.331400547703321, 11.422875300666451, 11.51416728360374], [0.0, 0.29780922379158176, 0.518515975053086, 0.7171915242391692, 0.9027887483210061, 1.0792303452988907, 1.248702970835229, 1.4125914610675137, 1.5718465067765095, 1.727158332746853, 1.87904917005244, 2.0279268846292893, 2.174118149300305, 2.3178900249780203, 2.4594645842792384, 2.5990291586527943, 2.736743723778671, 2.872746351568296, 3.0071573189487353, 3.140082260628293, 3.2716146269005324, 3.4018376267595065, 3.530825783474764, 3.6586461940109793, 3.7853595590914146, 3.911021033482467, 4.035680933806166, 4.159385332309215, 4.282176558502318, 4.404093625740964, 4.525172596176484, 4.645446894736367, 4.764947580665309, 4.883703583508625, 5.001741909129331, 5.119087820332485, 5.235764995861768, 5.351795670886049, 5.467200761572255, 5.58199997591795, 5.6962119126721955, 5.809854149890324, 5.922943324434876, 6.035495203541681, 6.147524749408869, 6.2590461776319675, 6.370073010194958, 6.4806181236316425, 6.590693792890799, 6.700311731369745, 6.809483127522302, 6.9182186783968165, 7.026528620416773, 7.134422757679323, 7.241910488014847, 7.3490008270228655, 7.455702430275302, 7.562023613857057, 7.667972373395334, 7.773556401713024, 7.878783105227245, 7.983659619201627, 8.088192821949951, 8.19238934807893, 8.296255600849378, 8.399797763727275, 8.503021811189466, 8.605933518842624, 8.70853847290874, 8.810842079125493, 8.912849571105546, 9.014566018194945, 9.115996332867182, 9.217145277686537, 9.318017471871217, 9.41861739748448, 9.518949405279452, 9.619017720221311, 9.718826446708643, 9.818379573513939, 9.917680978461746, 10.016734432861487, 10.115543605710693, 10.214112067683171, 10.3124432949156, 10.41054067260498, 10.508407498428532, 10.606046985796738, 10.703462266949511, 10.800656395904761, 10.897632351267925, 10.99439303891054, 11.090941294525317, 11.187279886064658, 11.283411516069195, 11.379338823892361, 11.47506438782671, 11.570590727137295, 11.665920304007122, 11.761055525399247, 11.855998744839988, 11.950752264127317], [0.0, 0.30859029869611865, 0.5372869167152505, 0.7431547749581351, 0.9354708559961983, 1.1182998645158624, 1.2939076159120178, 1.4637290791620294, 1.628749361269196, 1.7896836740383983, 1.9470731539765267, 2.1013404322882874, 2.2528240077707045, 2.40180060928301, 2.548500348754844, 2.693117339273153, 2.8358173478422017, 2.9767434447532533, 3.1160202611120096, 3.253757255738361, 3.3900512619460526, 3.524988501001176, 3.6586461940109793, 3.7910938669360994, 3.922394417943637, 4.052604998473097, 4.181777746672597, 4.309960402663115, 4.437196828337797, 4.5635274493855125, 4.688989633453606, 4.813618015494706, 4.937444779137899, 5.060499901215055, 5.182811365235979, 5.304405348551593, 5.425306387106392, 5.5455375210108055, 5.665120423623763, 5.784075516397551, 5.902422071379746, 6.020178302973767, 6.137361450317868, 6.253987851441982, 6.370073010194957, 6.485631656795065, 6.600677802739406, 6.715224790708779, 6.829285340020813, 6.942871588112794, 7.055995128474885, 7.168667045402267, 7.280897945890052, 7.392697988956252, 7.50407691264473, 7.615044058931241, 7.725608396730489, 7.835778543180284, 7.945562783359767, 8.054969088581856, 8.164005133385446, 8.27267831133984, 8.380995749762576, 8.488964323441616, 8.59659066744401, 8.70388118908512, 8.810842079125491, 8.91747932225615, 9.02379870692747, 9.12980583457175, 9.235506128265127, 9.340904840870456, 9.44600706269906, 9.550817728726134, 9.655341625391499, 9.759583397014833, 9.86354755185209, 9.967238467817594, 10.070660397894416, 10.173817475253708, 10.276713718102227, 10.379353034275626, 10.481739225593836, 10.58387599199363, 10.685766935452275, 10.787415563715237, 10.88882529383987, 10.989999455566227, 11.090941294525315, 11.191653975294397, 11.292140584308237, 11.392404132634644, 11.492447558622025, 11.592273730426209, 11.691885448423252, 11.791285447514555, 11.890476399330163, 11.989460914335755, 12.088241543848499, 12.186820781966599, 12.285201067417038, 12.383384785325818], [0.0, 0.31927799931143663, 0.5558952842972613, 0.7688931594088335, 0.9678699057572799, 1.1570310048031525, 1.338720746075793, 1.5144237971947048, 1.6851593833087333, 1.851667486831815, 2.01450798596493, 2.174118149300305, 2.3308481991849788, 2.484984448691335, 2.6367649794338113, 2.786390627402075, 2.934032900766334, 3.079839824906999, 3.2239403473971104, 3.3664477180477244, 3.507462123892621, 3.647072772380809, 3.7853595590914146, 3.922394417943637, 4.05824242551648, 4.192962712629476, 4.3266092231807, 4.459231350720038, 4.590874476251195, 4.7215804255642855, 4.851387860495835, 4.980332615543653, 5.108447988982987, 5.235764995861768, 5.362312588869249, 5.488117851981384, 5.613206170919313, 5.737601383763473, 5.861325914506796, 5.984400891877105, 6.106846255389083, 6.228680850282867, 6.349922512756141, 6.470588146689334, 6.590693792890798, 6.710254691744433, 6.829285340020813, 6.947799542510461, 7.065810459051201, 7.1833306474477014, 7.30037210271847, 7.4169462930516, 7.53306419280433, 7.6487363128415815, 7.763972728474131, 7.878783105227243, 7.993176722644555, 8.107162496309387, 8.220748998245886, 8.333944475845016, 8.446756869445256, 8.559193828684412, 8.671262727727171, 8.782970679462556, 8.894324548756183, 9.005330964834048, 9.11599633286718, 9.22632684482009, 9.336328489620044, 9.446007062699058, 9.555368174955817, 9.664417261180555, 9.773159587982176, 9.881600261253558, 9.989744233207828, 10.097596309015795, 10.205161153072126, 10.3124432949156, 10.419447134826882, 10.526176949125169, 10.632636895183586, 10.738831016181559, 10.844763245611063, 10.950437411552286, 11.055857240733197, 11.161026362386337, 11.265948311915247, 11.370626534382028, 11.475064387826707, 11.579265146428353, 11.683232003517153, 11.786968074446083, 11.890476399330163, 11.99375994566078, 12.096821610802072, 12.199664224375878, 12.302290550541338, 12.404703290174863, 12.506905082955818, 12.60889850936287, 12.71068609258575, 12.812270300356788], [0.0, 0.32987697769322355, 0.5743491774985174, 0.7944178807866092, 1.0, 1.1954406247375462, 1.3831618672225916, 1.564697681151467, 1.7411011265922485, 1.9131367509386863, 2.081383018504683, 2.2462917137600567, 2.4082246852806923, 2.567477750790315, 2.7242968954290983, 2.8788896222803313, 3.0314331330207964, 3.1820803669861744, 3.3309645523843803, 3.4782026985473338, 3.623898318388478, 3.768143580750421, 3.911021033482467, 4.052604998473097, 4.192962712629476, 4.3321552697196655, 4.470238404401549, 4.607263149928244, 4.7432763938033675, 4.878321350295555, 5.012437964687018, 5.145663261062906, 5.278031643091578, 5.409575155418439, 5.540323711866703, 5.670305295511152, 5.799546134795289, 5.928070859145336, 6.0559026369569615, 6.183063298362186, 6.309573444801933, 6.435452547116266, 6.560719033605906, 6.685390369304459, 6.809483127522302, 6.933013054573902, 7.055995128474885, 7.178443612289371, 7.3003721027184705, 7.421793574444622, 7.542720420681454, 7.663164490323149, 7.783137122039472, 7.902649175621454, 8.021711060847016, 8.14033276410504, 8.25852387298946, 8.376293599051609, 8.49365079887861, 8.610603993647656, 8.727161387290321, 8.8433308833872, 8.959120100900968, 9.074536388845143, 9.189586839976283, 9.304278303588854, 9.41861739748448, 9.532610519180505, 9.646263856416862, 9.759583397014833, 9.872574938136458, 9.98524409498912, 10.097596309015797, 10.209636855608197, 10.321370851376622, 10.432803261007733, 10.543938903738734, 10.654782459474186, 10.765338474569583, 10.87561136730384, 10.98560543306118, 11.095324849241274, 11.204773679915085, 11.313955880242453, 11.42287530066645, 11.531535690898187, 11.639940703704962, 11.748093898513595, 11.855998744839987, 11.963658625555173, 12.071076839997385, 12.178256606939064, 12.28520106741704, 12.391913287433638, 12.498396260535952, 12.604652910279949, 12.71068609258575, 12.816498597989971, 12.92209315380064, 13.027472426159822, 13.132639022018838, 13.237595491030609], [0.0, 0.3403914778215197, 0.5926559855174482, 0.8197391595489589, 1.0318740040660683, 1.2335441040711739, 1.4272487742024753, 1.6145708614026566, 1.7965969909806858, 1.9741160795170507, 2.1477250292995467, 2.3178900249780203, 2.484984448691335, 2.6493135470585454, 2.8111311457511823, 2.9706513618066563, 3.1280570450287155, 3.2835060095420476, 3.4371357300710095, 3.589066945503441, 3.73940646812381, 3.888249404564789, 4.035680933806166, 4.181777746672597, 4.3266092231807, 4.470238404401549, 4.612722801479738, 4.754115074302503, 4.894463604865941, 5.033812984850464, 5.172204432754366, 5.309676152768644, 5.446263645144316, 5.581999975917949, 5.7169160123860765, 5.851040629556123, 5.9844008918771046, 6.117022213813676, 6.248928502231041, 6.380142283074941, 6.510684814436707, 6.64057618777004, 6.769835418759393, 6.898480529118923, 7.026528620416771, 7.153995940865494, 7.280897945890052, 7.407249353175525, 7.53306419280433, 7.6583558530139895, 7.783137122039472, 7.90742022644666, 8.031216866314125, 8.154538247577923, 8.27739511181728, 8.399797763727273, 8.521756096496848, 8.64327961528636, 8.764377458977831, 8.885058420352486, 9.005330964834048, 9.12520324792187, 9.24468313142548, 9.363778198600878, 9.482495768279174, 9.600842908069275, 9.718826446708642, 9.83645298562911, 9.953728909798661, 10.070660397894414, 10.187253431857183, 10.303513805873488, 10.419447134826884, 10.535058862256934, 10.6503542678608, 10.765338474569583, 10.880016455228878, 10.99439303891054, 11.108472916880617, 11.22226064824626, 11.335760665302793, 11.44897727860034, 11.561914681748073, 11.674576955972618, 11.786968074446083, 11.899091906397887, 12.010952221023647, 12.12255269120337, 12.233896897040317, 12.344988329231171, 12.455830392277285, 12.566426407546262, 12.676779616192356, 12.786893181943665, 12.896770193763608, 13.006413668393591, 13.115826552783346, 13.225011726415064, 13.333972003526995, 13.442710135241834, 13.551228811604874, 13.659530663536685], [0.0, 0.350825385682457, 0.6108224742488859, 0.8448663540236125, 1.0635036980626, 1.2713555252226452, 1.470997760810397, 1.6640617702545601, 1.851667486831815, 2.03462800952276, 2.213558537264427, 2.3889395445111954, 2.561155858561657, 2.7305220826589465, 2.897299822909306, 3.061709759609174, 3.2239403473971104, 3.3841542378221914, 3.5424931195762213, 3.6990814325164036, 3.854029263008983, 4.00743463295892, 4.159385332309215, 4.309960402663115, 4.459231350720038, 4.607263149928244, 4.754115074302503, 4.89984139789623, 5.044491985742914, 5.188112796377059, 5.330746311754015, 5.472431907125259, 5.613206170919313, 5.753103182735074, 5.892154756034149, 6.0303906509200536, 6.167838761439447, 6.304525281078199, 6.440474849510779, 6.575710683163321, 6.710254691744433, 6.844127582564527, 6.977348954189568, 7.1099373807473825, 7.241910488014847, 7.373285022255626, 7.50407691264473, 7.634301328003594, 7.763972728474132, 7.893104912679097, 8.021711060847016, 8.149803774320668, 8.27739511181728, 8.404496622764773, 8.531119378000463, 8.657273998085856, 8.782970679462556, 8.908219218649469, 9.033029034659759, 9.157409189796875, 9.281368408972387, 9.404915097673486, 9.528057358695154, 9.650803007740441, 9.773159587982176, 9.895134383670358, 10.016734432861485, 10.137966539338908, 10.25883728378693, 10.379353034275624, 10.499519956108267, 10.619344021078668, 10.73883101618156, 10.857986551815532, 10.976816069514562, 11.095324849241274, 11.213518016272259, 11.33140054770332, 11.44897727860034, 11.566252907819282, 11.683232003517153, 11.799919008373955, 11.916318244544179, 12.032433918354947, 12.148270124766702, 12.263830851611079, 12.379119983619608, 12.494141306255875, 12.60889850936287, 12.723395190636447, 12.837634858935022, 12.951620937434985, 13.06535676664062, 13.178845607256743, 13.292090642931756, 13.40509498287824, 13.517861664377802, 13.630393655176462, 13.742693855776386, 13.854765101629521, 13.96661016523824, 14.07823175816785], [0.0, 0.36118227157927313, 0.6288548599518198, 0.8698080623029605, 1.094899905125124, 1.3088878266078583, 1.514423797194705, 1.7131873426422428, 1.9063314583190993, 2.0946932470941557, 2.2789060694898216, 2.4594645842792384, 2.6367649794338117, 2.8111311457511827, 2.9828324123379892, 3.1520959743004386, 3.3191158497376274, 3.484059491913682, 3.647072772380809, 3.808283804645426, 3.967805924986641, 4.125740049061481, 4.282176558502318, 4.437196828337797, 4.590874476251195, 4.7432763938033675, 4.894463604865941, 5.044491985742914, 5.1934128735575475, 5.34127358360847, 5.488117851981385, 5.6339862163436125, 5.778916345268371, 5.922943324434877, 6.066099906485328, 6.2084167300856485, 6.349922512756142, 6.49064422125324, 6.630607222651165, 6.769835418759394, 6.908351366093639, 7.046176383274838, 7.183330647447702, 7.31983328107587, 7.455702430275301, 7.590955335684211, 7.725608396730489, 7.859677230041685, 7.993176722644555, 8.126121080517672, 8.25852387298946, 8.390398073413035, 8.52175609649685, 8.65260983262507, 8.782970679462556, 8.912849571105548, 9.04225700500973, 9.17120306690179, 9.299697453858125, 9.427749495714833, 9.555368174955818, 9.682562145210724, 9.809339748481062, 9.935709031201032, 10.06167775922912, 10.187253431857185, 10.3124432949156, 10.437254353045494, 10.561693381202737, 10.685766935452275, 10.809481363106284, 10.932842812254792, 11.055857240733198, 11.178530424567384, 11.300867965933485, 11.42287530066645, 11.544557705348643, 11.665920304007122, 11.786968074446085, 11.907705854238694, 12.028138346400732, 12.148270124766704, 12.268105639087514, 12.387649219867301, 12.506905082955818, 12.625877333911406, 12.744569972148632, 12.862986894883583, 12.981131900888892, 13.09900869406973, 13.216620886871219, 13.333972003526995, 13.451065483157988, 13.567904682729854, 13.68449287987702, 13.800833275600635, 13.916928996847371, 14.032783098975505, 14.148398568114336, 14.263778323422558, 14.378925219250927, 14.493842047214184], [0.0, 0.37146542611247585, 0.6467588718945012, 0.8945722088923753, 1.1260726004890478, 1.3461529330284603, 1.5575406807206307, 1.7619631867934153, 1.9606062733361438, 2.154330876220694, 2.343788388261312, 2.529487551570787, 2.7118358339159476, 2.891166347530221, 3.067756089540084, 3.241838723482145, 3.41361379130939, 3.5832535138172648, 3.7509079156403162, 3.9167087577812194, 4.0807726032956, 4.243203240991739, 4.404093625740964, 4.5635274493855125, 4.7215804255642855, 4.878321350295555, 5.033812984850464, 5.188112796377059, 5.34127358360847, 5.493344008948559, 5.644369053685139, 5.794390409626061, 5.9434468177996145, 6.091574362802986, 6.238806729772872, 6.385175429683061, 6.530709997665136, 6.675438168241132, 6.819386030706607, 6.962578167375096, 7.1050377769647515, 7.24678678505508, 7.3878459432505945, 7.528234918447107, 7.667972373395332, 7.807076039588549, 7.945562783359766, 8.083448665954686, 8.220748998245885, 8.35747839066776, 8.49365079887861, 8.629279565593517, 8.764377458977831, 8.898956707944679, 9.033029034659757, 9.166605684521961, 9.299697453858123, 9.432314715543809, 9.564467442739113, 9.696165230908196, 9.827417318273618, 9.958232604840932, 10.088619670115254, 10.218586789619343, 10.348141950312021, 10.477292864996125, 10.606046985796736, 10.734411516782842, 10.862393425798846, 10.989999455566226, 11.117236134110321, 11.244109784562307, 11.370626534382028, 11.496792324043547, 11.622612915221529, 11.748093898513593, 11.873240700730715, 11.998058591785188, 12.122552691203369, 12.246727974288083, 12.370589277953814, 12.494141306255875, 12.617388635633215, 12.740335719882973, 12.862986894883582, 12.985346383081987, 13.107418297759361, 13.229206647088718, 13.350715337996851, 13.471948179842139, 13.592908887918972, 13.713601086798798, 13.83402831351713, 13.954194020615182, 14.07410157904431, 14.193754280940786, 14.313155342278007, 14.432307905402801, 14.551215041462006, 14.669879752725155, 14.788304974808698, 14.90649357880693], [0.0, 0.38167789096181765, 0.664539805948974, 0.9191661188401217, 1.157031004803153, 1.3831618672225916, 1.6003611650379603, 1.810403730235845, 2.0145079859649306, 2.213558537264427, 2.4082246852806923, 2.5990291586527947, 2.7863906274020755, 2.970651361806657, 3.152095974300439, 3.3309645523843803, 3.507462123892622, 3.681765644378398, 3.8540292630089836, 4.024388363209259, 4.192962712629476, 4.359858953478209, 4.525172596176484, 4.688989633453606, 4.851387860495835, 5.012437964687018, 5.172204432754366, 5.330746311754015, 5.488117851981385, 5.644369053685139, 5.79954613479529, 5.953691933326282, 6.106846255389084, 6.259046177631968, 6.410326311275864, 6.560719033605906, 6.710254691744434, 6.858961782701217, 7.006867113028375, 7.153995940865496, 7.3003721027184705, 7.446018126952942, 7.590955335684211, 7.735203936497659, 7.878783105227244, 8.021711060847016, 8.164005133385448, 8.305681825649945, 8.446756869445256, 8.587245276881243, 8.727161387290323, 8.866518910210432, 9.00533096483405, 9.143610116276097, 9.281368408972387, 9.41861739748448, 9.55536817495582, 9.691631399436899, 9.82741731827362, 9.962735790732188, 10.097596309015797, 10.232008017812245, 10.365979732497571, 10.49951995610827, 10.632636895183587, 10.765338474569583, 10.897632351267923, 11.029525927404523, 11.161026362386337, 11.292140584308237, 11.42287530066645, 11.55323700843001, 11.683232003517155, 11.812866389719654, 11.942146087114265, 12.071076839997385, 12.19966422437588, 12.327913655044425, 12.455830392277285, 12.583419548160151, 12.71068609258575, 12.837634858935022, 12.96427054946407, 13.090597740415465, 13.216620886871217, 13.342344327363346, 13.46777228825687, 13.592908887918973, 13.71775814068713, 13.842323960648006, 13.96661016523824, 14.090620478677339, 14.214358535242301, 14.337827882392883, 14.46103198375588, 14.583974221976193, 14.70665790144195, 14.829086250890535, 14.951262425901897, 15.073189511285065, 15.19487052336355, 15.31630841216483], [0.0, 0.39182248536911973, 0.6822025707003491, 0.943596581513947, 1.1877836644105058, 1.4199248458359468, 1.6428970711225273, 1.8585223454127107, 2.0680514762530007, 2.272392580548362, 2.4722327487612916, 2.668108603104875, 2.860449941406537, 3.0496081311261634, 3.2358753493949384, 3.4194980649855085, 3.600686755154862, 3.779623078747565, 3.956465282052619, 4.1313523468430615, 4.304407224066535, 4.475739390368659, 4.645446894736367, 4.813618015494706, 4.980332615543653, 5.145663261062906, 5.309676152768644, 5.472431907125259, 5.6339862163436125, 5.794390409626061, 5.953691933326282, 6.111934764047811, 6.269159765905917, 6.425405001006944, 6.580706000501447, 6.7350960022285316, 6.888606159904933, 7.0412657279607815, 7.1931022254379835, 7.344141581810745, 7.494408267134058, 7.643925408553681, 7.792714894904175, 7.940797470867154, 8.088192821949951, 8.234919651367662, 8.380995749762576, 8.526438058569257, 8.671262727727173, 8.815485168352177, 8.95912010090097, 9.102181599296495, 9.244683131425482, 9.386637596370312, 9.528057358695154, 9.668954280069585, 9.809339748481062, 9.949224705259782, 10.088619670115255, 10.227534764362547, 10.365979732497571, 10.503963962264242, 10.641496503341973, 10.778586084768962, 10.915241131205587, 11.051469778131931, 11.187279886064657, 11.322679053870353, 11.457674631245437, 11.592273730426209, 11.726483237187043, 11.860309821179541, 11.99375994566078, 12.126839876654858, 12.259555691587906, 12.391913287433637, 12.523918388403283, 12.655576553211029, 12.786893181943665, 12.917873522560706, 13.048522677049368, 13.178845607256743, 13.308847140419926, 13.43853197441317, 13.567904682729852, 13.69696971921558, 13.82573142256768, 13.954194020615182, 14.082361634392397, 14.210238282018276, 14.337827882392881, 14.465134258721532, 14.592161141876467, 14.718912173605164, 14.845390909593956, 14.971600822394864, 15.097545304223154, 15.223227669632637, 15.348651158075233, 15.473818936350934, 15.598734100953935, 15.723399680320323], [0.0, 0.4019018290415329, 0.6997517273236981, 0.96786990575728, 1.2183385207781625, 1.4564513624208641, 1.6851593833087335, 1.9063314583190991, 2.121250571097592, 2.3308481991849788, 2.535829107937782, 2.736743723778671, 2.934032900766334, 3.128057045028716, 3.3191158497376274, 3.5074621238926214, 3.6933117591224676, 3.876851087311168, 4.05824242551648, 4.237628330714771, 4.415134916675888, 4.590874476251196, 4.764947580665309, 4.937444779137899, 5.108447988982987, 5.278031643091578, 5.446263645144316, 5.613206170919313, 5.778916345268371, 5.9434468177996145, 6.106846255389084, 6.269159765905917, 6.430429264664527, 6.590693792890799, 6.749989795747856, 6.908351366093638, 7.065810459051201, 7.222397081599259, 7.378139460686717, 7.533064192804331, 7.687196377481162, 7.840559736791689, 7.993176722644555, 8.145068613362968, 8.296255600849376, 8.446756869445256, 8.596590667444012, 8.74577437208608, 8.894324548756185, 9.04225700500973, 9.189586839976283, 9.336328489620046, 9.482495768279174, 9.628101906855406, 9.773159587982176, 9.917680978461744, 10.06167775922912, 10.205161153072126, 10.348141950312023, 10.490630532627224, 10.632636895183586, 10.7741706672178, 10.915241131205587, 11.055857240733198, 11.19602763717917, 11.335760665302793, 11.475064387826707, 11.613946599092728, 11.752414837862773, 11.890476399330163, 12.02813834640073, 12.165407520297926, 12.302290550541338, 12.4387938643439, 12.574923695469037, 12.71068609258575, 12.846086927156367, 12.98113190088889, 13.115826552783346, 13.250176265799128, 13.3841862731683, 13.517861664377802, 13.651207390841831, 13.784228271283983, 13.91692899684737, 14.04931413594948, 14.181388138897425, 14.313155342278009, 14.444619973136101, 14.57578615295379, 14.706657901441949, 14.837239140155022, 14.967533695939176, 15.097545304223154, 15.22727761216069, 15.356734181632634, 15.485918492116483, 15.614833943430494, 15.743483858359092, 15.871871485165856, 16.000000000000004, 16.127872509201904], [0.0, 0.4119183620556749, 0.7171915242391691, 0.9919919678228659, 1.2487029708352293, 1.4927502595668962, 1.7271583327468532, 1.953842642912831, 2.174118149300305, 2.3889395445111954, 2.5990291586527943, 2.8049511363347412, 3.0071573189487353, 3.2060170949652185, 3.4018376267595065, 3.5948780240481604, 3.785359559091415, 3.9734732076920922, 4.159385332309215, 4.343242042843166, 4.525172596176483, 4.705292083816749, 4.883703583508625, 5.060499901215055, 5.235764995861768, 5.409575155418439, 5.581999975917949, 5.753103182735074, 5.922943324434877, 6.091574362802986, 6.259046177631968, 6.425405001006944, 6.590693792890799, 6.754952567527452, 6.918218678396816, 7.080527068047507, 7.241910488014848, 7.40239969313653, 7.562023613857056, 7.7208095095271325, 7.878783105227245, 8.035968714253224, 8.19238934807893, 8.348066815343708, 8.503021811189466, 8.657273998085858, 8.810842079125493, 8.96374386463891, 9.115996332867182, 9.267615685334814, 9.418617397484482, 9.569016265065551, 9.718826446708645, 9.868061503067084, 10.016734432861487, 10.164857706125316, 10.312443294915601, 10.459502701723856, 10.606046985796738, 10.752086787553516, 10.897632351267925, 11.042693546164529, 11.187279886064657, 11.331400547703323, 11.47506438782671, 11.618279959169167, 11.761055525399245, 11.903399075115853, 12.045318334968231, 12.186820781966599, 12.327913655044425, 12.468603965927844, 12.60889850936287, 12.748803872746803, 12.888326445206127, 13.027472426159822, 13.166247833403705, 13.304658510748505, 13.442710135241834, 13.580408224001694, 13.717758140687128, 13.854765101629521, 13.99143418164635, 14.127770319557461, 14.263778323422557, 14.399462875517042, 14.534828537062292, 14.669879752725157, 14.80462085490044, 14.939056067789258, 15.073189511285065, 15.207025204678565, 15.340567070191785, 15.473818936350936, 15.606784541207162, 15.73946753541349, 15.871871485165856, 16.003999875015626, 16.135856110560436, 16.2674435210198, 16.39876536170158, 16.529824816364954], [0.0, 0.42187436223424096, 0.7345259273664232, 1.0159682532195478, 1.2788839196488955, 1.5288297918718772, 1.768903470262513, 2.0010667035365257, 2.2266662332814025, 2.4466798268648198, 2.661847272995918, 2.872746351568296, 3.079839824906999, 3.2835060095420476, 3.4840594919136816, 3.6817656443783977, 3.8768510873111675, 4.069511412369074, 4.2599170029648645, 4.448217500451579, 4.634545285829697, 4.819018232349922, 5.001741909129331, 5.182811365235979, 5.362312588869249, 5.540323711866703, 5.7169160123860765, 5.892154756034149, 6.066099906485328, 6.238806729772872, 6.410326311275864, 6.580706000501447, 6.749989795747856, 6.918218678396816, 7.085430904755806, 7.25166226192919, 7.4169462930516, 7.581314496300181, 7.7447965013635995, 7.90742022644666, 8.06921201840088, 8.230196778170518, 8.390398073413035, 8.549838239879064, 8.70853847290874, 8.866518910210432, 9.023798706927472, 9.180396103863206, 9.336328489620046, 9.491612457310723, 9.646263856416864, 9.800297840298699, 9.953728909798663, 10.106570953328877, 10.25883728378693, 10.41054067260498, 10.561693381202737, 10.712307190085074, 10.862393425798848, 11.011962985940546, 11.161026362386337, 11.30959366289835, 11.457674631245437, 11.605278665962809, 11.752414837862773, 11.899091906397887, 12.045318334968231, 12.191102305255855, 12.336451730661867, 12.48137426891461, 12.625877333911404, 12.769968106850673, 12.91365354670634, 13.056940400092035, 13.19983521055839, 13.342344327363346, 13.484473913751868, 13.626229954778644, 13.767618264704609, 13.908644493995617, 14.049314135949482, 14.189632532975471, 14.329604882548582, 14.469236242859136, 14.608531538176862, 14.747495563947005, 14.886132991634922, 15.024448373334339, 15.162446146153346, 15.300130636391314, 15.437506063518859, 15.574576543972286, 15.711346094773097, 15.84781863698236, 15.983997998999316, 16.119887919712678, 16.255492051512764, 16.390813963171986, 16.525857142600717, 16.66062499948518, 16.795120867813488, 16.92934800829577], [0.0, 0.4317719603808523, 0.7517586466500455, 1.0398038934012055, 1.3088878266078583, 1.5646976811514668, 1.8104037302358449, 2.048013747180699, 2.2789060694898216, 2.5040814039397565, 2.724296895429098, 2.940143879150642, 3.152095974300438, 3.3605403730959673, 3.5657990424927277, 3.7681435807504204, 3.9678059249866404, 4.1649862556360695, 4.359858953478208, 4.5525771706032065, 4.743276393803367, 4.93207726175477, 5.119087820332485, 5.304405348551593, 5.488117851981384, 5.670305295511152, 5.851040629556123, 6.0303906509200536, 6.2084167300856485, 6.385175429683061, 6.560719033605906, 6.7350960022285316, 6.908351366093638, 7.080527068047507, 7.25166226192919, 7.421793574444621, 7.59095533568421, 7.759179782804117, 7.926497240635394, 8.092936282372097, 8.258523872989459, 8.423285497633014, 8.587245276881243, 8.75042607050402, 8.912849571105546, 9.074536388845141, 9.235506128265127, 9.395777458116497, 9.555368174955818, 9.714295261186988, 9.87257493813646, 10.030222714677581, 10.187253431857185, 10.343681303923546, 10.499519956108267, 10.654782459474186, 10.809481363106286, 10.963628723891974, 11.117236134110323, 11.270314747026424, 11.42287530066645, 11.574928139930822, 11.726483237187043, 11.87755021146944, 12.02813834640073, 12.178256606939064, 12.327913655044423, 12.477117864349378, 12.625877333911404, 12.77419990111688, 12.922093153800638, 13.069564441639258, 13.216620886871217, 13.3632693943925, 13.509516661272047, 13.655369185727785, 13.800833275600633, 13.945915056360697, 14.090620478677339, 14.234955325582039, 14.378925219250926, 14.522535627431575, 14.665791869536989, 14.808699122427742, 14.951262425901893, 15.093486687910673, 15.23537668951673, 15.3769370896105, 15.518172429399105, 15.659087136681265, 15.79968552992063, 15.93997182212926, 16.079950124572026, 16.219624450302053, 16.358998717536686, 16.49807675288274, 16.63686229441929, 16.775358994645757, 16.913570423302403, 17.05150007007013, 17.189151347155786, 17.326527591769036], [0.0, 0.44161315369070003, 0.7688931594088335, 1.0635036980626, 1.3387207460757933, 1.60036116503796, 1.8516674868318153, 2.0946932470941557, 2.3308481991849788, 2.561155858561657, 2.7863906274020755, 3.0071573189487353, 3.2239403473971104, 3.43713573007101, 3.647072772380809, 3.854029263008983, 4.05824242551648, 4.259917002964865, 4.459231350720038, 4.6563421116021235, 4.851387860495835, 5.044491985742915, 5.235764995861768, 5.425306387106392, 5.613206170919313, 5.799546134795289, 5.9844008918771046, 6.167838761439447, 6.349922512756142, 6.530709997665136, 6.710254691744434, 6.888606159904933, 7.065810459051201, 7.241910488014848, 7.4169462930516, 7.59095533568421, 7.7639727284741324, 7.936031443345212, 8.107162496309387, 8.277395111817281, 8.446756869445256, 8.615273835210852, 8.782970679462556, 8.949870783003188, 9.115996332867182, 9.281368408972387, 9.44600706269906, 9.609931388307038, 9.773159587982178, 9.935709031201032, 10.097596309015797, 10.258837283786931, 10.419447134826884, 10.579440400363204, 10.73883101618156, 10.897632351267923, 11.055857240733198, 11.213518016272259, 11.37062653438203, 11.527194202539194, 11.683232003517155, 11.838750518003216, 11.99375994566078, 12.148270124766704, 12.302290550541338, 12.455830392277285, 12.608898509362868, 12.76150346628728, 12.91365354670634, 13.06535676664062, 13.216620886871217, 13.367453424592743, 13.517861664377804, 13.667852668502722, 13.817433286679856, 13.966610165238238, 14.115389755790698, 14.263778323422557, 14.411781954434236, 14.559406563667373, 14.706657901441949, 14.853541560129568, 15.000062980386334, 15.146227457066784, 15.29204014483894, 15.437506063518857, 15.582630103141899, 15.727417028786595, 15.871871485165856, 16.015998000999318, 16.159800993179527, 16.30328477074392, 16.44645353866367, 16.589311401459696, 16.731862366655594, 16.874110348076393, 17.016059169001604, 17.157712565180493, 17.299074187716894, 17.4401476058305, 17.580936309501134, 17.721443712002053], [0.0, 0.45139981759995357, 0.7859327309668146, 1.08707218367541, 1.3683883633120433, 1.6358270399213373, 1.892702603684352, 2.1411140989890054, 2.3825025209783215, 2.617914067409109, 2.8481403021171032, 3.073799441713529, 3.295386635578907, 3.5133066772440453, 3.727896169912304, 3.9394390583882086, 4.148177823384227, 4.354321745307597, 4.558053132087695, 4.759532097932718, 4.9589002887088744, 5.156283827187851, 5.351795670886049, 5.5455375210108055, 5.737601383763473, 5.928070859145336, 6.117022213813676, 6.304525281078199, 6.49064422125324, 6.675438168241132, 6.858961782701217, 7.0412657279607815, 7.222397081599259, 7.40239969313653, 7.581314496300181, 7.759179782804117, 7.936031443345212, 8.111903180543704, 8.286826697762622, 8.460831867100596, 8.633946879329647, 8.806198378120747, 8.977611580546156, 9.148210385554625, 9.318017471871217, 9.48705438656941, 9.655341625391499, 9.822898705748443, 9.989744233207826, 10.155895962174116, 10.321370851376622, 10.486185114704263, 10.6503542678608, 10.813893171257908, 10.976816069514562, 11.139136627889098, 11.300867965933483, 11.462022688627375, 11.62261291522153, 11.78265030599566, 11.942146087114264, 12.101111073745056, 12.259555691587904, 12.417489996947385, 12.574923695469035, 12.731866159647705, 12.888326445206124, 13.044313306432578, 13.199835210558389, 13.354900351248517, 13.509516661272045, 13.663691824413407, 13.817433286679856, 13.970748266856017, 14.123643766451886, 14.276126579086919, 14.428203299349224, 14.579880331165747, 14.731163895716442, 14.882060038922754, 15.032574638538478, 15.182713410868711, 15.332481917140862, 15.481885569549638, 15.630929636996527, 15.77961925054258, 15.927959408592065, 16.07595498182322, 16.22361071788123, 16.37093124584745, 16.51792108049793, 16.66458462636342, 16.81092618160217, 16.956949941696077, 17.102660002980155, 17.24806036601436, 17.393154938806564, 17.537947539894596, 17.682441901295018, 17.82664167132561, 17.97055041730823, 18.114171628158257], [0.0, 0.4611337162929197, 0.8028804329472727, 1.1105135987918326, 1.3978960263233686, 1.671101699026141, 1.9335164779524718, 2.1872846708790252, 2.4338783462904443, 2.67436626195039, 2.9095570508246347, 3.140082260628293, 3.366447718047725, 3.5890669455034416, 3.808283804645426, 4.024388363209258, 4.237628330714771, 4.448217500451579, 4.6563421116021235, 4.862165731046535, 5.0658330590751905, 5.267472938146923, 5.467200761572255, 5.665120423623763, 5.861325914506796, 6.0559026369569615, 6.248928502231041, 6.440474849510779, 6.630607222651165, 6.819386030706607, 7.006867113028375, 7.1931022254379835, 7.378139460686717, 7.562023613857056, 7.7447965013635995, 7.926497240635394, 8.107162496309387, 8.286826697762622, 8.465522232003346, 8.64327961528636, 8.820127646284071, 8.99609354320643, 9.171203066901787, 9.345480631671222, 9.51894940527945, 9.691631399436897, 9.86354755185209, 10.03471780080568, 10.205161153072124, 10.374895745908447, 10.543938903738733, 10.712307190085072, 10.880016455228878, 11.047081880028875, 11.213518016272257, 11.37933882389236, 11.544557705348643, 11.709187537432111, 11.873240700730715, 12.036729106964186, 12.199664224375878, 12.362057101349693, 12.523918388403281, 12.685258358693437, 12.846086927156366, 13.006413668393591, 13.166247833403704, 13.325598365250771, 13.484473913751867, 13.642882849258557, 13.800833275600631, 13.958333042254173, 14.115389755790696, 14.27201079065931, 14.428203299349224, 14.58397422197619, 14.739330295332751, 14.894278061438893, 15.048823875626896, 15.202973914191295, 15.356734181632632, 15.510110517521309, 15.663108603005966, 15.815733966988835, 15.967991991988985, 16.119887919712674, 16.2714268563488, 16.422613777605967, 16.573453533506665, 16.723950852952868, 16.87411034807639, 17.023936518386428, 17.173433754725885, 17.322606343047234, 17.471458468018056, 17.619994216465624, 17.768217580669326, 17.916132461509207, 18.063742671478323, 18.21105193756607, 18.358063904019343, 18.50478213498783], [0.0, 0.47081651205027064, 0.819739159548959, 1.1338319465572162, 1.4272487742024755, 1.706191166288504, 1.974116079517051, 2.233212847420887, 2.4849844486913355, 2.7305220826589465, 2.970651361806657, 3.206017094965219, 3.43713573007101, 3.6644294726076057, 3.8882494045647893, 4.10889168446383, 4.326609223180701, 4.54162030319478, 4.754115074302504, 4.964260537929424, 5.172204432754366, 5.378078306644965, 5.58199997591795, 5.784075516397551, 5.984400891877105, 6.183063298362186, 6.380142283074941, 6.575710683163321, 6.769835418759394, 6.962578167375096, 7.153995940865496, 7.344141581810745, 7.533064192804331, 7.7208095095271325, 7.90742022644666, 8.092936282372097, 8.277395111817281, 8.460831867100596, 8.64327961528636, 8.824769513403744, 9.00533096483405, 9.184991759309888, 9.363778198600878, 9.541715209654823, 9.718826446708643, 9.89513438367036, 10.070660397894418, 10.245424846321594, 10.419447134826884, 10.592745781509894, 10.765338474569585, 10.937242125325652, 11.108472916880618, 11.279046348857921, 11.448977278600342, 11.618279959169167, 11.786968074446087, 11.955054771606449, 12.122552691203373, 12.289473995076555, 12.455830392277287, 12.621633163181276, 12.786893181943665, 12.951620937434988, 13.115826552783348, 13.279519803635878, 13.442710135241834, 13.605406678449999, 13.76761826470461, 13.92935344011625, 14.090620478677339, 14.251427394685727, 14.411781954434236, 14.571691687219214, 14.731163895716444, 14.890205665768873, 15.0488238756269, 15.207025204678567, 15.364816141704186, 15.522202992686912, 15.67919188820862, 15.835788790457874, 15.991999499874964, 16.147829661456928, 16.30328477074392, 16.45837017950653, 16.613091101152406, 16.76745261586911, 16.92145967551896, 17.07511710830049, 17.22842962319016, 17.381401814176975, 17.53403816430191, 17.686343049513027, 17.838320742346742, 17.98997541544472, 18.141311144915463, 18.29233191354893, 18.443041613892163, 18.593444051193153, 18.743542946219982, 18.89334193796165], [0.0, 0.4804497735925725, 0.8365116420730186, 1.1570310048031527, 1.4564513624208644, 1.7411011265922482, 2.01450798596493, 2.2789060694898216, 2.535829107937782, 2.7863906274020755, 3.0314331330207964, 3.271614626900533, 3.5074621238926214, 3.7394064681238106, 3.967805924986641, 4.192962712629476, 4.415134916675888, 4.634545285829698, 4.851387860495835, 5.065833059075191, 5.278031643091578, 5.488117851981385, 5.6962119126721955, 5.902422071379746, 6.106846255389083, 6.309573444801933, 6.510684814436707, 6.710254691744433, 6.908351366093639, 7.1050377769647515, 7.3003721027184705, 7.494408267134058, 7.687196377481162, 7.878783105227245, 8.06921201840088, 8.258523872989459, 8.446756869445256, 8.633946879329647, 8.820127646284071, 9.00533096483405, 9.18958683997628, 9.372923630042306, 9.555368174955818, 9.736945911688805, 9.917680978461744, 10.097596309015797, 10.276713718102227, 10.455053979180205, 10.632636895183586, 10.809481363106286, 10.98560543306118, 11.16102636238634, 11.335760665302795, 11.509824158567985, 11.683232003517153, 11.855998744839987, 12.028138346400732, 12.19966422437588, 12.370589277953814, 12.540925917814665, 12.71068609258575, 12.879881313447793, 13.048522677049366, 13.216620886871219, 13.3841862731683, 13.551228811604874, 13.717758140687126, 13.88378357808791, 14.04931413594948, 14.2143585352423, 14.378925219250924, 14.543022366251794, 14.706657901441949, 14.869839508172827, 15.032574638538478, 15.194870523363548, 15.356734181632634, 15.518172429399105, 15.67919188820862, 15.839798993069516, 16.000000000000004, 16.159800993179527, 16.319207891729768, 16.47822645614867, 16.63686229441929, 16.795120867813484, 16.953007496409164, 17.11052736433837, 17.267685524782255, 17.424486904727956, 17.580936309501134, 17.737038427087292, 17.8927978322538, 18.048218990483935, 18.203306261733424, 18.358063904019346, 18.512496076850447, 18.66660684450759, 18.820400179182265, 18.973879963980714, 19.127049995800743, 19.27991398808782], [0.0, 0.49003498354948044, 0.8532004619276143, 1.1801143440349768, 1.485508285471196, 1.7758369528364875, 2.05469841390697, 2.324371369608072, 2.5864201493960186, 2.8419804947588623, 3.091911719227754, 3.3368849523758564, 3.5774377232607315, 3.8140094715619632, 4.046965610243381, 4.276614386854473, 4.5032190359543, 4.727006750193185, 4.948175441177851, 5.166898927240337, 5.383330977671218, 5.5976085100498505, 5.809854149890324, 6.020178302973767, 6.228680850282867, 6.435452547116266, 6.64057618777004, 6.844127582564527, 7.046176383274838, 7.24678678505508, 7.446018126952942, 7.643925408553681, 7.840559736791689, 8.035968714253224, 8.230196778170518, 8.423285497633014, 8.615273835210852, 8.806198378120747, 8.99609354320643, 9.184991759309888, 9.372923630042306, 9.559918079497924, 9.746002483070152, 9.931202785211113, 10.115543605710691, 10.299048335849495, 10.481739225593838, 10.663637462843642, 10.844763245611064, 11.025135847894369, 11.204773679915085, 11.383694343303691, 11.561914681748075, 11.739450827557786, 11.916318244544179, 12.09253176757068, 12.268105639087514, 12.443053542930507, 12.617388635633217, 12.791123575474963, 12.96427054946407, 13.136841298434996, 13.308847140419925, 13.480298992439327, 13.651207390841831, 13.821582510311124, 13.991434181646348, 14.160771908412519, 14.32960488254858, 14.497941999012653, 14.665791869536989, 14.83316283555867, 15.000062980386334, 15.166500140658064, 15.332481917140864, 15.498015684917897, 15.663108603005966, 15.82776762344207, 15.991999499874963, 16.155810795694574, 16.319207891729768, 16.482196993542363, 16.64478413834344, 16.806975201555723, 16.96877590304429, 17.130191813036067, 17.29122835774714, 17.45189082473555, 17.6121843679959, 17.772114012811148, 17.931684660375577, 18.090901092202312, 18.24976797432759, 18.408289861323276, 18.56647120012837, 18.72431633370949, 18.881829504559633, 19.03901485804407, 19.195876445601467, 19.35241822780796, 19.508644077311327, 19.664557781642113], [0.0, 0.49957354516528457, 0.8698080623029605, 1.2030853435802271, 1.514423797194705, 1.8104037302358449, 2.0946932470941557, 2.3696154037511543, 2.6367649794338117, 2.897299822909306, 3.1520959743004386, 3.4018376267595065, 3.647072772380809, 3.8882494045647893, 4.125740049061481, 4.359858953478208, 4.590874476251196, 4.819018232349922, 5.044491985742914, 5.2674729381469225, 5.488117851981384, 5.706566309934905, 5.922943324434876, 6.137361450317868, 6.349922512756141, 6.560719033605906, 6.769835418759393, 6.977348954189568, 7.183330647447702, 7.3878459432505945, 7.590955335684211, 7.792714894904175, 7.993176722644555, 8.19238934807893, 8.390398073413035, 8.587245276881243, 8.782970679462556, 8.977611580546156, 9.171203066901787, 9.363778198600878, 9.555368174955818, 9.746002483070152, 9.935709031201032, 10.12451426881097, 10.3124432949156, 10.499519956108267, 10.685766935452275, 10.871205833271343, 11.055857240733198, 11.239740807005687, 11.422875300666451, 11.605278665962809, 11.786968074446085, 11.967959972442246, 12.148270124766702, 12.327913655044423, 12.50690508295582, 12.685258358693437, 12.862986894883583, 13.040103596199774, 13.216620886871219, 13.392550736268449, 13.567904682729852, 13.742693855776388, 13.91692899684737, 14.090620478677339, 14.263778323422557, 14.436412219635528, 14.608531538176864, 14.780145347145599, 14.951262425901893, 15.121891278249429, 15.292040144838941, 15.461717014849173, 15.630929636996528, 15.79968552992063, 15.967991991988987, 16.135856110560432, 16.30328477074392, 16.47028466368618, 16.63686229441929, 16.80302398929674, 16.96877590304429, 17.134124025450138, 17.29907418771689, 17.463632068496295, 17.627803199626072, 17.791592971586905, 17.95500663869623, 18.118049324054446, 18.2807260242579, 18.44304161389216, 18.605000849818154, 18.76660837526277, 18.92786872372496, 19.08878632270745, 19.249365497283637, 19.409610473508586, 19.569525381682467, 19.729114259474272, 19.888381054913125, 20.04732962925408], [0.0, 0.5090667883351854, 0.8863367586810889, 1.2259472061253547, 1.5432019290797656, 1.8448062781953012, 2.134498061727474, 2.41464447997958, 2.686870617280111, 2.9523563246419755, 3.211994289310292, 3.4664817059504123, 3.7163769799826754, 3.9621366178889916, 4.204140224412201, 4.442708018710724, 4.6781134587540105, 4.910592560819913, 5.140350922935894, 5.367569114128692, 5.5924068757260175, 5.815006442863585, 6.035495203541681, 6.253987851441982, 6.470588146689334, 6.685390369304459, 6.898480529118923, 7.1099373807473825, 7.31983328107587, 7.528234918447107, 7.735203936497659, 7.940797470867154, 8.145068613362968, 8.348066815343708, 8.549838239879064, 8.75042607050402, 8.949870783003188, 9.148210385554625, 9.345480631671222, 9.541715209654823, 9.736945911688805, 9.931202785211113, 10.12451426881097, 10.316907314561927, 10.508407498428532, 10.699039120153643, 10.88882529383987, 11.077788030275277, 11.265948311915247, 11.453326161314749, 11.63994070370496, 11.825810224322241, 12.010952221023649, 12.195383452659646, 12.379119983619606, 12.562177224918118, 12.74456997214863, 12.926312440594934, 13.107418297759363, 13.287900693538996, 13.467772288256867, 13.647045278733794, 13.825731422567678, 14.003842060770355, 14.181388138897425, 14.358380226793326, 14.53482853706229, 14.710742942365421, 14.886132991634922, 15.06100792528814, 15.235376689516729, 15.409247949719548, 15.582630103141899, 15.75553129077844, 15.927959408592066, 16.0999221180968, 16.271426856348803, 16.442480845385813, 16.613091101152403, 16.78326444194511, 16.953007496409164, 17.122326711115793, 17.29122835774714, 17.45971853991351, 17.627803199626072, 17.795488123446248, 17.96277894833158, 18.129681167196402, 18.296200134204348, 18.462341069808517, 18.628109065554046, 18.793509088656762, 18.95854598637077, 19.12322449015677, 19.28754921966241, 19.4515246865249, 19.615155298005675, 19.778445360466236, 19.94139908269358, 20.10402057908329, 20.266313872687675, 20.42828289813604], [0.0, 0.5185159750530859, 0.902788748321006, 1.248702970835229, 1.5718465067765095, 1.8790491700524399, 2.1741181493003046, 2.459464584279238, 2.7367437237786705, 3.007157318948735, 3.2716146269005324, 3.530825783474764, 3.7853595590914146, 4.035680933806166, 4.282176558502317, 4.525172596176483, 4.764947580665308, 5.001741909129331, 5.235764995861767, 5.467200761572254, 5.696211912672195, 5.922943324434876, 6.147524749408869, 6.370073010194957, 6.590693792890798, 6.809483127522302, 7.026528620416771, 7.241910488014847, 7.455702430275301, 7.667972373395332, 7.878783105227244, 8.088192821949951, 8.296255600849376, 8.503021811189466, 8.70853847290874, 8.912849571105546, 9.115996332867182, 9.318017471871217, 9.51894940527945, 9.718826446708643, 9.917680978461744, 10.115543605710691, 10.3124432949156, 10.508407498428532, 10.70346226694951, 10.897632351267923, 11.090941294525315, 11.283411516069194, 11.475064387826707, 11.665920304007122, 11.855998744839987, 12.045318334968231, 12.233896897040319, 12.421751500980843, 12.608898509362868, 12.795353619256874, 12.98113190088889, 13.166247833403705, 13.350715337996851, 13.53454780865093, 13.717758140687128, 13.900358757320992, 14.082361634392395, 14.263778323422557, 14.4446199731361, 14.624897349572604, 14.804620854900437, 14.983800545034883, 15.162446146153345, 15.340567070191781, 15.518172429399105, 15.695271050019416, 15.871871485165855, 16.04798202694445, 16.22361071788123, 16.398765361701578, 16.573453533506665, 16.747682589388123, 16.921459675518957, 17.094791736755436, 17.267685524782255, 17.440147605830497, 17.612184367995898, 17.783802028182645, 17.955006638696226, 18.125804093506954, 18.296200134204348, 18.46620035566102, 18.63581021142341, 18.80503501884555, 18.973879963980714, 19.14235010624511, 19.310450382866517, 19.478185613129973, 19.645560502432023, 19.8125796461539, 19.97924753336367, 20.145568550356565, 20.31154698404218, 20.477187025186613, 20.642492771517183, 20.807468230696934], [0.0, 0.5279223043403284, 0.9191661188401216, 1.2713555252226452, 1.60036116503796, 1.913136750938686, 2.213558537264427, 2.5040814039397565, 2.7863906274020755, 3.061709759609174, 3.3309645523843803, 3.5948780240481604, 3.854029263008983, 4.1088916844638295, 4.359858953478209, 4.607263149928244, 4.851387860495835, 5.092477843354414, 5.330746311754014, 5.566380522885388, 5.799546134795288, 6.030390650920054, 6.2590461776319675, 6.485631656795065, 6.710254691744433, 6.933013054573902, 7.153995940865494, 7.373285022255626, 7.590955335684211, 7.807076039588549, 8.021711060847016, 8.234919651367662, 8.446756869445256, 8.657273998085858, 8.866518910210432, 9.074536388845141, 9.281368408972387, 9.48705438656941, 9.691631399436897, 9.89513438367036, 10.097596309015797, 10.299048335849495, 10.499519956108267, 10.699039120153643, 10.897632351267923, 11.095324849241274, 11.292140584308237, 11.48810238252272, 11.683232003517153, 11.87755021146944, 12.071076839997385, 12.26383085161108, 12.455830392277285, 12.647092841583824, 12.83763485893502, 13.02747242615982, 13.216620886871219, 13.40509498287824, 13.592908887918973, 13.780076238954475, 13.966610165238238, 14.152523315353712, 14.33782788239288, 14.522535627431576, 14.706657901441949, 14.890205665768871, 15.073189511285062, 15.255619676328827, 15.437506063518857, 15.618858255531789, 15.799685529920628, 15.979996873045199, 16.159800993179527, 16.33910633285563, 16.51792108049793, 16.696253181398163, 16.874110348076393, 17.05150007007013, 17.228429623190156, 17.404906078278454, 17.580936309501134, 17.756527002206397, 17.931684660375577, 18.106415613692892, 18.2807260242579, 18.45462189296264, 18.628109065554046, 18.801193238400568, 18.973879963980714, 19.146174656109913, 19.318082594920952, 19.489608931612235, 19.660758692977122, 19.831536785726676, 20.0019480006174, 20.171997016394734, 20.341688403562326, 20.511026627986613, 20.68001605434544, 20.848660949429032, 21.016965485301043, 21.18493374232699], [0.0, 0.5372869167152506, 0.9354708559961983, 1.293907615912018, 1.628749361269196, 1.9470731539765267, 2.2528240077707045, 2.548500348754844, 2.8358173478422017, 3.11602026111201, 3.390051261946053, 3.65864619401098, 3.9223944179436376, 4.181777746672597, 4.437196828337797, 4.688989633453605, 4.937444779137899, 5.182811365235979, 5.425306387106392, 5.665120423623763, 5.902422071379746, 6.137361450317869, 6.370073010194958, 6.600677802739406, 6.829285340020813, 7.055995128474885, 7.280897945890052, 7.50407691264473, 7.725608396730489, 7.945562783359766, 8.164005133385448, 8.380995749762576, 8.596590667444012, 8.810842079125493, 9.023798706927472, 9.235506128265127, 9.44600706269906, 9.655341625391499, 9.86354755185209, 10.070660397894418, 10.276713718102227, 10.481739225593838, 10.685766935452275, 10.88882529383987, 11.090941294525315, 11.292140584308237, 11.492447558622027, 11.691885448423252, 11.890476399330165, 12.088241543848499, 12.285201067417038, 12.481374268914612, 12.676779616192357, 12.871434797127979, 13.06535676664062, 13.258561790054792, 13.451065483157988, 13.64288284925856, 13.83402831351713, 14.024515754795607, 14.214358535242301, 14.403569527809056, 14.592161141876465, 14.780145347145602, 14.967533695939176, 15.154337344041181, 15.340567070191783, 15.526233294343264, 15.711346094773095, 15.895915224141355, 16.079950124572026, 16.26345994183054, 16.44645353866367, 16.628939507362293, 16.81092618160217, 16.992421647613526, 17.173433754725888, 17.35397012533081, 17.534038164301908, 17.713645067908136, 17.8927978322538, 18.071503261275964, 18.24976797432759, 18.427598413372756, 18.605000849818154, 18.781981391003356, 18.95854598637077, 19.134700433334555, 19.310450382866517, 19.48580134481569, 19.660758692977122, 19.835327669924364, 20.009513391619144, 20.183320851810798, 20.356754926237237, 20.529820376638376, 20.70252185459229, 20.87486390518371, 21.04685097051384, 21.21848739305987, 21.3897774188921, 21.56072520075609], [0.0, 0.5466108982553799, 0.9517048507600429, 1.3163618584220589, 1.6570143878416181, 1.9808623150004865, 2.291919114701712, 2.5927265702903974, 2.885029617450606, 3.1700951222139695, 3.4488816082714764, 3.72213768898982, 3.9904629526654594, 4.2543475735227885, 4.514199152478268, 4.77036152512643, 5.023128317195254, 5.272752951364427, 5.519456188691334, 5.7634319153224745, 6.004851653644753, 6.243868128756482, 6.4806181236316425, 6.715224790708779, 6.947799542510461, 7.178443612289371, 7.407249353175525, 7.634301328003594, 7.859677230041685, 8.083448665954686, 8.305681825649945, 8.526438058569257, 8.74577437208608, 8.96374386463891, 9.180396103863206, 9.395777458116497, 9.609931388307038, 9.822898705748443, 10.03471780080568, 10.245424846321594, 10.455053979180205, 10.663637462843642, 10.871205833271343, 11.077788030275277, 11.283411516069194, 11.48810238252272, 11.691885448423252, 11.894784347873246, 12.096821610802072, 12.29801873644521, 12.498396260535952, 12.697973816862438, 12.89677019376361, 13.09480338606945, 13.292090642931754, 13.48864851194058, 13.68449287987702, 13.879639010414165, 14.07410157904431, 14.267894705480662, 14.461031983755879, 14.653526510216718, 14.845390909593954, 15.036637359308722, 15.227277612160687, 15.417323017529332, 15.60678454120716, 15.795672783972453, 15.983997998999314, 16.17177010819375, 16.358998717536682, 16.54569313150753, 16.731862366655594, 16.917515164380838, 17.102660002980155, 17.287305109010763, 17.47145846801806, 17.655127834671227, 17.83832074234674, 18.021044512196315, 18.203306261733424, 18.385112912969426, 18.56647120012837, 18.747387676967023, 18.927868723724956, 19.10792055372743, 19.28754921966241, 19.466760619551355, 19.645560502432023, 19.823954473770396, 20.0019480006174, 20.179546416525273, 20.356754926237237, 20.533578610163264, 20.71002242865395, 20.8860912260836, 21.061789734752946, 21.23712257862131, 21.412094276877333, 21.586709247356776, 21.76097180981549, 21.934886189065047], [0.0, 0.5558952842972614, 0.9678699057572799, 1.3387207460757933, 1.6851593833087335, 2.01450798596493, 2.3308481991849788, 2.6367649794338113, 2.934032900766334, 3.2239403473971104, 3.5074621238926214, 3.785359559091415, 4.05824242551648, 4.326609223180701, 4.590874476251196, 4.851387860495835, 5.108447988982987, 5.3623125888692496, 5.613206170919313, 5.861325914506797, 6.106846255389083, 6.349922512756142, 6.590693792890799, 6.829285340020813, 7.065810459051201, 7.3003721027184705, 7.53306419280433, 7.763972728474132, 7.993176722644555, 8.220748998245885, 8.446756869445256, 8.671262727727173, 8.894324548756185, 9.115996332867182, 9.336328489620046, 9.555368174955818, 9.773159587982178, 9.989744233207826, 10.205161153072124, 10.419447134826884, 10.632636895183586, 10.844763245611064, 11.055857240733198, 11.265948311915247, 11.475064387826707, 11.683232003517153, 11.890476399330165, 12.096821610802072, 12.302290550541338, 12.506905082955818, 12.71068609258575, 12.913653546706342, 13.115826552783346, 13.317223411295519, 13.517861664377802, 13.717758140687126, 13.916928996847371, 14.115389755790698, 14.313155342278009, 14.510240115851001, 14.706657901441949, 14.90242201784385, 15.097545304223154, 15.292040144838941, 15.485918492116483, 15.679191888208619, 15.871871485165855, 16.063968063824564, 16.255492051512764, 16.44645353866367, 16.63686229441929, 16.826727781299038, 17.016059169001604, 17.204865347402826, 17.393154938806564, 17.580936309501134, 17.768217580669326, 17.955006638696226, 18.14131114491546, 18.32713854483119, 18.512496076850447, 18.69739078055749, 18.88182950455963, 19.06581891393159, 19.249365497283637, 19.432475573476637, 19.615155298005675, 19.797410669072264, 19.97924753336367, 20.160671591556763, 20.341688403562326, 20.52230339352494, 20.70252185459229, 20.88234895346697, 21.061789734752946, 21.24084912510799, 21.419531937212696, 21.597842873566027, 21.775786530116694, 21.953367399739015, 22.130589875561473, 22.30745825415561], [0.0, 0.565141062813108, 0.983967741147443, 1.3609866581322931, 1.7131873426422428, 2.048013747180699, 2.3696154037511548, 2.680620262410361, 2.9828324123379892, 3.277561666451862, 3.5657990424927277, 3.8483185318958815, 4.125740049061481, 4.398570385169542, 4.667230958848688, 4.93207726175477, 5.193412873557547, 5.451499807991096, 5.706566309934904, 5.958812838295384, 6.2084167300856485, 6.455535887800239, 6.700311731369745, 6.942871588112794, 7.1833306474477014, 7.421793574444622, 7.6583558530139895, 7.893104912679097, 8.126121080517672, 8.35747839066776, 8.587245276881243, 8.815485168352177, 9.04225700500973, 9.267615685334814, 9.491612457310723, 9.714295261186988, 9.935709031201032, 10.155895962174116, 10.374895745908447, 10.592745781509894, 10.809481363106286, 11.025135847894369, 11.239740807005687, 11.453326161314749, 11.665920304007122, 11.87755021146944, 12.088241543848499, 12.29801873644521, 12.506905082955818, 12.714922811442054, 12.92209315380064, 13.128436409407113, 13.333972003526997, 13.538718541016829, 13.742693855776386, 13.945915056360697, 14.148398568114336, 14.350160172150453, 14.551215041462008, 14.75157777442191, 14.951262425901895, 15.150282536216196, 15.348651158075231, 15.546380881715944, 15.743483858359092, 15.939971822129262, 16.135856110560432, 16.33114768379834, 16.525857142600717, 16.719994745227194, 16.913570423302403, 17.106593796728557, 17.299074187716894, 17.49102063400171, 17.682441901295018, 17.87334649503516, 18.063742671478323, 18.25363844817776, 18.443041613892163, 18.631959737961033, 18.820400179182265, 19.008370094224105, 19.195876445601467, 19.382926009244144, 19.569525381682464, 19.755680986874044, 19.94139908269358, 20.126685767106054, 20.311546984042185, 20.495988528993813, 20.68001605434544, 20.86363507445727, 21.04685097051384, 21.229668995151535, 21.412094276877333, 21.59413182429032, 21.775786530116694, 21.95706317506847, 22.137966431535236, 22.318500867117837, 22.498670948012276, 22.678481042251665], [0.0, 0.5743491774985175, 1.0, 1.3831618672225918, 1.7411011265922485, 2.081383018504683, 2.4082246852806923, 2.724296895429098, 3.0314331330207964, 3.3309645523843803, 3.623898318388478, 3.9110210334824673, 4.192962712629476, 4.47023840440155, 4.7432763938033675, 5.012437964687017, 5.278031643091578, 5.540323711866703, 5.799546134795289, 6.0559026369569615, 6.3095734448019325, 6.560719033605906, 6.809483127522302, 7.055995128474885, 7.30037210271847, 7.542720420681454, 7.783137122039472, 8.021711060847016, 8.25852387298946, 8.49365079887861, 8.727161387290323, 8.95912010090097, 9.189586839976283, 9.418617397484482, 9.646263856416864, 9.87257493813646, 10.097596309015797, 10.321370851376622, 10.543938903738733, 10.765338474569585, 10.98560543306118, 11.204773679915085, 11.422875300666451, 11.63994070370496, 11.855998744839987, 12.071076839997385, 12.285201067417038, 12.498396260535952, 12.71068609258575, 12.92209315380064, 13.132639022018838, 13.342344327363348, 13.551228811604874, 13.759311382737815, 13.966610165238238, 14.173142546419077, 14.378925219250927, 14.583974221976193, 14.788304974808698, 14.991932313979646, 15.194870523363548, 15.397133363893477, 15.598734100953934, 15.799685529920632, 16.000000000000004, 16.199689436506365, 16.398765361701578, 16.597238914310296, 16.795120867813488, 16.992421647613526, 17.189151347155782, 17.385319743084153, 17.580936309501134, 17.776010231397173, 17.97055041730823, 18.164565511255844, 18.358063904019346, 18.551053743785832, 18.74354294621998, 18.935539203992178, 19.127049995800743, 19.318082594920952, 19.508644077311327, 19.69874132930513, 19.888381054913122, 20.077569782761554, 20.266313872687675, 20.45461952201354, 20.642492771517183, 20.82993951111918, 21.016965485301043, 21.203576298271095, 21.3897774188921, 21.57557418538416, 21.76097180981549, 21.94597538239268, 22.130589875561473, 22.314820147928312, 22.498670948012276, 22.682146917836317, 22.86525259636632, 23.04799242280586], [0.0, 0.5835205306012528, 1.0159682532195478, 1.4052485461620245, 1.7689034702625133, 2.114619069591032, 2.4466798268648198, 2.7677991581005377, 3.0798398249069994, 3.3841542378221914, 3.681765644378398, 3.9734732076920922, 4.2599170029648645, 4.54162030319478, 4.819018232349922, 5.092477843354414, 5.3623125888692496, 5.628793003816055, 5.89215475603415, 6.152604823736817, 6.410326311275864, 6.665482256436832, 6.9182186783968165, 7.168667045402267, 7.4169462930516, 7.663164490323149, 7.90742022644666, 8.149803774320668, 8.390398073413035, 8.629279565593517, 8.866518910210432, 9.102181599296495, 9.336328489620046, 9.569016265065551, 9.800297840298699, 10.030222714677581, 10.258837283786931, 10.486185114704263, 10.712307190085072, 10.937242125325652, 11.16102636238634, 11.383694343303691, 11.605278665962809, 11.825810224322241, 12.045318334968231, 12.26383085161108, 12.481374268914612, 12.697973816862438, 12.913653546706342, 13.128436409407113, 13.342344327363348, 13.55539826012508, 13.76761826470461, 13.979023551023978, 14.189632532975471, 14.399462875517042, 14.608531538176866, 14.816854815300065, 15.02444837333434, 15.231327285419594, 15.437506063518859, 15.642998688303274, 15.84781863698236, 16.051978909251627, 16.255492051512768, 16.45837017950653, 16.660624999485176, 16.862267828039332, 17.063309610683643, 17.263760939295942, 17.463632068496295, 17.662932931044523, 17.861673152327988, 18.059862064005394, 18.257508716866457, 18.454621892962642, 18.651210117059364, 18.84728166745604, 19.042844586216688, 19.2379066888502, 19.432475573476637, 19.626558629512786, 19.82016304590786, 20.013295818957843, 20.20596375972483, 20.39817350108583, 20.589931504433586, 20.781244066050554, 20.972117323175453, 21.16255725978059, 21.352569712076825, 21.542160373761888, 21.73133480102673, 21.92009841733351, 22.108456517978063, 22.296414274448686, 22.483976738592396, 22.671148846599095, 22.857935422813416, 23.04434118338331, 23.23037073975402, 23.41602860201544], [0.0, 0.5926559855174482, 1.0318740040660683, 1.4272487742024753, 1.796596990980686, 2.1477250292995467, 2.4849844486913355, 2.8111311457511827, 3.128057045028716, 3.43713573007101, 3.7394064681238106, 4.035680933806167, 4.326609223180701, 4.612722801479739, 4.894463604865942, 5.172204432754366, 5.446263645144317, 5.716916012386077, 5.984400891877105, 6.248928502231042, 6.510684814436707, 6.769835418759394, 7.026528620416773, 7.280897945890052, 7.53306419280433, 7.783137122039472, 8.031216866314125, 8.27739511181728, 8.52175609649685, 8.764377458977831, 9.00533096483405, 9.244683131425482, 9.482495768279174, 9.718826446708645, 9.953728909798663, 10.187253431857185, 10.419447134826884, 10.6503542678608, 10.880016455228878, 11.108472916880618, 11.335760665302795, 11.561914681748075, 11.786968074446085, 12.010952221023649, 12.233896897040319, 12.455830392277285, 12.676779616192357, 12.89677019376361, 13.115826552783346, 13.333972003526997, 13.551228811604874, 13.76761826470461, 13.98316073384619, 14.197875729697502, 14.411781954434234, 14.624897349572606, 14.837239140155024, 15.0488238756269, 15.25966746770601, 15.469785225513656, 15.67919188820862, 15.887901655340015, 16.095928215113258, 16.303284770743925, 16.509984065057097, 16.716038403474613, 16.921459675518957, 17.12625937495053, 17.330448618644283, 17.534038164301908, 17.737038427087292, 17.939459495265115, 18.141311144915463, 18.3426028537912, 18.543343814379, 18.74354294621998, 18.9432089075412, 19.142350106245114, 19.340974710300323, 19.53909065757342, 19.73670566513879, 19.933827238100108, 20.130462677955027, 20.32661909053183, 20.52230339352494, 20.717522323654066, 20.91228244346994, 21.106590147828083, 21.30045167005031, 21.49387308779255, 21.686860328635948, 21.87941917541738, 22.071555271314164, 22.263274124696853, 22.454581113763147, 22.645481490964904, 22.83598038723961, 23.026082816056963, 23.215793677290353, 23.405117760922593, 23.59405975059458, 23.782624227005087], [0.0, 0.6017563691784628, 1.0477186923106825, 1.4491645427804556, 1.8241841955338864, 2.180703894345387, 2.5231420180525914, 2.854296780745026, 3.1760891579558237, 3.4899138249574, 3.796826007208857, 4.097649842799824, 4.393045410183606, 4.683552335376582, 4.969619340583793, 5.251624949650299, 5.52989241107431, 5.804700714374848, 6.076292892343193, 6.3448823915533605, 6.610658038626088, 6.873787966507384, 7.134422757679323, 7.392697988956252, 7.6487363128415815, 7.902649175621454, 8.154538247577923, 8.404496622764773, 8.65260983262507, 8.898956707944679, 9.143610116276097, 9.386637596370312, 9.628101906855406, 9.868061503067084, 10.106570953328877, 10.343681303923546, 10.579440400363204, 10.813893171257908, 11.047081880028875, 11.279046348857921, 11.509824158567985, 11.739450827557786, 11.967959972442246, 12.195383452659646, 12.421751500980843, 12.647092841583824, 12.871434797127979, 13.09480338606945, 13.317223411295519, 13.538718541016829, 13.759311382737815, 13.979023551023978, 14.197875729697502, 14.41588772901755, 14.633078538336491, 14.84946637466709, 15.065068727546672, 15.279902400541598, 15.493983549698127, 15.707327719213017, 15.91994987456859, 16.13186443335165, 16.343085293953504, 16.553625862328456, 16.763499076970923, 16.972717432255624, 17.181293000271694, 17.389237451269153, 17.5965620728254, 17.803277787829373, 18.00939517137246, 18.214924466627217, 18.41987559978792, 18.624258194140754, 18.828081583325368, 19.031354823844694, 19.23408670687509, 19.43628576942448, 19.63796030488271, 19.839118373004343, 20.039767809361397, 20.239916234300335, 20.43957106143516, 20.63873950570596, 20.837428591030125, 21.035645157571405, 21.233395868650174, 21.43068721731658, 21.627525532606697, 21.8239169855004, 22.019867594598356, 22.21538323153437, 22.41046962613819, 22.605132371362807, 22.79937692798951, 22.993208629122886, 23.186632684487293, 23.379654184535518, 23.57227810437976, 23.764509307554242, 23.95635254961836, 24.14781248160867], [0.0, 0.6108224742488859, 1.0635036980625998, 1.470997760810397, 1.851667486831815, 2.2135585372644266, 2.5611558585616567, 2.8972998229093054, 3.2239403473971104, 3.5424931195762213, 3.854029263008983, 4.159385332309215, 4.459231350720038, 4.754115074302503, 5.044491985742914, 5.330746311754014, 5.613206170919313, 5.892154756034149, 6.167838761439447, 6.440474849510778, 6.710254691744433, 6.977348954189568, 7.241910488014847, 7.50407691264473, 7.763972728474131, 8.021711060847016, 8.27739511181728, 8.531119378000463, 8.782970679462556, 9.033029034659757, 9.281368408972387, 9.528057358695154, 9.773159587982176, 10.016734432861487, 10.25883728378693, 10.499519956108267, 10.73883101618156, 10.976816069514562, 11.213518016272257, 11.448977278600342, 11.683232003517153, 11.916318244544179, 12.148270124766702, 12.379119983619606, 12.608898509362868, 12.83763485893502, 13.06535676664062, 13.292090642931754, 13.517861664377802, 13.742693855776386, 13.966610165238238, 14.189632532975471, 14.411781954434234, 14.633078538336491, 14.853541560129566, 15.073189511285062, 15.292040144838941, 15.510110517521309, 15.727417028786594, 15.943975457021544, 16.159800993179527, 16.374908272063752, 16.589311401459693, 16.80302398929674, 17.0160591690016, 17.228429623190156, 17.440147605830497, 17.65122496299749, 17.861673152327985, 18.07150326127596, 18.280726024257895, 18.489351838770723, 18.69739078055749, 18.904852617889503, 19.1117468250277, 19.318082594920952, 19.523868851194102, 19.72911425947427, 19.933827238100108, 20.13801596825502, 20.341688403562326, 20.544852279177178, 20.74751512040763, 20.949684250894578, 21.151366800378256, 21.35256971207682, 21.553299749700713, 21.75356350412485, 21.95336739973901, 22.15271770049551, 22.351620515671684, 22.550081805363803, 22.74810738572764, 22.94570293398002, 23.14287399317476, 23.339625976765397, 23.535964172966356, 23.73189374892357, 23.927419754704633, 24.122547127118125, 24.317280693371046, 24.511625174572814], [0.0, 0.6198550611538589, 1.0792303452988907, 1.4927502595668962, 1.8790491700524399, 2.246291713760056, 2.599029158652794, 2.9401438791506416, 3.2716146269005324, 3.59487802404816, 3.9110210334824664, 4.220892580436508, 4.525172596176483, 4.824416936750646, 5.119087820332485, 5.409575155418438, 5.6962119126721955, 5.979285472625534, 6.259046177631967, 6.5357138939795245, 6.809483127522301, 7.080527068047507, 7.3490008270228655, 7.615044058931241, 7.878783105227243, 8.14033276410504, 8.399797763727273, 8.657273998085856, 8.912849571105548, 9.166605684521961, 9.41861739748448, 9.668954280069585, 9.917680978461744, 10.164857706125316, 10.41054067260498, 10.654782459474186, 10.897632351267923, 11.139136627889098, 11.37933882389236, 11.618279959169167, 11.855998744839987, 12.09253176757068, 12.327913655044423, 12.562177224918118, 12.795353619256874, 13.02747242615982, 13.258561790054792, 13.48864851194058, 13.717758140687126, 13.945915056360697, 14.173142546419077, 14.399462875517042, 14.624897349572606, 14.84946637466709, 15.073189511285062, 15.29608552434226, 15.518172429399106, 15.739467535413489, 15.959987484348096, 16.179748287913853, 16.398765361701578, 16.61705355692783, 16.834627189998095, 17.05150007007013, 17.267685524782255, 17.483196424295556, 17.698045203784684, 17.912243884499286, 18.125804093506954, 18.33873708221829, 18.55105374378583, 18.76276462946033, 18.973879963980714, 19.184409660067384, 19.394363332082687, 19.60375030891697, 19.8125796461539, 20.020860137564263, 20.228600325973577, 20.43580851354516, 20.642492771517183, 20.848660949429032, 21.05432068386986, 21.259479406779505, 21.464144353329807, 21.668322569412325, 21.87202091875642, 22.075246089700105, 22.278004601634347, 22.48030281114016, 22.682146917836313, 22.88354296995449, 23.084496869657336, 23.285014378113978, 23.4851011203466, 23.68476258986061, 23.884004153070343, 24.082831053531315, 24.28124841598941, 24.47926125025666, 24.676874454922782, 24.874092820910985], [0.0, 0.6288548599518199, 1.094899905125124, 1.5144237971947052, 1.9063314583190993, 2.2789060694898216, 2.6367649794338117, 2.9828324123379892, 3.3191158497376274, 3.647072772380809, 3.967805924986641, 4.282176558502318, 4.590874476251196, 4.894463604865942, 5.1934128735575475, 5.488117851981384, 5.778916345268371, 6.066099906485328, 6.349922512756142, 6.630607222651165, 6.908351366093638, 7.183330647447702, 7.455702430275302, 7.725608396730489, 7.993176722644555, 8.25852387298946, 8.521756096496848, 8.782970679462556, 9.04225700500973, 9.299697453858123, 9.55536817495582, 9.809339748481062, 10.06167775922912, 10.312443294915601, 10.561693381202737, 10.809481363106286, 11.055857240733198, 11.300867965933483, 11.544557705348643, 11.786968074446087, 12.028138346400732, 12.268105639087514, 12.50690508295582, 12.74456997214863, 12.98113190088889, 13.216620886871219, 13.451065483157988, 13.68449287987702, 13.916928996847371, 14.148398568114336, 14.378925219250927, 14.608531538176866, 14.837239140155024, 15.065068727546672, 15.292040144838941, 15.518172429399106, 15.743483858359093, 15.967991991988988, 16.191713713879444, 16.414665268218595, 16.63686229441929, 16.85831985932585, 17.0790524872065, 17.299074187716894, 17.518398482001988, 17.737038427087292, 17.95500663869623, 18.172315312617357, 18.388976244733975, 18.605000849818154, 18.820400179182265, 19.035184937272785, 19.249365497283637, 19.462951915859996, 19.67595394695704, 19.888381054913125, 20.100242426791745, 20.311546984042185, 20.522303393524943, 20.732520077944102, 20.942205225725736, 21.15136680037826, 21.360012549367983, 21.568150012540546, 21.775786530116694, 21.98292925028868, 22.18958513644172, 22.395760974023133, 22.601463377080222, 22.80669879448646, 23.01147351587412, 23.21579367729035, 23.419665266592478, 23.62309412859719, 23.82608596999748, 24.028646364060055, 24.230780755115287, 24.432494462850915, 24.633792686420023, 24.834680508373108, 25.035162898423483, 25.235244717054712], [0.0, 0.6378225720670078, 1.1105135987918326, 1.5360200628809915, 1.933516477952472, 2.311404146343843, 2.6743662619503903, 3.0253687495203847, 3.3664477180477252, 3.699081432516404, 4.024388363209259, 4.343242042843167, 4.656342111602124, 4.964260537929424, 5.267472938146923, 5.566380522885388, 5.861325914506798, 6.152604823736817, 6.440474849510779, 6.7251622313000246, 7.006867113028375, 7.28576770467177, 7.562023613857057, 7.835778543180284, 8.107162496309387, 8.376293599051609, 8.64327961528636, 8.908219218649469, 9.17120306690179, 9.432314715543809, 9.691631399436899, 9.949224705259782, 10.205161153072126, 10.459502701723856, 10.712307190085074, 10.963628723891974, 11.213518016272259, 11.462022688627375, 11.709187537432111, 11.955054771606449, 12.19966422437588, 12.443053542930507, 12.685258358693437, 12.926312440594934, 13.166247833403705, 13.40509498287824, 13.64288284925856, 13.879639010414165, 14.115389755790698, 14.350160172150453, 14.583974221976193, 14.816854815300065, 15.0488238756269, 15.279902400541598, 15.510110517521309, 15.739467535413489, 15.967991991988988, 16.1957016979341, 16.42261377760597, 16.648744706841104, 16.874110348076393, 17.098725983015143, 17.322606343047234, 17.545765637611403, 17.768217580669326, 17.989975415444718, 18.21105193756607, 18.431459516738574, 18.651210117059364, 18.87031531607954, 19.08878632270745, 19.306633994039082, 19.523868851194106, 19.740501094229312, 19.956540616195035, 20.171997016394734, 20.386879612902963, 20.601197454392302, 20.814959331316018, 21.028173786489187, 21.240849125107992, 21.452993424243534, 21.664614541843974, 21.875720125276047, 22.086317619434876, 22.296414274448686, 22.506017153003235, 22.715133137308932, 22.92376893573194, 23.13193108910915, 23.339625976765397, 23.54685982225024, 23.753638698810143, 23.959968534611125, 24.16585511772582, 24.371304100897863, 24.576321006095867, 24.780911228868366, 24.985080042510365, 25.188832602051484, 25.392173948075058, 25.595109010377026], [0.0, 0.6467588718945013, 1.1260726004890478, 1.557540680720631, 1.960606273336144, 2.343788388261312, 2.711835833915948, 3.067756089540084, 3.41361379130939, 3.7509079156403162, 4.080772603295601, 4.404093625740965, 4.721580425564286, 5.0338129848504645, 5.341273583608471, 5.644369053685139, 5.943446817799615, 6.238806729772873, 6.530709997665137, 6.819386030706608, 7.105037776964752, 7.387845943250596, 7.667972373395334, 7.945562783359767, 8.220748998245886, 8.49365079887861, 8.764377458977831, 9.033029034659759, 9.299697453858125, 9.564467442739113, 9.82741731827362, 10.088619670115255, 10.348141950312023, 10.606046985796738, 10.862393425798848, 11.117236134110323, 11.37062653438203, 11.62261291522153, 11.873240700730715, 12.122552691203373, 12.370589277953814, 12.617388635633217, 12.862986894883583, 13.107418297759363, 13.350715337996851, 13.592908887918973, 13.83402831351713, 14.07410157904431, 14.313155342278009, 14.551215041462008, 14.788304974808698, 15.02444837333434, 15.25966746770601, 15.493983549698127, 15.727417028786594, 15.959987484348096, 16.191713713879444, 16.42261377760597, 16.652705039807955, 16.88200420715885, 17.11052736433837, 17.338290007156207, 17.565307073398387, 17.791592971586905, 18.017161607824768, 18.24202641088168, 18.466200355661016, 18.689695985175415, 18.912525431146605, 19.134700433334555, 19.356232357691532, 19.577132213428357, 19.797410669072264, 20.017078067589335, 20.236144440637823, 20.45461952201354, 20.672512760343185, 20.889833331076996, 21.106590147828083, 21.322791873101785, 21.538446928455375, 21.75356350412485, 21.968149568153226, 22.182212875051707, 22.395760974023133, 22.60880121677463, 22.821340764944676, 23.03338659716783, 23.24494551579873, 23.45602415331554, 23.66662897842151, 23.87676630186207, 24.08644228197374, 24.29566292997991, 24.50443411504779, 24.712761569119554, 24.920650891530098, 25.128107553423032, 25.335136901975574, 25.541744164442584, 25.747934452029178, 25.953712763600866], [0.0, 0.6556644082892014, 1.1415780399387683, 1.578987213302013, 1.98760281143036, 2.3760611466264128, 2.7491764159548895, 3.109997510095221, 3.46061749419932, 3.802555984816477, 4.136962739243317, 4.46473572556221, 4.786594155019897, 5.103125995755727, 5.4148201685258766, 5.722089107042073, 6.02528501785528, 6.324711883619072, 6.6206345090940655, 6.913285462357345, 7.2028704859666925, 7.4895727749728005, 7.773556401713024, 8.054969088581856, 8.333944475845016, 8.610603993647656, 8.885058420352486, 9.157409189796875, 9.427749495714833, 9.696165230908196, 9.962735790732188, 10.227534764362547, 10.490630532627224, 10.752086787553516, 11.011962985940546, 11.270314747026424, 11.527194202539194, 11.78265030599566, 12.036729106964186, 12.289473995076555, 12.540925917814665, 12.791123575474963, 13.040103596199774, 13.287900693538996, 13.53454780865093, 13.780076238954475, 14.024515754795607, 14.267894705480662, 14.510240115851001, 14.75157777442191, 14.991932313979646, 15.231327285419594, 15.469785225513656, 15.707327719213017, 15.943975457021544, 16.179748287913853, 16.414665268218595, 16.648744706841104, 16.88200420715885, 17.114460705887566, 17.346130509184725, 17.57702932622933, 17.807172300493015, 18.036574038895715, 18.265248639020296, 18.493209714543706, 18.720470419027055, 18.947043468193797, 19.172941160813224, 19.398175398295745, 19.622757703096937, 19.846699236018775, 20.070010812488626, 20.292702917889873, 20.514785722011542, 20.736269092678796, 20.957162608621054, 21.177475571629778, 21.39721701805393, 21.616395729677095, 21.835020244017038, 22.053098864085094, 22.270639667640122, 22.487650515968955, 22.704139062223053, 22.920112759338775, 23.135578867566664, 23.350544461633483, 23.56501643755878, 23.779001519146536, 23.99250626417071, 24.205537070272438, 24.418100180585366, 24.630201689104336, 24.84184754581196, 25.053043561576295, 25.263795412832213, 25.474108646058134, 25.68398868205916, 25.893440820066754, 26.102470241664697, 26.311082014550294], [0.0, 0.664539805948974, 1.1570310048031527, 1.6003611650379603, 2.0145079859649306, 2.408224685280692, 2.7863906274020755, 3.1520959743004386, 3.5074621238926214, 3.854029263008983, 4.192962712629476, 4.525172596176484, 4.851387860495835, 5.172204432754366, 5.488117851981385, 5.799546134795289, 6.106846255389083, 6.410326311275864, 6.710254691744433, 7.006867113028375, 7.30037210271847, 7.590955335684211, 7.878783105227245, 8.164005133385446, 8.446756869445256, 8.727161387290321, 9.005330964834048, 9.281368408972387, 9.555368174955818, 9.827417318273618, 10.097596309015797, 10.365979732497571, 10.632636895183586, 10.897632351267925, 11.161026362386337, 11.42287530066645, 11.683232003517155, 11.942146087114264, 12.199664224375878, 12.455830392277287, 12.71068609258575, 12.96427054946407, 13.216620886871219, 13.467772288256867, 13.717758140687128, 13.966610165238238, 14.214358535242301, 14.461031983755879, 14.706657901441949, 14.951262425901895, 15.194870523363548, 15.437506063518859, 15.67919188820862, 15.91994987456859, 16.159800993179527, 16.398765361701578, 16.63686229441929, 16.874110348076393, 17.11052736433837, 17.346130509184725, 17.580936309501134, 17.814960687113818, 18.04821899048393, 18.280726024257902, 18.512496076850447, 18.74354294621998, 18.973879963980714, 19.203520017982427, 19.432475573476637, 19.660758692977122, 19.888381054913122, 20.115353971164744, 20.341688403562326, 20.56739497942459, 20.792484006203857, 21.016965485301043, 21.240849125107992, 21.464144353329807, 21.686860328635948, 21.90900595168456, 22.130589875561473, 22.351620515671684, 22.5721060591186, 22.792054473603304, 23.011473515874115, 23.230370739754015, 23.448753503771893, 23.66662897842151, 23.884004153070343, 24.100885842539114, 24.317280693371046, 24.533195189808918, 24.74863565949651, 24.963608278919995, 25.1781190786039, 25.392173948075058, 25.60577864060737, 25.81893877775913, 26.031659853714142, 26.24394723943689, 26.45580618665162, 26.667241831654515], [0.0, 0.6733856667011124, 1.1724325429243792, 1.6216639852638157, 2.041323621339051, 2.440281185185065, 2.8234809916969046, 3.1940543367889287, 3.55415085685279, 3.9053312405429854, 4.248776320727584, 4.585408335716583, 4.915965935555279, 5.2410529799507275, 5.5611716041800605, 5.876745389188699, 6.188136060945197, 6.495655818128114, 6.7995766226252945, 7.100137328349903, 7.397549238657264, 7.6920004999829485, 7.983659619201627, 8.27267831133984, 8.559193828684412, 8.8433308833872, 9.12520324792187, 9.404915097673486, 9.682562145210724, 9.958232604840932, 10.232008017812245, 10.503963962264242, 10.7741706672178, 11.042693546164529, 11.30959366289835, 11.574928139930822, 11.838750518003216, 12.101111073745056, 12.362057101349693, 12.621633163181276, 12.879881313447793, 13.136841298434996, 13.392550736268449, 13.647045278733794, 13.900358757320992, 14.152523315353712, 14.403569527809056, 14.653526510216718, 14.90242201784385, 15.150282536216196, 15.397133363893477, 15.642998688303274, 15.887901655340015, 16.13186443335165, 16.374908272063752, 16.61705355692783, 16.85831985932585, 17.098725983015143, 17.338290007156207, 17.57702932622933, 17.814960687113818, 18.05210022357543, 18.28846348838265, 18.52406548325036, 18.75892068679007, 18.99304308062836, 19.226446173840007, 19.45914302582828, 19.691146267772872, 19.922468122754793, 20.15312042465787, 20.383114635937567, 20.612461864339963, 20.841172878646766, 21.06925812351545, 21.296727733478164, 21.523591546157654, 21.749859114753644, 21.975539719849, 22.200642380580824, 22.4251758652184, 22.64914870118636, 22.872569184568746, 23.095445389126777, 23.317785174860838, 23.5395961961448, 23.760885909458835, 23.981661580744984, 24.201930292408008, 24.421698949982456, 24.64097428848541, 24.859762878473074, 25.078071131818124, 25.29590530722354, 25.513271515487705, 25.730175724534476, 25.946623764221055, 26.16262133093576, 26.37817399199688, 26.5932871898632, 26.80796624616603, 27.022216365572095], [0.0, 0.6822025707003491, 1.1877836644105055, 1.6428970711225273, 2.0680514762530007, 2.472232748761291, 2.860449941406537, 3.235875349394938, 3.6006867551548614, 3.9564652820526187, 4.304407224066535, 4.645446894736367, 4.980332615543652, 5.309676152768644, 5.633986216343612, 5.953691933326281, 6.269159765905917, 6.580706000501447, 6.888606159904932, 7.1931022254379835, 7.494408267134057, 7.792714894904175, 8.088192821949951, 8.380995749762576, 8.671262727727171, 8.959120100900968, 9.24468313142548, 9.528057358695154, 9.809339748481062, 10.088619670115254, 10.365979732497571, 10.641496503341973, 10.915241131205587, 11.187279886064657, 11.457674631245437, 11.726483237187043, 11.99375994566078, 12.259555691587904, 12.523918388403281, 12.786893181943665, 13.048522677049366, 13.308847140419925, 13.567904682729852, 13.825731422567678, 14.082361634392395, 14.33782788239288, 14.592161141876465, 14.845390909593954, 15.097545304223154, 15.348651158075231, 15.598734100953934, 15.84781863698236, 16.095928215113258, 16.343085293953504, 16.589311401459693, 16.834627189998095, 17.0790524872065, 17.322606343047234, 17.565307073398387, 17.807172300493015, 18.04821899048393, 18.28846348838265, 18.527921550596176, 18.76660837526277, 19.004538630568096, 19.24172648120569, 19.478185613129973, 19.713929256736122, 19.948970208588854, 20.183320851810794, 20.416993175231475, 20.649998791388803, 20.882348953466966, 21.11405457124757, 21.34512622614411, 21.575574185384156, 21.80540841539833, 22.034638594470163, 22.263274124696853, 22.491324143306617, 22.718797533375152, 22.94570293398002, 23.172048749829155, 23.397843160396718, 23.623094128597188, 23.847809409026155, 24.07199655579443, 24.29566292997991, 24.518815706720055, 24.741461881966316, 24.963608278919995, 25.185261554168186, 25.406428203536745, 25.627114567676305, 25.847326837396356, 26.067071058761126, 26.28635313796044, 26.50517884596767, 26.7235538229962, 26.941483582765077, 27.158973516583817, 27.37602889726591], [0.0, 0.6909910775458248, 1.2030853435802271, 1.6640617702545604, 2.0946932470941557, 2.5040814039397565, 2.897299822909306, 3.2775616664518625, 3.6470727723808096, 4.00743463295892, 4.359858953478209, 4.705292083816749, 5.044491985742914, 5.378078306644964, 5.706566309934905, 6.030390650920054, 6.349922512756142, 6.665482256436832, 6.977348954189568, 7.285767704671769, 7.59095533568421, 7.893104912679098, 8.19238934807893, 8.488964323441616, 8.782970679462556, 9.074536388845143, 9.363778198600878, 9.650803007740441, 9.935709031201032, 10.218586789619343, 10.49951995610827, 10.778586084768962, 11.055857240733198, 11.331400547703323, 11.605278665962809, 11.87755021146944, 12.148270124766704, 12.417489996947385, 12.685258358693437, 12.951620937434988, 13.216620886871219, 13.480298992439327, 13.742693855776388, 14.003842060770355, 14.263778323422557, 14.522535627431576, 14.780145347145602, 15.036637359308722, 15.292040144838941, 15.546380881715944, 15.799685529920632, 16.051978909251627, 16.303284770743925, 16.553625862328456, 16.80302398929674, 17.05150007007013, 17.299074187716894, 17.545765637611403, 17.791592971586905, 18.036574038895715, 18.280726024257902, 18.52406548325036, 18.76660837526277, 19.008370094224105, 19.249365497283637, 19.48960893161224, 19.729114259474272, 19.967894881706115, 20.20596375972483, 20.44333343617921, 20.68001605434544, 20.916023376360503, 21.151366800378263, 21.3860573767261, 21.620105823133066, 21.853522539094783, 22.08631761943488, 22.318500867117834, 22.550081805363806, 22.781069689111792, 23.01147351587412, 23.24130203602168, 23.47056376253646, 23.69926698026508, 23.927419754704633, 24.155029940349667, 24.382105188627175, 24.60865295544448, 24.834680508373108, 25.060194933490166, 25.28520314189718, 25.509711875935043, 25.733727715112384, 25.95725708176358, 26.180306246451508, 26.402881333129105, 26.62498832407297, 26.846633064601306, 27.06782126758782, 27.288558517782295, 27.508850275948056, 27.72870188282586], [0.0, 0.6997517273236981, 1.2183385207781623, 1.6851593833087335, 2.121250571097592, 2.5358291079377815, 2.934032900766334, 3.3191158497376274, 3.6933117591224676, 4.05824242551648, 4.415134916675888, 4.764947580665309, 5.108447988982987, 5.446263645144317, 5.778916345268371, 6.106846255389083, 6.430429264664527, 6.749989795747857, 7.065810459051201, 7.378139460686717, 7.687196377481161, 7.993176722644555, 8.296255600849378, 8.59659066744401, 8.894324548756183, 9.189586839976283, 9.482495768279174, 9.773159587982176, 10.06167775922912, 10.348141950312021, 10.632636895183587, 10.915241131205587, 11.19602763717917, 11.47506438782671, 11.752414837862773, 12.02813834640073, 12.302290550541338, 12.574923695469035, 12.846086927156366, 13.115826552783348, 13.3841862731683, 13.651207390841831, 13.91692899684737, 14.181388138897425, 14.4446199731361, 14.706657901441949, 14.967533695939176, 15.227277612160687, 15.485918492116483, 15.743483858359092, 16.000000000000004, 16.255492051512768, 16.509984065057097, 16.763499076970923, 17.0160591690016, 17.267685524782255, 17.518398482001988, 17.768217580669326, 18.017161607824768, 18.265248639020296, 18.512496076850447, 18.75892068679007, 19.004538630568096, 19.249365497283637, 19.493416332450604, 19.73670566513879, 19.97924753336367, 20.22105550786256, 20.46214271438233, 20.702521854592288, 20.942205225725736, 21.181204739044528, 21.419531937212696, 21.65719801065791, 21.8942138129927, 22.13058987556147, 22.366336421173905, 22.601463377080222, 22.83598038723961, 23.069896823928733, 23.303221798733833, 23.53596417296636, 23.76813256753914, 23.999735372337263, 24.230780755115283, 24.461276669950042, 24.691230865276253, 24.920650891530098, 25.149544108424156, 25.37791769187554, 25.60577864060737, 25.83313378244251, 26.059989780307138, 26.286353137960443, 26.512230205465897, 26.737627184418265, 26.96255013293974, 27.187004970457714, 27.41099748227589, 27.634533323949654, 27.857618025475983, 28.080256995307586], [0.0, 0.7084850415814244, 1.233544104071174, 1.706191166288504, 2.1477250292995467, 2.5674777507903146, 2.9706513618066563, 3.3605403730959673, 3.7394064681238106, 4.1088916844638295, 4.470238404401549, 4.824416936750647, 5.172204432754366, 5.514236227542064, 5.851040629556124, 6.1830632983621845, 6.510684814436707, 6.834233649418893, 7.153995940865495, 7.470222992647335, 7.783137122039471, 8.092936282372097, 8.399797763727275, 8.70388118908512, 9.005330964834048, 9.304278303588854, 9.600842908069275, 9.895134383670358, 10.187253431857185, 10.477292864996125, 10.765338474569583, 11.051469778131931, 11.335760665302793, 11.618279959169167, 11.899091906397887, 12.178256606939064, 12.455830392277285, 12.731866159647705, 13.006413668393591, 13.279519803635878, 13.551228811604874, 13.821582510311124, 14.090620478677339, 14.358380226793326, 14.624897349572604, 14.890205665768871, 15.154337344041181, 15.417323017529332, 15.679191888208619, 15.939971822129262, 16.199689436506365, 16.45837017950653, 16.716038403474613, 16.972717432255624, 17.228429623190156, 17.483196424295556, 17.737038427087292, 17.989975415444718, 18.24202641088168, 18.493209714543706, 18.74354294621998, 18.99304308062836, 19.24172648120569, 19.48960893161224, 19.73670566513879, 19.983031392186504, 20.228600325973574, 20.473426206608117, 20.717522323654066, 20.96090153730505, 21.203576298271095, 21.445558666473634, 21.686860328635948, 21.927492614848845, 22.167466514184344, 22.406792689424236, 22.6454814909649, 22.88354296995449, 23.120986890714498, 23.357822742493124, 23.594059750594578, 23.829706886924704, 24.064772879990414, 24.2992662243875, 24.533195189808918, 24.766567829603073, 24.999391988909725, 25.231675312398938, 25.46342525163685, 25.694649072100255, 25.92535385986046, 26.155546527955597, 26.385233822469083, 26.614422328330853, 26.843118474856922, 27.07132854104162, 27.29905866061607, 27.52631482688561, 27.75310289735795, 27.97942859817314, 28.205297528345778, 28.43071516382926], [0.0, 0.7171915242391691, 1.248702970835229, 1.727158332746853, 2.1741181493003046, 2.599029158652794, 3.007157318948735, 3.4018376267595056, 3.7853595590914146, 4.159385332309214, 4.525172596176483, 4.883703583508624, 5.235764995861767, 5.581999975917949, 5.922943324434876, 6.259046177631967, 6.590693792890798, 6.918218678396816, 7.241910488014847, 7.562023613857055, 7.878783105227243, 8.192389348078928, 8.503021811189466, 8.810842079125491, 9.11599633286718, 9.41861739748448, 9.718826446708642, 10.016734432861485, 10.3124432949156, 10.606046985796736, 10.897632351267923, 11.187279886064657, 11.475064387826707, 11.761055525399245, 12.045318334968231, 12.327913655044423, 12.608898509362868, 12.888326445206124, 13.166247833403704, 13.442710135241834, 13.717758140687126, 13.991434181646348, 14.263778323422557, 14.53482853706229, 14.804620854900437, 15.073189511285062, 15.340567070191783, 15.60678454120716, 15.871871485165855, 16.135856110560432, 16.398765361701578, 16.660624999485176, 16.921459675518957, 17.181293000271694, 17.440147605830497, 17.698045203784684, 17.95500663869623, 18.21105193756607, 18.466200355661016, 18.720470419027055, 18.973879963980714, 19.226446173840007, 19.478185613129973, 19.729114259474272, 19.97924753336367, 20.228600325973574, 20.47718702518661, 20.725021539961336, 20.97211732317545, 21.218487393059867, 21.464144353329807, 21.709100412109542, 21.95336739973901, 22.196956785543076, 22.439879693637053, 22.682146917836313, 22.92376893573194, 23.164755921989364, 23.40511776092259, 23.64486405839198, 23.884004153070343, 24.12254712711812, 24.36050181630575, 24.597876819618023, 24.8346805083731, 25.070921034885973, 25.306606340704317, 25.54174416444258, 25.77634204923825, 26.010407349852635, 26.243947239436885, 26.476968715982565, 26.70947860847486, 26.941483582765077, 27.17299014717827, 27.40400465787054, 27.63453332394965, 27.864582212371907, 28.094157252627184, 28.32326424122334, 28.55190884598056, 28.780096610145524], [0.0, 0.7258716624432953, 1.2638159692414097, 1.7480620558416777, 2.2004314078514926, 2.6304850968941063, 3.0435528147791064, 3.4430099213980885, 3.831173603199201, 4.209726194280444, 4.5799405656864485, 4.942810838154184, 5.299133234654911, 5.649558681798917, 5.9946284530145, 6.334799144603361, 6.670460676700612, 7.001949581823982, 7.329559019506579, 7.65354646075737, 7.9741396786422145, 8.291541484377213, 8.605933518842624, 8.91747932225615, 9.22632684482009, 9.532610519180505, 9.83645298562911, 10.137966539338908, 10.437254353045494, 10.734411516782842, 11.029525927404523, 11.322679053870353, 11.613946599092728, 11.903399075115853, 12.191102305255855, 12.477117864349378, 12.76150346628728, 13.044313306432578, 13.325598365250771, 13.605406678449999, 13.88378357808791, 14.160771908412519, 14.436412219635528, 14.710742942365421, 14.983800545034883, 15.255619676328827, 15.526233294343264, 15.795672783972453, 16.063968063824564, 16.33114768379834, 16.597238914310296, 16.862267828039332, 17.12625937495053, 17.389237451269153, 17.65122496299749, 17.912243884499286, 18.172315312617357, 18.431459516738574, 18.689695985175415, 18.947043468193797, 19.203520017982427, 19.45914302582828, 19.713929256736122, 19.967894881706115, 20.22105550786256, 20.473426206608117, 20.725021539961336, 20.975855585220305, 21.225941958082327, 21.4752938343374, 21.723923970242968, 21.971844721677712, 22.219068062163664, 22.46560559983843, 22.711468593452018, 22.956667967456887, 23.201214326253943, 23.44511796765217, 23.68838889559499, 23.931036832202086, 24.173071229171814, 24.41450127858563, 24.655335923152897, 24.895583865931574, 25.135253579557517, 25.37435331501283, 25.6128911099614, 25.8508747966778, 26.088312009593782, 26.32521019248502, 26.56157660531899, 26.797418330783664, 27.032742280515134, 27.26755520104122, 27.501863679456957, 27.735674148846723, 27.968992893466847, 28.201826053701755, 28.434179630805676, 28.666059491441356, 28.89747137202636, 29.12842088289705], [0.0, 0.7345259273664232, 1.2788839196488953, 1.768903470262513, 2.226666233281402, 2.6618472729959177, 3.079839824906999, 3.4840594919136816, 3.8768510873111675, 4.2599170029648645, 4.634545285829697, 5.001741909129331, 5.362312588869249, 5.716916012386077, 6.066099906485327, 6.410326311275863, 6.749989795747856, 7.085430904755806, 7.416946293051599, 7.7447965013635995, 8.06921201840088, 8.390398073413035, 8.70853847290874, 9.02379870692747, 9.336328489620044, 9.646263856416862, 9.953728909798661, 10.25883728378693, 10.561693381202737, 10.862393425798846, 11.161026362386337, 11.457674631245437, 11.752414837862773, 12.045318334968231, 12.336451730661867, 12.625877333911404, 12.91365354670634, 13.199835210558389, 13.484473913751867, 13.76761826470461, 14.04931413594948, 14.32960488254858, 14.608531538176864, 14.886132991634922, 15.162446146153345, 15.437506063518857, 15.711346094773095, 15.983997998999314, 16.255492051512764, 16.525857142600717, 16.795120867813488, 17.063309610683643, 17.330448618644283, 17.5965620728254, 17.861673152327985, 18.125804093506954, 18.388976244733975, 18.651210117059364, 18.912525431146605, 19.172941160813224, 19.432475573476637, 19.691146267772872, 19.948970208588854, 20.20596375972483, 20.46214271438233, 20.717522323654066, 20.97211732317545, 21.225941958082327, 21.479010006406266, 21.731334801026726, 21.982929250288677, 22.233805857384787, 22.483976738592393, 22.733453640448083, 22.982247955935243, 23.230370739754015, 23.477832722737162, 23.724644325470138, 23.97081567116921, 24.216356597866838, 24.461276669950042, 24.70558518909361, 24.949291204627116, 25.192403523371432, 25.434930718978126, 25.676881140802312, 25.918262922337597, 26.15908398923949, 26.399352066961885, 26.63907468802949, 26.878259198967346, 27.11691276690735, 27.355042385890158, 27.592654882879614, 27.82975692350595, 28.066355017552517, 28.302455524200212, 28.5380646570427, 28.773188488884664, 29.007832956334617, 29.242003864203042, 29.475706889715998], [0.0, 0.7431547749581351, 1.2939076159120178, 1.7896836740383986, 2.2528240077707045, 2.693117339273153, 3.1160202611120096, 3.5249885010011757, 3.922394417943637, 4.309960402663115, 4.688989633453605, 5.060499901215055, 5.425306387106391, 5.784075516397551, 6.137361450317868, 6.485631656795064, 6.829285340020813, 7.168667045402266, 7.504076912644729, 7.835778543180282, 8.164005133385446, 8.488964323441616, 8.810842079125493, 9.12980583457175, 9.446007062699058, 9.759583397014833, 10.070660397894414, 10.379353034275624, 10.685766935452275, 10.989999455566226, 11.292140584308237, 11.592273730426209, 11.890476399330163, 12.186820781966599, 12.48137426891461, 12.77419990111688, 13.06535676664062, 13.354900351248517, 13.642882849258557, 13.92935344011625, 14.2143585352423, 14.497941999012653, 14.780145347145599, 15.06100792528814, 15.340567070191781, 15.618858255531789, 15.895915224141355, 16.17177010819375, 16.44645353866367, 16.719994745227194, 16.992421647613526, 17.263760939295942, 17.534038164301908, 17.803277787829373, 18.07150326127596, 18.33873708221829, 18.605000849818154, 18.87031531607954, 19.134700433334555, 19.398175398295745, 19.660758692977122, 19.922468122754793, 20.183320851810794, 20.44333343617921, 20.702521854592288, 20.96090153730505, 21.218487393059867, 21.4752938343374, 21.731334801026726, 21.986623782635377, 22.241173839149187, 22.49499762064215, 22.74810738572764, 23.00051501893475, 23.252232047086007, 23.50326965474671, 23.75363869881014, 24.003349722277633, 24.25241296728801, 24.500838387446063, 24.748635659496507, 24.995814194385613, 25.24238314775, 25.48835142986873, 25.733727715112376, 25.97852045092017, 26.22273786633396, 26.466387980115954, 26.709478608474857, 26.952017372423757, 27.194011704791038, 27.435468856904517, 27.676395904967386, 27.91679975614329, 28.156687154366985, 28.396064685895546, 28.63493878461438, 28.87331573711138, 29.111201687531537, 29.34860264222371, 29.58552447419042, 29.821972927350977], [0.0, 0.7517586466500455, 1.308887826607858, 1.8104037302358449, 2.278906069489821, 2.7242968954290974, 3.152095974300438, 3.5657990424927273, 3.9678059249866404, 4.359858953478208, 4.743276393803367, 5.119087820332486, 5.488117851981384, 5.851040629556123, 6.2084167300856485, 6.560719033605905, 6.908351366093638, 7.25166226192919, 7.59095533568421, 7.926497240635394, 8.258523872989459, 8.587245276881243, 8.912849571105546, 9.235506128265127, 9.555368174955817, 9.872574938136458, 10.187253431857183, 10.499519956108267, 10.809481363106284, 11.117236134110321, 11.42287530066645, 11.726483237187043, 12.02813834640073, 12.327913655044425, 12.625877333911404, 12.922093153800638, 13.216620886871217, 13.509516661272045, 13.800833275600631, 14.090620478677339, 14.378925219250924, 14.665791869536989, 14.951262425901893, 15.235376689516729, 15.518172429399105, 15.799685529920628, 16.079950124572026, 16.358998717536682, 16.63686229441929, 16.913570423302403, 17.189151347155782, 17.463632068496295, 17.737038427087292, 18.00939517137246, 18.280726024257895, 18.55105374378583, 18.820400179182265, 19.08878632270745, 19.356232357691532, 19.622757703096937, 19.888381054913122, 20.15312042465787, 20.416993175231475, 20.68001605434544, 20.942205225725736, 21.203576298271095, 21.464144353329807, 21.723923970242968, 21.982929250288677, 22.241173839149187, 22.498670948012272, 22.755433373408103, 23.011473515874115, 23.26680339753249, 23.521434678657506, 23.77537867330372, 24.02864636406005, 24.281248415989406, 24.533195189808918, 24.784496754361214, 25.035162898423476, 25.285203141897178, 25.534626746418287, 25.783442725424578, 26.03165985371414, 26.279286676526375, 26.526331518174857, 26.772802490258968, 27.01870749947955, 27.264054255081934, 27.508850275948053, 27.753102897357948, 27.99681927743952, 28.24000640332408, 28.482671097024266, 28.724820021049513, 28.966459683773525, 29.20759644456713, 29.448236518709145, 29.688385982086906, 29.9280507756976, 30.167236709960743], [0.0, 0.7603379700186202, 1.3238252961902828, 1.831064668555052, 2.3049137146082184, 2.755387490957386, 3.1880687572844626, 3.6064931445016932, 4.0130878652022925, 4.4096151351595845, 4.797408264704094, 5.177508578056353, 5.550750104961527, 5.917814679748058, 6.279269276939119, 6.635592173237208, 6.987191803217392, 7.334420678851985, 7.677585879664583, 8.016957102069064, 8.35277293439926, 8.685245817884564, 9.014566018194945, 9.340904840870456, 9.664417261180555, 9.98524409498912, 10.303513805873488, 10.619344021078668, 10.932842812254792, 11.244109784562307, 11.55323700843001, 11.860309821179541, 12.165407520297926, 12.468603965927844, 12.769968106850673, 13.069564441639258, 13.367453424592743, 13.663691824413407, 13.958333042254173, 14.251427394685727, 14.543022366251794, 14.83316283555867, 15.121891278249429, 15.409247949719548, 15.695271050019416, 15.979996873045199, 16.26345994183054, 16.54569313150753, 16.826727781299038, 17.106593796728557, 17.385319743084153, 17.662932931044523, 17.939459495265115, 18.214924466627217, 18.489351838770723, 18.76276462946033, 19.035184937272785, 19.306633994039082, 19.577132213428357, 19.846699236018775, 20.115353971164744, 20.383114635937567, 20.649998791388803, 20.916023376360503, 21.181204739044528, 21.445558666473634, 21.709100412109542, 21.971844721677712, 22.233805857384787, 22.49499762064215, 22.755433373408103, 23.01512605825115, 23.274088217227835, 23.532332009660855, 23.789869228895476, 24.046711318106063, 24.302869385218546, 24.558354217009132, 24.81317629243495, 25.067345795247654, 25.320872625937263, 25.573766413049576, 25.82603652391747, 26.077692074843124, 26.32874194076557, 26.579194764445383, 26.829058965195998, 27.07834274718911, 27.327054107359505, 27.57520084293302, 27.822790558599603, 28.06983067335199, 28.316328427009054, 28.562290886441602, 28.807724951517383, 29.052637360780643, 29.297034696880836, 29.540923391764085, 29.784309731640057, 30.02719986173617, 30.269599790850275, 30.511515395712358], [0.0, 0.7688931594088335, 1.3387207460757933, 1.8516674868318153, 2.3308481991849788, 2.786390627402075, 3.2239403473971104, 3.647072772380809, 4.05824242551648, 4.459231350720038, 4.851387860495835, 5.235764995861768, 5.613206170919313, 5.984400891877105, 6.349922512756142, 6.710254691744433, 7.065810459051201, 7.4169462930516, 7.763972728474132, 8.107162496309387, 8.446756869445256, 8.782970679462556, 9.115996332867182, 9.44600706269906, 9.773159587982176, 10.097596309015797, 10.419447134826884, 10.73883101618156, 11.055857240733198, 11.370626534382028, 11.683232003517155, 11.99375994566078, 12.302290550541338, 12.60889850936287, 12.91365354670634, 13.216620886871217, 13.517861664377804, 13.817433286679856, 14.115389755790696, 14.411781954434236, 14.706657901441949, 15.000062980386334, 15.292040144838941, 15.582630103141899, 15.871871485165855, 16.159800993179527, 16.44645353866367, 16.731862366655594, 17.016059169001604, 17.299074187716894, 17.580936309501134, 17.861673152327988, 18.141311144915463, 18.41987559978792, 18.69739078055749, 18.973879963980714, 19.249365497283637, 19.523868851194106, 19.797410669072264, 20.070010812488626, 20.341688403562326, 20.612461864339963, 20.882348953466966, 21.151366800378263, 21.419531937212696, 21.686860328635948, 21.95336739973901, 22.219068062163664, 22.483976738592393, 22.74810738572764, 23.011473515874115, 23.274088217227835, 23.53596417296636, 23.797113679226953, 24.05754866205153, 24.317280693371046, 24.576321006095867, 24.834680508373104, 25.09236979706728, 25.349399170515838, 25.60577864060737, 25.86151794422637, 26.116626554105324, 26.371113689121422, 26.624988324072966, 26.878259198967346, 27.13093482785064, 27.38302350720645, 27.634533323949654, 27.88547216303911, 28.13584771473141, 28.385667481496487, 28.634938784614384, 28.883668770471104, 29.131864416570497, 29.379532537277722, 29.626679789309048, 29.87331267698173, 30.119437557236765, 30.365060644446586, 30.610188015018988, 30.85482561180789], [0.0, 0.7774246165214936, 1.353574875666119, 1.8722131524519368, 2.3567107409492425, 2.8173077604860475, 3.259712428954892, 3.6875398315080354, 4.103271726118779, 4.508709929841937, 4.905217715739342, 5.2938598091236075, 5.6754889824201165, 6.050802392435738, 6.420379754992431, 6.784710094835364, 7.1442110250595245, 7.499242979440024, 7.850119938325455, 8.19711765886514, 8.540480091054024, 8.880424450193455, 9.217145277686537, 9.550817728726134, 9.881600261253558, 10.209636855608197, 10.535058862256934, 10.857986551815532, 11.178530424567384, 11.496792324043547, 11.812866389719654, 12.126839876654858, 12.4387938643439, 12.748803872746803, 13.056940400092035, 13.3632693943925, 13.667852668502722, 13.970748266856017, 14.27201079065931, 14.571691687219214, 14.869839508172827, 15.166500140658064, 15.461717014849173, 15.75553129077844, 16.04798202694445, 16.33910633285563, 16.628939507362293, 16.917515164380838, 17.204865347402826, 17.49102063400171, 17.776010231397173, 18.059862064005394, 18.3426028537912, 18.624258194140754, 18.904852617889503, 19.184409660067384, 19.462951915859996, 19.740501094229312, 20.017078067589335, 20.292702917889873, 20.56739497942459, 20.841172878646766, 21.11405457124757, 21.3860573767261, 21.65719801065791, 21.927492614848845, 22.196956785543076, 22.46560559983843, 22.733453640448083, 23.00051501893475, 23.26680339753249, 23.532332009660855, 23.797113679226953, 24.061160838803087, 24.324485546759714, 24.587099503427204, 24.849014066353654, 25.1102402647204, 25.370788812972272, 25.630670123714637, 25.889894319925634, 26.148471246527947, 26.40641048136125, 26.66372134559323, 26.92041291360443, 27.1764940223793, 27.431973280433766, 27.68685907630725, 27.941159586645135, 28.194882783895924, 28.448036443645478, 28.70062815160937, 28.952665310302834, 29.204155145406492, 29.455104711844925, 29.705520899593886, 29.95541043923099, 30.204779907243875, 30.45363573110864, 30.70198419415094, 30.94983144020095, 31.197183478053095], [0.0, 0.7859327309668146, 1.3683883633120433, 1.8927026036843522, 2.3825025209783215, 2.8481403021171032, 3.295386635578907, 3.727896169912304, 4.148177823384228, 4.558053132087696, 4.958900288708875, 5.35179567088605, 5.737601383763474, 6.1170222138136765, 6.490644221253241, 6.858961782701217, 7.222397081599259, 7.581314496300183, 7.936031443345213, 8.286826697762624, 8.633946879329647, 8.977611580546156, 9.318017471871217, 9.655341625391499, 9.989744233207828, 10.321370851376622, 10.6503542678608, 10.976816069514562, 11.300867965933485, 11.622612915221529, 11.942146087114265, 12.259555691587906, 12.574923695469037, 12.888326445206127, 13.19983521055839, 13.509516661272047, 13.817433286679856, 14.123643766451886, 14.428203299349224, 14.731163895716444, 15.032574638538478, 15.332481917140864, 15.630929636996528, 15.927959408592066, 16.22361071788123, 16.51792108049793, 16.81092618160217, 17.102660002980155, 17.393154938806564, 17.682441901295018, 17.97055041730823, 18.257508716866457, 18.543343814379, 18.828081583325368, 19.1117468250277, 19.394363332082687, 19.67595394695704, 19.956540616195035, 20.236144440637823, 20.514785722011542, 20.792484006203857, 21.06925812351545, 21.34512622614411, 21.620105823133066, 21.8942138129927, 22.167466514184344, 22.439879693637053, 22.711468593452018, 22.982247955935243, 23.252232047086007, 23.521434678657506, 23.789869228895476, 24.05754866205153, 24.324485546759714, 24.590692073356966, 24.856180070221775, 25.120961019198933, 25.385046070172848, 25.648446054846954, 25.91117149978189, 26.173232638741403, 26.434639424390753, 26.695401539389234, 26.95552840691515, 27.21502920065882, 27.473912854316417, 27.732188070615248, 27.98986332989868, 28.246946898297086, 28.503446835509237, 28.759371002216803, 29.014727067153217, 29.26952251384666, 29.5237646470554, 29.77746059891293, 30.030617334798716, 30.28324165894964, 30.53534021982623, 30.786919515246733, 31.037985897301347, 31.288545577058162, 31.538604629071685], [0.0, 0.7944178807866091, 1.3831618672225916, 1.9131367509386863, 2.4082246852806923, 2.878889622280331, 3.3309645523843803, 3.7681435807504204, 4.192962712629476, 4.607263149928244, 5.012437964687017, 5.409575155418439, 5.799546134795288, 6.183063298362185, 6.560719033605906, 6.933013054573901, 7.30037210271847, 7.663164490323148, 8.021711060847016, 8.376293599051607, 8.727161387290321, 9.074536388845143, 9.41861739748448, 9.759583397014833, 10.097596309015795, 10.432803261007733, 10.765338474569583, 11.095324849241274, 11.42287530066645, 11.748093898513593, 12.071076839997385, 12.391913287433637, 12.71068609258575, 13.027472426159822, 13.342344327363346, 13.655369185727785, 13.966610165238238, 14.276126579086919, 14.58397422197619, 14.890205665768873, 15.194870523363548, 15.498015684917897, 15.79968552992063, 16.0999221180968, 16.398765361701578, 16.696253181398163, 16.992421647613526, 17.287305109010763, 17.580936309501134, 17.87334649503516, 18.164565511255844, 18.454621892962642, 18.74354294621998, 19.031354823844694, 19.318082594920952, 19.60375030891697, 19.888381054913125, 20.171997016394734, 20.45461952201354, 20.736269092678796, 21.016965485301043, 21.296727733478164, 21.575574185384156, 21.853522539094783, 22.13058987556147, 22.406792689424236, 22.682146917836313, 22.956667967456887, 23.230370739754015, 23.50326965474671, 23.77537867330372, 24.046711318106063, 24.317280693371046, 24.587099503427204, 24.856180070221775, 25.124534349835724, 25.392173948075058, 25.65911013520146, 25.92535385986046, 26.190915762260406, 26.455806186651618, 26.720035193151112, 26.983612568954886, 27.246547838976518, 27.50885027594805, 27.770528910016353, 28.031592537865798, 28.29204973139592, 28.55190884598056, 28.81117802833324, 29.069865224001752, 29.327978184513334, 29.58552447419042, 29.8425114766555, 30.09894640104257, 30.35483628793129, 30.610188015018984, 30.86500830254483, 31.119303718479333, 31.37308068349163, 31.626345475706252, 31.879104235260296], [0.0, 0.8028804329472728, 1.3978960263233688, 1.933516477952472, 2.4338783462904447, 2.9095570508246347, 3.3664477180477252, 3.808283804645426, 4.237628330714772, 4.6563421116021235, 5.065833059075191, 5.467200761572256, 5.861325914506797, 6.248928502231042, 6.630607222651165, 7.006867113028375, 7.378139460686718, 7.744796501363601, 8.107162496309387, 8.465522232003346, 8.820127646284071, 9.17120306690179, 9.518949405279452, 9.86354755185209, 10.205161153072126, 10.543938903738734, 10.880016455228878, 11.213518016272259, 11.544557705348643, 11.873240700730715, 12.19966422437588, 12.523918388403283, 12.846086927156367, 13.166247833403705, 13.484473913751868, 13.800833275600633, 14.115389755790698, 14.428203299349224, 14.739330295332751, 15.0488238756269, 15.356734181632634, 15.663108603005966, 15.967991991988987, 16.271426856348803, 16.573453533506665, 16.874110348076393, 17.173433754725888, 17.47145846801806, 17.768217580669326, 18.063742671478323, 18.358063904019346, 18.651210117059364, 18.9432089075412, 19.23408670687509, 19.523868851194102, 19.8125796461539, 20.100242426791745, 20.386879612902963, 20.672512760343185, 20.957162608621054, 21.240849125107992, 21.523591546157654, 21.80540841539833, 22.08631761943488, 22.366336421173905, 22.6454814909649, 22.92376893573194, 23.201214326253943, 23.477832722737162, 23.75363869881014, 24.02864636406005, 24.302869385218546, 24.576321006095867, 24.849014066353654, 25.120961019198933, 25.392173948075058, 25.66266458241911, 25.932444312549467, 26.201524203742316, 26.46991500955103, 26.737627184418265, 27.00467089562663, 27.271056034630426, 27.536792227807553, 27.801888846668025, 28.066355017552517, 28.330199630852267, 28.59343134977913, 28.856058618712737, 29.118089671149637, 29.379532537277722, 29.64039505119753, 29.90068485781059, 30.16040941939357, 30.41957602187592, 30.678191780837203, 30.936263647239556, 31.193798412909633, 31.45080271578338, 31.707283044926236, 31.963245745340572, 32.218697022571426], [0.0, 0.8113207438055555, 1.4125914610675134, 1.953842642912831, 2.459464584279238, 2.940143879150641, 3.4018376267595056, 3.8483185318958806, 4.282176558502317, 4.705292083816747, 5.119087820332485, 5.524674915952775, 5.9229433244348755, 6.314620598993694, 6.7003117313697445, 7.080527068047506, 7.4557024302753, 7.826213966932776, 8.192389348078928, 8.554516354021642, 8.912849571105546, 9.267615685334812, 9.619017720221311, 9.967238467817594, 10.3124432949156, 10.654782459474186, 10.99439303891054, 11.33140054770332, 11.665920304007122, 11.998058591785188, 12.327913655044425, 12.655576553211029, 12.98113190088889, 13.304658510748505, 13.626229954778644, 13.945915056360697, 14.263778323422557, 14.579880331165747, 14.894278061438893, 15.207025204678567, 15.518172429399105, 15.82776762344207, 16.135856110560432, 16.442480845385813, 16.747682589388123, 17.05150007007013, 17.35397012533081, 17.655127834671227, 17.955006638696226, 18.25363844817776, 18.551053743785832, 18.84728166745604, 19.142350106245114, 19.43628576942448, 19.72911425947427, 20.020860137564263, 20.311546984042185, 20.601197454392302, 20.889833331076996, 21.177475571629778, 21.464144353329807, 21.749859114753644, 22.034638594470163, 22.318500867117834, 22.601463377080222, 22.88354296995449, 23.164755921989364, 23.44511796765217, 23.724644325470138, 24.003349722277633, 24.281248415989406, 24.558354217009132, 24.834680508373104, 25.1102402647204, 25.385046070172848, 25.65911013520146, 25.932444312549467, 26.205060112276392, 26.476968715982565, 26.74818099026849, 27.01870749947955, 27.28855851778229, 27.5577440406153, 27.826273795554144, 28.094157252627184, 28.3614036341161, 28.6280219238727, 28.89402087618119, 29.159409024193046, 29.42419468795977, 29.688385982086903, 29.951990823031263, 30.215016936061694, 30.477471861902337, 30.739362963076236, 31.00069742996576, 31.2614822866053, 31.52172439622084, 31.781430466529876, 32.0406070548144, 32.299260572778856, 32.55739729120431], [0.0, 0.819739159548959, 1.4272487742024753, 1.974116079517051, 2.484984448691335, 2.9706513618066563, 3.43713573007101, 3.888249404564789, 4.326609223180701, 4.754115074302503, 5.172204432754366, 5.581999975917949, 5.9844008918771046, 6.38014228307494, 6.769835418759393, 7.153995940865495, 7.533064192804331, 7.90742022644666, 8.27739511181728, 8.64327961528636, 9.005330964834048, 9.363778198600878, 9.718826446708643, 10.070660397894416, 10.419447134826882, 10.765338474569583, 11.108472916880617, 11.44897727860034, 11.786968074446085, 12.122552691203369, 12.455830392277285, 12.786893181943665, 13.115826552783346, 13.442710135241834, 13.767618264704609, 14.090620478677339, 14.411781954434236, 14.731163895716442, 15.048823875626896, 15.364816141704186, 15.67919188820862, 15.991999499874963, 16.30328477074392, 16.613091101152403, 16.921459675518957, 17.228429623190156, 17.534038164301908, 17.83832074234674, 18.14131114491546, 18.443041613892163, 18.74354294621998, 19.042844586216688, 19.340974710300323, 19.63796030488271, 19.933827238100108, 20.228600325973577, 20.522303393524943, 20.814959331316018, 21.106590147828083, 21.39721701805393, 21.686860328635948, 21.975539719849, 22.263274124696853, 22.550081805363806, 22.83598038723961, 23.120986890714498, 23.40511776092259, 23.68838889559499, 23.97081567116921, 24.25241296728801, 24.533195189808918, 24.81317629243495, 25.09236979706728, 25.370788812972272, 25.648446054846954, 25.92535385986046, 26.201524203742316, 26.476968715982565, 26.751698694203917, 27.02572511776075, 27.29905866061607, 27.571709703543103, 27.843688345694968, 28.11500441558238, 28.385667481496487, 28.655686861411084, 28.925071632396104, 29.193830639571846, 29.46197250463136, 29.729505633956556, 29.996438226351646, 30.26277828041608, 30.528533601577532, 30.793711808804108, 31.05832034101378, 31.322366463197653, 31.58585727227282, 31.84879970267938, 32.111200531735356, 32.37306638476233, 32.6344037399938, 32.8952189332776], [0.0, 0.8281360166124454, 1.4418685514955454, 1.9943375979761124, 2.5104389594068275, 3.001080717998773, 3.4723434386414875, 3.9280780184561648, 4.370928100464299, 4.802813034229475, 5.2251850191019376, 5.6391782324159765, 6.045701072933896, 6.44549617299422, 6.839181063276276, 7.227276667604549, 7.610227839972107, 7.988418525245667, 8.362183184708872, 8.731815563147187, 9.097575523411322, 9.459694449754604, 9.818379573513939, 10.173817475253708, 10.526176949125169, 10.87561136730384, 11.22226064824626, 11.566252907819282, 11.907705854238694, 12.246727974288083, 12.583419548160151, 12.917873522560706, 13.250176265799128, 13.580408224001694, 13.908644493995617, 14.234955325582039, 14.559406563667373, 14.882060038922754, 15.202973914191295, 15.522202992686912, 15.839798993069516, 16.155810795694574, 16.47028466368618, 16.78326444194511, 17.094791736755436, 17.404906078278454, 17.713645067908136, 18.021044512196315, 18.32713854483119, 18.631959737961033, 18.935539203992178, 19.2379066888502, 19.53909065757342, 19.839118373004343, 20.13801596825502, 20.43580851354516, 20.732520077944102, 21.028173786489187, 21.322791873101785, 21.616395729677095, 21.90900595168456, 22.200642380580824, 22.491324143306617, 22.781069689111792, 23.069896823928733, 23.357822742493124, 23.64486405839198, 23.931036832202086, 24.216356597866838, 24.500838387446063, 24.784496754361214, 25.067345795247654, 25.349399170515838, 25.630670123714637, 25.91117149978189, 26.190915762260406, 26.46991500955103, 26.74818099026849, 27.02572511776075, 27.302558483847317, 27.578691871828095, 27.854135768809982, 28.128900377395034, 28.402995626770622, 28.676431183239032, 28.949216460221134, 29.22136062776626, 29.49287262159817, 29.76376115172475, 30.03403471063724, 30.30370158112289, 30.572769843713424, 30.841247383790076, 31.10914189836454, 31.376460902554058, 31.643211735767434, 31.909401567617802, 32.17503740357701, 32.44012609038537, 32.7046743212298, 32.96868864070247, 33.23217544955139], [0.0, 0.8365116420730186, 1.4564513624208644, 2.01450798596493, 2.535829107937782, 3.031433133020796, 3.5074621238926214, 3.967805924986641, 4.415134916675888, 4.851387860495835, 5.278031643091578, 5.696211912672196, 6.106846255389083, 6.510684814436707, 6.908351366093639, 7.30037210271847, 7.687196377481162, 8.06921201840088, 8.446756869445256, 8.820127646284071, 9.18958683997628, 9.555368174955818, 9.917680978461746, 10.276713718102227, 10.632636895183586, 10.98560543306118, 11.335760665302793, 11.683232003517153, 12.028138346400732, 12.370589277953814, 12.71068609258575, 13.048522677049368, 13.3841862731683, 13.717758140687128, 14.049314135949482, 14.378925219250926, 14.706657901441949, 15.032574638538478, 15.356734181632632, 15.67919188820862, 16.000000000000004, 16.319207891729768, 16.63686229441929, 16.953007496409164, 17.267685524782255, 17.580936309501134, 17.8927978322538, 18.203306261733424, 18.512496076850447, 18.820400179182265, 19.127049995800743, 19.432475573476637, 19.73670566513879, 20.039767809361397, 20.341688403562326, 20.642492771517183, 20.942205225725736, 21.240849125107992, 21.538446928455375, 21.835020244017038, 22.130589875561473, 22.4251758652184, 22.718797533375152, 23.01147351587412, 23.303221798733833, 23.594059750594578, 23.884004153070343, 24.173071229171814, 24.461276669950042, 24.748635659496507, 25.035162898423476, 25.320872625937263, 25.60577864060737, 25.889894319925634, 26.173232638741403, 26.455806186651618, 26.737627184418265, 27.01870749947955, 27.29905866061607, 27.578691871828095, 27.85761802547598, 28.13584771473141, 28.413391245383806, 28.69025864704264, 28.966459683773525, 29.24200386420304, 29.51690045112483, 29.79115847063703, 30.064786720839045, 30.33779378011372, 30.610188015018988, 30.881977587811683, 31.153170463624434, 31.42377441731519, 31.693797040007794, 31.96324574534057, 32.23212777543889, 32.500450206626745, 32.768219954891194, 33.03544378111291, 33.30212829607493, 33.568279965261354], [0.0, 0.8448663540236125, 1.470997760810397, 2.03462800952276, 2.561155858561657, 3.0617097596091734, 3.5424931195762213, 4.00743463295892, 4.459231350720038, 4.89984139789623, 5.330746311754014, 5.7531031827350745, 6.167838761439447, 6.575710683163321, 6.977348954189568, 7.373285022255626, 7.763972728474132, 8.149803774320668, 8.531119378000463, 8.908219218649469, 9.281368408972385, 9.650803007740441, 10.016734432861487, 10.379353034275626, 10.738831016181559, 11.095324849241274, 11.44897727860034, 11.799919008373955, 12.148270124766704, 12.494141306255875, 12.837634858935022, 13.178845607256743, 13.517861664377802, 13.854765101629521, 14.189632532975471, 14.522535627431575, 14.853541560129568, 15.182713410868711, 15.510110517521309, 15.835788790457874, 16.159800993179527, 16.482196993542363, 16.80302398929674, 17.122326711115793, 17.440147605830497, 17.756527002206397, 18.071503261275964, 18.385112912969426, 18.69739078055749, 19.008370094224105, 19.318082594920952, 19.626558629512786, 19.933827238100108, 20.239916234300335, 20.544852279177178, 20.848660949429032, 21.15136680037826, 21.452993424243534, 21.75356350412485, 22.053098864085094, 22.351620515671684, 22.64914870118636, 22.94570293398002, 23.24130203602168, 23.53596417296636, 23.829706886924704, 24.12254712711812, 24.41450127858563, 24.70558518909361, 24.995814194385613, 25.285203141897178, 25.573766413049576, 25.86151794422637, 26.148471246527947, 26.434639424390753, 26.720035193151112, 27.00467089562663, 27.28855851778229, 27.571709703543103, 27.854135768809982, 28.13584771473141, 28.416856240279024, 28.697171754171976, 28.976804386191066, 29.255763997921125, 29.534060192956733, 29.81170232660426, 30.08869951511055, 30.365060644446586, 30.64079437867233, 30.915909167907234, 31.190413255929187, 31.46431468742307, 31.737621314898703, 32.01034080529676, 32.28248064629973, 32.55404815236417, 32.82505047048928, 33.095494585735985, 33.36538732650967, 33.63473536961897, 33.903545245122416], [0.0, 0.8532004619276143, 1.4855082854711958, 2.05469841390697, 2.5864201493960186, 3.0919117192277534, 3.5774377232607315, 4.046965610243381, 4.5032190359543, 4.948175441177851, 5.383330977671218, 5.809854149890325, 6.228680850282867, 6.64057618777004, 7.046176383274837, 7.446018126952941, 7.840559736791689, 8.230196778170518, 8.61527383521085, 8.99609354320643, 9.372923630042306, 9.746002483070152, 10.115543605710693, 10.481739225593836, 10.844763245611063, 11.204773679915085, 11.561914681748073, 11.916318244544179, 12.268105639087514, 12.617388635633215, 12.96427054946407, 13.308847140419926, 13.651207390841831, 13.99143418164635, 14.329604882548582, 14.665791869536989, 15.000062980386334, 15.332481917140862, 15.663108603005966, 15.991999499874964, 16.319207891729768, 16.64478413834344, 16.96877590304429, 17.29122835774714, 17.612184367995898, 17.931684660375577, 18.24976797432759, 18.56647120012837, 18.88182950455963, 19.195876445601467, 19.508644077311327, 19.82016304590786, 20.130462677955027, 20.43957106143516, 20.74751512040763, 21.05432068386986, 21.360012549367983, 21.664614541843974, 21.968149568153226, 22.270639667640122, 22.5721060591186, 22.872569184568746, 23.172048749829155, 23.47056376253646, 23.76813256753914, 24.064772879990414, 24.36050181630575, 24.655335923152897, 24.949291204627116, 25.24238314775, 25.534626746418287, 25.82603652391747, 26.116626554105324, 26.40641048136125, 26.695401539389234, 26.983612568954886, 27.271056034630426, 27.5577440406153, 27.843688345694968, 28.128900377395034, 28.413391245383806, 28.697171754171976, 28.98025241515455, 29.262643458036646, 29.54435484168181, 29.825396264418405, 30.10577717383738, 30.385506776111985, 30.664594044868046, 30.943047729631374, 31.220876363876854, 31.498088272702383, 31.774691580148904, 32.05069421618661, 32.326103923386036, 32.60092826329122, 32.87517462251153, 33.14885021854708, 33.42196210536232, 33.6945171787208, 33.966522181293946, 34.23798370755544], [0.0, 0.8615142669552488, 1.4999834607710785, 2.07471992440313, 2.6116228934182644, 3.1220401032868077, 3.612297197741674, 4.086400285373643, 4.5470995619646475, 4.996391736991309, 5.435787541098841, 5.866466864951511, 6.289374720574051, 6.70528367230602, 7.114836140570936, 7.518574045171572, 7.916960170063767, 8.310393935117885, 8.699223282171769, 9.083753795475403, 9.464255811723298, 9.840970041174874, 10.214112067683171, 10.58387599199363, 10.950437411552286, 11.313955880242453, 11.674576955972618, 12.032433918354947, 12.387649219867301, 12.740335719882973, 13.090597740415465, 13.43853197441317, 13.784228271283983, 14.127770319557461, 14.469236242859136, 14.808699122427742, 15.146227457066784, 15.481885569549638, 15.815733966988835, 16.147829661456928, 16.47822645614867, 16.806975201555723, 17.134124025450138, 17.45971853991351, 17.783802028182645, 18.106415613692892, 18.427598413372756, 18.747387676967023, 19.06581891393159, 19.382926009244144, 19.69874132930513, 20.013295818957843, 20.32661909053183, 20.63873950570596, 20.949684250894578, 21.259479406779505, 21.568150012540546, 21.875720125276047, 22.182212875051707, 22.487650515968955, 22.792054473603304, 23.095445389126777, 23.397843160396718, 23.69926698026508, 23.999735372337263, 24.2992662243875, 24.597876819618023, 24.895583865931574, 25.192403523371432, 25.48835142986873, 25.783442725424578, 26.077692074843124, 26.371113689121422, 26.66372134559323, 26.95552840691515, 27.246547838976518, 27.536792227807553, 27.826273795554144, 28.11500441558238, 28.402995626770622, 28.69025864704264, 28.976804386191066, 29.262643458036646, 29.547786191965383, 29.83224264388254, 30.116022606619506, 30.39913561982698, 30.681590979385533, 30.96339774636232, 31.244564755540775, 31.52510062354817, 31.805013756604293, 32.084312357912836, 32.36300443471568, 32.64109780502892, 32.918600104078266, 33.19551879045009, 33.4718611519737, 33.747634311349174, 34.02284523153417, 34.29750072090244, 34.57160743818593], [0.0, 0.8698080623029604, 1.5144237971947048, 2.0946932470941557, 2.6367649794338113, 3.152095974300438, 3.6470727723808087, 4.125740049061481, 4.590874476251195, 5.044491985742914, 5.488117851981384, 5.922943324434876, 6.349922512756141, 6.769835418759393, 7.1833306474477014, 7.590955335684209, 7.993176722644554, 8.390398073413035, 8.782970679462554, 9.171203066901787, 9.555368174955817, 9.935709031201032, 10.3124432949156, 10.685766935452275, 11.055857240733197, 11.42287530066645, 11.786968074446083, 12.148270124766702, 12.506905082955818, 12.862986894883582, 13.216620886871217, 13.567904682729852, 13.91692899684737, 14.263778323422557, 14.608531538176862, 14.951262425901893, 15.29204014483894, 15.630929636996527, 15.967991991988985, 16.30328477074392, 16.63686229441929, 16.96877590304429, 17.29907418771689, 17.627803199626072, 17.955006638696226, 18.2807260242579, 18.605000849818154, 18.927868723724956, 19.249365497283637, 19.569525381682464, 19.888381054913122, 20.20596375972483, 20.52230339352494, 20.837428591030125, 21.151366800378256, 21.464144353329807, 21.775786530116694, 22.086317619434876, 22.395760974023133, 22.704139062223053, 23.011473515874115, 23.317785174860838, 23.623094128597188, 23.927419754704633, 24.230780755115283, 24.533195189808918, 24.8346805083731, 25.135253579557517, 25.434930718978126, 25.733727715112376, 26.03165985371414, 26.32874194076557, 26.624988324072966, 26.92041291360443, 27.21502920065882, 27.50885027594805, 27.801888846668025, 28.094157252627184, 28.385667481496487, 28.676431183239032, 28.966459683773525, 29.255763997921125, 29.54435484168181, 29.83224264388254, 30.11943755723676, 30.405949468851414, 30.691788010215394, 30.976962566700685, 31.2614822866053, 31.54535608976512, 31.82859267575966, 32.111200531735356, 32.39318793986812, 32.674562984485526, 32.9553335588677, 33.23550737174464, 33.51509195350649, 33.7940946621425, 34.07252268892294, 34.350383063837846, 34.62768266080517, 34.904428202660434], [0.0, 0.8780821334968424, 1.5288297918718772, 2.114619069591032, 2.661847272995918, 3.1820803669861735, 3.6817656443783977, 4.1649862556360695, 4.634545285829697, 5.092477843354413, 5.540323711866702, 5.979285472625534, 6.410326311275863, 6.834233649418893, 7.25166226192919, 7.6631644903231475, 8.06921201840088, 8.470211947315997, 8.86651891021043, 9.258444368055263, 9.646263856416862, 10.030222714677581, 10.41054067260498, 10.787415563715237, 11.161026362386337, 11.531535690898187, 11.899091906397887, 12.263830851611079, 12.625877333911406, 12.985346383081987, 13.342344327363346, 13.69696971921558, 14.04931413594948, 14.399462875517042, 14.747495563947005, 15.093486687910673, 15.437506063518857, 15.77961925054258, 16.119887919712674, 16.45837017950653, 16.795120867813484, 17.130191813036067, 17.463632068496295, 17.795488123446248, 18.125804093506954, 18.45462189296264, 18.781981391003356, 19.10792055372743, 19.432475573476637, 19.755680986874044, 20.077569782761554, 20.39817350108583, 20.717522323654066, 21.035645157571405, 21.35256971207682, 21.668322569412325, 21.98292925028868, 22.296414274448686, 22.60880121677463, 22.920112759338775, 23.230370739754015, 23.5395961961448, 23.847809409026155, 24.155029940349667, 24.461276669950042, 24.766567829603073, 25.070921034885973, 25.37435331501283, 25.676881140802312, 25.97852045092017, 26.279286676526375, 26.579194764445383, 26.878259198967346, 27.1764940223793, 27.473912854316417, 27.770528910016353, 28.066355017552517, 28.3614036341161, 28.655686861411084, 28.949216460221134, 29.24200386420304, 29.534060192956733, 29.825396264418405, 30.116022606619506, 30.405949468851414, 30.695186832272434, 30.983744419991236, 31.271631706658397, 31.558857927595348, 31.845432087488128, 32.13136296867122, 32.41665913902526, 32.70132895951058, 32.985380591357114, 33.26882200293, 33.551660976288744, 33.83390511345652, 34.11556184241561, 34.39663842284345, 34.67714195160304, 34.95707936800062, 35.23645745882288], [0.0, 0.8863367586810889, 1.5432019290797656, 2.134498061727474, 2.686870617280111, 3.211994289310292, 3.7163769799826754, 4.204140224412201, 4.6781134587540105, 5.140350922935894, 5.5924068757260175, 6.035495203541681, 6.470588146689334, 6.898480529118924, 7.31983328107587, 7.735203936497658, 8.145068613362968, 8.549838239879064, 8.949870783003188, 9.345480631671222, 9.736945911688805, 10.12451426881097, 10.508407498428532, 10.88882529383987, 11.265948311915247, 11.639940703704962, 12.010952221023647, 12.379119983619608, 12.744569972148632, 13.107418297759361, 13.46777228825687, 13.82573142256768, 14.181388138897425, 14.534828537062292, 14.886132991634922, 15.23537668951673, 15.582630103141899, 15.927959408592065, 16.2714268563488, 16.613091101152406, 16.953007496409164, 17.29122835774714, 17.627803199626072, 17.96277894833158, 18.296200134204348, 18.628109065554046, 18.95854598637077, 19.28754921966241, 19.615155298005675, 19.94139908269358, 20.266313872687675, 20.589931504433586, 20.91228244346994, 21.233395868650174, 21.553299749700713, 21.87202091875642, 22.18958513644172, 22.506017153003235, 22.821340764944676, 23.135578867566664, 23.448753503771893, 23.760885909458835, 24.07199655579443, 24.382105188627175, 24.691230865276253, 24.999391988909725, 25.306606340704317, 25.6128911099614, 25.918262922337597, 26.22273786633396, 26.526331518174857, 26.829058965195998, 27.13093482785064, 27.431973280433766, 27.732188070615248, 28.031592537865798, 28.330199630852267, 28.6280219238727, 28.925071632396104, 29.22136062776626, 29.51690045112483, 29.81170232660426, 30.10577717383738, 30.39913561982698, 30.691788010215394, 30.983744419991236, 31.275014663667637, 31.565608304963927, 31.855534666020436, 32.144802836173945, 32.43342168031942, 32.72139984688195, 33.0087457754211, 33.29546770388843, 33.581573675557664, 33.86707154564543, 34.15196898763959, 34.43627349935099, 34.71999240870342, 35.00313287927566, 35.28570191560863, 35.56770636828982], [0.0, 0.8945722088923754, 1.557540680720631, 2.1543308762206945, 2.711835833915948, 3.241838723482145, 3.7509079156403162, 4.243203240991739, 4.721580425564286, 5.188112796377059, 5.644369053685139, 6.091574362802987, 6.530709997665137, 6.962578167375096, 7.387845943250595, 7.80707603958855, 8.220748998245886, 8.629279565593517, 9.033029034659759, 9.432314715543809, 9.827417318273618, 10.218586789619343, 10.606046985796738, 10.989999455566227, 11.370626534382028, 11.748093898513595, 12.12255269120337, 12.494141306255875, 12.862986894883583, 13.229206647088718, 13.592908887918973, 13.954194020615182, 14.313155342278009, 14.669879752725157, 15.024448373334339, 15.3769370896105, 15.727417028786595, 16.07595498182322, 16.422613777605967, 16.76745261586911, 17.11052736433837, 17.45189082473555, 17.791592971586905, 18.129681167196402, 18.46620035566102, 18.801193238400568, 19.134700433334555, 19.466760619551355, 19.797410669072264, 20.126685767106054, 20.45461952201354, 20.781244066050554, 21.106590147828083, 21.43068721731658, 21.75356350412485, 22.075246089700105, 22.395760974023133, 22.715133137308932, 23.03338659716783, 23.350544461633483, 23.66662897842151, 23.981661580744984, 24.29566292997991, 24.60865295544448, 24.920650891530098, 25.231675312398938, 25.54174416444258, 25.8508747966778, 26.15908398923949, 26.466387980115954, 26.772802490258968, 27.07834274718911, 27.38302350720645, 27.68685907630725, 27.98986332989868, 28.29204973139592, 28.59343134977913, 28.89402087618119, 29.193830639571846, 29.49287262159817, 29.79115847063703, 30.08869951511055, 30.385506776111985, 30.681590979385533, 30.976962566700685, 31.271631706658397, 31.565608304963927, 31.858902014198474, 32.15152224311958, 32.44347816551813, 32.734778728657794, 33.025432661321, 33.315448481483976, 33.60483450364171, 33.89359884580248, 34.1817494361701, 34.46929401953111, 34.75624016336271, 35.04259526367652, 35.32836655061214, 35.61356109379357, 35.89818580746098], [0.0, 0.9027887483210061, 1.5718465067765095, 2.174118149300305, 2.736743723778671, 3.2716146269005324, 3.7853595590914146, 4.282176558502317, 4.764947580665309, 5.235764995861768, 5.6962119126721955, 6.14752474940887, 6.590693792890798, 7.026528620416772, 7.455702430275301, 7.878783105227244, 8.296255600849376, 8.70853847290874, 9.115996332867182, 9.518949405279452, 9.917680978461744, 10.312443294915601, 10.703462266949511, 11.090941294525315, 11.475064387826707, 11.855998744839987, 12.233896897040317, 12.60889850936287, 12.981131900888892, 13.350715337996851, 13.71775814068713, 14.082361634392397, 14.444619973136101, 14.80462085490044, 15.162446146153346, 15.518172429399105, 15.871871485165856, 16.22361071788123, 16.573453533506665, 16.92145967551896, 17.267685524782255, 17.6121843679959, 17.95500663869623, 18.296200134204348, 18.63581021142341, 18.973879963980714, 19.310450382866517, 19.645560502432023, 19.97924753336367, 20.311546984042185, 20.642492771517183, 20.972117323175453, 21.30045167005031, 21.627525532606697, 21.95336739973901, 22.278004601634347, 22.601463377080222, 22.92376893573194, 23.24494551579873, 23.56501643755878, 23.884004153070343, 24.201930292408008, 24.518815706720055, 24.834680508373108, 25.149544108424156, 25.46342525163685, 25.77634204923825, 26.088312009593782, 26.399352066961885, 26.709478608474857, 27.01870749947955, 27.327054107359505, 27.634533323949654, 27.941159586645135, 28.246946898297086, 28.55190884598056, 28.856058618712737, 29.159409024193046, 29.46197250463136, 29.76376115172475, 30.064786720839045, 30.365060644446586, 30.664594044868046, 30.96339774636232, 31.2614822866053, 31.558857927595348, 31.855534666020436, 32.15152224311958, 32.44683015406863, 32.74146765691867, 33.03544378111291, 33.328767335606614, 33.621446916612605, 33.913490914993524, 34.20490752332057, 34.49570474261721, 34.78589038880489, 35.07547209886719, 35.36445733674723, 35.65285339899258, 35.94066742016091, 36.22790637799885], [0.0, 0.9109866345596118, 1.586119855742221, 2.1938605013072383, 2.7615950677431154, 3.3013229330549554, 3.819732990412267, 4.3210613987769815, 4.808216283639134, 5.283309015310365, 5.747937077986809, 6.203348117432003, 6.6505414128883755, 7.090333893122721, 7.523404869484879, 7.950327381466202, 8.37159078834329, 8.78761744663122, 9.198775278691858, 9.60538741691911, 10.007739722064189, 10.406086727148244, 10.800656395904761, 11.191653975294397, 11.579265146428353, 11.963658625555173, 12.344988329231171, 12.723395190636447, 13.09900869406973, 13.471948179842139, 13.842323960648006, 14.210238282018276, 14.57578615295379, 14.939056067789258, 15.300130636391314, 15.659087136681265, 16.015998000999318, 16.37093124584745, 16.723950852952868, 17.07511710830049, 17.424486904727956, 17.772114012811148, 18.118049324054446, 18.462341069808517, 18.80503501884555, 19.146174656109913, 19.48580134481569, 19.823954473770396, 20.160671591556763, 20.495988528993813, 20.82993951111918, 21.16255725978059, 21.49387308779255, 21.8239169855004, 22.15271770049551, 22.48030281114016, 22.80669879448646, 23.13193108910915, 23.45602415331554, 23.779001519146536, 24.100885842539114, 24.421698949982456, 24.741461881966316, 25.060194933490166, 25.37791769187554, 25.694649072100255, 26.010407349852635, 26.32521019248502, 26.63907468802949, 26.952017372423757, 27.264054255081934, 27.57520084293302, 27.88547216303911, 28.194882783895924, 28.503446835509237, 28.81117802833324, 29.118089671149637, 29.42419468795977, 29.729505633956556, 30.03403471063724, 30.33779378011372, 30.64079437867233, 30.943047729631374, 31.244564755540775, 31.54535608976512, 31.845432087488128, 32.144802836173945, 32.44347816551813, 32.74146765691867, 33.03878065249554, 33.33542626368493, 33.63141337943292, 33.92675067401135, 34.22144661447711, 34.515509467795084, 34.80894730764301, 35.10176802091581, 35.39397931394566, 35.68558871845293, 35.9766035972424, 36.26703114965799, 36.55687841680863], [0.0, 0.9191661188401217, 1.60036116503796, 2.213558537264427, 2.7863906274020755, 3.3309645523843803, 3.8540292630089836, 4.359858953478209, 4.851387860495835, 5.330746311754014, 5.799546134795289, 6.259046177631968, 6.710254691744433, 7.153995940865496, 7.590955335684211, 8.021711060847016, 8.446756869445256, 8.866518910210432, 9.281368408972387, 9.691631399436897, 10.097596309015797, 10.49951995610827, 10.897632351267925, 11.292140584308237, 11.683232003517153, 12.071076839997385, 12.455830392277285, 12.837634858935022, 13.216620886871219, 13.592908887918972, 13.96661016523824, 14.337827882392881, 14.706657901441949, 15.073189511285065, 15.437506063518859, 15.79968552992063, 16.159800993179527, 16.51792108049793, 16.87411034807639, 17.22842962319016, 17.580936309501134, 17.931684660375577, 18.2807260242579, 18.628109065554046, 18.973879963980714, 19.318082594920952, 19.660758692977122, 20.0019480006174, 20.341688403562326, 20.68001605434544, 21.016965485301043, 21.352569712076825, 21.686860328635948, 22.019867594598356, 22.351620515671684, 22.682146917836313, 23.01147351587412, 23.339625976765397, 23.66662897842151, 23.99250626417071, 24.317280693371046, 24.64097428848541, 24.963608278919995, 25.28520314189718, 25.60577864060737, 25.92535385986046, 26.243947239436885, 26.56157660531899, 26.878259198967346, 27.194011704791038, 27.508850275948053, 27.822790558599603, 28.13584771473141, 28.448036443645478, 28.759371002216803, 29.069865224001752, 29.379532537277722, 29.688385982086903, 29.996438226351646, 30.30370158112289, 30.610188015018988, 30.915909167907234, 31.220876363876854, 31.52510062354817, 31.82859267575966, 32.13136296867122, 32.43342168031942, 32.734778728657794, 33.03544378111291, 33.33542626368493, 33.63473536961898, 33.93338006767241, 34.23136911000081, 34.52871103968433, 34.825414197914526, 35.12148673086035, 35.41693659623084, 35.7117715695511, 36.00599925016663, 36.2996270669907, 36.59266228400805, 36.88511200554766], [0.0, 0.9273274462596887, 1.6145708614026566, 2.2332128474208868, 2.8111311457511823, 3.360540373095967, 3.888249404564789, 4.398570385169542, 4.894463604865941, 5.378078306644963, 5.851040629556123, 6.314620598993695, 6.769835418759392, 7.217516671269847, 7.658355853013989, 8.092936282372095, 8.521756096496848, 8.945245227918186, 9.363778198600876, 9.77768393712222, 10.187253431857183, 10.592745781509892, 10.99439303891054, 11.392404132634644, 11.786968074446083, 12.178256606939064, 12.566426407546262, 12.951620937434985, 13.333972003526995, 13.713601086798798, 14.090620478677339, 14.465134258721532, 14.837239140155022, 15.207025204678565, 15.574576543972286, 15.93997182212926, 16.30328477074392, 16.66458462636342, 17.023936518386428, 17.381401814176975, 17.737038427087292, 18.090901092202312, 18.44304161389216, 18.793509088656762, 19.14235010624511, 19.489608931612235, 19.835327669924364, 20.179546416525273, 20.52230339352494, 20.86363507445727, 21.203576298271095, 21.542160373761888, 21.87941917541738, 22.21538323153437, 22.550081805363803, 22.88354296995449, 23.21579367729035, 23.54685982225024, 23.87676630186207, 24.205537070272438, 24.533195189808918, 24.859762878473074, 25.185261554168186, 25.509711875935043, 25.83313378244251, 26.155546527955597, 26.476968715982565, 26.797418330783664, 27.11691276690735, 27.435468856904517, 27.753102897357948, 28.06983067335199, 28.385667481496487, 28.70062815160937, 29.014727067153217, 29.327978184513334, 29.64039505119753, 29.951990823031263, 30.26277828041608, 30.572769843713424, 30.881977587811683, 31.190413255929187, 31.498088272702383, 31.805013756604293, 32.111200531735356, 32.41665913902526, 32.72139984688195, 33.025432661321, 33.328767335606614, 33.63141337943292, 33.93338006767241, 34.23467644871651, 34.535311352431705, 34.83529339775262, 35.134630999932725, 35.433332377471245, 35.731405558734195, 36.02885838828597, 36.3256985329471, 36.62193348759259, 36.9175705807045, 37.21261697969155], [0.0, 0.9354708559961984, 1.628749361269196, 2.2528240077707045, 2.8358173478422017, 3.390051261946053, 3.9223944179436376, 4.437196828337797, 4.937444779137899, 5.425306387106392, 5.902422071379746, 6.370073010194958, 6.829285340020814, 7.280897945890053, 7.725608396730489, 8.164005133385446, 8.596590667444012, 9.023798706927472, 9.44600706269906, 9.86354755185209, 10.276713718102227, 10.685766935452277, 11.090941294525317, 11.492447558622025, 11.890476399330163, 12.28520106741704, 12.676779616192356, 13.06535676664062, 13.451065483157988, 13.83402831351713, 14.214358535242301, 14.592161141876467, 14.967533695939176, 15.340567070191785, 15.711346094773097, 16.079950124572026, 16.44645353866367, 16.81092618160217, 17.173433754725885, 17.53403816430191, 17.8927978322538, 18.24976797432759, 18.605000849818154, 18.95854598637077, 19.310450382866517, 19.660758692977122, 20.009513391619144, 20.356754926237237, 20.70252185459229, 21.04685097051384, 21.3897774188921, 21.73133480102673, 22.071555271314164, 22.41046962613819, 22.74810738572764, 23.084496869657336, 23.419665266592478, 23.753638698810143, 24.08644228197374, 24.418100180585366, 24.74863565949651, 25.078071131818124, 25.406428203536745, 25.733727715112384, 26.059989780307138, 26.385233822469083, 26.70947860847486, 27.032742280515134, 27.355042385890158, 27.676395904967386, 27.99681927743952, 28.316328427009054, 28.634938784614384, 28.952665310302834, 29.26952251384666, 29.58552447419042, 29.90068485781059, 30.215016936061694, 30.528533601577532, 30.841247383790076, 31.153170463624434, 31.46431468742307, 31.774691580148904, 32.084312357912836, 32.39318793986812, 32.70132895951058, 33.0087457754211, 33.315448481483976, 33.621446916612605, 33.92675067401135, 34.23136911000081, 34.535311352431705, 34.838586308710774, 35.1412026734606, 35.44316893583396, 35.744493386501574, 36.04518412433128, 36.34524906277522, 36.644695935980806, 36.94353230463996, 37.24176556159047, 37.53940293718231], [0.0, 0.943596581513947, 1.6428970711225273, 2.272392580548362, 2.8604499414065376, 3.4194980649855085, 3.956465282052619, 4.475739390368659, 4.980332615543653, 5.472431907125259, 5.953691933326282, 6.425405001006945, 6.888606159904933, 7.344141581810745, 7.792714894904176, 8.234919651367662, 8.671262727727173, 9.102181599296495, 9.528057358695154, 9.94922470525978, 10.36597973249757, 10.778586084768962, 11.187279886064658, 11.592273730426209, 11.99375994566078, 12.391913287433638, 12.786893181943665, 13.178845607256743, 13.567904682729854, 13.954194020615182, 14.337827882392883, 14.718912173605164, 15.097545304223154, 15.473818936350936, 15.84781863698236, 16.219624450302053, 16.589311401459696, 16.956949941696077, 17.322606343047234, 17.686343049513027, 18.048218990483935, 18.408289861323276, 18.76660837526277, 19.12322449015677, 19.478185613129973, 19.831536785726676, 20.183320851810798, 20.533578610163264, 20.88234895346697, 21.229668995151535, 21.57557418538416, 21.92009841733351, 22.263274124696853, 22.605132371362807, 22.94570293398002, 23.285014378113978, 23.62309412859719, 23.959968534611125, 24.29566292997991, 24.630201689104336, 24.963608278919995, 25.29590530722354, 25.627114567676305, 25.95725708176358, 26.286353137960443, 26.614422328330853, 26.941483582765077, 27.26755520104122, 27.592654882879614, 27.91679975614329, 28.24000640332408, 28.562290886441602, 28.883668770471104, 29.204155145406492, 29.5237646470554, 29.8425114766555, 30.16040941939357, 30.477471861902337, 30.793711808804108, 31.10914189836454, 31.42377441731519, 31.737621314898703, 32.05069421618661, 32.36300443471568, 32.674562984485526, 32.985380591357114, 33.29546770388843, 33.60483450364171, 33.913490914993524, 34.22144661447711, 34.52871103968433, 34.83529339775262, 35.1412026734606, 35.446447636954446, 35.751036851125754, 36.05497867866002, 36.358281288773796, 36.66095266365738, 36.96300060463886, 37.264432738084146, 37.56525652104699, 37.86547924668195], [0.0, 0.9517048507600429, 1.6570143878416181, 2.291919114701712, 2.885029617450606, 3.448881608271476, 3.99046295266546, 4.514199152478268, 5.023128317195254, 5.519456188691334, 6.004851653644753, 6.480618123631643, 6.947799542510461, 7.407249353175525, 7.859677230041685, 8.305681825649943, 8.74577437208608, 9.180396103863206, 9.609931388307038, 10.03471780080568, 10.455053979180205, 10.871205833271343, 11.283411516069195, 11.691885448423252, 12.096821610802072, 12.498396260535952, 12.896770193763608, 13.292090642931756, 13.68449287987702, 14.07410157904431, 14.46103198375588, 14.845390909593956, 15.22727761216069, 15.606784541207162, 15.983997998999316, 16.358998717536686, 16.731862366655594, 17.102660002980155, 17.471458468018056, 17.838320742346742, 18.203306261733424, 18.56647120012837, 18.92786872372496, 19.28754921966241, 19.645560502432023, 20.0019480006174, 20.356754926237237, 20.71002242865395, 21.061789734752946, 21.412094276877333, 21.76097180981549, 22.108456517978063, 22.454581113763147, 22.79937692798951, 23.14287399317476, 23.4851011203466, 23.82608596999748, 24.16585511772582, 24.50443411504779, 24.84184754581196, 25.1781190786039, 25.513271515487705, 25.847326837396356, 26.180306246451508, 26.512230205465897, 26.843118474856922, 27.17299014717827, 27.501863679456957, 27.82975692350595, 28.156687154366985, 28.482671097024266, 28.807724951517383, 29.131864416570497, 29.455104711844925, 29.77746059891293, 30.09894640104257, 30.41957602187592, 30.739362963076236, 31.05832034101378, 31.376460902554058, 31.693797040007794, 32.01034080529676, 32.326103923386036, 32.64109780502892, 32.9553335588677, 33.26882200293, 33.581573675557664, 33.89359884580248, 34.20490752332057, 34.515509467795084, 34.825414197914526, 35.134630999932725, 35.44316893583396, 35.751036851125754, 36.058243382280125, 36.36479696384263, 36.6707058352274, 36.975978047215236, 37.28062146817056, 37.58464378999219, 37.88805253381191, 38.1908550554539], [0.0, 0.9597958863520394, 1.6711016990261414, 2.3114041463438433, 2.909557050824635, 3.4782026985473338, 4.024388363209259, 4.552577170603207, 5.065833059075191, 5.566380522885388, 6.0559026369569615, 6.535713893979525, 7.006867113028375, 7.470222992647336, 7.9264972406353955, 8.376293599051607, 8.820127646284071, 9.258444368055265, 9.691631399436897, 10.120029185755667, 10.543938903738733, 10.963628723891974, 11.379338823892361, 11.791285447514555, 12.199664224375878, 12.604652910279949, 13.006413668393591, 13.40509498287824, 13.800833275600635, 14.193754280940786, 14.583974221976193, 14.971600822394864, 15.356734181632634, 15.73946753541349, 16.119887919712678, 16.49807675288274, 16.874110348076393, 17.24806036601436, 17.619994216465624, 17.98997541544472, 18.358063904019346, 18.72431633370949, 19.08878632270745, 19.4515246865249, 19.8125796461539, 20.171997016394734, 20.529820376638376, 20.8860912260836, 21.24084912510799, 21.59413182429032, 21.94597538239268, 22.296414274448686, 22.645481490964904, 22.993208629122886, 23.339625976765397, 23.68476258986061, 24.028646364060055, 24.371304100897863, 24.712761569119554, 25.053043561576295, 25.392173948075058, 25.730175724534476, 26.067071058761126, 26.402881333129105, 26.737627184418265, 27.07132854104162, 27.40400465787054, 27.735674148846723, 28.066355017552517, 28.396064685895546, 28.724820021049513, 29.052637360780643, 29.379532537277722, 29.705520899593886, 30.030617334798716, 30.35483628793129, 30.678191780837203, 31.00069742996576, 31.322366463197653, 31.643211735767434, 31.96324574534057, 32.28248064629973, 32.60092826329122, 32.918600104078266, 33.23550737174464, 33.551660976288744, 33.86707154564543, 34.1817494361701, 34.49570474261721, 34.80894730764301, 35.12148673086035, 35.433332377471245, 35.744493386501574, 36.05497867866002, 36.36479696384263, 36.67395674830228, 36.98246634150149, 37.29033386266577, 37.5975672470534, 37.904174251956825, 38.210162462449645, 38.5155392968925], [0.0, 0.96786990575728, 1.6851593833087335, 2.3308481991849788, 2.934032900766334, 3.507462123892621, 4.05824242551648, 4.590874476251195, 5.108447988982987, 5.613206170919313, 6.106846255389083, 6.590693792890799, 7.065810459051201, 7.533064192804331, 7.993176722644555, 8.446756869445256, 8.894324548756185, 9.336328489620046, 9.773159587982176, 10.205161153072124, 10.632636895183586, 11.055857240733198, 11.47506438782671, 11.890476399330163, 12.302290550541338, 12.71068609258575, 13.115826552783346, 13.517861664377802, 13.916928996847371, 14.313155342278007, 14.70665790144195, 15.097545304223154, 15.485918492116483, 15.871871485165856, 16.255492051512764, 16.63686229441929, 17.016059169001604, 17.393154938806564, 17.768217580669326, 18.141311144915463, 18.512496076850447, 18.881829504559633, 19.249365497283637, 19.615155298005675, 19.97924753336367, 20.341688403562326, 20.70252185459229, 21.061789734752946, 21.419531937212696, 21.775786530116694, 22.130589875561473, 22.483976738592396, 22.83598038723961, 23.186632684487293, 23.535964172966356, 23.884004153070343, 24.230780755115287, 24.576321006095867, 24.920650891530098, 25.263795412832213, 25.60577864060737, 25.946623764221055, 26.28635313796044, 26.62498832407297, 26.96255013293974, 27.29905866061607, 27.63453332394965, 27.968992893466847, 28.302455524200212, 28.63493878461438, 28.966459683773525, 29.297034696880836, 29.626679789309048, 29.95541043923099, 30.28324165894964, 30.610188015018984, 30.936263647239556, 31.2614822866053, 31.58585727227282, 31.909401567617802, 32.23212777543889, 32.55404815236417, 32.87517462251153, 33.19551879045009, 33.51509195350649, 33.83390511345652, 34.15196898763959, 34.46929401953111, 34.78589038880489, 35.10176802091581, 35.41693659623084, 35.731405558734195, 36.04518412433128, 36.358281288773796, 36.6707058352274, 36.98246634150149, 37.29357118695967, 37.604028559128174, 37.913846460018476, 38.22303271217913, 38.531594964491084, 38.83954069771988], [0.0, 0.9759271214644057, 1.6991878106536067, 2.3502517849455105, 2.9584578114208107, 3.5366606543445673, 4.09202603054407, 4.629092077314587, 5.150974228440411, 5.659934365130786, 6.157683849653805, 6.6455592673032795, 7.124631131825087, 7.595774607474741, 8.059717430911679, 8.517073491253553, 8.968367032185236, 9.414050518279048, 9.854518099567395, 10.290115943222302, 10.721150287831131, 11.147893811026266, 11.570590727137295, 11.989460914335755, 12.404703290174863, 12.816498597989971, 13.225011726415064, 13.630393655176462, 14.032783098975505, 14.432307905402801, 14.829086250890535, 15.223227669632637, 15.614833943430494, 16.003999875015626, 16.390813963171986, 16.775358994645757, 17.157712565180493, 17.537947539894596, 17.916132461509207, 18.29233191354893, 18.66660684450759, 19.03901485804407, 19.409610473508586, 19.778445360466236, 20.145568550356565, 20.511026627986613, 20.87486390518371, 21.23712257862131, 21.597842873566027, 21.95706317506847, 22.314820147928312, 22.671148846599095, 23.026082816056963, 23.379654184535518, 23.73189374892357, 24.082831053531315, 24.432494462850915, 24.780911228868366, 25.128107553423032, 25.474108646058134, 25.81893877775913, 26.16262133093576, 26.50517884596767, 26.846633064601306, 27.187004970457714, 27.52631482688561, 27.864582212371907, 28.201826053701755, 28.5380646570427, 28.87331573711138, 29.20759644456713, 29.540923391764085, 29.87331267698173, 30.204779907243875, 30.53534021982623, 30.86500830254483, 31.193798412909633, 31.52172439622084, 31.84879970267938, 32.17503740357701, 32.500450206626745, 32.82505047048928, 33.14885021854708, 33.4718611519737, 33.7940946621425, 34.11556184241561, 34.43627349935099, 34.75624016336271, 35.07547209886719, 35.39397931394566, 35.7117715695511, 36.02885838828597, 36.34524906277522, 36.66095266365738, 36.975978047215236, 37.29033386266577, 37.604028559128174, 37.9170703922873, 38.229467430768885, 38.541227562241744, 38.852358499261385, 39.1628677848684], [0.0, 0.983967741147443, 1.7131873426422428, 2.3696154037511548, 2.9828324123379892, 3.5657990424927273, 4.125740049061481, 4.667230958848688, 5.193412873557547, 5.706566309934904, 6.2084167300856485, 6.700311731369746, 7.1833306474477014, 7.6583558530139895, 8.12612108051767, 8.587245276881243, 9.04225700500973, 9.491612457310724, 9.935709031201032, 10.374895745908447, 10.809481363106284, 11.239740807005687, 11.665920304007122, 12.088241543848499, 12.506905082955818, 12.92209315380064, 13.333972003526995, 13.742693855776386, 14.148398568114336, 14.551215041462006, 14.951262425901897, 15.348651158075233, 15.743483858359092, 16.135856110560436, 16.525857142600717, 16.913570423302403, 17.299074187716894, 17.682441901295018, 18.063742671478323, 18.443041613892163, 18.820400179182265, 19.195876445601467, 19.569525381682467, 19.94139908269358, 20.31154698404218, 20.68001605434544, 21.04685097051384, 21.412094276877333, 21.775786530116694, 22.137966431535236, 22.498670948012276, 22.857935422813416, 23.215793677290353, 23.57227810437976, 23.927419754704633, 24.28124841598941, 24.633792686420023, 24.985080042510365, 25.335136901975574, 25.68398868205916, 26.031659853714142, 26.37817399199688, 26.7235538229962, 27.06782126758782, 27.41099748227589, 27.75310289735795, 28.094157252627184, 28.434179630805676, 28.773188488884664, 29.111201687531537, 29.448236518709145, 29.784309731640057, 30.119437557236765, 30.45363573110864, 30.786919515246733, 31.119303718479333, 31.45080271578338, 31.781430466529876, 32.111200531735356, 32.44012609038537, 32.768219954891194, 33.095494585735985, 33.42196210536232, 33.747634311349174, 34.07252268892294, 34.39663842284345, 34.71999240870342, 35.04259526367652, 35.36445733674723, 35.68558871845293, 36.00599925016663, 36.3256985329471, 36.644695935980806, 36.96300060463886, 37.28062146817056, 37.5975672470534, 37.913846460018476, 38.229467430768885, 38.54443829440738, 38.85876700358894, 39.17246133441246, 39.48552889206532], [0.0, 0.9919919678228658, 1.727158332746853, 2.3889395445111954, 3.0071573189487353, 3.59487802404816, 4.159385332309215, 4.705292083816748, 5.235764995861768, 5.753103182735074, 6.2590461776319675, 6.754952567527452, 7.241910488014847, 7.7208095095271325, 8.19238934807893, 8.657273998085858, 9.115996332867182, 9.569016265065551, 10.016734432861487, 10.459502701723855, 10.897632351267923, 11.331400547703321, 11.761055525399247, 12.186820781966599, 12.60889850936287, 13.027472426159822, 13.442710135241834, 13.854765101629521, 14.263778323422558, 14.669879752725155, 15.073189511285065, 15.473818936350934, 15.871871485165856, 16.2674435210198, 16.66062499948518, 17.05150007007013, 17.4401476058305, 17.82664167132561, 18.21105193756607, 18.593444051193153, 18.973879963980714, 19.35241822780796, 19.729114259474272, 20.10402057908329, 20.477187025186613, 20.848660949429032, 21.21848739305987, 21.586709247356776, 21.953367399739015, 22.318500867117837, 22.682146917836317, 23.04434118338331, 23.405117760922593, 23.764509307554242, 24.122547127118125, 24.47926125025666, 24.834680508373108, 25.188832602051484, 25.541744164442584, 25.893440820066754, 26.24394723943689, 26.5932871898632, 26.941483582765077, 27.288558517782295, 27.634533323949654, 27.97942859817314, 28.32326424122334, 28.666059491441356, 29.007832956334617, 29.34860264222371, 29.688385982086906, 30.02719986173617, 30.365060644446586, 30.70198419415094, 31.037985897301347, 31.37308068349163, 31.707283044926236, 32.0406070548144, 32.37306638476233, 32.7046743212298, 33.03544378111291, 33.36538732650967, 33.6945171787208, 34.02284523153417, 34.350383063837846, 34.67714195160304, 35.00313287927566, 35.32836655061214, 35.65285339899258, 35.9766035972424, 36.2996270669907, 36.62193348759259, 36.94353230463996, 37.264432738084146, 37.58464378999219, 37.904174251956825, 38.22303271217913, 38.541227562241744, 38.85876700358894, 39.17565905372934, 39.49191155217571, 39.807532166135466], [0.0, 1.0, 1.7411011265922485, 2.4082246852806923, 3.031433133020797, 3.623898318388478, 4.192962712629476, 4.7432763938033675, 5.278031643091579, 5.799546134795289, 6.309573444801933, 6.809483127522303, 7.3003721027184705, 7.783137122039473, 8.25852387298946, 8.727161387290321, 9.189586839976283, 9.646263856416864, 10.097596309015797, 10.543938903738733, 10.98560543306118, 11.422875300666451, 11.855998744839988, 12.285201067417038, 12.71068609258575, 13.132639022018838, 13.551228811604874, 13.96661016523824, 14.378925219250927, 14.788304974808698, 15.19487052336355, 15.598734100953935, 16.000000000000004, 16.39876536170158, 16.795120867813488, 17.189151347155786, 17.580936309501134, 17.97055041730823, 18.358063904019343, 18.743542946219982, 19.127049995800743, 19.508644077311327, 19.888381054913125, 20.266313872687675, 20.642492771517183, 21.016965485301043, 21.3897774188921, 21.76097180981549, 22.130589875561473, 22.498670948012276, 22.86525259636632, 23.23037073975402, 23.59405975059458, 23.95635254961836, 24.317280693371046, 24.676874454922782, 25.035162898423483, 25.392173948075058, 25.747934452029178, 26.102470241664697, 26.45580618665162, 26.80796624616603, 27.158973516583817, 27.508850275948056, 27.857618025475983, 28.205297528345778, 28.55190884598056, 28.89747137202636, 29.242003864203042, 29.58552447419042, 29.9280507756976, 30.269599790850275, 30.610188015018988, 30.94983144020095, 31.288545577058162, 31.626345475706252, 31.963245745340572, 32.299260572778856, 32.6344037399938, 32.96868864070247, 33.30212829607493, 33.63473536961897, 33.966522181293946, 34.29750072090244, 34.62768266080517, 34.95707936800062, 35.28570191560863, 35.61356109379357, 35.94066742016091, 36.26703114965799, 36.59266228400805, 36.9175705807045, 37.24176556159047, 37.56525652104699, 37.88805253381191, 38.210162462449645, 38.531594964491084, 38.852358499261385, 39.17246133441246, 39.49191155217571, 39.810717055349734, 40.12888557303689], [0.0, 1.0079920318251188, 1.7550160622067237, 2.4274712936074923, 3.055660443095618, 3.6528606290800325, 4.226473004070347, 4.781184809697978, 5.32021383995715, 5.8458962920758175, 6.359999756575714, 6.86390473339007, 7.3587169088986055, 7.845340201618074, 8.324526258610895, 8.796909138840492, 9.263030310461065, 9.72335710415084, 10.178296620074653, 10.62820639901952, 11.0734027413004, 11.51416728360374, 11.950752264127317, 12.383384785325818, 12.812270300356788, 13.237595491030609, 13.659530663536685, 14.07823175816785, 14.493842047214184, 14.90649357880693, 15.31630841216483, 15.723399680320323, 16.127872509201904, 16.529824816364954, 16.92934800829577, 17.326527591769036, 17.721443712002053, 18.114171628158257, 18.50478213498783, 18.89334193796165, 19.27991398808782, 19.664557781642113, 20.04732962925408, 20.42828289813604, 20.807468230696934, 21.18493374232699, 21.56072520075609, 21.934886189065047, 22.30745825415561, 22.678481042251665, 23.04799242280586, 23.41602860201544, 23.782624227005087, 24.14781248160867, 24.511625174572814, 24.874092820910985, 25.235244717054712, 25.595109010377026, 25.953712763600866, 26.311082014550294, 26.667241831654515, 27.022216365572095, 27.37602889726591, 27.72870188282586, 28.080256995307586, 28.43071516382926, 28.780096610145524, 29.12842088289705, 29.475706889715998, 29.821972927350977, 30.167236709960743, 30.511515395712358, 30.85482561180789, 31.197183478053095, 31.538604629071685, 31.879104235260296, 32.218697022571426, 32.55739729120431, 32.8952189332776, 33.23217544955139, 33.568279965261354, 33.903545245122416, 34.23798370755544, 34.57160743818593, 34.904428202660434, 35.23645745882288, 35.56770636828982, 35.89818580746098, 36.22790637799885, 36.55687841680863, 36.88511200554766, 37.21261697969155, 37.53940293718231, 37.86547924668195, 38.1908550554539, 38.5155392968925, 38.83954069771988, 39.1628677848684, 39.48552889206532, 39.807532166135466, 40.12888557303689, 40.44959690364315]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 1.7000000000000002\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.019952623149688795, 0.03596462168791317, 0.05076367634561804, 0.0648262638677105, 0.07836542688315395, 0.09150157358062944, 0.10431177463084039, 0.11684940060021166, 0.12915348607498026, 0.14125375446227542, 0.15317355160842663, 0.16493167103832243, 0.17654354763209815, 0.18802207028360313, 0.19937815379651827, 0.210621152693478, 0.22175916781134827, 0.23279927814575477, 0.24374771931645303, 0.2546100231092847, 0.2653911281073648, 0.2760954684936768, 0.2867270461289272, 0.29728948964493074, 0.3077861033362291, 0.31821990794877125, 0.328593674968539, 0.3389099556482867, 0.34917110573890975, 0.35937930668721074, 0.3695365839058538, 0.37964482260124677, 0.3897057815518492, 0.39972110515634074, 0.40969233401336785, 0.4196209142486577, 0.42950820576846077, 0.4393554895885763, 0.4491639743640834, 0.45893480222519406, 0.4686690540084536, 0.4783677539591454, 0.48803187396966347, 0.4976623374093603, 0.5072600225936295, 0.516825765933465, 0.5263603648012247, 0.535864580143663, 0.5453391388693144, 0.5547847360339225, 0.5642020368446875, 0.5735916785016119, 0.5829542718920598, 0.592290403152777, 0.6016006351119998, 0.6108855086228687, 0.6201455437981329, 0.6293812411550551, 0.6385930826784818, 0.6477815328092162, 0.6569470393640988, 0.6660900343935533, 0.6752109349817923, 0.6843101439943604, 0.6933880507772526, 0.7024450318114386, 0.7114814513262697, 0.7204976618749289, 0.7294940048747914, 0.7384708111153172, 0.7474284012358585, 0.7563670861755647, 0.7652871675973778, 0.7741889382879459, 0.7830726825351272, 0.7919386764846243, 0.8007871884771606, 0.8096184793674986, 0.8184328028265004, 0.8272304056273322, 0.8360115279168341, 0.8447764034729981, 0.8535252599494246, 0.8622583191075672, 0.8709757970375107, 0.8796779043679792, 0.8883648464662179, 0.897036823628346, 0.9056940312607427, 0.9143366600529774, 0.9229648961427757, 0.9315789212734641, 0.9401789129443203, 0.9487650445542184, 0.9573374855389362, 0.9658964015024691, 0.9744419543426708, 0.982974302371523, 0.9914936004303154, 1.0000000000000002, 1.0084936493069705], [0.0, 0.03596462168791317, 0.0648262638677105, 0.09150157358062945, 0.11684940060021166, 0.1412537544622754, 0.16493167103832243, 0.18802207028360313, 0.21062115269347798, 0.23279927814575477, 0.2546100231092847, 0.2760954684936768, 0.29728948964493074, 0.31821990794877125, 0.33890995564828674, 0.35937930668721074, 0.3796448226012467, 0.39972110515634074, 0.41962091424865766, 0.43935548958857623, 0.45893480222519406, 0.4783677539591454, 0.4976623374093602, 0.516825765933465, 0.5358645801436629, 0.5547847360339225, 0.5735916785016119, 0.592290403152777, 0.6108855086228687, 0.6293812411550551, 0.6477815328092164, 0.6660900343935533, 0.6843101439943604, 0.7024450318114386, 0.7204976618749289, 0.7384708111153172, 0.7563670861755646, 0.7741889382879459, 0.7919386764846243, 0.8096184793674985, 0.8272304056273321, 0.844776403472998, 0.8622583191075672, 0.8796779043679792, 0.8970368236283461, 0.9143366600529775, 0.9315789212734641, 0.9487650445542183, 0.9658964015024691, 0.982974302371523, 1.0000000000000002, 1.0169746934244948, 1.0338995311986006, 1.0507756144473572, 1.067603999682791, 1.0843857014033182, 1.1011216944972257, 1.1178129164682244, 1.134460269499144, 1.1510646223681158, 1.1676268122301177, 1.1841476462754188, 1.2006279032753076, 1.217068335024463, 1.2334696676884025, 1.2498326030636417, 1.266157819757477, 1.282445974293651, 1.2986977021496025, 1.3149136187304662, 1.3310943202845493, 1.3472403847645815, 1.3633523726386667, 1.3794308276545375, 1.3954762775603975, 1.4114892347853745, 1.4274701970823527, 1.4434196481357342, 1.45933805813647, 1.4752258843265238, 1.4910835715147557, 1.5069115525660675, 1.5227102488655058, 1.5384800707588961, 1.5542214179714637, 1.5699346800057863, 1.585620236520334, 1.601278457689756, 1.6169097045479932, 1.6325143293152242, 1.6480926757095749, 1.663645079244467, 1.6791718675124154, 1.6946733604560325, 1.7101498706269487, 1.7256017034333107, 1.7410291573764731, 1.7564325242774672, 1.7718120894937865, 1.787168132126999, 1.8025009252216608, 1.8178107359559832], [0.0, 0.05076367634561804, 0.09150157358062945, 0.12915348607498028, 0.16493167103832243, 0.19937815379651827, 0.2327992781457548, 0.26539112810736487, 0.29728948964493074, 0.3285936749685389, 0.35937930668721074, 0.38970578155184926, 0.4196209142486578, 0.44916397436408334, 0.4783677539591454, 0.5072600225936295, 0.5358645801436629, 0.5642020368446875, 0.5922904031527769, 0.6201455437981329, 0.6477815328092162, 0.6752109349817923, 0.7024450318114386, 0.7294940048747914, 0.7563670861755647, 0.7830726825351272, 0.8096184793674985, 0.8360115279168342, 0.8622583191075671, 0.8883648464662178, 0.9143366600529775, 0.9401789129443202, 0.9658964015024691, 0.9914936004303153, 1.0169746934244948, 1.0423436000924937, 1.0676039996827908, 1.092759352083354, 1.1178129164682244, 1.1427677679105288, 1.1676268122301179, 1.1923927993028425, 1.217068335024463, 1.2416558920939607, 1.266157819757477, 1.290576352634392, 1.3149136187304662, 1.3391716467289452, 1.363352372638667, 1.387457645868068, 1.4114892347853745, 1.4354488318178307, 1.45933805813647, 1.4831584679674317, 1.5069115525660677, 1.5305987438859712, 1.5542214179714637, 1.5777808980989416, 1.601278457689756, 1.6247153230148874, 1.6480926757095749, 1.671411655114193, 1.6946733604560322, 1.717878852885189, 1.7410291573764731, 1.764125264508112, 1.787168132126999, 1.8101586869093291, 1.8330978258246664, 1.855986417510733, 1.8788253035655964, 1.9016152997633124, 1.9243571971985762, 1.9470517633654585, 1.9696997431748682, 1.9923018599150017, 2.0148588161586973, 2.037371294621282, 2.0598399589722205, 2.0822654546036223, 2.1046484093584055, 2.126989434220719, 2.1492891239710197, 2.171548057808023, 2.193766799939581, 2.215945900144389, 2.2380858943062907, 2.2601873049228183, 2.2822506415894925, 2.3042764014613044, 2.326265069692688, 2.348217119857226, 2.370133014348227, 2.392013204761244, 2.4138581322595387, 2.435668227923422, 2.4574439130843433, 2.4791855996445453, 2.5008936903830596, 2.5225685792487442, 2.544210651641051, 2.5658202846791487], [0.0, 0.0648262638677105, 0.11684940060021166, 0.16493167103832243, 0.21062115269347798, 0.25461002310928466, 0.29728948964493074, 0.33890995564828674, 0.3796448226012467, 0.41962091424865766, 0.45893480222519406, 0.4976623374093602, 0.535864580143663, 0.5735916785016117, 0.6108855086228687, 0.6477815328092162, 0.6843101439943604, 0.7204976618749288, 0.7563670861755645, 0.7919386764846243, 0.8272304056273321, 0.8622583191075672, 0.897036823628346, 0.931578921273464, 0.9658964015024691, 1.0, 1.0338995311986006, 1.067603999682791, 1.1011216944972255, 1.134460269499144, 1.1676268122301179, 1.2006279032753076, 1.2334696676884025, 1.2661578197574768, 1.2986977021496025, 1.3310943202845493, 1.3633523726386667, 1.3954762775603975, 1.4274701970823527, 1.4593380581364699, 1.4910835715147557, 1.5227102488655055, 1.5542214179714637, 1.585620236520334, 1.6169097045479934, 1.6480926757095749, 1.6791718675124154, 1.7101498706269485, 1.7410291573764731, 1.7718120894937863, 1.8025009252216608, 1.8330978258246662, 1.8636048615717187, 1.8940240172417202, 1.9243571971985762, 1.9546062300766205, 1.984772873112892, 2.0148588161586973, 2.0448656853994214, 2.07479504680845, 2.1046484093584055, 2.134427228010494, 2.1641329065006842, 2.1937667999395805, 2.2233302172411995, 2.2528244233944106, 2.2822506415894925, 2.3116100552110996, 2.340903809707903, 2.370133014348227, 2.3992987438701974, 2.428402040034144, 2.457443913084343, 2.4864253431265846, 2.5153472814274953, 2.5442106516410514, 2.5730163509672868, 2.6017652512477847, 2.630458200002169, 2.6590960214095016, 2.6876795172381653, 2.7162094677275457, 2.744686632424579, 2.773111750977996, 2.8014855438928845, 2.8298087132480014, 2.85808194337809, 2.8863059015232992, 2.9144812384476397, 2.94260858902831, 2.9706885728175507, 2.9987217945786147, 3.0267088447973123, 3.0546503001704988, 3.082546724072778, 3.110398667002616, 3.1382066670089808, 3.165971250099551, 3.1936929306314736, 3.2213722116855825, 3.249009585424943, 3.2766055334385276], [0.0, 0.07836542688315395, 0.1412537544622754, 0.19937815379651827, 0.25461002310928466, 0.30778610333622897, 0.3593793066872107, 0.40969233401336785, 0.458934802225194, 0.5072600225936293, 0.5547847360339224, 0.6016006351119997, 0.6477815328092162, 0.6933880507772525, 0.7384708111153171, 0.783072682535127, 0.827230405627332, 0.8709757970375106, 0.9143366600529773, 0.957337485538936, 0.9999999999999999, 1.0423436000924935, 1.084385701403318, 1.1261420215411435, 1.1676268122301177, 1.2088530513353746, 1.2498326030636415, 1.290576352634392, 1.331094320284549, 1.3713957584027912, 1.4114892347853742, 1.4513827043927483, 1.4910835715147557, 1.5305987438859707, 1.569934680005786, 1.6090974306911636, 1.6480926757095746, 1.6869257561950164, 1.7256017034333104, 1.7641252645081118, 1.8025009252216604, 1.8407329306407139, 1.8788253035655962, 1.9167818611767238, 1.9546062300766205, 1.9923018599150013, 2.0298720357589026, 2.0673198893481826, 2.1046484093584055, 2.141860450777469, 2.1789587434890403, 2.2159459001443884, 2.25282442339441, 2.2895967125451375, 2.326265069692688, 2.3628317053872556, 2.3992987438701974, 2.4356682279234216, 2.471942123366092, 2.5081223232299155, 2.5442106516410505, 2.580208867433791, 2.6161186675186445, 2.6519416900252017, 2.687679517238165, 2.7233336783431885, 2.758905651997574, 2.7943968687394714, 2.8298087132480014, 2.8651425264655628, 2.9003996075926195, 2.9355812159643233, 2.9706885728175507, 3.005722862956177, 3.0406852363217665, 3.075576809476246, 3.1103986670026154, 3.1451518628292314, 3.1798374214827785, 3.21445633927463, 3.2490095854249423, 3.2834981031284767, 3.317922810565866, 3.3522846018637336, 3.3865843480068545, 3.420822897705276, 3.455001078219141, 3.4891196961437387, 3.52317953815713, 3.5571813717325536, 3.591125945817625, 3.625013991482248, 3.6588462225369973, 3.692623336123625, 3.7263460132792403, 3.760014919475593, 3.793630705134822, 3.8271940061229124, 3.8607054442220714, 3.8941656275831, 3.927575151158822, 3.960934597119536], [0.0, 0.09150157358062944, 0.16493167103832243, 0.2327992781457548, 0.29728948964493074, 0.3593793066872107, 0.4196209142486577, 0.4783677539591454, 0.5358645801436629, 0.592290403152777, 0.6477815328092162, 0.7024450318114386, 0.7563670861755647, 0.8096184793674984, 0.8622583191075672, 0.9143366600529774, 0.965896401502469, 1.0169746934244948, 1.0676039996827908, 1.1178129164682244, 1.1676268122301179, 1.217068335024463, 1.2661578197574768, 1.3149136187304662, 1.3633523726386667, 1.4114892347853742, 1.45933805813647, 1.5069115525660677, 1.5542214179714635, 1.601278457689756, 1.6480926757095749, 1.6946733604560322, 1.7410291573764731, 1.7871681321269988, 1.8330978258246662, 1.8788253035655964, 1.924357197198576, 1.9696997431748682, 2.0148588161586973, 2.05983995897222, 2.1046484093584055, 2.1492891239710192, 2.193766799939581, 2.2380858943062902, 2.2822506415894925, 2.326265069692688, 2.370133014348227, 2.4138581322595383, 2.4574439130843433, 2.5008936903830596, 2.544210651641051, 2.5873978474599912, 2.6304582000021686, 2.673394510761636, 2.7162094677275457, 2.7589056519975745, 2.8014855438928845, 2.843951528620405, 2.886305901523299, 2.928550872956144, 2.9706885728175507, 3.0127210547696, 3.0546503001704988, 3.096478221744278, 3.1382066670089808, 3.1798374214827785, 3.2213722116855825, 3.262812707952092, 3.3041605270707755, 3.345417234761931, 3.386584348006855, 3.427663337239036, 3.468655628407395, 3.5095626049207045, 3.550385609481567, 3.591125945817626, 3.631784880317072, 3.6723636435749127, 3.7128634318559746, 3.7532854084801306, 3.793630705134822, 3.833900423119542, 3.874095634526615, 3.914217383362261, 3.9542666866116556, 3.994244535251406, 4.034151895212636, 4.073989708297631, 4.113758893052789, 4.15346034560044, 4.1930949404319, 4.232663531163992, 4.272166951261083, 4.311606014724571, 4.350981516751648, 4.39029423436497, 4.429544927014867, 4.46873433715551, 4.507863190796479, 4.546932198030952, 4.585942053541799, 4.62489343708667], [0.0, 0.10431177463084039, 0.18802207028360313, 0.26539112810736487, 0.33890995564828674, 0.40969233401336785, 0.4783677539591454, 0.5453391388693145, 0.6108855086228688, 0.6752109349817923, 0.7384708111153172, 0.8007871884771606, 0.8622583191075673, 0.9229648961427757, 0.982974302371523, 1.0423436000924937, 1.1011216944972257, 1.159350936541939, 1.217068335024463, 1.2743064895963698, 1.3310943202845493, 1.387457645868068, 1.4434196481357342, 1.499001248707177, 1.554221417971464, 1.609097430691164, 1.6636450792444673, 1.7178788528851892, 1.7718120894937863, 1.8254571048722776, 1.8788253035655966, 1.9319272743764166, 1.9847728731128922, 2.0373712946212814, 2.0897311357734436, 2.1418604507774694, 2.193766799939581, 2.245457292812905, 2.2969386265134233, 2.3482171198572264, 2.399298743870198, 2.450189149136588, 2.5008936903830596, 2.551417448636785, 2.601765251247785, 2.6519416900252026, 2.7019511377031113, 2.7517977629226493, 2.801485543892885, 2.851018280871994, 2.90039960759262, 2.949633001740029, 2.9987217945786147, 3.0476691798110087, 3.0964782217442783, 3.1451518628292323, 3.1936929306314736, 3.2421041442864, 3.2903881204847343, 3.33854737903023, 3.386584348006855, 3.434501368588949, 3.4823006995244516, 3.5299845213183554, 3.5775549401408413, 3.625013991482249, 3.6723636435749127, 3.71960580060004, 3.766742305696144, 3.8137749437840354, 3.860705444222072, 3.9075354833041223, 3.954266686611656, 4.000900631230383, 4.047438847840986, 4.0938828226927075, 4.1402339994678155, 4.18649378104436, 4.232663531163994, 4.278744576011125, 4.3247382057092, 4.370645675739407, 4.416468208286774, 4.462206993518168, 4.507863190796479, 4.5534379298348275, 4.598932311794494, 4.6443474103298845, 4.6896842725836985, 4.734943920135205, 4.780127349904322, 4.825235535014045, 4.870269425613576, 4.915229949664342, 4.9601180136909715, 5.00493450349913, 5.049680284862032, 5.09435620417728, 5.138963089095638, 5.183501749123183, 5.227972976198239, 5.272377545244385], [0.0, 0.11684940060021166, 0.21062115269347798, 0.29728948964493074, 0.3796448226012467, 0.458934802225194, 0.5358645801436629, 0.6108855086228688, 0.6843101439943604, 0.7563670861755646, 0.8272304056273321, 0.8970368236283459, 0.9658964015024691, 1.0338995311986006, 1.1011216944972255, 1.1676268122301177, 1.2334696676884023, 1.2986977021496025, 1.3633523726386665, 1.4274701970823527, 1.4910835715147557, 1.5542214179714637, 1.6169097045479932, 1.6791718675124154, 1.741029157376473, 1.8025009252216606, 1.8636048615717187, 1.924357197198576, 1.9847728731128917, 2.044865685399421, 2.1046484093584055, 2.1641329065006842, 2.2233302172411995, 2.282250641589492, 2.340903809707903, 2.3992987438701974, 2.457443913084343, 2.5153472814274953, 2.5730163509672868, 2.6304582000021686, 2.687679517238165, 2.7446866324245787, 2.8014855438928845, 2.85808194337809, 2.9144812384476397, 2.9706885728175507, 3.0267088447973123, 3.0825467240727775, 3.1382066670089808, 3.193692930631473, 3.249009585424943, 3.304160527070775, 3.359149487230608, 3.413980043470247, 3.468655628407395, 3.5231795381571303, 3.577554940140841, 3.6317848803170714, 3.6858722898864817, 3.739819991517549, 3.7936307051348215, 3.84730705330722, 3.9008515662701244, 3.954266686611655, 4.007554773650537, 4.060718107530379, 4.113758893052789, 4.166679263269701, 4.219481282853406, 4.272166951261082, 4.324738205709199, 4.377196923971713, 4.429544927014866, 4.481783981480254, 4.533915802026849, 4.585942053541799, 4.637864353228995, 4.689684272583698, 4.741403339260813, 4.793023038843863, 4.844544816521099, 4.895970078674734, 4.947300194388828, 4.998536496880897, 5.049680284862031, 5.100732823829839, 5.151695347298329, 5.202569057968486, 5.253355128843041, 5.304054704288734, 5.35466890104905, 5.405198809210311, 5.455645493123739, 5.506009992285947, 5.556293322180181, 5.6064964750804345, 5.656620420820472, 5.706666107529618, 5.756634462337108, 5.806526392046609, 5.856342783782503, 5.906084505609358], [0.0, 0.12915348607498026, 0.23279927814575477, 0.3285936749685389, 0.41962091424865766, 0.5072600225936293, 0.592290403152777, 0.6752109349817923, 0.7563670861755646, 0.836011527916834, 0.9143366600529774, 0.9914936004303153, 1.067603999682791, 1.1427677679105286, 1.217068335024463, 1.290576352634392, 1.3633523726386667, 1.4354488318178305, 1.5069115525660672, 1.5777808980989416, 1.6480926757095749, 1.717878852885189, 1.7871681321269988, 1.855986417510733, 1.924357197198576, 1.9923018599150015, 2.05983995897222, 2.126989434220719, 2.1937667999395805, 2.260187304922818, 2.326265069692688, 2.3920132047612435, 2.457443913084343, 2.522568579248744, 2.5873978474599912, 2.651941690025202, 2.7162094677275457, 2.7802099832508427, 2.843951528620405, 2.9074419274700354, 2.9706885728175507, 3.0336984609263813, 3.096478221744278, 3.1590341463383256, 3.2213722116855825, 3.283498103128477, 3.3454172347619315, 3.4071347679834685, 3.468655628407395, 3.5299845213183554, 3.5911259458176255, 3.652084207796628, 3.7128634318559737, 3.773467572274362, 3.8339004231195424, 3.8941656275831003, 3.9542666866116556, 4.014206966899111, 4.07398970829763, 4.133618030698907, 4.1930949404319, 4.252423336218528, 4.311606014724571, 4.370645675739407, 4.429544927014866, 4.488306288790625, 4.546932198030952, 4.605425012395293, 4.663787013963168, 4.722020412731921, 4.780127349904321, 4.838109900981409, 4.895970078674735, 4.95370983565089, 5.011331067120142, 5.068835613280024, 5.126225261623835, 5.183501749123182, 5.240666764292988, 5.29772194914673, 5.35466890104905, 5.411509174472325, 5.46824428266333, 5.524875699225608, 5.581404859622783, 5.63783316260767, 5.694161971581651, 5.750392615888513, 5.806526392046608, 5.86256456492296, 5.918508368852647, 5.9743590087066245, 6.030117660910871, 6.085785474419602, 6.1413635716450905, 6.196853049346452, 6.25225497947965, 6.307570410010758, 6.3628003656944765, 6.417945848819687, 6.473007839923781, 6.527987298477363], [0.0, 0.14125375446227542, 0.2546100231092847, 0.35937930668721074, 0.45893480222519406, 0.5547847360339224, 0.6477815328092162, 0.7384708111153172, 0.8272304056273321, 0.9143366600529774, 1.0, 1.0843857014033182, 1.1676268122301179, 1.2498326030636415, 1.3310943202845493, 1.4114892347853742, 1.4910835715147557, 1.5699346800057863, 1.6480926757095746, 1.7256017034333104, 1.8025009252216606, 1.8788253035655964, 1.9546062300766205, 2.0298720357589026, 2.1046484093584055, 2.1789587434890403, 2.2528244233944106, 2.326265069692688, 2.3992987438701974, 2.4719421233660923, 2.544210651641051, 2.616118667518645, 2.6876795172381653, 2.758905651997574, 2.8298087132480014, 2.9003996075926195, 2.9706885728175507, 3.040685236321767, 3.110398667002616, 3.1798374214827785, 3.2490095854249423, 3.317922810565866, 3.386584348006855, 3.4550010782191416, 3.5231795381571307, 3.5911259458176255, 3.6588462225369978, 3.7263460132792403, 3.7936307051348224, 3.8607054442220714, 3.9275751511588224, 3.994244535251406, 4.060718107530379, 4.127000192747083, 4.193094940431901, 4.259006335103603, 4.324738205709199, 4.39029423436497, 4.455677964461778, 4.520892808191024, 4.585942053541798, 4.650828870814541, 4.715556318692015, 4.780127349904321, 4.844544816521099, 4.908811474900906, 4.9729299903248965, 5.036902941339409, 5.10073282382984, 5.164422054846104, 5.227972976198238, 5.2913878578390205, 5.35466890104905, 5.417818241438408, 5.480837951777828, 5.543730044671217, 5.6064964750804345, 5.66913914271232, 5.731659894277168, 5.794060525627153, 5.856342783782503, 5.918508368852647, 5.980558935859026, 6.042496096465706, 6.10432142062355, 6.166036438133203, 6.227642640131838, 6.289141480508209, 6.35053437725025, 6.411822713729184, 6.47300783992378, 6.534091073588217, 6.595073701366716, 6.65595697985793, 6.716742136631877, 6.777430371202005, 6.838022855954818, 6.898520737039344, 6.958925135218586, 7.019237146684927, 7.07945784384138, 7.13958827605045], [0.0, 0.15317355160842663, 0.2760954684936768, 0.38970578155184926, 0.4976623374093602, 0.6016006351119997, 0.7024450318114386, 0.8007871884771606, 0.8970368236283459, 0.9914936004303153, 1.0843857014033182, 1.1758923494079665, 1.266157819757477, 1.355300603909902, 1.4434196481357342, 1.530598743885971, 1.6169097045479932, 1.7024147191354686, 1.7871681321269985, 1.871217813520291, 1.9546062300766205, 2.0373712946212814, 2.1195470477689318, 2.2011642112553993, 2.2822506415894925, 2.362831705387256, 2.442930592501074, 2.5225685792487442, 2.6017652512477842, 2.6805386932747477, 2.7589056519975745, 2.83688167623152, 2.9144812384476397, 2.9917178405469684, 3.0686041063526557, 3.145151862829232, 3.221372211685582, 3.2972755927354935, 3.3728718401615776, 3.448170232643122, 3.5231795381571303, 3.5979080541375352, 3.6723636435749127, 3.7465537675538845, 3.820485514654339, 3.8941656275831003, 3.9676005273526638, 4.040796335281268, 4.113758893052789, 4.18649378104436, 4.259006335103603, 4.331301661934967, 4.403384653235485, 4.475259998703675, 4.546932198030952, 4.618405571972496, 4.689684272583698, 4.760772292698802, 4.831673474720194, 4.902391518779441, 4.9729299903248965, 5.0432923271850285, 5.11348184615169, 5.183501749123182, 5.253355128843041, 5.323044974267076, 5.392574175588059, 5.461945528944772, 5.531161740839649, 5.600225432287059, 5.66913914271232, 5.737905333619768, 5.806526392046609, 5.8750046338178805, 5.943342306616526, 6.011541592881446, 6.079604612545328, 6.147533425623105, 6.215330034661016, 6.28299638705548, 6.35053437725025, 6.417945848819687, 6.485232596445373, 6.5523963677927775, 6.6194388652941685, 6.686361747843491, 6.7531666324085755, 6.819855095565598, 6.886428674960397, 6.952888870700948, 7.019237146684927, 7.08547493186612, 7.151603621463124, 7.217624578113552, 7.283539132976781, 7.349348586788038, 7.4150542108664865, 7.480657248079745, 7.546158913767188, 7.611560396624161, 7.676862859549159, 7.742067440455875], [0.0, 0.16493167103832243, 0.29728948964493074, 0.4196209142486578, 0.535864580143663, 0.6477815328092162, 0.7563670861755647, 0.8622583191075673, 0.9658964015024691, 1.067603999682791, 1.1676268122301179, 1.266157819757477, 1.363352372638667, 1.45933805813647, 1.554221417971464, 1.6480926757095749, 1.7410291573764731, 1.8330978258246664, 1.924357197198576, 2.0148588161586973, 2.1046484093584055, 2.193766799939581, 2.2822506415894925, 2.3701330143482275, 2.4574439130843433, 2.5442106516410514, 2.630458200002169, 2.716209467727546, 2.8014855438928845, 2.8863059015232992, 2.970688572817551, 3.054650300170499, 3.138206667008981, 3.2213722116855825, 3.3041605270707755, 3.386584348006855, 3.468655628407395, 3.5503856094815673, 3.6317848803170723, 3.7128634318559746, 3.7936307051348224, 3.8740956345266153, 3.954266686611656, 4.034151895212636, 4.11375889305279, 4.193094940431901, 4.272166951261084, 4.350981516751648, 4.429544927014867, 4.507863190796479, 4.585942053541799, 4.663787013963168, 4.741403339260813, 4.818796079130358, 4.895970078674736, 4.972929990324897, 5.049680284862032, 5.126225261623836, 5.202569057968486, 5.2787156580621515, 5.35466890104905, 5.430432488656981, 5.506009992285947, 5.581404859622784, 5.656620420820472, 5.731659894277168, 5.80652639204661, 5.881222924908638, 5.9557524071259635, 6.0301176609108715, 6.104321420623551, 6.178366336721727, 6.252254979479651, 6.325989842492912, 6.399573345984194, 6.473007839923782, 6.54629560697756, 6.619438865294169, 6.692439771142064, 6.765300421406394, 6.838022855954818, 6.9106090598806915, 6.983060965631421, 7.055380455029184, 7.1275693611907, 7.199629470352222, 7.271562523605493, 7.343370218550004, 7.4150542108664865, 7.486616115816271, 7.558057509670765, 7.6293799310750785, 7.700584882349503, 7.771673830732317, 7.84264820956719, 7.913509419438181, 7.984258829255211, 8.054897777292613, 8.12542757218332, 8.19584949387095, 8.266164794522014, 8.33637469940031], [0.0, 0.17654354763209815, 0.31821990794877125, 0.44916397436408334, 0.5735916785016117, 0.6933880507772525, 0.8096184793674984, 0.9229648961427757, 1.0338995311986006, 1.1427677679105286, 1.2498326030636415, 1.355300603909902, 1.45933805813647, 1.5620815356808382, 1.6636450792444668, 1.7641252645081118, 1.8636048615717187, 1.962155547751517, 2.0598399589722196, 2.1567132688531085, 2.25282442339441, 2.348217119857226, 2.4429305925010736, 2.5370002503386426, 2.6304582000021686, 2.723333678343189, 2.8156534133363835, 2.9074419274700354, 2.998721794578614, 3.0895138586693083, 3.1798374214827785, 3.2697104041482135, 3.3591494872306074, 3.448170232643121, 3.5367871902509234, 3.625013991482248, 3.7128634318559737, 3.800347544009218, 3.88747766254556, 3.974264481810999, 4.060718107530379, 4.146848103093769, 4.232663531163992, 4.318172991178318, 4.403384653235485, 4.488306288790625, 4.5729452985229875, 4.657308737692616, 4.741403339260813, 4.825235535014044, 4.908811474900906, 4.99213704476599, 5.075217882642358, 5.158059393745237, 5.240666764292987, 5.323044974267076, 5.405198809210311, 5.487132871151667, 5.568851588736571, 5.650359226633084, 5.731659894277167, 5.812757554013674, 5.8936560286840445, 5.974359008706624, 6.054870058691036, 6.135192623624073, 6.215330034661015, 6.295285514553146, 6.375062182739407, 6.4546630601275865, 6.534091073588217, 6.613349060182289, 6.6924397711420625, 6.771365875622647, 6.85012996424048, 6.928734552413545, 7.00718208351691, 7.08547493186612, 7.16361540553991, 7.2416057490528765, 7.319448145887858, 7.397144720897051, 7.474697542580208, 7.552108625247627, 7.629379931075078, 7.706513372057285, 7.783510811866104, 7.860374067619099, 7.937104911563822, 8.013705072682729, 8.090176238223298, 8.166520055157665, 8.242738131575727, 8.31883203801545, 8.394803308733865, 8.470653442921984, 8.546383905866685, 8.621996130062394, 8.69749151627525, 8.77287143456223, 8.848137225247587, 8.92329019985879], [0.0, 0.18802207028360313, 0.33890995564828674, 0.4783677539591454, 0.6108855086228687, 0.7384708111153171, 0.8622583191075672, 0.982974302371523, 1.1011216944972255, 1.217068335024463, 1.3310943202845493, 1.4434196481357342, 1.554221417971464, 1.6636450792444668, 1.7718120894937863, 1.8788253035655964, 1.984772873112892, 2.0897311357734436, 2.1937667999395805, 2.296938626513423, 2.399298743870198, 2.5008936903830596, 2.6017652512477847, 2.701951137703111, 2.8014855438928845, 2.90039960759262, 2.9987217945786147, 3.0964782217442783, 3.193692930631473, 3.2903881204847343, 3.386584348006855, 3.4823006995244516, 3.5775549401408413, 3.6723636435749123, 3.7667423056961438, 3.8607054442220714, 3.9542666866116556, 4.047438847840986, 4.1402339994678155, 4.232663531163993, 4.324738205709199, 4.416468208286773, 4.507863190796479, 4.598932311794493, 4.6896842725836985, 4.780127349904322, 4.870269425613576, 4.960118013690971, 5.049680284862032, 5.138963089095637, 5.227972976198239, 5.316716214700746, 5.405198809210311, 5.493426516378882, 5.581404859622784, 5.66913914271232, 5.756634462337107, 5.843895719741216, 5.930927631512095, 6.017734739598339, 6.10432142062355, 6.19069189455664, 6.27685023279286, 6.3628003656944765, 6.4485460896351885, 6.534091073588217, 6.6194388652941685, 6.704592897041428, 6.78955649108887, 6.87433286475791, 6.958925135218586, 7.043336323992149, 7.1275693611907, 7.211627089512691, 7.2955122680114695, 7.379227575652668, 7.4627756146749125, 7.546158913767187, 7.629379931075079, 7.712441057047214, 7.7953446171322955, 7.878092874336331, 7.960688031648958, 8.043132234347063, 8.125427572183318, 8.207576081466678, 8.289579747041365, 8.371440504170439, 8.453160240329586, 8.534740796916383, 8.616183970879904, 8.69749151627525, 8.778665145747235, 8.859706531947193, 8.9406173088866, 9.021399073230993, 9.10205338553739, 9.182581771438253, 9.26298572277485, 9.343266698682632, 9.423426126631163, 9.503465403420911], [0.0, 0.19937815379651827, 0.35937930668721074, 0.5072600225936295, 0.6477815328092162, 0.783072682535127, 0.9143366600529774, 1.0423436000924937, 1.1676268122301177, 1.290576352634392, 1.4114892347853742, 1.530598743885971, 1.6480926757095749, 1.7641252645081118, 1.8788253035655964, 1.9923018599150013, 2.1046484093584055, 2.215945900144389, 2.3262650696926874, 2.4356682279234216, 2.544210651641051, 2.651941690025202, 2.758905651997574, 2.865142526465563, 2.9706885728175507, 3.075576809476246, 3.1798374214827785, 3.283498103128477, 3.3865843480068545, 3.4891196961437387, 3.5911259458176255, 3.692623336123625, 3.793630705134822, 3.8941656275831, 3.994244535251406, 4.093882822692707, 4.1930949404319, 4.291894477438996, 4.39029423436497, 4.488306288790625, 4.585942053541798, 4.6832123289625525, 4.780127349904321, 4.876696828078179, 4.9729299903248965, 5.068835613280023, 5.164422054846104, 5.259697282829045, 5.35466890104905, 5.44934417319674, 5.543730044671217, 5.63783316260767, 5.7316598942771675, 5.8252163440196725, 5.918508368852648, 6.0115415928814455, 6.10432142062355, 6.196853049346452, 6.289141480508208, 6.38119153038025, 6.47300783992378, 6.564594883983743, 6.655956979857929, 6.747098295293089, 6.838022855954817, 6.928734552413545, 7.019237146684927, 7.109534278359362, 7.199629470352222, 7.289526134303437, 7.379227575652667, 7.46873699841382, 7.558057509670764, 7.647192123814141, 7.736143766537524, 7.824915278609665, 7.9135094194381805, 8.001928870438825, 8.0901762382233, 8.178254057617615, 8.266164794522012, 8.353910848622656, 8.44149455596449, 8.528918191393991, 8.616183970879902, 8.703294053719368, 8.790250544636455, 8.877055495779487, 8.963710908623169, 9.050218735781089, 9.136580882733744, 9.222799209476978, 9.308875532095252, 9.39481162426404, 9.480609218685208, 9.566270008459073, 9.651795648396565, 9.737187756274698, 9.82244791403839, 9.907577668951381, 9.992578534698985, 10.077451992445079], [0.0, 0.210621152693478, 0.3796448226012467, 0.5358645801436629, 0.6843101439943604, 0.827230405627332, 0.965896401502469, 1.1011216944972257, 1.2334696676884023, 1.3633523726386667, 1.4910835715147557, 1.6169097045479932, 1.7410291573764731, 1.8636048615717187, 1.984772873112892, 2.1046484093584055, 2.2233302172411995, 2.340903809707903, 2.4574439130843424, 2.5730163509672868, 2.6876795172381653, 2.8014855438928845, 2.9144812384476397, 3.0267088447973123, 3.1382066670089808, 3.249009585424943, 3.359149487230608, 3.468655628407395, 3.577554940140841, 3.6858722898864817, 3.7936307051348224, 3.900851566270125, 4.007554773650538, 4.113758893052789, 4.219481282853405, 4.324738205709199, 4.429544927014866, 4.533915802026849, 4.637864353228996, 4.741403339260813, 4.844544816521099, 4.947300194388827, 5.049680284862031, 5.15169534729833, 5.253355128843042, 5.35466890104905, 5.455645493123739, 5.5562933221801805, 5.656620420820472, 5.756634462337107, 5.8563427837825035, 5.955752407125962, 6.054870058691037, 6.153702187043406, 6.25225497947965, 6.35053437725025, 6.4485460896351885, 6.5462956069775595, 6.643788212769264, 6.7410289948728455, 6.838022855954817, 6.934774523198084, 7.031288557354264, 7.127569361190699, 7.2236211873815765, 7.319448145887859, 7.415054210866486, 7.510443227145544, 7.605618916298742, 7.700584882349502, 7.7953446171322955, 7.889901505336419, 7.984258829255209, 8.078419773261775, 8.172387428030502, 8.266164794522014, 8.359754787747823, 8.453160240329586, 8.546383905866687, 8.639428462124798, 8.732296514057081, 8.824990596668776, 8.917513177735163, 9.009866660382055, 9.10205338553739, 9.194075634261779, 9.285935629965364, 9.377635540517778, 9.469177480257539, 9.560563511906745, 9.651795648396565, 9.742875854608604, 9.833806049036921, 9.924588105375129, 10.01522385403271, 10.105715083584462, 10.19606354215664, 10.28627093875323, 10.376338944525534, 10.466269193988003, 10.556063286183157, 10.645722785798181], [0.0, 0.22175916781134827, 0.39972110515634074, 0.5642020368446875, 0.7204976618749288, 0.8709757970375106, 1.0169746934244948, 1.159350936541939, 1.2986977021496025, 1.4354488318178305, 1.5699346800057863, 1.7024147191354686, 1.8330978258246664, 1.962155547751517, 2.0897311357734436, 2.215945900144389, 2.340903809707903, 2.4646948994848707, 2.5873978474599912, 2.709081958097014, 2.8298087132480014, 2.949633001740029, 3.0686041063526557, 3.186766504911847, 3.3041605270707755, 3.4208228977052766, 3.536787190250924, 3.6520842077966282, 3.7667423056961433, 3.88078766643957, 3.9942445352514064, 4.107135423148048, 4.219481282853406, 4.331301661934966, 4.442614836710587, 4.5534379298348275, 4.663787013963168, 4.773677203483132, 4.883122735971176, 4.9921370447659905, 5.100732823829839, 5.208922085889622, 5.3167162147007465, 5.424126012153614, 5.531161740839649, 5.63783316260767, 5.744149573569001, 5.850119835948382, 5.955752407125963, 6.061055366171375, 6.166036438133204, 6.270703016314776, 6.375062182739407, 6.47912072698421, 6.582885163540838, 6.686361747843492, 6.789556491088869, 6.892475173959018, 6.995123359346134, 7.097506404167836, 7.199629470352221, 7.301497535063899, 7.403115400235013, 7.504487701458947, 7.6056189162987415, 7.706513372057286, 7.807175253051894, 7.9076086074318885, 8.00781735357431, 8.107805286089643, 8.207576081466678, 8.307133303383006, 8.406480407705375, 8.50562074720212, 8.604557575987894, 8.70329405371937, 8.801833249558971, 8.900178145922343, 8.998331642024025, 9.096296557234623, 9.194075634261779, 9.291671542166249, 9.389086879223585, 9.486324175641101, 9.583385896139099, 9.680274442404668, 9.776992155425766, 9.873541317712773, 9.969924155414118, 10.066142840332258, 10.162199491845685, 10.258096178742383, 10.353834920969732, 10.449417691305538, 10.544846416954547, 10.640122981074517, 10.73524922423568, 10.830226945817143, 10.925057905343614, 11.019743823765529, 11.114286384685572, 11.208687235534326], [0.0, 0.23279927814575477, 0.41962091424865766, 0.5922904031527769, 0.7563670861755645, 0.9143366600529773, 1.0676039996827908, 1.217068335024463, 1.3633523726386665, 1.5069115525660672, 1.6480926757095746, 1.7871681321269985, 1.924357197198576, 2.0598399589722196, 2.1937667999395805, 2.3262650696926874, 2.4574439130843424, 2.5873978474599912, 2.7162094677275452, 2.8439515286204045, 2.9706885728175507, 3.0964782217442774, 3.221372211685582, 3.345417234761931, 3.4686556284073946, 3.591125945817625, 3.7128634318559737, 3.833900423119542, 3.954266686611655, 4.07398970829763, 4.1930949404319, 4.31160601472457, 4.429544927014866, 4.546932198030951, 4.663787013963167, 4.780127349904321, 4.895970078674734, 5.011331067120141, 5.126225261623835, 5.240666764292987, 5.354668901049049, 5.4682442826633295, 5.581404859622783, 5.69416197158165, 5.806526392046609, 5.918508368852647, 6.030117660910871, 6.14136357164509, 6.25225497947965, 6.362800365694476, 6.47300783992378, 6.582885163540836, 6.6924397711420625, 6.80167879031847, 6.910609059880691, 7.019237146684926, 7.127569361190699, 7.235611771866882, 7.343370218550002, 7.450850324847718, 7.558057509670763, 7.6649969979680765, 7.771673830732315, 7.87809287433633, 7.984258829255208, 8.090176238223298, 8.195849493870949, 8.301282845881493, 8.406480407705375, 8.511446162864855, 8.616183970879902, 8.720697572843065, 8.824990596668776, 8.929066562040369, 9.032928885076105, 9.136580882733746, 9.240025776971612, 9.343266698682632, 9.446306691416517, 9.54914871490408, 9.651795648396563, 9.75425029383187, 9.856515378838708, 9.958593559588826, 10.060487423506737, 10.162199491845685, 10.26373222213792, 10.36508801052685, 10.466269193988003, 10.567278052445356, 10.668116810789037, 10.768787640800053, 10.86929266298732, 10.969633948341874, 11.069813520012875, 11.169833354909647, 11.269695385233803, 11.369401499945159, 11.468953546165013, 11.56835333052, 11.667602620429676, 11.766703145340696], [0.0, 0.24374771931645303, 0.43935548958857623, 0.6201455437981329, 0.7919386764846243, 0.957337485538936, 1.1178129164682244, 1.2743064895963698, 1.4274701970823527, 1.5777808980989416, 1.7256017034333104, 1.871217813520291, 2.0148588161586973, 2.1567132688531085, 2.296938626513423, 2.4356682279234216, 2.5730163509672868, 2.709081958097014, 2.8439515286204045, 2.977701238891943, 3.110398667002616, 3.2421041442863996, 3.3728718401615776, 3.502750642657204, 3.631784880317072, 3.7600149194755934, 3.8874776625455603, 4.014206966899111, 4.140233999467815, 4.265587538869084, 4.39029423436497, 4.5143788290538565, 4.637864353228996, 4.760772292698801, 4.883122735971176, 5.004934503499129, 5.126225261623835, 5.247011623401359, 5.367309238136412, 5.487132871151668, 5.6064964750804345, 5.725413253772695, 5.843895719741216, 5.961955745938875, 6.079604612545329, 6.196853049346452, 6.313711274210377, 6.430189028096582, 6.54629560697756, 6.662039891003862, 6.777430371202006, 6.892475173959017, 7.00718208351691, 7.121558562673967, 7.235611771866883, 7.349348586788038, 7.4627756146749125, 7.575899209393634, 7.6887254854255085, 7.801260330853834, 7.91350941943818, 8.025478221854392, 8.137172016170652, 8.248595897623051, 8.359754787747823, 8.470653442921984, 8.581296462359237, 8.691688295603536, 8.801833249558971, 8.911735495090994, 9.021399073230993, 9.13082790101335, 9.240025776971613, 9.34899638631818, 9.457743305829757, 9.566270008459075, 9.674579867691648, 9.782676161664837, 9.89056207706507, 9.998240712817918, 10.105715083584462, 10.212988123076432, 10.320062687201641, 10.426941557050352, 10.533627441732444, 10.640122981074516, 10.746430748185418, 10.852553251898058, 10.958492939094828, 11.064252196923471, 11.169833354909649, 11.275238686972216, 11.380470413346632, 11.485530702421675, 11.59042167249426, 11.695145393446833, 11.799703888351544, 11.904099135005108, 12.008333067398073, 12.112407577121878, 12.216324514716996, 12.320085690965149], [0.0, 0.2546100231092847, 0.45893480222519406, 0.6477815328092162, 0.8272304056273321, 0.9999999999999999, 1.1676268122301179, 1.3310943202845493, 1.4910835715147557, 1.6480926757095749, 1.8025009252216606, 1.9546062300766205, 2.1046484093584055, 2.25282442339441, 2.399298743870198, 2.544210651641051, 2.6876795172381653, 2.8298087132480014, 2.9706885728175507, 3.110398667002616, 3.2490095854249423, 3.386584348006855, 3.5231795381571303, 3.6588462225369978, 3.7936307051348224, 3.927575151158822, 4.060718107530379, 4.193094940431901, 4.324738205709199, 4.455677964461778, 4.585942053541799, 4.715556318692015, 4.8445448165211, 4.9729299903248965, 5.10073282382984, 5.227972976198238, 5.35466890104905, 5.480837951777828, 5.6064964750804345, 5.7316598942771675, 5.856342783782503, 5.980558935859026, 6.10432142062355, 6.227642640131838, 6.350534377250251, 6.473007839923781, 6.595073701366716, 6.716742136631877, 6.838022855954818, 6.958925135218586, 7.07945784384138, 7.199629470352221, 7.319448145887859, 7.438921665816589, 7.558057509670765, 7.676862859549158, 7.7953446171322955, 7.9135094194381805, 8.03136365343212, 8.148913469592273, 8.266164794522012, 8.383123342690821, 8.499794627377206, 8.616183970879902, 8.732296514057081, 8.848137225247587, 8.96371090862317, 9.079022212015987, 9.194075634261779, 9.308875532095252, 9.423426126631163, 9.537731509461496, 9.651795648396565, 9.765622392875521, 9.879215479069527, 9.992578534698987, 10.105715083584462, 10.218628549949289, 10.331322262490481, 10.443799458233245, 10.556063286183157, 10.668116810789037, 10.779963015228564, 10.891604804527708, 11.003045008524351, 11.11428638468557, 11.225331620787502, 11.336183337465972, 11.446844090645538, 11.557316373854112, 11.667602620429676, 11.777705205625356, 11.887626448618548, 11.997368614429488, 12.106933915754272, 12.216324514716996, 12.32554252454542, 12.43459001117423, 12.543468994779772, 12.65218145124983, 12.760729313591831, 12.869114473282657], [0.0, 0.2653911281073648, 0.4783677539591454, 0.6752109349817923, 0.8622583191075672, 1.0423436000924935, 1.217068335024463, 1.387457645868068, 1.5542214179714637, 1.717878852885189, 1.8788253035655964, 2.0373712946212814, 2.193766799939581, 2.348217119857226, 2.5008936903830596, 2.651941690025202, 2.8014855438928845, 2.949633001740029, 3.0964782217442774, 3.2421041442863996, 3.386584348006855, 3.5299845213183554, 3.6723636435749123, 3.8137749437840354, 3.9542666866116556, 4.093882822692707, 4.232663531163993, 4.370645675739407, 4.507863190796478, 4.644347410329884, 4.780127349904322, 4.915229949664342, 5.049680284862031, 5.183501749123182, 5.316716214700746, 5.44934417319674, 5.581404859622783, 5.712916362179671, 5.843895719741216, 5.9743590087066245, 6.10432142062355, 6.2337973317686295, 6.3628003656944765, 6.491343449604542, 6.6194388652941685, 6.74709829529309, 6.8743328647579105, 7.001153179589819, 7.1275693611907, 7.253591078217884, 7.379227575652668, 7.504487701458947, 7.6293799310750785, 7.753912389953313, 7.878092874336332, 8.001928870438825, 8.125427572183318, 8.248595897623053, 8.371440504170439, 8.493967802737023, 8.616183970879902, 8.738094965039771, 8.859706531947191, 8.981024219266196, 9.10205338553739, 9.222799209476978, 9.343266698682632, 9.46346069779246, 9.5833858961391, 9.703046834937092, 9.822447914038388, 9.941593398287708, 10.06048742350674, 10.179134002133743, 10.29753702854282, 10.415700284065117, 10.533627441732444, 10.65132207076208, 10.768787640800054, 10.886027525938875, 11.003045008524351, 11.119843282765098, 11.236425458157274, 11.352794562736111, 11.468953546165015, 11.584905282672143, 11.700652573843753, 11.816198151282821, 11.931544679140957, 12.04669475653102, 12.161650919827283, 12.276415644859636, 12.390991349007802, 12.505380393201126, 12.61958508382922, 12.7336076745683, 12.847450368127797, 12.961115317921507, 13.07460462966732, 13.187920362919218, 13.301064532535124, 13.41403911008386], [0.0, 0.2760954684936768, 0.4976623374093602, 0.7024450318114386, 0.897036823628346, 1.084385701403318, 1.2661578197574768, 1.4434196481357342, 1.6169097045479932, 1.7871681321269988, 1.9546062300766205, 2.1195470477689318, 2.2822506415894925, 2.4429305925010736, 2.6017652512477847, 2.758905651997574, 2.9144812384476397, 3.0686041063526557, 3.221372211685582, 3.3728718401615776, 3.5231795381571303, 3.6723636435749123, 3.820485514654339, 3.9676005273526638, 4.113758893052789, 4.259006335103603, 4.403384653235485, 4.546932198030952, 4.689684272583698, 4.831673474720194, 4.9729299903248965, 5.11348184615169, 5.253355128843042, 5.392574175588059, 5.531161740839648, 5.66913914271232, 5.806526392046609, 5.943342306616526, 6.079604612545329, 6.215330034661015, 6.35053437725025, 6.485232596445372, 6.6194388652941685, 6.7531666324085755, 6.886428674960398, 7.019237146684927, 7.151603621463125, 7.28353913297678, 7.4150542108664865, 7.546158913767187, 7.676862859549159, 7.807175253051894, 7.937104911563822, 8.066660288270862, 8.195849493870949, 8.324680316529298, 8.453160240329586, 8.581296462359237, 8.709095908552106, 8.836565248398765, 8.963710908623169, 9.090539085914315, 9.217055758792586, 9.343266698682632, 9.469177480257537, 9.594793491112915, 9.72011994082391, 9.845161869433262, 9.969924155414118, 10.094411523147297, 10.218628549949289, 10.342579672683932, 10.466269193988003, 10.589701288138274, 10.712880006585328, 10.835809283177303, 10.95849293909483, 11.08093468751673, 11.203138138034458, 11.325106800831852, 11.446844090645538, 11.56835333052, 11.689637755370455, 11.81070051536553, 11.931544679140957, 12.052173236854612, 12.172589103092504, 12.292795119634647, 12.41279405808909, 12.532588622401846, 12.65218145124983, 12.771575120323563, 12.89077214450586, 13.009774979952276, 13.12858602607882, 13.247207627461941, 13.365642075655613, 13.483891610929861, 13.601958423935038, 13.7198446572956, 13.83755240713716, 13.955083724550208], [0.0, 0.2867270461289272, 0.516825765933465, 0.7294940048747914, 0.931578921273464, 1.1261420215411435, 1.3149136187304662, 1.499001248707177, 1.6791718675124154, 1.855986417510733, 2.0298720357589026, 2.2011642112553993, 2.3701330143482275, 2.5370002503386426, 2.701951137703111, 2.865142526465563, 3.0267088447973123, 3.186766504911847, 3.345417234761931, 3.502750642657204, 3.6588462225369978, 3.8137749437840354, 3.9676005273526638, 4.1203804815559915, 4.272166951261083, 4.423007420480759, 4.572945298522988, 4.722020412731922, 4.870269425613575, 5.017726190235314, 5.164422054846105, 5.31038612542294, 5.45564549312374, 5.600225432287059, 5.744149573569001, 5.887440055978353, 6.030117660910871, 6.172201930754505, 6.313711274210377, 6.454663060127587, 6.595073701366716, 6.734958729974234, 6.8743328647579105, 7.013210072193893, 7.151603621463125, 7.289526134303438, 7.426989630269946, 7.564005567917202, 7.700584882349503, 7.836738019528535, 7.9724749676788385, 8.107805286089643, 8.242738131575729, 8.377282282828904, 8.511446162864857, 8.645237859746814, 8.778665145747235, 8.911735495090994, 9.044456100408112, 9.176833888010496, 9.308875532095252, 9.44058746796659, 9.571975904359117, 9.703046834937092, 9.833806049036921, 9.964259141713764, 10.094411523147297, 10.22426842745663, 10.353834920969733, 10.483115909988635, 10.612116148088047, 10.740840242981632, 10.86929266298732, 10.9974777431203, 11.125399690839915, 11.253062591474555, 11.380470413346632, 11.507627012617936, 11.634536137874052, 11.761201434465088, 11.887626448618548, 12.013814631339025, 12.139769342108258, 12.265493852398066, 12.390991349007802, 12.516264937237016, 12.64131764390336, 12.766152420214958, 12.89077214450586, 13.01517962484263, 13.139377601509421, 13.26336874937859, 13.387155680173256, 13.510740944627893, 13.63412703455255, 13.757316384806028, 13.880311375182911, 14.003114332219058, 14.12572753091995, 14.248153196415844, 14.370393505547634, 14.492450588386921], [0.0, 0.29728948964493074, 0.5358645801436629, 0.7563670861755647, 0.9658964015024691, 1.1676268122301177, 1.3633523726386667, 1.554221417971464, 1.741029157376473, 1.924357197198576, 2.1046484093584055, 2.2822506415894925, 2.4574439130843433, 2.6304582000021686, 2.8014855438928845, 2.9706885728175507, 3.1382066670089808, 3.3041605270707755, 3.4686556284073946, 3.631784880317072, 3.7936307051348224, 3.9542666866116556, 4.113758893052789, 4.272166951261083, 4.429544927014867, 4.585942053541799, 4.741403339260813, 4.895970078674735, 5.049680284862031, 5.202569057968486, 5.35466890104905, 5.506009992285947, 5.656620420820472, 5.806526392046609, 5.955752407125963, 6.10432142062355, 6.25225497947965, 6.399573345984194, 6.54629560697756, 6.692439771142063, 6.838022855954817, 6.983060965631419, 7.1275693611907, 7.271562523605493, 7.4150542108664865, 7.558057509670765, 7.700584882349503, 7.842648209567189, 7.98425882925521, 8.12542757218332, 8.266164794522014, 8.406480407705375, 8.546383905866687, 8.685884391086981, 8.824990596668778, 8.96371090862317, 9.10205338553739, 9.240025776971613, 9.377635540517778, 9.514889857639094, 9.651795648396565, 9.788359585157973, 9.924588105375129, 10.06048742350674, 10.196063542156638, 10.331322262490481, 10.466269193988005, 10.60090976358266, 10.73524922423568, 10.86929266298732, 11.003045008524351, 11.136511038299275, 11.269695385233804, 11.4026025440363, 11.535236877160388, 11.66760262042968, 11.799703888351544, 11.931544679140957, 12.063128879473808, 12.194460268987514, 12.32554252454542, 12.456379224280134, 12.586973851429898, 12.717329797980923, 12.847450368127797, 12.977338781563013, 13.106998176606053, 13.23643161318157, 13.365642075655611, 13.494632475538221, 13.623405654060072, 13.751964384630398, 13.880311375182911, 14.008449270415968, 14.136380653932859, 14.264108050287648, 14.391633926941727, 14.51896069613583, 14.646090716682025, 14.773026295679864, 14.899769690160648, 15.0263231086635], [0.0, 0.3077861033362291, 0.5547847360339225, 0.7830726825351272, 1.0, 1.2088530513353746, 1.4114892347853742, 1.609097430691164, 1.8025009252216606, 1.9923018599150015, 2.1789587434890403, 2.362831705387256, 2.5442106516410514, 2.723333678343189, 2.90039960759262, 3.075576809476246, 3.249009585424943, 3.4208228977052766, 3.591125945817625, 3.7600149194755934, 3.927575151158822, 4.093882822692707, 4.259006335103603, 4.423007420480759, 4.585942053541799, 4.747861205827337, 4.908811474900906, 5.068835613280024, 5.227972976198238, 5.386259903107411, 5.543730044671217, 5.700414644594649, 5.8563427837825035, 6.0115415928814455, 6.166036438133203, 6.319851084576119, 6.47300783992378, 6.625527681881353, 6.777430371202006, 6.928734552413545, 7.07945784384138, 7.229616918304224, 7.379227575652667, 7.52830480814966, 7.676862859549159, 7.824915278609665, 7.9724749676788385, 8.119554226900329, 8.266164794522014, 8.412317883723421, 8.558024216327805, 8.70329405371937, 8.848137225247587, 8.992563154367211, 9.136580882733746, 9.280199092449209, 9.423426126631163, 9.566270008459073, 9.70873845883544, 9.850838912784553, 9.992578534698985, 10.133964232532605, 10.275002671028957, 10.415700284065116, 10.556063286183157, 10.696097683374662, 10.835809283177301, 10.975203704137169, 11.114286384685572, 11.253062591474553, 11.39153742721157, 11.529715838030077, 11.667602620429678, 11.805202427816637, 11.942519776672862, 12.079559052379237, 12.216324514716996, 12.35282030306897, 12.489050441340705, 12.62501884261999, 12.76072931359183, 12.896185558724534, 13.031391184241535, 13.166349701892347, 13.301064532535124, 13.43553900954236, 13.56977638204044, 13.70377981799297, 13.83755240713716, 13.971097163781831, 14.104417029475027, 14.237514875548737, 14.370393505547634, 14.503055657548343, 14.635504006375287, 14.76774116571878, 14.899769690160648, 15.031592077112336, 15.16321076867019, 15.294628153392184, 15.425846568000244, 15.556868299011972], [0.0, 0.31821990794877125, 0.5735916785016119, 0.8096184793674985, 1.0338995311986006, 1.2498326030636415, 1.45933805813647, 1.6636450792444673, 1.8636048615717187, 2.05983995897222, 2.2528244233944106, 2.442930592501074, 2.630458200002169, 2.8156534133363835, 2.9987217945786147, 3.1798374214827785, 3.359149487230608, 3.536787190250924, 3.7128634318559737, 3.8874776625455603, 4.060718107530379, 4.232663531163993, 4.403384653235485, 4.572945298522988, 4.741403339260813, 4.908811474900906, 5.075217882642359, 5.240666764292988, 5.405198809210311, 5.568851588736572, 5.731659894277168, 5.893656028684045, 6.054870058691038, 6.215330034661015, 6.375062182739407, 6.534091073588217, 6.692439771142063, 6.850129964240482, 7.007182083516911, 7.16361540553991, 7.319448145887859, 7.474697542580209, 7.6293799310750785, 7.783510811866105, 7.937104911563824, 8.0901762382233, 8.242738131575729, 8.394803308733865, 8.546383905866687, 8.69749151627525, 8.848137225247589, 8.998331642024024, 9.148084929164368, 9.297406829574069, 9.446306691416517, 9.594793491112917, 9.742875854608604, 9.890562077065068, 10.037860141119785, 10.184777733840882, 10.33132226249048, 10.477500869198845, 10.623320444641209, 10.768787640800053, 10.913908882887524, 11.0586903804955, 11.203138138034456, 11.347257964516563, 11.491055482733403, 11.63453613787405, 11.777705205625356, 11.920567799792376, 12.063128879473808, 12.205393255824202, 12.347365598432088, 12.489050441340705, 12.630452188735875, 12.771575120323565, 12.91242339641783, 13.053001062758307, 13.193312055074834, 13.333360203415458, 13.473149236252901, 13.612682784383331, 13.751964384630398, 13.890997483366357, 14.029785439861453, 14.168331529471775, 14.306638946675177, 14.444710807964134, 14.582550154603789, 14.720159955262941, 14.857543108525114, 14.994702445286443, 15.13164073104665, 15.268360668098923, 15.404864897624213, 15.541156001695043, 15.677236505193683, 15.813108877649098, 15.948775534996996, 16.08423884126685], [0.0, 0.328593674968539, 0.592290403152777, 0.8360115279168342, 1.067603999682791, 1.290576352634392, 1.5069115525660677, 1.7178788528851892, 1.924357197198576, 2.126989434220719, 2.326265069692688, 2.5225685792487442, 2.716209467727546, 2.9074419274700354, 3.0964782217442783, 3.283498103128477, 3.468655628407395, 3.6520842077966282, 3.833900423119542, 4.014206966899111, 4.193094940431901, 4.370645675739407, 4.546932198030952, 4.722020412731922, 4.895970078674735, 5.068835613280024, 5.240666764292988, 5.411509174472326, 5.581404859622783, 5.750392615888513, 5.918508368852648, 6.085785474419603, 6.25225497947965, 6.417945848819687, 6.582885163540838, 6.74709829529309, 6.9106090598806915, 7.073439853185582, 7.235611771866884, 7.397144720897052, 7.558057509670764, 7.7183679381559624, 7.878092874336332, 8.037248324011763, 8.19584949387095, 8.353910848622657, 8.511446162864857, 8.668468568280101, 8.824990596668778, 8.981024219266196, 9.136580882733748, 9.291671542166249, 9.446306691416517, 9.60049639100253, 9.754250293831872, 9.907577668951381, 10.06048742350674, 10.212988123076432, 10.36508801052685, 10.516795023519665, 10.668116810789039, 10.819060747294154, 10.969633948341876, 11.119843282765098, 11.269695385233803, 11.419196667768622, 11.568353330520003, 11.717171371870224, 11.865656597910302, 12.013814631339025, 12.161650919827283, 12.30917074388693, 12.456379224280136, 12.603281329002035, 12.749881879866779, 12.896185558724536, 13.042196913334795, 13.187920362919218, 13.333360203415461, 13.478520612451701, 13.623405654060074, 13.76801928314576, 13.912365349727324, 14.05644760296259, 14.200269694973409, 14.343835184481588, 14.487147540267443, 14.630210144461604, 14.773026295679864, 14.91559921201038, 15.057932033861608, 15.200027826679063, 15.341889583538256, 15.483520227620739, 15.624922614579768, 15.76609953480157, 15.907053715567926, 16.047787823125283, 16.188304464665464, 16.328606190222516, 16.468695494490113, 16.608574818563596], [0.0, 0.3389099556482867, 0.6108855086228687, 0.8622583191075671, 1.1011216944972255, 1.331094320284549, 1.5542214179714635, 1.7718120894937863, 1.9847728731128917, 2.1937667999395805, 2.3992987438701974, 2.6017652512477842, 2.8014855438928845, 2.998721794578614, 3.193692930631473, 3.3865843480068545, 3.577554940140841, 3.7667423056961433, 3.954266686611655, 4.140233999467815, 4.324738205709199, 4.507863190796478, 4.689684272583698, 4.870269425613575, 5.049680284862031, 5.227972976198238, 5.405198809210311, 5.581404859622783, 5.756634462337107, 5.930927631512094, 6.10432142062355, 6.276850232792859, 6.4485460896351885, 6.619438865294168, 6.789556491088869, 6.9589251352185855, 7.127569361190699, 7.2955122680114695, 7.4627756146749125, 7.629379931075078, 7.795344617132295, 7.9606880316489566, 8.125427572183318, 8.289579747041364, 8.453160240329586, 8.616183970879904, 8.778665145747235, 8.9406173088866, 9.10205338553739, 9.262985722774848, 9.423426126631163, 9.583385896139099, 9.742875854608602, 9.901906378410139, 10.06048742350674, 10.218628549949287, 10.376338944525532, 10.533627441732442, 10.69050254322326, 10.846972435864533, 11.00304500852435, 11.158727867700577, 11.314028352086924, 11.468953546165013, 11.623510292901948, 11.777705205625356, 11.931544679140957, 12.085034900151745, 12.23818185703242, 12.3909913490078, 12.54346899477977, 12.695620240643176, 12.847450368127795, 12.998964501200215, 13.150167613056649, 13.301064532535124, 13.451659950173175, 13.601958423935036, 13.751964384630398, 13.901682141045125, 14.051115884802654, 14.200269694973407, 14.349147542448245, 14.49775329409074, 14.646090716682021, 14.794163480670859, 14.941975163740798, 15.0895292542053, 15.23682915424103, 15.383878182968832, 15.530679579391066, 15.67723650519368, 15.823552047420534, 15.969629221027203, 16.11547097132089, 16.261080176292698, 16.406459648848095, 16.551612138941007, 16.696540335616696, 16.841246868968174, 16.98573431201064, 17.130005182478232], [0.0, 0.34917110573890975, 0.6293812411550551, 0.8883648464662178, 1.134460269499144, 1.3713957584027912, 1.601278457689756, 1.8254571048722776, 2.044865685399421, 2.260187304922818, 2.4719421233660923, 2.6805386932747477, 2.8863059015232992, 3.0895138586693083, 3.2903881204847343, 3.4891196961437387, 3.6858722898864817, 3.88078766643957, 4.07398970829763, 4.265587538869084, 4.455677964461778, 4.644347410329884, 4.831673474720194, 5.017726190235314, 5.202569057968486, 5.386259903107411, 5.568851588736572, 5.750392615888513, 5.930927631512094, 6.110497861271665, 6.289141480508209, 6.4668939339637115, 6.643788212769264, 6.819855095565597, 6.995123359346134, 7.16961996460268, 7.343370218550002, 7.5163979195611565, 7.688725485425509, 7.860374067619099, 8.03136365343212, 8.201713157514979, 8.371440504170439, 8.540562701525163, 8.709095908552106, 8.877055495779487, 9.044456100408112, 9.211311676462259, 9.37763554051778, 9.54344041348134, 9.708738458835441, 9.873541317712771, 10.037860141119785, 10.201705619591497, 10.36508801052685, 10.52801716342564, 10.690502543223262, 10.852553251898057, 11.014178048507155, 11.175385367790216, 11.33618333746597, 11.496579794333622, 11.656582299279934, 11.81619815128282, 11.975434400493361, 12.134297860470385, 12.292795119634645, 12.450932552003454, 12.608716327261059, 12.766152420214956, 12.923246619684022, 13.080004536860146, 13.236431613181567, 13.392533127752808, 13.54831420434315, 13.70377981799297, 13.858934801254842, 14.01378385009412, 14.168331529471775, 14.322582278630442, 14.476540416103012, 14.6302101444616, 14.78359555482342, 14.936700631128762, 15.0895292542053, 15.242085205631685, 15.394372171412712, 15.546393745477232, 15.698153433009349, 15.84965465362266, 16.000900744386552, 16.151894962713087, 16.302640489112314, 16.453140429823375, 16.603397819328308, 16.75341562275493, 16.903196738174824, 17.052743998802054, 17.202060175097902, 17.35114797678649, 17.500010054786, 17.64864900305981], [0.0, 0.35937930668721074, 0.6477815328092164, 0.9143366600529775, 1.1676268122301179, 1.4114892347853742, 1.6480926757095749, 1.8788253035655966, 2.1046484093584055, 2.326265069692688, 2.544210651641051, 2.7589056519975745, 2.970688572817551, 3.1798374214827785, 3.386584348006855, 3.5911259458176255, 3.7936307051348224, 3.9942445352514064, 4.1930949404319, 4.39029423436497, 4.585942053541799, 4.780127349904322, 4.9729299903248965, 5.164422054846105, 5.35466890104905, 5.543730044671217, 5.731659894277168, 5.918508368852648, 6.10432142062355, 6.289141480508209, 6.473007839923781, 6.65595697985793, 6.838022855954818, 7.019237146684927, 7.199629470352222, 7.379227575652667, 7.558057509670764, 7.736143766537526, 7.913509419438181, 8.090176238223298, 8.266164794522014, 8.44149455596449, 8.616183970879904, 8.790250544636455, 8.96371090862317, 9.136580882733746, 9.308875532095254, 9.480609218685208, 9.651795648396567, 9.82244791403839, 9.992578534698987, 10.162199491845687, 10.331322262490481, 10.4999578497118, 10.66811681078904, 10.835809283177301, 11.003045008524351, 11.169833354909649, 11.336183337465972, 11.502103637527027, 11.667602620429678, 11.832688352086077, 11.997368614429488, 12.161650919827283, 12.32554252454542, 12.489050441340703, 12.652181451249831, 12.814942114637864, 12.977338781563015, 13.139377601509421, 13.301064532535124, 13.462405349878159, 13.623405654060074, 13.784070878522787, 13.944406296831671, 14.10441702947503, 14.264108050287648, 14.4234841925239, 14.582550154603792, 14.74131050555355, 14.899769690160648, 15.057932033861608, 15.215801747379603, 15.373382931127521, 15.530679579391068, 15.68769558430534, 15.844434739637418, 16.000900744386556, 16.157097206212754, 16.31302764470382, 16.468695494490113, 16.624104108215853, 16.77925675937497, 16.934156645019144, 17.088806888345093, 17.243210541167702, 17.397370586285206, 17.551289939742173, 17.704971452995768, 17.85841791499033, 18.01163205414503, 18.16461654025912], [0.0, 0.3695365839058538, 0.6660900343935533, 0.9401789129443202, 1.2006279032753076, 1.4513827043927483, 1.6946733604560322, 1.9319272743764166, 2.1641329065006842, 2.3920132047612435, 2.616118667518645, 2.83688167623152, 3.054650300170499, 3.2697104041482135, 3.4823006995244516, 3.692623336123625, 3.900851566270125, 4.107135423148048, 4.31160601472457, 4.5143788290538565, 4.715556318692015, 4.915229949664342, 5.11348184615169, 5.31038612542294, 5.506009992285947, 5.700414644594649, 5.893656028684045, 6.085785474419603, 6.276850232792859, 6.4668939339637115, 6.65595697985793, 6.844076882539531, 7.031288557354264, 7.217624578113552, 7.403115400235013, 7.587789556686804, 7.771673830732316, 7.954793408789717, 8.137172016170652, 8.31883203801545, 8.499794627377206, 8.68007980210729, 8.859706531947193, 9.038692817026142, 9.217055758792588, 9.39481162426404, 9.571975904359117, 9.748563366973501, 9.924588105375129, 10.100063582420225, 10.27500267102896, 10.449417691305538, 10.623320444641209, 10.796722245098689, 10.969633948341876, 11.142065978344705, 11.314028352086925, 11.485530702421675, 11.656582299279934, 11.827192069359327, 11.997368614429487, 12.167120228372582, 12.336454913065682, 12.505380393201124, 12.673904130131534, 12.842033334817993, 13.009774979952276, 13.177135811317598, 13.344122358446336, 13.51074094462789, 13.676997696315219, 13.842898551974155, 14.008449270415968, 14.173655438650057, 14.338522479290631, 14.503055657548343, 14.667260087835405, 14.831140740010348, 14.994702445286443, 15.157949901826088, 15.320887680041512, 15.483520227620737, 15.645851874296241, 15.807886836372477, 15.969629221027203, 16.131083030400447, 16.292252165484, 16.453140429823375, 16.613751533043274, 16.774089094206975, 16.934156645019144, 17.09395763288108, 17.25349542380675, 17.412773305207352, 17.571794488551724, 17.730562111909386, 17.889079242382557, 18.04734887843311, 18.205373952110055, 18.363157331182745, 18.52070182118473, 18.678010167372843], [0.0, 0.37964482260124677, 0.6843101439943604, 0.9658964015024691, 1.2334696676884025, 1.4910835715147557, 1.7410291573764731, 1.9847728731128922, 2.2233302172411995, 2.457443913084343, 2.6876795172381653, 2.9144812384476397, 3.138206667008981, 3.3591494872306074, 3.5775549401408413, 3.793630705134822, 4.007554773650538, 4.219481282853406, 4.429544927014866, 4.637864353228996, 4.8445448165211, 5.049680284862031, 5.253355128843042, 5.45564549312374, 5.656620420820472, 5.8563427837825035, 6.054870058691038, 6.25225497947965, 6.4485460896351885, 6.643788212769264, 6.838022855954818, 7.031288557354264, 7.223621187381577, 7.415054210866486, 7.605618916298742, 7.7953446171322955, 7.984258829255209, 8.172387428030504, 8.359754787747823, 8.546383905866687, 8.732296514057081, 8.917513177735163, 9.10205338553739, 9.285935629965364, 9.469177480257539, 9.651795648396565, 9.833806049036923, 10.01522385403271, 10.19606354215664, 10.376338944525534, 10.556063286183157, 10.735249224235679, 10.913908882887526, 11.092053885684296, 11.269695385233804, 11.44684409064554, 11.62351029290195, 11.799703888351543, 11.975434400493361, 12.150711000204346, 12.325542524545419, 12.499937494268147, 12.673904130131536, 12.847450368127795, 13.020583873706082, 13.193312055074834, 13.365642075655613, 13.537580865754597, 13.709135133511847, 13.88031137518291, 14.051115884802655, 14.221554763276668, 14.391633926941727, 14.561359115633307, 14.730735900294848, 14.89976969016065, 15.068465739541658, 15.236829154241034, 15.404864897624213, 15.572577796366298, 15.73997254589777, 15.907053715567924, 16.073825753543982, 16.24029299146245, 16.406459648848095, 16.572329837314783, 16.73790756456135, 16.903196738174824, 17.068201169252326, 17.23292457585236, 17.397370586285206, 17.561542742251785, 17.725444501839416, 17.889079242382557, 18.052450263196008, 18.215560788187485, 18.378413968356185, 18.541012884183377, 18.703360547920823, 18.86545990578234, 19.027313840043544, 19.18892517105454], [0.0, 0.3897057815518492, 0.7024450318114386, 0.9914936004303153, 1.2661578197574768, 1.5305987438859707, 1.7871681321269988, 2.0373712946212814, 2.282250641589492, 2.522568579248744, 2.758905651997574, 2.9917178405469684, 3.2213722116855825, 3.448170232643121, 3.6723636435749123, 3.8941656275831, 4.113758893052789, 4.331301661934966, 4.546932198030951, 4.760772292698801, 4.9729299903248965, 5.183501749123182, 5.392574175588059, 5.600225432287059, 5.806526392046609, 6.0115415928814455, 6.215330034661015, 6.417945848819687, 6.619438865294168, 6.819855095565597, 7.019237146684927, 7.217624578113552, 7.415054210866486, 7.611560396624159, 7.807175253051893, 8.001928870438825, 8.195849493870949, 8.388963684433701, 8.581296462359237, 8.77287143456223, 8.963710908623169, 9.153835994961844, 9.343266698682632, 9.532022002356502, 9.72011994082391, 9.907577668951381, 10.094411523147297, 10.280637077334724, 10.466269193988003, 10.651322070762077, 10.835809283177301, 11.019743823765527, 11.203138138034456, 11.386004157565004, 11.568353330520003, 11.750196649810805, 11.931544679140956, 12.112407577121878, 12.292795119634645, 12.472716720593402, 12.652181451249827, 12.831198058163732, 13.009774979952274, 13.187920362919217, 13.36564207565561, 13.542947722694658, 13.719844657295598, 13.8963399934245, 14.072440616993692, 14.24815319641584, 14.423484192523897, 14.59843986790341, 14.773026295679863, 14.947249367799982, 15.121114802842659, 15.294628153392184, 15.467794813003888, 15.640620022789701, 15.813108877649098, 15.985266332168788, 16.157097206212754, 16.328606190222512, 16.499797850246065, 16.670676632712517, 16.841246868968174, 17.01151277958868, 17.18147847848082, 17.35114797678649, 17.52052518660061, 17.68961392451387, 17.858417914990326, 18.02694079358943, 18.195186110041195, 18.363157331182745, 18.530857843763947, 18.698290957129228, 18.86545990578234, 19.032367851840316, 19.199017887382542, 19.36541303670037, 19.531556258452543, 19.697450447731203], [0.0, 0.39972110515634074, 0.7204976618749289, 1.0169746934244948, 1.2986977021496025, 1.569934680005786, 1.8330978258246662, 2.0897311357734436, 2.340903809707903, 2.5873978474599912, 2.8298087132480014, 3.0686041063526557, 3.3041605270707755, 3.5367871902509234, 3.7667423056961438, 3.994244535251406, 4.219481282853405, 4.442614836710587, 4.663787013963167, 4.883122735971176, 5.10073282382984, 5.316716214700746, 5.531161740839648, 5.744149573569001, 5.955752407125963, 6.166036438133203, 6.375062182739407, 6.582885163540838, 6.789556491088869, 6.995123359346134, 7.199629470352222, 7.403115400235013, 7.605618916298742, 7.807175253051893, 8.00781735357431, 8.207576081466678, 8.406480407705375, 8.604557575987894, 8.801833249558971, 8.998331642024024, 9.194075634261779, 9.389086879223585, 9.5833858961391, 9.776992155425766, 9.969924155414118, 10.162199491845687, 10.353834920969732, 10.544846416954547, 10.73524922423568, 10.925057905343614, 11.114286384685572, 11.302947988697643, 11.491055482733401, 11.678621105011876, 11.865656597910302, 12.052173236854612, 12.23818185703242, 12.423692878128456, 12.608716327261057, 12.793261860279186, 12.977338781563013, 13.160956062456352, 13.344122358446334, 13.526846025194326, 13.709135133511845, 13.890997483366357, 14.072440616993692, 14.253471831186745, 14.434098188823764, 14.614326529693653, 14.79416348067086, 14.973615465287537, 15.152688712746702, 15.331389266416373, 15.509722991841228, 15.687695584305342, 15.86531257597682, 16.042579342662627, 16.21950111019965, 16.396082960506014, 16.572329837314783, 16.74824655161044, 16.923837786787068, 17.099108103545692, 17.27406194454694, 17.448703638834008, 17.623037406039863, 17.797067360391566, 17.970797514523728, 18.144231783112293, 18.31737398633894, 18.490227853195925, 18.66279702464028, 18.835085056605823, 19.007095422880884, 19.17883151785907, 19.350296659169928, 19.52149409019596, 19.692426982482083, 19.863098438043046, 20.03351149157425, 20.20366911257084], [0.0, 0.40969233401336785, 0.7384708111153172, 1.0423436000924937, 1.3310943202845493, 1.6090974306911636, 1.8788253035655964, 2.1418604507774694, 2.3992987438701974, 2.651941690025202, 2.9003996075926195, 3.145151862829232, 3.386584348006855, 3.625013991482248, 3.8607054442220714, 4.093882822692707, 4.324738205709199, 4.5534379298348275, 4.780127349904321, 5.004934503499129, 5.227972976198238, 5.44934417319674, 5.66913914271232, 5.887440055978353, 6.10432142062355, 6.319851084576119, 6.534091073588217, 6.74709829529309, 6.9589251352185855, 7.16961996460268, 7.379227575652667, 7.587789556686804, 7.7953446171322955, 8.001928870438825, 8.207576081466678, 8.412317883723421, 8.616183970879902, 8.819202266240325, 9.021399073230993, 9.222799209476978, 9.423426126631162, 9.623302017787838, 9.822447914038388, 10.020883771498875, 10.218628549949289, 10.415700284065116, 10.612116148088047, 10.807892514669431, 11.003045008524351, 11.197588555452386, 11.391537427211572, 11.584905282672143, 11.777705205625356, 11.969949739578304, 12.161650919827283, 12.35282030306897, 12.54346899477977, 12.7336076745683, 12.923246619684022, 13.112395726845543, 13.301064532535122, 13.48926223189092, 13.676997696315219, 13.86427948990524, 14.051115884802654, 14.237514875548737, 14.4234841925239, 14.609031314542932, 14.79416348067086, 14.978887701318309, 15.163210768670188, 15.347139266496647, 15.530679579391068, 15.713837901476095, 15.89662024461515, 16.07903244616381, 16.261080176292698, 16.44276894491077, 16.624104108215853, 16.805090874896884, 16.98573431201064, 17.166039350553852, 17.346010790750054, 17.52565330706907, 17.704971452995764, 17.883969665563335, 18.062652269665445, 18.241023482160475, 18.419087415780066, 18.59684808285357, 18.774309398858883, 18.951475185809702, 19.128349175488427, 19.304935012533296, 19.48123625738791, 19.657256389120597, 19.832998808120717, 20.008466838678462, 20.183663731454406, 20.3585926658445, 20.533256752246032, 20.707659034229593], [0.0, 0.4196209142486577, 0.7563670861755646, 1.0676039996827908, 1.3633523726386667, 1.6480926757095746, 1.924357197198576, 2.193766799939581, 2.457443913084343, 2.7162094677275457, 2.9706885728175507, 3.221372211685582, 3.468655628407395, 3.7128634318559737, 3.9542666866116556, 4.1930949404319, 4.429544927014866, 4.663787013963168, 4.895970078674734, 5.126225261623835, 5.35466890104905, 5.581404859622783, 5.806526392046609, 6.030117660910871, 6.25225497947965, 6.47300783992378, 6.692439771142063, 6.9106090598806915, 7.127569361190699, 7.343370218550002, 7.558057509670764, 7.771673830732316, 7.984258829255209, 8.195849493870949, 8.406480407705375, 8.616183970879902, 8.824990596668776, 9.032928885076107, 9.240025776971613, 9.446306691416515, 9.651795648396565, 9.856515378838708, 10.06048742350674, 10.263732222137921, 10.466269193988005, 10.668116810789039, 10.86929266298732, 11.069813520012877, 11.269695385233804, 11.468953546165013, 11.667602620429678, 11.8656565979103, 12.063128879473807, 12.260032312609589, 12.456379224280136, 12.65218145124983, 12.847450368127795, 13.042196913334795, 13.236431613181567, 13.430164604226123, 13.623405654060072, 13.81616418065871, 14.008449270415966, 14.200269694973407, 14.391633926941726, 14.582550154603789, 14.773026295679863, 14.96307001022809, 15.152688712746702, 15.341889583538254, 15.530679579391068, 15.719065443627917, 15.907053715567924, 16.09465073944356, 16.281862672811144, 16.468695494490113, 16.655155012063325, 16.841246868968174, 17.026976551205834, 17.212349393693835, 17.397370586285206, 17.5820451794756, 17.7663780898183, 17.95037410506533, 18.134037889051775, 18.31737398633894, 18.500386826630972, 18.683080728978588, 18.865459905782338, 19.047528466607304, 19.229290421819993, 19.41074968605768, 19.591910081539652, 19.772775341229167, 19.953349111854457, 20.133634956796406, 20.31363635885021, 20.493356722867688, 20.672799378286683, 20.85196758155338, 21.030864518443167, 21.20949330628523], [0.0, 0.42950820576846077, 0.7741889382879459, 1.092759352083354, 1.3954762775603975, 1.6869257561950164, 1.9696997431748682, 2.245457292812905, 2.5153472814274953, 2.7802099832508427, 3.040685236321767, 3.2972755927354935, 3.5503856094815673, 3.800347544009218, 4.047438847840986, 4.291894477438996, 4.533915802026849, 4.773677203483132, 5.011331067120141, 5.247011623401359, 5.480837951777828, 5.712916362179671, 5.943342306616526, 6.172201930754505, 6.399573345984194, 6.625527681881353, 6.850129964240482, 7.073439853185582, 7.2955122680114695, 7.5163979195611565, 7.736143766537526, 7.954793408789717, 8.172387428030504, 8.388963684433701, 8.604557575987894, 8.819202266240325, 9.032928885076107, 9.24576670638516, 9.457743305829757, 9.66888470140616, 9.879215479069527, 10.08875890534285, 10.29753702854282, 10.50557077001673, 10.712880006585328, 10.919483645219696, 11.125399690839915, 11.33064530800466, 11.535236877160388, 11.739190046033121, 11.942519776672864, 12.145240388597847, 12.347365598432088, 12.548908556383141, 12.749881879866779, 12.950297684550401, 13.15016761305665, 13.34950286154214, 13.54831420434315, 13.7466120168597, 13.944406296831671, 14.14170668414481, 14.338522479290631, 14.534862660591962, 14.730735900294848, 14.926150579618064, 15.12111480284266, 15.315636410516422, 15.50972299184123, 15.70338189630507, 15.89662024461515, 16.08944493898337, 16.281862672811148, 16.473879939816527, 16.665503042642875, 16.85673810098518, 17.047591059267106, 17.23806769389919, 17.428173620146165, 17.617914298629223, 17.807295041486974, 17.996321018217067, 18.184997261218758, 18.37332867105518, 18.561320021452744, 18.748975964053685, 18.93630103293679, 19.12329964892013, 19.309976123658682, 19.496334663548897, 19.68237937345129, 19.868114260241537, 20.053543236199722, 20.238670122246823, 20.42349865103687, 20.60803246991269, 20.792275143732617, 20.97623015757509, 21.15990091932761, 21.34329076216618, 21.526402946930816, 21.70924066440258], [0.0, 0.4393554895885763, 0.7919386764846243, 1.1178129164682244, 1.4274701970823527, 1.7256017034333104, 2.0148588161586973, 2.2969386265134233, 2.5730163509672868, 2.843951528620405, 3.110398667002616, 3.3728718401615776, 3.6317848803170723, 3.88747766254556, 4.1402339994678155, 4.39029423436497, 4.637864353228996, 4.883122735971176, 5.126225261623835, 5.367309238136412, 5.6064964750804345, 5.843895719741216, 6.079604612545329, 6.313711274210377, 6.54629560697756, 6.777430371202006, 7.007182083516911, 7.235611771866884, 7.4627756146749125, 7.688725485425509, 7.913509419438181, 8.137172016170652, 8.359754787747823, 8.581296462359237, 8.801833249558971, 9.021399073230993, 9.240025776971613, 9.457743305829757, 9.67457986769165, 9.89056207706507, 10.105715083584462, 10.320062687201641, 10.533627441732444, 10.746430748185418, 10.95849293909483, 11.16983335490965, 11.380470413346634, 11.59042167249426, 11.799703888351544, 12.008333067398073, 12.216324514716998, 12.423692878128456, 12.630452188735875, 12.836615898240066, 13.042196913334797, 13.247207627461943, 13.451659950173177, 13.655565334318073, 13.858934801254842, 14.061778964259075, 14.264108050287646, 14.46593192023883, 14.667260087835407, 14.868101737245146, 15.068465739541658, 15.268360668098923, 15.46779481300389, 15.666776194563651, 15.865312575976821, 16.063411475232233, 16.261080176292698, 16.458325739616317, 16.655155012063325, 16.85157463623248, 17.047591059267106, 17.243210541167706, 17.438439162645047, 17.63328283254475, 17.827747294872058, 18.021838135443172, 18.215560788187485, 18.4089205411231, 18.601922542026497, 18.794571803815444, 18.986873209663003, 19.17883151785907, 19.370451366434718, 19.56173727756359, 19.752693661753465, 19.94332482184035, 20.133634956796406, 20.323628165362482, 20.51330844951504, 20.70267971777686, 20.891745788380092, 21.08051039228976, 21.268977176095284, 21.457149704777077, 21.64503146435489, 21.832625864424042, 22.01993624058544, 22.206965856774822], [0.0, 0.4491639743640834, 0.8096184793674985, 1.1427677679105288, 1.4593380581364699, 1.7641252645081118, 2.05983995897222, 2.3482171198572264, 2.6304582000021686, 2.9074419274700354, 3.1798374214827785, 3.448170232643122, 3.7128634318559746, 3.974264481810999, 4.232663531163993, 4.488306288790625, 4.741403339260813, 4.9921370447659905, 5.240666764292987, 5.487132871151668, 5.7316598942771675, 5.9743590087066245, 6.215330034661015, 6.454663060127587, 6.692439771142063, 6.928734552413545, 7.16361540553991, 7.397144720897052, 7.629379931075078, 7.860374067619099, 8.090176238223298, 8.31883203801545, 8.546383905866687, 8.77287143456223, 8.998331642024024, 9.222799209476978, 9.446306691416515, 9.66888470140616, 9.89056207706507, 10.111366027062246, 10.33132226249048, 10.550455114628656, 10.768787640800054, 10.986341719784575, 11.203138138034458, 11.419196667768622, 11.63453613787405, 11.84917449841849, 12.063128879473808, 12.276415644859636, 12.489050441340703, 12.70104824374551, 12.912423396417829, 13.123189651363814, 13.33336020341546, 13.54294772269466, 13.751964384630398, 13.960421897753815, 14.168331529471773, 14.375704129998184, 14.582550154603789, 14.788879684328572, 14.99470244528644, 15.200027826679063, 15.404864897624211, 15.609222422893973, 15.813108877649098, 16.016532461247728, 16.219501110199648, 16.422022510330628, 16.624104108215853, 16.825753121936113, 17.026976551205834, 17.22778118691787, 17.42817362014616, 17.62816025064393, 17.827747294872054, 18.026940793589432, 18.225746619034567, 18.4241704817254, 18.62221793690223, 18.819894390636648, 19.017205105627756, 19.214155206705268, 19.41074968605768, 19.60699340820234, 19.802891114713027, 19.998447428719608, 20.19366685919318, 20.38855380502932, 20.583112558941043, 20.777347311172395, 20.971262153042822, 21.16486108033174, 21.358147996512237, 21.551126715842052, 21.74380096631967, 21.93617439251266, 22.128250558265165, 22.320032949290734, 22.511524975656606, 22.70272997416494], [0.0, 0.45893480222519406, 0.8272304056273321, 1.1676268122301179, 1.4910835715147557, 1.8025009252216604, 2.1046484093584055, 2.399298743870198, 2.687679517238165, 2.9706885728175507, 3.2490095854249423, 3.5231795381571303, 3.7936307051348224, 4.060718107530379, 4.324738205709199, 4.585942053541798, 4.844544816521099, 5.100732823829839, 5.354668901049049, 5.6064964750804345, 5.856342783782503, 6.10432142062355, 6.35053437725025, 6.595073701366716, 6.838022855954817, 7.07945784384138, 7.319448145887859, 7.558057509670764, 7.795344617132295, 8.03136365343212, 8.266164794522014, 8.499794627377206, 8.732296514057081, 8.963710908623169, 9.194075634261779, 9.423426126631162, 9.651795648396565, 9.879215479069527, 10.105715083584462, 10.33132226249048, 10.556063286183155, 10.779963015228564, 11.003045008524351, 11.225331620787502, 11.44684409064554, 11.667602620429678, 11.887626448618548, 12.10693391575427, 12.32554252454542, 12.54346899477977, 12.760729313591831, 12.977338781563011, 13.193312055074832, 13.408663185285857, 13.623405654060074, 13.83755240713716, 14.051115884802654, 14.264108050287646, 14.476540416103012, 14.688424068491322, 14.899769690160646, 15.110587581447504, 15.320887680041512, 15.530679579391066, 15.739972545897768, 15.948775534996994, 16.157097206212754, 16.364945937266825, 16.572329837314783, 16.779256759374967, 16.98573431201064, 17.19176987032013, 17.397370586285206, 17.602543398523494, 17.807295041486974, 18.01163205414503, 18.21556078818748, 18.419087415780066, 18.62221793690223, 18.8249581862949, 19.02731384004354, 19.22929042181999, 19.43089330880477, 19.632127737309876, 19.832998808120713, 20.033511491574245, 20.233670632389437, 20.433480954264784, 20.63294706425668, 20.832073456951484, 21.030864518443163, 21.22932453012767, 21.427457672324415, 21.625268027734464, 21.822759584744578, 22.01993624058544, 22.21680180435204, 22.413359999893565, 22.60961446857975, 22.80556877195015, 23.00122639425244, 23.19659074487545], [0.0, 0.4686690540084536, 0.844776403472998, 1.1923927993028425, 1.5227102488655055, 1.8407329306407139, 2.1492891239710192, 2.450189149136588, 2.7446866324245787, 3.0336984609263813, 3.317922810565866, 3.5979080541375352, 3.8740956345266153, 4.146848103093769, 4.416468208286773, 4.6832123289625525, 4.947300194388827, 5.208922085889622, 5.4682442826633295, 5.725413253772695, 5.980558935859026, 6.2337973317686295, 6.485232596445372, 6.734958729974234, 6.983060965631419, 7.229616918304224, 7.474697542580209, 7.7183679381559624, 7.9606880316489566, 8.201713157514979, 8.44149455596449, 8.68007980210729, 8.917513177735163, 9.153835994961844, 9.389086879223585, 9.623302017787838, 9.856515378838708, 10.08875890534285, 10.320062687201641, 10.550455114628656, 10.779963015228564, 11.008611776873295, 11.236425458157274, 11.46342688795295, 11.689637755370455, 11.915078691243219, 12.139769342108258, 12.363728437520367, 12.586973851429898, 12.809522658260235, 13.031391184241535, 13.252595054488696, 13.473149236252898, 13.693068078725272, 13.912365349727324, 14.131054269584775, 14.349147542448245, 14.566657385295338, 14.783595554823417, 14.999973372420174, 15.2158017473796, 15.431091198513855, 15.64585187429624, 15.860093571657307, 16.073825753543982, 16.287057565341186, 16.499797850246065, 16.712055163676325, 16.923837786787068, 17.13515373916333, 17.346010790750054, 17.556416473075338, 17.7663780898183, 17.97590272676834, 18.184997261218754, 18.393668370833957, 18.601922542026493, 18.809766077877022, 19.017205105627756, 19.22424558377758, 19.430893308804766, 19.637153921541174, 19.843032913220185, 20.04853563121877, 20.25366728451271, 20.458432948862455, 20.662837571746056, 20.866885977054167, 21.0705828695613, 21.27393283918639, 21.476940365054794, 21.679609819373155, 21.881945471127683, 22.083951489615714, 22.285631947819816, 22.486990825633015, 22.68803201294324, 22.888759312584487, 23.0891764431619, 23.28928704175718, 23.489094666520757, 23.688602799156413], [0.0, 0.4783677539591454, 0.8622583191075672, 1.217068335024463, 1.5542214179714637, 1.8788253035655962, 2.193766799939581, 2.5008936903830596, 2.8014855438928845, 3.096478221744278, 3.386584348006855, 3.6723636435749127, 3.954266686611656, 4.232663531163992, 4.507863190796479, 4.780127349904321, 5.049680284862031, 5.3167162147007465, 5.581404859622783, 5.843895719741216, 6.10432142062355, 6.3628003656944765, 6.6194388652941685, 6.8743328647579105, 7.1275693611907, 7.379227575652667, 7.6293799310750785, 7.878092874336332, 8.125427572183318, 8.371440504170439, 8.616183970879904, 8.859706531947193, 9.10205338553739, 9.343266698682632, 9.5833858961391, 9.822447914038388, 10.06048742350674, 10.29753702854282, 10.533627441732444, 10.768787640800054, 11.003045008524351, 11.236425458157274, 11.468953546165015, 11.700652573843753, 11.93154467914096, 12.161650919827283, 12.390991349007802, 12.61958508382922, 12.847450368127797, 13.074604629667318, 13.301064532535126, 13.526846025194326, 13.751964384630398, 13.976434256978544, 14.20026969497341, 14.4234841925239, 14.646090716682023, 14.868101737245146, 15.0895292542053, 15.310384823236479, 15.530679579391068, 15.75042425915892, 15.969629221027203, 16.18830446466546, 16.406459648848095, 16.624104108215853, 16.841246868968174, 17.057896663569732, 17.274061944546943, 17.489750897443216, 17.704971452995768, 17.91973129859115, 18.13403788905178, 18.34789845680134, 18.561320021452744, 18.774309398858886, 18.986873209663003, 19.199017887382542, 19.410749686057684, 19.62207468749329, 19.832998808120717, 20.043527805503956, 20.25366728451271, 20.46342270318328, 20.672799378286683, 20.881802490621844, 21.090437090050568, 21.29870810028976, 21.506620323475158, 21.714178444510093, 21.921387035211534, 22.128250558265165, 22.334773371000157, 22.54095972899384, 22.746813789515635, 22.952339614819, 23.15754117528972, 23.362422352458154, 23.56698694188275, 23.77123865591147, 23.975181126327577, 24.178817906885698], [0.0, 0.48803187396966347, 0.8796779043679792, 1.2416558920939607, 1.585620236520334, 1.9167818611767238, 2.2380858943062902, 2.551417448636785, 2.85808194337809, 3.1590341463383256, 3.4550010782191416, 3.7465537675538845, 4.034151895212636, 4.318172991178318, 4.598932311794493, 4.876696828078179, 5.15169534729833, 5.424126012153614, 5.69416197158165, 5.961955745938875, 6.227642640131838, 6.491343449604542, 6.7531666324085755, 7.013210072193893, 7.271562523605493, 7.52830480814966, 7.783510811866105, 8.037248324011763, 8.289579747041364, 8.540562701525163, 8.790250544636455, 9.038692817026142, 9.285935629965364, 9.532022002356502, 9.776992155425766, 10.020883771498875, 10.263732222137921, 10.50557077001673, 10.746430748185418, 10.986341719784575, 11.225331620787502, 11.46342688795295, 11.700652573843753, 11.937032450495431, 12.172589103092504, 12.40734401482063, 12.64131764390336, 12.874529493697375, 13.106998176606053, 13.338741472473767, 13.56977638204044, 13.800119175964522, 14.02978543986145, 14.258790115751777, 14.487147540267443, 14.714871479925103, 14.941975163740798, 15.168471313430253, 15.394372171412712, 15.619689526813152, 15.844434739637416, 16.06861876327695, 16.292252165483998, 16.515345147944238, 16.73790756456135, 16.959948938557126, 17.181478478480823, 17.402505093212824, 17.623037406039863, 17.843083767872002, 18.06265226966545, 18.28175075410949, 18.500386826630972, 18.718567865765035, 18.93630103293679, 19.153593281694906, 19.370451366434718, 19.586881850645405, 19.802891114713027, 20.01848536330878, 20.233670632389437, 20.44845279583491, 20.662837571746056, 20.87683052842397, 21.090437090050568, 21.30366254208873, 21.516512036419, 21.72899059622859, 21.94110312066734, 22.152854389284315, 22.364249066257617, 22.57529170442936, 22.78598674915671, 22.996338541989367, 23.20635132418308, 23.416029240058084, 23.62537634021103, 23.83439658458804, 24.0430938454265, 24.251471910072272, 24.45953448367893, 24.667285191795045], [0.0, 0.4976623374093603, 0.8970368236283461, 1.266157819757477, 1.6169097045479934, 1.9546062300766205, 2.2822506415894925, 2.601765251247785, 2.9144812384476397, 3.2213722116855825, 3.5231795381571307, 3.820485514654339, 4.11375889305279, 4.403384653235485, 4.6896842725836985, 4.9729299903248965, 5.253355128843042, 5.531161740839649, 5.806526392046609, 6.079604612545329, 6.350534377250251, 6.6194388652941685, 6.886428674960398, 7.151603621463125, 7.4150542108664865, 7.676862859549159, 7.937104911563824, 8.19584949387095, 8.453160240329586, 8.709095908552106, 8.96371090862317, 9.217055758792588, 9.469177480257539, 9.72011994082391, 9.969924155414118, 10.218628549949289, 10.466269193988005, 10.712880006585328, 10.95849293909483, 11.203138138034458, 11.44684409064554, 11.689637755370455, 11.93154467914096, 12.172589103092504, 12.412794058089093, 12.652181451249831, 12.890772144505862, 13.12858602607882, 13.365642075655613, 13.601958423935038, 13.837552407137162, 14.072440616993692, 14.306638946675179, 14.540162633057058, 14.773026295679866, 15.005243972718606, 15.236829154241034, 15.46779481300389, 15.69815343300935, 15.927917036020347, 16.157097206212754, 16.385705113124224, 16.613751533043274, 16.841246868968174, 17.068201169252326, 17.294624145041798, 17.52052518660061, 17.74591337861047, 17.97079751452373, 18.195186110041195, 18.41908741578007, 18.64250942919153, 18.86545990578234, 19.08794636969025, 19.309976123658682, 19.531556258452547, 19.752693661753465, 19.9733950265697, 20.193666859193183, 20.413515486733537, 20.632947064256683, 20.85196758155338, 21.070582869561303, 21.28879860646231, 21.506620323475158, 21.724053410362178, 21.941103120667343, 22.157774576701765, 22.37407277429152, 22.590002587301786, 22.80556877195015, 23.020775970921164, 23.235628717293427, 23.450131438289592, 23.664288458859236, 23.87810400510359, 24.091582207550797, 24.304727104289665, 24.517542643969467, 24.730032688672775, 24.94220101666795, 25.15405132504749], [0.0, 0.5072600225936295, 0.9143366600529775, 1.290576352634392, 1.6480926757095749, 1.9923018599150013, 2.326265069692688, 2.6519416900252026, 2.9706885728175507, 3.283498103128477, 3.5911259458176255, 3.8941656275831003, 4.193094940431901, 4.488306288790625, 4.780127349904322, 5.068835613280023, 5.35466890104905, 5.63783316260767, 5.918508368852647, 6.196853049346452, 6.473007839923781, 6.74709829529309, 7.019237146684927, 7.289526134303438, 7.558057509670765, 7.824915278609665, 8.0901762382233, 8.353910848622657, 8.616183970879904, 8.877055495779487, 9.136580882733746, 9.39481162426404, 9.651795648396565, 9.907577668951381, 10.162199491845687, 10.415700284065116, 10.668116810789039, 10.919483645219696, 11.16983335490965, 11.419196667768622, 11.667602620429678, 11.915078691243219, 12.161650919827283, 12.40734401482063, 12.652181451249831, 12.896185558724534, 13.139377601509421, 13.38177785138115, 13.623405654060074, 13.864279489905242, 14.10441702947503, 14.343835184481588, 14.58255015460379, 14.820577470568391, 15.05793203386161, 15.294628153392186, 15.530679579391068, 15.76609953480157, 16.000900744386552, 16.235095461755094, 16.468695494490113, 16.701712227539787, 16.934156645019144, 17.166039350553852, 17.397370586285206, 17.62816025064393, 17.85841791499033, 18.088152839209062, 18.31737398633894, 18.54609003631062, 18.774309398858883, 19.00204022567005, 19.229290421819993, 19.45606765655349, 19.68237937345129, 19.908232800027513, 20.13363495679641, 20.3585926658445, 20.583112558941046, 20.80720108521738, 21.030864518443167, 21.254108963925493, 21.476940365054798, 21.699364509519718, 21.921387035211538, 22.14301343583704, 22.36424906625762, 22.585099147570904, 22.80556877195015, 23.02566290725565, 23.24538640143119, 23.46474398669799, 23.683740283557494, 23.902379804613734, 24.12066695822525, 24.3386060519959, 24.556201296113287, 24.773456806542917, 24.990376608085892, 25.20696463730712, 25.423224745340885, 25.639160700580103], [0.0, 0.516825765933465, 0.9315789212734641, 1.3149136187304662, 1.6791718675124154, 2.0298720357589026, 2.370133014348227, 2.7019511377031113, 3.0267088447973123, 3.3454172347619315, 3.6588462225369978, 3.9676005273526638, 4.272166951261084, 4.5729452985229875, 4.870269425613576, 5.164422054846104, 5.455645493123739, 5.744149573569001, 6.030117660910871, 6.313711274210377, 6.595073701366716, 6.8743328647579105, 7.151603621463125, 7.426989630269946, 7.700584882349503, 7.9724749676788385, 8.242738131575729, 8.511446162864857, 8.778665145747235, 9.044456100408112, 9.308875532095254, 9.571975904359117, 9.833806049036923, 10.094411523147297, 10.353834920969732, 10.612116148088047, 10.86929266298732, 11.125399690839915, 11.380470413346634, 11.63453613787405, 11.887626448618548, 12.139769342108258, 12.390991349007802, 12.64131764390336, 12.890772144505862, 13.139377601509421, 13.387155680173258, 13.63412703455255, 13.880311375182911, 14.125727530919947, 14.370393505547636, 14.614326529693653, 14.857543108525112, 15.100059065642126, 15.341889583538258, 15.58304924095496, 15.823552047420536, 16.063411475232233, 16.302640489112314, 16.541251573744407, 16.77925675937497, 17.016667645645793, 17.25349542380675, 17.489750897443216, 17.725444501839416, 17.960586322087448, 18.195186110041195, 18.42925330020519, 18.662797024640284, 18.895826126960426, 19.128349175488427, 19.360374475632437, 19.591910081539652, 19.82296380707896, 20.053543236199722, 20.283655732710145, 20.51330844951504, 20.742508337349605, 20.971262153042826, 21.199576467341643, 21.427457672324415, 21.654911988430115, 21.881945471127686, 22.108564017248103, 22.334773371000157, 22.560579129689152, 22.78598674915671, 23.011001548958202, 23.235628717293423, 23.459873315704947, 23.683740283557494, 23.907234442310966, 24.130360499598705, 24.35312305312195, 24.57552659437063, 24.79757551217998, 25.019274096131937, 25.240626539809547, 25.461636943912293, 25.68230931923952, 25.902647589548955, 26.122655594296624], [0.0, 0.5263603648012247, 0.9487650445542183, 1.3391716467289452, 1.7101498706269485, 2.0673198893481826, 2.4138581322595383, 2.7517977629226493, 3.0825467240727775, 3.4071347679834685, 3.7263460132792403, 4.040796335281268, 4.350981516751648, 4.657308737692616, 4.960118013690971, 5.259697282829045, 5.5562933221801805, 5.850119835948382, 6.14136357164509, 6.430189028096582, 6.716742136631877, 7.001153179589819, 7.28353913297678, 7.564005567917202, 7.842648209567189, 8.119554226900329, 8.394803308733865, 8.668468568280101, 8.9406173088866, 9.211311676462259, 9.480609218685208, 9.748563366973501, 10.01522385403271, 10.280637077334724, 10.544846416954547, 10.807892514669431, 11.069813520012877, 11.33064530800466, 11.59042167249426, 11.84917449841849, 12.10693391575427, 12.363728437520367, 12.61958508382922, 12.874529493697375, 13.12858602607882, 13.38177785138115, 13.63412703455255, 13.885654610682089, 14.136380653932859, 14.386324340522375, 14.635504006375287, 14.883937199996469, 15.131640731046648, 15.378630715045748, 15.624922614579766, 15.87053127734434, 16.11547097132089, 16.35975541734874, 16.603397819328304, 16.846410892265414, 17.08880688834509, 17.330597621203758, 17.57179448855172, 17.812408493283026, 18.052450263196004, 18.29193006943638, 18.53085784376395, 18.769243194734585, 19.007095422880884, 19.24442353496716, 19.48123625738791, 19.717542048772614, 19.953349111854457, 20.18866540465556, 20.42349865103687, 20.657856350656935, 20.891745788380092, 21.12517404317134, 21.358147996512237, 21.59067434036936, 21.822759584744578, 22.05441006483388, 22.28563194781982, 22.516431239320358, 22.746813789515635, 22.976785298972185, 23.206351324183075, 23.435517282840863, 23.664288458859232, 23.892670007158024, 24.120666958225247, 24.348284222468926, 24.575526594370626, 24.80239875645173, 25.028905283062883, 25.255050644006232, 25.48083920799956, 25.706275245990724, 25.931362934330476, 26.156106357810927, 26.380509512576776, 26.6045763089158], [0.0, 0.535864580143663, 0.9658964015024691, 1.363352372638667, 1.7410291573764731, 2.1046484093584055, 2.4574439130843433, 2.801485543892885, 3.1382066670089808, 3.468655628407395, 3.7936307051348224, 4.113758893052789, 4.429544927014867, 4.741403339260813, 5.049680284862032, 5.35466890104905, 5.656620420820472, 5.955752407125963, 6.25225497947965, 6.54629560697756, 6.838022855954818, 7.1275693611907, 7.4150542108664865, 7.700584882349503, 7.98425882925521, 8.266164794522014, 8.546383905866687, 8.824990596668778, 9.10205338553739, 9.37763554051778, 9.651795648396567, 9.924588105375129, 10.19606354215664, 10.466269193988003, 10.73524922423568, 11.003045008524351, 11.269695385233804, 11.535236877160388, 11.799703888351544, 12.063128879473808, 12.32554252454542, 12.586973851429898, 12.847450368127797, 13.106998176606053, 13.365642075655613, 13.623405654060074, 13.880311375182911, 14.136380653932859, 14.39163392694173, 14.646090716682025, 14.89976969016065, 15.152688712746702, 15.404864897624213, 15.656314651302663, 15.907053715567928, 16.157097206212757, 16.406459648848095, 16.655155012063325, 16.903196738174824, 17.150597771776663, 17.397370586285206, 17.64352720864956, 17.889079242382557, 18.13403788905178, 18.378413968356185, 18.62221793690223, 18.86545990578234, 19.108149657049083, 19.350296659169928, 19.591910081539652, 19.832998808120717, 20.07357145027568, 20.31363635885021, 20.553201635560292, 20.792275143732617, 21.03086451844317, 21.268977176095284, 21.50662032347516, 21.743800966319675, 21.98052591742878, 22.216801804352045, 22.452635076676817, 22.68803201294324, 22.92299872720961, 23.15754117528972, 23.39166516068227, 23.62537634021103, 23.858680229393016, 24.091582207550797, 24.324087522683914, 24.556201296113283, 24.787928526911617, 25.019274096131937, 25.25024277084548, 25.480839207999562, 25.71106795810522, 25.94093346876391, 26.17044008804176, 26.399592067699725, 26.628393566286878, 26.856848652104226, 27.084961306045578], [0.0, 0.5453391388693144, 0.982974302371523, 1.387457645868068, 1.7718120894937863, 2.141860450777469, 2.5008936903830596, 2.851018280871994, 3.193692930631473, 3.5299845213183554, 3.8607054442220714, 4.18649378104436, 4.507863190796479, 4.825235535014044, 5.138963089095637, 5.44934417319674, 5.756634462337107, 6.061055366171375, 6.362800365694476, 6.662039891003862, 6.958925135218586, 7.253591078217884, 7.546158913767187, 7.836738019528535, 8.12542757218332, 8.412317883723421, 8.69749151627525, 8.981024219266196, 9.262985722774848, 9.54344041348134, 9.82244791403839, 10.100063582420225, 10.376338944525534, 10.651322070762077, 10.925057905343614, 11.197588555452386, 11.468953546165013, 11.739190046033121, 12.008333067398073, 12.276415644859636, 12.54346899477977, 12.809522658260235, 13.074604629667318, 13.338741472473767, 13.601958423935038, 13.864279489905242, 14.125727530919947, 14.386324340522375, 14.646090716682025, 14.905046527045942, 15.16321076867019, 15.42060162279936, 15.677236505193681, 15.933132112444202, 16.18830446466546, 16.44276894491077, 16.696540335616696, 16.94963285234961, 17.202060175097902, 17.453835477327495, 17.704971452995764, 17.955480341698888, 18.20537395211005, 18.454663683850434, 18.703360547920823, 18.951475185809706, 19.199017887382542, 19.44599860764722, 19.692426982482083, 19.93831234340489, 20.183663731454402, 20.42848991024967, 20.672799378286683, 20.916600380526912, 21.159900919327608, 21.402708764759634, 21.645031464354886, 21.8868763523219, 22.128250558265165, 22.369161015440948, 22.60961446857975, 22.849617481303305, 23.0891764431619, 23.328297576315766, 23.56698694188275, 23.805250445972526, 24.0430938454265, 24.280522753280902, 24.517542643969463, 24.754158858281, 24.99037660808589, 25.22620098084487, 25.46163694391229, 25.696689348645407, 25.931362934330476, 26.165662331935597, 26.39959206769972, 26.63315656656665, 26.86636015547221, 27.099207066492294, 27.331701439859064, 27.563847326852045], [0.0, 0.5547847360339225, 1.0000000000000002, 1.4114892347853745, 1.8025009252216608, 2.1789587434890403, 2.544210651641051, 2.90039960759262, 3.249009585424943, 3.5911259458176255, 3.9275751511588224, 4.259006335103603, 4.585942053541799, 4.908811474900906, 5.227972976198239, 5.543730044671217, 5.8563427837825035, 6.166036438133204, 6.47300783992378, 6.777430371202006, 7.07945784384138, 7.379227575652668, 7.676862859549159, 7.9724749676788385, 8.266164794522014, 8.558024216327805, 8.848137225247589, 9.136580882733748, 9.423426126631163, 9.708738458835441, 9.992578534698987, 10.27500267102896, 10.556063286183157, 10.835809283177301, 11.114286384685572, 11.391537427211572, 11.667602620429678, 11.942519776672864, 12.216324514716998, 12.489050441340703, 12.760729313591831, 13.031391184241535, 13.301064532535126, 13.56977638204044, 13.837552407137162, 14.10441702947503, 14.370393505547636, 14.635504006375287, 14.89976969016065, 15.16321076867019, 15.425846568000246, 15.687695584305342, 15.948775534996996, 16.209103405861114, 16.468695494490117, 16.727567450380917, 16.985734312010642, 17.243210541167702, 17.500010054786, 17.756146254503694, 18.01163205414503, 18.266479905303235, 18.520701821184733, 18.774309398858883, 19.027313840043544, 19.27972597054409, 19.531556258452547, 19.782814831203446, 20.03351149157425, 20.28365573271014, 20.533256752246032, 20.78232346559205, 21.030864518443167, 21.278888298568482, 21.526402946930816, 21.77341636818326, 22.01993624058544, 22.265970025378735, 22.51152497565661, 22.756608144763433, 23.00122639425244, 23.24538640143119, 23.48909466652076, 23.73235751945289, 23.975181126327577, 24.21757149555182, 24.45953448367893, 24.70107580096625, 24.94220101666795, 25.18291556407847, 25.423224745340885, 25.663133736033753, 25.902647589548955, 26.141771241272128, 26.380509512576776, 26.618867114642107, 26.856848652104226, 27.09445862654957, 27.331701439859067, 27.56858139741067, 27.80510271114782, 28.041269502520603], [0.0, 0.5642020368446875, 1.0169746934244948, 1.4354488318178307, 1.8330978258246662, 2.2159459001443884, 2.5873978474599912, 2.949633001740029, 3.304160527070775, 3.652084207796628, 3.994244535251406, 4.331301661934967, 4.663787013963168, 4.99213704476599, 5.316716214700746, 5.63783316260767, 5.955752407125962, 6.270703016314776, 6.582885163540836, 6.892475173959017, 7.199629470352221, 7.504487701458947, 7.807175253051894, 8.107805286089643, 8.406480407705375, 8.70329405371937, 8.998331642024024, 9.291671542166249, 9.583385896139099, 9.873541317712771, 10.162199491845687, 10.449417691305538, 10.735249224235679, 11.019743823765527, 11.302947988697643, 11.584905282672143, 11.8656565979103, 12.145240388597847, 12.423692878128456, 12.70104824374551, 12.977338781563011, 13.252595054488696, 13.526846025194326, 13.800119175964522, 14.072440616993692, 14.343835184481588, 14.614326529693653, 14.883937199996469, 15.152688712746702, 15.42060162279936, 15.687695584305342, 15.95398940738572, 16.219501110199648, 16.484247966861535, 16.74824655161044, 17.011512779588685, 17.27406194454694, 17.535908753758036, 17.797067360391562, 18.057551393574382, 18.317373986338936, 18.576547801640448, 18.83508505660582, 19.09299754516112, 19.350296659169924, 19.60699340820234, 19.863098438043046, 20.118622048036666, 20.37357420735981, 20.627964570300886, 20.88180249062184, 21.13509703506915, 21.38785699609582, 21.640090903850744, 21.8918070374871, 22.14301343583704, 22.393717907496296, 22.643928040358524, 22.893651210636232, 23.142894591402147, 23.39166516068227, 23.6399697091294, 23.88781484730388, 24.1352070125861, 24.382152475743712, 24.628657347174588, 24.87472758284523, 25.12036898994285, 25.365587232258004, 25.610387835313634, 25.854776191255066, 26.09875756351473, 26.34233709126427, 26.585519793665988, 26.82831057393473, 27.070714223220516, 27.312735424321744, 27.5543787552379, 27.79564869257049, 28.03654961477994, 28.277085805306136, 28.517261455559517], [0.0, 0.5735916785016119, 1.0338995311986006, 1.45933805813647, 1.8636048615717187, 2.25282442339441, 2.6304582000021686, 2.9987217945786147, 3.359149487230608, 3.7128634318559737, 4.060718107530379, 4.403384653235485, 4.741403339260813, 5.075217882642358, 5.405198809210311, 5.7316598942771675, 6.054870058691037, 6.375062182739407, 6.6924397711420625, 7.00718208351691, 7.319448145887859, 7.6293799310750785, 7.937104911563822, 8.242738131575729, 8.546383905866687, 8.848137225247587, 9.148084929164368, 9.446306691416517, 9.742875854608602, 10.037860141119785, 10.331322262490481, 10.623320444641209, 10.913908882887526, 11.203138138034456, 11.491055482733401, 11.777705205625356, 12.063128879473807, 12.347365598432088, 12.630452188735875, 12.912423396417829, 13.193312055074832, 13.473149236252898, 13.751964384630398, 14.02978543986145, 14.306638946675179, 14.58255015460379, 14.857543108525112, 15.131640731046648, 15.404864897624213, 15.677236505193681, 15.948775534996996, 16.219501110199648, 16.489431548825102, 16.758584412469443, 17.026976551205834, 17.294624145041798, 17.561542742251785, 17.827747294872054, 18.09325219161404, 18.358071288425155, 18.622217936902228, 18.885705010741674, 19.14854493039196, 19.410749686057677, 19.672330859189664, 19.933299642583016, 20.19366685919318, 20.453442979769964, 20.712638139400394, 20.971262153042822, 21.229324530127673, 21.486834488293294, 21.74380096631967, 22.00023263631734, 22.256137915223942, 22.511524975656606, 22.766401756164363, 23.020775970921164, 23.274655118896955, 23.528046492541165, 23.780957186010475, 24.033394102970032, 24.285363963995362, 24.536873313599926, 24.787928526911614, 25.038535816019618, 25.288701236011647, 25.5384306907201, 25.78772993819425, 26.03660459591467, 26.2850601457646, 26.533101938772287, 26.78073519963722, 27.027965031052307, 27.27479641783335, 27.52123423086632, 27.767283230882324, 28.012948072069477, 28.258233305530403, 28.503143382593354, 28.747682657984665, 28.991855392869663], [0.0, 0.5829542718920598, 1.0507756144473572, 1.4831584679674317, 1.8940240172417202, 2.2895967125451375, 2.673394510761636, 3.0476691798110087, 3.413980043470247, 3.773467572274362, 4.127000192747083, 4.475259998703675, 4.818796079130358, 5.158059393745237, 5.493426516378882, 5.8252163440196725, 6.153702187043406, 6.47912072698421, 6.80167879031847, 7.121558562673967, 7.438921665816589, 7.753912389953313, 8.066660288270862, 8.377282282828904, 8.685884391086981, 8.992563154367211, 9.297406829574069, 9.60049639100253, 9.901906378410139, 10.201705619591497, 10.4999578497118, 10.796722245098689, 11.092053885684296, 11.386004157565004, 11.678621105011876, 11.969949739578304, 12.260032312609589, 12.548908556383141, 12.836615898240066, 13.123189651363814, 13.408663185285857, 13.693068078725272, 13.976434256978544, 14.258790115751777, 14.540162633057058, 14.820577470568391, 15.100059065642126, 15.378630715045748, 15.656314651302663, 15.933132112444202, 16.209103405861114, 16.484247966861535, 16.758584412469443, 17.03213059093446, 17.30490362736927, 17.576919965883615, 17.848195408542537, 18.11874515144064, 18.388583818152686, 18.657725490793258, 18.926183738893954, 19.19397164628531, 19.461101836151673, 19.727586494410737, 19.993437391554455, 20.258665903075133, 20.523283028588597, 20.787299409756088, 21.05072534709712, 21.313570815777155, 21.57584548044667, 21.83755870920121, 22.09871958672624, 22.359336926684975, 22.619419283402625, 22.878974962895906, 23.138012033292796, 23.396538334683775, 23.6545614884426, 23.912088906051526, 24.16912779746338, 24.425685179030097, 24.68176788102549, 24.937382554787465, 25.19253567950354, 25.447233568661265, 25.701482376184046, 25.955288102271055, 26.208656598958758, 26.461593575420466, 26.71410460301882, 26.96619512012557, 27.217870436721654, 27.46913573878997, 27.71999609251221, 27.970456448280608, 28.220521644534493, 28.47019641143112, 28.719485374359625, 28.968393057306177, 29.216923886078224, 29.46508219139502], [0.0, 0.592290403152777, 1.067603999682791, 1.5069115525660677, 1.9243571971985762, 2.326265069692688, 2.7162094677275457, 3.0964782217442783, 3.468655628407395, 3.8339004231195424, 4.193094940431901, 4.546932198030952, 4.895970078674736, 5.240666764292987, 5.581404859622784, 5.918508368852648, 6.25225497947965, 6.582885163540838, 6.910609059880691, 7.235611771866883, 7.558057509670765, 7.878092874336332, 8.195849493870949, 8.511446162864857, 8.824990596668778, 9.136580882733746, 9.446306691416517, 9.754250293831872, 10.06048742350674, 10.36508801052685, 10.66811681078904, 10.969633948341876, 11.269695385233804, 11.568353330520003, 11.865656597910302, 12.161650919827283, 12.456379224280136, 12.749881879866779, 13.042196913334797, 13.33336020341546, 13.623405654060074, 13.912365349727324, 14.20026969497341, 14.487147540267443, 14.773026295679866, 15.05793203386161, 15.341889583538258, 15.624922614579766, 15.907053715567928, 16.18830446466546, 16.468695494490117, 16.74824655161044, 17.026976551205834, 17.30490362736927, 17.582045179475603, 17.85841791499033, 18.13403788905178, 18.408920541123102, 18.68308072897859, 18.95653276026075, 19.229290421819993, 19.501367007027063, 19.77277534122917, 20.043527805503956, 20.31363635885021, 20.583112558941046, 20.851967581553385, 21.120212238776833, 21.387856996095824, 21.65491198843012, 21.921387035211538, 22.18729165456759, 22.452635076676817, 22.717426256355047, 22.981673884926753, 23.245386401431194, 23.508572003209057, 23.77123865591147, 24.03339410297004, 24.295045874563417, 24.556201296113283, 24.816867496339896, 25.077051414905274, 25.336759809669864, 25.59599926358668, 25.85477619125507, 26.11309684515477, 26.370967321579364, 26.628393566286874, 26.88538137988418, 27.14193642296043, 27.398064220984, 27.653770168976266, 27.90905953597468, 28.16393746929688, 28.418408998616627, 28.67247903986184, 28.926152398944218, 29.179433775329436, 29.43232776545622, 29.684838866012225, 29.936971477074056], [0.0, 0.6016006351119998, 1.0843857014033182, 1.5305987438859712, 1.9546062300766205, 2.3628317053872556, 2.7589056519975745, 3.1451518628292323, 3.5231795381571303, 3.8941656275831003, 4.259006335103603, 4.618405571972496, 4.972929990324897, 5.323044974267076, 5.66913914271232, 6.0115415928814455, 6.35053437725025, 6.686361747843492, 7.019237146684926, 7.349348586788038, 7.676862859549158, 8.001928870438825, 8.324680316529298, 8.645237859746814, 8.96371090862317, 9.280199092449209, 9.594793491112917, 9.907577668951381, 10.218628549949287, 10.52801716342564, 10.835809283177301, 11.142065978344705, 11.44684409064554, 11.750196649810805, 12.052173236854612, 12.35282030306897, 12.65218145124983, 12.950297684550401, 13.247207627461943, 13.54294772269466, 13.83755240713716, 14.131054269584775, 14.4234841925239, 14.714871479925103, 15.005243972718606, 15.294628153392186, 15.58304924095496, 15.87053127734434, 16.157097206212757, 16.44276894491077, 16.727567450380917, 17.011512779588685, 17.294624145041798, 17.576919965883615, 17.85841791499033, 18.139134962452623, 18.419087415780066, 18.69829095712923, 18.976760677824238, 19.25451111040989, 19.531556258452543, 19.807909624281866, 20.083584234847116, 20.3585926658445, 20.63294706425668, 20.90665916943222, 21.179740332820433, 21.452201536466514, 21.724053410362178, 21.995306248738324, 22.265970025378735, 22.536054408026672, 22.80556877195015, 23.07452221272604, 23.342923558298025, 23.610781380358894, 23.87810400510359, 24.144899523395576, 24.411175800385706, 24.676940484619756, 24.942201016667948, 25.206964637307117, 25.471238395284054, 25.735029154686234, 25.998343601944324, 26.261188252488964, 26.523569457082825, 26.785493407847316, 27.04696614400203, 27.30799355733377, 27.568581397410668, 27.82873527655612, 28.08846067459601, 28.347762943391967, 28.606647311172477, 28.865118886672903, 29.123182663094802, 29.380843521894143, 29.638106236407655, 29.89497547532564, 30.15145580601933, 30.407551697730277], [0.0, 0.6108855086228687, 1.1011216944972257, 1.5542214179714637, 1.984772873112892, 2.3992987438701974, 2.8014855438928845, 3.1936929306314736, 3.577554940140841, 3.9542666866116556, 4.324738205709199, 4.689684272583698, 5.049680284862032, 5.405198809210311, 5.756634462337107, 6.10432142062355, 6.4485460896351885, 6.789556491088869, 7.127569361190699, 7.4627756146749125, 7.7953446171322955, 8.125427572183318, 8.453160240329586, 8.778665145747235, 9.10205338553739, 9.423426126631163, 9.742875854608604, 10.06048742350674, 10.376338944525532, 10.690502543223262, 11.003045008524351, 11.314028352086925, 11.62351029290195, 11.931544679140956, 12.23818185703242, 12.54346899477977, 12.847450368127795, 13.15016761305665, 13.451659950173177, 13.751964384630398, 14.051115884802654, 14.349147542448245, 14.646090716682023, 14.941975163740798, 15.236829154241034, 15.530679579391068, 15.823552047420536, 16.11547097132089, 16.406459648848095, 16.696540335616696, 16.985734312010642, 17.27406194454694, 17.561542742251785, 17.848195408542537, 18.13403788905178, 18.419087415780066, 18.703360547920823, 18.986873209663003, 19.269640725244443, 19.551677851499672, 19.832998808120713, 20.11361730582702, 20.39354657262078, 20.67279937828668, 20.951388057279257, 21.229324530127673, 21.506620323475158, 21.783286588859582, 22.059334120331876, 22.334773371000153, 22.60961446857975, 22.88386723002217, 23.157541175289715, 23.43064554033691, 23.703189289354526, 23.975181126327577, 24.246629505954306, 24.517542643969463, 24.787928526911617, 25.057794921371272, 25.327149382753557, 25.595999263586677, 25.864351721405082, 26.13221372623394, 26.399592067699718, 26.666493361789726, 26.932924057281863, 27.198890441864368, 27.464398647963833, 27.72945465829864, 27.99406431117355, 28.2582333055304, 28.521967205768618, 28.785271446348403, 29.048151336188717, 29.31061206287119, 29.572658696660532, 29.834296194351232, 30.095529402949875, 30.356363063201528, 30.616801812968486, 30.876850190468854], [0.0, 0.6201455437981329, 1.1178129164682244, 1.5777808980989416, 2.0148588161586973, 2.4356682279234216, 2.843951528620405, 3.2421041442864, 3.6317848803170714, 4.014206966899111, 4.39029423436497, 4.760772292698802, 5.126225261623836, 5.487132871151667, 5.843895719741216, 6.196853049346452, 6.5462956069775595, 6.892475173959018, 7.235611771866882, 7.575899209393634, 7.9135094194381805, 8.248595897623053, 8.581296462359237, 8.911735495090994, 9.240025776971613, 9.566270008459073, 9.890562077065068, 10.212988123076432, 10.533627441732442, 10.852553251898057, 11.169833354909649, 11.485530702421675, 11.799703888351543, 12.112407577121878, 12.423692878128456, 12.7336076745683, 13.042196913334795, 13.34950286154214, 13.655565334318073, 13.960421897753815, 14.264108050287646, 14.566657385295338, 14.868101737245146, 15.168471313430253, 15.46779481300389, 15.76609953480157, 16.063411475232233, 16.35975541734874, 16.655155012063325, 16.94963285234961, 17.243210541167702, 17.535908753758036, 17.827747294872054, 18.11874515144064, 18.408920541123102, 18.69829095712923, 18.986873209663003, 19.2746834642983, 19.561737277563587, 19.848049629983112, 20.133634956796406, 20.418507176555224, 20.702679717776856, 20.986165543815243, 21.26897717609528, 21.551126715842052, 21.83262586442404, 22.113485942418365, 22.3937179074963, 22.67333237121814, 22.952339614818996, 23.23074960405946, 23.508572003209053, 23.785816188224405, 24.062491259178913, 24.338606051995903, 24.614169149533158, 24.889188892062666, 25.163673387185987, 25.43763051922256, 25.711067958105218, 25.9839931678146, 26.256413414381782, 26.52833577348623, 26.799767137674156, 27.070714223220516, 27.341183576656245, 27.611181580980762, 27.88071446157831, 28.149788291855593, 28.41840899861662, 28.686582367189967, 28.954314046322335, 29.221609552851547, 29.488474276171182, 29.7549134824982, 30.020932318954323, 30.286535817471016, 30.551728898527628, 30.816516374731258, 31.080902954246675, 31.344893244084027], [0.0, 0.6293812411550551, 1.134460269499144, 1.601278457689756, 2.0448656853994214, 2.471942123366092, 2.886305901523299, 3.2903881204847343, 3.6858722898864817, 4.07398970829763, 4.455677964461778, 4.831673474720194, 5.202569057968486, 5.568851588736571, 5.930927631512095, 6.289141480508208, 6.643788212769264, 6.995123359346134, 7.343370218550002, 7.6887254854255085, 8.03136365343212, 8.371440504170439, 8.709095908552106, 9.044456100408112, 9.377635540517778, 9.70873845883544, 10.037860141119785, 10.36508801052685, 10.69050254322326, 11.014178048507155, 11.336183337465972, 11.656582299279934, 11.975434400493361, 12.292795119634645, 12.608716327261057, 12.923246619684022, 13.236431613181567, 13.54831420434315, 13.858934801254842, 14.168331529471773, 14.476540416103012, 14.783595554823417, 15.0895292542053, 15.394372171412712, 15.69815343300935, 16.000900744386552, 16.302640489112314, 16.603397819328304, 16.903196738174824, 17.202060175097902, 17.500010054786, 17.797067360391562, 18.09325219161404, 18.388583818152686, 18.68308072897859, 18.976760677824238, 19.269640725244443, 19.561737277563587, 19.85306612299025, 20.143642465150474, 20.433480954264784, 20.722595716171003, 21.01100037937451, 21.298708100289755, 21.585731586820586, 21.872083120413087, 22.15777457670176, 22.44281744485872, 22.727222845745516, 23.0110015489582, 23.294163988848148, 23.576720279593932, 23.858680229393013, 24.140053353836176, 24.420848888522293, 24.701075800966247, 24.98074280184852, 25.259858355651016, 25.5384306907201, 25.816467808794734, 26.09397749403444, 26.37096732157936, 26.64744466567204, 26.923416707368556, 27.198890441864364, 27.4738726854585, 27.748370082178, 28.022389110082948, 28.29593608727094, 28.569017177598642, 28.841638396136716, 29.11380561437342, 29.38552456518105, 29.656800847558543, 29.927639931162574, 30.19804716063878, 30.468027759763874, 30.737586835408827, 31.00672938133265, 31.27546028181559, 31.543784315140126, 31.81170615692764], [0.0, 0.6385930826784818, 1.1510646223681158, 1.6247153230148874, 2.07479504680845, 2.5081223232299155, 2.928550872956144, 3.33854737903023, 3.739819991517549, 4.133618030698907, 4.520892808191024, 4.902391518779441, 5.2787156580621515, 5.650359226633084, 6.017734739598339, 6.38119153038025, 6.7410289948728455, 7.097506404167836, 7.450850324847718, 7.801260330853834, 8.148913469592273, 8.493967802737023, 8.836565248398765, 9.176833888010496, 9.514889857639094, 9.850838912784553, 10.184777733840882, 10.516795023519665, 10.846972435864533, 11.175385367790216, 11.502103637527027, 11.827192069359327, 12.150711000204346, 12.472716720593402, 12.793261860279186, 13.112395726845543, 13.430164604226123, 13.7466120168597, 14.061778964259075, 14.375704129998184, 14.688424068491322, 14.999973372420174, 15.310384823236479, 15.619689526813152, 15.927917036020347, 16.235095461755094, 16.541251573744407, 16.846410892265414, 17.150597771776663, 17.453835477327495, 17.756146254503694, 18.057551393574382, 18.358071288425155, 18.657725490793258, 18.95653276026075, 19.25451111040989, 19.551677851499672, 19.848049629983112, 20.143642465150474, 20.438471783153325, 20.73255244863789, 21.025898794192642, 21.318524647794472, 21.610443358419666, 21.90166781996934, 22.19221049364508, 22.482083428897283, 22.77129828305755, 23.059866339756216, 23.347798526216863, 23.63510542951164, 23.921797311853737, 24.207884124996784, 24.493375523805042, 24.778280879052808, 25.06260928950661, 25.346369593339464, 25.629570378922356, 25.912219995034576, 26.1943265605313, 26.47589797350372, 26.756941919964323, 27.037465882087638, 27.31747714603415, 27.596982809383423, 27.875989788200194, 28.154504823755786, 28.432534488925413, 28.71008519428052, 28.987163193894126, 29.263774590875535, 29.53992534265014, 29.815621265998544, 30.090868041868564, 30.36567121997267, 30.64003622318257, 30.913968351731985, 31.187472787237812, 31.460554596549457, 31.73321873543517, 32.005470052114035, 32.27731329064143], [0.0, 0.6477815328092162, 1.1676268122301177, 1.6480926757095749, 2.1046484093584055, 2.5442106516410505, 2.9706885728175507, 3.386584348006855, 3.7936307051348215, 4.1930949404319, 4.585942053541798, 4.9729299903248965, 5.35466890104905, 5.731659894277167, 6.10432142062355, 6.47300783992378, 6.838022855954817, 7.199629470352221, 7.558057509670763, 7.91350941943818, 8.266164794522012, 8.616183970879902, 8.963710908623169, 9.308875532095252, 9.651795648396565, 9.992578534698985, 10.33132226249048, 10.668116810789039, 11.00304500852435, 11.33618333746597, 11.667602620429678, 11.997368614429487, 12.325542524545419, 12.652181451249827, 12.977338781563013, 13.301064532535122, 13.623405654060072, 13.944406296831671, 14.264108050287646, 14.582550154603789, 14.899769690160646, 15.2158017473796, 15.530679579391068, 15.844434739637416, 16.157097206212754, 16.468695494490113, 16.77925675937497, 17.08880688834509, 17.397370586285206, 17.704971452995764, 18.01163205414503, 18.317373986338936, 18.622217936902228, 18.926183738893954, 19.229290421819993, 19.531556258452543, 19.832998808120713, 20.133634956796406, 20.433480954264784, 20.73255244863789, 21.030864518443163, 21.32843170249472, 21.62526802773446, 21.921387035211534, 22.21680180435204, 22.511524975656602, 22.80556877195015, 23.09894501829677, 23.39166516068227, 23.68374028355749, 23.975181126327573, 24.26599809886441, 24.556201296113283, 24.84580051185827, 25.134805251705835, 25.423224745340885, 25.711067958105218, 25.998343601944324, 26.2850601457646, 26.571225825240056, 26.85684865210422, 27.141936422960427, 27.42649672764109, 27.71053695714424, 27.994064311173545, 28.277085805306132, 28.559608277810664, 28.84163839613672, 29.123182663094795, 29.404247422745158, 29.684838866012218, 29.96496303604028, 30.244625833305182, 30.523833020495537, 30.802590227176314, 31.08090295424667, 31.358776578203187, 31.636216355218885, 31.913227425047957, 32.18981481476514, 32.46598344234853, 32.741738120113745], [0.0, 0.6569470393640988, 1.1841476462754188, 1.671411655114193, 2.134427228010494, 2.580208867433791, 3.0127210547696, 3.434501368588949, 3.84730705330722, 4.252423336218528, 4.650828870814541, 5.0432923271850285, 5.430432488656981, 5.812757554013674, 6.19069189455664, 6.564594883983743, 6.934774523198084, 7.301497535063899, 7.6649969979680765, 8.025478221854392, 8.383123342690821, 8.738094965039771, 9.090539085914315, 9.44058746796659, 9.788359585157973, 10.133964232532605, 10.477500869198845, 10.819060747294154, 11.158727867700577, 11.496579794333622, 11.832688352086077, 12.167120228372582, 12.499937494268147, 12.831198058163732, 13.160956062456352, 13.48926223189092, 13.81616418065871, 14.14170668414481, 14.46593192023883, 14.788879684328572, 15.110587581447504, 15.431091198513855, 15.75042425915892, 16.06861876327695, 16.385705113124224, 16.701712227539787, 17.016667645645793, 17.330597621203758, 17.64352720864956, 17.955480341698888, 18.266479905303235, 18.576547801640448, 18.885705010741674, 19.19397164628531, 19.501367007027063, 19.807909624281866, 20.11361730582702, 20.418507176555224, 20.722595716171003, 21.025898794192642, 21.32843170249472, 21.63020918560206, 21.93124546892476, 22.23155428510522, 22.53114889863126, 22.830042128854842, 23.128246371542506, 23.425773619072004, 23.7226354793792, 24.018843193749618, 24.314407653540986, 24.609339415915226, 24.90364871865169, 25.197345494107417, 25.49043938238436, 25.78293974375888, 26.074855670424043, 26.36619599759125, 26.656969313994075, 26.94718397183364, 27.236848096202063, 27.52596959401737, 27.81455616250105, 28.102615297226873, 28.39015429976764, 28.677180284964358, 28.963700187840843, 29.249720770184886, 29.535248626815708, 29.82029019155613, 30.104851742926385, 30.388939409575663, 30.67255917546604, 30.955716884822817, 31.238418246864082, 31.520668840321598, 31.80247411776437, 32.08383940973539, 32.36476992871159, 32.64527077289614, 32.925346929851955, 33.20500327998445], [0.0, 0.6660900343935533, 1.2006279032753076, 1.6946733604560322, 2.1641329065006842, 2.6161186675186445, 3.0546503001704988, 3.4823006995244516, 3.9008515662701244, 4.311606014724571, 4.715556318692015, 5.11348184615169, 5.506009992285947, 5.8936560286840445, 6.27685023279286, 6.655956979857929, 7.031288557354264, 7.403115400235013, 7.771673830732315, 8.137172016170652, 8.499794627377206, 8.859706531947191, 9.217055758792586, 9.571975904359117, 9.924588105375129, 10.275002671028957, 10.623320444641209, 10.969633948341876, 11.314028352086924, 11.656582299279934, 11.997368614429488, 12.336454913065682, 12.673904130131536, 13.009774979952274, 13.344122358446334, 13.676997696315219, 14.008449270415966, 14.338522479290631, 14.667260087835407, 14.99470244528644, 15.320887680041512, 15.64585187429624, 15.969629221027203, 16.292252165483998, 16.613751533043274, 16.934156645019144, 17.25349542380675, 17.57179448855172, 17.889079242382557, 18.20537395211005, 18.520701821184733, 18.83508505660582, 19.14854493039196, 19.461101836151673, 19.77277534122917, 20.083584234847116, 20.39354657262078, 20.702679717776856, 21.01100037937451, 21.318524647794472, 21.62526802773446, 21.93124546892476, 22.23647139475619, 22.540959728993837, 22.84472392073272, 23.14777696773684, 23.45013143828959, 23.751799491671445, 24.052792897370566, 24.353123053121948, 24.652801001862702, 24.951837447683, 25.250242770845478, 25.54802704193975, 25.845200035232942, 26.141771241272124, 26.437749878790054, 26.733144905961314, 27.02796503105231, 27.322218722505102, 27.615914218491966, 27.909059535974674, 28.201662479300026, 28.4937306483607, 28.7852714463484, 29.07629208712423, 29.366799602229513, 29.656800847558543, 29.94630250971328, 30.23531111205864, 30.523833020495534, 30.811874448968013, 31.099441464719355, 31.386539993311285, 31.673175823419356, 31.959354611416785, 32.24508188575816, 32.53036305117378, 32.815203392684694, 33.09960807944782, 33.38358216843997, 33.66713060798913], [0.0, 0.6752109349817923, 1.217068335024463, 1.717878852885189, 2.1937667999395805, 2.6519416900252017, 3.096478221744278, 3.5299845213183554, 3.954266686611655, 4.370645675739407, 4.780127349904321, 5.183501749123182, 5.581404859622784, 5.974359008706624, 6.3628003656944765, 6.747098295293089, 7.127569361190699, 7.504487701458947, 7.87809287433633, 8.248595897623051, 8.616183970879902, 8.981024219266196, 9.343266698682632, 9.703046834937092, 10.06048742350674, 10.415700284065116, 10.768787640800053, 11.119843282765098, 11.468953546165013, 11.81619815128282, 12.161650919827283, 12.505380393201124, 12.847450368127795, 13.187920362919217, 13.526846025194326, 13.86427948990524, 14.200269694973407, 14.534862660591962, 14.868101737245146, 15.200027826679063, 15.530679579391066, 15.860093571657307, 16.18830446466546, 16.515345147944238, 16.841246868968174, 17.166039350553852, 17.489750897443216, 17.812408493283026, 18.13403788905178, 18.454663683850434, 18.774309398858883, 19.09299754516112, 19.410749686057677, 19.727586494410737, 20.043527805503956, 20.3585926658445, 20.67279937828668, 20.986165543815243, 21.298708100289755, 21.610443358419666, 21.921387035211534, 22.23155428510522, 22.540959728993837, 22.849617481303305, 23.157541175289715, 23.46474398669799, 23.771238655911468, 24.077037508710028, 24.382152475743716, 24.68659511081893, 24.99037660808589, 25.29350781820794, 25.595999263586677, 25.897861152710266, 26.199103393686777, 26.499735607019186, 26.799767137674152, 27.099207066492294, 27.398064220984, 27.69634718555136, 27.99406431117355, 28.29122372459015, 28.587833337014413, 28.88390085240582, 29.17943377532943, 29.474439418427146, 29.76892490952455, 30.062897198395042, 30.356363063201524, 30.649329116634615, 30.94180181176475, 31.233787447624724, 31.52529217453776, 31.816321999205453, 32.10688278956882, 32.3969802794549, 32.68662007302048, 32.97580764900388, 33.26454836479499, 33.552847460332984, 33.84071006184085, 34.128141185405], [0.0, 0.6843101439943604, 1.2334696676884025, 1.7410291573764731, 2.2233302172411995, 2.687679517238165, 3.1382066670089808, 3.5775549401408413, 4.007554773650537, 4.429544927014866, 4.844544816521099, 5.253355128843041, 5.656620420820472, 6.054870058691036, 6.4485460896351885, 6.838022855954817, 7.2236211873815765, 7.6056189162987415, 7.984258829255208, 8.359754787747823, 8.732296514057081, 9.10205338553739, 9.469177480257537, 9.833806049036921, 10.196063542156638, 10.556063286183157, 10.913908882887524, 11.269695385233803, 11.623510292901948, 11.975434400493361, 12.32554252454542, 12.673904130131534, 13.020583873706082, 13.36564207565561, 13.709135133511845, 14.051115884802654, 14.391633926941726, 14.730735900294848, 15.068465739541658, 15.404864897624211, 15.739972545897768, 16.073825753543982, 16.406459648848095, 16.73790756456135, 17.068201169252326, 17.397370586285206, 17.725444501839416, 18.052450263196004, 18.378413968356185, 18.703360547920823, 19.027313840043544, 19.350296659169924, 19.672330859189664, 19.993437391554455, 20.31363635885021, 20.63294706425668, 20.951388057279257, 21.26897717609528, 21.585731586820586, 21.90166781996934, 22.21680180435204, 22.53114889863126, 22.84472392073272, 23.157541175289715, 23.469614479281447, 23.780957186010475, 24.091582207550793, 24.401502035785708, 24.710728762143876, 25.019274096131934, 25.327149382753557, 25.63436561889671, 25.9409334687639, 26.246863278413898, 26.552165089477395, 26.856848652104222, 27.16092343719473, 27.464398647963833, 27.767283230882324, 28.06958588603654, 28.371315076944263, 28.672479039861834, 28.973085792614782, 29.273143142981912, 29.57265869666053, 29.871639864838425, 30.170093871396464, 30.468027759763874, 30.765448399446743, 31.062362492248962, 31.358776578203184, 31.65469704122858, 31.95013011453074, 32.24508188575816, 32.539558301928814, 32.83356517413934, 33.12710818206871, 33.42019287828726, 33.71282469238159, 34.00500893490481, 34.296750801161394, 34.588055374835015], [0.0, 0.6933880507772526, 1.2498326030636417, 1.764125264508112, 2.2528244233944106, 2.7233336783431885, 3.1798374214827785, 3.625013991482249, 4.060718107530379, 4.488306288790625, 4.908811474900906, 5.323044974267076, 5.731659894277168, 6.135192623624073, 6.534091073588217, 6.928734552413545, 7.319448145887859, 7.706513372057286, 8.090176238223298, 8.470653442921984, 8.848137225247587, 9.222799209476978, 9.594793491112915, 9.964259141713764, 10.331322262490481, 10.696097683374662, 11.0586903804955, 11.419196667768622, 11.777705205625356, 12.134297860470385, 12.489050441340703, 12.842033334817993, 13.193312055074834, 13.542947722694658, 13.890997483366357, 14.237514875548737, 14.582550154603789, 14.926150579618064, 15.268360668098923, 15.609222422893973, 15.948775534996994, 16.287057565341186, 16.624104108215853, 16.959948938557126, 17.294624145041798, 17.62816025064393, 17.960586322087448, 18.29193006943638, 18.62221793690223, 18.951475185809706, 19.27972597054409, 19.60699340820234, 19.933299642583016, 20.258665903075133, 20.583112558941046, 20.90665916943222, 21.229324530127673, 21.551126715842052, 21.872083120413087, 22.19221049364508, 22.511524975656602, 22.830042128854842, 23.14777696773684, 23.46474398669799, 23.780957186010475, 24.09643009611881, 24.411175800385703, 24.725206956409014, 25.03853581601962, 25.35117424405987, 25.663133736033753, 25.97442543471151, 26.2850601457646, 26.595048352500307, 26.904400229759382, 27.213125657034983, 27.52123423086632, 27.82873527655612, 28.13563785925708, 28.441950794468948, 28.747682657984665, 29.05284179532092, 29.35743633066594, 29.661474175374792, 29.964963036040285, 30.267910422165375, 30.57032365346134, 30.87220986679397, 31.17357602279871, 31.474428912184088, 31.77477516174138, 32.07462124007742, 32.37397346308613, 32.67283799917338, 32.97122087424899, 33.26912797649831, 33.56656506094568, 33.86353775382059, 34.160051556737336, 34.45611185069767, 34.75172389992579, 35.04689285554443], [0.0, 0.7024450318114386, 1.266157819757477, 1.787168132126999, 2.2822506415894925, 2.758905651997574, 3.2213722116855825, 3.6723636435749127, 4.113758893052789, 4.546932198030952, 4.9729299903248965, 5.392574175588059, 5.80652639204661, 6.215330034661015, 6.6194388652941685, 7.019237146684927, 7.415054210866486, 7.807175253051894, 8.195849493870949, 8.581296462359237, 8.96371090862317, 9.343266698682632, 9.72011994082391, 10.094411523147297, 10.466269193988005, 10.835809283177301, 11.203138138034456, 11.568353330520003, 11.931544679140957, 12.292795119634645, 12.652181451249831, 13.009774979952276, 13.365642075655613, 13.719844657295598, 14.072440616993692, 14.4234841925239, 14.773026295679863, 15.12111480284266, 15.46779481300389, 15.813108877649098, 16.157097206212754, 16.499797850246065, 16.841246868968174, 17.181478478480823, 17.52052518660061, 17.85841791499033, 18.195186110041195, 18.53085784376395, 18.86545990578234, 19.199017887382542, 19.531556258452547, 19.863098438043046, 20.19366685919318, 20.523283028588597, 20.851967581553385, 21.179740332820433, 21.506620323475158, 21.83262586442404, 22.15777457670176, 22.482083428897283, 22.80556877195015, 23.128246371542506, 23.45013143828959, 23.771238655911468, 24.091582207550793, 24.411175800385703, 24.730032688672775, 25.048165695342426, 25.365587232258008, 25.682309319239515, 25.998343601944324, 26.313701368688676, 26.628393566286874, 26.94243081497835, 27.25582342250684, 27.56858139741067, 27.88071446157831, 28.19223206211887, 28.503143382593358, 28.813457353648904, 29.1231826630948, 29.432327765456215, 29.7409008910389, 30.04891005453543, 30.356363063201528, 30.663267524628708, 30.969630854137733, 31.275460281815594, 31.58076285921701, 31.885545465750223, 32.18981481476514, 32.49357745936105, 32.796839797929564, 33.09960807944782, 33.401888408535584, 33.70368675028924, 34.005008934904815, 34.30586066210116, 34.60624750535424, 34.90617491595203, 35.20564822687963, 35.504672656543306], [0.0, 0.7114814513262697, 1.282445974293651, 1.8101586869093291, 2.3116100552110996, 2.7943968687394714, 3.262812707952092, 3.71960580060004, 4.166679263269701, 4.605425012395293, 5.036902941339409, 5.461945528944772, 5.881222924908638, 6.295285514553146, 6.704592897041428, 7.109534278359362, 7.510443227145544, 7.9076086074318885, 8.301282845881493, 8.691688295603536, 9.079022212015987, 9.46346069779246, 9.845161869433262, 10.22426842745663, 10.60090976358266, 10.975203704137169, 11.347257964516563, 11.717171371870224, 12.085034900151745, 12.450932552003454, 12.814942114637864, 13.177135811317598, 13.537580865754597, 13.8963399934245, 14.253471831186745, 14.609031314542932, 14.96307001022809, 15.315636410516422, 15.666776194563651, 16.016532461247728, 16.364945937266825, 16.712055163676325, 17.057896663569732, 17.402505093212824, 17.74591337861047, 18.088152839209062, 18.42925330020519, 18.769243194734585, 19.108149657049083, 19.44599860764722, 19.782814831203446, 20.118622048036666, 20.453442979769964, 20.787299409756088, 21.120212238776833, 21.452201536466514, 21.783286588859582, 22.113485942418365, 22.44281744485872, 22.77129828305755, 23.09894501829677, 23.425773619072004, 23.751799491671445, 24.077037508710028, 24.401502035785708, 24.725206956409014, 25.048165695342426, 25.370391240473587, 25.691896163334988, 26.012692638372453, 26.33279246105585, 26.652207064916997, 26.970947537592618, 27.28902463594342, 27.606448800314404, 27.923230167996103, 28.239378585941665, 28.554903622790057, 28.869814580241794, 29.18412050382997, 29.497830193125907, 29.810952211415803, 30.12349489488201, 30.43546636132001, 30.746874518419915, 31.0577270716391, 31.368031531690775, 31.67779522167148, 31.987025283848816, 32.29572868612936, 32.60391222822514, 32.911582547536064, 33.218746124764195, 33.525409289274975, 33.83157822421945, 34.13725897143042, 34.442457436104924, 34.74717939128438, 35.05143048214324, 35.35521623009615, 35.658542036732996, 35.96141318759087], [0.0, 0.7204976618749289, 1.2986977021496025, 1.8330978258246664, 2.340903809707903, 2.8298087132480014, 3.3041605270707755, 3.766742305696144, 4.219481282853406, 4.663787013963168, 5.10073282382984, 5.531161740839649, 5.9557524071259635, 6.375062182739407, 6.78955649108887, 7.199629470352222, 7.605618916298742, 8.00781735357431, 8.406480407705375, 8.801833249558971, 9.194075634261779, 9.5833858961391, 9.969924155414118, 10.353834920969733, 10.73524922423568, 11.114286384685572, 11.491055482733403, 11.865656597910302, 12.23818185703242, 12.608716327261059, 12.977338781563015, 13.344122358446336, 13.709135133511847, 14.072440616993692, 14.434098188823764, 14.79416348067086, 15.152688712746702, 15.50972299184123, 15.865312575976821, 16.219501110199648, 16.572329837314783, 16.923837786787068, 17.274061944546943, 17.623037406039863, 17.97079751452373, 18.31737398633894, 18.662797024640284, 19.007095422880884, 19.350296659169928, 19.692426982482083, 20.03351149157425, 20.37357420735981, 20.712638139400394, 21.05072534709712, 21.387856996095824, 21.724053410362178, 22.059334120331876, 22.3937179074963, 22.727222845745516, 23.059866339756216, 23.39166516068227, 23.7226354793792, 24.052792897370566, 24.382152475743716, 24.710728762143876, 25.03853581601962, 25.365587232258008, 25.691896163334988, 26.01747534009513, 26.34233709126427, 26.66649336178973, 26.989955730094152, 27.312735424321744, 27.63484333764895, 27.956290042725477, 28.27708580530614, 28.597240597129066, 28.916764108091286, 29.235665757768622, 29.553954706323196, 29.87163986483843, 30.1887299051183, 30.50523326898499, 30.821158177106305, 31.13651263738214, 31.451304452916858, 31.765541229602785, 32.079230383338015, 32.39237914690014, 32.70499457649617, 33.017083558007116, 33.32865281294498, 33.63970890413816, 33.95025824116067, 34.26030708551919, 34.56986155561132, 34.878927631467405, 35.187511159287396, 35.49561785578395, 35.80325331234151, 36.11042299900135, 36.41713226828123], [0.0, 0.7294940048747914, 1.3149136187304662, 1.855986417510733, 2.370133014348227, 2.8651425264655628, 3.345417234761931, 3.8137749437840354, 4.272166951261082, 4.722020412731921, 5.164422054846104, 5.600225432287059, 6.0301176609108715, 6.4546630601275865, 6.87433286475791, 7.289526134303437, 7.700584882349502, 8.107805286089643, 8.511446162864855, 8.911735495090994, 9.308875532095252, 9.703046834937092, 10.094411523147297, 10.483115909988635, 10.86929266298732, 11.253062591474553, 11.63453613787405, 12.013814631339025, 12.3909913490078, 12.766152420214956, 13.139377601509421, 13.51074094462789, 13.88031137518291, 14.24815319641584, 14.614326529693653, 14.978887701318309, 15.341889583538254, 15.70338189630507, 16.063411475232233, 16.422022510330628, 16.779256759374967, 17.13515373916333, 17.489750897443216, 17.843083767872002, 18.195186110041195, 18.54609003631062, 18.895826126960426, 19.24442353496716, 19.591910081539652, 19.93831234340489, 20.28365573271014, 20.627964570300886, 20.971262153042822, 21.313570815777155, 21.65491198843012, 21.995306248738324, 22.334773371000153, 22.67333237121814, 23.0110015489582, 23.347798526216863, 23.68374028355749, 24.018843193749618, 24.353123053121948, 24.68659511081893, 25.019274096131934, 25.35117424405987, 25.682309319239515, 26.012692638372453, 26.34233709126427, 26.671255160580852, 26.999458940417604, 27.326960153768717, 27.653770168976262, 27.97990001523205, 28.305360397198964, 28.63016170881301, 28.954314046322335, 29.277827220614835, 29.600710768881896, 29.92297396566208, 30.244625833305182, 30.56567515189385, 30.8861304686573, 31.206000106908984, 31.52529217453776, 31.844014572079825, 32.16217500039688, 32.47978096798407, 32.79683979792956, 33.113358634546195, 33.429344449694106, 33.74480404881204, 34.059744076673795, 34.37417102288516, 34.68809122713581, 35.00151088421945, 35.3144360488348, 35.62687264017919, 35.93882644634577, 36.250303128534675, 36.56130822508767, 36.87184715535562], [0.0, 0.7384708111153172, 1.3310943202845493, 1.8788253035655964, 2.3992987438701974, 2.9003996075926195, 3.386584348006855, 3.860705444222072, 4.324738205709199, 4.780127349904321, 5.227972976198238, 5.66913914271232, 6.104321420623551, 6.534091073588217, 6.958925135218586, 7.379227575652667, 7.7953446171322955, 8.207576081466678, 8.616183970879902, 9.021399073230993, 9.423426126631163, 9.822447914038388, 10.218628549949289, 10.612116148088047, 11.003045008524351, 11.39153742721157, 11.777705205625356, 12.161650919827283, 12.54346899477977, 12.923246619684022, 13.301064532535124, 13.676997696315219, 14.051115884802655, 14.423484192523897, 14.79416348067086, 15.163210768670188, 15.530679579391068, 15.89662024461515, 16.261080176292698, 16.624104108215853, 16.98573431201064, 17.346010790750054, 17.704971452995768, 18.06265226966545, 18.41908741578007, 18.774309398858883, 19.128349175488427, 19.48123625738791, 19.832998808120717, 20.183663731454402, 20.533256752246032, 20.88180249062184, 21.229324530127673, 21.57584548044667, 21.921387035211538, 22.265970025378735, 22.60961446857975, 22.952339614818996, 23.294163988848148, 23.63510542951164, 23.975181126327573, 24.314407653540986, 24.652801001862702, 24.99037660808589, 25.327149382753557, 25.663133736033753, 25.998343601944324, 26.33279246105585, 26.66649336178973, 26.999458940417604, 27.331701439859064, 27.663232727365884, 27.99406431117355, 28.32420735619386, 28.653672698816187, 28.982470860879374, 29.31061206287119, 29.638106236407655, 29.964963036040288, 30.291191850435716, 30.616801812968486, 30.941801811764755, 31.266200499231882, 31.590006301106055, 31.913227425047957, 32.23587186881402, 32.557947428029095, 32.8794617035843, 33.20042210868222, 33.520835875550226, 33.84071006184085, 34.160051556737336, 34.47886708678088, 34.7971632214353, 35.11494637840347, 35.43222282870928, 35.74899870155768, 36.06527998898484, 36.38107255030944, 36.696382116395625, 37.01121429373738, 37.32557456837352], [0.0, 0.7474284012358585, 1.3472403847645815, 1.9016152997633124, 2.428402040034144, 2.9355812159643233, 3.427663337239036, 3.9075354833041223, 4.377196923971713, 4.838109900981409, 5.2913878578390205, 5.737905333619768, 6.178366336721727, 6.613349060182289, 7.043336323992149, 7.46873699841382, 7.889901505336419, 8.307133303383006, 8.720697572843065, 9.13082790101335, 9.537731509461496, 9.941593398287708, 10.342579672683932, 10.740840242981632, 11.136511038299275, 11.529715838030077, 11.920567799792376, 12.30917074388693, 12.695620240643176, 13.080004536860146, 13.462405349878159, 13.842898551974155, 14.221554763276668, 14.59843986790341, 14.973615465287537, 15.347139266496647, 15.719065443627917, 16.08944493898337, 16.458325739616317, 16.825753121936113, 17.19176987032013, 17.556416473075338, 17.91973129859115, 18.28175075410949, 18.64250942919153, 19.00204022567005, 19.360374475632437, 19.717542048772614, 20.07357145027568, 20.42848991024967, 20.78232346559205, 21.13509703506915, 21.486834488293294, 21.83755870920121, 22.18729165456759, 22.536054408026672, 22.88386723002217, 23.23074960405946, 23.576720279593932, 23.921797311853737, 24.26599809886441, 24.609339415915226, 24.951837447683, 25.29350781820794, 25.63436561889671, 25.97442543471151, 26.313701368688676, 26.652207064916997, 26.989955730094152, 27.326960153768717, 27.663232727365884, 27.998785462086218, 28.333630005759154, 28.66777765872595, 29.001239388820487, 29.33402584551065, 29.66614737325788, 29.997614024147882, 30.328435569841094, 30.658621512887894, 30.988181097449903, 31.317123319465523, 31.645456936295105, 31.97319047587832, 32.30033224543409, 32.62689033973099, 32.95287264895415, 33.27828686619286, 33.60314049457126, 33.92744085404304, 34.251195087869476, 34.57441016879903, 34.89709290496529, 35.219249945519124, 35.540887786009634, 35.862012773527695, 36.18263111162502, 36.50274886502068, 36.822371964106395, 37.14150620926123, 37.46015727498549, 37.77833071386318], [0.0, 0.7563670861755647, 1.3633523726386667, 1.9243571971985762, 2.457443913084343, 2.9706885728175507, 3.468655628407395, 3.954266686611656, 4.429544927014866, 4.895970078674735, 5.35466890104905, 5.806526392046609, 6.252254979479651, 6.6924397711420625, 7.1275693611907, 7.558057509670764, 7.984258829255209, 8.406480407705375, 8.824990596668776, 9.240025776971613, 9.651795648396565, 10.06048742350674, 10.466269193988003, 10.86929266298732, 11.269695385233804, 11.667602620429678, 12.063128879473808, 12.456379224280136, 12.847450368127795, 13.236431613181567, 13.623405654060074, 14.008449270415968, 14.391633926941727, 14.773026295679863, 15.152688712746702, 15.530679579391068, 15.907053715567924, 16.281862672811148, 16.655155012063325, 17.026976551205834, 17.397370586285206, 17.7663780898183, 18.13403788905178, 18.500386826630972, 18.86545990578234, 19.229290421819993, 19.591910081539652, 19.953349111854457, 20.31363635885021, 20.672799378286683, 21.030864518443167, 21.38785699609582, 21.74380096631967, 22.09871958672624, 22.452635076676817, 22.80556877195015, 23.157541175289715, 23.508572003209053, 23.858680229393013, 24.207884124996784, 24.556201296113283, 24.90364871865169, 25.250242770845478, 25.595999263586677, 25.9409334687639, 26.2850601457646, 26.628393566286874, 26.970947537592618, 27.312735424321744, 27.653770168976262, 27.99406431117355, 28.333630005759154, 28.672479039861837, 29.0106228489665, 29.34807253207411, 29.684838866012225, 30.020932318954323, 30.356363063201528, 30.69114098727604, 31.02527570737163, 31.358776578203187, 31.69165270329381, 32.02391294473533, 32.3555659324552, 32.68662007302048, 33.017083558007116, 33.34696437196095, 33.67627029997489, 34.00500893490481, 34.33318768424559, 34.66081377668655, 34.987894268365025, 35.3144360488348, 35.640445846765616, 35.96593023538846, 36.29089563770069, 36.61534833144387, 36.939294453866545, 37.262740006283515, 37.58569085844204, 37.9081527527052, 38.23013130806174], [0.0, 0.7652871675973778, 1.3794308276545375, 1.9470517633654585, 2.4864253431265846, 3.005722862956177, 3.5095626049207045, 4.000900631230383, 4.481783981480254, 4.95370983565089, 5.417818241438408, 5.8750046338178805, 6.325989842492912, 6.771365875622647, 7.211627089512691, 7.647192123814141, 8.078419773261775, 8.50562074720212, 8.929066562040369, 9.34899638631818, 9.765622392875521, 10.179134002133743, 10.589701288138274, 10.9974777431203, 11.4026025440363, 11.805202427816637, 12.205393255824202, 12.603281329002035, 12.998964501200215, 13.392533127752808, 13.784070878522787, 14.173655438650057, 14.561359115633307, 14.947249367799982, 15.331389266416373, 15.713837901476095, 16.09465073944356, 16.473879939816527, 16.85157463623248, 17.22778118691787, 17.602543398523494, 17.97590272676834, 18.34789845680134, 18.718567865765035, 19.08794636969025, 19.45606765655349, 19.82296380707896, 20.18866540465556, 20.553201635560292, 20.916600380526912, 21.278888298568482, 21.640090903850744, 22.00023263631734, 22.359336926684975, 22.717426256355047, 23.07452221272604, 23.43064554033691, 23.785816188224405, 24.140053353836176, 24.493375523805042, 24.84580051185827, 25.197345494107417, 25.54802704193975, 25.897861152710266, 26.246863278413898, 26.595048352500307, 26.94243081497835, 27.28902463594342, 27.63484333764895, 27.97990001523205, 28.32420735619386, 28.66777765872595, 29.0106228489665, 29.35275449726277, 29.694183833509843, 30.03492176162988, 30.374978873250914, 30.714365460639307, 31.05309152893578, 31.391166807741005, 31.72860076209303, 32.06540260287575, 32.40158129669451, 32.73714557525228, 33.072103944257485, 33.406464691891976, 33.74023589686592, 34.073425436084335, 34.40604099194811, 34.73809005931109, 35.06957995211289, 35.400517809706116, 35.730910602895314, 36.06076513970359, 36.39008807088218, 36.7188858951769, 37.047164964364775, 37.37493148807289, 37.7021915383915, 38.02895105429168, 38.355215845858055, 38.680991598345926], [0.0, 0.7741889382879459, 1.3954762775603975, 1.9696997431748682, 2.5153472814274953, 3.0406852363217665, 3.550385609481567, 4.047438847840986, 4.533915802026849, 5.011331067120142, 5.480837951777828, 5.943342306616526, 6.399573345984194, 6.85012996424048, 7.2955122680114695, 7.736143766537524, 8.172387428030502, 8.604557575987894, 9.032928885076105, 9.457743305829757, 9.879215479069527, 10.29753702854282, 10.712880006585328, 11.125399690839915, 11.535236877160388, 11.942519776672862, 12.347365598432088, 12.749881879866779, 13.150167613056649, 13.54831420434315, 13.944406296831671, 14.338522479290631, 14.730735900294848, 15.121114802842659, 15.509722991841228, 15.89662024461515, 16.281862672811144, 16.665503042642875, 17.047591059267106, 17.42817362014616, 17.807295041486974, 18.184997261218754, 18.561320021452744, 18.93630103293679, 19.309976123658682, 19.68237937345129, 20.053543236199722, 20.42349865103687, 20.792275143732617, 21.159900919327608, 21.526402946930816, 21.8918070374871, 22.256137915223942, 22.619419283402625, 22.981673884926753, 23.342923558298025, 23.703189289354526, 24.062491259178913, 24.420848888522293, 24.778280879052808, 25.134805251705835, 25.49043938238436, 25.845200035232942, 26.199103393686777, 26.552165089477395, 26.904400229759382, 27.25582342250684, 27.606448800314404, 27.956290042725477, 28.305360397198964, 28.653672698816187, 29.001239388820487, 29.34807253207411, 29.694183833509843, 30.03958465364818, 30.384286023245, 30.728298657129464, 31.071632967286902, 31.4142990752372, 31.756306823755093, 32.09766578797536, 32.43838528592228, 32.77847438850017, 33.117941928978624, 33.4567965120039, 33.795046522165435, 34.13270013214445, 34.46976531046959, 34.80624982890295, 35.14216126947802, 35.477507031209676, 35.812294336495036, 36.14653023722257, 36.480221620605874, 36.81337521475729, 37.14599759401565, 37.47809518404138, 37.809674266691594, 38.14074098468669, 38.471301346079464, 38.801361228537075, 39.13092638344534], [0.0, 0.7830726825351272, 1.4114892347853745, 1.9923018599150017, 2.5442106516410514, 3.075576809476246, 3.591125945817626, 4.0938828226927075, 4.585942053541799, 5.068835613280024, 5.543730044671217, 6.011541592881446, 6.473007839923782, 6.928734552413545, 7.379227575652668, 7.824915278609665, 8.266164794522014, 8.70329405371937, 9.136580882733746, 9.566270008459075, 9.992578534698987, 10.415700284065117, 10.835809283177303, 11.253062591474555, 11.66760262042968, 12.079559052379237, 12.489050441340705, 12.896185558724536, 13.301064532535124, 13.70377981799297, 14.10441702947503, 14.503055657548343, 14.89976969016065, 15.294628153392184, 15.687695584305342, 16.07903244616381, 16.468695494490113, 16.85673810098518, 17.243210541167706, 17.62816025064393, 18.01163205414503, 18.393668370833957, 18.774309398858886, 19.153593281694906, 19.531556258452547, 19.908232800027513, 20.283655732710145, 20.657856350656935, 21.03086451844317, 21.402708764759634, 21.77341636818326, 22.14301343583704, 22.511524975656606, 22.878974962895906, 23.245386401431194, 23.610781380358894, 23.975181126327577, 24.338606051995903, 24.701075800966247, 25.06260928950661, 25.423224745340885, 25.78293974375888, 26.141771241272124, 26.499735607019186, 26.856848652104222, 27.213125657034983, 27.56858139741067, 27.923230167996103, 28.27708580530614, 28.63016170881301, 28.982470860879374, 29.33402584551065, 29.684838866012225, 30.03492176162988, 30.384286023245, 30.732942808190334, 31.080902954246678, 31.428176992875912, 31.77477516174139, 32.12070741656275, 32.46598344234853, 32.81061266404646, 33.154604256648604, 33.497967154785485, 33.84071006184086, 34.18284145861653, 34.52436961157445, 34.86530258068138, 35.20564822687963, 35.54541421920582, 35.8846080415778, 36.223236999269005, 36.56130822508767, 36.8988286852775, 37.235805185155286, 37.57224437449975, 37.908152752705206, 38.24353667371244, 38.578402350728986, 38.91275586074949, 39.24660314888678, 39.57995003252326], [0.0, 0.7919386764846243, 1.4274701970823527, 2.0148588161586973, 2.5730163509672868, 3.1103986670026154, 3.631784880317072, 4.1402339994678155, 4.637864353228995, 5.126225261623835, 5.6064964750804345, 6.079604612545328, 6.54629560697756, 7.00718208351691, 7.4627756146749125, 7.9135094194381805, 8.359754787747823, 8.801833249558971, 9.240025776971612, 9.674579867691648, 10.105715083584462, 10.533627441732444, 10.95849293909483, 11.380470413346632, 11.799703888351544, 12.216324514716996, 12.630452188735875, 13.042196913334795, 13.451659950173175, 13.858934801254842, 14.264108050287648, 14.667260087835405, 15.068465739541658, 15.467794813003888, 15.86531257597682, 16.261080176292698, 16.655155012063325, 17.047591059267106, 17.438439162645047, 17.827747294872054, 18.21556078818748, 18.601922542026493, 18.986873209663003, 19.370451366434718, 19.752693661753465, 20.13363495679641, 20.51330844951504, 20.891745788380092, 21.268977176095284, 21.645031464354886, 22.01993624058544, 22.393717907496296, 22.766401756164363, 23.138012033292796, 23.508572003209057, 23.87810400510359, 24.246629505954306, 24.614169149533158, 24.98074280184852, 25.346369593339464, 25.711067958105218, 26.074855670424043, 26.437749878790054, 26.799767137674152, 27.16092343719473, 27.52123423086632, 27.88071446157831, 28.239378585941665, 28.597240597129066, 28.954314046322335, 29.31061206287119, 29.66614737325788, 30.020932318954323, 30.374978873250914, 30.728298657129464, 31.080902954246678, 31.43280272508934, 31.784008620357138, 32.13453099362484, 32.484379913331324, 32.83356517413934, 33.182096307706416, 33.529982592904425, 33.87723306552227, 34.223856527483925, 34.56986155561132, 34.91525650995976, 35.26004954175142, 35.60424860093065, 35.94786144336334, 36.29089563770069, 36.63335857192687, 36.975257459608166, 37.316599345860496, 37.65739111305085, 37.997639486247124, 38.33735103843013, 38.67653219548036, 39.01518924095164, 39.35332832064269, 39.690955446977235, 40.02807650320244], [0.0, 0.8007871884771606, 1.4434196481357342, 2.037371294621282, 2.6017652512477847, 3.1451518628292314, 3.6723636435749127, 4.18649378104436, 4.689684272583698, 5.183501749123182, 5.66913914271232, 6.147533425623105, 6.619438865294169, 7.08547493186612, 7.546158913767187, 8.001928870438825, 8.453160240329586, 8.900178145922343, 9.343266698682632, 9.782676161664837, 10.218628549949289, 10.65132207076208, 11.08093468751673, 11.507627012617936, 11.931544679140957, 12.35282030306897, 12.771575120323565, 13.187920362919218, 13.601958423935036, 14.01378385009412, 14.4234841925239, 14.831140740010348, 15.236829154241034, 15.640620022789701, 16.042579342662627, 16.44276894491077, 16.841246868968174, 17.23806769389919, 17.63328283254475, 18.026940793589432, 18.419087415780066, 18.809766077877022, 19.199017887382542, 19.586881850645405, 19.9733950265697, 20.3585926658445, 20.742508337349605, 21.12517404317134, 21.50662032347516, 21.8868763523219, 22.265970025378735, 22.643928040358524, 23.020775970921164, 23.396538334683775, 23.77123865591147, 24.144899523395576, 24.517542643969463, 24.889188892062666, 25.259858355651016, 25.629570378922356, 25.998343601944324, 26.36619599759125, 26.733144905961314, 27.099207066492294, 27.464398647963833, 27.82873527655612, 28.19223206211887, 28.554903622790057, 28.916764108091286, 29.277827220614835, 29.638106236407655, 29.997614024147882, 30.356363063201528, 30.714365460639307, 31.071632967286902, 31.428176992875912, 31.784008620357138, 32.13913861943298, 32.49357745936105, 32.84733532107721, 33.20042210868222, 33.552847460332984, 33.90462075857634, 34.255751140160136, 34.60624750535424, 34.95611852681139, 35.30537265799569, 35.654018141204794, 36.0020630152096, 36.349515122534044, 36.696382116395625, 37.04267146732613, 37.388390469490666, 37.733546246721865, 38.078145758284954, 38.42219580438857, 38.76570303145494, 39.108673937162386, 39.45111487527231, 39.79303206025185, 40.13443157170293, 40.47531935860758], [0.0, 0.8096184793674986, 1.45933805813647, 2.0598399589722205, 2.630458200002169, 3.1798374214827785, 3.7128634318559746, 4.232663531163994, 4.741403339260813, 5.240666764292988, 5.731659894277168, 6.215330034661016, 6.692439771142064, 7.16361540553991, 7.629379931075079, 8.0901762382233, 8.546383905866687, 8.998331642024025, 9.446306691416517, 9.89056207706507, 10.331322262490481, 10.768787640800054, 11.203138138034458, 11.634536137874052, 12.063128879473808, 12.489050441340705, 12.91242339641783, 13.333360203415461, 13.751964384630398, 14.168331529471775, 14.582550154603792, 14.994702445286443, 15.404864897624213, 15.813108877649098, 16.21950111019965, 16.624104108215853, 17.026976551205834, 17.428173620146165, 17.827747294872058, 18.225746619034567, 18.62221793690223, 19.017205105627756, 19.410749686057684, 19.802891114713027, 20.193666859193183, 20.583112558941046, 20.971262153042826, 21.358147996512237, 21.743800966319675, 22.128250558265165, 22.51152497565661, 22.893651210636232, 23.274655118896955, 23.6545614884426, 24.03339410297004, 24.411175800385706, 24.787928526911617, 25.163673387185987, 25.5384306907201, 25.912219995034576, 26.2850601457646, 26.656969313994075, 27.02796503105231, 27.398064220984, 27.767283230882324, 28.13563785925708, 28.503143382593358, 28.869814580241794, 29.235665757768622, 29.600710768881896, 29.964963036040288, 30.328435569841094, 30.69114098727604, 31.05309152893578, 31.4142990752372, 31.77477516174139, 32.13453099362484, 32.49357745936105, 32.85192514366536, 33.20958433975164, 33.56656506094568, 33.9228770516965, 34.27852979802412, 34.63353253743883, 34.98789426836503, 35.34162375909972, 35.69472955633403, 36.04721999326384, 36.39910319731369, 36.75038709749696, 37.101079431432815, 37.451187752040035, 37.800719433925686, 38.14968167948588, 38.49808152473447, 38.84592584487456, 39.193221359626854, 39.53997463832778, 39.886192104809695, 40.2318800420745, 40.57704459677156, 40.921691783489834], [0.0, 0.8184328028265004, 1.4752258843265238, 2.0822654546036223, 2.6590960214095016, 3.21445633927463, 3.7532854084801306, 4.278744576011125, 4.793023038843863, 5.29772194914673, 5.794060525627153, 6.28299638705548, 6.765300421406394, 7.2416057490528765, 7.712441057047214, 8.178254057617615, 8.639428462124798, 9.096296557234623, 9.54914871490408, 9.998240712817918, 10.443799458233245, 10.886027525938875, 11.325106800831852, 11.761201434465088, 12.194460268987514, 12.62501884261999, 13.053001062758307, 13.478520612451701, 13.901682141045125, 14.322582278630442, 14.74131050555355, 15.157949901826088, 15.572577796366298, 15.985266332168788, 16.396082960506014, 16.805090874896884, 17.212349393693835, 17.617914298629223, 18.021838135443172, 18.4241704817254, 18.8249581862949, 19.22424558377758, 19.62207468749329, 20.01848536330878, 20.413515486733537, 20.80720108521738, 21.199576467341643, 21.59067434036936, 21.98052591742878, 22.369161015440948, 22.756608144763433, 23.142894591402147, 23.528046492541165, 23.912088906051526, 24.295045874563417, 24.676940484619756, 25.057794921371272, 25.43763051922256, 25.816467808794734, 26.1943265605313, 26.571225825240056, 26.94718397183364, 27.322218722505102, 27.69634718555136, 28.06958588603654, 28.441950794468948, 28.813457353648904, 29.18412050382997, 29.553954706323196, 29.92297396566208, 30.291191850435716, 30.658621512887894, 31.02527570737163, 31.391166807741005, 31.756306823755093, 32.12070741656275, 32.484379913331324, 32.84733532107721, 33.20958433975164, 33.5711373746308, 33.93200454805563, 34.29219571056308, 34.65172045144752, 35.01058810878811, 35.368807778975174, 35.726388325766244, 36.08333838890035, 36.43966639229693, 36.79538055186389, 37.150488882937836, 37.504999207377466, 37.85891916033024, 38.21225619669065, 38.56501759726736, 38.91721047467534, 39.268841778968124, 39.61991830302406, 39.9704466877, 40.32043342676461, 40.669884871622905, 41.018807235842864, 41.36720659949433], [0.0, 0.8272304056273322, 1.4910835715147557, 2.1046484093584055, 2.6876795172381653, 3.2490095854249423, 3.793630705134822, 4.3247382057092, 4.844544816521099, 5.35466890104905, 5.856342783782503, 6.35053437725025, 6.838022855954818, 7.319448145887858, 7.7953446171322955, 8.266164794522012, 8.732296514057081, 9.194075634261779, 9.651795648396563, 10.105715083584462, 10.556063286183157, 11.003045008524351, 11.446844090645538, 11.887626448618548, 12.32554252454542, 12.76072931359183, 13.193312055074834, 13.623405654060074, 14.051115884802654, 14.476540416103012, 14.899769690160648, 15.320887680041512, 15.73997254589777, 16.157097206212754, 16.572329837314783, 16.98573431201064, 17.397370586285206, 17.807295041486974, 18.215560788187485, 18.62221793690223, 19.02731384004354, 19.430893308804766, 19.832998808120717, 20.233670632389437, 20.632947064256683, 21.030864518443167, 21.427457672324415, 21.822759584744578, 22.216801804352045, 22.60961446857975, 23.00122639425244, 23.39166516068227, 23.780957186010475, 24.16912779746338, 24.556201296113283, 24.942201016667948, 25.327149382753557, 25.711067958105218, 26.09397749403444, 26.47589797350372, 26.85684865210422, 27.236848096202063, 27.615914218491966, 27.99406431117355, 28.371315076944263, 28.747682657984665, 29.1231826630948, 29.497830193125907, 29.87163986483843, 30.244625833305182, 30.616801812968486, 30.988181097449903, 31.358776578203187, 31.72860076209303, 32.09766578797536, 32.46598344234853, 32.83356517413934, 33.20042210868222, 33.56656506094568, 33.93200454805563, 34.296750801161394, 34.66081377668655, 35.02420316700397, 35.38692841057088, 35.74899870155768, 36.110422999001344, 36.4712100355123, 36.831368325561456, 37.19090617337221, 37.54983168044065, 37.9081527527052, 38.265877107386025, 38.62301227951273, 38.979565628157765, 39.33554434239196, 39.69095544697723, 40.045805807810815, 40.40010213713431, 40.75385099852004, 41.107058811646354, 41.45973185687291, 41.81187627962621], [0.0, 0.8360115279168341, 1.5069115525660675, 2.126989434220719, 2.7162094677275457, 3.2834981031284767, 3.833900423119542, 4.370645675739407, 4.895970078674734, 5.411509174472325, 5.918508368852647, 6.417945848819687, 6.9106090598806915, 7.397144720897051, 7.878092874336331, 8.353910848622656, 8.824990596668776, 9.291671542166249, 9.75425029383187, 10.212988123076432, 10.668116810789037, 11.119843282765098, 11.56835333052, 12.013814631339025, 12.456379224280134, 12.896185558724534, 13.333360203415458, 13.76801928314576, 14.200269694973407, 14.6302101444616, 15.057932033861608, 15.483520227620737, 15.907053715567924, 16.328606190222512, 16.74824655161044, 17.166039350553852, 17.5820451794756, 17.996321018217067, 18.4089205411231, 18.819894390636648, 19.22929042181999, 19.637153921541174, 20.043527805503956, 20.44845279583491, 20.85196758155338, 21.254108963925493, 21.654911988430115, 22.05441006483388, 22.452635076676817, 22.849617481303305, 23.24538640143119, 23.6399697091294, 24.033394102970032, 24.425685179030097, 24.816867496339896, 25.206964637307117, 25.595999263586677, 25.9839931678146, 26.37096732157936, 26.756941919964323, 27.141936422960427, 27.52596959401737, 27.909059535974674, 28.29122372459015, 28.672479039861834, 29.05284179532092, 29.432327765456215, 29.810952211415803, 30.1887299051183, 30.56567515189385, 30.941801811764755, 31.317123319465523, 31.69165270329381, 32.06540260287575, 32.43838528592228, 32.81061266404646, 33.182096307706416, 33.552847460332984, 33.9228770516965, 34.29219571056308, 34.66081377668655, 35.02874131217882, 35.39598811229813, 35.76256371569173, 36.12847741412696, 36.493738261741726, 36.858355083843875, 37.222336485286164, 37.58569085844204, 37.948426390805665, 38.31055107223769, 38.67207270187724, 39.03299889473891, 39.393337088012345, 39.75309454708098, 40.11227837127517, 40.470895499374265, 40.82895271487089, 41.186456651010246, 41.54341379561612, 41.899830495714724, 42.25571296196683], [0.0, 0.8447764034729981, 1.5227102488655058, 2.1492891239710197, 2.744686632424579, 3.317922810565866, 3.874095634526615, 4.416468208286774, 4.947300194388828, 5.46824428266333, 5.980558935859026, 6.485232596445373, 6.983060965631421, 7.474697542580208, 7.960688031648958, 8.44149455596449, 8.917513177735163, 9.389086879223585, 9.856515378838708, 10.320062687201641, 10.779963015228564, 11.236425458157274, 11.689637755370455, 12.139769342108258, 12.586973851429898, 13.031391184241535, 13.473149236252901, 13.912365349727324, 14.349147542448245, 14.78359555482342, 15.215801747379603, 15.645851874296241, 16.073825753543982, 16.499797850246065, 16.923837786787068, 17.346010790750054, 17.7663780898183, 18.184997261218758, 18.601922542026497, 19.017205105627756, 19.43089330880477, 19.843032913220185, 20.25366728451271, 20.662837571746056, 21.070582869561303, 21.476940365054798, 21.881945471127686, 22.28563194781982, 22.68803201294324, 23.0891764431619, 23.48909466652076, 23.88781484730388, 24.285363963995362, 24.68176788102549, 25.077051414905274, 25.471238395284054, 25.864351721405082, 26.256413414381782, 26.64744466567204, 27.037465882087638, 27.42649672764109, 27.81455616250105, 28.201662479300026, 28.587833337014413, 28.973085792614782, 29.35743633066594, 29.7409008910389, 30.12349489488201, 30.50523326898499, 30.8861304686573, 31.266200499231882, 31.645456936295105, 32.02391294473533, 32.40158129669451, 32.77847438850017, 33.154604256648604, 33.529982592904425, 33.90462075857634, 34.27852979802412, 34.65172045144752, 35.02420316700397, 35.39598811229813, 35.76708518528325, 36.13750402461127, 36.50725401946583, 36.87634431890989, 37.24478384077716, 37.61258128013503, 37.97974511734392, 38.346283625736945, 38.7122048789417, 39.077516757864714, 39.442226957357576, 39.8063429925826, 40.16987220509462, 40.53282176865451, 40.895198694788846, 41.25700983810944, 41.618261901405496, 41.97896144052015, 42.33911486902284, 42.69872846268786], [0.0, 0.8535252599494246, 1.5384800707588961, 2.171548057808023, 2.773111750977996, 3.3522846018637336, 3.914217383362261, 4.462206993518168, 4.998536496880897, 5.524875699225608, 6.042496096465706, 6.5523963677927775, 7.055380455029184, 7.552108625247627, 8.043132234347063, 8.528918191393991, 9.009866660382055, 9.486324175641101, 9.958593559588826, 10.426941557050352, 10.891604804527708, 11.352794562736111, 11.81070051536553, 12.265493852398066, 12.717329797980923, 13.166349701892347, 13.612682784383331, 14.05644760296259, 14.49775329409074, 14.936700631128762, 15.373382931127521, 15.807886836372477, 16.24029299146245, 16.670676632712517, 17.099108103545692, 17.52565330706907, 17.95037410506533, 18.37332867105518, 18.794571803815444, 19.214155206705268, 19.632127737309876, 20.04853563121877, 20.46342270318328, 20.87683052842397, 21.28879860646231, 21.699364509519718, 22.108564017248103, 22.516431239320358, 22.92299872720961, 23.328297576315766, 23.73235751945289, 24.1352070125861, 24.536873313599926, 24.937382554787465, 25.336759809669864, 25.735029154686234, 26.13221372623394, 26.52833577348623, 26.923416707368556, 27.31747714603415, 27.71053695714424, 28.102615297226873, 28.4937306483607, 28.88390085240582, 29.273143142981912, 29.661474175374792, 30.04891005453543, 30.43546636132001, 30.821158177106305, 31.206000106908984, 31.590006301106055, 31.97319047587832, 32.3555659324552, 32.73714557525228, 33.117941928978624, 33.497967154785485, 33.87723306552227, 34.255751140160136, 34.63353253743883, 35.01058810878811, 35.38692841057088, 35.76256371569173, 36.13750402461127, 36.5117590758033, 36.8853383556898, 37.25825110808518, 37.630506343180016, 38.00211284609141, 38.37307918500591, 38.74341371893875, 39.113124605131354, 39.48221980610822, 39.850707096412016, 40.21859406903521, 40.585888141564844, 40.952596562056236, 41.318726414650264, 41.68428462494796, 42.0492779651554, 42.41371305901075, 42.77759638650507, 43.140934288407166], [0.0, 0.8622583191075672, 1.5542214179714637, 2.193766799939581, 2.8014855438928845, 3.3865843480068545, 3.9542666866116556, 4.507863190796479, 5.049680284862031, 5.581404859622783, 6.10432142062355, 6.6194388652941685, 7.1275693611907, 7.629379931075078, 8.125427572183318, 8.616183970879902, 9.10205338553739, 9.583385896139099, 10.060487423506737, 10.533627441732444, 11.003045008524351, 11.468953546165015, 11.931544679140957, 12.390991349007802, 12.847450368127797, 13.301064532535124, 13.751964384630398, 14.200269694973409, 14.646090716682021, 15.0895292542053, 15.530679579391068, 15.969629221027203, 16.406459648848095, 16.841246868968174, 17.27406194454694, 17.704971452995764, 18.134037889051775, 18.561320021452744, 18.986873209663003, 19.41074968605768, 19.832998808120713, 20.25366728451271, 20.672799378286683, 21.090437090050568, 21.506620323475158, 21.921387035211538, 22.334773371000157, 22.746813789515635, 23.15754117528972, 23.56698694188275, 23.975181126327577, 24.382152475743712, 24.787928526911614, 25.19253567950354, 25.59599926358668, 25.998343601944324, 26.399592067699718, 26.799767137674156, 27.198890441864364, 27.596982809383423, 27.994064311173545, 28.39015429976764, 28.7852714463484, 29.17943377532943, 29.57265869666053, 29.964963036040285, 30.356363063201528, 30.746874518419915, 31.13651263738214, 31.52529217453776, 31.913227425047957, 32.30033224543409, 32.68662007302048, 33.072103944257485, 33.4567965120039, 33.84071006184086, 34.223856527483925, 34.60624750535424, 34.98789426836503, 35.368807778975174, 35.74899870155768, 36.12847741412696, 36.50725401946583, 36.8853383556898, 37.262740006283515, 37.63946830964184, 38.01553236814537, 38.39094105679837, 38.76570303145494, 39.139826736657675, 39.513320413110904, 39.88619210480968, 40.258449665843884, 40.63010076689559, 41.00115290144676, 41.37161339171302, 41.741489394318414, 42.110787905725026, 42.47951576743045, 42.847679670945325, 43.21528616256235, 43.58234164792752], [0.0, 0.8709757970375107, 1.5699346800057863, 2.215945900144389, 2.8298087132480014, 3.420822897705276, 3.994244535251406, 4.5534379298348275, 5.100732823829839, 5.63783316260767, 6.166036438133203, 6.686361747843491, 7.199629470352222, 7.706513372057285, 8.207576081466678, 8.703294053719368, 9.194075634261779, 9.680274442404668, 10.162199491845685, 10.640122981074516, 11.11428638468557, 11.584905282672143, 12.052173236854612, 12.516264937237016, 12.977338781563013, 13.43553900954236, 13.890997483366357, 14.343835184481588, 14.794163480670859, 15.242085205631685, 15.68769558430534, 16.131083030400447, 16.572329837314783, 17.01151277958868, 17.448703638834008, 17.883969665563335, 18.31737398633894, 18.748975964053685, 19.17883151785907, 19.60699340820234, 20.033511491574245, 20.458432948862455, 20.881802490621844, 21.30366254208873, 21.724053410362178, 22.14301343583704, 22.560579129689152, 22.976785298972185, 23.39166516068227, 23.805250445972526, 24.21757149555182, 24.628657347174588, 25.038535816019618, 25.447233568661265, 25.85477619125507, 26.261188252488964, 26.666493361789726, 27.070714223220516, 27.4738726854585, 27.875989788200194, 28.277085805306132, 28.677180284964358, 29.07629208712423, 29.474439418427146, 29.871639864838425, 30.267910422165375, 30.663267524628708, 31.0577270716391, 31.451304452916858, 31.844014572079825, 32.23587186881402, 32.62689033973099, 33.017083558007116, 33.406464691891976, 33.795046522165435, 34.18284145861653, 34.56986155561132, 34.95611852681139, 35.34162375909972, 35.726388325766244, 36.110422999001344, 36.493738261741726, 36.87634431890989, 37.25825110808518, 37.63946830964184, 38.02000535638639, 38.39987144272497, 38.779075533388614, 39.15762637174259, 39.535532487704266, 39.912802205291925, 40.28944364982585, 40.665464754801185, 41.040873268451016, 41.415676760016815, 41.7898826257422, 42.163498094605075, 42.53653023380211, 42.90898595399883, 43.28087201435739, 43.65219502735387, 44.02296146339569], [0.0, 0.8796779043679792, 1.585620236520334, 2.2380858943062907, 2.85808194337809, 3.455001078219141, 4.034151895212636, 4.598932311794494, 5.151695347298329, 5.694161971581651, 6.227642640131838, 6.7531666324085755, 7.271562523605493, 7.783510811866104, 8.289579747041365, 8.790250544636455, 9.285935629965364, 9.776992155425766, 10.26373222213792, 10.746430748185418, 11.225331620787502, 11.700652573843753, 12.172589103092504, 12.64131764390336, 13.106998176606053, 13.56977638204044, 14.029785439861453, 14.487147540267443, 14.941975163740798, 15.394372171412712, 15.844434739637418, 16.292252165484, 16.73790756456135, 17.18147847848082, 17.623037406039863, 18.062652269665445, 18.500386826630972, 18.93630103293679, 19.370451366434718, 19.802891114713027, 20.233670632389437, 20.662837571746056, 21.090437090050568, 21.516512036419, 21.941103120667343, 22.36424906625762, 22.78598674915671, 23.206351324183075, 23.62537634021103, 24.0430938454265, 24.45953448367893, 24.87472758284523, 25.288701236011647, 25.701482376184046, 26.11309684515477, 26.523569457082825, 26.932924057281863, 27.341183576656245, 27.748370082178, 28.154504823755786, 28.559608277810664, 28.963700187840843, 29.366799602229513, 29.76892490952455, 30.170093871396464, 30.57032365346134, 30.969630854137733, 31.368031531690775, 31.765541229602785, 32.16217500039688, 32.557947428029095, 32.95287264895415, 33.34696437196095, 33.74023589686592, 34.13270013214445, 34.52436961157445, 34.91525650995976, 35.30537265799569, 35.69472955633403, 36.08333838890035, 36.4712100355123, 36.858355083843875, 37.24478384077716, 37.630506343180016, 38.01553236814537, 38.39987144272497, 38.78353285318825, 39.166525653834796, 39.54885867538675, 39.9305405329857, 40.31157963381701, 40.6919841843828, 41.07176219744347, 41.45092149864637, 41.829469732858904, 42.20741437022215, 42.58476271194031, 42.96152189581993, 43.33769890157248, 43.71330055589238, 44.088333537322384, 44.46280438091714], [0.0, 0.8883648464662179, 1.601278457689756, 2.2601873049228183, 2.8863059015232992, 3.4891196961437387, 4.073989708297631, 4.6443474103298845, 5.202569057968486, 5.750392615888513, 6.289141480508209, 6.819855095565598, 7.343370218550004, 7.860374067619099, 8.371440504170439, 8.877055495779487, 9.377635540517778, 9.873541317712773, 10.36508801052685, 10.852553251898058, 11.336183337465972, 11.816198151282821, 12.292795119634647, 12.766152420214958, 13.23643161318157, 13.70377981799297, 14.168331529471775, 14.630210144461604, 15.0895292542053, 15.546393745477232, 16.000900744386556, 16.453140429823375, 16.903196738174824, 17.35114797678649, 17.797067360391566, 18.241023482160475, 18.683080728978588, 19.12329964892013, 19.56173727756359, 19.998447428719608, 20.433480954264784, 20.866885977054167, 21.29870810028976, 21.72899059622859, 22.157774576701765, 22.585099147570904, 23.011001548958202, 23.435517282840863, 23.858680229393016, 24.280522753280902, 24.70107580096625, 25.12036898994285, 25.5384306907201, 25.955288102271055, 26.370967321579364, 26.785493407847316, 27.198890441864368, 27.611181580980762, 28.022389110082948, 28.432534488925413, 28.84163839613672, 29.249720770184886, 29.656800847558543, 30.062897198395042, 30.468027759763874, 30.87220986679397, 31.275460281815594, 31.67779522167148, 32.079230383338015, 32.47978096798407, 32.8794617035843, 33.27828686619286, 33.67627029997489, 34.073425436084335, 34.46976531046959, 34.86530258068138, 35.26004954175142, 35.654018141204794, 36.04721999326384, 36.43966639229693, 36.831368325561456, 37.222336485286164, 37.61258128013503, 38.00211284609141, 38.39094105679837, 38.779075533388614, 39.166525653834796, 39.553300561848985, 39.939409175357916, 40.324860194578925, 40.70966210971949, 41.09382320832208, 41.477351582274224, 41.86025513450265, 42.242541585368876, 42.62421847878268, 43.005293188048654, 43.3857729214602, 43.76566472765441, 44.14497550074026, 44.52371198521203, 44.90188078065898], [0.0, 0.897036823628346, 1.6169097045479932, 2.2822506415894925, 2.9144812384476397, 3.52317953815713, 4.113758893052789, 4.6896842725836985, 5.253355128843041, 5.806526392046608, 6.35053437725025, 6.886428674960397, 7.4150542108664865, 7.937104911563822, 8.453160240329586, 8.963710908623169, 9.469177480257539, 9.969924155414118, 10.466269193988003, 10.958492939094828, 11.446844090645538, 11.931544679140957, 12.41279405808909, 12.89077214450586, 13.365642075655611, 13.83755240713716, 14.306638946675177, 14.773026295679864, 15.23682915424103, 15.698153433009349, 16.157097206212754, 16.613751533043274, 17.068201169252326, 17.52052518660061, 17.970797514523728, 18.419087415780066, 18.865459905782338, 19.309976123658682, 19.752693661753465, 20.19366685919318, 20.63294706425668, 21.0705828695613, 21.506620323475158, 21.94110312066734, 22.37407277429152, 22.80556877195015, 23.235628717293423, 23.664288458859232, 24.091582207550797, 24.517542643969463, 24.94220101666795, 25.365587232258004, 25.78772993819425, 26.208656598958758, 26.628393566286874, 27.04696614400203, 27.464398647963833, 27.88071446157831, 28.29593608727094, 28.71008519428052, 29.123182663094795, 29.535248626815708, 29.94630250971328, 30.356363063201524, 30.765448399446743, 31.17357602279871, 31.58076285921701, 31.987025283848816, 32.39237914690014, 32.79683979792956, 33.20042210868222, 33.60314049457126, 34.00500893490481, 34.40604099194811, 34.80624982890295, 35.20564822687963, 35.60424860093065, 36.0020630152096, 36.39910319731369, 36.79538055186389, 37.19090617337221, 37.58569085844204, 37.97974511734392, 38.37307918500591, 38.76570303145494, 39.15762637174259, 39.54885867538675, 39.939409175357916, 40.32928687663723, 40.718500564371176, 41.107058811646354, 41.49496998690597, 41.88224226102838, 42.26888361408653, 42.65490184180604, 43.04030456173826, 43.425099219164004, 43.80929309274209, 44.19289329991648, 44.575906802094586, 44.95834040960862, 45.34020078647123], [0.0, 0.9056940312607427, 1.6325143293152242, 2.3042764014613044, 2.94260858902831, 3.5571813717325536, 4.15346034560044, 4.734943920135205, 5.304054704288734, 5.86256456492296, 6.411822713729184, 6.952888870700948, 7.486616115816271, 8.013705072682729, 8.534740796916383, 9.050218735781089, 9.560563511906745, 10.066142840332258, 10.567278052445356, 11.064252196923471, 11.557316373854112, 12.04669475653102, 12.532588622401846, 13.01517962484263, 13.494632475538221, 13.971097163781831, 14.444710807964134, 14.91559921201038, 15.383878182968832, 15.84965465362266, 16.31302764470382, 16.774089094206975, 17.23292457585236, 17.68961392451387, 18.144231783112293, 18.59684808285357, 19.047528466607304, 19.496334663548897, 19.94332482184035, 20.38855380502932, 20.832073456951484, 21.27393283918639, 21.714178444510093, 22.152854389284315, 22.590002587301786, 23.02566290725565, 23.459873315704947, 23.892670007158024, 24.324087522683914, 24.754158858281, 25.18291556407847, 25.610387835313634, 26.03660459591467, 26.461593575420466, 26.88538137988418, 27.30799355733377, 27.72945465829864, 28.149788291855593, 28.569017177598642, 28.987163193894126, 29.404247422745158, 29.82029019155613, 30.23531111205864, 30.649329116634615, 31.062362492248962, 31.474428912184088, 31.885545465750223, 32.29572868612936, 32.70499457649617, 33.113358634546195, 33.520835875550226, 33.92744085404304, 34.33318768424559, 34.73809005931109, 35.14216126947802, 35.54541421920582, 35.94786144336334, 36.349515122534044, 36.75038709749696, 37.150488882937836, 37.54983168044065, 37.948426390805665, 38.346283625736945, 38.74341371893875, 39.139826736657675, 39.535532487704266, 39.9305405329857, 40.324860194578925, 40.718500564371176, 41.11147051229348, 41.50377869417038, 41.895433559208044, 42.28644335714111, 42.67681614505737, 43.06655979391816, 43.45568199479103, 43.84419026481041, 44.23209195288066, 44.61939424513547, 45.00610417016604, 45.3922286040304, 45.77777427505486], [0.0, 0.9143366600529774, 1.6480926757095749, 2.326265069692688, 2.9706885728175507, 3.591125945817625, 4.1930949404319, 4.780127349904322, 5.35466890104905, 5.918508368852647, 6.47300783992378, 7.019237146684927, 7.558057509670765, 8.090176238223298, 8.616183970879904, 9.136580882733744, 9.651795648396565, 10.162199491845685, 10.668116810789037, 11.169833354909649, 11.667602620429676, 12.161650919827283, 12.65218145124983, 13.139377601509421, 13.623405654060072, 14.104417029475027, 14.582550154603789, 15.057932033861608, 15.530679579391066, 16.000900744386552, 16.468695494490113, 16.934156645019144, 17.397370586285206, 17.858417914990326, 18.31737398633894, 18.774309398858883, 19.229290421819993, 19.68237937345129, 20.133634956796406, 20.583112558941043, 21.030864518443163, 21.476940365054794, 21.921387035211534, 22.364249066257617, 22.80556877195015, 23.24538640143119, 23.683740283557494, 24.120666958225247, 24.556201296113283, 24.99037660808589, 25.423224745340885, 25.854776191255066, 26.2850601457646, 26.71410460301882, 27.14193642296043, 27.568581397410668, 27.99406431117355, 28.41840899861662, 28.841638396136716, 29.263774590875535, 29.684838866012218, 30.104851742926385, 30.523833020495534, 30.94180181176475, 31.358776578203184, 31.77477516174138, 32.18981481476514, 32.60391222822514, 33.017083558007116, 33.429344449694106, 33.84071006184085, 34.251195087869476, 34.66081377668655, 35.06957995211289, 35.477507031209676, 35.8846080415778, 36.29089563770069, 36.696382116395625, 37.101079431432815, 37.504999207377466, 37.9081527527052, 38.31055107223769, 38.7122048789417, 39.113124605131354, 39.513320413110904, 39.912802205291925, 40.31157963381701, 40.70966210971949, 41.107058811646354, 41.50377869417038, 41.899830495714724, 42.29522274611252, 42.689963773821894, 43.08406171281579, 43.477524509164546, 43.87035992732812, 44.26257555617353, 44.65417881473245, 45.04517695771256, 45.43557708077576, 45.82538612559516, 46.214610884702466], [0.0, 0.9229648961427757, 1.663645079244467, 2.348217119857226, 2.9987217945786147, 3.625013991482248, 4.232663531163992, 4.825235535014045, 5.405198809210311, 5.9743590087066245, 6.534091073588217, 7.08547493186612, 7.6293799310750785, 8.166520055157665, 8.69749151627525, 9.222799209476978, 9.742875854608604, 10.258096178742383, 10.768787640800053, 11.275238686972216, 11.777705205625356, 12.276415644859636, 12.771575120323563, 13.26336874937859, 13.751964384630398, 14.237514875548737, 14.720159955262941, 15.200027826679063, 15.67723650519368, 16.151894962713087, 16.624104108215853, 17.09395763288108, 17.561542742251785, 18.02694079358943, 18.490227853195925, 18.951475185809702, 19.41074968605768, 19.868114260241537, 20.323628165362482, 20.777347311172395, 21.22932453012767, 21.679609819373155, 22.128250558265165, 22.57529170442936, 23.020775970921164, 23.46474398669799, 23.907234442310966, 24.348284222468926, 24.787928526911617, 25.22620098084487, 25.663133736033753, 26.09875756351473, 26.533101938772287, 26.96619512012557, 27.398064220984, 27.82873527655612, 28.2582333055304, 28.686582367189967, 29.11380561437342, 29.53992534265014, 29.96496303604028, 30.388939409575663, 30.811874448968013, 31.233787447624724, 31.65469704122858, 32.07462124007742, 32.49357745936105, 32.911582547536064, 33.32865281294498, 33.74480404881204, 34.160051556737336, 34.57441016879903, 34.987894268365025, 35.400517809706116, 35.812294336495036, 36.223236999269005, 36.63335857192687, 37.04267146732613, 37.451187752040035, 37.85891916033024, 38.265877107386025, 38.67207270187724, 39.077516757864714, 39.48221980610822, 39.88619210480968, 40.28944364982585, 40.6919841843828, 41.09382320832208, 41.49496998690597, 41.895433559208044, 42.29522274611252, 42.694346157945226, 43.092812201756665, 43.49062908827689, 43.8878048385602, 44.2843472903367, 44.68026410408658, 45.07556276885199, 45.470250607800445, 45.864334783552806, 46.25782230328805, 46.65072002363633], [0.0, 0.9315789212734641, 1.6791718675124154, 2.370133014348227, 3.0267088447973123, 3.6588462225369973, 4.272166951261083, 4.870269425613576, 5.455645493123739, 6.030117660910871, 6.595073701366716, 7.151603621463124, 7.700584882349503, 8.242738131575727, 8.778665145747235, 9.308875532095252, 9.833806049036921, 10.353834920969732, 10.86929266298732, 11.380470413346632, 11.887626448618548, 12.390991349007802, 12.89077214450586, 13.387155680173256, 13.880311375182911, 14.370393505547634, 14.857543108525114, 15.341889583538256, 15.823552047420534, 16.302640489112314, 16.77925675937497, 17.25349542380675, 17.725444501839416, 18.195186110041195, 18.66279702464028, 19.128349175488427, 19.591910081539652, 20.053543236199722, 20.51330844951504, 20.971262153042822, 21.427457672324415, 21.881945471127683, 22.334773371000157, 22.78598674915671, 23.235628717293427, 23.683740283557494, 24.130360499598705, 24.575526594370626, 25.019274096131937, 25.46163694391229, 25.902647589548955, 26.34233709126427, 26.78073519963722, 27.217870436721654, 27.653770168976266, 28.08846067459601, 28.521967205768618, 28.954314046322335, 29.38552456518105, 29.815621265998544, 30.244625833305182, 30.67255917546604, 31.099441464719355, 31.52529217453776, 31.95013011453074, 32.37397346308613, 32.796839797929564, 33.218746124764195, 33.63970890413816, 34.059744076673795, 34.47886708678088, 34.89709290496529, 35.3144360488348, 35.730910602895314, 36.14653023722257, 36.56130822508767, 36.975257459608166, 37.388390469490666, 37.800719433925686, 38.21225619669065, 38.62301227951273, 39.03299889473891, 39.442226957357576, 39.850707096412016, 40.258449665843884, 40.665464754801185, 41.07176219744347, 41.477351582274224, 41.88224226102838, 42.28644335714111, 42.689963773821894, 43.092812201756665, 43.49499712645888, 43.896526835289265, 44.29740942416258, 44.697652803958405, 45.09726470665214, 45.49625269118111, 45.894624149059915, 46.29238630975811, 46.689546245852604, 47.086110877966455], [0.0, 0.9401789129443203, 1.6946733604560325, 2.392013204761244, 3.0546503001704988, 3.692623336123625, 4.311606014724571, 4.915229949664342, 5.506009992285947, 6.085785474419602, 6.65595697985793, 7.217624578113552, 7.771673830732317, 8.31883203801545, 8.859706531947193, 9.39481162426404, 9.924588105375129, 10.449417691305538, 10.969633948341874, 11.485530702421675, 11.997368614429488, 12.505380393201126, 13.009774979952276, 13.510740944627893, 14.008449270415968, 14.503055657548343, 14.994702445286443, 15.483520227620739, 15.969629221027203, 16.453140429823375, 16.934156645019144, 17.412773305207352, 17.889079242382557, 18.363157331182745, 18.835085056605823, 19.304935012533296, 19.772775341229167, 20.238670122246823, 20.70267971777686, 21.16486108033174, 21.625268027734464, 22.083951489615714, 22.54095972899384, 22.996338541989367, 23.450131438289592, 23.902379804613734, 24.35312305312195, 24.80239875645173, 25.25024277084548, 25.696689348645407, 26.141771241272128, 26.585519793665988, 27.027965031052307, 27.46913573878997, 27.90905953597468, 28.347762943391967, 28.785271446348403, 29.221609552851547, 29.656800847558543, 30.090868041868564, 30.523833020495537, 30.955716884822817, 31.386539993311285, 31.816321999205453, 32.24508188575816, 32.67283799917338, 33.09960807944782, 33.525409289274975, 33.95025824116067, 34.37417102288516, 34.7971632214353, 35.219249945519124, 35.640445846765616, 36.06076513970359, 36.480221620605874, 36.8988286852775, 37.316599345860496, 37.733546246721865, 38.14968167948588, 38.56501759726736, 38.979565628157765, 39.393337088012345, 39.8063429925826, 40.21859406903521, 40.63010076689559, 41.040873268451016, 41.45092149864637, 41.86025513450265, 42.26888361408653, 42.67681614505737, 43.08406171281579, 43.49062908827689, 43.896526835289265, 44.30176331771949, 44.706346706220806, 45.11028498470311, 45.51358595652052, 45.91625725039169, 46.31830632606694, 46.7197404797556, 47.120566849326, 47.52079241928983], [0.0, 0.9487650445542184, 1.7101498706269487, 2.4138581322595387, 3.082546724072778, 3.7263460132792403, 4.350981516751648, 4.9601180136909715, 5.556293322180181, 6.1413635716450905, 6.716742136631877, 7.283539132976781, 7.84264820956719, 8.394803308733865, 8.9406173088866, 9.480609218685208, 10.01522385403271, 10.544846416954547, 11.069813520012875, 11.59042167249426, 12.106933915754272, 12.61958508382922, 13.12858602607882, 13.63412703455255, 14.136380653932859, 14.635504006375287, 15.13164073104665, 15.624922614579768, 16.11547097132089, 16.603397819328308, 17.088806888345093, 17.571794488551724, 18.052450263196008, 18.530857843763947, 19.007095422880884, 19.48123625738791, 19.953349111854457, 20.42349865103687, 20.891745788380092, 21.358147996512237, 21.822759584744578, 22.285631947819816, 22.746813789515635, 23.20635132418308, 23.664288458859236, 24.12066695822525, 24.57552659437063, 25.028905283062883, 25.480839207999562, 25.931362934330476, 26.380509512576776, 26.82831057393473, 27.27479641783335, 27.71999609251221, 28.16393746929688, 28.606647311172477, 29.048151336188717, 29.488474276171182, 29.927639931162574, 30.36567121997267, 30.802590227176314, 31.238418246864082, 31.673175823419356, 32.10688278956882, 32.539558301928814, 32.97122087424899, 33.401888408535584, 33.83157822421945, 34.26030708551919, 34.68809122713581, 35.11494637840347, 35.540887786009634, 35.96593023538846, 36.39008807088218, 36.81337521475729, 37.235805185155286, 37.65739111305085, 38.078145758284954, 38.49808152473447, 38.91721047467534, 39.33554434239196, 39.75309454708098, 40.16987220509462, 40.585888141564844, 41.00115290144676, 41.415676760016815, 41.829469732858904, 42.242541585368876, 42.65490184180604, 43.06655979391816, 43.477524509164546, 43.8878048385602, 44.29740942416258, 44.706346706220806, 45.11462493000616, 45.52225215234113, 45.929236247843576, 46.335584914900956, 46.74130568138936, 47.14640591015036, 47.55089280423846, 47.954773411951], [0.0, 0.9573374855389362, 1.7256017034333107, 2.435668227923422, 3.110398667002616, 3.760014919475593, 4.39029423436497, 5.00493450349913, 5.6064964750804345, 6.196853049346452, 6.777430371202005, 7.349348586788038, 7.913509419438181, 8.470653442921984, 9.021399073230993, 9.566270008459073, 10.105715083584462, 10.640122981074517, 11.169833354909647, 11.695145393446833, 12.216324514716996, 12.7336076745683, 13.247207627461941, 13.757316384806028, 14.264108050287648, 14.76774116571878, 15.268360668098923, 15.76609953480157, 16.261080176292698, 16.75341562275493, 17.243210541167702, 17.730562111909386, 18.215560788187485, 18.698290957129228, 19.17883151785907, 19.657256389120597, 20.133634956796406, 20.60803246991269, 21.08051039228976, 21.551126715842052, 22.01993624058544, 22.486990825633015, 22.952339614819, 23.416029240058084, 23.87810400510359, 24.3386060519959, 24.79757551217998, 25.255050644006232, 25.71106795810522, 26.165662331935597, 26.618867114642107, 27.070714223220516, 27.52123423086632, 27.970456448280608, 28.418408998616627, 28.865118886672903, 29.31061206287119, 29.7549134824982, 30.19804716063878, 30.64003622318257, 31.08090295424667, 31.520668840321598, 31.959354611416785, 32.3969802794549, 32.83356517413934, 33.26912797649831, 33.70368675028924, 34.13725897143042, 34.56986155561132, 35.00151088421945, 35.43222282870928, 35.862012773527695, 36.29089563770069, 36.7188858951769, 37.14599759401565, 37.57224437449975, 37.997639486247124, 38.42219580438857, 38.84592584487456, 39.268841778968124, 39.69095544697723, 40.11227837127517, 40.53282176865451, 40.952596562056236, 41.37161339171302, 41.7898826257422, 42.20741437022215, 42.62421847878268, 43.04030456173826, 43.45568199479103, 43.87035992732812, 44.2843472903367, 44.697652803958405, 45.11028498470311, 45.52225215234113, 45.93356243649135, 46.34422378292165, 46.75424395957729, 47.163630562351464, 47.572391020611725, 47.98053260249483, 48.388062419982084], [0.0, 0.9658964015024691, 1.7410291573764731, 2.4574439130843433, 3.1382066670089808, 3.793630705134822, 4.429544927014867, 5.049680284862032, 5.656620420820472, 6.25225497947965, 6.838022855954818, 7.4150542108664865, 7.984258829255211, 8.546383905866685, 9.10205338553739, 9.651795648396565, 10.19606354215664, 10.73524922423568, 11.269695385233803, 11.799703888351544, 12.32554252454542, 12.847450368127797, 13.365642075655613, 13.880311375182911, 14.391633926941727, 14.899769690160648, 15.404864897624213, 15.907053715567926, 16.406459648848095, 16.903196738174824, 17.397370586285206, 17.889079242382557, 18.378413968356185, 18.86545990578234, 19.350296659169928, 19.832998808120717, 20.31363635885021, 20.792275143732617, 21.268977176095284, 21.74380096631967, 22.21680180435204, 22.68803201294324, 23.15754117528972, 23.62537634021103, 24.091582207550797, 24.556201296113287, 25.019274096131937, 25.48083920799956, 25.94093346876391, 26.39959206769972, 26.856848652104226, 27.312735424321744, 27.767283230882324, 28.220521644534493, 28.67247903986184, 29.123182663094802, 29.572658696660532, 30.020932318954323, 30.468027759763874, 30.913968351731985, 31.358776578203187, 31.80247411776437, 32.24508188575816, 32.68662007302048, 33.12710818206871, 33.56656506094568, 34.005008934904815, 34.442457436104924, 34.878927631467405, 35.3144360488348, 35.74899870155768, 36.18263111162502, 36.61534833144387, 37.047164964364775, 37.47809518404138, 37.908152752705206, 38.33735103843013, 38.76570303145494, 39.193221359626854, 39.61991830302406, 40.045805807810815, 40.470895499374265, 40.895198694788846, 41.318726414650264, 41.741489394318414, 42.163498094605075, 42.58476271194031, 43.005293188048654, 43.425099219164004, 43.84419026481041, 44.26257555617353, 44.68026410408658, 45.09726470665214, 45.51358595652052, 45.929236247843576, 46.34422378292165, 46.75855657856048, 47.17224247215331, 47.58528912750317, 47.99770404039861, 48.40949454395597, 48.82066781374003], [0.0, 0.9744419543426708, 1.7564325242774672, 2.4791855996445453, 3.165971250099551, 3.8271940061229124, 4.46873433715551, 5.09435620417728, 5.706666107529618, 6.307570410010758, 6.898520737039344, 7.480657248079745, 8.054897777292613, 8.621996130062394, 9.182581771438253, 9.737187756274698, 10.28627093875323, 10.830226945817143, 11.369401499945159, 11.904099135005108, 12.43459001117423, 12.961115317921507, 13.483891610929861, 14.003114332219058, 14.51896069613583, 15.031592077112336, 15.541156001695043, 16.047787823125283, 16.551612138941007, 17.052743998802054, 17.551289939742173, 18.04734887843311, 18.541012884183377, 19.032367851840316, 19.52149409019596, 20.008466838678462, 20.493356722867688, 20.97623015757509, 21.457149704777077, 21.93617439251266, 22.413359999893565, 22.888759312584487, 23.362422352458154, 23.83439658458804, 24.304727104289665, 24.773456806542917, 25.240626539809547, 25.706275245990724, 26.17044008804176, 26.63315656656665, 27.09445862654957, 27.5543787552379, 28.012948072069477, 28.47019641143112, 28.926152398944218, 29.380843521894143, 29.834296194351232, 30.286535817471016, 30.737586835408827, 31.187472787237812, 31.636216355218885, 32.08383940973539, 32.53036305117378, 32.97580764900388, 33.42019287828726, 33.86353775382059, 34.30586066210116, 34.74717939128438, 35.187511159287396, 35.62687264017919, 36.06527998898484, 36.50274886502068, 36.939294453866545, 37.37493148807289, 37.809674266691594, 38.24353667371244, 38.67653219548036, 39.108673937162386, 39.53997463832778, 39.9704466877, 40.40010213713431, 40.82895271487089, 41.25700983810944, 41.68428462494796, 42.110787905725026, 42.53653023380211, 42.96152189581993, 43.3857729214602, 43.80929309274209, 44.23209195288066, 44.65417881473245, 45.07556276885199, 45.49625269118111, 45.91625725039169, 46.335584914900956, 46.75424395957729, 47.17224247215331, 47.58958835936185, 48.00628935280974, 48.42235301460284, 48.8377867427356, 49.252597776257005], [0.0, 0.982974302371523, 1.7718120894937865, 2.5008936903830596, 3.1936929306314736, 3.8607054442220714, 4.507863190796479, 5.138963089095638, 5.756634462337108, 6.3628003656944765, 6.958925135218586, 7.546158913767188, 8.12542757218332, 8.69749151627525, 9.26298572277485, 9.82244791403839, 10.376338944525534, 10.925057905343614, 11.468953546165013, 12.008333067398073, 12.543468994779772, 13.07460462966732, 13.601958423935038, 14.12572753091995, 14.646090716682025, 15.16321076867019, 15.677236505193683, 16.188304464665464, 16.696540335616696, 17.202060175097902, 17.704971452995768, 18.205373952110055, 18.703360547920823, 19.199017887382542, 19.692426982482083, 20.183663731454406, 20.672799378286683, 21.15990091932761, 21.64503146435489, 22.128250558265165, 22.60961446857975, 23.0891764431619, 23.56698694188275, 24.0430938454265, 24.517542643969467, 24.990376608085892, 25.461636943912293, 25.931362934330476, 26.399592067699725, 26.86636015547221, 27.331701439859067, 27.79564869257049, 28.258233305530403, 28.719485374359625, 29.179433775329436, 29.638106236407655, 30.095529402949875, 30.551728898527628, 31.00672938133265, 31.460554596549457, 31.913227425047957, 32.36476992871159, 32.815203392684694, 33.26454836479499, 33.71282469238159, 34.160051556737336, 34.60624750535424, 35.05143048214324, 35.49561785578395, 35.93882644634577, 36.38107255030944, 36.822371964106395, 37.262740006283515, 37.7021915383915, 38.14074098468669, 38.578402350728986, 39.01518924095164, 39.45111487527231, 39.886192104809695, 40.32043342676461, 40.75385099852004, 41.186456651010246, 41.618261901405496, 42.0492779651554, 42.47951576743045, 42.90898595399883, 43.33769890157248, 43.76566472765441, 44.19289329991648, 44.61939424513547, 45.04517695771256, 45.470250607800445, 45.894624149059915, 46.31830632606694, 46.74130568138936, 47.163630562351464, 47.58528912750317, 48.00628935280974, 48.42663903757702, 48.846345810125726, 49.26541713322816, 49.683860309319414], [0.0, 0.9914936004303154, 1.787168132126999, 2.5225685792487442, 3.2213722116855825, 3.8941656275831, 4.546932198030952, 5.183501749123183, 5.806526392046609, 6.417945848819687, 7.019237146684927, 7.611560396624161, 8.19584949387095, 8.77287143456223, 9.343266698682632, 9.907577668951381, 10.466269193988003, 11.019743823765529, 11.56835333052, 12.112407577121878, 12.65218145124983, 13.187920362919218, 13.7198446572956, 14.248153196415844, 14.773026295679864, 15.294628153392184, 15.813108877649098, 16.328606190222516, 16.841246868968174, 17.35114797678649, 17.85841791499033, 18.363157331182745, 18.86545990578234, 19.36541303670037, 19.863098438043046, 20.3585926658445, 20.85196758155338, 21.34329076216618, 21.832625864424042, 22.320032949290734, 22.80556877195015, 23.28928704175718, 23.77123865591147, 24.251471910072272, 24.730032688672775, 25.20696463730712, 25.68230931923952, 26.156106357810927, 26.628393566286878, 27.099207066492294, 27.56858139741067, 28.03654961477994, 28.503143382593354, 28.968393057306177, 29.43232776545622, 29.89497547532564, 30.356363063201528, 30.816516374731258, 31.27546028181559, 31.73321873543517, 32.18981481476514, 32.64527077289614, 33.09960807944782, 33.552847460332984, 34.00500893490481, 34.45611185069767, 34.90617491595203, 35.35521623009615, 35.80325331234151, 36.250303128534675, 36.696382116395625, 37.14150620926123, 37.58569085844204, 38.02895105429168, 38.471301346079464, 38.91275586074949, 39.35332832064269, 39.79303206025185, 40.2318800420745, 40.669884871622905, 41.107058811646354, 41.54341379561612, 41.97896144052015, 42.41371305901075, 42.847679670945325, 43.28087201435739, 43.71330055589238, 44.14497550074026, 44.575906802094586, 45.00610417016604, 45.43557708077576, 45.864334783552806, 46.29238630975811, 46.7197404797556, 47.14640591015036, 47.572391020611725, 47.99770404039861, 48.42235301460284, 48.846345810125726, 49.26969012140155, 49.692393475881396, 50.11446323928951], [0.0, 1.0000000000000002, 1.8025009252216608, 2.544210651641051, 3.249009585424943, 3.927575151158822, 4.585942053541799, 5.227972976198239, 5.856342783782503, 6.473007839923781, 7.07945784384138, 7.676862859549159, 8.266164794522014, 8.848137225247587, 9.423426126631163, 9.992578534698985, 10.556063286183157, 11.114286384685572, 11.667602620429676, 12.216324514716996, 12.760729313591831, 13.301064532535124, 13.83755240713716, 14.370393505547634, 14.899769690160648, 15.425846568000244, 15.948775534996996, 16.468695494490113, 16.98573431201064, 17.500010054786, 18.01163205414503, 18.52070182118473, 19.027313840043544, 19.531556258452543, 20.03351149157425, 20.533256752246032, 21.030864518443167, 21.526402946930816, 22.01993624058544, 22.511524975656606, 23.00122639425244, 23.489094666520757, 23.975181126327577, 24.45953448367893, 24.94220101666795, 25.423224745340885, 25.902647589548955, 26.380509512576776, 26.856848652104226, 27.331701439859064, 27.80510271114782, 28.277085805306136, 28.747682657984665, 29.216923886078224, 29.684838866012225, 30.15145580601933, 30.616801812968486, 31.080902954246675, 31.543784315140126, 32.005470052114035, 32.46598344234853, 32.925346929851955, 33.38358216843997, 33.84071006184085, 34.296750801161394, 34.75172389992579, 35.20564822687963, 35.658542036732996, 36.11042299900135, 36.56130822508767, 37.01121429373738, 37.46015727498549, 37.9081527527052, 38.355215845858055, 38.801361228537075, 39.24660314888678, 39.690955446977235, 40.13443157170293, 40.57704459677156, 41.018807235842864, 41.45973185687291, 41.899830495714724, 42.33911486902284, 42.77759638650507, 43.21528616256235, 43.65219502735387, 44.088333537322384, 44.52371198521203, 44.95834040960862, 45.3922286040304, 45.82538612559516, 46.25782230328805, 46.689546245852604, 47.120566849326, 47.55089280423846, 47.98053260249483, 48.40949454395597, 48.8377867427356, 49.26541713322816, 49.692393475881396, 50.118723362727245, 50.544414222683315], [0.0, 1.0084936493069705, 1.8178107359559832, 2.5658202846791487, 3.2766055334385276, 3.960934597119536, 4.62489343708667, 5.272377545244385, 5.906084505609358, 6.527987298477363, 7.13958827605045, 7.742067440455875, 8.33637469940031, 8.92329019985879, 9.503465403420911, 10.077451992445079, 10.645722785798181, 11.208687235534326, 11.766703145340696, 12.320085690965149, 12.869114473282657, 13.41403911008386, 13.955083724550208, 14.492450588386921, 15.0263231086635, 15.556868299011972, 16.08423884126685, 16.608574818563596, 17.130005182478232, 17.64864900305981, 18.16461654025912, 18.678010167372843, 19.18892517105454, 19.697450447731203, 20.20366911257084, 20.707659034229593, 21.20949330628523, 21.70924066440258, 22.206965856774822, 22.70272997416494, 23.19659074487545, 23.688602799156413, 24.178817906885698, 24.667285191795045, 25.15405132504749, 25.639160700580103, 26.122655594296624, 26.6045763089158, 27.084961306045578, 27.563847326852045, 28.041269502520603, 28.517261455559517, 28.991855392869663, 29.46508219139502, 29.936971477074056, 30.407551697730277, 30.876850190468854, 31.344893244084027, 31.81170615692764, 32.27731329064143, 32.741738120113745, 33.20500327998445, 33.66713060798913, 34.128141185405, 34.588055374835015, 35.04689285554443, 35.504672656543306, 35.96141318759087, 36.41713226828123, 36.87184715535562, 37.32557456837352, 37.77833071386318, 38.23013130806174, 38.680991598345926, 39.13092638344534, 39.57995003252326, 40.02807650320244, 40.47531935860758, 40.921691783489834, 41.36720659949433, 41.81187627962621, 42.25571296196683, 42.69872846268786, 43.140934288407166, 43.58234164792752, 44.02296146339569, 44.46280438091714, 44.90188078065898, 45.34020078647123, 45.77777427505486, 46.214610884702466, 46.65072002363633, 47.086110877966455, 47.52079241928983, 47.954773411951, 48.388062419982084, 48.82066781374003, 49.252597776257005, 49.683860309319414, 50.11446323928951, 50.544414222683315, 50.973720751517035]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 1.8000000000000003\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.01584893192461113, 0.029575152732566265, 0.04259995391188703, 0.05518918645844858, 0.06746414238367815, 0.07949432487547616, 0.09132469616782778, 0.1029866634836179, 0.11450336728854528, 0.1258925411794167, 0.1371681927451782, 0.14834165549752876, 0.1594222804091646, 0.17041790893331674, 0.1813352073136745, 0.19217990943702898, 0.20295699742231393, 0.21367083864453842, 0.22432529154608916, 0.2349237886176038, 0.24546940237185758, 0.25596489844146203, 0.26641277878530395, 0.27681531719676356, 0.2871745887492587, 0.29749249441556525, 0.30777078180727846, 0.3180110627669995, 0.32821482838625377, 0.3383834619016498, 0.34851824982980034, 0.35862039163060777, 0.36869100813333205, 0.3787311489165394, 0.38874179879876347, 0.39872388356938443, 0.4086782750672989, 0.41860579569722817, 0.4285072224590918, 0.438383290554087, 0.4482346966214095, 0.4580621016515332, 0.4678661336153, 0.47764738984250493, 0.48740643917899545, 0.49714382394737167, 0.5068600617330474, 0.516555647014613, 0.5262310526550319, 0.5358867312681467, 0.5455231164732058, 0.5551406240486036, 0.56473965299471, 0.5743205865145341, 0.5838837929199803, 0.593429626470586, 0.6029584281508921, 0.6124705263919324, 0.6219662377417514, 0.6314458674893553, 0.6409097102460523, 0.6503580504877421, 0.6597911630613658, 0.669209313658415, 0.678612759258125, 0.6880017485427284, 0.6973765222869265, 0.7067373137235418, 0.7160843488871359, 0.72541784693722, 0.7347380204625458, 0.744045075767833, 0.7533392131441788, 0.7626206271242885, 0.7718895067235706, 0.781146035668061, 0.7903903926100557, 0.7996227513322693, 0.8088432809412662, 0.8180521460508584, 0.8272495069561095, 0.8364355197985341, 0.8456103367230421, 0.8547741060271344, 0.8639269723028192, 0.8730690765716861, 0.8822005564135441, 0.8913215460890002, 0.900432176656329, 0.9095325760829622, 0.9186228693518994, 0.9277031785633284, 0.9367736230317177, 0.9458343193786323, 0.9548853816214999, 0.9639269212585512, 0.9729590473501307, 0.9819818665965754, 0.9909954834128344, 1.0000000000000002, 1.0089955164139086], [0.0, 0.029575152732566265, 0.05518918645844858, 0.07949432487547616, 0.10298666348361787, 0.1258925411794167, 0.14834165549752873, 0.1704179089333167, 0.19217990943702898, 0.21367083864453842, 0.23492378861760377, 0.25596489844146203, 0.2768153171967635, 0.2974924944155652, 0.3180110627669995, 0.33838346190164975, 0.35862039163060777, 0.37873114891653936, 0.3987238835693844, 0.4186057956972281, 0.4383832905540869, 0.45806210165153316, 0.4776473898425048, 0.49714382394737167, 0.5165556470146131, 0.5358867312681466, 0.5551406240486036, 0.5743205865145341, 0.593429626470586, 0.6124705263919324, 0.6314458674893553, 0.6503580504877421, 0.6692093136584149, 0.6880017485427284, 0.7067373137235418, 0.72541784693722, 0.7440450757678329, 0.7626206271242884, 0.7811460356680608, 0.7996227513322692, 0.8180521460508584, 0.836435519798534, 0.8547741060271344, 0.873069076571686, 0.891321546089, 0.9095325760829622, 0.9277031785633283, 0.9458343193786323, 0.9639269212585511, 0.9819818665965754, 1.0000000000000002, 1.0179821306309549, 1.0359290343593577, 1.0538414557462255, 1.071720109873659, 1.089565684035974, 1.107378839304842, 1.125160211979916, 1.1429104149351756, 1.160630038870159, 1.1783196534742952, 1.1959798085117253, 1.213611034833248, 1.2312138453213912, 1.2487887357740093, 1.2663361857313116, 1.2838566592507525, 1.301350605633812, 1.3188184601083268, 1.3362606444697025, 1.3536775676840485, 1.3710696264560023, 1.3884372057637835, 1.4057806793637957, 1.423100410266902, 1.4403967511883273, 1.4576700449729771, 1.474920624997824, 1.4921488155528797, 1.509354932202152, 1.5265392821258754, 1.5437021644452158, 1.5608438705305416, 1.577964684294294, 1.595064882469395, 1.612144734874072, 1.6292045046639165, 1.6462444485719303, 1.6632648171372644, 1.6802658549233076, 1.6972478007257303, 1.7142108877710571, 1.7311553439062946, 1.7480813917801143, 1.764989249016051, 1.781879128378148, 1.7987512379294615, 1.8156057811837896, 1.832442957251002, 1.849262960976283, 1.8660659830736153, 1.8828522102537901], [0.0, 0.04259995391188703, 0.07949432487547616, 0.11450336728854528, 0.14834165549752873, 0.18133520731367453, 0.21367083864453845, 0.2454694023718576, 0.2768153171967635, 0.30777078180727846, 0.3383834619016498, 0.368691008133332, 0.3987238835693845, 0.42850722245909173, 0.45806210165153327, 0.48740643917899545, 0.516555647014613, 0.5455231164732058, 0.5743205865145341, 0.6029584281508921, 0.6314458674893553, 0.6597911630613656, 0.6880017485427284, 0.7160843488871359, 0.7440450757678331, 0.7718895067235705, 0.7996227513322692, 0.8272495069561095, 0.8547741060271346, 0.8822005564135441, 0.9095325760829623, 0.9367736230317179, 0.9639269212585511, 0.9909954834128345, 1.017982130630955, 1.044889509982403, 1.0717201098736593, 1.0984762736990297, 1.125160211979916, 1.1517740131952723, 1.1783196534742955, 1.2047990052963282, 1.2312138453213912, 1.2575658614568495, 1.2838566592507525, 1.310087767689849, 1.3362606444697027, 1.3623766807954047, 1.3884372057637835, 1.4144434903715566, 1.4403967511883276, 1.4662981537285988, 1.49214881555288, 1.5179498091244406, 1.5437021644452158, 1.5694068714917044, 1.5950648824693952, 1.6206771139022407, 1.6462444485719303, 1.671767737320159, 1.6972478007257306, 1.7226854306671266, 1.7480813917801146, 1.7734364228190196, 1.7987512379294612, 1.8240265278395993, 1.8492629609762832, 1.874461184511905, 1.8996218253472266, 1.9247454910349802, 1.9498327706486205, 1.9748842356002192, 1.9999004404111527, 2.024881923438931, 2.049829207563221, 2.074742800833888, 2.0996231970836194, 2.1244708765075226, 2.1492863062118785, 2.1740699407340576, 2.198822222535472, 2.2235435824692775, 2.2482344402244063, 2.2728952047474156, 2.2975262746435074, 2.3221280385579806, 2.3467008755392933, 2.3712451553848277, 2.395761238970363, 2.4202494785642092, 2.4447102181268754, 2.469143793597089, 2.4935505331649384, 2.5179307575328465, 2.5422847801650454, 2.566612907526173, 2.590915439309578, 2.6151926686558755, 2.639444882362274, 2.6636723610831443, 2.6878753795222874, 2.7120542066173208], [0.0, 0.05518918645844858, 0.10298666348361787, 0.14834165549752873, 0.19217990943702895, 0.23492378861760377, 0.27681531719676344, 0.3180110627669994, 0.35862039163060777, 0.3987238835693844, 0.43838329055408687, 0.47764738984250477, 0.516555647014613, 0.5551406240486035, 0.593429626470586, 0.6314458674893552, 0.6692093136584149, 0.7067373137235416, 0.7440450757678327, 0.7811460356680607, 0.8180521460508583, 0.8547741060271343, 0.8913215460889999, 0.9277031785633282, 0.9639269212585511, 1.0, 1.0359290343593575, 1.071720109873659, 1.107378839304842, 1.1429104149351756, 1.1783196534742952, 1.213611034833248, 1.248788735774009, 1.2838566592507525, 1.3188184601083266, 1.3536775676840485, 1.3884372057637833, 1.4231004102669018, 1.457670044972977, 1.4921488155528797, 1.5265392821258754, 1.5608438705305414, 1.595064882469395, 1.6292045046639163, 1.6632648171372642, 1.6972478007257303, 1.7311553439062946, 1.7649892490160508, 1.798751237929461, 1.8324429572510017, 1.866065983073615, 1.8996218253472261, 1.9331119318962953, 1.9665376921208098, 1.9999004404111522, 2.0332014593038656, 2.0664419824023086, 2.099623197083619, 2.132746247011082, 2.165812234469011, 2.198822222535472, 2.231777237106626, 2.2646782687850924, 2.2975262746435074, 2.330322179873383, 2.3630668793283918, 2.3957612389703624, 2.4284060972255035, 2.4610022662576756, 2.493550533164938, 2.526051661105034, 2.558506390354994, 2.5909154393095775, 2.6232795054228952, 2.655599266097171, 2.687875379522287, 2.720108485469459, 2.7522992060421148, 2.7844481463868145, 2.816555895366818, 2.848623026200712, 2.8806500970683286, 2.9126376516860013, 2.944586219853078, 2.9764963179714514, 3.0083684495397374, 3.040203105623633, 3.07200076530386, 3.1037618961030056, 3.1354869543924897, 3.167176385780791, 3.1988306254839918, 3.2304500986796416, 3.262035220844852, 3.293586398079498, 3.325104027415325, 3.356588497111722, 3.3880401869388668, 3.419459468448913, 3.4508467052358314, 3.4822022531844974, 3.5135264607095675], [0.0, 0.06746414238367815, 0.1258925411794167, 0.18133520731367453, 0.23492378861760377, 0.2871745887492587, 0.3383834619016498, 0.38874179879876347, 0.4383832905540869, 0.48740643917899545, 0.5358867312681466, 0.5838837929199803, 0.6314458674893554, 0.678612759258125, 0.7254178469372201, 0.7718895067235704, 0.8180521460508584, 0.8639269723028192, 0.9095325760829622, 0.9548853816214999, 1.0, 1.044889509982403, 1.089565684035974, 1.134039172248138, 1.1783196534742955, 1.2224159606786607, 1.2663361857313113, 1.3100877676898488, 1.3536775676840487, 1.3971119328426296, 1.4403967511883273, 1.4835374990359085, 1.5265392821258754, 1.5694068714917047, 1.6121447348740723, 1.6547570643496488, 1.6972478007257306, 1.739620655158611, 1.7818791283781483, 1.8240265278395993, 1.8660659830736153, 1.908000459463991, 1.9498327706486205, 1.991565589710743, 2.033201459303866, 2.0747428008338877, 2.11619192280521, 2.157551028423464, 2.1988222225354725, 2.2400075179768293, 2.281108841388703, 2.3221280385579806, 2.3630668793283918, 2.403927062124656, 2.4447102181268754, 2.4854179151281897, 2.526051661105034, 2.566612907526173, 2.60710305242386, 2.647523443248033, 2.687875379522287, 2.7281601153184636, 2.7683788615650147, 2.808532788202808, 2.8486230262007126, 2.8886506694421406, 2.928616776492654, 2.9685223722578313, 3.008368449539738, 3.048155970499604, 3.087885868033637, 3.1275590470682926, 3.1671763857807913, 3.2067387367501707, 3.24624692804372, 3.285701764243256, 3.3251040274153256, 3.3644544780290873, 3.403753855825354, 3.4430028806399746, 3.4822022531844974, 3.521352655786858, 3.560454753094582, 3.5995091927428464, 3.6385166059895684, 3.6774776083194913, 3.7163928000191615, 3.755262766724499, 3.794088079942577, 3.8328692975491037, 3.871606964262994, 3.910301612099335, 3.9489537608019485, 3.987563918256687, 4.02613258088652, 4.064660234029389, 4.103147352299768, 4.141594399934784, 4.18000183112572, 4.21837009033565, 4.256699612603924, 4.294990823838181], [0.0, 0.07949432487547616, 0.14834165549752873, 0.21367083864453845, 0.27681531719676344, 0.3383834619016498, 0.39872388356938443, 0.4580621016515332, 0.5165556470146131, 0.5743205865145341, 0.6314458674893553, 0.6880017485427283, 0.744045075767833, 0.7996227513322692, 0.8547741060271346, 0.9095325760829622, 0.9639269212585511, 1.017982130630955, 1.0717201098736593, 1.125160211979916, 1.1783196534742955, 1.2312138453213912, 1.2838566592507525, 1.3362606444697027, 1.3884372057637837, 1.4403967511883273, 1.4921488155528797, 1.5437021644452158, 1.5950648824693952, 1.6462444485719303, 1.6972478007257306, 1.7480813917801146, 1.798751237929461, 1.8492629609762832, 1.8996218253472263, 1.9498327706486205, 1.9999004404111527, 2.049829207563221, 2.099623197083619, 2.1492863062118785, 2.1988222225354725, 2.2482344402244063, 2.297526274643508, 2.3467008755392933, 2.395761238970363, 2.444710218126876, 2.493550533164938, 2.5422847801650454, 2.5909154393095775, 2.639444882362274, 2.6878753795222874, 2.7362091057165845, 2.784448146386815, 2.8325945028202053, 2.8806500970683286, 2.928616776492654, 2.976496317971452, 3.0242904317988937, 3.07200076530386, 3.1196289062130953, 3.1671763857807913, 3.2146446817044456, 3.262035220844852, 3.309349381766329, 3.356588497111722, 3.403753855825354, 3.450846705235832, 3.497868253009541, 3.544819668984667, 3.591702086894698, 3.6385166059895684, 3.6852642925619077, 3.7319461813851933, 3.778563277070061, 3.8251165553444717, 3.8716069642629947, 3.9180354253500105, 3.964402834681275, 4.010710063907928, 4.056957961226695, 4.103147352299767, 4.14927904112756, 4.195353810877315, 4.241372424670291, 4.287335626330097, 4.333244141094504, 4.379098676292944, 4.424899921991735, 4.470648551608892, 4.516345222500325, 4.561990576519039, 4.607585240548866, 4.653129827014167, 4.698624934366823, 4.744071147551774, 4.789469038452257, 4.834819166315834, 4.880122078162237, 4.925378309173978, 4.970588383070635, 5.015752812467623, 5.060872099220283], [0.0, 0.09132469616782778, 0.1704179089333167, 0.2454694023718576, 0.3180110627669994, 0.38874179879876347, 0.4580621016515332, 0.5262310526550319, 0.593429626470586, 0.6597911630613656, 0.72541784693722, 0.7903903926100556, 0.8547741060271346, 0.9186228693518994, 0.9819818665965755, 1.044889509982403, 1.107378839304842, 1.1694785625235247, 1.2312138453213912, 1.2926069208104465, 1.3536775676840487, 1.4144434903715564, 1.474920624997824, 1.5351233883472912, 1.5950648824693954, 1.654757064349649, 1.7142108877710571, 1.7734364228190194, 1.832442957251002, 1.8912390830327706, 1.9498327706486205, 2.0082314332630053, 2.0664419824023086, 2.1244708765075226, 2.182324163458979, 2.2400075179768293, 2.297526274643508, 2.3548854571680393, 2.412089804409904, 2.4691437935970892, 2.5260516611050345, 2.5828174211072623, 2.639444882362274, 2.695937663362886, 2.752299206042115, 2.808532788202808, 2.8646415348155867, 2.9206284283104917, 2.976496317971452, 3.032247928528857, 3.0878858680336374, 3.1434126350860976, 3.198830625483992, 3.254142138346765, 3.3093493817663284, 3.364454478029087, 3.4194594684489132, 3.4743663178465134, 3.529176918706789, 3.5838930950424945, 3.6385166059895684, 3.693049149156931, 3.7474923637512645, 3.801847833495276, 3.8561170893561543, 3.9103016120993357, 3.964402834681275, 4.0184221444936625, 4.072360885470385, 4.1262203600675145, 4.18000183112572, 4.233706523623646, 4.287335626330098, 4.34089029336219, 4.3943716456560376, 4.447780772355999, 4.5011187321280115, 4.55438655440212, 4.607585240548867, 4.660715764993893, 4.713779076274704, 4.7667760980433185, 4.819707730018183, 4.87257484888851, 4.925378309173978, 4.978118944042481, 5.030797566088449, 5.0834149680740905, 5.13597192363571, 5.188469187957138, 5.240907498412153, 5.293287575177642, 5.345610121819157, 5.397875825850386, 5.450085359267965, 5.502239379062978, 5.554338527710393, 5.606383433637595, 5.658374711673134, 5.710312963476703, 5.762198777951312, 5.8140327316385765], [0.0, 0.1029866634836179, 0.19217990943702898, 0.2768153171967635, 0.35862039163060777, 0.4383832905540869, 0.5165556470146131, 0.593429626470586, 0.669209313658415, 0.7440450757678329, 0.8180521460508584, 0.891321546089, 0.9639269212585512, 1.0359290343593577, 1.1073788393048423, 1.1783196534742952, 1.2487887357740093, 1.3188184601083268, 1.3884372057637835, 1.4576700449729771, 1.5265392821258756, 1.595064882469395, 1.6632648171372644, 1.7311553439062948, 1.7987512379294615, 1.8660659830736153, 1.9331119318962955, 1.9999004404111527, 2.066441982402309, 2.1327462470110823, 2.1988222225354725, 2.2646782687850924, 2.330322179873383, 2.395761238970363, 2.461002266257676, 2.526051661105034, 2.590915439309578, 2.655599266097171, 2.720108485469459, 2.784448146386815, 2.8486230262007126, 2.9126376516860013, 2.976496317971452, 3.0402031056236334, 3.103761896103006, 3.1671763857807913, 3.2304500986796416, 3.2935863980794986, 3.356588497111722, 3.4194594684489132, 3.482202253184498, 3.5448196689846667, 3.6073144175853957, 3.669689091698737, 3.731946181385193, 3.794088079942577, 3.8561170893561543, 3.91803542535001, 3.979845222075298, 4.041548536467278, 4.103147352299767, 4.164643583962693, 4.226039079985906, 4.287335626330098, 4.348534949463675, 4.409638719242635, 4.470648551608892, 4.531566011121071, 4.592392613330524, 4.653129827014167, 4.713779076274704, 4.774341742517918, 4.834819166315834, 4.895212649163843, 4.955523455139189, 5.015752812467623, 5.075901915004449, 5.13597192363571, 5.195963967604817, 5.255879145769468, 5.3157185277933685, 5.375483155276916, 5.435174042830664, 5.494792179095155, 5.554338527710392, 5.613814028238018, 5.673219597039023, 5.732556128109646, 5.791824493877883, 5.8510255459629175, 5.910160115899571, 5.9692290158297725, 6.028233039162882, 6.087172961206607, 6.1460495397701065, 6.204863515740816, 6.263615613636374, 6.322306542132991, 6.380936994571502, 6.439507649442247, 6.4980191708498865, 6.556472208959159], [0.0, 0.11450336728854528, 0.21367083864453842, 0.30777078180727846, 0.3987238835693844, 0.48740643917899545, 0.5743205865145341, 0.6597911630613656, 0.7440450757678329, 0.8272495069561094, 0.9095325760829622, 0.9909954834128343, 1.0717201098736593, 1.151774013195272, 1.2312138453213912, 1.3100877676898488, 1.3884372057637833, 1.4662981537285988, 1.5437021644452156, 1.6206771139022405, 1.6972478007257306, 1.7734364228190191, 1.849262960976283, 1.92474549103498, 1.999900440411153, 2.0747428008338877, 2.149286306211878, 2.2235435824692775, 2.2975262746435074, 2.3712451553848273, 2.4447102181268754, 2.517930757532846, 2.5909154393095775, 2.6636723610831443, 2.7362091057165845, 2.8085327882028075, 2.880650097068329, 2.9525673310650067, 3.0242904317988932, 3.09582501284115, 3.1671763857807913, 3.238349583608942, 3.3093493817663284, 3.380180317137601, 3.450846705235832, 3.5213526557868584, 3.591702086894698, 3.6618987379452617, 3.731946181385193, 3.8018478334952754, 3.8716069642629947, 3.9412267064460864, 4.010710063907927, 4.080059919296138, 4.14927904112756, 4.21837009033565, 4.287335626330098, 4.356178112613069, 4.424899921991734, 4.493503341422537, 4.561990576519039, 4.630363755751917, 4.698624934366823, 4.766776098043319, 4.8348191663158335, 4.902755995775582, 4.970588383070635, 5.0383180677197315, 5.105946734753996, 5.173476017199457, 5.240907498412152, 5.3082427142765205, 5.375483155276916, 5.442630268451234, 5.509685459234862, 5.576650093202519, 5.64352549771493, 5.710312963476703, 5.777013746011307, 5.843629067058551, 5.91016011589957, 5.9766080506139545, 6.042973999273252, 6.109259061074845, 6.175464307419843, 6.241590782938376, 6.307639506465461, 6.373611471970378, 6.439507649442247, 6.505328985734391, 6.571076405369788, 6.6367508113098745, 6.702353085688709, 6.767884090514438, 6.833344668339855, 6.898735642903712, 6.964057819744384, 7.029311986787313, 7.094498914907654, 7.159619358469382, 7.224674055842079, 7.289663729896545], [0.0, 0.1258925411794167, 0.23492378861760377, 0.3383834619016498, 0.43838329055408687, 0.5358867312681466, 0.6314458674893553, 0.72541784693722, 0.8180521460508584, 0.9095325760829622, 1.0, 1.089565684035974, 1.1783196534742955, 1.2663361857313113, 1.3536775676840487, 1.440396751188327, 1.5265392821258754, 1.612144734874072, 1.6972478007257303, 1.781879128378148, 1.866065983073615, 1.9498327706486203, 2.0332014593038656, 2.11619192280521, 2.1988222225354725, 2.2811088413887024, 2.3630668793283913, 2.4447102181268754, 2.526051661105034, 2.60710305242386, 2.687875379522287, 2.7683788615650147, 2.848623026200712, 2.928616776492654, 3.008368449539738, 3.0878858680336365, 3.1671763857807913, 3.2462469280437194, 3.325104027415325, 3.403753855825354, 3.4822022531844974, 3.5604547530945814, 3.6385166059895684, 3.716392800019161, 3.794088079942577, 3.871606964262994, 3.948953760801948, 4.02613258088652, 4.103147352299767, 4.18000183112572, 4.256699612603924, 4.333244141094503, 4.4096387192426345, 4.485886516420913, 4.561990576519039, 4.63795382514246, 4.713779076274704, 4.789469038452257, 4.865026320495552, 4.9404534368350825, 5.015752812467622, 5.090926787573975, 5.165977621826534, 5.240907498412153, 5.3157185277933685, 5.390412751228804, 5.464992144071646, 5.539458618863329, 5.613814028238018, 5.688060167652052, 5.762198777951311, 5.836231547788271, 5.910160115899571, 5.983986073253949, 6.057710965079607, 6.131336292779303, 6.204863515740816, 6.278294053049774, 6.351629285111347, 6.424870555186722, 6.498019170849886, 6.571076405369788, 6.644043499022565, 6.716921660338194, 6.789712067285596, 6.862415868399918, 6.9350341838554606, 7.007568106487495, 7.080018702765929, 7.152387013723644, 7.224674055842078, 7.296880821896487, 7.369008281763136, 7.44105738319054, 7.513029052536714, 7.58492419547428, 7.656743697665166, 7.728488425406481, 7.800159226249128, 7.8717569295905285, 7.943282347242818, 8.01473627397775], [0.0, 0.1371681927451782, 0.25596489844146203, 0.368691008133332, 0.47764738984250477, 0.5838837929199803, 0.6880017485427283, 0.7903903926100556, 0.891321546089, 0.9909954834128343, 1.089565684035974, 1.1871533798287799, 1.2838566592507525, 1.3797564524258426, 1.474920624997824, 1.5694068714917042, 1.6632648171372642, 1.7565375808180623, 1.8492629609762827, 1.941474351380762, 2.0332014593038656, 2.124470876507522, 2.2153065387893567, 2.3057300999226618, 2.395761238970363, 2.4854179151281897, 2.574716580798193, 2.6636723610831443, 2.7522992060421148, 2.8406100206664786, 2.9286167764926536, 3.016330607971816, 3.103761896103005, 3.190920341358448, 3.277815027555007, 3.3644544780290864, 3.450846705235832, 3.5369992547036344, 3.622919244121551, 3.708613398212436, 3.794088079942577, 3.8793493185346324, 3.9644028346812745, 4.049254063299246, 4.133908174115369, 4.21837009033565, 4.302644505614606, 4.386735899513142, 4.470648551608891, 4.554386554402119, 4.637953825142461, 4.721354116686508, 4.804591027483117, 4.887668010771905, 4.970588383070634, 5.053355332018606, 5.135971923635709, 5.218441109050352, 5.300765730743754, 5.382948528353095, 5.464992144071645, 5.546899127680102, 5.628671941239961, 5.710312963476703, 5.791824493877882, 5.873208756528848, 5.954467903706647, 6.035604019250795, 6.1166191217279025, 6.1975151674055855, 6.278294053049773, 6.358957618558259, 6.439507649442247, 6.519945879166682, 6.600273991359182, 6.680493621896674, 6.7606063608780005, 6.840613754490165, 6.920517306775269, 7.000318481304609, 7.080018702765928, 7.159619358469382, 7.239121799777288, 7.318527343462434, 7.397837272999338, 7.477052839792479, 7.556175264345337, 7.635205737373723, 7.7141454208666485, 7.792995449097819, 7.871756929590528, 7.950430944038626, 8.02901854918601, 8.107520777666936, 8.18593863880931, 8.264273119402944, 8.34252518443468, 8.42069577779212, 8.498785822937645, 8.576796223554222, 8.654727864164498, 8.7325816107245], [0.0, 0.14834165549752876, 0.2768153171967635, 0.3987238835693845, 0.516555647014613, 0.6314458674893554, 0.744045075767833, 0.8547741060271346, 0.9639269212585512, 1.0717201098736593, 1.1783196534742955, 1.2838566592507525, 1.3884372057637837, 1.49214881555288, 1.5950648824693954, 1.6972478007257306, 1.7987512379294612, 1.8996218253472266, 1.9999004404111527, 2.099623197083619, 2.1988222225354725, 2.2975262746435074, 2.395761238970363, 2.4935505331649384, 2.5909154393095783, 2.6878753795222874, 2.784448146386815, 2.880650097068329, 2.9764963179714523, 3.0720007653038603, 3.1671763857807917, 3.2620352208448526, 3.356588497111722, 3.4508467052358323, 3.544819668984667, 3.638516605989569, 3.7319461813851937, 3.8251165553444717, 3.91803542535001, 4.010710063907928, 4.103147352299768, 4.195353810877315, 4.287335626330098, 4.379098676292944, 4.4706485516088925, 4.56199057651904, 4.653129827014167, 4.744071147551775, 4.834819166315834, 4.925378309173979, 5.015752812467624, 5.105946734753996, 5.1959639676048175, 5.2858082455541044, 5.375483155276916, 5.464992144071646, 5.554338527710393, 5.64352549771493, 5.732556128109645, 5.821433381697407, 5.910160115899571, 5.9987390881971745, 6.087172961206607, 6.175464307419845, 6.263615613636374, 6.351629285111348, 6.439507649442248, 6.527252960214238, 6.614867400422559, 6.702353085688709, 6.789712067285597, 6.876946334985627, 6.964057819744385, 7.051048396231604, 7.137919885220042, 7.22467405584208, 7.311312627723017, 7.39783727299934, 7.4842496182295895, 7.570551246204822, 7.656743697665166, 7.742828472928448, 7.828807033436415, 7.91468080322369, 8.000451170314205, 8.086119488049498, 8.17168707635296, 8.25715522293387, 8.342525184434681, 8.427798187524894, 8.51297542994457, 8.5980580815003, 8.683047285016352, 8.767944157243425, 8.852749789727374, 8.937465249640054, 9.022091580574314, 9.106629803305069, 9.191080916518201, 9.275445897508996, 9.359725702851645, 9.443921269041327], [0.0, 0.1594222804091646, 0.2974924944155652, 0.42850722245909173, 0.5551406240486035, 0.678612759258125, 0.7996227513322692, 0.9186228693518994, 1.0359290343593577, 1.151774013195272, 1.2663361857313113, 1.3797564524258426, 1.49214881555288, 1.6036073352925262, 1.7142108877710573, 1.8240265278395988, 1.9331119318962953, 2.0415172144072486, 2.149286306211878, 2.2564580188646177, 2.3630668793283913, 2.469143793597089, 2.574716580798193, 2.6798104078005593, 2.784448146386815, 2.88865066944214, 2.992437098596708, 3.0958250128411495, 3.198830625483992, 3.30146893521489, 3.4037538558253537, 3.505698328213431, 3.6073144175853953, 3.708613398212436, 3.8096058276645706, 3.910301612099335, 4.010710063907927, 4.1108399528008706, 4.210699551236945, 4.310296674954123, 4.4096387192426345, 4.50873269150271, 4.607585240548866, 4.706202683055572, 4.804591027483117, 4.902755995775582, 5.000703043083256, 5.098437375728396, 5.195963967604816, 5.293287575177642, 5.390412751228804, 5.487343857476165, 5.584085076178822, 5.680640420827978, 5.777013746011306, 5.8732087565288476, 5.9692290158297725, 6.0650779538318424, 6.160758874178774, 6.256274960984887, 6.351629285111346, 6.446824810013786, 6.5418643971971235, 6.6367508113098745, 6.731486724907116, 6.8260747229085075, 6.920517306775269, 7.014816898427826, 7.10897584392386, 7.202996416914703, 7.296880821896487, 7.390631197270947, 7.484249618229588, 7.577738099473693, 7.67109859778165, 7.764333014434102, 7.8574431975065995, 7.950430944038627, 8.0432980020872, 8.136046072672565, 8.228676811622982, 8.321191831324994, 8.41359270238515, 8.505880955208696, 8.598058081500298, 8.690125535691577, 8.782084736299781, 8.873937067221762, 8.965683878966953, 9.057326489832963, 9.14886618702702, 9.240304227736353, 9.331641840150375, 9.422880224437321, 9.51402055367787, 9.605063974758036, 9.696011609223563, 9.786864554097832, 9.877623882665217, 9.968290645221689, 10.058865869794328, 10.149350562831366], [0.0, 0.17041790893331674, 0.3180110627669995, 0.45806210165153327, 0.593429626470586, 0.7254178469372201, 0.8547741060271346, 0.9819818665965755, 1.1073788393048423, 1.2312138453213912, 1.3536775676840487, 1.474920624997824, 1.5950648824693954, 1.7142108877710573, 1.8324429572510021, 1.9498327706486205, 2.0664419824023086, 2.182324163458979, 2.2975262746435074, 2.4120898044099044, 2.5260516611050345, 2.639444882362274, 2.752299206042115, 2.864641534815587, 2.9764963179714523, 3.087885868033637, 3.198830625483992, 3.309349381766329, 3.4194594684489132, 3.5291769187067894, 3.638516605989569, 3.747492363751265, 3.8561170893561543, 3.964402834681275, 4.072360885470385, 4.18000183112572, 4.287335626330098, 4.394371645656037, 4.5011187321280115, 4.607585240548867, 4.7137790762747045, 4.819707730018183, 4.925378309173979, 5.030797566088449, 5.13597192363571, 5.240907498412153, 5.345610121819157, 5.450085359267965, 5.554338527710393, 5.658374711673134, 5.762198777951313, 5.865815389097961, 5.969229015829773, 6.072443948455332, 6.175464307419844, 6.278294053049774, 6.380936994571503, 6.48339679847011, 6.5856769962472965, 6.687780991631214, 6.789712067285597, 6.891473391060707, 6.993068021824369, 7.094498914907656, 7.195768927196359, 7.2968808218964885, 7.39783727299934, 7.498640869469352, 7.599294119175831, 7.699799452587753, 7.800159226249129, 7.900375726050938, 8.000451170314207, 8.100387712697628, 8.200187444941953, 8.29985239946242, 8.399384551799523, 8.498785822937647, 8.598058081500302, 8.697203145830025, 8.796222785960392, 8.895118725487016, 8.993892643343882, 9.092546175490908, 9.1910809165182, 9.28949842117202, 9.387800205807192, 9.485987749770308, 9.584062496717756, 9.682025855872398, 9.779879203222356, 9.877623882665219, 9.975261207100733, 10.072792459474803, 10.170218893777491, 10.267541735997513, 10.36476218503555, 10.461881413578569, 10.55890056893721, 10.655820773848163, 10.752643127243298, 10.849368704987315], [0.0, 0.1813352073136745, 0.33838346190164975, 0.48740643917899545, 0.6314458674893552, 0.7718895067235704, 0.9095325760829622, 1.044889509982403, 1.1783196534742952, 1.3100877676898488, 1.440396751188327, 1.5694068714917042, 1.6972478007257306, 1.8240265278395988, 1.9498327706486205, 2.0747428008338873, 2.198822222535472, 2.3221280385579806, 2.4447102181268754, 2.5666129075261725, 2.687875379522287, 2.808532788202807, 2.9286167764926536, 3.0481559704996037, 3.1671763857807913, 3.2857017642432558, 3.4037538558253533, 3.521352655786858, 3.6385166059895684, 3.7552627667244987, 3.8716069642629938, 3.987563918256687, 4.103147352299767, 4.21837009033565, 4.333244141094503, 4.447780772355998, 4.561990576519039, 4.67588352870926, 4.789469038452257, 4.902755995775582, 5.015752812467623, 5.128467459110472, 5.240907498412152, 5.35308011528729, 5.464992144071646, 5.5766500932025185, 5.688060167652052, 5.799228289362418, 5.91016011589957, 6.020861057514746, 6.131336292779303, 6.241590782938375, 6.351629285111346, 6.461456364452205, 6.571076405369788, 6.680493621896673, 6.789712067285596, 6.898735642903712, 7.007568106487494, 7.116213079814458, 7.224674055842077, 7.332954405359181, 7.44105738319054, 7.548986133991408, 7.656743697665165, 7.764333014434102, 7.8717569295905285, 7.979018197952917, 8.086119488049496, 8.193063386049747, 8.299852399462416, 8.406488960617049, 8.51297542994457, 8.619314099071184, 8.72550719373857, 8.83155687656239, 8.937465249640052, 9.043234357017889, 9.148866187027021, 9.254362674496498, 9.359725702851643, 9.464957106104913, 9.570058670746029, 9.675032137537638, 9.779879203222354, 9.884601522146465, 9.989200707805397, 10.093678334315525, 10.198035937816638, 10.302275017809118, 10.406397038429523, 10.51040342966811, 10.614295588531498, 10.71807488015357, 10.821742638857398, 10.925300169170889, 11.028748746798604, 11.132089619552085, 11.235324008240898, 11.338453107526398, 11.441478086740144, 11.54440009066879], [0.0, 0.19217990943702898, 0.35862039163060777, 0.516555647014613, 0.6692093136584149, 0.8180521460508584, 0.9639269212585511, 1.107378839304842, 1.2487887357740093, 1.3884372057637833, 1.5265392821258754, 1.6632648171372642, 1.7987512379294612, 1.9331119318962953, 2.0664419824023086, 2.198822222535472, 2.330322179873383, 2.4610022662576756, 2.5909154393095775, 2.7201084854694586, 2.848623026200712, 2.9764963179714514, 3.1037618961030056, 3.2304500986796416, 3.3565884971117224, 3.4822022531844974, 3.6073144175853953, 3.731946181385193, 3.856117089356154, 3.979845222075298, 4.103147352299767, 4.226039079985906, 4.348534949463674, 4.470648551608892, 4.592392613330524, 4.713779076274704, 4.8348191663158335, 4.955523455139188, 5.075901915004447, 5.195963967604817, 5.3157185277933685, 5.435174042830663, 5.554338527710392, 5.673219597039022, 5.791824493877883, 5.910160115899571, 6.028233039162882, 6.146049539770106, 6.2636156136363725, 6.380936994571502, 6.4980191708498865, 6.614867400422558, 6.731486724907116, 6.847881982475324, 6.964057819744383, 7.080018702765928, 7.195768927196358, 7.311312627723015, 7.4266537868127696, 7.5417962428425405, 7.656743697665164, 7.7714997236585655, 7.886067770301414, 8.000451170314205, 8.114653145400904, 8.228676811622984, 8.34252518443468, 8.45620118340562, 8.569707636654632, 8.68304728501635, 8.79622278596039, 8.909236717281095, 9.022091580574312, 9.13478980451632, 9.247333747958667, 9.359725702851645, 9.471967897008021, 9.584062496717754, 9.696011609223563, 9.807817285066413, 9.919481520309361, 10.031006258647475, 10.142393393410996, 10.25364476946841, 10.364762185035548, 10.475747393396427, 10.586602104541122, 10.6973279867256, 10.807926667958073, 10.918399737416125, 11.028748746798602, 11.13897521161593, 11.249080612422329, 11.359066395993132, 11.468933976450241, 11.578684736338491, 11.688320027655603, 11.797841172838147, 11.907249465705867, 12.01654617236651, 12.12573253208319, 12.234809758106207], [0.0, 0.20295699742231393, 0.37873114891653936, 0.5455231164732058, 0.7067373137235416, 0.8639269723028192, 1.017982130630955, 1.1694785625235247, 1.3188184601083268, 1.4662981537285988, 1.612144734874072, 1.7565375808180623, 1.8996218253472266, 2.0415172144072486, 2.182324163458979, 2.3221280385579806, 2.4610022662576756, 2.599010646182192, 2.7362091057165845, 2.872647054996832, 3.008368449539738, 3.143412635086097, 3.277815027555007, 3.4116076663334582, 3.544819668984667, 3.6774776083194913, 3.80960582766457, 3.9412267064460864, 4.072360885470385, 4.203027459239247, 4.333244141094503, 4.463027405808716, 4.5923926133305235, 4.721354116686509, 4.8499253564867635, 4.978118944042481, 5.105946734753996, 5.233419893146813, 5.360548950706189, 5.487343857476166, 5.613814028238018, 5.739968383958794, 5.865815389097961, 5.9913630852748, 6.1166191217279025, 6.241590782938376, 6.366285013738026, 6.490708442181162, 6.6148674004225585, 6.7387679438133095, 6.862415868399919, 6.985816726989423, 7.10897584392386, 7.231898328690567, 7.354589088480302, 7.477052839792479, 7.5992941191758305, 7.721317293183191, 7.8431265676106845, 7.9647259960841925, 8.086119488049496, 8.207310816216758, 8.328303623504928, 8.449101429527197, 8.569707636654632, 8.690125535691578, 8.81035831119327, 8.930409046453315, 9.050280728186126, 9.169976250927188, 9.289498421172018, 9.408849961272818, 9.528033513110229, 9.647051641556128, 9.76590683774202, 9.884601522146465, 10.00313804751378, 10.121518701615392, 10.239745709864223, 10.357821237791729, 10.475747393396427, 10.593526229372147, 10.711159745223537, 10.82864988927583, 10.945998560585425, 11.06320761075721, 11.180278845674287, 11.297214027145285, 11.41401487447405, 11.530683065956259, 11.647220240307114, 11.763627998024013, 11.879907902687872, 11.99606148220647, 12.112090230003002, 12.227995606152819, 12.343779038471132, 12.459441923554266, 12.574985627776947, 12.690411488247863, 12.805720813725669, 12.920914885497467], [0.0, 0.21367083864453842, 0.3987238835693844, 0.5743205865145341, 0.7440450757678327, 0.9095325760829622, 1.0717201098736593, 1.2312138453213912, 1.3884372057637835, 1.5437021644452156, 1.6972478007257303, 1.8492629609762827, 1.9999004404111527, 2.149286306211878, 2.2975262746435074, 2.4447102181268754, 2.5909154393095775, 2.7362091057165845, 2.8806500970683286, 3.0242904317988932, 3.167176385780791, 3.309349381766328, 3.4508467052358314, 3.5917020868946974, 3.7319461813851933, 3.8716069642629938, 4.010710063907927, 4.14927904112756, 4.287335626330097, 4.424899921991734, 4.561990576519039, 4.698624934366822, 4.8348191663158335, 4.970588383070635, 5.105946734753995, 5.240907498412152, 5.375483155276915, 5.509685459234861, 5.643525497714929, 5.777013746011307, 5.910160115899571, 6.042973999273252, 6.175464307419844, 6.30763950646546, 6.439507649442247, 6.571076405369788, 6.702353085688708, 6.833344668339854, 6.964057819744383, 7.094498914907654, 7.224674055842079, 7.354589088480301, 7.484249618229588, 7.613661024300602, 7.742828472928446, 7.8717569295905285, 8.000451170314205, 8.128915792157072, 8.257155222933868, 8.38517373025622, 8.512975429944568, 8.640564293865637, 8.767944157243424, 8.895118725487016, 9.022091580574312, 9.148866187027021, 9.275445897508995, 9.401833958076978, 9.528033513110229, 9.654047609943074, 9.779879203222354, 9.905531159009769, 10.031006258647475, 10.156307202403665, 10.281436612913504, 10.406397038429525, 10.531190955894422, 10.655820773848161, 10.780288835180377, 10.904597419738165, 11.028748746798602, 11.15274497741461, 11.276588216642136, 11.400280515656021, 11.523823873761431, 11.647220240307114, 11.77047151650644, 11.893579557171671, 12.01654617236651, 12.139373128981727, 12.26206215223821, 12.384614927121572, 12.507033099752176, 12.629318278694102, 12.751472036206456, 12.873495909440102, 12.995391401582799, 13.117159982955412, 13.238803092061847, 13.360322136595052, 13.48171849440139, 13.60299351440547], [0.0, 0.22432529154608916, 0.4186057956972281, 0.6029584281508921, 0.7811460356680607, 0.9548853816214999, 1.125160211979916, 1.2926069208104465, 1.4576700449729771, 1.6206771139022405, 1.781879128378148, 1.941474351380762, 2.099623197083619, 2.2564580188646177, 2.4120898044099044, 2.5666129075261725, 2.7201084854694586, 2.872647054996832, 3.0242904317988932, 3.175093228149669, 3.325104027415325, 3.474366317846513, 3.622919244121551, 3.770798218889025, 3.91803542535001, 4.064660234029389, 4.210699551236944, 4.356178112613069, 4.5011187321280115, 4.645542514645037, 4.789469038452257, 4.932916512865958, 5.075901915004447, 5.218441109050352, 5.360548950706189, 5.502239379062978, 5.64352549771493, 5.7844196466427835, 5.92493346613749, 6.0650779538318424, 6.204863515740816, 6.344300012074007, 6.4833967984701095, 6.622162763208968, 6.7606063608780005, 6.898735642903712, 7.036558285303385, 7.174081613964936, 7.311312627723015, 7.448258019465361, 7.584924195474281, 7.72131729318319, 7.857443197506599, 7.9933075558833835, 8.128915792157072, 8.264273119402944, 8.399384551799521, 8.534254915631434, 8.668888859501363, 8.803290863820523, 8.937465249640052, 9.071416186879281, 9.205147702001282, 9.338663685181148, 9.471967897008021, 9.605063974758037, 9.737955438271811, 9.87064569546701, 10.00313804751378, 10.135435693698302, 10.267541735997513, 10.399459183386016, 10.531190955894422, 10.662739888436725, 10.7941087344228, 10.92530016917089, 11.056316793133616, 11.187161134950042, 11.317835654335326, 11.448342744818545, 11.578684736338491, 11.708863897706532, 11.83888243894483, 11.968742513507724, 12.098446220393452, 12.227995606152817, 12.35739266680103, 12.486639349638448, 12.61573755498554, 12.74468913783707, 12.873495909440102, 13.002159638800137, 13.130682054119452, 13.259064844171343, 13.387309659613823, 13.515418114246037, 13.643391786210485, 13.771232219143908, 13.898940923279566, 14.026519376503419, 14.153969025366562, 14.281291286056199], [0.0, 0.2349237886176038, 0.4383832905540869, 0.6314458674893553, 0.8180521460508583, 1.0, 1.1783196534742955, 1.3536775676840487, 1.5265392821258756, 1.6972478007257306, 1.866065983073615, 2.0332014593038656, 2.1988222225354725, 2.3630668793283913, 2.5260516611050345, 2.687875379522287, 2.848623026200712, 3.008368449539738, 3.167176385780791, 3.325104027415325, 3.4822022531844974, 3.638516605989568, 3.794088079942577, 3.948953760801948, 4.103147352299768, 4.256699612603924, 4.4096387192426345, 4.561990576519039, 4.713779076274704, 4.865026320495552, 5.015752812467623, 5.165977621826534, 5.3157185277933685, 5.464992144071646, 5.613814028238018, 5.762198777951311, 5.910160115899571, 6.057710965079606, 6.204863515740816, 6.351629285111347, 6.4980191708498865, 6.644043499022565, 6.789712067285597, 6.9350341838554606, 7.080018702765929, 7.224674055842079, 7.369008281763136, 7.513029052536715, 7.656743697665165, 7.800159226249128, 7.9432823472428185, 8.086119488049496, 8.228676811622984, 8.370960232221666, 8.51297542994457, 8.654727864164498, 8.796222785960392, 8.937465249640052, 9.078460123434544, 9.219212099437078, 9.359725702851643, 9.500005300610031, 9.640055109410028, 9.779879203222356, 9.919481520309361, 10.058865869794328, 10.19803593781664, 10.336995293304808, 10.475747393396427, 10.6142955885315, 10.752643127243296, 10.890793160668766, 11.028748746798604, 11.166512854485452, 11.304088367227093, 11.441478086740144, 11.578684736338493, 11.715710964129558, 11.852559346040469, 11.989232388685233, 12.12573253208319, 12.26206215223821, 12.398223563587404, 12.53421902132745, 12.670050723626083, 12.805720813725667, 12.941231381945366, 13.0765844675879, 13.211782060756484, 13.34682610408717, 13.481718494401388, 13.616461084283275, 13.751055683585937, 13.885504060870637, 14.019807944782555, 14.153969025366562, 14.287988955326254, 14.421869351229201, 14.555611794661306, 14.689217833332892, 14.822688982138962, 14.956026724176052], [0.0, 0.24546940237185758, 0.45806210165153316, 0.6597911630613656, 0.8547741060271343, 1.044889509982403, 1.2312138453213912, 1.4144434903715564, 1.595064882469395, 1.7734364228190191, 1.9498327706486203, 2.124470876507522, 2.2975262746435074, 2.469143793597089, 2.639444882362274, 2.808532788202807, 2.9764963179714514, 3.143412635086097, 3.309349381766328, 3.474366317846513, 3.638516605989568, 3.801847833495275, 3.964402834681274, 4.1262203600675145, 4.287335626330098, 4.447780772355998, 4.607585240548866, 4.7667760980433185, 4.925378309173978, 5.08341496807409, 5.240907498412152, 5.397875825850385, 5.554338527710391, 5.710312963476703, 5.8658153890979605, 6.020861057514745, 6.175464307419844, 6.329638641917057, 6.4833967984701095, 6.6367508113098745, 6.789712067285596, 6.942291355995457, 7.094498914907654, 7.246344470079944, 7.397837272999339, 7.5489861339914075, 7.699799452587751, 7.850285245188643, 8.000451170314205, 8.150304551700168, 8.299852399462418, 8.449101429527195, 8.5980580815003, 8.746728535128277, 8.895118725487015, 9.043234357017889, 9.1910809165182, 9.338663685181148, 9.485987749770304, 9.633058013004646, 9.779879203222354, 9.926455883384644, 10.072792459474801, 10.218893188342099, 10.364762185035548, 10.510403429668111, 10.655820773848161, 10.801017946711665, 10.945998560585426, 11.090766116309057, 11.235324008240898, 11.37967552897089, 11.523823873761431, 11.667772144735507, 11.811523354829697, 11.955080431528309, 12.098446220393454, 12.241623488404796, 12.384614927121573, 12.527423155678465, 12.670050723626083, 12.81250011362595, 12.954773744009122, 13.096873971206952, 13.238803092061845, 13.38056334602527, 13.522156917249786, 13.663585936581418, 13.804852483458141, 13.945958587719984, 14.086906231335764, 14.227697350051209, 14.368333834962845, 14.508817534021784, 14.64915025347124, 14.789333759221373, 14.929369778164833, 15.069259999436111, 15.209006075617735, 15.348609623895976, 15.488072227168738, 15.627395435108035], [0.0, 0.25596489844146203, 0.4776473898425048, 0.6880017485427284, 0.8913215460889999, 1.089565684035974, 1.2838566592507525, 1.474920624997824, 1.6632648171372644, 1.849262960976283, 2.0332014593038656, 2.2153065387893567, 2.395761238970363, 2.574716580798193, 2.752299206042115, 2.9286167764926536, 3.1037618961030056, 3.277815027555007, 3.4508467052358314, 3.622919244121551, 3.794088079942577, 3.964402834681274, 4.133908174115369, 4.302644505614607, 4.470648551608892, 4.63795382514246, 4.804591027483117, 4.970588383070635, 5.135971923635709, 5.300765730743755, 5.464992144071646, 5.628671941239962, 5.791824493877882, 5.9544679037066475, 6.1166191217279025, 6.278294053049773, 6.439507649442247, 6.600273991359181, 6.760606360878, 6.920517306775269, 7.080018702765929, 7.239121799777288, 7.397837272999339, 7.556175264345337, 7.714145420866649, 7.871756929590529, 8.02901854918601, 8.185938638809311, 8.34252518443468, 8.498785822937645, 8.654727864164498, 8.81035831119327, 8.965683878966953, 9.120711011458534, 9.275445897508995, 9.429894485463596, 9.584062496717754, 9.737955438271811, 9.891578614383272, 10.044937137395888, 10.198035937816638, 10.350879773704548, 10.503473239428823, 10.655820773848163, 10.807926667958073, 10.95979507204857, 11.111430002410632, 11.262835347626297, 11.41401487447405, 11.564972233478343, 11.715710964129556, 11.866234499798372, 12.016546172366512, 12.166649216593939, 12.316546774240884, 12.466241897961632, 12.615737554985541, 12.765036630599582, 12.91414193144556, 13.06305618864408, 13.211782060756482, 13.360322136595054, 13.508678937891041, 13.65685492182936, 13.804852483458141, 13.952673957980718, 14.100321622937114, 14.247797700281602, 14.395104358362348, 14.54224371380893, 14.68921783333289, 14.836028735446327, 14.98267839210308, 15.12916873026681, 15.275501633409986, 15.421678942947505, 15.567702459608492, 15.713573944749493, 15.859295121612238, 16.00486767652878, 16.150293260076733, 16.295573488187188], [0.0, 0.26641277878530395, 0.49714382394737167, 0.7160843488871359, 0.9277031785633282, 1.134039172248138, 1.3362606444697027, 1.5351233883472912, 1.7311553439062948, 1.92474549103498, 2.11619192280521, 2.3057300999226618, 2.4935505331649384, 2.6798104078005593, 2.864641534815587, 3.0481559704996037, 3.2304500986796416, 3.4116076663334582, 3.5917020868946974, 3.770798218889025, 3.948953760801948, 4.1262203600675145, 4.302644505614607, 4.478268254146013, 4.653129827014167, 4.827264105186323, 5.000703043083256, 5.173476017199457, 5.345610121819157, 5.51713042146018, 5.688060167652052, 5.858420986108567, 6.028233039162882, 6.197515167405586, 6.366285013738026, 6.534559132477137, 6.702353085688709, 6.869681528557345, 7.036558285303386, 7.202996416914704, 7.369008281763137, 7.5346055900121724, 7.699799452587752, 7.864600425371988, 8.02901854918601, 8.193063386049749, 8.35674405214034, 8.520069247814948, 8.68304728501635, 8.845686112339237, 9.007993338000492, 9.169976250927187, 9.331641840150375, 9.492996812670738, 9.654047609943076, 9.814800423110002, 9.975261207100733, 10.135435693698303, 10.29532940366744, 10.454947658025642, 10.614295588531498, 10.773378147456723, 10.93220011670178, 11.090766116309059, 11.249080612422329, 11.407147924736606, 11.564972233478345, 11.722557585952282, 11.879907902687874, 12.037026983215323, 12.193918511498618, 12.35058606105049, 12.507033099752178, 12.663262994398874, 12.819279014990018, 12.975084338782002, 13.130682054119454, 13.286075164059918, 13.441266589805664, 13.596259173955167, 13.751055683585937, 13.905658813179441, 14.06007118739802, 14.214295363723048, 14.368333834962845, 14.522189031638208, 14.675863324252948, 14.829359025456238, 14.98267839210308, 15.135823627218853, 15.288796881873363, 15.441600256969588, 15.59423580495185, 15.746705531437895, 15.899011396779075, 16.051155317552478, 16.203139167988724, 16.35496478133875, 16.50663395118294, 16.65814843268542, 16.80950994379646, 16.96072016640564], [0.0, 0.27681531719676356, 0.5165556470146131, 0.7440450757678331, 0.9639269212585511, 1.1783196534742955, 1.3884372057637837, 1.5950648824693954, 1.7987512379294615, 1.999900440411153, 2.1988222225354725, 2.395761238970363, 2.5909154393095783, 2.784448146386815, 2.9764963179714523, 3.1671763857807913, 3.3565884971117224, 3.544819668984667, 3.7319461813851933, 3.91803542535001, 4.103147352299768, 4.287335626330098, 4.470648551608892, 4.653129827014167, 4.834819166315835, 5.015752812467623, 5.195963967604817, 5.375483155276916, 5.554338527710393, 5.732556128109646, 5.910160115899572, 6.087172961206607, 6.263615613636373, 6.439507649442249, 6.61486740042256, 6.789712067285597, 6.964057819744385, 7.137919885220041, 7.311312627723016, 7.4842496182295895, 7.656743697665167, 7.828807033436415, 8.000451170314207, 8.17168707635296, 8.342525184434681, 8.512975429944571, 8.683047285016352, 8.852749789727376, 9.022091580574314, 9.191080916518201, 9.359725702851646, 9.528033513110229, 9.696011609223564, 9.86366696007854, 10.031006258647476, 10.19803593781664, 10.36476218503555, 10.531190955894424, 10.697327986725602, 10.86317880631473, 11.028748746798604, 11.194042953818782, 11.359066395993134, 11.523823873761435, 11.688320027655605, 11.85255934604047, 12.016546172366514, 12.180284711972345, 12.343779038471132, 12.507033099752178, 12.670050723626085, 12.832835623139447, 12.9953914015828, 13.157721557213565, 13.319829487713843, 13.481718494401392, 13.643391786210486, 13.804852483458145, 13.966103621409927, 14.127148153658384, 14.287988955326254, 14.448628826105601, 14.609070493143156, 14.769316613781484, 14.929369778164833, 15.089232511717801, 15.248907277504541, 15.408396478475527, 15.567702459608492, 15.726827509949674, 15.885773864561044, 16.0445437063789, 16.203139167988724, 16.36156233332101, 16.519815239272354, 16.67789987725584, 16.83581819468459, 16.993572096391954, 17.151163445991678, 17.308594067181254, 17.465865744991238, 17.62298022698343], [0.0, 0.2871745887492587, 0.5358867312681466, 0.7718895067235705, 1.0, 1.2224159606786607, 1.4403967511883273, 1.654757064349649, 1.8660659830736153, 2.0747428008338877, 2.2811088413887024, 2.4854179151281897, 2.6878753795222874, 2.88865066944214, 3.087885868033637, 3.2857017642432558, 3.4822022531844974, 3.6774776083194913, 3.8716069642629938, 4.064660234029389, 4.256699612603924, 4.447780772355998, 4.63795382514246, 4.827264105186323, 5.015752812467623, 5.203457546261708, 5.390412751228803, 5.5766500932025185, 5.762198777951311, 5.947085823295541, 6.131336292779303, 6.314973497429546, 6.498019170849886, 6.680493621896675, 6.862415868399919, 7.043803754770757, 7.224674055842079, 7.405042568891443, 7.58492419547428, 7.764333014434102, 7.943282347242818, 8.121784816648479, 8.299852399462418, 8.477496474197023, 8.654727864164498, 8.83155687656239, 9.00799333800049, 9.184046626863356, 9.359725702851643, 9.535039134001845, 9.709995121446676, 9.884601522146465, 10.058865869794328, 10.232795394074111, 10.406397038429525, 10.579677476485017, 10.752643127243298, 10.92530016917089, 11.09765455327115, 11.269712015233708, 11.441478086740142, 11.61295810599758, 11.78415722756469, 11.95508043152831, 12.12573253208319, 12.296118185562426, 12.466241897961632, 12.63610803199599, 12.805720813725669, 12.975084338782002, 13.144202578223911, 13.313079384051496, 13.48171849440139, 13.650123538446447, 13.81829804102038, 13.986245426986297, 14.153969025366562, 14.32147207324995, 14.488757719490897, 14.655829028214372, 14.82268898213896, 14.989340485729716, 15.155786368191505, 15.322029386312737, 15.488072227168738, 15.653917510693182, 15.819567792125575, 15.985025564342113, 16.150293260076733, 16.315373254038743, 16.48026786493294, 16.644979357387736, 16.80950994379646, 16.973861786076622, 17.138036997351684, 17.302037643559473, 17.465865744991238, 17.629523277764974, 17.793012175236544, 17.95633432935174, 18.119491591942396, 18.28248577596939], [0.0, 0.29749249441556525, 0.5551406240486036, 0.7996227513322692, 1.0359290343593575, 1.2663361857313113, 1.4921488155528797, 1.7142108877710571, 1.9331119318962955, 2.149286306211878, 2.3630668793283913, 2.574716580798193, 2.784448146386815, 2.992437098596708, 3.198830625483992, 3.4037538558253533, 3.6073144175853953, 3.80960582766457, 4.010710063907927, 4.210699551236944, 4.4096387192426345, 4.607585240548866, 4.804591027483117, 5.000703043083256, 5.195963967604817, 5.390412751228803, 5.584085076178822, 5.777013746011306, 5.9692290158297725, 6.160758874178774, 6.351629285111346, 6.5418643971971235, 6.731486724907115, 6.9205173067752686, 7.10897584392386, 7.296880821896486, 7.484249618229588, 7.671098597781649, 7.857443197506599, 8.043298002087198, 8.228676811622982, 8.41359270238515, 8.5980580815003, 8.782084736299781, 8.965683878966953, 9.14886618702702, 9.331641840150374, 9.51402055367787, 9.696011609223563, 9.877623882665217, 10.058865869794328, 10.239745709864222, 10.420271207246337, 10.600449851380075, 10.780288835180375, 10.959795072048568, 11.13897521161593, 11.317835654335326, 11.49638256502391, 11.674621885449104, 11.852559346040465, 12.030200476801745, 12.207550617489932, 12.384614927121573, 12.561398392860786, 12.737905838338218, 12.914141931445558, 13.090111191646129, 13.265817996838358, 13.441266589805661, 13.616461084283275, 13.791405470669938, 13.966103621409923, 14.140559296068764, 14.314776146124043, 14.488757719490895, 14.66250746480024, 14.836028735446327, 15.009324793418891, 15.182398812933956, 15.3552538838763, 15.527893015065608, 15.70031913735734, 15.872535106588654, 16.044543706378896, 16.216347650793427, 16.387949586879042, 16.55935209707857, 16.73055770153173, 16.901568860268842, 17.07238797530353, 17.24301739263012, 17.413459404131086, 17.583716249399558, 17.753790117481472, 17.923683148541816, 18.093397435458954, 18.262935025350885, 18.432297921037087, 18.60148808243913, 18.770507427923384, 18.93935783558866], [0.0, 0.30777078180727846, 0.5743205865145341, 0.8272495069561095, 1.071720109873659, 1.3100877676898488, 1.5437021644452158, 1.7734364228190194, 1.9999004404111527, 2.2235435824692775, 2.4447102181268754, 2.6636723610831443, 2.880650097068329, 3.0958250128411495, 3.309349381766329, 3.521352655786858, 3.731946181385193, 3.9412267064460864, 4.14927904112756, 4.356178112613069, 4.561990576519039, 4.7667760980433185, 4.970588383070635, 5.173476017199457, 5.375483155276916, 5.5766500932025185, 5.777013746011306, 5.9766080506139545, 6.175464307419844, 6.373611471970377, 6.571076405369788, 6.767884090514438, 6.964057819744383, 7.159619358469383, 7.354589088480302, 7.5489861339914075, 7.742828472928447, 7.93613303555146, 8.128915792157072, 8.321191831324995, 8.51297542994457, 8.704280116068725, 8.895118725487016, 9.085503452779992, 9.275445897508995, 9.464957106104915, 9.654047609943076, 9.842727460026804, 10.031006258647475, 10.218893188342097, 10.406397038429526, 10.593526229372147, 10.780288835180377, 10.96669260405178, 11.15274497741461, 11.338453107526398, 11.523823873761431, 11.708863897706532, 11.893579557171671, 12.077976999210765, 12.26206215223821, 12.445840737317926, 12.629318278694104, 12.812500113625951, 12.995391401582799, 13.17799713285046, 13.360322136595054, 13.542371088426169, 13.724148517497477, 13.905658813179441, 14.086906231335764, 14.267894900232417, 14.4486288261056, 14.629111898412846, 14.80934789478933, 14.989340485729718, 15.16909323901422, 15.348609623895978, 15.52789301506561, 15.706946696407469, 15.885773864561042, 16.064377632299937, 16.242761031739903, 16.42092701738652, 16.59887846903245, 16.776618194513294, 16.95414893233062, 17.13147335414998, 17.30859406718125, 17.48551361644816, 17.662234486953263, 17.838759105744373, 18.015089843887907, 18.191229018354342, 18.367178893820583, 18.542941684393742, 18.71851955526059, 18.89391462426651, 19.069128963427865, 19.244164600381005, 19.419023519771347, 19.593707664585526], [0.0, 0.3180110627669995, 0.593429626470586, 0.8547741060271346, 1.107378839304842, 1.3536775676840487, 1.5950648824693952, 1.832442957251002, 2.066441982402309, 2.2975262746435074, 2.526051661105034, 2.7522992060421148, 2.9764963179714523, 3.198830625483992, 3.4194594684489132, 3.6385166059895684, 3.856117089356154, 4.072360885470385, 4.287335626330097, 4.5011187321280115, 4.713779076274704, 4.925378309173978, 5.135971923635709, 5.345610121819157, 5.554338527710393, 5.762198777951311, 5.9692290158297725, 6.175464307419844, 6.380936994571502, 6.585676996247296, 6.789712067285597, 6.993068021824368, 7.195768927196358, 7.39783727299934, 7.5992941191758305, 7.800159226249128, 8.000451170314205, 8.200187444941951, 8.399384551799521, 8.5980580815003, 8.796222785960392, 8.993892643343882, 9.1910809165182, 9.38780020580719, 9.584062496717756, 9.779879203222356, 9.975261207100733, 10.170218893777491, 10.364762185035548, 10.55890056893721, 10.752643127243298, 10.945998560585426, 11.138975211615932, 11.331581086333722, 11.523823873761431, 11.715710964129556, 11.907249465705869, 12.098446220393454, 12.2893078182075, 12.479840610729335, 12.670050723626083, 12.859944068315356, 13.04952635284635, 13.238803092061849, 13.427779617099246, 13.616461084283277, 13.804852483458143, 13.992958645802311, 14.180784251165388, 14.368333834962845, 14.555611794661306, 14.742622395884167, 14.929369778164833, 15.115857960372528, 15.30209084583352, 15.48807222716874, 15.67380579086711, 15.85929512161224, 16.0445437063789, 16.22955493831424, 16.41433212041771, 16.59887846903245, 16.783197117160054, 16.96729111760968, 17.151163445991674, 17.334817003565156, 17.51825461994828, 17.701479055699394, 17.884493004776584, 18.067299096882685, 18.249899899702324, 18.432297921037087, 18.614495610844525, 18.79649536318634, 18.978299518090747, 19.15991036333357, 19.341330136142595, 19.52256102482907, 19.703605170350368, 19.88446466780722, 20.065141567879014, 20.245637878200267], [0.0, 0.32821482838625377, 0.6124705263919324, 0.8822005564135441, 1.1429104149351756, 1.3971119328426296, 1.6462444485719303, 1.8912390830327706, 2.1327462470110823, 2.3712451553848273, 2.60710305242386, 2.8406100206664786, 3.0720007653038603, 3.30146893521489, 3.5291769187067894, 3.7552627667244987, 3.979845222075298, 4.203027459239247, 4.424899921991734, 4.645542514645037, 4.865026320495552, 5.08341496807409, 5.300765730743755, 5.51713042146018, 5.732556128109646, 5.947085823295541, 6.160758874178774, 6.373611471970377, 6.585676996247296, 6.796986325957808, 7.007568106487495, 7.21744898025184, 7.4266537868127696, 7.635205737373723, 7.843126567610685, 8.050436672086994, 8.25715522293387, 8.463300275024359, 8.668888859501363, 8.873937067221764, 9.078460123434546, 9.282472454809923, 9.485987749770306, 9.68901901293601, 9.891578614383274, 10.093678334315525, 10.29532940366744, 10.4965425410924, 10.697327986725602, 10.897695533065189, 11.097654553271152, 11.297214027145285, 11.496382565023913, 11.695168429787998, 11.893579557171671, 12.091623574529823, 12.289307818207503, 12.486639349638448, 12.683624970286374, 12.880271235530692, 13.076584467587898, 13.272570767550507, 13.46823602661731, 13.66358593658142, 13.858625999636157, 14.053361537553112, 14.247797700281602, 14.441939474014244, 14.635791688759221, 14.829359025456238, 15.022646022669898, 15.21565708289123, 15.408396478475526, 15.600868357242238, 15.793076747760528, 15.985025564342115, 16.176718611761324, 16.368159589720634, 16.559352097078573, 16.75029963585548, 16.941005615031496, 17.13147335414998, 17.321706086738633, 17.511706963559647, 17.701479055699394, 17.89102535750736, 18.080348789393383, 18.269452200491635, 18.45833837119907, 18.647010015595686, 18.83546978375335, 19.023720263939452, 19.211763984721376, 19.399603416977158, 19.587240975817608, 19.774679022424586, 19.961919865810007, 20.148965764499707, 20.335818928146235, 20.522481519074137, 20.70895565376131, 20.895243404259624], [0.0, 0.3383834619016498, 0.6314458674893553, 0.9095325760829623, 1.1783196534742952, 1.4403967511883273, 1.6972478007257306, 1.9498327706486205, 2.1988222225354725, 2.4447102181268754, 2.687875379522287, 2.9286167764926536, 3.1671763857807917, 3.4037538558253537, 3.638516605989569, 3.8716069642629938, 4.103147352299767, 4.333244141094503, 4.561990576519039, 4.789469038452257, 5.015752812467623, 5.240907498412152, 5.464992144071646, 5.688060167652052, 5.910160115899572, 6.131336292779303, 6.351629285111346, 6.571076405369788, 6.789712067285597, 7.007568106487495, 7.224674055842078, 7.44105738319054, 7.656743697665164, 7.871756929590529, 8.086119488049496, 8.299852399462416, 8.51297542994457, 8.72550719373857, 8.937465249640052, 9.148866187027021, 9.359725702851645, 9.570058670746029, 9.779879203222354, 9.989200707805397, 10.19803593781664, 10.406397038429525, 10.614295588531498, 10.8217426388574, 11.028748746798604, 11.2353240082409, 11.441478086740144, 11.647220240307114, 11.852559346040467, 12.057503922818771, 12.26206215223821, 12.46624189796163, 12.670050723626083, 12.873495909440102, 13.076584467587898, 13.279323156545285, 13.481718494401388, 13.683776771270576, 13.885504060870637, 14.086906231335766, 14.287988955326252, 14.488757719490897, 14.689217833332892, 14.889374437525275, 15.0892325117178, 15.288796881873363, 15.488072227168738, 15.687063086491344, 15.885773864561044, 16.08420883770354, 16.282372159299666, 16.48026786493294, 16.677899877255836, 16.87527201059368, 17.072387975303535, 17.269251381904077, 17.465865744991234, 17.662234486953263, 17.85836094149786, 18.054248357002994, 18.249899899702324, 18.445318656715195, 18.64050763893053, 18.83546978375335, 19.03020795772186, 19.224724959002714, 19.419023519771343, 19.613106308483918, 19.806975932046967, 20.00063493789039, 20.194085815949087, 20.38733100055821, 20.580372872266636, 20.773213759573046, 20.965855940588643, 21.158301644630335, 21.35055305374797, 21.542612304188985], [0.0, 0.34851824982980034, 0.6503580504877421, 0.9367736230317179, 1.213611034833248, 1.4835374990359085, 1.7480813917801146, 2.0082314332630053, 2.2646782687850924, 2.517930757532846, 2.7683788615650147, 3.016330607971816, 3.2620352208448526, 3.505698328213431, 3.747492363751265, 3.987563918256687, 4.226039079985906, 4.463027405808716, 4.698624934366822, 4.932916512865958, 5.165977621826534, 5.397875825850385, 5.628671941239962, 5.858420986108567, 6.087172961206607, 6.314973497429546, 6.5418643971971235, 6.767884090514438, 6.993068021824368, 7.21744898025184, 7.44105738319054, 7.663921521160007, 7.886067770301414, 8.107520777666936, 8.328303623504928, 8.548437963989656, 8.767944157243425, 8.986841375016597, 9.205147702001284, 9.422880224437323, 9.640055109410028, 9.856687676025723, 10.072792459474803, 10.288383268845463, 10.503473239428823, 10.718074880153571, 10.93220011670178, 11.145860330784439, 11.359066395993134, 11.571828710591499, 11.784157227564691, 11.99606148220647, 12.207550617489934, 12.418633407439177, 12.629318278694104, 12.839613330438988, 13.04952635284635, 13.259064844171345, 13.468236026617308, 13.67704686108047, 13.885504060870636, 14.093614104494879, 14.301383247582482, 14.508817534021786, 14.715922806372662, 14.922704715612335, 15.129168730266812, 15.335320144975372, 15.541164088531273, 15.746705531437895, 15.951949293016169, 16.156900048095917, 16.36156233332101, 16.565940553095672, 16.770038985196987, 16.973861786076625, 17.177412995872853, 17.380696543152336, 17.583716249399558, 17.7864758332704, 17.988978914625047, 18.191229018354342, 18.393229578012527, 18.594983939268438, 18.79649536318634, 18.997767029346655, 19.19880203881624, 19.399603416977158, 19.600174116222153, 19.800517018524655, 20.00063493789039, 20.200530622697386, 20.400206757930597, 20.599665967316977, 20.79891081536647, 20.997943809324024, 21.196767401037395, 21.395383988745188, 21.593795918789407, 21.792005487256343, 21.99001494154955, 22.18782648189835], [0.0, 0.35862039163060777, 0.6692093136584149, 0.9639269212585511, 1.248788735774009, 1.5265392821258754, 1.798751237929461, 2.0664419824023086, 2.330322179873383, 2.5909154393095775, 2.848623026200712, 3.103761896103005, 3.356588497111722, 3.6073144175853953, 3.8561170893561543, 4.103147352299767, 4.348534949463674, 4.5923926133305235, 4.8348191663158335, 5.075901915004447, 5.3157185277933685, 5.554338527710391, 5.791824493877882, 6.028233039162882, 6.263615613636373, 6.498019170849886, 6.731486724907115, 6.964057819744383, 7.195768927196358, 7.4266537868127696, 7.656743697665164, 7.886067770301414, 8.114653145400903, 8.34252518443468, 8.569707636654632, 8.79622278596039, 9.022091580574312, 9.247333747958665, 9.47196789700802, 9.696011609223563, 9.919481520309361, 10.142393393410996, 10.364762185035548, 10.58660210454112, 10.807926667958073, 11.028748746798604, 11.249080612422329, 11.468933976450241, 11.688320027655601, 11.907249465705867, 12.12573253208319, 12.343779038471128, 12.561398392860786, 12.778599623599911, 12.995391401582797, 13.211782060756482, 13.427779617099244, 13.643391786210483, 13.858625999636155, 14.073489420040861, 14.28798895532625, 14.502131271785249, 14.71592280637266, 14.929369778164832, 15.14247819907394, 15.355253883876303, 15.56770245960849, 15.779829374380075, 15.991639905647393, 16.20313916798872, 16.414332120417708, 16.62522357326869, 16.835818194684588, 17.04612051673558, 17.256134941194304, 17.465865744991234, 17.675317085371994, 17.884493004776584, 18.09339743545895, 18.302034203863847, 18.510407034776645, 18.718519555260585, 18.926375298394827, 19.1339777068257, 19.341330136142588, 19.54843585808916, 19.75529806361973, 19.961919865810003, 20.16830430263072, 20.37445433959212, 20.580372872266633, 20.78606272869671, 20.991526671694217, 21.19676740103739, 21.401787555571005, 21.606589715214948, 21.811176402886176, 22.01555008633859, 22.219713179925197, 22.423668046286597, 22.62741699796953, 22.830962298979117], [0.0, 0.36869100813333205, 0.6880017485427284, 0.9909954834128345, 1.2838566592507525, 1.5694068714917047, 1.8492629609762832, 2.1244708765075226, 2.395761238970363, 2.6636723610831443, 2.928616776492654, 3.190920341358448, 3.4508467052358323, 3.708613398212436, 3.964402834681275, 4.21837009033565, 4.470648551608892, 4.721354116686509, 4.970588383070635, 5.218441109050352, 5.464992144071646, 5.710312963476703, 5.9544679037066475, 6.197515167405586, 6.439507649442249, 6.680493621896675, 6.9205173067752686, 7.159619358469383, 7.39783727299934, 7.635205737373723, 7.871756929590529, 8.107520777666936, 8.34252518443468, 8.576796223554224, 8.810358311193271, 9.043234357017889, 9.275445897508996, 9.507013214106578, 9.737955438271811, 9.96829064522169, 10.19803593781664, 10.427207521855802, 10.655820773848163, 10.883890302172624, 11.111430002410632, 11.3384531075264, 11.564972233478345, 11.79099942076793, 12.016546172366512, 12.241623488404798, 12.466241897961634, 12.690411488247863, 12.91414193144556, 13.137442509432475, 13.360322136595054, 13.582789380910485, 13.804852483458143, 14.02651937650342, 14.247797700281602, 14.468694818596013, 14.689217833332892, 14.909373597984999, 15.12916873026681, 15.34860962389598, 15.567702459608492, 15.7864532154686, 16.004867676528782, 16.222951443889972, 16.440709943207665, 16.65814843268542, 16.87527201059368, 17.09208562234842, 17.308594067181254, 17.524802004429915, 17.74071395947564, 17.956334329351744, 18.171667388045744, 18.38671729151563, 18.601488082439133, 18.815983694713506, 19.03020795772186, 19.244164600381005, 19.45785725498444, 19.671289460853327, 19.88446466780722, 20.097386239465404, 20.310057456389142, 20.52248151907414, 20.734661550802056, 20.946600600359258, 21.158301644630335, 21.369767591073558, 21.581001280084827, 21.792005487256343, 22.00278292553573, 22.213336247291025, 22.423668046286604, 22.633780859574717, 22.843677169307156, 23.053359404471127, 23.262829942553264, 23.472091111135462], [0.0, 0.3787311489165394, 0.7067373137235418, 1.017982130630955, 1.3188184601083266, 1.6121447348740723, 1.8996218253472263, 2.182324163458979, 2.461002266257676, 2.7362091057165845, 3.008368449539738, 3.277815027555007, 3.544819668984667, 3.8096058276645706, 4.072360885470385, 4.333244141094503, 4.592392613330524, 4.8499253564867635, 5.105946734753995, 5.360548950706189, 5.613814028238018, 5.8658153890979605, 6.1166191217279025, 6.366285013738026, 6.61486740042256, 6.862415868399919, 7.10897584392386, 7.354589088480302, 7.5992941191758305, 7.843126567610685, 8.086119488049496, 8.328303623504928, 8.569707636654632, 8.810358311193271, 9.050280728186126, 9.289498421172018, 9.52803351311023, 9.76590683774202, 10.00313804751378, 10.239745709864225, 10.475747393396428, 10.711159745223537, 10.945998560585426, 11.18027884567429, 11.41401487447405, 11.647220240307115, 11.879907902687872, 12.112090230003002, 12.34377903847113, 12.574985627776947, 12.80572081372567, 13.035994958221622, 13.26581799683836, 13.495199464216398, 13.724148517497477, 13.952673957980718, 14.180784251165388, 14.408487545327196, 14.63579168875922, 14.862704245794827, 15.0892325117178, 15.315383526654239, 15.541164088531273, 15.766580765179356, 15.991639905647395, 16.21634765079343, 16.440709943207665, 16.664732536519413, 16.888421004134834, 17.111780747448147, 17.334817003565156, 17.557534852574705, 17.77993922440039, 18.002034905262366, 18.223826543776404, 18.445318656715195, 18.666515634454885, 18.887421746127906, 19.108041144501616, 19.328377870600594, 19.548435858089164, 19.768218937429463, 19.98773083982909, 20.206975200991494, 20.425955564681217, 20.644675386115154, 20.86313803519033, 21.081346799557902, 21.29930488755228, 21.517015430983953, 21.734481487803603, 21.951706044644983, 22.168692019253253, 22.385442262805146, 22.60195956212688, 22.818246641815403, 23.034306166268117, 23.250140741625906, 23.46575291763417, 23.681145189425944, 23.896319999231245, 24.11127973801634], [0.0, 0.38874179879876347, 0.72541784693722, 1.044889509982403, 1.3536775676840485, 1.6547570643496488, 1.9498327706486205, 2.2400075179768293, 2.526051661105034, 2.8085327882028075, 3.0878858680336365, 3.3644544780290864, 3.638516605989569, 3.910301612099335, 4.18000183112572, 4.447780772355998, 4.713779076274704, 4.978118944042481, 5.240907498412152, 5.502239379062978, 5.762198777951311, 6.020861057514745, 6.278294053049773, 6.534559132477137, 6.789712067285597, 7.043803754770757, 7.296880821896486, 7.5489861339914075, 7.800159226249128, 8.050436672086994, 8.299852399462416, 8.548437963989656, 8.79622278596039, 9.043234357017889, 9.289498421172018, 9.535039134001845, 9.779879203222354, 10.024040013253806, 10.267541735997511, 10.510403429668111, 10.752643127243296, 10.994277915853948, 11.2353240082409, 11.475796807241124, 11.715710964129558, 11.955080431528309, 12.193918511498616, 12.432237899349277, 12.670050723626083, 12.907368582687834, 13.144202578223913, 13.38056334602527, 13.616461084283277, 13.851905579658776, 14.086906231335764, 14.321472073249948, 14.555611794661306, 14.789333759221373, 15.022646022669896, 15.255556349281262, 15.488072227168736, 15.720200882543558, 15.951949293016169, 16.183324200018408, 16.41433212041771, 16.64497935738774, 16.87527201059368, 17.1052159857452, 17.334817003565156, 17.56408060821781, 17.793012175236544, 18.02161691898748, 18.249899899702324, 18.477866030110963, 18.705520081701717, 18.932866690634956, 19.15991036333357, 19.38665548177202, 19.613106308483918, 19.839266991306502, 20.06514156787901, 20.290733969910637, 20.516048027232532, 20.74108747164734, 20.96585594058864, 21.19035698060188, 21.41459405065746, 21.638570525305965, 21.86228969768475, 22.08575478238454, 22.308968918184007, 22.53193517065983, 22.754656534679217, 22.977135936781423, 23.19937623745426, 23.42138023331143, 23.643150659175877, 23.864690190074207, 24.086001443146866, 24.30708697947844, 24.52794930585215, 24.74859087643246], [0.0, 0.39872388356938443, 0.7440450757678329, 1.0717201098736593, 1.3884372057637833, 1.6972478007257306, 1.9999004404111527, 2.297526274643508, 2.590915439309578, 2.880650097068329, 3.1671763857807913, 3.450846705235832, 3.7319461813851937, 4.010710063907927, 4.287335626330098, 4.561990576519039, 4.8348191663158335, 5.105946734753996, 5.375483155276915, 5.64352549771493, 5.910160115899571, 6.175464307419844, 6.439507649442247, 6.702353085688709, 6.964057819744385, 7.224674055842079, 7.484249618229588, 7.742828472928447, 8.000451170314205, 8.25715522293387, 8.51297542994457, 8.767944157243425, 9.022091580574312, 9.275445897508996, 9.52803351311023, 9.779879203222354, 10.031006258647476, 10.281436612913504, 10.531190955894424, 10.780288835180377, 11.028748746798604, 11.276588216642136, 11.523823873761433, 11.770471516506442, 12.016546172366512, 12.262062152238212, 12.507033099752178, 12.751472036206458, 12.995391401582799, 13.238803092061847, 13.481718494401392, 13.724148517497477, 13.966103621409925, 14.20759384410077, 14.4486288261056, 14.689217833332892, 14.929369778164833, 15.16909323901422, 15.408396478475524, 15.647287460193626, 15.885773864561042, 16.123863103343158, 16.36156233332101, 16.598878469032453, 16.835818194684588, 17.072387975303535, 17.308594067181254, 17.544442527673812, 17.77993922440039, 18.01508984388791, 18.249899899702324, 18.484374740103892, 18.718519555260585, 18.952339384051033, 19.185839120485497, 19.41902351977135, 19.651897204047092, 19.88446466780722, 20.116730283038386, 20.34869830408571, 20.580372872266636, 20.81175802024852, 21.04285767620465, 21.27367566776263, 21.50421572575782, 21.734481487803603, 21.964476501689578, 22.19420422861781, 22.4236680462866, 22.652871251830717, 22.881817064626162, 23.110508628967285, 23.33894901662329, 23.56714122928089, 23.795088200879313, 24.022792799843508, 24.250257831221013, 24.477486038727577, 24.704480106706406, 24.931242662005427, 25.157776275776868, 25.384083465203055], [0.0, 0.4086782750672989, 0.7626206271242884, 1.0984762736990297, 1.4231004102669018, 1.739620655158611, 2.049829207563221, 2.3548854571680393, 2.655599266097171, 2.9525673310650067, 3.2462469280437194, 3.5369992547036344, 3.8251165553444717, 4.1108399528008706, 4.394371645656037, 4.67588352870926, 4.955523455139188, 5.233419893146813, 5.509685459234861, 5.7844196466427835, 6.057710965079606, 6.329638641917057, 6.600273991359181, 6.869681528557345, 7.137919885220041, 7.405042568891443, 7.671098597781649, 7.93613303555146, 8.200187444941951, 8.463300275024359, 8.72550719373857, 8.986841375016597, 9.247333747958665, 9.507013214106578, 9.76590683774202, 10.024040013253806, 10.281436612913504, 10.538119117833284, 10.7941087344228, 11.04942549829002, 11.304088367227093, 11.558115304671944, 11.811523354829697, 12.064328710465999, 12.316546774240884, 12.568192214331415, 12.819279014990016, 13.069820522599597, 13.31982948771384, 13.56931810350899, 13.81829804102038, 14.066780481491476, 14.314776146124043, 14.56229532348413, 14.809347894789328, 15.055943357277327, 15.302090845833519, 15.547799153036145, 15.793076747760527, 16.03793179246892, 16.282372159299666, 16.5264054450575, 16.770038985196987, 17.013279866881746, 17.256134941194304, 17.4986108345642, 17.740713959475638, 17.982450524510387, 18.223826543776404, 18.46484784576832, 18.705520081701717, 18.94584873335952, 19.185839120485497, 19.42549640775703, 19.664825611366428, 19.90383160523778, 20.142519126904176, 20.38089278306798, 20.618957054865234, 20.856716302853442, 21.094174771740636, 21.33133659487224, 21.568205798490848, 21.804786305783182, 22.04108194072724, 22.277096431751705, 22.51283341521897, 22.748296438742177, 22.983488964345977, 23.21841437148017, 23.453075959894505, 23.6874769523826, 23.92162049740231, 24.155509671579328, 24.389147482100523, 24.62253686900286, 24.855680707363653, 25.088581809397233, 25.321242926463107, 25.553666750990114, 25.7858559183209, 26.017813008480836], [0.0, 0.41860579569722817, 0.7811460356680608, 1.125160211979916, 1.457670044972977, 1.7818791283781483, 2.099623197083619, 2.412089804409904, 2.720108485469459, 3.0242904317988932, 3.325104027415325, 3.622919244121551, 3.91803542535001, 4.210699551236945, 4.5011187321280115, 4.789469038452257, 5.075901915004447, 5.360548950706189, 5.643525497714929, 5.92493346613749, 6.204863515740816, 6.4833967984701095, 6.760606360878, 7.036558285303386, 7.311312627723016, 7.58492419547428, 7.857443197506599, 8.128915792157072, 8.399384551799521, 8.668888859501363, 8.937465249640052, 9.205147702001284, 9.47196789700802, 9.737955438271811, 10.00313804751378, 10.267541735997511, 10.531190955894424, 10.7941087344228, 11.056316793133616, 11.317835654335328, 11.578684736338491, 11.83888243894483, 12.098446220393454, 12.35739266680103, 12.615737554985541, 12.873495909440104, 13.130682054119452, 13.387309659613825, 13.643391786210483, 13.898940923279566, 14.153969025366562, 14.408487545327192, 14.66250746480024, 14.91603932227928, 15.169093239014218, 15.421678942947505, 15.673805790867108, 15.925482788938604, 16.17671861176132, 16.427521620078217, 16.677899877255836, 16.927861164638788, 17.177412995872853, 17.426562630281428, 17.675317085371994, 17.92368314854182, 18.171667388045744, 18.41927616328299, 18.666515634454882, 18.91339177164053, 19.15991036333357, 19.406077024479156, 19.65189720404709, 19.897376192173923, 20.142519126904176, 20.38733100055821, 20.6318166657522, 20.87598084109349, 21.11982811657286, 21.363362958673505, 21.606589715214948, 21.8495126199489, 22.09213579692254, 22.33446326462376, 22.57649893992177, 22.818246641815403, 23.059710095000746, 23.300892933268756, 23.541798702742817, 23.78243086496556, 24.022792799843504, 24.262887808457656, 24.50271911574749, 24.742289873075407, 24.981603160678173, 25.220661990011475, 25.459469305993352, 25.698027989151814, 25.93634085768178, 26.17441066941596, 26.41224012371415, 26.649831863275114], [0.0, 0.4285072224590918, 0.7996227513322692, 1.1517740131952723, 1.4921488155528797, 1.8240265278395993, 2.1492863062118785, 2.4691437935970892, 2.784448146386815, 3.09582501284115, 3.403753855825354, 3.708613398212436, 4.010710063907928, 4.310296674954123, 4.607585240548867, 4.902755995775582, 5.195963967604817, 5.487343857476166, 5.777013746011307, 6.0650779538318424, 6.351629285111347, 6.6367508113098745, 6.920517306775269, 7.202996416914704, 7.4842496182295895, 7.764333014434102, 8.043298002087198, 8.321191831324995, 8.5980580815003, 8.873937067221764, 9.148866187027021, 9.422880224437323, 9.696011609223563, 9.96829064522169, 10.239745709864225, 10.510403429668111, 10.780288835180377, 11.04942549829002, 11.317835654335328, 11.585540311045966, 11.852559346040469, 12.11891159433739, 12.384614927121575, 12.649686322826804, 12.914141931445561, 13.17799713285046, 13.441266589805664, 13.703964296256576, 13.966103621409925, 14.22769735005121, 14.488757719490899, 14.749296453483039, 15.009324793418894, 15.268853527062648, 15.527893015065612, 15.786453215468597, 16.0445437063789, 16.30217370698802, 16.55935209707857, 16.816087435153037, 17.072387975303535, 17.3282616829295, 17.583716249399558, 17.838759105744376, 18.093397435458954, 18.3476381864852, 18.601488082439133, 18.854953633141047, 19.108041144501616, 19.360756727812284, 19.613106308483918, 19.865095634273903, 20.116730283038386, 20.368015670043352, 20.618957054865238, 20.869559547909486, 21.119828116572865, 21.36976759107356, 21.619382669970985, 21.868677925395588, 22.11765780800737, 22.366326651700426, 22.614688678069435, 22.862748000652967, 23.110508628967285, 23.357974472343315, 23.605149343578663, 23.85203696241559, 24.098640958855153, 24.344964876317043, 24.591012174653873, 24.836786233028246, 25.082290352660245, 25.327527759452522, 25.57250160649975, 25.817214976488604, 26.06167088399429, 26.30587227767893, 26.549822042397178, 26.793523001213714, 27.03697791733721, 27.280189495975097], [0.0, 0.438383290554087, 0.8180521460508584, 1.1783196534742955, 1.5265392821258754, 1.8660659830736153, 2.1988222225354725, 2.5260516611050345, 2.8486230262007126, 3.1671763857807913, 3.4822022531844974, 3.794088079942577, 4.103147352299768, 4.4096387192426345, 4.7137790762747045, 5.015752812467623, 5.3157185277933685, 5.613814028238018, 5.910160115899571, 6.204863515740816, 6.4980191708498865, 6.789712067285596, 7.080018702765929, 7.369008281763137, 7.656743697665167, 7.943282347242818, 8.228676811622982, 8.51297542994457, 8.796222785960392, 9.078460123434546, 9.359725702851645, 9.640055109410028, 9.919481520309361, 10.19803593781664, 10.475747393396428, 10.752643127243296, 11.028748746798604, 11.304088367227093, 11.578684736338491, 11.852559346040469, 12.125732532083191, 12.398223563587404, 12.670050723626085, 12.941231381945366, 13.211782060756486, 13.48171849440139, 13.751055683585939, 14.019807944782555, 14.287988955326254, 14.555611794661308, 14.822688982138962, 15.0892325117178, 15.355253883876303, 15.620764135010859, 15.885773864561044, 16.150293260076733, 16.41433212041771, 16.677899877255836, 16.941005615031496, 17.20365808950022, 17.465865744991234, 17.72763673048741, 17.988978914625047, 18.249899899702328, 18.510407034776648, 18.770507427923388, 19.030207957721863, 19.28951528402817, 19.548435858089164, 19.806975932046967, 20.065141567879014, 20.322938645814766, 20.580372872266636, 20.837449787309556, 21.094174771740644, 21.350553053747973, 21.60658971521495, 21.862289697684755, 22.117657808007372, 22.372698723689936, 22.62741699796953, 22.881817064626166, 23.13590324255219, 23.389679740093413, 23.643150659175877, 23.896319999231242, 24.149191660932996, 24.40176944975458, 24.6540570793599, 24.906058174836012, 25.157776275776865, 25.409214839226692, 25.660377242490814, 25.91126678582124, 26.161886694983934, 26.41224012371415, 26.662330156065842, 26.912159808660757, 27.161732032842558, 27.41104971674082, 27.660115687249583, 27.908932711924844], [0.0, 0.4482346966214095, 0.836435519798534, 1.2047990052963282, 1.5608438705305414, 1.908000459463991, 2.2482344402244063, 2.5828174211072623, 2.9126376516860013, 3.238349583608942, 3.5604547530945814, 3.8793493185346324, 4.195353810877315, 4.50873269150271, 4.819707730018183, 5.128467459110472, 5.435174042830663, 5.739968383958794, 6.042973999273252, 6.344300012074007, 6.644043499022565, 6.942291355995457, 7.239121799777288, 7.5346055900121724, 7.828807033436415, 8.121784816648479, 8.41359270238515, 8.704280116068725, 8.993892643343882, 9.282472454809923, 9.570058670746029, 9.856687676025723, 10.142393393410996, 10.427207521855802, 10.711159745223537, 10.994277915853948, 11.276588216642136, 11.558115304671944, 11.83888243894483, 12.11891159433739, 12.398223563587404, 12.676838048833796, 12.954773744009122, 13.232048409194702, 13.508678937891043, 13.784681418024261, 14.060071187398018, 14.334862884206364, 14.609070493143152, 14.882707387575623, 15.155786368191505, 15.42831969847917, 15.70031913735734, 15.971795969233733, 16.242761031739903, 16.513224741361665, 16.783197117160054, 17.052687802756672, 17.32170608673863, 17.59026092162193, 17.85836094149786, 18.12601447847429, 18.393229578012527, 18.660014013250585, 18.92637529839483, 19.192320701254236, 19.45785725498444, 19.722991769102684, 19.987730839829087, 20.25208085980471, 20.516048027232532, 20.779638354483296, 21.04285767620465, 21.305711656968803, 21.568205798490848, 21.830345446447378, 22.09213579692254, 22.353581902506512, 22.614688678069435, 22.875460906231986, 23.135903242552185, 23.39602022044652, 23.655816255862046, 23.91529565171507, 24.174462602110637, 24.433321196356165, 24.691875422781575, 24.950129172377398, 25.208086242261484, 25.465750338984307, 25.723125081682035, 25.98021400508604, 26.237020562396893, 26.493548128030287, 26.749800000242022, 27.005779403638495, 27.26148949157892, 27.516933348474964, 27.77211399199326, 28.027034375165805, 28.281697388412972, 28.536105861483634], [0.0, 0.4580621016515332, 0.8547741060271344, 1.2312138453213912, 1.595064882469395, 1.9498327706486205, 2.297526274643508, 2.639444882362274, 2.976496317971452, 3.3093493817663284, 3.6385166059895684, 3.9644028346812745, 4.287335626330098, 4.607585240548866, 4.925378309173979, 5.240907498412152, 5.554338527710392, 5.865815389097961, 6.175464307419844, 6.4833967984701095, 6.789712067285597, 7.094498914907654, 7.397837272999339, 7.699799452587752, 8.000451170314207, 8.299852399462418, 8.5980580815003, 8.895118725487016, 9.1910809165182, 9.485987749770306, 9.779879203222354, 10.072792459474803, 10.364762185035548, 10.655820773848163, 10.945998560585426, 11.2353240082409, 11.523823873761433, 11.811523354829697, 12.098446220393454, 12.384614927121575, 12.670050723626085, 12.954773744009122, 13.238803092061849, 13.522156917249786, 13.804852483458143, 14.086906231335766, 14.368333834962845, 14.649150253471241, 14.929369778164832, 15.209006075617737, 15.488072227168741, 15.766580765179352, 16.0445437063789, 16.321972582582188, 16.59887846903245, 16.87527201059368, 17.151163445991678, 17.426562630281428, 17.701479055699394, 17.975921871042683, 18.249899899702324, 18.523421656465036, 18.79649536318634, 19.06912896342787, 19.34133013614259, 19.61310630848392, 19.88446466780722, 20.155412172926262, 20.42595556468122, 20.6961013758698, 20.965855940588643, 21.235225403027826, 21.50421572575782, 21.772832697544803, 22.041081940727242, 22.308968918184014, 22.576498939921773, 22.843677169307156, 23.11050862896729, 23.376998206380303, 23.643150659175873, 23.908970620164215, 24.17446260211064, 24.439631002271543, 24.704480106706406, 24.969014094379425, 25.233237041063408, 25.497152923057627, 25.760765620730556, 26.024078921897615, 26.287096525043406, 26.549822042397178, 26.81225900286983, 27.074410854860066, 27.336280968936908, 27.597872640405235, 27.85918909176068, 28.120233475039655, 28.381008874070194, 28.641518306628594, 28.901764726506787, 29.161751025495], [0.0, 0.4678661336153, 0.873069076571686, 1.2575658614568495, 1.6292045046639163, 1.991565589710743, 2.3467008755392933, 2.695937663362886, 3.0402031056236334, 3.380180317137601, 3.716392800019161, 4.049254063299246, 4.379098676292944, 4.706202683055572, 5.030797566088449, 5.35308011528729, 5.673219597039022, 5.9913630852748, 6.30763950646546, 6.622162763208968, 6.9350341838554606, 7.246344470079944, 7.556175264345337, 7.864600425371988, 8.17168707635296, 8.477496474197023, 8.782084736299781, 9.085503452779992, 9.38780020580719, 9.68901901293601, 9.989200707805397, 10.288383268845463, 10.58660210454112, 10.883890302172624, 11.18027884567429, 11.475796807241124, 11.770471516506442, 12.064328710465999, 12.35739266680103, 12.649686322826804, 12.941231381945366, 13.232048409194702, 13.522156917249786, 13.81157544403426, 14.100321622937116, 14.388412246491033, 14.675863324252948, 14.962690135529225, 15.248907277504538, 15.534528709262535, 15.819567792125577, 16.104037326688825, 16.387949586879042, 16.67131635132972, 16.954148932330618, 17.236458202580764, 17.51825461994828, 17.799548250418663, 18.08034878939338, 18.36066558148382, 18.64050763893053, 18.9198836587646, 19.19880203881624, 19.47727089266536, 19.75529806361973, 20.032891137798206, 20.310057456389142, 20.58680412714776, 20.86313803519033, 21.13906585313787, 21.41459405065746, 21.689728903445015, 21.964476501689578, 22.23884275805591, 22.512833415218974, 22.786454052981178, 23.059710095000746, 23.3326068151573, 23.60514934357866, 23.87734267235104, 24.149191660932992, 24.42070104129207, 24.691875422781575, 24.962719296773614, 25.233237041063404, 25.503432924058693, 25.773311108767192, 26.042875656594035, 26.3121305309603, 26.581079600753096, 26.84972664361673, 27.118075349094003, 27.38612932162609, 27.653892083418743, 27.921367077182225, 28.18855766875174, 28.455467149594913, 28.72209873921207, 28.98845558743529, 29.254540776631178, 29.520357323812508, 29.78590818266331], [0.0, 0.47764738984250493, 0.891321546089, 1.2838566592507525, 1.6632648171372642, 2.033201459303866, 2.395761238970363, 2.752299206042115, 3.103761896103006, 3.450846705235832, 3.794088079942577, 4.133908174115369, 4.4706485516088925, 4.804591027483117, 5.13597192363571, 5.464992144071646, 5.791824493877883, 6.1166191217279025, 6.439507649442247, 6.7606063608780005, 7.080018702765929, 7.397837272999339, 7.714145420866649, 8.02901854918601, 8.342525184434681, 8.654727864164498, 8.965683878966953, 9.275445897508995, 9.584062496717756, 9.891578614383274, 10.19803593781664, 10.503473239428823, 10.807926667958073, 11.111430002410632, 11.41401487447405, 11.715710964129558, 12.016546172366512, 12.316546774240884, 12.615737554985541, 12.914141931445561, 13.211782060756486, 13.508678937891043, 13.804852483458143, 14.100321622937116, 14.39510435836235, 14.689217833332894, 14.98267839210308, 15.275501633409988, 15.56770245960849, 15.85929512161224, 16.150293260076733, 16.440709943207665, 16.73055770153173, 17.019848559927716, 17.30859406718125, 17.596805323297087, 17.884493004776584, 18.171667388045744, 18.45833837119907, 18.744515494207324, 19.03020795772186, 19.315424640594774, 19.600174116222153, 19.884464667807222, 20.168304302630723, 20.451700765407676, 20.734661550802056, 21.017193915164526, 21.299304887552285, 21.581001280084827, 21.86228969768475, 22.143176547248295, 22.4236680462866, 22.703770231075197, 22.98348896434598, 23.262829942553264, 23.54179870274282, 23.820400629050518, 24.098640958855153, 24.376524788607988, 24.654057079359898, 24.93124266200543, 25.208086242261487, 25.484592405397244, 25.760765620730552, 26.036610245904914, 26.3121305309603, 26.58733062220998, 26.862214565934718, 27.13678631190496, 27.41104971674082, 27.685008547119054, 27.958666482835646, 28.232027119731935, 28.50509397249182, 28.777870477317006, 29.050359994486858, 29.322565810808907, 29.59449114196593, 29.866139134764804, 30.137512869292266, 30.408615360982363], [0.0, 0.48740643917899545, 0.9095325760829622, 1.310087767689849, 1.6972478007257303, 2.0747428008338877, 2.444710218126876, 2.808532788202808, 3.1671763857807913, 3.5213526557868584, 3.871606964262994, 4.21837009033565, 4.56199057651904, 4.902755995775582, 5.240907498412153, 5.5766500932025185, 5.910160115899571, 6.241590782938376, 6.571076405369788, 6.898735642903712, 7.224674055842079, 7.5489861339914075, 7.871756929590529, 8.193063386049749, 8.512975429944571, 8.83155687656239, 9.14886618702702, 9.464957106104915, 9.779879203222356, 10.093678334315525, 10.406397038429525, 10.718074880153571, 11.028748746798604, 11.3384531075264, 11.647220240307115, 11.955080431528309, 12.262062152238212, 12.568192214331415, 12.873495909440104, 13.17799713285046, 13.48171849440139, 13.784681418024261, 14.086906231335766, 14.388412246491033, 14.689217833332894, 14.989340485729718, 15.288796881873365, 15.587602939206393, 15.885773864561044, 16.183324200018408, 16.480267864932944, 16.776618194513294, 17.072387975303535, 17.36758947786867, 17.662234486953263, 17.95633432935174, 18.249899899702328, 18.542941684393746, 18.83546978375335, 19.12749393266775, 19.419023519771347, 19.710067605324436, 20.00063493789039, 20.29073396991064, 20.580372872266636, 20.869559547909486, 21.15830164463034, 21.446606567037932, 21.734481487803603, 22.02193335822862, 22.30896891818401, 22.595594705468464, 22.881817064626166, 23.167642155262758, 23.45307595989451, 23.738124291362798, 24.022792799843508, 24.307086979478445, 24.591012174653873, 24.87457358594916, 25.157776275776865, 25.440625173733913, 25.723125081682035, 26.005280678574305, 26.287096525043406, 26.568577067766004, 26.84972664361673, 27.13054948362423, 27.41104971674082, 27.691231373436658, 27.97109838912836, 28.25065460745152, 28.52990378338584, 28.808849586241067, 29.087495602511346, 29.365845338605112, 29.643902223457246, 29.921669611029674, 30.199150782706372, 30.476348949588175, 30.753267254692595, 31.029908775063497], [0.0, 0.49714382394737167, 0.9277031785633283, 1.3362606444697027, 1.7311553439062946, 2.11619192280521, 2.493550533164938, 2.8646415348155867, 3.2304500986796416, 3.591702086894698, 3.948953760801948, 4.302644505614606, 4.653129827014167, 5.000703043083256, 5.345610121819157, 5.688060167652052, 6.028233039162882, 6.366285013738026, 6.702353085688708, 7.036558285303385, 7.369008281763136, 7.699799452587751, 8.02901854918601, 8.35674405214034, 8.683047285016352, 9.00799333800049, 9.331641840150374, 9.654047609943076, 9.975261207100733, 10.29532940366744, 10.614295588531498, 10.93220011670178, 11.249080612422329, 11.564972233478345, 11.879907902687872, 12.193918511498616, 12.507033099752178, 12.819279014990016, 13.130682054119452, 13.441266589805664, 13.751055683585939, 14.060071187398018, 14.368333834962845, 14.675863324252948, 14.98267839210308, 15.288796881873365, 15.594235804951849, 15.899011396779075, 16.20313916798872, 16.50663395118294, 16.809509943796463, 17.111780747448144, 17.413459404131086, 17.714558429551115, 18.015089843887907, 18.315065200222097, 18.614495610844525, 18.91339177164053, 19.211763984721372, 19.50962217945681, 19.806975932046964, 20.10383448375763, 20.400206757930597, 20.6961013758698, 20.991526671694217, 21.28649070623976, 21.581001280084827, 21.87506594576711, 22.168692019253253, 22.46188659071733, 22.75465653467922, 23.04700851954947, 23.33894901662329, 23.630484308562664, 23.921620497402312, 24.212363512112304, 24.502719115747492, 24.79269291221141, 25.08229035266024, 25.371516741570304, 25.66037724249081, 25.94887688350197, 26.237020562396893, 26.524813051604575, 26.812259002869826, 27.099362951704823, 27.38612932162609, 27.67256242818958, 27.958666482835646, 28.244445596554996, 28.529903783385837, 28.815044963751742, 29.09987296764924, 29.384391537693386, 29.668604332029155, 29.95251492711585, 30.236126820391473, 30.51944343282325, 30.802468111350507, 31.085204131225314, 31.36765469825625, 31.64982295096023], [0.0, 0.5068600617330474, 0.9458343193786323, 1.3623766807954047, 1.7649892490160508, 2.157551028423464, 2.5422847801650454, 2.9206284283104917, 3.2935863980794986, 3.6618987379452617, 4.02613258088652, 4.386735899513142, 4.744071147551775, 5.098437375728396, 5.450085359267965, 5.799228289362418, 6.146049539770106, 6.490708442181162, 6.833344668339854, 7.174081613964936, 7.513029052536715, 7.850285245188643, 8.185938638809311, 8.520069247814948, 8.852749789727376, 9.184046626863356, 9.51402055367787, 9.842727460026804, 10.170218893777491, 10.4965425410924, 10.8217426388574, 11.145860330784439, 11.468933976450241, 11.79099942076793, 12.112090230003002, 12.432237899349277, 12.751472036206458, 13.069820522599597, 13.387309659613825, 13.703964296256576, 14.019807944782555, 14.334862884206364, 14.649150253471241, 14.962690135529225, 15.275501633409988, 15.587602939206393, 15.899011396779075, 16.20974355887595, 16.51981523927235, 16.829241560460574, 17.138036997351687, 17.4462154173962, 17.753790117481476, 18.06077385792177, 18.367178893820583, 18.673017004053317, 18.978299518090747, 19.283037340859863, 19.587240975817608, 19.890920546394508, 20.194085815949087, 20.49674620635953, 20.79891081536647, 21.100588432769637, 21.401787555571005, 21.70251640214843, 22.00278292553573, 22.30259482587829, 22.60195956212688, 22.90088436302677, 23.199376237454263, 23.49744198414812, 23.795088200879313, 24.092321293098916, 24.389147482100526, 24.685572812730722, 24.981603160678176, 25.277244239369775, 25.57250160649975, 25.867380670215724, 26.161886694983934, 26.45602480715398, 26.749800000242026, 27.04321713994998, 27.336280968936904, 27.62899611135757, 27.921367077182225, 28.213398266310563, 28.50509397249182, 28.7964583870624, 29.087495602511346, 29.378209615883453, 29.668604332029155, 29.958683566709624, 30.248451049565045, 30.537910426953474, 30.82706526466725, 31.115919050533392, 31.4044751969042, 31.69273704304366, 31.98070785741506, 32.26839083987485], [0.0, 0.516555647014613, 0.9639269212585511, 1.3884372057637835, 1.798751237929461, 2.1988222225354725, 2.5909154393095775, 2.976496317971452, 3.356588497111722, 3.731946181385193, 4.103147352299767, 4.470648551608891, 4.834819166315834, 5.195963967604816, 5.554338527710393, 5.91016011589957, 6.2636156136363725, 6.6148674004225585, 6.964057819744383, 7.311312627723015, 7.656743697665165, 8.000451170314205, 8.34252518443468, 8.68304728501635, 9.022091580574314, 9.359725702851643, 9.696011609223563, 10.031006258647475, 10.364762185035548, 10.697327986725602, 11.028748746798604, 11.359066395993134, 11.688320027655601, 12.016546172366512, 12.34377903847113, 12.670050723626083, 12.995391401582799, 13.31982948771384, 13.643391786210483, 13.966103621409925, 14.287988955326254, 14.609070493143152, 14.929369778164832, 15.248907277504538, 15.56770245960849, 15.885773864561044, 16.20313916798872, 16.51981523927235, 16.835818194684588, 17.151163445991678, 17.465865744991238, 17.779939224400387, 18.09339743545895, 18.406253382569695, 18.718519555260585, 19.03020795772186, 19.34133013614259, 19.65189720404709, 19.961919865810003, 20.271408438510154, 20.580372872266633, 20.888822769186117, 21.19676740103739, 21.504215725757824, 21.811176402886176, 22.11765780800737, 22.4236680462866, 22.729214965163195, 23.034306166268113, 23.33894901662329, 23.643150659175877, 23.946918022715817, 24.25025783122101, 24.553176612670622, 24.855680707363653, 25.157776275776868, 25.459469305993352, 25.760765620730552, 26.061670883994285, 26.36219060738313, 26.662330156065835, 26.962094754452515, 27.261489491578917, 27.560519326221616, 27.859189091760673, 28.157503500805028, 28.45546714959491, 28.75308452219446, 29.050359994486854, 29.347297837983405, 29.643902223457243, 29.940177224411517, 30.23612682039147, 30.5317549001489, 30.827065264667244, 31.122061630054734, 31.416747630312756, 31.711126819986, 32.005202676700705, 32.29897860359672, 32.59245793165884, 32.885643921952706], [0.0, 0.5262310526550319, 0.9819818665965754, 1.4144434903715566, 1.8324429572510017, 2.2400075179768293, 2.639444882362274, 3.032247928528857, 3.4194594684489132, 3.8018478334952754, 4.18000183112572, 4.554386554402119, 4.925378309173979, 5.293287575177642, 5.658374711673134, 6.020861057514746, 6.380936994571502, 6.7387679438133095, 7.094498914907654, 7.448258019465361, 7.800159226249128, 8.150304551700168, 8.498785822937645, 8.845686112339237, 9.191080916518201, 9.535039134001845, 9.877623882665217, 10.218893188342097, 10.55890056893721, 10.897695533065189, 11.2353240082409, 11.571828710591499, 11.907249465705867, 12.241623488404798, 12.574985627776947, 12.907368582687834, 13.238803092061847, 13.56931810350899, 13.898940923279566, 14.22769735005121, 14.555611794661308, 14.882707387575623, 15.209006075617737, 15.534528709262535, 15.85929512161224, 16.183324200018408, 16.50663395118294, 16.829241560460574, 17.151163445991678, 17.472415308214373, 17.793012175236548, 18.11296844448982, 18.432297921037087, 18.751013852861593, 19.069128963427865, 19.38665548177202, 19.703605170350368, 20.019989350850377, 20.33581892814623, 20.651104412562002, 20.96585594058864, 21.2800832941862, 21.593795918789404, 21.907002940123316, 22.219713179925197, 22.531935170659832, 22.843677169307156, 23.15494717029387, 23.46575291763417, 23.77610191633885, 24.086001443146866, 24.395458556628668, 24.704480106706406, 25.013072743632314, 25.321242926463107, 25.62899693106507, 25.936340857681785, 26.243280638093776, 26.549822042397178, 26.855970685426218, 27.161732032842554, 27.46711140691273, 27.77211399199326, 28.076744839741664, 28.38100887407019, 28.684910895857854, 28.98845558743529, 29.291647516855924, 29.59449114196593, 29.896990814284653, 30.19915078270637, 30.500975197033465, 30.802468111350507, 31.10363348724802, 31.404475196904198, 31.70499702603227, 32.00520267670071, 32.30509577003303, 32.60467984879353, 32.90395837986499, 33.202934756623584, 33.501612301216724], [0.0, 0.5358867312681467, 1.0000000000000002, 1.4403967511883276, 1.866065983073615, 2.281108841388703, 2.6878753795222874, 3.0878858680336374, 3.482202253184498, 3.8716069642629947, 4.256699612603924, 4.637953825142461, 5.015752812467624, 5.390412751228804, 5.762198777951313, 6.131336292779303, 6.4980191708498865, 6.862415868399919, 7.224674055842079, 7.584924195474281, 7.9432823472428185, 8.299852399462418, 8.654727864164498, 9.007993338000492, 9.359725702851646, 9.709995121446676, 10.058865869794328, 10.406397038429526, 10.752643127243298, 11.097654553271152, 11.441478086740144, 11.784157227564691, 12.12573253208319, 12.466241897961634, 12.80572081372567, 13.144202578223913, 13.481718494401392, 13.81829804102038, 14.153969025366562, 14.488757719490899, 14.822688982138962, 15.155786368191505, 15.488072227168741, 15.819567792125577, 16.150293260076733, 16.480267864932944, 16.809509943796463, 17.138036997351687, 17.465865744991238, 17.793012175236548, 18.1194915919424, 18.445318656715195, 18.770507427923388, 19.09507139663407, 19.419023519771347, 19.742376250758795, 20.065141567879014, 20.387331000558213, 20.70895565376131, 21.030026230663623, 21.35055305374797, 21.670546084461083, 21.99001494154955, 22.308968918184014, 22.627416997969533, 22.945367869930905, 23.262829942553264, 23.579811356951, 23.896319999231245, 24.212363512112304, 24.52794930585215, 24.843084568537137, 25.157776275776868, 25.472031199847365, 25.785855918320905, 26.09925682221804, 26.412240123714156, 26.724811863430496, 27.03697791733721, 27.348744003293678, 27.660115687249583, 27.971098389128365, 28.281697388412976, 28.5919178294525, 28.901764726506787, 29.21124296854495, 29.52035732381251, 29.829112444180936, 30.13751286929227, 30.445563030510773, 30.753267254692595, 31.06062976778378, 31.367654698256253, 31.674346080390745, 31.98070785741506, 32.2867438845055, 32.59245793165885, 32.89785368644168, 33.202934756623584, 33.50770467270026, 33.81216689031209, 34.11632479256371], [0.0, 0.5455231164732058, 1.0179821306309549, 1.4662981537285988, 1.8996218253472261, 2.3221280385579806, 2.7362091057165845, 3.1434126350860976, 3.5448196689846667, 3.9412267064460864, 4.333244141094503, 4.721354116686508, 5.105946734753996, 5.487343857476165, 5.865815389097961, 6.241590782938375, 6.614867400422558, 6.985816726989423, 7.354589088480301, 7.72131729318319, 8.086119488049496, 8.449101429527195, 8.81035831119327, 9.169976250927187, 9.528033513110229, 9.884601522146465, 10.239745709864222, 10.593526229372147, 10.945998560585426, 11.297214027145285, 11.647220240307114, 11.99606148220647, 12.343779038471128, 12.690411488247863, 13.035994958221622, 13.38056334602527, 13.724148517497477, 14.066780481491476, 14.408487545327192, 14.749296453483039, 15.0892325117178, 15.42831969847917, 15.766580765179352, 16.104037326688825, 16.440709943207665, 16.776618194513294, 17.111780747448144, 17.4462154173962, 17.779939224400387, 18.11296844448982, 18.445318656715195, 18.777004786329837, 19.108041144501613, 19.43844146489575, 19.76821893742946, 20.0973862394654, 20.425955564681217, 20.753938649826765, 21.0813467995579, 21.40819090951582, 21.7344814878036, 22.060228674995987, 22.385442262805142, 22.710131711512712, 23.03430616626811, 23.357974472343315, 23.681145189425944, 24.00382660502497, 24.32602674705652, 24.64775339567127, 24.96901409437942, 25.289816160524428, 25.610166695152223, 25.930072592318776, 26.24954054787513, 26.568577067766004, 26.88718847587493, 27.205380921446395, 27.52316038611301, 27.84053269055345, 28.157503500805024, 28.47407833425296, 28.790262565316553, 29.10606143085124, 29.421480035283956, 29.736523355497887, 30.051196245481773, 30.36550344075764, 30.679449562599963, 30.993039122058388, 31.306276523795145, 31.61916606974779, 31.93171196262698, 32.243918309258405, 32.5557891237775, 32.86732833068486, 33.17853976776984, 33.48942718890932, 33.799994266748264, 34.11024459526821, 34.42018169224933, 34.72980900163167], [0.0, 0.5551406240486036, 1.0359290343593577, 1.49214881555288, 1.9331119318962953, 2.3630668793283918, 2.784448146386815, 3.198830625483992, 3.6073144175853957, 4.010710063907927, 4.4096387192426345, 4.804591027483117, 5.1959639676048175, 5.584085076178822, 5.969229015829773, 6.351629285111346, 6.731486724907116, 7.10897584392386, 7.484249618229588, 7.857443197506599, 8.228676811622984, 8.5980580815003, 8.965683878966953, 9.331641840150375, 9.696011609223564, 10.058865869794328, 10.420271207246337, 10.780288835180377, 11.138975211615932, 11.496382565023913, 11.852559346040467, 12.207550617489934, 12.561398392860786, 12.91414193144556, 13.26581799683836, 13.616461084283277, 13.966103621409925, 14.314776146124043, 14.66250746480024, 15.009324793418894, 15.355253883876303, 15.70031913735734, 16.0445437063789, 16.387949586879042, 16.73055770153173, 17.072387975303535, 17.413459404131086, 17.753790117481476, 18.09339743545895, 18.432297921037087, 18.770507427923388, 19.108041144501613, 19.44491363424382, 19.78113887293812, 20.116730283038386, 20.451700765407672, 20.786062728696713, 21.11982811657286, 21.453008432991712, 21.785614765683324, 22.117657808007365, 22.449147879315724, 22.78009494394727, 23.11050862896729, 23.44039824075309, 23.769772780517748, 24.09864095885515, 24.427011209382066, 24.754891701545827, 25.08229035266024, 25.409214839226692, 25.73567260759253, 26.061670883994285, 26.38721668402931, 26.7123168215957, 27.036977917337207, 27.361206406626682, 27.685008547119054, 28.00839042590241, 28.33135796627329, 28.653916934160574, 28.976072944220327, 29.297831465622217, 29.619197827546824, 29.940177224411517, 30.260774720841344, 30.580995256400282, 30.900843650097052, 31.22032460467865, 31.53944271072398, 31.85820245054895, 32.17660820193377, 32.494664241682365, 32.812374749023284, 33.1297438088607, 33.446775414883675, 33.763473472541335, 34.07984180189096, 34.39588414032582, 34.711604145188915, 35.02700539627845, 35.34209139825073], [0.0, 0.56473965299471, 1.0538414557462255, 1.5179498091244406, 1.9665376921208098, 2.403927062124656, 2.8325945028202053, 3.254142138346765, 3.669689091698737, 4.080059919296138, 4.485886516420913, 4.887668010771905, 5.2858082455541044, 5.680640420827978, 6.072443948455332, 6.461456364452205, 6.847881982475324, 7.231898328690567, 7.613661024300602, 7.9933075558833835, 8.370960232221666, 8.746728535128277, 9.120711011458534, 9.492996812670738, 9.86366696007854, 10.232795394074111, 10.600449851380075, 10.96669260405178, 11.331581086333722, 11.695168429787998, 12.057503922818771, 12.418633407439177, 12.778599623599911, 13.137442509432475, 13.495199464216398, 13.851905579658776, 14.20759384410077, 14.56229532348413, 14.91603932227928, 15.268853527062648, 15.620764135010859, 15.971795969233733, 16.321972582582188, 16.67131635132972, 17.019848559927716, 17.36758947786867, 17.714558429551115, 18.06077385792177, 18.406253382569695, 18.751013852861593, 19.09507139663407, 19.43844146489575, 19.78113887293812, 20.123177838206953, 20.464572015246027, 20.805334527989356, 21.14547799964772, 21.485014580408414, 21.823955973143846, 22.162313457303856, 22.500097911148778, 22.83731983246413, 23.173989357883823, 23.510116280936337, 23.845710068917096, 24.18077987868065, 24.51533457143721, 24.849382726630623, 25.182932654967495, 25.51599241066122, 25.848569802948848, 26.180672406933763, 26.512307573802545, 26.843482440460416, 27.174203938625723, 27.504478803420863, 27.834313581493788, 28.163714638701585, 28.492688167385193, 28.82124019326186, 29.1493765819601, 29.477103045219934, 29.804425146779348, 30.131348307966675, 30.457877813016818, 30.7840188141281, 31.10977633627532, 31.435155281793485, 31.760160434745565, 32.08479646508693, 32.40906793263797, 32.7329792908758, 33.05653489055529, 33.37973898316873, 33.70259572425303, 34.02510917655282, 34.34728331304697, 34.66912201984603, 34.99062909896714, 35.31180827099304, 35.63266317762081, 35.953197384106375], [0.0, 0.5743205865145341, 1.071720109873659, 1.5437021644452158, 1.9999004404111522, 2.4447102181268754, 2.8806500970683286, 3.3093493817663284, 3.731946181385193, 4.14927904112756, 4.561990576519039, 4.970588383070634, 5.375483155276916, 5.777013746011306, 6.175464307419844, 6.571076405369788, 6.964057819744383, 7.354589088480302, 7.742828472928446, 8.128915792157072, 8.51297542994457, 8.895118725487015, 9.275445897508995, 9.654047609943076, 10.031006258647476, 10.406397038429525, 10.780288835180375, 11.15274497741461, 11.523823873761431, 11.893579557171671, 12.26206215223821, 12.629318278694104, 12.995391401582797, 13.360322136595054, 13.724148517497477, 14.086906231335764, 14.4486288261056, 14.809347894789328, 15.169093239014218, 15.527893015065612, 15.885773864561044, 16.242761031739903, 16.59887846903245, 16.954148932330618, 17.30859406718125, 17.662234486953263, 18.015089843887907, 18.367178893820583, 18.718519555260585, 19.069128963427865, 19.419023519771347, 19.76821893742946, 20.116730283038386, 20.464572015246027, 20.81175802024852, 21.158301644630335, 21.50421572575782, 21.8495126199489, 22.194204228617807, 22.538302022572747, 22.881817064626162, 23.22476003066082, 23.567141229280885, 23.908970620164215, 24.25025783122101, 24.591012174653873, 24.931242662005427, 25.27095801827168, 25.610166695152227, 25.94887688350197, 26.287096525043406, 26.624833323393222, 26.96209475445252, 27.29888807620569, 27.635220337969223, 27.97109838912836, 28.306528887396396, 28.641518306628594, 28.976072944220327, 29.310198928116474, 29.64390222345724, 29.977188638883575, 30.31006383252353, 30.64253331767946, 30.974602468234497, 31.306276523795145, 31.637560594586017, 31.968459666111322, 32.29897860359672, 32.62912215622441, 32.95889496117315, 33.288301547474276, 33.61734633969419, 33.94603366145267, 34.27436773878625, 34.60235270336492, 34.929992595570035, 35.257291367440835, 35.58425288549656, 35.91088093344044, 36.23717921475177, 36.56315135517181], [0.0, 0.5838837929199803, 1.089565684035974, 1.5694068714917044, 2.0332014593038656, 2.4854179151281897, 2.928616776492654, 3.364454478029087, 3.794088079942577, 4.21837009033565, 4.63795382514246, 5.053355332018606, 5.464992144071646, 5.8732087565288476, 6.278294053049774, 6.680493621896673, 7.080018702765928, 7.477052839792479, 7.8717569295905285, 8.264273119402944, 8.654727864164498, 9.043234357017889, 9.429894485463596, 9.814800423110002, 10.19803593781664, 10.579677476485017, 10.959795072048568, 11.338453107526398, 11.715710964129556, 12.091623574529823, 12.46624189796163, 12.839613330438988, 13.211782060756482, 13.582789380910485, 13.952673957980718, 14.321472073249948, 14.689217833332892, 15.055943357277327, 15.421678942947505, 15.786453215468597, 16.150293260076733, 16.513224741361665, 16.87527201059368, 17.236458202580764, 17.596805323297087, 17.95633432935174, 18.315065200222097, 18.673017004053317, 19.03020795772186, 19.38665548177202, 19.742376250758795, 20.0973862394654, 20.451700765407672, 20.805334527989356, 21.158301644630335, 21.510615684153574, 21.86228969768475, 22.213336247291025, 22.563767432561093, 22.91359491530748, 23.262829942553257, 23.611483367948935, 23.95956567175072, 24.307086979478445, 24.654057079359898, 25.000485438658323, 25.34638121897058, 25.691753290575544, 26.036610245904914, 26.380960412202295, 26.72481186343049, 27.06817243148171, 27.41104971674082, 27.75345109804736, 28.09538374209838, 28.436854612330556, 28.77787047731701, 29.118437918711358, 29.45856333876904, 29.798252967473417, 30.137512869292262, 30.47634894958817, 30.8147669607046, 31.15277250774777, 31.49037105408315, 31.827567926563713, 32.16436832050615, 32.50077730442998, 32.8367998245734, 33.172440709198824, 33.50770467270026, 33.842596319523466, 34.177120147909804, 34.51128055347311, 34.84508183261908, 35.17852818581553, 35.51162372072158, 35.84437245518321, 36.17677832010239, 36.508845162186056, 36.8405767465814, 37.17197675940313], [0.0, 0.593429626470586, 1.107378839304842, 1.5950648824693952, 2.0664419824023086, 2.526051661105034, 2.976496317971452, 3.4194594684489132, 3.8561170893561543, 4.287335626330098, 4.713779076274704, 5.135971923635709, 5.554338527710393, 5.9692290158297725, 6.380936994571503, 6.789712067285596, 7.195768927196358, 7.5992941191758305, 8.000451170314205, 8.399384551799521, 8.796222785960392, 9.1910809165182, 9.584062496717754, 9.975261207100733, 10.36476218503555, 10.752643127243298, 11.13897521161593, 11.523823873761431, 11.907249465705869, 12.289307818207503, 12.670050723626083, 13.04952635284635, 13.427779617099244, 13.804852483458143, 14.180784251165388, 14.555611794661306, 14.929369778164833, 15.302090845833519, 15.673805790867108, 16.0445437063789, 16.41433212041771, 16.783197117160054, 17.151163445991678, 17.51825461994828, 17.884493004776584, 18.249899899702328, 18.614495610844525, 18.978299518090747, 19.34133013614259, 19.703605170350368, 20.065141567879014, 20.425955564681217, 20.786062728696713, 21.14547799964772, 21.50421572575782, 21.86228969768475, 22.219713179925197, 22.576498939921773, 22.932659275077643, 23.28820603786266, 23.643150659175873, 23.9975041701126, 24.35127722226927, 24.70448010670641, 25.057122771678152, 25.409214839226696, 25.760765620730556, 26.11178413148753, 26.462279104405777, 26.812259002869826, 27.161732032842558, 27.51070615425868, 27.859189091760676, 28.20718834482369, 28.55471119731209, 28.90176472650679, 29.248355811639353, 29.59449114196593, 29.94017722441152, 30.285420390812607, 30.63022680478409, 30.9746024682345, 31.318553227551536, 31.66208477947852, 32.005202676700705, 32.34791233315903, 32.69021902910769, 33.0321279159307, 33.373644020731604, 33.71477225070942, 34.055517397333084, 34.39588414032582, 34.73587705147008, 35.07550059824297, 35.41475914729153, 35.753656967756406, 36.09219823445227, 36.4303870309123, 36.76822735230422, 37.10572310822424, 37.44287812537541, 37.779696150136196], [0.0, 0.6029584281508921, 1.125160211979916, 1.6206771139022407, 2.099623197083619, 2.566612907526173, 3.0242904317988937, 3.4743663178465134, 3.91803542535001, 4.356178112613069, 4.789469038452257, 5.218441109050352, 5.64352549771493, 6.0650779538318424, 6.48339679847011, 6.898735642903712, 7.311312627723015, 7.721317293183191, 8.128915792157072, 8.534254915631434, 8.937465249640052, 9.338663685181148, 9.737955438271811, 10.135435693698303, 10.531190955894424, 10.92530016917089, 11.317835654335326, 11.708863897706532, 12.098446220393454, 12.486639349638448, 12.873495909440102, 13.259064844171345, 13.643391786210483, 14.02651937650342, 14.408487545327196, 14.789333759221373, 15.16909323901422, 15.547799153036145, 15.925482788938604, 16.30217370698802, 16.677899877255836, 17.052687802756672, 17.426562630281428, 17.799548250418663, 18.171667388045744, 18.542941684393746, 18.91339177164053, 19.283037340859863, 19.65189720404709, 20.019989350850377, 20.387331000558213, 20.753938649826765, 21.11982811657286, 21.485014580408414, 21.8495126199489, 22.213336247291025, 22.576498939921773, 22.939013670292788, 23.300892933268752, 23.66214877163667, 24.022792799843504, 24.382836226112765, 24.742289873075407, 25.101164197037278, 25.459469305993352, 25.817214976488604, 26.174410669415963, 26.531065544833417, 26.88718847587493, 27.24278806182306, 27.597872640405235, 27.95245029937022, 28.306528887396396, 28.66011602437929, 29.013219111141517, 29.365845338605116, 29.718001696462654, 30.069694981380824, 30.420931804767438, 30.771718600130367, 31.122061630054734, 31.47196699282275, 31.821440628698575, 32.17048832589911, 32.51911572627003, 32.86732833068486, 33.215131504183745, 33.562530480867366, 33.909530368560326, 34.25613615325739, 34.60235270336492, 34.94818477374928, 35.293637009602804, 35.638713950137664, 35.98342003211689, 36.32775959323146, 36.67173687533176, 37.01535602752098, 37.35862110911791, 37.701536092495836, 38.044104865803845, 38.38633123557664], [0.0, 0.6124705263919324, 1.1429104149351756, 1.6462444485719303, 2.132746247011082, 2.60710305242386, 3.07200076530386, 3.529176918706789, 3.979845222075298, 4.424899921991734, 4.865026320495552, 5.300765730743754, 5.732556128109645, 6.160758874178774, 6.5856769962472965, 7.007568106487494, 7.4266537868127696, 7.8431265676106845, 8.257155222933868, 8.668888859501363, 9.078460123434544, 9.485987749770304, 9.891578614383272, 10.29532940366744, 10.697327986725602, 11.09765455327115, 11.49638256502391, 11.893579557171671, 12.2893078182075, 12.683624970286374, 13.076584467587898, 13.468236026617308, 13.858625999636155, 14.247797700281602, 14.63579168875922, 15.022646022669896, 15.408396478475524, 15.793076747760527, 16.17671861176132, 16.55935209707857, 16.941005615031496, 17.32170608673863, 17.701479055699394, 18.08034878939338, 18.45833837119907, 18.83546978375335, 19.211763984721372, 19.587240975817608, 19.961919865810003, 20.33581892814623, 20.70895565376131, 21.0813467995579, 21.453008432991712, 21.823955973143846, 22.194204228617807, 22.563767432561093, 22.932659275077643, 23.300892933268752, 23.66848109911449, 24.035436005385385, 24.40176944975457, 24.76749281726326, 25.132617101277106, 25.497152923057627, 25.861110550060605, 26.224499913062974, 26.58733062220998, 26.949611982066035, 27.31135300574512, 27.67256242818958, 28.033248718660435, 28.393420092496434, 28.753084522194456, 29.112249747859288, 29.4709232870668, 29.829112444180932, 30.186824319161637, 30.54406581589785, 30.900843650097052, 31.257164356760274, 31.613034297269376, 31.96845966611132, 32.32344649726215, 32.678000670252, 33.032127915930694, 33.38583382195194, 33.739123837993205, 34.09200328072684, 34.44447733855702, 34.79655107613611, 35.14822943867306, 35.49951725604563, 35.85041924672736, 36.200940021539736, 36.55108408723888, 36.90085584994593, 37.250259618429475, 37.59929960724776, 37.94797993975823, 38.29630465100117, 38.644277690463994, 38.9919029247322], [0.0, 0.6219662377417514, 1.160630038870159, 1.671767737320159, 2.165812234469011, 2.647523443248033, 3.1196289062130953, 3.5838930950424945, 4.041548536467278, 4.493503341422537, 4.9404534368350825, 5.382948528353095, 5.821433381697407, 6.256274960984887, 6.687780991631214, 7.116213079814458, 7.5417962428425405, 7.9647259960841925, 8.38517373025622, 8.803290863820523, 9.219212099437078, 9.633058013004646, 10.044937137395888, 10.454947658025642, 10.86317880631473, 11.269712015233708, 11.674621885449104, 12.077976999210765, 12.479840610729335, 12.880271235530692, 13.279323156545285, 13.67704686108047, 14.073489420040861, 14.468694818596013, 14.862704245794827, 15.255556349281262, 15.647287460193626, 16.03793179246892, 16.427521620078217, 16.816087435153037, 17.20365808950022, 17.59026092162193, 17.975921871042683, 18.36066558148382, 18.744515494207324, 19.12749393266775, 19.50962217945681, 19.890920546394508, 20.271408438510154, 20.651104412562002, 21.030026230663623, 21.40819090951582, 21.785614765683324, 22.162313457303856, 22.538302022572747, 22.91359491530748, 23.28820603786266, 23.66214877163667, 24.035436005385385, 24.40808016153558, 24.780093220670896, 25.151486744345632, 25.522271896366025, 25.892459462665077, 26.262059869884673, 26.631083202767996, 26.99953922045549, 27.367437371769054, 27.734786809561513, 28.101596404201317, 28.467874756256467, 28.8336302084359, 29.198870856841665, 29.563604561580743, 29.927838956781105, 30.29158146005318, 30.654839281434327, 31.017619431851017, 31.37992873113071, 31.741773815592765, 32.10316114524557, 32.46409701061509, 32.82458753922782, 33.18463870176984, 33.54425631794176, 33.90344606202798, 34.262213468197494, 34.620563935552056, 34.9785027329366, 35.33603500352559, 35.69316576919825, 36.049899934714496, 36.406242291702874, 36.76219752247077, 37.117770203646835, 37.47296480966448, 37.82778571609523, 38.18223720283961, 38.53632345718338, 38.8900485767259, 39.24341657218722, 39.59643137010018], [0.0, 0.6314458674893553, 1.1783196534742952, 1.6972478007257306, 2.198822222535472, 2.687875379522287, 3.1671763857807913, 3.6385166059895684, 4.103147352299767, 4.561990576519039, 5.015752812467622, 5.464992144071645, 5.910160115899571, 6.351629285111346, 6.789712067285597, 7.224674055842077, 7.656743697665164, 8.086119488049496, 8.512975429944568, 8.937465249640052, 9.359725702851643, 9.779879203222354, 10.198035937816638, 10.614295588531498, 11.028748746798604, 11.441478086740142, 11.852559346040465, 12.26206215223821, 12.670050723626083, 13.076584467587898, 13.481718494401388, 13.885504060870636, 14.28798895532625, 14.689217833332892, 15.0892325117178, 15.488072227168736, 15.885773864561042, 16.282372159299666, 16.677899877255836, 17.072387975303535, 17.465865744991234, 17.85836094149786, 18.249899899702324, 18.64050763893053, 19.03020795772186, 19.419023519771347, 19.806975932046964, 20.194085815949087, 20.580372872266633, 20.96585594058864, 21.35055305374797, 21.7344814878036, 22.117657808007365, 22.500097911148778, 22.881817064626162, 23.262829942553257, 23.643150659175873, 24.022792799843504, 24.40176944975457, 24.780093220670896, 25.15777627577686, 25.534830352840924, 25.911266785821237, 26.287096525043406, 26.662330156065835, 27.036977917337207, 27.411049716740816, 27.784555147111753, 28.157503500805028, 28.529903783385837, 28.901764726506784, 29.273094800031284, 29.643902223457243, 30.01419497669058, 30.38398081021399, 30.75326725469259, 31.122061630054734, 31.490371054083152, 31.85820245054895, 32.22556255691821, 32.59245793165884, 32.958894961173144, 33.32487986637965, 33.690418708965986, 34.055517397333084, 34.42018169224933, 34.78441721223213, 35.14822943867306, 35.51162372072157, 35.874605279941264, 36.23717921475176, 36.59935050466836, 36.96112401435065, 37.322504497470916, 37.68349660041198, 38.04410486580384, 38.4043337359078, 38.76418755585602, 39.123670576754336, 39.48278695865519, 39.84154077340758, 40.19993600739017], [0.0, 0.6409097102460523, 1.1959798085117253, 1.7226854306671266, 2.231777237106626, 2.7281601153184636, 3.2146446817044456, 3.693049149156931, 4.164643583962693, 4.630363755751917, 5.090926787573975, 5.546899127680102, 5.9987390881971745, 6.446824810013786, 6.891473391060707, 7.332954405359181, 7.7714997236585655, 8.207310816216758, 8.640564293865637, 9.071416186879281, 9.500005300610031, 9.926455883384644, 10.350879773704548, 10.773378147456723, 11.194042953818782, 11.61295810599758, 12.030200476801745, 12.445840737317926, 12.859944068315356, 13.272570767550507, 13.683776771270576, 14.093614104494879, 14.502131271785249, 14.909373597984999, 15.315383526654239, 15.720200882543558, 16.123863103343158, 16.5264054450575, 16.927861164638788, 17.3282616829295, 17.72763673048741, 18.12601447847429, 18.523421656465036, 18.9198836587646, 19.315424640594774, 19.710067605324436, 20.10383448375763, 20.49674620635953, 20.888822769186117, 21.2800832941862, 21.670546084461083, 22.060228674995987, 22.449147879315724, 22.83731983246413, 23.22476003066082, 23.611483367948935, 23.9975041701126, 24.382836226112765, 24.76749281726326, 25.151486744345632, 25.534830352840924, 25.917535556438278, 26.299613858964403, 26.681076374863743, 27.061933848346555, 27.44219667131105, 27.821874900135676, 28.20097827142886, 28.57951621681549, 28.957497876832353, 29.334932113998356, 29.711827525119634, 30.08819245288444, 30.464034996798137, 30.83936302350437, 31.214184176534665, 31.588505885525354, 31.96233537493748, 32.33567967231269, 32.708545616095364, 33.08093986304892, 33.45286889529236, 33.8243390269807, 34.19535641065158, 34.56592704325852, 34.93605677190987, 35.305751299330986, 35.67501618906623, 36.04385687043582, 36.41227864326193, 36.78028668237715, 37.14788604192763, 37.515081659482426, 37.88187835995983, 38.248280859380685, 38.614293768458, 38.97992159603181, 39.34516875235727, 39.710039552253974, 40.07453821812349, 40.438668882841945, 40.80243559253416], [0.0, 0.6503580504877421, 1.213611034833248, 1.7480813917801146, 2.2646782687850924, 2.7683788615650147, 3.262035220844852, 3.7474923637512645, 4.226039079985906, 4.698624934366823, 5.165977621826534, 5.628671941239961, 6.087172961206607, 6.5418643971971235, 6.993068021824369, 7.44105738319054, 7.886067770301414, 8.328303623504928, 8.767944157243424, 9.205147702001282, 9.640055109410028, 10.072792459474801, 10.503473239428823, 10.93220011670178, 11.359066395993134, 11.78415722756469, 12.207550617489932, 12.629318278694104, 13.04952635284635, 13.46823602661731, 13.885504060870637, 14.301383247582482, 14.71592280637266, 15.12916873026681, 15.541164088531273, 15.951949293016169, 16.36156233332101, 16.770038985196987, 17.177412995872853, 17.583716249399558, 17.988978914625047, 18.393229578012527, 18.79649536318634, 19.19880203881624, 19.600174116222153, 20.00063493789039, 20.400206757930597, 20.79891081536647, 21.19676740103739, 21.593795918789404, 21.99001494154955, 22.385442262805142, 22.78009494394727, 23.173989357883823, 23.567141229280885, 23.95956567175072, 24.35127722226927, 24.742289873075407, 25.132617101277106, 25.522271896366025, 25.911266785821237, 26.299613858964403, 26.687324789212532, 27.074410854860066, 27.46088295850923, 27.8467516452564, 28.23202711973193, 28.61671926208208, 29.00083764297347, 29.384391537693386, 29.767389939412674, 30.149841571672248, 30.5317549001489, 30.91313814375154, 31.293999285094465, 31.67434608039074, 32.05418606880497, 32.43352658130174, 32.812374749023284, 33.19073751122682, 33.56862162281032, 33.94603366145267, 34.322980034392636, 34.69946698486904, 35.07550059824297, 35.45108680782128, 35.82623140039935, 36.200940021539736, 36.575218180602114, 36.94907125553905, 37.322504497470916, 37.69552303505246, 38.06813187864276, 38.44033592428944, 38.81213995753727, 39.18354865707076, 39.5545665981996, 39.925198256195266, 40.29544800948677, 40.66532014272262, 41.03481884970614, 41.40394823621043], [0.0, 0.6597911630613658, 1.2312138453213912, 1.7734364228190196, 2.2975262746435074, 2.808532788202808, 3.309349381766329, 3.801847833495276, 4.287335626330098, 4.766776098043319, 5.240907498412153, 5.710312963476703, 6.175464307419845, 6.6367508113098745, 7.094498914907656, 7.548986133991408, 8.000451170314205, 8.449101429527197, 8.895118725487016, 9.338663685181148, 9.779879203222356, 10.218893188342099, 10.655820773848163, 11.090766116309059, 11.523823873761435, 11.95508043152831, 12.384614927121573, 12.812500113625951, 13.238803092061849, 13.66358593658142, 14.086906231335766, 14.508817534021786, 14.929369778164832, 15.34860962389598, 15.766580765179356, 16.183324200018408, 16.598878469032453, 17.013279866881746, 17.426562630281428, 17.838759105744376, 18.249899899702328, 18.660014013250585, 19.06912896342787, 19.47727089266536, 19.884464667807222, 20.29073396991064, 20.6961013758698, 21.100588432769637, 21.504215725757824, 21.907002940123316, 22.308968918184014, 22.710131711512712, 23.11050862896729, 23.510116280936337, 23.908970620164215, 24.307086979478445, 24.70448010670641, 25.101164197037278, 25.497152923057627, 25.892459462665077, 26.287096525043406, 26.681076374863743, 27.074410854860066, 27.467111406912736, 27.859189091760676, 28.250654607451523, 28.641518306628598, 29.031790212744653, 29.421480035283963, 29.81059718406713, 30.199150782706372, 30.587149681273118, 30.974602468234504, 31.36151748171052, 31.74790282009923, 32.133766352113625, 32.51911572627004, 32.90395837986499, 33.28830154747428, 33.672152269005544, 34.05551739733309, 34.4384036055417, 34.820817393803885, 35.20276509591345, 35.58425288549657, 35.96528678191968, 36.34587265591269, 36.72601623492417, 37.10572310822425, 37.484998731769956, 37.86384843284649, 38.24227741449713, 38.62029075975368, 38.99789343567842, 39.37509029722802, 39.75188609094892, 40.12828545851337, 40.504292940104364, 40.879912977657796, 41.25514991796883, 41.63000801566977, 42.00449143608587], [0.0, 0.669209313658415, 1.2487887357740093, 1.7987512379294612, 2.330322179873383, 2.8486230262007126, 3.356588497111722, 3.8561170893561543, 4.348534949463675, 4.8348191663158335, 5.3157185277933685, 5.791824493877882, 6.263615613636374, 6.731486724907116, 7.195768927196359, 7.656743697665165, 8.114653145400904, 8.569707636654632, 9.022091580574312, 9.471967897008021, 9.919481520309361, 10.364762185035548, 10.807926667958073, 11.249080612422329, 11.688320027655605, 12.12573253208319, 12.561398392860786, 12.995391401582799, 13.427779617099246, 13.858625999636157, 14.287988955326252, 14.715922806372662, 15.14247819907394, 15.567702459608492, 15.991639905647395, 16.41433212041771, 16.835818194684588, 17.256134941194304, 17.675317085371994, 18.093397435458954, 18.510407034776648, 18.92637529839483, 19.34133013614259, 19.75529806361973, 20.168304302630723, 20.580372872266636, 20.991526671694217, 21.401787555571005, 21.811176402886176, 22.219713179925197, 22.627416997969533, 23.03430616626811, 23.44039824075309, 23.845710068917096, 24.25025783122101, 24.654057079359898, 25.057122771678152, 25.459469305993352, 25.861110550060605, 26.262059869884673, 26.662330156065835, 27.061933848346555, 27.46088295850923, 27.859189091760676, 28.256863466725697, 28.65391693416058, 29.050359994486854, 29.446202814236464, 29.841455241491154, 30.23612682039147, 30.63022680478409, 31.023764171070283, 31.416747630312752, 31.809185639653503, 32.201086413090714, 32.59245793165885, 32.98330795305255, 33.373644020731604, 33.763473472541335, 34.15280344888012, 34.54164090044324, 34.92999259557003, 35.317865127219335, 35.70526491959633, 36.09219823445226, 36.47867117707666, 36.86468970200083, 37.250259618429475, 37.63538659541642, 38.020076166799456, 38.4043337359078, 38.78816458005526, 39.17157385483108, 39.55456659819959, 39.93714773441927, 40.319322077790844, 40.70109433624383, 41.08246911476983, 41.463450918710876, 41.84404415691021, 42.22425314473264, 42.604082106961116], [0.0, 0.678612759258125, 1.2663361857313116, 1.8240265278395993, 2.3630668793283918, 2.8886506694421406, 3.403753855825354, 3.9103016120993357, 4.409638719242635, 4.902755995775582, 5.390412751228804, 5.873208756528848, 6.351629285111348, 6.8260747229085075, 7.2968808218964885, 7.764333014434102, 8.228676811622984, 8.690125535691578, 9.148866187027021, 9.605063974758037, 10.058865869794328, 10.510403429668111, 10.95979507204857, 11.407147924736606, 11.85255934604047, 12.296118185562426, 12.737905838338218, 13.17799713285046, 13.616461084283277, 14.053361537553112, 14.488757719490897, 14.922704715612335, 15.355253883876303, 15.7864532154686, 16.21634765079343, 16.64497935738774, 17.072387975303535, 17.4986108345642, 17.92368314854182, 18.3476381864852, 18.770507427923388, 19.192320701254236, 19.61310630848392, 20.032891137798206, 20.451700765407676, 20.869559547909486, 21.28649070623976, 21.70251640214843, 22.11765780800737, 22.531935170659832, 22.945367869930905, 23.357974472343315, 23.769772780517748, 24.18077987868065, 24.591012174653873, 25.000485438658323, 25.409214839226696, 25.817214976488604, 26.224499913062974, 26.631083202767996, 27.036977917337207, 27.44219667131105, 27.8467516452564, 28.250654607451523, 28.65391693416058, 29.056549628610085, 29.45856333876904, 29.85996837402519, 30.260774720841347, 30.66099205746827, 31.06062976778378, 31.459696954321718, 31.858202450548955, 32.25615483244367, 32.65356242942366, 33.0504333346695, 33.44677541488368, 33.84259631952347, 34.2379034895425, 34.63270416567299, 35.02700539627844, 35.42081404480404, 35.81413679685008, 36.20698016689195, 36.599350504668365, 36.9912540012578, 37.38269669486212, 37.77368447631448, 38.16422309432788, 38.554318160499236, 38.943975154083056, 39.333199426547736, 39.72199620592667, 40.11037060097553, 40.498327605146365, 40.88587210038844, 41.2730088607851, 41.65974255603532, 42.0460777547883, 42.432018927838485, 42.817570451188345, 43.202736608985695], [0.0, 0.6880017485427284, 1.2838566592507525, 1.8492629609762832, 2.3957612389703624, 2.928616776492654, 3.450846705235832, 3.964402834681275, 4.470648551608892, 4.970588383070635, 5.464992144071646, 5.954467903706647, 6.439507649442248, 6.920517306775269, 7.39783727299934, 7.8717569295905285, 8.34252518443468, 8.81035831119327, 9.275445897508995, 9.737955438271811, 10.19803593781664, 10.655820773848161, 11.111430002410632, 11.564972233478345, 12.016546172366514, 12.466241897961632, 12.914141931445558, 13.360322136595054, 13.804852483458143, 14.247797700281602, 14.689217833332892, 15.129168730266812, 15.56770245960849, 16.004867676528782, 16.440709943207665, 16.87527201059368, 17.308594067181254, 17.740713959475638, 18.171667388045744, 18.601488082439133, 19.030207957721863, 19.45785725498444, 19.88446466780722, 20.310057456389142, 20.734661550802056, 21.15830164463034, 21.581001280084827, 22.00278292553573, 22.4236680462866, 22.843677169307156, 23.262829942553264, 23.681145189425944, 24.09864095885515, 24.51533457143721, 24.931242662005427, 25.34638121897058, 25.760765620730556, 26.174410669415963, 26.58733062220998, 26.99953922045549, 27.411049716740816, 27.821874900135676, 28.23202711973193, 28.641518306628598, 29.050359994486854, 29.45856333876904, 29.866139134764804, 30.273097834498063, 30.679449562599967, 31.085204131225314, 31.490371054083152, 31.894959559646004, 32.29897860359672, 32.70243688056697, 33.10534283521672, 33.50770467270026, 33.90953036856033, 34.31082767808875, 34.711604145188915, 35.11186711077267, 35.51162372072157, 35.91088093344044, 36.30964552702861, 36.707924106092904, 37.10572310822424, 37.50304881015815, 37.89990733363841, 38.29630465100118, 38.692246590496126, 39.08773884135977, 39.48278695865519, 39.87739636789135, 40.27157236943444, 40.66532014272262, 41.05864475029518, 41.45155114164589, 41.844044156910215, 42.236128530395064, 42.62780889395945, 43.01908978025378, 43.409975625824984, 43.80047077409446], [0.0, 0.6973765222869265, 1.301350605633812, 1.874461184511905, 2.4284060972255035, 2.9685223722578313, 3.497868253009541, 4.0184221444936625, 4.531566011121071, 5.0383180677197315, 5.539458618863329, 6.035604019250795, 6.527252960214238, 7.014816898427826, 7.498640869469352, 7.979018197952917, 8.45620118340562, 8.930409046453315, 9.401833958076978, 9.87064569546701, 10.336995293304808, 10.801017946711665, 11.262835347626297, 11.722557585952282, 12.180284711972345, 12.63610803199599, 13.090111191646129, 13.542371088426169, 13.992958645802311, 14.441939474014244, 14.889374437525275, 15.335320144975372, 15.779829374380075, 16.222951443889972, 16.664732536519413, 17.1052159857452, 17.544442527673812, 17.982450524510387, 18.41927616328299, 18.854953633141047, 19.28951528402817, 19.722991769102684, 20.155412172926262, 20.58680412714776, 21.017193915164526, 21.446606567037932, 21.87506594576711, 22.30259482587829, 22.729214965163195, 23.15494717029387, 23.579811356951, 24.00382660502497, 24.427011209382066, 24.849382726630623, 25.27095801827168, 25.691753290575544, 26.11178413148753, 26.531065544833417, 26.949611982066035, 27.367437371769054, 27.784555147111753, 28.20097827142886, 28.61671926208208, 29.031790212744653, 29.446202814236464, 29.85996837402519, 30.273097834498063, 30.685601790099224, 31.097490503418953, 31.508773920313356, 31.919461684126134, 32.329563149077806, 32.73908739288217, 33.14804322864472, 33.556439216093125, 33.96428367218584, 34.37158468114108, 34.77835010392496, 35.18458758723478, 35.59030457201031, 35.99550830150354, 36.400205828935135, 36.80440402476342, 37.20810958359019, 37.61132903072555, 38.0140687284324, 38.41633488186994, 38.818133544753934, 39.21947062475029, 39.620351888617584, 40.02078296711269, 40.420769359673024, 40.82031643888806, 41.21942945477145, 41.618113538845094, 42.01637370804501, 42.414214868458785, 42.81164181890341, 43.20865925435205, 43.60527176921739, 44.001483860499164, 44.39729993080261], [0.0, 0.7067373137235418, 1.3188184601083268, 1.8996218253472266, 2.4610022662576756, 3.008368449539738, 3.544819668984667, 4.072360885470385, 4.592392613330524, 5.105946734753996, 5.613814028238018, 6.1166191217279025, 6.614867400422559, 7.10897584392386, 7.599294119175831, 8.086119488049496, 8.569707636654632, 9.050280728186126, 9.528033513110229, 10.00313804751378, 10.475747393396427, 10.945998560585426, 11.41401487447405, 11.879907902687874, 12.343779038471132, 12.805720813725669, 13.265817996838358, 13.724148517497477, 14.180784251165388, 14.635791688759221, 15.0892325117178, 15.541164088531273, 15.991639905647393, 16.440709943207665, 16.888421004134834, 17.334817003565156, 17.77993922440039, 18.223826543776404, 18.666515634454882, 19.108041144501616, 19.548435858089164, 19.987730839829087, 20.42595556468122, 20.86313803519033, 21.299304887552285, 21.734481487803603, 22.168692019253253, 22.60195956212688, 23.034306166268113, 23.46575291763417, 23.896319999231245, 24.32602674705652, 24.754891701545827, 25.182932654967495, 25.610166695152227, 26.036610245904914, 26.462279104405777, 26.88718847587493, 27.31135300574512, 27.734786809561513, 28.157503500805028, 28.57951621681549, 29.00083764297347, 29.421480035283963, 29.841455241491154, 30.260774720841347, 30.679449562599967, 31.097490503418953, 31.51490794364196, 31.931711962626984, 32.34791233315903, 32.763518535019074, 33.17853976776984, 33.59298496281395, 34.00686279477516, 34.420181692249336, 34.83294984796806, 35.24517522841414, 35.65686558292549, 36.0680284523206, 36.47867117707666, 36.888800905088765, 37.29842459903648, 37.70754904338235, 38.116180851024836, 38.52432646962664, 38.931992187637974, 39.33918414003283, 39.745908313774905, 40.152170553029215, 40.55797656413351, 40.96333192034346, 41.368242066364026, 41.77271232267913, 42.17674788969039, 42.580353851675476, 42.98353518057574, 43.386296739622054, 43.788643286807556, 44.190579478215135, 44.592109871207136, 44.99323892748439], [0.0, 0.7160843488871359, 1.3362606444697025, 1.9247454910349802, 2.493550533164938, 3.048155970499604, 3.591702086894698, 4.1262203600675145, 4.653129827014167, 5.173476017199457, 5.688060167652052, 6.1975151674055855, 6.702353085688709, 7.202996416914703, 7.699799452587753, 8.193063386049747, 8.68304728501635, 9.169976250927188, 9.654047609943074, 10.135435693698302, 10.6142955885315, 11.090766116309057, 11.564972233478343, 12.037026983215323, 12.507033099752178, 12.975084338782002, 13.441266589805661, 13.905658813179441, 14.368333834962845, 14.829359025456238, 15.288796881873363, 15.746705531437895, 16.20313916798872, 16.65814843268542, 17.111780747448147, 17.56408060821781, 18.01508984388791, 18.46484784576832, 18.91339177164053, 19.360756727812284, 19.806975932046967, 20.25208085980471, 20.6961013758698, 21.13906585313787, 21.581001280084827, 22.02193335822862, 22.46188659071733, 22.90088436302677, 23.33894901662329, 23.77610191633885, 24.212363512112304, 24.64775339567127, 25.08229035266024, 25.51599241066122, 25.94887688350197, 26.380960412202295, 26.812259002869826, 27.24278806182306, 27.67256242818958, 28.101596404201317, 28.529903783385837, 28.957497876832353, 29.384391537693386, 29.81059718406713, 30.23612682039147, 30.66099205746827, 31.085204131225314, 31.508773920313356, 31.931711962626984, 32.354028470829896, 32.775733346958184, 33.19683619616875, 33.61734633969419, 34.037272827060406, 34.45662444761838, 34.87540974143736, 35.29363700960281, 35.71131432395918, 36.12844953633413, 36.54505028727812, 36.96112401435065, 37.376677959982125, 37.791719178937825, 38.20625454540897, 38.62029075975367, 39.03383435490894, 39.4468917024936, 39.85946901862044, 40.27157236943444, 40.68320767639327, 41.094380721304525, 41.505097151133576, 41.915362482594986, 42.32518210653933, 42.73456129214672, 43.143505190937546, 43.55201884061012, 43.960107168714536, 44.36777499617131, 44.775027040642904, 45.181867919765565, 45.588302154248865], [0.0, 0.72541784693722, 1.3536775676840485, 1.9498327706486205, 2.526051661105034, 3.087885868033637, 3.6385166059895684, 4.18000183112572, 4.713779076274704, 5.240907498412152, 5.762198777951311, 6.278294053049773, 6.789712067285597, 7.296880821896487, 7.800159226249129, 8.299852399462416, 8.79622278596039, 9.289498421172018, 9.779879203222354, 10.267541735997513, 10.752643127243296, 11.235324008240898, 11.715710964129556, 12.193918511498618, 12.670050723626085, 13.144202578223911, 13.616461084283275, 14.086906231335764, 14.555611794661306, 15.022646022669898, 15.488072227168738, 15.951949293016169, 16.414332120417708, 16.87527201059368, 17.334817003565156, 17.793012175236544, 18.249899899702324, 18.705520081701717, 19.15991036333357, 19.613106308483918, 20.065141567879014, 20.516048027232532, 20.965855940588643, 21.41459405065746, 21.86228969768475, 22.30896891818401, 22.75465653467922, 23.199376237454263, 23.643150659175877, 24.086001443146866, 24.52794930585215, 24.96901409437942, 25.409214839226692, 25.848569802948848, 26.287096525043406, 26.72481186343049, 27.161732032842558, 27.597872640405235, 28.033248718660435, 28.467874756256467, 28.901764726506784, 29.334932113998356, 29.767389939412674, 30.199150782706372, 30.63022680478409, 31.06062976778378, 31.490371054083152, 31.919461684126134, 32.34791233315903, 32.775733346958184, 33.202934756623584, 33.62952629250647, 34.05551739733309, 34.48091723858157, 34.90573472016396, 35.329978493461425, 35.753656967756406, 36.17677832010239, 36.599350504668365, 37.02138126159229, 37.4428781253754, 37.86384843284649, 38.28429933072318, 38.70423778279543, 39.123670576754336, 39.54260433068769, 39.961045499262504, 40.379000379612826, 40.79647511695026, 41.213475709913205, 41.630008015669766, 42.04607775478829, 42.461690515888634, 42.87685176008611, 43.29156682523975, 43.70584093001523, 44.119679177772625, 44.533086560288076, 44.94606796131837, 45.35862816001631, 45.77077183420479, 46.18250356351663], [0.0, 0.7347380204625458, 1.3710696264560023, 1.9748842356002192, 2.558506390354994, 3.1275590470682926, 3.6852642925619077, 4.233706523623646, 4.774341742517918, 5.3082427142765205, 5.836231547788271, 6.358957618558259, 6.876946334985627, 7.390631197270947, 7.900375726050938, 8.406488960617049, 8.909236717281095, 9.408849961272818, 9.905531159009769, 10.399459183386016, 10.890793160668766, 11.37967552897089, 11.866234499798372, 12.35058606105049, 12.832835623139447, 13.313079384051496, 13.791405470669938, 14.267894900232417, 14.742622395884167, 15.21565708289123, 15.687063086491344, 16.156900048095917, 16.62522357326869, 17.09208562234842, 17.557534852574705, 18.02161691898748, 18.484374740103892, 18.94584873335952, 19.406077024479156, 19.865095634273903, 20.322938645814766, 20.779638354483296, 21.235225403027826, 21.689728903445015, 22.143176547248295, 22.595594705468464, 23.04700851954947, 23.49744198414812, 23.946918022715817, 24.395458556628668, 24.843084568537137, 25.289816160524428, 25.73567260759253, 26.180672406933763, 26.624833323393222, 27.06817243148171, 27.51070615425868, 27.95245029937022, 28.393420092496434, 28.8336302084359, 29.273094800031284, 29.711827525119634, 30.149841571672248, 30.587149681273118, 31.023764171070283, 31.459696954321718, 31.894959559646004, 32.329563149077806, 32.763518535019074, 33.19683619616875, 33.62952629250647, 34.06159867939908, 34.49306292089307, 34.92392830225036, 35.35420384178054, 35.783898302017754, 36.213020200287, 36.64157781870058, 37.06957921362271, 37.49703222463669, 37.92394448304709, 38.35032341994631, 38.77617627387307, 39.20151009808814, 39.62633176749092, 40.050647985198445, 40.47446528880732, 40.89779005635724, 41.320628512013506, 41.742986731485075, 42.16487064719298, 42.58628605320349, 43.00723860993906, 43.42773384867947, 43.8477771758646, 44.267373877209565, 44.686529121642465, 45.10524796507381, 45.52353535400691, 45.941396128997184, 46.358835027968205, 46.775856689391965], [0.0, 0.744045075767833, 1.3884372057637835, 1.9999004404111527, 2.5909154393095775, 3.1671763857807913, 3.7319461813851933, 4.287335626330098, 4.834819166315834, 5.375483155276916, 5.910160115899571, 6.439507649442247, 6.964057819744385, 7.484249618229588, 8.000451170314207, 8.51297542994457, 9.022091580574312, 9.528033513110229, 10.031006258647475, 10.531190955894422, 11.028748746798604, 11.523823873761431, 12.016546172366512, 12.507033099752178, 12.9953914015828, 13.48171849440139, 13.966103621409923, 14.4486288261056, 14.929369778164833, 15.408396478475526, 15.885773864561044, 16.36156233332101, 16.835818194684588, 17.308594067181254, 17.77993922440039, 18.249899899702324, 18.718519555260585, 19.185839120485497, 19.65189720404709, 20.116730283038386, 20.580372872266636, 21.04285767620465, 21.50421572575782, 21.964476501689578, 22.4236680462866, 22.881817064626166, 23.33894901662329, 23.795088200879313, 24.25025783122101, 24.704480106706406, 25.157776275776868, 25.610166695152223, 26.061670883994285, 26.512307573802545, 26.96209475445252, 27.41104971674082, 27.859189091760676, 28.306528887396396, 28.753084522194456, 29.198870856841665, 29.643902223457243, 30.08819245288444, 30.5317549001489, 30.974602468234504, 31.416747630312752, 31.858202450548955, 32.29897860359672, 32.73908739288217, 33.17853976776984, 33.61734633969419, 34.05551739733309, 34.49306292089307, 34.929992595570035, 35.36631582424398, 35.80204173946099, 36.23717921475178, 36.67173687533176, 37.10572310822424, 37.53914607184479, 37.9720137050821, 38.4043337359078, 38.83611368954524, 39.267360896225, 39.69808249855272, 40.12828545851336, 40.55797656413351, 40.987162435822675, 41.415849532412274, 41.844044156910215, 42.27175246198752, 42.69898045521224, 43.1257340040451, 43.55201884061012, 43.977840566252766, 44.403204655897234, 44.828116462213735, 45.25258121960607, 45.676604048028864, 46.10018995664365, 46.52334384732201, 46.94607051800363, 47.36837466591683], [0.0, 0.7533392131441788, 1.4057806793637957, 2.024881923438931, 2.6232795054228952, 3.2067387367501707, 3.778563277070061, 4.34089029336219, 4.895212649163843, 5.442630268451234, 5.983986073253949, 6.519945879166682, 7.051048396231604, 7.577738099473693, 8.100387712697628, 8.619314099071184, 9.13478980451632, 9.647051641556128, 10.156307202403665, 10.662739888436725, 11.166512854485452, 11.667772144735507, 12.166649216593939, 12.663262994398874, 13.157721557213565, 13.650123538446447, 14.140559296068764, 14.629111898412846, 15.115857960372528, 15.600868357242238, 16.08420883770354, 16.565940553095672, 17.04612051673558, 17.524802004429915, 18.002034905262366, 18.477866030110963, 18.952339384051033, 19.42549640775703, 19.897376192173923, 20.368015670043352, 20.837449787309556, 21.305711656968803, 21.772832697544803, 22.23884275805591, 22.703770231075197, 23.167642155262758, 23.630484308562664, 24.092321293098916, 24.553176612670622, 25.013072743632314, 25.472031199847365, 25.930072592318776, 26.38721668402931, 26.843482440460416, 27.29888807620569, 27.75345109804736, 28.20718834482369, 28.66011602437929, 29.112249747859288, 29.563604561580743, 30.01419497669058, 30.464034996798137, 30.91313814375154, 31.36151748171052, 31.809185639653503, 32.25615483244367, 32.70243688056697, 33.14804322864472, 33.59298496281395, 34.037272827060406, 34.48091723858157, 34.92392830225036, 35.36631582424398, 35.80808932489722, 36.24925805083411, 36.68983098642785, 37.12981686463458, 37.569224177242944, 38.00806118457824, 38.44633592469671, 38.88405622210289, 39.32122969602044, 39.75786376824447, 40.19396567060155, 40.62954245204129, 41.064600985382015, 41.49914797373115, 41.93318995659972, 42.36673331572881, 42.79978428064469, 43.23234893395812, 43.66443321642241, 44.09604293176362, 44.527183751295674, 44.95786121833201, 45.38808075240501, 45.8178476533033, 46.24716710493673, 46.67604417903808, 47.10448383870999, 47.53249094182496, 47.96007024428611], [0.0, 0.7626206271242885, 1.423100410266902, 2.049829207563221, 2.655599266097171, 3.24624692804372, 3.8251165553444717, 4.3943716456560376, 4.955523455139189, 5.509685459234862, 6.057710965079607, 6.600273991359182, 7.137919885220042, 7.67109859778165, 8.200187444941953, 8.72550719373857, 9.247333747958667, 9.76590683774202, 10.281436612913504, 10.7941087344228, 11.304088367227093, 11.811523354829697, 12.316546774240884, 12.819279014990018, 13.319829487713843, 13.81829804102038, 14.314776146124043, 14.80934789478933, 15.30209084583352, 15.793076747760528, 16.282372159299666, 16.770038985196987, 17.256134941194304, 17.74071395947564, 18.223826543776404, 18.705520081701717, 19.185839120485497, 19.664825611366428, 20.142519126904176, 20.618957054865238, 21.094174771740644, 21.568205798490848, 22.041081940727242, 22.512833415218974, 22.98348896434598, 23.45307595989451, 23.921620497402312, 24.389147482100526, 24.855680707363653, 25.321242926463107, 25.785855918320905, 26.24954054787513, 26.7123168215957, 27.174203938625723, 27.635220337969223, 28.09538374209838, 28.55471119731209, 29.013219111141517, 29.4709232870668, 29.927838956781105, 30.38398081021399, 30.83936302350437, 31.293999285094465, 31.74790282009923, 32.201086413090714, 32.65356242942366, 33.10534283521672, 33.556439216093125, 34.00686279477516, 34.45662444761838, 34.90573472016396, 35.35420384178054, 35.80204173946099, 36.24925805083411, 36.6958621364457, 37.14186309135973, 37.587269756125536, 38.0320907271537, 38.47633436653975, 38.9200088113717, 39.363121982554844, 39.80568159318445, 40.24769515649487, 40.6891699934114, 41.13011323972928, 41.57053185294247, 42.010432618743124, 42.449822157211436, 42.88870692871386, 43.3270932395267, 43.76498724720071, 44.20239496568144, 44.63932227019898, 45.0757749019399, 45.5117584725133, 45.94727846822216, 46.38234025415045, 46.816949078075666, 47.2511100742162, 47.684828266821924, 48.11810857361609, 48.55095580909629], [0.0, 0.7718895067235706, 1.4403967511883273, 2.074742800833888, 2.687875379522287, 3.285701764243256, 3.8716069642629947, 4.447780772355999, 5.015752812467623, 5.576650093202519, 6.131336292779303, 6.680493621896674, 7.22467405584208, 7.764333014434102, 8.29985239946242, 8.83155687656239, 9.359725702851645, 9.884601522146465, 10.406397038429525, 10.92530016917089, 11.441478086740144, 11.955080431528309, 12.466241897961632, 12.975084338782002, 13.481718494401392, 13.986245426986297, 14.488757719490895, 14.989340485729718, 15.48807222716874, 15.985025564342115, 16.48026786493294, 16.973861786076625, 17.465865744991234, 17.956334329351744, 18.445318656715195, 18.932866690634956, 19.41902351977135, 19.90383160523778, 20.38733100055821, 20.869559547909486, 21.350553053747973, 21.830345446447378, 22.308968918184014, 22.786454052981178, 23.262829942553264, 23.738124291362798, 24.212363512112304, 24.685572812730722, 25.157776275776868, 25.62899693106507, 26.09925682221804, 26.568577067766004, 27.036977917337207, 27.504478803420863, 27.97109838912836, 28.436854612330556, 28.90176472650679, 29.365845338605116, 29.829112444180932, 30.29158146005318, 30.75326725469259, 31.214184176534665, 31.67434608039074, 32.133766352113625, 32.59245793165885, 33.0504333346695, 33.50770467270026, 33.96428367218584, 34.420181692249336, 34.87540974143736, 35.329978493461425, 35.783898302017754, 36.23717921475178, 36.68983098642785, 37.14186309135973, 37.59328473515265, 38.044104865803845, 38.494332184204545, 38.94397515408306, 39.39304201142546, 39.84154077340758, 40.28947924686955, 40.73686503636144, 41.183705551786986, 41.630008015669766, 42.075779470065015, 42.52102678313808, 42.96575665542952, 43.409975625824984, 43.85369007724716, 44.296906242085576, 44.7396302073792, 45.18186791976557, 45.62362519020955, 46.064907698523655, 46.50572099769131, 46.94607051800363, 47.38596157101953, 47.825399353358605, 48.26438895033538, 48.70293533944306, 49.141043393694545], [0.0, 0.781146035668061, 1.4576700449729771, 2.0996231970836194, 2.720108485469459, 3.3251040274153256, 3.9180354253500105, 4.5011187321280115, 5.075901915004449, 5.64352549771493, 6.204863515740816, 6.7606063608780005, 7.311312627723017, 7.8574431975065995, 8.399384551799523, 8.937465249640052, 9.471967897008021, 10.00313804751378, 10.531190955894422, 11.056316793133616, 11.578684736338493, 12.098446220393454, 12.615737554985541, 13.130682054119454, 13.643391786210486, 14.153969025366562, 14.66250746480024, 15.16909323901422, 15.67380579086711, 16.176718611761324, 16.677899877255836, 17.177412995872853, 17.675317085371994, 18.171667388045744, 18.666515634454885, 19.15991036333357, 19.651897204047092, 20.142519126904176, 20.6318166657522, 21.119828116572865, 21.60658971521495, 22.09213579692254, 22.576498939921773, 23.059710095000746, 23.54179870274282, 24.022792799843508, 24.502719115747492, 24.981603160678176, 25.459469305993352, 25.936340857681785, 26.412240123714156, 26.88718847587493, 27.361206406626682, 27.834313581493788, 28.306528887396396, 28.77787047731701, 29.248355811639353, 29.718001696462654, 30.186824319161637, 30.654839281434327, 31.122061630054734, 31.588505885525354, 32.05418606880497, 32.51911572627004, 32.98330795305255, 33.44677541488368, 33.90953036856033, 34.37158468114108, 34.83294984796806, 35.29363700960281, 35.753656967756406, 36.213020200287, 36.67173687533176, 37.12981686463458, 37.587269756125536, 38.044104865803845, 38.50033124897148, 38.95595771086108, 39.41099281669832, 39.86544490123553, 40.319322077790844, 40.77263224682431, 41.225383104080066, 41.67758214832168, 42.12923668868555, 42.580353851675476, 43.03094058782013, 43.48100367801321, 43.930549739554934, 44.379585231912245, 44.828116462213735, 45.27614959049437, 45.723690634704006, 46.170745475492815, 46.61731986078585, 47.06341941015812, 47.50904961902102, 47.95421586262986, 48.398923399922325, 48.84317737719622, 49.28698283163503, 49.73034469468903], [0.0, 0.7903903926100557, 1.474920624997824, 2.1244708765075226, 2.7522992060421148, 3.3644544780290873, 3.964402834681275, 4.55438655440212, 5.13597192363571, 5.710312963476703, 6.278294053049774, 6.840613754490165, 7.39783727299934, 7.950430944038627, 8.498785822937647, 9.043234357017889, 9.584062496717754, 10.121518701615392, 10.655820773848161, 11.187161134950042, 11.715710964129558, 12.241623488404796, 12.765036630599582, 13.286075164059918, 13.804852483458145, 14.32147207324995, 14.836028735446327, 15.348609623895978, 15.85929512161224, 16.368159589720634, 16.87527201059368, 17.380696543152336, 17.884493004776584, 18.38671729151563, 18.887421746127906, 19.38665548177202, 19.88446466780722, 20.38089278306798, 20.87598084109349, 21.36976759107356, 21.862289697684755, 22.353581902506512, 22.843677169307156, 23.3326068151573, 23.820400629050518, 24.307086979478445, 24.79269291221141, 25.277244239369775, 25.760765620730552, 26.243280638093776, 26.724811863430496, 27.205380921446395, 27.685008547119054, 28.163714638701585, 28.641518306628594, 29.118437918711358, 29.59449114196593, 30.069694981380824, 30.54406581589785, 31.017619431851017, 31.490371054083152, 31.96233537493748, 32.43352658130174, 32.90395837986499, 33.373644020731604, 33.84259631952347, 34.31082767808875, 34.77835010392496, 35.24517522841414, 35.71131432395918, 36.17677832010239, 36.64157781870058, 37.10572310822424, 37.569224177242944, 38.0320907271537, 38.494332184204545, 38.95595771086108, 39.41697621656016, 39.87739636789136, 40.3372265982434, 40.79647511695026, 41.25514991796883, 41.713258788117386, 42.1708093149025, 42.62780889395945, 43.084264736129605, 43.54018387419663, 43.99557316930171, 44.45043931705651, 44.904788853371585, 45.35862816001631, 45.81196346992566, 46.26480087226803, 46.71714631728729, 47.16900562093143, 47.620384469279514, 48.07128842277755, 48.52172292029353, 48.97169328300123, 49.42120471810156, 49.870262322389834, 50.31887108567681], [0.0, 0.7996227513322693, 1.4921488155528797, 2.1492863062118785, 2.7844481463868145, 3.403753855825354, 4.010710063907928, 4.607585240548867, 5.195963967604817, 5.777013746011307, 6.351629285111347, 6.920517306775269, 7.4842496182295895, 8.0432980020872, 8.598058081500302, 9.148866187027021, 9.696011609223563, 10.239745709864223, 10.780288835180377, 11.317835654335326, 11.852559346040469, 12.384614927121573, 12.91414193144556, 13.441266589805664, 13.966103621409927, 14.488757719490897, 15.009324793418891, 15.52789301506561, 16.0445437063789, 16.559352097078573, 17.072387975303535, 17.583716249399558, 18.09339743545895, 18.601488082439133, 19.108041144501616, 19.613106308483918, 20.116730283038386, 20.618957054865234, 21.11982811657286, 21.619382669970985, 22.117657808007372, 22.614688678069435, 23.11050862896729, 23.60514934357866, 24.098640958855153, 24.591012174653873, 25.08229035266024, 25.57250160649975, 26.061670883994285, 26.549822042397178, 27.03697791733721, 27.52316038611301, 28.00839042590241, 28.492688167385193, 28.976072944220327, 29.45856333876904, 29.94017722441152, 30.420931804767438, 30.900843650097052, 31.37992873113071, 31.85820245054895, 32.33567967231269, 32.812374749023284, 33.28830154747428, 33.763473472541335, 34.2379034895425, 34.711604145188915, 35.18458758723478, 35.65686558292549, 36.12844953633413, 36.599350504668365, 37.06957921362271, 37.53914607184479, 38.00806118457824, 38.47633436653975, 38.94397515408306, 39.41099281669832, 39.87739636789136, 40.34319457548408, 40.80839597137358, 41.27300886078508, 41.737041331050946, 42.20050125994539, 42.663396323602804, 43.1257340040451, 43.58752159634173, 44.048766215424614, 44.50947480257825, 44.969654131624125, 45.429310814817185, 45.888451308470714, 46.34708191832508, 46.805208804674784, 47.26283798726704, 47.71997534998455, 48.17662664532406, 48.63279749868181, 49.08849341245589, 49.543719769975425, 49.99848183926538, 50.45278477665548, 50.906633630241274], [0.0, 0.8088432809412662, 1.509354932202152, 2.1740699407340576, 2.816555895366818, 3.4430028806399746, 4.056957961226695, 4.660715764993893, 5.255879145769468, 5.843629067058551, 6.424870555186722, 7.000318481304609, 7.570551246204822, 8.136046072672565, 8.697203145830025, 9.254362674496498, 9.807817285066413, 10.357821237791729, 10.904597419738165, 11.448342744818545, 11.989232388685233, 12.527423155678465, 13.06305618864408, 13.596259173955167, 14.127148153658384, 14.655829028214372, 15.182398812933956, 15.706946696407469, 16.22955493831424, 16.75029963585548, 17.269251381904077, 17.7864758332704, 18.302034203863847, 18.815983694713506, 19.328377870600594, 19.839266991306502, 20.34869830408571, 20.856716302853442, 21.363362958673505, 21.868677925395588, 22.372698723689936, 22.875460906231986, 23.376998206380303, 23.87734267235104, 24.376524788607988, 24.87457358594916, 25.371516741570304, 25.867380670215724, 26.36219060738313, 26.855970685426218, 27.348744003293678, 27.84053269055345, 28.33135796627329, 28.82124019326186, 29.310198928116474, 29.798252967473417, 30.285420390812607, 30.771718600130367, 31.257164356760274, 31.741773815592765, 32.22556255691821, 32.708545616095364, 33.19073751122682, 33.672152269005544, 34.15280344888012, 34.63270416567299, 35.11186711077267, 35.59030457201031, 36.0680284523206, 36.54505028727812, 37.02138126159229, 37.49703222463669, 37.9720137050821, 38.44633592469671, 38.9200088113717, 39.39304201142546, 39.86544490123553, 40.3372265982434, 40.80839597137358, 41.27896165090534, 41.74893203783227, 42.21831531274256, 42.68711944424984, 43.15535219700277, 43.6230211392992, 44.090133650328745, 44.55669692706633, 45.02271799083708, 45.48820369357211, 45.953160723772925, 46.4175956122012, 46.88151473730942, 47.34492433042707, 47.807830480715666, 48.27023913990553, 48.73215612682604, 49.19358713174043, 49.65453772049549, 50.11501333849606, 50.57501931451322, 51.03456086433485, 51.49364309426658], [0.0, 0.8180521460508584, 1.5265392821258754, 2.198822222535472, 2.848623026200712, 3.4822022531844974, 4.103147352299767, 4.713779076274704, 5.3157185277933685, 5.91016011589957, 6.498019170849886, 7.080018702765928, 7.656743697665166, 8.228676811622982, 8.796222785960392, 9.359725702851643, 9.919481520309361, 10.475747393396427, 11.028748746798602, 11.578684736338491, 12.12573253208319, 12.670050723626083, 13.211782060756482, 13.751055683585937, 14.287988955326254, 14.82268898213896, 15.3552538838763, 15.885773864561042, 16.41433212041771, 16.941005615031496, 17.465865744991234, 17.988978914625047, 18.510407034776645, 19.03020795772186, 19.548435858089164, 20.06514156787901, 20.580372872266636, 21.094174771740636, 21.606589715214948, 22.11765780800737, 22.62741699796953, 23.135903242552185, 23.643150659175873, 24.149191660932992, 24.654057079359898, 25.157776275776865, 25.66037724249081, 26.161886694983934, 26.662330156065835, 27.161732032842554, 27.660115687249583, 28.157503500805024, 28.653916934160574, 29.1493765819601, 29.64390222345724, 30.137512869292262, 30.63022680478409, 31.122061630054734, 31.613034297269376, 32.10316114524557, 32.59245793165884, 33.08093986304892, 33.56862162281032, 34.05551739733309, 34.54164090044324, 35.02700539627844, 35.51162372072157, 35.99550830150354, 36.47867117707666, 36.96112401435065, 37.4428781253754, 37.92394448304709, 38.4043337359078, 38.88405622210289, 39.363121982554844, 39.84154077340758, 40.319322077790844, 40.79647511695026, 41.27300886078508, 41.74893203783227, 42.224253144732636, 42.69898045521224, 43.173122028609185, 43.64668571797443, 44.11967917777261, 44.59210987120713, 45.06398507719207, 45.53531189699198, 46.00609726054874, 46.476347932514, 46.946070518003616, 47.41527146809024, 47.883957085048436, 48.35213352736621, 48.81980681453572, 49.286982831635015, 49.753667333712286, 50.21986594998276, 50.68558418784844, 51.15082743674969, 51.615600971857305, 52.0799099576134], [0.0, 0.8272495069561095, 1.5437021644452158, 2.2235435824692775, 2.8806500970683286, 3.521352655786858, 4.14927904112756, 4.7667760980433185, 5.375483155276916, 5.9766080506139545, 6.571076405369788, 7.159619358469382, 7.742828472928448, 8.321191831324994, 8.895118725487016, 9.464957106104913, 10.031006258647475, 10.593526229372147, 11.15274497741461, 11.708863897706532, 12.26206215223821, 12.81250011362595, 13.360322136595054, 13.905658813179441, 14.448628826105601, 14.989340485729716, 15.527893015065608, 16.064377632299937, 16.59887846903245, 17.13147335414998, 17.662234486953263, 18.191229018354342, 18.718519555260585, 19.244164600381005, 19.768218937429463, 20.290733969910637, 20.81175802024852, 21.33133659487224, 21.8495126199489, 22.366326651700426, 22.881817064626166, 23.39602022044652, 23.908970620164215, 24.42070104129207, 24.93124266200543, 25.440625173733913, 25.94887688350197, 26.45602480715398, 26.962094754452515, 27.46711140691273, 27.971098389128365, 28.47407833425296, 28.976072944220327, 29.477103045219934, 29.977188638883575, 30.47634894958817, 30.9746024682345, 31.47196699282275, 31.96845966611132, 32.46409701061509, 32.958894961173144, 33.45286889529236, 33.94603366145267, 34.4384036055417, 34.92999259557003, 35.42081404480404, 35.91088093344044, 36.400205828935135, 36.888800905088765, 37.376677959982125, 37.86384843284649, 38.35032341994631, 38.83611368954524, 39.32122969602044, 39.80568159318445, 40.28947924686955, 40.77263224682431, 41.25514991796883, 41.737041331050946, 42.21831531274256, 42.69898045521224, 43.17904512520754, 43.65851747267771, 44.137405438965565, 44.61571676459491, 45.093458996677924, 45.570639495965544, 46.04726544356182, 46.52334384732201, 46.99888154795271, 47.47388522483113, 47.94836140155931, 48.42231645126831, 48.89575660168602, 49.36868793998173, 49.84111641739947, 50.3130478536914, 50.78448794136203, 51.25544224973311, 51.72591622883845, 52.195915213157626, 52.66544442519656], [0.0, 0.8364355197985341, 1.5608438705305416, 2.2482344402244063, 2.9126376516860013, 3.560454753094582, 4.195353810877315, 4.819707730018183, 5.435174042830664, 6.042973999273252, 6.644043499022565, 7.239121799777288, 7.828807033436415, 8.41359270238515, 8.993892643343882, 9.570058670746029, 10.142393393410996, 10.711159745223537, 11.276588216642136, 11.83888243894483, 12.398223563587404, 12.954773744009122, 13.508678937891041, 14.06007118739802, 14.609070493143156, 15.155786368191505, 15.70031913735734, 16.242761031739903, 16.783197117160054, 17.321706086738633, 17.85836094149786, 18.393229578012527, 18.926375298394827, 19.45785725498444, 19.98773083982909, 20.516048027232532, 21.04285767620465, 21.568205798490848, 22.09213579692254, 22.614688678069435, 23.13590324255219, 23.655816255862046, 24.17446260211064, 24.691875422781575, 25.208086242261487, 25.723125081682035, 26.237020562396893, 26.749800000242026, 27.261489491578917, 27.77211399199326, 28.281697388412976, 28.790262565316553, 29.297831465622217, 29.804425146779348, 30.31006383252353, 30.8147669607046, 31.318553227551536, 31.821440628698575, 32.32344649726215, 32.82458753922782, 33.32487986637965, 33.8243390269807, 34.322980034392636, 34.820817393803885, 35.317865127219335, 35.81413679685008, 36.30964552702861, 36.80440402476342, 37.29842459903648, 37.791719178937825, 38.28429933072318, 38.77617627387307, 39.267360896225, 39.75786376824447, 40.24769515649487, 40.73686503636144, 41.225383104080066, 41.713258788117386, 42.20050125994539, 42.68711944424984, 43.173122028609185, 43.65851747267771, 44.143314016904014, 44.627519690813834, 45.11114232088393, 45.59418953803176, 46.076668784744136, 46.55858732186611, 47.039952235070146, 47.52077044102399, 48.00104869327455, 48.480793587863786, 48.96001156869181, 49.43870893264097, 49.91689183447422, 50.39456629151985, 50.87173818815425, 51.34841328009308, 51.8245971985014, 52.30029545393178, 52.775513440099346, 53.25025643750221], [0.0, 0.8456103367230421, 1.577964684294294, 2.2728952047474156, 2.944586219853078, 3.5995091927428464, 4.241372424670291, 4.87257484888851, 5.494792179095155, 6.109259061074845, 6.716921660338194, 7.318527343462434, 7.91468080322369, 8.505880955208696, 9.092546175490908, 9.675032137537638, 10.25364476946841, 10.82864988927583, 11.400280515656021, 11.968742513507724, 12.53421902132745, 13.096873971206952, 13.65685492182936, 14.214295363723048, 14.769316613781484, 15.322029386312737, 15.872535106588654, 16.42092701738652, 16.96729111760968, 17.511706963559647, 18.054248357002994, 18.594983939268438, 19.1339777068257, 19.671289460853327, 20.206975200991494, 20.74108747164734, 21.27367566776263, 21.804786305783182, 22.33446326462376, 22.862748000652967, 23.389679740093413, 23.91529565171507, 24.439631002271543, 24.962719296773614, 25.484592405397244, 26.005280678574305, 26.524813051604575, 27.04321713994998, 27.560519326221616, 28.076744839741664, 28.5919178294525, 29.10606143085124, 29.619197827546824, 30.131348307966675, 30.64253331767946, 31.15277250774777, 31.66208477947852, 32.17048832589911, 32.678000670252, 33.18463870176984, 33.690418708965986, 34.19535641065158, 34.69946698486904, 35.20276509591345, 35.70526491959633, 36.20698016689195, 36.707924106092904, 37.20810958359019, 37.70754904338235, 38.20625454540897, 38.70423778279543, 39.20151009808814, 39.69808249855272, 40.19396567060155, 40.6891699934114, 41.183705551786986, 41.67758214832168, 42.1708093149025, 42.663396323602804, 43.15535219700277, 43.64668571797443, 44.137405438965565, 44.627519690813834, 45.1170365911204, 45.60596405221024, 46.094309788703946, 46.582081324724555, 47.06928600076096, 47.55593098020799, 48.042023255601954, 48.52756965456904, 49.01257684550288, 49.497051342986346, 49.980999512971984, 50.46442757773399, 50.94734162060444, 51.42974759050511, 51.91165130628582, 52.39305846087957, 52.8739746252839, 53.35440525237729, 53.83435568057938], [0.0, 0.8547741060271344, 1.595064882469395, 2.2975262746435074, 2.9764963179714514, 3.6385166059895684, 4.287335626330097, 4.925378309173978, 5.554338527710392, 6.175464307419843, 6.789712067285596, 7.397837272999338, 8.000451170314205, 8.598058081500298, 9.1910809165182, 9.779879203222354, 10.364762185035548, 10.945998560585425, 11.523823873761431, 12.098446220393452, 12.670050723626083, 13.238803092061845, 13.804852483458141, 14.368333834962845, 14.929369778164833, 15.488072227168738, 16.044543706378896, 16.59887846903245, 17.151163445991674, 17.701479055699394, 18.249899899702324, 18.79649536318634, 19.341330136142588, 19.88446466780722, 20.425955564681217, 20.96585594058864, 21.50421572575782, 22.04108194072724, 22.57649893992177, 23.110508628967285, 23.643150659175877, 24.174462602110637, 24.704480106706406, 25.233237041063404, 25.760765620730552, 26.287096525043406, 26.812259002869826, 27.336280968936904, 27.859189091760673, 28.38100887407019, 28.901764726506787, 29.421480035283956, 29.940177224411517, 30.457877813016818, 30.974602468234497, 31.49037105408315, 32.005202676700705, 32.51911572627003, 33.032127915930694, 33.54425631794176, 34.055517397333084, 34.56592704325852, 35.07550059824297, 35.58425288549657, 36.09219823445226, 36.599350504668365, 37.10572310822424, 37.61132903072555, 38.116180851024836, 38.62029075975367, 39.123670576754336, 39.62633176749092, 40.12828545851336, 40.62954245204129, 41.13011323972928, 41.630008015669766, 42.12923668868555, 42.62780889395945, 43.1257340040451, 43.6230211392992, 44.11967917777261, 44.61571676459491, 45.11114232088393, 45.60596405221024, 46.100189956643646, 46.59382783240709, 47.086885285161536, 47.579369734943825, 48.07128842277754, 48.56264841697622, 49.05345661915613, 49.54371976997542, 50.03344445461467, 50.52263710801339, 51.0113040198758, 51.49945133945821, 51.987085080150116, 52.47421112385944, 52.96083522521278, 53.446963015579826, 53.93260000693122, 54.41775159553833], [0.0, 0.8639269723028192, 1.612144734874072, 2.3221280385579806, 3.0083684495397374, 3.6774776083194913, 4.333244141094504, 4.978118944042481, 5.613814028238018, 6.241590782938376, 6.862415868399918, 7.477052839792479, 8.086119488049498, 8.690125535691577, 9.28949842117202, 9.884601522146465, 10.475747393396427, 11.06320761075721, 11.647220240307114, 12.227995606152817, 12.805720813725667, 13.38056334602527, 13.952673957980718, 14.522189031638208, 15.089232511717801, 15.653917510693182, 16.216347650793427, 16.776618194513294, 17.334817003565156, 17.89102535750736, 18.445318656715195, 18.997767029346655, 19.54843585808916, 20.097386239465404, 20.644675386115154, 21.19035698060188, 21.734481487803603, 22.277096431751705, 22.818246641815403, 23.357974472343315, 23.896319999231242, 24.433321196356165, 24.969014094379425, 25.503432924058693, 26.036610245904914, 26.568577067766004, 27.099362951704823, 27.62899611135757, 28.157503500805028, 28.684910895857854, 29.21124296854495, 29.736523355497887, 30.260774720841344, 30.7840188141281, 31.306276523795145, 31.827567926563713, 32.34791233315903, 32.86732833068486, 33.38583382195194, 33.90344606202798, 34.42018169224933, 34.93605677190987, 35.45108680782128, 35.96528678191968, 36.47867117707666, 36.9912540012578, 37.50304881015815, 38.0140687284324, 38.52432646962664, 39.03383435490894, 39.54260433068769, 40.050647985198445, 40.55797656413351, 41.064600985382015, 41.57053185294247, 42.075779470065015, 42.580353851675476, 43.084264736129605, 43.58752159634173, 44.090133650328745, 44.59210987120713, 45.093458996677924, 45.59418953803176, 46.094309788703946, 46.59382783240709, 47.092751550867, 47.591088631185585, 48.08884657285295, 48.58603269442911, 49.08265413991463, 49.57871788482787, 50.07423074200548, 50.569199367141756, 51.063630264081134, 51.55752978987755, 52.05090415963318, 52.5437594511285, 53.03610160925453, 53.52793645025804, 54.019269665809055, 54.510106826900056, 55.00045338758534], [0.0, 0.8730690765716861, 1.6292045046639165, 2.3467008755392933, 3.040203105623633, 3.7163928000191615, 4.379098676292944, 5.030797566088449, 5.673219597039023, 6.307639506465461, 6.9350341838554606, 7.556175264345337, 8.17168707635296, 8.782084736299781, 9.387800205807192, 9.989200707805397, 10.586602104541122, 11.180278845674287, 11.77047151650644, 12.35739266680103, 12.941231381945366, 13.522156917249786, 14.100321622937114, 14.675863324252948, 15.248907277504541, 15.819567792125575, 16.387949586879042, 16.95414893233062, 17.51825461994828, 18.080348789393383, 18.64050763893053, 19.19880203881624, 19.75529806361973, 20.310057456389142, 20.86313803519033, 21.41459405065746, 21.964476501689578, 22.51283341521897, 23.059710095000746, 23.605149343578663, 24.149191660932996, 24.691875422781575, 25.233237041063408, 25.773311108767192, 26.3121305309603, 26.84972664361673, 27.38612932162609, 27.921367077182225, 28.45546714959491, 28.98845558743529, 29.52035732381251, 30.051196245481773, 30.580995256400282, 31.10977633627532, 31.637560594586017, 32.16436832050615, 32.69021902910769, 33.215131504183745, 33.739123837993205, 34.262213468197494, 34.78441721223213, 35.305751299330986, 35.82623140039935, 36.34587265591269, 36.86468970200083, 37.38269669486212, 37.89990733363841, 38.41633488186994, 38.931992187637974, 39.4468917024936, 39.961045499262504, 40.47446528880732, 40.987162435822675, 41.49914797373115, 42.010432618743124, 42.52102678313808, 43.03094058782013, 43.54018387419663, 44.048766215424614, 44.55669692706633, 45.06398507719207, 45.570639495965544, 46.076668784744136, 46.582081324724555, 47.086885285161536, 47.591088631185585, 48.09469913124377, 48.597724364186064, 49.10017172601771, 49.60204843633734, 50.10336154447848, 50.60411793537146, 51.10432433514134, 51.60398731645646, 52.103113303641315, 52.60170857756651, 53.09977928032779, 53.59733141972521, 54.09437087355326, 54.590903393711415, 55.08693461014458, 55.58247003462204], [0.0, 0.8822005564135441, 1.6462444485719303, 2.3712451553848277, 3.07200076530386, 3.755262766724499, 4.424899921991735, 5.0834149680740905, 5.732556128109646, 6.373611471970378, 7.007568106487495, 7.635205737373723, 8.25715522293387, 8.873937067221762, 9.485987749770308, 10.093678334315525, 10.6973279867256, 11.297214027145285, 11.893579557171671, 12.486639349638448, 13.0765844675879, 13.663585936581418, 14.247797700281602, 14.829359025456238, 15.408396478475527, 15.985025564342113, 16.55935209707857, 17.13147335414998, 17.701479055699394, 18.269452200491635, 18.83546978375335, 19.399603416977158, 19.961919865810003, 20.52248151907414, 21.081346799557902, 21.638570525305965, 22.19420422861781, 22.748296438742177, 23.300892933268756, 23.85203696241559, 24.40176944975458, 24.950129172377398, 25.497152923057627, 26.042875656594035, 26.58733062220998, 27.13054948362423, 27.67256242818958, 28.213398266310563, 28.75308452219446, 29.291647516855924, 29.829112444180936, 30.36550344075764, 30.900843650097052, 31.435155281793485, 31.968459666111322, 32.50077730442998, 33.0321279159307, 33.562530480867366, 34.09200328072684, 34.620563935552056, 35.14822943867306, 35.67501618906623, 36.200940021539736, 36.72601623492417, 37.250259618429475, 37.77368447631448, 38.29630465100118, 38.818133544753934, 39.33918414003283, 39.85946901862044, 40.379000379612826, 40.89779005635724, 41.415849532412274, 41.93318995659972, 42.449822157211436, 42.96575665542952, 43.48100367801321, 43.99557316930171, 44.50947480257825, 45.02271799083708, 45.53531189699198, 46.04726544356182, 46.55858732186611, 47.06928600076096, 47.579369734943825, 48.08884657285295, 48.597724364186064, 49.10601076706074, 49.61371325483749, 50.12083912262514, 50.6273954934866, 51.133389324362085, 51.63882741172557, 52.14371639698933, 52.64806277167024, 53.15187288233089, 53.65515293530755, 54.15790900123622, 54.660147019387566, 55.16187280182052, 55.663092037363896, 56.16381029543491], [0.0, 0.8913215460890002, 1.6632648171372644, 2.395761238970363, 3.1037618961030056, 3.794088079942577, 4.470648551608892, 5.13597192363571, 5.791824493877883, 6.439507649442247, 7.080018702765929, 7.7141454208666485, 8.342525184434681, 8.965683878966953, 9.584062496717756, 10.198035937816638, 10.807926667958073, 11.41401487447405, 12.01654617236651, 12.61573755498554, 13.211782060756484, 13.804852483458141, 14.395104358362348, 14.98267839210308, 15.567702459608492, 16.150293260076733, 16.73055770153173, 17.30859406718125, 17.884493004776584, 18.45833837119907, 19.03020795772186, 19.600174116222153, 20.16830430263072, 20.734661550802056, 21.29930488755228, 21.86228969768475, 22.4236680462866, 22.983488964345977, 23.541798702742817, 24.098640958855153, 24.6540570793599, 25.208086242261484, 25.760765620730556, 26.3121305309603, 26.862214565934718, 27.41104971674082, 27.958666482835646, 28.50509397249182, 29.050359994486854, 29.59449114196593, 30.13751286929227, 30.679449562599963, 31.22032460467865, 31.760160434745565, 32.29897860359672, 32.8367998245734, 33.373644020731604, 33.909530368560326, 34.44447733855702, 34.9785027329366, 35.51162372072157, 36.04385687043582, 36.575218180602114, 37.10572310822425, 37.63538659541642, 38.16422309432788, 38.692246590496126, 39.21947062475029, 39.745908313774905, 40.27157236943444, 40.79647511695026, 41.320628512013506, 41.844044156910215, 42.36673331572881, 42.88870692871386, 43.409975625824984, 43.930549739554934, 44.45043931705651, 44.969654131624125, 45.48820369357211, 46.00609726054874, 46.52334384732201, 47.039952235070146, 47.55593098020799, 48.07128842277754, 48.58603269442911, 49.10017172601771, 49.61371325483749, 50.12666483151535, 50.63903382658355, 51.150827436749694, 51.66205269088115, 52.17271645572003, 52.682825441343525, 53.19238620638372, 53.70140516301972, 54.209888581754534, 54.71784259598789, 55.22527320639604, 55.73218628512824, 56.2385875798296, 56.74448271749898], [0.0, 0.900432176656329, 1.6802658549233076, 2.4202494785642092, 3.1354869543924897, 3.8328692975491037, 4.516345222500325, 5.188469187957138, 5.8510255459629175, 6.505328985734391, 7.152387013723644, 7.792995449097819, 8.427798187524894, 9.057326489832963, 9.682025855872398, 10.302275017809118, 10.918399737416125, 11.530683065956259, 12.139373128981727, 12.74468913783707, 13.34682610408717, 13.945958587719984, 14.54224371380893, 15.135823627218853, 15.726827509949674, 16.315373254038743, 16.901568860268842, 17.48551361644816, 18.067299096882685, 18.647010015595686, 19.224724959002714, 19.800517018524655, 20.37445433959212, 20.946600600359258, 21.517015430983953, 22.08575478238454, 22.652871251830717, 23.21841437148017, 23.78243086496556, 24.344964876317043, 24.906058174836012, 25.465750338984307, 26.024078921897615, 26.581079600753096, 27.13678631190496, 27.691231373436658, 28.244445596554996, 28.7964583870624, 29.347297837983405, 29.896990814284653, 30.445563030510773, 30.993039122058388, 31.53944271072398, 32.08479646508693, 32.62912215622441, 33.172440709198824, 33.71477225070942, 34.25613615325739, 34.79655107613611, 35.33603500352559, 35.874605279941264, 36.41227864326193, 36.94907125553905, 37.484998731769956, 38.020076166799456, 38.554318160499236, 39.08773884135977, 39.620351888617584, 40.152170553029215, 40.68320767639327, 41.213475709913205, 41.742986731485075, 42.27175246198752, 42.79978428064469, 43.3270932395267, 43.85369007724716, 44.379585231912245, 44.904788853371585, 45.429310814817185, 45.953160723772925, 46.476347932514, 46.99888154795271, 47.52077044102399, 48.042023255601954, 48.56264841697622, 49.08265413991463, 49.60204843633734, 50.12083912262514, 50.63903382658355, 51.15663999408262, 51.673664895391006, 52.19011563122154, 52.70599913850464, 53.221322195904456, 53.73609142909204, 54.250313315788496, 54.76399419059069, 55.27714024959081, 55.78975755480093, 56.3018520383924, 56.81342950675979, 57.32449564441828], [0.0, 0.9095325760829622, 1.6972478007257303, 2.4447102181268754, 3.167176385780791, 3.871606964262994, 4.561990576519039, 5.240907498412153, 5.910160115899571, 6.571076405369788, 7.224674055842078, 7.871756929590528, 8.51297542994457, 9.14886618702702, 9.779879203222356, 10.406397038429523, 11.028748746798602, 11.647220240307114, 12.26206215223821, 12.873495909440102, 13.481718494401388, 14.086906231335764, 14.68921783333289, 15.288796881873363, 15.885773864561044, 16.48026786493294, 17.07238797530353, 17.662234486953263, 18.249899899702324, 18.83546978375335, 19.419023519771343, 20.00063493789039, 20.580372872266633, 21.158301644630335, 21.734481487803603, 22.308968918184007, 22.881817064626162, 23.453075959894505, 24.022792799843504, 24.591012174653873, 25.157776275776865, 25.723125081682035, 26.287096525043406, 26.84972664361673, 27.41104971674082, 27.97109838912836, 28.529903783385837, 29.087495602511346, 29.643902223457243, 30.19915078270637, 30.753267254692595, 31.306276523795145, 31.85820245054895, 32.40906793263797, 32.95889496117315, 33.50770467270026, 34.055517397333084, 34.60235270336492, 35.14822943867306, 35.69316576919825, 36.23717921475176, 36.78028668237715, 37.322504497470916, 37.86384843284649, 38.4043337359078, 38.943975154083056, 39.48278695865519, 40.02078296711269, 40.55797656413351, 41.094380721304525, 41.630008015669766, 42.16487064719298, 42.69898045521224, 43.23234893395812, 43.76498724720071, 44.296906242085576, 44.828116462213735, 45.35862816001631, 45.888451308470714, 46.4175956122012, 46.946070518003616, 47.47388522483113, 48.00104869327455, 48.52756965456904, 49.05345661915613, 49.57871788482787, 50.10336154447848, 50.6273954934866, 51.150827436749694, 51.673664895391006, 52.19591521315762, 52.71758556252716, 53.23868295053954, 53.75921422436884, 54.279186076649786, 54.79860505057188, 55.317477544753864, 55.83580981791, 56.35360799331929, 56.87087806310779, 57.38762589235355, 57.90385722302345], [0.0, 0.9186228693518994, 1.7142108877710571, 2.469143793597089, 3.1988306254839918, 3.910301612099335, 4.607585240548866, 5.293287575177642, 5.9692290158297725, 6.6367508113098745, 7.296880821896487, 7.950430944038626, 8.5980580815003, 9.240304227736353, 9.877623882665219, 10.51040342966811, 11.13897521161593, 11.763627998024013, 12.384614927121572, 13.002159638800137, 13.616461084283275, 14.227697350051209, 14.836028735446327, 15.441600256969588, 16.0445437063789, 16.644979357387736, 17.24301739263012, 17.838759105744373, 18.432297921037087, 19.023720263939452, 19.613106308483918, 20.200530622697386, 20.78606272869671, 21.369767591073558, 21.951706044644983, 22.53193517065983, 23.110508628967285, 23.6874769523826, 24.262887808457656, 24.836786233028246, 25.409214839226692, 25.98021400508604, 26.549822042397178, 27.118075349094003, 27.685008547119054, 28.25065460745152, 28.815044963751742, 29.378209615883453, 29.940177224411517, 30.500975197033465, 31.06062976778378, 31.61916606974779, 32.17660820193377, 32.7329792908758, 33.288301547474276, 33.842596319523466, 34.39588414032582, 34.94818477374928, 35.49951725604563, 36.049899934714496, 36.59935050466836, 37.14788604192763, 37.69552303505246, 38.24227741449713, 38.78816458005526, 39.333199426547736, 39.87739636789135, 40.420769359673024, 40.96333192034346, 41.505097151133576, 42.04607775478829, 42.58628605320349, 43.1257340040451, 43.66443321642241, 44.20239496568144, 44.7396302073792, 45.27614959049437, 45.81196346992566, 46.34708191832508, 46.88151473730942, 47.41527146809024, 47.94836140155931, 48.480793587863786, 49.01257684550288, 49.54371976997542, 50.07423074200548, 50.60411793537146, 51.133389324362085, 51.66205269088115, 52.19011563122154, 52.71758556252716, 53.244469728960745, 53.770775207593815, 54.29650891403431, 54.82167760780628, 55.34628789749492, 55.870346245669744, 56.39385897359753, 56.9168322657562, 57.4392721741599, 57.96118462250502, 58.482575410146346], [0.0, 0.9277031785633284, 1.7311553439062946, 2.4935505331649384, 3.2304500986796416, 3.9489537608019485, 4.653129827014167, 5.345610121819157, 6.028233039162882, 6.702353085688709, 7.369008281763136, 8.02901854918601, 8.683047285016352, 9.331641840150375, 9.975261207100733, 10.614295588531498, 11.249080612422329, 11.879907902687872, 12.507033099752176, 13.130682054119452, 13.751055683585937, 14.368333834962845, 14.98267839210308, 15.59423580495185, 16.203139167988724, 16.80950994379646, 17.413459404131086, 18.015089843887907, 18.614495610844525, 19.211763984721376, 19.806975932046967, 20.400206757930597, 20.991526671694217, 21.581001280084827, 22.168692019253253, 22.754656534679217, 23.33894901662329, 23.92162049740231, 24.50271911574749, 25.082290352660245, 25.660377242490814, 26.237020562396893, 26.81225900286983, 27.38612932162609, 27.958666482835646, 28.52990378338584, 29.09987296764924, 29.668604332029155, 30.23612682039147, 30.802468111350507, 31.367654698256253, 31.93171196262698, 32.494664241682365, 33.05653489055529, 33.61734633969419, 34.177120147909804, 34.73587705147008, 35.293637009602804, 35.85041924672736, 36.406242291702874, 36.96112401435065, 37.515081659482426, 38.06813187864276, 38.62029075975368, 39.17157385483108, 39.72199620592667, 40.27157236943444, 40.82031643888806, 41.368242066364026, 41.915362482594986, 42.461690515888634, 43.00723860993906, 43.55201884061012, 44.09604293176362, 44.63932227019898, 45.18186791976557, 45.723690634704006, 46.26480087226803, 46.805208804674784, 47.34492433042707, 47.883957085048436, 48.42231645126831, 48.96001156869181, 49.497051342986346, 50.03344445461467, 50.569199367141756, 51.10432433514134, 51.63882741172557, 52.17271645572003, 52.70599913850464, 53.23868295053954, 53.770775207593815, 54.30228305669369, 54.83321348180582, 55.363573309270095, 55.893369212995566, 56.42260771943231, 56.9512952123309, 57.47943793730096, 58.00704200617896, 58.53411340121525, 59.06065797908946], [0.0, 0.9367736230317177, 1.7480813917801143, 2.5179307575328465, 3.262035220844852, 3.987563918256687, 4.698624934366823, 5.397875825850386, 6.087172961206607, 6.767884090514438, 7.44105738319054, 8.107520777666936, 8.767944157243425, 9.422880224437321, 10.072792459474803, 10.71807488015357, 11.359066395993132, 11.99606148220647, 12.629318278694102, 13.259064844171343, 13.885504060870637, 14.508817534021784, 15.12916873026681, 15.746705531437895, 16.36156233332101, 16.973861786076622, 17.583716249399558, 18.191229018354342, 18.79649536318634, 19.399603416977158, 20.00063493789039, 20.599665967316977, 21.19676740103739, 21.792005487256343, 22.385442262805146, 22.977135936781423, 23.56714122928089, 24.155509671579328, 24.742289873075407, 25.327527759452522, 25.91126678582124, 26.493548128030287, 27.074410854860066, 27.653892083418743, 28.232027119731935, 28.808849586241067, 29.384391537693386, 29.958683566709624, 30.5317549001489, 31.10363348724802, 31.674346080390745, 32.243918309258405, 32.812374749023284, 33.37973898316873, 33.94603366145267, 34.51128055347311, 35.07550059824297, 35.638713950137664, 36.200940021539736, 36.76219752247077, 37.322504497470916, 37.88187835995983, 38.44033592428944, 38.99789343567842, 39.55456659819959, 40.11037060097553, 40.66532014272262, 41.21942945477145, 41.77271232267913, 42.32518210653933, 42.87685176008611, 43.42773384867947, 43.977840566252766, 44.527183751295674, 45.0757749019399, 45.62362519020955, 46.170745475492815, 46.71714631728729, 47.26283798726704, 47.807830480715666, 48.35213352736621, 48.89575660168602, 49.43870893264097, 49.980999512971984, 50.52263710801339, 51.063630264081134, 51.60398731645646, 52.14371639698933, 52.682825441343525, 53.221322195904456, 53.75921422436884, 54.29650891403431, 54.83321348180582, 55.36933497993445, 55.90488030150335, 56.439856185674465, 56.974269222709026, 57.50812585877353, 58.04143240054289, 58.574195019610904, 59.10641975671825, 59.63811252580718], [0.0, 0.9458343193786323, 1.764989249016051, 2.5422847801650454, 3.293586398079498, 4.02613258088652, 4.744071147551774, 5.450085359267965, 6.1460495397701065, 6.833344668339855, 7.513029052536714, 8.18593863880931, 8.852749789727374, 9.51402055367787, 10.170218893777491, 10.821742638857398, 11.468933976450241, 12.112090230003002, 12.751472036206456, 13.387309659613823, 14.019807944782555, 14.64915025347124, 15.275501633409986, 15.899011396779075, 16.519815239272354, 17.138036997351684, 17.753790117481472, 18.367178893820583, 18.978299518090747, 19.587240975817608, 20.194085815949087, 20.79891081536647, 21.401787555571005, 22.00278292553573, 22.60195956212688, 23.19937623745426, 23.795088200879313, 24.389147482100523, 24.981603160678173, 25.57250160649975, 26.161886694983934, 26.749800000242022, 27.336280968936908, 27.921367077182225, 28.50509397249182, 29.087495602511346, 29.668604332029155, 30.248451049565045, 30.827065264667244, 31.404475196904198, 31.98070785741506, 32.5557891237775, 33.1297438088607, 33.70259572425303, 34.27436773878625, 34.84508183261908, 35.41475914729153, 35.98342003211689, 36.55108408723888, 37.117770203646835, 37.68349660041198, 38.248280859380685, 38.81213995753727, 39.37509029722802, 39.93714773441927, 40.498327605146365, 41.05864475029518, 41.618113538845094, 42.17674788969039, 42.73456129214672, 43.29156682523975, 43.8477771758646, 44.403204655897234, 44.95786121833201, 45.5117584725133, 46.064907698523655, 46.61731986078585, 47.16900562093143, 47.71997534998455, 48.27023913990553, 48.81980681453572, 49.36868793998173, 49.91689183447422, 50.46442757773399, 51.0113040198758, 51.55752978987755, 52.103113303641315, 52.64806277167024, 53.19238620638372, 53.73609142909204, 54.279186076649786, 54.82167760780628, 55.363573309270095, 55.90488030150335, 56.445605544260715, 56.98575584188693, 57.52533784838578, 58.06435807227262, 58.60282288122199, 59.14073850652084, 59.67811104733731, 60.21494647481469], [0.0, 0.9548853816214999, 1.781879128378148, 2.566612907526173, 3.325104027415325, 4.064660234029389, 4.789469038452257, 5.502239379062978, 6.204863515740816, 6.898735642903712, 7.58492419547428, 8.264273119402944, 8.937465249640054, 9.605063974758036, 10.267541735997513, 10.925300169170889, 11.578684736338491, 12.227995606152819, 12.873495909440102, 13.515418114246037, 14.153969025366562, 14.789333759221373, 15.421678942947505, 16.051155317552478, 16.67789987725584, 17.302037643559473, 17.923683148541816, 18.542941684393742, 19.15991036333357, 19.774679022424586, 20.38733100055821, 20.997943809324024, 21.606589715214948, 22.213336247291025, 22.818246641815403, 23.42138023331143, 24.022792799843508, 24.62253686900286, 25.220661990011475, 25.817214976488604, 26.41224012371415, 27.005779403638495, 27.597872640405235, 28.18855766875174, 28.777870477317006, 29.365845338605112, 29.95251492711585, 30.537910426953474, 31.122061630054734, 31.70499702603227, 32.2867438845055, 32.86732833068486, 33.446775414883675, 34.02510917655282, 34.60235270336492, 35.17852818581553, 35.753656967756406, 36.32775959323146, 36.90085584994593, 37.47296480966448, 38.04410486580384, 38.614293768458, 39.18354865707076, 39.75188609094892, 40.319322077790844, 40.88587210038844, 41.45155114164589, 42.01637370804501, 42.580353851675476, 43.143505190937546, 43.70584093001523, 44.267373877209565, 44.828116462213735, 45.38808075240501, 45.94727846822216, 46.50572099769131, 47.06341941015812, 47.620384469279514, 48.17662664532406, 48.73215612682604, 49.286982831635015, 49.84111641739947, 50.39456629151985, 50.94734162060444, 51.49945133945821, 52.05090415963318, 52.60170857756651, 53.15187288233089, 53.70140516301972, 54.250313315788496, 54.79860505057188, 55.34628789749492, 55.893369212995566, 56.439856185674465, 56.98575584188693, 57.53107505109116, 58.07582053096573, 58.61999885230854, 59.16361644372895, 59.70667959614353, 60.24919446708578, 60.791167084839216], [0.0, 0.9639269212585512, 1.7987512379294615, 2.590915439309578, 3.356588497111722, 4.103147352299768, 4.834819166315834, 5.554338527710393, 6.263615613636374, 6.964057819744384, 7.656743697665166, 8.34252518443468, 9.022091580574314, 9.696011609223563, 10.36476218503555, 11.028748746798604, 11.688320027655603, 12.343779038471132, 12.995391401582799, 13.643391786210485, 14.287988955326254, 14.929369778164833, 15.567702459608492, 16.203139167988724, 16.83581819468459, 17.465865744991238, 18.093397435458954, 18.71851955526059, 19.341330136142595, 19.961919865810007, 20.580372872266636, 21.196767401037395, 21.811176402886176, 22.423668046286604, 23.034306166268117, 23.643150659175877, 24.250257831221013, 24.855680707363653, 25.459469305993352, 26.06167088399429, 26.662330156065842, 27.26148949157892, 27.85918909176068, 28.455467149594913, 29.050359994486858, 29.643902223457246, 30.236126820391473, 30.82706526466725, 31.416747630312756, 32.00520267670071, 32.59245793165885, 33.17853976776984, 33.763473472541335, 34.34728331304697, 34.929992595570035, 35.51162372072158, 36.09219823445227, 36.67173687533176, 37.250259618429475, 37.82778571609523, 38.4043337359078, 38.97992159603181, 39.5545665981996, 40.12828545851337, 40.70109433624383, 41.2730088607851, 41.844044156910215, 42.414214868458785, 42.98353518057574, 43.55201884061012, 44.119679177772625, 44.686529121642465, 45.25258121960607, 45.8178476533033, 46.38234025415045, 46.94607051800363, 47.50904961902102, 48.07128842277755, 48.63279749868181, 49.19358713174043, 49.753667333712286, 50.3130478536914, 50.87173818815425, 51.42974759050511, 51.987085080150116, 52.5437594511285, 53.09977928032779, 53.65515293530755, 54.209888581754534, 54.76399419059069, 55.317477544753864, 55.870346245669744, 56.42260771943231, 56.974269222709026, 57.52533784838578, 58.07582053096573, 58.62572405173524, 59.17505504370926, 59.72381999636781, 60.272025260194376, 60.81967705102641, 61.366781454227535], [0.0, 0.9729590473501307, 1.8156057811837896, 2.6151926686558755, 3.3880401869388668, 4.141594399934784, 4.880122078162237, 5.606383433637595, 6.322306542132991, 7.029311986787313, 7.728488425406481, 8.42069577779212, 9.106629803305069, 9.786864554097832, 10.461881413578569, 11.132089619552085, 11.797841172838147, 12.459441923554266, 13.117159982955412, 13.771232219143908, 14.421869351229201, 15.069259999436111, 15.713573944749493, 16.35496478133875, 16.993572096391954, 17.629523277764974, 18.262935025350885, 18.89391462426651, 19.52256102482907, 20.148965764499707, 20.773213759573046, 21.395383988745188, 22.01555008633859, 22.633780859574717, 23.250140741625906, 23.864690190074207, 24.477486038727577, 25.088581809397233, 25.698027989151814, 26.30587227767893, 26.912159808660757, 27.516933348474964, 28.120233475039655, 28.72209873921207, 29.322565810808907, 29.921669611029674, 30.51944343282325, 31.115919050533392, 31.711126819986, 32.30509577003303, 32.89785368644168, 33.48942718890932, 34.07984180189096, 34.66912201984603, 35.257291367440835, 35.84437245518321, 36.4303870309123, 37.01535602752098, 37.59929960724776, 38.18223720283961, 38.76418755585602, 39.34516875235727, 39.925198256195266, 40.504292940104364, 41.08246911476983, 41.65974255603532, 42.236128530395064, 42.81164181890341, 43.386296739622054, 43.960107168714536, 44.533086560288076, 45.10524796507381, 45.676604048028864, 46.24716710493673, 46.816949078075666, 47.38596157101953, 47.95421586262986, 48.52172292029353, 49.08849341245589, 49.65453772049549, 50.21986594998276, 50.78448794136203, 51.34841328009308, 51.91165130628582, 52.47421112385944, 53.03610160925453, 53.59733141972521, 54.15790900123622, 54.71784259598789, 55.27714024959081, 55.83580981791, 56.39385897359753, 56.9512952123309, 57.50812585877353, 58.06435807227262, 58.61999885230854, 59.17505504370926, 59.729533341641954, 60.283440296393955, 60.83678231795366, 61.38956568040174, 61.94179652612251], [0.0, 0.9819818665965754, 1.832442957251002, 2.639444882362274, 3.419459468448913, 4.18000183112572, 4.925378309173978, 5.658374711673134, 6.380936994571502, 7.094498914907654, 7.800159226249128, 8.498785822937645, 9.191080916518201, 9.877623882665217, 10.55890056893721, 11.235324008240898, 11.907249465705867, 12.574985627776947, 13.238803092061847, 13.898940923279566, 14.555611794661306, 15.209006075617735, 15.859295121612238, 16.50663395118294, 17.151163445991678, 17.793012175236544, 18.432297921037087, 19.069128963427865, 19.703605170350368, 20.335818928146235, 20.965855940588643, 21.593795918789407, 22.219713179925197, 22.843677169307156, 23.46575291763417, 24.086001443146866, 24.704480106706406, 25.321242926463107, 25.93634085768178, 26.549822042397178, 27.161732032842558, 27.77211399199326, 28.381008874070194, 28.98845558743529, 29.59449114196593, 30.199150782706372, 30.802468111350507, 31.4044751969042, 32.005202676700705, 32.60467984879353, 33.202934756623584, 33.799994266748264, 34.39588414032582, 34.99062909896714, 35.58425288549656, 36.17677832010239, 36.76822735230422, 37.35862110911791, 37.94797993975823, 38.53632345718338, 39.123670576754336, 39.710039552253974, 40.29544800948677, 40.879912977657796, 41.463450918710876, 42.0460777547883, 42.62780889395945, 43.20865925435205, 43.788643286807556, 44.36777499617131, 44.94606796131837, 45.52353535400691, 46.10018995664365, 46.67604417903808, 47.2511100742162, 47.825399353358605, 48.398923399922325, 48.97169328300123, 49.543719769975425, 50.11501333849606, 50.68558418784844, 51.25544224973311, 51.8245971985014, 52.39305846087957, 52.96083522521278, 53.52793645025804, 54.09437087355326, 54.660147019387566, 55.22527320639604, 55.78975755480093, 56.35360799331929, 56.9168322657562, 57.47943793730096, 58.04143240054289, 58.60282288122199, 59.16361644372895, 59.72381999636781, 60.283440296393955, 60.84248395483939, 61.400957441136065, 61.958867087547894, 62.5162190934211], [0.0, 0.9909954834128344, 1.849262960976283, 2.6636723610831443, 3.4508467052358314, 4.21837009033565, 4.970588383070635, 5.710312963476703, 6.439507649442247, 7.159619358469382, 7.8717569295905285, 8.576796223554222, 9.275445897508996, 9.968290645221689, 10.655820773848163, 11.338453107526398, 12.01654617236651, 12.690411488247863, 13.360322136595052, 14.026519376503419, 14.689217833332892, 15.348609623895976, 16.00486767652878, 16.65814843268542, 17.308594067181254, 17.95633432935174, 18.60148808243913, 19.244164600381005, 19.88446466780722, 20.522481519074137, 21.158301644630335, 21.792005487256343, 22.423668046286597, 23.053359404471127, 23.681145189425944, 24.30708697947844, 24.931242662005427, 25.553666750990114, 26.17441066941596, 26.793523001213714, 27.41104971674082, 28.027034375165805, 28.641518306628594, 29.254540776631178, 29.866139134764804, 30.476348949588175, 31.085204131225314, 31.69273704304366, 32.29897860359672, 32.90395837986499, 33.50770467270026, 34.11024459526821, 34.711604145188915, 35.31180827099304, 35.91088093344044, 36.508845162186056, 37.10572310822424, 37.701536092495836, 38.29630465100117, 38.8900485767259, 39.48278695865519, 40.07453821812349, 40.66532014272262, 41.25514991796883, 41.84404415691021, 42.432018927838485, 43.01908978025378, 43.60527176921739, 44.190579478215135, 44.775027040642904, 45.35862816001631, 45.941396128997184, 46.52334384732201, 47.10448383870999, 47.684828266821924, 48.26438895033538, 48.84317737719622, 49.42120471810156, 49.99848183926538, 50.57501931451322, 51.15082743674969, 51.72591622883845, 52.30029545393178, 52.8739746252839, 53.446963015579826, 54.019269665809055, 54.590903393711415, 55.16187280182052, 55.73218628512824, 56.3018520383924, 56.87087806310779, 57.4392721741599, 58.00704200617896, 58.574195019610904, 59.14073850652084, 59.70667959614353, 60.272025260194376, 60.83678231795366, 61.400957441136065, 61.9645571585565, 62.527587860602765, 63.090055803524926], [0.0, 1.0000000000000002, 1.8660659830736153, 2.6878753795222874, 3.4822022531844974, 4.256699612603924, 5.015752812467623, 5.762198777951312, 6.4980191708498865, 7.224674055842079, 7.943282347242818, 8.654727864164498, 9.359725702851645, 10.058865869794328, 10.752643127243298, 11.441478086740144, 12.12573253208319, 12.805720813725669, 13.48171849440139, 14.153969025366562, 14.822688982138962, 15.488072227168738, 16.150293260076733, 16.80950994379646, 17.465865744991238, 18.119491591942396, 18.770507427923384, 19.419023519771347, 20.065141567879014, 20.70895565376131, 21.35055305374797, 21.99001494154955, 22.62741699796953, 23.262829942553264, 23.896319999231245, 24.52794930585215, 25.157776275776868, 25.7858559183209, 26.41224012371415, 27.03697791733721, 27.660115687249583, 28.281697388412972, 28.901764726506787, 29.520357323812508, 30.137512869292266, 30.753267254692595, 31.36765469825625, 31.98070785741506, 32.59245793165884, 33.202934756623584, 33.81216689031209, 34.42018169224933, 35.02700539627845, 35.63266317762081, 36.23717921475177, 36.8405767465814, 37.44287812537541, 38.044104865803845, 38.644277690463994, 39.24341657218722, 39.84154077340758, 40.438668882841945, 41.03481884970614, 41.63000801566977, 42.22425314473264, 42.817570451188345, 43.409975625824984, 44.001483860499164, 44.592109871207136, 45.181867919765565, 45.77077183420479, 46.358835027968205, 46.94607051800363, 47.53249094182496, 48.11810857361609, 48.70293533944306, 49.28698283163503, 49.870262322389834, 50.45278477665548, 51.03456086433485, 51.615600971857305, 52.195915213157626, 52.775513440099346, 53.35440525237729, 53.93260000693122, 54.510106826900056, 55.08693461014458, 55.663092037363896, 56.2385875798296, 56.81342950675979, 57.38762589235355, 57.96118462250502, 58.53411340121525, 59.10641975671825, 59.67811104733731, 60.24919446708578, 60.81967705102641, 61.38956568040174, 61.958867087547894, 62.527587860602765, 63.095734448019364, 63.663313162894134], [0.0, 1.0089955164139086, 1.8828522102537901, 2.7120542066173208, 3.5135264607095675, 4.294990823838181, 5.060872099220283, 5.8140327316385765, 6.556472208959159, 7.289663729896545, 8.01473627397775, 8.7325816107245, 9.443921269041327, 10.149350562831366, 10.849368704987315, 11.54440009066879, 12.234809758106207, 12.920914885497467, 13.60299351440547, 14.281291286056199, 14.956026724176052, 15.627395435108035, 16.295573488187188, 16.96072016640564, 17.62298022698343, 18.28248577596939, 18.93935783558866, 19.593707664585526, 20.245637878200267, 20.895243404259624, 21.542612304188985, 22.18782648189835, 22.830962298979117, 23.472091111135462, 24.11127973801634, 24.74859087643246, 25.384083465203055, 26.017813008480836, 26.649831863275114, 27.280189495975097, 27.908932711924844, 28.536105861483634, 29.161751025495, 29.78590818266331, 30.408615360982363, 31.029908775063497, 31.64982295096023, 32.26839083987485, 32.885643921952706, 33.501612301216724, 34.11632479256371, 34.72980900163167, 35.34209139825073, 35.953197384106375, 36.56315135517181, 37.17197675940313, 37.779696150136196, 38.38633123557664, 38.9919029247322, 39.59643137010018, 40.19993600739017, 40.80243559253416, 41.40394823621043, 42.00449143608587, 42.604082106961116, 43.202736608985695, 43.80047077409446, 44.39729993080261, 44.99323892748439, 45.588302154248865, 46.18250356351663, 46.775856689391965, 47.36837466591683, 47.96007024428611, 48.55095580909629, 49.141043393694545, 49.73034469468903, 50.31887108567681, 50.906633630241274, 51.49364309426658, 52.0799099576134, 52.66544442519656, 53.25025643750221, 53.83435568057938, 54.41775159553833, 55.00045338758534, 55.58247003462204, 56.16381029543491, 56.74448271749898, 57.32449564441828, 57.90385722302345, 58.482575410146346, 59.06065797908946, 59.63811252580718, 60.21494647481469, 60.791167084839216, 61.366781454227535, 61.94179652612251, 62.5162190934211, 63.090055803524926, 63.663313162894134, 64.23599754141475]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 1.9000000000000001\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.01258925411794167, 0.024320835813173142, 0.035749106525291105, 0.04698475772352076, 0.0580793174820771, 0.06906272143876586, 0.07995454165804432, 0.09076856878176184, 0.10151503857049493, 0.11220184543019633, 0.12283526041804774, 0.13342038322424146, 0.14396144085549922, 0.15446199290007995, 0.16492507722311722, 0.17535331622163475, 0.18574899612593704, 0.19611412737489595, 0.20645049138657176, 0.21675967734687362, 0.22704311154071619, 0.23730208102147282, 0.24753775291987262, 0.2577511903507397, 0.2679433656340733, 0.2781151713733844, 0.28826742980774844, 0.2984009007606376, 0.3085162884387364, 0.318614247281089, 0.3286953870184948, 0.3387602770718469, 0.34880945039376376, 0.35884340683872595, 0.36886261613176147, 0.3788675204936131, 0.38885853697058087, 0.3988360595093512, 0.4088004608107063, 0.41875209399074625, 0.4286912940739267, 0.4386183793386273, 0.4485336525329833, 0.4584374019762154, 0.46832990255860013, 0.47821141665145445, 0.4880821949370129, 0.4979424771668052, 0.507792492856054, 0.5176324619206887, 0.5274625952627684, 0.5372830953094224, 0.5470941565098245, 0.5568959657941943, 0.5666887029983826, 0.5764725412571948, 0.5862476473692739, 0.5960141821360636, 0.6057723006771053, 0.6155221527236963, 0.6252638828927287, 0.6349976309423525, 0.6447235320109391, 0.6544417168406867, 0.6641523119870781, 0.6738554400152905, 0.6835512196845535, 0.6932397661213675, 0.7029211909824057, 0.7125956026078565, 0.7222631061658954, 0.7319238037889187, 0.7415777947021138, 0.7512251753448985, 0.7608660394857152, 0.7705004783306278, 0.7801285806261317, 0.7897504327565577, 0.7993661188364192, 0.8089757207980267, 0.818579318474666, 0.8281769896796203, 0.8377688102812881, 0.847354854274638, 0.8569351938492177, 0.8665098994539242, 0.8760790398587238, 0.8856426822134986, 0.8952008921041874, 0.9047537336063698, 0.9143012693364417, 0.9238435605005114, 0.9333806669411454, 0.9429126471820781, 0.9524395584709954, 0.9619614568204952, 0.9714783970473183, 0.9809904328099454, 0.9904976166446369, 1.0, 1.0094976332701566], [0.0, 0.024320835813173142, 0.04698475772352076, 0.06906272143876586, 0.09076856878176186, 0.11220184543019633, 0.13342038322424146, 0.15446199290007995, 0.17535331622163478, 0.19611412737489597, 0.21675967734687362, 0.23730208102147285, 0.2577511903507397, 0.27811517137338443, 0.2984009007606376, 0.31861424728108906, 0.3387602770718469, 0.35884340683872595, 0.37886752049361316, 0.3988360595093512, 0.41875209399074625, 0.4386183793386273, 0.45843740197621546, 0.4782114166514545, 0.4979424771668052, 0.5176324619206887, 0.5372830953094225, 0.5568959657941943, 0.5764725412571948, 0.5960141821360637, 0.6155221527236963, 0.6349976309423525, 0.6544417168406867, 0.6738554400152905, 0.6932397661213676, 0.7125956026078565, 0.7319238037889187, 0.7512251753448985, 0.7705004783306278, 0.7897504327565578, 0.8089757207980267, 0.8281769896796204, 0.847354854274638, 0.8665098994539243, 0.8856426822134986, 0.9047537336063698, 0.9238435605005114, 0.9429126471820782, 0.9619614568204952, 0.9809904328099454, 1.0, 1.0189905658265803, 1.0379625213531227, 1.0569162422306695, 1.0758520895846009, 1.0947704108348797, 1.1136715404559028, 1.1325558006814078, 1.1514235021593073, 1.1702749445608018, 1.1891104171476905, 1.207930199301394, 1.2267345610168598, 1.2455237633642136, 1.2642980589207327, 1.2830576921754941, 1.3018028999088125, 1.3205339115483965, 1.3392509495039846, 1.3579542294820506, 1.376643960782042, 1.3953203465754822, 1.4139835841691546, 1.4326338652534854, 1.4512713761371494, 1.4698962979688368, 1.4885088069470485, 1.5071090745187121, 1.5256972675673548, 1.5442735485915053, 1.5628380758739535, 1.581391003642442, 1.5999324822223244, 1.6184626581816859, 1.6369816744693826, 1.6554896705464286, 1.6739867825111214, 1.6924731432182785, 1.710948882392921, 1.729414126738731, 1.747869000041569, 1.766313623268338, 1.7847481146614452, 1.803172589829108, 1.8215871618317296, 1.8399919412645485, 1.858387036336771, 1.8767725529473605, 1.895148594757668, 1.9135152632610593, 1.9318726578496912, 1.9502208758785904], [0.0, 0.035749106525291105, 0.06906272143876586, 0.10151503857049497, 0.13342038322424146, 0.16492507722311722, 0.19611412737489603, 0.22704311154071627, 0.25775119035073973, 0.2882674298077485, 0.31861424728108906, 0.3488094503937639, 0.3788675204936132, 0.4088004608107063, 0.4386183793386274, 0.46832990255860024, 0.4979424771668052, 0.5274625952627685, 0.5568959657941943, 0.5862476473692739, 0.6155221527236963, 0.6447235320109391, 0.6738554400152906, 0.7029211909824058, 0.731923803788919, 0.7608660394857152, 0.7897504327565578, 0.8185793184746663, 0.8473548542746382, 0.876079039858724, 0.90475373360637, 0.9333806669411456, 0.961961456820495, 0.990497616644637, 1.0189905658265803, 1.0474416382221605, 1.0758520895846009, 1.1042231041804564, 1.1325558006814078, 1.160851237428151, 1.1891104171476907, 1.2173342911930496, 1.2455237633642136, 1.2736796933606722, 1.3018028999088125, 1.329894163601486, 1.3579542294820508, 1.3859838094009327, 1.4139835841691548, 1.4419542055301855, 1.4698962979688368, 1.4978104603736606, 1.5256972675673548, 1.5535572717179955, 1.5813910036424421, 1.6091989740120123, 1.636981674469383, 1.664739578664733, 1.6924731432182787, 1.7201828086156083, 1.7478690000415695, 1.775532128157878, 1.8031725898291084, 1.8307907688012708, 1.858387036336771, 1.885961751809198, 1.9135152632610597, 1.9410479079272953, 1.9685600127271565, 1.9960518947267902, 2.02352386157468, 2.0509762119118955, 2.078409235758947, 2.1058232148808833, 2.133218423132135, 2.1605951267824914, 2.1879535848254763, 2.2152940492702946, 2.2426167654184246, 2.2699219721258523, 2.2972099020518644, 2.3244807818952484, 2.3517348326186864, 2.378972269662063, 2.406193303145373, 2.4333981380618446, 2.4605869744618616, 2.487760007628228, 2.5149174282432734, 2.5420594225482693, 2.569186172495595, 2.596297855894053, 2.623394646547719, 2.6504767143886854, 2.6775442256040196, 2.704597342757253, 2.7316362249046975, 2.758661027706848, 2.7856719035351394, 2.812669001574295, 2.8396524679204784, 2.8666224456754823], [0.0, 0.04698475772352076, 0.09076856878176186, 0.13342038322424146, 0.17535331622163478, 0.2167596773468736, 0.25775119035073973, 0.2984009007606376, 0.3387602770718469, 0.37886752049361316, 0.41875209399074625, 0.4584374019762155, 0.4979424771668052, 0.5372830953094225, 0.5764725412571948, 0.6155221527236963, 0.6544417168406867, 0.6932397661213676, 0.7319238037889189, 0.7705004783306278, 0.8089757207980267, 0.8473548542746381, 0.8856426822134987, 0.9238435605005114, 0.9619614568204952, 1.0, 1.037962521353123, 1.0758520895846009, 1.1136715404559028, 1.1514235021593073, 1.1891104171476905, 1.2267345610168598, 1.2642980589207324, 1.3018028999088125, 1.3392509495039848, 1.376643960782042, 1.4139835841691544, 1.4512713761371494, 1.4885088069470485, 1.525697267567355, 1.5628380758739535, 1.5999324822223244, 1.6369816744693828, 1.6739867825111214, 1.7109488823929209, 1.747869000041569, 1.784748114661445, 1.8215871618317296, 1.858387036336771, 1.895148594757668, 1.9318726578496912, 1.9685600127271565, 2.0052114148748243, 2.0418275900026717, 2.078409235758947, 2.1149570233147776, 2.1514715988321047, 2.1879535848254763, 2.224403581427101, 2.2608221675635765, 2.297209902051864, 2.333567324621291, 2.3698949568677152, 2.406193303145373, 2.4424628514014013, 2.4787040739575628, 2.5149174282432734, 2.5511033574836497, 2.5872622913459855, 2.6233946465477187, 2.6595008274287295, 2.695581226490529, 2.731636224904697, 2.7676661929927273, 2.8036714906792537, 2.8396524679204784, 2.8756094651094672, 2.9115428134598527, 2.9474528353693574, 2.983339844764446, 3.019204147427312, 3.055046041306315, 3.090865816810896, 3.12666375709193, 3.1624401383084044, 3.1981952298812386, 3.233929294735013, 3.2696425895283165, 3.3053353648733714, 3.341007865545555, 3.376660330683388, 3.4122929939795226, 3.4479060838632316, 3.48349982367487, 3.519074431832739, 3.554630121992756, 3.5901671032013285, 3.6256855800417678, 3.6611857527746037, 3.696667817472094, 3.73213196614723, 3.7675783868775254], [0.0, 0.0580793174820771, 0.11220184543019633, 0.16492507722311722, 0.2167596773468736, 0.2679433656340732, 0.318614247281089, 0.36886261613176147, 0.4187520939907462, 0.46832990255860013, 0.5176324619206887, 0.5666887029983827, 0.6155221527236961, 0.6641523119870781, 0.7125956026078564, 0.7608660394857151, 0.8089757207980265, 0.8569351938492177, 0.9047537336063697, 0.9524395584709954, 0.9999999999999999, 1.0474416382221603, 1.0947704108348797, 1.1419917022839345, 1.1891104171476905, 1.2361310411312894, 1.283057692175494, 1.3298941636014858, 1.3766439607820418, 1.4233103325072198, 1.4698962979688364, 1.5164046701015061, 1.562838075873953, 1.6091989740120118, 1.6554896705464284, 1.7017123325086074, 1.7478690000415689, 1.7939615971484535, 1.8399919412645485, 1.8859617518091978, 1.931872657849691, 1.9777262049892501, 2.023523861574679, 2.0692670243054896, 2.114957023314777, 2.1605951267824905, 2.206182545133558, 2.2517204348664466, 2.297209902051864, 2.342652005536296, 2.38804775988081, 2.433398138061844, 2.4787040739575623, 2.5239664646405937, 2.5691861724955944, 2.6143640271780284, 2.659500827428729, 2.7045973427572525, 2.7496543150056505, 2.7946724598030617, 2.839652467920478, 2.884595006534074, 2.929500720404681, 2.9743702329802257, 3.0192041474273115, 3.0640030475975304, 3.108767498933582, 3.1534980493197917, 3.198195229881238, 3.242859555735282, 3.287491526699001, 3.332091627955695, 3.376660330683388, 3.421198092647972, 3.4657053587634596, 3.510182561621576, 3.554630121992756, 3.599048449300451, 3.643437942070494, 3.6877989883571334, 3.7321319661472296, 3.776437243743999, 3.8207151801315655, 3.864966125321516, 3.9091904206825463, 3.953388399254219, 3.997560386045768, 4.0417066983208425, 4.08582764586899, 4.129923531264654, 4.1739946501143805, 4.218041291292911, 4.262063737168763, 4.3060622638198796, 4.350037141239904, 4.393988633535548, 4.437916999115563, 4.481822490871733, 4.525705356352314, 4.569565837928311, 4.613404172952941, 4.6572205939146585], [0.0, 0.06906272143876586, 0.13342038322424146, 0.19611412737489603, 0.25775119035073973, 0.318614247281089, 0.3788675204936133, 0.4386183793386274, 0.4979424771668052, 0.5568959657941943, 0.6155221527236963, 0.6738554400152906, 0.731923803788919, 0.7897504327565578, 0.8473548542746382, 0.90475373360637, 0.961961456820495, 1.0189905658265803, 1.0758520895846009, 1.1325558006814078, 1.1891104171476907, 1.2455237633642136, 1.3018028999088125, 1.3579542294820508, 1.4139835841691548, 1.4698962979688368, 1.525697267567355, 1.5813910036424421, 1.636981674469383, 1.6924731432182787, 1.7478690000415695, 1.8031725898291084, 1.8583870363367707, 1.9135152632610595, 1.9685600127271565, 2.02352386157468, 2.078409235758947, 2.133218423132135, 2.1879535848254763, 2.242616765418425, 2.2972099020518644, 2.3517348326186864, 2.406193303145373, 2.4605869744618616, 2.514917428243273, 2.569186172495595, 2.6233946465477187, 2.6775442256040196, 2.7316362249046975, 2.7856719035351394, 2.8396524679204784, 2.8935790750371333, 2.9474528353693574, 3.0012748156355586, 3.055046041306315, 3.1087674989335823, 3.162440138308405, 3.216064874462613, 3.269642589528317, 3.323174134467582, 3.376660330683389, 3.4301019715218786, 3.4834998236748707, 3.5368546284907905, 3.5901671032013285, 3.643437942070495, 3.6966678174720946, 3.7498573809010867, 3.803007263923834, 3.856118079071756, 3.9091904206825476, 3.9622248656927246, 4.015221974384983, 4.068182291093514, 4.1211063448702046, 4.173994650114381, 4.226847707168552, 4.279666002882409, 4.332450011147169, 4.3852001934021825, 4.437916999115564, 4.490600866240502, 4.5432522216487605, 4.595871481542762, 4.6484590518475795, 4.701015328584026, 4.753540698223967, 4.8060355380289135, 4.858500216372843, 4.910935093050177, 4.96334051956974, 5.015716839435498, 5.068064388414793, 5.120383494794787, 5.17267447962773, 5.2249376569656665, 5.277173334085135, 5.329381811702389, 5.381563384179638, 5.433718339722771, 5.485846960570969, 5.537949523178676], [0.0, 0.07995454165804432, 0.15446199290007995, 0.22704311154071627, 0.2984009007606376, 0.36886261613176147, 0.4386183793386274, 0.5077924928560541, 0.5764725412571948, 0.6447235320109391, 0.7125956026078565, 0.7801285806261319, 0.8473548542746381, 0.9143012693364418, 0.9809904328099456, 1.0474416382221605, 1.1136715404559028, 1.179694659394114, 1.2455237633642136, 1.3111701661790105, 1.376643960782042, 1.4419542055301855, 1.5071090745187123, 1.5721159802123823, 1.636981674469383, 1.7017123325086077, 1.7663136232683383, 1.8307907688012708, 1.8951485947576685, 1.9593915735647447, 2.02352386157468, 2.0875493311969233, 2.1514715988321047, 2.2152940492702946, 2.2790198570947933, 2.342652005536297, 2.406193303145373, 2.469646398589325, 2.5330137938294666, 2.596297855894053, 2.6595008274287295, 2.7226248361788383, 2.7856719035351394, 2.8486439522555798, 2.9115428134598527, 2.974370232980226, 3.0371278771408674, 3.0998173380284073, 3.162440138308405, 3.224997735635481, 3.2874915266990015, 3.3499228509411036, 3.4122929939795226, 3.4746031907638755, 3.53685462849079, 3.5990484493004518, 3.661185752774604, 3.7232675982539307, 3.785295006990812, 3.8472689641517794, 3.9091904206825476, 3.9710602950471685, 4.032879474851746, 4.094648818362104, 4.156369155923903, 4.218041291292912, 4.27966600288241, 4.341244044934042, 4.402776148617941, 4.464263023067312, 4.525705356352315, 4.587103816397612, 4.6484590518475795, 4.709771692882872, 4.771042351991678, 4.832271624698781, 4.893460090255261, 4.95460831229144, 5.015716839435498, 5.076786205899972, 5.137816932038193, 5.198809524872557, 5.259764478596392, 5.320682275051035, 5.381563384179638, 5.442408264459106, 5.503217363311435, 5.563991117495715, 5.624729953481855, 5.685434287807131, 5.746104527416515, 5.806741069987673, 5.867344304241518, 5.927914610239086, 5.9884523596654935, 6.048957916101649, 6.109431635284404, 6.1698738653557, 6.230284947101353, 6.290665214179941, 6.351014993342338, 6.411334604642371], [0.0, 0.09076856878176184, 0.17535331622163478, 0.25775119035073973, 0.3387602770718469, 0.4187520939907462, 0.4979424771668052, 0.5764725412571948, 0.6544417168406866, 0.7319238037889187, 0.8089757207980266, 0.8856426822134987, 0.961961456820495, 1.037962521353123, 1.1136715404559028, 1.1891104171476905, 1.2642980589207324, 1.3392509495039846, 1.4139835841691544, 1.4885088069470482, 1.5628380758739533, 1.6369816744693826, 1.710948882392921, 1.7847481146614448, 1.8583870363367707, 1.931872657849691, 2.0052114148748243, 2.0784092357589468, 2.1514715988321047, 2.2244035814271004, 2.297209902051864, 2.3698949568677152, 2.442462851401401, 2.514917428243273, 2.5872622913459855, 2.659500827428729, 2.7316362249046966, 2.8036714906792537, 2.8756094651094672, 2.9474528353693574, 3.0192041474273115, 3.090865816810896, 3.162440138308404, 3.2339292947350127, 3.3053353648733705, 3.376660330683388, 3.4479060838632307, 3.5190744318327387, 3.590167103201328, 3.6611857527746032, 3.73213196614723, 3.8030072639238335, 3.8738131056047664, 3.9445508931692905, 4.015221974384982, 4.08582764586899, 4.156369155923902, 4.226847707168552, 4.297264458981944, 4.367620529776546, 4.437916999115563, 4.508154909687327, 4.578335269148612, 4.6484590518475795, 4.71852720043596, 4.788540627379254, 4.858500216372842, 4.928406823671209, 4.998261279336851, 5.068064388414792, 5.137816932038192, 5.207519668469988, 5.277173334085133, 5.346778644297596, 5.4163362944359355, 5.485846960570969, 5.555311300298755, 5.624729953481853, 5.694103542951608, 5.763432675173974, 5.832717940881212, 5.901959915671608, 5.971159160579221, 6.040316222615488, 6.109431635284402, 6.178505919072872, 6.247539581917707, 6.316533119650615, 6.385487016422498, 6.454401745108215, 6.523277767692933, 6.5921155356411, 6.660915490248981, 6.7296780629817015, 6.798403675795605, 6.867092741446717, 6.935745663786077, 7.004362838042589, 7.072944651094096, 7.141491481727231, 7.210003700886642, 7.278481671914136], [0.0, 0.10151503857049493, 0.19611412737489597, 0.2882674298077485, 0.37886752049361316, 0.46832990255860013, 0.5568959657941943, 0.6447235320109391, 0.7319238037889187, 0.8185793184746659, 0.9047537336063698, 0.990497616644637, 1.0758520895846009, 1.1608512374281506, 1.2455237633642133, 1.3298941636014858, 1.4139835841691544, 1.4978104603736604, 1.5813910036424417, 1.6647395786647325, 1.747869000041569, 1.8307907688012703, 1.9135152632610593, 1.99605189472679, 2.0784092357589468, 2.1605951267824905, 2.242616765418424, 2.3244807818952484, 2.406193303145373, 2.487760007628228, 2.569186172495595, 2.6504767143886854, 2.7316362249046966, 2.8126690015742946, 2.893579075037133, 2.9743702329802257, 3.0550460413063147, 3.1356098629208438, 3.216064874462612, 3.2964140812513887, 3.376660330683388, 3.456806324270568, 3.5368546284907896, 3.61680768459183, 3.6966678174720937, 3.776437243743999, 3.8561180790717557, 3.935712344863183, 4.015221974384982, 4.094648818362103, 4.1739946501143805, 4.253261170277172, 4.332450011147168, 4.41156274068981, 4.490600866240501, 4.569565837928311, 4.648459051847579, 4.727281853000204, 4.806035538028913, 4.88472135775969, 4.96334051956974, 5.041894189595616, 5.120383494794786, 5.198809524872557, 5.277173334085133, 5.355475942928616, 5.43371833972277, 5.511901482097624, 5.590026298390237, 5.668093688958275, 5.746104527416515, 5.8240596618018055, 5.901959915671608, 5.979806089140735, 6.057598959860597, 6.135339283944858, 6.213027796845119, 6.290665214179939, 6.368252232520268, 6.4457895301340935, 6.523277767692934, 6.6007175889425636, 6.678109621340203, 6.7554544766602564, 6.832752751570483, 6.910005028180412, 6.987211874563606, 7.064373845255364, 7.141491481727232, 7.218565312839697, 7.295595855274281, 7.37258361394619, 7.449529082398599, 7.52643274317959, 7.603295068202677, 7.680116519091799, 7.756897547511601, 7.833638595483791, 7.910340095690293, 7.987002471763872, 8.06362613856686, 8.140211502458618], [0.0, 0.11220184543019633, 0.21675967734687362, 0.31861424728108906, 0.41875209399074625, 0.5176324619206887, 0.6155221527236963, 0.7125956026078565, 0.8089757207980266, 0.9047537336063698, 1.0, 1.09477041083488, 1.1891104171476905, 1.2830576921754941, 1.376643960782042, 1.4698962979688366, 1.5628380758739533, 1.6554896705464286, 1.747869000041569, 1.8399919412645485, 1.9318726578496912, 2.0235238615746796, 2.1149570233147776, 2.206182545133558, 2.297209902051864, 2.38804775988081, 2.4787040739575628, 2.569186172495595, 2.6595008274287295, 2.749654315005651, 2.839652467920478, 2.9295007204046812, 3.0192041474273115, 3.108767498933582, 3.1981952298812386, 3.287491526699001, 3.376660330683388, 3.46570535876346, 3.5546301219927563, 3.643437942070495, 3.73213196614723, 3.820715180131566, 3.9091904206825467, 3.9975603860457682, 4.08582764586899, 4.1739946501143805, 4.262063737168763, 4.350037141239905, 4.437916999115563, 4.525705356352314, 4.613404172952942, 4.701015328584025, 4.788540627379254, 4.875981802368713, 4.96334051956974, 5.050618381771041, 5.137816932038192, 5.2249376569656665, 5.311981989697839, 5.398951312739076, 5.485846960570969, 5.572670222092929, 5.659422342900776, 5.746104527416515, 5.832717940881212, 5.919263711221795, 6.005742930801556, 6.092156658063243, 6.178505919072872, 6.264791708971589, 6.351014993342338, 6.437176709497474, 6.523277767692934, 6.609319052274132, 6.695301422758283, 6.781225714857512, 6.867092741446718, 6.9529032934798725, 7.038658140858136, 7.124358033252898, 7.210003700886643, 7.295595855274282, 7.38113518992743, 7.4666223810239005, 7.552058088044544, 7.6374429543793845, 7.7227776079048756, 7.808062661533987, 7.893298713740674, 7.97848634906023, 8.06362613856686, 8.14871864032978, 8.233764399849006, 8.31876395047197, 8.403717813792007, 8.488626500029651, 8.57349050839771, 8.658310327450899, 8.74308643542093, 8.827819300537717, 8.912509381337456, 8.99715712695823], [0.0, 0.12283526041804774, 0.23730208102147285, 0.3488094503937639, 0.4584374019762155, 0.5666887029983827, 0.6738554400152906, 0.7801285806261319, 0.8856426822134987, 0.990497616644637, 1.09477041083488, 1.1985222524395718, 1.3018028999088125, 1.4046535967878186, 1.5071090745187123, 1.6091989740120123, 1.710948882392921, 1.8123811067570137, 1.9135152632610593, 2.014368733471058, 2.1149570233147776, 2.2152940492702946, 2.3153923693124336, 2.4152633713126064, 2.5149174282432734, 2.6143640271780293, 2.7136118773846114, 2.812669001574295, 2.911542813459853, 3.0102401840926367, 3.1087674989335823, 3.2071307072185093, 3.305335364873371, 3.4033866719976396, 3.501289505747237, 3.5990484493004518, 3.696667817472094, 3.794151679446118, 3.891503879020049, 3.988728052691905, 4.085827645868991, 4.182805927435696, 4.279666002882409, 4.376410826168567, 4.4730432104685045, 4.5695658379283115, 4.66598126854469, 4.762291948262197, 4.858500216372843, 4.954608312291439, 5.0506183817710415, 5.146532482615001, 5.242352589935499, 5.338080601002594, 5.433718339722771, 5.529267560781679, 5.624729953481854, 5.720107145302937, 5.815400705208986, 5.910612146724873, 6.005742930801557, 6.100794468487978, 6.195768123425582, 6.290665214179941, 6.385487016422499, 6.480234764974281, 6.574909655722296, 6.669512847418345, 6.764045463369146, 6.858508593025776, 6.952903293479874, 7.04723059087327, 7.141491481727232, 7.23568693419695, 7.329817889256442, 7.423885261818611, 7.517889941794845, 7.61183279509815, 7.7057146645935335, 7.799536370999053, 7.893298713740675, 7.987002471763873, 8.080648404304641, 8.174237251622445, 8.267769735697403, 8.361246560893878, 8.454668414592431, 8.54803596779205, 8.641349875684307, 8.73461077820115, 8.827819300537717, 8.920976053651678, 9.014081634740306, 9.107136627696587, 9.200141603545474, 9.29309712086131, 9.386003726167504, 9.478861954319305, 9.571672328870637, 9.66443536242576, 9.757151556976527, 9.849821404226029], [0.0, 0.13342038322424146, 0.2577511903507397, 0.3788675204936132, 0.4979424771668052, 0.6155221527236961, 0.731923803788919, 0.8473548542746381, 0.961961456820495, 1.0758520895846009, 1.1891104171476905, 1.3018028999088125, 1.4139835841691546, 1.525697267567355, 1.6369816744693828, 1.7478690000415693, 1.8583870363367705, 1.9685600127271565, 2.0784092357589468, 2.187953584825476, 2.297209902051864, 2.406193303145373, 2.514917428243273, 2.6233946465477187, 2.731636224904697, 2.839652467920478, 2.9474528353693574, 3.055046041306315, 3.1624401383084044, 3.269642589528317, 3.3766603306833884, 3.48349982367487, 3.5901671032013276, 3.696667817472094, 3.8030072639238335, 3.909190420682547, 4.015221974384982, 4.1211063448702046, 4.226847707168552, 4.332450011147169, 4.437916999115563, 4.54325222164876, 4.648459051847579, 4.753540698223966, 4.858500216372842, 4.96334051956974, 5.0680643884147925, 5.17267447962773, 5.277173334085134, 5.381563384179637, 5.485846960570969, 5.590026298390237, 5.694103542951608, 5.798080755019209, 5.9019599156716085, 6.0057429308015555, 6.109431635284403, 6.21302779684512, 6.316533119650616, 6.419949247651234, 6.523277767692935, 6.626520212419436, 6.729678062981702, 6.832752751570485, 6.935745663786076, 7.038658140858136, 7.141491481727232, 7.244246944998663, 7.346925750778218, 7.449529082398599, 7.552058088044545, 7.654513882283939, 7.7568975475116, 7.859210135311871, 7.961452667745628, 8.063626138566862, 8.165731514373585, 8.267769735697403, 8.369741718035806, 8.471648352830854, 8.57349050839771, 8.675269030806163, 8.776984744718105, 8.878638454183612, 8.980230943398237, 9.08176297742376, 9.18323530287461, 9.284648648571986, 9.386003726167502, 9.487301230738163, 9.58854184135426, 9.689726221621708, 9.790855020200254, 9.891928871298894, 9.992948395149691, 10.0939141984612, 10.194826874852565, 10.295687005269295, 10.396495158381695, 10.497251890966838, 10.597957748274887, 10.698613264380617], [0.0, 0.14396144085549922, 0.27811517137338443, 0.4088004608107063, 0.5372830953094225, 0.6641523119870781, 0.7897504327565578, 0.9143012693364418, 1.037962521353123, 1.1608512374281506, 1.2830576921754941, 1.4046535967878186, 1.525697267567355, 1.646237041450705, 1.7663136232683383, 1.885961751809198, 2.0052114148748243, 2.1240887561116697, 2.242616765418424, 2.3608158137803987, 2.4787040739575628, 2.5962978558940524, 2.7136118773846114, 2.8306594848769207, 2.9474528353693574, 3.064003047597531, 3.1803203287179858, 3.296414081251389, 3.412292993979523, 3.52796511969154, 3.643437942070495, 3.7587184335488777, 3.8738131056047664, 3.9887280526919047, 4.103468990778096, 4.218041291292912, 4.332450011147169, 4.446699919375288, 4.560795520861521, 4.674741077537601, 4.788540627379255, 4.902198001479484, 5.015716839435497, 5.129100603252061, 5.242352589935499, 5.355475942928616, 5.468473662516614, 5.581348615316956, 5.694103542951609, 5.806741069987672, 5.919263711221796, 6.031673878374641, 6.143973886253818, 6.256165958436908, 6.368252232520268, 6.480234764974281, 6.592115535641101, 6.703896451907202, 6.8155793525794985, 6.927166011490853, 7.038658140858137, 7.150057394413652, 7.261365370328698, 7.372583613946192, 7.483713620337648, 7.594756836698387, 7.7057146645935335, 7.816588462066195, 7.92737954561827, 8.038089192073256, 8.148718640329783, 8.259269093013671, 8.369741718035806, 8.480137650062371, 8.590457991903545, 8.700703815826195, 8.810876164795713, 8.920976053651678, 9.031004470221694, 9.140962376377406, 9.250850709036389, 9.360670381113321, 9.470422282423616, 9.58010728054242, 9.689726221621708, 9.799279931168002, 9.908769214783012, 10.018194858869444, 10.127557631303906, 10.236858282078902, 10.346097543915587, 10.45527613284896, 10.56439474878701, 10.673454076045262, 10.78245478385806, 10.891397526867786, 11.00028294559327, 11.109111666878396, 11.217884304322045, 11.326601458690208, 11.435263718311278, 11.543871659455327], [0.0, 0.15446199290007995, 0.2984009007606376, 0.4386183793386274, 0.5764725412571948, 0.7125956026078564, 0.8473548542746382, 0.9809904328099456, 1.1136715404559028, 1.2455237633642133, 1.376643960782042, 1.5071090745187123, 1.6369816744693828, 1.7663136232683383, 1.8951485947576683, 2.0235238615746796, 2.1514715988321047, 2.2790198570947933, 2.406193303145373, 2.5330137938294666, 2.6595008274287295, 2.7856719035351394, 2.911542813459853, 3.0371278771408674, 3.162440138308405, 3.287491526699001, 3.4122929939795226, 3.5368546284907905, 3.661185752774604, 3.785295006990812, 3.909190420682547, 4.032879474851746, 4.156369155923902, 4.279666002882409, 4.402776148617941, 4.525705356352315, 4.648459051847579, 4.771042351991677, 4.893460090255261, 5.015716839435498, 5.137816932038192, 5.259764478596392, 5.381563384179638, 5.503217363311435, 5.624729953481853, 5.746104527416514, 5.867344304241517, 5.9884523596654935, 6.109431635284403, 6.230284947101352, 6.351014993342338, 6.471624361639004, 6.5921155356411, 6.712490901114025, 6.832752751570485, 6.9529032934798725, 7.0729446510940965, 7.192878870924457, 7.312707925900504, 7.432433719238526, 7.552058088044546, 7.671582806674152, 7.791009589869309, 7.9103400956902945, 8.029575928259188, 8.14871864032978, 8.267769735697403, 8.386730671460871, 8.50560286014777, 8.624387671713146, 8.743086435420931, 8.861700441616515, 8.980230943398238, 9.098679158194873, 9.217046269255604, 9.33533342705848, 9.45354175064282, 9.571672328870637, 9.689726221621708, 9.807704460926628, 9.92560805204177, 10.043437974469837, 10.161195182929406, 10.278880608276584, 10.396495158381695, 10.514039718963737, 10.631515154385031, 10.74892230840852, 10.86626200491976, 10.983535048615728, 11.100742225662286, 11.217884304322045, 11.334962035554309, 11.4519761535886, 11.56892737647323, 11.685816406600221, 11.802643931207866, 11.919410622862063, 12.036117139917613, 12.152764126960399, 12.269352215231502, 12.385882023034155], [0.0, 0.16492507722311722, 0.31861424728108906, 0.46832990255860024, 0.6155221527236963, 0.7608660394857151, 0.90475373360637, 1.0474416382221605, 1.1891104171476905, 1.3298941636014858, 1.4698962979688366, 1.6091989740120123, 1.7478690000415693, 1.885961751809198, 2.0235238615746796, 2.160595126782491, 2.2972099020518635, 2.433398138061844, 2.569186172495595, 2.704597342757253, 2.839652467920478, 2.974370232980226, 3.108767498933582, 3.2428595557352824, 3.3766603306833884, 3.510182561621576, 3.643437942070495, 3.7764372437439997, 3.909190420682547, 4.041706698320843, 4.173994650114381, 4.30606226381988, 4.437916999115562, 4.5695658379283115, 4.701015328584025, 4.83227162469878, 4.96334051956974, 5.094227476697169, 5.2249376569656665, 5.355475942928617, 5.485846960570969, 5.616055098868725, 5.746104527416515, 5.875999212355548, 6.0057429308015555, 6.135339283944857, 6.264791708971589, 6.3941034899354765, 6.523277767692935, 6.652317549000001, 6.781225714857511, 6.910005028180412, 7.038658140858135, 7.167187600265187, 7.295595855274282, 7.423885261818609, 7.552058088044545, 7.680116519091801, 7.808062661533988, 7.935898547509158, 8.063626138566862, 8.191247329255571, 8.31876395047197, 8.446177772591506, 8.57349050839771, 8.700703815826193, 8.827819300537719, 8.95483851833336, 9.08176297742376, 9.2085941405632, 9.335333427058478, 9.461982214661555, 9.58854184135426, 9.715013607032645, 9.841398775097884, 9.967698573960135, 10.0939141984612, 10.220046811221396, 10.346097543915587, 10.472067498482977, 10.597957748274888, 10.723769339144456, 10.849503290481834, 10.975160596198291, 11.100742225662286, 11.226249124590431, 11.351682215896004, 11.477042400497508, 11.602330558089596, 11.727547547878531, 11.852694209284174, 11.977771362610396, 12.102779809685654, 12.227720334475363, 12.352593703667635, 12.477400667233747, 12.60214195896475, 12.72681829698542, 12.851430384246775, 12.975978908998234, 13.100464545240452, 13.224887953159836], [0.0, 0.17535331622163475, 0.3387602770718469, 0.4979424771668052, 0.6544417168406867, 0.8089757207980265, 0.961961456820495, 1.1136715404559028, 1.2642980589207324, 1.4139835841691544, 1.5628380758739533, 1.710948882392921, 1.8583870363367705, 2.0052114148748243, 2.1514715988321047, 2.2972099020518635, 2.4424628514014004, 2.5872622913459855, 2.7316362249046966, 2.875609465109467, 3.0192041474273115, 3.162440138308404, 3.305335364873371, 3.4479060838632307, 3.5901671032013276, 3.7321319661472296, 3.8738131056047664, 4.015221974384982, 4.156369155923902, 4.297264458981944, 4.437916999115562, 4.578335269148612, 4.718527200435959, 4.858500216372841, 4.998261279336851, 5.137816932038192, 5.277173334085133, 5.416336294435935, 5.555311300298755, 5.694103542951608, 5.832717940881211, 5.971159160579221, 6.109431635284402, 6.247539581917707, 6.3854870164224975, 6.523277767692933, 6.66091549024898, 6.798403675795605, 6.935745663786076, 7.072944651094095, 7.210003700886642, 7.346925750778218, 7.483713620337646, 7.62037001801033, 7.7568975475116, 7.8932987137406725, 8.029575928259186, 8.165731514373585, 8.301767711856463, 8.437686681338292, 8.573490508397708, 8.70918120737579, 8.84476072493711, 8.980230943398238, 9.11559368384228, 9.250850709036387, 9.386003726167502, 9.521054389410253, 9.65600430233968, 9.790855020200253, 9.925608052041769, 10.060264862731659, 10.194826874852563, 10.329295470493165, 10.463671992939696, 10.597957748274887, 10.73215400689058, 10.866262004919756, 11.000282945593266, 11.1342180005261, 11.268068310937764, 11.401834988810847, 11.535519117991711, 11.66912175523679, 11.80264393120786, 11.936086651419359, 12.069450897140507, 12.202737626255034, 12.335947774080825, 12.469082254151893, 12.602141958964747, 12.735127760691212, 12.868040511859476, 13.00088104600522, 13.133650178294365, 13.266348706118992, 13.398977409667877, 13.53153705247294, 13.664028381932907, 13.796452129815314, 13.928809012737988, 14.061099732631027], [0.0, 0.18574899612593704, 0.35884340683872595, 0.5274625952627685, 0.6932397661213676, 0.8569351938492177, 1.0189905658265803, 1.179694659394114, 1.3392509495039846, 1.4978104603736604, 1.6554896705464286, 1.8123811067570137, 1.9685600127271565, 2.1240887561116697, 2.2790198570947933, 2.433398138061844, 2.5872622913459855, 2.740646049285923, 2.893579075037133, 3.046087652652131, 3.1981952298812386, 3.349922850941103, 3.5012895057472364, 3.6523124148084354, 3.803007263923834, 3.953388399254219, 4.103468990778096, 4.253261170277172, 4.402776148617941, 4.552024316065271, 4.701015328584025, 4.849758182488271, 4.998261279336851, 5.146532482615, 5.2945791674592515, 5.442408264459105, 5.590026298390237, 5.737439422590312, 5.884653449572199, 6.031673878374641, 6.178505919072872, 6.325154514807744, 6.471624361639004, 6.617919926484363, 6.764045463369145, 6.910005028180412, 7.055802492093395, 7.201441553815978, 7.346925750778219, 7.4922584693779, 7.6374429543793845, 7.782482317551278, 7.927379545618269, 8.072137507593762, 8.216758961552248, 8.361246560893877, 8.50560286014777, 8.64983032035572, 8.793931314073436, 8.93790813002262, 9.081762977423761, 9.225497990036517, 9.369115229931904, 9.512616691018108, 9.65600430233968, 9.799279931168, 9.94244538589921, 10.08550241877435, 10.228452728435109, 10.371297962327374, 10.514039718963737, 10.656679550055117, 10.799218962520818, 10.941659420385536, 11.084002346571145, 11.226249124590431, 11.368401100149399, 11.510459582664172, 11.652425846698172, 11.794301133324643, 11.93608665141936, 12.077783578887912, 12.219393063831612, 12.360916225655847, 12.502354156124353, 12.643707920362669, 12.784978557813778, 12.926167083148771, 13.067274487135098, 13.208301737464899, 13.349249779545621, 13.49011953725509, 13.630911913662944, 13.771627791720348, 13.912268034919682, 14.05283348792577, 14.193324977180257, 14.33374331148043, 14.474089282533944, 14.61436366549059, 14.7545672194523, 14.894700687962533], [0.0, 0.19611412737489595, 0.37886752049361316, 0.5568959657941943, 0.7319238037889189, 0.9047537336063697, 1.0758520895846009, 1.2455237633642136, 1.4139835841691544, 1.5813910036424417, 1.747869000041569, 1.9135152632610593, 2.0784092357589468, 2.242616765418424, 2.406193303145373, 2.569186172495595, 2.7316362249046966, 2.893579075037133, 3.0550460413063147, 3.216064874462612, 3.376660330683388, 3.5368546284907896, 3.6966678174720937, 3.8561180790717557, 4.015221974384982, 4.1739946501143805, 4.332450011147169, 4.490600866240501, 4.6484590518475795, 4.806035538028913, 4.96334051956974, 5.120383494794787, 5.277173334085133, 5.43371833972277, 5.590026298390237, 5.746104527416514, 5.901959915671608, 6.057598959860597, 6.21302779684512, 6.368252232520268, 6.523277767692934, 6.678109621340203, 6.832752751570483, 6.987211874563606, 7.141491481727231, 7.295595855274281, 7.449529082398598, 7.603295068202678, 7.7568975475116, 7.910340095690293, 8.06362613856686, 8.216758961552248, 8.369741718035804, 8.52257743712709, 8.675269030806163, 8.827819300537717, 8.980230943398238, 9.132506557760118, 9.284648648571986, 9.436659632270365, 9.58854184135426, 9.740297528650997, 9.891928871298894, 10.043437974469837, 10.194826874852563, 10.346097543915587, 10.497251890966838, 10.648291766025588, 10.799218962520817, 10.950035219828884, 11.100742225662286, 11.251341618320229, 11.401834988810847, 11.552223882854078, 11.702509802773415, 11.852694209284174, 12.002778523185192, 12.152764126960397, 12.30265236629616, 12.452444551519863, 12.602141958964749, 12.751745832265675, 12.901257383590094, 13.050677794808244, 13.20000821860626, 13.349249779545621, 13.498403575072116, 13.647470676477322, 13.796452129815316, 13.945348956777213, 14.094162155525916, 14.242892701493309, 14.391541548141953, 14.540109627693296, 14.688597851824156, 14.837007112333191, 14.985338281778988, 15.133592214091193, 15.281769745156186, 15.429871693378523, 15.577898860219403, 15.725852030713359], [0.0, 0.20645049138657176, 0.3988360595093512, 0.5862476473692739, 0.7705004783306278, 0.9524395584709954, 1.1325558006814078, 1.3111701661790105, 1.4885088069470482, 1.6647395786647325, 1.8399919412645485, 2.014368733471058, 2.187953584825476, 2.3608158137803987, 2.5330137938294666, 2.704597342757253, 2.875609465109467, 3.046087652652131, 3.216064874462612, 3.3855703439184817, 3.5546301219927563, 3.7232675982539303, 3.8915038790200485, 4.059358104004257, 4.226847707168552, 4.393988633535548, 4.560795520861521, 4.727281853000204, 4.893460090255261, 5.05934178087369, 5.2249376569656665, 5.390257717473303, 5.555311300298754, 5.720107145302936, 5.884653449572199, 6.048957916101649, 6.213027796845119, 6.376869930922127, 6.540490778642891, 6.703896451907202, 6.867092741446718, 7.030085141309209, 7.192878870924456, 7.35547889504261, 7.517889941794843, 7.680116519091799, 7.842162929546388, 8.0040332840829, 8.165731514373585, 8.327261384226059, 8.488626500029651, 8.649830320355719, 8.810876164795712, 8.971767222111021, 9.132506557760118, 9.29309712086131, 9.45354175064282, 9.613843182426498, 9.774004053186445, 9.934026906719554, 10.0939141984612, 10.253668299975912, 10.413291503149958, 10.572786024110124, 10.73215400689058, 10.891397526867786, 11.050518593981394, 11.209519155757532, 11.368401100149397, 11.527166258208682, 11.685816406600223, 11.844353269971196, 12.002778523185192, 12.161093793430645, 12.319300662212306, 12.477400667233749, 12.635395304178235, 12.793286028394704, 12.951074256495078, 13.10876136786868, 13.266348706118993, 13.42383758042772, 13.581229266850643, 13.738525009549491, 13.895726021963714, 14.052833487925772, 14.209848562723279, 14.366772374111157, 14.523606023276667, 14.680350585760031, 14.837007112333191, 14.993576629839005, 15.150060141993103, 15.306458630150464, 15.462773054038621, 15.619004352459248, 15.775153443959882, 15.931221227477266, 16.0872085829539, 16.24311637192904, 16.398945438105606, 16.55469660789404], [0.0, 0.21675967734687362, 0.41875209399074625, 0.6155221527236963, 0.8089757207980267, 0.9999999999999999, 1.1891104171476907, 1.376643960782042, 1.5628380758739533, 1.747869000041569, 1.9318726578496912, 2.1149570233147776, 2.297209902051864, 2.4787040739575628, 2.6595008274287295, 2.839652467920478, 3.0192041474273115, 3.1981952298812386, 3.376660330683388, 3.5546301219927563, 3.73213196614723, 3.9091904206825467, 4.08582764586899, 4.262063737168763, 4.437916999115563, 4.613404172952942, 4.788540627379255, 4.96334051956974, 5.137816932038192, 5.311981989697839, 5.485846960570969, 5.659422342900776, 5.832717940881211, 6.0057429308015555, 6.178505919072872, 6.351014993342338, 6.523277767692934, 6.695301422758283, 6.867092741446718, 7.038658140858137, 7.210003700886643, 7.38113518992743, 7.552058088044544, 7.7227776079048756, 7.893298713740673, 8.06362613856686, 8.233764399849006, 8.403717813792007, 8.57349050839771, 8.74308643542093, 8.912509381337456, 9.08176297742376, 9.250850709036387, 9.419775924168773, 9.58854184135426, 9.757151556976526, 9.925608052041769, 10.093914198461201, 10.262072764887254, 10.430086422142317, 10.597957748274888, 10.765689233274497, 10.93328328347365, 11.100742225662286, 11.268068310937764, 11.435263718311276, 11.602330558089596, 11.76927087504933, 11.936086651419359, 12.102779809685652, 12.269352215231502, 12.435805678825014, 12.602141958964749, 12.76836276409343, 12.934469754688864, 13.100464545240454, 13.266348706118993, 13.432123765346832, 13.597791210274973, 13.763352489173075, 13.92880901273799, 14.094162155525918, 14.259413257312989, 14.424563624388632, 14.58961453078587, 14.7545672194523, 14.919422903365271, 15.084182766594598, 15.248847965315745, 15.413419628776465, 15.577898860219403, 15.742286737763216, 15.906584315244467, 16.07079262302248, 16.23491266874916, 16.398945438105606, 16.562891895507384, 16.72675298478, 16.890529629806213, 17.054222735146602, 17.2178331866347, 17.38136185194809], [0.0, 0.22704311154071619, 0.4386183793386273, 0.6447235320109391, 0.8473548542746381, 1.0474416382221603, 1.2455237633642136, 1.4419542055301855, 1.6369816744693826, 1.8307907688012703, 2.0235238615746796, 2.2152940492702946, 2.406193303145373, 2.5962978558940524, 2.7856719035351394, 2.974370232980226, 3.162440138308404, 3.349922850941103, 3.5368546284907896, 3.7232675982539303, 3.9091904206825467, 4.094648818362103, 4.279666002882409, 4.464263023067312, 4.6484590518475795, 4.83227162469878, 5.015716839435497, 5.198809524872557, 5.381563384179638, 5.563991117495715, 5.746104527416515, 5.927914610239086, 6.109431635284402, 6.29066521417994, 6.471624361639004, 6.652317549000001, 6.832752751570483, 7.012937490645097, 7.192878870924456, 7.372583613946191, 7.552058088044545, 7.7313083352768235, 7.910340095690293, 8.0891588292493, 8.267769735697401, 8.446177772591504, 8.624387671713146, 8.802403954035052, 8.980230943398238, 9.157872779035246, 9.335333427058478, 9.512616691018106, 9.689726221621706, 9.866665525697005, 10.043437974469835, 10.220046811221396, 10.396495158381695, 10.572786024110124, 10.74892230840852, 10.92490680880746, 11.100742225662286, 11.276431167091712, 11.4519761535886, 11.627379622329615, 11.802643931207863, 11.977771362610396, 12.152764126960399, 12.327624366042029, 12.502354156124353, 12.676955510899225, 12.851430384246775, 13.025780672840918, 13.200008218606262, 13.374114811036852, 13.548102189386288, 13.72197204473799, 13.895726021963714, 14.069365721577698, 14.242892701493309, 14.416308478688494, 14.589614530785871, 14.762812297552843, 14.935903182326708, 15.108888553369411, 15.281769745156186, 15.454548059602102, 15.62722476723014, 15.799801108284324, 15.97227829379098, 16.144657506571225, 16.316939902207334, 16.48912660996569, 16.661218733678584, 16.833217352587276, 17.005123522148324, 17.176938274805156, 17.348662620726795, 17.52029754851537, 17.69184402588416, 17.863303000307567, 18.034675399644527, 18.20596213273667], [0.0, 0.23730208102147282, 0.45843740197621546, 0.6738554400152906, 0.8856426822134987, 1.0947704108348797, 1.3018028999088125, 1.5071090745187123, 1.710948882392921, 1.9135152632610593, 2.1149570233147776, 2.3153923693124336, 2.514917428243273, 2.7136118773846114, 2.911542813459853, 3.108767498933582, 3.305335364873371, 3.5012895057472364, 3.6966678174720937, 3.8915038790200485, 4.08582764586899, 4.279666002882409, 4.4730432104685045, 4.66598126854469, 4.858500216372842, 5.050618381771041, 5.242352589935499, 5.433718339722771, 5.624729953481854, 5.815400705208986, 6.005742930801556, 6.195768123425581, 6.3854870164224975, 6.574909655722294, 6.764045463369145, 6.952903293479873, 7.141491481727231, 7.329817889256441, 7.517889941794845, 7.7057146645935335, 7.893298713740674, 8.080648404304641, 8.267769735697403, 8.454668414592431, 8.641349875684305, 8.827819300537717, 9.014081634740304, 9.200141603545474, 9.386003726167502, 9.571672328870635, 9.757151556976527, 9.94244538589921, 10.127557631303905, 10.312491958474759, 10.497251890966838, 10.681840818609379, 10.866262004919758, 11.050518593981394, 11.23461361683305, 11.418549997412047, 11.602330558089596, 11.785958024832563, 11.96943503202257, 12.152764126960399, 12.335947774080827, 12.518988358900831, 12.701888191721828, 12.88464951110474, 13.067274487135096, 13.24976522449365, 13.432123765346834, 13.614352092069993, 13.796452129815316, 13.978425748935345, 14.160274767272055, 14.342000952320669, 14.523606023276667, 14.705091652973705, 14.88645946971965, 15.067711059037274, 15.248847965315745, 15.429871693378525, 15.610783709972873, 15.791585445185806, 15.97227829379098, 16.152863616530645, 16.333342741336516, 16.51371696449318, 16.69398755174734, 16.87415573936601, 17.054222735146602, 17.234189719381515, 17.41405784577984, 17.59382824234848, 17.773502012234914, 17.95308023453365, 18.13256396505832, 18.31195423708115, 18.49125206204166, 18.67045843022599, 18.849574311418497, 19.028600655526915], [0.0, 0.24753775291987262, 0.4782114166514545, 0.7029211909824058, 0.9238435605005114, 1.1419917022839345, 1.3579542294820508, 1.5721159802123823, 1.7847481146614448, 1.99605189472679, 2.206182545133558, 2.4152633713126064, 2.6233946465477187, 2.8306594848769207, 3.0371278771408674, 3.2428595557352824, 3.4479060838632307, 3.6523124148084354, 3.8561180790717557, 4.059358104004257, 4.262063737168763, 4.464263023067312, 4.66598126854469, 4.8672414224519835, 5.0680643884147925, 5.268469284794337, 5.468473662516614, 5.668093688958276, 5.867344304241517, 6.066239354916637, 6.264791708971589, 6.463013355312992, 6.66091549024898, 6.858508593025775, 7.055802492093395, 7.252806423477808, 7.449529082398598, 7.645978669079781, 7.842162929546388, 8.038089192073258, 8.233764399849006, 8.429195140333078, 8.624387671713144, 8.819347946811542, 9.014081634740302, 9.208594140563198, 9.402890623188425, 9.59697601168616, 9.790855020200254, 9.984532161601924, 10.178011760015098, 10.371297962327374, 10.564394748787006, 10.757305942774721, 10.950035219828884, 11.142586115993966, 11.334962035554307, 11.527166258208682, 11.719201945735199, 11.911072148190858, 12.102779809685654, 12.294327773766968, 12.485718788446558, 12.676955510899226, 12.868040511859476, 13.05897627974001, 13.249765224493652, 13.440409681238316, 13.630911913662942, 13.821274117230551, 14.011498422193386, 14.201586896433598, 14.391541548141952, 14.58136432834586, 14.771057133297202, 14.960621806729476, 15.150060141993102, 15.339373884076922, 15.528564731523439, 15.717634338244588, 15.906584315244467, 16.095416232254852, 16.284131619288964, 16.472731968118495, 16.661218733678584, 16.84959333540507, 17.03785715850803, 17.226011555185355, 17.41405784577984, 17.601997319883047, 17.78983123738892, 17.97756082950002, 18.165187299688963, 18.352711824617543, 18.54013555501587, 18.727459616523582, 18.91468511049526, 19.101813114771794, 19.288844684419633, 19.475780852439446, 19.66262263044578, 19.84937100931924], [0.0, 0.2577511903507397, 0.4979424771668052, 0.731923803788919, 0.9619614568204952, 1.1891104171476905, 1.4139835841691548, 1.636981674469383, 1.8583870363367707, 2.0784092357589468, 2.297209902051864, 2.5149174282432734, 2.731636224904697, 2.9474528353693574, 3.162440138308405, 3.3766603306833884, 3.5901671032013276, 3.803007263923834, 4.015221974384982, 4.226847707168552, 4.437916999115563, 4.6484590518475795, 4.858500216372842, 5.0680643884147925, 5.277173334085134, 5.485846960570969, 5.694103542951609, 5.9019599156716085, 6.109431635284403, 6.316533119650616, 6.523277767692935, 6.729678062981702, 6.935745663786076, 7.141491481727232, 7.346925750778219, 7.552058088044545, 7.7568975475116, 7.961452667745628, 8.165731514373585, 8.369741718035806, 8.57349050839771, 8.776984744718105, 8.980230943398238, 9.18323530287461, 9.386003726167502, 9.58854184135426, 9.790855020200254, 9.992948395149691, 10.194826874852565, 10.396495158381695, 10.597957748274888, 10.799218962520818, 11.000282945593266, 11.201153678626103, 11.40183498881085, 11.602330558089596, 11.802643931207864, 12.002778523185194, 12.202737626255038, 12.402524416320114, 12.60214195896475, 12.801593215061438, 13.000881046005222, 13.200008218606264, 13.398977409667879, 13.597791210274973, 13.796452129815318, 13.994962599754073, 14.193324977180255, 14.391541548141953, 14.589614530785873, 14.787546078315232, 14.985338281778986, 15.182993172704176, 15.38051272558226, 15.577898860219406, 15.77515344395988, 15.97227829379098, 16.169275178337273, 16.3661458197513, 16.56289189550738, 16.759515040104617, 16.956016846684758, 17.15239886857017, 17.34866262072679, 17.544809581156564, 17.74084119222349, 17.93675886191731, 18.132563965058317, 18.328257844446785, 18.523841811960025, 18.719317149600172, 18.91468511049526, 19.10994691985629, 19.30510377589264, 19.500156850687972, 19.695107291038887, 19.88995621925812, 20.084704733944292, 20.279353910719802, 20.473904802938534, 20.668358442364944], [0.0, 0.2679433656340733, 0.5176324619206887, 0.7608660394857152, 1.0, 1.2361310411312894, 1.4698962979688368, 1.7017123325086077, 1.931872657849691, 2.1605951267824905, 2.38804775988081, 2.6143640271780293, 2.839652467920478, 3.064003047597531, 3.287491526699001, 3.510182561621576, 3.7321319661472296, 3.953388399254219, 4.1739946501143805, 4.393988633535548, 4.613404172952942, 4.83227162469878, 5.050618381771041, 5.268469284794337, 5.485846960570969, 5.702772103471755, 5.919263711221795, 6.135339283944858, 6.351014993342338, 6.566305827395848, 6.781225714857511, 6.995787632931618, 7.210003700886642, 7.423885261818609, 7.6374429543793845, 7.8506867759606935, 8.06362613856686, 8.276269918402, 8.488626500029651, 8.700703815826195, 8.912509381337456, 9.124050327055793, 9.335333427058478, 9.546365124884863, 9.757151556976526, 9.967698573960131, 10.178011760015098, 10.388096450536278, 10.597957748274888, 10.807600538117727, 11.017029500645053, 11.226249124590431, 11.435263718311276, 11.6440774203662, 11.852694209284174, 12.061117912601176, 12.269352215231502, 12.477400667233749, 12.685266691025133, 12.892953588092109, 13.100464545240452, 13.307802640423516, 13.514970848183605, 13.721972044737988, 13.92880901273799, 14.135484445726979, 14.342000952320667, 14.54836106013089, 14.754567219452298, 14.960621806729474, 15.16652712782061, 15.372285421072368, 15.577898860219403, 15.7833695571208, 15.988699564344719, 16.193890877611626, 16.398945438105606, 16.603865134662517, 16.8086518058431, 17.01330724189844, 17.2178331866347, 17.422231339183472, 17.626503355683617, 17.830650850880048, 18.034675399644527, 18.238578538423166, 18.44236176661492, 18.646026547885235, 18.849574311418497, 19.053006453112904, 19.256324336720937, 19.459529294938534, 19.66262263044578, 19.865605616901828, 20.06847949989646, 20.27124549786069, 20.473904802938538, 20.676458581822, 20.878907976551247, 21.081254105281676, 21.283498063019614, 21.485640922328265], [0.0, 0.2781151713733844, 0.5372830953094225, 0.7897504327565578, 1.037962521353123, 1.283057692175494, 1.525697267567355, 1.7663136232683383, 2.0052114148748243, 2.242616765418424, 2.4787040739575628, 2.7136118773846114, 2.9474528353693574, 3.1803203287179858, 3.4122929939795226, 3.643437942070495, 3.8738131056047664, 4.103468990778096, 4.332450011147169, 4.560795520861521, 4.788540627379255, 5.015716839435497, 5.242352589935499, 5.468473662516614, 5.694103542951609, 5.919263711221795, 6.143973886253819, 6.368252232520269, 6.592115535641101, 6.8155793525794985, 7.038658140858136, 7.261365370328698, 7.483713620337647, 7.705714664593533, 7.92737954561827, 8.14871864032978, 8.369741718035804, 8.590457991903545, 8.810876164795713, 9.031004470221694, 9.250850709036389, 9.470422282423616, 9.689726221621708, 9.908769214783012, 10.127557631303905, 10.346097543915587, 10.564394748787008, 10.78245478385806, 11.000282945593268, 11.217884304322045, 11.435263718311278, 11.652425846698172, 11.86937516139626, 12.086115958074268, 12.30265236629616, 12.518988358900831, 12.735127760691213, 12.95107425649508, 13.166831398653233, 13.382402613984878, 13.597791210274973, 13.81300038232374, 14.02803321759461, 14.24289270149331, 14.457581722307626, 14.672103075834626, 14.88645946971965, 15.100653527529051, 15.314687792576844, 15.528564731523439, 15.742286737763218, 15.955856134616127, 16.169275178337273, 16.382546060957228, 16.595670912964824, 16.808651805843102, 17.021490754468388, 17.234189719381515, 17.446750608939624, 17.659175281356248, 17.871465546636827, 18.083623168416274, 18.29564986570465, 18.50754731454666, 18.719317149600172, 18.930960965638665, 19.142480318982056, 19.353876728860225, 19.565151678713, 19.776306617430393, 19.987342960536367, 20.19826209131936, 20.40906536191248, 20.619754094326183, 20.83032958143599, 21.040793087927625, 21.251145851201898, 21.461389082241382, 21.67152396644096, 21.881551664404043, 22.09147331270615, 22.301290024627686], [0.0, 0.28826742980774844, 0.5568959657941943, 0.8185793184746663, 1.0758520895846009, 1.3298941636014858, 1.5813910036424421, 1.8307907688012708, 2.0784092357589468, 2.3244807818952484, 2.569186172495595, 2.812669001574295, 3.055046041306315, 3.296414081251389, 3.5368546284907905, 3.7764372437439997, 4.015221974384982, 4.253261170277172, 4.490600866240501, 4.727281853000204, 4.96334051956974, 5.198809524872557, 5.433718339722771, 5.668093688958276, 5.9019599156716085, 6.135339283944858, 6.368252232520269, 6.600717588942564, 6.832752751570485, 7.064373845255365, 7.295595855274283, 7.5264327431795905, 7.7568975475116, 7.987002471763873, 8.216758961552248, 8.446177772591506, 8.675269030806163, 8.904042285678967, 9.132506557760118, 9.360670381113321, 9.588541841354262, 9.816128609838035, 10.043437974469837, 10.27047686754494, 10.497251890966838, 10.723769339144456, 10.950035219828886, 11.17605527311583, 11.40183498881085, 11.627379622329615, 11.852694209284174, 12.077783578887912, 12.30265236629616, 12.527305023985846, 12.751745832265676, 12.975978908998234, 13.200008218606264, 13.423837580427723, 13.647470676477324, 13.870911058666174, 14.09416215552592, 14.31722727847911, 14.540109627693298, 14.762812297552845, 14.985338281778988, 15.207690478225993, 15.429871693378526, 15.651884646573059, 15.87373197396421, 16.095416232254852, 16.316939902207338, 16.538305391951603, 16.759515040104617, 16.98057111871439, 17.201475836040665, 17.422231339183476, 17.642839716569775, 17.86330300030757, 18.083623168416274, 18.30380214694126, 18.52384181196003, 18.74374399148686, 18.963510467282198, 19.18314297657274, 19.40264321368756, 19.622012831615418, 19.841253443487812, 20.060366623992273, 20.279353910719806, 20.498216805450404, 20.716956775380027, 20.935575254292377, 21.154073643678558, 21.372453313807416, 21.590715604749334, 21.80886182735586, 22.02689326419762, 22.244811170462654, 22.462616774817253, 22.680311280231237, 22.89789586476946, 23.115371682351277], [0.0, 0.2984009007606376, 0.5764725412571948, 0.8473548542746382, 1.1136715404559028, 1.3766439607820418, 1.636981674469383, 1.8951485947576685, 2.1514715988321047, 2.406193303145373, 2.6595008274287295, 2.911542813459853, 3.1624401383084044, 3.412292993979523, 3.661185752774604, 3.909190420682547, 4.156369155923902, 4.402776148617941, 4.6484590518475795, 4.893460090255261, 5.137816932038192, 5.381563384179638, 5.624729953481854, 5.867344304241517, 6.109431635284403, 6.351014993342338, 6.592115535641101, 6.832752751570485, 7.0729446510940965, 7.312707925900505, 7.552058088044545, 7.791009589869309, 8.029575928259186, 8.267769735697403, 8.50560286014777, 8.743086435420931, 8.980230943398238, 9.217046269255604, 9.45354175064282, 9.68972622162171, 9.925608052041769, 10.161195182929408, 10.396495158381697, 10.631515154385031, 10.866262004919758, 11.100742225662286, 11.334962035554309, 11.568927376473232, 11.802643931207864, 12.036117139917613, 12.269352215231502, 12.502354156124355, 12.735127760691213, 12.96767763792702, 13.200008218606262, 13.432123765346834, 13.664028381932908, 13.895726021963718, 14.127220496887912, 14.358515483476998, 14.589614530785873, 14.820521066643588, 15.051238403713254, 15.28176974515619, 15.512118189931979, 15.742286737763216, 15.972278293790982, 16.20209567294464, 16.431741604047605, 16.661218733678584, 16.890529629806217, 17.11967678521348, 17.348662620726795, 17.57748948826352, 17.806159673710404, 18.03467539964453, 18.26303882790737, 18.49125206204166, 18.719317149600176, 18.947236084334598, 19.17501080827223, 19.40264321368756, 19.630135144975313, 19.857488400430935, 20.084704733944292, 20.311785856611692, 20.53873343827108, 20.765549108965008, 20.99223446033545, 21.218791046954504, 21.445220387594496, 21.671523966440965, 21.897703234251647, 22.123759609464493, 22.349694479257394, 22.575509200562298, 22.801205101036068, 23.026783479990378, 23.252245609282863, 23.477592734171367, 23.702826074133277, 23.927946823651705], [0.0, 0.3085162884387364, 0.5960141821360637, 0.876079039858724, 1.1514235021593073, 1.4233103325072198, 1.6924731432182787, 1.9593915735647447, 2.2244035814271004, 2.487760007628228, 2.749654315005651, 3.0102401840926367, 3.269642589528317, 3.52796511969154, 3.785295006990812, 4.041706698320843, 4.297264458981944, 4.552024316065271, 4.806035538028913, 5.05934178087369, 5.311981989697839, 5.563991117495715, 5.815400705208986, 6.066239354916637, 6.316533119650616, 6.566305827395848, 6.8155793525794985, 7.064373845255365, 7.312707925900505, 7.560598852029195, 7.808062661533988, 8.055114296672894, 8.301767711856465, 8.548035967792048, 8.793931314073438, 9.039465261932424, 9.284648648571986, 9.529491694262155, 9.774004053186445, 10.018194858869446, 10.262072764887256, 10.505645981456354, 10.74892230840852, 10.991909164986403, 11.23461361683305, 11.477042400497508, 11.719201945735199, 11.96109839584515, 12.202737626255038, 12.444125261538328, 12.685266691025133, 12.926167083148773, 13.166831398653231, 13.407264402772164, 13.647470676477324, 13.8874546268836, 14.127220496887912, 14.36677237411116, 14.606114199204965, 14.845249773578423, 15.0841827665946, 15.322916722281322, 15.56145506559651, 15.799801108284326, 16.0379580543549, 16.27592900521737, 16.513716964493184, 16.751324842534004, 16.988755460666678, 17.226011555185355, 17.463095781109345, 17.700010715723607, 17.93675886191731, 18.173342651334625, 18.40976444735079, 18.64602654788524, 18.882131188062953, 19.11808054273393, 19.353876728860225, 19.589521807779004, 19.825017787349672, 20.060366623992273, 20.29557022462401, 20.530630448500137, 20.765549108965008, 21.000327975118783, 21.23496877340466, 21.469473189121434, 21.7038428678656, 21.938079416907144, 22.172184406502723, 22.406159371149762, 22.640005810784732, 22.873725191928706, 23.107318948783046, 23.340788484277848, 23.574135171075753, 23.807360352533355, 24.040465343622532, 24.2734514318137, 24.50631987792288, 24.739071916924544], [0.0, 0.318614247281089, 0.6155221527236963, 0.90475373360637, 1.1891104171476905, 1.4698962979688364, 1.7478690000415695, 2.02352386157468, 2.297209902051864, 2.569186172495595, 2.839652467920478, 3.1087674989335823, 3.3766603306833884, 3.643437942070495, 3.909190420682547, 4.173994650114381, 4.437916999115562, 4.701015328584025, 4.96334051956974, 5.2249376569656665, 5.485846960570969, 5.746104527416515, 6.005742930801556, 6.264791708971589, 6.523277767692935, 6.781225714857511, 7.038658140858136, 7.295595855274283, 7.552058088044545, 7.808062661533988, 8.06362613856686, 8.318763950471972, 8.573490508397708, 8.827819300537717, 9.08176297742376, 9.335333427058478, 9.58854184135426, 9.841398775097884, 10.0939141984612, 10.346097543915588, 10.597957748274888, 10.849503290481834, 11.100742225662286, 11.351682215896005, 11.602330558089596, 11.852694209284172, 12.102779809685654, 12.352593703667637, 12.60214195896475, 12.851430384246775, 13.100464545240452, 13.349249779545623, 13.597791210274972, 13.846093758631657, 14.094162155525918, 14.342000952320666, 14.589614530785871, 14.837007112333195, 15.084182766594598, 15.331145419402022, 15.577898860219404, 15.824446749073145, 16.070792623022484, 16.316939902207338, 16.56289189550738, 16.8086518058431, 17.054222735146602, 17.29960768902746, 17.544809581156564, 17.78983123738892, 18.03467539964453, 18.279344729564723, 18.52384181196003, 18.768169158064072, 19.012329208607046, 19.25632433672094, 19.500156850687972, 19.74382899654254, 19.987342960536367, 20.230700871475676, 20.473904802938538, 20.716956775380027, 20.95985875813211, 21.202612671304795, 21.445220387594496, 21.687683734005287, 21.930004493488084, 22.172184406502723, 22.41422517250724, 22.656128451378727, 22.89789586476946, 23.139528997402063, 23.381029398307003, 23.622398582005633, 23.863638029641756, 24.104749190064368, 24.34573348086435, 24.586592289367307, 24.827326973585098, 25.067938863127956, 25.30842926007932, 25.548799439835257], [0.0, 0.3286953870184948, 0.6349976309423525, 0.9333806669411456, 1.2267345610168598, 1.5164046701015061, 1.8031725898291084, 2.0875493311969233, 2.3698949568677152, 2.6504767143886854, 2.9295007204046812, 3.2071307072185093, 3.48349982367487, 3.7587184335488777, 4.032879474851746, 4.30606226381988, 4.578335269148612, 4.849758182488271, 5.120383494794787, 5.390257717473303, 5.659422342900776, 5.927914610239086, 6.195768123425581, 6.463013355312992, 6.729678062981702, 6.995787632931618, 7.261365370328698, 7.5264327431795905, 7.791009589869309, 8.055114296672894, 8.318763950471972, 8.581974470851547, 8.84476072493711, 9.107136627696587, 9.369115229931904, 9.630708795789008, 9.891928871298894, 10.15278634520792, 10.41329150314996, 10.673454076045264, 10.93328328347365, 11.192787872656524, 11.4519761535886, 11.710856030782294, 11.96943503202257, 12.227720334475363, 12.485718788446558, 12.74343693904942, 13.000881046005224, 13.25805710177343, 13.514970848183605, 13.77162779172035, 14.028033217594608, 14.284192202719261, 14.540109627693298, 14.79579018788739, 15.051238403713254, 15.306458630150468, 15.56145506559651, 15.816231760098923, 16.070792623022484, 16.32514143019895, 16.579281830602174, 16.83321735258728, 17.08695140972882, 17.340487306289535, 17.593828242348483, 17.846977318614446, 18.099937540948567, 18.352711824617543, 18.60530299829731, 18.857713807845087, 19.10994691985629, 19.362004925021456, 19.613890341296877, 19.86560561690183, 20.117153133153916, 20.368535207153368, 20.619754094326183, 20.870811990835243, 21.12171103586784, 21.372453313807416, 21.62304085629675, 21.87347564419923, 22.12375960946449, 22.373894636904065, 22.623882565882475, 22.87372519192871, 23.12342426827265, 23.372981507310858, 23.622398582005637, 23.871677127221147, 24.120818741000082, 24.369824985784128, 24.618697389581335, 24.86743744708313, 25.116046620733787, 25.364526341754697, 25.61287801112601, 25.861103000527592, 26.109202653241557, 26.357178285018247], [0.0, 0.3387602770718469, 0.6544417168406867, 0.961961456820495, 1.2642980589207324, 1.562838075873953, 1.8583870363367707, 2.1514715988321047, 2.442462851401401, 2.7316362249046966, 3.0192041474273115, 3.305335364873371, 3.5901671032013276, 3.8738131056047664, 4.156369155923902, 4.437916999115562, 4.718527200435959, 4.998261279336851, 5.277173334085133, 5.555311300298754, 5.832717940881211, 6.109431635284402, 6.3854870164224975, 6.66091549024898, 6.935745663786076, 7.210003700886642, 7.483713620337647, 7.7568975475116, 8.029575928259186, 8.301767711856465, 8.573490508397708, 8.84476072493711, 9.11559368384228, 9.3860037261675, 9.65600430233968, 9.925608052041769, 10.194826874852563, 10.463671992939696, 10.73215400689058, 11.000282945593266, 11.268068310937764, 11.535519117991711, 11.80264393120786, 12.069450897140507, 12.335947774080823, 12.602141958964747, 12.868040511859476, 13.133650178294365, 13.398977409667877, 13.664028381932905, 13.928809012737988, 14.193324977180254, 14.457581722307623, 14.721584480491716, 14.985338281778985, 15.248847965315742, 15.512118189931975, 15.77515344395988, 16.037958054354895, 16.300536195179944, 16.56289189550738, 16.825029046787648, 17.086951409728815, 17.34866262072679, 17.610166197882243, 17.871465546636824, 18.132563965058317, 18.39346464880145, 18.654170695769007, 18.914685110495256, 19.175010808272226, 19.435150619037266, 19.69510729103888, 19.954883494296407, 20.21448182386779, 20.473904802938534, 20.733154885743918, 20.992234460335446, 21.251145851201894, 21.509891321754235, 21.768473076683218, 22.026893264197618, 22.28515397815057, 22.543257260060948, 22.801205101036057, 23.058999443601735, 23.316642183445172, 23.574135171075746, 23.831480213408508, 24.088679075274833, 24.345733480864343, 24.602645115101918, 24.859415624963468, 25.11604662073378, 25.372539677209605, 25.628896334850907, 25.88511810088305, 26.141206450352477, 26.397162827138338, 26.652988644922342, 26.908685288118868, 27.164254112767484], [0.0, 0.34880945039376376, 0.6738554400152905, 0.990497616644637, 1.3018028999088125, 1.6091989740120118, 1.9135152632610595, 2.2152940492702946, 2.514917428243273, 2.8126690015742946, 3.108767498933582, 3.4033866719976396, 3.696667817472094, 3.9887280526919047, 4.279666002882409, 4.5695658379283115, 4.858500216372841, 5.146532482615, 5.43371833972277, 5.720107145302936, 6.0057429308015555, 6.29066521417994, 6.574909655722294, 6.858508593025775, 7.141491481727232, 7.423885261818609, 7.705714664593533, 7.987002471763873, 8.267769735697403, 8.548035967792048, 8.827819300537717, 9.107136627696587, 9.3860037261675, 9.664435362425758, 9.94244538589921, 10.220046811221396, 10.497251890966837, 10.774072180203794, 11.050518593981394, 11.32660145869021, 11.602330558089596, 11.877715174675178, 12.152764126960397, 12.427485803163467, 12.701888191721826, 12.975978908998234, 13.24976522449365, 13.523254083840566, 13.796452129815316, 14.069365721577698, 14.342000952320667, 14.61436366549059, 14.886459469719647, 15.158293752595442, 15.429871693378525, 15.701198274766332, 15.97227829379098, 16.243116371929045, 16.51371696449318, 16.784084369368035, 17.054222735146602, 17.324136068717483, 17.59382824234848, 17.86330300030757, 18.132563965058317, 18.40161464306329, 18.670458430225995, 18.939098616998837, 19.207538393182507, 19.475780852439446, 19.74382899654254, 20.011685739377967, 20.279353910719802, 20.546836259792325, 20.81413545863472, 21.081254105281676, 21.348194726772267, 21.614959781998486, 21.881551664404043, 22.147972704542983, 22.41422517250724, 22.680311280231237, 22.946233183681343, 23.211992984937176, 23.477592734171363, 23.743034431533907, 24.00832002894671, 24.2734514318137, 24.538430500651256, 24.803259052643696, 25.067938863127956, 25.332471667011472, 25.59685916012696, 25.86110300052759, 26.125204809725766, 26.389166173878504, 26.65298864492235, 26.916673741660333, 27.18022295080365, 27.44363772797024, 27.706919498642527, 27.970069659086388], [0.0, 0.35884340683872595, 0.6932397661213676, 1.0189905658265803, 1.3392509495039848, 1.6554896705464284, 1.9685600127271565, 2.2790198570947933, 2.5872622913459855, 2.893579075037133, 3.1981952298812386, 3.501289505747237, 3.8030072639238335, 4.103468990778096, 4.402776148617941, 4.701015328584025, 4.998261279336851, 5.2945791674592515, 5.590026298390237, 5.884653449572199, 6.178505919072872, 6.471624361639004, 6.764045463369145, 7.055802492093395, 7.346925750778219, 7.6374429543793845, 7.92737954561827, 8.216758961552248, 8.50560286014777, 8.793931314073438, 9.08176297742376, 9.369115229931904, 9.65600430233968, 9.94244538589921, 10.228452728435109, 10.514039718963735, 10.799218962520817, 11.084002346571145, 11.368401100149399, 11.652425846698174, 11.936086651419359, 12.219393063831612, 12.502354156124353, 12.784978557813778, 13.067274487135096, 13.349249779545621, 13.630911913662942, 13.912268034919682, 14.193324977180255, 14.474089282533942, 14.7545672194523, 15.034764799476012, 15.314687792576843, 15.594341741323342, 15.87373197396421, 16.15286361653064, 16.431741604047605, 16.71037069093445, 16.988755460666678, 17.266900334763164, 17.544809581156564, 17.82248732199883, 18.099937540948567, 18.377164089982486, 18.65417069576901, 18.93096096563866, 19.207538393182507, 19.483906363507092, 19.76006815817186, 20.03602695983247, 20.311785856611692, 20.58734784621743, 20.862715839825878, 21.137892665746318, 21.412881072882612, 21.687683734005287, 21.962303248846972, 22.23674214703288, 22.511002890857238, 22.7850878779155, 23.05899944360174, 23.332739863479546, 23.606311355534455, 23.879716082315134, 24.152956152970088, 24.42603362518622, 24.698950507035015, 24.971708758731808, 25.24431029431314, 25.516756983237006, 25.789050651910205, 26.06119308514704, 26.333186027563052, 26.605031184907464, 26.876730225337585, 27.148284780638306, 27.41969644738963, 27.69096678808493, 27.96209733220258, 28.233089577233258, 28.50394498966524, 28.7746650059298], [0.0, 0.36886261613176147, 0.7125956026078565, 1.0474416382221605, 1.376643960782042, 1.7017123325086074, 2.02352386157468, 2.342652005536297, 2.659500827428729, 2.9743702329802257, 3.287491526699001, 3.5990484493004518, 3.909190420682547, 4.218041291292912, 4.525705356352315, 4.83227162469878, 5.137816932038192, 5.442408264459105, 5.746104527416514, 6.048957916101649, 6.351014993342338, 6.652317549000001, 6.952903293479873, 7.252806423477808, 7.552058088044545, 7.8506867759606935, 8.14871864032978, 8.446177772591506, 8.743086435420931, 9.039465261932424, 9.335333427058478, 9.630708795789008, 9.925608052041769, 10.220046811221396, 10.514039718963735, 10.807600538117729, 11.100742225662286, 11.393477000970197, 11.685816406600223, 11.977771362610397, 12.269352215231502, 12.56056878061277, 12.851430384246775, 13.14194589659305, 13.432123765346832, 13.721972044737987, 14.011498422193386, 14.300710242652132, 14.589614530785871, 14.878218011344515, 15.16652712782061, 15.454548059602102, 15.742286737763214, 16.029748859625666, 16.316939902207338, 16.603865134662517, 16.890529629806213, 17.17693827480516, 17.463095781109345, 17.74900669369016, 18.03467539964453, 18.320106136218346, 18.60530299829731, 18.89026994540856, 19.17501080827223, 19.459529294938534, 19.74382899654254, 20.027913392705816, 20.311785856611692, 20.595449659778254, 20.87890797655125, 21.1621638883371, 21.445220387594496, 21.72808038160148, 22.010746696013623, 22.293222078227448, 22.575509200562298, 22.85761066327266, 23.139528997402063, 23.42126666748886, 23.702826074133277, 23.984209556434553, 24.265419394306246, 24.546457810677193, 24.827326973585095, 25.10802899816921, 25.388565948568058, 25.668939839727834, 25.94915263912659, 26.229206268419155, 26.50910260500714, 26.788843483538358, 27.068430697339494, 27.34786599978571, 27.627151105610675, 27.906287692160078, 28.18527740059178, 28.46412183702528, 28.742822573643277, 29.021381149747647, 29.29979907277224, 29.57807781925471], [0.0, 0.3788675204936131, 0.7319238037889187, 1.0758520895846009, 1.4139835841691544, 1.7478690000415689, 2.078409235758947, 2.406193303145373, 2.7316362249046966, 3.0550460413063147, 3.376660330683388, 3.696667817472094, 4.015221974384982, 4.332450011147169, 4.648459051847579, 4.96334051956974, 5.277173334085133, 5.590026298390237, 5.901959915671608, 6.213027796845119, 6.523277767692934, 6.832752751570483, 7.141491481727231, 7.449529082398598, 7.7568975475116, 8.06362613856686, 8.369741718035804, 8.675269030806163, 8.980230943398238, 9.284648648571986, 9.58854184135426, 9.891928871298894, 10.194826874852563, 10.497251890966837, 10.799218962520817, 11.100742225662286, 11.401834988810847, 11.702509802773415, 12.002778523185192, 12.30265236629616, 12.602141958964749, 12.901257383590094, 13.20000821860626, 13.498403575072116, 13.796452129815314, 14.094162155525916, 14.391541548141952, 14.688597851824156, 14.985338281778986, 15.281769745156186, 15.577898860219403, 15.87373197396421, 16.16927517833727, 16.46453432519252, 16.759515040104617, 17.0542227351466, 17.34866262072679, 17.642839716569775, 17.936758861917305, 18.230424725017038, 18.523841811960025, 18.81701447492178, 19.10994691985629, 19.40264321368756, 19.695107291038884, 19.987342960536367, 20.279353910719802, 20.571143715590836, 20.862715839825874, 21.15407364367855, 21.445220387594496, 21.736159236559143, 22.026893264197618, 22.317425456643985, 22.607758716195942, 22.89789586476946, 23.187839647166967, 23.477592734171363, 23.767157725477354, 24.056537152470582, 24.345733480864343, 24.634749113202812, 24.923586391239148, 25.21224759819615, 25.500734960916645, 25.789050651910205, 26.07719679130234, 26.365175448691968, 26.652988644922345, 26.940638353770613, 27.228126503560386, 27.515454978701847, 27.80262562116325, 28.08964023187773, 28.376500572088794, 28.663208364637892, 28.949765295197096, 29.236173013449744, 29.52243313422188, 29.808547238566884, 30.09451687480573, 30.38034355952518], [0.0, 0.38885853697058087, 0.7512251753448985, 1.1042231041804564, 1.4512713761371494, 1.7939615971484535, 2.133218423132135, 2.469646398589325, 2.8036714906792537, 3.1356098629208438, 3.46570535876346, 3.794151679446118, 4.1211063448702046, 4.446699919375288, 4.771042351991677, 5.094227476697169, 5.416336294435935, 5.737439422590312, 6.057598959860597, 6.376869930922127, 6.695301422758283, 7.012937490645097, 7.329817889256441, 7.645978669079781, 7.961452667745628, 8.276269918402, 8.590457991903545, 8.904042285678967, 9.217046269255604, 9.529491694262155, 9.841398775097884, 10.15278634520792, 10.463671992939696, 10.774072180203794, 11.084002346571145, 11.393477000970197, 11.702509802773415, 12.011113633761763, 12.319300662212308, 12.627082400155828, 12.934469754688864, 13.241473074090868, 13.548102189386286, 13.854366451899345, 14.160274767272053, 14.465835626351423, 14.771057133297202, 15.07594703121522, 15.38051272558226, 15.68476130569471, 15.988699564344719, 16.292334015902824, 16.59567091296482, 16.898716261702365, 17.201475836040665, 17.50395519077313, 17.806159673710404, 18.108094436950907, 18.409764447350785, 18.71117449626283, 19.012329208607046, 19.313233051329025, 19.613890341296877, 19.914305252682393, 20.21448182386779, 20.514423963915462, 20.814135458634723, 21.113619976276276, 21.412881072882612, 21.71192219731973, 22.010746696013623, 22.30935781741273, 22.607758716195946, 22.90595245724389, 23.203942019390002, 23.501730298966255, 23.79932011315755, 24.096714203177303, 24.393915237276094, 24.690925813594074, 24.98774846286722, 25.28438565099657, 25.580839781489043, 25.877113197777717, 26.173208185428905, 26.469126974242865, 26.76487174025438, 27.060444607639223, 27.355847650531782, 27.651082894759153, 27.946152319496274, 28.241057858846617, 28.535801403352504, 28.830384801439, 29.124809860794908, 29.419078349694278, 29.713191998261603, 30.00715249968359, 30.300961511370435, 30.59462065606907, 30.88813152293083, 31.181495668535995], [0.0, 0.3988360595093512, 0.7705004783306278, 1.1325558006814078, 1.4885088069470485, 1.8399919412645485, 2.1879535848254763, 2.5330137938294666, 2.8756094651094672, 3.216064874462612, 3.5546301219927563, 3.891503879020049, 4.226847707168552, 4.560795520861521, 4.893460090255261, 5.2249376569656665, 5.555311300298755, 5.884653449572199, 6.21302779684512, 6.540490778642891, 6.867092741446718, 7.192878870924456, 7.517889941794845, 7.842162929546388, 8.165731514373585, 8.488626500029651, 8.810876164795713, 9.132506557760118, 9.45354175064282, 9.774004053186445, 10.0939141984612, 10.41329150314996, 10.73215400689058, 11.050518593981394, 11.368401100149399, 11.685816406600223, 12.002778523185192, 12.319300662212308, 12.635395304178237, 12.951074256495081, 13.266348706118993, 13.581229266850643, 13.895726021963716, 14.209848562723279, 14.523606023276665, 14.837007112333193, 15.150060141993102, 15.462773054038623, 15.775153443959882, 16.0872085829539, 16.398945438105606, 16.71037069093445, 17.021490754468385, 17.33231178898836, 17.642839716569775, 17.95308023453365, 18.26303882790737, 18.57272078098441, 18.882131188062953, 19.19127496343465, 19.500156850687976, 19.80878143138359, 20.117153133153916, 20.425276237273696, 20.73315488574392, 21.040793087927625, 21.34819472677227, 21.65536356465033, 21.962303248846972, 22.269017316720888, 22.5755092005623, 22.881782232169936, 23.18783964716697, 23.493684589074245, 23.799320113157552, 24.104749190064375, 24.40997470926432, 24.714999482306197, 25.01982624590386, 25.32445766486182, 25.628896334850914, 25.933144785043467, 26.237205480616765, 26.54108082513283, 26.84477316280216, 27.14828478063831, 27.451617910509835, 27.754774731095644, 28.05775736974928, 28.360567904277506, 28.663208364637896, 28.965680734560095, 29.267986953094887, 29.570128916095122, 29.872108477632178, 30.173927451351343, 30.475587611769487, 30.77709069551793, 31.07843840253351, 31.379632397200396, 31.680674309445145, 31.98156573578753], [0.0, 0.4088004608107063, 0.7897504327565578, 1.160851237428151, 1.525697267567355, 1.8859617518091978, 2.242616765418425, 2.596297855894053, 2.9474528353693574, 3.2964140812513887, 3.643437942070495, 3.988728052691905, 4.332450011147169, 4.674741077537601, 5.015716839435498, 5.355475942928617, 5.694103542951608, 6.031673878374641, 6.368252232520268, 6.703896451907202, 7.038658140858137, 7.372583613946191, 7.7057146645935335, 8.038089192073258, 8.369741718035806, 8.700703815826195, 9.031004470221694, 9.360670381113321, 9.68972622162171, 10.018194858869446, 10.346097543915588, 10.673454076045264, 11.000282945593266, 11.32660145869021, 11.652425846698174, 11.977771362610397, 12.30265236629616, 12.627082400155828, 12.951074256495081, 13.274640037718884, 13.597791210274973, 13.920538653136052, 14.24289270149331, 14.564863186237128, 14.88645946971965, 15.207690478225995, 15.52856473152344, 15.849090369809337, 16.169275178337273, 16.48912660996569, 16.808651805843102, 17.12785761441803, 17.446750608939624, 17.765337103595446, 18.083623168416274, 18.401614643063294, 18.719317149600176, 19.03673610434162, 19.353876728860225, 19.670744060224855, 19.98734296053637, 20.30367812581979, 20.619754094326183, 20.93557525429238, 21.251145851201898, 21.566469994586498, 21.881551664404046, 22.196394717025008, 22.511002890857238, 22.825379811635745, 23.139528997402067, 23.453453863195598, 23.767157725477357, 24.080643806304977, 24.393915237276097, 24.706975063255975, 25.019826245903865, 25.332471667011472, 25.644914131665903, 25.957156371248338, 26.269201046279086, 26.581050749118564, 26.892708006533308, 27.204175282135218, 27.51545497870185, 27.826549440384827, 28.13746095481304, 28.44819175509686, 28.75874402173901, 29.06911988445754, 29.379321423925894, 29.689350673434618, 29.999209620479167, 30.308900208277816, 30.61842433722351, 30.927783866273103, 31.23698061427747, 31.546016361255415, 31.85489284961449, 32.163611785321336, 32.47217483902412, 32.78058364712958], [0.0, 0.41875209399074625, 0.8089757207980267, 1.1891104171476907, 1.5628380758739535, 1.931872657849691, 2.2972099020518644, 2.6595008274287295, 3.0192041474273115, 3.376660330683388, 3.73213196614723, 4.085827645868991, 4.437916999115563, 4.788540627379255, 5.137816932038192, 5.485846960570969, 5.832717940881211, 6.178505919072872, 6.523277767692934, 6.867092741446718, 7.210003700886643, 7.552058088044545, 7.893298713740674, 8.233764399849006, 8.57349050839771, 8.912509381337456, 9.250850709036389, 9.588541841354262, 9.925608052041769, 10.262072764887256, 10.597957748274888, 10.93328328347365, 11.268068310937764, 11.602330558089596, 11.936086651419359, 12.269352215231502, 12.602141958964749, 12.934469754688864, 13.266348706118993, 13.597791210274973, 13.92880901273799, 14.259413257312989, 14.589614530785871, 14.919422903365273, 15.248847965315743, 15.577898860219403, 15.906584315244466, 16.23491266874916, 16.56289189550738, 16.890529629806213, 17.2178331866347, 17.544809581156564, 17.871465546636824, 18.19780755097246, 18.52384181196003, 18.849574311418497, 19.17501080827223, 19.500156850687976, 19.82501778734967, 20.149598777946057, 20.473904802938538, 20.797940672669807, 21.12171103586784, 21.445220387594496, 21.76847307668322, 22.09147331270615, 22.41422517250724, 22.73673260633451, 23.05899944360174, 23.381029398307, 23.702826074133277, 24.024392969253967, 24.345733480864347, 24.6668509094582, 24.98774846286722, 25.308429260079322, 25.62889633485091, 25.949152639126588, 26.269201046279083, 26.589044354180952, 26.908685288118875, 27.22812650356039, 27.547370588782368, 27.866420067369642, 28.185277400591776, 28.503944989665243, 28.822425177907824, 29.140720252791613, 29.458832447900384, 29.77676394479699, 30.094516874805734, 30.41209332071457, 30.72949531840154, 31.046724858389652, 31.363783887334062, 31.680674309445145, 31.99739798785096, 32.31395674590219, 32.63035236842269, 32.9465866029083, 33.26266116067659, 33.578577717970184], [0.0, 0.4286912940739267, 0.8281769896796204, 1.2173342911930496, 1.5999324822223244, 1.9777262049892501, 2.3517348326186864, 2.7226248361788383, 3.090865816810896, 3.456806324270568, 3.820715180131566, 4.182805927435696, 4.54325222164876, 4.902198001479484, 5.259764478596392, 5.616055098868725, 5.971159160579221, 6.325154514807744, 6.678109621340203, 7.030085141309209, 7.38113518992743, 7.7313083352768235, 8.080648404304641, 8.429195140333078, 8.776984744718105, 9.124050327055793, 9.470422282423616, 9.816128609838035, 10.161195182929408, 10.505645981456354, 10.849503290481834, 11.192787872656524, 11.535519117991711, 11.877715174675178, 12.219393063831612, 12.56056878061277, 12.901257383590094, 13.241473074090868, 13.581229266850643, 13.920538653136052, 14.259413257312989, 14.597864487687785, 14.935903182326708, 15.27353965045767, 15.610783709972871, 15.947644721479959, 16.284131619288964, 16.620252939671424, 16.956016846684758, 17.291431155818024, 17.626503355683617, 17.961240627952165, 18.295649865704647, 18.629737690355416, 18.963510467282198, 19.29697432028414, 19.630135144975313, 19.962998621209778, 20.29557022462401, 20.62785523737343, 20.959858758132114, 21.2915857114176, 21.62304085629675, 21.954228794522997, 22.285153978150575, 22.615820716667024, 22.946233183681347, 23.276395423201823, 23.606311355534455, 23.935984782830126, 24.26541939430625, 24.594618771166363, 24.923586391239148, 25.252325633356552, 25.580839781489043, 25.909132028654625, 26.237205480616765, 26.56506315938531, 26.892708006533304, 27.220142886341616, 27.547370588782368, 27.874393832351384, 28.20121526675902, 28.527837475488113, 28.85426297822716, 29.180494233186188, 29.5065336393023, 29.832383538341382, 30.15804621690196, 30.483523908326895, 30.808818794528086, 31.13393300772905, 31.45886863212997, 31.78362770549949, 32.108212220697176, 32.432624127130374, 32.756865332149026, 33.08093770238156, 33.40484306501513, 33.72858320902288, 34.05215988634101, 34.37557481299822], [0.0, 0.4386183793386273, 0.847354854274638, 1.2455237633642136, 1.6369816744693828, 2.023523861574679, 2.406193303145373, 2.7856719035351394, 3.162440138308404, 3.5368546284907896, 3.9091904206825467, 4.279666002882409, 4.648459051847579, 5.015716839435497, 5.381563384179638, 5.746104527416515, 6.109431635284402, 6.471624361639004, 6.832752751570483, 7.192878870924456, 7.552058088044544, 7.910340095690293, 8.267769735697403, 8.624387671713144, 8.980230943398238, 9.335333427058478, 9.689726221621708, 10.043437974469837, 10.396495158381697, 10.74892230840852, 11.100742225662286, 11.4519761535886, 11.80264393120786, 12.152764126960397, 12.502354156124353, 12.851430384246775, 13.20000821860626, 13.548102189386286, 13.895726021963716, 14.24289270149331, 14.589614530785871, 14.935903182326708, 15.281769745156186, 15.62722476723014, 15.972278293790978, 16.316939902207334, 16.661218733678584, 17.005123522148324, 17.348662620726795, 17.69184402588416, 18.034675399644527, 18.377164089982486, 18.719317149600172, 19.061141353242192, 19.40264321368756, 19.743828996542536, 20.084704733944292, 20.425276237273692, 20.765549108965004, 21.105528753491054, 21.445220387594496, 21.78462904982856, 22.12375960946449, 22.462616774817253, 22.80120510103606, 23.139528997402063, 23.477592734171367, 23.81540044899823, 24.152956152970088, 24.490263736283175, 24.827326973585098, 25.164149529008323, 25.500734960916645, 25.837086726384683, 26.17320818542891, 26.50910260500714, 26.84477316280216, 27.180222950803646, 27.515454978701847, 27.85047217710498, 28.185277400591776, 28.519873430609515, 28.85426297822716, 29.18844868675254, 29.52243313422188, 29.856218835769297, 30.189808245883412, 30.523203760557735, 30.85640771934091, 31.189422407292717, 31.522250056850964, 31.854892849614487, 32.18735291804671, 32.51963234710433, 32.85173317579498, 33.183657398667926, 33.51540696724106, 33.84698379136782, 34.17838974054701, 34.50962664517854, 34.840696297767714, 35.17160045408082], [0.0, 0.4485336525329833, 0.8665098994539243, 1.2736796933606722, 1.6739867825111214, 2.0692670243054896, 2.4605869744618616, 2.8486439522555798, 3.2339292947350127, 3.61680768459183, 3.9975603860457682, 4.376410826168567, 4.753540698223966, 5.129100603252061, 5.503217363311435, 5.875999212355548, 6.247539581917707, 6.617919926484363, 6.987211874563606, 7.35547889504261, 7.7227776079048756, 8.0891588292493, 8.454668414592431, 8.819347946811542, 9.18323530287461, 9.546365124884863, 9.908769214783012, 10.27047686754494, 10.631515154385031, 10.991909164986403, 11.351682215896005, 11.710856030782294, 12.069450897140507, 12.427485803163467, 12.784978557813778, 13.14194589659305, 13.498403575072116, 13.854366451899345, 14.209848562723279, 14.564863186237128, 14.919422903365273, 15.27353965045767, 15.62722476723014, 15.980489040082391, 16.333342741336512, 16.685795664864216, 17.03785715850803, 17.38953615364842, 17.74084119222349, 18.09178045146916, 18.44236176661492, 18.79259265174143, 19.142480318982056, 19.492031696229215, 19.841253443487812, 20.190151968002496, 20.53873343827108, 20.88700379704474, 21.23496877340466, 21.582633893995528, 21.930004493488088, 22.277085724335567, 22.623882565882475, 22.9703998328785, 23.316642183445175, 23.662614126538507, 24.008320028946713, 24.353764121858596, 24.698950507035015, 25.043883162612794, 25.38856594856806, 25.73300261186355, 26.077196791302345, 26.42115202210863, 26.764871740254385, 27.108359286549288, 27.451617910509835, 27.794650774022294, 28.137460954813037, 28.480051449738728, 28.822425177907828, 29.164584983644165, 29.5065336393023, 29.848273847943876, 30.189808245883412, 30.531139405111386, 30.87226983560183, 31.213201987511354, 31.553938253275735, 31.894480969610104, 32.23483241941808, 32.574994833615065, 32.914970392870295, 33.25476122927235, 33.594369427922075, 33.93379702845687, 34.27304602651008, 34.61211837510868, 34.95101598601281, 35.28974073099984, 35.62829444309589, 35.96667891775758], [0.0, 0.4584374019762154, 0.8856426822134986, 1.3018028999088125, 1.7109488823929209, 2.114957023314777, 2.514917428243273, 2.9115428134598527, 3.3053353648733705, 3.6966678174720937, 4.08582764586899, 4.4730432104685045, 4.858500216372842, 5.242352589935499, 5.624729953481853, 6.0057429308015555, 6.3854870164224975, 6.764045463369145, 7.141491481727231, 7.517889941794843, 7.893298713740673, 8.267769735697401, 8.641349875684305, 9.014081634740302, 9.386003726167502, 9.757151556976526, 10.127557631303905, 10.497251890966838, 10.866262004919758, 11.23461361683305, 11.602330558089596, 11.96943503202257, 12.335947774080823, 12.701888191721826, 13.067274487135096, 13.432123765346832, 13.796452129815314, 14.160274767272053, 14.523606023276665, 14.88645946971965, 15.248847965315743, 15.610783709972871, 15.972278293790978, 16.333342741336512, 16.693987551747338, 17.0542227351466, 17.414057845779837, 17.77350201223491, 18.132563965058317, 18.491252062041657, 18.849574311418493, 19.207538393182503, 19.565151678712994, 19.922421248872197, 20.279353910719802, 20.63595621297422, 20.992234460335446, 21.348194726772267, 21.703842867865596, 22.059184532289994, 22.414225172507237, 22.768970054738176, 23.123424268272647, 23.477592734171367, 23.831480213408508, 24.18509131449909, 24.538430500651256, 24.891502096479638, 25.244310294313138, 25.596859160126957, 25.949152639126588, 26.30119456100876, 26.652988644922345, 27.004538504150283, 27.35584765053178, 27.70691949864253, 28.057757369749275, 28.408364495553617, 28.758744021739002, 29.10889901133352, 29.45883244790038, 29.808547238566884, 30.158046216901955, 30.5073321456516, 30.856407719340908, 31.20527556675063, 31.55393825327573, 31.902398283172975, 32.25065810170379, 32.598720097178635, 32.94658660290829, 33.29425989906739, 33.64174221447497, 33.98903572829671, 34.33614257167309, 34.68306482927728, 35.029804540806744, 35.37636370241187, 35.722744268065, 36.068948150872856, 36.41497722433531, 36.76083332355316], [0.0, 0.46832990255860013, 0.9047537336063698, 1.329894163601486, 1.747869000041569, 2.1605951267824905, 2.569186172495595, 2.974370232980226, 3.376660330683388, 3.776437243743999, 4.1739946501143805, 4.5695658379283115, 4.96334051956974, 5.355475942928616, 5.746104527416514, 6.135339283944857, 6.523277767692933, 6.910005028180412, 7.295595855274281, 7.680116519091799, 8.06362613856686, 8.446177772591504, 8.827819300537717, 9.208594140563198, 9.58854184135426, 9.967698573960131, 10.346097543915587, 10.723769339144456, 11.100742225662286, 11.477042400497508, 11.852694209284172, 12.227720334475363, 12.602141958964747, 12.975978908998234, 13.349249779545621, 13.721972044737987, 14.094162155525916, 14.465835626351423, 14.837007112333193, 15.207690478225995, 15.577898860219403, 15.947644721479959, 16.316939902207334, 16.685795664864216, 17.0542227351466, 17.42223133918347, 17.78983123738892, 18.157031755334216, 18.523841811960025, 18.890269945408555, 19.256324336720937, 19.622012831615418, 19.987342960536363, 20.352321957142085, 20.716956775380023, 21.081254105281673, 21.445220387594496, 21.80886182735586, 22.17218440650272, 22.535193895600916, 22.89789586476946, 23.260295693867604, 23.622398582005633, 23.984209556434553, 24.345733480864343, 24.706975063255967, 25.067938863127956, 25.42862929841468, 25.789050651910202, 26.149207077328338, 26.50910260500714, 26.868741147283348, 27.228126503560386, 27.587262365091274, 27.946152319496274, 28.30479985503332, 28.663208364637896, 29.021381149747643, 29.37932142392589, 29.737032316297007, 30.094516874805734, 30.4517780693115, 30.808818794528083, 31.165641872818057, 31.522250056850964, 31.878646032133318, 32.23483241941808, 32.59081177700072, 32.9465866029083, 33.30215933698801, 33.657532362900554, 34.012708010023836, 34.367688555272, 34.722476224834374, 35.07707319583875, 35.43148159794293, 35.78570351485846, 36.13974098581014, 36.49359600693457, 36.847270532620904, 37.200766476796765, 37.55408571416212], [0.0, 0.47821141665145445, 0.9238435605005114, 1.3579542294820508, 1.784748114661445, 2.206182545133558, 2.6233946465477187, 3.0371278771408674, 3.4479060838632307, 3.8561180790717557, 4.262063737168763, 4.66598126854469, 5.0680643884147925, 5.468473662516614, 5.867344304241517, 6.264791708971589, 6.66091549024898, 7.055802492093395, 7.449529082398598, 7.842162929546388, 8.233764399849006, 8.624387671713146, 9.014081634740304, 9.402890623188425, 9.790855020200254, 10.178011760015098, 10.564394748787008, 10.950035219828886, 11.334962035554309, 11.719201945735199, 12.102779809685654, 12.485718788446558, 12.868040511859476, 13.24976522449365, 13.630911913662942, 14.011498422193386, 14.391541548141952, 14.771057133297202, 15.150060141993102, 15.52856473152344, 15.906584315244466, 16.284131619288964, 16.661218733678584, 17.03785715850803, 17.414057845779837, 17.78983123738892, 18.165187299688963, 18.54013555501587, 18.91468511049526, 19.288844684419633, 19.66262263044578, 20.03602695983247, 20.409065361912475, 20.78174522297048, 21.154073643678554, 21.52605745522433, 21.897703234251647, 22.269017316720888, 22.640005810784732, 23.010674608764905, 23.381029398307003, 23.75107567278247, 24.12081874100008, 24.49026373628318, 24.859415624963468, 25.228279214337405, 25.59685916012696, 25.96515997348259, 26.33318602756305, 26.70094156372333, 27.06843069733949, 27.435657423296526, 27.80262562116325, 28.169339060076194, 28.535801403352504, 28.902016212850523, 29.267986953094884, 29.633716995181825, 29.999209620479164, 30.364468024134144, 30.72949531840154, 31.094294535803243, 31.458868632129967, 31.823220489294652, 32.18735291804671, 32.551268660555436, 32.914970392870295, 33.278460727265426, 33.64174221447497, 34.0048173458256, 34.367688555272, 34.73035822134071, 35.09282866898757, 35.45510217137335, 35.817180951562065, 36.17906718414617, 36.54076299680246, 36.90227047178227, 37.263591647339645, 37.624728519100316, 37.98568304137478, 38.346457128418166], [0.0, 0.4880821949370129, 0.9429126471820782, 1.3859838094009327, 1.8215871618317296, 2.2517204348664466, 2.6775442256040196, 3.0998173380284073, 3.5190744318327387, 3.935712344863183, 4.350037141239905, 4.762291948262197, 5.17267447962773, 5.581348615316956, 5.9884523596654935, 6.3941034899354765, 6.798403675795605, 7.201441553815978, 7.603295068202678, 8.0040332840829, 8.403717813792007, 8.802403954035052, 9.200141603545474, 9.59697601168616, 9.992948395149691, 10.388096450536278, 10.78245478385806, 11.17605527311583, 11.568927376473232, 11.96109839584515, 12.352593703667637, 12.74343693904942, 13.133650178294365, 13.523254083840566, 13.912268034919682, 14.300710242652132, 14.688597851824156, 15.07594703121522, 15.462773054038623, 15.849090369809337, 16.23491266874916, 16.620252939671424, 17.005123522148324, 17.38953615364842, 17.77350201223491, 18.157031755334216, 18.54013555501587, 18.92282313016664, 19.30510377589264, 19.686986390440943, 20.068479499896462, 20.44959128087862, 20.830329581435986, 21.210701940313793, 21.590715604749334, 21.970377546933012, 22.349694479257394, 22.728672868463654, 23.107318948783046, 23.48563873416092, 23.86363802964176, 24.241322441985872, 24.618697389581335, 24.99576811170861, 25.37253967720961, 25.749016992608365, 26.12520480972577, 26.50110773282708, 26.87673022533759, 27.252076616158227, 27.627151105610675, 28.001957771038487, 28.376500572088798, 28.750783355697, 29.124809860794908, 29.4985837227613, 29.872108477632178, 30.245387566086702, 30.618424337223505, 30.991222052140987, 31.363783887334066, 31.736112937919035, 32.108212220697176, 32.4800846770671, 32.85173317579499, 33.22316051565135, 33.594369427922075, 33.96536257880135, 34.3361425716731, 34.706711949287566, 35.07707319583876, 35.44722873894848, 35.81718095156207, 36.186932153760665, 36.55648461449464, 36.92584055324228, 37.29500214159783, 37.66397150479245, 38.03275072315185, 38.40134183349355, 38.769746830467014, 39.13796766783961], [0.0, 0.4979424771668052, 0.9619614568204952, 1.4139835841691548, 1.858387036336771, 2.297209902051864, 2.7316362249046975, 3.162440138308405, 3.590167103201328, 4.015221974384982, 4.437916999115563, 4.858500216372843, 5.277173334085134, 5.694103542951609, 6.109431635284403, 6.523277767692935, 6.935745663786076, 7.346925750778219, 7.7568975475116, 8.165731514373585, 8.57349050839771, 8.980230943398238, 9.386003726167502, 9.790855020200254, 10.194826874852565, 10.597957748274888, 11.000282945593268, 11.40183498881085, 11.802643931207864, 12.202737626255038, 12.60214195896475, 13.000881046005224, 13.398977409667877, 13.796452129815316, 14.193324977180255, 14.589614530785871, 14.985338281778986, 15.38051272558226, 15.775153443959882, 16.169275178337273, 16.56289189550738, 16.956016846684758, 17.348662620726795, 17.74084119222349, 18.132563965058317, 18.523841811960025, 18.91468511049526, 19.30510377589264, 19.695107291038884, 20.084704733944292, 20.473904802938534, 20.862715839825878, 21.251145851201894, 21.639202528110253, 22.026893264197618, 22.414225172507237, 22.801205101036064, 23.18783964716697, 23.57413517107575, 23.96009780820203, 24.345733480864347, 24.731047909091313, 25.116046620733783, 25.50073496091665, 25.885118100883055, 26.26920104627908, 26.65298864492235, 27.036485594093925, 27.419696447389626, 27.802625621163255, 28.18527740059178, 28.567655945389625, 28.949765295197096, 29.33160937466573, 29.7131919982616, 30.094516874805738, 30.475587611769484, 30.85640771934091, 31.236980614277467, 31.61730962355856, 31.997397987850956, 32.37724886479878, 32.75686533214902, 33.13625039072269, 33.515406967241056, 33.89433791701566, 34.27304602651007, 34.65153401578119, 35.02980454080675, 35.40786019570586, 35.785703514858454, 36.16333697492939, 36.54076299680246, 36.91798394742929, 37.29500214159782, 37.671819843624434, 38.04843926897413, 38.42486258581218, 38.80109191649124, 39.1771293389768, 39.552976888214424, 39.92863655744167], [0.0, 0.507792492856054, 0.9809904328099454, 1.4419542055301855, 1.895148594757668, 2.342652005536296, 2.7856719035351394, 3.224997735635481, 3.6611857527746032, 4.094648818362103, 4.525705356352314, 4.954608312291439, 5.381563384179637, 5.806741069987672, 6.230284947101352, 6.652317549000001, 7.072944651094095, 7.4922584693779, 7.910340095690293, 8.327261384226059, 8.74308643542093, 9.157872779035246, 9.571672328870635, 9.984532161601924, 10.396495158381695, 10.807600538117727, 11.217884304322045, 11.627379622329615, 12.036117139917613, 12.444125261538328, 12.851430384246775, 13.25805710177343, 13.664028381932905, 14.069365721577698, 14.474089282533942, 14.878218011344515, 15.281769745156186, 15.68476130569471, 16.0872085829539, 16.48912660996569, 16.890529629806213, 17.291431155818024, 17.69184402588416, 18.09178045146916, 18.491252062041657, 18.890269945408555, 19.288844684419633, 19.686986390440943, 20.084704733944292, 20.482008972516027, 20.878907976551247, 21.275410252867054, 21.671523966440958, 22.067256960456497, 22.46261677481725, 22.857610663272656, 23.252245609282863, 23.646528340736428, 24.040465343622532, 24.434062874748594, 24.827326973585098, 25.22026347331101, 25.612878011126007, 26.005176037889203, 26.39716282713834, 26.788843483538358, 27.18022295080365, 27.571306019134234, 27.962097332202575, 28.35260139372429, 28.742822573643277, 29.132765113959085, 29.52243313422188, 29.911830636718438, 30.30096151137043, 30.68982954036469, 31.078438402533507, 31.466791677501504, 31.854892849614487, 32.24274531166428, 32.63035236842269, 33.017717239996564, 33.40484306501512, 33.791732903659934, 34.17838974054701, 34.564816487470026, 34.951015986012806, 35.33699101003887, 35.722744268065, 36.1082784055257, 36.49359600693457, 36.87869959794843, 37.263591647339645, 37.64827456888153, 38.03275072315184, 38.417022419258394, 38.80109191649124, 39.184961425905094, 39.56863311183576, 39.95210909335389, 40.33539144565918, 40.71848220141826], [0.0, 0.5176324619206887, 1.0, 1.4698962979688368, 1.9318726578496912, 2.38804775988081, 2.8396524679204784, 3.2874915266990015, 3.73213196614723, 4.1739946501143805, 4.613404172952942, 5.0506183817710415, 5.485846960570969, 5.919263711221796, 6.351014993342338, 6.781225714857511, 7.210003700886642, 7.6374429543793845, 8.06362613856686, 8.488626500029651, 8.912509381337456, 9.335333427058478, 9.757151556976527, 10.178011760015098, 10.597957748274888, 11.017029500645053, 11.435263718311278, 11.852694209284174, 12.269352215231502, 12.685266691025133, 13.100464545240452, 13.514970848183605, 13.928809012737988, 14.342000952320667, 14.7545672194523, 15.16652712782061, 15.577898860219403, 15.988699564344719, 16.398945438105606, 16.808651805843102, 17.2178331866347, 17.626503355683617, 18.034675399644527, 18.44236176661492, 18.849574311418493, 19.256324336720937, 19.66262263044578, 20.068479499896462, 20.473904802938534, 20.878907976551247, 21.283498063019618, 21.687683734005287, 22.091473312706146, 22.49487479429043, 22.89789586476946, 23.300543918455354, 23.702826074133277, 24.10474919006437, 24.50631987792288, 24.907544515760215, 25.308429260079322, 25.708980057094116, 26.109202653241557, 26.50910260500714, 26.90868528811887, 27.307955906159545, 27.70691949864253, 28.105580948592014, 28.50394498966524, 28.90201621285052, 29.299799072772245, 29.697297893631134, 30.094516874805734, 30.491460096138862, 30.88813152293083, 31.284535010659443, 31.680674309445145, 32.076553068278294, 32.47217483902412, 32.86754308021973, 33.26266116067659, 33.65753236290056, 34.05215988634101, 34.44654685047949, 34.840696297767714, 35.2346111964239, 35.62829444309589, 36.02174886539895, 36.41497722433532, 36.80798221660255, 37.20076647679677, 37.59333257951683, 37.98568304137478, 38.377820322917884, 38.769746830467014, 39.16146491787572, 39.55297688821443, 39.944284995383526, 40.33539144565918, 40.72629839917523, 41.117007971344464, 41.5075222342224], [0.0, 0.5274625952627684, 1.0189905658265803, 1.4978104603736606, 1.9685600127271565, 2.433398138061844, 2.8935790750371333, 3.3499228509411036, 3.8030072639238335, 4.253261170277172, 4.701015328584025, 5.146532482615001, 5.590026298390237, 6.031673878374641, 6.471624361639004, 6.910005028180412, 7.346925750778218, 7.782482317551278, 8.216758961552248, 8.649830320355719, 9.08176297742376, 9.512616691018106, 9.94244538589921, 10.371297962327374, 10.799218962520818, 11.226249124590431, 11.652425846698172, 12.077783578887912, 12.502354156124355, 12.926167083148773, 13.349249779545623, 13.77162779172035, 14.193324977180254, 14.61436366549059, 15.034764799476012, 15.454548059602102, 15.87373197396421, 16.292334015902824, 16.71037069093445, 17.12785761441803, 17.544809581156564, 17.961240627952165, 18.377164089982486, 18.79259265174143, 19.207538393182503, 19.622012831615418, 20.03602695983247, 20.44959128087862, 20.862715839825878, 21.275410252867054, 21.687683734005287, 22.09954511958197, 22.511002890857235, 22.922065194832083, 23.332739863479546, 23.743034431533903, 24.152956152970088, 24.562512016291496, 24.971708758731808, 25.380552879465238, 25.78905065191021, 26.197208135202604, 26.605031184907464, 27.0125254630311, 27.419696447389626, 27.82654944038482, 28.23308957723326, 28.63932183369053, 29.045251033308702, 29.45088185426155, 29.8562188357693, 30.2612663841517, 30.666028778535864, 31.070510176243133, 31.47471461787712, 31.878646032133325, 32.28230824034912, 32.68570496081123, 33.08883981283683, 33.49171632064261, 33.89433791701566, 34.29670794679848, 34.69882967019981, 35.1007062659419, 35.50234083425436, 35.90373639972355, 36.30489591400629, 36.70582225841585, 37.10651824638747, 37.506986625830535, 37.90723008137362, 38.30725123650867, 38.70705265563962, 39.10663684604093, 39.50600625973085, 39.905163295263954, 40.304110299447274, 40.70284956898404, 41.10138335204885, 41.499713849797715, 41.8978432178163, 42.29577356750965], [0.0, 0.5372830953094224, 1.0379625213531227, 1.5256972675673548, 2.0052114148748243, 2.4787040739575623, 2.9474528353693574, 3.4122929939795226, 3.8738131056047664, 4.332450011147168, 4.788540627379254, 5.242352589935499, 5.694103542951608, 6.143973886253818, 6.5921155356411, 7.038658140858135, 7.483713620337646, 7.927379545618269, 8.369741718035804, 8.810876164795712, 9.250850709036387, 9.689726221621706, 10.127557631303905, 10.564394748787006, 11.000282945593266, 11.435263718311276, 11.86937516139626, 12.30265236629616, 12.735127760691213, 13.166831398653231, 13.597791210274972, 14.028033217594608, 14.457581722307623, 14.886459469719647, 15.314687792576843, 15.742286737763214, 16.16927517833727, 16.59567091296482, 17.021490754468385, 17.446750608939624, 17.871465546636824, 18.295649865704647, 18.719317149600172, 19.142480318982056, 19.565151678712994, 19.987342960536363, 20.409065361912475, 20.830329581435986, 21.251145851201894, 21.671523966440958, 22.091473312706146, 22.511002890857235, 22.930121340061696, 23.3488369590045, 23.767157725477354, 24.18509131449909, 24.602645115101918, 25.01982624590386, 25.436641569574984, 25.85309770629362, 26.26920104627908, 26.68495776147856, 27.10037381647825, 27.515454978701847, 27.930206827953548, 28.344634765357263, 28.758744021739002, 29.17253966549486, 29.586026609983644, 29.99920962047916, 30.41209332071457, 30.824682199048155, 31.23698061427746, 31.648992801126425, 32.06072287542816, 32.47217483902412, 32.883352584398786, 33.294259899067384, 33.704900469732905, 34.11527788622726, 34.52539564525047, 34.935257153920595, 35.34486573314618, 35.75422462083217, 36.163336974929386, 36.572205876337115, 36.98083433166727, 37.38922527587849, 37.79738157478762, 38.20530602746568, 38.6130013685247, 39.020470270301786, 39.42771534494592, 39.834739146412964, 40.241544172373786, 40.64813286604014, 41.05450761791284, 41.460670767455994, 41.86662460470158, 42.272371371787564, 42.677913264433144, 43.08325243335429], [0.0, 0.5470941565098245, 1.0569162422306695, 1.5535572717179955, 2.0418275900026717, 2.5239664646405937, 3.0012748156355586, 3.4746031907638755, 3.9445508931692905, 4.41156274068981, 4.875981802368713, 5.338080601002594, 5.798080755019209, 6.256165958436908, 6.712490901114025, 7.167187600265187, 7.62037001801033, 8.072137507593762, 8.52257743712709, 8.971767222111021, 9.419775924168773, 9.866665525697005, 10.312491958474759, 10.757305942774721, 11.201153678626103, 11.6440774203662, 12.086115958074268, 12.527305023985846, 12.96767763792702, 13.407264402772164, 13.846093758631657, 14.284192202719261, 14.721584480491716, 15.158293752595442, 15.594341741323342, 16.029748859625666, 16.46453432519252, 16.898716261702365, 17.33231178898836, 17.765337103595446, 18.19780755097246, 18.629737690355416, 19.061141353242192, 19.492031696229215, 19.922421248872197, 20.352321957142085, 20.78174522297048, 21.210701940313793, 21.639202528110253, 22.067256960456497, 22.49487479429043, 22.922065194832083, 23.3488369590045, 23.775198537030846, 24.201158052381324, 24.626723320224514, 25.051901864520076, 25.476700933875613, 25.90112751627701, 26.32518835279041, 26.74888995032376, 27.17223859352714, 27.595240355903094, 28.0179011101914, 28.4402265380863, 28.862222139338968, 29.28389324029293, 29.70524500189577, 30.126282427226705, 30.547010368575858, 30.967433534108096, 31.387556494141396, 31.807383687067148, 32.2269194249375, 32.646167898742746, 33.06513318339999, 33.48381924247247, 33.90222993263735, 34.32036900791867, 34.738240123700486, 35.155846840534345, 35.573192627754004, 35.99028086690948, 36.40711485503149, 36.82369780773665, 37.24003286218302, 37.65612307988476, 38.07197144939434, 38.487580888859895, 38.90295424846487, 39.318094312756706, 39.73300380287073, 40.147685378655105, 40.562141640702194, 40.97637513229161, 41.3903883412494, 41.80418370172812, 42.21776359591168, 42.63113035564919, 43.04428626402121, 43.45723355684187, 43.869974424100306], [0.0, 0.5568959657941943, 1.0758520895846009, 1.5813910036424421, 2.078409235758947, 2.5691861724955944, 3.055046041306315, 3.53685462849079, 4.015221974384982, 4.490600866240501, 4.96334051956974, 5.433718339722771, 5.9019599156716085, 6.368252232520268, 6.832752751570485, 7.295595855274282, 7.7568975475116, 8.216758961552248, 8.675269030806163, 9.132506557760118, 9.58854184135426, 10.043437974469835, 10.497251890966838, 10.950035219828884, 11.40183498881085, 11.852694209284174, 12.30265236629616, 12.751745832265676, 13.200008218606262, 13.647470676477324, 14.094162155525918, 14.540109627693298, 14.985338281778985, 15.429871693378525, 15.87373197396421, 16.316939902207338, 16.759515040104617, 17.201475836040665, 17.642839716569775, 18.083623168416274, 18.52384181196003, 18.963510467282198, 19.40264321368756, 19.841253443487812, 20.279353910719802, 20.716956775380023, 21.154073643678554, 21.590715604749334, 22.026893264197618, 22.46261677481725, 22.89789586476946, 23.332739863479546, 23.767157725477354, 24.201158052381324, 24.634749113202815, 25.067938863127956, 25.50073496091665, 25.93314478504347, 26.36517544869197, 26.796833813702094, 27.22812650356039, 27.659059915513538, 28.089640231877734, 28.51987343060952, 28.949765295197096, 29.37932142392589, 29.808547238566888, 30.237447992531866, 30.666028778535864, 31.094294535803243, 31.522250056850968, 31.94989999387942, 32.37724886479878, 32.80430105891647, 33.23106084230911, 33.65753236290056, 34.08371965526574, 34.50962664517854, 34.935257153920595, 35.36061490236629, 35.78570351485846, 36.210526522887896, 36.6350873685889, 37.059389408062216, 37.48343591453586, 37.90723008137362, 38.33077502494014, 38.75407378733119, 39.1771293389768, 39.599944581124674, 40.02252234821057, 40.44486541012204, 40.866976474361394, 41.28885818811357, 41.710513140223895, 42.13194386309063, 42.55315283447692, 42.97414247924619, 43.39491517102526, 43.81547323379865, 44.23581894343763, 44.65595452916745], [0.0, 0.5666887029983826, 1.0947704108348797, 1.6091989740120123, 2.1149570233147776, 2.6143640271780284, 3.1087674989335823, 3.5990484493004518, 4.08582764586899, 4.569565837928311, 5.050618381771041, 5.529267560781679, 6.0057429308015555, 6.480234764974281, 6.9529032934798725, 7.423885261818609, 7.8932987137406725, 8.361246560893877, 8.827819300537717, 9.29309712086131, 9.757151556976526, 10.220046811221396, 10.681840818609379, 11.142586115993966, 11.602330558089596, 12.061117912601176, 12.518988358900831, 12.975978908998234, 13.432123765346834, 13.8874546268836, 14.342000952320666, 14.79579018788739, 15.248847965315742, 15.701198274766332, 16.15286361653064, 16.603865134662517, 17.0542227351466, 17.50395519077313, 17.95308023453365, 18.401614643063294, 18.849574311418497, 19.29697432028414, 19.743828996542536, 20.190151968002496, 20.63595621297422, 21.081254105281673, 21.52605745522433, 21.970377546933012, 22.414225172507237, 22.857610663272656, 23.300543918455354, 23.743034431533903, 24.18509131449909, 24.626723320224514, 25.067938863127956, 25.508746038283526, 25.949152639126588, 26.389166173878507, 26.82879388080461, 27.268042742406866, 27.706919498642527, 28.145430659250657, 28.58358251526039, 29.021381149747647, 29.45883244790038, 29.895942106447066, 30.332715642497824, 30.769158401843047, 31.205275566750625, 31.641072163298716, 32.076553068278294, 32.51172301569636, 32.9465866029083, 33.381148296405286, 33.815412437280784, 34.24938324639781, 34.68306482927728, 35.11646118072585, 35.54957618922048, 35.982413641065264, 36.41497722433531, 36.847270532620904, 37.279297068584555, 37.71106024734237, 38.142563399680434, 38.573809775116246, 39.00480254481415, 39.43554480436367, 39.86603957642836, 40.296289813272914, 40.72629839917522, 41.156068152729915, 41.58560182904939, 42.01490212186801, 42.44397166555465, 42.87281303703853, 43.301428757653014, 43.72982129490155, 44.15799306414999, 44.58594643024897, 45.0136837090898, 45.44120716909756], [0.0, 0.5764725412571948, 1.1136715404559028, 1.636981674469383, 2.1514715988321047, 2.659500827428729, 3.162440138308405, 3.661185752774604, 4.156369155923902, 4.648459051847579, 5.137816932038192, 5.624729953481854, 6.109431635284403, 6.592115535641101, 7.0729446510940965, 7.552058088044545, 8.029575928259186, 8.50560286014777, 8.980230943398238, 9.45354175064282, 9.925608052041769, 10.396495158381695, 10.866262004919758, 11.334962035554307, 11.802643931207864, 12.269352215231502, 12.735127760691213, 13.200008218606264, 13.664028381932908, 14.127220496887912, 14.589614530785871, 15.051238403713254, 15.512118189931975, 15.97227829379098, 16.431741604047605, 16.890529629806213, 17.34866262072679, 17.806159673710404, 18.26303882790737, 18.719317149600176, 19.17501080827223, 19.630135144975313, 20.084704733944292, 20.53873343827108, 20.992234460335446, 21.445220387594496, 21.897703234251647, 22.349694479257394, 22.801205101036064, 23.252245609282863, 23.702826074133277, 24.152956152970088, 24.602645115101918, 25.051901864520076, 25.50073496091665, 25.949152639126588, 26.39716282713834, 26.844773162802163, 27.29199100935148, 27.73882346984065, 28.18527740059178, 28.631359423734086, 29.077075938910866, 29.522433134221885, 29.96743699646243, 30.41209332071457, 30.856407719340915, 31.30038563042654, 31.744032325710798, 32.18735291804671, 32.63035236842269, 33.07303549257802, 33.51540696724106, 33.95747133601665, 34.39923301494691, 34.84069629776772, 35.28186536088152, 35.722744268065, 36.16333697492939, 36.603647333149055, 37.043679094473426, 37.48343591453587, 37.92292135647209, 38.36213889435992, 38.80109191649124, 39.239783728486195, 39.67821755625908, 40.11639654884451, 40.55432378109212, 40.99200225623723, 41.429434908354565, 41.866624604701585, 42.30357414795751, 42.74028627836381, 43.176763675771554, 43.61300896160044, 44.04902470071448, 44.484813403218375, 44.920377526179095, 45.35571947527624, 45.79084160638482, 46.22574622709409], [0.0, 0.5862476473692739, 1.1325558006814078, 1.664739578664733, 2.1879535848254763, 2.7045973427572525, 3.216064874462613, 3.7232675982539307, 4.226847707168552, 4.727281853000204, 5.2249376569656665, 5.720107145302937, 6.21302779684512, 6.703896451907202, 7.192878870924457, 7.680116519091801, 8.165731514373585, 8.64983032035572, 9.132506557760118, 9.613843182426498, 10.093914198461201, 10.572786024110124, 11.050518593981394, 11.527166258208682, 12.002778523185194, 12.477400667233749, 12.95107425649508, 13.423837580427723, 13.895726021963718, 14.36677237411116, 14.837007112333195, 15.306458630150468, 15.77515344395988, 16.243116371929045, 16.71037069093445, 17.17693827480516, 17.642839716569775, 18.108094436950907, 18.57272078098441, 19.03673610434162, 19.500156850687976, 19.962998621209778, 20.425276237273692, 20.88700379704474, 21.348194726772267, 21.80886182735586, 22.269017316720888, 22.728672868463654, 23.18783964716697, 23.646528340736428, 24.10474919006437, 24.562512016291496, 25.01982624590386, 25.476700933875613, 25.93314478504347, 26.389166173878507, 26.844773162802163, 27.29997351917787, 27.754774731095644, 28.209184022054615, 28.663208364637903, 29.116854493264572, 29.570128916095126, 30.023037926159454, 30.475587611769484, 30.927783866273103, 31.3796323972004, 31.831138734848746, 32.28230824034912, 32.73314611325195, 33.18365739866793, 33.63384699399569, 34.083719655265746, 34.53328000312774, 34.98253252850556, 35.431481597942934, 35.88013145866055, 36.32848624334359, 36.77654997467762, 37.22432656964892, 37.67181984362444, 38.11903351422524, 38.56597120500626, 39.012636448954424, 39.45903269181607, 39.90516329526396, 40.351031539913414, 40.7966406281965, 41.24199368710231, 41.687093770791314, 42.13194386309063, 42.576546879877135, 43.020905671354384, 43.46502302422947, 43.90890166379504, 44.35254425592159, 44.795953408964905, 45.23913167559293, 45.68208155453653, 46.12480549226783, 46.56730588460985, 47.009585078281084], [0.0, 0.5960141821360636, 1.1514235021593073, 1.6924731432182787, 2.224403581427101, 2.7496543150056505, 3.269642589528317, 3.785295006990812, 4.297264458981944, 4.806035538028913, 5.311981989697839, 5.815400705208986, 6.316533119650616, 6.8155793525794985, 7.312707925900504, 7.808062661533988, 8.301767711856463, 8.793931314073436, 9.284648648571986, 9.774004053186445, 10.262072764887254, 10.74892230840852, 11.23461361683305, 11.719201945735199, 12.202737626255038, 12.685266691025133, 13.166831398653233, 13.647470676477324, 14.127220496887912, 14.606114199204965, 15.084182766594598, 15.56145506559651, 16.037958054354895, 16.51371696449318, 16.988755460666678, 17.463095781109345, 17.936758861917305, 18.409764447350785, 18.882131188062953, 19.353876728860225, 19.82501778734967, 20.29557022462401, 20.765549108965004, 21.23496877340466, 21.703842867865596, 22.17218440650272, 22.640005810784732, 23.107318948783046, 23.57413517107575, 24.040465343622532, 24.50631987792288, 24.971708758731808, 25.436641569574984, 25.90112751627701, 26.36517544869197, 26.82879388080461, 27.29199100935148, 27.754774731095644, 28.21715265887421, 28.679132136525475, 29.140720252791617, 29.601923854283097, 30.06274955758247, 30.523203760557738, 30.98329265294846, 31.443022226282164, 31.90239828317298, 32.36142644604972, 32.82011216535659, 33.278460727265426, 33.73647726093544, 34.19416674535298, 34.65153401578119, 35.10858376984697, 35.565320573290315, 36.021748865398955, 36.47787296414972, 36.93369707107587, 37.38922527587849, 37.84446156079851, 38.299409804764615, 38.75407378733119, 39.208457192419445, 39.66256361187375, 40.11639654884451, 40.569959421007944, 41.02325556363245, 41.476288232500714, 41.92906060669558, 42.381575791258, 42.83383681972389, 43.28584665654686, 43.73760819941315, 44.189124281454745, 44.64039767336603, 45.091431085429306, 45.542227169454, 45.99278852063397, 46.44311767932745, 46.893217132763326, 47.34308931667759, 47.79273661688367], [0.0, 0.6057723006771053, 1.1702749445608018, 1.7201828086156083, 2.2608221675635765, 2.7946724598030617, 3.323174134467582, 3.8472689641517794, 4.367620529776546, 4.88472135775969, 5.398951312739076, 5.910612146724873, 6.419949247651234, 6.927166011490853, 7.432433719238526, 7.935898547509158, 8.437686681338292, 8.93790813002262, 9.436659632270365, 9.934026906719554, 10.430086422142317, 10.92490680880746, 11.418549997412047, 11.911072148190858, 12.402524416320114, 12.892953588092109, 13.382402613984878, 13.870911058666174, 14.358515483476998, 14.845249773578423, 15.331145419402022, 15.816231760098923, 16.300536195179944, 16.784084369368035, 17.266900334763164, 17.74900669369016, 18.230424725017038, 18.71117449626283, 19.19127496343465, 19.670744060224855, 20.149598777946057, 20.62785523737343, 21.105528753491054, 21.582633893995528, 22.059184532289994, 22.535193895600916, 23.010674608764905, 23.48563873416092, 23.96009780820203, 24.434062874748594, 24.907544515760215, 25.380552879465238, 25.85309770629362, 26.32518835279041, 26.796833813702094, 27.268042742406866, 27.73882346984065, 28.209184022054615, 28.679132136525475, 29.14867527732699, 29.617820649260302, 30.086575211030578, 30.554945687549004, 31.02293858143134, 31.490560183757378, 31.957816584149686, 32.424713680224485, 32.891257186462646, 33.35745264254464, 33.82330542118904, 34.28882073553117, 34.75400364607479, 35.218859067247394, 35.683391773586806, 36.14760640558463, 36.61150747520994, 37.07509937113473, 37.538386363681, 38.00137260950761, 38.46406215605391, 38.926458945755535, 39.38856682004685, 39.85038952316329, 40.31193070575595, 40.773193928329846, 41.23418266451638, 41.694900304189964, 42.15535015643788, 42.615535452391875, 43.075459347929524, 43.53512492625268, 43.994535200349844, 44.45369311534906, 44.91260155076714, 45.37126332266111, 45.829681185686795, 46.28785783506982, 46.74579590849333, 47.203497987907035, 47.66096660126146, 48.11820422417119, 48.57521328151087], [0.0, 0.6155221527236963, 1.1891104171476905, 1.7478690000415695, 2.297209902051864, 2.839652467920478, 3.376660330683389, 3.9091904206825476, 4.437916999115563, 4.96334051956974, 5.485846960570969, 6.005742930801557, 6.523277767692935, 7.038658140858137, 7.552058088044546, 8.063626138566862, 8.573490508397708, 9.081762977423761, 9.58854184135426, 10.0939141984612, 10.597957748274888, 11.100742225662286, 11.602330558089596, 12.102779809685654, 12.60214195896475, 13.100464545240452, 13.597791210274973, 14.09416215552592, 14.589614530785873, 15.0841827665946, 15.577898860219404, 16.070792623022484, 16.56289189550738, 17.054222735146602, 17.544809581156564, 18.03467539964453, 18.523841811960025, 19.012329208607046, 19.500156850687976, 19.98734296053637, 20.473904802938538, 20.959858758132114, 21.445220387594496, 21.930004493488088, 22.414225172507237, 22.89789586476946, 23.381029398307003, 23.86363802964176, 24.345733480864347, 24.827326973585098, 25.308429260079322, 25.78905065191021, 26.26920104627908, 26.74888995032376, 27.22812650356039, 27.706919498642527, 28.18527740059178, 28.663208364637903, 29.140720252791617, 29.617820649260302, 30.094516874805738, 30.570816000132844, 31.046724858389656, 31.52225005685097, 31.997397987850956, 32.47217483902412, 32.946586602908305, 33.420639085958435, 33.89433791701566, 34.367688555272, 34.84069629776772, 35.31336628645495, 35.78570351485846, 36.25771283436185, 36.72939896014501, 37.20076647679678, 37.67181984362444, 38.14256339968044, 38.61300136852471, 39.083137862739775, 39.55297688821443, 40.02252234821058, 40.49177804722681, 40.960747694671134, 41.429434908354565, 41.89784321781631, 42.3659760674905, 42.83383681972389, 43.301428757653014, 43.76875508794903, 44.23581894343763, 44.70262338560113, 45.16917140696912, 45.63546593340401, 46.101509826286986, 46.567305884609844, 47.03285684697762, 47.49816539352674, 47.963234147763174, 48.42806567832457, 48.892662500670326, 49.35702707870324], [0.0, 0.6252638828927287, 1.207930199301394, 1.775532128157878, 2.333567324621291, 2.884595006534074, 3.4301019715218786, 3.9710602950471685, 4.508154909687327, 5.041894189595616, 5.572670222092929, 6.100794468487978, 6.626520212419436, 7.150057394413652, 7.671582806674152, 8.191247329255571, 8.70918120737579, 9.225497990036517, 9.740297528650997, 10.253668299975912, 10.765689233274497, 11.276431167091712, 11.785958024832563, 12.294327773766968, 12.801593215061438, 13.307802640423516, 13.81300038232374, 14.31722727847911, 14.820521066643588, 15.322916722281322, 15.824446749073145, 16.32514143019895, 16.825029046787648, 17.324136068717483, 17.82248732199883, 18.320106136218346, 18.81701447492178, 19.313233051329025, 19.80878143138359, 20.30367812581979, 20.797940672669807, 21.2915857114176, 21.78462904982856, 22.277085724335567, 22.768970054738176, 23.260295693867604, 23.75107567278247, 24.241322441985872, 24.731047909091313, 25.22026347331101, 25.708980057094116, 26.197208135202604, 26.68495776147856, 27.17223859352714, 27.659059915513538, 28.145430659250657, 28.631359423734086, 29.116854493264572, 29.601923854283097, 30.086575211030578, 30.570816000132844, 31.054653404201257, 31.538094364530558, 32.02114559296738, 32.50381358301592, 32.98610462024098, 33.46802479202295, 33.94957999671421, 34.4307759522423, 34.91161820420064, 35.39211213346457, 35.87226296336672, 36.35207576646325, 36.83155547091952, 37.31070686654151, 37.7895346104773, 38.26804323261062, 38.74623714066714, 39.224120625052116, 39.701697863436976, 40.17897292511081, 40.65594977511159, 41.13263227815083, 41.6090242023445, 42.08512922276189, 42.56095092480344, 43.03649280741757, 43.51175828616611, 43.98675069614708, 44.46147329478288, 44.935929264481736, 45.41012171517935, 45.884053686767416, 46.35772815141529, 46.83114801579061, 47.304316123184165, 47.777235255544284, 48.2499081354253, 48.72233742785483, 49.19452574212377, 49.66647563350312, 50.1381896048913], [0.0, 0.6349976309423525, 1.2267345610168598, 1.8031725898291084, 2.3698949568677152, 2.929500720404681, 3.4834998236748707, 4.032879474851746, 4.578335269148612, 5.120383494794786, 5.659422342900776, 6.195768123425582, 6.729678062981702, 7.261365370328698, 7.791009589869309, 8.31876395047197, 8.84476072493711, 9.369115229931904, 9.891928871298894, 10.413291503149958, 10.93328328347365, 11.4519761535886, 11.96943503202257, 12.485718788446558, 13.000881046005222, 13.514970848183605, 14.02803321759461, 14.540109627693298, 15.051238403713254, 15.56145506559651, 16.070792623022484, 16.579281830602174, 17.086951409728815, 17.59382824234848, 18.099937540948567, 18.60530299829731, 19.10994691985629, 19.613890341296877, 20.117153133153916, 20.619754094326183, 21.12171103586784, 21.62304085629675, 22.12375960946449, 22.623882565882475, 23.123424268272647, 23.622398582005633, 24.12081874100008, 24.618697389581335, 25.116046620733783, 25.612878011126007, 26.109202653241557, 26.605031184907464, 27.10037381647825, 27.595240355903094, 28.089640231877734, 28.58358251526039, 29.077075938910866, 29.570128916095126, 30.06274955758247, 30.554945687549004, 31.046724858389656, 31.538094364530558, 32.029061255324514, 32.51963234710433, 33.00981423446134, 33.499613300810395, 33.98903572829672, 34.47808750709484, 34.96677444414571, 35.45510217137335, 35.943076153419454, 36.430701694930505, 36.91798394742929, 37.40492791580001, 37.891538464413586, 38.37782032291789, 38.8637780917153, 39.34941624714838, 39.83473914641297, 40.31975103221608, 40.80445603719516, 41.28885818811357, 41.77296140984646, 42.25676952916966, 42.74028627836381, 43.223515298644806, 43.70646014343066, 44.18912428145475, 44.671511099733934, 45.153623906400306, 45.635465933404, 46.117040339094395, 46.59835021068647, 47.07939856661859, 47.56018835880775, 48.040722474807424, 48.521003739873734, 49.00103491894415, 49.48081871853391, 49.960357788553864, 50.43965472405397, 50.91871206689637], [0.0, 0.6447235320109391, 1.2455237633642136, 1.8307907688012708, 2.406193303145373, 2.9743702329802257, 3.5368546284907905, 4.094648818362104, 4.6484590518475795, 5.198809524872557, 5.746104527416515, 6.290665214179941, 6.832752751570485, 7.372583613946192, 7.9103400956902945, 8.446177772591506, 8.980230943398238, 9.512616691018108, 10.043437974469837, 10.572786024110124, 11.100742225662286, 11.627379622329615, 12.152764126960399, 12.676955510899226, 13.200008218606264, 13.721972044737988, 14.24289270149331, 14.762812297552845, 15.28176974515619, 15.799801108284326, 16.316939902207338, 16.83321735258728, 17.34866262072679, 17.86330300030757, 18.377164089982486, 18.89026994540856, 19.40264321368756, 19.914305252682393, 20.425276237273696, 20.93557525429238, 21.445220387594496, 21.954228794522997, 22.462616774817253, 22.9703998328785, 23.477592734171367, 23.984209556434553, 24.49026373628318, 24.99576811170861, 25.50073496091665, 26.005176037889203, 26.50910260500714, 27.0125254630311, 27.515454978701847, 28.0179011101914, 28.51987343060952, 29.021381149747647, 29.522433134221885, 30.023037926159454, 30.523203760557738, 31.02293858143134, 31.52225005685097, 32.02114559296738, 32.51963234710433, 33.01771723999657, 33.51540696724106, 34.012708010023836, 34.50962664517855, 35.00616895462787, 35.50234083425437, 35.99814800224309, 36.493596006934574, 36.988690234223576, 37.48343591453587, 37.97783812941262, 38.4719018177296, 38.96563178157604, 39.45903269181607, 39.95210909335389, 40.44486541012204, 40.93730594981069, 41.429434908354565, 41.921256374192716, 42.41277433231536, 42.90399266811091, 43.39491517102526, 43.885545538044745, 44.375887377013086, 44.86594420979229, 45.35571947527624, 45.845216532265844, 46.33443866221319, 46.8233890718423, 47.3120708956533, 47.80048719831628, 48.28864097696106, 48.77653516336819, 49.264172626066596, 49.751556172342774, 50.238688550166124, 50.72557245003467, 51.212210506745315, 51.69860530109245], [0.0, 0.6544417168406867, 1.2642980589207327, 1.858387036336771, 2.4424628514014013, 3.0192041474273115, 3.5901671032013285, 4.156369155923903, 4.71852720043596, 5.277173334085133, 5.832717940881212, 6.385487016422499, 6.935745663786076, 7.483713620337648, 8.029575928259188, 8.57349050839771, 9.11559368384228, 9.65600430233968, 10.194826874852563, 10.73215400689058, 11.268068310937764, 11.802643931207863, 12.335947774080827, 12.868040511859476, 13.398977409667879, 13.92880901273799, 14.457581722307626, 14.985338281778988, 15.512118189931979, 16.0379580543549, 16.56289189550738, 17.08695140972882, 17.610166197882243, 18.132563965058317, 18.65417069576901, 19.17501080827223, 19.695107291038884, 20.21448182386779, 20.73315488574392, 21.251145851201898, 21.76847307668322, 22.285153978150575, 22.80120510103606, 23.316642183445175, 23.831480213408508, 24.345733480864343, 24.859415624963468, 25.37253967720961, 25.885118100883055, 26.39716282713834, 26.90868528811887, 27.419696447389626, 27.930206827953548, 28.4402265380863, 28.949765295197096, 29.45883244790038, 29.96743699646243, 30.475587611769484, 30.98329265294846, 31.490560183757378, 31.997397987850956, 32.50381358301592, 33.00981423446134, 33.51540696724106, 34.020598577877564, 34.52539564525047, 35.02980454080675, 35.533831438144404, 36.037482322017105, 36.54076299680245, 37.043679094473426, 37.5462360821086, 38.04843926897412, 38.55029381320734, 39.05180472812974, 39.55297688821443, 40.053815034731414, 40.554323781092116, 41.05450761791284, 41.55437091781536, 42.05391793998146, 42.55315283447691, 43.05207964635937, 43.550702319583294, 44.049024700714476, 44.54705054246544, 45.044783507062455, 45.542227169453994, 46.03938502036982, 46.53626046923944, 47.032856846977616, 47.529177408644664, 48.025225335988324, 48.52100373987373, 49.016515662607674, 49.511764080162635, 50.0067519043061, 50.50148198463994, 50.99595711055482, 51.490180013103775, 51.984153366799084, 52.47787979133653], [0.0, 0.6641523119870781, 1.2830576921754941, 1.885961751809198, 2.4787040739575628, 3.0640030475975304, 3.643437942070495, 4.218041291292912, 4.788540627379254, 5.355475942928616, 5.919263711221795, 6.480234764974281, 7.038658140858136, 7.594756836698387, 8.14871864032978, 8.700703815826193, 9.250850709036387, 9.799279931168, 10.346097543915587, 10.891397526867786, 11.435263718311276, 11.977771362610396, 12.518988358900831, 13.05897627974001, 13.597791210274973, 14.135484445726979, 14.672103075834626, 15.207690478225993, 15.742286737763216, 16.27592900521737, 16.8086518058431, 17.340487306289535, 17.871465546636824, 18.40161464306329, 18.93096096563866, 19.459529294938534, 19.987342960536367, 20.514423963915462, 21.040793087927625, 21.566469994586498, 22.09147331270615, 22.615820716667024, 23.139528997402063, 23.662614126538507, 24.18509131449909, 24.706975063255967, 25.228279214337405, 25.749016992608365, 26.26920104627908, 26.788843483538358, 27.307955906159545, 27.82654944038482, 28.344634765357263, 28.862222139338968, 29.37932142392589, 29.895942106447066, 30.41209332071457, 30.927783866273103, 31.443022226282164, 31.957816584149686, 32.47217483902412, 32.98610462024098, 33.499613300810395, 34.012708010023836, 34.52539564525047, 35.03768288298722, 35.54957618922048, 36.061081829152, 36.57220587633712, 37.0829542212787, 37.59333257951683, 38.10334649925052, 38.613001368524706, 39.12230242201309, 39.63125474742476, 40.13986329156015, 40.64813286604015, 41.156068152729915, 41.66367370887743, 42.17095397198536, 42.67791326443315, 43.184555797865194, 43.69088567735963, 44.19690690539125, 44.70262338560112, 45.20803892638447, 45.71315724430759, 46.217981967364, 46.722516638078844, 47.22676471647069, 47.73072958287835, 48.23441454066068, 48.737822818776124, 49.240957574248796, 49.74382189452719, 50.24641879974119, 50.74875124486306, 51.250822121777006, 51.75263426126263, 52.25419043489628, 52.75549335687462, 53.2565456857644], [0.0, 0.6738554400152905, 1.3018028999088125, 1.9135152632610597, 2.5149174282432734, 3.108767498933582, 3.6966678174720946, 4.27966600288241, 4.858500216372842, 5.43371833972277, 6.005742930801556, 6.574909655722296, 7.141491481727232, 7.7057146645935335, 8.267769735697403, 8.827819300537719, 9.386003726167502, 9.94244538589921, 10.497251890966838, 11.050518593981394, 11.602330558089596, 12.152764126960399, 12.701888191721828, 13.249765224493652, 13.796452129815318, 14.342000952320667, 14.88645946971965, 15.429871693378526, 15.972278293790982, 16.513716964493184, 17.054222735146602, 17.593828242348483, 18.132563965058317, 18.670458430225995, 19.207538393182507, 19.74382899654254, 20.279353910719802, 20.814135458634723, 21.34819472677227, 21.881551664404046, 22.41422517250724, 22.946233183681347, 23.477592734171367, 24.008320028946713, 24.538430500651256, 25.067938863127956, 25.59685916012696, 26.12520480972577, 26.65298864492235, 27.18022295080365, 27.70691949864253, 28.23308957723326, 28.758744021739002, 29.28389324029293, 29.808547238566888, 30.332715642497824, 30.856407719340915, 31.3796323972004, 31.90239828317298, 32.424713680224485, 32.946586602908305, 33.46802479202295, 33.98903572829672, 34.50962664517855, 35.02980454080675, 35.54957618922048, 36.06894815087287, 36.587926782498954, 37.10651824638747, 37.62472851910032, 38.14256339968044, 38.66002851738488, 39.1771293389768, 39.69387117560741, 40.21025918931616, 40.726298399175235, 41.24199368710231, 41.7573498033636, 42.27237137178757, 42.78706289470787, 43.30142875765302, 43.815473233798656, 44.329200488197266, 44.842614581798976, 45.35571947527624, 45.86851903266414, 46.38101702482726, 46.89321713276333, 47.405122950753075, 47.916737989365195, 48.42806567832457, 48.939109369251454, 49.44987233827869, 49.960357788553864, 50.470568852632454, 50.980508594767834, 51.49018001310378, 51.99958604177434, 52.50872955291623, 53.017613358597934, 53.526240212669975, 54.03461281254023], [0.0, 0.6835512196845535, 1.3205339115483965, 1.9410479079272953, 2.5511033574836497, 3.1534980493197917, 3.7498573809010867, 4.341244044934042, 4.928406823671209, 5.511901482097624, 6.092156658063243, 6.669512847418345, 7.244246944998663, 7.816588462066195, 8.386730671460871, 8.95483851833336, 9.521054389410253, 10.08550241877435, 10.648291766025588, 11.209519155757532, 11.76927087504933, 12.327624366042029, 12.88464951110474, 13.440409681238316, 13.994962599754073, 14.54836106013089, 15.100653527529051, 15.651884646573059, 16.20209567294464, 16.751324842534004, 17.29960768902746, 17.846977318614446, 18.39346464880145, 18.939098616998837, 19.483906363507092, 20.027913392705816, 20.571143715590836, 21.113619976276276, 21.65536356465033, 22.196394717025008, 22.73673260633451, 23.276395423201823, 23.81540044899823, 24.353764121858596, 24.891502096479638, 25.42862929841468, 25.96515997348259, 26.50110773282708, 27.036485594093925, 27.571306019134234, 28.105580948592014, 28.63932183369053, 29.17253966549486, 29.70524500189577, 30.237447992531866, 30.769158401843047, 31.30038563042654, 31.831138734848746, 32.36142644604972, 32.891257186462646, 33.420639085958435, 33.94957999671421, 34.47808750709484, 35.00616895462787, 35.533831438144404, 36.061081829152, 36.587926782498954, 37.114372746384305, 37.64042597176296, 38.16609252119067, 38.69137827715001, 39.216288949894675, 39.740830084846436, 40.26500706957609, 40.78882514039718, 41.31228938859887, 41.83540476634239, 42.358176092243255, 42.88060805665994, 43.402705226707994, 43.92447205101719, 44.445912864247816, 44.96703189138129, 45.48783325179878, 46.008320963160934, 46.52849894510057, 47.04837102273942, 47.567940930039285, 48.08721231299728, 48.60618873269397, 49.124873668202895, 49.64327051936913, 50.161382609464226, 50.6792131877243, 51.196765431777656, 51.71404244996773, 52.23104728357713, 52.74778290895773, 53.264252239572045, 53.780458127950055, 54.2964033675661, 54.81209069463974], [0.0, 0.6932397661213675, 1.3392509495039846, 1.9685600127271565, 2.5872622913459855, 3.198195229881238, 3.803007263923834, 4.402776148617941, 4.998261279336851, 5.590026298390237, 6.178505919072872, 6.764045463369146, 7.346925750778218, 7.92737954561827, 8.50560286014777, 9.08176297742376, 9.65600430233968, 10.228452728435109, 10.799218962520817, 11.368401100149397, 11.936086651419359, 12.502354156124353, 13.067274487135096, 13.630911913662942, 14.193324977180255, 14.754567219452298, 15.314687792576844, 15.87373197396421, 16.431741604047605, 16.988755460666678, 17.544809581156564, 18.099937540948567, 18.654170695769007, 19.207538393182507, 19.76006815817186, 20.311785856611692, 20.862715839825874, 21.412881072882612, 21.962303248846972, 22.511002890857238, 23.05899944360174, 23.606311355534455, 24.152956152970088, 24.698950507035015, 25.244310294313138, 25.789050651910202, 26.33318602756305, 26.87673022533759, 27.419696447389626, 27.962097332202575, 28.50394498966524, 29.045251033308702, 29.586026609983644, 30.126282427226705, 30.666028778535864, 31.205275566750625, 31.744032325710798, 32.28230824034912, 32.82011216535659, 33.35745264254464, 33.89433791701566, 34.4307759522423, 34.96677444414571, 35.50234083425437, 36.037482322017105, 36.57220587633712, 37.10651824638747, 37.64042597176296, 38.17393539201852, 38.707052655639615, 39.239783728486195, 39.77213440174818, 40.30411029944727, 40.83571688551683, 41.36695947048908, 41.89784321781631, 42.428373149850906, 42.95855415350666, 43.48839098562245, 44.0178882780474, 44.54705054246544, 45.07588217497567, 45.6043874604437, 46.13257057663815, 46.66043559816537, 47.187986500214436, 47.71522716212371, 48.24216137077963, 48.76879282385705, 49.29512513291074, 49.821161826326076, 50.346906352137, 50.87236208071858, 51.3975323073611, 51.92242025473205, 52.447029075232045, 52.971361853250336, 53.495421607325156, 54.01921129221395, 54.54273380087803, 55.06599196638597, 55.5889885637401], [0.0, 0.7029211909824057, 1.3579542294820506, 1.9960518947267902, 2.6233946465477187, 3.242859555735282, 3.856118079071756, 4.464263023067312, 5.068064388414792, 5.668093688958275, 6.264791708971589, 6.858508593025776, 7.449529082398599, 8.038089192073256, 8.624387671713146, 9.2085941405632, 9.790855020200253, 10.371297962327374, 10.950035219828884, 11.527166258208682, 12.102779809685652, 12.676955510899225, 13.24976522449365, 13.821274117230551, 14.391541548141953, 14.960621806729474, 15.528564731523439, 16.095416232254852, 16.661218733678584, 17.226011555185355, 17.78983123738892, 18.352711824617543, 18.914685110495256, 19.475780852439446, 20.03602695983247, 20.595449659778254, 21.15407364367855, 21.71192219731973, 22.269017316720888, 22.825379811635745, 23.381029398307, 23.935984782830126, 24.490263736283175, 25.043883162612794, 25.596859160126957, 26.149207077328338, 26.70094156372333, 27.252076616158227, 27.802625621163255, 28.35260139372429, 28.90201621285052, 29.45088185426155, 29.99920962047916, 30.547010368575858, 31.094294535803243, 31.641072163298716, 32.18735291804671, 32.73314611325195, 33.278460727265426, 33.82330542118904, 34.367688555272, 34.91161820420064, 35.45510217137335, 35.99814800224309, 36.54076299680245, 37.0829542212787, 37.62472851910032, 38.16609252119067, 38.707052655639615, 39.24761515679916, 39.78778607384533, 40.327571278844786, 40.86697647436139, 41.40600720063494, 41.94466884236177, 42.482966635104276, 43.02090567135438, 43.55849090627396, 44.095727163133425, 44.63261913846789, 45.16917140696911, 45.70538842612981, 46.241274540655795, 46.776833986660236, 47.312070895653285, 47.846989298339444, 48.3815931282339, 48.91588622510876, 49.44987233827868, 49.98355512973553, 50.516938177140254, 51.05002497668025, 51.58281894579948, 52.11532342580854, 52.64754168438101, 53.179476917942274, 53.71113225395658, 54.24251075311747, 54.773615411447004, 55.30444916230806, 55.8350148783344, 56.36531537328256], [0.0, 0.7125956026078565, 1.376643960782042, 2.02352386157468, 2.6595008274287295, 3.287491526699001, 3.9091904206825476, 4.525705356352315, 5.137816932038192, 5.746104527416515, 6.351014993342338, 6.952903293479874, 7.552058088044545, 8.148718640329783, 8.743086435420931, 9.335333427058478, 9.925608052041769, 10.514039718963737, 11.100742225662286, 11.685816406600223, 12.269352215231502, 12.851430384246775, 13.432123765346834, 14.011498422193386, 14.589614530785873, 15.16652712782061, 15.742286737763218, 16.316939902207338, 16.890529629806217, 17.463095781109345, 18.03467539964453, 18.60530299829731, 19.175010808272226, 19.74382899654254, 20.311785856611692, 20.87890797655125, 21.445220387594496, 22.010746696013623, 22.5755092005623, 23.139528997402067, 23.702826074133277, 24.26541939430625, 24.827326973585098, 25.38856594856806, 25.949152639126588, 26.50910260500714, 27.06843069733949, 27.627151105610675, 28.18527740059178, 28.742822573643277, 29.299799072772245, 29.8562188357693, 30.41209332071457, 30.967433534108096, 31.522250056850968, 32.076553068278294, 32.63035236842269, 33.18365739866793, 33.73647726093544, 34.28882073553117, 34.84069629776772, 35.39211213346457, 35.943076153419454, 36.493596006934574, 37.043679094473426, 37.59333257951683, 38.14256339968044, 38.69137827715001, 39.239783728486195, 39.78778607384533, 40.335391445659184, 40.882605796812555, 41.429434908354565, 41.97588439677619, 42.52195972088415, 43.06766618829867, 43.61300896160044, 44.15799306414999, 44.70262338560113, 45.24690468712809, 45.79084160638482, 46.33443866221319, 46.877700259115855, 47.420630691508265, 47.963234147763174, 48.505514714060276, 49.047476378052345, 49.589123032358835, 50.130458477896816, 50.671486427058696, 51.212210506745315, 51.75263426126263, 52.292761155089416, 52.832594575523224, 53.37213783521113, 53.91139417457141, 54.450366764112076, 54.98905870665147, 55.52747303944634, 56.06561273623191, 56.60348070917843, 57.141079810768595], [0.0, 0.7222631061658954, 1.3953203465754822, 2.0509762119118955, 2.695581226490529, 3.332091627955695, 3.9622248656927246, 4.587103816397612, 5.207519668469988, 5.8240596618018055, 6.437176709497474, 7.04723059087327, 7.654513882283939, 8.259269093013671, 8.861700441616515, 9.461982214661555, 10.060264862731659, 10.656679550055117, 11.251341618320229, 11.844353269971196, 12.435805678825014, 13.025780672840918, 13.614352092069993, 14.201586896433598, 14.787546078315232, 15.372285421072368, 15.955856134616127, 16.538305391951603, 17.11967678521348, 17.700010715723607, 18.279344729564723, 18.857713807845087, 19.435150619037266, 20.011685739377967, 20.58734784621743, 21.1621638883371, 21.736159236559143, 22.30935781741273, 22.881782232169936, 23.453453863195598, 24.024392969253967, 24.594618771166363, 25.164149529008323, 25.73300261186355, 26.30119456100876, 26.868741147283348, 27.435657423296526, 28.001957771038487, 28.567655945389625, 29.132765113959085, 29.697297893631134, 30.2612663841517, 30.824682199048155, 31.387556494141396, 31.94989999387942, 32.51172301569636, 33.07303549257802, 33.63384699399569, 34.19416674535298, 34.75400364607479, 35.31336628645495, 35.87226296336672, 36.430701694930505, 36.988690234223576, 37.5462360821086, 38.10334649925052, 38.66002851738488, 39.216288949894675, 39.77213440174818, 40.327571278844786, 40.882605796812555, 41.437243989296725, 41.99149171577563, 42.54535466893696, 43.098838381644924, 43.651948233526134, 44.20468945719997, 44.757067144176915, 45.30908625044678, 45.86075160177679, 46.412067898738094, 46.96303972147791, 47.513671534253064, 48.06396768973963, 48.61393243313236, 49.163569906046554, 49.71288415023388, 50.26187911112344, 50.81055864119784, 51.35892650321404, 51.90698637327765, 52.45474184377879, 53.00219642619747, 53.549353553785366, 54.096216584130936, 54.64278880161393, 55.189073419755395, 55.73507358346837, 56.2807923712149, 56.82623279707368, 57.37139781272321, 57.91629030934473], [0.0, 0.7319238037889187, 1.4139835841691546, 2.078409235758947, 2.731636224904697, 3.376660330683388, 4.015221974384983, 4.6484590518475795, 5.277173334085133, 5.901959915671608, 6.523277767692934, 7.141491481727232, 7.7568975475116, 8.369741718035806, 8.980230943398238, 9.58854184135426, 10.194826874852563, 10.799218962520818, 11.401834988810847, 12.002778523185192, 12.602141958964749, 13.200008218606262, 13.796452129815316, 14.391541548141952, 14.985338281778986, 15.577898860219403, 16.169275178337273, 16.759515040104617, 17.348662620726795, 17.93675886191731, 18.52384181196003, 19.10994691985629, 19.69510729103888, 20.279353910719802, 20.862715839825878, 21.445220387594496, 22.026893264197618, 22.607758716195946, 23.18783964716697, 23.767157725477357, 24.345733480864347, 24.923586391239148, 25.500734960916645, 26.077196791302345, 26.652988644922345, 27.228126503560386, 27.80262562116325, 28.376500572088798, 28.949765295197096, 29.52243313422188, 30.094516874805734, 30.666028778535864, 31.23698061427746, 31.807383687067148, 32.37724886479878, 32.9465866029083, 33.51540696724106, 34.083719655265746, 34.65153401578119, 35.218859067247394, 35.78570351485846, 36.35207576646325, 36.91798394742929, 37.48343591453587, 38.04843926897412, 38.613001368524706, 39.1771293389768, 39.740830084846436, 40.30411029944727, 40.86697647436139, 41.429434908354565, 41.99149171577563, 42.55315283447691, 43.11442403328918, 43.67531091908198, 44.235818943437636, 44.7959534089649, 45.35571947527623, 45.91512216465076, 46.47416636740319, 47.032856846977616, 47.59119824478344, 48.14919508478957, 48.70685177789169, 49.26417262606658, 49.82116182632608, 50.377823474482696, 50.93416156873798, 51.490180013103775, 52.04588262066616, 52.601273116700824, 53.156355141648255, 53.71113225395658, 54.26560793279925, 54.81978558067447, 55.37366852589251, 55.92726002495717, 56.48056326484658, 57.03358136519901, 57.58631738040828, 58.13877430163333, 58.69095505872666], [0.0, 0.7415777947021138, 1.4326338652534854, 2.1058232148808833, 2.7676661929927273, 3.421198092647972, 4.068182291093514, 4.709771692882872, 5.346778644297596, 5.979806089140735, 6.609319052274132, 7.23568693419695, 7.859210135311871, 8.480137650062371, 9.098679158194873, 9.715013607032645, 10.329295470493165, 10.941659420385536, 11.552223882854078, 12.161093793430645, 12.76836276409343, 13.374114811036852, 13.978425748935345, 14.58136432834586, 15.182993172704176, 15.7833695571208, 16.382546060957228, 16.98057111871439, 17.57748948826352, 18.173342651334625, 18.768169158064072, 19.362004925021456, 19.954883494296407, 20.546836259792325, 21.137892665746318, 21.72808038160148, 22.317425456643985, 22.90595245724389, 23.493684589074245, 24.080643806304977, 24.6668509094582, 25.252325633356552, 25.837086726384683, 26.42115202210863, 27.004538504150283, 27.587262365091274, 28.169339060076194, 28.750783355697, 29.33160937466573, 29.911830636718438, 30.491460096138862, 31.070510176243133, 31.648992801126425, 32.2269194249375, 32.80430105891647, 33.381148296405286, 33.95747133601665, 34.53328000312774, 35.10858376984697, 35.683391773586806, 36.25771283436185, 36.83155547091952, 37.40492791580001, 37.97783812941262, 38.55029381320734, 39.12230242201309, 39.69387117560741, 40.26500706957609, 40.83571688551683, 41.40600720063494, 41.97588439677619, 42.54535466893696, 43.11442403328918, 43.68309833475383, 44.251383254154426, 44.81928431497902, 45.38680688977719, 45.953956206216084, 46.520737352818095, 47.087155284400644, 47.65321482723709, 48.218920683956505, 48.7842774381984, 49.34928955903771, 49.91396140519376, 50.4782972290365, 51.042301180401736, 51.60597731022685, 52.16932957401714, 52.73236183515286, 53.29507786804564, 53.85748136115298, 54.41957591985852, 54.98136506922562, 55.54285225663102, 56.10404085428506, 56.66493416164441, 57.2255354077231, 57.785847753307074, 58.34587429307724, 58.90561805764558, 59.46508201550902], [0.0, 0.7512251753448985, 1.4512713761371494, 2.133218423132135, 2.8036714906792537, 3.4657053587634596, 4.1211063448702046, 4.771042351991678, 5.4163362944359355, 6.057598959860597, 6.695301422758283, 7.329817889256442, 7.961452667745628, 8.590457991903545, 9.217046269255604, 9.841398775097884, 10.463671992939696, 11.084002346571145, 11.702509802773415, 12.319300662212306, 12.934469754688864, 13.548102189386288, 14.160274767272055, 14.771057133297202, 15.38051272558226, 15.988699564344719, 16.595670912964824, 17.201475836040665, 17.806159673710404, 18.40976444735079, 19.012329208607046, 19.613890341296877, 20.21448182386779, 20.81413545863472, 21.412881072882612, 22.010746696013623, 22.607758716195942, 23.203942019390002, 23.799320113157552, 24.393915237276097, 24.98774846286722, 25.580839781489043, 26.17320818542891, 26.764871740254385, 27.35584765053178, 27.946152319496274, 28.535801403352504, 29.124809860794908, 29.7131919982616, 30.30096151137043, 30.88813152293083, 31.47471461787712, 32.06072287542816, 32.646167898742746, 33.23106084230911, 33.815412437280784, 34.39923301494691, 34.98253252850556, 35.565320573290315, 36.14760640558463, 36.72939896014501, 37.31070686654151, 37.891538464413586, 38.4719018177296, 39.05180472812974, 39.63125474742476, 40.21025918931616, 40.78882514039718, 41.36695947048908, 41.94466884236177, 42.52195972088415, 43.098838381644924, 43.67531091908198, 44.251383254154426, 44.82706114158909, 45.40235017673056, 45.97725580202129, 46.551783313136546, 47.12593786479665, 47.69972447627753, 48.27314803663883, 48.846213309687336, 49.41892493869235, 49.991287450868164, 50.56330526163784, 51.13498267869152, 51.70632390585133, 52.27733304675433, 52.84801410836406, 53.4183710043205, 53.98840755813758, 54.55812750625692, 55.12753450096555, 55.696632113185295, 56.26542383514075, 56.83391308291219, 57.40210319887982, 57.96999745406474, 58.53759905037239, 59.10491112274321, 59.67193674121521, 60.23867891290327], [0.0, 0.7608660394857152, 1.4698962979688368, 2.1605951267824914, 2.8396524679204784, 3.510182561621576, 4.173994650114381, 4.832271624698781, 5.485846960570969, 6.135339283944858, 6.781225714857512, 7.423885261818611, 8.063626138566862, 8.700703815826195, 9.33533342705848, 9.967698573960135, 10.597957748274887, 11.226249124590431, 11.852694209284174, 12.477400667233749, 13.100464545240454, 13.72197204473799, 14.342000952320669, 14.960621806729476, 15.577898860219406, 16.193890877611626, 16.808651805843102, 17.422231339183476, 18.03467539964453, 18.64602654788524, 19.25632433672094, 19.86560561690183, 20.473904802938534, 21.081254105281676, 21.687683734005287, 22.293222078227448, 22.89789586476946, 23.501730298966255, 24.104749190064375, 24.706975063255975, 25.308429260079322, 25.909132028654625, 26.50910260500714, 27.108359286549288, 27.70691949864253, 28.30479985503332, 28.902016212850523, 29.4985837227613, 30.094516874805738, 30.68982954036469, 31.284535010659443, 31.878646032133325, 32.47217483902412, 33.06513318339999, 33.65753236290056, 34.24938324639781, 34.84069629776772, 35.431481597942934, 36.021748865398955, 36.61150747520994, 37.20076647679678, 37.7895346104773, 38.37782032291789, 38.96563178157604, 39.55297688821443, 40.13986329156015, 40.726298399175235, 41.31228938859887, 41.89784321781631, 42.482966635104276, 43.06766618829867, 43.651948233526134, 44.235818943437636, 44.81928431497902, 45.40235017673056, 45.98502219584477, 46.56730588460985, 47.1492066066632, 47.730729582878354, 48.311879896946245, 48.89266250067033, 49.473082218993845, 50.05314375477557, 50.6328516933299, 51.212210506745315, 51.79122455799481, 52.36989810485033, 52.94823530361306, 53.52624021266998, 54.10391679588686, 54.68126892584677, 55.25830038694305, 55.83501487833441, 56.41141601677018, 56.987507339292506, 57.563292305821996, 58.13877430163335, 58.7139566397264, 59.28884256309831, 59.863435246921824, 60.43773780063437, 61.01175326994268], [0.0, 0.7705004783306278, 1.4885088069470485, 2.1879535848254763, 2.8756094651094672, 3.554630121992756, 4.226847707168552, 4.893460090255261, 5.555311300298755, 6.213027796845119, 6.867092741446718, 7.517889941794845, 8.165731514373585, 8.810876164795713, 9.45354175064282, 10.0939141984612, 10.73215400689058, 11.368401100149399, 12.002778523185192, 12.635395304178235, 13.266348706118993, 13.895726021963714, 14.523606023276667, 15.150060141993102, 15.77515344395988, 16.398945438105606, 17.021490754468388, 17.642839716569775, 18.26303882790737, 18.882131188062953, 19.500156850687972, 20.117153133153916, 20.733154885743918, 21.348194726772267, 21.962303248846972, 22.575509200562298, 23.187839647166967, 23.79932011315755, 24.40997470926432, 25.019826245903865, 25.62889633485091, 26.237205480616765, 26.84477316280216, 27.451617910509835, 28.057757369749275, 28.663208364637896, 29.267986953094884, 29.872108477632178, 30.475587611769484, 31.078438402533507, 31.680674309445145, 32.28230824034912, 32.883352584398786, 33.48381924247247, 34.08371965526574, 34.68306482927728, 35.28186536088152, 35.88013145866055, 36.47787296414972, 37.07509937113473, 37.67181984362444, 38.26804323261062, 38.8637780917153, 39.45903269181607, 40.053815034731414, 40.64813286604015, 41.24199368710231, 41.83540476634239, 42.428373149850906, 43.02090567135438, 43.61300896160044, 44.20468945719997, 44.7959534089649, 45.38680688977719, 45.97725580202129, 46.56730588460985, 47.1569627196302, 47.74623173863661, 48.335118228611755, 48.92362733761859, 49.51176408016264, 50.09953334228278, 50.68693988638759, 51.273988355852836, 51.860683279394664, 52.447029075232045, 53.033030055050816, 53.61869042778118, 54.2040143031993, 54.78900569536323, 55.37366852589251, 55.958006627100204, 56.5420237449855, 57.12572354209469, 57.70910960025757, 58.29218542320588, 58.87495443908024, 59.45742000283122, 60.03958539852032, 60.6214538415258, 61.20302848065822, 61.784312400190466], [0.0, 0.7801285806261317, 1.5071090745187121, 2.2152940492702946, 2.9115428134598527, 3.599048449300451, 4.279666002882409, 4.95460831229144, 5.624729953481853, 6.290665214179939, 6.9529032934798725, 7.61183279509815, 8.267769735697403, 8.920976053651678, 9.571672328870637, 10.220046811221396, 10.866262004919756, 11.510459582664172, 12.152764126960397, 12.793286028394704, 13.432123765346832, 14.069365721577698, 14.705091652973705, 15.339373884076922, 15.97227829379098, 16.603865134662517, 17.234189719381515, 17.86330300030757, 18.49125206204166, 19.11808054273393, 19.74382899654254, 20.368535207153368, 20.992234460335446, 21.614959781998486, 22.23674214703288, 22.85761066327266, 23.477592734171363, 24.096714203177303, 24.714999482306197, 25.332471667011472, 25.949152639126588, 26.56506315938531, 27.180222950803646, 27.794650774022294, 28.408364495553617, 29.021381149747643, 29.633716995181825, 30.245387566086702, 30.85640771934091, 31.466791677501504, 32.076553068278294, 32.68570496081123, 33.294259899067384, 33.90222993263735, 34.50962664517854, 35.11646118072585, 35.722744268065, 36.32848624334359, 36.93369707107587, 37.538386363681, 38.14256339968044, 38.74623714066714, 39.34941624714838, 39.95210909335389, 40.554323781092116, 41.156068152729915, 41.7573498033636, 42.358176092243255, 42.95855415350666, 43.55849090627396, 44.15799306414999, 44.757067144176915, 45.35571947527623, 45.953956206216084, 46.551783313136546, 47.1492066066632, 47.74623173863661, 48.342864208483256, 48.93910936925145, 49.53497243333386, 50.13045847789681, 50.72557245003466, 51.32031917166661, 51.91470334419161, 52.508729552916215, 53.10240227126907, 53.69572586481442, 54.28870459507688, 54.881342623187976, 55.473644013365075, 56.06561273623191, 56.65725267198976, 57.24856761344748, 57.839561268918196, 58.43023726498991, 59.02059914917669, 59.61065039245686, 60.200394391704144, 60.789834472017375, 61.37897388895388, 61.967815830671455, 62.55636341998379], [0.0, 0.7897504327565577, 1.5256972675673548, 2.2426167654184246, 2.9474528353693574, 3.643437942070494, 4.332450011147169, 5.015716839435498, 5.694103542951608, 6.368252232520268, 7.038658140858136, 7.7057146645935335, 8.369741718035806, 9.031004470221694, 9.689726221621708, 10.346097543915587, 11.000282945593266, 11.652425846698172, 12.30265236629616, 12.951074256495078, 13.597791210274973, 14.242892701493309, 14.88645946971965, 15.528564731523439, 16.169275178337273, 16.8086518058431, 17.446750608939624, 18.083623168416274, 18.719317149600176, 19.353876728860225, 19.987342960536367, 20.619754094326183, 21.251145851201894, 21.881551664404043, 22.511002890857238, 23.139528997402063, 23.767157725477354, 24.393915237276094, 25.01982624590386, 25.644914131665903, 26.269201046279083, 26.892708006533304, 27.515454978701847, 28.137460954813037, 28.758744021739002, 29.37932142392589, 29.999209620479164, 30.618424337223505, 31.236980614277467, 31.854892849614487, 32.47217483902412, 33.08883981283683, 33.704900469732905, 34.32036900791867, 34.935257153920595, 35.54957618922048, 36.16333697492939, 36.77654997467762, 37.38922527587849, 38.00137260950761, 38.61300136852471, 39.224120625052116, 39.83473914641297, 40.44486541012204, 41.05450761791284, 41.66367370887743, 42.27237137178757, 42.88060805665994, 43.48839098562245, 44.095727163133425, 44.70262338560113, 45.30908625044678, 45.91512216465076, 46.520737352818095, 47.12593786479665, 47.730729582878354, 48.335118228611755, 48.93910936925145, 49.542708423868504, 50.14592066914357, 50.74875124486306, 51.3512051591372, 51.953287293357164, 52.555002406907434, 53.156355141648255, 53.75735002618207, 54.35799147991657, 54.95828381693664, 55.55823124969585, 56.15783789253829, 56.757107765060084, 57.35604479531965, 57.95465282290511, 58.552935601866714, 59.15089680352164, 59.74854001913781, 60.34586876250349, 60.94288647238834, 61.539596514901866, 62.13600218575438, 62.73210671242539, 63.327913256244344], [0.0, 0.7993661188364192, 1.5442735485915053, 2.2699219721258523, 2.983339844764446, 3.6877989883571334, 4.3852001934021825, 5.076786205899972, 5.763432675173974, 6.4457895301340935, 7.124358033252898, 7.799536370999053, 8.471648352830854, 9.140962376377406, 9.807704460926628, 10.472067498482977, 11.1342180005261, 11.794301133324643, 12.452444551519863, 13.10876136786868, 13.763352489173075, 14.416308478688494, 15.067711059037274, 15.717634338244588, 16.3661458197513, 17.01330724189844, 17.659175281356248, 18.30380214694126, 18.947236084334598, 19.589521807779004, 20.230700871475676, 20.870811990835243, 21.509891321754235, 22.147972704542983, 22.7850878779155, 23.42126666748886, 24.056537152470582, 24.690925813594074, 25.32445766486182, 25.957156371248338, 26.589044354180952, 27.220142886341616, 27.85047217710498, 28.480051449738728, 29.10889901133352, 29.737032316297007, 30.364468024134144, 30.991222052140987, 31.61730962355856, 32.24274531166428, 32.86754308021973, 33.49171632064261, 34.11527788622726, 34.738240123700486, 35.36061490236629, 35.982413641065264, 36.603647333149055, 37.22432656964892, 37.84446156079851, 38.46406215605391, 39.083137862739775, 39.701697863436976, 40.31975103221608, 40.93730594981069, 41.55437091781536, 42.17095397198536, 42.78706289470787, 43.402705226707994, 44.0178882780474, 44.63261913846789, 45.24690468712809, 45.86075160177679, 46.47416636740319, 47.087155284400644, 47.69972447627753, 48.311879896946245, 48.92362733761859, 49.53497243333386, 50.14592066914357, 50.7564773859751, 51.36664778619488, 51.97643693888988, 52.58584978488514, 53.19489114151351, 53.80356570715267, 54.41187806554352, 55.0198326899027, 55.62743394684167, 56.23468610010314, 56.84159331412584, 57.44815965744686, 58.05438910595111, 58.660285545975995, 59.2658527772796, 59.87109451587956, 60.47601439676968, 61.0806159765207, 61.68490273577134, 62.28887808161554, 62.89254534989087, 63.49590780737332, 64.09896865388343], [0.0, 0.8089757207980267, 1.5628380758739535, 2.2972099020518644, 3.019204147427312, 3.7321319661472296, 4.437916999115564, 5.137816932038193, 5.832717940881212, 6.523277767692934, 7.210003700886643, 7.893298713740675, 8.57349050839771, 9.250850709036389, 9.92560805204177, 10.597957748274888, 11.268068310937764, 11.93608665141936, 12.602141958964749, 13.266348706118993, 13.92880901273799, 14.589614530785871, 15.248847965315745, 15.906584315244467, 16.56289189550738, 17.2178331866347, 17.871465546636827, 18.52384181196003, 19.17501080827223, 19.825017787349672, 20.473904802938538, 21.12171103586784, 21.768473076683218, 22.41422517250724, 23.05899944360174, 23.702826074133277, 24.345733480864343, 24.98774846286722, 25.628896334850914, 26.269201046279086, 26.908685288118875, 27.547370588782368, 28.185277400591776, 28.822425177907828, 29.45883244790038, 30.094516874805734, 30.72949531840154, 31.363783887334066, 31.997397987850956, 32.63035236842269, 33.26266116067659, 33.89433791701566, 34.52539564525047, 35.155846840534345, 35.78570351485846, 36.41497722433531, 37.043679094473426, 37.67181984362444, 38.299409804764615, 38.926458945755535, 39.55297688821443, 40.17897292511081, 40.80445603719516, 41.429434908354565, 42.05391793998146, 42.67791326443315, 43.30142875765302, 43.92447205101719, 44.54705054246544, 45.16917140696911, 45.79084160638482, 46.412067898738094, 47.032856846977616, 47.65321482723709, 48.27314803663883, 48.89266250067033, 49.51176408016264, 50.13045847789681, 50.74875124486306, 51.36664778619488, 51.98415336679909, 52.60127311670083, 53.21801203612141, 53.834375000305364, 54.45036676411207, 55.06599196638598, 55.68125513411865, 56.296160686414865, 56.910712938274045, 57.52491610419782, 58.13877430163333, 58.752291554261696, 59.365471795140024, 59.9783188697053, 60.59083653864738, 61.20302848065822, 61.81489829506399, 62.426449504346024, 63.03768555655671, 63.64860982763548, 64.25922562362999, 64.86953618282747], [0.0, 0.818579318474666, 1.581391003642442, 2.3244807818952484, 3.055046041306315, 3.776437243743999, 4.490600866240502, 5.198809524872557, 5.901959915671608, 6.6007175889425636, 7.295595855274282, 7.987002471763873, 8.675269030806163, 9.360670381113321, 10.043437974469837, 10.723769339144456, 11.401834988810847, 12.077783578887912, 12.751745832265675, 13.42383758042772, 14.094162155525918, 14.762812297552843, 15.429871693378525, 16.095416232254852, 16.759515040104617, 17.422231339183472, 18.083623168416274, 18.74374399148686, 19.40264321368756, 20.060366623992273, 20.716956775380027, 21.372453313807416, 22.026893264197618, 22.680311280231237, 23.332739863479546, 23.984209556434553, 24.634749113202812, 25.28438565099657, 25.933144785043467, 26.581050749118564, 27.22812650356039, 27.874393832351384, 28.519873430609515, 29.164584983644165, 29.808547238566884, 30.4517780693115, 31.094294535803243, 31.736112937919035, 32.37724886479878, 33.017717239996564, 33.65753236290056, 34.29670794679848, 34.935257153920595, 35.573192627754004, 36.210526522887896, 36.847270532620904, 37.48343591453587, 38.11903351422524, 38.75407378733119, 39.38856682004685, 40.02252234821058, 40.65594977511159, 41.28885818811357, 41.921256374192716, 42.55315283447691, 43.184555797865194, 43.815473233798656, 44.445912864247816, 45.07588217497567, 45.70538842612981, 46.33443866221319, 46.96303972147791, 47.59119824478344, 48.218920683956505, 48.846213309687336, 49.473082218993845, 50.09953334228278, 50.72557245003466, 51.3512051591372, 51.97643693888988, 52.60127311670083, 53.22571888349528, 53.84977929885371, 54.47345929589616, 55.096763685928394, 55.71969716286401, 56.34226430743585, 56.96446959120924, 57.58631738040828, 58.20781193956625, 58.82895743500975, 59.44975793818623, 60.07021742884335, 60.69033979806842, 61.310128851195614, 61.92958831058776, 62.548721818299725, 63.167532938629286, 63.78602516056173, 64.40420190011328, 65.0220665025787, 65.63962224468793], [0.0, 0.8281769896796203, 1.5999324822223244, 2.3517348326186864, 3.090865816810896, 3.8207151801315655, 4.5432522216487605, 5.259764478596392, 5.971159160579221, 6.678109621340203, 7.38113518992743, 8.080648404304641, 8.776984744718105, 9.470422282423616, 10.161195182929406, 10.849503290481834, 11.535519117991711, 12.219393063831612, 12.901257383590094, 13.581229266850643, 14.259413257312989, 14.935903182326708, 15.610783709972873, 16.284131619288964, 16.956016846684758, 17.626503355683617, 18.29564986570465, 18.963510467282198, 19.630135144975313, 20.29557022462401, 20.95985875813211, 21.62304085629675, 22.28515397815057, 22.946233183681343, 23.606311355534455, 24.265419394306246, 24.923586391239148, 25.580839781489043, 26.237205480616765, 26.892708006533308, 27.547370588782368, 28.20121526675902, 28.85426297822716, 29.5065336393023, 30.158046216901955, 30.808818794528083, 31.458868632129967, 32.108212220697176, 32.75686533214902, 33.40484306501512, 34.05215988634101, 34.69882967019981, 35.34486573314618, 35.99028086690948, 36.6350873685889, 37.279297068584555, 37.92292135647209, 38.56597120500626, 39.208457192419445, 39.85038952316329, 40.49177804722681, 41.13263227815083, 41.77296140984646, 42.41277433231536, 43.05207964635937, 43.69088567735963, 44.329200488197266, 44.96703189138129, 45.6043874604437, 46.241274540655795, 46.877700259115855, 47.513671534253064, 48.14919508478957, 48.7842774381984, 49.41892493869235, 50.05314375477557, 50.68693988638759, 51.32031917166661, 51.953287293357164, 52.58584978488514, 53.21801203612141, 53.84977929885371, 54.481156691985035, 55.112149206475245, 55.74276171004165, 56.37299895163299, 57.00286556569026, 57.63236607620694, 58.26150490060021, 58.890286353404086, 59.51871464979449, 60.14679390895574, 60.774528157297205, 61.401921331528385, 62.028977281600184, 62.65569977351937, 63.28209249204314, 63.908159043259914, 64.5339029570626, 65.1593276895195, 65.78443662514825, 66.40923307909776], [0.0, 0.8377688102812881, 1.6184626581816859, 2.378972269662063, 3.12666375709193, 3.864966125321516, 4.595871481542762, 5.320682275051035, 6.040316222615488, 6.7554544766602564, 7.4666223810239005, 8.174237251622445, 8.878638454183612, 9.58010728054242, 10.278880608276584, 10.975160596198291, 11.66912175523679, 12.360916225655847, 13.050677794808244, 13.738525009549491, 14.424563624388632, 15.108888553369411, 15.791585445185806, 16.472731968118495, 17.15239886857017, 17.830650850880048, 18.50754731454666, 19.18314297657274, 19.857488400430935, 20.530630448500137, 21.202612671304795, 21.87347564419923, 22.543257260060948, 23.211992984937176, 23.879716082315134, 24.546457810677193, 25.21224759819615, 25.877113197777717, 26.54108082513283, 27.204175282135218, 27.866420067369642, 28.527837475488113, 29.18844868675254, 29.848273847943876, 30.5073321456516, 31.165641872818057, 31.823220489294652, 32.4800846770671, 33.13625039072269, 33.791732903659934, 34.44654685047949, 35.1007062659419, 35.75422462083217, 36.40711485503149, 37.059389408062216, 37.71106024734237, 38.36213889435992, 39.012636448954424, 39.66256361187375, 40.31193070575595, 40.960747694671134, 41.6090242023445, 42.25676952916966, 42.90399266811091, 43.550702319583294, 44.19690690539125, 44.842614581798976, 45.48783325179878, 46.13257057663815, 46.776833986660236, 47.420630691508265, 48.06396768973963, 48.70685177789169, 49.34928955903771, 49.991287450868164, 50.6328516933299, 51.273988355852836, 51.91470334419161, 52.555002406907434, 53.19489114151351, 53.834375000305364, 54.47345929589616, 55.112149206475245, 55.750449780807024, 56.388365942985956, 57.025902496962416, 57.66306413085277, 58.299855421046715, 58.93628083612329, 59.57234474058678, 60.20805139843265, 60.84340497655299, 61.47840954799042, 62.11306909504881, 62.74738751226864, 63.38136860927398, 64.01501611349832, 64.64833367279526, 65.28132485794039, 65.91399316502968, 66.54634201777972, 67.17837476973502], [0.0, 0.847354854274638, 1.6369816744693826, 2.406193303145373, 3.1624401383084044, 3.9091904206825463, 4.6484590518475795, 5.381563384179638, 6.109431635284402, 6.832752751570483, 7.552058088044544, 8.267769735697403, 8.980230943398237, 9.689726221621708, 10.396495158381695, 11.100742225662286, 11.80264393120786, 12.502354156124353, 13.20000821860626, 13.895726021963714, 14.58961453078587, 15.281769745156186, 15.97227829379098, 16.661218733678584, 17.34866262072679, 18.034675399644527, 18.719317149600172, 19.40264321368756, 20.084704733944292, 20.765549108965008, 21.445220387594496, 22.12375960946449, 22.801205101036057, 23.477592734171363, 24.152956152970088, 24.827326973585095, 25.500734960916645, 26.173208185428905, 26.84477316280216, 27.51545497870185, 28.185277400591776, 28.85426297822716, 29.52243313422188, 30.189808245883412, 30.856407719340908, 31.522250056850964, 32.18735291804671, 32.85173317579499, 33.515406967241056, 34.17838974054701, 34.840696297767714, 35.50234083425436, 36.163336974929386, 36.82369780773665, 37.48343591453586, 38.142563399680434, 38.80109191649124, 39.45903269181607, 40.11639654884451, 40.773193928329846, 41.429434908354565, 42.08512922276189, 42.74028627836381, 43.39491517102526, 44.049024700714476, 44.70262338560112, 45.35571947527624, 46.008320963160934, 46.66043559816537, 47.312070895653285, 47.963234147763174, 48.61393243313236, 49.26417262606658, 49.91396140519376, 50.56330526163784, 51.212210506745315, 51.860683279394664, 52.508729552916215, 53.156355141648255, 53.80356570715267, 54.45036676411207, 55.096763685928394, 55.74276171004165, 56.388365942985956, 57.03358136519901, 57.678412835599644, 58.32286509594731, 58.966942774996355, 59.610650392456854, 60.25399236277329, 60.89697299873125, 61.53959651490186, 62.181867030932914, 62.82378857469522, 63.465365085291936, 64.10660041593817, 64.74749833671805, 65.38806253722517, 66.02829662909318, 66.6682041484216, 67.3077885581024, 67.94705325005252], [0.0, 0.8569351938492177, 1.6554896705464286, 2.4333981380618446, 3.1981952298812386, 3.953388399254219, 4.701015328584026, 5.442408264459106, 6.178505919072872, 6.910005028180412, 7.6374429543793845, 8.361246560893878, 9.08176297742376, 9.799279931168002, 10.514039718963737, 11.226249124590431, 11.936086651419359, 12.643707920362669, 13.349249779545621, 14.052833487925772, 14.7545672194523, 15.454548059602102, 16.152863616530645, 16.84959333540507, 17.544809581156564, 18.238578538423166, 18.930960965638665, 19.622012831615418, 20.311785856611692, 21.000327975118783, 21.687683734005287, 22.373894636904065, 23.058999443601735, 23.743034431533907, 24.42603362518622, 25.10802899816921, 25.789050651910205, 26.469126974242865, 27.14828478063831, 27.826549440384827, 28.503944989665243, 29.180494233186188, 29.856218835769297, 30.531139405111386, 31.20527556675063, 31.878646032133318, 32.551268660555436, 33.22316051565135, 33.89433791701566, 34.564816487470026, 35.2346111964239, 35.90373639972355, 36.572205876337115, 37.24003286218302, 37.90723008137362, 38.573809775116246, 39.239783728486195, 39.90516329526396, 40.569959421007944, 41.23418266451638, 41.89784321781631, 42.56095092480344, 43.223515298644806, 43.885545538044745, 44.54705054246544, 45.20803892638447, 45.86851903266414, 46.52849894510057, 47.187986500214436, 47.846989298339444, 48.505514714060276, 49.163569906046554, 49.82116182632608, 50.4782972290365, 51.13498267869152, 51.79122455799481, 52.447029075232045, 53.10240227126907, 53.75735002618207, 54.41187806554352, 55.06599196638598, 55.71969716286401, 56.37299895163299, 57.025902496962416, 57.678412835599644, 58.3305348813993, 58.98227342973197, 59.633633161685495, 60.28461864807057, 60.93523435324215, 61.58548463874691, 62.235373766806646, 62.88490590364659, 63.53408512267736, 64.18291540753829, 64.8314006550096, 65.47954467780062, 66.12735120722013, 66.77482389573555, 67.42196631942613, 68.06878198033591, 68.7152743087314], [0.0, 0.8665098994539242, 1.6739867825111214, 2.4605869744618616, 3.233929294735013, 3.997560386045768, 4.753540698223967, 5.503217363311435, 6.247539581917707, 6.987211874563606, 7.7227776079048756, 8.454668414592431, 9.18323530287461, 9.908769214783012, 10.631515154385031, 11.351682215896004, 12.069450897140507, 12.784978557813778, 13.498403575072116, 14.209848562723279, 14.919422903365271, 15.62722476723014, 16.333342741336516, 17.03785715850803, 17.74084119222349, 18.44236176661492, 19.142480318982056, 19.841253443487812, 20.53873343827108, 21.23496877340466, 21.930004493488084, 22.623882565882475, 23.316642183445172, 24.00832002894671, 24.698950507035015, 25.388565948568058, 26.07719679130234, 26.76487174025438, 27.451617910509835, 28.13746095481304, 28.822425177907824, 29.5065336393023, 30.189808245883412, 30.87226983560183, 31.55393825327573, 32.23483241941808, 32.914970392870295, 33.594369427922075, 34.27304602651007, 34.951015986012806, 35.62829444309589, 36.30489591400629, 36.98083433166727, 37.65612307988476, 38.33077502494014, 39.00480254481415, 39.67821755625908, 40.351031539913414, 41.02325556363245, 41.694900304189964, 42.3659760674905, 43.03649280741757, 43.70646014343066, 44.375887377013086, 45.044783507062455, 45.71315724430759, 46.38101702482726, 47.04837102273942, 47.71522716212371, 48.3815931282339, 49.047476378052345, 49.71288415023388, 50.377823474482696, 51.042301180401736, 51.70632390585133, 52.36989810485033, 53.033030055050816, 53.69572586481442, 54.35799147991657, 55.0198326899027, 55.68125513411865, 56.34226430743585, 57.00286556569026, 57.66306413085277, 58.32286509594731, 58.98227342973197, 59.64129398115695, 60.29993148361282, 60.95819055898084, 61.61607572149707, 62.2735913814406, 62.9307418486559, 63.58753133591823, 64.24396396215124, 64.90004375550423, 65.55577465629693, 66.21116051983881, 66.86620511912933, 67.52091214744561, 68.17528522082317, 68.82932788043505, 69.48304359487479], [0.0, 0.8760790398587238, 1.6924731432182785, 2.487760007628228, 3.2696425895283165, 4.0417066983208425, 4.8060355380289135, 5.563991117495715, 6.316533119650615, 7.064373845255364, 7.808062661533987, 8.54803596779205, 9.284648648571986, 10.018194858869444, 10.74892230840852, 11.477042400497508, 12.202737626255034, 12.926167083148771, 13.647470676477322, 14.366772374111157, 15.084182766594598, 15.799801108284324, 16.51371696449318, 17.226011555185355, 17.93675886191731, 18.646026547885235, 19.353876728860225, 20.060366623992273, 20.765549108965008, 21.469473189121434, 22.172184406502723, 22.87372519192871, 23.574135171075746, 24.2734514318137, 24.971708758731808, 25.668939839727834, 26.365175448691968, 27.060444607639223, 27.754774731095644, 28.44819175509686, 29.140720252791613, 29.832383538341382, 30.523203760557735, 31.213201987511354, 31.902398283172975, 32.59081177700072, 33.278460727265426, 33.96536257880135, 34.65153401578119, 35.33699101003887, 36.02174886539895, 36.70582225841585, 37.38922527587849, 38.07197144939434, 38.75407378733119, 39.43554480436367, 40.11639654884451, 40.7966406281965, 41.476288232500714, 42.15535015643788, 42.83383681972389, 43.51175828616611, 44.18912428145475, 44.86594420979229, 45.542227169453994, 46.217981967364, 46.89321713276333, 47.567940930039285, 48.24216137077963, 48.91588622510876, 49.589123032358835, 50.26187911112344, 50.93416156873798, 51.60597731022685, 52.27733304675433, 52.94823530361306, 53.61869042778118, 54.28870459507688, 54.95828381693664, 55.62743394684167, 56.296160686414865, 56.96446959120924, 57.63236607620694, 58.299855421046715, 58.966942774996355, 59.633633161685495, 60.29993148361282, 60.965842526441214, 61.631370963092806, 62.296521357655806, 62.96129816911339, 63.62570575490496, 64.28974837432882, 64.95343019179516, 65.6167552799374, 66.27972762258945, 66.94235111763619, 67.60462957974347, 68.26656674297445, 68.92816626329763, 69.58943172099237, 70.25036662295696], [0.0, 0.8856426822134986, 1.710948882392921, 2.5149174282432734, 3.3053353648733714, 4.08582764586899, 4.858500216372843, 5.624729953481855, 6.385487016422498, 7.141491481727232, 7.893298713740674, 8.641349875684307, 9.386003726167502, 10.127557631303906, 10.86626200491976, 11.602330558089596, 12.335947774080825, 13.067274487135098, 13.796452129815316, 14.523606023276667, 15.248847965315745, 15.97227829379098, 16.69398755174734, 17.41405784577984, 18.132563965058317, 18.849574311418497, 19.565151678713, 20.279353910719806, 20.99223446033545, 21.7038428678656, 22.41422517250724, 23.12342426827265, 23.831480213408508, 24.538430500651256, 25.24431029431314, 25.94915263912659, 26.652988644922345, 27.355847650531782, 28.05775736974928, 28.75874402173901, 29.458832447900384, 30.15804621690196, 30.85640771934091, 31.553938253275735, 32.25065810170379, 32.9465866029083, 33.64174221447497, 34.3361425716731, 35.02980454080675, 35.722744268065, 36.41497722433532, 37.10651824638747, 37.79738157478762, 38.487580888859895, 39.1771293389768, 39.86603957642836, 40.55432378109212, 41.24199368710231, 41.92906060669558, 42.615535452391875, 43.301428757653014, 43.98675069614708, 44.671511099733934, 45.35571947527624, 46.03938502036982, 46.722516638078844, 47.405122950753075, 48.08721231299728, 48.76879282385705, 49.44987233827868, 50.130458477896816, 50.81055864119784, 51.490180013103775, 52.16932957401714, 52.84801410836406, 53.52624021266998, 54.2040143031993, 54.881342623187976, 55.55823124969585, 56.23468610010314, 56.910712938274045, 57.58631738040828, 58.26150490060021, 58.93628083612329, 59.610650392456854, 60.28461864807057, 60.95819055898084, 61.631370963092806, 62.304164584340185, 62.97657603663464, 63.64860982763548, 64.32027036234972, 64.99156194657192, 65.66248879017269, 66.33305501024404, 67.00326463410904, 67.67312160220352, 68.34262977083577, 69.01179291483156, 69.68061473006946, 70.34909883591263, 71.01724877754214], [0.0, 0.8952008921041874, 1.729414126738731, 2.5420594225482693, 3.341007865545555, 4.129923531264654, 4.910935093050177, 5.685434287807131, 6.454401745108215, 7.218565312839697, 7.97848634906023, 8.73461077820115, 9.487301230738163, 10.236858282078902, 10.983535048615728, 11.727547547878531, 12.469082254151893, 13.208301737464899, 13.945348956777213, 14.680350585760031, 15.413419628776465, 16.144657506571225, 16.87415573936601, 17.601997319883047, 18.328257844446785, 19.053006453112904, 19.776306617430393, 20.498216805450404, 21.218791046954504, 21.938079416907144, 22.656128451378727, 23.372981507310858, 24.088679075274833, 24.803259052643696, 25.516756983237006, 26.229206268419155, 26.940638353770613, 27.651082894759153, 28.360567904277506, 29.06911988445754, 29.77676394479699, 30.483523908326895, 31.189422407292717, 31.894480969610104, 32.598720097178635, 33.30215933698801, 34.0048173458256, 34.706711949287566, 35.40786019570586, 36.1082784055257, 36.80798221660255, 37.506986625830535, 38.20530602746568, 38.90295424846487, 39.599944581124674, 40.296289813272914, 40.99200225623723, 41.687093770791314, 42.381575791258, 43.075459347929524, 43.76875508794903, 44.46147329478288, 45.153623906400306, 45.845216532265844, 46.53626046923944, 47.22676471647069, 47.916737989365195, 48.60618873269397, 49.29512513291074, 49.98355512973553, 50.671486427058696, 51.35892650321404, 52.04588262066616, 52.73236183515286, 53.4183710043205, 54.10391679588686, 54.78900569536323, 55.473644013365075, 56.15783789253829, 56.84159331412584, 57.52491610419782, 58.20781193956625, 58.890286353404086, 59.57234474058678, 60.25399236277329, 60.93523435324215, 61.61607572149707, 62.296521357655806, 62.97657603663464, 63.65624442214043, 64.33553107048095, 65.01444043420379, 65.69297686557339, 66.37114461989496, 67.04894785869381, 67.72639065275749, 68.40347698504857, 69.0802107534942, 69.75659577365955, 70.43263578131061, 71.10833443487212, 71.7836953177862], [0.0, 0.9047537336063698, 1.747869000041569, 2.569186172495595, 3.376660330683388, 4.1739946501143805, 4.96334051956974, 5.746104527416515, 6.523277767692933, 7.295595855274281, 8.06362613856686, 8.827819300537717, 9.58854184135426, 10.346097543915587, 11.100742225662286, 11.852694209284174, 12.602141958964747, 13.349249779545621, 14.094162155525916, 14.837007112333191, 15.577898860219403, 16.316939902207334, 17.054222735146602, 17.78983123738892, 18.523841811960025, 19.256324336720937, 19.987342960536367, 20.716956775380027, 21.445220387594496, 22.172184406502723, 22.89789586476946, 23.622398582005637, 24.345733480864343, 25.067938863127956, 25.789050651910205, 26.50910260500714, 27.228126503560386, 27.946152319496274, 28.663208364637896, 29.379321423925894, 30.094516874805734, 30.808818794528086, 31.522250056850964, 32.23483241941808, 32.94658660290829, 33.657532362900554, 34.367688555272, 35.07707319583876, 35.785703514858454, 36.49359600693457, 37.20076647679677, 37.90723008137362, 38.6130013685247, 39.318094312756706, 40.02252234821057, 40.72629839917522, 41.429434908354565, 42.13194386309063, 42.83383681972389, 43.53512492625268, 44.23581894343763, 44.935929264481736, 45.635465933404, 46.33443866221319, 47.032856846977616, 47.73072958287835, 48.42806567832457, 49.124873668202895, 49.821161826326076, 50.516938177140254, 51.212210506745315, 51.90698637327765, 52.601273116700824, 53.29507786804564, 53.98840755813758, 54.68126892584677, 55.37366852589251, 56.06561273623191, 56.757107765060084, 57.44815965744686, 58.13877430163333, 58.82895743500975, 59.51871464979449, 60.20805139843265, 60.89697299873125, 61.58548463874691, 62.2735913814406, 62.96129816911339, 63.64860982763548, 64.33553107048095, 65.0220665025787, 65.70822062399023, 66.39399783342373, 67.0794024315935, 67.76443862443318, 68.44911052617041, 69.13342216227065, 69.81737747225645, 70.50098031240957, 71.18423445836096, 71.86714360757507, 72.5497113817335], [0.0, 0.9143012693364417, 1.766313623268338, 2.596297855894053, 3.4122929939795226, 4.218041291292911, 5.015716839435498, 5.806741069987673, 6.5921155356411, 7.37258361394619, 8.14871864032978, 8.920976053651678, 9.689726221621708, 10.45527613284896, 11.217884304322045, 11.977771362610396, 12.735127760691212, 13.49011953725509, 14.242892701493309, 14.993576629839005, 15.742286737763216, 16.48912660996569, 17.234189719381515, 17.97756082950002, 18.719317149600172, 19.459529294938534, 20.19826209131936, 20.935575254292377, 21.671523966440965, 22.406159371149762, 23.139528997402063, 23.871677127221147, 24.602645115101918, 25.332471667011472, 26.06119308514704, 26.788843483538358, 27.515454978701847, 28.241057858846617, 28.965680734560095, 29.689350673434618, 30.41209332071457, 31.13393300772905, 31.854892849614487, 32.574994833615065, 33.29425989906739, 34.012708010023836, 34.73035822134071, 35.44722873894848, 36.16333697492939, 36.87869959794843, 37.59333257951683, 38.30725123650867, 39.020470270301786, 39.73300380287073, 40.44486541012204, 41.156068152729915, 41.866624604701585, 42.576546879877135, 43.28584665654686, 43.994535200349844, 44.70262338560113, 45.41012171517935, 46.117040339094395, 46.8233890718423, 47.529177408644664, 48.23441454066068, 48.939109369251454, 49.64327051936913, 50.346906352137, 51.05002497668025, 51.75263426126263, 52.45474184377879, 53.156355141648255, 53.85748136115298, 54.55812750625692, 55.25830038694305, 55.958006627100204, 56.65725267198976, 57.35604479531965, 58.05438910595111, 58.752291554261696, 59.44975793818623, 60.14679390895574, 60.84340497655299, 61.53959651490186, 62.235373766806646, 62.9307418486559, 63.62570575490496, 64.32027036234972, 65.01444043420379, 65.70822062399023, 66.40161547925803, 67.09462944513335, 67.78726686771435, 68.47953199731836, 69.17142899158897, 69.86296191847086, 70.55413475905898, 71.24495141032898, 71.9354156877547, 72.62553132781856, 73.31530199042047], [0.0, 0.9238435605005114, 1.7847481146614452, 2.623394646547719, 3.4479060838632316, 4.262063737168763, 5.068064388414793, 5.867344304241518, 6.660915490248981, 7.449529082398599, 8.233764399849006, 9.014081634740306, 9.790855020200254, 10.56439474878701, 11.334962035554309, 12.102779809685654, 12.868040511859476, 13.630911913662944, 14.391541548141953, 15.150060141993103, 15.906584315244467, 16.661218733678584, 17.41405784577984, 18.165187299688963, 18.91468511049526, 19.66262263044578, 20.40906536191248, 21.154073643678558, 21.897703234251647, 22.640005810784732, 23.381029398307003, 24.120818741000082, 24.859415624963468, 25.59685916012696, 26.333186027563052, 27.068430697339494, 27.80262562116325, 28.535801403352504, 29.267986953094887, 29.999209620479167, 30.72949531840154, 31.45886863212997, 32.18735291804671, 32.914970392870295, 33.64174221447497, 34.367688555272, 35.09282866898757, 35.81718095156207, 36.54076299680246, 37.263591647339645, 37.98568304137478, 38.70705265563962, 39.42771534494592, 40.147685378655105, 40.866976474361394, 41.58560182904939, 42.30357414795751, 43.020905671354384, 43.73760819941315, 44.45369311534906, 45.16917140696912, 45.884053686767416, 46.59835021068647, 47.3120708956533, 48.025225335988324, 48.737822818776124, 49.44987233827869, 50.161382609464226, 50.87236208071858, 51.58281894579948, 52.292761155089416, 53.00219642619747, 53.71113225395658, 54.41957591985852, 55.12753450096555, 55.83501487833441, 56.5420237449855, 57.24856761344748, 57.95465282290511, 58.660285545975995, 59.365471795140024, 60.07021742884335, 60.774528157297205, 61.47840954799042, 62.181867030932914, 62.88490590364659, 63.58753133591823, 64.28974837432882, 64.99156194657192, 65.69297686557339, 66.39399783342373, 67.09462944513335, 67.79487619222087, 68.49474246614339, 69.19423256157755, 69.893350679559, 70.59210093048841, 71.2904873370102, 71.9885138367716, 72.68618428506741, 73.38350245737664, 74.08047205179645], [0.0, 0.9333806669411454, 1.803172589829108, 2.6504767143886854, 3.48349982367487, 4.3060622638198796, 5.120383494794787, 5.927914610239086, 6.7296780629817015, 7.52643274317959, 8.31876395047197, 9.107136627696587, 9.891928871298894, 10.673454076045262, 11.4519761535886, 12.227720334475363, 13.00088104600522, 13.771627791720348, 14.540109627693296, 15.306458630150464, 16.07079262302248, 16.833217352587276, 17.59382824234848, 18.352711824617543, 19.10994691985629, 19.865605616901828, 20.619754094326183, 21.372453313807416, 22.123759609464493, 22.873725191928706, 23.622398582005633, 24.369824985784128, 25.11604662073378, 25.86110300052759, 26.605031184907464, 27.34786599978571, 28.08964023187773, 28.830384801439, 29.570128916095122, 30.308900208277816, 31.046724858389652, 31.78362770549949, 32.51963234710433, 33.25476122927235, 33.98903572829671, 34.722476224834374, 35.45510217137335, 36.186932153760665, 36.91798394742929, 37.64827456888153, 38.377820322917884, 39.10663684604093, 39.834739146412964, 40.562141640702194, 41.28885818811357, 42.01490212186801, 42.74028627836381, 43.46502302422947, 44.189124281454745, 44.91260155076714, 45.63546593340401, 46.35772815141529, 47.07939856661859, 47.80048719831628, 48.52100373987373, 49.240957574248796, 49.960357788553864, 50.6792131877243, 51.3975323073611, 52.11532342580854, 52.832594575523224, 53.549353553785366, 54.26560793279925, 54.98136506922562, 55.696632113185295, 56.41141601677018, 57.12572354209469, 57.839561268918196, 58.552935601866714, 59.2658527772796, 59.9783188697053, 60.69033979806842, 61.401921331528385, 62.11306909504881, 62.82378857469522, 63.53408512267736, 64.24396396215124, 64.95343019179516, 65.66248879017269, 66.37114461989496, 67.0794024315935, 67.78726686771435, 68.49474246614339, 69.20183366367202, 69.90854479931205, 70.61488011746772, 71.32084377097247, 72.02643982399769, 72.7316722548401, 73.43654495859384, 74.14106174971327, 74.84522636447208], [0.0, 0.9429126471820781, 1.8215871618317296, 2.6775442256040196, 3.519074431832739, 4.350037141239904, 5.17267447962773, 5.9884523596654935, 6.798403675795605, 7.603295068202677, 8.403717813792007, 9.200141603545474, 9.992948395149691, 10.78245478385806, 11.56892737647323, 12.352593703667635, 13.133650178294365, 13.912268034919682, 14.688597851824156, 15.462773054038621, 16.23491266874916, 17.005123522148324, 17.773502012234914, 18.54013555501587, 19.30510377589264, 20.06847949989646, 20.83032958143599, 21.590715604749334, 22.349694479257394, 23.107318948783046, 23.863638029641756, 24.618697389581335, 25.372539677209605, 26.125204809725766, 26.876730225337585, 27.627151105610675, 28.376500572088794, 29.124809860794908, 29.872108477632178, 30.61842433722351, 31.363783887334062, 32.108212220697176, 32.85173317579498, 33.594369427922075, 34.33614257167309, 35.07707319583875, 35.817180951562065, 36.55648461449464, 37.29500214159782, 38.03275072315184, 38.769746830467014, 39.50600625973085, 40.241544172373786, 40.97637513229161, 41.710513140223895, 42.44397166555465, 43.176763675771554, 43.90890166379504, 44.64039767336603, 45.37126332266111, 46.101509826286986, 46.83114801579061, 47.56018835880775, 48.28864097696106, 49.016515662607674, 49.74382189452719, 50.470568852632454, 51.196765431777656, 51.92242025473205, 52.64754168438101, 53.37213783521113, 54.096216584130936, 54.81978558067447, 55.54285225663102, 56.26542383514075, 56.987507339292506, 57.70910960025757, 58.43023726498991, 59.15089680352164, 59.87109451587956, 60.59083653864738, 61.310128851195614, 62.028977281600184, 62.74738751226864, 63.465365085291936, 64.18291540753829, 64.90004375550423, 65.6167552799374, 66.33305501024404, 67.04894785869381, 67.76443862443318, 68.47953199731836, 69.19423256157755, 69.90854479931205, 70.6224730938451, 71.33602173292607, 72.04919491179852, 72.76199673613841, 73.47443122487012, 74.1865023128657, 74.89821385353396, 75.60956962130459], [0.0, 0.9524395584709954, 1.8399919412645485, 2.704597342757253, 3.554630121992756, 4.393988633535548, 5.2249376569656665, 6.048957916101649, 6.867092741446717, 7.680116519091799, 8.488626500029651, 9.29309712086131, 10.0939141984612, 10.891397526867786, 11.685816406600221, 12.477400667233747, 13.266348706118992, 14.05283348792577, 14.837007112333191, 15.619004352459248, 16.398945438105606, 17.176938274805156, 17.95308023453365, 18.727459616523582, 19.500156850687972, 20.27124549786069, 21.040793087927625, 21.80886182735586, 22.575509200562298, 23.340788484277848, 24.104749190064368, 24.86743744708313, 25.628896334850907, 26.389166173878504, 27.148284780638306, 27.906287692160078, 28.663208364637892, 29.419078349694278, 30.173927451351343, 30.927783866273103, 31.680674309445145, 32.432624127130374, 33.183657398667926, 33.93379702845687, 34.68306482927728, 35.43148159794293, 36.17906718414617, 36.92584055324228, 37.671819843624434, 38.417022419258394, 39.16146491787572, 39.905163295263954, 40.64813286604014, 41.3903883412494, 42.13194386309063, 42.87281303703853, 43.61300896160044, 44.35254425592159, 45.091431085429306, 45.829681185686795, 46.567305884609844, 47.304316123184165, 48.040722474807424, 48.77653516336819, 49.511764080162635, 50.24641879974119, 50.980508594767834, 51.71404244996773, 52.447029075232045, 53.179476917942274, 53.91139417457141, 54.64278880161393, 55.37366852589251, 56.10404085428506, 56.83391308291219, 57.563292305821996, 58.29218542320588, 59.02059914917669, 59.74854001913781, 60.47601439676968, 61.20302848065822, 61.92958831058776, 62.65569977351937, 63.38136860927398, 64.10660041593817, 64.8314006550096, 65.55577465629693, 66.27972762258945, 67.00326463410904, 67.72639065275749, 68.44911052617041, 69.17142899158897, 69.893350679559, 70.61488011746772, 71.33602173292607, 72.05677985700565, 72.77715872733748, 73.4971624910801, 74.21679520776388, 74.93606085201769, 75.65496331618401, 76.37350641282828], [0.0, 0.9619614568204952, 1.858387036336771, 2.7316362249046975, 3.5901671032013285, 4.437916999115563, 5.277173334085135, 6.109431635284404, 6.935745663786077, 7.756897547511601, 8.57349050839771, 9.386003726167504, 10.194826874852565, 11.00028294559327, 11.802643931207866, 12.60214195896475, 13.398977409667877, 14.193324977180257, 14.985338281778988, 15.775153443959882, 16.562891895507384, 17.348662620726795, 18.13256396505832, 18.91468511049526, 19.695107291038887, 20.473904802938538, 21.251145851201898, 22.02689326419762, 22.801205101036068, 23.574135171075753, 24.34573348086435, 25.116046620733787, 25.88511810088305, 26.65298864492235, 27.41969644738963, 28.18527740059178, 28.949765295197096, 29.713191998261603, 30.475587611769487, 31.23698061427747, 31.99739798785096, 32.756865332149026, 33.51540696724106, 34.27304602651008, 35.029804540806744, 35.78570351485846, 36.54076299680246, 37.29500214159783, 38.04843926897413, 38.80109191649124, 39.55297688821443, 40.304110299447274, 41.05450761791284, 41.80418370172812, 42.55315283447692, 43.301428757653014, 44.04902470071448, 44.795953408964905, 45.542227169454, 46.28785783506982, 47.03285684697762, 47.777235255544284, 48.521003739873734, 49.264172626066596, 50.0067519043061, 50.74875124486306, 51.49018001310378, 52.23104728357713, 52.971361853250336, 53.71113225395658, 54.450366764112076, 55.189073419755395, 55.92726002495717, 56.66493416164441, 57.40210319887982, 58.13877430163335, 58.87495443908024, 59.61065039245686, 60.34586876250349, 61.0806159765207, 61.81489829506399, 62.548721818299725, 63.28209249204314, 64.01501611349832, 64.74749833671805, 65.47954467780062, 66.21116051983881, 66.94235111763619, 67.67312160220352, 68.40347698504857, 69.13342216227065, 69.86296191847086, 70.59210093048841, 71.32084377097247, 72.04919491179852, 72.77715872733748, 73.50473949758562, 74.23194141116214, 74.9587685681821, 75.68522498301023, 76.41131458690222, 77.1370412305392], [0.0, 0.9714783970473183, 1.8767725529473605, 2.758661027706848, 3.6256855800417678, 4.481822490871733, 5.329381811702389, 6.1698738653557, 7.004362838042589, 7.833638595483791, 8.658310327450899, 9.478861954319305, 10.295687005269295, 11.109111666878396, 11.919410622862063, 12.72681829698542, 13.53153705247294, 14.33374331148043, 15.133592214091193, 15.931221227477266, 16.72675298478, 17.52029754851537, 18.31195423708115, 19.101813114771794, 19.88995621925812, 20.676458581822, 21.461389082241382, 22.244811170462654, 23.026783479990378, 23.807360352533355, 24.586592289367307, 25.364526341754697, 26.141206450352477, 26.916673741660333, 27.69096678808493, 28.46412183702528, 29.236173013449744, 30.00715249968359, 30.77709069551793, 31.546016361255415, 32.31395674590219, 33.08093770238156, 33.84698379136782, 34.61211837510868, 35.37636370241187, 36.13974098581014, 36.90227047178227, 37.66397150479245, 38.42486258581218, 39.184961425905094, 39.944284995383526, 40.70284956898404, 41.460670767455994, 42.21776359591168, 42.97414247924619, 43.72982129490155, 44.484813403218375, 45.23913167559293, 45.99278852063397, 46.74579590849333, 47.49816539352674, 48.2499081354253, 49.00103491894415, 49.751556172342774, 50.50148198463994, 51.250822121777006, 51.99958604177434, 52.74778290895773, 53.495421607325156, 54.24251075311747, 54.98905870665147, 55.73507358346837, 56.48056326484658, 57.2255354077231, 57.96999745406474, 58.7139566397264, 59.45742000283122, 60.200394391704144, 60.94288647238834, 61.68490273577134, 62.426449504346024, 63.167532938629286, 63.908159043259914, 64.64833367279526, 65.38806253722517, 66.12735120722013, 66.86620511912933, 67.60462957974347, 68.34262977083577, 69.0802107534942, 69.81737747225645, 70.55413475905898, 71.2904873370102, 72.02643982399769, 72.76199673613841, 73.4971624910801, 74.23194141116214, 74.96633772644289, 75.7003555776009, 76.43399901871608, 77.16727201993712, 77.9001784700409], [0.0, 0.9809904328099454, 1.895148594757668, 2.7856719035351394, 3.6611857527746037, 4.525705356352314, 5.381563384179638, 6.230284947101353, 7.072944651094096, 7.910340095690293, 8.74308643542093, 9.571672328870637, 10.396495158381695, 11.217884304322045, 12.036117139917613, 12.851430384246775, 13.664028381932907, 14.474089282533944, 15.281769745156186, 16.0872085829539, 16.890529629806213, 17.69184402588416, 18.49125206204166, 19.288844684419633, 20.084704733944292, 20.878907976551247, 21.67152396644096, 22.462616774817253, 23.252245609282863, 24.040465343622532, 24.827326973585098, 25.61287801112601, 26.397162827138338, 27.18022295080365, 27.96209733220258, 28.742822573643277, 29.52243313422188, 30.300961511370435, 31.07843840253351, 31.85489284961449, 32.63035236842269, 33.40484306501513, 34.17838974054701, 34.95101598601281, 35.722744268065, 36.49359600693457, 37.263591647339645, 38.03275072315185, 38.80109191649124, 39.56863311183576, 40.33539144565918, 41.10138335204885, 41.86662460470158, 42.63113035564919, 43.39491517102526, 44.15799306414999, 44.920377526179095, 45.68208155453653, 46.44311767932745, 47.203497987907035, 47.963234147763174, 48.72233742785483, 49.48081871853391, 50.238688550166124, 50.99595711055482, 51.75263426126263, 52.50872955291623, 53.264252239572045, 54.01921129221395, 54.773615411447004, 55.52747303944634, 56.2807923712149, 57.03358136519901, 57.785847753307074, 58.53759905037239, 59.28884256309831, 60.03958539852032, 60.789834472017375, 61.539596514901866, 62.28887808161554, 63.03768555655671, 63.78602516056173, 64.5339029570626, 65.28132485794039, 66.02829662909318, 66.77482389573555, 67.52091214744561, 68.26656674297445, 69.01179291483156, 69.75659577365955, 70.50098031240957, 71.24495141032898, 71.9885138367716, 72.7316722548401, 73.47443122487012, 74.21679520776388, 74.9587685681821, 75.7003555776009, 76.44156041724145, 77.1823871808784, 77.92283987753329, 78.66292243405924], [0.0, 0.9904976166446369, 1.9135152632610593, 2.812669001574295, 3.696667817472094, 4.569565837928311, 5.433718339722771, 6.290665214179941, 7.141491481727231, 7.987002471763872, 8.827819300537717, 9.66443536242576, 10.497251890966838, 11.326601458690208, 12.152764126960399, 12.975978908998234, 13.796452129815314, 14.61436366549059, 15.429871693378523, 16.24311637192904, 17.054222735146602, 17.863303000307567, 18.67045843022599, 19.475780852439446, 20.279353910719802, 21.081254105281676, 21.881551664404043, 22.680311280231237, 23.477592734171367, 24.2734514318137, 25.067938863127956, 25.861103000527592, 26.652988644922342, 27.44363772797024, 28.233089577233258, 29.021381149747647, 29.808547238566884, 30.59462065606907, 31.379632397200396, 32.163611785321336, 32.9465866029083, 33.72858320902288, 34.50962664517854, 35.28974073099984, 36.068948150872856, 36.847270532620904, 37.624728519100316, 38.40134183349355, 39.1771293389768, 39.95210909335389, 40.72629839917523, 41.499713849797715, 42.272371371787564, 43.04428626402121, 43.81547323379865, 44.58594643024897, 45.35571947527624, 46.12480549226783, 46.893217132763326, 47.66096660126146, 48.42806567832457, 49.19452574212377, 49.960357788553864, 50.72557245003467, 51.490180013103775, 52.25419043489628, 53.017613358597934, 53.780458127950055, 54.54273380087803, 55.30444916230806, 56.06561273623191, 56.82623279707368, 57.58631738040828, 58.34587429307724, 59.10491112274321, 59.863435246921824, 60.6214538415258, 61.37897388895388, 62.13600218575438, 62.89254534989087, 63.64860982763548, 64.40420190011328, 65.1593276895195, 65.91399316502968, 66.6682041484216, 67.42196631942613, 68.17528522082317, 68.92816626329763, 69.68061473006946, 70.43263578131061, 71.18423445836096, 71.9354156877547, 72.68618428506741, 73.43654495859384, 74.1865023128657, 74.93606085201769, 75.68522498301023, 76.43399901871608, 77.1823871808784, 77.93039360294622, 78.67802233279426, 79.42527733533234], [0.0, 1.0, 1.9318726578496912, 2.8396524679204784, 3.73213196614723, 4.613404172952941, 5.485846960570969, 6.351014993342338, 7.210003700886642, 8.06362613856686, 8.912509381337456, 9.757151556976527, 10.597957748274887, 11.435263718311278, 12.269352215231502, 13.100464545240452, 13.928809012737988, 14.7545672194523, 15.577898860219403, 16.398945438105606, 17.2178331866347, 18.034675399644527, 18.849574311418497, 19.66262263044578, 20.473904802938534, 21.283498063019614, 22.09147331270615, 22.89789586476946, 23.702826074133277, 24.50631987792288, 25.30842926007932, 26.109202653241557, 26.908685288118868, 27.706919498642527, 28.50394498966524, 29.29979907277224, 30.09451687480573, 30.88813152293083, 31.680674309445145, 32.47217483902412, 33.26266116067659, 34.05215988634101, 34.840696297767714, 35.62829444309589, 36.41497722433531, 37.200766476796765, 37.98568304137478, 38.769746830467014, 39.552976888214424, 40.33539144565918, 41.117007971344464, 41.8978432178163, 42.677913264433144, 43.45723355684187, 44.23581894343763, 45.0136837090898, 45.79084160638482, 46.56730588460985, 47.34308931667759, 48.11820422417119, 48.892662500670326, 49.66647563350312, 50.43965472405397, 51.212210506745315, 51.984153366799084, 52.75549335687462, 53.526240212669975, 54.2964033675661, 55.06599196638597, 55.8350148783344, 56.60348070917843, 57.37139781272321, 58.13877430163333, 58.90561805764558, 59.67193674121521, 60.43773780063437, 61.20302848065822, 61.967815830671455, 62.73210671242539, 63.49590780737332, 64.25922562362999, 65.0220665025787, 65.78443662514825, 66.54634201777972, 67.3077885581024, 68.06878198033591, 68.82932788043505, 69.58943172099237, 70.34909883591263, 71.10833443487212, 71.86714360757507, 72.62553132781856, 73.38350245737664, 74.14106174971327, 74.89821385353396, 75.65496331618401, 76.41131458690222, 77.16727201993712, 77.92283987753329, 78.67802233279426, 79.43282347242815, 80.18724729938238], [0.0, 1.0094976332701566, 1.9502208758785904, 2.8666224456754823, 3.7675783868775254, 4.6572205939146585, 5.537949523178676, 6.411334604642371, 7.278481671914136, 8.140211502458618, 8.99715712695823, 9.849821404226029, 10.698613264380617, 11.543871659455327, 12.385882023034155, 13.224887953159836, 14.061099732631027, 14.894700687962533, 15.725852030713359, 16.55469660789404, 17.38136185194809, 18.20596213273667, 19.028600655526915, 19.84937100931924, 20.668358442364944, 21.485640922328265, 22.301290024627686, 23.115371682351277, 23.927946823651705, 24.739071916924544, 25.548799439835257, 26.357178285018247, 27.164254112767484, 27.970069659086388, 28.7746650059298, 29.57807781925471, 30.38034355952518, 31.181495668535995, 31.98156573578753, 32.78058364712958, 33.578577717970184, 34.37557481299822, 35.17160045408082, 35.96667891775758, 36.76083332355316, 37.55408571416212, 38.346457128418166, 39.13796766783961, 39.92863655744167, 40.71848220141826, 41.5075222342224, 42.29577356750965, 43.08325243335429, 43.869974424100306, 44.65595452916745, 45.44120716909756, 46.22574622709409, 47.009585078281084, 47.79273661688367, 48.57521328151087, 49.35702707870324, 50.1381896048913, 50.91871206689637, 51.69860530109245, 52.47787979133653, 53.2565456857644, 54.03461281254023, 54.81209069463974, 55.5889885637401, 56.36531537328256, 57.141079810768595, 57.91629030934473, 58.69095505872666, 59.46508201550902, 60.23867891290327, 61.01175326994268, 61.784312400190466, 62.55636341998379, 63.327913256244344, 64.09896865388343, 64.86953618282747, 65.63962224468793, 66.40923307909776, 67.17837476973502, 67.94705325005252, 68.7152743087314, 69.48304359487479, 70.25036662295696, 71.01724877754214, 71.7836953177862, 72.5497113817335, 73.31530199042047, 74.08047205179645, 74.84522636447208, 75.60956962130459, 76.37350641282828, 77.1370412305392, 77.9001784700409, 78.66292243405924, 79.42527733533234, 80.18724729938238, 80.94883636717528]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 2.0\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.010000000000000002, 0.020000000000000004, 0.030000000000000006, 0.04000000000000001, 0.05, 0.06000000000000001, 0.07, 0.08000000000000002, 0.09000000000000001, 0.1, 0.11000000000000001, 0.12000000000000002, 0.13, 0.14, 0.15000000000000002, 0.16000000000000003, 0.17000000000000004, 0.18000000000000002, 0.19000000000000003, 0.2, 0.21000000000000002, 0.22000000000000003, 0.23000000000000004, 0.24000000000000005, 0.25, 0.26, 0.27, 0.28, 0.29000000000000004, 0.30000000000000004, 0.31000000000000005, 0.32000000000000006, 0.33000000000000007, 0.3400000000000001, 0.35000000000000003, 0.36000000000000004, 0.37000000000000005, 0.38000000000000006, 0.39000000000000007, 0.4, 0.4100000000000001, 0.42000000000000004, 0.43, 0.44000000000000006, 0.45, 0.4600000000000001, 0.47000000000000003, 0.4800000000000001, 0.49000000000000005, 0.5, 0.5100000000000001, 0.52, 0.5300000000000001, 0.54, 0.55, 0.56, 0.5700000000000001, 0.5800000000000001, 0.5900000000000001, 0.6000000000000001, 0.6100000000000001, 0.6200000000000001, 0.6300000000000001, 0.6400000000000001, 0.65, 0.6600000000000001, 0.67, 0.6800000000000002, 0.6900000000000001, 0.7000000000000001, 0.7100000000000001, 0.7200000000000001, 0.7300000000000001, 0.7400000000000001, 0.75, 0.7600000000000001, 0.77, 0.7800000000000001, 0.79, 0.8, 0.81, 0.8200000000000002, 0.8300000000000001, 0.8400000000000001, 0.8500000000000001, 0.86, 0.8700000000000001, 0.8800000000000001, 0.8900000000000001, 0.9, 0.91, 0.9200000000000002, 0.9300000000000002, 0.9400000000000001, 0.9500000000000001, 0.9600000000000002, 0.9700000000000002, 0.9800000000000001, 0.9900000000000001, 1.0, 1.0100000000000002], [0.0, 0.020000000000000004, 0.04000000000000001, 0.06000000000000001, 0.08000000000000002, 0.1, 0.12000000000000002, 0.14, 0.16000000000000003, 0.18000000000000002, 0.2, 0.22000000000000003, 0.24000000000000005, 0.26, 0.28, 0.30000000000000004, 0.32000000000000006, 0.3400000000000001, 0.36000000000000004, 0.38000000000000006, 0.4, 0.42000000000000004, 0.44000000000000006, 0.4600000000000001, 0.4800000000000001, 0.5, 0.52, 0.54, 0.56, 0.5800000000000001, 0.6000000000000001, 0.6200000000000001, 0.6400000000000001, 0.6600000000000001, 0.6800000000000002, 0.7000000000000001, 0.7200000000000001, 0.7400000000000001, 0.7600000000000001, 0.7800000000000001, 0.8, 0.8200000000000002, 0.8400000000000001, 0.86, 0.8800000000000001, 0.9, 0.9200000000000002, 0.9400000000000001, 0.9600000000000002, 0.9800000000000001, 1.0, 1.0200000000000002, 1.04, 1.0600000000000003, 1.08, 1.1, 1.12, 1.1400000000000001, 1.1600000000000001, 1.1800000000000002, 1.2000000000000002, 1.2200000000000002, 1.2400000000000002, 1.2600000000000002, 1.2800000000000002, 1.3, 1.3200000000000003, 1.34, 1.3600000000000003, 1.3800000000000001, 1.4000000000000001, 1.4200000000000002, 1.4400000000000002, 1.4600000000000002, 1.4800000000000002, 1.5, 1.5200000000000002, 1.54, 1.5600000000000003, 1.58, 1.6, 1.62, 1.6400000000000003, 1.6600000000000001, 1.6800000000000002, 1.7000000000000002, 1.72, 1.7400000000000002, 1.7600000000000002, 1.7800000000000002, 1.8, 1.82, 1.8400000000000003, 1.8600000000000003, 1.8800000000000001, 1.9000000000000001, 1.9200000000000004, 1.9400000000000004, 1.9600000000000002, 1.9800000000000002, 2.0, 2.0200000000000005], [0.0, 0.030000000000000006, 0.06000000000000001, 0.09000000000000002, 0.12000000000000002, 0.15000000000000002, 0.18000000000000005, 0.21000000000000005, 0.24000000000000005, 0.2700000000000001, 0.30000000000000004, 0.33000000000000007, 0.3600000000000001, 0.39000000000000007, 0.4200000000000001, 0.45000000000000007, 0.4800000000000001, 0.5100000000000001, 0.5400000000000001, 0.5700000000000002, 0.6000000000000001, 0.6300000000000001, 0.6600000000000001, 0.6900000000000002, 0.7200000000000002, 0.7500000000000001, 0.7800000000000001, 0.8100000000000002, 0.8400000000000002, 0.8700000000000002, 0.9000000000000001, 0.9300000000000002, 0.9600000000000002, 0.9900000000000002, 1.0200000000000002, 1.0500000000000003, 1.0800000000000003, 1.1100000000000003, 1.1400000000000003, 1.1700000000000004, 1.2000000000000002, 1.2300000000000004, 1.2600000000000002, 1.29, 1.3200000000000003, 1.35, 1.3800000000000003, 1.4100000000000004, 1.4400000000000004, 1.4700000000000004, 1.5000000000000002, 1.5300000000000005, 1.5600000000000003, 1.5900000000000005, 1.6200000000000003, 1.6500000000000004, 1.6800000000000004, 1.7100000000000004, 1.7400000000000004, 1.7700000000000005, 1.8000000000000003, 1.8300000000000005, 1.8600000000000003, 1.8900000000000006, 1.9200000000000004, 1.9500000000000002, 1.9800000000000004, 2.0100000000000002, 2.0400000000000005, 2.0700000000000003, 2.1000000000000005, 2.1300000000000003, 2.1600000000000006, 2.1900000000000004, 2.2200000000000006, 2.2500000000000004, 2.2800000000000007, 2.3100000000000005, 2.3400000000000007, 2.3700000000000006, 2.4000000000000004, 2.43, 2.460000000000001, 2.4900000000000007, 2.5200000000000005, 2.5500000000000003, 2.58, 2.6100000000000008, 2.6400000000000006, 2.6700000000000004, 2.7, 2.7300000000000004, 2.7600000000000007, 2.7900000000000005, 2.8200000000000007, 2.8500000000000005, 2.880000000000001, 2.9100000000000006, 2.940000000000001, 2.9700000000000006, 3.0000000000000004, 3.0300000000000007], [0.0, 0.04000000000000001, 0.08000000000000002, 0.12000000000000002, 0.16000000000000003, 0.2, 0.24000000000000005, 0.28, 0.32000000000000006, 0.36000000000000004, 0.4, 0.44000000000000006, 0.4800000000000001, 0.52, 0.56, 0.6000000000000001, 0.6400000000000001, 0.6800000000000002, 0.7200000000000001, 0.7600000000000001, 0.8, 0.8400000000000001, 0.8800000000000001, 0.9200000000000002, 0.9600000000000002, 1.0, 1.04, 1.08, 1.12, 1.1600000000000001, 1.2000000000000002, 1.2400000000000002, 1.2800000000000002, 1.3200000000000003, 1.3600000000000003, 1.4000000000000001, 1.4400000000000002, 1.4800000000000002, 1.5200000000000002, 1.5600000000000003, 1.6, 1.6400000000000003, 1.6800000000000002, 1.72, 1.7600000000000002, 1.8, 1.8400000000000003, 1.8800000000000001, 1.9200000000000004, 1.9600000000000002, 2.0, 2.0400000000000005, 2.08, 2.1200000000000006, 2.16, 2.2, 2.24, 2.2800000000000002, 2.3200000000000003, 2.3600000000000003, 2.4000000000000004, 2.4400000000000004, 2.4800000000000004, 2.5200000000000005, 2.5600000000000005, 2.6, 2.6400000000000006, 2.68, 2.7200000000000006, 2.7600000000000002, 2.8000000000000003, 2.8400000000000003, 2.8800000000000003, 2.9200000000000004, 2.9600000000000004, 3.0, 3.0400000000000005, 3.08, 3.1200000000000006, 3.16, 3.2, 3.24, 3.2800000000000007, 3.3200000000000003, 3.3600000000000003, 3.4000000000000004, 3.44, 3.4800000000000004, 3.5200000000000005, 3.5600000000000005, 3.6, 3.64, 3.6800000000000006, 3.7200000000000006, 3.7600000000000002, 3.8000000000000003, 3.8400000000000007, 3.880000000000001, 3.9200000000000004, 3.9600000000000004, 4.0, 4.040000000000001], [0.0, 0.05, 0.1, 0.15000000000000002, 0.2, 0.25, 0.30000000000000004, 0.35000000000000003, 0.4, 0.45, 0.5, 0.55, 0.6000000000000001, 0.65, 0.7000000000000001, 0.75, 0.8, 0.8500000000000001, 0.9, 0.9500000000000001, 1.0, 1.05, 1.1, 1.1500000000000001, 1.2000000000000002, 1.25, 1.3, 1.35, 1.4000000000000001, 1.4500000000000002, 1.5, 1.55, 1.6, 1.6500000000000001, 1.7000000000000002, 1.75, 1.8, 1.85, 1.9000000000000001, 1.9500000000000002, 2.0, 2.0500000000000003, 2.1, 2.15, 2.2, 2.25, 2.3000000000000003, 2.35, 2.4000000000000004, 2.45, 2.5, 2.5500000000000003, 2.6, 2.6500000000000004, 2.7, 2.75, 2.8000000000000003, 2.85, 2.9000000000000004, 2.95, 3.0, 3.0500000000000003, 3.1, 3.1500000000000004, 3.2, 3.25, 3.3000000000000003, 3.35, 3.4000000000000004, 3.45, 3.5, 3.5500000000000003, 3.6, 3.6500000000000004, 3.7, 3.75, 3.8000000000000003, 3.85, 3.9000000000000004, 3.95, 4.0, 4.05, 4.1000000000000005, 4.15, 4.2, 4.25, 4.3, 4.3500000000000005, 4.4, 4.45, 4.5, 4.55, 4.6000000000000005, 4.65, 4.7, 4.75, 4.800000000000001, 4.8500000000000005, 4.9, 4.95, 5.0, 5.050000000000001], [0.0, 0.06000000000000001, 0.12000000000000002, 0.18000000000000005, 0.24000000000000005, 0.30000000000000004, 0.3600000000000001, 0.4200000000000001, 0.4800000000000001, 0.5400000000000001, 0.6000000000000001, 0.6600000000000001, 0.7200000000000002, 0.7800000000000001, 0.8400000000000002, 0.9000000000000001, 0.9600000000000002, 1.0200000000000002, 1.0800000000000003, 1.1400000000000003, 1.2000000000000002, 1.2600000000000002, 1.3200000000000003, 1.3800000000000003, 1.4400000000000004, 1.5000000000000002, 1.5600000000000003, 1.6200000000000003, 1.6800000000000004, 1.7400000000000004, 1.8000000000000003, 1.8600000000000003, 1.9200000000000004, 1.9800000000000004, 2.0400000000000005, 2.1000000000000005, 2.1600000000000006, 2.2200000000000006, 2.2800000000000007, 2.3400000000000007, 2.4000000000000004, 2.460000000000001, 2.5200000000000005, 2.58, 2.6400000000000006, 2.7, 2.7600000000000007, 2.8200000000000007, 2.880000000000001, 2.940000000000001, 3.0000000000000004, 3.060000000000001, 3.1200000000000006, 3.180000000000001, 3.2400000000000007, 3.3000000000000007, 3.3600000000000008, 3.420000000000001, 3.480000000000001, 3.540000000000001, 3.6000000000000005, 3.660000000000001, 3.7200000000000006, 3.780000000000001, 3.8400000000000007, 3.9000000000000004, 3.960000000000001, 4.0200000000000005, 4.080000000000001, 4.140000000000001, 4.200000000000001, 4.260000000000001, 4.320000000000001, 4.380000000000001, 4.440000000000001, 4.500000000000001, 4.560000000000001, 4.620000000000001, 4.6800000000000015, 4.740000000000001, 4.800000000000001, 4.86, 4.920000000000002, 4.980000000000001, 5.040000000000001, 5.1000000000000005, 5.16, 5.2200000000000015, 5.280000000000001, 5.340000000000001, 5.4, 5.460000000000001, 5.520000000000001, 5.580000000000001, 5.6400000000000015, 5.700000000000001, 5.760000000000002, 5.820000000000001, 5.880000000000002, 5.940000000000001, 6.000000000000001, 6.060000000000001], [0.0, 0.07, 0.14, 0.21000000000000005, 0.28, 0.35000000000000003, 0.4200000000000001, 0.4900000000000001, 0.56, 0.6300000000000001, 0.7000000000000001, 0.7700000000000001, 0.8400000000000002, 0.9100000000000001, 0.9800000000000002, 1.05, 1.12, 1.1900000000000002, 1.2600000000000002, 1.3300000000000003, 1.4000000000000001, 1.4700000000000002, 1.5400000000000003, 1.6100000000000003, 1.6800000000000004, 1.7500000000000002, 1.8200000000000003, 1.8900000000000003, 1.9600000000000004, 2.0300000000000002, 2.1, 2.1700000000000004, 2.24, 2.3100000000000005, 2.3800000000000003, 2.45, 2.5200000000000005, 2.5900000000000003, 2.6600000000000006, 2.7300000000000004, 2.8000000000000003, 2.8700000000000006, 2.9400000000000004, 3.0100000000000002, 3.0800000000000005, 3.1500000000000004, 3.2200000000000006, 3.2900000000000005, 3.3600000000000008, 3.4300000000000006, 3.5000000000000004, 3.5700000000000007, 3.6400000000000006, 3.710000000000001, 3.7800000000000007, 3.8500000000000005, 3.920000000000001, 3.9900000000000007, 4.0600000000000005, 4.130000000000001, 4.2, 4.2700000000000005, 4.340000000000001, 4.410000000000001, 4.48, 4.550000000000001, 4.620000000000001, 4.69, 4.760000000000001, 4.830000000000001, 4.9, 4.970000000000001, 5.040000000000001, 5.110000000000001, 5.180000000000001, 5.250000000000001, 5.320000000000001, 5.390000000000001, 5.460000000000001, 5.530000000000001, 5.6000000000000005, 5.67, 5.740000000000001, 5.810000000000001, 5.880000000000001, 5.95, 6.0200000000000005, 6.090000000000002, 6.160000000000001, 6.23, 6.300000000000001, 6.37, 6.440000000000001, 6.510000000000001, 6.580000000000001, 6.65, 6.7200000000000015, 6.790000000000002, 6.860000000000001, 6.930000000000001, 7.000000000000001, 7.070000000000002], [0.0, 0.08000000000000002, 0.16000000000000003, 0.24000000000000005, 0.32000000000000006, 0.4, 0.4800000000000001, 0.56, 0.6400000000000001, 0.7200000000000001, 0.8, 0.8800000000000001, 0.9600000000000002, 1.04, 1.12, 1.2000000000000002, 1.2800000000000002, 1.3600000000000003, 1.4400000000000002, 1.5200000000000002, 1.6, 1.6800000000000002, 1.7600000000000002, 1.8400000000000003, 1.9200000000000004, 2.0, 2.08, 2.16, 2.24, 2.3200000000000003, 2.4000000000000004, 2.4800000000000004, 2.5600000000000005, 2.6400000000000006, 2.7200000000000006, 2.8000000000000003, 2.8800000000000003, 2.9600000000000004, 3.0400000000000005, 3.1200000000000006, 3.2, 3.2800000000000007, 3.3600000000000003, 3.44, 3.5200000000000005, 3.6, 3.6800000000000006, 3.7600000000000002, 3.8400000000000007, 3.9200000000000004, 4.0, 4.080000000000001, 4.16, 4.240000000000001, 4.32, 4.4, 4.48, 4.5600000000000005, 4.640000000000001, 4.720000000000001, 4.800000000000001, 4.880000000000001, 4.960000000000001, 5.040000000000001, 5.120000000000001, 5.2, 5.280000000000001, 5.36, 5.440000000000001, 5.5200000000000005, 5.6000000000000005, 5.680000000000001, 5.760000000000001, 5.840000000000001, 5.920000000000001, 6.0, 6.080000000000001, 6.16, 6.240000000000001, 6.32, 6.4, 6.48, 6.560000000000001, 6.640000000000001, 6.720000000000001, 6.800000000000001, 6.88, 6.960000000000001, 7.040000000000001, 7.120000000000001, 7.2, 7.28, 7.360000000000001, 7.440000000000001, 7.5200000000000005, 7.6000000000000005, 7.6800000000000015, 7.760000000000002, 7.840000000000001, 7.920000000000001, 8.0, 8.080000000000002], [0.0, 0.09000000000000001, 0.18000000000000002, 0.2700000000000001, 0.36000000000000004, 0.45, 0.5400000000000001, 0.6300000000000001, 0.7200000000000001, 0.81, 0.9, 0.9900000000000001, 1.0800000000000003, 1.1700000000000002, 1.2600000000000002, 1.35, 1.4400000000000002, 1.5300000000000002, 1.62, 1.7100000000000002, 1.8, 1.8900000000000001, 1.9800000000000002, 2.0700000000000003, 2.1600000000000006, 2.25, 2.3400000000000003, 2.43, 2.5200000000000005, 2.6100000000000003, 2.7, 2.79, 2.8800000000000003, 2.97, 3.0600000000000005, 3.15, 3.24, 3.33, 3.4200000000000004, 3.5100000000000002, 3.6, 3.6900000000000004, 3.7800000000000002, 3.87, 3.9600000000000004, 4.05, 4.140000000000001, 4.23, 4.320000000000001, 4.41, 4.5, 4.590000000000001, 4.680000000000001, 4.7700000000000005, 4.86, 4.95, 5.040000000000001, 5.13, 5.220000000000001, 5.3100000000000005, 5.4, 5.49, 5.58, 5.670000000000001, 5.760000000000001, 5.8500000000000005, 5.94, 6.03, 6.120000000000001, 6.210000000000001, 6.3, 6.390000000000001, 6.48, 6.570000000000001, 6.66, 6.75, 6.840000000000001, 6.930000000000001, 7.0200000000000005, 7.11, 7.2, 7.29, 7.380000000000001, 7.470000000000001, 7.5600000000000005, 7.65, 7.74, 7.830000000000001, 7.920000000000001, 8.01, 8.1, 8.19, 8.280000000000001, 8.370000000000001, 8.46, 8.55, 8.640000000000002, 8.73, 8.82, 8.91, 9.0, 9.090000000000002], [0.0, 0.1, 0.2, 0.30000000000000004, 0.4, 0.5, 0.6000000000000001, 0.7000000000000001, 0.8, 0.9, 1.0, 1.1, 1.2000000000000002, 1.3, 1.4000000000000001, 1.5, 1.6, 1.7000000000000002, 1.8, 1.9000000000000001, 2.0, 2.1, 2.2, 2.3000000000000003, 2.4000000000000004, 2.5, 2.6, 2.7, 2.8000000000000003, 2.9000000000000004, 3.0, 3.1, 3.2, 3.3000000000000003, 3.4000000000000004, 3.5, 3.6, 3.7, 3.8000000000000003, 3.9000000000000004, 4.0, 4.1000000000000005, 4.2, 4.3, 4.4, 4.5, 4.6000000000000005, 4.7, 4.800000000000001, 4.9, 5.0, 5.1000000000000005, 5.2, 5.300000000000001, 5.4, 5.5, 5.6000000000000005, 5.7, 5.800000000000001, 5.9, 6.0, 6.1000000000000005, 6.2, 6.300000000000001, 6.4, 6.5, 6.6000000000000005, 6.7, 6.800000000000001, 6.9, 7.0, 7.1000000000000005, 7.2, 7.300000000000001, 7.4, 7.5, 7.6000000000000005, 7.7, 7.800000000000001, 7.9, 8.0, 8.1, 8.200000000000001, 8.3, 8.4, 8.5, 8.6, 8.700000000000001, 8.8, 8.9, 9.0, 9.1, 9.200000000000001, 9.3, 9.4, 9.5, 9.600000000000001, 9.700000000000001, 9.8, 9.9, 10.0, 10.100000000000001], [0.0, 0.11000000000000001, 0.22000000000000003, 0.33000000000000007, 0.44000000000000006, 0.55, 0.6600000000000001, 0.7700000000000001, 0.8800000000000001, 0.9900000000000001, 1.1, 1.2100000000000002, 1.3200000000000003, 1.4300000000000002, 1.5400000000000003, 1.6500000000000001, 1.7600000000000002, 1.8700000000000003, 1.9800000000000002, 2.0900000000000003, 2.2, 2.3100000000000005, 2.4200000000000004, 2.5300000000000007, 2.6400000000000006, 2.75, 2.8600000000000003, 2.9700000000000006, 3.0800000000000005, 3.190000000000001, 3.3000000000000003, 3.4100000000000006, 3.5200000000000005, 3.630000000000001, 3.7400000000000007, 3.8500000000000005, 3.9600000000000004, 4.07, 4.180000000000001, 4.290000000000001, 4.4, 4.510000000000001, 4.620000000000001, 4.73, 4.840000000000001, 4.95, 5.060000000000001, 5.170000000000001, 5.280000000000001, 5.390000000000001, 5.5, 5.610000000000001, 5.720000000000001, 5.830000000000001, 5.940000000000001, 6.050000000000001, 6.160000000000001, 6.2700000000000005, 6.380000000000002, 6.490000000000001, 6.6000000000000005, 6.710000000000001, 6.820000000000001, 6.9300000000000015, 7.040000000000001, 7.15, 7.260000000000002, 7.370000000000001, 7.480000000000001, 7.590000000000001, 7.700000000000001, 7.810000000000001, 7.920000000000001, 8.030000000000001, 8.14, 8.25, 8.360000000000001, 8.47, 8.580000000000002, 8.690000000000001, 8.8, 8.91, 9.020000000000001, 9.13, 9.240000000000002, 9.350000000000001, 9.46, 9.570000000000002, 9.680000000000001, 9.790000000000001, 9.9, 10.01, 10.120000000000003, 10.230000000000002, 10.340000000000002, 10.450000000000001, 10.560000000000002, 10.670000000000002, 10.780000000000001, 10.89, 11.0, 11.110000000000003], [0.0, 0.12000000000000002, 0.24000000000000005, 0.3600000000000001, 0.4800000000000001, 0.6000000000000001, 0.7200000000000002, 0.8400000000000002, 0.9600000000000002, 1.0800000000000003, 1.2000000000000002, 1.3200000000000003, 1.4400000000000004, 1.5600000000000003, 1.6800000000000004, 1.8000000000000003, 1.9200000000000004, 2.0400000000000005, 2.1600000000000006, 2.2800000000000007, 2.4000000000000004, 2.5200000000000005, 2.6400000000000006, 2.7600000000000007, 2.880000000000001, 3.0000000000000004, 3.1200000000000006, 3.2400000000000007, 3.3600000000000008, 3.480000000000001, 3.6000000000000005, 3.7200000000000006, 3.8400000000000007, 3.960000000000001, 4.080000000000001, 4.200000000000001, 4.320000000000001, 4.440000000000001, 4.560000000000001, 4.6800000000000015, 4.800000000000001, 4.920000000000002, 5.040000000000001, 5.16, 5.280000000000001, 5.4, 5.520000000000001, 5.6400000000000015, 5.760000000000002, 5.880000000000002, 6.000000000000001, 6.120000000000002, 6.240000000000001, 6.360000000000002, 6.480000000000001, 6.600000000000001, 6.7200000000000015, 6.840000000000002, 6.960000000000002, 7.080000000000002, 7.200000000000001, 7.320000000000002, 7.440000000000001, 7.560000000000002, 7.6800000000000015, 7.800000000000001, 7.920000000000002, 8.040000000000001, 8.160000000000002, 8.280000000000001, 8.400000000000002, 8.520000000000001, 8.640000000000002, 8.760000000000002, 8.880000000000003, 9.000000000000002, 9.120000000000003, 9.240000000000002, 9.360000000000003, 9.480000000000002, 9.600000000000001, 9.72, 9.840000000000003, 9.960000000000003, 10.080000000000002, 10.200000000000001, 10.32, 10.440000000000003, 10.560000000000002, 10.680000000000001, 10.8, 10.920000000000002, 11.040000000000003, 11.160000000000002, 11.280000000000003, 11.400000000000002, 11.520000000000003, 11.640000000000002, 11.760000000000003, 11.880000000000003, 12.000000000000002, 12.120000000000003], [0.0, 0.13, 0.26, 0.39000000000000007, 0.52, 0.65, 0.7800000000000001, 0.9100000000000001, 1.04, 1.1700000000000002, 1.3, 1.4300000000000002, 1.5600000000000003, 1.6900000000000002, 1.8200000000000003, 1.9500000000000002, 2.08, 2.2100000000000004, 2.3400000000000003, 2.47, 2.6, 2.7300000000000004, 2.8600000000000003, 2.9900000000000007, 3.1200000000000006, 3.25, 3.3800000000000003, 3.5100000000000002, 3.6400000000000006, 3.7700000000000005, 3.9000000000000004, 4.03, 4.16, 4.290000000000001, 4.420000000000001, 4.55, 4.680000000000001, 4.8100000000000005, 4.94, 5.07, 5.2, 5.330000000000001, 5.460000000000001, 5.59, 5.720000000000001, 5.8500000000000005, 5.980000000000001, 6.11, 6.240000000000001, 6.370000000000001, 6.5, 6.630000000000001, 6.760000000000001, 6.8900000000000015, 7.0200000000000005, 7.15, 7.280000000000001, 7.41, 7.540000000000001, 7.670000000000001, 7.800000000000001, 7.930000000000001, 8.06, 8.190000000000001, 8.32, 8.450000000000001, 8.580000000000002, 8.71, 8.840000000000002, 8.97, 9.1, 9.23, 9.360000000000001, 9.490000000000002, 9.620000000000001, 9.75, 9.88, 10.01, 10.14, 10.270000000000001, 10.4, 10.53, 10.660000000000002, 10.790000000000001, 10.920000000000002, 11.05, 11.18, 11.310000000000002, 11.440000000000001, 11.57, 11.700000000000001, 11.83, 11.960000000000003, 12.090000000000002, 12.22, 12.35, 12.480000000000002, 12.610000000000001, 12.740000000000002, 12.870000000000001, 13.0, 13.130000000000003], [0.0, 0.14, 0.28, 0.4200000000000001, 0.56, 0.7000000000000001, 0.8400000000000002, 0.9800000000000002, 1.12, 1.2600000000000002, 1.4000000000000001, 1.5400000000000003, 1.6800000000000004, 1.8200000000000003, 1.9600000000000004, 2.1, 2.24, 2.3800000000000003, 2.5200000000000005, 2.6600000000000006, 2.8000000000000003, 2.9400000000000004, 3.0800000000000005, 3.2200000000000006, 3.3600000000000008, 3.5000000000000004, 3.6400000000000006, 3.7800000000000007, 3.920000000000001, 4.0600000000000005, 4.2, 4.340000000000001, 4.48, 4.620000000000001, 4.760000000000001, 4.9, 5.040000000000001, 5.180000000000001, 5.320000000000001, 5.460000000000001, 5.6000000000000005, 5.740000000000001, 5.880000000000001, 6.0200000000000005, 6.160000000000001, 6.300000000000001, 6.440000000000001, 6.580000000000001, 6.7200000000000015, 6.860000000000001, 7.000000000000001, 7.1400000000000015, 7.280000000000001, 7.420000000000002, 7.560000000000001, 7.700000000000001, 7.840000000000002, 7.980000000000001, 8.120000000000001, 8.260000000000002, 8.4, 8.540000000000001, 8.680000000000001, 8.820000000000002, 8.96, 9.100000000000001, 9.240000000000002, 9.38, 9.520000000000001, 9.660000000000002, 9.8, 9.940000000000001, 10.080000000000002, 10.220000000000002, 10.360000000000001, 10.500000000000002, 10.640000000000002, 10.780000000000001, 10.920000000000002, 11.060000000000002, 11.200000000000001, 11.34, 11.480000000000002, 11.620000000000003, 11.760000000000002, 11.9, 12.040000000000001, 12.180000000000003, 12.320000000000002, 12.46, 12.600000000000001, 12.74, 12.880000000000003, 13.020000000000001, 13.160000000000002, 13.3, 13.440000000000003, 13.580000000000004, 13.720000000000002, 13.860000000000001, 14.000000000000002, 14.140000000000004], [0.0, 0.15000000000000002, 0.30000000000000004, 0.45000000000000007, 0.6000000000000001, 0.75, 0.9000000000000001, 1.05, 1.2000000000000002, 1.35, 1.5, 1.6500000000000001, 1.8000000000000003, 1.9500000000000002, 2.1, 2.25, 2.4000000000000004, 2.5500000000000003, 2.7, 2.85, 3.0, 3.1500000000000004, 3.3000000000000003, 3.45, 3.6000000000000005, 3.75, 3.9000000000000004, 4.050000000000001, 4.2, 4.3500000000000005, 4.5, 4.65, 4.800000000000001, 4.95, 5.1000000000000005, 5.25, 5.4, 5.550000000000001, 5.7, 5.8500000000000005, 6.0, 6.15, 6.300000000000001, 6.449999999999999, 6.6000000000000005, 6.75, 6.9, 7.050000000000001, 7.200000000000001, 7.3500000000000005, 7.5, 7.65, 7.800000000000001, 7.950000000000001, 8.100000000000001, 8.25, 8.4, 8.55, 8.700000000000001, 8.850000000000001, 9.0, 9.15, 9.3, 9.450000000000001, 9.600000000000001, 9.75, 9.9, 10.05, 10.200000000000001, 10.350000000000001, 10.5, 10.65, 10.8, 10.950000000000001, 11.100000000000001, 11.25, 11.4, 11.55, 11.700000000000001, 11.850000000000001, 12.0, 12.149999999999999, 12.3, 12.450000000000001, 12.600000000000001, 12.75, 12.899999999999999, 13.05, 13.200000000000001, 13.350000000000001, 13.5, 13.649999999999999, 13.8, 13.950000000000001, 14.100000000000001, 14.25, 14.400000000000002, 14.55, 14.700000000000001, 14.850000000000001, 15.0, 15.150000000000002], [0.0, 0.16000000000000003, 0.32000000000000006, 0.4800000000000001, 0.6400000000000001, 0.8, 0.9600000000000002, 1.12, 1.2800000000000002, 1.4400000000000002, 1.6, 1.7600000000000002, 1.9200000000000004, 2.08, 2.24, 2.4000000000000004, 2.5600000000000005, 2.7200000000000006, 2.8800000000000003, 3.0400000000000005, 3.2, 3.3600000000000003, 3.5200000000000005, 3.6800000000000006, 3.8400000000000007, 4.0, 4.16, 4.32, 4.48, 4.640000000000001, 4.800000000000001, 4.960000000000001, 5.120000000000001, 5.280000000000001, 5.440000000000001, 5.6000000000000005, 5.760000000000001, 5.920000000000001, 6.080000000000001, 6.240000000000001, 6.4, 6.560000000000001, 6.720000000000001, 6.88, 7.040000000000001, 7.2, 7.360000000000001, 7.5200000000000005, 7.6800000000000015, 7.840000000000001, 8.0, 8.160000000000002, 8.32, 8.480000000000002, 8.64, 8.8, 8.96, 9.120000000000001, 9.280000000000001, 9.440000000000001, 9.600000000000001, 9.760000000000002, 9.920000000000002, 10.080000000000002, 10.240000000000002, 10.4, 10.560000000000002, 10.72, 10.880000000000003, 11.040000000000001, 11.200000000000001, 11.360000000000001, 11.520000000000001, 11.680000000000001, 11.840000000000002, 12.0, 12.160000000000002, 12.32, 12.480000000000002, 12.64, 12.8, 12.96, 13.120000000000003, 13.280000000000001, 13.440000000000001, 13.600000000000001, 13.76, 13.920000000000002, 14.080000000000002, 14.240000000000002, 14.4, 14.56, 14.720000000000002, 14.880000000000003, 15.040000000000001, 15.200000000000001, 15.360000000000003, 15.520000000000003, 15.680000000000001, 15.840000000000002, 16.0, 16.160000000000004], [0.0, 0.17000000000000004, 0.3400000000000001, 0.5100000000000001, 0.6800000000000002, 0.8500000000000001, 1.0200000000000002, 1.1900000000000002, 1.3600000000000003, 1.5300000000000002, 1.7000000000000002, 1.8700000000000003, 2.0400000000000005, 2.2100000000000004, 2.3800000000000003, 2.5500000000000003, 2.7200000000000006, 2.8900000000000006, 3.0600000000000005, 3.2300000000000004, 3.4000000000000004, 3.5700000000000007, 3.7400000000000007, 3.910000000000001, 4.080000000000001, 4.25, 4.420000000000001, 4.590000000000001, 4.760000000000001, 4.9300000000000015, 5.1000000000000005, 5.2700000000000005, 5.440000000000001, 5.610000000000001, 5.780000000000001, 5.950000000000001, 6.120000000000001, 6.290000000000001, 6.460000000000001, 6.630000000000002, 6.800000000000001, 6.9700000000000015, 7.1400000000000015, 7.3100000000000005, 7.480000000000001, 7.65, 7.820000000000002, 7.990000000000001, 8.160000000000002, 8.330000000000002, 8.5, 8.670000000000002, 8.840000000000002, 9.010000000000002, 9.180000000000001, 9.350000000000001, 9.520000000000001, 9.690000000000001, 9.860000000000003, 10.030000000000001, 10.200000000000001, 10.370000000000003, 10.540000000000001, 10.710000000000003, 10.880000000000003, 11.05, 11.220000000000002, 11.390000000000002, 11.560000000000002, 11.730000000000002, 11.900000000000002, 12.070000000000002, 12.240000000000002, 12.410000000000002, 12.580000000000002, 12.750000000000002, 12.920000000000002, 13.090000000000002, 13.260000000000003, 13.430000000000001, 13.600000000000001, 13.770000000000001, 13.940000000000003, 14.110000000000003, 14.280000000000003, 14.450000000000001, 14.620000000000001, 14.790000000000003, 14.960000000000003, 15.130000000000003, 15.3, 15.47, 15.640000000000004, 15.810000000000002, 15.980000000000002, 16.150000000000002, 16.320000000000004, 16.490000000000002, 16.660000000000004, 16.830000000000002, 17.0, 17.170000000000005], [0.0, 0.18000000000000002, 0.36000000000000004, 0.5400000000000001, 0.7200000000000001, 0.9, 1.0800000000000003, 1.2600000000000002, 1.4400000000000002, 1.62, 1.8, 1.9800000000000002, 2.1600000000000006, 2.3400000000000003, 2.5200000000000005, 2.7, 2.8800000000000003, 3.0600000000000005, 3.24, 3.4200000000000004, 3.6, 3.7800000000000002, 3.9600000000000004, 4.140000000000001, 4.320000000000001, 4.5, 4.680000000000001, 4.86, 5.040000000000001, 5.220000000000001, 5.4, 5.58, 5.760000000000001, 5.94, 6.120000000000001, 6.3, 6.48, 6.66, 6.840000000000001, 7.0200000000000005, 7.2, 7.380000000000001, 7.5600000000000005, 7.74, 7.920000000000001, 8.1, 8.280000000000001, 8.46, 8.640000000000002, 8.82, 9.0, 9.180000000000001, 9.360000000000001, 9.540000000000001, 9.72, 9.9, 10.080000000000002, 10.26, 10.440000000000001, 10.620000000000001, 10.8, 10.98, 11.16, 11.340000000000002, 11.520000000000001, 11.700000000000001, 11.88, 12.06, 12.240000000000002, 12.420000000000002, 12.6, 12.780000000000001, 12.96, 13.140000000000002, 13.32, 13.5, 13.680000000000001, 13.860000000000001, 14.040000000000001, 14.22, 14.4, 14.58, 14.760000000000002, 14.940000000000001, 15.120000000000001, 15.3, 15.48, 15.660000000000002, 15.840000000000002, 16.02, 16.2, 16.38, 16.560000000000002, 16.740000000000002, 16.92, 17.1, 17.280000000000005, 17.46, 17.64, 17.82, 18.0, 18.180000000000003], [0.0, 0.19000000000000003, 0.38000000000000006, 0.5700000000000002, 0.7600000000000001, 0.9500000000000001, 1.1400000000000003, 1.3300000000000003, 1.5200000000000002, 1.7100000000000002, 1.9000000000000001, 2.0900000000000003, 2.2800000000000007, 2.47, 2.6600000000000006, 2.85, 3.0400000000000005, 3.2300000000000004, 3.4200000000000004, 3.6100000000000003, 3.8000000000000003, 3.9900000000000007, 4.180000000000001, 4.370000000000001, 4.560000000000001, 4.75, 4.94, 5.130000000000001, 5.320000000000001, 5.510000000000001, 5.7, 5.890000000000001, 6.080000000000001, 6.270000000000001, 6.460000000000001, 6.65, 6.840000000000001, 7.030000000000001, 7.220000000000001, 7.410000000000001, 7.6000000000000005, 7.790000000000002, 7.980000000000001, 8.17, 8.360000000000001, 8.55, 8.740000000000002, 8.930000000000001, 9.120000000000003, 9.31, 9.5, 9.690000000000001, 9.88, 10.070000000000002, 10.260000000000002, 10.450000000000001, 10.640000000000002, 10.830000000000002, 11.020000000000001, 11.21, 11.4, 11.590000000000002, 11.780000000000001, 11.970000000000002, 12.160000000000002, 12.350000000000001, 12.540000000000003, 12.73, 12.920000000000002, 13.110000000000001, 13.3, 13.490000000000002, 13.680000000000001, 13.870000000000003, 14.060000000000002, 14.250000000000002, 14.440000000000001, 14.63, 14.820000000000002, 15.010000000000002, 15.200000000000001, 15.39, 15.580000000000004, 15.770000000000003, 15.960000000000003, 16.150000000000002, 16.34, 16.530000000000005, 16.720000000000002, 16.91, 17.1, 17.29, 17.480000000000004, 17.67, 17.860000000000003, 18.05, 18.240000000000006, 18.430000000000003, 18.62, 18.810000000000002, 19.0, 19.190000000000005], [0.0, 0.2, 0.4, 0.6000000000000001, 0.8, 1.0, 1.2000000000000002, 1.4000000000000001, 1.6, 1.8, 2.0, 2.2, 2.4000000000000004, 2.6, 2.8000000000000003, 3.0, 3.2, 3.4000000000000004, 3.6, 3.8000000000000003, 4.0, 4.2, 4.4, 4.6000000000000005, 4.800000000000001, 5.0, 5.2, 5.4, 5.6000000000000005, 5.800000000000001, 6.0, 6.2, 6.4, 6.6000000000000005, 6.800000000000001, 7.0, 7.2, 7.4, 7.6000000000000005, 7.800000000000001, 8.0, 8.200000000000001, 8.4, 8.6, 8.8, 9.0, 9.200000000000001, 9.4, 9.600000000000001, 9.8, 10.0, 10.200000000000001, 10.4, 10.600000000000001, 10.8, 11.0, 11.200000000000001, 11.4, 11.600000000000001, 11.8, 12.0, 12.200000000000001, 12.4, 12.600000000000001, 12.8, 13.0, 13.200000000000001, 13.4, 13.600000000000001, 13.8, 14.0, 14.200000000000001, 14.4, 14.600000000000001, 14.8, 15.0, 15.200000000000001, 15.4, 15.600000000000001, 15.8, 16.0, 16.2, 16.400000000000002, 16.6, 16.8, 17.0, 17.2, 17.400000000000002, 17.6, 17.8, 18.0, 18.2, 18.400000000000002, 18.6, 18.8, 19.0, 19.200000000000003, 19.400000000000002, 19.6, 19.8, 20.0, 20.200000000000003], [0.0, 0.21000000000000002, 0.42000000000000004, 0.6300000000000001, 0.8400000000000001, 1.05, 1.2600000000000002, 1.4700000000000002, 1.6800000000000002, 1.8900000000000001, 2.1, 2.3100000000000005, 2.5200000000000005, 2.7300000000000004, 2.9400000000000004, 3.1500000000000004, 3.3600000000000003, 3.5700000000000007, 3.7800000000000002, 3.9900000000000007, 4.2, 4.41, 4.620000000000001, 4.830000000000001, 5.040000000000001, 5.25, 5.460000000000001, 5.670000000000001, 5.880000000000001, 6.090000000000001, 6.300000000000001, 6.510000000000001, 6.720000000000001, 6.930000000000001, 7.1400000000000015, 7.3500000000000005, 7.5600000000000005, 7.7700000000000005, 7.980000000000001, 8.190000000000001, 8.4, 8.610000000000001, 8.82, 9.03, 9.240000000000002, 9.450000000000001, 9.660000000000002, 9.870000000000001, 10.080000000000002, 10.290000000000001, 10.5, 10.71, 10.920000000000002, 11.130000000000003, 11.340000000000002, 11.55, 11.760000000000002, 11.97, 12.180000000000001, 12.39, 12.600000000000001, 12.810000000000002, 13.020000000000001, 13.230000000000002, 13.440000000000001, 13.65, 13.860000000000001, 14.07, 14.280000000000003, 14.490000000000002, 14.700000000000001, 14.910000000000002, 15.120000000000001, 15.330000000000002, 15.540000000000001, 15.75, 15.960000000000003, 16.17, 16.380000000000003, 16.59, 16.8, 17.01, 17.220000000000002, 17.430000000000003, 17.64, 17.85, 18.06, 18.270000000000003, 18.480000000000004, 18.69, 18.900000000000002, 19.11, 19.320000000000004, 19.53, 19.740000000000002, 19.95, 20.160000000000004, 20.370000000000005, 20.580000000000002, 20.790000000000003, 21.0, 21.210000000000004], [0.0, 0.22000000000000003, 0.44000000000000006, 0.6600000000000001, 0.8800000000000001, 1.1, 1.3200000000000003, 1.5400000000000003, 1.7600000000000002, 1.9800000000000002, 2.2, 2.4200000000000004, 2.6400000000000006, 2.8600000000000003, 3.0800000000000005, 3.3000000000000003, 3.5200000000000005, 3.7400000000000007, 3.9600000000000004, 4.180000000000001, 4.4, 4.620000000000001, 4.840000000000001, 5.060000000000001, 5.280000000000001, 5.5, 5.720000000000001, 5.940000000000001, 6.160000000000001, 6.380000000000002, 6.6000000000000005, 6.820000000000001, 7.040000000000001, 7.260000000000002, 7.480000000000001, 7.700000000000001, 7.920000000000001, 8.14, 8.360000000000001, 8.580000000000002, 8.8, 9.020000000000001, 9.240000000000002, 9.46, 9.680000000000001, 9.9, 10.120000000000003, 10.340000000000002, 10.560000000000002, 10.780000000000001, 11.0, 11.220000000000002, 11.440000000000001, 11.660000000000002, 11.880000000000003, 12.100000000000001, 12.320000000000002, 12.540000000000001, 12.760000000000003, 12.980000000000002, 13.200000000000001, 13.420000000000002, 13.640000000000002, 13.860000000000003, 14.080000000000002, 14.3, 14.520000000000003, 14.740000000000002, 14.960000000000003, 15.180000000000001, 15.400000000000002, 15.620000000000003, 15.840000000000002, 16.060000000000002, 16.28, 16.5, 16.720000000000002, 16.94, 17.160000000000004, 17.380000000000003, 17.6, 17.82, 18.040000000000003, 18.26, 18.480000000000004, 18.700000000000003, 18.92, 19.140000000000004, 19.360000000000003, 19.580000000000002, 19.8, 20.02, 20.240000000000006, 20.460000000000004, 20.680000000000003, 20.900000000000002, 21.120000000000005, 21.340000000000003, 21.560000000000002, 21.78, 22.0, 22.220000000000006], [0.0, 0.23000000000000004, 0.4600000000000001, 0.6900000000000002, 0.9200000000000002, 1.1500000000000001, 1.3800000000000003, 1.6100000000000003, 1.8400000000000003, 2.0700000000000003, 2.3000000000000003, 2.5300000000000007, 2.7600000000000007, 2.9900000000000007, 3.2200000000000006, 3.45, 3.6800000000000006, 3.910000000000001, 4.140000000000001, 4.370000000000001, 4.6000000000000005, 4.830000000000001, 5.060000000000001, 5.290000000000001, 5.520000000000001, 5.750000000000001, 5.980000000000001, 6.210000000000001, 6.440000000000001, 6.670000000000002, 6.9, 7.130000000000001, 7.360000000000001, 7.590000000000002, 7.820000000000002, 8.05, 8.280000000000001, 8.510000000000002, 8.740000000000002, 8.970000000000002, 9.200000000000001, 9.430000000000001, 9.660000000000002, 9.89, 10.120000000000003, 10.350000000000001, 10.580000000000002, 10.810000000000002, 11.040000000000003, 11.270000000000001, 11.500000000000002, 11.730000000000002, 11.960000000000003, 12.190000000000003, 12.420000000000002, 12.650000000000002, 12.880000000000003, 13.110000000000001, 13.340000000000003, 13.570000000000002, 13.8, 14.030000000000003, 14.260000000000002, 14.490000000000004, 14.720000000000002, 14.950000000000001, 15.180000000000003, 15.410000000000002, 15.640000000000004, 15.870000000000003, 16.1, 16.330000000000002, 16.560000000000002, 16.790000000000003, 17.020000000000003, 17.250000000000004, 17.480000000000004, 17.71, 17.940000000000005, 18.17, 18.400000000000002, 18.630000000000003, 18.860000000000003, 19.090000000000003, 19.320000000000004, 19.55, 19.78, 20.010000000000005, 20.240000000000006, 20.470000000000002, 20.700000000000003, 20.930000000000003, 21.160000000000004, 21.390000000000004, 21.620000000000005, 21.85, 22.080000000000005, 22.310000000000006, 22.540000000000003, 22.770000000000003, 23.000000000000004, 23.230000000000008], [0.0, 0.24000000000000005, 0.4800000000000001, 0.7200000000000002, 0.9600000000000002, 1.2000000000000002, 1.4400000000000004, 1.6800000000000004, 1.9200000000000004, 2.1600000000000006, 2.4000000000000004, 2.6400000000000006, 2.880000000000001, 3.1200000000000006, 3.3600000000000008, 3.6000000000000005, 3.8400000000000007, 4.080000000000001, 4.320000000000001, 4.560000000000001, 4.800000000000001, 5.040000000000001, 5.280000000000001, 5.520000000000001, 5.760000000000002, 6.000000000000001, 6.240000000000001, 6.480000000000001, 6.7200000000000015, 6.960000000000002, 7.200000000000001, 7.440000000000001, 7.6800000000000015, 7.920000000000002, 8.160000000000002, 8.400000000000002, 8.640000000000002, 8.880000000000003, 9.120000000000003, 9.360000000000003, 9.600000000000001, 9.840000000000003, 10.080000000000002, 10.32, 10.560000000000002, 10.8, 11.040000000000003, 11.280000000000003, 11.520000000000003, 11.760000000000003, 12.000000000000002, 12.240000000000004, 12.480000000000002, 12.720000000000004, 12.960000000000003, 13.200000000000003, 13.440000000000003, 13.680000000000003, 13.920000000000003, 14.160000000000004, 14.400000000000002, 14.640000000000004, 14.880000000000003, 15.120000000000005, 15.360000000000003, 15.600000000000001, 15.840000000000003, 16.080000000000002, 16.320000000000004, 16.560000000000002, 16.800000000000004, 17.040000000000003, 17.280000000000005, 17.520000000000003, 17.760000000000005, 18.000000000000004, 18.240000000000006, 18.480000000000004, 18.720000000000006, 18.960000000000004, 19.200000000000003, 19.44, 19.680000000000007, 19.920000000000005, 20.160000000000004, 20.400000000000002, 20.64, 20.880000000000006, 21.120000000000005, 21.360000000000003, 21.6, 21.840000000000003, 22.080000000000005, 22.320000000000004, 22.560000000000006, 22.800000000000004, 23.040000000000006, 23.280000000000005, 23.520000000000007, 23.760000000000005, 24.000000000000004, 24.240000000000006], [0.0, 0.25, 0.5, 0.7500000000000001, 1.0, 1.25, 1.5000000000000002, 1.7500000000000002, 2.0, 2.25, 2.5, 2.75, 3.0000000000000004, 3.25, 3.5000000000000004, 3.75, 4.0, 4.25, 4.5, 4.75, 5.0, 5.25, 5.5, 5.750000000000001, 6.000000000000001, 6.25, 6.5, 6.75, 7.000000000000001, 7.250000000000001, 7.5, 7.75, 8.0, 8.25, 8.5, 8.75, 9.0, 9.25, 9.5, 9.75, 10.0, 10.250000000000002, 10.5, 10.75, 11.0, 11.25, 11.500000000000002, 11.75, 12.000000000000002, 12.25, 12.5, 12.750000000000002, 13.0, 13.250000000000002, 13.5, 13.75, 14.000000000000002, 14.25, 14.500000000000002, 14.75, 15.0, 15.250000000000002, 15.5, 15.750000000000002, 16.0, 16.25, 16.5, 16.75, 17.0, 17.25, 17.5, 17.75, 18.0, 18.25, 18.5, 18.75, 19.0, 19.25, 19.5, 19.75, 20.0, 20.25, 20.500000000000004, 20.75, 21.0, 21.25, 21.5, 21.750000000000004, 22.0, 22.25, 22.5, 22.75, 23.000000000000004, 23.25, 23.5, 23.75, 24.000000000000004, 24.250000000000004, 24.5, 24.75, 25.0, 25.250000000000004], [0.0, 0.26, 0.52, 0.7800000000000001, 1.04, 1.3, 1.5600000000000003, 1.8200000000000003, 2.08, 2.3400000000000003, 2.6, 2.8600000000000003, 3.1200000000000006, 3.3800000000000003, 3.6400000000000006, 3.9000000000000004, 4.16, 4.420000000000001, 4.680000000000001, 4.94, 5.2, 5.460000000000001, 5.720000000000001, 5.980000000000001, 6.240000000000001, 6.5, 6.760000000000001, 7.0200000000000005, 7.280000000000001, 7.540000000000001, 7.800000000000001, 8.06, 8.32, 8.580000000000002, 8.840000000000002, 9.1, 9.360000000000001, 9.620000000000001, 9.88, 10.14, 10.4, 10.660000000000002, 10.920000000000002, 11.18, 11.440000000000001, 11.700000000000001, 11.960000000000003, 12.22, 12.480000000000002, 12.740000000000002, 13.0, 13.260000000000002, 13.520000000000001, 13.780000000000003, 14.040000000000001, 14.3, 14.560000000000002, 14.82, 15.080000000000002, 15.340000000000002, 15.600000000000001, 15.860000000000001, 16.12, 16.380000000000003, 16.64, 16.900000000000002, 17.160000000000004, 17.42, 17.680000000000003, 17.94, 18.2, 18.46, 18.720000000000002, 18.980000000000004, 19.240000000000002, 19.5, 19.76, 20.02, 20.28, 20.540000000000003, 20.8, 21.06, 21.320000000000004, 21.580000000000002, 21.840000000000003, 22.1, 22.36, 22.620000000000005, 22.880000000000003, 23.14, 23.400000000000002, 23.66, 23.920000000000005, 24.180000000000003, 24.44, 24.7, 24.960000000000004, 25.220000000000002, 25.480000000000004, 25.740000000000002, 26.0, 26.260000000000005], [0.0, 0.27, 0.54, 0.8100000000000002, 1.08, 1.35, 1.6200000000000003, 1.8900000000000003, 2.16, 2.43, 2.7, 2.9700000000000006, 3.2400000000000007, 3.5100000000000002, 3.7800000000000007, 4.050000000000001, 4.32, 4.590000000000001, 4.86, 5.130000000000001, 5.4, 5.670000000000001, 5.940000000000001, 6.210000000000001, 6.480000000000001, 6.75, 7.0200000000000005, 7.290000000000001, 7.560000000000001, 7.830000000000002, 8.100000000000001, 8.370000000000001, 8.64, 8.910000000000002, 9.180000000000001, 9.450000000000001, 9.72, 9.990000000000002, 10.260000000000002, 10.530000000000001, 10.8, 11.070000000000002, 11.340000000000002, 11.61, 11.880000000000003, 12.15, 12.420000000000002, 12.690000000000001, 12.960000000000003, 13.230000000000002, 13.5, 13.770000000000003, 14.040000000000001, 14.310000000000002, 14.580000000000002, 14.850000000000001, 15.120000000000003, 15.390000000000002, 15.660000000000004, 15.930000000000001, 16.200000000000003, 16.470000000000002, 16.740000000000002, 17.01, 17.28, 17.55, 17.820000000000004, 18.090000000000003, 18.360000000000003, 18.630000000000003, 18.900000000000002, 19.17, 19.44, 19.710000000000004, 19.980000000000004, 20.25, 20.520000000000003, 20.790000000000003, 21.060000000000002, 21.330000000000002, 21.6, 21.87, 22.140000000000004, 22.410000000000004, 22.680000000000003, 22.950000000000003, 23.22, 23.490000000000006, 23.760000000000005, 24.03, 24.3, 24.57, 24.840000000000003, 25.110000000000003, 25.380000000000003, 25.650000000000002, 25.920000000000005, 26.190000000000005, 26.460000000000004, 26.730000000000004, 27.0, 27.270000000000007], [0.0, 0.28, 0.56, 0.8400000000000002, 1.12, 1.4000000000000001, 1.6800000000000004, 1.9600000000000004, 2.24, 2.5200000000000005, 2.8000000000000003, 3.0800000000000005, 3.3600000000000008, 3.6400000000000006, 3.920000000000001, 4.2, 4.48, 4.760000000000001, 5.040000000000001, 5.320000000000001, 5.6000000000000005, 5.880000000000001, 6.160000000000001, 6.440000000000001, 6.7200000000000015, 7.000000000000001, 7.280000000000001, 7.560000000000001, 7.840000000000002, 8.120000000000001, 8.4, 8.680000000000001, 8.96, 9.240000000000002, 9.520000000000001, 9.8, 10.080000000000002, 10.360000000000001, 10.640000000000002, 10.920000000000002, 11.200000000000001, 11.480000000000002, 11.760000000000002, 12.040000000000001, 12.320000000000002, 12.600000000000001, 12.880000000000003, 13.160000000000002, 13.440000000000003, 13.720000000000002, 14.000000000000002, 14.280000000000003, 14.560000000000002, 14.840000000000003, 15.120000000000003, 15.400000000000002, 15.680000000000003, 15.960000000000003, 16.240000000000002, 16.520000000000003, 16.8, 17.080000000000002, 17.360000000000003, 17.640000000000004, 17.92, 18.200000000000003, 18.480000000000004, 18.76, 19.040000000000003, 19.320000000000004, 19.6, 19.880000000000003, 20.160000000000004, 20.440000000000005, 20.720000000000002, 21.000000000000004, 21.280000000000005, 21.560000000000002, 21.840000000000003, 22.120000000000005, 22.400000000000002, 22.68, 22.960000000000004, 23.240000000000006, 23.520000000000003, 23.8, 24.080000000000002, 24.360000000000007, 24.640000000000004, 24.92, 25.200000000000003, 25.48, 25.760000000000005, 26.040000000000003, 26.320000000000004, 26.6, 26.880000000000006, 27.160000000000007, 27.440000000000005, 27.720000000000002, 28.000000000000004, 28.28000000000001], [0.0, 0.29000000000000004, 0.5800000000000001, 0.8700000000000002, 1.1600000000000001, 1.4500000000000002, 1.7400000000000004, 2.0300000000000002, 2.3200000000000003, 2.6100000000000003, 2.9000000000000004, 3.190000000000001, 3.480000000000001, 3.7700000000000005, 4.0600000000000005, 4.3500000000000005, 4.640000000000001, 4.9300000000000015, 5.220000000000001, 5.510000000000001, 5.800000000000001, 6.090000000000001, 6.380000000000002, 6.670000000000002, 6.960000000000002, 7.250000000000001, 7.540000000000001, 7.830000000000002, 8.120000000000001, 8.410000000000002, 8.700000000000001, 8.990000000000002, 9.280000000000001, 9.570000000000002, 9.860000000000003, 10.150000000000002, 10.440000000000001, 10.730000000000002, 11.020000000000001, 11.310000000000002, 11.600000000000001, 11.890000000000002, 12.180000000000001, 12.47, 12.760000000000003, 13.05, 13.340000000000003, 13.630000000000003, 13.920000000000003, 14.210000000000003, 14.500000000000002, 14.790000000000003, 15.080000000000002, 15.370000000000005, 15.660000000000004, 15.950000000000003, 16.240000000000002, 16.53, 16.820000000000004, 17.110000000000003, 17.400000000000002, 17.690000000000005, 17.980000000000004, 18.270000000000003, 18.560000000000002, 18.85, 19.140000000000004, 19.430000000000003, 19.720000000000006, 20.010000000000005, 20.300000000000004, 20.590000000000003, 20.880000000000003, 21.170000000000005, 21.460000000000004, 21.750000000000004, 22.040000000000003, 22.330000000000002, 22.620000000000005, 22.910000000000004, 23.200000000000003, 23.490000000000002, 23.780000000000005, 24.070000000000004, 24.360000000000003, 24.650000000000002, 24.94, 25.230000000000008, 25.520000000000007, 25.810000000000006, 26.1, 26.39, 26.680000000000007, 26.970000000000006, 27.260000000000005, 27.550000000000004, 27.840000000000007, 28.130000000000006, 28.420000000000005, 28.710000000000004, 29.000000000000004, 29.290000000000006], [0.0, 0.30000000000000004, 0.6000000000000001, 0.9000000000000001, 1.2000000000000002, 1.5, 1.8000000000000003, 2.1, 2.4000000000000004, 2.7, 3.0, 3.3000000000000003, 3.6000000000000005, 3.9000000000000004, 4.2, 4.5, 4.800000000000001, 5.1000000000000005, 5.4, 5.7, 6.0, 6.300000000000001, 6.6000000000000005, 6.9, 7.200000000000001, 7.5, 7.800000000000001, 8.100000000000001, 8.4, 8.700000000000001, 9.0, 9.3, 9.600000000000001, 9.9, 10.200000000000001, 10.5, 10.8, 11.100000000000001, 11.4, 11.700000000000001, 12.0, 12.3, 12.600000000000001, 12.899999999999999, 13.200000000000001, 13.5, 13.8, 14.100000000000001, 14.400000000000002, 14.700000000000001, 15.0, 15.3, 15.600000000000001, 15.900000000000002, 16.200000000000003, 16.5, 16.8, 17.1, 17.400000000000002, 17.700000000000003, 18.0, 18.3, 18.6, 18.900000000000002, 19.200000000000003, 19.5, 19.8, 20.1, 20.400000000000002, 20.700000000000003, 21.0, 21.3, 21.6, 21.900000000000002, 22.200000000000003, 22.5, 22.8, 23.1, 23.400000000000002, 23.700000000000003, 24.0, 24.299999999999997, 24.6, 24.900000000000002, 25.200000000000003, 25.5, 25.799999999999997, 26.1, 26.400000000000002, 26.700000000000003, 27.0, 27.299999999999997, 27.6, 27.900000000000002, 28.200000000000003, 28.5, 28.800000000000004, 29.1, 29.400000000000002, 29.700000000000003, 30.0, 30.300000000000004], [0.0, 0.31000000000000005, 0.6200000000000001, 0.9300000000000002, 1.2400000000000002, 1.55, 1.8600000000000003, 2.1700000000000004, 2.4800000000000004, 2.79, 3.1, 3.4100000000000006, 3.7200000000000006, 4.03, 4.340000000000001, 4.65, 4.960000000000001, 5.2700000000000005, 5.58, 5.890000000000001, 6.2, 6.510000000000001, 6.820000000000001, 7.130000000000001, 7.440000000000001, 7.75, 8.06, 8.370000000000001, 8.680000000000001, 8.990000000000002, 9.3, 9.610000000000001, 9.920000000000002, 10.23, 10.540000000000001, 10.85, 11.16, 11.47, 11.780000000000001, 12.090000000000002, 12.4, 12.710000000000003, 13.020000000000001, 13.33, 13.640000000000002, 13.950000000000001, 14.260000000000002, 14.57, 14.880000000000003, 15.190000000000001, 15.5, 15.810000000000002, 16.12, 16.430000000000003, 16.740000000000002, 17.05, 17.360000000000003, 17.67, 17.980000000000004, 18.290000000000003, 18.6, 18.910000000000004, 19.220000000000002, 19.53, 19.840000000000003, 20.150000000000002, 20.46, 20.77, 21.080000000000002, 21.39, 21.7, 22.01, 22.32, 22.630000000000003, 22.94, 23.25, 23.560000000000002, 23.87, 24.180000000000003, 24.490000000000002, 24.8, 25.11, 25.420000000000005, 25.730000000000004, 26.040000000000003, 26.35, 26.66, 26.970000000000002, 27.280000000000005, 27.590000000000003, 27.900000000000002, 28.21, 28.520000000000003, 28.830000000000002, 29.14, 29.45, 29.760000000000005, 30.070000000000004, 30.380000000000003, 30.69, 31.0, 31.310000000000006], [0.0, 0.32000000000000006, 0.6400000000000001, 0.9600000000000002, 1.2800000000000002, 1.6, 1.9200000000000004, 2.24, 2.5600000000000005, 2.8800000000000003, 3.2, 3.5200000000000005, 3.8400000000000007, 4.16, 4.48, 4.800000000000001, 5.120000000000001, 5.440000000000001, 5.760000000000001, 6.080000000000001, 6.4, 6.720000000000001, 7.040000000000001, 7.360000000000001, 7.6800000000000015, 8.0, 8.32, 8.64, 8.96, 9.280000000000001, 9.600000000000001, 9.920000000000002, 10.240000000000002, 10.560000000000002, 10.880000000000003, 11.200000000000001, 11.520000000000001, 11.840000000000002, 12.160000000000002, 12.480000000000002, 12.8, 13.120000000000003, 13.440000000000001, 13.76, 14.080000000000002, 14.4, 14.720000000000002, 15.040000000000001, 15.360000000000003, 15.680000000000001, 16.0, 16.320000000000004, 16.64, 16.960000000000004, 17.28, 17.6, 17.92, 18.240000000000002, 18.560000000000002, 18.880000000000003, 19.200000000000003, 19.520000000000003, 19.840000000000003, 20.160000000000004, 20.480000000000004, 20.8, 21.120000000000005, 21.44, 21.760000000000005, 22.080000000000002, 22.400000000000002, 22.720000000000002, 23.040000000000003, 23.360000000000003, 23.680000000000003, 24.0, 24.320000000000004, 24.64, 24.960000000000004, 25.28, 25.6, 25.92, 26.240000000000006, 26.560000000000002, 26.880000000000003, 27.200000000000003, 27.52, 27.840000000000003, 28.160000000000004, 28.480000000000004, 28.8, 29.12, 29.440000000000005, 29.760000000000005, 30.080000000000002, 30.400000000000002, 30.720000000000006, 31.040000000000006, 31.360000000000003, 31.680000000000003, 32.0, 32.32000000000001], [0.0, 0.33000000000000007, 0.6600000000000001, 0.9900000000000002, 1.3200000000000003, 1.6500000000000001, 1.9800000000000004, 2.3100000000000005, 2.6400000000000006, 2.97, 3.3000000000000003, 3.630000000000001, 3.960000000000001, 4.290000000000001, 4.620000000000001, 4.95, 5.280000000000001, 5.610000000000001, 5.94, 6.270000000000001, 6.6000000000000005, 6.930000000000001, 7.260000000000002, 7.590000000000002, 7.920000000000002, 8.25, 8.580000000000002, 8.910000000000002, 9.240000000000002, 9.570000000000002, 9.9, 10.23, 10.560000000000002, 10.890000000000002, 11.220000000000002, 11.55, 11.88, 12.21, 12.540000000000003, 12.870000000000003, 13.200000000000001, 13.530000000000003, 13.860000000000001, 14.190000000000001, 14.520000000000003, 14.850000000000001, 15.180000000000003, 15.510000000000002, 15.840000000000003, 16.17, 16.5, 16.830000000000002, 17.160000000000004, 17.490000000000002, 17.820000000000004, 18.150000000000002, 18.480000000000004, 18.810000000000002, 19.140000000000004, 19.470000000000002, 19.8, 20.130000000000003, 20.46, 20.790000000000003, 21.120000000000005, 21.450000000000003, 21.780000000000005, 22.110000000000003, 22.440000000000005, 22.770000000000003, 23.1, 23.430000000000003, 23.76, 24.090000000000003, 24.42, 24.750000000000004, 25.080000000000005, 25.410000000000004, 25.740000000000006, 26.070000000000004, 26.400000000000002, 26.73, 27.060000000000006, 27.390000000000004, 27.720000000000002, 28.05, 28.380000000000003, 28.710000000000004, 29.040000000000006, 29.370000000000005, 29.700000000000003, 30.03, 30.360000000000007, 30.690000000000005, 31.020000000000003, 31.35, 31.680000000000007, 32.010000000000005, 32.34, 32.67, 33.0, 33.330000000000005], [0.0, 0.3400000000000001, 0.6800000000000002, 1.0200000000000002, 1.3600000000000003, 1.7000000000000002, 2.0400000000000005, 2.3800000000000003, 2.7200000000000006, 3.0600000000000005, 3.4000000000000004, 3.7400000000000007, 4.080000000000001, 4.420000000000001, 4.760000000000001, 5.1000000000000005, 5.440000000000001, 5.780000000000001, 6.120000000000001, 6.460000000000001, 6.800000000000001, 7.1400000000000015, 7.480000000000001, 7.820000000000002, 8.160000000000002, 8.5, 8.840000000000002, 9.180000000000001, 9.520000000000001, 9.860000000000003, 10.200000000000001, 10.540000000000001, 10.880000000000003, 11.220000000000002, 11.560000000000002, 11.900000000000002, 12.240000000000002, 12.580000000000002, 12.920000000000002, 13.260000000000003, 13.600000000000001, 13.940000000000003, 14.280000000000003, 14.620000000000001, 14.960000000000003, 15.3, 15.640000000000004, 15.980000000000002, 16.320000000000004, 16.660000000000004, 17.0, 17.340000000000003, 17.680000000000003, 18.020000000000003, 18.360000000000003, 18.700000000000003, 19.040000000000003, 19.380000000000003, 19.720000000000006, 20.060000000000002, 20.400000000000002, 20.740000000000006, 21.080000000000002, 21.420000000000005, 21.760000000000005, 22.1, 22.440000000000005, 22.780000000000005, 23.120000000000005, 23.460000000000004, 23.800000000000004, 24.140000000000004, 24.480000000000004, 24.820000000000004, 25.160000000000004, 25.500000000000004, 25.840000000000003, 26.180000000000003, 26.520000000000007, 26.860000000000003, 27.200000000000003, 27.540000000000003, 27.880000000000006, 28.220000000000006, 28.560000000000006, 28.900000000000002, 29.240000000000002, 29.580000000000005, 29.920000000000005, 30.260000000000005, 30.6, 30.94, 31.28000000000001, 31.620000000000005, 31.960000000000004, 32.300000000000004, 32.64000000000001, 32.980000000000004, 33.32000000000001, 33.660000000000004, 34.0, 34.34000000000001], [0.0, 0.35000000000000003, 0.7000000000000001, 1.0500000000000003, 1.4000000000000001, 1.75, 2.1000000000000005, 2.45, 2.8000000000000003, 3.15, 3.5, 3.8500000000000005, 4.200000000000001, 4.55, 4.9, 5.25, 5.6000000000000005, 5.950000000000001, 6.3, 6.65, 7.0, 7.3500000000000005, 7.700000000000001, 8.05, 8.400000000000002, 8.75, 9.1, 9.450000000000001, 9.8, 10.150000000000002, 10.5, 10.85, 11.200000000000001, 11.55, 11.900000000000002, 12.25, 12.6, 12.950000000000001, 13.3, 13.650000000000002, 14.0, 14.350000000000001, 14.700000000000001, 15.049999999999999, 15.400000000000002, 15.75, 16.1, 16.45, 16.800000000000004, 17.150000000000002, 17.5, 17.85, 18.2, 18.550000000000004, 18.900000000000002, 19.25, 19.6, 19.95, 20.300000000000004, 20.650000000000002, 21.0, 21.35, 21.7, 22.050000000000004, 22.400000000000002, 22.75, 23.1, 23.45, 23.800000000000004, 24.150000000000002, 24.5, 24.85, 25.2, 25.550000000000004, 25.900000000000002, 26.25, 26.6, 26.95, 27.300000000000004, 27.650000000000002, 28.0, 28.349999999999998, 28.700000000000003, 29.050000000000004, 29.400000000000002, 29.75, 30.099999999999998, 30.450000000000003, 30.800000000000004, 31.150000000000002, 31.5, 31.849999999999998, 32.2, 32.550000000000004, 32.9, 33.25, 33.60000000000001, 33.95, 34.300000000000004, 34.65, 35.0, 35.35000000000001], [0.0, 0.36000000000000004, 0.7200000000000001, 1.0800000000000003, 1.4400000000000002, 1.8, 2.1600000000000006, 2.5200000000000005, 2.8800000000000003, 3.24, 3.6, 3.9600000000000004, 4.320000000000001, 4.680000000000001, 5.040000000000001, 5.4, 5.760000000000001, 6.120000000000001, 6.48, 6.840000000000001, 7.2, 7.5600000000000005, 7.920000000000001, 8.280000000000001, 8.640000000000002, 9.0, 9.360000000000001, 9.72, 10.080000000000002, 10.440000000000001, 10.8, 11.16, 11.520000000000001, 11.88, 12.240000000000002, 12.6, 12.96, 13.32, 13.680000000000001, 14.040000000000001, 14.4, 14.760000000000002, 15.120000000000001, 15.48, 15.840000000000002, 16.2, 16.560000000000002, 16.92, 17.280000000000005, 17.64, 18.0, 18.360000000000003, 18.720000000000002, 19.080000000000002, 19.44, 19.8, 20.160000000000004, 20.52, 20.880000000000003, 21.240000000000002, 21.6, 21.96, 22.32, 22.680000000000003, 23.040000000000003, 23.400000000000002, 23.76, 24.12, 24.480000000000004, 24.840000000000003, 25.2, 25.560000000000002, 25.92, 26.280000000000005, 26.64, 27.0, 27.360000000000003, 27.720000000000002, 28.080000000000002, 28.44, 28.8, 29.16, 29.520000000000003, 29.880000000000003, 30.240000000000002, 30.6, 30.96, 31.320000000000004, 31.680000000000003, 32.04, 32.4, 32.76, 33.120000000000005, 33.480000000000004, 33.84, 34.2, 34.56000000000001, 34.92, 35.28, 35.64, 36.0, 36.36000000000001], [0.0, 0.37000000000000005, 0.7400000000000001, 1.1100000000000003, 1.4800000000000002, 1.85, 2.2200000000000006, 2.5900000000000003, 2.9600000000000004, 3.33, 3.7, 4.07, 4.440000000000001, 4.8100000000000005, 5.180000000000001, 5.550000000000001, 5.920000000000001, 6.290000000000001, 6.66, 7.030000000000001, 7.4, 7.7700000000000005, 8.14, 8.510000000000002, 8.880000000000003, 9.25, 9.620000000000001, 9.990000000000002, 10.360000000000001, 10.730000000000002, 11.100000000000001, 11.47, 11.840000000000002, 12.21, 12.580000000000002, 12.950000000000001, 13.32, 13.690000000000001, 14.060000000000002, 14.430000000000001, 14.8, 15.170000000000003, 15.540000000000001, 15.91, 16.28, 16.650000000000002, 17.020000000000003, 17.39, 17.760000000000005, 18.130000000000003, 18.5, 18.870000000000005, 19.240000000000002, 19.610000000000003, 19.980000000000004, 20.35, 20.720000000000002, 21.090000000000003, 21.460000000000004, 21.830000000000002, 22.200000000000003, 22.570000000000004, 22.94, 23.310000000000002, 23.680000000000003, 24.05, 24.42, 24.790000000000003, 25.160000000000004, 25.53, 25.900000000000002, 26.270000000000003, 26.64, 27.010000000000005, 27.380000000000003, 27.75, 28.120000000000005, 28.490000000000002, 28.860000000000003, 29.230000000000004, 29.6, 29.97, 30.340000000000007, 30.710000000000004, 31.080000000000002, 31.450000000000003, 31.82, 32.190000000000005, 32.56, 32.93, 33.300000000000004, 33.67, 34.040000000000006, 34.410000000000004, 34.78, 35.15, 35.52000000000001, 35.89000000000001, 36.260000000000005, 36.63, 37.0, 37.370000000000005], [0.0, 0.38000000000000006, 0.7600000000000001, 1.1400000000000003, 1.5200000000000002, 1.9000000000000001, 2.2800000000000007, 2.6600000000000006, 3.0400000000000005, 3.4200000000000004, 3.8000000000000003, 4.180000000000001, 4.560000000000001, 4.94, 5.320000000000001, 5.7, 6.080000000000001, 6.460000000000001, 6.840000000000001, 7.220000000000001, 7.6000000000000005, 7.980000000000001, 8.360000000000001, 8.740000000000002, 9.120000000000003, 9.5, 9.88, 10.260000000000002, 10.640000000000002, 11.020000000000001, 11.4, 11.780000000000001, 12.160000000000002, 12.540000000000003, 12.920000000000002, 13.3, 13.680000000000001, 14.060000000000002, 14.440000000000001, 14.820000000000002, 15.200000000000001, 15.580000000000004, 15.960000000000003, 16.34, 16.720000000000002, 17.1, 17.480000000000004, 17.860000000000003, 18.240000000000006, 18.62, 19.0, 19.380000000000003, 19.76, 20.140000000000004, 20.520000000000003, 20.900000000000002, 21.280000000000005, 21.660000000000004, 22.040000000000003, 22.42, 22.8, 23.180000000000003, 23.560000000000002, 23.940000000000005, 24.320000000000004, 24.700000000000003, 25.080000000000005, 25.46, 25.840000000000003, 26.220000000000002, 26.6, 26.980000000000004, 27.360000000000003, 27.740000000000006, 28.120000000000005, 28.500000000000004, 28.880000000000003, 29.26, 29.640000000000004, 30.020000000000003, 30.400000000000002, 30.78, 31.160000000000007, 31.540000000000006, 31.920000000000005, 32.300000000000004, 32.68, 33.06000000000001, 33.440000000000005, 33.82, 34.2, 34.58, 34.96000000000001, 35.34, 35.720000000000006, 36.1, 36.48000000000001, 36.86000000000001, 37.24, 37.620000000000005, 38.0, 38.38000000000001], [0.0, 0.39000000000000007, 0.7800000000000001, 1.1700000000000004, 1.5600000000000003, 1.9500000000000002, 2.3400000000000007, 2.7300000000000004, 3.1200000000000006, 3.5100000000000002, 3.9000000000000004, 4.290000000000001, 4.6800000000000015, 5.07, 5.460000000000001, 5.8500000000000005, 6.240000000000001, 6.630000000000002, 7.0200000000000005, 7.410000000000001, 7.800000000000001, 8.190000000000001, 8.580000000000002, 8.970000000000002, 9.360000000000003, 9.75, 10.14, 10.530000000000001, 10.920000000000002, 11.310000000000002, 11.700000000000001, 12.090000000000002, 12.480000000000002, 12.870000000000003, 13.260000000000003, 13.650000000000002, 14.040000000000001, 14.430000000000001, 14.820000000000002, 15.210000000000003, 15.600000000000001, 15.990000000000004, 16.380000000000003, 16.77, 17.160000000000004, 17.55, 17.940000000000005, 18.330000000000002, 18.720000000000006, 19.110000000000003, 19.5, 19.890000000000004, 20.28, 20.670000000000005, 21.060000000000002, 21.450000000000003, 21.840000000000003, 22.230000000000004, 22.620000000000005, 23.010000000000005, 23.400000000000002, 23.790000000000003, 24.180000000000003, 24.570000000000004, 24.960000000000004, 25.35, 25.740000000000006, 26.130000000000003, 26.520000000000007, 26.910000000000004, 27.300000000000004, 27.690000000000005, 28.080000000000002, 28.470000000000006, 28.860000000000003, 29.250000000000004, 29.640000000000004, 30.030000000000005, 30.420000000000005, 30.810000000000006, 31.200000000000003, 31.59, 31.980000000000008, 32.370000000000005, 32.760000000000005, 33.150000000000006, 33.54, 33.93000000000001, 34.32000000000001, 34.71000000000001, 35.1, 35.49, 35.88000000000001, 36.27, 36.660000000000004, 37.050000000000004, 37.44000000000001, 37.830000000000005, 38.220000000000006, 38.61000000000001, 39.0, 39.39000000000001], [0.0, 0.4, 0.8, 1.2000000000000002, 1.6, 2.0, 2.4000000000000004, 2.8000000000000003, 3.2, 3.6, 4.0, 4.4, 4.800000000000001, 5.2, 5.6000000000000005, 6.0, 6.4, 6.800000000000001, 7.2, 7.6000000000000005, 8.0, 8.4, 8.8, 9.200000000000001, 9.600000000000001, 10.0, 10.4, 10.8, 11.200000000000001, 11.600000000000001, 12.0, 12.4, 12.8, 13.200000000000001, 13.600000000000001, 14.0, 14.4, 14.8, 15.200000000000001, 15.600000000000001, 16.0, 16.400000000000002, 16.8, 17.2, 17.6, 18.0, 18.400000000000002, 18.8, 19.200000000000003, 19.6, 20.0, 20.400000000000002, 20.8, 21.200000000000003, 21.6, 22.0, 22.400000000000002, 22.8, 23.200000000000003, 23.6, 24.0, 24.400000000000002, 24.8, 25.200000000000003, 25.6, 26.0, 26.400000000000002, 26.8, 27.200000000000003, 27.6, 28.0, 28.400000000000002, 28.8, 29.200000000000003, 29.6, 30.0, 30.400000000000002, 30.8, 31.200000000000003, 31.6, 32.0, 32.4, 32.800000000000004, 33.2, 33.6, 34.0, 34.4, 34.800000000000004, 35.2, 35.6, 36.0, 36.4, 36.800000000000004, 37.2, 37.6, 38.0, 38.400000000000006, 38.800000000000004, 39.2, 39.6, 40.0, 40.400000000000006], [0.0, 0.4100000000000001, 0.8200000000000002, 1.2300000000000004, 1.6400000000000003, 2.0500000000000003, 2.460000000000001, 2.8700000000000006, 3.2800000000000007, 3.6900000000000004, 4.1000000000000005, 4.510000000000001, 4.920000000000002, 5.330000000000001, 5.740000000000001, 6.15, 6.560000000000001, 6.9700000000000015, 7.380000000000001, 7.790000000000002, 8.200000000000001, 8.610000000000001, 9.020000000000001, 9.430000000000001, 9.840000000000003, 10.250000000000002, 10.660000000000002, 11.070000000000002, 11.480000000000002, 11.890000000000002, 12.3, 12.710000000000003, 13.120000000000003, 13.530000000000003, 13.940000000000003, 14.350000000000001, 14.760000000000002, 15.170000000000003, 15.580000000000004, 15.990000000000004, 16.400000000000002, 16.810000000000006, 17.220000000000002, 17.630000000000003, 18.040000000000003, 18.450000000000003, 18.860000000000003, 19.270000000000003, 19.680000000000007, 20.090000000000003, 20.500000000000004, 20.910000000000004, 21.320000000000004, 21.730000000000004, 22.140000000000004, 22.550000000000004, 22.960000000000004, 23.370000000000005, 23.780000000000005, 24.190000000000005, 24.6, 25.010000000000005, 25.420000000000005, 25.830000000000005, 26.240000000000006, 26.650000000000002, 27.060000000000006, 27.470000000000006, 27.880000000000006, 28.290000000000006, 28.700000000000003, 29.110000000000007, 29.520000000000003, 29.930000000000007, 30.340000000000007, 30.750000000000004, 31.160000000000007, 31.570000000000004, 31.980000000000008, 32.39000000000001, 32.800000000000004, 33.21, 33.62000000000001, 34.03000000000001, 34.440000000000005, 34.85, 35.260000000000005, 35.67000000000001, 36.080000000000005, 36.49000000000001, 36.900000000000006, 37.31, 37.720000000000006, 38.13000000000001, 38.540000000000006, 38.95, 39.360000000000014, 39.77000000000001, 40.18000000000001, 40.59, 41.00000000000001, 41.41000000000001], [0.0, 0.42000000000000004, 0.8400000000000001, 1.2600000000000002, 1.6800000000000002, 2.1, 2.5200000000000005, 2.9400000000000004, 3.3600000000000003, 3.7800000000000002, 4.2, 4.620000000000001, 5.040000000000001, 5.460000000000001, 5.880000000000001, 6.300000000000001, 6.720000000000001, 7.1400000000000015, 7.5600000000000005, 7.980000000000001, 8.4, 8.82, 9.240000000000002, 9.660000000000002, 10.080000000000002, 10.5, 10.920000000000002, 11.340000000000002, 11.760000000000002, 12.180000000000001, 12.600000000000001, 13.020000000000001, 13.440000000000001, 13.860000000000001, 14.280000000000003, 14.700000000000001, 15.120000000000001, 15.540000000000001, 15.960000000000003, 16.380000000000003, 16.8, 17.220000000000002, 17.64, 18.06, 18.480000000000004, 18.900000000000002, 19.320000000000004, 19.740000000000002, 20.160000000000004, 20.580000000000002, 21.0, 21.42, 21.840000000000003, 22.260000000000005, 22.680000000000003, 23.1, 23.520000000000003, 23.94, 24.360000000000003, 24.78, 25.200000000000003, 25.620000000000005, 26.040000000000003, 26.460000000000004, 26.880000000000003, 27.3, 27.720000000000002, 28.14, 28.560000000000006, 28.980000000000004, 29.400000000000002, 29.820000000000004, 30.240000000000002, 30.660000000000004, 31.080000000000002, 31.5, 31.920000000000005, 32.34, 32.760000000000005, 33.18, 33.6, 34.02, 34.440000000000005, 34.86000000000001, 35.28, 35.7, 36.12, 36.540000000000006, 36.96000000000001, 37.38, 37.800000000000004, 38.22, 38.64000000000001, 39.06, 39.480000000000004, 39.9, 40.32000000000001, 40.74000000000001, 41.160000000000004, 41.580000000000005, 42.0, 42.42000000000001], [0.0, 0.43, 0.86, 1.29, 1.72, 2.15, 2.58, 3.0100000000000002, 3.44, 3.87, 4.3, 4.73, 5.16, 5.59, 6.0200000000000005, 6.449999999999999, 6.88, 7.3100000000000005, 7.74, 8.17, 8.6, 9.03, 9.46, 9.89, 10.32, 10.75, 11.18, 11.61, 12.040000000000001, 12.47, 12.899999999999999, 13.33, 13.76, 14.190000000000001, 14.620000000000001, 15.049999999999999, 15.48, 15.91, 16.34, 16.77, 17.2, 17.630000000000003, 18.06, 18.49, 18.92, 19.349999999999998, 19.78, 20.21, 20.64, 21.07, 21.5, 21.93, 22.36, 22.790000000000003, 23.22, 23.65, 24.080000000000002, 24.509999999999998, 24.94, 25.37, 25.799999999999997, 26.23, 26.66, 27.090000000000003, 27.52, 27.95, 28.380000000000003, 28.81, 29.240000000000002, 29.67, 30.099999999999998, 30.53, 30.96, 31.39, 31.82, 32.25, 32.68, 33.11, 33.54, 33.97, 34.4, 34.83, 35.260000000000005, 35.690000000000005, 36.12, 36.55, 36.98, 37.410000000000004, 37.84, 38.27, 38.699999999999996, 39.129999999999995, 39.56, 39.99, 40.42, 40.85, 41.28, 41.71, 42.14, 42.57, 43.0, 43.43000000000001], [0.0, 0.44000000000000006, 0.8800000000000001, 1.3200000000000003, 1.7600000000000002, 2.2, 2.6400000000000006, 3.0800000000000005, 3.5200000000000005, 3.9600000000000004, 4.4, 4.840000000000001, 5.280000000000001, 5.720000000000001, 6.160000000000001, 6.6000000000000005, 7.040000000000001, 7.480000000000001, 7.920000000000001, 8.360000000000001, 8.8, 9.240000000000002, 9.680000000000001, 10.120000000000003, 10.560000000000002, 11.0, 11.440000000000001, 11.880000000000003, 12.320000000000002, 12.760000000000003, 13.200000000000001, 13.640000000000002, 14.080000000000002, 14.520000000000003, 14.960000000000003, 15.400000000000002, 15.840000000000002, 16.28, 16.720000000000002, 17.160000000000004, 17.6, 18.040000000000003, 18.480000000000004, 18.92, 19.360000000000003, 19.8, 20.240000000000006, 20.680000000000003, 21.120000000000005, 21.560000000000002, 22.0, 22.440000000000005, 22.880000000000003, 23.320000000000004, 23.760000000000005, 24.200000000000003, 24.640000000000004, 25.080000000000002, 25.520000000000007, 25.960000000000004, 26.400000000000002, 26.840000000000003, 27.280000000000005, 27.720000000000006, 28.160000000000004, 28.6, 29.040000000000006, 29.480000000000004, 29.920000000000005, 30.360000000000003, 30.800000000000004, 31.240000000000006, 31.680000000000003, 32.120000000000005, 32.56, 33.0, 33.440000000000005, 33.88, 34.32000000000001, 34.760000000000005, 35.2, 35.64, 36.080000000000005, 36.52, 36.96000000000001, 37.400000000000006, 37.84, 38.28000000000001, 38.720000000000006, 39.160000000000004, 39.6, 40.04, 40.48000000000001, 40.92000000000001, 41.36000000000001, 41.800000000000004, 42.24000000000001, 42.68000000000001, 43.120000000000005, 43.56, 44.0, 44.44000000000001], [0.0, 0.45, 0.9, 1.35, 1.8, 2.25, 2.7, 3.1500000000000004, 3.6, 4.05, 4.5, 4.95, 5.4, 5.8500000000000005, 6.300000000000001, 6.75, 7.2, 7.65, 8.1, 8.55, 9.0, 9.450000000000001, 9.9, 10.350000000000001, 10.8, 11.25, 11.700000000000001, 12.15, 12.600000000000001, 13.05, 13.5, 13.950000000000001, 14.4, 14.850000000000001, 15.3, 15.75, 16.2, 16.650000000000002, 17.1, 17.55, 18.0, 18.450000000000003, 18.900000000000002, 19.349999999999998, 19.8, 20.25, 20.700000000000003, 21.150000000000002, 21.6, 22.05, 22.5, 22.950000000000003, 23.400000000000002, 23.85, 24.3, 24.75, 25.200000000000003, 25.650000000000002, 26.1, 26.55, 27.0, 27.450000000000003, 27.900000000000002, 28.35, 28.8, 29.25, 29.700000000000003, 30.150000000000002, 30.6, 31.05, 31.5, 31.950000000000003, 32.4, 32.85, 33.300000000000004, 33.75, 34.2, 34.65, 35.1, 35.550000000000004, 36.0, 36.449999999999996, 36.900000000000006, 37.35, 37.800000000000004, 38.25, 38.699999999999996, 39.150000000000006, 39.6, 40.050000000000004, 40.5, 40.949999999999996, 41.400000000000006, 41.85, 42.300000000000004, 42.75, 43.2, 43.650000000000006, 44.1, 44.550000000000004, 45.0, 45.45], [0.0, 0.4600000000000001, 0.9200000000000002, 1.3800000000000003, 1.8400000000000003, 2.3000000000000003, 2.7600000000000007, 3.2200000000000006, 3.6800000000000006, 4.140000000000001, 4.6000000000000005, 5.060000000000001, 5.520000000000001, 5.980000000000001, 6.440000000000001, 6.9, 7.360000000000001, 7.820000000000002, 8.280000000000001, 8.740000000000002, 9.200000000000001, 9.660000000000002, 10.120000000000003, 10.580000000000002, 11.040000000000003, 11.500000000000002, 11.960000000000003, 12.420000000000002, 12.880000000000003, 13.340000000000003, 13.8, 14.260000000000002, 14.720000000000002, 15.180000000000003, 15.640000000000004, 16.1, 16.560000000000002, 17.020000000000003, 17.480000000000004, 17.940000000000005, 18.400000000000002, 18.860000000000003, 19.320000000000004, 19.78, 20.240000000000006, 20.700000000000003, 21.160000000000004, 21.620000000000005, 22.080000000000005, 22.540000000000003, 23.000000000000004, 23.460000000000004, 23.920000000000005, 24.380000000000006, 24.840000000000003, 25.300000000000004, 25.760000000000005, 26.220000000000002, 26.680000000000007, 27.140000000000004, 27.6, 28.060000000000006, 28.520000000000003, 28.980000000000008, 29.440000000000005, 29.900000000000002, 30.360000000000007, 30.820000000000004, 31.28000000000001, 31.740000000000006, 32.2, 32.660000000000004, 33.120000000000005, 33.580000000000005, 34.040000000000006, 34.50000000000001, 34.96000000000001, 35.42, 35.88000000000001, 36.34, 36.800000000000004, 37.260000000000005, 37.720000000000006, 38.18000000000001, 38.64000000000001, 39.1, 39.56, 40.02000000000001, 40.48000000000001, 40.940000000000005, 41.400000000000006, 41.86000000000001, 42.32000000000001, 42.78000000000001, 43.24000000000001, 43.7, 44.16000000000001, 44.62000000000001, 45.080000000000005, 45.540000000000006, 46.00000000000001, 46.460000000000015], [0.0, 0.47000000000000003, 0.9400000000000001, 1.4100000000000004, 1.8800000000000001, 2.35, 2.8200000000000007, 3.2900000000000005, 3.7600000000000002, 4.23, 4.7, 5.170000000000001, 5.6400000000000015, 6.11, 6.580000000000001, 7.050000000000001, 7.5200000000000005, 7.990000000000001, 8.46, 8.930000000000001, 9.4, 9.870000000000001, 10.340000000000002, 10.810000000000002, 11.280000000000003, 11.75, 12.22, 12.690000000000001, 13.160000000000002, 13.630000000000003, 14.100000000000001, 14.57, 15.040000000000001, 15.510000000000002, 15.980000000000002, 16.45, 16.92, 17.39, 17.860000000000003, 18.330000000000002, 18.8, 19.270000000000003, 19.740000000000002, 20.21, 20.680000000000003, 21.150000000000002, 21.620000000000005, 22.090000000000003, 22.560000000000006, 23.03, 23.5, 23.970000000000002, 24.44, 24.910000000000004, 25.380000000000003, 25.85, 26.320000000000004, 26.790000000000003, 27.260000000000005, 27.730000000000004, 28.200000000000003, 28.670000000000005, 29.14, 29.610000000000003, 30.080000000000002, 30.55, 31.020000000000003, 31.490000000000002, 31.960000000000004, 32.43, 32.9, 33.370000000000005, 33.84, 34.31, 34.78, 35.25, 35.720000000000006, 36.190000000000005, 36.660000000000004, 37.13, 37.6, 38.07, 38.540000000000006, 39.010000000000005, 39.480000000000004, 39.95, 40.42, 40.89000000000001, 41.36000000000001, 41.830000000000005, 42.300000000000004, 42.77, 43.24000000000001, 43.71000000000001, 44.18000000000001, 44.65, 45.12000000000001, 45.59, 46.06, 46.53, 47.0, 47.470000000000006], [0.0, 0.4800000000000001, 0.9600000000000002, 1.4400000000000004, 1.9200000000000004, 2.4000000000000004, 2.880000000000001, 3.3600000000000008, 3.8400000000000007, 4.320000000000001, 4.800000000000001, 5.280000000000001, 5.760000000000002, 6.240000000000001, 6.7200000000000015, 7.200000000000001, 7.6800000000000015, 8.160000000000002, 8.640000000000002, 9.120000000000003, 9.600000000000001, 10.080000000000002, 10.560000000000002, 11.040000000000003, 11.520000000000003, 12.000000000000002, 12.480000000000002, 12.960000000000003, 13.440000000000003, 13.920000000000003, 14.400000000000002, 14.880000000000003, 15.360000000000003, 15.840000000000003, 16.320000000000004, 16.800000000000004, 17.280000000000005, 17.760000000000005, 18.240000000000006, 18.720000000000006, 19.200000000000003, 19.680000000000007, 20.160000000000004, 20.64, 21.120000000000005, 21.6, 22.080000000000005, 22.560000000000006, 23.040000000000006, 23.520000000000007, 24.000000000000004, 24.480000000000008, 24.960000000000004, 25.44000000000001, 25.920000000000005, 26.400000000000006, 26.880000000000006, 27.360000000000007, 27.840000000000007, 28.320000000000007, 28.800000000000004, 29.28000000000001, 29.760000000000005, 30.24000000000001, 30.720000000000006, 31.200000000000003, 31.680000000000007, 32.160000000000004, 32.64000000000001, 33.120000000000005, 33.60000000000001, 34.080000000000005, 34.56000000000001, 35.040000000000006, 35.52000000000001, 36.00000000000001, 36.48000000000001, 36.96000000000001, 37.44000000000001, 37.92000000000001, 38.400000000000006, 38.88, 39.360000000000014, 39.84000000000001, 40.32000000000001, 40.800000000000004, 41.28, 41.76000000000001, 42.24000000000001, 42.720000000000006, 43.2, 43.68000000000001, 44.16000000000001, 44.64000000000001, 45.12000000000001, 45.60000000000001, 46.08000000000001, 46.56000000000001, 47.04000000000001, 47.52000000000001, 48.00000000000001, 48.48000000000001], [0.0, 0.49000000000000005, 0.9800000000000001, 1.4700000000000004, 1.9600000000000002, 2.45, 2.940000000000001, 3.4300000000000006, 3.9200000000000004, 4.41, 4.9, 5.390000000000001, 5.880000000000002, 6.370000000000001, 6.860000000000001, 7.3500000000000005, 7.840000000000001, 8.330000000000002, 8.82, 9.31, 9.8, 10.290000000000001, 10.780000000000001, 11.270000000000001, 11.760000000000003, 12.25, 12.740000000000002, 13.230000000000002, 13.720000000000002, 14.210000000000003, 14.700000000000001, 15.190000000000001, 15.680000000000001, 16.17, 16.660000000000004, 17.150000000000002, 17.64, 18.130000000000003, 18.62, 19.110000000000003, 19.6, 20.090000000000003, 20.580000000000002, 21.07, 21.560000000000002, 22.05, 22.540000000000003, 23.03, 23.520000000000007, 24.010000000000005, 24.5, 24.990000000000006, 25.480000000000004, 25.970000000000006, 26.460000000000004, 26.950000000000003, 27.440000000000005, 27.930000000000003, 28.420000000000005, 28.910000000000004, 29.400000000000002, 29.890000000000004, 30.380000000000003, 30.870000000000005, 31.360000000000003, 31.85, 32.34, 32.830000000000005, 33.32000000000001, 33.81, 34.300000000000004, 34.790000000000006, 35.28, 35.77, 36.260000000000005, 36.75, 37.24, 37.730000000000004, 38.220000000000006, 38.71000000000001, 39.2, 39.69, 40.18000000000001, 40.67000000000001, 41.160000000000004, 41.650000000000006, 42.14, 42.63000000000001, 43.120000000000005, 43.61000000000001, 44.1, 44.59, 45.080000000000005, 45.57000000000001, 46.06, 46.550000000000004, 47.04000000000001, 47.53000000000001, 48.02000000000001, 48.510000000000005, 49.0, 49.49000000000001], [0.0, 0.5, 1.0, 1.5000000000000002, 2.0, 2.5, 3.0000000000000004, 3.5000000000000004, 4.0, 4.5, 5.0, 5.5, 6.000000000000001, 6.5, 7.000000000000001, 7.5, 8.0, 8.5, 9.0, 9.5, 10.0, 10.5, 11.0, 11.500000000000002, 12.000000000000002, 12.5, 13.0, 13.5, 14.000000000000002, 14.500000000000002, 15.0, 15.5, 16.0, 16.5, 17.0, 17.5, 18.0, 18.5, 19.0, 19.5, 20.0, 20.500000000000004, 21.0, 21.5, 22.0, 22.5, 23.000000000000004, 23.5, 24.000000000000004, 24.5, 25.0, 25.500000000000004, 26.0, 26.500000000000004, 27.0, 27.5, 28.000000000000004, 28.5, 29.000000000000004, 29.5, 30.0, 30.500000000000004, 31.0, 31.500000000000004, 32.0, 32.5, 33.0, 33.5, 34.0, 34.5, 35.0, 35.5, 36.0, 36.5, 37.0, 37.5, 38.0, 38.5, 39.0, 39.5, 40.0, 40.5, 41.00000000000001, 41.5, 42.0, 42.5, 43.0, 43.50000000000001, 44.0, 44.5, 45.0, 45.5, 46.00000000000001, 46.5, 47.0, 47.5, 48.00000000000001, 48.50000000000001, 49.0, 49.5, 50.0, 50.50000000000001], [0.0, 0.5100000000000001, 1.0200000000000002, 1.5300000000000005, 2.0400000000000005, 2.5500000000000003, 3.060000000000001, 3.5700000000000007, 4.080000000000001, 4.590000000000001, 5.1000000000000005, 5.610000000000001, 6.120000000000002, 6.630000000000001, 7.1400000000000015, 7.65, 8.160000000000002, 8.670000000000002, 9.180000000000001, 9.690000000000001, 10.200000000000001, 10.71, 11.220000000000002, 11.730000000000002, 12.240000000000004, 12.750000000000002, 13.260000000000002, 13.770000000000003, 14.280000000000003, 14.790000000000003, 15.3, 15.810000000000002, 16.320000000000004, 16.830000000000002, 17.340000000000003, 17.85, 18.360000000000003, 18.870000000000005, 19.380000000000003, 19.890000000000004, 20.400000000000002, 20.910000000000004, 21.42, 21.93, 22.440000000000005, 22.950000000000003, 23.460000000000004, 23.970000000000002, 24.480000000000008, 24.990000000000006, 25.500000000000004, 26.010000000000005, 26.520000000000003, 27.030000000000005, 27.540000000000006, 28.050000000000004, 28.560000000000006, 29.070000000000004, 29.580000000000005, 30.090000000000003, 30.6, 31.110000000000007, 31.620000000000005, 32.13000000000001, 32.64000000000001, 33.150000000000006, 33.660000000000004, 34.17, 34.68000000000001, 35.190000000000005, 35.7, 36.21000000000001, 36.720000000000006, 37.230000000000004, 37.74000000000001, 38.25000000000001, 38.760000000000005, 39.27, 39.78000000000001, 40.290000000000006, 40.800000000000004, 41.31, 41.82000000000001, 42.330000000000005, 42.84, 43.35, 43.86, 44.37000000000001, 44.88000000000001, 45.39000000000001, 45.900000000000006, 46.410000000000004, 46.92000000000001, 47.43000000000001, 47.940000000000005, 48.45, 48.960000000000015, 49.47000000000001, 49.98000000000001, 50.49000000000001, 51.00000000000001, 51.51000000000001], [0.0, 0.52, 1.04, 1.5600000000000003, 2.08, 2.6, 3.1200000000000006, 3.6400000000000006, 4.16, 4.680000000000001, 5.2, 5.720000000000001, 6.240000000000001, 6.760000000000001, 7.280000000000001, 7.800000000000001, 8.32, 8.840000000000002, 9.360000000000001, 9.88, 10.4, 10.920000000000002, 11.440000000000001, 11.960000000000003, 12.480000000000002, 13.0, 13.520000000000001, 14.040000000000001, 14.560000000000002, 15.080000000000002, 15.600000000000001, 16.12, 16.64, 17.160000000000004, 17.680000000000003, 18.2, 18.720000000000002, 19.240000000000002, 19.76, 20.28, 20.8, 21.320000000000004, 21.840000000000003, 22.36, 22.880000000000003, 23.400000000000002, 23.920000000000005, 24.44, 24.960000000000004, 25.480000000000004, 26.0, 26.520000000000003, 27.040000000000003, 27.560000000000006, 28.080000000000002, 28.6, 29.120000000000005, 29.64, 30.160000000000004, 30.680000000000003, 31.200000000000003, 31.720000000000002, 32.24, 32.760000000000005, 33.28, 33.800000000000004, 34.32000000000001, 34.84, 35.36000000000001, 35.88, 36.4, 36.92, 37.440000000000005, 37.96000000000001, 38.480000000000004, 39.0, 39.52, 40.04, 40.56, 41.080000000000005, 41.6, 42.12, 42.64000000000001, 43.160000000000004, 43.68000000000001, 44.2, 44.72, 45.24000000000001, 45.760000000000005, 46.28, 46.800000000000004, 47.32, 47.84000000000001, 48.36000000000001, 48.88, 49.4, 49.92000000000001, 50.440000000000005, 50.96000000000001, 51.480000000000004, 52.0, 52.52000000000001], [0.0, 0.5300000000000001, 1.0600000000000003, 1.5900000000000005, 2.1200000000000006, 2.6500000000000004, 3.180000000000001, 3.710000000000001, 4.240000000000001, 4.7700000000000005, 5.300000000000001, 5.830000000000001, 6.360000000000002, 6.8900000000000015, 7.420000000000002, 7.950000000000001, 8.480000000000002, 9.010000000000002, 9.540000000000001, 10.070000000000002, 10.600000000000001, 11.130000000000003, 11.660000000000002, 12.190000000000003, 12.720000000000004, 13.250000000000002, 13.780000000000003, 14.310000000000002, 14.840000000000003, 15.370000000000005, 15.900000000000002, 16.430000000000003, 16.960000000000004, 17.490000000000002, 18.020000000000003, 18.550000000000004, 19.080000000000002, 19.610000000000003, 20.140000000000004, 20.670000000000005, 21.200000000000003, 21.730000000000004, 22.260000000000005, 22.790000000000003, 23.320000000000004, 23.85, 24.380000000000006, 24.910000000000004, 25.44000000000001, 25.970000000000006, 26.500000000000004, 27.030000000000005, 27.560000000000006, 28.090000000000007, 28.620000000000005, 29.150000000000006, 29.680000000000007, 30.210000000000004, 30.74000000000001, 31.270000000000007, 31.800000000000004, 32.330000000000005, 32.86000000000001, 33.39000000000001, 33.92000000000001, 34.45, 34.980000000000004, 35.510000000000005, 36.040000000000006, 36.57000000000001, 37.10000000000001, 37.63000000000001, 38.160000000000004, 38.69000000000001, 39.220000000000006, 39.75000000000001, 40.28000000000001, 40.81000000000001, 41.34000000000001, 41.870000000000005, 42.400000000000006, 42.93000000000001, 43.46000000000001, 43.99000000000001, 44.52000000000001, 45.050000000000004, 45.580000000000005, 46.110000000000014, 46.64000000000001, 47.17000000000001, 47.7, 48.230000000000004, 48.76000000000001, 49.29000000000001, 49.82000000000001, 50.35000000000001, 50.88000000000002, 51.41000000000001, 51.94000000000001, 52.470000000000006, 53.00000000000001, 53.530000000000015], [0.0, 0.54, 1.08, 1.6200000000000003, 2.16, 2.7, 3.2400000000000007, 3.7800000000000007, 4.32, 4.86, 5.4, 5.940000000000001, 6.480000000000001, 7.0200000000000005, 7.560000000000001, 8.100000000000001, 8.64, 9.180000000000001, 9.72, 10.260000000000002, 10.8, 11.340000000000002, 11.880000000000003, 12.420000000000002, 12.960000000000003, 13.5, 14.040000000000001, 14.580000000000002, 15.120000000000003, 15.660000000000004, 16.200000000000003, 16.740000000000002, 17.28, 17.820000000000004, 18.360000000000003, 18.900000000000002, 19.44, 19.980000000000004, 20.520000000000003, 21.060000000000002, 21.6, 22.140000000000004, 22.680000000000003, 23.22, 23.760000000000005, 24.3, 24.840000000000003, 25.380000000000003, 25.920000000000005, 26.460000000000004, 27.0, 27.540000000000006, 28.080000000000002, 28.620000000000005, 29.160000000000004, 29.700000000000003, 30.240000000000006, 30.780000000000005, 31.320000000000007, 31.860000000000003, 32.400000000000006, 32.940000000000005, 33.480000000000004, 34.02, 34.56, 35.1, 35.64000000000001, 36.18000000000001, 36.720000000000006, 37.260000000000005, 37.800000000000004, 38.34, 38.88, 39.42000000000001, 39.96000000000001, 40.5, 41.040000000000006, 41.580000000000005, 42.120000000000005, 42.660000000000004, 43.2, 43.74, 44.28000000000001, 44.82000000000001, 45.36000000000001, 45.900000000000006, 46.44, 46.98000000000001, 47.52000000000001, 48.06, 48.6, 49.14, 49.68000000000001, 50.220000000000006, 50.760000000000005, 51.300000000000004, 51.84000000000001, 52.38000000000001, 52.92000000000001, 53.46000000000001, 54.0, 54.54000000000001], [0.0, 0.55, 1.1, 1.6500000000000004, 2.2, 2.75, 3.3000000000000007, 3.8500000000000005, 4.4, 4.95, 5.5, 6.050000000000001, 6.600000000000001, 7.15, 7.700000000000001, 8.25, 8.8, 9.350000000000001, 9.9, 10.450000000000001, 11.0, 11.55, 12.100000000000001, 12.650000000000002, 13.200000000000003, 13.75, 14.3, 14.850000000000001, 15.400000000000002, 15.950000000000003, 16.5, 17.05, 17.6, 18.150000000000002, 18.700000000000003, 19.25, 19.8, 20.35, 20.900000000000002, 21.450000000000003, 22.0, 22.550000000000004, 23.1, 23.65, 24.200000000000003, 24.75, 25.300000000000004, 25.85, 26.400000000000006, 26.950000000000003, 27.5, 28.050000000000004, 28.6, 29.150000000000006, 29.700000000000003, 30.25, 30.800000000000004, 31.35, 31.900000000000006, 32.45, 33.0, 33.550000000000004, 34.1, 34.650000000000006, 35.2, 35.75, 36.300000000000004, 36.85, 37.400000000000006, 37.95, 38.5, 39.050000000000004, 39.6, 40.150000000000006, 40.7, 41.25, 41.800000000000004, 42.35, 42.900000000000006, 43.45, 44.0, 44.55, 45.10000000000001, 45.650000000000006, 46.2, 46.75, 47.3, 47.85000000000001, 48.400000000000006, 48.95, 49.5, 50.05, 50.60000000000001, 51.150000000000006, 51.7, 52.25, 52.80000000000001, 53.35000000000001, 53.900000000000006, 54.45, 55.0, 55.55000000000001], [0.0, 0.56, 1.12, 1.6800000000000004, 2.24, 2.8000000000000003, 3.3600000000000008, 3.920000000000001, 4.48, 5.040000000000001, 5.6000000000000005, 6.160000000000001, 6.7200000000000015, 7.280000000000001, 7.840000000000002, 8.4, 8.96, 9.520000000000001, 10.080000000000002, 10.640000000000002, 11.200000000000001, 11.760000000000002, 12.320000000000002, 12.880000000000003, 13.440000000000003, 14.000000000000002, 14.560000000000002, 15.120000000000003, 15.680000000000003, 16.240000000000002, 16.8, 17.360000000000003, 17.92, 18.480000000000004, 19.040000000000003, 19.6, 20.160000000000004, 20.720000000000002, 21.280000000000005, 21.840000000000003, 22.400000000000002, 22.960000000000004, 23.520000000000003, 24.080000000000002, 24.640000000000004, 25.200000000000003, 25.760000000000005, 26.320000000000004, 26.880000000000006, 27.440000000000005, 28.000000000000004, 28.560000000000006, 29.120000000000005, 29.680000000000007, 30.240000000000006, 30.800000000000004, 31.360000000000007, 31.920000000000005, 32.480000000000004, 33.040000000000006, 33.6, 34.160000000000004, 34.720000000000006, 35.28000000000001, 35.84, 36.400000000000006, 36.96000000000001, 37.52, 38.080000000000005, 38.64000000000001, 39.2, 39.760000000000005, 40.32000000000001, 40.88000000000001, 41.440000000000005, 42.00000000000001, 42.56000000000001, 43.120000000000005, 43.68000000000001, 44.24000000000001, 44.800000000000004, 45.36, 45.92000000000001, 46.48000000000001, 47.040000000000006, 47.6, 48.160000000000004, 48.72000000000001, 49.28000000000001, 49.84, 50.400000000000006, 50.96, 51.52000000000001, 52.080000000000005, 52.64000000000001, 53.2, 53.76000000000001, 54.320000000000014, 54.88000000000001, 55.440000000000005, 56.00000000000001, 56.56000000000002], [0.0, 0.5700000000000001, 1.1400000000000001, 1.7100000000000004, 2.2800000000000002, 2.85, 3.420000000000001, 3.9900000000000007, 4.5600000000000005, 5.13, 5.7, 6.2700000000000005, 6.840000000000002, 7.41, 7.980000000000001, 8.55, 9.120000000000001, 9.690000000000001, 10.26, 10.830000000000002, 11.4, 11.97, 12.540000000000001, 13.110000000000001, 13.680000000000003, 14.25, 14.82, 15.390000000000002, 15.960000000000003, 16.53, 17.1, 17.67, 18.240000000000002, 18.810000000000002, 19.380000000000003, 19.95, 20.52, 21.090000000000003, 21.660000000000004, 22.230000000000004, 22.8, 23.370000000000005, 23.94, 24.509999999999998, 25.080000000000002, 25.650000000000002, 26.220000000000002, 26.790000000000003, 27.360000000000007, 27.930000000000003, 28.5, 29.070000000000004, 29.64, 30.210000000000004, 30.780000000000005, 31.35, 31.920000000000005, 32.49, 33.06, 33.63, 34.2, 34.77, 35.34, 35.910000000000004, 36.480000000000004, 37.050000000000004, 37.620000000000005, 38.190000000000005, 38.760000000000005, 39.330000000000005, 39.9, 40.470000000000006, 41.04, 41.61000000000001, 42.18000000000001, 42.75, 43.32000000000001, 43.89, 44.46000000000001, 45.03, 45.6, 46.17, 46.74000000000001, 47.31, 47.88, 48.45, 49.019999999999996, 49.59000000000001, 50.160000000000004, 50.730000000000004, 51.300000000000004, 51.87, 52.440000000000005, 53.010000000000005, 53.580000000000005, 54.15, 54.72000000000001, 55.290000000000006, 55.86000000000001, 56.43000000000001, 57.0, 57.57000000000001], [0.0, 0.5800000000000001, 1.1600000000000001, 1.7400000000000004, 2.3200000000000003, 2.9000000000000004, 3.480000000000001, 4.0600000000000005, 4.640000000000001, 5.220000000000001, 5.800000000000001, 6.380000000000002, 6.960000000000002, 7.540000000000001, 8.120000000000001, 8.700000000000001, 9.280000000000001, 9.860000000000003, 10.440000000000001, 11.020000000000001, 11.600000000000001, 12.180000000000001, 12.760000000000003, 13.340000000000003, 13.920000000000003, 14.500000000000002, 15.080000000000002, 15.660000000000004, 16.240000000000002, 16.820000000000004, 17.400000000000002, 17.980000000000004, 18.560000000000002, 19.140000000000004, 19.720000000000006, 20.300000000000004, 20.880000000000003, 21.460000000000004, 22.040000000000003, 22.620000000000005, 23.200000000000003, 23.780000000000005, 24.360000000000003, 24.94, 25.520000000000007, 26.1, 26.680000000000007, 27.260000000000005, 27.840000000000007, 28.420000000000005, 29.000000000000004, 29.580000000000005, 30.160000000000004, 30.74000000000001, 31.320000000000007, 31.900000000000006, 32.480000000000004, 33.06, 33.64000000000001, 34.220000000000006, 34.800000000000004, 35.38000000000001, 35.96000000000001, 36.540000000000006, 37.120000000000005, 37.7, 38.28000000000001, 38.86000000000001, 39.44000000000001, 40.02000000000001, 40.60000000000001, 41.18000000000001, 41.760000000000005, 42.34000000000001, 42.92000000000001, 43.50000000000001, 44.080000000000005, 44.660000000000004, 45.24000000000001, 45.82000000000001, 46.400000000000006, 46.980000000000004, 47.56000000000001, 48.14000000000001, 48.720000000000006, 49.300000000000004, 49.88, 50.460000000000015, 51.04000000000001, 51.62000000000001, 52.2, 52.78, 53.360000000000014, 53.94000000000001, 54.52000000000001, 55.10000000000001, 55.680000000000014, 56.26000000000001, 56.84000000000001, 57.42000000000001, 58.00000000000001, 58.58000000000001], [0.0, 0.5900000000000001, 1.1800000000000002, 1.7700000000000005, 2.3600000000000003, 2.95, 3.540000000000001, 4.130000000000001, 4.720000000000001, 5.3100000000000005, 5.9, 6.490000000000001, 7.080000000000002, 7.670000000000001, 8.260000000000002, 8.850000000000001, 9.440000000000001, 10.030000000000001, 10.620000000000001, 11.21, 11.8, 12.39, 12.980000000000002, 13.570000000000002, 14.160000000000004, 14.75, 15.340000000000002, 15.930000000000001, 16.520000000000003, 17.110000000000003, 17.700000000000003, 18.290000000000003, 18.880000000000003, 19.470000000000002, 20.060000000000002, 20.650000000000002, 21.240000000000002, 21.830000000000002, 22.42, 23.010000000000005, 23.6, 24.190000000000005, 24.78, 25.37, 25.960000000000004, 26.55, 27.140000000000004, 27.730000000000004, 28.320000000000007, 28.910000000000004, 29.5, 30.090000000000003, 30.680000000000003, 31.270000000000007, 31.860000000000003, 32.45, 33.040000000000006, 33.63, 34.220000000000006, 34.81, 35.400000000000006, 35.99, 36.580000000000005, 37.17000000000001, 37.760000000000005, 38.35, 38.940000000000005, 39.53, 40.120000000000005, 40.71000000000001, 41.300000000000004, 41.89000000000001, 42.480000000000004, 43.07000000000001, 43.660000000000004, 44.25, 44.84, 45.43000000000001, 46.02000000000001, 46.61000000000001, 47.2, 47.79, 48.38000000000001, 48.970000000000006, 49.56, 50.150000000000006, 50.74, 51.33000000000001, 51.92000000000001, 52.510000000000005, 53.1, 53.69, 54.28000000000001, 54.870000000000005, 55.46000000000001, 56.050000000000004, 56.640000000000015, 57.23000000000001, 57.82000000000001, 58.410000000000004, 59.0, 59.59000000000001], [0.0, 0.6000000000000001, 1.2000000000000002, 1.8000000000000003, 2.4000000000000004, 3.0, 3.6000000000000005, 4.2, 4.800000000000001, 5.4, 6.0, 6.6000000000000005, 7.200000000000001, 7.800000000000001, 8.4, 9.0, 9.600000000000001, 10.200000000000001, 10.8, 11.4, 12.0, 12.600000000000001, 13.200000000000001, 13.8, 14.400000000000002, 15.0, 15.600000000000001, 16.200000000000003, 16.8, 17.400000000000002, 18.0, 18.6, 19.200000000000003, 19.8, 20.400000000000002, 21.0, 21.6, 22.200000000000003, 22.8, 23.400000000000002, 24.0, 24.6, 25.200000000000003, 25.799999999999997, 26.400000000000002, 27.0, 27.6, 28.200000000000003, 28.800000000000004, 29.400000000000002, 30.0, 30.6, 31.200000000000003, 31.800000000000004, 32.400000000000006, 33.0, 33.6, 34.2, 34.800000000000004, 35.400000000000006, 36.0, 36.6, 37.2, 37.800000000000004, 38.400000000000006, 39.0, 39.6, 40.2, 40.800000000000004, 41.400000000000006, 42.0, 42.6, 43.2, 43.800000000000004, 44.400000000000006, 45.0, 45.6, 46.2, 46.800000000000004, 47.400000000000006, 48.0, 48.599999999999994, 49.2, 49.800000000000004, 50.400000000000006, 51.0, 51.599999999999994, 52.2, 52.800000000000004, 53.400000000000006, 54.0, 54.599999999999994, 55.2, 55.800000000000004, 56.400000000000006, 57.0, 57.60000000000001, 58.2, 58.800000000000004, 59.400000000000006, 60.0, 60.60000000000001], [0.0, 0.6100000000000001, 1.2200000000000002, 1.8300000000000005, 2.4400000000000004, 3.0500000000000003, 3.660000000000001, 4.2700000000000005, 4.880000000000001, 5.49, 6.1000000000000005, 6.710000000000001, 7.320000000000002, 7.930000000000001, 8.540000000000001, 9.15, 9.760000000000002, 10.370000000000003, 10.98, 11.590000000000002, 12.200000000000001, 12.810000000000002, 13.420000000000002, 14.030000000000003, 14.640000000000004, 15.250000000000002, 15.860000000000001, 16.470000000000002, 17.080000000000002, 17.690000000000005, 18.3, 18.910000000000004, 19.520000000000003, 20.130000000000003, 20.740000000000006, 21.35, 21.96, 22.570000000000004, 23.180000000000003, 23.790000000000003, 24.400000000000002, 25.010000000000005, 25.620000000000005, 26.23, 26.840000000000003, 27.450000000000003, 28.060000000000006, 28.670000000000005, 29.28000000000001, 29.890000000000004, 30.500000000000004, 31.110000000000007, 31.720000000000002, 32.330000000000005, 32.940000000000005, 33.550000000000004, 34.160000000000004, 34.77, 35.38000000000001, 35.99, 36.6, 37.21000000000001, 37.82000000000001, 38.43000000000001, 39.040000000000006, 39.650000000000006, 40.260000000000005, 40.870000000000005, 41.48000000000001, 42.09, 42.7, 43.31000000000001, 43.92, 44.53000000000001, 45.14000000000001, 45.75000000000001, 46.36000000000001, 46.970000000000006, 47.580000000000005, 48.190000000000005, 48.800000000000004, 49.410000000000004, 50.02000000000001, 50.63000000000001, 51.24000000000001, 51.85, 52.46, 53.070000000000014, 53.68000000000001, 54.290000000000006, 54.900000000000006, 55.510000000000005, 56.12000000000001, 56.73000000000001, 57.34000000000001, 57.95, 58.56000000000002, 59.17000000000001, 59.78000000000001, 60.39000000000001, 61.00000000000001, 61.610000000000014], [0.0, 0.6200000000000001, 1.2400000000000002, 1.8600000000000003, 2.4800000000000004, 3.1, 3.7200000000000006, 4.340000000000001, 4.960000000000001, 5.58, 6.2, 6.820000000000001, 7.440000000000001, 8.06, 8.680000000000001, 9.3, 9.920000000000002, 10.540000000000001, 11.16, 11.780000000000001, 12.4, 13.020000000000001, 13.640000000000002, 14.260000000000002, 14.880000000000003, 15.5, 16.12, 16.740000000000002, 17.360000000000003, 17.980000000000004, 18.6, 19.220000000000002, 19.840000000000003, 20.46, 21.080000000000002, 21.7, 22.32, 22.94, 23.560000000000002, 24.180000000000003, 24.8, 25.420000000000005, 26.040000000000003, 26.66, 27.280000000000005, 27.900000000000002, 28.520000000000003, 29.14, 29.760000000000005, 30.380000000000003, 31.0, 31.620000000000005, 32.24, 32.86000000000001, 33.480000000000004, 34.1, 34.720000000000006, 35.34, 35.96000000000001, 36.580000000000005, 37.2, 37.82000000000001, 38.440000000000005, 39.06, 39.68000000000001, 40.300000000000004, 40.92, 41.54, 42.160000000000004, 42.78, 43.4, 44.02, 44.64, 45.260000000000005, 45.88, 46.5, 47.120000000000005, 47.74, 48.36000000000001, 48.980000000000004, 49.6, 50.22, 50.84000000000001, 51.46000000000001, 52.080000000000005, 52.7, 53.32, 53.940000000000005, 54.56000000000001, 55.18000000000001, 55.800000000000004, 56.42, 57.040000000000006, 57.660000000000004, 58.28, 58.9, 59.52000000000001, 60.14000000000001, 60.760000000000005, 61.38, 62.0, 62.62000000000001], [0.0, 0.6300000000000001, 1.2600000000000002, 1.8900000000000006, 2.5200000000000005, 3.1500000000000004, 3.780000000000001, 4.410000000000001, 5.040000000000001, 5.670000000000001, 6.300000000000001, 6.9300000000000015, 7.560000000000002, 8.190000000000001, 8.820000000000002, 9.450000000000001, 10.080000000000002, 10.710000000000003, 11.340000000000002, 11.970000000000002, 12.600000000000001, 13.230000000000002, 13.860000000000003, 14.490000000000004, 15.120000000000005, 15.750000000000002, 16.380000000000003, 17.01, 17.640000000000004, 18.270000000000003, 18.900000000000002, 19.53, 20.160000000000004, 20.790000000000003, 21.420000000000005, 22.050000000000004, 22.680000000000003, 23.310000000000002, 23.940000000000005, 24.570000000000004, 25.200000000000003, 25.830000000000005, 26.460000000000004, 27.090000000000003, 27.720000000000006, 28.35, 28.980000000000008, 29.610000000000003, 30.24000000000001, 30.870000000000005, 31.500000000000004, 32.13000000000001, 32.760000000000005, 33.39000000000001, 34.02, 34.650000000000006, 35.28000000000001, 35.910000000000004, 36.540000000000006, 37.17000000000001, 37.800000000000004, 38.43000000000001, 39.06, 39.69000000000001, 40.32000000000001, 40.95, 41.580000000000005, 42.21000000000001, 42.84000000000001, 43.470000000000006, 44.10000000000001, 44.73000000000001, 45.36000000000001, 45.99000000000001, 46.620000000000005, 47.25000000000001, 47.88000000000001, 48.510000000000005, 49.14000000000001, 49.77000000000001, 50.400000000000006, 51.03, 51.66000000000001, 52.29000000000001, 52.92000000000001, 53.550000000000004, 54.18000000000001, 54.81000000000001, 55.44000000000001, 56.07000000000001, 56.7, 57.330000000000005, 57.960000000000015, 58.59000000000001, 59.220000000000006, 59.85000000000001, 60.48000000000002, 61.110000000000014, 61.74000000000001, 62.37000000000001, 63.00000000000001, 63.63000000000002], [0.0, 0.6400000000000001, 1.2800000000000002, 1.9200000000000004, 2.5600000000000005, 3.2, 3.8400000000000007, 4.48, 5.120000000000001, 5.760000000000001, 6.4, 7.040000000000001, 7.6800000000000015, 8.32, 8.96, 9.600000000000001, 10.240000000000002, 10.880000000000003, 11.520000000000001, 12.160000000000002, 12.8, 13.440000000000001, 14.080000000000002, 14.720000000000002, 15.360000000000003, 16.0, 16.64, 17.28, 17.92, 18.560000000000002, 19.200000000000003, 19.840000000000003, 20.480000000000004, 21.120000000000005, 21.760000000000005, 22.400000000000002, 23.040000000000003, 23.680000000000003, 24.320000000000004, 24.960000000000004, 25.6, 26.240000000000006, 26.880000000000003, 27.52, 28.160000000000004, 28.8, 29.440000000000005, 30.080000000000002, 30.720000000000006, 31.360000000000003, 32.0, 32.64000000000001, 33.28, 33.92000000000001, 34.56, 35.2, 35.84, 36.480000000000004, 37.120000000000005, 37.760000000000005, 38.400000000000006, 39.040000000000006, 39.68000000000001, 40.32000000000001, 40.96000000000001, 41.6, 42.24000000000001, 42.88, 43.52000000000001, 44.160000000000004, 44.800000000000004, 45.440000000000005, 46.080000000000005, 46.720000000000006, 47.36000000000001, 48.0, 48.64000000000001, 49.28, 49.92000000000001, 50.56, 51.2, 51.84, 52.48000000000001, 53.120000000000005, 53.760000000000005, 54.400000000000006, 55.04, 55.68000000000001, 56.32000000000001, 56.96000000000001, 57.6, 58.24, 58.88000000000001, 59.52000000000001, 60.160000000000004, 60.800000000000004, 61.44000000000001, 62.08000000000001, 62.720000000000006, 63.36000000000001, 64.0, 64.64000000000001], [0.0, 0.65, 1.3, 1.9500000000000002, 2.6, 3.25, 3.9000000000000004, 4.550000000000001, 5.2, 5.8500000000000005, 6.5, 7.15, 7.800000000000001, 8.450000000000001, 9.100000000000001, 9.75, 10.4, 11.05, 11.700000000000001, 12.350000000000001, 13.0, 13.65, 14.3, 14.950000000000001, 15.600000000000001, 16.25, 16.900000000000002, 17.55, 18.200000000000003, 18.85, 19.5, 20.150000000000002, 20.8, 21.450000000000003, 22.1, 22.75, 23.400000000000002, 24.05, 24.700000000000003, 25.35, 26.0, 26.650000000000002, 27.3, 27.95, 28.6, 29.25, 29.900000000000002, 30.55, 31.200000000000003, 31.85, 32.5, 33.150000000000006, 33.800000000000004, 34.45, 35.1, 35.75, 36.400000000000006, 37.050000000000004, 37.7, 38.35, 39.0, 39.650000000000006, 40.300000000000004, 40.95, 41.6, 42.25, 42.900000000000006, 43.550000000000004, 44.2, 44.85, 45.5, 46.150000000000006, 46.800000000000004, 47.45, 48.1, 48.75, 49.400000000000006, 50.050000000000004, 50.7, 51.35, 52.0, 52.65, 53.300000000000004, 53.95, 54.6, 55.25, 55.9, 56.550000000000004, 57.2, 57.85, 58.5, 59.15, 59.800000000000004, 60.45, 61.1, 61.75, 62.400000000000006, 63.050000000000004, 63.7, 64.35000000000001, 65.0, 65.65], [0.0, 0.6600000000000001, 1.3200000000000003, 1.9800000000000004, 2.6400000000000006, 3.3000000000000003, 3.960000000000001, 4.620000000000001, 5.280000000000001, 5.94, 6.6000000000000005, 7.260000000000002, 7.920000000000002, 8.580000000000002, 9.240000000000002, 9.9, 10.560000000000002, 11.220000000000002, 11.88, 12.540000000000003, 13.200000000000001, 13.860000000000001, 14.520000000000003, 15.180000000000003, 15.840000000000003, 16.5, 17.160000000000004, 17.820000000000004, 18.480000000000004, 19.140000000000004, 19.8, 20.46, 21.120000000000005, 21.780000000000005, 22.440000000000005, 23.1, 23.76, 24.42, 25.080000000000005, 25.740000000000006, 26.400000000000002, 27.060000000000006, 27.720000000000002, 28.380000000000003, 29.040000000000006, 29.700000000000003, 30.360000000000007, 31.020000000000003, 31.680000000000007, 32.34, 33.0, 33.660000000000004, 34.32000000000001, 34.980000000000004, 35.64000000000001, 36.300000000000004, 36.96000000000001, 37.620000000000005, 38.28000000000001, 38.940000000000005, 39.6, 40.260000000000005, 40.92, 41.580000000000005, 42.24000000000001, 42.900000000000006, 43.56000000000001, 44.220000000000006, 44.88000000000001, 45.540000000000006, 46.2, 46.86000000000001, 47.52, 48.18000000000001, 48.84, 49.50000000000001, 50.16000000000001, 50.82000000000001, 51.48000000000001, 52.14000000000001, 52.800000000000004, 53.46, 54.12000000000001, 54.78000000000001, 55.440000000000005, 56.1, 56.760000000000005, 57.42000000000001, 58.08000000000001, 58.74000000000001, 59.400000000000006, 60.06, 60.72000000000001, 61.38000000000001, 62.040000000000006, 62.7, 63.360000000000014, 64.02000000000001, 64.68, 65.34, 66.0, 66.66000000000001], [0.0, 0.67, 1.34, 2.0100000000000002, 2.68, 3.35, 4.0200000000000005, 4.69, 5.36, 6.03, 6.7, 7.370000000000001, 8.040000000000001, 8.71, 9.38, 10.05, 10.72, 11.390000000000002, 12.06, 12.73, 13.4, 14.07, 14.740000000000002, 15.410000000000002, 16.080000000000002, 16.75, 17.42, 18.090000000000003, 18.76, 19.430000000000003, 20.1, 20.77, 21.44, 22.110000000000003, 22.780000000000005, 23.45, 24.12, 24.790000000000003, 25.46, 26.130000000000003, 26.8, 27.470000000000006, 28.14, 28.81, 29.480000000000004, 30.150000000000002, 30.820000000000004, 31.490000000000002, 32.160000000000004, 32.830000000000005, 33.5, 34.17, 34.84, 35.510000000000005, 36.18000000000001, 36.85, 37.52, 38.190000000000005, 38.86000000000001, 39.53, 40.2, 40.870000000000005, 41.54, 42.21000000000001, 42.88, 43.550000000000004, 44.220000000000006, 44.89, 45.56000000000001, 46.230000000000004, 46.9, 47.57000000000001, 48.24, 48.910000000000004, 49.580000000000005, 50.25, 50.92, 51.59, 52.260000000000005, 52.93000000000001, 53.6, 54.269999999999996, 54.94000000000001, 55.61000000000001, 56.28, 56.95, 57.62, 58.290000000000006, 58.96000000000001, 59.63, 60.300000000000004, 60.97, 61.64000000000001, 62.31000000000001, 62.980000000000004, 63.65, 64.32000000000001, 64.99000000000001, 65.66000000000001, 66.33, 67.0, 67.67000000000002], [0.0, 0.6800000000000002, 1.3600000000000003, 2.0400000000000005, 2.7200000000000006, 3.4000000000000004, 4.080000000000001, 4.760000000000001, 5.440000000000001, 6.120000000000001, 6.800000000000001, 7.480000000000001, 8.160000000000002, 8.840000000000002, 9.520000000000001, 10.200000000000001, 10.880000000000003, 11.560000000000002, 12.240000000000002, 12.920000000000002, 13.600000000000001, 14.280000000000003, 14.960000000000003, 15.640000000000004, 16.320000000000004, 17.0, 17.680000000000003, 18.360000000000003, 19.040000000000003, 19.720000000000006, 20.400000000000002, 21.080000000000002, 21.760000000000005, 22.440000000000005, 23.120000000000005, 23.800000000000004, 24.480000000000004, 25.160000000000004, 25.840000000000003, 26.520000000000007, 27.200000000000003, 27.880000000000006, 28.560000000000006, 29.240000000000002, 29.920000000000005, 30.6, 31.28000000000001, 31.960000000000004, 32.64000000000001, 33.32000000000001, 34.0, 34.68000000000001, 35.36000000000001, 36.040000000000006, 36.720000000000006, 37.400000000000006, 38.080000000000005, 38.760000000000005, 39.44000000000001, 40.120000000000005, 40.800000000000004, 41.48000000000001, 42.160000000000004, 42.84000000000001, 43.52000000000001, 44.2, 44.88000000000001, 45.56000000000001, 46.24000000000001, 46.92000000000001, 47.60000000000001, 48.28000000000001, 48.96000000000001, 49.64000000000001, 50.32000000000001, 51.00000000000001, 51.68000000000001, 52.36000000000001, 53.04000000000001, 53.720000000000006, 54.400000000000006, 55.080000000000005, 55.76000000000001, 56.44000000000001, 57.12000000000001, 57.800000000000004, 58.480000000000004, 59.16000000000001, 59.84000000000001, 60.52000000000001, 61.2, 61.88, 62.56000000000002, 63.24000000000001, 63.92000000000001, 64.60000000000001, 65.28000000000002, 65.96000000000001, 66.64000000000001, 67.32000000000001, 68.0, 68.68000000000002], [0.0, 0.6900000000000001, 1.3800000000000001, 2.0700000000000003, 2.7600000000000002, 3.45, 4.140000000000001, 4.830000000000001, 5.5200000000000005, 6.210000000000001, 6.9, 7.590000000000001, 8.280000000000001, 8.97, 9.660000000000002, 10.350000000000001, 11.040000000000001, 11.730000000000002, 12.420000000000002, 13.110000000000001, 13.8, 14.490000000000002, 15.180000000000001, 15.870000000000003, 16.560000000000002, 17.25, 17.94, 18.630000000000003, 19.320000000000004, 20.010000000000005, 20.700000000000003, 21.39, 22.080000000000002, 22.770000000000003, 23.460000000000004, 24.150000000000002, 24.840000000000003, 25.53, 26.220000000000002, 26.910000000000004, 27.6, 28.290000000000006, 28.980000000000004, 29.67, 30.360000000000003, 31.05, 31.740000000000006, 32.43, 33.120000000000005, 33.81, 34.5, 35.190000000000005, 35.88, 36.57000000000001, 37.260000000000005, 37.95, 38.64000000000001, 39.330000000000005, 40.02000000000001, 40.71000000000001, 41.400000000000006, 42.09, 42.78, 43.470000000000006, 44.160000000000004, 44.85, 45.540000000000006, 46.230000000000004, 46.92000000000001, 47.61000000000001, 48.300000000000004, 48.99000000000001, 49.68000000000001, 50.370000000000005, 51.06, 51.75, 52.440000000000005, 53.13, 53.82000000000001, 54.510000000000005, 55.2, 55.89, 56.58000000000001, 57.27000000000001, 57.96000000000001, 58.650000000000006, 59.34, 60.03000000000001, 60.720000000000006, 61.410000000000004, 62.1, 62.79, 63.48000000000001, 64.17, 64.86, 65.55, 66.24000000000001, 66.93, 67.62, 68.31, 69.0, 69.69000000000001], [0.0, 0.7000000000000001, 1.4000000000000001, 2.1000000000000005, 2.8000000000000003, 3.5, 4.200000000000001, 4.9, 5.6000000000000005, 6.3, 7.0, 7.700000000000001, 8.400000000000002, 9.1, 9.8, 10.5, 11.200000000000001, 11.900000000000002, 12.6, 13.3, 14.0, 14.700000000000001, 15.400000000000002, 16.1, 16.800000000000004, 17.5, 18.2, 18.900000000000002, 19.6, 20.300000000000004, 21.0, 21.7, 22.400000000000002, 23.1, 23.800000000000004, 24.5, 25.2, 25.900000000000002, 26.6, 27.300000000000004, 28.0, 28.700000000000003, 29.400000000000002, 30.099999999999998, 30.800000000000004, 31.5, 32.2, 32.9, 33.60000000000001, 34.300000000000004, 35.0, 35.7, 36.4, 37.10000000000001, 37.800000000000004, 38.5, 39.2, 39.9, 40.60000000000001, 41.300000000000004, 42.0, 42.7, 43.4, 44.10000000000001, 44.800000000000004, 45.5, 46.2, 46.9, 47.60000000000001, 48.300000000000004, 49.0, 49.7, 50.4, 51.10000000000001, 51.800000000000004, 52.5, 53.2, 53.9, 54.60000000000001, 55.300000000000004, 56.0, 56.699999999999996, 57.400000000000006, 58.10000000000001, 58.800000000000004, 59.5, 60.199999999999996, 60.900000000000006, 61.60000000000001, 62.300000000000004, 63.0, 63.699999999999996, 64.4, 65.10000000000001, 65.8, 66.5, 67.20000000000002, 67.9, 68.60000000000001, 69.3, 70.0, 70.70000000000002], [0.0, 0.7100000000000001, 1.4200000000000002, 2.1300000000000003, 2.8400000000000003, 3.5500000000000003, 4.260000000000001, 4.970000000000001, 5.680000000000001, 6.390000000000001, 7.1000000000000005, 7.810000000000001, 8.520000000000001, 9.23, 9.940000000000001, 10.65, 11.360000000000001, 12.070000000000002, 12.780000000000001, 13.490000000000002, 14.200000000000001, 14.910000000000002, 15.620000000000003, 16.330000000000002, 17.040000000000003, 17.75, 18.46, 19.17, 19.880000000000003, 20.590000000000003, 21.3, 22.01, 22.720000000000002, 23.430000000000003, 24.140000000000004, 24.85, 25.560000000000002, 26.270000000000003, 26.980000000000004, 27.690000000000005, 28.400000000000002, 29.110000000000007, 29.820000000000004, 30.53, 31.240000000000006, 31.950000000000003, 32.660000000000004, 33.370000000000005, 34.080000000000005, 34.790000000000006, 35.5, 36.21000000000001, 36.92, 37.63000000000001, 38.34, 39.050000000000004, 39.760000000000005, 40.470000000000006, 41.18000000000001, 41.89000000000001, 42.6, 43.31000000000001, 44.02, 44.73000000000001, 45.440000000000005, 46.150000000000006, 46.86000000000001, 47.57000000000001, 48.28000000000001, 48.99000000000001, 49.7, 50.41000000000001, 51.120000000000005, 51.830000000000005, 52.540000000000006, 53.25000000000001, 53.96000000000001, 54.67000000000001, 55.38000000000001, 56.09, 56.800000000000004, 57.510000000000005, 58.22000000000001, 58.93000000000001, 59.64000000000001, 60.35, 61.06, 61.77000000000001, 62.48000000000001, 63.190000000000005, 63.900000000000006, 64.61, 65.32000000000001, 66.03000000000002, 66.74000000000001, 67.45, 68.16000000000001, 68.87000000000002, 69.58000000000001, 70.29, 71.0, 71.71000000000002], [0.0, 0.7200000000000001, 1.4400000000000002, 2.1600000000000006, 2.8800000000000003, 3.6, 4.320000000000001, 5.040000000000001, 5.760000000000001, 6.48, 7.2, 7.920000000000001, 8.640000000000002, 9.360000000000001, 10.080000000000002, 10.8, 11.520000000000001, 12.240000000000002, 12.96, 13.680000000000001, 14.4, 15.120000000000001, 15.840000000000002, 16.560000000000002, 17.280000000000005, 18.0, 18.720000000000002, 19.44, 20.160000000000004, 20.880000000000003, 21.6, 22.32, 23.040000000000003, 23.76, 24.480000000000004, 25.2, 25.92, 26.64, 27.360000000000003, 28.080000000000002, 28.8, 29.520000000000003, 30.240000000000002, 30.96, 31.680000000000003, 32.4, 33.120000000000005, 33.84, 34.56000000000001, 35.28, 36.0, 36.720000000000006, 37.440000000000005, 38.160000000000004, 38.88, 39.6, 40.32000000000001, 41.04, 41.760000000000005, 42.480000000000004, 43.2, 43.92, 44.64, 45.36000000000001, 46.080000000000005, 46.800000000000004, 47.52, 48.24, 48.96000000000001, 49.68000000000001, 50.4, 51.120000000000005, 51.84, 52.56000000000001, 53.28, 54.0, 54.720000000000006, 55.440000000000005, 56.160000000000004, 56.88, 57.6, 58.32, 59.040000000000006, 59.760000000000005, 60.480000000000004, 61.2, 61.92, 62.64000000000001, 63.36000000000001, 64.08, 64.8, 65.52, 66.24000000000001, 66.96000000000001, 67.68, 68.4, 69.12000000000002, 69.84, 70.56, 71.28, 72.0, 72.72000000000001], [0.0, 0.7300000000000001, 1.4600000000000002, 2.1900000000000004, 2.9200000000000004, 3.6500000000000004, 4.380000000000001, 5.110000000000001, 5.840000000000001, 6.570000000000001, 7.300000000000001, 8.030000000000001, 8.760000000000002, 9.490000000000002, 10.220000000000002, 10.950000000000001, 11.680000000000001, 12.410000000000002, 13.140000000000002, 13.870000000000003, 14.600000000000001, 15.330000000000002, 16.060000000000002, 16.790000000000003, 17.520000000000003, 18.25, 18.980000000000004, 19.710000000000004, 20.440000000000005, 21.170000000000005, 21.900000000000002, 22.630000000000003, 23.360000000000003, 24.090000000000003, 24.820000000000004, 25.550000000000004, 26.280000000000005, 27.010000000000005, 27.740000000000006, 28.470000000000006, 29.200000000000003, 29.930000000000007, 30.660000000000004, 31.39, 32.120000000000005, 32.85, 33.580000000000005, 34.31, 35.040000000000006, 35.77, 36.5, 37.230000000000004, 37.96000000000001, 38.69000000000001, 39.42000000000001, 40.150000000000006, 40.88000000000001, 41.61000000000001, 42.34000000000001, 43.07000000000001, 43.800000000000004, 44.53000000000001, 45.260000000000005, 45.99000000000001, 46.720000000000006, 47.45, 48.18000000000001, 48.910000000000004, 49.64000000000001, 50.370000000000005, 51.10000000000001, 51.830000000000005, 52.56000000000001, 53.29000000000001, 54.02000000000001, 54.75000000000001, 55.48000000000001, 56.21000000000001, 56.94000000000001, 57.67000000000001, 58.400000000000006, 59.13, 59.860000000000014, 60.59000000000001, 61.32000000000001, 62.050000000000004, 62.78, 63.51000000000001, 64.24000000000001, 64.97000000000001, 65.7, 66.43, 67.16000000000001, 67.89000000000001, 68.62, 69.35000000000001, 70.08000000000001, 70.81000000000002, 71.54, 72.27000000000001, 73.0, 73.73000000000002], [0.0, 0.7400000000000001, 1.4800000000000002, 2.2200000000000006, 2.9600000000000004, 3.7, 4.440000000000001, 5.180000000000001, 5.920000000000001, 6.66, 7.4, 8.14, 8.880000000000003, 9.620000000000001, 10.360000000000001, 11.100000000000001, 11.840000000000002, 12.580000000000002, 13.32, 14.060000000000002, 14.8, 15.540000000000001, 16.28, 17.020000000000003, 17.760000000000005, 18.5, 19.240000000000002, 19.980000000000004, 20.720000000000002, 21.460000000000004, 22.200000000000003, 22.94, 23.680000000000003, 24.42, 25.160000000000004, 25.900000000000002, 26.64, 27.380000000000003, 28.120000000000005, 28.860000000000003, 29.6, 30.340000000000007, 31.080000000000002, 31.82, 32.56, 33.300000000000004, 34.040000000000006, 34.78, 35.52000000000001, 36.260000000000005, 37.0, 37.74000000000001, 38.480000000000004, 39.220000000000006, 39.96000000000001, 40.7, 41.440000000000005, 42.18000000000001, 42.92000000000001, 43.660000000000004, 44.400000000000006, 45.14000000000001, 45.88, 46.620000000000005, 47.36000000000001, 48.1, 48.84, 49.580000000000005, 50.32000000000001, 51.06, 51.800000000000004, 52.540000000000006, 53.28, 54.02000000000001, 54.760000000000005, 55.5, 56.24000000000001, 56.980000000000004, 57.720000000000006, 58.46000000000001, 59.2, 59.94, 60.680000000000014, 61.42000000000001, 62.160000000000004, 62.900000000000006, 63.64, 64.38000000000001, 65.12, 65.86, 66.60000000000001, 67.34, 68.08000000000001, 68.82000000000001, 69.56, 70.3, 71.04000000000002, 71.78000000000002, 72.52000000000001, 73.26, 74.0, 74.74000000000001], [0.0, 0.75, 1.5, 2.2500000000000004, 3.0, 3.75, 4.500000000000001, 5.250000000000001, 6.0, 6.75, 7.5, 8.25, 9.000000000000002, 9.75, 10.500000000000002, 11.25, 12.0, 12.750000000000002, 13.5, 14.250000000000002, 15.0, 15.75, 16.5, 17.250000000000004, 18.000000000000004, 18.75, 19.5, 20.25, 21.000000000000004, 21.750000000000004, 22.5, 23.25, 24.0, 24.750000000000004, 25.500000000000004, 26.25, 27.0, 27.75, 28.500000000000004, 29.250000000000004, 30.0, 30.750000000000004, 31.5, 32.25, 33.0, 33.75, 34.50000000000001, 35.25, 36.00000000000001, 36.75, 37.5, 38.25000000000001, 39.0, 39.75000000000001, 40.5, 41.25, 42.00000000000001, 42.75, 43.50000000000001, 44.25, 45.0, 45.75000000000001, 46.5, 47.25000000000001, 48.0, 48.75, 49.50000000000001, 50.25, 51.00000000000001, 51.75, 52.5, 53.25000000000001, 54.0, 54.75000000000001, 55.5, 56.25, 57.00000000000001, 57.75, 58.50000000000001, 59.25, 60.0, 60.75, 61.50000000000001, 62.25000000000001, 63.0, 63.75, 64.5, 65.25000000000001, 66.0, 66.75, 67.5, 68.25, 69.00000000000001, 69.75, 70.5, 71.25, 72.00000000000001, 72.75000000000001, 73.5, 74.25, 75.0, 75.75000000000001], [0.0, 0.7600000000000001, 1.5200000000000002, 2.2800000000000007, 3.0400000000000005, 3.8000000000000003, 4.560000000000001, 5.320000000000001, 6.080000000000001, 6.840000000000001, 7.6000000000000005, 8.360000000000001, 9.120000000000003, 9.88, 10.640000000000002, 11.4, 12.160000000000002, 12.920000000000002, 13.680000000000001, 14.440000000000001, 15.200000000000001, 15.960000000000003, 16.720000000000002, 17.480000000000004, 18.240000000000006, 19.0, 19.76, 20.520000000000003, 21.280000000000005, 22.040000000000003, 22.8, 23.560000000000002, 24.320000000000004, 25.080000000000005, 25.840000000000003, 26.6, 27.360000000000003, 28.120000000000005, 28.880000000000003, 29.640000000000004, 30.400000000000002, 31.160000000000007, 31.920000000000005, 32.68, 33.440000000000005, 34.2, 34.96000000000001, 35.720000000000006, 36.48000000000001, 37.24, 38.0, 38.760000000000005, 39.52, 40.28000000000001, 41.040000000000006, 41.800000000000004, 42.56000000000001, 43.32000000000001, 44.080000000000005, 44.84, 45.6, 46.36000000000001, 47.120000000000005, 47.88000000000001, 48.64000000000001, 49.400000000000006, 50.16000000000001, 50.92, 51.68000000000001, 52.440000000000005, 53.2, 53.96000000000001, 54.720000000000006, 55.48000000000001, 56.24000000000001, 57.00000000000001, 57.760000000000005, 58.52, 59.28000000000001, 60.040000000000006, 60.800000000000004, 61.56, 62.320000000000014, 63.08000000000001, 63.84000000000001, 64.60000000000001, 65.36, 66.12000000000002, 66.88000000000001, 67.64, 68.4, 69.16, 69.92000000000002, 70.68, 71.44000000000001, 72.2, 72.96000000000002, 73.72000000000001, 74.48, 75.24000000000001, 76.0, 76.76000000000002], [0.0, 0.77, 1.54, 2.3100000000000005, 3.08, 3.85, 4.620000000000001, 5.390000000000001, 6.16, 6.930000000000001, 7.7, 8.47, 9.240000000000002, 10.01, 10.780000000000001, 11.55, 12.32, 13.090000000000002, 13.860000000000001, 14.63, 15.4, 16.17, 16.94, 17.71, 18.480000000000004, 19.25, 20.02, 20.790000000000003, 21.560000000000002, 22.330000000000002, 23.1, 23.87, 24.64, 25.410000000000004, 26.180000000000003, 26.95, 27.720000000000002, 28.490000000000002, 29.26, 30.030000000000005, 30.8, 31.570000000000004, 32.34, 33.11, 33.88, 34.65, 35.42, 36.190000000000005, 36.96000000000001, 37.730000000000004, 38.5, 39.27, 40.04, 40.81000000000001, 41.580000000000005, 42.35, 43.120000000000005, 43.89, 44.660000000000004, 45.43000000000001, 46.2, 46.970000000000006, 47.74, 48.510000000000005, 49.28, 50.050000000000004, 50.82000000000001, 51.59, 52.36000000000001, 53.13, 53.9, 54.67000000000001, 55.440000000000005, 56.21000000000001, 56.980000000000004, 57.75, 58.52, 59.290000000000006, 60.06000000000001, 60.830000000000005, 61.6, 62.37, 63.14000000000001, 63.910000000000004, 64.68, 65.45, 66.22, 66.99000000000001, 67.76, 68.53, 69.3, 70.07, 70.84, 71.61000000000001, 72.38000000000001, 73.15, 73.92000000000002, 74.69000000000001, 75.46000000000001, 76.23, 77.0, 77.77000000000001], [0.0, 0.7800000000000001, 1.5600000000000003, 2.3400000000000007, 3.1200000000000006, 3.9000000000000004, 4.6800000000000015, 5.460000000000001, 6.240000000000001, 7.0200000000000005, 7.800000000000001, 8.580000000000002, 9.360000000000003, 10.14, 10.920000000000002, 11.700000000000001, 12.480000000000002, 13.260000000000003, 14.040000000000001, 14.820000000000002, 15.600000000000001, 16.380000000000003, 17.160000000000004, 17.940000000000005, 18.720000000000006, 19.5, 20.28, 21.060000000000002, 21.840000000000003, 22.620000000000005, 23.400000000000002, 24.180000000000003, 24.960000000000004, 25.740000000000006, 26.520000000000007, 27.300000000000004, 28.080000000000002, 28.860000000000003, 29.640000000000004, 30.420000000000005, 31.200000000000003, 31.980000000000008, 32.760000000000005, 33.54, 34.32000000000001, 35.1, 35.88000000000001, 36.660000000000004, 37.44000000000001, 38.220000000000006, 39.0, 39.78000000000001, 40.56, 41.34000000000001, 42.120000000000005, 42.900000000000006, 43.68000000000001, 44.46000000000001, 45.24000000000001, 46.02000000000001, 46.800000000000004, 47.580000000000005, 48.36000000000001, 49.14000000000001, 49.92000000000001, 50.7, 51.48000000000001, 52.260000000000005, 53.04000000000001, 53.82000000000001, 54.60000000000001, 55.38000000000001, 56.160000000000004, 56.94000000000001, 57.720000000000006, 58.50000000000001, 59.28000000000001, 60.06000000000001, 60.84000000000001, 61.62000000000001, 62.400000000000006, 63.18, 63.960000000000015, 64.74000000000001, 65.52000000000001, 66.30000000000001, 67.08, 67.86000000000001, 68.64000000000001, 69.42000000000002, 70.2, 70.98, 71.76000000000002, 72.54, 73.32000000000001, 74.10000000000001, 74.88000000000002, 75.66000000000001, 76.44000000000001, 77.22000000000001, 78.0, 78.78000000000002], [0.0, 0.79, 1.58, 2.3700000000000006, 3.16, 3.95, 4.740000000000001, 5.530000000000001, 6.32, 7.11, 7.9, 8.690000000000001, 9.480000000000002, 10.270000000000001, 11.060000000000002, 11.850000000000001, 12.64, 13.430000000000001, 14.22, 15.010000000000002, 15.8, 16.59, 17.380000000000003, 18.17, 18.960000000000004, 19.75, 20.540000000000003, 21.330000000000002, 22.120000000000005, 22.910000000000004, 23.700000000000003, 24.490000000000002, 25.28, 26.070000000000004, 26.860000000000003, 27.650000000000002, 28.44, 29.230000000000004, 30.020000000000003, 30.810000000000006, 31.6, 32.39000000000001, 33.18, 33.97, 34.760000000000005, 35.550000000000004, 36.34, 37.13, 37.92000000000001, 38.71000000000001, 39.5, 40.290000000000006, 41.080000000000005, 41.870000000000005, 42.660000000000004, 43.45, 44.24000000000001, 45.03, 45.82000000000001, 46.61000000000001, 47.400000000000006, 48.190000000000005, 48.980000000000004, 49.77000000000001, 50.56, 51.35, 52.14000000000001, 52.93000000000001, 53.720000000000006, 54.510000000000005, 55.300000000000004, 56.09, 56.88, 57.67000000000001, 58.46000000000001, 59.25, 60.040000000000006, 60.830000000000005, 61.62000000000001, 62.410000000000004, 63.2, 63.99, 64.78000000000002, 65.57000000000001, 66.36, 67.15, 67.94, 68.73000000000002, 69.52000000000001, 70.31, 71.10000000000001, 71.89, 72.68, 73.47000000000001, 74.26, 75.05, 75.84000000000002, 76.63000000000001, 77.42000000000002, 78.21000000000001, 79.0, 79.79000000000002], [0.0, 0.8, 1.6, 2.4000000000000004, 3.2, 4.0, 4.800000000000001, 5.6000000000000005, 6.4, 7.2, 8.0, 8.8, 9.600000000000001, 10.4, 11.200000000000001, 12.0, 12.8, 13.600000000000001, 14.4, 15.200000000000001, 16.0, 16.8, 17.6, 18.400000000000002, 19.200000000000003, 20.0, 20.8, 21.6, 22.400000000000002, 23.200000000000003, 24.0, 24.8, 25.6, 26.400000000000002, 27.200000000000003, 28.0, 28.8, 29.6, 30.400000000000002, 31.200000000000003, 32.0, 32.800000000000004, 33.6, 34.4, 35.2, 36.0, 36.800000000000004, 37.6, 38.400000000000006, 39.2, 40.0, 40.800000000000004, 41.6, 42.400000000000006, 43.2, 44.0, 44.800000000000004, 45.6, 46.400000000000006, 47.2, 48.0, 48.800000000000004, 49.6, 50.400000000000006, 51.2, 52.0, 52.800000000000004, 53.6, 54.400000000000006, 55.2, 56.0, 56.800000000000004, 57.6, 58.400000000000006, 59.2, 60.0, 60.800000000000004, 61.6, 62.400000000000006, 63.2, 64.0, 64.8, 65.60000000000001, 66.4, 67.2, 68.0, 68.8, 69.60000000000001, 70.4, 71.2, 72.0, 72.8, 73.60000000000001, 74.4, 75.2, 76.0, 76.80000000000001, 77.60000000000001, 78.4, 79.2, 80.0, 80.80000000000001], [0.0, 0.81, 1.62, 2.43, 3.24, 4.05, 4.86, 5.67, 6.48, 7.29, 8.1, 8.91, 9.72, 10.53, 11.34, 12.149999999999999, 12.96, 13.770000000000001, 14.58, 15.39, 16.2, 17.01, 17.82, 18.630000000000003, 19.44, 20.25, 21.06, 21.87, 22.68, 23.490000000000002, 24.299999999999997, 25.11, 25.92, 26.73, 27.540000000000003, 28.349999999999998, 29.16, 29.97, 30.78, 31.59, 32.4, 33.21, 34.02, 34.83, 35.64, 36.449999999999996, 37.260000000000005, 38.07, 38.88, 39.69, 40.5, 41.31, 42.12, 42.93000000000001, 43.74, 44.55, 45.36, 46.17, 46.980000000000004, 47.79, 48.599999999999994, 49.410000000000004, 50.22, 51.03, 51.84, 52.65, 53.46, 54.269999999999996, 55.080000000000005, 55.89, 56.699999999999996, 57.510000000000005, 58.32, 59.13, 59.94, 60.75, 61.56, 62.37, 63.18, 63.99, 64.8, 65.61, 66.42, 67.23, 68.04, 68.85, 69.66, 70.47, 71.28, 72.09, 72.89999999999999, 73.71, 74.52000000000001, 75.33, 76.14, 76.95, 77.76, 78.57000000000001, 79.38, 80.19, 81.0, 81.81], [0.0, 0.8200000000000002, 1.6400000000000003, 2.460000000000001, 3.2800000000000007, 4.1000000000000005, 4.920000000000002, 5.740000000000001, 6.560000000000001, 7.380000000000001, 8.200000000000001, 9.020000000000001, 9.840000000000003, 10.660000000000002, 11.480000000000002, 12.3, 13.120000000000003, 13.940000000000003, 14.760000000000002, 15.580000000000004, 16.400000000000002, 17.220000000000002, 18.040000000000003, 18.860000000000003, 19.680000000000007, 20.500000000000004, 21.320000000000004, 22.140000000000004, 22.960000000000004, 23.780000000000005, 24.6, 25.420000000000005, 26.240000000000006, 27.060000000000006, 27.880000000000006, 28.700000000000003, 29.520000000000003, 30.340000000000007, 31.160000000000007, 31.980000000000008, 32.800000000000004, 33.62000000000001, 34.440000000000005, 35.260000000000005, 36.080000000000005, 36.900000000000006, 37.720000000000006, 38.540000000000006, 39.360000000000014, 40.18000000000001, 41.00000000000001, 41.82000000000001, 42.64000000000001, 43.46000000000001, 44.28000000000001, 45.10000000000001, 45.92000000000001, 46.74000000000001, 47.56000000000001, 48.38000000000001, 49.2, 50.02000000000001, 50.84000000000001, 51.66000000000001, 52.48000000000001, 53.300000000000004, 54.12000000000001, 54.94000000000001, 55.76000000000001, 56.58000000000001, 57.400000000000006, 58.22000000000001, 59.040000000000006, 59.860000000000014, 60.680000000000014, 61.50000000000001, 62.320000000000014, 63.14000000000001, 63.960000000000015, 64.78000000000002, 65.60000000000001, 66.42, 67.24000000000002, 68.06000000000002, 68.88000000000001, 69.7, 70.52000000000001, 71.34000000000002, 72.16000000000001, 72.98000000000002, 73.80000000000001, 74.62, 75.44000000000001, 76.26000000000002, 77.08000000000001, 77.9, 78.72000000000003, 79.54000000000002, 80.36000000000001, 81.18, 82.00000000000001, 82.82000000000002], [0.0, 0.8300000000000001, 1.6600000000000001, 2.4900000000000007, 3.3200000000000003, 4.15, 4.980000000000001, 5.810000000000001, 6.640000000000001, 7.470000000000001, 8.3, 9.13, 9.960000000000003, 10.790000000000001, 11.620000000000003, 12.450000000000001, 13.280000000000001, 14.110000000000003, 14.940000000000001, 15.770000000000003, 16.6, 17.430000000000003, 18.26, 19.090000000000003, 19.920000000000005, 20.75, 21.580000000000002, 22.410000000000004, 23.240000000000006, 24.070000000000004, 24.900000000000002, 25.730000000000004, 26.560000000000002, 27.390000000000004, 28.220000000000006, 29.050000000000004, 29.880000000000003, 30.710000000000004, 31.540000000000006, 32.370000000000005, 33.2, 34.03000000000001, 34.86000000000001, 35.690000000000005, 36.52, 37.35, 38.18000000000001, 39.010000000000005, 39.84000000000001, 40.67000000000001, 41.5, 42.330000000000005, 43.160000000000004, 43.99000000000001, 44.82000000000001, 45.650000000000006, 46.48000000000001, 47.31, 48.14000000000001, 48.970000000000006, 49.800000000000004, 50.63000000000001, 51.46000000000001, 52.29000000000001, 53.120000000000005, 53.95, 54.78000000000001, 55.61000000000001, 56.44000000000001, 57.27000000000001, 58.10000000000001, 58.93000000000001, 59.760000000000005, 60.59000000000001, 61.42000000000001, 62.25000000000001, 63.08000000000001, 63.910000000000004, 64.74000000000001, 65.57000000000001, 66.4, 67.23, 68.06000000000002, 68.89000000000001, 69.72000000000001, 70.55000000000001, 71.38000000000001, 72.21000000000001, 73.04, 73.87, 74.7, 75.53, 76.36000000000001, 77.19000000000001, 78.02000000000001, 78.85000000000001, 79.68000000000002, 80.51000000000002, 81.34000000000002, 82.17000000000002, 83.0, 83.83000000000001], [0.0, 0.8400000000000001, 1.6800000000000002, 2.5200000000000005, 3.3600000000000003, 4.2, 5.040000000000001, 5.880000000000001, 6.720000000000001, 7.5600000000000005, 8.4, 9.240000000000002, 10.080000000000002, 10.920000000000002, 11.760000000000002, 12.600000000000001, 13.440000000000001, 14.280000000000003, 15.120000000000001, 15.960000000000003, 16.8, 17.64, 18.480000000000004, 19.320000000000004, 20.160000000000004, 21.0, 21.840000000000003, 22.680000000000003, 23.520000000000003, 24.360000000000003, 25.200000000000003, 26.040000000000003, 26.880000000000003, 27.720000000000002, 28.560000000000006, 29.400000000000002, 30.240000000000002, 31.080000000000002, 31.920000000000005, 32.760000000000005, 33.6, 34.440000000000005, 35.28, 36.12, 36.96000000000001, 37.800000000000004, 38.64000000000001, 39.480000000000004, 40.32000000000001, 41.160000000000004, 42.0, 42.84, 43.68000000000001, 44.52000000000001, 45.36000000000001, 46.2, 47.040000000000006, 47.88, 48.720000000000006, 49.56, 50.400000000000006, 51.24000000000001, 52.080000000000005, 52.92000000000001, 53.760000000000005, 54.6, 55.440000000000005, 56.28, 57.12000000000001, 57.96000000000001, 58.800000000000004, 59.64000000000001, 60.480000000000004, 61.32000000000001, 62.160000000000004, 63.0, 63.84000000000001, 64.68, 65.52000000000001, 66.36, 67.2, 68.04, 68.88000000000001, 69.72000000000001, 70.56, 71.4, 72.24, 73.08000000000001, 73.92000000000002, 74.76, 75.60000000000001, 76.44, 77.28000000000002, 78.12, 78.96000000000001, 79.8, 80.64000000000001, 81.48000000000002, 82.32000000000001, 83.16000000000001, 84.0, 84.84000000000002], [0.0, 0.8500000000000001, 1.7000000000000002, 2.5500000000000003, 3.4000000000000004, 4.25, 5.1000000000000005, 5.95, 6.800000000000001, 7.65, 8.5, 9.350000000000001, 10.200000000000001, 11.05, 11.9, 12.75, 13.600000000000001, 14.450000000000001, 15.3, 16.150000000000002, 17.0, 17.85, 18.700000000000003, 19.55, 20.400000000000002, 21.25, 22.1, 22.950000000000003, 23.8, 24.650000000000002, 25.5, 26.35, 27.200000000000003, 28.05, 28.900000000000002, 29.75, 30.6, 31.450000000000003, 32.300000000000004, 33.150000000000006, 34.0, 34.85, 35.7, 36.55, 37.400000000000006, 38.25, 39.1, 39.95, 40.800000000000004, 41.650000000000006, 42.5, 43.35, 44.2, 45.050000000000004, 45.900000000000006, 46.75, 47.6, 48.45, 49.300000000000004, 50.150000000000006, 51.0, 51.85, 52.7, 53.550000000000004, 54.400000000000006, 55.25, 56.1, 56.95, 57.800000000000004, 58.650000000000006, 59.5, 60.35, 61.2, 62.050000000000004, 62.900000000000006, 63.75, 64.60000000000001, 65.45, 66.30000000000001, 67.15, 68.0, 68.85, 69.7, 70.55000000000001, 71.4, 72.25, 73.1, 73.95, 74.80000000000001, 75.65, 76.5, 77.35, 78.2, 79.05000000000001, 79.9, 80.75, 81.60000000000001, 82.45, 83.30000000000001, 84.15, 85.0, 85.85000000000001], [0.0, 0.86, 1.72, 2.58, 3.44, 4.3, 5.16, 6.0200000000000005, 6.88, 7.74, 8.6, 9.46, 10.32, 11.18, 12.040000000000001, 12.899999999999999, 13.76, 14.620000000000001, 15.48, 16.34, 17.2, 18.06, 18.92, 19.78, 20.64, 21.5, 22.36, 23.22, 24.080000000000002, 24.94, 25.799999999999997, 26.66, 27.52, 28.380000000000003, 29.240000000000002, 30.099999999999998, 30.96, 31.82, 32.68, 33.54, 34.4, 35.260000000000005, 36.12, 36.98, 37.84, 38.699999999999996, 39.56, 40.42, 41.28, 42.14, 43.0, 43.86, 44.72, 45.580000000000005, 46.44, 47.3, 48.160000000000004, 49.019999999999996, 49.88, 50.74, 51.599999999999994, 52.46, 53.32, 54.18000000000001, 55.04, 55.9, 56.760000000000005, 57.62, 58.480000000000004, 59.34, 60.199999999999996, 61.06, 61.92, 62.78, 63.64, 64.5, 65.36, 66.22, 67.08, 67.94, 68.8, 69.66, 70.52000000000001, 71.38000000000001, 72.24, 73.1, 73.96, 74.82000000000001, 75.68, 76.54, 77.39999999999999, 78.25999999999999, 79.12, 79.98, 80.84, 81.7, 82.56, 83.42, 84.28, 85.14, 86.0, 86.86000000000001], [0.0, 0.8700000000000001, 1.7400000000000002, 2.6100000000000008, 3.4800000000000004, 4.3500000000000005, 5.2200000000000015, 6.090000000000002, 6.960000000000001, 7.830000000000001, 8.700000000000001, 9.570000000000002, 10.440000000000003, 11.310000000000002, 12.180000000000003, 13.05, 13.920000000000002, 14.790000000000003, 15.660000000000002, 16.530000000000005, 17.400000000000002, 18.270000000000003, 19.140000000000004, 20.010000000000005, 20.880000000000006, 21.750000000000004, 22.620000000000005, 23.490000000000006, 24.360000000000007, 25.230000000000008, 26.1, 26.970000000000002, 27.840000000000003, 28.710000000000004, 29.580000000000005, 30.450000000000003, 31.320000000000004, 32.190000000000005, 33.06000000000001, 33.93000000000001, 34.800000000000004, 35.67000000000001, 36.540000000000006, 37.410000000000004, 38.28000000000001, 39.150000000000006, 40.02000000000001, 40.89000000000001, 41.76000000000001, 42.63000000000001, 43.50000000000001, 44.37000000000001, 45.24000000000001, 46.110000000000014, 46.98000000000001, 47.85000000000001, 48.72000000000001, 49.59000000000001, 50.460000000000015, 51.33000000000001, 52.2, 53.070000000000014, 53.940000000000005, 54.81000000000001, 55.68000000000001, 56.550000000000004, 57.42000000000001, 58.290000000000006, 59.16000000000001, 60.03000000000001, 60.900000000000006, 61.77000000000001, 62.64000000000001, 63.51000000000001, 64.38000000000001, 65.25000000000001, 66.12000000000002, 66.99000000000001, 67.86000000000001, 68.73000000000002, 69.60000000000001, 70.47, 71.34000000000002, 72.21000000000001, 73.08000000000001, 73.95, 74.82000000000001, 75.69000000000001, 76.56000000000002, 77.43, 78.30000000000001, 79.17, 80.04000000000002, 80.91000000000001, 81.78000000000002, 82.65, 83.52000000000002, 84.39000000000001, 85.26000000000002, 86.13000000000001, 87.00000000000001, 87.87000000000002], [0.0, 0.8800000000000001, 1.7600000000000002, 2.6400000000000006, 3.5200000000000005, 4.4, 5.280000000000001, 6.160000000000001, 7.040000000000001, 7.920000000000001, 8.8, 9.680000000000001, 10.560000000000002, 11.440000000000001, 12.320000000000002, 13.200000000000001, 14.080000000000002, 14.960000000000003, 15.840000000000002, 16.720000000000002, 17.6, 18.480000000000004, 19.360000000000003, 20.240000000000006, 21.120000000000005, 22.0, 22.880000000000003, 23.760000000000005, 24.640000000000004, 25.520000000000007, 26.400000000000002, 27.280000000000005, 28.160000000000004, 29.040000000000006, 29.920000000000005, 30.800000000000004, 31.680000000000003, 32.56, 33.440000000000005, 34.32000000000001, 35.2, 36.080000000000005, 36.96000000000001, 37.84, 38.720000000000006, 39.6, 40.48000000000001, 41.36000000000001, 42.24000000000001, 43.120000000000005, 44.0, 44.88000000000001, 45.760000000000005, 46.64000000000001, 47.52000000000001, 48.400000000000006, 49.28000000000001, 50.160000000000004, 51.04000000000001, 51.92000000000001, 52.800000000000004, 53.68000000000001, 54.56000000000001, 55.44000000000001, 56.32000000000001, 57.2, 58.08000000000001, 58.96000000000001, 59.84000000000001, 60.720000000000006, 61.60000000000001, 62.48000000000001, 63.36000000000001, 64.24000000000001, 65.12, 66.0, 66.88000000000001, 67.76, 68.64000000000001, 69.52000000000001, 70.4, 71.28, 72.16000000000001, 73.04, 73.92000000000002, 74.80000000000001, 75.68, 76.56000000000002, 77.44000000000001, 78.32000000000001, 79.2, 80.08, 80.96000000000002, 81.84000000000002, 82.72000000000001, 83.60000000000001, 84.48000000000002, 85.36000000000001, 86.24000000000001, 87.12, 88.0, 88.88000000000002], [0.0, 0.8900000000000001, 1.7800000000000002, 2.6700000000000004, 3.5600000000000005, 4.45, 5.340000000000001, 6.23, 7.120000000000001, 8.01, 8.9, 9.790000000000001, 10.680000000000001, 11.57, 12.46, 13.350000000000001, 14.240000000000002, 15.130000000000003, 16.02, 16.91, 17.8, 18.69, 19.580000000000002, 20.470000000000002, 21.360000000000003, 22.25, 23.14, 24.03, 24.92, 25.810000000000006, 26.700000000000003, 27.590000000000003, 28.480000000000004, 29.370000000000005, 30.260000000000005, 31.150000000000002, 32.04, 32.93, 33.82, 34.71000000000001, 35.6, 36.49000000000001, 37.38, 38.27, 39.160000000000004, 40.050000000000004, 40.940000000000005, 41.830000000000005, 42.720000000000006, 43.61000000000001, 44.5, 45.39000000000001, 46.28, 47.17000000000001, 48.06, 48.95, 49.84, 50.730000000000004, 51.62000000000001, 52.510000000000005, 53.400000000000006, 54.290000000000006, 55.18000000000001, 56.07000000000001, 56.96000000000001, 57.85, 58.74000000000001, 59.63, 60.52000000000001, 61.410000000000004, 62.300000000000004, 63.190000000000005, 64.08, 64.97000000000001, 65.86, 66.75, 67.64, 68.53, 69.42000000000002, 70.31, 71.2, 72.09, 72.98000000000002, 73.87, 74.76, 75.65, 76.54, 77.43, 78.32000000000001, 79.21000000000001, 80.10000000000001, 80.99, 81.88000000000001, 82.77000000000001, 83.66000000000001, 84.55, 85.44000000000001, 86.33000000000001, 87.22000000000001, 88.11000000000001, 89.0, 89.89000000000001], [0.0, 0.9, 1.8, 2.7, 3.6, 4.5, 5.4, 6.300000000000001, 7.2, 8.1, 9.0, 9.9, 10.8, 11.700000000000001, 12.600000000000001, 13.5, 14.4, 15.3, 16.2, 17.1, 18.0, 18.900000000000002, 19.8, 20.700000000000003, 21.6, 22.5, 23.400000000000002, 24.3, 25.200000000000003, 26.1, 27.0, 27.900000000000002, 28.8, 29.700000000000003, 30.6, 31.5, 32.4, 33.300000000000004, 34.2, 35.1, 36.0, 36.900000000000006, 37.800000000000004, 38.699999999999996, 39.6, 40.5, 41.400000000000006, 42.300000000000004, 43.2, 44.1, 45.0, 45.900000000000006, 46.800000000000004, 47.7, 48.6, 49.5, 50.400000000000006, 51.300000000000004, 52.2, 53.1, 54.0, 54.900000000000006, 55.800000000000004, 56.7, 57.6, 58.5, 59.400000000000006, 60.300000000000004, 61.2, 62.1, 63.0, 63.900000000000006, 64.8, 65.7, 66.60000000000001, 67.5, 68.4, 69.3, 70.2, 71.10000000000001, 72.0, 72.89999999999999, 73.80000000000001, 74.7, 75.60000000000001, 76.5, 77.39999999999999, 78.30000000000001, 79.2, 80.10000000000001, 81.0, 81.89999999999999, 82.80000000000001, 83.7, 84.60000000000001, 85.5, 86.4, 87.30000000000001, 88.2, 89.10000000000001, 90.0, 90.9], [0.0, 0.91, 1.82, 2.7300000000000004, 3.64, 4.55, 5.460000000000001, 6.37, 7.28, 8.19, 9.1, 10.01, 10.920000000000002, 11.83, 12.74, 13.649999999999999, 14.56, 15.47, 16.38, 17.29, 18.2, 19.11, 20.02, 20.930000000000003, 21.840000000000003, 22.75, 23.66, 24.57, 25.48, 26.39, 27.299999999999997, 28.21, 29.12, 30.03, 30.94, 31.849999999999998, 32.76, 33.67, 34.58, 35.49, 36.4, 37.31, 38.22, 39.129999999999995, 40.04, 40.949999999999996, 41.86000000000001, 42.77, 43.68000000000001, 44.59, 45.5, 46.410000000000004, 47.32, 48.230000000000004, 49.14, 50.05, 50.96, 51.87, 52.78, 53.69, 54.599999999999994, 55.510000000000005, 56.42, 57.330000000000005, 58.24, 59.15, 60.06, 60.97, 61.88, 62.79, 63.699999999999996, 64.61, 65.52, 66.43, 67.34, 68.25, 69.16, 70.07, 70.98, 71.89, 72.8, 73.71, 74.62, 75.53, 76.44, 77.35, 78.25999999999999, 79.17, 80.08, 80.99, 81.89999999999999, 82.80999999999999, 83.72000000000001, 84.63000000000001, 85.54, 86.45, 87.36000000000001, 88.27000000000001, 89.18, 90.09, 91.0, 91.91000000000001], [0.0, 0.9200000000000002, 1.8400000000000003, 2.7600000000000007, 3.6800000000000006, 4.6000000000000005, 5.520000000000001, 6.440000000000001, 7.360000000000001, 8.280000000000001, 9.200000000000001, 10.120000000000003, 11.040000000000003, 11.960000000000003, 12.880000000000003, 13.8, 14.720000000000002, 15.640000000000004, 16.560000000000002, 17.480000000000004, 18.400000000000002, 19.320000000000004, 20.240000000000006, 21.160000000000004, 22.080000000000005, 23.000000000000004, 23.920000000000005, 24.840000000000003, 25.760000000000005, 26.680000000000007, 27.6, 28.520000000000003, 29.440000000000005, 30.360000000000007, 31.28000000000001, 32.2, 33.120000000000005, 34.040000000000006, 34.96000000000001, 35.88000000000001, 36.800000000000004, 37.720000000000006, 38.64000000000001, 39.56, 40.48000000000001, 41.400000000000006, 42.32000000000001, 43.24000000000001, 44.16000000000001, 45.080000000000005, 46.00000000000001, 46.92000000000001, 47.84000000000001, 48.76000000000001, 49.68000000000001, 50.60000000000001, 51.52000000000001, 52.440000000000005, 53.360000000000014, 54.28000000000001, 55.2, 56.12000000000001, 57.040000000000006, 57.960000000000015, 58.88000000000001, 59.800000000000004, 60.72000000000001, 61.64000000000001, 62.56000000000002, 63.48000000000001, 64.4, 65.32000000000001, 66.24000000000001, 67.16000000000001, 68.08000000000001, 69.00000000000001, 69.92000000000002, 70.84, 71.76000000000002, 72.68, 73.60000000000001, 74.52000000000001, 75.44000000000001, 76.36000000000001, 77.28000000000002, 78.2, 79.12, 80.04000000000002, 80.96000000000002, 81.88000000000001, 82.80000000000001, 83.72000000000001, 84.64000000000001, 85.56000000000002, 86.48000000000002, 87.4, 88.32000000000002, 89.24000000000002, 90.16000000000001, 91.08000000000001, 92.00000000000001, 92.92000000000003], [0.0, 0.9300000000000002, 1.8600000000000003, 2.7900000000000005, 3.7200000000000006, 4.65, 5.580000000000001, 6.510000000000001, 7.440000000000001, 8.370000000000001, 9.3, 10.230000000000002, 11.160000000000002, 12.090000000000002, 13.020000000000001, 13.950000000000001, 14.880000000000003, 15.810000000000002, 16.740000000000002, 17.67, 18.6, 19.53, 20.460000000000004, 21.390000000000004, 22.320000000000004, 23.25, 24.180000000000003, 25.110000000000003, 26.040000000000003, 26.970000000000006, 27.900000000000002, 28.830000000000002, 29.760000000000005, 30.690000000000005, 31.620000000000005, 32.550000000000004, 33.480000000000004, 34.410000000000004, 35.34, 36.27, 37.2, 38.13000000000001, 39.06, 39.99, 40.92000000000001, 41.85, 42.78000000000001, 43.71000000000001, 44.64000000000001, 45.57000000000001, 46.5, 47.43000000000001, 48.36000000000001, 49.29000000000001, 50.220000000000006, 51.150000000000006, 52.080000000000005, 53.010000000000005, 53.94000000000001, 54.870000000000005, 55.800000000000004, 56.73000000000001, 57.660000000000004, 58.59000000000001, 59.52000000000001, 60.45, 61.38000000000001, 62.31000000000001, 63.24000000000001, 64.17, 65.10000000000001, 66.03000000000002, 66.96000000000001, 67.89000000000001, 68.82000000000001, 69.75, 70.68, 71.61000000000001, 72.54, 73.47000000000001, 74.4, 75.33, 76.26000000000002, 77.19000000000001, 78.12, 79.05000000000001, 79.98, 80.91000000000001, 81.84000000000002, 82.77000000000001, 83.7, 84.63000000000001, 85.56000000000002, 86.49000000000001, 87.42000000000002, 88.35000000000001, 89.28000000000002, 90.21000000000002, 91.14000000000001, 92.07000000000001, 93.0, 93.93000000000002], [0.0, 0.9400000000000001, 1.8800000000000001, 2.8200000000000007, 3.7600000000000002, 4.7, 5.6400000000000015, 6.580000000000001, 7.5200000000000005, 8.46, 9.4, 10.340000000000002, 11.280000000000003, 12.22, 13.160000000000002, 14.100000000000001, 15.040000000000001, 15.980000000000002, 16.92, 17.860000000000003, 18.8, 19.740000000000002, 20.680000000000003, 21.620000000000005, 22.560000000000006, 23.5, 24.44, 25.380000000000003, 26.320000000000004, 27.260000000000005, 28.200000000000003, 29.14, 30.080000000000002, 31.020000000000003, 31.960000000000004, 32.9, 33.84, 34.78, 35.720000000000006, 36.660000000000004, 37.6, 38.540000000000006, 39.480000000000004, 40.42, 41.36000000000001, 42.300000000000004, 43.24000000000001, 44.18000000000001, 45.12000000000001, 46.06, 47.0, 47.940000000000005, 48.88, 49.82000000000001, 50.760000000000005, 51.7, 52.64000000000001, 53.580000000000005, 54.52000000000001, 55.46000000000001, 56.400000000000006, 57.34000000000001, 58.28, 59.220000000000006, 60.160000000000004, 61.1, 62.040000000000006, 62.980000000000004, 63.92000000000001, 64.86, 65.8, 66.74000000000001, 67.68, 68.62, 69.56, 70.5, 71.44000000000001, 72.38000000000001, 73.32000000000001, 74.26, 75.2, 76.14, 77.08000000000001, 78.02000000000001, 78.96000000000001, 79.9, 80.84, 81.78000000000002, 82.72000000000001, 83.66000000000001, 84.60000000000001, 85.54, 86.48000000000002, 87.42000000000002, 88.36000000000001, 89.3, 90.24000000000002, 91.18, 92.12, 93.06, 94.0, 94.94000000000001], [0.0, 0.9500000000000001, 1.9000000000000001, 2.8500000000000005, 3.8000000000000003, 4.75, 5.700000000000001, 6.65, 7.6000000000000005, 8.55, 9.5, 10.450000000000001, 11.400000000000002, 12.35, 13.3, 14.25, 15.200000000000001, 16.150000000000002, 17.1, 18.05, 19.0, 19.95, 20.900000000000002, 21.85, 22.800000000000004, 23.75, 24.7, 25.650000000000002, 26.6, 27.550000000000004, 28.5, 29.45, 30.400000000000002, 31.35, 32.300000000000004, 33.25, 34.2, 35.15, 36.1, 37.050000000000004, 38.0, 38.95, 39.9, 40.85, 41.800000000000004, 42.75, 43.7, 44.65, 45.60000000000001, 46.550000000000004, 47.5, 48.45, 49.4, 50.35000000000001, 51.300000000000004, 52.25, 53.2, 54.15, 55.10000000000001, 56.050000000000004, 57.0, 57.95, 58.9, 59.85000000000001, 60.800000000000004, 61.75, 62.7, 63.65, 64.60000000000001, 65.55, 66.5, 67.45, 68.4, 69.35000000000001, 70.3, 71.25, 72.2, 73.15, 74.10000000000001, 75.05, 76.0, 76.95, 77.9, 78.85000000000001, 79.8, 80.75, 81.7, 82.65, 83.60000000000001, 84.55, 85.5, 86.45, 87.4, 88.35000000000001, 89.3, 90.25, 91.20000000000002, 92.15, 93.10000000000001, 94.05, 95.0, 95.95000000000002], [0.0, 0.9600000000000002, 1.9200000000000004, 2.880000000000001, 3.8400000000000007, 4.800000000000001, 5.760000000000002, 6.7200000000000015, 7.6800000000000015, 8.640000000000002, 9.600000000000001, 10.560000000000002, 11.520000000000003, 12.480000000000002, 13.440000000000003, 14.400000000000002, 15.360000000000003, 16.320000000000004, 17.280000000000005, 18.240000000000006, 19.200000000000003, 20.160000000000004, 21.120000000000005, 22.080000000000005, 23.040000000000006, 24.000000000000004, 24.960000000000004, 25.920000000000005, 26.880000000000006, 27.840000000000007, 28.800000000000004, 29.760000000000005, 30.720000000000006, 31.680000000000007, 32.64000000000001, 33.60000000000001, 34.56000000000001, 35.52000000000001, 36.48000000000001, 37.44000000000001, 38.400000000000006, 39.360000000000014, 40.32000000000001, 41.28, 42.24000000000001, 43.2, 44.16000000000001, 45.12000000000001, 46.08000000000001, 47.04000000000001, 48.00000000000001, 48.960000000000015, 49.92000000000001, 50.88000000000002, 51.84000000000001, 52.80000000000001, 53.76000000000001, 54.72000000000001, 55.680000000000014, 56.640000000000015, 57.60000000000001, 58.56000000000002, 59.52000000000001, 60.48000000000002, 61.44000000000001, 62.400000000000006, 63.360000000000014, 64.32000000000001, 65.28000000000002, 66.24000000000001, 67.20000000000002, 68.16000000000001, 69.12000000000002, 70.08000000000001, 71.04000000000002, 72.00000000000001, 72.96000000000002, 73.92000000000002, 74.88000000000002, 75.84000000000002, 76.80000000000001, 77.76, 78.72000000000003, 79.68000000000002, 80.64000000000001, 81.60000000000001, 82.56, 83.52000000000002, 84.48000000000002, 85.44000000000001, 86.4, 87.36000000000001, 88.32000000000002, 89.28000000000002, 90.24000000000002, 91.20000000000002, 92.16000000000003, 93.12000000000002, 94.08000000000003, 95.04000000000002, 96.00000000000001, 96.96000000000002], [0.0, 0.9700000000000002, 1.9400000000000004, 2.9100000000000006, 3.880000000000001, 4.8500000000000005, 5.820000000000001, 6.790000000000002, 7.760000000000002, 8.73, 9.700000000000001, 10.670000000000002, 11.640000000000002, 12.610000000000001, 13.580000000000004, 14.55, 15.520000000000003, 16.490000000000002, 17.46, 18.430000000000003, 19.400000000000002, 20.370000000000005, 21.340000000000003, 22.310000000000006, 23.280000000000005, 24.250000000000004, 25.220000000000002, 26.190000000000005, 27.160000000000007, 28.130000000000006, 29.1, 30.070000000000004, 31.040000000000006, 32.010000000000005, 32.980000000000004, 33.95, 34.92, 35.89000000000001, 36.86000000000001, 37.830000000000005, 38.800000000000004, 39.77000000000001, 40.74000000000001, 41.71, 42.68000000000001, 43.650000000000006, 44.62000000000001, 45.59, 46.56000000000001, 47.53000000000001, 48.50000000000001, 49.47000000000001, 50.440000000000005, 51.41000000000001, 52.38000000000001, 53.35000000000001, 54.320000000000014, 55.290000000000006, 56.26000000000001, 57.23000000000001, 58.2, 59.17000000000001, 60.14000000000001, 61.110000000000014, 62.08000000000001, 63.050000000000004, 64.02000000000001, 64.99000000000001, 65.96000000000001, 66.93, 67.9, 68.87000000000002, 69.84, 70.81000000000002, 71.78000000000002, 72.75000000000001, 73.72000000000001, 74.69000000000001, 75.66000000000001, 76.63000000000001, 77.60000000000001, 78.57000000000001, 79.54000000000002, 80.51000000000002, 81.48000000000002, 82.45, 83.42, 84.39000000000001, 85.36000000000001, 86.33000000000001, 87.30000000000001, 88.27000000000001, 89.24000000000002, 90.21000000000002, 91.18, 92.15, 93.12000000000002, 94.09000000000002, 95.06000000000002, 96.03000000000002, 97.00000000000001, 97.97000000000003], [0.0, 0.9800000000000001, 1.9600000000000002, 2.940000000000001, 3.9200000000000004, 4.9, 5.880000000000002, 6.860000000000001, 7.840000000000001, 8.82, 9.8, 10.780000000000001, 11.760000000000003, 12.740000000000002, 13.720000000000002, 14.700000000000001, 15.680000000000001, 16.660000000000004, 17.64, 18.62, 19.6, 20.580000000000002, 21.560000000000002, 22.540000000000003, 23.520000000000007, 24.5, 25.480000000000004, 26.460000000000004, 27.440000000000005, 28.420000000000005, 29.400000000000002, 30.380000000000003, 31.360000000000003, 32.34, 33.32000000000001, 34.300000000000004, 35.28, 36.260000000000005, 37.24, 38.220000000000006, 39.2, 40.18000000000001, 41.160000000000004, 42.14, 43.120000000000005, 44.1, 45.080000000000005, 46.06, 47.04000000000001, 48.02000000000001, 49.0, 49.98000000000001, 50.96000000000001, 51.94000000000001, 52.92000000000001, 53.900000000000006, 54.88000000000001, 55.86000000000001, 56.84000000000001, 57.82000000000001, 58.800000000000004, 59.78000000000001, 60.760000000000005, 61.74000000000001, 62.720000000000006, 63.7, 64.68, 65.66000000000001, 66.64000000000001, 67.62, 68.60000000000001, 69.58000000000001, 70.56, 71.54, 72.52000000000001, 73.5, 74.48, 75.46000000000001, 76.44000000000001, 77.42000000000002, 78.4, 79.38, 80.36000000000001, 81.34000000000002, 82.32000000000001, 83.30000000000001, 84.28, 85.26000000000002, 86.24000000000001, 87.22000000000001, 88.2, 89.18, 90.16000000000001, 91.14000000000001, 92.12, 93.10000000000001, 94.08000000000003, 95.06000000000002, 96.04000000000002, 97.02000000000001, 98.0, 98.98000000000002], [0.0, 0.9900000000000001, 1.9800000000000002, 2.9700000000000006, 3.9600000000000004, 4.95, 5.940000000000001, 6.930000000000001, 7.920000000000001, 8.91, 9.9, 10.89, 11.880000000000003, 12.870000000000001, 13.860000000000001, 14.850000000000001, 15.840000000000002, 16.830000000000002, 17.82, 18.810000000000002, 19.8, 20.790000000000003, 21.78, 22.770000000000003, 23.760000000000005, 24.75, 25.740000000000002, 26.730000000000004, 27.720000000000002, 28.710000000000004, 29.700000000000003, 30.69, 31.680000000000003, 32.67, 33.660000000000004, 34.65, 35.64, 36.63, 37.620000000000005, 38.61000000000001, 39.6, 40.59, 41.580000000000005, 42.57, 43.56, 44.550000000000004, 45.540000000000006, 46.53, 47.52000000000001, 48.510000000000005, 49.5, 50.49000000000001, 51.480000000000004, 52.470000000000006, 53.46000000000001, 54.45, 55.440000000000005, 56.43000000000001, 57.42000000000001, 58.410000000000004, 59.400000000000006, 60.39000000000001, 61.38, 62.37000000000001, 63.36000000000001, 64.35000000000001, 65.34, 66.33, 67.32000000000001, 68.31, 69.3, 70.29, 71.28, 72.27000000000001, 73.26, 74.25, 75.24000000000001, 76.23, 77.22000000000001, 78.21000000000001, 79.2, 80.19, 81.18, 82.17000000000002, 83.16000000000001, 84.15, 85.14, 86.13000000000001, 87.12, 88.11000000000001, 89.10000000000001, 90.09, 91.08000000000001, 92.07000000000001, 93.06, 94.05, 95.04000000000002, 96.03000000000002, 97.02000000000001, 98.01, 99.0, 99.99000000000002], [0.0, 1.0, 2.0, 3.0000000000000004, 4.0, 5.0, 6.000000000000001, 7.000000000000001, 8.0, 9.0, 10.0, 11.0, 12.000000000000002, 13.0, 14.000000000000002, 15.0, 16.0, 17.0, 18.0, 19.0, 20.0, 21.0, 22.0, 23.000000000000004, 24.000000000000004, 25.0, 26.0, 27.0, 28.000000000000004, 29.000000000000004, 30.0, 31.0, 32.0, 33.0, 34.0, 35.0, 36.0, 37.0, 38.0, 39.0, 40.0, 41.00000000000001, 42.0, 43.0, 44.0, 45.0, 46.00000000000001, 47.0, 48.00000000000001, 49.0, 50.0, 51.00000000000001, 52.0, 53.00000000000001, 54.0, 55.0, 56.00000000000001, 57.0, 58.00000000000001, 59.0, 60.0, 61.00000000000001, 62.0, 63.00000000000001, 64.0, 65.0, 66.0, 67.0, 68.0, 69.0, 70.0, 71.0, 72.0, 73.0, 74.0, 75.0, 76.0, 77.0, 78.0, 79.0, 80.0, 81.0, 82.00000000000001, 83.0, 84.0, 85.0, 86.0, 87.00000000000001, 88.0, 89.0, 90.0, 91.0, 92.00000000000001, 93.0, 94.0, 95.0, 96.00000000000001, 97.00000000000001, 98.0, 99.0, 100.0, 101.00000000000001], [0.0, 1.0100000000000002, 2.0200000000000005, 3.0300000000000007, 4.040000000000001, 5.050000000000001, 6.060000000000001, 7.070000000000002, 8.080000000000002, 9.090000000000002, 10.100000000000001, 11.110000000000003, 12.120000000000003, 13.130000000000003, 14.140000000000004, 15.150000000000002, 16.160000000000004, 17.170000000000005, 18.180000000000003, 19.190000000000005, 20.200000000000003, 21.210000000000004, 22.220000000000006, 23.230000000000008, 24.240000000000006, 25.250000000000004, 26.260000000000005, 27.270000000000007, 28.28000000000001, 29.290000000000006, 30.300000000000004, 31.310000000000006, 32.32000000000001, 33.330000000000005, 34.34000000000001, 35.35000000000001, 36.36000000000001, 37.370000000000005, 38.38000000000001, 39.39000000000001, 40.400000000000006, 41.41000000000001, 42.42000000000001, 43.43000000000001, 44.44000000000001, 45.45, 46.460000000000015, 47.470000000000006, 48.48000000000001, 49.49000000000001, 50.50000000000001, 51.51000000000001, 52.52000000000001, 53.530000000000015, 54.54000000000001, 55.55000000000001, 56.56000000000002, 57.57000000000001, 58.58000000000001, 59.59000000000001, 60.60000000000001, 61.610000000000014, 62.62000000000001, 63.63000000000002, 64.64000000000001, 65.65, 66.66000000000001, 67.67000000000002, 68.68000000000002, 69.69000000000001, 70.70000000000002, 71.71000000000002, 72.72000000000001, 73.73000000000002, 74.74000000000001, 75.75000000000001, 76.76000000000002, 77.77000000000001, 78.78000000000002, 79.79000000000002, 80.80000000000001, 81.81, 82.82000000000002, 83.83000000000001, 84.84000000000002, 85.85000000000001, 86.86000000000001, 87.87000000000002, 88.88000000000002, 89.89000000000001, 90.9, 91.91000000000001, 92.92000000000003, 93.93000000000002, 94.94000000000001, 95.95000000000002, 96.96000000000002, 97.97000000000003, 98.98000000000002, 99.99000000000002, 101.00000000000001, 102.01000000000003]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 2.1\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.007943282347242814, 0.016446803188537782, 0.025175454367322016, 0.03405359690083138, 0.04304458296658674, 0.052126529696515406, 0.06128482383098003, 0.07050898880412834, 0.0797911335508692, 0.08912509381337455, 0.09850591726528544, 0.10792953559275667, 0.11739254552865523, 0.12689205695202357, 0.13642558414304154, 0.14599096584887694, 0.1555863051900745, 0.16520992359751557, 0.1748603249018378, 0.18453616691811767, 0.19423623866294415, 0.20395944187114154, 0.2137047758412981, 0.22347132489134094, 0.23325824788420188, 0.2430647694125374, 0.25289017232581057, 0.2627337913530248, 0.27259500762696415, 0.28247324395572265, 0.2923679607179662, 0.30227865228213346, 0.3122048438683787, 0.32214608878672757, 0.3321019659965806, 0.34207207794204353, 0.35205604862509987, 0.3620535218847593, 0.3720641598553125, 0.3820876415809296, 0.3921236617672288, 0.40217192965325704, 0.41223216798967666, 0.4223041121109144, 0.4323875090906928, 0.44248211697176026, 0.4525877040618276, 0.46270404828873163, 0.4728309366087107, 0.4829681644624228, 0.493115535273975, 0.503272859988785, 0.5134399566465774, 0.5236166499862263, 0.5338027710795276, 0.5439981569912912, 0.554202650463427, 0.5644160996209375, 0.5746383576979491, 0.5848692827820962, 0.5951087375757448, 0.6053565891726884, 0.6156127088490789, 0.6258769718674743, 0.6361492572929871, 0.6464294478206125, 0.6567174296128961, 0.6670130921471784, 0.6773163280717155, 0.6876270330700435, 0.697945105732999, 0.7082704474378628, 0.7186029622341402, 0.7289425567355206, 0.739289140017611, 0.7496426235210556, 0.7600029209596938, 0.7703699482334324, 0.7807436233455308, 0.7911238663240253, 0.8015105991470336, 0.8119037456717044, 0.8223032315665894, 0.832708984247238, 0.8431209328148188, 0.8535390079975971, 0.8639631420950986, 0.8743932689248127, 0.884829323771286, 0.895271243337478, 0.905718965698251, 0.9161724302558817, 0.9266315776974805, 0.9370963499542236, 0.9475666901622963, 0.9580425426254617, 0.9685238527791695, 0.9790105671561282, 0.9895026333532643, 1.0000000000000002, 1.0105026167277862], [0.0, 0.016446803188537782, 0.03405359690083139, 0.052126529696515406, 0.07050898880412834, 0.08912509381337455, 0.10792953559275666, 0.12689205695202355, 0.14599096584887694, 0.16520992359751557, 0.18453616691811767, 0.20395944187114154, 0.22347132489134097, 0.2430647694125374, 0.2627337913530248, 0.28247324395572265, 0.3022786522821335, 0.3221460887867276, 0.34207207794204353, 0.36205352188475926, 0.38208764158092967, 0.402171929653257, 0.42230411211091445, 0.44248211697176026, 0.46270404828873163, 0.48296816446242286, 0.5032728599887851, 0.5236166499862263, 0.5439981569912913, 0.5644160996209375, 0.5848692827820962, 0.6053565891726884, 0.6258769718674744, 0.6464294478206125, 0.6670130921471783, 0.6876270330700435, 0.7082704474378629, 0.7289425567355207, 0.7496426235210557, 0.7703699482334324, 0.7911238663240253, 0.8119037456717043, 0.832708984247238, 0.8535390079975971, 0.8743932689248127, 0.895271243337478, 0.9161724302558818, 0.9370963499542236, 0.9580425426254616, 0.9790105671561282, 1.0000000000000002, 1.0210104341408237, 1.0420414781354437, 1.0630927552296783, 1.0841639025401355, 1.1052545702959267, 1.1263644211348778, 1.1474931294494186, 1.1686403807778345, 1.1898058712370032, 1.2109893069931357, 1.2321904037673836, 1.2534088863734787, 1.2746444882848518, 1.2958969512289056, 1.3171660248063464, 1.3384514661336602, 1.3597530395070003, 1.3810705160859007, 1.402403673595372, 1.423752296045062, 1.4451161734642706, 1.466495101651715, 1.487888881939031, 1.5092973209670755, 1.5307202304741792, 1.5521574270955523, 1.5736087321731238, 1.5950739715751407, 1.6165529755249042, 1.6380455784380765, 1.6595516187680213, 1.6810709388586924, 1.7026033848046076, 1.7241488063174955, 1.7457070565992092, 1.7672779922205546, 1.788861473005679, 1.8104573619217188, 1.8320655249733961, 1.853685831102299, 1.8753181520905824, 1.8969623624688503, 1.9186183394279954, 1.9402859627347844, 1.9619651146509918, 1.9836556798558966, 2.005357545371969, 2.0270706004935857, 2.0487947367186194, 2.070529847682755, 2.0922758290964083], [0.0, 0.025175454367322016, 0.052126529696515406, 0.0797911335508692, 0.10792953559275666, 0.1364255841430415, 0.16520992359751557, 0.19423623866294415, 0.22347132489134092, 0.25289017232581057, 0.28247324395572265, 0.3122048438683787, 0.3420720779420436, 0.37206415985531244, 0.40217192965325704, 0.4323875090906928, 0.46270404828873163, 0.493115535273975, 0.5236166499862263, 0.554202650463427, 0.5848692827820962, 0.6156127088490789, 0.6464294478206125, 0.6773163280717155, 0.7082704474378629, 0.739289140017611, 0.7703699482334324, 0.8015105991470337, 0.832708984247238, 0.8639631420950986, 0.8952712433374781, 0.9266315776974805, 0.9580425426254616, 0.9895026333532642, 1.0210104341408237, 1.052564610541253, 1.0841639025401355, 1.1158071184486336, 1.1474931294494186, 1.179220864710261, 1.2109893069931357, 1.2427974886974407, 1.2746444882848518, 1.306529427040784, 1.3384514661336602, 1.3704098039384491, 1.4024036735953722, 1.4344323407784412, 1.4664951016517151, 1.4985912809938853, 1.5307202304741792, 1.5628813270645834, 1.5950739715751405, 1.6272975873006033, 1.6595516187680217, 1.6918355305760207, 1.7241488063174952, 1.756490947578351, 1.788861473005679, 1.8212599174394368, 1.8536858311022992, 1.8861387788428812, 1.9186183394279952, 1.9511241048800303, 1.9836556798558964, 2.016212681064329, 2.048794736718619, 2.0814014860221213, 2.114032578684103, 2.146687674463743, 2.179366442740239, 2.2120685621071923, 2.244793719989568, 2.277541612281682, 2.3103119430047827, 2.343104423982924, 2.3759187745359123, 2.4087547211882248, 2.4416119973928634, 2.4744903432692014, 2.507389505353942, 2.5403092363643824, 2.5732492949732224, 2.606209445594226, 2.6391894581780972, 2.672189108017942, 2.705208175563792, 2.7382464462456326, 2.7713037103044877, 2.8043797626310747, 2.8374744026116314, 2.8705874339805075, 2.9037186646791615, 2.936867906721208, 2.9700349760632037, 3.003219692480865, 3.0364218794504323, 3.069641364034914, 3.102877976774974, 3.13613155158421, 3.1694019256486143, 3.202688939330008], [0.0, 0.03405359690083138, 0.07050898880412834, 0.10792953559275666, 0.14599096584887694, 0.18453616691811764, 0.22347132489134092, 0.2627337913530248, 0.30227865228213346, 0.34207207794204353, 0.3820876415809296, 0.4223041121109144, 0.46270404828873163, 0.503272859988785, 0.5439981569912912, 0.5848692827820962, 0.6258769718674743, 0.6670130921471783, 0.7082704474378628, 0.7496426235210556, 0.7911238663240253, 0.8327089842472378, 0.8743932689248127, 0.9161724302558817, 0.9580425426254616, 1.0, 1.0420414781354437, 1.0841639025401355, 1.1263644211348778, 1.1686403807778343, 1.2109893069931357, 1.2534088863734785, 1.2958969512289056, 1.3384514661336602, 1.3810705160859007, 1.423752296045062, 1.466495101651715, 1.5092973209670757, 1.5521574270955523, 1.5950739715751405, 1.6380455784380763, 1.6810709388586922, 1.7241488063174955, 1.7672779922205544, 1.8104573619217186, 1.853685831102299, 1.8969623624688503, 1.9402859627347844, 1.9836556798558964, 2.0270706004935857, 2.070529847682755, 2.114032578684103, 2.157577983002893, 2.201165280558346, 2.244793719989568, 2.288462577085494, 2.332171153327673, 2.3759187745359123, 2.4197047896078465, 2.4635285693444, 2.5073895053539426, 2.5512870090286333, 2.5952205105870902, 2.6391894581780972, 2.683193317040532, 2.727231568715184, 2.7713037103044873, 2.8154092537765925, 2.8595477253104837, 2.9037186646791615, 2.9479216246681545, 2.992156170526862, 3.036421879450432, 3.0807183400900864, 3.125045152089949, 3.169401925648614, 3.2137882811038105, 3.2582038485386713, 3.302648267408203, 3.347121186184684, 3.3916222620208005, 3.4361511604294206, 3.4807075549789945, 3.5252911270036273, 3.5699015653269677, 3.614538565999071, 3.6592018320455098, 3.7038910732279975, 3.7486060058158985, 3.7933463523679922, 3.8381118415239244, 3.8829022078048188, 3.9277171914225475, 3.9725565380971877, 4.01741999888224, 4.062307329997197, 4.107218292667062, 4.1521526529684865, 4.1971101816821745, 4.242090654151233, 4.287093850145173, 4.332119553729296], [0.0, 0.04304458296658674, 0.08912509381337455, 0.1364255841430415, 0.18453616691811764, 0.23325824788420182, 0.28247324395572265, 0.33210196599658054, 0.3820876415809296, 0.43238750909069273, 0.48296816446242274, 0.5338027710795274, 0.5848692827820962, 0.636149257292987, 0.6876270330700435, 0.739289140017611, 0.7911238663240253, 0.8431209328148189, 0.895271243337478, 0.9475666901622963, 1.0, 1.0525646105412527, 1.1052545702959267, 1.158064456471143, 1.2109893069931357, 1.2640245637469165, 1.3171660248063461, 1.3704098039384491, 1.423752296045062, 1.4771901474897324, 1.5307202304741792, 1.5843396207947447, 1.6380455784380765, 1.6918355305760204, 1.7457070565992092, 1.79965787489203, 1.853685831102299, 1.9077888876997975, 1.9619651146509918, 2.0162126810643284, 2.0705298476827547, 2.1249149601184776, 2.179366442740239, 2.2338827931361127, 2.2884625770854936, 2.3431044239829237, 2.3978070226640087, 2.4525691175901017, 2.5073895053539426, 2.5622670314731044, 2.617200587442164, 2.6721891080179425, 2.727231568715184, 2.7823269834926223, 2.8374744026116314, 2.8926729106516356, 2.9479216246681545, 3.003219692480865, 3.0585662910803824, 3.11396062514362, 3.169401925648614, 3.2248894485805932, 3.2804224737218965, 3.33600030351903, 3.3916222620208005, 3.4472876938820294, 3.502995963427841, 3.5587464537739892, 3.6145385659990716, 3.670371718364856, 3.7262453455812654, 3.782158898112861, 3.838111841523924, 3.8941036558594964, 3.950133835059914, 4.006201886406626, 4.062307329997196, 4.118449698247618, 4.1746285354201635, 4.230843397175157, 4.2870938501451725, 4.343379471530259, 4.3996998487129195, 4.456054578891635, 4.512443268731855, 4.568865534033381, 4.625320999413243, 4.681809298003118, 4.7383300711605125, 4.794882968192908, 4.851467646094153, 4.908083769292425, 4.9647310094091495, 5.021409045028258, 5.0781175614752625, 5.1348562506056075, 5.191624810601837, 5.248422945779093, 5.305250366398552, 5.362106788488384, 5.418991933671841, 5.47590552900216], [0.0, 0.052126529696515406, 0.10792953559275666, 0.16520992359751557, 0.22347132489134092, 0.28247324395572265, 0.3420720779420436, 0.40217192965325704, 0.4627040482887316, 0.5236166499862263, 0.5848692827820962, 0.6464294478206125, 0.708270447437863, 0.7703699482334323, 0.832708984247238, 0.8952712433374781, 0.9580425426254616, 1.0210104341408237, 1.0841639025401355, 1.1474931294494186, 1.210989306993136, 1.2746444882848516, 1.3384514661336604, 1.4024036735953722, 1.4664951016517151, 1.5307202304741794, 1.5950739715751407, 1.6595516187680217, 1.7241488063174955, 1.788861473005679, 1.8536858311022992, 1.9186183394279952, 1.9836556798558964, 2.0487947367186194, 2.114032578684103, 2.179366442740239, 2.244793719989568, 2.310311943004783, 2.3759187745359127, 2.4416119973928634, 2.507389505353942, 2.5732492949732224, 2.6391894581780977, 2.705208175563792, 2.7713037103044877, 2.8374744026116314, 2.903718664679162, 2.9700349760632037, 3.0364218794504323, 3.102877976774974, 3.1694019256486143, 3.235992436073254, 3.302648267408203, 3.369368225568033, 3.4361511604294215, 3.5029959634278414, 3.5699015653269677, 3.6368669341455413, 3.703891073227998, 3.7709730194465845, 3.838111841523925, 3.9053066384660884, 3.9725565380971877, 4.039860695687401, 4.107218292667061, 4.1746285354201635, 4.242090654151233, 4.309603901820043, 4.377167553139179, 4.444780903629862, 4.512443268731855, 4.5801539829636155, 4.647912399129205, 4.715717887568728, 4.783569835449343, 4.851467646094154, 4.919410738346441, 4.987398545966972, 5.055430517062233, 5.1235061135416275, 5.191624810601837, 5.259786096236641, 5.327989470770663, 5.396234446415571, 5.464520546847429, 5.532847306803907, 5.6012142717002416, 5.6696209972628155, 5.738067049179405, 5.80655200276512, 5.875075442643178, 5.943636962439691, 6.012236164491718, 6.080872659567834, 6.1495460666006005, 6.218256012430257, 6.287002131559089, 6.355784065915896, 6.424601464630062, 6.493453983814737, 6.562341286358656, 6.631263041726207], [0.0, 0.06128482383098003, 0.12689205695202355, 0.19423623866294415, 0.2627337913530248, 0.33210196599658054, 0.40217192965325704, 0.4728309366087107, 0.5439981569912912, 0.6156127088490789, 0.6876270330700435, 0.7600029209596938, 0.832708984247238, 0.905718965698251, 0.9790105671561281, 1.052564610541253, 1.1263644211348778, 1.2003953639387528, 1.2746444882848516, 1.3491002507743892, 1.423752296045062, 1.498591280993885, 1.573608732173124, 1.6487969288689668, 1.7241488063174955, 1.7996578748920302, 1.8753181520905824, 1.95112410488003, 2.0270706004935857, 2.10315286418365, 2.179366442740239, 2.25570717282168, 2.332171153327673, 2.4087547211882248, 2.4854544300551913, 2.562267031473105, 2.639189458178097, 2.7162188092318416, 2.793352336744663, 2.870587433980508, 2.9479216246681545, 3.025352553369184, 3.102877976774974, 3.1804957558230966, 3.2582038485386713, 3.3360003035190298, 3.413883253990856, 3.4918509123781187, 3.5699015653269677, 3.648033569140398, 3.726245345581266, 3.804535378007152, 3.882902207804819, 3.9613444310957524, 4.039860695687401, 4.118449698247619, 4.1971101816821745, 4.275840932697377, 4.3546407795317235, 4.433508589842146, 4.512443268731855, 4.591443756908113, 4.670509028959372, 4.749638091742242, 4.828829982869662, 4.908083769292426, 4.987398545966972, 5.066773434602939, 5.146207582484604, 5.225700161360823, 5.305250366398552, 5.384857415195447, 5.464520546847428, 5.544239021067427, 5.624012117351839, 5.703839134191492, 5.783719388324194, 5.863652214026139, 5.943636962439692, 6.0236730009352195, 6.103759712504854, 6.183896495186194, 6.264082761514131, 6.344317937999078, 6.424601464630062, 6.504932794401174, 6.585311392860046, 6.665736737677059, 6.7462083182341415, 6.826725635232015, 6.907288200314881, 6.987895535711592, 7.068547173892394, 7.149242657240424, 7.229981537737156, 7.310763376661072, 7.391587744298876, 7.47245421966857, 7.553362390253845, 7.63431185174915, 7.715302207814954, 7.796333069842675], [0.0, 0.07050898880412834, 0.14599096584887694, 0.22347132489134092, 0.30227865228213346, 0.3820876415809296, 0.4627040482887316, 0.5439981569912912, 0.6258769718674743, 0.7082704474378628, 0.7911238663240253, 0.8743932689248127, 0.9580425426254617, 1.0420414781354437, 1.1263644211348778, 1.2109893069931357, 1.2958969512289056, 1.3810705160859007, 1.466495101651715, 1.5521574270955523, 1.6380455784380765, 1.724148806317495, 1.8104573619217188, 1.8969623624688503, 1.9836556798558964, 2.070529847682755, 2.157577983002893, 2.244793719989568, 2.332171153327673, 2.4197047896078465, 2.5073895053539426, 2.5952205105870902, 2.6831933170405327, 2.7713037103044873, 2.8595477253104837, 2.947921624668155, 3.036421879450432, 3.1250451520899496, 3.213788281103811, 3.302648267408203, 3.3916222620208005, 3.480707554978994, 3.5699015653269677, 3.6592018320455098, 3.7486060058158985, 3.8381118415239244, 3.927717191422548, 4.017419998882241, 4.107218292667061, 4.1971101816821745, 4.287093850145173, 4.377167553139178, 4.467329612510646, 4.5575784130790415, 4.647912399129205, 4.7383300711605125, 4.828829982869662, 4.919410738346441, 5.0100709894639675, 5.100809433446775, 5.191624810601837, 5.282515902199047, 5.37348152848905, 5.464520546847428, 5.5556318500353195, 5.646814364567451, 5.738067049179405, 5.8293888933866675, 5.920778916128685, 6.012236164491718, 6.103759712504854, 6.195348660003999, 6.287002131559087, 6.378719275460197, 6.470499262758534, 6.562341286358655, 6.654244560158496, 6.7462083182341415, 6.838231814066422, 6.930314319806697, 7.02245512557937, 7.1146535388188505, 7.206908883638872, 7.299220500232188, 7.391587744298875, 7.4840099865015, 7.576486611945648, 7.669017019684282, 7.761600622244654, 7.854236845176434, 7.9469251266199095, 8.039664916893145, 8.132455678097065, 8.225296883737503, 8.3181880183633, 8.411128577219635, 8.504118065915756, 8.597156000106388, 8.690241905186134, 8.783375315996192, 8.876555776542762, 8.969782839726605], [0.0, 0.0797911335508692, 0.16520992359751557, 0.25289017232581057, 0.34207207794204353, 0.43238750909069273, 0.5236166499862263, 0.6156127088490789, 0.7082704474378628, 0.8015105991470337, 0.895271243337478, 0.9895026333532643, 1.0841639025401355, 1.1792208647102609, 1.2746444882848516, 1.3704098039384491, 1.4664951016517151, 1.5628813270645834, 1.6595516187680215, 1.756490947578351, 1.8536858311022992, 1.9511241048800299, 2.0487947367186194, 2.1466876744637435, 2.244793719989568, 2.343104423982924, 2.4416119973928634, 2.540309236364383, 2.6391894581780972, 2.7382464462456326, 2.8374744026116314, 2.9368679067212073, 3.036421879450432, 3.1361315515842096, 3.2359924360732535, 3.33600030351903, 3.436151160429421, 3.53644122986353, 3.6368669341455413, 3.7374248793777247, 3.838111841523924, 3.938924753868929, 4.039860695687401, 4.14091688197964, 4.242090654151233, 4.34337947153026, 4.444780903629862, 4.54629262307584, 4.647912399129205, 4.749638091742242, 4.851467646094154, 4.9533990875587515, 5.0554305170622325, 5.157560106793874, 5.259786096236642, 5.362106788488384, 5.464520546847428, 5.567025791639184, 5.6696209972628155, 5.772304689439187, 5.875075442643178, 5.977931877705152, 6.0808726595678335, 6.183896495186195, 6.287002131559087, 6.390188353882437, 6.493453983814736, 6.596797877846397, 6.700218925765301, 6.803716049211532, 6.907288200314882, 7.010934360409294, 7.114653538818851, 7.218444771710412, 7.322307121008349, 7.426239673367265, 7.530241539198816, 7.634311851749149, 7.7384497662237, 7.842654458956305, 7.9469251266199095, 8.051260985476233, 8.155661270662067, 8.260125235509946, 8.364652150901183, 8.469241304649318, 8.573892000912254, 8.67860355963138, 8.78337531599619, 8.88820661993293, 8.993096835615955, 9.098045341000534, 9.203051527375957, 9.308114798937808, 9.413234572378451, 9.518410276494691, 9.623641351811782, 9.728927250222894, 9.834267434643278, 9.93966137867837, 10.045108566305142, 10.150608491566045], [0.0, 0.08912509381337455, 0.18453616691811767, 0.28247324395572265, 0.3820876415809296, 0.48296816446242274, 0.5848692827820962, 0.6876270330700435, 0.7911238663240253, 0.895271243337478, 1.0, 1.1052545702959267, 1.210989306993136, 1.3171660248063461, 1.423752296045062, 1.5307202304741792, 1.6380455784380765, 1.7457070565992094, 1.853685831102299, 1.9619651146509918, 2.070529847682755, 2.1793664427402386, 2.288462577085494, 2.3978070226640087, 2.5073895053539426, 2.617200587442164, 2.727231568715184, 2.8374744026116314, 2.947921624668155, 3.0585662910803824, 3.169401925648614, 3.2804224737218965, 3.391622262020801, 3.502995963427841, 3.6145385659990716, 3.726245345581266, 3.8381118415239244, 3.9501338350599147, 4.062307329997197, 4.1746285354201635, 4.2870938501451725, 4.3996998487129195, 4.512443268731855, 4.625320999413243, 4.7383300711605125, 4.851467646094153, 4.96473100940915, 5.0781175614752625, 5.191624810601837, 5.305250366398552, 5.418991933671841, 5.532847306803908, 5.646814364567451, 5.760891065334599, 5.875075442643178, 5.989365601087563, 6.103759712504854, 6.218256012430256, 6.3328527967982735, 6.447548418868717, 6.562341286358655, 6.6772298587633, 6.792212644850485, 6.907288200314882, 7.02245512557937, 7.137712063732194, 7.253057698589553, 7.3684907528742025, 7.484009986501502, 7.599614194965078, 7.715302207814953, 7.831072887221599, 7.9469251266199095, 8.062857849427623, 8.178870007833101, 8.294960581647878, 8.411128577219635, 8.52737302640173, 8.643692985575594, 8.760087534722668, 8.87655577654276, 8.993096835615953, 9.109709857605402, 9.226394008498541, 9.34314847388444, 9.459972458265126, 9.576865184398951, 9.693825892674102, 9.810853840510594, 9.9279483017891, 10.04510856630514, 10.162333939247247, 10.279623740697778, 10.396977305155168, 10.514393981076498, 10.631873130439272, 10.749414128321435, 10.867016362498662, 10.984679233058076, 11.102402152027521, 11.220184543019636, 11.33802584089], [0.0, 0.09850591726528544, 0.20395944187114154, 0.3122048438683787, 0.4223041121109144, 0.5338027710795274, 0.6464294478206125, 0.7600029209596938, 0.8743932689248127, 0.9895026333532643, 1.1052545702959267, 1.2215876651600335, 1.3384514661336604, 1.455803768755732, 1.5736087321731238, 1.6918355305760207, 1.8104573619217188, 1.929450702704126, 2.048794736718619, 2.1684709097291806, 2.288462577085494, 2.4087547211882248, 2.5293337222749366, 2.6501871704870643, 2.7713037103044877, 2.892672910651636, 3.0142851555777868, 3.13613155158421, 3.2582038485386717, 3.3804943717696543, 3.5029959634278414, 3.6257019315825953, 3.748606005815899, 3.871702298306804, 3.994985269581359, 4.118449698247619, 4.242090654151233, 4.365903474480547, 4.489883742426046, 4.6140272680609264, 4.7383300711605125, 4.8627883657202515, 4.987398545966973, 5.11215717368721, 5.2370609667207795, 5.362106788488384, 5.487291638439372, 5.61261264332054, 5.7380670491794055, 5.863652214026139, 5.989365601087564, 6.115204772594528, 6.241167384050864, 6.3672511789380355, 6.493453983814737, 6.619773703775239, 6.7462083182341415, 6.872755877008665, 6.9994144966726335, 7.126182357158925, 7.253057698589554, 7.380038818314563, 7.507124068142782, 7.63431185174915, 7.7616006222446545, 7.888988879896378, 8.01647516998616, 8.144058080797485, 8.271736241721142, 8.399508321470952, 8.52737302640173, 8.65532909892219, 8.78337531599619, 8.911510487726266, 9.039733456013817, 9.168043093290875, 9.296438301318677, 9.424918010048719, 9.553481176542268, 9.682126783944605, 9.810853840510594, 9.939661378678368, 10.068548454188226, 10.197514145243968, 10.32655755171419, 10.455677794371123, 10.584874014164884, 10.714145371531043, 10.843491045729678, 10.972910234214085, 11.10240215202752, 11.231966031226428, 11.361601120328729, 11.491306683785778, 11.621082001476783, 11.750926368224466, 11.88083909333087, 12.010819500132262, 12.140866925572192, 12.27098071979175, 12.401160245736166, 12.53140487877699], [0.0, 0.10792953559275667, 0.22347132489134097, 0.3420720779420436, 0.46270404828873163, 0.5848692827820962, 0.708270447437863, 0.832708984247238, 0.9580425426254617, 1.0841639025401355, 1.210989306993136, 1.3384514661336604, 1.4664951016517156, 1.5950739715751407, 1.7241488063174957, 1.8536858311022995, 1.9836556798558966, 2.1140325786841037, 2.2447937199895684, 2.3759187745359127, 2.507389505353943, 2.6391894581780972, 2.771303710304488, 2.9037186646791624, 3.0364218794504327, 3.169401925648615, 3.3026482674082036, 3.436151160429422, 3.569901565326968, 3.7038910732279984, 3.8381118415239253, 3.972556538097188, 4.107218292667062, 4.242090654151234, 4.377167553139179, 4.512443268731856, 4.647912399129206, 4.783569835449344, 4.919410738346442, 5.055430517062233, 5.191624810601837, 5.327989470770663, 5.46452054684743, 5.601214271700242, 5.7380670491794055, 5.875075442643179, 6.012236164491719, 6.149546066600601, 6.287002131559089, 6.424601464630063, 6.562341286358657, 6.700218925765303, 6.838231814066423, 6.976377478872495, 7.114653538818853, 7.253057698589555, 7.391587744298876, 7.5302415391988164, 7.669017019684284, 7.807912191570517, 7.946925126619911, 8.086053959297644, 8.225296883737503, 8.364652150901184, 8.504118065915756, 8.643692985575596, 8.783375315996192, 8.923163510408461, 9.063056067083162, 9.203051527375958, 9.343148473884442, 9.48334552870922, 9.623641351811782, 9.764034639462523, 9.90452412277275, 10.045108566305144, 10.185786766757367, 10.32655755171419, 10.467419778463618, 10.608372332873012, 10.749414128321435, 10.890544104684727, 11.031761227370104, 11.17306448639727, 11.314452895523294, 11.455925491408637, 11.597481332821976, 11.739119499881529, 11.88083909333087, 12.022639233847261, 12.164519061380675, 12.306477734521849, 12.44851442989779, 12.590628341593218, 12.732818680596628, 12.875084674269596, 13.017425565838199, 13.159840613905322, 13.302329091982891, 13.444890288042908, 13.587523504086445, 13.730228055729647], [0.0, 0.11739254552865523, 0.2430647694125374, 0.37206415985531244, 0.503272859988785, 0.636149257292987, 0.7703699482334323, 0.905718965698251, 1.0420414781354437, 1.1792208647102609, 1.3171660248063461, 1.455803768755732, 1.5950739715751407, 1.734926336904152, 1.8753181520905824, 2.0162126810643284, 2.157577983002893, 2.299386024217168, 2.441611997392863, 2.584233790873574, 2.727231568715184, 2.8705874339805075, 3.0142851555777868, 3.158309944295093, 3.302648267408203, 3.4472876938820294, 3.5922167640909546, 3.7374248793777243, 3.882902207804819, 4.0286396032290375, 4.1746285354201635, 4.320861029397671, 4.467329612510646, 4.614027268060926, 4.760947394486228, 4.908083769292426, 5.0554305170622325, 5.202982080978915, 5.35073319739409, 5.498678873042516, 5.64681436456745, 5.795135160070279, 5.943636962439692, 6.092315674250457, 6.241167384050864, 6.3901883538824364, 6.539375007896249, 6.688723921947668, 6.838231814066422, 6.987895535711592, 7.137712063732194, 7.287678492963401, 7.437792029396682, 7.58804998386917, 7.738449766223699, 7.888988879896377, 8.039664916893145, 8.190475553120923, 8.341418544042533, 8.49249172062775, 8.643692985575594, 8.795020309785496, 8.946471729057112, 9.098045341000534, 9.249739302140329, 9.401551825198435, 9.553481176542268, 9.705525673785633, 9.85768368353118, 10.009953619244031, 10.162333939247247, 10.314823144830429, 10.467419778463615, 10.620122422109226, 10.772929695625376, 10.925840255254473, 11.078852792191444, 11.231966031226428, 11.385178729457103, 11.538489675066282, 11.691897686160637, 11.845401609666796, 11.999000320281294, 12.152692719471114, 12.306477734521849, 12.460354317630594, 12.614321445041062, 12.768378116218377, 12.922523353061413, 13.076756199150463, 13.231075719028317, 13.385480997512913, 13.539971139039833, 13.69454526703303, 13.849202523302303, 14.0039420674661, 14.15876307639832, 14.313664743697881, 14.468646279179929, 14.623706908387513, 14.778845872122783, 14.93406242599671], [0.0, 0.12689205695202357, 0.2627337913530248, 0.40217192965325704, 0.5439981569912912, 0.6876270330700435, 0.832708984247238, 0.9790105671561281, 1.1263644211348778, 1.2746444882848516, 1.423752296045062, 1.5736087321731238, 1.7241488063174957, 1.8753181520905824, 2.0270706004935857, 2.179366442740239, 2.332171153327673, 2.4854544300551913, 2.6391894581780972, 2.793352336744663, 2.947921624668155, 3.1028779767749737, 3.2582038485386717, 3.413883253990856, 3.5699015653269677, 3.7262453455812663, 3.882902207804819, 4.039860695687401, 4.1971101816821745, 4.3546407795317235, 4.512443268731855, 4.670509028959372, 4.828829982869662, 4.987398545966972, 5.146207582484604, 5.305250366398552, 5.464520546847428, 5.62401211735184, 5.783719388324195, 5.943636962439692, 6.103759712504854, 6.264082761514131, 6.424601464630062, 6.585311392860046, 6.7462083182341415, 6.907288200314882, 7.068547173892396, 7.229981537737156, 7.391587744298875, 7.553362390253845, 7.715302207814954, 7.8774040567288015, 8.039664916893146, 8.202081881535618, 8.364652150901183, 8.52737302640173, 8.690241905186134, 8.853256275093589, 9.016413709956934, 9.179711865226045, 9.34314847388444, 9.506721342634894, 9.67042834833218, 9.834267434643277, 9.998236608917042, 10.16233393924725, 10.32655755171419, 10.490905627791452, 10.655376401905686, 10.819968159138174, 10.984679233058076, 11.149508003677983, 11.31445289552329, 11.479512375807527, 11.644684952706472, 11.809969173724449, 11.975363624146691, 12.14086692557219, 12.306477734521849, 12.472194741117125, 12.638016667824813, 12.803942268263794, 12.969970326070026, 13.136099653816201, 13.30232909198289, 13.468657507978023, 13.635083795202021, 13.801606872155824, 13.968225681589473, 14.134939189688904, 14.301746385298864, 14.468646279179927, 14.63563790329779, 14.802720310143071, 14.969892572080044, 15.137153780722715, 15.30450304633687, 15.471939497266726, 15.639462279384945, 15.80707055556482, 15.97476350517352, 16.14254032358538], [0.0, 0.13642558414304154, 0.28247324395572265, 0.4323875090906928, 0.5848692827820962, 0.739289140017611, 0.8952712433374781, 1.052564610541253, 1.2109893069931357, 1.3704098039384491, 1.5307202304741792, 1.6918355305760207, 1.8536858311022995, 2.0162126810643284, 2.179366442740239, 2.343104423982924, 2.5073895053539426, 2.672189108017943, 2.8374744026116314, 3.0032196924808656, 3.169401925648614, 3.33600030351903, 3.5029959634278414, 3.6703717183648568, 3.838111841523925, 4.006201886406627, 4.1746285354201635, 4.34337947153026, 4.512443268731855, 4.6818092980031185, 4.851467646094154, 5.021409045028259, 5.191624810601837, 5.362106788488384, 5.532847306803908, 5.703839134191493, 5.875075442643178, 6.046549774406766, 6.218256012430257, 6.390188353882437, 6.562341286358655, 6.734709566439052, 6.907288200314883, 7.0800724262389005, 7.253057698589553, 7.426239673367265, 7.599614194965079, 7.77317728407639, 7.946925126619911, 8.120854063576816, 8.294960581647878, 8.46924130464932, 8.643692985575594, 8.818312499265616, 8.993096835615955, 9.168043093290875, 9.34314847388444, 9.518410276494691, 9.693825892674104, 9.869392801724151, 10.045108566305142, 10.22097082833523, 10.396977305155168, 10.573125785937576, 10.749414128321433, 10.925840255254473, 11.102402152027521, 11.279097863486458, 11.455925491408637, 11.632883192031787, 11.809969173724449, 11.987181694787942, 12.164519061380673, 12.341979625556394, 12.519561783408635, 12.697263973314271, 12.875084674269594, 13.053022404312953, 13.231075719028318, 13.409243210124666, 13.587523504086441, 13.765915260890663, 13.944417172786643, 14.123027963134472, 14.301746385298866, 14.48057122159498, 14.659501282283305, 14.838535404610667, 15.017672451894862, 15.196911312650345, 15.376250899752756, 15.55569014964012, 15.735228021548746, 15.91486349678193, 16.09459557800974, 16.274423288598236, 16.454345671966585, 16.634361790970626, 16.814470727311587, 16.99467158096859, 17.17496346965384, 17.355345528289337], [0.0, 0.14599096584887694, 0.3022786522821335, 0.46270404828873163, 0.6258769718674743, 0.7911238663240253, 0.9580425426254616, 1.1263644211348778, 1.2958969512289056, 1.4664951016517151, 1.6380455784380765, 1.8104573619217188, 1.9836556798558966, 2.157577983002893, 2.332171153327673, 2.5073895053539426, 2.6831933170405327, 2.859547725310484, 3.036421879450432, 3.213788281103811, 3.391622262020801, 3.5699015653269672, 3.7486060058158994, 3.9277171914225484, 4.107218292667062, 4.287093850145173, 4.467329612510646, 4.647912399129205, 4.828829982869662, 5.0100709894639675, 5.191624810601837, 5.37348152848905, 5.55563185003532, 5.738067049179405, 5.920778916128685, 6.103759712504855, 6.287002131559087, 6.470499262758535, 6.654244560158497, 6.838231814066422, 7.02245512557937, 7.206908883638872, 7.391587744298876, 7.576486611945648, 7.761600622244654, 7.94692512661991, 8.132455678097067, 8.318188018363301, 8.504118065915756, 8.690241905186134, 8.876555776542762, 9.063056067083162, 9.24973930214033, 9.436602137434761, 9.623641351811782, 9.810853840510596, 9.998236608917042, 10.185786766757365, 10.37350152269462, 10.561378179293314, 10.749414128321435, 10.937606846361925, 11.12595389070853, 11.314452895523292, 11.503101568235094, 11.691897686160639, 11.880839093330868, 12.069923697507441, 12.259149467375194, 12.448514429897788, 12.638016667824814, 12.827654317339642, 13.017425565838193, 13.207328649829655, 13.397361852950807, 13.587523504086443, 13.777811975588774, 13.968225681589471, 14.15876307639832, 14.349422652982977, 14.540202941524836, 14.731102508046169, 14.92211995310429, 15.113253910548597, 15.30450304633687, 15.49586605740717, 15.687341670602256, 15.878928641643354, 16.0706257541506, 16.262431818707444, 16.454345671966582, 16.646366175795155, 16.838492216457077, 17.030722703830453, 17.223056570658283, 17.415492771830642, 17.608030283696717, 17.80066810340516, 17.993405248271344, 18.186240755170065, 18.379173679952565, 18.57220309688652], [0.0, 0.1555863051900745, 0.3221460887867276, 0.493115535273975, 0.6670130921471783, 0.8431209328148189, 1.0210104341408237, 1.2003953639387528, 1.3810705160859007, 1.5628813270645834, 1.7457070565992094, 1.929450702704126, 2.1140325786841037, 2.299386024217168, 2.4854544300551913, 2.672189108017943, 2.859547725310484, 3.0474931274602755, 3.2359924360732535, 3.4250163454477134, 3.614538565999072, 3.8045353780071514, 3.9949852695813592, 4.1858686398277, 4.377167553139179, 4.568865534033383, 4.760947394486228, 4.9533990875587515, 5.146207582484604, 5.339360757415495, 5.532847306803908, 5.7266566610029495, 5.920778916128685, 6.115204772594528, 6.309925481014567, 6.504932794401175, 6.700218925765301, 6.8957765103753905, 7.091598572050801, 7.287678492963402, 7.484009986501501, 7.680587072816618, 7.8774040567288015, 8.074455507712207, 8.271736241721142, 8.46924130464932, 8.66696595724247, 8.864905661307736, 9.063056067083162, 9.261413001647494, 9.459972458265128, 9.658730586573514, 9.85768368353118, 10.056828185053947, 10.25616065827492, 10.455677794371125, 10.655376401905686, 10.85525340063996, 11.055305815774785, 11.255530772584194, 11.455925491408637, 11.656487282978036, 11.857213544037872, 12.058101753254144, 12.259149467375194, 12.460354317630598, 12.661714006349005, 12.863226303778516, 13.064889045094626, 13.266700127582057, 13.468657507978024, 13.67075919996549, 13.873003271805942, 14.075387844102126, 14.277911087681876, 14.480571221594984, 14.683366511215587, 14.886295266443256, 15.089355839996404, 15.292546625792134, 15.495866057407172, 15.69931260661479, 15.90288478199313, 16.10658112760057, 16.3104002217142, 16.5143406756276, 16.71840113250454, 16.922580266285312, 17.1268767806428, 17.33128940798537, 17.535816908504053, 17.74045806926156, 17.945211703320872, 18.15007664891121, 18.355051768629497, 18.560135948675367, 18.76532809811797, 18.970627148192985, 19.176032051628276, 19.38154178199669, 19.587155333094756, 19.792871718345857], [0.0, 0.16520992359751557, 0.34207207794204353, 0.5236166499862263, 0.7082704474378628, 0.895271243337478, 1.0841639025401355, 1.2746444882848516, 1.466495101651715, 1.6595516187680215, 1.853685831102299, 2.048794736718619, 2.2447937199895684, 2.441611997392863, 2.6391894581780972, 2.8374744026116314, 3.036421879450432, 3.2359924360732535, 3.436151160429421, 3.636866934145541, 3.8381118415239244, 4.0398606956874, 4.242090654151233, 4.444780903629862, 4.647912399129205, 4.851467646094154, 5.0554305170622325, 5.259786096236641, 5.464520546847428, 5.669620997262815, 5.875075442643178, 6.0808726595678335, 6.287002131559087, 6.493453983814736, 6.700218925765301, 6.907288200314882, 7.114653538818851, 7.3223071210083495, 7.530241539198816, 7.738449766223699, 7.9469251266199095, 8.155661270662067, 8.364652150901183, 8.573892000912254, 8.78337531599619, 8.993096835615955, 9.203051527375957, 9.413234572378451, 9.623641351811782, 9.834267434643277, 10.045108566305142, 10.256160658274919, 10.467419778463615, 10.678882142334574, 10.890544104684727, 11.102402152027521, 11.31445289552329, 11.526693064408647, 11.739119499881527, 11.951729149402972, 12.164519061380673, 12.377486380202734, 12.590628341593217, 12.803942268263796, 13.017425565838193, 13.231075719028318, 13.444890288042904, 13.658866905211221, 13.873003271805942, 14.087297155050669, 14.301746385298864, 14.516348853372051, 14.73110250804617, 14.946005353675938, 15.161055447947769, 15.376250899752756, 15.591589867171677, 15.807070555564817, 16.022691215759806, 16.238450142331278, 16.454345671966582, 16.670376181912214, 16.886540088496076, 17.10283584572089, 17.319261943924655, 17.53581690850405, 17.75249929869724, 17.96930770642258, 18.18624075517006, 18.403297098942584, 18.62047542124417, 18.837774434112635, 19.055192877194283, 19.2727295168583, 19.490383145348797, 19.708152579972523, 19.926036662320314, 20.144034257520612, 20.362144253523425, 20.58036556041309, 20.798697109748524, 21.017137853929523], [0.0, 0.1748603249018378, 0.36205352188475926, 0.554202650463427, 0.7496426235210556, 0.9475666901622963, 1.1474931294494186, 1.3491002507743892, 1.5521574270955523, 1.756490947578351, 1.9619651146509918, 2.1684709097291806, 2.3759187745359127, 2.584233790873574, 2.793352336744663, 3.0032196924808656, 3.213788281103811, 3.4250163454477134, 3.636866934145541, 3.8493071111074793, 4.062307329997197, 4.275840932697377, 4.489883742426046, 4.704413730131945, 4.919410738346442, 5.134856250605608, 5.35073319739409, 5.567025791639184, 5.783719388324195, 6.000800363947181, 6.218256012430257, 6.436074454759471, 6.654244560158497, 6.872755877008665, 7.0915985720508, 7.310763376661073, 7.530241539198816, 7.750024782590088, 7.970105266445516, 8.190475553120923, 8.411128577219635, 8.632057618109995, 8.853256275093589, 9.074718444911444, 9.296438301318677, 9.518410276494691, 9.740629044086758, 9.963089503711029, 10.185786766757367, 10.408716143363351, 10.631873130439274, 10.85525340063996, 11.078852792191446, 11.302667299491072, 11.526693064408649, 11.750926368224468, 11.975363624146691, 12.200001370356947, 12.424836263538179, 12.649865072843582, 12.875084674269596, 13.100492045399564, 13.326084260487999, 13.551858485858231, 13.777811975588774, 14.003942067466102, 14.230246179183512, 14.456721804767607, 14.683366511215587, 14.910177935327964, 15.137153780722715, 15.364291815017998, 15.591589867171677, 15.819045824966915, 16.046657632633828, 16.274423288598236, 16.502340843348954, 16.730408397416046, 16.958624099452795, 17.186986144414885, 17.41549277183064, 17.644142264156724, 17.872932945214053, 18.101863178699066, 18.330931366765924, 18.560135948675363, 18.78947539950638, 19.018948228927098, 19.24855298002149, 19.47828822816877, 19.708152579972523, 19.93814467223689, 20.16826317098717, 20.39850677053252, 20.62887419256845, 20.859364185317087, 21.089975522703156, 21.32070700356389, 21.551557450891156, 21.782525711104093, 22.013610653350806, 22.244811168837654], [0.0, 0.18453616691811767, 0.38208764158092967, 0.5848692827820962, 0.7911238663240253, 1.0, 1.210989306993136, 1.423752296045062, 1.6380455784380765, 1.8536858311022992, 2.070529847682755, 2.288462577085494, 2.507389505353943, 2.727231568715184, 2.947921624668155, 3.169401925648614, 3.391622262020801, 3.614538565999072, 3.8381118415239244, 4.062307329997197, 4.287093850145173, 4.512443268731854, 4.738330071160513, 4.96473100940915, 5.191624810601837, 5.418991933671841, 5.646814364567452, 5.875075442643178, 6.103759712504855, 6.3328527967982735, 6.562341286358655, 6.792212644850485, 7.022455125579371, 7.253057698589553, 7.484009986501502, 7.715302207814954, 7.94692512661991, 8.178870007833103, 8.411128577219637, 8.643692985575594, 8.87655577654276, 9.109709857605402, 9.34314847388444, 9.576865184398951, 9.810853840510594, 10.04510856630514, 10.27962374069778, 10.5143939810765, 10.749414128321435, 10.984679233058076, 11.220184543019636, 11.455925491408637, 11.691897686160639, 11.928096900024192, 12.164519061380675, 12.401160245736165, 12.638016667824814, 12.875084674269594, 13.11236073675204, 13.349841445647433, 13.587523504086441, 13.82540372240792, 14.06347901297116, 14.301746385298866, 14.540202941524836, 14.778845872122783, 15.017672451894862, 15.256680036200413, 15.495866057407174, 15.735228021548746, 15.97476350517352, 16.21447015237149, 16.454345671966582, 16.694387834863083, 16.934594471535725, 17.17496346965384, 17.415492771830642, 17.656180373489608, 17.897024320840334, 18.138022708956928, 18.37917367995256, 18.620475421244166, 18.861926163901806, 19.10352418107757, 19.345267786509318, 19.58715533309475, 19.82918521153184, 20.071355849021657, 20.313665708030175, 20.556113285105653, 20.79869710974852, 21.041415743330898, 21.284267778063004, 21.527251836003995, 21.7703665681148, 22.013610653350803, 22.256982797792237, 22.50048173381036, 22.74410621926766, 22.987855036750236, 23.23172699283085, 23.475720917361112], [0.0, 0.19423623866294415, 0.402171929653257, 0.6156127088490789, 0.8327089842472378, 1.0525646105412527, 1.2746444882848516, 1.498591280993885, 1.724148806317495, 1.9511241048800299, 2.1793664427402386, 2.4087547211882248, 2.6391894581780972, 2.8705874339805075, 3.1028779767749737, 3.33600030351903, 3.5699015653269672, 3.8045353780071514, 4.0398606956874, 4.275840932697377, 4.512443268731854, 4.749638091742241, 4.987398545966972, 5.225700161360823, 5.464520546847428, 5.703839134191492, 5.943636962439691, 6.183896495186195, 6.4246014646300615, 6.665736737677058, 6.907288200314881, 7.149242657240424, 7.391587744298874, 7.634311851749149, 7.8774040567288, 8.120854063576814, 8.36465215090118, 8.608789124462383, 8.853256275093589, 9.098045341000534, 9.343148473884439, 9.588558208414241, 9.834267434643277, 10.080269373022965, 10.326557551714188, 10.573125785937572, 10.819968159138174, 11.067079005769077, 11.31445289552329, 11.562084618864361, 11.809969173724447, 12.058101753254142, 12.306477734521847, 12.55509266807229, 12.803942268263796, 13.053022404312953, 13.302329091982886, 13.551858485858228, 13.801606872155824, 14.051570662025366, 14.301746385298863, 14.55213068465188, 14.80272031014307, 15.05351211410187, 15.304503046336867, 15.55569014964012, 15.807070555564817, 16.058641480455794, 16.3104002217142, 16.562344154279263, 16.814470727311583, 17.066777461063666, 17.31926194392465, 17.57192182962729, 17.824754834606054, 18.077758735496435, 18.33093136676592, 18.5842706184682, 18.837774434112635, 19.091440808641646, 19.34526778650931, 19.599253459854836, 19.85339596676517, 20.107693489621315, 20.36214425352342, 20.616746524789896, 20.87149860952638, 21.126398852260376, 21.38144563463798, 21.636637374179102, 21.891972523087933, 22.147449567115668, 22.40306702447262, 22.65882344478701, 22.914717408108064, 23.17074752395096, 23.42691243038155, 23.683210793138677, 23.93964130479235, 24.196202683935788, 24.452893674409715, 24.70971304455734], [0.0, 0.20395944187114154, 0.42230411211091445, 0.6464294478206125, 0.8743932689248127, 1.1052545702959267, 1.3384514661336604, 1.573608732173124, 1.8104573619217188, 2.0487947367186194, 2.288462577085494, 2.5293337222749366, 2.771303710304488, 3.0142851555777868, 3.2582038485386717, 3.5029959634278414, 3.7486060058158994, 3.9949852695813592, 4.242090654151233, 4.489883742426046, 4.738330071160513, 4.987398545966972, 5.237060966720781, 5.487291638439373, 5.7380670491794055, 5.989365601087564, 6.241167384050865, 6.493453983814737, 6.746208318234142, 6.9994144966726335, 7.253057698589554, 7.507124068142783, 7.7616006222446545, 8.01647516998616, 8.271736241721142, 8.527373026401731, 8.78337531599619, 9.039733456013819, 9.296438301318679, 9.553481176542268, 9.810853840510594, 10.068548454188226, 10.32655755171419, 10.584874014164884, 10.843491045729678, 11.102402152027521, 11.36160112032873, 11.621082001476784, 11.88083909333087, 12.140866925572192, 12.401160245736166, 12.661714006349007, 12.922523353061415, 13.183583613684414, 13.444890288042906, 13.706439038572054, 13.968225681589473, 14.230246179183512, 14.492496631664055, 14.754973270527806, 15.017672451894864, 15.280590650377672, 15.54372445334722, 15.80707055556482, 16.0706257541506, 16.334386943862796, 16.59835111266403, 16.86251533755313, 17.1268767806428, 17.391432685465283, 17.656180373489608, 17.921117240835482, 18.186240755170065, 18.451548452775143, 18.717037935772993, 18.982706869500493, 19.248552980021493, 19.51457405176863, 19.780767925306133, 20.04713249520595, 20.313665708030175, 20.580365560413085, 20.84723009723679, 21.114257409894734, 21.381445634637988, 21.648792950999205, 21.916297580289967, 22.183957784167067, 22.451771863263993, 22.719738155883835, 22.987855036750233, 23.256120915813135, 23.52453423710646, 23.793093477654793, 24.06179714642653, 24.330643783331077, 24.599631958257692, 24.86876027015392, 25.13802734614159, 25.407431840668437, 25.676972434693543, 25.946647834905054], [0.0, 0.2137047758412981, 0.44248211697176026, 0.6773163280717155, 0.9161724302558817, 1.158064456471143, 1.4024036735953722, 1.6487969288689668, 1.8969623624688503, 2.1466876744637435, 2.3978070226640087, 2.6501871704870643, 2.9037186646791624, 3.158309944295093, 3.413883253990856, 3.6703717183648568, 3.9277171914225484, 4.1858686398277, 4.444780903629862, 4.704413730131945, 4.96473100940915, 5.225700161360823, 5.487291638439373, 5.749478517936838, 6.012236164491719, 6.27554194828919, 6.53937500789625, 6.803716049211532, 7.068547173892396, 7.333851732035951, 7.599614194965079, 7.865820044795203, 8.132455678097067, 8.399508321470952, 8.66696595724247, 8.934817257803836, 9.203051527375957, 9.471658650169376, 9.740629044086758, 10.009953619244033, 10.279623740697778, 10.549631194857614, 10.819968159138176, 11.090627174468386, 11.361601120328729, 11.632883192031787, 11.904466879999033, 12.176345950818815, 12.44851442989779, 12.720966585541253, 12.993696914317956, 13.266700127582057, 13.539971139039835, 13.813505053261643, 14.087297155050672, 14.361342899590001, 14.635637903297791, 14.910177935327964, 15.184958909660308, 15.459976877729634, 15.735228021548748, 16.01070864728445, 16.286415179249772, 16.562344154279266, 16.838492216457077, 17.11485611217067, 17.391432685465283, 17.668218873676572, 17.945211703320876, 18.22240828622435, 18.499805815873824, 18.777401563973665, 19.055192877194287, 19.33317717409918, 19.611351942238247, 19.889714735396414, 20.168263170987174, 20.44699492758171, 20.725907742564793, 21.004999409909455, 21.284267778063004, 21.563710747937407, 21.843326270997782, 22.123112347442937, 22.403067024472627, 22.683188394636225, 22.96347459425825, 23.243923801936166, 23.52453423710646, 23.80530415867512, 24.086231863708857, 24.36731568618385, 24.6485539957888, 24.929945196779382, 25.211487726881412, 25.493180056240064, 25.77502068641285, 26.05700814940398, 26.339141006738153, 26.621417848571593, 26.903837292838645, 27.186397984432045], [0.0, 0.22347132489134094, 0.46270404828873163, 0.7082704474378629, 0.9580425426254616, 1.2109893069931357, 1.4664951016517151, 1.7241488063174955, 1.9836556798558964, 2.244793719989568, 2.5073895053539426, 2.7713037103044877, 3.0364218794504327, 3.302648267408203, 3.5699015653269677, 3.838111841523925, 4.107218292667062, 4.377167553139179, 4.647912399129205, 4.919410738346442, 5.191624810601837, 5.464520546847428, 5.7380670491794055, 6.012236164491719, 6.287002131559089, 6.562341286358656, 6.838231814066422, 7.114653538818852, 7.391587744298876, 7.669017019684283, 7.946925126619911, 8.225296883737503, 8.504118065915756, 8.783375315996192, 9.063056067083162, 9.34314847388444, 9.623641351811782, 9.904524122772752, 10.185786766757367, 10.467419778463617, 10.749414128321433, 11.031761227370103, 11.314452895523292, 11.597481332821975, 11.880839093330868, 12.164519061380673, 12.44851442989779, 12.732818680596628, 13.017425565838197, 13.30232909198289, 13.587523504086443, 13.873003271805944, 14.158763076398317, 14.444797798707267, 14.731102508046174, 15.017672451894864, 15.304503046336869, 15.59158986717168, 15.878928641643355, 16.166515240732828, 16.454345671966582, 16.742416072699086, 17.030722703830453, 17.31926194392466, 17.608030283696714, 17.897024320840334, 18.186240755170065, 18.475676384054346, 18.76532809811797, 19.055192877194287, 19.345267786509318, 19.635549973081236, 19.92603666232031, 20.216725154815478, 20.507612823294835, 20.798697109748524, 21.089975522703153, 21.381445634637984, 21.67310507953373, 21.96495155054551, 22.256982797792233, 22.54919662625519, 22.841590893779145, 23.13416350916974, 23.42691243038155, 23.719835662791315, 24.01293125755148, 24.306197310019357, 24.599631958257685, 24.893233381602485, 25.186999799294497, 25.48092946917074, 25.775020686412844, 26.069271782349183, 26.363681123307874, 26.658247109518, 26.952968174056565, 27.24784278183872, 27.542869428649215, 27.838046640212834, 28.133372971301956, 28.428847004879394], [0.0, 0.23325824788420188, 0.48296816446242286, 0.739289140017611, 1.0, 1.2640245637469165, 1.5307202304741794, 1.7996578748920302, 2.070529847682755, 2.343104423982924, 2.617200587442164, 2.892672910651636, 3.169401925648615, 3.4472876938820294, 3.7262453455812663, 4.006201886406627, 4.287093850145173, 4.568865534033383, 4.851467646094154, 5.134856250605608, 5.418991933671841, 5.703839134191492, 5.989365601087564, 6.27554194828919, 6.562341286358656, 6.8497389149076096, 7.137712063732194, 7.426239673367266, 7.715302207814954, 8.004881493746378, 8.294960581647878, 8.585523625283425, 8.876555776542762, 9.168043093290875, 9.459972458265128, 9.75233150740892, 10.045108566305142, 10.338292593593978, 10.631873130439274, 10.925840255254474, 11.220184543019634, 11.514897028620654, 11.80996917372445, 12.105392836772918, 12.401160245736165, 12.69726397331427, 12.993696914317956, 13.290452264993428, 13.587523504086443, 13.884904375466048, 14.182588872150292, 14.480571221594984, 14.778845872122783, 15.077407480384029, 15.376250899752758, 15.67537116957226, 15.97476350517352, 16.274423288598236, 16.574346059965194, 16.874527509425004, 17.17496346965384, 17.475649908841667, 17.776582924134786, 18.077758735496438, 18.379173679952565, 18.68082420619292, 18.98270686950049, 19.284818326984517, 19.587155333094756, 19.88971473539641, 20.19249347058712, 20.495488560738774, 20.798697109748524, 21.10211629998464, 21.40574338911389, 21.709575707098423, 22.013610653350806, 22.31784569403707, 22.62227835951816, 22.926906241920946, 23.23172699283085, 23.53673832109834, 23.841937990752534, 24.14732381901525, 24.45289367440972, 24.758645474958183, 25.064577186463346, 25.370686820868723, 25.67697243469354, 25.983432127537867, 26.29006404065413, 26.596866355581337, 26.90383729283864, 27.210975110674955, 27.51827810387177, 27.825744602596224, 28.13337297130196, 28.44116160767511, 28.749108941623337, 29.057213434305577, 29.365473577200483, 29.673887891211745], [0.0, 0.2430647694125374, 0.5032728599887851, 0.7703699482334324, 1.0420414781354437, 1.3171660248063461, 1.5950739715751407, 1.8753181520905824, 2.157577983002893, 2.4416119973928634, 2.727231568715184, 3.0142851555777868, 3.3026482674082036, 3.5922167640909546, 3.882902207804819, 4.1746285354201635, 4.467329612510646, 4.760947394486228, 5.0554305170622325, 5.35073319739409, 5.646814364567452, 5.943636962439691, 6.241167384050865, 6.53937500789625, 6.838231814066422, 7.137712063732194, 7.437792029396683, 7.738449766223699, 8.039664916893146, 8.341418544042533, 8.643692985575594, 8.946471729057112, 9.24973930214033, 9.553481176542268, 9.85768368353118, 10.16233393924725, 10.467419778463617, 10.772929695625377, 11.078852792191446, 11.385178729457104, 11.691897686160637, 11.999000320281294, 12.306477734521849, 12.614321445041062, 12.922523353061415, 13.231075719028318, 13.539971139039837, 13.849202523302305, 14.15876307639832, 14.468646279179929, 14.778845872122783, 15.089355839996403, 15.400170397722723, 15.711283977309765, 16.02269121575981, 16.334386943862796, 16.646366175795155, 16.95862409945279, 17.271156067454495, 17.583957588758434, 17.897024320840334, 18.210352062386903, 18.5239367464627, 18.837774434112635, 19.15186130836581, 19.466193668609645, 19.78076792530613, 20.09558059502444, 20.410628295766596, 20.72590774256479, 21.041415743330898, 21.357149194940305, 21.673105079533727, 21.98928046102203, 22.30567248178024, 22.62227835951816, 22.93909538431582, 23.256120915813135, 23.57335238054376, 23.890787269404033, 24.20842313524854, 24.52625759060445, 24.844288305497358, 25.16251300538185, 25.48092946917074, 25.799535527356834, 26.11832906022218, 26.437307996129462, 26.756470309891096, 27.07581402121153, 27.395337193198703, 27.715037930940827, 28.034914380145047, 28.354964725834495, 28.675187191100747, 28.995580035908713, 29.31614155595123, 29.636870081550796, 29.95776397660608, 30.27882163758085, 30.600041492533304, 30.921422000183725], [0.0, 0.25289017232581057, 0.5236166499862263, 0.8015105991470337, 1.0841639025401355, 1.3704098039384491, 1.6595516187680217, 1.95112410488003, 2.244793719989568, 2.540309236364383, 2.8374744026116314, 3.13613155158421, 3.436151160429422, 3.7374248793777243, 4.039860695687401, 4.34337947153026, 4.647912399129205, 4.9533990875587515, 5.259786096236641, 5.567025791639184, 5.875075442643178, 6.183896495186195, 6.493453983814737, 6.803716049211532, 7.114653538818852, 7.426239673367266, 7.738449766223699, 8.051260985476235, 8.364652150901183, 8.678603559631382, 8.993096835615955, 9.308114798937808, 9.623641351811782, 9.93966137867837, 10.256160658274919, 10.573125785937574, 10.890544104684725, 11.208403643872623, 11.526693064408649, 11.845401609666798, 12.164519061380672, 12.484035699897177, 12.803942268263796, 13.124229939697127, 13.444890288042904, 13.765915260890663, 14.08729715505067, 14.409028594138656, 14.731102508046172, 15.05351211410187, 15.376250899752756, 15.699312606614793, 16.022691215759806, 16.346380934120976, 16.670376181912218, 16.99467158096859, 17.319261943924655, 17.644142264156727, 17.96930770642258, 18.29475359813908, 18.62047542124417, 18.946468804594943, 19.2727295168583, 19.599253459854843, 19.92603666232031, 20.253075274052343, 20.58036556041309, 20.90790389716106, 21.235686765587833, 21.563710747937407, 21.891972523087937, 22.22046886247725, 22.549196626255192, 22.878152759647147, 23.207334289514417, 23.536738321098344, 23.866362034935907, 24.196202683935788, 24.52625759060446, 24.856524144412802, 25.186999799294494, 25.517682071267927, 25.848568536174177, 26.179656827523935, 26.51094463444703, 26.842429699738325, 27.174109817994545, 27.50598283383661, 27.838046640212827, 28.170299176778187, 28.50273842834566, 28.835362423405492, 29.16816923270877, 29.50115696791185, 29.83432378027837, 30.16766785943583, 30.501187432183894, 30.834880761351712, 31.168746144701856, 31.50278191387838, 31.836986433396902, 32.17135809967459], [0.0, 0.2627337913530248, 0.5439981569912913, 0.832708984247238, 1.1263644211348778, 1.423752296045062, 1.7241488063174955, 2.0270706004935857, 2.332171153327673, 2.6391894581780972, 2.947921624668155, 3.2582038485386717, 3.569901565326968, 3.882902207804819, 4.1971101816821745, 4.512443268731855, 4.828829982869662, 5.146207582484604, 5.464520546847428, 5.783719388324195, 6.103759712504855, 6.4246014646300615, 6.746208318234142, 7.068547173892396, 7.391587744298876, 7.715302207814954, 8.039664916893146, 8.364652150901183, 8.690241905186134, 9.016413709956934, 9.34314847388444, 9.670428348332182, 9.998236608917043, 10.32655755171419, 10.655376401905686, 10.984679233058076, 11.314452895523292, 11.644684952706474, 11.975363624146693, 12.306477734521849, 12.638016667824813, 12.969970326070026, 13.30232909198289, 13.635083795202021, 13.968225681589473, 14.301746385298864, 14.635637903297791, 14.969892572080045, 15.30450304633687, 15.639462279384945, 15.974763505173522, 16.3104002217142, 16.646366175795155, 16.98265534885743, 17.31926194392466, 17.656180373489608, 17.99340524827134, 18.330931366765924, 18.668753705521837, 19.006867410078062, 19.345267786509318, 19.683950293528223, 20.02291053509923, 20.362144253523425, 20.70164732295715, 21.041415743330898, 21.381445634637984, 21.721733231565196, 22.062274878440206, 22.403067024472623, 22.74410621926766, 23.085389108593034, 23.426912430381545, 23.768673010953062, 24.110667761441, 24.452893674409715, 24.795347820650054, 25.138027346141588, 25.48092946917074, 25.8240514775949, 26.16739072624343, 26.510944634447025, 26.854710683687625, 27.19868641536155, 27.54286942864921, 27.88725737848493, 28.231847973621246, 28.576638974782067, 28.9216281928998, 29.266813487431573, 29.61219276475025, 29.957763976606078, 30.30352511865513, 30.64947422905096, 30.995609387096103, 31.341928711950242, 31.688430361392143, 32.03511253063248, 32.38197345117511, 32.72901138972419, 33.076224647134964, 33.42361155740597], [0.0, 0.27259500762696415, 0.5644160996209375, 0.8639631420950986, 1.1686403807778343, 1.4771901474897324, 1.788861473005679, 2.10315286418365, 2.4197047896078465, 2.7382464462456326, 3.0585662910803824, 3.3804943717696543, 3.7038910732279984, 4.0286396032290375, 4.3546407795317235, 4.6818092980031185, 5.0100709894639675, 5.339360757415495, 5.669620997262815, 6.000800363947181, 6.3328527967982735, 6.665736737677058, 6.9994144966726335, 7.333851732035951, 7.669017019684283, 8.004881493746378, 8.341418544042533, 8.678603559631382, 9.016413709956934, 9.354827756933206, 9.693825892674102, 10.033389598628315, 10.373501522694617, 10.714145371531043, 11.055305815774785, 11.39696840629003, 11.739119499881525, 12.08174619317033, 12.424836263538179, 12.768378116218377, 13.112360736752036, 13.456773648144793, 13.801606872155826, 14.146850894231571, 14.492496631664054, 14.838535404610665, 15.184958909660308, 15.53175919567155, 15.878928641643354, 16.22645993640846, 16.574346059965194, 16.922580266285312, 17.271156067454495, 17.62006721901856, 17.96930770642258, 18.318871732442812, 18.668753705521834, 19.018948228927098, 19.36945009066132, 19.720254254060475, 20.071355849021657, 20.422750163808853, 20.774432637389623, 21.12639885226038, 21.478644527721713, 21.83116551356908, 22.183957784167063, 22.537017432878542, 22.890340666822443, 23.243923801936162, 23.597763258320867, 23.95185555584951, 24.306197310019353, 24.660785228032193, 25.015616105086664, 25.37068682086872, 25.725994336226872, 26.081535690020434, 26.437307996129462, 26.7933084406162, 27.149534279028533, 27.505982833836608, 27.862651491994555, 28.219537702619647, 28.576638974782067, 28.933952875398532, 29.29147702722394, 29.649209106935206, 30.007146843302213, 30.365288015440864, 30.72363045114369, 31.082172025283747, 31.440910658287848, 31.79984431467535, 32.15897100165904, 32.51828876780482, 32.877795701747154, 33.23748993095736, 33.59736962056214, 33.95743297220967, 34.317678222981, 34.67810364434446], [0.0, 0.28247324395572265, 0.5848692827820962, 0.8952712433374781, 1.2109893069931357, 1.5307202304741792, 1.8536858311022992, 2.179366442740239, 2.5073895053539426, 2.8374744026116314, 3.169401925648614, 3.5029959634278414, 3.8381118415239253, 4.1746285354201635, 4.512443268731855, 4.851467646094154, 5.191624810601837, 5.532847306803908, 5.875075442643178, 6.218256012430257, 6.562341286358655, 6.907288200314881, 7.253057698589554, 7.599614194965079, 7.946925126619911, 8.294960581647878, 8.643692985575594, 8.993096835615955, 9.34314847388444, 9.693825892674102, 10.045108566305142, 10.396977305155168, 10.749414128321435, 11.102402152027521, 11.455925491408637, 11.809969173724449, 12.164519061380673, 12.519561783408637, 12.875084674269596, 13.231075719028318, 13.58752350408644, 13.944417172786642, 14.301746385298866, 14.659501282283305, 15.017672451894862, 15.376250899752756, 15.735228021548748, 16.09459557800974, 16.454345671966582, 16.814470727311587, 17.17496346965384, 17.535816908504053, 17.897024320840334, 18.258579235923374, 18.62047542124417, 18.98270686950049, 19.345267786509314, 19.708152579972523, 20.071355849021657, 20.434872374475187, 20.798697109748524, 21.162825172362826, 21.52725183600399, 21.891972523087937, 22.256982797792233, 22.62227835951816, 22.987855036750233, 23.3537087812835, 23.71983566279132, 24.086231863708857, 24.452893674409715, 24.819817488654788, 25.186999799294497, 25.554437194206947, 25.922126352455926, 26.29006404065413, 26.658247109517998, 27.02667249060169, 27.395337193198706, 27.764238301400443, 28.133372971301952, 28.50273842834566, 28.87233196479472, 29.242150937328113, 29.612192764750255, 29.98245492580834, 30.352934957111202, 30.72363045114369, 31.094539054371378, 31.465658465430256, 31.8369864333969, 32.20852075613449, 32.58025927871074, 32.95219989188373, 33.32434053065205, 33.696679172865984, 34.06921383789637, 34.441942585358255, 34.81486351388661, 35.18797475996134, 35.56127449677925, 35.93476093317051], [0.0, 0.2923679607179662, 0.6053565891726884, 0.9266315776974805, 1.2534088863734785, 1.5843396207947447, 1.9186183394279952, 2.25570717282168, 2.5952205105870902, 2.9368679067212073, 3.2804224737218965, 3.6257019315825953, 3.972556538097188, 4.320861029397671, 4.670509028959372, 5.021409045028259, 5.37348152848905, 5.7266566610029495, 6.0808726595678335, 6.436074454759471, 6.792212644850485, 7.149242657240424, 7.507124068142783, 7.865820044795203, 8.225296883737503, 8.585523625283425, 8.946471729057112, 9.308114798937808, 9.670428348332182, 10.033389598628315, 10.396977305155168, 10.761171606099687, 11.12595389070853, 11.491306683785776, 11.85721354403787, 12.2236589742464, 12.590628341593217, 12.958107806739807, 13.326084260487999, 13.69454526703303, 14.063479012971156, 14.43287426134869, 14.802720310143071, 15.173006954653026, 15.543724453347219, 15.914863496781928, 16.286415179249772, 16.658370972865285, 17.030722703830453, 17.403462530655137, 17.776582924134786, 18.15007664891121, 18.523936746462695, 18.898156519387296, 19.2727295168583, 19.647649521144498, 20.022910535099225, 20.398506770532517, 20.774432637389623, 21.15068273366702, 21.52725183600399, 21.904134890894014, 22.281327006465574, 22.658823444787014, 23.03661961465409, 23.41471106482299, 23.79309347765479, 24.171762663140512, 24.550714553278635, 24.92994519677938, 25.309450754072337, 25.689227492595954, 26.06927178234918, 26.449580091687373, 26.83014898334569, 27.210975110674955, 27.59205521407577, 27.973386117618137, 28.354964725834495, 28.736788020675284, 29.118853058616793, 29.501156967911843, 29.88369694597466, 30.26647025689167, 30.64947422905096, 31.032706252883095, 31.416163778707112, 31.79984431467535, 32.18374542481173, 32.5678647271381, 32.95219989188372, 33.33674863977344, 33.72150874039014, 34.10647801060753, 34.49165431308958, 34.87703555485296, 35.262619685889305, 35.648404697844185, 36.034388622749915, 36.42056953180943, 36.80694553422866, 37.19351477609516], [0.0, 0.30227865228213346, 0.6258769718674744, 0.9580425426254616, 1.2958969512289056, 1.6380455784380765, 1.9836556798558964, 2.332171153327673, 2.6831933170405327, 3.036421879450432, 3.391622262020801, 3.748606005815899, 4.107218292667062, 4.467329612510646, 4.828829982869662, 5.191624810601837, 5.55563185003532, 5.920778916128685, 6.287002131559087, 6.654244560158497, 7.022455125579371, 7.391587744298874, 7.7616006222446545, 8.132455678097067, 8.504118065915756, 8.876555776542762, 9.24973930214033, 9.623641351811782, 9.998236608917043, 10.373501522694617, 10.749414128321435, 11.12595389070853, 11.503101568235095, 11.880839093330868, 12.259149467375194, 12.638016667824814, 13.017425565838195, 13.397361852950809, 13.777811975588774, 14.15876307639832, 14.540202941524834, 14.922119953104287, 15.30450304633687, 15.687341670602256, 16.0706257541506, 16.454345671966582, 16.838492216457077, 17.223056570658283, 17.608030283696717, 17.99340524827134, 18.379173679952565, 18.765328098117966, 19.15186130836581, 19.538766386265554, 19.926036662320314, 20.313665708030175, 20.701647322957147, 21.089975522703153, 21.478644527721716, 21.867648752892155, 22.256982797792233, 22.646641437611617, 23.03661961465409, 23.42691243038155, 23.81751513795707, 24.208423135248545, 24.599631958257685, 24.991137274942556, 25.382934879404488, 25.775020686412844, 26.167390726243433, 26.560041139808284, 26.952968174056558, 27.346168177627884, 27.739637596740987, 28.133372971301956, 28.52737093121746, 28.921628192899796, 29.316141555951226, 29.71090790001632, 30.105924181791764, 30.501187432183887, 30.896694753604823, 31.292443317398988, 31.68843036139214, 32.084653187555645, 32.48110915977942, 32.87779570174715, 33.274710294908004, 33.67185047653951, 34.06921383789636, 34.46679802244051, 34.864600724148126, 35.262619685889305, 35.66085269787657, 36.05929759617862, 36.4579522612959, 36.856814616794765, 37.25588262799735, 37.65515430072419, 38.05462768008709, 38.454300849329634], [0.0, 0.3122048438683787, 0.6464294478206125, 0.9895026333532642, 1.3384514661336602, 1.6918355305760204, 2.0487947367186194, 2.4087547211882248, 2.7713037103044873, 3.1361315515842096, 3.502995963427841, 3.871702298306804, 4.242090654151234, 4.614027268060926, 4.987398545966972, 5.362106788488384, 5.738067049179405, 6.115204772594528, 6.493453983814736, 6.872755877008665, 7.253057698589553, 7.634311851749149, 8.01647516998616, 8.399508321470952, 8.783375315996192, 9.168043093290875, 9.553481176542268, 9.93966137867837, 10.32655755171419, 10.714145371531043, 11.102402152027521, 11.491306683785776, 11.880839093330868, 12.270980719791748, 12.661714006349005, 13.053022404312955, 13.444890288042904, 13.837302879214619, 14.230246179183512, 14.623706908387513, 15.01767245189486, 15.412130810335439, 15.807070555564819, 16.20248079050262, 16.59835111266403, 16.994671580968586, 17.391432685465283, 17.788625319659875, 18.186240755170065, 18.584270618468203, 18.98270686950049, 19.38154178199669, 19.78076792530613, 20.180378147614615, 20.58036556041309, 20.980723524103297, 21.381445634637984, 21.78252571110409, 22.183957784167067, 22.585736085302674, 22.987855036750233, 23.390309242127692, 23.79309347765479, 24.196202683935788, 24.599631958257685, 25.00337654736408, 25.40743184066843, 25.811793363873704, 26.216456772968414, 26.62141784857159, 27.02667249060169, 27.43221671324647, 27.838046640212827, 28.244158500237443, 28.650548622840386, 29.057213434305574, 29.464149453872942, 29.87135329012871, 30.278821637580847, 30.686551273408053, 31.094539054371374, 31.502781913878373, 31.911276859190536, 32.320020968765206, 32.729011389724185, 33.13824533544128, 33.54772008324215, 33.957432972209666, 34.36738140108914, 34.7775628262875, 35.187974759961335, 35.59861476818886, 36.009480469221316, 36.42056953180943, 36.83187967360096, 37.24340865960569, 37.65515430072419, 38.06711445233711, 38.47928701295207, 38.89166992290498, 39.30426116311324, 39.71705875387822], [0.0, 0.32214608878672757, 0.6670130921471783, 1.0210104341408237, 1.3810705160859007, 1.7457070565992092, 2.114032578684103, 2.4854544300551913, 2.8595477253104837, 3.2359924360732535, 3.6145385659990716, 3.994985269581359, 4.377167553139179, 4.760947394486228, 5.146207582484604, 5.532847306803908, 5.920778916128685, 6.309925481014567, 6.700218925765301, 7.0915985720508, 7.484009986501502, 7.8774040567288, 8.271736241721142, 8.66696595724247, 9.063056067083162, 9.459972458265128, 9.85768368353118, 10.256160658274919, 10.655376401905686, 11.055305815774785, 11.455925491408637, 11.85721354403787, 12.259149467375194, 12.661714006349005, 13.064889045094626, 13.468657507978024, 13.873003271805942, 14.277911087681877, 14.683366511215587, 15.089355839996403, 15.49586605740717, 15.902884781993128, 16.3104002217142, 16.718401132504535, 17.1268767806428, 17.53581690850405, 17.945211703320872, 18.355051768629497, 18.765328098117966, 19.176032051628273, 19.587155333094753, 19.998689970226824, 20.410628295766593, 20.822962930171386, 21.235686765587833, 21.64879295099921, 22.062274878440203, 22.476126170184763, 22.890340666822443, 23.304912416147314, 23.719835662791315, 24.13510483854048, 24.550714553278635, 24.966659586508463, 25.382934879404488, 25.799535527356838, 26.21645677296841, 26.63369399947134, 27.05124272453187, 27.46909859441526, 27.887257378484932, 28.305714964012168, 28.72446735127472, 29.14351064892448, 29.562841069605874, 29.982454925808344, 30.40234862593727, 30.82251867058927, 31.242961649018643, 31.663674235782818, 32.084653187555645, 32.50589534009808, 32.92739760537664, 33.34915696882074, 33.77117048671068, 34.19343528368834, 34.61594855038382, 35.03870754115092, 35.46170957190565, 35.88495201806169, 36.30843231255757, 36.73214794397044, 37.15609645471176, 37.58027543930046, 38.00468254270952, 38.42931545878203, 38.85417192871312, 39.27924973959436, 39.70454672301752, 40.13006075373456, 40.55578974837115, 40.98173166419096], [0.0, 0.3321019659965806, 0.6876270330700435, 1.052564610541253, 1.423752296045062, 1.79965787489203, 2.179366442740239, 2.562267031473105, 2.947921624668155, 3.33600030351903, 3.726245345581266, 4.118449698247619, 4.512443268731856, 4.908083769292426, 5.305250366398552, 5.703839134191493, 6.103759712504855, 6.504932794401175, 6.907288200314882, 7.310763376661073, 7.715302207814954, 8.120854063576814, 8.527373026401731, 8.934817257803836, 9.34314847388444, 9.75233150740892, 10.16233393924725, 10.573125785937574, 10.984679233058076, 11.39696840629003, 11.809969173724449, 12.2236589742464, 12.638016667824814, 13.053022404312955, 13.468657507978024, 13.884904375466048, 14.301746385298864, 14.719167817315082, 15.137153780722716, 15.555690149640121, 15.974763505173518, 16.394361083221117, 16.814470727311587, 17.235080845882887, 17.656180373489608, 18.077758735496438, 18.499805815873827, 18.922311927761683, 19.345267786509318, 19.76866448493591, 20.192493470587124, 20.616746524789903, 21.041415743330898, 21.466493518603748, 21.891972523087937, 22.31784569403707, 22.74410621926766, 23.170747523950965, 23.597763258320867, 24.025147286219408, 24.452893674409715, 24.880996682593, 25.30945075407234, 25.738250507011728, 26.167390726243433, 26.59686635558134, 27.02667249060169, 27.456804371856094, 27.887257378484936, 28.31802702220194, 28.749108941623334, 29.18049889691713, 29.61219276475025, 30.044186533513052, 30.476476298802304, 30.909058259145475, 31.341928711950242, 31.775084049664677, 32.20852075613449, 32.64223540314481, 33.07622464713496, 33.51048522607555, 33.94501395649791, 34.37980773066657, 34.8148635138866, 35.25017834193739, 35.68574931862586, 36.121573613452036, 36.55764845938069, 36.993971150713065, 37.43053904105303, 37.867349541362586, 38.304400118101775, 38.7416882914485, 39.17921163359398, 39.61696776710986, 40.054954363383246, 40.4931691411161, 40.93160986488584, 41.37027434376398, 41.80916042998978, 42.24826601769648], [0.0, 0.34207207794204353, 0.7082704474378629, 1.0841639025401355, 1.466495101651715, 1.853685831102299, 2.244793719989568, 2.639189458178097, 3.036421879450432, 3.436151160429421, 3.8381118415239244, 4.242090654151233, 4.647912399129206, 5.0554305170622325, 5.464520546847428, 5.875075442643178, 6.287002131559087, 6.700218925765301, 7.114653538818851, 7.530241539198816, 7.94692512661991, 8.36465215090118, 8.78337531599619, 9.203051527375957, 9.623641351811782, 10.045108566305142, 10.467419778463617, 10.890544104684725, 11.314452895523292, 11.739119499881525, 12.164519061380673, 12.590628341593217, 13.017425565838195, 13.444890288042904, 13.873003271805942, 14.301746385298864, 14.73110250804617, 15.16105544794777, 15.59158986717168, 16.022691215759806, 16.45434567196658, 16.886540088496076, 17.319261943924655, 17.75249929869724, 18.18624075517006, 18.62047542124417, 19.055192877194287, 19.4903831453488, 19.926036662320314, 20.36214425352342, 20.798697109748524, 21.235686765587833, 21.673105079533727, 22.110944215590102, 22.549196626255192, 22.987855036750233, 23.426912430381545, 23.866362034935904, 24.306197310019357, 24.746411935258877, 25.186999799294497, 25.627954989496544, 26.06927178234918, 26.510944634447025, 26.952968174056558, 27.395337193198703, 27.838046640212827, 28.281091612766012, 28.724467351274722, 29.16816923270877, 29.61219276475025, 30.056533580282167, 30.501187432183887, 30.946150188412282, 31.3914178273491, 31.8369864333969, 32.28285219280696, 32.729011389724185, 33.17546040243497, 33.6221956998052, 34.06921383789636, 34.51651145674892, 34.96408527732252, 35.41193209858364, 35.86004879473205, 36.30843231255757, 36.757079668919815, 37.2059879483437, 37.655154300724185, 38.10457593913408, 38.55425013772917, 39.00417422974533, 39.4543456055826, 39.90476171097155, 40.355420045217585, 40.80631815951901, 41.25745365535507, 41.708824182940354, 42.16042743974214, 42.61226116905753, 43.06432315864737, 43.51661123942416], [0.0, 0.35205604862509987, 0.7289425567355207, 1.1158071184486336, 1.5092973209670757, 1.9077888876997975, 2.310311943004783, 2.7162188092318416, 3.1250451520899496, 3.53644122986353, 3.9501338350599147, 4.365903474480547, 4.783569835449344, 5.202982080978915, 5.62401211735184, 6.046549774406766, 6.470499262758535, 6.8957765103753905, 7.3223071210083495, 7.750024782590088, 8.178870007833103, 8.608789124462383, 9.039733456013819, 9.471658650169376, 9.904524122772752, 10.338292593593978, 10.772929695625377, 11.208403643872623, 11.644684952706474, 12.08174619317033, 12.519561783408637, 12.958107806739807, 13.397361852950809, 13.837302879214619, 14.277911087681877, 14.719167817315082, 15.16105544794777, 15.60355731488515, 16.04665763263383, 16.490341426569806, 16.934594471535725, 17.379403236508892, 17.824754834606058, 18.27063697779539, 18.717037935772993, 19.163946498534994, 19.611351942238247, 20.05924399799538, 20.50761282329484, 20.956448975774933, 21.405743389113894, 21.85548735082624, 22.30567248178024, 22.756290717272556, 23.20733428951442, 23.658795711399947, 24.110667761441004, 24.5629434697655, 25.01561610508667, 25.468679162560374, 25.922126352455926, 26.375951589573248, 26.830148983345694, 27.284712828573923, 27.73963759674099, 28.19491792786387, 28.65054862284039, 29.10652463625449, 29.56284106960588, 30.01949316493317, 30.476476298802307, 30.933785976634375, 31.391417827349102, 31.84936759830247, 32.30763115049828, 32.766204454055554, 33.22508358391464, 33.68426471576674, 34.1437441221922, 34.603518168994604, 35.06358331171809, 35.523936092336825, 35.984573136105936, 36.44549114856416, 36.90668691267933, 37.36815728612799, 37.829899198701604, 38.29190964983185, 38.754185706228405, 39.21672449962274, 39.679523224612126, 40.14257913659826, 40.60588954981546, 41.06945183544348, 41.53326341980059, 41.997321782612545, 42.46162445535358, 42.92616901965568, 43.3909531057827, 43.85597439116592, 44.321230598998135, 44.78671949688323], [0.0, 0.3620535218847593, 0.7496426235210557, 1.1474931294494186, 1.5521574270955523, 1.9619651146509918, 2.3759187745359127, 2.793352336744663, 3.213788281103811, 3.6368669341455413, 4.062307329997197, 4.489883742426046, 4.919410738346442, 5.35073319739409, 5.783719388324195, 6.218256012430257, 6.654244560158497, 7.091598572050801, 7.530241539198816, 7.970105266445516, 8.411128577219637, 8.853256275093589, 9.296438301318679, 9.740629044086758, 10.185786766757367, 10.631873130439274, 11.078852792191446, 11.526693064408649, 11.975363624146693, 12.424836263538179, 12.875084674269596, 13.326084260487999, 13.777811975588774, 14.230246179183512, 14.683366511215587, 15.137153780722716, 15.59158986717168, 16.04665763263383, 16.502340843348957, 16.958624099452795, 17.41549277183064, 17.872932945214053, 18.330931366765927, 18.78947539950638, 19.24855298002149, 19.708152579972527, 20.168263170987174, 20.628874192568453, 21.089975522703153, 21.551557450891156, 22.013610653350806, 22.476126170184767, 22.93909538431582, 23.402510002024105, 23.86636203493591, 24.330643783331077, 24.795347820650054, 25.260466979094574, 25.72599433622688, 26.19192320248223, 26.658247109518, 27.124959799330306, 27.592055214075774, 28.059527486542294, 28.52737093121746, 28.995580035908713, 29.464149453872945, 29.933073996417438, 30.40234862593728, 30.871968449357386, 31.341928711950242, 31.812224791502615, 32.28285219280696, 32.75380654245527, 33.22508358391464, 33.69667917286599, 34.168589272788225, 34.64080995077213, 35.11333737354909, 35.586167803720976, 36.05929759617862, 36.53272319469728, 37.00644112869815, 37.480448010165844, 37.95474053071289, 38.42931545878203, 38.90416963697882, 39.37929997952663, 39.85470346983734, 40.330377158191084, 40.80631815951901, 41.282523651283384, 41.75899087144979, 42.23571711654635, 42.71269973980547, 43.189936149383705, 43.6674238066556, 44.14516022457779, 44.623142966119815, 45.10136964275806, 45.57983791302992, 46.05854548114508], [0.0, 0.3720641598553125, 0.7703699482334324, 1.179220864710261, 1.5950739715751405, 2.0162126810643284, 2.4416119973928634, 2.870587433980508, 3.302648267408203, 3.7374248793777247, 4.1746285354201635, 4.6140272680609264, 5.055430517062233, 5.498678873042516, 5.943636962439692, 6.390188353882437, 6.838231814066422, 7.287678492963402, 7.738449766223699, 8.190475553120923, 8.643692985575594, 9.098045341000534, 9.553481176542268, 10.009953619244033, 10.467419778463617, 10.925840255254474, 11.385178729457104, 11.845401609666798, 12.306477734521849, 12.768378116218377, 13.231075719028318, 13.69454526703303, 14.15876307639832, 14.623706908387513, 15.089355839996403, 15.555690149640121, 16.022691215759806, 16.490341426569806, 16.958624099452795, 17.4275234087443, 17.89702432084033, 18.36711253572073, 18.83777443411264, 19.308997029628635, 19.78076792530613, 20.253075274052343, 20.725907742564793, 21.199254478352888, 21.67310507953373, 22.147449567115675, 22.62227835951816, 23.097582249106193, 23.57335238054376, 24.049580230792884, 24.52625759060446, 25.00337654736408, 25.48092946917074, 25.958908990039347, 26.437307996129462, 26.916119612912503, 27.395337193198703, 27.87495430595282, 28.354964725834495, 28.835362423405495, 29.316141555951226, 29.797296458869162, 30.27882163758085, 30.76071175992825, 31.242961649018643, 31.72556627648535, 32.20852075613449, 32.69182033795045, 33.17546040243497, 33.65943645525701, 34.1437441221922, 34.62837914433267, 35.11333737354909, 35.59861476818886, 36.08420738899498, 36.57011139523173, 37.0563230410041, 37.542838671759135, 38.029654720957865, 38.516767706907636, 39.00417422974534, 39.491870968562424, 39.97985467866375, 40.468122188952144, 40.95667039943203, 41.445496278824926, 41.93459686229097, 42.423969249250355, 42.91361060129951, 43.4035181402166, 43.89368914605196, 44.38412095529869, 44.874810959139324, 45.365756601764744, 45.85695537876152, 46.348404835564324, 46.84010256597002, 47.33204621071059], [0.0, 0.3820876415809296, 0.7911238663240253, 1.2109893069931357, 1.6380455784380763, 2.0705298476827547, 2.507389505353942, 2.9479216246681545, 3.3916222620208005, 3.838111841523924, 4.2870938501451725, 4.7383300711605125, 5.191624810601837, 5.64681436456745, 6.103759712504854, 6.562341286358655, 7.02245512557937, 7.484009986501501, 7.9469251266199095, 8.411128577219635, 8.87655577654276, 9.343148473884439, 9.810853840510594, 10.279623740697778, 10.749414128321433, 11.220184543019634, 11.691897686160637, 12.164519061380672, 12.638016667824813, 13.112360736752036, 13.58752350408644, 14.063479012971156, 14.540202941524834, 15.01767245189486, 15.49586605740717, 15.974763505173518, 16.45434567196658, 16.934594471535725, 17.41549277183064, 17.89702432084033, 18.379173679952558, 18.861926163901803, 19.345267786509314, 19.829185211531836, 20.31366570803017, 20.79869710974852, 21.284267778063004, 21.7703665681148, 22.256982797792233, 22.744106219267657, 23.231726992830847, 23.719835662791315, 24.208423135248538, 24.69748065755223, 25.186999799294494, 25.676972434693536, 26.16739072624343, 26.658247109517994, 27.149534279028533, 27.641245175045306, 28.13337297130195, 28.625911063509864, 29.118853058616793, 29.612192764750247, 30.10592418179176, 30.600041492533297, 31.094539054371374, 31.589411391498565, 32.084653187555645, 32.58025927871074, 33.07622464713496, 33.57254441484632, 34.06921383789636, 34.56622830087589, 35.063583311718084, 35.56127449677924, 36.05929759617862, 36.55764845938068, 37.0563230410041, 37.55531739684294, 38.05462768008707, 38.55425013772916, 39.054181107146974, 39.554417012850365, 40.05495436338324, 40.55578974837113, 41.056919835706154, 41.55834136886118, 42.06005116432612, 42.562046109159255, 43.06432315864736, 43.56687933406844, 44.06971172055176, 44.57281746502965, 45.076193774276476, 45.579837913029905, 46.08374720219045, 46.587919017094976, 47.09235078586067, 47.59703998779571, 48.1019841518734, 48.60718085526656], [0.0, 0.3921236617672288, 0.8119037456717043, 1.2427974886974407, 1.6810709388586922, 2.1249149601184776, 2.5732492949732224, 3.025352553369184, 3.480707554978994, 3.938924753868929, 4.3996998487129195, 4.8627883657202515, 5.327989470770663, 5.795135160070279, 6.264082761514131, 6.734709566439052, 7.206908883638872, 7.680587072816618, 8.155661270662067, 8.632057618109995, 9.109709857605402, 9.588558208414241, 10.068548454188226, 10.549631194857614, 11.031761227370103, 11.514897028620654, 11.999000320281294, 12.484035699897177, 12.969970326070026, 13.456773648144793, 13.944417172786642, 14.43287426134869, 14.922119953104287, 15.412130810335439, 15.902884781993128, 16.394361083221117, 16.886540088496076, 17.379403236508892, 17.872932945214053, 18.36711253572073, 18.861926163901803, 19.357358758764487, 19.853395966765174, 20.350024101367136, 20.847230097236785, 21.345001468556067, 21.84332627099778, 22.34219306696913, 22.84159089377914, 23.34150923442787, 23.84193799075253, 24.342867458696837, 24.844288305497354, 25.346191548604246, 25.848568536174177, 26.351410928991317, 26.85471068368762, 27.3584600371476, 27.862651491994555, 28.367277803065917, 28.87233196479472, 29.377807199422282, 29.88369694597466, 30.38999484994192, 30.89669475360482, 31.403790686958917, 31.911276859190533, 32.41914765066318, 32.92739760537664, 33.43602142386441, 33.9450139564979, 34.454370197168714, 34.96408527732252, 35.474154460320484, 35.98457313610593, 36.4953368161558, 37.00644112869814, 37.51788181417832, 38.029654720957865, 38.541755801231254, 39.054181107146974, 39.566926787120146, 40.07998908232508, 40.59336432335682, 41.107048927051714, 41.62103939345746, 42.13533230294409, 42.64992431344763, 43.16481215783903, 43.67999264141119, 44.195462639477576, 44.71121909507628, 45.22725901677375, 45.74357947656285, 46.2601776078503, 46.77705060352862, 47.294195714128335, 47.811610246046186, 48.329291559845565, 48.847237068625475, 49.36544423645453, 49.8839105768669], [0.0, 0.40217192965325704, 0.832708984247238, 1.2746444882848518, 1.7241488063174955, 2.179366442740239, 2.6391894581780977, 3.102877976774974, 3.5699015653269677, 4.039860695687401, 4.512443268731855, 4.987398545966973, 5.46452054684743, 5.943636962439692, 6.424601464630062, 6.907288200314883, 7.391587744298876, 7.8774040567288015, 8.364652150901183, 8.853256275093589, 9.34314847388444, 9.834267434643277, 10.32655755171419, 10.819968159138176, 11.314452895523292, 11.80996917372445, 12.306477734521849, 12.803942268263796, 13.30232909198289, 13.801606872155826, 14.301746385298866, 14.802720310143071, 15.30450304633687, 15.807070555564819, 16.3104002217142, 16.814470727311587, 17.319261943924655, 17.824754834606058, 18.330931366765927, 18.83777443411264, 19.345267786509314, 19.853395966765174, 20.362144253523425, 20.871498609526384, 21.381445634637984, 21.891972523087937, 22.403067024472627, 22.914717408108068, 23.426912430381552, 23.939641304792353, 24.45289367440972, 24.966659586508467, 25.48092946917074, 25.995694109666594, 26.51094463444703, 27.026672490601694, 27.54286942864921, 28.059527486542294, 28.57663897478207, 29.094196462546854, 29.612192764750255, 30.130620929951807, 30.64947422905096, 31.168746144701856, 31.68843036139214, 32.2085207561345, 32.729011389724185, 33.24989649852011, 33.77117048671068, 34.29282791902922, 34.8148635138866, 35.337272136891634, 35.86004879473205, 36.383188629391476, 36.906686912679326, 37.43053904105304, 37.95474053071288, 38.47928701295207, 39.00417422974534, 39.52939802956113, 40.05495436338324, 40.58083928092895, 41.10704892705172, 41.63357953831716, 42.16042743974214, 42.687589041687204, 43.2150608368935, 43.742839397655814, 44.2709213731241, 44.79930348672607, 45.32798253370432, 45.85695537876151, 46.386218953807855, 46.9157702558053, 47.44560634470337, 47.97572434146177, 48.506121426155154, 49.03679483615601, 49.56774186439151, 50.09895985767064, 50.63044621507816, 51.1621983864319], [0.0, 0.41223216798967666, 0.8535390079975971, 1.306529427040784, 1.7672779922205544, 2.2338827931361127, 2.705208175563792, 3.1804957558230966, 3.6592018320455098, 4.14091688197964, 4.625320999413243, 5.11215717368721, 5.601214271700242, 6.092315674250457, 6.585311392860046, 7.0800724262389005, 7.576486611945648, 8.074455507712207, 8.573892000912254, 9.074718444911444, 9.576865184398951, 10.080269373022965, 10.584874014164884, 11.090627174468386, 11.597481332821975, 12.105392836772918, 12.614321445041062, 13.124229939697127, 13.635083795202021, 14.146850894231571, 14.659501282283305, 15.173006954653026, 15.687341670602256, 16.20248079050262, 16.718401132504535, 17.235080845882887, 17.75249929869724, 18.27063697779539, 18.78947539950638, 19.308997029628635, 19.829185211531836, 20.350024101367136, 20.871498609526384, 21.39359434761312, 21.916297580289964, 22.43959518145322, 22.96347459425825, 23.487923794580702, 24.01293125755148, 24.538485926848026, 25.064577186463342, 25.59119483470712, 26.11832906022218, 26.645970419824252, 27.174109817994545, 27.702738487873628, 28.231847973621242, 28.76143011402132, 29.29147702722394, 29.82198109652713, 30.352934957111202, 30.884331483647017, 31.416163778707112, 31.948425161915733, 32.48110915977942, 33.01420949614575, 33.54772008324215, 34.08163501325134, 34.61594855038382, 35.15065512341094, 35.68574931862586, 36.22122587320176, 36.757079668919815, 37.293305726241485, 37.8298991987016, 38.36685536760102, 38.904169636978814, 39.44183752884598, 39.97985467866375, 40.51821683105094, 41.05691983570616, 41.59595964353125, 42.13533230294409, 42.675033956368836, 43.2150608368935, 43.75540926508461, 44.29607564595005, 44.83705646604135, 45.37834829068772, 45.919947761354166, 46.461851593117025, 47.0040565722502, 47.546559553916346, 48.089357459957114, 48.632447276777334, 49.17582605331818, 49.71949089911453, 50.263438982432376, 50.80766752848208, 51.35217381770367, 51.89695518412061, 52.44200901375851], [0.0, 0.4223041121109144, 0.8743932689248127, 1.3384514661336602, 1.8104573619217186, 2.2884625770854936, 2.7713037103044877, 3.2582038485386713, 3.7486060058158985, 4.242090654151233, 4.7383300711605125, 5.2370609667207795, 5.7380670491794055, 6.241167384050864, 6.7462083182341415, 7.253057698589553, 7.761600622244654, 8.271736241721142, 8.78337531599619, 9.296438301318677, 9.810853840510594, 10.326557551714188, 10.843491045729678, 11.361601120328729, 11.880839093330868, 12.401160245736165, 12.922523353061415, 13.444890288042904, 13.968225681589473, 14.492496631664054, 15.017672451894862, 15.543724453347219, 16.0706257541506, 16.59835111266403, 17.1268767806428, 17.656180373489608, 18.18624075517006, 18.717037935772993, 19.24855298002149, 19.78076792530613, 20.31366570803017, 20.847230097236785, 21.381445634637984, 21.916297580289964, 22.45177186326399, 22.987855036750233, 23.52453423710646, 24.061797146426528, 24.599631958257685, 25.138027346141588, 25.67697243469354, 26.21645677296841, 26.756470309891093, 27.29700337155485, 27.83804664021283, 28.37959113480756, 28.921628192899796, 29.464149453872942, 30.007146843302213, 30.55061255838906, 31.094539054371374, 31.63891903182901, 32.18374542481173, 32.729011389724185, 33.274710294908004, 33.820835710867414, 34.36738140108914, 34.914341313411995, 35.46170957190565, 36.009480469221316, 36.55764845938069, 37.10620815097188, 37.65515430072418, 38.204481807435485, 38.7541857062284, 39.30426116311324, 39.85470346983733, 40.40550803900234, 40.95667039943203, 41.50818619177478, 42.06005116432612, 42.61226116905752, 43.16481215783903, 43.71770017884382, 44.2709213731241, 44.82447197134788, 45.37834829068772, 45.9325467318521, 46.48706377625195, 47.04189598329423, 47.59703998779571, 48.1524924975103, 48.70825029076379, 49.264310214190125, 49.82066918056387, 50.37732416672386, 50.93427221158312, 51.49151041422074, 52.049035932051474, 52.60684597906919, 53.16493782416031, 53.723308789484044], [0.0, 0.4323875090906928, 0.895271243337478, 1.3704098039384491, 1.853685831102299, 2.3431044239829237, 2.8374744026116314, 3.3360003035190298, 3.8381118415239244, 4.34337947153026, 4.851467646094153, 5.362106788488384, 5.875075442643179, 6.3901883538824364, 6.907288200314882, 7.426239673367265, 7.94692512661991, 8.46924130464932, 8.993096835615955, 9.518410276494691, 10.04510856630514, 10.573125785937572, 11.102402152027521, 11.632883192031787, 12.164519061380673, 12.69726397331427, 13.231075719028318, 13.765915260890663, 14.301746385298864, 14.838535404610665, 15.376250899752756, 15.914863496781928, 16.454345671966582, 16.994671580968586, 17.53581690850405, 18.077758735496438, 18.62047542124417, 19.163946498534994, 19.708152579972527, 20.253075274052343, 20.79869710974852, 21.345001468556067, 21.891972523087937, 22.43959518145322, 22.987855036750233, 23.53673832109834, 24.086231863708857, 24.63632305255977, 25.186999799294497, 25.738250507011728, 26.29006404065413, 26.84242969973833, 27.3953371931987, 27.948776616143682, 28.502738428345662, 29.05721343430557, 29.612192764750247, 30.167667859435827, 30.72363045114369, 31.28007255076709, 31.8369864333969, 32.39436462532398, 32.95219989188372, 33.51048522607556, 34.06921383789636, 34.62837914433267, 35.187974759961335, 35.747994488113136, 36.30843231255758, 36.869282389670936, 37.43053904105303, 37.992196746560715, 38.55425013772917, 39.11669399155439, 39.67952322461212, 40.242732887491016, 40.806318159519, 41.370274343763974, 41.93459686229097, 42.49928125165972, 43.06432315864736, 43.6297183361825, 44.19546263947758, 44.761552022347615, 45.32798253370432, 45.894750314215024, 46.461851593117025, 47.029282685178174, 47.59703998779571, 48.165119978225206, 48.73351921093261, 49.30223431506256, 49.87126199201662, 50.440599013135476, 51.01024221747973, 51.58018850970389, 52.15043485801882, 52.72097829223802, 53.29181590190359, 53.862944834487614, 54.43436229366547, 55.006065537657285], [0.0, 0.44248211697176026, 0.9161724302558818, 1.4024036735953722, 1.8969623624688503, 2.3978070226640087, 2.903718664679162, 3.413883253990856, 3.927717191422548, 4.444780903629862, 4.96473100940915, 5.487291638439372, 6.012236164491719, 6.539375007896249, 7.068547173892396, 7.599614194965079, 8.132455678097067, 8.66696595724247, 9.203051527375957, 9.740629044086758, 10.27962374069778, 10.819968159138174, 11.36160112032873, 11.904466879999033, 12.44851442989779, 12.993696914317956, 13.539971139039837, 14.08729715505067, 14.635637903297791, 15.184958909660308, 15.735228021548748, 16.286415179249772, 16.838492216457077, 17.391432685465283, 17.945211703320872, 18.499805815873827, 19.055192877194287, 19.611351942238247, 20.168263170987174, 20.725907742564793, 21.284267778063004, 21.84332627099778, 22.403067024472627, 22.96347459425825, 23.52453423710646, 24.086231863708857, 24.648553995788802, 25.211487726881412, 25.775020686412848, 26.33914100673815, 26.903837292838645, 27.469098594415264, 28.03491438014505, 28.6012745138948, 29.168169232708777, 29.7355891264079, 30.30352511865513, 30.871968449357382, 31.440910658287855, 32.01034356982446, 32.58025927871075, 33.150650136754834, 33.72150874039014, 34.29282791902922, 34.864600724148126, 35.436820419045006, 36.00948046922132, 36.58257453333913, 37.156096454711765, 37.730040253289076, 38.30440011810178, 38.87917040013232, 39.4543456055826, 40.02992038951129, 40.60588954981546, 41.18224802153378, 41.75899087144979, 42.33611329297582, 42.91361060129951, 43.49147822877619, 44.069711720551766, 44.64830673040183, 45.22725901677376, 45.8065644390195, 46.38621895380786, 46.96621861170538, 47.54655955391635, 48.12723800917245, 48.7082502907638, 49.28959279370326, 49.87126199201662, 50.45325443615185, 51.03556675050074, 51.61819563102705, 52.20113784299542, 52.78439021879579, 53.36794965585826, 53.95181311465373, 54.53597761677615, 55.12044024310192, 55.70519813202282, 56.29024847774884], [0.0, 0.4525877040618276, 0.9370963499542236, 1.4344323407784412, 1.9402859627347844, 2.4525691175901017, 2.9700349760632037, 3.4918509123781187, 4.017419998882241, 4.54629262307584, 5.0781175614752625, 5.61261264332054, 6.149546066600601, 6.688723921947668, 7.229981537737156, 7.77317728407639, 8.318188018363301, 8.864905661307736, 9.413234572378451, 9.963089503711029, 10.5143939810765, 11.067079005769077, 11.621082001476784, 12.176345950818815, 12.732818680596628, 13.290452264993428, 13.849202523302305, 14.409028594138656, 14.969892572080045, 15.53175919567155, 16.09459557800974, 16.658370972865285, 17.223056570658283, 17.788625319659875, 18.355051768629497, 18.922311927761683, 19.4903831453488, 20.05924399799538, 20.628874192568453, 21.199254478352888, 21.7703665681148, 22.34219306696913, 22.914717408108068, 23.487923794580702, 24.061797146426528, 24.63632305255977, 25.211487726881412, 25.787277968163465, 26.363681123307874, 26.940685053631558, 27.51827810387177, 28.096449073642034, 28.675187191100747, 29.25448208862156, 29.834323780278375, 30.414702640978597, 30.9956093870961, 31.57703505847122, 32.15897100165905, 32.741408854319296, 33.32434053065205, 33.9077582077929, 34.49165431308959, 35.07602151218987, 35.66085269787657, 36.24614097959229, 36.831879673600966, 37.418062293738565, 38.00468254270952, 38.59173430388885, 39.17921163359398, 39.76710875379279, 40.355420045217585, 40.94414004085708, 41.53326341980059, 42.122785001411145, 42.712699739805466, 43.30300271862108, 43.89368914605197, 44.484754350135724, 45.076193774276476, 45.66800297298898, 46.26017760785031, 46.852713443646586, 47.44560634470337, 48.03885227138844, 48.63244727677734, 49.22638750347197, 49.820669180563875, 50.41528862073373, 51.01024221747973, 51.60552644246753, 52.201137842995415, 52.79707303956821, 53.39332872357436, 53.98990165506064, 54.58678866059938, 55.183986631243485, 55.78149252056483, 56.3793033427717, 56.97741617090131, 57.57582813508384], [0.0, 0.46270404828873163, 0.9580425426254616, 1.4664951016517151, 1.9836556798558964, 2.5073895053539426, 3.0364218794504323, 3.5699015653269677, 4.107218292667061, 4.647912399129205, 5.191624810601837, 5.7380670491794055, 6.287002131559089, 6.838231814066422, 7.391587744298875, 7.946925126619911, 8.504118065915756, 9.063056067083162, 9.623641351811782, 10.185786766757367, 10.749414128321435, 11.31445289552329, 11.88083909333087, 12.44851442989779, 13.017425565838197, 13.587523504086443, 14.15876307639832, 14.731102508046172, 15.30450304633687, 15.878928641643354, 16.454345671966582, 17.030722703830453, 17.608030283696717, 18.186240755170065, 18.765328098117966, 19.345267786509318, 19.926036662320314, 20.50761282329484, 21.089975522703153, 21.67310507953373, 22.256982797792233, 22.84159089377914, 23.426912430381552, 24.01293125755148, 24.599631958257685, 25.186999799294497, 25.775020686412848, 26.363681123307874, 26.95296817405656, 27.54286942864921, 28.133372971301956, 28.724467351274722, 29.316141555951226, 29.908384985965554, 30.501187432183894, 31.094539054371378, 31.68843036139214, 32.28285219280696, 32.877795701747154, 33.473252338955476, 34.06921383789637, 34.66567220084695, 35.262619685889305, 35.86004879473206, 36.457952261295894, 37.0563230410041, 37.655154300724185, 38.25443940931192, 38.85417192871312, 39.4543456055826, 40.054954363383246, 40.65599229493102, 41.25745365535507, 41.859332855444215, 42.46162445535357, 43.06432315864737, 43.66742380665559, 44.2709213731241, 44.874810959139324, 45.47908778831009, 46.08374720219045, 46.68878465592865, 47.294195714128335, 47.89997604690917, 48.506121426155154, 49.11262772193928, 49.71949089911453, 50.32670701406137, 50.93427221158312, 51.54218272194066, 52.15043485801882, 52.759025012617116, 53.36794965585825, 53.977205332707804, 54.586788660599375, 55.19669632715955, 55.806925088027484, 56.41747176476418, 57.02833324284707, 57.63950646974531, 58.25098845307198, 58.862776258809276], [0.0, 0.4728309366087107, 0.9790105671561282, 1.4985912809938853, 2.0270706004935857, 2.5622670314731044, 3.102877976774974, 3.648033569140398, 4.1971101816821745, 4.749638091742242, 5.305250366398552, 5.863652214026139, 6.424601464630063, 6.987895535711592, 7.553362390253845, 8.120854063576816, 8.690241905186134, 9.261413001647494, 9.834267434643277, 10.408716143363351, 10.984679233058076, 11.562084618864361, 12.140866925572192, 12.720966585541253, 13.30232909198289, 13.884904375466048, 14.468646279179929, 15.05351211410187, 15.639462279384945, 16.22645993640846, 16.814470727311587, 17.403462530655137, 17.99340524827134, 18.584270618468203, 19.176032051628273, 19.76866448493591, 20.36214425352342, 20.956448975774933, 21.551557450891156, 22.147449567115675, 22.744106219267657, 23.34150923442787, 23.939641304792353, 24.538485926848026, 25.138027346141588, 25.738250507011728, 26.33914100673815, 26.940685053631558, 27.54286942864921, 28.145681450171974, 28.749108941623337, 29.353140201648678, 29.957763976606078, 30.562969435148528, 31.168746144701856, 31.77508404966468, 32.3819734511751, 32.989404988305616, 33.59736962056214, 34.205858611575664, 34.8148635138866, 35.424376154731355, 36.034388622749915, 36.64489325554093, 37.255882627997345, 37.86734954136259, 38.47928701295207, 39.09168826649021, 39.70454672301752, 40.317855992326116, 40.93160986488584, 41.54580230422616, 42.160427439742136, 42.77547955989534, 43.39095310578269, 44.00684266504896, 44.62314296611981, 45.23984887273491, 45.85695537876152, 46.47445760327083, 47.09235078586067, 47.710630282209195, 48.329291559845565, 48.948330194124296, 49.5677418643915, 50.18752235033127, 50.80766752848208, 51.42817336891306, 52.049035932051474, 52.670251365652504, 53.29181590190358, 53.9137258546559, 54.535977616776144, 55.15856765761189, 55.781492520564825, 56.404748820765874, 57.02833324284707, 57.65224253880509, 58.27647352595193, 58.90102308494808, 59.525888157914295, 60.151065746617924], [0.0, 0.4829681644624228, 1.0000000000000002, 1.5307202304741792, 2.070529847682755, 2.617200587442164, 3.1694019256486143, 3.726245345581266, 4.287093850145173, 4.851467646094154, 5.418991933671841, 5.989365601087564, 6.562341286358657, 7.137712063732194, 7.715302207814954, 8.294960581647878, 8.876555776542762, 9.459972458265128, 10.045108566305142, 10.631873130439274, 11.220184543019636, 11.809969173724447, 12.401160245736166, 12.993696914317956, 13.587523504086443, 14.182588872150292, 14.778845872122783, 15.376250899752756, 15.974763505173522, 16.574346059965194, 17.17496346965384, 17.776582924134786, 18.379173679952565, 18.98270686950049, 19.587155333094753, 20.192493470587124, 20.798697109748524, 21.405743389113894, 22.013610653350806, 22.62227835951816, 23.231726992830847, 23.84193799075253, 24.45289367440972, 25.064577186463342, 25.67697243469354, 26.29006404065413, 26.903837292838645, 27.51827810387177, 28.133372971301956, 28.749108941623337, 29.365473577200483, 29.982454925808348, 30.6000414925333, 31.21822221381037, 31.836986433396902, 32.4563238801051, 33.076224647134964, 33.696679172865984, 34.317678222981, 34.93921287380821, 35.56127449677925, 36.18385474391109, 36.80694553422866, 37.43053904105304, 38.05462768008708, 38.67920409823695, 39.30426116311324, 39.92979195316086, 40.55578974837115, 41.18224802153378, 41.80916042998978, 42.4365208078501, 43.06432315864736, 43.69256164839098, 44.32123059899813, 44.950324482075736, 45.57983791302991, 46.20976564548181, 46.84010256597002, 47.470843688921384, 48.10198415187341, 48.733519210932606, 49.365444236454536, 49.9977547089318, 50.63044621507816, 51.263514444096494, 51.89695518412061, 52.5307643188202, 53.16493782416032, 53.79947176530619, 54.43436229366547, 55.069605644060424, 55.705198132022815, 56.341136151205056, 56.9774161709013, 57.6140347336728, 58.25098845307198, 58.88827401146016, 59.5258881579143, 60.16382770621803, 60.80208953293288, 61.4406705755458], [0.0, 0.493115535273975, 1.0210104341408237, 1.5628813270645834, 2.114032578684103, 2.6721891080179425, 3.235992436073254, 3.804535378007152, 4.377167553139178, 4.9533990875587515, 5.532847306803908, 6.115204772594528, 6.700218925765303, 7.287678492963401, 7.8774040567288015, 8.46924130464932, 9.063056067083162, 9.658730586573514, 10.256160658274919, 10.85525340063996, 11.455925491408637, 12.058101753254142, 12.661714006349007, 13.266700127582057, 13.873003271805944, 14.480571221594984, 15.089355839996403, 15.699312606614793, 16.3104002217142, 16.922580266285312, 17.535816908504053, 18.15007664891121, 18.765328098117966, 19.38154178199669, 19.998689970226824, 20.616746524789903, 21.235686765587833, 21.85548735082624, 22.476126170184767, 23.097582249106193, 23.719835662791315, 24.342867458696837, 24.966659586508467, 25.59119483470712, 26.21645677296841, 26.84242969973833, 27.469098594415264, 28.096449073642034, 28.724467351274722, 29.353140201648678, 29.982454925808348, 30.612399320407256, 31.242961649018643, 31.874130615627234, 32.505895340098085, 33.13824533544129, 33.77117048671068, 34.40466103139195, 35.03870754115092, 35.673300904825574, 36.30843231255758, 36.94409324096917, 37.58027543930046, 38.21697091643061, 38.854171928713114, 39.49187096856244, 40.13006075373456, 40.76873421724953, 41.407884497908384, 42.04750493136128, 42.68758904168721, 43.32813053344913, 43.96912328419127, 44.61056133734837, 45.25243889553863, 45.89475031421504, 46.537490095651044, 47.1806528832391, 47.82423345608176, 48.4682267238568, 49.11262772193928, 49.75743160676447, 50.40263365141706, 51.048229241432864, 51.69421387080057, 52.340583138151345, 52.98733274312585, 53.634458482907895, 54.28195624891582, 54.92982202364225, 55.57805187763426, 56.22664196660608, 56.87558852867721, 57.52488788172913, 58.174536420874325, 58.82453061603176, 59.47486700960313, 60.12554221424472, 60.77655291073019, 61.42789584589938, 62.07956783068903, 62.73156573824134], [0.0, 0.503272859988785, 1.0420414781354437, 1.5950739715751405, 2.157577983002893, 2.727231568715184, 3.302648267408203, 3.882902207804819, 4.467329612510646, 5.0554305170622325, 5.646814364567451, 6.241167384050864, 6.838231814066423, 7.437792029396682, 8.039664916893146, 8.643692985575594, 9.24973930214033, 9.85768368353118, 10.467419778463615, 11.078852792191446, 11.691897686160639, 12.306477734521847, 12.922523353061415, 13.539971139039835, 14.158763076398317, 14.778845872122783, 15.400170397722723, 16.022691215759806, 16.646366175795155, 17.271156067454495, 17.897024320840334, 18.523936746462695, 19.15186130836581, 19.78076792530613, 20.410628295766593, 21.041415743330898, 21.673105079533727, 22.30567248178024, 22.93909538431582, 23.57335238054376, 24.208423135248538, 24.844288305497354, 25.48092946917074, 26.11832906022218, 26.756470309891093, 27.3953371931987, 28.03491438014505, 28.675187191100747, 29.316141555951226, 29.957763976606078, 30.6000414925333, 31.242961649018643, 31.886512467885304, 32.530682420439696, 33.17546040243497, 33.820835710867414, 34.46679802244051, 35.113337373549086, 35.76044414165165, 36.408109027912026, 37.0563230410041, 37.705077481983295, 38.3543639301384, 39.00417422974533, 39.65450047765191, 40.30533501162934, 40.95667039943203, 41.60849942851248, 42.26081509634294, 42.9136106012995, 43.566879334068446, 44.22061486953763, 44.87481095913931, 45.52946152361332, 46.184560646161856, 46.840102565970014, 47.496081672067625, 48.1524924975103, 48.80932971385918, 49.466588125940234, 50.124262666865846, 50.78234839330225, 51.44084048096789, 52.09973422034863, 52.759025012617116, 53.418708365743974, 54.0787798907899, 54.739235298368015, 55.400070395266965, 56.061281081225715, 56.72286334585142, 57.38481326567268, 58.0471270013208, 58.70980079483199, 59.37283096706432, 60.03621391522319, 60.69994611048978, 61.36402409574697, 62.02844448339811, 62.69320395327358, 63.35829925062096, 64.0237271841746], [0.0, 0.5134399566465774, 1.0630927552296783, 1.6272975873006033, 2.201165280558346, 2.7823269834926223, 3.369368225568033, 3.9613444310957524, 4.5575784130790415, 5.157560106793874, 5.760891065334599, 6.3672511789380355, 6.976377478872495, 7.58804998386917, 8.202081881535618, 8.818312499265616, 9.436602137434761, 10.056828185053947, 10.678882142334574, 11.302667299491072, 11.928096900024192, 12.55509266807229, 13.183583613684414, 13.813505053261643, 14.444797798707267, 15.077407480384029, 15.711283977309765, 16.346380934120976, 16.98265534885743, 17.62006721901856, 18.258579235923374, 18.898156519387296, 19.538766386265554, 20.180378147614615, 20.822962930171386, 21.466493518603748, 22.110944215590102, 22.756290717272556, 23.402510002024105, 24.049580230792884, 24.69748065755223, 25.346191548604246, 25.995694109666594, 26.645970419824252, 27.29700337155485, 27.948776616143682, 28.6012745138948, 29.25448208862156, 29.908384985965554, 30.562969435148528, 31.21822221381037, 31.874130615627234, 32.530682420439696, 33.18786586665201, 33.8456696256898, 34.504082778327735, 35.163094792718496, 35.82269550397261, 36.4828750951544, 37.14362407957301, 37.80493328425994, 38.466793834534904, 39.12919713957184, 39.79213487888511, 40.45559898966335, 41.11958165488578, 41.784075292160885, 42.449072543233605, 43.11456626411142, 43.78054951576431, 44.44701555535747, 45.11395782797893, 45.78136995882766, 46.44924574583053, 47.117579152658834, 47.786364302117946, 48.45559546988512, 49.12526707857298, 49.79537369209778, 50.46591001033281, 51.13687086402941, 51.808251209988796, 52.48004612646948, 53.15225080881592, 53.82486056529547, 54.497870813130945, 55.171277074717906, 55.84507497401543, 56.51926023310112, 57.19382866888063, 57.868776189943326, 58.544098793556024, 59.219792562787255, 59.895853663755005, 60.57227834299148, 61.2490629249186, 61.926203809428465, 62.603697469563436, 63.28154044929079, 63.95972936136697, 64.6382608852872, 65.317131765316], [0.0, 0.5236166499862263, 1.0841639025401355, 1.6595516187680217, 2.244793719989568, 2.8374744026116314, 3.4361511604294215, 4.039860695687401, 4.647912399129205, 5.259786096236642, 5.875075442643178, 6.493453983814737, 7.114653538818853, 7.738449766223699, 8.364652150901183, 8.993096835615955, 9.623641351811782, 10.25616065827492, 10.890544104684727, 11.526693064408649, 12.164519061380675, 12.803942268263796, 13.444890288042906, 14.087297155050672, 14.731102508046174, 15.376250899752758, 16.02269121575981, 16.670376181912218, 17.31926194392466, 17.96930770642258, 18.62047542124417, 19.2727295168583, 19.926036662320314, 20.58036556041309, 21.235686765587833, 21.891972523087937, 22.549196626255192, 23.20733428951442, 23.86636203493591, 24.52625759060446, 25.186999799294494, 25.848568536174177, 26.51094463444703, 27.174109817994545, 27.83804664021283, 28.502738428345662, 29.168169232708777, 29.834323780278375, 30.501187432183894, 31.168746144701856, 31.836986433396902, 32.505895340098085, 33.17546040243497, 33.8456696256898, 34.51651145674893, 35.187974759961335, 35.86004879473205, 36.53272319469729, 37.205987948343704, 37.87983338094845, 38.55425013772918, 39.22922916810404, 39.904761710971556, 40.580839280928956, 41.25745365535507, 41.934596862290974, 42.61226116905753, 43.290439071554566, 43.96912328419128, 44.648306730401835, 45.32798253370432, 46.00814400926443, 46.68878465592866, 47.369898148695015, 48.05147833159107, 48.73351921093262, 49.41601494893733, 50.098959857670636, 50.782348393302264, 51.46617515065377, 52.15043485801882, 52.835122372239354, 53.52023267402198, 54.20576086347993, 54.89170215588756, 55.57805187763426, 56.26480546236671, 56.9519584473082, 57.6395064697453, 58.32744526367218, 59.01577065658395, 59.70447856641081, 60.39356499858532, 61.08302604323558, 61.772857872497774, 62.46305673794162, 63.15361896810288, 63.844540966117485, 64.535819207452, 65.22745023772566, 65.91943067061924, 66.61175718586661], [0.0, 0.5338027710795276, 1.1052545702959267, 1.6918355305760207, 2.288462577085494, 2.8926729106516356, 3.5029959634278414, 4.118449698247619, 4.7383300711605125, 5.362106788488384, 5.989365601087563, 6.619773703775239, 7.253057698589555, 7.888988879896377, 8.52737302640173, 9.168043093290875, 9.810853840510596, 10.455677794371125, 11.102402152027521, 11.750926368224468, 12.401160245736165, 13.053022404312953, 13.706439038572054, 14.361342899590001, 15.017672451894864, 15.67537116957226, 16.334386943862796, 16.99467158096859, 17.656180373489608, 18.318871732442812, 18.98270686950049, 19.647649521144498, 20.313665708030175, 20.980723524103297, 21.64879295099921, 22.31784569403707, 22.987855036750233, 23.658795711399947, 24.330643783331077, 25.00337654736408, 25.676972434693536, 26.351410928991317, 27.026672490601694, 27.702738487873628, 28.37959113480756, 29.05721343430557, 29.7355891264079, 30.414702640978597, 31.094539054371378, 31.77508404966468, 32.4563238801051, 33.13824533544129, 33.820835710867414, 34.504082778327735, 35.187974759961335, 35.87250030349099, 36.55764845938069, 37.24340865960569, 37.929770697894746, 38.6167247113188, 39.30426116311324, 39.99237082663168, 40.681044770339476, 41.370274343763974, 42.06005116432612, 42.75036710498532, 43.4412142826356, 44.13258504719655, 44.8244719713479, 45.51686784086059, 46.20976564548181, 46.90315857033451, 47.59703998779571, 48.29140344982065, 48.986242680682345, 49.68155157009908, 50.37732416672386, 51.07355467197247, 51.77023743416832, 52.4673669429839, 53.16493782416031, 53.86294483448761, 54.56138285703008, 55.260246896581556, 55.95953207533723, 56.659233628768895, 57.35934690169218, 58.05986734451421, 58.76079050965196, 59.46211204811132, 60.163827706218015, 60.86593332249213, 61.56842482465833, 62.27129822678444, 62.974549626541695, 63.67817520258012, 64.38217121201305, 65.08653398800519, 65.79125993745896, 66.49634553879417, 67.20178733981619, 67.90758195566845], [0.0, 0.5439981569912912, 1.1263644211348778, 1.7241488063174952, 2.332171153327673, 2.9479216246681545, 3.5699015653269677, 4.1971101816821745, 4.828829982869662, 5.464520546847428, 6.103759712504854, 6.7462083182341415, 7.391587744298876, 8.039664916893145, 8.690241905186134, 9.34314847388444, 9.998236608917042, 10.655376401905686, 11.31445289552329, 11.975363624146691, 12.638016667824814, 13.302329091982886, 13.968225681589473, 14.635637903297791, 15.304503046336869, 15.97476350517352, 16.646366175795155, 17.319261943924655, 17.99340524827134, 18.668753705521834, 19.345267786509314, 20.022910535099225, 20.701647322957147, 21.381445634637984, 22.062274878440203, 22.74410621926766, 23.426912430381545, 24.110667761441004, 24.795347820650054, 25.48092946917074, 26.16739072624343, 26.85471068368762, 27.54286942864921, 28.231847973621242, 28.921628192899796, 29.612192764750247, 30.30352511865513, 30.9956093870961, 31.68843036139214, 32.3819734511751, 33.076224647134964, 33.77117048671068, 34.46679802244051, 35.163094792718496, 35.86004879473205, 36.55764845938069, 37.255882627997345, 37.95474053071288, 38.65421176632099, 39.35428628351525, 40.05495436338324, 40.75620660305391, 41.45803390040443, 42.160427439742136, 42.86337867838458, 43.566879334068446, 44.2709213731241, 44.97549699935812, 45.68059864359187, 46.386218953807855, 47.09235078586067, 47.79898719471227, 48.50612142615514, 49.213746908989854, 49.921857247625944, 50.63044621507815, 51.339507746331485, 52.049035932051474, 52.759025012617116, 53.469469372456196, 54.18036353466395, 54.89170215588754, 55.603480021460186, 56.31569204076957, 57.02833324284706, 57.74139877216419, 58.45488388462469, 59.16878394374059, 59.88309441698209, 60.59781087229129, 61.31292897475071, 62.028444483398104, 62.74435324817954, 63.46065120703341, 64.17733438309826, 64.8943988820381, 65.61184088947886, 66.32965666855038, 67.04784255752861, 67.76639496757278, 68.48531038055295, 69.20458534696336], [0.0, 0.554202650463427, 1.1474931294494186, 1.756490947578351, 2.3759187745359123, 3.003219692480865, 3.6368669341455413, 4.275840932697377, 4.919410738346441, 5.567025791639184, 6.218256012430256, 6.872755877008665, 7.5302415391988164, 8.190475553120923, 8.853256275093589, 9.518410276494691, 10.185786766757365, 10.85525340063996, 11.526693064408647, 12.200001370356947, 12.875084674269594, 13.551858485858228, 14.230246179183512, 14.910177935327964, 15.59158986717168, 16.274423288598236, 16.95862409945279, 17.644142264156727, 18.330931366765924, 19.018948228927098, 19.708152579972523, 20.398506770532517, 21.089975522703153, 21.78252571110409, 22.476126170184763, 23.170747523950965, 23.866362034935904, 24.5629434697655, 25.260466979094574, 25.958908990039347, 26.658247109517994, 27.3584600371476, 28.059527486542294, 28.76143011402132, 29.464149453872942, 30.167667859435827, 30.871968449357382, 31.57703505847122, 32.28285219280696, 32.989404988305616, 33.696679172865984, 34.40466103139195, 35.113337373549086, 35.82269550397261, 36.53272319469729, 37.24340865960569, 37.95474053071288, 38.66670783612503, 39.37929997952663, 40.09250672106559, 40.80631815951901, 41.52072471563372, 42.23571711654634, 42.95128638119658, 43.667423806655584, 44.38412095529869, 45.101369642758044, 45.819161926596756, 46.537490095651044, 47.25634665999191, 47.97572434146176, 48.69561606474527, 49.416014948937324, 50.136914299573796, 50.85830760109368, 51.580188509703895, 52.302550846619944, 53.02538859165814, 53.74869587715667, 54.47246698220457, 55.19669632715954, 55.92137846843641, 56.64650809354997, 57.372080016396545, 58.098089172760496, 58.82453061603175, 59.55139951312277, 60.27869114057283, 61.006400880829474, 61.73452421869682, 62.46305673794161, 63.19199411804824, 63.92133213111476, 64.65106663888204, 65.38119358988943, 66.1117090167497, 66.8426090335375, 67.57388983328528, 68.30554768558116, 69.03757893426375, 69.76997999520889, 70.50274735420385], [0.0, 0.5644160996209375, 1.1686403807778345, 1.788861473005679, 2.4197047896078465, 3.0585662910803824, 3.703891073227998, 4.3546407795317235, 5.0100709894639675, 5.6696209972628155, 6.3328527967982735, 6.9994144966726335, 7.669017019684284, 8.341418544042533, 9.016413709956934, 9.693825892674104, 10.37350152269462, 11.055305815774785, 11.739119499881527, 12.424836263538179, 13.11236073675204, 13.801606872155824, 14.492496631664055, 15.184958909660308, 15.878928641643355, 16.574346059965194, 17.271156067454495, 17.96930770642258, 18.668753705521837, 19.36945009066132, 20.071355849021657, 20.774432637389623, 21.478644527721716, 22.183957784167067, 22.890340666822443, 23.597763258320867, 24.306197310019357, 25.01561610508667, 25.72599433622688, 26.437307996129462, 27.149534279028533, 27.862651491994555, 28.57663897478207, 29.29147702722394, 30.007146843302213, 30.72363045114369, 31.440910658287855, 32.15897100165905, 32.877795701747154, 33.59736962056214, 34.317678222981, 35.03870754115092, 35.76044414165165, 36.4828750951544, 37.205987948343704, 37.929770697894746, 38.65421176632099, 39.37929997952663, 40.10502454591572, 40.83137503692504, 41.558341368861186, 42.285913785934106, 43.014082844389996, 43.742839397655814, 44.47217458241568, 45.2020798055472, 45.9325467318521, 46.66356727252161, 47.39513357428225, 48.12723800917245, 48.85987316490482, 49.593031835772436, 50.32670701406137, 51.06089188193463, 51.79557980375537, 52.5307643188202, 53.26643913447525, 54.00259811959035, 54.73923529836802, 55.47634484446614, 56.21392107541469, 56.95195844730819, 57.69045154975717, 58.429395101082825, 59.1687839437406, 59.908613039958944, 60.64887746758091, 61.389572416096705, 62.1306931828566, 62.872235169453766, 63.614193878267805, 64.35656490915994, 65.09934395631186, 65.84252680520008, 66.58610932969924, 67.33008748930676, 68.07445732648327, 68.81921496410224, 69.56435660300374, 70.30987851964666, 71.05577706385466, 71.80204865665132], [0.0, 0.5746383576979491, 1.1898058712370032, 1.8212599174394368, 2.4635285693444, 3.11396062514362, 3.7709730194465845, 4.433508589842146, 5.100809433446775, 5.772304689439187, 6.447548418868717, 7.126182357158925, 7.807912191570517, 8.49249172062775, 9.179711865226045, 9.869392801724151, 10.561378179293314, 11.255530772584194, 11.951729149402972, 12.649865072843582, 13.349841445647433, 14.051570662025366, 14.754973270527806, 15.459976877729634, 16.166515240732828, 16.874527509425004, 17.583957588758434, 18.29475359813908, 19.006867410078062, 19.720254254060475, 20.434872374475187, 21.15068273366702, 21.867648752892155, 22.585736085302674, 23.304912416147314, 24.025147286219408, 24.746411935258877, 25.468679162560374, 26.19192320248223, 26.916119612912503, 27.641245175045306, 28.367277803065917, 29.094196462546854, 29.82198109652713, 30.55061255838906, 31.28007255076709, 32.01034356982446, 32.741408854319296, 33.473252338955476, 34.205858611575664, 34.93921287380821, 35.673300904825574, 36.408109027912026, 37.14362407957301, 37.87983338094845, 38.6167247113188, 39.35428628351525, 40.09250672106559, 40.83137503692504, 41.57088061365649, 42.311013184938645, 43.0517628182923, 43.79311989892585, 44.53507511461076, 45.277619441505784, 46.02074413085668, 46.76444069650465, 47.508700903142824, 48.253516755265444, 48.99888048675934, 49.74478455109162, 50.4912216120513, 51.238184535006276, 51.98566637864029, 52.73366038713708, 53.48215998278211, 54.23115875895394, 54.98065047348022, 55.73062904233454, 56.481088533652695, 57.23202316204825, 57.9834272832089, 58.73529538875648, 59.487622101354575, 60.240402170049286, 60.99363046582892, 61.74730197739032, 62.50141180709954, 63.25595516713616, 64.01092737581067, 64.76632385404531, 65.52214012200949, 66.27837179590128, 67.03501458486714, 67.79206428805253, 68.54951679177653, 69.30736806682391, 70.06561416584873, 70.82425122088362, 71.58327544094968, 72.34268310976147, 73.10247058352297], [0.0, 0.5848692827820962, 1.2109893069931357, 1.8536858311022992, 2.5073895053539426, 3.169401925648614, 3.838111841523925, 4.512443268731855, 5.191624810601837, 5.875075442643178, 6.562341286358655, 7.253057698589554, 7.946925126619911, 8.643692985575594, 9.34314847388444, 10.045108566305142, 10.749414128321435, 11.455925491408637, 12.164519061380673, 12.875084674269596, 13.587523504086441, 14.301746385298863, 15.017672451894864, 15.735228021548748, 16.454345671966582, 17.17496346965384, 17.897024320840334, 18.62047542124417, 19.345267786509318, 20.071355849021657, 20.798697109748524, 21.52725183600399, 22.256982797792233, 22.987855036750233, 23.719835662791315, 24.452893674409715, 25.186999799294497, 25.922126352455926, 26.658247109518, 27.395337193198703, 28.13337297130195, 28.87233196479472, 29.612192764750255, 30.352934957111202, 31.094539054371374, 31.8369864333969, 32.58025927871075, 33.32434053065205, 34.06921383789637, 34.8148635138866, 35.56127449677925, 36.30843231255758, 37.0563230410041, 37.80493328425994, 38.55425013772918, 39.30426116311324, 40.05495436338324, 40.80631815951901, 41.558341368861186, 42.311013184938645, 43.06432315864737, 43.818261180669175, 44.57281746502966, 45.32798253370432, 46.08374720219045, 46.84010256597002, 47.59703998779572, 48.35455108573835, 49.11262772193929, 49.87126199201662, 50.63044621507815, 51.39017292429818, 52.15043485801881, 52.91122495133985, 53.672536328163694, 54.43436229366547, 55.19669632715954, 55.95953207533722, 56.72286334585143, 57.48668410122637, 58.25098845307197, 59.01577065658394, 59.78102510531235, 60.5467463261821, 61.312928974750726, 62.079567830689015, 62.846657793472026, 63.614193878267805, 64.38217121201305, 65.1505850296649, 65.91943067061922, 66.688703575286, 67.45839928181363, 68.22851342295371, 68.99904172305925, 69.76997999520887, 70.54132413845079, 71.31307013516002, 72.08521404850353, 72.85775202000738, 73.63068026722098, 74.40399508147375], [0.0, 0.5951087375757448, 1.2321904037673836, 1.8861387788428812, 2.5512870090286333, 3.2248894485805932, 3.9053066384660884, 4.591443756908113, 5.282515902199047, 5.977931877705152, 6.6772298587633, 7.380038818314563, 8.086053959297644, 8.795020309785496, 9.506721342634894, 10.22097082833523, 10.937606846361925, 11.656487282978036, 12.377486380202734, 13.100492045399564, 13.82540372240792, 14.55213068465188, 15.280590650377672, 16.01070864728445, 16.742416072699086, 17.475649908841667, 18.210352062386903, 18.946468804594943, 19.683950293528223, 20.422750163808853, 21.162825172362826, 21.904134890894014, 22.646641437611617, 23.390309242127692, 24.13510483854048, 24.880996682593, 25.627954989496544, 26.375951589573248, 27.124959799330306, 27.87495430595282, 28.625911063509864, 29.377807199422282, 30.130620929951807, 30.884331483647017, 31.63891903182901, 32.39436462532398, 33.150650136754834, 33.9077582077929, 34.66567220084695, 35.424376154731355, 36.18385474391109, 36.94409324096917, 37.705077481983295, 38.466793834534904, 39.22922916810404, 39.99237082663168, 40.75620660305391, 41.52072471563372, 42.285913785934106, 43.0517628182923, 43.818261180669175, 44.585398586760164, 45.3531650792653, 46.12155101422595, 46.89054704634395, 47.66014411520762, 48.43033343235519, 49.201106469112894, 49.97245494515055, 50.74437081770224, 51.51684627140442, 52.28987370870779, 53.06344574082278, 53.83755517916217, 54.61219502724681, 55.387358473043804, 56.163038881708225, 56.9392297887024, 57.71592489326825, 58.493118052230386, 59.27080327410917, 60.04897471352459, 60.82762666587316, 61.606753562261275, 62.386349964679944, 63.16641056140636, 63.946930162619374, 64.72790369621632, 65.50932620381994, 66.29119283696457, 67.0734988534517, 67.85623961386538, 68.63941057823929, 69.42300730286648, 70.20702543724512, 70.99146072115235, 71.77630898183996, 72.56156613134542, 73.34722816391253, 74.13329115351608, 74.91975125148517, 75.70660468422058], [0.0, 0.6053565891726884, 1.2534088863734787, 1.9186183394279952, 2.5952205105870902, 3.2804224737218965, 3.9725565380971877, 4.670509028959372, 5.37348152848905, 6.0808726595678335, 6.792212644850485, 7.507124068142782, 8.225296883737503, 8.946471729057112, 9.67042834833218, 10.396977305155168, 11.12595389070853, 11.857213544037872, 12.590628341593217, 13.326084260487999, 14.06347901297116, 14.80272031014307, 15.54372445334722, 16.286415179249772, 17.030722703830453, 17.776582924134786, 18.5239367464627, 19.2727295168583, 20.02291053509923, 20.774432637389623, 21.52725183600399, 22.281327006465574, 23.03661961465409, 23.79309347765479, 24.550714553278635, 25.30945075407234, 26.06927178234918, 26.830148983345694, 27.592055214075774, 28.354964725834495, 29.118853058616793, 29.88369694597466, 30.64947422905096, 31.416163778707112, 32.18374542481173, 32.95219989188372, 33.72150874039014, 34.49165431308959, 35.262619685889305, 36.034388622749915, 36.80694553422866, 37.58027543930046, 38.3543639301384, 39.12919713957184, 39.904761710971556, 40.681044770339476, 41.45803390040443, 42.23571711654634, 43.014082844389996, 43.79311989892585, 44.57281746502966, 45.3531650792653, 46.13415261286682, 46.91577025580529, 47.6980085018553, 48.48085813458366, 49.264310214190125, 50.048356065136026, 50.83298726450281, 51.61819563102704, 52.40397321476359, 53.19031228733234, 53.97720533270779, 54.76464503851429, 55.552624287792376, 56.34113615120505, 57.13017387965448, 57.919730897282776, 58.70980079483199, 59.50037732334042, 60.29145438815436, 61.08302604323556, 61.87508648574653, 62.66763005089655, 63.46065120703341, 64.25414455096572, 65.04810480350292, 65.84252680520008, 66.637405512296, 67.43273599283383, 68.2285134229537, 69.0247330833484, 69.8213903558727, 70.61848072029845, 71.41599975120762, 72.21394311501574, 73.01230656711931, 73.81108594916053, 74.6102771864036, 75.40987628521657, 76.20987933065393, 77.0102824841346], [0.0, 0.6156127088490789, 1.2746444882848518, 1.9511241048800303, 2.6391894581780972, 3.33600030351903, 4.039860695687401, 4.749638091742242, 5.464520546847428, 6.183896495186195, 6.907288200314882, 7.63431185174915, 8.364652150901184, 9.098045341000534, 9.834267434643277, 10.573125785937576, 11.314452895523292, 12.058101753254144, 12.803942268263796, 13.551858485858231, 14.301746385298866, 15.05351211410187, 15.80707055556482, 16.562344154279266, 17.31926194392466, 18.077758735496438, 18.837774434112635, 19.599253459854843, 20.362144253523425, 21.12639885226038, 21.891972523087937, 22.658823444787014, 23.42691243038155, 24.196202683935788, 24.966659586508463, 25.738250507011728, 26.510944634447025, 27.284712828573923, 28.059527486542294, 28.835362423405495, 29.612192764750247, 30.38999484994192, 31.168746144701856, 31.948425161915733, 32.729011389724185, 33.51048522607556, 34.29282791902922, 35.07602151218987, 35.86004879473206, 36.64489325554093, 37.43053904105304, 38.21697091643061, 39.00417422974533, 39.79213487888511, 40.580839280928956, 41.370274343763974, 42.160427439742136, 42.95128638119658, 43.742839397655814, 44.53507511461076, 45.32798253370432, 46.12155101422595, 46.91577025580529, 47.71063028220921, 48.50612142615515, 49.30223431506257, 50.098959857670636, 50.8962892314573, 51.69421387080057, 52.49272545582777, 53.29181590190358, 54.091477349711546, 54.89170215588755, 55.692482884167646, 56.49381229701487, 57.29568334769346, 58.09808917276049, 58.90102308494807, 59.70447856641082, 60.508449262315374, 61.31292897475072, 62.11791165693918, 62.92339140772996, 63.729362466357905, 64.535819207452, 65.34275613627848, 66.15016788420529, 66.9580492043747, 67.76639496757278, 68.57520015828402, 69.38445987092145, 70.19416930622197, 71.0043237677985, 71.81491865883991, 72.62594947895151, 73.43741182112804, 74.24930136885274, 75.06161389331577, 75.87434525074598, 76.68749137985026, 77.50104829935496, 78.31501210564471], [0.0, 0.6258769718674743, 1.2958969512289056, 1.9836556798558964, 2.683193317040532, 3.3916222620208005, 4.107218292667061, 4.828829982869662, 5.5556318500353195, 6.287002131559087, 7.02245512557937, 7.7616006222446545, 8.504118065915756, 9.249739302140329, 9.998236608917042, 10.749414128321433, 11.503101568235094, 12.259149467375194, 13.017425565838193, 13.777811975588774, 14.540202941524836, 15.304503046336867, 16.0706257541506, 16.838492216457077, 17.608030283696714, 18.379173679952565, 19.15186130836581, 19.92603666232031, 20.70164732295715, 21.478644527721713, 22.256982797792233, 23.03661961465409, 23.81751513795707, 24.599631958257685, 25.382934879404488, 26.167390726243433, 26.952968174056558, 27.73963759674099, 28.52737093121746, 29.316141555951226, 30.10592418179176, 30.89669475360482, 31.68843036139214, 32.48110915977942, 33.274710294908004, 34.06921383789636, 34.864600724148126, 35.66085269787657, 36.457952261295894, 37.255882627997345, 38.05462768008708, 38.854171928713114, 39.65450047765191, 40.45559898966335, 41.25745365535507, 42.06005116432612, 42.86337867838458, 43.667423806655584, 44.47217458241568, 45.277619441505784, 46.08374720219045, 46.89054704634395, 47.6980085018553, 48.50612142615515, 49.31487599077597, 50.12426266686585, 50.93427221158312, 51.74489565530563, 52.55612428959466, 53.36794965585825, 54.18036353466395, 54.993357935654956, 55.80692508802747, 56.621057431530865, 57.435747607954944, 58.25098845307197, 59.06677298900314, 59.88309441698209, 60.699946110489776, 61.51732160873715, 62.33521461047387, 63.15361896810286, 63.97252868208197, 64.79193789559537, 65.61184088947886, 66.4322320773836, 67.25310600116504, 68.07445732648326, 68.89628083860367, 69.71857143838587, 70.54132413845078, 71.36453405951602, 72.18819642689049, 73.0123065671193, 73.83685990477153, 74.66185195936285, 75.48727834240616, 76.3131347545836, 77.13941698303395, 77.9661208987491, 78.79324245407466, 79.62077768030932], [0.0, 0.6361492572929871, 1.3171660248063464, 2.016212681064329, 2.727231568715184, 3.4472876938820294, 4.1746285354201635, 4.908083769292426, 5.646814364567451, 6.390188353882437, 7.137712063732194, 7.888988879896378, 8.643692985575596, 9.401551825198435, 10.16233393924725, 10.925840255254473, 11.691897686160639, 12.460354317630598, 13.231075719028318, 14.003942067466102, 14.778845872122783, 15.55569014964012, 16.334386943862796, 17.11485611217067, 17.897024320840334, 18.68082420619292, 19.466193668609645, 20.253075274052343, 21.041415743330898, 21.83116551356908, 22.62227835951816, 23.41471106482299, 24.208423135248545, 25.00337654736408, 25.799535527356838, 26.59686635558134, 27.395337193198703, 28.19491792786387, 28.995580035908713, 29.797296458869162, 30.600041492533297, 31.403790686958917, 32.2085207561345, 33.01420949614575, 33.820835710867414, 34.62837914433267, 35.436820419045006, 36.24614097959229, 37.0563230410041, 37.86734954136259, 38.67920409823695, 39.49187096856244, 40.30533501162934, 41.11958165488578, 41.934596862290974, 42.75036710498532, 43.566879334068446, 44.38412095529869, 45.2020798055472, 46.02074413085668, 46.84010256597002, 47.66014411520762, 48.48085813458366, 49.30223431506257, 50.12426266686585, 50.9469335047481, 51.77023743416832, 52.594165338289315, 53.41870836574399, 54.24385791911266, 55.069605644060424, 55.895943419087715, 56.72286334585142, 57.55035774001736, 58.37841912260775, 59.207040211811076, 60.0362139152232, 60.86593332249213, 61.696191698340265, 62.52698247594001, 63.35829925062096, 64.1901357738878, 65.02248594773017, 65.85534381920648, 66.68870357528601, 67.52255953793329, 68.35690615942124, 69.19173801785945, 70.0270498129258, 70.8628363617896, 71.6990925952158, 72.53581355384019, 73.3729943846064, 74.21063033735588, 75.0487167615629, 75.88724910320656, 76.7262229017732, 77.56563378738184, 78.40547747802714, 79.24574977693311, 80.08644657001275, 80.9275638234279], [0.0, 0.6464294478206125, 1.3384514661336602, 2.048794736718619, 2.7713037103044873, 3.502995963427841, 4.242090654151233, 4.987398545966972, 5.738067049179405, 6.493453983814736, 7.253057698589553, 8.01647516998616, 8.783375315996192, 9.553481176542268, 10.32655755171419, 11.102402152027521, 11.880839093330868, 12.661714006349005, 13.444890288042904, 14.230246179183512, 15.017672451894862, 15.807070555564817, 16.59835111266403, 17.391432685465283, 18.186240755170065, 18.98270686950049, 19.78076792530613, 20.58036556041309, 21.381445634637984, 22.183957784167063, 22.987855036750233, 23.79309347765479, 24.599631958257685, 25.40743184066843, 26.21645677296841, 27.02667249060169, 27.838046640212827, 28.65054862284039, 29.464149453872945, 30.27882163758085, 31.094539054371374, 31.911276859190533, 32.729011389724185, 33.54772008324215, 34.36738140108914, 35.187974759961335, 36.00948046922132, 36.831879673600966, 37.655154300724185, 38.47928701295207, 39.30426116311324, 40.13006075373456, 40.95667039943203, 41.784075292160885, 42.61226116905753, 43.4412142826356, 44.2709213731241, 45.101369642758044, 45.9325467318521, 46.76444069650465, 47.59703998779572, 48.43033343235519, 49.264310214190125, 50.098959857670636, 50.93427221158312, 51.77023743416832, 52.60684597906919, 53.444088582120166, 54.28195624891582, 55.12044024310191, 55.95953207533722, 56.79922349287854, 57.63950646974529, 58.48037319742423, 59.32181607607708, 60.16382770621802, 61.006400880829474, 61.849528577887966, 62.69320395327358, 63.53742033403863, 64.38217121201303, 65.22745023772563, 66.073251214622, 66.91956809356087, 67.76639496757278, 68.61372606686501, 69.46155575405908, 70.30987851964665, 71.15868897765225, 72.0079818614905, 72.85775202000737, 73.70799441369515, 74.55870411107196, 75.40987628521657, 76.26150621045056, 77.11358925915998, 77.9661208987491, 78.81909668871957, 79.67251227786866, 80.52636340160043, 81.38064587934409, 82.2353556120745], [0.0, 0.6567174296128961, 1.3597530395070003, 2.0814014860221213, 2.8154092537765925, 3.5587464537739892, 4.309603901820043, 5.066773434602939, 5.8293888933866675, 6.596797877846397, 7.3684907528742025, 8.144058080797485, 8.923163510408461, 9.705525673785633, 10.490905627791452, 11.279097863486458, 12.069923697507441, 12.863226303778516, 13.658866905211221, 14.456721804767607, 15.256680036200413, 16.058641480455794, 16.86251533755313, 17.668218873676572, 18.475676384054346, 19.284818326984517, 20.09558059502444, 20.90790389716106, 21.721733231565196, 22.537017432878542, 23.3537087812835, 24.171762663140512, 24.991137274942556, 25.811793363873704, 26.63369399947134, 27.456804371856094, 28.281091612766012, 29.10652463625449, 29.933073996417438, 30.76071175992825, 31.589411391498565, 32.41914765066318, 33.24989649852011, 34.08163501325134, 34.914341313411995, 35.747994488113136, 36.58257453333913, 37.418062293738565, 38.25443940931192, 39.09168826649021, 39.92979195316086, 40.76873421724953, 41.60849942851248, 42.449072543233605, 43.290439071554566, 44.13258504719655, 44.97549699935812, 45.819161926596756, 46.66356727252161, 47.508700903142824, 48.35455108573835, 49.201106469112894, 50.048356065136026, 50.8962892314573, 51.74489565530563, 52.594165338289315, 53.444088582120166, 54.29465597519263, 55.145858379954504, 55.9976869210117, 56.8501329739144, 57.70318815457624, 58.556844309282454, 59.41109350524662, 60.26592802167836, 61.121340341328406, 61.97732314247883, 62.83386929135005, 63.690971834897375, 64.54862399397256, 65.40681915682741, 66.2655508729384, 67.12481284713238, 67.98459893399544, 68.84490313254821, 69.70571958117122, 70.56704255276657, 71.42886645014163, 72.29118580160267, 73.15399525674611, 74.01728958243686, 74.88106365896301, 75.7453124763577, 76.61003113087881, 77.47521482163835, 78.34085884737348, 79.2069586033518, 80.07350957840404, 80.94050735207772, 81.80794759190543, 82.67582605078225, 83.54413856444671], [0.0, 0.6670130921471784, 1.3810705160859007, 2.114032578684103, 2.8595477253104837, 3.6145385659990716, 4.377167553139179, 5.146207582484604, 5.920778916128685, 6.700218925765301, 7.484009986501502, 8.271736241721142, 9.063056067083162, 9.85768368353118, 10.655376401905686, 11.455925491408637, 12.259149467375194, 13.064889045094626, 13.873003271805942, 14.683366511215587, 15.495866057407174, 16.3104002217142, 17.1268767806428, 17.945211703320876, 18.76532809811797, 19.587155333094756, 20.410628295766596, 21.235686765587833, 22.062274878440206, 22.890340666822443, 23.71983566279132, 24.550714553278635, 25.382934879404488, 26.216456772968414, 27.05124272453187, 27.887257378484936, 28.724467351274722, 29.56284106960588, 30.40234862593728, 31.242961649018643, 32.084653187555645, 32.92739760537664, 33.77117048671068, 34.61594855038382, 35.46170957190565, 36.30843231255758, 37.156096454711765, 38.00468254270952, 38.85417192871312, 39.70454672301752, 40.55578974837115, 41.407884497908384, 42.26081509634294, 43.11456626411142, 43.96912328419128, 44.8244719713479, 45.68059864359187, 46.537490095651044, 47.39513357428225, 48.253516755265444, 49.11262772193929, 49.97245494515055, 50.83298726450281, 51.69421387080057, 52.55612428959466, 53.41870836574399, 54.28195624891582, 55.145858379954504, 56.01040547805422, 56.87558852867721, 57.741398772164196, 58.6078276929876, 59.474867009603116, 60.34250866485835, 61.210744816920545, 62.07956783068903, 62.948970269659924, 63.818944888214084, 64.68948462430073, 65.56058259249177, 66.43223207738362, 67.30442652732485, 68.17715954845, 69.0504248990007, 69.92421648391742, 70.79852834968537, 71.6733546794203, 72.54868978817981, 73.4245281184879, 74.30086423606025, 75.17769282571946, 76.05500868748955, 76.9328067328601, 77.81108198121076, 78.6898295563878, 79.56904468342451, 80.44872268539795, 81.32885898041522, 82.2094490787223, 83.09048857992974, 83.97197317034875, 84.85389862043284], [0.0, 0.6773163280717155, 1.402403673595372, 2.146687674463743, 2.9037186646791615, 3.670371718364856, 4.444780903629862, 5.225700161360823, 6.012236164491718, 6.803716049211532, 7.599614194965078, 8.399508321470952, 9.203051527375958, 10.009953619244031, 10.819968159138174, 11.632883192031787, 12.448514429897788, 13.266700127582057, 14.087297155050669, 14.910177935327964, 15.735228021548746, 16.562344154279263, 17.391432685465283, 18.22240828622435, 19.055192877194287, 19.88971473539641, 20.72590774256479, 21.563710747937407, 22.403067024472623, 23.243923801936162, 24.086231863708857, 24.92994519677938, 25.775020686412844, 26.62141784857159, 27.46909859441526, 28.31802702220194, 29.16816923270877, 30.01949316493317, 30.871968449357386, 31.72556627648535, 32.58025927871074, 33.43602142386441, 34.29282791902922, 35.15065512341094, 36.009480469221316, 36.869282389670936, 37.730040253289076, 38.59173430388885, 39.4543456055826, 40.317855992326116, 41.18224802153378, 42.04750493136128, 42.9136106012995, 43.78054951576431, 44.648306730401835, 45.51686784086059, 46.386218953807855, 47.25634665999191, 48.12723800917245, 48.99888048675934, 49.87126199201662, 50.74437081770224, 51.61819563102704, 52.49272545582777, 53.36794965585825, 54.24385791911266, 55.12044024310191, 55.9976869210117, 56.87558852867721, 57.75413591231471, 58.63332017695592, 59.51313267553542, 60.39356499858531, 61.27460896449576, 62.15625661030257, 63.03850018296699, 63.92133213111476, 64.8047450972049, 65.68873191010036, 66.57328557801502, 67.45839928181363, 68.34406636864252, 69.23028034587131, 70.11703487532625, 71.0043237677985, 71.89214097781033, 72.78048059862512, 73.66933685748612, 74.55870411107196, 75.44857684115587, 76.33894965045785, 77.22981725867875, 78.12117449870685, 79.01301631298698, 79.90533775004434, 80.7981339611541, 81.69140019714973, 82.5851318053626, 83.47932422668626, 84.37397299275918, 85.26907372325978, 86.1646221233085], [0.0, 0.6876270330700435, 1.423752296045062, 2.179366442740239, 2.9479216246681545, 3.7262453455812654, 4.512443268731855, 5.305250366398552, 6.103759712504854, 6.907288200314882, 7.715302207814953, 8.52737302640173, 9.343148473884442, 10.162333939247247, 10.984679233058076, 11.809969173724449, 12.638016667824814, 13.468657507978024, 14.301746385298864, 15.137153780722715, 15.97476350517352, 16.814470727311583, 17.656180373489608, 18.499805815873824, 19.345267786509318, 20.19249347058712, 21.041415743330898, 21.891972523087937, 22.74410621926766, 23.597763258320867, 24.452893674409715, 25.309450754072337, 26.167390726243433, 27.02667249060169, 27.887257378484932, 28.749108941623334, 29.61219276475025, 30.476476298802307, 31.341928711950242, 32.20852075613449, 33.07622464713496, 33.9450139564979, 34.8148635138866, 35.68574931862586, 36.55764845938069, 37.43053904105303, 38.30440011810178, 39.17921163359398, 40.054954363383246, 40.93160986488584, 41.80916042998978, 42.68758904168721, 43.566879334068446, 44.44701555535747, 45.32798253370432, 46.20976564548181, 47.09235078586067, 47.97572434146176, 48.85987316490482, 49.74478455109162, 50.63044621507815, 51.51684627140442, 52.40397321476359, 53.29181590190358, 54.18036353466395, 55.069605644060424, 55.95953207533722, 56.8501329739144, 57.741398772164196, 58.63332017695592, 59.52588815791429, 60.41909393634062, 61.31292897475071, 62.207384966987064, 63.10245382886623, 63.998127689325884, 64.8943988820381, 65.79125993745895, 66.688703575286, 67.58672269729806, 68.48531038055293, 69.38445987092143, 70.2841645769366, 71.18441806393945, 72.08521404850353, 72.98654639312157, 73.88840910113939, 74.79079631192226, 75.6937022962412, 76.59712145186616, 77.50104829935495, 78.40547747802712, 79.31040374211257, 80.21582195706563, 81.12172709603576, 82.0281142364866, 82.93497855695561, 83.84231533394714, 84.75011993895204, 85.65838783558742, 86.56711457685061, 87.4762958024816], [0.0, 0.697945105732999, 1.4451161734642706, 2.2120685621071923, 2.992156170526862, 3.782158898112861, 4.5801539829636155, 5.384857415195447, 6.195348660003999, 7.010934360409294, 7.831072887221599, 8.65532909892219, 9.48334552870922, 10.314823144830429, 11.149508003677983, 11.987181694787942, 12.827654317339642, 13.67075919996549, 14.516348853372051, 15.364291815017998, 16.21447015237149, 17.066777461063666, 17.921117240835482, 18.777401563973665, 19.635549973081236, 20.495488560738774, 21.357149194940305, 22.22046886247725, 23.085389108593034, 23.95185555584951, 24.819817488654788, 25.689227492595954, 26.560041139808284, 27.43221671324647, 28.305714964012168, 29.18049889691713, 30.056533580282167, 30.933785976634375, 31.812224791502615, 32.69182033795045, 33.57254441484632, 34.454370197168714, 35.337272136891634, 36.22122587320176, 37.10620815097188, 37.992196746560715, 38.87917040013232, 39.76710875379279, 40.65599229493102, 41.54580230422616, 42.4365208078501, 43.32813053344913, 44.22061486953763, 45.11395782797893, 46.00814400926443, 46.90315857033451, 47.79898719471227, 48.69561606474527, 49.593031835772436, 50.4912216120513, 51.39017292429818, 52.28987370870779, 53.19031228733234, 54.091477349711546, 54.993357935654956, 55.895943419087715, 56.79922349287854, 57.70318815457624, 58.6078276929876, 59.51313267553542, 60.41909393634062, 61.325702564977234, 62.232949895853245, 63.14082749817451, 64.0493271664517, 64.9584409115146, 65.86816095199947, 66.77847970627938, 67.68938978480855, 68.60088398285458, 69.51295527359427, 70.42559680155044, 71.338801876349, 72.25256396677673, 73.1668766951223, 74.08173383178308, 74.9971292901231, 75.91305712156688, 76.82951151091642, 77.74648677187834, 78.66397734278962, 79.58197778253098, 80.50048276661784, 81.41948708345893, 82.33898563077413, 83.25897341216282, 84.17944553381479, 85.10039720135676, 86.02182371682724, 86.94372047577346, 87.86608296446394, 88.78890675721155], [0.0, 0.7082704474378628, 1.466495101651715, 2.244793719989568, 3.036421879450432, 3.838111841523924, 4.647912399129205, 5.464520546847428, 6.287002131559087, 7.114653538818851, 7.9469251266199095, 8.78337531599619, 9.623641351811782, 10.467419778463615, 11.31445289552329, 12.164519061380673, 13.017425565838193, 13.873003271805942, 14.73110250804617, 15.591589867171677, 16.454345671966582, 17.31926194392465, 18.186240755170065, 19.055192877194287, 19.92603666232031, 20.798697109748524, 21.673105079533727, 22.549196626255192, 23.426912430381545, 24.306197310019353, 25.186999799294497, 26.06927178234918, 26.952968174056558, 27.838046640212827, 28.72446735127472, 29.61219276475025, 30.501187432183887, 31.391417827349102, 32.28285219280696, 33.17546040243497, 34.06921383789636, 34.96408527732252, 35.86004879473205, 36.757079668919815, 37.65515430072418, 38.55425013772917, 39.4543456055826, 40.355420045217585, 41.25745365535507, 42.160427439742136, 43.06432315864736, 43.96912328419127, 44.87481095913931, 45.78136995882766, 46.68878465592866, 47.59703998779571, 48.50612142615514, 49.416014948937324, 50.32670701406137, 51.238184535006276, 52.15043485801881, 53.06344574082278, 53.97720533270779, 54.89170215588755, 55.80692508802747, 56.72286334585142, 57.63950646974529, 58.556844309282454, 59.474867009603116, 60.39356499858531, 61.31292897475071, 62.232949895853245, 63.15361896810286, 64.07492763598094, 64.99686757260685, 65.91943067061922, 66.84260903353749, 67.76639496757277, 68.69078097385895, 69.61575974107743, 70.54132413845076, 71.46746720908241, 72.39418216362145, 73.32146237423244, 74.24930136885273, 75.17769282571945, 76.10663056815143, 77.0361085595705, 77.96612089874908, 78.89666181527126, 79.82772566519522, 80.75930692690623, 81.69140019714972, 82.62400018723456, 83.55710171939796, 84.49069972332293, 85.42478923280066, 86.3593653825303, 87.29442340504914, 88.22995862778646, 89.16596647023508, 90.10244244123456], [0.0, 0.7186029622341402, 1.487888881939031, 2.277541612281682, 3.0807183400900864, 3.8941036558594964, 4.715717887568728, 5.544239021067427, 6.378719275460197, 7.218444771710412, 8.062857849427623, 8.911510487726266, 9.764034639462523, 10.620122422109226, 11.479512375807527, 12.341979625556394, 13.207328649829655, 14.075387844102126, 14.946005353675938, 15.819045824966915, 16.694387834863083, 17.57192182962729, 18.451548452775143, 19.33317717409918, 20.216725154815478, 21.10211629998464, 21.98928046102203, 22.878152759647147, 23.768673010953062, 24.660785228032193, 25.554437194206947, 26.449580091687373, 27.346168177627884, 28.244158500237443, 29.14351064892448, 30.044186533513052, 30.946150188412282, 31.84936759830247, 32.75380654245527, 33.65943645525701, 34.56622830087589, 35.474154460320484, 36.383188629391476, 37.293305726241485, 38.204481807435485, 39.11669399155439, 40.02992038951129, 40.94414004085708, 41.859332855444215, 42.77547955989534, 43.69256164839098, 44.61056133734837, 45.52946152361332, 46.44924574583053, 47.369898148695015, 48.29140344982065, 49.213746908989854, 50.136914299573796, 51.06089188193463, 51.98566637864029, 52.91122495133985, 53.83755517916217, 54.76464503851429, 55.692482884167646, 56.621057431530865, 57.55035774001736, 58.48037319742423, 59.41109350524662, 60.34250866485835, 61.27460896449576, 62.207384966987064, 63.14082749817451, 64.07492763598094, 65.00967670007662, 65.94506624210528, 66.88108803643232, 67.81773407138033, 68.75499654092057, 69.69286783679067, 70.63134054101174, 71.57040741877991, 72.5100614117088, 73.45029563140191, 74.39110335333446, 75.33247801102688, 76.2744131904921, 77.2169026249412, 78.15994018973211, 79.10351989754798, 80.04763589379188, 80.99228245218606, 81.9374539705644, 82.88314496684762, 83.8293500751912, 84.7760640422972, 85.72328172388092, 86.67099808128467, 87.61920817823075, 88.5679071777069, 89.51709033897723, 90.46675301471235, 91.41689064823315], [0.0, 0.7289425567355206, 1.5092973209670755, 2.3103119430047827, 3.125045152089949, 3.950133835059914, 4.783569835449343, 5.624012117351839, 6.470499262758534, 7.322307121008349, 8.178870007833101, 9.039733456013817, 9.90452412277275, 10.772929695625376, 11.644684952706472, 12.519561783408635, 13.397361852950807, 14.277911087681876, 15.161055447947769, 16.046657632633828, 16.934594471535725, 17.824754834606054, 18.717037935772993, 19.611351942238247, 20.507612823294835, 21.40574338911389, 22.30567248178024, 23.207334289514417, 24.110667761441, 25.015616105086664, 25.922126352455926, 26.83014898334569, 27.739637596740987, 28.650548622840386, 29.562841069605874, 30.476476298802304, 31.3914178273491, 32.30763115049828, 33.22508358391464, 34.1437441221922, 35.063583311718084, 35.98457313610593, 36.906686912679326, 37.8298991987016, 38.7541857062284, 39.67952322461212, 40.60588954981546, 41.53326341980059, 42.46162445535357, 43.39095310578269, 44.32123059899813, 45.25243889553863, 46.184560646161856, 47.117579152658834, 48.05147833159107, 48.986242680682345, 49.921857247625944, 50.85830760109368, 51.79557980375537, 52.73366038713708, 53.672536328163694, 54.61219502724681, 55.552624287792376, 56.49381229701487, 57.435747607954944, 58.37841912260775, 59.32181607607708, 60.26592802167836, 61.210744816920545, 62.15625661030257, 63.10245382886623, 64.0493271664517, 64.99686757260685, 65.94506624210528, 66.89391460503184, 67.84340431739764, 68.79352725224958, 69.74427549124209, 70.69564131664158, 71.64761720373585, 72.60019581362324, 73.55336998635809, 74.50713273443037, 75.46147723655974, 76.41639683178506, 77.37188501383181, 78.3279354257416, 79.28454185474816, 80.2416982273863, 81.19939860482043, 82.15763717838047, 83.11640826529373, 84.07570630460216, 85.03552585325502, 85.99586158236745, 86.9567082736364, 87.91806081590558, 88.87991420187187, 89.84226352492581, 90.80510397611957, 91.76843084125585, 92.73223949809189], [0.0, 0.739289140017611, 1.5307202304741792, 2.343104423982924, 3.169401925648614, 4.006201886406626, 4.851467646094154, 5.703839134191492, 6.562341286358655, 7.426239673367265, 8.294960581647878, 9.168043093290875, 10.045108566305144, 10.925840255254473, 11.809969173724449, 12.697263973314271, 13.587523504086443, 14.480571221594984, 15.376250899752756, 16.274423288598236, 17.17496346965384, 18.077758735496435, 18.982706869500493, 19.889714735396414, 20.798697109748524, 21.709575707098423, 22.62227835951816, 23.536738321098344, 24.452893674409715, 25.37068682086872, 26.29006404065413, 27.210975110674955, 28.133372971301956, 29.057213434305574, 29.982454925808344, 30.909058259145475, 31.8369864333969, 32.766204454055554, 33.69667917286599, 34.62837914433267, 35.56127449677924, 36.4953368161558, 37.43053904105304, 38.36685536760102, 39.30426116311324, 40.242732887491016, 41.18224802153378, 42.122785001411145, 43.06432315864737, 44.00684266504896, 44.950324482075736, 45.89475031421504, 46.840102565970014, 47.786364302117946, 48.73351921093262, 49.68155157009908, 50.63044621507815, 51.580188509703895, 52.5307643188202, 53.48215998278211, 54.43436229366547, 55.387358473043804, 56.34113615120505, 57.29568334769346, 58.25098845307197, 59.207040211811076, 60.16382770621802, 61.121340341328406, 62.07956783068903, 63.03850018296699, 63.998127689325884, 64.9584409115146, 65.91943067061922, 66.88108803643232, 67.84340431739764, 68.8063710510921, 69.76997999520887, 70.73422311900971, 71.69909259521582, 72.66458079230947, 73.63068026722097, 74.5973837583766, 75.56468417908592, 76.53257461124755, 77.50104829935496, 78.47009864478379, 79.43971920034524, 80.40990366508923, 81.38064587934407, 82.35193981997857, 83.32377959587457, 84.29615944359831, 85.26907372325978, 86.2425169145497, 87.21648361294525, 88.190968526075, 89.16596647023509, 90.1414723670489, 91.11748124026278, 92.09398821267085, 93.0709885031627, 94.04847742388758], [0.0, 0.7496426235210556, 1.5521574270955523, 2.3759187745359123, 3.2137882811038105, 4.062307329997196, 4.919410738346441, 5.783719388324194, 6.654244560158496, 7.530241539198816, 8.411128577219635, 9.296438301318677, 10.185786766757367, 11.078852792191444, 11.975363624146691, 12.875084674269594, 13.777811975588774, 14.683366511215587, 15.591589867171677, 16.502340843348954, 17.415492771830642, 18.33093136676592, 19.248552980021493, 20.168263170987174, 21.089975522703153, 22.013610653350806, 22.93909538431582, 23.866362034935907, 24.795347820650054, 25.725994336226872, 26.658247109517998, 27.59205521407577, 28.52737093121746, 29.464149453872942, 30.40234862593727, 31.341928711950242, 32.28285219280696, 33.22508358391464, 34.168589272788225, 35.11333737354909, 36.05929759617862, 37.00644112869814, 37.95474053071288, 38.904169636978814, 39.85470346983733, 40.806318159519, 41.75899087144979, 42.712699739805466, 43.66742380665559, 44.62314296611981, 45.57983791302991, 46.537490095651044, 47.496081672067625, 48.45559546988512, 49.41601494893733, 50.37732416672386, 51.339507746331485, 52.302550846619944, 53.26643913447525, 54.23115875895394, 55.19669632715954, 56.163038881708225, 57.13017387965448, 58.09808917276049, 59.06677298900314, 60.0362139152232, 61.006400880829474, 61.97732314247883, 62.948970269659924, 63.92133213111476, 64.8943988820381, 65.86816095199947, 66.84260903353749, 67.81773407138033, 68.79352725224958, 69.76997999520887, 70.7470839425208, 71.72483095097948, 72.70321308368779, 73.68222260225134, 74.66185195936285, 75.64209379175281, 76.62294091348421, 77.6043863095701, 78.58642312989544, 79.56904468342448, 80.55224443267781, 81.53601598846278, 82.52035310484366, 83.50524967433743, 84.49069972332293, 85.47669740765151, 86.46323700844849, 87.45031292809463, 88.43791968637866, 89.42605191681135, 90.41470436309292, 91.40387187572587, 92.39354940876585, 93.38373201670346, 94.37441485147049, 95.36559315956455], [0.0, 0.7600029209596938, 1.5736087321731238, 2.4087547211882248, 3.2582038485386713, 4.118449698247618, 4.987398545966972, 5.863652214026139, 6.7462083182341415, 7.634311851749149, 8.52737302640173, 9.424918010048719, 10.32655755171419, 11.231966031226428, 12.14086692557219, 13.053022404312953, 13.968225681589471, 14.886295266443256, 15.807070555564817, 16.730408397416046, 17.656180373489608, 18.5842706184682, 19.51457405176863, 20.44699492758171, 21.381445634637984, 22.31784569403707, 23.256120915813135, 24.196202683935788, 25.138027346141588, 26.081535690020434, 27.02667249060169, 27.973386117618137, 28.921628192899796, 29.87135329012871, 30.82251867058927, 31.775084049664677, 32.729011389724185, 33.68426471576674, 34.64080995077213, 35.59861476818886, 36.55764845938068, 37.51788181417832, 38.47928701295207, 39.44183752884598, 40.40550803900234, 41.370274343763974, 42.33611329297582, 43.30300271862108, 44.2709213731241, 45.23984887273491, 46.20976564548181, 47.1806528832391, 48.1524924975103, 49.12526707857298, 50.098959857670636, 51.07355467197247, 52.049035932051474, 53.02538859165814, 54.00259811959035, 54.98065047348022, 55.95953207533722, 56.9392297887024, 57.919730897282776, 58.90102308494807, 59.88309441698209, 60.86593332249213, 61.849528577887966, 62.83386929135005, 63.818944888214084, 64.8047450972049, 65.79125993745895, 66.77847970627938, 67.76639496757277, 68.75499654092057, 69.74427549124209, 70.73422311900971, 71.72483095097948, 72.7160907314038, 73.70799441369516, 74.7005341525121, 75.6937022962412, 76.68749137985023, 77.68189411809024, 78.676903399025, 79.67251227786866, 80.66871397111329, 81.66550185092945, 82.66286943982381, 83.66081040553986, 84.65931855618722, 85.6583878355874, 86.65801231882381, 87.65818620798508, 88.65890382809113, 89.66015962319243, 90.66194815263317, 91.66426408746986, 92.66710220703733, 93.67045739565468, 94.67432463946399, 95.67869902339527, 96.68357572825117], [0.0, 0.7703699482334324, 1.5950739715751407, 2.4416119973928634, 3.302648267408203, 4.1746285354201635, 5.055430517062233, 5.943636962439692, 6.838231814066422, 7.7384497662237, 8.643692985575594, 9.553481176542268, 10.467419778463618, 11.385178729457103, 12.306477734521849, 13.231075719028318, 14.15876307639832, 15.089355839996404, 16.022691215759806, 16.958624099452795, 17.897024320840334, 18.837774434112635, 19.780767925306133, 20.725907742564793, 21.67310507953373, 22.62227835951816, 23.57335238054376, 24.52625759060446, 25.48092946917074, 26.437307996129462, 27.395337193198706, 28.354964725834495, 29.316141555951226, 30.278821637580847, 31.242961649018643, 32.20852075613449, 33.17546040243497, 34.1437441221922, 35.11333737354909, 36.08420738899498, 37.0563230410041, 38.029654720957865, 39.00417422974534, 39.97985467866375, 40.95667039943203, 41.93459686229097, 42.91361060129951, 43.89368914605197, 44.874810959139324, 45.85695537876152, 46.84010256597002, 47.82423345608176, 48.80932971385918, 49.79537369209778, 50.782348393302264, 51.77023743416832, 52.759025012617116, 53.74869587715667, 54.73923529836802, 55.73062904233454, 56.72286334585143, 57.71592489326825, 58.70980079483199, 59.70447856641082, 60.699946110489776, 61.696191698340265, 62.69320395327358, 63.690971834897375, 64.68948462430073, 65.68873191010036, 66.688703575286, 67.68938978480855, 68.69078097385895, 69.69286783679067, 70.69564131664158, 71.69909259521582, 72.70321308368779, 73.70799441369516, 74.71342842888873, 75.71950717691053, 76.72622290177318, 77.73356803661568, 78.74153519681266, 79.75011717341553, 80.75930692690625, 81.76909758124458, 82.77948241819233, 83.7904548718982, 84.8020085237288, 85.81413709733157, 86.82683445391706, 87.84009458774823, 88.85391162182573, 89.86827980375837, 90.88319350180917, 91.89864720110758, 92.91463550001917, 93.9311531066649, 94.94819483558199, 95.96575560451966, 96.98383043136253, 98.00241443117572], [0.0, 0.7807436233455308, 1.6165529755249042, 2.4744903432692014, 3.347121186184684, 4.230843397175157, 5.1235061135416275, 6.0236730009352195, 6.930314319806697, 7.842654458956305, 8.760087534722668, 9.682126783944605, 10.608372332873012, 11.538489675066282, 12.472194741117125, 13.409243210124666, 14.349422652982977, 15.292546625792134, 16.238450142331278, 17.186986144414885, 18.138022708956928, 19.091440808641646, 20.04713249520595, 21.004999409909455, 21.96495155054551, 22.926906241920946, 23.890787269404033, 24.856524144412802, 25.8240514775949, 26.7933084406162, 27.764238301400443, 28.736788020675284, 29.71090790001632, 30.686551273408053, 31.663674235782818, 32.64223540314481, 33.6221956998052, 34.603518168994604, 35.586167803720976, 36.57011139523173, 37.55531739684294, 38.541755801231254, 39.52939802956113, 40.51821683105094, 41.50818619177478, 42.49928125165972, 43.49147822877619, 44.484754350135724, 45.47908778831009, 46.47445760327083, 47.470843688921384, 48.4682267238568, 49.466588125940234, 50.46591001033281, 51.46617515065377, 52.4673669429839, 53.469469372456196, 54.47246698220457, 55.47634484446614, 56.481088533652695, 57.48668410122637, 58.493118052230386, 59.50037732334042, 60.508449262315374, 61.51732160873715, 62.52698247594001, 63.53742033403863, 64.54862399397256, 65.56058259249177, 66.57328557801502, 67.58672269729806, 68.60088398285458, 69.61575974107743, 70.63134054101174, 71.64761720373585, 72.66458079230947, 73.68222260225134, 74.7005341525121, 75.71950717691053, 76.73913361600347, 77.75940560936273, 78.78031548823319, 79.8018557685493, 80.82401914428799, 81.84679848113821, 82.87018681046808, 83.89417732357276, 84.91876336618624, 85.94393843324288, 86.96969616387378, 87.99603033662555, 89.02293486488892, 90.05040379252581, 91.07843128968427, 92.10701164879129, 93.13613928071395, 94.16580871108035, 95.19601457675181, 96.22675162243901, 97.25801469745441, 98.28979875259428, 99.32209883714398], [0.0, 0.7911238663240253, 1.6380455784380765, 2.507389505353942, 3.3916222620208005, 4.2870938501451725, 5.191624810601837, 6.103759712504854, 7.02245512557937, 7.9469251266199095, 8.87655577654276, 9.810853840510594, 10.749414128321435, 11.691897686160637, 12.638016667824813, 13.587523504086441, 14.540202941524836, 15.495866057407172, 16.454345671966582, 17.41549277183064, 18.37917367995256, 19.34526778650931, 20.313665708030175, 21.284267778063004, 22.256982797792233, 23.23172699283085, 24.20842313524854, 25.186999799294494, 26.16739072624343, 27.149534279028533, 28.133372971301952, 29.118853058616793, 30.105924181791764, 31.094539054371374, 32.084653187555645, 33.07622464713496, 34.06921383789636, 35.06358331171809, 36.05929759617862, 37.0563230410041, 38.05462768008707, 39.054181107146974, 40.05495436338324, 41.05691983570616, 42.06005116432612, 43.06432315864736, 44.069711720551766, 45.076193774276476, 46.08374720219045, 47.09235078586067, 48.10198415187341, 49.11262772193928, 50.124262666865846, 51.13687086402941, 52.15043485801882, 53.16493782416031, 54.18036353466395, 55.19669632715954, 56.21392107541469, 57.23202316204825, 58.25098845307197, 59.27080327410917, 60.29145438815436, 61.31292897475072, 62.33521461047387, 63.35829925062096, 64.38217121201303, 65.40681915682741, 66.43223207738362, 67.45839928181363, 68.48531038055293, 69.51295527359427, 70.54132413845076, 71.57040741877991, 72.60019581362324, 73.63068026722097, 74.66185195936285, 75.6937022962412, 76.72622290177318, 77.75940560936273, 78.79324245407464, 79.8277256651952, 80.86284765915576, 81.89860103279725, 82.93497855695561, 83.97197317034872, 85.00957797374775, 86.04778622441609, 87.08659133080104, 88.12598684746392, 89.16596647023506, 90.2065240315817, 91.24765349617697, 92.2893489566591, 93.33160462957102, 94.37441485147049, 95.41777407520199, 96.4616768663222, 97.50611789967097, 98.55109195608067, 99.59659391921674, 100.64261877254322], [0.0, 0.8015105991470336, 1.6595516187680213, 2.5403092363643824, 3.4361511604294206, 4.343379471530259, 5.259786096236641, 6.183896495186194, 7.1146535388188505, 8.051260985476233, 8.993096835615953, 9.939661378678368, 10.890544104684727, 11.845401609666796, 12.803942268263794, 13.765915260890663, 14.731102508046169, 15.69931260661479, 16.670376181912214, 17.644142264156724, 18.620475421244166, 19.599253459854836, 20.580365560413085, 21.563710747937407, 22.54919662625519, 23.53673832109834, 24.52625759060445, 25.517682071267927, 26.510944634447025, 27.505982833836608, 28.50273842834566, 29.501156967911843, 30.501187432183887, 31.502781913878373, 32.50589534009808, 33.51048522607555, 34.51651145674892, 35.523936092336825, 36.53272319469728, 37.542838671759135, 38.55425013772916, 39.566926787120146, 40.58083928092895, 41.59595964353125, 42.61226116905752, 43.6297183361825, 44.64830673040183, 45.66800297298898, 46.68878465592865, 47.710630282209195, 48.733519210932606, 49.75743160676447, 50.78234839330225, 51.808251209988796, 52.835122372239354, 53.86294483448761, 54.89170215588754, 55.92137846843641, 56.95195844730819, 57.9834272832089, 59.01577065658394, 60.04897471352459, 61.08302604323556, 62.11791165693918, 63.15361896810286, 64.1901357738878, 65.22745023772563, 66.2655508729384, 67.30442652732485, 68.34406636864252, 69.38445987092143, 70.42559680155044, 71.46746720908241, 72.5100614117088, 73.55336998635809, 74.5973837583766, 75.64209379175281, 76.68749137985023, 77.73356803661568, 78.78031548823319, 79.8277256651952, 80.87579069476567, 81.9245028938106, 82.97385476197422, 84.02383897518018, 85.07444837943817, 86.1256759849388, 87.17751496041946, 88.22995862778644, 89.28300045697833, 90.33663406105747, 91.39085319151702, 92.4456517337918, 93.50102370296182, 94.55696323963848, 95.6134646060237, 96.67052218213291, 97.7281304621735, 98.78628405107085, 99.84497766113445, 100.90420610885691, 101.96396431183976], [0.0, 0.8119037456717044, 1.6810709388586924, 2.5732492949732224, 3.4807075549789945, 4.3996998487129195, 5.327989470770663, 6.264082761514131, 7.206908883638872, 8.155661270662067, 9.109709857605402, 10.068548454188226, 11.031761227370104, 11.999000320281294, 12.969970326070026, 13.944417172786643, 14.92211995310429, 15.90288478199313, 16.886540088496076, 17.872932945214053, 18.861926163901806, 19.85339596676517, 20.84723009723679, 21.843326270997782, 22.841590893779145, 23.841937990752534, 24.844288305497358, 25.848568536174177, 26.854710683687625, 27.862651491994555, 28.87233196479472, 29.88369694597466, 30.896694753604823, 31.911276859190536, 32.92739760537664, 33.94501395649791, 34.96408527732252, 35.984573136105936, 37.00644112869815, 38.029654720957865, 39.054181107146974, 40.07998908232508, 41.10704892705172, 42.13533230294409, 43.16481215783903, 44.19546263947758, 45.22725901677376, 46.26017760785031, 47.294195714128335, 48.329291559845565, 49.365444236454536, 50.40263365141706, 51.44084048096789, 52.48004612646948, 53.52023267402198, 54.56138285703008, 55.603480021460186, 56.64650809354997, 57.69045154975717, 58.73529538875648, 59.78102510531235, 60.82762666587316, 61.87508648574653, 62.92339140772996, 63.97252868208197, 65.02248594773017, 66.073251214622, 67.12481284713238, 68.17715954845, 69.23028034587131, 70.2841645769366, 71.338801876349, 72.39418216362145, 73.45029563140191, 74.50713273443037, 75.56468417908592, 76.62294091348421, 77.68189411809024, 78.74153519681266, 79.8018557685493, 80.86284765915576, 81.9245028938106, 82.98681368975303, 84.04977244937058, 85.11337175361595, 86.17760435573342, 87.24246317527711, 88.30794129240375, 89.37403194242518, 90.44072851060497, 91.50802452718641, 92.57591366263858, 93.64438972310907, 94.71344664607169, 95.78307849615949, 96.85327946117265, 97.92404384825257, 98.99536608021326, 100.06724069202251, 101.13966232742455, 102.21262573569774, 103.28612576854042], [0.0, 0.8223032315665894, 1.7026033848046076, 2.606209445594226, 3.5252911270036273, 4.456054578891635, 5.396234446415571, 6.344317937999078, 7.299220500232188, 8.260125235509946, 9.226394008498541, 10.197514145243968, 11.17306448639727, 12.152692719471114, 13.136099653816201, 14.123027963134472, 15.113253910548597, 16.10658112760057, 17.10283584572089, 18.101863178699066, 19.10352418107757, 20.107693489621315, 21.114257409894734, 22.123112347442937, 23.13416350916974, 24.14732381901525, 25.16251300538185, 26.179656827523935, 27.19868641536155, 28.219537702619647, 29.242150937328113, 30.26647025689167, 31.292443317398988, 32.320020968765206, 33.34915696882074, 34.37980773066657, 35.41193209858364, 36.44549114856416, 37.480448010165844, 38.516767706907636, 39.554417012850365, 40.59336432335682, 41.63357953831716, 42.675033956368836, 43.71770017884382, 44.761552022347615, 45.8065644390195, 46.852713443646586, 47.89997604690917, 48.948330194124296, 49.9977547089318, 51.048229241432864, 52.09973422034863, 53.15225080881592, 54.20576086347993, 55.260246896581556, 56.31569204076957, 57.372080016396545, 58.429395101082825, 59.487622101354575, 60.5467463261821, 61.606753562261275, 62.66763005089655, 63.729362466357905, 64.79193789559537, 65.85534381920648, 66.91956809356087, 67.98459893399544, 69.0504248990007, 70.11703487532625, 71.18441806393945, 72.25256396677673, 73.32146237423244, 74.39110335333446, 75.46147723655974, 76.53257461124755, 77.6043863095701, 78.676903399025, 79.75011717341553, 80.82401914428799, 81.89860103279725, 82.97385476197422, 84.04977244937058, 85.12634640005778, 86.2035690999597, 87.28143320949857, 88.35993155753675, 89.43905713559636, 90.51880309234186, 91.59916272831022, 92.68012949087512, 93.76169696943218, 94.84385889079334, 95.92660911477896, 97.00994162999733, 98.09385054980153, 99.17833010841446, 100.26337465721326, 101.34897866116539, 102.43513669540803, 103.52184344196432, 104.60909368658913], [0.0, 0.832708984247238, 1.7241488063174955, 2.6391894581780972, 3.5699015653269677, 4.512443268731855, 5.464520546847429, 6.424601464630062, 7.391587744298875, 8.364652150901183, 9.34314847388444, 10.32655755171419, 11.314452895523294, 12.306477734521849, 13.30232909198289, 14.301746385298866, 15.30450304633687, 16.3104002217142, 17.319261943924655, 18.330931366765924, 19.345267786509318, 20.36214425352342, 21.381445634637988, 22.403067024472627, 23.42691243038155, 24.45289367440972, 25.48092946917074, 26.51094463444703, 27.54286942864921, 28.576638974782067, 29.612192764750255, 30.64947422905096, 31.68843036139214, 32.729011389724185, 33.77117048671068, 34.8148635138866, 35.86004879473205, 36.90668691267933, 37.95474053071289, 39.00417422974534, 40.05495436338324, 41.107048927051714, 42.16042743974214, 43.2150608368935, 44.2709213731241, 45.32798253370432, 46.38621895380786, 47.44560634470337, 48.506121426155154, 49.5677418643915, 50.63044621507816, 51.69421387080057, 52.759025012617116, 53.82486056529547, 54.89170215588756, 55.95953207533723, 57.02833324284706, 58.098089172760496, 59.1687839437406, 60.240402170049286, 61.312928974750726, 62.386349964679944, 63.46065120703341, 64.535819207452, 65.61184088947886, 66.68870357528601, 67.76639496757278, 68.84490313254821, 69.92421648391742, 71.0043237677985, 72.08521404850353, 73.1668766951223, 74.24930136885273, 75.33247801102688, 76.41639683178506, 77.50104829935496, 78.58642312989544, 79.67251227786866, 80.75930692690625, 81.84679848113821, 82.93497855695561, 84.02383897518018, 85.11337175361595, 86.2035690999597, 87.29442340504914, 88.38592723642864, 89.4780733322141, 90.57085459523951, 91.66426408746986, 92.75829502466445, 93.85294077127739, 94.94819483558197, 96.04405086500671, 97.14050264167167, 98.23754407811464, 99.33516921319668, 100.43337220817826, 101.53214734295662, 102.63148901245667, 103.73139172316726, 104.8318500898157, 105.93285883217375], [0.0, 0.8431209328148188, 1.7457070565992092, 2.672189108017942, 3.614538565999071, 4.568865534033381, 5.532847306803907, 6.504932794401174, 7.4840099865015, 8.469241304649318, 9.459972458265126, 10.455677794371123, 11.455925491408637, 12.460354317630594, 13.468657507978023, 14.48057122159498, 15.49586605740717, 16.5143406756276, 17.53581690850405, 18.560135948675363, 19.58715533309475, 20.616746524789896, 21.648792950999205, 22.683188394636225, 23.719835662791315, 24.758645474958183, 25.799535527356834, 26.842429699738325, 27.88725737848493, 28.933952875398532, 29.98245492580834, 31.032706252883095, 32.084653187555645, 33.13824533544128, 34.19343528368834, 35.25017834193739, 36.30843231255757, 37.36815728612799, 38.42931545878203, 39.491870968562424, 40.55578974837113, 41.62103939345746, 42.687589041687204, 43.75540926508461, 44.82447197134788, 45.894750314215024, 46.96621861170538, 48.03885227138844, 49.11262772193928, 50.18752235033127, 51.263514444096494, 52.340583138151345, 53.418708365743974, 54.497870813130945, 55.57805187763426, 56.659233628768895, 57.74139877216419, 58.82453061603175, 59.908613039958944, 60.99363046582892, 62.079567830689015, 63.16641056140636, 64.25414455096572, 65.34275613627848, 66.4322320773836, 67.52255953793329, 68.61372606686501, 69.70571958117122, 70.79852834968537, 71.89214097781033, 72.98654639312157, 74.08173383178308, 75.17769282571945, 76.2744131904921, 77.37188501383181, 78.47009864478379, 79.56904468342448, 80.66871397111329, 81.76909758124458, 82.87018681046808, 83.97197317034872, 85.07444837943817, 86.17760435573342, 87.28143320949857, 88.38592723642864, 89.49107891113474, 90.59688088093225, 91.70332595991435, 92.81040712329485, 93.9181175020049, 95.02645037752971, 96.1353991769719, 97.2449574683293, 98.35511895597546, 99.46587747633228, 100.57722699372454, 101.6891615964068, 102.80167549275382, 103.91476300760628, 105.0284185787638, 106.14263675361784, 107.25741218591769], [0.0, 0.8535390079975971, 1.7672779922205546, 2.705208175563792, 3.6592018320455098, 4.625320999413243, 5.6012142717002416, 6.585311392860046, 7.576486611945648, 8.573892000912254, 9.576865184398951, 10.584874014164884, 11.597481332821976, 12.614321445041062, 13.635083795202021, 14.659501282283305, 15.687341670602256, 16.71840113250454, 17.75249929869724, 18.78947539950638, 19.82918521153184, 20.87149860952638, 21.916297580289967, 22.96347459425825, 24.01293125755148, 25.064577186463346, 26.11832906022218, 27.174109817994545, 28.231847973621246, 29.29147702722394, 30.352934957111202, 31.416163778707112, 32.48110915977942, 33.54772008324215, 34.61594855038382, 35.68574931862586, 36.757079668919815, 37.829899198701604, 38.90416963697882, 39.97985467866375, 41.056919835706154, 42.13533230294409, 43.2150608368935, 44.29607564595005, 45.37834829068772, 46.461851593117025, 47.54655955391635, 48.63244727677734, 49.71949089911453, 50.80766752848208, 51.89695518412061, 52.98733274312585, 54.0787798907899, 55.171277074717906, 56.26480546236671, 57.35934690169218, 58.45488388462469, 59.55139951312277, 60.64887746758091, 61.74730197739032, 62.846657793472026, 63.946930162619374, 65.04810480350292, 66.15016788420529, 67.25310600116504, 68.35690615942124, 69.46155575405908, 70.56704255276657, 71.6733546794203, 72.78048059862512, 73.88840910113939, 74.9971292901231, 76.10663056815143, 77.2169026249412, 78.3279354257416, 79.43971920034524, 80.55224443267781, 81.66550185092945, 82.77948241819233, 83.89417732357276, 85.00957797374775, 86.1256759849388, 87.24246317527711, 88.35993155753675, 89.4780733322141, 90.59688088093225, 91.71634676015276, 92.8364636951757, 93.95722457441265, 95.07862244391671, 96.20065050215536, 97.3233020950128, 98.44657071100946, 99.57044997672656, 100.6949336524254, 101.82001562785055, 102.94568991820775, 104.07195066030717, 105.19879210886405, 106.32620863294835, 107.45419471257601, 108.58274493543507], [0.0, 0.8639631420950986, 1.788861473005679, 2.7382464462456326, 3.7038910732279975, 4.681809298003118, 5.6696209972628155, 6.665736737677059, 7.669017019684282, 8.67860355963138, 9.693825892674102, 10.714145371531043, 11.739119499881529, 12.768378116218377, 13.801606872155824, 14.838535404610667, 15.878928641643354, 16.922580266285312, 17.96930770642258, 19.018948228927098, 20.071355849021657, 21.126398852260376, 22.183957784167067, 23.243923801936166, 24.306197310019357, 25.370686820868723, 26.437307996129462, 27.50598283383661, 28.576638974782067, 29.649209106935206, 30.72363045114369, 31.79984431467535, 32.87779570174715, 33.957432972209666, 35.03870754115092, 36.121573613452036, 37.2059879483437, 38.29190964983185, 39.37929997952663, 40.468122188952144, 41.55834136886118, 42.64992431344763, 43.742839397655814, 44.83705646604135, 45.9325467318521, 47.029282685178174, 48.12723800917245, 49.22638750347197, 50.32670701406137, 51.42817336891306, 52.5307643188202, 53.634458482907895, 54.739235298368015, 55.84507497401543, 56.9519584473082, 58.05986734451421, 59.16878394374059, 60.27869114057283, 61.389572416096705, 62.50141180709954, 63.614193878267805, 64.72790369621632, 65.84252680520008, 66.9580492043747, 68.07445732648326, 69.19173801785945, 70.30987851964665, 71.42886645014163, 72.54868978817981, 73.66933685748612, 74.79079631192226, 75.91305712156688, 77.0361085595705, 78.15994018973211, 79.28454185474816, 80.40990366508923, 81.53601598846278, 82.66286943982381, 83.7904548718982, 84.91876336618624, 86.04778622441609, 87.17751496041946, 88.30794129240375, 89.43905713559636, 90.57085459523951, 91.70332595991435, 92.8364636951757, 93.97026043747886, 95.10470898838275, 96.23980230901306, 97.37553351477119, 98.51189587027577, 99.64888278452352, 100.78648780625818, 101.92470461953609, 103.06352703947827, 104.20294900819914, 105.34296459090267, 106.48356797213788, 107.62475345220506, 108.76651544370549, 109.90884846822753], [0.0, 0.8743932689248127, 1.8104573619217188, 2.7713037103044877, 3.7486060058158985, 4.7383300711605125, 5.738067049179405, 6.7462083182341415, 7.761600622244654, 8.78337531599619, 9.810853840510594, 10.843491045729678, 11.88083909333087, 12.922523353061413, 13.968225681589473, 15.017672451894862, 16.0706257541506, 17.1268767806428, 18.18624075517006, 19.24855298002149, 20.313665708030175, 21.38144563463798, 22.451771863263993, 23.52453423710646, 24.599631958257685, 25.67697243469354, 26.756470309891096, 27.838046640212827, 28.9216281928998, 30.007146843302213, 31.094539054371378, 32.18374542481173, 33.274710294908004, 34.36738140108914, 35.46170957190565, 36.55764845938069, 37.655154300724185, 38.754185706228405, 39.85470346983734, 40.95667039943203, 42.06005116432612, 43.16481215783903, 44.2709213731241, 45.37834829068772, 46.48706377625195, 47.59703998779571, 48.7082502907638, 49.820669180563875, 50.93427221158312, 52.049035932051474, 53.16493782416032, 54.28195624891582, 55.400070395266965, 56.51926023310112, 57.6395064697453, 58.76079050965196, 59.88309441698209, 61.006400880829474, 62.1306931828566, 63.25595516713616, 64.38217121201305, 65.50932620381994, 66.637405512296, 67.76639496757278, 68.89628083860367, 70.0270498129258, 71.15868897765225, 72.29118580160267, 73.4245281184879, 74.55870411107196, 75.6937022962412, 76.82951151091642, 77.96612089874908, 79.10351989754798, 80.2416982273863, 81.38064587934407, 82.52035310484366, 83.66081040553986, 84.8020085237288, 85.94393843324288, 87.08659133080104, 88.22995862778644, 89.37403194242518, 90.51880309234186, 91.66426408746986, 92.81040712329485, 93.95722457441265, 95.10470898838275, 96.25285307986148, 97.40164972499822, 98.55109195608065, 99.70117295641501, 100.85188605542868, 102.00322472398307, 103.15518256988584, 104.30775333359153, 105.4609308840812, 106.61470921491147, 107.7690824404248, 108.92404479211228, 110.0795906151218, 111.23571436490401], [0.0, 0.884829323771286, 1.8320655249733961, 2.8043797626310747, 3.7933463523679922, 4.794882968192908, 5.80655200276512, 6.826725635232015, 7.854236845176434, 8.88820661993293, 9.9279483017891, 10.972910234214085, 12.022639233847261, 13.076756199150463, 14.134939189688904, 15.196911312650345, 16.262431818707444, 17.33128940798537, 18.403297098942584, 19.47828822816877, 20.556113285105653, 21.636637374179102, 22.719738155883835, 23.80530415867512, 24.893233381602485, 25.983432127537867, 27.07581402121153, 28.170299176778187, 29.266813487431573, 30.365288015440864, 31.465658465430256, 32.5678647271381, 33.67185047653951, 34.7775628262875, 35.88495201806169, 36.993971150713065, 38.10457593913408, 39.21672449962274, 40.330377158191084, 41.445496278824926, 42.562046109159255, 43.67999264141119, 44.79930348672607, 45.919947761354166, 47.04189598329423, 48.165119978225206, 49.28959279370326, 50.41528862073373, 51.54218272194066, 52.670251365652504, 53.79947176530619, 54.92982202364225, 56.061281081225715, 57.19382866888063, 58.32744526367218, 59.46211204811132, 60.59781087229129, 61.73452421869682, 62.872235169453766, 64.01092737581067, 65.1505850296649, 66.29119283696457, 67.43273599283383, 68.57520015828402, 69.71857143838587, 70.8628363617896, 72.0079818614905, 73.15399525674611, 74.30086423606025, 75.44857684115587, 76.59712145186616, 77.74648677187834, 78.89666181527126, 80.04763589379188, 81.19939860482043, 82.35193981997857, 83.50524967433743, 84.65931855618722, 85.81413709733157, 86.96969616387378, 88.12598684746392, 89.28300045697833, 90.44072851060497, 91.59916272831022, 92.75829502466445, 93.9181175020049, 95.07862244391671, 96.23980230901306, 97.40164972499822, 98.56415748299706, 99.72731853213625, 100.89112597436343, 102.05557305949141, 103.22065318045506, 104.38635986876994, 105.55268679018172, 106.71962774049655, 107.88717664158294, 109.05532753753691, 110.22407459100127, 111.3934120796321, 112.56333439270479], [0.0, 0.895271243337478, 1.853685831102299, 2.8374744026116314, 3.8381118415239244, 4.851467646094153, 5.875075442643178, 6.907288200314881, 7.9469251266199095, 8.993096835615955, 10.04510856630514, 11.10240215202752, 12.164519061380675, 13.231075719028317, 14.301746385298864, 15.376250899752756, 16.454345671966582, 17.535816908504053, 18.62047542124417, 19.708152579972523, 20.79869710974852, 21.891972523087933, 22.987855036750233, 24.086231863708857, 25.186999799294497, 26.29006404065413, 27.395337193198703, 28.50273842834566, 29.61219276475025, 30.72363045114369, 31.8369864333969, 32.95219989188372, 34.06921383789636, 35.187974759961335, 36.30843231255757, 37.43053904105303, 38.55425013772917, 39.679523224612126, 40.80631815951901, 41.93459686229097, 43.06432315864736, 44.195462639477576, 45.32798253370432, 46.461851593117025, 47.59703998779571, 48.73351921093261, 49.87126199201662, 51.01024221747973, 52.15043485801882, 53.29181590190358, 54.43436229366547, 55.57805187763426, 56.72286334585142, 57.868776189943326, 59.01577065658395, 60.163827706218015, 61.31292897475071, 62.46305673794161, 63.614193878267805, 64.76632385404531, 65.91943067061922, 67.0734988534517, 68.2285134229537, 69.38445987092145, 70.54132413845078, 71.6990925952158, 72.85775202000737, 74.01728958243686, 75.17769282571946, 76.33894965045785, 77.50104829935495, 78.66397734278962, 79.82772566519522, 80.99228245218606, 82.15763717838047, 83.32377959587457, 84.49069972332293, 85.6583878355874, 86.82683445391706, 87.99603033662555, 89.16596647023506, 90.33663406105747, 91.50802452718641, 92.68012949087512, 93.85294077127739, 95.02645037752971, 96.20065050215536, 97.37553351477119, 98.55109195608065, 99.72731853213625, 100.90420610885691, 102.08174770678599, 103.25993649607695, 104.43876579169432, 105.61822904881875, 106.79831985844498, 107.97903194316315, 109.16035915311343, 110.34229546210585, 111.52483496389628, 112.70797186861107, 113.89170049931317], [0.0, 0.905718965698251, 1.8753181520905824, 2.8705874339805075, 3.8829022078048188, 4.908083769292425, 5.943636962439691, 6.987895535711592, 8.039664916893145, 9.098045341000534, 10.162333939247247, 11.231966031226428, 12.306477734521849, 13.385480997512913, 14.468646279179927, 15.55569014964012, 16.646366175795155, 17.74045806926156, 18.837774434112635, 19.93814467223689, 21.041415743330898, 22.147449567115668, 23.256120915813135, 24.36731568618385, 25.48092946917074, 26.596866355581337, 27.715037930940827, 28.835362423405492, 29.957763976606078, 31.082172025283747, 32.20852075613449, 33.33674863977344, 34.46679802244051, 35.59861476818886, 36.73214794397044, 37.867349541362586, 39.00417422974533, 40.14257913659826, 41.282523651283384, 42.423969249250355, 43.56687933406844, 44.71121909507628, 45.85695537876151, 47.0040565722502, 48.1524924975103, 49.30223431506256, 50.45325443615185, 51.60552644246753, 52.759025012617116, 53.9137258546559, 55.069605644060424, 56.22664196660608, 57.38481326567268, 58.544098793556024, 59.70447856641081, 60.86593332249213, 62.028444483398104, 63.19199411804824, 64.35656490915994, 65.52214012200949, 66.688703575286, 67.85623961386538, 69.0247330833484, 70.19416930622197, 71.36453405951602, 72.53581355384019, 73.70799441369515, 74.88106365896301, 76.05500868748955, 77.22981725867875, 78.40547747802712, 79.58197778253098, 80.75930692690623, 81.9374539705644, 83.11640826529373, 84.29615944359831, 85.47669740765151, 86.65801231882381, 87.84009458774823, 89.02293486488892, 90.2065240315817, 91.39085319151702, 92.57591366263858, 93.76169696943218, 94.94819483558197, 96.1353991769719, 97.3233020950128, 98.51189587027577, 99.70117295641501, 100.89112597436343, 102.08174770678599, 103.27303109277648, 104.46496922278477, 105.65755533376175, 106.85078280451069, 108.0446451512339, 109.23913602326479, 110.43424919897532, 111.62997858185051, 112.82631819672095, 114.02326218614581, 115.22080480693876], [0.0, 0.9161724302558817, 1.8969623624688503, 2.9037186646791615, 3.9277171914225475, 4.9647310094091495, 6.012236164491718, 7.068547173892394, 8.132455678097065, 9.203051527375957, 10.279623740697778, 11.361601120328729, 12.44851442989779, 13.539971139039833, 14.63563790329779, 15.735228021548746, 16.838492216457077, 17.945211703320872, 19.055192877194283, 20.16826317098717, 21.284267778063004, 22.40306702447262, 23.52453423710646, 24.6485539957888, 25.775020686412844, 26.90383729283864, 28.034914380145047, 29.16816923270877, 30.30352511865513, 31.440910658287848, 32.58025927871074, 33.72150874039014, 34.864600724148126, 36.009480469221316, 37.15609645471176, 38.304400118101775, 39.4543456055826, 40.60588954981546, 41.75899087144979, 42.91361060129951, 44.06971172055176, 45.22725901677375, 46.386218953807855, 47.546559553916346, 48.70825029076379, 49.87126199201662, 51.03556675050074, 52.201137842995415, 53.36794965585825, 54.535977616776144, 55.705198132022815, 56.87558852867721, 58.0471270013208, 59.219792562787255, 60.39356499858532, 61.56842482465833, 62.74435324817954, 63.92133213111476, 65.09934395631186, 66.27837179590128, 67.45839928181363, 68.63941057823929, 69.8213903558727, 71.0043237677985, 72.18819642689049, 73.3729943846064, 74.55870411107196, 75.7453124763577, 76.9328067328601, 78.12117449870685, 79.31040374211257, 80.50048276661784, 81.69140019714972, 82.88314496684762, 84.07570630460216, 85.26907372325978, 86.46323700844849, 87.65818620798508, 88.85391162182573, 90.05040379252581, 91.24765349617697, 92.4456517337918, 93.64438972310907, 94.84385889079334, 96.04405086500671, 97.2449574683293, 98.44657071100946, 99.64888278452352, 100.85188605542868, 102.05557305949141, 103.25993649607695, 104.46496922278477, 105.67066425031737, 106.87701473756907, 108.0840139869238, 109.29165543975034, 110.49993267208514, 111.70883939049246, 112.91836942809365, 114.1285167407562, 115.3392754034349, 116.55063960665773], [0.0, 0.9266315776974805, 1.9186183394279954, 2.936867906721208, 3.9725565380971877, 5.021409045028258, 6.080872659567834, 7.149242657240424, 8.225296883737503, 9.308114798937808, 10.396977305155168, 11.491306683785778, 12.590628341593218, 13.69454526703303, 14.802720310143071, 15.91486349678193, 17.030722703830453, 18.15007664891121, 19.2727295168583, 20.39850677053252, 21.527251836003995, 22.65882344478701, 23.793093477654793, 24.929945196779382, 26.069271782349183, 27.210975110674955, 28.354964725834495, 29.50115696791185, 30.64947422905096, 31.79984431467535, 32.95219989188373, 34.10647801060753, 35.262619685889305, 36.42056953180943, 37.58027543930046, 38.7416882914485, 39.90476171097155, 41.06945183544348, 42.23571711654635, 43.4035181402166, 44.57281746502965, 45.74357947656285, 46.9157702558053, 48.089357459957114, 49.264310214190125, 50.440599013135476, 51.61819563102705, 52.79707303956821, 53.977205332707804, 55.15856765761189, 56.341136151205056, 57.52488788172913, 58.70980079483199, 59.895853663755005, 61.08302604323558, 62.27129822678444, 63.46065120703341, 64.65106663888204, 65.84252680520008, 67.03501458486714, 68.22851342295371, 69.42300730286648, 70.61848072029845, 71.81491865883991, 73.0123065671193, 74.21063033735588, 75.40987628521657, 76.61003113087881, 77.81108198121076, 79.01301631298698, 80.21582195706563, 81.41948708345893, 82.62400018723456, 83.8293500751912, 85.03552585325502, 86.2425169145497, 87.45031292809463, 88.65890382809113, 89.86827980375837, 91.07843128968427, 92.2893489566591, 93.50102370296182, 94.71344664607169, 95.92660911477896, 97.14050264167167, 98.35511895597546, 99.57044997672656, 100.78648780625818, 102.00322472398307, 103.22065318045506, 104.43876579169432, 105.65755533376175, 106.87701473756907, 108.09713708391163, 109.31791559871246, 110.53934364846614, 111.7614147358723, 112.98412249564846, 114.2074606905141, 115.43142320733604, 116.65600405342796, 117.88119735299617], [0.0, 0.9370963499542236, 1.9402859627347844, 2.9700349760632037, 4.01741999888224, 5.0781175614752625, 6.1495460666006005, 7.229981537737156, 8.3181880183633, 9.413234572378451, 10.514393981076498, 11.621082001476783, 12.732818680596628, 13.849202523302303, 14.969892572080044, 16.09459557800974, 17.223056570658283, 18.355051768629497, 19.490383145348797, 20.62887419256845, 21.7703665681148, 22.914717408108064, 24.06179714642653, 25.211487726881412, 26.363681123307874, 27.51827810387177, 28.675187191100747, 29.83432378027837, 30.995609387096103, 32.15897100165904, 33.32434053065205, 34.49165431308958, 35.66085269787657, 36.83187967360096, 38.00468254270952, 39.17921163359398, 40.355420045217585, 41.53326341980059, 42.71269973980547, 43.89368914605196, 45.076193774276476, 46.2601776078503, 47.44560634470337, 48.632447276777334, 49.82066918056387, 51.01024221747973, 52.20113784299542, 53.39332872357436, 54.586788660599375, 55.781492520564825, 56.9774161709013, 58.174536420874325, 59.37283096706432, 60.57227834299148, 61.772857872497774, 62.974549626541695, 64.17733438309826, 65.38119358988943, 66.58610932969924, 67.79206428805253, 68.99904172305925, 70.20702543724512, 71.41599975120762, 72.62594947895151, 73.83685990477153, 75.0487167615629, 76.26150621045056, 77.47521482163835, 78.6898295563878, 79.90533775004434, 81.12172709603576, 82.33898563077413, 83.55710171939796, 84.7760640422972, 85.99586158236745, 87.21648361294525, 88.43791968637866, 89.66015962319243, 90.88319350180917, 92.10701164879129, 93.33160462957102, 94.55696323963848, 95.78307849615949, 97.00994162999733, 98.23754407811464, 99.46587747633228, 100.6949336524254, 101.92470461953609, 103.15518256988584, 104.38635986876994, 105.61822904881875, 106.85078280451069, 108.0840139869238, 109.31791559871246, 110.55248078929769, 111.78770285025963, 113.02357521092156, 114.26009143411575, 115.49724521212184, 116.73503036276892, 117.97344082569322, 119.21247065874361], [0.0, 0.9475666901622963, 1.9619651146509918, 3.003219692480865, 4.062307329997197, 5.1348562506056075, 6.218256012430257, 7.310763376661072, 8.411128577219635, 9.518410276494691, 10.631873130439272, 11.750926368224466, 12.875084674269596, 14.0039420674661, 15.137153780722715, 16.274423288598236, 17.415492771830642, 18.560135948675367, 19.708152579972523, 20.859364185317087, 22.013610653350803, 23.17074752395096, 24.330643783331077, 25.493180056240064, 26.658247109518, 27.825744602596224, 28.995580035908713, 30.16766785943583, 31.341928711950242, 32.51828876780482, 33.696679172865984, 34.87703555485296, 36.05929759617862, 37.24340865960569, 38.42931545878203, 39.61696776710986, 40.80631815951901, 41.997321782612545, 43.189936149383705, 44.38412095529869, 45.579837913029905, 46.77705060352862, 47.97572434146177, 49.17582605331818, 50.37732416672386, 51.58018850970389, 52.78439021879579, 53.98990165506064, 55.19669632715955, 56.404748820765874, 57.6140347336728, 58.82453061603176, 60.03621391522319, 61.2490629249186, 62.46305673794162, 63.67817520258012, 64.8943988820381, 66.1117090167497, 67.33008748930676, 68.54951679177653, 69.76997999520887, 70.99146072115235, 72.21394311501574, 73.43741182112804, 74.66185195936285, 75.88724910320656, 77.11358925915998, 78.34085884737348, 79.56904468342451, 80.7981339611541, 82.0281142364866, 83.25897341216282, 84.49069972332293, 85.72328172388092, 86.9567082736364, 88.190968526075, 89.42605191681135, 90.66194815263317, 91.89864720110758, 93.13613928071395, 94.37441485147049, 95.6134646060237, 96.85327946117265, 98.09385054980153, 99.33516921319668, 100.57722699372454, 101.82001562785055, 103.06352703947827, 104.30775333359153, 105.55268679018172, 106.79831985844498, 108.0446451512339, 109.29165543975034, 110.53934364846614, 111.78770285025963, 113.03672626175657, 114.28640723886495, 115.53673927249345, 116.78771598444443, 118.03933112347255, 119.29157856150051, 120.54445228998452], [0.0, 0.9580425426254617, 1.9836556798558966, 3.0364218794504323, 4.107218292667062, 5.191624810601837, 6.287002131559089, 7.391587744298876, 8.504118065915756, 9.623641351811782, 10.749414128321435, 11.88083909333087, 13.017425565838199, 14.15876307639832, 15.30450304633687, 16.454345671966585, 17.608030283696717, 18.76532809811797, 19.926036662320314, 21.089975522703156, 22.256982797792237, 23.42691243038155, 24.599631958257692, 25.77502068641285, 26.952968174056565, 28.13337297130196, 29.31614155595123, 30.501187432183894, 31.688430361392143, 32.877795701747154, 34.06921383789637, 35.262619685889305, 36.4579522612959, 37.65515430072419, 38.85417192871312, 40.054954363383246, 41.25745365535507, 42.46162445535358, 43.6674238066556, 44.874810959139324, 46.08374720219045, 47.294195714128335, 48.506121426155154, 49.71949089911453, 50.93427221158312, 52.15043485801882, 53.36794965585826, 54.58678866059938, 55.806925088027484, 57.02833324284707, 58.25098845307198, 59.47486700960313, 60.69994611048978, 61.926203809428465, 63.15361896810288, 64.38217121201305, 65.61184088947886, 66.8426090335375, 68.07445732648327, 69.30736806682391, 70.54132413845079, 71.77630898183996, 73.01230656711931, 74.24930136885274, 75.48727834240616, 76.7262229017732, 77.9661208987491, 79.2069586033518, 80.44872268539795, 81.69140019714973, 82.93497855695561, 84.17944553381479, 85.42478923280066, 86.67099808128467, 87.91806081590558, 89.16596647023509, 90.41470436309292, 91.66426408746986, 92.91463550001917, 94.16580871108035, 95.41777407520199, 96.67052218213291, 97.92404384825257, 99.17833010841446, 100.43337220817826, 101.6891615964068, 102.94568991820775, 104.20294900819914, 105.4609308840812, 106.71962774049655, 107.97903194316315, 109.23913602326479, 110.49993267208514, 111.7614147358723, 113.02357521092156, 114.28640723886495, 115.54990410215648, 116.81405921974333, 118.07886614291354, 119.34431855131093, 120.61041024910907, 121.87713516133648], [0.0, 0.9685238527791695, 2.005357545371969, 3.069641364034914, 4.1521526529684865, 5.248422945779093, 6.355784065915896, 7.47245421966857, 8.597156000106388, 9.728927250222894, 10.867016362498662, 12.010819500132262, 13.159840613905322, 14.313664743697881, 15.471939497266726, 16.634361790970626, 17.80066810340516, 18.970627148192985, 20.144034257520612, 21.32070700356389, 22.50048173381036, 23.683210793138677, 24.86876027015392, 26.05700814940398, 27.24784278183872, 28.44116160767511, 29.636870081550796, 30.834880761351712, 32.03511253063248, 33.23748993095736, 34.441942585358255, 35.648404697844185, 36.856814616794765, 38.06711445233711, 39.27924973959436, 40.4931691411161, 41.708824182940354, 42.92616901965568, 44.14516022457779, 45.365756601764744, 46.587919017094976, 47.811610246046186, 49.03679483615601, 50.263438982432376, 51.49151041422074, 52.72097829223802, 53.95181311465373, 55.183986631243485, 56.41747176476418, 57.65224253880509, 58.88827401146016, 60.12554221424472, 61.36402409574697, 62.603697469563436, 63.844540966117485, 65.08653398800519, 66.32965666855038, 67.57388983328528, 68.81921496410224, 70.06561416584873, 71.31307013516002, 72.56156613134542, 73.81108594916053, 75.06161389331577, 76.3131347545836, 77.56563378738184, 78.81909668871957, 80.07350957840404, 81.32885898041522, 82.5851318053626, 83.84231533394714, 85.10039720135676, 86.3593653825303, 87.61920817823075, 88.87991420187187, 90.1414723670489, 91.40387187572587, 92.66710220703733, 93.9311531066649, 95.19601457675181, 96.4616768663222, 97.7281304621735, 98.99536608021326, 100.26337465721326, 101.53214734295662, 102.80167549275382, 104.07195066030717, 105.34296459090267, 106.61470921491147, 107.88717664158294, 109.16035915311343, 110.43424919897532, 111.70883939049246, 112.98412249564846, 114.26009143411575, 115.53673927249345, 116.81405921974333, 118.09204462281365, 119.37068896244136, 120.64998584912342, 121.92992901924896, 123.21051233138427], [0.0, 0.9790105671561282, 2.0270706004935857, 3.102877976774974, 4.1971101816821745, 5.305250366398552, 6.424601464630062, 7.553362390253845, 8.690241905186134, 9.834267434643278, 10.984679233058076, 12.140866925572192, 13.302329091982891, 14.468646279179929, 15.639462279384945, 16.814470727311587, 17.993405248271344, 19.176032051628276, 20.362144253523425, 21.551557450891156, 22.74410621926766, 23.93964130479235, 25.13802734614159, 26.339141006738153, 27.542869428649215, 28.749108941623337, 29.95776397660608, 31.168746144701856, 32.38197345117511, 33.59736962056214, 34.81486351388661, 36.034388622749915, 37.25588262799735, 38.47928701295207, 39.70454672301752, 40.93160986488584, 42.16042743974214, 43.3909531057827, 44.623142966119815, 45.85695537876152, 47.09235078586067, 48.329291559845565, 49.56774186439151, 50.80766752848208, 52.049035932051474, 53.29181590190359, 54.53597761677615, 55.78149252056483, 57.02833324284707, 58.27647352595193, 59.5258881579143, 60.77655291073019, 62.02844448339811, 63.28154044929079, 64.535819207452, 65.79125993745896, 67.04784255752861, 68.30554768558116, 69.56435660300374, 70.82425122088362, 72.08521404850353, 73.34722816391253, 74.6102771864036, 75.87434525074598, 77.13941698303395, 78.40547747802714, 79.67251227786866, 80.94050735207772, 82.2094490787223, 83.47932422668626, 84.75011993895204, 86.02182371682724, 87.29442340504914, 88.5679071777069, 89.84226352492581, 91.11748124026278, 92.39354940876585, 93.67045739565468, 94.94819483558199, 96.22675162243901, 97.50611789967097, 98.78628405107085, 100.06724069202251, 101.34897866116539, 102.63148901245667, 103.91476300760628, 105.19879210886405, 106.48356797213788, 107.7690824404248, 109.05532753753691, 110.34229546210585, 111.62997858185051, 112.91836942809365, 114.2074606905141, 115.49724521212184, 116.78771598444443, 118.07886614291354, 119.37068896244136, 120.66317785317736, 121.956326356436, 123.25012814078701, 124.5445769983002], [0.0, 0.9895026333532643, 2.0487947367186194, 3.13613155158421, 4.242090654151233, 5.362106788488384, 6.493453983814737, 7.63431185174915, 8.783375315996192, 9.93966137867837, 11.102402152027521, 12.27098071979175, 13.444890288042908, 14.623706908387513, 15.80707055556482, 16.99467158096859, 18.186240755170065, 19.38154178199669, 20.58036556041309, 21.782525711104093, 22.987855036750236, 24.196202683935788, 25.407431840668437, 26.621417848571593, 27.838046640212834, 29.057213434305577, 30.27882163758085, 31.50278191387838, 32.72901138972419, 33.95743297220967, 35.18797475996134, 36.42056953180943, 37.65515430072419, 38.89166992290498, 40.13006075373456, 41.37027434376398, 42.61226116905753, 43.85597439116592, 45.10136964275806, 46.348404835564324, 47.59703998779571, 48.847237068625475, 50.09895985767064, 51.35217381770367, 52.60684597906919, 53.862944834487614, 55.12044024310192, 56.3793033427717, 57.63950646974531, 58.90102308494808, 60.16382770621803, 61.42789584589938, 62.69320395327358, 63.95972936136697, 65.22745023772566, 66.49634553879417, 67.76639496757278, 69.03757893426375, 70.30987851964666, 71.58327544094968, 72.85775202000738, 74.13329115351608, 75.40987628521657, 76.68749137985026, 77.9661208987491, 79.24574977693311, 80.52636340160043, 81.80794759190543, 83.09048857992974, 84.37397299275918, 85.65838783558742, 86.94372047577346, 88.22995862778646, 89.51709033897723, 90.80510397611957, 92.09398821267085, 93.38373201670346, 94.67432463946399, 95.96575560451966, 97.25801469745441, 98.55109195608067, 99.84497766113445, 101.13966232742455, 102.43513669540803, 103.73139172316726, 105.0284185787638, 106.32620863294835, 107.62475345220506, 108.92404479211228, 110.22407459100127, 111.52483496389628, 112.82631819672095, 114.1285167407562, 115.43142320733604, 116.73503036276892, 118.03933112347255, 119.34431855131093, 120.64998584912342, 121.956326356436, 123.26333354534533, 124.57100101656714, 125.87932249564078], [0.0, 1.0000000000000002, 2.070529847682755, 3.1694019256486143, 4.287093850145173, 5.418991933671841, 6.562341286358656, 7.715302207814954, 8.876555776542762, 10.045108566305142, 11.220184543019636, 12.401160245736166, 13.587523504086445, 14.778845872122783, 15.97476350517352, 17.17496346965384, 18.379173679952565, 19.587155333094756, 20.798697109748524, 22.013610653350806, 23.23172699283085, 24.452893674409715, 25.676972434693543, 26.903837292838645, 28.133372971301956, 29.365473577200483, 30.600041492533304, 31.836986433396902, 33.076224647134964, 34.317678222981, 35.56127449677925, 36.80694553422866, 38.05462768008709, 39.30426116311324, 40.55578974837115, 41.80916042998978, 43.06432315864737, 44.321230598998135, 45.57983791302992, 46.84010256597002, 48.1019841518734, 49.36544423645453, 50.63044621507816, 51.89695518412061, 53.16493782416031, 54.43436229366547, 55.70519813202282, 56.97741617090131, 58.25098845307198, 59.525888157914295, 60.80208953293288, 62.07956783068903, 63.35829925062096, 64.6382608852872, 65.91943067061924, 67.20178733981619, 68.48531038055295, 69.76997999520889, 71.05577706385466, 72.34268310976147, 73.63068026722098, 74.91975125148517, 76.20987933065393, 77.50104829935496, 78.79324245407466, 80.08644657001275, 81.38064587934409, 82.67582605078225, 83.97197317034875, 85.26907372325978, 86.56711457685061, 87.86608296446394, 89.16596647023508, 90.46675301471235, 91.76843084125585, 93.0709885031627, 94.37441485147049, 95.67869902339527, 96.98383043136253, 98.28979875259428, 99.59659391921674, 100.90420610885691, 102.21262573569774, 103.52184344196432, 104.8318500898157, 106.14263675361784, 107.45419471257601, 108.76651544370549, 110.0795906151218, 111.3934120796321, 112.70797186861107, 114.02326218614581, 115.3392754034349, 116.65600405342796, 117.97344082569322, 119.29157856150051, 120.61041024910907, 121.92992901924896, 123.25012814078701, 124.57100101656714, 125.89254117941675, 127.21474228831119], [0.0, 1.0105026167277862, 2.0922758290964083, 3.202688939330008, 4.332119553729296, 5.47590552900216, 6.631263041726207, 7.796333069842675, 8.969782839726605, 10.150608491566045, 11.33802584089, 12.53140487877699, 13.730228055729647, 14.93406242599671, 16.14254032358538, 17.355345528289337, 18.57220309688652, 19.792871718345857, 21.017137853929523, 22.244811168837654, 23.475720917361112, 24.70971304455734, 25.946647834905054, 27.186397984432045, 28.428847004879394, 29.673887891211745, 30.921422000183725, 32.17135809967459, 33.42361155740597, 34.67810364434446, 35.93476093317051, 37.19351477609516, 38.454300849329634, 39.71705875387822, 40.98173166419096, 42.24826601769648, 43.51661123942416, 44.78671949688323, 46.05854548114508, 47.33204621071059, 48.60718085526656, 49.8839105768669, 51.1621983864319, 52.44200901375851, 53.723308789484044, 55.006065537657285, 56.29024847774884, 57.57582813508384, 58.862776258809276, 60.151065746617924, 61.4406705755458, 62.73156573824134, 64.0237271841746, 65.317131765316, 66.61175718586661, 67.90758195566845, 69.20458534696336, 70.50274735420385, 71.80204865665132, 73.10247058352297, 74.40399508147375, 75.70660468422058, 77.0102824841346, 78.31501210564471, 79.62077768030932, 80.9275638234279, 82.2353556120745, 83.54413856444671, 84.85389862043284, 86.1646221233085, 87.4762958024816, 88.78890675721155, 90.10244244123456, 91.41689064823315, 92.73223949809189, 94.04847742388758, 95.36559315956455, 96.68357572825117, 98.00241443117572, 99.32209883714398, 100.64261877254322, 101.96396431183976, 103.28612576854042, 104.60909368658913, 105.93285883217375, 107.25741218591769, 108.58274493543507, 109.90884846822753, 111.23571436490401, 112.56333439270479, 113.89170049931317, 115.22080480693876, 116.55063960665773, 117.88119735299617, 119.21247065874361, 120.54445228998452, 121.87713516133648, 123.21051233138427, 124.5445769983002, 125.87932249564078, 127.21474228831119, 128.55082996868938]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 2.2\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.00630957344480193, 0.013524866756124824, 0.021126783420037105, 0.028991186547107816, 0.03705672245534738, 0.04528625163669504, 0.053654709028489386, 0.062143968777258696, 0.07074027770369604, 0.07943282347242814, 0.08821287032977507, 0.09707320544390105, 0.10600776727459531, 0.11501138655368277, 0.12407960005846735, 0.13320851318429971, 0.14239469625117057, 0.1516351047505385, 0.16092701697250666, 0.1702679845041569, 0.1796557924282295, 0.18908842694721617, 0.198564048771215, 0.20808097103621354, 0.217637640824031, 0.22723262357526913, 0.23686458984806724, 0.24653230399548132, 0.25623461442463663, 0.265970445169564, 0.2757387885625234, 0.28553869882969674, 0.2953692864693294, 0.3052297132958416, 0.315119188053697, 0.32503696252107633, 0.33498232803653694, 0.3449546123925206, 0.3549531770483064, 0.3649774146221923, 0.3750267466286341, 0.3851006214310102, 0.39519851238481146, 0.4053199161495176, 0.4154643511503421, 0.42563135617350106, 0.43582048908075827, 0.44603132563079345, 0.45626345839647053, 0.4665164957684037, 0.47679006103635063, 0.48708379154094467, 0.4973973378891306, 0.507730363227404, 0.5180825425676043, 0.5284535621605742, 0.5388431189134865, 0.5492509198470897, 0.5596766815894849, 0.5701201299034058, 0.5805809992442568, 0.5910590323464371, 0.6015539798357156, 0.6120655998656237, 0.6225936577760293, 0.633137925772215, 0.643698182622939, 0.6542742133760885, 0.6648658090906544, 0.6754727665838723, 0.6860948881924606, 0.6967319815469868, 0.7073838593584673, 0.7180503392163753, 0.7287312433973051, 0.7394263986835935, 0.7501356361912553, 0.7608587912066426, 0.7715957030312759, 0.7823462148343429, 0.7931101735123912, 0.8038874295557847, 0.8146778369215131, 0.8254812529119842, 0.8362975380594474, 0.8471265560157232, 0.8579681734469374, 0.868822259932977, 0.879688687871406, 0.890567332385593, 0.9014580712368239, 0.9123607847401829, 0.9232753556840018, 0.9342016692526901, 0.9451396129527676, 0.9560890765419368, 0.9670499519610372, 0.9780221332687382, 0.9890055165788326, 1.0, 1.0110054835779236], [0.0, 0.013524866756124824, 0.028991186547107813, 0.04528625163669504, 0.062143968777258696, 0.07943282347242814, 0.09707320544390102, 0.11501138655368276, 0.1332085131842997, 0.15163510475053849, 0.1702679845041569, 0.18908842694721614, 0.20808097103621354, 0.22723262357526913, 0.24653230399548132, 0.265970445169564, 0.2855386988296967, 0.3052297132958416, 0.32503696252107633, 0.34495461239252057, 0.3649774146221923, 0.38510062143101015, 0.40531991614951757, 0.42563135617350095, 0.4460313256307934, 0.46651649576840365, 0.48708379154094467, 0.5077303632274038, 0.528453562160574, 0.5492509198470896, 0.5701201299034059, 0.591059032346437, 0.6120655998656237, 0.633137925772215, 0.6542742133760884, 0.6754727665838722, 0.6967319815469867, 0.7180503392163752, 0.7394263986835935, 0.7608587912066425, 0.7823462148343427, 0.8038874295557846, 0.8254812529119842, 0.8471265560157231, 0.868822259932977, 0.890567332385593, 0.9123607847401829, 0.93420166925269, 0.9560890765419368, 0.9780221332687383, 1.0, 1.0220218692396401, 1.0440869636102885, 1.0661945341715362, 1.088343858862089, 1.1105342410545758, 1.1327650082129537, 1.155035510643526, 1.1773451203315186, 1.1996932298559693, 1.222079251376429, 1.244502615685596, 1.2669627713225835, 1.2894591837420246, 1.3119913345346659, 1.3345587206955016, 1.3571608539358668, 1.3797972600362132, 1.4024674782365998, 1.4251710606621695, 1.4479075717811325, 1.4706765878929686, 1.4934776966447734, 1.5163104965738214, 1.5391745966745887, 1.5620696159886158, 1.584995183215713, 1.6079509363451336, 1.6309365223054437, 1.653951596631912, 1.6769958231503326, 1.7000688736762715, 1.7231704277288078, 1.7463001722578952, 1.7694578013845494, 1.7926430161531028, 1.8158555242948335, 1.839095040002326, 1.8623612837139483, 1.8856539819078906, 1.908972866905234, 1.9323176766815582, 1.955688154686631, 1.9790840496717406, 2.002505115524281, 2.0259511111091992, 2.0494218001169573, 2.0729169509176737, 2.096436336421135, 2.1199797339423814, 2.1435469250725863, 2.1671376955549815], [0.0, 0.021126783420037105, 0.04528625163669504, 0.07074027770369606, 0.09707320544390105, 0.12407960005846737, 0.15163510475053854, 0.17965579242822954, 0.20808097103621354, 0.23686458984806724, 0.26597044516956403, 0.2953692864693295, 0.32503696252107644, 0.3549531770483064, 0.3851006214310103, 0.41546435115034214, 0.4460313256307935, 0.47679006103635074, 0.507730363227404, 0.5388431189134866, 0.5701201299034059, 0.6015539798357156, 0.6331379257722151, 0.6648658090906546, 0.6967319815469869, 0.7287312433973052, 0.7608587912066427, 0.7931101735123914, 0.8254812529119844, 0.8579681734469375, 0.8905673323855932, 0.923275355684002, 0.9560890765419369, 0.9890055165788328, 1.0220218692396403, 1.0551354851084376, 1.0883438588620893, 1.1216446176402188, 1.1550355106435264, 1.188514399801723, 1.2220792513764294, 1.2557281283842803, 1.2894591837420248, 1.3232706540492396, 1.3571608539358673, 1.3911281709115697, 1.4251710606621701, 1.4592880427454737, 1.493477696644774, 1.5277386581434653, 1.5620696159886163, 1.5964693088151325, 1.630936522305444, 1.6654700865624932, 1.7000688736762721, 1.7347317954663304, 1.76945780138455, 1.804245876564148, 1.8390950400023267, 1.8740043428652566, 1.9089728669052342, 1.9439997229808277, 1.979084049671741, 2.014225011980899, 2.0494218001169577, 2.0846736283510814, 2.1199797339423823, 2.1553393761269124, 2.1907518351655684, 2.2262164114466443, 2.2617324246391637, 2.297299212893418, 2.3329161320854643, 2.368582555102577, 2.404297871166908, 2.440061485194822, 2.4758728171895754, 2.5117313016651788, 2.547636387099474, 2.5835875354145696, 2.6195842214829534, 2.655625932657693, 2.6917121683252785, 2.727842439479745, 2.7640162683168246, 2.800233187846952, 2.836492741526038, 2.8727944829030023, 2.9091379752831137, 2.9455227914062636, 2.9819485131393466, 3.0184147311819767, 3.054921044784831, 3.091467061479931, 3.1280523968222536, 3.1646766741420573, 3.2013395243073943, 3.2380405854962637, 3.2747795029779443, 3.311555928903025, 3.3483695221017142, 3.3852199478900245], [0.0, 0.028991186547107816, 0.062143968777258696, 0.09707320544390105, 0.13320851318429971, 0.17026798450415692, 0.20808097103621354, 0.24653230399548134, 0.28553869882969674, 0.32503696252107633, 0.36497741462219235, 0.4053199161495176, 0.4460313256307935, 0.4870837915409447, 0.5284535621605742, 0.5701201299034059, 0.6120655998656238, 0.6542742133760885, 0.6967319815469868, 0.7394263986835935, 0.7823462148343429, 0.8254812529119842, 0.8688222599329771, 0.9123607847401829, 0.9560890765419369, 1.0, 1.0440869636102887, 1.088343858862089, 1.1327650082129537, 1.1773451203315188, 1.2220792513764294, 1.2669627713225835, 1.3119913345346659, 1.357160853935867, 1.4024674782365998, 1.4479075717811325, 1.4934776966447736, 1.5391745966745887, 1.5849951832157134, 1.6309365223054437, 1.6769958231503328, 1.7231704277288078, 1.7694578013845499, 1.8158555242948335, 1.8623612837139485, 1.9089728669052342, 1.9556881546866314, 2.0025051155242815, 2.0494218001169577, 2.0964363364211356, 2.1435469250725867, 2.190751835165568, 2.238049400355208, 2.2854380152525953, 2.3329161320854643, 2.3804822576003546, 2.4281349501847003, 2.475872817189575, 2.5236945124358416, 2.571598733888163, 2.619584221482953, 2.6676497550976506, 2.7157941526499667, 2.7640162683168246, 2.8123149908636624, 2.860689242075648, 2.9091379752831132, 2.957660173974205, 3.0062548504883684, 3.0549210447848303, 3.1036578232807623, 3.1524642777542167, 3.2013395243073934, 3.250282702386102, 3.2992929738516534, 3.348369522101714, 3.397511551236903, 3.446718285270198, 3.4959889673764124, 3.54532285917923, 3.594719240073467, 3.6441774065803876, 3.6936966717341, 3.74327636449714, 3.792915829203551, 3.842614425027831, 3.8923715254782603, 3.942186517913232, 3.992058803079269, 4.041987794669538, 4.091972918901714, 4.142013614114159, 4.1921093303794095, 4.242259529134062, 4.292463682824198, 4.342721274565514, 4.393031797817429, 4.443394756070421, 4.493809662545963, 4.544276039908392, 4.594793419988141, 4.645361343515772], [0.0, 0.03705672245534738, 0.07943282347242814, 0.12407960005846737, 0.17026798450415692, 0.21763764082403103, 0.26597044516956403, 0.31511918805369704, 0.36497741462219235, 0.415464351150342, 0.4665164957684037, 0.5180825425676044, 0.570120129903406, 0.6225936577760293, 0.6754727665838723, 0.7287312433973052, 0.782346214834343, 0.8362975380594475, 0.890567332385593, 0.9451396129527675, 1.0, 1.0551354851084374, 1.110534241054576, 1.1661854655146122, 1.2220792513764294, 1.2782064782044662, 1.3345587206955016, 1.3911281709115695, 1.4479075717811327, 1.504890159890164, 1.562069615988616, 1.61944002194841, 1.6769958231503328, 1.7347317954663304, 1.7926430161531028, 1.8507248380919417, 1.908972866905234, 1.9673829405572056, 2.0259511111091997, 2.084673628351081, 2.1435469250725867, 2.202567603773323, 2.2617324246391632, 2.321038294637024, 2.3804822576003546, 2.4400614851948226, 2.49977326866819, 2.5596150113007194, 2.619584221482954, 2.679678506356733, 2.7398955659630437, 2.8002331878469517, 2.8606892420756473, 2.9212616766306247, 2.981948513139346, 3.0427478429155657, 3.1036578232807623, 3.164676674142057, 3.2258026748045543, 3.2870341609982527, 3.348369522101714, 3.4098071985463747, 3.4713456793869963, 3.5329835000250993, 3.594719240073467, 3.6565515213509174, 3.7184790059974997, 3.780500394701177, 3.8426144250278313, 3.904819869847126, 3.967115535847442, 4.029500262133603, 4.091972918901714, 4.154532406185834, 4.217177652671662, 4.279907614572803, 4.342721274565514, 4.405617640778156, 4.468595745831872, 4.531654645929272, 4.594793419988141, 4.658011168817402, 4.721307014332802, 4.784680098809907, 4.848129584172243, 4.911654651312503, 4.975254499444913, 5.038928345486999, 5.102675423469089, 5.1664949839699865, 5.23038629357741, 5.294348634371811, 5.358381303432347, 5.422483612363786, 5.48665488684329, 5.550894466185997, 5.6152017029284504, 5.679575962428966, 5.744016622484076, 5.808523072960244, 5.8730947154400965, 5.937730962882462], [0.0, 0.04528625163669504, 0.09707320544390102, 0.15163510475053854, 0.20808097103621354, 0.26597044516956403, 0.3250369625210764, 0.38510062143101026, 0.44603132563079345, 0.5077303632274038, 0.5701201299034059, 0.633137925772215, 0.6967319815469869, 0.7608587912066426, 0.8254812529119843, 0.8905673323855932, 0.9560890765419368, 1.0220218692396403, 1.088343858862089, 1.1550355106435262, 1.2220792513764291, 1.2894591837420246, 1.357160853935867, 1.42517106066217, 1.4934776966447738, 1.562069615988616, 1.6309365223054437, 1.7000688736762721, 1.7694578013845499, 1.8390950400023265, 1.9089728669052342, 1.9790840496717408, 2.0494218001169573, 2.119979733942382, 2.190751835165568, 2.2617324246391632, 2.3329161320854643, 2.4042978711669076, 2.4758728171895754, 2.5476363870994736, 2.619584221482953, 2.691712168325278, 2.7640162683168246, 2.8364927415260377, 2.9091379752831137, 2.9819485131393466, 3.054921044784831, 3.128052396822253, 3.201339524307394, 3.2747795029779443, 3.348369522101714, 3.4221068778834347, 3.495988967376412, 3.570013282851406, 3.6441774065803885, 3.7184790059974993, 3.792915829203552, 3.8674857007839725, 3.9421865179132323, 4.017016246721494, 4.091972918901714, 4.167054628537513, 4.242259529134062, 4.31758583083595, 4.393031797817429, 4.468595745831872, 4.544276039908393, 4.620071092184709, 4.695979359866279, 4.771999343302582, 4.848129584172244, 4.924368663769359, 5.000715201384029, 5.077167852770699, 5.153725308698391, 5.23038629357741, 5.307149564157516, 5.384013908292959, 5.46097814377011, 5.538041117193762, 5.61520170292845, 5.692458802091417, 5.769811341594115, 5.8472582732293095, 5.924798572801134, 6.00243123929554, 6.080155294088849, 6.1579697801922215, 6.235873761530008, 6.313866322250118, 6.391946566064617, 6.470113615618923, 6.548366611888057, 6.626704713598491, 6.705127096674275, 6.783632953706146, 6.86222149344245, 6.9408919403007525, 7.019643533899105, 7.098475528605971, 7.1773871931078945, 7.256377809994043], [0.0, 0.053654709028489386, 0.11501138655368276, 0.17965579242822954, 0.24653230399548134, 0.31511918805369704, 0.38510062143101026, 0.4562634583964705, 0.5284535621605742, 0.6015539798357155, 0.6754727665838723, 0.7501356361912552, 0.8254812529119844, 0.9014580712368239, 0.9780221332687383, 1.0551354851084376, 1.1327650082129537, 1.2108815376181938, 1.2894591837420246, 1.368474801984601, 1.4479075717811323, 1.5277386581434649, 1.6079509363451339, 1.6885287656197117, 1.7694578013845499, 1.8507248380919414, 1.9323176766815584, 2.0142250119808986, 2.0964363364211356, 2.1789418572038874, 2.2617324246391632, 2.344799469824506, 2.4281349501847, 2.5117313016651783, 2.5955813965886447, 2.6796785063567325, 2.764016268316824, 2.848588656225808, 2.9333899538334083, 3.0184147311819767, 3.1036578232807615, 3.189114310863219, 3.274779502977944, 3.3606489211989135, 3.446718285270198, 3.532983500025099, 3.619440643440744, 3.70608595570696, 3.792915829203552, 3.8799267992930693, 3.9671155358474417, 4.054478835436419, 4.142013614114159, 4.229716900747528, 4.317585830835949, 4.405617640778155, 4.493809662545964, 4.582159318729415, 4.670664117921344, 4.759321650412612, 4.848129584172243, 4.937085661089107, 5.026187693454151, 5.1154335606641474, 5.204821206129691, 5.294348634371812, 5.384013908292959, 5.473815146609394, 5.5637505214331995, 5.65381825599307, 5.744016622484076, 5.834343940037302, 5.924798572801134, 6.015378928126556, 6.106083454849482, 6.196910641663686, 6.287859015578419, 6.378927140455221, 6.470113615618924, 6.56141707453814, 6.652836183570954, 6.744369640771799, 6.8360161747558355, 6.92777454361736, 7.019643533899104, 7.111621959609391, 7.203708661284436, 7.295902505093201, 7.388202381982389, 7.480607206859384, 7.573115917810985, 7.665727475356044, 7.758440861730149, 7.851255080200633, 7.9441691544103525, 8.037182127748691, 8.130293062748413, 8.223501040507012, 8.31680516013138, 8.410204538204548, 8.50369830827347, 8.597285620356791], [0.0, 0.062143968777258696, 0.1332085131842997, 0.20808097103621354, 0.28553869882969674, 0.36497741462219235, 0.44603132563079345, 0.5284535621605742, 0.6120655998656237, 0.6967319815469867, 0.7823462148343429, 0.868822259932977, 0.9560890765419369, 1.0440869636102887, 1.1327650082129537, 1.2220792513764294, 1.3119913345346659, 1.4024674782365998, 1.4934776966447736, 1.5849951832157132, 1.6769958231503326, 1.7694578013845497, 1.8623612837139485, 1.955688154686631, 2.0494218001169573, 2.1435469250725863, 2.238049400355208, 2.3329161320854643, 2.4281349501847, 2.523694512435841, 2.6195842214829534, 2.7157941526499667, 2.8123149908636624, 2.9091379752831132, 3.006254850488368, 3.103657823280762, 3.2013395243073934, 3.299292973851653, 3.397511551236903, 3.495988967376412, 3.5947192400734664, 3.6936966717340995, 3.792915829203551, 3.89237152547826, 3.992058803079269, 4.091972918901714, 4.1921093303794095, 4.292463682824198, 4.39303179781743, 4.493809662545964, 4.59479341998814, 4.695979359866279, 4.797363910291952, 4.898943630038695, 5.000715201384028, 5.102675423469089, 5.204821206129692, 5.307149564157515, 5.409657611954408, 5.512342558546528, 5.61520170292845, 5.718232429710207, 5.821432205042947, 5.9247985728011345, 6.028329151001342, 6.132021628439483, 6.235873761530008, 6.339883371332058, 6.44404834074889, 6.548366611888056, 6.652836183570955, 6.757455108981223, 6.86222149344245, 6.9671334923163455, 7.072189309013301, 7.177387193107894, 7.282725438552457, 7.38820238198239, 7.493816401107395, 7.59956591318319, 7.705449373558745, 7.811465274294383, 7.917612142846476, 8.023888540814735, 8.130293062748411, 8.236824335007972, 8.343481014679018, 8.450261788535515, 8.557165372049516, 8.664190508444813, 8.771335967792066, 8.878600546143195, 8.985983064702882, 9.093482369035197, 9.20109732830356, 9.308826834542213, 9.416669801957646, 9.524625166258406, 9.632691884011876, 9.740868932026665, 9.849155306759332, 9.957550023744291], [0.0, 0.07074027770369604, 0.15163510475053849, 0.23686458984806724, 0.32503696252107633, 0.415464351150342, 0.5077303632274038, 0.6015539798357155, 0.6967319815469867, 0.7931101735123912, 0.8905673323855929, 0.9890055165788325, 1.088343858862089, 1.1885143998017225, 1.2894591837420246, 1.3911281709115693, 1.4934776966447734, 1.5964693088151323, 1.7000688736762717, 1.8042458765641476, 1.9089728669052337, 2.014225011980898, 2.119979733942382, 2.226216411446644, 2.332916132085464, 2.4400614851948217, 2.547636387099473, 2.6556259326576925, 2.764016268316824, 2.872794482903002, 2.9819485131393457, 3.0914670614799307, 3.2013395243073934, 3.311555928903024, 3.422106877883434, 3.5329835000250984, 3.6441774065803876, 3.7556806523359376, 3.867485700783972, 3.979585392875099, 4.091972918901713, 4.204641793127751, 4.317585830835949, 4.430799127510073, 4.544276039908392, 4.658011168817403, 4.771999343302582, 4.886235606296406, 5.000715201384029, 5.1154335606641474, 5.230386293577409, 5.345569176607377, 5.460978143770109, 5.576609277817953, 5.692458802091417, 5.808523072960243, 5.924798572801134, 6.041281903465082, 6.157969780192221, 6.274859025936274, 6.3919465660646155, 6.509229423403176, 6.62670471359849, 6.7443696407718, 6.8622214934424495, 6.980257640699954, 7.09847552860597, 7.216872676809073, 7.335446675356785, 7.45419518169059, 7.573115917810984, 7.692206667600575, 7.811465274294383, 7.930889638087271, 8.050477713869306, 8.170227509080583, 8.290137081677681, 8.410204538204548, 8.5304280319612, 8.650805761264024, 8.771335967792064, 8.892016935013954, 9.012846986690677, 9.133824485449564, 9.254947831425365, 9.376215460964454, 9.497625845388518, 9.619177489814364, 9.740868932026663, 9.862698741400695, 9.984665517872306, 10.106767890952566, 10.22900451878465, 10.351374087240744, 10.473875309056845, 10.59650692300348, 10.719267693090474, 10.842156407804074, 10.965171879374743, 11.088312943074115, 11.211578456539659, 11.334967299125706], [0.0, 0.07943282347242814, 0.1702679845041569, 0.26597044516956403, 0.36497741462219235, 0.4665164957684037, 0.5701201299034059, 0.6754727665838723, 0.7823462148343429, 0.8905673323855929, 1.0, 1.1105342410545758, 1.2220792513764294, 1.3345587206955016, 1.4479075717811325, 1.562069615988616, 1.6769958231503328, 1.7926430161531028, 1.908972866905234, 2.0259511111091992, 2.1435469250725863, 2.261732424639163, 2.3804822576003546, 2.4997732686681897, 2.6195842214829534, 2.7398955659630433, 2.8606892420756473, 2.981948513139346, 3.103657823280762, 3.225802674804554, 3.348369522101714, 3.471345679386996, 3.594719240073467, 3.7184790059974993, 3.8426144250278305, 3.9671155358474417, 4.091972918901714, 4.217177652671661, 4.342721274565514, 4.4685957458318715, 4.59479341998814, 4.721307014332801, 4.848129584172243, 4.975254499444912, 5.102675423469089, 5.23038629357741, 5.358381303432347, 5.48665488684329, 5.6152017029284504, 5.744016622484076, 5.873094715440096, 6.0024312392955395, 6.132021628439482, 6.261861484273964, 6.391946566064616, 6.522272782452906, 6.652836183570955, 6.783632953706145, 6.914659404468226, 7.045911968416354, 7.177387193107894, 7.309081735534451, 7.440992356914004, 7.573115917810985, 7.705449373558745, 7.837989769961246, 7.9707342392529075, 8.103679996297407, 8.236824335007972, 8.370164624973144, 8.50369830827347, 8.637422896475666, 8.771335967792066, 8.905435164394058, 9.039718189869168, 9.17418280681228, 9.308826834542211, 9.443648146935558, 9.57864467037035, 9.713814381772591, 9.849155306759332, 9.984665517872306, 10.12034313289671, 10.256186313259974, 10.392193262505849, 10.528362224839382, 10.664691483738691, 10.801179360629753, 10.937824213620623, 11.074624436291806, 11.211578456539659, 11.348684735469943, 11.485941766338845, 11.623348073538883, 11.760902211627414, 11.898602764395429, 12.03644834397463, 12.174437589980785, 12.312569168691564, 12.450841772257101, 12.589254117941675, 12.727804947394988], [0.0, 0.08821287032977507, 0.18908842694721614, 0.2953692864693295, 0.4053199161495176, 0.5180825425676044, 0.633137925772215, 0.7501356361912552, 0.868822259932977, 0.9890055165788325, 1.1105342410545758, 1.2332863005546626, 1.357160853935867, 1.4820731560303444, 1.6079509363451336, 1.7347317954663304, 1.8623612837139485, 1.9907914514253717, 2.119979733942382, 2.2498880795893292, 2.380482257600354, 2.5117313016651783, 2.6436070572880928, 2.776083809728944, 2.9091379752831132, 3.0427478429155657, 3.1768933563414685, 3.3115559289030245, 3.4467182852701974, 3.5823643252558957, 3.7184790059974993, 3.855048239496118, 3.992058803079269, 4.129498260802806, 4.267354894163646, 4.405617640778155, 4.544276039908392, 4.68332018390204, 4.822740674761174, 4.962528585177103, 5.102675423469088, 5.243173101947722, 5.384013908292958, 5.525190479594419, 5.66669577875008, 5.808523072960244, 5.95066591408827, 6.093118120688892, 6.235873761530008, 6.378927140455221, 6.522272782452906, 6.665905420813348, 6.809819985269284, 6.954011591027066, 7.09847552860597, 7.243207254412254, 7.38820238198239, 7.533456673836864, 7.6789660338920065, 7.824726500382607, 7.970734239252907, 8.116985537977612, 8.263476799778392, 8.41020453820455, 8.557165372049516, 8.70435602057744, 8.851773299036449, 8.999414114437288, 9.147275461577939, 9.295354419296409, 9.443648146935558, 9.59215388100502, 9.740868932026665, 9.889790681551087, 10.0389165793336, 10.188244140659211, 10.337770943806804, 10.487494627643532, 10.637412889341194, 10.787523482206849, 10.937824213620623, 11.088312943074115, 11.238987580303336, 11.389846083510493, 11.540886457669409, 11.692106752909668, 11.843505062974945, 11.995079523751311, 12.14682831186154, 12.29874964332178, 12.450841772257101, 12.603102989672763, 12.755531622278163, 12.90812603136067, 13.060884611706731, 13.213805790567754, 13.366888026668471, 13.520129809255609, 13.673529657184854, 13.82708611804415, 13.98079776731155, 14.134663207545968], [0.0, 0.09707320544390105, 0.20808097103621354, 0.32503696252107644, 0.4460313256307935, 0.570120129903406, 0.6967319815469869, 0.8254812529119844, 0.9560890765419369, 1.088343858862089, 1.2220792513764294, 1.357160853935867, 1.493477696644774, 1.630936522305444, 1.76945780138455, 1.9089728669052344, 2.0494218001169577, 2.1907518351655684, 2.3329161320854643, 2.4758728171895754, 2.6195842214829534, 2.7640162683168246, 2.9091379752831137, 3.054921044784831, 3.2013395243073943, 3.3483695221017142, 3.4959889673764124, 3.644177406580389, 3.792915829203552, 3.9421865179132327, 4.091972918901715, 4.242259529134063, 4.39303179781743, 4.544276039908393, 4.695979359866279, 4.848129584172244, 5.000715201384029, 5.153725308698391, 5.307149564157517, 5.46097814377011, 5.6152017029284504, 5.769811341594115, 5.9247985728011345, 6.08015529408885, 6.235873761530009, 6.391946566064618, 6.548366611888059, 6.705127096674276, 6.862221493442452, 7.019643533899106, 7.177387193107895, 7.335446675356786, 7.493816401107395, 7.652490994924422, 7.811465274294385, 7.970734239252908, 8.130293062748414, 8.290137081677683, 8.450261788535517, 8.61066282362648, 8.771335967792066, 8.932277135611075, 9.093482369035199, 9.254947831425369, 9.416669801957648, 9.578644670370352, 9.740868932026666, 9.903339183269281, 10.066052117045698, 10.229004518784652, 10.392193262505852, 10.555615307146612, 10.719267693090476, 10.88314753888402, 11.047252038129205, 11.21157845653966, 11.376124129150162, 11.540886457669412, 11.705862907967022, 11.871051007686242, 12.036448343974632, 12.202052561325436, 12.367861359523, 12.53387249168593, 12.70008376240232, 12.866493025951591, 13.033098184607962, 13.199897187020948, 13.366888026668473, 13.534068740378602, 13.70143740691609, 13.86899214563022, 14.036731115160638, 14.204652512198061, 14.372754570297023, 14.541035558737878, 14.70949378143558, 14.87812757589278, 15.04693531219509, 15.215915392046334, 15.385066247841792, 15.55438634177768], [0.0, 0.10600776727459531, 0.22723262357526913, 0.3549531770483064, 0.4870837915409447, 0.6225936577760293, 0.7608587912066426, 0.9014580712368239, 1.0440869636102887, 1.1885143998017225, 1.3345587206955016, 1.4820731560303444, 1.630936522305444, 1.7810469789844139, 1.9323176766815584, 2.084673628351081, 2.238049400355208, 2.3923873703010106, 2.547636387099473, 2.703750723033523, 2.860689242075647, 3.0184147311819762, 3.176893356341469, 3.336094215462632, 3.495988967376412, 3.6565515213509165, 3.81775777521186, 3.9795853928750993, 4.142013614114159, 4.305023090903292, 4.4685957458318715, 4.6327146489745665, 4.797363910291952, 4.962528585177103, 5.128194591191222, 5.294348634371811, 5.4609781437701095, 5.628071213095151, 5.795616548521291, 5.963603421862743, 6.132021628439482, 6.300861449058681, 6.470113615618923, 6.6397692799137396, 6.809819985269284, 6.980257640699954, 7.151074497307368, 7.322263126683303, 7.493816401107395, 7.665727475356045, 7.837989769961245, 8.01059695577697, 8.183542939727342, 8.356821851625096, 8.530428031961199, 8.70435602057744, 8.878600546143197, 9.05315651636592, 9.228019008872236, 9.403183262702852, 9.578644670370348, 9.754398770433713, 9.930441240548157, 10.106767890952568, 10.283374658360513, 10.46025760022391, 10.637412889341192, 10.814836808784396, 10.992525747121816, 11.170476193914903, 11.348684735469945, 11.527148050826598, 11.705862907967019, 11.88482616023047, 12.064034742919652, 12.243485670086061, 12.42317603148261, 12.603102989672763, 12.783263777286239, 12.963655694411996, 13.144276106120046, 13.325122440104154, 13.50619218443814, 13.687482885438945, 13.868992145630218, 14.05071762180049, 14.23265702315052, 14.4148081095247, 14.59716868972182, 14.779736619880733, 14.962509801936815, 15.145486182145335, 15.3286637496682, 15.512040535220576, 15.695614609774378, 15.879384083315523, 16.063347103652273, 16.247501855271985, 16.43184655824389, 16.61637946716555, 16.801098870150817, 16.98600308785733], [0.0, 0.11501138655368277, 0.24653230399548132, 0.3851006214310103, 0.5284535621605742, 0.6754727665838723, 0.8254812529119843, 0.9780221332687383, 1.1327650082129537, 1.2894591837420246, 1.4479075717811325, 1.6079509363451336, 1.76945780138455, 1.9323176766815584, 2.096436336421135, 2.2617324246391632, 2.4281349501847, 2.5955813965886447, 2.764016268316824, 2.933389953833408, 3.1036578232807615, 3.2747795029779434, 3.446718285270198, 3.619440643440743, 3.7929158292035514, 3.9671155358474417, 4.142013614114159, 4.31758583083595, 4.493809662545964, 4.670664117921344, 4.848129584172243, 5.026187693454151, 5.204821206129691, 5.384013908292959, 5.563750521433199, 5.744016622484075, 5.924798572801134, 6.106083454849481, 6.287859015578419, 6.470113615618923, 6.652836183570954, 6.836016174755835, 7.019643533899104, 7.203708661284436, 7.38820238198239, 7.573115917810985, 7.75844086173015, 7.9441691544103525, 8.130293062748413, 8.31680516013138, 8.50369830827347, 8.69096564047162, 8.878600546143195, 9.066596656524913, 9.254947831425367, 9.443648146935558, 9.632691884011878, 9.822073517855136, 10.011787708017161, 10.201829289173341, 10.392193262505849, 10.582874787647512, 10.773869175141321, 10.965171879374745, 11.15677849195189, 11.348684735469945, 11.54088645766941, 11.733379625930315, 11.926160322089133, 12.119224737553198, 12.312569168691565, 12.506190012482838, 12.70008376240232, 12.894247004532112, 13.088676413879202, 13.283368750887782, 13.47832085813306, 13.673529657184856, 13.86899214563022, 14.064705394244996, 14.26066654430516, 14.456872805029295, 14.653321451144336, 14.850009820567134, 15.046935312195089, 15.244095383799392, 15.441487550015012, 15.63910938042191, 15.836958497712311, 16.035032575939262, 16.233329338841994, 16.43184655824389, 16.63058205251917, 16.829533685124588, 17.0286993631928, 17.228077036184057, 17.42766469459334, 17.62746036871002, 17.827462127427438, 18.02766807709987, 18.228076360444554, 18.428685155486562], [0.0, 0.12407960005846735, 0.265970445169564, 0.41546435115034214, 0.5701201299034059, 0.7287312433973052, 0.8905673323855932, 1.0551354851084376, 1.2220792513764294, 1.3911281709115693, 1.562069615988616, 1.7347317954663304, 1.9089728669052344, 2.084673628351081, 2.2617324246391632, 2.4400614851948226, 2.6195842214829534, 2.8002331878469517, 2.981948513139346, 3.164676674142057, 3.3483695221017133, 3.5329835000250984, 3.7184790059974997, 3.9048198698471266, 4.091972918901715, 4.279907614572803, 4.4685957458318715, 4.658011168817403, 4.848129584172244, 5.038928345487, 5.23038629357741, 5.422483612363786, 5.6152017029284504, 5.808523072960244, 6.0024312392955395, 6.196910641663686, 6.391946566064616, 6.587525076464595, 6.783632953706146, 6.980257640699954, 7.1773871931078945, 7.375010234843198, 7.573115917810985, 7.771693885393548, 7.970734239252908, 8.170227509080584, 8.370164624973146, 8.570536892153362, 8.771335967792067, 8.972553839715928, 9.174182806812281, 9.376215460964456, 9.57864467037035, 9.781463564113736, 9.984665517872308, 10.188244140659213, 10.39219326250585, 10.59650692300348, 10.801179360629755, 11.006205002793727, 11.211578456539659, 11.417294499855707, 11.623348073538885, 11.829734273572281, 12.03644834397463, 12.243485670086065, 12.450841772257103, 12.65851229991092, 12.866493025951591, 13.074779841493298, 13.283368750887785, 13.492255867029023, 13.701437406916089, 13.910909687456543, 14.120669121494238, 14.33071221404662, 14.541035558737876, 14.751635834415234, 14.962509801936816, 15.173654301120207, 15.38506624784179, 15.59674263127757, 15.808680511276993, 16.020877015861707, 16.233329338841994, 16.446034737543904, 16.65899053064076, 16.872194096083085, 17.08564286912135, 17.299334340416486, 17.513266054233146, 17.727435606711403, 17.941840644212526, 18.156478861734904, 18.3713480013965, 18.586445850980255, 18.801770242539263, 19.017319051058656, 19.233090193171304, 19.44908162592467, 19.665291345596255, 19.881717386555298], [0.0, 0.13320851318429971, 0.2855386988296967, 0.4460313256307935, 0.6120655998656238, 0.782346214834343, 0.9560890765419368, 1.1327650082129537, 1.3119913345346659, 1.4934776966447734, 1.6769958231503328, 1.8623612837139485, 2.0494218001169577, 2.238049400355208, 2.4281349501847, 2.6195842214829534, 2.8123149908636624, 3.006254850488368, 3.2013395243073934, 3.397511551236903, 3.5947192400734664, 3.792915829203551, 3.9920588030792694, 4.192109330379409, 4.39303179781743, 4.59479341998814, 4.797363910291952, 5.000715201384029, 5.204821206129691, 5.409657611954408, 5.61520170292845, 5.821432205042947, 6.028329151001342, 6.235873761530008, 6.444048340748889, 6.652836183570954, 6.8622214934424495, 7.072189309013301, 7.282725438552458, 7.493816401107394, 7.705449373558745, 7.917612142846476, 8.130293062748411, 8.343481014679016, 8.557165372049518, 8.771335967792066, 8.985983064702882, 9.20109732830356, 9.416669801957648, 9.632691884011878, 9.849155306759332, 10.066052117045695, 10.283374658360513, 10.50111555427338, 10.719267693090474, 10.937824213620623, 11.156778491951892, 11.37612412915016, 11.595854939800383, 11.815964941319164, 12.036448343974628, 12.25729954155566, 12.478513102638335, 12.70008376240232, 12.922006414954364, 13.144276106120047, 13.366888026668471, 13.589837505937655, 13.813120005831387, 14.036731115160634, 14.260666544305161, 14.484922120172742, 14.709493781435576, 14.934377574024932, 15.159569646866682, 15.385066247841788, 15.610863719957022, 15.836958497712311, 16.063347103652273, 16.29002614509027, 16.516992310994336, 16.744242369025013, 16.971773162715937, 17.199581608788588, 17.42766469459334, 17.65601947566939, 17.88464307341671, 18.113532672873678, 18.342685520594358, 18.57209892261997, 18.801770242539263, 19.031696899633033, 19.2618763670982, 19.492306170347174, 19.722983885378685, 19.953907137216138, 20.185073598410195, 20.41648098760218, 20.648127068145318, 20.880009646780845, 21.112126572366314, 21.344475734653535], [0.0, 0.14239469625117057, 0.3052297132958416, 0.47679006103635074, 0.6542742133760885, 0.8362975380594475, 1.0220218692396403, 1.2108815376181938, 1.4024674782365998, 1.5964693088151323, 1.7926430161531028, 1.9907914514253717, 2.1907518351655684, 2.3923873703010106, 2.5955813965886447, 2.8002331878469517, 3.006254850488368, 3.2135689833624936, 3.4221068778834343, 3.6318071103975247, 3.84261442502783, 4.054478835436419, 4.267354894163647, 4.481201092044245, 4.695979359866279, 4.911654651312503, 5.128194591191222, 5.345569176607378, 5.563750521433199, 5.782712636476382, 6.0024312392955395, 6.222883588806346, 6.444048340748889, 6.665905420813349, 6.888435912795311, 7.111621959609391, 7.335446675356785, 7.559894066938789, 7.784948963949371, 8.01059695577697, 8.23682433500797, 8.463618046358354, 8.69096564047162, 8.918855232014222, 9.147275461577939, 9.376215460964456, 9.605664821483357, 9.835613564941916, 10.066052117045697, 10.296971282963414, 10.528362224839382, 10.760216441062363, 10.992525747121814, 11.225282257901824, 11.458478371279542, 11.692106752909668, 11.926160322089133, 12.160632238607366, 12.39551589049734, 12.630804882611137, 12.866493025951588, 13.102574327698035, 13.339042981870506, 13.575893360581757, 13.813120005831385, 14.050717621800493, 14.28868106760914, 14.527005350502149, 14.765685619431967, 15.004717159009862, 15.244095383799392, 15.483815832928007, 15.723874164994964, 15.964266153255268, 16.204987681061134, 16.446034737543904, 16.68740341352069, 16.92908989761122, 17.171090472551548, 17.413401511692207, 17.65601947566939, 17.898940909238494, 18.1421624382603, 18.385680766830532, 18.62949267454444, 18.873595013888462, 19.11798470775164, 19.362658747049963, 19.607614188457312, 19.852848152237, 20.098357820168403, 20.344140433563517, 20.590193291368564, 20.8365137483461, 21.083099213333465, 21.32994714757347, 21.5770550631137, 21.824420521270866, 22.072041131156947, 22.319914548264016, 22.568038473104835, 22.816410649906537], [0.0, 0.1516351047505385, 0.32503696252107633, 0.507730363227404, 0.6967319815469868, 0.890567332385593, 1.088343858862089, 1.2894591837420246, 1.4934776966447736, 1.7000688736762717, 1.908972866905234, 2.119979733942382, 2.3329161320854643, 2.547636387099473, 2.764016268316824, 2.981948513139346, 3.2013395243073934, 3.4221068778834343, 3.644177406580388, 3.867485700783972, 4.091972918901714, 4.317585830835949, 4.544276039908392, 4.771999343302582, 5.000715201384029, 5.230386293577409, 5.4609781437701095, 5.6924588020914175, 5.924798572801134, 6.1579697801922215, 6.391946566064616, 6.626704713598491, 6.86222149344245, 7.098475528605971, 7.335446675356785, 7.573115917810984, 7.811465274294383, 8.050477713869306, 8.290137081677681, 8.5304280319612, 8.771335967792066, 9.012846986690677, 9.254947831425367, 9.497625845388518, 9.740868932026665, 9.984665517872308, 10.229004518784652, 10.473875309056847, 10.719267693090476, 10.965171879374745, 11.211578456539659, 11.458478371279542, 11.705862907967019, 11.953723669797933, 12.202052561325436, 12.450841772257101, 12.70008376240232, 12.94977124766924, 13.199897187020948, 13.450454770309667, 13.701437406916085, 13.952838715127884, 14.20465251219806, 14.456872805029297, 14.709493781435576, 14.962509801936815, 15.215915392046332, 15.469705235014457, 15.723874164994966, 15.978417160603755, 16.233329338841994, 16.48860594935806, 16.744242369025013, 17.000234096812008, 17.256576748929938, 17.513266054233142, 17.77029784986042, 18.02766807709987, 18.285372777463426, 18.543408088957715, 18.801770242539263, 19.06045555874253, 19.31946044447053, 19.578781389938115, 19.838414965759046, 20.098357820168403, 20.35860667637248, 20.619158330019022, 20.880009646780845, 21.14115756004673, 21.40259906871347, 21.664331235073725, 21.92635118279443, 22.18865609498095, 22.451243212322492, 22.714109831314484, 22.977253302554004, 23.240671029104465, 23.504360464926126, 23.76831911336908, 24.03254452572564, 24.29703429983923], [0.0, 0.16092701697250666, 0.34495461239252057, 0.5388431189134866, 0.7394263986835935, 0.9451396129527675, 1.1550355106435262, 1.368474801984601, 1.5849951832157132, 1.8042458765641476, 2.0259511111091992, 2.2498880795893292, 2.4758728171895754, 2.703750723033523, 2.933389953833408, 3.164676674142057, 3.397511551236903, 3.6318071103975247, 3.867485700783972, 4.1044779046045985, 4.3427212745655135, 4.582159318729415, 4.822740674761174, 5.064418431179393, 5.307149564157516, 5.550894466185996, 5.7956165485212905, 6.041281903465083, 6.287859015578419, 6.535318513239313, 6.783632953706145, 7.032776636198203, 7.282725438552457, 7.533456673836865, 7.78494896394937, 8.037182127748691, 8.290137081677681, 8.543795751175036, 8.798140991443562, 9.05315651636592, 9.308826834542211, 9.565137191575195, 9.822073517855136, 10.079622381201462, 10.337770943806804, 10.59650692300348, 10.855818555435523, 11.115694564272882, 11.376124129150162, 11.637096858551324, 11.898602764395427, 12.160632238607366, 12.42317603148261, 12.686225231676737, 12.94977124766924, 13.213805790567754, 13.47832085813306, 13.743308719917943, 14.008761903424077, 14.274673181190717, 14.541035558737875, 14.807842263293976, 15.075086733244985, 15.342762608247929, 15.610863719957022, 15.879384083315523, 16.148317888370567, 16.417659492572124, 16.68740341352069, 16.957544322131255, 17.228077036184057, 17.498996514234914, 17.77029784986042, 18.041976266215077, 18.31402711087948, 18.58644585098025, 18.859228068563922, 19.132369456208426, 19.40586581285702, 19.6797130398607, 19.953907137216135, 20.22844419998711, 20.503320414898447, 20.778532057092004, 21.05407548703526, 21.329947147573467, 21.606143561117214, 21.8826613269576, 22.159497118701804, 22.436647681822475, 22.714109831314484, 22.99188044945334, 23.269956483649743, 23.548334944395073, 23.8270129032932, 24.10598749117391, 24.385255896283883, 24.664815362551174, 24.94466318791954, 25.224796722749105, 25.505213368279996, 25.785910575156038], [0.0, 0.1702679845041569, 0.3649774146221923, 0.5701201299034059, 0.7823462148343429, 1.0, 1.2220792513764291, 1.4479075717811323, 1.6769958231503326, 1.9089728669052337, 2.1435469250725863, 2.380482257600354, 2.6195842214829534, 2.860689242075647, 3.1036578232807615, 3.3483695221017133, 3.5947192400734664, 3.84261442502783, 4.091972918901714, 4.3427212745655135, 4.5947934199881395, 4.848129584172242, 5.102675423469088, 5.358381303432346, 5.61520170292845, 5.873094715440095, 6.132021628439481, 6.391946566064616, 6.652836183570954, 6.9146594044682255, 7.177387193107894, 7.440992356914003, 7.705449373558744, 7.970734239252907, 8.23682433500797, 8.503698308273469, 8.771335967792064, 9.039718189869166, 9.308826834542211, 9.578644670370348, 9.84915530675933, 10.120343132896709, 10.392193262505849, 10.66469148373869, 10.937824213620623, 11.211578456539659, 11.485941766338845, 11.760902211627414, 12.03644834397463, 12.312569168691564, 12.589254117941673, 12.866493025951586, 13.144276106120044, 13.422593929845917, 13.701437406916085, 13.980797767311548, 14.26066654430516, 14.541035558737873, 14.821896904372107, 15.103242934231009, 15.385066247841786, 15.667359679309074, 15.95011628615163, 16.233329338841994, 16.516992310994333, 16.801098870150817, 17.08564286912135, 17.370618337835534, 17.65601947566939, 17.94184064421252, 18.22807636044455, 18.514721290291966, 18.80177024253926, 19.089218163070164, 19.37706012941678, 19.66529134559625, 19.953907137216135, 20.242902946831144, 20.53227432953528, 20.822016948774504, 21.11212657236631, 21.402599068713464, 21.693430403200207, 21.984616634759963, 22.27615391260446, 22.56803847310483, 22.86026663681587, 23.15283480563539, 23.445739460090966, 23.738977156747026, 24.032544525725637, 24.326438268334794, 24.62065515479842, 24.915192022082643, 25.210045771813324, 25.505213368279996, 25.800691836521843, 26.09647826049142, 26.39256978129233, 26.68896359548702, 26.98565695347127, 27.282647157912177], [0.0, 0.1796557924282295, 0.38510062143101015, 0.6015539798357156, 0.8254812529119842, 1.0551354851084374, 1.2894591837420246, 1.5277386581434649, 1.7694578013845497, 2.014225011980898, 2.261732424639163, 2.5117313016651783, 2.7640162683168246, 3.0184147311819762, 3.2747795029779434, 3.5329835000250984, 3.792915829203551, 4.054478835436419, 4.317585830835949, 4.582159318729415, 4.848129584172242, 5.115433560664147, 5.384013908292958, 5.65381825599307, 5.924798572801134, 6.196910641663685, 6.4701136156189225, 6.7443696407718, 7.019643533899104, 7.2959025050932, 7.573115917810984, 7.851255080200632, 8.130293062748411, 8.410204538204548, 8.690965640471617, 8.972553839715927, 9.254947831425365, 9.53812743751117, 9.822073517855136, 10.106767890952566, 10.392193262505847, 10.678333160992812, 10.965171879374743, 11.252694422226444, 11.540886457669409, 11.829734273572278, 12.1192247375532, 12.409345260378386, 12.70008376240232, 12.991428642738564, 13.283368750887782, 13.575893360581755, 13.868992145630216, 14.162655157581538, 14.456872805029295, 14.75163583441523, 15.046935312195089, 15.342762608247925, 15.63910938042191, 15.935967560120416, 16.23332933884199, 16.531187155596154, 16.829533685124588, 17.12836182686408, 17.427664694593336, 17.727435606711403, 18.02766807709987, 18.328355806525614, 18.62949267454444, 18.93107273186946, 19.233090193171304, 19.53553943027973, 19.838414965759046, 20.141711466831836, 20.445423739627536, 20.749546723734458, 21.05407548703526, 21.3590052208077, 21.664331235073725, 21.970048954181294, 22.27615391260446, 22.582641750948373, 22.88950821214678, 23.196749137840477, 23.504360464926126, 23.812338222265346, 24.12067852754494, 24.429377584279614, 24.738431678949116, 25.047837178262387, 25.357590526541646, 25.66768824321989, 25.978126920445785, 26.28890322079004, 26.600013875048163, 26.91145568013432, 27.223225497061776, 27.53532024900541, 27.84773691944217, 28.160472550365625, 28.47352424057079, 28.786889144005997], [0.0, 0.18908842694721617, 0.40531991614951757, 0.6331379257722151, 0.8688222599329771, 1.110534241054576, 1.357160853935867, 1.6079509363451339, 1.8623612837139485, 2.119979733942382, 2.3804822576003546, 2.6436070572880928, 2.9091379752831137, 3.176893356341469, 3.446718285270198, 3.7184790059974997, 3.9920588030792694, 4.267354894163647, 4.544276039908392, 4.822740674761174, 5.102675423469088, 5.384013908292958, 5.666695778750081, 5.95066591408827, 6.235873761530009, 6.522272782452907, 6.809819985269284, 7.098475528605971, 7.38820238198239, 7.6789660338920065, 7.970734239252908, 8.263476799778394, 8.557165372049518, 8.85177329903645, 9.147275461577939, 9.443648146935558, 9.740868932026665, 10.0389165793336, 10.337770943806804, 10.637412889341194, 10.937824213620623, 11.238987580303336, 11.54088645766941, 11.843505062974945, 12.146828311861542, 12.450841772257103, 12.755531622278165, 13.060884611706733, 13.366888026668473, 13.673529657184858, 13.98079776731155, 14.28868106760914, 14.597168689721821, 14.906250162865192, 15.215915392046332, 15.52615463785884, 15.836958497712313, 16.148317888370567, 16.460224029686046, 16.77266842942912, 17.08564286912135, 17.39913939079057, 17.713150284573633, 18.027668077099875, 18.342685520594358, 18.65819558264583, 18.974191436589205, 19.290666452456882, 19.607614188457315, 19.925028382942696, 20.242902946831148, 20.561231956451387, 20.88000964678085, 21.199230405050354, 21.518888764690747, 21.838979399598852, 22.159497118701804, 22.480436860800562, 22.801793689674817, 23.12356278943281, 23.44573946009097, 23.76831911336908, 24.09129726868821, 24.414669549358962, 24.738431678949116, 25.062579477819945, 25.387108859821556, 25.71201582913827, 26.037296477275444, 26.362946980179974, 26.688963595487024, 27.015342659886173, 27.3420805866005, 27.669173862972574, 27.99661904815183, 28.32441277087785, 28.652551727354776, 28.98103267921208, 29.309852451547414, 29.639007931047384, 29.968496064182357, 30.298313855471783], [0.0, 0.198564048771215, 0.42563135617350095, 0.6648658090906546, 0.9123607847401829, 1.1661854655146122, 1.42517106066217, 1.6885287656197117, 1.955688154686631, 2.226216411446644, 2.4997732686681897, 2.776083809728944, 3.054921044784831, 3.336094215462632, 3.619440643440743, 3.9048198698471266, 4.192109330379409, 4.481201092044245, 4.771999343302582, 5.064418431179393, 5.358381303432346, 5.65381825599307, 5.95066591408827, 6.248866394748045, 6.548366611888057, 6.849117694736917, 7.151074497307367, 7.454195181690592, 7.758440861730149, 8.06377529647477, 8.370164624973146, 8.677577135638428, 8.98598306470288, 9.29535441929641, 9.605664821483357, 9.916889370229717, 10.22900451878465, 10.541987965373481, 10.855818555435523, 11.170476193914904, 11.485941766338843, 11.802197067604757, 12.1192247375532, 12.437008202533525, 12.755531622278163, 13.0747798414933, 13.394738345651593, 13.715393220538548, 14.036731115160638, 14.358739207671434, 14.681405174013559, 15.004717159009864, 15.328663749668198, 15.653233950490968, 15.978417160603756, 16.30420315253787, 16.63058205251917, 16.957544322131255, 17.285080741234776, 17.613182392036467, 17.941840644212522, 18.27104714099992, 18.600793786177935, 18.931072731869463, 19.261876367098196, 19.593197307043855, 19.925028382942696, 20.25736263258539, 20.590193291368568, 20.92351378385997, 21.25731771584093, 21.591598866792438, 21.92635118279443, 22.261568769809973, 22.59724588732854, 22.933376942344637, 23.26995648364974, 23.606979196417395, 23.944439897062825, 24.282333528359743, 24.620655154798424, 24.95939995817022, 25.298563233364877, 25.638140384367833, 25.978126920445785, 26.318518452509437, 26.659310689643274, 27.000499435792825, 27.342080586600495, 27.684050126381777, 28.026404125234, 28.36913873627049, 28.712250192973336, 29.0557348066584, 29.399588964046803, 29.74380912493712, 30.088391819973282, 30.433333648503147, 30.778631276523285, 31.12428143470557, 31.470280916501526, 31.816626576320726], [0.0, 0.20808097103621354, 0.4460313256307934, 0.6967319815469869, 0.9560890765419369, 1.2220792513764294, 1.4934776966447738, 1.7694578013845499, 2.0494218001169573, 2.332916132085464, 2.6195842214829534, 2.9091379752831132, 3.2013395243073943, 3.495988967376412, 3.7929158292035514, 4.091972918901715, 4.39303179781743, 4.695979359866279, 5.000715201384029, 5.307149564157516, 5.61520170292845, 5.924798572801134, 6.235873761530009, 6.548366611888057, 6.862221493442451, 7.1773871931078945, 7.493816401107395, 7.811465274294385, 8.130293062748413, 8.450261788535515, 8.771335967792067, 9.093482369035197, 9.416669801957648, 9.740868932026666, 10.066052117045697, 10.39219326250585, 10.719267693090474, 11.047252038129203, 11.376124129150162, 11.70586290796702, 12.03644834397463, 12.367861359522998, 12.70008376240232, 13.03309818460796, 13.366888026668473, 13.701437406916089, 14.036731115160638, 14.372754570297023, 14.70949378143558, 15.046935312195092, 15.385066247841792, 15.723874164994966, 16.063347103652273, 16.403473541315904, 16.744242369025017, 17.08564286912135, 17.427664694593343, 17.77029784986042, 18.11353267287368, 18.457359818421377, 18.801770242539263, 19.146755187935288, 19.492306170347177, 19.838414965759053, 20.185073598410195, 20.532274329535284, 20.88000964678085, 21.228272254247727, 21.577055063113704, 21.92635118279443, 22.276153912604467, 22.626456733883245, 22.977253302554008, 23.328537442086127, 23.680303136833718, 24.03254452572564, 24.385255896283883, 24.73843167894912, 25.092066441693955, 25.44615488490567, 25.800691836521846, 26.155672247403217, 26.511091186929583, 26.866943838805252, 27.22322549706178, 27.579931562246408, 27.937057537785503, 28.294599026513037, 28.652551727354776, 29.010911432159563, 29.369674022669496, 29.728835467621508, 30.088391819973282, 30.448339214246744, 30.808673863983145, 31.169392059303718, 31.530490164570566, 31.89196461614262, 32.25381192022191, 32.61602865078556, 32.978611447599306, 33.341557014308584], [0.0, 0.217637640824031, 0.46651649576840365, 0.7287312433973052, 1.0, 1.2782064782044662, 1.562069615988616, 1.8507248380919414, 2.1435469250725863, 2.4400614851948217, 2.7398955659630433, 3.0427478429155657, 3.3483695221017142, 3.6565515213509165, 3.9671155358474417, 4.279907614572803, 4.59479341998814, 4.911654651312503, 5.230386293577409, 5.550894466185996, 5.873094715440095, 6.196910641663685, 6.522272782452907, 6.849117694736917, 7.1773871931078945, 7.5070277123839455, 7.837989769961245, 8.170227509080584, 8.50369830827347, 8.838362445368722, 9.17418280681228, 9.511124634877397, 9.849155306759332, 10.188244140659213, 10.528362224839382, 10.869482266331508, 11.211578456539659, 11.55462635143352, 11.898602764395429, 12.243485670086063, 12.589254117941673, 12.935888154120656, 13.283368750887782, 13.631677742566794, 13.98079776731155, 14.33071221404662, 14.68140517401356, 15.032861396431393, 15.385066247841792, 15.738005674762135, 16.0916661693153, 16.446034737543904, 16.801098870150817, 17.156846515436992, 17.513266054233142, 17.87034627664416, 18.228076360444554, 18.58644585098025, 18.94544464244715, 19.305062960429904, 19.665291345596252, 20.02612063845231, 20.387541965073574, 20.74954672373446, 21.112126572366314, 21.475273416780514, 21.838979399598852, 22.203236889838678, 22.568038473104835, 22.933376942344637, 23.299245289125913, 23.665636695401343, 24.03254452572564, 24.399962319894644, 24.767883785978, 25.136302793719352, 25.505213368279996, 25.874609684303845, 26.244486060283258, 26.614836953206765, 26.98565695347127, 27.356940780042425, 27.72868327584823, 28.100879403391854, 28.47352424057079, 28.846612976690224, 29.22014090865947, 29.594103437361, 29.968496064182354, 30.343314387701888, 30.718554100519793, 31.09421098622657, 31.470280916501526, 31.84675984833427, 32.2236438213629, 32.600928955322644, 32.978611447599306, 33.35668757088215, 33.73515367091129, 34.114006164314674, 34.49324153653038, 34.87285633981001], [0.0, 0.22723262357526913, 0.48708379154094467, 0.7608587912066427, 1.0440869636102887, 1.3345587206955016, 1.6309365223054437, 1.9323176766815584, 2.238049400355208, 2.547636387099473, 2.8606892420756473, 3.1768933563414685, 3.4959889673764124, 3.81775777521186, 4.142013614114159, 4.4685957458318715, 4.797363910291952, 5.128194591191222, 5.4609781437701095, 5.7956165485212905, 6.132021628439481, 6.4701136156189225, 6.809819985269284, 7.151074497307367, 7.493816401107395, 7.837989769961245, 8.183542939727342, 8.5304280319612, 8.878600546143197, 9.228019008872234, 9.578644670370348, 9.93044124054816, 10.283374658360513, 10.637412889341192, 10.992525747121814, 11.348684735469943, 11.705862907967019, 12.064034742919652, 12.42317603148261, 12.783263777286239, 13.144276106120046, 13.506192184438138, 13.868992145630218, 14.23265702315052, 14.597168689721821, 14.962509801936815, 15.3286637496682, 15.695614609774378, 16.063347103652273, 16.43184655824389, 16.801098870150817, 17.171090472551544, 17.54180830465202, 17.913239783430374, 18.285372777463426, 18.658195582645828, 19.031696899633037, 19.405865812857016, 19.78069177097946, 20.15616456866071, 20.532274329535277, 20.909011490295004, 21.286366785791007, 21.66433123507373, 22.042896128298036, 22.422053014427114, 22.80179368967481, 23.182110186631615, 23.562994764024204, 23.944439897062818, 24.3264382683348, 24.708982759205817, 25.092066441693948, 25.475682570784254, 25.859824577154274, 26.244486060283254, 26.629660781920006, 27.015342659886173, 27.401525762193696, 27.788204301456556, 28.175372629578693, 28.56302523270098, 28.951156726391773, 29.339761851066303, 29.728835467621504, 30.118372553273648, 30.508368197587046, 30.898817598683053, 31.289716059619042, 31.68105898492805, 32.07284187731009, 32.46506033446698, 32.857710046072896, 33.250786790873384, 33.64428643390623, 34.03820492383756, 34.432538290407464, 34.8272826419794, 35.222434163188254, 35.617989112681975, 36.01394382095229, 36.41029468825004], [0.0, 0.23686458984806724, 0.5077303632274038, 0.7931101735123914, 1.088343858862089, 1.3911281709115695, 1.7000688736762721, 2.0142250119808986, 2.3329161320854643, 2.6556259326576925, 2.981948513139346, 3.3115559289030245, 3.644177406580389, 3.9795853928750993, 4.31758583083595, 4.658011168817403, 5.000715201384029, 5.345569176607378, 5.6924588020914175, 6.041281903465083, 6.391946566064616, 6.7443696407718, 7.098475528605971, 7.454195181690592, 7.811465274294385, 8.170227509080584, 8.5304280319612, 8.892016935013958, 9.254947831425367, 9.619177489814366, 9.984665517872308, 10.351374087240746, 10.719267693090474, 11.088312943074117, 11.458478371279543, 11.82973427357228, 12.202052561325436, 12.575406631028738, 12.949771247669242, 13.325122440104156, 13.701437406916087, 14.078694431464061, 14.456872805029297, 14.835952757109597, 15.215915392046332, 15.596742631277573, 15.97841716060376, 16.360922381931076, 16.744242369025017, 17.12836182686408, 17.513266054233146, 17.898940909238497, 18.285372777463426, 18.672548542515287, 19.060455558742532, 19.44908162592467, 19.83841496575905, 20.22844419998711, 20.619158330019026, 21.01054671792987, 21.402599068713467, 21.795305413690908, 22.188656094980953, 22.582641750948383, 22.977253302554004, 23.372481940537345, 23.768319113369085, 24.164756515916114, 24.561786078767007, 24.95939995817022, 25.35759052654165, 25.756350363501358, 26.155672247403217, 26.55554914732371, 26.955974215479067, 27.35694078004243, 27.758442338334792, 28.16047255036563, 28.563025232700987, 28.966094352638375, 29.369674022669493, 29.773758495213023, 30.17834215760134, 30.583419527305693, 30.988985247386047, 31.395034082152254, 31.80156091302444, 32.20856073458128, 32.61602865078555, 33.02395987137702, 33.43234970842356, 33.84119357302179, 34.250486972139235, 34.660225505590354, 35.070404863139615, 35.48102082172466, 35.892069242793696, 36.303546069750965, 36.71544732550517, 37.127769110115324, 37.540507598529565, 37.9536590384121], [0.0, 0.24653230399548132, 0.528453562160574, 0.8254812529119844, 1.1327650082129537, 1.4479075717811327, 1.7694578013845499, 2.0964363364211356, 2.4281349501847, 2.764016268316824, 3.103657823280762, 3.4467182852701974, 3.792915829203552, 4.142013614114159, 4.493809662545964, 4.848129584172244, 5.204821206129691, 5.563750521433199, 5.924798572801134, 6.287859015578419, 6.652836183570954, 7.019643533899104, 7.38820238198239, 7.758440861730149, 8.130293062748413, 8.50369830827347, 8.878600546143197, 9.254947831425367, 9.632691884011876, 10.011787708017161, 10.39219326250585, 10.773869175141321, 11.15677849195189, 11.54088645766941, 11.926160322089133, 12.312569168691564, 12.700083762402318, 13.0886764138792, 13.47832085813306, 13.86899214563022, 14.26066654430516, 14.653321451144334, 15.046935312195089, 15.441487550015012, 15.836958497712311, 16.233329338841994, 16.63058205251917, 17.0286993631928, 17.427664694593343, 17.82746212742744, 18.228076360444554, 18.62949267454444, 19.031696899633033, 19.43467538396737, 19.83841496575905, 20.242902946831144, 20.64812706814532, 21.05407548703526, 21.460736755999704, 21.86809980292297, 22.276153912604464, 22.68488870949003, 23.094294141508502, 23.50436046492613, 23.915078230139443, 24.3264382683348, 24.73843167894912, 25.151049817872263, 25.56428428633685, 25.978126920445785, 26.392569781292337, 26.80760514563108, 27.223225497061776, 27.639423517691217, 28.05619208024085, 28.47352424057079, 28.891413230592825, 29.309852451547417, 29.72883546762151, 30.14835599988568, 30.568407920530834, 30.988985247386044, 31.410082138700613, 31.831692888174395, 32.2538119202219, 32.676433785456396, 33.099553156381305, 33.523164823277234, 33.947263690273395, 34.37184477159336, 34.79690318796536, 35.222434163188254, 35.64843302084481, 36.074895181154325, 36.501816157957435, 36.92919155582597, 37.35701706729163, 37.78528847018725, 38.21400162509508, 38.64315247289666, 39.07273703241923, 39.50275139817404], [0.0, 0.25623461442463663, 0.5492509198470896, 0.8579681734469375, 1.1773451203315188, 1.504890159890164, 1.8390950400023265, 2.1789418572038874, 2.523694512435841, 2.872794482903002, 3.225802674804554, 3.5823643252558957, 3.9421865179132327, 4.305023090903292, 4.670664117921344, 5.038928345487, 5.409657611954408, 5.782712636476382, 6.1579697801922215, 6.535318513239313, 6.9146594044682255, 7.2959025050932, 7.6789660338920065, 8.06377529647477, 8.450261788535515, 8.838362445368722, 9.228019008872234, 9.619177489814366, 10.011787708017161, 10.405802896776214, 10.801179360629755, 11.197876177737802, 11.595854939800383, 11.995079523751311, 12.395515890497338, 12.797131906795379, 13.199897187020946, 13.603782952114233, 14.008761903424078, 14.414808109524701, 14.821896904372107, 15.230004795408252, 15.639109380421912, 16.049189272142787, 16.460224029686046, 16.872194096083085, 17.28508074123478, 17.698866009708563, 18.11353267287368, 18.529064184930952, 18.94544464244715, 19.362658747049963, 19.780691770979455, 20.199529525226566, 20.619158330019022, 21.039564987441523, 21.460736755999704, 21.8826613269576, 22.30532680229607, 22.728721674154894, 23.152834805635393, 23.577655412852142, 24.003173048133434, 24.42937758427962, 24.856259199796874, 25.283808365031717, 25.71201582913827, 26.14087260781633, 26.570369971763956, 27.000499435792825, 27.431252748559523, 27.862621882869302, 28.294599026513037, 28.727176573600886, 29.160347116359343, 29.594103437361, 30.02843850215867, 30.463345452297794, 30.89881759868306, 31.33484841527697, 31.77143153310972, 32.20856073458128, 32.646229948038105, 33.08443324260788, 33.52316482327723, 33.962419026198106, 34.40219031420962, 34.8424732725632, 35.28326260483942, 35.72455312904598, 36.16633977388674, 36.608617575192554, 37.05138167250519, 37.49462730580609, 37.938349812382505, 38.382544623823634, 38.8272072631402, 39.272333342001126, 39.71791855808133, 40.16395869251523, 40.6104496074505, 41.057387243697384], [0.0, 0.265970445169564, 0.5701201299034059, 0.8905673323855932, 1.2220792513764294, 1.562069615988616, 1.9089728669052342, 2.2617324246391632, 2.6195842214829534, 2.9819485131393457, 3.348369522101714, 3.7184790059974993, 4.091972918901715, 4.4685957458318715, 4.848129584172243, 5.23038629357741, 5.61520170292845, 6.0024312392955395, 6.391946566064616, 6.783632953706145, 7.177387193107894, 7.573115917810984, 7.970734239252908, 8.370164624973146, 8.771335967792067, 9.17418280681228, 9.578644670370348, 9.984665517872308, 10.39219326250585, 10.801179360629755, 11.211578456539659, 11.623348073538885, 12.03644834397463, 12.450841772257101, 12.866493025951588, 13.283368750887783, 13.701437406916087, 14.120669121494236, 14.541035558737876, 14.962509801936815, 15.385066247841788, 15.80868051127699, 16.233329338841994, 16.65899053064076, 17.085642869121354, 17.513266054233146, 17.941840644212526, 18.3713480013965, 18.801770242539266, 19.233090193171307, 19.665291345596255, 20.098357820168403, 20.53227432953528, 20.96702614556554, 21.40259906871347, 21.838979399598852, 22.276153912604467, 22.71410983131448, 23.152834805635397, 23.59231689045701, 24.03254452572564, 24.473506517813856, 24.915192022082646, 25.35759052654165, 25.800691836521843, 26.24448606028326, 26.688963595487024, 27.134115116467566, 27.579931562246408, 28.026404125234, 28.473524240570793, 28.921283576062628, 29.369674022669493, 29.81868768550993, 30.268316875346397, 30.71855410051979, 31.169392059303714, 31.62082363265135, 32.0728418773101, 32.525440019280644, 32.978611447599306, 33.43234970842356, 33.88664849940272, 34.34150166431644, 34.796903187965356, 35.25284719129918, 35.70932792676834, 36.16633977388674, 36.62387723499344, 37.081934931202355, 37.540507598529565, 37.999590084188505, 38.45917734304411, 38.91926443421727, 39.37984651783187, 39.84091885189685, 40.302476789316295, 40.7645157750211, 41.22703134321607, 41.690019114736565, 42.1534747945094, 42.617394169112785], [0.0, 0.2757387885625234, 0.591059032346437, 0.923275355684002, 1.2669627713225835, 1.61944002194841, 1.9790840496717408, 2.344799469824506, 2.7157941526499667, 3.0914670614799307, 3.471345679386996, 3.855048239496118, 4.242259529134063, 4.6327146489745665, 5.026187693454151, 5.422483612363786, 5.821432205042947, 6.222883588806346, 6.626704713598491, 7.032776636198203, 7.440992356914003, 7.851255080200632, 8.263476799778394, 8.677577135638428, 9.093482369035197, 9.511124634877397, 9.93044124054816, 10.351374087240746, 10.773869175141321, 11.197876177737802, 11.623348073538885, 12.050240825798765, 12.478513102638335, 12.90812603136067, 13.339042981870504, 13.771229374993045, 14.20465251219806, 14.639281423809164, 15.075086733244985, 15.512040535220578, 15.95011628615163, 16.389288705263688, 16.829533685124588, 17.270828210498806, 17.71315028457363, 18.156478861734904, 18.600793786177938, 19.046075735731, 19.492306170347177, 19.93946728478718, 20.387541965073574, 20.836513748346103, 21.286366785791007, 21.737085808354266, 22.188656094980953, 22.641063443151296, 23.094294141508506, 23.548334944395073, 24.003173048133437, 24.458796068903233, 24.915192022082646, 25.372349302933923, 25.830256668525085, 26.288903220790047, 26.748278390638383, 27.208371923034445, 27.669173862972574, 28.13067454228183, 28.592864567199587, 29.0557348066584, 29.51927638123562, 29.983480652719116, 30.44833921424674, 30.913843880980334, 31.37998668127837, 31.84675984833427, 32.31415581224983, 32.78216719251576, 33.25078679087339, 33.72000758453355, 34.18982271973051, 34.660225505590354, 35.13120940829485, 35.60276804552306, 36.074895181154325, 36.54758472021745, 37.0208307040716, 37.49462730580609, 37.96896882584642, 38.443849687755204, 38.91926443421727, 39.39520772319874, 39.87167432427099, 40.34865911509036, 40.82615707802579, 41.30416329692624, 41.782672954021095, 42.26168132694643, 42.741183785890996, 43.22117579085582, 43.70165288902178, 44.182610712220026], [0.0, 0.28553869882969674, 0.6120655998656237, 0.9560890765419369, 1.3119913345346659, 1.6769958231503328, 2.0494218001169573, 2.4281349501847, 2.8123149908636624, 3.2013395243073934, 3.594719240073467, 3.992058803079269, 4.39303179781743, 4.797363910291952, 5.204821206129691, 5.6152017029284504, 6.028329151001342, 6.444048340748889, 6.86222149344245, 7.282725438552457, 7.705449373558744, 8.130293062748411, 8.557165372049518, 8.98598306470288, 9.416669801957648, 9.849155306759332, 10.283374658360513, 10.719267693090474, 11.15677849195189, 11.595854939800383, 12.03644834397463, 12.478513102638335, 12.922006414954364, 13.366888026668471, 13.813120005831385, 14.26066654430516, 14.709493781435576, 15.15956964686668, 15.610863719957024, 16.063347103652273, 16.516992310994333, 16.971773162715934, 17.42766469459334, 17.88464307341671, 18.342685520594358, 18.801770242539263, 19.2618763670982, 19.722983885378685, 20.185073598410195, 20.64812706814532, 21.112126572366314, 21.5770550631137, 22.042896128298036, 22.509633956194616, 22.977253302554004, 23.445739460090966, 23.915078230139446, 24.38525589628388, 24.856259199796874, 25.328075316730178, 25.800691836521843, 26.27409674199526, 26.748278390638383, 27.22322549706178, 27.69892711654366, 28.1753726295787, 28.652551727354776, 29.13045439808877, 29.609070914158497, 30.088391819973275, 30.568407920530838, 31.049110270612168, 31.530490164570562, 32.01253912667414, 32.49524890196479, 32.9786114475993, 33.46261892464107, 33.947263690273395, 34.43253829040747, 34.91843545266028, 35.404948079679464, 35.89206924279369, 36.37979217596919, 36.86811027005378, 37.35701706729163, 37.846506256092816, 38.33657166604312, 38.8272072631402, 39.31840714524349, 39.81016553772593, 40.302476789316295, 40.79533536812187, 41.28873585782167, 41.78267295402109, 42.27714146075965, 42.77213628716359, 43.26765244423602, 43.76368504177758, 44.26022928543094, 44.757280473843025, 45.25483399593906, 45.75288532830302], [0.0, 0.2953692864693294, 0.633137925772215, 0.9890055165788328, 1.357160853935867, 1.7347317954663304, 2.119979733942382, 2.5117313016651783, 2.9091379752831132, 3.311555928903024, 3.7184790059974993, 4.129498260802806, 4.544276039908393, 4.962528585177103, 5.384013908292959, 5.808523072960244, 6.235873761530008, 6.665905420813349, 7.098475528605971, 7.533456673836865, 7.970734239252907, 8.410204538204548, 8.85177329903645, 9.29535441929641, 9.740868932026666, 10.188244140659213, 10.637412889341192, 11.088312943074117, 11.54088645766941, 11.995079523751311, 12.450841772257101, 12.90812603136067, 13.366888026668471, 13.82708611804415, 14.288681067609138, 14.751635834415232, 15.21591539204633, 15.681486566021386, 16.148317888370567, 16.61637946716555, 17.08564286912135, 17.556081013665256, 18.02766807709987, 18.5003794056805, 18.974191436589205, 19.44908162592467, 19.9250283829427, 20.402011009880358, 20.88000964678085, 21.3590052208077, 21.838979399598852, 22.319914548264016, 22.80179368967481, 23.284600467737075, 23.768319113369085, 24.252934412940025, 24.73843167894912, 25.224796722749105, 25.71201582913827, 26.200075732662725, 26.68896359548702, 27.178666986704624, 27.669173862972574, 28.160472550365633, 28.652551727354773, 29.145400408824063, 29.639007931047384, 30.1333639375538, 30.628458365816456, 31.12428143470557, 31.62082363265135, 32.118075706466875, 32.61602865078555, 33.11467369807119, 33.61400230916222, 34.114006164314674, 34.614677154711366, 35.11600737440706, 35.61798911268198, 36.12061484677796, 36.62387723499344, 37.127769110115324, 37.63228347316738, 38.13741348745611, 38.64315247289666, 39.149493900602366, 39.65643138772264, 40.16395869251523, 40.672069709639395, 41.18075846565797, 41.690019114736565, 42.199845934529264, 42.71023332224083, 43.22117579085582, 43.7326679655261, 44.24470458010821, 44.75728047384303, 45.27039058817034, 45.784029963671664, 46.29819373713473, 46.81287713873368, 47.32807548931937], [0.0, 0.3052297132958416, 0.6542742133760884, 1.0220218692396403, 1.4024674782365998, 1.7926430161531028, 2.190751835165568, 2.5955813965886447, 3.006254850488368, 3.422106877883434, 3.8426144250278305, 4.267354894163646, 4.695979359866279, 5.128194591191222, 5.563750521433199, 6.0024312392955395, 6.444048340748889, 6.888435912795311, 7.335446675356785, 7.78494896394937, 8.23682433500797, 8.690965640471617, 9.147275461577939, 9.605664821483357, 10.066052117045697, 10.528362224839382, 10.992525747121814, 11.458478371279543, 11.926160322089133, 12.395515890497338, 12.866493025951588, 13.339042981870504, 13.813120005831385, 14.288681067609138, 14.765685619431965, 15.24409538379939, 15.723874164994962, 16.20498768106113, 16.68740341352069, 17.171090472551548, 17.656019475669385, 18.1421624382603, 18.62949267454444, 19.117984707751635, 19.607614188457315, 20.098357820168403, 20.590193291368568, 21.083099213333465, 21.5770550631137, 22.072041131156947, 22.56803847310483, 23.065028865354716, 23.5629947640242, 24.061919266997315, 24.561786078767, 25.06257947781994, 25.56428428633685, 26.06688584200538, 26.570369971763956, 27.074722967312916, 27.579931562246404, 28.085982910672133, 28.592864567199584, 29.10056446818837, 29.60907091415849, 30.11837255327365, 30.628458365816453, 31.13931764958189, 31.6509400061219, 32.163315327779465, 32.676433785456396, 33.19028581706306, 33.70486211660324, 34.2201536238507, 34.736151514577735, 35.252847191299175, 35.770232274498056, 36.28829859430192, 36.80703818258105, 37.32644326544216, 37.846506256092816, 38.3672197480541, 38.88857650870025, 39.41056947310578, 39.933191738182, 40.456436557085915, 40.98029733388575, 41.50476761846877, 42.02984110167729, 42.5555116106606, 43.08177310443055, 43.60861966960995, 44.13604551636328, 44.66404497449996, 45.192612489741215, 45.721742620141896, 46.25143003265926, 46.78166949986122, 47.312455896767126, 47.843784197814216, 48.375649473943696, 48.908046889800566], [0.0, 0.315119188053697, 0.6754727665838722, 1.0551354851084376, 1.4479075717811325, 1.8507248380919417, 2.2617324246391632, 2.6796785063567325, 3.103657823280762, 3.5329835000250984, 3.9671155358474417, 4.405617640778155, 4.848129584172244, 5.294348634371811, 5.744016622484075, 6.196910641663686, 6.652836183570954, 7.111621959609391, 7.573115917810984, 8.037182127748691, 8.503698308273469, 8.972553839715927, 9.443648146935558, 9.916889370229717, 10.39219326250585, 10.869482266331508, 11.348684735469943, 11.82973427357228, 12.312569168691564, 12.797131906795379, 13.283368750887783, 13.771229374993045, 14.26066654430516, 14.751635834415232, 15.24409538379939, 15.738005674762135, 16.233329338841994, 16.73003098334239, 17.228077036184054, 17.727435606711403, 18.22807636044455, 18.729970406065156, 19.233090193171304, 19.737409419542796, 20.242902946831144, 20.74954672373446, 21.25731771584093, 21.766193841429303, 22.276153912604467, 22.78717758122253, 23.299245289125913, 23.812338222265346, 24.326438268334797, 24.841527977587962, 25.357590526541646, 25.874609684303845, 26.392569781292337, 26.911455680134317, 27.43125274855952, 27.951946834117944, 28.473524240570786, 28.995971705817503, 29.519276381235617, 30.043425812321516, 30.568407920530834, 31.094210986226575, 31.620823632651348, 32.14823481084758, 32.676433785456396, 33.20541012133164, 33.735153670911295, 34.26565456229302, 34.79690318796536, 35.328890194149785, 35.861606470712694, 36.395043141609484, 36.929191555825966, 37.464043278784956, 37.99959008418851, 38.53582394626836, 39.07273703241922, 39.61032169619147, 40.148570470621515, 40.687476061879536, 41.22703134321606, 41.76722934918965, 42.308063270159664, 42.84952644702903, 43.391612366222695, 43.934314654888944, 44.47762707631096, 45.02154352551752, 45.56605802508184, 46.11116472109854, 46.65685787932965, 47.20313188151042, 47.74998122180697, 48.29740050341786, 48.845384435312525, 49.39392782909944, 49.9430255960178, 50.49267274404659], [0.0, 0.32503696252107633, 0.6967319815469867, 1.0883438588620893, 1.4934776966447736, 1.908972866905234, 2.3329161320854643, 2.764016268316824, 3.2013395243073934, 3.6441774065803876, 4.091972918901714, 4.544276039908392, 5.000715201384029, 5.4609781437701095, 5.924798572801134, 6.391946566064616, 6.8622214934424495, 7.335446675356785, 7.811465274294383, 8.290137081677681, 8.771335967792064, 9.254947831425365, 9.740868932026665, 10.22900451878465, 10.719267693090474, 11.211578456539659, 11.705862907967019, 12.202052561325436, 12.700083762402318, 13.199897187020946, 13.701437406916087, 14.20465251219806, 14.709493781435576, 15.21591539204633, 15.723874164994962, 16.233329338841994, 16.744242369025013, 17.256576748929934, 17.77029784986042, 18.285372777463426, 18.80177024253926, 19.31946044447053, 19.838414965759046, 20.35860667637248, 20.880009646780845, 21.40259906871347, 21.926351182794434, 22.451243212322492, 22.977253302554008, 23.50436046492613, 24.03254452572564, 24.561786078767, 25.092066441693948, 25.62336761556275, 26.155672247403217, 26.68896359548702, 27.22322549706178, 27.758442338334792, 28.294599026513037, 28.831680963725187, 29.36967402266949, 29.908564523846113, 30.44833921424674, 30.98898524738605, 31.53049016457056, 32.0728418773101, 32.61602865078555, 33.16003908829453, 33.70486211660324, 34.25048697213923, 34.79690318796536, 35.34410058148003, 35.89206924279369, 36.44079952373552, 36.99028202744786, 37.54050759852956, 38.09146731369229, 38.64315247289666, 39.19555459093771, 39.74866538945144, 40.302476789316295, 40.85698090342524, 41.41217002980627, 41.96803664507023, 42.52457339816679, 43.08177310443055, 43.639628739900466, 44.19813343589708, 44.757280473843025, 45.317063280313235, 45.87747542230216, 46.43851060269627, 47.00016265594067, 47.56242554388952, 48.125293351830656, 48.68876028467517, 49.25282066330357, 49.817468921060424, 50.38269960039007, 50.94850734960628, 51.51488691978922, 52.081833161803544], [0.0, 0.33498232803653694, 0.7180503392163752, 1.1216446176402188, 1.5391745966745887, 1.9673829405572056, 2.4042978711669076, 2.848588656225808, 3.299292973851653, 3.7556806523359376, 4.217177652671661, 4.68332018390204, 5.153725308698391, 5.628071213095151, 6.106083454849481, 6.587525076464595, 7.072189309013301, 7.559894066938789, 8.050477713869306, 8.543795751175036, 9.039718189869166, 9.53812743751117, 10.0389165793336, 10.541987965373481, 11.047252038129203, 11.55462635143352, 12.064034742919652, 12.575406631028738, 13.0886764138792, 13.603782952114233, 14.120669121494236, 14.639281423809164, 15.15956964686668, 15.681486566021386, 16.20498768106113, 16.73003098334239, 17.256576748929934, 17.784587354193263, 18.31402711087948, 18.844862118145823, 19.37706012941678, 19.910590432246252, 20.445423739627536, 20.981532091413214, 21.518888764690747, 22.05746819211481, 22.597245887328544, 23.138198376717284, 23.680303136833718, 24.2235385369144, 24.767883785978, 25.313318884055413, 25.85982457715427, 26.40738231560556, 26.955974215479063, 27.50558302278901, 28.05619208024085, 28.60778529629661, 29.16034711635934, 29.713862495897242, 30.26831687534639, 30.823696156646488, 31.37998668127837, 31.937175209684522, 32.495248901964786, 33.05419529974966, 33.61400230916222, 34.174658184787795, 34.736151514577735, 35.29847120561962, 35.861606470712694, 36.42554681569171, 36.990282027447854, 37.555802162599, 38.12209753676578, 38.68915871441332, 39.25697649922169, 39.825541924950784, 40.39484624676835, 40.96488093301196, 41.53563765735795, 42.10710829137241, 42.67928489742111, 43.25215972191692, 43.82572518888467, 44.399973893825134, 44.97489859786059, 45.550492222146175, 46.12674784253188, 46.703658684461296, 47.28121811809408, 47.85941965363985, 48.438256936892245, 49.017723744952384, 49.597813982131846, 50.17852167602565, 50.759840973746634, 51.341766138312806, 51.924291545180154, 52.50741167891347, 53.091121129988316, 53.67541459171795], [0.0, 0.3449546123925206, 0.7394263986835935, 1.1550355106435264, 1.5849951832157134, 2.0259511111091997, 2.4758728171895754, 2.9333899538334083, 3.397511551236903, 3.867485700783972, 4.342721274565514, 4.822740674761174, 5.307149564157517, 5.795616548521291, 6.287859015578419, 6.783632953706146, 7.282725438552458, 7.784948963949371, 8.290137081677681, 8.798140991443562, 9.308826834542211, 9.822073517855136, 10.337770943806804, 10.855818555435523, 11.376124129150162, 11.898602764395429, 12.42317603148261, 12.949771247669242, 13.47832085813306, 14.008761903424078, 14.541035558737876, 15.075086733244985, 15.610863719957024, 16.148317888370567, 16.68740341352069, 17.228077036184054, 17.77029784986042, 18.31402711087948, 18.859228068563926, 19.40586581285702, 19.953907137216135, 20.503320414898447, 21.05407548703526, 21.606143561117218, 22.159497118701807, 22.714109831314484, 23.269956483649747, 23.827012903293202, 24.385255896283887, 24.94466318791955, 25.50521336828, 26.066885842005384, 26.629660781920006, 27.19351908613893, 27.758442338334795, 28.32441277087785, 28.89141323059283, 29.459427146903376, 30.028438502158675, 30.598431803957478, 31.16939205930371, 31.741304750443692, 32.31415581224984, 32.887931611028506, 33.46261892464108, 34.03820492383757, 34.61467715471137, 35.19202352219174, 35.77023227449806, 36.349291988486556, 36.92919155582597, 37.50992016994416, 38.0914673136923, 38.67382274767792, 39.2569764992217, 39.84091885189685, 40.42564033561281, 41.011131717208244, 41.5973839915209, 42.184388372904294, 42.77213628716359, 43.360619363884766, 43.94982942913355, 44.53975849850174, 45.130398770480554, 45.721742620141896, 46.31378259310968, 46.90651139980477, 47.49992190994809, 48.09400714730754, 48.68876028467517, 49.28417463906223, 49.8802436671003, 50.4769609606374, 51.07432024251898, 51.67231536254407, 52.27094029358748, 52.87018912787966, 53.47005607343628, 54.070535450629905, 54.67162168889682, 55.27330932357242], [0.0, 0.3549531770483064, 0.7608587912066425, 1.188514399801723, 1.6309365223054437, 2.084673628351081, 2.5476363870994736, 3.0184147311819767, 3.495988967376412, 3.979585392875099, 4.4685957458318715, 4.962528585177103, 5.46097814377011, 5.963603421862743, 6.470113615618923, 6.980257640699954, 7.493816401107394, 8.01059695577697, 8.5304280319612, 9.05315651636592, 9.578644670370348, 10.106767890952566, 10.637412889341194, 11.170476193914904, 11.70586290796702, 12.243485670086063, 12.783263777286239, 13.325122440104156, 13.86899214563022, 14.414808109524701, 14.962509801936815, 15.512040535220578, 16.063347103652273, 16.61637946716555, 17.171090472551548, 17.727435606711403, 18.285372777463426, 18.844862118145823, 19.40586581285702, 19.9683479396667, 20.53227432953528, 21.09761243901373, 21.664331235073725, 22.23240109065041, 22.801793689674813, 23.372481940537345, 23.944439897062825, 24.517642686195575, 25.092066441693955, 25.667688243219896, 26.244486060283258, 26.822438700564376, 27.401525762193693, 27.981727589615083, 28.563025232700983, 29.14540040882406, 29.72883546762151, 30.313313358216174, 30.89881759868306, 31.485332247571186, 32.07284187731009, 32.66133154934668, 33.250786790873384, 33.8411935730218, 34.432538290407464, 35.02480774192255, 35.61798911268198, 36.21206995703743, 36.80703818258106, 37.402882035067414, 37.99959008418851, 38.59715121014196, 39.195554590937704, 39.79478969039284, 40.39484624676835, 40.99571426200525, 41.59738399152089, 42.19984593452927, 42.80309082485208, 43.40710962218945, 44.01189350382215, 44.61743385671837, 45.223722270021035, 45.83075052789258, 46.438510602696276, 47.04699464849424, 47.65619499484411, 48.266104140877125, 48.87671474964195, 49.48801964269925, 50.10001179495338, 50.71268432970808, 51.32603051393438, 51.940043753738934, 52.55471759002291, 53.17004569432076, 53.78602186481011, 54.40264002248376, 55.01989420747579, 55.637778575533844, 56.25628739463053, 56.87541504170709], [0.0, 0.3649774146221923, 0.7823462148343427, 1.2220792513764294, 1.6769958231503328, 2.1435469250725867, 2.619584221482953, 3.1036578232807615, 3.5947192400734664, 4.091972918901713, 4.59479341998814, 5.102675423469088, 5.6152017029284504, 6.132021628439482, 6.652836183570954, 7.1773871931078945, 7.705449373558745, 8.23682433500797, 8.771335967792066, 9.308826834542211, 9.84915530675933, 10.392193262505847, 10.937824213620623, 11.485941766338843, 12.03644834397463, 12.589254117941673, 13.144276106120046, 13.701437406916087, 14.26066654430516, 14.821896904372107, 15.385066247841788, 15.95011628615163, 16.516992310994333, 17.08564286912135, 17.656019475669385, 18.22807636044455, 18.80177024253926, 19.37706012941678, 19.953907137216135, 20.53227432953528, 21.11212657236631, 21.693430403200207, 22.27615391260446, 22.86026663681587, 23.445739460090966, 24.03254452572564, 24.620655154798424, 25.210045771813324, 25.800691836521846, 26.392569781292334, 26.98565695347127, 27.579931562246404, 28.175372629578693, 28.77195994481918, 29.36967402266949, 29.968496064182354, 30.568407920530834, 31.169392059303707, 31.77143153310972, 32.37450995029515, 32.9786114475993, 33.583720664589194, 34.18982271973051, 34.79690318796536, 35.40494807967946, 36.01394382095229, 36.62387723499344, 37.23473552467684, 37.84650625609282, 38.459177343044104, 39.07273703241923, 39.687173890381295, 40.30247678931629, 40.91863489548882, 41.53563765735796, 42.15347479450939, 42.77213628716358, 43.3916123662227, 44.01189350382216, 44.63297040435487, 45.25483399593905, 45.877475422302155, 46.50088603505597, 47.12505738633935, 47.74998122180696, 48.37564947394369, 49.0020542556861, 49.629187854333296, 50.25704272573099, 50.88561148871346, 51.51488691978921, 52.14486194805715, 52.77552965034069, 53.40688324652829, 54.03891609510961, 54.67162168889681, 55.30499365092178, 55.939025730499985, 56.573711799452845, 57.20904584848041, 57.84502198367701, 58.48163442318299], [0.0, 0.3750267466286341, 0.8038874295557846, 1.2557281283842803, 1.7231704277288078, 2.202567603773323, 2.691712168325278, 3.189114310863219, 3.6936966717340995, 4.204641793127751, 4.721307014332801, 5.243173101947722, 5.769811341594115, 6.300861449058681, 6.836016174755835, 7.375010234843198, 7.917612142846476, 8.463618046358354, 9.012846986690677, 9.565137191575195, 10.120343132896709, 10.678333160992812, 11.238987580303336, 11.802197067604757, 12.367861359522998, 12.935888154120656, 13.506192184438138, 14.078694431464061, 14.653321451144334, 15.230004795408252, 15.80868051127699, 16.389288705263688, 16.971773162715934, 17.556081013665256, 18.1421624382603, 18.729970406065156, 19.31946044447053, 19.910590432246252, 20.503320414898447, 21.09761243901373, 21.693430403200207, 22.29073992358811, 22.88950821214678, 23.48970396632009, 24.091297268688205, 24.694259495537167, 25.298563233364877, 25.904182202476566, 26.511091186929583, 27.119265970178272, 27.72868327584823, 28.33932071313636, 28.95115672639177, 29.56417054848307, 30.178342157601335, 30.793652237186823, 31.41008213870061, 32.02761384699196, 32.646229948038105, 33.26591359885556, 33.88664849940271, 34.50841886631057, 35.13120940829485, 35.75500530311639, 36.379792175969186, 37.00555607918677, 37.63228347316738, 38.259961208427356, 38.88857650870025, 39.518116955005986, 40.148570470621515, 40.779925306889304, 41.41217002980627, 42.04529350733965, 42.67928489742111, 43.3141336365742, 43.949829429133544, 44.58636223701781, 45.223722270021035, 45.861899976589775, 46.50088603505597, 47.14067134529737, 47.78124702080004, 48.42260438109839, 49.064734944570944, 49.70763042157067, 50.35128270787077, 50.99568387840793, 51.6408261813062, 52.28670203216595, 52.93330400860321, 53.58062484502583, 54.22865742763367, 54.877394789630785, 55.52683010663866, 56.1769566922998, 56.82776799406185, 57.479257589133205, 58.13141918060126, 58.7842465937053, 59.43773377225613, 60.091874775195684], [0.0, 0.3851006214310102, 0.8254812529119842, 1.2894591837420248, 1.7694578013845499, 2.2617324246391632, 2.7640162683168246, 3.274779502977944, 3.792915829203551, 4.317585830835949, 4.848129584172243, 5.384013908292958, 5.9247985728011345, 6.470113615618923, 7.019643533899104, 7.573115917810985, 8.130293062748411, 8.69096564047162, 9.254947831425367, 9.822073517855136, 10.392193262505849, 10.965171879374743, 11.54088645766941, 12.1192247375532, 12.70008376240232, 13.283368750887782, 13.868992145630218, 14.456872805029297, 15.046935312195089, 15.639109380421912, 16.233329338841994, 16.829533685124588, 17.42766469459334, 18.02766807709987, 18.62949267454444, 19.233090193171304, 19.838414965759046, 20.445423739627536, 21.05407548703526, 21.664331235073725, 22.27615391260446, 22.88950821214678, 23.504360464926126, 24.120678527544943, 24.73843167894912, 25.357590526541646, 25.97812692044579, 26.600013875048166, 27.22322549706178, 27.847736919442177, 28.47352424057079, 29.100564468188367, 29.728835467621504, 30.358315913897318, 30.988985247386047, 31.620823632651348, 32.25381192022191, 32.8879316110285, 33.523164823277234, 34.15949426155261, 34.796903187965356, 35.43537539517757, 36.074895181154325, 36.71544732550517, 37.35701706729163, 37.99959008418851, 38.64315247289666, 39.287690730714274, 39.93319173818201, 40.57964274272427, 41.22703134321607, 41.875345475410384, 42.52457339816679, 43.17470368042664, 43.825725188884675, 44.47762707631096, 45.13039877048055, 45.784029963671664, 46.438510602696276, 47.09383087942951, 47.74998122180696, 48.4069522852612, 49.064734944570944, 49.72332028609813, 50.38269960039007, 51.042864375125305, 51.703806288383326, 52.36551720221974, 53.02798915652964, 53.69121436318316, 54.3551852004181, 55.01989420747578, 55.68533407946695, 56.35149766245531, 57.01837794874763, 57.68596807237911, 58.35426130478441, 59.02325105064447, 59.69293084390061, 60.363294343927215, 61.03433533185527, 61.70604770703948], [0.0, 0.39519851238481146, 0.8471265560157231, 1.3232706540492396, 1.8158555242948335, 2.321038294637024, 2.8364927415260377, 3.3606489211989135, 3.89237152547826, 4.430799127510073, 4.975254499444912, 5.525190479594419, 6.08015529408885, 6.6397692799137396, 7.203708661284436, 7.771693885393548, 8.343481014679016, 8.918855232014222, 9.497625845388518, 10.079622381201462, 10.66469148373869, 11.252694422226444, 11.843505062974945, 12.437008202533525, 13.03309818460796, 13.631677742566794, 14.23265702315052, 14.835952757109597, 15.441487550015012, 16.049189272142787, 16.65899053064076, 17.270828210498806, 17.88464307341671, 18.5003794056805, 19.117984707751635, 19.737409419542796, 20.35860667637248, 20.981532091413214, 21.606143561117218, 22.23240109065041, 22.86026663681587, 23.48970396632009, 24.120678527544943, 24.75315733424684, 25.387108859821556, 26.022502940956002, 26.659310689643277, 27.29750441266849, 27.937057537785503, 28.577944545900266, 29.22014090865947, 29.863623030913832, 30.508368197587046, 31.15435452453483, 31.801560913024435, 32.449967007505904, 33.099553156381305, 33.750300375509276, 34.40219031420962, 35.055205223556214, 35.70932792676833, 36.3645417915284, 37.02083070407159, 37.67817904490698, 38.33657166604312, 38.99599386960288, 39.65643138772264, 40.3178703636404, 40.98029733388576, 41.64369921149227, 42.30806327015967, 42.97337712929906, 43.639628739900466, 44.30680637116647, 44.974898597860594, 45.64389428832294, 46.31378259310967, 46.98455293421574, 47.65619499484411, 48.328698709686776, 49.0020542556861, 49.676252043246656, 50.35128270787077, 51.02713710219201, 51.70380628838332, 52.38128153091798, 53.059554289662756, 53.73861621328469, 54.41845913295351, 55.09907505632338, 55.780456161778574, 56.46259479292862, 57.14548345333958, 57.82911480148868, 58.5134816459309, 59.19857694066602, 59.88439378069604, 60.57092539776317, 61.2581651562594, 61.946106549298804, 62.6347431949447, 63.324068832584125], [0.0, 0.4053199161495176, 0.868822259932977, 1.3571608539358673, 1.8623612837139485, 2.3804822576003546, 2.9091379752831137, 3.446718285270198, 3.992058803079269, 4.544276039908392, 5.102675423469089, 5.66669577875008, 6.235873761530009, 6.809819985269284, 7.38820238198239, 7.970734239252908, 8.557165372049518, 9.147275461577939, 9.740868932026665, 10.337770943806804, 10.937824213620623, 11.540886457669409, 12.146828311861542, 12.755531622278163, 13.366888026668473, 13.98079776731155, 14.597168689721821, 15.215915392046332, 15.836958497712311, 16.460224029686046, 17.085642869121354, 17.71315028457363, 18.342685520594358, 18.974191436589205, 19.607614188457315, 20.242902946831144, 20.880009646780845, 21.518888764690747, 22.159497118701807, 22.801793689674813, 23.445739460090966, 24.091297268688205, 24.73843167894912, 25.387108859821556, 26.037296477275444, 26.688963595487028, 27.3420805866005, 27.996619048151832, 28.65255172735478, 29.309852451547417, 29.968496064182357, 30.628458365816453, 31.289716059619042, 31.952246700972424, 32.61602865078555, 33.28104103218379, 33.947263690273395, 34.614677154711366, 35.28326260483942, 35.95300183716484, 36.62387723499344, 37.295871740038436, 37.96896882584642, 38.643152472896666, 39.31840714524349, 39.994717768583385, 40.672069709639395, 41.350448756764855, 42.0298411016773, 42.710233322240825, 43.39161236622271, 44.07396553595557, 44.757280473843025, 45.44154514865097, 46.126747842531884, 46.81287713873368, 47.49992190994809, 48.187871307257474, 48.876714749641955, 49.566441914011584, 50.257042725731, 50.94850734960628, 51.64082618130621, 52.33398983919171, 53.02798915652964, 53.72281517406825, 54.41845913295351, 55.11491246796701, 55.812166801067065, 56.51021393521641, 57.209045848480415, 57.908654688381276, 58.60903276649436, 59.31017255327364, 60.01206667309446, 60.71470789950192, 61.41808915065456, 62.1222034849532, 62.82704409684567, 63.532604312798625, 64.23887758742801, 64.94585749978069], [0.0, 0.4154643511503421, 0.890567332385593, 1.3911281709115697, 1.9089728669052342, 2.4400614851948226, 2.9819485131393466, 3.532983500025099, 4.091972918901714, 4.658011168817403, 5.23038629357741, 5.808523072960244, 6.391946566064618, 6.980257640699954, 7.573115917810985, 8.170227509080584, 8.771335967792066, 9.376215460964456, 9.984665517872308, 10.59650692300348, 11.211578456539659, 11.829734273572278, 12.450841772257103, 13.0747798414933, 13.701437406916089, 14.33071221404662, 14.962509801936815, 15.596742631277573, 16.233329338841994, 16.872194096083085, 17.513266054233146, 18.156478861734904, 18.801770242539263, 19.44908162592467, 20.098357820168403, 20.74954672373446, 21.40259906871347, 22.05746819211481, 22.714109831314484, 23.372481940537345, 24.03254452572564, 24.694259495537167, 25.357590526541646, 26.022502940956002, 26.688963595487028, 27.356940780042432, 28.026404125234006, 28.697324517734657, 29.369674022669496, 30.04342581232152, 30.718554100519793, 31.395034082152254, 32.07284187731009, 32.75195447962683, 33.43234970842356, 34.114006164314674, 34.79690318796536, 35.48102082172466, 36.16633977388675, 36.85284138535792, 37.540507598529565, 38.22932092817638, 38.91926443421727, 39.610321696191484, 40.302476789316295, 40.99571426200526, 41.69001911473657, 42.38537678017139, 43.08177310443056, 43.779194329446035, 44.47762707631097, 45.177058329558015, 45.87747542230216, 46.57886602218897, 47.28121811809409, 47.98452000752447, 48.68876028467517, 49.39392782909945, 50.10001179495338, 50.807001600778484, 51.51488691978922, 52.2236576706343, 52.933304008603216, 53.64381631725119, 54.3551852004181, 55.067401474618066, 55.78045616177858, 56.49434048230907, 57.209045848480415, 57.92456385809811, 58.640886288452805, 59.35800509053316, 60.075912383487, 60.794600449317166, 61.51406172780027, 62.23428881161613, 62.95527444167742, 63.677011502649094, 64.39949301864816, 65.1227121491146, 65.8466621848451, 66.57133654418149], [0.0, 0.42563135617350106, 0.9123607847401829, 1.4251710606621701, 1.9556881546866314, 2.49977326866819, 3.054921044784831, 3.619440643440744, 4.1921093303794095, 4.771999343302582, 5.358381303432347, 5.95066591408827, 6.548366611888059, 7.151074497307368, 7.75844086173015, 8.370164624973146, 8.985983064702882, 9.605664821483357, 10.229004518784652, 10.855818555435523, 11.485941766338845, 12.1192247375532, 12.755531622278165, 13.394738345651593, 14.036731115160638, 14.68140517401356, 15.3286637496682, 15.97841716060376, 16.63058205251917, 17.28508074123478, 17.941840644212526, 18.600793786177938, 19.2618763670982, 19.9250283829427, 20.590193291368568, 21.25731771584093, 21.926351182794434, 22.597245887328544, 23.269956483649747, 23.944439897062825, 24.620655154798424, 25.298563233364877, 25.97812692044579, 26.659310689643277, 27.3420805866005, 28.026404125234006, 28.71225019297334, 29.399588964046806, 30.088391819973285, 30.778631276523292, 31.47028091650153, 32.16331532777947, 32.857710046072896, 33.55344150201673, 34.250486972139235, 34.94882453338133, 35.64843302084481, 36.349291988486556, 37.051381672505194, 37.754682957192394, 38.45917734304411, 39.16484691694666, 39.87167432427099, 40.57964274272428, 41.28873585782167, 41.99893783985435, 42.71023332224083, 43.42260738115874, 44.136045516363296, 44.85053363310692, 45.566058025081844, 46.28260535831368, 47.00016265594068, 47.718717283818094, 48.43825693689225, 49.15876962629341, 49.8802436671003, 50.602667666733026, 51.326030513934384, 52.0503213683025, 52.775529650340694, 53.501645031992624, 54.228657427633685, 54.95655698549098, 55.68533407946695, 56.41497930134274, 57.14548345333958, 57.87683754101782, 58.60903276649436, 59.34206052196102, 60.075912383487, 60.81058010509022, 61.54605561306278, 62.28233100053715, 63.019398522280476, 63.75725058970491, 64.4958797660829, 65.235278761957, 65.97544043073444, 66.71635776445693, 67.45802388973736, 68.20043206385503], [0.0, 0.43582048908075827, 0.93420166925269, 1.4592880427454737, 2.0025051155242815, 2.5596150113007194, 3.128052396822253, 3.70608595570696, 4.292463682824198, 4.886235606296406, 5.48665488684329, 6.093118120688892, 6.705127096674276, 7.322263126683303, 7.9441691544103525, 8.570536892153362, 9.20109732830356, 9.835613564941916, 10.473875309056847, 11.115694564272882, 11.760902211627414, 12.409345260378386, 13.060884611706733, 13.715393220538548, 14.372754570297023, 15.032861396431393, 15.695614609774378, 16.360922381931076, 17.0286993631928, 17.698866009708563, 18.3713480013965, 19.046075735731, 19.722983885378685, 20.402011009880358, 21.083099213333465, 21.766193841429303, 22.451243212322492, 23.138198376717284, 23.827012903293202, 24.517642686195575, 25.210045771813324, 25.904182202476566, 26.600013875048166, 27.29750441266849, 27.996619048151832, 28.697324517734657, 29.399588964046806, 30.103381847321355, 30.808673863983145, 31.515436871861347, 32.223643821362906, 32.9332686920217, 33.64428643390623, 34.35667291342752, 35.070404863139615, 35.78545983517022, 36.50181615795744, 37.219452896003006, 37.938349812382505, 38.65848733377921, 39.37984651783187, 40.102409022607134, 40.82615707802579, 41.55107345908835, 42.27714146075965, 43.00434487438559, 43.7326679655261, 44.46209545309938, 45.19261248974122, 45.92420464329174, 46.65685787932966, 47.39055854468034, 48.125293351830656, 48.86104936418874, 49.59781398213185, 50.33557492979028, 51.07432024251898, 51.81403825501256, 52.55471759002292, 53.29634714764122, 54.03891609510961, 54.78241385712978, 55.52683010663867, 56.272154756023106, 57.01837794874763, 57.76549005137129, 58.51348164593091, 59.262343522670115, 60.01206667309445, 60.76264228333456, 61.51406172780027, 62.26631656311002, 63.019398522280476, 63.773299509162655, 64.52801159311161, 65.28352700387727, 66.03983812670523, 66.79693749763672, 67.55481779899759, 68.313471855067, 69.0728926279167, 69.83307321341292], [0.0, 0.44603132563079345, 0.9560890765419368, 1.493477696644774, 2.0494218001169577, 2.619584221482954, 3.201339524307394, 3.792915829203552, 4.39303179781743, 5.000715201384029, 5.6152017029284504, 6.235873761530008, 6.862221493442452, 7.493816401107395, 8.130293062748413, 8.771335967792067, 9.416669801957648, 10.066052117045697, 10.719267693090476, 11.376124129150162, 12.03644834397463, 12.70008376240232, 13.366888026668473, 14.036731115160638, 14.70949378143558, 15.385066247841792, 16.063347103652273, 16.744242369025017, 17.427664694593343, 18.11353267287368, 18.801770242539266, 19.492306170347177, 20.185073598410195, 20.88000964678085, 21.5770550631137, 22.276153912604467, 22.977253302554008, 23.680303136833718, 24.385255896283887, 25.092066441693955, 25.800691836521846, 26.511091186929583, 27.22322549706178, 27.937057537785503, 28.65255172735478, 29.369674022669496, 30.088391819973285, 30.808673863983145, 31.53049016457057, 32.253811920221914, 32.978611447599306, 33.704862116603245, 34.432538290407464, 35.161615269997235, 35.892069242793696, 36.623877234993444, 37.357017067291636, 38.0914673136923, 38.82720726314021, 39.56421688373546, 40.302476789316295, 41.04196820821628, 41.782672954021095, 42.5245733981668, 43.26765244423603, 44.011893503822165, 44.75728047384303, 45.50379771519642, 46.251430032659265, 47.00016265594068, 47.749981221806976, 48.50087175720335, 49.252820663303574, 50.00581470042442, 50.75984097374664, 51.51488691978922, 52.27094029358748, 53.02798915652966, 53.78602186481012, 54.54502705846033, 55.30499365092179, 56.06591081912755, 56.82776799406186, 57.59055485176887, 58.35426130478441, 59.11887749396567, 59.884393780696044, 60.650800739443824, 61.41808915065456, 62.18624999395878, 62.95527444167742, 63.72515385260893, 64.4958797660829, 65.26744389626566, 66.03983812670523, 66.81305450510239, 67.58708523829667, 68.36192268745624, 69.13755936346121, 69.91398792247077, 70.69120116166509, 71.4691920151535], [0.0, 0.45626345839647053, 0.9780221332687383, 1.5277386581434653, 2.0964363364211356, 2.679678506356733, 3.2747795029779443, 3.8799267992930693, 4.493809662545964, 5.1154335606641474, 5.744016622484076, 6.378927140455221, 7.019643533899106, 7.665727475356045, 8.31680516013138, 8.972553839715928, 9.632691884011878, 10.296971282963414, 10.965171879374745, 11.637096858551324, 12.312569168691564, 12.991428642738564, 13.673529657184858, 14.358739207671434, 15.046935312195092, 15.738005674762135, 16.43184655824389, 17.12836182686408, 17.82746212742744, 18.529064184930952, 19.233090193171307, 19.93946728478718, 20.64812706814532, 21.3590052208077, 22.072041131156947, 22.78717758122253, 23.50436046492613, 24.2235385369144, 24.94466318791955, 25.667688243219896, 26.392569781292334, 27.119265970178272, 27.847736919442177, 28.577944545900266, 29.309852451547417, 30.04342581232152, 30.778631276523292, 31.515436871861347, 32.253811920221914, 32.993726959373376, 33.735153670911295, 34.478064813831274, 35.222434163188254, 35.96823645336246, 36.71544732550517, 37.464043278784956, 38.21400162509509, 38.965300446918846, 39.71791855808134, 40.47183546714303, 41.22703134321607, 41.98348698400465, 42.741183785891, 43.50010371590505, 44.26022928543094, 45.02154352551754, 45.784029963671664, 46.547672602024, 47.31245589676714, 48.078364738773935, 48.84538443531253, 49.61350069278078, 50.382699600390076, 51.15296761473368, 51.92429154518017, 52.69665854003735, 53.47005607343628, 54.24447193288879, 55.019894207475794, 55.796311276626646, 56.57371179945285, 57.352084704602106, 58.13141918060128, 58.91170466665896, 59.69293084390062, 60.47508762701084, 61.25816515625941, 62.04215378988923, 62.827044096845675, 63.61282684982847, 64.39949301864816, 65.18703376387066, 65.97544043073444, 66.7647045433256, 67.5548177989976, 68.34577206302232, 69.13755936346121, 69.93017188624461, 70.72360197044928, 71.51784210376388, 72.31288491813308, 73.10872318557188], [0.0, 0.4665164957684037, 1.0, 1.5620696159886163, 2.1435469250725867, 2.7398955659630437, 3.348369522101714, 3.9671155358474417, 4.59479341998814, 5.230386293577409, 5.873094715440096, 6.522272782452906, 7.177387193107895, 7.837989769961245, 8.50369830827347, 9.174182806812281, 9.849155306759332, 10.528362224839382, 11.211578456539659, 11.898602764395427, 12.589254117941673, 13.283368750887782, 13.98079776731155, 14.681405174013559, 15.385066247841792, 16.0916661693153, 16.801098870150817, 17.513266054233146, 18.228076360444554, 18.94544464244715, 19.665291345596255, 20.387541965073574, 21.112126572366314, 21.838979399598852, 22.56803847310483, 23.299245289125913, 24.03254452572564, 24.767883785978, 25.50521336828, 26.244486060283258, 26.98565695347127, 27.72868327584823, 28.47352424057079, 29.22014090865947, 29.968496064182357, 30.718554100519793, 31.47028091650153, 32.223643821362906, 32.978611447599306, 33.735153670911295, 34.49324153653038, 35.252847191299175, 36.01394382095229, 36.77650559210729, 37.540507598529565, 38.30592581128293, 39.07273703241923, 39.840918851896845, 40.6104496074505, 41.38130834716221, 42.15347479450939, 42.926929315687104, 43.70165288902178, 44.47762707631097, 45.25483399593906, 46.033256297632924, 46.81287713873368, 47.593680161871916, 48.3756494739437, 49.158769626293406, 49.943025596017804, 50.72840276831252, 51.51488691978922, 52.302464202697145, 53.091121129988316, 53.88084456117058, 54.67162168889681, 55.46344002624288, 56.25628739463054, 57.05015191235461, 57.84502198367701, 58.64088628845279, 59.43773377225613, 60.23555363697619, 61.03433533185527, 61.83406854494331, 62.6347431949447, 63.43634942343523, 64.238877587428, 65.04231825226915, 65.84666218484509, 66.65190034708421, 67.45802388973735, 68.26502414642204, 69.0728926279167, 69.88162101669171, 70.69120116166509, 71.50162507317141, 72.31288491813308, 73.12497301542398, 73.93788183141571, 74.7516039756978], [0.0, 0.47679006103635063, 1.0220218692396401, 1.5964693088151325, 2.190751835165568, 2.8002331878469517, 3.4221068778834347, 4.054478835436419, 4.695979359866279, 5.345569176607377, 6.0024312392955395, 6.665905420813348, 7.335446675356786, 8.01059695577697, 8.69096564047162, 9.376215460964456, 10.066052117045695, 10.760216441062363, 11.458478371279542, 12.160632238607366, 12.866493025951586, 13.575893360581755, 14.28868106760914, 15.004717159009864, 15.723874164994966, 16.446034737543904, 17.171090472551544, 17.898940909238497, 18.62949267454444, 19.362658747049963, 20.098357820168403, 20.836513748346103, 21.5770550631137, 22.319914548264016, 23.065028865354716, 23.812338222265346, 24.561786078767, 25.313318884055413, 26.066885842005384, 26.822438700564376, 27.579931562246404, 28.33932071313636, 29.100564468188367, 29.863623030913832, 30.628458365816453, 31.395034082152254, 32.16331532777947, 32.9332686920217, 33.704862116603245, 34.478064813831274, 35.252847191299175, 36.02918078247099, 36.80703818258105, 37.58639298934757, 38.367219748054104, 39.149493900602366, 39.93319173818201, 40.718290357240434, 41.504767618468776, 42.29260210854865, 43.081773104430546, 43.87226053993645, 44.66404497449996, 45.45710756387497, 46.25143003265925, 47.04699464849424, 47.843784197814216, 48.64178196302991, 49.44097170104156, 50.241337622985235, 51.04286437512531, 51.8455370208121, 52.64934102343167, 53.4542622302799, 54.26028685729882, 55.06740147461806, 55.87559299284878, 56.68484865008143, 57.49515599954272, 58.30650289787009, 59.118877493965655, 59.93226821839371, 60.746663773289306, 61.56205312274702, 62.37842548366174, 63.195770316994995, 64.01407731944222, 64.83333641547826, 65.6535377497596, 66.47467167986369, 67.29672876934652, 68.11969978110122, 68.94357567100167, 69.76834758181542, 70.59400683737239, 71.42054493697539, 72.24795355004038, 73.07622451095456, 73.90534981414135, 74.73532160932186, 75.56613219696312, 76.39777402390399], [0.0, 0.48708379154094467, 1.0440869636102885, 1.630936522305444, 2.238049400355208, 2.8606892420756473, 3.495988967376412, 4.142013614114159, 4.797363910291952, 5.460978143770109, 6.132021628439482, 6.809819985269284, 7.493816401107395, 8.183542939727342, 8.878600546143195, 9.57864467037035, 10.283374658360513, 10.992525747121814, 11.705862907967019, 12.42317603148261, 13.144276106120044, 13.868992145630216, 14.597168689721821, 15.328663749668198, 16.063347103652273, 16.801098870150817, 17.54180830465202, 18.285372777463426, 19.031696899633033, 19.780691770979455, 20.53227432953528, 21.286366785791007, 22.042896128298036, 22.80179368967481, 23.5629947640242, 24.326438268334797, 25.092066441693948, 25.85982457715427, 26.629660781920006, 27.401525762193693, 28.175372629578693, 28.95115672639177, 29.728835467621504, 30.508368197587046, 31.289716059619042, 32.07284187731009, 32.857710046072896, 33.64428643390623, 34.432538290407464, 35.222434163188254, 36.01394382095229, 36.80703818258105, 37.601689251649596, 38.3978700558601, 39.195554590937704, 39.99471776858338, 40.79533536812187, 41.597383991520886, 42.40084102149163, 43.20568458240968, 44.011893503822144, 44.819447286329236, 45.628326069649546, 46.438510602696276, 47.24998221550768, 48.06272279288976, 48.87671474964195, 49.691941007248076, 50.50838497192554, 51.32603051393436, 52.144861948057155, 52.96486401516718, 53.7860218648101, 54.608321038729876, 55.43174745527554, 56.256287394630526, 57.08192748481068, 57.908654688381276, 58.73645628984756, 59.565319883676025, 60.395233362907724, 61.22618490832688, 62.058162978151614, 62.89115629821515, 63.725153852608926, 64.56014487476031, 65.39611883892, 66.23306545203577, 67.07097464599072, 67.90983657018576, 68.74964158444733, 69.5903802522427, 70.43204333418618, 71.27462178182081, 72.11810673166104, 72.96248949948257, 73.80776157484702, 74.65391461584882, 75.5009404440738, 76.34883103975831, 77.19757853713917, 78.0471752199851], [0.0, 0.4973973378891306, 1.0661945341715362, 1.6654700865624932, 2.2854380152525953, 2.9212616766306247, 3.570013282851406, 4.229716900747528, 4.898943630038695, 5.576609277817953, 6.261861484273964, 6.954011591027066, 7.652490994924422, 8.356821851625096, 9.066596656524913, 9.781463564113736, 10.50111555427338, 11.225282257901824, 11.953723669797933, 12.686225231676737, 13.422593929845917, 14.162655157581538, 14.906250162865192, 15.653233950490968, 16.403473541315904, 17.156846515436992, 17.913239783430374, 18.672548542515287, 19.43467538396737, 20.199529525226566, 20.96702614556554, 21.737085808354266, 22.509633956194616, 23.284600467737075, 24.061919266997315, 24.841527977587962, 25.62336761556275, 26.40738231560556, 27.19351908613893, 27.981727589615083, 28.77195994481918, 29.56417054848307, 30.358315913897318, 31.15435452453483, 31.952246700972424, 32.75195447962683, 33.55344150201673, 34.35667291342752, 35.161615269997235, 35.96823645336246, 36.77650559210729, 37.58639298934757, 38.3978700558601, 39.210909248233726, 40.02548401157724, 40.84156872637023, 41.65913865908715, 42.478169916264136, 43.29863940171233, 44.12052477661131, 44.94380442224353, 45.76845740515348, 46.59446344453674, 47.42180288168267, 48.250456651310444, 49.080406254653674, 49.91163373416151, 50.74412164969611, 51.57785305611692, 52.41281148215176, 53.24898091046331, 54.086345758827036, 54.92489086234403, 55.764601456618124, 56.605463161832496, 57.447461967666214, 58.2905842189958, 59.134816602330964, 59.980146132938174, 60.826560142608294, 61.67404626802878, 62.52259243972295, 63.37218687152241, 64.22281805054041, 65.07447472761676, 65.92714590820667, 66.78082084368786, 67.63548902306233, 68.49114016503013, 69.34776421041492, 70.20535131492143, 71.0638918422071, 71.92337635725087, 72.7837956200031, 73.64514057930218, 74.50740236704345, 75.37057229258787, 76.23464183739782, 77.0996026498888, 77.96544654048613, 78.83216547687637, 79.69975157944428], [0.0, 0.507730363227404, 1.088343858862089, 1.7000688736762721, 2.3329161320854643, 2.981948513139346, 3.6441774065803885, 4.317585830835949, 5.000715201384028, 5.692458802091417, 6.391946566064616, 7.09847552860597, 7.811465274294385, 8.530428031961199, 9.254947831425367, 9.984665517872308, 10.719267693090474, 11.458478371279542, 12.202052561325436, 12.94977124766924, 13.701437406916085, 14.456872805029295, 15.215915392046332, 15.978417160603756, 16.744242369025017, 17.513266054233142, 18.285372777463426, 19.060455558742532, 19.83841496575905, 20.619158330019022, 21.40259906871347, 22.188656094980953, 22.977253302554004, 23.768319113369085, 24.561786078767, 25.357590526541646, 26.155672247403217, 26.955974215479063, 27.758442338334795, 28.563025232700983, 29.36967402266949, 30.178342157601335, 30.988985247386047, 31.801560913024435, 32.61602865078555, 33.43234970842356, 34.250486972139235, 35.070404863139615, 35.892069242793696, 36.71544732550517, 37.540507598529565, 38.367219748054104, 39.195554590937704, 40.02548401157724, 40.85698090342524, 41.690019114736565, 42.524573398166794, 43.360619363884766, 44.198133435897084, 45.03709281131249, 45.877475422302155, 46.71925990053504, 47.562425543889525, 48.40695228526121, 49.25282066330357, 50.10001179495338, 50.94850734960629, 51.79828952481974, 52.649341023431674, 53.50164503199262, 54.3551852004181, 55.20994562277553, 56.06591081912755, 56.92306571835968, 57.78139564192608, 58.64088628845279, 59.50152371914224, 60.36329434392722, 61.2261849083269, 62.0901824809604, 62.95527444167741, 63.821448470267676, 64.68869253571475, 65.556994885961, 66.4263440381541, 67.29672876934652, 68.16813810762208, 69.04056132362535, 69.91398792247075, 70.7884076360107, 71.66381041544271, 72.54018642423704, 73.41752603136774, 74.29581980483064, 75.1750585054336, 76.05523308084432, 76.93633465988277, 77.81835454704567, 78.70128421725111, 79.58511531079266, 80.46983962849212, 81.35544912704162], [0.0, 0.5180825425676043, 1.1105342410545758, 1.7347317954663304, 2.3804822576003546, 3.0427478429155657, 3.7184790059974993, 4.405617640778155, 5.102675423469089, 5.808523072960243, 6.522272782452906, 7.243207254412254, 7.970734239252908, 8.70435602057744, 9.443648146935558, 10.188244140659213, 10.937824213620623, 11.692106752909668, 12.450841772257101, 13.213805790567754, 13.980797767311548, 14.75163583441523, 15.52615463785884, 16.30420315253787, 17.08564286912135, 17.87034627664416, 18.658195582645828, 19.44908162592467, 20.242902946831144, 21.039564987441523, 21.838979399598852, 22.641063443151296, 23.445739460090966, 24.252934412940025, 25.06257947781994, 25.874609684303845, 26.68896359548702, 27.50558302278901, 28.32441277087785, 29.14540040882406, 29.968496064182354, 30.793652237186823, 31.620823632651348, 32.449967007505904, 33.28104103218379, 34.114006164314674, 34.94882453338133, 35.78545983517022, 36.623877234993444, 37.464043278784956, 38.30592581128293, 39.149493900602366, 39.99471776858338, 40.84156872637023, 41.690019114736565, 42.540042248725975, 43.3916123662227, 44.244704580108206, 45.09929483369513, 45.95535985916116, 46.812877138733676, 47.6718248684, 48.53218192394031, 49.39392782909945, 50.257042725731, 51.12150734576255, 51.98730298484471, 52.85441147755864, 53.72281517406825, 54.592496918112474, 55.46344002624288, 56.335628268218784, 57.20904584848041, 58.083677388626384, 58.95950791082813, 59.836522822119136, 60.7147078995019, 61.594049275819614, 62.474533426344124, 63.35614715603498, 64.238877587428, 65.12271214911459, 66.00763856477639, 66.89364484274154, 67.78071926603236, 68.66885038287522, 69.55802699764617, 70.44823816222753, 71.33947316775215, 72.2317215367139, 73.12497301542398, 74.01921756679437, 74.9144453634309, 75.81064678101907, 76.70781239198767, 77.60593295943522, 78.50499943130609, 79.40500293480324, 80.30593477102579, 81.2077864098202, 82.11054948483415, 83.01421578876378], [0.0, 0.5284535621605742, 1.1327650082129537, 1.76945780138455, 2.4281349501847003, 3.1036578232807623, 3.792915829203552, 4.493809662545964, 5.204821206129692, 5.924798572801134, 6.652836183570955, 7.38820238198239, 8.130293062748414, 8.878600546143197, 9.632691884011878, 10.39219326250585, 11.156778491951892, 11.926160322089133, 12.70008376240232, 13.47832085813306, 14.26066654430516, 15.046935312195089, 15.836958497712313, 16.63058205251917, 17.427664694593343, 18.228076360444554, 19.031696899633037, 19.83841496575905, 20.64812706814532, 21.460736755999704, 22.276153912604467, 23.094294141508506, 23.915078230139446, 24.73843167894912, 25.56428428633685, 26.392569781292337, 27.22322549706178, 28.05619208024085, 28.89141323059283, 29.72883546762151, 30.568407920530834, 31.41008213870061, 32.25381192022191, 33.099553156381305, 33.947263690273395, 34.79690318796536, 35.64843302084481, 36.50181615795744, 37.357017067291636, 38.21400162509509, 39.07273703241923, 39.93319173818201, 40.79533536812187, 41.65913865908715, 42.524573398166794, 43.3916123662227, 44.260229285430945, 45.130398770480554, 46.00209628311541, 46.87529808973596, 47.74998122180696, 48.626123438841184, 49.5037031937524, 50.38269960039008, 51.263092403085764, 52.14486194805716, 53.02798915652965, 53.912455499447525, 54.7982429736588, 55.68533407946694, 56.57371179945286, 57.46335957847755, 58.354261304784416, 59.246401292125945, 60.139764262846136, 61.034335331855274, 61.930099991438695, 62.827044096845675, 63.72515385260895, 64.62441579954861, 65.52481680241837, 66.4263440381541, 67.32898498468907, 68.23272741030114, 69.1375593634612, 70.04346916315303, 70.95044538963778, 71.85847687563741, 72.7675526979138, 73.67766216922122, 74.58879483061163, 75.5009404440738, 76.41408898548795, 77.32823063787923, 78.24335578495453, 79.1594550049073, 80.07651906447711, 80.99453891325054, 81.91350567819138, 82.83341065838876, 83.75424532001202, 84.67600129146278], [0.0, 0.5388431189134865, 1.155035510643526, 1.804245876564148, 2.475872817189575, 3.164676674142057, 3.8674857007839725, 4.582159318729415, 5.307149564157515, 6.041281903465082, 6.783632953706145, 7.533456673836864, 8.290137081677683, 9.05315651636592, 9.822073517855136, 10.59650692300348, 11.37612412915016, 12.160632238607366, 12.94977124766924, 13.743308719917943, 14.541035558737873, 15.342762608247925, 16.148317888370567, 16.957544322131255, 17.77029784986042, 18.58644585098025, 19.405865812857016, 20.22844419998711, 21.05407548703526, 21.8826613269576, 22.71410983131448, 23.548334944395073, 24.38525589628388, 25.224796722749105, 26.06688584200538, 26.911455680134317, 27.758442338334792, 28.60778529629661, 29.459427146903376, 30.313313358216174, 31.169392059303707, 32.02761384699196, 32.8879316110285, 33.750300375509276, 34.614677154711366, 35.48102082172466, 36.349291988486556, 37.219452896003006, 38.0914673136923, 38.965300446918846, 39.840918851896845, 40.718290357240434, 41.597383991520886, 42.478169916264136, 43.360619363884766, 44.244704580108206, 45.130398770480554, 46.01767605060796, 46.90651139980477, 47.79688061786171, 48.688760284675155, 49.5821277225032, 50.47696096063739, 51.373238702299155, 52.27094029358747, 53.170045694320756, 54.070535450629905, 54.972390669172384, 55.87559299284878, 56.780124577913256, 57.68596807237911, 58.593106595628306, 59.50152371914224, 60.411203448277035, 61.32213020501335, 62.23428881161612, 63.1476644751446, 64.06224277275803, 64.97800963776604, 65.89495134637724, 66.81305450510236, 67.73230603877201, 68.65269317913182, 69.57420345398029, 70.49682467681765, 71.42054493697538, 72.34535259019907, 73.27123624965866, 74.19818477736186, 75.12618727594844, 76.0552330808443, 76.9853117527558, 77.91641307048596, 78.8485270240552, 79.78164380811121, 80.71575381561186, 81.65084763176806, 82.58691602823248, 83.52394995752236, 84.4619405476643, 85.40087909704994, 86.34075706949275], [0.0, 0.5492509198470897, 1.1773451203315186, 1.8390950400023267, 2.5236945124358416, 3.2258026748045543, 3.9421865179132323, 4.670664117921344, 5.409657611954408, 6.157969780192221, 6.914659404468226, 7.6789660338920065, 8.450261788535517, 9.228019008872236, 10.011787708017161, 10.801179360629755, 11.595854939800383, 12.39551589049734, 13.199897187020948, 14.008761903424077, 14.821896904372107, 15.63910938042191, 16.460224029686046, 17.285080741234776, 18.11353267287368, 18.94544464244715, 19.78069177097946, 20.619158330019026, 21.460736755999704, 22.30532680229607, 23.152834805635397, 24.003173048133437, 24.856259199796874, 25.71201582913827, 26.570369971763956, 27.43125274855952, 28.294599026513037, 29.16034711635934, 30.028438502158675, 30.89881759868306, 31.77143153310972, 32.646229948038105, 33.523164823277234, 34.40219031420962, 35.28326260483942, 36.16633977388675, 37.051381672505194, 37.938349812382505, 38.82720726314021, 39.71791855808134, 40.6104496074505, 41.504767618468776, 42.40084102149163, 43.29863940171233, 44.198133435897084, 45.09929483369513, 46.00209628311541, 46.90651139980477, 47.812514679800884, 48.72008145546537, 49.6291878543333, 50.539810760640236, 51.45192777931161, 52.36551720221975, 53.280557976531775, 54.19702967498828, 55.11491246796701, 56.03418709719891, 56.95483485101562, 57.876837541017814, 58.8001774800637, 59.724837461484654, 60.65080073944382, 61.57805101035942, 62.506572395321335, 63.43634942343524, 64.36736701603348, 65.2996104716969, 66.23306545203579, 67.16771796818256, 68.10355436795156, 69.04056132362535, 69.97872582032967, 70.91803514496138, 71.85847687563741, 72.80003887163366, 73.74270926378594, 74.68647644532662, 75.63132906313211, 76.57725600935876, 77.52424641344531, 78.47228963446224, 79.4213752537893, 80.37149306810328, 81.32263308266066, 82.27478550485849, 83.22794073806018, 84.18208937567212, 85.13722219545865, 86.0933301540834, 87.05040438186575, 88.00843617774197], [0.0, 0.5596766815894849, 1.1996932298559693, 1.8740043428652566, 2.571598733888163, 3.2870341609982527, 4.017016246721494, 4.759321650412612, 5.512342558546528, 6.274859025936274, 7.045911968416354, 7.824726500382607, 8.61066282362648, 9.403183262702852, 10.201829289173341, 11.006205002793727, 11.815964941319164, 12.630804882611137, 13.450454770309667, 14.274673181190717, 15.103242934231009, 15.935967560120416, 16.77266842942912, 17.613182392036467, 18.457359818421377, 19.305062960429904, 20.15616456866071, 21.01054671792987, 21.86809980292297, 22.728721674154894, 23.59231689045701, 24.458796068903233, 25.328075316730178, 26.200075732662725, 27.074722967312916, 27.951946834117944, 28.831680963725187, 29.713862495897242, 30.598431803957478, 31.485332247571186, 32.37450995029515, 33.26591359885556, 34.15949426155261, 35.055205223556214, 35.95300183716484, 36.85284138535792, 37.754682957192394, 38.65848733377921, 39.56421688373546, 40.47183546714303, 41.38130834716221, 42.29260210854865, 43.20568458240968, 44.12052477661131, 45.03709281131249, 45.95535985916116, 46.87529808973596, 47.79688061786171, 48.72008145546537, 49.644875466672815, 50.57123832587717, 51.499146478535565, 52.42857710447499, 53.35950808350882, 54.291917963183856, 55.225785928494886, 56.16109177341808, 57.09781587412809, 58.035939163775744, 58.975443108713456, 59.916309686065944, 60.85852136255134, 61.802061074466955, 62.74691220875995, 63.69305858511019, 64.64048443895817, 65.58917440541629, 66.53911350400617, 67.49028712416997, 68.44268101150641, 69.39628125468703, 70.35107427301055, 71.30704680455719, 72.26418589490645, 73.22247888638576, 74.18191340781843, 75.1424773647424, 76.10415893007287, 77.06694653518373, 78.03082886138465, 78.99579483177173, 79.96183360343166, 80.92893455998015, 81.89708730441679, 82.86628165227997, 83.83650762508566, 84.80775544403605, 85.78001552398356, 86.75327846763808, 87.7275350600046, 88.7027762630401, 89.67899321051922], [0.0, 0.5701201299034058, 1.222079251376429, 1.9089728669052342, 2.619584221482953, 3.348369522101714, 4.091972918901714, 4.848129584172243, 5.61520170292845, 6.3919465660646155, 7.177387193107894, 7.970734239252907, 8.771335967792066, 9.578644670370348, 10.392193262505849, 11.211578456539659, 12.036448343974628, 12.866493025951588, 13.701437406916085, 14.541035558737875, 15.385066247841786, 16.23332933884199, 17.08564286912135, 17.941840644212522, 18.801770242539263, 19.665291345596252, 20.532274329535277, 21.402599068713467, 22.276153912604464, 23.152834805635393, 24.03254452572564, 24.915192022082646, 25.800691836521843, 26.68896359548702, 27.579931562246404, 28.473524240570786, 29.36967402266949, 30.26831687534639, 31.16939205930371, 32.07284187731009, 32.9786114475993, 33.88664849940271, 34.796903187965356, 35.70932792676833, 36.62387723499344, 37.540507598529565, 38.45917734304411, 39.37984651783187, 40.302476789316295, 41.22703134321607, 42.15347479450939, 43.081773104430546, 44.011893503822144, 44.94380442224353, 45.877475422302155, 46.812877138733676, 47.74998122180696, 48.688760284675155, 49.6291878543333, 50.57123832587717, 51.514886919789205, 52.460109642003786, 53.40688324652829, 54.3551852004181, 55.30499365092177, 56.25628739463053, 57.20904584848041, 58.16324902246963, 59.11887749396566, 60.07591238348698, 61.03433533185527, 61.994128478621334, 62.9552744416774, 63.917756297974606, 64.88155756527144, 65.84666218484509, 66.81305450510236, 67.78071926603236, 68.74964158444733, 69.71980693996187, 70.69120116166508, 71.66381041544268, 72.63762119191027, 73.6126202949206, 74.58879483061162, 75.56613219696311, 76.5446200738329, 77.5242464134453, 78.50499943130608, 79.48686759752053, 80.46983962849211, 81.45390447898102, 82.43905133450349, 83.42526960405328, 84.4125489131289, 85.40087909704994, 86.39025019454823, 87.38065244161942, 88.37207626562193, 89.3645122796109, 90.35795127689539, 91.35238422580808], [0.0, 0.5805809992442568, 1.244502615685596, 1.9439997229808277, 2.6676497550976506, 3.4098071985463747, 4.167054628537513, 4.937085661089107, 5.718232429710207, 6.509229423403176, 7.309081735534451, 8.116985537977612, 8.932277135611075, 9.754398770433713, 10.582874787647512, 11.417294499855707, 12.25729954155566, 13.102574327698035, 13.952838715127884, 14.807842263293976, 15.667359679309074, 16.531187155596154, 17.39913939079057, 18.27104714099992, 19.146755187935288, 20.02612063845231, 20.909011490295004, 21.795305413690908, 22.68488870949003, 23.577655412852142, 24.473506517813856, 25.372349302933923, 26.27409674199526, 27.178666986704624, 28.085982910672133, 28.995971705817503, 29.908564523846113, 30.823696156646488, 31.741304750443692, 32.66133154934668, 33.583720664589194, 34.50841886631057, 35.43537539517757, 36.3645417915284, 37.295871740038436, 38.22932092817638, 39.16484691694666, 40.102409022607134, 41.04196820821628, 41.98348698400465, 42.926929315687104, 43.87226053993645, 44.819447286329236, 45.76845740515348, 46.71925990053504, 47.6718248684, 48.626123438841184, 49.5821277225032, 50.539810760640236, 51.499146478535565, 52.460109642003786, 53.422675816723306, 54.38682133017159, 55.35252323595749, 56.3197592803636, 57.28850787092962, 58.25874804692251, 59.230459451553266, 60.203622305812466, 61.17821738380778, 62.15422598949684, 63.13162993471737, 64.11041151842538, 65.09055350705886, 66.07203911595128, 67.05485199172581, 68.03897619560546, 69.02439618758045, 70.01109681137834, 70.99906328018592, 71.98828116307685, 72.97873637210111, 73.97041514999685, 74.9633040584869, 75.95738996712568, 76.95266004266439, 77.94910173890428, 78.94670278701061, 79.94545118626097, 80.94533519520395, 81.94634332320555, 82.94846432236199, 83.95168717975956, 84.9560011100626, 85.96139554841267, 86.96786014362236, 87.97538475164886, 88.98395942933261, 89.9935744283881, 91.00422018963377, 92.01588733744937, 93.02856667444973], [0.0, 0.5910590323464371, 1.2669627713225835, 1.979084049671741, 2.7157941526499667, 3.4713456793869963, 4.242259529134062, 5.026187693454151, 5.821432205042947, 6.62670471359849, 7.440992356914004, 8.263476799778392, 9.093482369035199, 9.930441240548157, 10.773869175141321, 11.623348073538885, 12.478513102638335, 13.339042981870506, 14.20465251219806, 15.075086733244985, 15.95011628615163, 16.829533685124588, 17.713150284573633, 18.600793786177935, 19.492306170347177, 20.387541965073574, 21.286366785791007, 22.188656094980953, 23.094294141508502, 24.003173048133434, 24.915192022082646, 25.830256668525085, 26.748278390638383, 27.669173862972574, 28.592864567199584, 29.519276381235617, 30.44833921424674, 31.37998668127837, 32.31415581224984, 33.250786790873384, 34.18982271973051, 35.13120940829485, 36.074895181154325, 37.02083070407159, 37.96896882584642, 38.91926443421727, 39.87167432427099, 40.82615707802579, 41.782672954021095, 42.741183785891, 43.70165288902178, 44.66404497449996, 45.628326069649546, 46.59446344453674, 47.562425543889525, 48.53218192394031, 49.5037031937524, 50.47696096063739, 51.45192777931161, 52.42857710447499, 53.40688324652829, 54.38682133017159, 55.36836725565262, 56.35149766245532, 57.33618989523842, 58.32242197185178, 59.31017255327364, 60.2994209153259, 61.29014692203759, 62.282331000537134, 63.27595411736544, 64.27099775610945, 65.26744389626566, 66.26527499324939, 67.26447395947297, 68.26502414642204, 69.26690932766458, 70.27011368273259, 71.27462178182083, 72.28041857125118, 73.2874893596552, 74.29581980483063, 75.30539590123155, 76.31620396805349, 77.32823063787923, 78.34146284585196, 79.35588781934547, 80.37149306810328, 81.38826637481998, 82.40619578614039, 83.4252696040533, 84.44547637765847, 85.46680489528669, 86.48924417695395, 87.51278346713259, 88.53741222782223, 89.56312013190544, 90.58989705677357, 91.61773307820893, 92.6466184645107, 93.67654367085215, 94.70749933385835], [0.0, 0.6015539798357156, 1.2894591837420246, 2.014225011980899, 2.7640162683168246, 3.5329835000250993, 4.31758583083595, 5.1154335606641474, 5.9247985728011345, 6.7443696407718, 7.573115917810985, 8.41020453820455, 9.254947831425369, 10.106767890952568, 10.965171879374745, 11.829734273572281, 12.70008376240232, 13.575893360581757, 14.456872805029297, 15.342762608247929, 16.233329338841994, 17.12836182686408, 18.027668077099875, 18.931072731869463, 19.838414965759053, 20.74954672373446, 21.66433123507373, 22.582641750948383, 23.50436046492613, 24.42937758427962, 25.35759052654165, 26.288903220790047, 27.22322549706178, 28.160472550365633, 29.10056446818837, 30.043425812321516, 30.98898524738605, 31.937175209684522, 32.887931611028506, 33.8411935730218, 34.79690318796536, 35.75500530311639, 36.71544732550517, 37.67817904490698, 38.643152472896666, 39.610321696191484, 40.57964274272428, 41.55107345908835, 42.5245733981668, 43.50010371590505, 44.47762707631097, 45.45710756387497, 46.438510602696276, 47.42180288168267, 48.40695228526121, 49.39392782909945, 50.38269960039008, 51.373238702299155, 52.36551720221975, 53.35950808350882, 54.3551852004181, 55.35252323595749, 56.35149766245532, 57.35208470460212, 58.35426130478441, 59.358005090533176, 60.36329434392722, 61.37010797280636, 62.37842548366175, 63.38822695608253, 64.39949301864817, 65.41220482616492, 66.42634403815411, 67.44189279850633, 68.45883371622371, 69.47714984717793, 70.49682467681767, 71.51784210376388, 72.54018642423705, 73.56384231726328, 74.58879483061163, 75.61502936741722, 76.64253167344917, 77.67128782498428, 78.70128421725111, 79.732507553411, 80.76494483404474, 81.79858334711666, 82.83341065838876, 83.86941460225998, 84.9065832730072, 85.94490501640597, 86.98436842171073, 88.02496231397497, 89.06667574669399, 90.10949799475281, 91.15341854766395, 92.1984271030799, 93.24451356056684, 94.29166801562619, 95.33988075395159, 96.38914224591039], [0.0, 0.6120655998656237, 1.3119913345346659, 2.0494218001169577, 2.8123149908636624, 3.594719240073467, 4.393031797817429, 5.204821206129691, 6.028329151001342, 6.8622214934424495, 7.705449373558745, 8.557165372049516, 9.416669801957648, 10.283374658360513, 11.15677849195189, 12.03644834397463, 12.922006414954364, 13.813120005831385, 14.709493781435576, 15.610863719957022, 16.516992310994333, 17.427664694593336, 18.342685520594358, 19.261876367098196, 20.185073598410195, 21.112126572366314, 22.042896128298036, 22.977253302554004, 23.915078230139443, 24.856259199796874, 25.800691836521843, 26.748278390638383, 27.69892711654366, 28.652551727354773, 29.60907091415849, 30.568407920530834, 31.53049016457056, 32.495248901964786, 33.46261892464108, 34.432538290407464, 35.40494807967946, 36.379792175969186, 37.35701706729163, 38.33657166604312, 39.31840714524349, 40.302476789316295, 41.28873585782167, 42.27714146075965, 43.26765244423603, 44.26022928543094, 45.25483399593906, 46.25143003265925, 47.24998221550768, 48.250456651310444, 49.25282066330357, 50.257042725731, 51.263092403085764, 52.27094029358747, 53.280557976531775, 54.291917963183856, 55.30499365092177, 56.3197592803636, 57.33618989523842, 58.35426130478441, 59.37395004847685, 60.39523336290773, 61.41808915065455, 62.442495950990384, 63.4684329123006, 64.49587976608288, 65.52481680241837, 66.55522484681038, 67.58708523829665, 68.62037980874821, 69.65509086327496, 70.69120116166508, 71.7286939007901, 72.7675526979138, 73.80776157484702, 74.84930494289554, 75.89216758855149, 76.93633465988276, 77.9817916535785, 79.02852440261084, 80.0765190644771, 81.12576210998817, 82.17624031257158, 83.22794073806017, 84.2808507349387, 85.33495792502306, 86.39025019454823, 87.44671568564256, 88.50434278816788, 89.56312013190544, 90.62303657907012, 91.6840812171351, 92.7462433519515, 93.80951250114748, 94.87387838779313, 95.93933093431752, 97.00586025666553, 98.0734566586826], [0.0, 0.6225936577760293, 1.3345587206955016, 2.0846736283510814, 2.860689242075648, 3.6565515213509174, 4.468595745831872, 5.294348634371812, 6.132021628439483, 6.980257640699954, 7.837989769961246, 8.70435602057744, 9.578644670370352, 10.46025760022391, 11.348684735469945, 12.243485670086065, 13.144276106120047, 14.050717621800493, 14.962509801936815, 15.879384083315523, 16.801098870150817, 17.727435606711403, 18.65819558264583, 19.593197307043855, 20.532274329535284, 21.475273416780514, 22.422053014427114, 23.372481940537345, 24.3264382683348, 25.283808365031717, 26.24448606028326, 27.208371923034445, 28.1753726295787, 29.145400408824063, 30.11837255327365, 31.094210986226575, 32.0728418773101, 33.05419529974966, 34.03820492383757, 35.02480774192255, 36.01394382095229, 37.00555607918677, 37.99959008418851, 38.99599386960288, 39.994717768583385, 40.99571426200526, 41.99893783985435, 43.00434487438559, 44.011893503822165, 45.02154352551754, 46.033256297632924, 47.04699464849424, 48.06272279288976, 49.080406254653674, 50.10001179495338, 51.12150734576255, 52.14486194805716, 53.170045694320756, 54.19702967498828, 55.225785928494886, 56.25628739463053, 57.28850787092962, 58.32242197185178, 59.358005090533176, 60.39523336290773, 61.43408363401715, 62.474533426344124, 63.51656091001866, 64.56014487476033, 65.60526470343102, 66.65190034708422, 67.7000323014053, 68.74964158444733, 69.80070971557377, 70.85321869552713, 71.907150987549, 72.96248949948259, 74.01921756679438, 75.07731893645662, 76.136777751636, 77.19757853713917, 78.25970618556795, 79.32314594414197, 80.38788340214822, 81.45390447898103, 82.5211954127375, 83.58974274933668, 84.65953333213255, 85.73055429199285, 86.802793037818, 87.87623724747574, 88.95087485912876, 90.02669406293448, 91.10368329309652, 92.18183122025026, 93.26112674416397, 94.34155898674014, 95.42311728530105, 96.50579118614472, 97.58957043835731, 98.67444498786934, 99.76040497174405], [0.0, 0.633137925772215, 1.3571608539358668, 2.1199797339423823, 2.9091379752831132, 3.7184790059974997, 4.544276039908393, 5.384013908292959, 6.235873761530008, 7.09847552860597, 7.9707342392529075, 8.851773299036449, 9.740868932026666, 10.637412889341192, 11.54088645766941, 12.450841772257103, 13.366888026668471, 14.28868106760914, 15.215915392046332, 16.148317888370567, 17.08564286912135, 18.02766807709987, 18.974191436589205, 19.925028382942696, 20.88000964678085, 21.838979399598852, 22.80179368967481, 23.768319113369085, 24.73843167894912, 25.71201582913827, 26.688963595487024, 27.669173862972574, 28.652551727354776, 29.639007931047384, 30.628458365816453, 31.620823632651348, 32.61602865078555, 33.61400230916222, 34.61467715471137, 35.61798911268198, 36.62387723499344, 37.63228347316738, 38.64315247289666, 39.65643138772264, 40.672069709639395, 41.69001911473657, 42.71023332224083, 43.7326679655261, 44.75728047384303, 45.784029963671664, 46.81287713873368, 47.843784197814216, 48.87671474964195, 49.91163373416151, 50.94850734960629, 51.98730298484471, 53.02798915652965, 54.070535450629905, 55.11491246796701, 56.16109177341808, 57.20904584848041, 58.25874804692251, 59.31017255327364, 60.36329434392722, 61.41808915065455, 62.474533426344124, 63.532604312798625, 64.59227961043662, 65.65353774975961, 66.71635776445692, 67.78071926603238, 68.84660241984561, 69.91398792247075, 70.98285698028256, 72.0531912891875, 73.12497301542398, 74.19818477736186, 75.27280962823653, 76.34883103975832, 77.42623288654211, 78.50499943130609, 79.58511531079266, 80.66656552236785, 81.74933541125831, 82.83341065838874, 83.91877726878418, 85.00542156050489, 86.0933301540834, 87.1824899624354, 88.27288818121804, 89.36451227961092, 90.4573499914971, 91.55138930702205, 92.6466184645107, 93.74302594272388, 94.84060045343594, 95.93933093431754, 97.0392065421075, 98.14021664605956, 99.24235082165004, 100.34559884453337, 101.44995068473378], [0.0, 0.643698182622939, 1.3797972600362132, 2.1553393761269124, 2.957660173974205, 3.780500394701177, 4.620071092184709, 5.473815146609394, 6.339883371332058, 7.216872676809073, 8.103679996297407, 8.999414114437288, 9.903339183269281, 10.814836808784396, 11.733379625930315, 12.65851229991092, 13.589837505937655, 14.527005350502149, 15.469705235014457, 16.417659492572124, 17.370618337835534, 18.328355806525614, 19.290666452456882, 20.25736263258539, 21.228272254247727, 22.203236889838678, 23.182110186631615, 24.164756515916114, 25.151049817872263, 26.14087260781633, 27.134115116467566, 28.13067454228183, 29.13045439808877, 30.1333639375538, 31.13931764958189, 32.14823481084758, 33.16003908829453, 34.174658184787795, 35.19202352219174, 36.21206995703743, 37.23473552467684, 38.259961208427356, 39.287690730714274, 40.3178703636404, 41.350448756764855, 42.38537678017139, 43.42260738115874, 44.46209545309938, 45.50379771519642, 46.547672602024, 47.593680161871916, 48.64178196302991, 49.691941007248076, 50.74412164969611, 51.79828952481974, 52.85441147755864, 53.912455499447525, 54.972390669172384, 56.03418709719891, 57.09781587412809, 58.16324902246963, 59.230459451553266, 60.2994209153259, 61.37010797280636, 62.442495950990384, 63.51656091001866, 64.59227961043662, 65.66962948239075, 66.7485885966198, 67.82913563711105, 68.91124987530382, 69.99491114573107, 71.08009982300052, 72.16679680002363, 73.25498346740858, 74.34464169394026, 75.43575380807623, 76.52830258039276, 77.62227120692097, 78.71764329331661, 79.81440283981205, 80.9125342269023, 82.0120222017209, 83.1128518650641, 84.21500865902533, 85.31847835520416, 86.42324704345654, 87.52930112115574, 88.63662728293485, 89.74521251088436, 90.85504406517938, 91.96610947511351, 93.07839653051701, 94.19189327353905, 95.306587990775, 96.42246920572026, 97.53952567153426, 98.6577463640985, 99.77712047535401, 100.89763740690402, 102.0192867638687, 103.14205834897993], [0.0, 0.6542742133760885, 1.4024674782365998, 2.1907518351655684, 3.0062548504883684, 3.8426144250278313, 4.695979359866279, 5.5637505214331995, 6.44404834074889, 7.335446675356785, 8.236824335007972, 9.147275461577939, 10.066052117045698, 10.992525747121816, 11.926160322089133, 12.866493025951591, 13.813120005831387, 14.765685619431967, 15.723874164994966, 16.68740341352069, 17.65601947566939, 18.62949267454444, 19.607614188457315, 20.590193291368568, 21.577055063113704, 22.568038473104835, 23.562994764024204, 24.561786078767007, 25.56428428633685, 26.570369971763956, 27.579931562246408, 28.592864567199587, 29.609070914158497, 30.628458365816456, 31.6509400061219, 32.676433785456396, 33.70486211660324, 34.736151514577735, 35.77023227449806, 36.80703818258106, 37.84650625609282, 38.88857650870025, 39.93319173818201, 40.98029733388576, 42.0298411016773, 43.08177310443056, 44.136045516363296, 45.19261248974122, 46.251430032659265, 47.31245589676714, 48.3756494739437, 49.44097170104156, 50.50838497192554, 51.57785305611692, 52.649341023431674, 53.72281517406825, 54.7982429736588, 55.87559299284878, 56.95483485101562, 58.035939163775744, 59.11887749396566, 60.203622305812466, 61.29014692203759, 62.37842548366175, 63.4684329123006, 64.56014487476033, 65.65353774975961, 66.7485885966198, 67.84527512577952, 68.94357567100167, 70.04346916315305, 71.14493510544581, 72.24795355004039, 73.3525050759167, 74.45857076792858, 75.56613219696312, 76.67517140113252, 77.78567086793174, 78.89761351730091, 80.0109826855349, 81.12576210998817, 82.24193591452558, 83.35948859567445, 84.47840500943545, 85.59867035871406, 86.72027018133569, 87.84319033861112, 88.967417004421, 90.09293665478978, 91.21973605792229, 92.34780226467699, 93.47712259945234, 94.60768465146425, 95.73947626639311, 96.87248553838177, 98.0067008023654, 99.14211062671664, 100.27870380618954, 101.41646935514754, 102.55539650106108, 103.6954746782613, 104.8366935219379], [0.0, 0.6648658090906544, 1.4251710606621695, 2.2262164114466443, 3.0549210447848303, 3.904819869847126, 4.771999343302582, 5.65381825599307, 6.548366611888056, 7.45419518169059, 8.370164624973144, 9.295354419296409, 10.229004518784652, 11.170476193914903, 12.119224737553198, 13.074779841493298, 14.036731115160634, 15.004717159009862, 15.978417160603755, 16.957544322131255, 17.94184064421252, 18.93107273186946, 19.925028382942696, 20.92351378385997, 21.92635118279443, 22.933376942344637, 23.944439897062818, 24.95939995817022, 25.978126920445785, 27.000499435792825, 28.026404125234, 29.0557348066584, 30.088391819973275, 31.12428143470557, 32.163315327779465, 33.20541012133164, 34.25048697213923, 35.29847120561962, 36.349291988486556, 37.402882035067414, 38.459177343044104, 39.518116955005986, 40.57964274272427, 41.64369921149227, 42.710233322240825, 43.779194329446035, 44.85053363310692, 45.92420464329174, 47.00016265594068, 48.078364738773935, 49.158769626293406, 50.241337622985235, 51.32603051393436, 52.41281148215176, 53.50164503199262, 54.592496918112474, 55.68533407946694, 56.780124577913256, 57.876837541017814, 58.975443108713456, 60.07591238348698, 61.17821738380778, 62.282331000537134, 63.38822695608253, 64.49587976608288, 65.60526470343102, 66.71635776445692, 67.82913563711105, 68.94357567100167, 70.05965584915182, 71.17735476135458, 72.2966515790137, 73.41752603136773, 74.53995838300304, 75.66392941256917, 76.78942039261698, 77.91641307048594, 79.0448896501732, 80.17483277512144, 81.30622551186832, 82.43905133450347, 83.57329410988395, 84.70893808356193, 85.84596786638237, 86.9843684217107, 88.12412505325415, 89.26522339344194, 90.4076493923332, 91.55138930702203, 92.69642969151283, 93.84275738703926, 94.99035951280322, 96.13922345711096, 97.2893368688849, 98.4406876495322, 99.59326394515028, 100.74705413905303, 101.90204684460048, 103.05823089831712, 104.21559535328431, 105.37412947279289, 106.5338227242437], [0.0, 0.6754727665838723, 1.4479075717811325, 2.2617324246391637, 3.1036578232807623, 3.967115535847442, 4.848129584172244, 5.744016622484076, 6.652836183570955, 7.573115917810984, 8.50369830827347, 9.443648146935558, 10.392193262505852, 11.348684735469945, 12.312569168691565, 13.283368750887785, 14.260666544305161, 15.244095383799392, 16.233329338841994, 17.228077036184057, 18.22807636044455, 19.233090193171304, 20.242902946831148, 21.25731771584093, 22.276153912604467, 23.299245289125913, 24.3264382683348, 25.35759052654165, 26.392569781292337, 27.431252748559523, 28.473524240570793, 29.51927638123562, 30.568407920530838, 31.62082363265135, 32.676433785456396, 33.735153670911295, 34.79690318796536, 35.861606470712694, 36.92919155582597, 37.99959008418851, 39.07273703241923, 40.148570470621515, 41.22703134321607, 42.30806327015967, 43.39161236622271, 44.47762707631097, 45.566058025081844, 46.65685787932966, 47.749981221806976, 48.84538443531253, 49.943025596017804, 51.04286437512531, 52.144861948057155, 53.24898091046331, 54.3551852004181, 55.46344002624288, 56.57371179945286, 57.68596807237911, 58.8001774800637, 59.916309686065944, 61.03433533185527, 62.15422598949684, 63.27595411736544, 64.39949301864817, 65.52481680241837, 66.65190034708422, 67.78071926603238, 68.91124987530382, 70.04346916315305, 71.17735476135458, 72.3128849181331, 73.45003847260266, 74.58879483061163, 75.72913394189683, 76.87103627845937, 78.01448281408113, 79.15945500490729, 80.3059347710258, 81.45390447898104, 82.6033469251621, 83.754245320012, 84.90658327300719, 86.0603447783608, 87.21551420140636, 88.37207626562194, 89.53001604025697, 90.6893189285272, 91.84997065634556, 93.0119572615583, 94.17526508365867, 95.33988075395159, 96.50579118614472, 97.67298356734324, 98.84144534942631, 100.01116424078576, 101.18212819840745, 102.35432542027809, 103.52774433810055, 104.70237361030254, 105.87820211532338, 107.05521894516545, 108.23341339919747], [0.0, 0.6860948881924606, 1.4706765878929686, 2.297299212893418, 3.1524642777542167, 4.029500262133603, 4.924368663769359, 5.834343940037302, 6.757455108981223, 7.692206667600575, 8.637422896475666, 9.59215388100502, 10.555615307146612, 11.527148050826598, 12.506190012482838, 13.492255867029023, 14.484922120172742, 15.483815832928007, 16.48860594935806, 17.498996514234914, 18.514721290291966, 19.53553943027973, 20.561231956451387, 21.591598866792438, 22.626456733883245, 23.665636695401343, 24.708982759205817, 25.756350363501358, 26.80760514563108, 27.862621882869302, 28.921283576062628, 29.983480652719116, 31.049110270612168, 32.118075706466875, 33.19028581706306, 34.26565456229302, 35.34410058148003, 36.42554681569171, 37.50992016994416, 38.59715121014196, 39.687173890381295, 40.779925306889304, 41.875345475410384, 42.97337712929906, 44.07396553595557, 45.177058329558015, 46.28260535831368, 47.39055854468034, 48.50087175720335, 49.61350069278078, 50.72840276831252, 51.8455370208121, 52.96486401516718, 54.086345758827036, 55.20994562277553, 56.335628268218784, 57.46335957847755, 58.593106595628306, 59.724837461484654, 60.85852136255134, 61.994128478621334, 63.13162993471737, 64.27099775610945, 65.41220482616492, 66.55522484681038, 67.7000323014053, 68.84660241984561, 69.99491114573107, 71.14493510544581, 72.2966515790137, 73.45003847260266, 74.60507429256208, 75.76173812088773, 76.92000959201677, 78.07986887086352, 79.24129663201377, 80.404274040002, 81.56878273060119, 82.73480479306147, 83.9023227532372, 85.07131955754787, 86.24177855772132, 87.41368349627233, 88.58701849267204, 89.76176803016817, 90.93791694321716, 92.11545040549362, 93.29435391844382, 94.47461330035271, 95.65621467589577, 96.83914446614895, 98.02338937903197, 99.20893640016129, 100.39577278409108, 101.58388604592193, 102.77326395325774, 103.96389451849308, 105.15576599141406, 106.34886685209688, 107.54318580408915, 108.73871176785998, 109.93543387450573], [0.0, 0.6967319815469868, 1.4934776966447734, 2.3329161320854643, 3.2013395243073934, 4.091972918901714, 5.000715201384029, 5.924798572801134, 6.86222149344245, 7.811465274294383, 8.771335967792066, 9.740868932026665, 10.719267693090476, 11.705862907967019, 12.70008376240232, 13.701437406916089, 14.709493781435576, 15.723874164994964, 16.744242369025013, 17.77029784986042, 18.80177024253926, 19.838414965759046, 20.88000964678085, 21.92635118279443, 22.977253302554008, 24.03254452572564, 25.092066441693948, 26.155672247403217, 27.223225497061776, 28.294599026513037, 29.369674022669493, 30.44833921424674, 31.530490164570562, 32.61602865078555, 33.70486211660324, 34.79690318796536, 35.89206924279369, 36.990282027447854, 38.0914673136923, 39.195554590937704, 40.30247678931629, 41.41217002980627, 42.52457339816679, 43.639628739900466, 44.757280473843025, 45.87747542230216, 47.00016265594068, 48.125293351830656, 49.252820663303574, 50.382699600390076, 51.51488691978922, 52.64934102343167, 53.7860218648101, 54.92489086234403, 56.06591081912755, 57.20904584848041, 58.354261304784416, 59.50152371914224, 60.65080073944382, 61.802061074466955, 62.9552744416774, 64.11041151842538, 65.26744389626566, 66.42634403815411, 67.58708523829665, 68.74964158444733, 69.91398792247075, 71.08009982300052, 72.24795355004039, 73.41752603136773, 74.58879483061163, 75.76173812088773, 76.93633465988277, 78.11256376628985, 79.29040529750363, 80.46983962849211, 81.65084763176806, 82.83341065838876, 84.01751051991923, 85.20312947129779, 86.39025019454823, 87.57885578328656, 88.76892972797435, 89.96045590187391, 91.15341854766392, 92.34780226467697, 93.54359199672291, 94.74077302046506, 95.93933093431754, 97.13925164783525, 98.34052137156897, 99.54312660736029, 100.74705413905305, 101.95229102359822, 103.15882458253279, 104.36664239381173, 105.57573228397592, 106.78608232063822, 107.99768080527197, 109.21051626628662, 110.42457745237618, 111.63985332612747], [0.0, 0.7073838593584673, 1.5163104965738214, 2.368582555102577, 3.250282702386102, 4.154532406185834, 5.077167852770699, 6.015378928126556, 6.9671334923163455, 7.930889638087271, 8.905435164394058, 9.889790681551087, 10.88314753888402, 11.88482616023047, 12.894247004532112, 13.910909687456543, 14.934377574024932, 15.964266153255268, 17.000234096812008, 18.041976266215077, 19.089218163070164, 20.141711466831836, 21.199230405050354, 22.261568769809973, 23.328537442086127, 24.399962319894644, 25.475682570784254, 26.55554914732371, 27.639423517691217, 28.727176573600886, 29.81868768550993, 30.913843880980334, 32.01253912667414, 33.11467369807119, 34.2201536238507, 35.328890194149785, 36.44079952373552, 37.555802162599, 38.67382274767792, 39.79478969039284, 40.91863489548882, 42.04529350733965, 43.17470368042664, 44.30680637116647, 45.44154514865097, 46.57886602218897, 47.718717283818094, 48.86104936418874, 50.00581470042442, 51.15296761473368, 52.302464202697145, 53.4542622302799, 54.608321038729876, 55.764601456618124, 56.92306571835968, 58.083677388626384, 59.246401292125945, 60.411203448277035, 61.57805101035942, 62.74691220875995, 63.917756297974606, 65.09055350705886, 66.26527499324939, 67.44189279850633, 68.62037980874821, 69.80070971557377, 70.98285698028256, 72.16679680002363, 73.3525050759167, 74.53995838300304, 75.72913394189683, 76.92000959201677, 78.11256376628985, 79.30677546722623, 80.50262424427349, 81.70009017236545, 82.89915383158724, 84.0997962878847, 85.30199907475185, 86.50574417583437, 87.71101400839291, 88.91779140757285, 90.1260596114323, 91.33580224668242, 92.54700331509859, 93.7596471805627, 94.97371855670039, 96.18920249507953, 97.40608437393787, 98.62434988741077, 99.84398503523114, 101.06497611287611, 102.28730970213635, 103.51097266208511, 104.73595212042662, 105.9622354652034, 107.1898103368443, 108.41866462053574, 109.64878643889996, 110.88016414496482, 112.11278631541049, 113.34664174407999], [0.0, 0.7180503392163753, 1.5391745966745887, 2.404297871166908, 3.2992929738516534, 4.217177652671662, 5.153725308698391, 6.106083454849482, 7.072189309013301, 8.050477713869306, 9.039718189869168, 10.0389165793336, 11.047252038129205, 12.064034742919652, 13.088676413879202, 14.120669121494238, 15.159569646866682, 16.204987681061134, 17.256576748929938, 18.31402711087948, 19.37706012941678, 20.445423739627536, 21.518888764690747, 22.59724588732854, 23.680303136833718, 24.767883785978, 25.859824577154274, 26.955974215479067, 28.05619208024085, 29.160347116359343, 30.268316875346397, 31.37998668127837, 32.49524890196479, 33.61400230916222, 34.736151514577735, 35.861606470712694, 36.99028202744786, 38.12209753676578, 39.2569764992217, 40.39484624676835, 41.53563765735796, 42.67928489742111, 43.825725188884675, 44.974898597860594, 46.126747842531884, 47.28121811809409, 48.43825693689225, 49.59781398213185, 50.75984097374664, 51.92429154518017, 53.091121129988316, 54.26028685729882, 55.43174745527554, 56.605463161832496, 57.78139564192608, 58.95950791082813, 60.139764262846136, 61.32213020501335, 62.506572395321335, 63.69305858511019, 64.88155756527144, 66.07203911595128, 67.26447395947297, 68.45883371622371, 69.65509086327496, 70.85321869552713, 72.0531912891875, 73.25498346740858, 74.45857076792858, 75.66392941256917, 76.87103627845937, 78.07986887086352, 79.29040529750363, 80.50262424427349, 81.71650495225151, 82.93202719592594, 84.14917126255345, 85.36791793257763, 86.58824846104021, 87.81014455992242, 89.03358838135878, 90.25856250166974, 91.48504990616392, 92.71303397466339, 93.94249846770994, 95.173427513412, 96.40580559489545, 97.6396175383242, 98.87484850145778, 100.11148396271662, 101.34950971072685, 102.58891183431821, 103.82967671295125, 105.0717910075502, 106.31524165172087, 107.56001584333293, 108.80610103644808, 110.05348493357626, 111.30215547824344, 112.55210084785539, 113.80330944684269, 115.05576990007326], [0.0, 0.7287312433973051, 1.5620696159886158, 2.440061485194822, 3.348369522101714, 4.279907614572803, 5.23038629357741, 6.196910641663686, 7.177387193107894, 8.170227509080583, 9.17418280681228, 10.188244140659211, 11.21157845653966, 12.243485670086061, 13.283368750887782, 14.33071221404662, 15.385066247841788, 16.446034737543904, 17.513266054233142, 18.58644585098025, 19.66529134559625, 20.749546723734458, 21.838979399598852, 22.933376942344637, 24.03254452572564, 25.136302793719352, 26.244486060283254, 27.35694078004243, 28.47352424057079, 29.594103437361, 30.71855410051979, 31.84675984833427, 32.9786114475993, 34.114006164314674, 35.252847191299175, 36.395043141609484, 37.54050759852956, 38.68915871441332, 39.84091885189685, 40.99571426200525, 42.15347479450939, 43.3141336365742, 44.47762707631096, 45.64389428832294, 46.81287713873368, 47.98452000752447, 49.15876962629341, 50.33557492979028, 51.51488691978922, 52.69665854003735, 53.88084456117058, 55.06740147461806, 56.256287394630526, 57.447461967666214, 58.64088628845279, 59.836522822119136, 61.034335331855274, 62.23428881161612, 63.43634942343524, 64.64048443895817, 65.84666218484509, 67.05485199172581, 68.26502414642204, 69.47714984717793, 70.69120116166508, 71.907150987549, 73.12497301542398, 74.34464169394026, 75.56613219696312, 76.78942039261698, 78.01448281408113, 79.24129663201377, 80.46983962849211, 81.70009017236545, 82.93202719592594, 84.16563017281003, 85.40087909704992, 86.63775446320084, 87.87623724747574, 89.11630888982396, 90.35795127689539, 91.60114672583553, 92.84587796886171, 94.09212813857307, 95.33988075395156, 96.58911970701334, 97.83982925007284, 99.09199398358513, 100.34559884453336, 101.60062909533141, 102.85707031321309, 104.11490838008132, 105.3741294727929, 106.63472005385505, 107.89666686251273, 109.15995690620561, 110.42457745237618, 111.69051602061084, 112.9577603750971, 114.22629851738122, 115.4961186794112, 116.76720931685136], [0.0, 0.7394263986835935, 1.584995183215713, 2.4758728171895754, 3.397511551236903, 4.342721274565514, 5.307149564157516, 6.287859015578419, 7.282725438552457, 8.290137081677681, 9.308826834542211, 10.337770943806804, 11.376124129150162, 12.42317603148261, 13.47832085813306, 14.541035558737876, 15.610863719957022, 16.68740341352069, 17.77029784986042, 18.859228068563922, 19.953907137216135, 21.05407548703526, 22.159497118701804, 23.26995648364974, 24.385255896283883, 25.505213368279996, 26.629660781920006, 27.758442338334792, 28.891413230592825, 30.02843850215867, 31.169392059303714, 32.31415581224983, 33.46261892464107, 34.614677154711366, 35.770232274498056, 36.929191555825966, 38.09146731369229, 39.25697649922169, 40.42564033561281, 41.59738399152089, 42.77213628716358, 43.949829429133544, 45.13039877048055, 46.31378259310967, 47.49992190994809, 48.68876028467517, 49.8802436671003, 51.07432024251898, 52.27094029358748, 53.47005607343628, 54.67162168889681, 55.87559299284878, 57.08192748481068, 58.2905842189958, 59.50152371914224, 60.7147078995019, 61.930099991438695, 63.1476644751446, 64.36736701603348, 65.58917440541629, 66.81305450510236, 68.03897619560546, 69.26690932766458, 70.49682467681767, 71.7286939007901, 72.96248949948259, 74.19818477736186, 75.43575380807623, 76.67517140113252, 77.91641307048594, 79.15945500490729, 80.404274040002, 81.65084763176806, 82.89915383158724, 84.14917126255345, 85.40087909704992, 86.65425703549316, 87.90928528616855, 89.16594454608824, 90.42421598280676, 91.6840812171351, 92.94552230669802, 94.20852173028389, 95.473062372939, 96.73912751176321, 98.00670080236537, 99.27576626594052, 100.54630827693373, 101.81831155125721, 103.09176113503007, 104.36664239381172, 105.64294100230218, 106.9206429344842, 108.19973445418327, 109.48020210602411, 110.76203270676231, 112.0452133369722, 113.32973133307254, 114.61557427967311, 115.90273000222601, 117.1911865599665, 118.48093223912959], [0.0, 0.7501356361912553, 1.6079509363451336, 2.5117313016651788, 3.446718285270198, 4.405617640778156, 5.384013908292959, 6.378927140455221, 7.38820238198239, 8.410204538204548, 9.443648146935558, 10.487494627643532, 11.540886457669412, 12.603102989672763, 13.673529657184856, 14.751635834415234, 15.836958497712311, 16.92908989761122, 18.02766807709987, 19.132369456208426, 20.242902946831144, 21.3590052208077, 22.480436860800562, 23.606979196417395, 24.73843167894912, 25.874609684303845, 27.015342659886173, 28.16047255036563, 29.309852451547417, 30.463345452297794, 31.62082363265135, 32.78216719251576, 33.947263690273395, 35.11600737440706, 36.28829859430192, 37.464043278784956, 38.64315247289666, 39.825541924950784, 41.011131717208244, 42.19984593452927, 43.3916123662227, 44.58636223701781, 45.784029963671664, 46.98455293421574, 48.187871307257474, 49.39392782909945, 50.602667666733026, 51.81403825501256, 53.02798915652966, 54.24447193288879, 55.46344002624288, 56.68484865008143, 57.908654688381276, 59.134816602330964, 60.36329434392722, 61.594049275819614, 62.827044096845675, 64.06224277275803, 65.2996104716969, 66.53911350400617, 67.78071926603236, 69.02439618758045, 70.27011368273259, 71.51784210376388, 72.7675526979138, 74.01921756679438, 75.27280962823653, 76.52830258039276, 77.78567086793174, 79.0448896501732, 80.3059347710258, 81.56878273060119, 82.83341065838876, 84.0997962878847, 85.36791793257763, 86.63775446320084, 87.90928528616855, 89.18249032311941, 90.45734999149713, 91.73384518610271, 93.0119572615583, 94.29166801562617, 95.57295967333202, 96.85581487184339, 98.14021664605956, 99.42614841487077, 100.71359396804833, 102.00253745372977, 103.29296336646527, 104.58485653579437, 105.87820211532338, 107.17298557227659, 108.46919267749557, 109.76680949586247, 111.06582237712554, 112.36621794710521, 113.66798309926159, 114.97110498660464, 116.27557101392998, 117.58136883036362, 118.88848632220075, 120.19691160602392], [0.0, 0.7608587912066426, 1.6309365223054437, 2.547636387099474, 3.4959889673764124, 4.468595745831872, 5.46097814377011, 6.470113615618924, 7.493816401107395, 8.5304280319612, 9.57864467037035, 10.637412889341194, 11.705862907967022, 12.783263777286239, 13.86899214563022, 14.962509801936816, 16.063347103652273, 17.171090472551548, 18.285372777463426, 19.40586581285702, 20.53227432953528, 21.664331235073725, 22.801793689674817, 23.944439897062825, 25.092066441693955, 26.244486060283258, 27.401525762193696, 28.563025232700987, 29.72883546762151, 30.89881759868306, 32.0728418773101, 33.25078679087339, 34.43253829040747, 35.61798911268198, 36.80703818258105, 37.99959008418851, 39.19555459093771, 40.39484624676835, 41.5973839915209, 42.80309082485208, 44.01189350382216, 45.223722270021035, 46.438510602696276, 47.65619499484411, 48.876714749641955, 50.10001179495338, 51.326030513934384, 52.55471759002292, 53.78602186481012, 55.019894207475794, 56.25628739463054, 57.49515599954272, 58.73645628984756, 59.980146132938174, 61.2261849083269, 62.474533426344124, 63.72515385260895, 64.97800963776604, 66.23306545203579, 67.49028712416997, 68.74964158444733, 70.01109681137834, 71.27462178182083, 72.54018642423705, 73.80776157484702, 75.07731893645662, 76.34883103975832, 77.62227120692097, 78.89761351730091, 80.17483277512144, 81.45390447898104, 82.73480479306147, 84.01751051991923, 85.30199907475185, 86.58824846104021, 87.87623724747574, 89.16594454608824, 90.45734999149713, 91.7504337212143, 93.04517635693288, 94.34155898674013, 95.63956314819818, 96.93917081224025, 98.24036436783298, 99.5431266073603, 100.84744071268626, 102.15329024185768, 103.46065911641041, 104.76953160924494, 106.07989233303975, 107.39172622917263, 108.70501855712251, 110.01975488432578, 111.3359210764627, 112.6535032881518, 113.97248795403019, 115.29286178020061, 116.61461173602589, 117.93772504625373, 119.262189183455, 120.58799186076, 121.91512102487837], [0.0, 0.7715957030312759, 1.653951596631912, 2.5835875354145696, 3.54532285917923, 4.531654645929272, 5.538041117193762, 6.56141707453814, 7.59956591318319, 8.650805761264024, 9.713814381772591, 10.787523482206849, 11.871051007686242, 12.963655694411996, 14.064705394244996, 15.173654301120207, 16.29002614509027, 17.413401511692207, 18.543408088957715, 19.6797130398607, 20.822016948774504, 21.970048954181294, 23.12356278943281, 24.282333528359743, 25.44615488490567, 26.614836953206765, 27.788204301456556, 28.966094352638375, 30.14835599988568, 31.33484841527697, 32.525440019280644, 33.72000758453355, 34.91843545266028, 36.12061484677796, 37.32644326544216, 38.53582394626836, 39.74866538945144, 40.96488093301196, 42.184388372904294, 43.40710962218945, 44.63297040435487, 45.861899976589775, 47.09383087942951, 48.328698709686776, 49.566441914011584, 50.807001600778484, 52.0503213683025, 53.29634714764122, 54.54502705846033, 55.796311276626646, 57.05015191235461, 58.30650289787009, 59.565319883676025, 60.826560142608294, 62.0901824809604, 63.35614715603498, 64.62441579954861, 65.89495134637724, 67.16771796818256, 68.44268101150641, 69.71980693996187, 70.99906328018592, 72.28041857125118, 73.56384231726328, 74.84930494289554, 76.136777751636, 77.42623288654211, 78.71764329331661, 80.0109826855349, 81.30622551186832, 82.6033469251621, 83.9023227532372, 85.20312947129779, 86.50574417583437, 87.81014455992242, 89.11630888982396, 90.42421598280676, 91.73384518610271, 93.04517635693288, 94.35818984353203, 95.67286646711064, 96.98918750469689, 98.30713467280555, 99.62669011188395, 100.94783637148954, 102.27055639615607, 103.59483351190858, 104.92065141339057, 106.24799415156849, 107.57684612198153, 108.90719205350669, 110.23901699761102, 111.57230631806476, 112.90704568109075, 114.24322104592746, 115.58081865578343, 116.91982502916366, 118.2602269515482, 119.60201146740592, 120.94516587252598, 122.28967770665166, 123.63553474640177], [0.0, 0.7823462148343429, 1.6769958231503326, 2.6195842214829534, 3.594719240073467, 4.594793419988141, 5.61520170292845, 6.652836183570954, 7.705449373558745, 8.771335967792064, 9.849155306759332, 10.937824213620623, 12.036448343974632, 13.144276106120046, 14.26066654430516, 15.38506624784179, 16.516992310994336, 17.65601947566939, 18.801770242539263, 19.953907137216135, 21.11212657236631, 22.27615391260446, 23.44573946009097, 24.620655154798424, 25.800691836521846, 26.98565695347127, 28.175372629578693, 29.369674022669493, 30.568407920530834, 31.77143153310972, 32.978611447599306, 34.18982271973051, 35.404948079679464, 36.62387723499344, 37.846506256092816, 39.07273703241922, 40.302476789316295, 41.53563765735795, 42.77213628716359, 44.01189350382215, 45.25483399593905, 46.50088603505597, 47.74998122180696, 49.0020542556861, 50.257042725731, 51.51488691978922, 52.775529650340694, 54.03891609510961, 55.30499365092179, 56.57371179945285, 57.84502198367701, 59.118877493965655, 60.395233362907724, 61.67404626802878, 62.95527444167741, 64.238877587428, 65.52481680241837, 66.81305450510236, 68.10355436795156, 69.39628125468703, 70.69120116166508, 71.98828116307685, 73.2874893596552, 74.58879483061163, 75.89216758855149, 77.19757853713917, 78.50499943130609, 79.81440283981205, 81.12576210998817, 82.43905133450347, 83.754245320012, 85.07131955754787, 86.39025019454823, 87.71101400839291, 89.03358838135878, 90.35795127689539, 91.6840812171351, 93.0119572615583, 94.34155898674013, 95.67286646711064, 97.00586025666551, 98.34052137156894, 99.676831273595, 101.01477185435691, 102.35432542027806, 103.69547467826129, 105.03820272201598, 106.3824930190059, 107.72832939798228, 109.07569603707002, 110.42457745237618, 111.77495848709242, 113.1268243010649, 114.48016036080635, 115.83495242992771, 117.1911865599665, 118.54884908159231, 119.90792659616955, 121.26840596765986, 122.6302743148468, 123.99351900386702, 125.35812764103304], [0.0, 0.7931101735123912, 1.7000688736762715, 2.655625932657693, 3.6441774065803876, 4.658011168817402, 5.692458802091417, 6.744369640771799, 7.811465274294383, 8.892016935013954, 9.984665517872306, 11.088312943074115, 12.202052561325436, 13.325122440104154, 14.456872805029295, 15.59674263127757, 16.744242369025013, 17.898940909238494, 19.06045555874253, 20.22844419998711, 21.402599068713464, 22.582641750948373, 23.76831911336908, 24.95939995817022, 26.155672247403217, 27.356940780042425, 28.56302523270098, 29.773758495213023, 30.988985247386044, 32.20856073458128, 33.43234970842356, 34.660225505590354, 35.89206924279369, 37.127769110115324, 38.3672197480541, 39.61032169619147, 40.85698090342524, 42.10710829137241, 43.360619363884766, 44.61743385671837, 45.877475422302155, 47.14067134529737, 48.4069522852612, 49.676252043246656, 50.94850734960628, 52.2236576706343, 53.501645031992624, 54.78241385712978, 56.06591081912755, 57.352084704602106, 58.64088628845279, 59.93226821839371, 61.22618490832688, 62.52259243972295, 63.821448470267676, 65.12271214911459, 66.4263440381541, 67.73230603877201, 69.04056132362535, 70.35107427301055, 71.66381041544268, 72.97873637210111, 74.29581980483063, 75.61502936741722, 76.93633465988276, 78.25970618556795, 79.58511531079266, 80.9125342269023, 82.24193591452558, 83.57329410988395, 84.90658327300719, 86.24177855772132, 87.57885578328656, 88.91779140757285, 90.25856250166974, 91.60114672583553, 92.94552230669802, 94.29166801562617, 95.63956314819818, 96.98918750469689, 98.34052137156894, 99.69354550378826, 101.04824110806958, 102.40458982688077, 103.76257372320705, 105.12217526602313, 106.48337731643215, 107.84616311443393, 109.2105162662866, 110.57642073242883, 111.94386081593154, 113.31282115145054, 114.68328669465281, 116.05524271209119, 117.42867477150439, 118.80356873251914, 120.17991073773472, 121.55768720416957, 122.93688481505235, 124.3174905119396, 125.69949148714417, 127.08287517645928], [0.0, 0.8038874295557847, 1.7231704277288078, 2.6917121683252785, 3.6936966717341, 4.721307014332802, 5.769811341594115, 6.8360161747558355, 7.917612142846476, 9.012846986690677, 10.12034313289671, 11.238987580303336, 12.367861359523, 13.50619218443814, 14.653321451144336, 15.808680511276993, 16.971773162715937, 18.1421624382603, 19.31946044447053, 20.503320414898447, 21.693430403200207, 22.88950821214678, 24.09129726868821, 25.298563233364877, 26.511091186929583, 27.72868327584823, 28.951156726391773, 30.17834215760134, 31.410082138700613, 32.646229948038105, 33.88664849940272, 35.13120940829485, 36.37979217596919, 37.63228347316738, 38.88857650870025, 40.148570470621515, 41.41217002980627, 42.67928489742111, 43.94982942913355, 45.223722270021035, 46.50088603505597, 47.78124702080004, 49.064734944570944, 50.35128270787077, 51.64082618130621, 52.933304008603216, 54.228657427633685, 55.52683010663867, 56.82776799406186, 58.13141918060128, 59.43773377225613, 60.746663773289306, 62.058162978151614, 63.37218687152241, 64.68869253571475, 66.00763856477639, 67.32898498468907, 68.65269317913182, 69.97872582032967, 71.30704680455719, 72.63762119191027, 73.97041514999685, 75.30539590123155, 76.64253167344917, 77.9817916535785, 79.32314594414197, 80.66656552236785, 82.0120222017209, 83.35948859567445, 84.70893808356193, 86.0603447783608, 87.41368349627233, 88.76892972797435, 90.1260596114323, 91.48504990616392, 92.84587796886171, 94.20852173028389, 95.57295967333202, 96.93917081224025, 98.30713467280555, 99.676831273595, 101.04824110806958, 102.42134512756961, 103.7961247251098, 105.17256171993652, 106.55063834280237, 107.9303372219169, 109.31164136953501, 110.69453416914683, 112.07899936323588, 113.46502104157383, 114.85258363002296, 116.24167187981885, 117.63227085730745, 119.02436593411323, 120.4179427777151, 121.81298734240963, 123.20948586064162, 124.60742483468343, 126.00679102864567, 127.40757146080266, 128.80975339621764], [0.0, 0.8146778369215131, 1.7463001722578952, 2.727842439479745, 3.74327636449714, 4.784680098809907, 5.8472582732293095, 6.92777454361736, 8.023888540814735, 9.133824485449564, 10.256186313259974, 11.389846083510493, 12.53387249168593, 13.687482885438945, 14.850009820567134, 16.020877015861707, 17.199581608788588, 18.385680766830532, 19.578781389938115, 20.778532057092004, 21.984616634759963, 23.196749137840477, 24.414669549358962, 25.638140384367833, 26.866943838805252, 28.100879403391854, 29.339761851066303, 30.583419527305693, 31.831692888174395, 33.08443324260788, 34.34150166431644, 35.60276804552306, 36.86811027005378, 38.13741348745611, 39.41056947310578, 40.687476061879536, 41.96803664507023, 43.25215972191692, 44.53975849850174, 45.83075052789258, 47.12505738633935, 48.42260438109839, 49.72332028609813, 51.02713710219201, 52.33398983919171, 53.64381631725119, 54.95655698549098, 56.272154756023106, 57.59055485176887, 58.91170466665896, 60.23555363697619, 61.56205312274702, 62.89115629821515, 64.22281805054041, 65.556994885961, 66.89364484274154, 68.23272741030114, 69.57420345398029, 70.91803514496138, 72.26418589490645, 73.6126202949206, 74.9633040584869, 76.31620396805349, 77.67128782498428, 79.02852440261084, 80.38788340214822, 81.74933541125831, 83.1128518650641, 84.47840500943545, 85.84596786638237, 87.21551420140636, 88.58701849267204, 89.96045590187391, 91.33580224668242, 92.71303397466339, 94.09212813857307, 95.473062372939, 96.85581487184339, 98.24036436783298, 99.62669011188395, 101.01477185435691, 102.40458982688077, 103.7961247251098, 105.18935769230121, 106.58427030366501, 107.980844551441, 109.37906283066097, 110.778907925557, 112.18036299657936, 113.58341156799048, 114.98803751600244, 116.39422505742922, 117.80195873882556, 119.21122342608618, 120.62200429448204, 122.0342868191097, 123.44805676573328, 124.86330018199867, 126.28000338900115, 127.69815297318884, 129.11773577858517, 130.53873889931506], [0.0, 0.8254812529119842, 1.7694578013845494, 2.7640162683168246, 3.792915829203551, 4.848129584172243, 5.924798572801134, 7.019643533899104, 8.130293062748411, 9.254947831425365, 10.392193262505849, 11.540886457669409, 12.70008376240232, 13.868992145630218, 15.046935312195089, 16.233329338841994, 17.42766469459334, 18.62949267454444, 19.838414965759046, 21.05407548703526, 22.27615391260446, 23.504360464926126, 24.738431678949116, 25.978126920445785, 27.22322549706178, 28.47352424057079, 29.728835467621504, 30.988985247386047, 32.2538119202219, 33.52316482327723, 34.796903187965356, 36.074895181154325, 37.35701706729163, 38.64315247289666, 39.933191738182, 41.22703134321606, 42.52457339816679, 43.82572518888467, 45.130398770480554, 46.438510602696276, 47.74998122180696, 49.064734944570944, 50.38269960039007, 51.70380628838332, 53.02798915652964, 54.3551852004181, 55.68533407946695, 57.01837794874763, 58.35426130478441, 59.69293084390062, 61.03433533185527, 62.37842548366174, 63.725153852608926, 65.07447472761676, 66.4263440381541, 67.78071926603236, 69.1375593634612, 70.49682467681765, 71.85847687563741, 73.22247888638576, 74.58879483061162, 75.95738996712568, 77.32823063787923, 78.70128421725111, 80.0765190644771, 81.45390447898103, 82.83341065838874, 84.21500865902533, 85.59867035871406, 86.9843684217107, 88.37207626562194, 89.76176803016817, 91.15341854766392, 92.54700331509859, 93.94249846770994, 95.33988075395156, 96.73912751176321, 98.14021664605956, 99.5431266073603, 100.94783637148954, 102.35432542027806, 103.76257372320705, 105.17256171993652, 106.58427030366501, 107.99768080527195, 109.41277497819692, 110.82953498401274, 112.24794337865376, 113.66798309926156, 115.08963745161434, 116.51289009810716, 117.93772504625372, 119.36412663768108, 120.79207953759112, 122.22156872466455, 123.65257948138364, 125.08509738475283, 126.51910829739626, 127.95459835901372, 129.39155397817663, 130.82996182444748, 132.26980882080682], [0.0, 0.8362975380594474, 1.7926430161531028, 2.800233187846952, 3.842614425027831, 4.911654651312503, 6.00243123929554, 7.111621959609391, 8.236824335007972, 9.376215460964454, 10.528362224839382, 11.692106752909668, 12.866493025951591, 14.05071762180049, 15.244095383799392, 16.446034737543904, 17.65601947566939, 18.873595013888462, 20.098357820168403, 21.329947147573467, 22.56803847310483, 23.812338222265346, 25.062579477819945, 26.318518452509437, 27.579931562246408, 28.846612976690224, 30.118372553273648, 31.395034082152254, 32.676433785456396, 33.962419026198106, 35.25284719129918, 36.54758472021745, 37.846506256092816, 39.149493900602366, 40.456436557085915, 41.76722934918965, 43.08177310443055, 44.399973893825134, 45.721742620141896, 47.04699464849424, 48.37564947394369, 49.70763042157067, 51.042864375125305, 52.38128153091798, 53.72281517406825, 55.067401474618066, 56.41497930134274, 57.76549005137129, 59.11887749396567, 60.47508762701084, 61.83406854494331, 63.195770316994995, 64.56014487476031, 65.92714590820667, 67.29672876934652, 68.66885038287522, 70.04346916315303, 71.42054493697538, 72.80003887163366, 74.18191340781843, 75.56613219696311, 76.95266004266439, 78.34146284585196, 79.732507553411, 81.12576210998817, 82.5211954127375, 83.91877726878418, 85.31847835520416, 86.72027018133569, 88.12412505325415, 89.53001604025697, 90.93791694321716, 92.34780226467697, 93.7596471805627, 95.173427513412, 96.58911970701334, 98.00670080236537, 99.42614841487077, 100.84744071268626, 102.27055639615607, 103.69547467826129, 105.12217526602313, 106.55063834280237, 107.980844551441, 109.41277497819692, 110.84641113742487, 112.2817349569607, 113.71872876416909, 115.15737527261689, 116.59765756933778, 118.03955910265518, 119.48306367053307, 120.92815540942682, 122.37481878360639, 123.823038574928, 125.27279987303028, 126.72408806593303, 128.17688883101832, 129.6311881263743, 131.0869721824839, 132.54422749424077, 134.0029408132772], [0.0, 0.8471265560157232, 1.8158555242948335, 2.836492741526038, 3.8923715254782603, 4.975254499444913, 6.080155294088849, 7.203708661284436, 8.343481014679018, 9.497625845388518, 10.664691483738691, 11.843505062974945, 13.033098184607962, 14.23265702315052, 15.441487550015012, 16.65899053064076, 17.88464307341671, 19.11798470775164, 20.35860667637248, 21.606143561117214, 22.86026663681587, 24.12067852754494, 25.387108859821556, 26.659310689643274, 27.937057537785503, 29.22014090865947, 30.508368197587046, 31.80156091302444, 33.099553156381305, 34.40219031420962, 35.70932792676834, 37.0208307040716, 38.33657166604312, 39.65643138772264, 40.98029733388575, 42.308063270159664, 43.639628739900466, 44.97489859786059, 46.31378259310968, 47.65619499484411, 49.0020542556861, 50.35128270787077, 51.703806288383326, 53.059554289662756, 54.41845913295351, 55.78045616177858, 57.14548345333958, 58.51348164593091, 59.884393780696044, 61.25816515625941, 62.6347431949447, 64.01407731944222, 65.39611883892, 66.78082084368786, 68.16813810762208, 69.55802699764617, 70.95044538963778, 72.34535259019907, 73.74270926378594, 75.1424773647424, 76.5446200738329, 77.94910173890428, 79.35588781934547, 80.76494483404474, 82.17624031257158, 83.58974274933668, 85.00542156050489, 86.42324704345654, 87.84319033861112, 89.26522339344194, 90.6893189285272, 92.11545040549362, 93.54359199672291, 94.97371855670039, 96.40580559489545, 97.83982925007284, 99.27576626594052, 100.71359396804833, 102.15329024185768, 103.59483351190858, 105.03820272201598, 106.48337731643215, 107.9303372219169, 109.37906283066097, 110.82953498401274, 112.2817349569607, 113.73564444332857, 115.19124554164225, 116.6485207416307, 118.10745291132564, 119.56802528472667, 121.03022145000159, 122.49402533819243, 123.95942121240066, 125.42639365742642, 126.89492756983758, 128.36500814844692, 129.83662088517627, 131.3097515562885, 132.78438621396828, 134.26051117823482, 135.7381130291705], [0.0, 0.8579681734469374, 1.839095040002326, 2.8727944829030023, 3.942186517913232, 5.038928345486999, 6.1579697801922215, 7.295902505093201, 8.450261788535515, 9.619177489814364, 10.801179360629753, 11.995079523751311, 13.199897187020948, 14.4148081095247, 15.63910938042191, 16.872194096083085, 18.113532672873678, 19.362658747049963, 20.619158330019022, 21.8826613269576, 23.15283480563539, 24.429377584279614, 25.71201582913827, 27.000499435792825, 28.294599026513037, 29.594103437361, 30.898817598683053, 32.20856073458128, 33.523164823277234, 34.8424732725632, 36.16633977388674, 37.49462730580609, 38.8272072631402, 40.16395869251523, 41.50476761846877, 42.84952644702903, 44.19813343589708, 45.550492222146175, 46.90651139980477, 48.266104140877125, 49.629187854333296, 50.99568387840793, 52.36551720221974, 53.73861621328469, 55.11491246796701, 56.49434048230907, 57.87683754101782, 59.262343522670115, 60.650800739443824, 62.04215378988923, 63.43634942343523, 64.83333641547826, 66.23306545203577, 67.63548902306233, 69.04056132362535, 70.44823816222753, 71.85847687563741, 73.27123624965866, 74.68647644532662, 76.10415893007287, 77.5242464134453, 78.94670278701061, 80.37149306810328, 81.79858334711666, 83.22794073806017, 84.65953333213255, 86.0933301540834, 87.52930112115574, 88.967417004421, 90.4076493923332, 91.84997065634556, 93.29435391844382, 94.74077302046506, 96.18920249507953, 97.6396175383242, 99.09199398358513, 100.54630827693373, 102.00253745372977, 103.46065911641041, 104.92065141339057, 106.3824930190059, 107.84616311443393, 109.31164136953501, 110.778907925557, 112.24794337865376, 113.71872876416909, 115.19124554164225, 116.66547558049416, 118.14140114635542, 119.61900488800097, 121.09826982485734, 122.57917933505188, 124.06171714397439, 125.54586731332378, 127.03161423061484, 128.51894259912004, 130.00783742822495, 131.4982840241755, 132.99026798119755, 134.48377517297018, 135.97879174443474, 137.475304103924], [0.0, 0.868822259932977, 1.8623612837139483, 2.9091379752831137, 3.992058803079269, 5.102675423469089, 6.235873761530008, 7.388202381982389, 8.557165372049516, 9.740868932026663, 10.937824213620623, 12.14682831186154, 13.366888026668473, 14.59716868972182, 15.836958497712311, 17.08564286912135, 18.342685520594358, 19.607614188457312, 20.880009646780845, 22.159497118701804, 23.445739460090966, 24.738431678949116, 26.037296477275444, 27.342080586600495, 28.652551727354776, 29.968496064182354, 31.289716059619042, 32.61602865078555, 33.947263690273395, 35.28326260483942, 36.62387723499344, 37.96896882584642, 39.31840714524349, 40.672069709639395, 42.02984110167729, 43.391612366222695, 44.757280473843025, 46.12674784253188, 47.49992190994809, 48.87671474964195, 50.25704272573099, 51.6408261813062, 53.02798915652964, 54.41845913295351, 55.812166801067065, 57.209045848480415, 58.60903276649436, 60.01206667309445, 61.41808915065456, 62.827044096845675, 64.238877587428, 65.6535377497596, 67.07097464599072, 68.49114016503013, 69.91398792247075, 71.33947316775215, 72.7675526979138, 74.19818477736186, 75.63132906313211, 77.06694653518373, 78.50499943130608, 79.94545118626097, 81.38826637481998, 82.83341065838876, 84.2808507349387, 85.73055429199285, 87.1824899624354, 88.63662728293485, 90.09293665478978, 91.55138930702203, 93.0119572615583, 94.47461330035271, 95.93933093431754, 97.40608437393787, 98.87484850145778, 100.34559884453336, 101.81831155125721, 103.29296336646527, 104.76953160924494, 106.24799415156849, 107.72832939798228, 109.2105162662866, 110.69453416914683, 112.18036299657936, 113.66798309926156, 115.15737527261689, 116.6485207416307, 118.14140114635542, 119.63599852806558, 121.13229531602715, 122.6302743148468, 124.1299186923699, 125.63121196809745, 127.13413800209422, 128.63868098436265, 130.1448254246576, 131.65255614271956, 133.16185825890494, 134.67271718519333, 136.18511861655284, 137.69904852264557, 139.21449313985727], [0.0, 0.879688687871406, 1.8856539819078906, 2.9455227914062636, 4.041987794669538, 5.1664949839699865, 6.313866322250118, 7.480607206859384, 8.664190508444813, 9.862698741400695, 11.074624436291806, 12.29874964332178, 13.534068740378602, 14.779736619880733, 16.035032575939262, 17.299334340416486, 18.57209892261997, 19.852848152237, 21.14115756004673, 22.436647681822475, 23.738977156747026, 25.047837178262387, 26.362946980179974, 27.684050126381777, 29.010911432159563, 30.343314387701888, 31.68105898492805, 33.02395987137702, 34.37184477159336, 35.72455312904598, 37.081934931202355, 38.443849687755204, 39.81016553772593, 41.18075846565797, 42.5555116106606, 43.934314654888944, 45.317063280313235, 46.703658684461296, 48.09400714730754, 49.48801964269925, 50.88561148871346, 52.28670203216595, 53.69121436318316, 55.09907505632338, 56.51021393521641, 57.92456385809811, 59.34206052196102, 60.76264228333456, 62.18624999395878, 63.61282684982847, 65.04231825226915, 66.47467167986369, 67.90983657018576, 69.34776421041492, 70.7884076360107, 72.2317215367139, 73.67766216922122, 75.12618727594844, 76.57725600935876, 78.03082886138465, 79.48686759752053, 80.94533519520395, 82.40619578614039, 83.86941460225998, 85.33495792502306, 86.802793037818, 88.27288818121804, 89.74521251088436, 91.21973605792229, 92.69642969151283, 94.17526508365867, 95.65621467589577, 97.13925164783525, 98.62434988741077, 100.11148396271662, 101.60062909533141, 103.09176113503007, 104.58485653579437, 106.07989233303975, 107.57684612198153, 109.07569603707002, 110.57642073242883, 112.07899936323588, 113.58341156799048, 115.08963745161434, 116.59765756933778, 118.10745291132564, 119.61900488800097, 121.13229531602715, 122.6473064049116, 124.16402074419688, 125.68242129120725, 127.20249135932085, 128.724214606739, 130.24757502572731, 131.77255693230285, 133.2991449563455, 134.82732403211074, 136.3570793891247, 137.88839654344127, 139.42126128924411, 140.9556596907763], [0.0, 0.890567332385593, 1.908972866905234, 2.9819485131393466, 4.091972918901714, 5.23038629357741, 6.391946566064617, 7.573115917810985, 8.771335967792066, 9.984665517872306, 11.211578456539659, 12.450841772257101, 13.70143740691609, 14.962509801936815, 16.233329338841994, 17.513266054233146, 18.801770242539263, 20.098357820168403, 21.40259906871347, 22.714109831314484, 24.032544525725637, 25.357590526541646, 26.688963595487024, 28.026404125234, 29.369674022669496, 30.718554100519793, 32.07284187731009, 33.43234970842356, 34.79690318796536, 36.16633977388674, 37.540507598529565, 38.91926443421727, 40.302476789316295, 41.690019114736565, 43.08177310443055, 44.47762707631096, 45.87747542230216, 47.28121811809408, 48.68876028467517, 50.10001179495338, 51.51488691978921, 52.93330400860321, 54.3551852004181, 55.780456161778574, 57.209045848480415, 58.640886288452805, 60.075912383487, 61.51406172780027, 62.95527444167742, 64.39949301864816, 65.84666218484509, 67.29672876934652, 68.74964158444733, 70.20535131492143, 71.66381041544271, 73.12497301542398, 74.58879483061163, 76.0552330808443, 77.52424641344531, 78.99579483177173, 80.46983962849211, 81.94634332320555, 83.4252696040533, 84.9065832730072, 86.39025019454823, 87.87623724747574, 89.36451227961092, 90.85504406517938, 92.34780226467699, 93.84275738703926, 95.33988075395159, 96.83914446614895, 98.34052137156897, 99.84398503523114, 101.34950971072685, 102.85707031321309, 104.36664239381172, 105.87820211532338, 107.39172622917263, 108.90719205350669, 110.42457745237618, 111.94386081593154, 113.46502104157383, 114.98803751600244, 116.51289009810716, 118.03955910265518, 119.56802528472667, 121.09826982485734, 122.6302743148468, 124.16402074419688, 125.6994914871442, 127.23666929025529, 128.77553726055368, 130.3160788541503, 131.85827786535154, 133.40211841621903, 134.9475849465584, 136.49466220431518, 138.04333523635674, 139.5935893796218, 141.14541025261806, 142.69878374725252], [0.0, 0.9014580712368239, 1.9323176766815582, 3.0184147311819767, 4.142013614114159, 5.294348634371811, 6.470113615618923, 7.665727475356044, 8.878600546143195, 10.106767890952566, 11.348684735469943, 12.603102989672763, 13.86899214563022, 15.145486182145335, 16.43184655824389, 17.727435606711403, 19.031696899633033, 20.344140433563517, 21.664331235073725, 22.99188044945334, 24.326438268334794, 25.66768824321989, 27.015342659886173, 28.36913873627049, 29.728835467621508, 31.09421098622657, 32.46506033446698, 33.84119357302179, 35.222434163188254, 36.608617575192554, 37.999590084188505, 39.39520772319874, 40.79533536812187, 42.199845934529264, 43.60861966960995, 45.02154352551752, 46.43851060269627, 47.85941965363985, 49.28417463906223, 50.71268432970808, 52.14486194805715, 53.58062484502583, 55.01989420747578, 56.46259479292862, 57.908654688381276, 59.35800509053316, 60.81058010509022, 62.26631656311002, 63.72515385260893, 65.18703376387066, 66.65190034708421, 68.11969978110122, 69.5903802522427, 71.0638918422071, 72.54018642423704, 74.01921756679437, 75.5009404440738, 76.9853117527558, 78.47228963446224, 79.96183360343166, 81.45390447898102, 82.94846432236199, 84.44547637765847, 85.94490501640597, 87.44671568564256, 88.95087485912876, 90.4573499914971, 91.96610947511351, 93.47712259945234, 94.99035951280322, 96.50579118614472, 98.02338937903197, 99.54312660736029, 101.06497611287611, 102.58891183431821, 104.11490838008132, 105.64294100230218, 107.17298557227659, 108.70501855712251, 110.23901699761102, 111.77495848709242, 113.31282115145054, 114.85258363002296, 116.39422505742922, 117.93772504625372, 119.48306367053307, 121.03022145000159, 122.57917933505188, 124.1299186923699, 125.68242129120725, 127.23666929025529, 128.7926452250885, 130.35033199614634, 131.9097128572247, 133.47077140445072, 135.03349156571488, 136.59785759053736, 138.16385404034642, 139.73146577914778, 141.3006779645657, 142.8714760392368, 144.44384572254032], [0.0, 0.9123607847401829, 1.955688154686631, 3.054921044784831, 4.1921093303794095, 5.358381303432347, 6.548366611888057, 7.758440861730149, 8.985983064702882, 10.22900451878465, 11.485941766338845, 12.755531622278163, 14.036731115160638, 15.3286637496682, 16.63058205251917, 17.941840644212526, 19.2618763670982, 20.590193291368564, 21.92635118279443, 23.269956483649743, 24.62065515479842, 25.978126920445785, 27.3420805866005, 28.712250192973336, 30.088391819973282, 31.470280916501526, 32.857710046072896, 34.250486972139235, 35.64843302084481, 37.05138167250519, 38.45917734304411, 39.87167432427099, 41.28873585782167, 42.71023332224083, 44.13604551636328, 45.56605802508184, 47.00016265594067, 48.438256936892245, 49.8802436671003, 51.32603051393438, 52.77552965034069, 54.22865742763367, 55.68533407946695, 57.14548345333958, 58.60903276649436, 60.075912383487, 61.54605561306278, 63.019398522280476, 64.4958797660829, 65.97544043073444, 67.45802388973735, 68.94357567100167, 70.43204333418618, 71.92337635725087, 73.41752603136774, 74.9144453634309, 76.41408898548795, 77.91641307048596, 79.4213752537893, 80.92893455998015, 82.43905133450349, 83.95168717975956, 85.46680489528669, 86.98436842171073, 88.50434278816788, 90.02669406293448, 91.55138930702205, 93.07839653051701, 94.60768465146425, 96.13922345711096, 97.67298356734324, 99.20893640016129, 100.74705413905305, 102.28730970213635, 103.82967671295125, 105.3741294727929, 106.9206429344842, 108.46919267749557, 110.01975488432578, 111.57230631806476, 113.1268243010649, 114.68328669465281, 116.24167187981885, 117.80195873882556, 119.36412663768108, 120.92815540942682, 122.49402533819243, 124.06171714397439, 125.63121196809745, 127.20249135932085, 128.77553726055368, 130.35033199614634, 131.9268582597271, 133.50509910255442, 135.0850379223582, 136.6666584526443, 138.24994475243824, 139.83488119644593, 141.4214524656104, 143.0096435380442, 144.5994396803196, 146.1908264390983], [0.0, 0.9232753556840018, 1.9790840496717406, 3.091467061479931, 4.242259529134062, 5.422483612363786, 6.626704713598491, 7.851255080200633, 9.093482369035197, 10.351374087240744, 11.623348073538883, 12.90812603136067, 14.204652512198061, 15.512040535220576, 16.829533685124588, 18.156478861734904, 19.492306170347174, 20.8365137483461, 22.18865609498095, 23.548334944395073, 24.915192022082643, 26.28890322079004, 27.669173862972574, 29.0557348066584, 30.448339214246744, 31.84675984833427, 33.250786790873384, 34.660225505590354, 36.074895181154325, 37.49462730580609, 38.91926443421727, 40.34865911509036, 41.78267295402109, 43.22117579085582, 44.66404497449996, 46.11116472109854, 47.56242554388952, 49.017723744952384, 50.4769609606374, 51.940043753738934, 53.40688324652829, 54.877394789630785, 56.35149766245531, 57.82911480148868, 59.31017255327364, 60.794600449317166, 62.28233100053715, 63.773299509162655, 65.26744389626566, 66.7647045433256, 68.26502414642204, 69.76834758181542, 71.27462178182081, 72.7837956200031, 74.29581980483064, 75.81064678101907, 77.32823063787923, 78.8485270240552, 80.37149306810328, 81.89708730441679, 83.42526960405328, 84.9560011100626, 86.48924417695395, 88.02496231397497, 89.56312013190544, 91.10368329309652, 92.6466184645107, 94.19189327353905, 95.73947626639311, 97.2893368688849, 98.84144534942631, 100.39577278409108, 101.95229102359822, 103.51097266208511, 105.0717910075502, 106.63472005385505, 108.19973445418327, 109.76680949586247, 111.3359210764627, 112.90704568109075, 114.48016036080635, 116.05524271209119, 117.63227085730745, 119.21122342608618, 120.79207953759112, 122.37481878360639, 123.95942121240066, 125.54586731332378, 127.13413800209422, 128.724214606739, 130.3160788541503, 131.9097128572247, 133.50509910255442, 135.10222043864007, 136.7010600645987, 138.30160151934004, 139.9038286711878, 141.50772570792253, 143.11327712722533, 144.72046772750204, 146.32928259906882, 147.9397071156822], [0.0, 0.9342016692526901, 2.002505115524281, 3.1280523968222536, 4.292463682824198, 5.48665488684329, 6.705127096674275, 7.9441691544103525, 9.20109732830356, 10.473875309056845, 11.760902211627414, 13.060884611706731, 14.372754570297023, 15.695614609774378, 17.0286993631928, 18.3713480013965, 19.722983885378685, 21.083099213333465, 22.451243212322492, 23.8270129032932, 25.210045771813324, 26.600013875048163, 27.99661904815183, 29.399588964046803, 30.808673863983145, 32.2236438213629, 33.64428643390623, 35.070404863139615, 36.501816157957435, 37.938349812382505, 39.37984651783187, 40.82615707802579, 42.27714146075965, 43.7326679655261, 45.192612489741215, 46.65685787932965, 48.125293351830656, 49.597813982131846, 51.07432024251898, 52.55471759002291, 54.03891609510961, 55.52683010663866, 57.01837794874763, 58.5134816459309, 60.01206667309446, 61.51406172780027, 63.019398522280476, 64.52801159311161, 66.03983812670523, 67.5548177989976, 69.0728926279167, 70.59400683737239, 72.11810673166104, 73.64514057930218, 75.1750585054336, 76.70781239198767, 78.24335578495453, 79.78164380811121, 81.32263308266066, 82.86628165227997, 84.4125489131289, 85.96139554841267, 87.51278346713259, 89.06667574669399, 90.62303657907012, 92.18183122025026, 93.74302594272388, 95.306587990775, 96.87248553838177, 98.4406876495322, 100.01116424078576, 101.58388604592193, 103.15882458253279, 104.73595212042662, 106.31524165172087, 107.89666686251273, 109.48020210602411, 111.06582237712554, 112.6535032881518, 114.24322104592746, 115.83495242992771, 117.42867477150439, 119.02436593411323, 120.62200429448204, 122.22156872466455, 123.823038574928, 125.42639365742642, 127.03161423061484, 128.63868098436265, 130.24757502572731, 131.85827786535154, 133.47077140445072, 135.0850379223582, 136.7010600645987, 138.3188208314626, 139.93830356705428, 141.55949194879037, 143.18236997732495, 144.8069219668801, 146.43313253596153, 148.06098659843977, 149.69046935498005], [0.0, 0.9451396129527676, 2.0259511111091992, 3.1646766741420573, 4.342721274565514, 5.550894466185997, 6.783632953706146, 8.037182127748691, 9.308826834542213, 10.59650692300348, 11.898602764395429, 13.213805790567754, 14.541035558737878, 15.879384083315523, 17.228077036184057, 18.586445850980255, 19.953907137216138, 21.32994714757347, 22.714109831314484, 24.10598749117391, 25.505213368279996, 26.91145568013432, 28.32441277087785, 29.74380912493712, 31.169392059303718, 32.600928955322644, 34.03820492383756, 35.48102082172466, 36.92919155582597, 38.382544623823634, 39.84091885189685, 41.30416329692624, 42.77213628716359, 44.24470458010821, 45.721742620141896, 47.20313188151042, 48.68876028467517, 50.17852167602565, 51.67231536254407, 53.17004569432076, 54.67162168889681, 56.1769566922998, 57.68596807237911, 59.19857694066602, 60.71470789950192, 62.23428881161613, 63.75725058970491, 65.28352700387727, 66.81305450510239, 68.34577206302232, 69.88162101669171, 71.42054493697539, 72.96248949948257, 74.50740236704345, 76.05523308084432, 77.60593295943522, 79.1594550049073, 80.71575381561186, 82.27478550485849, 83.83650762508566, 85.40087909704994, 86.96786014362236, 88.53741222782223, 90.10949799475281, 91.6840812171351, 93.26112674416397, 94.84060045343594, 96.42246920572026, 98.0067008023654, 99.59326394515028, 101.18212819840745, 102.77326395325774, 104.36664239381173, 105.9622354652034, 107.56001584333293, 109.15995690620561, 110.76203270676231, 112.36621794710521, 113.97248795403019, 115.58081865578343, 117.1911865599665, 118.80356873251914, 120.4179427777151, 122.0342868191097, 123.65257948138364, 125.27279987303028, 126.89492756983758, 128.51894259912004, 130.1448254246576, 131.77255693230285, 133.40211841621903, 135.03349156571488, 136.6666584526443, 138.30160151934004, 139.93830356705428, 141.57674774487856, 143.21691753911932, 144.858796763105, 146.50236954740336, 148.14762033042842, 149.79453384941735, 151.44309513175983], [0.0, 0.9560890765419368, 2.0494218001169573, 3.2013395243073943, 4.393031797817429, 5.6152017029284504, 6.86222149344245, 8.130293062748413, 9.416669801957646, 10.719267693090474, 12.03644834397463, 13.366888026668471, 14.70949378143558, 16.063347103652273, 17.42766469459334, 18.801770242539263, 20.185073598410195, 21.5770550631137, 22.977253302554004, 24.385255896283883, 25.800691836521843, 27.223225497061776, 28.652551727354776, 30.088391819973282, 31.530490164570566, 32.978611447599306, 34.432538290407464, 35.892069242793696, 37.35701706729163, 38.8272072631402, 40.302476789316295, 41.782672954021095, 43.26765244423602, 44.75728047384303, 46.25143003265926, 47.74998122180697, 49.25282066330357, 50.759840973746634, 52.27094029358748, 53.78602186481011, 55.30499365092178, 56.82776799406185, 58.35426130478441, 59.88439378069604, 61.41808915065456, 62.95527444167742, 64.4958797660829, 66.03983812670523, 67.58708523829667, 69.13755936346121, 70.69120116166509, 72.24795355004038, 73.80776157484702, 75.37057229258787, 76.93633465988277, 78.50499943130609, 80.07651906447711, 81.65084763176806, 83.22794073806018, 84.80775544403605, 86.39025019454823, 87.97538475164886, 89.56312013190544, 91.15341854766395, 92.7462433519515, 94.34155898674014, 95.93933093431754, 97.53952567153426, 99.14211062671664, 100.74705413905303, 102.35432542027809, 103.96389451849308, 105.57573228397592, 107.1898103368443, 108.80610103644808, 110.42457745237618, 112.0452133369722, 113.66798309926159, 115.29286178020061, 116.91982502916366, 118.54884908159231, 120.17991073773472, 121.81298734240963, 123.44805676573328, 125.08509738475283, 126.72408806593303, 128.36500814844692, 130.00783742822495, 131.65255614271956, 133.2991449563455, 134.9475849465584, 136.59785759053736, 138.24994475243824, 139.9038286711878, 141.55949194879037, 143.21691753911932, 144.87608873716962, 146.53698916874671, 148.19960278057067, 149.86391383077412, 151.52990687977487, 153.19756678150452], [0.0, 0.9670499519610372, 2.0729169509176737, 3.2380405854962637, 4.443394756070421, 5.679575962428966, 6.9408919403007525, 8.223501040507012, 9.524625166258406, 10.842156407804074, 12.174437589980785, 13.520129809255609, 14.87812757589278, 16.247501855271985, 17.62746036871002, 19.017319051058656, 20.41648098760218, 21.824420521270866, 23.240671029104465, 24.664815362551174, 26.09647826049142, 27.53532024900541, 28.98103267921208, 30.433333648503147, 31.89196461614262, 33.35668757088215, 34.8272826419794, 36.303546069750965, 37.78528847018725, 39.272333342001126, 40.7645157750211, 42.26168132694643, 43.76368504177758, 45.27039058817034, 46.78166949986122, 48.29740050341786, 49.817468921060424, 51.341766138312806, 52.87018912787966, 54.40264002248376, 55.939025730499985, 57.479257589133205, 59.02325105064447, 60.57092539776317, 62.1222034849532, 63.677011502649094, 65.235278761957, 66.79693749763672, 68.36192268745624, 69.93017188624461, 71.50162507317141, 73.07622451095456, 74.65391461584882, 76.23464183739782, 77.81835454704567, 79.40500293480324, 80.99453891325054, 82.58691602823248, 84.18208937567212, 85.78001552398356, 87.38065244161942, 88.98395942933261, 90.58989705677357, 92.1984271030799, 93.80951250114748, 95.42311728530105, 97.0392065421075, 98.6577463640985, 100.27870380618954, 101.90204684460048, 103.52774433810055, 105.15576599141406, 106.78608232063822, 108.41866462053574, 110.05348493357626, 111.69051602061084, 113.32973133307254, 114.97110498660464, 116.61461173602589, 118.2602269515482, 119.90792659616955, 121.55768720416957, 123.20948586064162, 124.86330018199867, 126.51910829739626, 128.17688883101832, 129.83662088517627, 131.4982840241755, 133.16185825890494, 134.82732403211074, 136.49466220431518, 138.16385404034642, 139.83488119644593, 141.50772570792253, 143.18236997732495, 144.858796763105, 146.53698916874671, 148.21693063233715, 149.89860491655705, 151.58199609906984, 153.26708856328952, 154.95386698950895], [0.0, 0.9780221332687382, 2.096436336421135, 3.2747795029779443, 4.493809662545963, 5.744016622484076, 7.019643533899105, 8.31680516013138, 9.632691884011876, 10.965171879374743, 12.312569168691564, 13.673529657184854, 15.04693531219509, 16.43184655824389, 17.827462127427438, 19.233090193171304, 20.648127068145318, 22.072041131156947, 23.504360464926126, 24.94466318791954, 26.39256978129233, 27.84773691944217, 29.309852451547414, 30.778631276523285, 32.25381192022191, 33.73515367091129, 35.222434163188254, 36.71544732550517, 38.21400162509508, 39.71791855808133, 41.22703134321607, 42.741183785890996, 44.26022928543094, 45.784029963671664, 47.312455896767126, 48.845384435312525, 50.38269960039007, 51.924291545180154, 53.47005607343628, 55.01989420747579, 56.573711799452845, 58.13141918060126, 59.69293084390061, 61.2581651562594, 62.82704409684567, 64.39949301864816, 65.97544043073444, 67.55481779899759, 69.13755936346121, 70.72360197044928, 72.31288491813308, 73.90534981414135, 75.5009404440738, 77.0996026498888, 78.70128421725111, 80.30593477102579, 81.91350567819138, 83.52394995752236, 85.13722219545865, 86.75327846763808, 88.37207626562193, 89.9935744283881, 91.61773307820893, 93.24451356056684, 94.87387838779313, 96.50579118614472, 98.14021664605956, 99.77712047535401, 101.41646935514754, 103.05823089831712, 104.70237361030254, 106.34886685209688, 107.99768080527197, 109.64878643889996, 111.30215547824344, 112.9577603750971, 114.61557427967311, 116.27557101392998, 117.93772504625373, 119.60201146740592, 121.26840596765986, 122.93688481505235, 124.60742483468343, 126.28000338900115, 127.95459835901372, 129.6311881263743, 131.3097515562885, 132.99026798119755, 134.67271718519333, 136.3570793891247, 138.04333523635674, 139.73146577914778, 141.4214524656104, 143.11327712722533, 144.8069219668801, 146.50236954740336, 148.19960278057067, 149.89860491655705, 151.59935953381407, 153.30185052934982, 155.00606210939196, 156.71197878041548], [0.0, 0.9890055165788326, 2.1199797339423814, 3.311555928903025, 4.544276039908392, 5.808523072960244, 7.098475528605971, 8.410204538204548, 9.740868932026665, 11.088312943074115, 12.450841772257101, 13.82708611804415, 15.215915392046334, 16.61637946716555, 18.02766807709987, 19.44908162592467, 20.880009646780845, 22.319914548264016, 23.76831911336908, 25.224796722749105, 26.68896359548702, 28.160472550365625, 29.639007931047384, 31.12428143470557, 32.61602865078556, 34.114006164314674, 35.617989112681975, 37.127769110115324, 38.64315247289666, 40.16395869251523, 41.690019114736565, 43.22117579085582, 44.757280473843025, 46.29819373713473, 47.843784197814216, 49.39392782909944, 50.94850734960628, 52.50741167891347, 54.070535450629905, 55.637778575533844, 57.20904584848041, 58.7842465937053, 60.363294343927215, 61.946106549298804, 63.532604312798625, 65.1227121491146, 66.71635776445693, 68.313471855067, 69.91398792247077, 71.51784210376388, 73.12497301542398, 74.73532160932186, 76.34883103975831, 77.96544654048613, 79.58511531079266, 81.2077864098202, 82.83341065838876, 84.4619405476643, 86.0933301540834, 87.7275350600046, 89.3645122796109, 91.00422018963377, 92.6466184645107, 94.29166801562619, 95.93933093431752, 97.58957043835731, 99.24235082165004, 100.89763740690402, 102.55539650106108, 104.21559535328431, 105.87820211532338, 107.54318580408915, 109.21051626628662, 110.88016414496482, 112.55210084785539, 114.22629851738122, 115.90273000222601, 117.58136883036362, 119.262189183455, 120.94516587252598, 122.6302743148468, 124.3174905119396, 126.00679102864567, 127.69815297318884, 129.39155397817663, 131.0869721824839, 132.78438621396828, 134.48377517297018, 136.18511861655284, 137.88839654344127, 139.5935893796218, 141.3006779645657, 143.0096435380442, 144.72046772750204, 146.43313253596153, 148.14762033042842, 149.86391383077412, 151.58199609906984, 153.30185052934982, 155.02346083778235, 156.74681105322793, 158.4718855081661], [0.0, 1.0, 2.1435469250725863, 3.3483695221017142, 4.594793419988141, 5.8730947154400965, 7.1773871931078945, 8.50369830827347, 9.849155306759332, 11.211578456539659, 12.589254117941675, 13.98079776731155, 15.385066247841792, 16.801098870150817, 18.228076360444554, 19.665291345596255, 21.112126572366314, 22.568038473104835, 24.03254452572564, 25.505213368279996, 26.98565695347127, 28.47352424057079, 29.968496064182357, 31.470280916501526, 32.978611447599306, 34.49324153653038, 36.01394382095229, 37.540507598529565, 39.07273703241923, 40.6104496074505, 42.1534747945094, 43.70165288902178, 45.25483399593906, 46.81287713873368, 48.375649473943696, 49.9430255960178, 51.51488691978922, 53.091121129988316, 54.67162168889682, 56.25628739463053, 57.84502198367701, 59.43773377225613, 61.03433533185527, 62.6347431949447, 64.23887758742801, 65.8466621848451, 67.45802388973736, 69.0728926279167, 70.69120116166509, 72.31288491813308, 73.93788183141571, 75.56613219696312, 77.19757853713917, 78.83216547687637, 80.46983962849212, 82.11054948483415, 83.75424532001202, 85.40087909704994, 87.05040438186575, 88.7027762630401, 90.35795127689539, 92.01588733744937, 93.67654367085215, 95.33988075395159, 97.00586025666553, 98.67444498786934, 100.34559884453337, 102.0192867638687, 103.6954746782613, 105.37412947279289, 107.05521894516545, 108.73871176785998, 110.42457745237618, 112.11278631541049, 113.80330944684269, 115.4961186794112, 117.1911865599665, 118.88848632220075, 120.58799186076, 122.28967770665166, 123.99351900386702, 125.69949148714417, 127.40757146080266, 129.11773577858517, 130.82996182444748, 132.54422749424077, 134.26051117823482, 135.97879174443474, 137.69904852264557, 139.42126128924411, 141.14541025261806, 142.8714760392368, 144.5994396803196, 146.32928259906882, 148.06098659843977, 149.79453384941735, 151.52990687977487, 153.26708856328952, 155.00606210939196, 156.74681105322793, 158.48931924611142, 160.23357084635077], [0.0, 1.0110054835779236, 2.1671376955549815, 3.3852199478900245, 4.645361343515772, 5.937730962882462, 7.256377809994043, 8.597285620356791, 9.957550023744291, 11.334967299125706, 12.727804947394988, 14.134663207545968, 15.55438634177768, 16.98600308785733, 18.428685155486562, 19.881717386555298, 21.344475734653535, 22.816410649906537, 24.29703429983923, 25.785910575156038, 27.282647157912177, 28.786889144005997, 30.298313855471783, 31.816626576320726, 33.341557014308584, 34.87285633981001, 36.41029468825004, 37.9536590384121, 39.50275139817404, 41.057387243697384, 42.617394169112785, 44.182610712220026, 45.75288532830302, 47.32807548931937, 48.908046889800566, 50.49267274404659, 52.081833161803544, 53.67541459171795, 55.27330932357242, 56.87541504170709, 58.48163442318299, 60.091874775195684, 61.70604770703948, 63.324068832584125, 64.94585749978069, 66.57133654418149, 68.20043206385503, 69.83307321341292, 71.4691920151535, 73.10872318557188, 74.7516039756978, 76.39777402390399, 78.0471752199851, 79.69975157944428, 81.35544912704162, 83.01421578876378, 84.67600129146278, 86.34075706949275, 88.00843617774197, 89.67899321051922, 91.35238422580808, 93.02856667444973, 94.70749933385835, 96.38914224591039, 98.0734566586826, 99.76040497174405, 101.44995068473378, 103.14205834897993, 104.8366935219379, 106.5338227242437, 108.23341339919747, 109.93543387450573, 111.63985332612747, 113.34664174407999, 115.05576990007326, 116.76720931685136, 118.48093223912959, 120.19691160602392, 121.91512102487837, 123.63553474640177, 125.35812764103304, 127.08287517645928, 128.80975339621764, 130.53873889931506, 132.26980882080682, 134.0029408132772, 135.7381130291705, 137.475304103924, 139.21449313985727, 140.9556596907763, 142.69878374725252, 144.44384572254032, 146.1908264390983, 147.9397071156822, 149.69046935498005, 151.44309513175983, 153.19756678150452, 154.95386698950895, 156.71197878041548, 158.4718855081661, 160.23357084635077, 161.99701877893233]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 2.3000000000000003\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.00501187233627272, 0.011122041084459121, 0.017729212397314648, 0.02468135450880038, 0.03190182328397956, 0.039343585679734214, 0.04697456272162094, 0.05477135498449793, 0.06271607717423539, 0.07079457843841377, 0.07899536096761979, 0.08730888318383746, 0.09572708958595398, 0.10424308151929365, 0.1128508794547425, 0.12154524686917981, 0.1303215568728387, 0.13917568928076518, 0.14810394985945305, 0.15710300604635283, 0.16616983512033304, 0.17530168192930146, 0.18449602405562207, 0.19375054284224735, 0.20306309908905887, 0.21243171250895657, 0.2218545442391117, 0.23132988185617595, 0.24085612645991733, 0.25043178147798134, 0.26005544291247557, 0.2697257908019835, 0.2794415817141558, 0.2892016421169105, 0.2990048625025113, 0.30885019215987414, 0.31873663450751405, 0.32866324291343185, 0.3386291169396208, 0.3486333989582464, 0.35867527109431885, 0.36875395245613757, 0.3788686966201998, 0.3890187893418007, 0.399203546466394, 0.40942231202002605, 0.4196744564599215, 0.42995937506866166, 0.4402764864774135, 0.45062523130541515, 0.46100507090441417, 0.4714154861980624, 0.4818559766073928, 0.49232605905448706, 0.502825267037299, 0.5133531497693483, 0.5239092713786557, 0.5344932101608733, 0.545104557882067, 0.5557429191270674, 0.5664079106896951, 0.5770991610015304, 0.5878163095962048, 0.5985590066064778, 0.609326912291608, 0.6201196965927588, 0.6309370387143718, 0.6417786267296287, 0.6526441572082785, 0.6635333348652601, 0.6744458722286716, 0.6853814893257681, 0.6963399133857711, 0.7073208785583681, 0.7183241256468774, 0.729349401855125, 0.7403964605471587, 0.7514650610189912, 0.762554968281621, 0.7736659528546398, 0.7847977905697833, 0.7959502623838292, 0.8071231542002879, 0.8183162566993758, 0.8295293651757856, 0.8407622793838152, 0.8520148033894351, 0.863286745428908, 0.8745779177736024, 0.8858881366006565, 0.8972172218691828, 0.9085649972017137, 0.9199312897706118, 0.9313159301891901, 0.9427187524072923, 0.9541395936111111, 0.965578294127025, 0.9770346973292588, 0.9885086495511719, 1.0, 1.0115086006748837], [0.0, 0.011122041084459121, 0.024681354508800383, 0.03934358567973422, 0.054771354984497936, 0.07079457843841379, 0.08730888318383746, 0.10424308151929365, 0.12154524686917982, 0.1391756892807652, 0.15710300604635286, 0.1753016819293015, 0.1937505428422474, 0.21243171250895657, 0.231329881856176, 0.25043178147798134, 0.2697257908019835, 0.2892016421169106, 0.3088501921598742, 0.3286632429134319, 0.3486333989582464, 0.3687539524561376, 0.3890187893418007, 0.4094223120200261, 0.42995937506866166, 0.45062523130541515, 0.4714154861980624, 0.4923260590544871, 0.5133531497693483, 0.5344932101608733, 0.5557429191270674, 0.5770991610015304, 0.5985590066064778, 0.6201196965927589, 0.6417786267296286, 0.6635333348652602, 0.6853814893257683, 0.7073208785583681, 0.7293494018551251, 0.7514650610189912, 0.7736659528546398, 0.7959502623838293, 0.8183162566993757, 0.8407622793838153, 0.8632867454289082, 0.8858881366006566, 0.9085649972017138, 0.93131593018919, 0.9541395936111111, 0.9770346973292591, 1.0000000000000002, 1.0230343062880207, 1.0461364642907813, 1.0693053631540017, 1.09253993086066, 1.1158391321778984, 1.1392019667478825, 1.162627467310129, 1.186114698044096, 1.2096627530219626, 1.2332707547625268, 1.2569378528780324, 1.2806632228065287, 1.30444606462306, 1.3282856019236067, 1.3521810807762593, 1.3761317687345995, 1.4001369539087103, 1.4241959440896415, 1.4483080659235068, 1.472472664131727, 1.496689100774209, 1.520956754552532, 1.5452750201504382, 1.5696433076091458, 1.5940610417352046, 1.6185276615387794, 1.643042619700424, 1.6676053820645462, 1.6922154271579013, 1.7168722457315782, 1.7415753403250516, 1.7663242248509763, 1.7911184241994949, 1.8159574738609232, 1.8408409195657425, 1.865768316940916, 1.890739231181609, 1.9157532367374435, 1.9408099170125026, 1.965908864078315, 1.9910496783991358, 2.0162319685688574, 2.0414553510589393, 2.066719449976788, 2.092023896834034, 2.1173683303242177, 2.1427523961093873, 2.1681757466151854, 2.193638040833985, 2.2191389441356906, 2.244678128085831], [0.0, 0.017729212397314648, 0.03934358567973422, 0.0627160771742354, 0.08730888318383745, 0.11285087945474251, 0.1391756892807652, 0.16616983512033306, 0.19375054284224738, 0.2218545442391117, 0.25043178147798134, 0.2794415817141558, 0.30885019215987425, 0.3386291169396208, 0.3687539524561377, 0.399203546466394, 0.4299593750686616, 0.46100507090441417, 0.49232605905448706, 0.5239092713786557, 0.5557429191270674, 0.5878163095962048, 0.6201196965927588, 0.6526441572082787, 0.6853814893257683, 0.7183241256468775, 0.7514650610189912, 0.7847977905697834, 0.8183162566993758, 0.8520148033894351, 0.8858881366006566, 0.9199312897706118, 0.954139593611111, 0.9885086495511721, 1.0230343062880207, 1.057712639001351, 1.09253993086066, 1.1275126565158122, 1.162627467310129, 1.197881177995542, 1.2332707547625268, 1.2687933044249762, 1.3044460646230598, 1.3402263949262296, 1.3761317687345995, 1.4121597658905016, 1.448308065923507, 1.484574441861971, 1.5209567545525322, 1.5574529474361187, 1.5940610417352046, 1.6307791320123346, 1.6676053820645462, 1.704538021122309, 1.7415753403250518, 1.778715689448407, 1.8159574738609232, 1.8532991516903463, 1.890739231181609, 1.9282762682304648, 1.965908864078315, 2.0036356631551673, 2.0414553510589393, 2.079366652660423, 2.1173683303242172, 2.1554591822368385, 2.193638040833985, 2.2319037713196748, 2.270255270270587, 2.308691464319524, 2.3472113089124322, 2.385813787133862, 2.4244979085962046, 2.4632627083883962, 2.502107246080127, 2.541030604777925, 2.580031890229751, 2.619110229974997, 2.658264772537044, 2.6974946866557077, 2.736799160557139, 2.7761774012588947, 2.8156286339080747, 2.8551521011505643, 2.8947470625295737, 2.934412793911759, 2.9741485869393753, 3.013953748506975, 3.0538276002612785, 3.093769478122965, 3.133778731829151, 3.1738547244954702, 3.2139968321966945, 3.25420444356492, 3.2944769594044065, 3.334813792322202, 3.375214366373753, 3.4156781167227352, 3.456204489314407, 3.496792940561795, 3.5374429370441005, 3.578153955216728], [0.0, 0.02468135450880038, 0.054771354984497936, 0.08730888318383745, 0.12154524686917981, 0.15710300604635286, 0.19375054284224735, 0.23132988185617598, 0.2697257908019835, 0.30885019215987414, 0.3486333989582464, 0.38901878934180073, 0.42995937506866166, 0.47141548619806234, 0.5133531497693483, 0.5557429191270674, 0.5985590066064777, 0.6417786267296286, 0.6853814893257681, 0.7293494018551251, 0.7736659528546398, 0.8183162566993758, 0.863286745428908, 0.9085649972017138, 0.954139593611111, 1.0000000000000002, 1.046136464290781, 1.0925399308606598, 1.1392019667478823, 1.1861146980440957, 1.2332707547625266, 1.2806632228065287, 1.3282856019236067, 1.3761317687345995, 1.4241959440896412, 1.472472664131727, 1.520956754552532, 1.5696433076091456, 1.6185276615387794, 1.6676053820645462, 1.7168722457315782, 1.7663242248509763, 1.815957473860923, 1.865768316940916, 1.9157532367374435, 1.965908864078315, 2.0162319685688574, 2.0667194499767874, 2.1173683303242177, 2.1681757466151854, 2.2191389441356906, 2.2702552702705865, 2.3215221687880883, 2.372937174548202, 2.4244979085962046, 2.476202073606546, 2.5280474496461975, 2.5800318902297508, 2.632153318641398, 2.68440972450143, 2.736799160557139, 2.789319739679938, 2.8419696320522903, 2.8947470625295733, 2.947650308163392, 3.000677695874084, 3.0538276002612785, 3.1070984415423366, 3.1604886836094193, 3.213996832196694, 3.267621433149947, 3.3213610707914736, 3.375214366373752, 3.4291799766159006, 3.4832565923174124, 3.5374429370441, 3.591737765881575, 3.646139864251937, 3.7006480467897114, 3.7552611562733107, 3.8099780626086455, 3.8647976618616897, 3.919718875337087, 3.974740648700048, 4.029861951139044, 4.085081774566894, 4.140399132858088, 4.1958130611202815, 4.251322614998061, 4.306926870007201, 4.362624920897746, 4.418415881044364, 4.474298881862518, 4.53027307224909, 4.586337618046183, 4.64249170152691, 4.6987345209020335, 4.755065289846406, 4.811483237044234, 4.867987605752213, 4.924577653379666, 4.981252651084868], [0.0, 0.03190182328397956, 0.07079457843841379, 0.11285087945474251, 0.15710300604635286, 0.20306309908905887, 0.25043178147798134, 0.29900486250251135, 0.3486333989582464, 0.399203546466394, 0.4506252313054151, 0.5028252670372991, 0.5557429191270675, 0.609326912291608, 0.6635333348652602, 0.7183241256468774, 0.7736659528546398, 0.8295293651757857, 0.8858881366006565, 0.9427187524072924, 1.0, 1.057712639001351, 1.1158391321778982, 1.1743634237093272, 1.2332707547625268, 1.2925475087927065, 1.352181080776259, 1.4121597658905016, 1.472472664131727, 1.533109598099309, 1.5940610417352046, 1.6553180582410172, 1.7168722457315782, 1.7787156894484073, 1.8408409195657423, 1.903240873788823, 1.9659088640783149, 2.0288385469433448, 2.092023896834034, 2.1554591822368385, 2.21913894413569, 2.2830579765513375, 2.3472113089124322, 2.411594190046342, 2.4762020736065464, 2.541030604777925, 2.6060756081218908, 2.6713330764409284, 2.7367991605571396, 2.802470159912224, 2.8683425139074634, 2.934412793911759, 3.000677695874084, 3.0671340334838817, 3.133778731829151, 3.200608821507475, 3.2676214331499476, 3.3348137923222017, 3.4021832147703934, 3.4697271019832385, 3.5374429370441, 3.605328280749624, 3.673380767973712, 3.7415981042576045, 3.8099780626086455, 3.8785184804918855, 3.9472172570001245, 4.016072350189248, 4.085081774566895, 4.154243598723487, 4.223555943095617, 4.293016977852595, 4.362624920897746, 4.432378035976713, 4.502274630885642, 4.572313055772706, 4.64249170152691, 4.712808998248618, 4.783263413796636, 4.853853452407085, 4.924577653379666, 4.9954345898272035, 5.0664228674847, 5.137541123574353, 5.208788025723287, 5.280162270930927, 5.351662584583203, 5.4232877195109195, 5.495036455089838, 5.566907596380176, 5.638899973303359, 5.711012439854023, 5.7832438733453895, 5.85559317368624, 5.928059262687868, 6.00064108339942, 6.073337599470214, 6.146147794537639, 6.219070671639391, 6.292105252648794, 6.3652505777321196, 6.43850570482681], [0.0, 0.039343585679734214, 0.08730888318383746, 0.1391756892807652, 0.19375054284224735, 0.25043178147798134, 0.3088501921598742, 0.3687539524561377, 0.4299593750686616, 0.49232605905448706, 0.5557429191270674, 0.6201196965927589, 0.6853814893257684, 0.7514650610189911, 0.8183162566993758, 0.8858881366006565, 0.9541395936111109, 1.0230343062880207, 1.0925399308606598, 1.162627467310129, 1.2332707547625266, 1.3044460646230598, 1.3761317687345993, 1.448308065923507, 1.5209567545525322, 1.5940610417352046, 1.6676053820645462, 1.7415753403250518, 1.8159574738609232, 1.8907392311816087, 1.965908864078315, 2.0414553510589393, 2.1173683303242172, 2.193638040833985, 2.2702552702705865, 2.3472113089124322, 2.424497908596205, 2.5021072460801266, 2.580031890229751, 2.658264772537044, 2.736799160557139, 2.8156286339080747, 2.8947470625295733, 2.974148586939376, 3.053827600261279, 3.1337787318291515, 3.213996832196695, 3.294476959404406, 3.3752143663737524, 3.4562044893144073, 3.5374429370441005, 3.6189254811323694, 3.7006480467897114, 3.7826067044324994, 3.8647976618616906, 3.947217257000124, 4.029861951139044, 4.112728322649685, 4.195813061120282, 4.279112961882863, 4.362624920897747, 4.446345929966771, 4.53027307224909, 4.6144035180558145, 4.6987345209020335, 4.783263413796636, 4.867987605752213, 4.952904578498807, 5.038011883386756, 5.123307138465109, 5.208788025723286, 5.294452288484611, 5.380297728941371, 5.466322205821847, 5.552523632180512, 5.63889997330336, 5.725449244720859, 5.8121695103216995, 5.899058880560957, 5.986115510756782, 6.0733375994702135, 6.160723386963028, 6.248271153728981, 6.335979219094061, 6.423845939881769, 6.511869709139601, 6.600048954923301, 6.688382139135574, 6.776867756416243, 6.865504333081023, 6.954290426106224, 7.043224622156949, 7.132305536656426, 7.221531812894328, 7.310902121172054, 7.400415157983028, 7.490069645226263, 7.579864329451473, 7.669797981134205, 7.759869393979436, 7.8500773842523, 7.940420790134594], [0.0, 0.04697456272162094, 0.10424308151929365, 0.16616983512033306, 0.23132988185617598, 0.29900486250251135, 0.3687539524561377, 0.4402764864774136, 0.5133531497693483, 0.5878163095962048, 0.6635333348652602, 0.7403964605471588, 0.8183162566993759, 0.897217221869183, 0.9770346973292591, 1.057712639001351, 1.1392019667478825, 1.2214593143158892, 1.3044460646230598, 1.3881275928841037, 1.472472664131727, 1.5574529474361187, 1.643042619700424, 1.7292180391681293, 1.8159574738609232, 1.9032408737888233, 1.9910496783991363, 2.0793666526604224, 2.1681757466151854, 2.257461974319211, 2.3472113089124327, 2.437410591203508, 2.5280474496461975, 2.6191102299749978, 2.7105879330756664, 2.802470159912224, 2.8947470625295733, 2.9874093003108086, 3.0804480007984467, 3.173854724495471, 3.2676214331499476, 3.3617404610997377, 3.456204489314407, 3.5510065218221305, 3.646139864251938, 3.7415981042576045, 3.837375093619951, 3.9334649318501764, 4.029861951139045, 4.1265607025156195, 4.223555943095618, 4.320842624313472, 4.418415881044365, 4.5162710215331, 4.6144035180558145, 4.712808998248618, 4.811483237044235, 4.9104221491638995, 5.009621782117204, 5.109078309667315, 5.208788025723287, 5.308747338624857, 5.4089527657885, 5.509400928686414, 5.610088548132787, 5.711012439854024, 5.8121695103217, 5.913556752828927, 6.015171243792478, 6.117010139264545, 6.2190706716393915, 6.321350146541345, 6.423845939881768, 6.526555495073582, 6.62947632039287, 6.732605986477914, 6.835942123956763, 6.939482421195117, 7.043224622156951, 7.147166524370841, 7.251305976995525, 7.355640878978643, 7.4601691773031, 7.564888865315833, 7.669797981134206, 7.774894606125492, 7.880176863455312, 7.985642916701122, 8.091290968527094, 8.197119259417066, 8.30312606646232, 8.409309702201288, 8.515668513508372, 8.622200880529332, 8.728905215660765, 8.835779962571436, 8.942823595263294, 9.050034617170176, 9.157411560292342, 9.264952984365003, 9.372657476059228, 9.480523648213655], [0.0, 0.05477135498449793, 0.12154524686917982, 0.19375054284224738, 0.2697257908019835, 0.3486333989582464, 0.4299593750686616, 0.5133531497693483, 0.5985590066064778, 0.6853814893257681, 0.7736659528546398, 0.8632867454289082, 0.9541395936111111, 1.046136464290781, 1.1392019667478825, 1.2332707547625266, 1.3282856019236065, 1.4241959440896412, 1.520956754552532, 1.6185276615387796, 1.716872245731578, 1.8159574738609232, 1.9157532367374432, 2.0162319685688574, 2.1173683303242172, 2.2191389441356906, 2.3215221687880883, 2.4244979085962046, 2.5280474496461975, 2.632153318641398, 2.736799160557139, 2.8419696320522903, 2.947650308163392, 3.053827600261279, 3.160488683609419, 3.267621433149947, 3.375214366373752, 3.483256592317412, 3.591737765881575, 3.7006480467897114, 3.8099780626086455, 3.9197188753370873, 4.029861951139044, 4.1403991328580885, 4.251322614998061, 4.362624920897746, 4.474298881862518, 4.586337618046183, 4.6987345209020335, 4.811483237044235, 4.924577653379667, 5.038011883386756, 5.151780254431996, 5.265877296027225, 5.380297728941371, 5.495036455089838, 5.610088548132787, 5.725449244720859, 5.841113936333125, 5.957078161657683, 6.0733375994702135, 6.189888061970176, 6.306725488538215, 6.423845939881769, 6.541245592538952, 6.658920733713531, 6.776867756416243, 6.89508315488991, 7.013563520297804, 7.132305536656426, 7.251305976995525, 7.370561699729576, 7.490069645226261, 7.60982683255866, 7.729830356428945, 7.8500773842523, 7.97056515339072, 8.091290968527092, 8.212252199170724, 8.333446277286125, 8.454870695037492, 8.576523002641835, 8.698400806324278, 8.820501766369434, 8.942823595263292, 9.06536405592033, 9.188120959991025, 9.311092166245201, 9.434275579026979, 9.557669146777414, 9.681270860621073, 9.805078753013154, 9.929090896443888, 10.053305402197193, 10.177720419160803, 10.30233413268513, 10.427144763488457, 10.552150566606022, 10.677349830380914, 10.802740875494592, 10.928322054035169, 11.054091748601582], [0.0, 0.06271607717423539, 0.1391756892807652, 0.2218545442391117, 0.30885019215987414, 0.399203546466394, 0.49232605905448706, 0.5878163095962048, 0.6853814893257681, 0.7847977905697834, 0.8858881366006565, 0.988508649551172, 1.09253993086066, 1.1978811779955418, 1.3044460646230598, 1.4121597658905014, 1.520956754552532, 1.6307791320123344, 1.7415753403250516, 1.8532991516903463, 1.9659088640783149, 2.0793666526604224, 2.1936380408339846, 2.308691464319524, 2.4244979085962046, 2.541030604777925, 2.6582647725370436, 2.776177401258895, 2.8947470625295733, 3.0139537485069745, 3.133778731829151, 3.2542044435649196, 3.3752143663737524, 3.496792940561795, 3.6189254811323686, 3.741598104257604, 3.8647976618616906, 3.98851168321969, 4.112728322649685, 4.237436312518397, 4.362624920897746, 4.488283913306976, 4.614403518055814, 4.740974394771867, 4.867987605752213, 4.995434589827204, 5.12330713846511, 5.251597373880816, 5.380297728941372, 5.509400928686413, 5.638899973303359, 5.76878812241594, 5.899058880560956, 6.029705983742238, 6.160723386963029, 6.292105252648794, 6.423845939881768, 6.555939994376836, 6.688382139135573, 6.821167265721612, 6.954290426106224, 7.087746825037917, 7.2215318128943276, 7.355640878978644, 7.490069645226261, 7.624813860290555, 7.759869393979436, 7.895232232016872, 8.03089847110583, 8.1668643142711, 8.303126066462319, 8.439680130399115, 8.576523002641835, 8.713651269872653, 8.851061605373008, 8.98875076568457, 9.12671558744177, 9.264952984365001, 9.403459944404307, 9.54223352702422, 9.681270860621073, 9.82056914006472, 9.960125624357245, 10.099937634401686, 10.240002550874394, 10.380317812194994, 10.520880912588384, 10.661689400233586, 10.802740875494592, 10.944032989228694, 11.085563441168047, 11.227329978370548, 11.369330393736307, 11.511562524586251, 11.654024251299639, 11.796713496007422, 11.939628221338607, 12.082766429216932, 12.226126159705357, 12.369705489895988, 12.513502532843189, 12.657515436537825], [0.0, 0.07079457843841377, 0.15710300604635286, 0.25043178147798134, 0.3486333989582464, 0.4506252313054151, 0.5557429191270674, 0.6635333348652602, 0.7736659528546398, 0.8858881366006565, 1.0, 1.1158391321778984, 1.2332707547625268, 1.352181080776259, 1.472472664131727, 1.5940610417352044, 1.716872245731578, 1.8408409195657423, 1.9659088640783149, 2.092023896834034, 2.21913894413569, 2.3472113089124322, 2.476202073606546, 2.6060756081218908, 2.736799160557139, 2.8683425139074634, 3.000677695874084, 3.133778731829151, 3.267621433149947, 3.402183214770393, 3.5374429370441, 3.6733807679737116, 3.8099780626086455, 3.9472172570001245, 4.085081774566894, 4.223555943095617, 4.362624920897746, 4.502274630885642, 4.64249170152691, 4.783263413796636, 4.924577653379666, 5.0664228674847, 5.208788025723286, 5.351662584583203, 5.495036455089838, 5.638899973303359, 5.7832438733453895, 5.928059262687867, 6.0733375994702135, 6.2190706716393915, 6.3652505777321196, 6.511869709139601, 6.658920733713531, 6.8063965805880615, 6.954290426106224, 7.102595680751473, 7.251305976995525, 7.400415157983027, 7.549917266981739, 7.699806537534072, 7.850077384252299, 8.000724394205264, 8.151742318849534, 8.30312606646232, 8.454870695037492, 8.606971405609524, 8.759423535973431, 8.912222554771507, 9.06536405592033, 9.218843753353688, 9.372657476059226, 9.526801163388399, 9.681270860621073, 9.836062714767587, 9.99117297059247, 10.146597966845274, 10.30233413268513, 10.458377984286617, 10.614726121615544, 10.771375225364034, 10.928322054035167, 11.085563441168045, 11.243096292694913, 11.400917584422476, 11.5590243596302, 11.717413726778766, 11.876082857322448, 12.035028983619517, 12.194249396935188, 12.353741445532057, 12.513502532843187, 12.673530115723448, 12.833821702774886, 12.994374852742238, 13.155187172974953, 13.316256317952233, 13.477579987867918, 13.639155927272158, 13.800981923767075, 13.963055806753674, 14.125375446227547, 14.287938751620985], [0.0, 0.07899536096761979, 0.1753016819293015, 0.2794415817141558, 0.38901878934180073, 0.5028252670372991, 0.6201196965927589, 0.7403964605471588, 0.8632867454289082, 0.988508649551172, 1.1158391321778984, 1.2450969688995255, 1.3761317687345997, 1.5088165637207538, 1.6430426197004242, 1.778715689448407, 1.9157532367374435, 2.0540823341658023, 2.193638040833985, 2.3343621295387136, 2.4762020736065464, 2.6191102299749973, 2.763043172910241, 2.9079611449567193, 3.053827600261279, 3.2006088215074757, 3.348273596109714, 3.496792940561795, 3.646139864251938, 3.796289165879608, 3.947217257000125, 4.098902008294768, 4.251322614998061, 4.4044594785686435, 4.558294102208472, 4.712808998248619, 4.867987605752213, 5.023814216954003, 5.180273911374883, 5.33735249662913, 5.4950364550898385, 5.653312895700387, 5.8121695103217, 5.971594534090251, 6.13157670933336, 6.292105252648795, 6.453169824806867, 6.614760503176782, 6.776867756416244, 6.939482421195119, 7.102595680751475, 7.266199045101876, 7.430284332748321, 7.594843653741997, 7.759869393979437, 7.925354200620213, 8.091290968527094, 8.257672827639947, 8.424493131203834, 8.591745444779727, 8.759423535973433, 8.927521364824544, 9.096033074802913, 9.264952984365003, 9.43427557902698, 9.603995503915318, 9.774107556759251, 9.94460668129253, 10.115487961034855, 10.28674661342582, 10.458377984286619, 10.630377542586704, 10.802740875494594, 10.975463683693649, 11.148541776945176, 11.32197106988266, 11.495747578022119, 11.669867413974817, 11.844326783849558, 12.019121983832719, 12.19424939693519, 12.369705489895988, 12.545486810233239, 12.721589983433718, 12.89801171027295, 13.074748764258212, 13.251797989187496, 13.429156296817856, 13.606820664637022, 13.784788133732627, 13.963055806753676, 14.141620845959313, 14.320480471350207, 14.499631958878206, 14.679072638730192, 14.858799893682276, 15.038811157520747, 15.219103913526405, 15.399675693019116, 15.580524073959586, 15.76164667960554, 15.943041177219724], [0.0, 0.08730888318383746, 0.1937505428422474, 0.30885019215987425, 0.42995937506866166, 0.5557429191270675, 0.6853814893257684, 0.8183162566993759, 0.9541395936111111, 1.09253993086066, 1.2332707547625268, 1.3761317687345997, 1.5209567545525324, 1.6676053820645462, 1.8159574738609234, 1.965908864078315, 2.1173683303242177, 2.270255270270587, 2.424497908596205, 2.5800318902297517, 2.736799160557139, 2.8947470625295737, 3.053827600261279, 3.2139968321966954, 3.375214366373753, 3.537442937044101, 3.700648046789712, 3.864797661861691, 4.029861951139044, 4.195813061120282, 4.362624920897747, 4.53027307224909, 4.6987345209020335, 4.867987605752214, 5.038011883386756, 5.208788025723287, 5.380297728941372, 5.552523632180513, 5.72544924472086, 5.899058880560958, 6.0733375994702135, 6.2482711537289815, 6.423845939881769, 6.600048954923302, 6.776867756416244, 6.954290426106226, 7.132305536656427, 7.310902121172054, 7.490069645226263, 7.669797981134207, 7.850077384252301, 8.030898471105832, 8.212252199170726, 8.39412984815492, 8.576523002641837, 8.759423535973433, 8.942823595263292, 9.126715587441772, 9.311092166245203, 9.495946220070083, 9.681270860621074, 9.867059412288485, 10.053305402197195, 10.240002550874397, 10.427144763488457, 10.614726121615544, 10.802740875494594, 10.991183436734671, 11.180048371441947, 11.369330393736309, 11.5590243596302, 11.74912526124453, 11.939628221338607, 12.13052848813297, 12.321821430405532, 12.51350253284319, 12.705567391632332, 12.89801171027295, 13.09083129560231, 13.284022054015084, 13.477579987867918, 13.671501192057189, 13.865781850759623, 14.060418234326072, 14.25540669631957, 14.45074367068924, 14.64642566907236, 14.842449278217327, 15.038811157520746, 15.235508036672428, 15.432536713402309, 15.62989405132387, 15.82757697786888, 16.025582482308618, 16.223907613857133, 16.422549479852215, 16.621505244010194, 16.820772124750725, 17.02034739358821, 17.220228373586387, 17.42041243787311, 17.620897008212367], [0.0, 0.09572708958595398, 0.21243171250895657, 0.3386291169396208, 0.47141548619806234, 0.609326912291608, 0.7514650610189911, 0.897217221869183, 1.046136464290781, 1.1978811779955418, 1.352181080776259, 1.5088165637207538, 1.6676053820645462, 1.8283936752092522, 1.991049678399136, 2.155459182236838, 2.3215221687880883, 2.489150264155568, 2.6582647725370436, 2.828795133830805, 3.0006776958740837, 3.1738547244954702, 3.3482735961097134, 3.523886132374905, 3.700648046789711, 3.878518480491886, 4.057459609868234, 4.237436312518396, 4.418415881044364, 4.600367776347078, 4.783263413796636, 4.967075976941418, 5.151780254431996, 5.337352496629129, 5.523770288993261, 5.711012439854024, 5.899058880560956, 6.087890576342481, 6.277489446465471, 6.467838292505074, 6.658920733713531, 6.8507211486250155, 7.043224622156949, 7.236416897571584, 7.43028433274832, 7.624813860290555, 7.819992951052847, 8.015809580726994, 8.212252199170724, 8.409309702201288, 8.606971405609524, 8.80522702117857, 9.004066634516203, 9.2034806845314, 9.403459944404306, 9.603995503915316, 9.805078753013156, 10.0067013665145, 10.208855289838707, 10.411532725690927, 10.614726121615544, 10.818428158349455, 11.022631738911532, 11.22732997837055, 11.432516194239318, 11.638183897447444, 11.844326783849555, 12.05093872622949, 12.258013766764604, 12.465546109917256, 12.67353011572345, 12.881960293451048, 13.090831295602307, 13.300137912237501, 13.509875065598273, 13.720037805011035, 13.930621302052323, 14.141620845959311, 14.353031839270095, 14.564849793679361, 14.7770703260963, 14.989689154892393, 15.20270209632776, 15.41610506114544, 15.62989405132387, 15.844065156978285, 16.05861455340267, 16.273538498244243, 16.488833328803068, 16.70449545945, 16.920521379156355, 17.1369076491294, 17.353650900547954, 17.570747832392843, 17.788195209367252, 18.00598985990234, 18.224128674243723, 18.442608602614786, 18.66142665345298, 18.880579891715403, 19.100065437250397, 19.319880463231858], [0.0, 0.10424308151929365, 0.231329881856176, 0.3687539524561377, 0.5133531497693483, 0.6635333348652602, 0.8183162566993758, 0.9770346973292591, 1.1392019667478825, 1.3044460646230598, 1.472472664131727, 1.6430426197004242, 1.8159574738609234, 1.991049678399136, 2.1681757466151854, 2.3472113089124322, 2.5280474496461975, 2.7105879330756664, 2.8947470625295733, 3.080448000798447, 3.267621433149947, 3.456204489314407, 3.6461398642519374, 3.837375093619951, 4.029861951139044, 4.223555943095618, 4.418415881044365, 4.6144035180558145, 4.811483237044234, 5.009621782117204, 5.208788025723287, 5.4089527657885, 5.610088548132787, 5.812169510321701, 6.015171243792477, 6.2190706716393915, 6.423845939881769, 6.629476320392869, 6.835942123956763, 7.043224622156951, 7.251305976995525, 7.4601691773031, 7.669797981134205, 7.880176863455313, 8.091290968527094, 8.30312606646232, 8.515668513508373, 8.728905215660765, 8.942823595263292, 9.157411560292344, 9.372657476059228, 9.588550139095483, 9.805078753013158, 10.02223290615558, 10.240002550874395, 10.458377984286619, 10.677349830380916, 10.896909023356082, 11.117046792086727, 11.337754645621683, 11.559024359630202, 11.780847963719122, 12.003217729551714, 12.22612615970536, 12.449565977211122, 12.673530115723452, 12.89801171027295, 13.123004088559266, 13.348500762745006, 13.574495421714834, 13.800981923767077, 14.02795428970775, 14.255406696319568, 14.483333470180575, 14.711729081809194, 14.940588140114224, 15.169905387130099, 15.399675693019116, 15.629894051323873, 15.86055557445426, 16.091655489394668, 16.323189133617987, 16.55515195119402, 16.787539489080817, 17.02034739358821, 17.253571407003598, 17.487207364370718, 17.72125119041278, 17.955698896591862, 18.19054657829712, 18.425790412154722, 18.66142665345298, 18.897451633676514, 19.13386175814368, 19.370653503741952, 19.607823416756066, 19.84536811078432, 20.08328426473847, 20.321568620923113, 20.56021798319056, 20.799229215167557, 21.038599238550294], [0.0, 0.1128508794547425, 0.25043178147798134, 0.399203546466394, 0.5557429191270674, 0.7183241256468774, 0.8858881366006565, 1.057712639001351, 1.2332707547625266, 1.4121597658905014, 1.5940610417352044, 1.778715689448407, 1.965908864078315, 2.155459182236838, 2.3472113089124322, 2.5410306047779248, 2.7367991605571387, 2.9344127939117586, 3.133778731829151, 3.3348137923222017, 3.5374429370440996, 3.741598104257604, 3.947217257000124, 4.154243598723488, 4.362624920897746, 4.572313055772706, 4.783263413796635, 4.995434589827204, 5.208788025723286, 5.4232877195109195, 5.638899973303359, 5.855593173686239, 6.0733375994702135, 6.292105252648795, 6.5118697091396, 6.732605986477912, 6.954290426106224, 7.176900588287549, 7.400415157983027, 7.624813860290555, 7.850077384252299, 8.076187314013723, 8.303126066462319, 8.530876834596016, 8.759423535973431, 8.98875076568457, 9.21884375335369, 9.44968832374825, 9.681270860621074, 9.913578273458345, 10.146597966845274, 10.380317812194995, 10.614726121615542, 10.849811623715139, 11.085563441168047, 11.321971069882656, 11.5590243596302, 11.796713496007422, 12.035028983619517, 12.2739616303811, 12.513502532843187, 12.753643062463105, 12.994374852742238, 13.235689787163656, 13.477579987867916, 13.720037805011035, 13.963055806753674, 14.206626769835053, 14.450743670689238, 14.695399677065062, 14.94058814011422, 15.186302586915067, 15.432536713402305, 15.679284377675222, 15.926539593659248, 16.174296525097684, 16.42254947985221, 16.67129290449245, 16.92052137915636, 17.170229612664563, 17.420412437873107, 17.67106480725003, 17.922181788662467, 18.1737585613617, 18.425790412154722, 18.678272731751342, 18.931201011277025, 19.184570838941905, 19.438377896857393, 19.6926179579922, 19.94728688326013, 20.202380618732604, 20.457895192969207, 20.713826714460033, 20.97017136917405, 21.226925418207934, 21.484085195530277, 21.741647105816345, 21.99960762236887, 22.257963285120557, 22.516710698714363, 22.77584653065774], [0.0, 0.12154524686917981, 0.2697257908019835, 0.4299593750686616, 0.5985590066064777, 0.7736659528546398, 0.9541395936111109, 1.1392019667478825, 1.3282856019236065, 1.520956754552532, 1.716872245731578, 1.9157532367374435, 2.1173683303242177, 2.3215221687880883, 2.5280474496461975, 2.7367991605571387, 2.9476503081633916, 3.160488683609419, 3.375214366373752, 3.591737765881575, 3.809978062608645, 4.029861951139044, 4.2513226149980605, 4.474298881862518, 4.698734520902033, 4.924577653379666, 5.151780254431996, 5.380297728941371, 5.6100885481327865, 5.841113936333124, 6.073337599470213, 6.3067254885382145, 6.541245592538951, 6.776867756416243, 7.013563520297803, 7.251305976995524, 7.490069645226261, 7.729830356428944, 7.97056515339072, 8.212252199170724, 8.454870695037492, 8.698400806324278, 8.94282359526329, 9.188120959991025, 9.434275579026979, 9.681270860621073, 9.929090896443888, 10.177720419160801, 10.427144763488457, 10.677349830380916, 10.928322054035167, 11.180048371441945, 11.432516194239316, 11.685713382653958, 11.939628221338605, 12.194249396935186, 12.44956597721112, 12.70556739163233, 12.962243413250555, 13.219584141794808, 13.477579987867916, 13.73622165815861, 13.995500141588339, 14.255406696319568, 14.515932837559125, 14.7770703260963, 15.038811157520744, 15.301147552070178, 15.564071945062263, 15.827576977868876, 16.091655489394668, 16.356300508024848, 16.621505244010187, 16.88726308225967, 17.153567575513733, 17.420412437873107, 17.687791538660207, 17.95569889659186, 18.22412867424372, 18.49307517278823, 18.762532826989286, 19.03249620043806, 19.302959981015494, 19.573918976568052, 19.845368110784317, 20.117302419260678, 20.389717045745485, 20.66260723855147, 20.935968347127055, 21.20979581877789, 21.48408519553027, 21.7588321111289, 22.034032288161782, 22.309681535305508, 22.585775744684756, 22.862310889339962, 23.139283020797766, 23.416688266738912, 23.694522828758892, 23.97278298021653, 24.25146506416638, 24.53056549137076], [0.0, 0.1303215568728387, 0.2892016421169106, 0.46100507090441417, 0.6417786267296286, 0.8295293651757857, 1.0230343062880207, 1.2214593143158892, 1.4241959440896412, 1.6307791320123344, 1.8408409195657423, 2.0540823341658023, 2.270255270270587, 2.489150264155568, 2.7105879330756664, 2.9344127939117586, 3.160488683609419, 3.3886952911476476, 3.618925481132369, 3.8510831940014705, 4.085081774566894, 4.320842624313471, 4.558294102208472, 4.797370618912952, 5.038011883386756, 5.280162270930928, 5.523770288993262, 5.76878812241594, 6.015171243792477, 6.262878077609064, 6.511869709139601, 6.76210963083184, 7.013563520297804, 7.266199045101876, 7.519985690394975, 7.774894606125491, 8.03089847110583, 8.287971371657038, 8.546088692915124, 8.80522702117857, 9.06536405592033, 9.32647853028944, 9.588550139095481, 9.85155947340972, 10.115487961034853, 10.380317812194995, 10.646031969882072, 10.912614064366549, 11.180048371441945, 11.448319774024997, 11.717413726778767, 11.987316223464846, 12.258013766764604, 12.52949334033885, 12.801742382920619, 13.07474876425821, 13.348500762745005, 13.622987044589733, 13.89819664439594, 14.174118947032536, 14.450743670689238, 14.728060851020885, 15.006060826293952, 15.284734223456782, 15.564071945062263, 15.844065156978285, 16.124705276827136, 16.40598396310013, 16.687893104898606, 16.970424812256503, 17.253571407003594, 17.53732541413188, 17.82167955363072, 18.106626732759075, 18.39216003872583, 18.678272731751346, 18.96495823848563, 19.25221014576029, 19.54002219465326, 19.828388274846784, 20.117302419260678, 20.406758798944157, 20.69675171821069, 20.98727561000151, 21.278325031464473, 21.569894659735674, 21.8619792879124, 22.15457382120651, 22.44767327326817, 22.741272762670654, 23.035367509547296, 23.32995283237248, 23.6250241448789, 23.92057695310398, 24.21660685255867, 24.513109525512313, 24.810080738387622, 25.107516339260222, 25.40541225545757, 25.703764491252212, 26.002569125644875, 26.301822310232975], [0.0, 0.13917568928076518, 0.3088501921598742, 0.49232605905448706, 0.6853814893257681, 0.8858881366006565, 1.0925399308606598, 1.3044460646230598, 1.520956754552532, 1.7415753403250516, 1.9659088640783149, 2.193638040833985, 2.424497908596205, 2.6582647725370436, 2.8947470625295733, 3.133778731829151, 3.375214366373752, 3.618925481132369, 3.86479766186169, 4.112728322649685, 4.362624920897746, 4.6144035180558145, 4.867987605752213, 5.12330713846511, 5.380297728941371, 5.638899973303359, 5.899058880560956, 6.160723386963029, 6.423845939881768, 6.688382139135573, 6.954290426106224, 7.2215318128943276, 7.490069645226261, 7.759869393979437, 8.030898471105829, 8.30312606646232, 8.576523002641835, 8.851061605373008, 9.12671558744177, 9.403459944404307, 9.681270860621073, 9.960125624357246, 10.240002550874394, 10.520880912588384, 10.802740875494592, 11.085563441168047, 11.369330393736309, 11.654024251299639, 11.939628221338607, 12.226126159705359, 12.513502532843189, 12.80174238292062, 13.090831295602307, 13.380755370210403, 13.671501192057187, 13.963055806753674, 14.255406696319568, 14.548541756938356, 14.842449278217325, 15.137117923826391, 15.432536713402307, 15.728695005615734, 16.025582482308614, 16.323189133617987, 16.621505244010187, 16.92052137915636, 17.220228373586384, 17.52061731906399, 17.821679553630723, 18.12340665127102, 18.42579041215472, 18.728822853416855, 19.032496200438064, 19.336802878591815, 19.641735505427405, 19.947286883260134, 20.253449992142276, 20.56021798319056, 20.86758417224763, 21.17554203385671, 21.484085195530273, 21.793207432294768, 22.10290266149497, 22.413164937842478, 22.72398844869418, 23.035367509547296, 23.347296559738723, 23.659770158337043, 23.972782980216532, 24.286329812303126, 24.600405549982867, 24.9150051936642, 25.2301238454858, 25.545756706162315, 25.86189907196081, 26.178546331801158, 26.495693964474047, 26.813337535970625, 27.131472696918287, 27.450095180117234, 27.769200798172918, 28.088785441219745], [0.0, 0.14810394985945305, 0.3286632429134319, 0.5239092713786557, 0.7293494018551251, 0.9427187524072924, 1.162627467310129, 1.3881275928841037, 1.6185276615387796, 1.8532991516903463, 2.092023896834034, 2.3343621295387136, 2.5800318902297517, 2.828795133830805, 3.080448000798447, 3.3348137923222017, 3.591737765881575, 3.8510831940014705, 4.112728322649685, 4.3765639849246565, 4.64249170152691, 4.9104221491638995, 5.180273911374882, 5.4519724491472825, 5.725449244720859, 6.000641083399421, 6.277489446465472, 6.555939994376837, 6.835942123956763, 7.117448586707298, 7.400415157983028, 7.68480034877156, 7.970565153390721, 8.257672827639947, 8.546088692915124, 8.835779962571436, 9.12671558744177, 9.418866117922393, 9.71220358044799, 10.006701366514502, 10.30233413268513, 10.599077710244403, 10.896909023356082, 11.19580601474065, 11.495747578022117, 11.796713496007422, 12.098684384257574, 12.40164163939136, 12.705567391632332, 13.010444461169293, 13.316256317952234, 13.622987044589735, 13.930621302052325, 14.23914429791968, 14.548541756938357, 14.858799893682274, 15.169905387130099, 15.481845356993306, 15.794607341645696, 16.1081792775202, 16.422549479852215, 16.73770662466041, 17.053639731866504, 17.370338149464747, 17.68779153866021, 18.00598985990234, 18.32492335974689, 18.644582558485258, 18.964958238485632, 19.286041433195074, 19.607823416756062, 19.930295694194804, 20.253449992142276, 20.577278250052036, 20.90177261188173, 21.226925418207934, 21.552729198746224, 21.879176665250558, 22.20626070476816, 22.533974373227636, 22.862310889339962, 23.191263628793276, 23.520826118723893, 23.85099203244717, 24.181755184433094, 24.513109525512313, 24.845049138299576, 25.177568232822246, 25.51066114234242, 25.844322319362085, 26.178546331801158, 26.513327859339253, 26.848661689912312, 27.184542716355992, 27.520965933188158, 27.857926433523254, 28.19541940611183, 28.53344013249891, 28.87198398429526, 29.211046420555906, 29.550622985260734, 29.890709304892134], [0.0, 0.15710300604635283, 0.3486333989582464, 0.5557429191270674, 0.7736659528546398, 1.0, 1.2332707547625266, 1.472472664131727, 1.716872245731578, 1.9659088640783149, 2.21913894413569, 2.4762020736065464, 2.736799160557139, 3.0006776958740837, 3.267621433149947, 3.5374429370440996, 3.809978062608645, 4.085081774566894, 4.362624920897746, 4.64249170152691, 4.924577653379665, 5.208788025723286, 5.495036455089837, 5.7832438733453895, 6.073337599470213, 6.3652505777321196, 6.658920733713531, 6.954290426106224, 7.251305976995524, 7.549917266981738, 7.850077384252299, 8.151742318849532, 8.454870695037492, 8.759423535973431, 9.065364055920329, 9.372657476059226, 9.681270860621073, 9.991172970592467, 10.30233413268513, 10.614726121615544, 10.928322054035167, 11.243096292694913, 11.559024359630198, 11.876082857322448, 12.194249396935188, 12.513502532843187, 12.833821702774886, 13.155187172974951, 13.477579987867916, 13.800981923767077, 14.125375446227547, 14.450743670689238, 14.7770703260963, 15.104339721214963, 15.432536713402305, 15.761646679605537, 16.091655489394668, 16.42254947985221, 16.754315432161672, 17.086940549752445, 17.420412437873107, 17.75471908447733, 18.089848842317977, 18.425790412154722, 18.76253282698929, 19.100065437250397, 19.438377896857393, 19.777460150097923, 20.117302419260678, 20.457895192969207, 20.799229215167554, 21.141295474712397, 21.48408519553027, 21.827589827301775, 22.171801036637618, 22.516710698714363, 22.862310889339962, 23.20859387742175, 23.555552117811445, 23.903178244503675, 24.25146506416638, 24.600405549982863, 24.949992835786883, 25.300220210473316, 25.651081112668486, 26.00256912564487, 26.354677972466508, 26.707401511351843, 27.060733731242028, 27.414668747563322, 27.769200798172914, 28.124324239478405, 28.480033542721564, 28.836323290417774, 29.19318817294301, 29.55062298526073, 29.90862262378152, 30.26718208334878, 30.626296454344214, 30.985960919907065, 31.346170753261603, 31.706921315147603], [0.0, 0.16616983512033304, 0.3687539524561376, 0.5878163095962048, 0.8183162566993758, 1.057712639001351, 1.3044460646230598, 1.5574529474361187, 1.8159574738609232, 2.0793666526604224, 2.3472113089124322, 2.6191102299749973, 2.8947470625295737, 3.1738547244954702, 3.456204489314407, 3.741598104257604, 4.029861951139044, 4.320842624313471, 4.6144035180558145, 4.9104221491638995, 5.208788025723286, 5.509400928686413, 5.8121695103216995, 6.117010139264546, 6.423845939881768, 6.732605986477914, 7.04322462215695, 7.355640878978644, 7.669797981134205, 7.985642916701121, 8.30312606646232, 8.62220088052933, 8.942823595263292, 9.264952984365003, 9.58855013909548, 9.913578273458345, 10.240002550874394, 10.567789929444325, 10.896909023356082, 11.22732997837055, 11.5590243596302, 11.891965050292642, 12.226126159705357, 12.56148294001723, 12.89801171027295, 13.235689787163658, 13.574495421714836, 13.914407741284057, 14.255406696319568, 14.597473011397616, 14.940588140114224, 15.284734223456782, 15.629894051323872, 15.976051026899206, 16.323189133617987, 16.671292904492454, 17.02034739358821, 17.370338149464747, 17.72125119041278, 18.07307298133785, 18.425790412154722, 18.779390777570164, 19.13386175814368, 19.489191402525957, 19.845368110784317, 20.202380618732608, 20.56021798319056, 20.918869568104128, 21.278325031464473, 21.63857431296851, 21.99960762236887, 22.361415428465364, 22.72398844869418, 23.0873176392744, 23.451394185874864, 23.81620949476712, 24.181755184433094, 24.548023077598355, 24.915005193664204, 25.282693741513658, 25.651081112668486, 26.020159874775853, 26.38992276540494, 26.760362686135046, 27.13147269691829, 27.503246010700888, 27.87567598828832, 28.248756133440626, 28.62248008818488, 28.996841628333062, 29.371834659193894, 29.747453211468365, 30.12369143731902, 30.5005436066039, 30.87800410326658, 31.256067421874107, 31.634728164295456, 32.01398103651324, 32.39382084556213, 32.77424249658763, 33.155240990019294, 33.536811418852956], [0.0, 0.17530168192930146, 0.3890187893418007, 0.6201196965927588, 0.863286745428908, 1.1158391321778982, 1.3761317687345993, 1.643042619700424, 1.9157532367374432, 2.1936380408339846, 2.476202073606546, 2.763043172910241, 3.053827600261279, 3.3482735961097134, 3.6461398642519374, 3.947217257000124, 4.2513226149980605, 4.558294102208472, 4.867987605752213, 5.180273911374882, 5.495036455089837, 5.8121695103216995, 6.131576709333358, 6.453169824806866, 6.776867756416242, 7.102595680751474, 7.43028433274832, 7.759869393979436, 8.091290968527092, 8.424493131203832, 8.759423535973431, 9.09603307480291, 9.434275579026979, 9.774107556759251, 10.115487961034852, 10.458377984286617, 10.802740875494592, 11.148541776945175, 11.495747578022117, 11.844326783849557, 12.194249396935188, 12.545486810233237, 12.898011710272947, 13.251797989187496, 13.60682066463702, 13.963055806753674, 14.320480471350207, 14.679072638730188, 15.038811157520744, 15.399675693019116, 15.761646679605539, 16.124705276827136, 16.488833328803068, 16.85401332664066, 17.220228373586384, 17.587462152665694, 17.95569889659186, 18.324923359746887, 18.69512079205805, 19.06627691461111, 19.438377896857393, 19.81141033528555, 20.185361233441448, 20.56021798319056, 20.935968347127055, 21.31260044204255, 21.690102723375393, 22.068463970568235, 22.44767327326817, 22.827720018309158, 23.20859387742175, 23.590284795619606, 23.97278298021653, 24.356078890431533, 24.740163227542745, 25.12502692555423, 25.510661142342418, 25.89705725125157, 26.284206833109977, 26.672101668640597, 27.060733731242028, 27.45009518011723, 27.840178353729215, 28.23097576356427, 28.62248008818488, 29.014684167555384, 29.407580997625, 29.80116372515353, 30.195425642766285, 30.59036018422561, 30.985960919907065, 31.38222155246941, 31.779135912707865, 32.17669795558108, 32.57490175640282, 32.97374150718959, 33.373211513156626, 33.77330618935433, 34.17402005743849, 34.575347742567374, 34.97728397041964, 35.379823564327204], [0.0, 0.18449602405562207, 0.4094223120200261, 0.6526441572082787, 0.9085649972017138, 1.1743634237093272, 1.448308065923507, 1.7292180391681293, 2.0162319685688574, 2.308691464319524, 2.6060756081218908, 2.9079611449567193, 3.2139968321966954, 3.523886132374905, 3.837375093619951, 4.154243598723488, 4.474298881862518, 4.797370618912952, 5.12330713846511, 5.4519724491472825, 5.7832438733453895, 6.117010139264546, 6.453169824806866, 6.791630075247883, 7.1323055366564265, 7.475117461233266, 7.819992951052848, 8.166864314271102, 8.515668513508373, 8.866346690374842, 9.21884375335369, 9.57310801876035, 9.929090896443888, 10.286746613425821, 10.64603196988207, 11.006906122839736, 11.369330393736309, 11.733268096617062, 12.098684384257574, 12.465546109917259, 12.833821702774888, 13.203481055382843, 13.574495421714834, 13.94683732458084, 14.320480471350207, 14.695399677065065, 15.071570794145785, 15.44897064799189, 15.827576977868882, 16.207368382545642, 16.58832427021145, 16.970424812256507, 17.353650900547958, 17.73798410787479, 18.123406651271022, 18.50990135795831, 18.897451633676514, 19.286041433195077, 19.6756552328194, 20.066278004725017, 20.45789519296921, 20.850492691044128, 21.24405682084875, 21.638574312968515, 22.034032288161786, 22.430418239961565, 22.82772001830916, 23.225925814143785, 23.625024144878903, 24.025003840701906, 24.425854031639233, 24.82756413533376, 25.230123845485803, 25.633523120912997, 26.037752175187766, 26.442801466814636, 26.848661689912312, 27.25532376536834, 27.662778832436548, 28.071018240749645, 28.480033542721568, 28.889816486315812, 29.300359008157873, 29.711653226971364, 30.123691437319025, 30.53646610363076, 30.949969854502562, 31.364195477250814, 31.77913591270787, 32.19478425024556, 32.61113372301413, 33.02817770338508, 33.44590969858698, 33.86432334652403, 34.283412411768, 34.703170781714334, 35.12359246289431, 35.54467157743508, 35.966402359660506, 36.38877915282548, 36.81179640597748, 37.235448670938986], [0.0, 0.19375054284224735, 0.42995937506866166, 0.6853814893257683, 0.954139593611111, 1.2332707547625268, 1.5209567545525322, 1.8159574738609232, 2.1173683303242172, 2.4244979085962046, 2.736799160557139, 3.053827600261279, 3.375214366373753, 3.700648046789711, 4.029861951139044, 4.362624920897746, 4.698734520902033, 5.038011883386756, 5.380297728941371, 5.725449244720859, 6.073337599470213, 6.423845939881768, 6.776867756416242, 7.1323055366564265, 7.490069645226261, 7.8500773842523, 8.212252199170724, 8.576523002641837, 8.942823595263292, 9.311092166245201, 9.681270860621074, 10.053305402197193, 10.427144763488457, 10.802740875494594, 11.180048371441943, 11.5590243596302, 11.939628221338607, 12.32182143040553, 12.705567391632332, 13.090831295602309, 13.477579987867916, 13.865781850759621, 14.255406696319566, 14.64642566907236, 15.038811157520746, 15.432536713402307, 15.82757697786888, 16.22390761385713, 16.62150524401019, 17.02034739358821, 17.42041243787311, 17.821679553630723, 18.22412867424372, 18.62774044817239, 19.032496200438064, 19.438377896857393, 19.845368110784317, 20.253449992142276, 20.662607238551473, 21.07282406837562, 21.484085195530273, 21.89637580590999, 22.30968153530551, 22.72398844869418, 23.139283020797762, 23.555552117811445, 23.972782980216532, 24.39096320659706, 24.810080738387622, 25.2301238454858, 25.651081112668486, 26.072941426756145, 26.495693964474043, 26.91932818096331, 27.343833798898647, 27.76920079817292, 28.195419406111828, 28.62248008818488, 29.050373539181358, 29.479090674822253, 29.908622623781515, 30.338960720091617, 30.770096495910522, 31.20202167462856, 31.634728164295456, 32.068208051348826, 32.502453594627106, 32.93745721965073, 33.37321151315662, 33.80970921787207, 34.24694322751487, 34.68490658200756, 35.1235924628943, 35.56299418894976, 36.003105211969896, 36.44391911273537, 36.88542959713861, 37.32763049246637, 37.77051574382998, 38.21407941073594, 38.65831566378998, 39.10321878152813], [0.0, 0.20306309908905887, 0.45062523130541515, 0.7183241256468775, 1.0000000000000002, 1.2925475087927065, 1.5940610417352046, 1.9032408737888233, 2.2191389441356906, 2.541030604777925, 2.8683425139074634, 3.2006088215074757, 3.537442937044101, 3.878518480491886, 4.223555943095618, 4.572313055772706, 4.924577653379666, 5.280162270930928, 5.638899973303359, 6.000641083399421, 6.3652505777321196, 6.732605986477914, 7.102595680751474, 7.475117461233266, 7.8500773842523, 8.227388777088986, 8.606971405609526, 8.98875076568457, 9.372657476059228, 9.758626755028285, 10.146597966845276, 10.536514226549045, 10.928322054035169, 11.32197106988266, 11.717413726778766, 12.11460507144769, 12.513502532843189, 12.91406573305632, 13.316256317952234, 13.720037805011039, 14.12537544622755, 14.532236104239324, 14.940588140114222, 15.350401311447898, 15.76164667960554, 16.174296525097684, 16.58832427021145, 17.00370440813054, 17.42041243787311, 17.83842480445831, 18.25771884378308, 18.678272731751346, 19.1000654372504, 19.523076678615123, 19.947286883260134, 20.37267715019497, 20.799229215167557, 21.226925418207934, 21.655748673367768, 22.0856824404716, 22.516710698714363, 22.948817921955495, 23.381989055574728, 23.816209494767122, 24.251465064166382, 24.687741998695678, 25.125026925554234, 25.5633068472561, 26.00256912564488, 26.442801466814636, 26.8839919068733, 27.326128798490025, 27.76920079817292, 28.21319685422793, 28.6581061953535, 29.10391831982933, 29.550622985260734, 29.998210198843147, 30.446670208113947, 30.895993492161242, 31.346170753261607, 31.79719290892062, 32.24905108429221, 32.70173660495417, 33.155240990019294, 33.60955594556243, 34.0646733583456, 34.52058528982439, 34.97728397041965, 35.43476179404024, 35.89301131284284, 36.35202523221614, 36.81179640597748, 37.27231783177059, 37.73358264665419, 38.19558412287125, 38.658315663789985, 39.1217708000077, 39.585943185609516, 40.05082659457404, 40.51641491731908, 40.9827021573804], [0.0, 0.21243171250895657, 0.4714154861980624, 0.7514650610189912, 1.046136464290781, 1.352181080776259, 1.6676053820645462, 1.9910496783991363, 2.3215221687880883, 2.6582647725370436, 3.000677695874084, 3.348273596109714, 3.700648046789712, 4.057459609868234, 4.418415881044365, 4.783263413796635, 5.151780254431996, 5.523770288993262, 5.899058880560956, 6.277489446465472, 6.658920733713531, 7.04322462215695, 7.43028433274832, 7.819992951052848, 8.212252199170724, 8.606971405609526, 9.004066634516203, 9.403459944404306, 9.805078753013156, 10.208855289838707, 10.614726121615544, 11.022631738911532, 11.432516194239318, 11.844326783849557, 12.258013766764602, 12.67353011572345, 13.090831295602307, 13.509875065598273, 13.930621302052325, 14.353031839270095, 14.7770703260963, 15.20270209632776, 15.62989405132387, 16.058614553402673, 16.488833328803068, 16.92052137915636, 17.353650900547958, 17.788195209367252, 18.224128674243723, 18.66142665345298, 19.1000654372504, 19.54002219465326, 19.981274924247685, 20.423802408644228, 20.86758417224763, 21.31260044204255, 21.758832111128907, 22.206260704768155, 22.654868348726726, 23.104637739723948, 23.555552117811448, 24.00759524052743, 24.460751358684682, 24.915005193664204, 25.37034191609842, 25.826747125838516, 26.284206833109977, 26.742707440768807, 27.20223572757876, 27.66277883243654, 28.12432423947841, 28.586859764006846, 29.05037353918135, 29.514854003421792, 29.98028988847684, 30.446670208113943, 30.913984247390548, 31.382221552469414, 31.851371920943784, 32.32142539264054, 32.79237224087218, 33.26420296411011, 33.73690827805423, 34.21047910807516, 34.684906582007564, 35.16018202327387, 35.63629694432003, 36.11324304034523, 36.591012183309424, 37.06959641620331, 37.54898794756641, 38.029179146239855, 38.51016253634136, 38.991930792450724, 39.47447673499479, 39.95779332582162, 40.44187366395417, 40.926710981514375, 41.41229863980927, 41.89863012557087, 42.38569904734244, 42.87349913200409], [0.0, 0.2218545442391117, 0.4923260590544871, 0.7847977905697834, 1.0925399308606598, 1.4121597658905016, 1.7415753403250518, 2.0793666526604224, 2.4244979085962046, 2.776177401258895, 3.133778731829151, 3.496792940561795, 3.864797661861691, 4.237436312518396, 4.6144035180558145, 4.995434589827204, 5.380297728941371, 5.76878812241594, 6.160723386963029, 6.555939994376837, 6.954290426106224, 7.355640878978644, 7.759869393979436, 8.166864314271102, 8.576523002641837, 8.98875076568457, 9.403459944404306, 9.820569140064721, 10.240002550874394, 10.661689400233586, 11.085563441168047, 11.511562524586251, 11.939628221338607, 12.36970548989599, 12.801742382920619, 13.235689787163656, 13.671501192057189, 14.109132483123368, 14.548541756938357, 14.989689154892398, 15.432536713402307, 15.877048228576415, 16.323189133617987, 16.77092638749267, 17.220228373586384, 17.671064807250033, 18.123406651271022, 18.577226038434038, 19.032496200438064, 19.489191402525957, 19.947286883260134, 20.40675879894416, 20.86758417224763, 21.329740844641524, 21.79320743229477, 22.257963285120557, 22.72398844869418, 23.191263628793276, 23.659770158337043, 24.12948996652333, 24.60040554998287, 25.072499945787126, 25.545756706162315, 26.02015987477586, 26.495693964474043, 26.97234393636078, 27.450095180117238, 27.92893349547101, 28.40884507473158, 28.889816486315812, 29.371834659193894, 29.854886868191777, 30.33896072009162, 30.824044140476367, 31.31012536126896, 31.797192908920625, 32.28523559320619, 32.774242496587625, 33.26420296411012, 33.75510659379724, 34.24694322751487, 34.739702942275194, 35.23337604195449, 35.727953049400135, 36.223424698904196, 36.71978192902225, 37.21701587571786, 37.71511786581424, 38.21407941073594, 38.713892200524676, 39.21454809811419, 39.71603913385038, 40.218357500243314, 40.72149554693918, 41.22544577590056, 41.73020083678427, 42.23575352250667, 42.74209676498699, 43.24922363105982, 43.75712731854819, 44.265801152489594, 44.775238581507395], [0.0, 0.23132988185617595, 0.5133531497693483, 0.8183162566993758, 1.1392019667478823, 1.472472664131727, 1.8159574738609232, 2.1681757466151854, 2.5280474496461975, 2.8947470625295733, 3.267621433149947, 3.646139864251938, 4.029861951139044, 4.418415881044364, 4.811483237044234, 5.208788025723286, 5.6100885481327865, 6.015171243792477, 6.423845939881768, 6.835942123956763, 7.251305976995524, 7.669797981134205, 8.091290968527092, 8.515668513508373, 8.942823595263292, 9.372657476059228, 9.805078753013156, 10.240002550874394, 10.677349830380914, 11.117046792086725, 11.5590243596302, 12.003217729551713, 12.44956597721112, 12.89801171027295, 13.348500762745003, 13.800981923767075, 14.255406696319568, 14.711729081809192, 15.169905387130099, 15.629894051323872, 16.091655489394668, 16.55515195119402, 17.020347393588207, 17.487207364370718, 17.955698896591862, 18.425790412154722, 18.897451633676514, 19.37065350374195, 19.845368110784317, 20.321568620923113, 20.799229215167557, 21.278325031464473, 21.758832111128907, 22.24072734924806, 22.72398844869418, 23.20859387742175, 23.694522828758895, 24.181755184433094, 24.6702714800984, 25.160052873154417, 25.651081112668486, 26.14333851123075, 26.636807918588186, 27.13147269691829, 27.6273166976159, 28.12432423947841, 28.62248008818488, 29.121769436973754, 29.622177888432407, 30.123691437319017, 30.626296454344214, 31.12997967084578, 31.634728164295453, 32.14052934458162, 32.647370941016376, 33.155240990019294, 33.66412782343421, 34.17402005743849, 34.684906582007564, 35.19677655089986, 35.70961937213057, 36.22342469890419, 36.73818242097861, 37.253882656435, 37.77051574382998, 38.28807223470769, 38.806542886451496, 39.32591865545596, 39.84619069060124, 40.36735032701336, 40.889389080094546, 41.41229863980927, 41.936070865212166, 42.460697779205226, 42.986171563512215, 43.51248455385911, 44.03962923535001, 44.567598238028644, 45.09638433261629, 45.62598042641713, 46.15637955938313, 46.687574900330425], [0.0, 0.24085612645991733, 0.5344932101608733, 0.8520148033894351, 1.1861146980440957, 1.533109598099309, 1.8907392311816087, 2.257461974319211, 2.632153318641398, 3.0139537485069745, 3.402183214770393, 3.796289165879608, 4.195813061120282, 4.600367776347078, 5.009621782117204, 5.4232877195109195, 5.841113936333124, 6.262878077609064, 6.688382139135573, 7.117448586707298, 7.549917266981738, 7.985642916701121, 8.424493131203832, 8.866346690374842, 9.311092166245201, 9.758626755028285, 10.208855289838707, 10.661689400233586, 11.117046792086725, 11.574850626865405, 12.035028983619517, 12.497514390260537, 12.962243413250555, 13.429156296817856, 13.898196644395936, 14.369311136243645, 14.842449278217325, 15.317563177485699, 15.794607341645694, 16.273538498244243, 16.754315432161672, 17.23689883868533, 17.721251190412776, 18.207336616383714, 18.69512079205805, 19.184570838941905, 19.6756552328194, 20.168343719680813, 20.662607238551473, 21.158417850522373, 21.655748673367764, 22.15457382120651, 22.654868348726726, 23.1566081995473, 23.65977015833704, 24.164331806353353, 24.6702714800984, 25.177568232822242, 25.68620179863043, 26.196152558977758, 26.707401511351843, 27.21993023996917, 27.733720888323365, 28.248756133440626, 28.76501916171064, 29.28249364617346, 29.80116372515353, 30.32101398214173, 30.842029426834998, 31.364195477250806, 31.887497942840934, 32.41192300853506, 32.93745721965073, 33.464087467611186, 33.991800976417345, 34.52058528982439, 35.050428259177444, 35.58131803186414, 36.11324304034523, 36.64619199172718, 37.18015385784355, 37.715117865814236, 38.251073489053866, 38.78801043870276, 39.32591865545596, 39.864788301766914, 40.40460975440484, 40.9453735973455, 41.487070614976886, 42.029691785602495, 42.57322827522589, 43.117671431601394, 43.6630127785367, 44.20924401043414, 44.75635698705816, 45.30434372851728, 45.853196410449584, 46.40290735940145, 46.95346904838995, 47.50487409263962, 48.057115245485214, 48.61018539443236], [0.0, 0.25043178147798134, 0.5557429191270674, 0.8858881366006566, 1.2332707547625266, 1.5940610417352046, 1.965908864078315, 2.3472113089124327, 2.736799160557139, 3.133778731829151, 3.5374429370441, 3.947217257000125, 4.362624920897747, 4.783263413796636, 5.208788025723287, 5.638899973303359, 6.073337599470213, 6.511869709139601, 6.954290426106224, 7.400415157983028, 7.850077384252299, 8.30312606646232, 8.759423535973431, 9.21884375335369, 9.681270860621074, 10.146597966845276, 10.614726121615544, 11.085563441168047, 11.5590243596302, 12.035028983619517, 12.513502532843189, 12.994374852742238, 13.477579987867918, 13.963055806753676, 14.450743670689237, 14.940588140114222, 15.432536713402307, 15.926539593659248, 16.422549479852215, 16.92052137915636, 17.420412437873107, 17.92218178866247, 18.42579041215472, 18.931201011277025, 19.438377896857396, 19.947286883260134, 20.45789519296921, 20.97017136917405, 21.484085195530277, 21.999607622368874, 22.516710698714363, 23.0353675095473, 23.555552117811448, 24.077239510722354, 24.60040554998287, 25.12502692555423, 25.651081112668486, 26.178546331801158, 26.707401511351847, 27.237626252805892, 27.769200798172918, 28.302105999517845, 28.836323290417777, 29.371834659193897, 29.90862262378152, 30.446670208113943, 30.98596091990707, 31.52647872974159, 32.068208051348826, 32.61113372301413, 33.155240990019294, 33.700515488051806, 34.24694322751487, 34.79451057867742, 35.34320425760825, 35.89301131284284, 36.44391911273537, 36.9959153334522, 37.54898794756642, 38.103125213215804, 38.65831566378997, 39.214548098114186, 39.77181157110033, 40.33009538483717, 40.88938908009455, 41.44968242821713, 42.010965423385805, 42.573228275225894, 43.13646140174266, 43.70065542256634, 44.26580115248959, 44.83188959528161, 45.398911937764304, 45.9668595441365, 46.53572395053339, 47.105496859809, 47.676170136530274, 48.24773580217207, 48.82018603050314, 49.39351314315339, 49.96770960535379, 50.542768021840345], [0.0, 0.26005544291247557, 0.5770991610015304, 0.9199312897706118, 1.2806632228065287, 1.6553180582410172, 2.0414553510589393, 2.437410591203508, 2.8419696320522903, 3.2542044435649196, 3.6733807679737116, 4.098902008294768, 4.53027307224909, 4.967075976941418, 5.4089527657885, 5.855593173686239, 6.3067254885382145, 6.76210963083184, 7.2215318128943276, 7.68480034877156, 8.151742318849532, 8.62220088052933, 9.09603307480291, 9.57310801876035, 10.053305402197193, 10.536514226549045, 11.022631738911532, 11.511562524586251, 12.003217729551713, 12.497514390260537, 12.994374852742238, 13.493726266519134, 13.995500141588339, 14.499631958878204, 15.006060826293949, 15.514729173828512, 16.025582482308614, 16.53856904123126, 17.053639731866504, 17.570747832392843, 18.089848842317977, 18.61090032384052, 19.133861758143677, 19.658694414892427, 20.185361233441448, 20.713826714460033, 21.244056820848748, 21.776018886966032, 22.30968153530551, 22.845014599869494, 23.381989055574724, 23.92057695310398, 24.460751358684682, 25.00248629833422, 25.54575670616231, 26.09053837636561, 26.636807918588186, 27.18454271635599, 27.733720888323365, 28.284321252095914, 28.836323290417777, 29.389707119531742, 29.944453459539307, 30.5005436066039, 31.05795940685525, 31.61668323186569, 32.17669795558108, 32.73798693259919, 33.3005339776979, 33.864323346524024, 34.42933971736099, 34.99556817390052, 35.56299418894975, 36.131603609010554, 36.701382639673156, 37.27231783177059, 37.844396068244684, 38.41760455167813, 38.991930792450724, 39.567362597480745, 40.14388805951575, 40.721495546939174, 41.30017369406203, 41.87991139187083, 42.460697779205226, 43.04252223434029, 43.62537436695057, 44.20924401043414, 44.79412121457675, 45.37999623853722, 45.96685954413649, 46.55470178943416, 47.1435138225769, 47.733286675904566, 48.324011560300654, 48.91567985977416, 49.508283126261375, 50.101813074636205, 50.69626157791881, 51.29162066267261, 51.887882504580354, 52.485039424190845], [0.0, 0.2697257908019835, 0.5985590066064778, 0.954139593611111, 1.3282856019236067, 1.7168722457315782, 2.1173683303242172, 2.5280474496461975, 2.947650308163392, 3.3752143663737524, 3.8099780626086455, 4.251322614998061, 4.6987345209020335, 5.151780254431996, 5.610088548132787, 6.0733375994702135, 6.541245592538951, 7.013563520297804, 7.490069645226261, 7.970565153390721, 8.454870695037492, 8.942823595263292, 9.434275579026979, 9.929090896443888, 10.427144763488457, 10.928322054035169, 11.432516194239318, 11.939628221338607, 12.44956597721112, 12.962243413250555, 13.477579987867918, 13.995500141588339, 14.515932837559127, 15.038811157520746, 15.564071945062262, 16.091655489394668, 16.62150524401019, 17.153567575513733, 17.68779153866021, 18.224128674243723, 18.76253282698929, 19.302959981015498, 19.845368110784317, 20.38971704574549, 20.93596834712706, 21.484085195530273, 22.034032288161786, 22.585775744684756, 23.139283020797766, 23.694522828758895, 24.251465064166382, 24.810080738387622, 25.37034191609842, 25.932221657455013, 26.495693964474043, 27.06073373124203, 27.6273166976159, 28.195419406111828, 28.765019161710644, 29.336093994335446, 29.90862262378152, 30.4825844268999, 31.057959406855254, 31.634728164295456, 32.212871870285554, 32.79237224087218, 33.373211513156626, 33.95537242276542, 34.53883818261739, 35.1235924628943, 35.70961937213057, 36.29690343934432, 36.88542959713861, 37.47518316570735, 38.066149837685764, 38.65831566378998, 39.251667039194615, 39.84619069060123, 40.44187366395417, 41.038703312763225, 41.636667286996236, 42.235753522506656, 42.83595023096421, 43.43724589025879, 44.039629235350006, 44.64308924953651, 45.24761515612113, 45.853196410449584, 46.45982269230177, 47.06748389861635, 47.67617013653027, 48.28587171671634, 48.896579147003045, 49.508283126261375, 50.12097453854522, 50.73464444747178, 51.34928409083006, 51.9648848754056, 52.58143837201102, 53.19893631071176, 53.817370576237764, 54.436733203571904], [0.0, 0.2794415817141558, 0.6201196965927589, 0.9885086495511721, 1.3761317687345995, 1.7787156894484073, 2.193638040833985, 2.6191102299749978, 3.053827600261279, 3.496792940561795, 3.9472172570001245, 4.4044594785686435, 4.867987605752214, 5.337352496629129, 5.812169510321701, 6.292105252648795, 6.776867756416243, 7.266199045101876, 7.759869393979437, 8.257672827639947, 8.759423535973431, 9.264952984365003, 9.774107556759251, 10.286746613425821, 10.802740875494594, 11.32197106988266, 11.844326783849557, 12.36970548989599, 12.89801171027295, 13.429156296817856, 13.963055806753676, 14.499631958878204, 15.038811157520746, 15.580524073959587, 16.124705276827136, 16.671292904492454, 17.220228373586387, 17.77145611878567, 18.32492335974689, 18.88057989171541, 19.438377896857396, 19.998271773795665, 20.56021798319056, 21.12417490750871, 21.690102723375396, 22.25796328512056, 22.827720018309165, 23.399337822200984, 23.972782980216536, 24.548023077598362, 25.125026925554234, 25.703764491252215, 26.28420683310998, 26.866326040883834, 27.450095180117238, 28.03548824055676, 28.622480088184883, 29.211046420555906, 29.801163725153536, 30.392809240516865, 30.985960919907072, 31.580597397308885, 32.17669795558109, 32.77424249658763, 33.373211513156626, 33.97358606272853, 34.57534774256738, 35.17847866641983, 35.78296144251737, 36.38877915282548, 36.99591533345221, 37.60435395613555, 38.21407941073595, 38.82507648866611, 39.43733036719579, 40.05082659457404, 40.665551075916156, 41.28149005980631, 41.898630125570875, 42.51695817118052, 43.13646140174266, 43.75712731854819, 44.37894370863948, 45.001898634868574, 45.62598042641714, 46.251177669751286, 46.87747919998652, 47.504874092639625, 48.13335165574593, 48.7629014223218, 49.3935131431534, 50.02517677989438, 50.65788249845575, 51.291620662672614, 51.92638182823342, 52.562156736857986, 53.19893631071177, 53.8367116470442, 54.47547401304018, 55.1152148408739, 55.75592572295521, 56.39759840735917], [0.0, 0.2892016421169105, 0.6417786267296286, 1.0230343062880207, 1.4241959440896412, 1.8408409195657423, 2.2702552702705865, 2.7105879330756664, 3.160488683609419, 3.6189254811323686, 4.085081774566894, 4.558294102208472, 5.038011883386756, 5.523770288993261, 6.015171243792477, 6.5118697091396, 7.013563520297803, 7.519985690394975, 8.030898471105829, 8.546088692915124, 9.065364055920329, 9.58855013909548, 10.115487961034852, 10.64603196988207, 11.180048371441943, 11.717413726778766, 12.258013766764602, 12.801742382920619, 13.348500762745003, 13.898196644395936, 14.450743670689237, 15.006060826293949, 15.564071945062262, 16.124705276827136, 16.687893104898603, 17.253571407003594, 17.82167955363072, 18.392160038725827, 18.96495823848563, 19.54002219465326, 20.117302419260678, 20.69675171821069, 21.27832503146447, 21.8619792879124, 22.44767327326817, 23.035367509547296, 23.6250241448789, 24.216606852558666, 24.81008073838762, 25.40541225545757, 26.002569125644875, 26.601520267160407, 27.202235727578753, 27.804686621834716, 28.408845074731577, 29.014684167555384, 29.622177888432404, 30.231301086105045, 30.842029426834994, 31.45433935417146, 32.068208051348826, 32.683613406100676, 33.3005339776979, 33.91894896603653, 34.53883818261738, 35.16018202327387, 35.78296144251736, 36.407157929381086, 37.03275348465396, 37.65973059940501, 38.28807223470769, 38.917761802480626, 39.548783147368695, 40.18112052959404, 40.81475860871267, 41.44968242821713, 42.08587740093046, 42.72332929514091, 43.36202422143079, 44.001948620155986, 44.6430892495365, 45.28543317432064, 45.928967754988605, 46.573680637463475, 47.219559743300096, 47.86659326032388, 48.51476963369425, 49.164077557368415, 49.814505965943276, 50.46604402685468, 51.11868113291437, 51.77240689516652, 52.42721113604674, 53.08308388282769, 53.74001536133616, 54.39799598992792, 55.05701637370673, 55.717067298975515, 56.37813972790803, 57.04022479342987, 57.70331379429886, 58.36739819037494], [0.0, 0.2990048625025113, 0.6635333348652602, 1.057712639001351, 1.472472664131727, 1.903240873788823, 2.3472113089124322, 2.802470159912224, 3.267621433149947, 3.741598104257604, 4.223555943095617, 4.712808998248619, 5.208788025723287, 5.711012439854024, 6.2190706716393915, 6.732605986477912, 7.251305976995524, 7.774894606125491, 8.30312606646232, 8.835779962571436, 9.372657476059226, 9.913578273458345, 10.458377984286617, 11.006906122839736, 11.5590243596302, 12.11460507144769, 12.67353011572345, 13.235689787163656, 13.800981923767075, 14.369311136243645, 14.940588140114222, 15.514729173828512, 16.091655489394668, 16.671292904492454, 17.253571407003594, 17.838424804458306, 18.42579041215472, 19.015608774725678, 19.607823416756062, 20.20238061873261, 20.799229215167557, 21.398320412200544, 21.99960762236887, 22.60304631455884, 23.208593877421755, 23.81620949476712, 24.425854031639236, 25.03748992994836, 25.651081112668486, 26.266592895734203, 26.8839919068733, 27.503246010700888, 28.12432423947841, 28.747196729008394, 29.371834659193894, 29.998210198843143, 30.626296454344217, 31.256067421874103, 31.88749794284094, 32.52056366228852, 33.155240990019294, 33.79150706421572, 34.429339717360996, 35.068717444279066, 35.70961937213057, 36.35202523221614, 36.99591533345221, 37.641270537396, 38.2880722347077, 38.93630232294687, 39.58594318560951, 40.236977672319306, 40.889389080094546, 41.54316113561785, 42.198277978442114, 42.85472414507126, 43.51248455385911, 44.1715444906741, 44.831889595281616, 45.49350584839915, 46.156379559383126, 46.820497354508795, 47.4858461658079, 48.15241322043087, 48.82018603050314, 49.489152383446616, 50.1593003327402, 50.83061818909421, 51.50309451201576, 52.17671810174355, 52.8514779915319, 53.52736344026505, 54.20436392538438, 54.88246913611171, 55.56166896695359, 56.241953511471706, 56.92331305630609, 57.60573807543813, 58.28921922468161, 58.97374733639025, 59.65931341437126, 60.34590862899498], [0.0, 0.30885019215987414, 0.6853814893257683, 1.09253993086066, 1.520956754552532, 1.9659088640783149, 2.424497908596205, 2.8947470625295733, 3.375214366373752, 3.8647976618616906, 4.362624920897746, 4.867987605752213, 5.380297728941372, 5.899058880560956, 6.423845939881769, 6.954290426106224, 7.490069645226261, 8.03089847110583, 8.576523002641835, 9.12671558744177, 9.681270860621073, 10.240002550874394, 10.802740875494592, 11.369330393736309, 11.939628221338607, 12.513502532843189, 13.090831295602307, 13.671501192057189, 14.255406696319568, 14.842449278217325, 15.432536713402307, 16.025582482308614, 16.62150524401019, 17.220228373586387, 17.82167955363072, 18.42579041215472, 19.032496200438064, 19.641735505427402, 20.25344999214228, 20.867584172247632, 21.484085195530273, 22.102902661494973, 22.723988448694175, 23.347296559738723, 23.972782980216532, 24.60040554998287, 25.230123845485803, 25.861899071960806, 26.495693964474047, 27.13147269691829, 27.769200798172918, 28.40884507473158, 29.050373539181354, 29.69375534398668, 30.33896072009162, 30.985960919907065, 31.634728164295453, 32.28523559320618, 32.93745721965073, 33.59136788673753, 34.24694322751487, 34.90415962739441, 35.56299418894976, 36.223424698904196, 36.88542959713861, 37.54898794756641, 38.21407941073594, 38.88068421803315, 39.5487831473687, 40.218357500243314, 40.889389080094546, 41.56186017183587, 42.23575352250666, 42.91105232295821, 43.587740190506665, 44.265801152489594, 44.945219630667616, 45.62598042641713, 46.30806870666425, 46.99146999051371, 47.67617013653026, 48.36215533063269, 49.04941207456388, 49.73792717490283, 50.42768773258682, 51.118681132914375, 51.81089503600142, 52.50431736766517, 53.19893631071176, 53.8947402966055, 54.591717997498755, 55.28985831860321, 55.98915039088406, 56.689583564060264, 57.3911473998949, 58.09383166576047, 58.79762632846532, 59.50252154832772, 60.208507673485556, 60.91557523442956, 61.623714938749416, 62.33291766608234], [0.0, 0.31873663450751405, 0.7073208785583681, 1.1275126565158122, 1.5696433076091456, 2.0288385469433448, 2.5021072460801266, 2.9874093003108086, 3.483256592317412, 3.98851168321969, 4.502274630885642, 5.023814216954003, 5.552523632180513, 6.087890576342481, 6.629476320392869, 7.176900588287549, 7.729830356428944, 8.287971371657038, 8.851061605373008, 9.418866117922393, 9.991172970592467, 10.567789929444325, 11.148541776945175, 11.733268096617062, 12.32182143040553, 12.91406573305632, 13.509875065598273, 14.109132483123368, 14.711729081809192, 15.317563177485699, 15.926539593659248, 16.53856904123126, 17.153567575513733, 17.77145611878567, 18.392160038725827, 19.015608774725678, 19.641735505427402, 20.270476851916445, 20.901772611881725, 21.535565520780047, 22.171801036637618, 22.810427145615257, 23.45139418587486, 24.094654687628843, 24.740163227542748, 25.38787629590544, 26.037752175187766, 26.68975082878623, 27.343833798898647, 27.999964112606964, 28.6581061953535, 29.318225791091894, 29.98028988847684, 30.64426665252841, 31.31012536126896, 31.977836346885294, 32.647370941016376, 33.31870142380855, 33.991800976417345, 34.66664363666707, 35.34320425760825, 36.02145846873826, 36.701382639673156, 37.3829538460786, 38.06614983768576, 38.750949008233896, 39.437330367195784, 40.12527351315458, 40.81475860871267, 41.50576635682289, 42.19827797844211, 42.89227519141541, 43.587740190506665, 44.28465562849827, 44.983004598288815, 45.68277061592332, 46.3839376044955, 47.08648987886656, 47.790412131148805, 48.49568941690661, 49.202307142030605, 49.91025105024423, 50.61950721120472, 51.330062009163335, 52.04190213215221, 52.755014561667224, 53.46938656281873, 54.185005674923566, 54.90185970251384, 55.6199367067395, 56.33922499714311, 57.05971312378686, 57.781389869712946, 58.50424424371973, 59.22826547343735, 59.95344299868699, 60.67976646510975, 61.407225718050974, 62.13581079668783, 62.86551192838753, 63.596319523285246, 64.32822416907104], [0.0, 0.32866324291343185, 0.7293494018551251, 1.162627467310129, 1.6185276615387794, 2.092023896834034, 2.580031890229751, 3.0804480007984467, 3.591737765881575, 4.112728322649685, 4.64249170152691, 5.180273911374883, 5.72544924472086, 6.277489446465471, 6.835942123956763, 7.400415157983027, 7.97056515339072, 8.546088692915124, 9.12671558744177, 9.71220358044799, 10.30233413268513, 10.896909023356082, 11.495747578022117, 12.098684384257574, 12.705567391632332, 13.316256317952234, 13.930621302052325, 14.548541756938357, 15.169905387130099, 15.794607341645694, 16.422549479852215, 17.053639731866504, 17.68779153866021, 18.32492335974689, 18.96495823848563, 19.607823416756062, 20.25344999214228, 20.901772611881725, 21.552729198746224, 22.20626070476816, 22.862310889339962, 23.520826118723893, 24.181755184433094, 24.845049138299576, 25.51066114234242, 26.178546331801158, 26.848661689912316, 27.520965933188155, 28.19541940611183, 28.871983984295262, 29.550622985260734, 30.231301086105052, 30.91398424739055, 31.598639642681214, 32.28523559320619, 32.97374150718959, 33.66412782343421, 34.356365958790164, 35.05042825917745, 35.74628795386458, 36.44391911273537, 37.14329660630185, 37.84439606824469, 38.5471938602831, 39.251667039194615, 39.95779332582162, 40.665551075916156, 41.374919252687675, 42.085877400930464, 42.79840562261769, 43.51248455385911, 44.228095343127556, 44.945219630667616, 45.66383952900677, 46.38393760449551, 47.105496859809, 47.828500717348156, 48.55293300348235, 49.27877793358108, 50.006020097785076, 50.73464444747178, 51.464636282372744, 52.1959812383041, 52.92866527547357, 53.66267466733061, 54.39799598992792, 55.13461611176546, 55.87252218408945, 56.61170163162114, 57.35214214369163, 58.09383166576047, 58.83675839129749, 59.580910754008364, 60.32627742038581, 61.07284728256947, 61.82060945149853, 62.56955325034196, 63.31966820819256, 64.07094405401153, 64.82337071081106, 65.57693829006337, 66.33163708632517], [0.0, 0.3386291169396208, 0.7514650610189912, 1.197881177995542, 1.6676053820645462, 2.1554591822368385, 2.658264772537044, 3.173854724495471, 3.7006480467897114, 4.237436312518397, 4.783263413796636, 5.33735249662913, 5.899058880560958, 6.467838292505074, 7.043224622156951, 7.624813860290555, 8.212252199170724, 8.80522702117857, 9.403459944404307, 10.006701366514502, 10.614726121615544, 11.22732997837055, 11.844326783849557, 12.465546109917259, 13.090831295602309, 13.720037805011039, 14.353031839270095, 14.989689154892398, 15.629894051323872, 16.273538498244243, 16.92052137915636, 17.570747832392843, 18.224128674243723, 18.88057989171541, 19.54002219465326, 20.20238061873261, 20.867584172247632, 21.535565520780047, 22.20626070476816, 22.879608885765446, 23.555552117811448, 24.234035140862208, 24.915005193664204, 25.598411843821182, 26.28420683310998, 26.972343936360783, 27.662778832436548, 28.355468986033134, 29.050373539181358, 29.747453211468372, 30.446670208113947, 31.147988135137997, 31.851371920943784, 32.5567877437174, 33.26420296411012, 33.97358606272853, 34.684906582007564, 35.39813507208626, 36.11324304034524, 36.83020290429888, 37.54898794756642, 38.26957227867229, 38.991930792450724, 39.716039133850394, 40.44187366395417, 41.16941142804584, 41.898630125570875, 42.62950808185173, 43.362024221430794, 44.09615804292436, 44.831889595281616, 45.569199455350955, 46.308068706664244, 47.04847891935702, 47.79041213114881, 48.53385082931433, 49.27877793358108, 50.02517677989439, 50.77303110499509, 51.52232503175928, 52.27304305525332, 53.02517002946065, 53.77869115464017, 54.53359196527875, 55.28985831860322, 56.04747638361936, 56.806432630647876, 57.56671382132935, 58.32830699907178, 59.091199479916654, 59.85537884380035, 60.62083292618981, 61.38754981007236, 62.155517818281, 62.92472550613789, 63.695161654399215, 64.46681526248632, 65.23967554198845, 66.01373191042376, 66.78897398524552, 67.56539157808156, 68.34297468919584], [0.0, 0.3486333989582464, 0.7736659528546398, 1.2332707547625268, 1.7168722457315782, 2.21913894413569, 2.736799160557139, 3.2676214331499476, 3.8099780626086455, 4.362624920897746, 4.924577653379666, 5.4950364550898385, 6.0733375994702135, 6.658920733713531, 7.251305976995525, 7.850077384252299, 8.454870695037492, 9.06536405592033, 9.681270860621073, 10.30233413268513, 10.928322054035167, 11.5590243596302, 12.194249396935188, 12.833821702774888, 13.477579987867916, 14.12537544622755, 14.7770703260963, 15.432536713402307, 16.091655489394668, 16.754315432161672, 17.420412437873107, 18.089848842317977, 18.76253282698929, 19.438377896857396, 20.117302419260678, 20.799229215167557, 21.484085195530273, 22.171801036637618, 22.862310889339962, 23.555552117811448, 24.25146506416638, 24.949992835786883, 25.651081112668482, 26.35467797246651, 27.06073373124203, 27.769200798172918, 28.480033542721568, 29.19318817294301, 29.90862262378152, 30.626296454344217, 31.346170753261607, 32.068208051348826, 32.79237224087218, 33.51862850080374, 34.24694322751487, 34.97728397041964, 35.70961937213057, 36.443919112735365, 37.18015385784355, 37.91829521008695, 38.65831566378998, 39.400188562552806, 40.14388805951575, 40.88938908009455, 41.63666728699624, 42.385699047342435, 43.13646140174266, 43.888932035174, 44.643089249536516, 45.398911937764304, 46.156379559383126, 46.91547211741391, 47.67617013653026, 48.438454642385395, 49.20230714203061, 49.96770960535379, 50.73464444747178, 51.50309451201575, 52.27304305525332, 53.04447373099509, 53.81737057623776, 54.59171799749875, 55.36750075780114, 56.144703964270214, 56.92331305630609, 57.703313794298865, 58.48469224885546, 59.26743479050927, 60.0515280798855, 60.83695905829738, 61.62371493874941, 62.41178319732591, 63.201151564944176, 63.99180801945312, 64.78374077805928, 65.57693829006335, 66.37138922989134, 67.16708249040529, 67.96400717648005, 68.76215259883233, 69.56150826809001, 70.36206388909007], [0.0, 0.35867527109431885, 0.7959502623838293, 1.2687933044249762, 1.7663242248509763, 2.2830579765513375, 2.8156286339080747, 3.3617404610997377, 3.9197188753370873, 4.488283913306976, 5.0664228674847, 5.653312895700387, 6.2482711537289815, 6.8507211486250155, 7.4601691773031, 8.076187314013723, 8.698400806324278, 9.32647853028944, 9.960125624357246, 10.599077710244403, 11.243096292694913, 11.891965050292642, 12.545486810233237, 13.203481055382843, 13.865781850759621, 14.532236104239324, 15.20270209632776, 15.877048228576415, 16.55515195119402, 17.23689883868533, 17.92218178866247, 18.61090032384052, 19.302959981015498, 19.998271773795665, 20.69675171821069, 21.398320412200544, 22.102902661494973, 22.810427145615257, 23.520826118723893, 24.234035140862208, 24.949992835786883, 25.668640672171893, 26.38992276540494, 27.113785697594615, 27.84017835372922, 28.569051772203004, 29.300359008157873, 30.034055008286302, 30.770096495910526, 31.508441865297247, 32.24905108429221, 32.99188560446582, 33.73690827805423, 34.484083281061025, 35.23337604195449, 35.98475317545732, 36.73818242097861, 37.49363258528561, 38.25107348905387, 39.01047591697081, 39.77181157110033, 40.535053027244224, 41.30017369406204, 42.067147774732994, 42.83595023096421, 43.60655674916703, 44.37894370863948, 45.15308815160728, 45.92896775498861, 46.70656080375961, 47.4858461658079, 48.26680326817083, 49.04941207456389, 49.83365306411215, 50.61950721120473, 51.40695596639866, 52.1959812383041, 52.98656537638826, 53.77869115464017, 54.57234175604251, 55.36750075780114, 56.164152117286164, 56.96228015864197, 57.76186956002647, 58.56290534144314, 59.36537285313106, 60.169257764481486, 60.97454605345107, 61.78122399644395, 62.58927815863711, 63.39869538472444, 64.2094627900573, 65.02156775216011, 65.83499790260142, 66.6497411192017, 67.4657855185608, 68.28311944888819, 69.10173148312116, 69.9216104123165, 70.74274523930184, 71.56512517257414, 72.38873962043336], [0.0, 0.36875395245613757, 0.8183162566993757, 1.3044460646230598, 1.815957473860923, 2.3472113089124322, 2.8947470625295733, 3.456204489314407, 4.029861951139044, 4.614403518055814, 5.208788025723286, 5.8121695103217, 6.423845939881769, 7.043224622156949, 7.669797981134205, 8.303126066462319, 8.94282359526329, 9.588550139095481, 10.240002550874394, 10.896909023356082, 11.559024359630198, 12.226126159705357, 12.898011710272947, 13.574495421714834, 14.255406696319566, 14.940588140114222, 15.62989405132387, 16.323189133617987, 17.020347393588207, 17.721251190412776, 18.42579041215472, 19.133861758143677, 19.845368110784317, 20.56021798319056, 21.27832503146447, 21.99960762236887, 22.723988448694175, 23.45139418587486, 24.181755184433094, 24.915005193664204, 25.651081112668482, 26.38992276540494, 27.131472696918287, 27.87567598828832, 28.62248008818488, 29.371834659193894, 30.12369143731902, 30.878004103266573, 31.634728164295453, 32.39382084556214, 33.155240990019294, 33.91894896603653, 34.68490658200756, 35.453077007291014, 36.22342469890419, 36.9959153334522, 37.77051574382998, 38.547193860283095, 39.32591865545596, 40.106660093093346, 40.88938908009455, 41.67407742164857, 42.460697779205226, 43.24922363105983, 44.039629235350006, 44.83188959528161, 45.62598042641713, 46.42187812587482, 47.219559743300096, 48.019002953482605, 48.82018603050313, 49.62308782330416, 50.42768773258681, 51.233965688944686, 52.0419021321522, 52.8514779915319, 53.6626746673306, 54.47547401304017, 55.289858318603216, 56.10581029444864, 56.923313056306085, 57.742350110751936, 58.562905341443134, 59.384962995997846, 60.20850767348556, 61.0335243124909, 61.85999817971875, 62.68791485911003, 63.51726024143941, 64.34802051436886, 65.18018215293161, 66.01373191042374, 66.84865680968146, 67.68494413472355, 68.5225814227405, 69.36155645641165, 70.2018572565342, 71.043472074948, 71.88638938774146, 72.73059788872453, 73.57608648315576, 74.4228442817111], [0.0, 0.3788686966201998, 0.8407622793838153, 1.3402263949262296, 1.865768316940916, 2.411594190046342, 2.974148586939376, 3.5510065218221305, 4.1403991328580885, 4.740974394771867, 5.351662584583203, 5.971594534090251, 6.600048954923302, 7.236416897571584, 7.880176863455313, 8.530876834596016, 9.188120959991025, 9.85155947340972, 10.520880912588384, 11.19580601474065, 11.876082857322448, 12.56148294001723, 13.251797989187496, 13.94683732458084, 14.64642566907236, 15.350401311447898, 16.058614553402673, 16.77092638749267, 17.487207364370718, 18.207336616383714, 18.931201011277025, 19.658694414892427, 20.38971704574549, 21.12417490750871, 21.8619792879124, 22.60304631455884, 23.347296559738723, 24.094654687628843, 24.845049138299576, 25.598411843821182, 26.35467797246651, 27.113785697594615, 27.87567598828832, 28.640292419227773, 29.407580997625004, 30.17749000533481, 30.949969854502562, 31.72497295531855, 32.50245359462711, 33.28236782429126, 34.0646733583456, 34.84932947808311, 35.63629694432004, 36.42553791616818, 37.21701587571786, 38.010695558099926, 38.8065428864515, 39.604524911360166, 40.404609754404845, 41.20676655545024, 42.01096542338581, 42.81717739003042, 43.625374366950574, 44.43552910496391, 45.24761515612113, 46.06160683797799, 46.87747919998651, 47.6952079918492, 48.514769633694264, 49.33614118794152, 50.1593003327402, 50.98422533686943, 51.810895036001426, 52.639288810235584, 53.469386562818734, 54.30116869997386, 55.13461611176546, 55.96971015393539, 56.80643263064788, 57.64476577808717, 58.48469224885547, 59.32619509712245, 60.16925776448149, 61.01386406647048, 61.859998179718765, 62.70764462968356, 63.55678827894253, 64.40741431601099, 65.25950824465434, 66.11305587366873, 66.96804330710403, 67.82445693490561, 68.68228342395226, 69.54150970946951, 70.40212298679894, 71.26411070350466, 72.12746055180008, 72.99216046127863, 73.85819859193337, 74.72556332745087, 75.59424326876623, 76.46422722786646], [0.0, 0.3890187893418007, 0.8632867454289082, 1.3761317687345995, 1.9157532367374435, 2.4762020736065464, 3.053827600261279, 3.646139864251938, 4.251322614998061, 4.867987605752213, 5.495036455089838, 6.13157670933336, 6.776867756416244, 7.43028433274832, 8.091290968527094, 8.759423535973431, 9.434275579026979, 10.115487961034853, 10.802740875494592, 11.495747578022117, 12.194249396935188, 12.89801171027295, 13.60682066463702, 14.320480471350207, 15.038811157520746, 15.76164667960554, 16.488833328803068, 17.220228373586384, 17.955698896591862, 18.69512079205805, 19.438377896857396, 20.185361233441448, 20.93596834712706, 21.690102723375396, 22.44767327326817, 23.208593877421755, 23.972782980216532, 24.740163227542748, 25.51066114234242, 26.28420683310998, 27.06073373124203, 27.84017835372922, 28.62248008818488, 29.407580997625004, 30.19542564276629, 30.985960919907072, 31.779135912707872, 32.57490175640282, 33.373211513156626, 34.1740200574385, 34.97728397041965, 35.78296144251737, 36.591012183309424, 37.40139733813022, 38.21407941073594, 39.02902219149296, 39.84619069060124, 40.665551075916156, 41.487070614976886, 42.31071762088878, 43.13646140174266, 43.96427221328448, 44.794121214576755, 45.62598042641714, 46.45982269230177, 47.295621641740155, 48.13335165574593, 48.972987834343314, 49.81450596594328, 50.65788249845575, 51.50309451201576, 52.350119693211525, 53.19893631071176, 54.04952319219781, 54.901859702513846, 55.755925722955205, 56.61170163162114, 57.46916828476393, 58.32830699907178, 59.18909953482688, 60.0515280798855, 60.915575234429554, 61.78122399644395, 62.64845774787628, 63.517260241439416, 64.38761558801939, 65.25950824465433, 66.13292300305204, 67.00784497861612, 67.88425959995288, 68.76215259883233, 69.64151000057927, 70.52231811487113, 71.40456352692124, 72.28823308902759, 73.17331391246789, 74.05979335972346, 74.94765903701514, 75.83689878713596, 76.72750068256528, 77.61945301885126, 78.51274430824809], [0.0, 0.399203546466394, 0.8858881366006566, 1.4121597658905016, 1.965908864078315, 2.541030604777925, 3.1337787318291515, 3.7415981042576045, 4.362624920897746, 4.995434589827204, 5.638899973303359, 6.292105252648795, 6.954290426106226, 7.624813860290555, 8.30312606646232, 8.98875076568457, 9.681270860621073, 10.380317812194995, 11.085563441168047, 11.796713496007422, 12.513502532843187, 13.235689787163658, 13.963055806753674, 14.695399677065065, 15.432536713402307, 16.174296525097684, 16.92052137915636, 17.671064807250033, 18.425790412154722, 19.184570838941905, 19.947286883260134, 20.713826714460033, 21.484085195530273, 22.25796328512056, 23.035367509547296, 23.81620949476712, 24.60040554998287, 25.38787629590544, 26.178546331801158, 26.972343936360783, 27.769200798172918, 28.569051772203004, 29.371834659193894, 30.17749000533481, 30.985960919907072, 31.797192908920625, 32.611133723014134, 33.42773321811134, 34.246943227514876, 35.068717444279066, 35.89301131284284, 36.71978192902225, 37.54898794756642, 38.380589496570096, 39.21454809811419, 40.05082659457403, 40.88938908009455, 41.73020083678427, 42.573228275225894, 43.418438878941906, 44.265801152489594, 45.115284572891596, 45.9668595441365, 46.8204973545088, 47.67617013653027, 48.533850829314325, 49.39351314315339, 50.255131526174644, 51.11868113291438, 51.984137794673956, 52.8514779915319, 53.72067882589725, 54.591717997498755, 55.46457377971311, 56.33922499714312, 57.215651004363735, 58.09383166576047, 58.97374733639025, 59.85537884380036, 60.738707470745716, 61.623714938749416, 62.51038339245518, 63.39869538472444, 64.2886338624337, 65.18018215293161, 66.07332395111719, 66.96804330710404, 67.86432461443725, 68.76215259883233, 69.66151230740732, 70.56238909838096, 71.46476863121227, 72.36863685715737, 73.27398001022205, 74.18078459848915, 75.08903739580153, 75.99872543378228, 76.90983599417532, 77.8223566014903, 78.73627501593661, 79.65157922663244, 80.5682574450756], [0.0, 0.40942231202002605, 0.9085649972017138, 1.448308065923507, 2.0162319685688574, 2.6060756081218908, 3.213996832196695, 3.837375093619951, 4.474298881862518, 5.12330713846511, 5.7832438733453895, 6.453169824806867, 7.132305536656427, 7.819992951052847, 8.515668513508373, 9.21884375335369, 9.929090896443888, 10.646031969882072, 11.369330393736309, 12.098684384257574, 12.833821702774886, 13.574495421714836, 14.320480471350207, 15.071570794145785, 15.82757697786888, 16.58832427021145, 17.353650900547958, 18.123406651271022, 18.897451633676514, 19.6756552328194, 20.45789519296921, 21.244056820848748, 22.034032288161786, 22.827720018309165, 23.6250241448789, 24.425854031639236, 25.230123845485803, 26.037752175187766, 26.848661689912316, 27.662778832436548, 28.480033542721568, 29.300359008157873, 30.12369143731902, 30.949969854502562, 31.779135912707872, 32.611133723014134, 33.44590969858698, 34.283412411768, 35.12359246289431, 35.966402359660506, 36.81179640597748, 37.65973059940502, 38.51016253634136, 39.363051324244914, 40.21835750024332, 41.07604295555538, 41.93607086521217, 42.79840562261769, 43.66301277853671, 44.5298589841387, 45.39891193776431, 46.27014033511259, 47.14351382257691, 48.01900295348262, 48.89657914700305, 49.776214649550234, 50.657882498455756, 51.54155648777291, 52.42721113604676, 53.31482165591113, 54.20436392538438, 55.095814460745686, 55.98915039088406, 56.88434943302067, 57.78138986971295, 58.680250527056714, 59.58091075400837, 60.48335040275588, 61.38754981007236, 62.293489779590864, 63.20115156494418, 64.11051685371673, 65.02156775216012, 65.934286770627, 66.84865680968147, 67.76466114684646, 68.68228342395226, 69.60150763505176, 70.52231811487114, 71.44469952776629, 72.36863685715737, 73.29411539541591, 74.22112073417995, 75.14963875507495, 76.07965562081925, 77.01115776669408, 77.94413189235956, 78.87856495399916, 79.8144441567764, 80.75175694758795, 81.69049100809886, 82.63063424804623], [0.0, 0.4196744564599215, 0.93131593018919, 1.484574441861971, 2.0667194499767874, 2.6713330764409284, 3.294476959404406, 3.9334649318501764, 4.586337618046183, 5.251597373880816, 5.928059262687867, 6.614760503176782, 7.310902121172054, 8.015809580726994, 8.728905215660765, 9.44968832374825, 10.177720419160801, 10.912614064366549, 11.654024251299639, 12.40164163939136, 13.155187172974951, 13.914407741284057, 14.679072638730188, 15.44897064799189, 16.22390761385713, 17.00370440813054, 17.788195209367252, 18.577226038434038, 19.37065350374195, 20.168343719680813, 20.97017136917405, 21.776018886966032, 22.585775744684756, 23.399337822200984, 24.216606852558666, 25.03748992994836, 25.861899071960806, 26.68975082878623, 27.520965933188155, 28.355468986033134, 29.19318817294301, 30.034055008286302, 30.878004103266573, 31.72497295531855, 32.57490175640282, 33.42773321811134, 34.283412411768, 35.14188662193942, 36.003105211969896, 36.86701950032235, 37.73358264665419, 38.60274954668156, 39.47447673499479, 40.348722295082084, 41.22544577590056, 42.10460811440561, 42.986171563512215, 43.870099625016984, 44.75635698705816, 45.64490946573345, 46.53572395053339, 47.42876835328129, 48.324011560300654, 49.22142338755704, 50.12097453854521, 51.02263656471315, 51.92638182823341, 52.83218346694896, 53.74001536133617, 54.649852103340514, 55.56166896695358, 56.475441880410145, 57.39114739989489, 58.30876268465676, 59.22826547343734, 60.14963406212701, 61.07284728256946, 61.997884482441144, 62.92472550613788, 63.85335067660588, 64.78374077805927, 65.71587703953021, 66.6497411192017, 67.58531508947665, 68.5225814227405, 69.46152297777682, 70.40212298679893, 71.34436504306262, 72.28823308902759, 73.23371140503731, 74.18078459848914, 75.12943759346803, 76.07965562081924, 77.03142420863692, 77.98472917314679, 78.93955660996257, 79.89589288569704, 80.85372462990985, 81.81303872737523, 82.77382231065373, 83.73606275295298, 84.6997476612637], [0.0, 0.42995937506866166, 0.9541395936111111, 1.5209567545525322, 2.1173683303242177, 2.7367991605571396, 3.3752143663737524, 4.029861951139045, 4.6987345209020335, 5.380297728941372, 6.0733375994702135, 6.776867756416244, 7.490069645226263, 8.212252199170724, 8.942823595263292, 9.681270860621074, 10.427144763488457, 11.180048371441945, 11.939628221338607, 12.705567391632332, 13.477579987867916, 14.255406696319568, 15.038811157520744, 15.827576977868882, 16.62150524401019, 17.42041243787311, 18.224128674243723, 19.032496200438064, 19.845368110784317, 20.662607238551473, 21.484085195530277, 22.30968153530551, 23.139283020797766, 23.972782980216536, 24.81008073838762, 25.651081112668486, 26.495693964474047, 27.343833798898647, 28.19541940611183, 29.050373539181358, 29.90862262378152, 30.770096495910526, 31.634728164295453, 32.50245359462711, 33.373211513156626, 34.246943227514876, 35.12359246289431, 36.003105211969896, 36.88542959713862, 37.77051574382999, 38.65831566378998, 39.5487831473687, 40.44187366395417, 41.33754426979097, 42.23575352250666, 43.13646140174266, 44.03962923535001, 44.94521963066762, 45.853196410449584, 46.763524553052235, 47.67617013653027, 48.59110028632538, 49.50828312626138, 50.427687732586826, 51.34928409083006, 52.27304305525332, 53.198936310711765, 54.12693633674028, 55.05701637370674, 55.98915039088406, 56.92331305630609, 57.85947970828333, 58.79762632846531, 59.73772951634505, 60.67976646510975, 61.62371493874942, 62.569553250341954, 63.517260241439416, 64.46681526248632, 65.41819815420533, 66.37138922989134, 67.32636925855829, 68.28311944888819, 69.24162143393414, 70.2018572565342, 71.16380935539388, 72.12746055180007, 73.0927940369302, 74.05979335972346, 75.02844241528335, 75.99872543378228, 76.9706269698413, 77.94413189235955, 78.91922537476965, 79.89589288569705, 80.87412018000208, 81.85389329018552, 82.83519851813902, 83.81802242722334, 84.80235183465798, 85.7881738042071, 86.77547563914723], [0.0, 0.4402764864774135, 0.9770346973292591, 1.5574529474361187, 2.1681757466151854, 2.802470159912224, 3.4562044893144073, 4.1265607025156195, 4.811483237044235, 5.509400928686413, 6.2190706716393915, 6.939482421195119, 7.669797981134207, 8.409309702201288, 9.157411560292344, 9.913578273458345, 10.677349830380916, 11.448319774024997, 12.226126159705359, 13.010444461169293, 13.800981923767077, 14.597473011397616, 15.399675693019116, 16.207368382545642, 17.02034739358821, 17.83842480445831, 18.66142665345298, 19.489191402525957, 20.321568620923113, 21.158417850522373, 21.999607622368874, 22.845014599869494, 23.694522828758895, 24.548023077598362, 25.40541225545757, 26.266592895734203, 27.13147269691829, 27.999964112606964, 28.871983984295262, 29.747453211468372, 30.626296454344217, 31.508441865297247, 32.39382084556214, 33.28236782429126, 34.1740200574385, 35.068717444279066, 35.966402359660506, 36.86701950032235, 37.77051574382999, 38.67684001884523, 39.585943185609516, 40.49777792564703, 41.41229863980928, 42.329461353881854, 43.24922363105983, 44.1715444906741, 45.096384332616296, 46.02370486696784, 46.95346904838996, 47.8856410148754, 48.820186030503145, 49.757070431871796, 50.696261577918825, 51.63772780286036, 52.58143837201103, 53.52736344026506, 54.47547401304018, 55.42574190950257, 56.37813972790805, 57.33264081290793, 58.28921922468162, 59.24784970976882, 60.20850767348556, 61.171169153816834, 62.13581079668784, 63.10240983252332, 64.07094405401155, 65.041391794996, 66.01373191042377, 66.98794375728461, 67.96400717648007, 68.94190247556604, 69.92161041231651, 70.90311217905963, 71.88638938774147, 72.87142405567464, 73.85819859193339, 74.84669578435818, 75.83689878713596, 76.82879110892443, 77.82235660149031, 78.81757944883428, 79.8144441567764, 80.8129355429777, 81.81303872737526, 82.81473912300949, 83.81802242722335, 84.82287461321485, 85.8292819219252, 86.83723085424587, 87.84670816352892, 88.857700848386], [0.0, 0.45062523130541515, 1.0000000000000002, 1.5940610417352046, 2.2191389441356906, 2.8683425139074634, 3.5374429370441005, 4.223555943095618, 4.924577653379667, 5.638899973303359, 6.3652505777321196, 7.102595680751475, 7.850077384252301, 8.606971405609524, 9.372657476059228, 10.146597966845274, 10.928322054035167, 11.717413726778767, 12.513502532843189, 13.316256317952234, 14.125375446227547, 14.940588140114224, 15.761646679605539, 16.58832427021145, 17.42041243787311, 18.25771884378308, 19.1000654372504, 19.947286883260134, 20.799229215167557, 21.655748673367764, 22.516710698714363, 23.381989055574724, 24.251465064166382, 25.125026925554234, 26.002569125644875, 26.8839919068733, 27.769200798172918, 28.6581061953535, 29.550622985260734, 30.446670208113947, 31.346170753261607, 32.24905108429221, 33.155240990019294, 34.0646733583456, 34.97728397041965, 35.89301131284284, 36.81179640597748, 37.73358264665419, 38.65831566378998, 39.585943185609516, 40.51641491731908, 41.44968242821714, 42.38569904734244, 43.32441976686208, 44.265801152489594, 45.20980126030097, 46.15637955938313, 47.105496859809, 48.057115245485214, 49.0111980114643, 49.96770960535379, 50.92661557249052, 51.88788250458036, 52.85147799153191, 53.817370576237764, 54.78552971207986, 55.755925722955205, 56.72852976563656, 57.70331379429887, 58.68025052705671, 59.659313414371255, 60.64047660919703, 61.623714938749416, 62.60900387778375, 63.59631952328525, 64.58563857047743, 65.57693829006337, 66.57019650662127, 67.56539157808156, 68.56250237621785, 69.56150826809001, 70.56238909838096, 71.56512517257414, 72.56969724092144, 73.57608648315578, 74.5842744939048, 75.59424326876623, 76.60597519100693, 77.61945301885126, 78.63465987332616, 79.65157922663244, 80.67019489101409, 81.69049100809886, 82.71245203868526, 83.73606275295299, 84.76130822107443, 85.78817380420712, 86.81664514584757, 87.84670816352892, 88.87834904084465, 89.91155421978299, 90.94631039335661], [0.0, 0.46100507090441417, 1.0230343062880207, 1.6307791320123346, 2.2702552702705865, 2.934412793911759, 3.6189254811323694, 4.320842624313472, 5.038011883386756, 5.76878812241594, 6.511869709139601, 7.266199045101876, 8.030898471105832, 8.80522702117857, 9.588550139095483, 10.380317812194995, 11.180048371441945, 11.987316223464846, 12.80174238292062, 13.622987044589735, 14.450743670689238, 15.284734223456782, 16.124705276827136, 16.970424812256507, 17.821679553630723, 18.678272731751346, 19.54002219465326, 20.40675879894416, 21.278325031464473, 22.15457382120651, 23.0353675095473, 23.92057695310398, 24.810080738387622, 25.703764491252215, 26.601520267160407, 27.503246010700888, 28.40884507473158, 29.318225791091894, 30.231301086105052, 31.147988135137997, 32.068208051348826, 32.99188560446582, 33.91894896603653, 34.84932947808311, 35.78296144251737, 36.71978192902225, 37.65973059940502, 38.60274954668156, 39.5487831473687, 40.49777792564703, 41.44968242821714, 42.404447108809876, 43.362024221430794, 44.32236772152276, 45.28543317432065, 46.25117766975128, 47.2195597433001, 48.19053930232723, 49.16407755736843, 50.1401369580032, 51.11868113291438, 52.09967483379955, 53.083083882827694, 54.06887512336343, 55.05701637370673, 56.047476383619355, 57.040224793429886, 58.03523209552733, 59.03246959807052, 60.03190939075471, 61.033524312490904, 62.03728792086483, 63.04317446325424, 64.05115884949248, 65.06121662597543, 66.0733239511172, 67.08745757206731, 68.1035948026085, 69.12171350216114, 70.1417920558248, 71.16380935539387, 72.18774478128755, 73.21357818533976, 74.24128987439775, 75.27086059468267, 76.30227151686721, 77.33550422183013, 78.3705406870491, 79.4073632735961, 80.44595471370268, 81.48629809886323, 82.52837686844802, 83.5721747987982, 84.61767599277755, 85.66486486975742, 86.71372615601199, 87.76424487550317, 88.81640634103542, 89.870196145762, 90.92560015502507, 91.98260449851344, 93.04119556272258], [0.0, 0.4714154861980624, 1.0461364642907813, 1.6676053820645462, 2.3215221687880883, 3.000677695874084, 3.7006480467897114, 4.418415881044365, 5.151780254431996, 5.899058880560956, 6.658920733713531, 7.430284332748321, 8.212252199170726, 9.004066634516203, 9.805078753013158, 10.614726121615542, 11.432516194239316, 12.258013766764604, 13.090831295602307, 13.930621302052325, 14.7770703260963, 15.629894051323872, 16.488833328803068, 17.353650900547958, 18.22412867424372, 19.1000654372504, 19.981274924247685, 20.86758417224763, 21.758832111128907, 22.654868348726726, 23.555552117811448, 24.460751358684682, 25.37034191609842, 26.28420683310998, 27.202235727578753, 28.12432423947841, 29.050373539181354, 29.98028988847684, 30.91398424739055, 31.851371920943784, 32.79237224087218, 33.73690827805423, 34.68490658200756, 35.63629694432004, 36.591012183309424, 37.54898794756642, 38.51016253634136, 39.47447673499479, 40.44187366395417, 41.41229863980928, 42.38569904734244, 43.362024221430794, 44.34122533787995, 45.323255312354725, 46.308068706664244, 47.295621641740155, 48.28587171671635, 49.278777933581075, 50.2743006269265, 51.27240139836863, 52.27304305525332, 53.27618955330106, 54.28180594287718, 55.28985831860322, 56.300313772052085, 57.31314034729275, 58.32830699907177, 59.345783553437364, 60.36554067062928, 61.38754981007234, 62.41178319732591, 63.4382137928532, 64.4668152624863, 65.49756194947248, 66.5304288479964, 67.56539157808156, 68.60242636178162, 69.64151000057927, 70.68261985391636, 71.72573381878482, 72.77083031031361, 73.81788824329061, 74.86688701456389, 75.91780648627001, 76.9706269698413, 78.02532921074666, 79.08189437392429, 80.14030402986728, 81.20054014132545, 82.26258505058958, 83.32642146732628, 84.39203245693372, 85.45940142939038, 86.528512128571, 87.59934862200521, 88.67189529105592, 89.74613682149624, 90.82205819446438, 91.89964467777823, 92.97888181759116, 94.05975543037263, 95.142251595198], [0.0, 0.4818559766073928, 1.0693053631540017, 1.704538021122309, 2.372937174548202, 3.0671340334838817, 3.7826067044324994, 4.5162710215331, 5.265877296027225, 6.029705983742238, 6.8063965805880615, 7.594843653741997, 8.39412984815492, 9.2034806845314, 10.02223290615558, 10.849811623715139, 11.685713382653958, 12.52949334033885, 13.380755370210403, 14.23914429791968, 15.104339721214963, 15.976051026899206, 16.85401332664066, 17.73798410787479, 18.62774044817239, 19.523076678615123, 20.423802408644228, 21.329740844641524, 22.24072734924806, 23.1566081995473, 24.077239510722354, 25.00248629833422, 25.932221657455013, 26.866326040883834, 27.804686621834716, 28.747196729008394, 29.69375534398668, 30.64426665252841, 31.598639642681214, 32.5567877437174, 33.51862850080374, 34.484083281061025, 35.453077007291014, 36.42553791616818, 37.40139733813022, 38.380589496570096, 39.363051324244914, 40.348722295082084, 41.33754426979097, 42.329461353881854, 43.32441976686208, 44.32236772152276, 45.323255312354725, 46.327034412240856, 47.3336585766657, 48.34308295476636, 49.35526420662011, 50.370160426227734, 51.38773106970727, 52.40793688826151, 53.430739865526526, 54.4561031589462, 55.483991044852466, 56.514368866960744, 57.547202988017396, 58.582460744359885, 59.62011040317215, 60.66012112223658, 61.702462912002055, 62.74710659980216, 63.79402379607265, 64.84318686242916, 65.89456888147811, 66.94814362824383, 68.00388554310445, 69.06176970613745, 70.12177181278375, 71.1838681507459, 72.24803557804282, 73.31425150214872, 74.38249386015006, 75.4527410998582, 76.52497216182097, 77.59916646217944, 78.67530387632111, 79.7533647232826, 80.83332975086, 81.9151801213861, 82.9988973981377, 84.0844635323384, 85.17186085072392, 86.2610720436399, 87.35208015364384, 88.44486856458427, 89.53942099113264, 90.63572146874425, 91.73375434402628, 92.8335042654926, 93.93495617468587, 95.03809529764848, 96.14290713672574, 97.24937746268472], [0.0, 0.49232605905448706, 1.09253993086066, 1.7415753403250518, 2.4244979085962046, 3.133778731829151, 3.8647976618616906, 4.6144035180558145, 5.380297728941371, 6.160723386963029, 6.954290426106224, 7.759869393979437, 8.576523002641837, 9.403459944404306, 10.240002550874395, 11.085563441168047, 11.939628221338605, 12.801742382920619, 13.671501192057187, 14.548541756938357, 15.432536713402305, 16.323189133617987, 17.220228373586384, 18.123406651271022, 19.032496200438064, 19.947286883260134, 20.86758417224763, 21.79320743229477, 22.72398844869418, 23.65977015833704, 24.60040554998287, 25.54575670616231, 26.495693964474043, 27.450095180117238, 28.408845074731577, 29.371834659193894, 30.33896072009162, 31.31012536126896, 32.28523559320619, 33.26420296411012, 34.24694322751487, 35.23337604195449, 36.22342469890419, 37.21701587571786, 38.21407941073594, 39.21454809811419, 40.21835750024332, 41.22544577590056, 42.23575352250666, 43.24922363105983, 44.265801152489594, 45.28543317432065, 46.308068706664244, 47.3336585766657, 48.36215533063269, 49.39351314315339, 50.42768773258682, 51.46463628237275, 52.50431736766517, 53.546690886843315, 54.591717997498755, 55.63936105653619, 56.689583564060264, 57.74235011075195, 58.79762632846531, 59.855378843800345, 60.91557523442956, 61.97818398797545, 63.043174463254246, 64.11051685371673, 65.18018215293161, 66.25214212196958, 67.32636925855829, 68.40283676788863, 69.48151853496249, 70.56238909838098, 71.64542362547958, 72.73059788872453, 73.81788824329062, 74.90727160574687, 75.99872543378227, 77.0922277069081, 78.18775690807863, 79.28529200617533, 80.38481243930494, 81.48629809886323, 82.58972931432176, 83.69508683869613, 84.80235183465798, 85.91150586125525, 87.02253086120737, 88.13540914874449, 89.25012339796167, 90.36665663166083, 91.48499221065512, 92.60511382351173, 93.7270054767107, 94.85065148519874, 95.97603646331844, 97.103145316094, 98.23196323085617, 99.36247566918993], [0.0, 0.502825267037299, 1.1158391321778984, 1.778715689448407, 2.476202073606546, 3.200608821507475, 3.947217257000124, 4.712808998248618, 5.495036455089838, 6.292105252648794, 7.102595680751473, 7.925354200620213, 8.759423535973433, 9.603995503915316, 10.458377984286619, 11.321971069882656, 12.194249396935186, 13.07474876425821, 13.963055806753674, 14.858799893682274, 15.761646679605537, 16.671292904492454, 17.587462152665694, 18.50990135795831, 19.438377896857393, 20.37267715019497, 21.31260044204255, 22.257963285120557, 23.20859387742175, 24.164331806353353, 25.12502692555423, 26.09053837636561, 27.06073373124203, 28.03548824055676, 29.014684167555384, 29.998210198843143, 30.985960919907065, 31.977836346885294, 32.97374150718959, 33.97358606272853, 34.97728397041964, 35.98475317545732, 36.9959153334522, 38.010695558099926, 39.02902219149296, 40.05082659457403, 41.07604295555538, 42.10460811440561, 43.13646140174266, 44.1715444906741, 45.20980126030097, 46.25117766975128, 47.295621641740155, 48.34308295476636, 49.39351314315339, 50.44686540422948, 51.50309451201576, 52.56215673685798, 53.62400977049546, 54.68861265611145, 55.7559257229552, 56.825910525165256, 57.8985297844597, 58.97374733639025, 60.05152807988549, 61.131837929833644, 62.214643772477686, 63.299913423415965, 64.38761558801939, 65.4777198240926, 66.57019650662126, 67.66501679446054, 68.76215259883233, 69.86157655350887, 70.96326198657094, 72.06718289363693, 73.17331391246788, 74.28163029886042, 75.39210790374639, 76.50472315142402, 77.61945301885125, 78.73627501593658, 79.85516716676779, 80.9761079917226, 82.09907649041052, 83.22405212539688, 84.35101480666503, 85.47994487677477, 86.61082309667812, 87.74363063215644, 88.87834904084464, 90.01496025981108, 91.15344659366342, 92.29379070315258, 93.43597559424909, 94.57998460766704, 95.72580140881315, 96.87340997813908, 98.02279460187718, 99.17393986314042, 100.32683063336869, 101.4814520641048], [0.0, 0.5133531497693483, 1.1392019667478825, 1.8159574738609232, 2.5280474496461975, 3.2676214331499476, 4.029861951139044, 4.811483237044235, 5.610088548132787, 6.423845939881768, 7.251305976995525, 8.091290968527094, 8.942823595263292, 9.805078753013156, 10.677349830380916, 11.5590243596302, 12.44956597721112, 13.348500762745005, 14.255406696319568, 15.169905387130099, 16.091655489394668, 17.02034739358821, 17.95569889659186, 18.897451633676514, 19.845368110784317, 20.799229215167557, 21.758832111128907, 22.72398844869418, 23.694522828758895, 24.6702714800984, 25.651081112668486, 26.636807918588186, 27.6273166976159, 28.622480088184883, 29.622177888432404, 30.626296454344217, 31.634728164295453, 32.647370941016376, 33.66412782343421, 34.684906582007564, 35.70961937213057, 36.73818242097861, 37.77051574382998, 38.8065428864515, 39.84619069060124, 40.88938908009455, 41.93607086521217, 42.986171563512215, 44.03962923535001, 45.096384332616296, 46.15637955938313, 47.2195597433001, 48.28587171671635, 49.35526420662011, 50.42768773258682, 51.50309451201576, 52.58143837201102, 53.662674667330606, 54.746760203886396, 55.833653167330034, 56.92331305630609, 58.01570061999453, 59.11077779960098, 60.20850767348557, 61.308854405649676, 62.41178319732592, 63.517260241439416, 64.62525267972896, 65.73572856233548, 66.84865680968146, 67.96400717648005, 69.08175021772621, 70.2018572565342, 71.32430035369704, 72.4490522788533, 73.57608648315578, 74.70537707334469, 75.83689878713595, 76.97062696984132, 78.10653755214373, 79.24460702895722, 80.38481243930492, 81.52713134715485, 82.67154182315609, 83.81802242722334, 84.96655219192027, 86.11711060659636, 87.26967760223458, 88.4242335369702, 89.58075918224394, 90.73923570955444, 91.89964467777823, 93.06196802102642, 94.22618803701013, 95.39228737588815, 96.56024902957144, 97.7300563214619, 98.90169289660254, 100.07514271221939, 101.25039002863498, 102.42741940053564, 103.60621566857522], [0.0, 0.5239092713786557, 1.162627467310129, 1.8532991516903463, 2.5800318902297508, 3.3348137923222017, 4.112728322649685, 4.9104221491638995, 5.725449244720859, 6.555939994376836, 7.400415157983027, 8.257672827639947, 9.126715587441772, 10.0067013665145, 10.896909023356082, 11.796713496007422, 12.70556739163233, 13.622987044589733, 14.548541756938356, 15.481845356993306, 16.42254947985221, 17.370338149464747, 18.324923359746887, 19.286041433195077, 20.253449992142276, 21.226925418207934, 22.206260704768155, 23.191263628793276, 24.181755184433094, 25.177568232822242, 26.178546331801158, 27.18454271635599, 28.195419406111828, 29.211046420555906, 30.231301086105045, 31.256067421874103, 32.28523559320618, 33.31870142380855, 34.356365958790164, 35.39813507208626, 36.443919112735365, 37.49363258528561, 38.547193860283095, 39.604524911360166, 40.665551075916156, 41.73020083678427, 42.79840562261769, 43.870099625016984, 44.94521963066762, 46.02370486696784, 47.105496859809, 48.19053930232723, 49.278777933581075, 50.370160426227734, 51.46463628237275, 52.56215673685798, 53.662674667330606, 54.76614451050496, 55.87252218408945, 56.98176501390395, 58.09383166576047, 59.20868208172121, 60.3262774203858, 61.44658000089175, 62.56955325034195, 63.69516165439921, 64.82337071081106, 65.95414688564928, 67.08745757206731, 68.22327105139578, 69.36155645641163, 70.50228373662985, 71.64542362547958, 72.79094760923773, 73.93882789760282, 75.08903739580153, 76.24154967812896, 77.39633896283065, 78.55338008824206, 79.71264849010684, 80.87412018000207, 82.03777172480248, 83.20358022712222, 84.37152330667533, 85.5415790825024, 86.71372615601197, 87.88794359479142, 89.06421091714294, 90.24250807730455, 91.42281545131858, 92.60511382351173, 93.7893843735542, 94.97560866406681, 96.16376862874712, 97.35384656098773, 98.54582510296096, 99.73968723514645, 100.93541626627893, 102.13299582369562, 103.33240984406282, 104.5336425644636, 105.73667851382902], [0.0, 0.5344932101608733, 1.186114698044096, 1.890739231181609, 2.632153318641398, 3.4021832147703934, 4.195813061120282, 5.009621782117204, 5.841113936333125, 6.688382139135573, 7.549917266981739, 8.424493131203834, 9.311092166245203, 10.208855289838707, 11.117046792086727, 12.035028983619517, 12.962243413250555, 13.89819664439594, 14.842449278217325, 15.794607341645696, 16.754315432161672, 17.72125119041278, 18.69512079205805, 19.6756552328194, 20.662607238551473, 21.655748673367768, 22.654868348726726, 23.659770158337043, 24.6702714800984, 25.68620179863043, 26.707401511351847, 27.733720888323365, 28.765019161710644, 29.801163725153536, 30.842029426834994, 31.88749794284094, 32.93745721965073, 33.991800976417345, 35.05042825917745, 36.11324304034524, 37.18015385784355, 38.25107348905387, 39.32591865545596, 40.404609754404845, 41.487070614976886, 42.573228275225894, 43.66301277853671, 44.75635698705816, 45.853196410449584, 46.95346904838996, 48.057115245485214, 49.16407755736843, 50.2743006269265, 51.38773106970727, 52.50431736766517, 53.62400977049546, 54.746760203886396, 55.87252218408945, 57.00125073826901, 58.13290233014737, 59.26743479050928, 60.40480725217233, 61.544980089067856, 62.68791485911004, 63.833574250561455, 64.98192203162944, 66.13292300305204, 67.2865429534535, 68.4427486172685, 69.60150763505176, 70.76278851600503, 71.92656060256779, 73.0927940369302, 74.26145972933908, 75.43252932807731, 76.60597519100693, 77.7817703585748, 78.95988852818721, 80.1403040298673, 81.32299180311524, 82.50792737489745, 83.69508683869613, 84.8844468345557, 86.07598453006699, 87.26967760223458, 88.46550422017584, 89.66344302860458, 90.86347313205468, 92.06557407980263, 93.26972585145042, 94.4759088431325, 95.68410385431353, 96.89429207514509, 98.10645507435191, 99.32057478762029, 100.53663350646224, 101.75461386753152, 102.97449884236839, 104.1962717275519, 105.41991613523919, 106.64541598407324, 107.87275549044078], [0.0, 0.545104557882067, 1.2096627530219626, 1.9282762682304648, 2.68440972450143, 3.4697271019832385, 4.279112961882863, 5.109078309667315, 5.957078161657683, 6.821167265721612, 7.699806537534072, 8.591745444779727, 9.495946220070083, 10.411532725690927, 11.337754645621683, 12.2739616303811, 13.219584141794808, 14.174118947032536, 15.137117923826391, 16.1081792775202, 17.086940549752445, 18.07307298133785, 19.06627691461111, 20.066278004725017, 21.07282406837562, 22.0856824404716, 23.104637739723948, 24.12948996652333, 25.160052873154417, 26.196152558977758, 27.237626252805892, 28.284321252095914, 29.336093994335446, 30.392809240516865, 31.45433935417146, 32.52056366228852, 33.59136788673753, 34.66664363666707, 35.74628795386458, 36.83020290429888, 37.91829521008695, 39.01047591697081, 40.106660093093346, 41.20676655545024, 42.31071762088878, 43.418438878941906, 44.5298589841387, 45.64490946573345, 46.763524553052235, 47.8856410148754, 49.0111980114643, 50.1401369580032, 51.27240139836863, 52.40793688826151, 53.546690886843315, 54.68861265611145, 55.833653167330034, 56.98176501390395, 58.13290233014737, 59.287020715452435, 60.44407716341422, 61.60402999551002, 62.766838798970795, 63.93246436851614, 65.10086865165492, 66.27201469728104, 67.44586660731804, 68.62238949118826, 69.80154942290176, 70.98331340057787, 72.16764930822842, 73.3545258796452, 74.54391266424825, 75.73577999476261, 76.93009895660161, 78.12684135884517, 79.32597970670938, 80.5274871754125, 81.73133758534905, 82.93750537849053, 84.14596559593775, 85.35669385655441, 86.56966633661739, 87.78485975042335, 89.0022513317962, 90.22181881644262, 91.44354042510771, 92.6673948474856, 93.89336122684247, 95.12141914531335, 96.35154860983515, 97.58373003868235, 98.81794424857272, 100.05417244231303, 101.29239619695691, 102.53259745244799, 103.77475850072378, 105.01886197525675, 106.26489084101128, 107.51282838479503, 108.76265820598613, 110.01436420761766], [0.0, 0.5557429191270674, 1.2332707547625268, 1.965908864078315, 2.736799160557139, 3.5374429370441, 4.362624920897747, 5.208788025723287, 6.0733375994702135, 6.954290426106224, 7.850077384252299, 8.759423535973433, 9.681270860621074, 10.614726121615544, 11.559024359630202, 12.513502532843187, 13.477579987867916, 14.450743670689238, 15.432536713402307, 16.422549479852215, 17.420412437873107, 18.425790412154722, 19.438377896857393, 20.45789519296921, 21.484085195530273, 22.516710698714363, 23.555552117811448, 24.60040554998287, 25.651081112668486, 26.707401511351843, 27.769200798172918, 28.836323290417777, 29.90862262378152, 30.985960919907072, 32.068208051348826, 33.155240990019294, 34.24694322751487, 35.34320425760825, 36.44391911273537, 37.54898794756642, 38.65831566378998, 39.77181157110033, 40.88938908009455, 42.01096542338581, 43.13646140174266, 44.265801152489594, 45.39891193776431, 46.53572395053339, 47.67617013653027, 48.820186030503145, 49.96770960535379, 51.11868113291438, 52.27304305525332, 53.430739865526526, 54.591717997498755, 55.7559257229552, 56.92331305630609, 58.09383166576047, 59.26743479050928, 60.44407716341422, 61.623714938749416, 62.80630562458642, 63.99180801945312, 65.18018215293162, 66.37138922989134, 67.56539157808155, 68.76215259883233, 69.96163672063506, 71.16380935539388, 72.36863685715737, 73.57608648315576, 74.78612635698376, 75.99872543378227, 77.21385346728431, 78.4314809786008, 79.65157922663245, 80.87412018000207, 82.09907649041052, 83.3264214673263, 84.55612905392572, 85.78817380420709, 87.02253086120736, 88.2591759362552, 89.49808528919924, 90.73923570955445, 91.98260449851344, 93.22816945177337, 94.4759088431325, 95.72580140881315, 96.97782633247151, 98.23196323085617, 99.48819214008107, 100.74649350247947, 102.00684815400864, 103.26923731217661, 104.53364256446362, 105.80004585721332, 107.06842948496987, 108.3387760802387, 109.61106860364976, 110.8852903345036, 112.16142486168192], [0.0, 0.5664079106896951, 1.2569378528780324, 2.0036356631551673, 2.789319739679938, 3.605328280749624, 4.446345929966771, 5.308747338624857, 6.189888061970176, 7.087746825037917, 8.000724394205264, 8.927521364824544, 9.867059412288485, 10.818428158349455, 11.780847963719122, 12.753643062463105, 13.73622165815861, 14.728060851020885, 15.728695005615734, 16.73770662466041, 17.75471908447733, 18.779390777570164, 19.81141033528555, 20.850492691044128, 21.89637580590999, 22.948817921955495, 24.00759524052743, 25.072499945787126, 26.14333851123075, 27.21993023996917, 28.302105999517845, 29.389707119531742, 30.4825844268999, 31.580597397308885, 32.683613406100676, 33.79150706421572, 34.90415962739441, 36.02145846873826, 37.14329660630185, 38.26957227867229, 39.400188562552806, 40.535053027244224, 41.67407742164857, 42.81717739003042, 43.96427221328448, 45.115284572891596, 46.27014033511259, 47.42876835328129, 48.59110028632538, 49.757070431871796, 50.92661557249052, 52.09967483379955, 53.27618955330106, 54.4561031589462, 55.63936105653619, 56.825910525165256, 58.01570061999453, 59.20868208172121, 60.40480725217233, 61.60402999551002, 62.80630562458642, 64.01159083203119, 65.21984362569485, 66.43102326810669, 67.64509021963768, 68.86200608508729, 70.08173356343836, 71.30423640054676, 72.52947934455337, 73.75742810382367, 74.98804930723739, 76.22131046666465, 77.45717994147961, 78.69562690497389, 79.93662131254344, 81.18013387153252, 82.42613601262745, 83.67459986270121, 84.92549821901731, 86.17880452470826, 87.43449284545054, 88.69253784726322, 89.95291477536296, 91.21559943401266, 92.48056816730622, 93.74779784083448, 95.01726582418266, 96.28894997421206, 97.56282861908218, 98.83888054297293, 100.11708497146785, 101.39742155756365, 102.67987036827196, 103.96441187178226, 105.25102692515689, 106.5396967625304, 107.83040298378754, 109.12312754369567, 110.41785274146913, 111.71456121074358, 113.0132359099408, 114.31386011300472], [0.0, 0.5770991610015304, 1.2806632228065287, 2.0414553510589393, 2.8419696320522903, 3.673380767973712, 4.53027307224909, 5.4089527657885, 6.306725488538215, 7.2215318128943276, 8.151742318849534, 9.096033074802913, 10.053305402197195, 11.022631738911532, 12.003217729551714, 12.994374852742238, 13.995500141588339, 15.006060826293952, 16.025582482308614, 17.053639731866504, 18.089848842317977, 19.13386175814368, 20.185361233441448, 21.24405682084875, 22.30968153530551, 23.381989055574728, 24.460751358684682, 25.545756706162315, 26.636807918588186, 27.733720888323365, 28.836323290417777, 29.944453459539307, 31.057959406855254, 32.17669795558109, 33.3005339776979, 34.429339717360996, 35.56299418894976, 36.701382639673156, 37.84439606824469, 38.991930792450724, 40.14388805951575, 41.30017369406204, 42.460697779205226, 43.625374366950574, 44.794121214576755, 45.9668595441365, 47.14351382257691, 48.324011560300654, 49.50828312626138, 50.696261577918825, 51.88788250458036, 53.083083882827694, 54.28180594287718, 55.483991044852466, 56.689583564060264, 57.8985297844597, 59.11077779960098, 60.3262774203858, 61.544980089067856, 62.766838798970795, 63.99180801945312, 65.21984362569485, 66.45090283292238, 67.68494413472357, 68.9219272451379, 70.16181304423502, 71.40456352692124, 72.6501417547362, 73.89851181042322, 75.14963875507493, 76.40348858767345, 77.66002820685819, 78.91922537476965, 80.18104868282897, 81.44546751932424, 82.71245203868526, 83.98197313233739, 85.2540024010335, 86.52851212857101, 87.80547525680743, 89.08486536189514, 90.36665663166082, 91.65082384406143, 92.9373423466525, 94.22618803701013, 95.5173373440509, 96.81076721019889, 98.10645507435191, 99.40437885560198, 100.70451693766908, 102.00684815400864, 103.31135177355686, 104.61800748707962, 105.92679539409309, 107.23769599032649, 108.55069015569869, 109.8657591427825, 111.18288456573191, 112.50204838964952, 113.82323292037165, 115.14642079465122, 116.47159497071895], [0.0, 0.5878163095962048, 1.30444606462306, 2.079366652660423, 2.8947470625295733, 3.7415981042576045, 4.6144035180558145, 5.509400928686414, 6.423845939881769, 7.355640878978644, 8.30312606646232, 9.264952984365003, 10.240002550874397, 11.22732997837055, 12.22612615970536, 13.235689787163656, 14.255406696319568, 15.284734223456782, 16.323189133617987, 17.370338149464747, 18.425790412154722, 19.489191402525957, 20.56021798319056, 21.638574312968515, 22.72398844869418, 23.816209494767122, 24.915005193664204, 26.02015987477586, 27.13147269691829, 28.248756133440626, 29.371834659193897, 30.5005436066039, 31.634728164295456, 32.77424249658763, 33.91894896603653, 35.068717444279066, 36.223424698904196, 37.3829538460786, 38.5471938602831, 39.716039133850394, 40.88938908009455, 42.067147774732994, 43.24922363105983, 44.43552910496391, 45.62598042641714, 46.8204973545088, 48.01900295348262, 49.22142338755704, 50.427687732586826, 51.63772780286036, 52.85147799153191, 54.06887512336343, 55.28985831860322, 56.514368866960744, 57.74235011075195, 58.97374733639025, 60.20850767348557, 61.44658000089175, 62.68791485911004, 63.93246436851614, 65.18018215293162, 66.43102326810669, 67.68494413472357, 68.94190247556605, 70.2018572565342, 71.46476863121228, 72.73059788872455, 73.99930740463671, 75.27086059468269, 76.54522187111435, 77.8223566014903, 79.10223106973378, 80.38481243930494, 81.6700687183449, 82.95796872666011, 84.24848206442658, 85.5415790825024, 86.83723085424587, 88.13540914874451, 89.43608640536657, 90.73923570955445, 92.04483076978414, 93.35284589562102, 94.6632559768069, 95.97603646331845, 97.29116334634017, 98.60861314010033, 99.92836286452074, 101.250390028635, 102.57467261473313, 103.90118906319255, 105.2299182579586, 106.56083951264, 107.89393255718656, 109.2291775251191, 110.56655494128275, 111.90604571009703, 113.24763110427752, 114.5912927540057, 115.9370126365245, 117.28477306613878, 118.6345566846013], [0.0, 0.5985590066064778, 1.3282856019236067, 2.1173683303242172, 2.947650308163392, 3.8099780626086455, 4.6987345209020335, 5.610088548132787, 6.541245592538952, 7.490069645226261, 8.454870695037492, 9.43427557902698, 10.427144763488457, 11.432516194239318, 12.449565977211122, 13.477579987867916, 14.515932837559125, 15.564071945062263, 16.621505244010187, 17.68779153866021, 18.76253282698929, 19.845368110784317, 20.935968347127055, 22.034032288161786, 23.139283020797762, 24.251465064166382, 25.37034191609842, 26.495693964474043, 27.6273166976159, 28.76501916171064, 29.90862262378152, 31.05795940685525, 32.212871870285554, 33.373211513156626, 34.53883818261738, 35.70961937213057, 36.88542959713861, 38.06614983768576, 39.251667039194615, 40.44187366395417, 41.63666728699624, 42.83595023096421, 44.039629235350006, 45.24761515612113, 46.45982269230177, 47.67617013653027, 48.89657914700305, 50.12097453854521, 51.34928409083006, 52.58143837201103, 53.817370576237764, 55.05701637370673, 56.300313772052085, 57.547202988017396, 58.79762632846531, 60.05152807988549, 61.308854405649676, 62.56955325034195, 63.833574250561455, 65.10086865165492, 66.37138922989134, 67.64509021963768, 68.9219272451379, 70.2018572565342, 71.48483846980376, 72.77083031031361, 74.05979335972344, 75.35168930598978, 76.64648089624703, 77.94413189235954, 79.24460702895722, 80.54787197378165, 81.85389329018551, 83.1626384016394, 84.47407555811296, 85.7881738042071, 87.104902948924, 88.42423353697019, 89.74613682149624, 91.07058473818323, 92.39754988059387, 93.72700547671067, 95.0589253665909, 96.39328398107124, 97.73005632146189, 99.06921794017184, 100.41074492221269, 101.7546138675315, 103.10080187412593, 104.4492865218991, 105.80004585721329, 107.1530583781053, 108.50830302012754, 109.86575914278248, 111.22540651651904, 112.58722531026218, 113.95119607944821, 115.31729975454029, 116.6855176300004, 118.05583135369473, 119.42822291671143, 120.80267464357082], [0.0, 0.609326912291608, 1.3521810807762593, 2.1554591822368385, 3.000677695874084, 3.8785184804918855, 4.783263413796636, 5.711012439854024, 6.658920733713531, 7.624813860290555, 8.606971405609524, 9.603995503915318, 10.614726121615544, 11.638183897447444, 12.673530115723452, 13.720037805011035, 14.7770703260963, 15.844065156978285, 16.92052137915636, 18.00598985990234, 19.100065437250397, 20.202380618732608, 21.31260044204255, 22.430418239961565, 23.555552117811445, 24.687741998695678, 25.826747125838516, 26.97234393636078, 28.12432423947841, 29.28249364617346, 30.446670208113943, 31.61668323186569, 32.79237224087218, 33.97358606272853, 35.16018202327387, 36.35202523221614, 37.54898794756641, 38.750949008233896, 39.95779332582162, 41.16941142804584, 42.385699047342435, 43.60655674916703, 44.83188959528161, 46.06160683797799, 47.295621641740155, 48.533850829314325, 49.776214649550234, 51.02263656471315, 52.27304305525332, 53.52736344026506, 54.78552971207986, 56.047476383619355, 57.31314034729275, 58.582460744359885, 59.855378843800345, 61.131837929833644, 62.41178319732592, 63.69516165439921, 64.98192203162944, 66.27201469728104, 67.56539157808155, 68.86200608508729, 70.16181304423502, 71.46476863121228, 72.77083031031361, 74.07995677698, 75.39210790374639, 76.70724468934662, 78.02532921074666, 79.34632457789718, 80.67019489101409, 81.9969052002115, 83.32642146732628, 84.65871052978662, 85.99374006638816, 87.33147856485301, 88.67189529105592, 90.01496025981109, 91.36064420712147, 92.70891856379909, 94.05975543037263, 95.41312755320368, 96.76900830173958, 98.12737164683506, 99.48819214008108, 100.85144489408137, 102.21710556362376, 103.58515032769503, 104.95555587229235, 106.32829937398769, 107.70335848420368, 109.08071131416288, 110.46033642047438, 111.84221279132392, 113.22631983323662, 114.61263735838203, 116.00114557239432, 117.39182506268112, 118.78465678719714, 120.1796220636589, 121.57670255917938, 122.97588028030206], [0.0, 0.6201196965927588, 1.3761317687345995, 2.193638040833985, 3.0538276002612785, 3.9472172570001245, 4.867987605752213, 5.8121695103217, 6.776867756416243, 7.759869393979436, 8.759423535973431, 9.774107556759251, 10.802740875494594, 11.844326783849555, 12.89801171027295, 13.963055806753674, 15.038811157520744, 16.124705276827136, 17.220228373586384, 18.32492335974689, 19.438377896857393, 20.56021798319056, 21.690102723375393, 22.82772001830916, 23.972782980216532, 25.125026925554234, 26.284206833109977, 27.450095180117238, 28.62248008818488, 29.80116372515353, 30.98596091990707, 32.17669795558108, 33.373211513156626, 34.57534774256738, 35.78296144251736, 36.99591533345221, 38.21407941073594, 39.437330367195784, 40.665551075916156, 41.898630125570875, 43.13646140174266, 44.37894370863948, 45.62598042641713, 46.87747919998651, 48.13335165574593, 49.39351314315339, 50.657882498455756, 51.92638182823341, 53.198936310711765, 54.47547401304018, 55.755925722955205, 57.040224793429886, 58.32830699907177, 59.62011040317215, 60.91557523442956, 62.214643772477686, 63.517260241439416, 64.82337071081106, 66.13292300305204, 67.44586660731804, 68.76215259883233, 70.08173356343836, 71.40456352692124, 72.73059788872455, 74.05979335972344, 75.39210790374639, 76.72750068256528, 78.0659320040988, 79.4073632735961, 80.75175694758794, 82.09907649041052, 83.4492863331234, 84.80235183465798, 86.15823924504592, 87.51691567058926, 88.87834904084465, 90.24250807730455, 91.60936226366657, 92.97888181759117, 94.35103766385484, 95.72580140881315, 97.10314531609399, 98.48304228344745, 99.8654658206836, 101.250390028635, 102.63778957908407, 104.02763969560084, 105.41991613523919, 106.8145951710439, 108.21165357532394, 109.61106860364976, 111.01281797953605, 112.41687987977295, 113.82323292037165, 115.23185614309259, 116.64272900252568, 118.05583135369474, 119.47114344015927, 120.8886458825892, 122.30831966778862, 123.73014613814678, 125.15410698149569], [0.0, 0.6309370387143718, 1.4001369539087103, 2.2319037713196748, 3.1070984415423366, 4.016072350189248, 4.952904578498807, 5.913556752828927, 6.89508315488991, 7.895232232016872, 8.912222554771507, 9.94460668129253, 10.991183436734671, 12.05093872622949, 13.123004088559266, 14.206626769835053, 15.301147552070178, 16.40598396310013, 17.52061731906399, 18.644582558485258, 19.777460150097923, 20.918869568104128, 22.068463970568235, 23.225925814143785, 24.39096320659706, 25.5633068472561, 26.742707440768807, 27.92893349547101, 29.121769436973754, 30.32101398214173, 31.52647872974159, 32.73798693259919, 33.95537242276542, 35.17847866641983, 36.407157929381086, 37.641270537396, 38.88068421803315, 40.12527351315458, 41.374919252687675, 42.62950808185173, 43.888932035174, 45.15308815160728, 46.42187812587482, 47.6952079918492, 48.972987834343314, 50.255131526174644, 51.54155648777291, 52.83218346694896, 54.12693633674028, 55.42574190950257, 56.72852976563656, 58.03523209552733, 59.345783553437364, 60.66012112223658, 61.97818398797545, 63.299913423415965, 64.62525267972896, 65.95414688564928, 67.2865429534535, 68.62238949118826, 69.96163672063506, 71.30423640054676, 72.6501417547362, 73.99930740463671, 75.35168930598978, 76.70724468934662, 78.0659320040988, 79.42771086577797, 80.79254200638808, 82.16038722755316, 83.53120935628282, 84.90497220317351, 86.28164052287929, 87.66117997669875, 89.04355709713764, 90.42873925431716, 91.81669462410878, 93.20739215788495, 94.60080155378432, 95.99689322939636, 97.3956382957791, 98.79700853272828, 100.20097636522351, 101.60751484098108, 103.01659760904954, 104.42819889938697, 105.84229350336436, 107.25885675514266, 108.67786451387462, 110.09929314668635, 111.52311951239543, 112.94932094592646, 114.3778752433864, 115.80876064776506, 117.2419558352282, 118.67743990197246, 120.11519235161354, 121.55519308308041, 122.99742237899079, 124.44186089448336, 125.88848964648479, 127.33729000339038], [0.0, 0.6417786267296287, 1.4241959440896415, 2.270255270270587, 3.1604886836094193, 4.085081774566895, 5.038011883386756, 6.015171243792478, 7.013563520297804, 8.03089847110583, 9.06536405592033, 10.115487961034855, 11.180048371441947, 12.258013766764604, 13.348500762745006, 14.450743670689238, 15.564071945062263, 16.687893104898606, 17.821679553630723, 18.964958238485632, 20.117302419260678, 21.278325031464473, 22.44767327326817, 23.625024144878903, 24.810080738387622, 26.00256912564488, 27.20223572757876, 28.40884507473158, 29.622177888432407, 30.842029426834998, 32.068208051348826, 33.3005339776979, 34.53883818261739, 35.78296144251737, 37.03275348465396, 38.2880722347077, 39.5487831473687, 40.81475860871267, 42.085877400930464, 43.362024221430794, 44.643089249536516, 45.92896775498861, 47.219559743300096, 48.514769633694264, 49.81450596594328, 51.11868113291438, 52.42721113604676, 53.74001536133617, 55.05701637370674, 56.37813972790805, 57.70331379429887, 59.03246959807052, 60.36554067062928, 61.702462912002055, 63.043174463254246, 64.38761558801939, 65.73572856233548, 67.08745757206731, 68.4427486172685, 69.80154942290176, 71.16380935539388, 72.52947934455337, 73.89851181042322, 75.27086059468269, 76.64648089624703, 78.02532921074666, 79.4073632735961, 80.79254200638808, 82.1808254663723, 83.5721747987982, 84.96655219192027, 86.36392083448118, 87.76424487550315, 89.16748938623223, 90.57362032409172, 91.98260449851345, 93.39440953852494, 94.80900386198041, 96.22635664633216, 97.64643780084586, 99.06921794017184, 100.49466835918928, 101.92276100904759, 103.35346847433355, 104.78676395129914, 106.2226212270877, 107.66101465990253, 109.10191916006376, 110.54531017190442, 111.99116365645958, 113.43945607490464, 114.89016437270317, 116.3432659644257, 117.79873871920452, 119.25656094679132, 120.71671138418617, 122.17916918280898, 123.64391389618575, 125.11092546812426, 126.58018422135441, 128.05167084661082, 129.52536639213608], [0.0, 0.6526441572082785, 1.4483080659235068, 2.308691464319524, 3.213996832196694, 4.154243598723487, 5.123307138465109, 6.117010139264545, 7.132305536656426, 8.1668643142711, 9.218843753353688, 10.28674661342582, 11.369330393736309, 12.465546109917256, 13.574495421714834, 14.695399677065062, 15.827576977868876, 16.970424812256503, 18.12340665127102, 19.286041433195074, 20.457895192969207, 21.63857431296851, 22.827720018309158, 24.025003840701906, 25.2301238454858, 26.442801466814636, 27.66277883243654, 28.889816486315812, 30.123691437319017, 31.364195477250806, 32.61113372301413, 33.864323346524024, 35.1235924628943, 36.38877915282548, 37.65973059940501, 38.93630232294687, 40.218357500243314, 41.50576635682289, 42.79840562261769, 44.09615804292436, 45.398911937764304, 46.70656080375961, 48.019002953482605, 49.33614118794152, 50.65788249845575, 51.984137794673956, 53.31482165591113, 54.649852103340514, 55.98915039088406, 57.33264081290793, 58.68025052705671, 60.03190939075471, 61.38754981007234, 62.74710659980216, 64.11051685371673, 65.4777198240926, 66.84865680968146, 68.22327105139578, 69.60150763505176, 70.98331340057787, 72.36863685715737, 73.75742810382367, 75.14963875507493, 76.54522187111435, 77.94413189235954, 79.34632457789718, 80.75175694758794, 82.16038722755316, 83.5721747987982, 84.98708014874832, 86.40506482549235, 87.82609139454578, 89.25012339796166, 90.67712531563029, 92.1070625286226, 93.53990128444279, 94.97560866406681, 96.41415255065242, 97.85550159981568, 99.2996252113759, 100.74649350247945, 102.19607728201805, 103.64834802626451, 105.10327785565337, 106.56083951263999, 108.02100634057518, 109.48375226353787, 110.94905176707138, 112.41687987977294, 113.88721215568977, 115.36002465747697, 116.83529394027696, 118.31299703628125, 119.79311143993904, 121.27561509377871, 122.76048637481053, 124.24770408148083, 125.73724742114987, 127.22909599806728, 128.72322980182005, 130.2196291962304, 131.71827490868122], [0.0, 0.6635333348652601, 1.472472664131727, 2.3472113089124322, 3.267621433149947, 4.223555943095617, 5.208788025723286, 6.2190706716393915, 7.251305976995525, 8.303126066462319, 9.372657476059226, 10.458377984286619, 11.5590243596302, 12.67353011572345, 13.800981923767077, 14.94058814011422, 16.091655489394668, 17.253571407003594, 18.42579041215472, 19.607823416756062, 20.799229215167554, 21.99960762236887, 23.20859387742175, 24.425854031639233, 25.651081112668486, 26.8839919068733, 28.12432423947841, 29.371834659193894, 30.626296454344214, 31.887497942840934, 33.155240990019294, 34.42933971736099, 35.70961937213057, 36.99591533345221, 38.28807223470769, 39.58594318560951, 40.889389080094546, 42.19827797844211, 43.51248455385911, 44.831889595281616, 46.156379559383126, 47.4858461658079, 48.82018603050313, 50.1593003327402, 51.50309451201576, 52.8514779915319, 54.20436392538438, 55.56166896695358, 56.92331305630609, 58.28921922468162, 59.659313414371255, 61.033524312490904, 62.41178319732591, 63.79402379607265, 65.18018215293161, 66.57019650662126, 67.96400717648005, 69.36155645641163, 70.76278851600503, 72.16764930822842, 73.57608648315576, 74.98804930723739, 76.40348858767345, 77.8223566014903, 79.24460702895722, 80.67019489101409, 82.09907649041052, 83.53120935628282, 84.96655219192027, 86.40506482549235, 87.8467081635289, 89.29144414696201, 90.73923570955444, 92.19004673855383, 93.64384203742438, 95.1005872905197, 96.56024902957144, 98.02279460187718, 99.48819214008108, 100.95641053344734, 102.42741940053563, 103.90118906319252, 105.37769052178075, 106.85689543157241, 108.3387760802387, 109.823305366372, 111.31045677898206, 112.80020437791093, 114.2925227751153, 115.78738711676874, 117.28477306613875, 118.78465678719712, 120.28701492892418, 121.79182461027054, 123.29906340574213, 124.8087093315759, 126.32074083247645, 127.8351367688849, 129.3518764047537, 130.87093939580203, 132.39230577822804, 133.91595595785674], [0.0, 0.6744458722286716, 1.496689100774209, 2.385813787133862, 3.3213610707914736, 4.293016977852595, 5.294452288484611, 6.321350146541345, 7.370561699729576, 8.439680130399115, 9.526801163388399, 10.630377542586704, 11.74912526124453, 12.881960293451048, 14.02795428970775, 15.186302586915067, 16.356300508024848, 17.53732541413188, 18.728822853416855, 19.930295694194804, 21.141295474712397, 22.361415428465364, 23.590284795619606, 24.82756413533376, 26.072941426756145, 27.326128798490025, 28.586859764006846, 29.854886868191777, 31.12997967084578, 32.41192300853506, 33.700515488051806, 34.99556817390052, 36.29690343934432, 37.60435395613555, 38.917761802480626, 40.236977672319306, 41.56186017183587, 42.89227519141541, 44.228095343127556, 45.569199455350955, 46.91547211741391, 48.26680326817083, 49.62308782330416, 50.98422533686943, 52.350119693211525, 53.72067882589725, 55.095814460745686, 56.475441880410145, 57.85947970828333, 59.24784970976882, 60.64047660919703, 62.03728792086483, 63.4382137928532, 64.84318686242916, 66.25214212196958, 67.66501679446054, 69.08175021772621, 70.50228373662985, 71.92656060256779, 73.3545258796452, 74.78612635698376, 76.22131046666465, 77.66002820685819, 79.10223106973378, 80.54787197378165, 81.9969052002115, 83.4492863331234, 84.90497220317351, 86.36392083448118, 87.82609139454578, 89.29144414696201, 90.75994040673855, 92.23154249804304, 93.7062137142091, 95.18391827985506, 96.66462131497592, 98.1482888008807, 99.63488754785736, 101.12438516445619, 102.61675002829105, 104.11195125826532, 105.60995868813563, 107.11074284133369, 108.6142749069713, 110.12052671695983, 111.62947072417914, 113.14107998163651, 114.65532812255951, 116.17218934137043, 117.69163837549428, 119.21365048795415, 120.73820145071205, 122.26526752871506, 123.7948254646097, 125.32685246408992, 126.86132618184544, 128.39822470808028, 129.93752655557216, 131.47921064724645, 133.02325630423803, 134.56964323441852, 136.11835152136499], [0.0, 0.6853814893257681, 1.520956754552532, 2.4244979085962046, 3.375214366373752, 4.362624920897746, 5.380297728941371, 6.423845939881768, 7.490069645226261, 8.576523002641835, 9.681270860621073, 10.802740875494594, 11.939628221338607, 13.090831295602307, 14.255406696319568, 15.432536713402305, 16.621505244010187, 17.82167955363072, 19.032496200438064, 20.253449992142276, 21.48408519553027, 22.72398844869418, 23.97278298021653, 25.230123845485803, 26.495693964474043, 27.76920079817292, 29.05037353918135, 30.33896072009162, 31.634728164295453, 32.93745721965073, 34.24694322751487, 35.56299418894975, 36.88542959713861, 38.21407941073595, 39.548783147368695, 40.889389080094546, 42.23575352250666, 43.587740190506665, 44.945219630667616, 46.308068706664244, 47.67617013653026, 49.04941207456389, 50.42768773258681, 51.810895036001426, 53.19893631071176, 54.591717997498755, 55.98915039088406, 57.39114739989489, 58.79762632846531, 60.20850767348556, 61.623714938749416, 63.04317446325424, 64.4668152624863, 65.89456888147811, 67.32636925855829, 68.76215259883233, 70.2018572565342, 71.64542362547958, 73.0927940369302, 74.54391266424825, 75.99872543378227, 77.45717994147961, 78.91922537476965, 80.38481243930494, 81.85389329018551, 83.32642146732628, 84.80235183465798, 86.28164052287929, 87.76424487550315, 89.25012339796166, 90.73923570955444, 92.23154249804304, 93.72700547671069, 95.22558734372085, 96.72725174362175, 98.23196323085617, 99.73968723514642, 101.25039002863498, 102.76403869466989, 104.28060109813256, 105.80004585721329, 107.32234231654645, 108.84746052162407, 110.37537119441171, 111.90604571009702, 113.43945607490463, 114.97557490491727, 116.51437540584567, 118.05583135369473, 119.59991707627636, 121.14660743552274, 122.69587781055704, 124.24770408148082, 125.80206261384068, 127.35893024373853, 128.9182842635522, 130.48010240823538, 132.04436284216715, 133.61104414652434, 135.1801253071502, 136.75158570289514, 138.32540509440688], [0.0, 0.6963399133857711, 1.5452750201504382, 2.4632627083883962, 3.4291799766159006, 4.432378035976713, 5.466322205821847, 6.526555495073582, 7.60982683255866, 8.713651269872653, 9.836062714767587, 10.975463683693649, 12.13052848813297, 13.300137912237501, 14.483333470180575, 15.679284377675222, 16.88726308225967, 18.106626732759075, 19.336802878591815, 20.577278250052036, 21.827589827301775, 23.0873176392744, 24.356078890431533, 25.633523120912997, 26.91932818096331, 28.21319685422793, 29.514854003421792, 30.824044140476367, 32.14052934458162, 33.464087467611186, 34.79451057867742, 36.131603609010554, 37.47518316570735, 38.82507648866611, 40.18112052959404, 41.54316113561785, 42.91105232295821, 44.28465562849827, 45.66383952900677, 47.04847891935702, 48.438454642385395, 49.83365306411215, 51.233965688944686, 52.639288810235584, 54.04952319219781, 55.46457377971311, 56.88434943302067, 58.30876268465676, 59.73772951634505, 61.171169153816834, 62.60900387778375, 64.05115884949248, 65.49756194947248, 66.94814362824383, 68.40283676788863, 69.86157655350887, 71.32430035369704, 72.79094760923773, 74.26145972933908, 75.73577999476261, 77.21385346728431, 78.69562690497389, 80.18104868282897, 81.6700687183449, 83.1626384016394, 84.65871052978662, 86.15823924504592, 87.66117997669875, 89.16748938623223, 90.67712531563029, 92.19004673855383, 93.7062137142091, 95.22558734372085, 96.74812972884112, 98.2738039328383, 99.80257394342341, 101.33440463758168, 102.8692617481878, 104.4071118322922, 105.94792224097449, 107.49166109066765, 109.03829723586368, 110.58780024311812, 112.14014036627607, 113.6952885228489, 115.25321627147454, 116.81389579039984, 118.37729985692718, 119.94340182777134, 121.5121756202769, 123.08359569444865, 124.65763703575155, 126.23427513863912, 127.81348599077148, 129.39524605788776, 130.9795322692983, 132.5663220039654, 134.155593077143, 135.74732372754679, 137.34149260502886, 138.93807875873236, 140.5370616257021], [0.0, 0.7073208785583681, 1.5696433076091458, 2.502107246080127, 3.4832565923174124, 4.502274630885642, 5.552523632180512, 6.62947632039287, 7.729830356428945, 8.851061605373008, 9.99117297059247, 11.148541776945176, 12.321821430405532, 13.509875065598273, 14.711729081809194, 15.926539593659248, 17.153567575513733, 18.39216003872583, 19.641735505427405, 20.90177261188173, 22.171801036637618, 23.451394185874864, 24.740163227542745, 26.037752175187766, 27.343833798898647, 28.6581061953535, 29.98028988847684, 31.31012536126896, 32.647370941016376, 33.991800976417345, 35.34320425760825, 36.701382639673156, 38.066149837685764, 39.43733036719579, 40.81475860871267, 42.198277978442114, 43.587740190506665, 44.983004598288815, 46.38393760449551, 47.79041213114881, 49.20230714203061, 50.61950721120473, 52.0419021321522, 53.469386562818734, 54.901859702513846, 56.33922499714312, 57.78138986971295, 59.22826547343734, 60.67976646510975, 62.13581079668784, 63.59631952328525, 65.06121662597543, 66.5304288479964, 68.00388554310445, 69.48151853496249, 70.96326198657094, 72.4490522788533, 73.93882789760282, 75.43252932807731, 76.93009895660161, 78.4314809786008, 79.93662131254344, 81.44546751932424, 82.95796872666011, 84.47407555811296, 85.99374006638816, 87.51691567058926, 89.04355709713764, 90.57362032409172, 92.1070625286226, 93.64384203742438, 95.18391827985506, 96.72725174362175, 98.2738039328383, 99.82353732829755, 101.376415349813, 102.93240232049588, 104.4914634328438, 106.05356471652705, 107.6186730077665, 109.18675592020574, 110.75778181718621, 112.33171978534182, 113.90853960943423, 115.48821174835719, 117.07070731224118, 118.65599804059663, 120.24405628143627, 121.83485497132237, 123.42836761628783, 125.02456827358326, 126.62343153420576, 128.22493250616745, 129.82904679846476, 131.43575050571212, 133.04502019340555, 134.65683288378392, 136.27116604225765, 137.88799756437686, 139.50730576331154, 141.12906935781922, 142.75326746067628], [0.0, 0.7183241256468774, 1.5940610417352046, 2.541030604777925, 3.5374429370441, 4.572313055772706, 5.63889997330336, 6.732605986477914, 7.8500773842523, 8.98875076568457, 10.146597966845274, 11.32197106988266, 12.51350253284319, 13.720037805011035, 14.940588140114224, 16.174296525097684, 17.420412437873107, 18.678272731751346, 19.947286883260134, 21.226925418207934, 22.516710698714363, 23.81620949476712, 25.12502692555423, 26.442801466814636, 27.76920079817292, 29.10391831982933, 30.446670208113943, 31.797192908920625, 33.155240990019294, 34.52058528982439, 35.89301131284284, 37.27231783177059, 38.65831566378998, 40.05082659457404, 41.44968242821713, 42.85472414507126, 44.265801152489594, 45.68277061592332, 47.105496859809, 48.53385082931433, 49.96770960535379, 51.40695596639866, 52.8514779915319, 54.30116869997386, 55.755925722955205, 57.215651004363735, 58.680250527056714, 60.14963406212701, 61.62371493874942, 63.10240983252332, 64.58563857047743, 66.0733239511172, 67.56539157808156, 69.06176970613745, 70.56238909838098, 72.06718289363693, 73.57608648315578, 75.08903739580153, 76.60597519100693, 78.12684135884517, 79.65157922663245, 81.18013387153252, 82.71245203868526, 84.24848206442658, 85.7881738042071, 87.33147856485301, 88.87834904084465, 90.42873925431716, 91.98260449851345, 93.53990128444279, 95.1005872905197, 96.66462131497592, 98.23196323085617, 99.80257394342341, 101.376415349813, 102.95345030078865, 104.53364256446362, 106.11695679186197, 107.70335848420369, 109.29281396180626, 110.8852903345036, 112.48075547348998, 114.07917798450384, 115.68052718227163, 117.28477306613878, 118.89188629681833, 120.50183817419396, 122.11460061611774, 123.73014613814678, 125.34844783416776, 126.96947935785987, 128.59321490495188, 130.21962919623041, 131.84869746125975, 133.4803954227767, 135.11469928172465, 136.75158570289517, 138.39103180114535, 140.03301512816338, 141.67751365975394, 143.32450578361858, 144.97397028760727], [0.0, 0.729349401855125, 1.6185276615387794, 2.580031890229751, 3.591737765881575, 4.64249170152691, 5.725449244720859, 6.835942123956763, 7.97056515339072, 9.12671558744177, 10.30233413268513, 11.495747578022119, 12.705567391632332, 13.930621302052323, 15.169905387130099, 16.42254947985221, 17.687791538660207, 18.96495823848563, 20.253449992142276, 21.552729198746224, 22.862310889339962, 24.181755184433094, 25.510661142342418, 26.848661689912312, 28.195419406111828, 29.550622985260734, 30.913984247390548, 32.28523559320619, 33.66412782343421, 35.050428259177444, 36.44391911273537, 37.844396068244684, 39.251667039194615, 40.665551075916156, 42.08587740093046, 43.51248455385911, 44.945219630667616, 46.3839376044955, 47.828500717348156, 49.27877793358108, 50.73464444747178, 52.1959812383041, 53.6626746673306, 55.13461611176546, 56.61170163162114, 58.09383166576047, 59.58091075400837, 61.07284728256946, 62.569553250341954, 64.07094405401155, 65.57693829006337, 67.08745757206731, 68.60242636178162, 70.12177181278375, 71.64542362547958, 73.17331391246788, 74.70537707334469, 76.24154967812896, 77.7817703585748, 79.32597970670938, 80.87412018000207, 82.42613601262745, 83.98197313233739, 85.5415790825024, 87.104902948924, 88.67189529105592, 90.24250807730455, 91.81669462410878, 93.39440953852494, 94.97560866406681, 96.56024902957144, 98.1482888008807, 99.73968723514642, 101.33440463758168, 102.93240232049588, 104.53364256446362, 106.13808858148909, 107.74570448003873, 109.35645523182427, 110.97030664022688, 112.58722531026218, 114.20717861999198, 115.83013469329646, 117.45606237392579, 119.0849312007571, 120.71671138418615, 122.3513737835898, 123.98888988579819, 125.62923178452046, 127.27237216067185, 128.9182842635522, 130.5669418928306, 132.2183193812929, 133.87239157831166, 135.52913383400147, 137.1885219840233, 138.8505323350057, 140.51514165055067, 142.18232713779605, 143.8520664345057, 145.52433759666252, 147.19911908653944], [0.0, 0.7403964605471587, 1.643042619700424, 2.619110229974997, 3.646139864251937, 4.712808998248618, 5.8121695103216995, 6.939482421195117, 8.091290968527092, 9.264952984365001, 10.458377984286617, 11.669867413974817, 12.89801171027295, 14.141620845959311, 15.399675693019116, 16.67129290449245, 17.95569889659186, 19.25221014576029, 20.56021798319056, 21.879176665250558, 23.20859387742175, 24.548023077598355, 25.89705725125157, 27.25532376536834, 28.62248008818488, 29.998210198843147, 31.382221552469414, 32.774242496587625, 34.17402005743849, 35.58131803186414, 36.9959153334522, 38.41760455167813, 39.84619069060123, 41.28149005980631, 42.72332929514091, 44.1715444906741, 45.62598042641713, 47.08648987886656, 48.55293300348235, 50.02517677989439, 51.50309451201575, 52.98656537638826, 54.47547401304017, 55.96971015393539, 57.46916828476393, 58.97374733639025, 60.48335040275588, 61.997884482441144, 63.517260241439416, 65.041391794996, 66.57019650662127, 68.1035948026085, 69.64151000057927, 71.1838681507459, 72.73059788872453, 74.28163029886042, 75.83689878713595, 77.39633896283065, 78.95988852818721, 80.5274871754125, 82.09907649041052, 83.67459986270121, 85.2540024010335, 86.83723085424587, 88.42423353697019, 90.01496025981109, 91.60936226366657, 93.20739215788495, 94.80900386198041, 96.41415255065242, 98.02279460187718, 99.63488754785736, 101.25039002863498, 102.8692617481878, 104.4914634328438, 106.11695679186197, 107.74570448003873, 109.37767006221101, 111.01281797953607, 112.65111351743751, 114.29252277511529, 115.93701263652447, 117.58455074273496, 119.23510546559018, 120.8886458825892, 122.54514175292084, 124.20456349458479, 125.86688216253769, 127.53206942780733, 129.2000975575216, 130.870939395802, 132.54456834547554, 134.22095835056064, 135.90008387948708, 137.58191990901096, 139.2664419087892, 140.95362582657972, 142.64344807403546, 144.33588551306315, 146.03091544271803, 147.72851558660892, 149.4286640807885], [0.0, 0.7514650610189912, 1.6676053820645462, 2.658264772537044, 3.7006480467897114, 4.783263413796636, 5.899058880560957, 7.043224622156951, 8.212252199170724, 9.403459944404307, 10.614726121615544, 11.844326783849558, 13.09083129560231, 14.353031839270095, 15.629894051323873, 16.92052137915636, 18.22412867424372, 19.54002219465326, 20.86758417224763, 22.20626070476816, 23.555552117811445, 24.915005193664204, 26.284206833109977, 27.662778832436548, 29.050373539181358, 30.446670208113947, 31.851371920943784, 33.26420296411012, 34.684906582007564, 36.11324304034523, 37.54898794756642, 38.991930792450724, 40.44187366395417, 41.898630125570875, 43.36202422143079, 44.831889595281616, 46.30806870666425, 47.790412131148805, 49.27877793358108, 50.77303110499509, 52.27304305525332, 53.77869115464017, 55.289858318603216, 56.80643263064788, 58.32830699907178, 59.85537884380036, 61.38754981007236, 62.92472550613788, 64.46681526248632, 66.01373191042377, 67.56539157808156, 69.12171350216114, 70.68261985391636, 72.24803557804282, 73.81788824329062, 75.39210790374639, 76.97062696984132, 78.55338008824206, 80.1403040298673, 81.73133758534905, 83.3264214673263, 84.92549821901731, 86.52851212857101, 88.13540914874451, 89.74613682149624, 91.36064420712147, 92.97888181759117, 94.60080155378432, 96.22635664633216, 97.85550159981568, 99.48819214008108, 101.12438516445619, 102.76403869466989, 104.4071118322922, 106.05356471652705, 107.70335848420369, 109.35645523182427, 111.01281797953607, 112.67241063690736, 114.33519797039412, 116.00114557239432, 117.67021983179274, 119.34238790590757, 121.01761769375524, 122.69587781055706, 124.3771375634151, 126.06136692809115, 127.74853652682626, 129.43861760714253, 131.13158202157368, 132.82740220827284, 134.52605117245093, 136.22750246860105, 137.93173018346718, 139.63870891971897, 141.34841378029557, 143.06082035338449, 144.77590469800325, 146.4936433301543, 148.2140132095238, 149.93699172669835, 151.66255669087425], [0.0, 0.762554968281621, 1.6922154271579013, 2.6974946866557077, 3.7552611562733107, 4.853853452407085, 5.986115510756782, 7.147166524370841, 8.333446277286125, 9.54223352702422, 10.771375225364034, 12.019121983832719, 13.284022054015084, 14.564849793679361, 15.86055557445426, 17.170229612664563, 18.49307517278823, 19.828388274846784, 21.17554203385671, 22.533974373227636, 23.903178244503675, 25.282693741513658, 26.672101668640597, 28.071018240749645, 29.479090674822253, 30.895993492161242, 32.32142539264054, 33.75510659379724, 35.19677655089986, 36.64619199172718, 38.103125213215804, 39.567362597480745, 41.038703312763225, 42.51695817118052, 44.001948620155986, 45.49350584839915, 46.99146999051371, 48.49568941690661, 50.006020097785076, 51.52232503175928, 53.04447373099509, 54.57234175604251, 56.10581029444864, 57.64476577808717, 59.18909953482688, 60.738707470745716, 62.293489779590864, 63.85335067660588, 65.41819815420533, 66.98794375728461, 68.56250237621785, 70.1417920558248, 71.72573381878482, 73.31425150214872, 74.90727160574687, 76.50472315142402, 78.10653755214373, 79.71264849010684, 81.32299180311524, 82.93750537849053, 84.55612905392572, 86.17880452470826, 87.80547525680743, 89.43608640536657, 91.07058473818323, 92.70891856379909, 94.35103766385484, 95.99689322939636, 97.64643780084586, 99.2996252113759, 100.95641053344734, 102.61675002829105, 104.28060109813256, 105.94792224097449, 107.6186730077665, 109.29281396180626, 110.97030664022688, 112.65111351743751, 114.33519797039412, 116.0225242455861, 117.71305742763379, 119.40676340939875, 121.1036088635162, 122.80356121526543, 124.50658861670011, 126.21265992196525, 127.92174466373352, 129.63381303069735, 131.348835846058, 133.06678454695685, 134.7876311647972, 136.51134830640854, 138.23790913600865, 139.96728735792115, 141.69945720000914, 143.43439339778797, 145.17207117918258, 146.91246624989634, 148.65555477936155, 150.40131338724194, 152.14971913046085, 153.900749490729], [0.0, 0.7736659528546398, 1.7168722457315782, 2.736799160557139, 3.8099780626086455, 4.924577653379666, 6.0733375994702135, 7.251305976995525, 8.454870695037492, 9.681270860621073, 10.928322054035167, 12.19424939693519, 13.477579987867918, 14.7770703260963, 16.091655489394668, 17.420412437873107, 18.762532826989286, 20.117302419260678, 21.484085195530273, 22.862310889339962, 24.25146506416638, 25.651081112668486, 27.060733731242028, 28.480033542721568, 29.908622623781515, 31.346170753261607, 32.79237224087218, 34.24694322751487, 35.70961937213057, 37.18015385784355, 38.65831566378997, 40.14388805951575, 41.636667286996236, 43.13646140174266, 44.6430892495365, 46.156379559383126, 47.67617013653026, 49.202307142030605, 50.73464444747178, 52.27304305525332, 53.81737057623776, 55.36750075780114, 56.923313056306085, 58.48469224885547, 60.0515280798855, 61.623714938749416, 63.20115156494418, 64.78374077805927, 66.37138922989134, 67.96400717648007, 69.56150826809001, 71.16380935539387, 72.77083031031361, 74.38249386015006, 75.99872543378227, 77.61945301885125, 79.24460702895722, 80.87412018000207, 82.50792737489745, 84.14596559593775, 85.78817380420709, 87.43449284545054, 89.08486536189514, 90.73923570955445, 92.39754988059387, 94.05975543037263, 95.72580140881315, 97.3956382957791, 99.06921794017184, 100.74649350247945, 102.42741940053563, 104.11195125826532, 105.80004585721329, 107.49166109066765, 109.18675592020574, 110.8852903345036, 112.58722531026218, 114.29252277511529, 116.00114557239432, 117.71305742763379, 119.42822291671142, 121.14660743552272, 122.86817717109885, 124.59289907408149, 126.32074083247645, 128.0516708466108, 129.7856582052259, 131.5226726626416, 133.26268461693186, 135.00566508905627, 136.7515857028951, 138.5004186661394, 140.25213675198995, 142.00671328162298, 143.76412210738272, 145.52433759666252, 147.28733461643998, 149.0530885184328, 150.82157512484443, 152.59277071466997, 154.36665201053535, 156.1431961660433], [0.0, 0.7847977905697833, 1.7415753403250516, 2.7761774012588947, 3.8647976618616897, 4.9954345898272035, 6.160723386963028, 7.355640878978643, 8.576523002641835, 9.82056914006472, 11.085563441168045, 12.369705489895988, 13.671501192057189, 14.989689154892393, 16.323189133617987, 17.67106480725003, 19.03249620043806, 20.406758798944157, 21.793207432294768, 23.191263628793276, 24.600405549982863, 26.020159874775853, 27.45009518011723, 28.889816486315812, 30.338960720091617, 31.79719290892062, 33.26420296411011, 34.739702942275194, 36.22342469890419, 37.715117865814236, 39.214548098114186, 40.721495546939174, 42.235753522506656, 43.75712731854819, 45.28543317432064, 46.820497354508795, 48.36215533063269, 49.91025105024423, 51.464636282372744, 53.02517002946065, 54.59171799749875, 56.164152117286164, 57.742350110751936, 59.32619509712245, 60.915575234429554, 62.51038339245518, 64.11051685371673, 65.71587703953021, 67.32636925855829, 68.94190247556604, 70.56238909838096, 72.18774478128755, 73.81788824329061, 75.4527410998582, 77.0922277069081, 78.73627501593658, 80.38481243930492, 82.03777172480248, 83.69508683869613, 85.35669385655441, 87.02253086120736, 88.69253784726322, 90.36665663166082, 92.04483076978414, 93.72700547671067, 95.41312755320368, 97.10314531609399, 98.79700853272828, 100.49466835918928, 102.19607728201805, 103.90118906319252, 105.60995868813563, 107.32234231654645, 109.03829723586368, 110.75778181718621, 112.48075547348998, 114.20717861999198, 115.93701263652447, 117.67021983179274, 119.40676340939875, 121.14660743552272, 122.88971680816151, 124.6360572278307, 126.38559516964371, 128.13829785668742, 129.8941332346193, 131.65306994741627, 133.41507731421032, 135.1801253071502, 136.94818453023265, 138.71922619905015, 140.49322212140606, 142.2701446787503, 144.04996680839275, 145.83266198645396, 147.61820421151427, 149.40656798892664, 151.1977283157587, 152.99166066633333, 154.78834097833771, 156.58774563947284, 158.38985147461779], [0.0, 0.7959502623838292, 1.7663242248509763, 2.8156286339080747, 3.919718875337087, 5.0664228674847, 6.248271153728981, 7.4601691773031, 8.698400806324278, 9.960125624357245, 11.243096292694913, 12.545486810233239, 13.865781850759623, 15.20270209632776, 16.55515195119402, 17.922181788662467, 19.302959981015494, 20.69675171821069, 22.10290266149497, 23.520826118723893, 24.949992835786883, 26.38992276540494, 27.840178353729215, 29.300359008157873, 30.770096495910522, 32.24905108429221, 33.73690827805423, 35.23337604195449, 36.73818242097861, 38.251073489053866, 39.77181157110033, 41.30017369406203, 42.83595023096421, 44.37894370863948, 45.928967754988605, 47.4858461658079, 49.04941207456388, 50.61950721120472, 52.1959812383041, 53.77869115464017, 55.36750075780114, 56.96228015864197, 58.562905341443134, 60.16925776448149, 61.78122399644395, 63.39869538472444, 65.02156775216012, 66.6497411192017, 68.28311944888819, 69.92161041231651, 71.56512517257414, 73.21357818533976, 74.86688701456389, 76.52497216182097, 78.18775690807863, 79.85516716676779, 81.52713134715485, 83.20358022712222, 84.8844468345557, 86.56966633661739, 88.2591759362552, 89.95291477536296, 91.65082384406143, 93.35284589562102, 95.0589253665909, 96.76900830173958, 98.48304228344745, 100.20097636522351, 101.92276100904759, 103.64834802626451, 105.37769052178075, 107.11074284133369, 108.84746052162407, 110.58780024311812, 112.33171978534182, 114.07917798450384, 115.83013469329646, 117.58455074273496, 119.34238790590757, 121.1036088635162, 122.86817717109885, 124.6360572278307, 126.4072142468101, 128.18161422674058, 129.9592239249285, 131.74001083151882, 133.52394314489962, 135.3109897482084, 137.1011201868792, 138.89430464717296, 140.69051393563765, 142.48971945944763, 144.29189320757584, 146.09700773275426, 147.90503613418238, 149.71595204094396, 151.52972959609693, 153.34634344140144, 155.16576870265513, 156.98798097560442, 158.81295631240468, 160.64067120860187], [0.0, 0.8071231542002879, 1.7911184241994949, 2.8551521011505643, 3.974740648700048, 5.137541123574353, 6.335979219094061, 7.564888865315833, 8.820501766369434, 10.099937634401686, 11.400917584422476, 12.721589983433718, 14.060418234326072, 15.41610506114544, 16.787539489080817, 18.1737585613617, 19.573918976568052, 20.98727561000151, 22.413164937842478, 23.85099203244717, 25.300220210473316, 26.760362686135046, 28.23097576356427, 29.711653226971364, 31.20202167462856, 32.70173660495417, 34.21047910807516, 35.727953049400135, 37.253882656435, 38.78801043870276, 40.33009538483717, 41.87991139187083, 43.43724589025879, 45.001898634868574, 46.573680637463475, 48.15241322043087, 49.73792717490283, 51.330062009163335, 52.92866527547357, 54.53359196527875, 56.144703964270214, 57.76186956002647, 59.384962995997846, 61.01386406647048, 62.64845774787628, 64.2886338624337, 65.934286770627, 67.58531508947665, 69.24162143393414, 70.90311217905963, 72.56969724092144, 74.24128987439775, 75.91780648627001, 77.59916646217944, 79.28529200617533, 80.9761079917226, 82.67154182315609, 84.37152330667533, 86.07598453006699, 87.78485975042335, 89.49808528919924, 91.21559943401266, 92.9373423466525, 94.6632559768069, 96.39328398107124, 98.12737164683506, 99.8654658206836, 101.60751484098108, 103.35346847433355, 105.10327785565337, 106.85689543157241, 108.6142749069713, 110.37537119441171, 112.14014036627607, 113.90853960943423, 115.68052718227163, 117.45606237392579, 119.23510546559018, 121.01761769375524, 122.80356121526543, 124.59289907408149, 126.38559516964371, 128.18161422674058, 129.98092176679364, 131.78348408047572, 133.58926820158533, 135.39824188210582, 137.21037356838193, 139.02563237835156, 140.84398807977516, 142.6654110694071, 144.48987235305927, 146.317343526509, 148.1477967572062, 149.98120476673915, 151.8175408140185, 153.6567786791438, 155.4988926479172, 157.3438574969728, 159.19164847949034, 161.04224131146512, 162.89561215850702], [0.0, 0.8183162566993758, 1.8159574738609232, 2.8947470625295737, 4.029861951139044, 5.208788025723287, 6.423845939881769, 7.669797981134206, 8.942823595263292, 10.240002550874394, 11.5590243596302, 12.89801171027295, 14.25540669631957, 15.62989405132387, 17.02034739358821, 18.425790412154722, 19.845368110784317, 21.278325031464473, 22.72398844869418, 24.181755184433094, 25.651081112668486, 27.13147269691829, 28.62248008818488, 30.123691437319025, 31.634728164295456, 33.155240990019294, 34.684906582007564, 36.223424698904196, 37.77051574382998, 39.32591865545596, 40.88938908009455, 42.460697779205226, 44.039629235350006, 45.62598042641714, 47.219559743300096, 48.82018603050314, 50.42768773258682, 52.04190213215221, 53.66267466733061, 55.28985831860322, 56.92331305630609, 58.56290534144314, 60.20850767348556, 61.859998179718765, 63.517260241439416, 65.18018215293161, 66.84865680968147, 68.5225814227405, 70.2018572565342, 71.88638938774147, 73.57608648315578, 75.27086059468267, 76.9706269698413, 78.67530387632111, 80.38481243930494, 82.09907649041052, 83.81802242722334, 85.5415790825024, 87.26967760223458, 89.0022513317962, 90.73923570955445, 92.48056816730622, 94.22618803701013, 95.97603646331845, 97.73005632146189, 99.48819214008108, 101.250390028635, 103.01659760904954, 104.78676395129914, 106.56083951263999, 108.3387760802387, 110.12052671695983, 111.90604571009702, 113.6952885228489, 115.48821174835719, 117.28477306613878, 119.0849312007571, 120.8886458825892, 122.69587781055706, 124.50658861670011, 126.32074083247645, 128.13829785668742, 129.9592239249285, 131.78348408047572, 133.61104414652436, 135.44187069970104, 137.2759310447768, 139.1131931905135, 140.95362582657972, 142.79719830147826, 144.6438806014286, 146.4936433301543, 148.34645768952564, 150.20229546101362, 152.06112898791224, 153.9229311582894, 155.78767538862976, 157.6553356081335, 159.5258862436397, 161.39930220514165, 163.27555887186654, 165.15463207889127], [0.0, 0.8295293651757856, 1.8408409195657425, 2.934412793911759, 4.085081774566894, 5.280162270930927, 6.511869709139601, 7.774894606125492, 9.06536405592033, 10.380317812194994, 11.717413726778766, 13.074748764258212, 14.45074367068924, 15.844065156978285, 17.253571407003598, 18.678272731751342, 20.117302419260678, 21.569894659735674, 23.035367509547296, 24.513109525512313, 26.00256912564487, 27.503246010700888, 29.014684167555384, 30.53646610363076, 32.068208051348826, 33.60955594556243, 35.16018202327387, 36.71978192902225, 38.28807223470769, 39.864788301766914, 41.44968242821713, 43.04252223434029, 44.64308924953651, 46.251177669751286, 47.86659326032388, 49.489152383446616, 51.118681132914375, 52.755014561667224, 54.39799598992792, 56.04747638361936, 57.703313794298865, 59.36537285313106, 61.0335243124909, 62.70764462968356, 64.38761558801939, 66.07332395111719, 67.76466114684646, 69.46152297777682, 71.16380935539388, 72.87142405567464, 74.5842744939048, 76.30227151686721, 78.02532921074666, 79.7533647232826, 81.48629809886323, 83.22405212539688, 84.96655219192027, 86.71372615601197, 88.46550422017584, 90.22181881644262, 91.98260449851344, 93.74779784083448, 95.5173373440509, 97.29116334634017, 99.06921794017184, 100.85144489408137, 102.63778957908407, 104.42819889938697, 106.2226212270877, 108.02100634057518, 109.823305366372, 111.62947072417914, 113.43945607490463, 115.25321627147454, 117.07070731224118, 118.89188629681833, 120.71671138418615, 122.54514175292084, 124.3771375634151, 126.21265992196525, 128.0516708466108, 129.8941332346193, 131.74001083151882, 133.58926820158533, 135.44187069970104, 137.29778444450343, 139.15697629275203, 141.01941381484363, 142.88506527141206, 144.75389959095307, 146.62588634841762, 148.50099574472202, 150.37919858712567, 152.2604662704307, 154.14477075896068, 156.03208456927794, 157.92238075360234, 159.81563288389475, 161.71181503657394, 163.61090177783345, 165.5128681495304, 167.41768965561798], [0.0, 0.8407622793838152, 1.865768316940916, 2.9741485869393753, 4.140399132858088, 5.351662584583203, 6.600048954923301, 7.880176863455312, 9.188120959991025, 10.520880912588384, 11.876082857322448, 13.251797989187496, 14.64642566907236, 16.05861455340267, 17.487207364370718, 18.931201011277025, 20.389717045745485, 21.8619792879124, 23.347296559738723, 24.845049138299576, 26.354677972466508, 27.87567598828832, 29.407580997625, 30.949969854502562, 32.502453594627106, 34.0646733583456, 35.63629694432003, 37.21701587571786, 38.806542886451496, 40.40460975440484, 42.010965423385805, 43.62537436695057, 45.24761515612113, 46.87747919998652, 48.51476963369425, 50.1593003327402, 51.81089503600142, 53.46938656281873, 55.13461611176546, 56.806432630647876, 58.48469224885546, 60.169257764481486, 61.85999817971875, 63.55678827894253, 65.25950824465433, 66.96804330710404, 68.68228342395226, 70.40212298679893, 72.12746055180007, 73.85819859193339, 75.59424326876623, 77.33550422183013, 79.08189437392429, 80.83332975086, 82.58972931432176, 84.35101480666503, 86.11711060659636, 87.88794359479142, 89.66344302860458, 91.44354042510771, 93.22816945177337, 95.01726582418266, 96.81076721019889, 98.60861314010033, 100.41074492221269, 102.21710556362376, 104.02763969560084, 105.84229350336436, 107.66101465990253, 109.48375226353787, 111.31045677898206, 113.14107998163651, 114.97557490491727, 116.81389579039984, 118.65599804059663, 120.50183817419396, 122.3513737835898, 124.20456349458479, 126.06136692809115, 127.92174466373352, 129.7856582052259, 131.65306994741627, 133.52394314489962, 135.39824188210582, 137.2759310447768, 139.15697629275203, 141.0413440339881, 142.92900139974256, 144.81991622085658, 146.7140570050771, 148.61139291536, 150.51189374910302, 152.41552991825762, 154.322272430274, 156.232092869836, 158.14496338134424, 160.06085665211026, 161.97974589622473, 163.90160483906715, 165.82640770242398, 167.7541291901864, 169.68474447459909], [0.0, 0.8520148033894351, 1.890739231181609, 3.013953748506975, 4.1958130611202815, 5.4232877195109195, 6.688382139135574, 7.985642916701122, 9.311092166245201, 10.661689400233586, 12.035028983619517, 13.429156296817856, 14.842449278217327, 16.273538498244243, 17.72125119041278, 19.184570838941905, 20.66260723855147, 22.15457382120651, 23.659770158337043, 25.177568232822246, 26.707401511351843, 28.248756133440626, 29.80116372515353, 31.364195477250814, 32.93745721965073, 34.52058528982439, 36.11324304034523, 37.71511786581424, 39.32591865545596, 40.9453735973455, 42.573228275225894, 44.20924401043414, 45.853196410449584, 47.504874092639625, 49.164077557368415, 50.83061818909421, 52.50431736766517, 54.185005674923566, 55.87252218408945, 57.56671382132935, 59.26743479050927, 60.97454605345107, 62.68791485911003, 64.40741431601099, 66.13292300305204, 67.86432461443725, 69.60150763505176, 71.34436504306262, 73.0927940369302, 74.84669578435818, 76.60597519100693, 78.3705406870491, 80.14030402986728, 81.9151801213861, 83.69508683869613, 85.47994487677477, 87.26967760223458, 89.06421091714294, 90.86347313205468, 92.6673948474856, 94.4759088431325, 96.28894997421206, 98.10645507435191, 99.92836286452074, 101.7546138675315, 103.58515032769503, 105.41991613523919, 107.25885675514266, 109.10191916006376, 110.94905176707138, 112.80020437791093, 114.65532812255951, 116.51437540584567, 118.37729985692718, 120.24405628143627, 122.11460061611774, 123.98888988579819, 125.86688216253769, 127.74853652682626, 129.63381303069735, 131.5226726626416, 133.41507731421032, 135.3109897482084, 137.21037356838193, 139.1131931905135, 141.01941381484363, 142.92900139974256, 144.84192263656183, 146.7581449255998, 148.67763635311996, 150.600365669364, 152.5263022675065, 154.45541616350093, 156.38767797676942, 158.32305891169327, 160.26153073986163, 162.20306578304076, 164.14763689682636, 166.09521745494578, 168.04578133417726, 169.999302899856, 171.955756991939], [0.0, 0.863286745428908, 1.9157532367374435, 3.0538276002612785, 4.251322614998061, 5.495036455089838, 6.776867756416243, 8.091290968527094, 9.434275579026979, 10.802740875494592, 12.194249396935188, 13.606820664637022, 15.038811157520746, 16.488833328803068, 17.955698896591862, 19.438377896857393, 20.935968347127055, 22.44767327326817, 23.972782980216532, 25.51066114234242, 27.060733731242028, 28.62248008818488, 30.195425642766285, 31.77913591270787, 33.37321151315662, 34.97728397041965, 36.591012183309424, 38.21407941073594, 39.84619069060124, 41.487070614976886, 43.13646140174266, 44.79412121457675, 46.45982269230177, 48.13335165574593, 49.814505965943276, 51.50309451201576, 53.19893631071176, 54.90185970251384, 56.61170163162114, 58.32830699907178, 60.0515280798855, 61.78122399644395, 63.51726024143941, 65.25950824465434, 67.00784497861612, 68.76215259883233, 70.52231811487114, 72.28823308902759, 74.05979335972346, 75.83689878713596, 77.61945301885126, 79.4073632735961, 81.20054014132545, 82.9988973981377, 84.80235183465798, 86.61082309667812, 88.4242335369702, 90.24250807730455, 92.06557407980263, 93.89336122684247, 95.72580140881315, 97.56282861908218, 99.40437885560198, 101.250390028635, 103.10080187412593, 104.95555587229235, 106.8145951710439, 108.67786451387462, 110.54531017190442, 112.41687987977294, 114.2925227751153, 116.17218934137043, 118.05583135369473, 119.94340182777134, 121.83485497132237, 123.73014613814678, 125.62923178452046, 127.53206942780733, 129.43861760714253, 131.348835846058, 133.26268461693186, 135.1801253071502, 137.1011201868792, 139.02563237835156, 140.95362582657972, 142.88506527141206, 144.81991622085658, 146.7581449255998, 148.6997183546542, 150.64460417207252, 152.59277071467, 154.5441869707006, 156.49882255943638, 158.45664771160182, 160.41763325061933, 162.3817505746234, 164.3489716392041, 166.3192689408435, 168.2926155010101, 170.26898485087835, 172.24835101664337, 174.2306885054011], [0.0, 0.8745779177736024, 1.9408099170125026, 3.093769478122965, 4.306926870007201, 5.566907596380176, 6.865504333081023, 8.197119259417066, 9.557669146777414, 10.944032989228694, 12.353741445532057, 13.784788133732627, 15.235508036672428, 16.70449545945, 18.19054657829712, 19.6926179579922, 21.20979581877789, 22.741272762670654, 24.286329812303126, 25.844322319362085, 27.414668747563322, 28.996841628333062, 30.59036018422561, 32.19478425024556, 33.80970921787207, 35.43476179404024, 37.06959641620331, 38.713892200524676, 40.36735032701336, 42.029691785602495, 43.70065542256634, 45.37999623853722, 47.06748389861635, 48.7629014223218, 50.46604402685468, 52.17671810174355, 53.8947402966055, 55.6199367067395, 57.35214214369163, 59.091199479916654, 60.83695905829738, 62.58927815863711, 64.34802051436886, 66.11305587366873, 67.88425959995288, 69.66151230740732, 71.44469952776629, 73.23371140503731, 75.02844241528335, 76.82879110892443, 78.63465987332616, 80.44595471370268, 82.26258505058958, 84.0844635323384, 85.91150586125525, 87.74363063215644, 89.58075918224394, 91.42281545131858, 93.26972585145042, 95.12141914531335, 96.97782633247151, 98.83888054297293, 100.70451693766908, 102.57467261473313, 104.4492865218991, 106.32829937398769, 108.21165357532394, 110.09929314668635, 111.99116365645958, 113.88721215568977, 115.78738711676874, 117.69163837549428, 119.59991707627636, 121.5121756202769, 123.42836761628783, 125.34844783416776, 127.27237216067185, 129.2000975575216, 131.13158202157368, 133.06678454695685, 135.00566508905627, 136.94818453023265, 138.89430464717296, 140.84398807977516, 142.79719830147826, 144.75389959095307, 146.7140570050771, 148.67763635311996, 150.64460417207252, 152.61492770305648, 154.58857486875525, 156.56551425181144, 158.5457150741389, 160.5291471771013, 162.51578100251237, 164.5055875744146, 166.49853848159734, 168.49460586081628, 170.49376238068007, 172.49598122616993, 174.50123608376214, 176.5095011271237], [0.0, 0.8858881366006565, 1.965908864078315, 3.133778731829151, 4.362624920897746, 5.638899973303359, 6.954290426106224, 8.30312606646232, 9.681270860621073, 11.085563441168047, 12.513502532843187, 13.963055806753676, 15.432536713402309, 16.920521379156355, 18.425790412154722, 19.94728688326013, 21.48408519553027, 23.035367509547296, 24.600405549982867, 26.178546331801158, 27.769200798172914, 29.371834659193894, 30.985960919907065, 32.61113372301413, 34.24694322751487, 35.89301131284284, 37.54898794756641, 39.21454809811419, 40.889389080094546, 42.57322827522589, 44.26580115248959, 45.96685954413649, 47.67617013653027, 49.3935131431534, 51.11868113291437, 52.8514779915319, 54.591717997498755, 56.33922499714311, 58.09383166576047, 59.85537884380035, 61.62371493874941, 63.39869538472444, 65.18018215293161, 66.96804330710403, 68.76215259883233, 70.56238909838096, 72.36863685715737, 74.18078459848914, 75.99872543378228, 77.82235660149031, 79.65157922663244, 81.48629809886323, 83.32642146732628, 85.17186085072392, 87.02253086120737, 88.87834904084464, 90.73923570955444, 92.60511382351173, 94.4759088431325, 96.35154860983515, 98.23196323085617, 100.11708497146785, 102.00684815400864, 103.90118906319255, 105.80004585721329, 107.70335848420368, 109.61106860364976, 111.52311951239543, 113.43945607490464, 115.36002465747697, 117.28477306613875, 119.21365048795415, 121.14660743552274, 123.08359569444865, 125.02456827358326, 126.96947935785987, 128.9182842635522, 130.870939395802, 132.82740220827284, 134.7876311647972, 136.7515857028951, 138.71922619905015, 140.69051393563765, 142.6654110694071, 144.6438806014286, 146.62588634841762, 148.61139291536, 150.600365669364, 152.59277071467, 154.58857486875525, 156.58774563947287, 158.59025120316977, 160.5960603837314, 162.60514263250383, 164.61746800904828, 166.63300716268435, 168.65173131478184, 170.67361224176332, 172.69862225878234, 174.72673420404288, 176.75792142372939, 178.79215775751751], [0.0, 0.8972172218691828, 1.9910496783991358, 3.1738547244954702, 4.418415881044364, 5.711012439854023, 7.043224622156949, 8.409309702201288, 9.805078753013154, 11.227329978370548, 12.673530115723448, 14.141620845959313, 15.62989405132387, 17.1369076491294, 18.66142665345298, 20.202380618732604, 21.7588321111289, 23.32995283237248, 24.9150051936642, 26.513327859339253, 28.124324239478405, 29.747453211468365, 31.38222155246941, 33.02817770338508, 34.68490658200756, 36.35202523221614, 38.029179146239855, 39.71603913385038, 41.41229863980927, 43.117671431601394, 44.83188959528161, 46.55470178943416, 48.28587171671634, 50.02517677989438, 51.77240689516652, 53.52736344026505, 55.28985831860321, 57.05971312378686, 58.83675839129749, 60.62083292618981, 62.41178319732591, 64.2094627900573, 66.01373191042374, 67.82445693490561, 69.64151000057927, 71.46476863121227, 73.29411539541591, 75.12943759346803, 76.9706269698413, 78.81757944883428, 80.67019489101409, 82.52837686844802, 84.39203245693372, 86.2610720436399, 88.13540914874449, 90.01496025981108, 91.89964467777823, 93.7893843735542, 95.68410385431353, 97.58373003868235, 99.48819214008107, 101.39742155756365, 103.31135177355686, 105.2299182579586, 107.1530583781053, 109.08071131416288, 111.01281797953605, 112.94932094592646, 114.89016437270317, 116.83529394027696, 118.78465678719712, 120.73820145071205, 122.69587781055704, 124.65763703575155, 126.62343153420576, 128.59321490495188, 130.5669418928306, 132.54456834547554, 134.52605117245093, 136.51134830640854, 138.5004186661394, 140.49322212140606, 142.48971945944763, 144.48987235305927, 146.4936433301543, 148.50099574472202, 150.51189374910302, 152.5263022675065, 154.5441869707006, 156.56551425181144, 158.59025120316977, 160.6183655941492, 162.6498258499427, 164.6846010312282, 166.72266081467689, 168.76397547426026, 170.8085158633157, 172.85625339733167, 174.90716003741696, 176.96120827441985, 179.01837111366535, 181.07862206028062], [0.0, 0.9085649972017137, 2.0162319685688574, 3.2139968321966945, 4.474298881862518, 5.7832438733453895, 7.132305536656426, 8.515668513508372, 9.929090896443888, 11.369330393736307, 12.833821702774886, 14.320480471350207, 15.82757697786888, 17.353650900547954, 18.897451633676514, 20.457895192969207, 22.034032288161782, 23.6250241448789, 25.2301238454858, 26.848661689912312, 28.480033542721564, 30.12369143731902, 31.779135912707865, 33.44590969858698, 35.1235924628943, 36.81179640597748, 38.51016253634136, 40.218357500243314, 41.936070865212166, 43.6630127785367, 45.398911937764304, 47.1435138225769, 48.896579147003045, 50.65788249845575, 52.42721113604674, 54.20436392538438, 55.98915039088406, 57.781389869712946, 59.580910754008364, 61.38754981007236, 63.201151564944176, 65.02156775216011, 66.84865680968146, 68.68228342395226, 70.52231811487113, 72.36863685715737, 74.22112073417995, 76.07965562081924, 77.94413189235955, 79.8144441567764, 81.69049100809886, 83.5721747987982, 85.45940142939038, 87.35208015364384, 89.25012339796167, 91.15344659366342, 93.06196802102642, 94.97560866406681, 96.89429207514509, 98.81794424857272, 100.74649350247947, 102.67987036827196, 104.61800748707962, 106.56083951264, 108.50830302012754, 110.46033642047438, 112.41687987977295, 114.3778752433864, 116.3432659644257, 118.31299703628125, 120.28701492892418, 122.26526752871506, 124.24770408148082, 126.23427513863912, 128.22493250616745, 130.21962919623041, 132.2183193812929, 134.22095835056064, 136.22750246860105, 138.23790913600865, 140.25213675198995, 142.2701446787503, 144.29189320757584, 146.317343526509, 148.34645768952564, 150.37919858712567, 152.41552991825762, 154.45541616350093, 156.49882255943638, 158.5457150741389, 160.5960603837314, 162.6498258499427, 164.70697949861568, 166.76748999911555, 168.83132664459174, 170.89845933304855, 172.96885854918375, 175.04249534695614, 177.11934133284578, 179.1993686497722, 181.28254996163858, 183.3688584384717], [0.0, 0.9199312897706118, 2.0414553510589393, 3.25420444356492, 4.53027307224909, 5.85559317368624, 7.221531812894328, 8.622200880529332, 10.053305402197193, 11.511562524586251, 12.994374852742238, 14.499631958878206, 16.025582482308618, 17.570747832392843, 19.13386175814368, 20.713826714460033, 22.309681535305508, 23.92057695310398, 25.545756706162315, 27.184542716355992, 28.836323290417774, 30.5005436066039, 32.17669795558108, 33.86432334652403, 35.56299418894976, 37.27231783177059, 38.991930792450724, 40.72149554693918, 42.460697779205226, 44.20924401043414, 45.9668595441365, 47.733286675904566, 49.508283126261375, 51.291620662672614, 53.08308388282769, 54.88246913611171, 56.689583564060264, 58.50424424371973, 60.32627742038581, 62.155517818281, 63.99180801945312, 65.83499790260142, 67.68494413472355, 69.54150970946951, 71.40456352692124, 73.27398001022205, 75.14963875507495, 77.03142420863692, 78.91922537476965, 80.8129355429777, 82.71245203868526, 84.61767599277755, 86.528512128571, 88.44486856458427, 90.36665663166083, 92.29379070315258, 94.22618803701013, 96.16376862874712, 98.10645507435191, 100.05417244231303, 102.00684815400864, 103.96441187178226, 105.92679539409309, 107.89393255718656, 109.86575914278248, 111.84221279132392, 113.82323292037165, 115.80876064776506, 117.79873871920452, 119.79311143993904, 121.79182461027054, 123.7948254646097, 125.80206261384068, 127.81348599077148, 129.82904679846476, 131.84869746125975, 133.87239157831166, 135.90008387948708, 137.93173018346718, 139.96728735792115, 142.00671328162298, 144.04996680839275, 146.09700773275426, 148.1477967572062, 150.20229546101362, 152.2604662704307, 154.322272430274, 156.38767797676942, 158.45664771160182, 160.5291471771013, 162.60514263250383, 164.6846010312282, 166.76748999911555, 168.85377781357985, 170.943433383623, 173.03642623066844, 175.1327264701729, 177.23230479397557, 179.33513245334908, 181.44118124271643, 183.55042348400193, 185.66283201158504], [0.0, 0.9313159301891901, 2.066719449976788, 3.2944769594044065, 4.586337618046183, 5.928059262687868, 7.310902121172054, 8.728905215660765, 10.177720419160803, 11.654024251299639, 13.155187172974953, 14.679072638730192, 16.223907613857133, 17.788195209367252, 19.370653503741952, 20.97017136917405, 22.585775744684756, 24.21660685255867, 25.86189907196081, 27.520965933188158, 29.19318817294301, 30.87800410326658, 32.57490175640282, 34.283412411768, 36.003105211969896, 37.73358264665419, 39.47447673499479, 41.22544577590056, 42.986171563512215, 44.75635698705816, 46.53572395053339, 48.324011560300654, 50.12097453854522, 51.92638182823342, 53.74001536133616, 55.56166896695359, 57.3911473998949, 59.22826547343735, 61.07284728256947, 62.92472550613789, 64.78374077805928, 66.6497411192017, 68.5225814227405, 70.40212298679894, 72.28823308902759, 74.18078459848915, 76.07965562081925, 77.98472917314679, 79.89589288569705, 81.81303872737526, 83.73606275295299, 85.66486486975742, 87.59934862200521, 89.53942099113264, 91.48499221065512, 93.43597559424909, 95.39228737588815, 97.35384656098773, 99.32057478762029, 101.29239619695691, 103.26923731217661, 105.25102692515689, 107.23769599032649, 109.2291775251191, 111.22540651651904, 113.22631983323662, 115.23185614309259, 117.2419558352282, 119.25656094679132, 121.27561509377871, 123.29906340574213, 125.32685246408992, 127.35893024373853, 129.39524605788776, 131.43575050571212, 133.4803954227767, 135.52913383400147, 137.58191990901096, 139.63870891971897, 141.69945720000914, 143.76412210738272, 145.83266198645396, 147.90503613418238, 149.98120476673915, 152.06112898791224, 154.14477075896068, 156.232092869836, 158.32305891169327, 160.41763325061933, 162.51578100251237, 164.61746800904828, 166.72266081467689, 168.83132664459174, 170.943433383623, 173.05894955600473, 175.1778443059719, 177.30008737914395, 179.425649104656, 181.55450037799983, 183.68661264453937, 185.82195788366798, 187.96050859357615], [0.0, 0.9427187524072923, 2.092023896834034, 3.334813792322202, 4.64249170152691, 6.00064108339942, 7.400415157983028, 8.835779962571436, 10.30233413268513, 11.796713496007422, 13.316256317952233, 14.858799893682276, 16.422549479852215, 18.00598985990234, 19.607823416756066, 21.226925418207934, 22.862310889339962, 24.513109525512313, 26.178546331801158, 27.857926433523254, 29.55062298526073, 31.256067421874107, 32.97374150718959, 34.703170781714334, 36.44391911273537, 38.19558412287125, 39.95779332582162, 41.73020083678427, 43.51248455385911, 45.30434372851728, 47.105496859809, 48.91567985977416, 50.73464444747178, 52.562156736857986, 54.39799598992792, 56.241953511471706, 58.09383166576047, 59.95344299868699, 61.82060945149853, 63.695161654399215, 65.57693829006335, 67.4657855185608, 69.36155645641165, 71.26411070350466, 73.17331391246789, 75.08903739580153, 77.01115776669408, 78.93955660996257, 80.87412018000208, 82.81473912300949, 84.76130822107443, 86.71372615601199, 88.67189529105592, 90.63572146874425, 92.60511382351173, 94.57998460766704, 96.56024902957144, 98.54582510296096, 100.53663350646224, 102.53259745244799, 104.53364256446362, 106.5396967625304, 108.55069015569869, 110.56655494128275, 112.58722531026218, 114.61263735838203, 116.64272900252568, 118.67743990197246, 120.71671138418617, 122.76048637481053, 124.8087093315759, 126.86132618184544, 128.9182842635522, 130.9795322692983, 133.04502019340555, 135.11469928172465, 137.1885219840233, 139.2664419087892, 141.34841378029557, 143.43439339778797, 145.52433759666252, 147.61820421151427, 149.71595204094396, 151.8175408140185, 153.9229311582894, 156.03208456927794, 158.14496338134424, 160.26153073986163, 162.3817505746234, 164.5055875744146, 166.63300716268435, 168.76397547426026, 170.89845933304855, 173.03642623066844, 175.1778443059719, 177.32268232540275, 179.47090966415274, 181.6224962880735, 183.77741273630787, 185.93563010460323, 188.09712002927492, 190.26185467178746], [0.0, 0.9541395936111111, 2.1173683303242177, 3.375214366373753, 4.6987345209020335, 6.073337599470214, 7.490069645226263, 8.942823595263294, 10.427144763488457, 11.939628221338607, 13.477579987867918, 15.038811157520747, 16.621505244010194, 18.224128674243723, 19.84536811078432, 21.484085195530277, 23.139283020797766, 24.810080738387622, 26.495693964474047, 28.19541940611183, 29.90862262378152, 31.634728164295456, 33.373211513156626, 35.12359246289431, 36.88542959713861, 38.658315663789985, 40.44187366395417, 42.23575352250667, 44.03962923535001, 45.853196410449584, 47.676170136530274, 49.508283126261375, 51.34928409083006, 53.19893631071177, 55.05701637370673, 56.92331305630609, 58.79762632846532, 60.67976646510975, 62.56955325034196, 64.46681526248632, 66.37138922989134, 68.28311944888819, 70.2018572565342, 72.12746055180008, 74.05979335972346, 75.99872543378228, 77.94413189235956, 79.89589288569704, 81.85389329018552, 83.81802242722335, 85.78817380420712, 87.76424487550317, 89.74613682149624, 91.73375434402628, 93.7270054767107, 95.72580140881315, 97.7300563214619, 99.73968723514645, 101.75461386753152, 103.77475850072378, 105.80004585721332, 107.83040298378754, 109.8657591427825, 111.90604571009703, 113.95119607944821, 116.00114557239432, 118.05583135369474, 120.11519235161354, 122.17916918280898, 124.24770408148083, 126.32074083247645, 128.39822470808028, 130.48010240823538, 132.5663220039654, 134.65683288378392, 136.75158570289517, 138.8505323350057, 140.95362582657972, 143.06082035338449, 145.17207117918258, 147.28733461643998, 149.40656798892664, 151.52972959609693, 153.6567786791438, 155.78767538862976, 157.92238075360234, 160.06085665211026, 162.20306578304076, 164.3489716392041, 166.49853848159734, 168.65173131478184, 170.8085158633157, 172.96885854918375, 175.1327264701729, 177.30008737914395, 179.47090966415274, 181.64516232937777, 183.82281497681333, 186.00383778869002, 188.18820151058625, 190.37587743519725, 192.5668373867295], [0.0, 0.965578294127025, 2.1427523961093873, 3.4156781167227352, 4.755065289846406, 6.146147794537639, 7.579864329451473, 9.050034617170176, 10.552150566606022, 12.082766429216932, 13.639155927272158, 15.219103913526405, 16.820772124750725, 18.442608602614786, 20.08328426473847, 21.741647105816345, 23.416688266738912, 25.107516339260222, 26.813337535970625, 28.53344013249891, 30.26718208334878, 32.01398103651324, 33.77330618935433, 35.54467157743508, 37.32763049246637, 39.1217708000077, 40.926710981514375, 42.74209676498699, 44.567598238028644, 46.40290735940145, 48.24773580217207, 50.101813074636205, 51.9648848754056, 53.8367116470442, 55.717067298975515, 57.60573807543813, 59.50252154832772, 61.407225718050974, 63.31966820819256, 65.23967554198845, 67.16708249040529, 69.10173148312116, 71.043472074948, 72.99216046127863, 74.94765903701514, 76.90983599417532, 78.87856495399916, 80.85372462990985, 82.83519851813902, 84.82287461321485, 86.81664514584757, 88.81640634103542, 90.82205819446438, 92.8335042654926, 94.85065148519874, 96.87340997813908, 98.90169289660254, 100.93541626627893, 102.97449884236839, 105.01886197525675, 107.06842948496987, 109.12312754369567, 111.18288456573191, 113.24763110427752, 115.31729975454029, 117.39182506268112, 119.47114344015927, 121.55519308308041, 123.64391389618575, 125.73724742114987, 127.8351367688849, 129.93752655557216, 132.04436284216715, 134.155593077143, 136.27116604225765, 138.39103180114535, 140.51514165055067, 142.64344807403546, 144.77590469800325, 146.91246624989634, 149.0530885184328, 151.1977283157587, 153.34634344140144, 155.4988926479172, 157.6553356081335, 159.81563288389475, 161.97974589622473, 164.14763689682636, 166.3192689408435, 168.49460586081628, 170.67361224176332, 172.85625339733167, 175.04249534695614, 177.23230479397557, 179.425649104656, 181.6224962880735, 183.82281497681333, 186.02657440844325, 188.23374440772363, 190.4442953695163, 192.65819824235905, 194.8754245126729], [0.0, 0.9770346973292588, 2.1681757466151854, 3.456204489314407, 4.811483237044234, 6.219070671639391, 7.669797981134205, 9.157411560292342, 10.677349830380914, 12.226126159705357, 13.800981923767075, 15.399675693019116, 17.02034739358821, 18.66142665345298, 20.321568620923113, 21.99960762236887, 23.694522828758892, 25.40541225545757, 27.131472696918287, 28.87198398429526, 30.626296454344214, 32.39382084556213, 34.17402005743849, 35.966402359660506, 37.77051574382998, 39.585943185609516, 41.41229863980927, 43.24922363105982, 45.09638433261629, 46.95346904838995, 48.82018603050314, 50.69626157791881, 52.58143837201102, 54.47547401304018, 56.37813972790803, 58.28921922468161, 60.208507673485556, 62.13581079668783, 64.07094405401153, 66.01373191042376, 67.96400717648005, 69.9216104123165, 71.88638938774146, 73.85819859193337, 75.83689878713596, 77.8223566014903, 79.8144441567764, 81.81303872737523, 83.81802242722334, 85.8292819219252, 87.84670816352892, 89.870196145762, 91.89964467777823, 93.93495617468587, 95.97603646331844, 98.02279460187718, 100.07514271221939, 102.13299582369562, 104.1962717275519, 106.26489084101128, 108.3387760802387, 110.41785274146913, 112.50204838964952, 114.5912927540057, 116.6855176300004, 118.78465678719714, 120.8886458825892, 122.99742237899079, 125.11092546812426, 127.22909599806728, 129.3518764047537, 131.47921064724645, 133.61104414652434, 135.74732372754679, 137.88799756437686, 140.03301512816338, 142.18232713779605, 144.33588551306315, 146.4936433301543, 148.65555477936155, 150.82157512484443, 152.99166066633333, 155.16576870265513, 157.3438574969728, 159.5258862436397, 161.71181503657394, 163.90160483906715, 166.09521745494578, 168.2926155010101, 170.49376238068007, 172.69862225878234, 174.90716003741696, 177.11934133284578, 179.33513245334908, 181.55450037799983, 183.77741273630787, 186.00383778869002, 188.23374440772363, 190.46710206014558, 192.70388078955835, 194.94405119980968, 197.1875844390123], [0.0, 0.9885086495511719, 2.193638040833985, 3.496792940561795, 4.867987605752213, 6.292105252648794, 7.759869393979436, 9.264952984365003, 10.802740875494592, 12.369705489895988, 13.963055806753674, 15.580524073959586, 17.220228373586387, 18.880579891715403, 20.56021798319056, 22.257963285120557, 23.97278298021653, 25.703764491252212, 27.450095180117234, 29.211046420555906, 30.985960919907065, 32.77424249658763, 34.575347742567374, 36.38877915282548, 38.21407941073594, 40.05082659457404, 41.89863012557087, 43.75712731854819, 45.62598042641713, 47.50487409263962, 49.39351314315339, 51.29162066267261, 53.19893631071176, 55.1152148408739, 57.04022479342987, 58.97374733639025, 60.91557523442956, 62.86551192838753, 64.82337071081106, 66.78897398524552, 68.76215259883233, 70.74274523930184, 72.73059788872453, 74.72556332745087, 76.72750068256528, 78.73627501593661, 80.75175694758795, 82.77382231065373, 84.80235183465798, 86.83723085424587, 88.87834904084465, 90.92560015502507, 92.97888181759116, 95.03809529764848, 97.103145316094, 99.17393986314042, 101.25039002863498, 103.33240984406282, 105.41991613523919, 107.51282838479503, 109.61106860364976, 111.71456121074358, 113.82323292037165, 115.9370126365245, 118.05583135369473, 120.1796220636589, 122.30831966778862, 124.44186089448336, 126.58018422135441, 128.72322980182005, 130.87093939580203, 133.02325630423803, 135.1801253071502, 137.34149260502886, 139.50730576331154, 141.67751365975394, 143.8520664345057, 146.03091544271803, 148.2140132095238, 150.40131338724194, 152.59277071466997, 154.78834097833771, 156.98798097560442, 159.19164847949034, 161.39930220514165, 163.61090177783345, 165.82640770242398, 168.04578133417726, 170.26898485087835, 172.49598122616993, 174.72673420404288, 176.96120827441985, 179.1993686497722, 181.44118124271643, 183.68661264453937, 185.93563010460323, 188.18820151058625, 190.4442953695163, 192.70388078955835, 194.9669274625175, 197.23340564702332, 199.50328615236222], [0.0, 1.0, 2.2191389441356906, 3.5374429370441005, 4.924577653379666, 6.3652505777321196, 7.8500773842523, 9.372657476059228, 10.928322054035169, 12.513502532843189, 14.125375446227547, 15.76164667960554, 17.42041243787311, 19.100065437250397, 20.799229215167557, 22.516710698714363, 24.25146506416638, 26.002569125644875, 27.769200798172918, 29.550622985260734, 31.346170753261603, 33.155240990019294, 34.97728397041964, 36.81179640597748, 38.65831566378998, 40.51641491731908, 42.38569904734244, 44.265801152489594, 46.15637955938313, 48.057115245485214, 49.96770960535379, 51.887882504580354, 53.817370576237764, 55.75592572295521, 57.70331379429886, 59.65931341437126, 61.623714938749416, 63.596319523285246, 65.57693829006337, 67.56539157808156, 69.56150826809001, 71.56512517257414, 73.57608648315576, 75.59424326876623, 77.61945301885126, 79.65157922663244, 81.69049100809886, 83.73606275295298, 85.7881738042071, 87.84670816352892, 89.91155421978299, 91.98260449851344, 94.05975543037263, 96.14290713672574, 98.23196323085617, 100.32683063336869, 102.42741940053564, 104.5336425644636, 106.64541598407324, 108.76265820598613, 110.8852903345036, 113.0132359099408, 115.14642079465122, 117.28477306613878, 119.42822291671143, 121.57670255917938, 123.73014613814678, 125.88848964648479, 128.05167084661082, 130.2196291962304, 132.39230577822804, 134.56964323441852, 136.75158570289514, 138.93807875873236, 141.12906935781922, 143.32450578361858, 145.52433759666252, 147.72851558660892, 149.93699172669835, 152.14971913046085, 154.36665201053535, 156.58774563947284, 158.81295631240468, 161.04224131146512, 163.27555887186654, 165.5128681495304, 167.7541291901864, 169.999302899856, 172.24835101664337, 174.50123608376214, 176.75792142372939, 179.01837111366535, 181.28254996163858, 183.55042348400193, 185.82195788366798, 188.09712002927492, 190.37587743519725, 192.65819824235905, 194.94405119980968, 197.23340564702332, 199.52623149688807, 201.82249921935014], [0.0, 1.0115086006748837, 2.244678128085831, 3.578153955216728, 4.981252651084868, 6.43850570482681, 7.940420790134594, 9.480523648213655, 11.054091748601582, 12.657515436537825, 14.287938751620985, 15.943041177219724, 17.620897008212367, 19.319880463231858, 21.038599238550294, 22.77584653065774, 24.53056549137076, 26.301822310232975, 28.088785441219745, 29.890709304892134, 31.706921315147603, 33.536811418852956, 35.379823564327204, 37.235448670938986, 39.10321878152813, 40.9827021573804, 42.87349913200409, 44.775238581507395, 46.687574900330425, 48.61018539443236, 50.542768021840345, 52.485039424190845, 54.436733203571904, 56.39759840735917, 58.36739819037494, 60.34590862899498, 62.33291766608234, 64.32822416907104, 66.33163708632517, 68.34297468919584, 70.36206388909007, 72.38873962043336, 74.4228442817111, 76.46422722786646, 78.51274430824809, 80.5682574450756, 82.63063424804623, 84.6997476612637, 86.77547563914723, 88.857700848386, 90.94631039335661, 93.04119556272258, 95.142251595198, 97.24937746268472, 99.36247566918993, 101.4814520641048, 103.60621566857522, 105.73667851382902, 107.87275549044078, 110.01436420761766, 112.16142486168192, 114.31386011300472, 116.47159497071895, 118.6345566846013, 120.80267464357082, 122.97588028030206, 125.15410698149569, 127.33729000339038, 129.52536639213608, 131.71827490868122, 133.91595595785674, 136.11835152136499, 138.32540509440688, 140.5370616257021, 142.75326746067628, 144.97397028760727, 147.19911908653944, 149.4286640807885, 151.66255669087425, 153.900749490729, 156.1431961660433, 158.38985147461779, 160.64067120860187, 162.89561215850702, 165.15463207889127, 167.41768965561798, 169.68474447459909, 171.955756991939, 174.2306885054011, 176.5095011271237, 178.79215775751751, 181.07862206028062, 183.3688584384717, 185.66283201158504, 187.96050859357615, 190.26185467178746, 192.5668373867295, 194.8754245126729, 197.1875844390123, 199.50328615236222, 201.82249921935014, 204.1451937700726]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 2.4000000000000004\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.00398107170553497, 0.009146101038546522, 0.014878032589238489, 0.02101222243523013, 0.027464013582652932, 0.034180743121701065, 0.04112611144188372, 0.04827341069236129, 0.05560207655106705, 0.0630957344480193, 0.07074100447107011, 0.07852672679294848, 0.08644343632726739, 0.09448299312143316, 0.10263831433779472, 0.1109031749048234, 0.11927205600272427, 0.1277400277372599, 0.13630265679826026, 0.14495593273553906, 0.15369620834769088, 0.16252015093351227, 0.1714247020192063, 0.180407043780723, 0.18946457081379975, 0.198594866218846, 0.2077956811996041, 0.2170649175475729, 0.2264006125149731, 0.2358009256789868, 0.24526412747718696, 0.25478858915423824, 0.2643727739072751, 0.2740152290548873, 0.28371457908463216, 0.29346951945813216, 0.30327881107237303, 0.31314127529177405, 0.3230557894786829, 0.33302128296074923, 0.3430367333825799, 0.3531011633965482, 0.3632136376538791, 0.37337326006239085, 0.3835791712817216, 0.39383054643063836, 0.4041265929842368, 0.41446654884158923, 0.4248496805467505, 0.43527528164806206, 0.445742671182445, 0.4562511922728893, 0.4668002108286678, 0.47738911433894715, 0.4880173107514793, 0.4986842274289281, 0.5093893101761645, 0.5201320223325415, 0.5309118439237587, 0.5417282708684605, 0.5525808142351797, 0.5634689995456557, 0.574392366120934, 0.5853504664669777, 0.5963428656968237, 0.60736914098658, 0.6184288810627978, 0.6295216857189695, 0.6406471653590878, 0.6518049405663864, 0.6629946416955279, 0.6742159084866536, 0.6854683896998351, 0.6967517427685831, 0.7080656334711766, 0.7194097356186692, 0.7307837307585184, 0.7421873078928632, 0.753620163210543, 0.7650819998320296, 0.776572527566488, 0.7880914626802521, 0.7996385276760425, 0.8112134510823085, 0.8228159672521091, 0.8344458161710001, 0.8461027432734183, 0.857786499267097, 0.869496839965074, 0.8812335261248792, 0.8929963232945216, 0.9047850016649155, 0.9165993359284086, 0.9284391051430984, 0.9403040926026391, 0.9521940857112638, 0.9641088758637568, 0.9760482583301363, 0.9880120321448116, 1.0, 1.0120119681431987], [0.0, 0.009146101038546522, 0.02101222243523013, 0.034180743121701065, 0.048273410692361296, 0.0630957344480193, 0.07852672679294848, 0.09448299312143316, 0.1109031749048234, 0.1277400277372599, 0.14495593273553908, 0.1625201509335123, 0.18040704378072303, 0.198594866218846, 0.2170649175475729, 0.2358009256789868, 0.25478858915423824, 0.27401522905488723, 0.29346951945813216, 0.31314127529177405, 0.33302128296074923, 0.3531011633965482, 0.37337326006239085, 0.3938305464306384, 0.4144665488415893, 0.4352752816480621, 0.45625119227288935, 0.47738911433894715, 0.49868422742892815, 0.5201320223325415, 0.5417282708684605, 0.5634689995456555, 0.5853504664669779, 0.60736914098658, 0.6295216857189696, 0.6518049405663864, 0.6742159084866537, 0.6967517427685831, 0.7194097356186692, 0.7421873078928632, 0.7650819998320297, 0.7880914626802521, 0.8112134510823085, 0.8344458161710002, 0.8577864992670972, 0.8812335261248793, 0.9047850016649156, 0.9284391051430984, 0.9521940857112638, 0.9760482583301364, 1.0000000000000002, 1.0240477462785178, 1.048189988058608, 1.07242526858232, 1.0967521806692804, 1.1211693641406024, 1.1456755034211543, 1.1702693253048695, 1.1949495968693433, 1.2197151235273287, 1.244564747203978, 1.2694973446297464, 1.2945118257398396, 1.3196071321719434, 1.3447822358547292, 1.3700361376803187, 1.3953678662544935, 1.420776476718986, 1.4462610496406818, 1.4718206899629955, 1.4974545260150967, 1.5231617085750033, 1.5489414099829013, 1.5747928233013346, 1.6007151615191777, 1.6267076567965484, 1.6527695597480345, 1.678900138761813, 1.70509867935242, 1.7313644835450959, 1.7576968692897887, 1.7840951699030292, 1.8105587335360258, 1.8370869226674424, 1.8636791136194313, 1.8903346960955842, 1.9170530727395727, 1.943833658713309, 1.9706758812935599, 1.9975791794860018, 2.0245430036557712, 2.051566815173635, 2.0786500860769563, 2.1057922987446758, 2.132992945585593, 2.1602515287392627, 2.1875675597888695, 2.2149405594854765, 2.2423700574830976, 2.269855592084046, 2.2973967099940706, 2.324992966086809], [0.0, 0.014878032589238489, 0.034180743121701065, 0.055602076551067074, 0.07852672679294848, 0.10263831433779473, 0.12774002773725993, 0.1536962083476909, 0.18040704378072303, 0.20779568119960412, 0.23580092567898683, 0.2643727739072751, 0.29346951945813227, 0.32305578947868296, 0.35310116339654823, 0.38357917128172164, 0.4144665488415893, 0.4457426711824451, 0.47738911433894715, 0.5093893101761646, 0.5417282708684606, 0.574392366120934, 0.60736914098658, 0.6406471653590879, 0.6742159084866538, 0.7080656334711767, 0.7421873078928632, 0.7765725275664882, 0.8112134510823087, 0.8461027432734185, 0.8812335261248793, 0.9165993359284087, 0.952194085711264, 0.9880120321448119, 1.024047746278518, 1.0602960875571599, 1.0967521806692804, 1.1334113948479931, 1.1702693253048695, 1.2073217765265378, 1.244564747203978, 1.2819944165979573, 1.3196071321719434, 1.357399398347211, 1.3953678662544937, 1.433509324373162, 1.4718206899629958, 1.5102990012056137, 1.5489414099829015, 1.587745175228568, 1.6267076567965484, 1.6658263097965138, 1.70509867935242, 1.7445223957449545, 1.7840951699030294, 1.8238147892132353, 1.8636791136194315, 1.9036860719875615, 1.9438336587133092, 1.984119930552453, 2.0245430036557712, 2.0651010507920944, 2.1057922987446758, 2.146615025867435, 2.1875675597888695, 2.2286482752525445, 2.2698555920840464, 2.311187973275197, 2.35264392317711, 2.3942219857943834, 2.4359207431734036, 2.4777388138782706, 2.519674851548427, 2.561727543532535, 2.6038956095935695, 2.646177800680517, 2.6885728977623877, 2.7310797107206284, 2.7736970772962644, 2.8164238620884086, 2.859258955601021, 2.902201273334996, 2.9452497549229144, 2.988403363303937, 3.031661083936533, 3.075021924046863, 3.1184849119108127, 3.162049096167788, 3.2057135451645196, 3.2494773463272453, 3.2933396055607247, 3.337299446672661, 3.381356010822189, 3.425508455991168, 3.469755956477107, 3.514097702406607, 3.5585328992682945, 3.603060767464255, 3.6476805418790708, 3.69239147146558, 3.7371928188465535, 3.782083859931529], [0.0, 0.02101222243523013, 0.048273410692361296, 0.07852672679294848, 0.1109031749048234, 0.14495593273553908, 0.18040704378072303, 0.2170649175475729, 0.25478858915423824, 0.29346951945813216, 0.33302128296074923, 0.37337326006239085, 0.4144665488415893, 0.45625119227288935, 0.49868422742892815, 0.5417282708684605, 0.5853504664669777, 0.6295216857189695, 0.6742159084866536, 0.7194097356186692, 0.7650819998320296, 0.8112134510823085, 0.8577864992670972, 0.9047850016649156, 0.9521940857112638, 1.0000000000000002, 1.0481899880586079, 1.0967521806692802, 1.1456755034211543, 1.194949596869343, 1.2445647472039778, 1.2945118257398394, 1.3447822358547292, 1.3953678662544935, 1.4462610496406818, 1.4974545260150967, 1.5489414099829013, 1.6007151615191775, 1.6527695597480343, 1.7050986793524199, 1.7576968692897887, 1.8105587335360258, 1.863679113619431, 1.9170530727395727, 1.97067588129356, 2.0245430036557712, 2.0786500860769563, 2.1329929455855927, 2.187567559788869, 2.2423700574830976, 2.2973967099940706, 2.3526439231771095, 2.4081082300145695, 2.4637862837555287, 2.5196748515484266, 2.5757708085227637, 2.6320711322805597, 2.6885728977623873, 2.7452732724563695, 2.802169511921696, 2.8592589556010206, 2.9165390228985877, 2.9740072095031245, 3.031661083936533, 3.0894982843111247, 3.1475165152797473, 3.2057135451645196, 3.264087203251165, 3.322635377237073, 3.3813560108221883, 3.440247101432813, 3.4993066980691596, 3.5585328992682936, 3.6179238511747593, 3.6774777457117853, 3.737192818846553, 3.7970673489434823, 3.857099655199977, 3.917288096159484, 3.977631068297086, 4.038127004673238, 4.098774373651531, 4.159571677676697, 4.220517452109314, 4.281610264113946, 4.342848711597636, 4.404231422195918, 4.465757052303692, 4.52742428614849, 4.589231834903795, 4.651178435840281, 4.713262851512922, 4.77548386898209, 4.837840299066868, 4.900330975628902, 4.962954754885243, 5.025710514748705, 5.088597154194359, 5.151613592650883, 5.214758769415529, 5.278031643091579, 5.34143119104719], [0.0, 0.027464013582652932, 0.0630957344480193, 0.10263831433779473, 0.14495593273553908, 0.1894645708137997, 0.23580092567898683, 0.28371457908463216, 0.33302128296074923, 0.3835791712817216, 0.435275281648062, 0.4880173107514793, 0.5417282708684606, 0.5963428656968237, 0.6518049405663864, 0.7080656334711763, 0.7650819998320296, 0.8228159672521093, 0.881233526124879, 0.9403040926026391, 0.9999999999999999, 1.0602960875571596, 1.1211693641406024, 1.1825987304152459, 1.2445647472039778, 1.3070494407390916, 1.3700361376803185, 1.4335093243731616, 1.4974545260150967, 1.5618582022994778, 1.626707656796548, 1.6919909578633974, 1.7576968692897887, 1.823814789213235, 1.8903346960955847, 1.9572471007602532, 2.024543003655771, 2.0922138566462256, 2.1602515287392627, 2.228648275252544, 2.29739670999407, 2.3664897800935405, 2.435920743173403, 2.5056831465914153, 2.5757708085227637, 2.646177800680516, 2.71689843249915, 2.7879272366280765, 2.8592589556010206, 2.9308885295633673, 3.0028110849535787, 3.0750219240468626, 3.147516515279747, 3.2202904842833084, 3.2933396055607242, 3.366659794751756, 3.440247101432813, 3.5140977024066067, 3.5882078954400733, 3.6625740934133852, 3.7371928188465526, 3.812060698773335, 3.887174459935085, 3.9625309242697133, 4.038127004673238, 4.113959701013448, 4.190026096377015, 4.2663233535330605, 4.342848711597637, 4.419599482884906, 4.496573049932039, 4.573766862685852, 4.651178435840281, 4.728805346314589, 4.806645230863044, 4.884695783807536, 4.962954754885243, 5.041419947204073, 5.120089215299154, 5.19896046328414, 5.278031643091579, 5.357300752796953, 5.4367658350214905, 5.516424975409053, 5.596276301172887, 5.676317979708174, 5.756548217266707, 5.836965257690195, 5.917567381198963, 5.99835290323304, 6.0793201733427615, 6.1604675741263, 6.241793520211594, 6.323296457280389, 6.404974861132203, 6.486827236786172, 6.568852117618866, 6.651048064536269, 6.733413665178238, 6.815947533153841, 6.898648307306076, 6.981514651004568], [0.0, 0.034180743121701065, 0.07852672679294848, 0.12774002773725993, 0.18040704378072303, 0.23580092567898683, 0.29346951945813227, 0.35310116339654823, 0.4144665488415893, 0.4773891143389472, 0.5417282708684606, 0.60736914098658, 0.6742159084866539, 0.7421873078928632, 0.8112134510823086, 0.8812335261248793, 0.952194085711264, 1.024047746278518, 1.0967521806692804, 1.1702693253048695, 1.244564747203978, 1.3196071321719434, 1.3953678662544937, 1.4718206899629958, 1.5489414099829015, 1.6267076567965486, 1.70509867935242, 1.7840951699030294, 1.8636791136194315, 1.9438336587133092, 2.0245430036557712, 2.1057922987446758, 2.1875675597888695, 2.2698555920840464, 2.35264392317711, 2.4359207431734036, 2.519674851548427, 2.6038956095935695, 2.6885728977623877, 2.773697077296264, 2.859258955601021, 2.9452497549229144, 3.031661083936533, 3.118484911910813, 3.2057135451645196, 3.293339605560725, 3.381356010822189, 3.4697559564771074, 3.5585328992682945, 3.647680541879071, 3.7371928188465535, 3.827063883548074, 3.917288096159484, 4.007860012495431, 4.098774373651532, 4.190026096377015, 4.281610264113947, 4.3735221186457585, 4.465757052303693, 4.558310600684869, 4.651178435840282, 4.744356359895056, 4.837840299066869, 4.931626298051682, 5.025710514748705, 5.120089215299155, 5.214758769415531, 5.309715645980302, 5.404956408894634, 5.500477713159486, 5.596276301172888, 5.692348999228549, 5.788692714202154, 5.885304430412837, 5.982181206648271, 6.079320173342763, 6.176718529898534, 6.274373542141129, 6.372282539900606, 6.470442914710704, 6.568852117618867, 6.667507657100422, 6.766407097070745, 6.865548054989679, 6.9649282000528485, 7.064545251464899, 7.16439697679005, 7.2644811903756, 7.364795751844395, 7.465338564652476, 7.566107574708378, 7.667100769050803, 7.768316174581571, 7.869751856850978, 7.971405918892835, 8.073276500106662, 8.17536177518464, 8.27765995308109, 8.380169276022364, 8.482888018555188, 8.585814486631538, 8.68894701672837], [0.0, 0.04112611144188372, 0.09448299312143316, 0.1536962083476909, 0.2170649175475729, 0.28371457908463216, 0.35310116339654823, 0.4248496805467505, 0.4986842274289281, 0.5743923661209339, 0.6518049405663864, 0.7307837307585185, 0.8112134510823086, 0.8929963232945216, 0.9760482583301363, 1.0602960875571596, 1.145675503421154, 1.2321294942391605, 1.3196071321719431, 1.4080626192983405, 1.4974545260150964, 1.5877451752285678, 1.678900138761813, 1.770887821320017, 1.8636791136194313, 1.9572471007602537, 2.051566815173635, 2.146615025867434, 2.2423700574830976, 2.3388116340271554, 2.435920743173403, 2.533679517829163, 2.6320711322805597, 2.7310797107206284, 2.8306902463517054, 2.9308885295633673, 3.0316610839365326, 3.132995109026391, 3.2348784290416406, 3.337299446672661, 3.440247101432813, 3.5437108319695425, 3.6476805418790703, 3.7521465686230635, 3.857099655199977, 3.962530924269713, 4.068431854469174, 4.174794258689475, 4.281610264113946, 4.388872293840396, 4.496573049932039, 4.604705497759626, 4.713262851512922, 4.822238560773387, 4.93162629805168, 5.041419947204073, 5.151613592650883, 5.262201509328025, 5.373178153309842, 5.484538153047513, 5.596276301172887, 5.708387546822403, 5.820866988440081, 5.933709867022467, 6.046911559771726, 6.160467574126301, 6.274373542141129, 6.388625215191987, 6.503218458980712, 6.618149248819984, 6.733413665178238, 6.849007889466797, 6.964928200052847, 7.0811709684831685, 7.197732655904744, 7.314609809669455, 7.431799060111052, 7.549297117483528, 7.667100769050803, 7.78520687631838, 7.903612372398381, 8.022314259499883, 8.141309606537178, 8.260595546849006, 8.380169276022364, 8.500028049814874, 8.620169182170166, 8.740590043321056, 8.86128805797569, 8.98226070358211, 9.103505508667, 9.225020051244671, 9.346801957292554, 9.468848899289744, 9.591158594815331, 9.713728805203456, 9.836557334252223, 9.959642026983785, 10.082980768453053, 10.206571482602651, 10.33041213116187, 10.4545007125875], [0.0, 0.04827341069236129, 0.1109031749048234, 0.18040704378072303, 0.25478858915423824, 0.33302128296074923, 0.4144665488415893, 0.4986842274289281, 0.5853504664669777, 0.6742159084866537, 0.7650819998320296, 0.8577864992670972, 0.952194085711264, 1.0481899880586079, 1.145675503421154, 1.2445647472039778, 1.3447822358547292, 1.4462610496406818, 1.548941409982901, 1.6527695597480343, 1.7576968692897885, 1.863679113619431, 1.9706758812935599, 2.0786500860769563, 2.187567559788869, 2.2973967099940706, 2.4081082300145695, 2.5196748515484266, 2.63207113228056, 2.7452732724563695, 2.8592589556010206, 2.974007209503124, 3.0894982843111247, 3.2057135451645196, 3.322635377237073, 3.440247101432813, 3.5585328992682936, 3.6774777457117853, 3.7970673489434823, 3.917288096159484, 4.038127004673238, 4.159571677676697, 4.281610264113946, 4.404231422195918, 4.52742428614849, 4.651178435840282, 4.77548386898209, 4.900330975628902, 5.025710514748705, 5.151613592650883, 5.278031643091579, 5.404956408894633, 5.532379924945117, 5.660294502428469, 5.788692714202153, 5.917567381198964, 6.046911559771726, 6.176718529898532, 6.306981784175918, 6.437695017534593, 6.568852117618866, 6.700447155776535, 6.832474378611124, 6.964928200052848, 7.097803193908702, 7.231094086855692, 7.364795751844394, 7.498903201882973, 7.633411584174358, 7.768316174581569, 7.903612372398381, 8.0392956954043, 8.175361775184639, 8.31180635269797, 8.448625274074667, 8.585814486631538, 8.723370035088664, 8.86128805797569, 8.999564784215734, 9.138196529875923, 9.277179695074507, 9.416510761035033, 9.556186287278958, 9.696202908948493, 9.836557334252223, 9.977246342026396, 10.118266779405404, 10.25961555959532, 10.401289659744792, 10.543286118908028, 10.685602036094828, 10.828234568403058, 10.97118092922921, 11.114438386552951, 11.258004261291873, 11.401875925722784, 11.546050801966281, 11.69052636053131, 11.835300118916871, 11.980369640267964, 12.125732532083191, 12.271386444971522], [0.0, 0.05560207655106705, 0.1277400277372599, 0.20779568119960412, 0.29346951945813216, 0.3835791712817216, 0.4773891143389472, 0.5743923661209339, 0.6742159084866537, 0.7765725275664881, 0.8812335261248792, 0.9880120321448117, 1.0967521806692804, 1.2073217765265374, 1.3196071321719431, 1.4335093243731616, 1.5489414099829013, 1.6658263097965138, 1.784095169903029, 1.9036860719875612, 2.024543003655771, 2.146615025867434, 2.269855592084046, 2.3942219857943834, 2.5196748515484266, 2.6461778006805163, 2.7736970772962635, 2.902201273334996, 3.0316610839365326, 3.1620490961677876, 3.2933396055607242, 3.4255084559911673, 3.558532899268294, 3.69239147146558, 3.8270638835480737, 3.962530924269713, 4.098774373651531, 4.235776925624774, 4.3735221186457585, 4.511994273272038, 4.651178435840281, 4.791060327511261, 4.93162629805168, 5.072863283809827, 5.21475876941553, 5.357300752796954, 5.500477713159485, 5.64427858161674, 5.788692714202153, 5.933709867022466, 6.079320173342762, 6.2255141224171835, 6.372282539900604, 6.519616569695026, 6.667507657100421, 6.815947533153841, 6.964928200052847, 7.114441917570115, 7.264481190375599, 7.415038756190947, 7.5661075747083775, 7.717680817212685, 7.869751856850977, 8.022314259499884, 8.175361775184639, 8.328888330008562, 8.482888018555187, 8.637355096728584, 8.792283975000474, 8.9476692120353, 9.103505508667, 9.259787702203246, 9.416510761035033, 9.573669779531206, 9.731259973199153, 9.88927667409439, 10.047715326463061, 10.206571482602651, 10.36584079892727, 10.525519032224873, 10.685602036094828, 10.846085757554867, 11.006966233807484, 11.168239589156357, 11.329902032064165, 11.491949852343645, 11.654379418474413, 11.817187175038487, 11.980369640267964, 12.143923403698732, 12.307845123924476, 12.47213152644564, 12.63677940160831, 12.801785602628334, 12.967147043696295, 13.13286069815914, 13.298923596774673, 13.46533282603516, 13.632085526556764, 13.799178891531419, 13.966610165238244, 14.134376641611562], [0.0, 0.0630957344480193, 0.14495593273553908, 0.23580092567898683, 0.33302128296074923, 0.435275281648062, 0.5417282708684606, 0.6518049405663864, 0.7650819998320296, 0.8812335261248792, 1.0, 1.1211693641406024, 1.244564747203978, 1.3700361376803185, 1.4974545260150967, 1.626707656796548, 1.7576968692897887, 1.8903346960955845, 2.024543003655771, 2.1602515287392627, 2.29739670999407, 2.435920743173403, 2.5757708085227637, 2.7168984324991503, 2.8592589556010206, 3.0028110849535787, 3.147516515279747, 3.2933396055607242, 3.440247101432813, 3.5882078954400733, 3.7371928188465526, 3.8871744599350846, 4.038127004673238, 4.190026096377015, 4.342848711597637, 4.496573049932039, 4.651178435840281, 4.806645230863044, 4.962954754885243, 5.120089215299154, 5.278031643091579, 5.4367658350214905, 5.596276301172887, 5.756548217266707, 5.917567381198964, 6.079320173342762, 6.241793520211594, 6.404974861132203, 6.568852117618866, 6.733413665178238, 6.898648307306076, 7.0645452514648985, 7.231094086855691, 7.398284763817684, 7.5661075747083775, 7.7345531361319955, 7.903612372398381, 8.07327650010666, 8.243537013758772, 8.414385672317426, 8.585814486631536, 8.757815707659557, 8.930381815427841, 9.103505508667002, 9.277179695074507, 9.451397482156484, 9.626152168605852, 9.801437236177723, 9.977246342026397, 10.153573311471279, 10.330412131161868, 10.507756942614376, 10.685602036094828, 10.863941844825508, 11.042770939493446, 11.22208402304134, 11.401875925722786, 11.582141600405116, 11.762876118104398, 11.944074663738233, 12.12573253208319, 12.307845123924476, 12.490407942386536, 12.673416589433879, 12.856866762532377, 13.040754251461747, 13.225074935270763, 13.409824779367144, 13.594999832734725, 13.780596225270966, 13.966610165238242, 14.153037936822914, 14.339875897796423, 14.527120477273126, 14.71476817355985, 14.902815552092477, 15.091259243455166, 15.280095941478054, 15.469322401409599, 15.658935438159833, 15.848931924611142, 16.039308789993296], [0.0, 0.07074100447107011, 0.1625201509335123, 0.2643727739072751, 0.37337326006239085, 0.4880173107514793, 0.60736914098658, 0.7307837307585185, 0.8577864992670972, 0.9880120321448117, 1.1211693641406024, 1.2570207430874427, 1.3953678662544937, 1.5360425453326896, 1.6789001387618132, 1.823814789213235, 1.97067588129356, 2.1193853492344052, 2.269855592084046, 2.4220078328603636, 2.5757708085227637, 2.731079710720628, 2.8878753195633924, 3.0461032879996717, 3.205713545164519, 3.3666597947517563, 3.5288990900582387, 3.6923914714655797, 3.8570996551999777, 4.022988764534836, 4.190026096377015, 4.358180917549008, 4.52742428614849, 4.697728894207549, 4.869068928540757, 5.041419947204073, 5.214758769415529, 5.389063377136178, 5.564312826793267, 5.740487169860108, 5.917567381198964, 6.095535294232396, 6.274373542141128, 6.454065504397633, 6.634595258038012, 6.8159475331538415, 6.998107672152566, 7.181061592392135, 7.364795751844394, 7.549297117483529, 7.734553136131996, 7.920551707527412, 8.107281159400866, 8.29473022438058, 8.482888018555187, 8.671744021548811, 8.861288057975692, 9.051510280155853, 9.242401151985442, 9.433951433865923, 9.626152168605852, 9.818994668217245, 10.012470501536031, 10.206571482602653, 10.401289659744792, 10.596617305309476, 10.792546905996504, 10.989071153749402, 11.186182937163888, 11.383875333377244, 11.582141600405118, 11.780975169894962, 11.980369640267964, 12.180318770223497, 12.38081647258219, 12.581856808445673, 12.783433981652658, 12.985542333512623, 13.188176337799785, 13.391330595991274, 13.594999832734727, 13.799178891531419, 14.003862730622243, 14.209046419064544, 14.41472513298887, 14.620894152025224, 14.82754885588934, 15.034684721119955, 15.242297317958789, 15.450382307365434, 15.658935438159833, 15.86795254428557, 16.077429542187566, 16.287362428298234, 16.49774727662647, 16.708580236444202, 16.919857530065617, 17.13157545071435, 17.343730360474378, 17.556318688320406, 17.769336928223968, 17.98278163733156], [0.0, 0.07852672679294848, 0.18040704378072303, 0.29346951945813227, 0.4144665488415893, 0.5417282708684606, 0.6742159084866539, 0.8112134510823086, 0.952194085711264, 1.0967521806692804, 1.244564747203978, 1.3953678662544937, 1.5489414099829018, 1.70509867935242, 1.8636791136194315, 2.0245430036557712, 2.1875675597888695, 2.35264392317711, 2.5196748515484266, 2.6885728977623877, 2.8592589556010206, 3.0316610839365326, 3.2057135451645196, 3.381356010822189, 3.5585328992682945, 3.7371928188465535, 3.917288096159484, 4.098774373651532, 4.281610264113947, 4.465757052303693, 4.651178435840282, 4.837840299066868, 5.025710514748705, 5.214758769415531, 5.404956408894635, 5.596276301172888, 5.788692714202154, 5.982181206648271, 6.176718529898533, 6.372282539900605, 6.568852117618867, 6.766407097070746, 6.964928200052848, 7.16439697679005, 7.364795751844395, 7.566107574708379, 7.768316174581571, 7.971405918892835, 8.17536177518464, 8.380169276022364, 8.585814486631538, 8.792283975000474, 8.999564784215734, 9.207644406823798, 9.416510761035035, 9.626152168605852, 9.836557334252225, 10.047715326463061, 10.259615559595321, 10.472247777144512, 10.68560203609483, 10.899668692262344, 11.114438386552953, 11.329902032064169, 11.546050801966281, 11.762876118104398, 11.980369640267968, 12.198523256079184, 12.417329071455898, 12.63677940160831, 12.856866762532379, 13.077583862965707, 13.298923596774673, 13.520879035743977, 13.743443422742095, 13.966610165238246, 14.190372829148302, 14.41472513298887, 14.63966094232031, 14.865174264460812, 15.091259243455166, 15.31791015528278, 15.545121403290858, 15.772887513839477, 16.001203132146337, 16.23006301831969, 16.459462043568923, 16.68939518658271, 16.919857530065617, 17.150844257424453, 17.382350649596244, 17.61437208201032, 17.84690402167742, 18.07994202439916, 18.313481732091656, 18.547518870217488, 18.782049245320476, 19.017068742658164, 19.252573323927173, 19.488559025076807, 19.725021954206724, 19.961958289544548], [0.0, 0.08644343632726739, 0.198594866218846, 0.32305578947868296, 0.45625119227288935, 0.5963428656968237, 0.7421873078928632, 0.8929963232945216, 1.0481899880586079, 1.2073217765265374, 1.3700361376803185, 1.5360425453326896, 1.70509867935242, 1.8769990185500047, 2.051566815173635, 2.2286482752525436, 2.40810823001457, 2.5898268459618934, 2.773697077296263, 2.959622660851943, 3.147516515279747, 3.3372994466726604, 3.5288990900582387, 3.7222490349308472, 3.9172880961594836, 4.113959701013448, 4.31221136987888, 4.511994273272038, 4.713262851512922, 4.915974486262742, 5.120089215299153, 5.3255694835790415, 5.532379924945117, 5.740487169860108, 5.949859675367174, 6.1604675741263, 6.372282539900604, 6.585277667291128, 6.79942736386515, 7.0147072531071055, 7.231094086855692, 7.4485656660851545, 7.667100769050801, 7.8866790859546025, 8.107281159400866, 8.328888330008562, 8.55148268662873, 8.775047020685097, 8.999564784215734, 9.225020051244671, 9.451397482156484, 9.678682290784804, 9.90686021395876, 10.135917483279927, 10.365840798927268, 10.596617305309474, 10.828234568403058, 11.060680554631407, 11.293943611154814, 11.528012447454376, 11.762876118104396, 11.998524006637924, 12.23494581041931, 12.472131526445644, 12.710071438006151, 12.948756102135157, 13.188176337799783, 13.428323214768984, 13.669188043114932, 13.910762363302073, 14.153037936822914, 14.396006737342953, 14.639660942320305, 14.883992925068332, 15.128995247232062, 15.374660651651569, 15.620982055587453, 15.867952544285568, 16.11556536485981, 16.363813920473277, 16.61269176479984, 16.86219259674903, 17.112310255438825, 17.363038715401668, 17.61437208201032, 17.866304587110847, 18.118830584851146, 18.371944547693992, 18.62564106260446, 18.87991482740221, 19.134760647269676, 19.390173431407888, 19.6461481898321, 19.90268003029994, 20.159764155365213, 20.41739585955096, 20.67557052663572, 20.934283627047304, 21.193530715358836, 21.453307427881963, 21.713609480352545, 21.9744326657044], [0.0, 0.09448299312143316, 0.2170649175475729, 0.35310116339654823, 0.49868422742892815, 0.6518049405663864, 0.8112134510823086, 0.9760482583301363, 1.145675503421154, 1.3196071321719431, 1.4974545260150967, 1.6789001387618132, 1.8636791136194315, 2.051566815173635, 2.2423700574830976, 2.435920743173403, 2.63207113228056, 2.8306902463517054, 3.031661083936532, 3.2348784290416406, 3.4402471014328126, 3.6476805418790703, 3.8570996551999777, 4.068431854469174, 4.281610264113946, 4.4965730499320395, 4.713262851512922, 4.93162629805168, 5.151613592650883, 5.373178153309842, 5.596276301172887, 5.820866988440081, 6.046911559771726, 6.274373542141129, 6.5032184589807125, 6.733413665178238, 6.964928200052847, 7.197732655904744, 7.431799060111052, 7.667100769050802, 7.903612372398381, 8.141309606537178, 8.380169276022364, 8.620169182170168, 8.861288057975692, 9.103505508667002, 9.346801957292554, 9.591158594815333, 9.836557334252223, 10.082980768453053, 10.33041213116187, 10.57883526104457, 10.828234568403058, 11.07859500432732, 11.329902032064165, 11.582141600405116, 11.835300118916871, 12.089364434856037, 12.344321811626047, 12.600159908648312, 12.856866762532377, 13.11443076944091, 13.372840668555337, 13.632085526556766, 13.892154723044674, 14.153037936822916, 14.41472513298887, 14.677206550767231, 14.940472692034996, 15.20451431048876, 15.469322401409599, 15.734888191984453, 16.001203132146333, 16.268258885898756, 16.53604732309244, 16.80456051162496, 17.073790710036157, 17.343730360474375, 17.61437208201032, 17.88570866427706, 18.15773306141647, 18.430438386313547, 18.70381790510163, 18.977865031922573, 19.25257332392717, 19.527936476502006, 19.803948318710017, 20.080602808932724, 20.357894030703097, 20.635816188718564, 20.914363605024462, 21.193530715358836, 21.473312065650052, 21.753702308659232, 22.034696200760095, 22.316288598849052, 22.5984744573791, 22.88124882551122, 23.164606844377527, 23.44854374445063, 23.73305484301411, 24.018135541729183], [0.0, 0.10263831433779472, 0.2358009256789868, 0.38357917128172164, 0.5417282708684605, 0.7080656334711763, 0.8812335261248793, 1.0602960875571596, 1.2445647472039778, 1.4335093243731616, 1.626707656796548, 1.823814789213235, 2.0245430036557712, 2.2286482752525436, 2.435920743173403, 2.6461778006805154, 2.8592589556010206, 3.0750219240468626, 3.293339605560724, 3.5140977024066067, 3.737192818846552, 3.9625309242697124, 4.190026096377014, 4.419599482884907, 4.651178435840281, 4.884695783807536, 5.120089215299153, 5.357300752796953, 5.596276301172887, 5.836965257690195, 6.0793201733427615, 6.323296457280388, 6.5688521176188654, 6.8159475331538415, 7.064545251464899, 7.314609809669453, 7.566107574708377, 7.819006600549525, 8.07327650010666, 8.328888330008562, 8.585814486631536, 8.844028612039336, 9.103505508667, 9.364221061746271, 9.62615216860585, 9.889276674094388, 10.153573311471279, 10.41902164819316, 10.685602036094828, 10.953295565523948, 11.222084023041338, 11.491949852343645, 11.762876118104394, 12.034846472463467, 12.307845123924476, 12.58185680844567, 12.856866762532377, 13.13286069815914, 13.409824779367144, 13.687745600397925, 13.966610165238242, 14.246405868462878, 14.527120477273126, 14.808742114638164, 15.091259243455164, 15.374660651651567, 15.658935438159835, 15.944072999701095, 16.23006301831969, 16.516895449615408, 16.804560511624956, 17.09304867430789, 17.38235064959624, 17.67245738197007, 17.963360039524396, 18.255050005495555, 18.547518870217484, 18.840758423480825, 19.13476064726968, 19.429517708852636, 19.725021954206717, 20.021265901754003, 20.318242236392592, 20.615943803804484, 20.914363605024462, 21.21349479125496, 21.513330658913063, 21.81386464489661, 22.115090322057366, 22.417001394869885, 22.719591695285548, 23.02285517876185, 23.326785920457713, 23.631378111586116, 23.936626055915962, 24.242524166415507, 24.5490669620302, 24.85624906458821, 25.164065195827355, 25.47251017453741, 25.781578913812194, 26.09126641840627], [0.0, 0.1109031749048234, 0.25478858915423824, 0.4144665488415893, 0.5853504664669777, 0.7650819998320296, 0.952194085711264, 1.145675503421154, 1.3447822358547292, 1.5489414099829013, 1.7576968692897887, 1.97067588129356, 2.1875675597888695, 2.40810823001457, 2.63207113228056, 2.8592589556010206, 3.0894982843111247, 3.322635377237073, 3.5585328992682936, 3.7970673489434823, 4.038127004673238, 4.281610264113946, 4.52742428614849, 4.775483868982091, 5.025710514748705, 5.2780316430915795, 5.532379924945117, 5.788692714202153, 6.046911559771726, 6.306981784175918, 6.568852117618866, 6.832474378611123, 7.097803193908702, 7.364795751844395, 7.633411584174359, 7.903612372398381, 8.175361775184639, 8.448625274074667, 8.723370035088662, 8.999564784215734, 9.277179695074507, 9.556186287278958, 9.836557334252223, 10.118266779405406, 10.401289659744792, 10.68560203609483, 10.97118092922921, 11.258004261291873, 11.546050801966281, 11.835300118916871, 12.125732532083191, 12.417329071455896, 12.710071438006151, 13.003941967476688, 13.29892359677467, 13.594999832734725, 13.892154723044674, 14.190372829148298, 14.489639200958287, 14.789939353229194, 15.091259243455166, 15.393585251170139, 15.696904158539978, 16.001203132146337, 16.306469705871258, 16.612691764799845, 16.919857530065617, 17.227955544569944, 17.536974659512797, 17.84690402167742, 18.15773306141647, 18.469451481291333, 18.782049245320472, 19.09551656879613, 19.40984390863189, 19.72502195420672, 20.041041618673553, 20.357894030703097, 20.675570526635724, 20.99406264301618, 21.313362109487965, 21.633460842025645, 21.954350936485127, 22.2760246624532, 22.5984744573791, 22.921692920971815, 23.245672809848276, 23.57040703241826, 23.89588864399303, 24.222110842105458, 24.549066962030196, 24.876750472493246, 25.205154971560873, 25.534274182698557, 25.86410195099117, 26.19463223951612, 26.525859125861732, 26.857776798783583, 27.19037955499205, 27.523661796064467, 27.85761802547599, 28.192242845743404], [0.0, 0.11927205600272427, 0.27401522905488723, 0.4457426711824451, 0.6295216857189695, 0.8228159672521093, 1.024047746278518, 1.2321294942391605, 1.4462610496406818, 1.6658263097965138, 1.8903346960955845, 2.1193853492344052, 2.35264392317711, 2.5898268459618934, 2.8306902463517054, 3.0750219240468626, 3.322635377237073, 3.5733652632627857, 3.8270638835480733, 4.083598417069356, 4.342848711597636, 4.604705497759626, 4.869068928540757, 5.135847372720851, 5.404956408894633, 5.676317979708175, 5.949859675367173, 6.2255141224171835, 6.5032184589807125, 6.782913881554488, 7.0645452514648985, 7.348060751391905, 7.633411584174358, 7.920551707527413, 8.20943759942702, 8.500028049814876, 8.792283975000473, 9.086168251722782, 9.381645568312132, 9.678682290784804, 9.977246342026397, 10.277307092488206, 10.57883526104457, 10.88180282484644, 11.186182937163887, 11.491949852343646, 11.799078857120572, 12.107546207618201, 12.417329071455896, 12.728405474450561, 13.04075425146175, 13.354355000981403, 13.66918804311493, 13.985234380639895, 14.30247566286286, 14.620894152025226, 14.940472692034996, 15.261194679324747, 15.583044035656389, 15.906005182711201, 16.23006301831969, 16.555202894199763, 16.881410595084322, 17.208672319130518, 17.536974659512794, 17.86630458711085, 18.196649434211395, 18.52799687914996, 18.860334931825253, 19.193651920024298, 19.52793647650201, 19.863177526763216, 20.199364277499676, 20.53648620563833, 20.874533047960494, 21.213494791254966, 21.553361662970744, 21.894124122337832, 22.235772851926885, 22.578298749620583, 22.921692920971818, 23.265946671925295, 23.61105150188113, 23.95699909708023, 24.303781324293062, 24.65139022479414, 24.99981800860639, 25.349057049000027, 25.69909987723212, 26.04993917751355, 26.401567782191133, 26.75397866713342, 27.107164947309396, 27.461119872550036, 27.815836823483238, 28.171309307633283, 28.5275309556765, 28.88449551784529, 29.242196860473232, 29.600628962674246, 29.95978591314941, 30.319661907115215], [0.0, 0.1277400277372599, 0.29346951945813216, 0.47738911433894715, 0.6742159084866536, 0.881233526124879, 1.0967521806692804, 1.3196071321719431, 1.548941409982901, 1.784095169903029, 2.024543003655771, 2.269855592084046, 2.5196748515484266, 2.773697077296263, 3.031661083936532, 3.293339605560724, 3.5585328992682936, 3.8270638835480733, 4.09877437365153, 4.373522118645758, 4.651178435840281, 4.931626298051679, 5.214758769415529, 5.500477713159485, 5.788692714202153, 6.079320173342762, 6.372282539900604, 6.66750765710042, 6.964928200052847, 7.264481190375598, 7.566107574708377, 7.869751856850975, 8.175361775184639, 8.482888018555187, 8.792283975000474, 9.103505508667, 9.416510761035033, 9.731259973199153, 10.04771532646306, 10.365840798927268, 10.685602036094828, 11.006966233807484, 11.329902032064163, 11.654379418474413, 11.980369640267964, 12.307845123924478, 12.636779401608308, 12.967147043696293, 13.29892359677467, 13.632085526556763, 13.966610165238242, 14.302475662862857, 14.639660942320305, 14.978145657640178, 15.317910155282778, 15.658935438159832, 16.00120313214633, 16.344695454869488, 16.689395186582708, 17.035285642951603, 17.38235064959624, 17.73057451824877, 18.079942024399156, 18.430438386313547, 18.78204924532047, 19.134760647269676, 19.488559025076803, 19.843431182274763, 20.199364277499676, 20.556345809845133, 20.91436360502446, 21.27340580228529, 21.63346084202564, 21.99451745406465, 22.356564646524717, 22.71959169528555, 23.08358813397323, 23.448543744450628, 23.81444854777781, 24.18129279561339, 24.549066962030196, 24.91776173572009, 25.287368012565132, 25.65787688855334, 26.029279653019344, 26.40156778219113, 26.77473293302572, 27.14876693731754, 27.523661796064463, 27.899409674077457, 28.27600289482065, 28.653433935469536, 29.031695422175762, 29.41078012552779, 29.7906809561972, 30.171390960761236, 30.552903317692635, 30.93521133350833, 31.31830843906929, 31.702188186023903, 32.08684424338808, 32.47227039425543], [0.0, 0.13630265679826026, 0.31314127529177405, 0.5093893101761646, 0.7194097356186692, 0.9403040926026391, 1.1702693253048695, 1.4080626192983405, 1.6527695597480343, 1.9036860719875612, 2.1602515287392627, 2.4220078328603636, 2.6885728977623877, 2.959622660851943, 3.2348784290416406, 3.5140977024066067, 3.7970673489434823, 4.083598417069356, 4.373522118645758, 4.666686667420322, 4.962954754885243, 5.262201509328025, 5.564312826793267, 5.869183992235596, 6.176718529898532, 6.486827236786173, 6.79942736386515, 7.114441917570115, 7.431799060111052, 7.751431591558711, 8.07327650010666, 8.397274569550985, 8.723370035088662, 9.051510280155853, 9.381645568312132, 9.713728805203456, 10.04771532646306, 10.383562708079177, 10.72123059630464, 11.060680554631409, 11.401875925722786, 11.74478170650257, 12.089364434856035, 12.435592086611681, 12.783433981652658, 13.132860698159142, 13.48384399411192, 13.83635673529739, 14.190372829148298, 14.545867163835132, 14.902815552092479, 15.261194679324745, 15.62098205558745, 15.982155971085547, 16.344695454869488, 16.708580236444202, 17.073790710036153, 17.440307901290176, 17.808113436191082, 18.177189512025468, 18.547518870217484, 18.919084770888286, 19.291870969003305, 19.66586169198419, 20.04104161867355, 20.41739585955096, 20.794909938107562, 21.173569773294858, 21.553361662970744, 21.934272268272007, 22.31628859884905, 22.699397998903308, 23.08358813397323, 23.46884697841875, 23.85516280355822, 24.24252416641551, 24.630919899038044, 25.020339098349762, 25.41077111650559, 25.802205551716412, 26.19463223951612, 26.588041244443932, 26.982422852117544, 27.37776756167407, 27.77406607855758, 28.17130930763328, 28.569488346609972, 28.96859447975352, 29.36861917187521, 29.769554062580116, 30.17139096076124, 30.57412183932648, 30.97773883014603, 31.38223421920872, 31.787600441976515, 32.193830078927036, 32.60091585127455, 33.00885061686057, 33.41762736620561, 33.8272392187142, 34.237679419025724, 34.64894133350411], [0.0, 0.14495593273553906, 0.33302128296074923, 0.5417282708684606, 0.7650819998320296, 0.9999999999999999, 1.244564747203978, 1.4974545260150964, 1.7576968692897885, 2.024543003655771, 2.29739670999407, 2.5757708085227637, 2.8592589556010206, 3.147516515279747, 3.4402471014328126, 3.737192818846552, 4.038127004673238, 4.342848711597636, 4.651178435840281, 4.962954754885243, 5.278031643091578, 5.596276301172887, 5.917567381198964, 6.241793520211594, 6.568852117618866, 6.898648307306076, 7.231094086855691, 7.566107574708377, 7.903612372398381, 8.243537013758772, 8.585814486631536, 8.93038181542784, 9.277179695074507, 9.626152168605852, 9.977246342026397, 10.330412131161868, 10.685602036094828, 11.042770939493446, 11.401875925722784, 11.762876118104396, 12.12573253208319, 12.490407942386536, 12.856866762532375, 13.225074935270763, 13.594999832734725, 13.966610165238244, 14.339875897796423, 14.71476817355985, 15.091259243455164, 15.469322401409599, 15.848931924611142, 16.23006301831969, 16.61269176479984, 16.996795075994005, 17.38235064959624, 17.769336928223964, 18.15773306141647, 18.547518870217484, 18.938674814123743, 19.331181960203295, 19.725021954206717, 20.120176993511453, 20.516629801754796, 20.914363605024466, 21.31336210948796, 21.713609480352545, 22.11509032205737, 22.517789659608074, 22.921692920971818, 23.326785920457713, 23.733054843014106, 24.14048622937962, 24.549066962030196, 24.95878425186903, 25.369625625610368, 25.781578913812194, 26.19463223951612, 26.60877400745617, 27.023992893800862, 27.440277836395747, 27.857618025475986, 28.27600289482065, 28.695422113322632, 29.115865576949663, 29.537323401073994, 29.9597859131494, 30.383243645716092, 30.807687329715034, 31.233107888094693, 31.65949642969422, 32.08684424338807, 32.51514279247822, 32.94438370932077, 33.37455879017477, 33.80565999026185, 34.23767941902572, 34.6706093355815, 35.10444214434543, 35.539170390835984, 35.97478675763796, 36.41128406052162, 36.84865524470957], [0.0, 0.15369620834769088, 0.3531011633965482, 0.574392366120934, 0.8112134510823085, 1.0602960875571596, 1.3196071321719434, 1.5877451752285678, 1.863679113619431, 2.146615025867434, 2.435920743173403, 2.731079710720628, 3.0316610839365326, 3.3372994466726604, 3.6476805418790703, 3.9625309242697124, 4.281610264113946, 4.604705497759626, 4.931626298051679, 5.262201509328025, 5.596276301172887, 5.933709867022465, 6.274373542141128, 6.618149248819984, 6.964928200052847, 7.314609809669454, 7.667100769050801, 8.02231425949988, 8.380169276022364, 8.740590043321056, 9.103505508667, 9.468848899289743, 9.836557334252221, 10.206571482602651, 10.578835261044572, 10.953295565523948, 11.329902032064163, 11.708606822934799, 12.089364434856035, 12.472131526445642, 12.856866762532377, 13.243530673305317, 13.632085526556763, 14.022495211517846, 14.414725132988869, 14.808742114638164, 15.204514310488758, 15.602011123736121, 16.001203132146333, 16.402062019374924, 16.804560511624956, 17.20867231913051, 17.614372082010316, 18.02163532008724, 18.430438386313547, 18.840758423480825, 19.25257332392717, 19.665861691984187, 20.080602808932724, 20.4967766002591, 20.914363605024462, 21.33334494717777, 21.753702308659232, 22.175417904155292, 22.598474457379098, 23.02285517876185, 23.448543744450635, 23.875524276517506, 24.30378132429306, 24.73329984674475, 25.164065195827355, 25.596063100738697, 26.029279653019344, 26.463701292439982, 26.899314793624534, 27.336107253361234, 27.77406607855758, 28.213178974798417, 28.65343393546954, 29.09481923141185, 29.537323401073994, 29.980935241133256, 30.42564379755719, 30.87143835707991, 31.318308439069295, 31.766243787762416, 32.215234364848705, 32.66527034238113, 33.11634209599746, 33.568440198434644, 34.02155541332034, 34.47567868922704, 34.930801153974635, 35.386914109168714, 35.84400902496225, 36.302077535029255, 36.7611114317398, 37.221102661526125, 37.682043320430644, 38.14392564982664, 38.606742032303444, 39.07048498770816], [0.0, 0.16252015093351227, 0.37337326006239085, 0.60736914098658, 0.8577864992670972, 1.1211693641406024, 1.3953678662544937, 1.678900138761813, 1.9706758812935599, 2.269855592084046, 2.5757708085227637, 2.8878753195633924, 3.2057135451645196, 3.5288990900582387, 3.8570996551999777, 4.190026096377014, 4.52742428614849, 4.869068928540757, 5.214758769415529, 5.564312826793267, 5.917567381198964, 6.274373542141128, 6.634595258038012, 6.998107672152566, 7.364795751844394, 7.734553136131997, 8.107281159400866, 8.482888018555187, 8.861288057975692, 9.242401151985442, 9.626152168605852, 10.012470501536031, 10.401289659744792, 10.792546905996504, 11.186182937163888, 11.582141600405118, 11.980369640267964, 12.38081647258219, 12.783433981652657, 13.188176337799785, 13.594999832734727, 14.003862730622243, 14.414725132988869, 14.82754885588934, 15.242297317958789, 15.658935438159835, 16.077429542187566, 16.49774727662647, 16.919857530065617, 17.343730360474378, 17.769336928223968, 18.196649434211395, 18.62564106260446, 19.05628592778032, 19.488559025076803, 19.922436185016988, 20.357894030703097, 20.79490993810756, 21.23346199901676, 21.673528986407415, 22.11509032205737, 22.558126046211616, 23.00261678914156, 23.44854374445064, 23.89588864399303, 24.34463373428422, 24.794761754293052, 25.246255914514617, 25.699099877232122, 26.15327773788353, 26.608774007456173, 27.065573595838515, 27.523661796064467, 27.983024269390484, 28.44364703115071, 28.905516437339582, 29.368619171875217, 29.83294223450062, 30.298472929282873, 30.765198853673287, 31.233107888094697, 31.702188186023903, 32.172428164540115, 32.64381649531191, 33.11634209599747, 33.58999412203429, 34.06476195879651, 34.5406352140991, 35.01760371102996, 35.49565748109194, 35.97478675763796, 36.454981969583706, 36.93623373538318, 37.418532857253396, 37.901870315635286, 38.386237263878854, 38.87162502314114, 39.358025077486325, 39.8454290691781, 40.33382879415471, 40.82321619767788, 41.313583370147306], [0.0, 0.1714247020192063, 0.3938305464306384, 0.6406471653590879, 0.9047850016649156, 1.1825987304152459, 1.4718206899629958, 1.770887821320017, 2.0786500860769563, 2.3942219857943834, 2.7168984324991503, 3.0461032879996717, 3.381356010822189, 3.7222490349308472, 4.068431854469174, 4.419599482884907, 4.775483868982091, 5.135847372720851, 5.500477713159485, 5.869183992235596, 6.241793520211594, 6.618149248819984, 6.998107672152566, 7.38153709251634, 7.76831617458157, 8.158332729801451, 8.551482686628733, 8.947669212035303, 9.346801957292556, 9.74879640660221, 10.15357331147128, 10.561058197048363, 10.97118092922921, 11.383875333377247, 11.799078857120573, 12.21673227097828, 12.63677940160831, 13.05916689331132, 13.483843994111922, 13.910762363302075, 14.339875897796425, 14.77114057503482, 15.20451431048876, 15.639956828097695, 16.077429542187566, 16.516895449615415, 16.958319031046234, 17.401666160406545, 17.84690402167742, 18.294001032291114, 18.742926772482797, 19.193651920024298, 19.6461481898321, 20.10038827799861, 20.556345809845137, 21.013995291638405, 21.473312065650052, 21.93427226827201, 22.396852790929934, 22.861031243562522, 23.326785920457716, 23.794095768256685, 24.262940355954818, 24.733299846744757, 25.205154971560873, 25.678487004197365, 26.153277737883535, 26.62950946321006, 27.1071649473094, 27.586227414201524, 28.066680526223887, 28.548508366471065, 29.031695422175765, 29.51622656896835, 30.002087055956913, 30.489262491574774, 30.977738830146034, 31.46750235912386, 31.95853968695953, 32.45083773156322, 32.94438370932077, 33.43916512463272, 33.93516975994492, 34.432385666241636, 34.93080115397464, 35.43040478440305, 35.931185361320935, 36.43313192315086, 36.93623373538318, 37.440480283342396, 37.94586126526248, 38.452366585655184, 38.95998634895545, 39.46871085342966, 39.97853058533314, 40.48943621330401, 41.00141858298166, 41.514468711838354, 42.02857778421373, 42.543737146541844, 43.05993830276175, 43.57717290990263], [0.0, 0.180407043780723, 0.4144665488415893, 0.6742159084866538, 0.9521940857112638, 1.2445647472039778, 1.5489414099829015, 1.8636791136194313, 2.187567559788869, 2.5196748515484266, 2.8592589556010206, 3.205713545164519, 3.5585328992682945, 3.9172880961594836, 4.281610264113946, 4.651178435840281, 5.025710514748705, 5.404956408894633, 5.788692714202153, 6.176718529898532, 6.568852117618866, 6.964928200052847, 7.364795751844394, 7.76831617458157, 8.175361775184639, 8.585814486631538, 8.999564784215734, 9.416510761035033, 9.836557334252223, 10.25961555959532, 10.685602036094828, 11.114438386552951, 11.546050801966281, 11.980369640267966, 12.417329071455898, 12.856866762532377, 13.29892359677467, 13.743443422742093, 14.1903728291483, 14.639660942320308, 15.091259243455166, 15.545121403290858, 16.001203132146333, 16.459462043568923, 16.919857530065617, 17.382350649596244, 17.84690402167742, 18.313481732091656, 18.782049245320472, 19.25257332392717, 19.72502195420672, 20.199364277499676, 20.67557052663572, 21.153611967032294, 21.633460842025645, 22.11509032205737, 22.5984744573791, 23.083588133973233, 23.570407032418263, 24.058907589454513, 24.5490669620302, 25.040862993628878, 25.534274182698557, 26.02927965301935, 26.52585912586173, 27.023992893800862, 27.52366179606447, 28.02484719530247, 28.5275309556765, 29.031695422175765, 29.537323401073998, 30.044398141448955, 30.552903317692635, 31.062823012946005, 31.57414170339733, 32.08684424338808, 32.60091585127455, 33.11634209599747, 33.63310888431537, 34.15120244866079, 34.670609335581496, 35.19131639473141, 35.71331076837882, 36.23657988140136, 36.7611114317398, 37.28689338128409, 37.81391394716752, 38.34216159344599, 38.87162502314114, 39.40229317062763, 39.93415519434569, 40.46720046982191, 41.00141858298165, 41.53679932373816, 42.07333267984387, 42.611008830990585, 43.149818143145865, 43.68975116311393, 44.23079861330988, 44.77295138673669, 45.31620054215533, 45.8605372994385], [0.0, 0.18946457081379975, 0.4352752816480621, 0.7080656334711767, 1.0000000000000002, 1.3070494407390916, 1.6267076567965486, 1.9572471007602537, 2.2973967099940706, 2.6461778006805163, 3.0028110849535787, 3.3666597947517563, 3.7371928188465535, 4.113959701013448, 4.4965730499320395, 4.884695783807536, 5.2780316430915795, 5.676317979708175, 6.079320173342762, 6.486827236786173, 6.898648307306076, 7.314609809669454, 7.734553136131997, 8.158332729801451, 8.585814486631538, 9.016874411920089, 9.451397482156484, 9.88927667409439, 10.33041213116187, 10.774710443545404, 11.22208402304134, 11.672450557441513, 12.125732532083191, 12.581856808445673, 13.04075425146175, 13.502359398639447, 13.966610165238244, 14.433447580674802, 14.902815552092479, 15.374660651651569, 15.848931924611144, 16.32558071569943, 16.804560511624956, 17.28582679787823, 17.769336928223968, 18.25505000549556, 18.742926772482793, 19.23292951185679, 19.72502195420672, 20.21916919337512, 20.715337608374927, 21.213494791254966, 21.713609480352545, 22.215651498434912, 22.719591695285555, 23.225401894339623, 23.733054843014113, 24.24252416641551, 24.75378432413996, 25.26681056990934, 25.781578913812197, 26.298066086940686, 26.816249508234588, 27.33610725336124, 27.85761802547599, 28.380761127721833, 28.905516437339585, 29.431864381271232, 29.95978591314941, 30.48926249157477, 31.02027605959178, 31.552809025280375, 32.08684424338808, 32.62236499793307, 33.15935498571417, 33.697798300668985, 34.23767941902573, 34.77898318519846, 35.32169479837961, 35.86579979978635, 36.41128406052162, 36.95813377001227, 37.50633542499051, 38.05587581898663, 38.60674203230345, 39.15892142244484, 39.712401614972784, 40.267170494768834, 40.82321619767788, 41.3805271025131, 41.93909182340273, 42.49889920246037, 43.05993830276175, 43.62219840161187, 44.18566898408764, 44.75033973684188, 45.31620054215533, 45.88324147222449, 46.45145278367346, 47.02082491227877, 47.59134846789699, 48.163014229585244], [0.0, 0.198594866218846, 0.45625119227288935, 0.7421873078928632, 1.0481899880586079, 1.3700361376803185, 1.70509867935242, 2.051566815173635, 2.4081082300145695, 2.7736970772962635, 3.147516515279747, 3.5288990900582387, 3.917288096159484, 4.31221136987888, 4.713262851512922, 5.120089215299153, 5.532379924945117, 5.949859675367173, 6.372282539900604, 6.79942736386515, 7.231094086855691, 7.667100769050801, 8.107281159400866, 8.551482686628733, 8.999564784215734, 9.451397482156484, 9.90686021395876, 10.365840798927266, 10.828234568403058, 11.293943611154814, 11.762876118104396, 12.23494581041931, 12.710071438006151, 13.188176337799783, 13.669188043114932, 14.153037936822914, 14.639660942320305, 15.128995247232062, 15.62098205558745, 16.115565364859805, 16.61269176479984, 17.112310255438825, 17.614372082010316, 18.118830584851146, 18.625641062604462, 19.13476064726968, 19.6461481898321, 20.159764155365213, 20.67557052663572, 21.193530715358836, 21.713609480352545, 22.235772851926882, 22.75998806192001, 23.28622347885868, 23.814448547777808, 24.344633734284216, 24.876750472493246, 25.410771116505586, 25.94666889512562, 26.484417869552374, 27.023992893800862, 27.565369577634836, 28.10852425181306, 28.653433935469543, 29.200076305464936, 29.74842966756095, 30.29847292928287, 30.850185574347257, 31.403547638542527, 31.95853968695952, 32.51514279247822, 33.07333851542417, 33.63310888431536, 34.19443637762701, 34.75730390650687, 35.3216947983796, 35.88759278138302, 36.4549819695837, 37.02384684892331, 37.594172263850474, 38.16594340459674, 38.739145795057595, 39.313765281242944, 39.88978802026346, 40.467200469821904, 41.04598937818042, 41.62614177457696, 42.20764496006567, 42.79048649875794, 43.374654209442106, 43.96013615756136, 44.54692064753092, 45.134996215376226, 45.724351621675766, 46.31497584479243, 46.90685807437893, 47.499987705143276, 48.09435433086121, 48.689947738623665, 49.286757903307375, 49.884774982257994, 50.48398931017551], [0.0, 0.2077956811996041, 0.47738911433894715, 0.7765725275664882, 1.0967521806692802, 1.4335093243731616, 1.7840951699030294, 2.146615025867434, 2.5196748515484266, 2.902201273334996, 3.2933396055607242, 3.6923914714655797, 4.098774373651532, 4.511994273272038, 4.93162629805168, 5.357300752796953, 5.788692714202153, 6.2255141224171835, 6.66750765710042, 7.114441917570115, 7.566107574708377, 8.02231425949988, 8.482888018555187, 8.947669212035303, 9.416510761035033, 9.88927667409439, 10.365840798927266, 10.846085757554867, 11.329902032064165, 11.817187175038487, 12.307845123924476, 12.801785602628334, 13.29892359677467, 13.79917889153142, 14.30247566286286, 14.808742114638163, 15.317910155282778, 15.829915108680833, 16.344695454869488, 16.862192596749033, 17.38235064959624, 17.905116250635697, 18.430438386313543, 18.95826823524443, 19.488559025076803, 20.021265901754006, 20.556345809845137, 21.093757382787484, 21.633460842025645, 22.17541790415529, 22.71959169528555, 23.265946671925295, 23.814448547777808, 24.365064225897246, 24.917761735720095, 25.47251017453741, 26.029279653019344, 26.588041244443932, 27.148766937317543, 27.71142959110568, 28.276002894820653, 28.84246132823704, 29.410780125527793, 29.980935241133263, 30.552903317692635, 31.126661655882856, 31.702188186023907, 32.279461441321736, 32.8584605326314, 33.439165124632716, 34.02155541332035, 34.60561210471759, 35.19131639473141, 35.778649950072285, 36.367594890168775, 36.958133770012275, 37.5502495638722, 38.14392564982664, 38.7391457950576, 39.33589414186351, 39.93415519434569, 40.53391380572792, 41.135155166271815, 41.73786479175291, 42.34202851246516, 42.94763246272337, 43.55466307083564, 44.16310704951942, 44.77295138673669, 45.38418333692549, 45.99679041260611, 46.61076037634234, 47.226081233038606, 47.842741222555794, 48.4607288126291, 49.080032692072464, 49.70064176425527, 50.322545140837356, 50.945732135749964, 51.57019225941015, 52.195915213157626, 52.82289088390318], [0.0, 0.2170649175475729, 0.49868422742892815, 0.8112134510823087, 1.1456755034211543, 1.4974545260150967, 1.8636791136194315, 2.2423700574830976, 2.63207113228056, 3.0316610839365326, 3.440247101432813, 3.8570996551999777, 4.281610264113947, 4.713262851512922, 5.151613592650883, 5.596276301172887, 6.046911559771726, 6.5032184589807125, 6.964928200052847, 7.431799060111052, 7.903612372398381, 8.380169276022364, 8.861288057975692, 9.346801957292556, 9.836557334252223, 10.33041213116187, 10.828234568403058, 11.329902032064165, 11.835300118916873, 12.344321811626047, 12.856866762532377, 13.372840668555336, 13.892154723044674, 14.414725132988872, 14.940472692034996, 15.4693224014096, 16.001203132146333, 16.53604732309244, 17.073790710036153, 17.61437208201032, 18.157733061416472, 18.70381790510163, 19.25257332392717, 19.803948318710017, 20.357894030703097, 20.914363605024466, 21.473312065650052, 22.034696200760095, 22.5984744573791, 23.164606844377527, 23.733054843014113, 24.303781324293062, 24.876750472493246, 25.451927714298332, 26.029279653019348, 26.608774007456173, 27.190379554992052, 27.77406607855758, 28.359804317137723, 28.94756591952782, 29.537323401073998, 30.12905010315855, 30.722720155213935, 31.318308439069302, 31.91579055545142, 32.51514279247823, 33.116342095997474, 33.71936604163605, 34.32419280843745, 34.930801153974635, 35.539170390835984, 36.149280364389625, 36.7611114317398, 37.3746444417956, 37.98986071637883, 38.60674203230345, 39.22527060436439, 39.8454290691781, 40.46720046982191, 41.090568241222556, 41.71551619624876, 42.34202851246516, 42.97008971950867, 43.59968468705043, 44.23079861330989, 44.86341701408891, 45.49752571229699, 46.13311082793973, 46.770158768545215, 47.4086562200044, 48.048590137802925, 48.68994773862367, 49.332716492300406, 49.97688411410414, 50.622438557345085, 51.26936800627399, 51.917660869267785, 52.56730577228517, 53.21829155257905, 53.870607252652924, 54.52424211444946, 55.17918557376028], [0.0, 0.2264006125149731, 0.5201320223325415, 0.8461027432734185, 1.194949596869343, 1.5618582022994778, 1.9438336587133092, 2.3388116340271554, 2.7452732724563695, 3.1620490961677876, 3.5882078954400733, 4.022988764534836, 4.465757052303693, 4.915974486262742, 5.373178153309842, 5.836965257690195, 6.306981784175918, 6.782913881554488, 7.264481190375598, 7.751431591558711, 8.243537013758772, 8.740590043321056, 9.242401151985442, 9.74879640660221, 10.25961555959532, 10.774710443545404, 11.293943611154814, 11.817187175038487, 12.344321811626047, 12.875235900898481, 13.409824779367144, 13.947990088092073, 14.489639200958287, 15.034684721119955, 15.58304403565639, 16.134638920189193, 16.689395186582708, 17.247242367962148, 17.808113436191082, 18.371944547693992, 18.938674814123747, 19.508246094882956, 20.080602808932724, 20.65569176367788, 21.23346199901676, 21.813864644896615, 22.39685279092993, 22.982381366809758, 23.570407032418263, 24.160888076656637, 24.75378432413996, 25.349057049000027, 25.94666889512562, 26.546583802244612, 27.148766937317546, 27.753184630769606, 28.359804317137723, 28.96859447975352, 29.579524599121708, 30.19256510468722, 30.807687329715037, 31.424863469033113, 32.04406653941263, 32.665270342381135, 33.28844942928268, 33.913579068416325, 34.540635214099105, 35.169594477513236, 35.80043409920971, 36.43313192315085, 37.06766637218493, 37.70401642485415, 38.34216159344599, 38.98208190320468, 39.62375787262658, 40.26717049476884, 40.912301219506595, 41.55913193667856, 42.20764496006568, 42.857823012151265, 43.50964920961545, 44.16310704951941, 44.81818039613877, 45.47485346840785, 46.13311082793973, 46.79293736758874, 47.454318300525166, 48.11723914979312, 48.781685738325216, 49.44764417938895, 50.11510086744145, 50.78404246937087, 51.45445591610394, 52.126328394560595, 52.79964733993776, 53.474400428305344, 54.15057556949881, 54.828160900293376, 55.507144777845916, 56.18751577339148, 56.86926266618194, 57.55237443765532], [0.0, 0.2358009256789868, 0.5417282708684605, 0.8812335261248793, 1.2445647472039778, 1.626707656796548, 2.0245430036557712, 2.435920743173403, 2.8592589556010206, 3.2933396055607242, 3.7371928188465526, 4.190026096377015, 4.651178435840282, 5.120089215299153, 5.596276301172887, 6.0793201733427615, 6.568852117618866, 7.0645452514648985, 7.566107574708377, 8.07327650010666, 8.585814486631536, 9.103505508667, 9.626152168605852, 10.15357331147128, 10.685602036094828, 11.22208402304134, 11.762876118104396, 12.307845123924476, 12.856866762532377, 13.409824779367144, 13.966610165238242, 14.527120477273124, 15.091259243455164, 15.658935438159835, 16.23006301831969, 16.804560511624956, 17.38235064959624, 17.963360039524396, 18.547518870217484, 19.13476064726968, 19.725021954206717, 20.318242236392596, 20.914363605024462, 21.513330658913063, 22.11509032205737, 22.71959169528555, 23.326785920457713, 23.936626055915966, 24.5490669620302, 25.16406519582736, 25.781578913812194, 26.401567782191133, 27.02399289380086, 27.64881669112131, 28.276002894820657, 28.905516437339575, 29.537323401073994, 30.17139096076124, 30.807687329715037, 31.446181709590007, 32.08684424338808, 32.729645971446836, 33.37455879017477, 34.02155541332036, 34.670609335581496, 35.321694798379596, 35.97478675763796, 36.629860853418585, 37.28689338128409, 37.94586126526247, 38.606742032303444, 39.269513788123454, 39.93415519434569, 40.60064544684845, 41.2689642552423, 41.93909182340273, 42.611008830990585, 43.28469641589792, 43.960136157561365, 44.63731006108958, 45.31620054215532, 45.99679041260611, 46.67906286675091, 47.36300146828306, 48.048590137802925, 48.73581314090549, 49.424655076801436, 50.11510086744145, 50.8071357471163, 51.50074525250656, 52.19591521315762, 52.89263174235742, 53.59088122839555, 54.29065032618383, 54.99192594921968, 55.69469526187473, 56.39894567199231, 57.10466482377814, 57.811840590970064, 58.520461070272724, 59.23051457504463, 59.94198962922533], [0.0, 0.24526412747718696, 0.5634689995456555, 0.9165993359284087, 1.2945118257398394, 1.6919909578633974, 2.1057922987446758, 2.533679517829163, 2.974007209503124, 3.4255084559911673, 3.8871744599350846, 4.358180917549008, 4.837840299066868, 5.3255694835790415, 5.820866988440081, 6.323296457280388, 6.832474378611123, 7.348060751391905, 7.869751856850975, 8.397274569550985, 8.93038181542784, 9.468848899289743, 10.012470501536031, 10.561058197048363, 11.114438386552951, 11.672450557441513, 12.23494581041931, 12.801785602628334, 13.372840668555336, 13.947990088092073, 14.527120477273124, 15.110125281971616, 15.696904158539976, 16.287362428298234, 16.881410595084322, 17.47896391692823, 18.079942024399156, 18.6842685793796, 19.291870969003305, 19.90268003029994, 20.516629801754792, 21.13365729854318, 21.75370230865923, 22.376707207543987, 23.002616789141555, 23.631378111586116, 24.262940355954814, 24.897254696719365, 25.534274182698553, 26.173953627458737, 26.816249508234584, 27.461119872550032, 28.108524251813055, 28.758423581238972, 29.41078012552779, 30.065557409783104, 30.72272015521393, 31.382234219208716, 32.04406653941263, 32.708185081476, 33.37455879017477, 34.04315754363254, 34.713952110399816, 35.38691410916872, 36.062015970921976, 36.73923090333345, 37.418532857253396, 38.099896495126764, 38.78329716120576, 39.468710853429656, 40.15611419685598, 40.845484418536174, 41.53679932373815, 42.23003727342576, 42.925177162912284, 43.62219840161186, 44.32108089381831, 45.02180502044643, 45.724351621675766, 46.42870198044099, 47.134837806717755, 47.84274122255579, 48.55239474781528, 49.26378128656498, 49.97688411410413, 50.69168686457198, 51.408173519112154, 52.126328394560595, 52.84613613262817, 53.56758168955113, 54.29065032618382, 55.015327598510375, 55.741599348552946, 56.46945169565607, 57.198871028127485, 57.929843995217254, 58.66235749941819, 59.39639868907123, 60.131954951261065, 60.869013904987305, 61.60756339459824, 62.34759148347425], [0.0, 0.25478858915423824, 0.5853504664669779, 0.952194085711264, 1.3447822358547292, 1.7576968692897887, 2.1875675597888695, 2.6320711322805597, 3.0894982843111247, 3.558532899268294, 4.038127004673238, 4.52742428614849, 5.025710514748705, 5.532379924945117, 6.046911559771726, 6.5688521176188654, 7.097803193908702, 7.633411584174358, 8.175361775184639, 8.723370035088662, 9.277179695074507, 9.836557334252221, 10.401289659744792, 10.97118092922921, 11.546050801966281, 12.125732532083191, 12.710071438006151, 13.29892359677467, 13.892154723044674, 14.489639200958287, 15.091259243455164, 15.696904158539976, 16.306469705871258, 16.919857530065617, 17.536974659512797, 18.15773306141647, 18.782049245320472, 19.40984390863189, 20.04104161867355, 20.67557052663572, 21.313362109487965, 21.954350936485127, 22.598474457379098, 23.245672809848276, 23.89588864399303, 24.5490669620302, 25.20515497156087, 25.864101950991174, 26.52585912586173, 27.19037955499205, 27.85761802547599, 28.527530955676497, 29.200076305464936, 29.87521349303476, 30.55290331769264, 31.233107888094693, 31.91579055545142, 32.60091585127455, 33.28844942928268, 33.97835801112058, 34.6706093355815, 35.36517211105152, 36.06201597092198, 36.761111431739806, 37.462429853886604, 38.165943404596746, 38.87162502314114, 39.57944838801909, 40.289387886014076, 41.00141858298164, 41.71551619624876, 42.431657068513815, 43.14981814314586, 43.86997694078948, 44.592111537189346, 45.31620054215533, 46.042223079594855, 46.770158768545215, 47.499987705143276, 48.23169044547478, 48.965247989249924, 49.700641764255266, 50.43785361153616, 51.176865771266755, 51.91766086926778, 52.66022190413502, 53.40453223494404, 54.15057556949881, 54.89833595309425, 55.64779775776478, 56.3989456719923, 57.15176469084942, 57.90624010655463, 58.662357499418185, 59.42010272915833, 60.17946192656894, 60.94042148552093, 61.70296805528047, 62.467088533128766, 63.232770057267984, 64.00000000000004, 64.76876596116476], [0.0, 0.2643727739072751, 0.60736914098658, 0.9880120321448119, 1.3953678662544935, 1.823814789213235, 2.2698555920840464, 2.7310797107206284, 3.2057135451645196, 3.69239147146558, 4.190026096377015, 4.697728894207549, 5.214758769415531, 5.740487169860108, 6.274373542141129, 6.8159475331538415, 7.364795751844395, 7.920551707527413, 8.482888018555187, 9.051510280155853, 9.626152168605852, 10.206571482602651, 10.792546905996504, 11.383875333377247, 11.980369640267966, 12.581856808445673, 13.188176337799783, 13.79917889153142, 14.414725132988872, 15.034684721119955, 15.658935438159835, 16.287362428298234, 16.919857530065617, 17.55631868832041, 18.1966494342114, 18.84075842348083, 19.488559025076803, 20.139968953342276, 20.794909938107562, 21.453307427881967, 22.11509032205737, 22.78019072863102, 23.448543744450635, 24.120087255400087, 24.794761754293052, 25.472510174537415, 26.153277737883535, 26.83701181478268, 27.52366179606447, 28.213178974798424, 28.905516437339582, 29.60062896267425, 30.29847292928287, 30.99900622882456, 31.70218818602391, 32.40797948420774, 33.11634209599747, 33.8272392187142, 34.540635214099105, 35.256495551990874, 35.974786757637965, 36.69547636235408, 37.4185328572534, 38.143925649826656, 38.87162502314114, 39.60160209746768, 40.33382879415472, 41.06827780158606, 41.80492254307272, 42.543737146541844, 43.284696415897926, 44.027775803941, 44.7729513867367, 45.52019983934113, 46.269498412791265, 47.020824912278776, 47.774157676431315, 48.52947555763129, 49.28675790330739, 50.04598453813872, 50.807135747116305, 51.570192259410156, 52.335135232994325, 53.101946239985345, 53.87060725265293, 54.64110063006423, 55.41340910532607, 56.18751577339148, 56.96340407939966, 57.74105780751994, 58.52046107027273, 59.30159829830192, 60.08445423057479, 60.86901390498732, 61.65526264935372, 62.44318607276072, 63.232770057268, 64.02400074993757, 64.81686455517578, 65.61134812737255, 66.40743836382347, 67.20512239792116], [0.0, 0.2740152290548873, 0.6295216857189696, 1.024047746278518, 1.4462610496406818, 1.8903346960955847, 2.35264392317711, 2.8306902463517054, 3.322635377237073, 3.8270638835480737, 4.342848711597637, 4.869068928540757, 5.404956408894635, 5.949859675367174, 6.5032184589807125, 7.064545251464899, 7.633411584174359, 8.20943759942702, 8.792283975000474, 9.381645568312132, 9.977246342026397, 10.578835261044572, 11.186182937163888, 11.799078857120573, 12.417329071455898, 13.04075425146175, 13.669188043114932, 14.30247566286286, 14.940472692034996, 15.58304403565639, 16.23006301831969, 16.881410595084322, 17.536974659512797, 18.1966494342114, 18.860334931825253, 19.52793647650201, 20.199364277499676, 20.874533047960497, 21.553361662970744, 22.235772851926885, 22.92169292097182, 23.61105150188113, 24.303781324293062, 24.999818008606393, 25.699099877232122, 26.401567782191137, 27.1071649473094, 27.81583682348324, 28.527530955676504, 29.242196860473236, 29.95978591314941, 30.680251243347538, 31.40354763854253, 32.12963145457805, 32.8584605326314, 33.5899941220343, 34.32419280843745, 35.061018446859684, 35.80043409920971, 36.54240397590935, 37.286893381284095, 38.033868662418854, 38.783297161205766, 39.53514716933648, 40.289387886014076, 41.04598937818044, 41.80492254307272, 42.56615907293953, 43.329671421761574, 44.09543277383519, 44.86341701408892, 45.63359870001397, 46.40595303509951, 47.180455843672114, 47.957083547046935, 48.735813140905506, 49.51662217382131, 50.29948872686075, 51.084391394192295, 51.87130926464156, 52.66022190413503, 53.45110933897867, 54.243952039922256, 55.03873090696304, 55.835427254846216, 56.63402279922205, 57.43449964342283, 58.23684026582467, 59.04102750776209, 59.84704456196527, 60.65487496149136, 61.464502569123866, 62.2759115672152, 63.08908644794924, 63.90401200400231, 64.72067331958203, 65.5390557618252, 66.35914497253624, 67.18092686025014, 68.00438759260301, 68.82951358899615, 69.65629151353903], [0.0, 0.28371457908463216, 0.6518049405663864, 1.0602960875571599, 1.4974545260150967, 1.9572471007602532, 2.4359207431734036, 2.9308885295633673, 3.440247101432813, 3.962530924269713, 4.496573049932039, 5.041419947204073, 5.596276301172888, 6.1604675741263, 6.733413665178238, 7.314609809669453, 7.903612372398381, 8.500028049814876, 9.103505508667, 9.713728805203456, 10.330412131161868, 10.953295565523948, 11.582141600405118, 12.21673227097828, 12.856866762532377, 13.502359398639447, 14.153037936822914, 14.808742114638163, 15.4693224014096, 16.134638920189193, 16.804560511624956, 17.47896391692823, 18.15773306141647, 18.84075842348083, 19.52793647650201, 20.219169193375116, 20.914363605024462, 21.613431405683126, 22.316288598849052, 23.022855178761855, 23.73305484301411, 24.44681473254889, 25.16406519582736, 25.884739574395798, 26.608774007456173, 27.336107253361234, 28.066680526223884, 28.800437346059265, 29.537323401073998, 30.27728642088458, 31.02027605959178, 31.76624378776242, 32.51514279247822, 33.26692788470542, 34.02155541332035, 34.77898318519846, 35.539170390835984, 36.302077535029255, 37.06766637218493, 37.83589984587682, 38.606742032303444, 39.38015808733345, 40.15611419685599, 40.934577530179894, 41.71551619624876, 42.49889920246037, 43.284696415897926, 44.07287852679711, 44.86341701408892, 45.65628411287096, 46.45145278367345, 47.24889668339608, 48.048590137802925, 48.850508115471335, 49.65462620309893, 50.460920582080604, 51.26936800627399, 52.079945780878376, 52.89263174235743, 53.707404239341415, 54.52424211444945, 55.34312468697625, 56.16403173639239, 56.986943486609995, 57.811840590970064, 58.63870411790955, 59.467515537270216, 60.29825670721314, 61.13090986170554, 61.9654575985486, 62.801882867917136, 63.64016896138366, 64.48029950140139, 65.3222584312222, 66.16603000522692, 67.01159877964709, 67.85894960365826, 68.70806761082613, 69.55893821088837, 70.41154708185525, 71.26588016241398, 72.12192364462192], [0.0, 0.29346951945813216, 0.6742159084866537, 1.0967521806692804, 1.5489414099829013, 2.024543003655771, 2.519674851548427, 3.0316610839365326, 3.5585328992682936, 4.098774373651531, 4.651178435840281, 5.214758769415529, 5.788692714202154, 6.372282539900604, 6.964928200052847, 7.566107574708377, 8.175361775184639, 8.792283975000473, 9.416510761035033, 10.04771532646306, 10.685602036094828, 11.329902032064163, 11.980369640267964, 12.63677940160831, 13.29892359677467, 13.966610165238244, 14.639660942320305, 15.317910155282778, 16.001203132146333, 16.689395186582708, 17.38235064959624, 18.079942024399156, 18.782049245320472, 19.488559025076803, 20.199364277499676, 20.914363605024462, 21.63346084202564, 22.356564646524717, 23.08358813397323, 23.81444854777781, 24.549066962030196, 25.287368012565135, 26.02927965301934, 26.77473293302572, 27.523661796064467, 28.276002894820657, 29.031695422175765, 29.7906809561972, 30.552903317692635, 31.31830843906929, 32.08684424338808, 32.85846053263139, 33.63310888431536, 34.41074255567452, 35.191316394731416, 35.97478675763796, 36.7611114317398, 37.55024956387219, 38.34216159344599, 39.13680918992624, 39.93415519434569, 40.73416356452942, 41.53679932373816, 42.34202851246517, 43.14981814314586, 43.960136157561365, 44.77295138673669, 45.588233513151785, 46.40595303509951, 47.226081233038606, 48.04859013780292, 48.87345250053899, 49.700641764255266, 50.53013203687528, 51.361898065695634, 52.195915213157626, 53.032159433848264, 53.87060725265292, 54.71123574398781, 55.55402251204553, 56.3989456719923, 57.24598383205947, 58.09511607647643, 58.94632194919534, 59.79958143836224, 60.654874961491345, 61.51218335130317, 62.37148784218911, 63.232770057267984, 64.09601199600229, 64.96119602234377, 65.82830485338016, 66.69732154845651, 67.56822949874653, 68.44101241725045, 69.3156543291977, 70.19213956283399, 71.07045274057332, 71.95057877049732, 72.8325028381842, 73.71621039885194, 74.60168716980029], [0.0, 0.30327881107237303, 0.6967517427685831, 1.1334113948479931, 1.6007151615191775, 2.0922138566462256, 2.6038956095935695, 3.132995109026391, 3.6774777457117853, 4.235776925624774, 4.806645230863044, 5.389063377136178, 5.982181206648271, 6.585277667291128, 7.197732655904744, 7.819006600549525, 8.448625274074667, 9.086168251722782, 9.731259973199153, 10.383562708079177, 11.042770939493446, 11.708606822934799, 12.38081647258219, 13.05916689331132, 13.743443422742093, 14.433447580674802, 15.128995247232062, 15.829915108680833, 16.53604732309244, 17.247242367962148, 17.963360039524396, 18.6842685793796, 19.40984390863189, 20.139968953342276, 20.874533047960497, 21.613431405683126, 22.356564646524717, 23.103838375378444, 23.85516280355822, 24.61045240831098, 25.36962562561037, 26.13260457222518, 26.899314793624534, 27.669685034758174, 28.44364703115071, 29.221135318087484, 30.00208705595691, 30.78644187005879, 31.57414170339733, 32.36513068115703, 33.15935498571416, 33.95676274116992, 34.75730390650686, 35.56093017657099, 36.367594890168775, 37.17725294464565, 37.98986071637883, 38.80537598667636, 39.62375787262658, 40.444966762486885, 41.2689642552423, 42.09571310399926, 42.925177162912284, 43.757321337369696, 44.592111537189346, 45.42951463259844, 46.269498412791265, 47.112031546877105, 47.957083547046935, 48.8046247338017, 49.65462620309893, 50.50705979528543, 51.361898065695634, 52.219114256803984, 53.07868227182919, 53.94057664969602, 54.80477254126758, 55.67124568676771, 56.5399723943193, 57.41092951952949, 58.284094446058525, 59.15944506711255, 60.03695976780613, 60.91661740834294, 61.79839730796783, 62.68227922964557, 63.568243365425595, 64.45627032245415, 65.34634110959824, 66.23843712464794, 67.13254014206571, 68.0286323012536, 68.92669609531109, 69.82671436025774, 70.72867026469676, 71.6325472998969, 72.5383292702716, 73.44600028423524, 74.3555447454183, 75.26694734422327, 76.18019304970518, 77.09526710176097], [0.0, 0.31314127529177405, 0.7194097356186692, 1.1702693253048695, 1.6527695597480343, 2.1602515287392627, 2.6885728977623877, 3.2348784290416406, 3.7970673489434823, 4.3735221186457585, 4.962954754885243, 5.564312826793267, 6.176718529898533, 6.79942736386515, 7.431799060111052, 8.07327650010666, 8.723370035088662, 9.381645568312132, 10.04771532646306, 10.72123059630464, 11.401875925722784, 12.089364434856035, 12.783433981652657, 13.483843994111922, 14.1903728291483, 14.902815552092479, 15.62098205558745, 16.344695454869488, 17.073790710036153, 17.808113436191082, 18.547518870217484, 19.291870969003305, 20.04104161867355, 20.794909938107562, 21.553361662970744, 22.316288598849052, 23.08358813397323, 23.85516280355822, 24.630919899038044, 25.41077111650559, 26.19463223951612, 26.982422852117544, 27.77406607855758, 28.569488346609972, 29.368619171875213, 30.171390960761244, 30.97773883014603, 31.787600441976515, 32.60091585127455, 33.41762736620561, 34.237679419025724, 35.061018446859684, 35.88759278138302, 36.717352546584024, 37.5502495638722, 38.386237263878854, 39.22527060436438, 40.06730599370764, 40.912301219506595, 41.76021538186603, 42.611008830990585, 43.46464310873767, 44.32108089381831, 45.1802859503629, 46.042223079594855, 46.90685807437894, 47.77415767643131, 48.6440895359975, 49.51662217382131, 50.39172494524229, 51.26936800627399, 52.149522281526444, 53.032159433848264, 53.917251835573516, 54.80477254126758, 55.694695261874735, 56.58699434017748, 57.48164472748475, 58.37862196147229, 59.27790214510402, 60.17946192656894, 61.08327848017213, 61.989329488123666, 62.89759312317239, 63.808048032036105, 64.72067331958203, 65.63544853371569, 66.55235365093812, 67.47136906253489, 68.39247556136218, 69.3156543291977, 70.24088692462651, 71.16815527143305, 72.09744164747345, 73.0287286740029, 73.96199930543511, 74.89723681951169, 75.83442480786121, 76.77354716692858, 77.71458808925638, 78.6575320551014, 79.6023638243699], [0.0, 0.3230557894786829, 0.7421873078928632, 1.2073217765265378, 1.7050986793524199, 2.228648275252544, 2.773697077296264, 3.337299446672661, 3.917288096159484, 4.511994273272038, 5.120089215299154, 5.740487169860108, 6.372282539900605, 7.0147072531071055, 7.667100769050802, 8.328888330008562, 8.999564784215734, 9.678682290784804, 10.365840798927268, 11.060680554631409, 11.762876118104396, 12.472131526445642, 13.188176337799785, 13.910762363302075, 14.639660942320308, 15.374660651651569, 16.115565364859805, 16.862192596749033, 17.61437208201032, 18.371944547693992, 19.13476064726968, 19.90268003029994, 20.67557052663572, 21.453307427881967, 22.235772851926885, 23.022855178761855, 23.81444854777781, 24.61045240831098, 25.41077111650559, 26.215313572622705, 27.023992893800862, 27.83672611800043, 28.65343393546954, 29.474040444576836, 30.298472929282873, 31.12666165588286, 31.958539686959522, 32.79404271074519, 33.63310888431536, 34.475678689227045, 35.3216947983796, 36.17110195301827, 37.023846848923306, 37.87987803093497, 38.7391457950576, 39.601602097467676, 40.46720046982191, 41.33589594032421, 42.20764496006568, 43.082405334200175, 43.960136157561365, 44.84079775436522, 45.724351621675766, 46.610760376342355, 47.499987705143276, 48.39199831789499, 49.28675790330738, 50.1842330873851, 51.08439139419229, 51.98720120881341, 52.89263174235743, 53.80065299886468, 54.71123574398781, 55.624351475328275, 56.53997239431929, 57.45807137955491, 58.37862196147229, 59.30159829830191, 60.226975153206304, 61.15472787253399, 62.08483236512124, 63.017265082577985, 63.9520030005002, 64.88902360055378, 65.82830485338017, 66.76982520227588, 67.71356354760299, 68.65949923188907, 69.60761202557886, 70.5578821134021, 71.51029008132386, 72.46481690404678, 73.42144393303573, 74.38015288503763, 75.34092583107102, 76.30374518586119, 77.26859369769846, 78.23545443869816, 79.2043107954429, 80.17514645998789, 81.14794542121197, 82.12269195649759], [0.0, 0.33302128296074923, 0.7650819998320297, 1.244564747203978, 1.7576968692897887, 2.29739670999407, 2.859258955601021, 3.440247101432813, 4.038127004673238, 4.651178435840281, 5.278031643091579, 5.917567381198964, 6.568852117618867, 7.231094086855692, 7.903612372398381, 8.585814486631536, 9.277179695074507, 9.977246342026397, 10.685602036094828, 11.401875925722786, 12.12573253208319, 12.856866762532377, 13.594999832734727, 14.339875897796425, 15.091259243455166, 15.848931924611144, 16.61269176479984, 17.38235064959624, 18.157733061416472, 18.938674814123747, 19.725021954206717, 20.516629801754792, 21.313362109487965, 22.11509032205737, 22.92169292097182, 23.73305484301411, 24.549066962030196, 25.36962562561037, 26.19463223951612, 27.023992893800862, 27.85761802547599, 28.695422113322635, 29.537323401073994, 30.383243645716096, 31.233107888094697, 32.08684424338808, 32.94438370932077, 33.80565999026186, 34.6706093355815, 35.539170390835984, 36.41128406052162, 37.28689338128409, 38.16594340459674, 39.048381088032045, 39.9341551943457, 40.82321619767788, 41.71551619624876, 42.611008830990585, 43.50964920961545, 44.41139383566778, 45.31620054215532, 46.22402842939161, 47.13483780671776, 48.04859013780293, 48.96524798924993, 49.884774982257994, 50.807135747116305, 51.732295880322084, 52.66022190413503, 53.59088122839555, 54.52424211444945, 55.4602736410339, 56.3989456719923, 57.34022882569573, 58.284094446058525, 59.23051457504464, 60.17946192656895, 61.13090986170554, 62.084832365121244, 63.041204022658796, 64.00000000000004, 64.96119602234377, 65.92476835503851, 66.89069378511377, 67.85894960365826, 68.82951358899614, 69.8023639906164, 70.77747951381333, 71.7548393049986, 72.73442293764852, 73.71621039885194, 74.70018207642688, 75.68631874657578, 76.6746015620512, 77.66501204080576, 78.65753205510138, 79.65214382105465, 80.64882988859637, 81.64757313182527, 82.64835673973569, 83.65116420730192, 84.65597932690152], [0.0, 0.3430367333825799, 0.7880914626802521, 1.2819944165979573, 1.8105587335360258, 2.3664897800935405, 2.9452497549229144, 3.5437108319695425, 4.159571677676697, 4.791060327511261, 5.4367658350214905, 6.095535294232396, 6.766407097070746, 7.4485656660851545, 8.141309606537178, 8.844028612039336, 9.556186287278958, 10.277307092488206, 11.006966233807484, 11.74478170650257, 12.490407942386536, 13.243530673305317, 14.003862730622243, 14.77114057503482, 15.545121403290858, 16.32558071569943, 17.112310255438825, 17.905116250635697, 18.70381790510163, 19.508246094882956, 20.318242236392596, 21.13365729854318, 21.954350936485127, 22.78019072863102, 23.61105150188113, 24.44681473254889, 25.287368012565135, 26.13260457222518, 26.982422852117544, 27.83672611800043, 28.695422113322635, 29.558422744856923, 30.42564379755719, 31.297004675289504, 32.17242816454012, 33.051840218586854, 33.93516975994492, 34.82234849917508, 35.71331076837882, 36.60799336790788, 37.50633542499051, 38.40827826312766, 39.313765281242944, 40.22274184168402, 41.135155166271815, 42.050954239680756, 42.97008971950867, 43.89251385246176, 44.81818039613877, 45.74704454594971, 46.67906286675091, 47.61419322881803, 48.552394747815285, 49.49362772845069, 50.43785361153617, 51.38503492419651, 52.335135232994325, 53.288119099758504, 54.243952039922256, 55.202600483193066, 56.16403173639239, 57.12821394831571, 58.09511607647644, 59.064707855607665, 60.03695976780613, 61.01184301421168, 61.98932948812367, 62.96939174946366, 63.952003000500206, 64.93713706275783, 65.92476835503851, 66.91487187248843, 67.90742316664819, 68.9023983264287, 69.89977395995939, 70.89952717725848, 71.90163557367913, 72.90607721408789, 73.91283061773503, 74.9218747437793, 75.93318897743113, 76.94675311668186, 77.96254735958772, 78.98055229207962, 80.00074887627177, 81.0231184392433, 82.04764266226931, 83.07430357047842, 84.10308352291631, 85.13396520299466, 86.16693160930726, 87.20196604679543], [0.0, 0.3531011633965482, 0.8112134510823085, 1.3196071321719434, 1.863679113619431, 2.435920743173403, 3.031661083936533, 3.6476805418790703, 4.281610264113946, 4.93162629805168, 5.596276301172887, 6.274373542141128, 6.964928200052848, 7.667100769050801, 8.380169276022364, 9.103505508667, 9.836557334252223, 10.57883526104457, 11.329902032064163, 12.089364434856035, 12.856866762532375, 13.632085526556763, 14.414725132988869, 15.20451431048876, 16.001203132146333, 16.804560511624956, 17.614372082010316, 18.430438386313543, 19.25257332392717, 20.080602808932724, 20.914363605024462, 21.75370230865923, 22.598474457379098, 23.448543744450635, 24.303781324293062, 25.16406519582736, 26.02927965301934, 26.899314793624534, 27.77406607855758, 28.65343393546954, 29.537323401073994, 30.42564379755719, 31.31830843906929, 32.215234364848705, 33.11634209599747, 34.02155541332035, 34.930801153974635, 35.844009024962254, 36.7611114317398, 37.682043320430644, 38.606742032303444, 39.53514716933647, 40.467200469821904, 41.40284569308135, 42.34202851246516, 43.28469641589792, 44.23079861330988, 45.180285950362894, 46.133110827939724, 47.0892271269187, 48.048590137802925, 49.011156494814834, 49.97688411410413, 50.94573213574997, 51.91766086926777, 52.89263174235742, 53.870607252652924, 54.85155092225487, 55.83542725484621, 56.82220169520823, 57.81184059097006, 58.804311156437706, 59.79958143836223, 60.797620283517446, 61.798397307967825, 62.80188286791714, 63.8080480320361, 64.81686455517577, 65.82830485338016, 66.8423419801178, 67.85894960365826, 68.87810198552482, 69.89977395995938, 70.92394091434014, 71.95057877049732, 72.97966396687495, 74.01117344149132, 75.04508461565328, 76.0813753783827, 77.12002407151645, 78.16100947544311, 79.20431079544288, 80.2499076485984, 81.29778005124696, 82.34790840694603, 83.40027349492587, 84.45485645900442, 85.51163879694165, 86.57060235021139, 87.63172929417016, 88.69500212860373, 89.76040366863346], [0.0, 0.3632136376538791, 0.8344458161710002, 1.357399398347211, 1.9170530727395727, 2.5056831465914153, 3.118484911910813, 3.7521465686230635, 4.404231422195918, 5.072863283809827, 5.756548217266707, 6.454065504397633, 7.16439697679005, 7.8866790859546025, 8.620169182170168, 9.364221061746271, 10.118266779405406, 10.88180282484644, 11.654379418474413, 12.435592086611681, 13.225074935270763, 14.022495211517846, 14.82754885588934, 15.639956828097695, 16.459462043568923, 17.28582679787823, 18.118830584851146, 18.95826823524443, 19.803948318710017, 20.65569176367788, 21.513330658913063, 22.376707207543987, 23.245672809848276, 24.120087255400087, 24.999818008606393, 25.884739574395798, 26.77473293302572, 27.669685034758174, 28.569488346609972, 29.474040444576836, 30.383243645716096, 31.297004675289504, 32.215234364848705, 33.137847377716504, 34.06476195879652, 34.99589970604981, 35.931185361320935, 36.87054661848866, 37.81391394716752, 38.761220430401075, 39.712401614972784, 40.66739537312024, 41.62614177457696, 42.588582967986135, 43.55466307083564, 44.52432806715526, 45.49752571229699, 46.4742054441902, 47.45431830052517, 48.437816841373404, 49.424655076801436, 50.414788399077985, 51.40817351911216, 52.40476840679468, 53.40453223494405, 54.40742532658695, 55.41340910532607, 56.42244604857039, 57.43449964342283, 58.44953434503681, 59.467515537270216, 60.488409495478656, 61.51218335130318, 62.53880505931946, 63.568243365425595, 64.60046777685582, 65.63544853371569, 66.67315658194264, 67.713563547603, 68.75664171244277, 69.8023639906164, 70.85070390652218, 71.90163557367913, 72.9551336745839, 74.01117344149134, 75.06973063806535, 76.13078154185153, 77.19430292752484, 78.26027205087027, 79.3286666334559, 80.39946484796127, 81.47264530412602, 82.54818703528582, 83.6260694854653, 84.70627249699884, 85.78877629865251, 86.87356149422156, 87.96060905157974, 89.04990029215837, 90.14141688083346, 91.23514081620168, 92.33105442122614], [0.0, 0.37337326006239085, 0.8577864992670972, 1.3953678662544937, 1.97067588129356, 2.5757708085227637, 3.2057135451645196, 3.857099655199977, 4.52742428614849, 5.21475876941553, 5.917567381198964, 6.634595258038012, 7.364795751844395, 8.107281159400866, 8.861288057975692, 9.62615216860585, 10.401289659744792, 11.186182937163887, 11.980369640267964, 12.783433981652658, 13.594999832734725, 14.414725132988869, 15.242297317958789, 16.077429542187566, 16.919857530065617, 17.769336928223968, 18.625641062604462, 19.488559025076803, 20.357894030703097, 21.23346199901676, 22.11509032205737, 23.002616789141555, 23.89588864399303, 24.794761754293052, 25.699099877232122, 26.608774007456173, 27.523661796064467, 28.44364703115071, 29.368619171875213, 30.298472929282873, 31.233107888094697, 32.17242816454012, 33.11634209599747, 34.06476195879652, 35.01760371102996, 35.974786757637965, 36.93623373538318, 37.901870315635286, 38.87162502314114, 39.8454290691781, 40.82321619767788, 41.80492254307271, 42.79048649875794, 43.77984859518881, 44.7729513867367, 45.769739346524844, 46.77015876854522, 47.77415767643131, 48.78168573832522, 49.79269418733352, 50.807135747116305, 51.82496456219811, 52.84613613262818, 53.87060725265293, 54.898335953094254, 55.929281447155226, 56.96340407939966, 58.000665277674216, 59.041027507762095, 60.084454230574785, 61.13090986170554, 62.18035973318179, 63.232770057267984, 64.28810789218193, 65.34634110959826, 66.40743836382347, 67.4713690625349, 68.53810333898488, 69.60761202557887, 70.67986662874235, 71.7548393049986, 72.8325028381842, 73.91283061773504, 74.99579661797975, 76.08137537838272, 77.16954198468174, 78.26027205087027, 79.35354170197661, 80.44932755759638, 81.54760671613704, 82.64835673973569, 83.75155563981475, 84.85718186324132, 85.96521427905897, 87.07563216576243, 88.18841519908707, 89.30354344028764, 90.4209973248812, 91.54075765183187, 92.66280557315514, 93.78712258392181, 94.91369051264215], [0.0, 0.3835791712817216, 0.8812335261248793, 1.433509324373162, 2.0245430036557712, 2.646177800680516, 3.293339605560725, 3.962530924269713, 4.651178435840282, 5.357300752796954, 6.079320173342762, 6.8159475331538415, 7.566107574708379, 8.328888330008562, 9.103505508667002, 9.889276674094388, 10.68560203609483, 11.491949852343646, 12.307845123924478, 13.132860698159142, 13.966610165238244, 14.808742114638164, 15.658935438159835, 16.516895449615415, 17.382350649596244, 18.25505000549556, 19.13476064726968, 20.021265901754006, 20.914363605024466, 21.813864644896615, 22.71959169528555, 23.631378111586116, 24.5490669620302, 25.472510174537415, 26.401567782191137, 27.336107253361234, 28.276002894820657, 29.221135318087484, 30.171390960761244, 31.12666165588286, 32.08684424338808, 33.051840218586854, 34.02155541332035, 34.99589970604981, 35.974786757637965, 36.958133770012275, 37.94586126526248, 38.93789288303426, 39.9341551943457, 40.934577530179894, 41.93909182340273, 42.94763246272338, 43.960136157561365, 44.97654181281124, 45.996790412606124, 47.02082491227877, 48.04859013780293, 49.08003269207247, 50.115100867441456, 51.15374456400563, 52.19591521315763, 53.24156570599286, 54.29065032618384, 55.343124686976275, 56.39894567199231, 57.4580713795549, 58.52046107027274, 59.58607511764816, 60.65487496149136, 61.72682306394202, 62.80188286791714, 63.88001875781804, 64.96119602234378, 66.04538081927029, 67.13254014206571, 68.22264178822273, 69.31565432919771, 70.41154708185525, 71.51029008132387, 72.61185405517601, 73.71621039885194, 74.82333115225242, 75.93318897743113, 77.04575713732221, 78.16100947544314, 79.2789203965168, 80.39946484796128, 81.52261830219834, 82.64835673973569, 83.7766566329809, 84.90749493074694, 86.04084904341296, 87.17669682870545, 88.31501657806726, 89.45578700358443, 90.59898722544206, 91.74459675988243, 92.89259550764041, 94.04296374283248, 95.19568210227696, 96.35073157522464, 97.50809349348013], [0.0, 0.39383054643063836, 0.9047850016649156, 1.4718206899629958, 2.0786500860769563, 2.71689843249915, 3.381356010822189, 4.068431854469174, 4.77548386898209, 5.500477713159485, 6.241793520211594, 6.998107672152566, 7.768316174581571, 8.55148268662873, 9.346801957292554, 10.153573311471279, 10.97118092922921, 11.799078857120572, 12.636779401608308, 13.48384399411192, 14.339875897796423, 15.204514310488758, 16.077429542187566, 16.958319031046234, 17.84690402167742, 18.742926772482793, 19.6461481898321, 20.556345809845137, 21.473312065650052, 22.39685279092993, 23.326785920457713, 24.262940355954814, 25.20515497156087, 26.153277737883535, 27.1071649473094, 28.066680526223884, 29.031695422175765, 30.00208705595691, 30.97773883014603, 31.958539686959522, 32.94438370932077, 33.93516975994492, 34.930801153974635, 35.931185361320935, 36.93623373538318, 37.94586126526248, 38.95998634895545, 39.97853058533314, 41.00141858298165, 42.02857778421373, 43.05993830276175, 44.09543277383519, 45.134996215376226, 46.178565899477384, 47.22608123303861, 48.277483646840956, 49.3327164923004, 50.39172494524229, 51.45445591610394, 52.52085796603219, 53.59088122839556, 54.664477335276736, 55.74159934855295, 56.82220169520824, 57.90624010655463, 58.99367156106852, 60.08445423057479, 61.178547429534746, 62.275911567215196, 63.37650810253481, 64.48029950140139, 65.5872491963688, 66.69732154845651, 67.81048181098744, 68.92669609531109, 70.04593133828949, 71.16815527143305, 72.29333639158179, 73.42144393303575, 74.55244784104478, 75.68631874657578, 76.82302794227967, 77.96254735958772, 79.10484954687051, 80.24990764859841, 81.39769538544573, 82.54818703528582, 83.7013574150267, 84.85718186324131, 86.01563622354867, 87.17669682870545, 88.34034048537013, 89.50654445950413, 90.67528646237656, 91.84654463714166, 93.0202975459594, 94.19652415763179, 95.3752038357292, 96.55631632718249, 97.73984175131775, 98.92576058931249, 100.11405367405303], [0.0, 0.4041265929842368, 0.9284391051430984, 1.5102990012056137, 2.1329929455855927, 2.7879272366280765, 3.4697559564771074, 4.174794258689475, 4.900330975628902, 5.64427858161674, 6.404974861132203, 7.181061592392135, 7.971405918892835, 8.775047020685097, 9.591158594815333, 10.41902164819316, 11.258004261291873, 12.107546207618201, 12.967147043696293, 13.83635673529739, 14.71476817355985, 15.602011123736121, 16.49774727662647, 17.401666160406545, 18.313481732091656, 19.23292951185679, 20.159764155365213, 21.093757382787484, 22.034696200760095, 22.982381366809758, 23.936626055915966, 24.897254696719365, 25.864101950991174, 26.83701181478268, 27.81583682348324, 28.800437346059265, 29.7906809561972, 30.78644187005879, 31.787600441976515, 32.79404271074519, 33.80565999026186, 34.82234849917508, 35.844009024962254, 36.87054661848866, 37.901870315635286, 38.93789288303426, 39.97853058533314, 41.02370297173548, 42.07333267984388, 43.127345255070665, 44.18566898408764, 45.248234740963554, 46.31497584479243, 47.385827927749666, 48.4607288126291, 49.539618399016675, 50.622438557345085, 51.709133030152536, 52.79964733993776, 53.893928703064105, 54.99192594921968, 56.093589445988194, 57.19887102812749, 58.30772393119068, 59.42010272915833, 60.535963275780475, 61.65526264935372, 62.77795910068341, 63.904012004002304, 65.0333818106364, 66.16603000522692, 67.30191906433245, 68.44101241725046, 69.58327440890959, 70.72867026469676, 71.87716605709312, 73.0287286740029, 74.18332578866827, 75.34092583107102, 76.50149796072945, 77.66501204080576, 78.83143861344483, 80.00074887627177, 81.17291465997982, 82.34790840694605, 83.52570315081539, 84.70627249699884, 85.88959060403424, 87.07563216576241, 88.26437239427386, 89.45578700358442, 90.64985219400114, 91.84654463714168, 93.04584146157322, 94.24772023903907, 95.45215897124235, 96.65913607715933, 97.86863038085514, 99.08062109977773, 100.29508783350592, 101.51201055293, 102.73136958984384], [0.0, 0.41446654884158923, 0.9521940857112638, 1.5489414099829015, 2.187567559788869, 2.8592589556010206, 3.5585328992682945, 4.281610264113946, 5.025710514748705, 5.788692714202153, 6.568852117618866, 7.364795751844394, 8.17536177518464, 8.999564784215734, 9.836557334252223, 10.685602036094828, 11.546050801966281, 12.417329071455896, 13.29892359677467, 14.190372829148298, 15.091259243455164, 16.001203132146333, 16.919857530065617, 17.84690402167742, 18.782049245320472, 19.72502195420672, 20.67557052663572, 21.633460842025645, 22.5984744573791, 23.570407032418263, 24.5490669620302, 25.534274182698553, 26.52585912586173, 27.52366179606447, 28.527530955676504, 29.537323401073998, 30.552903317692635, 31.57414170339733, 32.60091585127455, 33.63310888431536, 34.6706093355815, 35.71331076837882, 36.7611114317398, 37.81391394716752, 38.87162502314114, 39.9341551943457, 41.00141858298165, 42.07333267984388, 43.149818143145865, 44.23079861330989, 45.31620054215533, 46.40595303509951, 47.49998770514327, 48.59823853755119, 49.70064176425527, 50.807135747116305, 51.91766086926778, 53.032159433848264, 54.15057556949881, 55.272855142064174, 56.39894567199231, 57.52879625697525, 58.66235749941819, 59.79958143836225, 60.94042148552092, 62.08483236512124, 63.23277005726799, 64.38419174457444, 65.5390557618252, 66.69732154845651, 67.85894960365826, 69.02390144391678, 70.19213956283399, 71.36362739307025, 72.5383292702716, 73.71621039885196, 74.89723681951169, 76.08137537838272, 77.26859369769846, 78.45886014789474, 79.65214382105464, 80.84841450561633, 82.04764266226931, 83.24979940096881, 84.45485645900442, 85.66278618006173, 86.87356149422155, 88.0871558988438, 89.30354344028764, 90.52269869642174, 91.74459675988241, 92.96921322203934, 94.19652415763177, 95.42650611003997, 96.65913607715932, 97.89439149784604, 99.13225023890575, 100.37269058259756, 101.61569121462841, 102.86123121261333, 104.10929003497915, 105.35984751029035], [0.0, 0.4248496805467505, 0.9760482583301364, 1.587745175228568, 2.2423700574830976, 2.9308885295633673, 3.647680541879071, 4.388872293840396, 5.151613592650883, 5.933709867022466, 6.733413665178238, 7.549297117483529, 8.380169276022364, 9.225020051244671, 10.082980768453053, 10.953295565523948, 11.835300118916871, 12.728405474450561, 13.632085526556763, 14.545867163835132, 15.469322401409599, 16.402062019374924, 17.343730360474378, 18.294001032291114, 19.25257332392717, 20.21916919337512, 21.193530715358836, 22.17541790415529, 23.164606844377527, 24.160888076656637, 25.16406519582736, 26.173953627458737, 27.19037955499205, 28.213178974798424, 29.242196860473236, 30.27728642088458, 31.31830843906929, 32.36513068115703, 33.41762736620561, 34.475678689227045, 35.539170390835984, 36.60799336790788, 37.682043320430644, 38.761220430401075, 39.8454290691781, 40.934577530179894, 42.02857778421373, 43.127345255070665, 44.23079861330989, 45.338859586409036, 46.45145278367346, 47.56850553448378, 48.689947738623665, 49.81571172756995, 50.94573213574997, 52.079945780878376, 53.21829155257905, 54.36071030858053, 55.50714477784592, 56.65753947006213, 57.811840590970064, 58.96999596306748, 60.13195495126107, 61.29766839308376, 62.467088533128766, 63.640168961383665, 64.81686455517578, 65.9971314244659, 67.18092686025014, 68.36820928584977, 69.55893821088837, 70.75307418777115, 71.95057877049732, 73.15141447564976, 74.3555447454183, 75.56293391252494, 76.77354716692858, 77.98735052419715, 79.20431079544291, 80.42439555872419, 81.64757313182527, 82.87381254633041, 84.10308352291631, 85.33535644779066, 86.5706023502114, 87.80879288102373, 89.04990029215837, 90.29389741703648, 91.54075765183187, 92.79045493754317, 94.04296374283247, 95.29825904758943, 96.5563163271825, 97.81711153736148, 99.08062109977773, 100.34682188809026, 101.61569121462841, 102.88720681758286, 104.16134684869924, 105.43808986144921, 106.7174147996563, 107.99930098655429], [0.0, 0.43527528164806206, 1.0000000000000002, 1.6267076567965484, 2.2973967099940706, 3.0028110849535787, 3.7371928188465535, 4.496573049932039, 5.278031643091579, 6.079320173342762, 6.898648307306076, 7.734553136131996, 8.585814486631538, 9.451397482156484, 10.33041213116187, 11.222084023041338, 12.125732532083191, 13.04075425146175, 13.966610165238242, 14.902815552092479, 15.848931924611142, 16.804560511624956, 17.769336928223968, 18.742926772482797, 19.72502195420672, 20.715337608374927, 21.713609480352545, 22.71959169528555, 23.733054843014113, 24.75378432413996, 25.781578913812194, 26.816249508234584, 27.85761802547599, 28.905516437339582, 29.95978591314941, 31.02027605959178, 32.08684424338808, 33.15935498571416, 34.237679419025724, 35.3216947983796, 36.41128406052162, 37.50633542499051, 38.606742032303444, 39.712401614972784, 40.82321619767788, 41.93909182340273, 43.05993830276175, 44.18566898408764, 45.31620054215533, 46.45145278367346, 47.59134846789699, 48.7358131409055, 49.884774982257994, 51.0381646628792, 52.19591521315763, 53.35796190034589, 54.52424211444946, 55.694695261874735, 56.86926266618194, 58.047887475353114, 59.23051457504464, 60.41709050734417, 61.607563394598245, 62.80188286791716, 64.00000000000004, 65.20186724195574, 66.40743836382347, 67.6166683985242, 68.82951358899615, 70.04593133828949, 71.26588016241398, 72.48931964575034, 73.71621039885194, 74.94651401847715, 76.1801930497052, 77.41721095000071, 78.6575320551014, 79.90112154661404, 81.14794542121197, 82.39797046133515, 83.65116420730192, 84.90749493074694, 86.16693160930726, 87.42944390248277, 88.69500212860373, 89.9635772428411, 91.23514081620166, 92.50966501545223, 93.7871225839218, 95.06748682313405, 96.35073157522464, 97.63683120610207, 98.92576058931249, 100.21749509057169, 101.51201055292998, 102.80928328253744, 104.10929003497915, 105.41200800215202, 106.7174147996563, 108.02548845467646, 109.33620739432789, 110.64955043444672], [0.0, 0.445742671182445, 1.0240477462785178, 1.6658263097965138, 2.3526439231771095, 3.0750219240468626, 3.827063883548074, 4.604705497759626, 5.404956408894633, 6.2255141224171835, 7.0645452514648985, 7.920551707527412, 8.792283975000474, 9.678682290784804, 10.57883526104457, 11.491949852343645, 12.417329071455896, 13.354355000981403, 14.302475662862857, 15.261194679324745, 16.23006301831969, 17.20867231913051, 18.196649434211395, 19.193651920024298, 20.199364277499676, 21.213494791254966, 22.235772851926882, 23.265946671925295, 24.303781324293062, 25.349057049000027, 26.401567782191133, 27.461119872550032, 28.527530955676497, 29.60062896267425, 30.680251243347538, 31.76624378776242, 32.85846053263139, 33.95676274116992, 35.061018446859684, 36.17110195301827, 37.28689338128409, 38.40827826312766, 39.53514716933647, 40.66739537312024, 41.80492254307271, 42.94763246272338, 44.09543277383519, 45.248234740963554, 46.40595303509951, 47.56850553448378, 48.7358131409055, 49.907799609995244, 51.08439139419228, 52.26551749721333, 53.45110933897867, 54.64110063006423, 55.83542725484621, 57.03402716259166, 58.23684026582466, 59.443808345364346, 60.65487496149135, 61.869985370751024, 63.089086447949235, 64.31212661293802, 65.53905576182518, 66.76982520227588, 68.00438759260301, 69.24269688437057, 70.48470826825812, 71.73037812295514, 72.97966396687495, 74.23252441249372, 75.48891912313736, 76.74880877205285, 78.012155003613, 79.27892039651681, 80.54906842885686, 81.82256344493602, 83.09937062372428, 84.37945594885414, 85.66278618006173, 86.94932882598607, 88.23905211824626, 89.53192498672158, 90.82791703596499, 92.12699852268477, 93.42914033423452, 94.73431396805448, 96.04249151201219, 97.3536456255931, 98.6677495218952, 99.98477695038488, 101.30470218037367, 102.62749998517835, 103.95314562692906, 105.28161484199215, 106.61288382697695, 107.94692922529686, 109.28372811425777, 110.62325799264747, 111.96549676880208, 113.31042274912635], [0.0, 0.4562511922728893, 1.048189988058608, 1.70509867935242, 2.4081082300145695, 3.147516515279747, 3.917288096159484, 4.713262851512922, 5.532379924945117, 6.372282539900604, 7.231094086855691, 8.107281159400866, 8.999564784215734, 9.90686021395876, 10.828234568403058, 11.762876118104394, 12.710071438006151, 13.66918804311493, 14.639660942320305, 15.62098205558745, 16.61269176479984, 17.614372082010316, 18.62564106260446, 19.6461481898321, 20.67557052663572, 21.713609480352545, 22.75998806192001, 23.814448547777808, 24.876750472493246, 25.94666889512562, 27.02399289380086, 28.108524251813055, 29.200076305464936, 30.29847292928287, 31.40354763854253, 32.51514279247822, 33.63310888431536, 34.75730390650686, 35.88759278138302, 37.023846848923306, 38.16594340459674, 39.313765281242944, 40.467200469821904, 41.62614177457696, 42.79048649875794, 43.960136157561365, 45.134996215376226, 46.31497584479243, 47.49998770514327, 48.689947738623665, 49.884774982257994, 51.08439139419228, 52.28872169295934, 53.49769320851661, 54.71123574398781, 55.92928144715521, 57.15176469084942, 58.37862196147228, 59.60979175496708, 60.84521447961779, 62.08483236512123, 63.32858937742891, 64.57643113890386, 65.82830485338017, 67.08415923575095, 68.34394444574451, 69.60761202557887, 70.87511484121192, 72.14640702692965, 73.42144393303572, 74.70018207642688, 75.98257909385565, 77.26859369769845, 78.55818563406184, 79.85131564307292, 81.14794542121196, 82.44803758555629, 83.75155563981474, 85.05846394204073, 86.36872767392042, 87.68231281154044, 88.99918609754593, 90.31931501460664, 91.64266776011415, 92.96921322203934, 94.29892095588326, 95.63176116265983, 96.96770466785267, 98.30672290129218, 99.64878787790273, 100.99387217927284, 102.34194893600444, 103.69299181080017, 105.04697498224992, 106.40387312928095, 107.76366141623694, 109.12631547855494, 110.4918114090096, 111.86012574449724, 113.2312354533326, 114.60511792303402, 115.98175094857304], [0.0, 0.4668002108286678, 1.07242526858232, 1.7445223957449545, 2.4637862837555287, 3.2202904842833084, 4.007860012495431, 4.822238560773387, 5.660294502428469, 6.519616569695026, 7.398284763817684, 8.29473022438058, 9.207644406823798, 10.135917483279927, 11.07859500432732, 12.034846472463467, 13.003941967476688, 13.985234380639895, 14.978145657640178, 15.982155971085547, 16.996795075994005, 18.02163532008724, 19.05628592778032, 20.10038827799861, 21.153611967032294, 22.215651498434912, 23.28622347885868, 24.365064225897246, 25.451927714298332, 26.546583802244612, 27.64881669112131, 28.758423581238972, 29.87521349303476, 30.99900622882456, 32.12963145457805, 33.26692788470542, 34.41074255567452, 35.56093017657099, 36.717352546584024, 37.87987803093497, 39.048381088032045, 40.22274184168402, 41.40284569308135, 42.588582967986135, 43.77984859518881, 44.97654181281124, 46.178565899477384, 47.385827927749666, 48.59823853755119, 49.81571172756995, 51.0381646628792, 52.26551749721333, 53.49769320851661, 54.73461744653689, 55.97621839137056, 57.22242662198363, 58.47317499383588, 59.72839852482646, 60.98803428885865, 62.25202131639183, 63.52030050141124, 64.79281451430089, 66.0695077201543, 67.35032610210143, 68.63521718926852, 69.92412998902313, 71.21701492318724, 72.51382376792895, 73.81450959706962, 75.11902672856382, 76.42733067393222, 77.73937809044344, 79.05512673585959, 80.37453542557394, 81.69756399198305, 83.0241732459486, 84.35432494021454, 85.68798173465613, 87.02510716324667, 88.3656656026354, 89.70962224223949, 91.05694305575823, 92.4075947740257, 93.76154485912295, 95.11876147967727, 96.47921348728013, 97.84287039396084, 99.20970235065677, 100.57968012662528, 101.95277508974567, 103.32895918766327, 104.70820492973063, 106.09048536970371, 107.47577408915365, 108.86404518155722, 110.255273237031, 111.64943332767714, 113.04650099350951, 114.44645222893223, 115.84926346974268, 117.2549115806343, 118.66337384317445], [0.0, 0.47738911433894715, 1.0967521806692804, 1.7840951699030294, 2.5196748515484266, 3.2933396055607242, 4.098774373651532, 4.93162629805168, 5.788692714202153, 6.667507657100421, 7.5661075747083775, 8.482888018555187, 9.416510761035035, 10.365840798927268, 11.329902032064165, 12.307845123924476, 13.29892359677467, 14.30247566286286, 15.317910155282778, 16.344695454869488, 17.38235064959624, 18.430438386313547, 19.488559025076803, 20.556345809845137, 21.633460842025645, 22.719591695285555, 23.814448547777808, 24.917761735720095, 26.029279653019348, 27.148766937317546, 28.276002894820657, 29.41078012552779, 30.55290331769264, 31.70218818602391, 32.8584605326314, 34.02155541332035, 35.191316394731416, 36.367594890168775, 37.5502495638722, 38.7391457950576, 39.9341551943457, 41.135155166271815, 42.34202851246516, 43.55466307083564, 44.7729513867367, 45.996790412606124, 47.22608123303861, 48.4607288126291, 49.70064176425527, 50.94573213574997, 52.19591521315763, 53.45110933897867, 54.71123574398781, 55.97621839137056, 57.24598383205949, 58.520461070272724, 59.799581438362246, 61.08327848017214, 62.37148784218912, 63.66414717183852, 64.96119602234378, 66.26257576362298, 67.56822949874655, 68.87810198552485, 70.19213956283399, 71.51029008132386, 72.83250283818421, 74.158728515673, 75.48891912313738, 76.82302794227967, 78.16100947544312, 79.50281939670917, 80.84841450561633, 82.19775268332558, 83.55079285107091, 84.90749493074695, 86.26781980749627, 87.63172929417016, 88.99918609754596, 90.37015378619226, 91.74459675988241, 93.12248022046255, 94.50377014408845, 95.88843325475048, 97.27643699901259, 98.6677495218952, 100.06233964383803, 101.46017683868185, 102.86123121261333, 104.26547348402033, 105.67287496420809, 107.08340753893087, 108.49704365069562, 109.91375628179738, 111.33351893804894, 112.7563056331687, 114.18209087379395, 115.61084964508784, 117.04255739691115, 118.47719003053056, 119.91472388583779, 121.35513572905494], [0.0, 0.4880173107514793, 1.1211693641406024, 1.8238147892132353, 2.5757708085227637, 3.366659794751756, 4.190026096377015, 5.041419947204073, 5.917567381198964, 6.815947533153841, 7.7345531361319955, 8.671744021548811, 9.626152168605852, 10.596617305309474, 11.582141600405116, 12.58185680844567, 13.594999832734725, 14.620894152025226, 15.658935438159832, 16.708580236444202, 17.769336928223964, 18.840758423480825, 19.922436185016988, 21.013995291638405, 22.11509032205737, 23.225401894339623, 24.344633734284216, 25.47251017453741, 26.608774007456173, 27.753184630769606, 28.905516437339575, 30.065557409783104, 31.233107888094693, 32.40797948420774, 33.5899941220343, 34.77898318519846, 35.97478675763796, 37.17725294464565, 38.386237263878854, 39.601602097467676, 40.82321619767788, 42.050954239680756, 43.28469641589792, 44.52432806715526, 45.769739346524844, 47.02082491227877, 48.277483646840956, 49.539618399016675, 50.807135747116305, 52.079945780878376, 53.35796190034589, 54.64110063006423, 55.92928144715521, 57.22242662198363, 58.520461070272724, 59.82331221564929, 61.13090986170554, 62.44318607276071, 63.76007506258809, 65.08151309044688, 66.40743836382346, 67.73779094734428, 69.07251267737355, 70.41154708185526, 71.7548393049986, 73.10233603644348, 74.4539854445742, 75.80973711367932, 77.16954198468176, 78.5333522991863, 79.90112154661404, 81.27280441421077, 82.64835673973569, 84.02773546665075, 85.4108986016463, 86.79780517435115, 88.18841519908707, 89.58268963853824, 90.98059036921653, 92.38208014861125, 93.7871225839218, 95.19568210227695, 96.60772392235377, 98.02321402731307, 99.44211913897601, 100.86440669317011, 102.29004481617913, 103.71900230223468, 105.15124859199233, 106.58675375193829, 108.02548845467645, 109.46742396004878, 110.91253209704495, 112.36078524646018, 113.81215632426262, 115.26661876563354, 116.72414650964713, 118.18471398455686, 119.64829609365954, 121.11486820170758, 122.58440612184361, 124.05688610303213], [0.0, 0.4986842274289281, 1.1456755034211543, 1.8636791136194315, 2.6320711322805597, 3.440247101432813, 4.281610264113947, 5.151613592650883, 6.046911559771726, 6.964928200052847, 7.903612372398381, 8.861288057975692, 9.836557334252225, 10.828234568403058, 11.835300118916871, 12.856866762532377, 13.892154723044674, 14.940472692034996, 16.00120313214633, 17.073790710036153, 18.15773306141647, 19.25257332392717, 20.357894030703097, 21.473312065650052, 22.5984744573791, 23.733054843014113, 24.876750472493246, 26.029279653019344, 27.190379554992052, 28.359804317137723, 29.537323401073994, 30.72272015521393, 31.91579055545142, 33.11634209599747, 34.32419280843745, 35.539170390835984, 36.7611114317398, 37.98986071637883, 39.22527060436438, 40.46720046982191, 41.71551619624876, 42.97008971950867, 44.23079861330988, 45.49752571229699, 46.77015876854522, 48.04859013780293, 49.3327164923004, 50.622438557345085, 51.91766086926778, 53.21829155257905, 54.52424211444946, 55.83542725484621, 57.15176469084942, 58.47317499383588, 59.799581438362246, 61.13090986170554, 62.467088533128766, 63.8080480320361, 65.15372113426784, 66.50404270585967, 67.85894960365826, 69.21838058224296, 70.582276206657, 71.95057877049733, 73.32323221895392, 74.7001820764269, 76.08137537838272, 77.46676060714044, 78.85628763130633, 80.24990764859841, 81.64757313182527, 83.04923777780198, 84.45485645900442, 85.86438517777938, 87.2777810229417, 88.69500212860373, 90.11600763509387, 91.54075765183187, 92.96921322203936, 94.40133628917154, 95.83708966496624, 97.27643699901257, 98.71934274974923, 100.1657721568085, 101.61569121462841, 103.06906664725986, 104.52586588430172, 105.98605703790055, 107.4496088807561, 108.91649082507803, 110.38667290244197, 111.86012574449724, 113.33682056448116, 114.81672913949775, 116.29982379352157, 117.78607738108911, 119.27546327164369, 120.76795533450024, 122.26352792440035, 123.76215586762753, 125.2638144486563, 126.76847939730912], [0.0, 0.5093893101761645, 1.1702693253048695, 1.9036860719875615, 2.6885728977623873, 3.5140977024066067, 4.3735221186457585, 5.262201509328025, 6.176718529898532, 7.114441917570115, 8.07327650010666, 9.051510280155853, 10.047715326463061, 11.060680554631407, 12.089364434856037, 13.13286069815914, 14.190372829148298, 15.261194679324747, 16.344695454869488, 17.440307901290176, 18.547518870217484, 19.665861691984187, 20.79490993810756, 21.93427226827201, 23.083588133973233, 24.24252416641551, 25.410771116505586, 26.588041244443932, 27.77406607855758, 28.96859447975352, 30.17139096076124, 31.382234219208716, 32.60091585127455, 33.8272392187142, 35.061018446859684, 36.302077535029255, 37.55024956387219, 38.80537598667636, 40.06730599370764, 41.33589594032421, 42.611008830990585, 43.89251385246176, 45.180285950362894, 46.4742054441902, 47.77415767643131, 49.08003269207247, 50.39172494524229, 51.709133030152536, 53.032159433848264, 54.36071030858053, 55.694695261874735, 57.03402716259166, 58.37862196147228, 59.72839852482646, 61.08327848017214, 62.44318607276071, 63.8080480320361, 65.17779344717444, 66.55235365093813, 67.93166211115445, 69.31565432919771, 70.70426774491288, 72.09744164747345, 73.49511709171283, 74.89723681951169, 76.30374518586119, 77.7145880892564, 79.12971290610398, 80.54906842885686, 81.97260480761123, 83.40027349492587, 84.83202719364125, 86.26781980749625, 87.70760639435517, 89.15134312187318, 90.59898722544206, 92.05049696826964, 93.50583160345836, 94.96495133795808, 96.42781729827723, 97.89439149784604, 99.36463680593182, 100.8385169180148, 102.31599632753843, 103.79704029895504, 105.28161484199214, 106.76968668707106, 108.26122326181273, 109.75619266857123, 111.25456366293864, 112.7563056331687, 114.26138858047048, 115.76978310012575, 117.28146036338737, 118.79639210011814, 120.31455058213226, 121.835908607204, 123.36043948370992, 124.88811701587363, 126.41891548958317, 127.95280965875335, 129.48977473220705], [0.0, 0.5201320223325415, 1.1949495968693433, 1.9438336587133092, 2.7452732724563695, 3.5882078954400733, 4.465757052303693, 5.373178153309842, 6.306981784175918, 7.264481190375599, 8.243537013758772, 9.242401151985442, 10.259615559595321, 11.293943611154814, 12.344321811626047, 13.409824779367144, 14.489639200958287, 15.583044035656389, 16.689395186582708, 17.808113436191082, 18.938674814123743, 20.080602808932724, 21.23346199901676, 22.396852790929934, 23.570407032418263, 24.75378432413996, 25.94666889512562, 27.148766937317543, 28.359804317137723, 29.579524599121708, 30.807687329715037, 32.04406653941263, 33.28844942928268, 34.540635214099105, 35.80043409920971, 37.06766637218493, 38.34216159344599, 39.62375787262658, 40.912301219506595, 42.20764496006568, 43.50964920961545, 44.81818039613877, 46.133110827939724, 47.45431830052517, 48.78168573832522, 50.115100867441456, 51.45445591610394, 52.79964733993776, 54.15057556949881, 55.50714477784592, 56.86926266618194, 58.23684026582466, 59.60979175496708, 60.98803428885865, 62.37148784218912, 63.76007506258809, 65.15372113426784, 66.55235365093813, 67.95590249721089, 69.36429973779019, 70.77747951381333, 72.19537794576952, 73.61793304247767, 75.04508461565331, 76.47677419963802, 77.91294497590343, 79.35354170197661, 80.79851064446453, 82.24779951588391, 83.7013574150267, 85.1591347706155, 86.62108328802232, 88.0871558988438, 89.55730671314183, 91.03149097417395, 92.50966501545223, 93.99178621998085, 95.47781298153483, 96.9677046678527, 98.46142158562448, 99.95892494716665, 101.46017683868183, 102.96514019000995, 104.47377874578264, 105.98605703790057, 107.50194035925698, 109.02139473863792, 110.5443869167326, 112.07088432319301, 113.60085505468562, 115.13426785388096, 116.67109208933176, 118.21129773619211, 119.754855357734, 121.30173608762018, 122.8519116128942, 124.40535415765186, 125.96203646735952, 127.52193179378776, 129.08501388052952, 130.651256949075, 132.22063568541614], [0.0, 0.5309118439237587, 1.2197151235273287, 1.984119930552453, 2.802169511921696, 3.6625740934133852, 4.558310600684869, 5.484538153047513, 6.437695017534593, 7.415038756190947, 8.414385672317426, 9.433951433865923, 10.472247777144512, 11.528012447454376, 12.600159908648312, 13.687745600397925, 14.789939353229194, 15.906005182711201, 17.035285642951603, 18.177189512025468, 19.331181960203295, 20.4967766002591, 21.673528986407415, 22.861031243562522, 24.058907589454513, 25.26681056990934, 26.484417869552374, 27.71142959110568, 28.94756591952782, 30.19256510468722, 31.446181709590007, 32.708185081476, 33.97835801112058, 35.256495551990874, 36.54240397590935, 37.83589984587682, 39.13680918992624, 40.444966762486885, 41.76021538186603, 43.082405334200175, 44.41139383566778, 45.74704454594971, 47.0892271269187, 48.437816841373404, 49.79269418733352, 51.15374456400563, 52.52085796603219, 53.893928703064105, 55.272855142064174, 56.65753947006213, 58.047887475353114, 59.443808345364346, 60.84521447961779, 62.25202131639183, 63.66414717183852, 65.08151309044688, 66.50404270585967, 67.93166211115445, 69.36429973779019, 70.80188624250079, 72.2443544014878, 73.69163901132707, 75.1436767960601, 76.60040631999038, 78.06176790574908, 79.52770355723452, 80.9981568870644, 82.47307304821234, 83.95239866952836, 85.43608179486853, 86.92407182558254, 88.41631946612837, 89.91277667260223, 91.4133966039895, 92.91813357595689, 94.42694301702134, 95.9397814269428, 97.45660633720043, 98.97737627342246, 100.50205071964857, 102.03059008431408, 103.56295566785201, 105.09910963181706, 106.63901496944241, 108.18263547754657, 109.72993572971228, 111.28088105066662, 112.83543749179408, 114.39357180772087, 115.95525143391161, 117.52044446522358, 119.08911963536771, 120.6612462972282, 122.23679440399607, 123.81573449107447, 125.39803765871625, 126.98367555535707, 128.57262036160859, 130.16484477487992, 131.7603219945957, 133.35902570798223, 134.96093007639453], [0.0, 0.5417282708684605, 1.244564747203978, 2.0245430036557712, 2.8592589556010206, 3.7371928188465526, 4.651178435840282, 5.596276301172887, 6.568852117618866, 7.5661075747083775, 8.585814486631536, 9.626152168605852, 10.68560203609483, 11.762876118104396, 12.856866762532377, 13.966610165238242, 15.091259243455166, 16.23006301831969, 17.38235064959624, 18.547518870217484, 19.725021954206717, 20.914363605024462, 22.11509032205737, 23.326785920457716, 24.5490669620302, 25.781578913812197, 27.023992893800862, 28.276002894820653, 29.537323401073998, 30.807687329715037, 32.08684424338808, 33.37455879017477, 34.6706093355815, 35.974786757637965, 37.286893381284095, 38.606742032303444, 39.93415519434569, 41.2689642552423, 42.611008830990585, 43.960136157561365, 45.31620054215532, 46.67906286675091, 48.048590137802925, 49.424655076801436, 50.807135747116305, 52.19591521315763, 53.59088122839556, 54.99192594921968, 56.39894567199231, 57.811840590970064, 59.23051457504464, 60.65487496149135, 62.08483236512123, 63.52030050141124, 64.96119602234378, 66.40743836382346, 67.85894960365826, 69.31565432919771, 70.77747951381333, 72.2443544014878, 73.71621039885194, 75.19298097407264, 76.6746015620512, 78.16100947544314, 79.65214382105464, 81.14794542121196, 82.6483567397357, 84.15332181218446, 85.66278618006174, 87.17669682870545, 88.69500212860372, 90.21765177990162, 91.74459675988241, 93.27578927322539, 94.81118270485656, 96.35073157522464, 97.89439149784604, 99.44211913897601, 100.99387217927287, 102.54960927733241, 104.10929003497914, 105.67287496420808, 107.24032545567992, 108.81160374867783, 110.38667290244197, 111.96549676880205, 113.54803996603535, 115.13426785388096, 116.72414650964711, 118.31764270535132, 119.91472388583777, 121.51535814781988, 123.11951421979893, 124.72716144281324, 126.33826975197483, 127.95280965875334, 129.57075223396944, 131.192069091462, 132.81673237239627, 134.44471473018064, 136.07598931596337, 137.71052976468098], [0.0, 0.5525808142351797, 1.2694973446297464, 2.0651010507920944, 2.9165390228985877, 3.812060698773335, 4.744356359895056, 5.708387546822403, 6.700447155776535, 7.717680817212685, 8.757815707659557, 9.818994668217245, 10.899668692262344, 11.998524006637924, 13.11443076944091, 14.246405868462878, 15.393585251170139, 16.555202894199763, 17.73057451824877, 18.919084770888286, 20.120176993511453, 21.33334494717777, 22.558126046211616, 23.794095768256685, 25.040862993628878, 26.298066086940686, 27.565369577634836, 28.84246132823704, 30.12905010315855, 31.424863469033113, 32.729645971446836, 34.04315754363254, 35.36517211105152, 36.69547636235408, 38.033868662418854, 39.38015808733345, 40.73416356452942, 42.09571310399926, 43.46464310873767, 44.84079775436522, 46.22402842939161, 47.61419322881803, 49.011156494814834, 50.414788399077985, 51.82496456219811, 53.24156570599286, 54.664477335276736, 56.093589445988194, 57.52879625697525, 58.96999596306748, 60.41709050734417, 61.869985370751024, 63.32858937742891, 64.79281451430089, 66.26257576362298, 67.73779094734428, 69.21838058224296, 70.70426774491288, 72.19537794576952, 73.69163901132707, 75.19298097407264, 76.69933596932846, 78.21063813855122, 79.72682353856918, 81.24783005630381, 82.77359732856404, 84.30406666653744, 85.83918098463653, 87.37888473338764, 88.92312383607603, 90.47184562888624, 92.02499880429694, 93.58253335751023, 95.14440053571278, 96.71055278998217, 98.2809437296668, 99.85552807908036, 101.43426163636512, 103.01710123438816, 104.60400470354523, 106.19493083635665, 107.78983935374686, 109.38869087290848, 110.99144687665724, 112.59806968419213, 114.20852242317983, 115.82276900308898, 117.44077408970392, 119.06250308075322, 120.68792208259205, 122.31699788788112, 123.94969795420931, 125.5859903836102, 127.22584390292538, 128.8692278449714, 130.51611213046863, 132.16646725069413, 133.82026425082154, 135.47747471391483, 137.13807074554308, 138.80202495898646, 140.46931046100528], [0.0, 0.5634689995456557, 1.2945118257398396, 2.1057922987446758, 2.9740072095031245, 3.887174459935085, 4.837840299066869, 5.820866988440081, 6.832474378611124, 7.869751856850977, 8.930381815427841, 10.012470501536031, 11.114438386552953, 12.23494581041931, 13.372840668555337, 14.527120477273126, 15.696904158539978, 16.881410595084322, 18.079942024399156, 19.291870969003305, 20.516629801754796, 21.753702308659232, 23.00261678914156, 24.262940355954818, 25.534274182698557, 26.816249508234588, 28.10852425181306, 29.410780125527793, 30.722720155213935, 32.04406653941263, 33.37455879017477, 34.713952110399816, 36.06201597092198, 37.4185328572534, 38.783297161205766, 40.15611419685599, 41.53679932373816, 42.925177162912284, 44.32108089381831, 45.724351621675766, 47.13483780671776, 48.552394747815285, 49.97688411410413, 51.40817351911216, 52.84613613262818, 54.29065032618384, 55.74159934855295, 57.19887102812749, 58.66235749941819, 60.13195495126107, 61.607563394598245, 63.089086447949235, 64.57643113890386, 66.0695077201543, 67.56822949874655, 69.07251267737355, 70.582276206657, 72.09744164747345, 73.61793304247767, 75.1436767960601, 76.6746015620512, 78.21063813855122, 79.75171936932426, 81.29778005124697, 82.84875684734978, 84.40458820503075, 85.96521427905898, 87.53057685901885, 89.10061930087649, 90.67528646237656, 92.25452464200312, 93.83828152125908, 95.42650611003997, 97.0191486948953, 98.61616078998729, 100.2174950905717, 101.82310542883926, 103.43294673196816, 105.04697498224995, 106.66514717916033, 108.2874213032575, 109.91375628179738, 111.5441119559642, 113.17844904962185, 114.81672913949777, 116.4589146267173, 118.10496870961256, 119.754855357734, 121.40853928699873, 123.06598593591339, 124.72716144281324, 126.39203262406372, 128.06056695317318, 129.73273254076935, 131.40849811539525, 133.08783300508188, 134.77070711965933, 136.45709093376837, 138.14695547053884, 139.84027228590116, 141.53701345350112, 143.23715155018806], [0.0, 0.574392366120934, 1.3196071321719434, 2.146615025867435, 3.031661083936533, 3.9625309242697133, 4.931626298051682, 5.933709867022467, 6.964928200052848, 8.022314259499884, 9.103505508667002, 10.206571482602653, 11.329902032064169, 12.472131526445644, 13.632085526556766, 14.808742114638164, 16.001203132146337, 17.208672319130518, 18.430438386313547, 19.66586169198419, 20.914363605024466, 22.175417904155292, 23.44854374445064, 24.733299846744757, 26.02927965301935, 27.33610725336124, 28.653433935469543, 29.980935241133263, 31.318308439069302, 32.665270342381135, 34.02155541332036, 35.38691410916872, 36.761111431739806, 38.143925649826656, 39.53514716933648, 40.934577530179894, 42.34202851246517, 43.757321337369696, 45.1802859503629, 46.610760376342355, 48.04859013780293, 49.49362772845069, 50.94573213574997, 52.40476840679468, 53.87060725265293, 55.343124686976275, 56.82220169520824, 58.30772393119068, 59.79958143836225, 61.29766839308376, 62.80188286791716, 64.31212661293802, 65.82830485338017, 67.35032610210143, 68.87810198552485, 70.41154708185526, 71.95057877049733, 73.49511709171283, 75.04508461565331, 76.60040631999038, 78.16100947544314, 79.72682353856918, 81.29778005124697, 82.87381254633046, 84.45485645900443, 86.04084904341298, 87.63172929417019, 89.22743787239777, 90.827917035965, 92.43311057363304, 94.04296374283248, 95.65742321082391, 97.2764369990126, 98.89995443020696, 100.52792607862646, 102.16030372248079, 103.79704029895505, 105.43808986144921, 107.0834075389309, 108.73294949727098, 110.38667290244199, 112.04453588546677, 113.7064975090139, 115.37251773554308, 117.04255739691118, 118.71657816535465, 120.39454252577129, 122.07641374922805, 123.76215586762754, 125.45173364946993, 127.14511257665089, 128.84225882224047, 130.5431392291909, 132.2477212899251, 133.95597312675997, 135.66786347312214, 137.38336165551593, 139.10243757620577, 140.82506169657813, 142.55120502114897, 144.28083908218585, 146.01393592491505], [0.0, 0.5853504664669777, 1.3447822358547292, 2.1875675597888695, 3.0894982843111247, 4.038127004673238, 5.025710514748705, 6.046911559771726, 7.097803193908702, 8.175361775184639, 9.277179695074507, 10.401289659744792, 11.546050801966281, 12.710071438006151, 13.892154723044674, 15.091259243455164, 16.306469705871258, 17.536974659512794, 18.78204924532047, 20.04104161867355, 21.31336210948796, 22.598474457379098, 23.89588864399303, 25.205154971560873, 26.52585912586173, 27.85761802547599, 29.200076305464936, 30.552903317692635, 31.91579055545142, 33.28844942928268, 34.670609335581496, 36.062015970921976, 37.462429853886604, 38.87162502314114, 40.289387886014076, 41.71551619624876, 43.14981814314586, 44.592111537189346, 46.042223079594855, 47.499987705143276, 48.96524798924993, 50.43785361153617, 51.91766086926777, 53.40453223494405, 54.898335953094254, 56.39894567199231, 57.90624010655463, 59.42010272915833, 60.94042148552092, 62.467088533128766, 64.00000000000004, 65.53905576182518, 67.08415923575095, 68.63521718926852, 70.19213956283399, 71.7548393049986, 73.32323221895392, 74.89723681951169, 76.47677419963802, 78.06176790574908, 79.65214382105464, 81.24783005630381, 82.84875684734978, 84.45485645900443, 86.06606309470271, 87.68231281154044, 89.30354344028764, 90.92969451001517, 92.56070717700369, 94.19652415763177, 95.83708966496624, 97.48234934880027, 99.13225023890574, 100.78674069128547, 102.44577033722743, 104.10929003497915, 105.77725182387428, 107.44960888075609, 109.12631547855496, 110.8073269468862, 112.49259963454655, 114.18209087379392, 115.87575894630572, 117.57356305071639, 119.27546327164367, 120.98142055011746, 122.69139665533272, 124.40535415765184, 126.1232564027879, 127.84506748710419, 129.57075223396942, 131.30027617111273, 133.0336055089253, 134.77070711965933, 136.51154851747802, 138.2560978393129, 140.00432382648773, 141.75619580707058, 143.51168367891833, 145.27075789337903, 147.0333894396206, 148.79954982955587], [0.0, 0.5963428656968237, 1.3700361376803187, 2.2286482752525445, 3.1475165152797473, 4.113959701013448, 5.120089215299155, 6.160467574126301, 7.231094086855692, 8.328888330008562, 9.451397482156484, 10.596617305309476, 11.762876118104398, 12.948756102135157, 14.153037936822916, 15.374660651651567, 16.612691764799845, 17.86630458711085, 19.134760647269676, 20.41739585955096, 21.713609480352545, 23.02285517876185, 24.34463373428422, 25.678487004197365, 27.023992893800862, 28.380761127721833, 29.74842966756095, 31.126661655882856, 32.51514279247823, 33.913579068416325, 35.321694798379596, 36.73923090333345, 38.165943404596746, 39.60160209746768, 41.04598937818044, 42.49889920246037, 43.960136157561365, 45.42951463259844, 46.90685807437894, 48.39199831789499, 49.884774982257994, 51.38503492419651, 52.89263174235742, 54.40742532658695, 55.929281447155226, 57.4580713795549, 58.99367156106852, 60.535963275780475, 62.08483236512124, 63.640168961383665, 65.20186724195574, 66.76982520227588, 68.34394444574451, 69.92412998902313, 71.51029008132386, 73.10233603644348, 74.7001820764269, 76.30374518586119, 77.91294497590343, 79.52770355723452, 81.14794542121196, 82.77359732856404, 84.40458820503075, 86.04084904341298, 87.68231281154044, 89.32891436571391, 90.98059036921653, 92.63727921552493, 94.29892095588328, 95.96545723093091, 97.63683120610207, 99.31298751053782, 100.99387217927286, 102.67943259847827, 104.36961745355914, 106.06437667992142, 107.76366141623697, 109.46742396004878, 111.17561772557053, 112.88819720354458, 114.60511792303402, 116.32633641503175, 118.05181017777946, 119.78149764369557, 121.5153581478199, 123.25335189768701, 124.99543994454892, 126.74158415587024, 128.4917471890268, 130.24589246614116, 132.00398414999387, 133.76598712095327, 135.53186695486957, 137.30158990188312, 139.07512286609992, 140.85243338608933, 142.6334896161629, 144.4182603083952, 146.20671479534957, 147.99882297347477, 149.79455528713925, 151.593882713273], [0.0, 0.60736914098658, 1.3953678662544935, 2.2698555920840464, 3.2057135451645196, 4.190026096377015, 5.214758769415531, 6.274373542141129, 7.364795751844394, 8.482888018555187, 9.626152168605852, 10.792546905996504, 11.980369640267968, 13.188176337799783, 14.41472513298887, 15.658935438159835, 16.919857530065617, 18.196649434211395, 19.488559025076803, 20.794909938107562, 22.11509032205737, 23.448543744450635, 24.794761754293052, 26.153277737883535, 27.52366179606447, 28.905516437339585, 30.29847292928287, 31.702188186023907, 33.116342095997474, 34.540635214099105, 35.97478675763796, 37.418532857253396, 38.87162502314114, 40.33382879415472, 41.80492254307272, 43.284696415897926, 44.77295138673669, 46.269498412791265, 47.77415767643131, 49.28675790330738, 50.807135747116305, 52.335135232994325, 53.870607252652924, 55.41340910532607, 56.96340407939966, 58.52046107027274, 60.08445423057479, 61.65526264935372, 63.23277005726799, 64.81686455517578, 66.40743836382347, 68.00438759260301, 69.60761202557887, 71.21701492318724, 72.83250283818421, 74.4539854445742, 76.08137537838272, 77.7145880892564, 79.35354170197661, 80.9981568870644, 82.6483567397357, 84.30406666653744, 85.96521427905898, 87.63172929417019, 89.30354344028764, 90.98059036921653, 92.66280557315515, 94.35012630648633, 96.04249151201222, 97.73984175131775, 99.44211913897603, 101.14926728033058, 102.86123121261333, 104.57795734917492, 106.29939342662252, 108.02548845467648, 109.75619266857126, 111.49145748383977, 113.23123545333263, 114.975480226334, 116.72414650964713, 118.47719003053056, 120.23456750137592, 121.99623658602432, 123.76215586762754, 125.53228481796448, 127.30658376813156, 129.08501388052952, 130.86753712207556, 132.65411623857372, 134.44471473018064, 136.2392968279088, 138.03782747111183, 139.8402722859012, 141.64659756444553, 143.45677024510803, 145.27075789337906, 147.08852868356445, 148.9100513811921, 150.73529532610132, 152.56423041618206, 154.39682709173286], [0.0, 0.6184288810627978, 1.420776476718986, 2.311187973275197, 3.264087203251165, 4.2663233535330605, 5.309715645980302, 6.388625215191987, 7.498903201882973, 8.637355096728584, 9.801437236177723, 10.989071153749402, 12.198523256079184, 13.428323214768984, 14.677206550767231, 15.944072999701095, 17.227955544569944, 18.52799687914996, 19.843431182274763, 21.173569773294858, 22.517789659608074, 23.875524276517506, 25.246255914514617, 26.62950946321006, 28.02484719530247, 29.431864381271232, 30.850185574347257, 32.279461441321736, 33.71936604163605, 35.169594477513236, 36.629860853418585, 38.099896495126764, 39.57944838801909, 41.06827780158606, 42.56615907293953, 44.07287852679711, 45.588233513151785, 47.112031546877105, 48.6440895359975, 50.1842330873851, 51.732295880322084, 53.288119099758504, 54.85155092225487, 56.42244604857039, 58.000665277674216, 59.58607511764816, 61.178547429534746, 62.77795910068341, 64.38419174457444, 65.9971314244659, 67.6166683985242, 69.24269688437057, 70.87511484121192, 72.51382376792895, 74.158728515673, 75.80973711367932, 77.46676060714044, 79.12971290610398, 80.79851064446453, 82.47307304821234, 84.15332181218446, 85.83918098463653, 87.53057685901885, 89.22743787239777, 90.92969451001517, 92.63727921552493, 94.35012630648633, 96.0681718947312, 97.7913538112555, 99.51961153531494, 101.25288612743199, 102.99112016604553, 104.73425768755634, 106.48224412954204, 108.23502627693232, 109.9925522109525, 111.75477126065766, 113.52163395689375, 115.2930919885341, 117.06909816085083, 118.84960635589175, 120.63457149474178, 122.42394950155737, 124.2176972692697, 126.01577262686057, 127.81813430812011, 129.62474192180355, 131.43555592310784, 133.25053758639604, 135.069648979101, 136.8928529367444, 138.72011303901203, 140.5513935868293, 142.3866595803847, 144.2258766980524, 146.06901127616766, 147.9160302896127, 149.7669013331711, 151.62159260361423, 153.48007288248272, 155.34231151952952, 157.20827841679295], [0.0, 0.6295216857189695, 1.4462610496406818, 2.35264392317711, 3.322635377237073, 4.342848711597637, 5.404956408894634, 6.503218458980712, 7.633411584174358, 8.792283975000474, 9.977246342026397, 11.186182937163888, 12.417329071455898, 13.669188043114932, 14.940472692034996, 16.23006301831969, 17.536974659512797, 18.860334931825253, 20.199364277499676, 21.553361662970744, 22.921692920971818, 24.30378132429306, 25.699099877232122, 27.1071649473094, 28.5275309556765, 29.95978591314941, 31.403547638542527, 32.8584605326314, 34.32419280843745, 35.80043409920971, 37.28689338128409, 38.78329716120576, 40.289387886014076, 41.80492254307272, 43.329671421761574, 44.86341701408892, 46.40595303509951, 47.957083547046935, 49.51662217382131, 51.08439139419229, 52.66022190413503, 54.243952039922256, 55.83542725484621, 57.43449964342283, 59.041027507762095, 60.65487496149136, 62.275911567215196, 63.904012004002304, 65.5390557618252, 67.18092686025014, 68.82951358899615, 70.48470826825812, 72.14640702692965, 73.81450959706962, 75.48891912313738, 77.16954198468176, 78.85628763130633, 80.54906842885686, 82.24779951588391, 83.95239866952836, 85.66278618006174, 87.37888473338764, 89.10061930087649, 90.827917035965, 92.56070717700369, 94.29892095588328, 96.04249151201222, 97.7913538112555, 99.54544456947913, 101.30470218037367, 103.06906664725987, 104.83847951860177, 106.61288382697694, 108.3922240312728, 110.17644596189639, 111.96549676880208, 113.75932487215651, 115.5578799154737, 117.36111272106677, 119.16897524767246, 120.98142055011749, 122.79840274090292, 124.61987695359353, 126.44579930790583, 128.27612687639692, 130.11081765266192, 131.94983052095523, 133.79312522715577, 135.64066235100202, 137.4924032795275, 139.34831018163194, 141.20834598372724, 143.07247434640186, 144.94065964205006, 146.81286693341647, 148.68906195300877, 150.56921108333512, 152.45328133792432, 154.34124034309093, 156.2330563204077, 158.1286980698519, 160.02813495359246], [0.0, 0.6406471653590878, 1.4718206899629955, 2.3942219857943834, 3.3813560108221883, 4.419599482884906, 5.500477713159486, 6.618149248819984, 7.768316174581569, 8.9476692120353, 10.153573311471279, 11.383875333377244, 12.63677940160831, 13.910762363302073, 15.20451431048876, 16.516895449615408, 17.84690402167742, 19.193651920024298, 20.556345809845133, 21.934272268272007, 23.326785920457713, 24.73329984674475, 26.15327773788353, 27.586227414201524, 29.031695422175765, 30.48926249157477, 31.95853968695952, 33.439165124632716, 34.930801153974635, 36.43313192315085, 37.94586126526247, 39.468710853429656, 41.00141858298164, 42.543737146541844, 44.09543277383519, 45.65628411287096, 47.226081233038606, 48.8046247338017, 50.39172494524229, 51.98720120881341, 53.59088122839555, 55.202600483193066, 56.82220169520823, 58.44953434503681, 60.084454230574785, 61.72682306394202, 63.37650810253481, 65.0333818106364, 66.69732154845651, 68.36820928584977, 70.04593133828949, 71.73037812295514, 73.42144393303572, 75.11902672856382, 76.82302794227967, 78.5333522991863, 80.24990764859841, 81.97260480761123, 83.7013574150267, 85.43608179486853, 87.17669682870545, 88.92312383607603, 90.67528646237656, 92.43311057363304, 94.19652415763177, 95.96545723093091, 97.73984175131775, 99.51961153531494, 101.30470218037367, 103.09505099142183, 104.89059691146427, 106.69128045595637, 108.4970436506956, 110.30782997299633, 112.12358429593127, 113.94425283544079, 115.76978310012576, 117.60012384355463, 119.4352250189277, 121.27503773595281, 123.11951421979892, 124.96860777200148, 126.82227273320483, 128.6804644476332, 130.54313922919087, 132.4102543290976, 134.28176790497298, 136.15763899128845, 138.0378274711118, 139.92229404907312, 141.81100022548648, 143.70390827156567, 145.600981205676, 147.5021827705683, 149.40747741154428, 151.3168302555053, 153.23020709084062, 155.14757434811216, 157.0688990814973, 158.9941489509515, 160.9232922050568, 162.85629766452263], [0.0, 0.6518049405663864, 1.4974545260150967, 2.4359207431734036, 3.440247101432813, 4.496573049932039, 5.596276301172888, 6.733413665178238, 7.903612372398381, 9.103505508667, 10.330412131161868, 11.582141600405118, 12.856866762532379, 14.153037936822914, 15.469322401409599, 16.804560511624956, 18.15773306141647, 19.52793647650201, 20.91436360502446, 22.31628859884905, 23.733054843014106, 25.164065195827355, 26.608774007456173, 28.066680526223887, 29.537323401073998, 31.02027605959178, 32.51514279247822, 34.02155541332035, 35.539170390835984, 37.06766637218493, 38.606742032303444, 40.15611419685598, 41.71551619624876, 43.284696415897926, 44.86341701408892, 46.45145278367345, 48.04859013780292, 49.65462620309893, 51.26936800627399, 52.89263174235743, 54.52424211444945, 56.16403173639239, 57.81184059097006, 59.467515537270216, 61.13090986170554, 62.80188286791714, 64.48029950140139, 66.16603000522692, 67.85894960365826, 69.55893821088837, 71.26588016241398, 72.97966396687495, 74.70018207642688, 76.42733067393222, 78.16100947544312, 79.90112154661404, 81.64757313182527, 83.40027349492587, 85.1591347706155, 86.92407182558254, 88.69500212860372, 90.47184562888624, 92.25452464200312, 94.04296374283248, 95.83708966496624, 97.63683120610207, 99.44211913897603, 101.25288612743199, 103.06906664725987, 104.89059691146427, 106.71741479965628, 108.5494597912839, 110.38667290244197, 112.22899662602246, 114.07637487498484, 115.92875292854404, 117.78607738108911, 119.64829609365954, 121.5153581478199, 123.38721380178455, 125.26381444865629, 127.14511257665086, 129.03106173119042, 130.92161647875582, 132.81673237239627, 134.71636591880113, 136.62047454684586, 138.52901657752935, 140.44195119522638, 142.35923842018263, 144.2808390821858, 146.20671479534957, 148.13682793395185, 150.07114160927227, 152.00961964737724, 153.95222656780388, 155.8989275630979, 157.84968847916213, 159.80447579637575, 161.76325661144682, 163.72599861996156, 165.69267009959793], [0.0, 0.6629946416955279, 1.5231617085750033, 2.4777388138782706, 3.4993066980691596, 4.573766862685852, 5.692348999228549, 6.849007889466797, 8.0392956954043, 9.259787702203246, 10.507756942614376, 11.780975169894962, 13.077583862965707, 14.396006737342953, 15.734888191984453, 17.09304867430789, 18.469451481291333, 19.863177526763216, 21.27340580228529, 22.699397998903308, 24.14048622937962, 25.596063100738697, 27.065573595838515, 28.548508366471065, 30.044398141448955, 31.552809025280375, 33.07333851542417, 34.60561210471759, 36.149280364389625, 37.70401642485415, 39.269513788123454, 40.845484418536174, 42.431657068513815, 44.027775803941, 45.63359870001397, 47.24889668339608, 48.87345250053899, 50.50705979528543, 52.149522281526444, 53.80065299886468, 55.4602736410339, 57.12821394831571, 58.804311156437706, 60.488409495478656, 62.18035973318179, 63.88001875781804, 65.5872491963688, 67.30191906433245, 69.02390144391678, 70.75307418777115, 72.48931964575034, 74.23252441249372, 75.98257909385565, 77.73937809044344, 79.50281939670917, 81.27280441421077, 83.04923777780198, 84.83202719364125, 86.62108328802232, 88.41631946612837, 90.21765177990162, 92.02499880429694, 93.83828152125908, 95.65742321082391, 97.48234934880027, 99.31298751053782, 101.14926728033058, 102.99112016604553, 104.83847951860177, 106.69128045595637, 108.5494597912839, 110.41295596506063, 112.28170898078974, 114.15566034412407, 116.03475300516253, 117.91893130371452, 119.80814091734132, 121.70232881199964, 123.60144319512433, 125.50543347099989, 127.41425019828213, 129.32784504953992, 131.24617077269787, 133.16918115426805, 135.0968309842676, 137.02907602272512, 138.96587296768675, 140.9071794246374, 142.8529538772596, 144.80315565945645, 146.75774492857067, 148.7166826397356, 150.67993052129893, 152.64745105126215, 154.6192074346846, 156.59516358200122, 158.5752840882094, 160.55953421287978, 162.5478798609518, 164.54028756427428, 166.53672446385536, 168.53715829278784], [0.0, 0.6742159084866536, 1.5489414099829013, 2.519674851548427, 3.5585328992682936, 4.651178435840281, 5.788692714202154, 6.964928200052847, 8.175361775184639, 9.416510761035033, 10.685602036094828, 11.980369640267964, 13.298923596774673, 14.639660942320305, 16.001203132146333, 17.38235064959624, 18.782049245320472, 20.199364277499676, 21.63346084202564, 23.08358813397323, 24.549066962030196, 26.029279653019344, 27.523661796064467, 29.031695422175765, 30.552903317692635, 32.08684424338808, 33.63310888431536, 35.19131639473141, 36.7611114317398, 38.34216159344599, 39.93415519434569, 41.53679932373815, 43.14981814314586, 44.7729513867367, 46.40595303509951, 48.048590137802925, 49.700641764255266, 51.361898065695634, 53.032159433848264, 54.71123574398781, 56.3989456719923, 58.09511607647644, 59.79958143836223, 61.51218335130318, 63.232770057267984, 64.96119602234378, 66.69732154845651, 68.44101241725046, 70.19213956283399, 71.95057877049732, 73.71621039885194, 75.48891912313736, 77.26859369769845, 79.05512673585959, 80.84841450561633, 82.64835673973569, 84.45485645900442, 86.26781980749625, 88.0871558988438, 89.91277667260223, 91.74459675988241, 93.58253335751023, 95.42650611003997, 97.2764369990126, 99.13225023890574, 100.99387217927286, 102.86123121261333, 104.73425768755634, 106.61288382697694, 108.4970436506956, 110.38667290244197, 112.28170898078974, 114.18209087379392, 116.08775909708325, 117.99865563517996, 119.91472388583779, 121.835908607204, 123.76215586762751, 125.69341299794758, 127.62962854610991, 129.57075223396942, 131.5167349161472, 133.46752854082058, 135.42308611233264, 137.3833616555159, 139.34831018163192, 141.31788765583593, 143.29205096608044, 145.27075789337903, 147.25396708335612, 149.24163801901247, 151.23373099464226, 153.2302070908406, 155.23102815054457, 157.2361567560545, 159.24555620698504, 161.25919049909942, 163.27702430398222, 165.29902294950975, 167.32515240107816, 169.35537924355313, 171.38967066390603], [0.0, 0.6854683896998351, 1.5747928233013346, 2.561727543532535, 3.6179238511747593, 4.728805346314589, 5.885304430412837, 7.0811709684831685, 8.31180635269797, 9.573669779531206, 10.863941844825508, 12.180318770223497, 13.520879035743977, 14.883992925068332, 16.268258885898756, 17.67245738197007, 19.09551656879613, 20.53648620563833, 21.99451745406465, 23.46884697841875, 24.95878425186903, 26.463701292439982, 27.983024269390484, 29.51622656896835, 31.062823012946005, 32.62236499793307, 34.19443637762701, 35.778649950072285, 37.3746444417956, 38.98208190320468, 40.60064544684845, 42.23003727342576, 43.86997694078948, 45.52019983934113, 47.180455843672114, 48.850508115471335, 50.53013203687528, 52.219114256803984, 53.917251835573516, 55.624351475328275, 57.34022882569573, 59.064707855607665, 60.797620283517446, 62.53880505931946, 64.28810789218193, 66.04538081927029, 67.81048181098744, 69.58327440890959, 71.36362739307025, 73.15141447564976, 74.94651401847715, 76.74880877205285, 78.55818563406184, 80.37453542557394, 82.19775268332558, 84.02773546665075, 85.86438517777938, 87.70760639435517, 89.55730671314183, 91.4133966039895, 93.27578927322539, 95.14440053571278, 97.0191486948953, 98.89995443020696, 100.78674069128547, 102.67943259847827, 104.57795734917492, 106.48224412954204, 108.3922240312728, 110.30782997299633, 112.22899662602246, 114.15566034412407, 116.08775909708325, 118.02523240775066, 119.96802129238593, 121.91606820406659, 123.86931697896834, 125.82771278533541, 127.791202074973, 129.75973253710595, 131.73325305446053, 133.71171366143471, 135.69506550423395, 137.6832608028565, 139.67625281482174, 141.6739958005414, 143.67644499024104, 145.6835565523447, 147.69528756324257, 149.7115959783657, 151.73244060449704, 153.7577810732533, 155.78757781567532, 157.82179203786902, 159.86038569764347, 161.90332148209382, 163.95056278608232, 166.00207369157184, 168.05781894777036, 170.11776395204566, 172.18187473157386, 174.25011792568574], [0.0, 0.6967517427685831, 1.6007151615191777, 2.6038956095935695, 3.6774777457117853, 4.806645230863044, 5.982181206648271, 7.197732655904744, 8.448625274074667, 9.731259973199153, 11.042770939493446, 12.38081647258219, 13.743443422742095, 15.128995247232062, 16.53604732309244, 17.963360039524396, 19.40984390863189, 20.874533047960494, 22.356564646524717, 23.85516280355822, 25.369625625610368, 26.899314793624534, 28.44364703115071, 30.002087055956913, 31.57414170339733, 33.15935498571417, 34.75730390650687, 36.367594890168775, 37.98986071637883, 39.62375787262658, 41.2689642552423, 42.925177162912284, 44.592111537189346, 46.269498412791265, 47.957083547046935, 49.65462620309893, 51.361898065695634, 53.07868227182919, 54.80477254126758, 56.53997239431929, 58.284094446058525, 60.03695976780613, 61.798397307967825, 63.568243365425595, 65.34634110959826, 67.13254014206571, 68.92669609531109, 70.72867026469676, 72.5383292702716, 74.3555447454183, 76.1801930497052, 78.012155003613, 79.85131564307292, 81.69756399198305, 83.55079285107091, 85.4108986016463, 87.2777810229417, 89.15134312187318, 91.03149097417395, 92.91813357595689, 94.81118270485656, 96.71055278998217, 98.61616078998729, 100.52792607862646, 102.44577033722743, 104.36961745355914, 106.29939342662252, 108.23502627693232, 110.17644596189639, 112.12358429593127, 114.07637487498484, 116.03475300516253, 117.99865563517996, 119.96802129238593, 121.94279002212096, 123.9229033301946, 125.90830412828151, 127.89893668205173, 129.8947465618647, 131.8956805958685, 133.90168682535852, 135.91271446225932, 137.92871384860416, 139.94963641789457, 141.9754346582317, 144.00606207711738, 146.04147316783116, 148.0816233772946, 150.12646907534128, 152.1759675253153, 154.2300768559266, 156.28875603429634, 158.35196484012883, 160.41966384095184, 162.49181436836977, 164.56837849527778, 166.64931901398856, 168.7345994152256, 170.8241838679409, 172.91803719991546, 175.01612487910583, 177.11841299569974], [0.0, 0.7080656334711766, 1.6267076567965484, 2.646177800680517, 3.737192818846553, 4.884695783807536, 6.079320173342763, 7.314609809669455, 8.585814486631538, 9.88927667409439, 11.22208402304134, 12.581856808445673, 13.966610165238246, 15.374660651651569, 16.80456051162496, 18.255050005495555, 19.72502195420672, 21.213494791254966, 22.71959169528555, 24.24252416641551, 25.781578913812194, 27.336107253361234, 28.905516437339582, 30.489262491574774, 32.08684424338808, 33.697798300668985, 35.3216947983796, 36.958133770012275, 38.60674203230345, 40.26717049476884, 41.93909182340273, 43.62219840161186, 45.31620054215533, 47.020824912278776, 48.735813140905506, 50.460920582080604, 52.195915213157626, 53.94057664969602, 55.694695261874735, 57.45807137955491, 59.23051457504464, 61.01184301421168, 62.80188286791714, 64.60046777685582, 66.40743836382347, 68.22264178822273, 70.04593133828949, 71.87716605709312, 73.71621039885196, 75.56293391252494, 77.41721095000071, 79.27892039651681, 81.14794542121196, 83.0241732459486, 84.90749493074695, 86.79780517435115, 88.69500212860373, 90.59898722544206, 92.50966501545223, 94.42694301702134, 96.35073157522464, 98.2809437296668, 100.2174950905717, 102.16030372248079, 104.10929003497915, 106.06437667992142, 108.02548845467648, 109.9925522109525, 111.96549676880208, 113.94425283544079, 115.92875292854404, 117.91893130371452, 119.91472388583779, 121.91606820406659, 123.9229033301946, 125.9351698201997, 127.95280965875337, 129.9757662065087, 132.0039841499939, 134.0374094539497, 136.07598931596337, 138.11967212326013, 140.1684074115246, 142.222145825633, 144.28083908218582, 146.3444399337373, 148.4129021346265, 150.48618040831988, 152.56423041618206, 154.6470087275971, 156.73447279136684, 158.8265809083184, 160.92329220505684, 163.02456660880344, 165.1303648232632, 167.240648305469, 169.35537924355316, 171.4745205353997, 173.59803576813417, 175.7258891984093, 177.85804573344853, 179.9944709128103], [0.0, 0.7194097356186692, 1.6527695597480345, 2.6885728977623877, 3.7970673489434823, 4.962954754885243, 6.176718529898534, 7.431799060111052, 8.723370035088664, 10.047715326463061, 11.401875925722786, 12.783433981652658, 14.190372829148302, 15.620982055587453, 17.073790710036157, 18.547518870217484, 20.041041618673553, 21.553361662970744, 23.08358813397323, 24.630919899038044, 26.19463223951612, 27.77406607855758, 29.368619171875217, 30.977738830146034, 32.60091585127455, 34.23767941902573, 35.88759278138302, 37.5502495638722, 39.22527060436439, 40.912301219506595, 42.611008830990585, 44.32108089381831, 46.042223079594855, 47.774157676431315, 49.51662217382131, 51.26936800627399, 53.032159433848264, 54.80477254126758, 56.58699434017748, 58.37862196147229, 60.17946192656895, 61.98932948812367, 63.8080480320361, 65.63544853371569, 67.4713690625349, 69.31565432919771, 71.16815527143305, 73.0287286740029, 74.89723681951169, 76.77354716692858, 78.6575320551014, 80.54906842885686, 82.44803758555629, 84.35432494021454, 86.26781980749627, 88.18841519908707, 90.11600763509387, 92.05049696826964, 93.99178621998085, 95.9397814269428, 97.89439149784604, 99.85552807908036, 101.82310542883926, 103.79704029895505, 105.77725182387428, 107.76366141623697, 109.75619266857126, 111.75477126065766, 113.75932487215651, 115.76978310012576, 117.78607738108911, 119.80814091734132, 121.835908607204, 123.86931697896834, 125.90830412828151, 127.95280965875337, 130.00277462557685, 132.05814148197146, 134.11885402827403, 136.18485736351244, 138.25609783931293, 140.33252301599907, 142.41408162075373, 144.50072350772191, 146.59239961994336, 148.68906195300877, 150.79066352034354, 152.8971583200271, 155.00850130306335, 157.12464834302332, 159.24555620698504, 161.37118252770247, 163.50148577693747, 165.63642523989498, 167.7759609907039, 169.92005386889034, 172.06866545679293, 174.22175805787307, 176.3792946758763, 178.541238994802, 180.70755535964307, 182.87820875785843], [0.0, 0.7307837307585184, 1.678900138761813, 2.7310797107206284, 3.857099655199977, 5.041419947204073, 6.274373542141129, 7.549297117483528, 8.86128805797569, 10.206571482602651, 11.582141600405116, 12.985542333512623, 14.41472513298887, 15.867952544285568, 17.343730360474375, 18.840758423480825, 20.357894030703097, 21.894124122337832, 23.448543744450628, 25.020339098349762, 26.60877400745617, 28.213178974798417, 29.83294223450062, 31.46750235912386, 33.11634209599747, 34.77898318519846, 36.4549819695837, 38.14392564982664, 39.8454290691781, 41.55913193667856, 43.28469641589792, 45.02180502044643, 46.770158768545215, 48.52947555763129, 50.29948872686075, 52.079945780878376, 53.87060725265292, 55.67124568676771, 57.48164472748475, 59.30159829830191, 61.13090986170554, 62.96939174946366, 64.81686455517577, 66.67315658194264, 68.53810333898488, 70.41154708185525, 72.29333639158179, 74.18332578866827, 76.08137537838272, 77.98735052419715, 79.90112154661404, 81.82256344493602, 83.75155563981474, 85.68798173465613, 87.63172929417016, 89.58268963853824, 91.54075765183187, 93.50583160345836, 95.47781298153483, 97.45660633720043, 99.44211913897601, 101.43426163636512, 103.43294673196816, 105.43808986144921, 107.44960888075609, 109.46742396004878, 111.49145748383977, 113.52163395689375, 115.5578799154737, 117.60012384355463, 119.64829609365954, 121.70232881199964, 123.76215586762751, 125.82771278533541, 127.89893668205173, 129.9757662065087, 132.05814148197146, 134.14600405183478, 136.2392968279088, 138.33796404122734, 140.44195119522638, 142.55120502114895, 144.66567343554556, 146.78530549974644, 148.9100513811921, 151.03986231651498, 153.17469057627451, 155.31448943125156, 157.45921312021744, 159.60881681909655, 161.76325661144682, 163.92248946018847, 166.08647318051462, 168.2551664139221, 170.42852860330476, 172.6065199690546, 174.78910148612033, 176.97623486197435, 179.1678825154449, 181.3640075563689, 183.56457376602742, 185.7695455783248], [0.0, 0.7421873078928632, 1.70509867935242, 2.7736970772962644, 3.917288096159484, 5.120089215299154, 6.372282539900606, 7.667100769050803, 8.999564784215734, 10.36584079892727, 11.762876118104398, 13.188176337799785, 14.63966094232031, 16.11556536485981, 17.61437208201032, 19.13476064726968, 20.675570526635724, 22.235772851926885, 23.81444854777781, 25.41077111650559, 27.023992893800862, 28.65343393546954, 30.298472929282873, 31.95853968695953, 33.63310888431537, 35.32169479837961, 37.02384684892331, 38.7391457950576, 40.46720046982191, 42.20764496006568, 43.960136157561365, 45.724351621675766, 47.499987705143276, 49.28675790330739, 51.084391394192295, 52.89263174235743, 54.71123574398781, 56.5399723943193, 58.37862196147229, 60.226975153206304, 62.084832365121244, 63.952003000500206, 65.82830485338016, 67.713563547603, 69.60761202557887, 71.51029008132387, 73.42144393303575, 75.34092583107102, 77.26859369769846, 79.20431079544291, 81.14794542121197, 83.09937062372428, 85.05846394204073, 87.02510716324667, 88.99918609754596, 90.98059036921653, 92.96921322203936, 94.96495133795808, 96.9677046678527, 98.97737627342246, 100.99387217927287, 103.01710123438816, 105.04697498224995, 107.0834075389309, 109.12631547855496, 111.17561772557053, 113.23123545333263, 115.2930919885341, 117.36111272106677, 119.4352250189277, 121.5153581478199, 123.60144319512433, 125.69341299794758, 127.791202074973, 129.8947465618647, 132.0039841499939, 134.11885402827403, 136.2392968279088, 138.36525456987079, 140.49667061494227, 142.6334896161629, 144.77565747353887, 146.9231212908801, 149.07582933463985, 151.23373099464231, 153.3967767465878, 155.56491811623752, 157.73810764518234, 159.91629885810858, 162.09944623147945, 164.28750516355504, 166.48043194567978, 168.6781837347704, 170.88071852694142, 173.08799513220984, 175.2999731502234, 177.516612946961, 179.73787563235612, 181.96372303879835, 184.19411770046892, 186.42902283347078, 188.6684023167141], [0.0, 0.753620163210543, 1.7313644835450959, 2.8164238620884086, 3.977631068297086, 5.19896046328414, 6.470442914710704, 7.78520687631838, 9.138196529875923, 10.525519032224873, 11.944074663738233, 13.391330595991274, 14.865174264460812, 16.363813920473277, 17.88570866427706, 19.429517708852636, 20.99406264301618, 22.578298749620583, 24.18129279561339, 25.802205551716412, 27.440277836395747, 29.09481923141185, 30.765198853673287, 32.45083773156322, 34.15120244866079, 35.86579979978635, 37.594172263850474, 39.33589414186351, 41.090568241222556, 42.857823012151265, 44.63731006108958, 46.42870198044099, 48.23169044547478, 50.04598453813872, 51.87130926464156, 53.707404239341415, 55.55402251204553, 57.41092951952949, 59.27790214510402, 61.15472787253399, 63.041204022658796, 64.93713706275783, 66.8423419801178, 68.75664171244277, 70.67986662874235, 72.61185405517601, 74.55244784104478, 76.50149796072945, 78.45886014789474, 80.42439555872419, 82.39797046133515, 84.37945594885414, 86.36872767392042, 88.3656656026354, 90.37015378619226, 92.38208014861125, 94.40133628917154, 96.42781729827723, 98.46142158562448, 100.50205071964857, 102.54960927733241, 104.60400470354523, 106.66514717916033, 108.73294949727098, 110.8073269468862, 112.88819720354458, 114.975480226334, 117.06909816085083, 119.16897524767246, 121.27503773595281, 123.38721380178455, 125.50543347099989, 127.62962854610991, 129.75973253710595, 131.8956805958685, 134.0374094539497, 136.18485736351244, 138.33796404122734, 140.49667061494227, 142.6609195729536, 144.83065471572127, 147.0058211098805, 149.18636504441383, 151.372233988857, 153.56337655342116, 155.7597424509209, 157.96128246040706, 160.16794839240825, 162.37969305569234, 164.59647022546568, 166.81823461293095, 169.0449418361326, 171.2765483920208, 173.5130116296708, 175.75428972459792, 178.00034165411185, 180.25112717365826, 182.50660679409742, 184.76674175987466, 187.0314940280376, 189.30082624805996, 191.57470174243286], [0.0, 0.7650819998320296, 1.7576968692897887, 2.859258955601021, 4.038127004673238, 5.278031643091579, 6.568852117618867, 7.903612372398381, 9.277179695074507, 10.685602036094828, 12.12573253208319, 13.594999832734727, 15.091259243455166, 16.61269176479984, 18.15773306141647, 19.725021954206717, 21.313362109487965, 22.921692920971818, 24.549066962030196, 26.19463223951612, 27.857618025475986, 29.537323401073994, 31.233107888094697, 32.94438370932077, 34.670609335581496, 36.41128406052162, 38.16594340459674, 39.93415519434569, 41.71551619624876, 43.50964920961545, 45.31620054215532, 47.134837806717755, 48.965247989249924, 50.807135747116305, 52.66022190413503, 54.52424211444945, 56.3989456719923, 58.284094446058525, 60.17946192656894, 62.08483236512124, 64.00000000000004, 65.92476835503851, 67.85894960365826, 69.8023639906164, 71.7548393049986, 73.71621039885194, 75.68631874657578, 77.66501204080576, 79.65214382105464, 81.64757313182527, 83.65116420730192, 85.66278618006173, 87.68231281154044, 89.70962224223949, 91.74459675988241, 93.7871225839218, 95.83708966496624, 97.89439149784604, 99.95892494716665, 102.03059008431408, 104.10929003497914, 106.19493083635665, 108.2874213032575, 110.38667290244199, 112.49259963454655, 114.60511792303402, 116.72414650964713, 118.84960635589175, 120.98142055011749, 123.11951421979892, 125.26381444865629, 127.41425019828213, 129.57075223396942, 131.73325305446053, 133.90168682535852, 136.07598931596337, 138.25609783931293, 140.44195119522638, 142.6334896161629, 144.83065471572127, 147.03338943962058, 149.24163801901247, 151.45534592598668, 153.67445983114118, 155.8989275630979, 158.12869806985188, 160.36372138185067, 162.60394857670744, 164.84933174545696, 167.09982396027095, 169.35537924355313, 171.61595253834113, 173.8814996799457, 176.1519773687626, 178.427343144197, 180.70755535964304, 182.99257315846546, 185.28235645093275, 187.57686589205562, 189.87606286028503, 192.17990943702915, 194.48836838694956], [0.0, 0.776572527566488, 1.7840951699030292, 2.902201273334996, 4.098774373651531, 5.357300752796953, 6.667507657100422, 8.022314259499883, 9.416510761035033, 10.846085757554867, 12.307845123924476, 13.799178891531419, 15.31791015528278, 16.86219259674903, 18.430438386313547, 20.021265901754003, 21.633460842025645, 23.265946671925295, 24.91776173572009, 26.588041244443932, 28.27600289482065, 29.980935241133256, 31.702188186023903, 33.43916512463272, 35.19131639473141, 36.95813377001227, 38.739145795057595, 40.53391380572792, 42.34202851246516, 44.16310704951941, 45.99679041260611, 47.84274122255579, 49.700641764255266, 51.570192259410156, 53.45110933897867, 55.34312468697625, 57.24598383205947, 59.15944506711255, 61.08327848017213, 63.017265082577985, 64.96119602234377, 66.91487187248843, 68.87810198552482, 70.85070390652218, 72.8325028381842, 74.82333115225242, 76.82302794227967, 78.83143861344483, 80.84841450561633, 82.87381254633041, 84.90749493074694, 86.94932882598607, 88.99918609754593, 91.05694305575823, 93.12248022046255, 95.19568210227695, 97.27643699901257, 99.36463680593182, 101.46017683868183, 103.56295566785201, 105.67287496420808, 107.78983935374686, 109.91375628179738, 112.04453588546677, 114.18209087379392, 116.32633641503175, 118.47719003053056, 120.63457149474178, 122.79840274090292, 124.96860777200148, 127.14511257665086, 129.32784504953992, 131.5167349161472, 133.71171366143471, 135.91271446225932, 138.11967212326013, 140.33252301599907, 142.55120502114895, 144.77565747353887, 147.0058211098805, 149.24163801901247, 151.48305159451152, 153.73000648952967, 155.98244857372734, 158.24032489218078, 160.50358362615086, 162.77217405560808, 165.04604652341553, 167.32515240107816, 169.60944405597328, 171.89887481998153, 174.19339895944404, 176.49297164637582, 178.79754893086945, 181.10708771462768, 183.42154572556726, 185.74088149343984, 188.06505432641885, 190.3940242886048, 192.72775217840368, 195.0661995077362, 197.40932848203798], [0.0, 0.7880914626802521, 1.8105587335360258, 2.9452497549229144, 4.159571677676697, 5.4367658350214905, 6.766407097070745, 8.141309606537178, 9.556186287278958, 11.006966233807484, 12.490407942386536, 14.003862730622243, 15.545121403290858, 17.112310255438825, 18.70381790510163, 20.318242236392592, 21.954350936485127, 23.61105150188113, 25.287368012565132, 26.982422852117544, 28.695422113322632, 30.42564379755719, 32.172428164540115, 33.93516975994492, 35.71331076837882, 37.50633542499051, 39.313765281242944, 41.135155166271815, 42.97008971950867, 44.81818039613877, 46.67906286675091, 48.55239474781528, 50.43785361153616, 52.335135232994325, 54.243952039922256, 56.16403173639239, 58.09511607647643, 60.03695976780613, 61.989329488123666, 63.9520030005002, 65.92476835503851, 67.90742316664819, 69.89977395995938, 71.90163557367913, 73.91283061773504, 75.93318897743113, 77.96254735958772, 80.00074887627177, 82.04764266226931, 84.10308352291631, 86.16693160930726, 88.23905211824626, 90.31931501460664, 92.4075947740257, 94.50377014408845, 96.60772392235377, 98.71934274974923, 100.8385169180148, 102.96514019000995, 105.09910963181706, 107.24032545567992, 109.38869087290848, 111.5441119559642, 113.7064975090139, 115.87575894630572, 118.05181017777946, 120.23456750137592, 122.42394950155737, 124.61987695359353, 126.82227273320483, 129.03106173119042, 131.24617077269787, 133.46752854082058, 135.69506550423395, 137.92871384860416, 140.1684074115246, 142.41408162075373, 144.66567343554556, 146.9231212908801, 149.18636504441383, 151.45534592598668, 153.73000648952967, 156.01029056723266, 158.29614322583822, 160.58751072493988, 162.8843404771688, 165.18658101016305, 167.49418193021916, 169.80709388753345, 172.1252685429464, 174.44865853610827, 176.77721745499088, 179.1108998066737, 181.44966098933833, 183.7934572654086, 186.14224573577746, 188.49598431506664, 190.85463170786576, 193.21814738590442, 195.58649156610957, 197.95962518950654, 200.33750990092244], [0.0, 0.7996385276760425, 1.8370869226674424, 2.988403363303937, 4.220517452109314, 5.516424975409053, 6.865548054989679, 8.260595546849006, 9.696202908948493, 11.168239589156357, 12.673416589433879, 14.209046419064544, 15.772887513839477, 17.363038715401668, 18.977865031922573, 20.615943803804484, 22.2760246624532, 23.95699909708023, 25.65787688855334, 27.37776756167407, 29.115865576949663, 30.87143835707991, 32.64381649531191, 34.432385666241636, 36.23657988140136, 38.05587581898663, 39.88978802026346, 41.73786479175291, 43.59968468705043, 45.47485346840785, 47.36300146828306, 49.26378128656498, 51.176865771266755, 53.101946239985345, 55.03873090696304, 56.986943486609995, 58.94632194919534, 60.91661740834294, 62.89759312317239, 64.88902360055378, 66.89069378511377, 68.9023983264287, 70.92394091434014, 72.9551336745839, 74.99579661797975, 77.04575713732221, 79.10484954687051, 81.17291465997982, 83.24979940096881, 85.33535644779066, 87.42944390248277, 89.53192498672158, 91.64266776011415, 93.76154485912295, 95.88843325475048, 98.02321402731307, 100.1657721568085, 102.31599632753843, 104.47377874578264, 106.63901496944241, 108.81160374867783, 110.99144687665724, 113.17844904962185, 115.37251773554308, 117.57356305071639, 119.78149764369557, 121.99623658602432, 124.2176972692697, 126.44579930790583, 128.6804644476332, 130.92161647875582, 133.16918115426805, 135.42308611233264, 137.6832608028565, 139.94963641789457, 142.222145825633, 144.50072350772191, 146.78530549974644, 149.07582933463985, 151.372233988857, 153.67445983114118, 155.98244857372734, 158.29614322583822, 160.61548804933784, 162.94042851641888, 165.2709112692057, 167.60688408116667, 169.94829582023306, 172.29509641353107, 174.64723681363895, 177.00466896628618, 179.36734577941854, 181.73522109355622, 184.10824965337784, 186.48638708046707, 188.86958984716202, 191.2578152514521, 193.65102139286927, 196.04916714932554, 198.4522121548489, 200.86011677817507, 203.27284210215367], [0.0, 0.8112134510823085, 1.8636791136194313, 3.031661083936533, 4.281610264113946, 5.596276301172887, 6.9649282000528485, 8.380169276022364, 9.836557334252223, 11.329902032064165, 12.856866762532377, 14.41472513298887, 16.001203132146337, 17.61437208201032, 19.25257332392717, 20.914363605024462, 22.5984744573791, 24.303781324293062, 26.029279653019344, 27.77406607855758, 29.537323401073994, 31.318308439069295, 33.11634209599747, 34.93080115397464, 36.7611114317398, 38.60674203230345, 40.467200469821904, 42.34202851246516, 44.23079861330989, 46.13311082793973, 48.048590137802925, 49.97688411410413, 51.91766086926778, 53.87060725265293, 55.835427254846216, 57.811840590970064, 59.79958143836224, 61.79839730796783, 63.808048032036105, 65.82830485338017, 67.85894960365826, 69.89977395995939, 71.95057877049732, 74.01117344149134, 76.08137537838272, 78.16100947544314, 80.24990764859841, 82.34790840694605, 84.45485645900442, 86.5706023502114, 88.69500212860373, 90.82791703596499, 92.96921322203934, 95.11876147967727, 97.27643699901259, 99.44211913897601, 101.61569121462841, 103.79704029895504, 105.98605703790057, 108.18263547754657, 110.38667290244197, 112.59806968419213, 114.81672913949777, 117.04255739691118, 119.27546327164367, 121.5153581478199, 123.76215586762754, 126.01577262686057, 128.27612687639692, 130.54313922919087, 132.81673237239627, 135.0968309842676, 137.3833616555159, 139.67625281482174, 141.9754346582317, 144.28083908218582, 146.59239961994336, 148.9100513811921, 151.23373099464231, 153.56337655342116, 155.8989275630979, 158.24032489218078, 160.58751072493988, 162.94042851641888, 165.29902294950978, 167.66323989397134, 170.0330263672827, 172.4083304972285, 174.7891014861203, 177.1752895765654, 179.56684601869839, 181.96372303879832, 184.36587380921796, 186.77325241955634, 189.18581384901088, 191.60351393984837, 194.02630937193823, 196.45415763829507, 198.88701702158062, 201.32484657151753, 203.76760608317127, 206.2152560760582], [0.0, 0.8228159672521091, 1.8903346960955842, 3.075021924046863, 4.342848711597636, 5.676317979708174, 7.064545251464899, 8.500028049814874, 9.977246342026396, 11.491949852343645, 13.040754251461747, 14.620894152025224, 16.23006301831969, 17.866304587110847, 19.527936476502006, 21.21349479125496, 22.921692920971815, 24.65139022479414, 26.40156778219113, 28.17130930763328, 29.9597859131494, 31.766243787762416, 33.58999412203429, 35.43040478440305, 37.28689338128409, 39.15892142244484, 41.04598937818042, 42.94763246272337, 44.86341701408891, 46.79293736758874, 48.73581314090549, 50.69168686457198, 52.66022190413502, 54.64110063006423, 56.63402279922205, 58.63870411790955, 60.654874961491345, 62.68227922964557, 64.72067331958203, 66.76982520227588, 68.82951358899614, 70.89952717725848, 72.97966396687495, 75.06973063806535, 77.16954198468174, 79.2789203965168, 81.39769538544573, 83.52570315081539, 85.66278618006173, 87.80879288102373, 89.9635772428411, 92.12699852268477, 94.29892095588326, 96.47921348728013, 98.6677495218952, 100.86440669317011, 103.06906664725986, 105.28161484199214, 107.50194035925698, 109.72993572971228, 111.96549676880205, 114.20852242317983, 116.4589146267173, 118.71657816535465, 120.98142055011746, 123.25335189768701, 125.53228481796448, 127.81813430812011, 130.11081765266192, 132.4102543290976, 134.71636591880113, 137.02907602272512, 139.34831018163192, 141.6739958005414, 144.00606207711738, 146.3444399337373, 148.68906195300877, 151.03986231651498, 153.3967767465878, 155.7597424509209, 158.12869806985188, 160.50358362615086, 162.8843404771688, 165.2709112692057, 167.66323989397134, 170.06127144701765, 172.46495218803238, 174.87422950288916, 177.2890518673571, 179.70936881238003, 182.13513089083946, 184.5662896457228, 187.00279757962255, 189.44460812549653, 191.89167561862462, 194.34395526970022, 196.80140313899935, 199.26397611157333, 201.73163187341467, 204.20432888854788, 206.68202637700057, 209.16468429361285], [0.0, 0.8344458161710001, 1.9170530727395727, 3.1184849119108127, 4.404231422195918, 5.756548217266707, 7.16439697679005, 8.620169182170166, 10.118266779405404, 11.654379418474413, 13.225074935270763, 14.82754885588934, 16.459462043568923, 18.118830584851146, 19.803948318710017, 21.513330658913063, 23.245672809848276, 24.99981800860639, 26.77473293302572, 28.569488346609972, 30.383243645716092, 32.215234364848705, 34.06476195879651, 35.931185361320935, 37.81391394716752, 39.712401614972784, 41.62614177457696, 43.55466307083564, 45.49752571229699, 47.454318300525166, 49.424655076801436, 51.408173519112154, 53.40453223494404, 55.41340910532607, 57.43449964342283, 59.467515537270216, 61.51218335130317, 63.568243365425595, 65.63544853371569, 67.71356354760299, 69.8023639906164, 71.90163557367913, 74.01117344149132, 76.13078154185153, 78.26027205087027, 80.39946484796128, 82.54818703528582, 84.70627249699884, 86.87356149422155, 89.04990029215837, 91.23514081620166, 93.42914033423452, 95.63176116265983, 97.84287039396084, 100.06233964383803, 102.29004481617913, 104.52586588430172, 106.76968668707106, 109.02139473863792, 111.28088105066662, 113.54803996603535, 115.82276900308898, 118.10496870961256, 120.39454252577129, 122.69139665533272, 124.99543994454892, 127.30658376813156, 129.62474192180355, 131.94983052095523, 134.28176790497298, 136.62047454684586, 138.96587296768675, 141.31788765583593, 143.67644499024104, 146.04147316783116, 148.4129021346265, 150.79066352034354, 153.17469057627451, 155.56491811623752, 157.96128246040706, 160.36372138185067, 162.77217405560808, 165.18658101016305, 167.60688408116667, 170.0330263672827, 172.46495218803238, 174.90260704352698, 177.3459375759812, 179.79489153291024, 182.24941773191793, 184.70946602699013, 187.17498727621296, 189.6459333108408, 192.12225690564347, 194.60391175046632, 197.09085242294154, 199.58303436229215, 202.08041384417393, 204.58294795650463, 207.09059457623073, 209.60331234698742, 212.12106065760838], [0.0, 0.8461027432734183, 1.943833658713309, 3.162049096167788, 4.465757052303692, 5.836965257690195, 7.2644811903756, 8.740590043321056, 10.25961555959532, 11.817187175038487, 13.409824779367144, 15.034684721119955, 16.68939518658271, 18.371944547693992, 20.080602808932724, 21.81386464489661, 23.57040703241826, 25.349057049000027, 27.14876693731754, 28.96859447975352, 30.807687329715034, 32.66527034238113, 34.5406352140991, 36.43313192315086, 38.34216159344599, 40.267170494768834, 42.20764496006567, 44.16310704951942, 46.13311082793973, 48.11723914979312, 50.11510086744145, 52.126328394560595, 54.15057556949881, 56.18751577339148, 58.23684026582467, 60.29825670721314, 62.37148784218911, 64.45627032245415, 66.55235365093812, 68.65949923188907, 70.77747951381333, 72.90607721408789, 75.04508461565328, 77.19430292752484, 79.35354170197661, 81.52261830219834, 83.7013574150267, 85.88959060403424, 88.0871558988438, 90.29389741703648, 92.50966501545223, 94.73431396805448, 96.96770466785267, 99.20970235065677, 101.46017683868185, 103.71900230223468, 105.98605703790055, 108.26122326181273, 110.5443869167326, 112.83543749179408, 115.13426785388096, 117.44077408970392, 119.754855357734, 122.07641374922805, 124.40535415765184, 126.74158415587024, 129.08501388052952, 131.43555592310784, 133.79312522715577, 136.15763899128845, 138.52901657752935, 140.9071794246374, 143.29205096608044, 145.6835565523447, 148.0816233772946, 150.48618040831988, 152.8971583200271, 155.31448943125156, 157.73810764518234, 160.16794839240825, 162.60394857670744, 165.04604652341553, 167.49418193021916, 169.94829582023306, 172.4083304972285, 174.87422950288916, 177.3459375759812, 179.82340061332906, 182.3065656324983, 184.79538073609191, 187.28979507757282, 189.78975882853115, 192.29522314732014, 194.80614014898902, 197.32246287644588, 199.84414527278773, 202.37114215473855, 204.90340918713974, 207.4409028584417, 209.98358045714605, 212.5314000491535, 215.08432045597334], [0.0, 0.857786499267097, 1.9706758812935599, 3.2057135451645196, 4.52742428614849, 5.917567381198963, 7.364795751844395, 8.86128805797569, 10.401289659744792, 11.980369640267964, 13.594999832734725, 15.242297317958789, 16.919857530065617, 18.62564106260446, 20.357894030703097, 22.115090322057366, 23.89588864399303, 25.69909987723212, 27.523661796064463, 29.36861917187521, 31.233107888094693, 33.11634209599746, 35.01760371102996, 36.93623373538318, 38.87162502314114, 40.82321619767788, 42.79048649875794, 44.77295138673669, 46.770158768545215, 48.781685738325216, 50.8071357471163, 52.84613613262817, 54.89833595309425, 56.96340407939966, 59.04102750776209, 61.13090986170554, 63.232770057267984, 65.34634110959824, 67.47136906253489, 69.60761202557886, 71.7548393049986, 73.91283061773503, 76.0813753783827, 78.26027205087027, 80.44932755759638, 82.64835673973569, 84.85718186324131, 87.07563216576241, 89.30354344028764, 91.54075765183187, 93.7871225839218, 96.04249151201219, 98.30672290129218, 100.57968012662528, 102.86123121261333, 105.15124859199233, 107.4496088807561, 109.75619266857123, 112.07088432319301, 114.39357180772087, 116.72414650964711, 119.06250308075322, 121.40853928699873, 123.76215586762754, 126.1232564027879, 128.4917471890268, 130.86753712207556, 133.25053758639604, 135.64066235100202, 138.0378274711118, 140.44195119522638, 142.8529538772596, 145.27075789337903, 147.69528756324257, 150.12646907534128, 152.56423041618206, 155.00850130306335, 157.45921312021744, 159.91629885810858, 162.37969305569234, 164.84933174545696, 167.32515240107816, 169.80709388753345, 172.29509641353107, 174.7891014861203, 177.2890518673571, 179.79489153291024, 182.3065656324983, 184.8240204520572, 187.34720337754356, 189.876062860285, 192.41054838379574, 194.9506104319791, 197.49620045864535, 200.04727085827642, 202.6037749379737, 205.16566689052937, 207.7329017685647, 210.30543545968303, 212.8832246625868, 215.4662268641125, 218.05440031713945], [0.0, 0.869496839965074, 1.9975791794860018, 3.2494773463272453, 4.589231834903795, 5.99835290323304, 7.465338564652476, 8.98226070358211, 10.543286118908028, 12.143923403698732, 13.780596225270966, 15.450382307365434, 17.150844257424453, 18.87991482740221, 20.635816188718564, 22.417001394869885, 24.222110842105458, 26.04993917751355, 27.899409674077457, 29.769554062580116, 31.65949642969422, 33.568440198434644, 35.49565748109194, 37.440480283342396, 39.40229317062763, 41.3805271025131, 43.374654209442106, 45.38418333692549, 47.4086562200044, 49.44764417938895, 51.50074525250656, 53.56758168955113, 55.64779775776478, 57.74105780751994, 59.84704456196527, 61.9654575985486, 64.09601199600229, 66.23843712464794, 68.39247556136218, 70.5578821134021, 72.73442293764852, 74.9218747437793, 77.12002407151645, 79.3286666334559, 81.54760671613704, 83.7766566329809, 86.01563622354867, 88.26437239427386, 90.52269869642174, 92.79045493754317, 95.06748682313405, 97.3536456255931, 99.64878787790273, 101.95277508974567, 104.26547348402033, 106.58675375193829, 108.91649082507803, 111.25456366293864, 113.60085505468562, 115.95525143391161, 118.31764270535132, 120.68792208259205, 123.06598593591339, 125.45173364946993, 127.84506748710419, 130.24589246614116, 132.65411623857372, 135.069648979101, 137.4924032795275, 139.92229404907312, 142.35923842018263, 144.80315565945645, 147.25396708335612, 149.7115959783657, 152.1759675253153, 154.6470087275971, 157.12464834302332, 159.60881681909655, 162.09944623147945, 164.59647022546568, 167.09982396027095, 169.60944405597328, 172.1252685429464, 174.64723681363895, 177.1752895765654, 179.70936881238003, 182.24941773191793, 184.79538073609191, 187.34720337754356, 189.90483232395238, 192.4682153229132, 195.03730116829863, 197.61203966802748, 200.1923816131666, 202.7782787482962, 205.36968374307503, 207.96655016494384, 210.56883245291067, 213.1764858923647, 215.78946659086716, 218.4077314548728, 221.03123816733702], [0.0, 0.8812335261248792, 2.0245430036557712, 3.2933396055607247, 4.651178435840281, 6.0793201733427615, 7.566107574708378, 9.103505508667, 10.685602036094828, 12.307845123924476, 13.966610165238242, 15.658935438159833, 17.382350649596244, 19.134760647269676, 20.914363605024462, 22.719591695285548, 24.549066962030196, 26.401567782191133, 28.27600289482065, 30.17139096076124, 32.08684424338807, 34.02155541332034, 35.97478675763796, 37.94586126526248, 39.93415519434569, 41.93909182340273, 43.96013615756136, 45.99679041260611, 48.048590137802925, 50.11510086744145, 52.19591521315762, 54.29065032618382, 56.3989456719923, 58.52046107027273, 60.65487496149136, 62.801882867917136, 64.96119602234377, 67.13254014206571, 69.3156543291977, 71.51029008132386, 73.71621039885194, 75.93318897743113, 78.16100947544311, 80.39946484796127, 82.64835673973569, 84.90749493074694, 87.17669682870545, 89.45578700358442, 91.74459675988241, 94.04296374283247, 96.35073157522464, 98.6677495218952, 100.99387217927284, 103.32895918766327, 105.67287496420809, 108.02548845467645, 110.38667290244197, 112.7563056331687, 115.13426785388096, 117.52044446522358, 119.91472388583777, 122.31699788788112, 124.72716144281324, 127.14511257665089, 129.57075223396942, 132.00398414999387, 134.44471473018064, 136.8928529367444, 139.34831018163194, 141.81100022548648, 144.2808390821858, 146.75774492857067, 149.24163801901247, 151.73244060449704, 154.2300768559266, 156.73447279136684, 159.24555620698504, 161.76325661144682, 164.28750516355504, 166.81823461293095, 169.35537924355313, 171.89887481998153, 174.44865853610827, 177.00466896628618, 179.56684601869839, 182.13513089083946, 184.70946602699013, 187.28979507757282, 189.876062860285, 192.4682153229132, 195.0661995077362, 197.6699635174334, 200.2794564824184, 202.89462852952346, 205.51543075196517, 208.14181518052536, 210.7737347558865, 213.41114330206298, 216.05399550087495, 218.70224686741247, 221.35585372644286, 224.01477318971544], [0.0, 0.8929963232945216, 2.051566815173635, 3.337299446672661, 4.713262851512922, 6.1604675741263, 7.667100769050803, 9.225020051244671, 10.828234568403058, 12.47213152644564, 14.153037936822914, 15.86795254428557, 17.61437208201032, 19.390173431407888, 21.193530715358836, 23.02285517876185, 24.876750472493246, 26.75397866713342, 28.653433935469536, 30.57412183932648, 32.51514279247822, 34.47567868922704, 36.454981969583706, 38.452366585655184, 40.46720046982191, 42.49889920246037, 44.54692064753092, 46.61076037634234, 48.68994773862367, 50.78404246937087, 52.89263174235742, 55.015327598510375, 57.15176469084942, 59.30159829830192, 61.464502569123866, 63.64016896138366, 65.82830485338016, 68.0286323012536, 70.24088692462651, 72.46481690404678, 74.70018207642688, 76.94675311668186, 79.20431079544288, 81.47264530412602, 83.75155563981475, 86.04084904341296, 88.34034048537013, 90.64985219400114, 92.96921322203934, 95.29825904758943, 97.63683120610207, 99.98477695038488, 102.34194893600444, 104.70820492973063, 107.08340753893087, 109.46742396004878, 111.86012574449724, 114.26138858047048, 116.67109208933176, 119.08911963536771, 121.51535814781988, 123.94969795420931, 126.39203262406372, 128.84225882224047, 131.30027617111273, 133.76598712095327, 136.2392968279088, 138.72011303901203, 141.20834598372724, 143.70390827156567, 146.20671479534957, 148.7166826397356, 151.23373099464226, 153.7577810732533, 156.28875603429634, 158.8265809083184, 161.37118252770247, 163.92248946018847, 166.48043194567978, 169.0449418361326, 171.61595253834113, 174.19339895944404, 176.77721745499088, 179.36734577941854, 181.96372303879832, 184.5662896457228, 187.17498727621296, 189.78975882853115, 192.41054838379574, 195.03730116829863, 197.6699635174334, 200.3084828411486, 202.9528075908453, 205.60288722764355, 208.25867219194697, 210.92011387423935, 213.58716458705044, 216.25977753803272, 218.93790680409458, 221.62150730653687, 224.3105347871453, 227.00494578519235], [0.0, 0.9047850016649155, 2.0786500860769563, 3.381356010822189, 4.77548386898209, 6.241793520211594, 7.768316174581571, 9.346801957292554, 10.97118092922921, 12.63677940160831, 14.339875897796423, 16.077429542187566, 17.84690402167742, 19.6461481898321, 21.473312065650052, 23.326785920457713, 25.205154971560873, 27.107164947309396, 29.031695422175762, 30.97773883014603, 32.94438370932077, 34.930801153974635, 36.93623373538318, 38.95998634895545, 41.00141858298165, 43.05993830276175, 45.134996215376226, 47.226081233038606, 49.332716492300406, 51.45445591610394, 53.59088122839555, 55.741599348552946, 57.90624010655463, 60.08445423057479, 62.2759115672152, 64.48029950140139, 66.69732154845651, 68.92669609531109, 71.16815527143305, 73.42144393303573, 75.68631874657578, 77.96254735958772, 80.2499076485984, 82.54818703528582, 84.85718186324132, 87.17669682870545, 89.50654445950413, 91.84654463714168, 94.19652415763177, 96.5563163271825, 98.92576058931249, 101.30470218037367, 103.69299181080017, 106.09048536970371, 108.49704365069562, 110.91253209704495, 113.33682056448116, 115.76978310012575, 118.21129773619211, 120.6612462972282, 123.11951421979893, 125.5859903836102, 128.06056695317318, 130.5431392291909, 133.0336055089253, 135.53186695486957, 138.03782747111183, 140.5513935868293, 143.07247434640186, 145.600981205676, 148.13682793395185, 150.67993052129893, 153.2302070908406, 155.78757781567532, 158.35196484012883, 160.92329220505684, 163.50148577693747, 166.08647318051462, 168.6781837347704, 171.2765483920208, 173.8814996799457, 176.49297164637582, 179.1108998066737, 181.73522109355622, 184.36587380921796, 187.00279757962255, 189.6459333108408, 192.29522314732014, 194.9506104319791, 197.61203966802748, 200.2794564824184, 202.9528075908453, 205.63204076420277, 208.31710479643377, 211.0079494736928, 213.7045255447566, 216.40678469262022, 219.11467950721809, 221.8281634592158, 224.54719087481845, 227.2717169115476, 230.00169753493918], [0.0, 0.9165993359284086, 2.1057922987446758, 3.425508455991168, 4.837840299066868, 6.323296457280389, 7.869751856850978, 9.468848899289744, 11.114438386552951, 12.801785602628334, 14.527120477273126, 16.287362428298234, 18.07994202439916, 19.90268003029994, 21.753702308659232, 23.631378111586116, 25.534274182698557, 27.461119872550036, 29.41078012552779, 31.38223421920872, 33.37455879017477, 35.386914109168714, 37.418532857253396, 39.46871085342966, 41.53679932373816, 43.62219840161187, 45.724351621675766, 47.842741222555794, 49.97688411410414, 52.126328394560595, 54.29065032618383, 56.46945169565607, 58.662357499418185, 60.86901390498732, 63.08908644794924, 65.3222584312222, 67.56822949874653, 69.82671436025774, 72.09744164747345, 74.38015288503763, 76.6746015620512, 78.98055229207962, 81.29778005124696, 83.6260694854653, 85.96521427905897, 88.31501657806726, 90.67528646237656, 93.04584146157322, 95.42650611003997, 97.81711153736148, 100.21749509057169, 102.62749998517835, 105.04697498224992, 107.47577408915365, 109.91375628179738, 112.36078524646018, 114.81672913949775, 117.28146036338737, 119.754855357734, 122.23679440399607, 124.72716144281324, 127.22584390292538, 129.73273254076935, 132.2477212899251, 134.77070711965933, 137.30158990188312, 139.8402722859012, 142.3866595803847, 144.94065964205006, 147.5021827705683, 150.07114160927227, 152.64745105126215, 155.23102815054457, 157.82179203786902, 160.41966384095184, 163.02456660880344, 165.63642523989498, 168.2551664139221, 170.88071852694142, 173.5130116296708, 176.1519773687626, 178.79754893086945, 181.44966098933833, 184.10824965337784, 186.77325241955634, 189.44460812549653, 192.12225690564347, 194.80614014898902, 197.49620045864535, 200.1923816131666, 202.89462852952346, 205.60288722764355, 208.31710479643377, 211.03722936120818, 213.7632100524482, 216.49499697582704, 219.23254118343488, 221.9757946461438, 224.72471022705727, 227.47924165598954, 230.2393435049263, 233.00497116441846], [0.0, 0.9284391051430984, 2.132992945585593, 3.469755956477107, 4.900330975628902, 6.404974861132203, 7.971405918892835, 9.591158594815331, 11.258004261291873, 12.967147043696295, 14.71476817355985, 16.49774727662647, 18.313481732091656, 20.159764155365213, 22.034696200760095, 23.936626055915962, 25.86410195099117, 27.815836823483238, 29.7906809561972, 31.787600441976515, 33.80565999026185, 35.84400902496225, 37.901870315635286, 39.97853058533314, 42.07333267984387, 44.18566898408764, 46.31497584479243, 48.4607288126291, 50.622438557345085, 52.79964733993776, 54.99192594921968, 57.198871028127485, 59.42010272915833, 61.65526264935372, 63.90401200400231, 66.16603000522692, 68.44101241725045, 70.72867026469676, 73.0287286740029, 75.34092583107102, 77.66501204080576, 80.00074887627177, 82.34790840694603, 84.70627249699884, 87.07563216576243, 89.45578700358443, 91.84654463714166, 94.24772023903907, 96.65913607715932, 99.08062109977773, 101.51201055292998, 103.95314562692906, 106.40387312928095, 108.86404518155722, 111.33351893804894, 113.81215632426262, 116.29982379352157, 118.79639210011814, 121.30173608762018, 123.81573449107447, 126.33826975197483, 128.8692278449714, 131.40849811539525, 133.95597312675997, 136.51154851747802, 139.07512286609992, 141.64659756444553, 144.2258766980524, 146.81286693341647, 149.40747741154428, 152.00961964737724, 154.6192074346846, 157.2361567560545, 159.86038569764347, 162.49181436836977, 165.1303648232632, 167.7759609907039, 170.42852860330476, 173.08799513220984, 175.75428972459792, 178.427343144197, 181.10708771462768, 183.7934572654086, 186.48638708046707, 189.18581384901088, 191.89167561862462, 194.60391175046632, 197.32246287644588, 200.04727085827642, 202.7782787482962, 205.51543075196517, 208.25867219194697, 211.0079494736928, 213.7632100524482, 216.5244024016099, 219.29147598236315, 222.064381214535, 224.8430694486023, 227.6274929387984, 230.4176048172628, 233.2133590691847, 236.0147105088921], [0.0, 0.9403040926026391, 2.1602515287392627, 3.514097702406607, 4.962954754885243, 6.486827236786172, 8.073276500106662, 9.713728805203456, 11.401875925722784, 13.13286069815914, 14.902815552092477, 16.708580236444202, 18.547518870217488, 20.41739585955096, 22.316288598849052, 24.242524166415507, 26.19463223951612, 28.171309307633283, 30.171390960761236, 32.193830078927036, 34.23767941902572, 36.302077535029255, 38.386237263878854, 40.48943621330401, 42.611008830990585, 44.75033973684188, 46.90685807437893, 49.080032692072464, 51.26936800627399, 53.474400428305344, 55.69469526187473, 57.929843995217254, 60.17946192656894, 62.44318607276072, 64.72067331958203, 67.01159877964709, 69.3156543291977, 71.6325472998969, 73.96199930543511, 76.30374518586119, 78.65753205510138, 81.0231184392433, 83.40027349492587, 85.78877629865251, 88.18841519908707, 90.59898722544206, 93.0202975459594, 95.45215897124235, 97.89439149784604, 100.34682188809026, 102.80928328253744, 105.28161484199215, 107.76366141623694, 110.255273237031, 112.7563056331687, 115.26661876563354, 117.78607738108911, 120.31455058213226, 122.8519116128942, 125.39803765871625, 127.95280965875334, 130.51611213046863, 133.08783300508188, 135.66786347312214, 138.2560978393129, 140.85243338608933, 143.45677024510803, 146.06901127616766, 148.68906195300877, 151.3168302555053, 153.95222656780388, 156.59516358200122, 159.24555620698504, 161.90332148209382, 164.56837849527778, 167.240648305469, 169.92005386889034, 172.6065199690546, 175.2999731502234, 178.00034165411185, 180.70755535964304, 183.42154572556726, 186.14224573577746, 188.86958984716202, 191.60351393984837, 194.34395526970022, 197.09085242294154, 199.84414527278773, 202.6037749379737, 205.36968374307503, 208.14181518052536, 210.92011387423935, 213.7045255447566, 216.49499697582704, 219.29147598236315, 222.0939113796894, 224.902252954023, 227.71645143412428, 230.5364584640595, 233.36222657702038, 236.19370917014987, 239.03086048032566], [0.0, 0.9521940857112638, 2.1875675597888695, 3.5585328992682945, 5.025710514748705, 6.568852117618866, 8.17536177518464, 9.836557334252223, 11.546050801966281, 13.298923596774673, 15.091259243455166, 16.919857530065617, 18.782049245320476, 20.67557052663572, 22.5984744573791, 24.5490669620302, 26.525859125861732, 28.5275309556765, 30.552903317692635, 32.60091585127455, 34.6706093355815, 36.7611114317398, 38.87162502314114, 41.00141858298166, 43.149818143145865, 45.31620054215533, 47.499987705143276, 49.70064176425527, 51.917660869267785, 54.15057556949881, 56.39894567199231, 58.66235749941819, 60.94042148552093, 63.232770057268, 65.5390557618252, 67.85894960365826, 70.19213956283399, 72.5383292702716, 74.89723681951169, 77.26859369769846, 79.65214382105465, 82.04764266226931, 84.45485645900442, 86.87356149422156, 89.30354344028764, 91.74459675988243, 94.19652415763179, 96.65913607715933, 99.13225023890575, 101.61569121462841, 104.10929003497915, 106.61288382697695, 109.12631547855494, 111.64943332767714, 114.18209087379395, 116.72414650964713, 119.27546327164369, 121.835908607204, 124.40535415765186, 126.98367555535707, 129.57075223396944, 132.16646725069413, 134.77070711965933, 137.38336165551593, 140.00432382648773, 142.6334896161629, 145.27075789337906, 147.9160302896127, 150.56921108333512, 153.23020709084062, 155.8989275630979, 158.5752840882094, 161.25919049909942, 163.95056278608232, 166.64931901398856, 169.35537924355316, 172.06866545679293, 174.78910148612033, 177.516612946961, 180.25112717365826, 182.99257315846546, 185.74088149343984, 188.49598431506664, 191.2578152514521, 194.02630937193823, 196.80140313899935, 199.58303436229215, 202.37114215473855, 205.16566689052937, 207.96655016494384, 210.7737347558865, 213.58716458705044, 216.40678469262022, 219.23254118343488, 222.064381214535, 224.902252954023, 227.746105553171, 230.59588911771246, 233.45155468026067, 236.31305417379727, 239.18034040617957, 242.053367035618], [0.0, 0.9641088758637568, 2.2149405594854765, 3.603060767464255, 5.088597154194359, 6.651048064536269, 8.27765995308109, 9.959642026983785, 11.69052636053131, 13.46533282603516, 15.280095941478054, 17.13157545071435, 19.017068742658164, 20.934283627047304, 22.88124882551122, 24.85624906458821, 26.857776798783583, 28.88449551784529, 30.93521133350833, 33.00885061686057, 35.10444214434543, 37.221102661526125, 39.358025077486325, 41.514468711838354, 43.68975116311393, 45.88324147222449, 48.09435433086121, 50.322545140837356, 52.56730577228517, 54.828160900293376, 57.10466482377814, 59.39639868907123, 61.70296805528047, 64.02400074993757, 66.35914497253624, 68.70806761082613, 71.07045274057332, 73.44600028423524, 75.83442480786121, 78.23545443869816, 80.64882988859637, 83.07430357047842, 85.51163879694165, 87.96060905157974, 90.4209973248812, 92.89259550764041, 95.3752038357292, 97.86863038085514, 100.37269058259756, 102.88720681758286, 105.41200800215202, 107.94692922529686, 110.4918114090096, 113.04650099350951, 115.61084964508784, 118.18471398455686, 120.76795533450024, 123.36043948370992, 125.96203646735952, 128.57262036160859, 131.192069091462, 133.82026425082154, 136.45709093376837, 139.10243757620577, 141.75619580707058, 144.4182603083952, 147.08852868356445, 149.7669013331711, 152.45328133792432, 155.14757434811216, 157.84968847916213, 160.55953421287978, 163.27702430398222, 166.00207369157184, 168.7345994152256, 171.4745205353997, 174.22175805787307, 176.97623486197435, 179.73787563235612, 182.50660679409742, 185.28235645093275, 188.06505432641885, 190.85463170786576, 193.65102139286927, 196.45415763829507, 199.26397611157333, 202.08041384417393, 204.90340918713974, 207.7329017685647, 210.56883245291067, 213.41114330206298, 216.25977753803272, 219.11467950721809, 221.9757946461438, 224.8430694486023, 227.71645143412428, 230.59588911771246, 233.4813319807741, 236.37273044319434, 239.27003583649295, 242.17320037801267, 245.08217714608983], [0.0, 0.9760482583301363, 2.2423700574830976, 3.6476805418790708, 5.151613592650883, 6.733413665178238, 8.380169276022364, 10.082980768453053, 11.835300118916871, 13.632085526556764, 15.469322401409599, 17.343730360474378, 19.252573323927173, 21.193530715358836, 23.164606844377527, 25.164065195827355, 27.19037955499205, 29.242196860473232, 31.31830843906929, 33.41762736620561, 35.539170390835984, 37.682043320430644, 39.8454290691781, 42.02857778421373, 44.23079861330988, 46.45145278367346, 48.689947738623665, 50.945732135749964, 53.21829155257905, 55.507144777845916, 57.811840590970064, 60.131954951261065, 62.467088533128766, 64.81686455517578, 67.18092686025014, 69.55893821088837, 71.95057877049732, 74.3555447454183, 76.77354716692858, 79.2043107954429, 81.64757313182527, 84.10308352291631, 86.57060235021139, 89.04990029215837, 91.54075765183187, 94.04296374283248, 96.55631632718249, 99.08062109977773, 101.61569121462841, 104.16134684869924, 106.7174147996563, 109.28372811425777, 111.86012574449724, 114.44645222893223, 117.04255739691115, 119.64829609365954, 122.26352792440035, 124.88811701587363, 127.52193179378776, 130.16484477487992, 132.81673237239627, 135.47747471391483, 138.14695547053884, 140.82506169657813, 143.51168367891833, 146.20671479534957, 148.9100513811921, 151.62159260361423, 154.34124034309093, 157.0688990814973, 159.80447579637575, 162.5478798609518, 165.29902294950975, 168.05781894777036, 170.8241838679409, 173.59803576813417, 176.3792946758763, 179.1678825154449, 181.96372303879835, 184.76674175987466, 187.57686589205562, 190.3940242886048, 193.21814738590442, 196.04916714932554, 198.88701702158062, 201.73163187341467, 204.58294795650463, 207.4409028584417, 210.30543545968303, 213.1764858923647, 216.05399550087495, 218.93790680409458, 221.8281634592158, 224.72471022705727, 227.6274929387984, 230.5364584640595, 233.45155468026067, 236.37273044319434, 239.29993555875285, 242.23312075575254, 245.17223765980287, 248.1172387681692], [0.0, 0.9880120321448116, 2.269855592084046, 3.69239147146558, 5.214758769415529, 6.815947533153841, 8.482888018555188, 10.206571482602651, 11.980369640267964, 13.799178891531419, 15.658935438159833, 17.556318688320406, 19.488559025076807, 21.453307427881963, 23.44854374445063, 25.47251017453741, 27.523661796064467, 29.600628962674246, 31.702188186023903, 33.8272392187142, 35.97478675763796, 38.14392564982664, 40.33382879415471, 42.543737146541844, 44.77295138673669, 47.02082491227877, 49.286757903307375, 51.57019225941015, 53.870607252652924, 56.18751577339148, 58.520461070272724, 60.869013904987305, 63.232770057267984, 65.61134812737255, 68.00438759260301, 70.41154708185525, 72.8325028381842, 75.26694734422327, 77.71458808925638, 80.17514645998789, 82.64835673973569, 85.13396520299466, 87.63172929417016, 90.14141688083346, 92.66280557315514, 95.19568210227696, 97.73984175131775, 100.29508783350592, 102.86123121261333, 105.43808986144921, 108.02548845467646, 110.62325799264747, 113.2312354533326, 115.84926346974268, 118.47719003053056, 121.11486820170758, 123.76215586762753, 126.41891548958317, 129.08501388052952, 131.7603219945957, 134.44471473018064, 137.13807074554308, 139.84027228590116, 142.55120502114897, 145.27075789337903, 147.99882297347477, 150.73529532610132, 153.48007288248272, 156.2330563204077, 158.9941489509515, 161.76325661144682, 164.54028756427428, 167.32515240107816, 170.11776395204566, 172.91803719991546, 175.7258891984093, 178.541238994802, 181.3640075563689, 184.19411770046892, 187.0314940280376, 189.87606286028503, 192.72775217840368, 195.58649156610957, 198.4522121548489, 201.32484657151753, 204.20432888854788, 207.09059457623073, 209.98358045714605, 212.8832246625868, 215.78946659086716, 218.70224686741247, 221.62150730653687, 224.54719087481845, 227.47924165598954, 230.4176048172628, 233.36222657702038, 236.31305417379727, 239.27003583649295, 242.23312075575254, 245.2022590564579, 248.17740177127615, 251.15850081521452], [0.0, 1.0, 2.2973967099940706, 3.7371928188465535, 5.278031643091579, 6.898648307306076, 8.585814486631538, 10.33041213116187, 12.125732532083191, 13.966610165238244, 15.848931924611142, 17.769336928223968, 19.725021954206724, 21.713609480352545, 23.73305484301411, 25.781578913812194, 27.85761802547599, 29.95978591314941, 32.08684424338808, 34.237679419025724, 36.41128406052162, 38.606742032303444, 40.82321619767788, 43.05993830276175, 45.31620054215533, 47.59134846789699, 49.884774982257994, 52.195915213157626, 54.52424211444946, 56.86926266618194, 59.23051457504463, 61.60756339459824, 64.00000000000004, 66.40743836382347, 68.82951358899615, 71.26588016241398, 73.71621039885194, 76.18019304970518, 78.6575320551014, 81.14794542121197, 83.65116420730192, 86.16693160930726, 88.69500212860373, 91.23514081620168, 93.78712258392181, 96.35073157522464, 98.92576058931249, 101.51201055293, 104.10929003497915, 106.7174147996563, 109.33620739432789, 111.96549676880208, 114.60511792303402, 117.2549115806343, 119.91472388583779, 122.58440612184361, 125.2638144486563, 127.95280965875335, 130.651256949075, 133.35902570798223, 136.07598931596337, 138.80202495898646, 141.53701345350112, 144.28083908218585, 147.0333894396206, 149.79455528713925, 152.56423041618206, 155.34231151952952, 158.1286980698519, 160.9232922050568, 163.72599861996156, 166.53672446385536, 169.35537924355313, 172.18187473157386, 175.01612487910583, 177.85804573344853, 180.70755535964307, 183.56457376602742, 186.42902283347078, 189.30082624805996, 192.17990943702915, 195.0661995077362, 197.95962518950654, 200.86011677817507, 203.76760608317127, 206.68202637700057, 209.60331234698742, 212.5314000491535, 215.4662268641125, 218.4077314548728, 221.35585372644286, 224.3105347871453, 227.2717169115476, 230.2393435049263, 233.2133590691847, 236.19370917014987, 239.18034040617957, 242.17320037801267, 245.17223765980287, 248.17740177127615, 251.18864315095823, 254.20591313042084], [0.0, 1.0120119681431987, 2.324992966086809, 3.782083859931529, 5.34143119104719, 6.981514651004568, 8.68894701672837, 10.4545007125875, 12.271386444971522, 14.134376641611562, 16.039308789993296, 17.98278163733156, 19.961958289544548, 21.9744326657044, 24.018135541729183, 26.09126641840627, 28.192242845743404, 30.319661907115215, 32.47227039425543, 34.64894133350411, 36.84865524470957, 39.07048498770816, 41.313583370147306, 43.57717290990263, 45.8605372994385, 48.163014229585244, 50.48398931017551, 52.82289088390318, 55.17918557376028, 57.55237443765532, 59.94198962922533, 62.34759148347425, 64.76876596116476, 67.20512239792116, 69.65629151353903, 72.12192364462192, 74.60168716980029, 77.09526710176097, 79.6023638243699, 82.12269195649759, 84.65597932690152, 87.20196604679543, 89.76040366863346, 92.33105442122614, 94.91369051264215, 97.50809349348013, 100.11405367405303, 102.73136958984384, 105.35984751029035, 107.99930098655429, 110.64955043444672, 113.31042274912635, 115.98175094857304, 118.66337384317445, 121.35513572905494, 124.05688610303213, 126.76847939730912, 129.48977473220705, 132.22063568541614, 134.96093007639453, 137.71052976468098, 140.46931046100528, 143.23715155018806, 146.01393592491505, 148.79954982955587, 151.593882713273, 154.39682709173286, 157.20827841679295, 160.02813495359246, 162.85629766452263, 165.69267009959793, 168.53715829278784, 171.38967066390603, 174.25011792568574, 177.11841299569974, 179.9944709128103, 182.87820875785843, 185.7695455783248, 188.6684023167141, 191.57470174243286, 194.48836838694956, 197.40932848203798, 200.33750990092244, 203.27284210215367, 206.2152560760582, 209.16468429361285, 212.12106065760838, 215.08432045597334, 218.05440031713945, 221.03123816733702, 224.01477318971544, 227.00494578519235, 230.00169753493918, 233.00497116441846, 236.0147105088921, 239.03086048032566, 242.053367035618, 245.08217714608983, 248.1172387681692, 251.15850081521452, 254.20591313042084, 257.2594264607562]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 2.5000000000000004\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.003162277660168377, 0.007521206186172781, 0.012485374350863445, 0.01788854381999831, 0.02364354022507938, 0.029695392023038582, 0.036005807065272795, 0.042546367175559895, 0.04929503017546493, 0.056234132519034884, 0.06334915939718562, 0.07062794295318507, 0.07806011565155496, 0.08563672388687532, 0.09334994659327171, 0.10119288512538811, 0.10915940297580888, 0.11724400123787347, 0.12544172027751302, 0.13374806099528436, 0.14215892098196034, 0.1506705421691493, 0.15927946747250343, 0.16798250455586797, 0.17677669529663684, 0.1856592898615289, 0.19462772454491506, 0.20367960270359126, 0.2128126782595463, 0.22202484134768555, 0.23131410576702083, 0.24067859795752916, 0.25011654727506355, 0.2596262773765623, 0.2692061985597105, 0.278854800926934, 0.28857064826448064, 0.2983523725443993, 0.30819866897123294, 0.31810829150682024, 0.32808004881620917, 0.3381128005857138, 0.34820545417087306, 0.35835696153773977, 0.36856631646572396, 0.3788325519842912, 0.3891547380192859, 0.3995319792276305, 0.40996341300169703, 0.42044820762685725, 0.4309855605776132, 0.4415746969393655, 0.4522148679443101, 0.46290534961120555, 0.4736454414798519, 0.4844344654320764, 0.49527176459187194, 0.5061567022980749, 0.5170886611436247, 0.528067042076036, 0.5390912635542211, 0.5501607607572664, 0.5612749848411747, 0.5724334022399462, 0.5836354940077014, 0.5948807551988402, 0.6061686942834926, 0.6174988325957559, 0.6288707038124209, 0.6402838534600861, 0.651737838448728, 0.6632322266299546, 0.6747665963783116, 0.6863405361941362, 0.6979536443265747, 0.7096055284154843, 0.7212958051510344, 0.7330240999499174, 0.7447900466471514, 0.7565932872025407, 0.7684334714209161, 0.7803102566853521, 0.7922233077026015, 0.804172296260054, 0.8161569009935596, 0.8281768071655123, 0.8402317064526265, 0.8523212967428733, 0.8644452819410859, 0.8766033717827671, 0.8887952816556649, 0.9010207324287148, 0.9132794502879614, 0.9255711665791095, 0.9378956176563621, 0.9502525447372352, 0.9626416937630512, 0.9750628152648345, 0.9875156642343444, 1.0, 1.0125155861074646], [0.0, 0.007521206186172781, 0.017888543819998305, 0.02969539202303858, 0.04254636717555989, 0.05623413251903488, 0.07062794295318506, 0.08563672388687531, 0.10119288512538811, 0.11724400123787347, 0.13374806099528436, 0.15067054216914927, 0.16798250455586797, 0.18565928986152888, 0.20367960270359123, 0.22202484134768552, 0.24067859795752913, 0.2596262773765623, 0.27885480092693393, 0.2983523725443992, 0.3181082915068202, 0.33811280058571375, 0.3583569615377397, 0.37883255198429117, 0.39953197922763045, 0.4204482076268572, 0.4415746969393655, 0.4629053496112055, 0.48443446543207636, 0.5061567022980747, 0.5280670420760359, 0.5501607607572663, 0.5724334022399461, 0.5948807551988401, 0.6174988325957558, 0.6402838534600861, 0.6632322266299546, 0.686340536194136, 0.7096055284154843, 0.7330240999499172, 0.7565932872025407, 0.780310256685352, 0.804172296260054, 0.8281768071655123, 0.8523212967428732, 0.876603371782767, 0.9010207324287147, 0.9255711665791095, 0.9502525447372351, 0.9750628152648344, 1.0, 1.025062190204668, 1.0502475428109277, 1.0755542769387791, 1.1009806706609355, 1.1265250579928898, 1.15218582608873, 1.1779614126252138, 1.2038503033583696, 1.229851029838459, 1.2559621672705268, 1.2821823325089736, 1.308510182175702, 1.3349444108923387, 1.3614837496179173, 1.3881269640841731, 1.4148728533213057, 1.4417202482676774, 1.4686680104574943, 1.4957150307809997, 1.5228602283121881, 1.5501025491994427, 1.5774409656148787, 1.604874474758515, 1.6324020979136988, 1.6600228795504826, 1.6877358864739191, 1.715540207014453, 1.743434950257815, 1.7714192453120021, 1.7994922406091172, 1.8276531032399874, 1.855901018319641, 1.8842351883818476, 1.912654832801065, 1.9411591872402252, 1.969747503122928, 1.9984190471286825, 2.0271731007099407, 2.0560089596297457, 2.0849259335188846, 2.1139233454515285, 2.1430005315383815, 2.1721568405364353, 2.2013916334744916, 2.230704283293635, 2.260094174501923, 2.289560702842582, 2.3191032749750504, 2.3487213081682414, 2.3784142300054425, 2.4081814781002944], [0.0, 0.012485374350863445, 0.02969539202303858, 0.04929503017546494, 0.07062794295318507, 0.09334994659327173, 0.1172440012378735, 0.14215892098196037, 0.167982504555868, 0.1946277245449151, 0.22202484134768555, 0.2501165472750636, 0.27885480092693404, 0.30819866897123294, 0.3381128005857138, 0.368566316465724, 0.39953197922763045, 0.4309855605776133, 0.46290534961120555, 0.495271764591872, 0.528067042076036, 0.5612749848411747, 0.5948807551988403, 0.6288707038124209, 0.6632322266299547, 0.6979536443265747, 0.7330240999499174, 0.7684334714209163, 0.8041722962600543, 0.8402317064526266, 0.8766033717827673, 0.9132794502879614, 0.9502525447372351, 0.9875156642343444, 1.025062190204668, 1.0628858461504915, 1.1009806706609355, 1.139340993245212, 1.177961412625214, 1.2168367771787625, 1.255962167270527, 1.2953328792455945, 1.334944410892339, 1.3747924482078187, 1.414872853321306, 1.4551816534504913, 1.495715030781, 1.536469313173553, 1.577440965614879, 1.6186265823385309, 1.6600228795504828, 1.7016266887018776, 1.743434950257815, 1.7854447079167495, 1.8276531032399879, 1.8700573706551313, 1.9126548328010655, 1.955442896185462, 1.998419047128683, 2.0415808479705655, 2.084925933518885, 2.128452007720301, 2.1721568405364358, 2.216038265009323, 2.2600941745019236, 2.3043225201006785, 2.348721308168242, 2.393288598035547, 2.438022499823328, 2.482921172384014, 2.527982821355704, 2.573205697320603, 2.6185880940609048, 2.6641283469056987, 2.7098248311629476, 2.755675960631076, 2.8016801861851217, 2.8478359944327636, 2.8941419064359306, 2.9405964764939725, 2.987198290984697, 3.0339459672598195, 3.0808381525916437, 3.127873523167981, 3.175050783132571, 3.2223686636683935, 3.269825922121496, 3.317421341163087, 3.365153727987797, 3.4130219135461624, 3.461024751809497, 3.5091611190654364, 3.557429913242559, 3.605830053262572, 3.654360478418667, 3.703020147778696, 3.751808039611954, 3.8007231508383708, 3.849764496499038, 3.898931109247021, 3.9482220388574785, 3.997636351756189], [0.0, 0.01788854381999831, 0.04254636717555989, 0.07062794295318507, 0.10119288512538813, 0.13374806099528436, 0.167982504555868, 0.20367960270359123, 0.2406785979575292, 0.278854800926934, 0.31810829150682024, 0.35835696153773977, 0.3995319792276305, 0.4415746969393655, 0.48443446543207647, 0.528067042076036, 0.5724334022399462, 0.6174988325957559, 0.6632322266299546, 0.7096055284154843, 0.7565932872025407, 0.8041722962600542, 0.8523212967428733, 0.9010207324287147, 0.9502525447372352, 1.0, 1.050247542810928, 1.1009806706609357, 1.1521858260887303, 1.2038503033583696, 1.255962167270527, 1.3085101821757021, 1.3614837496179173, 1.4148728533213057, 1.4686680104574943, 1.5228602283121884, 1.5774409656148787, 1.6324020979136988, 1.6877358864739194, 1.7434349502578153, 1.7994922406091176, 1.855901018319641, 1.9126548328010653, 1.9697475031229281, 2.027173100709941, 2.0849259335188846, 2.1430005315383815, 2.201391633474492, 2.2600941745019236, 2.3191032749750504, 2.378414230005443, 2.438022499823328, 2.4979237008497606, 2.558113597414407, 2.618588094060905, 2.6793432283879954, 2.740375164380012, 2.8016801861851217, 2.8632546923039155, 2.92509519015464, 2.987198290984697, 3.0495607051009133, 3.112179237393704, 3.1750507831325714, 3.2381723240124214, 3.3015409244320515, 3.365153727987797, 3.4290079541668237, 3.493100895225887, 3.5574299132425584, 3.621992437327046, 3.686785960983667, 3.7518080396119537, 3.817056288138163, 3.8825283787686793, 3.9482220388574785, 4.014135048880419, 4.080265240509658, 4.146610494782019, 4.2131687403555675, 4.279937951849103, 4.346916148259592, 4.414101391453026, 4.481491784724373, 4.549085471422734, 4.616880633637951, 4.684875490945262, 4.7530682992047755, 4.82145734941278, 4.890040966602073, 4.958817508788697, 5.027785365962627, 5.096942959120114, 5.1662887393355215, 5.235821186870657, 5.305538810319675, 5.3754401457877785, 5.445523756102061, 5.515788230052885, 5.586232181664344, 5.656854249492382, 5.7276530959492815], [0.0, 0.02364354022507938, 0.05623413251903488, 0.09334994659327173, 0.13374806099528436, 0.1767766952966368, 0.22202484134768555, 0.2692061985597105, 0.31810829150682024, 0.36856631646572396, 0.4204482076268572, 0.4736454414798519, 0.528067042076036, 0.5836354940077013, 0.6402838534600861, 0.6979536443265747, 0.7565932872025406, 0.8161569009935596, 0.876603371782767, 0.9378956176563621, 1.0, 1.0628858461504913, 1.1265250579928898, 1.1908917877928655, 1.2559621672705268, 1.3217140793007052, 1.3881269640841731, 1.4551816534504913, 1.5228602283121884, 1.591145895319182, 1.6600228795504826, 1.7294763306899559, 1.7994922406091172, 1.8700573706551311, 1.9411591872402252, 2.0127858045673057, 2.0849259335188846, 2.157568835892544, 2.2307042832936355, 2.3043225201006785, 2.3784142300054425, 2.452970505701585, 2.527982821355704, 2.6034430075449837, 2.6793432283879954, 2.7556759606310757, 2.8324339744831732, 2.9096103160180133, 2.987198290984697, 3.0651914498868984, 3.143583574207339, 3.222368663668393, 3.301540924432051, 3.381094758153197, 3.461024751809497, 3.541325668239418, 3.621992437327046, 3.703020147778696, 3.7844040394418927, 3.8661394961221602, 3.9482220388574785, 4.030647319614062, 4.11341111537059, 4.196509322561049, 4.279937951849102, 4.363693123209307, 4.447771061292726, 4.5321680910563975, 4.616880633637952, 4.701905202458175, 4.787238399535833, 4.872876912000292, 4.958817508788696, 5.045057037515499, 5.131592421503104, 5.218420656963265, 5.305538810319674, 5.392944015662893, 5.4806334723294565, 5.568604442597571, 5.6568542494923815, 5.745380274694295, 5.834179956544297, 5.923250788140647, 6.012590315521712, 6.102196135930041, 6.192065896153156, 6.282197290936808, 6.37258806146673, 6.463235993915188, 6.554138918048868, 6.645294705894852, 6.736701270461652, 6.828356564512449, 6.920258579387876, 7.012405343875826, 7.104794923125942, 7.197425417606552, 7.290294962102013, 7.383401724748457, 7.476743906106105, 7.570319738266437], [0.0, 0.029695392023038582, 0.07062794295318506, 0.1172440012378735, 0.167982504555868, 0.22202484134768555, 0.27885480092693404, 0.3381128005857138, 0.3995319792276305, 0.46290534961120555, 0.528067042076036, 0.5948807551988403, 0.6632322266299548, 0.7330240999499172, 0.8041722962600543, 0.8766033717827671, 0.9502525447372352, 1.0250621902046682, 1.1009806706609355, 1.177961412625214, 1.2559621672705268, 1.334944410892339, 1.414872853321306, 1.4957150307809999, 1.577440965614879, 1.6600228795504828, 1.743434950257815, 1.8276531032399879, 1.9126548328010655, 1.9984190471286827, 2.084925933518885, 2.1721568405364358, 2.260094174501923, 2.3487213081682414, 2.4380224998233277, 2.5279828213557045, 2.6185880940609048, 2.709824831162947, 2.801680186185122, 2.8941419064359306, 2.987198290984697, 3.0808381525916433, 3.1750507831325714, 3.2698259221214965, 3.365153727987797, 3.461024751809497, 3.557429913242559, 3.654360478418667, 3.751808039611954, 3.8497644964990374, 3.948222038857479, 4.047173130565587, 4.146610494782018, 4.246527100197108, 4.346916148259593, 4.447771061292727, 4.5490854714227345, 4.650853210250558, 4.753068299204776, 4.855724940519772, 4.958817508788697, 5.062340543045618, 5.1662887393355215, 5.270656943734746, 5.3754401457877785, 5.4806334723294565, 5.586232181664344, 5.69223165807752, 5.798627406653245, 5.905415048379935, 6.012590315521713, 6.1201490472383995, 6.228087185437286, 6.33640077084139, 6.44508593926005, 6.554138918048869, 6.663556022746991, 6.773333653880585, 6.883468293922298, 6.993956504397129, 7.104794923125942, 7.215980261598381, 7.327509302467644, 7.439378897159984, 7.551585963592431, 7.664127483992528, 7.777000502814435, 7.890202124746026, 8.00372951280204, 8.117579886498598, 8.231750520104763, 8.346238740967056, 8.461041927903128, 8.576157509660986, 8.691582963440453, 8.807315813473707, 8.923353629661895, 9.039694026265103, 9.156334660643049, 9.27327323204402, 9.390507480439728, 9.508035185403962], [0.0, 0.036005807065272795, 0.08563672388687531, 0.14215892098196037, 0.20367960270359123, 0.2692061985597105, 0.3381128005857138, 0.40996341300169703, 0.4844344654320764, 0.5612749848411747, 0.6402838534600861, 0.7212958051510344, 0.8041722962600543, 0.8887952816556649, 0.9750628152648345, 1.0628858461504913, 1.15218582608873, 1.2428928845856204, 1.3349444108923387, 1.4282839344371685, 1.5228602283121881, 1.6186265823385306, 1.7155402070144532, 1.8135617398533532, 1.9126548328010653, 2.0127858045673057, 2.113923345451529, 2.2160382650093227, 2.3191032749750504, 2.423092801423771, 2.527982821355704, 2.633750719815032, 2.7403751643800116, 2.847835994432763, 2.956114123070951, 3.0651914498868984, 3.175050783132571, 3.285675770026582, 3.3970508341535224, 3.5091611190654364, 3.621992437327046, 3.73553122435578, 3.8497644964990374, 3.9646798128677236, 4.080265240509658, 4.196509322561049, 4.313401049060644, 4.43092983015069, 4.5490854714227345, 4.66785815119533, 4.787238399535833, 4.90721707886009, 5.027785365962627, 5.148934735346321, 5.270656943734745, 5.392944015662893, 5.515788230052884, 5.639182107690898, 5.763118399530049, 5.887590075751362, 6.012590315521713, 6.13811249739338, 6.264150190295149, 6.390697145069546, 6.517747286514923, 6.645294705894852, 6.773333653880585, 6.90185853389536, 7.030863895832011, 7.160344430117722, 7.290294962102013, 7.4207104467459555, 7.551585963592431, 7.682916711998865, 7.814698006615312, 7.946925273092117, 8.079594044002596, 8.212699954967242, 8.346238740967058, 8.480206232834401, 8.614598353910742, 8.749411116861296, 8.884640620637441, 9.020283047578216, 9.156334660643047, 9.292791800768175, 9.429650884339909, 9.566908400778239, 9.70456091022475, 9.842605041329236, 9.981037489129697, 10.11985501302081, 10.259054434806242, 10.398632636830458, 10.538586560186, 10.67891320299235, 10.819609618742849, 10.96067291471626, 11.102100250449869, 11.24388883627104, 11.386035931884505, 11.528538845012692], [0.0, 0.042546367175559895, 0.10119288512538811, 0.167982504555868, 0.2406785979575292, 0.31810829150682024, 0.3995319792276305, 0.4844344654320764, 0.5724334022399462, 0.6632322266299547, 0.7565932872025407, 0.8523212967428733, 0.9502525447372353, 1.0502475428109277, 1.1521858260887303, 1.2559621672705268, 1.3614837496179175, 1.4686680104574943, 1.5774409656148787, 1.6877358864739194, 1.7994922406091174, 1.9126548328010653, 2.027173100709941, 2.1430005315383815, 2.2600941745019236, 2.3784142300054425, 2.497923700849761, 2.6185880940609048, 2.740375164380012, 2.863254692303915, 2.987198290984697, 3.112179237393704, 3.2381723240124214, 3.3651537279877966, 3.4931008952258864, 3.621992437327046, 3.7518080396119537, 3.8825283787686793, 4.01413504888042, 4.146610494782019, 4.279937951849103, 4.414101391453026, 4.5490854714227345, 4.684875490945262, 4.82145734941278, 4.958817508788696, 5.096942959120113, 5.235821186870657, 5.3754401457877785, 5.515788230052884, 5.656854249492383, 5.798627406653245, 5.941097275568929, 6.0842537820608396, 6.228087185437286, 6.372588061466731, 6.517747286514924, 6.663556022746991, 6.810005704305487, 6.957088024384271, 7.104794923125942, 7.253118576277442, 7.402051384544672, 7.551585963592432, 7.701715134640938, 7.852431915614515, 8.00372951280204, 8.155601312992223, 8.30804087605, 8.461041927903128, 8.614598353910742, 8.768704192587842, 8.923353629661893, 9.078540992439562, 9.234260744463388, 9.390507480439728, 9.547275921420782, 9.704560910224751, 9.862357407079461, 10.020660485475789, 10.179465328218255, 10.338767223661064, 10.4985615621187, 10.658843832440935, 10.819609618742847, 10.980854597281049, 11.142574533467945, 11.304765279016404, 11.46742276920768, 11.630543020275939, 11.794122126903176, 11.958156259818633, 12.122641663497328, 12.287574653952483, 12.452951616617156, 12.61876900431046, 12.785023335284183, 12.951711191345828, 13.118829216054314, 13.286374112984824, 13.45434264405944, 13.622731627940498], [0.0, 0.04929503017546493, 0.11724400123787347, 0.1946277245449151, 0.278854800926934, 0.36856631646572396, 0.46290534961120555, 0.5612749848411747, 0.6632322266299547, 0.7684334714209163, 0.8766033717827671, 0.9875156642343446, 1.1009806706609357, 1.2168367771787623, 1.334944410892339, 1.4551816534504913, 1.577440965614879, 1.7016266887018774, 1.8276531032399876, 1.955442896185462, 2.0849259335188846, 2.2160382650093227, 2.3487213081682414, 2.482921172384014, 2.618588094060905, 2.755675960631076, 2.89414190643593, 3.03394596725982, 3.1750507831325714, 3.3174213411630875, 3.461024751809497, 3.6058300532625718, 3.7518080396119533, 3.89893110924702, 4.047173130565587, 4.196509322561049, 4.346916148259592, 4.4983712193045156, 4.650853210250558, 4.804341781349497, 4.958817508788697, 5.114261821494169, 5.270656943734745, 5.427985842868938, 5.586232181664344, 5.745380274694295, 5.905415048379935, 6.0663220043000345, 6.228087185437286, 6.390697145069546, 6.554138918048869, 6.718399994240826, 6.883468293922296, 7.049332144958363, 7.215980261598382, 7.383401724748458, 7.551585963592432, 7.7205227384467365, 7.890202124746027, 8.060614498066727, 8.231750520104763, 8.40360112553174, 8.576157509660984, 8.749411116861298, 8.923353629661893, 9.097976958497103, 9.27327323204402, 9.449234788110262, 9.625854165032866, 9.803124093552412, 9.9810374891297, 10.159587444674829, 10.338767223661064, 10.518570253598021, 10.698990119840794, 10.880020559713367, 11.06165545692642, 11.24388883627104, 11.426714858571339, 11.61012781588015, 11.794122126903176, 11.978692332637989, 12.163833092215286, 12.349539178930609, 12.535805476455712, 12.722626975219272, 12.909998768947567, 13.097916051356234, 13.286374112984824, 13.475368338166481, 13.66489420212549, 13.854947268195927, 14.045523185155117, 14.236617684665923, 14.428226578822338, 14.620345757793123, 14.812971187558588, 15.00609890773589, 15.199725029488564, 15.393845733516121, 15.588457268119903, 15.78355594734159], [0.0, 0.056234132519034884, 0.13374806099528436, 0.22202484134768555, 0.31810829150682024, 0.4204482076268572, 0.528067042076036, 0.6402838534600861, 0.7565932872025407, 0.8766033717827671, 1.0, 1.1265250579928898, 1.255962167270527, 1.3881269640841731, 1.5228602283121884, 1.6600228795504826, 1.7994922406091174, 1.9411591872402254, 2.0849259335188846, 2.2307042832936355, 2.3784142300054425, 2.527982821355704, 2.6793432283879954, 2.8324339744831732, 2.987198290984697, 3.143583574207339, 3.3015409244320515, 3.461024751809497, 3.621992437327046, 3.7844040394418927, 3.9482220388574785, 4.11341111537059, 4.279937951849102, 4.447771061292726, 4.616880633637951, 4.787238399535833, 4.958817508788696, 5.131592421503104, 5.305538810319675, 5.4806334723294565, 5.656854249492382, 5.834179956544297, 6.012590315521713, 6.192065896153156, 6.372588061466731, 6.554138918048868, 6.736701270461652, 6.920258579387876, 7.104794923125942, 7.290294962102013, 7.476743906106106, 7.664127483992528, 7.852431915614514, 8.041643885788375, 8.231750520104763, 8.422739362424165, 8.614598353910742, 8.807315813473707, 9.000880419498676, 9.195281192763018, 9.390507480439728, 9.58654894110338, 9.78339553065997, 9.9810374891297, 10.179465328218253, 10.37866981961791, 10.57864198398503, 10.779373080545138, 10.980854597281049, 11.183078241663145, 11.386035931884505, 11.589719788566473, 11.794122126903174, 11.999235449215965, 12.20505243789107, 12.41156594867578, 12.61876900431046, 12.826654788475318, 13.03521664003252, 13.244448047545587, 13.45434264405944, 13.664894202125488, 13.876096629057491, 14.087943962404669, 14.300430365629754, 14.513550123980234, 14.727297640542067, 14.941667432465746, 15.156654127355269, 15.372252459811254, 15.588457268119903, 15.805263491080147, 16.022666164961738, 16.240660420587485, 16.45924148053337, 16.678404656440474, 16.898145346433164, 17.118459032638288, 17.33934127880042, 17.56078772798846, 17.782794100389236, 18.00535619118397], [0.0, 0.06334915939718562, 0.15067054216914927, 0.2501165472750636, 0.35835696153773977, 0.4736454414798519, 0.5948807551988403, 0.7212958051510344, 0.8523212967428733, 0.9875156642343446, 1.1265250579928898, 1.2690587062858838, 1.414872853321306, 1.5637598087164173, 1.7155402070144534, 1.8700573706551313, 2.027173100709941, 2.1867644659792256, 2.3487213081682414, 2.5129442721023505, 2.6793432283879954, 2.8478359944327636, 3.018347285742643, 3.1908078473656882, 3.365153727987797, 3.5413256682394185, 3.7192685813617157, 3.898931109247021, 4.080265240509658, 4.263225980000804, 4.447771061292727, 4.633860695291451, 4.82145734941278, 5.0105255527618855, 5.201031723555243, 5.392944015662893, 5.586232181664344, 5.780867450229658, 5.9768224159789, 6.174070940253714, 6.372588061466732, 6.572349913887019, 6.773333653880585, 6.975517392759729, 7.1788801355086065, 7.383401724748457, 7.5890627893875875, 7.79584469747072, 8.00372951280204, 8.212699954967244, 8.422739362424165, 8.633831658369584, 8.845961319122859, 9.059113344795916, 9.27327323204402, 9.48842694871388, 9.704560910224751, 9.921661957535164, 10.139717336562812, 10.358714678938288, 10.578641983985031, 10.799487601828162, 11.021240217544102, 11.243888836271042, 11.467422769207678, 11.69183162043412, 11.917105274494755, 12.143233884688108, 12.370207862013524, 12.598017864728599, 12.82665478847532, 13.05610975693619, 13.286374112984824, 13.517439410298353, 13.749297405401498, 13.98194005011456, 14.215359484379722, 14.449548029441935, 14.684498181362516, 14.920202604845109, 15.15665412735527, 15.39384573351612, 15.631770559763932, 15.870421889248501, 16.109793146964343, 16.349877895099546, 16.5906698285902, 16.832162770868948, 17.074350669797067, 17.317227593770216, 17.56078772798846, 17.805025370881967, 18.049934930684234, 18.295510922145148, 18.541747963376835, 18.788640772825488, 19.0361841663629, 19.284373054491756, 19.53320243965915, 19.782667413673025, 20.032763155216603, 20.28348492745616], [0.0, 0.07062794295318507, 0.16798250455586797, 0.27885480092693404, 0.3995319792276305, 0.528067042076036, 0.6632322266299548, 0.8041722962600543, 0.9502525447372353, 1.1009806706609357, 1.255962167270527, 1.414872853321306, 1.5774409656148793, 1.743434950257815, 1.9126548328010657, 2.084925933518885, 2.2600941745019236, 2.438022499823328, 2.6185880940609048, 2.801680186185122, 2.9871982909846975, 3.1750507831325714, 3.3651537279877974, 3.557429913242559, 3.7518080396119546, 3.948222038857479, 4.146610494782019, 4.346916148259593, 4.5490854714227345, 4.753068299204776, 4.958817508788697, 5.1662887393355215, 5.3754401457877785, 5.586232181664344, 5.798627406653245, 6.012590315521714, 6.228087185437286, 6.44508593926005, 6.6635560227469925, 6.883468293922298, 7.104794923125943, 7.327509302467644, 7.551585963592433, 7.777000502814436, 8.00372951280204, 8.231750520104763, 8.46104192790313, 8.691582963440455, 8.923353629661895, 9.156334660643049, 9.39050748043973, 9.625854165032868, 9.862357407079461, 10.100000483212549, 10.338767223661065, 10.578641983985031, 10.819609618742849, 11.061655456926422, 11.304765279016408, 11.548925295524556, 11.794122126903178, 12.040342784713177, 12.287574653952483, 12.535805476455716, 12.785023335284183, 13.03521664003252, 13.286374112984825, 13.538484776059049, 13.791537938483636, 14.045523185155117, 14.300430365629758, 14.556249583706062, 14.812971187558588, 15.070585760386619, 15.329084111544097, 15.588457268119907, 15.848696466939915, 16.109793146964343, 16.37173894205608, 16.634525674097254, 16.898145346433164, 17.162590137623987, 17.4278523954863, 17.693924631407505, 17.9607995149176, 18.22846986850364, 18.496928662653335, 18.766169011115128, 19.0361841663629, 19.306967515254232, 19.578512574871873, 19.850812988538756, 20.123862521997488, 20.397655059745727, 20.67218460151965, 20.947445258917828, 21.223431252158566, 21.500136906964112, 21.777556651565483, 22.055685013822057, 22.334516618450404, 22.61404618435722], [0.0, 0.07806011565155496, 0.18565928986152888, 0.30819866897123294, 0.4415746969393655, 0.5836354940077013, 0.7330240999499172, 0.8887952816556649, 1.0502475428109277, 1.2168367771787623, 1.3881269640841731, 1.5637598087164173, 1.743434950257815, 1.9268964684175434, 2.113923345451529, 2.3043225201006785, 2.4979237008497606, 2.694575409387875, 2.8941419064359297, 3.0965007645379554, 3.301540924432051, 3.509161119065436, 3.7192685813617152, 3.9317779739681957, 4.146610494782018, 4.363693123209307, 4.582957980231518, 4.804341781349496, 5.027785365962627, 5.253233290138356, 5.480633472329456, 5.709936883609469, 5.941097275568928, 6.174070940253713, 6.408816497510863, 6.645294705894852, 6.883468293922295, 7.1233018089784546, 7.364761481599806, 7.607815103202789, 7.852431915614514, 8.098582510998568, 8.346238740967056, 8.595373633836225, 8.845961319122859, 9.097976958497103, 9.351396682507925, 9.606197532483145, 9.86235740707946, 10.11985501302081, 10.37866981961791, 10.638782016708621, 10.900172475699643, 11.16282271342547, 11.426714858571337, 11.69183162043412, 11.958156259818633, 12.225672561887787, 12.494364810803376, 12.764217766010422, 13.035216640032518, 13.30734707765818, 13.580595136409691, 13.854947268195927, 14.130390302059704, 14.406911427938242, 14.684498181362514, 14.963138429027783, 15.242820355173478, 15.523532448715635, 15.805263491080147, 16.088002544689044, 16.371738942056073, 16.656462275451346, 16.942162387097866, 17.22882935986581, 17.516453508432942, 17.805025370881964, 18.094535700707837, 18.38497545921001, 18.676335808246456, 18.968608103327874, 19.261783887032205, 19.555854882720748, 19.850812988538753, 20.14665027168416, 20.443358962929665, 20.74093145138404, 21.03936027947952, 21.33863813817326, 21.638757862351145, 21.939712426423505, 22.241494940102537, 22.544098644352097, 22.84751690750108, 23.151743221512053, 23.456771198397366, 23.76259456677548, 24.06920716856061, 24.376602955779223, 24.684775987507255, 24.993720426922376], [0.0, 0.08563672388687532, 0.20367960270359123, 0.3381128005857138, 0.48443446543207647, 0.6402838534600861, 0.8041722962600543, 0.9750628152648345, 1.1521858260887303, 1.334944410892339, 1.5228602283121884, 1.7155402070144534, 1.9126548328010657, 2.113923345451529, 2.3191032749750504, 2.527982821355704, 2.740375164380012, 2.9561141230709516, 3.175050783132571, 3.3970508341535224, 3.621992437327046, 3.8497644964990374, 4.080265240509658, 4.313401049060644, 4.5490854714227345, 4.787238399535833, 5.027785365962627, 5.270656943734745, 5.515788230052885, 5.763118399530049, 6.012590315521713, 6.264150190295149, 6.517747286514924, 6.773333653880585, 7.030863895832011, 7.290294962102014, 7.551585963592431, 7.814698006615313, 8.079594044002596, 8.346238740967058, 8.614598353910742, 8.884640620637441, 9.156334660643049, 9.42965088433991, 9.704560910224751, 9.9810374891297, 10.259054434806242, 10.538586560186001, 10.819609618742849, 11.102100250449869, 11.386035931884507, 11.67139493008658, 11.958156259818633, 12.246299643916998, 12.535805476455714, 12.82665478847532, 13.118829216054314, 13.412310970524116, 13.70708281064846, 14.00312801660586, 14.300430365629758, 14.598974109174662, 14.898743951489285, 15.199725029488565, 15.501902893826454, 15.805263491080149, 16.109793146964343, 16.415478550501227, 16.72230673907836, 17.030265084332203, 17.33934127880042, 17.649523323290627, 17.9607995149176, 18.273158435764728, 18.586588942129026, 18.90108015431218, 19.216621446922993, 19.53320243965915, 19.85081298853876, 20.16944317755419, 20.48908331072277, 20.80972390451072, 21.13135568060848, 21.45396955903689, 21.77755665156548, 22.10210825542493, 22.427615847297446, 22.754071077569574, 23.081465764833116, 23.409791890620763, 23.73904159436387, 24.06920716856061, 24.40028105414361, 24.73225583603658, 25.06512423889049, 25.398879122990007, 25.73351348032175, 26.069020430796385, 26.405393218616958, 26.74262520878638, 27.08070988374739, 27.419640840148695], [0.0, 0.09334994659327171, 0.22202484134768552, 0.368566316465724, 0.528067042076036, 0.6979536443265747, 0.8766033717827671, 1.0628858461504913, 1.2559621672705268, 1.4551816534504913, 1.6600228795504826, 1.8700573706551313, 2.084925933518885, 2.3043225201006785, 2.527982821355704, 2.755675960631076, 2.987198290984697, 3.2223686636683935, 3.4610247518094965, 3.703020147778696, 3.9482220388574785, 4.196509322561049, 4.447771061292727, 4.701905202458176, 4.958817508788697, 5.218420656963265, 5.4806334723294565, 5.745380274694296, 6.012590315521713, 6.282197290936809, 6.554138918048869, 6.828356564512449, 7.104794923125941, 7.383401724748457, 7.664127483992528, 7.946925273092117, 8.231750520104763, 8.518560828223016, 8.807315813473709, 9.097976958497105, 9.390507480439728, 9.684872211278373, 9.9810374891297, 10.2789710592985, 10.57864198398503, 10.880020559713365, 11.183078241663146, 11.487787574189394, 11.794122126903176, 12.10205643576096, 12.411565948675781, 12.722626975219272, 13.035216640032518, 13.34931283960595, 13.66489420212549, 13.981940050114558, 14.300430365629756, 14.620345757793125, 14.941667432465747, 15.264377163886861, 15.588457268119905, 15.913890578162063, 16.240660420587485, 16.568750593606403, 16.89814534643316, 17.22882935986581, 17.56078772798846, 17.894005940915495, 18.22846986850364, 18.564165744964, 18.90108015431218, 19.239200016599327, 19.57851257487187, 19.919005382811715, 20.26066629301257, 20.603483445851484, 20.947445258917824, 21.292540416964783, 21.63875786235115, 21.986086785943392, 22.334516618450404, 22.684037022165047, 23.03463788308876, 23.386309303416834, 23.739041594363865, 24.09282526930993, 24.44765103724967, 24.803509796527454, 25.160392628843, 25.518290793512865, 25.87719572197405, 26.23709901251698, 26.59799242523587, 26.95986787718519, 27.322717437731754, 27.686533324092494, 28.051307897048567, 28.41703365682718, 28.783703239142817, 29.151309411390177, 29.51984506898147, 29.889303231821323], [0.0, 0.10119288512538811, 0.24067859795752913, 0.39953197922763045, 0.5724334022399462, 0.7565932872025406, 0.9502525447372352, 1.15218582608873, 1.3614837496179175, 1.577440965614879, 1.7994922406091174, 2.027173100709941, 2.2600941745019236, 2.4979237008497606, 2.740375164380012, 2.987198290984697, 3.238172324012422, 3.4931008952258864, 3.7518080396119533, 4.014135048880419, 4.279937951849102, 4.5490854714227345, 4.82145734941278, 5.096942959120113, 5.3754401457877785, 5.656854249492382, 5.941097275568929, 6.228087185437286, 6.517747286514924, 6.810005704305486, 7.104794923125942, 7.402051384544671, 7.701715134640938, 8.003729512802039, 8.308040876049999, 8.614598353910742, 8.923353629661893, 9.234260744463386, 9.547275921420782, 9.862357407079461, 10.179465328218255, 10.4985615621187, 10.819609618742847, 11.142574533467945, 11.46742276920768, 11.794122126903174, 12.122641663497326, 12.452951616617156, 12.785023335284183, 13.118829216054312, 13.454342644059441, 13.791537938483632, 14.130390302059705, 14.470875774217932, 14.812971187558587, 15.15665412735527, 15.501902893826454, 15.848696466939913, 16.197014473538406, 16.546837156596, 16.898145346433164, 17.250920433735086, 17.605144344232535, 17.9607995149176, 18.31786887167829, 18.676335808246456, 19.0361841663629, 19.397398217071775, 19.759962643064203, 20.12386252199748, 20.48908331072277, 20.85561083035931, 21.223431252158562, 21.592531084105985, 21.96289715821237, 22.334516618450404, 22.707376909295512, 23.081465764833116, 23.45677119839737, 23.83328149270886, 24.210985190481317, 24.589871085469333, 24.969928213931286, 25.351145846483266, 25.733513480321747, 26.117020831793926, 26.501657829296413, 26.887414606484064, 27.27428149577196, 27.662249022114768, 28.051307897048567, 28.441449012981295, 28.832663437718892, 29.224942409214783, 29.618277330531523, 30.012659765003605, 30.408081431591544, 30.804534200417656, 31.202010088474722, 31.600501255499044, 32.00000000000002, 32.40049875543889], [0.0, 0.10915940297580888, 0.2596262773765623, 0.4309855605776133, 0.6174988325957559, 0.8161569009935596, 1.0250621902046682, 1.2428928845856204, 1.4686680104574943, 1.7016266887018774, 1.9411591872402254, 2.1867644659792256, 2.438022499823328, 2.694575409387875, 2.9561141230709516, 3.2223686636683935, 3.4931008952258864, 3.7680989902071325, 4.047173130565586, 4.330152113531563, 4.616880633637951, 4.90721707886009, 5.201031723555243, 5.498205231819358, 5.798627406653245, 6.102196135930041, 6.4088164975108635, 6.718399994240826, 7.030863895832011, 7.34613066939165, 7.664127483992528, 7.984785777497683, 8.308040876049999, 8.633831658369582, 8.962100258377783, 9.292791800768175, 9.625854165032864, 9.961237774173066, 10.298895404911612, 10.638782016708623, 10.980854597281049, 11.325072022658741, 11.67139493008658, 12.019785602314577, 12.370207862013523, 12.72262697521927, 13.077009562849534, 13.433323519456765, 13.791537938483634, 14.151623043375455, 14.513550123980236, 14.87729147773241, 15.242820355173476, 15.61011090941229, 15.979138149170863, 16.349877895099546, 16.72230673907836, 17.096402006250607, 17.472141719560508, 17.84950456658919, 18.22846986850364, 18.60901755095088, 18.99112811674556, 19.374782620213228, 19.7599626430642, 20.14665027168416, 20.534828075737707, 20.924479087990164, 21.31558678526117, 21.70813507043068, 22.10210825542493, 22.497491045115652, 22.894268522071325, 23.29242613210416, 23.69194967056096, 24.092825269309934, 24.495039384379442, 24.898578784207693, 25.303430538465786, 25.709582007418984, 26.117020831793926, 26.525734923121583, 26.93571245452807, 27.34694185194729, 27.759411785731295, 28.173111162635745, 28.58802911815953, 29.00415500921895, 29.421478407138164, 29.83998909093877, 30.259677040912617, 30.680532432462748, 31.102545630198588, 31.5257071822721, 31.950007814942765, 32.37543842735958, 32.801990086549395, 33.22965402260123, 33.65842162403711, 34.0882844333602, 34.51923414277184, 34.95126259004944], [0.0, 0.11724400123787347, 0.27885480092693393, 0.46290534961120555, 0.6632322266299546, 0.876603371782767, 1.1009806706609355, 1.3349444108923387, 1.5774409656148787, 1.8276531032399876, 2.0849259335188846, 2.3487213081682414, 2.6185880940609048, 2.8941419064359297, 3.175050783132571, 3.4610247518094965, 3.7518080396119533, 4.047173130565586, 4.346916148259592, 4.650853210250557, 4.958817508788696, 5.270656943734745, 5.586232181664343, 5.905415048379934, 6.228087185437286, 6.554138918048868, 6.883468293922296, 7.215980261598381, 7.551585963592431, 7.8902021247460254, 8.231750520104763, 8.576157509660982, 8.923353629661891, 9.273273232044016, 9.625854165032864, 9.981037489129697, 10.338767223661062, 10.698990119840792, 11.06165545692642, 11.426714858571337, 11.794122126903174, 12.163833092215283, 12.535805476455712, 12.909998768947567, 13.286374112984822, 13.664894202125488, 14.045523185155115, 14.428226578822336, 14.812971187558587, 15.199725029488562, 15.588457268119903, 15.979138149170863, 16.371738942056073, 16.76623188560376, 17.162590137623987, 17.56078772798846, 17.9607995149176, 18.3626011442023, 18.766169011115128, 19.171480224790077, 19.57851257487187, 19.98724450025444, 20.39765505974572, 20.809723904510722, 21.22343125215856, 21.638757862351145, 22.055685013822053, 22.474194482703908, 22.894268522071325, 23.315889842614258, 23.739041594363865, 24.163707349399242, 24.589871085469333, 25.017517170469485, 25.446630347716976, 25.87719572197405, 26.309198746171152, 26.742625208786375, 27.177461221840698, 27.61369320947135, 28.051307897048563, 28.490292300803276, 28.930633717935937, 29.37231971717829, 29.81533812978242, 30.259677040912614, 30.705324781417637, 31.15226991996236, 31.60050125549904, 32.050007810059945, 32.50077882185413, 32.95280373865222, 33.4060722114443, 33.860574088356564, 34.31629940881379, 34.77323839793487, 35.23138146114996, 35.690719179028164, 36.15124230230549, 36.61294174710331, 37.07580859032814, 37.53983406524427], [0.0, 0.12544172027751302, 0.2983523725443992, 0.495271764591872, 0.7096055284154843, 0.9378956176563621, 1.177961412625214, 1.4282839344371685, 1.6877358864739194, 1.955442896185462, 2.2307042832936355, 2.5129442721023505, 2.801680186185122, 3.0965007645379554, 3.3970508341535224, 3.703020147778696, 4.014135048880419, 4.330152113531563, 4.650853210250557, 4.976041599504572, 5.305538810319675, 5.639182107690898, 5.976822415978899, 6.31832259902603, 6.663556022746992, 7.012405343875827, 7.364761481599806, 7.7205227384467365, 8.079594044002596, 8.441886300496765, 8.807315813473707, 9.175803794004825, 9.54727592142078, 9.921661957535163, 10.298895404911612, 10.678913202992351, 11.06165545692642, 11.447065194764132, 11.835088149360718, 12.225672561887789, 12.618769004310462, 13.014330218569238, 13.412310970524116, 13.812667916985287, 14.215359484379722, 14.620345757793123, 15.027588379288483, 15.437050454540064, 15.848696466939915, 16.262492198434973, 16.678404656440478, 17.096402006250607, 17.516453508432942, 17.938529460750203, 18.362601144202305, 18.788640772825488, 19.216621446922993, 19.646517109435568, 20.078302505189512, 20.511953142785874, 20.947445258917828, 21.384755784923378, 21.823862315399005, 22.264743078715973, 22.70737690929551, 23.151743221512053, 23.597821985105288, 24.04559370199215, 24.495039384379442, 24.946140534085835, 25.398879122990007, 25.85323757452824, 26.309198746171152, 26.766745912814883, 27.225862751027037, 27.686533324092494, 28.148742067808307, 28.612473776980714, 29.077713592581013, 29.54444698951997, 30.012659765003608, 30.48233802743569, 30.95346818583492, 31.426036939736807, 31.900031269552663, 32.37543842735958, 32.85224592809744, 33.33044154115036, 33.81001328229156, 34.290949405972086, 34.77323839793487, 35.256868968137006, 35.74183004396416, 36.228110763721915, 36.71570047039007, 37.20458870562628, 37.69476520400687, 38.186219887492854, 38.67894286011023, 39.17292440283416, 39.66815496866706, 40.16462517790166], [0.0, 0.13374806099528436, 0.3181082915068202, 0.528067042076036, 0.7565932872025407, 1.0, 1.2559621672705268, 1.5228602283121881, 1.7994922406091174, 2.0849259335188846, 2.3784142300054425, 2.6793432283879954, 2.9871982909846975, 3.301540924432051, 3.621992437327046, 3.9482220388574785, 4.279937951849102, 4.616880633637951, 4.958817508788696, 5.305538810319675, 5.656854249492382, 6.012590315521713, 6.372588061466731, 6.736701270461651, 7.104794923125942, 7.476743906106105, 7.852431915614514, 8.231750520104763, 8.614598353910742, 9.000880419498676, 9.390507480439728, 9.78339553065997, 10.179465328218253, 10.578641983985028, 10.980854597281047, 11.386035931884505, 11.794122126903174, 12.20505243789107, 12.61876900431046, 13.03521664003252, 13.45434264405944, 13.87609662905749, 14.300430365629756, 14.727297640542067, 15.156654127355269, 15.588457268119903, 16.022666164961738, 16.45924148053337, 16.898145346433164, 17.33934127880042, 17.78279410038924, 18.228469868503637, 18.676335808246456, 19.126360250595333, 19.57851257487187, 20.032763155216603, 20.48908331072277, 20.947445258917824, 21.407822072313007, 21.87018763776898, 22.334516618450404, 22.800784418163886, 23.26896714789332, 23.73904159436387, 24.210985190481317, 24.684775987507255, 25.160392628843002, 25.63781432530616, 26.11702083179393, 26.597992425235866, 27.080709883747385, 27.565154466902168, 28.051307897048563, 28.539152341601, 29.028670396242738, 29.51984506898147, 30.012659765003608, 30.507098272277148, 31.003144747857075, 31.500783704850225, 32.00000000000002, 32.50077882185413, 33.00310567948089, 33.50696639170253, 34.01234707681574, 34.51923414277184, 35.02761427779083, 35.53747444138541, 36.048801855772496, 36.561583997651255, 37.075808590328144, 37.59146359617052, 38.108537209371725, 38.62701784901145, 39.14689415239642, 39.668154968667054, 40.190789352656886, 40.71478655899211, 41.240136036419685, 41.76682742235269, 42.29485053762259, 42.82419538142855], [0.0, 0.14215892098196034, 0.33811280058571375, 0.5612749848411747, 0.8041722962600542, 1.0628858461504913, 1.334944410892339, 1.6186265823385306, 1.9126548328010653, 2.2160382650093227, 2.527982821355704, 2.8478359944327636, 3.1750507831325714, 3.509161119065436, 3.8497644964990374, 4.196509322561049, 4.5490854714227345, 4.90721707886009, 5.270656943734745, 5.639182107690898, 6.012590315521713, 6.390697145069546, 6.773333653880585, 7.160344430117723, 7.551585963592432, 7.946925273092117, 8.346238740967056, 8.749411116861298, 9.156334660643049, 9.566908400778239, 9.9810374891297, 10.398632636830456, 10.819609618742847, 11.24388883627104, 11.671394930086578, 12.10205643576096, 12.535805476455712, 12.972577487758967, 13.412310970524118, 13.854947268195929, 14.300430365629756, 14.74870670684175, 15.199725029488564, 15.65343621417769, 16.109793146964343, 16.5687505936064, 17.030265084332203, 17.49429480803198, 17.9607995149176, 18.429740426809925, 18.90108015431218, 19.374782620213225, 19.850812988538756, 20.329137598733144, 20.809723904510722, 21.292540416964787, 21.77755665156548, 22.26474307871597, 22.754071077569577, 23.245512892840097, 23.73904159436387, 24.23463103919506, 24.732255836036575, 25.231891311827148, 25.733513480321747, 26.237099012516982, 26.74262520878638, 27.250069972602226, 27.7594117857313, 28.270629684801182, 28.783703239142813, 29.298612529822307, 29.815338129782422, 30.333861085020352, 30.85416289673418, 31.376225504375782, 31.900031269552667, 32.425562960725486, 32.95280373865223, 33.48173714253334, 34.01234707681574, 34.54461779861639, 35.07853390572913, 35.614080325180815, 36.15124230230549, 36.69000539030698, 37.230355440282736, 37.772278591683396, 38.31576126318415, 38.86079014394581, 39.407352185244584, 39.9554345924511, 40.505024817340555, 41.05611055071667, 41.60867971533359, 42.1627204591005, 42.718221148554875, 43.27517036259098, 43.8335568864313, 44.39336970582889, 44.95459800148955, 45.51723114370365], [0.0, 0.1506705421691493, 0.3583569615377397, 0.5948807551988403, 0.8523212967428733, 1.1265250579928898, 1.414872853321306, 1.7155402070144532, 2.027173100709941, 2.3487213081682414, 2.6793432283879954, 3.018347285742643, 3.3651537279877974, 3.7192685813617152, 4.080265240509658, 4.447771061292727, 4.82145734941278, 5.201031723555243, 5.586232181664343, 5.976822415978899, 6.372588061466731, 6.773333653880585, 7.178880135508606, 7.589062789387587, 8.00372951280204, 8.422739362424165, 8.84596131912286, 9.273273232044017, 9.704560910224751, 10.139717336562812, 10.57864198398503, 11.0212402175441, 11.467422769207678, 11.917105274494753, 12.370207862013523, 12.82665478847532, 13.286374112984822, 13.749297405401498, 14.215359484379722, 14.684498181362516, 15.15665412735527, 15.63177055976393, 16.109793146964343, 16.5906698285902, 17.074350669797067, 17.56078772798846, 18.049934930684234, 18.541747963376835, 19.0361841663629, 19.53320243965915, 20.032763155216603, 20.534828075737707, 21.039360279479524, 21.54632409049481, 22.055685013822057, 22.56740967518821, 23.08146576483312, 23.597821985105288, 24.116448001513877, 24.63731439695308, 25.160392628843002, 25.685654988955452, 26.213074565715168, 26.74262520878638, 27.27428149577196, 27.808018700868104, 28.34381276533124, 28.881640269626462, 29.421478407138167, 29.96330495933328, 30.507098272277148, 31.052837234409928, 31.60050125549904, 32.15007024668998, 32.701524601583834, 33.254845178275474, 33.81001328229156, 34.3670106503718, 34.925819435041646, 35.48642218992788, 36.048801855772496, 36.61294174710331, 37.17882553952268, 37.74643725757849, 38.31576126318415, 38.886782244556194, 39.45948520564089, 40.03385545600254, 40.6098786011483, 41.18754053326599, 41.76682742235269, 42.3477257077136, 42.930222089811686, 43.514303522450014, 44.099957205269895, 44.687170576548596, 45.27593130628182, 45.86622728953671, 46.45804664006235, 47.05137768414489, 47.646208954695894, 48.24252918556264], [0.0, 0.15927946747250343, 0.37883255198429117, 0.6288707038124209, 0.9010207324287147, 1.1908917877928655, 1.4957150307809999, 1.8135617398533532, 2.1430005315383815, 2.482921172384014, 2.8324339744831732, 3.1908078473656882, 3.557429913242559, 3.9317779739681957, 4.313401049060644, 4.701905202458176, 5.096942959120113, 5.498205231819358, 5.905415048379934, 6.31832259902603, 6.736701270461651, 7.160344430117723, 7.589062789387587, 8.022682219806546, 8.461041927903128, 8.903992917212113, 9.351396682507925, 9.803124093552412, 10.25905443480624, 10.719074574486577, 11.183078241663145, 11.650965394192381, 12.122641663497324, 12.598017864728597, 13.077009562849533, 13.559536686795745, 14.045523185155115, 14.534896717865768, 15.027588379288483, 15.523532448715637, 16.022666164961738, 16.52492952216483, 17.030265084332203, 17.538617816502793, 18.049934930684234, 18.564165744964, 19.08126155439954, 19.60117551246688, 20.123862521997484, 20.64927913466126, 21.17738345816496, 21.70813507043068, 22.241494940102537, 22.777425352801874, 23.31588984261426, 23.85685312834695, 24.400281054143605, 24.946140534085835, 25.494399500448406, 26.045026855308127, 26.59799242523587, 27.153266918826905, 27.710821886848134, 28.270629684801186, 28.832663437718885, 29.396897007028915, 29.96330495933328, 30.53186253696539, 31.102545630198584, 31.675330750990238, 32.25019500815585, 32.827116083875616, 33.4060722114443, 33.987042154182156, 34.57000518543134, 35.154941069567755, 35.74183004396415, 36.33065280184477, 36.9213904759765, 37.51402462314545, 38.108537209371725, 38.70491059581837, 39.30312752535387, 39.90317110973008, 40.50502481734054, 41.10867246152609, 41.71409818939723, 42.321286471144745, 42.93022208981168, 43.540890131501925, 44.153275976001964, 44.767365287793936, 45.38314400743964, 46.00059834331618, 46.619714763685444, 47.240479989080356, 47.862880984992024, 48.48690495484304, 49.11253933323282, 49.73977177944168, 50.36859017118141, 50.998982598580426], [0.0, 0.16798250455586797, 0.39953197922763045, 0.6632322266299547, 0.9502525447372352, 1.2559621672705268, 1.577440965614879, 1.9126548328010653, 2.2600941745019236, 2.618588094060905, 2.987198290984697, 3.365153727987797, 3.7518080396119546, 4.146610494782018, 4.5490854714227345, 4.958817508788697, 5.3754401457877785, 5.798627406653245, 6.228087185437286, 6.663556022746992, 7.104794923125942, 7.551585963592432, 8.00372951280204, 8.461041927903128, 8.923353629661895, 9.390507480439728, 9.862357407079461, 10.338767223661064, 10.819609618742849, 11.304765279016406, 11.794122126903176, 12.287574653952483, 12.785023335284182, 13.286374112984824, 13.791537938483632, 14.300430365629756, 14.812971187558587, 15.329084111544095, 15.848696466939915, 16.37173894205608, 16.898145346433164, 17.427852395486298, 17.9607995149176, 18.496928662653332, 19.0361841663629, 19.57851257487187, 20.123862521997484, 20.67218460151965, 21.223431252158566, 21.77755665156548, 22.334516618450408, 22.894268522071325, 23.456771198397366, 24.02198487233457, 24.589871085469337, 25.160392628843002, 25.73351348032175, 26.309198746171155, 26.887414606484068, 27.468128264145413, 28.05130789704857, 28.636922613305174, 29.224942409214783, 29.81533812978243, 30.408081431591544, 31.003144747857075, 31.600501255499044, 32.20012484409089, 32.8019900865494, 33.4060722114443, 34.01234707681574, 34.62079114539729, 35.23138146114996, 35.84409562702092, 36.458911783846816, 37.075808590328144, 37.69476520400687, 38.31576126318415, 38.93877686972043, 39.563792572663786, 40.190789352656886, 40.81974860707595, 41.45065213585905, 42.08348212798341, 42.71822114855487, 43.35485212647449, 43.993358342650225, 44.633723418723385, 45.27593130628181, 45.91996627653348, 46.56581291041575, 47.21345608911744, 47.86288098499203, 48.514073052841745, 49.16701802155372, 49.821701886070194, 50.47811089967616, 51.13623156658864, 51.79605063483302, 52.457555089392166, 53.12073214561548, 53.78556924287549], [0.0, 0.17677669529663684, 0.4204482076268572, 0.6979536443265747, 1.0, 1.3217140793007052, 1.6600228795504828, 2.0127858045673057, 2.3784142300054425, 2.755675960631076, 3.143583574207339, 3.5413256682394185, 3.948222038857479, 4.363693123209307, 4.787238399535833, 5.218420656963265, 5.656854249492382, 6.102196135930041, 6.554138918048868, 7.012405343875827, 7.476743906106105, 7.946925273092117, 8.422739362424165, 8.903992917212113, 9.390507480439728, 9.882117688026188, 10.37866981961791, 10.880020559713367, 11.386035931884505, 11.896590376553437, 12.41156594867578, 12.930851616240876, 13.45434264405944, 13.981940050114558, 14.513550123980234, 15.049083998595476, 15.588457268119903, 16.13158964576402, 16.678404656440478, 17.228829359865813, 17.78279410038924, 18.34023228036234, 18.90108015431218, 19.465276641556507, 20.032763155216603, 20.60348344585148, 21.17738345816496, 21.754411199431143, 22.334516618450404, 22.917651493990405, 23.50376933178997, 24.092825269309934, 24.684775987507255, 25.279579628989215, 25.87719572197405, 26.4775851095462, 27.08070988374739, 27.686533324092494, 28.2950198401405, 28.90613491778749, 29.519845068981475, 30.136117784587345, 30.754921490156175, 31.376225504375785, 32.00000000000002, 32.626215967072305, 33.254845178275474, 33.88586015625446, 34.51923414277185, 35.154941069567755, 35.79295553080669, 36.433252757003316, 37.075808590328144, 37.72059946120173, 38.36760236609361, 39.016794846448306, 39.66815496866706, 40.32166130507892, 40.97729291584041, 41.63502933170677, 42.294850537622594, 42.95673695708279, 43.62066943721896, 44.28662923456877, 44.95459800148955, 45.624557773179156, 46.29649095527054, 46.970380311968064, 47.646208954695894, 48.32396033123102, 49.003618215294736, 49.68516669657849, 50.36859017118142, 51.05387333243807, 51.74100116211679, 52.42995892196947, 53.12073214561548, 53.81330663074298, 54.507668431612274, 55.20380385184633, 55.90169943749478, 56.60134197035835], [0.0, 0.1856592898615289, 0.4415746969393655, 0.7330240999499174, 1.050247542810928, 1.3881269640841731, 1.743434950257815, 2.113923345451529, 2.497923700849761, 2.89414190643593, 3.3015409244320515, 3.7192685813617157, 4.146610494782019, 4.582957980231518, 5.027785365962627, 5.4806334723294565, 5.941097275568929, 6.4088164975108635, 6.883468293922296, 7.364761481599806, 7.852431915614514, 8.346238740967056, 8.84596131912286, 9.351396682507925, 9.862357407079461, 10.37866981961791, 10.900172475699645, 11.426714858571339, 11.958156259818635, 12.494364810803376, 13.035216640032518, 13.580595136409693, 14.130390302059705, 14.684498181362514, 15.242820355173476, 15.805263491080149, 16.371738942056076, 16.942162387097866, 17.516453508432946, 18.094535700707837, 18.67633580824646, 19.261783887032205, 19.850812988538756, 20.44335896292967, 21.039360279479524, 21.638757862351145, 22.241494940102537, 22.847516907501085, 23.45677119839737, 24.06920716856061, 24.68477598750726, 25.303430538465786, 25.925125325717687, 26.549816388639105, 27.177461221840698, 27.808018700868107, 28.4414490129813, 29.07771359258101, 29.71677506089401, 30.35859716956747, 31.003144747857075, 31.65038365312356, 32.30028072437952, 32.95280373865223, 33.60792136994971, 34.265603150636345, 34.925819435041646, 35.58854136514097, 36.253740838161214, 36.9213904759765, 37.59146359617053, 38.26393418465219, 38.93877686972042, 39.615966897482316, 40.295480108536545, 40.9772929158404, 41.661382283685676, 42.3477257077136, 43.036301195905025, 43.72708725048594, 44.420062850693576, 45.11520743635157, 45.81250089220694, 46.51192353298445, 47.21345608911744, 47.91707969311662, 48.622775866541225, 49.33052650753923, 50.04031387892538, 50.75212059676812, 51.465929619458116, 52.181724237232906, 52.899488062133926, 53.619205018373435, 54.34085933309051, 55.06443552747631, 55.78991840825012, 56.51729305946881, 57.24654483465356, 57.97765934921804, 58.71062247318391, 59.44542032416989], [0.0, 0.19462772454491506, 0.4629053496112055, 0.7684334714209163, 1.1009806706609357, 1.4551816534504913, 1.8276531032399879, 2.2160382650093227, 2.6185880940609048, 3.03394596725982, 3.461024751809497, 3.898931109247021, 4.346916148259593, 4.804341781349496, 5.270656943734745, 5.745380274694296, 6.228087185437286, 6.718399994240826, 7.215980261598381, 7.7205227384467365, 8.231750520104763, 8.749411116861298, 9.273273232044017, 9.803124093552412, 10.338767223661064, 10.880020559713367, 11.426714858571339, 11.97869233263799, 12.535805476455714, 13.097916051356234, 13.66489420212549, 14.236617684665921, 14.812971187558585, 15.39384573351612, 15.979138149170863, 16.5687505936064, 17.162590137623987, 17.760568387020275, 18.362601144202305, 18.968608103327878, 19.578512574871873, 20.192241236110668, 20.809723904510722, 21.430893331421526, 22.055685013822057, 22.68403702216505, 23.31588984261426, 23.951186232183467, 24.589871085469337, 25.231891311827148, 25.877195721974054, 26.525734923121586, 27.177461221840698, 27.832328533951067, 28.490292300803283, 29.151309411390177, 29.815338129782425, 30.482338027435695, 31.152269919962368, 31.82509580800116, 32.500778821854134, 33.179283169591926, 33.860574088356564, 34.5446177986164, 35.23138146114996, 35.92083313655579, 36.612941747103314, 37.307677040755706, 38.00500955721081, 38.70491059581837, 39.407352185244584, 40.11230705476489, 40.81974860707595, 41.529650892526405, 42.241988584673834, 42.95673695708279, 43.67387186128498, 44.39336970582888, 45.115207436351575, 45.839362516610244, 46.56581291041575, 47.2945370644144, 48.025513891668304, 48.75872275598772, 49.494143456972715, 50.23175621572339, 50.971541661181696, 51.7134808170698, 52.45755508939216, 53.20374625447117, 53.952036447487636, 54.70240815149937, 55.45484418691312, 56.20932770138612, 56.965842160135594, 57.72437133663525, 58.48489930367965, 59.24741042479797, 60.01188934600039, 60.778320987840516, 61.54669053777904, 62.31698344283409], [0.0, 0.20367960270359126, 0.48443446543207636, 0.8041722962600543, 1.1521858260887303, 1.5228602283121884, 1.9126548328010655, 2.3191032749750504, 2.740375164380012, 3.1750507831325714, 3.621992437327046, 4.080265240509658, 4.5490854714227345, 5.027785365962627, 5.515788230052885, 6.012590315521713, 6.517747286514924, 7.030863895832011, 7.551585963592431, 8.079594044002596, 8.614598353910742, 9.156334660643049, 9.704560910224751, 10.25905443480624, 10.819609618742849, 11.386035931884505, 11.958156259818635, 12.535805476455714, 13.118829216054314, 13.707082810648458, 14.300430365629756, 14.898743951489283, 15.501902893826454, 16.109793146964343, 16.72230673907836, 17.33934127880042, 17.9607995149176, 18.586588942129023, 19.216621446922993, 19.85081298853876, 20.48908331072277, 21.131355680608475, 21.77755665156548, 22.427615847297446, 23.08146576483312, 23.739041594363865, 24.400281054143605, 25.06512423889049, 25.73351348032175, 26.405393218616954, 27.08070988374739, 27.7594117857313, 28.4414490129813, 29.12677333800277, 29.815338129782425, 30.50709827227715, 31.202010088474722, 31.900031269552667, 32.60112080870929, 33.305238939283264, 34.01234707681575, 34.722407764742044, 35.43538462342963, 36.1512423023055, 36.869946434839385, 37.59146359617053, 38.31576126318415, 39.04280777686123, 39.77257230673988, 40.50502481734055, 41.24013603641968, 41.97787742492737, 42.71822114855487, 43.46114005076682, 44.20660762722148, 44.95459800148955, 45.70508590198942, 46.45804664006234, 47.21345608911745, 47.97129066478107, 48.731527305990056, 49.494143456972715, 50.25911705006555, 51.026426489316925, 51.79605063483301, 52.56796878782342, 53.34216067630781, 54.11860644144675, 54.89728662446254, 55.67818215411844, 56.46127433472611, 57.246544834653555, 58.03397567530735, 58.82354922056455, 59.61524816663148, 60.40905553230758, 61.20495464963413, 62.002929154908735, 62.80296298004778, 63.60504034427979, 64.40914574615381, 65.21526395584804], [0.0, 0.2128126782595463, 0.5061567022980747, 0.8402317064526266, 1.2038503033583696, 1.591145895319182, 1.9984190471286827, 2.423092801423771, 2.863254692303915, 3.3174213411630875, 3.7844040394418927, 4.263225980000804, 4.753068299204776, 5.253233290138356, 5.763118399530049, 6.282197290936809, 6.810005704305486, 7.34613066939165, 7.8902021247460254, 8.441886300496765, 9.000880419498676, 9.566908400778239, 10.139717336562812, 10.719074574486577, 11.304765279016406, 11.896590376553437, 12.494364810803376, 13.097916051356234, 13.707082810648458, 14.321713933744116, 14.941667432465747, 15.566809640893641, 16.197014473538403, 16.832162770868948, 17.472141719560508, 18.116844336974747, 18.766169011115124, 19.42001908870575, 20.078302505189512, 20.740931451384043, 21.407822072313007, 22.078894194377163, 22.754071077569577, 23.433279189892385, 24.116448001513877, 24.803509796527454, 25.494399500448406, 26.18905452181789, 26.887414606484068, 27.58942170330174, 28.2950198401405, 29.004155009218955, 29.716775060894008, 30.432829605130724, 31.152269919962364, 31.875048866324242, 32.60112080870929, 33.33044154115036, 34.06296821808423, 34.79865928969643, 35.53747444138542, 36.27937453701903, 37.02432156568735, 37.7722785916834, 38.52320970746785, 39.27707998939568, 40.03385545600254, 40.79350302866622, 41.55599049447448, 42.321286471144745, 43.089360373854255, 43.8601823838506, 44.63372341872338, 45.40995510422725, 46.18884974755508, 46.970380311968064, 47.754520392696655, 48.54124419403269, 49.33052650753925, 50.12234269130981, 50.91666865021386, 51.7134808170698, 52.5127561346912, 53.314472038755255, 54.118606441446744, 54.92513771583318, 55.73404468093046, 56.54530658742074, 57.35890310398692, 58.17481430423028, 58.993020654140295, 59.81350300008718, 60.63624255731014, 61.46122089887535, 62.28841994508005, 63.1178219532798, 63.94940950811789, 64.78316551213689, 65.61907317675386, 66.45711601358114, 67.29727782607648, 68.13954270150671], [0.0, 0.22202484134768555, 0.5280670420760359, 0.8766033717827673, 1.255962167270527, 1.6600228795504826, 2.084925933518885, 2.527982821355704, 2.987198290984697, 3.461024751809497, 3.9482220388574785, 4.447771061292727, 4.958817508788697, 5.480633472329456, 6.012590315521713, 6.554138918048869, 7.104794923125942, 7.664127483992528, 8.231750520104763, 8.807315813473707, 9.390507480439728, 9.9810374891297, 10.57864198398503, 11.183078241663145, 11.794122126903176, 12.41156594867578, 13.035216640032518, 13.66489420212549, 14.300430365629756, 14.941667432465747, 15.588457268119905, 16.240660420587485, 16.89814534643316, 17.56078772798846, 18.228469868503637, 18.90108015431218, 19.57851257487187, 20.26066629301257, 20.947445258917828, 21.63875786235115, 22.334516618450404, 23.03463788308876, 23.73904159436387, 24.44765103724967, 25.160392628843002, 25.87719572197405, 26.59799242523587, 27.322717437731757, 28.05130789704857, 28.783703239142817, 29.519845068981475, 30.259677040912617, 31.00314474785707, 31.750195618513153, 32.500778821854134, 33.254845178275474, 34.01234707681574, 34.77323839793487, 35.53747444138542, 36.305011858758625, 37.075808590328144, 37.84982380585019, 38.62701784901145, 39.40735218524459, 40.190789352656886, 40.9772929158404, 41.7668274223527, 42.55935836167534, 43.3548521264745, 44.153275976001964, 44.95459800148955, 45.758787093400784, 46.56581291041575, 47.37564585003439, 48.18825702069272, 49.003618215294736, 49.821701886070194, 50.64248112067506, 51.46592961945812, 52.29202167382239, 53.12073214561548, 53.95203644748763, 54.78591052416075, 55.622330834555264, 56.461274334726106, 57.30271846156145, 58.14664111720193, 58.993020654140295, 59.84183586096424, 60.693065948707876, 61.54669053777904, 62.402689645432126, 63.26104367375797, 64.12173339816387, 64.98473995631905, 65.85004483754147, 66.71762987260436, 67.58747722394136, 68.45956937623103, 69.33388912734198, 70.21041957962153, 71.0891441315115], [0.0, 0.23131410576702083, 0.5501607607572663, 0.9132794502879614, 1.3085101821757021, 1.7294763306899559, 2.1721568405364358, 2.633750719815032, 3.112179237393704, 3.6058300532625718, 4.11341111537059, 4.633860695291451, 5.1662887393355215, 5.709936883609469, 6.264150190295149, 6.828356564512449, 7.402051384544671, 7.984785777497683, 8.576157509660982, 9.175803794004825, 9.78339553065997, 10.398632636830456, 11.0212402175441, 11.650965394192381, 12.287574653952483, 12.930851616240876, 13.580595136409693, 14.236617684665921, 14.898743951489283, 15.566809640893641, 16.240660420587485, 16.92015100405432, 17.60514434423253, 18.295510922145144, 18.99112811674556, 19.691879644579608, 20.39765505974572, 21.10834930616235, 21.823862315399005, 22.544098644352097, 23.26896714789332, 23.998380682321613, 24.732255836036575, 25.470512684343543, 26.213074565715168, 26.959867877185186, 27.710821886848134, 28.465868561692776, 29.224942409214783, 29.987980331440635, 30.754921490156175, 31.525707182272097, 32.30028072437951, 33.078587345653844, 33.860574088356564, 34.64618971526495, 35.43538462342963, 36.228110763721915, 37.02432156568735, 37.82397186726953, 38.62701784901145, 39.4334169723788, 40.24312792188367, 41.05611055071667, 41.87232582962249, 42.691735798777586, 43.51430352245001, 44.339993046240885, 45.168769356724106, 46.00059834331617, 46.83544676222265, 47.67328220231981, 48.51407305284174, 49.35778847275376, 50.20439836170204, 51.053873332438066, 51.90618468462451, 52.76130437993577, 53.619205018373435, 54.47985981572232, 55.343242582078624, 56.20932770138611, 57.078090111921455, 57.949505287673354, 58.82354922056454, 59.7001984034685, 60.5794298139768, 61.46122089887534, 62.34554955929069, 63.2323941364705, 64.12173339816387, 65.01354652557005, 65.90781310082588, 66.80451309500376, 67.70362685659465, 68.60513510045085, 69.50901889716599, 70.41525966287041, 71.32383914942173, 72.23473943497116, 73.14794291488762, 74.06343229302281], [0.0, 0.24067859795752916, 0.5724334022399461, 0.9502525447372351, 1.3614837496179173, 1.7994922406091172, 2.260094174501923, 2.7403751643800116, 3.2381723240124214, 3.7518080396119533, 4.279937951849102, 4.82145734941278, 5.3754401457877785, 5.941097275568928, 6.517747286514924, 7.104794923125941, 7.701715134640938, 8.308040876049999, 8.923353629661891, 9.54727592142078, 10.179465328218253, 10.819609618742847, 11.467422769207678, 12.122641663497324, 12.785023335284182, 13.45434264405944, 14.130390302059705, 14.812971187558585, 15.501902893826454, 16.197014473538403, 16.89814534643316, 17.60514434423253, 18.317868871678286, 19.036184166362897, 19.759962643064195, 20.489083310722766, 21.22343125215856, 21.962897158212368, 22.707376909295512, 23.456771198397366, 24.210985190481317, 24.969928213931283, 25.733513480321747, 26.501657829296413, 27.27428149577196, 28.051307897048563, 28.83266343771889, 29.618277330531523, 30.408081431591544, 31.20201008847472, 32.00000000000002, 32.801990086549395, 33.60792136994971, 34.417736862040954, 35.23138146114996, 36.048801855772496, 36.869946434839385, 37.69476520400686, 38.52320970746785, 39.35523295483072, 40.190789352656886, 41.029834640287184, 41.87232582962249, 42.71822114855487, 43.567479987773375, 44.42006285069357, 45.27593130628181, 46.135047944565706, 46.997376334639846, 47.86288098499202, 48.73152730599005, 49.6032815743822, 50.478110899676146, 51.35598319227252, 52.23686713323839, 53.12073214561547, 54.00754836716544, 54.89728662446253, 55.78991840825012, 56.685415849984096, 57.58375169949179, 58.48489930367963, 59.388832586228546, 60.295526028219165, 61.20495464963412, 62.11709399168725, 63.03192009993373, 63.949409508117874, 64.86953922271815, 65.79228670815189, 66.71762987260435, 67.64554705444895, 68.57601700922825, 69.50901889716597, 70.44453227118379, 71.38253706539636, 72.3230135840616, 73.26594249096267, 74.21130479920166, 75.15908186138377, 76.1092553601742, 77.06180729920948], [0.0, 0.25011654727506355, 0.5948807551988401, 0.9875156642343444, 1.4148728533213057, 1.8700573706551311, 2.3487213081682414, 2.847835994432763, 3.3651537279877966, 3.89893110924702, 4.447771061292726, 5.0105255527618855, 5.586232181664344, 6.174070940253713, 6.773333653880585, 7.383401724748457, 8.003729512802039, 8.633831658369582, 9.273273232044016, 9.921661957535163, 10.578641983985028, 11.24388883627104, 11.917105274494753, 12.598017864728597, 13.286374112984824, 13.981940050114558, 14.684498181362514, 15.39384573351612, 16.109793146964343, 16.832162770868948, 17.56078772798846, 18.295510922145144, 19.036184166362897, 19.78266741367302, 20.534828075737703, 21.292540416964783, 22.05568501382205, 22.82414827071057, 23.597821985105288, 24.376602955779223, 25.160392628843, 25.94909677709178, 26.742625208786375, 27.540891502527614, 28.343812765331236, 29.151309411390173, 29.96330495933328, 30.779725846064103, 31.600501255499044, 32.425562960725486, 33.254845178275474, 34.0882844333602, 34.92581943504164, 35.76739096043112, 36.61294174710331, 37.46241639300135, 38.31576126318415, 39.172924402834155, 40.03385545600254, 40.89850558962061, 41.76682742235269, 42.638774957906044, 43.51430352245001, 44.39336970582889, 45.275931306281805, 46.16194727840873, 47.05137768414488, 47.94418364652649, 48.840327306049836, 49.739771779441675, 50.64248112067506, 51.54842028407761, 52.45755508939215, 53.36985218866059, 54.285279034812135, 55.20380385184633, 56.12539560650969, 57.05002398137229, 57.977659349218044, 58.90827274866821, 59.84183586096423, 60.7783209878405, 61.717701030423456, 62.659949469097064, 63.60504034427978, 64.55294823806074, 65.50364825664765, 66.45711601358113, 67.41332761367372, 68.37225963763441, 69.33388912734196, 70.29819357173272, 71.26515089327091, 72.23473943497116, 73.20693794794518, 74.18172557944578, 75.15908186138377, 76.13898669929365, 77.1214203617269, 78.1063634700515, 79.09379698863826, 80.08370221541588], [0.0, 0.2596262773765623, 0.6174988325957558, 1.025062190204668, 1.4686680104574943, 1.9411591872402252, 2.4380224998233277, 2.956114123070951, 3.4931008952258864, 4.047173130565587, 4.616880633637951, 5.201031723555243, 5.798627406653245, 6.408816497510863, 7.030863895832011, 7.664127483992528, 8.308040876049999, 8.962100258377783, 9.625854165032864, 10.298895404911612, 10.980854597281047, 11.671394930086578, 12.370207862013523, 13.077009562849533, 13.791537938483632, 14.513550123980234, 15.242820355173476, 15.979138149170863, 16.72230673907836, 17.472141719560508, 18.228469868503637, 18.99112811674556, 19.759962643064195, 20.534828075737703, 21.315586785261168, 22.102108255424927, 22.89426852207132, 23.69194967056096, 24.495039384379442, 25.303430538465786, 26.117020831793926, 26.93571245452807, 27.759411785731295, 28.58802911815953, 29.421478407138164, 30.259677040912614, 31.102545630198584, 31.950007814942765, 32.801990086549395, 33.6584216240371, 34.51923414277184, 35.38436175457746, 36.25374083816121, 37.12730991890939, 38.00500955721081, 38.886782244556194, 39.772572306739875, 40.66232581356004, 41.55599049447448, 42.453515659722854, 43.35485212647449, 44.259952149602604, 45.1687693567241, 46.08125868717727, 46.99737633463984, 47.91707969311661, 48.840327306049836, 49.76707881832711, 50.69729493098114, 51.63093735839252, 52.56796878782341, 53.50835284112308, 54.452054038460105, 55.39903776394717, 56.34927023303494, 57.30271846156145, 58.259350236351814, 59.219134087271186, 60.182039260641304, 61.148035693937196, 62.11709399168725, 63.08918540250469, 64.06428179718439, 65.04235564780282, 66.0233800077641, 67.00732849273803, 67.99417526244056, 68.98389500321, 69.97646291133526, 70.97185467709593, 71.97004646947555, 72.97101492151289, 73.97473711625791, 74.98119057330074, 75.99035323584496, 77.00220345829705, 78.01671999434654, 79.03388198551237, 80.05366895013276, 81.07606077277691, 82.10103769405828, 83.12858030083045], [0.0, 0.2692061985597105, 0.6402838534600861, 1.0628858461504915, 1.5228602283121884, 2.0127858045673057, 2.5279828213557045, 3.0651914498868984, 3.621992437327046, 4.196509322561049, 4.787238399535833, 5.392944015662893, 6.012590315521714, 6.645294705894852, 7.290294962102014, 7.946925273092117, 8.614598353910742, 9.292791800768175, 9.981037489129697, 10.678913202992351, 11.386035931884505, 12.10205643576096, 12.82665478847532, 13.559536686795745, 14.300430365629756, 15.049083998595476, 15.805263491080149, 16.5687505936064, 17.33934127880042, 18.116844336974747, 18.90108015431218, 19.691879644579608, 20.489083310722766, 21.292540416964783, 22.102108255424927, 22.917651493990405, 23.739041594363865, 24.56615629098673, 25.398879122990007, 26.237099012516982, 27.08070988374739, 27.929610317771157, 28.783703239142817, 29.64289563052065, 30.50709827227715, 31.376225504375782, 32.250195008155856, 33.128927605962936, 34.01234707681575, 34.90037998651739, 35.79295553080669, 36.690005390306986, 37.59146359617052, 38.49726640543866, 39.407352185244584, 40.321661305078926, 41.240136036419685, 42.162720459100505, 43.08936037385426, 44.02000322052478, 44.95459800148956, 45.89309520987968, 46.83544676222266, 47.781605935168415, 48.731527305990056, 49.6851666965785, 50.642481120675065, 51.603428734108554, 52.567968787823425, 53.536061583503475, 54.50766843161227, 55.482751611685735, 56.461274334726106, 57.44320070755827, 58.428495699020566, 59.41712510787208, 60.40905553230758, 61.404254340979215, 62.40268964543214, 63.40433027386763, 64.40914574615383, 65.41710625000971, 66.42818261829375, 67.44234630733263, 68.45956937623102, 69.47982446710623, 70.50308478619645, 71.529324085794, 72.55851664695842, 73.5906372629676, 74.62566122346705, 75.66356429928067, 76.70432272784838, 77.74791319925818, 78.79431284284237, 79.84349921430908, 80.89545028338259, 81.95014442192705, 83.00756039253012, 84.06767733752396, 85.13047476842262, 86.19593255575616], [0.0, 0.278854800926934, 0.6632322266299546, 1.1009806706609355, 1.5774409656148787, 2.0849259335188846, 2.6185880940609048, 3.175050783132571, 3.7518080396119537, 4.346916148259592, 4.958817508788696, 5.586232181664344, 6.228087185437286, 6.883468293922295, 7.551585963592431, 8.231750520104763, 8.923353629661893, 9.625854165032864, 10.338767223661062, 11.06165545692642, 11.794122126903174, 12.535805476455712, 13.286374112984822, 14.045523185155115, 14.812971187558587, 15.588457268119903, 16.371738942056076, 17.162590137623987, 17.9607995149176, 18.766169011115124, 19.57851257487187, 20.39765505974572, 21.22343125215856, 22.05568501382205, 22.89426852207132, 23.739041594363865, 24.589871085469333, 25.446630347716976, 26.309198746171152, 27.177461221840698, 28.051307897048567, 28.930633717935933, 29.815338129782422, 30.705324781417637, 31.60050125549904, 32.50077882185413, 33.4060722114443, 34.31629940881379, 35.23138146114996, 36.15124230230549, 37.075808590328144, 38.00500955721081, 38.938776869720414, 39.87704450029096, 40.81974860707596, 41.76682742235269, 42.71822114855487, 43.67387186128498, 44.633723418723385, 45.59772137690866, 46.56581291041575, 47.53794673800318, 48.51407305284174, 49.49414345697272, 50.478110899676146, 51.46592961945811, 52.45755508939216, 53.45294396557278, 54.45205403846011, 55.45484418691311, 56.461274334726106, 57.47130540949826, 58.48489930367964, 59.50201883765012, 60.522627724698395, 61.54669053777904, 62.57417267793481, 63.60504034427978, 64.63926050544701, 65.67680087241132, 66.71762987260435, 67.76171662524501, 68.8090309178141, 69.85954318360628, 70.91322448029837, 71.97004646947553, 73.02998139706246, 74.09300207460899, 75.15908186138377, 76.22819464723214, 77.30031483615738, 78.37541733058698, 79.4534775162885, 80.53447124790081, 81.61837483505006, 82.70516502901994, 83.79481900994901, 84.88731437452876, 85.9826291241781, 87.08074165367084, 88.18163074019448, 89.28527553282002], [0.0, 0.28857064826448064, 0.686340536194136, 1.139340993245212, 1.6324020979136988, 2.157568835892544, 2.709824831162947, 3.285675770026582, 3.8825283787686793, 4.4983712193045156, 5.131592421503104, 5.780867450229658, 6.44508593926005, 7.1233018089784546, 7.814698006615313, 8.518560828223016, 9.234260744463386, 9.961237774173066, 10.698990119840792, 11.447065194764132, 12.20505243789107, 12.972577487758967, 13.749297405401498, 14.534896717865768, 15.329084111544095, 16.13158964576402, 16.942162387097866, 17.760568387020275, 18.586588942129023, 19.42001908870575, 20.26066629301257, 21.10834930616235, 21.962897158212368, 22.82414827071057, 23.69194967056096, 24.56615629098673, 25.446630347716976, 26.33324078042809, 27.225862751027037, 28.12437719164208, 29.028670396242738, 29.938633650688022, 30.85416289673418, 31.77515842614736, 32.701524601583834, 33.633169601338125, 34.57000518543135, 35.51194648082866, 36.45891178384681, 37.41082237804495, 38.36760236609361, 39.32917851428971, 40.295480108536545, 41.266438820738394, 42.241988584673834, 43.22206548051173, 44.20660762722147, 45.19555508220612, 46.18884974755509, 47.18643528237272, 48.18825702069272, 49.19426189453471, 50.20439836170204, 51.218616337956334, 52.23686713323839, 53.259103391634255, 54.285279034812135, 55.31534920868, 56.34927023303494, 57.38699955399485, 58.42849569902056, 59.47371823435227, 60.522627724698395, 61.57518569502803, 62.63135459432979, 63.691097761210614, 64.75437939121782, 65.82116450577644, 66.89141892264203, 67.96510922777652, 69.04220274856145, 70.12266752826886, 71.20647230171619, 72.29358647203621, 73.3839800884985, 74.47762382532241, 75.57448896142621, 76.67454736106096, 77.77777145528005, 78.88413422419988, 79.99360918000907, 81.10617035068657, 82.22179226439185, 83.34044993449216, 84.46211884519458, 85.58677493775201, 86.71439459721437, 87.84495463969799, 88.97843230014817, 90.11480522057029, 91.2540514387075, 92.39614937714366], [0.0, 0.2983523725443993, 0.7096055284154843, 1.177961412625214, 1.6877358864739194, 2.2307042832936355, 2.801680186185122, 3.3970508341535224, 4.01413504888042, 4.650853210250558, 5.305538810319675, 5.9768224159789, 6.6635560227469925, 7.364761481599806, 8.079594044002596, 8.807315813473709, 9.547275921420782, 10.298895404911612, 11.06165545692642, 11.835088149360718, 12.61876900431046, 13.412310970524118, 14.215359484379722, 15.027588379288483, 15.848696466939915, 16.678404656440478, 17.516453508432946, 18.362601144202305, 19.216621446922993, 20.078302505189512, 20.947445258917828, 21.823862315399005, 22.707376909295512, 23.597821985105288, 24.495039384379442, 25.398879122990007, 26.309198746171152, 27.225862751027037, 28.14874206780831, 29.077713592581013, 30.01265976500361, 30.95346818583492, 31.900031269552667, 32.852245928097446, 33.810013282291564, 34.773238397934875, 35.74183004396416, 36.715700470390075, 37.69476520400688, 38.67894286011023, 39.66815496866707, 40.66232581356004, 41.661382283685676, 42.66525373482014, 43.67387186128499, 44.6871705765486, 45.70508590198943, 46.72755586312695, 47.75452039269666, 48.78592124000678, 49.8217018860702, 50.861807464052966, 51.90618468462452, 52.95478176583326, 54.00754836716545, 55.06443552747632, 56.1253956065097, 57.19038222974738, 58.25935023635183, 59.33225562998532, 60.40905553230759, 61.489708138969355, 62.57417267793482, 63.66240936997894, 64.75437939121782, 65.85004483754147, 66.94936869082811, 68.0523147868285, 69.15884778461736, 70.26893313751576, 71.38253706539638, 72.49962652828908, 73.62016920121053, 74.7441334501467, 75.87148830912264, 77.00220345829706, 78.13624920302532, 79.27359645383655, 80.41421670727526, 81.55808202756069, 82.70516502901995, 83.85543885925435, 85.00887718300041, 86.16545416664955, 87.32514446339327, 88.48792319896131, 89.65376595792397, 90.82264877052984, 91.9945481000536, 93.16944083062823, 94.34730425553883, 95.5281160659562], [0.0, 0.30819866897123294, 0.7330240999499172, 1.2168367771787625, 1.7434349502578153, 2.3043225201006785, 2.8941419064359306, 3.5091611190654364, 4.146610494782019, 4.804341781349497, 5.4806334723294565, 6.174070940253714, 6.883468293922298, 7.607815103202789, 8.346238740967058, 9.097976958497105, 9.862357407079461, 10.638782016708623, 11.426714858571337, 12.225672561887789, 13.03521664003252, 13.854947268195929, 14.684498181362516, 15.523532448715637, 16.37173894205608, 17.228829359865813, 18.094535700707837, 18.968608103327878, 19.85081298853876, 20.740931451384043, 21.63875786235115, 22.544098644352097, 23.456771198397366, 24.376602955779223, 25.303430538465786, 26.237099012516982, 27.177461221840698, 28.12437719164208, 29.077713592581013, 30.037343258018037, 31.00314474785708, 31.975001953430287, 32.95280373865223, 33.93644361332668, 34.925819435041646, 35.92083313655579, 36.92139047597651, 37.92740080736829, 38.93877686972043, 39.9554345924511, 40.97729291584041, 42.00427362496959, 43.03630119590502, 44.073302653005285, 45.115207436351575, 46.161947278408746, 47.21345608911745, 48.26966984870054, 49.33052650753925, 50.39596589253853, 51.46592961945812, 52.540361010735694, 53.619205018373435, 54.702408151499384, 55.78991840825012, 56.88168521165344, 57.977659349218044, 59.077792915962775, 60.18203926064131, 61.29035293493828, 62.40268964543213, 63.51900620813648, 64.63926050544701, 65.7634114453352, 66.89141892264203, 68.02324378233698, 69.15884778461735, 70.29819357173274, 71.44124463642814, 72.58796529190687, 73.73832064322177, 74.89227656000968, 76.04979965049043, 77.21085723665671, 78.375417330587, 79.54344861181741, 80.71492040571349, 81.88980266278669, 83.0680659389037, 84.24968137634038, 85.43462068563534, 86.62285612820058, 87.81436049964995, 89.00910711380796, 90.20706978736465, 91.40822282514313, 92.61254100594984, 93.81999956897793, 95.03057420073742, 96.2442410224859, 97.46097657813603, 98.68075782261728], [0.0, 0.31810829150682024, 0.7565932872025407, 1.255962167270527, 1.7994922406091176, 2.3784142300054425, 2.987198290984697, 3.621992437327046, 4.279937951849103, 4.958817508788697, 5.656854249492382, 6.372588061466732, 7.104794923125943, 7.852431915614514, 8.614598353910742, 9.390507480439728, 10.179465328218255, 10.980854597281049, 11.794122126903174, 12.618769004310462, 13.45434264405944, 14.300430365629756, 15.15665412735527, 16.022666164961738, 16.898145346433164, 17.78279410038924, 18.67633580824646, 19.578512574871873, 20.48908331072277, 21.407822072313007, 22.334516618450404, 23.26896714789332, 24.210985190481317, 25.160392628843, 26.117020831793926, 27.08070988374739, 28.051307897048567, 29.028670396242738, 30.01265976500361, 31.00314474785708, 32.00000000000002, 33.00310567948089, 34.01234707681574, 35.02761427779083, 36.048801855772496, 37.075808590328144, 38.108537209371725, 39.14689415239642, 40.190789352656886, 41.240136036419685, 42.2948505376226, 43.3548521264745, 44.420062850693576, 45.4904073882264, 46.56581291041576, 47.6462089546959, 48.73152730599006, 49.8217018860702, 50.916668650213865, 52.01636549055886, 53.120732145615484, 54.229710115447354, 55.34324258207863, 56.46127433472612, 57.58375169949179, 58.71062247318391, 59.84183586096424, 60.97734241754556, 62.11709399168726, 63.26104367375796, 64.40914574615383, 65.56135563637821, 66.71762987260435, 67.87792604155696, 69.04220274856145, 70.21041957962153, 71.38253706539638, 72.55851664695842, 73.73832064322177, 74.92191221993934, 76.10925536017422, 77.30031483615738, 78.4950561824508, 79.6934456703394, 80.89545028338257, 82.10103769405828, 83.31017624143954, 84.52283490984578, 85.73898330841591, 86.95859165155302, 88.18163074019449, 89.40807194386353, 90.63788718346161, 91.87104891476305, 93.1075301125765, 94.34730425553883, 95.59034531151038, 96.83662772354116, 98.08612639638082, 99.33881668350519, 100.59467437463492, 101.85367568372303], [0.0, 0.32808004881620917, 0.780310256685352, 1.2953328792455945, 1.855901018319641, 2.452970505701585, 3.0808381525916433, 3.73553122435578, 4.414101391453026, 5.114261821494169, 5.834179956544297, 6.572349913887019, 7.327509302467644, 8.098582510998568, 8.884640620637441, 9.684872211278373, 10.4985615621187, 11.325072022658741, 12.163833092215283, 13.014330218569238, 13.87609662905749, 14.74870670684175, 15.63177055976393, 16.52492952216483, 17.427852395486298, 18.34023228036234, 19.261783887032205, 20.192241236110668, 21.131355680608475, 22.078894194377163, 23.03463788308876, 23.998380682321613, 24.969928213931283, 25.94909677709178, 26.93571245452807, 27.929610317771157, 28.930633717935933, 29.938633650688022, 30.95346818583492, 31.975001953430287, 33.00310567948089, 34.03765576534322, 35.07853390572913, 36.12562674093824, 37.17882553952268, 38.23802590808763, 39.30312752535387, 40.37403389796845, 41.45065213585905, 42.53289274519143, 43.62066943721896, 44.71389895150948, 45.812500892206934, 46.916397576133534, 48.0255138916683, 49.139777167451754, 50.25911705006554, 51.383465389923934, 52.5127561346912, 53.64692522960673, 54.78591052416075, 55.929651684616296, 57.07809011192145, 58.231168864597706, 59.388832586228546, 60.551027437206024, 61.717701030423456, 62.8888023706296, 64.06428179718439, 65.24409092997776, 66.42818261829375, 67.61651089241933, 68.80903091781408, 70.00569895167158, 71.20647230171619, 72.41130928709194, 73.62016920121052, 74.83301227643562, 76.04979965049041, 77.27049333448271, 78.49505618245078, 79.72345186233889, 80.9556448283191, 82.19160029438056, 83.43128420911455, 84.67466323162648, 85.92170470851265, 87.17237665184234, 88.4266477180905, 89.68448718796958, 90.94586494711241, 92.21075146756114, 93.47911779002024, 94.75093550683377, 96.02617674565028, 97.30481415374008, 98.58682088293266, 99.87217057514297, 101.16083734845856, 102.45279578375933, 103.74802091184505, 105.04648820104629], [0.0, 0.3381128005857138, 0.804172296260054, 1.334944410892339, 1.9126548328010653, 2.527982821355704, 3.1750507831325714, 3.8497644964990374, 4.5490854714227345, 5.270656943734745, 6.012590315521713, 6.773333653880585, 7.551585963592433, 8.346238740967056, 9.156334660643049, 9.9810374891297, 10.819609618742847, 11.67139493008658, 12.535805476455712, 13.412310970524116, 14.300430365629756, 15.199725029488564, 16.109793146964343, 17.030265084332203, 17.9607995149176, 18.90108015431218, 19.850812988538756, 20.809723904510722, 21.77755665156548, 22.754071077569577, 23.73904159436387, 24.732255836036575, 25.733513480321747, 26.742625208786375, 27.759411785731295, 28.783703239142817, 29.815338129782422, 30.85416289673418, 31.900031269552667, 32.95280373865223, 34.01234707681574, 35.07853390572913, 36.15124230230549, 37.23035544028274, 38.31576126318415, 39.407352185244584, 40.50502481734055, 41.608679715333594, 42.718221148554875, 43.8335568864313, 44.95459800148956, 46.08125868717727, 47.21345608911744, 48.35111014856558, 49.49414345697272, 50.642481120675065, 51.796050634833016, 52.954781765833246, 54.11860644144676, 55.28745864810587, 56.46127433472611, 57.63999132255312, 58.823549220564544, 60.01188934600039, 61.204954649634125, 62.40268964543213, 63.60504034427979, 64.81195419148115, 66.02338000776412, 67.2392679335454, 68.45956937623102, 69.68423696034513, 70.91322448029837, 72.14648685562074, 73.38398008849852, 74.62566122346705, 75.87148830912264, 77.1214203617269, 78.37541733058701, 79.63344006510306, 80.89545028338259, 82.16141054232851, 83.43128420911457, 84.7050354339669, 85.98262912417809, 87.26403091928252, 88.54920716732902, 89.83812490218972, 91.13075182184849, 92.42705626761598, 93.72700720422179, 95.03057420073739, 96.33772741228637, 97.6484375625011, 98.96267592668822, 100.28041431566623, 101.60162506024234, 102.92628099629617, 104.25435545044127, 105.58582222623595, 106.92065559091697, 108.25883026263166], [0.0, 0.34820545417087306, 0.8281768071655123, 1.3747924482078187, 1.9697475031229281, 2.6034430075449837, 3.2698259221214965, 3.9646798128677236, 4.684875490945262, 5.427985842868938, 6.192065896153156, 6.975517392759729, 7.777000502814436, 8.595373633836225, 9.42965088433991, 10.2789710592985, 11.142574533467945, 12.019785602314577, 12.909998768947567, 13.812667916985287, 14.727297640542067, 15.65343621417769, 16.5906698285902, 17.538617816502793, 18.496928662653332, 19.465276641556507, 20.44335896292967, 21.430893331421526, 22.427615847297446, 23.433279189892385, 24.44765103724967, 25.470512684343543, 26.501657829296413, 27.540891502527614, 28.58802911815953, 29.64289563052065, 30.705324781417637, 31.77515842614736, 32.852245928097446, 33.93644361332668, 35.02761427779083, 36.12562674093824, 37.23035544028274, 38.341680062302984, 39.459485205640895, 40.58366007310054, 41.714098189397234, 42.85069714198895, 43.993358342650225, 45.14198680772904, 46.29649095527055, 47.45678241740023, 48.622775866541225, 49.794388854198736, 50.9715416611817, 52.15415715825345, 53.34216067630781, 54.535479885260926, 55.73404468093046, 56.93778707924639, 58.14664111720194, 59.36054276000939, 60.5794298139768, 61.80324184466613, 63.031920099933735, 64.26540743749008, 65.50364825664766, 66.74658843395493, 67.99417526244058, 69.24635739421475, 70.50308478619645, 71.76430864875383, 73.02998139706246, 74.30005660500217, 75.57448896142623, 76.85323422865108, 78.13624920302532, 79.42349167744759, 80.71492040571349, 82.01049506857927, 83.31017624143954, 84.61392536352223, 85.92170470851265, 87.2334773565227, 88.549207167329, 89.86885875480742, 91.19239746249737, 92.51978934023343, 93.85100112178553, 95.18600020345372, 96.52475462356604, 97.86723304283194, 99.21340472550665, 100.56323952132414, 101.91670784816006, 103.27378067538704, 104.63442950788794, 105.99862637069448, 107.36634379422071, 108.73755480006218, 110.11223288733372, 111.49035201952034], [0.0, 0.35835696153773977, 0.8523212967428732, 1.414872853321306, 2.027173100709941, 2.6793432283879954, 3.365153727987797, 4.080265240509658, 4.82145734941278, 5.586232181664344, 6.372588061466731, 7.1788801355086065, 8.00372951280204, 8.845961319122859, 9.704560910224751, 10.57864198398503, 11.46742276920768, 12.370207862013523, 13.286374112984822, 14.215359484379722, 15.156654127355269, 16.109793146964343, 17.074350669797067, 18.049934930684234, 19.0361841663629, 20.032763155216603, 21.039360279479524, 22.055685013822057, 23.08146576483312, 24.116448001513877, 25.160392628843002, 26.213074565715168, 27.27428149577196, 28.343812765331236, 29.421478407138164, 30.50709827227715, 31.60050125549904, 32.701524601583834, 33.810013282291564, 34.925819435041646, 36.048801855772496, 37.17882553952268, 38.31576126318415, 39.459485205640895, 40.6098786011483, 41.76682742235269, 42.930222089811686, 44.099957205269895, 45.27593130628182, 46.45804664006234, 47.6462089546959, 48.840327306049836, 50.04031387892538, 51.24608382114193, 52.457555089392166, 53.67464830583014, 54.897286624462545, 56.12539560650969, 57.358903103986925, 58.59773915083117, 59.841835860964245, 61.091127332741934, 62.345549559290696, 63.60504034427979, 64.86953922271816, 66.13898738640216, 67.41332761367373, 68.6925042031778, 69.97646291133528, 71.26515089327091, 72.55851664695842, 73.85650996036343, 75.15908186138377, 76.46618457040204, 77.77777145528005, 79.09379698863827, 80.41421670727526, 81.73898717359289, 83.0680659389037, 84.40141150850536, 85.73898330841591, 87.08074165367083, 88.4266477180905, 89.7766635054323, 91.13075182184849, 92.48887624957543, 93.85100112178553, 95.21709149853747, 96.58711314376464, 97.96103250324578, 99.33881668350519, 100.72043343159334, 102.1058511157021, 103.49503870657107, 104.88796575964496, 106.2846023979437, 107.68491929560957, 109.08888766209807, 110.49647922698082, 111.90766622533073, 113.32242138366145, 114.74071790639506], [0.0, 0.36856631646572396, 0.876603371782767, 1.4551816534504913, 2.0849259335188846, 2.7556759606310757, 3.461024751809497, 4.196509322561049, 4.958817508788696, 5.745380274694295, 6.554138918048868, 7.383401724748457, 8.231750520104763, 9.097976958497103, 9.9810374891297, 10.880020559713365, 11.794122126903174, 12.72262697521927, 13.664894202125488, 14.620345757793123, 15.588457268119903, 16.5687505936064, 17.56078772798846, 18.564165744964, 19.57851257487187, 20.60348344585148, 21.638757862351145, 22.68403702216505, 23.739041594363865, 24.803509796527454, 25.87719572197405, 26.959867877185186, 28.051307897048563, 29.151309411390173, 30.259677040912614, 31.376225504375782, 32.50077882185413, 33.633169601338125, 34.773238397934875, 35.92083313655579, 37.075808590328144, 38.23802590808763, 39.407352185244584, 40.58366007310054, 41.76682742235269, 42.95673695708279, 44.15327597600197, 45.35633607812765, 46.56581291041575, 47.78160593516841, 49.003618215294736, 50.23175621572339, 51.46592961945811, 52.70605115693532, 53.952036447487636, 55.20380385184633, 56.461274334726106, 57.72437133663525, 58.993020654140295, 60.26715032789091, 61.54669053777904, 62.83157350466583, 64.12173339816387, 65.41710625000972, 66.71762987260435, 68.02324378233696, 69.33388912734198, 70.6495086193692, 71.97004646947555, 73.29544832726992, 74.62566122346705, 75.96063351552462, 77.30031483615738, 78.64465604453794, 79.99360918000907, 81.34712741814604, 82.70516502901995, 84.06767733752396, 85.43462068563534, 86.80595239649487, 88.18163074019448, 89.561614901171, 90.94586494711241, 92.33434179928803, 93.72700720422178, 95.12382370663182, 96.52475462356604, 97.92976401966705, 99.33881668350517, 100.75187810492137, 102.1689144533264, 103.58989255690531, 105.01477988268053, 106.44354451738833, 107.87615514912804, 109.31258104974397, 110.75279205790397, 112.19675856283978, 113.64445148871705, 115.09584227960411, 116.5509028850109, 118.009605745971], [0.0, 0.3788325519842912, 0.9010207324287147, 1.495715030781, 2.1430005315383815, 2.8324339744831732, 3.557429913242559, 4.313401049060644, 5.096942959120113, 5.905415048379935, 6.736701270461652, 7.5890627893875875, 8.46104192790313, 9.351396682507925, 10.259054434806242, 11.183078241663146, 12.122641663497326, 13.077009562849534, 14.045523185155115, 15.027588379288483, 16.022666164961738, 17.030265084332203, 18.049934930684234, 19.08126155439954, 20.123862521997484, 21.17738345816496, 22.241494940102537, 23.31588984261426, 24.400281054143605, 25.494399500448406, 26.59799242523587, 27.710821886848134, 28.83266343771889, 29.96330495933328, 31.102545630198584, 32.250195008155856, 33.4060722114443, 34.57000518543135, 35.74183004396416, 36.92139047597651, 38.108537209371725, 39.30312752535387, 40.50502481734055, 41.714098189397234, 42.930222089811686, 44.15327597600197, 45.38314400743964, 46.61971476368545, 47.86288098499203, 49.11253933323282, 50.36859017118142, 51.63093735839253, 52.899488062133926, 54.174152581990725, 55.45484418691312, 56.74147896361024, 58.03397567530735, 59.332255629985326, 60.63624255731014, 61.945862493538755, 63.26104367375797, 64.58171643087395, 65.90781310082586, 67.23926793354542, 68.57601700922824, 69.91799815952199, 71.26515089327093, 72.61741632648857, 73.97473711625791, 75.33705739828417, 76.70432272784836, 78.07648002393032, 79.4534775162885, 80.83526469530169, 82.22179226439185, 83.61301209486271, 85.0088771830004, 86.40934160929471, 87.81436049964995, 89.22388998846371, 90.63788718346161, 92.05631013218284, 93.47911779002025, 94.9062699897241, 96.33772741228636, 97.77345155912651, 99.21340472550663, 100.65754997510749, 102.10585111570208, 103.55827267586773, 105.01477988268053, 106.4753386403408, 107.93991550968067, 109.40847768850799, 110.8809929927443, 112.35742983831608, 113.83775722376195, 115.3219447135201, 116.80996242186295, 118.30178099744724, 119.79737160845013, 121.29670592826363], [0.0, 0.3891547380192859, 0.9255711665791095, 1.536469313173553, 2.201391633474492, 2.9096103160180133, 3.654360478418667, 4.43092983015069, 5.235821186870657, 6.0663220043000345, 6.920258579387876, 7.79584469747072, 8.691582963440455, 9.606197532483145, 10.538586560186001, 11.487787574189394, 12.452951616617156, 13.433323519456765, 14.428226578822336, 15.437050454540064, 16.45924148053337, 17.49429480803198, 18.541747963376835, 19.60117551246688, 20.67218460151965, 21.754411199431143, 22.847516907501085, 23.951186232183467, 25.06512423889049, 26.18905452181789, 27.322717437731757, 28.465868561692776, 29.618277330531523, 30.779725846064103, 31.950007814942765, 33.128927605962936, 34.31629940881379, 35.51194648082866, 36.715700470390075, 37.92740080736829, 39.14689415239642, 40.37403389796845, 41.608679715333594, 42.85069714198895, 44.099957205269895, 45.35633607812765, 46.61971476368545, 47.889978805591504, 49.16701802155372, 50.45072625775467, 51.741001162116795, 53.03774397462171, 54.34085933309051, 55.65025509300906, 56.965842160135594, 58.2875343347638, 59.61524816663148, 60.94890281956993, 62.28841994508006, 63.633723564102254, 64.98473995631906, 66.34139755639242, 67.70362685659465, 69.07136031534182, 70.44453227118379, 71.82307886184486, 73.20693794794518, 74.59604904106521, 75.99035323584498, 77.38979314583526, 78.79431284284237, 80.20385779952858, 81.61837483505008, 83.03781206353192, 84.46211884519458, 85.89124573996199, 87.32514446339326, 88.76376784479291, 90.20706978736465, 91.65500523028435, 93.1075301125765, 94.56460133868656, 96.02617674565029, 97.49221507176654, 98.9626759266882, 100.43751976285019, 101.91670784816006, 103.4002022398815, 104.88796575964496, 106.37996196952521, 107.87615514912805, 109.37651027363336, 110.8809929927443, 112.38956961049566, 113.90220706587787, 115.4188729142349, 116.93953530939741, 118.46416298651499, 119.99272524555293, 121.52519193542146, 123.06153343870672, 124.60172065697549], [0.0, 0.3995319792276305, 0.9502525447372351, 1.577440965614879, 2.2600941745019236, 2.987198290984697, 3.751808039611954, 4.5490854714227345, 5.3754401457877785, 6.228087185437286, 7.104794923125942, 8.00372951280204, 8.923353629661895, 9.86235740707946, 10.819609618742849, 11.794122126903176, 12.785023335284183, 13.791537938483634, 14.812971187558587, 15.848696466939915, 16.898145346433164, 17.9607995149176, 19.0361841663629, 20.123862521997484, 21.223431252158566, 22.334516618450404, 23.45677119839737, 24.589871085469337, 25.73351348032175, 26.887414606484068, 28.05130789704857, 29.224942409214783, 30.408081431591544, 31.600501255499044, 32.801990086549395, 34.01234707681575, 35.23138146114996, 36.45891178384681, 37.69476520400688, 38.93877686972043, 40.190789352656886, 41.45065213585905, 42.718221148554875, 43.993358342650225, 45.27593130628182, 46.56581291041575, 47.86288098499203, 49.16701802155372, 50.47811089967616, 51.796050634833016, 53.120732145615484, 54.45205403846011, 55.78991840825012, 57.13423065333602, 58.48489930367965, 59.841835860964245, 61.20495464963413, 62.57417267793482, 63.949409508117895, 65.33058713505814, 66.71762987260436, 68.11046424704968, 69.50901889716599, 70.91322448029838, 72.3230135840616, 73.73832064322177, 75.15908186138378, 76.58523513713754, 78.01671999434656, 79.4534775162885, 80.89545028338259, 82.34258231425935, 83.79481900994901, 85.25210710098241, 86.71439459721437, 88.18163074019449, 89.65376595792395, 91.13075182184849, 92.61254100594985, 94.09908724780718, 95.59034531151036, 97.0862709523143, 98.58682088293266, 100.09195274137547, 101.60162506024234, 103.11579723738866, 104.63442950788794, 106.15748291721886, 107.68491929560957, 109.21670123347727, 110.75279205790397, 112.29315581009404, 113.83775722376195, 115.38656170440238, 116.93953530939741, 118.49664472891835, 120.0578572675826, 121.62314082682794, 123.1924638879693, 124.76579549590474, 126.3431052434394, 127.92436325619812], [0.0, 0.40996341300169703, 0.9750628152648344, 1.6186265823385309, 2.3191032749750504, 3.0651914498868984, 3.8497644964990374, 4.66785815119533, 5.515788230052884, 6.390697145069546, 7.290294962102013, 8.212699954967244, 9.156334660643049, 10.11985501302081, 11.102100250449869, 12.10205643576096, 13.118829216054312, 14.151623043375455, 15.199725029488562, 16.262492198434973, 17.33934127880042, 18.429740426809925, 19.53320243965915, 20.64927913466126, 21.77755665156548, 22.917651493990405, 24.06920716856061, 25.231891311827148, 26.405393218616954, 27.58942170330174, 28.783703239142817, 29.987980331440635, 31.20201008847472, 32.425562960725486, 33.6584216240371, 34.90037998651739, 36.15124230230549, 37.41082237804495, 38.67894286011023, 39.9554345924511, 41.240136036419685, 42.53289274519143, 43.8335568864313, 45.14198680772904, 46.45804664006234, 47.78160593516841, 49.11253933323282, 50.45072625775467, 51.796050634833016, 53.14840063445, 54.507668431612274, 55.87374998545831, 57.246544834653555, 58.62595590758145, 60.01188934600038, 61.404254340979215, 62.80296298004778, 64.20793010460876, 65.61907317675386, 67.03631215471162, 68.45956937623103, 69.88876944927037, 71.32383914942173, 72.76470732355358, 74.21130479920164, 75.66356429928067, 77.1214203617269, 78.58480926371628, 80.05366895013276, 81.52793896598946, 83.00756039253011, 84.49247578676017, 85.98262912417809, 87.47796574449504, 88.97843230014816, 90.48397670742793, 91.99454810005359, 93.51009678504327, 95.03057420073742, 96.55593287684344, 98.0861263963808, 99.62110935941246, 101.16083734845856, 102.70526689549423, 104.25435545044125, 105.80806135106816, 107.3663437942207, 108.92916280830875, 110.49647922698081, 112.06825466392226, 113.64445148871704, 115.22503280371647, 116.80996242186295, 118.39920484541851, 119.99272524555292, 121.59048944274674, 123.19246388796928, 124.79861564459262, 126.40891237100617, 128.02332230389712, 129.64181424216505, 131.2643575314408], [0.0, 0.42044820762685725, 1.0, 1.6600228795504828, 2.378414230005443, 3.143583574207339, 3.948222038857479, 4.787238399535833, 5.656854249492383, 6.554138918048869, 7.476743906106106, 8.422739362424165, 9.39050748043973, 10.37866981961791, 11.386035931884507, 12.411565948675781, 13.454342644059441, 14.513550123980236, 15.588457268119903, 16.678404656440478, 17.78279410038924, 18.90108015431218, 20.032763155216603, 21.17738345816496, 22.334516618450408, 23.50376933178997, 24.68477598750726, 25.877195721974054, 27.08070988374739, 28.2950198401405, 29.519845068981475, 30.754921490156175, 32.00000000000002, 33.254845178275474, 34.51923414277184, 35.79295553080669, 37.075808590328144, 38.36760236609361, 39.66815496866707, 40.97729291584041, 42.2948505376226, 43.62066943721896, 44.95459800148956, 46.29649095527055, 47.6462089546959, 49.003618215294736, 50.36859017118142, 51.741001162116795, 53.120732145615484, 54.507668431612274, 55.901699437494784, 57.302718461561454, 58.71062247318391, 60.12531191814365, 61.54669053777905, 62.97466520072491, 64.40914574615383, 65.85004483754147, 67.2972778260765, 68.75076262292298, 70.21041957962154, 71.67617137598265, 73.14794291488764, 74.62566122346706, 76.10925536017422, 77.59865632731557, 79.09379698863827, 80.59461199161007, 82.10103769405829, 83.6130120948627, 85.13047476842263, 86.65336680264173, 88.18163074019449, 89.71521052285782, 91.25405143870752, 92.79810007199568, 94.34730425553884, 95.90161302545954, 97.46097657813604, 99.02534622922538, 100.59467437463492, 102.1689144533264, 103.74802091184507, 105.33194917047341, 106.92065559091698, 108.51409744543473, 110.11223288733373, 111.71502092275233, 113.32242138366146, 114.93439490201838, 116.55090288501091, 118.1719074913348, 119.79737160845016, 121.4272588307661, 123.06153343870672, 124.700160378613, 126.34310524343941, 127.99033425420534, 129.64181424216508, 131.2975126316606, 132.95739742362483, 134.6214371797046], [0.0, 0.4309855605776132, 1.025062190204668, 1.7016266887018776, 2.438022499823328, 3.222368663668393, 4.047173130565587, 4.90721707886009, 5.798627406653245, 6.718399994240826, 7.664127483992528, 8.633831658369584, 9.625854165032868, 10.638782016708621, 11.67139493008658, 12.722626975219272, 13.791537938483632, 14.87729147773241, 15.979138149170863, 17.096402006250607, 18.228469868503637, 19.374782620213225, 20.534828075737707, 21.70813507043068, 22.894268522071325, 24.092825269309934, 25.303430538465786, 26.525734923121586, 27.7594117857313, 29.004155009218955, 30.259677040912617, 31.525707182272097, 32.801990086549395, 34.0882844333602, 35.38436175457746, 36.690005390306986, 38.00500955721081, 39.32917851428971, 40.66232581356004, 42.00427362496959, 43.3548521264745, 44.71389895150948, 46.08125868717727, 47.45678241740023, 48.840327306049836, 50.23175621572339, 51.63093735839253, 53.03774397462171, 54.45205403846011, 55.87374998545831, 57.302718461561454, 58.73885009088964, 60.1820392606413, 61.63218392155115, 63.089185402504704, 64.55294823806075, 66.0233800077641, 67.50039118624585, 68.98389500321001, 70.47380731249464, 71.97004646947555, 73.47253321614988, 74.98119057330074, 76.49594373919871, 78.01671999434653, 79.5434486118174, 81.07606077277691, 82.6144894868152, 84.1586695167474, 85.70853730756934, 87.26403091928252, 88.82508996332439, 90.39165554236303, 91.96367019323351, 93.54107783281096, 95.12382370663184, 96.71185434008883, 98.30511749203806, 99.90356211066998, 101.50713829150531, 103.11579723738865, 104.7294912203601, 106.3481735452956, 107.97179851521223, 109.60032139814432, 111.23369839550008, 112.87188661181678, 114.5148440258368, 116.16252946283231, 117.81490256811118, 119.47192378164084, 121.13355431373105, 122.79975612172042, 124.4704918876142, 126.14572499662569, 127.8254195165744, 129.50954017809886, 131.19805235564326, 132.89092204918043, 134.58811586663506, 136.28960100697333, 137.9953452439281], [0.0, 0.4415746969393655, 1.0502475428109277, 1.743434950257815, 2.4979237008497606, 3.301540924432051, 4.146610494782018, 5.027785365962627, 5.941097275568929, 6.883468293922296, 7.852431915614514, 8.845961319122859, 9.862357407079461, 10.900172475699643, 11.958156259818633, 13.035216640032518, 14.130390302059705, 15.242820355173476, 16.371738942056073, 17.516453508432942, 18.676335808246456, 19.850812988538756, 21.039360279479524, 22.241494940102537, 23.456771198397366, 24.684775987507255, 25.925125325717687, 27.177461221840698, 28.4414490129813, 29.716775060894008, 31.00314474785707, 32.30028072437951, 33.60792136994971, 34.92581943504164, 36.25374083816121, 37.59146359617052, 38.938776869720414, 40.295480108536545, 41.661382283685676, 43.03630119590502, 44.420062850693576, 45.812500892206934, 47.21345608911744, 48.622775866541225, 50.04031387892538, 51.46592961945811, 52.899488062133926, 54.34085933309051, 55.78991840825012, 57.246544834653555, 58.71062247318391, 60.1820392606413, 61.66068698936143, 63.14646110277095, 64.63926050544701, 66.13898738640216, 67.64554705444897, 69.15884778461735, 70.67880067470117, 72.20531951110222, 73.73832064322175, 75.2777228657207, 76.82344730803474, 78.375417330587, 79.93355842719238, 81.4977981331928, 83.06806593890369, 84.64429320798858, 86.22641310041207, 87.81436049964992, 89.40807194386353, 91.00748556076847, 92.61254100594982, 94.2231794043965, 95.83934329504457, 97.46097657813603, 99.08802446521464, 100.72043343159332, 102.35815117114075, 104.00112655324531, 105.6493095818257, 107.30265135626591, 108.96110403416202, 110.62462079577523, 112.29315581009402, 113.96666420241338, 115.64510202334687, 117.328426219192, 119.01659460357497, 120.7095658303056, 122.40729936737776, 124.10975547205463, 125.81689516698236, 127.5286802172786, 129.24507310854653, 130.9660370257669, 132.69153583302466, 134.42153405402846, 136.15599685338458, 137.89489001858826, 139.63817994269792, 141.3858336076604], [0.0, 0.4522148679443101, 1.0755542769387791, 1.7854447079167495, 2.558113597414407, 3.381094758153197, 4.246527100197108, 5.148934735346321, 6.0842537820608396, 7.049332144958363, 8.041643885788375, 9.059113344795916, 10.100000483212549, 11.16282271342547, 12.246299643916998, 13.34931283960595, 14.470875774217932, 15.61011090941229, 16.76623188560376, 17.938529460750203, 19.126360250595333, 20.329137598733144, 21.54632409049481, 22.777425352801874, 24.02198487233457, 25.279579628989215, 26.549816388639105, 27.832328533951067, 29.12677333800277, 30.432829605130724, 31.750195618513153, 33.078587345653844, 34.417736862040954, 35.76739096043112, 37.12730991890939, 38.49726640543866, 39.87704450029096, 41.266438820738394, 42.66525373482014, 44.073302653005285, 45.4904073882264, 46.916397576133534, 48.35111014856558, 49.794388854198736, 51.24608382114193, 52.70605115693532, 54.174152581990725, 55.65025509300906, 57.13423065333602, 58.62595590758145, 60.12531191814365, 61.63218392155115, 63.14646110277095, 64.66803638583755, 66.19680623933574, 67.73267049542736, 69.2755321812489, 70.8252973616281, 72.38187499217383, 73.94517678188755, 75.51511706452814, 77.09161267803502, 78.67458285138106, 80.2639490982844, 81.85963511726106, 83.4615666975467, 85.06967163045742, 86.68387962579762, 88.30412223295632, 89.93033276636343, 91.56244623500577, 93.20039927572611, 94.84413009005229, 96.49357838432269, 98.14868531289322, 99.80939342422776, 101.47564660968906, 103.14739005486072, 104.8245701932444, 106.50713466218674, 108.19503226090238, 109.88821291046744, 111.58662761566885, 113.29022842860076, 114.99896841390893, 116.71280161558876, 118.43168302525068, 120.15556855177145, 121.88441499225563, 123.61818000423646, 125.35682207904978, 127.1003005163189, 128.84857539949283, 130.6016075723826, 132.35935861664558, 134.1217908301689, 135.88886720630754, 137.66055141393446, 139.43680777826336, 141.2176012624059, 143.00289744962868, 144.79266252627644], [0.0, 0.46290534961120555, 1.1009806706609355, 1.8276531032399879, 2.618588094060905, 3.461024751809497, 4.346916148259593, 5.270656943734745, 6.228087185437286, 7.215980261598382, 8.231750520104763, 9.27327323204402, 10.338767223661065, 11.426714858571337, 12.535805476455714, 13.66489420212549, 14.812971187558587, 15.979138149170863, 17.162590137623987, 18.362601144202305, 19.57851257487187, 20.809723904510722, 22.055685013822057, 23.31588984261426, 24.589871085469337, 25.87719572197405, 27.177461221840698, 28.490292300803283, 29.815338129782425, 31.152269919962364, 32.500778821854134, 33.860574088356564, 35.23138146114996, 36.61294174710331, 38.00500955721081, 39.407352185244584, 40.81974860707596, 42.241988584673834, 43.67387186128499, 45.115207436351575, 46.56581291041576, 48.0255138916683, 49.49414345697272, 50.9715416611817, 52.457555089392166, 53.952036447487636, 55.45484418691312, 56.965842160135594, 58.48489930367965, 60.01188934600038, 61.54669053777905, 63.089185402504704, 64.63926050544701, 66.19680623933574, 67.76171662524503, 69.33388912734198, 70.91322448029838, 72.49962652828908, 74.093002074609, 75.69326074103651, 77.3003148361574, 78.91407923193752, 80.53447124790081, 82.16141054232854, 83.79481900994901, 85.43462068563534, 87.08074165367084, 88.73310996218072, 90.39165554236304, 92.05631013218284, 93.72700720422179, 95.40368189740053, 97.0862709523143, 98.77471264994303, 100.46894675351571, 102.16891445332641, 103.87455831431448, 105.58582222623595, 107.30265135626595, 109.0249921038839, 110.75279205790397, 112.48599995552304, 114.22456564326795, 115.96844003973139, 117.71757509999468, 119.47192378164084, 121.23144001226981, 122.9960786584323, 124.76579549590474, 126.54054718123301, 128.32029122447688, 130.10498596309182, 131.89459053688876, 133.68906486401588, 135.48836961791048, 137.29246620517156, 139.10131674430707, 140.9148840453123, 142.73313159003933, 144.55602351331834, 146.383524584795, 148.21560019145016], [0.0, 0.4736454414798519, 1.1265250579928898, 1.8700573706551313, 2.6793432283879954, 3.541325668239418, 4.447771061292727, 5.392944015662893, 6.372588061466731, 7.383401724748458, 8.422739362424165, 9.48842694871388, 10.578641983985031, 11.69183162043412, 12.82665478847532, 13.981940050114558, 15.15665412735527, 16.349877895099546, 17.56078772798846, 18.788640772825488, 20.032763155216603, 21.292540416964787, 22.56740967518821, 23.85685312834695, 25.160392628843002, 26.4775851095462, 27.808018700868107, 29.151309411390177, 30.50709827227715, 31.875048866324242, 33.254845178275474, 34.64618971526495, 36.048801855772496, 37.46241639300135, 38.886782244556194, 40.321661305078926, 41.76682742235269, 43.22206548051173, 44.6871705765486, 46.161947278408746, 47.6462089546959, 49.139777167451754, 50.642481120675065, 52.15415715825345, 53.67464830583014, 55.20380385184633, 56.74147896361024, 58.2875343347638, 59.841835860964245, 61.404254340979215, 62.97466520072491, 64.55294823806075, 66.13898738640216, 67.73267049542736, 69.33388912734198, 70.94253836732943, 72.55851664695842, 74.1817255794458, 75.81206980578443, 77.4494568508437, 79.09379698863827, 80.74500311603714, 82.40299063425438, 84.06767733752397, 85.73898330841591, 87.41683081929948, 89.10114423950358, 90.79184994776297, 92.48887624957544, 94.1921532991254, 95.90161302545954, 97.6171890626251, 99.33881668350519, 101.06643273710672, 102.79997558907613, 104.53938506523491, 106.2846023979437, 108.03557017511747, 109.79223229172837, 111.5545339036441, 113.32242138366146, 115.09584227960411, 116.8747452743638, 118.65908014777168, 120.44879774019553, 122.24384991776445, 124.0441895391302, 125.84977042368045, 127.66054732112391, 129.47647588237393, 131.29751263166057, 133.12361493980634, 134.95474099860508, 136.79084979624642, 138.63190109373303, 140.47785540223967, 142.32867396136734, 144.18431871824802, 146.04475230745845, 147.9099380317036, 149.77983984323265, 151.65442232595288], [0.0, 0.4844344654320764, 1.15218582608873, 1.9126548328010655, 2.740375164380012, 3.621992437327046, 4.5490854714227345, 5.515788230052884, 6.517747286514924, 7.551585963592432, 8.614598353910742, 9.704560910224751, 10.819609618742849, 11.958156259818633, 13.118829216054314, 14.300430365629756, 15.501902893826454, 16.72230673907836, 17.9607995149176, 19.216621446922993, 20.48908331072277, 21.77755665156548, 23.08146576483312, 24.400281054143605, 25.73351348032175, 27.08070988374739, 28.4414490129813, 29.815338129782425, 31.202010088474722, 32.60112080870929, 34.01234707681574, 35.43538462342963, 36.869946434839385, 38.31576126318415, 39.772572306739875, 41.240136036419685, 42.71822114855487, 44.20660762722147, 45.70508590198943, 47.21345608911745, 48.73152730599006, 50.25911705006554, 51.796050634833016, 53.34216067630781, 54.897286624462545, 56.461274334726106, 58.03397567530735, 59.61524816663148, 61.20495464963413, 62.80296298004778, 64.40914574615383, 66.0233800077641, 67.64554705444897, 69.2755321812489, 70.91322448029838, 72.55851664695842, 74.21130479920166, 75.87148830912264, 77.53896964556073, 79.21365422692269, 80.89545028338259, 82.58426872771395, 84.28002303408108, 85.9826291241781, 87.69200526016043, 89.40807194386355, 91.13075182184849, 92.85996959585391, 94.59565193827052, 96.33772741228636, 98.08612639638082, 99.84078101287149, 101.60162506024234, 103.36859394900327, 105.1416246408507, 106.92065559091698, 108.70562669291277, 110.49647922698081, 112.29315581009405, 114.09560034884255, 115.90375799446554, 117.71757509999466, 119.53699917938505, 121.36197886851804, 123.19246388796927, 125.02840500744117, 126.86975401176724, 128.71646366840116, 130.56848769630915, 132.42578073619038, 134.28829832195365, 136.15599685338458, 138.02883356994073, 139.9067665256163, 141.78975456482218, 143.67775729922934, 145.5707350855276, 147.46864900405427, 149.37146083825067, 151.27913305490532, 153.19162878514675, 155.10891180615002], [0.0, 0.49527176459187194, 1.1779614126252138, 1.955442896185462, 2.8016801861851217, 3.703020147778696, 4.650853210250558, 5.639182107690898, 6.663556022746991, 7.7205227384467365, 8.807315813473707, 9.921661957535164, 11.061655456926422, 12.225672561887787, 13.412310970524116, 14.620345757793125, 15.848696466939913, 17.096402006250607, 18.3626011442023, 19.646517109435568, 20.947445258917824, 22.26474307871597, 23.597821985105288, 24.946140534085835, 26.309198746171155, 27.686533324092494, 29.07771359258101, 30.482338027435695, 31.900031269552667, 33.33044154115036, 34.77323839793487, 36.228110763721915, 37.69476520400686, 39.172924402834155, 40.66232581356004, 42.162720459100505, 43.67387186128498, 45.19555508220612, 46.72755586312695, 48.26966984870054, 49.8217018860702, 51.383465389923934, 52.954781765833246, 54.535479885260926, 56.12539560650969, 57.72437133663525, 59.332255629985326, 60.94890281956993, 62.57417267793482, 64.20793010460876, 65.85004483754147, 67.50039118624585, 69.15884778461735, 70.8252973616281, 72.49962652828908, 74.1817255794458, 75.87148830912264, 77.56881183826403, 79.27359645383655, 80.98574545835909, 82.70516502901995, 84.43176408561942, 86.16545416664954, 87.9061493128859, 89.65376595792394, 91.40822282514313, 93.16944083062822, 94.93734299161798, 96.71185434008883, 98.49290184111355, 100.28041431566623, 102.07432236757064, 103.87455831431447, 105.68105612147404, 107.49375134051384, 109.31258104974398, 111.13748379823538, 112.96839955250692, 114.80526964581401, 116.64803672987921, 118.49664472891834, 120.35103879582499, 122.21116527038724, 124.07697163941808, 125.94840649869052, 127.8254195165744, 129.70796139928018, 131.59598385762064, 133.4894395752076, 135.38828217800574, 137.29246620517156, 139.20194708110884, 141.11668108867764, 143.0366253434967, 144.96173776928396, 146.8919770741817, 148.82730272801794, 150.76767494045703, 152.71305463999633, 154.66340345376776, 156.61868368810505, 158.5788583098413], [0.0, 0.5061567022980749, 1.2038503033583696, 1.998419047128683, 2.8632546923039155, 3.7844040394418927, 4.753068299204776, 5.763118399530049, 6.810005704305487, 7.890202124746027, 9.000880419498676, 10.139717336562812, 11.304765279016408, 12.494364810803376, 13.70708281064846, 14.941667432465747, 16.197014473538406, 17.472141719560508, 18.766169011115128, 20.078302505189512, 21.407822072313007, 22.754071077569577, 24.116448001513877, 25.494399500448406, 26.887414606484068, 28.2950198401405, 29.71677506089401, 31.152269919962368, 32.60112080870929, 34.06296821808423, 35.53747444138542, 37.02432156568735, 38.52320970746785, 40.03385545600254, 41.55599049447448, 43.08936037385426, 44.633723418723385, 46.18884974755509, 47.75452039269666, 49.33052650753925, 50.916668650213865, 52.5127561346912, 54.11860644144676, 55.73404468093046, 57.358903103986925, 58.993020654140295, 60.63624255731014, 62.28841994508006, 63.949409508117895, 65.61907317675386, 67.2972778260765, 68.98389500321001, 70.67880067470117, 72.38187499217383, 74.093002074609, 75.81206980578443, 77.53896964556073, 79.27359645383655, 81.01584832611466, 82.76562643972508, 84.5228349098458, 86.28738065454318, 88.05917326812818, 89.83812490218975, 91.62415015372534, 93.4171659598407, 95.21709149853748, 97.02384809514986, 98.83735913402901, 100.65754997510749, 102.4843478750076, 104.3176819123843, 106.15748291721886, 108.00368340380238, 109.85621750716831, 111.71502092275233, 113.58003084907483, 115.45118593325643, 117.32842621919202, 119.21169309822055, 121.10092926214065, 122.9960786584323, 124.89708644755515, 126.80389896220278, 128.71646366840116, 130.63472912834627, 132.55864496488414, 134.488161827542, 136.42323136002582, 138.3638061691055, 140.30983979481226, 142.2612866818806, 144.21810215236806, 146.18024237939304, 148.14766436193324, 150.1203259006306, 152.09818557455296, 154.0812027188642, 156.0693374033598, 158.06255041182396, 160.06080322217005, 162.06405798732706], [0.0, 0.5170886611436247, 1.229851029838459, 2.0415808479705655, 2.92509519015464, 3.8661394961221602, 4.855724940519772, 5.887590075751362, 6.957088024384271, 8.060614498066727, 9.195281192763018, 10.358714678938288, 11.548925295524556, 12.764217766010422, 14.00312801660586, 15.264377163886861, 16.546837156596, 17.84950456658919, 19.171480224790077, 20.511953142785874, 21.87018763776898, 23.245512892840097, 24.63731439695308, 26.045026855308127, 27.468128264145413, 28.90613491778749, 30.35859716956747, 31.82509580800116, 33.305238939283264, 34.79865928969643, 36.305011858758625, 37.82397186726953, 39.35523295483072, 40.89850558962061, 42.453515659722854, 44.02000322052478, 45.59772137690866, 47.18643528237272, 48.78592124000678, 50.39596589253853, 52.01636549055886, 53.64692522960673, 55.28745864810587, 56.93778707924639, 58.59773915083117, 60.26715032789091, 61.945862493538755, 63.633723564102254, 65.33058713505814, 67.03631215471162, 68.75076262292298, 70.47380731249464, 72.20531951110222, 73.94517678188755, 75.69326074103651, 77.4494568508437, 79.21365422692269, 80.98574545835909, 82.76562643972508, 84.55319621398127, 86.34835682538787, 88.15101318163013, 89.96107292443938, 91.77844630805693, 93.60304608494852, 95.4347873982297, 97.2735876803108, 99.11936655731266, 100.97204575884375, 102.83154903276242, 104.69780206458152, 106.57073240119867, 108.45026937866291, 110.33634405371086, 112.22888913882616, 114.12783894059628, 116.03312930115688, 117.94469754253079, 119.86248241368256, 121.78642404012281, 123.71646387590921, 125.6525446579009, 127.59461036213466, 129.54260616219895, 131.49647838949244, 133.4561744952588, 135.42164301429963, 137.39283353027196, 139.36969664248386, 141.35218393410744, 143.3402479417329, 145.33384212619322, 147.33292084459302, 149.33743932347883, 151.34735363309343, 153.36262066265823, 155.38319809663278, 157.40904439190305, 159.44011875585295, 161.47638112527588, 163.5177921460863, 165.56431315379314], [0.0, 0.528067042076036, 1.2559621672705268, 2.084925933518885, 2.987198290984697, 3.9482220388574785, 4.958817508788697, 6.012590315521713, 7.104794923125942, 8.231750520104763, 9.390507480439728, 10.578641983985031, 11.794122126903178, 13.035216640032518, 14.300430365629758, 15.588457268119905, 16.898145346433164, 18.22846986850364, 19.57851257487187, 20.947445258917828, 22.334516618450404, 23.73904159436387, 25.160392628843002, 26.59799242523587, 28.05130789704857, 29.519845068981475, 31.003144747857075, 32.500778821854134, 34.01234707681575, 35.53747444138542, 37.075808590328144, 38.62701784901145, 40.190789352656886, 41.76682742235269, 43.35485212647449, 44.95459800148956, 46.56581291041575, 48.18825702069272, 49.8217018860702, 51.46592961945812, 53.120732145615484, 54.78591052416075, 56.46127433472611, 58.14664111720194, 59.841835860964245, 61.54669053777904, 63.26104367375797, 64.98473995631906, 66.71762987260436, 68.45956937623103, 70.21041957962154, 71.97004646947555, 73.73832064322175, 75.51511706452814, 77.3003148361574, 79.09379698863827, 80.89545028338259, 82.70516502901995, 84.5228349098458, 86.34835682538787, 88.18163074019449, 90.02255954303286, 91.87104891476305, 93.7270072042218, 95.59034531151036, 97.46097657813603, 99.33881668350519, 101.22378354730976, 103.11579723738866, 105.01477988268053, 106.92065559091698, 108.83335037073381, 110.75279205790397, 112.67891024542008, 114.61163621717523, 116.55090288501091, 118.49664472891835, 120.44879774019554, 122.4072993673778, 124.37208846477219, 126.3431052434394, 128.32029122447688, 130.30358919446886, 132.29294316297674, 134.28829832195365, 136.28960100697333, 138.29679866017264, 140.30983979481226, 142.32867396136734, 144.3532517150656, 146.383524584795, 148.41944504330905, 150.46096647866173, 152.5080431668082, 154.5606302453125, 156.61868368810508, 158.68216028123842, 160.75101759959088, 162.8252139844727, 164.9047085220898, 166.9894610228246, 169.07943200129486], [0.0, 0.5390912635542211, 1.2821823325089736, 2.128452007720301, 3.0495607051009133, 4.030647319614062, 5.062340543045618, 6.13811249739338, 7.253118576277442, 8.40360112553174, 9.58654894110338, 10.799487601828162, 12.040342784713177, 13.30734707765818, 14.598974109174662, 15.913890578162063, 17.250920433735086, 18.60901755095088, 19.98724450025444, 21.384755784923378, 22.800784418163886, 24.23463103919506, 25.685654988955452, 27.153266918826905, 28.636922613305174, 30.136117784587345, 31.65038365312356, 33.179283169591926, 34.722407764742044, 36.27937453701903, 37.84982380585019, 39.4334169723788, 41.029834640287184, 42.638774957906044, 44.259952149602604, 45.89309520987968, 47.53794673800318, 49.19426189453471, 50.861807464052966, 52.540361010735694, 54.229710115447354, 55.929651684616296, 57.63999132255312, 59.36054276000939, 61.091127332741934, 62.83157350466583, 64.58171643087395, 66.34139755639242, 68.11046424704968, 69.88876944927037, 71.67617137598265, 73.47253321614988, 75.2777228657207, 77.09161267803502, 78.91407923193752, 80.74500311603714, 82.58426872771395, 84.43176408561942, 86.28738065454318, 88.15101318163013, 90.02255954303286, 91.90192060017034, 93.78900006484388, 95.68370437252946, 97.58594256322927, 99.49562616931969, 101.41266910988345, 103.33698759105827, 105.26850001197482, 107.20712687589207, 109.15279070617245, 111.10541596676681, 113.06492898690757, 115.03125788973145, 117.00433252457587, 118.98408440271257, 120.9704466363006, 122.96335388035666, 124.96274227755691, 126.96854940569689, 128.98071422765008, 130.99917704367581, 133.0238794459393, 135.05476427511425, 137.09177557895055, 139.13485857269356, 141.18395960125287, 143.23902610302335, 145.30000657526784, 147.36685054097742, 149.43950851713015, 151.5179319842743, 153.60207335736692, 155.69188595780253, 157.78732398657203, 159.88834249849313, 161.99489737745986, 164.10694531266017, 166.2244437757143, 168.347350998689, 170.47562595294588, 172.6092283287839], [0.0, 0.5501607607572664, 1.308510182175702, 2.1721568405364358, 3.112179237393704, 4.11341111537059, 5.1662887393355215, 6.264150190295149, 7.402051384544672, 8.576157509660984, 9.78339553065997, 11.021240217544102, 12.287574653952483, 13.580595136409691, 14.898743951489285, 16.240660420587485, 17.605144344232535, 18.99112811674556, 20.39765505974572, 21.823862315399005, 23.26896714789332, 24.732255836036575, 26.213074565715168, 27.710821886848134, 29.224942409214783, 30.754921490156175, 32.30028072437952, 33.860574088356564, 35.43538462342963, 37.02432156568735, 38.62701784901145, 40.24312792188367, 41.87232582962249, 43.51430352245001, 45.1687693567241, 46.83544676222266, 48.51407305284174, 50.20439836170204, 51.90618468462452, 53.619205018373435, 55.34324258207863, 57.07809011192145, 58.823549220564544, 60.5794298139768, 62.345549559290696, 64.12173339816387, 65.90781310082586, 67.70362685659465, 69.50901889716599, 71.32383914942173, 73.14794291488764, 74.98119057330074, 76.82344730803474, 78.67458285138106, 80.53447124790081, 82.40299063425438, 84.28002303408108, 86.16545416664954, 88.05917326812818, 89.96107292443938, 91.87104891476305, 93.78900006484388, 95.71482810933747, 97.6484375625011, 99.58973559659857, 101.53863192744538, 103.49503870657105, 105.4588704195217, 107.43004378986639, 109.40847768850796, 111.3940930479327, 113.38681278106264, 115.38656170440237, 117.39326646519615, 119.40685547233406, 121.42725883076609, 123.45440827920152, 125.48823713088773, 127.52868021727862, 129.57567383441565, 131.62915569185895, 133.68906486401585, 135.75534174372692, 137.82792799797795, 139.90676652561626, 141.99180141695768, 144.0829779151784, 146.180242379393, 148.28354224932653, 150.39282601149415, 152.5080431668082, 154.6291441995367, 156.75608054754338, 158.88880457374188, 161.02726953870337, 163.17142957435817, 165.3212396587368, 167.47665559169923, 169.63763397160395, 171.80413217287074, 173.97610832439452, 176.15352128877007], [0.0, 0.5612749848411747, 1.3349444108923387, 2.216038265009323, 3.1750507831325714, 4.196509322561049, 5.270656943734746, 6.390697145069546, 7.551585963592432, 8.749411116861298, 9.9810374891297, 11.243888836271042, 12.535805476455716, 13.854947268195927, 15.199725029488565, 16.568750593606403, 17.9607995149176, 19.374782620213228, 20.809723904510722, 22.264743078715973, 23.73904159436387, 25.231891311827148, 26.74262520878638, 28.270629684801186, 29.81533812978243, 31.376225504375785, 32.95280373865223, 34.5446177986164, 36.1512423023055, 37.7722785916834, 39.40735218524459, 41.05611055071667, 42.71822114855487, 44.39336970582889, 46.08125868717727, 47.781605935168415, 49.49414345697272, 51.218616337956334, 52.95478176583326, 54.702408151499384, 56.46127433472612, 58.231168864597706, 60.01188934600039, 61.80324184466613, 63.60504034427979, 65.41710625000972, 67.23926793354542, 69.07136031534182, 70.91322448029838, 72.76470732355358, 74.62566122346706, 76.49594373919871, 78.375417330587, 80.2639490982844, 82.16141054232854, 84.06767733752397, 85.9826291241781, 87.9061493128859, 89.83812490218975, 91.77844630805693, 93.7270072042218, 95.68370437252946, 97.6484375625011, 99.62110935941249, 101.60162506024234, 103.58989255690533, 105.58582222623596, 107.58932682623652, 109.60032139814435, 111.61872317391048, 113.64445148871705, 115.6774276981903, 117.71757509999468, 119.76481885951858, 121.81908593938459, 123.88030503253857, 125.94840649869055, 128.02332230389712, 130.10498596309185, 132.19333248538317, 134.28829832195368, 136.38982131640557, 138.49784065740906, 140.6122968335194, 142.7331315900393, 144.8602878878097, 146.99370986382175, 149.1333427935489, 151.27913305490532, 153.43102809374236, 155.5889763908011, 157.75292743004388, 159.9228316682931, 162.09864050610858, 164.2803062598422, 166.46778213480772, 168.661022199512, 170.85998136089367, 173.06461534052107, 175.27488065170155, 177.4907345774594, 179.71213514934075], [0.0, 0.5724334022399462, 1.3614837496179173, 2.2600941745019236, 3.2381723240124214, 4.279937951849102, 5.3754401457877785, 6.517747286514923, 7.701715134640938, 8.923353629661893, 10.179465328218253, 11.467422769207678, 12.785023335284183, 14.130390302059704, 15.501902893826454, 16.89814534643316, 18.31786887167829, 19.7599626430642, 21.22343125215856, 22.70737690929551, 24.210985190481317, 25.733513480321747, 27.27428149577196, 28.832663437718885, 30.408081431591544, 32.00000000000002, 33.60792136994971, 35.23138146114996, 36.869946434839385, 38.52320970746785, 40.190789352656886, 41.87232582962249, 43.567479987773375, 45.275931306281805, 46.99737633463984, 48.731527305990056, 50.478110899676146, 52.23686713323839, 54.00754836716545, 55.78991840825012, 57.58375169949179, 59.388832586228546, 61.204954649634125, 63.031920099933735, 64.86953922271816, 66.71762987260435, 68.57601700922824, 70.44453227118379, 72.3230135840616, 74.21130479920164, 76.10925536017422, 78.01671999434653, 79.93355842719238, 81.85963511726106, 83.79481900994901, 85.73898330841591, 87.69200526016043, 89.65376595792394, 91.62415015372534, 93.60304608494852, 95.59034531151036, 97.58594256322927, 99.58973559659857, 101.60162506024234, 103.62151436839754, 105.6493095818257, 107.68491929560956, 109.72825453333841, 111.77922864722844, 113.83775722376193, 115.90375799446552, 117.9771507514774, 120.05785726758258, 122.14580122042129, 124.24090812059781, 126.34310524343938, 128.4523215641735, 130.56848769630912, 132.69153583302466, 134.82139969137825, 136.95801445917135, 139.10131674430704, 141.25124452649692, 143.40773711118, 145.57073508552756, 147.74018027641452, 149.91601571024847, 152.0981855745529, 154.28663518120905, 156.48131093126642, 158.6821602812384, 160.88913171080415, 163.10217469184374, 165.32123965873677, 167.54627797986112, 169.77724193022968, 172.01408466520903, 174.25676019526603, 176.5052233616924, 178.7594298132591, 181.01933598375632, 183.2848990703771], [0.0, 0.5836354940077014, 1.3881269640841731, 2.3043225201006785, 3.3015409244320515, 4.363693123209307, 5.4806334723294565, 6.645294705894852, 7.852431915614515, 9.097976958497103, 10.37866981961791, 11.69183162043412, 13.03521664003252, 14.406911427938242, 15.805263491080149, 17.22882935986581, 18.676335808246456, 20.14665027168416, 21.638757862351145, 23.151743221512053, 24.684775987507255, 26.237099012516982, 27.808018700868104, 29.396897007028915, 31.003144747857075, 32.626215967072305, 34.265603150636345, 35.92083313655579, 37.59146359617053, 39.27707998939568, 40.9772929158404, 42.691735798777586, 44.42006285069357, 46.16194727840873, 47.91707969311661, 49.6851666965785, 51.46592961945811, 53.259103391634255, 55.06443552747632, 56.88168521165344, 58.71062247318391, 60.551027437206024, 62.40268964543213, 64.26540743749008, 66.13898738640216, 68.02324378233696, 69.91799815952199, 71.82307886184486, 73.73832064322177, 75.66356429928067, 77.59865632731557, 79.5434486118174, 81.4977981331928, 83.4615666975467, 85.43462068563534, 87.41683081929948, 89.40807194386355, 91.40822282514313, 93.4171659598407, 95.4347873982297, 97.46097657813603, 99.49562616931969, 101.53863192744538, 103.58989255690533, 105.6493095818257, 107.71678722464766, 109.79223229172835, 111.87555406545556, 113.9666642024134, 116.06547663717501, 118.17190749133479, 120.28587498742331, 122.40729936737776, 124.53610281526709, 126.67220938399403, 128.81554492571865, 130.96603702576692, 133.12361493980634, 135.2882095340867, 137.45975322855872, 139.63817994269795, 141.82342504387157, 144.0154252981008, 146.21411882307768, 148.41944504330905, 150.63134464726542, 152.849759546424, 155.07463283610005, 157.30590875796935, 159.54353266419022, 161.7874509830395, 164.03761118598234, 166.29396175610142, 168.55645215781445, 170.82503280781492, 173.09965504717357, 175.38027111454272, 177.6668341204086, 179.95929802234093, 182.2576176011904, 184.56174843818917, 186.87164689291157], [0.0, 0.5948807551988402, 1.4148728533213057, 2.348721308168242, 3.365153727987797, 4.447771061292726, 5.586232181664344, 6.773333653880585, 8.00372951280204, 9.27327323204402, 10.57864198398503, 11.917105274494755, 13.286374112984825, 14.684498181362514, 16.109793146964343, 17.56078772798846, 19.0361841663629, 20.534828075737707, 22.055685013822053, 23.597821985105288, 25.160392628843002, 26.74262520878638, 28.34381276533124, 29.96330495933328, 31.600501255499044, 33.254845178275474, 34.925819435041646, 36.612941747103314, 38.31576126318415, 40.03385545600254, 41.7668274223527, 43.51430352245001, 45.27593130628181, 47.05137768414488, 48.840327306049836, 50.642481120675065, 52.45755508939216, 54.285279034812135, 56.1253956065097, 57.977659349218044, 59.84183586096424, 61.717701030423456, 63.60504034427979, 65.50364825664766, 67.41332761367373, 69.33388912734198, 71.26515089327093, 73.20693794794518, 75.15908186138378, 77.1214203617269, 79.09379698863827, 81.07606077277691, 83.06806593890369, 85.06967163045742, 87.08074165367084, 89.10114423950358, 91.13075182184849, 93.16944083062822, 95.21709149853748, 97.2735876803108, 99.33881668350519, 101.41266910988345, 103.49503870657105, 105.58582222623596, 107.68491929560956, 109.79223229172835, 111.90766622533073, 114.03112863089284, 116.16252946283232, 118.30178099744722, 120.44879774019554, 122.6034963379514, 124.76579549590473, 126.93561589879747, 129.1128801362133, 131.2975126316606, 133.4894395752076, 135.68858885944763, 137.89489001858828, 140.10827417047432, 142.32867396136734, 144.5560235133183, 146.79025837398072, 149.03131546872245, 151.27913305490532, 153.53365067820843, 155.794809130882, 158.06255041182393, 160.33681768838042, 162.61755525977648, 164.90470852208978, 167.19822393468624, 169.49804898804064, 171.80413217287074, 174.11642295051826, 176.43487172451262, 178.75942981325912, 181.09004942379516, 183.42668362656278, 185.76928633114778, 188.11781226293886, 190.47221694066354], [0.0, 0.6061686942834926, 1.4417202482676774, 2.393288598035547, 3.4290079541668237, 4.5321680910563975, 5.69223165807752, 6.90185853389536, 8.155601312992223, 9.449234788110262, 10.779373080545138, 12.143233884688108, 13.538484776059049, 14.963138429027783, 16.415478550501227, 17.894005940915495, 19.397398217071775, 20.924479087990164, 22.474194482703908, 24.04559370199215, 25.63781432530616, 27.250069972602226, 28.881640269626462, 30.53186253696539, 32.20012484409089, 33.88586015625446, 35.58854136514097, 37.307677040755706, 39.04280777686123, 40.79350302866622, 42.55935836167534, 44.339993046240885, 46.135047944565706, 47.94418364652649, 49.76707881832711, 51.603428734108554, 53.45294396557278, 55.31534920868, 57.19038222974738, 59.077792915962775, 60.97734241754556, 62.8888023706296, 64.81195419148115, 66.74658843395493, 68.6925042031778, 70.6495086193692, 72.61741632648857, 74.59604904106521, 76.58523513713754, 78.58480926371628, 80.59461199161007, 82.6144894868152, 84.64429320798858, 86.68387962579762, 88.73310996218072, 90.79184994776297, 92.85996959585391, 94.93734299161798, 97.02384809514986, 99.11936655731266, 101.22378354730976, 103.33698759105827, 105.4588704195217, 107.58932682623652, 109.72825453333841, 111.87555406545556, 114.03112863089284, 116.19488400958119, 118.36672844731166, 120.54657255581375, 122.73432921827552, 124.92991349993473, 127.13324256340185, 129.34423558840152, 131.56281369564482, 133.78889987456637, 136.02241891468154, 138.26329734033624, 140.51146334864058, 142.76684675039152, 145.0293789138048, 147.29899271088883, 149.57562246630545, 151.8592039085733, 154.14967412347966, 156.4469715095751, 158.7510357356351, 161.06180769997925, 163.37922949154674, 165.70324435263322, 168.03379664319988, 170.37083180667221, 172.71429633714996, 175.0641377479556, 177.42030454145333, 179.78274618007313, 182.15141305848076, 184.52625647683593, 186.90722861508635, 189.2942825082462, 191.68737202261264, 194.08645183287524], [0.0, 0.6174988325957559, 1.4686680104574943, 2.438022499823328, 3.493100895225887, 4.616880633637952, 5.798627406653245, 7.030863895832011, 8.30804087605, 9.625854165032866, 10.980854597281049, 12.370207862013524, 13.791537938483636, 15.242820355173478, 16.72230673907836, 18.22846986850364, 19.759962643064203, 21.31558678526117, 22.894268522071325, 24.495039384379442, 26.11702083179393, 27.7594117857313, 29.421478407138167, 31.102545630198584, 32.8019900865494, 34.51923414277185, 36.253740838161214, 38.00500955721081, 39.77257230673988, 41.55599049447448, 43.3548521264745, 45.168769356724106, 46.997376334639846, 48.840327306049836, 50.69729493098114, 52.567968787823425, 54.45205403846011, 56.34927023303494, 58.25935023635183, 60.18203926064131, 62.11709399168726, 64.06428179718439, 66.02338000776412, 67.99417526244058, 69.97646291133528, 71.97004646947555, 73.97473711625791, 75.99035323584498, 78.01671999434656, 80.05366895013276, 82.10103769405829, 84.1586695167474, 86.22641310041207, 88.30412223295632, 90.39165554236304, 92.48887624957544, 94.59565193827052, 96.71185434008883, 98.83735913402901, 100.97204575884375, 103.11579723738866, 105.26850001197482, 107.43004378986639, 109.60032139814435, 111.77922864722844, 113.9666642024134, 116.16252946283232, 118.36672844731166, 120.57916768662834, 122.7997561217204, 125.02840500744118, 127.2650278214793, 129.50954017809886, 131.76185974638085, 134.02190617267243, 136.28960100697336, 138.56486763301012, 140.84763120176618, 143.1378185682555, 145.43535823134096, 147.74018027641455, 150.05221632076882, 152.37139946150202, 154.6976642258091, 157.030946523523, 159.3711836017773, 161.7183140016727, 164.072277516836, 166.43301515376788, 168.80046909388332, 171.17458265715362, 173.55530026726575, 175.9425674182196, 178.33633064228846, 180.7365374792738, 183.14313644698802, 185.55607701290396, 187.97530956691344, 190.40078539514062, 192.8324566547587, 195.27027634976145, 197.7141983076453], [0.0, 0.6288707038124209, 1.4957150307809997, 2.482921172384014, 3.5574299132425584, 4.701905202458175, 5.905415048379935, 7.160344430117722, 8.461041927903128, 9.803124093552412, 11.183078241663145, 12.598017864728599, 14.045523185155117, 15.523532448715635, 17.030265084332203, 18.564165744964, 20.12386252199748, 21.70813507043068, 23.315889842614258, 24.946140534085835, 26.597992425235866, 28.270629684801182, 29.96330495933328, 31.675330750990238, 33.4060722114443, 35.154941069567755, 36.9213904759765, 38.70491059581837, 40.50502481734055, 42.321286471144745, 44.153275976001964, 46.00059834331617, 47.86288098499202, 49.739771779441675, 51.63093735839252, 53.536061583503475, 55.45484418691311, 57.38699955399485, 59.33225562998532, 61.29035293493828, 63.26104367375796, 65.24409092997776, 67.2392679335454, 69.24635739421475, 71.26515089327091, 73.29544832726992, 75.33705739828417, 77.38979314583526, 79.4534775162885, 81.52793896598946, 83.6130120948627, 85.70853730756934, 87.81436049964992, 89.93033276636343, 92.05631013218284, 94.1921532991254, 96.33772741228636, 98.49290184111355, 100.65754997510749, 102.83154903276242, 105.01477988268053, 107.20712687589207, 109.40847768850796, 111.61872317391048, 113.83775722376193, 116.06547663717501, 118.30178099744722, 120.54657255581375, 122.7997561217204, 125.06123895915965, 127.33093068865236, 129.6087431944905, 131.89459053688873, 134.18838886872015, 136.49005635653734, 138.7995131056033, 141.1166810886776, 143.44148407832273, 145.77384758251304, 148.11369878334497, 150.4609664786617, 152.8155810264184, 155.17747429162813, 157.5465795957373, 159.92283166829304, 162.3061666007708, 164.69652180244296, 167.0938359581745, 169.4980489880406, 171.909102008668, 174.3269372962074, 176.75149825085126, 179.18272936281588, 181.62057617971172, 184.06498527523223, 186.51590421909273, 188.97328154815804, 191.43706673869917, 193.90721017972456, 196.3836631473329, 198.8663777800386, 201.35530705502427], [0.0, 0.6402838534600861, 1.5228602283121881, 2.527982821355704, 3.621992437327046, 4.787238399535833, 6.012590315521713, 7.290294962102013, 8.614598353910742, 9.9810374891297, 11.386035931884505, 12.82665478847532, 14.300430365629758, 15.805263491080147, 17.33934127880042, 18.90108015431218, 20.48908331072277, 22.10210825542493, 23.739041594363865, 25.398879122990007, 27.080709883747385, 28.783703239142813, 30.507098272277148, 32.25019500815585, 34.01234707681574, 35.79295553080669, 37.59146359617053, 39.407352185244584, 41.24013603641968, 43.089360373854255, 44.95459800148955, 46.83544676222265, 48.73152730599005, 50.64248112067506, 52.56796878782341, 54.50766843161227, 56.461274334726106, 58.42849569902056, 60.40905553230759, 62.40268964543213, 64.40914574615383, 66.42818261829375, 68.45956937623102, 70.50308478619645, 72.55851664695842, 74.62566122346705, 76.70432272784836, 78.79431284284237, 80.89545028338259, 83.00756039253011, 85.13047476842263, 87.26403091928252, 89.40807194386353, 91.56244623500577, 93.72700720422179, 95.90161302545954, 98.08612639638082, 100.28041431566623, 102.4843478750076, 104.69780206458152, 106.92065559091698, 109.15279070617245, 111.3940930479327, 113.64445148871705, 115.90375799446552, 118.17190749133479, 120.44879774019554, 122.73432921827552, 125.02840500744118, 127.33093068865236, 129.64181424216505, 131.96096595309075, 134.28829832195365, 136.6237259799153, 138.9671656083623, 141.31853586257662, 143.67775729922937, 146.04475230745842, 148.41944504330908, 150.80176136733164, 153.19162878514675, 155.58897639080107, 157.99373481275006, 160.40583616231493, 162.82521398447267, 165.25180321084576, 167.68554011476988, 170.12636226832348, 172.5742085012127, 175.02901886141092, 177.4907345774594, 179.9592980223409, 182.43465267884446, 184.91674310634363, 187.4055149089169, 189.9009147047411, 192.40289009669496, 194.9113896441124, 197.4263628356298, 199.94776006307305, 202.47553259633563, 205.00963255919982], [0.0, 0.651737838448728, 1.5501025491994427, 2.573205697320603, 3.686785960983667, 4.872876912000292, 6.1201490472383995, 7.4207104467459555, 8.768704192587842, 10.159587444674829, 11.589719788566473, 13.05610975693619, 14.556249583706062, 16.088002544689044, 17.649523323290627, 19.239200016599327, 20.85561083035931, 22.497491045115652, 24.163707349399242, 25.85323757452824, 27.565154466902168, 29.298612529822307, 31.052837234409928, 32.827116083875616, 34.62079114539729, 36.433252757003316, 38.26393418465219, 40.11230705476489, 41.97787742492737, 43.8601823838506, 45.758787093400784, 47.67328220231981, 49.6032815743822, 51.54842028407761, 53.50835284112308, 55.482751611685735, 57.47130540949826, 59.47371823435227, 61.489708138969355, 63.51900620813648, 65.56135563637821, 67.61651089241933, 69.68423696034513, 71.76430864875383, 73.85650996036343, 75.96063351552462, 78.07648002393032, 80.20385779952858, 82.34258231425935, 84.49247578676017, 86.65336680264173, 88.82508996332439, 91.00748556076847, 93.20039927572611, 95.40368189740053, 97.6171890626251, 99.84078101287149, 102.07432236757064, 104.3176819123843, 106.57073240119867, 108.83335037073381, 111.10541596676681, 113.38681278106264, 115.6774276981903, 117.9771507514774, 120.28587498742331, 122.6034963379514, 124.92991349993473, 127.2650278214793, 129.6087431944905, 131.96096595309075, 134.32160477748928, 136.6905706029394, 139.0677765334466, 141.4531377599176, 143.8465714824655, 146.24799683660618, 148.6573348231033, 151.07450824123586, 153.49944162527967, 155.93206118400946, 158.37229474304104, 160.82007168984813, 163.27532292129695, 165.73798079355606, 168.20797907424512, 170.68525289669873, 173.16973871622747, 175.66137426826708, 178.16009852831414, 180.6658516735521, 183.1785750460788, 185.69821111765154, 188.22470345587107, 190.75799669173176, 193.29803648846737, 195.8447695116289, 198.39814340033246, 200.95810673962072, 203.5246090338831, 206.09760068128426, 208.67703294915273], [0.0, 0.6632322266299546, 1.5774409656148787, 2.6185880940609048, 3.7518080396119537, 4.958817508788696, 6.228087185437286, 7.551585963592431, 8.923353629661893, 10.338767223661064, 11.794122126903174, 13.286374112984824, 14.812971187558588, 16.371738942056073, 17.9607995149176, 19.57851257487187, 21.223431252158562, 22.894268522071325, 24.589871085469333, 26.309198746171152, 28.051307897048563, 29.815338129782422, 31.60050125549904, 33.4060722114443, 35.23138146114996, 37.075808590328144, 38.93877686972042, 40.81974860707595, 42.71822114855487, 44.63372341872338, 46.56581291041575, 48.51407305284174, 50.478110899676146, 52.45755508939215, 54.452054038460105, 56.461274334726106, 58.48489930367964, 60.522627724698395, 62.57417267793482, 64.63926050544701, 66.71762987260435, 68.80903091781408, 70.91322448029837, 73.02998139706246, 75.15908186138377, 77.30031483615738, 79.4534775162885, 81.61837483505008, 83.79481900994901, 85.98262912417809, 88.18163074019449, 90.39165554236303, 92.61254100594982, 94.84413009005229, 97.0862709523143, 99.33881668350519, 101.60162506024234, 103.87455831431447, 106.15748291721886, 108.45026937866291, 110.75279205790397, 113.06492898690757, 115.38656170440237, 117.71757509999468, 120.05785726758258, 122.40729936737776, 124.76579549590473, 127.13324256340185, 129.50954017809886, 131.89459053688873, 134.28829832195365, 136.6905706029394, 139.10131674430704, 141.52044831751894, 143.94787901774458, 146.383524584795, 148.82730272801794, 151.27913305490532, 153.738937003184, 156.20663777617696, 158.6821602812384, 161.16543107107913, 163.6563782878135, 166.15493160956888, 168.66102219951193, 171.1745826571536, 173.6955469718061, 176.2238504780728, 178.7594298132591, 181.30222287660166, 183.85216879021755, 186.40920786168329, 188.97328154815804, 191.54433242197146, 194.1223041376012, 196.70714139996952, 199.29878993399328, 201.89719645532475, 204.5023086422256, 207.1140751085184, 209.7324453775639, 212.35736985721593], [0.0, 0.6747665963783116, 1.604874474758515, 2.6641283469056987, 3.817056288138163, 5.045057037515499, 6.33640077084139, 7.682916711998865, 9.078540992439562, 10.518570253598021, 11.999235449215965, 13.517439410298353, 15.070585760386619, 16.656462275451346, 18.273158435764728, 19.919005382811715, 21.592531084105985, 23.29242613210416, 25.017517170469485, 26.766745912814883, 28.539152341601, 30.333861085020352, 32.15007024668998, 33.987042154182156, 35.84409562702092, 37.72059946120173, 39.615966897482316, 41.529650892526405, 43.46114005076682, 45.40995510422725, 47.37564585003439, 49.35778847275376, 51.35598319227252, 53.36985218866059, 55.39903776394717, 57.44320070755827, 59.50201883765012, 61.57518569502803, 63.66240936997894, 65.7634114453352, 67.87792604155696, 70.00569895167158, 72.14648685562074, 74.30005660500217, 76.46618457040204, 78.64465604453794, 80.83526469530169, 83.03781206353192, 85.25210710098241, 87.47796574449504, 89.71521052285782, 91.96367019323351, 94.2231794043965, 96.49357838432269, 98.77471264994303, 101.06643273710672, 103.36859394900327, 105.68105612147404, 108.00368340380238, 110.33634405371086, 112.67891024542008, 115.03125788973145, 117.39326646519615, 119.76481885951858, 122.14580122042129, 124.53610281526709, 126.93561589879747, 129.34423558840152, 131.76185974638085, 134.18838886872015, 136.6237259799153, 139.0677765334466, 141.52044831751894, 143.98165136572106, 146.45129787228225, 148.92930211163218, 151.4155803619897, 153.91005083272873, 156.412633595288, 158.92325051740818, 161.44182520049608, 163.96828291992986, 166.5025505681328, 169.0445566002541, 171.59423098230897, 174.1515051416364, 176.716311919547, 179.28858552603867, 181.8682614964668, 184.4552766500645, 187.0495690502126, 189.65107796636778, 192.2597438375621, 194.875508237392, 197.4983138404219, 200.12810438992915, 202.76482466692462, 205.40842046038458, 208.05883853863565, 210.7160266218358, 213.37993335549902, 216.05050828501484], [0.0, 0.6863405361941362, 1.6324020979136988, 2.7098248311629476, 3.8825283787686793, 5.131592421503104, 6.44508593926005, 7.814698006615312, 9.234260744463388, 10.698990119840794, 12.20505243789107, 13.749297405401498, 15.329084111544097, 16.942162387097866, 18.586588942129026, 20.26066629301257, 21.96289715821237, 23.69194967056096, 25.446630347716976, 27.225862751027037, 29.028670396242738, 30.85416289673418, 32.701524601583834, 34.57000518543134, 36.458911783846816, 38.36760236609361, 40.295480108536545, 42.241988584673834, 44.20660762722148, 46.18884974755508, 48.18825702069272, 50.20439836170204, 52.23686713323839, 54.285279034812135, 56.34927023303494, 58.428495699020566, 60.522627724698395, 62.63135459432979, 64.75437939121782, 66.89141892264203, 69.04220274856145, 71.20647230171619, 73.38398008849852, 75.57448896142623, 77.77777145528005, 79.99360918000907, 82.22179226439185, 84.46211884519458, 86.71439459721437, 88.97843230014816, 91.25405143870752, 93.54107783281096, 95.83934329504457, 98.14868531289322, 100.46894675351571, 102.79997558907613, 105.1416246408507, 107.49375134051384, 109.85621750716831, 112.22888913882616, 114.61163621717523, 117.00433252457587, 119.40685547233406, 121.81908593938459, 124.24090812059781, 126.67220938399403, 129.1128801362133, 131.56281369564482, 134.02190617267243, 136.49005635653734, 138.9671656083623, 141.4531377599176, 143.94787901774458, 146.45129787228225, 148.96330501167074, 151.4838132399311, 154.01273739924363, 156.54999429606784, 159.09550263086714, 161.6491829312179, 164.21095748809944, 166.78075029517524, 169.35848699089019, 171.94409480321988, 174.53750249692092, 177.13864032313919, 179.74743997124534, 182.36383452277366, 184.98775840734916, 187.61914736049633, 190.25793838322758, 192.90406970331847, 195.557480738181, 198.2181120592523, 200.88590535782166, 203.56080341222258, 206.2427500563217, 208.93169014924032, 211.6275695462483, 214.33033507077312, 217.03993448747056, 219.75631647630698], [0.0, 0.6979536443265747, 1.6600228795504826, 2.755675960631076, 3.9482220388574785, 5.218420656963265, 6.554138918048869, 7.946925273092117, 9.390507480439728, 10.880020559713367, 12.41156594867578, 13.98194005011456, 15.588457268119907, 17.22882935986581, 18.90108015431218, 20.603483445851484, 22.334516618450404, 24.092825269309934, 25.87719572197405, 27.686533324092494, 29.51984506898147, 31.376225504375782, 33.254845178275474, 35.154941069567755, 37.075808590328144, 39.016794846448306, 40.9772929158404, 42.95673695708279, 44.95459800148955, 46.970380311968064, 49.003618215294736, 51.053873332438066, 53.12073214561547, 55.20380385184633, 57.30271846156145, 59.41712510787208, 61.54669053777904, 63.691097761210614, 65.85004483754147, 68.02324378233698, 70.21041957962153, 72.41130928709194, 74.62566122346705, 76.85323422865108, 79.09379698863827, 81.34712741814604, 83.61301209486271, 85.89124573996199, 88.18163074019449, 90.48397670742793, 92.79810007199568, 95.12382370663184, 97.46097657813603, 99.80939342422776, 102.16891445332641, 104.53938506523491, 106.92065559091698, 109.31258104974398, 111.71502092275233, 114.12783894059628, 116.55090288501091, 118.98408440271257, 121.42725883076609, 123.88030503253857, 126.34310524343938, 128.81554492571865, 131.2975126316606, 133.78889987456637, 136.28960100697336, 138.7995131056033, 141.31853586257662, 143.8465714824655, 146.383524584795, 148.92930211163218, 151.4838132399311, 154.0469692983281, 156.61868368810508, 159.19887180805938, 161.78745098303952, 164.3843403959222, 166.98946102282457, 169.60273557135778, 172.2240884217447, 174.85344557063434, 177.4907345774594, 180.13588451319222, 182.78882591136508, 185.4494907212297, 188.11781226293886, 190.79372518464083, 193.47716542138446, 196.16807015573883, 198.86637778003865, 201.5720278601701, 204.2849611008199, 207.00511931211216, 209.73244537756395, 212.4668832232947, 215.2083777884276, 217.95687499662506, 220.71232172870359, 223.4746657962776], [0.0, 0.7096055284154843, 1.6877358864739191, 2.8016801861851217, 4.014135048880419, 5.305538810319674, 6.663556022746991, 8.079594044002596, 9.547275921420782, 11.06165545692642, 12.61876900431046, 14.215359484379722, 15.848696466939915, 17.516453508432942, 19.216621446922993, 20.947445258917824, 22.707376909295512, 24.495039384379442, 26.309198746171152, 28.148742067808307, 30.012659765003608, 31.900031269552667, 33.81001328229156, 35.74183004396415, 37.69476520400687, 39.66815496866706, 41.661382283685676, 43.67387186128498, 45.70508590198942, 47.754520392696655, 49.821701886070194, 51.90618468462451, 54.00754836716544, 56.12539560650969, 58.259350236351814, 60.40905553230758, 62.57417267793481, 64.75437939121782, 66.94936869082811, 69.15884778461735, 71.38253706539638, 73.62016920121052, 75.87148830912264, 78.13624920302532, 80.41421670727526, 82.70516502901995, 85.0088771830004, 87.32514446339326, 89.65376595792395, 91.99454810005359, 94.34730425553884, 96.71185434008883, 99.08802446521464, 101.47564660968906, 103.87455831431448, 106.2846023979437, 108.70562669291277, 111.13748379823538, 113.58003084907483, 116.03312930115688, 118.49664472891835, 120.9704466363006, 123.45440827920152, 125.94840649869055, 128.4523215641735, 130.96603702576692, 133.4894395752076, 136.02241891468154, 138.56486763301012, 141.1166810886776, 143.67775729922937, 146.24799683660618, 148.82730272801794, 151.4155803619897, 154.01273739924363, 156.61868368810508, 159.2333311841464, 161.8565938738027, 164.4883877017143, 167.12863050156844, 169.77724193022968, 172.4341434049628, 175.09925804356752, 177.77251060725473, 180.45382744610885, 183.14313644698802, 185.84036698372682, 188.54544986951382, 191.25831731132487, 193.97890286630147, 196.70714139996954, 199.44296904620188, 202.18632316883313, 204.93714232484103, 207.69536622901552, 210.4609357200383, 213.23379272790385, 216.01388024261445, 218.8011422840876, 221.59552387321625, 224.3969710040266, 227.20543061688173], [0.0, 0.7212958051510344, 1.715540207014453, 2.8478359944327636, 4.080265240509658, 5.392944015662893, 6.773333653880585, 8.212699954967242, 9.704560910224751, 11.24388883627104, 12.826654788475318, 14.449548029441935, 16.109793146964343, 17.805025370881964, 19.53320243965915, 21.292540416964783, 23.081465764833116, 24.898578784207693, 26.742625208786375, 28.612473776980714, 30.507098272277148, 32.425562960725486, 34.3670106503718, 36.33065280184477, 38.31576126318415, 40.32166130507892, 42.3477257077136, 44.39336970582888, 46.45804664006234, 48.54124419403269, 50.64248112067506, 52.76130437993577, 54.89728662446253, 57.05002398137229, 59.219134087271186, 61.404254340979215, 63.60504034427978, 65.82116450577644, 68.0523147868285, 70.29819357173274, 72.55851664695842, 74.83301227643562, 77.1214203617269, 79.42349167744759, 81.73898717359289, 84.06767733752396, 86.40934160929471, 88.76376784479291, 91.13075182184849, 93.51009678504327, 95.90161302545954, 98.30511749203806, 100.72043343159332, 103.14739005486072, 105.58582222623595, 108.03557017511747, 110.49647922698081, 112.96839955250692, 115.45118593325643, 117.94469754253079, 120.44879774019554, 122.96335388035666, 125.48823713088773, 128.02332230389712, 130.56848769630912, 133.12361493980634, 135.68858885944763, 138.26329734033624, 140.84763120176618, 143.44148407832273, 146.04475230745842, 148.6573348231033, 151.27913305490532, 153.91005083272873, 156.54999429606784, 159.19887180805938, 161.8565938738027, 164.5230730627168, 167.19822393468627, 169.88196296976318, 172.5742085012127, 175.27488065170152, 177.9839012724465, 180.7011938851498, 183.42668362656275, 186.16029719552762, 188.90196280236017, 191.65161012044248, 194.40917023990565, 197.1745756232895, 199.94776006307305, 202.7286586409773, 205.51720768894793, 208.31334475173003, 211.11700855095495, 213.92813895066126, 216.74667692417887, 219.57256452230845, 222.40574484273313, 225.24616200060177, 228.09376110022822, 230.9484882078536], [0.0, 0.7330240999499174, 1.743434950257815, 2.8941419064359306, 4.146610494782019, 5.4806334723294565, 6.883468293922298, 8.346238740967058, 9.862357407079461, 11.426714858571339, 13.03521664003252, 14.684498181362516, 16.37173894205608, 18.094535700707837, 19.85081298853876, 21.63875786235115, 23.45677119839737, 25.303430538465786, 27.177461221840698, 29.077713592581013, 31.003144747857075, 32.95280373865223, 34.925819435041646, 36.9213904759765, 38.93877686972043, 40.97729291584041, 43.036301195905025, 45.115207436351575, 47.21345608911745, 49.33052650753925, 51.46592961945812, 53.619205018373435, 55.78991840825012, 57.977659349218044, 60.182039260641304, 62.40268964543214, 64.63926050544701, 66.89141892264203, 69.15884778461736, 71.44124463642814, 73.73832064322177, 76.04979965049041, 78.37541733058701, 80.71492040571349, 83.0680659389037, 85.43462068563534, 87.81436049964995, 90.20706978736465, 92.61254100594985, 95.03057420073742, 97.46097657813604, 99.90356211066998, 102.35815117114075, 104.8245701932444, 107.30265135626595, 109.79223229172837, 112.29315581009405, 114.80526964581401, 117.32842621919202, 119.86248241368256, 122.4072993673778, 124.96274227755691, 127.52868021727862, 130.10498596309185, 132.69153583302466, 135.2882095340867, 137.89489001858828, 140.51146334864058, 143.1378185682555, 145.77384758251304, 148.41944504330908, 151.07450824123586, 153.738937003184, 156.412633595288, 159.09550263086714, 161.78745098303952, 164.4883877017143, 167.19822393468627, 169.9168728525807, 172.64424957741247, 175.38027111454272, 178.12485628783006, 180.87792567778936, 183.639401562583, 186.4092078616833, 189.1872700820532, 191.97351526670562, 194.76787194550946, 197.57027008811897, 200.3806410589125, 203.19891757383243, 206.0250336590264, 208.85892461119528, 211.7005269595595, 214.54977842936208, 217.40661790682873, 220.27098540551367, 223.1428220339616, 226.02206996462195, 228.90867240395403, 231.80257356366587, 234.70371863303384], [0.0, 0.7447900466471514, 1.7714192453120021, 2.9405964764939725, 4.2131687403555675, 5.568604442597571, 6.993956504397129, 8.480206232834401, 10.020660485475789, 11.61012781588015, 13.244448047545587, 14.920202604845109, 16.634525674097254, 18.38497545921001, 20.16944317755419, 21.986086785943392, 23.83328149270886, 25.709582007418984, 27.61369320947135, 29.54444698951997, 31.500783704850225, 33.48173714253334, 35.48642218992788, 37.51402462314545, 39.563792572663786, 41.63502933170677, 43.72708725048594, 45.839362516610244, 47.97129066478107, 50.12234269130981, 52.29202167382239, 54.47985981572232, 56.685415849984096, 58.90827274866821, 61.148035693937196, 63.40433027386763, 65.67680087241132, 67.96510922777652, 70.26893313751576, 72.58796529190687, 74.92191221993934, 77.27049333448271, 79.63344006510306, 82.01049506857927, 84.40141150850536, 86.80595239649487, 89.22388998846371, 91.65500523028435, 94.09908724780718, 96.55593287684344, 99.02534622922538, 101.50713829150531, 104.00112655324531, 106.50713466218674, 109.0249921038839, 111.5545339036441, 114.09560034884255, 116.64803672987921, 119.21169309822055, 121.78642404012281, 124.37208846477219, 126.96854940569689, 129.57567383441565, 132.19333248538317, 134.82139969137825, 137.45975322855872, 140.10827417047432, 142.76684675039152, 145.43535823134096, 148.11369878334497, 150.80176136733164, 153.49944162527967, 156.20663777617696, 158.92325051740818, 161.6491829312179, 164.3843403959222, 167.12863050156844, 169.88196296976318, 172.64424957741247, 175.4154040841341, 178.19534216312238, 180.98398133525794, 183.7812409062744, 186.58704190680217, 189.40130703512662, 192.22396060250503, 195.05492848090012, 197.89413805299642, 200.74151816437427, 203.596999077725, 206.46051242899847, 209.33199118538002, 212.21136960500223, 215.09858319830082, 217.99356869093157, 220.89626398816827, 223.80660814070828, 226.7245413118153, 229.6500047457348, 232.58294073731923, 235.5232926028054, 238.47100465168938], [0.0, 0.7565932872025407, 1.7994922406091172, 2.987198290984697, 4.279937951849103, 5.6568542494923815, 7.104794923125942, 8.614598353910742, 10.179465328218255, 11.794122126903176, 13.45434264405944, 15.15665412735527, 16.898145346433164, 18.676335808246456, 20.48908331072277, 22.334516618450404, 24.210985190481317, 26.117020831793926, 28.051307897048563, 30.012659765003608, 32.00000000000002, 34.01234707681574, 36.048801855772496, 38.108537209371725, 40.190789352656886, 42.294850537622594, 44.420062850693576, 46.56581291041575, 48.731527305990056, 50.91666865021386, 53.12073214561548, 55.343242582078624, 57.58375169949179, 59.84183586096423, 62.11709399168725, 64.40914574615383, 66.71762987260435, 69.04220274856145, 71.38253706539638, 73.73832064322177, 76.10925536017422, 78.49505618245078, 80.89545028338259, 83.31017624143954, 85.73898330841591, 88.18163074019448, 90.63788718346161, 93.1075301125765, 95.59034531151036, 98.0861263963808, 100.59467437463492, 103.11579723738865, 105.6493095818257, 108.19503226090238, 110.75279205790397, 113.32242138366146, 115.90375799446554, 118.49664472891834, 121.10092926214065, 123.71646387590921, 126.3431052434394, 128.98071422765008, 131.62915569185895, 134.28829832195368, 136.95801445917135, 139.63817994269795, 142.32867396136734, 145.0293789138048, 147.74018027641455, 150.4609664786617, 153.19162878514675, 155.93206118400946, 158.6821602812384, 161.44182520049608, 164.21095748809944, 166.98946102282457, 169.77724193022968, 172.5742085012127, 175.38027111454272, 178.19534216312238, 181.01933598375635, 183.85216879021755, 186.69375860941764, 189.54402522050086, 192.40289009669493, 195.27027634976142, 198.1461086769011, 201.030313309978, 203.9228179669355, 206.82355180528617, 209.73244537756392, 212.6494305886354, 215.574440654773, 218.5074100643985, 221.44827454041217, 224.3969710040266, 227.35343754003028, 230.3176133634098, 233.2894387872646, 236.2688551919508, 239.2558049953955, 242.25023162452615], [0.0, 0.7684334714209161, 1.8276531032399874, 3.0339459672598195, 4.346916148259592, 5.745380274694295, 7.215980261598381, 8.749411116861296, 10.338767223661064, 11.978692332637989, 13.664894202125488, 15.39384573351612, 17.162590137623987, 18.968608103327874, 20.80972390451072, 22.684037022165047, 24.589871085469333, 26.525734923121583, 28.490292300803276, 30.48233802743569, 32.50077882185413, 34.54461779861639, 36.61294174710331, 38.70491059581837, 40.81974860707595, 42.95673695708279, 45.11520743635157, 47.2945370644144, 49.494143456972715, 51.7134808170698, 53.95203644748763, 56.20932770138611, 58.48489930367963, 60.7783209878405, 63.08918540250469, 65.41710625000971, 67.76171662524501, 70.12266752826886, 72.49962652828908, 74.89227656000968, 77.30031483615738, 79.72345186233889, 82.16141054232851, 84.61392536352223, 87.08074165367083, 89.561614901171, 92.05631013218284, 94.56460133868656, 97.0862709523143, 99.62110935941246, 102.1689144533264, 104.7294912203601, 107.30265135626591, 109.88821291046744, 112.48599995552304, 115.09584227960411, 117.71757509999466, 120.35103879582499, 122.9960786584323, 125.6525446579009, 128.32029122447688, 130.99917704367581, 133.68906486401585, 136.38982131640557, 139.10131674430704, 141.82342504387157, 144.5560235133183, 147.29899271088883, 150.05221632076882, 152.8155810264184, 155.58897639080107, 158.37229474304104, 161.16543107107913, 163.96828291992986, 166.78075029517524, 169.60273557135778, 172.4341434049628, 175.27488065170152, 178.12485628783006, 180.98398133525794, 183.85216879021755, 186.72933355528278, 189.61539237454073, 192.51026377173233, 195.4138679911933, 198.32612694143518, 201.24696414121968, 204.1763046679884, 207.11407510851836, 210.06020351168408, 213.0146193432126, 215.97725344232677, 218.94803798017787, 221.9269064199748, 224.91379347872382, 227.90863509049618, 230.91136837114834, 233.92193158442163, 236.94026410935498, 239.9663064089459, 243.0000000000002, 246.0412874241141], [0.0, 0.7803102566853521, 1.855901018319641, 3.0808381525916437, 4.414101391453026, 5.834179956544297, 7.327509302467644, 8.884640620637441, 10.4985615621187, 12.163833092215286, 13.876096629057491, 15.631770559763932, 17.4278523954863, 19.261783887032205, 21.13135568060848, 23.03463788308876, 24.969928213931286, 26.93571245452807, 28.930633717935937, 30.95346818583492, 33.00310567948089, 35.07853390572913, 37.17882553952268, 39.30312752535387, 41.45065213585905, 43.62066943721896, 45.81250089220694, 48.025513891668304, 50.25911705006555, 52.5127561346912, 54.78591052416075, 57.078090111921455, 59.388832586228546, 61.717701030423456, 64.06428179718439, 66.42818261829375, 68.8090309178141, 71.20647230171619, 73.62016920121053, 76.04979965049043, 78.4950561824508, 80.9556448283191, 83.43128420911457, 85.92170470851265, 88.4266477180905, 90.94586494711241, 93.47911779002025, 96.02617674565029, 98.58682088293266, 101.16083734845856, 103.74802091184507, 106.3481735452956, 108.96110403416202, 111.58662761566885, 114.22456564326795, 116.8747452743638, 119.53699917938505, 122.21116527038724, 124.89708644755515, 127.59461036213466, 130.30358919446886, 133.0238794459393, 135.75534174372692, 138.49784065740906, 141.25124452649692, 144.0154252981008, 146.79025837398072, 149.57562246630545, 152.37139946150202, 155.17747429162813, 157.99373481275006, 160.82007168984813, 163.6563782878135, 166.5025505681328, 169.35848699089019, 172.2240884217447, 175.09925804356752, 177.9839012724465, 180.87792567778936, 183.7812409062744, 186.69375860941764, 189.61539237454073, 192.54605765894067, 195.48567172707425, 198.43415359058642, 201.39142395101905, 204.35740514505213, 207.33202109213602, 210.31519724438476, 213.30686053860765, 216.30693935036533, 219.31536344994265, 222.3320639601391, 225.3569733157814, 228.39002522487235, 231.4311546312904, 234.48029767896475, 237.5373916774509, 240.6023750688399, 243.6751873959348, 246.7557692716345, 249.84406234946732], [0.0, 0.7922233077026015, 1.8842351883818476, 3.127873523167981, 4.481491784724373, 5.923250788140647, 7.439378897159984, 9.020283047578216, 10.658843832440935, 12.349539178930609, 14.087943962404669, 15.870421889248501, 17.693924631407505, 19.555854882720748, 21.45396955903689, 23.386309303416834, 25.351145846483266, 27.34694185194729, 29.37231971717829, 31.426036939736807, 33.50696639170253, 35.614080325180815, 37.74643725757849, 39.90317110973008, 42.08348212798341, 44.28662923456877, 46.51192353298445, 48.75872275598772, 51.026426489316925, 53.314472038755255, 55.622330834555264, 57.949505287673354, 60.295526028219165, 62.659949469097064, 65.04235564780282, 67.44234630733263, 69.85954318360628, 72.29358647203621, 74.7441334501467, 77.21085723665671, 79.6934456703394, 82.19160029438056, 84.7050354339669, 87.2334773565227, 89.7766635054323, 92.33434179928803, 94.9062699897241, 97.49221507176654, 100.09195274137547, 102.70526689549423, 105.33194917047341, 107.97179851521223, 110.62462079577523, 113.29022842860076, 115.96844003973139, 118.65908014777168, 121.36197886851804, 124.07697163941808, 126.80389896220278, 129.54260616219895, 132.29294316297674, 135.05476427511425, 137.82792799797795, 140.6122968335194, 143.40773711118, 146.21411882307768, 149.03131546872245, 151.8592039085733, 154.6976642258091, 157.5465795957373, 160.40583616231493, 163.27532292129695, 166.15493160956888, 169.0445566002541, 171.94409480321988, 174.85344557063434, 177.77251060725473, 180.7011938851498, 183.639401562583, 186.58704190680217, 189.54402522050086, 192.51026377173233, 195.48567172707425, 198.47016508785416, 201.4636616292621, 204.46608084218488, 207.47734387761113, 210.49737349346427, 213.52609400373046, 216.56343122975827, 219.60931245361297, 222.6636663733775, 225.7264230602983, 228.79751391767994, 231.8768716414406, 234.9644301822425, 238.06012470911966, 241.16389157452824, 244.2756682807504, 247.395393447585, 250.5230067812639, 253.65844904453576], [0.0, 0.804172296260054, 1.912654832801065, 3.175050783132571, 4.549085471422734, 6.012590315521712, 7.551585963592431, 9.156334660643047, 10.819609618742847, 12.535805476455712, 14.300430365629754, 16.109793146964343, 17.9607995149176, 19.850812988538753, 21.77755665156548, 23.739041594363865, 25.733513480321747, 27.759411785731295, 29.81533812978242, 31.900031269552663, 34.01234707681574, 36.15124230230549, 38.31576126318415, 40.50502481734054, 42.71822114855487, 44.95459800148955, 47.21345608911744, 49.494143456972715, 51.79605063483301, 54.118606441446744, 56.461274334726106, 58.82354922056454, 61.20495464963412, 63.60504034427978, 66.0233800077641, 68.45956937623102, 70.91322448029837, 73.3839800884985, 75.87148830912264, 78.375417330587, 80.89545028338257, 83.43128420911455, 85.98262912417809, 88.549207167329, 91.13075182184849, 93.72700720422178, 96.33772741228636, 98.9626759266882, 101.60162506024234, 104.25435545044125, 106.92065559091698, 109.60032139814432, 112.29315581009402, 114.99896841390893, 117.71757509999468, 120.44879774019553, 123.19246388796927, 125.94840649869052, 128.71646366840116, 131.49647838949244, 134.28829832195365, 137.09177557895055, 139.90676652561626, 142.7331315900393, 145.57073508552756, 148.41944504330905, 151.27913305490532, 154.14967412347966, 157.030946523523, 159.92283166829304, 162.82521398447267, 165.73798079355606, 168.66102219951193, 171.59423098230897, 174.53750249692092, 177.4907345774594, 180.45382744610885, 183.42668362656275, 186.4092078616833, 189.40130703512662, 192.40289009669493, 195.4138679911933, 198.43415359058642, 201.4636616292621, 204.50230864222556, 207.55001290605642, 210.6066943824752, 213.67227466437433, 216.74667692417884, 219.82982586441153, 222.9216476703437, 226.0220699646219, 229.13102176376728, 232.24843343645057, 235.37423666345228, 238.50836439922205, 241.65075083495796, 244.80133136312952, 247.96004254337495, 251.1268220697045, 254.30160873894786, 257.48434242038695], [0.0, 0.8161569009935596, 1.9411591872402252, 3.2223686636683935, 4.616880633637951, 6.102196135930041, 7.664127483992528, 9.292791800768175, 10.980854597281049, 12.722626975219272, 14.513550123980234, 16.349877895099546, 18.22846986850364, 20.14665027168416, 22.10210825542493, 24.09282526930993, 26.117020831793926, 28.173111162635745, 30.259677040912614, 32.37543842735958, 34.51923414277184, 36.69000539030698, 38.886782244556194, 41.10867246152609, 43.35485212647449, 45.624557773179156, 47.91707969311662, 50.23175621572339, 52.56796878782342, 54.92513771583318, 57.30271846156145, 59.7001984034685, 62.11709399168725, 64.55294823806074, 67.00732849273803, 69.47982446710623, 71.97004646947553, 74.47762382532241, 77.00220345829706, 79.54344861181741, 82.10103769405828, 84.67466323162648, 87.26403091928252, 89.86885875480742, 92.48887624957543, 95.12382370663182, 97.77345155912651, 100.43751976285019, 103.11579723738866, 105.80806135106816, 108.51409744543473, 111.23369839550008, 113.96666420241338, 116.71280161558876, 119.47192378164084, 122.24384991776445, 125.02840500744117, 127.8254195165744, 130.63472912834627, 133.4561744952588, 136.28960100697333, 139.13485857269356, 141.99180141695768, 144.8602878878097, 147.74018027641452, 150.63134464726542, 153.53365067820843, 156.4469715095751, 159.3711836017773, 162.3061666007708, 165.25180321084576, 168.20797907424512, 171.1745826571536, 174.1515051416364, 177.13864032313919, 180.13588451319222, 183.14313644698802, 186.16029719552762, 189.1872700820532, 192.22396060250503, 195.27027634976142, 198.32612694143518, 201.39142395101905, 204.46608084218488, 207.55001290605642, 210.6431372012867, 213.74537249678315, 216.85663921693467, 219.9768593892026, 223.1059565939491, 226.24385591638222, 229.39048390050655, 232.54576850497435, 235.70963906073837, 238.88202623041573, 242.06286196927417, 245.25207948776108, 248.449613215498, 251.6553987666694, 254.86937290673748, 258.0914735204192, 261.3216395808664], [0.0, 0.8281768071655123, 1.969747503122928, 3.269825922121496, 4.684875490945262, 6.192065896153156, 7.777000502814435, 9.429650884339909, 11.142574533467945, 12.909998768947567, 14.727297640542067, 16.5906698285902, 18.496928662653335, 20.443358962929665, 22.427615847297446, 24.44765103724967, 26.501657829296413, 28.58802911815953, 30.705324781417637, 32.85224592809744, 35.02761427779083, 37.230355440282736, 39.45948520564089, 41.71409818939723, 43.993358342650225, 46.29649095527054, 48.622775866541225, 50.971541661181696, 53.34216067630781, 55.73404468093046, 58.14664111720193, 60.5794298139768, 63.03192009993373, 65.50364825664765, 67.99417526244056, 70.50308478619645, 73.02998139706246, 75.57448896142621, 78.13624920302532, 80.71492040571349, 83.31017624143954, 85.92170470851265, 88.54920716732902, 91.19239746249737, 93.85100112178553, 96.52475462356604, 99.21340472550663, 101.91670784816006, 104.63442950788794, 107.3663437942207, 110.11223288733373, 112.87188661181678, 115.64510202334687, 118.43168302525068, 121.23144001226981, 124.0441895391302, 126.86975401176724, 129.70796139928018, 132.55864496488414, 135.42164301429963, 138.29679866017264, 141.18395960125287, 144.0829779151784, 146.99370986382175, 149.91601571024847, 152.849759546424, 155.794809130882, 158.7510357356351, 161.7183140016727, 164.69652180244296, 167.68554011476988, 170.68525289669873, 173.6955469718061, 176.716311919547, 179.74743997124534, 182.78882591136508, 185.84036698372682, 188.90196280236017, 191.97351526670562, 195.05492848090012, 198.1461086769011, 201.24696414121968, 204.35740514505213, 207.47734387761113, 210.6066943824752, 213.74537249678315, 216.89329579311595, 220.05038352391702, 223.21655656831143, 226.39173738119527, 229.5758499444731, 232.76881972033033, 235.97057360643421, 239.181039892963, 242.40014822137124, 245.6278295448016, 248.86401609006205, 252.1086413210899, 255.36163990383108, 258.62294767246453, 261.8925015969078, 265.1702397515432], [0.0, 0.8402317064526265, 1.9984190471286825, 3.317421341163087, 4.7530682992047755, 6.282197290936808, 7.890202124746026, 9.566908400778239, 11.304765279016404, 13.097916051356234, 14.941667432465746, 16.832162770868948, 18.766169011115128, 20.74093145138404, 22.754071077569574, 24.803509796527454, 26.887414606484064, 29.00415500921895, 31.15226991996236, 33.33044154115036, 35.53747444138541, 37.772278591683396, 40.03385545600254, 42.321286471144745, 44.633723418723385, 46.970380311968064, 49.33052650753923, 51.7134808170698, 54.11860644144675, 56.54530658742074, 58.993020654140295, 61.46122089887534, 63.949409508117874, 66.45711601358113, 68.98389500321, 71.529324085794, 74.09300207460899, 76.67454736106096, 79.27359645383655, 81.88980266278669, 84.52283490984578, 87.17237665184234, 89.83812490218972, 92.51978934023343, 95.21709149853747, 97.92976401966705, 100.65754997510749, 103.4002022398815, 106.15748291721886, 108.92916280830875, 111.71502092275233, 114.5148440258368, 117.328426219192, 120.15556855177145, 122.9960786584323, 125.84977042368045, 128.71646366840116, 131.59598385762064, 134.488161827542, 137.39283353027196, 140.30983979481226, 143.23902610302335, 146.180242379393, 149.1333427935489, 152.0981855745529, 155.07463283610005, 158.06255041182393, 161.06180769997925, 164.072277516836, 167.0938359581745, 170.12636226832348, 173.16973871622747, 176.2238504780728, 179.28858552603867, 182.36383452277366, 185.4494907212297, 188.54544986951382, 191.65161012044248, 194.76787194550946, 197.89413805299642, 201.030313309978, 204.1763046679884, 207.33202109213602, 210.49737349346427, 213.67227466437433, 216.85663921693467, 220.05038352391702, 223.25342566240752, 226.46568535985176, 229.68708394240326, 232.9175442854511, 236.1569907662121, 239.4053492182796, 242.66254688802746, 245.92851239277476, 249.20317568062168, 252.486467991873, 255.7783218219706, 259.0786708858612, 262.3874500837293, 265.7045954680298, 269.030044211759], [0.0, 0.8523212967428733, 2.0271731007099407, 3.365153727987797, 4.82145734941278, 6.37258806146673, 8.00372951280204, 9.70456091022475, 11.46742276920768, 13.286374112984824, 15.156654127355269, 17.074350669797067, 19.0361841663629, 21.03936027947952, 23.081465764833116, 25.160392628843, 27.27428149577196, 29.421478407138164, 31.60050125549904, 33.81001328229156, 36.048801855772496, 38.31576126318415, 40.6098786011483, 42.93022208981168, 45.27593130628181, 47.646208954695894, 50.04031387892538, 52.45755508939216, 54.89728662446254, 57.35890310398692, 59.84183586096424, 62.34554955929069, 64.86953922271815, 67.41332761367372, 69.97646291133526, 72.55851664695842, 75.15908186138377, 77.77777145528005, 80.41421670727526, 83.0680659389037, 85.73898330841591, 88.4266477180905, 91.13075182184849, 93.85100112178553, 96.58711314376464, 99.33881668350517, 102.10585111570208, 104.88796575964496, 107.68491929560957, 110.49647922698081, 113.32242138366146, 116.16252946283231, 119.01659460357497, 121.88441499225563, 124.76579549590474, 127.66054732112391, 130.56848769630915, 133.4894395752076, 136.42323136002582, 139.36969664248386, 142.32867396136734, 145.30000657526784, 148.28354224932653, 151.27913305490532, 154.28663518120905, 157.30590875796935, 160.33681768838042, 163.37922949154674, 166.43301515376788, 169.4980489880406, 172.5742085012127, 175.66137426826708, 178.7594298132591, 181.8682614964668, 184.98775840734916, 188.11781226293886, 191.25831731132487, 194.40917023990565, 197.57027008811897, 200.74151816437427, 203.9228179669355, 207.11407510851836, 210.31519724438476, 213.52609400373046, 216.74667692417884, 219.9768593892026, 223.21655656831143, 226.46568535985176, 229.72416433627552, 232.99191369174542, 236.26885519195076, 239.55491212601746, 242.85000926040294, 246.15407279467266, 249.46703031906318, 252.78881077373984, 256.1193444096655, 259.4585627509992, 262.80639855895197, 266.162785797026, 269.52765959757346, 272.9009562296103], [0.0, 0.8644452819410859, 2.0560089596297457, 3.4130219135461624, 4.890040966602073, 6.463235993915188, 8.117579886498598, 9.842605041329236, 11.630543020275939, 13.475368338166481, 15.372252459811254, 17.317227593770216, 19.306967515254232, 21.33863813817326, 23.409791890620763, 25.518290793512865, 27.662249022114768, 29.83998909093877, 32.050007810059945, 34.290949405972086, 36.561583997651255, 38.86079014394581, 41.18754053326599, 43.540890131501925, 45.91996627653348, 48.32396033123102, 50.75212059676812, 53.20374625447117, 55.67818215411844, 58.17481430423028, 60.693065948707876, 63.2323941364705, 65.79228670815189, 68.37225963763441, 70.97185467709593, 73.5906372629676, 76.22819464723214, 78.88413422419988, 81.55808202756069, 84.24968137634038, 86.95859165155302, 89.68448718796958, 92.42705626761598, 95.18600020345372, 97.96103250324578, 100.75187810492137, 103.55827267586773, 106.37996196952521, 109.21670123347727, 112.06825466392226, 114.93439490201838, 117.81490256811118, 120.7095658303056, 123.61818000423646, 126.54054718123301, 129.47647588237393, 132.42578073619038, 135.38828217800574, 138.3638061691055, 141.35218393410744, 144.3532517150656, 147.36685054097742, 150.39282601149415, 153.43102809374236, 156.48131093126642, 159.54353266419022, 162.61755525977648, 165.70324435263322, 168.80046909388332, 171.909102008668, 175.02901886141092, 178.16009852831414, 181.30222287660166, 184.4552766500645, 187.61914736049633, 190.79372518464083, 193.97890286630147, 197.1745756232895, 200.3806410589125, 203.596999077725, 206.82355180528617, 210.06020351168408, 213.30686053860765, 216.56343122975827, 219.82982586441153, 223.1059565939491, 226.39173738119527, 229.68708394240326, 232.99191369174542, 236.30614568817313, 239.6297005845188, 242.9625005787218, 246.3044693670676, 249.65553209933523, 253.01561533575654, 256.38464700569455, 259.7625563679553, 263.1492739726521, 266.54473162454656, 269.94886234779386, 273.36160035202545, 276.7828809997056], [0.0, 0.8766033717827671, 2.0849259335188846, 3.461024751809497, 4.958817508788697, 6.554138918048868, 8.231750520104763, 9.981037489129697, 11.794122126903176, 13.66489420212549, 15.588457268119903, 17.56078772798846, 19.578512574871873, 21.638757862351145, 23.73904159436387, 25.87719572197405, 28.051307897048567, 30.259677040912617, 32.50077882185413, 34.77323839793487, 37.075808590328144, 39.407352185244584, 41.76682742235269, 44.153275976001964, 46.56581291041575, 49.003618215294736, 51.465929619458116, 53.952036447487636, 56.46127433472611, 58.993020654140295, 61.54669053777904, 64.12173339816387, 66.71762987260435, 69.33388912734196, 71.97004646947555, 74.62566122346705, 77.30031483615738, 79.99360918000907, 82.70516502901995, 85.43462068563534, 88.18163074019449, 90.94586494711241, 93.72700720422179, 96.52475462356604, 99.33881668350519, 102.1689144533264, 105.01477988268053, 107.87615514912805, 110.75279205790397, 113.64445148871704, 116.55090288501091, 119.47192378164084, 122.40729936737776, 125.35682207904978, 128.32029122447688, 131.29751263166057, 134.28829832195365, 137.29246620517156, 140.30983979481226, 143.3402479417329, 146.383524584795, 149.43950851713015, 152.5080431668082, 155.5889763908011, 158.6821602812384, 161.7874509830395, 164.90470852208978, 168.03379664319988, 171.17458265715362, 174.3269372962074, 177.4907345774594, 180.6658516735521, 183.85216879021755, 187.0495690502126, 190.25793838322758, 193.47716542138446, 196.70714139996954, 199.94776006307305, 203.19891757383243, 206.46051242899847, 209.73244537756392, 213.0146193432126, 216.30693935036533, 219.60931245361297, 222.9216476703437, 226.24385591638222, 229.5758499444731, 232.9175442854511, 236.26885519195076, 239.6297005845188, 243.00000000000023, 246.37967454207848, 249.76864683385665, 253.16684097237422, 256.57418248496106, 259.99059828733436, 263.4160166433526, 266.85036712634314, 270.2935805819278, 273.7455890922725, 277.20632594169234, 280.6757255835495], [0.0, 0.8887952816556649, 2.1139233454515285, 3.5091611190654364, 5.027785365962627, 6.645294705894852, 8.346238740967056, 10.11985501302081, 11.958156259818633, 13.854947268195927, 15.805263491080147, 17.805025370881967, 19.850812988538756, 21.939712426423505, 24.06920716856061, 26.23709901251698, 28.441449012981295, 30.680532432462748, 32.95280373865222, 35.256868968137006, 37.59146359617052, 39.9554345924511, 42.3477257077136, 44.767365287793936, 47.21345608911744, 49.68516669657849, 52.181724237232906, 54.70240815149937, 57.246544834653555, 59.81350300008718, 62.402689645432126, 65.01354652557005, 67.64554705444895, 70.29819357173272, 72.97101492151289, 75.66356429928067, 78.37541733058698, 81.10617035068657, 83.85543885925435, 86.62285612820058, 89.40807194386353, 92.21075146756114, 95.03057420073739, 97.86723304283194, 100.72043343159334, 103.58989255690531, 106.4753386403408, 109.37651027363336, 112.29315581009404, 115.22503280371647, 118.1719074913348, 121.13355431373105, 124.10975547205463, 127.1003005163189, 130.10498596309182, 133.12361493980634, 136.15599685338458, 139.20194708110884, 142.2612866818806, 145.33384212619322, 148.41944504330905, 151.5179319842743, 154.6291441995367, 157.75292743004388, 160.88913171080415, 164.03761118598234, 167.19822393468624, 170.37083180667221, 173.55530026726575, 176.75149825085126, 179.9592980223409, 183.1785750460788, 186.40920786168329, 189.65107796636778, 192.90406970331847, 196.16807015573883, 199.44296904620188, 202.7286586409773, 206.0250336590264, 209.33199118538002, 212.6494305886354, 215.97725344232677, 219.31536344994265, 222.6636663733775, 226.0220699646219, 229.39048390050655, 232.76881972033033, 236.1569907662121, 239.55491212601746, 242.9625005787218, 246.37967454207848, 249.806354022471, 253.24246056683492, 256.68791721654173, 260.14264846314603, 263.6065802058998, 267.07963971094597, 270.5617555721091, 274.0528576732032, 277.5528771517843, 281.06174636427744, 284.57939885241393], [0.0, 0.9010207324287148, 2.1430005315383815, 3.557429913242559, 5.096942959120114, 6.736701270461652, 8.461041927903128, 10.259054434806242, 12.122641663497328, 14.045523185155117, 16.022666164961738, 18.049934930684234, 20.123862521997488, 22.241494940102537, 24.40028105414361, 26.59799242523587, 28.832663437718892, 31.102545630198588, 33.4060722114443, 35.74183004396416, 38.108537209371725, 40.505024817340555, 42.930222089811686, 45.38314400743964, 47.86288098499203, 50.36859017118142, 52.899488062133926, 55.45484418691312, 58.03397567530735, 60.63624255731014, 63.26104367375797, 65.90781310082588, 68.57601700922825, 71.26515089327091, 73.97473711625791, 76.70432272784838, 79.4534775162885, 82.22179226439185, 85.00887718300041, 87.81436049964995, 90.63788718346161, 93.47911779002024, 96.33772741228637, 99.21340472550665, 102.1058511157021, 105.01477988268053, 107.93991550968067, 110.8809929927443, 113.83775722376195, 116.80996242186295, 119.79737160845016, 122.79975612172042, 125.81689516698236, 128.84857539949283, 131.89459053688876, 134.95474099860508, 138.02883356994073, 141.11668108867764, 144.21810215236806, 147.33292084459302, 150.46096647866173, 153.60207335736692, 156.75608054754338, 159.9228316682931, 163.10217469184374, 166.29396175610142, 169.49804898804064, 172.71429633714996, 175.9425674182196, 179.18272936281588, 182.43465267884446, 185.69821111765154, 188.97328154815804, 192.2597438375621, 195.557480738181, 198.86637778003865, 202.18632316883313, 205.51720768894793, 208.85892461119528, 212.21136960500223, 215.574440654773, 218.94803798017787, 222.3320639601391, 225.7264230602983, 229.13102176376728, 232.54576850497435, 235.97057360643421, 239.4053492182796, 242.85000926040294, 246.3044693670676, 249.76864683385665, 253.24246056683492, 256.7258310338097, 260.21868021758036, 263.7209315710768, 267.2325099742891, 270.7533416929003, 274.28335433853715, 277.8224768305599, 281.370639359316, 284.9277733507878, 288.4938114325678], [0.0, 0.9132794502879614, 2.1721568405364353, 3.605830053262572, 5.1662887393355215, 6.828356564512449, 8.576157509660986, 10.398632636830458, 12.287574653952483, 14.236617684665923, 16.240660420587485, 18.295510922145148, 20.397655059745727, 22.544098644352097, 24.73225583603658, 26.95986787718519, 29.224942409214783, 31.5257071822721, 33.860574088356564, 36.228110763721915, 38.62701784901145, 41.05611055071667, 43.514303522450014, 46.00059834331618, 48.514073052841745, 51.05387333243807, 53.619205018373435, 56.20932770138612, 58.82354922056455, 61.46122089887535, 64.12173339816387, 66.80451309500376, 69.50901889716597, 72.23473943497116, 74.98119057330074, 77.74791319925818, 80.53447124790081, 83.34044993449216, 86.16545416664955, 89.00910711380796, 91.87104891476305, 94.75093550683377, 97.6484375625011, 100.56323952132414, 103.49503870657107, 106.44354451738833, 109.40847768850799, 112.38956961049566, 115.38656170440238, 118.39920484541851, 121.4272588307661, 124.4704918876142, 127.5286802172786, 130.6016075723826, 133.68906486401588, 136.79084979624642, 139.9067665256163, 143.0366253434967, 146.18024237939304, 149.33743932347883, 152.5080431668082, 155.69188595780253, 158.88880457374188, 162.09864050610858, 165.32123965873677, 168.55645215781445, 171.80413217287074, 175.0641377479556, 178.33633064228846, 181.62057617971172, 184.91674310634363, 188.22470345587107, 191.54433242197146, 194.875508237392, 198.2181120592523, 201.5720278601701, 204.93714232484103, 208.31334475173003, 211.7005269595595, 215.09858319830082, 218.5074100643985, 221.9269064199748, 225.3569733157814, 228.79751391767994, 232.24843343645057, 235.70963906073837, 239.181039892963, 242.66254688802746, 246.15407279467266, 249.65553209933523, 253.16684097237422, 256.68791721654173, 260.21868021758036, 263.75905089683687, 267.30895166579006, 270.8683063823948, 274.4370403091517, 278.015080072817, 281.6023536256727, 285.19879020828057, 288.8043203136481, 292.41887565274135], [0.0, 0.9255711665791095, 2.2013916334744916, 3.654360478418667, 5.235821186870657, 6.920258579387876, 8.691582963440453, 10.538586560186, 12.452951616617156, 14.428226578822338, 16.45924148053337, 18.541747963376835, 20.67218460151965, 22.84751690750108, 25.06512423889049, 27.322717437731754, 29.618277330531523, 31.950007814942765, 34.31629940881379, 36.71570047039007, 39.14689415239642, 41.60867971533359, 44.099957205269895, 46.619714763685444, 49.16701802155372, 51.74100116211679, 54.34085933309051, 56.965842160135594, 59.61524816663148, 62.28841994508005, 64.98473995631905, 67.70362685659465, 70.44453227118379, 73.20693794794518, 75.99035323584496, 78.79431284284237, 81.61837483505006, 84.46211884519458, 87.32514446339327, 90.20706978736465, 93.1075301125765, 96.02617674565028, 98.96267592668822, 101.91670784816006, 104.88796575964496, 107.87615514912804, 110.8809929927443, 113.90220706587787, 116.93953530939741, 119.99272524555292, 123.06153343870672, 126.14572499662569, 129.24507310854653, 132.35935861664558, 135.48836961791048, 138.63190109373303, 141.78975456482218, 144.96173776928396, 148.14766436193324, 151.34735363309343, 154.5606302453125, 157.78732398657203, 161.02726953870337, 164.2803062598422, 167.54627797986112, 170.82503280781492, 174.11642295051826, 177.42030454145333, 180.7365374792738, 184.06498527523223, 187.4055149089169, 190.75799669173176, 194.1223041376012, 197.4983138404219, 200.88590535782166, 204.2849611008199, 207.69536622901552, 211.11700855095495, 214.54977842936208, 217.99356869093157, 221.44827454041217, 224.91379347872382, 228.39002522487235, 231.8768716414406, 235.37423666345228, 238.88202623041573, 242.40014822137124, 245.92851239277476, 249.46703031906318, 253.01561533575654, 256.57418248496106, 260.14264846314603, 263.7209315710768, 267.30895166579006, 270.9066301145104, 274.513889750406, 278.1306548300947, 281.7568509928113, 285.3924052211564, 289.03724580334904, 292.69130229691064, 296.3545054937136], [0.0, 0.9378956176563621, 2.230704283293635, 3.703020147778696, 5.305538810319675, 7.012405343875826, 8.807315813473707, 10.67891320299235, 12.61876900431046, 14.620345757793123, 16.678404656440474, 18.788640772825488, 20.947445258917828, 23.151743221512053, 25.398879122990007, 27.686533324092494, 30.012659765003605, 32.37543842735958, 34.77323839793487, 37.20458870562628, 39.668154968667054, 42.1627204591005, 44.687170576548596, 47.240479989080356, 49.821701886070194, 52.42995892196947, 55.06443552747631, 57.72437133663525, 60.40905553230758, 63.1178219532798, 65.85004483754147, 68.60513510045085, 71.38253706539636, 74.18172557944578, 77.00220345829705, 79.84349921430908, 82.70516502901994, 85.58677493775201, 88.48792319896131, 91.40822282514313, 94.34730425553883, 97.30481415374008, 100.28041431566623, 103.27378067538704, 106.2846023979437, 109.31258104974397, 112.35742983831608, 115.4188729142349, 118.49664472891835, 121.59048944274674, 124.700160378613, 127.8254195165744, 130.9660370257669, 134.1217908301689, 137.29246620517156, 140.47785540223967, 143.67775729922934, 146.8919770741817, 150.1203259006306, 153.36262066265823, 156.61868368810508, 159.88834249849313, 163.17142957435817, 166.46778213480772, 169.77724193022968, 173.09965504717357, 176.43487172451262, 179.78274618007313, 183.14313644698802, 186.51590421909273, 189.9009147047411, 193.29803648846737, 196.70714139996952, 200.12810438992915, 203.56080341222258, 207.00511931211216, 210.4609357200383, 213.92813895066126, 217.40661790682873, 220.89626398816827, 224.3969710040266, 227.90863509049618, 231.4311546312904, 234.9644301822425, 238.50836439922205, 242.06286196927417, 245.6278295448016, 249.20317568062168, 252.78881077373984, 256.38464700569455, 259.99059828733436, 263.6065802058998, 267.2325099742891, 270.8683063823948, 274.513889750406, 278.1691818839753, 281.8341060311588, 285.5085868410399, 289.1925503239554, 292.8859238132454, 296.58863592845404, 300.300616539912], [0.0, 0.9502525447372352, 2.260094174501923, 3.751808039611954, 5.3754401457877785, 7.104794923125942, 8.923353629661895, 10.819609618742849, 12.785023335284183, 14.812971187558588, 16.898145346433164, 19.0361841663629, 21.223431252158566, 23.456771198397366, 25.73351348032175, 28.051307897048567, 30.408081431591544, 32.801990086549395, 35.23138146114996, 37.69476520400687, 40.190789352656886, 42.718221148554875, 45.27593130628182, 47.862880984992024, 50.47811089967616, 53.12073214561548, 55.78991840825012, 58.48489930367965, 61.20495464963413, 63.94940950811789, 66.71762987260436, 69.50901889716599, 72.3230135840616, 75.15908186138377, 78.01671999434654, 80.89545028338259, 83.79481900994901, 86.71439459721437, 89.65376595792397, 92.61254100594984, 95.59034531151038, 98.58682088293266, 101.60162506024234, 104.63442950788794, 107.68491929560957, 110.75279205790397, 113.83775722376195, 116.93953530939741, 120.0578572675826, 123.19246388796928, 126.34310524343941, 129.50954017809886, 132.69153583302466, 135.88886720630754, 139.10131674430707, 142.32867396136734, 145.5707350855276, 148.82730272801794, 152.09818557455296, 155.38319809663278, 158.68216028123842, 161.99489737745986, 165.3212396587368, 168.661022199512, 172.01408466520903, 175.38027111454272, 178.75942981325912, 182.15141305848076, 185.55607701290396, 188.97328154815804, 192.40289009669496, 195.8447695116289, 199.29878993399328, 202.76482466692462, 206.2427500563217, 209.73244537756395, 213.23379272790385, 216.74667692417887, 220.27098540551367, 223.80660814070828, 227.35343754003028, 230.91136837114834, 234.48029767896475, 238.06012470911966, 241.65075083495796, 245.25207948776108, 248.86401609006205, 252.486467991873, 256.1193444096655, 259.7625563679553, 263.4160166433526, 267.07963971094597, 270.7533416929003, 274.4370403091517, 278.1306548300947, 281.8341060311588, 285.5473161491808, 289.27020884048346, 293.00270914057774, 296.7447434254088, 300.4962393740715, 304.25712593292695], [0.0, 0.9626416937630512, 2.289560702842582, 3.8007231508383708, 5.445523756102061, 7.197425417606552, 9.039694026265103, 10.96067291471626, 12.951711191345828, 15.00609890773589, 17.118459032638288, 19.284373054491756, 21.500136906964112, 23.76259456677548, 26.069020430796385, 28.41703365682718, 30.804534200417656, 33.22965402260123, 35.690719179028164, 38.186219887492854, 40.71478655899211, 43.27517036259098, 45.86622728953671, 48.48690495484304, 51.13623156658864, 53.81330663074298, 56.51729305946881, 59.24741042479797, 62.002929154908735, 64.78316551213689, 67.58747722394136, 70.41525966287041, 73.26594249096267, 76.13898669929365, 79.03388198551237, 81.95014442192705, 84.88731437452876, 87.84495463969799, 90.82264877052984, 93.81999956897793, 96.83662772354116, 99.87217057514297, 102.92628099629617, 105.99862637069448, 109.08888766209807, 112.19675856283978, 115.3219447135201, 118.46416298651499, 121.62314082682794, 124.79861564459262, 127.99033425420534, 131.19805235564326, 134.42153405402846, 137.66055141393446, 140.9148840453123, 144.18431871824802, 147.46864900405427, 150.76767494045703, 154.0812027188642, 157.40904439190305, 160.75101759959088, 164.10694531266017, 167.47665559169923, 170.85998136089367, 174.25676019526603, 177.6668341204086, 181.09004942379516, 184.52625647683593, 187.97530956691344, 191.43706673869917, 194.9113896441124, 198.39814340033246, 201.89719645532475, 205.40842046038458, 208.93169014924032, 212.4668832232947, 216.01388024261445, 219.57256452230845, 223.1428220339616, 226.7245413118153, 230.3176133634098, 233.92193158442163, 237.5373916774509, 241.16389157452824, 244.80133136312952, 248.449613215498, 252.1086413210899, 255.7783218219706, 259.4585627509992, 263.1492739726521, 266.85036712634314, 270.5617555721091, 274.28335433853715, 278.015080072817, 281.7568509928113, 285.5085868410399, 289.27020884048346, 293.0416396521154, 296.82280333407897, 300.61362530242764, 304.414032293355, 308.22395232684295], [0.0, 0.9750628152648345, 2.3191032749750504, 3.849764496499038, 5.515788230052885, 7.290294962102013, 9.156334660643049, 11.102100250449869, 13.118829216054314, 15.199725029488564, 17.33934127880042, 19.53320243965915, 21.777556651565483, 24.06920716856061, 26.405393218616958, 28.783703239142817, 31.202010088474722, 33.65842162403711, 36.15124230230549, 38.67894286011023, 41.240136036419685, 43.8335568864313, 46.45804664006235, 49.11253933323282, 51.79605063483302, 54.507668431612274, 57.24654483465356, 60.01188934600039, 62.80296298004778, 65.61907317675386, 68.45956937623103, 71.32383914942173, 74.21130479920166, 77.1214203617269, 80.05366895013276, 83.00756039253012, 85.9826291241781, 88.97843230014817, 91.9945481000536, 95.03057420073742, 98.08612639638082, 101.16083734845856, 104.25435545044127, 107.36634379422071, 110.49647922698082, 113.64445148871705, 116.80996242186295, 119.99272524555293, 123.1924638879693, 126.40891237100617, 129.64181424216508, 132.89092204918043, 136.15599685338458, 139.43680777826336, 142.73313159003933, 146.04475230745845, 149.37146083825067, 152.71305463999633, 156.0693374033598, 159.44011875585295, 162.8252139844727, 166.2244437757143, 169.63763397160395, 173.06461534052107, 176.5052233616924, 179.95929802234093, 183.42668362656278, 186.90722861508635, 190.40078539514062, 193.90721017972456, 197.4263628356298, 200.95810673962072, 204.5023086422256, 208.05883853863565, 211.6275695462483, 215.2083777884276, 218.8011422840876, 222.40574484273313, 226.02206996462195, 229.6500047457348, 233.2894387872646, 236.94026410935498, 240.6023750688399, 244.2756682807504, 247.96004254337495, 251.6553987666694, 255.36163990383108, 259.0786708858612, 262.80639855895197, 266.54473162454656, 270.2935805819278, 274.0528576732032, 277.8224768305599, 281.6023536256727, 285.3924052211564, 289.1925503239554, 293.00270914057774, 296.82280333407897, 300.6527559827121, 304.49249154016206, 308.34193579728765, 312.2010158453009], [0.0, 0.9875156642343444, 2.3487213081682414, 3.898931109247021, 5.586232181664344, 7.383401724748457, 9.27327323204402, 11.24388883627104, 13.286374112984824, 15.393845733516121, 17.56078772798846, 19.782667413673025, 22.055685013822057, 24.376602955779223, 26.74262520878638, 29.151309411390177, 31.600501255499044, 34.0882844333602, 36.61294174710331, 39.17292440283416, 41.76682742235269, 44.39336970582889, 47.05137768414489, 49.73977177944168, 52.457555089392166, 55.20380385184633, 57.97765934921804, 60.778320987840516, 63.60504034427979, 66.45711601358114, 69.33388912734198, 72.23473943497116, 75.15908186138377, 78.1063634700515, 81.07606077277691, 84.06767733752396, 87.08074165367084, 90.11480522057029, 93.16944083062823, 96.2442410224859, 99.33881668350519, 102.45279578375933, 105.58582222623595, 108.73755480006218, 111.90766622533073, 115.09584227960411, 118.30178099744724, 121.52519193542146, 124.76579549590474, 128.02332230389712, 131.2975126316606, 134.58811586663506, 137.89489001858826, 141.2176012624059, 144.55602351331834, 147.9099380317036, 151.27913305490532, 154.66340345376776, 158.06255041182396, 161.47638112527588, 164.9047085220898, 168.347350998689, 171.80413217287074, 175.27488065170155, 178.7594298132591, 182.2576176011904, 185.76928633114778, 189.2942825082462, 192.8324566547587, 196.3836631473329, 199.94776006307305, 203.5246090338831, 207.1140751085184, 210.7160266218358, 214.33033507077312, 217.95687499662506, 221.59552387321625, 225.24616200060177, 228.90867240395403, 232.58294073731923, 236.2688551919508, 239.9663064089459, 243.6751873959348, 247.395393447585, 251.1268220697045, 254.86937290673748, 258.62294767246453, 262.3874500837293, 266.162785797026, 269.94886234779386, 273.7455890922725, 277.5528771517843, 281.370639359316, 285.19879020828057, 289.03724580334904, 292.8859238132454, 296.7447434254088, 300.61362530242764, 304.49249154016206, 308.38126562747004, 312.27987240746086, 316.1882380402045], [0.0, 1.0, 2.3784142300054425, 3.9482220388574785, 5.656854249492382, 7.476743906106105, 9.390507480439728, 11.386035931884505, 13.45434264405944, 15.588457268119903, 17.782794100389236, 20.032763155216603, 22.334516618450404, 24.684775987507255, 27.08070988374739, 29.51984506898147, 32.00000000000002, 34.51923414277184, 37.07580859032814, 39.66815496866706, 42.29485053762259, 44.95459800148955, 47.646208954695894, 50.36859017118141, 53.12073214561548, 55.90169943749478, 58.71062247318391, 61.54669053777904, 64.40914574615381, 67.29727782607648, 70.21041957962153, 73.14794291488762, 76.1092553601742, 79.09379698863826, 82.10103769405828, 85.13047476842262, 88.18163074019448, 91.2540514387075, 94.34730425553883, 97.46097657813603, 100.59467437463492, 103.74802091184505, 106.92065559091697, 110.11223288733372, 113.32242138366145, 116.5509028850109, 119.79737160845013, 123.06153343870672, 126.3431052434394, 129.64181424216505, 132.95739742362483, 136.28960100697333, 139.63817994269792, 143.00289744962868, 146.383524584795, 149.77983984323265, 153.19162878514675, 156.61868368810505, 160.06080322217005, 163.5177921460863, 166.9894610228246, 170.47562595294588, 173.97610832439452, 177.4907345774594, 181.01933598375632, 184.56174843818917, 188.11781226293886, 191.68737202261264, 195.27027634976145, 198.8663777800386, 202.47553259633563, 206.09760068128426, 209.7324453775639, 213.37993335549902, 217.03993448747056, 220.71232172870359, 224.3969710040266, 228.09376110022822, 231.80257356366587, 235.5232926028054, 239.2558049953955, 243.0000000000002, 246.7557692716345, 250.5230067812639, 254.30160873894786, 258.0914735204192, 261.8925015969078, 265.7045954680298, 269.52765959757346, 273.36160035202545, 277.20632594169234, 281.06174636427744, 284.9277733507878, 288.8043203136481, 292.69130229691064, 296.58863592845404, 300.4962393740715, 304.414032293355, 308.34193579728765, 312.27987240746086, 316.2277660168382, 320.1855418519931], [0.0, 1.0125155861074646, 2.4081814781002944, 3.997636351756189, 5.7276530959492815, 7.570319738266437, 9.508035185403962, 11.528538845012692, 13.622731627940498, 15.78355594734159, 18.00535619118397, 20.28348492745616, 22.61404618435722, 24.993720426922376, 27.419640840148695, 29.889303231821323, 32.40049875543889, 34.95126259004944, 37.53983406524427, 40.16462517790166, 42.82419538142855, 45.51723114370365, 48.24252918556264, 50.998982598580426, 53.78556924287549, 56.60134197035835, 59.44542032416989, 62.31698344283409, 65.21526395584804, 68.13954270150671, 71.0891441315115, 74.06343229302281, 77.06180729920948, 80.08370221541588, 83.12858030083045, 86.19593255575616, 89.28527553282002, 92.39614937714366, 95.5281160659562, 98.68075782261728, 101.85367568372303, 105.04648820104629, 108.25883026263166, 111.49035201952034, 114.74071790639506, 118.009605745971, 121.29670592826363, 124.60172065697549, 127.92436325619812, 131.2643575314408, 134.6214371797046, 137.9953452439281, 141.3858336076604, 144.79266252627644, 148.21560019145016, 151.65442232595288, 155.10891180615002, 158.5788583098413, 162.06405798732706, 165.56431315379314, 169.07943200129486, 172.6092283287839, 176.15352128877007, 179.71213514934075, 183.2848990703771, 186.87164689291157, 190.47221694066354, 194.08645183287524, 197.7141983076453, 201.35530705502427, 205.00963255919982, 208.67703294915273, 212.35736985721593, 216.05050828501484, 219.75631647630698, 223.4746657962776, 227.20543061688173, 230.9484882078536, 234.70371863303384, 238.47100465168938, 242.25023162452615, 246.0412874241141, 249.84406234946732, 253.65844904453576, 257.48434242038695, 261.3216395808664, 265.1702397515432, 269.030044211759, 272.9009562296103, 276.7828809997056, 280.6757255835495, 284.57939885241393, 288.4938114325678, 292.41887565274135, 296.3545054937136, 300.300616539912, 304.25712593292695, 308.22395232684295, 312.2010158453009, 316.1882380402045, 320.1855418519931, 324.19285157140695]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 2.6\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.00251188643150958, 0.006184989894219835, 0.010477499074303186, 0.015229231509727027, 0.02035452657684522, 0.025798628902309804, 0.03152299346982144, 0.037498766585473596, 0.043703403734718343, 0.05011872336272723, 0.0567297004945868, 0.0635236756900748, 0.07048981292767126, 0.07761871460455788, 0.08490213995805886, 0.09233279397806167, 0.09990416579859136, 0.10761040270431169, 0.11544621033669152, 0.12340677254400192, 0.13148768620913656, 0.13968490766928177, 0.14799470822753338, 0.15641363688193974, 0.16493848884661177, 0.17356627876726147, 0.18229421777608878, 0.1911196937128298, 0.20004025397681277, 0.20905359058078468, 0.21815752705936722, 0.22735000694923554, 0.23662908360881574, 0.24599291118564004, 0.2554397365718449, 0.26496789221442, 0.27457578966804486, 0.2842619137957198, 0.2940248175366855, 0.30386311717294956, 0.31377548803556854, 0.32376066060005576, 0.3338174169271837, 0.34394458741127343, 0.354141047802992, 0.3644057164778773, 0.37473755192538427, 0.3851355504363209, 0.39559874396917566, 0.40612619817811785, 0.4167170105874195, 0.42737030889876065, 0.4380852494193666, 0.44886101560022645, 0.45969681667478385, 0.4705918863894838, 0.4815454818184454, 0.49255688225530236, 0.5036253881759386, 0.514750320266457, 0.5259310185112551, 0.5371668413365648, 0.5484571648052401, 0.5598013818589584, 0.571198901604346, 0.5826491486398413, 0.5941515624203891, 0.6057055966573057, 0.6173107187508757, 0.6289664092534478, 0.6406721613609769, 0.6524274804311223, 0.6642318835261687, 0.6760848989791646, 0.6879860659818013, 0.6999349341926693, 0.7119310633646238, 0.7239740229900975, 0.7360633919632708, 0.7481987582580971, 0.7603797186212513, 0.7726058782791297, 0.7848768506580984, 0.7971922571172363, 0.8095517266928728, 0.8219548958542658, 0.8344014082698136, 0.846890914583223, 0.8594230721991122, 0.8719975450775371, 0.884614003536983, 0.8972721240653804, 0.9099715891387324, 0.9227120870469747, 0.9354933117266965, 0.9483149626003916, 0.9611767444219128, 0.9740783671278331, 0.9870195456944258, 1.0, 1.0130194546923375], [0.0, 0.006184989894219835, 0.015229231509727027, 0.0257986289023098, 0.03749876658547359, 0.05011872336272723, 0.0635236756900748, 0.07761871460455788, 0.09233279397806167, 0.10761040270431167, 0.12340677254400192, 0.13968490766928177, 0.15641363688193974, 0.17356627876726147, 0.19111969371282977, 0.20905359058078468, 0.22735000694923552, 0.24599291118564, 0.26496789221442, 0.2842619137957198, 0.30386311717294956, 0.32376066060005576, 0.34394458741127343, 0.36440571647787734, 0.3851355504363209, 0.4061261981781178, 0.42737030889876065, 0.44886101560022645, 0.47059188638948385, 0.4925568822553024, 0.514750320266457, 0.5371668413365648, 0.5598013818589584, 0.5826491486398412, 0.6057055966573058, 0.6289664092534478, 0.6524274804311223, 0.6760848989791645, 0.6999349341926693, 0.7239740229900975, 0.7481987582580971, 0.7726058782791297, 0.7971922571172363, 0.8219548958542658, 0.846890914583223, 0.8719975450775371, 0.8972721240653803, 0.9227120870469747, 0.9483149626003915, 0.974078367127833, 1.0000000000000002, 1.0260776390609918, 1.0523091364604007, 1.0786924147829349, 1.1052254634490883, 1.1319063353632046, 1.158733143787717, 1.18570405942453, 1.2128173076864104, 1.2400711661429435, 1.2674639621271098, 1.294994070489867, 1.3226599114912936, 1.3504599488179267, 1.3783926877168415, 1.4064566732378863, 1.4346504885762246, 1.4629727535080308, 1.4914221229127824, 1.519997285376151, 1.548696961867989, 1.577519904490359, 1.606464895290952, 1.6355307451376275, 1.664716292650121, 1.6940204031852832, 1.7234419678724928, 1.7529799026961241, 1.7826331476222053, 1.8124006657665803, 1.8422814426021197, 1.8722744852026658, 1.902378821521586, 1.9325934997029401, 1.9629175874234193, 1.9933501712633217, 2.023890356104964, 2.0545372645570232, 2.085290036403403, 2.116147828075323, 2.1471098121453833, 2.1781751768424735, 2.209343125586439, 2.240612876541492, 2.2719836621874223, 2.303454728907713, 2.335025336593731, 2.3666947582641846, 2.39846227969914, 2.4303271990878597, 2.4622888266898326, 2.494346484508369], [0.0, 0.010477499074303186, 0.0257986289023098, 0.04370340373471836, 0.0635236756900748, 0.08490213995805886, 0.10761040270431171, 0.1314876862091366, 0.15641363688193974, 0.18229421777608878, 0.2090535905807847, 0.23662908360881577, 0.2649678922144201, 0.2940248175366856, 0.3237606606000558, 0.35414104780299205, 0.385135550436321, 0.41671701058741956, 0.4488610156002265, 0.48154548181844553, 0.5147503202664571, 0.5484571648052401, 0.5826491486398413, 0.6173107187508758, 0.6524274804311224, 0.6879860659818015, 0.7239740229900976, 0.7603797186212514, 0.7971922571172365, 0.8344014082698136, 0.8719975450775372, 0.9099715891387326, 0.9483149626003917, 0.987019545694426, 1.0260776390609918, 1.0654819301935257, 1.1052254634490883, 1.1453016131561657, 1.1857040594245305, 1.2264267663213566, 1.26746396212711, 1.3088101214257313, 1.350459948817927, 1.392408364075161, 1.4346504885762248, 1.4771816328888268, 1.5199972853761512, 1.5630931017232506, 1.6064648952909522, 1.6501086282159543, 1.6940204031852837, 1.7381964558215048, 1.7826331476222053, 1.8273269594034942, 1.8722744852026663, 1.9174724265999525, 1.9629175874234195, 2.00860686880477, 2.0545372645570232, 2.1007058568479136, 2.1471098121453833, 2.1937463774137957, 2.2406128765414923, 2.2877067069821218, 2.3350253365937306, 2.3825663006610767, 2.43032719908786, 2.4783056937467585, 2.526499505976163, 2.574906414213444, 2.6235242517554345, 2.6723509046375677, 2.7213843096237826, 2.7706224522999707, 2.8200633652642684, 2.86970512640803, 2.9195458572817983, 2.9695837215409875, 3.019816923466419, 3.0702437065551784, 3.120862352177608, 3.1716711782965388, 3.2226685382451414, 3.273852819560033, 3.3252224428665045, 3.376775860812946, 3.4285115570517375, 3.4804280452640777, 3.5325238682263476, 3.5847975969158212, 3.6372478296536004, 3.689873191282863, 3.742672332380574, 3.7956439285009558, 3.848786679449114, 3.902099308583292, 3.9555805621443643, 4.009229208611191, 4.063044038080632, 4.117023861670976, 4.171167510947729, 4.225473837370663], [0.0, 0.015229231509727027, 0.03749876658547359, 0.0635236756900748, 0.09233279397806167, 0.12340677254400192, 0.15641363688193977, 0.1911196937128298, 0.22735000694923552, 0.26496789221442, 0.30386311717294956, 0.3439445874112734, 0.3851355504363209, 0.42737030889876065, 0.47059188638948385, 0.514750320266457, 0.5598013818589584, 0.6057055966573058, 0.6524274804311223, 0.6999349341926692, 0.7481987582580971, 0.7971922571172364, 0.846890914583223, 0.8972721240653804, 0.9483149626003915, 1.0, 1.0523091364604007, 1.1052254634490883, 1.1587331437877173, 1.2128173076864106, 1.26746396212711, 1.3226599114912936, 1.3783926877168418, 1.4346504885762246, 1.4914221229127826, 1.5486969618679893, 1.606464895290952, 1.6647162926501209, 1.7234419678724928, 1.7826331476222053, 1.8422814426021197, 1.902378821521586, 1.9629175874234193, 2.023890356104964, 2.0852900364034035, 2.1471098121453833, 2.209343125586439, 2.2719836621874223, 2.3350253365937306, 2.39846227969914, 2.462288826689833, 2.526499505976163, 2.591089028930071, 2.656052280355095, 2.721384309623782, 2.7870803224242535, 2.853135673063679, 2.919545857281798, 2.9863065055322933, 3.053413376694001, 3.1208623521776078, 3.188649430396785, 3.2567707215755752, 3.3252224428665045, 3.394000913756147, 3.463102551737, 3.5325238682263476, 3.602261464714483, 3.6723120291261746, 3.742672332380574, 3.8133392251360396, 3.8843096347074226, 3.955580562144363, 4.027149079460076, 4.0990123270009144, 4.171167510947728, 4.243611900940777, 4.316342827820497, 4.389357681477083, 4.462653908802265, 4.536229011737226, 4.610080545410983, 4.684206116363973, 4.75860338085195, 4.833270043225648, 4.9082038543819415, 4.983402610282559, 5.0588641505366505, 5.134586357043735, 5.210567152693826, 5.286804500121683, 5.363296400512373, 5.440040892455481, 5.517036050845481, 5.594279985825937, 5.67177084177532, 5.749506796332409, 5.8274860594592965, 5.905706872540217, 5.984167507514433, 6.062866266041593, 6.141801478698022], [0.0, 0.02035452657684522, 0.05011872336272723, 0.08490213995805886, 0.12340677254400192, 0.16493848884661177, 0.2090535905807847, 0.2554397365718449, 0.30386311717294956, 0.35414104780299194, 0.40612619817811774, 0.45969681667478385, 0.514750320266457, 0.5711989016043459, 0.6289664092534479, 0.6879860659818012, 0.7481987582580971, 0.8095517266928727, 0.8719975450775371, 0.9354933117266964, 1.0, 1.0654819301935257, 1.1319063353632046, 1.1992430008228632, 1.26746396212711, 1.336543249988985, 1.4064566732378863, 1.4771816328888265, 1.5486969618679893, 1.6209827860580859, 1.6940204031852832, 1.7677921767347164, 1.8422814426021197, 1.917472426599952, 1.9933501712633217, 2.0699004706631094, 2.1471098121453833, 2.2249653240882066, 2.303454728907713, 2.382566300661076, 2.4622888266898326, 2.5426115728266754, 2.6235242517554345, 2.7050169941698923, 2.7870803224242535, 2.8697051264080295, 2.9528826414121214, 3.036604427781853, 3.120862352177608, 3.2056485702850783, 3.290955510835594, 3.3767758608129457, 3.4631025517369998, 3.549928746926453, 3.6372478296536, 3.7250533921132596, 3.8133392251360396, 3.902099308583291, 3.99132780236738, 4.08101903804644, 4.171167510947728, 4.261767872778044, 4.3528149246835905, 4.444303610725109, 4.536229011737225, 4.628586339543717, 4.721370931502903, 4.814578245359576, 4.908203854381941, 5.0022434427637865, 5.0966928012738, 5.1915478231353855, 5.286804500121683, 5.38245891885172, 5.478507257274714, 5.574945781330542, 5.671770841775319, 5.768978871161853, 5.866566380965496, 5.964529958846626, 6.062866266041593, 6.161572034874586, 6.260644066383385, 6.360079228052437, 6.4598744516472095, 6.560026731144102, 6.660533120750642, 6.76139073301102, 6.862596736992335, 6.964148356547257, 7.066042868649025, 7.1682776017950305, 7.270849934475427, 7.373757293703414, 7.47699715360413, 7.580567034059147, 7.684464499403875, 7.788687157175231, 7.893232656907186, 7.998098688971823, 8.103282983463812, 8.208783309126208], [0.0, 0.025798628902309804, 0.0635236756900748, 0.10761040270431171, 0.15641363688193977, 0.2090535905807847, 0.26496789221442013, 0.3237606606000558, 0.385135550436321, 0.4488610156002265, 0.5147503202664571, 0.5826491486398413, 0.6524274804311224, 0.7239740229900977, 0.7971922571172365, 0.8719975450775372, 0.9483149626003916, 1.0260776390609918, 1.1052254634490886, 1.1857040594245305, 1.2674639621271102, 1.350459948817927, 1.434650488576225, 1.5199972853761514, 1.6064648952909524, 1.6940204031852837, 1.7826331476222055, 1.8722744852026665, 1.96291758742342, 2.0545372645570232, 2.1471098121453838, 2.2406128765414923, 2.335025336593731, 2.4303271990878597, 2.5264995059761635, 2.623524251755435, 2.7213843096237826, 2.8200633652642684, 2.9195458572817987, 3.019816923466419, 3.1208623521776087, 3.2226685382451414, 3.325222442866505, 3.428511557051738, 3.532523868226348, 3.637247829653601, 3.7426723323805744, 3.848786679449114, 3.955580562144364, 4.063044038080632, 4.17116751094773, 4.279941711761159, 4.389357681477083, 4.499406754848329, 4.610080545410984, 4.7213709315029035, 4.8332700432256495, 4.945770250270436, 5.0588641505366505, 5.172544559478509, 5.286804500121684, 5.401637193697287, 5.5170360508454825, 5.632994663345469, 5.749506796332408, 5.866566380965497, 5.984167507514434, 6.102304418834438, 6.220971504202489, 6.340163293489745, 6.45987445164721, 6.58009977348355, 6.700834178715664, 6.822072707274202, 6.943810514847537, 7.066042868649027, 7.188765143393561, 7.311972817470385, 7.435661469300229, 7.559826773865594, 7.684464499403875, 7.809570504253744, 7.935140733845868, 8.061171217829674, 8.187658067328465, 8.31459747231566, 8.441985699105455, 8.569819087951673, 8.698094050748884, 8.826807068830389, 8.955954690857904, 9.085533530798148, 9.215540265981863, 9.345971635241007, 9.476824437120216, 9.608095528158762, 9.739781821239555, 9.871880284001858, 10.004387937314679, 10.137301853807873, 10.270619156458233, 10.404337017227993], [0.0, 0.03152299346982144, 0.07761871460455788, 0.1314876862091366, 0.1911196937128298, 0.2554397365718449, 0.3237606606000558, 0.39559874396917577, 0.47059188638948385, 0.5484571648052401, 0.6289664092534479, 0.7119310633646239, 0.7971922571172365, 0.8846140035369833, 0.9740783671278332, 1.0654819301935257, 1.1587331437877173, 1.253750299604237, 1.350459948817927, 1.4487956497189587, 1.5486969618679893, 1.6501086282159543, 1.7529799026961246, 1.857263991915819, 1.9629175874234197, 2.06990047066311, 2.178175176842474, 2.2877067069821213, 2.3984622796991406, 2.510411116008467, 2.6235242517554345, 2.7377743733230555, 2.85313567306368, 2.9695837215409875, 3.0870953541745427, 3.205648570285079, 3.3252224428665045, 3.4457970376770324, 3.567353340459829, 3.6898731912828633, 3.81333922513604, 3.937734818047063, 4.063044038080632, 4.189251600672193, 4.316342827820498, 4.44430361072511, 4.573120375507677, 4.702780051700641, 4.833270043225649, 4.964578201616965, 5.096692801273802, 5.229602516550174, 5.3632964005123736, 5.497763865212836, 5.632994663345468, 5.7689788711618535, 5.905706872540217, 6.043169344110126, 6.181357241345601, 6.320261785547947, 6.45987445164721, 6.600186956757962, 6.741191249431118, 6.882879499548913, 7.025244088814873, 7.168277601795033, 7.3119728174703855, 7.4563227012640905, 7.601320397510068, 7.7469592223323485, 7.893232656907187, 8.040134341082146, 8.187658067328465, 8.335797775004922, 8.484547544913081, 8.633901594125375, 8.783854271068886, 8.934400050848984, 9.08553353079815, 9.237249426236374, 9.389542566430537, 9.542407890741037, 9.695840444944805, 9.849835377724517, 10.004387937314677, 10.15949346829567, 10.315147408527638, 10.471345286216547, 10.628082717105206, 10.785355401782688, 10.943159123105717, 11.101489743726322, 11.260343203720163, 11.419715518310404, 11.579602775682321, 11.740001134884036, 11.900906823809201, 12.06231613725751, 12.224225435069357, 12.386631140331012, 12.549529737646983, 12.712917771476418], [0.0, 0.037498766585473596, 0.09233279397806167, 0.15641363688193974, 0.22735000694923552, 0.30386311717294956, 0.385135550436321, 0.47059188638948385, 0.5598013818589584, 0.6524274804311223, 0.7481987582580971, 0.846890914583223, 0.9483149626003915, 1.0523091364604007, 1.1587331437877173, 1.26746396212711, 1.3783926877168418, 1.4914221229127824, 1.606464895290952, 1.7234419678724928, 1.8422814426021197, 1.9629175874234195, 2.0852900364034035, 2.2093431255864395, 2.3350253365937306, 2.462288826689833, 2.591089028930071, 2.721384309623782, 2.8531356730636794, 2.9863065055322937, 3.1208623521776078, 3.256770721575575, 3.3940009137561473, 3.532523868226347, 3.6723120291261746, 3.81333922513604, 3.955580562144363, 4.0990123270009144, 4.243611900940777, 4.389357681477083, 4.536229011737226, 4.684206116363972, 4.833270043225649, 4.9834026102825595, 5.134586357043735, 5.286804500121683, 5.440040892455481, 5.594279985825937, 5.749506796332408, 5.905706872540217, 6.062866266041594, 6.220971504202488, 6.380009564893122, 6.539967853022401, 6.700834178715663, 6.8625967369923355, 7.025244088814873, 7.18876514339356, 7.353149141643325, 7.518385640698911, 7.684464499403873, 7.851375864696903, 8.019110158826123, 8.187658067328465, 8.357010527716843, 8.527158718823063, 8.698094050748882, 8.869808155381822, 9.042292877436047, 9.215540265981863, 9.389542566430535, 9.564292212943753, 9.739781821239552, 9.916004181768793, 10.092952253238243, 10.270619156458233, 10.448998168494475, 10.628082717105205, 10.80786637544621, 10.988342857027524, 11.169506010906833, 11.351349817105632, 11.533868382235184, 11.71705593532022, 11.900906823809198, 12.085415509760624, 12.270576566195691, 12.456384673608147, 12.642834616622839, 12.829921280795062, 13.017639649543145, 13.205984801207412, 13.394951906228917, 13.584536224441829, 13.77473310247376, 13.965537971248557, 14.156946343586547, 14.348953811897388, 14.541556045961133, 14.734748790793134, 14.92852786458892, 15.12288915674523], [0.0, 0.043703403734718343, 0.10761040270431167, 0.18229421777608878, 0.26496789221442, 0.35414104780299194, 0.4488610156002265, 0.5484571648052401, 0.6524274804311223, 0.7603797186212512, 0.871997545077537, 0.9870195456944257, 1.1052254634490883, 1.2264267663213564, 1.3504599488179267, 1.4771816328888265, 1.6064648952909517, 1.7381964558215044, 1.872274485202666, 2.0086068688047694, 2.147109812145383, 2.287706706982121, 2.430327199087859, 2.5749064142134435, 2.721384309623782, 2.8697051264080295, 3.0198169234664185, 3.1716711782965388, 3.325222442866504, 3.480428045264077, 3.6372478296535995, 3.7956439285009553, 3.955580562144363, 4.117023861670975, 4.279941711761158, 4.444303610725109, 4.610080545410983, 4.777244879033021, 4.945770250270435, 5.115631482236323, 5.286804500121683, 5.459266256490561, 5.6329946633454675, 5.807968530202187, 5.9841675075144325, 6.161572034874587, 6.340163293489743, 6.519923162494534, 6.700834178715662, 6.882879499548911, 7.066042868649025, 7.250308584167148, 7.435661469300227, 7.622086844942752, 7.809570504253743, 7.998098688971822, 8.187658067328464, 8.3782357134249, 8.56981908795167, 8.762396020141624, 8.9559546908579, 9.150483616727696, 9.345971635241005, 9.542407890741039, 9.73978182123955, 9.938083145996398, 10.137301853807871, 10.337428191953247, 10.538452655753256, 10.740365978698028, 10.943159123105715, 11.146823271275991, 11.351349817105632, 11.556730358135958, 11.76295668800423, 11.970020789273317, 12.177914826615869, 12.386631140331009, 12.596162240173246, 12.806500799474689, 13.017639649543144, 13.22957177431982, 13.442290305281539, 13.655788516573422, 13.870059820359, 14.085097762375506, 14.300896017683014, 14.517448386596827, 14.734748790793132, 14.952791269578759, 15.171569976316231, 15.391079174996086, 15.611313236948805, 15.832266637689186, 16.053933953886528, 16.27630986045422, 16.49938912775292, 16.72316661890167, 16.947637287191792, 17.172796173598528, 17.398638404385867, 17.625159188800126], [0.0, 0.05011872336272723, 0.12340677254400192, 0.2090535905807847, 0.30386311717294956, 0.40612619817811774, 0.5147503202664571, 0.6289664092534479, 0.7481987582580971, 0.871997545077537, 1.0, 1.1319063353632046, 1.26746396212711, 1.4064566732378863, 1.5486969618679893, 1.6940204031852832, 1.8422814426021197, 1.9933501712633217, 2.1471098121453833, 2.303454728907713, 2.4622888266898326, 2.6235242517554345, 2.7870803224242535, 2.952882641412122, 3.120862352177608, 3.2909555108355937, 3.463102551737, 3.6372478296536, 3.81333922513604, 3.9913278023673806, 4.171167510947728, 4.3528149246835905, 4.536229011737226, 4.721370931502903, 4.9082038543819415, 5.0966928012738, 5.286804500121683, 5.478507257274714, 5.67177084177532, 5.866566380965496, 6.062866266041593, 6.260644066383385, 6.4598744516472095, 6.660533120750642, 6.8625967369923355, 7.066042868649025, 7.270849934475427, 7.47699715360413, 7.684464499403874, 7.893232656907186, 8.103282983463814, 8.314597472315658, 8.527158718823063, 8.740949889102044, 8.955954690857903, 9.172157346223539, 9.389542566430535, 9.60809552815876, 9.827801851425685, 10.04864757889024, 10.270619156458231, 10.493703415087076, 10.717887553697151, 10.943159123105717, 11.169506010906831, 11.396916427227687, 11.625378891297766, 11.854882218772824, 12.085415509760624, 12.316968137499753, 12.549529737646981, 12.783090198132184, 13.017639649543145, 13.253168456005627, 13.48966720652669, 13.727126706771813, 13.965537971248557, 14.204892215871553, 14.44518085088555, 14.686395474124815, 14.92852786458892, 15.171569976316231, 15.41551393253781, 15.660352020095612, 15.906076684110033, 16.15268052288275, 16.400156283021868, 16.648496854777214, 16.89769526757433, 17.147744685736672, 17.398638404385867, 17.650369845510895, 17.902932554197346, 18.156320195008576, 18.410526548511132, 18.66554550793712, 18.92137107597684, 19.17799736169517, 19.435418577565866, 19.69362903661792, 19.952623149688797, 20.21239542277945], [0.0, 0.0567297004945868, 0.13968490766928177, 0.23662908360881577, 0.3439445874112734, 0.45969681667478385, 0.5826491486398413, 0.7119310633646239, 0.846890914583223, 0.9870195456944257, 1.1319063353632046, 1.2812119520353595, 1.4346504885762246, 1.59197721885182, 1.7529799026961244, 1.9174724265999523, 2.0852900364034035, 2.2562856874502826, 2.4303271990878597, 2.6072950008729734, 2.7870803224242535, 2.9695837215409875, 3.1547138741181358, 3.3423865693984145, 3.5325238682263476, 3.72505339211326, 3.9199077183235906, 4.117023861670976, 4.316342827820497, 4.517809226010935, 4.721370931502903, 4.926978789912867, 5.134586357043735, 5.344149668967811, 5.555627038029019, 5.768978871161853, 5.9841675075144325, 6.201157072842543, 6.419913348533781, 6.640403653443633, 6.8625967369923355, 7.086462682193409, 7.311972817470384, 7.539099636274108, 7.76781672364448, 7.998098688971824, 8.229921104307877, 8.463260447657163, 8.698094050748882, 8.934400050848984, 9.17215734622354, 9.41134555490898, 9.651944976483412, 9.893936556566905, 10.137301853807871, 10.382023009138582, 10.628082717105206, 10.875464199097776, 11.124151178322965, 11.37412785637799, 11.625378891297764, 11.877889376959557, 12.131644823740245, 12.386631140331012, 12.642834616622837, 12.900241907583998, 13.158840018057608, 13.418616288413563, 13.679558380994784, 13.9416542673027, 14.204892215871553, 14.469260780785103, 14.734748790793134, 15.00134533898855, 15.269039773008823, 15.537821685728458, 15.807680906411637, 16.07860749229648, 16.3505917205846, 16.623624080811375, 16.89769526757433, 17.172796173598528, 17.448917883119297, 17.72605166556418, 18.004188969517102, 18.283321416948827, 18.56344079769912, 18.844539064196713, 19.126608326404227, 19.409640846976064, 19.69362903661792, 19.97856544963745, 20.264442779676134, 20.5512538556131, 20.838991637632223, 21.127649213444233, 21.41721979465628, 21.707696713281585, 21.999073418382526, 22.291343472840587, 22.584500550247288, 22.8785384319103], [0.0, 0.0635236756900748, 0.15641363688193974, 0.2649678922144201, 0.3851355504363209, 0.514750320266457, 0.6524274804311224, 0.7971922571172365, 0.9483149626003915, 1.1052254634490883, 1.26746396212711, 1.4346504885762246, 1.6064648952909522, 1.7826331476222055, 1.9629175874234195, 2.1471098121453833, 2.3350253365937306, 2.526499505976163, 2.721384309623782, 2.9195458572817983, 3.120862352177608, 3.3252224428665045, 3.5325238682263476, 3.742672332380574, 3.9555805621443634, 4.171167510947729, 4.389357681477083, 4.610080545410983, 4.833270043225649, 5.0588641505366505, 5.286804500121683, 5.517036050845482, 5.749506796332409, 5.984167507514433, 6.220971504202488, 6.45987445164721, 6.700834178715663, 6.943810514847535, 7.188765143393561, 7.4356614693002285, 7.684464499403874, 7.935140733845866, 8.187658067328464, 8.441985699105453, 8.698094050748882, 8.955954690857904, 9.215540265981863, 9.476824437120214, 9.739781821239553, 10.004387937314677, 10.270619156458235, 10.538452655753257, 10.807866375446212, 11.0788389791958, 11.351349817105634, 11.625378891297766, 11.9009068238092, 12.177914826615869, 12.456384673608145, 12.736298674359213, 13.017639649543145, 13.30039090787305, 13.58453622444183, 13.870059820359003, 14.156946343586544, 14.445180850885551, 14.734748790793136, 15.025635987556027, 15.317828625953627, 15.611313236948808, 15.906076684110035, 16.20210615075284, 16.49938912775292, 16.797913401986925, 17.097667045360463, 17.39863840438587, 17.700816090275296, 18.004188969517102, 18.308746154906057, 18.614476996999894, 18.921371075976836, 19.229418193870476, 19.538608367160037, 19.848931819695675, 20.160378975939746, 20.472940454506368, 20.786607061982714, 21.101369787016658, 21.417219794656276, 21.734148420927898, 22.05214716763981, 22.371207697400106, 22.69132182883739, 23.012481532014032, 23.334678924022267, 23.657906264753862, 23.982155952834905, 24.30742052171742, 24.63369263592047, 24.96096508741325, 25.289230792133658, 25.618482786635905], [0.0, 0.07048981292767126, 0.17356627876726147, 0.2940248175366856, 0.42737030889876065, 0.5711989016043459, 0.7239740229900977, 0.8846140035369833, 1.0523091364604007, 1.2264267663213564, 1.4064566732378863, 1.59197721885182, 1.7826331476222055, 1.9781203736953823, 2.178175176842474, 2.382566300661076, 2.591089028930071, 2.803560650473182, 3.019816923466419, 3.2397092749736194, 3.463102551737, 3.6898731912828633, 3.919907718323591, 4.153101496302395, 4.389357681477083, 4.628586339543718, 4.8707036939976565, 5.115631482236324, 5.3632964005123736, 5.613629622719509, 5.866566380965496, 6.122045598190703, 6.380009564893124, 6.640403653443633, 6.903176064607396, 7.168277601795032, 7.4356614693002285, 7.705283091376211, 7.977099949490962, 8.251071435501958, 8.527158718823063, 8.805324625932089, 9.085533530798148, 9.367751255001705, 9.651944976483414, 9.938083145996398, 10.226135410454212, 10.51607254246721, 10.807866375446212, 11.101489743726322, 11.396916427227689, 11.694121100225217, 11.993079283847322, 12.293767301965532, 12.596162240173248, 12.900241907583998, 13.205984801207414, 13.513370072685982, 13.822377497197309, 14.132987444345906, 14.44518085088555, 14.758939195128415, 15.074244472910642, 15.391079174996092, 15.709426265810595, 16.02926916340887, 16.350591720584603, 16.673378207042198, 16.99761329255548, 17.323282031044947, 17.650369845510898, 17.978862513764824, 18.308746154906057, 18.64000721649497, 18.97263246237774, 19.306608961121224, 19.641924075019624, 19.97856544963745, 20.31652100385611, 20.655778920393537, 20.996327636768818, 21.338155836685523, 21.681252441809413, 22.025606603917886, 22.371207697400106, 22.718045312088073, 23.066109246400355, 23.415389500781373, 23.76587627142017, 24.117559944233843, 24.47043108910147, 24.824480454335557, 25.17969896137865, 25.536077699713612, 25.893607921976752, 26.252281039263615, 26.61208861661795, 26.973022368694746, 27.335074155589098, 27.69823597882268, 28.06249997748054, 28.427858424491067], [0.0, 0.07761871460455788, 0.19111969371282977, 0.3237606606000558, 0.47059188638948385, 0.6289664092534479, 0.7971922571172365, 0.9740783671278332, 1.1587331437877173, 1.3504599488179267, 1.5486969618679893, 1.7529799026961244, 1.9629175874234195, 2.178175176842474, 2.3984622796991406, 2.6235242517554345, 2.8531356730636794, 3.0870953541745427, 3.3252224428665045, 3.5673533404598285, 3.81333922513604, 4.063044038080632, 4.316342827820497, 4.573120375507677, 4.833270043225649, 5.096692801273801, 5.3632964005123736, 5.632994663345468, 5.905706872540218, 6.181357241345601, 6.4598744516472095, 6.741191249431117, 7.0252440888148735, 7.311972817470384, 7.601320397510068, 7.893232656907187, 8.187658067328464, 8.484547544913081, 8.783854271068886, 9.085533530798148, 9.389542566430535, 9.695840444944803, 10.004387937314677, 10.315147408527638, 10.628082717105206, 10.943159123105717, 11.260343203720163, 11.57960277568232, 11.9009068238092, 12.224225435069355, 12.549529737646985, 12.876791844530523, 13.205984801207414, 13.537082537092674, 13.870059820359002, 14.204892215871554, 14.541556045961133, 14.880028353796886, 15.220286869143559, 15.562309976309441, 15.906076684110033, 16.2515665976891, 16.598759892053515, 16.947637287191796, 17.298180024657654, 17.650369845510898, 18.004188969517106, 18.35962007551632, 18.716646282878557, 19.075251133970696, 19.435418577565866, 19.797132953131786, 20.160378975939746, 20.525141722940585, 20.891406619358133, 21.259159425954444, 21.628386226924682, 21.999073418382526, 22.371207697400106, 22.74477605156889, 23.119765749050483, 23.49616432908855, 23.873959592954964, 24.253139595305303, 24.63369263592047, 25.01560725181276, 25.398872209676185, 25.783476498662246, 26.16940932346347, 26.556660097688344, 26.945218437512114, 27.335074155589094, 27.72621725521295, 28.1186379247122, 28.51232653206915, 28.907273619750917, 29.30346989974218, 29.700906248769623, 30.099573703708934, 30.49946345716539, 30.900566853219953, 31.30287538333299], [0.0, 0.08490213995805886, 0.20905359058078468, 0.35414104780299205, 0.514750320266457, 0.6879860659818012, 0.8719975450775372, 1.0654819301935257, 1.26746396212711, 1.4771816328888265, 1.6940204031852832, 1.9174724265999523, 2.1471098121453833, 2.382566300661076, 2.6235242517554345, 2.8697051264080295, 3.120862352177608, 3.3767758608129457, 3.6372478296536, 3.9020993085832916, 4.171167510947728, 4.444303610725109, 4.7213709315029035, 5.0022434427637865, 5.286804500121684, 5.574945781330542, 5.866566380965496, 6.161572034874588, 6.45987445164721, 6.76139073301102, 7.066042868649025, 7.373757293703414, 7.684464499403874, 7.998098688971823, 8.314597472315658, 8.633901594125375, 8.955954690857903, 9.28070307282201, 9.608095528158762, 9.938083145996398, 10.270619156458231, 10.605658785534333, 10.943159123105717, 11.283079002642936, 11.625378891297766, 11.970020789273317, 12.316968137499753, 12.666185732763683, 13.017639649543147, 13.371297167889155, 13.727126706771815, 14.085097762375508, 14.44518085088555, 14.807347455359002, 15.171569976316233, 15.537821685728456, 15.906076684110033, 16.27630986045422, 16.64849685477721, 17.022614023058463, 17.398638404385867, 17.776547690132592, 18.15632019500858, 18.537934829844257, 18.921371075976836, 19.306608961121224, 19.69362903661792, 20.082412355959583, 20.472940454506368, 20.865195330307618, 21.25915942595444, 21.654815611393726, 22.05214716763981, 22.45113777132513, 22.851771480035637, 23.254032718381055, 23.657906264753862, 24.06337723873422, 24.47043108910147, 24.879053582415438, 25.289230792133658, 25.70094908823296, 26.11419512730605, 26.528955843105834, 26.94521843751211, 27.36297037189691, 27.78219935886636, 28.202893354358615, 28.62504055007832, 29.048629366249937, 29.4736484446727, 29.90008664206173, 30.32793302366032, 30.757176857109528, 31.18780760656219, 31.619814927028894, 32.05318865894464, 32.48791882294515, 32.92399561484287, 33.361409400792894, 33.800150712639834, 34.24021024343722], [0.0, 0.09233279397806167, 0.22735000694923552, 0.385135550436321, 0.5598013818589584, 0.7481987582580971, 0.9483149626003916, 1.1587331437877173, 1.3783926877168418, 1.6064648952909517, 1.8422814426021197, 2.0852900364034035, 2.3350253365937306, 2.591089028930071, 2.8531356730636794, 3.120862352177608, 3.3940009137561473, 3.6723120291261746, 3.955580562144363, 4.243611900940777, 4.536229011737226, 4.833270043225649, 5.134586357043735, 5.440040892455482, 5.749506796332408, 6.062866266041593, 6.380009564893123, 6.700834178715663, 7.0252440888148735, 7.353149141643326, 7.684464499403873, 8.019110158826122, 8.357010527716843, 8.698094050748882, 9.042292877436047, 9.389542566430535, 9.739781821239552, 10.092952253238241, 10.448998168494475, 10.807866375446212, 11.169506010906833, 11.533868382235184, 11.900906823809198, 12.270576566195691, 12.642834616622839, 13.017639649543145, 13.394951906228917, 13.77473310247376, 14.156946343586544, 14.541556045961132, 14.928527864588922, 15.317828625953627, 15.709426265810595, 16.103289771407752, 16.499389127752917, 16.89769526757433, 17.298180024657654, 17.700816090275296, 18.105576972452294, 18.512436957838208, 18.921371075976836, 19.332355065785407, 19.745365344072493, 20.160378975939746, 20.577373646926485, 20.996327636768818, 21.41721979465628, 21.840029515879014, 22.264736719767836, 22.69132182883739, 23.119765749050483, 23.550049851127977, 23.982155952834898, 24.416066302178955, 24.851763561462494, 25.289230792133658, 25.728451440386472, 26.169409323463466, 26.612088616617946, 27.056473840695904, 27.502549850300817, 27.950301822506873, 28.39971524608883, 28.850775911238763, 29.303469899742172, 29.757783575587595, 30.213703575985743, 30.671216802775817, 31.13031041419785, 31.590971817011788, 32.053188658944634, 32.516948821448764, 32.98224041275514, 33.4490517612064, 33.917371408855715, 34.38718810531792, 34.85849080186063, 35.33126864572342, 35.80551097465408, 36.28120731165146, 36.75834735990512, 37.23692099792261], [0.0, 0.09990416579859136, 0.24599291118564, 0.41671701058741956, 0.6057055966573058, 0.8095517266928727, 1.0260776390609918, 1.253750299604237, 1.4914221229127824, 1.7381964558215044, 1.9933501712633217, 2.2562856874502826, 2.526499505976163, 2.803560650473182, 3.0870953541745427, 3.3767758608129457, 3.6723120291261746, 3.973444905275514, 4.2799417117611585, 4.591591878365499, 4.9082038543819415, 5.229602516550173, 5.555627038029019, 5.886129118979343, 6.220971504202488, 6.560026731144103, 6.903176064607396, 7.250308584167149, 7.601320397510068, 7.956113958417076, 8.314597472315658, 8.676684375595578, 9.042292877436047, 9.41134555490898, 9.78376899372754, 10.159493468295668, 10.538452655753256, 10.920583379555902, 11.305825378819149, 11.694121100225217, 12.085415509760624, 12.479655921944019, 12.876791844530521, 13.276774836953319, 13.679558380994784, 14.085097762375508, 14.493349962116504, 14.904273556672162, 15.317828625953627, 15.733976668467182, 16.152680522882754, 16.573904295425997, 16.99761329255548, 17.423773958445672, 17.85235381684815, 18.283321416948827, 18.716646282878557, 19.15229886656962, 19.59025050368138, 20.03047337234562, 20.472940454506368, 20.917625499650327, 21.36450299074324, 21.81354811220456, 22.264736719767832, 22.718045312088073, 23.173451003969408, 23.630931501097315, 24.090465076169746, 24.55203054633001, 25.01560725181276, 25.48117503572128, 25.948714224861035, 26.41820561156047, 26.889630436415192, 27.36297037189691, 27.838207506772733, 28.315324331284586, 28.794303723042365, 29.275128933587574, 29.757783575587595, 30.24225161062343, 30.728517337536363, 31.216565381301493, 31.70638068239826, 32.19794848665005, 32.69125433550688, 33.186284056747034, 33.683023755574716, 34.18145980609291, 34.68157884313118, 35.18336775441011, 35.68681367302498, 36.19190397023205, 36.698626248522594, 37.20696833496979, 37.716918274835294, 38.2284643254226, 38.741594950165265, 39.25629881293866, 39.77256477258468, 40.2903818776394], [0.0, 0.10761040270431169, 0.26496789221442, 0.4488610156002265, 0.6524274804311223, 0.8719975450775371, 1.1052254634490886, 1.350459948817927, 1.606464895290952, 1.872274485202666, 2.1471098121453833, 2.4303271990878597, 2.721384309623782, 3.019816923466419, 3.3252224428665045, 3.6372478296536, 3.955580562144363, 4.2799417117611585, 4.610080545410983, 4.945770250270435, 5.286804500121683, 5.632994663345468, 5.984167507514433, 6.340163293489744, 6.700834178715663, 7.066042868649026, 7.4356614693002285, 7.809570504253744, 8.187658067328465, 8.569819087951672, 8.955954690857903, 9.345971635241005, 9.739781821239553, 10.137301853807871, 10.538452655753257, 10.943159123105717, 11.351349817105634, 11.76295668800423, 12.17791482661587, 12.596162240173248, 13.017639649543145, 13.442290305281539, 13.870059820359002, 14.300896017683016, 14.734748790793134, 15.171569976316233, 15.611313236948806, 16.05393395388653, 16.49938912775292, 16.947637287191792, 17.39863840438587, 17.85235381684815, 18.308746154906054, 18.7677792743621, 19.229418193870476, 19.69362903661792, 20.160378975939746, 20.62963618453985, 21.10136978701665, 21.575549815426182, 22.05214716763981, 22.531133568276978, 23.012481532014032, 23.496164329088554, 23.982155952834898, 24.47043108910147, 24.96096508741325, 25.45373393375496, 25.948714224861035, 26.445883143907768, 26.94521843751211, 27.446698393949085, 27.950301822506876, 28.456008033905363, 28.96379682170926, 29.4736484446727, 29.985543609956707, 30.499463457165387, 31.01538954315096, 31.53330382754094, 32.053188658944634, 32.57502676179888, 33.0988012238158, 33.62449548399806, 34.152093321189554, 34.68157884313118, 35.21293647599401, 35.746150954363706, 36.28120731165146, 36.81809087090906, 37.35678723602639, 37.89728228329144, 38.43956215329413, 38.98361324315629, 39.52942219907133, 40.07697590913798, 40.626261496473724, 41.17726631259397, 41.72997793104434, 42.28438414127357, 42.84047294273594, 43.398232539212195], [0.0, 0.11544621033669152, 0.2842619137957198, 0.48154548181844553, 0.6999349341926692, 0.9354933117266964, 1.1857040594245305, 1.4487956497189587, 1.7234419678724928, 2.0086068688047694, 2.303454728907713, 2.6072950008729734, 2.9195458572817983, 3.2397092749736194, 3.5673533404598285, 3.9020993085832916, 4.243611900940777, 4.591591878365499, 4.945770250270435, 5.305903688127306, 5.671770841775319, 6.043169344110125, 6.419913348533781, 6.801831484270251, 7.18876514339356, 7.580567034059147, 7.977099949490961, 8.378235713424901, 8.783854271068886, 9.193842900983974, 9.60809552815876, 10.026512122322488, 10.448998168494475, 10.875464199097776, 11.305825378819149, 11.740001134884034, 12.177914826615869, 12.619493449124665, 13.064667366768242, 13.513370072685982, 13.965537971248557, 14.421110180718824, 14.880028353796886, 15.342236514039516, 15.807680906411637, 16.27630986045422, 16.74807366474576, 17.222924451498944, 17.700816090275296, 18.18170408992165, 18.665545507937125, 19.15229886656962, 19.641924075019624, 20.134382357197456, 20.62963618453985, 21.127649213444233, 21.628386226924682, 22.131813080134346, 22.637896649434474, 23.146604784721767, 23.657906264753862, 24.171770755237343, 24.688168769464824, 25.20707163130745, 25.72845144038647, 26.252281039263615, 26.778533982503745, 27.307184507476226, 27.83820750677273, 28.371578502129434, 28.907273619750914, 29.445269566941416, 29.985543609956704, 30.5280735529967, 31.072837718265205, 31.619814927028894, 32.16898448161272, 32.72032614827369, 33.27382014089946, 33.82944710548164, 34.38718810531791, 34.9470246068999, 35.508938466446956, 36.0729119170487, 36.63892755638197, 37.20696833496979, 37.777017544952265, 38.34905880934176, 38.92307607173558, 39.499053586462246, 40.07697590913798, 40.656827887612174, 41.23859465328172, 41.82226161275511, 42.40781443984897, 42.99523906789989, 43.584521682376476, 44.17564871377638, 44.768606830794916, 45.3633829337518, 45.95996414826417, 46.55833781915394], [0.0, 0.12340677254400192, 0.30386311717294956, 0.5147503202664571, 0.7481987582580971, 1.0, 1.2674639621271102, 1.5486969618679893, 1.8422814426021197, 2.147109812145383, 2.4622888266898326, 2.7870803224242535, 3.120862352177608, 3.463102551737, 3.81333922513604, 4.171167510947728, 4.536229011737226, 4.9082038543819415, 5.286804500121683, 5.671770841775319, 6.062866266041593, 6.4598744516472095, 6.8625967369923355, 7.270849934475427, 7.684464499403874, 8.103282983463812, 8.527158718823063, 8.955954690857903, 9.389542566430535, 9.827801851425686, 10.270619156458231, 10.71788755369715, 11.169506010906833, 11.625378891297764, 12.085415509760624, 12.549529737646981, 13.017639649543145, 13.489667206526688, 13.965537971248557, 14.44518085088555, 14.92852786458892, 15.415513932537808, 15.906076684110033, 16.400156283021868, 16.89769526757433, 17.398638404385867, 17.902932554197346, 18.410526548511132, 18.921371075976836, 19.435418577565866, 19.9526231496888, 20.472940454506368, 20.996327636768818, 21.522743246591695, 22.05214716763981, 22.584500550247288, 23.119765749050483, 23.657906264753862, 24.198886689687114, 24.742672656845276, 25.289230792133658, 25.838528669565846, 26.39053476918652, 26.945218437512114, 27.502549850300813, 28.06249997748054, 28.625040550078324, 29.190144029008295, 29.75778357558759, 30.32793302366032, 30.90056685321995, 31.475660165429197, 32.053188658944634, 32.6331286074608, 33.215456838394914, 33.800150712639834, 34.38718810531791, 34.9765473874739, 35.568207408649414, 36.16214748028566, 36.75834735990512, 37.356787236026385, 37.95744771376929, 38.560309801110975, 39.1653548957558, 39.77256477258468, 40.3819215716518, 40.993407786698754, 41.60700625415794, 42.22270014261937, 42.840472942735936, 43.46030845754462, 44.08219079318179, 44.70610434997258, 45.33203381387549, 45.95996414826417, 46.58988058602995, 47.221768621989106, 47.85561400558043, 48.49140273383876, 49.129121044631624, 49.76875541014656], [0.0, 0.13148768620913656, 0.32376066060005576, 0.5484571648052401, 0.7971922571172364, 1.0654819301935257, 1.350459948817927, 1.6501086282159543, 1.9629175874234195, 2.287706706982121, 2.6235242517554345, 2.9695837215409875, 3.3252224428665045, 3.6898731912828633, 4.063044038080632, 4.444303610725109, 4.833270043225649, 5.229602516550173, 5.632994663345468, 6.043169344110125, 6.4598744516472095, 6.882879499548912, 7.311972817470385, 7.746959222332348, 8.187658067328465, 8.633901594125375, 9.085533530798148, 9.542407890741039, 10.004387937314677, 10.471345286216545, 10.943159123105717, 11.419715518310404, 11.9009068238092, 12.386631140331012, 12.876791844530523, 13.371297167889155, 13.870059820359002, 14.372996652878362, 14.880028353796888, 15.39107917499609, 15.906076684110035, 16.424951539765573, 16.947637287191792, 17.474070171909617, 18.004188969517102, 18.537934829844257, 19.075251133970696, 19.61608336278679, 20.160378975939746, 20.708087300143983, 21.259159425954447, 21.81354811220456, 22.371207697400106, 22.93209401743819, 23.496164329088554, 24.063377238734223, 24.63369263592047, 25.207071631307446, 25.783476498662242, 26.362870620562074, 26.945218437512114, 27.530485400209766, 28.118637924712203, 28.709643350286584, 29.303469899742172, 29.900086642061737, 30.499463457165394, 31.101571002654776, 31.706380682398265, 32.31386461682957, 32.92399561484287, 33.53674714717697, 34.152093321189554, 34.770008856930886, 35.39046906443276, 36.01344982213556, 36.63892755638198, 37.26687922191101, 37.89728228329144, 38.53011469723771, 39.165354895755804, 39.802981770070254, 40.44297465528673, 41.085313315748046, 41.72997793104434, 42.37694908264055, 43.026207741087134, 43.677735253782096, 44.33151333325429, 44.98752404594053, 45.6457498014298, 46.30617334215065, 46.9687777334786, 47.63354635424196, 48.30046288760623, 48.96951131231775, 49.64067589428906, 50.31394117850902, 50.989291981262156, 51.66671338264213, 52.346190719345465, 53.02770957773243], [0.0, 0.13968490766928177, 0.34394458741127343, 0.5826491486398413, 0.846890914583223, 1.1319063353632046, 1.434650488576225, 1.7529799026961246, 2.0852900364034035, 2.430327199087859, 2.7870803224242535, 3.1547138741181358, 3.5325238682263476, 3.919907718323591, 4.316342827820497, 4.7213709315029035, 5.134586357043735, 5.555627038029019, 5.984167507514433, 6.419913348533781, 6.8625967369923355, 7.311972817470385, 7.767816723644481, 8.229921104307879, 8.698094050748882, 9.17215734622354, 9.651944976483414, 10.137301853807871, 10.628082717105208, 11.124151178322967, 11.625378891297766, 12.131644823740244, 12.64283461662284, 13.158840018057608, 13.679558380994786, 14.204892215871554, 14.734748790793134, 15.269039773008823, 15.807680906411639, 16.3505917205846, 16.89769526757433, 17.448917883119293, 18.004188969517102, 18.56344079769912, 19.126608326404227, 19.69362903661792, 20.264442779676134, 20.838991637632226, 21.41721979465628, 21.999073418382526, 22.58450055024729, 23.173451003969408, 23.76587627142017, 24.36172943521277, 24.96096508741325, 25.563539253838687, 26.16940932346347, 26.778533982503745, 27.390873152793173, 28.006387934101102, 28.62504055007832, 29.246794297545378, 29.871613498865152, 30.499463457165394, 31.130310414197847, 31.764121510640013, 32.400864748662286, 33.04050895659891, 33.683023755574716, 34.328379527952066, 34.97654738747391, 35.62749915098856, 36.28120731165146, 36.93764501350711, 37.596786027362285, 38.25860472786817, 38.92307607173558, 39.590175577013056, 40.25987930336275, 40.93216383327389, 41.60700625415794, 42.28438414127356, 42.964275541433054, 43.64665895744539, 44.33151333325429, 45.01881803973202, 45.708552861092734, 46.400697981891646, 47.09523397457785, 47.792141787571744, 48.49140273383876, 49.19299847993383, 49.896911035492, 50.603122743142485, 51.311616268824686, 52.02237459248597, 52.73538099914248, 53.45061907028486, 54.1680726756126, 54.88772596508072, 55.60956336124428, 56.33356955188666], [0.0, 0.14799470822753338, 0.36440571647787734, 0.6173107187508758, 0.8972721240653804, 1.1992430008228632, 1.5199972853761514, 1.857263991915819, 2.2093431255864395, 2.5749064142134435, 2.952882641412122, 3.3423865693984145, 3.742672332380574, 4.153101496302395, 4.573120375507677, 5.0022434427637865, 5.440040892455482, 5.886129118979343, 6.340163293489744, 6.801831484270251, 7.270849934475427, 7.746959222332348, 8.229921104307879, 8.71951589395303, 9.215540265981863, 9.717805401605986, 10.226135410454212, 10.74036597869803, 11.260343203720163, 11.78592258379623, 12.316968137499753, 12.853351632377787, 13.394951906228918, 13.9416542673027, 14.493349962116506, 15.049935701491526, 15.611313236948808, 16.177388980856836, 16.74807366474576, 17.323282031044947, 17.902932554197346, 18.4869471876833, 19.075251133970696, 19.66777263481508, 20.264442779676138, 20.86519533030762, 21.46996655982495, 22.07869510476548, 22.691321828837392, 23.307789697208513, 23.928043660320526, 24.552030546330013, 25.17969896137865, 25.81099919698264, 26.445883143907768, 27.084304211964163, 27.72621725521295, 28.371578502129434, 29.020345490312817, 29.672477005372933, 30.32793302366032, 30.98667465853773, 31.64866410991935, 32.31386461682957, 32.98224041275514, 33.65375668358529, 34.32837952795207, 35.00607591979949, 35.68681367302498, 36.37056140804921, 37.05728852018299, 37.74696514966997, 38.43956215329413, 39.13505107744971, 39.83340413257901, 40.53459416889123, 41.23859465328172, 41.94537964737728, 42.654923786638726, 43.367202260456715, 44.082190793181795, 44.799865626033515, 45.52020349983761, 46.24318163854359, 46.968777733478596, 47.69696992829615, 48.42773680458122, 49.161057368075944, 49.896911035492, 50.63527762187878, 51.37613732851732, 52.11947073131308, 52.865258769661324, 53.613482735761174, 54.364124264355546, 55.117165322875536, 55.872588201969414, 56.63037550639714, 57.390510146272916, 58.15297532863879, 58.91775454935371, 59.68483158528327], [0.0, 0.15641363688193974, 0.3851355504363209, 0.6524274804311224, 0.9483149626003915, 1.26746396212711, 1.6064648952909524, 1.9629175874234197, 2.3350253365937306, 2.721384309623782, 3.120862352177608, 3.5325238682263476, 3.9555805621443634, 4.389357681477083, 4.833270043225649, 5.286804500121684, 5.749506796332408, 6.220971504202488, 6.700834178715663, 7.18876514339356, 7.684464499403874, 8.187658067328465, 8.698094050748882, 9.215540265981863, 9.739781821239553, 10.270619156458233, 10.807866375446212, 11.351349817105634, 11.9009068238092, 12.456384673608147, 13.017639649543147, 13.584536224441829, 14.156946343586545, 14.734748790793134, 15.317828625953629, 15.906076684110035, 16.49938912775292, 17.09766704536046, 17.7008160902753, 18.308746154906057, 18.92137107597684, 19.538608367160037, 20.160378975939746, 20.786607061982714, 21.41721979465628, 22.05214716763981, 22.69132182883739, 23.334678924022267, 23.9821559528349, 24.63369263592047, 25.289230792133665, 25.94871422486104, 26.612088616617946, 27.27930143116961, 27.950301822506876, 28.625040550078324, 29.303469899742176, 29.985543609956707, 30.671216802775817, 31.36044591925922, 32.053188658944634, 32.74940392306285, 33.449051761206405, 34.15209332118956, 34.858490801860626, 35.56820740864942, 36.281207311651464, 36.99745560606786, 37.71691827483529, 38.43956215329413, 39.165354895755804, 39.894264943841335, 40.62626149647372, 41.3613144814158, 42.09939452825403, 42.84047294273594, 43.584521682376476, 44.33151333325429, 45.08142108792562, 45.83421872438775, 46.58988058602994, 47.34838156251345, 48.10969707152664, 48.87380304136495, 49.640675894289046, 50.4102925306173, 51.18263031351201, 51.95766705442153, 52.735380999142464, 53.51575081446923, 54.29875557539935, 55.084374752865855, 55.87258820196941, 56.66337615068427, 57.456719189014756, 58.252598258578836, 59.05099464259844, 59.85188995627595, 60.65526613753859, 61.46110543813265, 62.26939041505118, 63.0801039222794], [0.0, 0.16493848884661177, 0.4061261981781178, 0.6879860659818015, 1.0, 1.336543249988985, 1.6940204031852837, 2.06990047066311, 2.462288826689833, 2.8697051264080295, 3.2909555108355937, 3.72505339211326, 4.171167510947729, 4.628586339543718, 5.096692801273801, 5.574945781330542, 6.062866266041593, 6.560026731144103, 7.066042868649026, 7.580567034059147, 8.103282983463812, 8.633901594125375, 9.17215734622354, 9.717805401605986, 10.270619156458233, 10.830388174299163, 11.396916427227687, 11.970020789273317, 12.549529737646983, 13.13528222675225, 13.727126706771813, 14.324920264034882, 14.928527864588922, 15.537821685728458, 16.15268052288275, 16.772989261388112, 17.398638404385867, 18.029523649481014, 18.665545507937125, 19.306608961121224, 19.952623149688797, 20.60350109164456, 21.259159425954444, 21.919518178837322, 22.58450055024729, 23.254032718381055, 23.928043660320522, 24.60646498715556, 25.28923079213366, 25.976277510556177, 26.667543790290527, 27.36297037189691, 28.06249997748054, 28.766077207478144, 29.4736484446727, 30.18516176480553, 30.900566853219953, 31.619814927028894, 32.342858662349606, 33.06965212619358, 33.800150712639834, 34.5343110829551, 35.27209110935586, 36.01344982213556, 36.75834735990512, 37.506744922717665, 38.25860472786817, 39.01388996817732, 39.77256477258468, 40.53459416889123, 41.29994404850449, 42.06858113305157, 42.84047294273594, 43.615587766324175, 44.3938946326572, 45.17536328358915, 45.95996414826418, 46.74766831864812, 47.53844752623859, 48.33227411988198, 49.129121044631624, 49.92896182158574, 50.73177052864818, 51.537521782158976, 52.34619071934546, 53.157752981547745, 53.9721846981758, 54.78946247135812, 55.60956336124428, 56.43246487192687, 57.25814493794947, 58.086581911370466, 58.9177545493537, 59.751642002259054, 60.588223802207715, 61.42747985209823, 62.269390415051184, 63.11393610426119, 63.96109787323686, 64.8108570064096, 65.6631951100942, 66.51809410378416], [0.0, 0.17356627876726147, 0.42737030889876065, 0.7239740229900976, 1.0523091364604007, 1.4064566732378863, 1.7826331476222055, 2.178175176842474, 2.591089028930071, 3.0198169234664185, 3.463102551737, 3.9199077183235906, 4.389357681477083, 4.8707036939976565, 5.3632964005123736, 5.866566380965496, 6.380009564893123, 6.903176064607396, 7.4356614693002285, 7.977099949490961, 8.527158718823063, 9.085533530798148, 9.651944976483414, 10.226135410454212, 10.807866375446212, 11.396916427227687, 11.993079283847322, 12.596162240173248, 13.205984801207416, 13.822377497197309, 14.44518085088555, 15.07424447291064, 15.709426265810597, 16.3505917205846, 16.99761329255548, 17.650369845510898, 18.308746154906057, 18.972632462377735, 19.641924075019624, 20.31652100385611, 20.996327636768818, 21.68125244180941, 22.371207697400106, 23.066109246400355, 23.76587627142017, 24.47043108910147, 25.17969896137865, 25.893607921976752, 26.612088616617946, 27.335074155589098, 28.062499977480545, 28.794303723042365, 29.53042511822256, 30.27080586555454, 31.01538954315096, 31.76412151064001, 32.516948821448764, 33.27382014089946, 34.0346856696379, 34.799497071960616, 35.568207408649414, 36.340771073959324, 37.11714373643884, 37.897282283291446, 38.68114476801321, 39.46869036106554, 40.25987930336275, 41.05467286237376, 41.85303329065394, 42.65492378663872, 43.46030845754463, 44.2691522842358, 45.08142108792562, 45.89708149859341, 46.71610092500551, 47.53844752623859, 48.364090184610845, 49.19299847993383, 50.025142665004196, 50.86049364226038, 51.6990229415348, 52.5407026988372, 53.38550563610897, 54.2334050418928, 55.084374752865855, 55.938389136187794, 56.795423072618625, 57.655451940364394, 58.5184515996109, 59.38439837770925, 60.25326905497806, 61.12504085109058, 61.99969141201624, 62.87719879748823, 63.75754146897069, 64.64069827810015, 65.52664845557807, 66.415371600492, 67.30684767004504, 68.2010569696734, 69.09798014353402, 69.99759816534478], [0.0, 0.18229421777608878, 0.44886101560022645, 0.7603797186212514, 1.1052254634490883, 1.4771816328888265, 1.8722744852026665, 2.2877067069821213, 2.721384309623782, 3.1716711782965388, 3.6372478296536, 4.117023861670976, 4.610080545410983, 5.115631482236324, 5.632994663345468, 6.161572034874588, 6.700834178715663, 7.250308584167149, 7.809570504253744, 8.378235713424901, 8.955954690857903, 9.542407890741039, 10.137301853807871, 10.74036597869803, 11.351349817105634, 11.970020789273317, 12.596162240173248, 13.229571774319822, 13.870059820359002, 14.517448386596827, 15.171569976316233, 15.832266637689187, 16.49938912775292, 17.172796173598528, 17.85235381684815, 18.537934829844257, 19.229418193870476, 19.92668863126395, 20.629636184539855, 21.338155836685527, 22.05214716763981, 22.771514042686658, 23.49616432908855, 24.22600963778619, 24.96096508741325, 25.700949088232964, 26.445883143907764, 27.195691669272765, 27.950301822506876, 28.70964335028658, 29.473648444672705, 30.242251610623434, 31.01538954315096, 31.793001013247284, 32.57502676179888, 33.36140940079289, 34.152093321189554, 34.94702460689991, 35.7461509543637, 36.54942159727243, 37.35678723602639, 38.16819997155404, 38.9836132431563, 39.80298177007026, 40.62626149647371, 41.45340953967737, 42.28438414127357, 43.11914462103051, 43.95765133333879, 44.79986562603352, 45.645749801429794, 46.49526707942249, 47.34838156251345, 48.20505820264002, 49.065262769688545, 49.928961821585744, 50.79612267586875, 51.66671338264212, 52.54070269883721, 53.41806006369494, 54.29875557539934, 55.18275996879393, 56.07004459411798, 56.960581396704136, 57.854342897582946, 58.75130217494326, 59.65143284640114, 60.5547090520332, 61.46110543813264, 62.37059714164976, 63.28315977528027, 64.19876941316785, 65.11740257718908, 66.03903622379077, 66.9636477313521, 67.8912148880448, 68.82171588016716, 69.75512928092822, 70.6914340396607, 71.63060947144164, 72.57263524710176, 73.51749138360492], [0.0, 0.1911196937128298, 0.47059188638948385, 0.7971922571172365, 1.1587331437877173, 1.5486969618679893, 1.96291758742342, 2.3984622796991406, 2.8531356730636794, 3.325222442866504, 3.81333922513604, 4.316342827820497, 4.833270043225649, 5.3632964005123736, 5.905706872540218, 6.45987445164721, 7.0252440888148735, 7.601320397510068, 8.187658067328465, 8.783854271068886, 9.389542566430535, 10.004387937314677, 10.628082717105208, 11.260343203720163, 11.9009068238092, 12.549529737646983, 13.205984801207416, 13.870059820359002, 14.541556045961135, 15.22028686914356, 15.906076684110035, 16.598759892053515, 17.298180024657658, 18.004188969517102, 18.716646282878557, 19.435418577565866, 20.160378975939746, 20.89140661935813, 21.628386226924686, 22.37120769740011, 23.119765749050483, 23.873959592954964, 24.63369263592047, 25.398872209676185, 26.16940932346347, 26.945218437512114, 27.72621725521295, 28.51232653206915, 29.303469899742176, 30.099573703708934, 30.900566853219956, 31.70638068239827, 32.51694882144877, 33.33220707706134, 34.15209332118956, 34.97654738747391, 35.805510974654084, 36.63892755638198, 37.47674229690616, 38.31890197215045, 39.1653548957558, 40.01605084969557, 40.8709410191107, 41.729977931044345, 42.593115396783794, 43.460308457544635, 44.3315133332543, 45.20668737421418, 46.08578901543766, 46.9687777334786, 47.855614005580435, 48.74625927098949, 49.64067589428905, 50.538827130621904, 51.440677092679536, 52.346190719345465, 53.25533374588892, 54.16807267561259, 55.08437475286586, 56.00420793734057, 56.92754087957329, 57.854342897582946, 58.78458395457756, 59.71823463766902, 60.65526613753859, 61.595650228999716, 62.539359252408566, 63.486366095875944, 64.43664417823683, 65.39016743273773, 66.34691029140295, 67.30684767004504, 68.26995495388569, 69.23620798375583, 70.20558304284593, 71.17805684397844, 72.153606517377, 73.13220959890768, 74.11384401876961, 75.0984880906132, 76.0861205010657, 77.07672029964503], [0.0, 0.20004025397681277, 0.4925568822553024, 0.8344014082698136, 1.2128173076864106, 1.6209827860580859, 2.0545372645570232, 2.510411116008467, 2.9863065055322937, 3.480428045264077, 3.9913278023673806, 4.517809226010935, 5.0588641505366505, 5.613629622719509, 6.181357241345601, 6.76139073301102, 7.353149141643326, 7.956113958417076, 8.569819087951672, 9.193842900983974, 9.827801851425686, 10.471345286216545, 11.124151178322967, 11.78592258379623, 12.456384673608147, 13.13528222675225, 13.822377497197309, 14.517448386596827, 15.22028686914356, 15.930697625950824, 16.648496854777214, 17.373511227449292, 18.105576972452297, 18.844539064196713, 19.590250503681382, 20.342571677849804, 21.101369787016655, 21.86651833143203, 22.637896649434477, 23.415389500781373, 24.198886689687118, 24.988282722882378, 25.783476498662246, 26.584371023440813, 27.390873152793176, 28.202893354358615, 29.02034549031282, 29.843146617401935, 30.671216802775817, 31.5044789540678, 32.34285866234961, 33.186284056747034, 34.03468566963791, 34.88799631147306, 35.746150954363706, 36.60908662367022, 37.47674229690616, 38.34905880934176, 39.225978765752956, 40.10744645781628, 40.993407786698754, 41.88381019043457, 42.77860257571875, 43.677735253782096, 44.58115988004201, 45.488829397251386, 46.400697981891646, 47.31672099357867, 48.236854927269526, 49.16105736807594, 50.08928694850662, 51.02150330797493, 51.95766705442152, 52.89773972791363, 53.841683766093496, 54.78946247135812, 55.74103997966171, 56.69638123084012, 57.65545194036439, 58.618218572436845, 59.5846483143499, 60.554709052033196, 61.52836934671987, 62.50559841266779, 63.48636609587593, 64.47064285374, 65.45839973559526, 66.44960836409818, 67.44424091740115, 68.44227011207828, 69.44366918676215, 70.44841188645448, 71.45647244747593, 72.46782558302206, 73.48244646929525, 74.50031073218301, 75.52139443445635, 76.5456740634622, 77.57312651928613, 78.60372910336264, 79.6374595075119, 80.6742958033828], [0.0, 0.20905359058078468, 0.514750320266457, 0.8719975450775372, 1.26746396212711, 1.6940204031852832, 2.1471098121453838, 2.6235242517554345, 3.1208623521776078, 3.6372478296535995, 4.171167510947728, 4.721370931502903, 5.286804500121683, 5.866566380965496, 6.4598744516472095, 7.066042868649025, 7.684464499403873, 8.314597472315658, 8.955954690857903, 9.60809552815876, 10.270619156458231, 10.943159123105717, 11.625378891297766, 12.316968137499753, 13.017639649543147, 13.727126706771813, 14.44518085088555, 15.171569976316233, 15.906076684110035, 16.648496854777214, 17.398638404385867, 18.156320195008576, 18.921371075976836, 19.69362903661792, 20.472940454506368, 21.25915942595444, 22.05214716763981, 22.851771480035634, 23.657906264753862, 24.47043108910147, 25.289230792133658, 26.114195127306047, 26.94521843751211, 27.78219935886636, 28.62504055007832, 29.473648444672698, 30.327933023660318, 31.18780760656219, 32.053188658944634, 32.923995614842866, 33.800150712639834, 34.68157884313118, 35.568207408649414, 36.45996619224459, 37.356787236026385, 38.25860472786816, 39.1653548957558, 40.07697590913797, 40.99340778669875, 41.914592310030514, 42.840472942735936, 43.77099475453243, 44.706104349972584, 45.6457498014298, 46.589880586029935, 47.538447526238585, 48.49140273383876, 49.44869955705712, 50.41029253061729, 51.37613732851732, 52.34619071934546, 53.320410523963325, 54.29875557539934, 55.28118568080794, 56.267661585361125, 57.25814493794947, 58.25259825857883, 59.250984907357704, 60.25326905497806, 61.25941565459919, 62.26939041505117, 63.28315977528026, 64.30069087996375, 65.32195155622745, 66.34691029140293, 67.37553621176669, 68.40779906220607, 69.44366918676215, 70.48311751000124, 71.52611551917137, 72.57263524710174, 73.62264925580652, 74.6761306207564, 75.73305291578389, 76.79339019859025, 77.85711699682363, 78.92420829470065, 79.99463952014413, 81.06838653241265, 82.14542561019748, 83.22573344016544, 84.30928710592622], [0.0, 0.21815752705936722, 0.5371668413365648, 0.9099715891387326, 1.3226599114912936, 1.7677921767347164, 2.2406128765414923, 2.7377743733230555, 3.256770721575575, 3.7956439285009553, 4.3528149246835905, 4.926978789912867, 5.517036050845482, 6.122045598190703, 6.741191249431117, 7.373757293703414, 8.019110158826122, 8.676684375595578, 9.345971635241005, 10.026512122322488, 10.71788755369715, 11.419715518310404, 12.131644823740244, 12.853351632377787, 13.584536224441829, 14.324920264034882, 15.07424447291064, 15.832266637689187, 16.598759892053515, 17.373511227449292, 18.156320195008576, 18.94699776854821, 19.745365344072493, 20.5512538556131, 21.36450299074324, 22.184960491912015, 23.01248153201403, 23.846928154452737, 24.688168769464824, 25.536077699713612, 26.39053476918652, 27.251424930285364, 28.1186379247122, 28.992067974352768, 29.87161349886515, 30.757176857109528, 31.648664109919345, 32.54598480202478, 33.4490517612064, 34.35778091298551, 35.27209110935586, 36.191903970232055, 37.117143736438834, 38.04773713319475, 38.98361324315629, 39.92470338818806, 40.870941019110695, 41.82226161275511, 42.77860257571874, 43.73990315427906, 44.70610434997258, 45.67714884039419, 46.65298090481346, 47.63354635424196, 48.61879246561833, 49.60866791980826, 50.603122743142485, 51.60210825224046, 52.60557700188859, 53.613482735761174, 54.625780339790325, 55.642425798006286, 56.66337615068427, 57.68858945464707, 58.718024745584174, 59.751642002259054, 60.78940211248611, 61.831266840767455, 62.87719879748823, 63.92716140957603, 64.98111889253751, 66.03903622379076, 67.10087911721841, 68.166613998871, 69.23620798375583, 70.30962885364998, 71.38684503588095, 72.46782558302208, 73.55254015345282, 74.64095899273832, 75.7330529157839, 76.82879328972503, 77.92815201751392, 79.0311015221674, 80.13761473164273, 81.24766506430946, 82.3612264149884, 83.47827314152926, 84.59878005190141, 85.7227223917726, 86.8500758325527, 87.98081645988069], [0.0, 0.22735000694923554, 0.5598013818589584, 0.9483149626003917, 1.3783926877168418, 1.8422814426021197, 2.335025336593731, 2.85313567306368, 3.3940009137561473, 3.955580562144363, 4.536229011737226, 5.134586357043735, 5.749506796332409, 6.380009564893124, 7.0252440888148735, 7.684464499403874, 8.357010527716843, 9.042292877436047, 9.739781821239553, 10.448998168494475, 11.169506010906833, 11.9009068238092, 12.64283461662284, 13.394951906228918, 14.156946343586545, 14.928527864588922, 15.709426265810597, 16.49938912775292, 17.298180024657658, 18.105576972452297, 18.921371075976836, 19.745365344072493, 20.57737364692649, 21.41721979465628, 22.26473671976784, 23.119765749050483, 23.9821559528349, 24.851763561462494, 25.728451440386475, 26.612088616617946, 27.50254985030082, 28.39971524608883, 29.303469899742176, 30.213703575985747, 31.130310414197854, 32.05318865894464, 32.98224041275514, 33.917371408855715, 34.85849080186063, 35.805510974654084, 36.75834735990514, 37.716918274835294, 38.68114476801321, 39.65095047708598, 40.62626149647372, 41.607006254157945, 42.5931153967838, 43.58452168237647, 44.581159880042016, 45.582966676084936, 46.58988058602994, 47.601841872084, 48.61879246561834, 49.64067589428905, 50.6674372134489, 51.69902294153481, 52.73538099914247, 53.776460651525056, 54.82221245427518, 55.87258820196941, 56.92754087957329, 57.987024616420975, 59.05099464259843, 60.11940724757338, 61.19221974092663, 62.269390415051184, 63.35087850969554, 64.43664417823683, 65.52664845557806, 66.62085322757127, 67.71922120187584, 68.82171588016715, 69.92830153161742, 71.03894316757538, 72.15360651737699, 73.27225800522356, 74.39486472806834, 75.52139443445635, 76.65181550426551, 77.78609692930154, 78.92420829470065, 80.06611976109842, 81.21180204752484, 82.3612264149884, 83.51436465071461, 84.67118905300582, 85.83167241669175, 86.9957880191416, 88.16350960681093, 89.33481138229685, 90.5096679918781, 91.68805451351686], [0.0, 0.23662908360881574, 0.5826491486398412, 0.987019545694426, 1.4346504885762246, 1.917472426599952, 2.4303271990878597, 2.9695837215409875, 3.532523868226347, 4.117023861670975, 4.721370931502903, 5.344149668967811, 5.984167507514433, 6.640403653443633, 7.311972817470384, 7.998098688971823, 8.698094050748882, 9.41134555490898, 10.137301853807871, 10.875464199097776, 11.625378891297764, 12.386631140331012, 13.158840018057608, 13.9416542673027, 14.734748790793134, 15.537821685728458, 16.3505917205846, 17.172796173598528, 18.004188969517102, 18.844539064196713, 19.69362903661792, 20.5512538556131, 21.41721979465628, 22.291343472840587, 23.173451003969404, 24.06337723873422, 24.960965087413246, 25.86606491252453, 26.778533982503745, 27.698235978822677, 28.62504055007832, 29.55882290750864, 30.499463457165387, 31.446847464624394, 32.400864748662286, 33.36140940079289, 34.328379527952066, 35.301677015956486, 36.28120731165146, 37.26687922191101, 38.25860472786817, 39.25629881293866, 40.259879303362744, 41.26926672012991, 42.28438414127356, 43.305157073630625, 44.33151333325429, 45.3633829337518, 46.40069798189164, 47.4433925798894, 48.491402733838754, 49.54466626780486, 50.603122743142485, 51.66671338264213, 52.73538099914246, 53.80906992828072, 54.88772596508071, 55.97129630410465, 57.059729482918144, 58.15297532863878, 59.250984907357704, 60.35371047624098, 61.46110543813264, 62.57312429849617, 63.68972262454307, 64.8108570064096, 65.93648502025296, 67.06656519314781, 68.2010569696734, 69.3399206800887, 70.48311751000124, 71.63060947144163, 72.78235937526202, 73.93833080478218, 75.09848809061319, 76.26279628659172, 77.43122114676414, 78.60372910336264, 79.7802872457196, 80.9608633000705, 82.14542561019748, 83.33394311887052, 84.52638535004436, 85.7227223917726, 86.92292487980292, 88.1269639818189, 89.33481138229685, 90.54643926794694, 91.76182031371097, 92.98092766928936, 94.20373494617257, 95.43021620515323], [0.0, 0.24599291118564004, 0.6057055966573058, 1.0260776390609918, 1.4914221229127826, 1.9933501712633217, 2.5264995059761635, 3.0870953541745427, 3.6723120291261746, 4.279941711761158, 4.9082038543819415, 5.555627038029019, 6.220971504202488, 6.903176064607396, 7.601320397510068, 8.314597472315658, 9.042292877436047, 9.78376899372754, 10.538452655753257, 11.305825378819149, 12.085415509760624, 12.876791844530523, 13.679558380994786, 14.493349962116506, 15.317828625953629, 16.15268052288275, 16.99761329255548, 17.85235381684815, 18.716646282878557, 19.590250503681382, 20.472940454506368, 21.36450299074324, 22.26473671976784, 23.173451003969404, 24.090465076169746, 25.01560725181276, 25.948714224861035, 26.88963043641519, 27.838207506772736, 28.794303723042365, 29.757783575587595, 30.728517337536363, 31.706380682398265, 32.69125433550688, 33.683023755574716, 34.68157884313118, 35.68681367302498, 36.6986262485226, 37.716918274835294, 38.741594950165265, 39.77256477258469, 40.80973936125406, 41.85303329065394, 42.902363936650055, 43.95765133333879, 45.01881803973201, 46.08578901543766, 47.15849150457872, 48.236854927269526, 49.32081077803484, 50.4102925306173, 51.50523554867133, 52.6055770018886, 53.71125578714239, 54.822212454275174, 55.9383891361878, 57.05972948291816, 58.186178599424714, 59.31768298681439, 60.45419048677585, 61.59565022899971, 62.7420125813844, 63.89322910284285, 65.04925249853999, 66.21003657740398, 67.3755362117667, 68.54570729899953, 69.7205067250208, 70.89989232956067, 72.08382287307691, 73.27225800522355, 74.46515823478067, 75.66248490096059, 76.8642001460113, 78.0702668890436, 79.28064880101323, 80.49531028079414, 81.71421643228315, 82.93733304247982, 84.16462656049019, 85.39606407740439, 86.63161330700336, 87.87124256725134, 89.11492076253377, 90.3626173666034, 91.61430240619852, 92.86994644530051, 94.12952056999893, 95.39299637393518, 96.6603459442962, 97.93154184833291, 99.20655712037802], [0.0, 0.2554397365718449, 0.6289664092534478, 1.0654819301935257, 1.5486969618679893, 2.0699004706631094, 2.623524251755435, 3.205648570285079, 3.81333922513604, 4.444303610725109, 5.0966928012738, 5.768978871161853, 6.45987445164721, 7.168277601795032, 7.893232656907187, 8.633901594125375, 9.389542566430535, 10.159493468295668, 10.943159123105717, 11.740001134884034, 12.549529737646981, 13.371297167889155, 14.204892215871554, 15.049935701491526, 15.906076684110035, 16.772989261388112, 17.650369845510898, 18.537934829844257, 19.435418577565866, 20.342571677849804, 21.25915942595444, 22.184960491912015, 23.119765749050483, 24.06337723873422, 25.01560725181276, 25.976277510556177, 26.945218437512114, 27.922268499878307, 28.907273619750917, 29.900086642061733, 30.90056685321995, 31.90857954447373, 32.92399561484287, 33.94669120917552, 34.97654738747391, 36.013449822135556, 37.05728852018299, 38.10795756791887, 39.165354895755804, 40.22938206123813, 41.2999440485045, 42.37694908264055, 43.46030845754463, 44.54993637608141, 45.645749801429794, 46.74766831864812, 47.85561400558043, 48.96951131231774, 50.08928694850661, 51.214869777867285, 52.34619071934546, 53.48318265437659, 54.62578033979033, 55.77392032592662, 56.927540879573286, 58.08658191137047, 59.25098490735772, 60.42069286436823, 61.59565022899971, 62.77580283991376, 63.96109787323685, 65.15148379085397, 66.34691029140295, 67.54732826379288, 68.75268974308383, 69.96294786857723, 71.17805684397842, 72.39797189950278, 73.62264925580652, 74.85204608963207, 76.0861205010657, 77.32483148231266, 78.56813888790143, 79.81600340623493, 81.06838653241265, 82.32525054225204, 83.58655846744284, 84.85227407177253, 86.12236182836446, 87.39678689787516, 88.67551510759932, 89.95851293143554, 91.24574747066798, 92.53718643552233, 93.83279812745687, 95.13255142215165, 96.43641575316146, 97.7443610961997, 99.05635795402303, 100.37237734188724, 101.69239077354787, 103.01637024777953], [0.0, 0.26496789221442, 0.6524274804311223, 1.1052254634490883, 1.606464895290952, 2.1471098121453833, 2.7213843096237826, 3.3252224428665045, 3.955580562144363, 4.610080545410983, 5.286804500121683, 5.9841675075144325, 6.700834178715663, 7.4356614693002285, 8.187658067328464, 8.955954690857903, 9.739781821239552, 10.538452655753256, 11.351349817105634, 12.177914826615869, 13.017639649543145, 13.870059820359002, 14.734748790793134, 15.611313236948808, 16.49938912775292, 17.398638404385867, 18.308746154906057, 19.229418193870476, 20.160378975939746, 21.101369787016655, 22.05214716763981, 23.01248153201403, 23.9821559528349, 24.960965087413246, 25.948714224861035, 26.945218437512114, 27.950301822506876, 28.963796821709256, 29.985543609956707, 31.01538954315096, 32.053188658944634, 33.09880122381579, 34.152093321189554, 35.21293647599401, 36.28120731165146, 37.35678723602639, 38.439562153294126, 39.52942219907133, 40.62626149647372, 41.72997793104434, 42.84047294273594, 43.95765133333879, 45.08142108792561, 46.211693209042814, 47.34838156251345, 48.49140273383876, 49.640675894289046, 50.79612267586875, 51.95766705442151, 53.12523524021377, 54.29875557539934, 55.478158437824625, 56.66337615068427, 57.85434289758295, 59.05099464259842, 60.25326905497807, 61.46110543813265, 62.67444466262069, 63.89322910284285, 65.11740257718908, 66.34691029140295, 67.58169878494661, 68.82171588016715, 70.06691063408128, 71.31723329260919, 72.57263524710176, 73.83306899301711, 75.09848809061319, 76.36884712753329, 77.6441016831698, 78.92420829470063, 80.20912442469967, 81.49880843022939, 82.79321953333117, 84.0923177928335, 85.39606407740438, 86.70442003977891, 88.01734809209786, 89.33481138229683, 90.65677377149031, 91.98319981229713, 93.31405472805905, 94.6493043929055, 95.98891531262153, 97.33285460627837, 98.68108998858804, 100.0335897529466, 101.39032275513178, 102.75125839762377, 104.11636661451867, 105.4856178570068, 106.8589830793893], [0.0, 0.27457578966804486, 0.6760848989791645, 1.1453016131561657, 1.6647162926501209, 2.2249653240882066, 2.8200633652642684, 3.4457970376770324, 4.0990123270009144, 4.777244879033021, 5.478507257274714, 6.201157072842543, 6.943810514847535, 7.705283091376211, 8.484547544913081, 9.28070307282201, 10.092952253238241, 10.920583379555902, 11.76295668800423, 12.619493449124665, 13.489667206526688, 14.372996652878362, 15.269039773008823, 16.177388980856836, 17.09766704536046, 18.029523649481014, 18.972632462377735, 19.92668863126395, 20.89140661935813, 21.86651833143203, 22.851771480035634, 23.846928154452737, 24.851763561462494, 25.86606491252453, 26.88963043641519, 27.922268499878307, 28.963796821709256, 30.014041768011708, 31.072837718265205, 32.140026493403326, 33.215456838394914, 34.29898395289525, 35.39046906443275, 36.48977903935099, 37.596786027362285, 38.711367136107924, 39.833404132579005, 40.96278316864261, 42.099394528254024, 43.24313239422379, 44.3938946326572, 45.551582593399324, 46.716100925005506, 47.88735740292015, 49.06526276968854, 50.24973058615124, 51.44067709267953, 52.63802107960649, 53.84168376609348, 55.051588686746165, 56.26766158536112, 57.489830315243, 58.718024745584174, 59.952176673446665, 61.19221974092662, 62.43808935712029, 63.68972262454308, 64.94705826968388, 66.21003657740397, 67.47859932891382, 68.75268974308382, 70.03225242086444, 71.31723329260919, 72.60757956811115, 73.90323968917718, 75.20416328457893, 76.5103011272308, 77.82160509345739, 79.13802812422222, 80.45952418819931, 81.78604824657819, 83.11755621949963, 84.45400495402785, 85.79535219357054, 87.14155654866494, 88.49257746905307, 89.8483752169748, 91.20891084161222, 92.57414615462257, 93.94404370670227, 95.31856676512652, 96.6976792922142, 98.08134592466989, 99.46953195375794, 100.86220330626703, 102.25932652622495, 103.66086875732698, 105.06679772604231, 106.47708172536639, 107.89168959918732, 109.31059072723754, 110.73375501060343], [0.0, 0.2842619137957198, 0.6999349341926693, 1.1857040594245305, 1.7234419678724928, 2.303454728907713, 2.9195458572817987, 3.567353340459829, 4.243611900940777, 4.945770250270435, 5.67177084177532, 6.419913348533781, 7.188765143393561, 7.977099949490962, 8.783854271068886, 9.608095528158762, 10.448998168494475, 11.305825378819149, 12.17791482661587, 13.064667366768242, 13.965537971248557, 14.880028353796888, 15.807680906411639, 16.74807366474576, 17.7008160902753, 18.665545507937125, 19.641924075019624, 20.629636184539855, 21.628386226924686, 22.637896649434477, 23.657906264753862, 24.688168769464824, 25.728451440386475, 26.778533982503745, 27.838207506772736, 28.907273619750917, 29.985543609956707, 31.072837718265205, 32.168984481612725, 33.27382014089947, 34.38718810531792, 35.508938466446956, 36.63892755638198, 37.77701754495227, 38.923076071735586, 40.07697590913798, 41.23859465328172, 42.40781443984897, 43.584521682376476, 44.768606830794916, 45.959964148264184, 47.15849150457873, 48.364090184610845, 49.57666471042819, 50.79612267586875, 52.02237459248597, 53.25533374588891, 54.4949160616027, 55.74103997966171, 56.99362633722583, 58.25259825857883, 59.517881051928974, 60.789402112486115, 62.06709083133859, 63.350878509695534, 64.64069827810015, 65.93648502025296, 67.23817530111641, 68.54570729899953, 69.85902074134677, 71.17805684397842, 72.50275825355003, 73.83306899301711, 75.16893440990916, 76.51030112723082, 77.85711699682365, 79.20933105503362, 80.5668934805415, 81.92975555422386, 83.29786962092216, 84.67118905300582, 86.04966821562428, 87.43326243354915, 88.82192795951552, 90.21562194397755, 91.61430240619852, 93.01792820660175, 94.42645902031353, 95.8398553118329, 97.25807831076895, 98.68108998858804, 100.10885303631905, 101.54133084316666, 102.97848747598603, 104.42028765957586, 105.86669675774807, 107.31768075513635, 108.77320623970668, 110.23324038593644, 111.69775093862931, 113.16670619733617, 114.64007500135344], [0.0, 0.2940248175366855, 0.7239740229900975, 1.2264267663213566, 1.7826331476222053, 2.382566300661076, 3.019816923466419, 3.6898731912828633, 4.389357681477083, 5.115631482236323, 5.866566380965496, 6.640403653443633, 7.4356614693002285, 8.251071435501958, 9.085533530798148, 9.938083145996398, 10.807866375446212, 11.694121100225217, 12.596162240173248, 13.513370072685982, 14.44518085088555, 15.39107917499609, 16.3505917205846, 17.323282031044947, 18.308746154906057, 19.306608961121224, 20.31652100385611, 21.338155836685527, 22.37120769740011, 23.415389500781373, 24.47043108910147, 25.536077699713612, 26.612088616617946, 27.698235978822677, 28.794303723042365, 29.900086642061733, 31.01538954315096, 32.140026493403326, 33.27382014089947, 34.4166011022746, 35.56820740864942, 36.72848400303588, 37.89728228329144, 39.074459685502916, 40.25987930336275, 41.45340953967737, 42.65492378663872, 43.8643001319087, 45.08142108792562, 46.30617334215066, 47.53844752623859, 48.77813800234773, 50.025142665004196, 51.279362757110135, 52.54070269883721, 53.80906992828072, 55.08437475286586, 56.366530210601105, 57.65545194036438, 58.95105806048781, 60.25326905497806, 61.56200766677266, 62.877198797488234, 64.19876941316787, 65.52664845557804, 66.86076675864734, 68.2010569696734, 69.5474534749583, 70.89989232956066, 72.25831119087925, 73.62264925580652, 74.99284720121183, 76.36884712753329, 77.75059250527501, 79.13802812422222, 80.53110004520113, 81.92975555422386, 83.33394311887052, 84.74361234677173, 86.15871394606445, 87.57919968770399, 89.0050223695223, 90.43613578193153, 91.87249467517802, 93.31405472805906, 94.76077251802012, 96.21260549255615, 97.66951194184581, 99.13145097255133, 100.59838248272251, 102.07026713774529, 103.54706634728137, 105.0287422431469, 106.5152576580822, 108.00657610536814, 109.50266175924546, 111.00347943609866, 112.50899457636586, 114.01917322714016, 115.53398202542861, 117.05338818203819, 118.57735946605881], [0.0, 0.30386311717294956, 0.7481987582580971, 1.26746396212711, 1.8422814426021197, 2.4622888266898326, 3.1208623521776087, 3.81333922513604, 4.536229011737226, 5.286804500121683, 6.062866266041593, 6.8625967369923355, 7.684464499403874, 8.527158718823063, 9.389542566430535, 10.270619156458231, 11.169506010906833, 12.085415509760624, 13.017639649543145, 13.965537971248557, 14.92852786458892, 15.906076684110035, 16.89769526757433, 17.902932554197346, 18.92137107597684, 19.952623149688797, 20.996327636768818, 22.05214716763981, 23.119765749050483, 24.198886689687118, 25.289230792133658, 26.39053476918652, 27.50254985030082, 28.62504055007832, 29.757783575587595, 30.90056685321995, 32.053188658944634, 33.215456838394914, 34.38718810531792, 35.56820740864942, 36.75834735990512, 37.95744771376929, 39.1653548957558, 40.3819215716518, 41.60700625415794, 42.84047294273594, 44.082190793181795, 45.33203381387549, 46.58988058602994, 47.85561400558043, 49.12912104463163, 50.4102925306173, 51.6990229415348, 52.99521021579678, 54.29875557539934, 55.60956336124428, 56.92754087957329, 58.25259825857883, 59.58464831434989, 60.92360642539416, 62.26939041505117, 63.62192044117689, 64.98111889253751, 66.34691029140295, 67.71922120187583, 69.09798014353402, 70.48311751000124, 71.87456549209406, 73.27225800522355, 74.6761306207564, 76.08612050106568, 77.50216633802256, 78.92420829470063, 80.35218795008305, 81.78604824657819, 83.22573344016544, 84.67118905300582, 86.12236182836445, 87.57919968770399, 89.04165168981727, 90.5096679918781, 91.98319981229713, 93.46219939527766, 94.94661997697399, 96.43641575316144, 97.93154184833291, 99.43195428614337, 100.93760996112833, 102.44846661162708, 103.96448279384687, 105.4856178570068, 107.01183191950577, 108.54308584606093, 110.07934122576721, 111.6205603510313, 113.16670619733617, 114.7177424037951, 116.27363325445631, 117.83434366032216, 119.39983914204798, 120.97008581328876, 122.54505036466304], [0.0, 0.31377548803556854, 0.7726058782791297, 1.3088101214257313, 1.902378821521586, 2.5426115728266754, 3.2226685382451414, 3.937734818047063, 4.684206116363972, 5.459266256490561, 6.260644066383385, 7.086462682193409, 7.935140733845866, 8.805324625932089, 9.695840444944803, 10.605658785534333, 11.533868382235184, 12.479655921944019, 13.442290305281539, 14.421110180718824, 15.415513932537808, 16.424951539765573, 17.448917883119293, 18.4869471876833, 19.538608367160037, 20.60350109164456, 21.68125244180941, 22.771514042686658, 23.873959592954964, 24.988282722882378, 26.114195127306047, 27.251424930285364, 28.39971524608883, 29.55882290750864, 30.728517337536363, 31.90857954447373, 33.09880122381579, 34.29898395289525, 35.508938466446956, 36.72848400303588, 37.95744771376929, 39.19566412594149, 40.442974655286726, 41.69922716137752, 42.96427554143305, 44.23797935841815, 45.520203499837606, 46.81081786407716, 48.10969707152663, 49.41672019804953, 50.73177052864818, 52.054735329419316, 53.38550563610896, 54.72397605776122, 56.070044594117974, 57.42361246556918, 58.78458395457755, 60.152866257611876, 61.528369346719856, 62.91100583995695, 64.30069087996375, 65.69734202005196, 67.10087911721841, 68.51122423156102, 69.92830153161741, 71.35203720519034, 72.78235937526202, 74.21919802063398, 75.66248490096058, 77.11215348587105, 78.56813888790141, 80.03037779897987, 81.49880843022939, 82.97337045487107, 84.45400495402785, 85.94065436524384, 87.43326243354913, 88.93177416491177, 90.43613578193151, 91.94629468163933, 93.46219939527765, 94.98379954994452, 96.51104583199324, 98.04388995208664, 99.58228461181258, 101.12618347177236, 102.67554112106104, 104.23031304806341, 105.79045561249384, 107.35592601861453, 108.92668228956846, 110.50268324277, 112.08388846629755, 113.67025829623726, 115.26175379493, 116.85833673007559, 118.4599695546526, 120.06661538761307, 121.67823799531514, 123.29480177365753, 124.91627173088294, 126.54261347101887], [0.0, 0.32376066060005576, 0.7971922571172363, 1.350459948817927, 1.9629175874234193, 2.6235242517554345, 3.325222442866505, 4.063044038080632, 4.833270043225649, 5.6329946633454675, 6.4598744516472095, 7.311972817470384, 8.187658067328464, 9.085533530798148, 10.004387937314677, 10.943159123105717, 11.900906823809198, 12.876791844530521, 13.870059820359002, 14.880028353796886, 15.906076684110033, 16.947637287191792, 18.004188969517102, 19.075251133970696, 20.160378975939746, 21.259159425954444, 22.371207697400106, 23.49616432908855, 24.63369263592047, 25.783476498662246, 26.94521843751211, 28.1186379247122, 29.303469899742176, 30.499463457165387, 31.706380682398265, 32.92399561484287, 34.152093321189554, 35.39046906443275, 36.63892755638198, 37.89728228329144, 39.1653548957558, 40.442974655286726, 41.72997793104434, 43.026207741087134, 44.33151333325429, 45.645749801429794, 46.968777733478596, 48.30046288760623, 49.640675894289046, 50.989291981262156, 52.346190719345465, 53.711255787142385, 55.084374752865855, 56.465438871738804, 57.854342897582946, 59.25098490735771, 60.65526613753858, 62.067090831338575, 63.48636609587592, 64.91300176847965, 66.34691029140293, 67.78800659428407, 69.23620798375583, 70.6914340396607, 72.15360651737697, 73.62264925580654, 75.0984880906132, 76.58105077233735, 78.0702668890436, 79.56606779318737, 81.06838653241265, 82.57715778401597, 84.0923177928335, 85.61380431232745, 87.14155654866495, 88.67551510759932, 90.21562194397755, 91.76182031371096, 93.31405472805906, 94.8722709100861, 96.43641575316144, 98.00643728138309, 99.5822846118126, 101.16390791841741, 102.75125839762377, 104.34428823538977, 105.94295057571443, 107.54719949050425, 109.15698995072339, 110.77227779875953, 112.39301972194023, 114.01917322714013, 115.65069661642255, 117.28754896366218, 118.92969009209975, 120.57708055278135, 122.22968160383925, 123.88745519057221, 125.55036392628729, 127.21837107386575, 128.89144052801933, 130.56953679820398], [0.0, 0.3338174169271837, 0.8219548958542658, 1.392408364075161, 2.023890356104964, 2.7050169941698923, 3.428511557051738, 4.189251600672193, 4.9834026102825595, 5.807968530202187, 6.660533120750642, 7.539099636274108, 8.441985699105453, 9.367751255001705, 10.315147408527638, 11.283079002642936, 12.270576566195691, 13.276774836953319, 14.300896017683016, 15.342236514039516, 16.400156283021868, 17.474070171909617, 18.56344079769912, 19.66777263481508, 20.786607061982714, 21.919518178837322, 23.066109246400355, 24.22600963778619, 25.398872209676185, 26.584371023440813, 27.78219935886636, 28.992067974352768, 30.213703575985747, 31.446847464624394, 32.69125433550688, 33.94669120917552, 35.21293647599401, 36.48977903935099, 37.77701754495227, 39.074459685502916, 40.3819215716518, 41.69922716137752, 43.026207741087134, 44.36270145261629, 45.708552861092734, 47.06361255928071, 48.42773680458122, 49.800787185338585, 51.18263031351201, 52.5731375411209, 53.97218469817581, 55.37965185006801, 56.795423072618625, 58.21938624318582, 59.65143284640114, 61.0914577932582, 62.539359252408566, 63.995038492637555, 65.45839973559525, 66.92935001794919, 68.40779906220607, 69.89365915552159, 71.38684503588095, 72.88727378509019, 74.39486472806834, 75.9095393379771, 77.43122114676414, 78.95983566073426, 80.49531028079414, 82.03757422704746, 83.58655846744284, 85.14219565020231, 86.70442003977891, 88.27316745611313, 89.84837521697482, 91.42998208319435, 93.01792820660174, 94.61215508050546, 96.21260549255615, 97.81922347985066, 99.43195428614337, 101.0507443210403, 102.67554112106106, 104.30629331246105, 105.94295057571443, 107.58546361156436, 109.2337841085539, 110.88786471195654, 112.54765899403023, 114.21312142552492, 115.88420734837618, 117.56087294952371, 119.24307523579631, 120.93077200980838, 122.62392184681741, 124.32248407249357, 126.02641874155697, 127.73568661723911, 129.4502491515298, 131.17006846617022, 132.89510733435824, 134.62532916313123], [0.0, 0.34394458741127343, 0.846890914583223, 1.4346504885762248, 2.0852900364034035, 2.7870803224242535, 3.532523868226348, 4.316342827820498, 5.134586357043735, 5.9841675075144325, 6.8625967369923355, 7.76781672364448, 8.698094050748882, 9.651944976483414, 10.628082717105206, 11.625378891297766, 12.642834616622839, 13.679558380994784, 14.734748790793134, 15.807680906411637, 16.89769526757433, 18.004188969517102, 19.126608326404227, 20.264442779676138, 21.41721979465628, 22.58450055024729, 23.76587627142017, 24.96096508741325, 26.16940932346347, 27.390873152793176, 28.62504055007832, 29.87161349886515, 31.130310414197854, 32.400864748662286, 33.683023755574716, 34.97654738747391, 36.28120731165146, 37.596786027362285, 38.923076071735586, 40.25987930336275, 41.60700625415794, 42.96427554143305, 44.33151333325429, 45.708552861092734, 47.09523397457785, 48.49140273383876, 49.896911035492, 51.311616268824686, 52.735380999142464, 54.1680726756126, 55.609563361244284, 57.05972948291815, 58.5184515996109, 59.985614187165204, 61.46110543813264, 62.94481707537394, 64.43664417823683, 65.93648502025296, 67.44424091740113, 68.95981608607809, 70.48311751000124, 72.0140548153419, 73.55254015345284, 75.0984880906132, 76.6518155042655, 78.21244148526708, 79.78028724571962, 81.35527603197885, 82.93733304247982, 84.52638535004436, 86.12236182836446, 87.72519308238063, 89.33481138229683, 90.95115060099397, 92.57414615462258, 94.20373494617259, 95.8398553118329, 97.48244696996794, 99.13145097255133, 100.78680965890796, 102.44846661162708, 104.11636661451865, 105.79045561249386, 107.47068067325948, 109.15698995072339, 110.84933265001482, 112.54765899403023, 114.25192019142128, 115.96206840594644, 117.67805672711415, 119.39983914204798, 121.12737050851098, 122.86060652902856, 124.5995037260539, 126.34401941812327, 128.09411169695124, 129.84973940541983, 131.61086211641688, 133.37744011248373, 135.14943436623165, 136.92680652149207, 138.7095188751651], [0.0, 0.354141047802992, 0.8719975450775371, 1.4771816328888268, 2.1471098121453833, 2.8697051264080295, 3.637247829653601, 4.44430361072511, 5.286804500121683, 6.161572034874587, 7.066042868649025, 7.998098688971824, 8.955954690857904, 9.938083145996398, 10.943159123105717, 11.970020789273317, 13.017639649543145, 14.085097762375508, 15.171569976316233, 16.27630986045422, 17.398638404385867, 18.537934829844257, 19.69362903661792, 20.86519533030762, 22.05214716763981, 23.254032718381055, 24.47043108910147, 25.700949088232964, 26.945218437512114, 28.202893354358615, 29.473648444672698, 30.757176857109528, 32.05318865894464, 33.36140940079289, 34.68157884313118, 36.013449822135556, 37.35678723602639, 38.711367136107924, 40.07697590913798, 41.45340953967737, 42.84047294273594, 44.23797935841815, 45.645749801429794, 47.06361255928071, 48.49140273383876, 49.928961821585744, 51.37613732851732, 52.832782416133526, 54.29875557539935, 55.77392032592662, 57.258144937949474, 58.75130217494326, 60.25326905497806, 61.763926629107985, 63.28315977528027, 64.8108570064096, 66.34691029140295, 67.8912148880448, 69.44366918676215, 71.00417456438467, 72.57263524710174, 74.14895818189395, 75.7330529157839, 77.32483148231267, 78.92420829470063, 80.53110004520113, 82.14542561019749, 83.76710596063384, 85.39606407740438, 87.0322248713574, 88.67551510759932, 90.32586333380917, 91.98319981229714, 93.64745645556278, 95.31856676512653, 96.99646577342655, 98.68108998858804, 100.37237734188723, 102.07026713774529, 103.77470000609897, 105.4856178570068, 107.20296383735896, 108.92668228956848, 110.65671871212996, 112.39301972194023, 114.13553301828166, 115.88420734837618, 117.63899247442426, 119.39983914204798, 121.16669905006383, 122.93952482151381, 124.71826997589005, 126.50288890249062, 128.29333683484862, 130.08956982618065, 131.89154472580293, 133.69921915646808, 135.51255149257597, 137.33150083921805, 139.15602701201342, 140.98609051769998, 142.82165253544494], [0.0, 0.3644057164778773, 0.8972721240653803, 1.5199972853761512, 2.209343125586439, 2.9528826414121214, 3.7426723323805744, 4.573120375507677, 5.440040892455481, 6.340163293489743, 7.270849934475427, 8.229921104307877, 9.215540265981863, 10.226135410454212, 11.260343203720163, 12.316968137499753, 13.394951906228917, 14.493349962116504, 15.611313236948806, 16.74807366474576, 17.902932554197346, 19.075251133970696, 20.264442779676134, 21.46996655982495, 22.69132182883739, 23.928043660320522, 25.17969896137865, 26.445883143907764, 27.72621725521295, 29.02034549031282, 30.327933023660318, 31.648664109919345, 32.98224041275514, 34.328379527952066, 35.68681367302498, 37.05728852018299, 38.439562153294126, 39.833404132579005, 41.23859465328172, 42.65492378663872, 44.082190793181795, 45.520203499837606, 46.968777733478596, 48.42773680458122, 49.896911035492, 51.37613732851732, 52.86525876966132, 54.364124264355546, 55.8725882019694, 57.39051014627291, 58.91775454935371, 60.45419048677585, 61.99969141201623, 63.554134928430585, 65.11740257718907, 66.68937963978773, 68.26995495388569, 69.85902074134677, 71.45647244747592, 73.06220859054076, 74.6761306207564, 76.29814278799043, 77.92815201751392, 79.56606779318737, 81.21180204752483, 82.86526905813035, 84.52638535004438, 86.19506960357829, 87.87124256725134, 89.554826975476, 91.24574747066798, 92.94393052948286, 94.64930439290549, 96.3617989999403, 98.0813459246699, 99.80787831646772, 101.54133084316665, 103.28163963700018, 105.0287422431469, 106.78257757072062, 108.54308584606093, 110.31020856818823, 112.08388846629757, 113.8640694591743, 115.65069661642255, 117.44371612140455, 119.24307523579631, 121.04872226567126, 122.86060652902856, 124.67867832468983, 126.50288890249062, 128.33319043469993, 130.16953598860377, 132.01187950019298, 133.86017574890028, 135.7143803333327, 137.57444964795144, 139.44034086065122, 141.31201189119727, 143.18942139047678, 145.07252872052769, 146.9612939353074], [0.0, 0.37473755192538427, 0.9227120870469747, 1.5630931017232506, 2.2719836621874223, 3.036604427781853, 3.848786679449114, 4.702780051700641, 5.594279985825937, 6.519923162494534, 7.47699715360413, 8.463260447657163, 9.476824437120214, 10.51607254246721, 11.57960277568232, 12.666185732763683, 13.77473310247376, 14.904273556672162, 16.05393395388653, 17.222924451498944, 18.410526548511132, 19.61608336278679, 20.838991637632226, 22.07869510476548, 23.334678924022267, 24.60646498715556, 25.893607921976752, 27.195691669272765, 28.51232653206915, 29.843146617401935, 31.18780760656219, 32.54598480202478, 33.917371408855715, 35.301677015956486, 36.6986262485226, 38.10795756791887, 39.52942219907133, 40.96278316864261, 42.40781443984897, 43.8643001319087, 45.33203381387549, 46.81081786407716, 48.30046288760623, 49.800787185338585, 51.311616268824686, 52.832782416133526, 54.364124264355546, 55.90548643500426, 57.456719189014756, 59.0176781084302, 60.58822380220772, 62.16822163386827, 63.757541468970686, 65.35605744061232, 66.9636477313521, 68.58019437012261, 70.20558304284593, 71.83970291559962, 73.48244646929524, 75.13370934493335, 76.79339019859025, 78.461390565372, 80.13761473164274, 81.82196961489852, 83.5143646507146, 85.21471168624556, 86.92292487980293, 88.63892060607662, 90.3626173666034, 92.09393570511841, 93.83279812745687, 95.5791290256992, 97.33285460627836, 99.09390282179011, 100.86220330626703, 102.63768731369608, 104.42028765957586, 106.20993866532507, 108.00657610536814, 109.81013715673582, 111.6205603510313, 113.43778552862234, 115.26175379493002, 117.09240747869357, 118.92969009209973, 120.7735462926712, 122.6239218468174, 124.48076359495654, 126.34401941812325, 128.21363820598344, 130.08956982618062, 131.97176509494514, 133.86017574890028, 135.7547544180043, 137.65545459957102, 139.56223063331421, 141.47503767736634, 143.3938316852223, 145.3185693835648, 147.24920825092784, 149.185706497159, 151.1280230436431], [0.0, 0.3851355504363209, 0.9483149626003915, 1.6064648952909522, 2.3350253365937306, 3.120862352177608, 3.955580562144364, 4.833270043225649, 5.749506796332408, 6.700834178715662, 7.684464499403874, 8.698094050748882, 9.739781821239553, 10.807866375446212, 11.9009068238092, 13.017639649543147, 14.156946343586544, 15.317828625953627, 16.49938912775292, 17.700816090275296, 18.921371075976836, 20.160378975939746, 21.41721979465628, 22.691321828837392, 23.9821559528349, 25.28923079213366, 26.612088616617946, 27.950301822506876, 29.303469899742176, 30.671216802775817, 32.053188658944634, 33.4490517612064, 34.85849080186063, 36.28120731165146, 37.716918274835294, 39.165354895755804, 40.62626149647372, 42.099394528254024, 43.584521682376476, 45.08142108792562, 46.58988058602994, 48.10969707152663, 49.640675894289046, 51.18263031351201, 52.735380999142464, 54.29875557539935, 55.8725882019694, 57.456719189014756, 59.05099464259843, 60.65526613753859, 62.269390415051184, 63.89322910284286, 65.52664845557806, 67.16951911387288, 68.82171588016715, 70.48311751000124, 72.15360651737699, 73.83306899301711, 75.52139443445634, 77.21847558700273, 78.92420829470063, 80.63849136050983, 82.3612264149884, 84.09231779283351, 85.83167241669172, 87.57919968770399, 89.33481138229685, 91.09842155477399, 92.86994644530049, 94.6493043929055, 96.43641575316144, 98.2312028202244, 100.03358975294658, 101.84350250479449, 103.66086875732698, 105.4856178570068, 107.31768075513634, 109.15698995072337, 111.00347943609864, 112.85708464511787, 114.71774240379509, 116.58539088322375, 118.4599695546526, 120.34141914659247, 122.22968160383924, 124.1247000483049, 126.02641874155694, 127.93478304897255, 129.8497394054198, 131.7712352823849, 133.69921915646805, 135.6336404791771, 137.5744496479514, 139.52159797835301, 141.47503767736634, 143.43472181775027, 145.4006043133913, 147.37263989560768, 149.35078409035944, 151.33499319631972, 153.32522426376747, 155.32143507426204], [0.0, 0.39559874396917566, 0.974078367127833, 1.6501086282159543, 2.39846227969914, 3.2056485702850783, 4.063044038080632, 4.964578201616965, 5.905706872540217, 6.882879499548911, 7.893232656907186, 8.934400050848984, 10.004387937314677, 11.101489743726322, 12.224225435069355, 13.371297167889155, 14.541556045961132, 15.733976668467182, 16.947637287191792, 18.18170408992165, 19.435418577565866, 20.708087300143983, 21.999073418382526, 23.307789697208513, 24.63369263592047, 25.976277510556177, 27.335074155589098, 28.70964335028658, 30.099573703708934, 31.5044789540678, 32.923995614842866, 34.35778091298551, 35.805510974654084, 37.26687922191101, 38.741594950165265, 40.22938206123813, 41.72997793104434, 43.24313239422379, 44.768606830794916, 46.30617334215066, 47.85561400558043, 49.41672019804953, 50.989291981262156, 52.5731375411209, 54.1680726756126, 55.77392032592662, 57.39051014627291, 59.0176781084302, 60.65526613753859, 62.30312177606607, 63.96109787323687, 65.62905229751989, 67.30684767004504, 68.9943511170495, 70.69143403966069, 72.39797189950279, 74.11384401876961, 75.83893339354663, 77.57312651928612, 79.31631322744776, 81.06838653241265, 82.82924248786377, 84.59878005190143, 86.37690096022985, 88.1635096068109, 89.95851293143555, 91.76182031371098, 93.57334347300596, 95.39299637393516, 97.22069513699833, 99.05635795402303, 100.8999050080871, 102.75125839762377, 104.6103420644358, 106.4770817253664, 108.35140480739406, 110.23324038593643, 112.12251912616402, 114.01917322714014, 115.92313636861589, 117.83434366032216, 119.75273159361186, 121.67823799531516, 123.6108019836811, 125.55036392628728, 127.49686539980677, 129.4502491515298, 131.41045906254408, 133.37744011248373, 135.35113834576336, 137.33150083921805, 139.31847567107644, 141.31201189119727, 143.31205949250514, 145.3185693835648, 147.3314933622365, 149.35078409035944, 151.37639506941215, 153.4082806171035, 155.44639584484818, 157.49069663608591, 159.5411396254041], [0.0, 0.40612619817811785, 1.0000000000000002, 1.6940204031852837, 2.462288826689833, 3.290955510835594, 4.17116751094773, 5.096692801273802, 6.062866266041594, 7.066042868649025, 8.103282983463814, 9.17215734622354, 10.270619156458235, 11.396916427227689, 12.549529737646985, 13.727126706771815, 14.928527864588922, 16.152680522882754, 17.39863840438587, 18.665545507937125, 19.9526231496888, 21.259159425954447, 22.58450055024729, 23.928043660320526, 25.289230792133665, 26.667543790290527, 28.062499977480545, 29.473648444672705, 30.900566853219956, 32.34285866234961, 33.800150712639834, 35.27209110935586, 36.75834735990514, 38.25860472786817, 39.77256477258469, 41.2999440485045, 42.84047294273594, 44.3938946326572, 45.959964148264184, 47.53844752623859, 49.12912104463163, 50.73177052864818, 52.346190719345465, 53.97218469817581, 55.609563361244284, 57.258144937949474, 58.91775454935371, 60.58822380220772, 62.269390415051184, 63.96109787323687, 65.66319511009421, 67.3755362117667, 69.09798014353402, 70.8303904956705, 72.57263524710176, 74.32458654530582, 76.0861205010657, 77.85711699682363, 79.6374595075119, 81.42703493284613, 83.22573344016546, 85.03344831699121, 86.85007583255273, 88.67551510759935, 90.5096679918781, 92.35243894871331, 94.2037349461726, 96.06346535434956, 97.93154184833291, 99.80787831646774, 101.69239077354788, 103.5849972786076, 105.48561785700682, 107.39417442652977, 109.31059072723757, 111.2347922548357, 113.16670619733618, 115.10626137480953, 117.0533881820382, 119.00801853389558, 120.97008581328878, 122.93952482151381, 124.91627173088297, 126.90026403949393, 128.89144052801936, 130.88974121840317, 132.89510733435824, 134.907481263567, 136.9268065214921, 138.95302771671203, 140.9860905177, 143.02594162097125, 145.07252872052769, 147.1258004785334, 149.18570649715903, 151.2521972915363, 153.32522426376752, 155.40473967793838, 157.49069663608594, 159.58304905507487, 161.68175164433939, 163.7867598844506], [0.0, 0.4167170105874195, 1.0260776390609918, 1.7381964558215048, 2.526499505976163, 3.3767758608129457, 4.279941711761159, 5.229602516550174, 6.220971504202488, 7.250308584167148, 8.314597472315658, 9.41134555490898, 10.538452655753257, 11.694121100225217, 12.876791844530523, 14.085097762375508, 15.317828625953627, 16.573904295425997, 17.85235381684815, 19.15229886656962, 20.472940454506368, 21.81354811220456, 23.173451003969408, 24.552030546330013, 25.94871422486104, 27.36297037189691, 28.794303723042365, 30.242251610623434, 31.70638068239827, 33.186284056747034, 34.68157884313118, 36.191903970232055, 37.716918274835294, 39.25629881293866, 40.80973936125406, 42.37694908264055, 43.95765133333879, 45.551582593399324, 47.15849150457873, 48.77813800234773, 50.4102925306173, 52.054735329419316, 53.711255787142385, 55.37965185006801, 57.05972948291815, 58.75130217494326, 60.45419048677585, 62.16822163386827, 63.89322910284286, 65.62905229751989, 67.3755362117667, 69.13253112663793, 70.89989232956066, 72.67747985356569, 74.46515823478067, 76.26279628659172, 78.0702668890436, 79.8874467921962, 81.71421643228314, 83.55045975963164, 85.39606407740438, 87.25091989031318, 89.11492076253379, 90.98796318412283, 92.86994644530049, 94.76077251802012, 96.66034594429621, 98.56857373080835, 100.48536524934013, 102.41063214264794, 104.34428823538977, 106.28624944977292, 108.23643372560753, 110.19476094447799, 112.16115285776624, 114.13553301828168, 116.11782671527159, 118.10796091260197, 120.10586418991554, 122.1114666865863, 124.1247000483049, 126.14549737613906, 128.1737931779257, 130.2095233218604, 132.2526249921603, 134.30303664668327, 136.3606979763954, 138.4255498665858, 140.49753435973378, 142.57659461994038, 144.66267489884086, 146.75572050292138, 148.85567776216695, 150.96249399997203, 153.07611750425096, 155.19649749968687, 157.32358412106362, 159.457328387627, 161.5976821784259, 163.74459820858561, 165.89803000646936, 168.0579318916866], [0.0, 0.42737030889876065, 1.0523091364604007, 1.7826331476222053, 2.591089028930071, 3.4631025517369998, 4.389357681477083, 5.3632964005123736, 6.380009564893122, 7.435661469300227, 8.527158718823063, 9.651944976483412, 10.807866375446212, 11.993079283847322, 13.205984801207414, 14.44518085088555, 15.709426265810595, 16.99761329255548, 18.308746154906054, 19.641924075019624, 20.996327636768818, 22.371207697400106, 23.76587627142017, 25.17969896137865, 26.612088616617946, 28.06249997748054, 29.53042511822256, 31.01538954315096, 32.51694882144877, 34.03468566963791, 35.568207408649414, 37.117143736438834, 38.68114476801321, 40.259879303362744, 41.85303329065394, 43.46030845754463, 45.08142108792561, 46.716100925005506, 48.364090184610845, 50.025142665004196, 51.6990229415348, 53.38550563610896, 55.084374752865855, 56.795423072618625, 58.5184515996109, 60.25326905497806, 61.99969141201623, 63.757541468970686, 65.52664845557806, 67.30684767004504, 69.09798014353402, 70.89989232956066, 72.71243581600018, 74.53546705765199, 76.36884712753327, 78.21244148526706, 80.06611976109842, 81.92975555422386, 83.80322624424997, 85.68641281471417, 87.57919968770398, 89.48147456870312, 91.39312830087385, 93.31405472805906, 95.2441505658508, 97.18331528013236, 99.13145097255133, 101.08846227242918, 103.05425623465479, 105.02874224314688, 107.01183191950577, 109.00343903650449, 111.00347943609864, 113.01187095165918, 115.02853333415563, 117.05338818203819, 119.08635887458668, 121.12737050851098, 123.17634983760466, 125.233225215267, 127.29792653972245, 129.37038520177916, 131.45053403497818, 133.53830726799666, 135.6336404791771, 137.73647055306313, 139.84673563883078, 141.96437511051187, 144.08932952891166, 146.2215406051313, 148.36095116560872, 150.5075051185999, 152.66114742202515, 154.82182405261062, 156.98948197626018, 159.1640691195947, 161.34553434260243, 163.53382741234466, 165.72889897766652, 167.93070054486356, 170.13918445425972, 172.35430385765318], [0.0, 0.4380852494193666, 1.0786924147829349, 1.8273269594034942, 2.656052280355095, 3.549928746926453, 4.499406754848329, 5.497763865212836, 6.539967853022401, 7.622086844942752, 8.740949889102044, 9.893936556566905, 11.0788389791958, 12.293767301965532, 13.537082537092674, 14.807347455359002, 16.103289771407752, 17.423773958445672, 18.7677792743621, 20.134382357197456, 21.522743246591695, 22.93209401743819, 24.36172943521277, 25.81099919698264, 27.27930143116961, 28.766077207478144, 30.27080586555454, 31.793001013247284, 33.33220707706134, 34.88799631147306, 36.45996619224459, 38.04773713319475, 39.65095047708598, 41.26926672012991, 42.902363936650055, 44.54993637608141, 46.211693209042814, 47.88735740292015, 49.57666471042819, 51.279362757110135, 52.99521021579678, 54.72397605776122, 56.465438871738804, 58.21938624318582, 59.985614187165204, 61.763926629107985, 63.554134928430585, 65.35605744061232, 67.16951911387288, 68.9943511170495, 70.8303904956705, 72.67747985356569, 74.53546705765199, 76.40420496379303, 78.28355116185732, 80.17336773829915, 82.07352105475991, 83.98388154134116, 85.9043235033362, 87.83472494032617, 89.77496737665291, 91.72493570237512, 93.6845180238973, 95.65360552353694, 97.63209232736068, 99.61987538068111, 101.61685433065846, 103.6229314155001, 105.63801135979425, 107.66200127555187, 109.69481056856819, 111.73635084974494, 113.78653585104453, 115.84528134577309, 117.91250507291295, 119.98812666524678, 122.07206758103545, 124.16425103902894, 126.26460195660701, 128.37304689086005, 130.48951398243528, 132.61393290198527, 134.7462347990674, 136.88635225335372, 139.0342192280202, 141.18977102519273, 143.3529442433362, 145.5236767364806, 147.70190757518398, 149.88757700914013, 152.0806264313432, 154.28099834372853, 156.48863632421265, 158.70348499506142, 160.92548999251864, 163.15459793763213, 165.39075640821838, 167.63391391190868, 169.88401986022615, 172.1410245436422, 174.40487910756718, 176.6755355292307], [0.0, 0.44886101560022645, 1.1052254634490883, 1.8722744852026663, 2.721384309623782, 3.6372478296536, 4.610080545410984, 5.632994663345468, 6.700834178715663, 7.809570504253743, 8.955954690857903, 10.137301853807871, 11.351349817105634, 12.596162240173248, 13.870059820359002, 15.171569976316233, 16.499389127752917, 17.85235381684815, 19.229418193870476, 20.62963618453985, 22.05214716763981, 23.496164329088554, 24.96096508741325, 26.445883143907768, 27.950301822506876, 29.4736484446727, 31.01538954315096, 32.57502676179888, 34.15209332118956, 35.746150954363706, 37.356787236026385, 38.98361324315629, 40.62626149647372, 42.28438414127356, 43.95765133333879, 45.645749801429794, 47.34838156251345, 49.06526276968854, 50.79612267586875, 52.54070269883721, 54.29875557539934, 56.070044594117974, 57.854342897582946, 59.65143284640114, 61.46110543813264, 63.28315977528027, 65.11740257718907, 66.9636477313521, 68.82171588016715, 70.69143403966069, 72.57263524710176, 74.46515823478067, 76.36884712753327, 78.28355116185732, 80.20912442469967, 82.14542561019748, 84.0923177928335, 86.04966821562428, 88.01734809209783, 89.99523242093994, 91.98319981229713, 93.98113232482069, 95.98891531262153, 98.0064372813831, 100.03358975294657, 102.07026713774529, 104.11636661451867, 106.17178801678641, 108.23643372560751, 110.31020856818824, 112.39301972194023, 114.48477662362161, 116.58539088322375, 118.69477620229358, 120.81284829640472, 122.93952482151381, 125.07472530395766, 127.21837107386574, 129.3703852017792, 131.53069243828241, 133.69921915646805, 135.87589329706827, 138.06064431609735, 140.25340313486132, 142.45410209220077, 144.66267489884086, 146.8790565937324, 149.10318350227502, 151.33499319631972, 153.574424455857, 155.82141723230006, 158.07591261328017, 160.33785278887638, 162.60718101920511, 164.88384160330222, 167.16777984923112, 169.45894204535782, 171.75727543273433, 174.06272817853784, 176.37524935051366, 178.69478889237536, 181.02129760011644], [0.0, 0.45969681667478385, 1.1319063353632046, 1.9174724265999525, 2.7870803224242535, 3.7250533921132596, 4.7213709315029035, 5.7689788711618535, 6.8625967369923355, 7.998098688971822, 9.172157346223539, 10.382023009138582, 11.625378891297766, 12.900241907583998, 14.204892215871554, 15.537821685728456, 16.89769526757433, 18.283321416948827, 19.69362903661792, 21.127649213444233, 22.584500550247288, 24.063377238734223, 25.563539253838687, 27.084304211964163, 28.625040550078324, 30.18516176480553, 31.76412151064001, 33.36140940079289, 34.97654738747391, 36.60908662367022, 38.25860472786816, 39.92470338818806, 41.607006254157945, 43.305157073630625, 45.01881803973201, 46.74766831864812, 48.49140273383876, 50.24973058615124, 52.02237459248597, 53.80906992828072, 55.60956336124428, 57.42361246556918, 59.25098490735771, 61.0914577932582, 62.94481707537394, 64.8108570064096, 66.68937963978773, 68.58019437012261, 70.48311751000124, 72.39797189950279, 74.32458654530582, 76.26279628659172, 78.21244148526706, 80.17336773829915, 82.14542561019748, 84.12847038388243, 86.12236182836445, 88.1269639818189, 90.1421449487834, 92.16777671032949, 94.20373494617257, 96.24989886778197, 98.30615106164116, 100.37237734188724, 102.44846661162707, 104.53431073229216, 106.62980440044886, 108.73484503153196, 110.8493326500148, 112.97316978556962, 115.10626137480952, 117.24851466823623, 119.39983914204798, 121.56014641449009, 123.72935016645455, 125.90736606605842, 128.09411169695122, 130.28950649011983, 132.49347165897748, 134.70593013753805, 136.92680652149207, 139.1560270120134, 141.393519362138, 143.6392128255666, 145.8930381077548, 148.1549273191609, 150.42481393053316, 152.70263273012432, 154.98831978272864, 157.28181239044528, 159.58304905507484, 161.89196944206518, 164.20851434592572, 166.5326256570347, 168.86424632976988, 171.20332035189526, 173.54979271514256, 175.903609386928, 178.2647172831502, 180.63306424201625, 183.00859899884796, 185.39127116182158], [0.0, 0.4705918863894838, 1.158733143787717, 1.9629175874234195, 2.853135673063679, 3.8133392251360396, 4.8332700432256495, 5.905706872540217, 7.025244088814873, 8.187658067328464, 9.389542566430535, 10.628082717105206, 11.9009068238092, 13.205984801207414, 14.541556045961133, 15.906076684110033, 17.298180024657654, 18.716646282878557, 20.160378975939746, 21.628386226924682, 23.119765749050483, 24.63369263592047, 26.16940932346347, 27.72621725521295, 29.303469899742176, 30.900566853219953, 32.516948821448764, 34.152093321189554, 35.805510974654084, 37.47674229690616, 39.1653548957558, 40.870941019110695, 42.5931153967838, 44.33151333325429, 46.08578901543766, 47.85561400558043, 49.640675894289046, 51.44067709267953, 53.25533374588891, 55.08437475286586, 56.92754087957329, 58.78458395457755, 60.65526613753858, 62.539359252408566, 64.43664417823683, 66.34691029140295, 68.26995495388569, 70.20558304284593, 72.15360651737699, 74.11384401876961, 76.0861205010657, 78.0702668890436, 80.06611976109842, 82.07352105475991, 84.0923177928335, 86.12236182836445, 88.16350960681092, 90.21562194397755, 92.27856381840628, 94.35220417704905, 96.43641575316144, 98.53107489545756, 100.63606140765543, 102.75125839762377, 104.87655213541142, 107.01183191950578, 109.15698995072339, 111.3119212131879, 113.47652336189716, 115.65069661642256, 117.83434366032216, 120.02736954588309, 122.22968160383924, 124.44118935773928, 126.66180444266445, 128.89144052801933, 131.13001324414026, 133.3774401124837, 135.63364047917713, 137.8985354517277, 140.172047838702, 142.45410209220077, 144.74462425296673, 147.04354189797417, 149.3507840903594, 151.666281331561, 153.98996551554703, 156.32176988501553, 158.66162898946098, 161.00947864500748, 163.36525589591415, 165.7288989776665, 168.10034728157092, 170.47954132077538, 172.8664226976447, 175.26093407242186, 177.66301913311207, 180.07262256652928, 182.4896900304495, 184.91416812681635, 187.34600437595026, 189.78514719171338], [0.0, 0.4815454818184454, 1.18570405942453, 2.00860686880477, 2.919545857281798, 3.902099308583291, 4.945770250270436, 6.043169344110126, 7.18876514339356, 8.3782357134249, 9.60809552815876, 10.875464199097776, 12.177914826615869, 13.513370072685982, 14.880028353796886, 16.27630986045422, 17.700816090275296, 19.15229886656962, 20.62963618453985, 22.131813080134346, 23.657906264753862, 25.207071631307446, 26.778533982503745, 28.371578502129434, 29.985543609956707, 31.619814927028894, 33.27382014089946, 34.94702460689991, 36.63892755638198, 38.34905880934176, 40.07697590913797, 41.82226161275511, 43.58452168237647, 45.3633829337518, 47.15849150457872, 48.96951131231774, 50.79612267586875, 52.63802107960649, 54.4949160616027, 56.366530210601105, 58.25259825857883, 60.152866257611876, 62.067090831338575, 63.995038492637555, 65.93648502025296, 67.8912148880448, 69.85902074134677, 71.83970291559962, 73.83306899301711, 75.83893339354663, 77.85711699682363, 79.8874467921962, 81.92975555422386, 83.98388154134116, 86.04966821562428, 88.1269639818189, 90.21562194397755, 92.31549967822436, 94.4264590203135, 96.54836586677867, 98.68108998858803, 100.82450485632243, 102.97848747598603, 105.14291823464178, 107.31768075513631, 109.50266175924546, 111.69775093862931, 113.90284083303996, 116.11782671527158, 118.3426064823853, 120.57708055278134, 122.82115176872391, 125.07472530395766, 127.33770857608239, 129.61001116337897, 131.89154472580293, 134.1822229298846, 136.48196137729263, 138.790677536838, 141.10829067970968, 143.43472181775024, 145.7698936445917, 148.11373047948558, 150.46615821367266, 152.82710425914792, 155.19649749968684, 157.57426824400721, 159.96034818095012, 162.35467033657036, 164.75716903303467, 167.16777984923112, 169.58643958300144, 172.0130862149114, 174.44765887348046, 176.89009780179794, 179.34034432545448, 181.7983408217256, 184.26403068994387, 186.7373583230043, 189.21826907994614, 191.70670925956188, 194.20262607498384], [0.0, 0.49255688225530236, 1.2128173076864104, 2.0545372645570232, 2.9863065055322933, 3.99132780236738, 5.0588641505366505, 6.181357241345601, 7.353149141643325, 8.56981908795167, 9.827801851425685, 11.124151178322965, 12.456384673608145, 13.822377497197309, 15.220286869143559, 16.64849685477721, 18.105576972452294, 19.59025050368138, 21.10136978701665, 22.637896649434474, 24.198886689687114, 25.783476498662242, 27.390873152793173, 29.020345490312817, 30.671216802775817, 32.342858662349606, 34.0346856696379, 35.7461509543637, 37.47674229690616, 39.225978765752956, 40.99340778669875, 42.77860257571874, 44.581159880042016, 46.40069798189164, 48.236854927269526, 50.08928694850661, 51.95766705442151, 53.84168376609348, 55.74103997966171, 57.65545194036438, 59.58464831434989, 61.528369346719856, 63.48636609587592, 65.45839973559525, 67.44424091740113, 69.44366918676215, 71.45647244747592, 73.48244646929524, 75.52139443445634, 77.57312651928612, 79.6374595075119, 81.71421643228314, 83.80322624424997, 85.9043235033362, 88.01734809209783, 90.1421449487834, 92.27856381840628, 94.4264590203135, 96.58568923088612, 98.75611728014172, 100.9376099611283, 103.13003785110479, 105.33327514359716, 107.54719949050424, 109.77169185350047, 112.00663636405206, 114.25192019142125, 116.50743341808898, 118.77306892207415, 121.04872226567124, 123.33429159016869, 125.629677516145, 127.93478304897252, 130.2495134891886, 132.57377634741934, 134.90748126356698, 137.25053992999227, 139.60286601844473, 141.96437511051184, 144.33498463137366, 146.71461378666692, 149.103183502275, 151.50061636687352, 153.90683657707362, 156.3217698850155, 158.7453435482747, 161.1774862819529, 163.6181282128342, 166.06720083549405, 168.5246369702578, 170.99037072290943, 173.46433744606006, 175.94647370208983, 178.43671722758282, 180.93500689917943, 183.44128270077482, 185.95548569199758, 188.47755797790467, 191.00744267983495, 193.54508390736422, 196.09042673131054, 198.64341715773992], [0.0, 0.5036253881759386, 1.2400711661429435, 2.1007058568479136, 3.053413376694001, 4.08101903804644, 5.172544559478509, 6.320261785547947, 7.518385640698911, 8.762396020141624, 10.04864757889024, 11.37412785637799, 12.736298674359213, 14.132987444345906, 15.562309976309441, 17.022614023058463, 18.512436957838208, 20.03047337234562, 21.575549815426182, 23.146604784721767, 24.742672656845276, 26.362870620562074, 28.006387934101102, 29.672477005372933, 31.36044591925922, 33.06965212619358, 34.799497071960616, 36.54942159727243, 38.31890197215045, 40.10744645781628, 41.914592310030514, 43.73990315427906, 45.582966676084936, 47.4433925798894, 49.32081077803484, 51.214869777867285, 53.12523524021377, 55.051588686746165, 56.99362633722583, 58.95105806048781, 60.92360642539416, 62.91100583995695, 64.91300176847965, 66.92935001794919, 68.95981608607809, 71.00417456438467, 73.06220859054076, 75.13370934493335, 77.21847558700273, 79.31631322744776, 81.42703493284613, 83.55045975963164, 85.68641281471417, 87.83472494032617, 89.99523242093994, 92.16777671032949, 94.35220417704905, 96.54836586677867, 98.75611728014172, 100.97531816473668, 103.20583232024772, 105.44752741560698, 107.7002748172767, 109.96394942780691, 112.23842953389891, 114.5235966632759, 116.819335449721, 119.12553350570049, 121.44208130203864, 123.76887205415511, 126.1058016144174, 128.45276837019654, 130.8096731472473, 133.17641911806544, 135.5529117148995, 137.93905854712213, 140.33476932268653, 142.7399557734145, 145.15453158388272, 147.5784123236889, 150.01151538289693, 152.45375991047393, 154.90506675554482, 157.36535841130265, 159.8345589614248, 162.31259402885328, 164.79939072680924, 167.29487761191882, 169.79898463933586, 172.3116431197558, 174.83278567821878, 177.36234621461034, 179.9002598657704, 182.44646296912887, 185.00089302779088, 187.56348867699793, 190.13418965189848, 192.71293675656156, 195.29967183417563, 197.8943377383732, 200.49687830562968, 203.1072383286849], [0.0, 0.514750320266457, 1.2674639621271098, 2.1471098121453833, 3.1208623521776078, 4.171167510947728, 5.286804500121684, 6.45987445164721, 7.684464499403873, 8.9559546908579, 10.270619156458231, 11.625378891297764, 13.017639649543145, 14.44518085088555, 15.906076684110033, 17.398638404385867, 18.921371075976836, 20.472940454506368, 22.05214716763981, 23.657906264753862, 25.289230792133658, 26.945218437512114, 28.62504055007832, 30.32793302366032, 32.053188658944634, 33.800150712639834, 35.568207408649414, 37.35678723602639, 39.1653548957558, 40.993407786698754, 42.840472942735936, 44.70610434997258, 46.58988058602994, 48.491402733838754, 50.4102925306173, 52.34619071934546, 54.29875557539934, 56.26766158536112, 58.25259825857883, 60.25326905497806, 62.26939041505117, 64.30069087996375, 66.34691029140293, 68.40779906220607, 70.48311751000124, 72.57263524710174, 74.6761306207564, 76.79339019859025, 78.92420829470063, 81.06838653241265, 83.22573344016546, 85.39606407740438, 87.57919968770398, 89.77496737665291, 91.98319981229713, 94.20373494617257, 96.43641575316144, 98.68108998858803, 100.9376099611283, 103.20583232024772, 105.48561785700679, 107.77683131718449, 110.07934122576721, 112.39301972194023, 114.71774240379506, 117.05338818203819, 119.39983914204798, 121.75698041368422, 124.12470004830489, 126.50288890249062, 128.89144052801933, 131.29025106766986, 133.69921915646805, 136.11824582801935, 138.5472344255994, 140.98609051769998, 143.43472181775024, 145.8930381077548, 148.36095116560872, 150.8383746958678, 153.32522426376747, 155.82141723230004, 158.32687270217158, 160.84151145447336, 163.36525589591412, 165.89803000646933, 168.43975928931323, 170.99037072290946, 173.54979271514253, 176.1179550593819, 178.69478889237536, 181.2802266538769, 183.87420204791894, 186.47665000564453, 189.08750664962128, 191.70670925956188, 194.33419623938244, 196.96990708553182, 199.61378235653217, 202.26576364367008, 204.92579354278573, 207.5938156271073], [0.0, 0.5259310185112551, 1.294994070489867, 2.1937463774137957, 3.188649430396785, 4.261767872778044, 5.401637193697287, 6.600186956757962, 7.851375864696903, 9.150483616727696, 10.493703415087076, 11.877889376959557, 13.30039090787305, 14.758939195128415, 16.2515665976891, 17.776547690132592, 19.332355065785407, 20.917625499650327, 22.531133568276978, 24.171770755237343, 25.838528669565846, 27.530485400209766, 29.246794297545378, 30.98667465853773, 32.74940392306285, 34.5343110829551, 36.340771073959324, 38.16819997155404, 40.01605084969557, 41.88381019043457, 43.77099475453243, 45.67714884039419, 47.601841872084, 49.54466626780486, 51.50523554867133, 53.48318265437659, 55.478158437824625, 57.489830315243, 59.517881051928974, 61.56200766677266, 63.62192044117689, 65.69734202005196, 67.78800659428407, 69.89365915552159, 72.0140548153419, 74.14895818189395, 76.29814278799043, 78.461390565372, 80.63849136050983, 82.82924248786377, 85.03344831699121, 87.25091989031318, 89.48147456870312, 91.72493570237512, 93.98113232482069, 96.24989886778197, 98.53107489545756, 100.82450485632243, 103.13003785110479, 105.44752741560698, 107.77683131718449, 110.11781136381016, 112.47033322475106, 114.83426626197576, 117.20948337148863, 119.59586083386118, 121.99327817329257, 124.40161802459143, 126.82076600752137, 129.25061060799985, 131.69104306568295, 134.14195726750583, 136.60324964678384, 139.07481908751055, 141.55656683351725, 144.04839640218438, 146.5502135024192, 149.06192595663512, 151.58344362648813, 154.11467834214295, 156.65554383485932, 159.20595567270217, 161.76583119919442, 164.3350894747431, 166.91365122068237, 169.50143876578522, 172.09837599510834, 174.7043883010421, 177.31940253644547, 179.94334696975616, 182.57615124196911, 185.21774632538762, 187.86806448405426, 190.52703923577593, 193.19460531566256, 195.870698641103, 198.55525627810798, 201.24821640895152, 203.94951830104972, 206.65910227701548, 209.3769096858348, 212.1028828751111], [0.0, 0.5371668413365648, 1.3226599114912936, 2.2406128765414923, 3.2567707215755752, 4.3528149246835905, 5.5170360508454825, 6.741191249431118, 8.019110158826123, 9.345971635241005, 10.717887553697151, 12.131644823740245, 13.58453622444183, 15.074244472910642, 16.598759892053515, 18.15632019500858, 19.745365344072493, 21.36450299074324, 23.012481532014032, 24.688168769464824, 26.39053476918652, 28.118637924712203, 29.871613498865152, 31.64866410991935, 33.449051761206405, 35.27209110935586, 37.11714373643884, 38.9836132431563, 40.8709410191107, 42.77860257571875, 44.706104349972584, 46.65298090481346, 48.61879246561834, 50.603122743142485, 52.6055770018886, 54.62578033979033, 56.66337615068427, 58.718024745584174, 60.789402112486115, 62.877198797488234, 64.98111889253751, 67.10087911721841, 69.23620798375583, 71.38684503588095, 73.55254015345284, 75.7330529157839, 77.92815201751392, 80.13761473164274, 82.3612264149884, 84.59878005190143, 86.85007583255273, 89.11492076253379, 91.39312830087385, 93.6845180238973, 95.98891531262153, 98.30615106164116, 100.63606140765543, 102.97848747598603, 105.33327514359716, 107.7002748172767, 110.07934122576721, 112.47033322475106, 114.8731136136963, 117.2875489636622, 119.71350945524385, 122.15086872591023, 124.59950372605391, 127.05929458313092, 129.5301244733219, 132.01187950019298, 134.50444857987887, 137.007723332349, 139.52159797835301, 142.04596924167438, 144.58073625634904, 147.1258004785334, 149.68106560272986, 152.24643748209925, 154.82182405261065, 157.40713526079654, 160.0022829948987, 162.60718101920511, 165.22174491139202, 167.8458920026988, 170.47954132077538, 173.1226135350514, 175.7750309044882, 178.43671722758288, 181.10759779450217, 183.78759934123354, 186.47665000564456, 189.17467928535274, 191.88161799731128, 194.59739823902265, 197.32195335129845, 200.05521788248706, 202.79712755409744, 205.54761922774946, 208.30663087338758, 211.07410153869603, 213.8499713196592, 216.63418133221316], [0.0, 0.5484571648052401, 1.3504599488179267, 2.2877067069821218, 3.3252224428665045, 4.444303610725109, 5.632994663345469, 6.882879499548913, 8.187658067328465, 9.542407890741039, 10.943159123105717, 12.386631140331012, 13.870059820359003, 15.391079174996092, 16.947637287191796, 18.537934829844257, 20.160378975939746, 21.81354811220456, 23.496164329088554, 25.20707163130745, 26.945218437512114, 28.709643350286584, 30.499463457165394, 32.31386461682957, 34.15209332118956, 36.01344982213556, 37.897282283291446, 39.80298177007026, 41.729977931044345, 43.677735253782096, 45.6457498014298, 47.63354635424196, 49.64067589428905, 51.66671338264213, 53.71125578714239, 55.77392032592662, 57.85434289758295, 59.952176673446665, 62.06709083133859, 64.19876941316787, 66.34691029140295, 68.51122423156102, 70.6914340396607, 72.88727378509019, 75.0984880906132, 77.32483148231267, 79.56606779318737, 81.82196961489852, 84.09231779283351, 86.37690096022985, 88.67551510759935, 90.98796318412283, 93.31405472805906, 95.65360552353694, 98.0064372813831, 100.37237734188724, 102.75125839762377, 105.14291823464178, 107.54719949050424, 109.96394942780691, 112.39301972194023, 114.83426626197576, 117.2875489636622, 119.75273159361188, 122.22968160383924, 124.71826997589008, 127.21837107386577, 129.7298625057076, 132.25262499216032, 134.78654224288286, 137.33150083921805, 139.88739012317347, 142.45410209220077, 145.03153129939489, 147.61957475876255, 150.2181318552381, 152.82710425914794, 155.44639584484818, 158.0759126132802, 160.71556261820749, 163.36525589591415, 166.02490439816177, 168.6944219282144, 171.37372407975636, 174.06272817853784, 176.7613532265964, 179.4695198489103, 182.18715024235212, 184.91416812681635, 187.65049869840684, 190.3960685845727, 193.1508058010926, 195.91463971081103, 198.68750098403666, 201.4693215605196, 204.26003461292706, 207.0595745117446, 209.86787679153187, 212.68487811846825, 215.51051625912507, 218.3447300504073, 221.1874593706092], [0.0, 0.5598013818589584, 1.3783926877168415, 2.3350253365937306, 3.394000913756147, 4.536229011737225, 5.749506796332408, 7.025244088814873, 8.357010527716843, 9.73978182123955, 11.169506010906831, 12.642834616622837, 14.156946343586544, 15.709426265810595, 17.298180024657654, 18.921371075976836, 20.577373646926485, 22.264736719767832, 23.982155952834898, 25.72845144038647, 27.502549850300813, 29.303469899742172, 31.130310414197847, 32.98224041275514, 34.858490801860626, 36.75834735990512, 38.68114476801321, 40.62626149647371, 42.593115396783794, 44.58115988004201, 46.589880586029935, 48.61879246561833, 50.6674372134489, 52.73538099914246, 54.822212454275174, 56.927540879573286, 59.05099464259842, 61.19221974092662, 63.350878509695534, 65.52664845557804, 67.71922120187583, 69.92830153161741, 72.15360651737697, 74.39486472806834, 76.6518155042655, 78.92420829470063, 81.21180204752483, 83.5143646507146, 85.83167241669172, 88.1635096068109, 90.5096679918781, 92.86994644530049, 95.2441505658508, 97.63209232736068, 100.03358975294657, 102.44846661162707, 104.87655213541142, 107.31768075513631, 109.77169185350047, 112.23842953389891, 114.71774240379506, 117.20948337148863, 119.71350945524385, 122.22968160383924, 124.75786452768384, 127.29792653972245, 129.8497394054198, 132.41317820117555, 134.98812118057793, 137.5744496479514, 140.17204783870199, 142.78080280600162, 145.40060431339126, 148.03134473291564, 150.67291894843262, 153.32522426376747, 155.98816031540835, 158.66162898946095, 161.3455343426024, 164.039782526792, 166.74428171751606, 169.45894204535776, 172.18367553069908, 174.91839602137486, 177.66301913311202, 180.4174621925966, 183.1816441830242, 185.95548569199755, 188.7389088616434, 191.53183734083143, 194.33419623938238, 197.1459120841626, 199.96691277696684, 202.7971275540974, 205.63648694755489, 208.48492274775867, 211.34236796772197, 214.20875680860954, 217.08402462661223, 219.96810790107318, 222.8609442038078, 225.7624721695608], [0.0, 0.571198901604346, 1.4064566732378863, 2.3825663006610767, 3.463102551737, 4.628586339543717, 5.866566380965497, 7.168277601795033, 8.527158718823063, 9.938083145996398, 11.396916427227687, 12.900241907583998, 14.445180850885551, 16.02926916340887, 17.650369845510898, 19.306608961121224, 20.996327636768818, 22.718045312088073, 24.47043108910147, 26.252281039263615, 28.06249997748054, 29.900086642061737, 31.764121510640013, 33.65375668358529, 35.56820740864942, 37.506744922717665, 39.46869036106554, 41.45340953967737, 43.460308457544635, 45.488829397251386, 47.538447526238585, 49.60866791980826, 51.69902294153481, 53.80906992828072, 55.9383891361878, 58.08658191137047, 60.25326905497807, 62.43808935712029, 64.64069827810015, 66.86076675864734, 69.09798014353402, 71.35203720519034, 73.62264925580654, 75.9095393379771, 78.21244148526708, 80.53110004520113, 82.86526905813035, 85.21471168624556, 87.57919968770399, 89.95851293143555, 92.35243894871331, 94.76077251802012, 97.18331528013236, 99.61987538068111, 102.07026713774529, 104.53431073229216, 107.01183191950578, 109.50266175924546, 112.00663636405206, 114.5235966632759, 117.05338818203819, 119.59586083386118, 122.15086872591023, 124.71826997589008, 127.29792653972245, 129.8897040492123, 132.4934716589775, 135.1091019019814, 137.73647055306313, 140.37545649991094, 143.02594162097125, 145.68781066982592, 148.36095116560875, 151.04525328906632, 153.74060978389866, 156.44691586304359, 159.1640691195947, 161.8919694420652, 164.63051893373233, 167.37962183581547, 170.13918445425972, 172.90911508991283, 175.68932397189744, 178.47972319399597, 181.28022665387692, 184.09074999500314, 186.91121055107328, 189.7415272928589, 192.58162077730543, 195.43141309877856, 198.2908278423398, 201.15979003894734, 204.03822612248106, 206.92606388849904, 209.82323245463797, 212.72966222257455, 215.64528484147127, 218.57003317283292, 221.50384125670658, 224.44664427915896, 227.3983785409717, 230.35898142749684], [0.0, 0.5826491486398413, 1.4346504885762246, 2.43032719908786, 3.5325238682263476, 4.721370931502903, 5.984167507514434, 7.3119728174703855, 8.698094050748882, 10.137301853807871, 11.625378891297766, 13.158840018057608, 14.734748790793136, 16.350591720584603, 18.004188969517106, 19.69362903661792, 21.41721979465628, 23.173451003969408, 24.96096508741325, 26.778533982503745, 28.625040550078324, 30.499463457165394, 32.400864748662286, 34.32837952795207, 36.281207311651464, 38.25860472786817, 40.25987930336275, 42.28438414127357, 44.3315133332543, 46.400697981891646, 48.49140273383876, 50.603122743142485, 52.73538099914247, 54.88772596508071, 57.05972948291816, 59.25098490735772, 61.46110543813265, 63.68972262454308, 65.93648502025296, 68.2010569696734, 70.48311751000124, 72.78235937526202, 75.0984880906132, 77.43122114676414, 79.78028724571962, 82.14542561019749, 84.52638535004438, 86.92292487980293, 89.33481138229685, 91.76182031371098, 94.2037349461726, 96.66034594429621, 99.13145097255133, 101.61685433065846, 104.11636661451867, 106.62980440044886, 109.15698995072339, 111.69775093862931, 114.25192019142125, 116.819335449721, 119.39983914204798, 121.99327817329257, 124.59950372605391, 127.21837107386577, 129.8497394054198, 132.4934716589775, 135.14943436623167, 137.81749750494282, 140.49753435973378, 143.18942139047678, 145.89303810775482, 148.60826695492128, 151.33499319631972, 154.0731048112612, 156.82249239338708, 159.58304905507484, 162.3546703365704, 165.1372541195531, 167.93070054486356, 170.73491193414168, 173.54979271514256, 176.37524935051366, 179.21119026983166, 182.05752580471184, 184.91416812681635, 187.7810311885977, 190.65803066662684, 193.54508390736427, 196.4421098752408, 199.34902910292655, 202.2657636436701, 205.19223702560097, 208.12837420789342, 211.07410153869603, 214.02934671473844, 216.99403874253005, 219.96810790107324, 222.95148570601526, 225.94410487517067, 228.94589929534672, 231.9568039904113, 234.9767550905438], [0.0, 0.5941515624203891, 1.4629727535080308, 2.4783056937467585, 3.602261464714483, 4.814578245359576, 6.102304418834438, 7.4563227012640905, 8.869808155381822, 10.337428191953247, 11.854882218772824, 13.418616288413563, 15.025635987556027, 16.673378207042198, 18.35962007551632, 20.082412355959583, 21.840029515879014, 23.630931501097315, 25.45373393375496, 27.307184507476226, 29.190144029008295, 31.101571002654776, 33.04050895659891, 35.00607591979949, 36.99745560606786, 39.01388996817732, 41.05467286237376, 43.11914462103051, 45.20668737421418, 47.31672099357867, 49.44869955705712, 51.60210825224046, 53.776460651525056, 55.97129630410465, 58.186178599424714, 60.42069286436823, 62.67444466262069, 64.94705826968388, 67.23817530111641, 69.5474534749583, 71.87456549209406, 74.21919802063398, 76.58105077233735, 78.95983566073426, 81.35527603197885, 83.76710596063384, 86.19506960357829, 88.63892060607662, 91.09842155477399, 93.57334347300596, 96.06346535434956, 98.56857373080835, 101.08846227242918, 103.6229314155001, 106.17178801678641, 108.73484503153196, 111.3119212131879, 113.90284083303996, 116.50743341808898, 119.12553350570049, 121.75698041368422, 124.40161802459143, 127.05929458313092, 129.7298625057076, 132.41317820117555, 135.1091019019814, 137.81749750494282, 140.53823242097607, 143.27117743314253, 146.01620656243725, 148.773196940792, 151.5420286908064, 154.32258481176112, 157.11475107150198, 159.9184159038161, 162.7334703109507, 165.5598077709512, 168.39732414952016, 171.24591761612078, 174.10548856406794, 176.97593953436981, 179.8571751430989, 182.7491020120872, 185.65162870275455, 188.56466565289304, 191.48812511624084, 194.42192110469136, 197.36596933299367, 200.32018716580862, 203.28449356699585, 206.25880905101198, 209.24305563631114, 212.23715680064325, 215.24103743815309, 218.25462381818963, 221.27784354573873, 224.31062552340026, 227.3528999148322, 230.4045981095926, 233.46565268930996, 236.53599739512075, 239.61556709631333], [0.0, 0.6057055966573057, 1.4914221229127824, 2.526499505976163, 3.6723120291261746, 4.908203854381941, 6.220971504202489, 7.601320397510068, 9.042292877436047, 10.538452655753256, 12.085415509760624, 13.679558380994784, 15.317828625953627, 16.99761329255548, 18.716646282878557, 20.472940454506368, 22.264736719767836, 24.090465076169746, 25.948714224861035, 27.83820750677273, 29.75778357558759, 31.706380682398265, 33.683023755574716, 35.68681367302498, 37.71691827483529, 39.77256477258468, 41.85303329065394, 43.95765133333879, 46.08578901543766, 48.236854927269526, 50.41029253061729, 52.60557700188859, 54.82221245427518, 57.059729482918144, 59.31768298681439, 61.59565022899971, 63.89322910284285, 66.21003657740397, 68.54570729899953, 70.89989232956066, 73.27225800522355, 75.66248490096058, 78.0702668890436, 80.49531028079414, 82.93733304247982, 85.39606407740438, 87.87124256725134, 90.3626173666034, 92.86994644530049, 95.39299637393516, 97.93154184833291, 100.48536524934013, 103.05425623465479, 105.63801135979425, 108.23643372560751, 110.8493326500148, 113.47652336189716, 116.11782671527158, 118.77306892207415, 121.44208130203864, 124.12470004830489, 126.82076600752137, 129.5301244733219, 132.25262499216032, 134.98812118057793, 137.73647055306313, 140.49753435973378, 143.27117743314253, 146.05726804356266, 148.85567776216695, 151.666281331561, 154.4889565431757, 157.3235841210636, 160.17004761168067, 163.02823327926694, 165.89803000646936, 168.77932919987822, 171.67202470017202, 174.57601269658937, 177.49119164546627, 180.4174621925966, 183.3547270991908, 186.30289117122342, 189.26186119197462, 192.23154585758525, 195.21185571545556, 198.20270310533064, 201.2040021029255, 204.21566846595152, 207.2376195824173, 210.2697744210818, 213.3120534839486, 216.364378760695, 219.42667368493667, 222.49886309223618, 225.58087317976603, 228.67263146754658, 231.77406676117914, 234.8851091160043, 238.0056898026144, 241.13574127365786, 244.27519713187343], [0.0, 0.6173107187508757, 1.519997285376151, 2.574906414213444, 3.742672332380574, 5.0022434427637865, 6.340163293489745, 7.7469592223323485, 9.215540265981863, 10.740365978698028, 12.316968137499753, 13.9416542673027, 15.611313236948808, 17.323282031044947, 19.075251133970696, 20.865195330307618, 22.69132182883739, 24.55203054633001, 26.445883143907768, 28.371578502129434, 30.32793302366032, 32.31386461682957, 34.328379527952066, 36.37056140804921, 38.43956215329413, 40.53459416889123, 42.65492378663872, 44.79986562603352, 46.9687777334786, 49.16105736807594, 51.37613732851732, 53.613482735761174, 55.87258820196941, 58.15297532863878, 60.45419048677585, 62.77580283991376, 65.11740257718908, 67.47859932891382, 69.85902074134677, 72.25831119087925, 74.6761306207564, 77.11215348587105, 79.56606779318737, 82.03757422704746, 84.52638535004436, 87.0322248713574, 89.554826975476, 92.09393570511841, 94.6493043929055, 97.22069513699833, 99.80787831646774, 102.41063214264794, 105.02874224314688, 107.66200127555187, 110.31020856818824, 112.97316978556962, 115.65069661642256, 118.3426064823853, 121.04872226567124, 123.76887205415511, 126.50288890249062, 129.25061060799985, 132.01187950019298, 134.78654224288286, 137.5744496479514, 140.37545649991094, 143.18942139047678, 146.01620656243725, 148.85567776216695, 151.70770410018415, 154.5721579192035, 157.44891466917952, 160.33785278887638, 163.2388535935381, 166.15180116826454, 169.07658226673033, 172.01308621491143, 174.96120481950817, 177.92083228077888, 180.89186510951592, 183.87420204791897, 186.8677439941349, 189.87239393025172, 192.88805685354754, 195.914639710811, 198.9520513355597, 202.00020238799672, 205.05900529755579, 208.12837420789342, 211.2082249241993, 214.29847486270026, 217.39904300224413, 220.50984983785577, 223.63081733616391, 226.76186889260492, 229.90292929031318, 233.05392466061616, 236.21478244505371, 239.38543135884953, 242.5658013557629, 245.7558235942569, 248.95543040492035], [0.0, 0.6289664092534478, 1.548696961867989, 2.6235242517554345, 3.8133392251360396, 5.0966928012738, 6.45987445164721, 7.893232656907187, 9.389542566430535, 10.943159123105715, 12.549529737646981, 14.204892215871553, 15.906076684110035, 17.650369845510898, 19.435418577565866, 21.25915942595444, 23.119765749050483, 25.01560725181276, 26.94521843751211, 28.907273619750914, 30.90056685321995, 32.92399561484287, 34.97654738747391, 37.05728852018299, 39.165354895755804, 41.29994404850449, 43.46030845754463, 45.645749801429794, 47.855614005580435, 50.08928694850662, 52.34619071934546, 54.625780339790325, 56.92754087957329, 59.250984907357704, 61.59565022899971, 63.96109787323685, 66.34691029140295, 68.75268974308382, 71.17805684397842, 73.62264925580652, 76.08612050106568, 78.56813888790141, 81.06838653241265, 83.58655846744284, 86.12236182836446, 88.67551510759932, 91.24574747066798, 93.83279812745687, 96.43641575316144, 99.05635795402303, 101.69239077354788, 104.34428823538977, 107.01183191950577, 109.69481056856819, 112.39301972194023, 115.10626137480952, 117.83434366032216, 120.57708055278134, 123.33429159016869, 126.1058016144174, 128.89144052801933, 131.69104306568295, 134.50444857987887, 137.33150083921805, 140.17204783870199, 143.02594162097125, 145.89303810775482, 148.773196940792, 151.666281331561, 154.5721579192035, 157.49069663608591, 160.4217705804835, 163.36525589591415, 166.32103165668755, 169.288979759268, 172.26898481908094, 175.26093407242186, 178.26471728315016, 181.28022665387692, 184.3073567413734, 187.34600437595026, 190.39606858457265, 193.4574505174946, 196.53005337820986, 199.61378235653214, 202.70854456462828, 205.8142489758409, 208.9308063661489, 212.05812925812074, 215.19613186723035, 218.34473005040726, 221.50384125670652, 224.67338447998782, 227.85328021350057, 231.0434504062797, 234.24381842125993, 237.4543089950248, 240.67484819910888, 243.90536340277941, 247.14578323722466, 250.39603756108315, 253.65605742725046], [0.0, 0.6406721613609769, 1.577519904490359, 2.6723509046375677, 3.8843096347074226, 5.1915478231353855, 6.58009977348355, 8.040134341082146, 9.564292212943753, 11.146823271275991, 12.783090198132184, 14.469260780785103, 16.20210615075284, 17.978862513764824, 19.797132953131786, 21.654815611393726, 23.550049851127977, 25.48117503572128, 27.446698393949085, 29.445269566941416, 31.475660165429197, 33.53674714717697, 35.62749915098856, 37.74696514966997, 39.894264943841335, 42.06858113305157, 44.2691522842358, 46.49526707942249, 48.74625927098949, 51.02150330797493, 53.320410523963325, 55.642425798006286, 57.987024616420975, 60.35371047624098, 62.7420125813844, 65.15148379085397, 67.58169878494661, 70.03225242086444, 72.50275825355003, 74.99284720121183, 77.50216633802256, 80.03037779897987, 82.57715778401597, 85.14219565020231, 87.72519308238063, 90.32586333380917, 92.94393052948286, 95.5791290256992, 98.2312028202244, 100.8999050080871, 103.5849972786076, 106.28624944977292, 109.00343903650449, 111.73635084974494, 114.48477662362161, 117.24851466823623, 120.02736954588309, 122.82115176872391, 125.629677516145, 128.45276837019654, 131.29025106766986, 134.14195726750583, 137.007723332349, 139.88739012317347, 142.78080280600162, 145.68781066982592, 148.60826695492128, 151.5420286908064, 154.4889565431757, 157.44891466917952, 160.4217705804835, 163.4073950135831, 166.40566180689186, 169.41644778416017, 172.43963264381648, 175.4750988538533, 178.52273155191025, 181.5824184502318, 184.65404974520177, 187.73751803117779, 190.83271821836982, 193.93954745452456, 197.0579050501942, 200.18769240738376, 203.32881295138583, 206.48117206562313, 209.6446770293328, 212.8192369579371, 216.00476274595403, 219.2011670123137, 222.40836404795115, 225.6262697655582, 228.85480165138168, 232.09387871896354, 235.343421464725, 238.60335182530125, 241.87359313654136, 245.1540700940904, 248.44470871547838, 251.7454363036419, 255.05618141181216, 258.37687380970385], [0.0, 0.6524274804311223, 1.606464895290952, 2.7213843096237826, 3.955580562144363, 5.286804500121683, 6.700834178715664, 8.187658067328465, 9.739781821239552, 11.351349817105632, 13.017639649543145, 14.734748790793134, 16.49938912775292, 18.308746154906057, 20.160378975939746, 22.05214716763981, 23.982155952834898, 25.948714224861035, 27.950301822506876, 29.985543609956704, 32.053188658944634, 34.152093321189554, 36.28120731165146, 38.43956215329413, 40.62626149647372, 42.84047294273594, 45.08142108792562, 47.34838156251345, 49.64067589428905, 51.95766705442152, 54.29875557539934, 56.66337615068427, 59.05099464259843, 61.46110543813264, 63.89322910284285, 66.34691029140295, 68.82171588016715, 71.31723329260919, 73.83306899301711, 76.36884712753329, 78.92420829470063, 81.49880843022939, 84.0923177928335, 86.70442003977891, 89.33481138229683, 91.98319981229714, 94.64930439290549, 97.33285460627836, 100.03358975294658, 102.75125839762377, 105.48561785700682, 108.23643372560753, 111.00347943609864, 113.78653585104453, 116.58539088322375, 119.39983914204798, 122.22968160383924, 125.07472530395766, 127.93478304897252, 130.8096731472473, 133.69921915646805, 136.60324964678384, 139.52159797835301, 142.45410209220077, 145.40060431339126, 148.36095116560875, 151.33499319631972, 154.32258481176112, 157.3235841210636, 160.33785278887638, 163.36525589591415, 166.40566180689186, 169.4589420453578, 172.52497117497336, 175.60362668682376, 178.69478889237539, 181.79834082172556, 184.91416812681632, 188.04215898930912, 191.1822040328382, 194.3341962393824, 197.49803086951252, 200.67360538628895, 203.86081938259974, 207.05957451174453, 210.2697744210818, 213.49132468856962, 216.72413276204222, 219.96810790107318, 223.22316112128846, 226.48920514099754, 229.76615433002334, 233.0539246606161, 236.35243366034456, 239.66160036686523, 242.98134528447423, 246.31159034235495, 249.65225885443687, 253.00327548078886, 256.36456619047163, 259.73605822578133, 263.1176800678182], [0.0, 0.6642318835261687, 1.6355307451376275, 2.7706224522999707, 4.027149079460076, 5.38245891885172, 6.822072707274202, 8.335797775004922, 9.916004181768793, 11.556730358135958, 13.253168456005627, 15.00134533898855, 16.797913401986925, 18.64000721649497, 20.525141722940585, 22.45113777132513, 24.416066302178955, 26.41820561156047, 28.456008033905363, 30.5280735529967, 32.6331286074608, 34.770008856930886, 36.93764501350711, 39.13505107744971, 41.3613144814158, 43.615587766324175, 45.89708149859341, 48.20505820264002, 50.538827130621904, 52.89773972791363, 55.28118568080794, 57.68858945464707, 60.11940724757338, 62.57312429849617, 65.04925249853999, 67.54732826379288, 70.06691063408128, 72.60757956811115, 75.16893440990916, 77.75059250527501, 80.35218795008305, 82.97337045487107, 85.61380431232745, 88.27316745611313, 90.95115060099397, 93.64745645556278, 96.3617989999403, 99.09390282179011, 101.84350250479449, 104.6103420644358, 107.39417442652977, 110.19476094447799, 113.01187095165918, 115.84528134577309, 118.69477620229358, 121.56014641449009, 124.44118935773928, 127.33770857608239, 130.2495134891886, 133.17641911806544, 136.11824582801935, 139.07481908751055, 142.04596924167438, 145.03153129939489, 148.03134473291564, 151.04525328906632, 154.0731048112612, 157.11475107150198, 160.17004761168067, 163.2388535935381, 166.32103165668755, 169.41644778416017, 172.52497117497336, 175.64647412326258, 178.78083190355306, 181.9279226617806, 185.08762731170017, 188.25982943634872, 191.44441519425288, 194.6412732300948, 197.85029458957092, 201.07137263819632, 204.30440298382536, 207.54928340267514, 210.80591376865365, 214.07419598580614, 217.3540339237079, 220.64533335564226, 223.94800189941168, 227.2619489606434, 230.58708567845486, 233.9233248733579, 237.2705809972845, 240.62877008562558, 243.99780971118187, 247.3776189399298, 250.7681182885135, 254.16922968337755, 257.58087642146165, 261.00298313238113, 264.4354757420232, 267.8782814374931], [0.0, 0.6760848989791646, 1.664716292650121, 2.8200633652642684, 4.0990123270009144, 5.478507257274714, 6.943810514847537, 8.484547544913081, 10.092952253238243, 11.76295668800423, 13.48966720652669, 15.269039773008823, 17.097667045360463, 18.97263246237774, 20.891406619358133, 22.851771480035637, 24.851763561462494, 26.889630436415192, 28.96379682170926, 31.072837718265205, 33.215456838394914, 35.39046906443276, 37.596786027362285, 39.83340413257901, 42.09939452825403, 44.3938946326572, 46.71610092500551, 49.065262769688545, 51.440677092679536, 53.841683766093496, 56.267661585361125, 58.718024745584174, 61.19221974092663, 63.68972262454307, 66.21003657740398, 68.75268974308383, 71.31723329260919, 73.90323968917718, 76.51030112723082, 79.13802812422222, 81.78604824657819, 84.45400495402785, 87.14155654866495, 89.84837521697482, 92.57414615462258, 95.31856676512653, 98.0813459246699, 100.86220330626703, 103.66086875732698, 106.4770817253664, 109.31059072723757, 112.16115285776624, 115.02853333415563, 117.91250507291295, 120.81284829640472, 123.72935016645455, 126.66180444266445, 129.61001116337897, 132.57377634741934, 135.5529117148995, 138.5472344255994, 141.55656683351725, 144.58073625634904, 147.61957475876255, 150.67291894843262, 153.74060978389866, 156.82249239338708, 159.9184159038161, 163.02823327926694, 166.15180116826454, 169.288979759268, 172.43963264381648, 175.60362668682376, 178.78083190355306, 181.9711213428416, 185.17437097617645, 188.39045959225493, 191.61926869668872, 194.8606824165381, 198.11458740938352, 201.38087277666506, 204.65942998103796, 207.9501527675106, 211.25293708814777, 214.5676810301379, 217.89428474703382, 221.23265039299275, 224.58268205985092, 227.9442857168787, 231.3173691530743, 234.70184192185988, 238.09761528805586, 241.50460217701504, 244.92271712580546, 248.35187623633962, 251.79199713035095, 255.2429989061274, 258.7048020969147, 262.17732863090987, 265.6605017927666, 269.15424618654225, 272.65848770001816], [0.0, 0.6879860659818013, 1.6940204031852832, 2.86970512640803, 4.171167510947728, 5.574945781330542, 7.066042868649027, 8.633901594125375, 10.270619156458233, 11.970020789273317, 13.727126706771813, 15.537821685728458, 17.39863840438587, 19.306608961121224, 21.259159425954444, 23.254032718381055, 25.289230792133658, 27.36297037189691, 29.4736484446727, 31.619814927028894, 33.800150712639834, 36.01344982213556, 38.25860472786817, 40.53459416889123, 42.84047294273594, 45.17536328358915, 47.53844752623859, 49.928961821585744, 52.346190719345465, 54.78946247135812, 57.25814493794947, 59.751642002259054, 62.269390415051184, 64.8108570064096, 67.3755362117667, 69.96294786857723, 72.57263524710176, 75.20416328457893, 77.85711699682365, 80.53110004520113, 83.22573344016544, 85.94065436524384, 88.67551510759932, 91.42998208319435, 94.20373494617259, 96.99646577342655, 99.80787831646772, 102.63768731369608, 105.4856178570068, 108.35140480739406, 111.2347922548357, 114.13553301828168, 117.05338818203819, 119.98812666524678, 122.93952482151381, 125.90736606605842, 128.89144052801933, 131.89154472580293, 134.90748126356698, 137.93905854712213, 140.98609051769998, 144.04839640218438, 147.1258004785334, 150.2181318552381, 153.32522426376747, 156.44691586304359, 159.58304905507484, 162.7334703109507, 165.89803000646936, 169.07658226673033, 172.26898481908094, 175.4750988538533, 178.69478889237539, 181.9279226617806, 185.17437097617645, 188.43400762376797, 191.7067092595619, 194.99235530330543, 198.2908278423398, 201.60201153907144, 204.92579354278575, 208.26206340554793, 211.61071300195275, 214.9716364525024, 218.34473005040726, 221.7298921916167, 225.12702330790103, 228.5360258028188, 231.9568039904113, 235.3892640364803, 238.83331390231095, 242.28886329071247, 245.7558235942569, 249.23410784560264, 252.72363066979864, 256.2243082384683, 259.7360582257814, 263.25879976612515, 266.79245341339345, 270.3369411018147, 273.8921861082466, 277.45811301586815], [0.0, 0.6999349341926693, 1.7234419678724928, 2.9195458572817983, 4.243611900940777, 5.671770841775319, 7.188765143393561, 8.783854271068886, 10.448998168494475, 12.177914826615869, 13.965537971248557, 15.807680906411637, 17.700816090275296, 19.641924075019624, 21.628386226924682, 23.657906264753862, 25.728451440386472, 27.838207506772733, 29.985543609956707, 32.16898448161272, 34.38718810531791, 36.63892755638198, 38.92307607173558, 41.23859465328172, 43.584521682376476, 45.95996414826418, 48.364090184610845, 50.79612267586875, 53.25533374588892, 55.74103997966171, 58.25259825857883, 60.78940211248611, 63.35087850969554, 65.93648502025296, 68.54570729899953, 71.17805684397842, 73.83306899301711, 76.5103011272308, 79.20933105503362, 81.92975555422386, 84.67118905300582, 87.43326243354913, 90.21562194397755, 93.01792820660174, 95.8398553118329, 98.68108998858804, 101.54133084316665, 104.42028765957586, 107.31768075513634, 110.23324038593643, 113.16670619733618, 116.11782671527159, 119.08635887458668, 122.07206758103545, 125.07472530395766, 128.09411169695122, 131.13001324414026, 134.1822229298846, 137.25053992999227, 140.33476932268653, 143.43472181775024, 146.5502135024192, 149.68106560272986, 152.82710425914794, 155.98816031540835, 159.1640691195947, 162.3546703365704, 165.5598077709512, 168.77932919987822, 172.01308621491143, 175.26093407242186, 178.52273155191025, 181.79834082172556, 185.08762731170017, 188.39045959225493, 191.7067092595619, 195.03625082638524, 198.37896161824722, 201.73472167459468, 205.10341365466306, 208.4849227477587, 211.8791365876989, 215.28594517116792, 218.7052407797643, 222.13691790553, 225.58087317976603, 229.0370053049525, 232.50521498960336, 235.98540488589637, 239.47747952993114, 242.98134528447423, 246.49691028406292, 250.02408438234494, 253.56277910153926, 257.11290758391186, 260.6743845451638, 264.2471262296387, 267.8310503672585, 271.4260761321057, 275.0321241025707, 278.6491162229919, 282.27697576671693], [0.0, 0.7119310633646238, 1.7529799026961241, 2.9695837215409875, 4.316342827820497, 5.768978871161853, 7.311972817470385, 8.934400050848984, 10.628082717105205, 12.386631140331009, 14.204892215871553, 16.07860749229648, 18.004188969517102, 19.97856544963745, 21.999073418382526, 24.06337723873422, 26.169409323463466, 28.315324331284586, 30.499463457165387, 32.72032614827369, 34.9765473874739, 37.26687922191101, 39.590175577013056, 41.94537964737728, 44.33151333325429, 46.74766831864812, 49.19299847993383, 51.66671338264212, 54.16807267561259, 56.69638123084012, 59.250984907357704, 61.831266840767455, 64.43664417823683, 67.06656519314781, 69.7205067250208, 72.39797189950278, 75.09848809061319, 77.82160509345739, 80.5668934805415, 83.33394311887052, 86.12236182836445, 88.93177416491177, 91.76182031371096, 94.61215508050546, 97.48244696996794, 100.37237734188723, 103.28163963700018, 106.20993866532507, 109.15698995072337, 112.12251912616402, 115.10626137480953, 118.10796091260197, 121.12737050851098, 124.16425103902894, 127.21837107386574, 130.28950649011983, 133.3774401124837, 136.48196137729263, 139.60286601844473, 142.7399557734145, 145.8930381077548, 149.06192595663512, 152.24643748209925, 155.44639584484818, 158.66162898946095, 161.8919694420652, 165.1372541195531, 168.39732414952016, 171.67202470017202, 174.96120481950817, 178.26471728315016, 181.5824184502318, 184.91416812681632, 188.25982943634872, 191.61926869668872, 194.99235530330543, 198.37896161824722, 201.77896286452824, 205.19223702560095, 208.61866474960678, 212.05812925812072, 215.51051625912498, 218.9757138639658, 222.4536125080645, 225.9441048751706, 229.4470858249572, 232.96245232377427, 236.49010337838686, 240.0299399725362, 243.58186500617364, 247.14578323722466, 250.7216012257517, 254.3092272803913, 257.9085714069488, 261.51954525904233, 265.14206209069226, 268.77603671076054, 272.4213854391489, 276.0780260646707, 279.7458778045159, 283.42486126523295, 287.11489840515765], [0.0, 0.7239740229900975, 1.7826331476222053, 3.019816923466419, 4.389357681477083, 5.866566380965496, 7.435661469300229, 9.08553353079815, 10.80786637544621, 12.596162240173246, 14.44518085088555, 16.3505917205846, 18.308746154906057, 20.31652100385611, 22.371207697400106, 24.47043108910147, 26.612088616617946, 28.794303723042365, 31.01538954315096, 33.27382014089946, 35.568207408649414, 37.89728228329144, 40.25987930336275, 42.654923786638726, 45.08142108792562, 47.53844752623859, 50.025142665004196, 52.54070269883721, 55.08437475286586, 57.65545194036439, 60.25326905497806, 62.87719879748823, 65.52664845557806, 68.2010569696734, 70.89989232956067, 73.62264925580652, 76.36884712753329, 79.13802812422222, 81.92975555422386, 84.74361234677173, 87.57919968770399, 90.43613578193151, 93.31405472805906, 96.21260549255615, 99.13145097255133, 102.07026713774529, 105.0287422431469, 108.00657610536814, 111.00347943609864, 114.01917322714014, 117.0533881820382, 120.10586418991554, 123.17634983760466, 126.26460195660701, 129.3703852017792, 132.49347165897748, 135.63364047917713, 138.790677536838, 141.96437511051184, 145.15453158388272, 148.36095116560872, 151.58344362648813, 154.82182405261065, 158.0759126132802, 161.3455343426024, 164.63051893373233, 167.93070054486356, 171.24591761612078, 174.57601269658937, 177.92083228077888, 181.28022665387692, 184.65404974520177, 188.04215898930912, 191.44441519425288, 194.8606824165381, 198.2908278423398, 201.73472167459468, 205.19223702560095, 208.66324981479056, 212.14763867135997, 215.6452848414712, 219.15607209975335, 222.67988666485456, 226.21661711881197, 229.76615433002337, 233.3283913796179, 236.9032234910378, 240.4905479626561, 244.0902641032641, 247.7022731702778, 251.32647831051662, 254.96278450342172, 258.61109850658704, 262.27132880348444, 265.94338555327306, 269.6271805425861, 273.32262713920034, 277.02964024749264, 280.7481362655997, 284.4780330441968, 288.21924984682033, 291.97170731166045], [0.0, 0.7360633919632708, 1.8124006657665803, 3.0702437065551784, 4.462653908802265, 5.964529958846626, 7.559826773865594, 9.237249426236374, 10.988342857027524, 12.806500799474689, 14.686395474124815, 16.623624080811375, 18.614476996999894, 20.655778920393537, 22.74477605156889, 24.879053582415438, 27.056473840695904, 29.275128933587574, 31.53330382754094, 33.82944710548164, 36.16214748028566, 38.53011469723771, 40.93216383327389, 43.367202260456715, 45.83421872438775, 48.33227411988198, 50.86049364226038, 53.41806006369494, 56.00420793734057, 58.618218572436845, 61.25941565459919, 63.92716140957603, 66.62085322757127, 69.3399206800887, 72.08382287307691, 74.85204608963207, 77.6441016831698, 80.45952418819931, 83.29786962092216, 86.15871394606445, 89.04165168981727, 91.94629468163933, 94.8722709100861, 97.81922347985066, 100.78680965890796, 103.77470000609897, 106.78257757072062, 109.81013715673582, 112.85708464511787, 115.92313636861589, 119.00801853389558, 122.1114666865863, 125.233225215267, 128.37304689086005, 131.53069243828241, 134.70593013753805, 137.8985354517277, 141.10829067970968, 144.33498463137366, 147.5784123236889, 150.8383746958678, 154.11467834214295, 157.40713526079654, 160.71556261820749, 164.039782526792, 167.37962183581547, 170.73491193414168, 174.10548856406794, 177.49119164546627, 180.89186510951592, 184.3073567413734, 187.73751803117779, 191.1822040328382, 194.6412732300948, 198.11458740938352, 201.60201153907144, 205.10341365466306, 208.61866474960678, 212.14763867135997, 215.69021202239387, 219.2462640658449, 222.81567663553864, 226.39833405013133, 229.9941230311336, 233.60293262459584, 237.22465412624928, 240.85918100991202, 244.5064088589813, 248.16623530084397, 251.8385599440509, 255.5232843181068, 259.22031181574033, 262.92954763752573, 266.6508987387349, 270.3842737783086, 274.12958306983853, 277.88673853446244, 281.65565365557757, 285.43624343528467, 289.2284243524785, 293.03211432250754, 296.8472326583293], [0.0, 0.7481987582580971, 1.8422814426021197, 3.120862352177608, 4.536229011737226, 6.062866266041593, 7.684464499403875, 9.389542566430537, 11.169506010906833, 13.017639649543144, 14.92852786458892, 16.89769526757433, 18.921371075976836, 20.996327636768818, 23.119765749050483, 25.289230792133658, 27.502549850300817, 29.757783575587595, 32.053188658944634, 34.38718810531791, 36.75834735990512, 39.165354895755804, 41.60700625415794, 44.082190793181795, 46.58988058602994, 49.129121044631624, 51.6990229415348, 54.29875557539934, 56.92754087957329, 59.5846483143499, 62.26939041505117, 64.98111889253751, 67.71922120187584, 70.48311751000124, 73.27225800522355, 76.0861205010657, 78.92420829470063, 81.78604824657819, 84.67118905300582, 87.57919968770399, 90.5096679918781, 93.46219939527765, 96.43641575316144, 99.43195428614337, 102.44846661162708, 105.4856178570068, 108.54308584606093, 111.6205603510313, 114.71774240379509, 117.83434366032216, 120.97008581328878, 124.1247000483049, 127.29792653972245, 130.48951398243528, 133.69921915646805, 136.92680652149207, 140.172047838702, 143.43472181775024, 146.71461378666692, 150.01151538289693, 153.32522426376747, 156.65554383485932, 160.0022829948987, 163.36525589591415, 166.74428171751606, 170.13918445425972, 173.54979271514256, 176.97593953436981, 180.4174621925966, 183.87420204791897, 187.34600437595026, 190.83271821836982, 194.3341962393824, 197.85029458957092, 201.38087277666506, 204.92579354278575, 208.4849227477587, 212.05812925812072, 215.6452848414712, 219.2462640658449, 222.86094420380783, 226.4892051409975, 230.13092928884942, 233.78600150126874, 237.45430899502477, 241.13574127365789, 244.830190054705, 248.53754920006264, 252.25771464931574, 255.99058435587648, 259.73605822578133, 263.4940380590094, 267.2644274931912, 271.04713194958407, 274.84205858120254, 278.6491162229919, 282.46821534394707, 286.29926800107916, 290.1421877951412, 293.9968898280281, 297.86329066177115, 301.7413082790526], [0.0, 0.7603797186212513, 1.8722744852026658, 3.1716711782965388, 4.610080545410983, 6.161572034874586, 7.809570504253744, 9.542407890741037, 11.351349817105632, 13.22957177431982, 15.171569976316231, 17.172796173598528, 19.229418193870476, 21.338155836685523, 23.49616432908855, 25.70094908823296, 27.950301822506873, 30.24225161062343, 32.57502676179888, 34.9470246068999, 37.356787236026385, 39.802981770070254, 42.28438414127356, 44.799865626033515, 47.34838156251345, 49.92896182158574, 52.5407026988372, 55.18275996879393, 57.854342897582946, 60.554709052033196, 63.28315977528026, 66.03903622379076, 68.82171588016715, 71.63060947144163, 74.46515823478067, 77.32483148231266, 80.20912442469967, 83.11755621949963, 86.04966821562428, 89.0050223695223, 91.98319981229713, 94.98379954994452, 98.00643728138309, 101.0507443210403, 104.11636661451865, 107.20296383735896, 110.31020856818823, 113.43778552862234, 116.58539088322375, 119.75273159361186, 122.93952482151381, 126.14549737613906, 129.37038520177916, 132.61393290198527, 135.87589329706827, 139.1560270120134, 142.45410209220077, 145.7698936445917, 149.103183502275, 152.45375991047393, 155.82141723230004, 159.20595567270217, 162.60718101920511, 166.02490439816177, 169.45894204535776, 172.90911508991283, 176.37524935051366, 179.8571751430989, 183.3547270991908, 186.8677439941349, 190.39606858457265, 193.93954745452456, 197.49803086951252, 201.07137263819632, 204.65942998103796, 208.26206340554793, 211.8791365876989, 215.51051625912498, 219.15607209975335, 222.81567663553864, 226.4892051409975, 230.17653554626008, 233.8775483483752, 237.59212652662583, 241.32015546162742, 245.0615228579959, 248.81611867038856, 252.5838350327332, 256.3645661904716, 260.1582084356587, 263.96466004476315, 267.7838212190305, 271.6155940272749, 275.45988235097616, 279.3165918315644, 283.1856298197831, 287.06690532702856, 290.96032897856634, 294.865812968537, 298.783271016662, 302.71261832657075, 306.6537715456723], [0.0, 0.7726058782791297, 1.902378821521586, 3.2226685382451414, 4.684206116363973, 6.260644066383385, 7.935140733845868, 9.695840444944805, 11.533868382235184, 13.442290305281539, 15.41551393253781, 17.448917883119297, 19.538608367160037, 21.681252441809413, 23.873959592954964, 26.11419512730605, 28.39971524608883, 30.728517337536363, 33.0988012238158, 35.508938466446956, 37.95744771376929, 40.44297465528673, 42.964275541433054, 45.52020349983761, 48.10969707152664, 50.73177052864818, 53.38550563610897, 56.07004459411798, 58.78458395457756, 61.52836934671987, 64.30069087996375, 67.10087911721841, 69.92830153161742, 72.78235937526202, 75.66248490096059, 78.56813888790143, 81.49880843022939, 84.45400495402785, 87.43326243354915, 90.43613578193153, 93.46219939527766, 96.51104583199324, 99.5822846118126, 102.67554112106106, 105.79045561249386, 108.92668228956848, 112.08388846629757, 115.26175379493002, 118.4599695546526, 121.67823799531516, 124.91627173088297, 128.1737931779257, 131.45053403497818, 134.7462347990674, 138.06064431609735, 141.393519362138, 144.74462425296673, 148.11373047948558, 151.50061636687352, 154.90506675554482, 158.32687270217158, 161.76583119919442, 165.22174491139202, 168.6944219282144, 172.18367553069908, 175.68932397189744, 179.21119026983166, 182.7491020120872, 186.30289117122342, 189.87239393025172, 193.4574505174946, 197.0579050501942, 200.67360538628895, 204.30440298382536, 207.9501527675106, 211.61071300195275, 215.28594517116792, 218.9757138639658, 222.67988666485456, 226.39833405013133, 230.13092928884942, 233.8775483483752, 237.63806980426733, 241.41237475423054, 245.20034673591303, 249.00187164833116, 252.8168376767211, 256.64513522063004, 260.4866568250703, 264.34129711457484, 268.20895272999775, 272.0895222679184, 275.9829062225139, 279.8890069297723, 283.8077285139306, 287.7389768360232, 291.6826594444389, 295.63868552738523, 299.6069658671708, 303.5874127962147, 307.5799401547041, 311.5844632498201], [0.0, 0.7848768506580984, 1.9325934997029401, 3.273852819560033, 4.75860338085195, 6.360079228052437, 8.061171217829674, 9.849835377724517, 11.71705593532022, 13.655788516573422, 15.660352020095612, 17.72605166556418, 19.848931819695675, 22.025606603917886, 24.253139595305303, 26.528955843105834, 28.850775911238763, 31.216565381301493, 33.62449548399806, 36.0729119170487, 38.560309801110975, 41.085313315748046, 43.64665895744539, 46.24318163854359, 48.87380304136495, 51.537521782158976, 54.2334050418928, 56.960581396704136, 59.71823463766902, 62.50559841266779, 65.32195155622745, 68.166613998871, 71.03894316757538, 73.93833080478218, 76.8642001460113, 79.81600340623493, 82.79321953333117, 85.79535219357054, 88.82192795951552, 91.87249467517802, 94.94661997697399, 98.04388995208664, 101.16390791841741, 104.30629331246105, 107.47068067325948, 110.65671871212996, 113.8640694591743, 117.09240747869357, 120.34141914659247, 123.6108019836811, 126.90026403949393, 130.2095233218604, 133.53830726799666, 136.88635225335372, 140.25340313486132, 143.6392128255666, 147.04354189797417, 150.46615821367266, 153.90683657707362, 157.36535841130265, 160.84151145447336, 164.3350894747431, 167.8458920026988, 171.37372407975636, 174.91839602137486, 178.47972319399597, 182.05752580471184, 185.65162870275455, 189.26186119197462, 192.88805685354754, 196.53005337820986, 200.18769240738376, 203.86081938259974, 207.54928340267514, 211.25293708814777, 214.9716364525024, 218.7052407797643, 222.4536125080645, 226.21661711881197, 229.9941230311336, 233.78600150126874, 237.59212652662583, 241.41237475423054, 245.2466253933127, 249.09476013179827, 252.95666305648592, 256.83222057670525, 260.7213213512658, 264.62385621851774, 268.5397181293601, 272.4688020830373, 276.4110050655812, 280.3662259907599, 284.3343656434053, 288.3153266250002, 292.30901330140966, 296.3153317526526, 300.33418972461124, 304.3654965825874, 308.40916326661306, 312.4651022484354, 316.5332274900955], [0.0, 0.7971922571172363, 1.9629175874234193, 3.3252224428665045, 4.833270043225648, 6.4598744516472095, 8.187658067328465, 10.004387937314677, 11.900906823809198, 13.870059820359, 15.906076684110033, 18.004188969517102, 20.160378975939746, 22.371207697400106, 24.63369263592047, 26.94521843751211, 29.303469899742172, 31.70638068239826, 34.152093321189554, 36.63892755638197, 39.1653548957558, 41.72997793104434, 44.33151333325429, 46.968777733478596, 49.640675894289046, 52.34619071934546, 55.084374752865855, 57.854342897582946, 60.65526613753859, 63.48636609587593, 66.34691029140293, 69.23620798375583, 72.15360651737699, 75.09848809061319, 78.0702668890436, 81.06838653241265, 84.0923177928335, 87.14155654866494, 90.21562194397755, 93.31405472805906, 96.43641575316144, 99.58228461181258, 102.75125839762377, 105.94295057571443, 109.15698995072339, 112.39301972194023, 115.65069661642255, 118.92969009209973, 122.22968160383924, 125.55036392628728, 128.89144052801936, 132.2526249921603, 135.6336404791771, 139.0342192280202, 142.45410209220077, 145.8930381077548, 149.3507840903594, 152.82710425914792, 156.3217698850155, 159.8345589614248, 163.36525589591412, 166.91365122068237, 170.47954132077538, 174.06272817853784, 177.66301913311202, 181.28022665387692, 184.91416812681635, 188.56466565289304, 192.23154585758525, 195.914639710811, 199.61378235653214, 203.32881295138583, 207.05957451174453, 210.80591376865365, 214.5676810301379, 218.34473005040726, 222.13691790553, 225.9441048751706, 229.76615433002337, 233.60293262459584, 237.45430899502477, 241.32015546162742, 245.20034673591303, 249.09476013179827, 253.00327548078883, 256.92577505090355, 260.8621434691348, 264.8122676472511, 268.77603671076054, 272.7533419308678, 276.74407665926344, 280.74813626559967, 284.7654180775129, 288.79582132306206, 292.8392470754617, 296.8955981999934, 300.9647793029892, 305.04669668278325, 309.1412582825394, 313.24837364486064, 317.36795386809905, 321.49991156428456], [0.0, 0.8095517266928728, 1.9933501712633217, 3.376775860812946, 4.9082038543819415, 6.560026731144102, 8.31459747231566, 10.15949346829567, 12.085415509760624, 14.085097762375506, 16.15268052288275, 18.283321416948827, 20.472940454506368, 22.718045312088073, 25.01560725181276, 27.36297037189691, 29.757783575587595, 32.19794848665005, 34.68157884313118, 37.20696833496979, 39.77256477258468, 42.37694908264055, 45.01881803973202, 47.69696992829615, 50.4102925306173, 53.157752981547745, 55.938389136187794, 58.75130217494326, 61.595650228999716, 64.47064285374, 67.37553621176669, 70.30962885364998, 73.27225800522356, 76.26279628659172, 79.28064880101323, 82.32525054225204, 85.39606407740438, 88.49257746905307, 91.61430240619852, 94.76077251802012, 97.93154184833291, 101.12618347177236, 104.34428823538977, 107.58546361156436, 110.84933265001482, 114.13553301828166, 117.44371612140455, 120.7735462926712, 124.1247000483049, 127.49686539980677, 130.88974121840317, 134.30303664668327, 137.73647055306313, 141.18977102519273, 144.66267489884086, 148.1549273191609, 151.666281331561, 155.19649749968684, 158.7453435482747, 162.31259402885328, 165.89803000646933, 169.50143876578522, 173.1226135350514, 176.7613532265964, 180.4174621925966, 184.09074999500314, 187.7810311885977, 191.48812511624084, 195.21185571545556, 198.9520513355597, 202.70854456462828, 206.48117206562313, 210.2697744210818, 214.07419598580614, 217.89428474703382, 221.7298921916167, 225.58087317976603, 229.4470858249572, 233.3283913796179, 237.22465412624928, 241.13574127365789, 245.0615228579959, 249.00187164833116, 252.95666305648592, 256.92577505090355, 260.9090880743158, 264.9064849650005, 268.9178508814346, 272.9430732301559, 276.98204159666494, 281.03464767920343, 285.10078522526084, 289.180349970667, 293.2732395811378, 297.3793535961516, 301.49859337503756, 305.63086204516816, 309.77606445215037, 313.9341071119217, 318.1048981646565, 322.2883473303977, 326.4843658663341], [0.0, 0.8219548958542658, 2.023890356104964, 3.4285115570517375, 4.983402610282559, 6.660533120750642, 8.441985699105455, 10.315147408527638, 12.270576566195691, 14.300896017683014, 16.400156283021868, 18.56344079769912, 20.786607061982714, 23.066109246400355, 25.398872209676185, 27.78219935886636, 30.213703575985743, 32.69125433550688, 35.21293647599401, 37.777017544952265, 40.3819215716518, 43.026207741087134, 45.708552861092734, 48.42773680458122, 51.18263031351201, 53.9721846981758, 56.795423072618625, 59.65143284640114, 62.539359252408566, 65.45839973559526, 68.40779906220607, 71.38684503588095, 74.39486472806834, 77.43122114676414, 80.49531028079414, 83.58655846744284, 86.70442003977891, 89.8483752169748, 93.01792820660175, 96.21260549255615, 99.43195428614337, 102.67554112106104, 105.94295057571443, 109.2337841085539, 112.54765899403023, 115.88420734837618, 119.24307523579631, 122.6239218468174, 126.02641874155694, 129.4502491515298, 132.89510733435824, 136.3606979763954, 139.84673563883078, 143.3529442433362, 146.8790565937324, 150.42481393053316, 153.98996551554703, 157.57426824400721, 161.1774862819529, 164.79939072680924, 168.43975928931323, 172.09837599510834, 175.7750309044882, 179.4695198489103, 183.1816441830242, 186.91121055107328, 190.65803066662684, 194.42192110469136, 198.20270310533064, 202.00020238799672, 205.8142489758409, 209.6446770293328, 213.49132468856962, 217.3540339237079, 221.23265039299275, 225.12702330790103, 229.0370053049525, 232.96245232377427, 236.9032234910378, 240.85918100991202, 244.830190054705, 248.81611867038856, 252.8168376767211, 256.83222057670525, 260.8621434691348, 264.9064849650005, 268.96512610754166, 273.03795029574434, 277.12484321109804, 281.22569274743915, 285.34038894371446, 289.4688239195152, 293.6108918132363, 297.7664887227267, 301.93551264830575, 306.1178634380256, 310.3134427350698, 314.5221539271818, 318.74390209802675, 322.9785939803913, 327.22613791113633, 331.48644378781887], [0.0, 0.8344014082698136, 2.0545372645570232, 3.4804280452640777, 5.0588641505366505, 6.76139073301102, 8.569819087951673, 10.471345286216547, 12.456384673608147, 14.517448386596827, 16.648496854777214, 18.844539064196713, 21.101369787016658, 23.415389500781373, 25.783476498662246, 28.202893354358615, 30.671216802775817, 33.186284056747034, 35.746150954363706, 38.34905880934176, 40.993407786698754, 43.677735253782096, 46.400697981891646, 49.161057368075944, 51.95766705442153, 54.78946247135812, 57.655451940364394, 60.5547090520332, 63.486366095875944, 66.44960836409818, 69.44366918676215, 72.46782558302208, 75.52139443445635, 78.60372910336264, 81.71421643228315, 84.85227407177253, 88.01734809209786, 91.20891084161222, 94.42645902031353, 97.66951194184581, 100.93760996112833, 104.23031304806341, 107.54719949050425, 110.88786471195654, 114.25192019142128, 117.63899247442426, 121.04872226567126, 124.48076359495654, 127.93478304897255, 131.41045906254408, 134.907481263567, 138.4255498665858, 141.96437511051187, 145.5236767364806, 149.10318350227502, 152.70263273012432, 156.32176988501553, 159.96034818095012, 163.6181282128342, 167.29487761191882, 170.99037072290946, 174.7043883010421, 178.43671722758288, 182.18715024235212, 185.95548569199755, 189.7415272928589, 193.54508390736427, 197.36596933299367, 201.2040021029255, 205.05900529755579, 208.9308063661489, 212.8192369579371, 216.72413276204222, 220.64533335564226, 224.58268205985092, 228.5360258028188, 232.50521498960336, 236.49010337838686, 240.4905479626561, 244.5064088589813, 248.53754920006264, 252.5838350327332, 256.64513522063004, 260.7213213512658, 264.8122676472511, 268.9178508814346, 273.03795029574434, 277.1724475235268, 281.32122651519506, 285.48417346700967, 289.66117675282413, 293.8521268586427, 298.0569163198431, 302.27543966092827, 306.50759333767996, 310.75327568159213, 315.01238684647296, 319.28482875710773, 323.57050505988394, 327.8693210752827, 332.18118375214897, 336.506001623657], [0.0, 0.846890914583223, 2.085290036403403, 3.5325238682263476, 5.134586357043735, 6.862596736992335, 8.698094050748884, 10.628082717105206, 12.642834616622839, 14.734748790793132, 16.89769526757433, 19.126608326404227, 21.417219794656276, 23.76587627142017, 26.16940932346347, 28.62504055007832, 31.13031041419785, 33.683023755574716, 36.28120731165146, 38.92307607173558, 41.60700625415794, 44.33151333325429, 47.09523397457785, 49.896911035492, 52.735380999142464, 55.60956336124428, 58.5184515996109, 61.46110543813264, 64.43664417823683, 67.44424091740115, 70.48311751000124, 73.55254015345282, 76.65181550426551, 79.7802872457196, 82.93733304247982, 86.12236182836446, 89.33481138229683, 92.57414615462257, 95.8398553118329, 99.13145097255133, 102.44846661162708, 105.79045561249384, 109.15698995072339, 112.54765899403023, 115.96206840594644, 119.39983914204798, 122.86060652902856, 126.34401941812325, 129.8497394054198, 133.37744011248373, 136.9268065214921, 140.49753435973378, 144.08932952891166, 147.70190757518398, 151.33499319631972, 154.98831978272864, 158.66162898946098, 162.35467033657036, 166.06720083549405, 169.79898463933586, 173.54979271514253, 177.31940253644547, 181.10759779450217, 184.91416812681635, 188.7389088616434, 192.58162077730543, 196.4421098752408, 200.32018716580862, 204.21566846595152, 208.12837420789342, 212.05812925812074, 216.00476274595403, 219.96810790107318, 223.94800189941168, 227.9442857168787, 231.9568039904113, 235.98540488589637, 240.0299399725362, 244.0902641032641, 248.16623530084397, 252.25771464931574, 256.3645661904716, 260.4866568250703, 264.62385621851774, 268.77603671076054, 272.9430732301559, 277.12484321109804, 281.32122651519506, 285.53210535580394, 289.75736422574545, 293.9968898280281, 298.2505710094261, 302.51829869676294, 306.79996583576064, 311.09546733232816, 315.40469999616244, 319.7275624865517, 324.0639552602695, 328.413780521461, 332.7769421734231, 337.15334577219045, 341.5428984818414], [0.0, 0.8594230721991122, 2.116147828075323, 3.5847975969158212, 5.210567152693826, 6.964148356547257, 8.826807068830389, 10.785355401782688, 12.829921280795062, 14.952791269578759, 17.147744685736672, 19.409640846976064, 21.734148420927898, 24.117559944233843, 26.556660097688344, 29.048629366249937, 31.590971817011788, 34.18145980609291, 36.81809087090906, 39.499053586462246, 42.22270014261937, 44.98752404594053, 47.792141787571744, 50.63527762187878, 53.51575081446923, 56.43246487192687, 59.38439837770925, 62.37059714164976, 65.39016743273773, 68.44227011207828, 71.52611551917137, 74.64095899273832, 77.78609692930154, 80.9608633000705, 84.16462656049019, 87.39678689787516, 90.65677377149031, 93.94404370670227, 97.25807831076895, 100.59838248272251, 103.96448279384687, 107.35592601861453, 110.77227779875953, 114.21312142552492, 117.67805672711415, 121.16669905006383, 124.67867832468983, 128.21363820598344, 131.7712352823849, 135.35113834576336, 138.95302771671203, 142.57659461994038, 146.2215406051313, 149.88757700914013, 153.574424455857, 157.28181239044528, 161.00947864500748, 164.75716903303467, 168.5246369702578, 172.3116431197558, 176.1179550593819, 179.94334696975616, 183.78759934123354, 187.65049869840684, 191.53183734083143, 195.43141309877856, 199.34902910292655, 203.28449356699585, 207.2376195824173, 211.2082249241993, 215.19613186723035, 219.2011670123137, 223.22316112128846, 227.2619489606434, 231.3173691530743, 235.3892640364803, 239.47747952993114, 243.58186500617364, 247.7022731702778, 251.8385599440509, 255.99058435587648, 260.1582084356587, 264.34129711457484, 268.5397181293601, 272.7533419308678, 276.98204159666494, 281.22569274743915, 285.48417346700967, 289.75736422574545, 294.0451478072103, 298.3474092378617, 302.6640357196463, 306.9949165653396, 311.33994313649174, 315.69900878384567, 320.0720087901048, 324.4588403149334, 328.8594023420803, 333.27359562852286, 337.7013226555344, 342.1424875815826, 346.5969961969746], [0.0, 0.8719975450775371, 2.1471098121453833, 3.6372478296536004, 5.286804500121683, 7.066042868649025, 8.955954690857904, 10.943159123105717, 13.017639649543145, 15.171569976316231, 17.398638404385867, 19.69362903661792, 22.05214716763981, 24.47043108910147, 26.945218437512114, 29.4736484446727, 32.053188658944634, 34.68157884313118, 37.35678723602639, 40.07697590913798, 42.840472942735936, 45.6457498014298, 48.49140273383876, 51.37613732851732, 54.29875557539935, 57.25814493794947, 60.25326905497806, 63.28315977528027, 66.34691029140295, 69.44366918676215, 72.57263524710174, 75.7330529157839, 78.92420829470065, 82.14542561019748, 85.39606407740439, 88.67551510759932, 91.98319981229713, 95.31856676512652, 98.68108998858804, 102.07026713774529, 105.4856178570068, 108.92668228956846, 112.39301972194023, 115.88420734837618, 119.39983914204798, 122.93952482151381, 126.50288890249062, 130.08956982618062, 133.69921915646805, 137.33150083921805, 140.9860905177, 144.66267489884086, 148.36095116560872, 152.0806264313432, 155.82141723230006, 159.58304905507484, 163.36525589591415, 167.16777984923112, 170.99037072290943, 174.83278567821878, 178.69478889237536, 182.57615124196911, 186.47665000564456, 190.3960685845727, 194.33419623938238, 198.2908278423398, 202.2657636436701, 206.25880905101198, 210.2697744210818, 214.29847486270026, 218.34473005040726, 222.40836404795115, 226.48920514099754, 230.58708567845486, 234.70184192185988, 238.83331390231095, 242.98134528447423, 247.14578323722466, 251.32647831051662, 255.5232843181068, 259.73605822578133, 263.96466004476315, 268.20895272999775, 272.4688020830373, 276.74407665926344, 281.03464767920343, 285.34038894371446, 289.66117675282413, 293.9968898280281, 298.3474092378617, 302.7126183265708, 307.0924026457201, 311.4866498885879, 315.8952498272029, 320.31809425189135, 324.7550769132069, 329.20609346612656, 333.6710414164004, 338.149820068952, 342.6423304782292, 347.148475400414, 351.66815924740365], [0.0, 0.884614003536983, 2.1781751768424735, 3.689873191282863, 5.363296400512373, 7.1682776017950305, 9.085533530798148, 11.101489743726322, 13.205984801207412, 15.391079174996086, 17.650369845510895, 19.97856544963745, 22.371207697400106, 24.824480454335557, 27.335074155589094, 29.90008664206173, 32.516948821448764, 35.18336775441011, 37.89728228329144, 40.656827887612174, 43.46030845754462, 46.30617334215065, 49.19299847993383, 52.11947073131308, 55.084374752865855, 58.086581911370466, 61.12504085109058, 64.19876941316785, 67.30684767004504, 70.44841188645448, 73.62264925580652, 76.82879328972503, 80.06611976109842, 83.33394311887052, 86.63161330700336, 89.95851293143554, 93.31405472805905, 96.6976792922142, 100.10885303631905, 103.54706634728137, 107.01183191950577, 110.50268324277, 114.01917322714013, 117.56087294952371, 121.12737050851098, 124.71826997589005, 128.33319043469993, 131.97176509494514, 135.6336404791771, 139.31847567107644, 143.02594162097125, 146.75572050292138, 150.5075051185999, 154.28099834372853, 158.07591261328017, 161.89196944206518, 165.7288989776665, 169.58643958300144, 173.46433744606006, 177.36234621461034, 181.2802266538769, 185.21774632538762, 189.17467928535274, 193.1508058010926, 197.1459120841626, 201.15979003894734, 205.19223702560097, 209.24305563631114, 213.3120534839486, 217.39904300224413, 221.50384125670652, 225.6262697655582, 229.76615433002334, 233.9233248733579, 238.09761528805586, 242.28886329071247, 246.49691028406292, 250.7216012257517, 254.96278450342172, 259.22031181574033, 263.4940380590094, 267.7838212190305, 272.0895222679184, 276.4110050655812, 280.74813626559967, 285.10078522526084, 289.4688239195152, 293.8521268586427, 298.2505710094261, 302.6640357196463, 307.0924026457201, 311.5355556833203, 315.99338090082017, 320.46576647541985, 324.95260263181865, 329.4537815833047, 333.96919747514363, 338.4987463301519, 343.0423259963508, 347.5998360965987, 352.17117798010975, 356.75625467576884], [0.0, 0.8972721240653804, 2.209343125586439, 3.742672332380574, 5.440040892455481, 7.270849934475427, 9.215540265981863, 11.260343203720163, 13.394951906228917, 15.611313236948805, 17.902932554197346, 20.264442779676134, 22.69132182883739, 25.17969896137865, 27.72621725521295, 30.32793302366032, 32.98224041275514, 35.68681367302498, 38.43956215329413, 41.23859465328172, 44.08219079318179, 46.9687777334786, 49.896911035492, 52.865258769661324, 55.87258820196941, 58.9177545493537, 61.99969141201624, 65.11740257718908, 68.26995495388569, 71.45647244747593, 74.6761306207564, 77.92815201751392, 81.21180204752484, 84.52638535004436, 87.87124256725134, 91.24574747066798, 94.6493043929055, 98.08134592466989, 101.54133084316666, 105.0287422431469, 108.54308584606093, 112.08388846629755, 115.65069661642255, 119.24307523579631, 122.86060652902856, 126.50288890249062, 130.16953598860377, 133.86017574890028, 137.5744496479514, 141.31201189119727, 145.07252872052769, 148.85567776216695, 152.66114742202515, 156.48863632421265, 160.33785278887638, 164.20851434592572, 168.10034728157092, 172.0130862149114, 175.94647370208983, 179.9002598657704, 183.87420204791894, 187.86806448405426, 191.88161799731128, 195.91463971081103, 199.96691277696684, 204.03822612248106, 208.12837420789342, 212.23715680064325, 216.364378760695, 220.50984983785577, 224.67338447998782, 228.85480165138168, 233.0539246606161, 237.2705809972845, 241.50460217701504, 245.7558235942569, 250.02408438234494, 254.3092272803913, 258.61109850658704, 262.92954763752573, 267.2644274931912, 271.6155940272749, 275.9829062225139, 280.3662259907599, 284.7654180775129, 289.180349970667, 293.6108918132363, 298.0569163198431, 302.51829869676294, 306.9949165653396, 311.4866498885879, 315.99338090082017, 320.5149940401391, 325.0513758836497, 329.60241508525445, 334.1680023158995, 338.7480302061538, 343.34239329100325, 347.9509879567558, 352.5737123899531, 357.2104665281951, 361.86115201278767], [0.0, 0.9099715891387324, 2.240612876541492, 3.7956439285009558, 5.517036050845481, 7.373757293703414, 9.345971635241007, 11.419715518310404, 13.584536224441829, 15.832266637689186, 18.156320195008576, 20.5512538556131, 23.012481532014032, 25.536077699713612, 28.1186379247122, 30.757176857109528, 33.4490517612064, 36.19190397023205, 38.98361324315629, 41.82226161275511, 44.70610434997258, 47.63354635424196, 50.603122743142485, 53.613482735761174, 56.66337615068427, 59.751642002259054, 62.87719879748823, 66.03903622379077, 69.23620798375583, 72.46782558302206, 75.73305291578389, 79.0311015221674, 82.3612264149884, 85.7227223917726, 89.11492076253377, 92.53718643552233, 95.98891531262153, 99.46953195375794, 102.97848747598603, 106.5152576580822, 110.07934122576721, 113.67025829623726, 117.28754896366218, 120.93077200980838, 124.5995037260539, 128.29333683484862, 132.01187950019298, 135.7547544180043, 139.52159797835301, 143.31205949250514, 147.1258004785334, 150.96249399997203, 154.82182405261062, 158.70348499506142, 162.60718101920511, 166.5326256570347, 170.47954132077538, 174.44765887348046, 178.43671722758282, 182.44646296912887, 186.47665000564453, 190.52703923577593, 194.59739823902265, 198.68750098403666, 202.7971275540974, 206.92606388849904, 211.07410153869603, 215.24103743815309, 219.42667368493667, 223.63081733616391, 227.85328021350057, 232.09387871896354, 236.35243366034456, 240.62877008562558, 244.92271712580546, 249.23410784560264, 253.56277910153926, 257.9085714069488, 262.27132880348444, 266.6508987387349, 271.04713194958407, 275.45988235097616, 279.8890069297723, 284.3343656434053, 288.79582132306206, 293.2732395811378, 297.7664887227267, 302.27543966092827, 306.79996583576064, 311.33994313649174, 315.8952498272029, 320.46576647541985, 325.0513758836497, 329.6519630236762, 334.2674149734742, 338.89762085661033, 343.5424717840094, 348.2018607979672, 352.87568281830397, 357.56383459055326, 362.2662146360903, 366.98272320410945], [0.0, 0.9227120870469747, 2.2719836621874223, 3.848786679449114, 5.594279985825937, 7.47699715360413, 9.476824437120216, 11.579602775682321, 13.77473310247376, 16.053933953886528, 18.410526548511132, 20.838991637632223, 23.334678924022267, 25.893607921976752, 28.51232653206915, 31.18780760656219, 33.917371408855715, 36.698626248522594, 39.52942219907133, 42.40781443984897, 45.33203381387549, 48.30046288760623, 51.311616268824686, 54.364124264355546, 57.456719189014756, 60.588223802207715, 63.75754146897069, 66.9636477313521, 70.20558304284593, 73.48244646929525, 76.79339019859025, 80.13761473164273, 83.51436465071461, 86.92292487980292, 90.3626173666034, 93.83279812745687, 97.33285460627837, 100.86220330626703, 104.42028765957586, 108.00657610536814, 111.6205603510313, 115.26175379493, 118.92969009209975, 122.62392184681741, 126.34401941812327, 130.08956982618065, 133.86017574890028, 137.65545459957102, 141.47503767736634, 145.3185693835648, 149.18570649715903, 153.07611750425096, 156.98948197626018, 160.92548999251864, 164.88384160330222, 168.86424632976988, 172.8664226976447, 176.89009780179794, 180.93500689917943, 185.00089302779088, 189.08750664962128, 193.19460531566256, 197.32195335129845, 201.4693215605196, 205.63648694755489, 209.82323245463797, 214.02934671473844, 218.25462381818963, 222.49886309223618, 226.76186889260492, 231.0434504062797, 235.343421464725, 239.66160036686523, 243.99780971118187, 248.35187623633962, 252.72363066979864, 257.11290758391186, 261.51954525904233, 265.94338555327306, 270.3842737783086, 274.84205858120254, 279.3165918315644, 283.8077285139306, 288.3153266250002, 292.8392470754617, 297.3793535961516, 301.93551264830575, 306.50759333767996, 311.09546733232816, 315.69900878384567, 320.31809425189135, 324.95260263181865, 329.60241508525445, 334.2674149734742, 338.94748779343325, 343.6425211163191, 348.35240452850223, 353.0770295747654, 357.81628970370286, 362.57008021518396, 367.33829820978343, 372.12084254008596], [0.0, 0.9354933117266965, 2.303454728907713, 3.902099308583292, 5.67177084177532, 7.580567034059147, 9.608095528158762, 11.740001134884036, 13.965537971248557, 16.27630986045422, 18.66554550793712, 21.127649213444233, 23.657906264753862, 26.252281039263615, 28.907273619750917, 31.619814927028894, 34.38718810531792, 37.20696833496979, 40.07697590913798, 42.99523906789989, 45.95996414826417, 48.96951131231775, 52.02237459248597, 55.117165322875536, 58.252598258578836, 61.42747985209823, 64.64069827810015, 67.8912148880448, 71.17805684397844, 74.50031073218301, 77.85711699682363, 81.24766506430946, 84.67118905300582, 88.1269639818189, 91.61430240619852, 95.13255142215165, 98.68108998858804, 102.25932652622495, 105.86669675774807, 109.50266175924546, 113.16670619733617, 116.85833673007559, 120.57708055278135, 124.32248407249357, 128.09411169695124, 131.89154472580293, 135.7143803333327, 139.56223063331421, 143.43472181775027, 147.3314933622365, 151.2521972915363, 155.19649749968687, 159.1640691195947, 163.15459793763213, 167.16777984923112, 171.20332035189526, 175.26093407242186, 179.34034432545448, 183.44128270077482, 187.56348867699793, 191.70670925956188, 195.870698641103, 200.05521788248706, 204.26003461292706, 208.48492274775867, 212.72966222257455, 216.99403874253005, 221.27784354573873, 225.58087317976603, 229.90292929031318, 234.24381842125993, 238.60335182530125, 242.98134528447423, 247.3776189399298, 251.79199713035095, 256.2243082384683, 260.6743845451638, 265.14206209069226, 269.6271805425861, 274.12958306983853, 278.6491162229919, 283.1856298197831, 287.7389768360232, 292.30901330140966, 296.8955981999934, 301.49859337503756, 306.1178634380256, 310.75327568159213, 315.40469999616244, 320.0720087901048, 324.7550769132069, 329.4537815833047, 334.1680023158995, 338.89762085661033, 343.6425211163191, 348.40258910887167, 353.1777128912109, 357.96778250581923, 362.7726899253622, 367.59232899942367, 372.426595403236, 377.2753865883098], [0.0, 0.9483149626003916, 2.335025336593731, 3.9555805621443643, 5.749506796332409, 7.684464499403875, 9.739781821239555, 11.900906823809201, 14.156946343586547, 16.49938912775292, 18.92137107597684, 21.41721979465628, 23.982155952834905, 26.61208861661795, 29.30346989974218, 32.05318865894464, 34.85849080186063, 37.716918274835294, 40.626261496473724, 43.584521682376476, 46.58988058602995, 49.64067589428906, 52.73538099914248, 55.872588201969414, 59.05099464259844, 62.269390415051184, 65.52664845557807, 68.82171588016716, 72.153606517377, 75.52139443445635, 78.92420829470065, 82.3612264149884, 85.83167241669175, 89.33481138229685, 92.86994644530051, 96.43641575316146, 100.0335897529466, 103.66086875732698, 107.31768075513635, 111.00347943609866, 114.7177424037951, 118.4599695546526, 122.22968160383925, 126.02641874155697, 129.84973940541983, 133.69921915646808, 137.57444964795144, 141.47503767736634, 145.4006043133913, 149.35078409035944, 153.32522426376752, 157.32358412106362, 161.34553434260243, 165.39075640821838, 169.45894204535782, 173.54979271514256, 177.66301913311207, 181.7983408217256, 185.95548569199758, 190.13418965189848, 194.33419623938244, 198.55525627810798, 202.79712755409744, 207.0595745117446, 211.34236796772197, 215.64528484147127, 219.96810790107324, 224.31062552340026, 228.67263146754658, 233.05392466061616, 237.4543089950248, 241.87359313654136, 246.31159034235495, 250.7681182885135, 255.2429989061274, 259.7360582257814, 264.2471262296387, 268.77603671076054, 273.32262713920034, 277.88673853446244, 282.46821534394707, 287.06690532702856, 291.6826594444389, 296.3153317526526, 300.9647793029892, 305.63086204516816, 310.3134427350698, 315.01238684647296, 319.7275624865517, 324.4588403149334, 329.20609346612656, 333.96919747514363, 338.7480302061538, 343.5424717840094, 348.35240452850223, 353.1777128912109, 358.01828339481295, 362.8740045747391, 367.7447669230577, 372.63046283447994, 377.53098655438754, 382.44623412878576], [0.0, 0.9611767444219128, 2.3666947582641846, 4.009229208611191, 5.8274860594592965, 7.788687157175231, 9.871880284001858, 12.06231613725751, 14.348953811897388, 16.72316661890167, 19.17799736169517, 21.707696713281585, 24.30742052171742, 26.973022368694746, 29.700906248769623, 32.48791882294515, 35.33126864572342, 38.2284643254226, 41.17726631259397, 44.17564871377638, 47.221768621989106, 50.31394117850902, 53.45061907028486, 56.63037550639714, 59.85188995627595, 63.11393610426119, 66.415371600492, 69.75512928092822, 73.13220959890768, 76.5456740634622, 79.99463952014413, 83.47827314152926, 86.9957880191416, 90.54643926794694, 94.12952056999893, 97.7443610961997, 101.39032275513178, 105.06679772604231, 108.77320623970668, 112.50899457636586, 116.27363325445631, 120.06661538761307, 123.88745519057221, 127.73568661723911, 131.61086211641688, 135.51255149257597, 139.44034086065122, 143.3938316852223, 147.37263989560768, 151.37639506941215, 155.40473967793838, 159.457328387627, 163.53382741234466, 167.63391391190868, 171.75727543273433, 175.903609386928, 180.07262256652928, 184.26403068994387, 188.47755797790467, 192.71293675656156, 196.96990708553182, 201.24821640895152, 205.54761922774946, 209.86787679153187, 214.20875680860954, 218.57003317283292, 222.95148570601526, 227.3528999148322, 231.77406676117914, 236.21478244505371, 240.67484819910888, 245.1540700940904, 249.65225885443687, 254.16922968337755, 258.7048020969147, 263.25879976612515, 267.8310503672585, 272.4213854391489, 277.02964024749264, 281.65565365557757, 286.29926800107916, 290.96032897856634, 295.63868552738523, 300.33418972461124, 305.04669668278325, 309.77606445215037, 314.5221539271818, 319.28482875710773, 324.0639552602695, 328.8594023420803, 333.6710414164004, 338.4987463301519, 343.34239329100325, 348.2018607979672, 353.0770295747654, 357.96778250581923, 362.8740045747391, 367.7955828051869, 372.73240620399946, 377.68436570646185, 382.6513541236297, 387.63326609160384], [0.0, 0.9740783671278331, 2.39846227969914, 4.063044038080632, 5.905706872540217, 7.893232656907186, 10.004387937314679, 12.224225435069357, 14.541556045961133, 16.947637287191792, 19.435418577565866, 21.999073418382526, 24.63369263592047, 27.335074155589098, 30.099573703708934, 32.92399561484287, 35.80551097465408, 38.741594950165265, 41.72997793104434, 44.768606830794916, 47.85561400558043, 50.989291981262156, 54.1680726756126, 57.390510146272916, 60.65526613753859, 63.96109787323686, 67.30684767004504, 70.6914340396607, 74.11384401876961, 77.57312651928613, 81.06838653241265, 84.59878005190141, 88.16350960681093, 91.76182031371097, 95.39299637393518, 99.05635795402303, 102.75125839762377, 106.47708172536639, 110.23324038593644, 114.01917322714016, 117.83434366032216, 121.67823799531514, 125.55036392628729, 129.4502491515298, 133.37744011248373, 137.33150083921805, 141.31201189119727, 145.3185693835648, 149.35078409035944, 153.4082806171035, 157.49069663608594, 161.5976821784259, 165.72889897766652, 169.88401986022615, 174.06272817853784, 178.2647172831502, 182.4896900304495, 186.7373583230043, 191.00744267983495, 195.29967183417563, 199.61378235653217, 203.94951830104972, 208.30663087338758, 212.68487811846825, 217.08402462661223, 221.50384125670658, 225.94410487517067, 230.4045981095926, 234.8851091160043, 239.38543135884953, 243.90536340277941, 248.44470871547838, 253.00327548078886, 257.58087642146165, 262.17732863090987, 266.79245341339345, 271.4260761321057, 276.0780260646707, 280.7481362655997, 285.43624343528467, 290.1421877951412, 294.865812968537, 299.6069658671708, 304.3654965825874, 309.1412582825394, 313.9341071119217, 318.74390209802675, 323.57050505988394, 328.413780521461, 333.27359562852286, 338.149820068952, 343.0423259963508, 347.9509879567558, 352.87568281830397, 357.81628970370286, 362.7726899253622, 367.7447669230577, 372.73240620399946, 377.73549528519237, 382.7539236379745, 387.78758263463243, 392.83636549699503], [0.0, 0.9870195456944258, 2.4303271990878597, 4.117023861670976, 5.984167507514433, 7.998098688971823, 10.137301853807873, 12.386631140331012, 14.734748790793134, 17.172796173598528, 19.69362903661792, 22.291343472840587, 24.96096508741325, 27.69823597882268, 30.49946345716539, 33.361409400792894, 36.28120731165146, 39.25629881293866, 42.28438414127357, 45.3633829337518, 48.49140273383876, 51.66671338264213, 54.88772596508072, 58.15297532863879, 61.46110543813265, 64.8108570064096, 68.2010569696734, 71.63060947144164, 75.0984880906132, 78.60372910336264, 82.14542561019748, 85.7227223917726, 89.33481138229685, 92.98092766928936, 96.6603459442962, 100.37237734188724, 104.11636661451867, 107.89168959918732, 111.69775093862931, 115.53398202542861, 119.39983914204798, 123.29480177365753, 127.21837107386575, 131.17006846617022, 135.14943436623165, 139.15602701201342, 143.18942139047678, 147.24920825092784, 151.33499319631972, 155.44639584484818, 159.58304905507487, 163.74459820858561, 167.93070054486356, 172.1410245436422, 176.37524935051366, 180.63306424201625, 184.91416812681635, 189.21826907994614, 193.54508390736422, 197.8943377383732, 202.26576364367008, 206.65910227701548, 211.07410153869603, 215.51051625912507, 219.96810790107318, 224.44664427915896, 228.94589929534672, 233.46565268930996, 238.0056898026144, 242.5658013557629, 247.14578323722466, 251.7454363036419, 256.36456619047163, 261.00298313238113, 265.6605017927666, 270.3369411018147, 275.0321241025707, 279.7458778045159, 284.4780330441968, 289.2284243524785, 293.9968898280281, 298.783271016662, 303.5874127962147, 308.40916326661306, 313.24837364486064, 318.1048981646565, 322.9785939803913, 327.8693210752827, 332.7769421734231, 337.7013226555344, 342.6423304782292, 347.5998360965987, 352.5737123899531, 357.56383459055326, 362.57008021518396, 367.59232899942367, 372.63046283447994, 377.68436570646185, 382.7539236379745, 387.8390246319205, 392.9395586174062, 398.05541739765255], [0.0, 1.0, 2.4622888266898326, 4.171167510947729, 6.062866266041593, 8.103282983463812, 10.270619156458233, 12.549529737646983, 14.92852786458892, 17.398638404385867, 19.952623149688797, 22.584500550247288, 25.289230792133658, 28.06249997748054, 30.900566853219953, 33.800150712639834, 36.75834735990512, 39.77256477258468, 42.84047294273594, 45.95996414826417, 49.129121044631624, 52.346190719345465, 55.60956336124428, 58.91775454935371, 62.26939041505118, 65.6631951100942, 69.09798014353402, 72.57263524710176, 76.0861205010657, 79.6374595075119, 83.22573344016544, 86.8500758325527, 90.5096679918781, 94.20373494617257, 97.93154184833291, 101.69239077354787, 105.4856178570068, 109.31059072723754, 113.16670619733617, 117.05338818203819, 120.97008581328876, 124.91627173088294, 128.89144052801933, 132.89510733435824, 136.92680652149207, 140.98609051769998, 145.07252872052769, 149.185706497159, 153.32522426376747, 157.49069663608591, 161.68175164433939, 165.89803000646936, 170.13918445425972, 174.40487910756718, 178.69478889237536, 183.00859899884796, 187.34600437595026, 191.70670925956188, 196.09042673131054, 200.49687830562968, 204.92579354278573, 209.3769096858348, 213.8499713196592, 218.3447300504073, 222.8609442038078, 227.3983785409717, 231.9568039904113, 236.53599739512075, 241.13574127365786, 245.7558235942569, 250.39603756108315, 255.05618141181216, 259.73605822578133, 264.4354757420232, 269.15424618654225, 273.8921861082466, 278.6491162229919, 283.42486126523295, 288.21924984682033, 293.03211432250754, 297.86329066177115, 302.71261832657075, 307.5799401547041, 312.4651022484354, 317.36795386809905, 322.2883473303977, 327.22613791113633, 332.18118375214897, 337.15334577219045, 342.1424875815826, 347.148475400414, 352.17117798010975, 357.2104665281951, 362.2662146360903, 367.33829820978343, 372.426595403236, 377.53098655438754, 382.6513541236297, 387.78758263463243, 392.9395586174062, 398.1071705534973, 403.2903088232132], [0.0, 1.0130194546923375, 2.494346484508369, 4.225473837370663, 6.141801478698022, 8.208783309126208, 10.404337017227993, 12.712917771476418, 15.12288915674523, 17.625159188800126, 20.21239542277945, 22.8785384319103, 25.618482786635905, 28.427858424491067, 31.30287538333299, 34.24021024343722, 37.23692099792261, 40.2903818776394, 43.398232539212195, 46.55833781915394, 49.76875541014656, 53.02770957773243, 56.33356955188666, 59.68483158528327, 63.0801039222794, 66.51809410378416, 69.99759816534478, 73.51749138360492, 77.07672029964503, 80.6742958033828, 84.30928710592622, 87.98081645988069, 91.68805451351686, 95.43021620515323, 99.20655712037802, 103.01637024777953, 106.8589830793893, 110.73375501060343, 114.64007500135344, 118.57735946605881, 122.54505036466304, 126.54261347101887, 130.56953679820398, 134.62532916313123, 138.7095188751651, 142.82165253544494, 146.9612939353074, 151.1280230436431, 155.32143507426204, 159.5411396254041, 163.7867598844506, 168.0579318916866, 172.35430385765318, 176.6755355292307, 181.02129760011644, 185.39127116182158, 189.78514719171338, 194.20262607498384, 198.64341715773992, 203.1072383286849, 207.5938156271073, 212.1028828751111, 216.63418133221316, 221.1874593706092, 225.7624721695608, 230.35898142749684, 234.9767550905438, 239.61556709631333, 244.27519713187343, 248.95543040492035, 253.65605742725046, 258.37687380970385, 263.1176800678182, 267.8782814374931, 272.65848770001816, 277.45811301586815, 282.27697576671693, 287.11489840515765, 291.97170731166045, 296.8472326583293, 301.7413082790526, 306.6537715456723, 311.5844632498201, 316.5332274900955, 321.49991156428456, 326.4843658663341, 331.48644378781887, 336.506001623657, 341.5428984818414, 346.5969961969746, 351.66815924740365, 356.75625467576884, 361.86115201278767, 366.98272320410945, 372.12084254008596, 377.2753865883098, 382.44623412878576, 387.63326609160384, 392.83636549699503, 398.05541739765255, 403.2903088232132, 408.5409287267957]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 2.7\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.001995262314968879, 0.005086165575666436, 0.008792526660959284, 0.012965252773542098, 0.017523042159652173, 0.022413216593427203, 0.027598301448902, 0.03305000141679724, 0.03874604582249407, 0.04466835921509631, 0.05080191984912899, 0.05713400680312215, 0.06365368133398491, 0.07035141681531729, 0.07721882692514963, 0.0842484610773912, 0.0914336472335261, 0.09876836893931785, 0.10624716762189358, 0.11386506388503059, 0.12161749333217217, 0.12950025366385745, 0.13750946064114491, 0.14564151110450074, 0.1538930516681145, 0.16226095202444843, 0.1707422820273849, 0.17933429189785938, 0.18803439502934174, 0.19684015297315252, 0.2057492622632959, 0.21475954280296433, 0.22386892758426616, 0.23307545355210224, 0.24237725345473807, 0.2517725485491946, 0.2612596420504011, 0.27083691323011094, 0.28050281208563704, 0.2902558545101049, 0.30009461790562536, 0.31001773718889913, 0.320023901145597, 0.3301118490956195, 0.34028036783623034, 0.35052828883422216, 0.36085448564182876, 0.37125787151415557, 0.3817373972085201, 0.3922920489483754, 0.4029208465364432, 0.41362284160340346, 0.42439711597997093, 0.4352427801814922, 0.4461589719953403, 0.4571448551623826, 0.4681996181446849, 0.47932247297239156, 0.4905126541634126, 0.5017694177101616, 0.5130920401281289, 0.5244798175615637, 0.5359320649419675, 0.5474481151954883, 0.5590273184956533, 0.5706690415581855, 0.5823726669749315, 0.5941375925841781, 0.6059632308748616, 0.6178490084223816, 0.6297943653539098, 0.6417987548412617, 0.6538616426195442, 0.6659825065299302, 0.6781608360850471, 0.6903961320555657, 0.7026879060766946, 0.7150356802733734, 0.727438986903045, 0.7398973680149757, 0.7524103751251506, 0.7649775689058564, 0.7775985188891104, 0.7902728031831627, 0.8030000082013438, 0.8157797284025792, 0.8286115660429461, 0.8414951309376689, 0.854430040233013, 0.8674159181875502, 0.8804523959623135, 0.8935391114193875, 0.9066757089285024, 0.9198618391812381, 0.9330971590124537, 0.9463813312285921, 0.9597140244425256, 0.9730949129146276, 0.9865236763997746, 1.0, 1.0135235740225363], [0.0, 0.005086165575666436, 0.012965252773542098, 0.022413216593427206, 0.033050001416797245, 0.04466835921509631, 0.05713400680312215, 0.07035141681531729, 0.08424846107739119, 0.09876836893931785, 0.11386506388503059, 0.12950025366385745, 0.14564151110450074, 0.16226095202444843, 0.17933429189785938, 0.1968401529731525, 0.21475954280296433, 0.2330754535521023, 0.2517725485491946, 0.270836913230111, 0.29025585451010494, 0.3100177371888991, 0.3301118490956195, 0.35052828883422216, 0.3712578715141555, 0.3922920489483754, 0.41362284160340346, 0.4352427801814922, 0.4571448551623827, 0.47932247297239156, 0.5017694177101616, 0.5244798175615637, 0.5474481151954883, 0.5706690415581855, 0.594137592584178, 0.6178490084223816, 0.6417987548412617, 0.6659825065299302, 0.6903961320555656, 0.7150356802733733, 0.7398973680149756, 0.7649775689058563, 0.7902728031831628, 0.8157797284025793, 0.8414951309376688, 0.8674159181875502, 0.8935391114193875, 0.919861839181238, 0.9463813312285924, 0.9730949129146276, 1.0, 1.0270940938429944, 1.0543747769352194, 1.0818397087518348, 1.109486621888605, 1.1373133184609963, 1.1653176667430794, 1.1934975980262572, 1.221851103679823, 1.250376232397111, 1.279071087612569, 1.307933825076456, 1.3369626505751175, 1.3661558177858835, 1.3955116262566187, 1.4250284195008498, 1.4547045832001664, 1.484538543506321, 1.5145287654360924, 1.5446737513525413, 1.5749720395268296, 1.6054222027752316, 1.6360228471663998, 1.6667726107943388, 1.697670162612885, 1.7287142013278258, 1.759903454343068, 1.7912366767575416, 1.8227126504097724, 1.8543301829672674, 1.886088107058077, 1.9179852794420666, 1.950020580219625, 1.9821929120756674, 2.0145011995569675, 2.046944388380955, 2.0795214447742576, 2.112231354839387, 2.14507312394804, 2.1780457761596232, 2.211148353663676, 2.2443799162449474, 2.277739540769981, 2.3112263206940975, 2.344839365587778, 2.3785778006814686, 2.4124407664279057, 2.4464274180811185, 2.480536925291301, 2.514768471714803, 2.5491212546385245, 2.5835944846180494], [0.0, 0.008792526660959284, 0.022413216593427206, 0.038746045822494087, 0.05713400680312216, 0.07721882692514964, 0.09876836893931787, 0.12161749333217219, 0.14564151110450074, 0.1707422820273849, 0.19684015297315252, 0.2238689275842662, 0.2517725485491947, 0.28050281208563704, 0.3100177371888992, 0.3402803678362304, 0.3712578715141555, 0.4029208465364433, 0.4352427801814922, 0.46819961814468497, 0.5017694177101616, 0.5359320649419675, 0.5706690415581857, 0.6059632308748618, 0.6417987548412619, 0.6781608360850471, 0.7150356802733734, 0.7524103751251507, 0.790272803183163, 0.8286115660429462, 0.8674159181875503, 0.9066757089285022, 0.9463813312285921, 0.9865236763997746, 1.0270940938429944, 1.0680843551360863, 1.1094866218886048, 1.1512934168741917, 1.1934975980262572, 1.236092334944683, 1.279071087612569, 1.3224275870647892, 1.3661558177858835, 1.4102500016448956, 1.4547045832001664, 1.4995142162286335, 1.5446737513525415, 1.5901782246521388, 1.6360228471664005, 1.6822029951953805, 1.7287142013278258, 1.7755521461263193, 1.8227126504097724, 1.8701916680796558, 1.917985279442067, 1.9660896849828002, 2.014501199556968, 2.06321624695864, 2.1122313548393876, 2.1615431499476676, 2.211148353663676, 2.261043777806694, 2.3112263206940975, 2.361692963433086, 2.4124407664279057, 2.4634668660868657, 2.5147684717148033, 2.5663428625779034, 2.6181873851288726, 2.670299450381465, 2.72267653142428, 2.7753161610645436, 2.8282159295933385, 2.8813734826644306, 2.9347865192794136, 2.9884527898725026, 3.0423700944887586, 3.0965362810500223, 3.1509492437032542, 3.2056069212463405, 3.2605072956268146, 3.315648390509219, 3.3710282699071925, 3.426645036876564, 3.48249683226607, 3.538581833522457, 3.594898253547017, 3.6514443396007628, 3.70821837225562, 3.765218664389227, 3.822443560221038, 3.879891434387597, 3.937560691054987, 3.995449763066546, 4.053557111124122, 4.111881223001162, 4.170420612786105, 4.229173820154596, 4.2881394096691325, 4.3473159701048525, 4.406702113800223, 4.4662964760314665], [0.0, 0.012965252773542098, 0.033050001416797245, 0.05713400680312216, 0.0842484610773912, 0.11386506388503059, 0.14564151110450074, 0.17933429189785938, 0.21475954280296433, 0.2517725485491946, 0.29025585451010494, 0.3301118490956195, 0.3712578715141555, 0.41362284160340346, 0.4571448551623827, 0.5017694177101616, 0.5474481151954884, 0.5941375925841782, 0.6417987548412618, 0.6903961320555657, 0.7398973680149757, 0.7902728031831628, 0.8414951309376689, 0.8935391114193875, 0.9463813312285922, 1.0, 1.0543747769352194, 1.109486621888605, 1.1653176667430796, 1.221851103679823, 1.279071087612569, 1.3369626505751175, 1.3955116262566187, 1.4547045832001664, 1.5145287654360924, 1.5749720395268296, 1.6360228471664, 1.697670162612885, 1.759903454343068, 1.8227126504097724, 1.8860881070580768, 1.9500205802196249, 2.014501199556968, 2.0795214447742576, 2.14507312394804, 2.2111483536636753, 2.277739540769981, 2.344839365587778, 2.412440766427906, 2.480536925291301, 2.549121254638525, 2.6181873851288726, 2.687729154240321, 2.7577405956912533, 2.828215929593339, 2.8991495532723985, 2.9705360327005566, 3.0423700944887586, 3.114646618393776, 3.187360630298315, 3.260507295626814, 3.3340819131630606, 3.408079909238891, 3.4824968322660705, 3.5573283475859196, 3.6325702326135603, 3.7082183722556197, 3.784268754582081, 3.8607174667345876, 3.937560691054986, 4.014794701419228, 4.0924158597629425, 4.1704206127861045, 4.2488054888251945, 4.327567094882145, 4.406702113800223, 4.486207301577675, 4.566079484810726, 4.6463155582580695, 4.726912482519605, 4.807867281822685, 4.889177041909583, 4.9708389080203945, 5.052850082965915, 5.1352078252854705, 5.217909447484947, 5.300952314350672, 5.3843338413350095, 5.468051493009807, 5.552102781584158, 5.636485265483057, 5.721196547983827, 5.806234275907351, 5.891596138361319, 5.977279865532919, 6.063283227528488, 6.149604033257828, 6.236240129361027, 6.3231893991757495, 6.410449761743044, 6.498019170849886, 6.585895614106734], [0.0, 0.017523042159652173, 0.04466835921509631, 0.07721882692514964, 0.11386506388503059, 0.1538930516681145, 0.1968401529731525, 0.24237725345473807, 0.2902558545101049, 0.34028036783623034, 0.3922920489483753, 0.4461589719953402, 0.5017694177101616, 0.5590273184956533, 0.6178490084223816, 0.678160836085047, 0.7398973680149756, 0.8030000082013438, 0.86741591818755, 0.9330971590124536, 1.0, 1.0680843551360861, 1.137313318460996, 1.207652777325871, 1.279071087612569, 1.3515387987969703, 1.4250284195008498, 1.4995142162286332, 1.5749720395268296, 1.6513791729761802, 1.7287142013278256, 1.8069568947947077, 1.8860881070580766, 1.9660896849827998, 2.0469443883809544, 2.1286358184409053, 2.211148353663675, 2.2944670923312755, 2.378577800681468, 2.4634668660868653, 2.549121254638524, 2.6355284726194026, 2.7226765314242796, 2.81055391554274, 2.899149553272398, 2.9884527898725017, 3.078453362904623, 3.1691413795383547, 3.260507295626814, 3.352541896379735, 3.445236278481977, 3.5385818335224566, 3.63257023261356, 3.7271934120941967, 3.8224435602210374, 3.9183131047625497, 4.014794701419227, 4.111881223001161, 4.209565749300969, 4.307841557606138, 4.406702113800222, 4.506141064007107, 4.606152226736818, 4.706729585495138, 4.807867281822684, 4.909559608732161, 5.011801004515216, 5.1145860468927715, 5.217909447484946, 5.321766046578623, 5.426150808172583, 5.531058815281677, 5.6364852654830555, 5.742425466688776, 5.848874833130308, 5.955828881541621, 6.063283227528487, 6.171233582112576, 6.279675748439784, 6.388605618642951, 6.498019170849886, 6.6079124663282, 6.7182816467591255, 6.829122931632924, 6.940432615759125, 7.052207066885166, 7.164442723417526, 7.277136092239794, 7.390283746622453, 7.5038823242195685, 7.617928525147792, 7.732419110143433, 7.847350898793617, 7.962720767837724, 8.078525649535676, 8.194762530099668, 8.311428448186286, 8.428520493446063, 8.546035805127728, 8.663971570734516, 8.782325024730138, 8.901093447292048], [0.0, 0.022413216593427203, 0.05713400680312215, 0.09876836893931787, 0.14564151110450074, 0.1968401529731525, 0.2517725485491946, 0.31001773718889913, 0.37125787151415546, 0.43524278018149215, 0.5017694177101616, 0.5706690415581855, 0.6417987548412618, 0.7150356802733733, 0.790272803183163, 0.8674159181875502, 0.9463813312285921, 1.0270940938429947, 1.1094866218886048, 1.1934975980262572, 1.279071087612569, 1.3661558177858832, 1.4547045832001664, 1.5446737513525415, 1.6360228471664002, 1.7287142013278258, 1.8227126504097722, 1.9179852794420669, 2.014501199556968, 2.1122313548393876, 2.2111483536636753, 2.311226320694097, 2.4124407664279057, 2.514768471714803, 2.618187385128872, 2.7226765314242796, 2.8282159295933385, 2.934786519279413, 3.042370094488758, 3.150949243703254, 3.2605072956268137, 3.371028269907192, 3.48249683226607, 3.594898253547017, 3.7082183722556197, 3.8224435602210374, 3.9375606910549865, 4.053557111124121, 4.170420612786105, 4.288139409669132, 4.406702113800222, 4.526097714409647, 4.646315558258069, 4.767345331349727, 4.889177041909583, 5.011801004515217, 5.1352078252854705, 5.259388388037795, 5.3843338413350095, 5.510035586349907, 5.636485265483056, 5.763674751675229, 5.891596138361318, 6.020241730017522, 6.149604033257826, 6.279675748439784, 6.410449761743043, 6.5419191376872075, 6.674077112058469, 6.806917085216961, 6.940432615759126, 7.074617414511422, 7.209465338833631, 7.344970387211728, 7.481126694121766, 7.617928525147792, 7.75537027233791, 7.8934464497839425, 8.032151689411148, 8.171480736965409, 8.311428448186287, 8.451989785155064, 8.593159812807757, 8.73493369560366, 8.87730669434077, 9.020274163109855, 9.163831546379612, 9.307974376205834, 9.452698269557873, 9.597998925756256, 9.7438721240156, 9.890313721087375, 10.037319648997423, 10.184885912873389, 10.333008588857632, 10.48168382210131, 10.63090782483568, 10.780676874516884, 10.93098731204068, 11.081835540023775, 11.23321802114866, 11.385131276568952], [0.0, 0.027598301448902, 0.07035141681531729, 0.12161749333217219, 0.17933429189785938, 0.24237725345473807, 0.31001773718889913, 0.3817373972085201, 0.4571448551623826, 0.5359320649419674, 0.6178490084223816, 0.7026879060766946, 0.790272803183163, 0.8804523959623136, 0.9730949129146276, 1.0680843551360863, 1.1653176667430794, 1.2647025606569313, 1.3661558177858832, 1.4696019356065344, 1.5749720395268296, 1.6822029951953803, 1.7912366767575416, 1.9020193577451672, 2.014501199556968, 2.1286358184409053, 2.244379916244948, 2.361692963433086, 2.480536925291301, 2.6008760240944233, 2.72267653142428, 2.8459065859318877, 2.970536032700556, 3.096536281050022, 3.2238801781663504, 3.3525418963797344, 3.48249683226607, 3.613721516036183, 3.746193529912533, 3.879891434387597, 4.014794701419227, 4.150883653752411, 4.288139409669132, 4.426543832562466, 4.566079484810725, 4.706729585495138, 4.8484779715621205, 4.9913090620803935, 5.135207825285471, 5.280159748140336, 5.426150808172584, 5.573167447375451, 5.721196547983828, 5.87022540995696, 6.020241730017522, 6.171233582112577, 6.3231893991757495, 6.476097956082213, 6.629948353698834, 6.784730003941373, 6.940432615759126, 7.0970461819748705, 7.254560966914733, 7.412967494768547, 7.572256538626587, 7.732419110143435, 7.8934464497839425, 8.055330017610173, 8.218061484571678, 8.381632724264566, 8.546035805127728, 8.711262983047032, 8.87730669434077, 9.044159549101629, 9.211814324872385, 9.380263960634403, 9.549501551089358, 9.719520341216306, 9.890313721087377, 10.061875220926652, 10.234198506397883, 10.407277374107688, 10.581105747311888, 10.755677671813348, 10.930987312040678, 11.107028947297652, 11.283796968174055, 11.461285873109212, 11.639490265099944, 11.81840484854542, 11.99802442622163, 12.178343896378836, 12.359358249955681, 12.541062567904023, 12.72345201861901, 12.906521855469117, 13.090267414421268, 13.274684111756427, 13.459767441871328, 13.645512975162209, 13.83191635598674, 14.018973300700456], [0.0, 0.03305000141679724, 0.08424846107739119, 0.14564151110450074, 0.21475954280296433, 0.2902558545101049, 0.37125787151415546, 0.4571448551623826, 0.5474481151954883, 0.6417987548412617, 0.7398973680149756, 0.8414951309376688, 0.9463813312285921, 1.0543747769352194, 1.1653176667430794, 1.2790710876125688, 1.3955116262566187, 1.5145287654360926, 1.6360228471663998, 1.759903454343068, 1.8860881070580768, 2.0145011995569675, 2.14507312394804, 2.277739540769981, 2.4124407664279057, 2.5491212546385245, 2.6877291542403206, 2.8282159295933385, 2.9705360327005566, 3.1146466183937758, 3.2605072956268137, 3.4080799092388907, 3.557328347585919, 3.7082183722556192, 3.860717466734587, 4.014794701419227, 4.170420612786104, 4.327567094882145, 4.486207301577674, 4.646315558258069, 4.807867281822684, 4.970838908020394, 5.13520782528547, 5.300952314350672, 5.468051493009806, 5.6364852654830555, 5.80623427590735, 5.9772798655329185, 6.149604033257828, 6.323189399175749, 6.498019170849885, 6.674077112058469, 6.851347513785627, 7.0298151672560785, 7.209465338833632, 7.390283746622454, 7.572256538626587, 7.75537027233791, 7.939611895635579, 8.124968728891478, 8.311428448186286, 8.498979069549831, 8.68760893414739, 8.877306694340772, 9.068061300559407, 9.259861988922435, 9.452698269557871, 9.64655991556964, 9.841436952607337, 10.037319648997421, 10.234198506397881, 10.432064250941506, 10.630907824835678, 10.830720378389127, 11.031493262438367, 11.233218021148659, 11.43588638516619, 11.639490265099942, 11.844021745313304, 12.049473078006876, 12.255836677575354, 12.463105115222422, 12.67127111381894, 12.880327542990445, 13.090267414421264, 13.301083877363036, 13.512770214336575, 13.725319837016563, 13.938726282289215, 14.152983208473847, 14.368084391699725, 14.584023722430128, 14.800795202126151, 15.01839294004309, 15.236811150152864, 15.45604414818614, 15.67608634878832, 15.896932262783894, 16.118576494543902, 16.341013739451654, 16.564238781462045, 16.78824649075011], [0.0, 0.03874604582249407, 0.09876836893931785, 0.1707422820273849, 0.2517725485491946, 0.34028036783623034, 0.43524278018149215, 0.5359320649419674, 0.6417987548412617, 0.7524103751251505, 0.86741591818755, 0.9865236763997743, 1.1094866218886048, 1.2360923349446828, 1.3661558177858832, 1.499514216228633, 1.6360228471663998, 1.775552146126319, 1.9179852794420666, 2.0632162469586395, 2.2111483536636753, 2.3616929634330854, 2.514768471714803, 2.6702994503814645, 2.828215929593339, 2.9884527898725017, 3.1509492437032534, 3.3156483905092187, 3.48249683226607, 3.6514443396007623, 3.822443560221037, 3.995449763066545, 4.170420612786104, 4.347315970104852, 4.526097714409646, 4.706729585495138, 4.889177041909582, 5.07340713374378, 5.259388388037794, 5.447090705252986, 5.6364852654830555, 5.827544443266133, 6.0202417300175215, 6.2145516632353255, 6.410449761743043, 6.6079124663282, 6.806917085216961, 7.007441743893662, 7.209465338833633, 7.412967494768546, 7.617928525147791, 7.82432939549737, 8.032151689411148, 8.24137757693818, 8.451989785155064, 8.663971570734516, 8.87730669434077, 9.091979396699596, 9.307974376205834, 9.525276767944774, 9.743872124015597, 9.963746395055596, 10.184885912873385, 10.407277374107688, 10.630907824835678, 10.855764646061795, 11.081835540023773, 11.309108517258156, 11.537571884372475, 11.767214232475569, 11.998024426221628, 12.229991593427037, 12.463105115222422, 12.69735461670525, 12.932729958060984, 13.169221226123325, 13.40681872634619, 13.645512975162207, 13.885294692704337, 14.126154795868867, 14.368084391699725, 14.611074771075275, 14.855117402680326, 15.100203927246993, 15.346326152049466, 15.593476045638472, 15.84164573280236, 16.090827489742534, 16.341013739451657, 16.592197047284053, 16.844370116708088, 17.097525785231195, 17.35165702048867, 17.60675691648794, 17.862818690000584, 18.119835677094656, 18.377801329800544, 18.636709212903813, 18.896553000858997, 19.15732647481851, 19.41902351977134, 19.681638121786342], [0.0, 0.04466835921509631, 0.11386506388503059, 0.19684015297315252, 0.29025585451010494, 0.3922920489483753, 0.5017694177101616, 0.6178490084223816, 0.7398973680149756, 0.86741591818755, 1.0, 1.137313318460996, 1.279071087612569, 1.4250284195008498, 1.5749720395268296, 1.7287142013278256, 1.8860881070580768, 2.046944388380955, 2.2111483536636753, 2.3785778006814686, 2.5491212546385245, 2.7226765314242796, 2.899149553272398, 3.078453362904623, 3.260507295626814, 3.445236278481977, 3.63257023261356, 3.8224435602210374, 4.014794701419228, 4.209565749300969, 4.406702113800222, 4.606152226736818, 4.807867281822684, 5.011801004515216, 5.217909447484946, 5.426150808172583, 5.6364852654830555, 5.848874833130308, 6.063283227528487, 6.279675748439784, 6.498019170849885, 6.7182816467591255, 6.940432615759126, 7.164442723417527, 7.390283746622453, 7.617928525147791, 7.847350898793617, 8.078525649535676, 8.311428448186287, 8.546035805127728, 8.782325024730138, 9.020274163109855, 9.259861988922435, 9.501067946918003, 9.7438721240156, 9.988255217678883, 10.234198506397881, 10.48168382210131, 10.730693524341447, 10.981210476108934, 11.233218021148659, 11.486699962659971, 11.74164054327539, 11.99802442622163, 12.255836677575353, 12.51506274953395, 12.775688464628445, 13.037700000811993, 13.301083877363036, 13.5658269415472, 13.831916355986738, 14.099339586690299, 14.368084391699723, 14.638138810313908, 14.909491152852821, 15.182129990927738, 15.45604414818614, 15.731222691502206, 16.00765492258594, 16.285330369985846, 16.564238781462045, 16.844370116708088, 17.125714540401596, 17.408262415564838, 17.692004297218038, 17.976930926308984, 18.263033223903932, 18.550302285625595, 18.838729376324924, 19.128305924974434, 19.419023519771343, 19.710873903439733, 20.003848968721538, 20.297940754046735, 20.593141439373884, 20.889443342192436, 21.18683891367895, 21.485320734999746, 21.784881513752946, 22.085514080543277, 22.3872113856834, 22.689966496015856], [0.0, 0.05080191984912899, 0.12950025366385745, 0.2238689275842662, 0.3301118490956195, 0.4461589719953402, 0.5706690415581855, 0.7026879060766946, 0.8414951309376688, 0.9865236763997743, 1.137313318460996, 1.293481584348763, 1.4547045832001664, 1.6207038006837398, 1.7912366767575416, 1.9660896849827998, 2.14507312394804, 2.328017115054658, 2.514768471714803, 2.705188211710699, 2.899149553272398, 3.096536281050022, 3.2972413991469454, 3.5011660098924695, 3.7082183722556197, 3.9183131047625497, 4.13137050579636, 4.3473159701048525, 4.566079484810726, 4.787595191617235, 5.011801004515216, 5.238638274326556, 5.468051493009805, 5.699988031911354, 5.934397909148086, 6.171233582112576, 6.410449761743042, 6.652003245730436, 6.895852768269322, 7.14195886431709, 7.390283746622452, 7.640791194031226, 7.8934464497839425, 8.148216128693724, 8.405068132239546, 8.663971570734516, 8.924896691834848, 9.187814814745693, 9.452698269557873, 9.719520341216306, 9.988255217678882, 10.258877941874452, 10.531364367112213, 10.805691115632715, 11.081835540023775, 11.359775687253729, 11.639490265099944, 11.920958610772978, 12.204160661556692, 12.489076927302106, 12.775688464628445, 13.06397685269861, 13.353924170448705, 13.645512975162209, 13.938726282289213, 14.233547546420054, 14.529960643330444, 14.82794985302242, 15.127499843691806, 15.428595656558631, 15.731222691502206, 16.03536669344723, 16.341013739451654, 16.648150226450806, 16.956762859615903, 17.26683864128824, 17.578364860453238, 17.891329082721295, 18.205719140784712, 18.521523125322243, 18.838729376324924, 19.15732647481851, 19.47730323495987, 19.79864869648588, 20.12135211749525, 20.445402967544577, 20.770790921041602, 21.097505850919443, 21.42553782257675, 21.754877088069804, 22.085514080543277, 22.41743940888729, 22.750643852609265, 23.085118356909586, 23.420854027950966, 23.75784212831184, 24.096074072614773, 24.435541423321407, 24.77623588668597, 25.118149308859728, 25.46127367213938, 25.80560109135261], [0.0, 0.05713400680312215, 0.14564151110450074, 0.2517725485491947, 0.3712578715141555, 0.5017694177101616, 0.6417987548412618, 0.790272803183163, 0.9463813312285921, 1.1094866218886048, 1.279071087612569, 1.4547045832001664, 1.6360228471664002, 1.8227126504097722, 2.014501199556968, 2.2111483536636753, 2.4124407664279057, 2.6181873851288726, 2.828215929593339, 3.0423700944887586, 3.260507295626814, 3.48249683226607, 3.70821837225562, 3.9375606910549865, 4.170420612786105, 4.406702113800222, 4.646315558258069, 4.889177041909583, 5.135207825285471, 5.38433384133501, 5.636485265483056, 5.891596138361318, 6.149604033257827, 6.410449761743044, 6.674077112058469, 6.940432615759126, 7.209465338833632, 7.481126694121767, 7.75537027233791, 8.032151689411148, 8.311428448186286, 8.593159812807755, 8.877306694340772, 9.163831546379612, 9.452698269557873, 9.7438721240156, 10.037319648997423, 10.333008588857632, 10.630907824835681, 10.93098731204068, 11.23321802114866, 11.537571884372479, 11.844021745313306, 12.152541312345328, 12.463105115222426, 12.775688464628447, 13.090267414421268, 13.406818726346192, 13.725319837016567, 14.045748826979192, 14.368084391699725, 14.692305814318745, 15.01839294004309, 15.34632615204947, 15.67608634878832, 16.00765492258594, 16.341013739451657, 16.67614512000499, 17.013031821444745, 17.35165702048867, 17.69200429721804, 18.03405761976691, 18.37780132980054, 18.723220128731967, 19.070299064629435, 19.419023519771343, 19.769379198808327, 20.121352117495253, 20.47492859195869, 20.830095228467798, 21.186838913678955, 21.54514680532647, 21.905006323333858, 22.266405141321528, 22.629331178488922, 22.99377259185006, 23.359717768803286, 23.727155320017054, 24.096074072614776, 24.466463063642998, 24.838311533807993, 25.211608921466862, 25.586344856860226, 25.962509156574047, 26.34009181821942, 26.719083015319217, 27.099473092391637, 27.481252560221005, 27.86441209130693, 28.248942515483197, 28.634834815698557, 29.022080123951753], [0.0, 0.06365368133398491, 0.16226095202444843, 0.28050281208563704, 0.41362284160340346, 0.5590273184956533, 0.7150356802733733, 0.8804523959623136, 1.0543747769352194, 1.2360923349446828, 1.4250284195008498, 1.6207038006837398, 1.8227126504097722, 2.0307059963850898, 2.244379916244948, 2.4634668660868653, 2.687729154240321, 2.916953926580646, 3.1509492437032534, 3.3895409639649206, 3.63257023261356, 3.8798914343875968, 4.13137050579636, 4.386883530247051, 4.646315558258069, 4.909559608732161, 5.176515817307135, 5.447090705252986, 5.721196547983828, 5.99875082651127, 6.279675748439784, 6.563897827647087, 6.851347513785626, 7.14195886431709, 7.435669253048024, 7.732419110143435, 8.032151689411146, 8.33481285931398, 8.64035091471093, 8.948716406776962, 9.259861988922435, 9.573742276842722, 9.890313721087375, 10.209534490756042, 10.531364367112213, 10.855764646061797, 11.182698048576441, 11.5121286382549, 11.844021745313306, 12.178343896378838, 12.51506274953395, 12.854147034120787, 13.195566494870132, 13.539291839966745, 13.885294692704338, 14.233547546420056, 14.58402372243013, 14.936697330716656, 15.291543233140295, 15.648537008975689, 16.007654922585935, 16.368873893069807, 16.73217146573083, 17.0975257852312, 17.464915570305752, 17.834320089922326, 18.205719140784712, 18.579093026083342, 18.95442253540688, 19.331688925735055, 19.710873903439737, 20.09195960722704, 20.474928591958687, 20.85976381329568, 21.24644861311176, 21.634966705628205, 22.025302164225053, 22.417439408887294, 22.81136319424764, 23.20705859819012, 23.60451101098154, 24.00370612489987, 24.404629924331207, 24.807268676308407, 25.211608921466862, 25.61763746539404, 26.02534137035133, 26.43470794734804, 26.845724748548538, 27.25837955999506, 27.672660394629588, 28.08855548559927, 28.506053279830958, 28.925142431861104, 29.34581179790842, 29.768050430177038, 30.191847571379018, 30.617192649465526, 31.04407527255664, 31.47248522406035, 31.902412457971845, 32.33384709434471], [0.0, 0.07035141681531729, 0.17933429189785938, 0.3100177371888992, 0.4571448551623827, 0.6178490084223816, 0.790272803183163, 0.9730949129146276, 1.1653176667430794, 1.3661558177858832, 1.5749720395268296, 1.7912366767575416, 2.014501199556968, 2.244379916244948, 2.480536925291301, 2.72267653142428, 2.9705360327005566, 3.2238801781663513, 3.4824968322660705, 3.7461935299125333, 4.014794701419228, 4.288139409669132, 4.566079484810726, 4.848477971562121, 5.135207825285471, 5.426150808172584, 5.721196547983828, 6.020241730017523, 6.32318939917575, 6.629948353698834, 6.940432615759127, 7.254560966914734, 7.572256538626587, 7.893446449783943, 8.218061484571678, 8.546035805127728, 8.877306694340772, 9.211814324872387, 9.549501551089358, 9.890313721087377, 10.234198506397881, 10.581105747311888, 10.93098731204068, 11.283796968174055, 11.639490265099944, 11.99802442622163, 12.359358249955683, 12.72345201861901, 13.09026741442127, 13.459767441871328, 13.83191635598674, 14.206679595764294, 14.584023722430132, 14.963916362040434, 15.34632615204947, 15.731222691502209, 16.118576494543905, 16.508358946970276, 16.900542265569392, 17.295099460030677, 17.69200429721804, 18.091231267623332, 18.49275555383335, 18.896553000859, 19.302600088188576, 19.710873903439737, 20.121352117495253, 20.53401296101781, 20.948835202247892, 21.36579812599661, 21.784881513752946, 22.206065624830988, 22.62933117848892, 23.054659336956934, 23.48203168931583, 23.911430236172908, 24.342837375085445, 24.77623588668597, 25.21160892146687, 25.64893998718483, 26.088212936848684, 26.529411957256517, 26.972521558050584, 27.417526561260406, 27.864412091306928, 28.3131635654418, 28.763766684598227, 29.21620742463095, 29.670472027924465, 30.126546995350125, 30.584419078553747, 31.044075272556636, 31.50550280865403, 31.96868914759574, 32.43362197303516, 32.90028918523297, 33.368678895003335, 33.838779417890635, 34.3105792685658, 34.78406715543176, 35.259231975428044, 35.736062809025526], [0.0, 0.07721882692514963, 0.1968401529731525, 0.3402803678362304, 0.5017694177101616, 0.678160836085047, 0.8674159181875502, 1.0680843551360863, 1.2790710876125688, 1.499514216228633, 1.7287142013278256, 1.9660896849827998, 2.2111483536636753, 2.4634668660868653, 2.72267653142428, 2.988452789872502, 3.2605072956268137, 3.5385818335224566, 3.822443560221037, 4.111881223001161, 4.406702113800222, 4.706729585495138, 5.011801004515216, 5.321766046578624, 5.636485265483056, 5.955828881541621, 6.279675748439784, 6.607912466328201, 6.940432615759127, 7.277136092239795, 7.617928525147791, 7.962720767837723, 8.311428448186286, 8.663971570734516, 9.020274163109853, 9.380263960634402, 9.743872124015597, 10.11103298582128, 10.481683822101308, 10.855764646061797, 11.233218021148659, 11.61398889127259, 11.99802442622163, 12.385273880571681, 12.775688464628445, 13.169221226123325, 13.565826941547202, 13.96546201614342, 14.368084391699727, 14.77365346138038, 15.182129990927736, 15.593476045638473, 16.00765492258594, 16.424631087617758, 16.84437011670809, 17.26683864128824, 17.692004297218038, 18.119835677094656, 18.550302285625595, 18.98337449781941, 19.41902351977134, 19.857221351842096, 20.29794075404673, 20.741155213487467, 21.186838913678947, 21.634966705628205, 22.085514080543277, 22.538457144055496, 22.993772591850057, 23.45143768660827, 23.9114302361729, 24.373728572855114, 24.838311533807982, 25.305158442397655, 25.774249090508246, 26.245563721721872, 26.719083015319214, 27.194788071050404, 27.672660394629588, 28.152681883909864, 28.634834815698554, 29.119101833175314, 29.605465933878676, 30.093910458228372, 30.58441907855374, 31.076975788599725, 31.57156489348463, 32.06817100008499, 32.566779007824586, 33.0673740998465, 33.569941734547776, 34.0744676374583, 34.580937793445905, 35.089338439231426, 35.59965605619817, 36.111877363481064, 36.6259893113218, 37.14197907467726, 37.659834047068735, 38.17954183466082, 38.701090250558885, 39.22446730931517], [0.0, 0.0842484610773912, 0.21475954280296433, 0.3712578715141555, 0.5474481151954884, 0.7398973680149756, 0.9463813312285921, 1.1653176667430794, 1.3955116262566187, 1.6360228471663998, 1.8860881070580768, 2.14507312394804, 2.4124407664279057, 2.687729154240321, 2.9705360327005566, 3.2605072956268137, 3.5573283475859196, 3.860717466734588, 4.1704206127861045, 4.486207301577675, 4.807867281822684, 5.13520782528547, 5.468051493009806, 5.806234275907351, 6.149604033257828, 6.498019170849886, 6.851347513785627, 7.209465338833632, 7.572256538626588, 7.93961189563558, 8.311428448186286, 8.68760893414739, 9.068061300559407, 9.452698269557871, 9.841436952607337, 10.234198506397881, 10.630907824835678, 11.031493262438367, 11.43588638516619, 11.844021745313304, 12.255836677575353, 12.67127111381894, 13.090267414421266, 13.512770214336577, 13.938726282289213, 14.368084391699725, 14.800795202126151, 15.236811150152864, 15.676086348788324, 16.118576494543905, 16.564238781462045, 17.013031821444745, 17.464915570305752, 17.919851259032743, 18.377801329800544, 18.838729376324924, 19.302600088188576, 19.769379198808327, 20.239033436745522, 20.711530480090623, 21.18683891367895, 21.664928188917425, 22.145768586022648, 22.629331178488922, 23.115587799621046, 23.60451101098154, 24.096074072614773, 24.590250914922578, 25.087016112076352, 25.58634485686022, 26.08821293684868, 26.592596711829714, 27.09947309239163, 27.608819519598327, 28.12061394568332, 28.634834815698554, 29.15146105005846, 29.67047202792446, 30.191847571379018, 30.715567930342015, 31.241613768185733, 31.769966148007594, 32.30060651952303, 32.83351670654295, 33.36867889500333, 33.90607562151591, 34.44568976241173, 34.98750452325069, 35.53150342877206, 36.07767031326283, 36.6259893113218, 37.17644484899909, 37.729021635291666, 38.283704653977, 38.84047915576793, 39.399330650772676, 39.96024490124513, 40.52320791461132, 41.08820593675878, 41.65522544557637, 42.22425314473263, 42.79527595768173], [0.0, 0.0914336472335261, 0.2330754535521023, 0.4029208465364433, 0.5941375925841782, 0.8030000082013438, 1.0270940938429947, 1.2647025606569313, 1.5145287654360926, 1.775552146126319, 2.046944388380955, 2.328017115054658, 2.6181873851288726, 2.916953926580646, 3.2238801781663513, 3.5385818335224566, 3.860717466734588, 4.189981329124281, 4.526097714409647, 4.868816481432446, 5.217909447484947, 5.573167447375451, 5.934397909148087, 6.301422836090097, 6.6740771120584705, 7.052207066885168, 7.435669253048026, 7.8243293954973705, 8.21806148457168, 8.616746988052288, 9.020274163109855, 9.428537452547369, 9.841436952607339, 10.258877941874454, 10.680770462609278, 11.107028947297652, 11.537571884372477, 11.972321518018678, 12.4112035777538, 12.854147034120789, 13.301083877363036, 13.751948916396353, 14.206679595764294, 14.665215828576272, 15.127499843691808, 15.593476045638475, 16.063090885941836, 16.53629274470866, 17.01303182144475, 17.49326003420892, 17.976930926308988, 18.46399957983543, 18.954422535406884, 19.448157717569966, 19.945164365355346, 20.445402967544585, 20.948835202247892, 21.455423880433713, 21.965132893086576, 22.477927161701338, 22.99377259185006, 23.512636029582552, 24.034485220443862, 24.55928877091199, 25.087016112076352, 25.617637465394044, 26.151123810374493, 26.68744685405648, 27.226579002152658, 27.768493331747212, 28.3131635654418, 28.860564046853156, 29.410669717373732, 29.96345609411352, 30.518899248947577, 31.07697578859973, 31.637662835697913, 32.20093801074158, 32.766779414926056, 33.33516561377247, 33.90607562151592, 34.47948888620747, 35.05538527548917, 35.63374506300353, 36.2145489154022, 36.79777787992022, 37.383413372485094, 37.97143716633171, 38.56183138109575, 39.15457847236059, 39.74966122163373, 40.34706272673057, 40.9467663925447, 41.54875592218505, 42.15301530846167, 42.7595288257027, 43.368281021886375, 43.9792567110727, 44.59244096612059, 45.20781911167662, 45.825376717422856, 46.445099591571534], [0.0, 0.09876836893931785, 0.2517725485491946, 0.4352427801814922, 0.6417987548412618, 0.86741591818755, 1.1094866218886048, 1.3661558177858832, 1.6360228471663998, 1.9179852794420666, 2.2111483536636753, 2.514768471714803, 2.828215929593339, 3.1509492437032534, 3.4824968322660705, 3.822443560221037, 4.1704206127861045, 4.526097714409647, 4.889177041909582, 5.259388388037795, 5.6364852654830555, 6.0202417300175215, 6.410449761743043, 6.806917085216962, 7.209465338833633, 7.617928525147791, 8.032151689411148, 8.451989785155064, 8.877306694340772, 9.307974376205834, 9.7438721240156, 10.184885912873387, 10.630907824835678, 11.081835540023775, 11.537571884372475, 11.998024426221628, 12.463105115222422, 12.932729958060985, 13.40681872634619, 13.885294692704337, 14.368084391699723, 14.855117402680326, 15.346326152049468, 15.841645732802363, 16.341013739451654, 16.844370116708088, 17.35165702048867, 17.862818690000584, 18.377801329800544, 18.896553000858997, 19.419023519771343, 19.945164365355343, 20.474928591958687, 21.00827074887446, 21.54514680532647, 22.085514080543277, 22.62933117848892, 23.176557926862493, 23.727155320017054, 24.281085465482576, 24.838311533807985, 25.398797711464198, 25.96250915657404, 26.52941195725652, 27.09947309239163, 27.672660394629585, 28.248942515483193, 28.828288892356337, 29.410669717373732, 29.996055907888426, 30.58441907855374, 31.17573151485534, 31.769966148007594, 32.36709653112595, 32.967096816593646, 33.569941734547776, 34.175606572414864, 34.78406715543176, 35.39529982809213, 36.009281436463255, 36.6259893113218, 37.2454012520607, 37.86749551132306, 38.49225078032143, 39.11964617480433, 39.74966122163372, 40.382275845940185, 41.017470358824546, 41.65522544557637, 42.29552215438235, 42.938341885498595, 43.583666380863065, 44.23147771412544, 44.88175828107326, 45.53449079043477, 46.189658255039426, 46.847243983318705, 47.50723157113072, 48.169604893893066, 48.83434809900919, 49.50144559857454, 50.17088206234941], [0.0, 0.10624716762189358, 0.270836913230111, 0.46819961814468497, 0.6903961320555657, 0.9330971590124536, 1.1934975980262572, 1.4696019356065344, 1.759903454343068, 2.0632162469586395, 2.3785778006814686, 2.705188211710699, 3.0423700944887586, 3.3895409639649206, 3.7461935299125333, 4.111881223001161, 4.486207301577675, 4.868816481432446, 5.259388388037795, 5.657632353894693, 6.063283227528488, 6.476097956082213, 6.8958527682693225, 7.322340829438149, 7.7553702723379105, 8.194762530099668, 8.640350914710933, 9.091979396699598, 9.54950155108936, 10.012779641796339, 10.48168382210131, 10.95609143307571, 11.43588638516619, 11.920958610772978, 12.411203577753799, 12.906521855469116, 13.40681872634619, 13.91200383704828, 14.421990884243545, 14.936697330716656, 15.45604414818614, 15.979955583706996, 16.508358946970272, 17.04118441617481, 17.578364860453238, 18.119835677094656, 18.665534642028266, 19.2154017722214, 19.76937919880833, 20.327411049905795, 20.889443342192436, 21.455423880433713, 22.025302164225053, 22.599029301305418, 23.176557926862493, 23.757842128311843, 24.342837375085445, 24.931500453012266, 25.523789402914957, 26.11966346308349, 26.719083015319217, 27.32200953427166, 27.92840553981634, 28.538234552244784, 29.151461050058458, 29.768050430177038, 30.387968970387536, 31.01118379387617, 31.63766283569791, 32.26737481105076, 32.90028918523297, 33.536376145170976, 34.175606572414864, 34.81795201750651, 35.463384675632476, 36.111877363481064, 36.76340349722827, 37.41793707158373, 38.07545263983235, 38.73592529481206, 39.39933065077268, 40.06564482606418, 40.734844426607076, 41.40690653010008, 42.08180867092397, 42.7595288257027, 43.440045399486, 44.12333721251975, 44.80938348757231, 45.49816383778799, 46.18965825503943, 46.883847098753435, 47.58071108518594, 48.280231277123235, 48.982389073988344, 49.68716620233223, 50.394544706691036, 51.10450694079165, 51.817035559088865, 52.53211350861824, 53.24972402114996, 53.9698506056296], [0.0, 0.11386506388503059, 0.29025585451010494, 0.5017694177101616, 0.7398973680149757, 1.0, 1.279071087612569, 1.5749720395268296, 1.8860881070580768, 2.2111483536636753, 2.5491212546385245, 2.899149553272398, 3.260507295626814, 3.63257023261356, 4.014794701419228, 4.406702113800222, 4.807867281822684, 5.217909447484947, 5.6364852654830555, 6.063283227528488, 6.498019170849885, 6.940432615759126, 7.390283746622453, 7.847350898793617, 8.311428448186287, 8.782325024730138, 9.259861988922435, 9.7438721240156, 10.234198506397883, 10.730693524341447, 11.233218021148659, 11.74164054327539, 12.255836677575353, 12.775688464628445, 13.301083877363034, 13.831916355986738, 14.368084391699723, 14.909491152852821, 15.45604414818614, 16.00765492258594, 16.56423878146204, 17.125714540401596, 17.692004297218038, 18.263033223903932, 18.838729376324924, 19.41902351977134, 20.003848968721538, 20.593141439373884, 21.186838913678955, 21.784881513752946, 22.3872113856834, 22.99377259185006, 23.60451101098154, 24.219374245253487, 24.83831153380799, 25.461273672139384, 26.08821293684868, 26.719083015319217, 27.35383893991076, 27.992437026308515, 28.634834815698554, 29.280991020472076, 29.930865473188728, 30.584419078553744, 31.24161376818573, 31.902412457971845, 32.566779007824586, 33.23467818367056, 33.90607562151591, 34.5809377934459, 35.259231975428044, 35.94092621679859, 36.625989311321796, 37.31439076972027, 38.00610079358216, 38.701090250558885, 39.399330650772676, 40.10079412436013, 40.80545340008282, 41.513281784941185, 42.22425314473263, 42.93834188549859, 43.655522935809735, 44.37577172984131, 45.09906419119461, 45.82537671742285, 46.554686165223046, 47.2869698362578, 48.022205463573016, 48.76037119858035, 49.50144559857454, 50.245407614758044, 50.992236580747004, 51.74191220153405, 52.494414542885345, 53.24972402114995, 54.0078213934616, 54.76868774831366, 55.53230449648951, 56.29865336233127, 57.06771637533113, 57.83947586203002], [0.0, 0.12161749333217217, 0.3100177371888991, 0.5359320649419675, 0.7902728031831628, 1.0680843551360861, 1.3661558177858832, 1.6822029951953803, 2.0145011995569675, 2.3616929634330854, 2.7226765314242796, 3.096536281050022, 3.48249683226607, 3.8798914343875968, 4.288139409669132, 4.706729585495138, 5.13520782528547, 5.573167447375451, 6.0202417300175215, 6.476097956082213, 6.940432615759126, 7.412967494768546, 7.8934464497839425, 8.381632724264568, 8.877306694340772, 9.380263960634402, 9.890313721087375, 10.407277374107688, 10.93098731204068, 11.461285873109212, 11.99802442622163, 12.54106256790402, 13.090267414421264, 13.645512975162209, 14.20667959576429, 14.773653461380379, 15.346326152049466, 15.92459424340199, 16.508358946970272, 17.0975257852312, 17.692004297218038, 18.291707771129534, 18.896553000858997, 19.506460063782352, 20.12135211749525, 20.741155213487467, 21.36579812599661, 21.99521219449987, 22.629331178488922, 23.268091123332862, 23.9114302361729, 24.559288770911987, 25.211608921466865, 25.868334722541107, 26.52941195725652, 27.194788071050404, 27.864412091306924, 28.53823455224478, 29.216207424630948, 29.898284049932236, 30.58441907855374, 31.274568411846452, 31.968689147595732, 32.66673952872889, 33.36867889500333, 34.074467637458305, 34.78406715543176, 35.49743981596112, 36.2145489154022, 36.93535864311377, 37.659834047068735, 38.38794100126298, 39.11964617480433, 39.8549170025726, 40.5937216573503, 41.33602902333166, 42.08180867092397, 42.831030832762146, 43.58366638086308, 44.339686804851546, 45.099064191194614, 45.861771203385565, 46.627781063022965, 47.397067531733725, 48.16960489389306, 48.94536794009681, 49.724331951345135, 50.50647268389898, 51.291766354773024, 52.080189627831885, 52.871719600457546, 53.66633379075864, 54.46401012529391, 55.26472692728349, 56.068462905284086, 56.875197142304515, 57.68490908534036, 58.49757853530726, 59.31318563735378, 60.13171087153565, 60.95313504383462, 61.777439277505565], [0.0, 0.12950025366385745, 0.3301118490956195, 0.5706690415581857, 0.8414951309376689, 1.137313318460996, 1.4547045832001664, 1.7912366767575416, 2.14507312394804, 2.514768471714803, 2.899149553272398, 3.2972413991469454, 3.70821837225562, 4.13137050579636, 4.566079484810726, 5.011801004515216, 5.468051493009806, 5.934397909148087, 6.410449761743043, 6.8958527682693225, 7.390283746622453, 7.8934464497839425, 8.405068132239546, 8.92489669183485, 9.452698269557873, 9.988255217678883, 10.531364367112213, 11.081835540023775, 11.639490265099946, 12.204160661556692, 12.775688464628445, 13.353924170448707, 13.938726282289213, 14.529960643330444, 15.127499843691806, 15.731222691502206, 16.341013739451654, 16.956762859615903, 17.578364860453238, 18.205719140784712, 18.83872937632492, 19.47730323495987, 20.121352117495253, 20.770790921041606, 21.42553782257675, 22.085514080543277, 22.750643852609265, 23.420854027950963, 24.096074072614776, 24.77623588668597, 25.46127367213938, 26.15112381037449, 26.845724748548534, 27.545016893918028, 28.248942515483197, 28.957445652304436, 29.67047202792446, 30.387968970387536, 31.10988533739752, 31.836171446201394, 32.566779007824586, 33.30166106531973, 34.04077193572192, 34.78406715543176, 35.531503428772055, 36.28303857948738, 37.03863150497489, 37.798242133053634, 38.56183138109574, 39.32936111735723, 40.10079412436013, 40.87609406418902, 41.65522544557637, 42.43815359266092, 43.22484461531203, 44.015265380921626, 44.80938348757231, 45.60716723849723, 46.40858561775373, 47.213608267037884, 48.022205463573016, 48.83434809900918, 49.6500076592759, 50.469156205333476, 51.291766354773024, 52.11781126421745, 52.94726461248005, 53.78010058443939, 54.616293855592005, 55.4558195772474, 56.29865336233128, 57.14477127176587, 57.99414980139757, 58.8467658694442, 59.702596804436105, 60.56162033362627, 61.42381457184659, 62.289158010788704, 63.15762950868898, 64.0292082803983, 64.90387388781878, 65.78160623069004], [0.0, 0.13750946064114491, 0.35052828883422216, 0.6059632308748618, 0.8935391114193875, 1.207652777325871, 1.5446737513525415, 1.9020193577451672, 2.277739540769981, 2.6702994503814645, 3.078453362904623, 3.5011660098924695, 3.9375606910549865, 4.386883530247051, 4.848477971562121, 5.321766046578624, 5.806234275907351, 6.301422836090097, 6.806917085216962, 7.322340829438149, 7.847350898793617, 8.381632724264568, 8.92489669183485, 9.476875107578781, 10.037319648997423, 10.60599920749385, 11.182698048576441, 11.767214232475572, 12.359358249955683, 12.958951837303687, 13.565826941547202, 14.179824812448572, 14.800795202126151, 15.428595656558633, 16.063090885941833, 16.704152203046526, 17.35165702048867, 18.005488399258212, 18.665534642028266, 19.331688925735058, 20.003848968721538, 20.681916728406037, 21.36579812599661, 22.05540279524224, 22.750643852609265, 23.451437686608273, 24.157703764283823, 24.869364453124355, 25.58634485686023, 26.30857266379877, 27.03597800650192, 27.768493331747216, 28.506053279830958, 29.248594572375048, 29.996055907888433, 30.748377864413204, 31.505502808654025, 32.26737481105076, 33.03393956630779, 33.805144318941025, 34.580937793445905, 35.36127012872699, 36.14609281646339, 36.93535864311379, 37.729021635291666, 38.52703700826516, 39.32936111735724, 40.13595141204129, 40.946766392544696, 41.761765568788114, 42.58090942150283, 43.40415936538103, 44.23147771412543, 45.062827647275526, 45.89817317869649, 46.737479126626624, 47.58071108518594, 48.42783539725648, 49.27881912865143, 50.133630043495714, 50.992236580747004, 51.85460783179015, 52.72071351904389, 53.590523975521734, 54.46401012529391, 55.34114346480001, 56.221896044965916, 57.10624045408142, 57.99414980139757, 58.88559770140597, 59.78055825876406, 60.67900605383302, 61.58091612879699, 62.486263974333966, 63.39502551681108, 64.30717710597789, 65.2226955031335, 66.14155786974439, 67.06374175649151, 67.98922509272585, 68.91798617631373, 69.85000366385323], [0.0, 0.14564151110450074, 0.3712578715141555, 0.6417987548412619, 0.9463813312285922, 1.279071087612569, 1.6360228471664002, 2.014501199556968, 2.4124407664279057, 2.828215929593339, 3.260507295626814, 3.7082183722556197, 4.170420612786105, 4.646315558258069, 5.135207825285471, 5.636485265483056, 6.149604033257828, 6.6740771120584705, 7.209465338833633, 7.7553702723379105, 8.311428448186287, 8.877306694340772, 9.452698269557873, 10.037319648997423, 10.630907824835681, 11.23321802114866, 11.844021745313306, 12.463105115222426, 13.09026741442127, 13.725319837016567, 14.368084391699727, 15.01839294004309, 15.676086348788322, 16.341013739451657, 17.013031821444745, 17.69200429721804, 18.377801329800544, 19.070299064629435, 19.769379198808327, 20.47492859195869, 21.18683891367895, 21.905006323333858, 22.629331178488922, 23.35971776880329, 24.096074072614773, 24.83831153380799, 25.586344856860226, 26.34009181821942, 27.09947309239164, 27.86441209130693, 28.634834815698557, 29.41066971737374, 30.191847571379018, 30.978301357172224, 31.769966148007605, 32.56677900782459, 33.368678895003335, 34.17560657241487, 34.9875045232507, 35.80431687216678, 36.62598931132181, 37.45246903092909, 38.283704653977, 39.119646174804345, 39.96024490124513, 40.80545340008282, 41.65522544557638, 42.50951597084123, 43.368281021886375, 44.23147771412544, 45.09906419119462, 45.97099958592367, 46.847243983318705, 47.72775838542651, 48.61250467796006, 49.50144559857455, 50.394544706691036, 51.29176635477303, 52.19307566096794, 53.09843848303178, 54.007821393461604, 54.921191655765014, 55.838517201801615, 56.75976661013522, 57.68490908534036, 58.61391443820975, 59.546753066813665, 60.483395938365014, 61.4238145718466, 62.367981021360755, 63.31586786016316, 64.26744816534543, 65.2226955031335, 66.18158391477021, 67.14408790295342, 68.11018241880141, 69.0798428493203, 70.05304500534874, 71.0297651099572, 72.00997978728009, 72.99366605176041, 73.98080129778768], [0.0, 0.1538930516681145, 0.3922920489483754, 0.6781608360850471, 1.0, 1.3515387987969703, 1.7287142013278258, 2.1286358184409053, 2.5491212546385245, 2.9884527898725017, 3.445236278481977, 3.9183131047625497, 4.406702113800222, 4.909559608732161, 5.426150808172584, 5.955828881541621, 6.498019170849886, 7.052207066885168, 7.617928525147791, 8.194762530099668, 8.782325024730138, 9.380263960634402, 9.988255217678883, 10.60599920749385, 11.23321802114866, 11.869653014568343, 12.51506274953395, 13.169221226123325, 13.83191635598674, 14.502948636146867, 15.182129990927738, 15.869282755764225, 16.56423878146204, 17.266838641288235, 17.976930926308984, 18.69437161683048, 19.41902351977134, 20.150755763400756, 20.889443342192436, 21.634966705628205, 22.387211385683397, 23.146067658474177, 23.911430236172905, 24.68319798582428, 25.46127367213938, 26.245563721721872, 27.035978006501917, 27.83242964442749, 28.634834815698557, 29.44311259303198, 30.257184784620396, 31.076975788599725, 31.902412457971845, 32.733423975044175, 33.56994173454778, 34.411899234684185, 35.259231975428044, 36.111877363481064, 36.969774623332775, 37.83286471393684, 38.701090250558885, 39.574395431393704, 40.4527259685872, 41.33602902333166, 42.22425314473263, 43.117348212172764, 44.015265380921626, 44.91795703076198, 45.82537671742285, 46.73747912662662, 47.65422003057374, 48.5755562467025, 49.501445598574534, 50.43184687874848, 51.366719813514614, 52.306025029373494, 53.24972402114995, 54.19777912164229, 55.15015347271368, 56.10681099773956, 57.06771637533113, 58.0328350142604, 59.00213302951788, 59.97557721943827, 60.953135043834614, 61.93477460308433, 62.92046461811548, 63.910174411244434, 64.90387388781878, 65.90153351862367, 66.903124323011, 67.90861785271423, 68.91798617631373, 69.93120186431963, 70.94823797484146, 71.96906803981518, 72.9936660517604, 74.02200645104217, 75.05406411361302, 76.08981433921223, 77.12923284000122, 78.1722957296144], [0.0, 0.16226095202444843, 0.41362284160340346, 0.7150356802733734, 1.0543747769352194, 1.4250284195008498, 1.8227126504097722, 2.244379916244948, 2.6877291542403206, 3.1509492437032534, 3.63257023261356, 4.13137050579636, 4.646315558258069, 5.176515817307135, 5.721196547983828, 6.279675748439784, 6.851347513785627, 7.435669253048026, 8.032151689411148, 8.640350914710933, 9.259861988922435, 9.890313721087375, 10.531364367112213, 11.182698048576441, 11.844021745313306, 12.51506274953395, 13.195566494870132, 13.885294692704338, 14.584023722430132, 15.291543233140295, 16.00765492258594, 16.73217146573083, 17.464915570305752, 18.205719140784712, 18.95442253540688, 19.710873903439737, 20.474928591958687, 21.24644861311176, 22.025302164225053, 22.811363194247637, 23.604511010981536, 24.404629924331207, 25.211608921466865, 26.02534137035133, 26.845724748548534, 27.672660394629585, 28.506053279830958, 29.345811797908418, 30.19184757137902, 31.04407527255664, 31.902412457971845, 32.76677941492605, 33.63709901906943, 34.51329660201316, 35.39529982809213, 36.28303857948738, 37.1764448489991, 38.07545263983234, 38.97999787182183, 39.89001829357749, 40.80545340008282, 41.7262443553219, 42.652333919550685, 43.58366638086308, 44.5201874907337, 45.46184440324784, 46.40858561775372, 47.36036092469543, 48.31712135440511, 49.27881912865141, 50.24540761475805, 51.21684128212115, 52.19307566096792, 53.17406730321157, 54.15977374526838, 55.150153472713676, 56.14516588666197, 57.144771271765876, 58.1489307657356, 59.157606330288154, 60.17076072344213, 61.18835747307919, 62.210360851700045, 63.23673585230625, 64.26744816534543, 65.30246415666012, 66.34175084638588, 67.38527588874682, 68.43300755270053, 69.48491470338772, 70.54096678434398, 71.60113380043462, 72.66538630147532, 73.73369536650381, 74.80603258867033, 75.88237006071576, 76.96268036100876, 78.04693654011497, 79.13511210787237, 80.22718102094915, 81.32311767086088, 82.4228968724262], [0.0, 0.1707422820273849, 0.4352427801814922, 0.7524103751251507, 1.109486621888605, 1.4995142162286332, 1.9179852794420669, 2.361692963433086, 2.8282159295933385, 3.3156483905092187, 3.8224435602210374, 4.3473159701048525, 4.889177041909583, 5.447090705252986, 6.020241730017523, 6.607912466328201, 7.209465338833632, 7.8243293954973705, 8.451989785155064, 9.091979396699598, 9.7438721240156, 10.407277374107688, 11.081835540023775, 11.767214232475572, 12.463105115222426, 13.169221226123325, 13.885294692704338, 14.611074771075279, 15.34632615204947, 16.090827489742537, 16.84437011670809, 17.60675691648794, 18.377801329800544, 19.157326474818515, 19.945164365355343, 20.741155213487467, 21.54514680532647, 22.356993940437842, 23.176557926862493, 24.003706124899875, 24.838311533807985, 25.680252416405605, 26.52941195725652, 27.385677950699797, 28.248942515483197, 29.119101833175318, 29.99605590788843, 30.879708345148117, 31.769966148007605, 32.66673952872889, 33.56994173454778, 34.47948888620747, 35.39529982809213, 36.317295988919234, 37.24540125206071, 38.179541834660824, 39.11964617480434, 40.06564482606418, 41.01747035882455, 41.97505726783439, 42.938341885498595, 43.907262300460836, 44.88175828107325, 45.86177120338557, 46.8472439833187, 47.83812101271824, 48.83434809900919, 49.835872408197616, 50.8426424109862, 51.85460783179015, 52.871719600457546, 53.893929806513874, 54.92119165576501, 55.95345942910603, 56.990688443394795, 58.03283501426041, 59.07985642072616, 60.13171087153566, 61.18835747307921, 62.249756198824485, 63.31586786016316, 64.38665407859051, 65.46207725914186, 66.54210056501374, 67.62668789330401, 68.71580385180819, 69.80941373681443, 70.90748351184314, 72.00997978728009, 73.11686980085643, 74.22812139893084, 75.34370301853211, 76.46358367012388, 77.58773292105408, 78.71612087965569, 79.8487181799657, 80.98549596703259, 82.12642588278331, 83.27148005242327, 84.42063107134369, 85.5738519925126, 86.73111631432691], [0.0, 0.17933429189785938, 0.4571448551623827, 0.790272803183163, 1.1653176667430796, 1.5749720395268296, 2.014501199556968, 2.480536925291301, 2.9705360327005566, 3.48249683226607, 4.014794701419228, 4.566079484810726, 5.135207825285471, 5.721196547983828, 6.32318939917575, 6.940432615759127, 7.572256538626588, 8.21806148457168, 8.877306694340772, 9.54950155108936, 10.234198506397883, 10.93098731204068, 11.639490265099946, 12.359358249955683, 13.09026741442127, 13.83191635598674, 14.584023722430132, 15.34632615204947, 16.118576494543905, 16.900542265569392, 17.69200429721804, 18.49275555383335, 19.302600088188576, 20.121352117495253, 20.94883520224789, 21.784881513752946, 22.629331178488922, 23.482031689315832, 24.342837375085445, 25.21160892146687, 26.08821293684868, 26.97252155805058, 27.864412091306928, 28.76376668459823, 29.67047202792446, 30.584419078553744, 31.50550280865403, 32.43362197303516, 33.36867889500334, 34.3105792685658, 35.259231975428044, 36.214548915402204, 37.176444848999104, 38.14483725111046, 39.119646174804345, 40.100794124360135, 41.08820593675879, 42.08180867092398, 43.08153150407966, 44.087305634651464, 45.09906419119462, 46.116742146879695, 47.140276239111216, 48.169604893893066, 49.20466815458896, 50.24540761475806, 51.29176635477303, 52.343688881953454, 53.40112107396983, 54.46401012529391, 55.53230449648951, 56.60595386615458, 57.68490908534036, 58.769122134287436, 59.85854608133036, 60.95313504383463, 62.05284415103937, 63.15762950868898, 64.26744816534544, 65.3822580802808, 66.5020180928567, 67.62668789330401, 68.75622799482255, 69.8905997069252, 71.02976510995718, 72.17368703072476, 73.32232901917283, 74.47565532605462, 75.63363088154006, 76.79622127471337, 77.96339273391335, 79.13511210787237, 80.31134684761372, 81.49206498906824, 82.677235136375, 83.86682644583136, 85.06080861046097, 86.25915184516965, 87.46182687246102, 88.66880490868489, 89.88005765079393, 91.09555726358425], [0.0, 0.18803439502934174, 0.47932247297239156, 0.8286115660429462, 1.221851103679823, 1.6513791729761802, 2.1122313548393876, 2.6008760240944233, 3.1146466183937758, 3.6514443396007623, 4.209565749300969, 4.787595191617235, 5.38433384133501, 5.99875082651127, 6.629948353698834, 7.277136092239795, 7.93961189563558, 8.616746988052288, 9.307974376205834, 10.012779641796339, 10.730693524341447, 11.461285873109212, 12.204160661556692, 12.958951837303687, 13.725319837016567, 14.502948636146867, 15.291543233140295, 16.090827489742537, 16.900542265569392, 17.72044379768783, 18.550302285625595, 19.3899006497377, 20.239033436745522, 21.097505850919447, 21.965132893086572, 22.841738592625077, 23.72715532001705, 24.621223169493767, 25.523789402914954, 26.434707947348045, 27.35383893991076, 28.28104831435453, 29.21620742463095, 30.15919270132698, 31.10988533739752, 32.06817100008499, 33.03393956630779, 34.007084879134744, 34.9875045232507, 35.97509961756542, 36.969774623332775, 37.97143716633171, 38.97999787182183, 39.9953702111273, 41.01747035882455, 42.046217059617724, 43.081531504079656, 44.12333721251975, 45.17155992631346, 46.22612750609316, 47.2869698362578, 48.354018735310135, 49.4272078715757, 50.506472683898984, 51.591750306947795, 52.68297950079053, 53.78010058443939, 54.88305537307939, 55.99178711872677, 57.106240454081416, 58.226361339357645, 59.35209701189476, 60.48339593836501, 61.62020776941066, 62.76248329655506, 63.91017441124444, 65.06323406588805, 66.2216162367739, 67.38527588874683, 68.5541689415433, 69.72825223768545, 70.90748351184314, 72.09182136158014, 73.2812252194051, 74.47565532605462, 75.67507270493965, 76.87943913769165, 78.08871714074898, 79.30286994292742, 80.52186146392317, 81.7456562936994, 82.9742196727102, 84.2075174729197, 85.44551617957542, 86.68818287369876, 87.93548521525645, 89.18739142697987, 90.44387027880086, 91.70489107287426, 92.97042362915927, 94.24043827153353, 95.51490581441487], [0.0, 0.19684015297315252, 0.5017694177101616, 0.8674159181875503, 1.279071087612569, 1.7287142013278256, 2.2111483536636753, 2.72267653142428, 3.2605072956268137, 3.822443560221037, 4.406702113800222, 5.011801004515216, 5.636485265483056, 6.279675748439784, 6.940432615759127, 7.617928525147791, 8.311428448186286, 9.020274163109855, 9.7438721240156, 10.48168382210131, 11.233218021148659, 11.99802442622163, 12.775688464628445, 13.565826941547202, 14.368084391699727, 15.182129990927738, 16.00765492258594, 16.84437011670809, 17.69200429721804, 18.550302285625595, 19.419023519771343, 20.29794075404673, 21.186838913678947, 22.085514080543277, 22.993772591850057, 23.911430236172905, 24.838311533807985, 25.77424909050825, 26.719083015319214, 27.672660394629585, 28.63483481569855, 29.605465933878673, 30.584419078553744, 31.571564893484634, 32.566779007824586, 33.569941734547776, 34.580937793445905, 35.59965605619817, 36.62598931132181, 37.65983404706874, 38.701090250558885, 39.74966122163372, 40.80545340008282, 41.8683762050431, 42.938341885498595, 44.01526538092163, 45.099064191194614, 46.18965825503943, 47.28696983625781, 48.39092341715438, 49.50144559857454, 50.618465006042626, 51.74191220153404, 52.871719600457546, 54.0078213934616, 55.150153472713676, 56.29865336233128, 57.45326015267136, 58.61391443820974, 59.780558258764046, 60.95313504383462, 62.131589559855286, 63.315867860163145, 64.50591723751137, 65.70168617896223, 66.903124323011, 68.11018241880141, 69.32281228730479, 70.54096678434398, 71.76459976535158, 72.9936660517604, 74.22812139893082, 75.46792246552691, 76.71302678425853, 77.96339273391334, 79.21897951260638, 80.47974711218113, 81.7456562936994, 83.01666856396137, 84.29274615300214, 85.5738519925126, 86.8599496951375, 88.1510035346056, 89.44697842664941, 90.74783991067584, 92.05355413214937, 93.36408782565383, 94.67940829859911, 95.99948341554249, 97.32428158309462, 98.65377173538343, 99.98792332004929], [0.0, 0.2057492622632959, 0.5244798175615637, 0.9066757089285022, 1.3369626505751175, 1.8069568947947077, 2.311226320694097, 2.8459065859318877, 3.4080799092388907, 3.995449763066545, 4.606152226736818, 5.238638274326556, 5.891596138361318, 6.563897827647087, 7.254560966914734, 7.962720767837723, 8.68760893414739, 9.428537452547369, 10.184885912873387, 10.95609143307571, 11.74164054327539, 12.54106256790402, 13.353924170448707, 14.179824812448572, 15.01839294004309, 15.869282755764225, 16.73217146573083, 17.60675691648794, 18.49275555383335, 19.3899006497377, 20.29794075404673, 21.216638335872542, 22.145768586022648, 23.085118356909582, 24.03448522044386, 24.993676627673924, 25.96250915657404, 26.9408078365281, 27.92840553981634, 28.925142431861104, 29.930865473188724, 30.94542796706464, 31.968689147595732, 33.00051380379803, 34.04077193572192, 35.08933843923142, 36.14609281646339, 37.21091890935925, 38.283704653977, 39.364341853561655, 40.4527259685872, 41.548755922185045, 42.652333919550685, 43.76336528007416, 44.88175828107325, 46.007424012127224, 47.14027623911121, 48.28023127712323, 49.4272078715757, 50.58112708679484, 51.74191220153404, 52.909488610863946, 54.08378373395123, 55.26472692728349, 56.452249402936474, 57.6462841515168, 58.846765869444184, 60.053630890266774, 61.266817119728934, 62.48626397433395, 63.71191232316572, 64.94370443275209, 66.18158391477019, 67.42549567641004, 68.6753858732259, 69.93120186431962, 71.19289216971015, 72.46040642975564, 73.7336953665038, 75.01271074685503, 76.29740534743175, 77.58773292105407, 78.8836481647299, 80.18510668907282, 81.49206498906821, 82.80448041611209, 84.12231115125357, 85.4455161795754, 86.77405526565134, 88.10788893002405, 89.44697842664941, 90.79128572125755, 92.14077347058371, 93.49540500242436, 94.85514429647824, 96.21995596593227, 97.58980523975656, 98.96465794567379, 100.34448049377087, 101.72923986072175, 103.11890357459343, 104.51343970020721], [0.0, 0.21475954280296433, 0.5474481151954883, 0.9463813312285921, 1.3955116262566187, 1.8860881070580766, 2.4124407664279057, 2.970536032700556, 3.557328347585919, 4.170420612786104, 4.807867281822684, 5.468051493009805, 6.149604033257827, 6.851347513785626, 7.572256538626587, 8.311428448186286, 9.068061300559407, 9.841436952607339, 10.630907824835678, 11.43588638516619, 12.255836677575353, 13.090267414421264, 13.938726282289213, 14.800795202126151, 15.676086348788322, 16.56423878146204, 17.464915570305752, 18.377801329800544, 19.302600088188576, 20.239033436745522, 21.186838913678947, 22.145768586022648, 23.115587799621046, 24.09607407261477, 25.08701611207635, 26.088212936848677, 27.09947309239163, 28.12061394568332, 29.151461050058458, 30.191847571379014, 31.241613768185726, 32.30060651952302, 33.36867889500333, 34.44568976241173, 35.531503428772055, 36.6259893113218, 37.729021635291666, 38.84047915576792, 39.96024490124513, 41.08820593675878, 42.22425314473263, 43.36828102188637, 44.5201874907337, 45.679873724361286, 46.847243983318705, 48.022205463573016, 49.20466815458896, 50.39454470669103, 51.591750306947795, 52.796202562892645, 54.00782139346159, 55.226528926586724, 56.452249402936474, 57.68490908534036, 58.92443617347697, 60.17076072344212, 61.423814571846584, 62.683531264123566, 63.94984598675295, 65.22269550313348, 66.50201809285669, 67.78775349415565, 69.07984284932029, 70.37822865288707, 71.68285470242586, 72.9936660517604, 74.3106089664711, 75.63363088154004, 76.96268036100876, 78.29770705952826, 79.63866168568981, 80.98549596703256, 82.33816261663183, 83.69661530117772, 85.06080861046094, 86.43069802818732, 87.80623990404837, 89.18739142697986, 90.57411059954447, 91.96635621337958, 93.36408782565383, 94.76726573648047, 96.17585096723873, 97.58980523975656, 99.00909095631259, 100.43367118041571, 101.86350961832468, 103.29857060127179, 104.73881906835662, 106.18422055007822, 107.6347411524755, 109.09034754184752], [0.0, 0.22386892758426616, 0.5706690415581855, 0.9865236763997746, 1.4547045832001664, 1.9660896849827998, 2.514768471714803, 3.096536281050022, 3.7082183722556192, 4.347315970104852, 5.011801004515216, 5.699988031911354, 6.410449761743044, 7.14195886431709, 7.893446449783943, 8.663971570734516, 9.452698269557871, 10.258877941874454, 11.081835540023775, 11.920958610772978, 12.775688464628445, 13.645512975162209, 14.529960643330444, 15.428595656558633, 16.341013739451657, 17.266838641288235, 18.205719140784712, 19.157326474818515, 20.121352117495253, 21.097505850919447, 22.085514080543277, 23.085118356909582, 24.09607407261477, 25.118149308859728, 26.151123810374486, 27.1947880710504, 28.24894251548319, 29.313396763966246, 30.387968970387533, 31.47248522406035, 32.566779007824586, 33.670690705843526, 34.78406715543176, 35.90676123801569, 37.03863150497488, 38.17954183466082, 39.32936111735723, 40.487962965344835, 41.65522544557638, 42.831030832762146, 44.015265380921626, 45.20781911167662, 46.40858561775372, 47.617461880330964, 48.83434809900919, 50.05914753331737, 51.291766354773024, 52.53211350861823, 53.78010058443939, 55.03564169495577, 56.29865336233127, 57.56905441142413, 58.846765869444184, 60.13171087153566, 61.42381457184658, 62.72300405968521, 64.0292082803983, 65.34235796063759, 66.66238553770921, 67.98922509272585, 69.32281228730479, 70.66308430357559, 72.00997978728007, 73.36343879376442, 74.7234027366785, 76.08981433921223, 77.46261758771082, 78.84175768752331, 80.22718102094915, 81.61883510715722, 83.01666856396137, 84.42063107134368, 85.83067333662555, 87.24674706119234, 88.66880490868488, 90.09680047457601, 91.53068825705648, 92.97042362915926, 94.41596281205557, 95.86726284946123, 97.32428158309462, 98.78697762913201, 100.25531035560927, 101.72923986072176, 103.20872695197795, 104.69373312616374, 106.18422055007824, 107.68015204200333, 109.18149105387198, 110.68820165410175, 112.20024851106254, 113.71759687714886], [0.0, 0.23307545355210224, 0.594137592584178, 1.0270940938429944, 1.5145287654360924, 2.0469443883809544, 2.618187385128872, 3.2238801781663504, 3.860717466734587, 4.526097714409646, 5.217909447484946, 5.934397909148086, 6.674077112058469, 7.435669253048024, 8.218061484571678, 9.020274163109853, 9.841436952607337, 10.680770462609278, 11.537571884372475, 12.411203577753799, 13.301083877363034, 14.20667959576429, 15.127499843691806, 16.063090885941833, 17.013031821444745, 17.976930926308984, 18.95442253540688, 19.945164365355343, 20.94883520224789, 21.965132893086572, 22.993772591850057, 24.03448522044386, 25.08701611207635, 26.151123810374486, 27.22657900215265, 28.313163565441794, 29.41066971737373, 30.51889924894757, 31.637662835697906, 32.76677941492605, 33.9060756215159, 35.05538527548916, 36.2145489154022, 37.38341337248509, 38.561831381095736, 39.749661221633716, 40.946766392544696, 42.15301530846166, 43.36828102188637, 44.592440966120584, 45.82537671742285, 47.066973774595276, 48.31712135440511, 49.57571220141984, 50.8426424109862, 52.11781126421745, 53.401121073969826, 54.69247704089254, 55.99178711872676, 57.29896188810947, 58.61391443820973, 59.93656025558843, 61.26681711972893, 62.60460500473699, 63.94984598675294, 65.30246415666012, 66.6623855377092, 68.02953800771138, 69.40385122548227, 70.78525656124495, 72.17368703072475, 73.56907723268979, 74.97136328971098, 76.38048279193299, 77.79637474366395, 79.21897951260638, 80.64823878156487, 82.08409550247892, 83.52649385264007, 84.97537919296265, 86.43069802818732, 87.89239796890423, 89.36042769529179, 90.83473692247287, 92.31527636739825, 93.80199771717194, 95.29485359873978, 96.79379754986738, 98.298783991338, 99.80976820030637, 101.32670628474726, 102.84955515894265, 104.3782725199541, 105.91281682503016, 107.45314726990273, 108.99922376792742, 110.55100693002709, 112.10845804539937, 113.67153906295164, 115.24021257342855, 116.81444179219996, 118.39419054267802], [0.0, 0.24237725345473807, 0.6178490084223816, 1.0680843551360863, 1.5749720395268296, 2.1286358184409053, 2.7226765314242796, 3.3525418963797344, 4.014794701419227, 4.706729585495138, 5.426150808172583, 6.171233582112576, 6.940432615759126, 7.732419110143435, 8.546035805127728, 9.380263960634402, 10.234198506397881, 11.107028947297652, 11.998024426221628, 12.906521855469116, 13.831916355986738, 14.773653461380379, 15.731222691502206, 16.704152203046526, 17.69200429721804, 18.69437161683048, 19.710873903439737, 20.741155213487467, 21.784881513752946, 22.841738592625077, 23.911430236172905, 24.993676627673924, 26.088212936848677, 27.1947880710504, 28.313163565441794, 29.443112593031973, 30.584419078553736, 31.7368769026903, 32.900289185232964, 34.074467637458305, 35.25923197542804, 36.45440938709306, 37.659834047068735, 38.875346673778196, 40.10079412436013, 41.33602902333166, 42.58090942150283, 43.83529848207095, 45.09906419119462, 46.37207909066565, 47.65422003057374, 48.94536794009681, 50.24540761475805, 51.554227518671745, 52.871719600457546, 54.19777912164229, 55.5323044964895, 56.87519714230451, 58.226361339357645, 59.58570409965173, 60.953135043834614, 62.32856628562338, 63.71191232316572, 65.10308993681689, 66.50201809285669, 67.90861785271423, 69.32281228730479, 70.74452639611768, 72.17368703072475, 73.61022282240575, 75.05406411361301, 76.50514289301925, 77.96339273391332, 79.42874873572727, 80.90114746849432, 82.38052692005375, 83.86682644583134, 85.35998672103757, 86.85994969513752, 88.36665854845621, 89.88005765079392, 91.4000925219337, 92.92670979393307, 94.45985717509755, 95.99948341554246, 97.5455382742542, 99.09797248756905, 100.65673773899303, 102.22178663029007, 103.79307265377243, 105.37055016572967, 106.95417436093739, 108.54390124819066, 110.1396876268099, 111.74149106407091, 113.34926987351287, 114.96298309408137, 116.58259047006602, 118.20805243179451, 119.83933007704687, 121.47638515315643, 123.11918003976527], [0.0, 0.2517725485491946, 0.6417987548412617, 1.1094866218886048, 1.6360228471664, 2.211148353663675, 2.8282159295933385, 3.48249683226607, 4.170420612786104, 4.889177041909582, 5.6364852654830555, 6.410449761743042, 7.209465338833632, 8.032151689411146, 8.877306694340772, 9.743872124015597, 10.630907824835678, 11.537571884372477, 12.463105115222422, 13.40681872634619, 14.368084391699723, 15.346326152049466, 16.341013739451654, 17.35165702048867, 18.377801329800544, 19.41902351977134, 20.474928591958687, 21.54514680532647, 22.629331178488922, 23.72715532001705, 24.838311533807985, 25.96250915657404, 27.09947309239163, 28.24894251548319, 29.41066971737373, 30.584419078553736, 31.76996614800759, 32.967096816593646, 34.175606572414864, 35.39529982809212, 36.625989311321796, 37.86749551132305, 39.11964617480433, 40.382275845940185, 41.65522544557636, 42.93834188549859, 44.23147771412543, 45.534490790434766, 46.847243983318705, 48.16960489389306, 49.501445598574534, 50.8426424109862, 52.19307566096792, 53.552629489156665, 54.92119165576501, 56.29865336233127, 57.68490908534035, 59.07985642072615, 60.48339593836501, 61.895431045756176, 63.31586786016314, 64.7446150885577, 66.18158391477019, 67.62668789330401, 69.07984284932029, 70.54096678434396, 72.00997978728007, 73.48680395036521, 74.97136328971098, 76.46358367012385, 77.96339273391332, 79.47071983342182, 80.98549596703256, 82.50765371843, 84.0371271989049, 85.57385199251259, 87.11776510390678, 88.66880490868488, 90.22691110609294, 91.79202467394894, 93.36408782565381, 94.94304396916823, 96.52883766784251, 98.12141460299368, 99.72072153813237, 101.32670628474725, 102.93931766956202, 104.55850550318532, 106.18422055007822, 107.81641449977063, 109.45503993926008, 111.10005032653254, 112.75139996514737, 114.40904397983245, 116.07293829303941, 117.74303960241078, 119.41930535911443, 121.10169374700364, 122.79016366256269, 124.48467469560073, 126.18518711065899, 127.89166182909757], [0.0, 0.2612596420504011, 0.6659825065299302, 1.1512934168741917, 1.697670162612885, 2.2944670923312755, 2.934786519279413, 3.613721516036183, 4.327567094882145, 5.07340713374378, 5.848874833130308, 6.652003245730436, 7.481126694121767, 8.33481285931398, 9.211814324872387, 10.11103298582128, 11.031493262438367, 11.972321518018678, 12.932729958060985, 13.91200383704828, 14.909491152852821, 15.92459424340199, 16.956762859615903, 18.005488399258212, 19.070299064629435, 20.150755763400756, 21.24644861311176, 22.356993940437842, 23.482031689315832, 24.621223169493767, 25.77424909050825, 26.9408078365281, 28.12061394568332, 29.313396763966246, 30.51889924894757, 31.7368769026903, 32.967096816593646, 34.20933681362509, 35.463384675632476, 36.72903744526818, 38.00610079358216, 39.29438844561069, 40.59372165735031, 41.90392873840034, 43.22484461531203, 44.5563104313224, 45.89817317869649, 47.25028536036689, 48.61250467796007, 49.984693743642076, 51.366719813514614, 52.75845454054878, 54.15977374526839, 55.570557202589754, 56.9906884433948, 58.42005456956451, 59.85854608133035, 61.30605671591745, 62.76248329655506, 64.22772559102043, 65.70168617896223, 67.18427032732076, 68.6753858732259, 70.1749431138104, 71.68285470242586, 73.19903555079571, 74.7234027366785, 76.25587541665226, 77.79637474366396, 79.34482378901652, 80.90114746849432, 82.46527247235078, 84.0371271989049, 85.61664169151305, 87.20374757869985, 88.79837801725012, 90.40046763807688, 92.00995249469568, 93.62677001414738, 95.2508589502229, 96.8821593388544, 98.52061245554617, 100.16616077472868, 101.81874793092541, 103.47831868163185, 105.14481887181054, 106.81819539991439, 108.49839618535518, 110.18537013733948, 111.87906712500033, 113.57943794875615, 115.28643431283362, 117.00000879889508, 118.72011484071398, 120.44670669984676, 122.1797394422508, 123.9191689158027, 125.66495172867279, 127.4170452285153, 129.17540748243462, 130.93999725769194, 132.71077400311702], [0.0, 0.27083691323011094, 0.6903961320555656, 1.1934975980262572, 1.759903454343068, 2.378577800681468, 3.042370094488758, 3.746193529912533, 4.486207301577674, 5.259388388037794, 6.063283227528487, 6.895852768269322, 7.75537027233791, 8.64035091471093, 9.549501551089358, 10.481683822101308, 11.43588638516619, 12.4112035777538, 13.40681872634619, 14.421990884243545, 15.45604414818614, 16.508358946970272, 17.578364860453238, 18.665534642028266, 19.769379198808327, 20.889443342192436, 22.025302164225053, 23.176557926862493, 24.342837375085445, 25.523789402914954, 26.719083015319214, 27.92840553981634, 29.151461050058458, 30.387968970387533, 31.637662835697906, 32.900289185232964, 34.175606572414864, 35.463384675632476, 36.76340349722827, 38.07545263983234, 39.39933065077267, 40.73484442660707, 42.08180867092397, 43.440045399486, 44.809383487572305, 46.189658255039426, 47.58071108518593, 48.98238907398834, 50.394544706691036, 51.81703555908886, 53.24972402114995, 54.69247704089254, 56.14516588666197, 57.60766592615644, 59.07985642072615, 60.56162033362627, 62.052844151039366, 63.55341771480356, 65.06323406588804, 66.58218929775141, 68.1101824188014, 69.6471152232483, 71.19289216971013, 72.74742026698671, 74.3106089664711, 75.88237006071574, 77.46261758771081, 79.0512677404715, 80.64823878156487, 82.25345096223721, 83.86682644583134, 85.48828923520772, 87.11776510390678, 88.75518153081012, 90.40046763807688, 92.05355413214937, 93.71437324763684, 95.38285869390086, 97.05894560417914, 98.74257048709548, 100.43367118041571, 102.13218680691821, 103.83805773225772, 105.55122552470883, 107.27163291668404, 108.99922376792742, 110.73394303029222, 112.47573671401702, 114.22455185541911, 115.98033648593126, 117.74303960241079, 119.51261113865509, 121.28900193806233, 123.0721637273785, 124.86204909147752, 126.65861144912202, 128.46180502965746, 130.271584850594, 132.08790669603363, 133.91072709590227, 135.74000330594893, 137.57569328847626], [0.0, 0.28050281208563704, 0.7150356802733733, 1.236092334944683, 1.8227126504097724, 2.4634668660868653, 3.150949243703254, 3.879891434387597, 4.646315558258069, 5.447090705252986, 6.279675748439784, 7.14195886431709, 8.032151689411148, 8.948716406776962, 9.890313721087377, 10.855764646061797, 11.844021745313304, 12.854147034120789, 13.885294692704337, 14.936697330716656, 16.00765492258594, 17.0975257852312, 18.205719140784712, 19.331688925735058, 20.47492859195869, 21.634966705628205, 22.811363194247637, 24.003706124899875, 25.21160892146687, 26.434707947348045, 27.672660394629585, 28.925142431861104, 30.191847571379014, 31.47248522406035, 32.76677941492605, 34.074467637458305, 35.39529982809212, 36.72903744526818, 38.07545263983234, 39.43432750554276, 40.80545340008281, 42.188630328341375, 43.58366638086308, 44.990377221330924, 46.40858561775372, 47.83812101271823, 49.27881912865142, 50.73052160453794, 52.193075660967935, 53.66633379075866, 55.150153472713676, 56.64439690635893, 58.1489307657356, 59.66362597053955, 61.18835747307921, 62.72300405968522, 64.26744816534543, 65.82157570046321, 67.38527588874682, 68.95844111533417, 70.54096678434398, 72.13275118512, 73.7336953665038, 75.34370301853212, 76.96268036100876, 78.59053603845047, 80.22718102094915, 81.87252851053243, 83.52649385264007, 85.18899445236501, 86.85994969513752, 88.53928087155607, 90.22691110609294, 91.92276528942344, 93.62677001414738, 95.33885351368923, 97.05894560417914, 98.78697762913202, 100.52288240675564, 102.26659417973002, 104.01804856731296, 105.7771825196356, 107.54393427406248, 109.31824331349829, 111.10005032653255, 112.88929716931968, 114.68592682909957, 116.48988338927015, 118.30111199592777, 120.11955882579899, 121.94517105548988, 123.77789683198512, 125.61768524433283, 127.46448629645482, 129.31825088102653, 131.17893075437274, 133.04647851233, 134.92084756702835, 136.80199212454855, 138.689867163413, 140.58442841387105, 142.485632337942], [0.0, 0.2902558545101049, 0.7398973680149756, 1.279071087612569, 1.8860881070580768, 2.549121254638524, 3.2605072956268137, 4.014794701419227, 4.807867281822684, 5.6364852654830555, 6.498019170849885, 7.390283746622452, 8.311428448186286, 9.259861988922435, 10.234198506397881, 11.233218021148659, 12.255836677575353, 13.301083877363036, 14.368084391699723, 15.45604414818614, 16.56423878146204, 17.692004297218038, 18.83872937632492, 20.003848968721538, 21.18683891367895, 22.387211385683397, 23.604511010981536, 24.838311533807985, 26.08821293684868, 27.35383893991076, 28.63483481569855, 29.930865473188724, 31.241613768185726, 32.566779007824586, 33.9060756215159, 35.25923197542804, 36.625989311321796, 38.00610079358216, 39.39933065077267, 40.80545340008281, 42.22425314473262, 43.65552293580973, 45.099064191194614, 46.554686165223046, 48.02220546357301, 49.501445598574534, 50.992236580747, 52.49441454288534, 54.007821393461604, 55.5323044964895, 57.06771637533112, 58.61391443820974, 60.17076072344212, 61.738121662620536, 63.31586786016315, 64.90387388781878, 66.50201809285669, 68.1101824188014, 69.72825223768544, 71.35611619289345, 72.99366605176039, 74.64079656716514, 76.29740534743173, 77.96339273391334, 79.6386616856898, 81.32311767086088, 83.01666856396136, 84.71922454906588, 86.43069802818732, 88.15100353460556, 89.8800576507939, 91.61777893063625, 93.3640878256538, 95.1189066149815, 96.88215933885438, 98.65377173538343, 100.43367118041571, 102.22178663029005, 104.01804856731296, 105.82238894779188, 107.6347411524755, 109.45503993926006, 111.2832213980322, 113.11922290752584, 114.96298309408135, 116.81444179219996, 118.67354000679613, 120.54021987705555, 122.41442464181225, 124.2960986063653, 126.185187110659, 128.0816364987561, 129.98539408953826, 131.89640814857086, 133.81462786107468, 135.74000330594893, 137.67248543079418, 139.61202602788688, 141.5585777110599, 143.51209389344527, 145.47252876603955, 147.43983727705262], [0.0, 0.30009461790562536, 0.7649775689058563, 1.3224275870647892, 1.9500205802196249, 2.6355284726194026, 3.371028269907192, 4.150883653752411, 4.970838908020394, 5.827544443266133, 6.7182816467591255, 7.640791194031226, 8.593159812807755, 9.573742276842722, 10.581105747311888, 11.61398889127259, 12.67127111381894, 13.751948916396353, 14.855117402680326, 15.979955583706996, 17.125714540401596, 18.291707771129534, 19.47730323495987, 20.681916728406037, 21.905006323333858, 23.146067658474177, 24.404629924331207, 25.680252416405605, 26.97252155805058, 28.28104831435453, 29.605465933878673, 30.94542796706464, 32.30060651952302, 33.670690705843526, 35.05538527548916, 36.45440938709306, 37.86749551132305, 39.29438844561069, 40.73484442660707, 42.188630328341375, 43.65552293580973, 45.13530828518051, 46.627781063022965, 48.13274405799294, 49.65000765927589, 51.17938939682322, 52.72071351904388, 54.27381060414837, 55.838517201801615, 57.414675502135964, 59.00213302951787, 60.60074235875647, 62.210360851700045, 63.830850412390625, 65.46207725914186, 67.10391171207812, 68.75622799482254, 70.41890404915527, 72.09182136158014, 73.7748648008417, 75.4679224655269, 77.17088554096722, 78.88364816472989, 80.60610730005246, 82.33816261663183, 84.07971637823273, 85.83067333662555, 87.59094063140665, 89.36042769529179, 91.13904616450704, 92.92670979393307, 94.72333437668583, 96.52883766784251, 98.34313931204439, 100.16616077472867, 101.9978252767611, 103.83805773225772, 105.68678468939996, 107.54393427406248, 109.4094361360849, 111.2832213980322, 113.16522260629782, 115.05537368441594, 116.95360988845593, 118.85986776438352, 120.77408510727818, 122.69620092230593, 124.62615538735228, 126.56388981722573, 128.50934662934958, 130.4624693108636, 132.42320238706256, 134.39149139110336, 136.36728283491627, 138.35052418126037, 140.34116381686604, 142.33915102661135, 144.3444359686821, 146.3569696506686, 148.37670390655413, 150.4035913745537, 152.4375854757628], [0.0, 0.31001773718889913, 0.7902728031831628, 1.3661558177858835, 2.014501199556968, 2.7226765314242796, 3.48249683226607, 4.288139409669132, 5.13520782528547, 6.0202417300175215, 6.940432615759126, 7.8934464497839425, 8.877306694340772, 9.890313721087375, 10.93098731204068, 11.99802442622163, 13.090267414421266, 14.206679595764294, 15.346326152049468, 16.508358946970272, 17.692004297218038, 18.896553000858997, 20.121352117495253, 21.36579812599661, 22.629331178488922, 23.911430236172905, 25.211608921466865, 26.52941195725652, 27.864412091306928, 29.21620742463095, 30.584419078553744, 31.968689147595732, 33.36867889500333, 34.78406715543176, 36.2145489154022, 37.659834047068735, 39.11964617480433, 40.59372165735031, 42.08180867092397, 43.58366638086308, 45.099064191194614, 46.627781063022965, 48.16960489389306, 49.72433195134514, 51.291766354773024, 52.871719600457546, 54.46401012529391, 56.06846290528408, 57.684909085340365, 59.31318563735378, 60.95313504383462, 62.60460500473699, 64.26744816534543, 65.9415218633333, 67.62668789330401, 69.32281228730479, 71.02976510995718, 72.74742026698671, 74.47565532605462, 76.21435134890224, 77.96339273391334, 79.7226670682844, 81.49206498906821, 83.27148005242327, 85.06080861046094, 86.85994969513752, 88.66880490868489, 90.48727832011834, 92.31527636739827, 94.15270776485806, 95.99948341554247, 97.85551632812914, 99.72072153813238, 101.59501603311213, 103.47831868163185, 105.37055016572967, 107.27163291668406, 109.18149105387197, 111.10005032653257, 113.0272380582624, 114.96298309408138, 116.90721574991917, 118.85986776438354, 120.82087225267995, 122.79016366256268, 124.7676777322038, 126.75335144987538, 128.74712301534694, 130.74893180290508, 132.7587183259111, 134.7764242028146, 136.80199212454852, 138.83536582323453, 140.87649004213233, 142.92531050677132, 144.9817738972047, 147.04582782133204, 149.11742078923808, 151.19650218849898, 153.28302226040998, 155.37693207709114, 157.47818351943025], [0.0, 0.320023901145597, 0.8157797284025793, 1.4102500016448956, 2.0795214447742576, 2.81055391554274, 3.594898253547017, 4.426543832562466, 5.300952314350672, 6.2145516632353255, 7.164442723417527, 8.148216128693724, 9.163831546379612, 10.209534490756042, 11.283796968174055, 12.385273880571681, 13.512770214336577, 14.665215828576272, 15.841645732802363, 17.04118441617481, 18.263033223903932, 19.506460063782352, 20.770790921041606, 22.05540279524224, 23.35971776880329, 24.68319798582428, 26.02534137035133, 27.385677950699797, 28.76376668459823, 30.15919270132698, 31.571564893484634, 33.00051380379803, 34.44568976241173, 35.90676123801569, 37.38341337248509, 38.875346673778196, 40.382275845940185, 41.90392873840034, 43.440045399486, 44.990377221330924, 46.554686165223046, 48.13274405799294, 49.72433195134514, 51.32923953713035, 52.947264612480055, 54.5782125895099, 56.221896044965916, 57.878134305757726, 59.54675306681367, 61.227584038112994, 62.92046461811549, 64.62523759112352, 66.34175084638588, 68.06985711699218, 69.80941373681445, 71.56028241393662, 73.32232901917283, 75.09542338841695, 76.87943913769166, 78.67425348987497, 80.47974711218114, 82.2958039635596, 84.12231115125358, 85.9591587958293, 87.80623990404837, 89.66345024901226, 91.5306882570565, 93.40785490091817, 95.29485359873979, 97.19159011850928, 99.09797248756907, 101.013910906856, 102.93931766956203, 104.87410708392918, 106.81819539991439, 108.77150073948124, 110.73394303029224, 112.70544394259366, 114.68592682909959, 116.67531666769555, 118.67354000679615, 120.6805249132009, 122.69620092230595, 124.72049899053633, 126.75335144987538, 128.7946919643739, 130.84445548853105, 132.90257822744582, 134.9689975986431, 137.04365219548745, 139.1264817520996, 141.21742710969923, 143.31643018430023, 145.4234339356902, 147.53838233763017, 149.6612203492133, 151.79189388732647, 153.93034980016066, 156.0765358417203, 158.2304006472836, 160.39189370976945, 162.56096535696827], [0.0, 0.3301118490956195, 0.8414951309376688, 1.4547045832001664, 2.14507312394804, 2.899149553272398, 3.7082183722556197, 4.566079484810725, 5.468051493009806, 6.410449761743043, 7.390283746622453, 8.405068132239546, 9.452698269557873, 10.531364367112213, 11.639490265099944, 12.775688464628445, 13.938726282289213, 15.127499843691808, 16.341013739451654, 17.578364860453238, 18.838729376324924, 20.12135211749525, 21.42553782257675, 22.750643852609265, 24.096074072614773, 25.46127367213938, 26.845724748548534, 28.248942515483197, 29.67047202792446, 31.10988533739752, 32.566779007824586, 34.04077193572192, 35.531503428772055, 37.03863150497488, 38.561831381095736, 40.10079412436013, 41.65522544557636, 43.22484461531203, 44.809383487572305, 46.40858561775372, 48.02220546357301, 49.65000765927589, 51.291766354773024, 52.947264612480055, 54.616293855592, 56.29865336233127, 57.99414980139756, 59.7025968044361, 61.4238145718466, 63.15762950868898, 64.90387388781878, 66.66238553770921, 68.43300755270053, 70.21558802366367, 72.00997978728009, 73.81604019232917, 75.63363088154004, 77.46261758771082, 79.3028699429274, 81.15426129982806, 83.01666856396136, 84.88997203637472, 86.77405526565134, 88.66880490868489, 90.57411059954445, 92.48986482584085, 94.41596281205555, 96.35230240934041, 98.298783991338, 100.25531035560925, 102.22178663029005, 104.19812018562784, 106.18422055007822, 108.1799993306662, 110.18537013733946, 112.20024851106255, 114.2245518554191, 116.25819937150706, 118.30111199592777, 120.35321234168342, 122.41442464181226, 124.48467469560073, 126.56388981722573, 128.65199878668736, 130.74893180290505, 132.85462043885582, 134.96899759864309, 137.09199747639218, 139.22355551687303, 141.36360837776053, 143.5120938934453, 145.66895104031533, 147.8341199034331, 150.00754164453707, 152.1891584713021, 154.37891360779537, 156.57675126606966, 158.782616618839, 160.99645577318435, 163.21821574524031, 165.44784443581716, 167.68529060691398], [0.0, 0.34028036783623034, 0.8674159181875502, 1.4995142162286335, 2.2111483536636753, 2.9884527898725017, 3.8224435602210374, 4.706729585495138, 5.6364852654830555, 6.6079124663282, 7.617928525147791, 8.663971570734516, 9.7438721240156, 10.855764646061797, 11.99802442622163, 13.169221226123325, 14.368084391699725, 15.593476045638475, 16.844370116708088, 18.119835677094656, 19.41902351977134, 20.741155213487467, 22.085514080543277, 23.451437686608273, 24.83831153380799, 26.245563721721872, 27.672660394629585, 29.119101833175318, 30.584419078553744, 32.06817100008499, 33.569941734547776, 35.08933843923142, 36.6259893113218, 38.17954183466082, 39.749661221633716, 41.33602902333166, 42.93834188549859, 44.5563104313224, 46.189658255039426, 47.83812101271823, 49.501445598574534, 51.17938939682322, 52.871719600457546, 54.5782125895099, 56.29865336233127, 58.0328350142604, 59.78055825876405, 61.54163098673591, 63.31586786016316, 65.10308993681689, 66.903124323011, 68.71580385180819, 70.54096678434398, 72.37845653219401, 74.22812139893082, 76.08981433921223, 77.96339273391334, 79.8487181799657, 81.7456562936994, 83.65407652660201, 85.57385199251259, 87.50485930536146, 89.4469784266494, 91.40009252193371, 93.36408782565381, 95.33885351368922, 97.32428158309462, 99.32026673850507, 101.32670628474726, 103.34350002523084, 105.37055016572967, 107.40776122319349, 109.45503993926006, 111.51229519816327, 113.57943794875614, 115.65638113039019, 117.74303960241079, 119.83933007704687, 121.94517105548988, 124.06048276697081, 126.185187110659, 128.31920760021757, 130.4624693108636, 132.61489882878956, 134.77642420281458, 136.94697489814072, 139.12648175209958, 141.31487693178147, 143.5120938934453, 145.71806734361624, 147.93273320178199, 150.15602856460472, 152.38789167157202, 154.62826187201247, 156.87707959340935, 159.13428631094638, 161.39982451822613, 163.67363769910386, 165.95567030058336, 168.24586770672383, 170.54417621351098, 172.85054300464685], [0.0, 0.35052828883422216, 0.8935391114193875, 1.5446737513525415, 2.277739540769981, 3.078453362904623, 3.9375606910549865, 4.8484779715621205, 5.80623427590735, 6.806917085216961, 7.847350898793617, 8.924896691834848, 10.037319648997423, 11.182698048576441, 12.359358249955683, 13.565826941547202, 14.800795202126151, 16.063090885941836, 17.35165702048867, 18.665534642028266, 20.003848968721538, 21.36579812599661, 22.750643852609265, 24.157703764283823, 25.586344856860226, 27.035978006501917, 28.506053279830958, 29.99605590788843, 31.50550280865403, 33.03393956630779, 34.580937793445905, 36.14609281646339, 37.729021635291666, 39.32936111735723, 40.946766392544696, 42.58090942150283, 44.23147771412543, 45.89817317869649, 47.58071108518593, 49.27881912865142, 50.992236580747, 52.72071351904388, 54.46401012529391, 56.221896044965916, 57.99414980139756, 59.78055825876405, 61.580916128796986, 63.395025516811074, 65.2226955031335, 67.06374175649151, 68.91798617631372, 70.78525656124496, 72.66538630147531, 74.55821409274621, 76.46358367012388, 78.38134355983242, 80.3113468476137, 82.25345096223722, 84.2075174729197, 86.17341189953532, 88.15100353460558, 90.14016527615233, 92.1407734705837, 94.15270776485808, 96.17585096723872, 98.21008891601376, 100.25531035560927, 102.31140681957353, 104.37827251995411, 106.45580424262909, 108.54390124819066, 110.64246517801054, 112.75139996514736, 114.87061174978257, 117.00000879889507, 119.13950142990831, 121.28900193806233, 123.44842452728237, 125.61768524433283, 127.79670191605942, 129.98539408953826, 132.18368297496156, 134.3914913911034, 136.60874371321788, 138.8353658232345, 141.07128506212158, 143.3164301843002, 145.5707313139973, 147.8341199034331, 150.1065286927474, 152.38789167157205, 154.67814404216543, 156.97722218402873, 159.28506361992822, 161.60160698325473, 163.92679198665215, 166.2605593918541, 168.6028509806694, 170.95360952706164, 173.31277877027037, 175.68030338892532, 178.0561289761071], [0.0, 0.36085448564182876, 0.919861839181238, 1.5901782246521388, 2.344839365587778, 3.1691413795383547, 4.053557111124121, 4.9913090620803935, 5.9772798655329185, 7.007441743893662, 8.078525649535676, 9.187814814745693, 10.333008588857632, 11.5121286382549, 12.72345201861901, 13.96546201614342, 15.236811150152864, 16.53629274470866, 17.862818690000584, 19.2154017722214, 20.593141439373884, 21.99521219449987, 23.420854027950963, 24.869364453124355, 26.34009181821942, 27.83242964442749, 29.345811797908418, 30.879708345148117, 32.43362197303516, 34.007084879134744, 35.59965605619817, 37.21091890935925, 38.84047915576792, 40.487962965344835, 42.15301530846166, 43.83529848207095, 45.534490790434766, 47.25028536036689, 48.98238907398834, 50.73052160453794, 52.49441454288534, 54.27381060414837, 56.06846290528408, 57.878134305757726, 59.7025968044361, 61.54163098673591, 63.395025516811074, 65.26257667020582, 67.14408790295342, 69.03936945357462, 70.94823797484146, 72.87051619252692, 74.80603258867032, 76.75462110715834, 78.71612087965569, 80.6903759701274, 82.67723513637499, 84.67655160716858, 86.68818287369876, 88.7119904941959, 90.74783991067582, 92.79560027686907, 94.85514429647824, 96.92634807098699, 99.00909095631259, 101.1032554276585, 103.20872695197795, 105.32539386751098, 107.45314726990273, 109.59188090445117, 111.7414910640709, 113.90187649259131, 116.07293829303941, 118.25457984058455, 120.44670669984674, 122.64922654629457, 124.86204909147752, 127.08508601185822, 129.31825088102653, 131.56145910509298, 133.8146278610747, 136.07767603809853, 138.35052418126037, 140.63309443798843, 142.92531050677132, 145.22709758811826, 147.53838233763014, 149.85909282106664, 152.18915847130214, 154.5285100470712, 156.87707959340935, 159.23480040370129, 161.60160698325473, 163.97743501432205, 166.36222132249796, 168.75590384442384, 171.158421596736, 173.56971464619616, 175.98972408094875, 178.41839198285018, 180.85566140082048, 183.3014763251692], [0.0, 0.37125787151415557, 0.9463813312285924, 1.6360228471664005, 2.412440766427906, 3.260507295626814, 4.170420612786105, 5.135207825285471, 6.149604033257828, 7.209465338833633, 8.311428448186287, 9.452698269557873, 10.630907824835681, 11.844021745313306, 13.09026741442127, 14.368084391699727, 15.676086348788324, 17.01303182144475, 18.377801329800544, 19.76937919880833, 21.186838913678955, 22.629331178488922, 24.096074072614776, 25.58634485686023, 27.09947309239164, 28.634834815698557, 30.19184757137902, 31.769966148007605, 33.36867889500334, 34.9875045232507, 36.62598931132181, 38.283704653977, 39.96024490124513, 41.65522544557638, 43.36828102188637, 45.09906419119462, 46.847243983318705, 48.61250467796007, 50.394544706691036, 52.193075660967935, 54.007821393461604, 55.838517201801615, 57.684909085340365, 59.54675306681367, 61.4238145718466, 63.31586786016316, 65.2226955031335, 67.14408790295342, 69.07984284932031, 71.0297651099572, 72.99366605176041, 74.97136328971101, 76.96268036100878, 78.96744642216517, 80.98549596703259, 83.01666856396139, 85.06080861046097, 87.1177651039068, 89.18739142697987, 91.26954514665309, 93.36408782565384, 95.47088484543245, 97.58980523975657, 99.72072153813241, 101.8635096183247, 104.01804856731297, 106.18422055007825, 108.36191068566718, 110.5510069300271, 112.75139996514739, 114.96298309408138, 117.18565214145684, 119.41930535911445, 121.6638433365428, 123.9191689158027, 126.18518711065903, 128.46180502965748, 130.74893180290508, 133.04647851233003, 135.35435812521249, 137.6724854307942, 140.00077697978656, 142.33915102661138, 144.68752747421775, 147.04582782133204, 149.41397511200435, 151.79189388732647, 154.17951013920367, 156.5767512660697, 158.98354603044282, 161.39982451822615, 163.82551809966168, 166.26055939185412, 168.70488222278385, 171.15842159673602, 173.62111366107385, 176.0928956742915, 178.57370597528362, 181.06348395377378, 183.5621700218462, 186.06970558652898, 188.5860330233799], [0.0, 0.3817373972085201, 0.9730949129146276, 1.6822029951953805, 2.480536925291301, 3.352541896379735, 4.288139409669132, 5.280159748140336, 6.323189399175749, 7.412967494768546, 8.546035805127728, 9.719520341216306, 10.93098731204068, 12.178343896378838, 13.459767441871328, 14.77365346138038, 16.118576494543905, 17.49326003420892, 18.896553000858997, 20.327411049905795, 21.784881513752946, 23.268091123332862, 24.77623588668597, 26.30857266379877, 27.86441209130693, 29.44311259303198, 31.04407527255664, 32.66673952872889, 34.3105792685658, 35.97509961756542, 37.65983404706874, 39.364341853561655, 41.08820593675878, 42.831030832762146, 44.592440966120584, 46.37207909066565, 48.16960489389306, 49.984693743642076, 51.81703555908886, 53.66633379075866, 55.5323044964895, 57.414675502135964, 59.31318563735378, 61.227584038112994, 63.15762950868898, 65.10308993681689, 67.06374175649151, 69.03936945357462, 71.0297651099572, 73.03472798252513, 75.05406411361302, 77.08758597000538, 79.13511210787239, 81.19646686131264, 83.27148005242327, 85.35998672103759, 87.461826872461, 89.57684524170585, 91.70489107287426, 93.84581791247065, 95.99948341554249, 98.16574916365144, 100.34448049377086, 102.53554633728712, 104.73881906835662, 106.9541743609374, 109.18149105387198, 111.4206510234531, 113.67153906295165, 115.93404276862876, 118.20805243179451, 120.49346093651008, 122.79016366256268, 125.09805839337245, 127.41704522851529, 129.74702650057196, 132.08790669603363, 134.43959238001563, 136.80199212454855, 139.17501644023304, 141.5585777110599, 143.95259013221084, 146.3569696506686, 148.77163390847642, 151.19650218849898, 153.63149536254454, 156.07653584172027, 158.53154752889907, 160.99645577318435, 163.47118732626836, 165.95567030058336, 168.4498341291537, 170.95360952706164, 173.4669284544447, 175.98972408094878, 178.5219307515636, 181.06348395377378, 183.614320285961, 186.1743774269978, 188.74359410697542, 191.32191007901346, 193.90926609210004], [0.0, 0.3922920489483754, 1.0, 1.7287142013278258, 2.549121254638525, 3.445236278481977, 4.406702113800222, 5.426150808172584, 6.498019170849885, 7.617928525147791, 8.782325024730138, 9.988255217678882, 11.23321802114866, 12.51506274953395, 13.83191635598674, 15.182129990927736, 16.564238781462045, 17.976930926308988, 19.419023519771343, 20.889443342192436, 22.3872113856834, 23.9114302361729, 25.46127367213938, 27.03597800650192, 28.634834815698557, 30.257184784620396, 31.902412457971845, 33.56994173454778, 35.259231975428044, 36.969774623332775, 38.701090250558885, 40.4527259685872, 42.22425314473263, 44.015265380921626, 45.82537671742285, 47.65422003057374, 49.501445598574534, 51.366719813514614, 53.24972402114995, 55.150153472713676, 57.06771637533112, 59.00213302951787, 60.95313504383462, 62.92046461811549, 64.90387388781878, 66.903124323011, 68.91798617631372, 70.94823797484146, 72.99366605176041, 75.05406411361302, 77.12923284000122, 79.21897951260638, 81.32311767086088, 83.44146679187936, 85.5738519925126, 87.72010375161263, 89.88005765079392, 92.05355413214937, 94.24043827153353, 96.44055956616025, 98.65377173538343, 100.87993253363541, 103.11890357459343, 105.37055016572967, 107.6347411524755, 109.91134877129997, 112.20024851106254, 114.50131898205531, 116.81444179219996, 119.1395014299083, 121.47638515315643, 123.82498288435849, 126.18518711065899, 128.5568927892933, 130.9399972576919, 133.33440014803062, 135.74000330594893, 138.1567107131824, 140.58442841387108, 143.0230644443244, 145.47252876603957, 147.93273320178196, 150.40359137455374, 152.8850186492842, 155.3769320770911, 157.87925034196854, 160.39189370976942, 162.91478397935833, 165.44784443581716, 167.99099980559674, 170.544176213511, 173.10730114147898, 175.68030338892532, 178.26311303475438, 180.85566140082048, 183.45788101681902, 186.06970558652895, 188.6910699553416, 191.32191007901346, 193.96216299358505, 196.6117667864108, 199.27066056824845], [0.0, 0.4029208465364432, 1.0270940938429944, 1.7755521461263193, 2.6181873851288726, 3.5385818335224566, 4.526097714409647, 5.573167447375451, 6.674077112058469, 7.82432939549737, 9.020274163109855, 10.258877941874452, 11.537571884372479, 12.854147034120787, 14.206679595764294, 15.593476045638473, 17.013031821444745, 18.46399957983543, 19.945164365355343, 21.455423880433713, 22.99377259185006, 24.559288770911987, 26.15112381037449, 27.768493331747216, 29.41066971737374, 31.076975788599725, 32.76677941492605, 34.47948888620747, 36.214548915402204, 37.97143716633171, 39.74966122163372, 41.548755922185045, 43.36828102188637, 45.20781911167662, 47.066973774595276, 48.94536794009681, 50.8426424109862, 52.75845454054878, 54.69247704089254, 56.64439690635893, 58.61391443820974, 60.60074235875647, 62.60460500473699, 64.62523759112352, 66.66238553770921, 68.71580385180819, 70.78525656124496, 72.87051619252692, 74.97136328971101, 77.08758597000538, 79.21897951260638, 81.36534597766719, 83.52649385264007, 85.70223772353566, 87.89239796890425, 90.09680047457603, 92.31527636739827, 94.547661766387, 96.79379754986739, 99.05352913731669, 101.32670628474726, 103.61318289257667, 105.91281682503016, 108.22546974020791, 110.55100693002709, 112.88929716931968, 115.24021257342858, 117.60362846370175, 119.97942324033484, 122.3674782620578, 124.7676777322038, 127.17990859073448, 129.604060411831, 132.04002530669018, 134.48769783119326, 136.94697489814072, 139.4177556937687, 141.8999415982848, 144.39343611018023, 146.89814477409158, 149.41397511200435, 151.9408365576017, 154.47864039357927, 157.02729969175587, 159.5867292558244, 162.15684556659545, 164.73756672959752, 167.32881242490623, 169.93050385908234, 172.54256371910805, 175.16491612821605, 177.79748660351373, 180.4402020153106, 183.09299054806235, 185.75578166285115, 188.4285060613256, 191.1110956510287, 193.80348351204665, 196.5056038649152, 199.21739203972342, 201.93878444635877, 204.66971854584008], [0.0, 0.41362284160340346, 1.0543747769352194, 1.8227126504097724, 2.687729154240321, 3.63257023261356, 4.646315558258069, 5.721196547983828, 6.851347513785627, 8.032151689411148, 9.259861988922435, 10.531364367112213, 11.844021745313306, 13.195566494870132, 14.584023722430132, 16.00765492258594, 17.464915570305752, 18.954422535406884, 20.474928591958687, 22.025302164225053, 23.60451101098154, 25.211608921466865, 26.845724748548534, 28.506053279830958, 30.191847571379018, 31.902412457971845, 33.63709901906943, 35.39529982809213, 37.176444848999104, 38.97999787182183, 40.80545340008282, 42.652333919550685, 44.5201874907337, 46.40858561775372, 48.31712135440511, 50.24540761475805, 52.19307566096792, 54.15977374526839, 56.14516588666197, 58.1489307657356, 60.17076072344212, 62.210360851700045, 64.26744816534543, 66.34175084638588, 68.43300755270053, 70.54096678434398, 72.66538630147531, 74.80603258867032, 76.96268036100878, 79.13511210787239, 81.32311767086088, 83.52649385264007, 85.74504405389054, 87.97857793583533, 90.22691110609296, 92.48986482584087, 94.7672657364805, 97.05894560417914, 99.36474108082548, 101.68449348007795, 104.01804856731296, 106.36525636239182, 108.72597095426634, 111.10005032653257, 113.48735619312143, 115.88775384338851, 118.30111199592776, 120.72730266049297, 123.166201007463, 125.6176852443328, 128.08163649875613, 130.55793870770285, 133.04647851233, 135.54714515819603, 138.05983040047715, 140.58442841387105, 143.12083570689586, 145.66895104031533, 148.22867534944064, 150.79991167007606, 153.38256506789526, 155.97654257104617, 158.58175310580097, 161.19810743507588, 163.82551809966168, 166.46389936201274, 169.11316715245556, 171.7732390176854, 174.4440340714276, 177.12547294715054, 179.8174777527214, 182.51997202690475, 185.2328806976098, 187.95613004179694, 190.68964764696165, 193.43336237411657, 196.1872043221984, 198.95110479383118, 201.72499626237993, 204.5088123402339, 207.30248774826126, 210.1059582863808], [0.0, 0.42439711597997093, 1.0818397087518348, 1.8701916680796558, 2.7577405956912533, 3.7271934120941967, 4.767345331349727, 5.87022540995696, 7.0298151672560785, 8.24137757693818, 9.501067946918003, 10.805691115632715, 12.152541312345328, 13.539291839966745, 14.963916362040434, 16.424631087617758, 17.919851259032743, 19.448157717569966, 21.00827074887446, 22.599029301305418, 24.219374245253487, 25.868334722541107, 27.545016893918028, 29.248594572375048, 30.978301357172224, 32.733423975044175, 34.51329660201316, 36.317295988919234, 38.14483725111046, 39.9953702111273, 41.8683762050431, 43.76336528007416, 45.679873724361286, 47.617461880330964, 49.57571220141984, 51.554227518671745, 53.552629489156665, 55.570557202589754, 57.60766592615644, 59.66362597053955, 61.738121662620536, 63.830850412390625, 65.9415218633333, 68.06985711699218, 70.21558802366367, 72.37845653219401, 74.55821409274621, 76.75462110715834, 78.96744642216517, 81.19646686131264, 83.44146679187936, 85.70223772353566, 87.97857793583533, 90.27029213195267, 92.57719111635245, 94.89909149432533, 97.23581539153301, 99.58719019189573, 101.9530482923211, 104.33322687291877, 106.7275676814772, 109.13591683109287, 111.55812460994669, 113.99404530231358, 116.4435370199732, 118.9064615432645, 121.38268417109138, 123.87207357924764, 126.37450168648176, 128.88984352777078, 131.41797713431646, 133.95878341981532, 136.5121460725911, 139.0779514532099, 141.65608849722747, 144.24644862274604, 146.84892564248088, 149.46341568006076, 152.08981709030544, 154.7280303832428, 157.37795815164515, 160.03950500187867, 162.71257748787718, 165.39708404806044, 168.09293494503385, 170.80004220791324, 173.5183195771322, 176.2476824515971, 178.9880478380633, 181.7393343026163, 184.50146192414633, 187.2743522497138, 190.05792825170894, 192.85211428671406, 195.65683605598406, 198.47202056746423, 201.29759609927012, 204.13349216455882, 206.97963947772465, 209.83596992185596, 212.7024165173943, 215.57891339193964], [0.0, 0.4352427801814922, 1.109486621888605, 1.917985279442067, 2.828215929593339, 3.8224435602210374, 4.889177041909583, 6.020241730017522, 7.209465338833632, 8.451989785155064, 9.7438721240156, 11.081835540023775, 12.463105115222426, 13.885294692704338, 15.34632615204947, 16.84437011670809, 18.377801329800544, 19.945164365355346, 21.54514680532647, 23.176557926862493, 24.83831153380799, 26.52941195725652, 28.248942515483197, 29.996055907888433, 31.769966148007605, 33.56994173454778, 35.39529982809213, 37.24540125206071, 39.119646174804345, 41.01747035882455, 42.938341885498595, 44.88175828107325, 46.847243983318705, 48.83434809900919, 50.8426424109862, 52.871719600457546, 54.92119165576501, 56.9906884433948, 59.07985642072615, 61.18835747307921, 63.31586786016315, 65.46207725914186, 67.62668789330401, 69.80941373681445, 72.00997978728009, 74.22812139893082, 76.46358367012388, 78.71612087965569, 80.98549596703259, 83.27148005242327, 85.5738519925126, 87.89239796890425, 90.22691110609296, 92.57719111635245, 94.94304396916826, 97.32428158309463, 99.7207215381324, 102.13218680691824, 104.55850550318533, 106.99951064610592, 109.45503993926009, 111.92493556309351, 114.40904397983245, 116.90721574991919, 119.41930535911443, 121.94517105548988, 124.48467469560076, 127.03768159919014, 129.604060411831, 132.18368297496156, 134.7764242028146, 137.38216196578122, 140.00077697978656, 142.63215270128856, 145.2761752275398, 147.93273320178199, 150.60171772306535, 153.28302226040998, 155.97654257104622, 158.68217662248972, 161.39982451822613, 164.12938842679333, 166.87077251406774, 169.6238828785707, 172.38862748962703, 175.16491612821605, 177.95266033036827, 180.7517733329701, 183.5621700218462, 186.3837668820008, 189.21648194990328, 192.06023476771296, 194.914946339344, 197.78053908827616, 200.65693681702567, 203.54406466819214, 206.44184908700527, 209.35021778529838, 212.26909970684008, 215.19842499395963, 218.13812495540512, 221.08813203537682], [0.0, 0.4461589719953403, 1.1373133184609963, 1.9660896849828002, 2.8991495532723985, 3.9183131047625497, 5.011801004515217, 6.171233582112577, 7.390283746622454, 8.663971570734516, 9.988255217678883, 11.359775687253729, 12.775688464628447, 14.233547546420056, 15.731222691502209, 17.26683864128824, 18.838729376324924, 20.445402967544585, 22.085514080543277, 23.757842128311843, 25.461273672139384, 27.194788071050404, 28.957445652304436, 30.748377864413204, 32.56677900782459, 34.411899234684185, 36.28303857948738, 38.179541834660824, 40.100794124360135, 42.046217059617724, 44.01526538092163, 46.007424012127224, 48.022205463573016, 50.05914753331737, 52.11781126421745, 54.19777912164229, 56.29865336233127, 58.42005456956451, 60.56162033362627, 62.72300405968522, 64.90387388781878, 67.10391171207812, 69.32281228730479, 71.56028241393662, 73.81604019232917, 76.08981433921223, 78.38134355983242, 80.6903759701274, 83.01666856396139, 85.35998672103759, 87.72010375161263, 90.09680047457603, 92.48986482584087, 94.89909149432533, 97.32428158309463, 99.76524229348944, 102.22178663029007, 104.69373312616375, 107.18090558381647, 109.68313283442508, 112.20024851106255, 114.73209083595029, 117.27850242048032, 119.83933007704688, 122.41442464181225, 125.0036408076111, 127.60683696626499, 130.22387505964238, 132.85462043885582, 135.4989417310376, 138.15671071318243, 140.8278021925858, 143.5120938934453, 146.20946634922566, 148.91980280041935, 151.64298909736303, 154.37891360779537, 157.12746712886536, 159.88854280332205, 162.66203603963552, 165.4478444358172, 168.24586770672383, 171.05600761464535, 173.8781679029887, 176.7122542328853, 179.5581741225586, 182.41583688930126, 185.28515359392037, 188.16603698751788, 191.0584014604838, 193.96216299358508, 196.87723911104246, 199.80354883549325, 202.74101264474416, 205.68955243022543, 208.64909145706102, 211.61955432567578, 214.6008669348655, 217.5929564462591, 220.59575125010684, 223.60918093233232, 226.63317624278943], [0.0, 0.4571448551623826, 1.1653176667430794, 2.014501199556968, 2.9705360327005566, 4.014794701419227, 5.1352078252854705, 6.3231893991757495, 7.572256538626587, 8.87730669434077, 10.234198506397881, 11.639490265099944, 13.090267414421268, 14.58402372243013, 16.118576494543905, 17.692004297218038, 19.302600088188576, 20.948835202247892, 22.62933117848892, 24.342837375085445, 26.08821293684868, 27.864412091306924, 29.67047202792446, 31.505502808654025, 33.368678895003335, 35.259231975428044, 37.1764448489991, 39.11964617480434, 41.08820593675879, 43.081531504079656, 45.099064191194614, 47.14027623911121, 49.20466815458896, 51.291766354773024, 53.401121073969826, 55.5323044964895, 57.68490908534035, 59.85854608133035, 62.052844151039366, 64.26744816534543, 66.50201809285669, 68.75622799482254, 71.02976510995718, 73.32232901917283, 75.63363088154004, 77.96339273391334, 80.3113468476137, 82.67723513637499, 85.06080861046097, 87.461826872461, 89.88005765079392, 92.31527636739827, 94.7672657364805, 97.23581539153301, 99.7207215381324, 102.22178663029007, 104.73881906835662, 107.27163291668406, 109.82004763942865, 112.38388785303482, 114.96298309408137, 117.55716760129528, 120.1662801106498, 122.79016366256269, 125.42866542029805, 128.0816364987561, 130.74893180290508, 133.43040987517375, 136.12593275118172, 138.8353658232345, 141.5585777110599, 144.29544013930237, 147.045827821332, 149.80961834895945, 152.58669208767876, 155.37693207709114, 158.1802239361863, 160.99645577318432, 163.8255180996617, 166.6673037487052, 169.52170779685673, 172.38862748962703, 175.2679621703745, 178.15961321235605, 181.06348395377373, 183.97947963564928, 186.9075073423725, 189.84747594477867, 192.79929604561843, 195.7628799272951, 198.7381415017492, 201.72499626237988, 204.72336123789876, 207.73315494801778, 210.7542973608805, 213.786709852149, 216.83031516566564, 219.88503737561382, 222.95080185010522, 226.0275352161254, 229.11516532577468, 232.21362122374344], [0.0, 0.4681996181446849, 1.1934975980262572, 2.06321624695864, 3.0423700944887586, 4.111881223001161, 5.259388388037795, 6.476097956082213, 7.75537027233791, 9.091979396699596, 10.48168382210131, 11.920958610772978, 13.406818726346192, 14.936697330716656, 16.508358946970276, 18.119835677094656, 19.769379198808327, 21.455423880433713, 23.176557926862493, 24.931500453012266, 26.719083015319217, 28.53823455224478, 30.387968970387536, 32.26737481105076, 34.17560657241487, 36.111877363481064, 38.07545263983234, 40.06564482606418, 42.08180867092398, 44.12333721251975, 46.18965825503943, 48.28023127712323, 50.39454470669103, 52.53211350861823, 54.69247704089254, 56.87519714230451, 59.07985642072615, 61.30605671591745, 63.55341771480356, 65.82157570046321, 68.1101824188014, 70.41890404915527, 72.74742026698671, 75.09542338841695, 77.46261758771082, 79.8487181799657, 82.25345096223722, 84.67655160716858, 87.1177651039068, 89.57684524170585, 92.05355413214937, 94.547661766387, 97.05894560417914, 99.58719019189573, 102.13218680691824, 104.69373312616375, 107.27163291668406, 109.86569574650032, 112.47573671401703, 115.10157619452045, 117.74303960241079, 120.39995716794473, 123.07216372737848, 125.7594985255036, 128.46180502965746, 131.17893075437274, 133.9107270959023, 136.65704917592132, 139.4177556937687, 142.1927087866414, 144.9817738972047, 147.78481964812428, 150.60171772306532, 153.4323427537406, 156.27657221262004, 159.13428631094638, 162.0053679017263, 164.8897023873917, 167.78717763184943, 170.6976838766558, 173.62111366107382, 176.55736174578593, 179.5063250400526, 182.46790253212023, 185.44199522269716, 188.4285060613256, 191.4273398854926, 194.43840336233075, 197.46160493276966, 200.49685475800916, 203.54406466819214, 206.60314811316314, 209.67402011520653, 212.75659722366254, 215.85079747132932, 218.95654033256037, 222.07374668297516, 225.20233876070466, 228.34224012909814, 231.49337564082114, 234.65567140327994, 237.82905474531015], [0.0, 0.47932247297239156, 1.221851103679823, 2.1122313548393876, 3.114646618393776, 4.209565749300969, 5.3843338413350095, 6.629948353698834, 7.939611895635579, 9.307974376205834, 10.730693524341447, 12.204160661556692, 13.725319837016567, 15.291543233140295, 16.900542265569392, 18.550302285625595, 20.239033436745522, 21.965132893086576, 23.727155320017054, 25.523789402914957, 27.35383893991076, 29.216207424630948, 31.10988533739752, 33.03393956630779, 34.9875045232507, 36.969774623332775, 38.97999787182183, 41.01747035882455, 43.08153150407966, 45.17155992631346, 47.28696983625781, 49.4272078715757, 51.591750306947795, 53.78010058443939, 55.99178711872676, 58.226361339357645, 60.48339593836501, 62.76248329655506, 65.06323406588804, 67.38527588874682, 69.72825223768544, 72.09182136158014, 74.47565532605462, 76.87943913769166, 79.3028699429274, 81.7456562936994, 84.2075174729197, 86.68818287369876, 89.18739142697987, 91.70489107287426, 94.24043827153353, 96.79379754986739, 99.36474108082548, 101.9530482923211, 104.55850550318533, 107.18090558381647, 109.82004763942865, 112.47573671401703, 115.14778351334347, 117.8360041454126, 120.54021987705556, 123.2602569053685, 125.99594614287021, 128.74712301534694, 131.51362727144422, 134.29530280315083, 137.09199747639218, 139.90356297101974, 142.72985462954196, 145.57073131399727, 148.42605527041945, 151.2956920003886, 154.17951013920364, 157.07738134024666, 159.98918016514386, 162.91478397935836, 165.85407285287653, 168.80692946567595, 171.77323901768543, 174.75288914296823, 177.74576982788022, 180.75177333297006, 183.77079411840757, 186.80272877273822, 189.84747594477867, 192.90493627847732, 195.97501235057862, 199.05760861093893, 202.15263132535085, 205.25998852074528, 208.37958993264462, 211.51134695475156, 214.65517259056455, 217.81098140691566, 220.97868948933686, 224.15821439916192, 227.3494751322801, 230.5523920794608, 233.76688698817443, 236.9928829258376, 240.23030424441598, 243.47907654632175], [0.0, 0.4905126541634126, 1.250376232397111, 2.1615431499476676, 3.187360630298315, 4.307841557606138, 5.510035586349907, 6.784730003941373, 8.124968728891478, 9.525276767944774, 10.981210476108934, 12.489076927302106, 14.045748826979192, 15.648537008975689, 17.295099460030677, 18.98337449781941, 20.711530480090623, 22.477927161701338, 24.281085465482576, 26.11966346308349, 27.992437026308515, 29.898284049932236, 31.836171446201394, 33.805144318941025, 35.80431687216678, 37.83286471393684, 39.89001829357749, 41.97505726783439, 44.087305634651464, 46.22612750609316, 48.39092341715438, 50.58112708679484, 52.796202562892645, 55.03564169495577, 57.29896188810947, 59.58570409965173, 61.895431045756176, 64.22772559102043, 66.58218929775141, 68.95844111533417, 71.35611619289345, 73.7748648008417, 76.21435134890224, 78.67425348987497, 81.15426129982806, 83.65407652660201, 86.17341189953532, 88.7119904941959, 91.26954514665309, 93.84581791247065, 96.44055956616025, 99.05352913731669, 101.68449348007795, 104.33322687291877, 106.99951064610592, 109.68313283442508, 112.38388785303482, 115.10157619452045, 117.8360041454126, 120.5869835206046, 123.35433141425332, 126.13786996588178, 128.9374261405211, 131.75283152183584, 134.5839221172706, 137.4305381743429, 140.29252400728194, 143.1697278332821, 146.0620016177026, 148.96920092759893, 151.89118479302408, 154.82781557558093, 157.77895884375027, 160.74448325455586, 163.72426044116088, 166.7181649060233, 169.72607391926383, 172.7478674219266, 175.78342793383746, 178.83264046578356, 181.8953924357609, 184.97157358905113, 188.06107592190912, 191.16379360865403, 194.279622931975, 197.40846221627092, 200.55021176385938, 203.70477379389928, 206.8720523838804, 210.05195341354585, 213.24438451111888, 216.4492550017146, 219.66647585782587, 222.89595965177648, 226.1376205100455, 229.3913740693676, 232.65713743452372, 235.9348291377397, 239.22436909961573, 242.5256785915132, 245.83868019933178, 249.16329778861004], [0.0, 0.5017694177101616, 1.279071087612569, 2.211148353663676, 3.260507295626814, 4.406702113800222, 5.636485265483056, 6.940432615759126, 8.311428448186286, 9.743872124015597, 11.233218021148659, 12.775688464628445, 14.368084391699725, 16.007654922585935, 17.69200429721804, 19.41902351977134, 21.18683891367895, 22.99377259185006, 24.838311533807985, 26.719083015319217, 28.634834815698554, 30.58441907855374, 32.566779007824586, 34.580937793445905, 36.62598931132181, 38.701090250558885, 40.80545340008282, 42.938341885498595, 45.09906419119462, 47.2869698362578, 49.50144559857454, 51.74191220153404, 54.00782139346159, 56.29865336233127, 58.61391443820973, 60.953135043834614, 63.31586786016314, 65.70168617896223, 68.1101824188014, 70.54096678434398, 72.99366605176039, 75.4679224655269, 77.96339273391334, 80.47974711218114, 83.01666856396136, 85.57385199251259, 88.15100353460558, 90.74783991067582, 93.36408782565384, 95.99948341554249, 98.65377173538343, 101.32670628474726, 104.01804856731296, 106.7275676814772, 109.45503993926009, 112.20024851106255, 114.96298309408137, 117.74303960241079, 120.54021987705556, 123.35433141425332, 126.18518711065899, 129.0326050240796, 131.89640814857083, 134.7764242028146, 137.67248543079415, 140.58442841387105, 143.5120938934453, 146.45532660345117, 149.41397511200432, 152.387891671572, 155.3769320770911, 158.38095553150416, 161.3998245182261, 164.4334046800938, 167.4815647043828, 170.54417621351098, 173.62111366107382, 176.71225423288527, 179.8174777527214, 182.93666659248456, 186.06970558652895, 189.21648194990323, 192.37688520028684, 195.55080708340782, 198.73814150174917, 201.93878444635874, 205.15263393159432, 208.3795899326446, 211.61955432567578, 214.87243083046747, 218.13812495540512, 221.41654394470802, 224.7075967277788, 228.0111938705656, 231.32724752883794, 234.65567140327994, 237.99638069631206, 241.3492920705581, 244.71432360887786, 248.0913947758912, 251.4804263809232, 254.8813405423046], [0.0, 0.5130920401281289, 1.307933825076456, 2.261043777806694, 3.3340819131630606, 4.506141064007107, 5.763674751675229, 7.0970461819748705, 8.498979069549831, 9.963746395055596, 11.486699962659971, 13.06397685269861, 14.692305814318745, 16.368873893069807, 18.091231267623332, 19.857221351842096, 21.664928188917425, 23.512636029582552, 25.398797711464198, 27.32200953427166, 29.280991020472076, 31.274568411846452, 33.30166106531973, 35.36127012872699, 37.45246903092909, 39.574395431393704, 41.7262443553219, 43.907262300460836, 46.116742146879695, 48.354018735310135, 50.618465006042626, 52.909488610863946, 55.226528926586724, 57.56905441142413, 59.93656025558843, 62.32856628562338, 64.7446150885577, 67.18427032732076, 69.6471152232483, 72.13275118512, 74.64079656716514, 77.17088554096722, 79.7226670682844, 82.2958039635596, 84.88997203637472, 87.50485930536146, 90.14016527615233, 92.79560027686907, 95.47088484543245, 98.16574916365144, 100.87993253363541, 103.61318289257667, 106.36525636239182, 109.13591683109287, 111.92493556309351, 114.73209083595029, 117.55716760129528, 120.39995716794473, 123.2602569053685, 126.13786996588178, 129.0326050240796, 131.94427603217258, 134.8727019900082, 137.81770672867341, 140.7791187066715, 143.75677081775882, 146.750500209603, 149.76014811249902, 152.78555967744313, 155.82658382292186, 158.8830730898287, 161.9548835039657, 165.04187444563252, 168.14390852584424, 171.26085146875366, 174.39257199988847, 177.5389417398406, 180.69983510307407, 183.8751292015416, 187.0647037528217, 190.2684409925109, 193.48622559062153, 196.71794457175633, 199.9634872388436, 203.22274510023448, 206.49561179997428, 209.78198305107512, 213.0817565716267, 216.3948320235928, 219.72111095415232, 223.0604967394506, 226.41289453063658, 229.7782112020694, 233.15635530158295, 236.5472370027075, 239.95076805874945, 243.36686175863883, 246.79543288445907, 250.23639767057787, 253.6896737643027, 257.15518018799037, 260.6328373025413], [0.0, 0.5244798175615637, 1.3369626505751175, 2.3112263206940975, 3.408079909238891, 4.606152226736818, 5.891596138361318, 7.254560966914733, 8.68760893414739, 10.184885912873385, 11.74164054327539, 13.353924170448705, 15.01839294004309, 16.73217146573083, 18.49275555383335, 20.29794075404673, 22.145768586022648, 24.034485220443862, 25.96250915657404, 27.92840553981634, 29.930865473188728, 31.968689147595732, 34.04077193572192, 36.14609281646339, 38.283704653977, 40.4527259685872, 42.652333919550685, 44.88175828107325, 47.140276239111216, 49.4272078715757, 51.74191220153404, 54.08378373395123, 56.452249402936474, 58.846765869444184, 61.26681711972893, 63.71191232316572, 66.18158391477019, 68.6753858732259, 71.19289216971013, 73.7336953665038, 76.29740534743173, 78.88364816472989, 81.49206498906821, 84.12231115125358, 86.77405526565134, 89.4469784266494, 92.1407734705837, 94.85514429647824, 97.58980523975657, 100.34448049377086, 103.11890357459343, 105.91281682503016, 108.72597095426634, 111.55812460994669, 114.40904397983245, 117.27850242048032, 120.1662801106498, 123.07216372737848, 125.99594614287021, 128.9374261405211, 131.89640814857083, 134.8727019900082, 137.8661226474884, 140.87649004213233, 143.9036288251803, 146.9473681815634, 150.00754164453707, 153.08398692059566, 156.17654572395244, 159.2850636199282, 162.40938987664788, 165.54937732449048, 168.70488222278377, 171.87576413327477, 175.06188579994242, 178.26311303475435, 181.4793146089967, 184.7103621498361, 187.9561300417969, 191.2164953328598, 194.49133764490927, 197.7805390882761, 201.08398418014022, 204.40155976657326, 207.73315494801773, 211.07866100801078, 214.43797134497586, 217.8109814069156, 221.19758862884981, 224.59769237285465, 228.01119387056556, 231.4379961680168, 234.8780040726984, 238.33112410271698, 241.7972644379569, 245.27633487314085, 248.76824677269747, 252.2729130273484, 255.79024801233214, 259.32016754718643, 262.86258885701665, 266.41743053518], [0.0, 0.5359320649419675, 1.3661558177858835, 2.361692963433086, 3.4824968322660705, 4.706729585495138, 6.020241730017522, 7.412967494768547, 8.877306694340772, 10.407277374107688, 11.99802442622163, 13.645512975162209, 15.34632615204947, 17.0975257852312, 18.896553000859, 20.741155213487467, 22.629331178488922, 24.55928877091199, 26.52941195725652, 28.538234552244784, 30.584419078553744, 32.66673952872889, 34.78406715543176, 36.93535864311379, 39.119646174804345, 41.33602902333166, 43.58366638086308, 45.86177120338557, 48.169604893893066, 50.506472683898984, 52.871719600457546, 55.26472692728349, 57.68490908534036, 60.13171087153566, 62.60460500473699, 65.10308993681689, 67.62668789330401, 70.1749431138104, 72.74742026698671, 75.34370301853212, 77.96339273391334, 80.60610730005246, 83.27148005242327, 85.9591587958293, 88.66880490868489, 91.40009252193371, 94.15270776485808, 96.92634807098699, 99.72072153813241, 102.53554633728712, 105.37055016572967, 108.22546974020791, 111.10005032653257, 113.99404530231358, 116.90721574991919, 119.83933007704688, 122.79016366256269, 125.7594985255036, 128.74712301534694, 131.75283152183584, 134.7764242028146, 137.81770672867341, 140.87649004213233, 143.95259013221087, 147.045827821332, 150.15602856460475, 153.28302226040998, 156.42664307149207, 159.5867292558244, 162.76312300657878, 165.95567030058336, 169.1642207547038, 172.38862748962703, 175.6287470005691, 178.88443903446344, 182.15556647322296, 185.4419952226972, 188.74359410697542, 192.060234767713, 195.39179156817912, 198.73814150174923, 202.09916410458132, 205.47474137223728, 208.86475768002288, 212.26909970684005, 215.68765636235423, 219.12031871729653, 222.5669799367308, 226.02753521612541, 229.5018817200832, 232.9899185235889, 236.4915465556444, 240.00666854516936, 243.5351889690522, 247.0770140022447, 250.63205146979763, 254.20021080074298, 257.781402983733, 261.3755405243519, 264.98253740402, 268.6023090404164, 272.2347722493486], [0.0, 0.5474481151954883, 1.3955116262566187, 2.4124407664279057, 3.5573283475859196, 4.807867281822684, 6.149604033257826, 7.572256538626587, 9.068061300559407, 10.630907824835678, 12.255836677575353, 13.938726282289213, 15.67608634878832, 17.464915570305752, 19.302600088188576, 21.186838913678947, 23.115587799621046, 25.087016112076352, 27.09947309239163, 29.151461050058458, 31.24161376818573, 33.36867889500333, 35.531503428772055, 37.729021635291666, 39.96024490124513, 42.22425314473263, 44.5201874907337, 46.8472439833187, 49.20466815458896, 51.591750306947795, 54.0078213934616, 56.452249402936474, 58.92443617347697, 61.42381457184658, 63.94984598675294, 66.50201809285669, 69.07984284932029, 71.68285470242586, 74.3106089664711, 76.96268036100876, 79.6386616856898, 82.33816261663183, 85.06080861046094, 87.80623990404837, 90.57411059954445, 93.36408782565381, 96.17585096723872, 99.00909095631259, 101.8635096183247, 104.73881906835662, 107.6347411524755, 110.55100693002709, 113.48735619312143, 116.4435370199732, 119.41930535911443, 122.41442464181225, 125.42866542029805, 128.46180502965746, 131.51362727144422, 134.5839221172706, 137.67248543079415, 140.7791187066715, 143.9036288251803, 147.045827821332, 150.20553266740126, 153.38256506789523, 156.57675126606964, 159.78792186117582, 163.01591163569208, 166.26055939185406, 169.52170779685667, 172.79920323614908, 176.0928956742914, 179.40263852288444, 182.72828851511883, 186.06970558652893, 189.4267527615636, 192.79929604561838, 196.1872043221984, 199.59034925490434, 203.0086051939586, 206.4418490870052, 209.8899603939394, 213.35282100553604, 216.83031516566558, 220.32232939689632, 223.82875242929904, 227.34947513228005, 230.88439044927924, 234.4333933351836, 237.99638069631206, 241.57325133283953, 245.16390588353534, 248.7682467726975, 252.38617815917533, 256.0176058873743, 259.66243744014724, 263.3205818934801, 266.9919498728866, 270.6764535114292, 274.37400640929116, 278.08452359482703], [0.0, 0.5590273184956533, 1.4250284195008498, 2.4634668660868657, 3.6325702326135603, 4.909559608732161, 6.279675748439784, 7.732419110143435, 9.259861988922435, 10.855764646061795, 12.51506274953395, 14.233547546420054, 16.00765492258594, 17.834320089922326, 19.710873903439737, 21.634966705628205, 23.60451101098154, 25.617637465394044, 27.672660394629585, 29.768050430177038, 31.902412457971845, 34.074467637458305, 36.28303857948738, 38.52703700826516, 40.80545340008282, 43.117348212172764, 45.46184440324784, 47.83812101271824, 50.24540761475806, 52.68297950079053, 55.150153472713676, 57.6462841515168, 60.17076072344212, 62.72300405968521, 65.30246415666012, 67.90861785271423, 70.54096678434396, 73.19903555079571, 75.88237006071574, 78.59053603845047, 81.32311767086088, 84.07971637823273, 86.85994969513752, 89.66345024901226, 92.48986482584085, 95.33885351368922, 98.21008891601376, 101.1032554276585, 104.01804856731297, 106.9541743609374, 109.91134877129997, 112.88929716931968, 115.88775384338851, 118.9064615432645, 121.94517105548988, 125.0036408076111, 128.0816364987561, 131.17893075437274, 134.29530280315083, 137.4305381743429, 140.58442841387105, 143.75677081775882, 146.9473681815634, 150.15602856460475, 153.38256506789523, 156.62679562477226, 159.88854280332203, 163.16763361976092, 166.46389936201274, 169.77717542278145, 173.107301141479, 176.45411965441716, 179.81747775272137, 183.1972257474668, 186.59321734157433, 190.00530950804193, 193.43336237411654, 196.87723911104246, 200.33680582904904, 203.8119314772638, 207.30248774826126, 210.80834898697623, 214.32939210373195, 217.8654964911474, 221.41654394470802, 224.9824185867944, 228.56300679398103, 232.15819712742737, 235.767880266195, 239.3919489433371, 243.030297884614, 246.68282374969945, 250.34942507575005, 254.03000222321734, 257.724457323792, 261.43269423037253, 265.15461846895977, 268.8901371923847, 272.6391591357803, 276.4015945737147, 280.17735527890864, 283.9663544824614], [0.0, 0.5706690415581855, 1.4547045832001664, 2.5147684717148033, 3.7082183722556197, 5.011801004515216, 6.410449761743043, 7.8934464497839425, 9.452698269557871, 11.081835540023773, 12.775688464628445, 14.529960643330444, 16.341013739451657, 18.205719140784712, 20.121352117495253, 22.085514080543277, 24.096074072614773, 26.151123810374493, 28.248942515483193, 30.387968970387536, 32.566779007824586, 34.78406715543176, 37.03863150497489, 39.32936111735724, 41.65522544557638, 44.015265380921626, 46.40858561775372, 48.83434809900919, 51.29176635477303, 53.78010058443939, 56.29865336233128, 58.846765869444184, 61.423814571846584, 64.0292082803983, 66.6623855377092, 69.32281228730479, 72.00997978728007, 74.7234027366785, 77.46261758771081, 80.22718102094915, 83.01666856396136, 85.83067333662555, 88.66880490868489, 91.5306882570565, 94.41596281205555, 97.32428158309462, 100.25531035560927, 103.20872695197795, 106.18422055007825, 109.18149105387198, 112.20024851106254, 115.24021257342858, 118.30111199592776, 121.38268417109138, 124.48467469560076, 127.60683696626499, 130.74893180290508, 133.9107270959023, 137.09199747639218, 140.29252400728194, 143.5120938934453, 146.750500209603, 150.00754164453707, 153.28302226040998, 156.57675126606964, 159.88854280332203, 163.21821574524031, 166.56559350566005, 169.93050385908234, 173.31277877027034, 176.7122542328853, 180.12877011655843, 183.56217002184616, 187.01230114255733, 190.47901413498164, 193.96216299358505, 197.46160493276963, 200.97720027432595, 204.50881234023393, 208.05630735049147, 211.61955432567578, 215.1984249939596, 218.79279370232828, 222.4025373317566, 226.02753521612536, 229.66766906466805, 233.3228228877555, 236.9928829258376, 240.67773758137136, 244.3772773535798, 248.09139477589122, 251.81998435592084, 255.56294251786537, 259.3201675471865, 263.0915595374709, 266.8770203393574, 270.6764535114292, 274.4897642729786, 278.316859458551, 282.1576474741858, 286.012038255274, 289.8799432259557], [0.0, 0.5823726669749315, 1.484538543506321, 2.5663428625779034, 3.784268754582081, 5.1145860468927715, 6.5419191376872075, 8.055330017610173, 9.64655991556964, 11.309108517258156, 13.037700000811993, 14.82794985302242, 16.67614512000499, 18.579093026083342, 20.53401296101781, 22.538457144055496, 24.590250914922578, 26.68744685405648, 28.828288892356337, 31.01118379387617, 33.23467818367056, 35.49743981596112, 37.798242133053634, 40.13595141204129, 42.50951597084123, 44.91795703076198, 47.36036092469543, 49.835872408197616, 52.343688881953454, 54.88305537307939, 57.45326015267136, 60.053630890266774, 62.683531264123566, 65.34235796063759, 68.02953800771138, 70.74452639611768, 73.48680395036521, 76.25587541665226, 79.0512677404715, 81.87252851053243, 84.71922454906588, 87.59094063140665, 90.48727832011834, 93.40785490091817, 96.35230240934041, 99.32026673850507, 102.31140681957353, 105.32539386751098, 108.36191068566718, 111.4206510234531, 114.50131898205531, 117.60362846370175, 120.72730266049297, 123.87207357924764, 127.03768159919014, 130.22387505964238, 133.43040987517375, 136.65704917592132, 139.90356297101974, 143.1697278332821, 146.45532660345117, 149.76014811249902, 153.08398692059566, 156.42664307149207, 159.78792186117582, 163.16763361976092, 166.56559350566005, 169.98162131117306, 173.41554127869645, 176.8671819268253, 180.33637588567973, 183.82295974084067, 187.32677388533025, 190.84766237911572, 194.38547281565562, 197.94005619504637, 201.51126680335662, 205.09896209777196, 208.70300259719681, 212.32325177798805, 215.95957597451775, 219.61184428428257, 223.27992847729985, 226.96370290954508, 230.6630444402054, 234.3778323525358, 238.10794827812174, 241.85327612436353, 245.61370200500838, 249.38911417357124, 253.17940295949097, 256.9844607068813, 260.80418171574377, 264.6384621855169, 268.4872001608464, 272.3502954794644, 276.2276497220756, 280.11916616415215, 284.024749729546, 287.94430694583235, 291.8777459013027, 295.82497620353], [0.0, 0.5941375925841781, 1.5145287654360924, 2.6181873851288726, 3.8607174667345876, 5.217909447484946, 6.674077112058469, 8.218061484571678, 9.841436952607337, 11.537571884372475, 13.301083877363036, 15.127499843691806, 17.013031821444745, 18.95442253540688, 20.948835202247892, 22.993772591850057, 25.087016112076352, 27.226579002152658, 29.410669717373732, 31.63766283569791, 33.90607562151591, 36.2145489154022, 38.56183138109574, 40.946766392544696, 43.368281021886375, 45.82537671742285, 48.31712135440511, 50.8426424109862, 53.40112107396983, 55.99178711872677, 58.61391443820974, 61.266817119728934, 63.94984598675295, 66.66238553770921, 69.40385122548227, 72.17368703072475, 74.97136328971098, 77.79637474366396, 80.64823878156487, 83.52649385264007, 86.43069802818732, 89.36042769529179, 92.31527636739827, 95.29485359873979, 98.298783991338, 101.32670628474726, 104.37827251995411, 107.45314726990273, 110.5510069300271, 113.67153906295165, 116.81444179219996, 119.97942324033484, 123.166201007463, 126.37450168648176, 129.604060411831, 132.85462043885582, 136.12593275118172, 139.4177556937687, 142.72985462954196, 146.0620016177026, 149.41397511200432, 152.78555967744313, 156.17654572395244, 159.5867292558244, 163.01591163569208, 166.46389936201274, 169.93050385908234, 173.41554127869645, 176.91883231264688, 180.44020201531058, 183.97947963564928, 187.53649845799274, 191.11109565102868, 194.70311212446845, 198.3123923928975, 201.93878444635874, 205.58213962724994, 209.24231251314754, 212.91916080519886, 216.61254522174934, 220.32232939689635, 224.04837978368167, 227.7905655616574, 231.54875854857437, 235.3228331159644, 239.11266610839738, 242.91813676621405, 246.73912665154526, 250.57551957744084, 254.4272015399453, 258.2940606529642, 262.17598708577805, 266.07287300306723, 269.9846125073211, 273.91110158351256, 277.8522380459244, 281.8079214870229, 285.77805322827885, 289.76253627284336, 293.7612752599885, 297.7741764212317, 301.80114753806396], [0.0, 0.6059632308748616, 1.5446737513525413, 2.670299450381465, 3.937560691054986, 5.321766046578623, 6.806917085216961, 8.381632724264566, 10.037319648997421, 11.767214232475569, 13.5658269415472, 15.428595656558631, 17.35165702048867, 19.331688925735055, 21.36579812599661, 23.45143768660827, 25.58634485686022, 27.768493331747212, 29.996055907888426, 32.26737481105076, 34.5809377934459, 36.93535864311377, 39.32936111735723, 41.761765568788114, 44.23147771412544, 46.73747912662662, 49.27881912865141, 51.85460783179015, 54.46401012529391, 57.106240454081416, 59.780558258764046, 62.48626397433395, 65.22269550313348, 67.98922509272585, 70.78525656124495, 73.61022282240575, 76.46358367012385, 79.34482378901652, 82.25345096223721, 85.18899445236501, 88.15100353460556, 91.13904616450704, 94.15270776485806, 97.19159011850928, 100.25531035560925, 103.34350002523084, 106.45580424262909, 109.59188090445117, 112.75139996514739, 115.93404276862876, 119.1395014299083, 122.3674782620578, 125.6176852443328, 128.88984352777078, 132.18368297496156, 135.4989417310376, 138.8353658232345, 142.1927087866414, 145.57073131399727, 148.96920092759893, 152.387891671572, 155.82658382292186, 159.2850636199282, 162.76312300657878, 166.26055939185406, 169.77717542278145, 173.31277877027034, 176.8671819268253, 180.44020201531058, 184.03166060800788, 187.64138355527228, 191.26920082314624, 194.9149463393439, 198.5784578470641, 202.25957676613044, 205.95814806099926, 209.67402011520647, 213.40704461185928, 217.157076419807, 220.92397348515084, 224.7075967277788, 228.50780994263116, 232.3244797054266, 236.15747528259303, 240.0066685451693, 243.8719338864555, 247.7531481432076, 251.6501905201843, 255.56294251786534, 259.4912878631751, 263.43511244305284, 267.39430424072236, 271.36875327452384, 275.3583515391761, 279.3629929493503, 283.38257328543796, 287.41699014140653, 291.46614287464223, 295.5299325576833, 299.60826193175404, 303.7010353620161, 307.8081587944552], [0.0, 0.6178490084223816, 1.5749720395268296, 2.72267653142428, 4.014794701419228, 5.426150808172583, 6.940432615759126, 8.546035805127728, 10.234198506397881, 11.998024426221628, 13.831916355986738, 15.731222691502206, 17.69200429721804, 19.710873903439737, 21.784881513752946, 23.9114302361729, 26.08821293684868, 28.3131635654418, 30.58441907855374, 32.90028918523297, 35.259231975428044, 37.659834047068735, 40.10079412436013, 42.58090942150283, 45.09906419119462, 47.65422003057374, 50.24540761475805, 52.871719600457546, 55.53230449648951, 58.226361339357645, 60.95313504383462, 63.71191232316572, 66.50201809285669, 69.32281228730479, 72.17368703072475, 75.05406411361301, 77.96339273391332, 80.90114746849432, 83.86682644583134, 86.85994969513752, 89.8800576507939, 92.92670979393307, 95.99948341554247, 99.09797248756907, 102.22178663029005, 105.37055016572967, 108.54390124819066, 111.7414910640709, 114.96298309408138, 118.20805243179451, 121.47638515315643, 124.7676777322038, 128.08163649875613, 131.41797713431646, 134.7764242028146, 138.15671071318243, 141.5585777110599, 144.9817738972047, 148.42605527041945, 151.89118479302408, 155.3769320770911, 158.8830730898287, 162.40938987664788, 165.95567030058336, 169.52170779685667, 173.107301141479, 176.7122542328853, 180.33637588567973, 183.97947963564928, 187.64138355527228, 191.32191007901346, 195.02088583775284, 198.73814150174917, 202.4735116315852, 206.2268345365845, 209.99795214023018, 213.786709852149, 217.59295644625908, 221.41654394470808, 225.2573275072548, 229.1151653257747, 232.98991852358884, 236.88145105934075, 240.78962963516048, 244.71432360887783, 248.65540491005706, 252.61274795964601, 256.58622959304284, 260.57572898639654, 264.5811275859719, 268.6023090404164, 272.63915913578023, 276.6915657331479, 280.7594187087488, 284.84260989642394, 288.9410330323298, 293.0545837017722, 297.183159288064, 301.3266589233125, 305.48498344104195, 309.65803533056675, 313.84571869303284], [0.0, 0.6297943653539098, 1.6054222027752316, 2.7753161610645436, 4.0924158597629425, 5.531058815281677, 7.074617414511422, 8.711262983047032, 10.432064250941506, 12.229991593427037, 14.099339586690299, 16.03536669344723, 18.03405761976691, 20.09195960722704, 22.206065624830988, 24.373728572855114, 26.592596711829714, 28.860564046853156, 31.17573151485534, 33.536376145170976, 35.94092621679859, 38.38794100126298, 40.87609406418902, 43.40415936538103, 45.97099958592367, 48.5755562467025, 51.21684128212115, 53.893929806513874, 56.60595386615458, 59.35209701189476, 62.131589559855286, 64.94370443275209, 67.78775349415565, 70.66308430357559, 73.56907723268979, 76.50514289301925, 79.47071983342182, 82.46527247235078, 85.48828923520772, 88.53928087155607, 91.61777893063625, 94.72333437668583, 97.85551632812914, 101.013910906856, 104.19812018562784, 107.40776122319349, 110.64246517801054, 113.90187649259131, 117.18565214145684, 120.49346093651008, 123.82498288435849, 127.17990859073448, 130.55793870770285, 133.95878341981532, 137.38216196578122, 140.8278021925858, 144.29544013930237, 147.78481964812428, 151.2956920003886, 154.82781557558093, 158.38095553150416, 161.9548835039657, 165.54937732449048, 169.1642207547038, 172.79920323614908, 176.45411965441716, 180.12877011655843, 183.82295974084067, 187.53649845799274, 191.26920082314624, 195.02088583775284, 198.79137678081216, 202.5805010487989, 206.38809000372652, 210.21397882882655, 214.05800639136547, 217.92001511215378, 221.79985084133776, 225.69736274009375, 229.6124031678712, 233.5448275748585, 237.49449439936544, 241.46126496984186, 245.4450034112662, 249.44557655566115, 253.46285385650538, 257.49670730682885, 261.54701136079245, 265.6136428585634, 269.6964809543146, 273.7954070471821, 277.9103047150286, 282.0410596508695, 286.18755960182546, 290.34969431047665, 294.52735545849794, 298.72043661246414, 302.9288331717198, 307.1524423182146, 311.3911629682098, 315.64489572576974, 319.91354283795295], [0.0, 0.6417987548412617, 1.6360228471663998, 2.8282159295933385, 4.1704206127861045, 5.6364852654830555, 7.209465338833631, 8.87730669434077, 10.630907824835678, 12.463105115222422, 14.368084391699723, 16.341013739451654, 18.37780132980054, 20.474928591958687, 22.62933117848892, 24.838311533807982, 27.09947309239163, 29.410669717373732, 31.769966148007594, 34.175606572414864, 36.625989311321796, 39.11964617480433, 41.65522544557637, 44.23147771412543, 46.847243983318705, 49.501445598574534, 52.19307566096792, 54.92119165576501, 57.68490908534036, 60.48339593836501, 63.315867860163145, 66.18158391477019, 69.07984284932029, 72.00997978728007, 74.97136328971098, 77.96339273391332, 80.98549596703256, 84.0371271989049, 87.11776510390678, 90.22691110609294, 93.3640878256538, 96.52883766784251, 99.72072153813238, 102.93931766956203, 106.18422055007822, 109.45503993926006, 112.75139996514736, 116.07293829303941, 119.41930535911445, 122.79016366256268, 126.18518711065899, 129.604060411831, 133.04647851233, 136.5121460725911, 140.00077697978656, 143.5120938934453, 147.045827821332, 150.60171772306532, 154.17951013920364, 157.77895884375027, 161.3998245182261, 165.04187444563252, 168.70488222278377, 172.38862748962703, 176.0928956742914, 179.81747775272137, 183.56217002184616, 187.32677388533025, 191.11109565102868, 194.9149463393439, 198.73814150174917, 202.5805010487989, 206.4418490870052, 210.32201376400522, 214.22082712148972, 218.1381249554051, 222.0737466829751, 226.02753521612536, 229.99933684092227, 233.98900110266712, 237.99638069631206, 242.02133136188672, 246.06371178464917, 250.12338349969008, 254.20021080074292, 258.29406065296416, 262.40480260946754, 266.5323087314088, 270.6764535114292, 274.8371138002825, 279.01416873647645, 283.20749967877384, 287.41699014140653, 291.6425257318646, 295.88399409113265, 300.14128483625086, 304.41428950508686, 308.7029015032123, 313.0070160527815, 317.32653014331834, 321.66134248432, 326.01135345959506], [0.0, 0.6538616426195442, 1.6667726107943388, 2.8813734826644306, 4.2488054888251945, 5.742425466688776, 7.344970387211728, 9.044159549101629, 10.830720378389127, 12.69735461670525, 14.638138810313908, 16.648150226450806, 18.723220128731967, 20.85976381329568, 23.054659336956934, 25.305158442397655, 27.608819519598327, 29.96345609411352, 32.36709653112595, 34.81795201750651, 37.31439076972027, 39.8549170025726, 42.43815359266092, 45.062827647275526, 47.72775838542651, 50.43184687874848, 53.17406730321157, 55.95345942910603, 58.769122134287436, 61.62020776941066, 64.50591723751137, 67.42549567641004, 70.37822865288707, 73.36343879376442, 76.38048279193299, 79.42874873572727, 82.50765371843, 85.61664169151305, 88.75518153081012, 91.92276528942344, 95.1189066149815, 98.34313931204439, 101.59501603311213, 104.87410708392918, 108.1799993306662, 111.51229519816327, 114.87061174978257, 118.25457984058455, 121.6638433365428, 125.09805839337245, 128.5568927892933, 132.04002530669018, 135.54714515819603, 139.0779514532099, 142.63215270128856, 146.20946634922566, 149.80961834895945, 153.4323427537406, 157.07738134024666, 160.74448325455586, 164.4334046800938, 168.14390852584424, 171.87576413327477, 175.6287470005691, 179.40263852288444, 183.1972257474668, 187.01230114255733, 190.84766237911572, 194.70311212446845, 198.5784578470641, 202.4735116315852, 206.38809000372652, 210.32201376400522, 214.27510783001827, 218.24720108660674, 222.23812624343006, 226.2477196994887, 230.27582141416926, 234.32227478441771, 238.38692652767358, 242.46962657022632, 246.5702279406765, 250.6885866682098, 254.8245616854086, 258.9780147353478, 263.1488102827359, 267.33681542888047, 271.54189983027084, 275.7639356205826, 280.0027973359257, 284.25836184316347, 288.53050827114475, 292.81911794470057, 297.1240743212639, 301.44526292998245, 305.78257131320055, 310.1358889701928, 314.50510730304194, 318.890119564557, 323.2908208081348, 327.70710783947357, 332.13887917005195], [0.0, 0.6659825065299302, 1.697670162612885, 2.9347865192794136, 4.327567094882145, 5.848874833130308, 7.481126694121766, 9.211814324872385, 11.031493262438367, 12.932729958060984, 14.909491152852821, 16.956762859615903, 19.070299064629435, 21.24644861311176, 23.48203168931583, 25.774249090508246, 28.12061394568332, 30.518899248947577, 32.967096816593646, 35.463384675632476, 38.00610079358216, 40.5937216573503, 43.22484461531203, 45.89817317869649, 48.61250467796006, 51.366719813514614, 54.15977374526838, 56.990688443394795, 59.85854608133036, 62.76248329655506, 65.70168617896223, 68.6753858732259, 71.68285470242586, 74.7234027366785, 77.79637474366395, 80.90114746849432, 84.0371271989049, 87.20374757869985, 90.40046763807688, 93.62677001414738, 96.88215933885438, 100.16616077472867, 103.47831868163185, 106.81819539991439, 110.18537013733946, 113.57943794875614, 117.00000879889507, 120.44670669984674, 123.9191689158027, 127.41704522851529, 130.9399972576919, 134.48769783119326, 138.05983040047715, 141.65608849722747, 145.2761752275398, 148.91980280041935, 152.58669208767876, 156.27657221262004, 159.98918016514386, 163.72426044116088, 167.4815647043828, 171.26085146875366, 175.06188579994242, 178.88443903446344, 182.72828851511883, 186.59321734157433, 190.47901413498164, 194.38547281565562, 198.3123923928975, 202.25957676613044, 206.2268345365845, 210.21397882882655, 214.22082712148972, 218.24720108660674, 222.29292643699654, 226.3578327811986, 230.44175348548387, 234.5445255425097, 238.66598944621597, 242.80598907258934, 246.96437156594996, 251.14098723043767, 255.3356894264005, 259.54833447140425, 263.7787815456064, 268.0268926012501, 272.2925322760528, 276.5755678102803, 280.875868967305, 285.1933079574685, 289.5277593650717, 293.87910007833227, 298.2472092221578, 302.6319680935905, 307.03326009979173, 311.45097069843837, 315.88498734041417, 320.335199414684, 324.80149819524655, 329.2837767900664, 333.7819300918926, 338.2958547308753], [0.0, 0.6781608360850471, 1.7287142013278258, 2.9884527898725026, 4.406702113800223, 5.955828881541621, 7.617928525147792, 9.380263960634403, 11.233218021148659, 13.169221226123325, 15.182129990927738, 17.26683864128824, 19.419023519771343, 21.634966705628205, 23.911430236172908, 26.245563721721872, 28.634834815698554, 31.07697578859973, 33.569941734547776, 36.111877363481064, 38.701090250558885, 41.33602902333166, 44.015265380921626, 46.737479126626624, 49.50144559857455, 52.306025029373494, 55.150153472713676, 58.03283501426041, 60.95313504383463, 63.91017441124444, 66.903124323011, 69.93120186431962, 72.9936660517604, 76.08981433921223, 79.21897951260638, 82.38052692005375, 85.57385199251259, 88.79837801725012, 92.05355413214937, 95.33885351368923, 98.65377173538343, 101.9978252767611, 105.37055016572967, 108.77150073948124, 112.20024851106255, 115.65638113039019, 119.13950142990831, 122.64922654629457, 126.18518711065903, 129.74702650057196, 133.33440014803062, 136.94697489814072, 140.58442841387105, 144.24644862274604, 147.93273320178199, 151.64298909736303, 155.37693207709114, 159.13428631094638, 162.91478397935836, 166.7181649060233, 170.54417621351098, 174.39257199988847, 178.26311303475435, 182.15556647322296, 186.06970558652893, 190.00530950804193, 193.96216299358505, 197.94005619504637, 201.93878444635874, 205.95814806099926, 209.99795214023018, 214.05800639136547, 218.1381249554051, 222.23812624343006, 226.3578327811986, 230.49707106142748, 234.65567140327994, 238.8334678186186, 243.03029788461401, 247.24600262232843, 251.48042638092323, 255.73341672716083, 260.00482433989833, 264.2945029092871, 268.6023090404164, 272.92810216115197, 277.2717444339416, 281.6331006713717, 286.01203825527404, 290.4084270591951, 294.82213937405163, 299.25304983680724, 303.70103536201617, 308.1659750760873, 312.6477502541351, 317.14624425928554, 321.6613424843201, 326.19293229554125, 330.74090297875586, 335.3051456872729, 339.8855533918229, 344.4820208323079], [0.0, 0.6903961320555657, 1.759903454343068, 3.0423700944887586, 4.486207301577675, 6.063283227528487, 7.75537027233791, 9.549501551089358, 11.43588638516619, 13.40681872634619, 15.45604414818614, 17.578364860453238, 19.769379198808327, 22.025302164225053, 24.342837375085445, 26.719083015319214, 29.15146105005846, 31.637662835697913, 34.175606572414864, 36.76340349722827, 39.399330650772676, 42.08180867092397, 44.80938348757231, 47.58071108518594, 50.394544706691036, 53.24972402114995, 56.14516588666197, 59.07985642072616, 62.05284415103937, 65.06323406588805, 68.11018241880141, 71.19289216971015, 74.3106089664711, 77.46261758771082, 80.64823878156487, 83.86682644583134, 87.11776510390678, 90.40046763807688, 93.71437324763684, 97.05894560417914, 100.43367118041571, 103.83805773225772, 107.27163291668406, 110.73394303029224, 114.2245518554191, 117.74303960241079, 121.28900193806233, 124.86204909147752, 128.46180502965748, 132.08790669603363, 135.74000330594893, 139.4177556937687, 143.12083570689586, 146.84892564248088, 150.60171772306535, 154.37891360779537, 158.1802239361863, 162.0053679017263, 165.85407285287653, 169.72607391926383, 173.62111366107382, 177.5389417398406, 181.4793146089967, 185.4419952226972, 189.4267527615636, 193.43336237411654, 197.46160493276963, 201.51126680335662, 205.58213962724994, 209.67402011520647, 213.786709852149, 217.92001511215378, 222.0737466829751, 226.2477196994887, 230.44175348548387, 234.65567140327994, 238.889300710679, 243.14247242480567, 247.41502119241744, 251.70678516629775, 256.0176058873744, 260.34732817222755, 264.6958000056804, 269.0628724381796, 273.4483994877009, 277.8522380459244, 282.27424778844943, 286.71429108882745, 291.1722329362092, 295.64794085641535, 300.14128483625086, 304.65213725089455, 309.18037279420787, 313.725868411813, 318.2885032368042, 322.86815852795934, 327.46471761032996, 332.0780658180951, 336.7080904395696, 341.35468066426347, 346.01772753189806, 350.6971238832854], [0.0, 0.7026879060766946, 1.7912366767575416, 3.0965362810500223, 4.566079484810726, 6.171233582112576, 7.8934464497839425, 9.719520341216306, 11.639490265099942, 13.645512975162207, 15.731222691502206, 17.891329082721295, 20.121352117495253, 22.417439408887294, 24.77623588668597, 27.194788071050404, 29.67047202792446, 32.20093801074158, 34.78406715543176, 37.41793707158373, 40.10079412436013, 42.831030832762146, 45.60716723849723, 48.42783539725648, 51.29176635477303, 54.19777912164229, 57.144771271765876, 60.13171087153566, 63.15762950868898, 66.2216162367739, 69.32281228730479, 72.46040642975564, 75.63363088154004, 78.84175768752331, 82.08409550247892, 85.35998672103757, 88.66880490868488, 92.00995249469568, 95.38285869390086, 98.78697762913202, 102.22178663029005, 105.68678468939996, 109.18149105387197, 112.70544394259366, 116.25819937150706, 119.83933007704687, 123.44842452728237, 127.08508601185822, 130.74893180290508, 134.43959238001563, 138.1567107131824, 141.8999415982848, 145.66895104031533, 149.46341568006076, 153.28302226040998, 157.12746712886536, 160.99645577318432, 164.8897023873917, 168.80692946567595, 172.7478674219266, 176.71225423288527, 180.69983510307407, 184.7103621498361, 188.74359410697542, 192.79929604561838, 196.87723911104246, 200.97720027432595, 205.09896209777196, 209.24231251314754, 213.40704461185928, 217.59295644625908, 221.79985084133776, 226.02753521612536, 230.27582141416926, 234.5445255425097, 238.8334678186186, 243.14247242480567, 247.4713673696339, 251.8199843559209, 256.1881586549313, 260.57572898639654, 264.9825374040199, 269.4084291861549, 273.85325273135857, 278.31685945855094, 282.79910371151965, 287.2998426675362, 291.8189362498586, 296.3562470439118, 300.9116402169539, 305.484983441042, 310.0761468191298, 314.68500281413526, 319.31142618082737, 323.95529390039286, 328.6164851175473, 333.29488108006825, 337.99036508063085, 342.70282240083725, 347.43214025733386, 352.17820774991924, 356.9409158115494], [0.0, 0.7150356802733734, 1.8227126504097724, 3.1509492437032542, 4.6463155582580695, 6.279675748439784, 8.032151689411148, 9.890313721087377, 11.844021745313304, 13.885294692704337, 16.00765492258594, 18.205719140784712, 20.47492859195869, 22.81136319424764, 25.21160892146687, 27.672660394629588, 30.191847571379018, 32.766779414926056, 35.39529982809213, 38.07545263983235, 40.80545340008282, 43.58366638086308, 46.40858561775373, 49.27881912865143, 52.19307566096794, 55.15015347271368, 58.1489307657356, 61.18835747307921, 64.26744816534544, 67.38527588874683, 70.54096678434398, 73.7336953665038, 76.96268036100876, 80.22718102094915, 83.52649385264007, 86.85994969513752, 90.22691110609294, 93.62677001414738, 97.05894560417914, 100.52288240675564, 104.01804856731296, 107.54393427406248, 111.10005032653257, 114.68592682909959, 118.30111199592777, 121.94517105548988, 125.61768524433283, 129.31825088102653, 133.04647851233003, 136.80199212454855, 140.58442841387108, 144.39343611018023, 148.22867534944064, 152.08981709030544, 155.97654257104622, 159.88854280332205, 163.8255180996617, 167.78717763184943, 171.77323901768543, 175.78342793383746, 179.8174777527214, 183.8751292015416, 187.9561300417969, 192.060234767713, 196.1872043221984, 200.33680582904904, 204.50881234023393, 208.70300259719681, 212.91916080519886, 217.157076419807, 221.41654394470808, 225.69736274009375, 229.99933684092227, 234.32227478441771, 238.66598944621597, 243.03029788461401, 247.41502119241744, 251.8199843559209, 256.24501612058987, 260.6899488630422, 265.1546184689598, 269.63886421658174, 274.1425286654612, 278.66545755018427, 283.2074996787739, 287.7685068355174, 292.3483336879763, 296.94683769795176, 301.563879036192, 306.19932050064676, 310.8530274380799, 315.5248676688678, 320.214711414821, 324.92243122987395, 329.6479019335018, 334.39100054672684, 339.1516062305882, 343.92960022695644, 348.72486580157874, 353.53728818924964, 358.36675454100686, 363.21315387325825], [0.0, 0.727438986903045, 1.8543301829672674, 3.2056069212463405, 4.726912482519605, 6.388605618642951, 8.171480736965409, 10.061875220926652, 12.049473078006876, 14.126154795868867, 16.285330369985846, 18.521523125322243, 20.830095228467798, 23.20705859819012, 25.64893998718483, 28.152681883909864, 30.715567930342015, 33.33516561377247, 36.009281436463255, 38.73592529481206, 41.513281784941185, 44.339686804851546, 47.213608267037884, 50.133630043495714, 53.09843848303178, 56.10681099773956, 59.157606330288154, 62.249756198824485, 65.3822580802808, 68.5541689415433, 71.76459976535158, 75.01271074685503, 78.29770705952826, 81.61883510715722, 84.97537919296265, 88.36665854845621, 91.79202467394894, 95.2508589502229, 98.74257048709548, 102.26659417973002, 105.82238894779188, 109.4094361360849, 113.0272380582624, 116.67531666769555, 120.35321234168342, 124.06048276697081, 127.79670191605942, 131.56145910509298, 135.35435812521249, 139.17501644023304, 143.0230644443244, 146.89814477409158, 150.79991167007606, 154.7280303832428, 158.68217662248972, 162.66203603963552, 166.6673037487052, 170.6976838766558, 174.75288914296823, 178.83264046578356, 182.93666659248456, 187.0647037528217, 191.2164953328598, 195.39179156817912, 199.59034925490434, 203.8119314772638, 208.05630735049147, 212.32325177798805, 216.61254522174934, 220.92397348515084, 225.2573275072548, 229.6124031678712, 233.98900110266712, 238.38692652767358, 242.80598907258934, 247.24600262232843, 251.70678516629775, 256.1881586549313, 260.6899488630422, 265.21198525958334, 269.7541008834412, 274.31613222490824, 278.8979191125103, 283.4993046048812, 288.120134887405, 292.7602591733575, 297.41952960930325, 302.09780118451636, 306.7949316442088, 311.51078140636633, 316.2452134820017, 320.99809339864856, 325.7692891269309, 330.5586710100507, 335.3661116960496, 340.1914860727051, 345.0346712049338, 349.895546274578, 354.7739925224641, 359.6698931926215, 364.5831334785628, 369.5136004715284], [0.0, 0.7398973680149757, 1.886088107058077, 3.2605072956268146, 4.807867281822685, 6.498019170849886, 8.311428448186287, 10.234198506397883, 12.255836677575354, 14.368084391699725, 16.564238781462045, 18.838729376324924, 21.186838913678955, 23.60451101098154, 26.088212936848684, 28.634834815698554, 31.241613768185733, 33.90607562151592, 36.6259893113218, 39.39933065077268, 42.22425314473263, 45.099064191194614, 48.022205463573016, 50.992236580747004, 54.007821393461604, 57.06771637533113, 60.17076072344213, 63.31586786016316, 66.5020180928567, 69.72825223768545, 72.9936660517604, 76.29740534743175, 79.63866168568981, 83.01666856396137, 86.43069802818732, 89.88005765079392, 93.36408782565381, 96.8821593388544, 100.43367118041571, 104.01804856731296, 107.6347411524755, 111.2832213980322, 114.96298309408138, 118.67354000679615, 122.41442464181226, 126.185187110659, 129.98539408953826, 133.8146278610747, 137.6724854307942, 141.5585777110599, 145.47252876603957, 149.41397511200435, 153.38256506789526, 157.37795815164515, 161.39982451822613, 165.4478444358172, 169.52170779685673, 173.62111366107382, 177.74576982788022, 181.8953924357609, 186.06970558652895, 190.2684409925109, 194.49133764490927, 198.73814150174923, 203.0086051939586, 207.30248774826126, 211.61955432567578, 215.95957597451775, 220.32232939689635, 224.7075967277788, 229.1151653257747, 233.5448275748585, 237.99638069631206, 242.46962657022632, 246.96437156594996, 251.48042638092323, 256.0176058873744, 260.57572898639654, 265.1546184689598, 269.7541008834412, 274.3740064092912, 279.01416873647645, 283.6744249503686, 288.3546154217672, 293.0545837017722, 297.7741764212317, 302.5132431945193, 307.2716365274035, 312.0492117287896, 316.8458268261317, 321.6613424843201, 326.4956219278646, 331.34853086620683, 336.2199374219999, 341.10971206221, 346.01772753189806, 350.94385879055005, 355.8879829508334, 360.84997921966215, 365.829728841461, 370.8271150435256, 375.84202298338033], [0.0, 0.7524103751251506, 1.9179852794420666, 3.315648390509219, 4.889177041909583, 6.6079124663282, 8.451989785155064, 10.407277374107688, 12.463105115222422, 14.611074771075275, 16.844370116708088, 19.15732647481851, 21.54514680532647, 24.00370612489987, 26.529411957256517, 29.119101833175314, 31.769966148007594, 34.47948888620747, 37.2454012520607, 40.06564482606418, 42.93834188549859, 45.861771203385565, 48.83434809900918, 51.85460783179015, 54.921191655765014, 58.0328350142604, 61.18835747307919, 64.38665407859051, 67.62668789330401, 70.90748351184314, 74.22812139893082, 77.58773292105407, 80.98549596703256, 84.42063107134368, 87.89239796890423, 91.4000925219337, 94.94304396916823, 98.52061245554617, 102.13218680691821, 105.7771825196356, 109.45503993926006, 113.16522260629782, 116.90721574991917, 120.6805249132009, 124.48467469560073, 128.31920760021757, 132.18368297496156, 136.07767603809853, 140.00077697978656, 143.95259013221084, 147.93273320178196, 151.9408365576017, 155.97654257104617, 160.03950500187867, 164.12938842679333, 168.24586770672383, 172.38862748962703, 176.55736174578593, 180.75177333297006, 184.97157358905113, 189.21648194990323, 193.48622559062153, 197.7805390882761, 202.09916410458132, 206.4418490870052, 210.80834898697623, 215.1984249939596, 219.61184428428257, 224.04837978368167, 228.50780994263116, 232.98991852358884, 237.49449439936544, 242.02133136188672, 246.5702279406765, 251.14098723043767, 255.73341672716083, 260.34732817222755, 264.9825374040199, 269.63886421658174, 274.31613222490824, 279.01416873647645, 283.73280462864847, 288.4718742316138, 293.2312152165529, 298.0106684887306, 302.8100780852445, 307.62929107717434, 312.4681574758935, 317.32653014331834, 322.2042647058896, 327.1012194720879, 332.01725535330155, 336.952235787875, 341.9060266681761, 346.8784962705324, 351.869515187893, 356.8789562650818, 361.9066945365184, 366.9526071662866, 372.0165733904389, 377.09847446143255, 382.1981935945972], [0.0, 0.7649775689058564, 1.950020580219625, 3.3710282699071925, 4.9708389080203945, 6.7182816467591255, 8.593159812807757, 10.581105747311888, 12.67127111381894, 14.855117402680326, 17.125714540401596, 19.47730323495987, 21.905006323333858, 24.404629924331207, 26.972521558050584, 29.605465933878676, 32.30060651952303, 35.05538527548917, 37.86749551132306, 40.734844426607076, 43.655522935809735, 46.627781063022965, 49.6500076592759, 52.72071351904389, 55.838517201801615, 59.00213302951788, 62.210360851700045, 65.46207725914186, 68.75622799482255, 72.09182136158014, 75.46792246552691, 78.8836481647299, 82.33816261663183, 85.83067333662555, 89.36042769529179, 92.92670979393307, 96.52883766784251, 100.16616077472868, 103.83805773225772, 107.54393427406248, 111.2832213980322, 115.05537368441594, 118.85986776438354, 122.69620092230595, 126.56388981722573, 130.4624693108636, 134.3914913911034, 138.35052418126037, 142.33915102661138, 146.3569696506686, 150.40359137455374, 154.47864039357927, 158.58175310580097, 162.71257748787718, 166.87077251406774, 171.05600761464535, 175.2679621703745, 179.5063250400526, 183.77079411840757, 188.06107592190912, 192.37688520028684, 196.71794457175633, 201.08398418014022, 205.47474137223728, 209.8899603939394, 214.32939210373195, 218.79279370232828, 223.27992847729985, 227.7905655616574, 232.3244797054266, 236.88145105934075, 241.46126496984186, 246.06371178464917, 250.6885866682098, 255.3356894264005, 260.00482433989833, 264.6958000056804, 269.4084291861549, 274.1425286654612, 278.8979191125103, 283.6744249503686, 288.4718742316138, 293.29009851932267, 298.12893277336536, 302.98821524171444, 307.8677873564849, 312.767493634449, 317.6871815817832, 322.62670160281846, 327.5859069125847, 332.5646534529487, 337.5627998121602, 342.58020714763194, 347.6167391117883, 352.672261780832, 357.7466435862803, 362.83975524913797, 367.95146971657704, 373.0816621010048, 378.2302096214042, 383.39699154684234, 388.5818891420438], [0.0, 0.7775985188891104, 1.9821929120756674, 3.426645036876564, 5.052850082965915, 6.829122931632924, 8.73493369560366, 10.755677671813348, 12.880327542990445, 15.100203927246993, 17.408262415564838, 19.79864869648588, 22.266405141321528, 24.807268676308407, 27.417526561260406, 30.093910458228372, 32.83351670654295, 35.63374506300353, 38.49225078032143, 41.40690653010008, 44.37577172984131, 47.397067531733725, 50.469156205333476, 53.590523975521734, 56.75976661013522, 59.97557721943827, 63.23673585230625, 66.54210056501374, 69.8905997069252, 73.2812252194051, 76.71302678425853, 80.18510668907282, 83.69661530117772, 87.24674706119234, 90.83473692247287, 94.45985717509755, 98.12141460299368, 101.81874793092541, 105.55122552470883, 109.31824331349829, 113.11922290752584, 116.95360988845593, 120.82087225267995, 124.72049899053633, 128.65199878668736, 132.61489882878956, 136.60874371321788, 140.63309443798843, 144.68752747421775, 148.77163390847642, 152.8850186492842, 157.02729969175587, 161.19810743507588, 165.39708404806044, 169.6238828785707, 173.8781679029887, 178.15961321235605, 182.46790253212023, 186.80272877273822, 191.16379360865403, 195.55080708340782, 199.9634872388436, 204.40155976657326, 208.86475768002288, 213.35282100553604, 217.8654964911474, 222.4025373317566, 226.96370290954508, 231.54875854857437, 236.15747528259303, 240.78962963516048, 245.4450034112662, 250.12338349969008, 254.8245616854086, 259.54833447140425, 264.2945029092871, 269.0628724381796, 273.85325273135857, 278.66545755018427, 283.4993046048812, 288.3546154217672, 293.2312152165529, 298.12893277336536, 303.0476003291673, 307.9870534632724, 312.9471309916699, 317.9276748658988, 322.92853007622256, 327.9495445588744, 332.99056910715865, 338.0514572862051, 343.1320653511877, 348.2322521688306, 353.35187914203357, 358.4908101374632, 363.64891141595973, 368.82605156562386, 374.02210143745197, 379.23693408339864, 384.47042469674955, 389.72245055469756, 394.9928909630182], [0.0, 0.7902728031831627, 2.0145011995569675, 3.48249683226607, 5.1352078252854705, 6.940432615759125, 8.87730669434077, 10.930987312040678, 13.090267414421264, 15.346326152049466, 17.692004297218038, 20.12135211749525, 22.629331178488922, 25.211608921466862, 27.864412091306928, 30.58441907855374, 33.36867889500333, 36.2145489154022, 39.11964617480433, 42.08180867092397, 45.09906419119461, 48.16960489389306, 51.291766354773024, 54.46401012529391, 57.68490908534036, 60.953135043834614, 64.26744816534543, 67.62668789330401, 71.02976510995718, 74.47565532605462, 77.96339273391334, 81.49206498906821, 85.06080861046094, 88.66880490868488, 92.31527636739825, 95.99948341554246, 99.72072153813237, 103.47831868163185, 107.27163291668404, 111.10005032653255, 114.96298309408135, 118.85986776438352, 122.79016366256268, 126.75335144987538, 130.74893180290505, 134.77642420281458, 138.8353658232345, 142.92531050677132, 147.04582782133204, 151.19650218849898, 155.3769320770911, 159.5867292558244, 163.82551809966168, 168.09293494503385, 172.38862748962703, 176.7122542328853, 181.06348395377373, 185.44199522269716, 189.84747594477867, 194.279622931975, 198.73814150174917, 203.22274510023448, 207.73315494801773, 212.26909970684005, 216.83031516566558, 221.41654394470802, 226.02753521612536, 230.6630444402054, 235.3228331159644, 240.0066685451693, 244.71432360887783, 249.44557655566115, 254.20021080074292, 258.9780147353478, 263.7787815456064, 268.6023090404164, 273.4483994877009, 278.31685945855094, 283.2074996787739, 288.120134887405, 293.0545837017722, 298.0106684887306, 302.98821524171444, 307.9870534632724, 313.0070160527815, 318.0479391990504, 323.10966227754415, 328.1920277519816, 333.29488108006825, 338.41807062314894, 343.56144755957274, 348.72486580157863, 353.90818191552205, 359.11125504527195, 364.3339468386216, 369.57612137656133, 374.83764510527436, 380.1183867707233, 385.4182173557029, 390.73701001924115, 396.0746400382393, 401.43098475124583], [0.0, 0.8030000082013438, 2.046944388380955, 3.538581833522457, 5.217909447484947, 7.052207066885166, 9.020274163109855, 11.107028947297652, 13.301083877363036, 15.593476045638472, 17.976930926308984, 20.445402967544577, 22.99377259185006, 25.61763746539404, 28.3131635654418, 31.076975788599725, 33.90607562151591, 36.79777787992022, 39.74966122163372, 42.7595288257027, 45.82537671742285, 48.94536794009681, 52.11781126421745, 55.34114346480001, 58.61391443820975, 61.93477460308433, 65.30246415666012, 68.71580385180819, 72.17368703072476, 75.67507270493965, 79.21897951260638, 82.80448041611209, 86.43069802818732, 90.09680047457601, 93.80199771717194, 97.5455382742542, 101.32670628474725, 105.14481887181054, 108.99922376792742, 112.88929716931968, 116.81444179219996, 120.77408510727818, 124.7676777322038, 128.7946919643739, 132.85462043885582, 136.94697489814072, 141.07128506212158, 145.22709758811826, 149.41397511200435, 153.63149536254454, 157.87925034196854, 162.15684556659545, 166.46389936201274, 170.80004220791324, 175.16491612821605, 179.5581741225586, 183.97947963564928, 188.4285060613256, 192.90493627847732, 197.40846221627092, 201.93878444635874, 206.49561179997428, 211.07866100801078, 215.68765636235423, 220.32232939689632, 224.9824185867944, 229.66766906466805, 234.3778323525358, 239.11266610839738, 243.8719338864555, 248.65540491005706, 253.46285385650538, 258.29406065296416, 263.1488102827359, 268.0268926012501, 272.92810216115197, 277.8522380459244, 282.79910371151965, 287.7685068355174, 292.7602591733575, 297.7741764212317, 302.8100780852445, 307.8677873564849, 312.9471309916699, 318.0479391990504, 323.1700455292844, 328.3132867710071, 333.477502850843, 338.6625367376211, 343.86823435057227, 349.094444471299, 354.34101865932246, 359.6078111710243, 364.89467888181025, 370.2014812113355, 375.52808005163854, 380.8743396980418, 386.2401267826846, 391.62531021056225, 397.029761097951, 402.45335271310853, 407.89596041914217], [0.0, 0.8157797284025792, 2.0795214447742576, 3.594898253547017, 5.300952314350672, 7.164442723417526, 9.163831546379612, 11.283796968174055, 13.512770214336575, 15.84164573280236, 18.263033223903932, 20.770790921041602, 23.359717768803286, 26.02534137035133, 28.763766684598227, 31.57156489348463, 34.44568976241173, 37.383413372485094, 40.382275845940185, 43.440045399486, 46.554686165223046, 49.724331951345135, 52.94726461248005, 56.221896044965916, 59.546753066813665, 62.92046461811548, 66.34175084638588, 69.80941373681443, 73.32232901917283, 76.87943913769165, 80.47974711218113, 84.12231115125357, 87.80623990404837, 91.53068825705648, 95.29485359873978, 99.09797248756905, 102.93931766956202, 106.81819539991439, 110.73394303029222, 114.68592682909957, 118.67354000679613, 122.69620092230593, 126.75335144987538, 130.84445548853105, 134.96899759864309, 139.12648175209958, 143.3164301843002, 147.53838233763014, 151.79189388732647, 156.07653584172027, 160.39189370976942, 164.73756672959752, 169.11316715245556, 173.5183195771322, 177.95266033036827, 182.41583688930126, 186.9075073423725, 191.4273398854926, 195.97501235057862, 200.55021176385938, 205.15263393159432, 209.78198305107512, 214.43797134497586, 219.12031871729653, 223.82875242929904, 228.56300679398103, 233.3228228877555, 238.10794827812174, 242.91813676621405, 247.7531481432076, 252.61274795964601, 257.49670730682885, 262.40480260946754, 267.33681542888047, 272.2925322760528, 277.2717444339416, 282.27424778844943, 287.2998426675362, 292.3483336879763, 297.41952960930325, 302.5132431945193, 307.62929107717434, 312.767493634449, 317.9276748658988, 323.10966227754415, 328.3132867710071, 333.53838253741884, 338.7847869558413, 344.0523404959571, 349.3408866248065, 354.6502717173559, 359.98034497070086, 365.33095832171784, 370.70196636798914, 376.0932262918381, 381.50459778731926, 386.9359429900194, 392.3871264095324, 397.85801486448065, 403.34847741996, 408.85838532729633, 414.38761196600467], [0.0, 0.8286115660429461, 2.112231354839387, 3.6514443396007628, 5.3843338413350095, 7.277136092239794, 9.307974376205834, 11.461285873109212, 13.725319837016563, 16.090827489742534, 18.550302285625595, 21.097505850919443, 23.727155320017054, 26.43470794734804, 29.21620742463095, 32.06817100008499, 34.98750452325069, 37.97143716633171, 41.017470358824546, 44.12333721251975, 47.2869698362578, 50.50647268389898, 53.78010058443939, 57.10624045408142, 60.483395938365014, 63.910174411244434, 67.38527588874682, 70.90748351184314, 74.47565532605462, 78.08871714074898, 81.7456562936994, 85.4455161795754, 89.18739142697986, 92.97042362915926, 96.79379754986738, 100.65673773899303, 104.55850550318532, 108.49839618535518, 112.47573671401702, 116.48988338927015, 120.54021987705555, 124.62615538735228, 128.74712301534694, 132.90257822744582, 137.09199747639218, 141.31487693178147, 145.5707313139973, 149.85909282106664, 154.17951013920367, 158.53154752889907, 162.91478397935833, 167.32881242490623, 171.7732390176854, 176.2476824515971, 180.7517733329701, 185.28515359392037, 189.84747594477867, 194.43840336233075, 199.05760861093893, 203.70477379389928, 208.3795899326446, 213.0817565716267, 217.8109814069156, 222.5669799367308, 227.34947513228005, 232.15819712742737, 236.9928829258376, 241.85327612436353, 246.73912665154526, 251.6501905201843, 256.58622959304284, 261.54701136079245, 266.5323087314088, 271.54189983027084, 276.5755678102803, 281.6331006713717, 286.71429108882745, 291.8189362498586, 296.94683769795176, 302.09780118451636, 307.2716365274035, 312.4681574758935, 317.6871815817832, 322.92853007622256, 328.1920277519816, 333.477502850843, 338.7847869558413, 344.1137148880862, 349.46412460792226, 354.83585712019885, 360.2287563834315, 365.64266922265597, 371.07744524578436, 376.53293676328605, 382.0089987110285, 387.5054885761187, 393.02226632559996, 398.55919433786477, 404.11613733665405, 409.6929623275182, 415.28953853662614, 420.90573735181107], [0.0, 0.8414951309376689, 2.14507312394804, 3.70821837225562, 5.468051493009807, 7.390283746622453, 9.452698269557873, 11.639490265099944, 13.938726282289215, 16.341013739451657, 18.838729376324924, 21.42553782257675, 24.096074072614776, 26.845724748548538, 29.670472027924465, 32.566779007824586, 35.53150342877206, 38.56183138109575, 41.65522544557637, 44.80938348757231, 48.022205463573016, 51.291766354773024, 54.616293855592005, 57.99414980139757, 61.4238145718466, 64.90387388781878, 68.43300755270053, 72.00997978728009, 75.63363088154006, 79.30286994292742, 83.01666856396137, 86.77405526565134, 90.57411059954447, 94.41596281205557, 98.298783991338, 102.22178663029007, 106.18422055007822, 110.18537013733948, 114.22455185541911, 118.30111199592777, 122.41442464181225, 126.56388981722573, 130.74893180290508, 134.9689975986431, 139.22355551687303, 143.5120938934453, 147.8341199034331, 152.18915847130214, 156.5767512660697, 160.99645577318435, 165.44784443581716, 169.93050385908234, 174.4440340714276, 178.9880478380633, 183.5621700218462, 188.16603698751788, 192.79929604561843, 197.46160493276966, 202.15263132535085, 206.8720523838804, 211.61955432567578, 216.3948320235928, 221.19758862884981, 226.02753521612541, 230.88439044927924, 235.767880266195, 240.67773758137136, 245.61370200500838, 250.57551957744084, 255.56294251786534, 260.57572898639654, 265.6136428585634, 270.6764535114292, 275.7639356205826, 280.875868967305, 286.01203825527404, 291.1722329362092, 296.3562470439118, 301.563879036192, 306.7949316442088, 312.0492117287896, 317.32653014331834, 322.62670160281846, 327.9495445588744, 333.29488108006825, 338.6625367376211, 344.0523404959571, 349.46412460792226, 354.8977245144077, 360.352978748146, 365.829728841461, 371.32781923776645, 376.84709720662147, 382.3874127621631, 387.9486185847469, 393.53056994563576, 399.1331246345877, 404.75614289020274, 410.39948733289543, 416.06302290036837, 421.7466167854697, 427.45013837632223], [0.0, 0.854430040233013, 2.1780457761596232, 3.765218664389227, 5.552102781584158, 7.5038823242195685, 9.597998925756256, 11.81840484854542, 14.152983208473847, 16.592197047284053, 19.128305924974434, 21.754877088069804, 24.466463063642998, 27.25837955999506, 30.126546995350125, 33.0673740998465, 36.07767031326283, 39.15457847236059, 42.29552215438235, 45.49816383778799, 48.76037119858035, 52.080189627831885, 55.4558195772474, 58.88559770140597, 62.367981021360755, 65.90153351862367, 69.48491470338772, 73.11686980085643, 76.79622127471337, 80.52186146392317, 84.29274615300214, 88.10788893002405, 91.96635621337958, 95.86726284946123, 99.80976820030637, 103.79307265377243, 107.81641449977063, 111.87906712500033, 115.98033648593126, 120.11955882579899, 124.2960986063653, 128.50934662934958, 132.7587183259111, 137.04365219548745, 141.36360837776053, 145.71806734361624, 150.1065286927474, 154.5285100470712, 158.98354603044282, 163.47118732626836, 167.99099980559674, 172.54256371910805, 177.12547294715054, 181.7393343026163, 186.3837668820008, 191.0584014604838, 195.7628799272951, 200.49685475800916, 205.25998852074528, 210.05195341354585, 214.87243083046747, 219.72111095415232, 224.59769237285465, 229.5018817200832, 234.4333933351836, 239.3919489433371, 244.3772773535798, 249.38911417357124, 254.4272015399453, 259.4912878631751, 264.5811275859719, 269.6964809543146, 274.8371138002825, 280.0027973359257, 285.1933079574685, 290.4084270591951, 295.64794085641535, 300.9116402169539, 306.19932050064676, 311.51078140636633, 316.8458268261317, 322.2042647058896, 327.5859069125847, 332.99056910715865, 338.41807062314894, 343.86823435057227, 349.3408866248065, 354.83585712019885, 360.352978748146, 365.89208755941206, 371.45302265046007, 377.0356260735902, 382.63974275068995, 388.2652203904122, 393.911909408612, 399.57966285187734, 405.268336324004, 410.97778791527173, 416.7078781343865, 422.45846984296224, 428.2294281924229, 434.0206205632115], [0.0, 0.8674159181875502, 2.211148353663676, 3.822443560221038, 5.636485265483057, 7.617928525147792, 9.7438721240156, 11.99802442622163, 14.368084391699725, 16.844370116708088, 19.419023519771343, 22.085514080543277, 24.838311533807993, 27.672660394629588, 30.584419078553747, 33.569941734547776, 36.6259893113218, 39.74966122163373, 42.938341885498595, 46.18965825503943, 49.50144559857454, 52.871719600457546, 56.29865336233128, 59.78055825876406, 63.31586786016316, 66.903124323011, 70.54096678434398, 74.22812139893084, 77.96339273391335, 81.7456562936994, 85.5738519925126, 89.44697842664941, 93.36408782565383, 97.32428158309462, 101.32670628474726, 105.37055016572967, 109.45503993926008, 113.57943794875615, 117.74303960241079, 121.94517105548988, 126.185187110659, 130.4624693108636, 134.7764242028146, 139.1264817520996, 143.5120938934453, 147.93273320178199, 152.38789167157205, 156.87707959340935, 161.39982451822615, 165.95567030058336, 170.544176213511, 175.16491612821605, 179.8174777527214, 184.50146192414633, 189.21648194990328, 193.96216299358508, 198.7381415017492, 203.54406466819214, 208.37958993264462, 213.24438451111888, 218.13812495540512, 223.0604967394506, 228.01119387056556, 232.9899185235889, 237.99638069631206, 243.030297884614, 248.09139477589122, 253.17940295949097, 258.2940606529642, 263.43511244305284, 268.6023090404164, 273.7954070471821, 279.01416873647645, 284.25836184316347, 289.5277593650717, 294.82213937405163, 300.14128483625086, 305.484983441042, 310.8530274380799, 316.2452134820017, 321.6613424843201, 327.1012194720879, 332.5646534529487, 338.0514572862051, 343.56144755957274, 349.094444471299, 354.6502717173559, 360.2287563834315, 365.829728841461, 371.45302265046007, 377.0984744614326, 382.7659239261434, 388.4552136095573, 394.1661889057588, 399.89869795717937, 405.6525915769658, 411.42772317433827, 417.223948682791, 423.0411264910004, 428.87911737631106, 434.73778444067875, 440.6169930489557], [0.0, 0.8804523959623135, 2.2443799162449474, 3.879891434387597, 5.721196547983827, 7.732419110143433, 9.890313721087375, 12.178343896378836, 14.584023722430128, 17.097525785231195, 19.710873903439733, 22.41743940888729, 25.211608921466862, 28.08855548559927, 31.044075272556636, 34.0744676374583, 37.17644484899909, 40.34706272673057, 43.583666380863065, 46.883847098753435, 50.245407614758044, 53.66633379075864, 57.14477127176587, 60.67900605383302, 64.26744816534543, 67.90861785271423, 71.60113380043462, 75.34370301853211, 79.13511210787237, 82.9742196727102, 86.8599496951375, 90.79128572125755, 94.76726573648047, 98.78697762913201, 102.84955515894265, 106.95417436093739, 111.10005032653254, 115.28643431283362, 119.51261113865509, 123.77789683198512, 128.0816364987561, 132.42320238706256, 136.80199212454852, 141.21742710969923, 145.66895104031533, 150.15602856460472, 154.67814404216543, 159.23480040370129, 163.82551809966168, 168.4498341291537, 173.10730114147898, 177.79748660351373, 182.51997202690475, 187.2743522497138, 192.06023476771296, 196.87723911104246, 201.72499626237988, 206.60314811316314, 211.51134695475156, 216.4492550017146, 221.41654394470802, 226.41289453063658, 231.4379961680168, 236.4915465556444, 241.57325133283953, 246.68282374969945, 251.81998435592084, 256.9844607068813, 262.17598708577805, 267.39430424072236, 272.63915913578023, 277.9103047150286, 283.20749967877384, 288.53050827114475, 293.87910007833227, 299.25304983680724, 304.65213725089455, 310.0761468191298, 315.5248676688678, 320.99809339864856, 326.4956219278646, 332.01725535330155, 337.5627998121602, 343.1320653511877, 348.72486580157863, 354.34101865932246, 359.98034497070086, 365.64266922265597, 371.32781923776645, 377.0356260735902, 382.7659239261434, 388.5185500373015, 394.2933446059232, 400.0901507025056, 405.90881418719806, 411.74918363100375, 417.6111102400159, 423.49444778253905, 429.3990525189596, 435.32478313423127, 441.2715006728558, 447.23906847624085], [0.0, 0.8935391114193875, 2.277739540769981, 3.937560691054987, 5.806234275907351, 7.847350898793617, 10.037319648997423, 12.359358249955681, 14.800795202126151, 17.35165702048867, 20.003848968721538, 22.750643852609265, 25.586344856860226, 28.506053279830958, 31.50550280865403, 34.580937793445905, 37.729021635291666, 40.9467663925447, 44.23147771412544, 47.58071108518594, 50.992236580747004, 54.46401012529391, 57.99414980139757, 61.58091612879699, 65.2226955031335, 68.91798617631373, 72.66538630147532, 76.46358367012388, 80.31134684761372, 84.2075174729197, 88.1510035346056, 92.14077347058371, 96.17585096723873, 100.25531035560927, 104.3782725199541, 108.54390124819066, 112.75139996514737, 117.00000879889508, 121.28900193806233, 125.61768524433283, 129.98539408953826, 134.39149139110336, 138.83536582323453, 143.31643018430023, 147.8341199034331, 152.38789167157202, 156.97722218402873, 161.60160698325473, 166.26055939185412, 170.95360952706164, 175.68030338892532, 180.4402020153106, 185.2328806976098, 190.05792825170894, 194.914946339344, 199.80354883549325, 204.72336123789876, 209.67402011520653, 214.65517259056455, 219.66647585782587, 224.7075967277788, 229.7782112020694, 234.8780040726984, 240.00666854516936, 245.16390588353534, 250.34942507575005, 255.56294251786537, 260.80418171574377, 266.07287300306723, 271.36875327452384, 276.6915657331479, 282.0410596508695, 287.41699014140653, 292.81911794470057, 298.2472092221578, 303.70103536201617, 309.18037279420787, 314.68500281413526, 320.214711414821, 325.7692891269309, 331.34853086620683, 336.952235787875, 342.58020714763194, 348.2322521688306, 353.90818191552205, 359.6078111710243, 365.33095832171784, 371.07744524578436, 376.84709720662147, 382.63974275068995, 388.4552136095573, 394.2933446059232, 400.15397356342174, 406.03694122000866, 411.94209114475603, 417.86926965788314, 423.818325753866, 429.78911102747617, 435.78147960260776, 441.79528806376067, 447.830395390054, 453.88666289165303], [0.0, 0.9066757089285024, 2.3112263206940975, 3.995449763066546, 5.891596138361319, 7.962720767837724, 10.184885912873389, 12.541062567904023, 15.01839294004309, 17.60675691648794, 20.297940754046735, 23.085118356909586, 25.962509156574047, 28.925142431861104, 31.96868914759574, 35.089338439231426, 38.283704653977, 41.54875592218505, 44.88175828107326, 48.280231277123235, 51.74191220153405, 55.26472692728349, 58.8467658694442, 62.486263974333966, 66.18158391477021, 69.93120186431963, 73.73369536650381, 77.58773292105408, 81.49206498906824, 85.44551617957542, 89.44697842664941, 93.49540500242436, 97.58980523975656, 101.72923986072176, 105.91281682503016, 110.1396876268099, 114.40904397983245, 118.72011484071398, 123.0721637273785, 127.46448629645482, 131.89640814857086, 136.36728283491627, 140.87649004213233, 145.4234339356902, 150.00754164453707, 154.62826187201247, 159.28506361992822, 163.97743501432205, 168.70488222278385, 173.4669284544447, 178.26311303475438, 183.09299054806235, 187.95613004179694, 192.85211428671406, 197.78053908827616, 202.74101264474416, 207.73315494801778, 212.75659722366254, 217.81098140691566, 222.89595965177648, 228.0111938705656, 233.15635530158295, 238.33112410271698, 243.5351889690522, 248.7682467726975, 254.03000222321734, 259.3201675471865, 264.6384621855169, 269.9846125073211, 275.3583515391761, 280.7594187087488, 286.18755960182546, 291.6425257318646, 297.1240743212639, 302.6319680935905, 308.1659750760873, 313.725868411813, 319.31142618082737, 324.92243122987395, 330.5586710100507, 336.2199374219999, 341.9060266681761, 347.6167391117883, 353.35187914203357, 359.11125504527195, 364.89467888181025, 370.70196636798914, 376.53293676328605, 382.3874127621631, 388.2652203904122, 394.1661889057588, 400.0901507025056, 406.03694122000866, 412.0063988547913, 417.99836487611583, 424.0126833448381, 430.0492010353872, 436.1077673607167, 442.18823430008524, 448.2904563295324, 454.4142903549222, 460.55959564743523], [0.0, 0.9198618391812381, 2.344839365587778, 4.053557111124122, 5.977279865532919, 8.078525649535676, 10.333008588857632, 12.72345201861901, 15.236811150152864, 17.862818690000584, 20.593141439373884, 23.420854027950966, 26.34009181821942, 29.34581179790842, 32.43362197303516, 35.59965605619817, 38.84047915576793, 42.15301530846167, 45.53449079043477, 48.982389073988344, 52.494414542885345, 56.068462905284086, 59.702596804436105, 63.39502551681108, 67.14408790295342, 70.94823797484146, 74.80603258867033, 78.71612087965569, 82.677235136375, 86.68818287369876, 90.74783991067584, 94.85514429647824, 99.00909095631259, 103.20872695197795, 107.45314726990273, 111.74149106407091, 116.07293829303941, 120.44670669984676, 124.86204909147752, 129.31825088102653, 133.81462786107468, 138.35052418126037, 142.92531050677132, 147.53838233763017, 152.1891584713021, 156.87707959340935, 161.60160698325473, 166.36222132249796, 171.15842159673602, 175.98972408094878, 180.85566140082048, 185.75578166285115, 190.68964764696165, 195.65683605598406, 200.65693681702567, 205.68955243022543, 210.7542973608805, 215.85079747132932, 220.97868948933686, 226.1376205100455, 231.32724752883794, 236.5472370027075, 241.7972644379569, 247.0770140022447, 252.38617815917533, 257.724457323792, 263.0915595374709, 268.4872001608464, 273.91110158351256, 279.3629929493503, 284.84260989642394, 290.34969431047665, 295.88399409113265, 301.44526292998245, 307.03326009979173, 312.6477502541351, 318.2885032368042, 323.95529390039286, 329.6479019335018, 335.3661116960496, 341.10971206221, 346.8784962705324, 352.672261780832, 358.4908101374632, 364.3339468386216, 370.2014812113355, 376.0932262918381, 382.0089987110285, 387.9486185847469, 393.911909408612, 399.89869795717937, 405.90881418719806, 411.94209114475603, 417.99836487611583, 424.0774743420579, 430.17926133555596, 436.3035704026212, 442.45024876616225, 448.6191462527159, 454.81011522191113, 461.0230104985397, 467.25768930710916], [0.0, 0.9330971590124537, 2.3785778006814686, 4.111881223001162, 6.063283227528488, 8.194762530099668, 10.48168382210131, 12.906521855469117, 15.45604414818614, 18.119835677094656, 20.889443342192436, 23.75784212831184, 26.719083015319217, 29.768050430177038, 32.90028918523297, 36.111877363481064, 39.399330650772676, 42.7595288257027, 46.189658255039426, 49.68716620233223, 53.24972402114995, 56.875197142304515, 60.56162033362627, 64.30717710597789, 68.11018241880141, 71.96906803981518, 75.88237006071576, 79.8487181799657, 83.86682644583136, 87.93548521525645, 92.05355413214937, 96.21995596593227, 100.43367118041571, 104.69373312616374, 108.99922376792742, 113.34926987351287, 117.74303960241078, 122.1797394422508, 126.65861144912202, 131.17893075437274, 135.74000330594893, 140.34116381686604, 144.9817738972047, 149.6612203492133, 154.37891360779537, 159.13428631094638, 163.92679198665215, 168.75590384442384, 173.62111366107385, 178.5219307515636, 183.45788101681902, 188.4285060613256, 193.43336237411657, 198.47202056746423, 203.54406466819214, 208.64909145706102, 213.786709852149, 218.95654033256037, 224.15821439916192, 229.3913740693676, 234.65567140327994, 239.95076805874945, 245.27633487314085, 250.63205146979763, 256.0176058873743, 261.43269423037253, 266.8770203393574, 272.3502954794644, 277.8522380459244, 283.38257328543796, 288.9410330323298, 294.52735545849794, 300.14128483625086, 305.78257131320055, 311.45097069843837, 317.14624425928554, 322.86815852795934, 328.6164851175473, 334.39100054672684, 340.1914860727051, 346.01772753189806, 351.869515187893, 357.7466435862803, 363.64891141595973, 369.57612137656133, 375.52808005163854, 381.50459778731926, 387.5054885761187, 393.53056994563576, 399.57966285187734, 405.6525915769658, 411.74918363100375, 417.86926965788314, 424.0126833448381, 430.17926133555596, 436.36884314666787, 442.5812710874544, 448.81639018260955, 455.07404809791757, 461.35409506870207, 467.6563838309188, 473.98076955476785], [0.0, 0.9463813312285921, 2.4124407664279057, 4.170420612786105, 6.149604033257828, 8.311428448186286, 10.63090782483568, 13.090267414421268, 15.67608634878832, 18.377801329800544, 21.18683891367895, 24.096074072614773, 27.099473092391637, 30.191847571379018, 33.368678895003335, 36.6259893113218, 39.96024490124513, 43.368281021886375, 46.847243983318705, 50.394544706691036, 54.0078213934616, 57.68490908534036, 61.42381457184659, 65.2226955031335, 69.0798428493203, 72.9936660517604, 76.96268036100876, 80.98549596703259, 85.06080861046097, 89.18739142697987, 93.36408782565383, 97.58980523975656, 101.86350961832468, 106.18422055007824, 110.55100693002709, 114.96298309408137, 119.41930535911443, 123.9191689158027, 128.46180502965746, 133.04647851233, 137.67248543079418, 142.33915102661135, 147.04582782133204, 151.79189388732647, 156.57675126606966, 161.39982451822613, 166.2605593918541, 171.158421596736, 176.0928956742915, 181.06348395377378, 186.06970558652895, 191.1110956510287, 196.1872043221984, 201.29759609927012, 206.44184908700527, 211.61955432567578, 216.83031516566564, 222.07374668297516, 227.3494751322801, 232.65713743452372, 237.99638069631206, 243.36686175863883, 248.76824677269747, 254.20021080074298, 259.66243744014724, 265.15461846895977, 270.6764535114292, 276.2276497220756, 281.8079214870229, 287.41699014140653, 293.0545837017722, 298.72043661246414, 304.41428950508686, 310.1358889701928, 315.88498734041417, 321.6613424843201, 327.46471761032996, 333.29488108006825, 339.1516062305882, 345.0346712049338, 350.94385879055005, 356.8789562650818, 362.83975524913797, 368.82605156562386, 374.83764510527436, 380.8743396980418, 386.9359429900194, 393.02226632559996, 399.1331246345877, 405.268336324004, 411.42772317433827, 417.6111102400159, 423.818325753866, 430.0492010353872, 436.3035704026212, 442.5812710874544, 448.88214315418065, 455.20602942116585, 461.55277538546613, 467.9222291502587, 474.31424135495354, 480.72866510786037], [0.0, 0.9597140244425256, 2.4464274180811185, 4.229173820154596, 6.236240129361027, 8.428520493446063, 10.780676874516884, 13.274684111756427, 15.896932262783894, 18.636709212903813, 21.485320734999746, 24.435541423321407, 27.481252560221005, 30.617192649465526, 33.838779417890635, 37.14197907467726, 40.52320791461132, 43.9792567110727, 47.50723157113072, 51.10450694079165, 54.76868774831366, 58.49757853530726, 62.289158010788704, 66.14155786974439, 70.05304500534874, 74.02200645104217, 78.04693654011497, 82.12642588278331, 86.25915184516965, 90.44387027880086, 94.67940829859911, 98.96465794567379, 103.29857060127179, 107.68015204200333, 112.10845804539937, 116.58259047006602, 121.10169374700364, 125.66495172867279, 130.271584850594, 134.92084756702835, 139.61202602788688, 144.3444359686821, 149.11742078923808, 153.93034980016066, 158.782616618839, 163.67363769910386, 168.6028509806694, 173.56971464619616, 178.57370597528362, 183.614320285961, 188.6910699553416, 193.80348351204665, 198.95110479383118, 204.13349216455882, 209.35021778529838, 214.6008669348655, 219.88503737561382, 225.20233876070466, 230.5523920794608, 235.9348291377397, 241.3492920705581, 246.79543288445907, 252.2729130273484, 257.781402983733, 263.3205818934801, 268.8901371923847, 274.4897642729786, 280.11916616415215, 285.77805322827885, 291.46614287464223, 297.183159288064, 302.9288331717198, 308.7029015032123, 314.50510730304194, 320.335199414684, 326.19293229554125, 332.0780658180951, 337.99036508063085, 343.92960022695644, 349.895546274578, 355.8879829508334, 361.9066945365184, 367.95146971657704, 374.02210143745197, 380.1183867707233, 386.2401267826846, 392.3871264095324, 398.55919433786477, 404.75614289020274, 410.97778791527173, 417.223948682791, 423.49444778253905, 429.78911102747617, 436.1077673607167, 442.45024876616225, 448.81639018260955, 455.20602942116585, 461.61900708581004, 468.05516649694886, 474.5143536178253, 480.996416983646, 487.50120763329903], [0.0, 0.9730949129146276, 2.480536925291301, 4.2881394096691325, 6.3231893991757495, 8.546035805127728, 10.93098731204068, 13.459767441871328, 16.118576494543902, 18.896553000858997, 21.784881513752946, 24.77623588668597, 27.86441209130693, 31.04407527255664, 34.3105792685658, 37.659834047068735, 41.08820593675878, 44.59244096612059, 48.169604893893066, 51.817035559088865, 55.53230449648951, 59.31318563735378, 63.15762950868898, 67.06374175649151, 71.0297651099572, 75.05406411361302, 79.13511210787237, 83.27148005242327, 87.46182687246102, 91.70489107287426, 95.99948341554249, 100.34448049377087, 104.73881906835662, 109.18149105387198, 113.67153906295164, 118.20805243179451, 122.79016366256269, 127.4170452285153, 132.08790669603363, 136.80199212454855, 141.5585777110599, 146.3569696506686, 151.19650218849898, 156.0765358417203, 160.99645577318435, 165.95567030058336, 170.95360952706164, 175.98972408094875, 181.06348395377378, 186.1743774269978, 191.32191007901346, 196.5056038649152, 201.72499626237993, 206.97963947772465, 212.26909970684008, 217.5929564462591, 222.95080185010522, 228.34224012909814, 233.76688698817443, 239.22436909961573, 244.71432360887786, 250.23639767057787, 255.79024801233214, 261.3755405243519, 266.9919498728866, 272.6391591357803, 278.316859458551, 284.024749729546, 289.76253627284336, 295.5299325576833, 301.3266589233125, 307.1524423182146, 313.0070160527815, 318.890119564557, 324.80149819524655, 330.74090297875586, 336.7080904395696, 342.70282240083725, 348.72486580157874, 354.7739925224641, 360.84997921966215, 366.9526071662866, 373.0816621010048, 379.23693408339864, 385.4182173557029, 391.62531021056225, 397.85801486448065, 404.11613733665405, 410.39948733289543, 416.7078781343865, 423.0411264910004, 429.3990525189596, 435.78147960260776, 442.18823430008524, 448.6191462527159, 455.07404809791757, 461.55277538546613, 468.05516649694886, 474.5810625682549, 481.13030741495766, 487.7027474604538, 494.2982316667295], [0.0, 0.9865236763997746, 2.514768471714803, 4.3473159701048525, 6.410449761743044, 8.663971570734516, 11.081835540023775, 13.645512975162209, 16.341013739451654, 19.15732647481851, 22.085514080543277, 25.118149308859728, 28.248942515483197, 31.47248522406035, 34.78406715543176, 38.17954183466082, 41.65522544557637, 45.20781911167662, 48.83434809900919, 52.53211350861824, 56.29865336233127, 60.13171087153565, 64.0292082803983, 67.98922509272585, 72.00997978728009, 76.08981433921223, 80.22718102094915, 84.42063107134369, 88.66880490868489, 92.97042362915927, 97.32428158309462, 101.72923986072175, 106.18422055007822, 110.68820165410175, 115.24021257342855, 119.83933007704687, 124.48467469560073, 129.17540748243462, 133.91072709590227, 138.689867163413, 143.51209389344527, 148.37670390655413, 153.28302226040998, 158.2304006472836, 163.21821574524031, 168.24586770672383, 173.31277877027037, 178.41839198285018, 183.5621700218462, 188.74359410697542, 193.96216299358505, 199.21739203972342, 204.5088123402339, 209.83596992185596, 215.19842499395963, 220.59575125010684, 226.0275352161254, 231.49337564082114, 236.9928829258376, 242.5256785915132, 248.0913947758912, 253.6896737643027, 259.32016754718643, 264.98253740402, 270.6764535114292, 276.4015945737147, 282.1576474741858, 287.94430694583235, 293.7612752599885, 299.60826193175404, 305.48498344104195, 311.3911629682098, 317.32653014331834, 323.2908208081348, 329.2837767900664, 335.3051456872729, 341.35468066426347, 347.43214025733386, 353.53728818924964, 359.6698931926215, 365.829728841461, 372.0165733904389, 378.2302096214042, 384.47042469674955, 390.73701001924115, 397.029761097951, 403.34847741996, 409.6929623275182, 416.06302290036837, 422.45846984296224, 428.87911737631106, 435.32478313423127, 441.79528806376067, 448.2904563295324, 454.81011522191113, 461.35409506870207, 467.9222291502587, 474.5143536178253, 481.13030741495766, 487.76993220187535, 494.4330722826095, 501.1195745348134], [0.0, 1.0, 2.5491212546385245, 4.406702113800223, 6.498019170849886, 8.782325024730138, 11.23321802114866, 13.83191635598674, 16.564238781462045, 19.41902351977134, 22.3872113856834, 25.46127367213938, 28.634834815698557, 31.902412457971845, 35.259231975428044, 38.701090250558885, 42.22425314473263, 45.825376717422856, 49.50144559857454, 53.24972402114996, 57.06771637533113, 60.95313504383462, 64.90387388781878, 68.91798617631373, 72.99366605176041, 77.12923284000122, 81.32311767086088, 85.5738519925126, 89.88005765079393, 94.24043827153353, 98.65377173538343, 103.11890357459343, 107.6347411524755, 112.20024851106254, 116.81444179219996, 121.47638515315643, 126.18518711065899, 130.93999725769194, 135.74000330594893, 140.58442841387105, 145.47252876603955, 150.4035913745537, 155.37693207709114, 160.39189370976945, 165.44784443581716, 170.54417621351098, 175.68030338892532, 180.85566140082048, 186.06970558652898, 191.32191007901346, 196.6117667864108, 201.93878444635877, 207.30248774826126, 212.7024165173943, 218.13812495540512, 223.60918093233232, 229.11516532577468, 234.65567140327994, 240.23030424441598, 245.83868019933178, 251.4804263809232, 257.15518018799037, 262.86258885701665, 268.6023090404164, 274.37400640929116, 280.17735527890864, 286.012038255274, 291.8777459013027, 297.7741764212317, 303.7010353620161, 309.65803533056675, 315.64489572576974, 321.66134248432, 327.70710783947357, 333.7819300918926, 339.8855533918229, 346.01772753189806, 352.17820774991924, 358.36675454100686, 364.5831334785628, 370.8271150435256, 377.09847446143255, 383.39699154684234, 389.72245055469756, 396.0746400382393, 402.45335271310853, 408.85838532729633, 415.28953853662614, 421.7466167854697, 428.2294281924229, 434.73778444067875, 441.2715006728558, 447.830395390054, 454.4142903549222, 461.0230104985397, 467.6563838309188, 474.31424135495354, 480.996416983646, 487.7027474604538, 494.4330722826095, 501.18723362727246, 507.9650762803811], [0.0, 1.0135235740225363, 2.5835944846180494, 4.4662964760314665, 6.585895614106734, 8.901093447292048, 11.385131276568952, 14.018973300700456, 16.78824649075011, 19.681638121786342, 22.689966496015856, 25.80560109135261, 29.022080123951753, 32.33384709434471, 35.736062809025526, 39.22446730931517, 42.79527595768173, 46.445099591571534, 50.17088206234941, 53.9698506056296, 57.83947586203002, 61.777439277505565, 65.78160623069004, 69.85000366385323, 73.98080129778768, 78.1722957296144, 82.4228968724262, 86.73111631432691, 91.09555726358425, 95.51490581441487, 99.98792332004929, 104.51343970020721, 109.09034754184752, 113.71759687714886, 118.39419054267802, 123.11918003976527, 127.89166182909757, 132.71077400311702, 137.57569328847626, 142.485632337942, 147.43983727705262, 152.4375854757628, 157.47818351943025, 162.56096535696827, 167.68529060691398, 172.85054300464685, 178.0561289761071, 183.3014763251692, 188.5860330233799, 193.90926609210004, 199.27066056824845, 204.66971854584008, 210.1059582863808, 215.57891339193964, 221.08813203537682, 226.63317624278943, 232.21362122374344, 237.82905474531015, 243.47907654632175, 249.16329778861004, 254.8813405423046, 260.6328373025413, 266.41743053518, 272.2347722493486, 278.08452359482703, 283.9663544824614, 289.8799432259557, 295.82497620353, 301.80114753806396, 307.8081587944552, 313.84571869303284, 319.91354283795295, 326.01135345959506, 332.13887917005195, 338.2958547308753, 344.4820208323079, 350.6971238832854, 356.9409158115494, 363.21315387325825, 369.5136004715284, 375.84202298338033, 382.1981935945972, 388.5818891420438, 394.9928909630182, 401.43098475124583, 407.89596041914217, 414.38761196600467, 420.90573735181107, 427.45013837632223, 434.0206205632115, 440.6169930489557, 447.23906847624085, 453.88666289165303, 460.55959564743523, 467.25768930710916, 473.98076955476785, 480.72866510786037, 487.50120763329903, 494.2982316667295, 501.1195745348134, 507.9650762803811, 514.834579590322]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 2.8000000000000003\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0015848931924611126, 0.004182558210365091, 0.0073785284575480885, 0.011037837291689716, 0.015085440841362902, 0.019472053339195248, 0.02416224346186057, 0.029129027248417278, 0.03435101018656358, 0.03981071705534971, 0.045493542850690565, 0.05138705684011977, 0.05748052064666411, 0.06376454277989134, 0.07023082380069307, 0.07687196377481159, 0.08368131378304117, 0.09065285936842184, 0.09778112763297016, 0.10506111217615068, 0.11248821171646099, 0.1200581793611437, 0.12776708027118985, 0.13561125602374882, 0.14358729437462936, 0.15169200341723596, 0.1599223893526204, 0.16827563724976652, 0.17674909430053443, 0.18534025517022354, 0.19404674911982525, 0.20286632863502252, 0.21179685934371875, 0.2208363110411833, 0.2299827496719143, 0.23923433014163062, 0.2485892898526275, 0.25804594287199634, 0.26760267465562854, 0.27725793726205855, 0.2870102449994907, 0.2968581704571329, 0.3068003408785195, 0.3168354348400403, 0.3269621792026052, 0.33717934630838087, 0.3474857513979723, 0.35788025022636977, 0.36836173685852236, 0.3789291416275995, 0.3895814292409045, 0.4003175970200636, 0.4111366732635635, 0.422037715720971, 0.4330198101692835, 0.44408206908283376, 0.45522363038903285, 0.466443656302999, 0.477741332234789, 0.48911586576355365, 0.5005664856734657, 0.5120924410467451, 0.5236930004095318, 0.5353674509267319, 0.5471150976423076, 0.5589352627617817, 0.5708272849740063, 0.5827905188094897, 0.5948243340328034, 0.6069281150667863, 0.6191012604464526, 0.6313431823006718, 0.6436533058598425, 0.656031068987916, 0.6684759217372512, 0.6809873259248991, 0.6935647547290115, 0.7062076923041738, 0.7189156334145386, 0.7316880830837221, 0.7445245562604984, 0.757424577499389, 0.7703876806553119, 0.7834134085915104, 0.7965013129000282, 0.809650953634054, 0.8228618990514989, 0.8361337253692062, 0.8494660165272466, 0.8628583639627645, 0.8763103663928941, 0.8898216296062837, 0.9033917662627952, 0.9170203957009756, 0.9307071437529183, 0.9444516425661558, 0.9582535304322439, 0.972112451621727, 0.9860280562251719, 1.0, 1.0140279442228424], [0.0, 0.004182558210365091, 0.011037837291689716, 0.01947205333919525, 0.029129027248417278, 0.03981071705534972, 0.05138705684011977, 0.06376454277989134, 0.07687196377481159, 0.09065285936842185, 0.10506111217615068, 0.12005817936114371, 0.13561125602374882, 0.15169200341723596, 0.16827563724976652, 0.18534025517022357, 0.20286632863502252, 0.22083631104118334, 0.23923433014163065, 0.2580459428719964, 0.27725793726205855, 0.2968581704571329, 0.31683543484004034, 0.33717934630838087, 0.3578802502263698, 0.37892914162759955, 0.40031759702006353, 0.42203771572097104, 0.44408206908283376, 0.466443656302999, 0.48911586576355365, 0.5120924410467452, 0.535367450926732, 0.5589352627617818, 0.5827905188094897, 0.6069281150667865, 0.6313431823006718, 0.656031068987916, 0.6809873259248992, 0.7062076923041739, 0.7316880830837222, 0.7574245774993891, 0.7834134085915105, 0.8096509536340541, 0.8361337253692063, 0.8628583639627646, 0.8898216296062839, 0.9170203957009756, 0.9444516425661557, 0.9721124516217271, 1.0000000000000002, 1.0281115555471683, 1.056444472179139, 1.0849961855602457, 1.1137642090766864, 1.1427461300794932, 1.1719396063743883, 1.20134236293817, 1.2309521888432806, 1.2607669343739714, 1.2907845083190843, 1.3210028754278496, 1.3514200540163648, 1.38203411371354, 1.412843173336284, 1.443845398884619, 1.475039001648195, 1.5064222364164293, 1.537993399785122, 1.5697508285530055, 1.6016928982022125, 1.6338180214571287, 1.66612464691654, 1.6986112577543753, 1.7312763704847072, 1.7641185337870107, 1.7971363273879675, 1.8303283609963859, 1.8636932732880551, 1.8972297309375796, 1.9309364276944525, 1.964812083500813, 1.998855443648522, 2.033065277973333, 2.0674403800841117, 2.1019795666251673, 2.136681676569905, 2.171545570544119, 2.2065701301773566, 2.2417542574808804, 2.27709687425085, 2.3125969214954347, 2.3482533588846395, 2.384065164221712, 2.4200313329350545, 2.4561508775896423, 2.4924228274169935, 2.528846227862801, 2.565420140151403, 2.6021436408662693, 2.639015821545789, 2.676035788293632], [0.0, 0.0073785284575480885, 0.01947205333919525, 0.03435101018656359, 0.05138705684011978, 0.07023082380069309, 0.09065285936842188, 0.11248821171646103, 0.13561125602374885, 0.15992238935262043, 0.1853402551702236, 0.2117968593437188, 0.23923433014163073, 0.26760267465562854, 0.29685817045713303, 0.32696217920260523, 0.3578802502263698, 0.3895814292409046, 0.4220377157209711, 0.455223630389033, 0.48911586576355376, 0.5236930004095319, 0.558935262761782, 0.5948243340328037, 0.631343182300672, 0.6684759217372515, 0.7062076923041739, 0.7445245562604987, 0.7834134085915108, 0.822861899051499, 0.8628583639627646, 0.9033917662627954, 0.9444516425661558, 0.9860280562251722, 1.0281115555471683, 1.0706931364657335, 1.1137642090766866, 1.1573165675416877, 1.2013423629381703, 1.245834078696748, 1.2907845083190845, 1.3361867351124683, 1.38203411371354, 1.4283202532041626, 1.4750390016481953, 1.5221844318998512, 1.5697508285530062, 1.6177326759167896, 1.6661246469165405, 1.7149215928310175, 1.764118533787011, 1.8137106499413531, 1.8636932732880556, 1.9140618800350402, 1.9648120835008138, 2.0159396274866164, 2.0674403800841126, 2.1193103278827077, 2.1715455705441196, 2.2241423157149547, 2.2770968742508506, 2.330405655728203, 2.3840651642217123, 2.4380719943279607, 2.492422827416993, 2.5471144280954556, 2.6021436408662697, 2.657507386971101, 2.713202661403029, 2.7692265300778733, 2.8255761271535547, 2.882248652487745, 2.9392413692248076, 2.9965516015037585, 3.054176732279579, 3.1121142012508325, 3.1703615028870344, 3.2289161845497265, 3.2877758447016383, 3.346938131198728, 3.406400739660266, 3.466161411912456, 3.5262179345014157, 3.5865681372715974, 3.647209892006044, 3.708141111125047, 3.769359746440072, 3.830863787959969, 3.892651262746692, 3.9547202338179597, 4.017068799094395, 4.0796950903888805, 4.142597272435993, 4.205773541959495, 4.269222126776014, 4.33294128493312, 4.396929303880142, 4.4611844996701375, 4.52570521619156, 4.590489824428197, 4.655536721746081, 4.72084433120613], [0.0, 0.011037837291689716, 0.029129027248417278, 0.05138705684011978, 0.07687196377481159, 0.10506111217615068, 0.13561125602374882, 0.16827563724976652, 0.20286632863502255, 0.23923433014163065, 0.27725793726205855, 0.31683543484004034, 0.3578802502263698, 0.4003175970200636, 0.44408206908283376, 0.48911586576355365, 0.535367450926732, 0.5827905188094897, 0.6313431823006719, 0.6809873259248992, 0.7316880830837222, 0.7834134085915105, 0.8361337253692063, 0.8898216296062837, 0.9444516425661558, 1.0000000000000002, 1.056444472179139, 1.1137642090766864, 1.1719396063743883, 1.2309521888432804, 1.2907845083190843, 1.3514200540163648, 1.4128431733362843, 1.4750390016481951, 1.5379933997851218, 1.6016928982022125, 1.66612464691654, 1.7312763704847072, 1.7971363273879677, 1.8636932732880553, 1.9309364276944525, 1.9988554436485222, 2.0674403800841117, 2.136681676569905, 2.2065701301773566, 2.2770968742508506, 2.34825335888464, 2.4200313329350545, 2.492422827416993, 2.565420140151403, 2.6390158215457893, 2.7132026614030287, 2.787973676665338, 2.863322100010319, 2.939241369224807, 3.0157251172900046, 3.092767163118155, 3.170361502887034, 3.2485023019238373, 3.3271838870946913, 3.4064007396602656, 3.4861474885615755, 3.566418904103451, 3.6472098920060434, 3.7285154877974134, 3.8103308515226, 3.8926512627466914, 3.9754721158313475, 4.058788915465935, 4.142597272435992, 4.226892899613167, 4.3116716081519995, 4.396929303880141, 4.482661983869588, 4.568865733177511, 4.65553672174608, 4.742671201451539, 4.830265503293434, 4.9183160347156365, 5.006819277051332, 5.095771783084766, 5.185170174722991, 5.275011140771377, 5.365291434807013, 5.45600787314461, 5.547157332889777, 5.63873675007496, 5.730743117873607, 5.823173484888395, 5.916024953509675, 6.0092946783404555, 6.102979864684536, 6.197077767094605, 6.291585687977257, 6.386500976252153, 6.48182102606264, 6.5775432755353345, 6.673665205586319, 6.770184338771767, 6.867098238180848, 6.964404506368996, 7.062100784329651], [0.0, 0.015085440841362902, 0.03981071705534972, 0.07023082380069309, 0.10506111217615068, 0.14358729437462936, 0.1853402551702236, 0.22998274967191432, 0.27725793726205855, 0.3269621792026052, 0.3789291416275995, 0.43301981016928354, 0.48911586576355376, 0.5471150976423077, 0.6069281150667865, 0.6684759217372512, 0.7316880830837222, 0.7965013129000283, 0.8628583639627645, 0.9307071437529185, 1.0, 1.0706931364657333, 1.1427461300794932, 1.2161215279823923, 1.2907845083190845, 1.3667025924290976, 1.443845398884619, 1.5221844318998508, 1.6016928982022125, 1.6823455476483833, 1.7641185337870104, 1.8469892912848367, 1.9309364276944525, 2.015939627486616, 2.1019795666251677, 2.1890378362482386, 2.27709687425085, 2.366139903752688, 2.456150877589643, 2.5471144280954556, 2.639015821545789, 2.7318409167254494, 2.825576127153554, 2.9202083865638393, 3.0157251172900046, 3.112114201250832, 3.209363953267973, 3.3074630964819836, 3.4064007396602656, 3.506166356214741, 3.6067497647680344, 3.7081411111250464, 3.8103308515226, 3.9133097370436305, 4.017068799094394, 4.1215993358537935, 4.226892899613167, 4.332941284933119, 4.439736517551199, 4.547270843980637, 4.65553672174608, 4.764526810207293, 4.874233961926327, 4.984651214537708, 5.095771783084766, 5.207589052788507, 5.320096572218303, 5.433288046836291, 5.547157332889777, 5.661698431627979, 5.77690548382146, 5.892772764564274, 6.0092946783404555, 6.126465754337928, 6.244280641994173, 6.36273410675923, 6.48182102606264, 6.6015363854719755, 6.72187527503146, 6.842832885770036, 6.964404506368995, 7.086585519979948, 7.209371401184612, 7.332757713088376, 7.456740104540305, 7.581314307472537, 7.706476134352672, 7.832221475743069, 7.958546297961352, 8.085446640836905, 8.21291861555828, 8.340958402606939, 8.46956224977292, 8.598726470248323, 8.72844744079478, 8.858721599981244, 8.98954544648872, 9.120915537478687, 9.25282848702225, 9.385280964587054, 9.518269693579395, 9.651791449938898], [0.0, 0.019472053339195248, 0.05138705684011977, 0.09065285936842188, 0.13561125602374882, 0.1853402551702236, 0.23923433014163067, 0.296858170457133, 0.3578802502263698, 0.4220377157209711, 0.4891158657635537, 0.5589352627617818, 0.631343182300672, 0.7062076923041739, 0.7834134085915107, 0.8628583639627646, 0.9444516425661558, 1.0281115555471683, 1.1137642090766866, 1.2013423629381703, 1.2907845083190845, 1.3820341137135397, 1.4750390016481951, 1.5697508285530057, 1.6661246469165405, 1.764118533787011, 1.8636932732880551, 1.9648120835008136, 2.067440380084112, 2.171545570544119, 2.27709687425085, 2.384065164221712, 2.492422827416993, 2.6021436408662697, 2.713202661403029, 2.8255761271535547, 2.9392413692248076, 3.0541767322795788, 3.1703615028870344, 3.2877758447016383, 3.4064007396602656, 3.5262179345014157, 3.6472098920060434, 3.769359746440072, 3.892651262746692, 4.017068799094395, 4.142597272435993, 4.269222126776013, 4.396929303880141, 4.52570521619156, 4.65553672174608, 4.786411100901327, 4.918316034715637, 5.051239584830148, 5.185170174722993, 5.320096572218303, 5.456007873144611, 5.592893486047858, 5.730743117873608, 5.869546760541254, 6.009294678340456, 6.149977396086516, 6.291585687977257, 6.434110567099182, 6.577543275535334, 6.7218752750314605, 6.867098238180849, 7.013204040091542, 7.160184750502736, 7.308032626319853, 7.456740104540306, 7.606299795544188, 7.756704476726175, 7.90794708644679, 8.060020718282825, 8.212918615558282, 8.366634166138569, 8.52116089747199, 8.676492471863693, 8.832622681968337, 8.989545446488718, 9.14725480606846, 9.305744919367747, 9.465010059311753, 9.625044609502256, 9.785843060783378, 9.947400007953172, 10.10971014661319, 10.272768270148713, 10.436569266832857, 10.60110811704805, 10.766379890618932, 10.932379744251016, 11.099102919069779, 11.266544738255261, 11.43470060476744, 11.603565999158006, 11.773136477464325, 11.943407669181832, 12.11437527531096, 12.286035066475321, 12.458382881107722], [0.0, 0.02416224346186057, 0.06376454277989134, 0.11248821171646103, 0.16827563724976652, 0.22998274967191432, 0.296858170457133, 0.36836173685852236, 0.44408206908283376, 0.5236930004095318, 0.6069281150667865, 0.6935647547290116, 0.7834134085915108, 0.8763103663928942, 0.9721124516217271, 1.0706931364657333, 1.1719396063743883, 1.2757504962807138, 1.3820341137135397, 1.4907070224551153, 1.6016928982022125, 1.714921592831017, 1.830328360996386, 1.9478532147202208, 2.067440380084112, 2.1890378362482386, 2.3125969214954347, 2.4380719943279603, 2.565420140151403, 2.6946009159905273, 2.825576127153554, 2.9583096309064603, 3.0927671631181544, 3.2289161845497265, 3.366725744029695, 3.506166356214741, 3.647209892006043, 3.789829479993547, 3.9339994175484625, 4.079695090388881, 4.226892899613167, 4.375570195337374, 4.52570521619156, 4.677277034029842, 4.830265503293434, 4.984651214537708, 5.14041545169549, 5.2975401527010915, 5.45600787314461, 5.615801752664679, 5.776905483821461, 5.939303283220648, 6.102979864684538, 6.2679204142883505, 6.434110567099181, 6.601536385471976, 6.7701843387717675, 6.940041284404546, 7.111094450050778, 7.283331417005766, 7.456740104540306, 7.631308755203062, 7.807025920993431, 7.98388045034008, 8.161861475826095, 8.340958402606939, 8.52116089747199, 8.702458878504657, 8.884842505299883, 9.06830216970114, 9.25282848702225, 9.438412287722015, 9.625044609502256, 9.81271668980212, 10.00141995866362, 10.191146031945257, 10.381886704862309, 10.573633945833967, 10.766379890618934, 10.960116836722417, 11.154837238058704, 11.350533699854516, 11.547198973779526, 11.744825953291148, 11.94340766918183, 12.142937285317586, 12.343408094557514, 12.544813514844524, 12.747147085458206, 12.950402463421405, 13.154573420052444, 13.359653837655603, 13.565637706342839, 13.772519120980117, 13.980292278252275, 14.188951473840499, 14.398491099707018, 14.60890564148183, 14.82018967594666, 15.032337868611492, 15.245344971379465, 15.459205820295967], [0.0, 0.029129027248417278, 0.07687196377481159, 0.13561125602374885, 0.20286632863502255, 0.27725793726205855, 0.3578802502263698, 0.44408206908283376, 0.535367450926732, 0.6313431823006719, 0.7316880830837222, 0.8361337253692063, 0.9444516425661559, 1.056444472179139, 1.1719396063743883, 1.2907845083190843, 1.4128431733362843, 1.5379933997851223, 1.6661246469165403, 1.797136327387968, 1.9309364276944527, 2.0674403800841117, 2.206570130177357, 2.3482533588846395, 2.4924228274169935, 2.6390158215457893, 2.787973676665338, 2.9392413692248076, 3.092767163118155, 3.248502301923837, 3.406400739660265, 3.5664189041034513, 3.728515487797414, 3.892651262746692, 4.058788915465935, 4.226892899613167, 4.396929303880141, 4.568865733177511, 4.7426712014515395, 4.918316034715637, 5.095771783084767, 5.275011140771377, 5.45600787314461, 5.638736750074961, 5.823173484888396, 6.0092946783404555, 6.197077767094606, 6.386500976252154, 6.577543275535334, 6.7701843387717675, 6.964404506368996, 7.160184750502735, 7.357506642773011, 7.556352324108945, 7.756704476726174, 7.958546297961352, 8.161861475826095, 8.366634166138569, 8.572848971104921, 8.780490919235108, 8.989545446488718, 9.199998378556115, 9.411835914189, 9.625044609502256, 9.839611363175889, 10.05552340249218, 10.272768270148712, 10.491333811793039, 10.711208164229275, 10.932379744251016, 11.154837238058704, 11.378569591222902, 11.603565999158002, 11.829815898073678, 12.057308956373852, 12.286035066475321, 12.515984337020186, 12.747147085458206, 12.979513830976913, 13.213075287758915, 13.447822358547294, 13.683746128501316, 13.920837859325964, 14.159088983659812, 14.398491099707016, 14.639035966099863, 14.880715496979503, 15.123521757283093, 15.367446958226402, 15.612483452971723, 15.858623732471374, 16.105860421477868, 16.354186274712312, 16.603594173183026, 16.85407712064706, 17.105628240207466, 17.35824077103986, 17.611908065241927, 17.86662358480021, 18.12238089866847, 18.37917367995257, 18.636995703196874], [0.0, 0.03435101018656358, 0.09065285936842185, 0.15992238935262043, 0.23923433014163065, 0.3269621792026052, 0.4220377157209711, 0.5236930004095318, 0.6313431823006719, 0.7445245562604985, 0.8628583639627645, 0.986028056225172, 1.1137642090766866, 1.2458340786967474, 1.3820341137135397, 1.5221844318998508, 1.6661246469165403, 1.813710649941353, 1.9648120835008134, 2.1193103278827072, 2.27709687425085, 2.43807199432796, 2.6021436408662693, 2.7692265300778733, 2.9392413692248076, 3.112114201250832, 3.2877758447016374, 3.466161411912456, 3.6472098920060434, 3.8308637879599683, 4.017068799094394, 4.205773541959495, 4.396929303880141, 4.590489824428197, 4.786411100901326, 4.984651214537708, 5.185170174722992, 5.387929778875453, 5.592893486047858, 5.800026302575404, 6.0092946783404555, 6.220666412426097, 6.434110567099181, 6.649597389205637, 6.867098238180848, 7.08658551997995, 7.308032626319853, 7.531413878699162, 7.756704476726174, 7.983880450340079, 8.21291861555828, 8.443796533423917, 8.676492471863693, 8.910985370197468, 9.147254806068462, 9.385280964587052, 9.625044609502256, 9.866527056233668, 10.109710146613189, 10.354576225200333, 10.60110811704805, 10.8492891068074, 11.099102919069777, 11.35053369985452, 11.603565999158, 11.858184754487656, 12.11437527531096, 12.372123228355427, 12.631414623700996, 12.892235801611012, 13.154573420052442, 13.418414442859849, 13.683746128501317, 13.950556019407772, 14.218831931830024, 14.488561946190718, 14.759734397900676, 15.032337868611492, 15.30636117787821, 15.581793375207873, 15.858623732471372, 16.136841736657676, 16.41643708295095, 16.697399668112354, 16.979719584149688, 17.26338711225896, 17.548392717023244, 17.834727040854922, 18.122380898668467, 18.41134527277175, 18.701611307964377, 18.993170306832624, 19.286013725230912, 19.580133167940502, 19.875520384496625, 20.17216726517578, 20.470065837135426, 20.769208260698733, 21.069586825777588, 21.37119394842718, 21.674022167526235, 21.978064141576944], [0.0, 0.03981071705534971, 0.10506111217615068, 0.1853402551702236, 0.27725793726205855, 0.3789291416275995, 0.4891158657635537, 0.6069281150667865, 0.7316880830837222, 0.8628583639627645, 1.0, 1.1427461300794932, 1.2907845083190845, 1.443845398884619, 1.6016928982022125, 1.7641185337870104, 1.9309364276944525, 2.1019795666251677, 2.27709687425085, 2.456150877589643, 2.639015821545789, 2.825576127153554, 3.0157251172900046, 3.2093639532679727, 3.4064007396602656, 3.6067497647680344, 3.8103308515225995, 4.017068799094394, 4.226892899613167, 4.439736517551198, 4.6555367217460795, 4.874233961926327, 5.095771783084766, 5.320096572218303, 5.547157332889777, 5.77690548382146, 6.009294678340455, 6.244280641994173, 6.481821026062641, 6.7218752750314605, 6.964404506368995, 7.209371401184612, 7.456740104540305, 7.706476134352672, 7.958546297961352, 8.21291861555828, 8.46956224977292, 8.72844744079478, 8.989545446488718, 9.25282848702225, 9.518269693579395, 9.785843060783378, 10.05552340249218, 10.327286310667331, 10.601108117048048, 10.876965857390775, 11.154837238058704, 11.43470060476744, 11.716534913312216, 12.000319702118771, 12.28603506647532, 12.573661634316135, 12.863180543439391, 13.154573420052444, 13.447822358547292, 13.74290990241752, 14.03981902623562, 14.33853311861659, 14.639035966099863, 14.941311737887215, 15.245344971379463, 15.551120558459235, 15.858623732471372, 16.167840055856246, 16.47875540839472, 16.79135597602662, 17.105628240207466, 17.421558967770743, 17.739135201265473, 18.05834424974095, 18.379173679952565, 18.701611307964374, 19.02564519112592, 19.35126362040214, 19.678455113036865, 20.00720840553148, 20.337512446921732, 20.669356392336663, 21.002729596824672, 21.33762160943284, 21.674022167526235, 22.011921191335, 22.35130877871768, 22.6921752001299, 23.034510893788273, 23.378306461019925, 23.72355266178863, 24.07024041038907, 24.4183607713013, 24.767904955197753, 25.11886431509581, 25.47123034264912], [0.0, 0.045493542850690565, 0.12005817936114371, 0.2117968593437188, 0.31683543484004034, 0.43301981016928354, 0.5589352627617818, 0.6935647547290116, 0.8361337253692063, 0.986028056225172, 1.1427461300794932, 1.3058687178116581, 1.4750390016481953, 1.6499487420084806, 1.830328360996386, 2.015939627486616, 2.2065701301773566, 2.4020290152670807, 2.6021436408662693, 2.806756910256915, 3.0157251172900046, 3.228916184549726, 3.4462082071666784, 3.6674882376135995, 3.892651262746692, 4.1215993358537935, 4.354240834899951, 4.590489824428197, 4.830265503293435, 5.073491724004238, 5.3200965722183025, 5.570011997093347, 5.823173484888395, 6.079519769551643, 6.3389925751018765, 6.601536385471976, 6.867098238180848, 7.135627538769135, 7.407075893400973, 7.6813969574192305, 7.958546297961352, 8.238481269009489, 8.52116089747199, 8.806545779081489, 9.094597983053813, 9.385280964587054, 9.678559484395372, 9.974399534570491, 10.272768270148712, 10.573633945833967, 10.876965857390777, 11.18273428727547, 11.490910454121716, 11.80146646573802, 12.114375275310959, 12.429610640540085, 12.747147085458206, 13.066959864715633, 13.389024930128805, 13.713318899312922, 14.039819026235621, 14.36850317354376, 14.699349786529197, 15.032337868611494, 15.3674469582264, 15.704657107018766, 16.043948859247195, 16.385303232315756, 16.728701698355135, 17.074126166781923, 17.421558967770743, 17.770982836578938, 18.122380898668467, 18.475736655573943, 18.831033971469584, 19.18825706039159, 19.547390474075574, 19.908419090371705, 20.271328102203032, 20.63610300703474, 21.002729596824672, 21.371193948427177, 21.741482414424667, 22.11358161436263, 22.487478426365893, 22.863159979115004, 23.240613644163332, 23.61982702857656, 24.00078796787743, 24.383484519279946, 24.767904955197753, 25.15403775701286, 25.541871609091434, 25.931395393034293, 26.32259818215048, 26.715469236142933, 27.109997995996018, 27.50617407905514, 27.903987274289467, 28.303427537728936, 28.704484988067616, 29.107149902425643], [0.0, 0.05138705684011977, 0.13561125602374882, 0.23923433014163073, 0.3578802502263698, 0.48911586576355376, 0.631343182300672, 0.7834134085915108, 0.9444516425661559, 1.1137642090766866, 1.2907845083190845, 1.4750390016481953, 1.6661246469165407, 1.8636932732880553, 2.0674403800841126, 2.2770968742508506, 2.4924228274169935, 2.7132026614030296, 2.939241369224808, 3.170361502887035, 3.406400739660266, 3.6472098920060434, 3.8926512627466923, 4.142597272435993, 4.396929303880142, 4.655536721746081, 4.918316034715637, 5.185170174722993, 5.456007873144612, 5.730743117873608, 6.0092946783404555, 6.291585687977258, 6.5775432755353345, 6.86709823818085, 7.160184750502736, 7.456740104540307, 7.756704476726175, 8.060020718282827, 8.36663416613857, 8.676492471863694, 8.98954544648872, 9.305744919367749, 9.625044609502257, 9.947400007953174, 10.272768270148713, 10.601108117048051, 10.932379744251019, 11.266544738255261, 11.603565999158004, 11.943407669181832, 12.286035066475323, 12.631414623700998, 12.979513830976915, 13.330301182785144, 13.68374612850132, 14.039819026235621, 14.39849109970702, 14.75973439790068, 15.123521757283097, 15.489826766371202, 15.858623732471376, 16.22988765042129, 16.60359417318303, 16.97971958414969, 17.358240771039856, 17.739135201265476, 18.12238089866847, 18.507956421530427, 18.895840841767605, 19.286013725230916, 19.67845511303687, 20.07314550386161, 20.470065837135426, 20.869197477080004, 21.270522197535232, 21.674022167526243, 22.079679937525242, 22.487478426365897, 22.897400908771218, 23.30943100345864, 23.72355266178863, 24.139750156925427, 24.558008073480828, 24.978311297613764, 25.400645007560463, 25.824994664571406, 26.25134600423313, 26.679685028154207, 27.109997995996018, 27.54227141783044, 27.97649204680729, 28.412646872115783, 28.85072311222514, 29.290708208390196, 29.732589818409092, 30.176355810620482, 30.621994258128748, 31.069493433246212, 31.51884180214217, 31.97002801968875, 32.42304092449474, 32.87786953411849], [0.0, 0.05748052064666411, 0.15169200341723596, 0.26760267465562854, 0.4003175970200636, 0.5471150976423077, 0.7062076923041739, 0.8763103663928942, 1.056444472179139, 1.2458340786967474, 1.443845398884619, 1.6499487420084806, 1.8636932732880553, 2.084689535880284, 2.3125969214954347, 2.547114428095455, 2.787973676665338, 3.0349335258212338, 3.287775844701638, 3.546302143574225, 3.8103308515226, 4.0796950903888805, 4.354240834899951, 4.633825377272114, 4.918316034715637, 5.207589052788508, 5.501528668199017, 5.800026302575403, 6.102979864684537, 6.410293143126319, 6.72187527503146, 7.037640279014474, 7.35750664277301, 7.6813969574192305, 8.009237591981979, 8.340958402606939, 8.67649247186369, 9.01577587428758, 9.358747464874124, 9.705348687730456, 10.05552340249218, 10.409217726450759, 10.766379890618932, 11.126960108199231, 11.490910454121716, 11.858184754487658, 12.228738484901493, 12.60252867679777, 12.979513830976913, 13.359653837655605, 13.742909902417521, 14.129244477519057, 14.518621198064942, 14.911004822621138, 15.30636117787821, 15.704657107018765, 16.10586042147787, 16.50993985581664, 16.91686502545684, 17.326606387048628, 17.739135201265473, 18.15442349783941, 18.57244404266712, 18.993170306832628, 19.41657643740621, 19.8426372298914, 20.27132810220303, 20.70262507006929, 21.13650472375974, 21.572944206049204, 22.011921191335002, 22.453413865831372, 22.897400908771214, 23.34386147455048, 23.792775175755743, 24.244122067019784, 24.69788262965435, 25.15403775701286, 25.61256874053933, 26.073457256462987, 26.5366853531008, 27.00223543873292, 27.47009027001844, 27.940232940920943, 28.412646872115783, 28.8873158008523, 29.36422377124661, 29.843355124981677, 30.32469449239311, 30.808226783920624, 31.293937181905992, 31.781811132719877, 32.271834339200915, 32.763992753391214, 33.25827256955383, 33.75466021745818, 34.25314235592047, 34.75370586658688, 35.25633784794805, 35.76102560957383, 36.26775666655813, 36.77651873416423], [0.0, 0.06376454277989134, 0.16827563724976652, 0.29685817045713303, 0.44408206908283376, 0.6069281150667865, 0.7834134085915107, 0.9721124516217271, 1.1719396063743883, 1.3820341137135397, 1.6016928982022125, 1.830328360996386, 2.0674403800841126, 2.3125969214954347, 2.565420140151403, 2.8255761271535547, 3.0927671631181544, 3.3667257440296954, 3.6472098920060434, 3.9339994175484625, 4.226892899613167, 4.525705216191559, 4.830265503293434, 5.140415451695489, 5.456007873144611, 5.776905483821461, 6.102979864684537, 6.434110567099181, 6.7701843387717675, 7.111094450050777, 7.456740104540305, 7.807025920993432, 8.161861475826095, 8.52116089747199, 8.884842505299883, 9.25282848702225, 9.625044609502256, 10.00141995866362, 10.38188670486231, 10.766379890618934, 11.154837238058704, 11.547198973779526, 11.94340766918183, 12.343408094557516, 12.747147085458206, 13.154573420052444, 13.56563770634284, 13.980292278252275, 14.398491099707016, 14.82018967594666, 15.245344971379467, 15.673915333378138, 16.10586042147787, 16.54114114149679, 16.979719584149688, 17.421558967770743, 17.86662358480021, 18.314878751724553, 18.76629076219045, 19.220826843039728, 19.67845511303687, 20.139144544081777, 20.60286492471975, 21.069586825777588, 21.539281567970125, 22.011921191335002, 22.487478426365893, 22.965926666725416, 23.447239943428915, 23.93139290039931, 24.4183607713013, 24.90811935757058, 25.40064500756046, 25.89591459673421, 26.393905508837122, 26.894595617987115, 27.397963271627507, 27.903987274289467, 28.412646872115783, 28.923921738100844, 29.437791958005047, 29.95423801690473, 30.473240786341464, 30.994781512036944, 31.518841802142163, 32.04540361599138, 32.57444925333364, 33.10596134401614, 33.639922838095494, 34.17631699635464, 34.7151273812041, 35.25633784794805, 35.799932536396874, 36.345895862808426, 36.894212512142175, 37.444867430610515, 37.99784581851304, 38.55313312334008, 39.11071503313279, 39.67057747008763, 40.23270658439394, 40.7970887482938], [0.0, 0.07023082380069307, 0.18534025517022357, 0.32696217920260523, 0.48911586576355365, 0.6684759217372512, 0.8628583639627646, 1.0706931364657333, 1.2907845083190843, 1.5221844318998508, 1.7641185337870104, 2.015939627486616, 2.2770968742508506, 2.547114428095455, 2.8255761271535547, 3.1121142012508316, 3.406400739660265, 3.7081411111250464, 4.017068799094394, 4.33294128493312, 4.6555367217460795, 4.984651214537707, 5.320096572218303, 5.66169843162798, 6.0092946783404555, 6.36273410675923, 6.72187527503146, 7.08658551997995, 7.456740104540306, 7.832221475743068, 8.212918615558278, 8.598726470248323, 8.989545446488718, 9.385280964587054, 9.785843060783378, 10.191146031945255, 10.601108117048048, 11.015651210709374, 11.434700604767443, 11.858184754487658, 12.28603506647532, 12.718185705783803, 13.154573420052442, 13.595137378798825, 14.03981902623562, 14.488561946190718, 14.941311737887219, 15.39801590149187, 15.858623732471372, 16.323086223908373, 16.79135597602662, 17.263387112258965, 17.739135201265473, 18.218557184373115, 18.701611307964377, 19.18825706039159, 19.678455113036865, 20.17216726517578, 20.669356392336663, 21.169986397877143, 21.674022167526235, 22.181429526663766, 22.6921752001299, 23.206226774376496, 23.723552661788624, 24.24412206701978, 24.767904955197753, 25.29487202187039, 25.824994664571403, 26.358244955896243, 26.89459561798711, 27.43401999833414, 27.976492046807284, 28.52198629384002, 29.07047782969206, 29.621942284723836, 30.176355810620475, 30.733695062507667, 31.29393718190599, 31.8570597804741, 32.423040924494735, 32.99185912006069, 33.563493298920946, 34.13792280494974, 34.71512738120409, 35.295087157537345, 35.877782638738644, 36.463194693170124, 37.05130454187539, 37.64209374813469, 38.235544207443546, 38.83163813789312, 39.43035807093217, 40.03168684249112, 40.63560758445069, 41.24210371643786, 41.85115893793349, 42.462757220676416, 43.0768828013503, 43.69352017453949, 44.31265408594168, 44.93426952582537], [0.0, 0.07687196377481159, 0.20286632863502252, 0.3578802502263698, 0.535367450926732, 0.7316880830837222, 0.9444516425661558, 1.1719396063743883, 1.4128431733362843, 1.6661246469165403, 1.9309364276944525, 2.2065701301773566, 2.4924228274169935, 2.787973676665338, 3.0927671631181544, 3.406400739660265, 3.728515487797414, 4.058788915465935, 4.396929303880141, 4.7426712014515395, 5.095771783084766, 5.45600787314461, 5.823173484888395, 6.197077767094605, 6.577543275535334, 6.964404506368996, 7.35750664277301, 7.756704476726174, 8.161861475826095, 8.57284897110492, 8.989545446488718, 9.411835914189, 9.839611363175889, 10.272768270148713, 10.711208164229273, 11.154837238058704, 11.603565999158002, 12.057308956373852, 12.515984337020187, 12.979513830976915, 13.447822358547294, 13.920837859325964, 14.398491099707016, 14.880715496979503, 15.367446958226402, 15.858623732471374, 16.354186274712312, 16.85407712064706, 17.358240771039856, 17.86662358480021, 18.37917367995257, 18.895840841767605, 19.416576437406214, 19.9413333364978, 20.470065837135422, 21.002729596824672, 21.53928156797013, 22.07967993752524, 22.623884070468424, 23.171854456800578, 23.723552661788627, 24.27894127920519, 24.837983887337643, 25.400645007560463, 25.966890065282893, 26.5366853531008, 27.109997995996014, 27.686795918440115, 28.26704781327148, 28.850723112225133, 29.437791958005047, 30.028225177797037, 30.621994258128737, 31.219071320990338, 31.819429101136336, 32.423040924494735, 33.029880687615545, 33.639922838095494, 34.25314235592047, 34.86951473567145, 35.48901596954351, 36.111622531130905, 36.73731135993483, 37.36605984655293, 37.997845818513035, 38.632647526715374, 39.270443632450515, 39.91121319496205, 40.55493565952518, 41.201590846014206, 41.851158937933484, 42.50362047188822, 43.15895632747277, 43.81714771755548, 44.47817617894048, 45.14202356338795, 45.80867202897536, 46.47810403178332, 47.15030231789088, 47.82524991566528, 48.502930128332764, 49.18332652681743], [0.0, 0.08368131378304117, 0.22083631104118334, 0.3895814292409046, 0.5827905188094897, 0.7965013129000283, 1.0281115555471683, 1.2757504962807138, 1.5379933997851223, 1.813710649941353, 2.1019795666251677, 2.4020290152670807, 2.7132026614030296, 3.0349335258212338, 3.3667257440296954, 3.7081411111250464, 4.058788915465935, 4.418318098509728, 4.786411100901326, 5.162778957241903, 5.547157332889778, 5.939303283220648, 6.3389925751018765, 6.746017451632649, 7.160184750502736, 7.581314307472539, 8.00923759198198, 8.443796533423917, 8.884842505299885, 9.332235441092198, 9.785843060783378, 10.245540190919575, 10.711208164229275, 11.18273428727547, 11.660011366589275, 12.142937285317588, 12.631414623700996, 13.125350317744836, 13.62465535130505, 14.129244477519059, 14.639035966099865, 15.153951373501908, 15.673915333378138, 16.198855365093827, 16.728701698355135, 17.263387112258965, 17.802846787282565, 18.347018168912363, 18.895840841767605, 19.449256413208033, 20.007208405531486, 20.56964215596735, 21.136504723759742, 21.707744803710543, 22.283312645619205, 22.863159979115007, 23.44723994342892, 24.035507021697608, 24.62791697943266, 25.224426806823075, 25.824994664571406, 26.429579832991326, 27.03814266412002, 27.650644536620785, 28.26704781327148, 28.887315800852303, 29.511412712262533, 30.139303630710316, 30.770954475832834, 31.4063319716157, 32.04540361599138, 32.68813765200588, 33.33450304045177, 33.98446943387374, 34.63800715185967, 35.29508715753735, 35.95568103520252, 36.61976096900955, 37.28729972266125, 37.958270620038576, 38.63264752671538, 39.31040483230729, 39.99151743360707, 40.675960718462264, 41.36371055035404, 42.05474325363847, 42.7490355994145, 43.44656479198496, 44.147308455879106, 44.85124462340745, 45.55835172272108, 46.268608566349684, 46.9819943401943, 47.69848859295142, 48.41807122594778, 49.14072248336502, 49.86642294283581, 50.59515350639322, 51.3268953917569, 52.06163012393992, 52.79933952716148, 53.540005717051415], [0.0, 0.09065285936842184, 0.23923433014163065, 0.4220377157209711, 0.6313431823006719, 0.8628583639627645, 1.1137642090766866, 1.3820341137135397, 1.6661246469165403, 1.9648120835008134, 2.27709687425085, 2.6021436408662693, 2.939241369224808, 3.287775844701638, 3.6472098920060434, 4.017068799094394, 4.396929303880141, 4.786411100901326, 5.185170174722992, 5.592893486047858, 6.0092946783404555, 6.434110567099181, 6.867098238180848, 7.308032626319853, 7.756704476726175, 8.21291861555828, 8.67649247186369, 9.147254806068462, 9.625044609502256, 10.109710146613189, 10.601108117048048, 11.099102919069777, 11.603565999158002, 12.11437527531096, 12.631414623700994, 13.154573420052444, 13.683746128501317, 14.218831931830024, 14.759734397900678, 15.306361177878212, 15.858623732471374, 16.416437082950953, 16.979719584149688, 17.548392717023244, 18.12238089866847, 18.70161130796438, 19.286013725230916, 19.875520384496625, 20.470065837135422, 21.069586825777588, 21.67402216752624, 22.2833126456192, 22.897400908771214, 23.516231377514174, 24.139750156925427, 24.767904955197753, 25.40064500756046, 26.037921005110245, 26.679685028154204, 27.325890483705546, 27.976492046807287, 28.631445605389107, 29.29070820839019, 29.954238016904736, 30.621994258128733, 31.29393718190599, 31.970028019688744, 32.65022894574413, 33.33450304045177, 34.022814255550514, 34.71512738120409, 35.41140801476566, 36.11162253113091, 36.81573805457795, 37.52372243199991, 38.235544207443546, 38.951172597873494, 39.67057747008763, 40.39372931871483, 41.120599245230935, 41.851158937933484, 42.58538065282003, 43.323237195318555, 44.0647019028219, 44.809748627981904, 45.55835172272106, 46.310486022923236, 47.066126833766646, 47.82524991566528, 48.58783147078692, 49.353848130117626, 50.12327694104498, 50.896095355433616, 51.67228121816845, 52.45181275614243, 53.23466856766692, 54.02082761228433, 54.81026920096345, 55.602972986659765, 56.398918955222946, 57.19808741663589, 58.00045899656972], [0.0, 0.09778112763297016, 0.2580459428719964, 0.455223630389033, 0.6809873259248992, 0.9307071437529185, 1.2013423629381703, 1.4907070224551153, 1.797136327387968, 2.1193103278827072, 2.456150877589643, 2.806756910256915, 3.170361502887035, 3.546302143574225, 3.9339994175484625, 4.33294128493312, 4.7426712014515395, 5.162778957241903, 5.592893486047858, 6.0326771334843725, 6.481821026062641, 6.940041284404546, 7.4070758934009735, 7.882682090323697, 8.366634166138569, 8.858721599981246, 9.358747464874124, 9.86652705623367, 10.38188670486231, 10.90466274385016, 11.43470060476744, 11.97185402316259, 12.515984337020187, 13.066959864715637, 13.62465535130505, 14.1889514738405, 14.759734397900678, 15.336895378750006, 15.920330401542754, 16.509939855816643, 17.10562824020747, 17.707303893889257, 18.314878751724557, 18.928268120513955, 19.547390474075577, 20.172167265175784, 20.80252275257987, 21.438383841703168, 22.079679937525242, 22.726342808586143, 23.378306461019932, 24.03550702169761, 24.697882629654355, 25.36537333506507, 26.03792100511025, 26.715469236142933, 27.397963271627514, 28.08534992537437, 28.77757750964149, 29.4745957677153, 30.176355810620482, 30.882810057640796, 31.59391218036268, 32.309617049979195, 33.02988068761555, 33.75466021745818, 34.48391382248838, 35.21760070263829, 35.955681035202524, 36.698115937352114, 37.444867430610515, 38.195898407161984, 38.951172597873494, 39.7106545419203, 40.47430955791376, 41.242103716437875, 42.01400381390774, 42.78997734766982, 43.56999249226951, 44.35401807681712, 45.14202356338796, 45.93397902639708, 46.7298551328931, 47.52962312371925, 48.333254795493886, 49.14072248336502, 49.95199904449709, 50.767057842250786, 51.58587273101888, 52.4084180416842, 53.23466856766694, 54.064599551531515, 54.89818667212452, 55.73540603221698, 56.576234146626255, 57.420647930793706, 58.268624689796255, 59.120142107770796, 59.97517823773219, 60.833711491765825, 61.695720631577736, 62.56118475938557], [0.0, 0.10506111217615068, 0.27725793726205855, 0.48911586576355376, 0.7316880830837222, 1.0, 1.2907845083190845, 1.6016928982022125, 1.9309364276944527, 2.27709687425085, 2.639015821545789, 3.0157251172900046, 3.406400739660266, 3.8103308515226, 4.226892899613167, 4.6555367217460795, 5.095771783084766, 5.547157332889778, 6.0092946783404555, 6.481821026062641, 6.964404506368995, 7.456740104540305, 7.958546297961352, 8.46956224977292, 8.989545446488718, 9.518269693579395, 10.055523402492177, 10.601108117048048, 11.154837238058704, 11.716534913312215, 12.286035066475318, 12.863180543439391, 13.447822358547294, 14.039819026235621, 14.639035966099863, 15.245344971379463, 15.858623732471372, 16.47875540839472, 17.10562824020747, 17.739135201265476, 18.379173679952565, 19.02564519112592, 19.678455113036865, 20.337512446921732, 21.002729596824672, 21.674022167526235, 22.351308778717684, 23.034510893788273, 23.723552661788627, 24.4183607713013, 25.11886431509581, 25.824994664571403, 26.536685353100804, 27.253871967484326, 27.976492046807284, 28.704484988067613, 29.43779195800505, 30.176355810620475, 30.920121009924557, 31.669033557499084, 32.423040924494735, 33.18209198772356, 33.94613696953651, 34.7151273812041, 35.48901596954351, 36.26775666655813, 37.05130454187539, 37.83961575778746, 38.63264752671538, 39.430358070932165, 40.23270658439394, 41.0396531965399, 41.851158937933484, 42.66718570762638, 43.4876962421369, 44.31265408594168, 45.14202356338795, 45.975769751939914, 46.81385845667943, 47.65625618598679, 48.50293012833276, 49.35384813011762, 50.20897867449786, 51.06829086114469, 51.93175438688291, 52.799339527161465, 53.67101711831086, 54.54675854054504, 55.426535701668314, 56.310321021450584, 57.198087416635886, 58.08980828655209, 58.98545749929124, 59.88500937843178, 60.78843869027608, 61.69572063157772, 62.60683081773491, 63.521745271427555, 64.44044041167716, 65.36289304330921, 66.28908034679976, 67.21897986848819], [0.0, 0.11248821171646099, 0.2968581704571329, 0.5236930004095319, 0.7834134085915105, 1.0706931364657333, 1.3820341137135397, 1.714921592831017, 2.0674403800841117, 2.43807199432796, 2.825576127153554, 3.228916184549726, 3.6472098920060434, 4.0796950903888805, 4.525705216191559, 4.984651214537707, 5.45600787314461, 5.939303283220648, 6.434110567099181, 6.940041284404546, 7.456740104540305, 7.983880450340078, 8.521160897471988, 9.06830216970114, 9.625044609502256, 10.191146031945255, 10.766379890618932, 11.350533699854518, 11.94340766918183, 12.544813514844522, 13.154573420052442, 13.772519120980116, 14.398491099707014, 15.032337868611492, 15.673915333378137, 16.323086223908373, 16.979719584149684, 17.643690313265804, 18.314878751724553, 18.993170306832628, 19.678455113036865, 20.37062772297081, 21.069586825777584, 21.775234989705517, 22.487478426365893, 23.206226774376496, 23.931392900399313, 24.662892715824263, 25.40064500756046, 26.144571281576408, 26.894595617987115, 27.65064453662078, 28.412646872115783, 29.180533657701314, 29.95423801690473, 30.733695062507667, 31.518841802142163, 32.30961704997919, 33.10596134401614, 33.90781686851725, 34.71512738120409, 35.52783814483021, 36.345895862808426, 37.16924861858887, 37.997845818513035, 38.83163813789312, 39.67057747008763, 40.51461687836364, 41.36371055035404, 42.217813754933296, 43.076882801350294, 43.94087500046926, 44.809748627981904, 45.683462889464394, 46.561977887162634, 47.44525458839798, 48.33325479549388, 49.22594111713093, 50.12327694104498, 51.02522640798869, 51.93175438688291, 52.84282645108909, 53.758408855739226, 54.67846851606335, 55.602972986659765, 56.531890441655676, 57.46518965571031, 58.40283998581519, 59.34481135384919, 60.29107422984924, 61.24159961595906, 62.19635903102159, 63.15532449578234, 64.11846851867297, 65.08576408214662, 66.05718462953759, 67.03270405242012, 68.01229667844213, 68.9959372596118, 69.983600961015, 70.97526334994403, 71.97090038541859], [0.0, 0.1200581793611437, 0.31683543484004034, 0.558935262761782, 0.8361337253692063, 1.1427461300794932, 1.4750390016481951, 1.830328360996386, 2.206570130177357, 2.6021436408662693, 3.0157251172900046, 3.4462082071666784, 3.8926512627466923, 4.354240834899951, 4.830265503293434, 5.320096572218303, 5.823173484888395, 6.3389925751018765, 6.867098238180848, 7.4070758934009735, 7.958546297961352, 8.521160897471988, 9.094597983053811, 9.67855948439537, 10.272768270148713, 10.876965857390777, 11.490910454121714, 12.11437527531096, 12.747147085458208, 13.389024930128803, 14.03981902623562, 14.699349786529197, 15.367446958226402, 16.043948859247195, 16.728701698355135, 17.421558967770743, 18.122380898668467, 18.831033971469584, 19.547390474075577, 20.271328102203032, 21.002729596824672, 21.741482414424667, 22.487478426365893, 23.240613644163336, 24.00078796787743, 24.767904955197757, 25.541871609091434, 26.322598182150475, 27.109997995996014, 27.903987274289467, 28.704484988067616, 29.51141271226253, 30.324694492393114, 31.144256720524695, 31.970028019688744, 32.801939136039174, 33.639922838095494, 34.483913822488375, 35.333848625680915, 36.18966554118968, 37.05130454187539, 37.918707206912856, 38.791816653086265, 39.67057747008763, 40.55493565952518, 41.44483857737404, 42.34023487962485, 43.24107447090663, 44.147308455879106, 45.058889093206446, 45.975769751939914, 46.89790487015048, 47.82524991566528, 48.75776134877311, 49.69539658677446, 50.638113970261095, 51.585872731018874, 52.53863296145516, 53.49635558545957, 54.45900233061331, 55.426535701668314, 56.39891895522294, 57.376116075526234, 58.35809175134704, 59.34481135384919, 60.33624091541699, 61.33234710937997, 62.33309723058839, 63.33845917679434, 64.34840143079659, 65.36289304330921, 66.38190361651708, 67.40540328828348, 68.43336271697707, 69.46575306688753, 70.50254599420099, 71.54371363350812, 72.58922858481918, 73.63906390106226, 74.69319307604142, 75.75159003283402, 76.81422911260624], [0.0, 0.12776708027118985, 0.33717934630838087, 0.5948243340328037, 0.8898216296062837, 1.2161215279823923, 1.5697508285530057, 1.9478532147202208, 2.3482533588846395, 2.7692265300778733, 3.2093639532679727, 3.6674882376135995, 4.142597272435993, 4.633825377272114, 5.140415451695489, 5.66169843162798, 6.197077767094605, 6.746017451632649, 7.308032626319853, 7.882682090323697, 8.46956224977292, 9.06830216970114, 9.67855948439537, 10.30001698453583, 10.932379744251016, 11.57537268350427, 12.228738484901491, 12.892235801611013, 13.565637706342839, 14.248730341436296, 14.941311737887215, 15.643190777200891, 16.354186274712312, 17.074126166781927, 17.80284678728256, 18.540192221212674, 19.286013725230912, 20.040169206505094, 20.802522752579865, 21.57294420604921, 22.35130877871768, 23.13749670068291, 23.93139290039931, 24.732886712311377, 25.541871609091434, 26.358244955896247, 27.181907784380407, 28.012764584480852, 28.850723112225133, 29.69569421202024, 30.547591652056703, 31.4063319716157, 32.271834339200915, 33.14402042053352, 34.022814255550514, 34.908142143636425, 35.799932536396874, 36.698115937352114, 37.60262480798992, 38.51339347967144, 39.43035807093217, 40.35345640976267, 41.28262796049231, 42.21781375493331, 43.15895632747277, 44.105999653828256, 45.058889093206446, 46.017571333627096, 46.98199434019429, 47.952107306114875, 48.927860606280404, 49.909205753243576, 50.896095355433616, 51.888483077467086, 52.88632360242166, 53.88957259595059, 54.89818667212451, 55.91212336089581, 56.93134107708841, 57.95579909082258, 58.985457499291236, 60.02027719980956, 61.06021986406568, 62.10524791350451, 63.155324495782345, 64.21041346223272, 65.27047934628933, 66.33548734281423, 67.40540328828348, 68.4801936417855, 69.55982546678968, 70.64426641364595, 71.73348470277851, 72.82744910853835, 73.92612894368251, 75.0294940444491, 76.1375147561989, 77.25016191959678, 78.36740685730712, 79.48922136117888, 80.6155776798977, 81.74644850708351], [0.0, 0.13561125602374882, 0.3578802502263698, 0.631343182300672, 0.9444516425661558, 1.2907845083190845, 1.6661246469165405, 2.067440380084112, 2.4924228274169935, 2.9392413692248076, 3.4064007396602656, 3.892651262746692, 4.396929303880142, 4.918316034715637, 5.456007873144611, 6.0092946783404555, 6.577543275535334, 7.160184750502736, 7.756704476726175, 8.366634166138569, 8.989545446488718, 9.625044609502256, 10.272768270148713, 10.932379744251016, 11.603565999158004, 12.286035066475321, 12.979513830976913, 13.683746128501319, 14.398491099707018, 15.123521757283093, 15.858623732471374, 16.603594173183026, 17.358240771039856, 18.12238089866847, 18.895840841767605, 19.67845511303687, 20.470065837135422, 21.27052219753523, 22.079679937525242, 22.897400908771218, 23.72355266178863, 24.558008073480828, 25.400645007560463, 26.251346004233127, 27.109997995996018, 27.97649204680729, 28.85072311222514, 29.73258981840909, 30.62199425812874, 31.518841802142166, 32.42304092449474, 33.33450304045178, 34.25314235592047, 35.17887572734053, 36.11162253113091, 37.05130454187539, 37.99784581851304, 38.951172597873494, 39.91121319496206, 40.87789790945704, 41.85115893793349, 42.83093029137239, 43.81714771755548, 44.80974862798191, 45.80867202897535, 46.81385845667943, 47.82524991566528, 48.842789820898766, 49.866422942835804, 50.896095355433616, 51.931754386882915, 52.9733485728815, 54.02082761228432, 55.074142324977586, 56.13324461183637, 57.19808741663589, 58.26862468979624, 59.34481135384919, 60.42660327052416, 61.51395720935728, 62.6068308177349, 63.70518259228863, 64.80897185156512, 65.91815870989863, 67.03270405242012, 68.15256951113952, 69.27771744204405, 70.40811090315725, 71.54371363350812, 72.6844900329629, 73.83040514287435, 74.98142462750701, 76.1375147561989, 77.29864238622282, 78.46477494631282, 79.63588042082263, 80.81192733448606, 81.99288473774973, 83.17872219265196, 84.36940975922079, 85.56491798236821, 86.76521787925695], [0.0, 0.14358729437462936, 0.37892914162759955, 0.6684759217372515, 1.0000000000000002, 1.3667025924290976, 1.764118533787011, 2.1890378362482386, 2.6390158215457893, 3.112114201250832, 3.6067497647680344, 4.1215993358537935, 4.655536721746081, 5.207589052788508, 5.776905483821461, 6.36273410675923, 6.964404506368996, 7.581314307472539, 8.21291861555828, 8.858721599981246, 9.518269693579395, 10.191146031945255, 10.876965857390777, 11.57537268350427, 12.286035066475321, 13.008643865654271, 13.74290990241752, 14.488561946190718, 15.245344971379467, 16.013018640309838, 16.79135597602662, 17.580142195602146, 18.37917367995257, 19.188257060391592, 20.007208405531482, 20.83585249486022, 21.674022167526235, 22.521557736658075, 23.37830646101993, 24.244122067019788, 25.11886431509581, 26.00239860534799, 26.894595617987115, 27.795330984766974, 28.704484988067616, 29.621942284723836, 30.547591652056706, 31.481325753876725, 32.423040924494735, 33.372636969006464, 34.330016978316195, 35.29508715753735, 36.267756666558135, 37.247937471691536, 38.235544207443546, 39.23049404753412, 40.23270658439394, 41.24210371643787, 42.258609542485296, 43.28215026275809, 44.31265408594168, 45.35005114184258, 46.39427339921878, 47.44525458839799, 48.50293012833276, 49.56723705777268, 50.638113970261095, 51.715500952689055, 52.79933952716148, 53.88957259595058, 54.98614438933041, 56.089000416102195, 57.19808741663589, 58.31335331826672, 59.434747192897625, 60.562219216670336, 61.69572063157772, 62.83520370889957, 63.9806217143526, 65.13192887485336, 66.28908034679976, 67.45203218578372, 68.6207413176535, 69.79516551084964, 70.97526334994404, 72.1609942103157, 73.35231823390193, 74.54919630596693, 75.75159003283402, 76.95946172053122, 78.17277435430242, 79.39149157894002, 80.6155776798977, 81.84499756514354, 83.07971674771758, 84.31970132895863, 85.56491798236821, 86.81533393808081, 88.07091696791196, 89.33163537095653, 90.59745795971199, 91.86835404670212], [0.0, 0.15169200341723596, 0.40031759702006353, 0.7062076923041739, 1.056444472179139, 1.443845398884619, 1.8636932732880551, 2.3125969214954347, 2.787973676665338, 3.2877758447016374, 3.8103308515225995, 4.354240834899951, 4.918316034715637, 5.501528668199017, 6.102979864684537, 6.72187527503146, 7.35750664277301, 8.00923759198198, 8.67649247186369, 9.358747464874124, 10.055523402492177, 10.766379890618932, 11.490910454121714, 12.228738484901491, 12.979513830976913, 13.74290990241752, 14.518621198064938, 15.306361177878209, 16.10586042147787, 16.916865025456836, 17.73913520126547, 18.572444042667115, 19.41657643740621, 20.271328102203032, 21.13650472375974, 22.011921191335, 22.89740090877121, 23.792775175755743, 24.69788262965435, 25.612568740539334, 26.5366853531008, 27.47009027001844, 28.41264687211578, 29.36422377124661, 30.32469449239311, 31.293937181905992, 32.271834339200915, 33.258272569553824, 34.25314235592046, 35.25633784794805, 36.26775666655813, 37.28729972266125, 38.314871048723454, 39.35037764204274, 40.39372931871483, 41.444838577374036, 42.503620471888226, 43.569992492269506, 44.643874453135204, 45.72518838911765, 46.81385845667942, 47.90981084184084, 49.01297367337235, 50.123276941044985, 51.24065241856815, 52.36503359087691, 53.49635558545956, 54.63455510744335, 55.77957037817925, 56.931341077088405, 58.08980828655209, 59.25491443964458, 60.42660327052415, 61.60481976731192, 62.78951012730129, 63.980621714352594, 65.17810301833875, 66.38190361651708, 67.5919741367124, 68.80826622220368, 70.0307324982154, 71.25932653992056, 72.49400284186969, 73.73471678876518, 74.98142462750701, 76.23408344043887, 77.49265111973075, 78.75708634283625, 80.02734854896785, 81.30339791653725, 82.58519534150994, 83.87270241662785, 85.1658814114559, 86.46469525321098, 87.76910750833487, 89.07908236477434, 90.3945846149343, 91.71557963927147, 93.04203339049852, 94.37391237836947, 95.71118365501965, 97.05381480083449], [0.0, 0.1599223893526204, 0.42203771572097104, 0.7445245562604987, 1.1137642090766864, 1.5221844318998508, 1.9648120835008136, 2.4380719943279603, 2.9392413692248076, 3.466161411912456, 4.017068799094394, 4.590489824428197, 5.185170174722993, 5.800026302575403, 6.434110567099181, 7.08658551997995, 7.756704476726174, 8.443796533423917, 9.147254806068462, 9.86652705623367, 10.601108117048048, 11.350533699854518, 12.11437527531096, 12.892235801611013, 13.683746128501319, 14.488561946190718, 15.306361177878209, 16.13684173665768, 16.979719584149688, 17.83472704085492, 18.701611307964377, 19.580133167940502, 20.470065837135422, 21.371193948427184, 22.2833126456192, 23.206226774376496, 24.139750156925423, 25.083704939743907, 26.03792100511025, 27.00223543873293, 27.976492046807287, 28.96054091678214, 29.954238016904732, 30.9574448302737, 31.970028019688744, 32.991859120060695, 34.02281425555052, 35.06277387895202, 36.11162253113091, 37.16924861858887, 38.235544207443546, 39.3104048323073, 40.39372931871483, 41.48541961789639, 42.585380652820035, 43.69352017453949, 44.80974862798191, 45.93397902639709, 47.066126833766646, 48.20610985453905, 49.353848130117626, 50.50926384158158, 51.67228121816845, 52.84282645108911, 54.020827612284315, 55.2062145777668, 56.398918955222946, 57.59887401557635, 58.806014628240426, 60.02027719980957, 61.24159961595906, 62.469921186341985, 63.70518259228864, 64.94732583712869, 66.19629419897042, 67.45203218578374, 68.71448549264537, 69.983600961015, 71.2593265399206, 72.54161124894004, 73.83040514287435, 75.1256592780146, 76.42732567991224, 77.73535731256787, 79.04970804895994, 80.37033264283961, 81.69718670172318, 83.03022666101788, 84.36940975922077, 85.71469401413498, 87.06603820004989, 88.42340182583654, 89.78674511391142, 91.15602898002541, 92.5312150138368, 93.91226546023003, 95.29914320134388, 96.69181173927498, 98.09023517942498, 99.49437821446034, 100.90420610885695, 102.3196846840022], [0.0, 0.16827563724976652, 0.44408206908283376, 0.7834134085915108, 1.1719396063743883, 1.6016928982022125, 2.067440380084112, 2.565420140151403, 3.092767163118155, 3.6472098920060434, 4.226892899613167, 4.830265503293435, 5.456007873144612, 6.102979864684537, 6.7701843387717675, 7.456740104540306, 8.161861475826095, 8.884842505299885, 9.625044609502256, 10.38188670486231, 11.154837238058704, 11.94340766918183, 12.747147085458208, 13.565637706342839, 14.398491099707018, 15.245344971379467, 16.10586042147787, 16.979719584149688, 17.86662358480021, 18.76629076219045, 19.678455113036865, 20.60286492471975, 21.539281567970125, 22.487478426365897, 23.447239943428915, 24.418360771301302, 25.40064500756046, 26.393905508837122, 27.397963271627514, 28.412646872115786, 29.43779195800505, 30.473240786341467, 31.518841802142163, 32.57444925333364, 33.639922838095494, 34.7151273812041, 35.79993253639688, 36.894212512142175, 37.99784581851304, 39.11071503313279, 40.232706584393945, 41.36371055035405, 42.50362047188823, 43.652333178832, 44.80974862798191, 45.975769751939914, 47.15030231789089, 48.333254795493886, 49.52453823314919, 50.724066141973836, 51.931754386882915, 53.14752108422937, 54.371286505506205, 55.60297298665977, 56.84250484260274, 58.0898082865521, 59.344811353849195, 60.607443829948714, 61.8776371822893, 63.155324495782345, 64.44044041167716, 65.7329210695797, 67.03270405242012, 68.33972833418012, 69.65393423020572, 70.97526334994404, 72.30365855195542, 73.63906390106226, 74.98142462750702, 76.3306870880003, 77.68679872854871, 79.04970804895993, 80.41936456892957, 81.7957187956204, 83.17872219265195, 84.5683271504219, 85.96448695768788, 87.36715577434188, 88.77628860531352, 90.19184127554416, 91.61377040597503, 93.04203339049852, 94.47658837382322, 95.91739423020708, 97.36441054301581, 98.81759758506576, 100.27691629971342, 101.74232828265549, 103.21379576440616, 104.69128159341916, 106.17474921982505, 107.66416267975502], [0.0, 0.17674909430053443, 0.466443656302999, 0.822861899051499, 1.2309521888432804, 1.6823455476483833, 2.171545570544119, 2.6946009159905273, 3.248502301923837, 3.8308637879599683, 4.439736517551198, 5.073491724004238, 5.730743117873608, 6.410293143126319, 7.111094450050777, 7.832221475743068, 8.57284897110492, 9.332235441092198, 10.109710146613189, 10.90466274385016, 11.716534913312215, 12.544813514844522, 13.389024930128803, 14.248730341436296, 15.123521757283093, 16.013018640309838, 16.916865025456836, 17.83472704085492, 18.76629076219045, 19.71126034527764, 20.66935639233666, 21.640314515852573, 22.623884070468417, 23.619827028576555, 24.627916979432655, 25.64793823496391, 26.679685028154196, 27.72296079209957, 28.777577509641485, 29.84335512498168, 30.920121009924554, 32.00770947842857, 33.10596134401613, 34.214723515322355, 35.333848625680915, 36.463194693170124, 37.60262480798992, 38.75200684442288, 39.91121319496205, 41.080120524470686, 42.258609542485296, 43.446564791984954, 44.643874453135204, 45.85043016067634, 47.06612683376664, 48.2908625172154, 49.52453823314918, 50.76705784225078, 52.01832791379581, 53.278257603785825, 54.54675854054504, 55.82374471720583, 57.10913239056193, 58.40283998581519, 59.70478800678389, 61.014898951179035, 62.333097230588386, 63.659309094839344, 64.99346256043894, 66.33548734281423, 67.68531479209894, 69.04287783223265, 70.40811090315724, 71.78094990591198, 73.16133215044434, 74.54919630596692, 75.94448235370413, 77.34713154188333, 78.75708634283625, 80.1742904120856, 81.59868854930124, 83.03022666101786, 84.4688517250141, 85.91451175625939, 87.36715577434187, 88.82673377229538, 90.29319668675043, 91.76649636933737, 93.24658555927586, 94.73341785708855, 96.2269476993804, 97.72713033462907, 99.23392179993556, 100.74727889868639, 102.26715917908268, 103.79352091349328, 105.32632307859191, 106.86552533624089, 108.41108801508602, 109.96297209282874, 111.52113917914453, 113.08555149921742], [0.0, 0.18534025517022354, 0.48911586576355365, 0.8628583639627646, 1.2907845083190843, 1.7641185337870104, 2.27709687425085, 2.825576127153554, 3.406400739660265, 4.017068799094394, 4.6555367217460795, 5.3200965722183025, 6.0092946783404555, 6.72187527503146, 7.456740104540305, 8.212918615558278, 8.989545446488718, 9.785843060783378, 10.601108117048048, 11.43470060476744, 12.286035066475318, 13.154573420052442, 14.03981902623562, 14.941311737887215, 15.858623732471374, 16.79135597602662, 17.73913520126547, 18.701611307964377, 19.678455113036865, 20.66935639233666, 21.674022167526232, 22.6921752001299, 23.723552661788624, 24.767904955197753, 25.8249946645714, 26.89459561798711, 27.97649204680728, 29.070477829692056, 30.17635581062048, 31.293937181905992, 32.423040924494735, 33.563493298920946, 34.71512738120409, 35.87778263873864, 37.05130454187539, 38.235544207443546, 39.43035807093217, 40.63560758445068, 41.851158937933484, 43.0768828013503, 44.31265408594167, 45.55835172272107, 46.81385845667942, 48.07906065529735, 49.35384813011762, 50.63811397026109, 51.93175438688291, 53.23466856766692, 54.54675854054504, 55.86792904590691, 57.198087416635886, 58.537143465368594, 59.885009378431775, 61.24159961595907, 62.60683081773489, 63.980621714352594, 65.36289304330921, 66.75356746969187, 68.1525695111395, 69.55982546678966, 70.97526334994403, 72.39881282420737, 73.83040514287434, 75.26997309135594, 76.71745093245343, 78.1727743543024, 79.63588042082263, 81.10670752452141, 82.58519534150994, 84.07128478860115, 85.56491798236819, 87.06603820004987, 88.57458984219844, 90.09051839697115, 91.61377040597502, 93.14429343157863, 94.68203602561209, 96.2269476993804, 97.77897889492048, 99.33808095743727, 100.90420610885694, 102.4773074224408, 104.05733879840568, 105.64425494050043, 107.23801133349141, 108.83856422151189, 110.44587058723393, 112.05988813182273, 113.68057525563711, 115.30789103963983, 116.94179522748573, 118.58224820825595], [0.0, 0.19404674911982525, 0.5120924410467452, 0.9033917662627954, 1.3514200540163648, 1.8469892912848367, 2.384065164221712, 2.9583096309064603, 3.5664189041034513, 4.205773541959495, 4.874233961926327, 5.570011997093347, 6.291585687977258, 7.037640279014474, 7.807025920993432, 8.598726470248323, 9.411835914189, 10.245540190919575, 11.099102919069777, 11.97185402316259, 12.863180543439391, 13.772519120980116, 14.699349786529197, 15.643190777200891, 16.603594173183026, 17.580142195602146, 18.572444042667115, 19.580133167940502, 20.60286492471975, 21.640314515852573, 22.6921752001299, 23.758156715596023, 24.837983887337643, 25.931395393034293, 27.03814266412002, 28.157988904081005, 29.29070820839019, 30.436084773007128, 31.59391218036268, 32.763992753391214, 33.94613696953651, 35.14016292779443, 36.345895862808426, 37.563167700836516, 38.791816653086265, 40.03168684249112, 41.28262796049232, 42.54449495081085, 43.81714771755548, 45.100450855323245, 46.39427339921878, 47.69848859295142, 49.01297367337236, 50.33760966999155, 51.67228121816845, 53.01687638480723, 54.371286505506205, 55.73540603221697, 57.10913239056194, 58.49236584604094, 59.88500937843178, 61.286968563753796, 62.69815146322223, 64.11846851867298, 65.54783245398342, 66.9861581820571, 68.43336271697707, 69.88936509096641, 71.35408627582494, 72.82744910853835, 74.30937822078053, 75.79979997205272, 77.29864238622282, 78.80583509124736, 80.32130926187469, 81.84499756514354, 83.3768341085053, 84.91675439041032, 86.46469525321098, 88.02059483824435, 89.58439254296727, 91.1560289800254, 92.73544593814627, 94.32258634475353, 95.91739423020707, 97.51981469357942, 99.1297938698853, 100.74727889868639, 102.37221789399806, 104.00455991543065, 105.64425494050045, 107.29125383805088, 108.94550834272778, 110.60697103045551, 112.27559529486476, 113.951335324625, 115.63414608163787, 117.3239832800499, 119.02080336604634, 120.72456349838826, 122.43522152965929, 124.1527359881887], [0.0, 0.20286632863502252, 0.535367450926732, 0.9444516425661558, 1.4128431733362843, 1.9309364276944525, 2.492422827416993, 3.0927671631181544, 3.728515487797414, 4.396929303880141, 5.095771783084766, 5.823173484888395, 6.5775432755353345, 7.35750664277301, 8.161861475826095, 8.989545446488718, 9.839611363175889, 10.711208164229275, 11.603565999158002, 12.515984337020187, 13.447822358547294, 14.398491099707014, 15.367446958226402, 16.354186274712312, 17.358240771039856, 18.37917367995257, 19.41657643740621, 20.470065837135422, 21.539281567970125, 22.623884070468417, 23.723552661788624, 24.837983887337643, 25.966890065282897, 27.109997995996014, 28.267047813271475, 29.437791958005047, 30.621994258128733, 31.819429101136336, 33.02988068761555, 34.25314235592047, 35.48901596954351, 36.73731135993483, 37.997845818513035, 39.270443632450515, 40.55493565952518, 41.851158937933484, 43.15895632747278, 44.47817617894047, 45.80867202897535, 47.15030231789088, 48.502930128332764, 49.8664229428358, 51.24065241856817, 52.62549417773616, 54.020827612284315, 55.426535701668314, 56.84250484260275, 58.26862468979623, 59.70478800678391, 61.15089052605302, 62.6068308177349, 64.07251016620364, 65.54783245398342, 67.03270405242012, 68.52703371862171, 70.03073249821541, 71.5437136335081, 73.06589247667283, 74.59718640761471, 76.13751475619888, 77.6867987285487, 79.24496133714598, 80.81192733448603, 82.38762315005988, 83.97197683045329, 85.5649179823682, 87.16637771838712, 88.77628860531351, 90.3945846149343, 92.02120107706098, 93.65607463471649, 95.29914320134384, 96.95034591992184, 98.60962312387997, 100.27691629971339, 101.95216805120366, 103.63532206515897, 105.3263230785919, 107.02511684725845, 108.73165011548762, 110.44587058723391, 112.1677268982905, 113.89716858960438, 115.63414608163784, 117.37861064972493, 119.13051440037361, 120.889810248468, 122.6564518953273, 124.43039380758111, 126.21159119682207, 128.00000000000006, 129.79557686052388], [0.0, 0.21179685934371875, 0.5589352627617818, 0.9860280562251722, 1.4750390016481951, 2.015939627486616, 2.6021436408662697, 3.2289161845497265, 3.892651262746692, 4.590489824428197, 5.320096572218303, 6.079519769551643, 6.86709823818085, 7.6813969574192305, 8.52116089747199, 9.385280964587054, 10.272768270148713, 11.18273428727547, 12.11437527531096, 13.066959864715637, 14.039819026235621, 15.032337868611492, 16.043948859247195, 17.074126166781927, 18.12238089866847, 19.188257060391592, 20.271328102203032, 21.371193948427184, 22.487478426365897, 23.619827028576555, 24.767904955197753, 25.931395393034293, 27.109997995996014, 28.30342753772894, 29.51141271226253, 30.73369506250767, 31.970028019688744, 33.22017603944231, 34.48391382248838, 35.761025609573835, 37.051304541875396, 38.35455207929092, 39.67057747008763, 40.99919726625181, 42.34023487962485, 43.6935201745395, 45.05888909320645, 46.436183310559926, 47.82524991566528, 49.22594111713094, 50.6381139702611, 52.06163012393992, 53.496355585459575, 54.942160501698275, 56.39891895522295, 57.866508774040184, 59.344811353849195, 60.833711491765825, 62.3330972305884, 63.84285971276584, 65.36289304330923, 66.89309416095806, 68.43336271697707, 69.98360096101501, 71.5437136335081, 73.11360786415642, 74.69319307604144, 76.28238089499074, 77.88108506382834, 79.48922136117888, 81.10670752452143, 82.73346317721257, 84.36940975922079, 86.0144704613346, 87.66857016262458, 89.33163537095653, 91.00359416636834, 92.68437614713618, 94.37391237836948, 96.07213534298495, 97.7789788949205, 99.49437821446033, 101.21826976555066, 102.95059125499418, 104.69128159341916, 106.44028085792525, 108.19753025631539, 109.96297209282876, 111.73654973529484, 113.51820758363485, 115.30789103963984, 117.10554647796076, 118.9111212182488, 120.72456349838826, 122.54582244876816, 124.37484806754111, 126.2115911968221, 128.05600349978138, 129.90803743858993, 131.7676462531763, 133.63478394075787, 135.5094052361104], [0.0, 0.2208363110411833, 0.5827905188094897, 1.0281115555471683, 1.5379933997851218, 2.1019795666251677, 2.713202661403029, 3.366725744029695, 4.058788915465935, 4.786411100901326, 5.547157332889777, 6.3389925751018765, 7.160184750502736, 8.009237591981979, 8.884842505299883, 9.785843060783378, 10.711208164229273, 11.660011366589275, 12.631414623700994, 13.62465535130505, 14.639035966099863, 15.673915333378137, 16.728701698355135, 17.80284678728256, 18.895840841767605, 20.007208405531482, 21.13650472375974, 22.2833126456192, 23.447239943428915, 24.627916979432655, 25.8249946645714, 27.03814266412002, 28.267047813271475, 29.51141271226253, 30.77095447583283, 32.04540361599138, 33.33450304045177, 34.63800715185967, 35.95568103520252, 37.28729972266125, 38.63264752671538, 39.991517433607065, 41.36371055035404, 42.74903559941449, 44.147308455879106, 45.55835172272107, 46.9819943401943, 48.41807122594777, 49.8664229428358, 51.32689539175689, 52.79933952716147, 54.28361109313306, 55.77957037817926, 57.2870819870705, 58.80601462824042, 60.33624091541699, 61.87763718228929, 63.43008330913488, 64.99346256043896, 66.5676614326298, 68.15256951113952, 69.74807933607161, 71.35408627582493, 72.97048840808087, 74.59718640761471, 76.23408344043888, 77.88108506382834, 79.53809913181695, 81.20503570578805, 82.88180696981317, 84.56832715042188, 86.26451244051012, 87.97028092711842, 89.68555252283204, 91.41024890057385, 93.14429343157865, 94.8876111263533, 96.64012857844114, 98.40177391082294, 100.17247672479847, 101.95216805120367, 103.74078030382896, 105.53824723491329, 107.34450389259692, 109.15948658022478, 110.98313281739793, 112.815381302679, 114.65617187786252, 116.50544549372714, 118.36314417719275, 120.22921099980874, 122.10359004750582, 123.98622639154743, 125.87706606062012, 127.77605601400708, 129.68314411579112, 131.5982791100376, 133.52141059690956, 135.45248900967206, 137.39146559254226, 139.33829237934708, 141.29292217295065], [0.0, 0.2299827496719143, 0.6069281150667865, 1.0706931364657335, 1.6016928982022125, 2.1890378362482386, 2.8255761271535547, 3.506166356214741, 4.226892899613167, 4.984651214537708, 5.77690548382146, 6.601536385471976, 7.456740104540307, 8.340958402606939, 9.25282848702225, 10.191146031945255, 11.154837238058704, 12.142937285317588, 13.154573420052444, 14.1889514738405, 15.245344971379463, 16.323086223908373, 17.421558967770743, 18.540192221212674, 19.67845511303687, 20.83585249486022, 22.011921191335, 23.206226774376496, 24.418360771301302, 25.64793823496391, 26.89459561798711, 28.157988904081005, 29.437791958005047, 30.73369506250767, 32.04540361599138, 33.372636969006464, 34.71512738120409, 36.07261908325633, 37.444867430610515, 38.83163813789313, 40.23270658439394, 41.64785718240899, 43.0768828013503, 44.51958424148116, 45.975769751939914, 47.44525458839799, 48.92786060628041, 50.423415885974755, 51.931754386882915, 53.45271562753826, 54.98614438933042, 56.53189044165568, 58.0898082865521, 59.6597569210884, 61.24159961595906, 62.83520370889956, 64.44044041167716, 66.0571846295376, 67.68531479209894, 69.32471269478064, 70.97526334994403, 72.63685484699639, 74.30937822078053, 75.99272732763299, 77.6867987285487, 79.39149157894002, 81.10670752452143, 82.83235060289181, 84.5683271504219, 86.3145457140866, 88.07091696791194, 89.83735363373181, 91.61377040597503, 93.40008388022422, 95.196212485308, 97.00207641870642, 98.81759758506574, 100.64269953763375, 102.47730742244082, 104.32134792506425, 106.17474921982502, 108.03744092127683, 109.90935403785673, 111.79042092757585, 113.68057525563712, 115.57975195387361, 117.48788718190936, 119.40491828994983, 121.33078378311573, 123.26542328723987, 125.2087775160502, 127.16078823966896, 129.1213982543609, 131.09055135346776, 133.06819229947064, 135.05426679712468, 137.04872146761394, 139.05150382367754, 141.0625622456613, 143.08184595845063, 145.10930500924417, 147.14489024612928], [0.0, 0.23923433014163062, 0.6313431823006718, 1.1137642090766866, 1.66612464691654, 2.27709687425085, 2.9392413692248076, 3.647209892006043, 4.396929303880141, 5.185170174722992, 6.009294678340455, 6.867098238180848, 7.756704476726175, 8.67649247186369, 9.625044609502256, 10.601108117048048, 11.603565999158002, 12.631414623700996, 13.683746128501317, 14.759734397900678, 15.858623732471372, 16.979719584149684, 18.122380898668467, 19.286013725230912, 20.470065837135422, 21.674022167526235, 22.89740090877121, 24.139750156925423, 25.40064500756046, 26.679685028154196, 27.97649204680728, 29.29070820839019, 30.621994258128733, 31.970028019688744, 33.33450304045177, 34.71512738120409, 36.111622531130905, 37.5237224319999, 38.951172597873494, 40.39372931871483, 41.851158937933484, 43.323237195318555, 44.809748627981904, 46.310486022923236, 47.825249915665275, 49.353848130117626, 50.896095355433616, 52.45181275614243, 54.020827612284315, 55.602972986659765, 57.198087416635886, 58.80601462824042, 60.426603270524154, 62.05970666839142, 63.70518259228863, 65.36289304330921, 67.0327040524201, 68.71448549264537, 70.40811090315724, 72.11345732432645, 73.83040514287435, 75.5588379463495, 77.29864238622281, 79.04970804895994, 80.81192733448601, 82.58519534150993, 84.36940975922077, 86.16447076491104, 87.97028092711842, 89.78674511391141, 91.61377040597502, 93.45126601417992, 95.29914320134385, 97.15731520791658, 99.02569718134036, 100.90420610885695, 102.79276075354892, 104.69128159341915, 106.59969076332644, 108.51791199960824, 110.4458705872339, 112.38349330934199, 114.33070839902666, 116.28744549324581, 118.25363558873394, 120.22921099980873, 122.21410531796953, 124.20825337319097, 126.21159119682206, 128.22405598600704, 130.24558606954847, 132.2761208751389, 134.31560089789244, 136.36396767010984, 138.4211637322171, 140.4871326048193, 142.56181876181594, 144.6451676045264, 146.7371254367782, 148.83763944091203, 150.9466576546612, 153.06412894886526], [0.0, 0.2485892898526275, 0.656031068987916, 1.1573165675416877, 1.7312763704847072, 2.366139903752688, 3.0541767322795788, 3.789829479993547, 4.568865733177511, 5.387929778875453, 6.244280641994173, 7.135627538769135, 8.060020718282827, 9.01577587428758, 10.00141995866362, 11.015651210709374, 12.057308956373852, 13.125350317744836, 14.218831931830024, 15.336895378750006, 16.47875540839472, 17.643690313265804, 18.831033971469584, 20.040169206505094, 21.27052219753523, 22.521557736658075, 23.792775175755743, 25.083704939743907, 26.393905508837122, 27.72296079209957, 29.070477829692056, 30.436084773007128, 31.819429101136336, 33.22017603944231, 34.63800715185967, 36.07261908325633, 37.5237224319999, 38.99104073598316, 40.474309557913756, 41.97327565777821, 43.4876962421369, 45.01733828136348, 46.561977887162634, 48.12139974372848, 49.69539658677446, 51.28376872540415, 52.88632360242166, 54.502875389218424, 56.13324461183637, 57.77725780520527, 59.434747192897625, 61.10555039004266, 62.7895101273013, 64.48647399403144, 66.19629419897042, 67.91882734693678, 69.65393423020572, 71.4014796333484, 73.16133215044435, 74.93336401368153, 76.71745093245343, 78.51347194214506, 80.32130926187467, 82.14084816052456, 83.97197683045329, 85.81458626833574, 87.66857016262456, 89.53382478716992, 91.41024890057385, 93.29774365088946, 95.196212485308, 97.10556106450461, 99.02569718134038, 100.95653068364115, 102.89797340079593, 104.8499390739362, 106.81234328947633, 108.78510341581084, 110.7681385429794, 112.76136942512422, 114.76471842557662, 116.77810946442126, 118.80146796839712, 120.83472082300317, 122.87779632668736, 124.93062414700333, 126.99313527862893, 129.06526200314636, 131.1469378504904, 133.23809756197804, 135.33867705483667, 137.44861338815446, 139.56784473018124, 141.69631032691137, 143.833950471886, 145.98070647715403, 148.13652064533608, 150.30133624273836, 152.4750974734666, 154.6577494544929, 156.84923819163097, 159.0495105563785], [0.0, 0.25804594287199634, 0.6809873259248992, 1.2013423629381703, 1.7971363273879677, 2.456150877589643, 3.1703615028870344, 3.9339994175484625, 4.7426712014515395, 5.592893486047858, 6.481821026062641, 7.407075893400973, 8.36663416613857, 9.358747464874124, 10.38188670486231, 11.434700604767443, 12.515984337020187, 13.62465535130505, 14.759734397900678, 15.920330401542754, 17.10562824020747, 18.314878751724553, 19.547390474075577, 20.802522752579865, 22.079679937525242, 23.37830646101993, 24.69788262965435, 26.03792100511025, 27.397963271627514, 28.777577509641485, 30.17635581062048, 31.59391218036268, 33.02988068761555, 34.48391382248838, 35.95568103520252, 37.444867430610515, 38.951172597873494, 40.474309557913756, 42.01400381390775, 43.56999249226952, 45.14202356338796, 46.7298551328931, 48.333254795493886, 49.95199904449709, 51.58587273101888, 53.23466856766694, 54.898186672124524, 56.57623414662625, 58.26862468979624, 59.97517823773219, 61.695720631577736, 63.43008330913489, 65.17810301833876, 66.93962155065239, 68.71448549264537, 70.50254599420099, 72.30365855195542, 74.11768280671279, 75.94448235370415, 77.78392456466722, 79.63588042082264, 81.50022435590748, 83.37683410850532, 85.26559058298068, 87.16637771838712, 89.07908236477435, 91.00359416636836, 92.93980545114455, 94.88761112635332, 96.84690857959389, 98.81759758506576, 100.79958021465607, 102.79276075354893, 104.7970456200668, 106.81234328947635, 108.83856422151192, 110.87562079138765, 112.92342722408657, 114.98189953173048, 117.05095545384829, 119.13051440037363, 121.22049739721433, 123.32082703424757, 125.43142741560365, 127.55222411211223, 129.68314411579115, 131.82411579626796, 133.97506885903005, 136.1359343054063, 138.30664439419036, 140.48713260481932, 142.67733360202902, 144.87718320191075, 147.0866183392992, 149.30557703642577, 151.53399837277505, 153.77182245608589, 156.0189903944425, 158.27544426940392, 160.54112711012186, 162.81598286840259, 165.09995639466777], [0.0, 0.26760267465562854, 0.7062076923041739, 1.245834078696748, 1.8636932732880553, 2.5471144280954556, 3.2877758447016383, 4.079695090388881, 4.918316034715637, 5.800026302575404, 6.7218752750314605, 7.6813969574192305, 8.676492471863694, 9.705348687730456, 10.766379890618934, 11.858184754487658, 12.979513830976915, 14.129244477519059, 15.306361177878212, 16.509939855816643, 17.739135201265476, 18.993170306832628, 20.271328102203032, 21.57294420604921, 22.897400908771218, 24.244122067019788, 25.612568740539334, 27.00223543873293, 28.412646872115786, 29.84335512498168, 31.293937181905992, 32.763992753391214, 34.25314235592047, 35.761025609573835, 37.28729972266125, 38.83163813789313, 40.39372931871483, 41.97327565777821, 43.56999249226952, 45.18360721307927, 46.81385845667943, 48.46049537014176, 50.123276941044985, 51.801971385125256, 53.496355585459575, 55.206214577766815, 56.931341077088426, 58.671535041690056, 60.42660327052416, 62.196359031021615, 63.98062171435261, 65.77921651561797, 67.59197413671241, 69.4187305098456, 71.2593265399206, 73.11360786415642, 74.98142462750702, 76.86263127257355, 78.75708634283626, 80.66465229814507, 82.58519534150996, 84.51858525632129, 86.46469525321099, 88.42340182583656, 90.3945846149343, 92.37812628004535, 94.37391237836948, 96.3818312502486, 98.40177391082295, 100.43363394744141, 102.47730742244083, 104.53269278094058, 106.59969076332645, 108.67820432212336, 110.76813854297941, 112.86940056950509, 114.98189953173048, 117.10554647796077, 119.24025430982661, 121.38593772034025, 123.54251313478213, 125.7098986542545, 127.88801400175053, 130.07678047059693, 132.27612087513893, 134.48595950354365, 136.70622207260777, 138.93683568446127, 141.17772878506725, 143.42883112442362, 145.6900737183784, 147.96138881197578, 150.242709844256, 152.53397141443526, 154.83510924939822, 157.14606017243807, 159.4667620731838, 161.79715387865738, 164.13717552540834, 166.48676793267296, 168.8458729765126, 171.21443346488422], [0.0, 0.27725793726205855, 0.7316880830837222, 1.2907845083190845, 1.9309364276944525, 2.639015821545789, 3.4064007396602656, 4.226892899613167, 5.095771783084767, 6.0092946783404555, 6.964404506368995, 7.958546297961352, 8.98954544648872, 10.05552340249218, 11.154837238058704, 12.28603506647532, 13.447822358547294, 14.639035966099865, 15.858623732471374, 17.10562824020747, 18.379173679952565, 19.678455113036865, 21.002729596824672, 22.35130877871768, 23.72355266178863, 25.11886431509581, 26.5366853531008, 27.976492046807287, 29.43779195800505, 30.920121009924554, 32.423040924494735, 33.94613696953651, 35.48901596954351, 37.051304541875396, 38.63264752671538, 40.23270658439394, 41.851158937933484, 43.4876962421369, 45.14202356338796, 46.81385845667943, 48.502930128332764, 50.208978674497864, 51.93175438688291, 53.671017118310864, 55.42653570166832, 57.19808741663589, 58.98545749929125, 60.78843869027608, 62.6068308177349, 64.44044041167716, 66.28908034679976, 68.15256951113952, 70.03073249821541, 71.92339932057439, 73.83040514287435, 75.75159003283402, 77.68679872854871, 79.63588042082263, 81.59868854930126, 83.5750806113046, 85.5649179823682, 87.56806574759023, 89.58439254296727, 91.61377040597503, 93.65607463471649, 95.71118365501965, 97.7789788949205, 99.85934466601445, 101.95216805120367, 104.05733879840568, 106.17474921982503, 108.30429409642102, 110.44587058723391, 112.59937814325838, 114.76471842557662, 116.94179522748574, 119.13051440037361, 121.33078378311573, 123.54251313478213, 125.76561407045851, 128.00000000000006, 130.24558606954844, 132.50228910565497, 134.77002756186306, 137.04872146761392, 139.33829237934705, 141.63866333367724, 143.94975880253625, 146.27150465017522, 148.60382809193052, 150.9466576546612, 153.29992313877264, 155.6635555817463, 158.03748722309942, 160.42165147070475, 162.81598286840256, 165.2204170648429, 167.63489078349872, 170.05934179379466, 172.49370888329818, 174.93793183092458, 177.39195138110819], [0.0, 0.2870102449994907, 0.7574245774993891, 1.3361867351124683, 1.9988554436485222, 2.7318409167254494, 3.5262179345014157, 4.375570195337374, 5.275011140771377, 6.220666412426097, 7.209371401184612, 8.238481269009489, 9.305744919367749, 10.409217726450759, 11.547198973779526, 12.718185705783803, 13.920837859325964, 15.153951373501908, 16.416437082950953, 17.707303893889257, 19.02564519112592, 20.37062772297081, 21.741482414424667, 23.13749670068291, 24.558008073480828, 26.00239860534799, 27.47009027001844, 28.96054091678214, 30.473240786341467, 32.00770947842857, 33.563493298920946, 35.14016292779443, 36.73731135993483, 38.35455207929092, 39.991517433607065, 41.64785718240899, 43.323237195318555, 45.01733828136348, 46.7298551328931, 48.46049537014176, 50.208978674497864, 51.97503600021857, 53.758408855739226, 55.558848646913894, 57.376116075526234, 59.20998058726258, 61.060219864065694, 62.9266193564089, 64.80897185156512, 66.70707707440448, 68.62074131765351, 70.54977709889258, 72.4940028418697, 74.4532425799704, 76.42732567991224, 78.41608658393451, 80.41936456892957, 82.43700352111877, 84.46885172501412, 86.5147616655273, 88.57458984219845, 90.64819659461091, 92.73544593814628, 94.83620540930933, 96.95034591992184, 99.07774161954566, 101.21826976555066, 103.37181060029285, 105.5382472349133, 107.71746553930804, 109.90935403785673, 112.11380381053007, 114.33070839902668, 116.55996371761704, 118.80146796839713, 121.05512156067662, 123.32082703424756, 125.5984889862977, 127.88801400175053, 130.189310586829, 132.50228910565497, 134.8268617197091, 137.16294232998877, 139.51044652171137, 141.86929151142306, 144.239396096379, 146.62068060607362, 149.01306685580428, 151.4164781021614, 153.8308390003439, 156.25607556320494, 158.69211512194005, 161.1388862883338, 163.59631891848719, 166.06434407795257, 168.54289400820647, 171.03190209439603, 173.5313028342971, 176.0410318084278, 178.5610256512613, 181.09122202348843, 183.63155958528026], [0.0, 0.2968581704571329, 0.7834134085915105, 1.38203411371354, 2.0674403800841117, 2.825576127153554, 3.6472098920060434, 4.52570521619156, 5.45600787314461, 6.434110567099181, 7.456740104540305, 8.52116089747199, 9.625044609502257, 10.766379890618932, 11.94340766918183, 13.154573420052442, 14.398491099707016, 15.673915333378138, 16.979719584149688, 18.314878751724557, 19.678455113036865, 21.069586825777584, 22.487478426365893, 23.93139290039931, 25.400645007560463, 26.894595617987115, 28.41264687211578, 29.954238016904732, 31.518841802142163, 33.10596134401613, 34.71512738120409, 36.345895862808426, 37.997845818513035, 39.67057747008763, 41.36371055035404, 43.0768828013503, 44.809748627981904, 46.561977887162634, 48.333254795493886, 50.123276941044985, 51.93175438688291, 53.758408855739226, 55.602972986659765, 57.46518965571031, 59.34481135384919, 61.24159961595907, 63.15532449578235, 65.08576408214662, 67.0327040524201, 68.99593725961181, 70.97526334994403, 72.97048840808087, 74.98142462750701, 77.00789000382318, 79.04970804895994, 81.10670752452143, 83.17872219265195, 85.26559058298066, 87.36715577434187, 89.48326519009422, 91.61377040597503, 93.75852696952492, 95.91739423020707, 98.09023517942498, 100.27691629971339, 102.47730742244082, 104.69128159341916, 106.9187149458677, 109.15948658022478, 111.4134784503424, 113.68057525563711, 115.96066433880421, 118.25363558873394, 120.55938134829644, 122.87779632668736, 125.2087775160502, 127.55222411211221, 129.9080374385899, 132.2761208751389, 134.65637978863816, 137.04872146761392, 139.45305505962241, 141.86929151142306, 144.29734351178445, 146.73712543677823, 149.1885532974225, 151.65154468954893, 154.1260187457733, 156.61189608945816, 159.1090987905637, 161.61755032328847, 164.1371755254083, 166.66790055922792, 169.20965287406355, 171.76236117018158, 174.325955364121, 176.9003665553332, 179.48552699407486, 182.08137005049613, 184.68783018486565, 187.30484291888126, 189.93234480801559], [0.0, 0.3068003408785195, 0.8096509536340541, 1.4283202532041626, 2.136681676569905, 2.9202083865638393, 3.769359746440072, 4.677277034029842, 5.638736750074961, 6.649597389205637, 7.706476134352672, 8.806545779081489, 9.947400007953174, 11.126960108199231, 12.343408094557516, 13.595137378798825, 14.880715496979503, 16.198855365093827, 17.548392717023244, 18.928268120513955, 20.337512446921732, 21.775234989705517, 23.240613644163336, 24.732886712311377, 26.251346004233127, 27.795330984766974, 29.36422377124661, 30.9574448302737, 32.57444925333364, 34.214723515322355, 35.87778263873864, 37.563167700836516, 39.270443632450515, 40.99919726625181, 42.74903559941449, 44.51958424148116, 46.310486022923236, 48.12139974372848, 49.95199904449709, 51.801971385125256, 53.671017118310864, 55.558848646913894, 57.46518965571031, 59.38977440934731, 61.33234710937997, 63.292661304180676, 65.27047934628933, 67.26557189243663, 69.27771744204404, 71.3067019104955, 73.35231823390193, 75.4143660024478, 77.49265111973077, 79.58698548578485, 81.69718670172318, 83.82307779415086, 85.96448695768788, 88.12124731410836, 90.29319668675045, 92.48017738898048, 94.68203602561209, 96.89862330628311, 99.1297938698853, 101.37540611922417, 103.63532206515897, 105.90940717953963, 108.19753025631537, 110.49956328024415, 112.81538130267901, 115.14486232395127, 117.48788718190936, 119.8443394462073, 122.21410531796953, 124.59707353448734, 126.99313527862893, 129.40218409266927, 131.82411579626793, 134.25882840834302, 136.70622207260774, 139.16619898655347, 141.63866333367721, 144.1235212187675, 146.6206806060736, 149.13005126019618, 151.65154468954893, 154.18507409224853, 156.73055430430276, 159.28790174997235, 161.85703439419186, 164.43787169694204, 167.0303345694717, 169.63434533227502, 172.24982767473517, 174.87670661635065, 177.51490846946598, 180.16436080343294, 182.8249924101329, 185.49673327079464, 188.17951452404697, 190.87326843514677, 193.57792836632885, 196.29342874822507], [0.0, 0.3168354348400403, 0.8361337253692063, 1.4750390016481953, 2.2065701301773566, 3.0157251172900046, 3.892651262746692, 4.830265503293434, 5.823173484888396, 6.867098238180848, 7.958546297961352, 9.094597983053813, 10.272768270148713, 11.490910454121716, 12.747147085458206, 14.03981902623562, 15.367446958226402, 16.728701698355135, 18.12238089866847, 19.547390474075577, 21.002729596824672, 22.487478426365893, 24.00078796787743, 25.541871609091434, 27.109997995996018, 28.704484988067616, 30.32469449239311, 31.970028019688744, 33.639922838095494, 35.333848625680915, 37.05130454187539, 38.791816653086265, 40.55493565952518, 42.34023487962485, 44.147308455879106, 45.975769751939914, 47.825249915665275, 49.69539658677446, 51.58587273101888, 53.496355585459575, 55.42653570166832, 57.376116075526234, 59.34481135384919, 61.33234710937997, 63.33845917679434, 65.36289304330921, 67.4054032882835, 69.46575306688753, 71.5437136335081, 73.63906390106226, 75.75159003283402, 77.88108506382834, 80.02734854896786, 82.19018623574843, 84.36940975922077, 86.56483635738938, 88.77628860531352, 91.00359416636834, 93.24658555927587, 95.50509993965002, 97.7789788949205, 100.06806825160535, 102.37221789399806, 104.69128159341918, 107.02511684725845, 109.37358472710135, 111.73654973529484, 114.1138796693623, 116.50544549372715, 118.91112121824878, 121.33078378311573, 123.76431294967641, 126.21159119682207, 128.67250362256598, 131.1469378504904, 133.63478394075787, 136.13593430540627, 138.65028362766722, 141.17772878506722, 143.7181687760875, 146.2715046501752, 148.83763944091203, 151.4164781021614, 154.00792744702562, 156.61189608945818, 159.2282943883838, 161.85703439419186, 164.49802979747474, 167.1511958798923, 169.81644946705188, 172.49370888329818, 175.18289390831617, 177.88392573545465, 180.5967269316842, 183.32122139910908, 186.05733433795606, 188.8049922109691, 191.56412270914166, 194.33465471872464, 197.1165182894477, 199.90964460389927, 202.71396594801098], [0.0, 0.3269621792026052, 0.8628583639627646, 1.5221844318998512, 2.2770968742508506, 3.112114201250832, 4.017068799094395, 4.984651214537708, 6.0092946783404555, 7.08658551997995, 8.21291861555828, 9.385280964587054, 10.601108117048051, 11.858184754487658, 13.154573420052444, 14.488561946190718, 15.858623732471374, 17.263387112258965, 18.70161130796438, 20.172167265175784, 21.674022167526235, 23.206226774376496, 24.767904955197757, 26.358244955896247, 27.97649204680729, 29.621942284723836, 31.293937181905992, 32.991859120060695, 34.7151273812041, 36.463194693170124, 38.235544207443546, 40.03168684249112, 41.851158937933484, 43.6935201745395, 45.55835172272107, 47.44525458839799, 49.353848130117626, 51.28376872540415, 53.23466856766694, 55.206214577766815, 57.19808741663589, 59.20998058726258, 61.24159961595907, 63.292661304180676, 65.36289304330921, 67.45203218578374, 69.55982546678969, 71.68602847142547, 73.83040514287435, 75.99272732763299, 78.17277435430242, 80.37033264283963, 82.58519534150996, 84.8171619890799, 87.0660382000499, 89.33163537095653, 91.61377040597505, 93.91226546023003, 96.22694769938042, 98.55764907418205, 100.90420610885697, 103.26645970220594, 105.64425494050045, 108.03744092127687, 110.44587058723391, 112.86940056950507, 115.30789103963984, 117.76120556968512, 120.22921099980876, 122.71177731295334, 125.2087775160502, 127.72008752736093, 130.24558606954847, 132.78515456811058, 135.33867705483667, 137.9060400759748, 140.48713260481932, 143.08184595845063, 145.6900737183784, 148.31171165485728, 150.9466576546612, 153.59481165211585, 156.25607556320494, 158.93035322257646, 161.6175503232885, 164.31757435914358, 167.0303345694717, 169.7557418862303, 172.4937088832982, 175.24414972784962, 178.00698013369905, 180.782117316517, 183.56947995082163, 186.36898812865678, 189.1805633198737, 192.00412833393696, 194.83960728318104, 197.68692554744754, 200.54600974003847, 203.4167876749218, 206.29918833513295, 209.19314184231584], [0.0, 0.33717934630838087, 0.8898216296062839, 1.5697508285530062, 2.34825335888464, 3.209363953267973, 4.142597272435993, 5.14041545169549, 6.197077767094606, 7.308032626319853, 8.46956224977292, 9.678559484395372, 10.932379744251019, 12.228738484901493, 13.56563770634284, 14.941311737887219, 16.354186274712312, 17.802846787282565, 19.286013725230916, 20.80252275257987, 22.351308778717684, 23.931392900399313, 25.541871609091434, 27.181907784380407, 28.85072311222514, 30.547591652056706, 32.271834339200915, 34.02281425555052, 35.79993253639688, 37.60262480798992, 39.43035807093217, 41.28262796049232, 43.15895632747278, 45.05888909320645, 46.9819943401943, 48.92786060628041, 50.896095355433616, 52.88632360242166, 54.898186672124524, 56.931341077088426, 58.98545749929125, 61.060219864065694, 63.15532449578235, 65.27047934628933, 67.4054032882835, 69.55982546678969, 71.73348470277853, 73.92612894368253, 76.1375147561989, 78.36740685730713, 80.61557767989771, 82.88180696981318, 85.16588141145591, 87.46759427942469, 89.78674511391144, 92.12313941782585, 94.47658837382323, 96.8469085795939, 99.23392179993559, 101.63745473427136, 104.0573387984057, 106.49340991942202, 108.94550834272779, 111.41347845034244, 113.89716858960438, 116.39643091154588, 118.91112121824881, 121.44109881855385, 123.98622639154745, 126.54636985729859, 129.1213982543609, 131.7111836235939, 134.31560089789247, 136.93452779744658, 139.56784473018126, 142.21543469705398, 144.87718320191075, 147.55297816562395, 150.242709844256, 152.94627075100985, 155.6635555817463, 158.39446114386143, 161.1388862883338, 163.896731844762, 166.66790055922795, 169.4522970348289, 172.2498276747352, 175.0604006276372, 177.88392573545468, 180.7203144831913, 183.56947995082166, 186.43133676710747, 189.30580106524533, 192.19279044025345, 195.09222390801224, 198.00402186587672, 200.92810605478488, 203.8643995227899, 206.81282658994945, 209.77331281450654, 212.74578496030358, 215.73017096537154], [0.0, 0.3474857513979723, 0.9170203957009756, 1.6177326759167896, 2.4200313329350545, 3.3074630964819836, 4.269222126776013, 5.2975401527010915, 6.386500976252154, 7.531413878699162, 8.72844744079478, 9.974399534570491, 11.266544738255261, 12.60252867679777, 13.980292278252275, 15.39801590149187, 16.85407712064706, 18.347018168912363, 19.875520384496625, 21.438383841703168, 23.034510893788273, 24.662892715824263, 26.322598182150475, 28.012764584480852, 29.73258981840909, 31.481325753876725, 33.258272569553824, 35.06277387895202, 36.894212512142175, 38.75200684442288, 40.63560758445068, 42.54449495081085, 44.47817617894047, 46.436183310559926, 48.41807122594777, 50.423415885974755, 52.45181275614243, 54.502875389218424, 56.57623414662625, 58.671535041690056, 60.78843869027608, 62.9266193564089, 65.08576408214662, 67.26557189243663, 69.46575306688753, 71.68602847142547, 73.92612894368253, 76.18579472671694, 78.46477494631282, 80.76282712766238, 83.07971674771758, 85.41521681991402, 87.76910750833487, 90.14117576869923, 92.5312150138368, 94.93902480155471, 97.3644105430158, 99.80718322993688, 102.2671591790827, 104.74415979267776, 107.23801133349141, 109.74854471346617, 112.27559529486476, 114.81900270300378, 117.37861064972492, 119.95426676682943, 122.54582244876815, 125.15313270394016, 127.77605601400708, 130.41445420067865, 133.06819229947064, 135.7371384399746, 138.4211637322171, 141.12014215871778, 143.833950471886, 146.56246809642366, 149.30557703642577, 152.0631617868939, 154.8351092493982, 157.62130865164252, 160.42165147070475, 163.23603135974034, 166.06434407795254, 168.90648742364417, 171.76236117018158, 174.63186700470905, 177.51490846946595, 180.41139090556615, 183.32122139910908, 186.24430872950145, 189.1805633198737, 192.12989718948435, 195.09222390801222, 198.06745855164058, 201.0555176608457, 204.05631919980542, 207.06978251734915, 210.09582830937555, 213.13437858266846, 216.18535662004416, 219.24868694676934, 222.32429529819004], [0.0, 0.35788025022636977, 0.9444516425661557, 1.6661246469165405, 2.492422827416993, 3.4064007396602656, 4.396929303880141, 5.45600787314461, 6.577543275535334, 7.756704476726174, 8.989545446488718, 10.272768270148712, 11.603565999158004, 12.979513830976913, 14.398491099707016, 15.858623732471372, 17.358240771039856, 18.895840841767605, 20.470065837135422, 22.079679937525242, 23.723552661788627, 25.40064500756046, 27.109997995996014, 28.850723112225133, 30.62199425812874, 32.423040924494735, 34.25314235592046, 36.11162253113091, 37.99784581851304, 39.91121319496205, 41.851158937933484, 43.81714771755548, 45.80867202897535, 47.82524991566528, 49.8664229428358, 51.931754386882915, 54.020827612284315, 56.13324461183637, 58.26862468979624, 60.42660327052416, 62.6068308177349, 64.80897185156512, 67.0327040524201, 69.27771744204404, 71.5437136335081, 73.83040514287435, 76.1375147561989, 78.46477494631282, 80.81192733448604, 83.17872219265195, 85.56491798236821, 87.97028092711844, 90.3945846149343, 92.83760962864477, 95.29914320134387, 97.7789788949205, 100.2769162997134, 102.79276075354893, 105.32632307859191, 107.87741933459064, 110.44587058723391, 113.0315026904565, 115.63414608163785, 118.25363558873396, 120.88981024846798, 123.54251313478211, 126.21159119682207, 128.89689510578745, 131.5982791100376, 134.31560089789244, 137.04872146761392, 139.7975050040943, 142.56181876181594, 145.3415329536804, 148.13652064533608, 150.9466576546612, 153.77182245608583, 156.61189608945816, 159.46676207318376, 162.33630632138448, 165.22041706484288, 168.11898477551304, 171.031902094396, 173.95906376258884, 176.90036655533316, 179.8557092188963, 182.82499241013286, 185.80811863858253, 188.80499221096906, 191.81551917797626, 194.839607283181, 197.87716591403404, 200.92810605478482, 203.99234024125195, 207.06978251734913, 210.16034839327943, 213.2639548053173, 216.38052007710178, 219.50996388237033, 222.6522072090633, 225.80717232473748, 228.97478274322665], [0.0, 0.36836173685852236, 0.9721124516217271, 1.7149215928310175, 2.565420140151403, 3.506166356214741, 4.52570521619156, 5.615801752664679, 6.7701843387717675, 7.983880450340079, 9.25282848702225, 10.573633945833967, 11.943407669181832, 13.359653837655605, 14.82018967594666, 16.323086223908373, 17.86662358480021, 19.449256413208033, 21.069586825777588, 22.726342808586143, 24.4183607713013, 26.144571281576408, 27.903987274289467, 29.69569421202024, 31.518841802142166, 33.372636969006464, 35.25633784794805, 37.16924861858887, 39.11071503313279, 41.080120524470686, 43.0768828013503, 45.100450855323245, 47.15030231789088, 49.22594111713094, 51.32689539175689, 53.45271562753826, 55.602972986659765, 57.77725780520527, 59.97517823773219, 62.196359031021615, 64.44044041167716, 66.70707707440448, 68.99593725961181, 71.3067019104955, 73.63906390106226, 75.99272732763299, 78.36740685730713, 80.76282712766238, 83.17872219265195, 85.61483501025045, 88.07091696791196, 90.54672744234544, 93.04203339049853, 95.55660896897759, 98.09023517942498, 100.64269953763375, 103.21379576440616, 105.80332349636272, 108.41108801508604, 111.03689999313892, 113.68057525563712, 116.34193455617907, 119.02080336604634, 121.71701167568695, 124.43039380758111, 127.16078823966899, 129.90803743858993, 132.67198770204755, 135.4524890096721, 138.24939488180274, 141.0625622456613, 143.89185130842895, 146.73712543677823, 149.59825104244607, 152.4750974734666, 155.36753691071038, 158.2754442694039, 161.19869710532706, 164.13717552540834, 167.0907621024575, 170.05934179379463, 173.04280186355018, 176.0410318084278, 179.05392328673423, 182.08137005049613, 185.12326788049265, 188.17951452404697, 191.2500096354281, 194.33465471872464, 197.4333530730617, 200.54600974003847, 203.6725314532732, 206.81282658994942, 209.96680512426175, 213.13437858266846, 216.31546000086146, 219.50996388237036, 222.71780615872208, 225.93890415108322, 229.1731765333133, 232.4205432963651, 235.68092571396926], [0.0, 0.3789291416275995, 1.0000000000000002, 1.764118533787011, 2.6390158215457893, 3.6067497647680344, 4.65553672174608, 5.776905483821461, 6.964404506368996, 8.21291861555828, 9.518269693579395, 10.876965857390777, 12.286035066475323, 13.742909902417521, 15.245344971379467, 16.79135597602662, 18.37917367995257, 20.007208405531486, 21.67402216752624, 23.378306461019932, 25.11886431509581, 26.894595617987115, 28.704484988067616, 30.547591652056703, 32.42304092449474, 34.330016978316195, 36.26775666655813, 38.235544207443546, 40.232706584393945, 42.258609542485296, 44.31265408594167, 46.39427339921878, 48.502930128332764, 50.6381139702611, 52.79933952716147, 54.98614438933042, 57.198087416635886, 59.434747192897625, 61.695720631577736, 63.98062171435261, 66.28908034679976, 68.62074131765351, 70.97526334994403, 73.35231823390193, 75.75159003283402, 78.17277435430242, 80.61557767989771, 83.07971674771758, 85.56491798236821, 88.07091696791196, 90.59745795971199, 93.14429343157865, 95.71118365501967, 98.29789630774222, 100.90420610885695, 103.52989447850044, 106.17474921982505, 108.83856422151192, 111.52113917914455, 114.22227933394082, 116.94179522748574, 119.67950247123323, 122.43522152965929, 125.20877751605022, 128.00000000000006, 130.80872282577283, 133.63478394075787, 136.47802523331274, 139.33829237934708, 142.21543469705395, 145.10930500924417, 148.019759512782, 150.9466576546612, 153.8898620142955, 156.849238191631, 159.82465470071742, 162.81598286840256, 165.8230967378386, 168.84587297651257, 171.88419078853303, 174.93793183092458, 178.00698013369902, 181.0912220234884, 184.19054605053915, 187.30484291888126, 190.4340054194972, 193.57792836632885, 196.7365085349696, 199.90964460389927, 203.0972370981294, 206.29918833513295, 209.51540237294196, 212.74578496030358, 215.99024348879036, 219.24868694676934, 222.5210258751373, 225.8071723247375, 229.10703981537634, 232.4205432963651, 235.7475991085137, 239.08812494750939, 242.442039828617], [0.0, 0.3895814292409045, 1.0281115555471683, 1.8137106499413531, 2.7132026614030287, 3.7081411111250464, 4.786411100901327, 5.939303283220648, 7.160184750502735, 8.443796533423917, 9.785843060783378, 11.18273428727547, 12.631414623700998, 14.129244477519057, 15.673915333378138, 17.263387112258965, 18.895840841767605, 20.56964215596735, 22.2833126456192, 24.03550702169761, 25.824994664571403, 27.65064453662078, 29.51141271226253, 31.4063319716157, 33.33450304045178, 35.29508715753735, 37.28729972266125, 39.3104048323073, 41.36371055035405, 43.446564791984954, 45.55835172272107, 47.69848859295142, 49.8664229428358, 52.06163012393992, 54.28361109313306, 56.53189044165568, 58.80601462824042, 61.10555039004266, 63.43008330913489, 65.77921651561797, 68.15256951113952, 70.54977709889258, 72.97048840808087, 75.4143660024478, 77.88108506382834, 80.37033264283963, 82.88180696981318, 85.41521681991402, 87.97028092711844, 90.54672744234544, 93.14429343157865, 95.76272441028219, 98.40177391082295, 101.06120307996707, 103.74078030382898, 106.44028085792525, 109.1594865802248, 111.89818556529896, 114.65617187786253, 117.43324528416103, 120.22921099980876, 123.04387945281074, 125.87706606062012, 128.7285910201857, 131.59827911003757, 134.48595950354365, 137.3914655925423, 140.31463482062682, 143.25530852541664, 146.21333178920483, 149.1885532974225, 152.18082520440404, 155.19000300597958, 158.21594541845639, 161.25851426358602, 164.3175743591436, 167.39299341477442, 170.48464193278775, 173.59239311360187, 176.7161227655649, 179.85570921889632, 183.01103324351112, 186.18197797050624, 189.3684288171021, 192.570273414849, 195.7874015409171, 199.0197050523046, 202.2670778228063, 205.52941568259638, 208.8066163602898, 212.09857942735172, 215.40520624473618, 218.726399911641, 222.06206521627183, 225.4121085885171, 228.77643805443904, 232.1549631924933, 235.54759509139353, 238.95424630954386, 242.3748308359642, 245.80926405263955, 249.2574626982279], [0.0, 0.4003175970200636, 1.056444472179139, 1.8636932732880556, 2.787973676665338, 3.8103308515226, 4.918316034715637, 6.102979864684538, 7.357506642773011, 8.676492471863693, 10.05552340249218, 11.490910454121716, 12.979513830976915, 14.518621198064942, 16.10586042147787, 17.739135201265473, 19.416576437406214, 21.136504723759742, 22.897400908771214, 24.697882629654355, 26.536685353100804, 28.412646872115783, 30.324694492393114, 32.271834339200915, 34.25314235592047, 36.267756666558135, 38.314871048723454, 40.39372931871483, 42.50362047188823, 44.643874453135204, 46.81385845667942, 49.01297367337236, 51.24065241856817, 53.496355585459575, 55.77957037817926, 58.0898082865521, 60.426603270524154, 62.7895101273013, 65.17810301833876, 67.59197413671241, 70.03073249821541, 72.4940028418697, 74.98142462750701, 77.49265111973077, 80.02734854896786, 82.58519534150996, 85.16588141145591, 87.76910750833487, 90.3945846149343, 93.04203339049853, 95.71118365501967, 98.40177391082295, 101.11355089806788, 103.84626918115246, 106.59969076332644, 109.37358472710136, 112.16772689829052, 114.98189953173048, 117.81589101692767, 120.66949560204328, 123.54251313478213, 126.43474881888396, 129.34601298503685, 132.27612087513893, 135.22489243892986, 138.19215214210087, 141.17772878506722, 144.1814553316583, 147.20316874704187, 150.24270984425598, 153.29992313877264, 156.3746567105641, 159.46676207318376, 162.57609404941294, 165.70251065305766, 168.84587297651257, 172.0060450837373, 175.1828939083162, 178.3762891562978, 181.5861032135302, 184.8122110572313, 188.05449017154814, 191.3128204668795, 194.58708420274925, 197.87716591403407, 201.18295234036003, 204.50433235849746, 207.84119691759264, 211.1934389770856, 214.56095344717477, 217.94363713169432, 221.3413886732826, 224.75410850072453, 228.18169877835885, 231.62406335744902, 235.08110772941995, 238.5527389808712, 242.03886575028022, 245.5393981863172, 249.05424790769302, 252.5833279644716, 256.1265528007771], [0.0, 0.4111366732635635, 1.0849961855602457, 1.9140618800350402, 2.863322100010319, 3.9133097370436305, 5.051239584830148, 6.2679204142883505, 7.556352324108945, 8.910985370197468, 10.327286310667331, 11.80146646573802, 13.330301182785144, 14.911004822621138, 16.54114114149679, 18.218557184373115, 19.9413333364978, 21.707744803710543, 23.516231377514174, 25.36537333506507, 27.253871967484326, 29.180533657701314, 31.144256720524695, 33.14402042053352, 35.17887572734053, 37.247937471691536, 39.35037764204274, 41.48541961789639, 43.652333178832, 45.85043016067634, 48.07906065529735, 50.33760966999155, 52.62549417773616, 54.942160501698275, 57.2870819870705, 59.6597569210884, 62.05970666839142, 64.48647399403144, 66.93962155065239, 69.4187305098456, 71.92339932057439, 74.4532425799704, 77.00789000382318, 79.58698548578485, 82.19018623574843, 84.8171619890799, 87.46759427942469, 90.14117576869923, 92.83760962864477, 95.55660896897759, 98.29789630774222, 101.06120307996707, 103.84626918115246, 106.65284254249686, 109.48067873509463, 112.32954060062771, 115.19919790632584, 118.08942702219424, 121.00001061870509, 123.93073738332265, 126.88140175438936, 129.85180367103604, 132.841748337904, 135.85104600357593, 138.8795117517115, 141.92696530397095, 144.99323083388984, 148.07813679093925, 151.18151573406982, 154.30320417409575, 157.44304242432815, 160.60087445891335, 163.77654777837566, 166.96991328190313, 170.18082514595002, 173.40914070876178, 176.65472036045907, 179.91742743834246, 183.19712812710588, 186.49369136366784, 189.80698874635144, 193.13689444816183, 196.48328513392846, 199.84603988109376, 203.22504010394715, 206.6201694811136, 210.03131388612127, 213.45836132088272, 216.901201851935, 220.3597275492952, 223.83383242779396, 227.32341239076206, 230.82836517594964, 234.3485903035662, 237.88398902633713, 241.4344642814767, 244.99992064448526, 248.5802642846826, 252.17540292239607, 255.7852457877233, 259.4097035807991, 263.0486884334946], [0.0, 0.422037715720971, 1.1137642090766864, 1.9648120835008138, 2.939241369224807, 4.017068799094394, 5.185170174722993, 6.434110567099181, 7.756704476726174, 9.147254806068462, 10.601108117048048, 12.114375275310959, 13.68374612850132, 15.30636117787821, 16.979719584149688, 18.701611307964377, 20.470065837135422, 22.283312645619205, 24.139750156925427, 26.03792100511025, 27.976492046807284, 29.95423801690473, 31.970028019688744, 34.022814255550514, 36.11162253113091, 38.235544207443546, 40.39372931871483, 42.585380652820035, 44.80974862798191, 47.06612683376664, 49.35384813011762, 51.67228121816845, 54.020827612284315, 56.39891895522295, 58.80601462824042, 61.24159961595906, 63.70518259228863, 66.19629419897042, 68.71448549264537, 71.2593265399206, 73.83040514287435, 76.42732567991224, 79.04970804895994, 81.69718670172318, 84.36940975922077, 87.0660382000499, 89.78674511391144, 92.5312150138368, 95.29914320134387, 98.09023517942498, 100.90420610885695, 103.74078030382898, 106.59969076332644, 109.48067873509463, 112.383493309342, 115.30789103963983, 118.25363558873396, 121.22049739721433, 124.20825337319098, 127.21668660130291, 130.24558606954847, 133.2947464125644, 136.36396767010984, 139.45305505962244, 142.5618187618159, 145.69007371837836, 148.83763944091206, 152.0043398303286, 155.19000300597958, 158.39446114386143, 161.61755032328847, 164.85911038147498, 168.11898477551307, 171.3970204512722, 174.69306771878266, 178.00698013369905, 181.33861438446968, 184.68783018486562, 188.05449017154817, 191.43845980637673, 194.83960728318098, 198.25780343873868, 201.69292166772115, 205.1448378413817, 208.61343022978076, 212.0985794273517, 215.60016828162767, 219.11808182495915, 222.6522072090633, 226.2024336422583, 229.7686523292417, 233.3507564132834, 236.94864092071128, 240.56220270757348, 244.19134040837054, 247.83595438675513, 251.49594668810428, 255.17122099387348, 258.86168257764984, 262.5672382628215, 266.2877963817907, 270.0232667366581], [0.0, 0.4330198101692835, 1.1427461300794932, 2.0159396274866164, 3.0157251172900046, 4.1215993358537935, 5.320096572218303, 6.601536385471976, 7.958546297961352, 9.385280964587052, 10.876965857390775, 12.429610640540085, 14.039819026235621, 15.704657107018765, 17.421558967770743, 19.18825706039159, 21.002729596824672, 22.863159979115007, 24.767904955197753, 26.715469236142933, 28.704484988067613, 30.733695062507667, 32.801939136039174, 34.908142143636425, 37.05130454187539, 39.23049404753412, 41.444838577374036, 43.69352017453949, 45.975769751939914, 48.2908625172154, 50.63811397026109, 53.01687638480723, 55.426535701668314, 57.866508774040184, 60.33624091541699, 62.83520370889956, 65.36289304330921, 67.91882734693678, 70.50254599420099, 73.11360786415642, 75.75159003283402, 78.41608658393451, 81.10670752452143, 83.82307779415086, 86.56483635738938, 89.33163537095653, 92.12313941782585, 94.93902480155471, 97.7789788949205, 100.64269953763375, 103.52989447850044, 106.44028085792525, 109.37358472710136, 112.32954060062771, 115.30789103963983, 118.30838626284465, 121.33078378311573, 124.37484806754111, 127.44035021902397, 130.5270676777197, 133.63478394075787, 136.7632882988409, 139.91237558844358, 143.08184595845063, 146.2715046501752, 149.48116178979296, 152.71063219231024, 155.95973517625953, 159.2282943883838, 162.51613763763126, 165.82309673783857, 169.14900735852888, 172.49370888329818, 175.85704427530337, 179.23885994940295, 182.6390056505361, 186.05733433795606, 189.49370207496244, 192.9479679238034, 196.41999384544135, 199.90964460389924, 203.41678767492175, 206.94129315870765, 210.4830336964823, 214.04188439069893, 217.61772272866764, 221.2104285094276, 224.81988377368765, 228.44597273667267, 232.08858172372462, 235.74759910851367, 239.42291525372727, 243.11442245411092, 246.8220148817426, 250.54558853343093, 254.28504118013188, 258.040272318287, 261.81118312298963, 265.5976764028945, 269.39965655678577, 273.21702953172866, 277.0497027827304], [0.0, 0.44408206908283376, 1.1719396063743883, 2.0674403800841126, 3.092767163118155, 4.226892899613167, 5.456007873144611, 6.7701843387717675, 8.161861475826095, 9.625044609502256, 11.154837238058704, 12.747147085458206, 14.39849109970702, 16.10586042147787, 17.86662358480021, 19.678455113036865, 21.53928156797013, 23.44723994342892, 25.40064500756046, 27.397963271627514, 29.43779195800505, 31.518841802142163, 33.639922838095494, 35.799932536396874, 37.99784581851304, 40.23270658439394, 42.503620471888226, 44.80974862798191, 47.15030231789089, 49.52453823314918, 51.93175438688291, 54.371286505506205, 56.84250484260275, 59.344811353849195, 61.87763718228929, 64.44044041167716, 67.0327040524201, 69.65393423020572, 72.30365855195542, 74.98142462750702, 77.68679872854871, 80.41936456892957, 83.17872219265195, 85.96448695768788, 88.77628860531352, 91.61377040597505, 94.47658837382323, 97.3644105430158, 100.2769162997134, 103.21379576440616, 106.17474921982505, 109.1594865802248, 112.16772689829052, 115.19919790632584, 118.25363558873396, 121.33078378311573, 124.43039380758114, 127.55222411211223, 130.69603995203002, 133.861613081804, 137.04872146761394, 140.2571490172197, 143.4866853258299, 146.73712543677823, 150.00826961592176, 153.29992313877264, 156.61189608945818, 159.94400317068235, 163.29606352393142, 166.66790055922792, 170.05934179379463, 173.47021869904134, 176.90036655533316, 180.34962431404236, 183.81783446642268, 187.3048429188813, 190.81049887425482, 194.33465471872464, 197.87716591403407, 201.43789089469362, 205.01669096988329, 208.61343022978073, 212.22797545606394, 215.86019603635248, 219.50996388237033, 223.17715335162364, 226.86164117240492, 230.56330637194372, 234.28203020753753, 238.01769610050755, 241.77018957283147, 245.53939818631716, 249.3252114841884, 253.1275209349612, 256.9462198784983, 260.78120347413346, 264.6323686507665, 268.4996140588334, 272.38284002406357, 276.2819485029386, 280.19684303977465, 284.1274287253531], [0.0, 0.45522363038903285, 1.20134236293817, 2.1193103278827077, 3.170361502887034, 4.332941284933119, 5.592893486047858, 6.940041284404546, 8.366634166138569, 9.866527056233668, 11.43470060476744, 13.066959864715633, 14.75973439790068, 16.50993985581664, 18.314878751724553, 20.17216726517578, 22.07967993752524, 24.035507021697608, 26.037921005110245, 28.08534992537437, 30.176355810620475, 32.30961704997919, 34.483913822488375, 36.698115937352114, 38.951172597873494, 41.24210371643787, 43.569992492269506, 45.93397902639709, 48.333254795493886, 50.76705784225078, 53.23466856766692, 55.73540603221697, 58.26862468979623, 60.833711491765825, 63.43008330913488, 66.0571846295376, 68.71448549264537, 71.4014796333484, 74.11768280671279, 76.86263127257355, 79.63588042082263, 82.43700352111877, 85.26559058298066, 88.12124731410836, 91.00359416636834, 93.91226546023003, 96.8469085795939, 99.80718322993688, 102.79276075354893, 105.80332349636272, 108.83856422151192, 111.89818556529896, 114.98189953173048, 118.08942702219424, 121.22049739721433, 124.37484806754111, 127.55222411211223, 130.7523779206689, 133.97506885903005, 137.22006295522016, 140.48713260481932, 143.77605629405588, 147.08661833929918, 150.41860864173137, 153.77182245608583, 157.14606017243807, 160.54112711012186, 163.9568333229231, 167.39299341477442, 170.8494263652378, 174.325955364121, 177.8224076546252, 181.33861438446968, 184.87441046448268, 188.42963443418583, 192.00412833393696, 195.5977375832273, 199.21031086475975, 202.8417000139617, 206.4917599136115, 210.16034839327943, 213.84732613330584, 217.55255657305833, 221.27590582322654, 225.01724258193158, 228.77643805443904, 232.55336587628128, 236.3479020396058, 240.15992482257812, 243.98931472168053, 247.83595438675516, 251.69972855865154, 255.58052400934687, 259.4782294844141, 263.392735647723, 267.3239350282631, 271.2717219689867, 275.2359925775736, 279.2166446790285, 283.21357777002225, 287.22669297489733, 291.25589300326067], [0.0, 0.466443656302999, 1.2309521888432806, 2.1715455705441196, 3.2485023019238373, 4.439736517551199, 5.730743117873608, 7.111094450050778, 8.572848971104921, 10.109710146613189, 11.716534913312216, 13.389024930128805, 15.123521757283097, 16.91686502545684, 18.76629076219045, 20.669356392336663, 22.623884070468424, 24.62791697943266, 26.679685028154204, 28.77757750964149, 30.920121009924557, 33.10596134401614, 35.333848625680915, 37.60262480798992, 39.91121319496206, 42.258609542485296, 44.643874453135204, 47.066126833766646, 49.52453823314919, 52.01832791379581, 54.54675854054504, 57.10913239056194, 59.70478800678391, 62.3330972305884, 64.99346256043896, 67.68531479209894, 70.40811090315724, 73.16133215044435, 75.94448235370415, 78.75708634283626, 81.59868854930126, 84.46885172501412, 87.36715577434187, 90.29319668675045, 93.24658555927587, 96.22694769938042, 99.23392179993559, 102.2671591790827, 105.32632307859191, 108.41108801508604, 111.52113917914455, 114.65617187786253, 117.81589101692767, 121.00001061870509, 124.20825337319098, 127.44035021902397, 130.69603995203002, 133.97506885903005, 137.2771903748641, 140.60216476078304, 143.94975880253625, 147.31974552663934, 150.71190393344602, 154.12601874577334, 157.56188017193998, 161.01928368217904, 164.49802979747477, 167.99792388995476, 171.51877599404227, 175.0604006276372, 178.62261662265632, 182.205246964315, 185.80811863858253, 189.43106248728745, 193.07391307038924, 196.7365085349696, 200.41869049053017, 204.12030389021345, 207.84119691759264, 211.58122087870075, 215.3402300989932, 219.11808182495912, 222.91463613011754, 226.72975582515022, 230.56330637194372, 234.4151558013232, 238.28517463428022, 242.17323580650555, 246.07921459605208, 250.00298855396508, 253.94443743772405, 257.9034431473535, 261.87988966406755, 265.8736629913196, 269.88465109814086, 273.9127438646525, 277.9578330296475, 282.0198121401421, 286.0985765028051, 290.19402313717313, 294.3060507305724, 298.43455959466587], [0.0, 0.477741332234789, 1.2607669343739714, 2.2241423157149547, 3.3271838870946913, 4.547270843980637, 5.869546760541254, 7.283331417005766, 8.780490919235108, 10.354576225200333, 12.000319702118771, 13.713318899312922, 15.489826766371202, 17.326606387048628, 19.220826843039728, 21.169986397877143, 23.171854456800578, 25.224426806823075, 27.325890483705546, 29.4745957677153, 31.669033557499084, 33.90781686851725, 36.18966554118968, 38.51339347967144, 40.87789790945704, 43.28215026275809, 45.72518838911765, 48.20610985453905, 50.724066141973836, 53.278257603785825, 55.86792904590691, 58.49236584604094, 61.15089052605302, 63.84285971276584, 66.5676614326298, 69.32471269478064, 72.11345732432645, 74.93336401368153, 77.78392456466722, 80.66465229814507, 83.5750806113046, 86.5147616655273, 89.48326519009422, 92.48017738898048, 95.50509993965002, 98.55764907418205, 101.63745473427136, 104.74415979267776, 107.87741933459064, 111.03689999313892, 114.22227933394082, 117.43324528416103, 120.66949560204328, 123.93073738332265, 127.21668660130291, 130.5270676777197, 133.861613081804, 137.22006295522016, 140.60216476078304, 144.00767295305997, 147.43634866914587, 150.88795943805883, 154.36227890734656, 157.85908658562326, 161.3781675998684, 164.91931246642412, 168.4823168747173, 172.06698148281717, 175.6731117240135, 179.3005176236664, 182.94901362564232, 186.61841842770264, 190.30855482526454, 194.01924956299678, 197.7503331937554, 201.501639944402, 205.2730075880809, 209.0642773225632, 212.8752936542947, 216.70590428780957, 220.55596002019752, 224.4253146403321, 228.31382483258966, 232.22135008480603, 236.14775260023617, 240.09289721329569, 244.0566513088806, 248.03888474507224, 252.03946977904815, 256.0582809960322, 260.0951952411241, 264.1500915538631, 268.22285110538604, 272.3133571380498, 276.4214949073969, 280.54715162634795, 284.6902164115143, 288.8505802315274, 293.0281358572911, 297.2227778140647, 301.43440233529236, 305.66290731809767], [0.0, 0.48911586576355365, 1.2907845083190843, 2.2770968742508506, 3.4064007396602656, 4.65553672174608, 6.009294678340456, 7.456740104540306, 8.989545446488718, 10.60110811704805, 12.28603506647532, 14.039819026235621, 15.858623732471376, 17.739135201265473, 19.67845511303687, 21.674022167526235, 23.723552661788627, 25.824994664571406, 27.976492046807287, 30.176355810620482, 32.423040924494735, 34.71512738120409, 37.05130454187539, 39.43035807093217, 41.85115893793349, 44.31265408594168, 46.81385845667942, 49.353848130117626, 51.931754386882915, 54.54675854054504, 57.198087416635886, 59.88500937843178, 62.6068308177349, 65.36289304330923, 68.15256951113952, 70.97526334994403, 73.83040514287435, 76.71745093245343, 79.63588042082264, 82.58519534150996, 85.5649179823682, 88.57458984219845, 91.61377040597503, 94.68203602561209, 97.7789788949205, 100.90420610885697, 104.0573387984057, 107.23801133349141, 110.44587058723391, 113.68057525563712, 116.94179522748574, 120.22921099980876, 123.54251313478213, 126.88140175438936, 130.24558606954847, 133.63478394075787, 137.04872146761394, 140.48713260481932, 143.94975880253625, 147.43634866914587, 150.9466576546612, 154.4804477532034, 158.03748722309942, 161.6175503232885, 165.22041706484288, 168.84587297651257, 172.49370888329818, 176.16372069714114, 179.85570921889632, 183.56947995082163, 187.30484291888126, 191.06161250421542, 194.83960728318098, 198.63864987541413, 202.45856679940735, 206.29918833513295, 210.16034839327943, 214.04188439069893, 217.94363713169432, 221.86545069480027, 225.80717232473745, 229.76865232924166, 233.7497439804906, 237.75030342086885, 241.77018957283147, 245.80926405263952, 249.86739108775868, 253.94443743772405, 258.04027231828695, 262.1547673286734, 266.2877963817907, 270.43923563723297, 274.60896343694304, 278.79686024339753, 283.00280858019045, 287.22669297489733, 291.46839990410905, 295.7278177405314, 300.00483670205307, 304.2993488026874, 308.6112478053027, 312.94042917605725], [0.0, 0.5005664856734657, 1.3210028754278496, 2.330405655728203, 3.4861474885615755, 4.764526810207293, 6.149977396086516, 7.631308755203062, 9.199998378556115, 10.8492891068074, 12.573661634316135, 14.36850317354376, 16.22988765042129, 18.15442349783941, 20.139144544081777, 22.181429526663766, 24.27894127920519, 26.429579832991326, 28.631445605389107, 30.882810057640796, 33.18209198772356, 35.52783814483021, 37.918707206912856, 40.35345640976267, 42.83093029137239, 45.35005114184258, 47.90981084184084, 50.50926384158158, 53.14752108422937, 55.82374471720583, 58.537143465368594, 61.286968563753796, 64.07251016620364, 66.89309416095806, 69.74807933607161, 72.63685484699639, 75.5588379463495, 78.51347194214506, 81.50022435590748, 84.51858525632129, 87.56806574759023, 90.64819659461091, 93.75852696952492, 96.89862330628311, 100.06806825160535, 103.26645970220594, 106.49340991942202, 109.74854471346617, 113.0315026904565, 116.34193455617907, 119.67950247123323, 123.04387945281074, 126.43474881888396, 129.85180367103604, 133.2947464125644, 136.7632882988409, 140.2571490172197, 143.77605629405588, 147.31974552663934, 150.88795943805883, 154.4804477532034, 158.0969668942735, 161.73727969432565, 165.4011551275082, 169.0883680547648, 172.79869898389046, 176.53193384292052, 180.28786376592072, 184.06628489032389, 187.86699816502983, 191.68980916854838, 195.5345279365238, 199.40096879803065, 203.28895022007933, 207.19829465981218, 211.12882842391085, 215.08038153477125, 219.0527876030352, 223.04588370609852, 227.0595102722412, 231.09351097005248, 235.14773260284443, 239.22202500777126, 243.31624095938793, 247.4302360774038, 251.56386873839844, 255.71699999128666, 259.8894934763305, 264.08121534751035, 268.2920341980806, 272.52182098914204, 276.7704489810792, 281.0377936677159, 285.3237327130534, 289.6281458904627, 293.95091502421127, 298.2919239332101, 302.6510583768749, 307.0282060030013, 311.4232562975585, 315.8361005363128, 320.2666317381962], [0.0, 0.5120924410467451, 1.3514200540163648, 2.3840651642217123, 3.566418904103451, 4.874233961926327, 6.291585687977257, 7.807025920993431, 9.411835914189, 11.099102919069777, 12.863180543439391, 14.699349786529197, 16.60359417318303, 18.57244404266712, 20.60286492471975, 22.6921752001299, 24.837983887337643, 27.03814266412002, 29.29070820839019, 31.59391218036268, 33.94613696953651, 36.345895862808426, 38.791816653086265, 41.28262796049231, 43.81714771755548, 46.39427339921878, 49.01297367337235, 51.67228121816845, 54.371286505506205, 57.10913239056193, 59.885009378431775, 62.69815146322223, 65.54783245398342, 68.43336271697707, 71.35408627582493, 74.30937822078053, 77.29864238622281, 80.32130926187467, 83.37683410850532, 86.46469525321099, 89.58439254296727, 92.73544593814628, 95.91739423020707, 99.1297938698853, 102.37221789399806, 105.64425494050045, 108.94550834272779, 112.27559529486476, 115.63414608163785, 119.02080336604634, 122.43522152965929, 125.87706606062012, 129.34601298503685, 132.841748337904, 136.36396767010984, 139.91237558844358, 143.4866853258299, 147.08661833929918, 150.71190393344602, 154.36227890734656, 158.03748722309942, 161.73727969432565, 165.46141369311772, 169.20965287406355, 172.98176691409475, 176.77753126701757, 180.5967269316842, 184.43914023285026, 188.30456261384523, 192.19279044025342, 196.10362481386989, 200.03687139625316, 203.99234024125192, 207.9698456359301, 211.96920594935958, 215.99024348879036, 220.03278436274405, 224.09665835061065, 228.18169877835885, 232.28774239999842, 236.41462928445918, 240.56220270757345, 244.73030904887216, 248.9187976929233, 253.1275209349612, 257.35633389056954, 261.6050944092001, 265.8736629913196, 270.16190270899375, 274.46967912972843, 278.79686024339753, 283.14331639210155, 287.5089202028073, 291.8935465226288, 296.29707235662, 300.7193768079549, 305.1603410203793, 309.61984812282526, 314.0977831760865, 318.5940331214558, 323.10848673123445, 327.6410345610272], [0.0, 0.5236930004095318, 1.38203411371354, 2.4380719943279607, 3.6472098920060434, 4.984651214537708, 6.434110567099182, 7.98388045034008, 9.625044609502256, 11.35053369985452, 13.154573420052444, 15.032337868611494, 16.97971958414969, 18.993170306832628, 21.069586825777588, 23.206226774376496, 25.400645007560463, 27.650644536620785, 29.954238016904736, 32.309617049979195, 34.7151273812041, 37.16924861858887, 39.67057747008763, 42.21781375493331, 44.80974862798191, 47.44525458839799, 50.123276941044985, 52.84282645108911, 55.60297298665977, 58.40283998581519, 61.24159961595907, 64.11846851867298, 67.03270405242012, 69.98360096101501, 72.97048840808087, 75.99272732763299, 79.04970804895994, 82.14084816052456, 85.26559058298068, 88.42340182583656, 91.61377040597503, 94.83620540930933, 98.09023517942498, 101.37540611922417, 104.69128159341918, 108.03744092127687, 111.41347845034244, 114.81900270300378, 118.25363558873396, 121.71701167568695, 125.20877751605022, 128.7285910201857, 132.27612087513893, 135.85104600357593, 139.45305505962244, 143.08184595845063, 146.73712543677823, 150.41860864173137, 154.12601874577334, 157.85908658562326, 161.6175503232885, 165.4011551275082, 169.20965287406355, 173.04280186355024, 176.90036655533316, 180.78211731651703, 184.68783018486567, 188.61728664469547, 192.570273414849, 196.54658224792874, 200.54600974003847, 204.56835715033898, 208.6134302297808, 212.6810390584258, 216.7709978908146, 220.88312500887852, 225.01724258193158, 229.1731765333133, 233.35075641328345, 237.5498152777992, 241.77018957283147, 246.01171902390035, 250.27424653053365, 254.5576180653698, 258.86168257764984, 263.1862919008542, 267.53130066426235, 271.89656620822296, 276.2819485029386, 280.6873100705819, 285.11251591056805, 289.5574334278245, 294.02193236390445, 298.505884730802, 303.00916474733566, 307.53164877797303, 312.07321527397914, 316.6337447167763, 321.21311956341134, 325.8112241940296, 330.42794486126314, 335.06316964144537], [0.0, 0.5353674509267319, 1.412843173336284, 2.492422827416993, 3.7285154877974134, 5.095771783084766, 6.577543275535334, 8.161861475826095, 9.839611363175889, 11.603565999158, 13.447822358547292, 15.3674469582264, 17.358240771039856, 19.41657643740621, 21.539281567970125, 23.723552661788624, 25.966890065282893, 28.26704781327148, 30.621994258128733, 33.02988068761555, 35.48901596954351, 37.997845818513035, 40.55493565952518, 43.15895632747277, 45.80867202897535, 48.50293012833276, 51.24065241856815, 54.020827612284315, 56.84250484260274, 59.70478800678389, 62.60683081773489, 65.54783245398342, 68.52703371862171, 71.5437136335081, 74.59718640761471, 77.6867987285487, 80.81192733448601, 83.97197683045329, 87.16637771838712, 90.3945846149343, 93.65607463471649, 96.95034591992184, 100.27691629971339, 103.63532206515897, 107.02511684725845, 110.44587058723391, 113.89716858960438, 117.37861064972492, 120.88981024846798, 124.43039380758111, 128.00000000000006, 131.59827911003757, 135.22489243892986, 138.8795117517115, 142.5618187618159, 146.2715046501752, 150.00826961592176, 153.77182245608583, 157.56188017193998, 161.3781675998684, 165.22041706484288, 169.0883680547648, 172.98176691409475, 176.90036655533316, 180.84392618704445, 184.8122110572313, 188.80499221096903, 192.822046261303, 196.86315517249568, 200.9281060547848, 205.01669096988326, 209.12870674651256, 213.2639548053172, 217.42224099256012, 221.6033754220426, 225.80717232473745, 230.03344990565992, 234.28203020753747, 238.55273898087114, 242.84540556001028, 247.15986274489, 251.49594668810417, 255.85349678701093, 260.2323555805867, 264.6323686507664, 269.0533845280215, 273.49525460094793, 277.95783302964736, 282.44097666270176, 286.9445449575528, 291.46839990410894, 296.01240595141576, 300.57642993723397, 305.16034102037924, 309.7640106156871, 314.38731233147433, 319.0301219093753, 323.69231716643867, 328.3737779393797, 333.07438603088264, 337.79402515786114, 342.532580901585], [0.0, 0.5471150976423076, 1.443845398884619, 2.5471144280954556, 3.8103308515226, 5.207589052788507, 6.7218752750314605, 8.340958402606939, 10.05552340249218, 11.858184754487656, 13.74290990241752, 15.704657107018766, 17.739135201265476, 19.8426372298914, 22.011921191335002, 24.24412206701978, 26.5366853531008, 28.887315800852303, 31.29393718190599, 33.75466021745818, 36.26775666655813, 38.83163813789312, 41.44483857737404, 44.105999653828256, 46.81385845667943, 49.56723705777268, 52.36503359087691, 55.2062145777668, 58.0898082865521, 61.014898951179035, 63.980621714352594, 66.9861581820571, 70.03073249821541, 73.11360786415642, 76.23408344043888, 79.39149157894002, 82.58519534150993, 85.81458626833574, 89.07908236477435, 92.37812628004535, 95.71118365501965, 99.07774161954566, 102.47730742244082, 105.90940717953963, 109.37358472710135, 112.86940056950507, 116.39643091154588, 119.95426676682943, 123.54251313478211, 127.16078823966899, 130.80872282577283, 134.48595950354365, 138.19215214210087, 141.92696530397095, 145.69007371837836, 149.48116178979296, 153.29992313877264, 157.14606017243807, 161.01928368217904, 164.91931246642412, 168.84587297651257, 172.79869898389046, 176.77753126701757, 180.78211731651703, 184.8122110572313, 188.86757258596552, 192.9479679238034, 197.0531687819775, 201.18295234036003, 205.33710103771733, 209.51540237294196, 213.7176487165381, 217.94363713169432, 222.19316920432942, 226.46605088154402, 230.7620923179538, 235.08110772941995, 239.42291525372727, 243.78733681779445, 248.1741980110294, 252.58332796447155, 257.014559235387, 261.4677276970067, 265.94267243311646, 270.43923563723297, 274.9572625161096, 279.4966011973402, 284.05710264084036, 288.6386205539993, 293.2410113103126, 297.86413387131313, 302.5078497116318, 307.17202274703084, 311.85651926525844, 316.56120785958706, 321.28595936490217, 326.0306467962185, 330.79514528950625, 335.5793320447201, 340.3830862709232, 345.20628913341227, 350.04882370275016], [0.0, 0.5589352627617817, 1.475039001648195, 2.6021436408662697, 3.8926512627466914, 5.320096572218303, 6.867098238180849, 8.52116089747199, 10.272768270148712, 12.11437527531096, 14.03981902623562, 16.043948859247195, 18.12238089866847, 20.27132810220303, 22.487478426365893, 24.767904955197753, 27.109997995996014, 29.511412712262533, 31.970028019688744, 34.48391382248838, 37.05130454187539, 39.67057747008763, 42.34023487962485, 45.058889093206446, 47.82524991566528, 50.638113970261095, 53.49635558545956, 56.398918955222946, 59.344811353849195, 62.333097230588386, 65.36289304330921, 68.43336271697707, 71.5437136335081, 74.69319307604144, 77.88108506382834, 81.10670752452143, 84.36940975922077, 87.66857016262456, 91.00359416636836, 94.37391237836948, 97.7789788949205, 101.21826976555066, 104.69128159341916, 108.19753025631537, 111.73654973529484, 115.30789103963984, 118.91112121824881, 122.54582244876815, 126.21159119682207, 129.90803743858993, 133.63478394075787, 137.3914655925423, 141.17772878506722, 144.99323083388984, 148.83763944091206, 152.71063219231024, 156.61189608945818, 160.54112711012186, 164.49802979747477, 168.4823168747173, 172.49370888329818, 176.53193384292052, 180.5967269316842, 184.68783018486567, 188.80499221096903, 192.9479679238034, 197.1165182894477, 201.31041008706276, 205.52941568259638, 209.7733128145065, 214.04188439069893, 218.33491829593987, 222.6522072090633, 226.99354842934488, 231.3587437114633, 235.7475991085137, 240.1599248225781, 244.59553506239345, 249.05424790769302, 253.5358851798256, 258.04027231828695, 262.56723826282143, 267.1166153407779, 271.6882391594231, 276.2819485029386, 280.89758523384205, 285.5349941985955, 290.19402313717313, 294.874522596381, 299.5763458467315, 304.2993488026874, 309.0433899461041, 313.8083302527077, 318.5940331214558, 323.40036430664026, 328.2271918525947, 333.0743860308827, 337.9418192798459, 342.82936614640147, 347.7369032299809, 352.6643091285131, 357.6114643863551], [0.0, 0.5708272849740063, 1.5064222364164293, 2.657507386971101, 3.9754721158313475, 5.433288046836291, 7.013204040091542, 8.702458878504657, 10.491333811793039, 12.372123228355427, 14.33853311861659, 16.385303232315756, 18.507956421530427, 20.70262507006929, 22.965926666725416, 25.29487202187039, 27.686795918440115, 30.139303630710316, 32.65022894574413, 35.21760070263829, 37.83961575778746, 40.51461687836364, 43.24107447090663, 46.017571333627096, 48.842789820898766, 51.715500952689055, 54.63455510744335, 57.59887401557635, 60.607443829948714, 63.659309094839344, 66.75356746969187, 69.88936509096641, 73.06589247667283, 76.28238089499074, 79.53809913181695, 82.83235060289181, 86.16447076491104, 89.53382478716992, 92.93980545114455, 96.3818312502486, 99.85934466601445, 103.37181060029285, 106.9187149458677, 110.49956328024415, 114.1138796693623, 117.76120556968512, 121.44109881855385, 125.15313270394016, 128.89689510578745, 132.67198770204755, 136.47802523331274, 140.31463482062682, 144.1814553316583, 148.07813679093925, 152.0043398303286, 155.95973517625953, 159.94400317068235, 163.9568333229231, 167.99792388995476, 172.06698148281717, 176.16372069714114, 180.28786376592072, 184.43914023285026, 188.61728664469547, 192.822046261303, 197.0531687819775, 201.31041008706276, 205.5935319936648, 209.9023020245423, 214.23649318927065, 218.59588377685932, 222.98025715906707, 227.38940160371982, 231.8231100973907, 236.28118017684992, 240.76341376873827, 245.26961703695798, 249.79960023731266, 254.35317757896235, 258.9301670922901, 263.5303905028062, 268.1536731107417, 272.79984367600747, 277.4687343082165, 282.16018036148904, 286.8740203337773, 291.6100957704644, 296.3682511720088, 301.1483339054194, 305.9501941193618, 310.7736846627051, 315.61866100633523, 320.48498116806917, 325.3725056405126, 330.28109732171777, 335.2106214485024, 340.16094553230107, 345.13193929742704, 350.12347462163183, 355.13542547885095, 360.1676678840377, 365.22007983998617], [0.0, 0.5827905188094897, 1.537993399785122, 2.713202661403029, 4.058788915465935, 5.547157332889777, 7.160184750502736, 8.884842505299883, 10.711208164229275, 12.631414623700996, 14.639035966099863, 16.728701698355135, 18.895840841767605, 21.13650472375974, 23.447239943428915, 25.824994664571403, 28.26704781327148, 30.770954475832834, 33.33450304045177, 35.955681035202524, 38.63264752671538, 41.36371055035404, 44.147308455879106, 46.98199434019429, 49.866422942835804, 52.79933952716148, 55.77957037817925, 58.806014628240426, 61.8776371822893, 64.99346256043894, 68.1525695111395, 71.35408627582494, 74.59718640761471, 77.88108506382834, 81.20503570578805, 84.5683271504219, 87.97028092711842, 91.41024890057385, 94.88761112635332, 98.40177391082295, 101.95216805120367, 105.5382472349133, 109.15948658022478, 112.81538130267901, 116.50544549372715, 120.22921099980876, 123.98622639154745, 127.77605601400708, 131.5982791100376, 135.4524890096721, 139.33829237934708, 143.25530852541664, 147.20316874704187, 151.18151573406982, 155.19000300597958, 159.2282943883838, 163.29606352393142, 167.39299341477442, 171.51877599404227, 175.6731117240135, 179.85570921889632, 184.06628489032389, 188.30456261384523, 192.570273414849, 196.86315517249568, 201.18295234036003, 205.52941568259638, 209.9023020245423, 214.30137401676535, 218.72639991164098, 223.17715335162364, 227.65341316843973, 232.15496319249326, 236.6815920718296, 241.2330931000529, 245.80926405263955, 250.4099070311306, 255.0348283147255, 259.6838382188334, 264.3567509601704, 269.0533845280216, 273.7735605613104, 278.51710423114724, 283.2838441285468, 288.07361215702844, 292.8862434298308, 297.7215761714909, 302.57945162355253, 307.45971395418644, 312.362210171517, 317.2867900404623, 322.23330600290876, 327.20161310105175, 332.191568903741, 337.20303343568565, 342.23586910937547, 347.2899406595879, 352.3651150803559, 357.4612615642817, 362.5782514440829, 367.71595813626993, 372.8742570868546], [0.0, 0.5948243340328034, 1.5697508285530055, 2.7692265300778733, 4.142597272435992, 5.661698431627979, 7.308032626319853, 9.06830216970114, 10.932379744251016, 12.892235801611012, 14.941311737887215, 17.074126166781923, 19.286013725230916, 21.572944206049204, 23.93139290039931, 26.358244955896243, 28.850723112225133, 31.4063319716157, 34.022814255550514, 36.698115937352114, 39.430358070932165, 42.217813754933296, 45.058889093206446, 47.952107306114875, 50.896095355433616, 53.88957259595058, 56.931341077088405, 60.02027719980957, 63.155324495782345, 66.33548734281423, 69.55982546678966, 72.82744910853835, 76.13751475619888, 79.48922136117888, 82.88180696981317, 86.3145457140866, 89.78674511391141, 93.29774365088946, 96.84690857959389, 100.43363394744141, 104.05733879840568, 107.71746553930804, 111.4134784503424, 115.14486232395127, 118.91112121824878, 122.71177731295334, 126.54636985729859, 130.41445420067865, 134.31560089789244, 138.24939488180274, 142.21543469705395, 146.21333178920483, 150.24270984425598, 154.30320417409575, 158.39446114386143, 162.51613763763126, 166.66790055922792, 170.8494263652378, 175.0604006276372, 179.3005176236664, 183.56947995082163, 187.86699816502983, 192.19279044025342, 196.54658224792874, 200.9281060547848, 205.33710103771733, 209.7733128145065, 214.23649318927065, 218.72639991164098, 223.24279644872627, 227.78545176901181, 232.35414013740615, 236.94864092071128, 241.56873840284803, 246.21422160922043, 250.88488413964916, 255.58052400934685, 260.3009434974473, 265.0459490026361, 269.8153509054626, 274.60896343694304, 279.4266045530924, 284.26809581504716, 289.13326227446436, 294.0219323639044, 298.93393779192326, 303.86911344261904, 308.8272972793939, 313.80833025270766, 318.8120562116148, 323.83832181888744, 328.88697646954193, 333.95787221259604, 339.05086367589405, 344.1658079938496, 349.3025647379615, 354.46099584996796, 359.6409655775134, 364.8423404122088, 370.0649890299711, 375.30878223353733, 380.57359289705227], [0.0, 0.6069281150667863, 1.6016928982022125, 2.8255761271535547, 4.226892899613167, 5.77690548382146, 7.456740104540306, 9.25282848702225, 11.154837238058704, 13.154573420052442, 15.245344971379463, 17.421558967770743, 19.67845511303687, 22.011921191335002, 24.4183607713013, 26.89459561798711, 29.437791958005047, 32.04540361599138, 34.71512738120409, 37.444867430610515, 40.23270658439394, 43.076882801350294, 45.975769751939914, 48.927860606280404, 51.931754386882915, 54.98614438933041, 58.08980828655209, 61.24159961595906, 64.44044041167716, 67.68531479209894, 70.97526334994403, 74.30937822078053, 77.6867987285487, 81.10670752452143, 84.56832715042188, 88.07091696791194, 91.61377040597502, 95.196212485308, 98.81759758506576, 102.47730742244083, 106.17474921982503, 109.90935403785673, 113.68057525563711, 117.48788718190936, 121.33078378311573, 125.2087775160502, 129.1213982543609, 133.06819229947064, 137.04872146761392, 141.0625622456613, 145.10930500924417, 149.1885532974225, 153.29992313877264, 157.44304242432815, 161.61755032328847, 165.82309673783857, 170.05934179379463, 174.325955364121, 178.62261662265632, 182.94901362564232, 187.30484291888126, 191.68980916854838, 196.10362481386989, 200.54600974003847, 205.01669096988326, 209.51540237294196, 214.04188439069893, 218.59588377685932, 223.17715335162364, 227.78545176901181, 232.42054329636508, 237.0821976052223, 241.77018957283144, 246.48429909361548, 251.22431089996255, 255.99001439175993, 260.7812034741334, 265.5976764028945, 270.439235637233, 275.30568769922746, 280.19684303977465, 285.112515910568, 290.05252424178144, 295.0166895251361, 300.00483670205307, 305.01679405661025, 310.05239311304547, 315.1114685375597, 320.19385804419363, 325.29940230456475, 330.4279448612631, 335.57933204472005, 340.75341289337325, 345.9500390769621, 351.1690648228005, 356.4103468448781, 361.67374427565517, 366.95911860041974, 372.2663335940878, 377.59525526032854, 382.9457517729089, 388.3176934191537], [0.0, 0.6191012604464526, 1.6338180214571287, 2.882248652487745, 4.3116716081519995, 5.892772764564274, 7.606299795544188, 9.438412287722015, 11.378569591222902, 13.418414442859849, 15.551120558459235, 17.770982836578938, 20.07314550386161, 22.453413865831372, 24.90811935757058, 27.43401999833414, 30.028225177797037, 32.68813765200588, 35.41140801476566, 38.195898407161984, 41.0396531965399, 43.94087500046926, 46.89790487015048, 49.909205753243576, 52.9733485728815, 56.089000416102195, 59.25491443964458, 62.469921186341985, 65.7329210695797, 69.04287783223265, 72.39881282420737, 75.79979997205272, 79.24496133714598, 82.73346317721257, 86.26451244051012, 89.83735363373181, 93.45126601417992, 97.10556106450461, 100.79958021465607, 104.53269278094058, 108.30429409642102, 112.11380381053007, 115.96066433880421, 119.8443394462073, 123.76431294967641, 127.72008752736093, 131.7111836235939, 135.7371384399746, 139.7975050040943, 143.89185130842895, 148.019759512782, 152.18082520440404, 156.3746567105641, 160.60087445891335, 164.85911038147498, 169.14900735852888, 173.47021869904134, 177.8224076546252, 182.205246964315, 186.61841842770264, 191.06161250421542, 195.5345279365238, 200.03687139625316, 204.56835715033898, 209.12870674651256, 213.7176487165381, 218.33491829593987, 222.98025715906707, 227.65341316843973, 232.35414013740615, 237.0821976052223, 241.83735062373347, 246.6193695549051, 251.42802987850678, 256.26311200930843, 261.1244011231949, 266.0116869916512, 270.92476382410945, 275.8634301176874, 280.8274885138806, 285.8167456618032, 290.8310120875985, 295.87010206966943, 300.9338335194, 306.0220278670648, 311.134509952639, 316.2711079212451, 321.4316531229875, 326.6159800169404, 331.8239260790751, 337.05533171391846, 342.3100401697542, 347.5878974571869, 352.88875227089886, 358.21245591444404, 363.5588622279273, 368.9278275184315, 374.3192104930577, 379.73287219445814, 385.16867593874014, 390.6264872556345, 396.1061738308214], [0.0, 0.6313431823006718, 1.66612464691654, 2.9392413692248076, 4.396929303880141, 6.0092946783404555, 7.756704476726175, 9.625044609502256, 11.603565999158002, 13.683746128501317, 15.858623732471372, 18.122380898668467, 20.470065837135426, 22.897400908771214, 25.40064500756046, 27.976492046807284, 30.621994258128737, 33.33450304045177, 36.11162253113091, 38.951172597873494, 41.851158937933484, 44.809748627981904, 47.82524991566528, 50.896095355433616, 54.02082761228432, 57.19808741663589, 60.42660327052415, 63.70518259228864, 67.03270405242012, 70.40811090315724, 73.83040514287434, 77.29864238622282, 80.81192733448603, 84.36940975922079, 87.97028092711842, 91.61377040597503, 95.29914320134385, 99.02569718134038, 102.79276075354893, 106.59969076332645, 110.44587058723391, 114.33070839902668, 118.25363558873394, 122.21410531796953, 126.21159119682207, 130.24558606954847, 134.31560089789247, 138.4211637322171, 142.56181876181594, 146.73712543677823, 150.9466576546612, 155.19000300597958, 159.46676207318376, 163.77654777837566, 168.11898477551307, 172.49370888329818, 176.90036655533316, 181.33861438446968, 185.80811863858253, 190.30855482526454, 194.83960728318098, 199.40096879803065, 203.99234024125192, 208.6134302297808, 213.2639548053172, 217.94363713169432, 222.6522072090633, 227.38940160371982, 232.15496319249326, 236.94864092071128, 241.77018957283144, 246.6193695549051, 251.49594668810423, 256.3996920126031, 261.33038160115944, 266.2877963817907, 271.27172196898664, 276.2819485029386, 281.318270496307, 286.38048668807977, 291.46839990410894, 296.5818169239388, 301.72054835356937, 306.88440850381926, 312.07321527397903, 317.2867900404622, 322.5249575501849, 327.78754581841906, 333.07438603088264, 338.3853124498456, 343.7201623240422, 349.07877580219474, 354.4609958499679, 359.86666817017834, 365.2956411261011, 370.7477656677194, 376.22289526077554, 381.72088581848755, 387.24159563580673, 392.7848853260944, 398.3506177601067, 403.9386580071802], [0.0, 0.6436533058598425, 1.6986112577543753, 2.9965516015037585, 4.482661983869588, 6.126465754337928, 7.90794708644679, 9.81271668980212, 11.829815898073678, 13.950556019407772, 16.167840055856246, 18.475736655573943, 20.869197477080004, 23.34386147455048, 25.89591459673421, 28.52198629384002, 31.219071320990338, 33.98446943387374, 36.81573805457795, 39.7106545419203, 42.66718570762638, 45.683462889464394, 48.75776134877311, 51.888483077467086, 55.074142324977586, 58.31335331826672, 61.60481976731192, 64.94732583712869, 68.33972833418012, 71.78094990591198, 75.26997309135594, 78.80583509124736, 82.38762315005988, 86.0144704613346, 89.68555252283204, 93.40008388022422, 97.15731520791658, 100.95653068364115, 104.7970456200668, 108.67820432212336, 112.59937814325838, 116.55996371761704, 120.55938134829644, 124.59707353448734, 128.67250362256598, 132.78515456811058, 136.93452779744658, 141.12014215871778, 145.3415329536804, 149.59825104244607, 153.8898620142955, 158.21594541845639, 162.57609404941294, 166.96991328190313, 171.3970204512722, 175.85704427530337, 180.34962431404236, 184.87441046448268, 189.43106248728745, 194.01924956299678, 198.63864987541413, 203.28895022007933, 207.9698456359301, 212.6810390584258, 217.42224099256012, 222.19316920432942, 226.99354842934488, 231.8231100973907, 236.6815920718296, 241.56873840284803, 246.48429909361548, 251.42802987850678, 256.3996920126031, 261.3990520717497, 266.4258817625019, 271.4799577413443, 276.5610614426121, 281.6689789145854, 286.80350066326946, 291.96442150340306, 297.1515404162759, 302.3646604139605, 307.6035884095944, 312.86813509337145, 318.15811481392655, 323.4733454648156, 328.8136483758162, 334.1788482087891, 339.5687728578594, 344.9832533536921, 350.4221237716469, 355.88522114361695, 361.37238537336304, 366.8834591551679, 372.4182878956471, 377.97671963856084, 383.55860499248126, 389.16379706117806, 394.79215137659395, 400.4435258342866, 406.1177806312241, 411.8147782058234], [0.0, 0.656031068987916, 1.7312763704847072, 3.054176732279579, 4.568865733177511, 6.244280641994173, 8.060020718282825, 10.00141995866362, 12.057308956373852, 14.218831931830024, 16.47875540839472, 18.831033971469584, 21.270522197535232, 23.792775175755743, 26.393905508837122, 29.07047782969206, 31.819429101136336, 34.63800715185967, 37.52372243199991, 40.47430955791376, 43.4876962421369, 46.561977887162634, 49.69539658677446, 52.88632360242166, 56.13324461183637, 59.434747192897625, 62.78951012730129, 66.19629419897042, 69.65393423020572, 73.16133215044434, 76.71745093245343, 80.32130926187469, 83.97197683045329, 87.66857016262458, 91.41024890057385, 95.196212485308, 99.02569718134036, 102.89797340079593, 106.81234328947635, 110.76813854297941, 114.76471842557662, 118.80146796839713, 122.87779632668736, 126.99313527862893, 131.1469378504904, 135.33867705483667, 139.56784473018126, 143.833950471886, 148.13652064533608, 152.4750974734666, 156.849238191631, 161.25851426358602, 165.70251065305766, 170.18082514595002, 174.69306771878266, 179.23885994940295, 183.81783446642268, 188.42963443418583, 193.07391307038924, 197.7503331937554, 202.45856679940735, 207.19829465981218, 211.96920594935958, 216.7709978908146, 221.6033754220426, 226.46605088154402, 231.3587437114633, 236.28118017684992, 241.2330931000529, 246.21422160922043, 251.22431089996255, 256.26311200930843, 261.33038160115944, 266.4258817625019, 271.54937980969817, 276.70064810422963, 281.8794638773082, 287.08560906281963, 292.31887013809853, 297.57903797207234, 302.8659076803442, 308.17927848681376, 313.5189535914652, 318.88474004397375, 324.2764486228089, 329.6938937195321, 335.1368932280064, 340.60526843825573, 346.0988439347264, 351.61744749872145, 357.16091001479, 362.72906538086994, 368.3217504219943, 373.9388048073811, 379.58007097074056, 385.2453940336413, 390.9346217317863, 396.64760434405997, 402.3841946242147, 408.1442477350713, 413.92762118511814, 419.73417476739684], [0.0, 0.6684759217372512, 1.7641185337870107, 3.1121142012508325, 4.65553672174608, 6.36273410675923, 8.212918615558282, 10.191146031945257, 12.286035066475321, 14.488561946190718, 16.79135597602662, 19.18825706039159, 21.674022167526243, 24.244122067019784, 26.894595617987115, 29.621942284723836, 32.423040924494735, 35.29508715753735, 38.235544207443546, 41.242103716437875, 44.31265408594168, 47.44525458839798, 50.638113970261095, 53.88957259595059, 57.19808741663589, 60.562219216670336, 63.980621714352594, 67.45203218578374, 70.97526334994404, 74.54919630596692, 78.1727743543024, 81.84499756514354, 85.5649179823682, 89.33163537095653, 93.14429343157865, 97.00207641870642, 100.90420610885695, 104.8499390739362, 108.83856422151192, 112.86940056950509, 116.94179522748574, 121.05512156067662, 125.2087775160502, 129.40218409266927, 133.63478394075787, 137.9060400759748, 142.21543469705398, 146.56246809642366, 150.9466576546612, 155.36753691071038, 159.82465470071742, 164.3175743591436, 168.84587297651257, 173.40914070876178, 178.00698013369905, 182.6390056505361, 187.3048429188813, 192.00412833393696, 196.7365085349696, 201.501639944402, 206.29918833513295, 211.12882842391085, 215.99024348879036, 220.88312500887852, 225.80717232473745, 230.7620923179538, 235.7475991085137, 240.76341376873827, 245.80926405263955, 250.88488413964916, 255.99001439175993, 261.1244011231949, 266.2877963817907, 271.4799577413443, 276.70064810422963, 281.94963551364486, 287.22669297489733, 292.5315982851774, 297.86413387131313, 303.22408663503364, 308.61124780530264, 314.0254127973146, 319.4663810777743, 324.933956036106, 330.42794486126314, 335.948158423831, 341.49441116313494, 347.06652097908625, 352.6643091285131, 358.28760012574486, 363.93622164722507, 369.6100044399499, 375.30878223353733, 381.0323916557442, 386.78067215126197, 392.55346590362865, 398.35061776010673, 404.1719751593839, 410.017388061964, 415.8867088831191, 421.7797924282858, 427.69649583079183], [0.0, 0.6809873259248991, 1.7971363273879675, 3.1703615028870344, 4.742671201451539, 6.48182102606264, 8.366634166138569, 10.381886704862309, 12.515984337020186, 14.759734397900676, 17.105628240207466, 19.547390474075574, 22.079679937525242, 24.69788262965435, 27.397963271627507, 30.176355810620475, 33.029880687615545, 35.95568103520252, 38.951172597873494, 42.01400381390774, 45.14202356338795, 48.33325479549388, 51.585872731018874, 54.89818667212451, 58.26862468979624, 61.69572063157772, 65.17810301833875, 68.71448549264537, 72.30365855195542, 75.94448235370413, 79.63588042082263, 83.3768341085053, 87.16637771838712, 91.00359416636834, 94.8876111263533, 98.81759758506574, 102.79276075354892, 106.81234328947633, 110.87562079138765, 114.98189953173048, 119.13051440037361, 123.32082703424756, 127.55222411211221, 131.82411579626793, 136.13593430540627, 140.48713260481932, 144.87718320191075, 149.30557703642577, 153.77182245608583, 158.2754442694039, 162.81598286840256, 167.39299341477442, 172.0060450837373, 176.65472036045907, 181.33861438446968, 186.05733433795606, 190.81049887425482, 195.5977375832273, 200.41869049053017, 205.2730075880809, 210.16034839327943, 215.08038153477125, 220.03278436274405, 225.01724258193158, 230.03344990565992, 235.08110772941995, 240.1599248225781, 245.26961703695798, 250.4099070311306, 255.58052400934685, 260.7812034741334, 266.0116869916512, 271.27172196898664, 276.5610614426121, 281.8794638773082, 287.22669297489733, 292.60251749218315, 298.00671106753884, 303.43905205562504, 308.8993233697569, 314.3873123314744, 319.9028105268987, 325.4456136694909, 331.0155214688502, 336.6123375052184, 342.23586910937547, 347.8859272476352, 353.56232641166673, 359.26488451288526, 364.99342278117547, 370.7477656677194, 376.5277407517211, 382.3331786508302, 388.1639129350775, 394.0197800441512, 399.90061920784706, 405.8062723695406, 411.7365841125342, 417.69140158914564, 423.6705744524051, 429.6739547902424, 435.70139706204804], [0.0, 0.6935647547290115, 1.8303283609963859, 3.2289161845497265, 4.830265503293434, 6.6015363854719755, 8.52116089747199, 10.573633945833967, 12.747147085458206, 15.032337868611492, 17.421558967770743, 19.908419090371705, 22.487478426365897, 25.15403775701286, 27.903987274289467, 30.733695062507667, 33.639922838095494, 36.61976096900955, 39.67057747008763, 42.78997734766982, 45.975769751939914, 49.22594111713093, 52.53863296145516, 55.91212336089581, 59.34481135384919, 62.83520370889957, 66.38190361651708, 69.983600961015, 73.63906390106226, 77.34713154188333, 81.10670752452141, 84.91675439041032, 88.77628860531351, 92.68437614713618, 96.64012857844114, 100.64269953763375, 104.69128159341915, 108.78510341581084, 112.92342722408657, 117.10554647796077, 121.33078378311573, 125.5984889862977, 129.9080374385899, 134.25882840834302, 138.65028362766722, 143.08184595845063, 147.55297816562395, 152.0631617868939, 156.61189608945816, 161.19869710532706, 165.8230967378386, 170.48464193278775, 175.1828939083162, 179.91742743834246, 184.68783018486562, 189.49370207496244, 194.33465471872464, 199.21031086475975, 204.12030389021345, 209.0642773225632, 214.04188439069893, 219.0527876030352, 224.09665835061065, 229.1731765333133, 234.28203020753747, 239.42291525372727, 244.59553506239345, 249.79960023731266, 255.0348283147255, 260.3009434974473, 265.5976764028945, 270.92476382410945, 276.2819485029386, 281.6689789145854, 287.08560906281963, 292.5315982851774, 298.00671106753884, 303.51071686751317, 309.0433899461042, 314.6045092071657, 320.19385804419363, 325.8112241940295, 331.4563995970841, 337.1291802637126, 342.8293661464014, 348.5567610174451, 354.3111723518184, 360.09241121496234, 365.90029215522486, 371.7346331007135, 377.59525526032854, 383.4819830287651, 389.39464389528194, 395.3330683560479, 401.29708982988996, 407.28654457727436, 413.3012716223652, 419.3411126780114, 425.4059120735254, 431.49551668511884, 437.6097758688739, 443.748541396133], [0.0, 0.7062076923041738, 1.8636932732880551, 3.2877758447016383, 4.9183160347156365, 6.72187527503146, 8.676492471863693, 10.766379890618934, 12.979513830976913, 15.30636117787821, 17.739135201265473, 20.271328102203032, 22.897400908771218, 25.61256874053933, 28.412646872115783, 31.29393718190599, 34.25314235592047, 37.28729972266125, 40.39372931871483, 43.56999249226951, 46.81385845667943, 50.12327694104498, 53.49635558545957, 56.93134107708841, 60.42660327052416, 63.9806217143526, 67.5919741367124, 71.2593265399206, 74.98142462750702, 78.75708634283625, 82.58519534150994, 86.46469525321098, 90.3945846149343, 94.37391237836948, 98.40177391082294, 102.47730742244082, 106.59969076332644, 110.7681385429794, 114.98189953173048, 119.24025430982661, 123.54251313478213, 127.88801400175053, 132.2761208751389, 136.70622207260774, 141.17772878506722, 145.6900737183784, 150.242709844256, 154.8351092493982, 159.46676207318376, 164.13717552540834, 168.84587297651257, 173.59239311360187, 178.3762891562978, 183.19712812710588, 188.05449017154817, 192.9479679238034, 197.87716591403407, 202.8417000139617, 207.84119691759264, 212.8752936542947, 217.94363713169432, 223.04588370609852, 228.18169877835885, 233.35075641328345, 238.55273898087114, 243.78733681779445, 249.05424790769302, 254.35317757896235, 259.6838382188334, 265.0459490026361, 270.439235637233, 275.8634301176874, 281.318270496307, 286.80350066326946, 292.31887013809853, 297.86413387131313, 303.43905205562504, 309.0433899461042, 314.6769176887758, 320.33941015714964, 326.03064679621843, 331.75041147349526, 337.49849233668897, 343.2746816776435, 349.0787758021948, 354.9105749056179, 360.769882953364, 366.6565075668008, 372.5702599136927, 378.51095460317293, 384.47840958497284, 390.4724460526921, 396.49288835090476, 402.5395638859077, 408.61230303993256, 414.7109390886506, 420.83530812180993, 426.9852489668554, 433.16060311539076, 439.361214652346, 445.5869301877272, 451.83759879082817], [0.0, 0.7189156334145386, 1.8972297309375796, 3.346938131198728, 5.006819277051332, 6.842832885770036, 8.832622681968337, 10.960116836722417, 13.213075287758915, 15.581793375207873, 18.05834424974095, 20.63610300703474, 23.30943100345864, 26.073457256462987, 28.923921738100844, 31.8570597804741, 34.86951473567145, 37.958270620038576, 41.120599245230935, 44.35401807681712, 47.65625618598679, 51.02522640798869, 54.45900233061331, 57.95579909082258, 61.51395720935728, 65.13192887485336, 68.80826622220368, 72.54161124894004, 76.3306870880003, 80.1742904120856, 84.07128478860115, 88.02059483824435, 92.02120107706098, 96.07213534298495, 100.17247672479847, 104.32134792506425, 108.51791199960824, 112.76136942512422, 117.05095545384829, 121.38593772034025, 125.76561407045851, 130.189310586829, 134.65637978863816, 139.16619898655347, 143.7181687760875, 148.31171165485728, 152.94627075100985, 157.62130865164252, 162.33630632138448, 167.0907621024575, 171.88419078853303, 176.7161227655649, 181.5861032135302, 186.49369136366784, 191.43845980637673, 196.41999384544135, 201.43789089469362, 206.4917599136115, 211.58122087870075, 216.70590428780957, 221.86545069480027, 227.0595102722412, 232.28774239999842, 237.5498152777992, 242.84540556001028, 248.1741980110294, 253.5358851798256, 258.9301670922901, 264.3567509601704, 269.8153509054626, 275.30568769922746, 280.8274885138806, 286.38048668807977, 291.96442150340306, 297.57903797207234, 303.22408663503364, 308.8993233697569, 314.6045092071657, 320.33941015714964, 326.1037970421521, 331.89744533836165, 337.7201350240688, 343.57165043478034, 349.45178012471024, 355.3603167342947, 361.2970568633982, 367.26180094990406, 373.25435315339917, 379.2745212436829, 385.3221164938498, 391.3969535777053, 397.4988504712954, 403.62762835834087, 409.78311153938, 415.9651273444368, 422.1735060490409, 428.40808079343736, 434.6686875048317, 440.95516482252884, 447.2673540258258, 453.60509896453357, 459.96824599200494], [0.0, 0.7316880830837221, 1.9309364276944525, 3.406400739660266, 5.095771783084766, 6.964404506368995, 8.989545446488718, 11.154837238058704, 13.447822358547294, 15.858623732471372, 18.379173679952565, 21.002729596824672, 23.72355266178863, 26.5366853531008, 29.437791958005047, 32.423040924494735, 35.48901596954351, 38.63264752671538, 41.851158937933484, 45.14202356338796, 48.50293012833276, 51.93175438688291, 55.426535701668314, 58.985457499291236, 62.6068308177349, 66.28908034679976, 70.0307324982154, 73.83040514287435, 77.68679872854871, 81.59868854930124, 85.56491798236819, 89.58439254296727, 93.65607463471649, 97.7789788949205, 101.95216805120367, 106.17474921982502, 110.4458705872339, 114.76471842557662, 119.13051440037363, 123.54251313478213, 128.00000000000006, 132.50228910565497, 137.04872146761392, 141.63866333367721, 146.2715046501752, 150.9466576546612, 155.6635555817463, 160.42165147070475, 165.22041706484288, 170.05934179379463, 174.93793183092458, 179.85570921889632, 184.8122110572313, 189.80698874635144, 194.83960728318098, 199.90964460389924, 205.01669096988329, 210.16034839327943, 215.3402300989932, 220.55596002019752, 225.80717232473745, 231.09351097005248, 236.41462928445918, 241.77018957283147, 247.15986274489, 252.58332796447155, 258.04027231828695, 263.5303905028062, 269.0533845280216, 274.60896343694304, 280.19684303977465, 285.8167456618032, 291.46839990410894, 297.1515404162759, 302.8659076803442, 308.61124780530264, 314.3873123314744, 320.19385804419363, 326.03064679621843, 331.89744533836165, 337.79402515786114, 343.72016232404206, 349.67563734085763, 355.6602350059186, 361.6737442756551, 367.7159581362699, 373.7866734801716, 379.8856909875933, 386.01281501312076, 392.16785347687517, 398.3506177601066, 404.56092260497434, 410.7985860183007, 417.0634291790998, 423.35527634969407, 429.6739547902424, 436.0192946765142, 442.3911290207534, 448.78929359548704, 455.21362686013725, 461.66396989030864, 468.14016630962584], [0.0, 0.7445245562604984, 1.964812083500813, 3.466161411912456, 5.185170174722991, 7.086585519979948, 9.14725480606846, 11.350533699854516, 13.683746128501316, 16.136841736657676, 18.701611307964374, 21.371193948427177, 24.139750156925427, 27.00223543873292, 29.95423801690473, 32.99185912006069, 36.111622531130905, 39.31040483230729, 42.58538065282003, 45.93397902639708, 49.35384813011762, 52.84282645108909, 56.39891895522294, 60.02027719980956, 63.70518259228863, 67.45203218578372, 71.25932653992056, 75.1256592780146, 79.04970804895993, 83.03022666101786, 87.06603820004987, 91.1560289800254, 95.29914320134384, 99.49437821446033, 103.74078030382896, 108.03744092127683, 112.38349330934199, 116.77810946442126, 121.22049739721433, 125.7098986542545, 130.24558606954844, 134.8268617197091, 139.45305505962241, 144.1235212187675, 148.83763944091203, 153.59481165211585, 158.39446114386143, 163.23603135974034, 168.11898477551304, 173.04280186355018, 178.00698013369902, 183.01103324351112, 188.05449017154814, 193.13689444816183, 198.25780343873868, 203.41678767492175, 208.61343022978073, 213.84732613330584, 219.11808182495912, 224.4253146403321, 229.76865232924166, 235.14773260284443, 240.56220270757345, 246.01171902390035, 251.49594668810417, 257.014559235387, 262.56723826282143, 268.1536731107417, 273.7735605613104, 279.4266045530924, 285.112515910568, 290.8310120875985, 296.5818169239388, 302.3646604139605, 308.17927848681376, 314.0254127973146, 319.9028105268987, 325.8112241940295, 331.75041147349526, 337.7201350240688, 343.72016232404206, 349.7502655141809, 355.81022124767856, 361.8998105467123, 368.01881866523956, 374.16703495768735, 380.3442527532177, 386.55026923526907, 392.7848853260943, 399.04790557603417, 405.3391380572792, 411.65839426189126, 418.00548900386997, 424.380240325058, 430.7824694046993, 437.2120004724668, 443.66866072479456, 450.1522802443532, 456.662691922522, 463.1997313847132, 469.76323691841856, 476.353049403852], [0.0, 0.757424577499389, 1.998855443648522, 3.5262179345014157, 5.275011140771377, 7.209371401184612, 9.305744919367747, 11.547198973779526, 13.920837859325964, 16.41643708295095, 19.02564519112592, 21.741482414424667, 24.558008073480828, 27.47009027001844, 30.473240786341464, 33.563493298920946, 36.73731135993483, 39.99151743360707, 43.323237195318555, 46.7298551328931, 50.20897867449786, 53.758408855739226, 57.376116075526234, 61.06021986406568, 64.80897185156512, 68.6207413176535, 72.49400284186969, 76.42732567991224, 80.41936456892957, 84.4688517250141, 88.57458984219844, 92.73544593814627, 96.95034591992184, 101.21826976555066, 105.53824723491329, 109.90935403785673, 114.33070839902666, 118.80146796839712, 123.32082703424757, 127.88801400175053, 132.50228910565497, 137.16294232998877, 141.86929151142306, 146.6206806060736, 151.4164781021614, 156.25607556320494, 161.1388862883338, 166.06434407795254, 171.031902094396, 176.0410318084278, 181.0912220234884, 186.18197797050624, 191.3128204668795, 196.48328513392846, 201.69292166772115, 206.94129315870765, 212.22797545606394, 217.55255657305833, 222.91463613011754, 228.31382483258966, 233.7497439804906, 239.22202500777126, 244.73030904887216, 250.27424653053365, 255.85349678701093, 261.4677276970067, 267.1166153407779, 272.79984367600747, 278.51710423114724, 284.26809581504716, 290.05252424178144, 295.87010206966943, 301.72054835356937, 307.6035884095944, 313.5189535914652, 319.4663810777743, 325.4456136694909, 331.4563995970841, 337.49849233668897, 343.57165043478034, 349.67563734085763, 355.81022124767856, 361.9751749386129, 368.17027564171394, 374.39530489013714, 380.65004838855407, 386.93429588524003, 393.24784104952784, 399.5904813543454, 405.9620179635705, 412.36225562395214, 418.7910025613655, 425.24807038118064, 431.7332739725383, 438.2464314163405, 444.7873638967718, 451.3558956161814, 457.9518537131636, 464.57506818368637, 471.225371805122, 477.9026000630471, 484.60659108068285], [0.0, 0.7703876806553119, 2.033065277973333, 3.5865681372715974, 5.365291434807013, 7.332757713088376, 9.465010059311753, 11.744825953291148, 14.159088983659812, 16.697399668112354, 19.35126362040214, 22.11358161436263, 24.978311297613764, 27.940232940920943, 30.994781512036944, 34.13792280494974, 37.36605984655293, 40.675960718462264, 44.0647019028219, 47.52962312371925, 51.06829086114469, 54.67846851606335, 58.35809175134704, 62.10524791350451, 65.91815870989863, 69.79516551084964, 73.73471678876518, 77.73535731256787, 81.7957187956204, 85.91451175625939, 90.09051839697115, 94.32258634475353, 98.60962312387997, 102.95059125499418, 107.34450389259692, 111.79042092757585, 116.28744549324581, 120.83472082300317, 125.43142741560365, 130.07678047059693, 134.77002756186306, 139.51044652171137, 144.29734351178445, 149.13005126019618, 154.00792744702562, 158.93035322257646, 163.896731844762, 168.90648742364417, 173.95906376258884, 179.05392328673423, 184.19054605053915, 189.3684288171021, 194.58708420274925, 199.84603988109376, 205.1448378413817, 210.4830336964823, 215.86019603635248, 221.27590582322654, 226.72975582515022, 232.22135008480603, 237.75030342086885, 243.31624095938793, 248.9187976929233, 254.5576180653698, 260.2323555805867, 265.94267243311646, 271.6882391594231, 277.4687343082165, 283.2838441285468, 289.13326227446436, 295.0166895251361, 300.9338335194, 306.88440850381926, 312.86813509337145, 318.88474004397375, 324.933956036106, 331.0155214688502, 337.1291802637126, 343.2746816776435, 349.45178012471024, 355.6602350059186, 361.8998105467123, 368.17027564171394, 374.4714037062993, 380.80297253462675, 387.1647641637652, 393.5565647435922, 399.9781644121509, 406.42935717617655, 412.90994079652427, 419.41971667824, 425.9584897650399, 432.5260684379744, 439.12226441806536, 445.7468926727218, 452.39977132574717, 459.0807215707647, 465.7895675878955, 472.52613646353757, 479.2902581130962, 486.08176520653103, 492.900493096589], [0.0, 0.7834134085915104, 2.0674403800841117, 3.647209892006044, 5.45600787314461, 7.456740104540305, 9.625044609502256, 11.94340766918183, 14.398491099707016, 16.979719584149688, 19.678455113036865, 22.487478426365893, 25.400645007560463, 28.412646872115783, 31.518841802142163, 34.71512738120409, 37.997845818513035, 41.36371055035404, 44.809748627981904, 48.333254795493886, 51.93175438688291, 55.602972986659765, 59.34481135384919, 63.155324495782345, 67.03270405242012, 70.97526334994404, 74.98142462750701, 79.04970804895994, 83.17872219265195, 87.36715577434187, 91.61377040597502, 95.91739423020707, 100.27691629971339, 104.69128159341916, 109.15948658022478, 113.68057525563712, 118.25363558873394, 122.87779632668736, 127.55222411211223, 132.27612087513893, 137.04872146761392, 141.86929151142306, 146.73712543677823, 151.65154468954893, 156.61189608945818, 161.6175503232885, 166.66790055922795, 171.76236117018158, 176.90036655533316, 182.08137005049613, 187.30484291888126, 192.570273414849, 197.87716591403407, 203.22504010394715, 208.61343022978076, 214.04188439069893, 219.50996388237033, 225.01724258193158, 230.56330637194372, 236.14775260023617, 241.77018957283147, 247.4302360774038, 253.1275209349612, 258.86168257764984, 264.6323686507664, 270.43923563723297, 276.2819485029386, 282.16018036148904, 288.07361215702844, 294.0219323639044, 300.00483670205307, 306.0220278670648, 312.07321527397903, 318.15811481392655, 324.2764486228089, 330.42794486126314, 336.6123375052184, 342.8293661464014, 349.0787758021948, 355.3603167342947, 361.6737442756551, 368.01881866523956, 374.39530489013714, 380.80297253462675, 387.24159563580673, 393.7109525454251, 400.21082579757785, 406.7410019819586, 413.30127162236516, 419.8914290601896, 426.511272342631, 433.1606031153907, 439.8392265196227, 446.54695109292453, 453.2835886741712, 460.0489543120003, 466.8428661767738, 473.66514547584734, 480.51561637199285, 487.3941059048223, 494.30044391507636, 501.23446297164327], [0.0, 0.7965013129000282, 2.1019795666251673, 3.708141111125047, 5.547157332889777, 7.581314307472537, 9.785843060783378, 12.142937285317586, 14.639035966099863, 17.26338711225896, 20.00720840553148, 22.863159979115004, 25.824994664571406, 28.8873158008523, 32.04540361599138, 35.295087157537345, 38.632647526715374, 42.05474325363847, 45.55835172272106, 49.14072248336502, 52.799339527161465, 56.531890441655676, 60.33624091541699, 64.21041346223272, 68.15256951113952, 72.1609942103157, 76.23408344043887, 80.37033264283961, 84.5683271504219, 88.82673377229538, 93.14429343157863, 97.51981469357942, 101.95216805120366, 106.44028085792525, 110.98313281739793, 115.57975195387361, 120.22921099980873, 124.93062414700333, 129.68314411579115, 134.48595950354365, 139.33829237934705, 144.239396096379, 149.1885532974225, 154.18507409224853, 159.2282943883838, 164.31757435914358, 169.4522970348289, 174.63186700470905, 179.8557092188963, 185.12326788049265, 190.4340054194972, 195.7874015409171, 201.18295234036003, 206.6201694811136, 212.0985794273517, 217.61772272866764, 223.17715335162364, 228.77643805443904, 234.4151558013232, 240.09289721329569, 245.80926405263952, 251.56386873839844, 257.35633389056954, 263.1862919008542, 269.0533845280215, 274.9572625161096, 280.89758523384205, 286.8740203337773, 292.8862434298308, 298.93393779192326, 305.01679405661025, 311.134509952639, 317.2867900404622, 323.4733454648156, 329.6938937195321, 335.948158423831, 342.23586910937547, 348.5567610174451, 354.9105749056179, 361.2970568633982, 367.7159581362699, 374.16703495768735, 380.65004838855407, 387.1647641637652, 393.7109525454251, 400.2883881823695, 406.89684997565354, 413.5361209496839, 420.20598812869537, 426.9062424182949, 433.6366784918065, 440.39709468117405, 447.1872928721899, 454.0070784038319, 460.85625997150714, 467.7346495340087, 474.64206222400617, 481.57831626189966, 488.54323287287946, 495.53663620703725, 502.5583532623896, 509.6082138106779], [0.0, 0.809650953634054, 2.136681676569905, 3.769359746440072, 5.63873675007496, 7.706476134352672, 9.947400007953172, 12.343408094557514, 14.880715496979503, 17.548392717023244, 20.337512446921732, 23.240613644163332, 26.25134600423313, 29.36422377124661, 32.57444925333364, 35.877782638738644, 39.270443632450515, 42.7490355994145, 46.310486022923236, 49.95199904449709, 53.67101711831086, 57.46518965571031, 61.33234710937997, 65.27047934628933, 69.27771744204405, 73.35231823390193, 77.49265111973075, 81.69718670172318, 85.96448695768788, 90.29319668675043, 94.68203602561209, 99.1297938698853, 103.63532206515897, 108.19753025631539, 112.815381302679, 117.48788718190936, 122.21410531796953, 126.99313527862893, 131.82411579626796, 136.70622207260777, 141.63866333367724, 146.62068060607362, 151.65154468954893, 156.73055430430276, 161.85703439419186, 167.0303345694717, 172.2498276747352, 177.51490846946595, 182.82499241013286, 188.17951452404697, 193.57792836632885, 199.0197050523046, 204.50433235849746, 210.03131388612127, 215.60016828162767, 221.2104285094276, 226.86164117240492, 232.55336587628128, 238.28517463428022, 244.0566513088806, 249.86739108775868, 255.71699999128666, 261.6050944092001, 267.53130066426235, 273.49525460094793, 279.4966011973402, 285.5349941985955, 291.6100957704644, 297.7215761714909, 303.86911344261904, 310.05239311304547, 316.2711079212451, 322.5249575501849, 328.8136483758162, 335.1368932280064, 341.49441116313494, 347.8859272476352, 354.3111723518184, 360.769882953364, 367.26180094990406, 373.7866734801716, 380.3442527532177, 386.93429588524003, 393.5565647435922, 400.21082579757785, 406.89684997565354, 413.6144125286964, 420.3632928990082, 427.1432745947532, 433.9541450695465, 440.7956956069223, 447.6677212094358, 454.5700204921618, 461.5023955803705, 468.4646520111732, 475.4565986389435, 482.47804754432946, 489.5288139466861, 496.6087161197655, 503.7175753105088, 510.85521566079916, 518.021464132037], [0.0, 0.8228618990514989, 2.171545570544119, 3.830863787959969, 5.730743117873607, 7.832221475743069, 10.10971014661319, 12.544813514844524, 15.123521757283093, 17.834727040854922, 20.669356392336663, 23.61982702857656, 26.679685028154207, 29.843355124981677, 33.10596134401614, 36.463194693170124, 39.91121319496205, 43.44656479198496, 47.066126833766646, 50.767057842250786, 54.54675854054504, 58.40283998581519, 62.33309723058839, 66.33548734281423, 70.40811090315725, 74.54919630596693, 78.75708634283625, 83.03022666101788, 87.36715577434188, 91.76649636933737, 96.2269476993804, 100.74727889868639, 105.3263230785919, 109.96297209282876, 114.65617187786252, 119.40491828994983, 124.20825337319097, 129.06526200314636, 133.97506885903005, 138.93683568446127, 143.94975880253625, 149.01306685580428, 154.1260187457733, 159.28790174997235, 164.49802979747474, 169.7557418862303, 175.0604006276372, 180.41139090556615, 185.80811863858253, 191.2500096354281, 196.7365085349696, 202.2670778228063, 207.84119691759264, 213.45836132088272, 219.11808182495915, 224.81988377368765, 230.56330637194372, 236.3479020396058, 242.17323580650555, 248.03888474507224, 253.94443743772405, 259.8894934763305, 265.8736629913196, 271.89656620822296, 277.95783302964736, 284.05710264084036, 290.19402313717313, 296.3682511720088, 302.57945162355253, 308.8272972793939, 315.1114685375597, 321.4316531229875, 327.78754581841906, 334.1788482087891, 340.60526843825573, 347.06652097908625, 353.56232641166673, 360.09241121496234, 366.6565075668008, 373.25435315339917, 379.8856909875933, 386.55026923526907, 393.24784104952784, 399.9781644121509, 406.7410019819586, 413.5361209496839, 420.3632928990082, 427.2222936734285, 434.1129032486465, 441.03490561019163, 447.98808863600493, 454.9722439837309, 461.98716698247887, 469.03265652882845, 476.1085149868711, 483.2145480920877, 490.3505648588763, 497.51637749155555, 504.7118012986793, 511.9366546105036, 519.1907586994629, 526.4739377035141], [0.0, 0.8361337253692062, 2.2065701301773566, 3.892651262746692, 5.823173484888395, 7.958546297961352, 10.272768270148713, 12.747147085458206, 15.367446958226402, 18.122380898668467, 21.002729596824672, 24.00078796787743, 27.109997995996018, 30.32469449239311, 33.639922838095494, 37.05130454187539, 40.55493565952518, 44.147308455879106, 47.82524991566528, 51.58587273101888, 55.426535701668314, 59.34481135384919, 63.33845917679434, 67.40540328828348, 71.54371363350812, 75.75159003283402, 80.02734854896785, 84.36940975922077, 88.77628860531352, 93.24658555927586, 97.77897889492048, 102.37221789399806, 107.02511684725845, 111.73654973529484, 116.50544549372714, 121.33078378311573, 126.21159119682206, 131.1469378504904, 136.1359343054063, 141.17772878506725, 146.27150465017522, 151.4164781021614, 156.61189608945816, 161.85703439419186, 167.1511958798923, 172.4937088832982, 177.88392573545468, 183.32122139910908, 188.80499221096906, 194.33465471872464, 199.90964460389927, 205.52941568259638, 211.1934389770856, 216.901201851935, 222.6522072090633, 228.44597273667267, 234.28203020753753, 240.15992482257812, 246.07921459605208, 252.03946977904815, 258.04027231828695, 264.08121534751035, 270.16190270899375, 276.2819485029386, 282.44097666270176, 288.6386205539993, 294.874522596381, 301.1483339054194, 307.45971395418644, 313.80833025270766, 320.19385804419363, 326.6159800169404, 333.07438603088264, 339.5687728578594, 346.0988439347264, 352.6643091285131, 359.26488451288526, 365.90029215522486, 372.5702599136927, 379.2745212436829, 386.01281501312076, 392.7848853260943, 399.5904813543454, 406.42935717617655, 413.30127162236516, 420.20598812869537, 427.1432745947532, 434.1129032486465, 441.11465051733506, 448.14829690228083, 455.2136268601373, 462.3104286882238, 469.4384944145409, 476.59761969209904, 483.78760369734727, 491.0082490325006, 498.2593616315768, 505.5407506699637, 512.8522284773524, 520.1936104538723, 527.5647149892858, 534.9653633850953], [0.0, 0.8494660165272466, 2.2417542574808804, 3.9547202338179597, 5.916024953509675, 8.085446640836905, 10.436569266832857, 12.950402463421405, 15.612483452971723, 18.41134527277175, 21.33762160943284, 24.383484519279946, 27.54227141783044, 30.808226783920624, 34.17631699635464, 37.64209374813469, 41.201590846014206, 44.85124462340745, 48.58783147078692, 52.4084180416842, 56.310321021450584, 60.29107422984924, 64.34840143079659, 68.4801936417855, 72.6844900329629, 76.95946172053122, 81.30339791653725, 85.71469401413498, 90.19184127554416, 94.73341785708855, 99.33808095743727, 104.00455991543065, 108.73165011548762, 113.51820758363485, 118.36314417719275, 123.26542328723987, 128.22405598600704, 133.23809756197804, 138.30664439419036, 143.42883112442362, 148.60382809193052, 153.8308390003439, 159.1090987905637, 164.43787169694204, 169.81644946705188, 175.24414972784962, 180.7203144831913, 186.24430872950145, 191.81551917797626, 197.4333530730617, 203.0972370981294, 208.8066163602898, 214.56095344717477, 220.3597275492952, 226.2024336422583, 232.08858172372462, 238.01769610050755, 243.98931472168053, 250.00298855396508, 256.0582809960322, 262.1547673286734, 268.2920341980806, 274.46967912972843, 280.6873100705819, 286.9445449575528, 293.2410113103126, 299.5763458467315, 305.9501941193618, 312.362210171517, 318.8120562116148, 325.29940230456475, 331.8239260790751, 338.3853124498456, 344.9832533536921, 351.61744749872145, 358.28760012574486, 364.99342278117547, 371.7346331007135, 378.51095460317293, 385.3221164938498, 392.16785347687517, 399.04790557603417, 405.9620179635705, 412.90994079652427, 419.8914290601896, 426.9062424182949, 433.9541450695465, 441.03490561019163, 448.14829690228083, 455.29409594733534, 462.47208376513424, 469.68204527736236, 476.9237691958723, 484.19704791532774, 491.5016774100128, 498.8374571346021, 506.20418992869907, 513.6016819249614, 521.0297424606457, 528.4881839924063, 535.9768220141998, 543.4954749781513], [0.0, 0.8628583639627645, 2.27709687425085, 4.017068799094395, 6.0092946783404555, 8.21291861555828, 10.60110811704805, 13.154573420052444, 15.858623732471374, 18.701611307964377, 21.674022167526235, 24.767904955197753, 27.97649204680729, 31.293937181905992, 34.7151273812041, 38.235544207443546, 41.851158937933484, 45.55835172272108, 49.353848130117626, 53.23466856766694, 57.198087416635886, 61.24159961595906, 65.36289304330921, 69.55982546678968, 73.83040514287435, 78.17277435430242, 82.58519534150994, 87.06603820004989, 91.61377040597503, 96.2269476993804, 100.90420610885694, 105.64425494050045, 110.44587058723391, 115.30789103963984, 120.22921099980874, 125.2087775160502, 130.24558606954847, 135.33867705483667, 140.48713260481932, 145.6900737183784, 150.9466576546612, 156.25607556320494, 161.61755032328847, 167.0303345694717, 172.49370888329818, 178.00698013369905, 183.56947995082166, 189.1805633198737, 194.839607283181, 200.54600974003847, 206.29918833513295, 212.09857942735172, 217.94363713169432, 223.83383242779396, 229.7686523292417, 235.74759910851367, 241.77018957283147, 247.83595438675516, 253.94443743772405, 260.0951952411241, 266.2877963817907, 272.52182098914204, 278.79686024339753, 285.11251591056805, 291.46839990410894, 297.86413387131313, 304.2993488026874, 310.7736846627051, 317.2867900404623, 323.83832181888744, 330.4279448612631, 337.05533171391846, 343.7201623240422, 350.4221237716469, 357.16091001479, 363.93622164722507, 370.7477656677194, 377.59525526032854, 384.47840958497284, 391.3969535777053, 398.3506177601066, 405.3391380572792, 412.36225562395214, 419.41971667824, 426.511272342631, 433.6366784918065, 440.7956956069223, 447.98808863600493, 455.2136268601373, 462.47208376513424, 469.76323691841867, 477.08686785083523, 484.44276194315074, 491.8307083170045, 499.2504997300916, 506.70193247536764, 514.1848062840828, 521.6989242324585, 529.2440926518374, 536.820121042139, 544.4268219884702, 552.0640110807439], [0.0, 0.8763103663928941, 2.3125969214954347, 4.0796950903888805, 6.102979864684536, 8.340958402606939, 10.766379890618932, 13.359653837655603, 16.105860421477868, 18.993170306832624, 22.011921191335, 25.15403775701286, 28.412646872115783, 31.781811132719877, 35.25633784794805, 38.83163813789312, 42.50362047188822, 46.268608566349684, 50.12327694104498, 54.064599551531515, 58.08980828655209, 62.19635903102159, 66.38190361651708, 70.64426641364595, 74.98142462750701, 79.39149157894002, 83.87270241662785, 88.42340182583654, 93.04203339049852, 97.72713033462907, 102.4773074224408, 107.29125383805088, 112.1677268982905, 117.10554647796076, 122.10359004750582, 127.16078823966896, 132.2761208751389, 137.44861338815446, 142.67733360202902, 147.96138881197578, 153.29992313877264, 158.69211512194005, 164.1371755254083, 169.63434533227502, 175.18289390831617, 180.782117316517, 186.43133676710747, 192.12989718948435, 197.87716591403404, 203.6725314532732, 209.51540237294196, 215.40520624473618, 221.3413886732826, 227.32341239076206, 233.3507564132834, 239.42291525372727, 245.53939818631716, 251.69972855865154, 257.9034431473535, 264.1500915538631, 270.43923563723297, 276.7704489810792, 283.14331639210155, 289.5574334278245, 296.01240595141576, 302.5078497116318, 309.0433899461041, 315.61866100633523, 322.23330600290876, 328.88697646954193, 335.57933204472005, 342.3100401697542, 349.07877580219474, 355.88522114361695, 362.72906538086994, 369.6100044399499, 376.5277407517211, 383.4819830287651, 390.4724460526921, 397.4988504712954, 404.56092260497434, 411.65839426189126, 418.7910025613655, 425.9584897650399, 433.1606031153907, 440.39709468117405, 447.6677212094358, 454.9722439837309, 462.3104286882238, 469.68204527736236, 477.08686785083523, 484.5246745335428, 491.9952473603277, 499.4983721652258, 507.033838475015, 514.6014394068484, 522.2009715697769, 529.8322349699712, 537.4950329194703, 545.1891719482885, 552.914461719726, 560.6707149487331], [0.0, 0.8898216296062837, 2.3482533588846395, 4.142597272435993, 6.197077767094605, 8.46956224977292, 10.932379744251016, 13.565637706342839, 16.354186274712312, 19.286013725230912, 22.35130877871768, 25.541871609091434, 28.85072311222514, 32.271834339200915, 35.799932536396874, 39.43035807093217, 43.15895632747277, 46.9819943401943, 50.896095355433616, 54.89818667212452, 58.98545749929124, 63.15532449578234, 67.40540328828348, 71.73348470277851, 76.1375147561989, 80.6155776798977, 85.1658814114559, 89.78674511391142, 94.47658837382322, 99.23392179993556, 104.05733879840568, 108.94550834272778, 113.89716858960438, 118.9111212182488, 123.98622639154743, 129.1213982543609, 134.31560089789244, 139.56784473018124, 144.87718320191075, 150.242709844256, 155.6635555817463, 161.1388862883338, 166.66790055922792, 172.24982767473517, 177.88392573545465, 183.56947995082163, 189.30580106524533, 195.09222390801222, 200.92810605478482, 206.81282658994942, 212.74578496030358, 218.726399911641, 224.75410850072453, 230.82836517594964, 236.94864092071128, 243.11442245411092, 249.3252114841884, 255.58052400934687, 261.87988966406755, 268.22285110538604, 274.60896343694304, 281.0377936677159, 287.5089202028073, 294.02193236390445, 300.57642993723397, 307.17202274703084, 313.8083302527077, 320.48498116806917, 327.20161310105175, 333.95787221259604, 340.75341289337325, 347.5878974571869, 354.4609958499679, 361.37238537336304, 368.3217504219943, 375.30878223353733, 382.3331786508302, 389.39464389528194, 396.49288835090476, 403.62762835834087, 410.7985860183007, 418.00548900386997, 425.24807038118064, 432.5260684379744, 439.8392265196227, 447.1872928721899, 454.5700204921618, 461.98716698247887, 469.4384944145409, 476.9237691958723, 484.44276194315074, 491.9952473603277, 499.58100412158205, 507.19981475886306, 514.8514655537979, 522.5357464337469, 530.2524508718074, 538.0013757905742, 545.7823214694821, 553.5950914555567, 561.4394924774192, 569.3153343623934], [0.0, 0.9033917662627952, 2.384065164221712, 4.205773541959495, 6.291585687977257, 8.598726470248323, 11.099102919069779, 13.772519120980117, 16.603594173183026, 19.580133167940502, 22.6921752001299, 25.931395393034293, 29.290708208390196, 32.763992753391214, 36.345895862808426, 40.03168684249112, 43.81714771755548, 47.69848859295142, 51.67228121816845, 55.73540603221698, 59.88500937843178, 64.11846851867297, 68.43336271697707, 72.82744910853835, 77.29864238622282, 81.84499756514354, 86.46469525321098, 91.15602898002541, 95.91739423020708, 100.74727889868639, 105.64425494050043, 110.60697103045551, 115.63414608163784, 120.72456349838826, 125.87706606062012, 131.09055135346776, 136.36396767010984, 141.69631032691137, 147.0866183392992, 152.53397141443526, 158.03748722309942, 163.59631891848719, 169.20965287406355, 174.87670661635065, 180.5967269316842, 186.36898812865678, 192.19279044025345, 198.06745855164058, 203.99234024125195, 209.96680512426175, 215.99024348879036, 222.06206521627183, 228.18169877835885, 234.3485903035662, 240.56220270757348, 246.8220148817426, 253.1275209349612, 259.4782294844141, 265.8736629913196, 272.3133571380498, 278.79686024339753, 285.3237327130534, 291.8935465226288, 298.505884730802, 305.16034102037924, 311.85651926525844, 318.5940331214558, 325.3725056405126, 332.191568903741, 339.05086367589405, 345.9500390769621, 352.88875227089886, 359.86666817017834, 366.8834591551679, 373.9388048073811, 381.0323916557442, 388.1639129350775, 395.3330683560479, 402.5395638859077, 409.78311153938, 417.0634291790998, 424.380240325058, 431.7332739725383, 439.12226441806536, 446.54695109292453, 454.0070784038319, 461.5023955803705, 469.03265652882845, 476.59761969209904, 484.19704791532774, 491.8307083170045, 499.4983721652258, 507.19981475886306, 514.9348153133905, 522.7031568511443, 530.5046260957929, 538.3390133708157, 546.2061125017954, 554.1057207223481, 562.037638583513, 570.001669866445, 577.9976214982585], [0.0, 0.9170203957009756, 2.4200313329350545, 4.269222126776014, 6.386500976252153, 8.72844744079478, 11.266544738255261, 13.980292278252275, 16.85407712064706, 19.875520384496625, 23.034510893788273, 26.32259818215048, 29.732589818409092, 33.25827256955383, 36.894212512142175, 40.63560758445069, 44.47817617894048, 48.41807122594778, 52.45181275614243, 56.576234146626255, 60.78843869027608, 65.08576408214662, 69.46575306688753, 73.92612894368251, 78.46477494631282, 83.07971674771758, 87.76910750833487, 92.5312150138368, 97.36441054301581, 102.26715917908268, 107.23801133349141, 112.27559529486476, 117.37861064972493, 122.54582244876816, 127.77605601400708, 133.06819229947064, 138.4211637322171, 143.833950471886, 149.30557703642577, 154.83510924939822, 160.42165147070475, 166.06434407795257, 171.76236117018158, 177.51490846946598, 183.32122139910908, 189.1805633198737, 195.09222390801224, 201.0555176608457, 207.06978251734913, 213.13437858266846, 219.24868694676934, 225.4121085885171, 231.62406335744902, 237.88398902633713, 244.19134040837054, 250.54558853343093, 256.9462198784983, 263.392735647723, 269.88465109814086, 276.4214949073969, 283.00280858019045, 289.6281458904627, 296.29707235662, 303.00916474733566, 309.7640106156871, 316.56120785958706, 323.40036430664026, 330.28109732171777, 337.20303343568565, 344.1658079938496, 351.1690648228005, 358.21245591444404, 365.2956411261011, 372.4182878956471, 379.58007097074056, 386.78067215126197, 394.0197800441512, 401.29708982988996, 408.61230303993256, 415.9651273444368, 423.35527634969407, 430.7824694046993, 438.2464314163405, 445.7468926727218, 453.2835886741712, 460.85625997150714, 468.4646520111732, 476.1085149868711, 483.78760369734727, 491.5016774100128, 499.2504997300916, 507.033838475015, 514.8514655537979, 522.7031568511443, 530.5886921160507, 538.5078548546842, 546.46043222733, 554.4462149492097, 562.464997194992, 570.5165765068152, 578.6007537056639, 586.7173328059415], [0.0, 0.9307071437529183, 2.4561508775896423, 4.33294128493312, 6.48182102606264, 8.858721599981244, 11.43470060476744, 14.188951473840499, 17.105628240207466, 20.17216726517578, 23.378306461019925, 26.715469236142933, 30.176355810620482, 33.75466021745818, 37.444867430610515, 41.24210371643786, 45.14202356338795, 49.14072248336502, 53.23466856766692, 57.420647930793706, 61.69572063157772, 66.05718462953759, 70.50254599420099, 75.0294940444491, 79.63588042082263, 84.31970132895863, 89.07908236477434, 93.91226546023003, 98.81759758506576, 103.79352091349328, 108.83856422151189, 113.951335324625, 119.13051440037361, 124.37484806754111, 129.68314411579112, 135.05426679712468, 140.4871326048193, 145.98070647715403, 151.53399837277505, 157.14606017243807, 162.81598286840256, 168.54289400820647, 174.325955364121, 180.16436080343294, 186.05733433795606, 192.00412833393696, 198.00402186587672, 204.05631919980542, 210.16034839327943, 216.31546000086146, 222.5210258751373, 228.77643805443904, 235.08110772941995, 241.4344642814767, 247.83595438675513, 254.28504118013188, 260.78120347413346, 267.3239350282631, 273.9127438646525, 280.54715162634795, 287.22669297489733, 293.95091502421127, 300.7193768079549, 307.53164877797303, 314.38731233147433, 321.28595936490217, 328.2271918525947, 335.2106214485024, 342.23586910937547, 349.3025647379615, 356.4103468448781, 363.5588622279273, 370.7477656677194, 377.97671963856084, 385.2453940336413, 392.55346590362865, 399.90061920784706, 407.28654457727436, 414.7109390886506, 422.1735060490409, 429.6739547902424, 437.2120004724668, 444.7873638967718, 452.39977132574717, 460.0489543120003, 467.7346495340087, 475.4565986389435, 483.2145480920877, 491.0082490325006, 498.8374571346021, 506.70193247536764, 514.6014394068484, 522.5357464337469, 530.5046260957929, 538.5078548546842, 546.545212985366, 554.6164844714395, 562.7214569045017, 570.8599213872286, 579.031672440027, 587.2365079110872, 595.4742288896806], [0.0, 0.9444516425661558, 2.4924228274169935, 4.396929303880142, 6.5775432755353345, 8.98954544648872, 11.603565999158006, 14.398491099707018, 17.35824077103986, 20.470065837135426, 23.72355266178863, 27.109997995996018, 30.621994258128748, 34.25314235592047, 37.99784581851304, 41.85115893793349, 45.80867202897536, 49.86642294283581, 54.02082761228433, 58.268624689796255, 62.60683081773491, 67.03270405242012, 71.54371363350812, 76.1375147561989, 80.81192733448606, 85.56491798236821, 90.3945846149343, 95.29914320134388, 100.27691629971342, 105.32632307859191, 110.44587058723393, 115.63414608163787, 120.889810248468, 126.2115911968221, 131.5982791100376, 137.04872146761394, 142.56181876181594, 148.13652064533608, 153.77182245608589, 159.4667620731838, 165.2204170648429, 171.03190209439603, 176.9003665553332, 182.8249924101329, 188.8049922109691, 194.83960728318104, 200.92810605478488, 207.06978251734915, 213.2639548053173, 219.50996388237036, 225.8071723247375, 232.1549631924933, 238.5527389808712, 244.99992064448526, 251.49594668810428, 258.040272318287, 264.6323686507665, 271.2717219689867, 277.9578330296475, 284.6902164115143, 291.46839990410905, 298.2919239332101, 305.1603410203793, 312.07321527397914, 319.0301219093753, 326.0306467962185, 333.0743860308827, 340.16094553230107, 347.2899406595879, 354.46099584996796, 361.67374427565517, 368.9278275184315, 376.22289526077554, 383.55860499248126, 390.9346217317863, 398.35061776010673, 405.8062723695406, 413.3012716223652, 420.83530812180993, 428.40808079343736, 436.0192946765142, 443.66866072479456, 451.3558956161814, 459.0807215707647, 466.8428661767738, 474.64206222400617, 482.47804754432946, 490.3505648588763, 498.2593616315768, 506.20418992869907, 514.1848062840828, 522.2009715697769, 530.2524508718074, 538.3390133708157, 546.46043222733, 554.6164844714395, 562.8069508966585, 571.0316159577778, 579.29026767252, 587.5826975268095, 595.9087003834986, 604.2680743943848], [0.0, 0.9582535304322439, 2.528846227862801, 4.4611844996701375, 6.673665205586319, 9.120915537478687, 11.773136477464325, 14.60890564148183, 17.611908065241927, 20.769208260698733, 24.07024041038907, 27.50617407905514, 31.069493433246212, 34.75370586658688, 38.55313312334008, 42.462757220676416, 46.47810403178332, 50.59515350639322, 54.81026920096345, 59.120142107770796, 63.521745271427555, 68.01229667844213, 72.58922858481918, 77.25016191959678, 81.99288473774973, 86.81533393808081, 91.71557963927147, 96.69181173927498, 101.74232828265549, 106.86552533624089, 112.05988813182273, 117.3239832800499, 122.6564518953273, 128.05600349978138, 133.52141059690956, 139.05150382367754, 144.6451676045264, 150.30133624273836, 156.0189903944425, 161.79715387865738, 167.63489078349872, 173.5313028342971, 179.48552699407486, 185.49673327079464, 191.56412270914166, 197.68692554744754, 203.8643995227899, 210.09582830937555, 216.38052007710178, 222.71780615872208, 229.10703981537634, 235.54759509139353, 242.03886575028022, 248.5802642846826, 255.17122099387348, 261.81118312298963, 268.4996140588334, 275.2359925775736, 282.0198121401421, 288.8505802315274, 295.7278177405314, 302.6510583768749, 309.61984812282526, 316.6337447167763, 323.69231716643867, 330.79514528950625, 337.9418192798459, 345.13193929742704, 352.3651150803559, 359.6409655775134, 366.95911860041974, 374.3192104930577, 381.72088581848755, 389.16379706117806, 396.64760434405997, 404.1719751593839, 411.7365841125342, 419.3411126780114, 426.9852489668554, 434.6686875048317, 442.3911290207534, 450.1522802443532, 457.9518537131636, 465.7895675878955, 473.66514547584734, 481.57831626189966, 489.5288139466861, 497.51637749155555, 505.5407506699637, 513.6016819249614, 521.6989242324585, 529.8322349699712, 538.0013757905742, 546.2061125017954, 554.4462149492097, 562.7214569045017, 571.0316159577778, 579.3764734139269, 587.7558141928357, 596.1694267332766, 604.6171029002991, 613.098637895961], [0.0, 0.972112451621727, 2.565420140151403, 4.52570521619156, 6.770184338771767, 9.25282848702225, 11.943407669181832, 14.82018967594666, 17.86662358480021, 21.069586825777588, 24.4183607713013, 27.903987274289467, 31.51884180214217, 35.25633784794805, 39.11071503313279, 43.0768828013503, 47.15030231789088, 51.3268953917569, 55.602972986659765, 59.97517823773219, 64.44044041167716, 68.9959372596118, 73.63906390106226, 78.36740685730712, 83.17872219265196, 88.07091696791196, 93.04203339049852, 98.09023517942498, 103.21379576440616, 108.41108801508602, 113.68057525563711, 119.02080336604634, 124.43039380758111, 129.90803743858993, 135.45248900967206, 141.0625622456613, 146.7371254367782, 152.4750974734666, 158.27544426940392, 164.13717552540834, 170.05934179379466, 176.0410318084278, 182.08137005049613, 188.17951452404697, 194.33465471872464, 200.54600974003847, 206.81282658994945, 213.13437858266846, 219.50996388237033, 225.93890415108322, 232.4205432963651, 238.95424630954386, 245.5393981863172, 252.17540292239607, 258.86168257764984, 265.5976764028945, 272.38284002406357, 279.2166446790285, 286.0985765028051, 293.0281358572911, 300.00483670205307, 307.0282060030013, 314.0977831760865, 321.21311956341134, 328.3737779393797, 335.5793320447201, 342.82936614640147, 350.12347462163183, 357.4612615642817, 364.8423404122088, 372.2663335940878, 379.73287219445814, 387.24159563580673, 394.79215137659395, 402.3841946242147, 410.017388061964, 417.69140158914564, 425.4059120735254, 433.16060311539076, 440.95516482252884, 448.78929359548704, 456.662691922522, 464.57506818368637, 472.52613646353757, 480.51561637199285, 488.54323287287946, 496.6087161197655, 504.7118012986793, 512.8522284773524, 521.0297424606457, 529.2440926518374, 537.4950329194703, 545.7823214694821, 554.1057207223481, 562.464997194992, 570.8599213872286, 579.29026767252, 587.7558141928357, 596.2563427574262, 604.7916387453199, 613.3614910113755, 621.9656917957226], [0.0, 0.9860280562251719, 2.6021436408662693, 4.590489824428197, 6.867098238180848, 9.385280964587054, 12.11437527531096, 15.032337868611492, 18.12238089866847, 21.37119394842718, 24.767904955197753, 28.303427537728936, 31.97002801968875, 35.76102560957383, 39.67057747008763, 43.69352017453949, 47.82524991566528, 52.06163012393992, 56.398918955222946, 60.833711491765825, 65.36289304330921, 69.983600961015, 74.69319307604142, 79.48922136117888, 84.36940975922079, 89.33163537095653, 94.37391237836947, 99.49437821446034, 104.69128159341916, 109.96297209282874, 115.30789103963983, 120.72456349838826, 126.21159119682207, 131.7676462531763, 137.39146559254226, 143.08184595845063, 148.83763944091203, 154.6577494544929, 160.54112711012186, 166.48676793267296, 172.49370888329818, 178.5610256512613, 184.68783018486565, 190.87326843514677, 197.1165182894477, 203.4167876749218, 209.77331281450654, 216.18535662004416, 222.6522072090633, 229.1731765333133, 235.7475991085137, 242.3748308359642, 249.05424790769302, 255.7852457877233, 262.5672382628215, 269.39965655678577, 276.2819485029386, 283.21357777002225, 290.19402313717313, 297.2227778140647, 304.2993488026874, 311.4232562975585, 318.5940331214558, 325.8112241940296, 333.07438603088264, 340.3830862709232, 347.7369032299809, 355.13542547885095, 362.5782514440829, 370.0649890299711, 377.59525526032854, 385.16867593874014, 392.7848853260944, 400.4435258342866, 408.1442477350713, 415.8867088831191, 423.6705744524051, 431.49551668511884, 439.361214652346, 447.2673540258258, 455.21362686013725, 463.1997313847132, 471.225371805122, 479.2902581130962, 487.3941059048223, 495.53663620703725, 503.7175753105088, 511.9366546105036, 520.1936104538723, 528.4881839924063, 536.820121042139, 545.1891719482885, 553.5950914555567, 562.037638583513, 570.5165765068152, 579.031672440027, 587.5826975268095, 596.1694267332766, 604.7916387453199, 613.4491158697094, 622.1416439388015, 630.8690122186824], [0.0, 1.0, 2.639015821545789, 4.655536721746081, 6.964404506368996, 9.518269693579395, 12.286035066475321, 15.245344971379465, 18.37917367995257, 21.674022167526235, 25.11886431509581, 28.704484988067616, 32.42304092449474, 36.26775666655813, 40.23270658439394, 44.31265408594168, 48.502930128332764, 52.79933952716148, 57.19808741663589, 61.695720631577736, 66.28908034679976, 70.97526334994403, 75.75159003283402, 80.6155776798977, 85.56491798236821, 90.59745795971199, 95.71118365501965, 100.90420610885695, 106.17474921982505, 111.52113917914453, 116.94179522748573, 122.43522152965929, 128.00000000000006, 133.63478394075787, 139.33829237934708, 145.10930500924417, 150.9466576546612, 156.84923819163097, 162.81598286840259, 168.8458729765126, 174.93793183092458, 181.09122202348843, 187.30484291888126, 193.57792836632885, 199.90964460389927, 206.29918833513295, 212.74578496030358, 219.24868694676934, 225.80717232473748, 232.4205432963651, 239.08812494750939, 245.80926405263955, 252.5833279644716, 259.4097035807991, 266.2877963817907, 273.21702953172866, 280.19684303977465, 287.22669297489733, 294.3060507305724, 301.43440233529236, 308.6112478053027, 315.8361005363128, 323.10848673123445, 330.42794486126314, 337.79402515786114, 345.20628913341227, 352.6643091285131, 360.1676678840377, 367.71595813626993, 375.30878223353733, 382.9457517729089, 390.6264872556345, 398.3506177601067, 406.1177806312241, 413.92762118511814, 421.7797924282858, 429.6739547902424, 437.6097758688739, 445.5869301877272, 453.60509896453357, 461.66396989030864, 469.76323691841856, 477.9026000630471, 486.08176520653103, 494.30044391507636, 502.5583532623896, 510.85521566079916, 519.1907586994629, 527.5647149892858, 535.9768220141998, 544.4268219884702, 552.914461719726, 561.4394924774192, 570.001669866445, 578.6007537056639, 587.2365079110872, 595.9087003834986, 604.6171029002991, 613.3614910113755, 622.1416439388015, 630.9573444801937, 639.8083789155545], [0.0, 1.0140279442228424, 2.676035788293632, 4.72084433120613, 7.062100784329651, 9.651791449938898, 12.458382881107722, 15.459205820295967, 18.636995703196874, 21.978064141576944, 25.47123034264912, 29.107149902425643, 32.87786953411849, 36.77651873416423, 40.7970887482938, 44.93426952582537, 49.18332652681743, 53.540005717051415, 58.00045899656972, 62.56118475938557, 67.21897986848819, 71.97090038541859, 76.81422911260624, 81.74644850708351, 86.76521787925695, 91.86835404670212, 97.05381480083449, 102.3196846840022, 107.66416267975502, 113.08555149921742, 118.58224820825595, 124.1527359881887, 129.79557686052388, 135.5094052361104, 141.29292217295065, 147.14489024612928, 153.06412894886526, 159.0495105563785, 165.09995639466777, 171.21443346488422, 177.39195138110819, 183.63155958528026, 189.93234480801559, 196.29342874822507, 202.71396594801098, 209.19314184231584, 215.73017096537154, 222.32429529819004, 228.97478274322665, 235.68092571396926, 242.442039828617, 249.2574626982279, 256.1265528007771, 263.0486884334946, 270.0232667366581, 277.0497027827304, 284.1274287253531, 291.25589300326067, 298.43455959466587, 305.66290731809767, 312.94042917605725, 320.2666317381962, 327.6410345610272, 335.06316964144537, 342.532580901585, 350.04882370275016, 357.6114643863551, 365.22007983998617, 372.8742570868546, 380.57359289705227, 388.3176934191537, 396.1061738308214, 403.9386580071802, 411.8147782058234, 419.73417476739684, 427.69649583079183, 435.70139706204804, 443.748541396133, 451.83759879082817, 459.96824599200494, 468.14016630962584, 476.353049403852, 484.60659108068285, 492.900493096589, 501.23446297164327, 509.6082138106779, 518.021464132037, 526.4739377035141, 534.9653633850953, 543.4954749781513, 552.0640110807439, 560.6707149487331, 569.3153343623934, 577.9976214982585, 586.7173328059415, 595.4742288896806, 604.2680743943848, 613.098637895961, 621.9656917957226, 630.8690122186824, 639.8083789155545, 648.7835751682891]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 2.9000000000000004\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.0012589254117941666, 0.0034394855855238732, 0.0061919268826996264, 0.009396951544704149, 0.01298693019767163, 0.016916842777294886, 0.021153983341733913, 0.025673228201672543, 0.03045451157114848, 0.03548133892335754, 0.04073984698322584, 0.046218176501939295, 0.05190603566941788, 0.05779438567104081, 0.06387520774571051, 0.0701413264886539, 0.0765862730879684, 0.08320417761196275, 0.08998968287983806, 0.09693787466570612, 0.10404422446536338, 0.11130454206620125, 0.11871493586631204, 0.12627177939085826, 0.13397168281703664, 0.14181146858590885, 0.1497881503782946, 0.1578989148820623, 0.1661411058928041, 0.1745122103783815, 0.18300984620681973, 0.19163175129130933, 0.20037577394914752, 0.20923986430590125, 0.2182220666038348, 0.2273205122961679, 0.23653341382712342, 0.24585905901284125, 0.2552958059507204, 0.26484207839513324, 0.27449636154612134, 0.28425719820495393, 0.29412318525656717, 0.30409297044408795, 0.31416524940506485, 0.324338762942797, 0.3346122945093772, 0.34498466787984494, 0.3554547449992378, 0.36602142398640636, 0.37668363728025256, 0.38744034991562565, 0.3982905579174757, 0.4092332868030632, 0.4202675901830809, 0.4313925484534658, 0.44260726757050073, 0.4539108779025307, 0.46530253315225323, 0.4767814093441227, 0.4883467038719071, 0.49999763460189295, 0.5117334390276408, 0.5235533734725494, 0.5354567123368217, 0.5474427473857084, 0.5595107870761754, 0.5716601559193765, 0.5838901938765245, 0.5962002557859547, 0.6085897108193413, 0.6210579419651958, 0.6336043455379178, 0.6462283307107948, 0.6589293190714831, 0.6717067441985914, 0.6845600512581069, 0.6974886966184849, 0.7104921474833091, 0.7235698815405113, 0.7367213866271994, 0.749946160409222, 0.7632437100746419, 0.7766135520403609, 0.7900552116711762, 0.8035682230106036, 0.8171521285228424, 0.8308064788452976, 0.8445308325511145, 0.858324755921207, 0.8721878227253049, 0.8861196140115631, 0.900119717904309, 0.9141877294095342, 0.9283232502277446, 0.9425258885738265, 0.9567952590035856, 0.9711309822466542, 0.9855326850454628, 1.0000000000000002, 1.0145325654180988], [0.0, 0.0034394855855238732, 0.009396951544704149, 0.016916842777294886, 0.025673228201672543, 0.03548133892335754, 0.0462181765019393, 0.05779438567104081, 0.0701413264886539, 0.08320417761196276, 0.09693787466570612, 0.11130454206620123, 0.12627177939085826, 0.14181146858590882, 0.1578989148820623, 0.17451221037838147, 0.19163175129130933, 0.20923986430590122, 0.22732051229616787, 0.24585905901284125, 0.26484207839513324, 0.28425719820495393, 0.30409297044408795, 0.324338762942797, 0.3449846678798449, 0.36602142398640636, 0.38744034991562565, 0.40923328680306315, 0.43139254845346575, 0.4539108779025307, 0.4767814093441227, 0.49999763460189295, 0.5235533734725494, 0.5474427473857084, 0.5716601559193765, 0.5962002557859547, 0.6210579419651959, 0.6462283307107948, 0.6717067441985916, 0.6974886966184848, 0.7235698815405112, 0.7499461604092219, 0.7766135520403608, 0.8035682230106034, 0.8308064788452976, 0.8583247559212069, 0.8861196140115629, 0.9141877294095341, 0.9425258885738266, 0.9711309822466541, 1.0, 1.0291300251709916, 1.0585182301515081, 1.0881618720008799, 1.1180582883538035, 1.1482048935984939, 1.1785991753026108, 1.2092386908667367, 1.2401210643871723, 1.2712439837115492, 1.302605197672336, 1.3342025134846855, 1.3660337942963208, 1.3980969568782566, 1.4303899694461428, 1.4629108496029128, 1.49565766239421, 1.5286285184687853, 1.5618215723367257, 1.5952350207189228, 1.628867100981764, 1.6627160896514728, 1.6967803010029854, 1.731058085718636, 1.7655478296122773, 1.8002479524148158, 1.835156906617406, 1.8702731763688534, 1.9055952764240078, 1.941121751140163, 1.9768511735186953, 2.0127821442893477, 2.048913291034774, 2.0852432673530825, 2.1217707520563156, 2.158494448402884, 2.1954130833621566, 2.2325254069094886, 2.269830191350091, 2.307326230670256, 2.3450123399145193, 2.382887354587466, 2.420950130078923, 2.459199541111393, 2.4976344812086357, 2.536253862184367, 2.57505661365011, 2.614041682541293, 2.6532080326607357, 2.692554644238706, 2.7320805135087918, 2.7717846522988703], [0.0, 0.0061919268826996264, 0.016916842777294886, 0.030454511571148483, 0.046218176501939295, 0.06387520774571051, 0.08320417761196278, 0.10404422446536339, 0.12627177939085826, 0.1497881503782946, 0.1745122103783815, 0.2003757739491475, 0.22732051229616793, 0.2552958059507203, 0.28425719820495393, 0.3141652494050648, 0.3449846678798449, 0.37668363728025256, 0.40923328680306315, 0.44260726757050084, 0.4767814093441227, 0.5117334390276407, 0.5474427473857084, 0.5838901938765246, 0.621057941965196, 0.6589293190714832, 0.6974886966184848, 0.7367213866271995, 0.7766135520403609, 0.8171521285228424, 0.858324755921207, 0.900119717904309, 0.9425258885738264, 0.9855326850454629, 1.0291300251709918, 1.0733082897078543, 1.1180582883538035, 1.1633712291545528, 1.2092386908667367, 1.2556525979199058, 1.302605197672336, 1.3500890396980547, 1.3980969568782564, 1.4466220481004508, 1.49565766239421, 1.5451973843540994, 1.5952350207189232, 1.6457645879922636, 1.696780301002986, 1.7482765623161278, 1.8002479524148158, 1.8526892205826857, 1.9055952764240074, 1.958961181965457, 2.012782144289348, 2.0670535086533603, 2.121770752056316, 2.176929477213615, 2.2325254069094886, 2.2885543786963702, 2.3450123399145193, 2.4018953430075056, 2.459199541111393, 2.5169211838974666, 2.5750566136501094, 2.6336022615630625, 2.6925546442387063, 2.751910360376324, 2.8116660876364783, 2.871818579669647, 2.9323646632982774, 2.993301235842233, 3.054625262578419, 3.116333774326085, 3.178423865149924, 3.240892690173737, 3.303737463497893, 3.3669554562143817, 3.430543994513665, 3.4945004578779404, 3.558822277355857, 3.6235069339140007, 3.6885519568608527, 3.753954922339167, 3.819713451883026, 3.885825211036039, 3.9522879080274196, 4.019099292502861, 4.086257154307331, 4.153759322317123, 4.221603663318589, 4.289788080931243, 4.358310514572963, 4.42716893846524, 4.496361360676487, 4.565885822201575, 4.635740396075839, 4.705923186521943, 4.776432328128031, 4.847265985055733, 4.918422350276621, 4.9898996448358535], [0.0, 0.009396951544704149, 0.025673228201672543, 0.046218176501939295, 0.0701413264886539, 0.09693787466570612, 0.12627177939085826, 0.1578989148820623, 0.19163175129130933, 0.2273205122961679, 0.26484207839513324, 0.30409297044408795, 0.3449846678798449, 0.3874403499156256, 0.43139254845346575, 0.47678140934412266, 0.5235533734725494, 0.5716601559193765, 0.6210579419651958, 0.6717067441985916, 0.7235698815405112, 0.7766135520403608, 0.8308064788452975, 0.886119614011563, 0.9425258885738264, 1.0, 1.0585182301515084, 1.1180582883538033, 1.1785991753026108, 1.2401210643871723, 1.302605197672336, 1.3660337942963208, 1.4303899694461428, 1.4956576623942097, 1.561821572336726, 1.628867100981764, 1.6967803010029856, 1.7655478296122773, 1.8351569066174063, 1.9055952764240074, 1.976851173518695, 2.0489132910347734, 2.1217707520563156, 2.195413083362156, 2.269830191350091, 2.3450123399145193, 2.4209501300789227, 2.497634481208636, 2.57505661365011, 2.6532080326607357, 2.7320805135087918, 2.8116660876364783, 2.8919570297907495, 2.972945846036852, 3.0546252625784196, 3.1369882153158803, 3.220027840081795, 3.3037374634978924, 3.3881105944039747, 3.473140915813611, 3.5588222773558567, 3.64514868816596, 3.7321143101914545, 3.819713451883026, 3.907940562242242, 3.9967902252007086, 4.086257154307331, 4.176336187702382, 4.26702228335883, 4.358310514572962, 4.450196065687834, 4.5426742280343255, 4.635740396075838, 4.7293900637437165, 4.823618820951443, 4.91842235027662, 5.013796423800488, 5.109736900095535, 5.20623972135243, 5.303300910638101, 5.400916569277414, 5.499082874351368, 5.597796076305272, 5.69705249666076, 5.796848525825952, 5.897180620998426, 5.998045304156, 6.0994391601307, 6.201358834761516, 6.303801033121896, 6.406762517818112, 6.510240107354929, 6.614230674565199, 6.7187311451001985, 6.823738495977754, 6.92924975418532, 7.035261995335401, 7.141772342370801, 7.248777964317393, 7.356276075082165, 7.464263932294463, 7.572738836188485], [0.0, 0.01298693019767163, 0.03548133892335754, 0.06387520774571051, 0.09693787466570612, 0.1339716828170366, 0.1745122103783815, 0.2182220666038348, 0.26484207839513324, 0.3141652494050648, 0.3660214239864063, 0.42026759018308085, 0.4767814093441227, 0.5354567123368216, 0.5962002557859547, 0.658929319071483, 0.7235698815405112, 0.7900552116711762, 0.8583247559212068, 0.9283232502277446, 1.0, 1.073308289707854, 1.1482048935984939, 1.2246496663528565, 1.302605197672336, 1.382036518533576, 1.4629108496029128, 1.5451973843540991, 1.628867100981764, 1.7138925983858002, 1.8002479524148156, 1.887908589268498, 1.976851173518695, 2.06705350865336, 2.158494448402884, 2.2511538173947154, 2.345012339914519, 2.4400515757418626, 2.5362538621843664, 2.6336022615630625, 2.7320805135087913, 2.8316729915188694, 2.932364663298277, 3.0341410544728977, 3.1369882153158803, 3.2408926901737365, 3.345841489317682, 3.451822062978997, 3.558822277355857, 3.666830392403761, 3.7758350412431145, 3.8858252110360385, 3.996790225200708, 4.108719726845627, 4.2216036633185885, 4.335432271776015, 4.450196065687834, 4.565885822201574, 4.682492570296793, 4.800007579667558, 4.91842235027662, 5.037728602530114, 5.157918268026336, 5.278983480836285, 5.400916569277413, 5.523710048145414, 5.647356611371821, 5.771849125077987, 5.897180620998426, 6.023344290248694, 6.15033347741503, 6.278141674944758, 6.406762517818111, 6.536189778483652, 6.666417362040764, 6.797439301654028, 6.929249754185319, 7.061842996030579, 7.195213419149127, 7.329355527274224, 7.464263932294461, 7.5999333507961735, 7.73635860075785, 7.873534598388052, 8.011456355098991, 8.150118974608336, 8.289517650162422, 8.42964766187439, 8.570504374171238, 8.712083233344144, 8.85437976519675, 8.997389572786458, 9.141108334254072, 9.285531800737383, 9.430655794364634, 9.576476206323916, 9.722988995004915, 9.870190184209523, 10.01807586142811, 10.166642176178392, 10.315885338403977, 10.465801616929935], [0.0, 0.016916842777294886, 0.0462181765019393, 0.08320417761196278, 0.12627177939085826, 0.1745122103783815, 0.22732051229616795, 0.284257198204954, 0.3449846678798449, 0.40923328680306326, 0.4767814093441228, 0.5474427473857084, 0.621057941965196, 0.6974886966184848, 0.776613552040361, 0.858324755921207, 0.9425258885738265, 1.0291300251709918, 1.1180582883538035, 1.209238690866737, 1.3026051976723363, 1.3980969568782566, 1.49565766239421, 1.5952350207189234, 1.6967803010029858, 1.800247952414816, 1.9055952764240076, 2.012782144289348, 2.1217707520563156, 2.232525406909489, 2.3450123399145193, 2.4591995411113934, 2.5750566136501094, 2.6925546442387063, 2.8116660876364787, 2.9323646632982774, 3.0546252625784196, 3.1784238651499246, 3.3037374634978933, 3.430543994513665, 3.558822277355857, 3.6885519568608527, 3.819713451883026, 3.9522879080274196, 4.086257154307332, 4.221603663318589, 4.358310514572963, 4.496361360676488, 4.63574039607584, 4.776432328128031, 4.918422350276621, 5.0616961171417465, 5.20623972135243, 5.352039671967975, 5.4990828743513696, 5.647356611371822, 5.796848525825954, 5.947546603978199, 6.0994391601307, 6.252514822141572, 6.4067625178181125, 6.562171462118322, 6.718731145100199, 6.8764313205637455, 7.035261995335401, 7.195213419149127, 7.356276075082166, 7.518440670507111, 7.681698128525125, 7.846039579847938, 8.011456355098993, 8.177939977506348, 8.345482155962175, 8.5140747784256, 8.683709905647403, 8.854379765196752, 9.026076745771554, 9.198793391775416, 9.372522398145394, 9.547256605415871, 9.722988995004917, 9.89971268471043, 10.077420924404256, 10.256107091913247, 10.435764689077015, 10.61638733797275, 10.797968777298141, 10.980502858904037, 11.163983544468948, 11.348404902308095, 11.533761104310047, 11.720046422994523, 11.907255228685267, 12.095381986792283, 12.284421255198106, 12.474367681742988, 12.665216001804328, 12.856961035965798, 13.049597687772025, 13.243120941564765, 13.437525860396867, 13.632807584020476], [0.0, 0.021153983341733913, 0.05779438567104081, 0.10404422446536339, 0.1578989148820623, 0.2182220666038348, 0.284257198204954, 0.3554547449992378, 0.4313925484534657, 0.5117334390276407, 0.5962002557859547, 0.6845600512581069, 0.7766135520403609, 0.8721878227253049, 0.9711309822466542, 1.0733082897078543, 1.1785991753026108, 1.2868949422503626, 1.3980969568782562, 1.512115201372435, 1.628867100981764, 1.7482765623161276, 1.8702731763688534, 1.994791551750462, 2.1217707520563156, 2.251153817394716, 2.382887354587466, 2.5169211838974657, 2.6532080326607357, 2.791703268126781, 2.9323646632982774, 3.07515219072035, 3.2200278400817948, 3.366955456214382, 3.5159005946552373, 3.666830392403761, 3.8197134518830254, 3.9745197364246327, 4.131220475850052, 4.289788080931243, 4.450196065687834, 4.6124189766237, 4.776432328128031, 4.9422125433690205, 5.109736900095536, 5.278983480836284, 5.449931127049401, 5.622559396829491, 5.796848525825954, 5.972779391066538, 6.150333477415031, 6.329492846422123, 6.510240107354929, 6.692558390213621, 6.876431320563745, 7.06184299603058, 7.2487779643173935, 7.437221202623215, 7.627158098347985, 7.818574430983589, 8.011456355098991, 8.20579038433614, 8.401563376340938, 8.59876251856042, 8.797375314843274, 8.99738957278646, 9.198793391775416, 9.40157515166991, 9.605723502091545, 9.81122735227245, 10.01807586142811, 10.226258429620064, 10.435764689077013, 10.646584495945303, 10.858707922441837, 11.072125249384701, 11.286826959078441, 11.502803728532704, 11.720046422994523, 11.938546089775832, 12.158293952359221, 12.379281404765985, 12.601500006171774, 12.824941475755963, 13.049597687772023, 13.275460666826746, 13.502522583357226, 13.730775749295042, 13.960212613907832, 14.190825759809108, 14.422607899127621, 14.655551869828232, 14.889650632176673, 15.12489726534108, 15.361284964123595, 15.598807035815677, 15.83745689717125, 16.077228071492026, 16.318114185819795, 16.56010896823063, 16.80320624522637, 17.047399939218923], [0.0, 0.025673228201672543, 0.0701413264886539, 0.12627177939085826, 0.19163175129130933, 0.26484207839513324, 0.3449846678798449, 0.4313925484534657, 0.5235533734725494, 0.6210579419651958, 0.7235698815405112, 0.8308064788452975, 0.9425258885738264, 1.0585182301515081, 1.1785991753026108, 1.3026051976723358, 1.4303899694461426, 1.5618215723367257, 1.6967803010029854, 1.8351569066174063, 1.976851173518695, 2.121770752056315, 2.269830191350091, 2.420950130078923, 2.5750566136501094, 2.7320805135087913, 2.8919570297907495, 3.054625262578419, 3.2200278400817948, 3.3881105944039747, 3.558822277355856, 3.7321143101914545, 3.907940562242242, 4.086257154307331, 4.26702228335883, 4.450196065687833, 4.635740396075838, 4.823618820951443, 5.013796423800488, 5.206239721352429, 5.400916569277413, 5.597796076305271, 5.796848525825952, 5.9980453041559985, 6.201358834761515, 6.406762517818112, 6.614230674565198, 6.823738495977754, 7.035261995335401, 7.248777964317393, 7.464263932294461, 7.681698128525124, 7.9010594469960695, 8.12232741367419, 8.345482155962175, 8.570504374171238, 8.797375314843276, 9.026076745771553, 9.256590932583787, 9.488900616764445, 9.722988995004915, 9.958839699780352, 10.196436781061378, 10.435764689077015, 10.676808258052619, 10.91955269085327, 11.163983544468946, 11.41008671628327, 11.657848431072445, 11.907255228685262, 12.15829395235922, 12.410951737631171, 12.665216001804321, 12.921074433936306, 13.178514985315687, 13.437525860396864, 13.698095508165379, 13.960212613907828, 14.223866091362414, 14.489045075227784, 14.755738914009576, 15.023937163185284, 15.293629578669604, 15.564806110563469, 15.837456897171249, 16.111572259271473, 16.387142694627517, 16.664158872725512, 16.94261162972752, 17.22249196362892, 17.50379102960938, 17.78650013556778, 18.07061073783169, 18.356114437032858, 18.643002974140607, 18.931268226645294, 19.220902204884826, 19.5118970485073, 19.804245023063473, 20.097938516722916, 20.392970037108203, 20.6893322082418], [0.0, 0.03045451157114848, 0.08320417761196276, 0.1497881503782946, 0.2273205122961679, 0.3141652494050648, 0.40923328680306326, 0.5117334390276407, 0.6210579419651958, 0.7367213866271994, 0.8583247559212069, 0.9855326850454627, 1.1180582883538033, 1.2556525979199056, 1.3980969568782564, 1.5451973843540991, 1.6967803010029854, 1.8526892205826855, 2.0127821442893477, 2.176929477213615, 2.345012339914519, 2.5169211838974657, 2.6925546442387054, 2.871818579669647, 3.0546252625784196, 3.2408926901737365, 3.430543994513664, 3.6235069339140007, 3.8197134518830254, 4.01909929250286, 4.2216036633185885, 4.427168938465239, 4.635740396075838, 4.847265985055732, 5.061696117141746, 5.278983480836284, 5.499082874351368, 5.721951055142535, 5.947546603978198, 6.175829801792166, 6.406762517818112, 6.640308107714411, 6.876431320563744, 7.115098213780196, 7.356276075082164, 7.599933350796174, 7.846039579847937, 8.094565332874941, 8.345482155962177, 8.598762518560418, 8.85437976519675, 9.112308070630451, 9.37252239814539, 9.634998460703207, 9.89971268471043, 10.166642176178392, 10.435764689077015, 10.70705859570344, 10.980502858904034, 11.256077006003649, 11.533761104310045, 11.813535738073444, 12.095381986792281, 12.379281404765988, 12.665216001804323, 12.953168225010819, 13.243120941564763, 13.535057422432699, 13.828961326946075, 14.124816688186849, 14.422607899127621, 14.722319699477065, 15.023937163185284, 15.32744568656731, 15.632830977005987, 15.940079042198626, 16.249176179914222, 16.560108968230626, 16.87286425622324, 17.187429155078743, 17.503791029609385, 17.821937490144926, 18.14185638478098, 18.46353579196389, 18.786964013393728, 19.112129567228013, 19.439021181570084, 19.767627788227017, 20.097938516722916, 20.4299426885544, 20.763629811675802, 21.09898957520247, 21.436011844321257, 21.77468665539785, 22.11500421127143, 22.456954876727362, 22.800529174139594, 23.14571777927449, 23.492511517248694, 23.84090135863373, 24.190878415700592, 24.542433938798027], [0.0, 0.03548133892335754, 0.09693787466570612, 0.1745122103783815, 0.26484207839513324, 0.3660214239864063, 0.4767814093441228, 0.5962002557859547, 0.7235698815405112, 0.8583247559212069, 1.0, 1.1482048935984939, 1.302605197672336, 1.4629108496029128, 1.628867100981764, 1.8002479524148156, 1.976851173518695, 2.158494448402884, 2.345012339914519, 2.536253862184367, 2.7320805135087913, 2.932364663298277, 3.1369882153158803, 3.3458414893176824, 3.5588222773558567, 3.7758350412431145, 3.9967902252007086, 4.2216036633185885, 4.450196065687834, 4.682492570296794, 4.91842235027662, 5.157918268026336, 5.400916569277413, 5.647356611371821, 5.8971806209984265, 6.15033347741503, 6.406762517818112, 6.666417362040764, 6.92924975418532, 7.195213419149126, 7.464263932294461, 7.736358600757849, 8.011456355098991, 8.28951765016242, 8.570504374171238, 8.85437976519675, 9.141108334254072, 9.430655794364634, 9.722988995004917, 10.01807586142811, 10.315885338403977, 10.616387337972748, 10.91955269085327, 11.225353101184101, 11.533761104310045, 11.844750027356401, 12.158293952359221, 12.474367681742986, 12.792946705957563, 13.114007173104234, 13.437525860396864, 13.7634801473184, 14.091847990345768, 14.422607899127623, 14.755738914009575, 15.091220584810793, 15.429032950763993, 15.769156521538333, 16.111572259271473, 16.4562615615429, 16.803206245226367, 17.152388531164018, 17.50379102960938, 17.85739672639053, 18.213188969748252, 18.571151457807776, 18.931268226645294, 19.293523638913687, 19.657902372994293, 20.02438941264386, 20.392970037108203, 20.7636298116758, 21.13635457864666, 21.511130448693265, 21.88794379259212, 22.266781233305686, 22.647629638395937, 23.030476112751966, 23.415307991615098, 23.802112833886202, 24.19087841570059, 24.581592724257074, 24.97424395188836, 25.368820490360804, 25.765310925392388, 26.163704031378167, 26.563988766313358, 26.966154266904585, 27.37018984386054, 27.776084977353598, 28.18382931264455, 28.59341265586308], [0.0, 0.04073984698322584, 0.11130454206620123, 0.2003757739491475, 0.30409297044408795, 0.42026759018308085, 0.5474427473857084, 0.6845600512581069, 0.8308064788452975, 0.9855326850454627, 1.1482048935984939, 1.3183744776835287, 1.4956576623942097, 1.6797213964123947, 1.8702731763688534, 2.06705350865336, 2.269830191350091, 2.478393888461373, 2.6925546442387054, 2.91213909596817, 3.1369882153158803, 3.3669554562143813, 3.6019052199864996, 3.841711571239436, 4.086257154307331, 4.335432271776015, 4.58913409526208, 4.847265985055732, 5.109736900095536, 5.376460883453368, 5.64735661137182, 5.922346996128907, 6.201358834761515, 6.484322497072933, 6.771171647464598, 7.061842996030579, 7.356276075082164, 7.654413037865167, 7.956198476721745, 8.261579258352578, 8.570504374171238, 8.88292480402296, 9.198793391775414, 9.518064731487579, 9.840695063030712, 10.166642176178392, 10.495865322304503, 10.828325132932465, 11.163983544468946, 11.502803728532704, 11.844750027356401, 12.189787893797396, 12.537883835544326, 12.889005363150615, 13.243120941564763, 13.600199944861513, 13.960212613907832, 14.323130016724196, 14.688924011325206, 15.057567210844033, 15.429032950763991, 15.803295258096707, 16.180328822361112, 16.56010896823063, 16.94261162972752, 17.327813325854077, 17.715691137559627, 18.106222685950918, 18.499386111661245, 18.895160055300348, 19.293523638913687, 19.694456448385207, 20.097938516722913, 20.50395030817133, 20.912472703099056, 21.32348698361369, 21.736974819859807, 22.152918256958916, 22.571299702553492, 22.99210191491955, 23.415307991615098, 23.840901358633726, 24.268865760035027, 24.699185248025174, 25.13184417346305, 25.566827176768694, 26.004119179212502, 26.443705374565027, 26.885571221088377, 27.32970243385165, 27.776084977353594, 28.224705058437106, 28.675549119480806, 29.12860383185402, 29.58385608962228, 30.041293003491052, 30.500901894976415, 30.96267029079175, 31.42658591744047, 31.892636696005013, 32.36081073712315, 32.8310963361431], [0.0, 0.046218176501939295, 0.12627177939085826, 0.22732051229616793, 0.3449846678798449, 0.4767814093441227, 0.621057941965196, 0.7766135520403609, 0.9425258885738264, 1.1180582883538033, 1.302605197672336, 1.4956576623942097, 1.6967803010029858, 1.9055952764240074, 2.1217707520563156, 2.3450123399145193, 2.5750566136501094, 2.8116660876364787, 3.054625262578419, 3.303737463497893, 3.5588222773558567, 3.8197134518830254, 4.086257154307331, 4.358310514572963, 4.635740396075839, 4.918422350276621, 5.206239721352429, 5.499082874351368, 5.796848525825953, 6.0994391601307, 6.4067625178181125, 6.7187311451001985, 7.0352619953354, 7.356276075082165, 7.681698128525125, 8.011456355098991, 8.345482155962175, 8.683709905647403, 9.026076745771554, 9.372522398145392, 9.722988995004915, 10.077420924404255, 10.435764689077015, 10.797968777298138, 11.163983544468946, 11.533761104310045, 11.907255228685266, 12.284421255198106, 12.665216001804328, 13.049597687772023, 13.437525860396866, 13.828961326946077, 14.223866091362412, 14.622203295309687, 15.023937163185288, 15.429032950763993, 15.837456897171252, 16.249176179914222, 16.664158872725512, 17.082373905997873, 17.503791029609385, 17.92838077795696, 18.35611443703286, 18.78696401339373, 19.220902204884823, 19.65790237299429, 20.09793851672292, 20.540985247864448, 20.98701776760044, 21.436011844321254, 21.88794379259212, 22.342790453189615, 22.80052917413959, 23.261137792693262, 23.724594618182532, 24.190878415700592, 24.659968390557307, 25.13184417346305, 25.606485806397714, 26.08387372912479, 26.563988766313358, 27.046812115233163, 27.532325333990617, 28.0205103302755, 28.511349350590443, 29.004824969936816, 29.5009200819326, 29.999617889339287, 30.500901894976415, 31.004755893003583, 31.511163960551112, 32.020110449681745, 32.53157997966668, 33.045557429560446, 33.56202793105995, 34.08097686163385, 34.60238983790933, 35.126252709303955, 35.65255155189132, 36.181272662489285, 36.71240255296073, 37.2459279447172], [0.0, 0.05190603566941788, 0.14181146858590882, 0.2552958059507203, 0.3874403499156256, 0.5354567123368216, 0.6974886966184848, 0.8721878227253049, 1.0585182301515081, 1.2556525979199056, 1.4629108496029128, 1.6797213964123947, 1.9055952764240074, 2.140108153885916, 2.382887354587466, 2.633602261563062, 2.8919570297907495, 3.1576849473762336, 3.4305439945136635, 3.710313292336801, 3.996790225200708, 4.289788080931242, 4.58913409526208, 4.894667815774406, 5.206239721352429, 5.523710048145414, 5.846947784032986, 6.175829801792165, 6.510240107354929, 6.8500691842722095, 7.195213419149125, 7.545574595660792, 7.9010594469960695, 8.261579258352578, 8.627049512526641, 8.997389572786458, 9.37252239814539, 9.752374286910662, 10.13687464500602, 10.525955776081727, 10.91955269085327, 11.317602933467466, 11.720046422994521, 12.126825308397448, 12.537883835544326, 12.953168225010817, 13.372626559575892, 13.7962086804466, 14.223866091362414, 14.65555186982823, 15.091220584810793, 15.530828220307319, 15.974332104259929, 16.421690842345924, 16.872864256223238, 17.327813325854077, 17.786500135567785, 18.24888782355775, 18.714940534537163, 19.184623375304607, 19.65790237299429, 20.134744435806386, 20.615117316031828, 21.098989575202474, 21.58633055121251, 22.077110327270525, 22.57129970255349, 23.068870164444956, 23.56979386224955, 24.074043582284478, 24.581592724257074, 25.092415278844413, 25.606485806397703, 26.123779416700245, 26.644271749712818, 27.167938957245948, 27.694757685502296, 28.224705058437106, 28.757758661888197, 29.293896528430402, 29.833097122912704, 30.37533932863901, 30.920602434156404, 31.46886612061695, 32.020110449681745, 32.57431585193741, 33.131463115797914, 33.69153337686557, 34.25450810772752, 34.82036910816486, 35.389098495753316, 35.9606786968357, 36.53509243784741, 37.11232273697751, 37.69235289614899, 38.27516649330259, 38.860747374969705, 39.4490796491206, 40.04014767827504, 40.63393607286306, 41.23042968482432, 41.82961360143534], [0.0, 0.05779438567104081, 0.1578989148820623, 0.28425719820495393, 0.43139254845346575, 0.5962002557859547, 0.776613552040361, 0.9711309822466542, 1.1785991753026108, 1.3980969568782564, 1.628867100981764, 1.8702731763688534, 2.1217707520563156, 2.382887354587466, 2.6532080326607357, 2.932364663298277, 3.2200278400817948, 3.515900594655237, 3.819713451883025, 4.131220475850052, 4.450196065687834, 4.77643232812803, 5.109736900095536, 5.449931127049401, 5.796848525825953, 6.150333477415031, 6.51024010735493, 6.876431320563744, 7.2487779643173935, 7.627158098347986, 8.011456355098991, 8.401563376340938, 8.797375314843274, 9.198793391775416, 9.605723502091545, 10.01807586142811, 10.435764689077013, 10.858707922441837, 11.286826959078443, 11.720046422994523, 12.15829395235922, 12.601500006171772, 13.049597687772023, 13.502522583357225, 13.960212613907832, 14.422607899127621, 14.889650632176672, 15.361284964123596, 15.837456897171252, 16.318114185819795, 16.803206245226367, 17.292684066103178, 17.786500135567785, 18.2846083634224, 18.78696401339373, 19.29352363891369, 19.804245023063476, 20.319087122341305, 20.8380100139473, 21.360974846308352, 21.88794379259212, 22.418880006982583, 22.953747583510207, 23.4925115172487, 24.03513766770658, 24.581592724257078, 25.131844173463055, 25.685860268165822, 26.24360999821773, 26.805063062748015, 27.37018984386054, 27.93896138166999, 28.511349350590436, 29.087326036796984, 29.666864316786874, 30.24993763697261, 30.836519994243897, 31.42658591744047, 32.02011044968175, 32.61706913150313, 33.217437984752415, 33.821193497202884, 34.42831260784282, 35.03877269280355, 35.65255155189132, 36.26962739568978, 36.88997883320266, 37.51358486000806, 38.14042484689721, 38.77047852897306, 39.403725995184544, 40.04014767827504, 40.679724345123745, 41.32243708746077, 41.96826731293767, 42.617196736535846, 43.26920737229698, 43.924281525359895, 44.58240178428964, 45.24355101368508, 45.90771234705219, 46.57486917993097], [0.0, 0.06387520774571051, 0.17451221037838147, 0.3141652494050648, 0.47678140934412266, 0.658929319071483, 0.858324755921207, 1.0733082897078543, 1.3026051976723358, 1.5451973843540991, 1.8002479524148156, 2.06705350865336, 2.3450123399145193, 2.633602261563062, 2.932364663298277, 3.240892690173736, 3.558822277355856, 3.8858252110360385, 4.2216036633185885, 4.565885822201574, 4.91842235027662, 5.278983480836283, 5.64735661137182, 6.023344290248695, 6.406762517818112, 6.797439301654028, 7.195213419149125, 7.5999333507961735, 8.011456355098991, 8.42964766187439, 8.85437976519675, 9.285531800737383, 9.722988995004913, 10.166642176178392, 10.616387337972748, 11.072125249384701, 11.533761104310043, 12.001204205956462, 12.474367681742986, 12.953168225010819, 13.437525860396864, 13.927363730161066, 14.42260789912762, 14.92318717621137, 15.429032950763991, 15.940079042198626, 16.4562615615429, 16.97751878373385, 17.50379102960939, 18.035020556672247, 18.571151457807776, 19.112129567228013, 19.65790237299429, 20.208418935539978, 20.763629811675802, 21.32348698361369, 21.887943792592125, 22.456954876727362, 23.030476112751963, 23.608464561334102, 24.19087841570059, 24.777676953311914, 25.368820490360804, 25.964270338886248, 26.56398876631335, 27.167938957245948, 27.776084977353598, 28.38839173920812, 29.004824969936813, 29.625351180570238, 30.249937636972607, 30.878552332251388, 31.511163960551105, 32.147741892143586, 32.78825614973339, 33.432677385903865, 34.08097686163385, 34.733126425821204, 35.38909849575332, 36.04886603846902, 36.712402552960725, 37.37968205316858, 38.05067905172216, 38.72536854438805, 39.40372599518454, 40.085727322127205, 40.77134888357138, 41.46056746512005, 42.15336026706735, 42.84970489235004, 43.54957933498074, 44.25296196893873, 44.95983153749511, 45.67016714295106, 46.383948236768724, 47.1011546100758, 47.82176638452579, 48.54576400349702, 49.27312822361472, 50.00384010658073, 50.73788101129701, 51.475232586269385], [0.0, 0.0701413264886539, 0.19163175129130933, 0.3449846678798449, 0.5235533734725494, 0.7235698815405112, 0.9425258885738265, 1.1785991753026108, 1.4303899694461426, 1.6967803010029854, 1.976851173518695, 2.269830191350091, 2.5750566136501094, 2.8919570297907495, 3.2200278400817948, 3.558822277355856, 3.907940562242242, 4.26702228335883, 4.635740396075838, 5.013796423800488, 5.400916569277413, 5.796848525825952, 6.201358834761515, 6.614230674565199, 7.0352619953354, 7.464263932294461, 7.90105944699607, 8.345482155962173, 8.797375314843274, 9.256590932583787, 9.722988995004915, 10.196436781061378, 10.676808258052619, 11.163983544468946, 11.657848431072447, 12.15829395235922, 12.665216001804323, 13.178514985315687, 13.698095508165379, 14.223866091362412, 14.755738914009575, 15.293629578669604, 15.837456897171249, 16.387142694627517, 16.94261162972752, 17.503791029609385, 18.070610737831686, 18.643002974140607, 19.220902204884826, 19.804245023063473, 20.392970037108203, 20.98701776760044, 21.58633055121251, 22.190852451237514, 22.800529174139594, 23.415307991615098, 24.03513766770658, 24.659968390557307, 25.289751708434334, 25.92444046968369, 26.563988766313354, 27.208351880927644, 27.857486236762096, 28.511349350590443, 29.169899788295304, 29.833097122912704, 30.500901894976415, 31.17327557500304, 31.850180527972064, 32.531579979666674, 33.21743798475241, 33.907719396480196, 34.602389837909314, 35.30141567455402, 36.00476398836459, 36.712402552960725, 37.424299810040935, 38.140424846897204, 38.86074737496971, 39.58523770938035, 40.313866749388936, 41.04660595971907, 41.7834273527049, 42.52430347121302, 43.269207372296975, 44.0181126115444, 44.77099322807979, 45.527823730188, 46.28857908152599, 47.053234687892335, 47.82176638452578, 48.594150423906214, 49.37036346403268, 50.15038255715487, 50.934185138936, 51.72174901802574, 52.513052366024, 53.3080737078165, 54.10679191226518, 54.90918618323646, 55.71523605095198, 56.52492136364724], [0.0, 0.0765862730879684, 0.20923986430590122, 0.37668363728025256, 0.5716601559193765, 0.7900552116711762, 1.0291300251709918, 1.2868949422503626, 1.5618215723367257, 1.8526892205826855, 2.158494448402884, 2.478393888461373, 2.8116660876364787, 3.1576849473762336, 3.515900594655237, 3.8858252110360385, 4.26702228335883, 4.6590982837860695, 5.061696117141746, 5.474489881265328, 5.8971806209984265, 6.329492846422123, 6.771171647464598, 7.221980279928254, 7.681698128525125, 8.150118974608336, 8.627049512526641, 9.11230807063045, 9.605723502091545, 10.10713421767338, 10.616387337972748, 11.133337946850663, 11.657848431072447, 12.189787893797398, 12.729031631654175, 13.275460666826746, 13.828961326946075, 14.389424866701587, 14.95674712600606, 15.53082822030732, 16.111572259271473, 16.698887090589718, 17.292684066103174, 17.8928778278133, 18.49938611166125, 19.112129567228017, 19.73103159173675, 20.35601817693455, 20.98701776760045, 21.623961130571516, 22.26678123330569, 22.915413131108846, 23.569793862249554, 24.22986235026798, 24.895559312858346, 25.566827176768697, 26.243609998217735, 26.925853388378588, 27.61350444352336, 28.306511679461085, 29.004824969936816, 29.708395488690073, 30.417175654898674, 31.131119081758555, 31.850180527972064, 32.57431585193742, 33.30348196844925, 34.037636807736625, 34.77673927667938, 35.52074922205612, 36.26962739568978, 37.02333542136683, 37.78183576341605, 38.54509169684179, 39.31306727891424, 40.085727322127205, 40.86303736843978, 41.644963664725, 42.43147313935406, 43.22253337984925, 44.01811261154441, 44.81817967719483, 45.62270401748369, 46.43165565237465, 47.24500516326446, 48.06272367589184, 48.88478284396224, 49.71115483345035, 50.541812307544866, 51.3767284122024, 52.21587676227887, 53.059231428209614, 53.90676692321033, 54.75845819097312, 55.61428059383364, 56.474209901385926, 57.338222279523954, 58.206294279889285, 59.07840282970597, 59.95452522198448, 60.83463910607773, 61.71872247857322], [0.0, 0.08320417761196275, 0.22732051229616787, 0.40923328680306315, 0.6210579419651958, 0.8583247559212068, 1.1180582883538035, 1.3980969568782562, 1.6967803010029854, 2.0127821442893477, 2.345012339914519, 2.6925546442387054, 3.054625262578419, 3.4305439945136635, 3.819713451883025, 4.2216036633185885, 4.635740396075838, 5.061696117141746, 5.499082874351367, 5.947546603978198, 6.406762517818111, 6.876431320563743, 7.356276075082163, 7.846039579847937, 8.345482155962173, 8.85437976519675, 9.37252239814539, 9.899712684710428, 10.435764689077013, 10.980502858904034, 11.533761104310043, 12.09538198679228, 12.665216001804323, 13.243120941564761, 13.828961326946075, 14.42260789912762, 15.023937163185284, 15.632830977005986, 16.249176179914222, 16.872864256223238, 17.50379102960938, 18.141856384780976, 18.786964013393728, 19.43902118157008, 20.097938516722913, 20.7636298116758, 21.436011844321254, 22.115004211271426, 22.800529174139594, 23.492511517248694, 24.19087841570059, 24.895559312858342, 25.606485806397707, 26.32359154217443, 27.046812115233163, 27.776084977353594, 28.51134935059044, 29.252546146318174, 29.99961788933928, 30.752508646656946, 31.51116396055111, 32.275530785630146, 33.04555742956044, 33.82119349720289, 34.602389837909314, 35.38909849575331, 36.181272662489285, 36.9788666330509, 37.78183576341605, 38.59013643067907, 39.40372599518454, 40.22256276458789, 41.04660595971906, 41.87581568213493, 42.71015288325465, 43.54957933498074, 44.39405760171486, 45.243551013685064, 46.09802364150652, 46.957440271903494, 47.82176638452578, 48.69096812979672, 49.56501230773516, 50.44386634769665, 51.32749828898392, 52.21587676227886, 53.108970971852266, 54.00675067850992, 54.90918618323646, 55.816248311500885, 56.72790839818966, 57.644138273135795, 58.564910247213746, 59.49019709897238, 60.41997206177952, 61.35420881145304, 62.29288145435548, 63.23596451592981, 64.183432929656, 65.13526202640848, 66.091427524196, 67.05190551826689], [0.0, 0.08998968287983806, 0.24585905901284125, 0.44260726757050084, 0.6717067441985916, 0.9283232502277446, 1.209238690866737, 1.512115201372435, 1.8351569066174063, 2.176929477213615, 2.536253862184367, 2.91213909596817, 3.303737463497893, 3.710313292336801, 4.131220475850052, 4.565885822201574, 5.013796423800488, 5.474489881265328, 5.947546603978198, 6.432583653445118, 6.92924975418532, 7.437221202623215, 7.956198476721746, 8.485903399538666, 9.026076745771556, 9.576476206323917, 10.136874645006023, 10.707058595703442, 11.286826959078443, 11.875989866064845, 12.474367681742988, 13.081790128113095, 13.69809550816538, 14.3231300167242, 14.956747126006062, 15.598807035815678, 16.249176179914222, 16.907726781408805, 17.57433645109259, 18.248887823557755, 18.931268226645297, 19.621369380415338, 20.31908712234131, 21.024321155869917, 21.73697481985981, 22.456954876727366, 23.184171317397595, 23.918537181388682, 24.659968390557317, 25.408383595203023, 26.16370403137817, 26.92585338837859, 27.6947576855023, 28.470345157261438, 29.25254614631818, 30.041293003491056, 30.836519994243904, 31.638163211128496, 32.446160491703644, 33.260451341499106, 34.08097686163385, 34.907679680734155, 35.74050389082946, 36.579394986933195, 37.42429981004094, 38.27516649330259, 39.131944411145035, 39.994584131141394, 40.86303736843978, 41.737256942579315, 42.617196736535846, 43.50281165785158, 44.39405760171487, 45.29089141586645, 46.19327086721771, 47.10115461007581, 48.01450215587732, 48.93327384434022, 49.85743081595, 50.786934985701734, 51.721749018025754, 52.6618363028292, 53.607160932590816, 54.55768768045003, 55.51338197923611, 56.474209901385926, 57.44013813970283, 58.41113398891198, 59.387165327970266, 60.368200603091964, 61.354208811453056, 62.34515948554014, 63.34102267811142, 64.3417689477395, 65.3473693449075, 66.35779539863157, 67.37301910358438, 68.3930129076962, 69.41774970021063, 70.44720280017424, 71.48134594533971, 72.52015328146409], [0.0, 0.09693787466570612, 0.26484207839513324, 0.4767814093441227, 0.7235698815405112, 1.0, 1.3026051976723363, 1.628867100981764, 1.976851173518695, 2.345012339914519, 2.7320805135087913, 3.1369882153158803, 3.5588222773558567, 3.996790225200708, 4.450196065687834, 4.91842235027662, 5.400916569277413, 5.8971806209984265, 6.406762517818111, 6.92924975418532, 7.464263932294461, 8.011456355098991, 8.570504374171238, 9.141108334254072, 9.722988995004915, 10.315885338403977, 10.91955269085327, 11.533761104310043, 12.15829395235922, 12.792946705957565, 13.437525860396864, 14.091847990345768, 14.755738914009575, 15.429032950763993, 16.111572259271473, 16.803206245226367, 17.503791029609385, 18.213188969748252, 18.931268226645294, 19.65790237299429, 20.392970037108203, 21.136354578646657, 21.88794379259212, 22.647629638395934, 23.415307991615098, 24.19087841570059, 24.974243951888358, 25.765310925392388, 26.56398876631336, 27.37018984386054, 28.183829312644548, 29.004824969936816, 29.833097122912704, 30.66856846500056, 31.511163960551112, 32.360810737123145, 33.217437984752415, 34.08097686163385, 34.95136040570314, 35.828523451652586, 36.712402552960725, 37.60293590855371, 38.500063293751694, 39.403725995184544, 40.313866749388936, 41.230429684824315, 42.153360267067356, 43.08260524696495, 44.0181126115444, 44.959831537495106, 45.90771234705218, 46.86170646612489, 47.82176638452577, 48.787845618167246, 49.759898673102455, 50.737881011297006, 51.72174901802574, 52.71145997079731, 53.70697200971593, 54.70824410919604, 55.71523605095197, 56.72790839818966, 57.746222470932864, 58.770140322420495, 59.79962471651665, 60.83463910607772, 61.875147612225696, 62.92111500447935, 63.972506681698285, 65.029288653798, 66.09142752419599, 67.15889047295224, 68.23164524056898, 69.30966011241729, 70.3929039037597, 71.4813459453397, 72.57495606951116, 73.67370459688196, 74.77756232344761, 75.88650050819204, 77.00049086113405, 78.11950553179918], [0.0, 0.10404422446536338, 0.28425719820495393, 0.5117334390276407, 0.7766135520403608, 1.073308289707854, 1.3980969568782566, 1.7482765623161276, 2.121770752056315, 2.5169211838974657, 2.932364663298277, 3.3669554562143813, 3.8197134518830254, 4.289788080931242, 4.77643232812803, 5.278983480836283, 5.796848525825952, 6.329492846422123, 6.876431320563743, 7.437221202623215, 8.011456355098991, 8.598762518560417, 9.198793391775414, 9.811227352272452, 10.435764689077013, 11.072125249384701, 11.720046422994521, 12.379281404765985, 13.049597687772021, 13.730775749295042, 14.42260789912762, 15.124897265341078, 15.837456897171247, 16.56010896823063, 17.292684066103174, 18.035020556672244, 18.786964013393728, 19.54836670324645, 20.319087122341305, 21.09898957520247, 21.88794379259212, 22.68582458346602, 23.492511517248694, 24.30788863312365, 25.13184417346305, 25.964270338886244, 26.805063062748015, 27.654121803123996, 28.511349350590443, 29.376651650293237, 30.249937636972607, 31.13111908175855, 32.02011044968174, 32.916828766957984, 33.82119349720289, 34.73312642582121, 35.65255155189133, 36.57939498693318, 37.51358486000805, 38.45505122865099, 39.40372599518454, 40.35954282800384, 41.32243708746077, 42.292345756008444, 43.26920737229697, 44.25296196893873, 45.24355101368508, 46.240917353778585, 47.24500516326445, 48.25575989306212, 49.27312822361472, 50.297058019948004, 51.32749828898391, 52.364399138965915, 53.407711740863725, 54.4573882916358, 55.513381979236094, 56.57564694926048, 57.64413827313581, 58.718811917760995, 59.79962471651665, 60.88653434156477, 61.97949927736621, 63.07847879534774, 64.183432929656, 65.29432245393882, 66.41110885909897, 67.53375433196894, 68.66222173485787, 69.7964745859263, 70.93647704034541, 72.08219387220147, 73.23359045710815, 74.39063275549128, 75.55328729651366, 76.72152116260801, 77.89530197458969, 79.07459787732105, 80.25937752590204, 81.4496100723618, 82.64526515282905, 83.84631287515863], [0.0, 0.11130454206620125, 0.30409297044408795, 0.5474427473857084, 0.8308064788452975, 1.1482048935984939, 1.49565766239421, 1.8702731763688534, 2.269830191350091, 2.6925546442387054, 3.1369882153158803, 3.6019052199864996, 4.086257154307331, 4.58913409526208, 5.109736900095536, 5.64735661137182, 6.201358834761515, 6.771171647464598, 7.356276075082163, 7.956198476721746, 8.570504374171238, 9.198793391775414, 9.840695063030712, 10.495865322304503, 11.163983544468946, 11.844750027356401, 12.537883835544326, 13.243120941564761, 13.96021261390783, 14.688924011325208, 15.429032950763991, 16.180328822361112, 16.94261162972752, 17.715691137559627, 18.49938611166125, 19.293523638913687, 20.097938516722913, 20.912472703099056, 21.73697481985981, 22.57129970255349, 23.415307991615098, 24.268865760035027, 25.13184417346305, 26.0041191792125, 26.885571221088377, 27.776084977353598, 28.675549119480802, 29.58385608962228, 30.50090189497642, 31.42658591744047, 32.360810737123145, 33.30348196844924, 34.25450810772752, 35.2138003911741, 36.181272662489285, 37.15684124917948, 38.14042484689721, 39.13194441114503, 40.131323055752986, 41.138485957595904, 42.15336026706735, 43.175875023871896, 44.20596107773744, 45.24355101368508, 46.28857908152598, 47.34098112928389, 48.40069454026705, 49.46765817353731, 50.541812307544866, 51.623098586715784, 52.711459970797314, 53.80684068678079, 54.90918618323645, 56.018443086907475, 57.13455916142145, 58.25748326798932, 59.38716532797025, 60.523556287190594, 61.666608081913175, 62.81627360635987, 63.972506681698285, 65.13526202640847, 66.30449522795243, 67.48016271567337, 68.66222173485787, 69.85063032189674, 71.04534728048671, 72.2463321588168, 73.45354522768832, 74.66694745951989, 75.88650050819204, 77.11216668968903, 78.3439089634977, 79.58169091472587, 80.82547673690542, 82.0752312154459, 83.33091971170843, 84.59250814766973, 85.8599629911489, 87.1332512415707, 88.41234041624023, 89.69719853710643], [0.0, 0.11871493586631204, 0.324338762942797, 0.5838901938765246, 0.886119614011563, 1.2246496663528565, 1.5952350207189234, 1.994791551750462, 2.420950130078923, 2.871818579669647, 3.3458414893176824, 3.841711571239436, 4.358310514572963, 4.894667815774406, 5.449931127049401, 6.023344290248695, 6.614230674565199, 7.221980279928254, 7.846039579847937, 8.485903399538666, 9.141108334254072, 9.811227352272452, 10.495865322304503, 11.194655271639567, 11.907255228685266, 12.633345537810754, 13.372626559575894, 14.12481668818685, 14.889650632176673, 15.666877915120807, 16.456261561542902, 17.257576939672116, 18.07061073783169, 18.895160055300355, 19.731031591736752, 20.578040921874706, 21.436011844321257, 22.304775795023723, 23.184171317397595, 24.074043582284485, 24.97424395188836, 25.884629582655304, 26.80506306274802, 27.735412080344645, 28.675549119480806, 29.625351180570245, 30.584699523094926, 31.5534794282594, 32.53157997966669, 33.51889386029816, 34.515317164276006, 35.520749222056125, 36.53509243784741, 37.55825213818268, 38.59013643067908, 39.6306560721258, 40.679724345123745, 41.73725694257932, 42.80317185942279, 43.87738929098184, 44.95983153749511, 46.05042291429815, 47.149089667256874, 48.25575989306214, 49.37036346403268, 50.49283195710501, 51.6230985867158, 52.761098141307464, 53.90676692321032, 55.06004269167402, 56.22086460884037, 57.38917318846535, 58.564910247213746, 59.748018858363196, 60.938443307766875, 62.13612905193582, 63.34102267811141, 64.55307186620888, 65.77222535252083, 66.99843289507757, 68.23164524056898, 69.47181409273838, 70.71889208216575, 71.97283273736282, 73.23359045710815, 74.50112048395452, 75.77537887884594, 77.05632249678534, 78.3439089634977, 79.63809665303734, 80.93884466629063, 82.246112810329, 83.55986157856928, 84.88005213170173, 86.20664627934802, 87.53960646241337, 88.87889573610008, 90.22447775355042, 91.57631675009006, 92.93437752804327, 94.29862544209399, 95.669026385168], [0.0, 0.12627177939085826, 0.3449846678798449, 0.621057941965196, 0.9425258885738264, 1.302605197672336, 1.6967803010029858, 2.1217707520563156, 2.5750566136501094, 3.0546252625784196, 3.5588222773558567, 4.086257154307331, 4.635740396075839, 5.206239721352429, 5.796848525825953, 6.406762517818112, 7.0352619953354, 7.681698128525125, 8.345482155962173, 9.026076745771556, 9.722988995004915, 10.435764689077013, 11.163983544468946, 11.907255228685266, 12.665216001804326, 13.437525860396866, 14.223866091362414, 15.023937163185286, 15.83745689717125, 16.664158872725515, 17.503791029609385, 18.35611443703286, 19.220902204884823, 20.097938516722916, 20.987017767600445, 21.88794379259212, 22.800529174139594, 23.724594618182532, 24.65996839055731, 25.606485806397714, 26.563988766313354, 27.532325333990617, 28.511349350590443, 29.50092008193259, 30.500901894976415, 31.511163960551112, 32.53157997966668, 33.56202793105995, 34.60238983790933, 35.65255155189132, 36.71240255296073, 37.781835763416055, 38.860747374969705, 39.94903668767963, 41.046605959719074, 42.153360267067356, 43.26920737229698, 44.39405760171487, 45.527823730188, 46.67042087304785, 47.82176638452579, 48.98177976222179, 50.15038255715488, 51.32749828898393, 52.51305236602399, 53.70697200971593, 54.909186183236464, 56.11962552396201, 57.33822227952395, 58.564910247213746, 59.799624716516654, 61.042302414569605, 62.292881454355474, 63.55130128546016, 64.81750264723205, 66.091427524196, 67.37301910358437, 68.66222173485787, 69.95898089109865, 71.26324313216573, 72.57495606951116, 73.89406833256203, 75.2205295365802, 76.55429025191748, 77.89530197458969, 79.2435170980976, 80.59888888642823, 81.96137144817361, 83.33091971170843, 84.70748940137196, 86.09103701460221, 87.48151979997472, 88.87889573610006, 90.28312351133776, 91.69416250428667, 93.11197276501386, 94.5365149969867, 95.96775053967473, 97.40564135178991, 98.85014999513533, 100.30123961903443, 101.75887394531442], [0.0, 0.13397168281703664, 0.36602142398640636, 0.6589293190714832, 1.0, 1.382036518533576, 1.800247952414816, 2.251153817394716, 2.7320805135087913, 3.2408926901737365, 3.7758350412431145, 4.335432271776015, 4.918422350276621, 5.523710048145414, 6.150333477415031, 6.797439301654028, 7.464263932294461, 8.150118974608336, 8.85437976519675, 9.576476206323917, 10.315885338403977, 11.072125249384701, 11.844750027356401, 12.633345537810754, 13.437525860396866, 14.256930258679393, 15.091220584810795, 15.940079042198626, 16.803206245226367, 17.68031952728717, 18.571151457807776, 19.475448536281835, 20.392970037108203, 21.323486983613694, 22.26678123330569, 23.222644659354287, 24.19087841570059, 25.171292275145003, 26.16370403137817, 27.16793895724595, 28.183829312644548, 29.211213896364036, 30.24993763697261, 31.29985121848655, 32.360810737123145, 33.43267738590387, 34.515317164276006, 35.6086006102644, 36.71240255296074, 37.82660188341206, 38.95108134219182, 40.08572732212721, 41.230429684824315, 42.385081589778, 43.54957933498075, 44.72382220805764, 45.90771234705219, 47.1011546100758, 48.30405645311024, 49.51632781532052, 50.73788101129701, 51.96863062969876, 53.20849343781891, 54.457388291635816, 55.71523605095197, 56.981959499258004, 58.257483267989336, 59.54173376487182, 60.834639106077724, 62.13612905193581, 63.44613494596086, 64.76458965698562, 66.09142752419599, 67.42658430488544, 68.76999712475804, 70.12160443062375, 71.4813459453397, 72.84916262486267, 74.22499661728803, 75.60879122375832, 77.00049086113405, 78.40004102632565, 79.8073882621934, 81.22248012492776, 82.64526515282904, 84.07569283641018, 85.5137135897515, 86.95927872304138, 88.41234041624023, 89.87285169380998, 91.340766400454, 92.81603917781665, 94.29862544209399, 95.78848136251065, 97.28556384062064, 98.78983049039142, 100.30123961903443, 101.81975020854587, 103.34532189792503, 104.87791496603818, 106.41749031509814, 107.96400945473216], [0.0, 0.14181146858590885, 0.38744034991562565, 0.6974886966184848, 1.0585182301515084, 1.4629108496029128, 1.9055952764240076, 2.382887354587466, 2.8919570297907495, 3.430543994513664, 3.9967902252007086, 4.58913409526208, 5.206239721352429, 5.846947784032986, 6.51024010735493, 7.195213419149125, 7.90105944699607, 8.627049512526641, 9.37252239814539, 10.136874645006023, 10.91955269085327, 11.720046422994521, 12.537883835544326, 13.372626559575894, 14.223866091362414, 15.091220584810795, 15.97433210425993, 16.872864256223238, 17.786500135567785, 18.714940534537167, 19.65790237299429, 20.615117316031828, 21.586330551212512, 22.571299702553492, 23.569793862249554, 24.581592724257074, 25.60648580639771, 26.644271749712818, 27.6947576855023, 28.757758661888197, 29.833097122912704, 30.9206024341564, 32.020110449681745, 33.13146311579791, 34.25450810772752, 35.389098495753316, 36.53509243784741, 37.692352896148996, 38.86074737496971, 40.04014767827504, 41.230429684824315, 42.431473139354054, 43.64316145836644, 44.865381549239075, 46.09802364150652, 47.34098112928389, 48.59415042390623, 49.85743081594999, 51.13072434588479, 52.41393568267498, 53.706972009715926, 55.00974291754619, 56.322160302828216, 57.64413827313581, 58.975593057127185, 60.3164429197195, 61.666608081913175, 63.026010644944414, 64.39457451847112, 65.7722253525208, 67.15889047295224, 68.55449882020109, 69.95898089109862, 71.3722686835688, 72.79429564402318, 74.22499661728801, 75.66430779890867, 77.11216668968903, 78.5685120523334, 80.03328387006754, 81.50642330712499, 82.98787267099186, 84.47757537631121, 85.97547591035458, 87.48151979997472, 88.99565357995874, 90.51782476270674, 92.04798180916546, 93.58607410095127, 95.1320519136007, 96.68586639089091, 98.24746952017553, 99.81681410868532, 101.39385376074551, 102.97854285586531, 104.57083652765662, 106.17069064354266, 107.77806178521863, 109.39290722982952, 111.0151849318311, 112.64485350550295, 114.2818722080838], [0.0, 0.1497881503782946, 0.40923328680306315, 0.7367213866271995, 1.1180582883538033, 1.5451973843540991, 2.012782144289348, 2.5169211838974657, 3.054625262578419, 3.6235069339140007, 4.2216036633185885, 4.847265985055732, 5.499082874351368, 6.175829801792165, 6.876431320563744, 7.5999333507961735, 8.345482155962173, 9.11230807063045, 9.899712684710428, 10.707058595703442, 11.533761104310043, 12.379281404765985, 13.243120941564761, 14.12481668818685, 15.023937163185286, 15.940079042198626, 16.872864256223238, 17.821937490144926, 18.786964013393728, 19.767627788227017, 20.7636298116758, 21.774686655397847, 22.80052917413959, 23.84090135863373, 24.895559312858346, 25.964270338886244, 27.046812115233163, 28.14297195680193, 29.252546146318174, 30.375339328639015, 31.51116396055111, 32.6598398097056, 33.821193497202884, 34.99505807906977, 36.181272662489285, 37.37968205316859, 38.590136430679074, 39.812491048986416, 41.04660595971908, 42.29234575600844, 43.54957933498074, 44.818179677194834, 46.098023641506515, 47.38899177400348, 48.69096812979674, 50.00384010658073, 51.327498288983925, 52.6618363028292, 54.00675067850992, 55.36214072276308, 56.72790839818967, 58.103958209932024, 59.49019709897238, 60.88653434156478, 62.292881454355474, 63.709152104786135, 65.13526202640848, 66.57112893877044, 68.0166724715626, 69.47181409273838, 70.93647704034541, 72.41058625782576, 73.89406833256201, 75.38685143746363, 76.88886527540294, 78.40004102632565, 79.92031129687257, 81.4496100723618, 82.98787267099188, 84.53503570013528, 86.09103701460221, 87.6558156767616, 89.22931191841536, 90.81146710432752, 92.40222369731826, 94.00152522483688, 95.60931624693492, 97.22554232556494, 98.85014999513533, 100.48308673425637, 102.12430093861617, 103.77374189492923, 105.43135975590401, 107.09710551617884, 108.77093098917895, 110.45278878484939, 112.1426322882223, 113.84041563877858, 115.54609371056688, 117.25962209304436, 118.98095707260606, 120.71005561477168], [0.0, 0.1578989148820623, 0.43139254845346575, 0.7766135520403609, 1.1785991753026108, 1.628867100981764, 2.1217707520563156, 2.6532080326607357, 3.2200278400817948, 3.8197134518830254, 4.450196065687834, 5.109736900095536, 5.796848525825953, 6.510240107354929, 7.2487779643173935, 8.011456355098991, 8.797375314843274, 9.605723502091545, 10.435764689077013, 11.286826959078443, 12.15829395235922, 13.049597687772021, 13.96021261390783, 14.889650632176673, 15.83745689717125, 16.803206245226367, 17.786500135567785, 18.786964013393728, 19.804245023063476, 20.838010013947304, 21.88794379259212, 22.953747583510207, 24.03513766770658, 25.131844173463055, 26.243609998217735, 27.37018984386054, 28.51134935059044, 29.666864316786874, 30.8365199942439, 32.020110449681745, 33.21743798475241, 34.42831260784281, 35.65255155189132, 36.88997883320266, 38.14042484689721, 39.403725995184544, 40.679724345123745, 41.96826731293767, 43.26920737229699, 44.58240178428964, 45.90771234705218, 47.24500516326446, 48.59415042390622, 49.95502220684621, 51.32749828898393, 52.71145997079732, 54.10679191226519, 55.5133819792361, 56.93112109940648, 58.359903127150496, 59.79962471651665, 61.25018520176896, 62.711486484907745, 64.18343292965602, 65.66593126144228, 67.15889047295225, 68.66222173485787, 70.17583831136554, 71.69965548025515, 73.23359045710814, 74.77756232344761, 76.33149195853524, 77.89530197458967, 79.46891665520994, 81.05226189680272, 82.64526515282904, 84.24785538069798, 85.8599629911489, 87.48151979997473, 89.11245898194882, 90.75271502682881, 92.40222369731826, 94.0609219888764, 95.72874809127254, 97.40564135178991, 99.09154223998866, 100.78639231394477, 102.49013418788644, 104.2027115011544, 105.92406888841828, 107.65415195108349, 109.39290722982952, 111.14028217822177, 112.89622513734456, 114.66068531140496, 116.43361274426003, 118.21495829682353, 120.00467362530998, 121.80271116027728, 123.60902408642993, 125.42356632314824, 127.2462925057106], [0.0, 0.1661411058928041, 0.4539108779025307, 0.8171521285228424, 1.2401210643871723, 1.7138925983858002, 2.232525406909489, 2.791703268126781, 3.3881105944039747, 4.01909929250286, 4.682492570296794, 5.376460883453368, 6.0994391601307, 6.8500691842722095, 7.627158098347986, 8.42964766187439, 9.256590932583787, 10.10713421767338, 10.980502858904034, 11.875989866064845, 12.792946705957565, 13.730775749295042, 14.688924011325208, 15.666877915120807, 16.664158872725515, 17.68031952728717, 18.714940534537167, 19.767627788227017, 20.838010013947304, 21.925736670884675, 23.030476112751966, 24.151913968231423, 25.289751708434334, 26.443705374565027, 27.613504443523365, 28.79889081284352, 29.999617889339287, 31.215449768253425, 32.446160491703644, 33.69153337686557, 34.95136040570314, 36.22544166920033, 37.51358486000806, 38.815604808229665, 40.13132305575299, 41.46056746512005, 42.8031718594228, 44.15897569013881, 45.52782373018801, 46.90956578980678, 48.30405645311025, 49.71115483345035, 51.13072434588479, 52.56263249525263, 54.00675067850993, 55.46295400011909, 56.93112109940649, 58.41113398891197, 59.90287790284913, 61.40624115487943, 62.92111500447935, 64.44739353124584, 65.98497351654586, 67.53375433196895, 69.09363783408911, 70.66452826508657, 72.24633215881681, 73.83895825195047, 75.4423173998386, 77.05632249678534, 78.68088840043714, 80.31593186001945, 81.9613714481736, 83.61712749616593, 85.28312203225771, 86.95927872304138, 88.64552281756235, 90.3417810940589, 92.04798180916549, 93.76405464943466, 95.48993068504429, 97.22554232556494, 98.9708232776716, 100.72570850469135, 102.49013418788644, 104.26403768937794, 106.04735751662244, 107.84003328835887, 109.64200570194883, 111.4532165020381, 113.27360845047107, 115.10312529739547, 116.94171175349689, 118.78931346330752, 120.64587697953667, 122.51134973837253, 124.38568003570978, 126.2688170042579, 128.16071059148973, 130.0613115383906, 131.9705713589711, 133.88844232050917], [0.0, 0.1745122103783815, 0.4767814093441227, 0.858324755921207, 1.302605197672336, 1.8002479524148156, 2.3450123399145193, 2.9323646632982774, 3.558822277355856, 4.2216036633185885, 4.91842235027662, 5.64735661137182, 6.4067625178181125, 7.195213419149125, 8.011456355098991, 8.85437976519675, 9.722988995004915, 10.616387337972748, 11.533761104310043, 12.474367681742988, 13.437525860396864, 14.42260789912762, 15.429032950763991, 16.456261561542902, 17.503791029609385, 18.571151457807776, 19.65790237299429, 20.7636298116758, 21.88794379259212, 23.030476112751966, 24.19087841570059, 25.368820490360804, 26.563988766313354, 27.776084977353598, 29.004824969936816, 30.249937636972607, 31.51116396055111, 32.7882561497334, 34.08097686163385, 35.389098495753316, 36.712402552960725, 38.05067905172216, 39.403725995184544, 40.77134888357137, 42.15336026706735, 43.54957933498074, 44.95983153749511, 46.383948236768724, 47.821766384525795, 49.27312822361472, 50.73788101129701, 52.21587676227887, 53.706972009715926, 55.211027582610846, 56.727908398189676, 58.25748326798933, 59.799624716516654, 61.35420881145305, 62.92111500447934, 64.50022598188377, 66.091427524196, 67.69460837415936, 69.30966011241729, 70.93647704034542, 72.57495606951115, 74.22499661728801, 75.88650050819204, 77.55937188054446, 79.24351709809758, 80.93884466629062, 82.64526515282904, 84.36269111230547, 86.0910370146022, 87.83021917683573, 89.58015569862141, 91.340766400454, 93.11197276501385, 94.89369788122337, 96.68586639089094, 98.48840443779008, 100.30123961903442, 102.12430093861617, 103.9575187629873, 105.8008247785689, 107.65415195108349, 109.51743448661068, 111.39060779427378, 113.27360845047107, 115.16637416457044, 117.06884374599187, 118.98095707260605, 120.90265506038314, 122.83387963422841, 124.77457369994606, 126.7246811172763, 128.68414667395288, 130.65291606073268, 132.63093584735074, 134.61815345935784, 136.6145171557986, 138.61997600769232, 140.63447987727935], [0.0, 0.18300984620681973, 0.49999763460189295, 0.900119717904309, 1.3660337942963208, 1.887908589268498, 2.4591995411113934, 3.07515219072035, 3.7321143101914545, 4.427168938465239, 5.157918268026336, 5.922346996128907, 6.7187311451001985, 7.545574595660792, 8.401563376340938, 9.285531800737383, 10.196436781061378, 11.133337946850663, 12.09538198679228, 13.081790128113095, 14.091847990345768, 15.124897265341078, 16.180328822361112, 17.257576939672116, 18.35611443703286, 19.475448536281835, 20.615117316031828, 21.774686655397847, 22.953747583510207, 24.151913968231423, 25.368820490360804, 26.604120859639796, 27.857486236762096, 29.12860383185402, 30.417175654898674, 31.72291739761292, 33.04555742956044, 34.38483589395799, 35.74050389082946, 37.11232273697751, 38.500063293751694, 39.90350535485157, 41.32243708746077, 42.75665452089949, 44.20596107773744, 45.67016714295106, 47.14908966725687, 48.642551801221764, 50.150382557154884, 51.67241649613372, 53.20849343781891, 54.758458190973116, 56.32216030282821, 57.899453825643555, 59.49019709897239, 61.09425254630702, 62.711486484907745, 64.34176894773948, 65.98497351654585, 67.64097716518273, 69.30966011241729, 70.99090568347138, 72.68460017965464, 74.3906327554913, 76.10889530279707, 77.83928234121068, 79.58169091472588, 81.3360204938092, 83.10217288272267, 84.88005213170172, 86.66956445366729, 88.4706181451763, 90.28312351133773, 92.1069927944434, 93.94214010608027, 95.78848136251065, 97.64593422312029, 99.51441803175085, 101.39385376074551, 103.28416395754891, 105.1852726937141, 107.09710551617883, 109.0195894006837, 110.95265270721254, 112.89622513734454, 114.85023769341338, 116.81462263937708, 118.78931346330752, 120.77424484141457, 122.76935260352573, 124.77457369994605, 126.78984616962883, 128.81510910959122, 130.8503026455128, 132.89536790345994, 134.95024698267974, 137.01488292941403, 139.08921971168348, 141.17320219499717, 143.266776118944, 145.36988807462546, 147.4824854828916], [0.0, 0.19163175129130933, 0.5235533734725494, 0.9425258885738264, 1.4303899694461428, 1.976851173518695, 2.5750566136501094, 3.2200278400817948, 3.907940562242242, 4.635740396075838, 5.400916569277413, 6.201358834761515, 7.0352619953354, 7.9010594469960695, 8.797375314843274, 9.722988995004913, 10.676808258052619, 11.657848431072447, 12.665216001804323, 13.69809550816538, 14.755738914009575, 15.837456897171247, 16.94261162972752, 18.07061073783169, 19.220902204884823, 20.392970037108203, 21.586330551212512, 22.80052917413959, 24.03513766770658, 25.289751708434334, 26.563988766313354, 27.857486236762096, 29.169899788295304, 30.500901894976412, 31.850180527972068, 33.21743798475241, 34.602389837909314, 36.00476398836459, 37.424299810040935, 38.860747374969705, 40.313866749388936, 41.78342735270489, 43.269207372296975, 44.77099322807978, 46.28857908152599, 47.82176638452578, 49.37036346403267, 50.934185138936, 52.513052366024, 54.10679191226518, 55.71523605095197, 57.33822227952395, 58.975593057127185, 60.627195560174805, 62.29288145435548, 63.97250668169828, 65.66593126144228, 67.37301910358437, 69.09363783408911, 70.82765863084151, 72.57495606951115, 74.33540797857268, 76.10889530279708, 77.89530197458969, 79.69451479260582, 81.50642330712499, 83.33091971170843, 85.16789874070537, 87.01725757220963, 88.87889573610003, 90.7527150268288, 92.63861942064761, 94.53651499698665, 96.44630986372285, 98.36791408609396, 100.3012396190344, 102.2462002427236, 104.20271150115438, 106.17069064354266, 108.15005656841143, 110.14072977019552, 112.14263228822227, 114.15568765793526, 116.17982086423534, 118.2149582968235, 120.26102770743603, 122.31795816887085, 124.38568003570977, 126.46412490664781, 128.55322558834655, 130.65291606073265, 132.76313144366915, 134.88380796493007, 137.01488292941403, 139.1562946895361, 141.3079826167406, 143.46988707408087, 145.64194938981578, 147.82411183197476, 150.0163175838465, 152.2185107203484, 154.4306361852374], [0.0, 0.20037577394914752, 0.5474427473857084, 0.9855326850454629, 1.4956576623942097, 2.06705350865336, 2.6925546442387063, 3.366955456214382, 4.086257154307331, 4.847265985055732, 5.647356611371821, 6.484322497072933, 7.356276075082165, 8.261579258352578, 9.198793391775416, 10.166642176178392, 11.163983544468946, 12.189787893797398, 13.243120941564761, 14.3231300167242, 15.429032950763993, 16.56010896823063, 17.715691137559627, 18.895160055300355, 20.097938516722916, 21.323486983613694, 22.571299702553492, 23.84090135863373, 25.131844173463055, 26.443705374565027, 27.776084977353598, 29.12860383185402, 30.500901894976412, 31.892636696005017, 33.30348196844925, 34.73312642582121, 36.181272662489285, 37.6476361636848, 39.131944411145035, 40.633936072863065, 42.15336026706735, 43.68997589193309, 45.24355101368508, 46.81386230672815, 48.40069454026705, 50.00384010658074, 51.62309858671579, 53.25827634987709, 54.90918618323647, 56.575646949260495, 58.25748326798933, 59.95452522198448, 61.66660808191317, 63.39357205095521, 65.13526202640848, 66.89152737703773, 68.66222173485788, 70.44720280017422, 72.2463321588168, 74.05947511060768, 75.88650050819204, 77.72728060544337, 79.58169091472588, 81.44961007236184, 83.33091971170843, 85.22550434330175, 87.13325124157072, 89.05405033766657, 90.98779411799158, 92.93437752804326, 94.89369788122339, 96.86565477228731, 98.85014999513531, 100.84708746467108, 102.85637314247212, 104.87791496603818, 106.91162278139859, 108.95740827887772, 111.01518493183113, 113.08486793817819, 115.16637416457046, 117.25962209304436, 119.36453177001928, 121.4810247575096, 123.60902408642993, 125.74845421187885, 127.8992409702957, 130.0613115383906, 132.23459439375495, 134.4190192770653, 136.6145171557986, 138.82102018938264, 141.03846169570946, 143.266776118944, 145.5058989985653, 147.75576693957905, 150.01631758384653, 152.28748958247604, 154.5692225692277, 156.86145713488335, 159.16413480253814, 161.47719800377106], [0.0, 0.20923986430590125, 0.5716601559193765, 1.0291300251709918, 1.561821572336726, 2.158494448402884, 2.8116660876364787, 3.5159005946552373, 4.26702228335883, 5.061696117141746, 5.8971806209984265, 6.771171647464598, 7.681698128525125, 8.627049512526641, 9.605723502091545, 10.616387337972748, 11.657848431072447, 12.729031631654175, 13.828961326946075, 14.956747126006062, 16.111572259271473, 17.292684066103174, 18.49938611166125, 19.731031591736752, 20.987017767600445, 22.26678123330569, 23.569793862249554, 24.895559312858346, 26.243609998217735, 27.613504443523365, 29.004824969936816, 30.417175654898674, 31.850180527972068, 33.30348196844925, 34.776739276679386, 36.26962739568978, 37.781835763416055, 39.31306727891424, 40.86303736843978, 42.431473139354054, 44.01811261154441, 45.62270401748369, 47.24500516326446, 48.884782843962235, 50.54181230754487, 52.215876762278874, 53.90676692321032, 55.61428059383364, 57.33822227952396, 59.07840282970597, 60.834639106077724, 62.60675367450596, 64.39457451847112, 66.19793477216747, 68.01667247156261, 69.85063032189674, 71.69965548025516, 73.56359935198381, 75.4423173998386, 77.33566896486465, 79.2435170980976, 81.16572840226264, 83.10217288272268, 85.05272380699425, 87.01725757220963, 88.99565357995876, 90.9877941179916, 92.99356424830681, 95.01285170119156, 97.0455467748121, 99.09154223998867, 101.15073324981611, 103.22301725381854, 105.30829391635098, 107.4064650389817, 109.5174344866107, 111.64110811709588, 113.77739371417684, 115.92620092350093, 118.08744119156944, 120.26102770743606, 122.44687534699973, 124.64490061974645, 126.85502161780312, 129.07715796717707, 131.31123078106174, 133.55716261509812, 135.81487742448806, 138.08430052286215, 140.36535854281166, 142.65797939799862, 144.96209224676474, 147.2776274571632, 149.60451657334355, 151.94269228322304, 154.29208838738174, 156.65263976912303, 159.02428236564376, 161.40695314026232, 163.80059005565516, 166.20513204805485, 168.6205190023669], [0.0, 0.2182220666038348, 0.5962002557859547, 1.0733082897078543, 1.628867100981764, 2.2511538173947154, 2.9323646632982774, 3.666830392403761, 4.450196065687833, 5.278983480836284, 6.15033347741503, 7.061842996030579, 8.011456355098991, 8.997389572786458, 10.01807586142811, 11.072125249384701, 12.15829395235922, 13.275460666826746, 14.42260789912762, 15.598807035815678, 16.803206245226367, 18.035020556672244, 19.293523638913687, 20.578040921874706, 21.88794379259212, 23.222644659354287, 24.581592724257074, 25.964270338886244, 27.37018984386054, 28.79889081284352, 30.249937636972607, 31.72291739761292, 33.21743798475241, 34.73312642582121, 36.26962739568978, 37.82660188341205, 39.40372599518454, 41.000689876180104, 42.61719673653584, 44.252961968938735, 45.907712347052176, 47.5811852955287, 49.27312822361472, 50.983297915416706, 52.711459970797314, 54.45738829163581, 56.22086460884036, 58.00167804605884, 59.799624716516654, 61.61450734982473, 63.44613494596085, 65.29432245393882, 67.15889047295224, 69.0396649740172, 70.93647704034542, 72.84916262486267, 74.77756232344761, 76.72152116260801, 78.68088840043713, 80.65551733980381, 82.64526515282904, 84.64999271578951, 86.66956445366729, 88.70384819363508, 90.75271502682878, 92.81603917781665, 94.89369788122339, 96.98557126501476, 99.09154223998864, 101.21149639505543, 103.34532189792503, 105.49290940084768, 107.65415195108348, 109.82894490580124, 112.01718585112883, 114.2187745251001, 116.43361274426002, 118.66160433370909, 120.90265506038317, 123.15667256937861, 125.42356632314821, 127.7032475434024, 129.995629155565, 132.30062573563998, 134.6181534593578, 136.9481300534767, 139.29047474912338, 141.64510823706559, 144.01195262481403, 146.39093139546023, 148.78196936816, 151.18499266018, 153.59992865042884, 156.02670594439843, 158.46525434044804, 160.91550479736372, 163.37738940313383, 165.85084134488142, 168.33579487990033, 170.83218530774252, 173.33994894330883, 175.8590230908973], [0.0, 0.2273205122961679, 0.6210579419651959, 1.1180582883538035, 1.6967803010029856, 2.345012339914519, 3.0546252625784196, 3.8197134518830254, 4.635740396075838, 5.499082874351368, 6.406762517818112, 7.356276075082164, 8.345482155962175, 9.37252239814539, 10.435764689077013, 11.533761104310043, 12.665216001804323, 13.828961326946075, 15.023937163185284, 16.249176179914222, 17.503791029609385, 18.786964013393728, 20.097938516722913, 21.436011844321257, 22.800529174139594, 24.19087841570059, 25.60648580639771, 27.046812115233163, 28.51134935059044, 29.999617889339287, 31.51116396055111, 33.04555742956044, 34.602389837909314, 36.181272662489285, 37.781835763416055, 39.40372599518454, 41.04660595971907, 42.71015288325466, 44.39405760171487, 46.098023641506515, 47.82176638452578, 49.56501230773516, 51.327498288983925, 53.10897097185226, 54.90918618323646, 56.72790839818967, 58.564910247213746, 60.419972061779525, 62.29288145435549, 64.183432929656, 66.091427524196, 68.0166724715626, 69.95898089109862, 71.9181714979396, 73.89406833256203, 75.88650050819204, 77.89530197458969, 79.92031129687257, 81.9613714481736, 84.01832961504206, 86.0910370146022, 88.17934872257322, 90.28312351133775, 92.40222369731828, 94.53651499698667, 96.68586639089091, 98.85014999513533, 101.02924093979883, 103.22301725381854, 105.431359755904, 107.65415195108349, 109.89127993251488, 112.14263228822227, 114.4081000124467, 116.68757642132137, 118.98095707260605, 121.28813968923203, 123.60902408642991, 125.94351210222754, 128.29150753112052, 130.65291606073265, 133.02764521129524, 135.41560427778666, 137.8167042745839, 140.2308578824888, 142.65797939799862, 145.09798468470163, 147.55079112668466, 150.0163175838465, 152.49448434901956, 154.9852131068057, 157.48842689404063, 160.00405006180404, 162.5320082388997, 165.07222829673344, 167.62463831552026, 170.1891675517578, 172.76574640690524, 175.35430639721167, 177.95478012463977, 180.5671012488345, 183.1912044600896], [0.0, 0.23653341382712342, 0.6462283307107948, 1.1633712291545528, 1.7655478296122773, 2.4400515757418626, 3.1784238651499246, 3.9745197364246327, 4.823618820951443, 5.721951055142535, 6.666417362040764, 7.654413037865167, 8.683709905647403, 9.752374286910662, 10.858707922441837, 12.001204205956462, 13.178514985315687, 14.389424866701587, 15.632830977005986, 16.907726781408805, 18.213188969748252, 19.54836670324645, 20.912472703099056, 22.304775795023723, 23.724594618182532, 25.171292275145003, 26.644271749712818, 28.14297195680193, 29.666864316786874, 31.215449768253425, 32.7882561497334, 34.38483589395799, 36.00476398836459, 37.6476361636848, 39.31306727891424, 41.000689876180104, 42.71015288325466, 44.44112044491853, 46.19327086721771, 47.966295661004416, 49.759898673102455, 51.573795295065516, 53.407711740863725, 55.26138438598611, 57.13455916142145, 59.026990996810035, 60.938443307766875, 62.868687522982725, 64.81750264723205, 66.78467485686583, 68.76999712475802, 70.77326887201126, 72.79429564402318, 74.83288880877183, 76.88886527540294, 78.96204723140153, 81.05226189680273, 83.15934129405164, 85.2831220322577, 87.42344510470917, 89.58015569862141, 91.75310301618676, 93.94214010608027, 96.14712370465065, 98.36791408609395, 100.60437492096963, 102.85637314247212, 105.12377881992148, 107.40646503898168, 109.70430778815363, 112.01718585112884, 114.34498070462068, 116.68757642132135, 119.04485957765972, 121.41671916605908, 123.8030465114184, 126.20373519155885, 128.6186809613981, 131.0477816806315, 133.49093724471427, 135.9480495189552, 138.41902227554274, 140.90376113333988, 143.40217350029252, 145.9141685183085, 148.43965701047247, 150.97855143047167, 153.53076581411477, 156.09621573283474, 158.67481824907225, 161.26649187344356, 163.87115652360228, 166.4887334847101, 169.11914537143673, 171.7623160914144, 174.41817081007534, 177.08663591680718, 179.76763899236235, 182.4611087774637, 185.16697514254966, 187.88516905860703, 190.61562256904173], [0.0, 0.24585905901284125, 0.6717067441985916, 1.2092386908667367, 1.8351569066174063, 2.5362538621843664, 3.3037374634978933, 4.131220475850052, 5.013796423800488, 5.947546603978198, 6.92924975418532, 7.956198476721745, 9.026076745771554, 10.13687464500602, 11.286826959078443, 12.474367681742986, 13.698095508165379, 14.95674712600606, 16.249176179914222, 17.57433645109259, 18.931268226645294, 20.319087122341305, 21.73697481985981, 23.184171317397595, 24.65996839055731, 26.16370403137817, 27.6947576855023, 29.252546146318174, 30.8365199942439, 32.446160491703644, 34.08097686163385, 35.74050389082946, 37.424299810040935, 39.131944411145035, 40.86303736843978, 42.61719673653584, 44.39405760171487, 46.19327086721771, 48.01450215587732, 49.857430815949996, 51.72174901802575, 53.60716093259081, 55.5133819792361, 57.44013813970282, 59.38716532797026, 61.354208811453056, 63.34102267811141, 65.3473693449075, 67.37301910358438, 69.41774970021062, 71.4813459453397, 73.56359935198381, 75.66430779890867, 77.78327521702336, 79.92031129687258, 82.07523121544591, 84.247855380698, 86.43800919233489, 88.64552281756234, 90.87023098061704, 93.11197276501385, 95.37059142754056, 97.6459342231203, 99.93785223974133, 102.2462002427236, 104.57083652765662, 106.9116227813986, 109.26842395057933, 111.64110811709587, 114.02954638013045, 116.43361274426003, 118.85318401325937, 121.28813968923201, 123.73836187673132, 126.20373519155886, 128.68414667395288, 131.17948570589826, 133.68964393231133, 136.21451518586971, 138.75399541527358, 141.30798261674062, 143.8763767685495, 146.45907976846112, 149.05599537385615, 151.66702914444105, 154.2920883873817, 156.93108210473522, 159.58392094305745, 162.25051714507248, 164.93078450329722, 167.62463831552026, 170.33199534204198, 173.05277376458665, 175.78689314680412, 178.53427439628354, 181.29483972800463, 184.06851262915845, 186.855217825272, 189.65488124757618, 192.46743000155797, 195.29279233664326, 198.13089761695866], [0.0, 0.2552958059507204, 0.6974886966184848, 1.2556525979199058, 1.9055952764240074, 2.6336022615630625, 3.430543994513665, 4.289788080931243, 5.206239721352429, 6.175829801792166, 7.195213419149126, 8.261579258352578, 9.372522398145392, 10.525955776081727, 11.720046422994523, 12.953168225010819, 14.223866091362412, 15.53082822030732, 16.872864256223238, 18.248887823557755, 19.65790237299429, 21.09898957520247, 22.57129970255349, 24.074043582284485, 25.606485806397714, 27.16793895724595, 28.757758661888197, 30.375339328639015, 32.020110449681745, 33.69153337686557, 35.389098495753316, 37.11232273697751, 38.860747374969705, 40.633936072863065, 42.431473139354054, 44.252961968938735, 46.098023641506515, 47.966295661004416, 49.857430815949996, 51.771096147103655, 53.706972009715926, 55.66475121952263, 57.6441382731358, 59.64484863472217, 61.66660808191317, 63.70915210478614, 65.77222535252082, 67.85558112298888, 69.95898089109865, 72.08219387220149, 74.22499661728801, 76.38717263706639, 78.56851205233339, 80.7688112683271, 82.98787267099188, 85.22550434330175, 87.48151979997473, 89.7557377390773, 92.04798180916546, 94.35808039073748, 96.68586639089092, 99.03117705017794, 101.39385376074551, 103.77374189492926, 106.17069064354264, 108.58455286317015, 111.01518493183112, 113.46244661243557, 115.9262009235009, 118.40631401664142, 120.90265506038315, 123.41509612989091, 125.94351210222752, 128.4877805567948, 131.04778168063146, 133.62339817826935, 136.2145151858697, 138.82102018938264, 141.44280294649198, 144.07975541212278, 146.731771667307, 149.39874785121455, 152.08058209617252, 154.77717446550514, 157.48842689404066, 160.214243131139, 162.9545286861059, 165.70919077586635, 168.47813827477873, 171.26128166647962, 174.05853299765383, 176.86980583363302, 179.69501521573105, 182.53407762022937, 185.3869109189329, 188.25343434121828, 191.1335684375045, 194.02723504407734, 196.93435724920448, 199.85485936048104, 202.78866687334857, 205.73570644073448], [0.0, 0.26484207839513324, 0.7235698815405112, 1.302605197672336, 1.976851173518695, 2.7320805135087913, 3.558822277355857, 4.450196065687834, 5.400916569277413, 6.406762517818112, 7.464263932294461, 8.570504374171238, 9.722988995004915, 10.91955269085327, 12.15829395235922, 13.437525860396864, 14.755738914009575, 16.111572259271473, 17.50379102960938, 18.931268226645297, 20.392970037108203, 21.88794379259212, 23.415307991615098, 24.97424395188836, 26.563988766313354, 28.183829312644548, 29.833097122912704, 31.51116396055111, 33.21743798475241, 34.95136040570314, 36.712402552960725, 38.500063293751694, 40.313866749388936, 42.15336026706735, 44.01811261154441, 45.907712347052176, 47.82176638452578, 49.759898673102455, 51.72174901802575, 53.706972009715926, 55.71523605095197, 57.74622247093286, 59.79962471651665, 61.87514761222568, 63.972506681698285, 66.091427524196, 68.23164524056898, 70.39290390375972, 72.57495606951117, 74.77756232344761, 77.00049086113404, 79.24351709809758, 81.50642330712499, 83.78899828043826, 86.09103701460221, 88.41234041624021, 90.75271502682881, 93.11197276501385, 95.48993068504427, 97.88641075005278, 100.3012396190344, 102.7342484464796, 105.1852726937141, 107.6541519510835, 110.1407297701955, 112.64485350550292, 115.16637416457046, 117.70514626642456, 120.26102770743604, 122.83387963422838, 125.42356632314821, 128.02995506586873, 130.65291606073262, 133.29232230947002, 135.9480495189552, 138.6199760076923, 141.3079826167406, 144.01195262481403, 146.731771667307, 149.46732765901663, 152.2185107203484, 154.9852131068057, 157.76732914157915, 160.56475515106231, 163.3773894031338, 166.20513204805482, 169.04788506184184, 171.90555219198365, 174.77803890537882, 177.66525233837987, 180.56710124883446, 183.48349597002402, 186.41434836640337, 189.35957179105284, 192.31908104475883, 195.29279233664323, 198.28062324626802, 201.28249268714427, 204.2983208715804, 207.32802927680646, 210.37154061231612, 213.42877878837078], [0.0, 0.27449636154612134, 0.7499461604092219, 1.3500890396980547, 2.0489132910347734, 2.8316729915188694, 3.6885519568608527, 4.6124189766237, 5.597796076305271, 6.640308107714411, 7.736358600757849, 8.88292480402296, 10.077420924404255, 11.317602933467466, 12.601500006171772, 13.927363730161066, 15.293629578669604, 16.698887090589718, 18.141856384780976, 19.621369380415338, 21.136354578646657, 22.68582458346602, 24.268865760035027, 25.884629582655304, 27.532325333990617, 29.211213896364036, 30.9206024341564, 32.6598398097056, 34.42831260784281, 36.22544166920033, 38.05067905172216, 39.90350535485157, 41.78342735270489, 43.68997589193309, 45.62270401748369, 47.5811852955287, 49.56501230773516, 51.573795295065516, 53.60716093259081, 55.66475121952263, 57.74622247093286, 59.85124439951994, 61.97949927736621, 64.13068116896802, 66.30449522795242, 68.50065705085613, 70.71889208216575, 72.95893506551968, 75.2205295365802, 77.50342735360395, 79.8073882621934, 82.13217949110219, 84.47757537631121, 86.8433570108894, 89.22931191841536, 91.63523374796546, 94.0609219888764, 96.5061817036681, 98.97082327767158, 101.45466218404506, 103.95751876298729, 106.47921801406662, 109.01958940068369, 111.57846666577407, 114.15568765793526, 116.75109416723488, 119.36453177001927, 121.9958496820998, 124.64490061974642, 127.3115406679632, 129.995629155565, 132.69702853661104, 135.41560427778663, 138.15122475135644, 140.90376113333988, 143.67308730658786, 146.4590797684611, 149.26161754283478, 152.08058209617252, 154.91585725743172, 157.76732914157915, 160.63488607651013, 163.51841853318064, 166.41781905877218, 169.33298221272443, 172.2638045054779, 175.21018433978278, 178.17202195443687, 181.14921937032545, 184.1416803386443, 187.14931029119265, 190.17201629263278, 193.20970699461623, 196.26229259168474, 199.32968477885956, 202.4117967108353, 205.50854296270322, 208.61983949213024, 211.74560360292563, 214.8857539099304, 218.04021030516884, 221.20889392520468], [0.0, 0.28425719820495393, 0.7766135520403608, 1.3980969568782564, 2.1217707520563156, 2.932364663298277, 3.819713451883026, 4.776432328128031, 5.796848525825952, 6.876431320563744, 8.011456355098991, 9.198793391775414, 10.435764689077015, 11.720046422994521, 13.049597687772023, 14.42260789912762, 15.837456897171249, 17.292684066103174, 18.786964013393728, 20.31908712234131, 21.88794379259212, 23.492511517248694, 25.13184417346305, 26.80506306274802, 28.511349350590443, 30.24993763697261, 32.020110449681745, 33.821193497202884, 35.65255155189132, 37.51358486000806, 39.403725995184544, 41.32243708746077, 43.269207372296975, 45.24355101368508, 47.24500516326446, 49.27312822361472, 51.327498288983925, 53.407711740863725, 55.5133819792361, 57.6441382731358, 59.79962471651665, 61.97949927736621, 64.183432929656, 66.41110885909897, 68.66222173485787, 70.93647704034542, 73.23359045710814, 75.55328729651367, 77.89530197458969, 80.25937752590204, 82.64526515282904, 85.05272380699424, 87.4815197999747, 89.93142644071153, 92.40222369731826, 94.89369788122339, 97.40564135178991, 99.93785223974132, 102.49013418788643, 105.06229610777967, 107.65415195108349, 110.2655204945128, 112.89622513734454, 115.54609371056691, 118.2149582968235, 120.90265506038314, 123.60902408642993, 126.33390922902898, 129.07715796717704, 131.8386212683941, 134.61815345935784, 137.41561210312102, 140.23085788248878, 143.06375448916532, 145.9141685183085, 148.78196936816, 151.66702914444105, 154.56922256922766, 157.48842689404066, 160.4245218169026, 163.3773894031338, 166.34691400967293, 169.33298221272443, 172.33548273854706, 175.35430639721167, 178.3893460191658, 181.4404963944554, 184.50765421446224, 187.59071801602497, 190.68958812782085, 193.8041666188915, 196.93435724920445, 200.08006542214855, 203.24119813886657, 206.41766395433632, 209.6093729351137, 212.81623661865936, 216.03816797417252, 219.2750813648624, 222.5268925115891, 225.79351845781142, 229.07487753578218], [0.0, 0.29412318525656717, 0.8035682230106034, 1.4466220481004508, 2.195413083362156, 3.0341410544728977, 3.9522879080274196, 4.9422125433690205, 5.9980453041559985, 7.115098213780196, 8.28951765016242, 9.518064731487579, 10.797968777298138, 12.126825308397448, 13.502522583357225, 14.92318717621137, 16.387142694627517, 17.8928778278133, 19.43902118157008, 21.024321155869917, 22.647629638395934, 24.30788863312365, 26.0041191792125, 27.735412080344645, 29.50092008193259, 31.29985121848655, 33.13146311579791, 34.99505807906977, 36.88997883320266, 38.815604808229665, 40.77134888357137, 42.75665452089949, 44.77099322807978, 46.81386230672815, 48.884782843962235, 50.983297915416706, 53.10897097185226, 55.26138438598611, 57.44013813970282, 59.64484863472217, 61.87514761222568, 64.13068116896802, 66.41110885909897, 68.71610287235428, 71.0453472804867, 73.39853734483944, 75.77537887884593, 78.17558765999213, 80.59888888642823, 83.04501667397442, 85.51371358975149, 88.00473021908593, 90.51782476270672, 93.05276266157107, 95.60931624693492, 98.18726441353269, 100.78639231394477, 103.40649107242416, 106.04735751662241, 108.70879392580413, 111.39060779427376, 114.09261160885595, 116.81462263937706, 119.55646274119037, 122.31795816887083, 125.09893940028351, 127.89924097029568, 130.71870131346586, 133.5571626150981, 136.41447067009923, 139.29047474912338, 142.1850274715276, 145.0979846847016, 148.02920534936692, 150.97855143047164, 153.9458877933371, 156.93108210473517, 159.9340047386009, 162.9545286861059, 165.99252946983677, 169.04788506184184, 172.12047580532513, 175.21018433978276, 178.3168955293891, 181.44049639445538, 184.58087604579282, 187.73792562182467, 190.91153822830142, 194.10160888048253, 197.30803444765712, 200.53071359988314, 203.76954675683314, 207.02443603864063, 210.29528521864793, 213.58199967796284, 216.884486361735, 220.20265373707082, 223.5364117525082, 226.88567179897817, 230.2503466721839, 233.630350536332, 237.0255988891545], [0.0, 0.30409297044408795, 0.8308064788452976, 1.49565766239421, 2.269830191350091, 3.1369882153158803, 4.086257154307332, 5.109736900095536, 6.201358834761515, 7.356276075082164, 8.570504374171238, 9.840695063030712, 11.163983544468946, 12.537883835544326, 13.960212613907832, 15.429032950763991, 16.94261162972752, 18.49938611166125, 20.097938516722913, 21.73697481985981, 23.415307991615098, 25.13184417346305, 26.885571221088377, 28.675549119480806, 30.500901894976415, 32.360810737123145, 34.25450810772752, 36.181272662489285, 38.14042484689721, 40.13132305575299, 42.15336026706735, 44.20596107773744, 46.28857908152599, 48.40069454026705, 50.54181230754487, 52.711459970797314, 54.90918618323646, 57.13455916142145, 59.38716532797026, 61.66660808191317, 63.972506681698285, 66.30449522795242, 68.66222173485787, 71.0453472804867, 73.45354522768832, 75.88650050819204, 78.34390896349768, 80.82547673690543, 83.33091971170845, 85.85996299114892, 88.41234041624023, 90.98779411799158, 93.58607410095125, 96.206937855315, 98.85014999513533, 101.51548192042293, 104.20271150115441, 106.91162278139859, 109.64200570194882, 112.39365584000282, 115.16637416457044, 117.95996680641134, 120.77424484141457, 123.60902408642994, 126.46412490664781, 129.33937203370394, 132.23459439375497, 135.14962494483518, 138.08430052286212, 141.03846169570943, 144.01195262481403, 147.00462093382578, 150.01631758384647, 153.04689675484119, 156.09621573283474, 159.16413480253811, 162.25051714507245, 165.35522874048593, 168.47813827477873, 171.61911705117242, 174.77803890537885, 177.95478012463974, 181.14921937032548, 184.36123760389373, 187.59071801602497, 190.83754595876042, 194.10160888048256, 197.38279626358693, 200.68099956470394, 203.99611215733904, 207.32802927680646, 210.67664796734113, 214.04186703127877, 217.4235869802022, 220.82170998795743, 224.23613984544824, 227.66678191712424, 231.11354309908214, 234.57633177870395, 238.055057795761, 241.54963240491568, 245.05996823955775], [0.0, 0.31416524940506485, 0.8583247559212069, 1.5451973843540994, 2.3450123399145193, 3.2408926901737365, 4.221603663318589, 5.278983480836284, 6.406762517818112, 7.599933350796174, 8.85437976519675, 10.166642176178392, 11.533761104310045, 12.953168225010817, 14.422607899127621, 15.940079042198626, 17.503791029609385, 19.112129567228017, 20.7636298116758, 22.456954876727366, 24.19087841570059, 25.964270338886244, 27.776084977353598, 29.625351180570245, 31.511163960551112, 33.43267738590387, 35.389098495753316, 37.37968205316859, 39.403725995184544, 41.46056746512005, 43.54957933498074, 45.67016714295106, 47.82176638452578, 50.00384010658074, 52.215876762278874, 54.45738829163581, 56.72790839818967, 59.026990996810035, 61.354208811453056, 63.70915210478614, 66.091427524196, 68.50065705085613, 70.93647704034542, 73.39853734483944, 75.88650050819204, 78.40004102632565, 80.93884466629063, 83.5026078381577, 86.09103701460222, 88.70384819363507, 91.340766400454, 94.0015252248369, 96.68586639089091, 99.3935393563131, 102.12430093861619, 104.87791496603818, 107.6541519510835, 110.45278878484939, 113.27360845047107, 116.11639975417917, 118.98095707260605, 121.86708011510324, 124.77457369994606, 127.70324754340244, 130.65291606073265, 133.62339817826935, 136.6145171557986, 139.62610041852938, 142.65797939799862, 145.70998938131052, 148.78196936816, 151.87376193513148, 154.9852131068057, 158.116172233243, 161.26649187344356, 164.4360276844173, 167.62463831552026, 170.83218530774252, 174.05853299765386, 177.30354842573382, 180.5671012488345, 183.8490636565382, 187.14931029119268, 190.46771817141735, 193.8041666188915, 197.1585371882446, 200.53071359988317, 203.92058167559813, 207.3280292768065, 210.75294624529187, 214.19522434631412, 217.6547572139695, 221.13144029868764, 224.6251708167594, 228.1358477017971, 231.66337155803149, 235.2076446153588, 238.76857068605398, 242.34605512307238, 245.94000477986512, 249.55032797163895, 253.17693443799473], [0.0, 0.324338762942797, 0.8861196140115629, 1.5952350207189232, 2.4209501300789227, 3.345841489317682, 4.358310514572963, 5.449931127049401, 6.614230674565198, 7.846039579847937, 9.141108334254072, 10.495865322304503, 11.907255228685266, 13.372626559575892, 14.889650632176672, 16.4562615615429, 18.070610737831686, 19.73103159173675, 21.436011844321254, 23.184171317397595, 24.974243951888358, 26.805063062748015, 28.675549119480802, 30.584699523094926, 32.53157997966668, 34.515317164276006, 36.53509243784741, 38.590136430679074, 40.679724345123745, 42.8031718594228, 44.95983153749511, 47.14908966725687, 49.37036346403267, 51.62309858671579, 53.90676692321032, 56.22086460884036, 58.564910247213746, 60.938443307766875, 63.34102267811141, 65.77222535252082, 68.23164524056898, 70.71889208216575, 73.23359045710814, 75.77537887884593, 78.34390896349768, 80.93884466629063, 83.55986157856927, 86.20664627934802, 88.87889573610008, 91.57631675009004, 94.29862544209398, 97.0455467748121, 99.8168141086853, 102.61216878817879, 105.43135975590401, 108.27414319222375, 111.14028217822177, 114.02954638013047, 116.94171175349686, 119.8765602655308, 122.8338796342284, 125.8134630829927, 128.8151091095912, 131.83862126839412, 134.88380796493007, 137.95048226188055, 141.03846169570943, 144.14756810319102, 147.27762745716316, 150.42846971088474, 153.5999286504288, 156.79184175458738, 160.00405006180398, 163.23639804368986, 166.48873348471008, 169.76090736766133, 173.05277376458662, 176.36418973280186, 179.69501521573105, 183.04511294826779, 186.41434836640337, 189.80258952087596, 193.2097069946162, 196.63557382377655, 200.08006542214852, 203.5430595087828, 207.02443603864066, 210.52407713611632, 214.04186703127877, 217.57769199869298, 221.1314402986876, 224.7030021209456, 228.29226953030107, 231.89913641463264, 235.52349843475187, 239.16525297618784, 242.82429910277858, 246.50053751198251, 250.19387049182976, 253.9042018794363, 257.63143702100933, 261.3754827332759], [0.0, 0.3346122945093772, 0.9141877294095341, 1.6457645879922636, 2.497634481208636, 3.451822062978997, 4.496361360676488, 5.622559396829491, 6.823738495977754, 8.094565332874941, 9.430655794364634, 10.828325132932465, 12.284421255198106, 13.7962086804466, 15.361284964123596, 16.97751878373385, 18.643002974140607, 20.35601817693455, 22.115004211271426, 23.918537181388682, 25.765310925392388, 27.654121803123996, 29.58385608962228, 31.5534794282594, 33.56202793105995, 35.6086006102644, 37.692352896148996, 39.812491048986416, 41.96826731293767, 44.15897569013881, 46.383948236768724, 48.642551801221764, 50.934185138936, 53.25827634987709, 55.61428059383364, 58.00167804605884, 60.419972061779525, 62.868687522982725, 65.3473693449075, 67.85558112298888, 70.39290390375972, 72.95893506551968, 75.55328729651367, 78.17558765999213, 80.82547673690543, 83.5026078381577, 86.20664627934802, 88.93726871178325, 91.6941625042867, 94.47702517096148, 97.28556384062064, 100.11949476407203, 102.97854285586531, 105.86244126747086, 108.77093098917896, 111.7037604782893, 114.66068531140498, 117.64146785886443, 120.64587697953665, 123.67368773437482, 126.7246811172763, 129.7986438019309, 132.89536790345994, 136.01465075375705, 139.1562946895361, 142.32010685218074, 145.50589899856533, 148.71348732208835, 151.942692283223, 155.19333844894453, 158.46525434044804, 161.75827228861544, 165.0722282967334, 168.4069619100029, 171.7623160914144, 175.13813710359813, 178.53427439628354, 181.9505804990324, 185.38691091893293, 188.84312404296367, 192.31908104475883, 195.81464579552264, 199.3296847788596, 202.86406700930266, 206.41766395433632, 209.99034945972397, 213.58199967796287, 217.19249299970062, 220.82170998795746, 224.46953331500973, 228.1358477017971, 231.82053985972652, 235.5234984347519, 239.24461395361737, 242.98377877215813, 246.74088702555784, 250.5158345804701, 254.30851898891433, 258.11883944386346, 261.9466967364442, 265.7919932146752, 269.6546327436742], [0.0, 0.34498466787984494, 0.9425258885738266, 1.696780301002986, 2.57505661365011, 3.558822277355857, 4.63574039607584, 5.796848525825954, 7.035261995335401, 8.345482155962177, 9.722988995004917, 11.163983544468946, 12.665216001804328, 14.223866091362414, 15.837456897171252, 17.50379102960939, 19.220902204884826, 20.98701776760045, 22.800529174139594, 24.659968390557317, 26.56398876631336, 28.511349350590443, 30.50090189497642, 32.53157997966669, 34.60238983790933, 36.71240255296074, 38.86074737496971, 41.04660595971908, 43.26920737229699, 45.52782373018801, 47.821766384525795, 50.150382557154884, 52.513052366024, 54.90918618323647, 57.33822227952396, 59.799624716516654, 62.29288145435549, 64.81750264723205, 67.37301910358438, 69.95898089109865, 72.57495606951117, 75.2205295365802, 77.89530197458969, 80.59888888642823, 83.33091971170845, 86.09103701460222, 88.87889573610008, 91.6941625042867, 94.53651499698672, 97.40564135178992, 100.30123961903443, 103.22301725381857, 106.17069064354266, 109.14398466785732, 112.14263228822233, 115.16637416457047, 118.21495829682354, 121.28813968923205, 124.38568003570978, 127.507347424508, 130.65291606073268, 133.82216600534545, 137.01488292941406, 140.23085788248886, 143.4698870740809, 146.73177166730702, 150.01631758384653, 153.32333531942723, 156.65263976912303, 160.00405006180404, 163.37738940313386, 166.7724849265563, 170.1891675517578, 173.62727185013193, 177.08663591680718, 180.56710124883452, 184.06851262915845, 187.590718016025, 191.13356843750455, 194.6969178908292, 198.28062324626805, 201.8845441552798, 205.50854296270325, 209.1524846227598, 212.8162366186594, 216.49966888561318, 220.20265373707088, 223.92506579401098, 227.66678191712427, 231.42768114174083, 235.2076446153588, 239.00655553764446, 242.82429910277864, 246.66076244403334, 250.51583458047014, 254.3894063656557, 258.281370438299, 262.19162117471814, 266.1200546430514, 270.0665685591304, 274.03106224393997, 278.01343658259105], [0.0, 0.3554547449992378, 0.9711309822466541, 1.7482765623161278, 2.6532080326607357, 3.666830392403761, 4.776432328128031, 5.972779391066538, 7.248777964317393, 8.598762518560418, 10.01807586142811, 11.502803728532704, 13.049597687772023, 14.65555186982823, 16.318114185819795, 18.035020556672247, 19.804245023063473, 21.623961130571516, 23.492511517248694, 25.408383595203023, 27.37018984386054, 29.376651650293237, 31.42658591744047, 33.51889386029816, 35.65255155189132, 37.82660188341206, 40.04014767827504, 42.29234575600844, 44.58240178428964, 46.90956578980678, 49.27312822361472, 51.67241649613372, 54.10679191226518, 56.575646949260495, 59.07840282970597, 61.61450734982473, 64.183432929656, 66.78467485686583, 69.41774970021062, 72.08219387220149, 74.77756232344761, 77.50342735360395, 80.25937752590204, 83.04501667397442, 85.85996299114892, 88.70384819363507, 91.57631675009004, 94.47702517096148, 97.40564135178992, 100.36184396532859, 103.34532189792503, 106.35577372611583, 109.3929072298295, 112.45643893897963, 115.5460937105669, 118.66160433370912, 121.8027111602773, 124.96916175904835, 128.16071059148973, 131.37711870747063, 134.6181534593578, 137.88358823309548, 141.17320219499717, 144.48678005309284, 147.82411183197476, 151.18499266018003, 154.5692225692277, 157.97660630350484, 161.40695314026232, 164.8600767190402, 168.33579487990033, 171.83392950989062, 175.35430639721164, 178.89675509259834, 182.4611087774637, 186.04720413838956, 189.65488124757618, 193.28398344889385, 196.9343572492045, 200.60585221464407, 204.29832087158042, 208.01161861197843, 211.74560360292563, 215.50013670008525, 219.2750813648624, 223.07030358508015, 226.8856717989782, 230.72105682235718, 234.57633177870395, 238.4513720321436, 242.34605512307235, 246.26026070633668, 250.19387049182978, 254.1467681873864, 258.11883944386346, 262.10997180229896, 266.12005464305133, 270.14897913682347, 274.1966381974841, 278.2629264366021, 282.3477401196144, 286.450977123555], [0.0, 0.36602142398640636, 1.0, 1.8002479524148158, 2.7320805135087918, 3.7758350412431145, 4.918422350276621, 6.150333477415031, 7.464263932294461, 8.85437976519675, 10.315885338403977, 11.844750027356401, 13.437525860396866, 15.091220584810793, 16.803206245226367, 18.571151457807776, 20.392970037108203, 22.26678123330569, 24.19087841570059, 26.16370403137817, 28.183829312644548, 30.249937636972607, 32.360810737123145, 34.515317164276006, 36.71240255296073, 38.95108134219182, 41.230429684824315, 43.54957933498074, 45.90771234705218, 48.30405645311025, 50.73788101129701, 53.20849343781891, 55.71523605095197, 58.25748326798933, 60.834639106077724, 63.44613494596085, 66.091427524196, 68.76999712475802, 71.4813459453397, 74.22499661728801, 77.00049086113404, 79.8073882621934, 82.64526515282904, 85.51371358975149, 88.41234041624023, 91.340766400454, 94.29862544209398, 97.28556384062064, 100.30123961903443, 103.34532189792503, 106.41749031509812, 109.5174344866107, 112.64485350550294, 115.79945547491268, 118.98095707260606, 122.189083144266, 125.42356632314822, 128.68414667395288, 131.97057135897109, 135.28259432475053, 138.6199760076923, 141.98248305713608, 145.36988807462544, 148.78196936816002, 152.21851072034838, 155.67930116946994, 159.16413480253811, 162.67281055953475, 166.20513204805482, 169.76090736766133, 173.3399489433088, 176.9420733672434, 180.56710124883446, 184.21485707183524, 187.88516905860703, 191.57786904087888, 195.29279233664323, 199.02977763282024, 202.78866687334857, 206.5693051523846, 210.3715406123161, 214.1952243463141, 218.04021030516884, 221.9063552081702, 225.7935184578114, 229.70156205810693, 233.630350536332, 237.579750868001, 241.54963240491566, 245.5398668061238, 249.55032797163892, 253.5808919787814, 257.63143702100933, 261.7018433491154, 265.79199321467513, 269.9017708156351, 274.0310622439399, 278.17975543510084, 282.3477401196144, 286.5349077761449, 290.7411515863902, 294.96636639155264], [0.0, 0.37668363728025256, 1.0291300251709916, 1.8526892205826857, 2.8116660876364783, 3.8858252110360385, 5.0616961171417465, 6.329492846422123, 7.681698128525124, 9.112308070630451, 10.616387337972748, 12.189787893797396, 13.828961326946077, 15.530828220307319, 17.292684066103178, 19.112129567228013, 20.98701776760044, 22.915413131108846, 24.895559312858342, 26.92585338837859, 29.004824969936816, 31.13111908175855, 33.30348196844924, 35.520749222056125, 37.781835763416055, 40.08572732212721, 42.431473139354054, 44.818179677194834, 47.24500516326446, 49.71115483345035, 52.21587676227887, 54.758458190973116, 57.33822227952395, 59.95452522198448, 62.60675367450596, 65.29432245393882, 68.0166724715626, 70.77326887201126, 73.56359935198381, 76.38717263706639, 79.24351709809758, 82.13217949110219, 85.05272380699424, 88.00473021908593, 90.98779411799158, 94.0015252248369, 97.0455467748121, 100.11949476407203, 103.22301725381857, 106.35577372611583, 109.5174344866107, 112.7076801098681, 115.9262009235009, 119.17269652768401, 122.44687534699975, 125.74845421187885, 129.07715796717707, 132.4327191056727, 135.81487742448806, 139.22337970262757, 142.65797939799862, 146.11843636243037, 149.60451657334352, 153.11599188084423, 156.652639769123, 160.214243131139, 163.80059005565516, 167.41147362576996, 171.04669172816264, 174.70604687233168, 178.3893460191658, 182.09640041823866, 185.827025453266, 189.5810404952084, 193.35826876254026, 197.15853718824462, 200.9816762931229, 204.82752006504117, 208.69590584376104, 212.58667421102783, 216.49966888561318, 220.4347366230284, 224.39172711964673, 228.37049292098723, 232.3708893339342, 236.3927743426757, 240.43600852816294, 244.50045499090382, 248.58597927691463, 252.69244930666812, 256.81973530688197, 260.96770974500583, 265.13624726627006, 269.32522463317, 273.53452066726663, 277.7640161931897, 282.01359398473943, 286.28313871298565, 290.57253689627134, 294.8816768520318, 299.2104486503448, 303.55874406913455], [0.0, 0.38744034991562565, 1.0585182301515081, 1.9055952764240074, 2.8919570297907495, 3.996790225200708, 5.20623972135243, 6.510240107354929, 7.9010594469960695, 9.37252239814539, 10.91955269085327, 12.537883835544326, 14.223866091362412, 15.974332104259929, 17.786500135567785, 19.65790237299429, 21.58633055121251, 23.569793862249554, 25.606485806397707, 27.6947576855023, 29.833097122912704, 32.02011044968174, 34.25450810772752, 36.53509243784741, 38.860747374969705, 41.230429684824315, 43.64316145836644, 46.098023641506515, 48.59415042390622, 51.13072434588479, 53.706972009715926, 56.32216030282821, 58.975593057127185, 61.66660808191317, 64.39457451847112, 67.15889047295224, 69.95898089109862, 72.79429564402318, 75.66430779890867, 78.56851205233339, 81.50642330712499, 84.47757537631121, 87.4815197999747, 90.51782476270672, 93.58607410095125, 96.68586639089091, 99.8168141086853, 102.97854285586531, 106.17069064354266, 109.3929072298295, 112.64485350550294, 115.9262009235009, 119.23663096832087, 122.57583466181295, 125.94351210222753, 129.3393720337039, 132.76313144366915, 136.2145151858697, 139.69325562698137, 143.1990923149394, 146.73177166730696, 150.2910466781562, 153.87667664207535, 157.48842689404066, 161.12606856400154, 164.78937834513096, 168.47813827477873, 172.1921355272503, 175.93116221760468, 179.695015215731, 183.48349597002402, 187.2964103400328, 191.13356843750444, 194.99478447529208, 198.8798766236336, 202.78866687334852, 206.72098090552961, 210.6766479673411, 214.6555007535607, 218.657375293529, 222.68211084319498, 226.72954978196563, 230.79953751408996, 234.89192237432422, 239.0065555376444, 243.14329093278417, 247.3019851593946, 251.48249740863267, 255.6846893869987, 259.90842524325524, 264.15357149826764, 268.4199969776205, 272.70757274686855, 277.0161720492929, 281.34567024603956, 285.695944758524, 290.066875012993, 294.45834238714235, 298.8702301586922, 303.30242345583054, 307.75480920943704, 312.22727610700764], [0.0, 0.3982905579174757, 1.0881618720008799, 1.958961181965457, 2.972945846036852, 4.108719726845627, 5.352039671967975, 6.692558390213621, 8.12232741367419, 9.634998460703207, 11.225353101184101, 12.889005363150615, 14.622203295309687, 16.421690842345924, 18.2846083634224, 20.208418935539978, 22.190852451237514, 24.22986235026798, 26.32359154217443, 28.470345157261438, 30.66856846500056, 32.916828766957984, 35.2138003911741, 37.55825213818268, 39.94903668767963, 42.385081589778, 44.865381549239075, 47.38899177400348, 49.95502220684621, 52.56263249525263, 55.211027582610846, 57.899453825643555, 60.627195560174805, 63.39357205095521, 66.19793477216747, 69.0396649740172, 71.9181714979396, 74.83288880877183, 77.78327521702336, 80.7688112683271, 83.78899828043826, 86.8433570108894, 89.93142644071153, 93.05276266157107, 96.206937855315, 99.3935393563131, 102.61216878817879, 105.86244126747086, 109.14398466785732, 112.45643893897963, 115.79945547491268, 119.17269652768401, 122.57583466181295, 126.00855224626352, 129.47054098058334, 132.96150145233565, 136.48114272322348, 140.02918194156436, 143.60534397900366, 147.20936108955615, 150.84097258924749, 154.49992455478642, 158.1859695398428, 161.8988663076346, 165.6383795786403, 169.40427979235918, 173.19634288213027, 177.0143500621078, 180.85808762556476, 184.7273467537623, 188.62192333468786, 192.54161779101662, 196.48623491670412, 200.45558372166275, 204.44947728401561, 208.46773260946216, 212.5101704973208, 216.57661541284853, 220.6668953654658, 224.78084179253983, 228.91828944840702, 233.07907629833358, 237.26304341713808, 241.4700348922147, 245.69989773071728, 249.95248177067592, 254.2276395958368, 258.52522645402667, 262.8451001788574, 267.18712111459837, 271.5511520440521, 275.9370581192837, 280.3447067950583, 284.77396776485443, 289.22471289932605, 293.6968161870939, 298.1901536777553, 302.70460342700625, 307.2400454437775, 311.79636163928933, 316.3734357779379, 320.97115342992936], [0.0, 0.4092332868030632, 1.1180582883538035, 2.012782144289348, 3.0546252625784196, 4.2216036633185885, 5.4990828743513696, 6.876431320563745, 8.345482155962175, 9.89971268471043, 11.533761104310045, 13.243120941564763, 15.023937163185288, 16.872864256223238, 18.78696401339373, 20.763629811675802, 22.800529174139594, 24.895559312858346, 27.046812115233163, 29.25254614631818, 31.511163960551112, 33.82119349720289, 36.181272662489285, 38.59013643067908, 41.046605959719074, 43.54957933498075, 46.09802364150652, 48.69096812979674, 51.32749828898393, 54.00675067850993, 56.727908398189676, 59.49019709897239, 62.29288145435548, 65.13526202640848, 68.01667247156261, 70.93647704034542, 73.89406833256203, 76.88886527540294, 79.92031129687258, 82.98787267099188, 86.09103701460221, 89.22931191841536, 92.40222369731826, 95.60931624693492, 98.85014999513533, 102.12430093861619, 105.43135975590401, 108.77093098917896, 112.14263228822233, 115.5460937105669, 118.98095707260606, 122.44687534699975, 125.94351210222753, 129.47054098058334, 133.02764521129527, 136.6145171557986, 140.23085788248883, 143.87637676854953, 147.55079112668466, 151.25382585479255, 154.98521310680573, 158.74469198308446, 162.5320082388997, 166.346914009673, 170.18916755175778, 174.05853299765383, 177.9547801246398, 181.87768413589592, 185.82702545326603, 189.80258952087598, 193.80416661889151, 197.83155168675324, 201.88454415527977, 205.96294778707662, 210.06657052473113, 214.19522434631412, 218.34872512774209, 222.5268925115891, 226.72954978196572, 230.95652374510962, 235.20764461535876, 239.48274590619883, 243.78166432610038, 248.10423967887786, 252.4503147683235, 256.81973530688197, 261.2123498281504, 265.62800960300024, 270.06656855913036, 274.5278832038756, 279.01181255010084, 283.518218045027, 288.04696350184037, 292.5979150339471, 297.1709409917454, 301.7659119017894, 306.382700408234, 311.02118121644844, 315.6812310387005, 320.36272854181146, 325.06555429669305, 329.7895907296802], [0.0, 0.4202675901830809, 1.1482048935984939, 2.0670535086533603, 3.1369882153158803, 4.335432271776015, 5.647356611371822, 7.06184299603058, 8.570504374171238, 10.166642176178392, 11.844750027356401, 13.600199944861513, 15.429032950763993, 17.327813325854077, 19.29352363891369, 21.32348698361369, 23.415307991615098, 25.566827176768697, 27.776084977353594, 30.041293003491056, 32.360810737123145, 34.73312642582121, 37.15684124917948, 39.6306560721258, 42.153360267067356, 44.72382220805764, 47.34098112928389, 50.00384010658073, 52.71145997079732, 55.46295400011909, 58.25748326798933, 61.09425254630702, 63.97250668169828, 66.89152737703773, 69.85063032189674, 72.84916262486267, 75.88650050819204, 78.96204723140153, 82.07523121544591, 85.22550434330175, 88.41234041624021, 91.63523374796546, 94.89369788122339, 98.18726441353269, 101.51548192042293, 104.87791496603818, 108.27414319222375, 111.7037604782893, 115.16637416457047, 118.66160433370912, 122.189083144266, 125.74845421187885, 129.3393720337039, 132.96150145233565, 136.6145171557986, 140.29810321055947, 144.01195262481406, 147.75576693957905, 151.52925584535984, 155.3321368223784, 159.1641348025381, 163.0249818514689, 166.91441686915027, 170.83218530774255, 174.77803890537882, 178.75173543477914, 182.7530384656446, 186.78171713987854, 190.83754595876042, 194.92030458126933, 199.02977763282024, 203.16575452373263, 207.32802927680643, 211.51640036342832, 215.7306705476729, 219.9706467379085, 224.2361398454482, 228.52696464982427, 232.84293967029362, 237.18388704320859, 241.54963240491566, 245.9400047798651, 250.3548364736396, 254.79396297062667, 259.2572228360809, 263.74445762233654, 268.2555117789479, 272.7902325665498, 277.3484699742415, 281.93007664031376, 286.5349077761449, 291.1628210931079, 295.8136767323351, 300.48733719720076, 305.18366728838765, 309.90253404141134, 314.64380666648526, 319.40735649061503, 324.19305690181704, 329.00078329536274, 333.8304130219547, 338.68182533774706], [0.0, 0.4313925484534658, 1.1785991753026108, 2.121770752056316, 3.220027840081795, 4.450196065687834, 5.796848525825954, 7.2487779643173935, 8.797375314843276, 10.435764689077015, 12.158293952359221, 13.960212613907832, 15.837456897171252, 17.786500135567785, 19.804245023063476, 21.887943792592125, 24.03513766770658, 26.243609998217735, 28.51134935059044, 30.836519994243904, 33.217437984752415, 35.65255155189133, 38.14042484689721, 40.679724345123745, 43.26920737229698, 45.90771234705219, 48.59415042390623, 51.327498288983925, 54.10679191226519, 56.93112109940649, 59.799624716516654, 62.711486484907745, 65.66593126144228, 68.66222173485788, 71.69965548025516, 74.77756232344761, 77.89530197458969, 81.05226189680273, 84.247855380698, 87.48151979997473, 90.75271502682881, 94.0609219888764, 97.40564135178991, 100.78639231394477, 104.20271150115441, 107.6541519510835, 111.14028217822177, 114.66068531140498, 118.21495829682354, 121.8027111602773, 125.42356632314822, 129.07715796717707, 132.76313144366915, 136.48114272322348, 140.23085788248883, 144.01195262481406, 147.82411183197482, 151.66702914444107, 155.54040656789766, 159.44395410394867, 163.37738940313383, 167.3404374385575, 171.33283019858638, 175.3543063972117, 179.40461120079425, 183.48349597002405, 187.59071801602502, 191.72604036962548, 195.88923156289894, 200.08006542214855, 204.29832087158044, 208.54378174696714, 212.81623661865933, 217.11547862335334, 221.44130530406585, 225.79351845781142, 230.17192399051174, 234.57633177870395, 239.0065555376445, 243.46241269543387, 247.94372427281547, 252.4503147683235, 256.9820120484798, 261.53864724275763, 266.12005464305133, 270.7260716074063, 275.3565384677808, 280.01129844162574, 284.6901975470824, 289.39308452161043, 294.11981074386966, 298.8702301586922, 303.6441992049881, 308.44157674644043, 313.26222400485324, 318.10600449602174, 322.972783968006, 327.86243034169183, 332.7748136535334, 337.70980600037404, 342.6672814862508, 347.6471161710917], [0.0, 0.44260726757050073, 1.2092386908667367, 2.176929477213615, 3.3037374634978924, 4.565885822201574, 5.947546603978199, 7.437221202623215, 9.026076745771553, 10.70705859570344, 12.474367681742986, 14.323130016724196, 16.249176179914222, 18.24888782355775, 20.319087122341305, 22.456954876727362, 24.659968390557307, 26.925853388378588, 29.252546146318174, 31.638163211128496, 34.08097686163385, 36.57939498693318, 39.13194441114503, 41.73725694257932, 44.39405760171487, 47.1011546100758, 49.85743081594999, 52.6618363028292, 55.5133819792361, 58.41113398891197, 61.35420881145305, 64.34176894773948, 67.37301910358437, 70.44720280017422, 73.56359935198381, 76.72152116260801, 79.92031129687257, 83.15934129405164, 86.43800919233489, 89.7557377390773, 93.11197276501385, 96.5061817036681, 99.93785223974132, 103.40649107242416, 106.91162278139859, 110.45278878484939, 114.02954638013047, 117.64146785886443, 121.28813968923205, 124.96916175904835, 128.68414667395288, 132.4327191056727, 136.2145151858697, 140.02918194156436, 143.87637676854953, 147.75576693957905, 151.66702914444107, 155.6098490593139, 159.58392094305742, 163.58894725831715, 167.62463831552026, 171.69071193801986, 175.7868931468041, 179.91291386332873, 184.0685126291584, 188.25343434121825, 192.46743000155797, 196.71025648062442, 200.9816762931229, 205.28145738562012, 209.6093729351137, 213.96520115785148, 218.34872512774206, 222.75973260374903, 227.19801586570543, 231.66337155803149, 236.15560054087192, 240.67450774820924, 245.21990205253877, 249.791596135721, 254.38940636565565, 259.0131526784438, 263.6626584657303, 268.33775046693677, 273.03825866611817, 277.76401619318966, 282.5148592292909, 287.29062691606697, 292.09116126866166, 296.91630709223, 301.7659119017894, 306.639825845241, 311.5379016294014, 316.45999444889605, 321.4059619177743, 326.3756640037125, 331.3689629646831, 336.3857232879703, 341.42581163142404, 346.4890967668466, 351.57544952541383, 356.6847427450393], [0.0, 0.4539108779025307, 1.2401210643871723, 2.2325254069094886, 3.3881105944039747, 4.682492570296793, 6.0994391601307, 7.627158098347985, 9.256590932583787, 10.980502858904034, 12.792946705957563, 14.688924011325206, 16.664158872725512, 18.714940534537163, 20.8380100139473, 23.030476112751963, 25.289751708434334, 27.61350444352336, 29.99961788933928, 32.446160491703644, 34.95136040570314, 37.51358486000805, 40.131323055752986, 42.80317185942279, 45.527823730188, 48.30405645311024, 51.13072434588479, 54.00675067850992, 56.93112109940648, 59.90287790284913, 62.92111500447934, 65.98497351654585, 69.09363783408911, 72.2463321588168, 75.4423173998386, 78.68088840043713, 81.9613714481736, 85.2831220322577, 88.64552281756234, 92.04798180916546, 95.48993068504427, 98.97082327767158, 102.49013418788643, 106.04735751662241, 109.64200570194882, 113.27360845047107, 116.94171175349686, 120.64587697953665, 124.38568003570978, 128.16071059148973, 131.97057135897109, 135.81487742448806, 139.69325562698137, 143.60534397900366, 147.55079112668466, 151.52925584535984, 155.54040656789766, 159.58392094305742, 163.65948542147046, 167.76679486706766, 171.90555219198362, 176.07546801314925, 180.27626032894858, 184.50765421446226, 188.76938153394863, 193.06118066933422, 197.38279626358693, 201.73397897794305, 206.11448526204424, 210.5240771361163, 214.96252198439421, 219.429592359059, 223.9250657940109, 228.44872462785509, 233.00035583552352, 237.57975086800099, 242.186705499661, 246.82101968275524, 251.4824974086327, 256.1709465752938, 260.88617886091464, 265.6280096030002, 270.39625768284884, 275.190745415034, 280.0112984416257, 284.85774563089564, 289.7299189802642, 294.6276535232646, 299.55078724031415, 304.4991609730947, 309.4726183423568, 314.47100566897495, 319.4941718980908, 324.54196852619, 329.61424953097094, 334.7108713038679, 339.8316925851022, 344.9765744011405, 350.14538000444884, 355.3379748154331, 360.5542263664663, 365.7940042479089], [0.0, 0.46530253315225323, 1.2712439837115492, 2.2885543786963702, 3.473140915813611, 4.800007579667558, 6.252514822141572, 7.818574430983589, 9.488900616764445, 11.256077006003649, 13.114007173104234, 15.057567210844033, 17.082373905997873, 19.184623375304607, 21.360974846308352, 23.608464561334102, 25.92444046968369, 28.306511679461085, 30.752508646656946, 33.260451341499106, 35.828523451652586, 38.45505122865099, 41.138485957595904, 43.87738929098184, 46.67042087304785, 49.51632781532052, 52.41393568267498, 55.36214072276308, 58.359903127150496, 61.40624115487943, 64.50022598188377, 67.64097716518273, 70.82765863084151, 74.05947511060768, 77.33566896486465, 80.65551733980381, 84.01832961504206, 87.42344510470917, 90.87023098061704, 94.35808039073748, 97.88641075005278, 101.45466218404506, 105.06229610777967, 108.70879392580413, 112.39365584000282, 116.11639975417917, 119.8765602655308, 123.67368773437482, 127.507347424508, 131.37711870747063, 135.28259432475053, 139.22337970262757, 143.1990923149394, 147.20936108955615, 151.25382585479255, 155.3321368223784, 159.44395410394867, 163.58894725831715, 167.76679486706766, 171.9771841362293, 176.21981052201812, 180.49437737881124, 184.8005956276889, 189.13818344402944, 193.50686596277484, 197.906375000107, 202.3364487903806, 206.79683173725712, 211.2872741780733, 215.80753216055305, 220.35736723104844, 224.93654623355573, 229.54484111881496, 234.18202876285346, 238.8478907943815, 243.54221343049633, 248.26478732018666, 253.0154073951702, 257.7938727276299, 262.59998639444404, 267.4335553475367, 272.29439028999735, 277.1823055576468, 282.0971190057444, 287.03865190055535, 292.0067288155135, 297.00117753173237, 302.021828942635, 307.06851696248526, 312.14107843862, 317.2393530671899, 322.3631833122341, 327.51241432791903, 332.6868938837853, 337.88647229285664, 343.1110023424694, 348.36033922769366, 353.63434048722206, 358.9328659416118, 364.2557776337678, 369.602939771566, 374.9742186725178], [0.0, 0.4767814093441227, 1.302605197672336, 2.3450123399145193, 3.5588222773558567, 4.91842235027662, 6.4067625178181125, 8.011456355098991, 9.722988995004915, 11.533761104310045, 13.437525860396864, 15.429032950763991, 17.503791029609385, 19.65790237299429, 21.88794379259212, 24.19087841570059, 26.563988766313354, 29.004824969936816, 31.51116396055111, 34.08097686163385, 36.712402552960725, 39.40372599518454, 42.15336026706735, 44.95983153749511, 47.82176638452579, 50.73788101129701, 53.706972009715926, 56.72790839818967, 59.79962471651665, 62.92111500447935, 66.091427524196, 69.30966011241729, 72.57495606951115, 75.88650050819204, 79.2435170980976, 82.64526515282904, 86.0910370146022, 89.58015569862141, 93.11197276501385, 96.68586639089092, 100.3012396190344, 103.95751876298729, 107.65415195108349, 111.39060779427376, 115.16637416457044, 118.98095707260605, 122.8338796342284, 126.7246811172763, 130.65291606073268, 134.6181534593578, 138.6199760076923, 142.65797939799862, 146.73177166730696, 150.84097258924749, 154.98521310680573, 159.1641348025381, 163.37738940313383, 167.62463831552026, 171.90555219198362, 176.21981052201812, 180.5671012488345, 184.94712040864985, 189.35957179105282, 193.80416661889151, 198.280623246268, 202.78866687334852, 207.3280292768065, 211.8984485548172, 216.49966888561315, 221.13144029868758, 225.7935184578114, 230.48566445509107, 235.2076446153587, 239.95923031023904, 244.74019778128707, 249.55032797163892, 254.38940636565562, 259.25722283608087, 264.1535714982677, 269.078250571059, 274.03106224393986, 279.0118125501008, 284.02031124508215, 289.05637169068615, 294.11981074386966, 299.21044865034474, 304.3281089426359, 309.4726183423568, 314.6438066664852, 319.84150673742994, 325.065554296693, 330.31578792194784, 335.59204894735984, 340.89418138698915, 346.2220318611261, 351.5754495254138, 356.95428600262755, 362.3583953169816, 367.7876338308476, 373.2418601837698, 378.7209352336723, 384.2247220001591], [0.0, 0.4883467038719071, 1.3342025134846855, 2.4018953430075056, 3.64514868816596, 5.037728602530114, 6.562171462118322, 8.20579038433614, 9.958839699780352, 11.813535738073444, 13.7634801473184, 15.803295258096707, 17.92838077795696, 20.134744435806386, 22.418880006982583, 24.777676953311914, 27.208351880927644, 29.708395488690073, 32.275530785630146, 34.907679680734155, 37.60293590855371, 40.35954282800384, 43.175875023871896, 46.05042291429815, 48.98177976222179, 51.96863062969876, 55.00974291754619, 58.103958209932024, 61.25018520176896, 64.44739353124584, 67.69460837415936, 70.99090568347138, 74.33540797857268, 77.72728060544337, 81.16572840226264, 84.64999271578951, 88.17934872257322, 91.75310301618676, 95.37059142754056, 99.03117705017794, 102.7342484464796, 106.47921801406662, 110.2655204945128, 114.09261160885595, 117.95996680641134, 121.86708011510324, 125.8134630829927, 129.7986438019309, 133.82216600534545, 137.88358823309548, 141.98248305713608, 146.11843636243037, 150.2910466781562, 154.49992455478642, 158.74469198308446, 163.0249818514689, 167.3404374385575, 171.69071193801986, 176.07546801314925, 180.49437737881124, 184.94712040864985, 189.43338576562775, 193.95287005415267, 198.50527749220058, 203.09031960198436, 207.70771491784615, 212.35718871016167, 217.03847272414933, 221.7513049325688, 226.4954293013746, 231.27059556746966, 236.0765590277678, 240.91308033883863, 245.77992532646465, 250.67686480448853, 255.6036744023805, 260.5601344009921, 265.5460295760068, 270.5611490486302, 275.6052861430965, 280.67823825059776, 285.77980669926836, 290.9097966298857, 296.0680168769661, 301.2542798549627, 306.4684014492847, 311.7102009118823, 316.97950076115234, 322.2761266859403, 327.59990745342526, 332.9506748206882, 338.32826344977866, 343.7325108261021, 349.16325717996517, 354.620345411124, 360.1036210161878, 365.6129320187429, 371.1481289020666, 376.70906454431025, 382.2955941560351, 387.9075752199937, 393.5448674330542], [0.0, 0.49999763460189295, 1.3660337942963208, 2.459199541111393, 3.7321143101914545, 5.157918268026336, 6.718731145100199, 8.401563376340938, 10.196436781061378, 12.095381986792281, 14.091847990345768, 16.180328822361112, 18.35611443703286, 20.615117316031828, 22.953747583510207, 25.368820490360804, 27.857486236762096, 30.417175654898674, 33.04555742956044, 35.74050389082946, 38.500063293751694, 41.32243708746077, 44.20596107773744, 47.149089667256874, 50.15038255715488, 53.20849343781891, 56.322160302828216, 59.49019709897238, 62.711486484907745, 65.98497351654586, 69.30966011241729, 72.68460017965464, 76.10889530279708, 79.58169091472588, 83.10217288272268, 86.66956445366729, 90.28312351133775, 93.94214010608027, 97.6459342231203, 101.39385376074551, 105.1852726937141, 109.01958940068369, 112.89622513734454, 116.81462263937706, 120.77424484141457, 124.77457369994606, 128.8151091095912, 132.89536790345994, 137.01488292941406, 141.17320219499717, 145.36988807462544, 149.60451657334352, 153.87667664207535, 158.1859695398428, 162.5320082388997, 166.91441686915027, 171.33283019858638, 175.7868931468041, 180.27626032894858, 184.8005956276889, 189.35957179105282, 193.95287005415267, 198.58017978301206, 203.2411981388666, 207.93562976145267, 212.66318646993065, 217.4235869802022, 222.21655663748783, 227.0418271631253, 231.8991364146326, 236.78822815815863, 241.70885185251345, 246.66076244403322, 251.6437201715935, 256.6574903811346, 261.7018433491154, 266.7765541143482, 271.8814023177144, 277.01617204929295, 282.18065170246643, 287.3746338346047, 292.59791503394706, 297.8502957923375, 303.1315803834838, 308.44157674644043, 313.7800963740276, 319.14695420592506, 324.54196852619, 329.9649608649684, 335.4157559041825, 340.89418138698915, 346.4000680308202, 351.93324944382294, 357.4935620445334, 363.08084498462455, 368.69494007457786, 374.33569171214043, 380.0029468134333, 385.6965547465883, 391.4163672677936, 397.1622384596383, 402.9340246716514], [0.0, 0.5117334390276408, 1.3980969568782566, 2.5169211838974666, 3.819713451883026, 5.278983480836285, 6.8764313205637455, 8.59876251856042, 10.435764689077015, 12.379281404765988, 14.422607899127623, 16.56010896823063, 18.78696401339373, 21.098989575202474, 23.4925115172487, 25.964270338886248, 28.511349350590443, 31.131119081758555, 33.82119349720289, 36.579394986933195, 39.403725995184544, 42.292345756008444, 45.24355101368508, 48.25575989306214, 51.32749828898393, 54.457388291635816, 57.64413827313581, 60.88653434156478, 64.18343292965602, 67.53375433196895, 70.93647704034542, 74.3906327554913, 77.89530197458969, 81.44961007236184, 85.05272380699425, 88.70384819363508, 92.40222369731828, 96.14712370465065, 99.93785223974133, 103.77374189492926, 107.6541519510835, 111.57846666577407, 115.54609371056691, 119.55646274119037, 123.60902408642994, 127.70324754340244, 131.83862126839412, 136.01465075375705, 140.23085788248886, 144.48678005309284, 148.78196936816002, 153.11599188084423, 157.48842689404066, 161.8988663076346, 166.346914009673, 170.83218530774255, 175.3543063972117, 179.91291386332873, 184.50765421446226, 189.13818344402944, 193.80416661889151, 198.50527749220058, 203.2411981388666, 208.01161861197852, 212.81623661865936, 217.65475721396953, 222.52689251158915, 227.43236141011863, 232.37088933393423, 237.34220798761888, 242.3460551230724, 247.3821743184722, 252.4503147683235, 257.5502310838958, 262.68168310339524, 267.8444357112739, 273.0382586661182, 278.2629264366021, 283.51821804502714, 288.80391691800486, 294.1198107438697, 299.46569133643715, 304.8413545047516, 310.2465999284882, 315.68123103870056, 321.1450549036213, 326.6378821192461, 332.15952670444653, 337.7098060003741, 343.28854057393414, 348.89555412511925, 354.5306733980082, 360.1937280952454, 365.88455079582843, 371.6029768760435, 377.348844433392, 383.12199421336845, 388.92226953895215, 394.7495162426857, 400.6035826012201, 406.48431927221196, 412.3915792334666], [0.0, 0.5235533734725494, 1.4303899694461428, 2.5750566136501094, 3.907940562242242, 5.400916569277413, 7.035261995335401, 8.797375314843274, 10.676808258052619, 12.665216001804323, 14.755738914009575, 16.94261162972752, 19.220902204884823, 21.58633055121251, 24.03513766770658, 26.56398876631335, 29.169899788295304, 31.850180527972064, 34.602389837909314, 37.42429981004094, 40.313866749388936, 43.26920737229697, 46.28857908152598, 49.37036346403268, 52.51305236602399, 55.71523605095197, 58.975593057127185, 62.292881454355474, 65.66593126144228, 69.09363783408911, 72.57495606951115, 76.10889530279707, 79.69451479260582, 83.33091971170843, 87.01725757220963, 90.75271502682878, 94.53651499698667, 98.36791408609395, 102.2462002427236, 106.17069064354264, 110.1407297701955, 114.15568765793526, 118.2149582968235, 122.31795816887083, 126.46412490664781, 130.65291606073265, 134.88380796493007, 139.1562946895361, 143.4698870740809, 147.82411183197476, 152.21851072034838, 156.652639769123, 161.12606856400154, 165.6383795786403, 170.18916755175778, 174.77803890537882, 179.40461120079425, 184.0685126291584, 188.76938153394863, 193.50686596277484, 198.280623246268, 203.09031960198436, 207.93562976145267, 212.81623661865936, 217.73183089841646, 222.68211084319495, 227.66678191712424, 232.68555652597104, 237.73815375200923, 242.82429910277853, 247.94372427281542, 253.09616691750844, 258.2813704382989, 263.49908377850795, 268.74906122912427, 274.03106224393986, 279.344851263463, 284.6901975470823, 290.0668750129931, 295.47466208543034, 300.91334154878876, 306.38270040823386, 311.882529756441, 317.41262464611947, 322.9727839680059, 328.56281033402684, 334.1825099653555, 339.83169258510213, 345.5101713153943, 351.2177625786214, 356.95428600262744, 362.71956432965476, 368.51342332884735, 374.3356917121404, 380.1862010533685, 386.064785710436, 391.9712827504032, 397.90553187734935, 403.8673753628826, 409.85665797917324, 415.8732269343929, 421.9169318104527], [0.0, 0.5354567123368217, 1.4629108496029128, 2.6336022615630625, 3.9967902252007086, 5.523710048145414, 7.195213419149127, 8.99738957278646, 10.91955269085327, 12.953168225010819, 15.091220584810793, 17.327813325854077, 19.65790237299429, 22.077110327270525, 24.581592724257078, 27.167938957245948, 29.833097122912704, 32.57431585193742, 35.38909849575331, 38.27516649330259, 41.230429684824315, 44.25296196893873, 47.34098112928389, 50.49283195710501, 53.70697200971593, 56.981959499258004, 60.3164429197195, 63.709152104786135, 67.15889047295225, 70.66452826508657, 74.22499661728801, 77.83928234121068, 81.50642330712499, 85.22550434330175, 88.99565357995876, 92.81603917781665, 96.68586639089091, 100.60437492096963, 104.57083652765662, 108.58455286317015, 112.64485350550292, 116.75109416723488, 120.90265506038314, 125.09893940028351, 129.33937203370394, 133.62339817826935, 137.95048226188055, 142.32010685218074, 146.73177166730702, 151.18499266018003, 155.67930116946994, 160.214243131139, 164.78937834513096, 169.40427979235918, 174.05853299765383, 178.75173543477914, 183.48349597002405, 188.25343434121825, 193.06118066933422, 197.906375000107, 202.78866687334852, 207.70771491784615, 212.66318646993065, 217.65475721396953, 222.68211084319495, 227.74493873941702, 232.8429396702936, 237.97581950294267, 243.1432909327842, 248.3450732265868, 253.58089197878144, 258.850478880175, 264.1535714982676, 269.48991306843766, 274.8592522953137, 280.2613431637077, 285.695944758524, 291.1628210931079, 296.6617409455324, 302.1924777023583, 307.75480920943704, 313.34851762935284, 318.97338930513234, 324.62921462987003, 330.31578792194784, 336.0329073055414, 341.7803745961318, 347.5579951907557, 353.36557796274644, 359.20293516073264, 365.0698823116758, 370.96623812774357, 376.8918244168241, 382.8464659965028, 388.82999061133205, 394.84222885323135, 400.8830140848708, 406.95218236589386, 413.0495723818475, 419.1750253756925, 425.3283850817753, 431.50949766215035], [0.0, 0.5474427473857084, 1.49565766239421, 2.6925546442387063, 4.086257154307331, 5.647356611371821, 7.356276075082166, 9.198793391775416, 11.163983544468946, 13.243120941564763, 15.429032950763993, 17.715691137559627, 20.09793851672292, 22.57129970255349, 25.131844173463055, 27.776084977353598, 30.500901894976415, 33.30348196844925, 36.181272662489285, 39.131944411145035, 42.153360267067356, 45.24355101368508, 48.40069454026705, 51.6230985867158, 54.909186183236464, 58.257483267989336, 61.666608081913175, 65.13526202640848, 68.66222173485787, 72.24633215881681, 75.88650050819204, 79.58169091472588, 83.33091971170843, 87.13325124157072, 90.9877941179916, 94.89369788122339, 98.85014999513533, 102.85637314247212, 106.9116227813986, 111.01518493183112, 115.16637416457046, 119.36453177001927, 123.60902408642993, 127.89924097029568, 132.23459439375497, 136.6145171557986, 141.03846169570943, 145.50589899856533, 150.01631758384653, 154.5692225692277, 159.16413480253811, 163.80059005565516, 168.47813827477873, 173.19634288213027, 177.9547801246398, 182.7530384656446, 187.59071801602502, 192.46743000155797, 197.38279626358693, 202.3364487903806, 207.3280292768065, 212.35718871016167, 217.4235869802022, 222.52689251158915, 227.66678191712424, 232.8429396702936, 238.05505779576106, 243.30283557656986, 248.58597927691463, 253.9042018794363, 259.2572228360809, 264.64476783163605, 270.06656855913036, 275.52236250634456, 281.0118927527371, 286.53490777614496, 292.09116126866166, 297.6804119611433, 303.30242345583065, 308.95696406661176, 314.64380666648526, 320.36272854181146, 326.11351125297074, 331.89594050107104, 337.70980600037404, 343.5549013561267, 349.43102394751014, 355.33797481543314, 361.2755585549168, 367.24358321183274, 373.24186018376986, 379.27020412482284, 385.3284328541039, 391.4163672677936, 397.53383125455866, 403.6806516141705, 409.85665797917335, 416.0616827394559, 422.29556096959027, 428.5581303588094, 434.8492311435009, 441.1687060421036], [0.0, 0.5595107870761754, 1.5286285184687853, 2.751910360376324, 4.176336187702382, 5.771849125077987, 7.518440670507111, 9.40157515166991, 11.41008671628327, 13.535057422432699, 15.769156521538333, 18.106222685950918, 20.540985247864448, 23.068870164444956, 25.685860268165822, 28.38839173920812, 31.17327557500304, 34.037636807736625, 36.9788666330509, 39.994584131141394, 43.08260524696495, 46.240917353778585, 49.46765817353731, 52.761098141307464, 56.11962552396201, 59.54173376487182, 63.026010644944414, 66.57112893877044, 70.17583831136554, 73.83895825195047, 77.55937188054446, 81.3360204938092, 85.16789874070537, 89.05405033766657, 92.99356424830681, 96.98557126501476, 101.02924093979883, 105.12377881992148, 109.26842395057933, 113.46244661243557, 117.70514626642456, 121.9958496820998, 126.33390922902898, 130.71870131346586, 135.14962494483518, 139.62610041852938, 144.14756810319102, 148.71348732208835, 153.32333531942723, 157.97660630350484, 162.67281055953475, 167.41147362576996, 172.1921355272503, 177.0143500621078, 181.87768413589592, 186.78171713987854, 191.72604036962548, 196.71025648062442, 201.73397897794305, 206.79683173725712, 211.8984485548172, 217.03847272414933, 222.21655663748783, 227.43236141011863, 232.68555652597104, 237.97581950294267, 243.30283557656986, 248.66629740077494, 254.06590476452683, 259.5013643233448, 264.97238934466503, 270.47869946616436, 276.02002046620896, 281.5960840456585, 287.20662762031566, 292.8513941233656, 298.53013181719507, 304.24259411402977, 309.98853940486686, 315.76773089621605, 321.57993645420066, 327.4249284555952, 333.30248364541256, 339.21238300067324, 345.15441160001853, 351.1283584988497, 357.1340166096961, 363.17118258753544, 369.23965671980585, 375.33924282086787, 381.46974813068584, 387.63098321751767, 393.8227618844096, 400.0449010793084, 406.2972208086142, 412.5795440540058, 418.8916966923813, 425.2335074187672, 431.6048076720557, 438.00543156343844, 444.4352158074121, 450.89399965524], [0.0, 0.5716601559193765, 1.5618215723367257, 2.8116660876364783, 4.26702228335883, 5.897180620998426, 7.681698128525125, 9.605723502091545, 11.657848431072445, 13.828961326946075, 16.111572259271473, 18.499386111661245, 20.98701776760044, 23.56979386224955, 26.24360999821773, 29.004824969936813, 31.850180527972064, 34.77673927667938, 37.78183576341605, 40.86303736843978, 44.0181126115444, 47.24500516326445, 50.541812307544866, 53.90676692321032, 57.33822227952395, 60.834639106077724, 64.39457451847112, 68.0166724715626, 71.69965548025515, 75.4423173998386, 79.24351709809758, 83.10217288272267, 87.01725757220963, 90.98779411799158, 95.01285170119156, 99.09154223998864, 103.22301725381854, 107.40646503898168, 111.64110811709587, 115.9262009235009, 120.26102770743604, 124.64490061974642, 129.07715796717704, 133.5571626150981, 138.08430052286212, 142.65797939799862, 147.27762745716316, 151.942692283223, 156.65263976912303, 161.40695314026232, 166.20513204805482, 171.04669172816264, 175.93116221760468, 180.85808762556476, 185.82702545326603, 190.83754595876042, 195.88923156289894, 200.9816762931229, 206.11448526204424, 211.2872741780733, 216.49966888561315, 221.7513049325688, 227.0418271631253, 232.37088933393423, 237.73815375200923, 243.1432909327842, 248.58597927691463, 254.06590476452683, 259.5827606657261, 265.13624726627, 270.7260716074063, 276.35194723894836, 282.0135939847394, 287.71073771971885, 293.44311015786514, 299.21044865034474, 305.01249599324575, 310.84900024432017, 316.7197145482017, 322.6243969696022, 328.56281033402684, 334.5347220755779, 340.5399040914491, 346.57813260273633, 352.6491880212204, 358.75285482179453, 364.8889214202344, 371.05718005602887, 377.25742668000345, 383.48946084649043, 389.7530856098106, 396.0481074248497, 402.3743360515229, 408.73158446293485, 415.1196687570562, 421.5384080717417, 427.98762450293333, 434.467143025895, 440.9767914193373, 447.51640019229734, 454.0858025136461, 460.6848341441054], [0.0, 0.5838901938765245, 1.5952350207189228, 2.871818579669647, 4.358310514572962, 6.023344290248694, 7.846039579847938, 9.81122735227245, 11.907255228685262, 14.124816688186849, 16.4562615615429, 18.895160055300348, 21.436011844321254, 24.074043582284478, 26.805063062748015, 29.625351180570238, 32.531579979666674, 35.52074922205612, 38.59013643067907, 41.737256942579315, 44.959831537495106, 48.25575989306212, 51.623098586715784, 55.06004269167402, 58.564910247213746, 62.13612905193581, 65.7722253525208, 69.47181409273838, 73.23359045710814, 77.05632249678534, 80.93884466629062, 84.88005213170172, 88.87889573610003, 92.93437752804326, 97.0455467748121, 101.21149639505543, 105.431359755904, 109.70430778815363, 114.02954638013045, 118.40631401664142, 122.83387963422838, 127.3115406679632, 131.8386212683941, 136.41447067009923, 141.03846169570943, 145.70998938131052, 150.42846971088474, 155.19333844894453, 160.00405006180404, 164.8600767190402, 169.76090736766133, 174.70604687233168, 179.695015215731, 184.7273467537623, 189.80258952087598, 194.92030458126933, 200.08006542214855, 205.28145738562012, 210.5240771361163, 215.80753216055305, 221.13144029868758, 226.4954293013746, 231.8991364146326, 237.34220798761888, 242.82429910277853, 248.3450732265868, 253.9042018794363, 259.5013643233448, 265.13624726627, 270.8085445819143, 276.51795704399626, 282.2641920740437, 288.04696350184025, 293.86599133772245, 299.72100155598525, 305.61172588871347, 311.53790162940135, 317.4992714457746, 323.4955832012689, 329.52658978465774, 335.5920489473598, 341.69172314798664, 347.8253794037243, 353.992789148166, 360.1937280952452, 366.42797610893314, 372.69531707839474, 378.9955387983121, 385.32843285410377, 391.69379451178844, 398.0914226122514, 404.52111946969427, 410.98269077405564, 417.4759454972064, 424.00069580273606, 430.5567569591535, 437.14394725633986, 443.76208792509794, 450.41100305965404, 457.0905195429732, 463.80046697475854, 470.5406776020139], [0.0, 0.5962002557859547, 1.628867100981764, 2.9323646632982774, 4.450196065687834, 6.15033347741503, 8.011456355098993, 10.01807586142811, 12.15829395235922, 14.422607899127621, 16.803206245226367, 19.293523638913687, 21.88794379259212, 24.581592724257074, 27.37018984386054, 30.249937636972607, 33.21743798475241, 36.26962739568978, 39.40372599518454, 42.617196736535846, 45.90771234705218, 49.27312822361472, 52.711459970797314, 56.22086460884037, 59.799624716516654, 63.44613494596086, 67.15889047295224, 70.93647704034541, 74.77756232344761, 78.68088840043714, 82.64526515282904, 86.66956445366729, 90.7527150268288, 94.89369788122339, 99.09154223998867, 103.34532189792503, 107.65415195108349, 112.01718585112884, 116.43361274426003, 120.90265506038315, 125.42356632314821, 129.995629155565, 134.61815345935784, 139.29047474912338, 144.01195262481403, 148.78196936816, 153.5999286504288, 158.46525434044804, 163.37738940313386, 168.33579487990033, 173.3399489433088, 178.3893460191658, 183.48349597002402, 188.62192333468786, 193.80416661889151, 199.02977763282024, 204.29832087158044, 209.6093729351137, 214.96252198439421, 220.35736723104844, 225.7935184578114, 231.27059556746966, 236.78822815815863, 242.3460551230724, 247.94372427281542, 253.58089197878144, 259.2572228360809, 264.97238934466503, 270.7260716074063, 276.51795704399626, 282.34774011961434, 288.2151220874043, 294.1198107438696, 300.0615201963702, 306.0399706419618, 312.05488815688034, 318.1060044960217, 324.193056901817, 330.3157879219479, 336.473945235382, 342.6672814862507, 348.89555412511913, 355.1585252572345, 361.4559614973617, 367.7876338308476, 374.15331748057133, 380.55279177946835, 386.9858400483305, 393.45224947860567, 399.95181101993927, 406.48431927221185, 413.0495723818475, 419.64737194217736, 426.27752289765726, 432.9398334517525, 439.6341149783079, 446.36018193623966, 453.11785178738876, 459.9069449173887, 466.72728455940626, 473.5786967206229, 480.46101011133317], [0.0, 0.6085897108193413, 1.6627160896514728, 2.993301235842233, 4.5426742280343255, 6.278141674944758, 8.177939977506348, 10.226258429620064, 12.410951737631171, 14.722319699477065, 17.152388531164018, 19.694456448385207, 22.342790453189615, 25.092415278844413, 27.93896138166999, 30.878552332251388, 33.907719396480196, 37.02333542136683, 40.22256276458789, 43.50281165785158, 46.86170646612489, 50.297058019948004, 53.80684068678079, 57.38917318846535, 61.042302414569605, 64.76458965698562, 68.55449882020109, 72.41058625782576, 76.33149195853524, 80.31593186001945, 84.36269111230547, 88.4706181451763, 92.63861942064761, 96.86565477228731, 101.15073324981611, 105.49290940084768, 109.89127993251488, 114.34498070462068, 118.85318401325937, 123.41509612989091, 128.02995506586873, 132.69702853661104, 137.41561210312102, 142.1850274715276, 147.00462093382578, 151.87376193513148, 156.79184175458738, 161.75827228861544, 166.7724849265563, 171.83392950989062, 176.9420733672434, 182.09640041823866, 187.2964103400328, 192.54161779101662, 197.83155168675324, 203.16575452373263, 208.54378174696714, 213.96520115785148, 219.429592359059, 224.93654623355573, 230.48566445509107, 236.0765590277678, 241.70885185251345, 247.3821743184722, 253.09616691750844, 258.850478880175, 264.64476783163605, 270.47869946616436, 276.35194723894836, 282.2641920740437, 288.2151220874043, 294.2044323240069, 300.2318245081636, 306.2970068061868, 312.39969360063293, 318.53960527541204, 324.7164680111005, 330.930013589845, 337.17997920928923, 343.46610730499475, 349.7881453808662, 356.14584584712327, 362.538965865395, 368.9672672005395, 375.4305160788198, 381.92848305209066, 388.46094286767277, 395.0276743436137, 401.62846024905195, 408.2630871894216, 414.93134549624597, 421.6330291212919, 428.3679355348623, 435.1358656280234, 441.93662361857537, 448.7700169605806, 455.635856257283, 462.53395517725386, 469.46413037361543, 476.42620140619704, 483.4199906664887, 490.44532330526596], [0.0, 0.6210579419651958, 1.6967803010029854, 3.054625262578419, 4.635740396075838, 6.406762517818111, 8.345482155962175, 10.435764689077013, 12.665216001804321, 15.023937163185284, 17.50379102960938, 20.097938516722913, 22.80052917413959, 25.606485806397703, 28.511349350590436, 31.511163960551105, 34.602389837909314, 37.78183576341605, 41.04660595971906, 44.39405760171487, 47.82176638452577, 51.32749828898391, 54.90918618323645, 58.564910247213746, 62.292881454355474, 66.09142752419599, 69.95898089109862, 73.89406833256201, 77.89530197458967, 81.9613714481736, 86.0910370146022, 90.28312351133773, 94.53651499698665, 98.85014999513531, 103.22301725381854, 107.65415195108348, 112.14263228822227, 116.68757642132135, 121.28813968923201, 125.94351210222752, 130.65291606073262, 135.41560427778663, 140.23085788248878, 145.0979846847016, 150.01631758384647, 154.9852131068057, 160.00405006180398, 165.0722282967334, 170.1891675517578, 175.35430639721164, 180.56710124883446, 185.827025453266, 191.13356843750444, 196.48623491670412, 201.88454415527977, 207.32802927680643, 212.81623661865933, 218.34872512774206, 223.9250657940109, 229.54484111881496, 235.2076446153587, 240.91308033883863, 246.66076244403322, 252.4503147683235, 258.2813704382989, 264.1535714982676, 270.06656855913036, 276.02002046620896, 282.0135939847394, 288.04696350184025, 294.1198107438696, 300.2318245081636, 306.38270040823386, 312.5721406315705, 318.79985370926, 325.06555429669294, 331.368962964683, 337.70980600037393, 344.0878152173545, 350.50272777444064, 356.95428600262744, 363.4422372397408, 369.9663336723586, 376.5263321845944, 383.12199421336834, 389.75308560981057, 396.41937650647037, 403.120641190021, 409.85665797917324, 416.6272091075276, 423.43208061111113, 430.27106222036224, 437.14394725633986, 444.0505325309481, 450.9906182509799, 457.964007925792, 464.97050827844015, 472.0099291601072, 479.0820834676719, 486.1867870642698, 493.32385870270963, 500.49311995161554], [0.0, 0.6336043455379178, 1.731058085718636, 3.116333774326085, 4.7293900637437165, 6.536189778483652, 8.5140747784256, 10.646584495945303, 12.921074433936306, 15.32744568656731, 17.85739672639053, 20.50395030817133, 23.261137792693262, 26.123779416700245, 29.087326036796984, 32.147741892143586, 35.30141567455402, 38.54509169684179, 41.87581568213493, 45.29089141586645, 48.787845618167246, 52.364399138965915, 56.018443086907475, 59.748018858363196, 63.55130128546016, 67.42658430488544, 71.3722686835688, 75.38685143746363, 79.46891665520994, 83.61712749616593, 87.83021917683573, 92.1069927944434, 96.44630986372285, 100.84708746467108, 105.30829391635098, 109.82894490580124, 114.4081000124467, 119.04485957765972, 123.73836187673132, 128.4877805567948, 133.29232230947002, 138.15122475135644, 143.06375448916532, 148.02920534936692, 153.04689675484119, 158.116172233243, 163.23639804368986, 168.4069619100029, 173.62727185013193, 178.89675509259834, 184.21485707183524, 189.5810404952084, 194.99478447529208, 200.45558372166275, 205.96294778707662, 211.51640036342832, 217.11547862335334, 222.75973260374903, 228.44872462785509, 234.18202876285346, 239.95923031023904, 245.77992532646465, 251.6437201715935, 257.5502310838958, 263.49908377850795, 269.48991306843766, 275.52236250634456, 281.5960840456585, 287.71073771971885, 293.86599133772245, 300.0615201963702, 306.2970068061868, 312.5721406315705, 318.8866178437032, 325.24014108551455, 331.6324192479593, 338.0631672569167, 344.53210587007555, 351.0389614832129, 357.58346594531565, 364.1653563820362, 370.7843750270042, 377.44026906055433, 384.13279045545477, 390.8616958292545, 397.62674630288706, 404.42770736519674, 411.2643487430723, 418.1364442768934, 425.0437718010175, 431.986113029043, 438.96325344361355, 445.9749821905297, 453.021091976958, 460.10137897353616, 467.21564272018315, 474.36368603543895, 481.54531492916396, 488.76033851844255, 496.0085689465393, 503.2898213047683, 510.6039135571429], [0.0, 0.6462283307107948, 1.7655478296122773, 3.178423865149924, 4.823618820951443, 6.666417362040764, 8.683709905647403, 10.858707922441837, 13.178514985315687, 15.632830977005987, 18.213188969748252, 20.912472703099056, 23.724594618182532, 26.644271749712818, 29.666864316786874, 32.78825614973339, 36.00476398836459, 39.31306727891424, 42.71015288325465, 46.19327086721771, 49.759898673102455, 53.407711740863725, 57.13455916142145, 60.938443307766875, 64.81750264723205, 68.76999712475804, 72.79429564402318, 76.88886527540294, 81.05226189680272, 85.28312203225771, 89.58015569862141, 93.94214010608027, 98.36791408609396, 102.85637314247212, 107.4064650389817, 112.01718585112883, 116.68757642132137, 121.41671916605908, 126.20373519155886, 131.04778168063146, 135.9480495189552, 140.90376113333988, 145.9141685183085, 150.97855143047164, 156.09621573283474, 161.26649187344356, 166.48873348471008, 171.7623160914144, 177.08663591680718, 182.4611087774637, 187.88516905860703, 193.35826876254026, 198.8798766236336, 204.44947728401561, 210.06657052473113, 215.7306705476729, 221.44130530406585, 227.19801586570543, 233.00035583552352, 238.8478907943815, 244.74019778128707, 250.67686480448853, 256.6574903811346, 262.68168310339524, 268.74906122912427, 274.8592522953137, 281.0118927527371, 287.20662762031566, 293.44311015786514, 299.72100155598525, 306.0399706419618, 312.39969360063293, 318.79985370926, 325.24014108551455, 331.7202524477594, 338.23989088686875, 344.7987656488816, 351.3965919278399, 358.03309066820765, 364.70798837630883, 371.4210169402657, 378.17191345794964, 384.9604200724953, 391.78628381495594, 398.6492564537086, 405.5490943502405, 412.48555832097645, 419.4584135048247, 426.4674292361422, 433.5123789228395, 440.593039929359, 447.70919346428286, 454.8606244723351, 462.04712153056283, 469.2684767484908, 476.5244856720547, 483.81494719113493, 491.13966345051637, 498.4984397641164, 505.89108453232666, 513.3174091623252, 520.7772279912256], [0.0, 0.6589293190714831, 1.8002479524148158, 3.240892690173737, 4.91842235027662, 6.797439301654028, 8.854379765196752, 11.072125249384701, 13.437525860396864, 15.940079042198626, 18.571151457807776, 21.32348698361369, 24.190878415700592, 27.167938957245948, 30.24993763697261, 33.432677385903865, 36.712402552960725, 40.085727322127205, 43.54957933498074, 47.10115461007581, 50.737881011297006, 54.4573882916358, 58.25748326798932, 62.13612905193582, 66.091427524196, 70.12160443062375, 74.22499661728801, 78.40004102632565, 82.64526515282904, 86.95927872304138, 91.340766400454, 95.78848136251065, 100.3012396190344, 104.87791496603818, 109.5174344866107, 114.2187745251001, 118.98095707260605, 123.8030465114184, 128.68414667395288, 133.62339817826935, 138.6199760076923, 143.67308730658786, 148.78196936816, 153.9458877933371, 159.16413480253811, 164.4360276844173, 169.76090736766133, 175.13813710359813, 180.56710124883452, 186.04720413838956, 191.57786904087888, 197.15853718824462, 202.78866687334852, 208.46773260946216, 214.19522434631412, 219.9706467379085, 225.79351845781142, 231.66337155803149, 237.57975086800099, 243.54221343049633, 249.55032797163892, 255.6036744023805, 261.7018433491154, 267.8444357112739, 274.03106224393986, 280.2613431637077, 286.53490777614496, 292.8513941233656, 299.21044865034474, 305.61172588871347, 312.05488815688034, 318.53960527541204, 325.06555429669294, 331.6324192479593, 338.23989088686875, 344.8876664688359, 351.5754495254138, 358.3029496530607, 365.0698823116759, 371.8759686323316, 378.7209352336723, 385.604514046484, 392.526442145976, 399.4864615913432, 406.48431927221185, 413.5197667615917, 420.5925601749873, 427.70246003534083, 434.8492311435008, 442.0326424539309, 449.2524669553886, 456.5084815563238, 463.8004669747586, 471.1282076324278, 478.49149155297147, 485.8901102639798, 493.3238587027097, 500.7925351252945, 508.29594101928626, 515.8338810193729, 523.4061628261244, 531.012597127631], [0.0, 0.6717067441985914, 1.835156906617406, 3.303737463497893, 5.013796423800488, 6.929249754185319, 9.026076745771554, 11.286826959078441, 13.698095508165379, 16.249176179914222, 18.931268226645294, 21.736974819859807, 24.659968390557307, 27.694757685502296, 30.836519994243897, 34.08097686163385, 37.424299810040935, 40.86303736843978, 44.39405760171486, 48.01450215587732, 51.72174901802574, 55.513381979236094, 59.38716532797025, 63.34102267811141, 67.37301910358437, 71.4813459453397, 75.66430779890867, 79.92031129687257, 84.24785538069798, 88.64552281756235, 93.11197276501385, 97.64593422312029, 102.2462002427236, 106.91162278139859, 111.64110811709588, 116.43361274426002, 121.28813968923203, 126.20373519155885, 131.17948570589826, 136.2145151858697, 141.3079826167406, 146.4590797684611, 151.66702914444105, 156.93108210473517, 162.25051714507245, 167.62463831552026, 173.05277376458662, 178.53427439628354, 184.06851262915845, 189.65488124757618, 195.29279233664323, 200.9816762931229, 206.72098090552961, 212.5101704973208, 218.34872512774209, 224.2361398454482, 230.17192399051174, 236.15560054087192, 242.186705499661, 248.26478732018666, 254.38940636565562, 260.5601344009921, 266.7765541143482, 273.0382586661182, 279.344851263463, 285.695944758524, 292.09116126866166, 298.53013181719507, 305.01249599324575, 311.53790162940135, 318.1060044960217, 324.7164680111005, 331.368962964683, 338.0631672569167, 344.7987656488816, 351.5754495254138, 358.3929166691897, 365.2508710453966, 372.149022596362, 379.0870870455571, 386.064785710436, 393.08184532360303, 400.1379978618423, 407.23298038256894, 414.36653486729733, 421.5384080717416, 428.74835138219527, 435.9961206778547, 443.28147619877655, 450.604182419176, 457.964007925792, 465.3607253010631, 472.79411101087254, 480.2639452966356, 487.7700120715178, 495.3120988205809, 502.8899965046706, 510.50349946786616, 518.1524053483267, 525.8365149923738, 533.5556323716621, 541.3095645032981], [0.0, 0.6845600512581069, 1.8702731763688534, 3.3669554562143817, 5.109736900095535, 7.061842996030579, 9.198793391775416, 11.502803728532704, 13.960212613907828, 16.560108968230626, 19.293523638913687, 22.152918256958916, 25.13184417346305, 28.224705058437106, 31.42658591744047, 34.733126425821204, 38.140424846897204, 41.644963664725, 45.243551013685064, 48.93327384434022, 52.71145997079731, 56.57564694926048, 60.523556287190594, 64.55307186620888, 68.66222173485787, 72.84916262486267, 77.11216668968903, 81.4496100723618, 85.8599629911489, 90.3417810940589, 94.89369788122337, 99.51441803175085, 104.20271150115438, 108.95740827887772, 113.77739371417684, 118.66160433370909, 123.60902408642991, 128.6186809613981, 133.68964393231133, 138.82102018938264, 144.01195262481403, 149.26161754283478, 154.56922256922766, 159.9340047386009, 165.35522874048593, 170.83218530774252, 176.36418973280186, 181.9505804990324, 187.590718016025, 193.28398344889385, 199.02977763282024, 204.82752006504117, 210.6766479673411, 216.57661541284853, 222.5268925115891, 228.52696464982427, 234.57633177870395, 240.67450774820924, 246.82101968275524, 253.0154073951702, 259.25722283608087, 265.5460295760068, 271.8814023177144, 278.2629264366021, 284.6901975470823, 291.1628210931079, 297.6804119611433, 304.24259411402977, 310.84900024432017, 317.4992714457746, 324.193056901817, 330.930013589845, 337.70980600037393, 344.53210587007555, 351.3965919278399, 358.3029496530607, 365.2508710453966, 372.24005440532125, 379.27020412482284, 386.3410304876573, 393.4522494786056, 400.60358260121995, 407.7947567035809, 415.0255038116195, 422.2955609695902, 429.6046700873029, 436.95257779375424, 444.33903529681703, 451.76379824867047, 459.2266266166743, 466.7272845594062, 474.2655403076026, 481.84116604975526, 489.4539378221341, 497.1036354030191, 504.790042210936, 512.5129452067044, 520.2721347991168, 528.0674047540787, 535.898552107047, 543.7653770786161, 551.6676829931081], [0.0, 0.6974886966184849, 1.9055952764240078, 3.430543994513665, 5.20623972135243, 7.195213419149127, 9.372522398145394, 11.720046422994523, 14.223866091362414, 16.87286425622324, 19.657902372994293, 22.571299702553492, 25.606485806397714, 28.757758661888197, 32.02011044968175, 35.38909849575332, 38.86074737496971, 42.43147313935406, 46.09802364150652, 49.85743081595, 53.70697200971593, 57.64413827313581, 61.666608081913175, 65.77222535252083, 69.95898089109865, 74.22499661728803, 78.5685120523334, 82.98787267099188, 87.48151979997473, 92.04798180916549, 96.68586639089094, 101.39385376074551, 106.17069064354266, 111.01518493183113, 115.92620092350093, 120.90265506038317, 125.94351210222754, 131.0477816806315, 136.21451518586971, 141.44280294649198, 146.731771667307, 152.08058209617252, 157.48842689404066, 162.9545286861059, 168.47813827477873, 174.05853299765386, 179.69501521573105, 185.38691091893293, 191.13356843750455, 196.9343572492045, 202.78866687334857, 208.69590584376104, 214.6555007535607, 220.6668953654658, 226.72954978196572, 232.84293967029362, 239.0065555376445, 245.21990205253877, 251.4824974086327, 257.7938727276299, 264.1535714982677, 270.5611490486302, 277.01617204929295, 283.51821804502714, 290.0668750129931, 296.6617409455324, 303.30242345583065, 309.98853940486686, 316.7197145482017, 323.4955832012689, 330.3157879219479, 337.17997920928923, 344.0878152173545, 351.0389614832129, 358.03309066820765, 365.0698823116759, 372.149022596362, 379.27020412482284, 386.4331257061747, 393.63749215257354, 400.88301408487087, 408.1694077469167, 415.49639482802695, 422.86370229315713, 430.27106222036235, 437.71821164514466, 445.2048924113194, 452.73085102805527, 460.2958385327627, 467.8996103595295, 475.54192621281703, 483.2225499461524, 490.9412494455646, 498.6977965175299, 506.4919667812068, 514.3235395647492, 522.1922978055051, 530.0980279539139, 538.0405198809304, 546.0195667888104, 554.0349651251014, 562.0865144996959], [0.0, 0.7104921474833091, 1.941121751140163, 3.4945004578779404, 5.303300910638101, 7.329355527274224, 9.547256605415871, 11.938546089775832, 14.489045075227784, 17.187429155078743, 20.02438941264386, 22.99210191491955, 26.08387372912479, 29.293896528430402, 32.61706913150313, 36.04886603846902, 39.58523770938035, 43.22253337984925, 46.957440271903494, 50.786934985701734, 54.70824410919604, 58.718811917760995, 62.81627360635987, 66.99843289507757, 71.26324313216573, 75.60879122375832, 80.03328387006754, 84.53503570013528, 89.11245898194882, 93.76405464943466, 98.48840443779008, 103.28416395754891, 108.15005656841143, 113.08486793817819, 118.08744119156944, 123.15667256937861, 128.29150753112052, 133.49093724471427, 138.75399541527358, 144.07975541212278, 149.46732765901663, 154.91585725743172, 160.4245218169026, 165.99252946983677, 171.61911705117242, 177.30354842573382, 183.04511294826779, 188.84312404296367, 194.6969178908292, 200.60585221464407, 206.5693051523846, 212.58667421102783, 218.657375293529, 224.78084179253983, 230.95652374510962, 237.18388704320859, 243.46241269543387, 249.791596135721, 256.1709465752938, 262.59998639444404, 269.078250571059, 275.6052861430965, 282.18065170246643, 288.80391691800486, 295.47466208543034, 302.1924777023583, 308.95696406661176, 315.76773089621605, 322.6243969696022, 329.52658978465774, 336.473945235382, 343.46610730499475, 350.50272777444064, 357.58346594531565, 364.70798837630883, 371.8759686323316, 379.0870870455571, 386.3410304876573, 393.63749215257354, 400.9761713492035, 408.35677330343293, 415.7790089689773, 423.24259484653874, 430.74725281081436, 438.29270994492555, 445.8786983818634, 453.5049551525749, 461.1712220403378, 468.8772454410925, 476.6227762294254, 484.40756962990974, 492.2313850935367, 500.09398617897824, 507.9951404384435, 515.9346193079045, 523.9121980014764, 531.9276554097556, 539.9807740019252, 548.0713397314535, 556.1991419452155, 564.3639732958812, 572.5656296574216], [0.0, 0.7235698815405113, 1.9768511735186953, 3.558822277355857, 5.400916569277414, 7.464263932294461, 9.722988995004917, 12.158293952359221, 14.755738914009576, 17.503791029609385, 20.392970037108203, 23.415307991615098, 26.563988766313358, 29.833097122912704, 33.217437984752415, 36.712402552960725, 40.313866749388936, 44.01811261154441, 47.82176638452578, 51.721749018025754, 55.71523605095197, 59.79962471651665, 63.972506681698285, 68.23164524056898, 72.57495606951116, 77.00049086113405, 81.50642330712499, 86.09103701460221, 90.75271502682881, 95.48993068504429, 100.30123961903442, 105.1852726937141, 110.14072977019552, 115.16637416457046, 120.26102770743606, 125.42356632314821, 130.65291606073265, 135.9480495189552, 141.30798261674062, 146.731771667307, 152.2185107203484, 157.76732914157915, 163.3773894031338, 169.04788506184184, 174.77803890537885, 180.5671012488345, 186.41434836640337, 192.31908104475883, 198.28062324626805, 204.29832087158042, 210.3715406123161, 216.49966888561318, 222.68211084319498, 228.91828944840702, 235.20764461535876, 241.54963240491566, 247.94372427281547, 254.38940636565565, 260.88617886091464, 267.4335553475367, 274.03106224393986, 280.67823825059776, 287.3746338346047, 294.1198107438697, 300.91334154878876, 307.75480920943704, 314.64380666648526, 321.57993645420066, 328.56281033402684, 335.5920489473598, 342.6672814862507, 349.7881453808662, 356.95428600262744, 364.1653563820362, 371.4210169402657, 378.7209352336723, 386.064785710436, 393.4522494786056, 400.88301408487087, 408.35677330343293, 415.87322693439296, 423.4320806111112, 431.03304561603613, 438.6758387045277, 446.3601819362396, 454.08580251364606, 461.852432627332, 469.65980930768706, 477.5076742826669, 485.3957738413099, 493.32385870270963, 501.2916838901715, 509.2990086102901, 517.3455961367044, 525.4312136983036, 533.555632371662, 541.7186269775071, 549.9199759810227, 558.1594613958113, 566.4368686913432, 574.7519867037322, 583.1046075496863], [0.0, 0.7367213866271994, 2.0127821442893477, 3.6235069339140007, 5.499082874351368, 7.5999333507961735, 9.89971268471043, 12.379281404765985, 15.023937163185284, 17.821937490144926, 20.7636298116758, 23.840901358633726, 27.046812115233163, 30.37533932863901, 33.821193497202884, 37.37968205316858, 41.04660595971907, 44.81817967719483, 48.69096812979672, 52.6618363028292, 56.72790839818966, 60.88653434156477, 65.13526202640847, 69.47181409273838, 73.89406833256203, 78.40004102632565, 82.98787267099186, 87.6558156767616, 92.40222369731826, 97.22554232556494, 102.12430093861617, 107.09710551617883, 112.14263228822227, 117.25962209304436, 122.44687534699973, 127.7032475434024, 133.02764521129524, 138.41902227554274, 143.8763767685495, 149.39874785121455, 154.9852131068057, 160.63488607651013, 166.34691400967293, 172.12047580532513, 177.95478012463974, 183.8490636565382, 189.80258952087596, 195.81464579552264, 201.8845441552798, 208.01161861197843, 214.1952243463141, 220.4347366230284, 226.72954978196563, 233.07907629833358, 239.48274590619883, 245.9400047798651, 252.4503147683235, 259.0131526784438, 265.6280096030002, 272.29439028999735, 279.0118125501008, 285.77980669926836, 292.59791503394706, 299.46569133643715, 306.38270040823386, 313.34851762935284, 320.36272854181146, 327.4249284555952, 334.5347220755779, 341.69172314798664, 348.89555412511913, 356.14584584712327, 363.4422372397408, 370.7843750270042, 378.17191345794964, 385.604514046484, 393.08184532360303, 400.60358260121995, 408.1694077469167, 415.7790089689773, 423.4320806111112, 431.12832295631193, 438.8674420393381, 446.6491494673345, 454.47316224815, 462.33920262592915, 470.24699792359024, 478.1962803918241, 486.1867870642698, 494.2182596185507, 502.29044424286536, 510.4030915078571, 518.5559562434931, 526.7487974207074, 534.9813780375736, 543.2534650097859, 551.564829065245, 559.9152446425486, 568.3044897932089, 576.7323460874195, 585.1985985232086, 593.7030354388268], [0.0, 0.749946160409222, 2.048913291034774, 3.6885519568608527, 5.597796076305272, 7.73635860075785, 10.077420924404256, 12.601500006171774, 15.293629578669604, 18.14185638478098, 21.13635457864666, 24.268865760035027, 27.532325333990617, 30.920602434156404, 34.42831260784282, 38.05067905172216, 41.7834273527049, 45.62270401748369, 49.56501230773516, 53.607160932590816, 57.746222470932864, 61.97949927736621, 66.30449522795243, 70.71889208216575, 75.2205295365802, 79.8073882621934, 84.47757537631121, 89.22931191841536, 94.0609219888764, 98.9708232776716, 103.9575187629873, 109.0195894006837, 114.15568765793526, 119.36453177001928, 124.64490061974645, 129.995629155565, 135.41560427778666, 140.90376113333988, 146.45907976846112, 152.08058209617252, 157.76732914157915, 163.51841853318064, 169.33298221272443, 175.21018433978276, 181.14921937032548, 187.14931029119268, 193.2097069946162, 199.3296847788596, 205.50854296270325, 211.74560360292563, 218.04021030516884, 224.39172711964673, 230.79953751408996, 237.26304341713808, 243.78166432610038, 250.3548364736396, 256.9820120484798, 263.6626584657303, 270.39625768284884, 277.1823055576468, 284.02031124508215, 290.9097966298857, 297.8502957923375, 304.8413545047516, 311.882529756441, 318.97338930513234, 326.11351125297074, 333.30248364541256, 340.5399040914491, 347.8253794037243, 355.1585252572345, 362.538965865395, 369.9663336723586, 377.44026906055433, 384.9604200724953, 392.526442145976, 400.1379978618423, 407.7947567035809, 415.49639482802695, 423.24259484653874, 431.03304561603613, 438.8674420393381, 446.7454848742776, 454.6668805511035, 462.63134099771526, 470.63858347230416, 478.68833040300376, 486.78030923417754, 494.9142522789955, 503.0898965779751, 511.3069837631778, 519.5652599277785, 527.8644755007342, 536.2043851263028, 544.5847475481722, 553.005325497976, 561.4658855879858, 569.9661982077808, 578.50603742471, 587.0851808879664, 595.7034097361106, 604.360508507885], [0.0, 0.7632437100746419, 2.0852432673530825, 3.753954922339167, 5.69705249666076, 7.873534598388052, 10.256107091913247, 12.824941475755963, 15.564806110563469, 18.46353579196389, 21.511130448693265, 24.699185248025174, 28.0205103302755, 31.46886612061695, 35.03877269280355, 38.72536854438805, 42.52430347121302, 46.43165565237465, 50.44386634769665, 54.55768768045003, 58.770140322420495, 63.07847879534774, 67.48016271567337, 71.97283273736282, 76.55429025191748, 81.22248012492776, 85.97547591035458, 90.81146710432752, 95.72874809127254, 100.72570850469135, 105.8008247785689, 110.95265270721254, 116.17982086423534, 121.4810247575096, 126.85502161780312, 132.30062573563998, 137.8167042745839, 143.40217350029252, 149.05599537385615, 154.77717446550514, 160.56475515106231, 166.41781905877218, 172.33548273854706, 178.3168955293891, 184.36123760389373, 190.46771817141735, 196.63557382377655, 202.86406700930266, 209.1524846227598, 215.50013670008525, 221.9063552081702, 228.37049292098723, 234.89192237432422, 241.4700348922147, 248.10423967887786, 254.79396297062667, 261.53864724275763, 268.33775046693677, 275.190745415034, 282.0971190057444, 289.05637169068615, 296.0680168769661, 303.1315803834838, 310.2465999284882, 317.41262464611947, 324.62921462987003, 331.89594050107104, 339.21238300067324, 346.57813260273633, 353.992789148166, 361.4559614973617, 368.9672672005395, 376.5263321845944, 384.13279045545477, 391.78628381495594, 399.4864615913432, 407.23298038256894, 415.0255038116195, 422.86370229315713, 430.74725281081436, 438.6758387045277, 446.6491494673345, 454.6668805511035, 462.7287331806985, 470.83441417611516, 478.9836357821537, 487.1761155052269, 495.41157595692175, 503.6897447039623, 512.0103541242422, 520.3731412686136, 528.7778477281432, 537.2242195065594, 545.712006897634, 554.2409643672574, 562.8108504399776, 571.4214275897891, 580.072462134971, 588.7637241367836, 597.4949873018426, 606.266028888002, 615.0766296135877], [0.0, 0.7766135520403609, 2.1217707520563156, 3.819713451883026, 5.796848525825952, 8.011456355098991, 10.435764689077015, 13.049597687772023, 15.837456897171249, 18.786964013393728, 21.88794379259212, 25.13184417346305, 28.511349350590443, 32.020110449681745, 35.65255155189132, 39.40372599518454, 43.269207372296975, 47.24500516326446, 51.32749828898392, 55.51338197923611, 59.79962471651665, 64.183432929656, 68.66222173485787, 73.23359045710815, 77.89530197458969, 82.64526515282904, 87.48151979997472, 92.40222369731826, 97.40564135178991, 102.49013418788644, 107.65415195108349, 112.89622513734454, 118.2149582968235, 123.60902408642993, 129.07715796717707, 134.6181534593578, 140.2308578824888, 145.9141685183085, 151.66702914444105, 157.48842689404066, 163.3773894031338, 169.33298221272443, 175.35430639721167, 181.44049639445538, 187.59071801602497, 193.8041666188915, 200.08006542214852, 206.41766395433632, 212.8162366186594, 219.2750813648624, 225.7935184578114, 232.3708893339342, 239.0065555376444, 245.69989773071728, 252.4503147683235, 259.2572228360809, 266.12005464305133, 273.03825866611817, 280.0112984416257, 287.03865190055535, 294.11981074386966, 301.2542798549627, 308.44157674644043, 315.68123103870056, 322.9727839680059, 330.31578792194784, 337.70980600037404, 345.15441160001853, 352.6491880212204, 360.1937280952452, 367.7876338308476, 375.4305160788198, 383.12199421336834, 390.8616958292545, 398.6492564537086, 406.48431927221185, 414.36653486729733, 422.2955609695902, 430.27106222036235, 438.29270994492555, 446.3601819362396, 454.47316224815, 462.63134099771526, 470.83441417611516, 479.08208346767196, 487.37405607653994, 495.7100445606537, 504.0897666725505, 512.5129452067043, 520.9793078530367, 529.4885870562845, 538.0405198809303, 546.6348478814162, 555.2713169773766, 563.9496773336483, 572.6696832448212, 581.4310930241153, 590.2336688963758, 599.0771768949952, 607.961386762578, 616.8860718551742, 625.8510090499233], [0.0, 0.7900552116711762, 2.158494448402884, 3.885825211036039, 5.897180620998426, 8.150118974608336, 10.61638733797275, 13.275460666826746, 16.111572259271473, 19.112129567228013, 22.266781233305686, 25.566827176768694, 29.004824969936816, 32.57431585193741, 36.26962739568978, 40.085727322127205, 44.0181126115444, 48.06272367589184, 52.21587676227886, 56.474209901385926, 60.83463910607772, 65.29432245393882, 69.85063032189674, 74.50112048395452, 79.2435170980976, 84.07569283641018, 88.99565357995874, 94.00152522483688, 99.09154223998866, 104.26403768937794, 109.51743448661068, 114.85023769341338, 120.26102770743603, 125.74845421187885, 131.31123078106174, 136.9481300534767, 142.65797939799862, 148.43965701047247, 154.2920883873817, 160.214243131139, 166.20513204805482, 172.2638045054779, 178.3893460191658, 184.58087604579282, 190.83754595876042, 197.1585371882446, 203.5430595087828, 209.99034945972397, 216.49966888561318, 223.07030358508015, 229.70156205810693, 236.3927743426757, 243.14329093278417, 249.95248177067592, 256.81973530688197, 263.74445762233654, 270.7260716074063, 277.76401619318966, 284.85774563089564, 292.0067288155135, 299.21044865034474, 306.4684014492847, 313.7800963740276, 321.1450549036213, 328.56281033402684, 336.0329073055414, 343.5549013561267, 351.1283584988497, 358.75285482179453, 366.42797610893314, 374.15331748057133, 381.92848305209066, 389.75308560981057, 397.62674630288706, 405.5490943502405, 413.5197667615917, 421.5384080717416, 429.6046700873029, 437.71821164514466, 445.8786983818634, 454.08580251364606, 462.33920262592915, 470.63858347230416, 478.9836357821537, 487.37405607653994, 495.80954649189425, 504.2898146110923, 512.8145733015203, 521.3835405597678, 529.9964393626017, 538.6529975239015, 547.352947557251, 556.0960265439059, 564.8819760058667, 573.7105417838131, 582.5814739196557, 591.4945265434893, 600.4494577647371, 609.4460295672877, 618.484007708441, 627.5631616214844, 636.6832643217373], [0.0, 0.8035682230106036, 2.1954130833621566, 3.9522879080274196, 5.998045304156, 8.289517650162422, 10.797968777298141, 13.502522583357226, 16.387142694627517, 19.439021181570084, 22.647629638395937, 26.004119179212502, 29.5009200819326, 33.131463115797914, 36.88997883320266, 40.77134888357138, 44.77099322807979, 48.88478284396224, 53.108970971852266, 57.44013813970283, 61.875147612225696, 66.41110885909897, 71.04534728048671, 75.77537887884594, 80.59888888642823, 85.5137135897515, 90.51782476270674, 95.60931624693492, 100.78639231394477, 106.04735751662244, 111.39060779427378, 116.81462263937708, 122.31795816887085, 127.8992409702957, 133.55716261509812, 139.29047474912338, 145.09798468470163, 150.97855143047167, 156.93108210473522, 162.9545286861059, 169.04788506184184, 175.21018433978278, 181.4404963944554, 187.73792562182467, 194.10160888048256, 200.53071359988317, 207.02443603864066, 213.58199967796287, 220.20265373707088, 226.8856717989782, 233.630350536332, 240.43600852816294, 247.3019851593946, 254.2276395958368, 261.2123498281504, 268.2555117789479, 275.3565384677808, 282.5148592292909, 289.7299189802642, 297.00117753173237, 304.3281089426359, 311.7102009118823, 319.14695420592506, 326.6378821192461, 334.1825099653555, 341.7803745961318, 349.43102394751014, 357.1340166096961, 364.8889214202344, 372.69531707839474, 380.55279177946835, 388.46094286767277, 396.41937650647037, 404.42770736519674, 412.48555832097645, 420.5925601749873, 428.74835138219527, 436.95257779375424, 445.2048924113194, 453.5049551525749, 461.852432627332, 470.24699792359024, 478.68833040300376, 487.1761155052269, 495.7100445606537, 504.2898146110923, 512.9151282379501, 521.585693397531, 530.3012232630714, 539.0614360731655, 547.8660549862532, 556.7148079408624, 565.6074275213173, 574.5436508286415, 583.5232193564033, 592.5458788712594, 601.6113792979751, 610.7194746087054, 619.8699227163395, 629.0624853717175, 638.2969280645409, 647.5730199278102], [0.0, 0.8171521285228424, 2.2325254069094886, 4.019099292502861, 6.0994391601307, 8.42964766187439, 10.980502858904037, 13.730775749295042, 16.664158872725512, 19.767627788227017, 23.030476112751966, 26.443705374565027, 29.999617889339287, 33.69153337686557, 37.51358486000806, 41.46056746512005, 45.527823730188, 49.71115483345035, 54.00675067850992, 58.41113398891198, 62.92111500447935, 67.53375433196894, 72.2463321588168, 77.05632249678534, 81.96137144817361, 86.95927872304138, 92.04798180916546, 97.22554232556494, 102.49013418788644, 107.84003328835887, 113.27360845047107, 118.78931346330752, 124.38568003570977, 130.0613115383906, 135.81487742448806, 141.64510823706559, 147.55079112668466, 153.53076581411477, 159.58392094305745, 165.70919077586635, 171.90555219198365, 178.17202195443687, 184.50765421446224, 190.91153822830142, 197.38279626358693, 203.92058167559813, 210.52407713611632, 217.19249299970062, 223.92506579401098, 230.72105682235718, 237.579750868001, 244.50045499090382, 251.48249740863267, 258.52522645402667, 265.62800960300024, 272.7902325665498, 280.01129844162574, 287.29062691606697, 294.6276535232646, 302.021828942635, 309.4726183423568, 316.97950076115234, 324.54196852619, 332.15952670444653, 339.83169258510213, 347.5579951907557, 355.33797481543314, 363.17118258753544, 371.05718005602887, 378.9955387983121, 386.9858400483305, 395.0276743436137, 403.120641190021, 411.2643487430723, 419.4584135048247, 427.70246003534083, 435.9961206778547, 444.33903529681703, 452.73085102805527, 461.1712220403378, 469.65980930768706, 478.1962803918241, 486.78030923417754, 495.41157595692175, 504.0897666725505, 512.8145733015203, 521.585693397531, 530.4028299800389, 539.2656913736217, 548.1739910538432, 557.1274474992795, 566.1257840494001, 575.1687287680052, 584.2560143119471, 593.3873778048767, 602.5625607157672, 611.7813087419913, 621.0433716967306, 630.3485034005166, 639.6964615767108, 649.087007750739, 658.5199071529145], [0.0, 0.8308064788452976, 2.269830191350091, 4.086257154307331, 6.201358834761516, 8.570504374171238, 11.163983544468948, 13.960212613907832, 16.94261162972752, 20.097938516722916, 23.415307991615098, 26.885571221088377, 30.500901894976415, 34.25450810772752, 38.14042484689721, 42.15336026706735, 46.28857908152599, 50.541812307544866, 54.90918618323646, 59.387165327970266, 63.972506681698285, 68.66222173485787, 73.45354522768832, 78.3439089634977, 83.33091971170843, 88.41234041624023, 93.58607410095127, 98.85014999513533, 104.2027115011544, 109.64200570194883, 115.16637416457044, 120.77424484141457, 126.46412490664781, 132.23459439375495, 138.08430052286215, 144.01195262481403, 150.0163175838465, 156.09621573283474, 162.25051714507248, 168.47813827477873, 174.77803890537882, 181.14921937032545, 187.59071801602497, 194.10160888048253, 200.68099956470394, 207.3280292768065, 214.04186703127877, 220.82170998795746, 227.66678191712427, 234.57633177870395, 241.54963240491566, 248.58597927691463, 255.6846893869987, 262.8451001788574, 270.06656855913036, 277.3484699742415, 284.6901975470824, 292.09116126866166, 299.55078724031415, 307.06851696248526, 314.6438066664852, 322.2761266859403, 329.9649608649684, 337.7098060003741, 345.5101713153943, 353.36557796274644, 361.2755585549168, 369.23965671980585, 377.25742668000345, 385.32843285410377, 393.45224947860567, 401.62846024905195, 409.85665797917324, 418.1364442768934, 426.4674292361422, 434.8492311435008, 443.28147619877655, 451.76379824867047, 460.2958385327627, 468.8772454410925, 477.5076742826669, 486.1867870642698, 494.9142522789955, 503.6897447039623, 512.5129452067043, 521.3835405597678, 530.3012232630714, 539.2656913736217, 548.2766483421939, 557.3338028566199, 566.4368686913432, 575.5855645629242, 584.7796139911966, 594.0187451657941, 603.3026908177882, 612.6311880961813, 622.0039784490308, 631.4208075089765, 640.8814249829701, 650.3855845460077, 659.9330437386818, 669.523563868379], [0.0, 0.8445308325511145, 2.307326230670256, 4.153759322317123, 6.303801033121896, 8.712083233344144, 11.348404902308095, 14.190825759809108, 17.22249196362892, 20.4299426885544, 23.802112833886202, 27.32970243385165, 31.004755893003583, 34.82036910816486, 38.77047852897306, 42.84970489235004, 47.053234687892335, 51.3767284122024, 55.816248311500885, 60.368200603091964, 65.029288653798, 69.7964745859263, 74.66694745951989, 79.63809665303734, 84.70748940137196, 89.87285169380998, 95.1320519136007, 100.48308673425637, 105.92406888841828, 111.4532165020381, 117.06884374599187, 122.76935260352573, 128.55322558834655, 134.4190192770653, 140.36535854281166, 146.39093139546023, 152.49448434901956, 158.67481824907225, 164.93078450329722, 171.26128166647962, 177.66525233837987, 184.1416803386443, 190.68958812782085, 197.30803444765712, 203.99611215733904, 210.75294624529187, 217.57769199869298, 224.46953331500973, 231.42768114174083, 238.4513720321436, 245.5398668061238, 252.69244930666812, 259.90842524325524, 267.18712111459837, 274.5278832038756, 281.93007664031376, 289.39308452161043, 296.91630709223, 304.4991609730947, 312.14107843862, 319.84150673742994, 327.59990745342526, 335.4157559041825, 343.28854057393414, 351.2177625786214, 359.20293516073264, 367.24358321183274, 375.33924282086787, 383.48946084649043, 391.69379451178844, 399.95181101993927, 408.2630871894216, 416.6272091075276, 425.0437718010175, 433.5123789228395, 442.0326424539309, 450.604182419176, 459.2266266166743, 467.8996103595295, 476.6227762294254, 485.3957738413099, 494.2182596185507, 503.0898965779751, 512.0103541242422, 520.9793078530367, 529.9964393626017, 539.0614360731655, 548.1739910538432, 557.3338028566199, 566.5405753570502, 575.7940176013277, 585.093843659403, 594.4397724838468, 603.8315277741722, 613.2688378463505, 622.7514355072665, 632.2790579338761, 641.8514465568447, 651.4683469484547, 661.1295087145818, 670.834685390555, 680.5836343407228], [0.0, 0.858324755921207, 2.3450123399145193, 4.221603663318589, 6.406762517818112, 8.85437976519675, 11.533761104310047, 14.422607899127621, 17.50379102960938, 20.763629811675802, 24.19087841570059, 27.776084977353594, 31.511163960551112, 35.389098495753316, 39.403725995184544, 43.54957933498074, 47.82176638452578, 52.21587676227887, 56.72790839818966, 61.354208811453056, 66.09142752419599, 70.93647704034541, 75.88650050819204, 80.93884466629063, 86.09103701460221, 91.340766400454, 96.68586639089091, 102.12430093861617, 107.65415195108349, 113.27360845047107, 118.98095707260605, 124.77457369994605, 130.65291606073265, 136.6145171557986, 142.65797939799862, 148.78196936816, 154.9852131068057, 161.26649187344356, 167.62463831552026, 174.05853299765383, 180.56710124883446, 187.14931029119265, 193.8041666188915, 200.53071359988314, 207.32802927680646, 214.19522434631412, 221.1314402986876, 228.1358477017971, 235.2076446153588, 242.34605512307235, 249.55032797163892, 256.81973530688197, 264.15357149826764, 271.5511520440521, 279.01181255010084, 286.5349077761449, 294.11981074386966, 301.7659119017894, 309.4726183423568, 317.2393530671899, 325.065554296693, 332.9506748206882, 340.89418138698915, 348.89555412511925, 356.95428600262744, 365.0698823116758, 373.24186018376986, 381.46974813068584, 389.7530856098106, 398.0914226122514, 406.48431927221185, 414.93134549624597, 423.43208061111113, 431.986113029043, 440.593039929359, 449.2524669553886, 457.964007925792, 466.7272845594062, 475.54192621281703, 484.40756962990974, 493.32385870270963, 502.29044424286536, 511.3069837631778, 520.3731412686136, 529.4885870562845, 538.6529975239015, 547.8660549862532, 557.1274474992795, 566.4368686913432, 575.7940176013277, 585.1985985232086, 594.6503208567731, 604.1488989641771, 613.694052032052, 623.2855039388893, 632.9229831274446, 642.6062224819227, 652.3349592097145, 662.1089347274734, 671.9278945513286, 681.7915881910426, 691.6997690479382], [0.0, 0.8721878227253049, 2.382887354587466, 4.289788080931243, 6.510240107354929, 8.997389572786458, 11.720046422994523, 14.655551869828232, 17.78650013556778, 21.09898957520247, 24.581592724257074, 28.224705058437106, 32.020110449681745, 35.9606786968357, 40.04014767827504, 44.25296196893873, 48.594150423906214, 53.059231428209614, 57.644138273135795, 62.34515948554014, 67.15889047295224, 72.08219387220147, 77.11216668968903, 82.246112810329, 87.48151979997472, 92.81603917781665, 98.24746952017553, 103.77374189492923, 109.39290722982952, 115.10312529739547, 120.90265506038314, 126.78984616962883, 132.76313144366915, 138.82102018938264, 144.96209224676474, 151.18499266018, 157.48842689404063, 163.87115652360228, 170.33199534204198, 176.86980583363302, 183.48349597002402, 190.17201629263278, 196.93435724920445, 203.76954675683314, 210.67664796734113, 217.6547572139695, 224.7030021209456, 231.82053985972652, 239.00655553764446, 246.26026070633668, 253.5808919787814, 260.96770974500583, 268.4199969776205, 275.9370581192837, 283.518218045027, 291.1628210931079, 298.8702301586922, 306.639825845241, 314.47100566897495, 322.3631833122341, 330.31578792194784, 338.32826344977866, 346.4000680308202, 354.5306733980082, 362.71956432965476, 370.96623812774357, 379.27020412482284, 387.63098321751767, 396.0481074248497, 404.52111946969427, 413.0495723818475, 421.6330291212919, 430.27106222036224, 438.96325344361355, 447.70919346428286, 456.5084815563238, 465.3607253010631, 474.2655403076026, 483.2225499461524, 492.2313850935367, 501.2916838901715, 510.4030915078571, 519.5652599277785, 528.7778477281432, 538.0405198809303, 547.352947557251, 556.7148079408624, 566.1257840494001, 575.5855645629242, 585.093843659403, 594.6503208567731, 604.2547008612484, 613.9066934215601, 623.6060131888369, 633.3523795818469, 643.145516657341, 652.9851529852551, 662.8710215285356, 672.8028595273771, 682.7804083876614, 692.8034135734066, 702.871624503044], [0.0, 0.8861196140115631, 2.420950130078923, 4.358310514572963, 6.614230674565199, 9.141108334254072, 11.907255228685267, 14.889650632176673, 18.07061073783169, 21.436011844321257, 24.97424395188836, 28.675549119480806, 32.53157997966668, 36.53509243784741, 40.679724345123745, 44.95983153749511, 49.37036346403268, 53.90676692321033, 58.564910247213746, 63.34102267811142, 68.23164524056898, 73.23359045710815, 78.3439089634977, 83.55986157856928, 88.87889573610006, 94.29862544209399, 99.81681410868532, 105.43135975590401, 111.14028217822177, 116.94171175349689, 122.83387963422841, 128.81510910959122, 134.88380796493007, 141.03846169570946, 147.2776274571632, 153.59992865042884, 160.00405006180404, 166.4887334847101, 173.05277376458665, 179.69501521573105, 186.41434836640337, 193.20970699461623, 200.08006542214855, 207.02443603864063, 214.04186703127877, 221.13144029868764, 228.29226953030107, 235.5234984347519, 242.82429910277864, 250.19387049182978, 257.63143702100933, 265.13624726627006, 272.70757274686855, 280.3447067950583, 288.04696350184037, 295.8136767323351, 303.6441992049881, 311.5379016294014, 319.4941718980908, 327.51241432791903, 335.59204894735984, 343.7325108261021, 351.93324944382294, 360.1937280952454, 368.51342332884735, 376.8918244168241, 385.3284328541039, 393.8227618844096, 402.3743360515229, 410.98269077405564, 419.64737194217736, 428.3679355348623, 437.14394725633986, 445.9749821905297, 454.8606244723351, 463.8004669747586, 472.79411101087254, 481.84116604975526, 490.9412494455646, 500.09398617897824, 509.2990086102901, 518.5559562434931, 527.8644755007342, 537.2242195065594, 546.6348478814162, 556.0960265439059, 565.6074275213173, 575.1687287680052, 584.7796139911966, 594.4397724838468, 604.1488989641771, 613.9066934215601, 623.7128609684324, 633.5671116979348, 643.469160547004, 653.4187271646433, 663.4155357851317, 673.4593151059304, 683.5497981700704, 693.6867222528102, 703.8698287523671, 714.0988630845367], [0.0, 0.900119717904309, 2.459199541111393, 4.42716893846524, 6.7187311451001985, 9.285531800737383, 12.095381986792283, 15.12489726534108, 18.356114437032858, 21.77468665539785, 25.368820490360804, 29.12860383185402, 33.045557429560446, 37.11232273697751, 41.32243708746077, 45.67016714295106, 50.15038255715487, 54.75845819097312, 59.49019709897238, 64.3417689477395, 69.30966011241729, 74.39063275549128, 79.58169091472587, 84.88005213170173, 90.28312351133776, 95.78848136251065, 101.39385376074551, 107.09710551617884, 112.89622513734456, 118.78931346330752, 124.77457369994606, 130.8503026455128, 137.01488292941403, 143.266776118944, 149.60451657334355, 156.02670594439843, 162.5320082388997, 169.11914537143673, 175.78689314680412, 182.53407762022937, 189.35957179105284, 196.26229259168474, 203.24119813886657, 210.29528521864793, 217.4235869802022, 224.6251708167594, 231.89913641463264, 239.24461395361737, 246.66076244403334, 254.1467681873864, 261.7018433491154, 269.32522463317, 277.0161720492929, 284.77396776485443, 292.5979150339471, 300.48733719720076, 308.44157674644043, 316.45999444889605, 324.54196852619, 332.6868938837853, 340.89418138698915, 349.16325717996517, 357.4935620445334, 365.88455079582843, 374.3356917121404, 382.8464659965028, 391.4163672677936, 400.0449010793084, 408.73158446293485, 417.4759454972064, 426.27752289765726, 435.1358656280234, 444.0505325309481, 453.021091976958, 462.04712153056283, 471.1282076324278, 480.2639452966356, 489.4539378221341, 498.6977965175299, 507.9951404384435, 517.3455961367044, 526.7487974207074, 536.2043851263028, 545.712006897634, 555.2713169773766, 564.8819760058667, 574.5436508286415, 584.2560143119471, 594.0187451657941, 603.8315277741722, 613.694052032052, 623.6060131888369, 633.5671116979348, 643.5770530721502, 653.6355477446115, 663.742310934962, 673.8970625205645, 684.0995269124794, 694.3494329359944, 704.6465137154909, 714.9905065634485, 725.3811528734012], [0.0, 0.9141877294095342, 2.4976344812086357, 4.496361360676487, 6.823738495977754, 9.430655794364634, 12.284421255198106, 15.361284964123595, 18.643002974140607, 22.11500421127143, 25.765310925392388, 29.58385608962228, 33.56202793105995, 37.69235289614899, 41.96826731293767, 46.383948236768724, 50.934185138936, 55.61428059383364, 60.41997206177952, 65.3473693449075, 70.3929039037597, 75.55328729651366, 80.82547673690542, 86.20664627934802, 91.69416250428667, 97.28556384062064, 102.97854285586531, 108.77093098917895, 114.66068531140496, 120.64587697953667, 126.7246811172763, 132.89536790345994, 139.1562946895361, 145.5058989985653, 151.94269228322304, 158.46525434044804, 165.07222829673344, 171.7623160914144, 178.53427439628354, 185.3869109189329, 192.31908104475883, 199.32968477885956, 206.41766395433632, 213.58199967796284, 220.82170998795743, 228.1358477017971, 235.52349843475187, 242.98377877215813, 250.51583458047014, 258.11883944386346, 265.79199321467513, 273.53452066726663, 281.34567024603956, 289.22471289932605, 297.1709409917454, 305.18366728838765, 313.26222400485324, 321.4059619177743, 329.61424953097094, 337.88647229285664, 346.2220318611261, 354.620345411124, 363.08084498462455, 371.6029768760435, 380.1862010533685, 388.82999061133205, 397.53383125455866, 406.2972208086142, 415.1196687570562, 424.00069580273606, 432.9398334517525, 441.93662361857537, 450.9906182509799, 460.10137897353616, 469.2684767484908, 478.49149155297147, 487.7700120715178, 497.1036354030191, 506.4919667812068, 515.9346193079045, 525.4312136983036, 534.9813780375736, 544.5847475481722, 554.2409643672574, 563.9496773336483, 573.7105417838131, 583.5232193564033, 593.3873778048767, 603.3026908177882, 613.2688378463505, 623.2855039388893, 633.3523795818469, 643.469160547004, 653.6355477446115, 663.8512470821444, 674.1159693284008, 684.4294299826943, 694.7913491488932, 705.2014514140837, 715.659465731636, 726.1651253084749, 736.718167496362], [0.0, 0.9283232502277446, 2.536253862184367, 4.565885822201575, 6.92924975418532, 9.576476206323916, 12.474367681742988, 15.598807035815677, 18.931268226645294, 22.456954876727362, 26.163704031378167, 30.041293003491052, 34.08097686163385, 38.27516649330259, 42.617196736535846, 47.1011546100758, 51.72174901802574, 56.474209901385926, 61.35420881145304, 66.35779539863157, 71.4813459453397, 76.72152116260801, 82.0752312154459, 87.53960646241337, 93.11197276501386, 98.78983049039142, 104.57083652765662, 110.45278878484939, 116.43361274426003, 122.51134973837253, 128.68414667395288, 134.95024698267974, 141.3079826167406, 147.75576693957905, 154.29208838738174, 160.91550479736372, 167.62463831552026, 174.41817081007534, 181.29483972800463, 188.25343434121828, 195.29279233664323, 202.4117967108353, 209.6093729351137, 216.884486361735, 224.23613984544824, 231.66337155803149, 239.16525297618784, 246.74088702555784, 254.3894063656557, 262.10997180229896, 269.9017708156351, 277.7640161931897, 285.695944758524, 293.6968161870939, 301.7659119017894, 309.90253404141134, 318.10600449602174, 326.3756640037125, 334.7108713038679, 343.1110023424694, 351.5754495254138, 360.1036210161878, 368.69494007457786, 377.348844433392, 386.064785710436, 394.84222885323135, 403.6806516141705, 412.5795440540058, 421.5384080717417, 430.5567569591535, 439.6341149783079, 448.7700169605806, 457.964007925792, 467.21564272018315, 476.5244856720547, 485.8901102639798, 495.3120988205809, 504.790042210936, 514.3235395647492, 523.9121980014764, 533.555632371662, 543.2534650097859, 553.005325497976, 562.8108504399776, 572.6696832448212, 582.5814739196557, 592.5458788712594, 602.5625607157672, 612.6311880961813, 622.7514355072665, 632.9229831274446, 643.145516657341, 653.4187271646433, 663.742310934962, 674.1159693284008, 684.5394086415541, 695.0123399746772, 705.534479103777, 716.1055463573998, 726.7252664978889, 737.3933686069124, 748.1095859750644], [0.0, 0.9425258885738265, 2.57505661365011, 4.635740396075839, 7.035261995335401, 9.722988995004915, 12.665216001804328, 15.83745689717125, 19.220902204884826, 22.800529174139594, 26.563988766313358, 30.500901894976415, 34.60238983790933, 38.860747374969705, 43.26920737229698, 47.82176638452579, 52.513052366024, 57.338222279523954, 62.29288145435548, 67.37301910358438, 72.57495606951116, 77.89530197458969, 83.33091971170843, 88.87889573610008, 94.5365149969867, 100.30123961903443, 106.17069064354266, 112.1426322882223, 118.21495829682353, 124.38568003570978, 130.65291606073268, 137.01488292941403, 143.46988707408087, 150.01631758384653, 156.65263976912303, 163.37738940313383, 170.1891675517578, 177.08663591680718, 184.06851262915845, 191.1335684375045, 198.28062324626802, 205.50854296270322, 212.81623661865936, 220.20265373707082, 227.66678191712424, 235.2076446153588, 242.82429910277858, 250.5158345804701, 258.281370438299, 266.12005464305133, 274.0310622439399, 282.01359398473943, 290.066875012993, 298.1901536777553, 306.382700408234, 314.64380666648526, 322.972783968006, 331.3689629646831, 339.8316925851022, 348.36033922769366, 356.95428600262755, 365.6129320187429, 374.33569171214043, 383.12199421336845, 391.9712827504032, 400.8830140848708, 409.85665797917335, 418.8916966923813, 427.98762450293333, 437.14394725633986, 446.36018193623966, 455.635856257283, 464.97050827844015, 474.36368603543895, 483.81494719113493, 493.3238587027097, 502.8899965046706, 512.5129452067044, 522.1922978055051, 531.9276554097556, 541.7186269775071, 551.564829065245, 561.4658855879858, 571.4214275897891, 581.4310930241153, 591.4945265434893, 601.6113792979751, 611.7813087419913, 622.0039784490308, 632.2790579338761, 642.6062224819227, 652.9851529852551, 663.4155357851317, 673.8970625205645, 684.4294299826943, 695.0123399746772, 705.6454991768222, 716.3286190167264, 727.0614155441754, 737.8436093105862, 748.6749252527829, 759.5550925809091], [0.0, 0.9567952590035856, 2.614041682541293, 4.705923186521943, 7.141772342370801, 9.870190184209523, 12.856961035965798, 16.077228071492026, 19.5118970485073, 23.14571777927449, 26.966154266904585, 30.96267029079175, 35.126252709303955, 39.4490796491206, 43.924281525359895, 48.54576400349702, 53.3080737078165, 58.206294279889285, 63.23596451592981, 68.3930129076962, 73.67370459688196, 79.07459787732105, 84.59250814766973, 90.22447775355042, 95.96775053967473, 101.81975020854587, 107.77806178521863, 113.84041563877858, 120.00467362530998, 126.2688170042579, 132.63093584735074, 139.08921971168348, 145.64194938981578, 152.28748958247604, 159.02428236564376, 165.85084134488142, 172.76574640690524, 179.76763899236235, 186.855217825272, 194.02723504407734, 201.28249268714427, 208.61983949213024, 216.03816797417252, 223.5364117525082, 231.11354309908214, 238.76857068605398, 246.50053751198251, 254.30851898891433, 262.19162117471814, 270.14897913682347, 278.17975543510084, 286.28313871298565, 294.45834238714235, 302.70460342700625, 311.02118121644844, 319.40735649061503, 327.86243034169183, 336.3857232879703, 344.9765744011405, 353.63434048722206, 362.3583953169816, 371.1481289020666, 380.0029468134333, 388.92226953895215, 397.90553187734935, 406.95218236589386, 416.0616827394559, 425.2335074187672, 434.467143025895, 443.76208792509794, 453.11785178738876, 462.53395517725386, 472.0099291601072, 481.54531492916396, 491.13966345051637, 500.7925351252945, 510.50349946786616, 520.2721347991168, 530.0980279539139, 539.9807740019252, 549.9199759810227, 559.9152446425486, 569.9661982077808, 580.072462134971, 590.2336688963758, 600.4494577647371, 610.7194746087054, 621.0433716967306, 631.4208075089765, 641.8514465568447, 652.3349592097145, 662.8710215285356, 673.4593151059304, 684.0995269124794, 694.7913491488932, 705.534479103777, 716.3286190167264, 727.1734759464964, 738.0687616440084, 749.014192429968, 760.0094890768804, 771.0543766952658], [0.0, 0.9711309822466542, 2.6532080326607357, 4.776432328128031, 7.248777964317393, 10.01807586142811, 13.049597687772025, 16.318114185819795, 19.804245023063473, 23.492511517248694, 27.37018984386054, 31.42658591744047, 35.65255155189132, 40.04014767827504, 44.58240178428964, 49.27312822361472, 54.10679191226518, 59.07840282970597, 64.183432929656, 69.41774970021063, 74.77756232344761, 80.25937752590204, 85.8599629911489, 91.57631675009006, 97.40564135178991, 103.34532189792503, 109.39290722982952, 115.54609371056688, 121.80271116027728, 128.16071059148973, 134.61815345935784, 141.17320219499717, 147.82411183197476, 154.5692225692277, 161.40695314026232, 168.33579487990033, 175.35430639721167, 182.4611087774637, 189.65488124757618, 196.93435724920448, 204.2983208715804, 211.74560360292563, 219.2750813648624, 226.88567179897817, 234.57633177870395, 242.34605512307238, 250.19387049182976, 258.11883944386346, 266.1200546430514, 274.1966381974841, 282.3477401196144, 290.57253689627134, 298.8702301586922, 307.2400454437775, 315.6812310387005, 324.19305690181704, 332.7748136535334, 341.42581163142404, 350.14538000444884, 358.9328659416118, 367.7876338308476, 376.70906454431025, 385.6965547465883, 394.7495162426857, 403.8673753628826, 413.0495723818475, 422.29556096959027, 431.6048076720557, 440.9767914193373, 450.41100305965404, 459.9069449173887, 469.46413037361543, 479.0820834676719, 488.76033851844255, 498.4984397641164, 508.29594101928626, 518.1524053483267, 528.0674047540787, 538.0405198809304, 548.0713397314535, 558.1594613958113, 568.3044897932089, 578.50603742471, 588.7637241367836, 599.0771768949952, 609.4460295672877, 619.8699227163395, 630.3485034005166, 640.8814249829701, 651.4683469484547, 662.1089347274734, 672.8028595273771, 683.5497981700704, 694.3494329359944, 705.2014514140837, 716.1055463573998, 727.0614155441754, 738.0687616440084, 749.1272920889667, 760.2367189493708, 771.3967588140429, 782.6071326748171], [0.0, 0.9855326850454628, 2.692554644238706, 4.847265985055733, 7.356276075082165, 10.166642176178392, 13.243120941564765, 16.56010896823063, 20.097938516722916, 23.84090135863373, 27.776084977353598, 31.892636696005013, 36.181272662489285, 40.63393607286306, 45.24355101368508, 50.00384010658073, 54.90918618323646, 59.95452522198448, 65.13526202640848, 70.44720280017424, 75.88650050819204, 81.4496100723618, 87.1332512415707, 92.93437752804327, 98.85014999513533, 104.87791496603818, 111.0151849318311, 117.25962209304436, 123.60902408642993, 130.0613115383906, 136.6145171557986, 143.266776118944, 150.0163175838465, 156.86145713488335, 163.80059005565516, 170.83218530774252, 177.95478012463977, 185.16697514254966, 192.46743000155797, 199.85485936048104, 207.32802927680646, 214.8857539099304, 222.5268925115891, 230.2503466721839, 238.055057795761, 245.94000477986512, 253.9042018794363, 261.9466967364442, 270.0665685591304, 278.2629264366021, 286.5349077761449, 294.8816768520318, 303.30242345583054, 311.79636163928933, 320.36272854181146, 329.00078329536274, 337.70980600037404, 346.4890967668466, 355.3379748154331, 364.2557776337678, 373.2418601837698, 382.2955941560351, 391.4163672677936, 400.6035826012201, 409.85665797917324, 419.1750253756925, 428.5581303588094, 438.00543156343844, 447.51640019229734, 457.0905195429732, 466.72728455940626, 476.42620140619704, 486.1867870642698, 496.0085689465393, 505.89108453232666, 515.8338810193729, 525.8365149923738, 535.898552107047, 546.0195667888104, 556.1991419452155, 566.4368686913432, 576.7323460874195, 587.0851808879664, 597.4949873018426, 607.961386762578, 618.484007708441, 629.0624853717175, 639.6964615767108, 650.3855845460077, 661.1295087145818, 671.9278945513286, 682.7804083876614, 693.6867222528102, 704.6465137154909, 715.659465731636, 726.7252664978889, 737.8436093105862, 749.014192429968, 760.2367189493708, 771.5108966691682, 782.8364379752443, 794.2130597217907], [0.0, 1.0000000000000002, 2.7320805135087918, 4.918422350276621, 7.464263932294463, 10.315885338403977, 13.437525860396867, 16.80320624522637, 20.392970037108203, 24.190878415700592, 28.18382931264455, 32.36081073712315, 36.71240255296073, 41.23042968482432, 45.90771234705219, 50.73788101129701, 55.71523605095198, 60.83463910607773, 66.091427524196, 71.48134594533971, 77.00049086113405, 82.64526515282905, 88.41234041624023, 94.29862544209399, 100.30123961903443, 106.41749031509814, 112.64485350550295, 118.98095707260606, 125.42356632314824, 131.9705713589711, 138.61997600769232, 145.36988807462546, 152.2185107203484, 159.16413480253814, 166.20513204805485, 173.33994894330883, 180.5671012488345, 187.88516905860703, 195.29279233664326, 202.78866687334857, 210.37154061231612, 218.04021030516884, 225.79351845781142, 233.630350536332, 241.54963240491568, 249.55032797163895, 257.63143702100933, 265.7919932146752, 274.03106224393997, 282.3477401196144, 290.7411515863902, 299.2104486503448, 307.75480920943704, 316.3734357779379, 325.06555429669305, 333.8304130219547, 342.6672814862508, 351.57544952541383, 360.5542263664663, 369.602939771566, 378.7209352336723, 387.9075752199937, 397.1622384596383, 406.48431927221196, 415.8732269343929, 425.3283850817753, 434.8492311435009, 444.4352158074121, 454.0858025136461, 463.80046697475854, 473.5786967206229, 483.4199906664887, 493.32385870270963, 503.2898213047683, 513.3174091623252, 523.4061628261244, 533.5556323716621, 543.7653770786161, 554.0349651251014, 564.3639732958812, 574.7519867037322, 585.1985985232086, 595.7034097361106, 606.266028888002, 616.8860718551742, 627.5631616214844, 638.2969280645409, 649.087007750739, 659.9330437386818, 670.834685390555, 681.7915881910426, 692.8034135734066, 703.8698287523671, 714.9905065634485, 726.1651253084749, 737.3933686069124, 748.6749252527829, 760.0094890768804, 771.3967588140429, 782.8364379752443, 794.3282347242822, 805.8718617588555], [0.0, 1.0145325654180988, 2.7717846522988703, 4.9898996448358535, 7.572738836188485, 10.465801616929935, 13.632807584020476, 17.047399939218923, 20.6893322082418, 24.542433938798027, 28.59341265586308, 32.8310963361431, 37.2459279447172, 41.82961360143534, 46.57486917993097, 51.475232586269385, 56.52492136364724, 61.71872247857322, 67.05190551826689, 72.52015328146409, 78.11950553179918, 83.84631287515863, 89.69719853710643, 95.669026385168, 101.75887394531442, 107.96400945473216, 114.2818722080838, 120.71005561477168, 127.2462925057106, 133.88844232050917, 140.63447987727935, 147.4824854828916, 154.4306361852374, 161.47719800377106, 168.6205190023669, 175.8590230908973, 183.1912044600896, 190.61562256904173, 198.13089761695866, 205.73570644073448, 213.42877878837078, 221.20889392520468, 229.07487753578218, 237.0255988891545, 245.05996823955775, 253.17693443799473, 261.3754827332759, 269.6546327436742, 278.01343658259105, 286.450977123555, 294.96636639155264, 303.55874406913455, 312.22727610700764, 320.97115342992936, 329.7895907296802, 338.68182533774706, 347.6471161710917, 356.6847427450393, 365.7940042479089, 374.9742186725178, 384.2247220001591, 393.5448674330542, 402.9340246716514, 412.3915792334666, 421.9169318104527, 431.50949766215035, 441.1687060421036, 450.89399965524, 460.6848341441054, 470.5406776020139, 480.46101011133317, 490.44532330526596, 500.49311995161554, 510.6039135571429, 520.7772279912256, 531.012597127631, 541.3095645032981, 551.6676829931081, 562.0865144996959, 572.5656296574216, 583.1046075496863, 593.7030354388268, 604.360508507885, 615.0766296135877, 625.8510090499233, 636.6832643217373, 647.5730199278102, 658.5199071529145, 669.523563868379, 680.5836343407228, 691.6997690479382, 702.871624503044, 714.0988630845367, 725.3811528734012, 736.718167496362, 748.1095859750644, 759.5550925809091, 771.0543766952658, 782.6071326748171, 794.2130597217907, 805.8718617588555, 817.583247308471]]}, {\"colorscale\": [[0.0, \"rgb(0,0,0)\"], [0.2, \"rgb(30,0,100)\"], [0.4, \"rgb(120,0,100)\"], [0.6, \"rgb(160,90,0)\"], [0.8, \"rgb(230,200,0)\"], [1.0, \"rgb(255,250,220)\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 3.0000000000000004\", \"showscale\": false, \"type\": \"surface\", \"visible\": false, \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.000999999999999999, 0.002828427124746188, 0.005196152422706629, 0.007999999999999995, 0.011180339887498942, 0.014696938456699062, 0.018520259177452127, 0.02262741699796951, 0.026999999999999986, 0.03162277660168378, 0.03648287269390939, 0.04156921938165304, 0.04687216658103184, 0.05238320341483516, 0.05809475019311123, 0.06399999999999997, 0.07009279563550022, 0.07636753236814711, 0.08281907992727278, 0.08944271909999156, 0.0962340895940726, 0.10318914671611543, 0.11030412503619254, 0.11757550765359254, 0.12499999999999996, 0.1325745073534124, 0.14029611541307904, 0.14816207341961707, 0.1561697794069006, 0.16431676725154978, 0.17260069524773064, 0.18101933598375614, 0.18957056733575492, 0.1982523644247402, 0.20706279240848652, 0.21599999999999994, 0.2250622136210341, 0.2342477321128211, 0.2435549219375375, 0.2529822128134703, 0.2625280937347468, 0.2721911093331301, 0.28196985654498596, 0.29186298155127516, 0.30186917696247156, 0.31198717922376235, 0.32221576621884906, 0.33255375505322443, 0.34299999999999997, 0.35355339059327373, 0.36421284985568536, 0.37497733264825484, 0.3858458241318675, 0.3968173383308748, 0.4078909167902614, 0.4190656273186814, 0.4303405628104327, 0.44171484014010676, 0.4531875991242479, 0.46475800154489, 0.4764252302303059, 0.48818848818873223, 0.5000469977912076, 0.512, 0.5240467536394057, 0.5361865347059734, 0.5484186357154541, 0.5607423650840019, 0.5731570465413471, 0.5856620185738529, 0.5982566338955215, 0.610940258945177, 0.6237122734081798, 0.6365720697611543, 0.649519052838329, 0.6625526394181824, 0.6756722578291934, 0.6888773475735721, 0.7021673589679315, 0.7155417527999327, 0.7289999999999999, 0.7425415813272683, 0.7561659870689769, 0.7698727167525811, 0.7836612788698953, 0.7975311906126304, 0.811481977618727, 0.8255131737289236, 0.8396243207530378, 0.8538149682454624, 0.8680846732894205, 0.8824330002895405, 0.8968595207723449, 0.91136381319427, 0.9259454627568515, 0.9406040612287406, 0.9553392067742223, 0.9701505037879433, 0.9850375627355538, 1.0, 1.01503743773321], [0.0, 0.002828427124746188, 0.007999999999999995, 0.014696938456699065, 0.022627416997969513, 0.03162277660168378, 0.04156921938165305, 0.05238320341483517, 0.06399999999999999, 0.07636753236814711, 0.08944271909999156, 0.10318914671611544, 0.11757550765359254, 0.1325745073534124, 0.14816207341961707, 0.16431676725154978, 0.18101933598375614, 0.19825236442474023, 0.21599999999999997, 0.23424773211282107, 0.25298221281347033, 0.2721911093331301, 0.29186298155127516, 0.31198717922376235, 0.3325537550532245, 0.35355339059327373, 0.3749773326482549, 0.39681733833087485, 0.41906562731868147, 0.4417148401401067, 0.46475800154489, 0.4881884881887323, 0.512, 0.5361865347059734, 0.5607423650840019, 0.5856620185738529, 0.610940258945177, 0.6365720697611544, 0.6625526394181824, 0.6888773475735721, 0.7155417527999326, 0.7425415813272683, 0.7698727167525812, 0.7975311906126304, 0.8255131737289236, 0.8538149682454624, 0.8824330002895406, 0.91136381319427, 0.9406040612287406, 0.9701505037879433, 1.0, 1.0301495037129322, 1.0605960588272993, 1.0913367949446224, 1.1223689233046326, 1.1536897329871667, 1.1852965873569368, 1.2171869207315695, 1.2493582352552053, 1.2818080979616258, 1.3145341380123987, 1.3475340440968462, 1.3808055619818456, 1.4143464922005502, 1.4481546878700498, 1.4822280526288796, 1.5165645386860398, 1.5511621449738906, 1.586018915397922, 1.6211329371769612, 1.6565023392678928, 1.6921252908694442, 1.7280000000000002, 1.764124712144808, 1.8004977089682734, 1.8371173070873839, 1.8739818569025692, 1.9110897414825923, 1.9484393755003009, 1.9860292042162928, 2.023857702507763, 2.0619233739399725, 2.100224749877975, 2.1387603886363715, 2.1775288746650414, 2.216528817768901, 2.2557588523598886, 2.2952176367394888, 2.334903852410202, 2.374816203414488, 2.4149534156997734, 2.455314236508232, 2.4958974337900997, 2.53670179563937, 2.5777261297507934, 2.6189692628971426, 2.660430040425797, 2.7021073257737203, 2.744000000000001, 2.786106961335118, 2.8284271247461907, 2.870959421517484], [0.0, 0.005196152422706629, 0.014696938456699065, 0.027000000000000003, 0.041569219381653054, 0.05809475019311125, 0.07636753236814714, 0.09623408959407265, 0.11757550765359255, 0.14029611541307907, 0.16431676725154984, 0.18957056733575497, 0.21600000000000005, 0.24355492193753758, 0.2721911093331302, 0.3018691769624716, 0.3325537550532245, 0.36421284985568547, 0.39681733833087496, 0.4303405628104328, 0.46475800154489016, 0.5000469977912078, 0.5361865347059735, 0.5731570465413474, 0.6109402589451773, 0.6495190528383291, 0.6888773475735723, 0.7290000000000002, 0.7698727167525815, 0.8114819776187272, 0.8538149682454627, 0.8968595207723451, 0.9406040612287407, 0.9850375627355541, 1.0301495037129325, 1.075929830425758, 1.1223689233046328, 1.1694575665666544, 1.21718692073157, 1.2655484976878608, 1.314534138012399, 1.364135990288359, 1.4143464922005504, 1.4651583532164711, 1.5165645386860402, 1.5685582552140043, 1.6211329371769618, 1.6742822342723471, 1.7280000000000009, 1.7822802809883755, 1.8371173070873843, 1.8925054821585072, 1.948439375500301, 2.0049137138540414, 2.0619233739399734, 2.119463375479747, 2.1775288746650423, 2.2361151580363665, 2.295217636739489, 2.3548318411300637, 2.414953415699774, 2.47557811429977, 2.5367017956393703, 2.598320419039963, 2.6604300404257972, 2.7230268085349447, 2.786106961335119, 2.8496668226303243, 2.9137027988454847, 2.9782113759772004, 3.0431891166997835, 3.10863265761653, 3.174538706647, 3.240904040541776, 3.307725502516799, 3.3750000000000018, 3.442724502483464, 3.510896039474825, 3.579511698542137, 3.6485686234467365, 3.718064012359122, 3.787995116153136, 3.858359236774101, 3.9291537256768176, 4.000375982329663, 4.0720234527811865, 4.144093628285927, 4.21658404398632, 4.289492277647789, 4.36281594844431, 4.436552715791848, 4.510700278227319, 4.585256372330781, 4.660218771688731, 4.735585285896563, 4.81135375959823, 4.8875220715614205, 4.96408813378651, 5.041049890647784, 5.118405318065387, 5.196152422706635, 5.274289241215355], [0.0, 0.007999999999999995, 0.022627416997969513, 0.041569219381653054, 0.06399999999999999, 0.08944271909999157, 0.11757550765359255, 0.14816207341961707, 0.18101933598375616, 0.216, 0.25298221281347033, 0.2918629815512752, 0.3325537550532245, 0.3749773326482549, 0.41906562731868147, 0.46475800154489, 0.512, 0.560742365084002, 0.6109402589451771, 0.6625526394181824, 0.7155417527999328, 0.7698727167525812, 0.8255131737289237, 0.8824330002895406, 0.9406040612287407, 1.0000000000000002, 1.0605960588272996, 1.1223689233046328, 1.185296587356937, 1.2493582352552053, 1.314534138012399, 1.3808055619818458, 1.4481546878700498, 1.51656453868604, 1.5860189153979223, 1.6565023392678928, 1.7280000000000004, 1.8004977089682737, 1.8739818569025695, 1.9484393755003009, 2.023857702507763, 2.100224749877975, 2.177528874665042, 2.2557588523598886, 2.334903852410202, 2.4149534156997734, 2.4958974337901, 2.5777261297507934, 2.660430040425797, 2.744000000000001, 2.8284271247461907, 2.913702798845484, 2.99981866118604, 3.0867665930549415, 3.174538706647, 3.2631273343220926, 3.3525250185494526, 3.442724502483463, 3.5337187211208554, 3.625500792993985, 3.7180640123591213, 3.811401841842449, 3.9055079055098596, 4.000375982329663, 4.096000000000002, 4.192374029115247, 4.289492277647789, 4.387349085723636, 4.485938920672017, 4.58525637233078, 4.685296148590825, 4.786053071164174, 4.887522071561418, 4.98969818726544, 5.092576558089237, 5.196152422706635, 5.300421115345461, 5.40537806263355, 5.5110187805885795, 5.6173388717434545, 5.724334022399464, 5.832000000000002, 5.940332650618149, 6.049327896551818, 6.158981734020651, 6.269290230959166, 6.380249524901047, 6.4918558209498185, 6.604105389831392, 6.716994566024305, 6.830519745963702, 6.944677386315367, 7.059464002316327, 7.174876166178762, 7.290910505554162, 7.407563702054816, 7.524832489829929, 7.642713654193782, 7.76120403030355, 7.880300501884434, 8.000000000000004, 8.120299501865684], [0.0, 0.011180339887498942, 0.03162277660168378, 0.05809475019311125, 0.08944271909999157, 0.12499999999999997, 0.16431676725154984, 0.20706279240848655, 0.25298221281347033, 0.30186917696247156, 0.35355339059327373, 0.4078909167902615, 0.46475800154489005, 0.5240467536394058, 0.5856620185738529, 0.649519052838329, 0.7155417527999327, 0.7836612788698957, 0.8538149682454625, 0.9259454627568516, 1.0000000000000002, 1.0759298304257578, 1.153689732987167, 1.2332376088978154, 1.3145341380123992, 1.3975424859373686, 1.4822280526288798, 1.5685582552140043, 1.656502339267893, 1.7460312139248833, 1.8371173070873839, 1.929734437688254, 2.023857702507763, 2.119463375479747, 2.2165288177689013, 2.315032397181517, 2.4149534156997734, 2.5162720441160578, 2.618969262897143, 2.7230268085349443, 2.8284271247461903, 2.9351533179716536, 3.043189116699783, 3.1525188342022643, 3.2631273343220926, 3.3750000000000004, 3.488122704263715, 3.6024817834376357, 3.7180640123591218, 3.834856581412141, 3.9528470752104754, 4.0720234527811865, 4.192374029115247, 4.313887457966424, 4.436552715791847, 4.560359086738676, 4.685296148590825, 4.811353759598229, 4.938522046118659, 5.066791391008715, 5.196152422706634, 5.326596004954761, 5.4581132271142945, 5.590695395029139, 5.724334022399464, 5.859020822628985, 5.994747701113036, 6.131506747937251, 6.269290230959166, 6.408090589247318, 6.5479004268544, 6.688712506902957, 6.830519745963701, 6.973315208708125, 7.1170921028184, 7.26184377413891, 7.407563702054816, 7.554245495084207, 7.701882886671289, 7.85046973116896, 8.000000000000004, 8.150467777986735, 8.301867259839806, 8.454192746797299, 8.607438643406066, 8.761599454437532, 8.916669781930924, 9.072644322357187, 9.229517863897337, 9.387285283829403, 9.545941546018396, 9.705481698504205, 9.865900871182525, 10.027194273574244, 10.18935719267904, 10.352384990909103, 10.516273104099197, 10.681017039589449, 10.846612374377548, 11.013054753337064, 11.180339887498954, 11.348463552393344], [0.0, 0.014696938456699062, 0.04156921938165305, 0.07636753236814714, 0.11757550765359255, 0.16431676725154984, 0.21600000000000003, 0.2721911093331302, 0.3325537550532245, 0.3968173383308749, 0.46475800154489005, 0.5361865347059735, 0.6109402589451772, 0.6888773475735722, 0.7698727167525813, 0.8538149682454625, 0.9406040612287406, 1.0301495037129325, 1.1223689233046328, 1.2171869207315698, 1.3145341380123992, 1.4143464922005502, 1.51656453868604, 1.6211329371769616, 1.7280000000000009, 1.837117307087384, 1.9484393755003009, 2.0619233739399734, 2.1775288746650423, 2.2952176367394888, 2.4149534156997734, 2.5367017956393703, 2.6604300404257963, 2.7861069613351184, 2.913702798845484, 3.043189116699783, 3.174538706647, 3.307725502516799, 3.4427245024834634, 3.5795116985421367, 3.7180640123591213, 3.8583592367741, 4.000375982329663, 4.144093628285926, 4.289492277647789, 4.436552715791847, 4.58525637233078, 4.735585285896562, 4.88752207156142, 5.041049890647783, 5.196152422706634, 5.352813839467989, 5.5110187805885795, 5.670752331040393, 5.8320000000000025, 5.994747701113036, 6.158981734020652, 6.324688767046172, 6.491855820949819, 6.660470253668284, 6.830519745963702, 7.001992287913494, 7.174876166178762, 7.349159951994518, 7.524832489829928, 7.701882886671288, 7.8803005018844345, 8.0600749376169, 8.241196029703461, 8.423653839041588, 8.607438643406068, 8.79254092967443, 8.978951386437064, 9.166660896967887, 9.355660532533237, 9.545941546018398, 9.737495365852562, 9.930313590214567, 10.124387981502888, 10.319710461054617, 10.516273104099195, 10.714068134933626, 10.913087922306875, 11.113324975001863, 11.314771937604405, 11.517421586448945, 11.721266825731771, 11.926300683782888, 12.132516309488324, 12.339906968855162, 12.548466041712038, 12.758187018538338, 12.969063497415696, 13.18108918109578, 13.394257874178779, 13.608563480397194, 13.824000000000012, 14.040561527232459, 14.258242247907008, 14.47703643706129, 14.696938456699078, 14.917942753610511], [0.0, 0.018520259177452127, 0.05238320341483517, 0.09623408959407265, 0.14816207341961707, 0.20706279240848655, 0.2721911093331302, 0.343, 0.41906562731868147, 0.5000469977912076, 0.5856620185738529, 0.6756722578291936, 0.7698727167525813, 0.8680846732894207, 0.9701505037879434, 1.0759298304257578, 1.1852965873569368, 1.2981367416416505, 1.4143464922005502, 1.5338308250912163, 1.656502339267893, 1.782280280988375, 1.9110897414825925, 2.0428609840123735, 2.177528874665042, 2.3150323971815174, 2.4553142365082326, 2.5983204190399625, 2.7440000000000015, 2.8923047903013277, 3.043189116699783, 3.196609610196404, 3.3525250185494526, 3.5108960394748245, 3.671685171688882, 3.8348565814121405, 4.000375982329662, 4.1682105273126515, 4.338328710459826, 4.510700278227319, 4.685296148590824, 4.862088337329961, 5.041049890647783, 5.222154823442141, 5.40537806263355, 5.5906953950291385, 5.7780834192662915, 5.967519501434413, 6.158981734020653, 6.352448897866085, 6.5479004268544, 6.745316375085757, 6.944677386315368, 7.145964665459806, 7.349159951994517, 7.554245495084208, 7.761204030303549, 7.970018757819837, 8.180673321921619, 8.393151791788355, 8.607438643406066, 8.823518742542575, 9.041377328703856, 9.261000000000006, 9.4823726988555, 9.705481698504206, 9.930313590214567, 10.156855271194924, 10.385093933133206, 10.615017051328751, 10.846612374377546, 11.079867914375159, 11.314771937604403, 11.551312955677384, 11.789479717103726, 12.029261199259087, 12.270646600729734, 12.51362533401093, 12.75818701853834, 13.004321474033167, 13.252018714143148, 13.50126894036261, 13.752062536216169, 14.004390061691378, 14.258242247907006, 14.513609992004064, 14.770484352247905, 15.028856543330244, 15.288717931860745, 15.550060032038472, 15.812874501494036, 16.077153137293937, 16.342887872098995, 16.610070770469353, 16.87869402530896, 17.148749954442753, 17.420230997320342, 17.693129711840143, 17.967438771288478, 18.24315096138823, 18.520259177452147, 18.798756421635996], [0.0, 0.02262741699796951, 0.06399999999999999, 0.11757550765359255, 0.18101933598375616, 0.25298221281347033, 0.3325537550532245, 0.41906562731868147, 0.512, 0.6109402589451771, 0.7155417527999327, 0.8255131737289237, 0.9406040612287406, 1.0605960588272993, 1.1852965873569368, 1.3145341380123987, 1.4481546878700495, 1.5860189153979223, 1.7280000000000004, 1.8739818569025692, 2.023857702507763, 2.1775288746650414, 2.334903852410202, 2.4958974337900997, 2.660430040425797, 2.8284271247461907, 2.99981866118604, 3.1745387066469997, 3.352525018549453, 3.5337187211208545, 3.718064012359121, 3.9055079055098596, 4.096000000000001, 4.289492277647788, 4.485938920672017, 4.685296148590824, 4.887522071561418, 5.092576558089237, 5.300421115345461, 5.511018780588579, 5.7243340223994625, 5.940332650618148, 6.158981734020652, 6.380249524901046, 6.604105389831392, 6.830519745963701, 7.059464002316327, 7.290910505554162, 7.524832489829927, 7.761204030303549, 8.000000000000004, 8.24119602970346, 8.484768470618398, 8.730694359556981, 8.978951386437064, 9.229517863897337, 9.482372698855498, 9.73749536585256, 9.994865882041646, 10.25446478369301, 10.516273104099193, 10.780272352774771, 11.046444495854768, 11.314771937604405, 11.585237502960402, 11.85782442103104, 12.132516309488324, 12.409297159791128, 12.68815132318338, 12.969063497415693, 13.252018714143146, 13.537002326955559, 13.824000000000005, 14.112997697158468, 14.403981671746191, 14.696938456699076, 14.99185485522056, 15.288717931860743, 15.58751500400241, 15.888233633730348, 16.190861620062112, 16.495386991519787, 16.801797999023808, 17.110083109090976, 17.420230997320335, 17.732230542151214, 18.046070818879116, 18.361741093915914, 18.67923081928162, 18.99852962731591, 19.319627325598194, 19.64251389206586, 19.9671794703208, 20.293614365114966, 20.62180903800635, 20.951754103177148, 21.28344032340638, 21.61685860618977, 21.952000000000016, 22.288855690680947, 22.627416997969533, 22.96767537213988], [0.0, 0.026999999999999986, 0.07636753236814711, 0.14029611541307907, 0.216, 0.30186917696247156, 0.3968173383308749, 0.5000469977912076, 0.6109402589451771, 0.729, 0.8538149682454624, 0.985037562735554, 1.1223689233046328, 1.2655484976878604, 1.4143464922005502, 1.5685582552140038, 1.7280000000000002, 1.8925054821585068, 2.061923373939973, 2.236115158036366, 2.4149534156997734, 2.5983204190399616, 2.786106961335118, 2.9782113759772, 3.174538706647, 3.375000000000001, 3.5795116985421362, 3.787995116153136, 4.000375982329663, 4.216584043986318, 4.436552715791846, 4.66021877168873, 4.887522071561418, 5.118405318065386, 5.352813839467989, 5.5906953950291385, 5.832000000000002, 6.076679767767924, 6.324688767046172, 6.575982892313516, 6.830519745963701, 7.088258530838167, 7.349159951994517, 7.613186126714625, 7.880300501884434, 8.150467777986735, 8.423653839041588, 8.699825687908929, 8.978951386437064, 9.261000000000005, 9.545941546018396, 9.83374694610351, 10.124387981502887, 10.417837251560428, 10.714068134933626, 11.013054753337064, 11.314771937604403, 11.619195195881689, 11.926300683782888, 12.2360651763547, 12.548466041712036, 12.863481216218267, 13.181089181095778, 13.501268940362614, 13.824000000000009, 14.14926234826396, 14.477036437061289, 14.80730316431727, 15.140043857268058, 15.475240256616383, 15.812874501494036, 16.152929115179088, 16.495386991519787, 16.840231382020864, 17.187445883551177, 17.537014426634894, 17.888921264290932, 18.24315096138823, 18.599688384486456, 18.95851869213416, 19.319627325598194, 19.683000000000007, 20.048622695836254, 20.416481650862387, 20.7865633523197, 21.158854529487186, 21.533342146541035, 21.91001339570564, 22.28885569068095, 22.669856660332034, 23.053004142627497, 23.438286178814366, 23.825691007817607, 24.215207060853324, 24.6068229562453, 25.000527494435005, 25.39630965317601, 25.794158582904018, 26.194063602274483, 26.596014193859965, 27.000000000000014, 27.406010818796688], [0.0, 0.03162277660168378, 0.08944271909999156, 0.16431676725154984, 0.25298221281347033, 0.35355339059327373, 0.46475800154489005, 0.5856620185738529, 0.7155417527999327, 0.8538149682454624, 1.0, 1.153689732987167, 1.314534138012399, 1.4822280526288796, 1.6565023392678928, 1.8371173070873836, 2.023857702507763, 2.2165288177689013, 2.4149534156997734, 2.6189692628971426, 2.8284271247461907, 3.0431891166997826, 3.2631273343220926, 3.4881227042637146, 3.7180640123591218, 3.952847075210475, 4.192374029115247, 4.436552715791847, 4.685296148590825, 4.938522046118658, 5.196152422706633, 5.4581132271142945, 5.724334022399463, 5.9947477011130355, 6.269290230959166, 6.547900426854399, 6.830519745963701, 7.1170921028184, 7.407563702054816, 7.701882886671288, 8.000000000000002, 8.301867259839804, 8.607438643406066, 8.916669781930922, 9.229517863897337, 9.545941546018394, 9.865900871182525, 10.18935719267904, 10.516273104099195, 10.846612374377546, 11.180339887498953, 11.517421586448945, 11.85782442103104, 12.201516299214626, 12.548466041712036, 12.898643339514436, 13.252018714143146, 13.608563480397192, 13.968249711399071, 14.331050205759528, 14.696938456699074, 15.06588862297874, 15.437875501506035, 15.812874501494036, 16.190861620062112, 16.571813419176557, 16.95570700383798, 17.34252000143002, 17.732230542151214, 18.12481724045791, 18.520259177452143, 18.918535884153414, 19.31962732559819, 19.723513885715203, 20.130176352928466, 20.53959590644374, 20.951754103177148, 21.366632865287887, 21.78421446827956, 22.20448152963722, 22.627416997969533, 23.053004142627493, 23.481226543773236, 23.912068082873983, 24.34551293359827, 24.78154555309254, 25.22015067361812, 25.661313294529585, 26.105018674576748, 26.551252324513825, 27.000000000000014, 27.45124769477702, 27.904981634109724, 28.36118826847706, 28.819854267501093, 29.28096651410265, 29.744512098872985, 30.21047831465105, 30.678852651297134, 31.149622790653517, 31.62277660168381, 32.098302135782845], [0.0, 0.03648287269390939, 0.10318914671611544, 0.18957056733575497, 0.2918629815512752, 0.4078909167902615, 0.5361865347059735, 0.6756722578291936, 0.8255131737289237, 0.985037562735554, 1.153689732987167, 1.3310000000000006, 1.5165645386860402, 1.7100312862635005, 1.9110897414825927, 2.119463375479747, 2.334903852410202, 2.5571865399301648, 2.7861069613351184, 3.0214779496134017, 3.263127334322093, 3.5108960394748245, 3.7646365030371807, 4.024211351308479, 4.289492277647789, 4.560359086738677, 4.836698874232303, 5.118405318065387, 5.405378062633551, 5.697522180737872, 5.9947477011130355, 6.296969191603214, 6.604105389831393, 6.916078874622531, 7.232815772574335, 7.554245495084208, 7.880300501884434, 8.210916087745634, 8.54603018950905, 8.885583211022228, 9.229517863897337, 9.577779022299486, 9.930313590214567, 10.287070379850626, 10.648000000000007, 11.013054753337064, 11.382188541752425, 11.75535677893275, 12.132516309488325, 12.513625334010932, 12.898643339514438, 13.287531034770916, 13.680250290108008, 14.076764081279487, 14.47703643706129, 14.881032390261108, 15.288717931860745, 15.700059968038348, 16.115026279842066, 16.533585485308393, 16.95570700383798, 17.381361022658737, 17.810518465221623, 18.243150961388235, 18.679230819281628, 19.118730998682953, 19.561625085866474, 20.007887269774404, 20.45749231944132, 20.910415562585086, 21.36663286528789, 21.82612061269709, 22.28885569068095, 22.75481546837945, 23.223977781594623, 23.696320916969384, 24.171823596907224, 24.650464965188807, 25.132224573244624, 25.617082367045644, 26.10501867457675, 26.596014193859965, 27.09004998149692, 27.587107441701843, 28.087168315798603, 28.590214672156645, 29.09622889654261, 29.605193682865874, 30.117092024297456, 30.63190720474325, 31.149622790653524, 31.670222623151883, 32.19369081046784, 32.72001172065807, 33.249169974602395, 33.78115043926126, 34.31593822118233, 34.85351866024436, 35.39387732362763, 35.937000000000026, 36.48287269390943, 37.03148162037272], [0.0, 0.04156921938165304, 0.11757550765359254, 0.21600000000000005, 0.3325537550532245, 0.46475800154489005, 0.6109402589451772, 0.7698727167525813, 0.9406040612287406, 1.1223689233046328, 1.314534138012399, 1.5165645386860402, 1.7280000000000006, 1.9484393755003009, 2.177528874665042, 2.4149534156997734, 2.6604300404257963, 2.913702798845484, 3.174538706647, 3.442724502483463, 3.7180640123591218, 4.000375982329662, 4.289492277647789, 4.58525637233078, 4.88752207156142, 5.196152422706634, 5.5110187805885795, 5.832000000000003, 6.158981734020653, 6.4918558209498185, 6.830519745963702, 7.174876166178762, 7.524832489829927, 7.8803005018844345, 8.241196029703461, 8.607438643406066, 8.978951386437064, 9.355660532533237, 9.737495365852562, 10.124387981502888, 10.516273104099193, 10.913087922306874, 11.314771937604405, 11.721266825731771, 12.132516309488324, 12.548466041712036, 12.969063497415696, 13.394257874178779, 13.82400000000001, 14.258242247907008, 14.696938456699076, 15.14004385726806, 15.587515004002412, 16.039309710832335, 16.49538699151979, 16.95570700383798, 17.42023099732034, 17.888921264290936, 18.361741093915917, 18.838654729040513, 19.319627325598194, 19.804624914398165, 20.293614365114966, 20.786563352319707, 21.28344032340638, 21.78421446827956, 22.288855690680954, 22.797334581042602, 23.30962239076388, 23.825691007817607, 24.345512933598272, 24.869061260932245, 25.396309653176004, 25.927232324334216, 26.461804020134398, 27.000000000000018, 27.541796019867714, 28.087168315798607, 28.636093588337104, 29.188548987573895, 29.744512098872985, 30.303960929225095, 30.86687389419281, 31.43322980541455, 32.00300785863731, 32.5761876222495, 33.15274902628742, 33.732672351890564, 34.31593822118232, 34.90252758755449, 35.49242172633479, 36.08560222581856, 36.68205097864625, 37.281750173509856, 37.8846822871725, 38.49083007678585, 39.10017657249137, 39.71270507029209, 40.32839912518228, 40.9472425445231, 41.569219381653085, 42.194313929722846], [0.0, 0.04687216658103184, 0.1325745073534124, 0.24355492193753758, 0.3749773326482549, 0.5240467536394058, 0.6888773475735722, 0.8680846732894207, 1.0605960588272993, 1.2655484976878604, 1.4822280526288796, 1.7100312862635005, 1.9484393755003009, 2.1970000000000005, 2.4553142365082326, 2.723026808534944, 2.99981866118604, 3.285401193157391, 3.5795116985421362, 3.881909710438924, 4.192374029115247, 4.510700278227319, 4.836698874232302, 5.170193323271387, 5.5110187805885795, 5.859020822628985, 6.214054393067382, 6.575982892313516, 6.944677386315369, 7.320015915283248, 7.701882886671287, 8.09016853965355, 8.484768470618398, 8.885583211022228, 9.292517850399864, 9.705481698504206, 10.124387981502887, 10.549153567940895, 10.979698720821084, 11.415946872686476, 11.857824421031038, 12.305260541735805, 12.758187018538338, 13.216538086806247, 13.680250290108006, 14.14926234826396, 14.623515035722441, 15.102951069244721, 15.587515004002412, 16.077153137293937, 16.57181341917656, 17.07144536938804, 17.57600000000001, 18.085429743304427, 18.599688384486456, 19.11873099868295, 19.642513892065864, 20.170994546625618, 20.704131568360953, 21.241884638609648, 21.78421446827956, 22.33108275476137, 22.88245214132438, 23.43828617881437, 23.99854928948833, 24.5632067328352, 25.13222457324462, 25.705569649397013, 26.283209545259137, 26.865112562578272, 27.451247694777024, 28.04158460215829, 28.636093588337094, 29.234745577822313, 29.83751209467708, 30.444365242192212, 31.055277683511402, 31.670222623151883, 32.28917378936788, 32.912105417308105, 33.53899223292199, 34.16980943757224, 34.80453269331456, 35.44313810880749, 36.08560222581856, 36.73190200629422, 37.38201481996391, 38.03591843245017, 38.69359099385843, 39.35501102782214, 40.02015742097977, 40.68900941286236, 41.36154658617111, 42.03774885742578, 42.71759646796625, 43.40106997528981, 44.08815024470865, 44.77881844131222, 45.47305602222049, 46.17084472911453, 46.87216658103189, 47.57700386741481], [0.0, 0.05238320341483516, 0.14816207341961707, 0.2721911093331302, 0.41906562731868147, 0.5856620185738529, 0.7698727167525813, 0.9701505037879434, 1.1852965873569368, 1.4143464922005502, 1.6565023392678928, 1.9110897414825927, 2.177528874665042, 2.4553142365082326, 2.744000000000001, 3.0431891166997826, 3.3525250185494526, 3.671685171688882, 4.000375982329663, 4.338328710459826, 4.685296148590825, 5.041049890647782, 5.40537806263355, 5.7780834192662915, 6.158981734020653, 6.5479004268544, 6.944677386315368, 7.349159951994517, 7.76120403030355, 8.180673321921617, 8.607438643406066, 9.041377328703856, 9.482372698855498, 9.930313590214565, 10.385093933133207, 10.846612374377546, 11.314771937604403, 11.789479717103726, 12.270646600729734, 12.75818701853834, 13.252018714143146, 13.752062536216167, 14.258242247907006, 14.770484352247905, 15.288717931860743, 15.812874501494035, 16.342887872098995, 16.87869402530896, 17.420230997320342, 17.967438771288478, 18.520259177452143, 19.078635800287202, 19.642513892065864, 20.211840292264352, 20.786563352319703, 21.366632865287887, 21.952000000000016, 22.542617239353568, 23.13843832241063, 23.739418190006276, 24.345512933598272, 24.956679747113814, 25.57287688157124, 26.194063602274486, 26.82020014839563, 27.451247694777024, 28.087168315798607, 28.72792495116905, 29.373481373511062, 30.023802157621564, 30.678852651297134, 31.3385989476237, 32.003007858637304, 32.67204689027, 33.34568421850122, 34.02388866664129, 34.706629683678614, 35.39387732362762, 36.08560222581857, 36.78177559607477, 37.482369188726615, 38.18735528941487, 38.896706698639704, 39.61039671601387, 40.32839912518227, 41.05068817937163, 41.77723858753714, 42.508025501074535, 43.24302450106841, 43.98221158604923, 44.72556316023313, 45.47305602222048, 46.22466735413035, 46.98037471114937, 47.74015601147532, 48.50398952663588, 49.27185387216524, 50.04372799862141, 50.8195911829287, 51.59942302003002, 52.383203414835215, 53.17091257445188], [0.0, 0.05809475019311123, 0.16431676725154978, 0.3018691769624716, 0.46475800154489, 0.649519052838329, 0.8538149682454625, 1.0759298304257578, 1.3145341380123987, 1.5685582552140038, 1.8371173070873836, 2.119463375479747, 2.4149534156997734, 2.723026808534944, 3.0431891166997826, 3.375, 3.718064012359121, 4.0720234527811865, 4.436552715791847, 4.811353759598228, 5.196152422706633, 5.5906953950291385, 5.9947477011130355, 6.408090589247317, 6.830519745963702, 7.261843774138908, 7.701882886671287, 8.150467777986737, 8.607438643406066, 9.072644322357185, 9.545941546018394, 10.027194273574242, 10.516273104099193, 11.013054753337064, 11.517421586448945, 12.029261199259084, 12.548466041712034, 13.074933078222625, 13.608563480397192, 14.149262348263962, 14.696938456699073, 15.251504024193817, 15.812874501494035, 16.380968377968383, 16.95570700383798, 17.537014426634887, 18.12481724045791, 18.71904444676598, 19.319627325598194, 19.92649931623717, 20.539595906443736, 21.158854529487186, 21.784214468279558, 22.415616765995992, 23.053004142627497, 23.696320916969377, 24.34551293359827, 25.000527494435005, 25.661313294529585, 26.32782036173904, 27.00000000000001, 27.677804735925154, 28.361188268477058, 29.050105421495477, 29.74451209887298, 30.444365242192205, 31.149622790653517, 31.860243643136208, 32.57618762224949, 33.297415440241025, 34.023888666641284, 34.75556969753195, 35.49242172633478, 36.23440871602573, 36.98149537268607, 37.73364712030897, 38.49083007678584, 39.25301103100247, 40.02015742097977, 40.79223731299868, 41.56921938165308, 42.35107289077812, 43.13776767520548, 43.92927412329963, 44.72556316023312, 45.52660623196069, 46.332375289855385, 47.142842775971864, 47.9579816089043, 48.777765170208475, 49.602167291359386, 50.43116224121751, 51.26472471397855, 52.10282981758287, 52.94545306256245, 53.792570351304114, 54.64415796770964, 55.50019256723353, 56.36065116728163, 57.225511137953184, 58.09475019311129, 58.968346381766594], [0.0, 0.06399999999999997, 0.18101933598375614, 0.3325537550532245, 0.512, 0.7155417527999327, 0.9406040612287406, 1.1852965873569368, 1.4481546878700495, 1.7280000000000002, 2.023857702507763, 2.334903852410202, 2.6604300404257963, 2.99981866118604, 3.3525250185494526, 3.718064012359121, 4.096000000000001, 4.485938920672017, 4.887522071561419, 5.300421115345461, 5.724334022399463, 6.158981734020651, 6.604105389831392, 7.059464002316327, 7.524832489829928, 8.000000000000004, 8.484768470618398, 8.978951386437064, 9.482372698855498, 9.994865882041644, 10.516273104099193, 11.046444495854768, 11.5852375029604, 12.132516309488322, 12.688151323183382, 13.252018714143146, 13.824000000000005, 14.403981671746193, 14.99185485522056, 15.58751500400241, 16.19086162006211, 16.801797999023805, 17.42023099732034, 18.046070818879112, 18.67923081928162, 19.31962732559819, 19.967179470320804, 20.621809038006354, 21.283440323406378, 21.952000000000012, 22.627416997969533, 23.309622390763877, 23.998549289488327, 24.69413274443954, 25.396309653176004, 26.105018674576748, 26.820200148395628, 27.54179601986771, 28.26974976896685, 29.004006343951882, 29.744512098872978, 30.4912147347396, 31.244063244078884, 32.00300785863731, 32.76800000000002, 33.538992232921984, 34.31593822118232, 35.09879268578909, 35.88751136537614, 36.682050978646245, 37.48236918872661, 38.2884245693134, 39.10017657249136, 39.917585498123536, 40.740612464713905, 41.569219381653085, 42.403368922763704, 43.243024501068405, 44.08815024470864, 44.93871097394764, 45.79467217919572, 46.65600000000003, 47.5226612049452, 48.39462317241455, 49.271853872165224, 50.15432184767334, 51.041996199208384, 51.93484656759856, 52.83284311865115, 53.73595652819446, 54.64415796770963, 55.55741909052295, 56.47571201853063, 57.39900932943011, 58.32728404443331, 59.26050961643854, 60.19865991863944, 61.14170923355027, 62.089632242428415, 63.04240401507548, 64.00000000000004, 64.96239601492549], [0.0, 0.07009279563550022, 0.19825236442474023, 0.36421284985568547, 0.560742365084002, 0.7836612788698957, 1.0301495037129325, 1.2981367416416505, 1.5860189153979223, 1.8925054821585068, 2.2165288177689013, 2.5571865399301648, 2.913702798845484, 3.285401193157391, 3.671685171688882, 4.0720234527811865, 4.485938920672017, 4.913000000000003, 5.352813839467989, 5.805020844062494, 6.269290230959167, 6.745316375085756, 7.232815772574334, 7.731524493914514, 8.241196029703461, 8.761599454437533, 9.292517850399864, 9.833746946103512, 10.385093933133207, 10.946376432409044, 11.517421586448945, 12.09806525854445, 12.688151323183382, 13.287531034770915, 13.896062463878042, 14.513609992004065, 15.14004385726806, 15.775239744612453, 16.419078415063385, 17.071445369388044, 17.732230542151214, 18.40132802272707, 19.078635800287206, 19.764055530179036, 20.45749231944132, 21.15885452948719, 21.868053594227376, 22.585003852113925, 23.309622390763884, 24.041828902976597, 24.781545553092545, 25.528696852757705, 26.283209545259137, 27.045012497686177, 27.814036600249185, 28.590214672156645, 29.373481373511062, 30.163773122737833, 30.96102801910818, 31.765185769958936, 32.5761876222495, 33.393976298129004, 34.218495934216655, 35.04969202432458, 35.88751136537615, 36.73190200629423, 37.582813199652875, 38.44019535590321, 39.30400000000004, 40.17417973026957, 41.05068817937164, 41.933479977221104, 42.82251071574392, 43.71773691535283, 44.619115993036026, 45.526606231960706, 46.44016675249997, 47.35975748459871, 48.28533914139989, 49.216873194058195, 50.15432184767335, 51.0976480182797, 52.04681531083344, 53.00178799814215, 53.96253100068606, 54.929009867282375, 55.90119075654834, 56.87904041912105, 57.86252618059469, 58.851615925138425, 59.84627807976037, 60.84648159918539, 61.85219595131613, 62.863391103248695, 63.88003750781622, 64.90210609063473, 65.92956823762772, 66.96239578300651, 68.00056099768597, 69.04403657811446, 70.0927956355003, 71.14681168541576], [0.0, 0.07636753236814711, 0.21599999999999997, 0.39681733833087496, 0.6109402589451771, 0.8538149682454625, 1.1223689233046328, 1.4143464922005502, 1.7280000000000004, 2.061923373939973, 2.4149534156997734, 2.7861069613351184, 3.174538706647, 3.5795116985421362, 4.000375982329663, 4.436552715791847, 4.887522071561419, 5.352813839467989, 5.8320000000000025, 6.324688767046172, 6.830519745963702, 7.349159951994516, 7.880300501884434, 8.423653839041588, 8.978951386437066, 9.545941546018396, 10.124387981502887, 10.714068134933626, 11.314771937604407, 11.926300683782888, 12.548466041712036, 13.181089181095778, 13.824000000000007, 14.477036437061289, 15.14004385726806, 15.812874501494036, 16.49538699151979, 17.187445883551177, 17.888921264290936, 18.599688384486456, 19.31962732559819, 20.048622695836254, 20.786563352319703, 21.533342146541035, 22.28885569068095, 23.053004142627497, 23.82569100781761, 24.606822956245303, 25.396309653176008, 26.194063602274486, 27.000000000000014, 27.81403660024918, 28.636093588337097, 29.46609346350482, 30.303960929225095, 31.14962279065352, 32.00300785863731, 32.8640468597524, 33.732672351890564, 34.60881864496391, 35.49242172633478, 36.383419190614866, 37.28175017350985, 38.187355289414874, 39.100176572491364, 40.020157420979764, 40.9472425445231, 41.881377914295065, 42.82251071574392, 43.770589303777975, 44.72556316023313, 45.68738285347502, 46.65600000000003, 47.63136722790984, 48.61343814214341, 49.60216729135939, 50.597510136369394, 51.59942302003002, 52.60786313850815, 53.622788513839936, 54.64415796770964, 55.67193109637929, 56.70606824670536, 57.74653049318206, 58.79327961595615, 59.84627807976035, 60.90548901371702, 61.97087619196623, 63.04240401507549, 64.12003749219122, 65.20374222389391, 66.2934843857223, 67.38923071233272, 68.49094848226302, 69.59860550327146, 70.71217009822288, 71.83161109149655, 72.95689779589048, 74.08800000000006, 75.22488795604822, 76.3675323681472, 77.51590438097212], [0.0, 0.08281907992727278, 0.23424773211282107, 0.4303405628104328, 0.6625526394181824, 0.9259454627568516, 1.2171869207315698, 1.5338308250912163, 1.8739818569025692, 2.236115158036366, 2.6189692628971426, 3.0214779496134017, 3.442724502483463, 3.881909710438924, 4.338328710459826, 4.811353759598228, 5.300421115345461, 5.805020844062494, 6.324688767046172, 6.859000000000003, 7.407563702054816, 7.970018757819836, 8.546030189509048, 9.135286147680329, 9.737495365852562, 10.352384990909103, 10.979698720821082, 11.619195195881689, 12.270646600729734, 12.93383744292467, 13.608563480397192, 14.294630775224668, 14.991854855220557, 15.700059968038346, 16.419078415063385, 17.148749954442753, 17.888921264290932, 18.63944545848938, 19.40018164863413, 20.170994546625618, 20.951754103177144, 21.742335178172574, 22.542617239353568, 23.352484086280853, 24.17182359690722, 25.000527494435005, 25.838491132417175, 26.685613296306325, 27.541796019867714, 28.40694441505459, 29.280966514102655, 30.163773122737833, 31.0552776835114, 31.955396148381602, 32.86404685975239, 33.78115043926126, 34.706629683678614, 35.64040946734481, 36.58241665062605, 37.532579993919974, 38.49083007678584, 39.457099221813074, 40.43132142287712, 41.41343227746286, 42.403368922763704, 43.40106997528981, 44.40647547374147, 45.419526824924134, 46.44016675249996, 47.46833924838748, 48.50398952663588, 49.54706397961441, 50.59751013636939, 51.6552766230131, 52.720313125018556, 53.79257035130413, 54.872000000000035, 55.95855472579688, 57.05218810878339, 58.15285462468721, 59.26050961643854, 60.3751092669819, 61.49661057326661, 62.62497132135076, 63.76015006255871, 64.90210609063473, 66.05079941984053, 67.2061907639468, 68.3682415160724, 69.53691372932802, 70.71217009822288, 71.89397394079705, 73.08228918144265, 74.27708033438046, 75.4783124877604, 76.68595128835534, 77.89996292682052, 79.12031412349177, 80.3469721146977, 81.57990463956187, 82.81907992727285, 84.06446668480098], [0.0, 0.08944271909999156, 0.25298221281347033, 0.46475800154489016, 0.7155417527999328, 1.0000000000000002, 1.3145341380123992, 1.656502339267893, 2.023857702507763, 2.4149534156997734, 2.8284271247461907, 3.263127334322093, 3.7180640123591218, 4.192374029115247, 4.685296148590825, 5.196152422706633, 5.724334022399463, 6.269290230959167, 6.830519745963702, 7.407563702054816, 8.000000000000004, 8.607438643406066, 9.229517863897339, 9.865900871182525, 10.516273104099197, 11.180339887498953, 11.857824421031042, 12.548466041712038, 13.252018714143148, 13.968249711399071, 14.696938456699074, 15.437875501506037, 16.190861620062112, 16.95570700383798, 17.732230542151218, 18.520259177452143, 19.319627325598194, 20.13017635292847, 20.95175410317715, 21.78421446827956, 22.62741699796953, 23.481226543773236, 24.345512933598272, 25.22015067361812, 26.10501867457675, 27.000000000000014, 27.904981634109728, 28.819854267501096, 29.744512098872985, 30.678852651297134, 31.62277660168381, 32.5761876222495, 33.53899223292199, 34.51109966373141, 35.49242172633479, 36.48287269390942, 37.48236918872661, 38.49083007678585, 39.508176368949286, 40.534331128069724, 41.56921938165308, 42.612768039638105, 43.66490581691437, 44.72556316023313, 45.79467217919573, 46.87216658103189, 47.957981608904305, 49.05205398349802, 50.154321847673344, 51.26472471397856, 52.383203414835215, 53.509700055223675, 54.64415796770963, 55.78652166966502, 56.93673682254722, 58.094750193111295, 59.26050961643855, 60.43396396067368, 61.61506309337033, 62.803757849351705, 64.00000000000004, 65.20374222389391, 66.41493807871846, 67.63354197437842, 68.85950914724854, 70.09279563550028, 71.33335825544741, 72.58115457885751, 73.83614291117873, 75.09828227063525, 76.3675323681472, 77.64385358803366, 78.92720696946023, 80.21755418859397, 81.51485754143235, 82.81907992727285, 84.1301848327936, 85.4481363167156, 86.7728989950204, 88.10443802669654, 89.44271909999165, 90.78770841914678], [0.0, 0.0962340895940726, 0.2721911093331301, 0.5000469977912078, 0.7698727167525812, 1.0759298304257578, 1.4143464922005502, 1.782280280988375, 2.1775288746650414, 2.5983204190399616, 3.0431891166997826, 3.5108960394748245, 4.000375982329662, 4.510700278227319, 5.041049890647782, 5.5906953950291385, 6.158981734020651, 6.745316375085756, 7.349159951994516, 7.970018757819836, 8.607438643406066, 9.261000000000003, 9.930313590214565, 10.615017051328751, 11.314771937604405, 12.029261199259084, 12.758187018538338, 13.501268940362612, 14.258242247907006, 15.028856543330242, 15.812874501494035, 16.61007077046935, 17.42023099732034, 18.24315096138823, 19.078635800287202, 19.92649931623717, 20.7865633523197, 21.658657229846927, 22.542617239353568, 23.43828617881437, 24.34551293359827, 25.264152093430738, 26.194063602274483, 27.13511243757801, 28.087168315798603, 29.050105421495473, 30.023802157621564, 31.008140914927505, 32.00300785863731, 33.00829273076694, 34.023888666641284, 35.04969202432457, 36.08560222581856, 37.131521609004956, 38.18735528941487, 39.25301103100247, 40.32839912518227, 41.41343227746285, 42.508025501074535, 43.61209601704557, 44.72556316023312, 45.848348290859974, 46.980374711149366, 48.121567586686155, 49.27185387216523, 50.431162241217514, 51.59942302003002, 52.77656812450014, 53.96253100068606, 55.1572465683341, 56.36065116728163, 57.57268250654997, 58.793279615956145, 60.022382800085545, 61.25993359447923, 62.505874723900995, 63.760150062558715, 65.02270459616399, 66.29348438572231, 67.57243653295333, 68.85950914724854, 70.15465131407899, 71.45781306477276, 72.76894534758634, 74.08800000000005, 75.41492972217111, 76.74968805148336, 78.09222933813588, 79.44250872171655, 80.80048210871028, 82.16610615089418, 83.53933822457543, 84.92013641063002, 86.30845947530294, 87.70426685173311, 89.10751862216796, 90.51817550083527, 91.93619881744087, 93.36155050126371, 94.7941930658203, 96.23408959407271, 97.68120372415574], [0.0, 0.10318914671611543, 0.29186298155127516, 0.5361865347059735, 0.8255131737289237, 1.153689732987167, 1.51656453868604, 1.9110897414825925, 2.334903852410202, 2.786106961335118, 3.2631273343220926, 3.7646365030371807, 4.289492277647789, 4.836698874232302, 5.40537806263355, 5.9947477011130355, 6.604105389831392, 7.232815772574334, 7.880300501884434, 8.546030189509048, 9.229517863897339, 9.930313590214565, 10.648000000000005, 11.382188541752424, 12.132516309488325, 12.898643339514438, 13.680250290108008, 14.47703643706129, 15.288717931860747, 16.115026279842063, 16.95570700383798, 17.810518465221623, 18.679230819281624, 19.56162508586647, 20.45749231944132, 21.366632865287887, 22.28885569068095, 23.223977781594623, 24.171823596907224, 25.132224573244624, 26.105018674576748, 27.090049981496914, 28.087168315798607, 29.096228896542605, 30.117092024297452, 31.149622790653517, 32.19369081046784, 33.249169974602395, 34.31593822118232, 35.39387732362763, 36.48287269390942, 37.582813199652875, 38.69359099385843, 39.815101356143785, 40.9472425445231, 42.08991565684116, 43.24302450106841, 44.406475473741466, 45.58017744590299, 46.76404165595616, 47.9579816089043, 49.161912981494154, 50.375753532825726, 51.599423020030024, 52.832843118651155, 54.07593734740068, 55.32863099698026, 56.590851062693915, 57.862526180594685, 59.14358656693053, 60.43396396067368, 61.73359156893438, 63.04240401507548, 64.36033728935863, 65.68732870196509, 67.02331683824673, 68.36824151607242, 69.72204374514568, 71.08466568817785, 72.45605062380925, 73.83614291117873, 75.2248879560482, 76.62223217839592, 78.02812298139698, 79.44250872171655, 80.86533868104436, 82.29656303880503, 83.7361328459824, 85.18400000000007, 86.64011722060407, 88.10443802669654, 89.57691671407322, 91.05750833401942, 92.54616867272256, 94.04285423146203, 95.54752220753824, 97.06013047590663, 98.58063757148265, 100.10900267208748, 101.64518558200392, 103.18914671611553, 104.74084708460221], [0.0, 0.11030412503619254, 0.31198717922376235, 0.5731570465413474, 0.8824330002895406, 1.2332376088978154, 1.6211329371769616, 2.0428609840123735, 2.4958974337900997, 2.9782113759772, 3.4881227042637146, 4.024211351308479, 4.58525637233078, 5.170193323271387, 5.7780834192662915, 6.408090589247317, 7.059464002316327, 7.731524493914514, 8.423653839041588, 9.135286147680329, 9.865900871182525, 10.615017051328751, 11.382188541752424, 12.167000000000009, 12.969063497415696, 13.788015629524077, 14.623515035722441, 15.475240256616384, 16.342887872098995, 17.226170874573388, 18.12481724045791, 19.038568669939462, 19.967179470320804, 20.910415562585086, 21.868053594227376, 22.839880144168898, 23.825691007817607, 24.825290552176845, 25.838491132417175, 26.86511256257828, 27.904981634109724, 28.957931676830814, 30.023802157621567, 31.102438312775437, 32.19369081046784, 33.297415440241025, 34.41347282678693, 35.54172816563654, 36.68205097864625, 37.834314887414074, 38.99839740297032, 40.17417973026958, 41.36154658617111, 42.56038602973431, 43.770589303777975, 44.992050686760244, 46.22466735413035, 47.46833924838748, 48.72296895715618, 49.98846159865299, 51.26472471397856, 52.551668165720535, 53.84920404239978, 55.157246568334116, 56.47571201853064, 57.80451863825185, 59.14358656693054, 60.492837766135644, 61.852195951316126, 63.22158652707165, 64.60093652571925, 65.99017454894333, 67.38923071233272, 68.79803659262384, 70.21652517748232, 71.64463081766846, 73.08228918144265, 74.52943721107795, 75.98601308135603, 77.45195615993188, 78.92720696946023, 80.41170715138443, 81.90539943129522, 83.40822758577245, 84.92013641063004, 86.44107169048758, 87.97098016959919, 89.50980952387295, 91.05750833401942, 92.6140260597714, 94.17931301512034, 95.75332034451868, 97.3360000000001, 98.92730471917254, 100.52718800404207, 102.13560410062702, 103.75250797932561, 105.37785531600092, 107.01160247375059, 108.65370648532898, 110.30412503619266, 111.96281644814063], [0.0, 0.11757550765359254, 0.3325537550532245, 0.6109402589451773, 0.9406040612287407, 1.3145341380123992, 1.7280000000000009, 2.177528874665042, 2.660430040425797, 3.174538706647, 3.7180640123591218, 4.289492277647789, 4.88752207156142, 5.5110187805885795, 6.158981734020653, 6.830519745963702, 7.524832489829928, 8.241196029703461, 8.978951386437066, 9.737495365852562, 10.516273104099197, 11.314771937604405, 12.132516309488325, 12.969063497415696, 13.824000000000012, 14.696938456699078, 15.587515004002414, 16.495386991519794, 17.420230997320342, 18.361741093915917, 19.319627325598194, 20.29361436511497, 21.28344032340638, 22.288855690680954, 23.309622390763884, 24.345512933598272, 25.396309653176008, 26.4618040201344, 27.541796019867718, 28.636093588337104, 29.74451209887298, 30.86687389419281, 32.00300785863732, 33.152749026287424, 34.31593822118232, 35.49242172633479, 36.68205097864625, 37.88468228717251, 39.10017657249137, 40.32839912518228, 41.569219381653085, 42.822510715743924, 44.08815024470865, 45.366018648323156, 46.65600000000004, 47.957981608904305, 49.27185387216524, 50.5975101363694, 51.934846567598576, 53.283762029346285, 54.64415796770964, 56.015938303307976, 57.399009329430115, 58.793279615956166, 60.19865991863944, 61.615063093370324, 63.0424040150755, 64.48059950093523, 65.9295682376277, 67.38923071233273, 68.85950914724856, 70.34032743739547, 71.83161109149654, 73.33328717574312, 74.84528426026593, 76.36753236814721, 77.89996292682052, 79.44250872171656, 80.99510385202314, 82.55768368843698, 84.13018483279359, 85.71254507946904, 87.30470337845503, 88.90659980001493, 90.51817550083527, 92.13937269159159, 93.7701346058542, 95.41040547026314, 97.06013047590662, 98.71925575084133, 100.38772833369634, 102.06549614830674, 103.7525079793256, 105.44871344876627, 107.15406299343027, 108.8685078431776, 110.59200000000013, 112.32449221785971, 114.0659379832561, 115.81629149649036, 117.57550765359267, 119.34354202888413], [0.0, 0.12499999999999996, 0.35355339059327373, 0.6495190528383291, 1.0000000000000002, 1.3975424859373686, 1.837117307087384, 2.3150323971815174, 2.8284271247461907, 3.375000000000001, 3.952847075210475, 4.560359086738677, 5.196152422706634, 5.859020822628985, 6.5479004268544, 7.261843774138908, 8.000000000000004, 8.761599454437533, 9.545941546018396, 10.352384990909103, 11.180339887498953, 12.029261199259084, 12.898643339514438, 13.788015629524077, 14.696938456699078, 15.625000000000007, 16.57181341917656, 17.53701442663489, 18.520259177452147, 19.52122242586259, 20.539595906443736, 21.575086905966344, 22.627416997969533, 23.69632091696938, 24.781545553092542, 25.882849051060834, 27.000000000000014, 28.132776702629283, 29.280966514102655, 30.44436524219221, 31.622776601683807, 32.81601171684337, 34.02388866664129, 35.24623206812327, 36.48287269390942, 37.733647120308966, 38.99839740297032, 40.27697077735616, 41.569219381653085, 42.87500000000003, 44.19417382415924, 45.5266062319607, 46.87216658103189, 48.230728016483475, 49.602167291359386, 50.986364598782714, 52.383203414835215, 53.79257035130412, 55.21435501751338, 56.648449890531026, 58.09475019311129, 59.553153778788285, 61.023561023591576, 62.505874723901, 64.00000000000006, 65.50584420492575, 67.02331683824673, 68.55232946443182, 70.09279563550028, 71.64463081766844, 73.20775232173166, 74.78207923694023, 76.36753236814718, 77.96403417602254, 79.57150872014435, 81.18988160479118, 82.81907992727285, 84.45903222864924, 86.10966844669657, 87.7709198709915, 89.44271909999165, 91.12500000000006, 92.81769766590861, 94.52074838362218, 96.2340895940727, 97.95765985873699, 99.69139882657888, 101.43524720234095, 103.18914671611553, 104.9530400941298, 106.72687103068289, 108.51058416117763, 110.30412503619264, 112.10744009654319, 113.92047664928381, 115.74318284460652, 117.57550765359267, 119.41740084677788, 121.268812973493, 123.12969534194431, 125.00000000000009, 126.87967971665137], [0.0, 0.1325745073534124, 0.3749773326482549, 0.6888773475735723, 1.0605960588272996, 1.4822280526288798, 1.9484393755003009, 2.4553142365082326, 2.99981866118604, 3.5795116985421362, 4.192374029115247, 4.836698874232303, 5.5110187805885795, 6.214054393067382, 6.944677386315368, 7.701882886671287, 8.484768470618398, 9.292517850399864, 10.124387981502887, 10.979698720821082, 11.857824421031042, 12.758187018538338, 13.680250290108008, 14.623515035722441, 15.587515004002414, 16.57181341917656, 17.57600000000001, 18.59968838448646, 19.642513892065868, 20.704131568360953, 21.784214468279558, 22.88245214132438, 23.998549289488327, 25.13222457324462, 26.283209545259137, 27.451247694777024, 28.636093588337097, 29.837512094677084, 31.055277683511402, 32.28917378936788, 33.538992232921984, 34.804532693314556, 36.08560222581857, 37.38201481996391, 38.69359099385843, 40.020157420979764, 41.36154658617111, 42.71759646796625, 44.08815024470865, 45.47305602222049, 46.87216658103189, 48.28533914139989, 49.71243514453907, 51.15332004865378, 52.607863138508144, 54.07593734740068, 55.557419090522956, 57.05218810878339, 58.56012732226601, 60.08112269257296, 61.615063093370324, 63.161840188518944, 64.72134831722842, 66.29348438572231, 67.87814776494722, 69.47524019389934, 71.08466568817785, 72.70633045340693, 74.34014280319893, 75.98601308135603, 77.64385358803368, 79.31357850960963, 80.9951038520231, 82.68834737736637, 84.39322854352719, 86.10966844669657, 87.8375897665687, 89.57691671407323, 91.32757498149185, 93.08949169482028, 94.86259536824836, 96.6468158606377, 98.44208433388648, 100.2483332130765, 102.06549614830674, 103.8935079781216, 105.73230469445002, 107.58182340897565, 109.44200232086409, 111.3127806857776, 113.19409878611174, 115.08589790239297, 116.98812028577956, 118.90070913161125, 120.82360855395781, 122.75676356111717, 124.70012003201936, 126.65362469349242, 128.61722509835155, 130.5908696042722, 132.5745073534125, 134.56808825275047], [0.0, 0.14029611541307904, 0.39681733833087485, 0.7290000000000002, 1.1223689233046328, 1.5685582552140043, 2.0619233739399734, 2.5983204190399625, 3.1745387066469997, 3.787995116153136, 4.436552715791847, 5.118405318065387, 5.832000000000003, 6.575982892313516, 7.349159951994517, 8.150467777986737, 8.978951386437064, 9.833746946103512, 10.714068134933626, 11.619195195881689, 12.548466041712038, 13.501268940362612, 14.47703643706129, 15.475240256616384, 16.495386991519794, 17.53701442663489, 18.59968838448646, 19.683000000000014, 20.786563352319707, 21.91001339570564, 23.053004142627497, 24.215207060853324, 25.396309653176008, 26.59601419385997, 27.814036600249185, 29.050105421495477, 30.303960929225095, 31.575354297299683, 32.8640468597524, 34.169809437572255, 35.49242172633478, 36.831671737785705, 38.187355289414874, 39.55927553684473, 40.9472425445231, 42.35107289077813, 43.77058930377798, 45.20562032535339, 46.65600000000004, 48.121567586686155, 49.60216729135939, 51.09764801827971, 52.607863138508144, 54.13267027405914, 55.6719310963793, 57.22551113795319, 58.79327961595615, 60.375109266981916, 61.970876191966234, 63.58045971051174, 65.20374222389391, 66.84060908609382, 68.49094848226302, 70.15465131407902, 71.83161109149654, 73.52172383044353, 75.22488795604822, 76.94100421101878, 78.66997556882811, 80.41170715138443, 82.16610615089418, 83.93308175564634, 85.71254507946902, 87.50440909462799, 89.3085885679536, 91.12500000000007, 92.95356156705355, 94.79419306582031, 96.64681586063773, 98.51135283306192, 100.38772833369633, 102.2758681361347, 104.17569939290075, 106.08715059327412, 108.01015152290093, 109.94463322509208, 111.89052796372006, 113.84776918763066, 115.81629149649035, 117.7960306079964, 119.78692332637993, 121.78890751213767, 123.8019220529311, 125.82590683559577, 127.86080271920723, 129.90655150915225, 131.96309593215838, 134.0303796122358, 136.1083470474902, 138.19694358776547, 140.29611541307918, 142.4058095128146], [0.0, 0.14816207341961707, 0.41906562731868147, 0.7698727167525815, 1.185296587356937, 1.656502339267893, 2.1775288746650423, 2.7440000000000015, 3.352525018549453, 4.000375982329663, 4.685296148590825, 5.405378062633551, 6.158981734020653, 6.944677386315369, 7.76120403030355, 8.607438643406066, 9.482372698855498, 10.385093933133207, 11.314771937604407, 12.270646600729734, 13.252018714143148, 14.258242247907006, 15.288717931860747, 16.342887872098995, 17.420230997320342, 18.520259177452147, 19.642513892065868, 20.786563352319707, 21.95200000000002, 23.13843832241063, 24.345512933598272, 25.572876881571244, 26.82020014839563, 28.087168315798607, 29.373481373511066, 30.678852651297138, 32.00300785863731, 33.345684218501226, 34.70662968367862, 36.08560222581857, 37.48236918872661, 38.896706698639704, 40.32839912518228, 41.77723858753714, 43.24302450106841, 44.72556316023313, 46.224667354130354, 47.74015601147533, 49.27185387216524, 50.819591182928704, 52.38320341483522, 53.96253100068607, 55.55741909052296, 57.16771732367847, 58.79327961595616, 60.43396396067369, 62.08963224242842, 63.76015006255872, 65.44538657537298, 67.14521433430687, 68.85950914724856, 70.58814994034061, 72.33101862963088, 74.08800000000008, 75.85898159084402, 77.64385358803368, 79.44250872171656, 81.25484216955942, 83.08075146506569, 84.92013641063004, 86.77289899502041, 88.63894331500131, 90.51817550083527, 92.4105036454191, 94.31583773682985, 96.23408959407273, 98.16517280583791, 100.10900267208748, 102.06549614830676, 104.03457179226538, 106.01614971314523, 108.01015152290093, 110.0165002897294, 112.03512049353107, 114.06593798325609, 116.10887993603257, 118.16387481798328, 120.230852346642, 122.309743454886, 124.40048025630782, 126.50299601195235, 128.61722509835153, 130.743102976792, 132.88056616375488, 135.02955220247173, 137.18999963554208, 139.3618479785628, 141.5450376947212, 143.73951017030788, 145.9452076911059, 148.16207341961723, 150.39005137308803], [0.0, 0.1561697794069006, 0.4417148401401067, 0.8114819776187272, 1.2493582352552053, 1.7460312139248833, 2.2952176367394888, 2.8923047903013277, 3.5337187211208545, 4.216584043986318, 4.938522046118658, 5.697522180737872, 6.4918558209498185, 7.320015915283248, 8.180673321921617, 9.072644322357185, 9.994865882041644, 10.946376432409044, 11.926300683782888, 12.93383744292467, 13.968249711399071, 15.028856543330242, 16.115026279842063, 17.226170874573388, 18.361741093915917, 19.52122242586259, 20.704131568360953, 21.91001339570564, 23.13843832241063, 24.389000000000017, 25.661313294529585, 26.955012502315796, 28.269749768966847, 29.60519368286587, 30.961028019108177, 32.336950613810224, 33.73267235189056, 35.14791625402567, 36.58241665062605, 38.03591843245017, 39.50817636894927, 40.99895448666957, 42.508025501074535, 44.03517029602591, 45.58017744590298, 47.142842775971864, 48.722968957156176, 50.32036513182316, 51.93484656759857, 53.56623433656696, 55.21435501751338, 56.87904041912105, 58.560127322266005, 60.25745723974757, 61.97087619196622, 63.700234497213636, 65.44538657537296, 67.2061907639468, 68.9825091454349, 70.77420738517677, 72.58115457885751, 74.40322310894878, 76.24028850942268, 78.09222933813588, 79.9589270563332, 81.84026591476845, 83.7361328459824, 85.64641736231594, 87.57101145927237, 89.50980952387293, 91.46270824767882, 93.42960654417857, 95.41040547026311, 97.40500815153202, 99.41331971119371, 101.43524720234095, 103.4706995433974, 105.5195874565477, 107.58182340897565, 109.65732155674796, 111.7459976911926, 113.84776918763063, 115.96255495633075, 118.09027539556348, 120.23085234664197, 122.38420905084129, 124.55027010809742, 126.72896143739217, 128.92021023873653, 131.12394495667078, 133.34009524520383, 135.56859193412032, 137.80936699658713, 140.06235351799583, 142.32748566598104, 144.60469866155813, 146.8939287513274, 149.19511318069385, 151.50819016805676, 153.8330988799226, 156.16977940690074, 158.5181727405412], [0.0, 0.16431676725154978, 0.46475800154489, 0.8538149682454627, 1.314534138012399, 1.8371173070873839, 2.4149534156997734, 3.043189116699783, 3.718064012359121, 4.436552715791846, 5.196152422706633, 5.9947477011130355, 6.830519745963702, 7.701882886671287, 8.607438643406066, 9.545941546018394, 10.516273104099193, 11.517421586448945, 12.548466041712036, 13.608563480397192, 14.696938456699074, 15.812874501494035, 16.95570700383798, 18.12481724045791, 19.319627325598194, 20.539595906443736, 21.784214468279558, 23.053004142627497, 24.345512933598272, 25.661313294529585, 27.00000000000001, 28.36118826847706, 29.744512098872978, 31.149622790653517, 32.5761876222495, 34.023888666641284, 35.49242172633478, 36.98149537268608, 38.49083007678585, 40.02015742097977, 41.56921938165307, 43.137767675205474, 44.72556316023312, 46.332375289855385, 47.9579816089043, 49.60216729135938, 51.26472471397856, 52.94545306256245, 54.64415796770964, 56.36065116728163, 58.09475019311129, 59.84627807976036, 61.61506309337032, 63.40093847885855, 65.20374222389391, 67.02331683824671, 68.85950914724854, 70.71217009822288, 72.58115457885751, 74.46632124658777, 76.36753236814718, 78.28465366851928, 80.21755418859397, 82.16610615089418, 84.13018483279359, 86.10966844669656, 88.10443802669654, 90.11437732126885, 92.13937269159157, 94.17931301512033, 96.2340895940727, 98.30359606850614, 100.3877283336963, 102.48638446154696, 104.59946462578102, 106.72687103068287, 108.86850784317757, 111.02428112804881, 113.19409878611172, 115.37787049516912, 117.57550765359264, 119.78692332637989, 122.0120321935506, 124.2507505007516, 126.5029960119523, 128.76868796411657, 131.04774702374712, 133.34009524520383, 135.64565603070386, 137.96435409191764, 140.29611541307915, 142.64086721553548, 144.99853792366335, 147.36905713208603, 149.7523555741279, 152.1483650914463, 154.5570186047856, 156.97825008580025, 159.4119945298974, 161.85818793005203, 164.31676725154995, 166.78767040761753], [0.0, 0.17260069524773064, 0.4881884881887323, 0.8968595207723451, 1.3808055619818458, 1.929734437688254, 2.5367017956393703, 3.196609610196404, 3.9055079055098596, 4.66021877168873, 5.4581132271142945, 6.296969191603214, 7.174876166178762, 8.09016853965355, 9.041377328703856, 10.027194273574242, 11.046444495854768, 12.09806525854445, 13.181089181095778, 14.294630775224668, 15.437875501506037, 16.61007077046935, 17.810518465221623, 19.038568669939462, 20.29361436511497, 21.575086905966344, 22.88245214132438, 24.215207060853324, 25.572876881571244, 26.955012502315796, 28.36118826847706, 29.791000000000018, 31.244063244078884, 32.72001172065807, 34.218495934216655, 35.73918192964133, 37.28175017350985, 38.8458945449838, 40.43132142287712, 42.03774885742578, 43.66490581691436, 45.31253150067874, 46.980374711149366, 48.6681932785675, 50.375753532825726, 52.10282981758287, 53.84920404239978, 55.61466526915364, 57.399009329430115, 59.20203846997167, 61.023561023591576, 62.86339110324869, 64.72134831722842, 66.59725750359401, 68.49094848226302, 70.40225582323343, 72.33101862963088, 74.27708033438046, 76.2402885094227, 78.22049468649512, 80.21755418859397, 82.23132597131102, 84.26167247331381, 86.30845947530295, 88.37155596683819, 90.45083402047773, 92.54616867272256, 94.65743781129942, 96.78452206835561, 98.92730471917254, 101.08567158603644, 103.25951094693417, 105.44871344876624, 107.6531720247946, 109.87278181606224, 112.1074400965432, 114.35704620179739, 116.62150146092281, 118.90070913161126, 121.19457433812795, 123.50300401204832, 125.82590683559575, 128.16319318743598, 130.51477509079203, 132.88056616375485, 135.2604815716698, 137.65443798149056, 140.06235351799583, 142.484147721773, 144.91974150887808, 147.36905713208603, 149.83201814365324, 152.30854935951575, 154.7985768248534, 157.30202778095406, 159.8188306333144, 162.3489149209198, 164.89221128664644, 167.44865144873532, 170.01816817328685, 172.6006952477308, 175.19616745522737], [0.0, 0.18101933598375614, 0.512, 0.9406040612287407, 1.4481546878700498, 2.023857702507763, 2.6604300404257963, 3.3525250185494526, 4.096000000000001, 4.887522071561418, 5.724334022399463, 6.604105389831393, 7.524832489829927, 8.484768470618398, 9.482372698855498, 10.516273104099193, 11.5852375029604, 12.688151323183382, 13.824000000000007, 14.991854855220557, 16.190861620062112, 17.42023099732034, 18.679230819281624, 19.967179470320804, 21.28344032340638, 22.627416997969533, 23.998549289488327, 25.396309653176008, 26.82020014839563, 28.269749768966847, 29.744512098872978, 31.244063244078884, 32.76800000000002, 34.31593822118232, 35.88751136537615, 37.48236918872661, 39.10017657249136, 40.74061246471391, 42.403368922763704, 44.08815024470864, 45.794672179195715, 47.5226612049452, 49.27185387216523, 51.041996199208384, 52.83284311865115, 54.644157967709624, 56.475712018530636, 58.32728404443331, 60.198659918639436, 62.089632242428415, 64.00000000000004, 65.9295682376277, 67.8781477649472, 69.84555487645588, 71.83161109149653, 73.83614291117873, 75.858981590844, 77.8999629268205, 79.9589270563332, 82.03571826954409, 84.13018483279357, 86.2421788221982, 88.37155596683817, 90.51817550083527, 92.68190002368324, 94.86259536824835, 97.06013047590662, 99.27437727832906, 101.50521058546708, 103.75250797932559, 106.0161497131452, 108.2960186156445, 110.59200000000008, 112.90398157726779, 115.23185337396957, 117.57550765359265, 119.9348388417645, 122.30974345488598, 124.70012003201933, 127.10586906984283, 129.52689296049692, 131.96309593215832, 134.4143839921905, 136.88066487272786, 139.36184797856274, 141.85784433720974, 144.36856655103296, 146.89392875132737, 149.43384655425302, 151.98823701852734, 154.55701860478558, 157.14011113652694, 159.73743576256646, 162.34891492091978, 164.97447230405086, 167.6140328254172, 170.2675225872511, 172.9348688495182, 175.61600000000016, 178.31084552544763, 181.01933598375632, 183.7414029771191], [0.0, 0.18957056733575492, 0.5361865347059734, 0.9850375627355541, 1.51656453868604, 2.119463375479747, 2.7861069613351184, 3.5108960394748245, 4.289492277647788, 5.118405318065386, 5.9947477011130355, 6.916078874622531, 7.8803005018844345, 8.885583211022228, 9.930313590214565, 11.013054753337064, 12.132516309488322, 13.287531034770915, 14.477036437061289, 15.700059968038346, 16.95570700383798, 18.24315096138823, 19.56162508586647, 20.910415562585086, 22.288855690680954, 23.69632091696938, 25.13222457324462, 26.59601419385997, 28.087168315798607, 29.60519368286587, 31.149622790653517, 32.72001172065807, 34.31593822118232, 35.937000000000026, 37.582813199652875, 39.25301103100247, 40.94724254452309, 42.66517152198035, 44.40647547374147, 46.170844729114535, 47.95798160890429, 49.76759967087024, 51.599423020030024, 53.45318567681447, 55.32863099698026, 57.225511137953184, 59.14358656693054, 61.08262560663225, 63.0424040150755, 65.022704596164, 67.02331683824671, 69.04403657811446, 71.08466568817784, 73.14501178481011, 75.22488795604822, 77.32411250703113, 79.44250872171655, 81.57990463956187, 83.73613284598241, 85.91103027551242, 88.10443802669654, 90.31620118782683, 92.54616867272256, 94.79419306582031, 97.06013047590662, 99.34384039788281, 101.64518558200392, 103.96403191007946, 106.30024827816735, 108.65370648532898, 111.02428112804883, 113.41184949995315, 115.81629149649034, 118.23748952426224, 120.67532841471791, 123.12969534194433, 125.60047974430681, 128.0875732497108, 130.59086960427223, 133.11026460419959, 135.6456560307039, 138.19694358776545, 140.764028842599, 143.3468151686672, 145.94520769110588, 148.55911323442947, 151.1884402723966, 153.8330988799226, 156.49300068693182, 159.1680588340514, 161.85818793005205, 164.56330401094905, 167.28332450068075, 170.01816817328685, 172.76775511651488, 175.53200669678463, 178.3108455254477, 181.10419542627957, 183.91198140414906, 186.73412961480838, 189.5705673357551, 192.42122293811585], [0.0, 0.1982523644247402, 0.5607423650840019, 1.0301495037129325, 1.5860189153979223, 2.2165288177689013, 2.913702798845484, 3.671685171688882, 4.485938920672017, 5.352813839467989, 6.269290230959166, 7.232815772574335, 8.241196029703461, 9.292517850399864, 10.385093933133207, 11.517421586448945, 12.688151323183382, 13.896062463878042, 15.14004385726806, 16.419078415063385, 17.732230542151218, 19.078635800287202, 20.45749231944132, 21.868053594227376, 23.309622390763884, 24.781545553092542, 26.283209545259137, 27.814036600249185, 29.373481373511066, 30.961028019108177, 32.5761876222495, 34.218495934216655, 35.88751136537615, 37.582813199652875, 39.30400000000004, 41.05068817937164, 42.82251071574392, 44.619115993036026, 46.44016675249997, 48.28533914139989, 50.154321847673344, 52.04681531083343, 53.96253100068607, 55.90119075654833, 57.862526180594685, 59.84627807976036, 61.85219595131613, 63.88003750781622, 65.9295682376277, 68.00056099768595, 70.09279563550028, 72.2060586377626, 74.34014280319893, 76.4948469375553, 78.66997556882811, 80.86533868104436, 83.08075146506567, 85.31603408504179, 87.5710114592724, 89.84551305435356, 92.13937269159159, 94.45242836475946, 96.78452206835563, 99.13549963559986, 101.5052105854671, 103.8935079781216, 106.30024827816736, 108.72529122517918, 111.16849971102437, 113.62973966352305, 116.10887993603257, 118.60579220257343, 121.1203508581445, 123.65243292390178, 126.20191795689965, 128.76868796411662, 131.3526273205071, 133.9536226908404, 136.57156295510438, 139.20633913726786, 141.85784433720977, 144.52597366563575, 147.21062418181663, 149.91169483399233, 152.62908640229765, 155.36270144407263, 158.1124442414323, 160.8782207509769, 163.6599385555306, 166.45750681780638, 169.27083623589758, 172.0998390005059, 174.94442875381904, 177.80452054995695, 180.68003081691143, 183.57087731990623, 186.47697912611113, 189.39825657064554, 192.33463122381283, 195.2860258595071, 198.25236442474042, 201.23357201023913], [0.0, 0.20706279240848652, 0.5856620185738529, 1.075929830425758, 1.6565023392678928, 2.315032397181517, 3.043189116699783, 3.8348565814121405, 4.685296148590824, 5.5906953950291385, 6.547900426854399, 7.554245495084208, 8.607438643406066, 9.705481698504206, 10.846612374377546, 12.029261199259084, 13.252018714143146, 14.513609992004065, 15.812874501494036, 17.148749954442753, 18.520259177452143, 19.92649931623717, 21.366632865287887, 22.839880144168898, 24.345512933598272, 25.882849051060834, 27.451247694777024, 29.050105421495477, 30.678852651297138, 32.336950613810224, 34.023888666641284, 35.73918192964133, 37.48236918872661, 39.25301103100247, 41.05068817937164, 42.87500000000002, 44.72556316023312, 46.60201041800668, 48.503989526635884, 50.43116224121752, 52.38320341483521, 54.35980017439362, 56.36065116728163, 58.38546587122521, 60.43396396067368, 62.50587472390099, 64.60093652571925, 66.71889631131504, 68.85950914724856, 71.02253779611094, 73.20775232173166, 75.41492972217112, 77.64385358803366, 79.89431378389835, 82.16610615089418, 84.45903222864924, 86.7728989950204, 89.10751862216796, 91.46270824767882, 93.83828975956465, 96.2340895940727, 98.64993854534333, 101.08567158603644, 103.54112769812785, 106.01614971314521, 108.51058416117763, 111.02428112804883, 113.55709412009459, 116.10887993603255, 118.67949854545233, 121.268812973493, 123.8766891913084, 126.5029960119523, 129.14760499134326, 131.81039033399463, 134.49122880321983, 137.18999963554205, 139.9065844590598, 142.6408672155355, 145.39273408599217, 148.1620734196172, 150.9487756657868, 153.7527333090376, 156.573840806822, 159.41199452989738, 162.26709270520638, 165.13903536111636, 168.02772427489472, 170.93306292230315, 173.85495642920293, 176.79331152506887, 179.74803649831628, 182.71904115335124, 185.70623676925894, 188.709536060052, 191.7288531364021, 194.76410346878626, 197.81520385197916, 200.88207237083174, 203.9646283672737, 207.06279240848673, 210.17648625619395], [0.0, 0.21599999999999994, 0.610940258945177, 1.1223689233046328, 1.7280000000000004, 2.4149534156997734, 3.174538706647, 4.000375982329662, 4.887522071561418, 5.832000000000002, 6.830519745963701, 7.880300501884434, 8.978951386437064, 10.124387981502887, 11.314771937604403, 12.548466041712034, 13.824000000000005, 15.14004385726806, 16.49538699151979, 17.888921264290932, 19.319627325598194, 20.7865633523197, 22.28885569068095, 23.825691007817607, 25.396309653176008, 27.000000000000014, 28.636093588337097, 30.303960929225095, 32.00300785863731, 33.73267235189056, 35.49242172633478, 37.28175017350985, 39.10017657249136, 40.94724254452309, 42.82251071574392, 44.72556316023312, 46.65600000000003, 48.6134381421434, 50.597510136369394, 52.607863138508144, 54.644157967709624, 56.70606824670535, 58.79327961595615, 60.905489013717016, 63.04240401507548, 65.2037422238939, 67.38923071233272, 69.59860550327144, 71.83161109149654, 74.08800000000005, 76.36753236814718, 78.6699755688281, 80.9951038520231, 83.34269801248345, 85.71254507946902, 88.10443802669653, 90.51817550083526, 92.95356156705353, 95.41040547026313, 97.88852141083763, 100.38772833369632, 102.90784972974616, 105.44871344876626, 108.01015152290094, 110.5920000000001, 113.19409878611171, 115.81629149649034, 118.45842531453819, 121.12035085814449, 123.80192205293109, 126.50299601195232, 129.22343292143273, 131.96309593215832, 134.72185105616694, 137.49956706840945, 140.29611541307918, 143.1113701143275, 145.94520769110588, 148.7975070758917, 151.66814953707333, 154.55701860478558, 157.4640000000001, 160.3889815666901, 163.33185320689913, 166.29250681855765, 169.27083623589755, 172.26673717232833, 175.28010716564518, 178.31084552544763, 181.3588532826563, 184.42403314102003, 187.50628943051498, 190.6055280625409, 193.72165648682665, 196.85458364996245, 200.0042199554801, 203.17047722540815, 206.3532686632322, 209.55250881819592, 212.76811355087978, 216.00000000000017, 219.24808655037356], [0.0, 0.2250622136210341, 0.6365720697611544, 1.1694575665666544, 1.8004977089682737, 2.5162720441160578, 3.307725502516799, 4.1682105273126515, 5.092576558089237, 6.076679767767924, 7.1170921028184, 8.210916087745634, 9.355660532533237, 10.549153567940895, 11.789479717103726, 13.074933078222625, 14.403981671746193, 15.775239744612453, 17.187445883551177, 18.63944545848938, 20.13017635292847, 21.658657229846927, 23.223977781594623, 24.825290552176845, 26.4618040201344, 28.132776702629283, 29.837512094677084, 31.575354297299683, 33.345684218501226, 35.14791625402567, 36.98149537268608, 38.8458945449838, 40.74061246471391, 42.66517152198035, 44.619115993036026, 46.60201041800668, 48.6134381421434, 50.65300000000004, 52.72031312501856, 54.815009869560406, 56.93673682254722, 59.085153913652505, 61.25993359447924, 63.46076008842004, 65.68732870196509, 67.93934519113358, 70.21652517748232, 72.51859360881187, 74.84528426026593, 77.19633927201477, 79.57150872014437, 81.97055021774597, 84.39322854352719, 86.8393152955504, 89.3085885679536, 91.80083264872935, 94.31583773682983, 96.85339967703774, 99.41331971119374, 101.99540424450515, 104.59946462578104, 107.22531694054358, 109.87278181606226, 112.54168423744166, 115.23185337396959, 117.94312241500147, 120.67532841471792, 123.42831214514776, 126.20191795689965, 128.9959936470898, 131.81039033399466, 134.6449623379948, 137.49956706840945, 140.37406491585273, 143.2683191497689, 146.18219582083188, 149.1155636679151, 152.06829402936052, 155.0402607582948, 158.0313401417581, 161.0414108234278, 164.070353729734, 167.1180519991783, 170.18439091467835, 173.26925783877547, 176.37254215154937, 179.49413519109768, 182.63393019644533, 185.79182225275704, 188.96770823873604, 192.16148677609692, 195.37305818100936, 198.60232441741482, 201.84918905212396, 205.1135572116092, 208.39533554041, 211.6944321610753, 215.01075663556952, 218.34421992807617, 221.69473436913222, 225.06221362103435, 228.44657264445908], [0.0, 0.2342477321128211, 0.6625526394181824, 1.21718692073157, 1.8739818569025695, 2.618969262897143, 3.4427245024834634, 4.338328710459826, 5.300421115345461, 6.324688767046172, 7.407563702054816, 8.54603018950905, 9.737495365852562, 10.979698720821084, 12.270646600729734, 13.608563480397192, 14.99185485522056, 16.419078415063385, 17.888921264290936, 19.40018164863413, 20.95175410317715, 22.542617239353568, 24.171823596907224, 25.838491132417175, 27.541796019867718, 29.280966514102655, 31.055277683511402, 32.8640468597524, 34.70662968367862, 36.58241665062605, 38.49083007678585, 40.43132142287712, 42.403368922763704, 44.40647547374147, 46.44016675249997, 48.503989526635884, 50.597510136369394, 52.72031312501856, 54.87200000000005, 57.0521881087834, 59.26050961643854, 61.49661057326661, 63.76015006255872, 66.05079941984053, 68.36824151607242, 70.71217009822288, 73.08228918144266, 75.47831248776042, 77.89996292682052, 80.3469721146977, 82.81907992727287, 85.31603408504179, 87.8375897665687, 90.38350924809247, 92.95356156705355, 95.54752220753825, 98.1651728058379, 100.806300874499, 103.47069954339742, 106.15816731650948, 108.86850784317758, 111.60152970277792, 114.35704620179739, 117.13487518241536, 119.93483884176453, 122.75676356111717, 125.60047974430682, 128.46582166475267, 131.3526273205071, 134.26073829679336, 137.18999963554208, 140.14025971147635, 143.1113701143275, 146.10318553679807, 149.1155636679151, 152.14836509144632, 155.20145318907308, 158.27469404803804, 161.36795637300503, 164.48111140188726, 167.61403282541727, 170.76659671024672, 173.93868142538068, 177.1301675717608, 180.34093791482857, 183.57087731990623, 186.8198726902469, 190.08781290761402, 193.37458877525782, 196.68009296316717, 200.00421995548012, 203.3468659999462, 206.70792905933746, 210.08730876471355, 213.4849063704507, 216.90062471094933, 220.33436815894183, 223.78604258532326, 227.2555553204368, 230.74281511674442, 234.24773211282132, 237.77021779861357], [0.0, 0.2435549219375375, 0.6888773475735721, 1.2655484976878608, 1.9484393755003009, 2.7230268085349443, 3.5795116985421367, 4.510700278227319, 5.511018780588579, 6.575982892313516, 7.701882886671288, 8.885583211022228, 10.124387981502888, 11.415946872686476, 12.75818701853834, 14.149262348263962, 15.58751500400241, 17.071445369388044, 18.599688384486456, 20.170994546625618, 21.78421446827956, 23.43828617881437, 25.132224573244624, 26.86511256257828, 28.636093588337104, 30.44436524219221, 32.28917378936788, 34.169809437572255, 36.08560222581857, 38.03591843245017, 40.02015742097977, 42.03774885742578, 44.08815024470864, 46.170844729114535, 48.28533914139989, 50.43116224121752, 52.607863138508144, 54.815009869560406, 57.0521881087834, 59.31900000000005, 61.61506309337032, 63.94000937597685, 66.29348438572231, 68.67514639955277, 71.08466568817784, 73.52172383044352, 75.98601308135603, 78.4772357884757, 80.99510385202314, 83.53933822457545, 86.10966844669657, 88.7058322152496, 91.32757498149184, 93.97464957636191, 96.64681586063773, 99.34384039788283, 102.06549614830674, 104.811562181851, 107.58182340897567, 110.37607032776634, 113.19409878611172, 116.03570975781561, 118.90070913161125, 121.7889075121377, 124.70012003201934, 127.63416617426553, 130.59086960427223, 133.5700580107684, 136.57156295510435, 139.5952197283275, 142.64086721553554, 145.70834776703785, 148.79750707589167, 151.90819406141344, 155.04026075829478, 158.1935622109827, 161.367956373005, 164.56330401094908, 167.77946861281941, 171.01631630052162, 174.27371574623655, 177.551538092465, 180.84965687553867, 184.16794795240583, 187.506289430515, 190.86456160062838, 194.24264687241077, 197.6404297126478, 201.05779658595705, 204.49463589786427, 207.95083794012487, 211.42629483817777, 214.92090050062626, 218.43455057064597, 221.96714237922714, 225.51857490016224, 229.08874870669692, 232.67756592976497, 236.28493021773548, 239.91074669760025, 243.55492193753776, 247.21736391079034], [0.0, 0.2529822128134703, 0.7155417527999326, 1.314534138012399, 2.023857702507763, 2.8284271247461903, 3.7180640123591213, 4.685296148590824, 5.7243340223994625, 6.830519745963701, 8.000000000000002, 9.229517863897337, 10.516273104099193, 11.857824421031038, 13.252018714143146, 14.696938456699073, 16.19086162006211, 17.732230542151214, 19.31962732559819, 20.951754103177144, 22.62741699796953, 24.34551293359827, 26.105018674576748, 27.904981634109724, 29.74451209887298, 31.622776601683807, 33.538992232921984, 35.49242172633478, 37.48236918872661, 39.50817636894927, 41.56921938165307, 43.66490581691436, 45.794672179195715, 47.95798160890429, 50.154321847673344, 52.38320341483521, 54.644157967709624, 56.93673682254722, 59.26050961643854, 61.61506309337032, 64.00000000000003, 66.41493807871845, 68.85950914724854, 71.3333582554474, 73.83614291117871, 76.36753236814717, 78.92720696946022, 81.51485754143233, 84.13018483279357, 86.77289899502038, 89.44271909999163, 92.13937269159157, 94.86259536824834, 97.61213039371704, 100.38772833369632, 103.18914671611552, 106.0161497131452, 108.86850784317757, 111.7459976911926, 114.64840164607625, 117.57550765359262, 120.52710898382995, 123.50300401204831, 126.50299601195232, 129.52689296049692, 132.57450735341249, 135.64565603070386, 138.7401600114402, 141.85784433720974, 144.99853792366332, 148.16207341961717, 151.34828707322734, 154.55701860478555, 157.78811108572165, 161.04141082342775, 164.31676725154995, 167.6140328254172, 170.93306292230312, 174.27371574623652, 177.6358522370978, 181.0193359837563, 184.42403314101998, 187.8498123501859, 191.2965446629919, 194.7641034687862, 198.25236442474036, 201.76120538894503, 205.29050635623673, 208.84014939661404, 212.41001859611066, 216.00000000000017, 219.60998155821622, 223.23985307287785, 226.88950614781655, 230.5588341400088, 234.24773211282127, 237.95609679098393, 241.68382651720844, 245.43082121037713, 249.1969823252282, 252.98221281347054, 256.7864170862628], [0.0, 0.2625280937347468, 0.7425415813272683, 1.364135990288359, 2.100224749877975, 2.9351533179716536, 3.8583592367741, 4.862088337329961, 5.940332650618148, 7.088258530838167, 8.301867259839804, 9.577779022299486, 10.913087922306874, 12.305260541735805, 13.752062536216167, 15.251504024193817, 16.801797999023805, 18.40132802272707, 20.048622695836254, 21.742335178172574, 23.481226543773236, 25.264152093430738, 27.090049981496914, 28.957931676830814, 30.86687389419281, 32.81601171684337, 34.804532693314556, 36.831671737785705, 38.896706698639704, 40.99895448666957, 43.137767675205474, 45.31253150067874, 47.5226612049452, 49.76759967087024, 52.04681531083343, 54.35980017439362, 56.70606824670535, 59.085153913652505, 61.49661057326661, 63.94000937597685, 66.41493807871845, 68.92100000000006, 71.45781306477276, 74.02500892941525, 76.62223217839592, 79.24913958523467, 81.90539943129521, 84.59069087671534, 87.30470337845502, 90.04713615101824, 92.8176976659086, 95.61610518631272, 98.44208433388648, 101.29536868485164, 104.17569939290074, 107.08282483666565, 110.01650028972936, 112.97648761136107, 115.96255495633075, 118.97447650231551, 122.0120321935506, 125.0750074995002, 128.16319318743595, 131.27638510790902, 134.4143839921905, 137.5769952608358, 140.76402884259898, 143.97529900298886, 147.2106241818166, 150.46982683913757, 153.7527333090376, 157.05917366075772, 160.38898156669006, 163.7419941768148, 167.11805199917828, 170.51699878604495, 173.93868142538065, 177.38294983735065, 180.84965687553867, 184.33865823261291, 187.84981235018594, 191.38298033263058, 194.9380258646324, 198.51481513227188, 202.11321674744596, 205.73310167544764, 209.37434316553708, 213.03681668434706, 216.7203998519754, 220.42497238062683, 224.15041601567484, 227.89661447902225, 231.66345341464657, 235.45082033622248, 239.25860457672178, 243.08669723989445, 246.93499115354257, 250.80338082450194, 254.69176239525325, 258.6000336020862, 262.5280937347471, 266.4758435975017], [0.0, 0.2721911093331301, 0.7698727167525812, 1.4143464922005504, 2.177528874665042, 3.043189116699783, 4.000375982329663, 5.041049890647783, 6.158981734020652, 7.349159951994517, 8.607438643406066, 9.930313590214567, 11.314771937604405, 12.758187018538338, 14.258242247907006, 15.812874501494035, 17.42023099732034, 19.078635800287206, 20.786563352319703, 22.542617239353568, 24.345512933598272, 26.194063602274483, 28.087168315798607, 30.023802157621567, 32.00300785863732, 34.02388866664129, 36.08560222581857, 38.187355289414874, 40.32839912518228, 42.508025501074535, 44.72556316023312, 46.980374711149366, 49.27185387216523, 51.599423020030024, 53.96253100068607, 56.36065116728163, 58.79327961595615, 61.25993359447924, 63.76015006255872, 66.29348438572231, 68.85950914724854, 71.45781306477276, 74.08800000000006, 76.74968805148336, 79.44250872171655, 82.16610615089418, 84.92013641063004, 87.70426685173312, 90.51817550083528, 93.36155050126372, 96.23408959407271, 99.13549963559986, 102.06549614830674, 105.02380290200895, 108.01015152290094, 111.02428112804883, 114.06593798325609, 117.13487518241534, 120.230852346642, 123.35363534164702, 126.50299601195233, 129.67871193067901, 132.88056616375485, 136.1083470474902, 139.36184797856276, 142.6408672155355, 145.9452076911059, 149.2746768343514, 152.62908640229767, 156.00825232018994, 159.4119945298974, 162.84013684592645, 166.29250681855765, 169.7689356036612, 173.26925783877547, 176.7933115250689, 180.3409379148286, 183.91198140414903, 187.50628943051504, 191.12371237499565, 194.76410346878623, 198.42731870385202, 202.11321674744602, 205.82165886028633, 209.55250881819592, 213.30563283701647, 217.08089950062416, 220.8781796918838, 224.6973465263889, 228.53827528884545, 232.4008433719639, 236.28493021773542, 240.1904172609726, 244.11718787500425, 248.06512731942013, 252.03412268976618, 256.0240628690986, 260.0348384813084, 264.06634184613563, 268.1184669357934, 272.1911093331304, 276.28416619126074], [0.0, 0.28196985654498596, 0.7975311906126304, 1.4651583532164711, 2.2557588523598886, 3.1525188342022643, 4.144093628285926, 5.222154823442141, 6.380249524901046, 7.613186126714625, 8.916669781930922, 10.287070379850626, 11.721266825731771, 13.216538086806247, 14.770484352247905, 16.380968377968383, 18.046070818879112, 19.764055530179036, 21.533342146541035, 23.352484086280853, 25.22015067361812, 27.13511243757801, 29.096228896542605, 31.102438312775437, 33.152749026287424, 35.24623206812327, 37.38201481996391, 39.55927553684473, 41.77723858753714, 44.03517029602591, 46.332375289855385, 48.6681932785675, 51.041996199208384, 53.45318567681447, 55.90119075654833, 58.38546587122521, 60.905489013717016, 63.46076008842004, 66.05079941984053, 68.67514639955277, 71.3333582554474, 74.02500892941525, 76.74968805148336, 79.50700000000005, 82.29656303880502, 85.11800852346117, 87.97098016959919, 90.8551333772617, 93.7701346058542, 96.71566079493029, 99.69139882657888, 102.69704502564821, 105.73230469445001, 108.79689167894468, 111.89052796372005, 115.01294329335293, 118.16387481798327, 121.34306676114635, 124.55027010809742, 127.7852423130309, 131.04774702374712, 134.3375538224514, 137.65443798149056, 140.99818023293787, 144.36856655103298, 147.76538794656898, 151.1884402723966, 154.63752403928368, 158.1124442414323, 161.61301019101168, 165.13903536111636, 168.69033723660655, 172.2667371723283, 175.8680602582517, 179.49413519109768, 183.14479415205898, 186.81987269024688, 190.51920961152462, 194.24264687241077, 197.9900294787595, 201.76120538894503, 205.55602542129495, 209.37434316553708, 213.21601489803732, 217.08089950062413, 220.96885838280485, 224.8797554071955, 228.8134568179942, 232.7698311723409, 236.7487492744156, 240.75008411213503, 244.77371079631914, 248.81950650220355, 252.88735041318319, 256.9771236666799, 261.08870930203034, 265.22199221029945, 269.3768590859284, 273.5531983801325, 277.750900255967, 281.96985654498627, 286.20996070542367], [0.0, 0.29186298155127516, 0.8255131737289236, 1.5165645386860402, 2.334903852410202, 3.2631273343220926, 4.289492277647789, 5.40537806263355, 6.604105389831392, 7.880300501884434, 9.229517863897337, 10.648000000000007, 12.132516309488324, 13.680250290108006, 15.288717931860743, 16.95570700383798, 18.67923081928162, 20.45749231944132, 22.28885569068095, 24.17182359690722, 26.10501867457675, 28.087168315798603, 30.117092024297452, 32.19369081046784, 34.31593822118232, 36.48287269390942, 38.69359099385843, 40.9472425445231, 43.24302450106841, 45.58017744590298, 47.9579816089043, 50.375753532825726, 52.83284311865115, 55.32863099698026, 57.862526180594685, 60.43396396067368, 63.04240401507548, 65.68732870196509, 68.36824151607242, 71.08466568817784, 73.83614291117871, 76.62223217839592, 79.44250872171655, 82.29656303880502, 85.18400000000007, 88.10443802669653, 91.05750833401942, 94.04285423146202, 97.06013047590662, 100.10900267208747, 103.18914671611553, 106.30024827816735, 109.44200232086409, 112.61411265023592, 115.81629149649035, 119.0482591220889, 122.30974345488599, 125.60047974430681, 128.92021023873656, 132.26868388246717, 135.64565603070386, 139.05088818126993, 142.484147721773, 145.9452076911059, 149.43384655425305, 152.94984798946365, 156.49300068693182, 160.06309815819526, 163.6599385555306, 167.28332450068072, 170.93306292230315, 174.60896490157674, 178.31084552544763, 182.03852374703564, 185.79182225275702, 189.57056733575513, 193.37458877525782, 197.2037197215105, 201.05779658595705, 204.9366589363652, 208.84014939661407, 212.76811355087978, 216.7203998519754, 220.69685953361477, 224.69734652638888, 228.7217173772532, 232.76983117234093, 236.84154946292702, 240.93673619437968, 245.05525763794606, 249.19698232522825, 253.36178098521512, 257.5495264837428, 261.7600937652646, 265.9933597968192, 270.24920351409014, 274.5275057694587, 278.82814928195495, 283.1510185890211, 287.49600000000027, 291.8629815512755, 296.25185296298184], [0.0, 0.30186917696247156, 0.8538149682454624, 1.5685582552140043, 2.4149534156997734, 3.3750000000000004, 4.436552715791847, 5.5906953950291385, 6.830519745963701, 8.150467777986735, 9.545941546018394, 11.013054753337064, 12.548466041712036, 14.14926234826396, 15.812874501494035, 17.537014426634887, 19.31962732559819, 21.15885452948719, 23.053004142627497, 25.000527494435005, 27.000000000000014, 29.050105421495473, 31.149622790653517, 33.297415440241025, 35.49242172633479, 37.733647120308966, 40.020157420979764, 42.35107289077813, 44.72556316023313, 47.142842775971864, 49.60216729135938, 52.10282981758287, 54.644157967709624, 57.225511137953184, 59.84627807976036, 62.50587472390099, 65.2037422238939, 67.93934519113358, 70.71217009822288, 73.52172383044352, 76.36753236814717, 79.24913958523467, 82.16610615089418, 85.11800852346117, 88.10443802669653, 91.12500000000004, 94.17931301512033, 97.2670081528162, 100.38772833369633, 103.54112769812784, 106.72687103068287, 109.94463322509206, 113.19409878611171, 116.4749613650935, 119.7869233263799, 123.1296953419443, 126.50299601195232, 129.90655150915222, 133.34009524520383, 136.80336755723533, 140.29611541307915, 143.8180921337786, 147.369057132086, 150.94877566578683, 154.55701860478558, 158.19356221098263, 161.85818793005203, 165.5506821943058, 169.27083623589755, 173.01844590967764, 176.79331152506887, 180.5952376863799, 184.42403314102, 188.27951063511944, 192.16148677609687, 196.06978190175064, 200.0042199554801, 203.9646283672737, 207.95083794012487, 211.96268274156202, 216.00000000000017, 220.06263000564195, 224.15041601567484, 228.26320416352718, 232.40084337196387, 236.56318526981343, 240.75008411213503, 244.9613967036441, 249.19698232522822, 253.456702663394, 257.7404217424968, 262.0480058596136, 266.37932352192826, 270.73424538650465, 275.1126442023342, 279.5143947545459, 283.93937381067843, 288.3874600689152, 292.85853410819385, 297.35247834010084, 301.86917696247184, 306.4085159146204], [0.0, 0.31198717922376235, 0.8824330002895406, 1.6211329371769618, 2.4958974337901, 3.488122704263715, 4.58525637233078, 5.7780834192662915, 7.059464002316327, 8.423653839041588, 9.865900871182525, 11.382188541752425, 12.969063497415696, 14.623515035722441, 16.342887872098995, 18.12481724045791, 19.967179470320804, 21.868053594227376, 23.82569100781761, 25.838491132417175, 27.904981634109728, 30.023802157621564, 32.19369081046784, 34.41347282678693, 36.68205097864625, 38.99839740297032, 41.36154658617111, 43.77058930377798, 46.224667354130354, 48.722968957156176, 51.26472471397856, 53.84920404239978, 56.475712018530636, 59.14358656693054, 61.85219595131613, 64.60093652571925, 67.38923071233272, 70.21652517748232, 73.08228918144266, 75.98601308135603, 78.92720696946022, 81.90539943129521, 84.92013641063004, 87.97098016959919, 91.05750833401942, 94.17931301512033, 97.33600000000011, 100.52718800404207, 103.7525079793256, 107.01160247375059, 110.30412503619264, 113.62973966352307, 116.98812028577956, 120.37895028616936, 123.8019220529311, 127.25673656038815, 130.743102976792, 134.26073829679336, 137.80936699658716, 141.38872070996342, 144.99853792366335, 148.63856369058485, 152.30854935951575, 156.00825232018994, 159.7374357625665, 163.49586844932824, 167.28332450068075, 171.0995831906088, 174.94442875381904, 178.81765020265777, 182.71904115335124, 186.64839966096702, 190.6055280625409, 194.59023282785824, 198.60232441741482, 202.64161714712031, 206.70792905933746, 210.80108179988093, 214.9209005006263, 219.06721366740413, 223.2398530728779, 227.43865365412296, 231.6634534146466, 235.91409333060227, 240.1904172609726, 244.49227186150512, 248.81950650220358, 253.17197318818714, 257.5495264837428, 261.952023439408, 266.3793235219283, 270.8312885469479, 275.3077826142955, 279.80867204573946, 284.33382532509245, 288.8831130405517, 293.45640782917013, 298.0535843233566, 302.6745190993127, 307.3190906273156, 311.98717922376267, 316.67866700489986], [0.0, 0.32221576621884906, 0.91136381319427, 1.6742822342723471, 2.5777261297507934, 3.6024817834376357, 4.735585285896562, 5.967519501434413, 7.290910505554162, 8.699825687908929, 10.18935719267904, 11.75535677893275, 13.394257874178779, 15.102951069244721, 16.87869402530896, 18.71904444676598, 20.621809038006354, 22.585003852113925, 24.606822956245303, 26.685613296306325, 28.819854267501096, 31.008140914927505, 33.249169974602395, 35.54172816563654, 37.88468228717251, 40.27697077735616, 42.71759646796625, 45.20562032535339, 47.74015601147533, 50.32036513182316, 52.94545306256245, 55.61466526915364, 58.32728404443331, 61.08262560663225, 63.88003750781622, 66.71889631131504, 69.59860550327144, 72.51859360881187, 75.47831248776042, 78.4772357884757, 81.51485754143233, 84.59069087671534, 87.70426685173312, 90.8551333772617, 94.04285423146202, 97.2670081528162, 100.52718800404207, 103.82300000000009, 107.15406299343027, 110.52000781306533, 113.92047664928383, 117.3551224830004, 120.8236085539578, 124.32560786499309, 127.86080271920721, 131.428884287283, 135.0295522024717, 138.66251418101444, 142.32748566598104, 146.0241894927003, 149.7523555741279, 153.51172060464975, 157.30202778095406, 161.12302653872925, 164.9744723040509, 168.85612625842168, 172.76775511651488, 176.7091309157511, 180.68003081691143, 184.6802369150529, 188.709536060052, 192.76771968615512, 196.85458364996245, 200.96992807631713, 205.1135572116092, 209.2852792840435, 213.48490637045066, 217.7122542692535, 221.96714237922717, 226.2493935837179, 230.55883414000883, 234.89529357354115, 239.2586045767218, 243.64860291206293, 248.0651273194201, 252.50801942710675, 256.97712366668, 261.4722871912053, 265.9933597968192, 270.54019384742105, 275.11264420233425, 279.71056814679014, 284.33382532509245, 288.98227767633114, 293.655789372524, 298.35422675906597, 303.0774582973802, 307.82535450966384, 312.5977879256349, 317.39463303118436, 322.2157662188494, 327.06106574002393], [0.0, 0.33255375505322443, 0.9406040612287406, 1.7280000000000009, 2.660430040425797, 3.7180640123591218, 4.88752207156142, 6.158981734020653, 7.524832489829927, 8.978951386437064, 10.516273104099195, 12.132516309488325, 13.82400000000001, 15.587515004002412, 17.420230997320342, 19.319627325598194, 21.283440323406378, 23.309622390763884, 25.396309653176008, 27.541796019867714, 29.744512098872985, 32.00300785863731, 34.31593822118232, 36.68205097864625, 39.10017657249137, 41.569219381653085, 44.08815024470865, 46.65600000000004, 49.27185387216524, 51.93484656759857, 54.64415796770964, 57.399009329430115, 60.198659918639436, 63.0424040150755, 65.9295682376277, 68.85950914724856, 71.83161109149654, 74.84528426026593, 77.89996292682052, 80.99510385202314, 84.13018483279357, 87.30470337845502, 90.51817550083528, 93.7701346058542, 97.06013047590662, 100.38772833369633, 103.7525079793256, 107.15406299343027, 110.59200000000011, 114.06593798325609, 117.57550765359265, 121.12035085814452, 124.70012003201934, 128.31447768665873, 131.96309593215838, 135.6456560307039, 139.36184797856276, 143.1113701143275, 146.8939287513274, 150.70923783232416, 154.5570186047856, 158.43699931518537, 162.34891492091978, 166.2925068185577, 170.2675225872511, 174.27371574623655, 178.3108455254477, 182.37867664834087, 186.4769791261111, 190.60552806254094, 194.76410346878626, 198.95249008745805, 203.17047722540812, 207.4178585946738, 211.69443216107524, 216.00000000000023, 220.3343681589418, 224.6973465263889, 229.0887487066969, 233.50839190059125, 237.95609679098396, 242.43168743380085, 246.93499115354257, 251.46583844331647, 256.02406286909854, 260.60950097799605, 265.22199221029945, 269.86137881512457, 274.5275057694587, 279.22022070043596, 283.93937381067843, 288.6848178065486, 293.4564078291701, 298.25400138807896, 303.07745829738013, 307.9266406142869, 312.8014125799311, 317.7016405623368, 322.62719300145835, 327.5779403561849, 332.5537550532248, 337.5545114377829], [0.0, 0.34299999999999997, 0.9701505037879433, 1.7822802809883755, 2.744000000000001, 3.834856581412141, 5.041049890647783, 6.352448897866085, 7.761204030303549, 9.261000000000005, 10.846612374377546, 12.513625334010932, 14.258242247907008, 16.077153137293937, 17.967438771288478, 19.92649931623717, 21.952000000000012, 24.041828902976597, 26.194063602274486, 28.40694441505459, 30.678852651297134, 33.00829273076694, 35.39387732362763, 37.834314887414074, 40.32839912518228, 42.87500000000003, 45.47305602222049, 48.121567586686155, 50.819591182928704, 53.56623433656696, 56.36065116728163, 59.20203846997167, 62.089632242428415, 65.022704596164, 68.00056099768595, 71.02253779611094, 74.08800000000005, 77.19633927201477, 80.3469721146977, 83.53933822457545, 86.77289899502038, 90.04713615101824, 93.36155050126372, 96.71566079493029, 100.10900267208747, 103.54112769812784, 107.01160247375059, 110.52000781306533, 114.06593798325609, 117.64900000000011, 121.268812973493, 124.9250075005002, 128.61722509835155, 132.3451176772307, 136.10834704749018, 139.9065844590598, 143.73951017030785, 147.60681304397855, 151.50819016805676, 155.44334649961718, 159.4119945298974, 163.41385396899508, 167.44865144873532, 171.51612024238437, 175.61600000000018, 179.7480364983163, 183.91198140414906, 188.10759205040097, 192.33463122381283, 196.59286696368227, 200.88207237083174, 205.20202542616408, 209.55250881819592, 213.93330977900587, 218.34421992807617, 222.78503512354706, 227.25555532043677, 231.75558443541357, 236.28493021773548, 240.84340412600073, 245.43082121037716, 250.0470000000002, 254.69176239525328, 259.36493356465934, 264.0663418461356, 268.7958186523744, 273.5531983801325, 278.33831832322363, 283.1510185890211, 287.99114201829224, 292.8585341081939, 297.7530429382715, 302.6745190993127, 307.6228156249146, 312.59778792563486, 317.5992937256004, 322.62719300145835, 327.6813479235586, 332.7616227992649, 337.8678840182953, 343.00000000000034, 348.1578411424914], [0.0, 0.35355339059327373, 1.0, 1.8371173070873843, 2.8284271247461907, 3.9528470752104754, 5.196152422706634, 6.5479004268544, 8.000000000000004, 9.545941546018396, 11.180339887498953, 12.898643339514438, 14.696938456699076, 16.57181341917656, 18.520259177452143, 20.539595906443736, 22.627416997969533, 24.781545553092545, 27.000000000000014, 29.280966514102655, 31.62277660168381, 34.023888666641284, 36.48287269390942, 38.99839740297032, 41.569219381653085, 44.19417382415924, 46.87216658103189, 49.60216729135939, 52.38320341483522, 55.21435501751338, 58.09475019311129, 61.023561023591576, 64.00000000000004, 67.02331683824671, 70.09279563550028, 73.20775232173166, 76.36753236814718, 79.57150872014437, 82.81907992727287, 86.10966844669657, 89.44271909999163, 92.8176976659086, 96.23408959407271, 99.69139882657888, 103.18914671611553, 106.72687103068287, 110.30412503619264, 113.92047664928383, 117.57550765359265, 121.268812973493, 125.00000000000009, 128.7686879641166, 132.5745073534125, 136.41709936807788, 140.29611541307918, 144.21121662339596, 148.1620734196172, 152.1483650914463, 156.16977940690077, 160.22601224520332, 164.31676725154995, 168.44175551210589, 172.6006952477308, 176.7933115250689, 181.01933598375635, 185.27850657861006, 189.5705673357551, 193.89526812173645, 198.2523644247404, 202.6416171471203, 207.06279240848673, 211.5156613586807, 216.00000000000017, 220.51558901810114, 225.06221362103432, 229.63966338592314, 234.24773211282132, 238.8862176853242, 243.55492193753776, 248.25365052703677, 252.98221281347057, 257.7404217424968, 262.5280937347471, 267.3450485795466, 272.1911093331304, 277.06610222111277, 281.96985654498627, 286.90220459243625, 291.8629815512754, 296.8520254268112, 301.8691769624719, 306.9142795635292, 311.98717922376267, 317.08772445492144, 322.21576621884935, 327.37115786214304, 332.55375505322485, 337.76341572171526, 343.00000000000034, 348.26337016688996, 353.55339059327406, 358.86992768968577], [0.0, 0.36421284985568536, 1.0301495037129322, 1.8925054821585072, 2.913702798845484, 4.0720234527811865, 5.352813839467989, 6.745316375085757, 8.24119602970346, 9.83374694610351, 11.517421586448945, 13.287531034770916, 15.14004385726806, 17.07144536938804, 19.078635800287202, 21.158854529487186, 23.309622390763877, 25.528696852757705, 27.81403660024918, 30.163773122737833, 32.5761876222495, 35.04969202432457, 37.582813199652875, 40.17417973026958, 42.822510715743924, 45.5266062319607, 48.28533914139989, 51.09764801827971, 53.96253100068607, 56.87904041912105, 59.84627807976036, 62.86339110324869, 65.9295682376277, 69.04403657811446, 72.2060586377626, 75.41492972217112, 78.6699755688281, 81.97055021774597, 85.31603408504179, 88.7058322152496, 92.13937269159157, 95.61610518631272, 99.13549963559986, 102.69704502564821, 106.30024827816735, 109.94463322509206, 113.62973966352307, 117.3551224830004, 121.12035085814452, 124.9250075005002, 128.7686879641166, 132.65100000000012, 136.57156295510435, 140.5300072119832, 144.52597366563575, 148.55911323442947, 152.62908640229767, 156.7355627896874, 160.8782207509769, 165.0567469962984, 169.27083623589758, 173.52019084533092, 177.80452054995695, 182.12354212731552, 186.4769791261111, 190.86456160062838, 195.2860258595071, 199.74111422789272, 204.22957482206166, 208.75116133569196, 213.3056328370165, 217.8927535761575, 222.5122928019935, 227.1640245879618, 231.8477276662424, 236.56318526981352, 241.31018498190275, 246.08851859239618, 250.89798196079644, 255.73837488535062, 260.6095009779961, 265.51116754479483, 270.4431854715518, 275.40536911432963, 280.3975361945967, 285.41950769875587, 290.47110778182423, 295.5521636750443, 300.66250559722306, 305.80196666960825, 310.97038283412166, 316.1675927747817, 321.3934378421567, 326.6477619807003, 331.9304116588298, 337.2412358016146, 342.5800857259515, 347.94681507810975, 353.3412797735361, 358.76333793881486, 364.2128498556857, 369.6896779070256], [0.0, 0.37497733264825484, 1.0605960588272993, 1.948439375500301, 2.99981866118604, 4.192374029115247, 5.5110187805885795, 6.944677386315368, 8.484768470618398, 10.124387981502887, 11.85782442103104, 13.680250290108008, 15.587515004002412, 17.57600000000001, 19.642513892065864, 21.784214468279558, 23.998549289488327, 26.283209545259137, 28.636093588337097, 31.0552776835114, 33.53899223292199, 36.08560222581856, 38.69359099385843, 41.36154658617111, 44.08815024470865, 46.87216658103189, 49.71243514453907, 52.607863138508144, 55.55741909052296, 58.560127322266005, 61.61506309337032, 64.72134831722842, 67.8781477649472, 71.08466568817784, 74.34014280319893, 77.64385358803366, 80.9951038520231, 84.39322854352719, 87.8375897665687, 91.32757498149184, 94.86259536824834, 98.44208433388648, 102.06549614830674, 105.73230469445001, 109.44200232086409, 113.19409878611171, 116.98812028577956, 120.8236085539578, 124.70012003201934, 128.61722509835155, 132.5745073534125, 136.57156295510435, 140.60800000000012, 144.68343794643548, 148.7975070758917, 152.94984798946365, 157.14011113652697, 161.367956373005, 165.63305254688768, 169.93507710887724, 174.27371574623652, 178.648662038091, 183.0596171305951, 187.506289430515, 191.9883943159067, 196.50565386268167, 201.05779658595705, 205.64455719517616, 210.26567636207315, 214.92090050062626, 219.60998155821628, 224.33267681726642, 229.08874870669683, 233.87796462257856, 238.70009675741673, 243.55492193753776, 248.44222146809128, 253.36178098521512, 258.3133903149431, 263.2968433384649, 268.311937863376, 273.35847550057804, 278.43626154651656, 283.54510487046, 288.6848178065486, 293.8552160503539, 299.0561185597114, 304.2873474596014, 309.5487279508675, 314.8400882225772, 320.1612593678382, 325.512075302899, 330.8923726893689, 336.3019908594063, 341.7407717437301, 347.2085598023185, 352.7052019576693, 358.23054753049786, 363.78444817776403, 369.36675783291633, 374.97733264825524, 380.6160309393186], [0.0, 0.3858458241318675, 1.0913367949446224, 2.0049137138540414, 3.0867665930549415, 4.313887457966424, 5.670752331040393, 7.145964665459806, 8.730694359556981, 10.417837251560428, 12.201516299214626, 14.076764081279487, 16.039309710832335, 18.085429743304427, 20.211840292264352, 22.415616765995992, 24.69413274443954, 27.045012497686177, 29.46609346350482, 31.955396148381602, 34.51109966373141, 37.131521609004956, 39.815101356143785, 42.56038602973431, 45.366018648323156, 48.230728016483475, 51.15332004865378, 54.13267027405914, 57.16771732367847, 60.25745723974757, 63.40093847885855, 66.59725750359401, 69.84555487645588, 73.14501178481011, 76.4948469375553, 79.89431378389835, 83.34269801248345, 86.8393152955504, 90.38350924809247, 93.97464957636191, 97.61213039371704, 101.29536868485164, 105.02380290200895, 108.79689167894468, 112.61411265023592, 116.4749613650935, 120.37895028616936, 124.32560786499309, 128.31447768665873, 132.3451176772307, 136.41709936807788, 140.5300072119832, 144.68343794643548, 148.87700000000018, 153.11031293809066, 157.38300694484155, 161.69472233811484, 166.04510911496325, 170.43382652513577, 174.860542670438, 179.32493412796802, 183.8266855954273, 188.36548955687206, 192.94104596741485, 197.5530619555164, 202.20125154162642, 206.8853353720367, 211.60504046690406, 216.36009998148944, 221.15025297973347, 225.9752442193616, 230.83482394777468, 235.7287477080386, 240.65677615434006, 245.6186748763215, 250.6142142317553, 255.6431691870529, 260.70531916514506, 265.8004479003001, 270.9283432994787, 276.0887973098513, 281.28160579213164, 286.50656839940024, 291.76348846111676, 297.05217287203976, 302.37243198578835, 307.72407951280024, 313.1069324224557, 318.5208108491504, 323.9655380021157, 329.4409400787951, 334.94684618159977, 340.4830882378746, 346.0495009229175, 351.6459215859048, 357.2721901785812, 362.92814918658536, 368.61364356328477, 374.32852066600583, 380.07263019454626, 385.8458241318679, 391.64795668687003], [0.0, 0.3968173383308748, 1.1223689233046326, 2.0619233739399734, 3.174538706647, 4.436552715791847, 5.8320000000000025, 7.349159951994517, 8.978951386437064, 10.714068134933626, 12.548466041712036, 14.47703643706129, 16.49538699151979, 18.599688384486456, 20.786563352319703, 23.053004142627497, 25.396309653176004, 27.814036600249185, 30.303960929225095, 32.86404685975239, 35.49242172633479, 38.18735528941487, 40.9472425445231, 43.770589303777975, 46.65600000000004, 49.602167291359386, 52.607863138508144, 55.6719310963793, 58.79327961595616, 61.97087619196622, 65.20374222389391, 68.49094848226302, 71.83161109149653, 75.22488795604822, 78.66997556882811, 82.16610615089418, 85.71254507946902, 89.3085885679536, 92.95356156705355, 96.64681586063773, 100.38772833369632, 104.17569939290074, 108.01015152290094, 111.89052796372005, 115.81629149649035, 119.7869233263799, 123.8019220529311, 127.86080271920721, 131.96309593215838, 136.10834704749018, 140.29611541307918, 144.52597366563575, 148.7975070758917, 153.11031293809066, 157.46400000000014, 161.85818793005203, 166.29250681855765, 170.76659671024672, 175.2801071656452, 179.8326968490437, 184.42403314102003, 189.05379177366441, 193.72165648682665, 198.42731870385205, 203.17047722540812, 207.95083794012484, 212.7681135508798, 217.62202331565638, 222.5122928019935, 227.43865365412296, 232.4008433719639, 237.3986051012097, 242.43168743380082, 247.49984421813303, 252.6028343783975, 257.74042174249684, 262.91237487801925, 268.1184669357934, 273.3584755005781, 278.6321824484748, 283.9393738106784, 289.279839643208, 294.65337390228575, 300.0597743250504, 305.49884231531905, 310.9703828341216, 316.47420429475795, 322.0101184621381, 327.57794035618485, 333.1774881590895, 338.80858312622513, 344.47104950053523, 350.1647144302239, 355.88940788958615, 361.64496260282715, 367.43121397072434, 373.24800000000045, 379.0951612352765, 384.97254069348935, 390.87998380065494, 396.81733833087526, 402.784454347484], [0.0, 0.4078909167902614, 1.1536897329871667, 2.119463375479747, 3.2631273343220926, 4.560359086738676, 5.994747701113036, 7.554245495084208, 9.229517863897337, 11.013054753337064, 12.898643339514436, 14.881032390261108, 16.95570700383798, 19.11873099868295, 21.366632865287887, 23.696320916969377, 26.105018674576748, 28.590214672156645, 31.14962279065352, 33.78115043926126, 36.48287269390942, 39.25301103100247, 42.08991565684116, 44.992050686760244, 47.957981608904305, 50.986364598782714, 54.07593734740068, 57.22551113795319, 60.43396396067369, 63.700234497213636, 67.02331683824671, 70.40225582323343, 73.83614291117873, 77.32411250703113, 80.86533868104436, 84.45903222864924, 88.10443802669653, 91.80083264872935, 95.54752220753825, 99.34384039788283, 103.18914671611552, 107.08282483666565, 111.02428112804883, 115.01294329335293, 119.0482591220889, 123.1296953419443, 127.25673656038815, 131.428884287283, 135.6456560307039, 139.9065844590598, 144.21121662339596, 148.55911323442947, 152.94984798946365, 157.38300694484155, 161.85818793005203, 166.3750000000001, 170.93306292230315, 175.53200669678463, 180.17147110461207, 184.85110528476713, 189.5705673357551, 194.32952394065103, 199.1276500137539, 203.96462836727372, 208.84014939661407, 213.75391078293765, 218.70561721181303, 223.69498010684123, 228.7217173772532, 233.78555317854887, 238.8862176853242, 244.02344687550027, 249.1969823252282, 254.40657101380089, 259.6519651379518, 264.93292193496853, 270.2492035140902, 275.60057669569585, 280.98681285782817, 286.40768778962644, 291.8629815512754, 297.35247834010084, 302.87596636247025, 308.4332377111782, 314.02408824801984, 319.64831749127063, 325.3057285078149, 330.99612780967726, 336.7193252547293, 342.47513395135746, 348.26337016688996, 354.08385323959664, 359.93640549408207, 365.8208521599066, 371.73702129327967, 377.6847437016754, 383.66385287123455, 389.67418489681904, 395.71557841459855, 401.7878745370501, 407.8909167902618, 414.0245510534374], [0.0, 0.4190656273186814, 1.1852965873569368, 2.1775288746650423, 3.3525250185494526, 4.685296148590825, 6.158981734020652, 7.761204030303549, 9.482372698855498, 11.314771937604403, 13.252018714143146, 15.288717931860745, 17.42023099732034, 19.642513892065864, 21.952000000000016, 24.34551293359827, 26.820200148395628, 29.373481373511062, 32.00300785863731, 34.706629683678614, 37.48236918872661, 40.32839912518227, 43.24302450106841, 46.22466735413035, 49.27185387216524, 52.383203414835215, 55.557419090522956, 58.79327961595615, 62.08963224242842, 65.44538657537296, 68.85950914724854, 72.33101862963088, 75.858981590844, 79.44250872171655, 83.08075146506567, 86.7728989950204, 90.51817550083526, 94.31583773682983, 98.1651728058379, 102.06549614830674, 106.0161497131452, 110.01650028972936, 114.06593798325609, 118.16387481798327, 122.30974345488599, 126.50299601195232, 130.743102976792, 135.0295522024717, 139.36184797856276, 143.73951017030785, 148.1620734196172, 152.62908640229767, 157.14011113652697, 161.69472233811484, 166.29250681855765, 170.93306292230315, 175.61600000000016, 180.34093791482857, 185.1075065792851, 189.91534552005024, 194.76410346878623, 199.65343797691057, 204.58301505256998, 209.55250881819595, 214.5616011871651, 219.60998155821625, 224.6973465263889, 229.82339960935246, 234.98785098808855, 240.19041726097257, 245.43082121037716, 250.7087915809897, 256.02406286909854, 261.3763751221601, 266.76547374800987, 272.1911093331304, 277.653037469429, 283.1510185890211, 288.6848178065486, 294.2542047685983, 299.858953509813, 305.498842315319, 311.1736535891177, 316.88317372811105, 322.62719300145824, 328.4055054349732, 334.21790870029724, 340.0642040085964, 345.94419600854735, 351.8576926883939, 357.80450528186515, 363.784448177764, 369.79733883304283, 375.84299768919504, 381.9212480918027, 388.03191621308713, 394.174830977322, 400.34982398897137, 406.5567294634297, 412.79538416024025, 419.06562731868183, 425.3673005956152], [0.0, 0.4303405628104327, 1.2171869207315695, 2.2361151580363665, 3.442724502483463, 4.811353759598229, 6.324688767046172, 7.970018757819837, 9.73749536585256, 11.619195195881689, 13.608563480397192, 15.700059968038348, 17.888921264290936, 20.170994546625618, 22.542617239353568, 25.000527494435005, 27.54179601986771, 30.163773122737833, 32.8640468597524, 35.64040946734481, 38.49083007678585, 41.41343227746285, 44.406475473741466, 47.46833924838748, 50.5975101363694, 53.79257035130412, 57.05218810878339, 60.375109266981916, 63.76015006255872, 67.2061907639468, 70.71217009822288, 74.27708033438046, 77.8999629268205, 81.57990463956187, 85.31603408504179, 89.10751862216796, 92.95356156705353, 96.85339967703774, 100.806300874499, 104.811562181851, 108.86850784317757, 112.97648761136107, 117.13487518241534, 121.34306676114635, 125.60047974430681, 129.90655150915222, 134.26073829679336, 138.66251418101444, 143.1113701143275, 147.60681304397855, 152.1483650914463, 156.7355627896874, 161.367956373005, 166.04510911496325, 170.76659671024672, 175.53200669678463, 180.34093791482857, 185.19300000000015, 190.08781290761402, 195.02500646583778, 200.0042199554801, 205.02510171440002, 210.08730876471353, 215.1905064611357, 220.33436815894177, 225.51857490016224, 230.74281511674442, 236.00678434951845, 241.31018498190272, 246.65272598736897, 252.03412268976618, 257.45409653567395, 262.9123748780192, 268.4086907702508, 273.94278277041747, 279.51439475454595, 285.1232757387586, 290.76917970961114, 296.4518654621694, 302.1710964453751, 307.92664061428684, 313.7182702888057, 319.54576201852564, 325.4088964533702, 331.30745821970294, 337.24123580161455, 343.2100214271142, 349.2136109589663, 355.25180378993184, 361.32440274218993, 367.4312139707244, 373.57204687048016, 379.74671398709995, 385.95503093106623, 392.19681629508455, 398.4718915745504, 404.7800810909553, 411.1212119180916, 417.4951138109288, 423.90161913703554, 430.34056281043314, 436.81178222776964], [0.0, 0.44171484014010676, 1.2493582352552053, 2.295217636739489, 3.5337187211208554, 4.938522046118659, 6.491855820949819, 8.180673321921619, 9.994865882041646, 11.926300683782888, 13.968249711399071, 16.115026279842066, 18.361741093915917, 20.704131568360953, 23.13843832241063, 25.661313294529585, 28.26974976896685, 30.96102801910818, 33.732672351890564, 36.58241665062605, 39.508176368949286, 42.508025501074535, 45.58017744590299, 48.72296895715618, 51.934846567598576, 55.21435501751338, 58.56012732226601, 61.970876191966234, 65.44538657537298, 68.9825091454349, 72.58115457885751, 76.2402885094227, 79.9589270563332, 83.73613284598241, 87.5710114592724, 91.46270824767882, 95.41040547026313, 99.41331971119374, 103.47069954339742, 107.58182340897567, 111.7459976911926, 115.96255495633075, 120.230852346642, 124.55027010809742, 128.92021023873656, 133.34009524520383, 137.80936699658716, 142.32748566598104, 146.8939287513274, 151.50819016805676, 156.16977940690077, 160.8782207509769, 165.63305254688768, 170.43382652513577, 175.2801071656452, 180.17147110461207, 185.1075065792851, 190.08781290761402, 195.11200000000025, 200.17968790064612, 205.29050635623676, 210.44409440989332, 215.64010001852645, 220.87817969188382, 226.1579981517349, 231.4792280097722, 236.84154946292708, 242.2446500049075, 247.6882241528655, 253.17197318818714, 258.6956049104819, 264.2588334039189, 269.86137881512457, 275.50296714191694, 281.18333003220545, 286.9022045924363, 292.6593332050085, 298.4544633541274, 304.28734745960145, 310.15774271812114, 316.06541095159434, 322.0101184621381, 327.9916358933567, 334.0097380975595, 340.0642040085964, 346.1548165200078, 352.2813623682074, 358.443632020434, 364.64141956722403, 370.8745226191742, 377.14274220777514, 383.44588269011354, 389.7837516572495, 396.15615984608945, 402.56292105458544, 409.00385206010026, 415.4787725407888, 421.98750499985243, 428.5298746925358, 435.1057095557359, 441.7148401401072, 448.35709954454893], [0.0, 0.4531875991242479, 1.2818080979616258, 2.3548318411300637, 3.625500792993985, 5.066791391008715, 6.660470253668284, 8.393151791788355, 10.25446478369301, 12.2360651763547, 14.331050205759528, 16.533585485308393, 18.838654729040513, 21.241884638609648, 23.739418190006276, 26.32782036173904, 29.004006343951882, 31.765185769958936, 34.60881864496391, 37.532579993919974, 40.534331128069724, 43.61209601704557, 46.76404165595616, 49.98846159865299, 53.283762029346285, 56.648449890531026, 60.08112269257296, 63.58045971051174, 67.14521433430687, 70.77420738517677, 74.46632124658777, 78.22049468649512, 82.03571826954409, 85.91103027551242, 89.84551305435356, 93.83828975956465, 97.88852141083763, 101.99540424450515, 106.15816731650948, 110.37607032776634, 114.64840164607625, 118.97447650231551, 123.35363534164702, 127.7852423130309, 132.26868388246717, 136.80336755723533, 141.38872070996342, 146.0241894927003, 150.70923783232416, 155.44334649961718, 160.22601224520332, 165.0567469962984, 169.93507710887724, 174.860542670438, 179.8326968490437, 184.85110528476713, 189.91534552005024, 195.02500646583778, 200.17968790064612, 205.37900000000022, 210.6225628939124, 215.9100062502896, 221.24096888234803, 226.6150983782857, 232.03205075161517, 237.4914901106987, 242.99308834615053, 248.53652483488244, 254.12148615967155, 259.7476658432182, 265.41476409574534, 271.1224875752658, 276.87054915971135, 282.6586677301798, 288.4865679646111, 294.3539801412581, 300.2606399513599, 306.20628832047225, 312.19067123794747, 318.2135395940911, 324.2746490245579, 330.373759761577, 336.5106364916275, 342.68504821920703, 348.8967681363647, 355.1455734976859, 361.43124550044126, 367.7535691696279, 374.1123332476494, 380.507330088397, 386.9383555555075, 393.40520892459, 399.90769278922403, 406.4456129705429, 413.0187784302311, 419.62700118676867, 426.27009623477045, 432.94788146727365, 439.66017760083804, 446.40680810332674, 453.1875991242484, 460.0023794275422], [0.0, 0.46475800154489, 1.3145341380123987, 2.414953415699774, 3.7180640123591213, 5.196152422706634, 6.830519745963702, 8.607438643406066, 10.516273104099193, 12.548466041712036, 14.696938456699074, 16.95570700383798, 19.319627325598194, 21.78421446827956, 24.345512933598272, 27.00000000000001, 29.744512098872978, 32.5761876222495, 35.49242172633478, 38.49083007678584, 41.56921938165308, 44.72556316023312, 47.9579816089043, 51.26472471397856, 54.64415796770964, 58.09475019311129, 61.615063093370324, 65.20374222389391, 68.85950914724856, 72.58115457885751, 76.36753236814718, 80.21755418859397, 84.13018483279357, 88.10443802669654, 92.13937269159159, 96.2340895940727, 100.38772833369632, 104.59946462578104, 108.86850784317758, 113.19409878611172, 117.57550765359262, 122.0120321935506, 126.50299601195233, 131.04774702374712, 135.64565603070386, 140.29611541307915, 144.99853792366335, 149.7523555741279, 154.5570186047856, 159.4119945298974, 164.31676725154995, 169.27083623589758, 174.27371574623652, 179.32493412796802, 184.42403314102003, 189.5705673357551, 194.76410346878623, 200.0042199554801, 205.29050635623676, 210.6225628939124, 216.00000000000017, 221.42243788740132, 226.88950614781655, 232.4008433719639, 237.95609679098393, 243.55492193753773, 249.19698232522825, 254.88194914508975, 260.60950097799605, 266.37932352192826, 272.1911093331304, 278.04455758025574, 283.9393738106783, 289.875269728206, 295.85196298148867, 301.8691769624719, 307.92664061428684, 314.0240882480199, 320.1612593678383, 326.33789850398955, 332.55375505322473, 338.8085831262251, 345.10214140164396, 351.43419298639714, 357.8045052818651, 364.21284985568565, 370.65900231884325, 377.1427422077751, 383.6638528712345, 390.2221213616679, 396.8173383308752, 403.4492979297402, 410.1177977118286, 416.82263854066315, 423.56362450049977, 430.3405628104331, 437.1532637416773, 444.00154053786844, 450.8852093382532, 457.8040891036256, 464.7580015448905, 471.7467710541329], [0.0, 0.4764252302303059, 1.3475340440968462, 2.47557811429977, 3.811401841842449, 5.326596004954761, 7.001992287913494, 8.823518742542575, 10.780272352774771, 12.863481216218267, 15.06588862297874, 17.381361022658737, 19.804624914398165, 22.33108275476137, 24.956679747113814, 27.677804735925154, 30.4912147347396, 33.393976298129004, 36.383419190614866, 39.457099221813074, 42.612768039638105, 45.848348290859974, 49.161912981494154, 52.551668165720535, 56.015938303307976, 59.553153778788285, 63.161840188518944, 66.84060908609382, 70.58814994034061, 74.40322310894878, 78.28465366851928, 82.23132597131102, 86.2421788221982, 90.31620118782683, 94.45242836475946, 98.64993854534333, 102.90784972974616, 107.22531694054358, 111.60152970277792, 116.03570975781561, 120.52710898382995, 125.0750074995002, 129.67871193067901, 134.3375538224514, 139.05088818126993, 143.8180921337786, 148.63856369058485, 153.51172060464975, 158.43699931518537, 163.41385396899508, 168.44175551210589, 173.52019084533092, 178.648662038091, 183.8266855954273, 189.05379177366441, 194.32952394065103, 199.65343797691057, 205.02510171440002, 210.44409440989332, 215.9100062502896, 221.42243788740132, 226.98100000000022, 232.58531288110197, 238.2350060486496, 243.9297178779169, 249.6690952540985, 255.45279324368354, 261.2804747833258, 267.1518103850321, 273.0664778565838, 279.02416203619384, 285.024554540482, 291.067353524919, 297.1522634559599, 303.2789948941406, 309.44726428747146, 315.6567937745047, 321.9073109965044, 328.1985489181819, 334.530245656503, 340.90214431710496, 347.3139928378933, 353.7655438394196, 360.2565544816642, 366.7867863268799, 373.35600520816627, 379.96398110347286, 386.61048801474635, 393.29530385195335, 400.0182103217307, 406.7789928204262, 413.57744033131246, 420.4133453257644, 427.28650366820665, 434.19671452465, 441.14378027464056, 448.127506426464, 455.14770153544714, 462.2041771252186, 469.2967476117861, 476.4252302303064, 483.58944496442496], [0.0, 0.48818848818873223, 1.3808055619818456, 2.5367017956393703, 3.9055079055098596, 5.4581132271142945, 7.174876166178762, 9.041377328703856, 11.046444495854768, 13.181089181095778, 15.437875501506035, 17.810518465221623, 20.293614365114966, 22.88245214132438, 25.57287688157124, 28.361188268477058, 31.244063244078884, 34.218495934216655, 37.28175017350985, 40.43132142287712, 43.66490581691437, 46.980374711149366, 50.375753532825726, 53.84920404239978, 57.399009329430115, 61.023561023591576, 64.72134831722842, 68.49094848226302, 72.33101862963088, 76.24028850942268, 80.21755418859397, 84.26167247331381, 88.37155596683817, 92.54616867272256, 96.78452206835563, 101.08567158603644, 105.44871344876626, 109.87278181606226, 114.35704620179739, 118.90070913161125, 123.50300401204831, 128.16319318743595, 132.88056616375485, 137.65443798149056, 142.484147721773, 147.369057132086, 152.30854935951575, 157.30202778095406, 162.34891492091978, 167.44865144873532, 172.6006952477308, 177.80452054995695, 183.0596171305951, 188.36548955687206, 193.72165648682665, 199.1276500137539, 204.58301505256998, 210.08730876471353, 215.64010001852645, 221.24096888234803, 226.88950614781655, 232.58531288110197, 238.3280000000002, 244.11718787500425, 249.95250595263118, 255.83359239943474, 261.7600937652646, 267.7316646644549, 273.7479674737333, 279.8086720457394, 285.9134554371307, 292.0620016503348, 298.25400138807885, 304.48915181989685, 310.76715635987046, 317.08772445492144, 323.45057138301706, 329.85541806070154, 336.3019908594064, 342.7900214300297, 349.3192465353151, 355.8894078895861, 362.50025200543007, 369.15153004694463, 375.84299768919504, 382.57441498354314, 389.3455462285401, 396.1561598460894, 403.0060282626059, 409.8949277949171, 416.82263854066315, 423.7889442729722, 430.7936323391983, 437.83649356352237, 444.9173221532293, 452.0359156084839, 459.1920746354411, 466.3856030625308, 473.6163077597735, 480.88399856098397, 488.1884881887328, 495.5295921819408], [0.0, 0.5000469977912076, 1.4143464922005502, 2.598320419039963, 4.000375982329663, 5.590695395029139, 7.349159951994518, 9.261000000000006, 11.314771937604405, 13.501268940362614, 15.812874501494036, 18.243150961388235, 20.786563352319707, 23.43828617881437, 26.194063602274486, 29.050105421495477, 32.00300785863731, 35.04969202432458, 38.187355289414874, 41.41343227746286, 44.72556316023313, 48.121567586686155, 51.599423020030024, 55.157246568334116, 58.793279615956166, 62.505874723901, 66.29348438572231, 70.15465131407902, 74.08800000000008, 78.09222933813588, 82.16610615089418, 86.30845947530295, 90.51817550083527, 94.79419306582031, 99.13549963559986, 103.54112769812785, 108.01015152290094, 112.54168423744166, 117.13487518241536, 121.7889075121377, 126.50299601195232, 131.27638510790902, 136.1083470474902, 140.99818023293787, 145.9452076911059, 150.94877566578683, 156.00825232018994, 161.12302653872925, 166.2925068185577, 171.51612024238437, 176.7933115250689, 182.12354212731552, 187.506289430515, 192.94104596741485, 198.42731870385205, 203.96462836727372, 209.55250881819595, 215.1905064611357, 220.87817969188382, 226.6150983782857, 232.4008433719639, 238.2350060486496, 244.11718787500425, 250.04700000000028, 256.0240628690986, 262.0480058596137, 268.11846693579344, 274.2350923222631, 280.3975361945967, 286.6054603858764, 292.8585341081939, 299.1564336881295, 305.49884231531905, 311.8854498032895, 318.3159523618007, 324.79005237999553, 331.307458219703, 337.8678840182953, 344.47104950053534, 351.1166797988957, 357.80450528186515, 364.5342613897907, 371.3056884778367, 378.1185316656674, 384.97254069348935, 391.8674697841099, 398.80307751069364, 405.7791266699168, 412.7953841602403, 419.8516208650389, 426.9476115403392, 434.0831347069365, 441.25797254667305, 448.4719108026727, 455.72473868334214, 463.01624876995453, 470.3462369276495, 477.7145022196841, 485.12084682478917, 492.5650759574825, 500.0469977912082, 507.56642338417214], [0.0, 0.512, 1.4481546878700498, 2.6604300404257972, 4.096000000000002, 5.724334022399464, 7.524832489829928, 9.4823726988555, 11.585237502960402, 13.824000000000009, 16.190861620062112, 18.679230819281628, 21.28344032340638, 23.99854928948833, 26.82020014839563, 29.74451209887298, 32.76800000000002, 35.88751136537615, 39.100176572491364, 42.403368922763704, 45.79467217919573, 49.27185387216523, 52.832843118651155, 56.47571201853064, 60.19865991863944, 64.00000000000006, 67.87814776494722, 71.83161109149654, 75.85898159084402, 79.9589270563332, 84.13018483279359, 88.37155596683819, 92.68190002368324, 97.06013047590662, 101.5052105854671, 106.01614971314521, 110.5920000000001, 115.23185337396959, 119.93483884176453, 124.70012003201934, 129.52689296049692, 134.4143839921905, 139.36184797856276, 144.36856655103298, 149.43384655425305, 154.55701860478558, 159.7374357625665, 164.9744723040509, 170.2675225872511, 175.61600000000018, 181.01933598375635, 186.4769791261111, 191.9883943159067, 197.5530619555164, 203.17047722540812, 208.84014939661407, 214.5616011871651, 220.33436815894177, 226.1579981517349, 232.03205075161517, 237.95609679098393, 243.9297178779169, 249.95250595263118, 256.0240628690986, 262.1440000000003, 268.311937863376, 274.5275057694587, 280.79034148631285, 287.10009092300925, 293.4564078291701, 299.858953509813, 306.30739655450736, 312.80141257993097, 319.3406839849884, 325.9248997177114, 332.5537550532248, 339.22695138210975, 345.9441960085474, 352.7052019576693, 359.5096877915813, 366.35737743356594, 373.24800000000033, 380.1812896395618, 387.15698537931655, 394.17483097732196, 401.23457478138687, 408.33596959366724, 415.47877254078867, 422.66274494920935, 429.8876522255558, 437.1532637416772, 444.45935272418376, 451.80569614824526, 459.1920746354411, 466.61827235546673, 474.0840769315085, 481.5892793491157, 489.13367386840235, 496.71705793942755, 504.3392321206041, 512.0000000000006, 519.6991681194041], [0.0, 0.5240467536394057, 1.4822280526288796, 2.7230268085349447, 4.192374029115247, 5.859020822628985, 7.701882886671288, 9.705481698504206, 11.85782442103104, 14.14926234826396, 16.571813419176557, 19.118730998682953, 21.78421446827956, 24.5632067328352, 27.451247694777024, 30.444365242192205, 33.538992232921984, 36.73190200629423, 40.020157420979764, 43.40106997528981, 46.87216658103189, 50.431162241217514, 54.07593734740068, 57.80451863825185, 61.615063093370324, 65.50584420492575, 69.47524019389934, 73.52172383044353, 77.64385358803368, 81.84026591476845, 86.10966844669656, 90.45083402047773, 94.86259536824835, 99.34384039788281, 103.8935079781216, 108.51058416117763, 113.19409878611171, 117.94312241500147, 122.75676356111717, 127.63416617426553, 132.57450735341249, 137.5769952608358, 142.6408672155355, 147.76538794656898, 152.94984798946365, 158.19356221098263, 163.49586844932824, 168.85612625842168, 174.27371574623655, 179.7480364983163, 185.27850657861006, 190.86456160062838, 196.50565386268167, 202.20125154162642, 207.95083794012484, 213.75391078293765, 219.60998155821625, 225.51857490016224, 231.4792280097722, 237.4914901106987, 243.55492193753773, 249.6690952540985, 255.83359239943474, 262.0480058596137, 268.311937863376, 274.6250000000002, 280.98681285782817, 287.39700568203585, 293.8552160503539, 300.361089565543, 306.9142795635292, 313.5144468361868, 320.16125936783817, 326.85439208461037, 333.5935266158506, 340.3783510668683, 347.2085598023186, 354.08385323959664, 361.00393765165535, 367.9685249787001, 374.97733264825524, 382.03008340312704, 389.1265051368261, 396.26633073603455, 403.4492979297402, 410.67514914467404, 417.9436313667195, 425.2544960079792, 432.60749877920557, 440.002399567321, 447.4389623177673, 454.9169549214454, 462.4361491060149, 469.9963203313409, 477.59724768888736, 485.2387138048657, 492.92050474696276, 500.64240993447663, 508.40422205170614, 516.2057369644399, 524.0467536394062, 531.9270740665497], [0.0, 0.5361865347059734, 1.5165645386860398, 2.786106961335119, 4.289492277647789, 5.994747701113036, 7.8803005018844345, 9.930313590214567, 12.132516309488324, 14.477036437061289, 16.95570700383798, 19.561625085866474, 22.288855690680954, 25.13222457324462, 28.087168315798607, 31.149622790653517, 34.31593822118232, 37.582813199652875, 40.9472425445231, 44.40647547374147, 47.957981608904305, 51.59942302003002, 55.32863099698026, 59.14358656693054, 63.0424040150755, 67.02331683824673, 71.08466568817785, 75.22488795604822, 79.44250872171656, 83.7361328459824, 88.10443802669654, 92.54616867272256, 97.06013047590662, 101.64518558200392, 106.30024827816736, 111.02428112804883, 115.81629149649034, 120.67532841471792, 125.60047974430682, 130.59086960427223, 135.64565603070386, 140.76402884259898, 145.9452076911059, 151.1884402723966, 156.49300068693182, 161.85818793005203, 167.28332450068075, 172.76775511651488, 178.3108455254477, 183.91198140414906, 189.5705673357551, 195.2860258595071, 201.05779658595705, 206.8853353720367, 212.7681135508798, 218.70561721181303, 224.6973465263889, 230.74281511674442, 236.84154946292708, 242.99308834615053, 249.19698232522825, 255.45279324368354, 261.7600937652646, 268.11846693579344, 274.5275057694587, 280.98681285782817, 287.4960000000003, 294.0546878524473, 300.66250559722306, 307.3190906273156, 314.0240882480199, 320.7771513933002, 327.57794035618485, 334.4261225323169, 341.32137217584284, 348.26337016689, 355.2518037899319, 362.2863665223966, 369.3667578329164, 376.4926829886609, 383.66385287123455, 390.87998380065494, 398.1407973669621, 405.446020269037, 412.79538416024025, 420.1886255005011, 427.62548541451594, 435.1057095557359, 442.6290479758422, 450.19525499942847, 457.8040891036257, 465.45531280242193, 473.1486925354444, 480.883998560984, 488.66100485305816, 496.4794890023157, 504.33923212060415, 512.2400187490242, 520.1816367693121, 528.163877318395, 536.1865347059739, 544.2494063350008], [0.0, 0.5484186357154541, 1.5511621449738906, 2.8496668226303243, 4.387349085723636, 6.131506747937251, 8.0600749376169, 10.156855271194924, 12.409297159791128, 14.80730316431727, 17.34252000143002, 20.007887269774404, 22.797334581042602, 25.705569649397013, 28.72792495116905, 31.860243643136208, 35.09879268578909, 38.44019535590321, 41.881377914295065, 45.419526824924134, 49.05205398349802, 52.77656812450014, 56.590851062693915, 60.492837766135644, 64.48059950093523, 68.55232946443182, 72.70633045340693, 76.94100421101878, 81.25484216955942, 85.64641736231594, 90.11437732126885, 94.65743781129942, 99.27437727832906, 103.96403191007946, 108.72529122517918, 113.55709412009459, 118.45842531453819, 123.42831214514776, 128.46582166475267, 133.5700580107684, 138.7401600114402, 143.97529900298886, 149.2746768343514, 154.63752403928368, 160.06309815819526, 165.5506821943058, 171.0995831906088, 176.7091309157511, 182.37867664834087, 188.10759205040097, 193.89526812173645, 199.74111422789272, 205.64455719517616, 211.60504046690406, 217.62202331565638, 223.69498010684123, 229.82339960935246, 236.00678434951845, 242.2446500049075, 248.53652483488244, 254.88194914508975, 261.2804747833258, 267.7316646644549, 274.2350923222631, 280.79034148631285, 287.39700568203585, 294.0546878524473, 300.7630000000003, 307.5215628472257, 314.330005514905, 321.1879652166317, 328.09508696870216, 335.05102331436063, 342.05543406149866, 349.10798603297553, 356.20835282879074, 363.3562145993932, 370.5512578294672, 377.7931751315795, 385.08166504911696, 392.4164318679843, 399.79718543656645, 407.2236409934969, 414.69551900279845, 422.2125449960012, 429.7744494208565, 437.3809674963011, 445.0318390733414, 452.7268085015515, 460.46562450089635, 468.24804003861084, 476.07381221088025, 483.94270212908526, 491.8544748103859, 499.808899072436, 507.8057474320279, 515.844796007482, 523.9258244246037, 532.048615726045, 540.2129562839091, 548.4186357154548, 556.665446801758], [0.0, 0.5607423650840019, 1.586018915397922, 2.9137027988454847, 4.485938920672017, 6.269290230959166, 8.241196029703461, 10.385093933133206, 12.68815132318338, 15.140043857268058, 17.732230542151214, 20.45749231944132, 23.30962239076388, 26.283209545259137, 29.373481373511062, 32.57618762224949, 35.88751136537614, 39.30400000000004, 42.82251071574392, 46.44016675249996, 50.154321847673344, 53.96253100068606, 57.862526180594685, 61.852195951316126, 65.9295682376277, 70.09279563550028, 74.34014280319893, 78.66997556882811, 83.08075146506569, 87.57101145927237, 92.13937269159157, 96.78452206835561, 101.50521058546708, 106.30024827816735, 111.16849971102437, 116.10887993603255, 121.12035085814449, 126.20191795689965, 131.3526273205071, 136.57156295510435, 141.85784433720974, 147.2106241818166, 152.62908640229767, 158.1124442414323, 163.6599385555306, 169.27083623589755, 174.94442875381904, 180.68003081691143, 186.4769791261111, 192.33463122381283, 198.2523644247404, 204.22957482206166, 210.26567636207315, 216.36009998148944, 222.5122928019935, 228.7217173772532, 234.98785098808855, 241.31018498190272, 247.6882241528655, 254.12148615967155, 260.60950097799605, 267.1518103850321, 273.7479674737333, 280.3975361945967, 287.10009092300925, 293.8552160503539, 300.66250559722306, 307.5215628472257, 314.43200000000036, 321.3934378421567, 328.40550543497324, 335.4678398177689, 342.5800857259514, 349.7418953228227, 356.95292794428826, 364.21284985568576, 371.52133401999987, 378.8780598767898, 386.2827131311992, 393.7349855524656, 401.23457478138687, 408.7811841462377, 416.37452248666756, 424.01430398513725, 431.7002480054886, 439.4320789382591, 447.20952605238676, 455.0323233529685, 462.9002094447576, 470.81292740110746, 478.77022463808305, 486.77185279348316, 494.8175676105291, 502.9071288259897, 511.04030006252987, 519.216848725078, 527.4365459010219, 535.6991662640522, 544.0044879814878, 552.3522926249158, 560.7423650840025, 569.1744934833262], [0.0, 0.5731570465413471, 1.6211329371769612, 2.9782113759772004, 4.58525637233078, 6.408090589247318, 8.423653839041588, 10.615017051328751, 12.969063497415693, 15.475240256616383, 18.12481724045791, 20.910415562585086, 23.825691007817607, 26.865112562578272, 30.023802157621564, 33.297415440241025, 36.682050978646245, 40.17417973026957, 43.770589303777975, 47.46833924838748, 51.26472471397856, 55.1572465683341, 59.14358656693053, 63.22158652707165, 67.38923071233273, 71.64463081766844, 75.98601308135603, 80.41170715138443, 84.92013641063004, 89.50980952387293, 94.17931301512033, 98.92730471917254, 103.75250797932559, 108.65370648532898, 113.62973966352305, 118.67949854545233, 123.80192205293109, 128.9959936470898, 134.26073829679336, 139.5952197283275, 144.99853792366332, 150.46982683913757, 156.00825232018994, 161.61301019101168, 167.28332450068072, 173.01844590967764, 178.81765020265777, 184.6802369150529, 190.60552806254094, 196.59286696368227, 202.6416171471203, 208.75116133569196, 214.92090050062626, 221.15025297973347, 227.43865365412296, 233.78555317854887, 240.19041726097257, 246.65272598736897, 253.17197318818714, 259.7476658432182, 266.37932352192826, 273.0664778565838, 279.8086720457394, 286.6054603858764, 293.4564078291701, 300.361089565543, 307.3190906273156, 314.330005514905, 321.3934378421567, 328.50900000000036, 335.67631283723347, 342.89500535732543, 350.16471443022385, 357.4850845182219, 364.85576741501603, 372.27642199715024, 379.74671398709995, 387.2663157273045, 394.83490596450605, 402.45216964379796, 410.1177977118286, 417.83148692864245, 425.59293968767906, 433.4018638434777, 441.25797254667293, 449.1609840858847, 457.11062173613993, 465.1066136134816, 473.14869253544435, 481.23659588709637, 489.3700654923639, 497.54884749037507, 505.7726922165733, 514.0413540883657, 522.3545914950884, 530.7121666920785, 539.113845698662, 547.5593981998672, 556.0485974516982, 564.5812201897976, 573.1570465413478, 581.7758599400639], [0.0, 0.5856620185738529, 1.6565023392678928, 3.0431891166997835, 4.685296148590825, 6.5479004268544, 8.607438643406068, 10.846612374377546, 13.252018714143146, 15.812874501494036, 18.520259177452143, 21.36663286528789, 24.345512933598272, 27.451247694777024, 30.678852651297134, 34.023888666641284, 37.48236918872661, 41.05068817937164, 44.72556316023313, 48.50398952663588, 52.383203414835215, 56.36065116728163, 60.43396396067368, 64.60093652571925, 68.85950914724856, 73.20775232173166, 77.64385358803368, 82.16610615089418, 86.77289899502041, 91.46270824767882, 96.2340895940727, 101.08567158603644, 106.0161497131452, 111.02428112804883, 116.10887993603257, 121.268812973493, 126.50299601195232, 131.81039033399466, 137.18999963554208, 142.64086721553554, 148.16207341961717, 153.7527333090376, 159.4119945298974, 165.13903536111636, 170.93306292230315, 176.79331152506887, 182.71904115335124, 188.709536060052, 194.76410346878626, 200.88207237083174, 207.06279240848673, 213.3056328370165, 219.60998155821628, 225.9752442193616, 232.4008433719639, 238.8862176853242, 245.43082121037716, 252.03412268976618, 258.6956049104819, 265.41476409574534, 272.1911093331304, 279.02416203619384, 285.9134554371307, 292.8585341081939, 299.858953509813, 306.9142795635292, 314.0240882480199, 321.1879652166317, 328.40550543497324, 335.67631283723347, 343.00000000000034, 350.37618783244994, 357.8045052818651, 365.28458905352176, 372.81608334405354, 380.39863958747316, 388.0319162130872, 395.71557841459855, 403.4492979297403, 411.23275282983036, 419.06562731868183, 426.9476115403391, 434.8784013951491, 442.85769836370736, 450.88520933825316, 458.9606464611104, 467.0837269698019, 475.2541730484862, 483.4717116853896, 491.73607453592473, 500.0469977912081, 508.4042220517061, 516.8074922057541, 525.2565573127104, 533.7511704905204, 542.2910888074786, 550.8760731779887, 559.505888262135, 568.1803023688877, 576.8990873627732, 585.6620185738535, 594.4688747108639], [0.0, 0.5982566338955215, 1.6921252908694442, 3.10863265761653, 4.786053071164174, 6.688712506902957, 8.79254092967443, 11.079867914375159, 13.537002326955559, 16.152929115179088, 18.918535884153414, 21.82612061269709, 24.869061260932245, 28.04158460215829, 31.3385989476237, 34.75556969753195, 38.2884245693134, 41.933479977221104, 45.68738285347502, 49.54706397961441, 53.509700055223675, 57.57268250654997, 61.73359156893438, 65.99017454894333, 70.34032743739547, 74.78207923694023, 79.31357850960963, 83.93308175564634, 88.63894331500131, 93.42960654417857, 98.30359606850614, 103.25951094693417, 108.2960186156445, 113.41184949995315, 118.60579220257343, 123.8766891913084, 129.22343292143273, 134.6449623379948, 140.14025971147635, 145.70834776703785, 151.34828707322734, 157.05917366075772, 162.84013684592645, 168.69033723660655, 174.60896490157674, 180.5952376863799, 186.64839966096702, 192.76771968615512, 198.95249008745805, 205.20202542616408, 211.5156613586807, 217.8927535761575, 224.33267681726642, 230.83482394777468, 237.3986051012097, 244.02344687550027, 250.7087915809897, 257.45409653567395, 264.2588334039189, 271.1224875752658, 278.04455758025574, 285.024554540482, 292.0620016503348, 299.1564336881295, 306.30739655450736, 313.5144468361868, 320.7771513933002, 328.09508696870216, 335.4678398177689, 342.89500535732543, 350.37618783244994, 357.9110000000004, 365.49906282780023, 373.1400052085012, 380.8334636872137, 388.57908220206645, 396.3765118369154, 404.2254105854806, 412.12544312624084, 420.07628060746345, 428.0776004417895, 436.12908610983555, 444.2304269723096, 452.38131809017096, 460.5814600523999, 468.8305588109636, 477.12832552260033, 485.474476397061, 493.8687325514752, 502.31081987052653, 510.80046887214246, 519.3374145784228, 527.9213963915468, 536.5521579744141, 545.2294471357914, 553.9530157197455, 562.7226194991639, 571.5380180731644, 580.3989747682199, 589.3052565428216, 598.2566338955221, 607.2528807762059], [0.0, 0.610940258945177, 1.7280000000000002, 3.174538706647, 4.887522071561418, 6.830519745963701, 8.978951386437064, 11.314771937604403, 13.824000000000005, 16.495386991519787, 19.31962732559819, 22.28885569068095, 25.396309653176004, 28.636093588337094, 32.003007858637304, 35.49242172633478, 39.10017657249136, 42.82251071574392, 46.65600000000003, 50.59751013636939, 54.64415796770963, 58.793279615956145, 63.04240401507548, 67.38923071233272, 71.83161109149654, 76.36753236814718, 80.9951038520231, 85.71254507946902, 90.51817550083527, 95.41040547026311, 100.3877283336963, 105.44871344876624, 110.59200000000008, 115.81629149649034, 121.1203508581445, 126.5029960119523, 131.96309593215832, 137.49956706840945, 143.1113701143275, 148.79750707589167, 154.55701860478555, 160.38898156669006, 166.29250681855765, 172.2667371723283, 178.31084552544763, 184.42403314102, 190.6055280625409, 196.85458364996245, 203.17047722540812, 209.55250881819592, 216.00000000000017, 222.5122928019935, 229.08874870669683, 235.7287477080386, 242.43168743380082, 249.1969823252282, 256.02406286909854, 262.9123748780192, 269.86137881512457, 276.87054915971135, 283.9393738106783, 291.067353524919, 298.25400138807885, 305.49884231531905, 312.80141257993097, 320.16125936783817, 327.57794035618485, 335.05102331436063, 342.5800857259514, 350.16471443022385, 357.8045052818651, 365.49906282780023, 373.2480000000003, 381.0509378232788, 388.9075051371473, 396.8173383308752, 404.78008109095526, 412.79538416024025, 420.86290510806526, 428.98230811071954, 437.15326374167716, 445.3754487710344, 453.64854597364297, 461.97224394545657, 470.3462369276493, 478.77022463808294, 487.2439121097363, 495.76700953572987, 504.339232120604, 512.9602999375297, 521.6299377911514, 530.3478750857785, 539.1138456986619, 547.9275878581043, 556.7888440261718, 565.6973607857832, 574.6528887319726, 583.655182367124, 592.7040000000006, 601.7991036483859, 610.9402589451777, 620.127235047777], [0.0, 0.6237122734081798, 1.764124712144808, 3.240904040541776, 4.98969818726544, 6.973315208708125, 9.166660896967887, 11.551312955677384, 14.112997697158468, 16.840231382020864, 19.723513885715203, 22.75481546837945, 25.927232324334216, 29.234745577822313, 32.67204689027, 36.23440871602573, 39.917585498123536, 43.71773691535283, 47.63136722790984, 51.6552766230131, 55.78652166966502, 60.022382800085545, 64.36033728935863, 68.79803659262384, 73.33328717574312, 77.96403417602254, 82.68834737736637, 87.50440909462799, 92.4105036454191, 97.40500815153202, 102.48638446154696, 107.6531720247946, 112.90398157726779, 118.23748952426224, 123.65243292390178, 129.14760499134326, 134.72185105616694, 140.37406491585273, 146.10318553679807, 151.90819406141344, 157.78811108572165, 163.7419941768148, 169.7689356036612, 175.8680602582517, 182.03852374703564, 188.27951063511944, 194.59023282785824, 200.96992807631713, 207.4178585946738, 213.93330977900587, 220.51558901810114, 227.1640245879618, 233.87796462257856, 240.65677615434006, 247.49984421813303, 254.40657101380089, 261.3763751221601, 268.4086907702508, 275.50296714191694, 282.6586677301798, 289.875269728206, 297.1522634559599, 304.48915181989685, 311.8854498032895, 319.3406839849884, 326.85439208461037, 334.4261225323169, 342.05543406149866, 349.7418953228227, 357.4850845182219, 365.28458905352176, 373.1400052085012, 381.0509378232788, 389.01700000000045, 397.0378128188804, 405.11300506772227, 413.242212984105, 421.4250800094845, 429.66125655451, 437.9503997749065, 446.2921733573203, 454.68624731456345, 463.13229778973584, 471.6300068687323, 480.17906240068453, 488.7791578259045, 497.42999201093664, 506.1312690903424, 514.8826983148691, 523.6839939056765, 532.5348749143108, 541.435065088142, 550.3842927409909, 559.3822906286904, 568.4287958293463, 577.5235496280656, 586.6662974059452, 595.856788533118, 605.0947762656697, 614.3800176462454, 623.7122734081804, 633.0913078829949], [0.0, 0.6365720697611543, 1.8004977089682734, 3.307725502516799, 5.092576558089237, 7.1170921028184, 9.355660532533237, 11.789479717103726, 14.403981671746191, 17.187445883551177, 20.130176352928466, 23.223977781594623, 26.461804020134398, 29.83751209467708, 33.34568421850122, 36.98149537268607, 40.740612464713905, 44.619115993036026, 48.61343814214341, 52.720313125018556, 56.93673682254722, 61.25993359447923, 65.68732870196509, 70.21652517748232, 74.84528426026593, 79.57150872014435, 84.39322854352719, 89.3085885679536, 94.31583773682985, 99.41331971119371, 104.59946462578102, 109.87278181606224, 115.23185337396957, 120.67532841471791, 126.20191795689965, 131.81039033399463, 137.49956706840945, 143.2683191497689, 149.1155636679151, 155.04026075829478, 161.04141082342775, 167.11805199917828, 173.26925783877547, 179.49413519109768, 185.79182225275702, 192.16148677609687, 198.60232441741482, 205.1135572116092, 211.69443216107524, 218.34421992807617, 225.06221362103432, 231.8477276662424, 238.70009675741673, 245.6186748763215, 252.6028343783975, 259.6519651379518, 266.76547374800987, 273.94278277041747, 281.18333003220545, 288.4865679646111, 295.85196298148867, 303.2789948941406, 310.76715635987046, 318.3159523618007, 325.9248997177114, 333.5935266158506, 341.32137217584284, 349.10798603297553, 356.95292794428826, 364.85576741501603, 372.81608334405354, 380.8334636872137, 388.9075051371473, 397.0378128188804, 405.2240000000004, 413.4656878146001, 421.76250500014856, 430.1140876465224, 438.52007895648336, 446.98012901694005, 455.4938945803779, 464.0610388558819, 472.6812313092202, 481.35414747148536, 490.079468755834, 498.856882281883, 507.6860807073604, 516.5667620666283, 525.4986296157208, 534.4813916835652, 543.5147615290689, 552.5984572037825, 561.7322014198587, 570.9157214230491, 580.1487488704951, 589.4310197130794, 598.7622740821276, 608.1422561802467, 617.5707141761184, 627.047400103055, 636.572069761155, 646.1444826228891], [0.0, 0.649519052838329, 1.8371173070873839, 3.3750000000000018, 5.196152422706635, 7.26184377413891, 9.545941546018398, 12.029261199259087, 14.696938456699076, 17.537014426634894, 20.53959590644374, 23.696320916969384, 27.000000000000018, 30.444365242192212, 34.02388866664129, 37.73364712030897, 41.569219381653085, 45.526606231960706, 49.60216729135939, 53.79257035130413, 58.094750193111295, 62.505874723900995, 67.02331683824673, 71.64463081766846, 76.36753236814721, 81.18988160479118, 86.10966844669657, 91.12500000000007, 96.23408959407273, 101.43524720234095, 106.72687103068287, 112.1074400965432, 117.57550765359265, 123.12969534194433, 128.76868796411662, 134.49122880321983, 140.29611541307918, 146.18219582083188, 152.14836509144632, 158.1935622109827, 164.31676725154995, 170.51699878604495, 176.7933115250689, 183.14479415205898, 189.57056733575513, 196.06978190175064, 202.64161714712031, 209.2852792840435, 216.00000000000023, 222.78503512354706, 229.63966338592314, 236.56318526981352, 243.55492193753776, 250.6142142317553, 257.74042174249684, 264.93292193496853, 272.1911093331304, 279.51439475454595, 286.9022045924363, 294.3539801412581, 301.8691769624719, 309.44726428747146, 317.08772445492144, 324.79005237999553, 332.5537550532248, 340.3783510668683, 348.26337016689, 356.20835282879074, 364.21284985568576, 372.27642199715024, 380.39863958747316, 388.57908220206645, 396.8173383308752, 405.11300506772227, 413.4656878146001, 421.87500000000045, 430.3405628104332, 438.86200493435337, 447.4389623177674, 456.0710779308423, 464.75800154489053, 473.49938951914226, 482.2949045967628, 491.14421570960246, 500.0469977912081, 509.00293159764857, 518.011703535741, 527.0730054982902, 536.1865347059739, 545.351993555539, 554.5690894739813, 563.8375347784153, 573.1570465413479, 582.5273464610917, 591.9481607370706, 601.4192199497791, 610.9402589451779, 620.511016723314, 630.1312363309733, 639.8006647581736, 649.5190528383297, 659.2861551519197], [0.0, 0.6625526394181824, 1.8739818569025692, 3.442724502483464, 5.300421115345461, 7.407563702054816, 9.737495365852562, 12.270646600729734, 14.99185485522056, 17.888921264290932, 20.951754103177148, 24.171823596907224, 27.541796019867714, 31.055277683511402, 34.706629683678614, 38.49083007678584, 42.403368922763704, 46.44016675249997, 50.597510136369394, 54.872000000000035, 59.26050961643855, 63.760150062558715, 68.36824151607242, 73.08228918144265, 77.89996292682052, 82.81907992727285, 87.8375897665687, 92.95356156705355, 98.16517280583791, 103.4706995433974, 108.86850784317757, 114.35704620179739, 119.9348388417645, 125.60047974430681, 131.3526273205071, 137.18999963554205, 143.1113701143275, 149.1155636679151, 155.20145318907308, 161.367956373005, 167.6140328254172, 173.93868142538065, 180.3409379148286, 186.81987269024688, 193.37458877525782, 200.0042199554801, 206.70792905933746, 213.48490637045066, 220.3343681589418, 227.25555532043677, 234.24773211282132, 241.31018498190275, 248.44222146809128, 255.6431691870529, 262.91237487801925, 270.2492035140902, 277.653037469429, 285.1232757387586, 292.6593332050085, 300.2606399513599, 307.92664061428684, 315.6567937745047, 323.45057138301706, 331.307458219703, 339.22695138210975, 347.2085598023186, 355.2518037899319, 363.3562145993932, 371.52133401999987, 379.74671398709995, 388.0319162130872, 396.3765118369154, 404.78008109095526, 413.242212984105, 421.76250500014856, 430.3405628104332, 438.97600000000045, 447.6684378063752, 456.4175048702673, 465.22283699749784, 474.0840769315085, 483.0008741358554, 491.97288458613303, 500.9997705708063, 510.08120050046983, 519.216848725078, 528.4063953587244, 537.6495261115746, 546.9459321285794, 556.2953098346243, 565.6973607857833, 575.1517915263767, 584.6583134515414, 594.2166426750439, 603.8264999020835, 613.4876103068428, 623.1997034145644, 632.9625129879344, 642.7757769175819, 652.6392371164952, 662.552639418183, 672.515733478408], [0.0, 0.6756722578291934, 1.9110897414825923, 3.510896039474825, 5.40537806263355, 7.554245495084207, 9.930313590214567, 12.51362533401093, 15.288717931860743, 18.24315096138823, 21.366632865287887, 24.650464965188807, 28.087168315798607, 31.670222623151883, 35.39387732362762, 39.25301103100247, 43.243024501068405, 47.35975748459871, 51.59942302003002, 55.95855472579688, 60.43396396067368, 65.02270459616399, 69.72204374514568, 74.52943721107795, 79.44250872171656, 84.45903222864924, 89.57691671407323, 94.79419306582031, 100.10900267208748, 105.5195874565477, 111.02428112804881, 116.62150146092281, 122.30974345488598, 128.0875732497108, 133.9536226908404, 139.9065844590598, 145.94520769110588, 152.06829402936052, 158.27469404803804, 164.56330401094908, 170.93306292230312, 177.38294983735065, 183.91198140414903, 190.51920961152462, 197.2037197215105, 203.9646283672737, 210.80108179988093, 217.7122542692535, 224.6973465263889, 231.75558443541357, 238.8862176853242, 246.08851859239618, 253.36178098521512, 260.70531916514506, 268.1184669357934, 275.60057669569585, 283.1510185890211, 290.76917970961114, 298.4544633541274, 306.20628832047225, 314.0240882480199, 321.9073109965044, 329.85541806070154, 337.8678840182953, 345.9441960085474, 354.08385323959664, 362.2863665223966, 370.5512578294672, 378.8780598767898, 387.2663157273045, 395.71557841459855, 404.2254105854806, 412.79538416024025, 421.4250800094845, 430.1140876465224, 438.86200493435337, 447.6684378063752, 456.53300000000047, 465.455312802422, 474.4350048078245, 483.4717116853896, 492.5650759574824, 501.7147467874555, 510.9203797765368, 520.181636769312, 529.4981856673359, 538.8697002504414, 548.2958600053448, 557.7763499611656, 567.3108605315085, 576.8990873627732, 586.5407311883811, 596.2354976886237, 605.9830973558593, 615.7832453647962, 625.6356614476198, 635.5400697737327, 645.49619883389, 655.5037813285297, 665.562554060098, 675.6722578291941, 685.8326373343581], [0.0, 0.6888773475735721, 1.9484393755003009, 3.579511698542137, 5.5110187805885795, 7.701882886671289, 10.124387981502888, 12.75818701853834, 15.58751500400241, 18.599688384486456, 21.78421446827956, 25.132224573244624, 28.636093588337104, 32.28917378936788, 36.08560222581857, 40.02015742097977, 44.08815024470864, 48.28533914139989, 52.60786313850815, 57.05218810878339, 61.61506309337033, 66.29348438572231, 71.08466568817785, 75.98601308135603, 80.99510385202314, 86.10966844669657, 91.32757498149185, 96.64681586063773, 102.06549614830676, 107.58182340897565, 113.19409878611172, 118.90070913161126, 124.70012003201933, 130.59086960427223, 136.57156295510438, 142.6408672155355, 148.7975070758917, 155.0402607582948, 161.36795637300503, 167.77946861281941, 174.27371574623652, 180.84965687553867, 187.50628943051504, 194.24264687241077, 201.05779658595705, 207.95083794012487, 214.9209005006263, 221.96714237922717, 229.0887487066969, 236.28493021773548, 243.55492193753776, 250.89798196079644, 258.3133903149431, 265.8004479003001, 273.3584755005781, 280.98681285782817, 288.6848178065486, 296.4518654621694, 304.28734745960145, 312.19067123794747, 320.1612593678383, 328.1985489181819, 336.3019908594064, 344.47104950053534, 352.7052019576693, 361.00393765165535, 369.3667578329164, 377.7931751315795, 386.2827131311992, 394.83490596450605, 403.4492979297403, 412.12544312624084, 420.86290510806526, 429.66125655451, 438.52007895648336, 447.4389623177674, 456.4175048702673, 465.455312802422, 474.5520000000006, 483.7071877985694, 492.92050474696276, 502.1915863811345, 511.520075007815, 520.9056194974294, 530.3478750857786, 539.8465031840075, 549.4011711964224, 559.011552345746, 568.6773255054229, 578.3981750386154, 588.1737906435485, 598.0038672048876, 607.8881046508485, 617.8262078157586, 627.8178863078058, 637.8628543817243, 647.9608308161853, 658.1115387956673, 668.3147057966038, 678.5700634776051, 688.8773475735728, 699.2362977935294], [0.0, 0.7021673589679315, 1.9860292042162928, 3.6485686234467365, 5.6173388717434545, 7.85046973116896, 10.319710461054617, 13.004321474033167, 15.888233633730348, 18.95851869213416, 22.20448152963722, 25.617082367045644, 29.188548987573895, 32.912105417308105, 36.78177559607477, 40.79223731299868, 44.93871097394764, 49.216873194058195, 53.622788513839936, 58.15285462468721, 62.803757849351705, 67.57243653295333, 72.45605062380925, 77.45195615993188, 82.55768368843698, 87.7709198709915, 93.08949169482028, 98.51135283306192, 104.03457179226538, 109.65732155674796, 115.37787049516912, 121.19457433812795, 127.10586906984283, 133.11026460419959, 139.20633913726786, 145.39273408599217, 151.66814953707333, 158.0313401417581, 164.48111140188726, 171.01631630052162, 177.6358522370978, 184.33865823261291, 191.12371237499565, 197.9900294787595, 204.9366589363652, 211.96268274156202, 219.06721366740413, 226.2493935837179, 233.50839190059125, 240.84340412600073, 248.25365052703677, 255.73837488535062, 263.2968433384649, 270.9283432994787, 278.6321824484748, 286.40768778962644, 294.2542047685983, 302.1710964453751, 310.15774271812114, 318.2135395940911, 326.33789850398955, 334.530245656503, 342.7900214300297, 351.1166797988957, 359.5096877915813, 367.9685249787001, 376.4926829886609, 385.08166504911696, 393.7349855524656, 402.45216964379796, 411.23275282983036, 420.07628060746345, 428.98230811071954, 437.9503997749065, 446.98012901694005, 456.0710779308423, 465.22283699749784, 474.4350048078245, 483.7071877985694, 493.0390000000005, 502.4300627948138, 511.8800046876225, 521.38846108444, 530.955074081603, 540.5794922636268, 550.2613705095067, 560.0003698070213, 569.7961570746162, 579.6484049904741, 589.5567918284046, 599.5210013002053, 609.5407224041727, 619.6156492794553, 629.7454810659627, 639.9299217695644, 650.1686801323183, 660.4614695074961, 670.808007739175, 681.2080170461891, 691.6612239102326, 702.1673589679323, 712.7261569067051], [0.0, 0.7155417527999327, 2.023857702507763, 3.718064012359122, 5.724334022399464, 8.000000000000004, 10.516273104099195, 13.252018714143148, 16.190861620062112, 19.319627325598194, 22.627416997969533, 26.10501867457675, 29.744512098872985, 33.53899223292199, 37.482369188726615, 41.56921938165308, 45.79467217919572, 50.15432184767335, 54.64415796770964, 59.26050961643854, 64.00000000000004, 68.85950914724854, 73.83614291117873, 78.92720696946023, 84.13018483279359, 89.44271909999165, 94.86259536824836, 100.38772833369633, 106.01614971314523, 111.7459976911926, 117.57550765359264, 123.50300401204832, 129.52689296049692, 135.6456560307039, 141.85784433720977, 148.1620734196172, 154.55701860478558, 161.0414108234278, 167.61403282541727, 174.27371574623655, 181.0193359837563, 187.84981235018594, 194.76410346878623, 201.76120538894503, 208.84014939661407, 216.00000000000017, 223.2398530728779, 230.55883414000883, 237.95609679098396, 245.43082121037716, 252.98221281347057, 260.6095009779961, 268.311937863376, 276.0887973098513, 283.9393738106784, 291.8629815512754, 299.858953509813, 307.92664061428684, 316.06541095159434, 324.2746490245579, 332.55375505322473, 340.90214431710496, 349.3192465353151, 357.80450528186515, 366.35737743356594, 374.97733264825524, 383.66385287123455, 392.4164318679843, 401.23457478138687, 410.1177977118286, 419.06562731868183, 428.0776004417895, 437.15326374167716, 446.2921733573203, 455.4938945803779, 464.75800154489053, 474.0840769315085, 483.4717116853896, 492.92050474696276, 502.4300627948138, 512.0000000000006, 521.6299377911514, 531.3195046297479, 541.0683357950275, 550.8760731779886, 560.7423650840024, 570.6668660435795, 580.6492366308603, 590.68914328943, 600.7862581650822, 610.9402589451777, 621.1508287042695, 631.4176557556821, 641.740433508752, 652.118860331459, 662.552639418183, 673.041478662349, 683.5850905337251, 694.1831919601634, 704.8355042135726, 715.5417527999334, 726.3016673531745], [0.0, 0.7289999999999999, 2.0619233739399725, 3.787995116153136, 5.832000000000002, 8.150467777986735, 10.714068134933626, 13.50126894036261, 16.495386991519787, 19.683000000000007, 23.053004142627493, 26.596014193859965, 30.303960929225095, 34.16980943757224, 38.18735528941487, 42.35107289077812, 46.65600000000003, 51.0976480182797, 55.67193109637929, 60.3751092669819, 65.20374222389391, 70.15465131407899, 75.2248879560482, 80.41170715138443, 85.71254507946904, 91.12500000000006, 96.6468158606377, 102.2758681361347, 108.01015152290093, 113.84776918763063, 119.78692332637989, 125.82590683559575, 131.96309593215832, 138.19694358776545, 144.52597366563575, 150.9487756657868, 157.4640000000001, 164.070353729734, 170.76659671024672, 177.551538092465, 184.42403314101998, 191.38298033263058, 198.42731870385202, 205.55602542129495, 212.76811355087978, 220.06263000564195, 227.43865365412296, 234.89529357354115, 242.43168743380085, 250.0470000000002, 257.7404217424968, 265.51116754479483, 273.35847550057804, 281.28160579213164, 289.279839643208, 297.35247834010084, 305.498842315319, 313.7182702888057, 322.0101184621381, 330.373759761577, 338.8085831262251, 347.3139928378933, 355.8894078895861, 364.5342613897907, 373.24800000000033, 382.03008340312704, 390.87998380065494, 399.79718543656645, 408.7811841462377, 417.83148692864245, 426.9476115403391, 436.12908610983555, 445.3754487710344, 454.68624731456345, 464.0610388558819, 473.49938951914226, 483.0008741358554, 492.5650759574824, 502.1915863811345, 511.8800046876225, 521.6299377911514, 531.4410000000004, 541.3128127875791, 551.2450045732846, 561.2372105126321, 571.2890722961542, 581.4002379566082, 591.5703616840525, 601.7991036483859, 612.0861298289651, 622.4311118509427, 632.8337268279881, 643.2936572110756, 653.81059064304, 664.3842198186234, 675.0142423497454, 685.7003606357525, 696.4422817384087, 707.2397172614113, 718.0923832342193, 729.0000000000007, 739.9622921075108], [0.0, 0.7425415813272683, 2.100224749877975, 3.858359236774101, 5.940332650618149, 8.301867259839806, 10.913087922306875, 13.752062536216169, 16.801797999023808, 20.048622695836254, 23.481226543773236, 27.09004998149692, 30.86687389419281, 34.80453269331456, 38.896706698639704, 43.13776767520548, 47.5226612049452, 52.04681531083344, 56.70606824670536, 61.49661057326661, 66.41493807871846, 71.45781306477276, 76.62223217839592, 81.90539943129522, 87.30470337845503, 92.81769766590861, 98.44208433388648, 104.17569939290075, 110.0165002897294, 115.96255495633075, 122.0120321935506, 128.16319318743598, 134.4143839921905, 140.764028842599, 147.21062418181663, 153.7527333090376, 160.3889815666901, 167.1180519991783, 173.93868142538068, 180.84965687553867, 187.8498123501859, 194.9380258646324, 202.11321674744602, 209.37434316553708, 216.7203998519754, 224.15041601567484, 231.6634534146466, 239.2586045767218, 246.93499115354257, 254.69176239525328, 262.5280937347471, 270.4431854715518, 278.43626154651656, 286.50656839940024, 294.65337390228575, 302.87596636247025, 311.1736535891177, 319.54576201852564, 327.9916358933567, 336.5106364916275, 345.10214140164396, 353.7655438394196, 362.50025200543007, 371.3056884778367, 380.1812896395618, 389.1265051368261, 398.1407973669621, 407.2236409934969, 416.37452248666756, 425.59293968767906, 434.8784013951491, 444.2304269723096, 453.64854597364297, 463.13229778973584, 472.6812313092202, 482.2949045967628, 491.97288458613303, 501.7147467874555, 511.520075007815, 521.38846108444, 531.3195046297479, 541.3128127875791, 551.3680000000007, 561.4846877840934, 571.6625045181822, 581.9010852370021, 592.2000714353223, 602.5591108795891, 612.9778574271676, 623.4559708527948, 633.9931166818777, 644.588966030292, 655.2431954503619, 665.9554867827137, 676.725527013723, 687.5530081382824, 698.4376270276405, 709.3790853020699, 720.3770892081462, 731.4313495004171, 742.5415813272691, 753.7075041207972], [0.0, 0.7561659870689769, 2.1387603886363715, 3.9291537256768176, 6.049327896551818, 8.454192746797299, 11.113324975001863, 14.004390061691378, 17.110083109090976, 20.416481650862387, 23.912068082873983, 27.587107441701843, 31.43322980541455, 35.44313810880749, 39.61039671601387, 43.92927412329963, 48.39462317241455, 53.00178799814215, 57.74653049318206, 62.62497132135076, 67.63354197437842, 72.76894534758634, 78.02812298139698, 83.40822758577245, 88.90659980001493, 94.52074838362218, 100.2483332130765, 106.08715059327412, 112.03512049353107, 118.09027539556348, 124.2507505007516, 130.51477509079203, 136.88066487272786, 143.3468151686672, 149.91169483399233, 156.573840806822, 163.33185320689913, 170.18439091467835, 177.1301675717608, 184.16794795240583, 191.2965446629919, 198.51481513227188, 205.82165886028633, 213.21601489803732, 220.69685953361477, 228.26320416352718, 235.91409333060227, 243.64860291206293, 251.46583844331647, 259.36493356465934, 267.3450485795466, 275.40536911432963, 283.54510487046, 291.76348846111676, 300.0597743250504, 308.4332377111782, 316.88317372811105, 325.4088964533702, 334.0097380975595, 342.68504821920703, 351.43419298639714, 360.2565544816642, 369.15153004694463, 378.1185316656674, 387.15698537931655, 396.26633073603455, 405.446020269037, 414.69551900279845, 424.01430398513725, 433.4018638434777, 442.85769836370736, 452.38131809017096, 461.97224394545657, 471.6300068687323, 481.35414747148536, 491.14421570960246, 500.9997705708063, 510.9203797765368, 520.9056194974294, 530.955074081603, 541.0683357950275, 551.2450045732846, 561.4846877840934, 571.7870000000006, 582.1515627806909, 592.5780044643918, 603.0659599678967, 613.6150705947507, 624.2249838511759, 634.8953532693407, 645.6258382375979, 656.4161038373455, 667.2658206861798, 678.1746647870303, 689.1423173829925, 700.1684648175759, 711.2527984001197, 722.3950142761239, 733.5948133022761, 744.85190092595, 756.1659870689776, 767.5367860154987], [0.0, 0.7698727167525811, 2.1775288746650414, 4.000375982329663, 6.158981734020651, 8.607438643406066, 11.314771937604405, 14.258242247907006, 17.420230997320335, 20.7865633523197, 24.34551293359827, 28.087168315798603, 32.00300785863731, 36.08560222581856, 40.32839912518227, 44.72556316023312, 49.271853872165224, 53.96253100068606, 58.79327961595615, 63.76015006255871, 68.85950914724854, 74.08800000000005, 79.44250872171655, 84.92013641063004, 90.51817550083527, 96.2340895940727, 102.06549614830674, 108.01015152290093, 114.06593798325609, 120.23085234664197, 126.5029960119523, 132.88056616375485, 139.36184797856274, 145.94520769110588, 152.62908640229765, 159.41199452989738, 166.29250681855765, 173.26925783877547, 180.34093791482857, 187.506289430515, 194.7641034687862, 202.11321674744596, 209.55250881819592, 217.08089950062413, 224.69734652638888, 232.40084337196387, 240.1904172609726, 248.0651273194201, 256.02406286909854, 264.0663418461356, 272.1911093331304, 280.3975361945967, 288.6848178065486, 297.05217287203976, 305.49884231531905, 314.02408824801984, 322.62719300145824, 331.30745821970294, 340.0642040085964, 348.8967681363647, 357.8045052818651, 366.7867863268799, 375.84299768919504, 384.97254069348935, 394.17483097732196, 403.4492979297402, 412.79538416024025, 422.2125449960012, 431.7002480054886, 441.25797254667293, 450.88520933825316, 460.5814600523999, 470.3462369276493, 480.17906240068453, 490.079468755834, 500.0469977912081, 510.08120050046983, 520.181636769312, 530.3478750857786, 540.5794922636268, 550.8760731779886, 561.2372105126321, 571.6625045181822, 582.1515627806909, 592.7040000000005, 603.319437777369, 613.9975044118671, 624.7378347050872, 635.5400697737325, 646.4038568696824, 657.3288492071536, 668.3147057966036, 679.3610912850404, 690.4676758024237, 701.6341348138651, 712.8601489773439, 724.1454040066824, 735.4895905395272, 746.8924040101099, 758.3535445265626, 769.8727167525819, 781.4496297932461], [0.0, 0.7836612788698953, 2.216528817768901, 4.0720234527811865, 6.269290230959166, 8.761599454437532, 11.517421586448945, 14.513609992004064, 17.732230542151214, 21.158854529487186, 24.78154555309254, 28.590214672156645, 32.5761876222495, 36.73190200629422, 41.05068817937163, 45.52660623196069, 50.15432184767334, 54.929009867282375, 59.84627807976035, 64.90210609063473, 70.09279563550028, 75.41492972217111, 80.86533868104436, 86.44107169048758, 92.13937269159159, 97.95765985873699, 103.8935079781216, 109.94463322509208, 116.10887993603257, 122.38420905084129, 128.76868796411657, 135.2604815716698, 141.85784433720974, 148.55911323442947, 155.36270144407263, 162.26709270520638, 169.27083623589755, 176.37254215154937, 183.57087731990623, 190.86456160062838, 198.25236442474036, 205.73310167544764, 213.30563283701647, 220.96885838280485, 228.7217173772532, 236.56318526981343, 244.49227186150512, 252.50801942710675, 260.60950097799605, 268.7958186523744, 277.06610222111277, 285.41950769875587, 293.8552160503539, 302.37243198578835, 310.9703828341216, 319.64831749127063, 328.4055054349732, 337.24123580161455, 346.1548165200078, 355.1455734976859, 364.21284985568565, 373.35600520816627, 382.57441498354314, 391.8674697841099, 401.23457478138687, 410.67514914467404, 420.1886255005011, 429.7744494208565, 439.4320789382591, 449.1609840858847, 458.9606464611104, 468.8305588109636, 478.77022463808294, 488.7791578259045, 498.856882281883, 509.00293159764857, 519.216848725078, 529.4981856673359, 539.8465031840075, 550.2613705095067, 560.7423650840024, 571.2890722961542, 581.9010852370021, 592.5780044643918, 603.319437777369, 614.1250000000006, 624.994312774125, 635.9270043605641, 646.922709448355, 657.9810689715935, 669.1017299334989, 680.2843452373432, 691.5285735239008, 702.834079015098, 714.2005313635667, 725.6276055078121, 737.114981532733, 748.6623445352393, 760.2693844947337, 771.9357961482297, 783.6612788698963, 795.4455365548301], [0.0, 0.7975311906126304, 2.2557588523598886, 4.144093628285927, 6.380249524901047, 8.916669781930924, 11.721266825731771, 14.770484352247905, 18.046070818879116, 21.533342146541035, 25.22015067361812, 29.09622889654261, 33.15274902628742, 37.38201481996391, 41.77723858753714, 46.332375289855385, 51.041996199208384, 55.90119075654834, 60.90548901371702, 66.05079941984053, 71.33335825544741, 76.74968805148336, 82.29656303880503, 87.97098016959919, 93.7701346058542, 99.69139882657888, 105.73230469445002, 111.89052796372006, 118.16387481798328, 124.55027010809742, 131.04774702374712, 137.65443798149056, 144.36856655103296, 151.1884402723966, 158.1124442414323, 165.13903536111636, 172.26673717232833, 179.49413519109768, 186.8198726902469, 194.24264687241077, 201.76120538894503, 209.37434316553708, 217.08089950062416, 224.8797554071955, 232.76983117234093, 240.75008411213503, 248.81950650220358, 256.97712366668, 265.22199221029945, 273.5531983801325, 281.96985654498627, 290.47110778182423, 299.0561185597114, 307.72407951280024, 316.47420429475795, 325.3057285078149, 334.21790870029724, 343.2100214271142, 352.2813623682074, 361.43124550044126, 370.65900231884325, 379.96398110347286, 389.3455462285401, 398.80307751069364, 408.33596959366724, 417.9436313667195, 427.62548541451594, 437.3809674963011, 447.20952605238676, 457.11062173613993, 467.0837269698019, 477.12832552260033, 487.2439121097363, 497.42999201093664, 507.6860807073604, 518.011703535741, 528.4063953587244, 538.8697002504414, 549.4011711964224, 560.0003698070213, 570.6668660435795, 581.4002379566082, 592.2000714353223, 603.0659599678967, 613.9975044118671, 624.994312774125, 636.0560000000006, 647.1821877709559, 658.3725043104404, 669.6265841974921, 680.9440681876896, 692.3246030410886, 703.7678413567937, 715.2734414138421, 726.8410670180938, 738.4703873548357, 750.1610768468339, 761.9128150175723, 773.7252863594425, 785.5981802066507, 797.5311906126313, 809.5240162317617], [0.0, 0.811481977618727, 2.2952176367394888, 4.21658404398632, 6.4918558209498185, 9.072644322357187, 11.926300683782888, 15.028856543330244, 18.361741093915914, 21.91001339570564, 25.661313294529585, 29.605193682865874, 33.732672351890564, 38.03591843245017, 42.508025501074535, 47.142842775971864, 51.93484656759856, 56.87904041912105, 61.97087619196623, 67.2061907639468, 72.58115457885751, 78.09222933813588, 83.7361328459824, 89.50980952387295, 95.41040547026314, 101.43524720234095, 107.58182340897565, 113.84776918763066, 120.230852346642, 126.72896143739217, 133.34009524520383, 140.06235351799583, 146.89392875132737, 153.8330988799226, 160.8782207509769, 168.02772427489472, 175.28010716564518, 182.63393019644533, 190.08781290761402, 197.6404297126478, 205.29050635623673, 213.03681668434706, 220.8781796918838, 228.8134568179942, 236.84154946292702, 244.9613967036441, 253.17197318818714, 261.4722871912053, 269.86137881512457, 278.33831832322363, 286.90220459243625, 295.5521636750443, 304.2873474596014, 313.1069324224557, 322.0101184621381, 330.99612780967726, 340.0642040085964, 349.2136109589663, 358.443632020434, 367.7535691696279, 377.1427422077751, 386.61048801474635, 396.1561598460894, 405.7791266699168, 415.47877254078867, 425.2544960079792, 435.1057095557359, 445.0318390733414, 455.0323233529685, 465.1066136134816, 475.2541730484862, 485.474476397061, 495.76700953572987, 506.1312690903424, 516.5667620666283, 527.0730054982902, 537.6495261115746, 548.2958600053448, 559.011552345746, 569.7961570746162, 580.6492366308603, 591.5703616840525, 602.5591108795891, 613.6150705947507, 624.7378347050872, 635.9270043605641, 647.1821877709559, 658.5030000000008, 669.8890627678594, 681.3400042614562, 692.8554589522992, 704.4350674214062, 716.0784761909838, 727.7853375625269, 739.555309461031, 751.3880552850179, 763.2832437621054, 775.2405488098526, 787.2596494016453, 799.3402294373789, 811.4819776187278, 823.6845873287916], [0.0, 0.8255131737289236, 2.334903852410202, 4.289492277647789, 6.604105389831392, 9.229517863897337, 12.132516309488324, 15.288717931860745, 18.67923081928162, 22.28885569068095, 26.105018674576748, 30.117092024297456, 34.31593822118232, 38.69359099385843, 43.24302450106841, 47.9579816089043, 52.83284311865115, 57.86252618059469, 63.04240401507549, 68.3682415160724, 73.83614291117873, 79.44250872171655, 85.18400000000007, 91.05750833401942, 97.06013047590662, 103.18914671611553, 109.44200232086409, 115.81629149649035, 122.309743454886, 128.92021023873653, 135.64565603070386, 142.484147721773, 149.43384655425302, 156.49300068693182, 163.6599385555306, 170.93306292230315, 178.31084552544763, 185.79182225275704, 193.37458877525782, 201.05779658595705, 208.84014939661404, 216.7203998519754, 224.6973465263889, 232.7698311723409, 240.93673619437968, 249.19698232522822, 257.5495264837428, 265.9933597968192, 274.5275057694587, 283.1510185890211, 291.8629815512754, 300.66250559722306, 309.5487279508675, 318.5208108491504, 327.57794035618485, 336.7193252547293, 345.94419600854735, 355.25180378993184, 364.64141956722403, 374.1123332476494, 383.6638528712345, 393.29530385195335, 403.0060282626059, 412.7953841602403, 422.66274494920935, 432.60749877920557, 442.6290479758422, 452.7268085015515, 462.9002094447576, 473.14869253544435, 483.4717116853896, 493.8687325514752, 504.339232120604, 514.8826983148691, 525.4986296157208, 536.1865347059739, 546.9459321285794, 557.7763499611656, 568.6773255054229, 579.6484049904741, 590.68914328943, 601.7991036483859, 612.9778574271676, 624.2249838511759, 635.5400697737325, 646.922709448355, 658.3725043104404, 669.8890627678594, 681.4720000000008, 693.1209377648327, 704.8355042135726, 716.615333712586, 728.4600666721556, 740.3693493817807, 752.3428338516964, 764.3801776603061, 776.4810438072533, 788.6451005718615, 800.8720213767001, 813.1614846560316, 825.5131737289245, 837.9267766768179], [0.0, 0.8396243207530378, 2.374816203414488, 4.36281594844431, 6.716994566024305, 9.387285283829403, 12.339906968855162, 15.550060032038472, 18.99852962731591, 22.669856660332034, 26.551252324513825, 30.63190720474325, 34.90252758755449, 39.35501102782214, 43.98221158604923, 48.777765170208475, 53.73595652819446, 58.851615925138425, 64.12003749219122, 69.53691372932802, 75.09828227063525, 80.80048210871028, 86.64011722060407, 92.6140260597714, 98.71925575084133, 104.9530400941298, 111.3127806857776, 117.7960306079964, 124.40048025630782, 131.12394495667078, 137.96435409191764, 144.91974150887808, 151.98823701852734, 159.1680588340514, 166.45750681780638, 173.85495642920293, 181.3588532826563, 188.96770823873604, 196.68009296316717, 204.49463589786427, 212.41001859611066, 220.42497238062683, 228.53827528884545, 236.7487492744156, 245.05525763794606, 253.456702663394, 261.952023439408, 270.54019384742105, 279.22022070043596, 287.99114201829224, 296.8520254268112, 305.80196666960825, 314.8400882225772, 323.9655380021157, 333.1774881590895, 342.47513395135746, 351.8576926883939, 361.32440274218993, 370.8745226191742, 380.507330088397, 390.2221213616679, 400.0182103217307, 409.8949277949171, 419.8516208650389, 429.8876522255558, 440.002399567321, 450.19525499942847, 460.46562450089635, 470.81292740110746, 481.23659588709637, 491.73607453592473, 502.31081987052653, 512.9602999375297, 523.6839939056765, 534.4813916835652, 545.351993555539, 556.2953098346243, 567.3108605315085, 578.3981750386154, 589.5567918284046, 600.7862581650822, 612.0861298289651, 623.4559708527948, 634.8953532693407, 646.4038568696824, 657.9810689715935, 669.6265841974921, 681.3400042614562, 693.1209377648327, 704.9690000000008, 716.8838127618736, 728.8650041667531, 740.9122084781715, 753.0250659393758, 765.2032226121381, 777.4463302215795, 789.754046006731, 802.1260325765531, 814.5619577711702, 827.061494528068, 839.6243207530387, 852.2501191956513], [0.0, 0.8538149682454624, 2.4149534156997734, 4.436552715791848, 6.830519745963702, 9.545941546018396, 12.548466041712038, 15.812874501494036, 19.319627325598194, 23.053004142627497, 27.000000000000014, 31.149622790653524, 35.49242172633479, 40.02015742097977, 44.72556316023313, 49.602167291359386, 54.64415796770963, 59.84627807976037, 65.20374222389391, 70.71217009822288, 76.3675323681472, 82.16610615089418, 88.10443802669654, 94.17931301512034, 100.38772833369634, 106.72687103068289, 113.19409878611174, 119.78692332637993, 126.50299601195235, 133.34009524520383, 140.29611541307915, 147.36905713208603, 154.55701860478558, 161.85818793005205, 169.27083623589758, 176.79331152506887, 184.42403314102003, 192.16148677609692, 200.00421995548012, 207.95083794012487, 216.00000000000017, 224.15041601567484, 232.4008433719639, 240.75008411213503, 249.19698232522825, 257.7404217424968, 266.3793235219283, 275.11264420233425, 283.93937381067843, 292.8585341081939, 301.8691769624719, 310.97038283412166, 320.1612593678382, 329.4409400787951, 338.80858312622513, 348.26337016688996, 357.80450528186515, 367.4312139707244, 377.14274220777514, 386.9383555555075, 396.8173383308752, 406.7789928204262, 416.82263854066315, 426.9476115403392, 437.1532637416772, 447.4389623177673, 457.8040891036257, 468.24804003861084, 478.77022463808305, 489.3700654923639, 500.0469977912081, 510.80046887214246, 521.6299377911514, 532.5348749143108, 543.5147615290689, 554.5690894739813, 565.6973607857833, 576.8990873627732, 588.1737906435485, 599.5210013002053, 610.9402589451777, 622.4311118509427, 633.9931166818777, 645.6258382375979, 657.3288492071536, 669.1017299334989, 680.9440681876896, 692.8554589522992, 704.8355042135726, 716.8838127618736, 729.0000000000008, 741.1836877589799, 753.434504120963, 765.752083248881, 778.13606522253, 790.586095880772, 803.101826669571, 815.6829144955788, 828.329021585023, 841.0398153476453, 853.8149682454633, 866.6541576661373], [0.0, 0.8680846732894205, 2.455314236508232, 4.510700278227319, 6.944677386315367, 9.705481698504205, 12.758187018538338, 16.077153137293937, 19.64251389206586, 23.438286178814366, 27.45124769477702, 31.670222623151883, 36.08560222581856, 40.68900941286236, 45.47305602222048, 50.43116224121751, 55.55741909052295, 60.84648159918539, 66.2934843857223, 71.89397394079705, 77.64385358803366, 83.53933822457543, 89.57691671407322, 95.75332034451868, 102.06549614830674, 108.51058416117763, 115.08589790239297, 121.78890751213767, 128.61722509835153, 135.56859193412032, 142.64086721553548, 149.83201814365324, 157.14011113652694, 164.56330401094905, 172.0998390005059, 179.74803649831628, 187.50628943051498, 195.37305818100936, 203.3468659999462, 211.42629483817777, 219.60998155821622, 227.89661447902225, 236.28493021773542, 244.77371079631914, 253.36178098521512, 262.0480058596136, 270.8312885469479, 279.71056814679014, 288.6848178065486, 297.7530429382715, 306.9142795635292, 316.1675927747817, 325.512075302899, 334.94684618159977, 344.47104950053523, 354.08385323959664, 363.784448177764, 373.57204687048016, 383.44588269011354, 393.40520892459, 403.4492979297402, 413.57744033131246, 423.7889442729722, 434.0831347069365, 444.45935272418376, 454.9169549214454, 465.45531280242193, 476.07381221088025, 486.77185279348316, 497.54884749037507, 508.4042220517061, 519.3374145784228, 530.3478750857785, 541.435065088142, 552.5984572037825, 563.8375347784153, 575.1517915263767, 586.5407311883811, 598.0038672048876, 609.5407224041727, 621.1508287042695, 632.8337268279881, 644.588966030292, 656.4161038373455, 668.3147057966036, 680.2843452373432, 692.3246030410886, 704.4350674214062, 716.615333712586, 728.8650041667531, 741.1836877589799, 753.5710000000007, 766.0265627561497, 778.550004076168, 791.140958024549, 803.7990645211036, 816.5239691864542, 829.3153231931758, 842.1727831223243, 855.0960108251011, 868.0846732894214, 881.1384425111652], [0.0, 0.8824330002895405, 2.4958974337900997, 4.585256372330781, 7.059464002316327, 9.865900871182525, 12.969063497415696, 16.342887872098995, 19.9671794703208, 23.825691007817607, 27.904981634109724, 32.19369081046784, 36.68205097864625, 41.36154658617111, 46.22466735413035, 51.26472471397855, 56.47571201853063, 61.85219595131613, 67.38923071233272, 73.08228918144265, 78.92720696946023, 84.92013641063002, 91.05750833401942, 97.3360000000001, 103.7525079793256, 110.30412503619264, 116.98812028577956, 123.8019220529311, 130.743102976792, 137.80936699658713, 144.99853792366335, 152.30854935951575, 159.73743576256646, 167.28332450068075, 174.94442875381904, 182.71904115335124, 190.6055280625409, 198.60232441741482, 206.70792905933746, 214.92090050062626, 223.23985307287785, 231.66345341464657, 240.1904172609726, 248.81950650220355, 257.5495264837428, 266.37932352192826, 275.3077826142955, 284.33382532509245, 293.4564078291701, 302.6745190993127, 311.98717922376267, 321.3934378421567, 330.8923726893689, 340.4830882378746, 350.1647144302239, 359.93640549408207, 369.79733883304283, 379.74671398709995, 389.7837516572495, 399.90769278922403, 410.1177977118286, 420.4133453257644, 430.7936323391983, 441.25797254667305, 451.80569614824526, 462.4361491060149, 473.1486925354444, 483.94270212908526, 494.8175676105291, 505.7726922165733, 516.8074922057541, 527.9213963915468, 539.1138456986619, 550.3842927409909, 561.7322014198587, 573.1570465413479, 584.6583134515414, 596.2354976886237, 607.8881046508485, 619.6156492794553, 631.4176557556821, 643.2936572110756, 655.2431954503619, 667.2658206861798, 679.3610912850404, 691.5285735239008, 703.7678413567937, 716.0784761909838, 728.4600666721556, 740.9122084781715, 753.434504120963, 766.0265627561497, 778.688000000001, 791.4184377533805, 804.2175040323367, 817.0848328050163, 830.0200638346051, 843.0228425280076, 856.0928197900049, 869.2296518826321, 882.4330002895415, 895.7025315851253], [0.0, 0.8968595207723449, 2.53670179563937, 4.660218771688731, 7.174876166178762, 10.027194273574244, 13.18108918109578, 16.610070770469353, 20.293614365114966, 24.215207060853324, 28.36118826847706, 32.72001172065807, 37.281750173509856, 42.03774885742578, 46.98037471114937, 52.10282981758287, 57.39900932943011, 62.863391103248695, 68.49094848226302, 74.27708033438046, 80.21755418859397, 86.30845947530294, 92.54616867272256, 98.92730471917254, 105.44871344876627, 112.10744009654319, 118.90070913161125, 125.82590683559577, 132.88056616375488, 140.06235351799583, 147.36905713208603, 154.7985768248534, 162.34891492091978, 170.01816817328685, 177.80452054995695, 185.70623676925894, 193.72165648682665, 201.84918905212396, 210.08730876471355, 218.43455057064597, 226.88950614781655, 235.45082033622248, 244.11718787500425, 252.88735041318319, 261.7600937652646, 270.73424538650465, 279.80867204573946, 288.98227767633114, 298.25400138807896, 307.6228156249146, 317.08772445492144, 326.6477619807003, 336.3019908594063, 346.0495009229175, 355.88940788958615, 365.8208521599066, 375.84299768919504, 385.95503093106623, 396.15615984608945, 406.4456129705429, 416.82263854066315, 427.28650366820665, 437.83649356352237, 448.4719108026727, 459.1920746354411, 469.9963203313409, 480.883998560984, 491.8544748103859, 502.9071288259897, 514.0413540883657, 525.2565573127104, 536.5521579744141, 547.9275878581043, 559.3822906286904, 570.9157214230491, 582.5273464610917, 594.2166426750439, 605.9830973558593, 617.8262078157586, 629.7454810659627, 641.740433508752, 653.81059064304, 665.9554867827137, 678.1746647870303, 690.4676758024237, 702.834079015098, 715.2734414138421, 727.7853375625269, 740.3693493817807, 753.0250659393758, 765.752083248881, 778.550004076168, 791.4184377533805, 804.3570000000009, 817.3653127506706, 830.4430039894378, 843.5897075901305, 856.805063162562, 870.0887159043046, 883.4403164577682, 896.8595207723458, 910.3459899713966], [0.0, 0.91136381319427, 2.5777261297507934, 4.735585285896563, 7.290910505554162, 10.18935719267904, 13.394257874178779, 16.87869402530896, 20.62180903800635, 24.6068229562453, 28.819854267501093, 33.249169974602395, 37.8846822871725, 42.71759646796625, 47.74015601147532, 52.94545306256245, 58.32728404443331, 63.88003750781622, 69.59860550327146, 75.4783124877604, 81.51485754143235, 87.70426685173311, 94.04285423146203, 100.52718800404207, 107.15406299343027, 113.92047664928381, 120.82360855395781, 127.86080271920723, 135.02955220247173, 142.32748566598104, 149.7523555741279, 157.30202778095406, 164.97447230405086, 172.76775511651488, 180.68003081691143, 188.709536060052, 196.85458364996245, 205.1135572116092, 213.4849063704507, 221.96714237922714, 230.5588341400088, 239.25860457672178, 248.06512731942013, 256.9771236666799, 265.9933597968192, 275.1126442023342, 284.33382532509245, 293.655789372524, 303.07745829738013, 312.59778792563486, 322.21576621884935, 331.9304116588298, 341.7407717437301, 351.6459215859048, 361.64496260282715, 371.73702129327967, 381.9212480918027, 392.19681629508455, 402.56292105458544, 413.0187784302311, 423.56362450049977, 434.19671452465, 444.9173221532293, 455.72473868334214, 466.61827235546673, 477.59724768888736, 488.66100485305816, 499.808899072436, 511.04030006252987, 522.3545914950884, 533.7511704905204, 545.2294471357914, 556.7888440261718, 568.4287958293463, 580.1487488704951, 591.9481607370706, 603.8264999020835, 615.7832453647962, 627.8178863078058, 639.9299217695644, 652.118860331459, 664.3842198186234, 676.725527013723, 689.1423173829925, 701.6341348138651, 714.2005313635667, 726.8410670180938, 739.555309461031, 752.3428338516964, 765.2032226121381, 778.13606522253, 791.140958024549, 804.2175040323367, 817.3653127506706, 830.584000000001, 843.8731877480179, 857.2325039474425, 870.6615823797453, 884.1600625045229, 897.7275893142651, 911.3638131942708, 925.0683897874807], [0.0, 0.9259454627568515, 2.6189692628971426, 4.81135375959823, 7.407563702054816, 10.352384990909103, 13.608563480397194, 17.148749954442753, 20.951754103177148, 25.000527494435005, 29.28096651410265, 33.78115043926126, 38.49083007678585, 43.40106997528981, 48.50398952663588, 53.792570351304114, 59.26050961643854, 64.90210609063473, 70.71217009822288, 76.68595128835534, 82.81907992727285, 89.10751862216796, 95.54752220753824, 102.13560410062702, 108.8685078431776, 115.74318284460652, 122.75676356111717, 129.90655150915225, 137.18999963554208, 144.60469866155813, 152.1483650914463, 159.8188306333144, 167.6140328254172, 175.53200669678463, 183.57087731990623, 191.7288531364021, 200.0042199554801, 208.39533554041, 216.90062471094933, 225.51857490016224, 234.24773211282127, 243.08669723989445, 252.03412268976618, 261.08870930203034, 270.24920351409014, 279.5143947545459, 288.8831130405517, 298.35422675906597, 307.9266406142869, 317.5992937256004, 327.37115786214304, 337.2412358016146, 347.2085598023185, 357.2721901785812, 367.43121397072434, 377.6847437016754, 388.03191621308713, 398.4718915745504, 409.00385206010026, 419.62700118676867, 430.3405628104331, 441.14378027464056, 452.0359156084839, 463.01624876995453, 474.0840769315085, 485.2387138048657, 496.4794890023157, 507.8057474320279, 519.216848725078, 530.7121666920785, 542.2910888074786, 553.9530157197455, 565.6973607857832, 577.5235496280656, 589.4310197130794, 601.4192199497791, 613.4876103068428, 625.6356614476198, 637.8628543817243, 650.1686801323183, 662.552639418183, 675.0142423497454, 687.5530081382824, 700.1684648175759, 712.8601489773439, 725.6276055078121, 738.4703873548357, 751.3880552850179, 764.3801776603061, 777.4463302215795, 790.586095880772, 803.7990645211036, 817.0848328050163, 830.4430039894378, 843.8731877480179, 857.3750000000008, 870.948062745421, 884.5920039063217, 898.3064571737208, 912.0910618600544, 925.9454627568525, 939.8693099974071], [0.0, 0.9406040612287406, 2.660430040425797, 4.8875220715614205, 7.524832489829929, 10.516273104099197, 13.824000000000012, 17.420230997320342, 21.28344032340638, 25.39630965317601, 29.744512098872985, 34.31593822118233, 39.10017657249137, 44.08815024470865, 49.27185387216524, 54.64415796770964, 60.19865991863944, 65.92956823762772, 71.83161109149655, 77.89996292682052, 84.1301848327936, 90.51817550083527, 97.06013047590663, 103.75250797932561, 110.59200000000013, 117.57550765359267, 124.70012003201936, 131.96309593215838, 139.3618479785628, 146.8939287513274, 154.5570186047856, 162.3489149209198, 170.2675225872511, 178.3108455254477, 186.47697912611113, 194.76410346878626, 203.17047722540815, 211.6944321610753, 220.33436815894183, 229.08874870669692, 237.95609679098393, 246.93499115354257, 256.0240628690986, 265.22199221029945, 274.5275057694587, 283.93937381067843, 293.45640782917013, 303.0774582973802, 312.8014125799311, 322.62719300145835, 332.55375505322485, 342.5800857259515, 352.7052019576693, 362.92814918658536, 373.24800000000045, 383.66385287123455, 394.174830977322, 404.7800810909553, 415.4787725407888, 426.27009623477045, 437.1532637416773, 448.127506426464, 459.1920746354411, 470.3462369276495, 481.5892793491157, 492.92050474696276, 504.33923212060415, 515.844796007482, 527.4365459010219, 539.113845698662, 550.8760731779887, 562.7226194991639, 574.6528887319726, 586.6662974059452, 598.7622740821276, 610.9402589451779, 623.1997034145644, 635.5400697737327, 647.9608308161853, 660.4614695074961, 673.041478662349, 685.7003606357525, 698.4376270276405, 711.2527984001197, 724.1454040066824, 737.114981532733, 750.1610768468339, 763.2832437621054, 776.4810438072533, 789.754046006731, 803.101826669571, 816.5239691864542, 830.0200638346051, 843.5897075901305, 857.2325039474425, 870.948062745421, 884.7360000000014, 898.595937742878, 912.5275038660492, 926.5303319719231, 940.6040612287417, 954.7483362310734], [0.0, 0.9553392067742223, 2.7021073257737203, 4.96408813378651, 7.642713654193782, 10.681017039589449, 14.040561527232459, 17.693129711840143, 21.61685860618977, 25.794158582904018, 30.21047831465105, 34.85351866024436, 39.71270507029209, 44.77881844131222, 50.04372799862141, 55.50019256723353, 61.14170923355027, 66.96239578300651, 72.95689779589048, 79.12031412349177, 85.4481363167156, 91.93619881744087, 98.58063757148265, 105.37785531600092, 112.32449221785971, 119.41740084677788, 126.65362469349242, 134.0303796122358, 141.5450376947212, 149.19511318069385, 156.97825008580025, 164.89221128664644, 172.9348688495182, 181.10419542627957, 189.39825657064554, 197.81520385197916, 206.3532686632322, 215.01075663556952, 223.78604258532326, 232.67756592976497, 241.68382651720844, 250.80338082450194, 260.0348384813084, 269.3768590859284, 278.82814928195495, 288.3874600689152, 298.0535843233566, 307.82535450966384, 317.7016405623368, 327.6813479235586, 337.76341572171526, 347.94681507810975, 358.23054753049786, 368.61364356328477, 379.0951612352765, 389.67418489681904, 400.34982398897137, 411.1212119180916, 421.98750499985243, 432.94788146727365, 444.00154053786844, 455.14770153544714, 466.3856030625308, 477.7145022196841, 489.13367386840235, 500.64240993447663, 512.2400187490242, 523.9258244246037, 535.6991662640522, 547.5593981998672, 559.505888262135, 571.5380180731644, 583.655182367124, 595.856788533118, 608.1422561802467, 620.511016723314, 632.9625129879344, 645.49619883389, 658.1115387956673, 670.808007739175, 683.5850905337251, 696.4422817384087, 709.3790853020699, 722.3950142761239, 735.4895905395272, 748.6623445352393, 761.9128150175723, 775.2405488098526, 788.6451005718615, 802.1260325765531, 815.6829144955788, 829.3153231931758, 843.0228425280076, 856.805063162562, 870.6615823797453, 884.5920039063217, 898.595937742878, 912.6730000000013, 926.8228127403869, 941.0450038265982, 955.3392067742234, 969.7050606101851], [0.0, 0.9701505037879433, 2.744000000000001, 5.041049890647784, 7.76120403030355, 10.846612374377548, 14.258242247907008, 17.967438771288478, 21.952000000000016, 26.194063602274483, 30.678852651297134, 35.39387732362763, 40.32839912518228, 45.47305602222049, 50.8195911829287, 56.36065116728163, 62.089632242428415, 68.00056099768597, 74.08800000000006, 80.3469721146977, 86.7728989950204, 93.36155050126371, 100.10900267208748, 107.01160247375059, 114.0659379832561, 121.268812973493, 128.61722509835155, 136.1083470474902, 143.73951017030788, 151.50819016805676, 159.4119945298974, 167.44865144873532, 175.61600000000016, 183.91198140414906, 192.33463122381283, 200.88207237083174, 209.55250881819592, 218.34421992807617, 227.2555553204368, 236.28493021773548, 245.43082121037713, 254.69176239525325, 264.06634184613563, 273.5531983801325, 283.1510185890211, 292.85853410819385, 302.6745190993127, 312.5977879256349, 322.62719300145835, 332.7616227992649, 343.00000000000034, 353.3412797735361, 363.78444817776403, 374.32852066600583, 384.97254069348935, 395.71557841459855, 406.5567294634297, 417.4951138109288, 428.5298746925358, 439.66017760083804, 450.8852093382532, 462.2041771252186, 473.6163077597735, 485.12084682478917, 496.71705793942755, 508.40422205170614, 520.1816367693121, 532.048615726045, 544.0044879814878, 556.0485974516982, 568.1803023688877, 580.3989747682199, 592.7040000000006, 605.0947762656697, 617.5707141761184, 630.1312363309733, 642.7757769175819, 655.5037813285297, 668.3147057966038, 681.2080170461891, 694.1831919601634, 707.2397172614113, 720.3770892081462, 733.5948133022761, 746.8924040101099, 760.2693844947337, 773.7252863594425, 787.2596494016453, 800.8720213767001, 814.5619577711702, 828.329021585023, 842.1727831223243, 856.0928197900049, 870.0887159043046, 884.1600625045229, 898.3064571737208, 912.5275038660492, 926.8228127403869, 941.1920000000013, 955.6346877379463, 970.1505037879443, 984.739081580498], [0.0, 0.9850375627355538, 2.786106961335118, 5.118405318065387, 7.880300501884434, 11.013054753337064, 14.47703643706129, 18.24315096138823, 22.288855690680947, 26.596014193859965, 31.149622790653517, 35.937000000000026, 40.9472425445231, 46.17084472911453, 51.59942302003002, 57.225511137953184, 63.04240401507548, 69.04403657811446, 75.22488795604822, 81.57990463956187, 88.10443802669654, 94.7941930658203, 101.64518558200392, 108.65370648532898, 115.81629149649036, 123.12969534194431, 130.5908696042722, 138.19694358776547, 145.9452076911059, 153.8330988799226, 161.85818793005203, 170.01816817328685, 178.31084552544763, 186.73412961480838, 195.2860258595071, 203.9646283672737, 212.76811355087978, 221.69473436913222, 230.74281511674442, 239.91074669760025, 249.1969823252282, 258.6000336020862, 268.1184669357934, 277.750900255967, 287.49600000000027, 297.35247834010084, 307.3190906273156, 317.39463303118436, 327.5779403561849, 337.8678840182953, 348.26337016688996, 358.76333793881486, 369.36675783291633, 380.07263019454626, 390.87998380065494, 401.7878745370501, 412.79538416024025, 423.90161913703554, 435.1057095557359, 446.40680810332674, 457.8040891036256, 469.2967476117861, 480.88399856098397, 492.5650759574825, 504.3392321206041, 516.2057369644399, 528.163877318395, 540.2129562839091, 552.3522926249158, 564.5812201897976, 576.8990873627732, 589.3052565428216, 601.7991036483859, 614.3800176462454, 627.047400103055, 639.8006647581736, 652.6392371164952, 665.562554060098, 678.5700634776051, 691.6612239102326, 704.8355042135726, 718.0923832342193, 731.4313495004171, 744.85190092595, 758.3535445265626, 771.9357961482297, 785.5981802066507, 799.3402294373789, 813.1614846560316, 827.061494528068, 841.0398153476453, 855.0960108251011, 869.2296518826321, 883.4403164577682, 897.7275893142651, 912.0910618600544, 926.5303319719231, 941.0450038265982, 955.6346877379463, 970.299000000001, 985.0375627355548, 999.8500037500637], [0.0, 1.0, 2.8284271247461907, 5.196152422706635, 8.000000000000004, 11.180339887498954, 14.696938456699078, 18.520259177452147, 22.627416997969533, 27.000000000000014, 31.62277660168381, 36.48287269390943, 41.569219381653085, 46.87216658103189, 52.383203414835215, 58.09475019311129, 64.00000000000004, 70.0927956355003, 76.3675323681472, 82.81907992727285, 89.44271909999165, 96.23408959407271, 103.18914671611553, 110.30412503619266, 117.57550765359267, 125.00000000000009, 132.5745073534125, 140.29611541307918, 148.16207341961723, 156.16977940690074, 164.31676725154995, 172.6006952477308, 181.01933598375632, 189.5705673357551, 198.25236442474042, 207.06279240848673, 216.00000000000017, 225.06221362103435, 234.24773211282132, 243.55492193753776, 252.98221281347054, 262.5280937347471, 272.1911093331304, 281.96985654498627, 291.8629815512755, 301.86917696247184, 311.98717922376267, 322.2157662188494, 332.5537550532248, 343.00000000000034, 353.55339059327406, 364.2128498556857, 374.97733264825524, 385.8458241318679, 396.81733833087526, 407.8909167902618, 419.06562731868183, 430.34056281043314, 441.7148401401072, 453.1875991242484, 464.7580015448905, 476.4252302303064, 488.1884881887328, 500.0469977912082, 512.0000000000006, 524.0467536394062, 536.1865347059739, 548.4186357154548, 560.7423650840025, 573.1570465413478, 585.6620185738535, 598.2566338955221, 610.9402589451777, 623.7122734081804, 636.572069761155, 649.5190528383297, 662.552639418183, 675.6722578291941, 688.8773475735728, 702.1673589679323, 715.5417527999334, 729.0000000000007, 742.5415813272691, 756.1659870689776, 769.8727167525819, 783.6612788698963, 797.5311906126313, 811.4819776187278, 825.5131737289245, 839.6243207530387, 853.8149682454633, 868.0846732894214, 882.4330002895415, 896.8595207723458, 911.3638131942708, 925.9454627568525, 940.6040612287417, 955.3392067742234, 970.1505037879443, 985.0375627355548, 1000.000000000001, 1015.0374377332113], [0.0, 1.01503743773321, 2.870959421517484, 5.274289241215355, 8.120299501865684, 11.348463552393344, 14.917942753610511, 18.798756421635996, 22.96767537213988, 27.406010818796688, 32.098302135782845, 37.03148162037272, 42.194313929722846, 47.57700386741481, 53.17091257445188, 58.968346381766594, 64.96239601492549, 71.14681168541576, 77.51590438097212, 84.06446668480098, 90.78770841914678, 97.68120372415574, 104.74084708460221, 111.96281644814063, 119.34354202888413, 126.87967971665137, 134.56808825275047, 142.4058095128146, 150.39005137308803, 158.5181727405412, 166.78767040761753, 175.19616745522737, 183.7414029771191, 192.42122293811585, 201.23357201023913, 210.17648625619395, 219.24808655037356, 228.44657264445908, 237.77021779861357, 247.21736391079034, 256.7864170862628, 266.4758435975017, 276.28416619126074, 286.20996070542367, 296.25185296298184, 306.4085159146204, 316.67866700489986, 327.06106574002393, 337.5545114377829, 348.1578411424914, 358.86992768968577, 369.6896779070256, 380.6160309393186, 391.64795668687003, 402.784454347484, 414.0245510534374, 425.3673005956152, 436.81178222776964, 448.35709954454893, 460.0023794275422, 471.7467710541329, 483.58944496442496, 495.5295921819408, 507.56642338417214, 519.6991681194041, 531.9270740665497, 544.2494063350008, 556.665446801758, 569.1744934833262, 581.7758599400639, 594.4688747108639, 607.2528807762059, 620.127235047777, 633.0913078829949, 646.1444826228891, 659.2861551519197, 672.515733478408, 685.8326373343581, 699.2362977935294, 712.7261569067051, 726.3016673531745, 739.9622921075108, 753.7075041207972, 767.5367860154987, 781.4496297932461, 795.4455365548301, 809.5240162317617, 823.6845873287916, 837.9267766768179, 852.2501191956513, 866.6541576661373, 881.1384425111652, 895.7025315851253, 910.3459899713966, 925.0683897874807, 939.8693099974071, 954.7483362310734, 969.7050606101851, 984.739081580498, 999.8500037500637, 1015.0374377332113, 1030.3010000000015]]}, {\"colorscale\": [[0.0, \"#440154\"], [0.1111111111111111, \"#482878\"], [0.2222222222222222, \"#3e4989\"], [0.3333333333333333, \"#31688e\"], [0.4444444444444444, \"#26828e\"], [0.5555555555555556, \"#1f9e89\"], [0.6666666666666666, \"#35b779\"], [0.7777777777777778, \"#6ece58\"], [0.8888888888888888, \"#b5de2b\"], [1.0, \"#fde725\"]], \"contours\": {\"z\": {\"project\": {\"z\": true}, \"show\": false}}, \"name\": \"alpha + beta = 1\", \"showscale\": false, \"type\": \"surface\", \"z\": [[0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], [0.0, 0.1, 0.1414213562373095, 0.17320508075688776, 0.2, 0.223606797749979, 0.24494897427831783, 0.2645751311064591, 0.282842712474619, 0.3, 0.31622776601683794, 0.33166247903554, 0.3464101615137755, 0.36055512754639896, 0.37416573867739417, 0.38729833462074165, 0.4, 0.41231056256176607, 0.4242640687119285, 0.43588989435406744, 0.447213595499958, 0.45825756949558405, 0.469041575982343, 0.479583152331272, 0.48989794855663565, 0.5, 0.5099019513592785, 0.5196152422706632, 0.5291502622129182, 0.5385164807134505, 0.5477225575051661, 0.5567764362830022, 0.565685424949238, 0.574456264653803, 0.5830951894845301, 0.5916079783099616, 0.6, 0.608276253029822, 0.6164414002968976, 0.6244997998398399, 0.6324555320336759, 0.6403124237432849, 0.6480740698407861, 0.6557438524302001, 0.66332495807108, 0.6708203932499369, 0.6782329983125268, 0.6855654600401044, 0.692820323027551, 0.7000000000000001, 0.7071067811865476, 0.7141428428542851, 0.7211102550927979, 0.7280109889280519, 0.7348469228349535, 0.7416198487095663, 0.7483314773547883, 0.754983443527075, 0.7615773105863909, 0.7681145747868608, 0.7745966692414833, 0.7810249675906654, 0.787400787401181, 0.7937253933193772, 0.8, 0.8062257748298549, 0.812403840463596, 0.8185352771872451, 0.8246211251235321, 0.8306623862918076, 0.8366600265340756, 0.8426149773176359, 0.848528137423857, 0.8544003745317531, 0.8602325267042626, 0.8660254037844387, 0.8717797887081349, 0.8774964387392122, 0.8831760866327848, 0.8888194417315589, 0.894427190999916, 0.9, 0.9055385138137417, 0.9110433579144299, 0.9165151389911681, 0.9219544457292888, 0.9273618495495705, 0.9327379053088816, 0.938083151964686, 0.9433981132056604, 0.9486832980505138, 0.9539392014169457, 0.959166304662544, 0.9643650760992956, 0.9695359714832659, 0.9746794344808963, 0.9797958971132713, 0.9848857801796106, 0.9899494936611666, 0.9949874371066201, 1.0, 1.0049875621120892], [0.0, 0.1414213562373095, 0.19999999999999998, 0.24494897427831783, 0.282842712474619, 0.31622776601683794, 0.34641016151377546, 0.3741657386773941, 0.39999999999999997, 0.4242640687119285, 0.4472135954999579, 0.469041575982343, 0.48989794855663565, 0.5099019513592785, 0.529150262212918, 0.5477225575051661, 0.565685424949238, 0.58309518948453, 0.6, 0.6164414002968976, 0.6324555320336759, 0.6480740698407861, 0.6633249580710799, 0.6782329983125268, 0.6928203230275509, 0.7071067811865476, 0.7211102550927979, 0.7348469228349535, 0.7483314773547882, 0.7615773105863909, 0.7745966692414833, 0.7874007874011811, 0.7999999999999999, 0.812403840463596, 0.8246211251235321, 0.8366600265340756, 0.848528137423857, 0.8602325267042626, 0.8717797887081348, 0.8831760866327847, 0.8944271909999159, 0.9055385138137417, 0.9165151389911681, 0.9273618495495702, 0.938083151964686, 0.9486832980505137, 0.9591663046625439, 0.9695359714832658, 0.9797958971132713, 0.9899494936611665, 1.0, 1.0099504938362078, 1.019803902718557, 1.0295630140987002, 1.0392304845413265, 1.0488088481701516, 1.058300524425836, 1.0677078252031311, 1.0770329614269007, 1.0862780491200215, 1.0954451150103321, 1.104536101718726, 1.1135528725660042, 1.1224972160321824, 1.131370849898476, 1.1401754250991378, 1.1489125293076057, 1.1575836902790224, 1.16619037896906, 1.174734012447073, 1.1832159566199232, 1.1916375287812984, 1.2, 1.2083045973594573, 1.2165525060596438, 1.224744871391589, 1.2328828005937953, 1.2409673645990857, 1.2489995996796797, 1.2569805089976536, 1.2649110640673518, 1.2727922061357855, 1.2806248474865698, 1.2884098726725124, 1.2961481396815722, 1.3038404810405297, 1.3114877048604001, 1.3190905958272918, 1.3266499161421599, 1.3341664064126333, 1.3416407864998738, 1.349073756323204, 1.3564659966250536, 1.3638181696985856, 1.3711309200802089, 1.378404875209022, 1.3856406460551018, 1.392838827718412, 1.4, 1.407124727947029, 1.4142135623730951, 1.4212670403551897], [0.0, 0.17320508075688776, 0.24494897427831783, 0.3000000000000001, 0.3464101615137755, 0.38729833462074176, 0.42426406871192857, 0.45825756949558405, 0.48989794855663565, 0.5196152422706632, 0.5477225575051662, 0.574456264653803, 0.6000000000000002, 0.6244997998398399, 0.6480740698407861, 0.6708203932499369, 0.692820323027551, 0.7141428428542851, 0.7348469228349536, 0.7549834435270751, 0.7745966692414835, 0.7937253933193773, 0.8124038404635961, 0.8306623862918077, 0.8485281374238571, 0.8660254037844388, 0.8831760866327849, 0.9000000000000001, 0.9165151389911681, 0.9327379053088817, 0.9486832980505139, 0.9643650760992957, 0.9797958971132713, 0.9949874371066202, 1.009950493836208, 1.02469507659596, 1.0392304845413265, 1.053565375285274, 1.0677078252031313, 1.081665382639197, 1.0954451150103324, 1.1090536506409419, 1.1224972160321827, 1.1357816691600549, 1.148912529307606, 1.161895003862225, 1.1747340124470733, 1.187434208703792, 1.2000000000000004, 1.2124355652982142, 1.2247448713915892, 1.2369316876852985, 1.2489995996796799, 1.2609520212918495, 1.2727922061357857, 1.2845232578665131, 1.2961481396815722, 1.3076696830622023, 1.3190905958272923, 1.3304134695650072, 1.3416407864998738, 1.3527749258468684, 1.3638181696985856, 1.3747727084867523, 1.385640646055102, 1.3964240043768943, 1.4071247279470291, 1.4177446878757827, 1.4282856857085702, 1.4387494569938162, 1.4491376746189442, 1.4594519519326425, 1.4696938456699071, 1.4798648586948744, 1.489966442575134, 1.5000000000000002, 1.5099668870541503, 1.5198684153570665, 1.5297058540778359, 1.5394804318340656, 1.549193338482967, 1.5588457268119897, 1.5684387141358125, 1.5779733838059502, 1.5874507866387546, 1.5968719422671316, 1.6062378404209012, 1.6155494421403516, 1.6248076809271923, 1.6340134638368193, 1.6431676725154984, 1.6522711641858308, 1.6613247725836153, 1.670329308849007, 1.6792855623746668, 1.6881943016134133, 1.6970562748477143, 1.7058722109231985, 1.7146428199482249, 1.7233687939614089, 1.7320508075688776, 1.7406895185529214], [0.0, 0.2, 0.282842712474619, 0.3464101615137755, 0.4, 0.447213595499958, 0.48989794855663565, 0.5291502622129182, 0.565685424949238, 0.6, 0.6324555320336759, 0.66332495807108, 0.692820323027551, 0.7211102550927979, 0.7483314773547883, 0.7745966692414833, 0.8, 0.8246211251235321, 0.848528137423857, 0.8717797887081349, 0.894427190999916, 0.9165151389911681, 0.938083151964686, 0.959166304662544, 0.9797958971132713, 1.0, 1.019803902718557, 1.0392304845413265, 1.0583005244258363, 1.077032961426901, 1.0954451150103321, 1.1135528725660044, 1.131370849898476, 1.148912529307606, 1.1661903789690602, 1.1832159566199232, 1.2, 1.216552506059644, 1.2328828005937953, 1.2489995996796799, 1.2649110640673518, 1.2806248474865698, 1.2961481396815722, 1.3114877048604001, 1.32664991614216, 1.3416407864998738, 1.3564659966250536, 1.3711309200802089, 1.385640646055102, 1.4000000000000001, 1.4142135623730951, 1.4282856857085702, 1.4422205101855958, 1.4560219778561039, 1.469693845669907, 1.4832396974191326, 1.4966629547095767, 1.50996688705415, 1.5231546211727818, 1.5362291495737217, 1.5491933384829666, 1.5620499351813308, 1.574801574802362, 1.5874507866387544, 1.6, 1.6124515496597098, 1.624807680927192, 1.6370705543744901, 1.6492422502470643, 1.661324772583615, 1.6733200530681511, 1.6852299546352718, 1.697056274847714, 1.7088007490635062, 1.7204650534085253, 1.7320508075688774, 1.7435595774162698, 1.7549928774784245, 1.7663521732655696, 1.7776388834631178, 1.788854381999832, 1.8, 1.8110770276274835, 1.8220867158288598, 1.8330302779823362, 1.8439088914585775, 1.854723699099141, 1.8654758106177631, 1.876166303929372, 1.8867962264113207, 1.8973665961010275, 1.9078784028338913, 1.918332609325088, 1.9287301521985911, 1.9390719429665317, 1.9493588689617927, 1.9595917942265426, 1.9697715603592212, 1.9798989873223332, 1.9899748742132402, 2.0, 2.0099751242241783], [0.0, 0.223606797749979, 0.31622776601683794, 0.38729833462074176, 0.447213595499958, 0.5000000000000001, 0.5477225575051662, 0.5916079783099617, 0.6324555320336759, 0.6708203932499369, 0.7071067811865476, 0.7416198487095664, 0.7745966692414835, 0.806225774829855, 0.8366600265340756, 0.8660254037844386, 0.894427190999916, 0.9219544457292888, 0.9486832980505139, 0.9746794344808966, 1.0000000000000002, 1.02469507659596, 1.0488088481701516, 1.072380529476361, 1.0954451150103324, 1.118033988749895, 1.140175425099138, 1.1618950038622253, 1.1832159566199234, 1.2041594578792296, 1.2247448713915892, 1.2449899597988734, 1.2649110640673518, 1.2845232578665131, 1.30384048104053, 1.3228756555322954, 1.3416407864998738, 1.3601470508735445, 1.3784048752090223, 1.3964240043768943, 1.4142135623730951, 1.4317821063276355, 1.4491376746189442, 1.466287829861518, 1.4832396974191329, 1.5, 1.5165750888103102, 1.5329709716755893, 1.549193338482967, 1.565247584249853, 1.5811388300841898, 1.5968719422671316, 1.61245154965971, 1.627882059609971, 1.6431676725154984, 1.6583123951777001, 1.6733200530681511, 1.6881943016134133, 1.7029386365926404, 1.7175564037317668, 1.7320508075688772, 1.746424919657298, 1.760681686165901, 1.7748239349298849, 1.788854381999832, 1.8027756377319946, 1.8165902124584952, 1.8303005217723127, 1.8439088914585775, 1.8574175621006712, 1.8708286933869709, 1.8841443681416774, 1.8973665961010278, 1.91049731745428, 1.9235384061671346, 1.9364916731037085, 1.9493588689617931, 1.9621416870348585, 1.9748417658131503, 1.9874606914351793, 2.0000000000000004, 2.012461179749811, 2.024845673131659, 2.0371548787463363, 2.04939015319192, 2.0615528128088303, 2.0736441353327724, 2.0856653614614213, 2.0976176963403033, 2.1095023109728985, 2.121320343559643, 2.1330729007701543, 2.144761058952722, 2.1563858652847827, 2.1679483388678804, 2.179449471770337, 2.1908902300206647, 2.2022715545545246, 2.2135943621178655, 2.224859546128699, 2.23606797749979, 2.2472205054244236], [0.0, 0.24494897427831783, 0.34641016151377546, 0.42426406871192857, 0.48989794855663565, 0.5477225575051662, 0.6000000000000001, 0.6480740698407861, 0.6928203230275509, 0.7348469228349535, 0.7745966692414834, 0.8124038404635961, 0.8485281374238571, 0.8831760866327848, 0.916515138991168, 0.9486832980505138, 0.9797958971132713, 1.0099504938362078, 1.0392304845413265, 1.0677078252031313, 1.0954451150103324, 1.1224972160321824, 1.148912529307606, 1.174734012447073, 1.2000000000000002, 1.2247448713915892, 1.2489995996796799, 1.2727922061357857, 1.2961481396815722, 1.319090595827292, 1.3416407864998738, 1.3638181696985856, 1.3856406460551018, 1.4071247279470291, 1.4282856857085702, 1.449137674618944, 1.469693845669907, 1.489966442575134, 1.50996688705415, 1.5297058540778357, 1.5491933384829668, 1.5684387141358125, 1.5874507866387546, 1.606237840420901, 1.6248076809271923, 1.6431676725154982, 1.661324772583615, 1.6792855623746665, 1.6970562748477143, 1.7146428199482247, 1.7320508075688774, 1.7492855684535904, 1.7663521732655696, 1.7832554500127011, 1.8, 1.8165902124584952, 1.833030277982336, 1.849324200890693, 1.8654758106177631, 1.8814887722226779, 1.8973665961010275, 1.9131126469708992, 1.928730152198591, 1.9442222095223582, 1.9595917942265426, 1.9748417658131499, 1.98997487421324, 2.004993765576342, 2.0199009876724157, 2.0346989949375804, 2.04939015319192, 2.0639767440550294, 2.078460969082653, 2.092844953645635, 2.1071307505705477, 2.121320343559643, 2.1354156504062627, 2.149418526020468, 2.1633307652783937, 2.177154105707724, 2.1908902300206647, 2.2045407685048604, 2.2181073012818837, 2.2315913604421396, 2.244994432064365, 2.2583179581272432, 2.2715633383201097, 2.2847319317591728, 2.297825058615212, 2.3108440016582685, 2.32379000772445, 2.3366642891095846, 2.349468024894146, 2.3622023622035435, 2.374868417407584, 2.3874672772626644, 2.4000000000000004, 2.412467616362964, 2.4248711305964283, 2.4372115213907883, 2.4494897427831783, 2.4617067250182347], [0.0, 0.2645751311064591, 0.3741657386773941, 0.45825756949558405, 0.5291502622129182, 0.5916079783099617, 0.6480740698407861, 0.7000000000000001, 0.7483314773547882, 0.7937253933193772, 0.8366600265340756, 0.8774964387392122, 0.9165151389911681, 0.9539392014169458, 0.9899494936611666, 1.0246950765959597, 1.0583005244258363, 1.0908712114635715, 1.1224972160321824, 1.1532562594670797, 1.1832159566199234, 1.2124355652982142, 1.2409673645990857, 1.2688577540449522, 1.2961481396815722, 1.3228756555322954, 1.3490737563232043, 1.374772708486752, 1.4000000000000001, 1.4247806848775009, 1.4491376746189437, 1.4730919862656235, 1.4966629547095764, 1.5198684153570665, 1.5427248620541514, 1.5652475842498528, 1.5874507866387544, 1.6093476939431082, 1.6309506430300091, 1.6522711641858308, 1.6733200530681511, 1.6941074346097418, 1.7146428199482249, 1.7349351572897471, 1.7549928774784245, 1.7748239349298847, 1.7944358444926363, 1.8138357147217055, 1.8330302779823362, 1.8520259177452134, 1.8708286933869709, 1.8894443627691186, 1.9078784028338915, 1.9261360284258224, 1.9442222095223582, 1.9621416870348585, 1.9798989873223332, 1.997498435543818, 2.0149441679609885, 2.0322401432901573, 2.0493901531919194, 2.0663978319771825, 2.083266665599966, 2.1, 2.1166010488516727, 2.133072900770154, 2.149418526020468, 2.1656407827707715, 2.181742422927143, 2.1977260975835913, 2.2135943621178655, 2.2293496809607953, 2.244994432064365, 2.260530911091463, 2.2759613353482084, 2.29128784747792, 2.3065125189341593, 2.32163735324878, 2.336664289109585, 2.3515952032609695, 2.366431913239847, 2.3811761799581315, 2.395829710142188, 2.41039415863879, 2.4248711305964283, 2.4392621835300936, 2.4535688292770597, 2.4677925358506134, 2.4819347291981715, 2.495996794869737, 2.5099800796022267, 2.5238858928247927, 2.5377155080899043, 2.551470164434615, 2.5651510676761324, 2.578759391645525, 2.5922962793631443, 2.6057628441590768, 2.619160170741759, 2.632489316217637, 2.6457513110645907, 2.6589471600616665], [0.0, 0.282842712474619, 0.39999999999999997, 0.48989794855663565, 0.565685424949238, 0.6324555320336759, 0.6928203230275509, 0.7483314773547882, 0.7999999999999999, 0.848528137423857, 0.8944271909999159, 0.938083151964686, 0.9797958971132713, 1.019803902718557, 1.058300524425836, 1.0954451150103321, 1.131370849898476, 1.16619037896906, 1.2, 1.2328828005937953, 1.2649110640673518, 1.2961481396815722, 1.3266499161421599, 1.3564659966250536, 1.3856406460551018, 1.4142135623730951, 1.4422205101855958, 1.469693845669907, 1.4966629547095764, 1.5231546211727818, 1.5491933384829666, 1.5748015748023623, 1.5999999999999999, 1.624807680927192, 1.6492422502470643, 1.6733200530681511, 1.697056274847714, 1.7204650534085253, 1.7435595774162695, 1.7663521732655694, 1.7888543819998317, 1.8110770276274835, 1.8330302779823362, 1.8547236990991405, 1.876166303929372, 1.8973665961010273, 1.9183326093250879, 1.9390719429665315, 1.9595917942265426, 1.979898987322333, 2.0, 2.0199009876724157, 2.039607805437114, 2.0591260281974004, 2.078460969082653, 2.0976176963403033, 2.116601048851672, 2.1354156504062622, 2.1540659228538015, 2.172556098240043, 2.1908902300206643, 2.209072203437452, 2.2271057451320084, 2.244994432064365, 2.262741699796952, 2.2803508501982757, 2.2978250586152114, 2.315167380558045, 2.33238075793812, 2.349468024894146, 2.3664319132398464, 2.3832750575625967, 2.4, 2.4166091947189146, 2.4331050121192876, 2.449489742783178, 2.4657656011875906, 2.4819347291981715, 2.4979991993593593, 2.513961017995307, 2.5298221281347035, 2.545584412271571, 2.5612496949731396, 2.576819745345025, 2.5922962793631443, 2.6076809620810595, 2.6229754097208002, 2.6381811916545836, 2.6532998322843198, 2.6683328128252666, 2.6832815729997477, 2.698147512646408, 2.7129319932501073, 2.727636339397171, 2.7422618401604177, 2.756809750418044, 2.7712812921102037, 2.785677655436824, 2.8, 2.814249455894058, 2.8284271247461903, 2.8425340807103794], [0.0, 0.3, 0.4242640687119285, 0.5196152422706632, 0.6, 0.6708203932499369, 0.7348469228349535, 0.7937253933193772, 0.848528137423857, 0.8999999999999999, 0.9486832980505138, 0.99498743710662, 1.0392304845413265, 1.0816653826391969, 1.1224972160321824, 1.1618950038622249, 1.2, 1.236931687685298, 1.2727922061357855, 1.307669683062202, 1.3416407864998738, 1.374772708486752, 1.407124727947029, 1.438749456993816, 1.469693845669907, 1.5, 1.5297058540778354, 1.5588457268119895, 1.5874507866387544, 1.6155494421403513, 1.6431676725154982, 1.6703293088490065, 1.697056274847714, 1.7233687939614086, 1.7492855684535902, 1.7748239349298847, 1.7999999999999998, 1.8248287590894658, 1.849324200890693, 1.8734993995195195, 1.8973665961010275, 1.9209372712298547, 1.9442222095223582, 1.9672315572906, 1.98997487421324, 2.0124611797498106, 2.0346989949375804, 2.056696380120313, 2.078460969082653, 2.1, 2.1213203435596424, 2.142428528562855, 2.1633307652783937, 2.1840329667841556, 2.2045407685048604, 2.224859546128699, 2.244994432064365, 2.264950330581225, 2.2847319317591723, 2.3043437243605824, 2.3237900077244498, 2.3430749027719964, 2.362202362203543, 2.3811761799581315, 2.4, 2.4186773244895647, 2.437211521390788, 2.455605831561735, 2.473863375370596, 2.4919871588754225, 2.5099800796022267, 2.5278449319529073, 2.545584412271571, 2.563201123595259, 2.580697580112788, 2.598076211353316, 2.615339366124404, 2.6324893162176366, 2.6495282598983545, 2.6664583251946765, 2.6832815729997477, 2.7, 2.716615541441225, 2.7331300737432893, 2.749545416973504, 2.765863337187866, 2.7820855486487113, 2.7982137159266447, 2.814249455894058, 2.830194339616981, 2.846049894151541, 2.8618176042508368, 2.877498913987632, 2.8930952282978866, 2.9086079144497976, 2.9240383034426887, 2.939387691339814, 2.9546573405388314, 2.9698484809834995, 2.98496231131986, 3.0, 3.0149626863362675], [0.0, 0.31622776601683794, 0.4472135954999579, 0.5477225575051662, 0.6324555320336759, 0.7071067811865476, 0.7745966692414834, 0.8366600265340756, 0.8944271909999159, 0.9486832980505138, 1.0, 1.0488088481701516, 1.0954451150103324, 1.140175425099138, 1.1832159566199232, 1.224744871391589, 1.2649110640673518, 1.3038404810405297, 1.3416407864998738, 1.3784048752090223, 1.4142135623730951, 1.449137674618944, 1.4832396974191326, 1.5165750888103102, 1.5491933384829668, 1.5811388300841898, 1.61245154965971, 1.6431676725154984, 1.6733200530681511, 1.7029386365926402, 1.7320508075688772, 1.760681686165901, 1.7888543819998317, 1.8165902124584952, 1.8439088914585775, 1.8708286933869707, 1.8973665961010275, 1.9235384061671346, 1.949358868961793, 1.97484176581315, 2.0, 2.024845673131659, 2.04939015319192, 2.073644135332772, 2.0976176963403033, 2.1213203435596424, 2.1447610589527217, 2.16794833886788, 2.1908902300206647, 2.2135943621178655, 2.23606797749979, 2.2583179581272432, 2.280350850198276, 2.302172886644268, 2.32379000772445, 2.345207879911715, 2.3664319132398464, 2.3874672772626644, 2.4083189157584592, 2.4289915602982237, 2.449489742783178, 2.4698178070456938, 2.4899799195977463, 2.5099800796022267, 2.5298221281347035, 2.5495097567963922, 2.569046515733026, 2.588435821108957, 2.6076809620810595, 2.6267851073127395, 2.6457513110645907, 2.6645825188948455, 2.6832815729997477, 2.701851217221259, 2.7202941017470885, 2.7386127875258306, 2.7568097504180447, 2.7748873851023217, 2.7928480087537886, 2.8106938645110393, 2.8284271247461903, 2.8460498941515415, 2.863564212655271, 2.8809720581775866, 2.898275349237888, 2.9154759474226504, 2.932575659723036, 2.9495762407505253, 2.9664793948382653, 2.9832867780352594, 3.0, 3.0166206257996713, 3.0331501776206204, 3.0495901363953815, 3.0659419433511785, 3.082207001484488, 3.0983866769659336, 3.1144823004794877, 3.1304951684997055, 3.146426544510455, 3.1622776601683795, 3.178049716414141], [0.0, 0.33166247903554, 0.469041575982343, 0.574456264653803, 0.66332495807108, 0.7416198487095664, 0.8124038404635961, 0.8774964387392122, 0.938083151964686, 0.99498743710662, 1.0488088481701516, 1.1, 1.148912529307606, 1.1958260743101399, 1.2409673645990857, 1.284523257866513, 1.32664991614216, 1.3674794331177345, 1.407124727947029, 1.4456832294800963, 1.4832396974191329, 1.5198684153570665, 1.5556349186104048, 1.5905973720586868, 1.6248076809271923, 1.6583123951777001, 1.6911534525287766, 1.7233687939614089, 1.7549928774784245, 1.7860571099491753, 1.816590212458495, 1.846618531261939, 1.876166303929372, 1.9052558883257653, 1.9339079605813718, 1.9621416870348585, 1.98997487421324, 2.017424100183202, 2.0445048300260877, 2.0712315177207983, 2.0976176963403033, 2.1236760581595306, 2.149418526020468, 2.1748563170931545, 2.2, 2.224859546128699, 2.249444375840399, 2.273763400180415, 2.297825058615212, 2.32163735324878, 2.345207879911715, 2.368543856465403, 2.3916521486202797, 2.4145392935299275, 2.4372115213907883, 2.459674775249769, 2.4819347291981715, 2.503996805109783, 2.525866188063018, 2.5475478405713994, 2.569046515733026, 2.5903667693977237, 2.6115129714401193, 2.632489316217637, 2.65329983228432, 2.6739483914241875, 2.6944387170614963, 2.714774392099646, 2.734958866235469, 2.7549954627911823, 2.774887385102322, 2.7946377224964243, 2.814249455894058, 2.833725463060951, 2.8530685235374214, 2.8722813232690148, 2.8913664589601926, 2.91032644217105, 2.9291637031753623, 2.9478805945967355, 2.9664793948382657, 2.9849623113198605, 3.003331483536242, 3.0215889859476257, 3.039736830714133, 3.0577769702841313, 3.07571129984594, 3.093541659651604, 3.1112698372208096, 3.1288975694324033, 3.146426544510455, 3.1638584039112754, 3.1811947441173736, 3.1984371183438958, 3.2155870381627056, 3.2326459750489227, 3.2496153618543846, 3.2664965942122155, 3.283291031876401, 3.3000000000000007, 3.3166247903554003, 3.333166662499792], [0.0, 0.3464101615137755, 0.48989794855663565, 0.6000000000000002, 0.692820323027551, 0.7745966692414835, 0.8485281374238571, 0.9165151389911681, 0.9797958971132713, 1.0392304845413265, 1.0954451150103324, 1.148912529307606, 1.2000000000000004, 1.2489995996796799, 1.2961481396815722, 1.3416407864998738, 1.385640646055102, 1.4282856857085702, 1.4696938456699071, 1.5099668870541503, 1.549193338482967, 1.5874507866387546, 1.6248076809271923, 1.6613247725836153, 1.6970562748477143, 1.7320508075688776, 1.7663521732655698, 1.8000000000000003, 1.8330302779823362, 1.8654758106177634, 1.8973665961010278, 1.9287301521985913, 1.9595917942265426, 1.9899748742132404, 2.019900987672416, 2.04939015319192, 2.078460969082653, 2.107130750570548, 2.1354156504062627, 2.163330765278394, 2.1908902300206647, 2.2181073012818837, 2.2449944320643653, 2.2715633383201097, 2.297825058615212, 2.32379000772445, 2.3494680248941466, 2.374868417407584, 2.400000000000001, 2.4248711305964283, 2.4494897427831783, 2.473863375370597, 2.4979991993593598, 2.521904042583699, 2.5455844122715714, 2.5690465157330262, 2.5922962793631443, 2.6153393661244047, 2.6381811916545845, 2.6608269391300143, 2.6832815729997477, 2.705549851693737, 2.727636339397171, 2.7495454169735045, 2.771281292110204, 2.7928480087537886, 2.8142494558940583, 2.8354893757515653, 2.8565713714171403, 2.8774989139876324, 2.8982753492378883, 2.918903903865285, 2.9393876913398143, 2.9597297173897488, 2.979932885150268, 3.0000000000000004, 3.0199337741083006, 3.039736830714133, 3.0594117081556718, 3.078960863668131, 3.098386676965934, 3.1176914536239795, 3.136877428271625, 3.1559467676119004, 3.174901573277509, 3.193743884534263, 3.2124756808418025, 3.231098884280703, 3.2496153618543846, 3.2680269276736387, 3.286335345030997, 3.3045423283716615, 3.3226495451672307, 3.340658617698014, 3.3585711247493335, 3.3763886032268267, 3.3941125496954285, 3.411744421846397, 3.4292856398964497, 3.4467375879228177, 3.4641016151377553, 3.481379037105843], [0.0, 0.36055512754639896, 0.5099019513592785, 0.6244997998398399, 0.7211102550927979, 0.806225774829855, 0.8831760866327848, 0.9539392014169458, 1.019803902718557, 1.0816653826391969, 1.140175425099138, 1.1958260743101399, 1.2489995996796799, 1.3000000000000003, 1.3490737563232043, 1.396424004376894, 1.4422205101855958, 1.4866068747318506, 1.5297058540778357, 1.5716233645501714, 1.61245154965971, 1.6522711641858308, 1.6911534525287764, 1.7291616465790585, 1.7663521732655696, 1.8027756377319948, 1.8384776310850237, 1.8734993995195197, 1.9078784028338915, 1.94164878389476, 1.9748417658131499, 2.0074859899884734, 2.039607805437114, 2.0712315177207983, 2.102379604162864, 2.1330729007701543, 2.1633307652783937, 2.193171219946131, 2.222611077089287, 2.2516660498395407, 2.280350850198276, 2.3086792761230397, 2.336664289109585, 2.364318083507378, 2.3916521486202797, 2.4186773244895647, 2.445403852127497, 2.471841418861655, 2.4979991993593598, 2.5238858928247927, 2.5495097567963927, 2.574878637916747, 2.6000000000000005, 2.624880949681338, 2.6495282598983545, 2.673948391424188, 2.6981475126464085, 2.72213151776324, 2.7459060435491964, 2.7694764848252458, 2.792848008753788, 2.816025568065745, 2.839013913315678, 2.861817604250837, 2.8844410203711917, 2.9068883707497264, 2.9291637031753623, 2.951270912674741, 2.973213749463701, 2.994995826374388, 3.0166206257996717, 3.0380915061926625, 3.0594117081556713, 3.0805843601498726, 3.1016124838541645, 3.122498999199199, 3.1432467291003428, 3.1638584039112754, 3.1843366656181322, 3.204684071792413, 3.22490309931942, 3.2449961479175906, 3.264965543462902, 3.2848135411313684, 3.3045423283716615, 3.3241540277189325, 3.343650699460098, 3.363034344160048, 3.3823069050575527, 3.4014702703389896, 3.420526275297414, 3.439476704383968, 3.458323293158117, 3.4770677301427426, 3.4957116585897072, 3.5142566781611158, 3.532704346531139, 3.5510561809129415, 3.5693136595149495, 3.58747822293042, 3.6055512754639896, 3.6235341863986883], [0.0, 0.37416573867739417, 0.529150262212918, 0.6480740698407861, 0.7483314773547883, 0.8366600265340756, 0.916515138991168, 0.9899494936611666, 1.058300524425836, 1.1224972160321824, 1.1832159566199232, 1.2409673645990857, 1.2961481396815722, 1.3490737563232043, 1.4, 1.4491376746189437, 1.4966629547095767, 1.5427248620541512, 1.5874507866387544, 1.6309506430300091, 1.6733200530681511, 1.7146428199482247, 1.7549928774784245, 1.7944358444926363, 1.833030277982336, 1.8708286933869707, 1.9078784028338913, 1.9442222095223582, 1.9798989873223332, 2.0149441679609885, 2.0493901531919194, 2.083266665599966, 2.116601048851672, 2.149418526020468, 2.181742422927143, 2.2135943621178655, 2.244994432064365, 2.2759613353482084, 2.3065125189341593, 2.3366642891095846, 2.3664319132398464, 2.395829710142188, 2.4248711305964283, 2.453568829277059, 2.4819347291981715, 2.5099800796022262, 2.5377155080899043, 2.565151067676132, 2.5922962793631443, 2.619160170741759, 2.6457513110645907, 2.672077843177478, 2.6981475126464085, 2.7239676943752476, 2.749545416973504, 2.7748873851023217, 2.8, 2.824889378365107, 2.8495613697550017, 2.8740215726399825, 2.8982753492378874, 2.9223278392404914, 2.9461839725312466, 2.9698484809834995, 2.9933259094191533, 3.016620625799671, 3.0397368307141326, 3.062678566222711, 3.0854497241083023, 3.1080540535840107, 3.1304951684997055, 3.152776554086889, 3.1749015732775088, 3.196873472629156, 3.218695387886216, 3.24037034920393, 3.2619012860600183, 3.283291031876401, 3.3045423283716615, 3.3256578296631782, 3.3466401061363023, 3.3674916480965473, 3.3882148692194836, 3.408812109811862, 3.4292856398964493, 3.449637662132068, 3.4698703145794947, 3.4899856733230297, 3.509985754956849, 3.529872518944558, 3.5496478698597693, 3.5693136595149495, 3.5888716889852725, 3.6083237105337433, 3.627671429443411, 3.6469165057620936, 3.666060555964672, 3.685105154537656, 3.704051835490427, 3.722902093797257, 3.7416573867739413, 3.7603191353926335], [0.0, 0.38729833462074165, 0.5477225575051661, 0.6708203932499369, 0.7745966692414833, 0.8660254037844386, 0.9486832980505138, 1.0246950765959597, 1.0954451150103321, 1.1618950038622249, 1.224744871391589, 1.284523257866513, 1.3416407864998738, 1.396424004376894, 1.4491376746189437, 1.4999999999999998, 1.5491933384829666, 1.5968719422671311, 1.6431676725154982, 1.6881943016134133, 1.7320508075688772, 1.7748239349298847, 1.816590212458495, 1.857417562100671, 1.8973665961010275, 1.9364916731037083, 1.9748417658131499, 2.0124611797498106, 2.0493901531919194, 2.085665361461421, 2.1213203435596424, 2.1563858652847823, 2.1908902300206643, 2.224859546128699, 2.258317958127243, 2.29128784747792, 2.3237900077244498, 2.355843797877949, 2.3874672772626644, 2.4186773244895647, 2.449489742783178, 2.479919353527449, 2.5099800796022267, 2.5396850198400585, 2.569046515733026, 2.5980762113533156, 2.626785107312739, 2.6551836094703507, 2.6832815729997477, 2.7110883423451915, 2.7386127875258306, 2.765863337187866, 2.792848008753788, 2.819574435974337, 2.846049894151541, 2.8722813232690143, 2.8982753492378874, 2.924038303442689, 2.9495762407505253, 2.974894956128703, 2.9999999999999996, 3.0248966924508345, 3.049590136395381, 3.074085229787879, 3.098386676965933, 3.1224989991991987, 3.1464265445104544, 3.1701734968294715, 3.1937438845342623, 3.217141588429082, 3.24037034920393, 3.2634337744161437, 3.2863353450309964, 3.309078421554859, 3.3316662497915357, 3.3541019662496843, 3.3763886032268267, 3.3985290935932855, 3.420526275297414, 3.442382895611701, 3.4641016151377544, 3.485685011586675, 3.5071355833500366, 3.5284557528754696, 3.5496478698597693, 3.5707142142714248, 3.591656999213594, 3.6124783736376886, 3.63318042491699, 3.6537651812890215, 3.674234614174767, 3.694590640382233, 3.714835124201342, 3.7349698793966195, 3.7549966711037173, 3.7749172176353745, 3.794733192202055, 3.8144462245521304, 3.8340579025361623, 3.853569773599539, 3.8729833462074166, 3.892300091205713], [0.0, 0.4, 0.565685424949238, 0.692820323027551, 0.8, 0.894427190999916, 0.9797958971132713, 1.0583005244258363, 1.131370849898476, 1.2, 1.2649110640673518, 1.32664991614216, 1.385640646055102, 1.4422205101855958, 1.4966629547095767, 1.5491933384829666, 1.6, 1.6492422502470643, 1.697056274847714, 1.7435595774162698, 1.788854381999832, 1.8330302779823362, 1.876166303929372, 1.918332609325088, 1.9595917942265426, 2.0, 2.039607805437114, 2.078460969082653, 2.1166010488516727, 2.154065922853802, 2.1908902300206643, 2.227105745132009, 2.262741699796952, 2.297825058615212, 2.3323807579381204, 2.3664319132398464, 2.4, 2.433105012119288, 2.4657656011875906, 2.4979991993593598, 2.5298221281347035, 2.5612496949731396, 2.5922962793631443, 2.6229754097208002, 2.65329983228432, 2.6832815729997477, 2.7129319932501073, 2.7422618401604177, 2.771281292110204, 2.8000000000000003, 2.8284271247461903, 2.8565713714171403, 2.8844410203711917, 2.9120439557122078, 2.939387691339814, 2.9664793948382653, 2.9933259094191533, 3.0199337741083, 3.0463092423455636, 3.0724582991474434, 3.098386676965933, 3.1240998703626617, 3.149603149604724, 3.1749015732775088, 3.2, 3.2249030993194197, 3.249615361854384, 3.2741411087489802, 3.2984845004941286, 3.32264954516723, 3.3466401061363023, 3.3704599092705436, 3.394112549695428, 3.4176014981270124, 3.4409301068170506, 3.464101615137755, 3.4871191548325395, 3.509985754956849, 3.532704346531139, 3.5552777669262356, 3.577708763999664, 3.6, 3.622154055254967, 3.6441734316577197, 3.6660605559646724, 3.687817782917155, 3.709447398198282, 3.7309516212355263, 3.752332607858744, 3.7735924528226414, 3.794733192202055, 3.8157568056677826, 3.836665218650176, 3.8574603043971822, 3.8781438859330635, 3.8987177379235853, 3.9191835884530852, 3.9395431207184424, 3.9597979746446663, 3.9799497484264803, 4.0, 4.019950248448357], [0.0, 0.41231056256176607, 0.58309518948453, 0.7141428428542851, 0.8246211251235321, 0.9219544457292888, 1.0099504938362078, 1.0908712114635715, 1.16619037896906, 1.236931687685298, 1.3038404810405297, 1.3674794331177345, 1.4282856857085702, 1.4866068747318506, 1.5427248620541512, 1.5968719422671311, 1.6492422502470643, 1.7, 1.7492855684535902, 1.797220075561143, 1.8439088914585775, 1.8894443627691184, 1.9339079605813716, 1.977371993328519, 2.0199009876724157, 2.0615528128088303, 2.102379604162864, 2.142428528562855, 2.181742422927143, 2.220360331117452, 2.258317958127243, 2.2956480566497994, 2.33238075793812, 2.3685438564654024, 2.4041630560342617, 2.4392621835300936, 2.473863375370596, 2.5079872407968904, 2.541653005427767, 2.574878637916747, 2.6076809620810595, 2.6400757564888173, 2.672077843177478, 2.7037011669191546, 2.734958866235469, 2.765863337187866, 2.7964262908219126, 2.826658805020514, 2.8565713714171403, 2.8861739379323623, 2.9154759474226504, 2.944486372867092, 2.973213749463701, 3.001666203960727, 3.0298514815086235, 3.0577769702841313, 3.0854497241083023, 3.1128764832546763, 3.1400636936215167, 3.167017524422623, 3.1937438845342623, 3.2202484376209237, 3.246536616149585, 3.2726136343907144, 3.2984845004941286, 3.324154027718932, 3.3496268448888453, 3.374907406137241, 3.4, 3.424908757908742, 3.4496376621320683, 3.4741905532080417, 3.4985711369071804, 3.522782990761707, 3.5468295701936396, 3.570714214271425, 3.594440151122286, 3.6180105030251086, 3.6414282912066254, 3.664696440361739, 3.687817782917155, 3.710795063055895, 3.733630940518894, 3.7563279941985894, 3.778888725538237, 3.8013155617496426, 3.8236108588610325, 3.845776904605882, 3.867815921162743, 3.8897300677553446, 3.9115214431215892, 3.9331920878594273, 3.954743986657038, 3.976179070414209, 3.9974992182613374, 4.018706259482023, 4.039801975344831, 4.060788100849391, 4.08166632639171, 4.102438299353203, 4.123105625617661, 4.1436698710201325], [0.0, 0.4242640687119285, 0.6, 0.7348469228349536, 0.848528137423857, 0.9486832980505139, 1.0392304845413265, 1.1224972160321824, 1.2, 1.2727922061357855, 1.3416407864998738, 1.407124727947029, 1.4696938456699071, 1.5297058540778357, 1.5874507866387544, 1.6431676725154982, 1.697056274847714, 1.7492855684535902, 1.8, 1.8493242008906932, 1.8973665961010278, 1.9442222095223582, 1.98997487421324, 2.0346989949375804, 2.078460969082653, 2.121320343559643, 2.1633307652783937, 2.2045407685048604, 2.244994432064365, 2.2847319317591728, 2.32379000772445, 2.3622023622035435, 2.4, 2.4372115213907883, 2.4738633753705965, 2.5099800796022267, 2.545584412271571, 2.5806975801127883, 2.615339366124404, 2.6495282598983545, 2.6832815729997477, 2.716615541441225, 2.749545416973504, 2.782085548648711, 2.814249455894058, 2.846049894151541, 2.877498913987632, 2.9086079144497976, 2.9393876913398143, 2.9698484809834995, 3.0, 3.029851481508624, 3.0594117081556713, 3.0886890422961004, 3.1176914536239795, 3.146426544510455, 3.1749015732775088, 3.2031234756093934, 3.2310988842807027, 3.2588341473600644, 3.2863353450309964, 3.3136083051561784, 3.340658617698013, 3.3674916480965473, 3.394112549695428, 3.420526275297414, 3.4467375879228173, 3.4727510708370675, 3.4985711369071804, 3.5242020373412193, 3.5496478698597698, 3.5749125863438955, 3.6, 3.6249137920783716, 3.6496575181789317, 3.6742346141747673, 3.6986484017813863, 3.722902093797257, 3.7469987990390394, 3.7709415269929605, 3.7947331922020555, 3.8183766184073566, 3.84187454245971, 3.8652296180175374, 3.8884444190447165, 3.9115214431215897, 3.9344631145812006, 3.957271787481876, 3.97994974842648, 4.0024992192379, 4.024922359499621, 4.047221268969612, 4.069397989875161, 4.091454509095757, 4.113392760240627, 4.135214625627066, 4.156921938165306, 4.178516483155236, 4.2, 4.221374183841087, 4.242640687119286, 4.263801121065569], [0.0, 0.43588989435406744, 0.6164414002968976, 0.7549834435270751, 0.8717797887081349, 0.9746794344808966, 1.0677078252031313, 1.1532562594670797, 1.2328828005937953, 1.307669683062202, 1.3784048752090223, 1.4456832294800963, 1.5099668870541503, 1.5716233645501714, 1.6309506430300091, 1.6881943016134133, 1.7435595774162698, 1.797220075561143, 1.8493242008906932, 1.9000000000000004, 1.9493588689617931, 1.9974984355438181, 2.0445048300260877, 2.0904544960366875, 2.1354156504062627, 2.179449471770337, 2.2226110770892875, 2.2649503305812253, 2.3065125189341593, 2.3473389188611007, 2.3874672772626644, 2.4269322199023198, 2.4657656011875906, 2.503996805109783, 2.5416530054277673, 2.5787593916455256, 2.615339366124404, 2.651414716712571, 2.687005768508881, 2.7221315177632404, 2.7568097504180447, 2.791057147390573, 2.8248893783651075, 2.8583211855912904, 2.8913664589601926, 2.924038303442689, 2.956349099818897, 2.9883105594967874, 3.0199337741083006, 3.051229260478472, 3.082207001484489, 3.1128764832546767, 3.1432467291003428, 3.1733263305244868, 3.203123475609394, 3.232645975048923, 3.2619012860600183, 3.290896534380867, 3.319638534539567, 3.3481338085566414, 3.3763886032268267, 3.4044089061098406, 3.432200460346103, 3.4597687784012394, 3.4871191548325395, 3.5142566781611158, 3.541186241925155, 3.567912554982255, 3.594440151122286, 3.6207733980463352, 3.6469165057620945, 3.672873534441392, 3.6986484017813863, 3.7242448899072147, 3.749666651850535, 3.7749172176353754, 3.8000000000000007, 3.824918299781056, 3.8496753109840323, 3.874274125562104, 3.8987177379235862, 3.9230090491866068, 3.947150871198111, 3.9711459303329564, 3.9949968710876362, 4.018706259482024, 4.042276586281548, 4.065710270051225, 4.0890096600521755, 4.112177038990418, 4.135214625627067, 4.158124577258358, 4.180908992073375, 4.203569911396741, 4.226109321823088, 4.2485291572496005, 4.270831300812525, 4.293017586733137, 4.315089802078284, 4.337049688440289, 4.358898943540674, 4.380639222761903], [0.0, 0.447213595499958, 0.6324555320336759, 0.7745966692414835, 0.894427190999916, 1.0000000000000002, 1.0954451150103324, 1.1832159566199234, 1.2649110640673518, 1.3416407864998738, 1.4142135623730951, 1.4832396974191329, 1.549193338482967, 1.61245154965971, 1.6733200530681511, 1.7320508075688772, 1.788854381999832, 1.8439088914585775, 1.8973665961010278, 1.9493588689617931, 2.0000000000000004, 2.04939015319192, 2.0976176963403033, 2.144761058952722, 2.1908902300206647, 2.23606797749979, 2.280350850198276, 2.3237900077244507, 2.366431913239847, 2.4083189157584592, 2.4494897427831783, 2.489979919597747, 2.5298221281347035, 2.5690465157330262, 2.60768096208106, 2.6457513110645907, 2.6832815729997477, 2.720294101747089, 2.7568097504180447, 2.7928480087537886, 2.8284271247461903, 2.863564212655271, 2.8982753492378883, 2.932575659723036, 2.9664793948382657, 3.0, 3.0331501776206204, 3.0659419433511785, 3.098386676965934, 3.130495168499706, 3.1622776601683795, 3.193743884534263, 3.22490309931942, 3.255764119219942, 3.286335345030997, 3.3166247903554003, 3.3466401061363023, 3.3763886032268267, 3.405877273185281, 3.4351128074635335, 3.4641016151377544, 3.492849839314596, 3.521363372331802, 3.5496478698597698, 3.577708763999664, 3.605551275463989, 3.6331804249169903, 3.6606010435446255, 3.687817782917155, 3.7148351242013424, 3.7416573867739418, 3.768288736283355, 3.7947331922020555, 3.82099463490856, 3.847076812334269, 3.872983346207417, 3.8987177379235862, 3.924283374069717, 3.9496835316263006, 3.9749213828703587, 4.000000000000001, 4.024922359499622, 4.049691346263318, 4.0743097574926725, 4.09878030638384, 4.123105625617661, 4.147288270665545, 4.171330722922843, 4.1952353926806065, 4.219004621945797, 4.242640687119286, 4.266145801540309, 4.289522117905444, 4.312771730569565, 4.335896677735761, 4.358898943540674, 4.3817804600413295, 4.404543109109049, 4.427188724235731, 4.449719092257398, 4.47213595499958, 4.494441010848847], [0.0, 0.45825756949558405, 0.6480740698407861, 0.7937253933193773, 0.9165151389911681, 1.02469507659596, 1.1224972160321824, 1.2124355652982142, 1.2961481396815722, 1.374772708486752, 1.449137674618944, 1.5198684153570665, 1.5874507866387546, 1.6522711641858308, 1.7146428199482247, 1.7748239349298847, 1.8330302779823362, 1.8894443627691184, 1.9442222095223582, 1.9974984355438181, 2.04939015319192, 2.1, 2.149418526020468, 2.1977260975835913, 2.244994432064365, 2.2912878474779204, 2.336664289109585, 2.381176179958132, 2.4248711305964283, 2.4677925358506134, 2.5099800796022267, 2.551470164434615, 2.5922962793631443, 2.632489316217637, 2.672077843177478, 2.711088342345192, 2.749545416973504, 2.787471972953271, 2.824889378365107, 2.861817604250837, 2.898275349237888, 2.934280150224242, 2.9698484809835, 3.004995840263344, 3.039736830714133, 3.0740852297878796, 3.108054053584011, 3.1416556144810017, 3.174901573277509, 3.2078029864690882, 3.2403703492039306, 3.272613634390715, 3.3045423283716615, 3.336165463522456, 3.3674916480965478, 3.398529093593286, 3.4292856398964493, 3.459768778401239, 3.48998567332303, 3.5199431813596083, 3.5496478698597693, 3.5791060336346563, 3.608323710533743, 3.6373066958946425, 3.6660605559646724, 3.6945906403822333, 3.722902093797257, 3.7509998667022106, 3.778888725538237, 3.8065732621348563, 3.834057902536163, 3.861346915261565, 3.8884444190447165, 3.915354390090379, 3.9420806688854046, 3.968626966596886, 3.9949968710876362, 4.02119385257662, 4.047221268969613, 4.07308237088326, 4.09878030638384, 4.124318125460256, 4.149698784249287, 4.174925149029621, 4.2, 4.224926034855522, 4.249705872175156, 4.274342054632503, 4.298837052040936, 4.323193264243457, 4.347413023856832, 4.371498598878879, 4.3954521951671826, 4.419275958796871, 4.442971978304612, 4.466542286825459, 4.48998886412873, 4.513313638558704, 4.536518488885503, 4.559605246071199, 4.582575694955841, 4.605431575867782], [0.0, 0.469041575982343, 0.6633249580710799, 0.8124038404635961, 0.938083151964686, 1.0488088481701516, 1.148912529307606, 1.2409673645990857, 1.3266499161421599, 1.407124727947029, 1.4832396974191326, 1.5556349186104048, 1.6248076809271923, 1.6911534525287764, 1.7549928774784245, 1.816590212458495, 1.876166303929372, 1.9339079605813716, 1.98997487421324, 2.0445048300260877, 2.0976176963403033, 2.149418526020468, 2.2, 2.249444375840399, 2.297825058615212, 2.345207879911715, 2.3916521486202797, 2.4372115213907883, 2.4819347291981715, 2.5258661880630178, 2.569046515733026, 2.6115129714401193, 2.6532998322843198, 2.6944387170614963, 2.734958866235469, 2.7748873851023217, 2.814249455894058, 2.8530685235374214, 2.891366458960192, 2.9291637031753623, 2.9664793948382653, 3.0033314835362415, 3.039736830714133, 3.0757112998459397, 3.1112698372208096, 3.1464265445104544, 3.1811947441173736, 3.2155870381627056, 3.2496153618543846, 3.283291031876401, 3.3166247903554003, 3.3496268448888458, 3.3823069050575527, 3.414674215792775, 3.4467375879228173, 3.4785054261852175, 3.509985754956849, 3.5411862419251547, 3.5721142198983507, 3.602776706930364, 3.63318042491699, 3.6633318168028404, 3.6932370625238775, 3.722902093797257, 3.752332607858744, 3.7815340802378072, 3.81051177665153, 3.8392707640904935, 3.867815921162743, 3.8961519477556315, 3.924283374069717, 3.952214569073901, 3.97994974842648, 4.007492981902776, 4.034848200366403, 4.06201920231798, 4.0890096600521755, 4.115823125451336, 4.1424630354415966, 4.168932717135166, 4.1952353926806065, 4.221374183841087, 4.247352116319061, 4.273172123844299, 4.298837052040936, 4.324349662087931, 4.349712634186309, 4.374928570845472, 4.4, 4.424929377967517, 4.449719092257398, 4.474371464239419, 4.498888751680798, 4.523273151159457, 4.54752680036083, 4.571651780264984, 4.595650117230424, 4.61952378498044, 4.64327470649756, 4.666904755831214, 4.69041575982343, 4.713809499757071], [0.0, 0.479583152331272, 0.6782329983125268, 0.8306623862918077, 0.959166304662544, 1.072380529476361, 1.174734012447073, 1.2688577540449522, 1.3564659966250536, 1.438749456993816, 1.5165750888103102, 1.5905973720586868, 1.6613247725836153, 1.7291616465790585, 1.7944358444926363, 1.857417562100671, 1.918332609325088, 1.977371993328519, 2.0346989949375804, 2.0904544960366875, 2.144761058952722, 2.1977260975835913, 2.249444375840399, 2.3000000000000003, 2.349468024894146, 2.39791576165636, 2.4454038521274972, 2.491987158875423, 2.5377155080899043, 2.582634314028992, 2.6267851073127395, 2.670205984563738, 2.7129319932501073, 2.754995462791183, 2.7964262908219126, 2.8372521918222215, 2.877498913987632, 2.917190429162965, 2.956349099818897, 2.994995826374388, 3.0331501776206204, 3.0708305065568178, 3.108054053584011, 3.1448370387032774, 3.1811947441173736, 3.2171415884290826, 3.252691193458119, 3.2878564445547194, 3.3226495451672307, 3.357082066318904, 3.3911649915626345, 3.4249087579087423, 3.458323293158117, 3.491418050019219, 3.5242020373412197, 3.5566838487557484, 3.5888716889852725, 3.620773398046335, 3.6523964735499352, 3.6837480912787726, 3.714835124201342, 3.745664160065609, 3.7762415176998414, 3.8065732621348563, 3.836665218650176, 3.866522985836241, 3.8961519477556315, 3.9255572852781047, 3.954743986657038, 3.9837168574084183, 4.012480529547776, 4.041039470235351, 4.069397989875161, 4.097560249709576, 4.125530268947254, 4.153311931459037, 4.180908992073375, 4.2083250825001635, 4.235563716909475, 4.262628297189424, 4.289522117905444, 4.316248370981448, 4.342810150121694, 4.369210454990696, 4.3954521951671826, 4.421538193886829, 4.447471191587417, 4.473253849269009, 4.498888751680798, 4.524378410345448, 4.549725266430931, 4.57493169347915, 4.6000000000000005, 4.624932431938872, 4.649731175025068, 4.674398357008098, 4.698936049788292, 4.723346271447818, 4.747630988187688, 4.77179211617606, 4.79583152331272, 4.819751030914357], [0.0, 0.48989794855663565, 0.6928203230275509, 0.8485281374238571, 0.9797958971132713, 1.0954451150103324, 1.2000000000000002, 1.2961481396815722, 1.3856406460551018, 1.469693845669907, 1.5491933384829668, 1.6248076809271923, 1.6970562748477143, 1.7663521732655696, 1.833030277982336, 1.8973665961010275, 1.9595917942265426, 2.0199009876724157, 2.078460969082653, 2.1354156504062627, 2.1908902300206647, 2.244994432064365, 2.297825058615212, 2.349468024894146, 2.4000000000000004, 2.4494897427831783, 2.4979991993593598, 2.5455844122715714, 2.5922962793631443, 2.638181191654584, 2.6832815729997477, 2.727636339397171, 2.7712812921102037, 2.8142494558940583, 2.8565713714171403, 2.898275349237888, 2.939387691339814, 2.979932885150268, 3.0199337741083, 3.0594117081556713, 3.0983866769659336, 3.136877428271625, 3.174901573277509, 3.212475680841802, 3.2496153618543846, 3.2863353450309964, 3.32264954516723, 3.358571124749333, 3.3941125496954285, 3.4292856398964493, 3.464101615137755, 3.498571136907181, 3.532704346531139, 3.5665109000254023, 3.6, 3.6331804249169903, 3.666060555964672, 3.698648401781386, 3.7309516212355263, 3.7629775444453557, 3.794733192202055, 3.8262252939417984, 3.857460304397182, 3.8884444190447165, 3.9191835884530852, 3.9496835316262997, 3.97994974842648, 4.009987531152684, 4.039801975344831, 4.069397989875161, 4.09878030638384, 4.127953488110059, 4.156921938165306, 4.18568990729127, 4.214261501141095, 4.242640687119286, 4.270831300812525, 4.298837052040936, 4.3266615305567875, 4.354308211415448, 4.3817804600413295, 4.409081537009721, 4.436214602563767, 4.463182720884279, 4.48998886412873, 4.5166359162544865, 4.543126676640219, 4.5694638635183455, 4.595650117230424, 4.621688003316537, 4.6475800154489, 4.673328578219169, 4.698936049788292, 4.724404724407087, 4.749736834815168, 4.774934554525329, 4.800000000000001, 4.824935232725928, 4.849742261192857, 4.874423042781577, 4.898979485566357, 4.9234134500364695], [0.0, 0.5, 0.7071067811865476, 0.8660254037844388, 1.0, 1.118033988749895, 1.2247448713915892, 1.3228756555322954, 1.4142135623730951, 1.5, 1.5811388300841898, 1.6583123951777001, 1.7320508075688776, 1.8027756377319948, 1.8708286933869707, 1.9364916731037083, 2.0, 2.0615528128088303, 2.121320343559643, 2.179449471770337, 2.23606797749979, 2.2912878474779204, 2.345207879911715, 2.39791576165636, 2.4494897427831783, 2.5000000000000004, 2.5495097567963927, 2.5980762113533165, 2.6457513110645907, 2.6925824035672523, 2.7386127875258306, 2.783882181415011, 2.8284271247461903, 2.8722813232690148, 2.9154759474226504, 2.958039891549808, 3.0, 3.04138126514911, 3.0822070014844885, 3.1224989991991996, 3.1622776601683795, 3.2015621187164247, 3.2403703492039306, 3.278719262151, 3.3166247903554003, 3.3541019662496843, 3.3911649915626345, 3.4278273002005224, 3.4641016151377553, 3.5, 3.535533905932738, 3.5707142142714257, 3.6055512754639896, 3.64005494464026, 3.6742346141747677, 3.708099243547832, 3.7416573867739413, 3.774917217635375, 3.8078865529319548, 3.840572873934304, 3.8729833462074166, 3.9051248379533274, 3.9370039370059056, 3.968626966596886, 4.0, 4.031128874149275, 4.06201920231798, 4.092676385936225, 4.123105625617661, 4.153311931459037, 4.183300132670378, 4.2130748865881795, 4.242640687119286, 4.272001872658766, 4.301162633521313, 4.330127018922194, 4.358898943540674, 4.387482193696061, 4.415880433163924, 4.444097208657795, 4.47213595499958, 4.500000000000001, 4.527692569068709, 4.55521678957215, 4.582575694955841, 4.609772228646444, 4.636809247747852, 4.663689526544408, 4.69041575982343, 4.716990566028302, 4.743416490252569, 4.769696007084729, 4.79583152331272, 4.821825380496478, 4.847679857416329, 4.873397172404482, 4.898979485566357, 4.924428900898053, 4.949747468305833, 4.974937185533101, 5.000000000000001, 5.024937810560446], [0.0, 0.5099019513592785, 0.7211102550927979, 0.8831760866327849, 1.019803902718557, 1.140175425099138, 1.2489995996796799, 1.3490737563232043, 1.4422205101855958, 1.5297058540778354, 1.61245154965971, 1.6911534525287766, 1.7663521732655698, 1.8384776310850237, 1.9078784028338913, 1.9748417658131499, 2.039607805437114, 2.102379604162864, 2.1633307652783937, 2.2226110770892875, 2.280350850198276, 2.336664289109585, 2.3916521486202797, 2.4454038521274972, 2.4979991993593598, 2.5495097567963927, 2.6000000000000005, 2.6495282598983545, 2.6981475126464085, 2.7459060435491964, 2.792848008753788, 2.839013913315678, 2.8844410203711917, 2.9291637031753623, 2.973213749463701, 3.0166206257996713, 3.059411708155671, 3.101612483854165, 3.1432467291003428, 3.1843366656181322, 3.22490309931942, 3.264965543462902, 3.304542328371662, 3.3436506994600976, 3.382306905057553, 3.420526275297414, 3.458323293158117, 3.4957116585897072, 3.5327043465311396, 3.5693136595149495, 3.6055512754639896, 3.6414282912066254, 3.6769552621700474, 3.712142238654118, 3.7469987990390394, 3.7815340802378077, 3.8157568056677826, 3.849675310984032, 3.8832975677895205, 3.916631205513228, 3.9496835316262997, 3.9824615503479754, 4.014971979976946, 4.047221268969613, 4.079215610874228, 4.110960958218893, 4.142463035441596, 4.173727350941841, 4.204759208325728, 4.235563716909475, 4.266145801540309, 4.296510211788167, 4.3266615305567875, 4.356604182158393, 4.386342439892262, 4.415880433163924, 4.445222154178575, 4.474371464239419, 4.503332099679082, 4.532107677449864, 4.560701700396552, 4.589117562233507, 4.617358552246079, 4.645427859734774, 4.67332857821917, 4.701063709417264, 4.7286361670147565, 4.756048780237647, 4.7833042972405595, 4.810405388322278, 4.83735464897913, 4.864154602806124, 4.8908077042549944, 4.917316341257699, 4.943682837723311, 4.969909455915671, 4.9959983987187195, 5.021951811795889, 5.047771785649585, 5.073460357586329, 5.099019513592785, 5.1244511901275835], [0.0, 0.5196152422706632, 0.7348469228349535, 0.9000000000000001, 1.0392304845413265, 1.1618950038622253, 1.2727922061357857, 1.374772708486752, 1.469693845669907, 1.5588457268119895, 1.6431676725154984, 1.7233687939614089, 1.8000000000000003, 1.8734993995195197, 1.9442222095223582, 2.0124611797498106, 2.078460969082653, 2.142428528562855, 2.2045407685048604, 2.2649503305812253, 2.3237900077244507, 2.381176179958132, 2.4372115213907883, 2.491987158875423, 2.5455844122715714, 2.5980762113533165, 2.6495282598983545, 2.7, 2.749545416973504, 2.7982137159266447, 2.8460498941515415, 2.8930952282978866, 2.939387691339814, 2.9849623113198605, 3.0298514815086235, 3.0740852297878796, 3.117691453623979, 3.160696125855822, 3.203123475609394, 3.244996147917591, 3.286335345030997, 3.3271609519228256, 3.3674916480965478, 3.407345007480164, 3.4467375879228177, 3.4856850115866753, 3.5242020373412197, 3.5623026261113755, 3.6000000000000005, 3.6373066958946425, 3.6742346141747677, 3.7107950630558952, 3.7469987990390394, 3.782856063875548, 3.818376618407357, 3.853569773599539, 3.8884444190447165, 3.9230090491866063, 3.957271787481876, 3.9912404086950213, 4.024922359499621, 4.058324777540605, 4.091454509095756, 4.124318125460256, 4.156921938165306, 4.189272013130682, 4.221374183841087, 4.253234063627348, 4.28485705712571, 4.316248370981448, 4.3474130238568325, 4.378355855797928, 4.409081537009721, 4.439594576084623, 4.469899327725402, 4.5, 4.529900661162451, 4.559605246071199, 4.589117562233508, 4.618441295502196, 4.647580015448901, 4.676537180435969, 4.705316142407438, 4.73392015141785, 4.762352359916264, 4.790615826801394, 4.818713521262704, 4.846648326421054, 4.874423042781577, 4.902040391510457, 4.929503017546495, 4.956813492557492, 4.983974317750846, 5.0109879265470205, 5.037856687124, 5.06458290484024, 5.091168824543143, 5.117616632769595, 5.143928459844674, 5.170106381884226, 5.196152422706633, 5.222068555658764], [0.0, 0.5291502622129182, 0.7483314773547882, 0.9165151389911681, 1.0583005244258363, 1.1832159566199234, 1.2961481396815722, 1.4000000000000001, 1.4966629547095764, 1.5874507866387544, 1.6733200530681511, 1.7549928774784245, 1.8330302779823362, 1.9078784028338915, 1.9798989873223332, 2.0493901531919194, 2.1166010488516727, 2.181742422927143, 2.244994432064365, 2.3065125189341593, 2.366431913239847, 2.4248711305964283, 2.4819347291981715, 2.5377155080899043, 2.5922962793631443, 2.6457513110645907, 2.6981475126464085, 2.749545416973504, 2.8000000000000003, 2.8495613697550017, 2.8982753492378874, 2.946183972531247, 2.993325909419153, 3.039736830714133, 3.0854497241083028, 3.1304951684997055, 3.1749015732775088, 3.2186953878862163, 3.2619012860600183, 3.3045423283716615, 3.3466401061363023, 3.3882148692194836, 3.4292856398964497, 3.4698703145794942, 3.509985754956849, 3.5496478698597693, 3.5888716889852725, 3.627671429443411, 3.6660605559646724, 3.704051835490427, 3.7416573867739418, 3.7788887255382373, 3.815756805667783, 3.852272056851645, 3.8884444190447165, 3.924283374069717, 3.9597979746446663, 3.994996871087636, 4.029888335921977, 4.064480286580315, 4.098780306383839, 4.132795663954365, 4.166533331199932, 4.2, 4.233202097703345, 4.266145801540308, 4.298837052040936, 4.331281565541543, 4.363484845854286, 4.3954521951671826, 4.427188724235731, 4.458699361921591, 4.48998886412873, 4.521061822182926, 4.551922670696417, 4.58257569495584, 4.613025037868319, 4.64327470649756, 4.67332857821917, 4.703190406521939, 4.732863826479694, 4.762352359916263, 4.791659420284376, 4.82078831727758, 4.849742261192857, 4.878524367060187, 4.907137658554119, 4.935585071701227, 4.963869458396343, 4.991993589739474, 5.019960159204453, 5.047771785649585, 5.075431016179809, 5.10294032886923, 5.130302135352265, 5.15751878329105, 5.184592558726289, 5.2115256883181535, 5.238320341483518, 5.264978632435274, 5.291502622129181, 5.317894320123333], [0.0, 0.5385164807134505, 0.7615773105863909, 0.9327379053088817, 1.077032961426901, 1.2041594578792296, 1.319090595827292, 1.4247806848775009, 1.5231546211727818, 1.6155494421403513, 1.7029386365926402, 1.7860571099491753, 1.8654758106177634, 1.94164878389476, 2.0149441679609885, 2.085665361461421, 2.154065922853802, 2.220360331117452, 2.2847319317591728, 2.3473389188611007, 2.4083189157584592, 2.4677925358506134, 2.5258661880630178, 2.582634314028992, 2.638181191654584, 2.6925824035672523, 2.7459060435491964, 2.7982137159266447, 2.8495613697550017, 2.9000000000000004, 2.9495762407505253, 2.99833287011299, 3.0463092423455636, 3.0935416596516045, 3.1400636936215167, 3.1859064644147983, 3.2310988842807027, 3.2756678708318403, 3.3196385345395667, 3.363034344160048, 3.4058772731852804, 3.448187929913334, 3.48998567332303, 3.531288716601915, 3.5721142198983507, 3.6124783736376886, 3.6523964735499352, 3.691882988394947, 3.7309516212355267, 3.769615364994153, 3.8078865529319548, 3.845776904605883, 3.88329756778952, 3.9204591567825324, 3.957271787481876, 3.993745109543172, 4.029888335921977, 4.065710270051224, 4.101219330881976, 4.136423575989287, 4.171330722922842, 4.205948168962618, 4.240283009422838, 4.274342054632503, 4.308131845707604, 4.341658669218482, 4.374928570845472, 4.407947368106838, 4.440720662234904, 4.473253849269009, 4.505552130427525, 4.537620521815371, 4.5694638635183455, 4.601086828130937, 4.632493928760188, 4.663689526544408, 4.694677837722201, 4.725462940284264, 4.756048780237647, 4.786439177509728, 4.8166378315169185, 4.846648326421054, 4.876474136094644, 4.906118628814432, 4.935585071701227, 4.964876634922565, 4.993996395673509, 5.022947341949744, 5.0517323761260355, 5.0803543183522155, 5.10881590977792, 5.137119815616529, 5.165268628057984, 5.193264869039514, 5.221110992882646, 5.2488093888042835, 5.276362383309168, 5.3037722424704485, 5.331041174104736, 5.358171329847527, 5.385164807134505, 5.412023651093924], [0.0, 0.5477225575051661, 0.7745966692414833, 0.9486832980505139, 1.0954451150103321, 1.2247448713915892, 1.3416407864998738, 1.4491376746189437, 1.5491933384829666, 1.6431676725154982, 1.7320508075688772, 1.816590212458495, 1.8973665961010278, 1.9748417658131499, 2.0493901531919194, 2.1213203435596424, 2.1908902300206643, 2.258317958127243, 2.32379000772445, 2.3874672772626644, 2.4494897427831783, 2.5099800796022267, 2.569046515733026, 2.6267851073127395, 2.6832815729997477, 2.7386127875258306, 2.792848008753788, 2.8460498941515415, 2.8982753492378874, 2.9495762407505253, 2.9999999999999996, 3.049590136395381, 3.098386676965933, 3.146426544510455, 3.1937438845342623, 3.2403703492039297, 3.2863353450309964, 3.331666249791536, 3.376388603226826, 3.420526275297414, 3.4641016151377544, 3.5071355833500366, 3.5496478698597698, 3.5916569992135936, 3.63318042491699, 3.674234614174767, 3.714835124201342, 3.7549966711037173, 3.7947331922020555, 3.8340579025361627, 3.872983346207417, 3.9115214431215892, 3.9496835316262997, 3.9874804074753776, 4.024922359499621, 4.06201920231798, 4.098780306383839, 4.135214625627066, 4.171330722922842, 4.207136793592525, 4.242640687119285, 4.277849927241487, 4.3127717305695645, 4.347413023856832, 4.381780460041329, 4.415880433163923, 4.449719092257397, 4.483302354291978, 4.516635916254486, 4.54972526643093, 4.58257569495584, 4.61519230368573, 4.6475800154489, 4.679743582719036, 4.711687595755898, 4.743416490252569, 4.774934554525329, 4.806245936279166, 4.83735464897913, 4.868264577855234, 4.898979485566357, 4.929503017546495, 4.959838707054898, 4.9899899799498595, 5.019960159204453, 5.049752469181039, 5.079370039680118, 5.10881590977792, 5.138093031466052, 5.167204273105525, 5.196152422706632, 5.224940191045253, 5.253570214625479, 5.282045058497703, 5.310367218940701, 5.338539126015655, 5.366563145999495, 5.394441583704471, 5.422176684690383, 5.449770637375485, 5.477225575051661, 5.504543577809154], [0.0, 0.5567764362830022, 0.7874007874011811, 0.9643650760992957, 1.1135528725660044, 1.2449899597988734, 1.3638181696985856, 1.4730919862656235, 1.5748015748023623, 1.6703293088490065, 1.760681686165901, 1.846618531261939, 1.9287301521985913, 2.0074859899884734, 2.083266665599966, 2.1563858652847823, 2.227105745132009, 2.2956480566497994, 2.3622023622035435, 2.4269322199023198, 2.489979919597747, 2.551470164434615, 2.6115129714401193, 2.670205984563738, 2.727636339397171, 2.783882181415011, 2.839013913315678, 2.8930952282978866, 2.946183972531247, 2.99833287011299, 3.049590136395381, 3.1, 3.1496031496047245, 3.1984371183438953, 3.2465366161495854, 3.2939338184001206, 3.340658617698013, 3.38673884437522, 3.432200460346103, 3.477067730142742, 3.521363372331802, 3.5651086939951777, 3.6083237105337433, 3.6510272527057364, 3.693237062523878, 3.7349698793966195, 3.7762415176998414, 3.817066936798463, 3.8574603043971827, 3.8974350539810154, 3.9370039370059056, 3.9761790704142093, 4.014971979976947, 4.053393639902249, 4.091454509095757, 4.129164564412516, 4.166533331199932, 4.20356991139674, 4.240283009422838, 4.276680956068619, 4.3127717305695645, 4.34856298103178, 4.384062043356595, 4.419275958796871, 4.454211490264018, 4.488875137492688, 4.523273151159456, 4.557411546042337, 4.591296113299599, 4.624932431938872, 4.658325879540847, 4.69148164229596, 4.724404724407087, 4.757099956906519, 4.789572005931219, 4.8218253804964775, 4.8538644398046396, 4.8856934001224435, 4.917316341257699, 4.948737212663449, 4.979959839195494, 5.01098792654702, 5.041825066382213, 5.072474741188959, 5.10294032886923, 5.13322510708424, 5.163332257370235, 5.193264869039514, 5.223025942880239, 5.252618394667558, 5.282045058497703, 5.3113086899558, 5.340411969127476, 5.36935750346352, 5.398147830506312, 5.426785420486054, 5.455272678794342, 5.483611948342078, 5.511805511808268, 5.539855593785817, 5.567764362830022, 5.595533933415113], [0.0, 0.565685424949238, 0.7999999999999999, 0.9797958971132713, 1.131370849898476, 1.2649110640673518, 1.3856406460551018, 1.4966629547095764, 1.5999999999999999, 1.697056274847714, 1.7888543819998317, 1.876166303929372, 1.9595917942265426, 2.039607805437114, 2.116601048851672, 2.1908902300206643, 2.262741699796952, 2.33238075793812, 2.4, 2.4657656011875906, 2.5298221281347035, 2.5922962793631443, 2.6532998322843198, 2.7129319932501073, 2.7712812921102037, 2.8284271247461903, 2.8844410203711917, 2.939387691339814, 2.993325909419153, 3.0463092423455636, 3.098386676965933, 3.1496031496047245, 3.1999999999999997, 3.249615361854384, 3.2984845004941286, 3.3466401061363023, 3.394112549695428, 3.4409301068170506, 3.487119154832539, 3.5327043465311387, 3.5777087639996634, 3.622154055254967, 3.6660605559646724, 3.709447398198281, 3.752332607858744, 3.7947331922020546, 3.8366652186501757, 3.878143885933063, 3.9191835884530852, 3.959797974644666, 4.0, 4.039801975344831, 4.079215610874228, 4.118252056394801, 4.156921938165306, 4.1952353926806065, 4.233202097703344, 4.2708313008125245, 4.308131845707603, 4.345112196480086, 4.381780460041329, 4.418144406874904, 4.454211490264017, 4.48998886412873, 4.525483399593904, 4.560701700396551, 4.595650117230423, 4.63033476111609, 4.66476151587624, 4.698936049788292, 4.732863826479693, 4.766550115125193, 4.8, 4.833218389437829, 4.866210024238575, 4.898979485566356, 4.931531202375181, 4.963869458396343, 4.995998398718719, 5.027922035990614, 5.059644256269407, 5.091168824543142, 5.122499389946279, 5.15363949069005, 5.184592558726289, 5.215361924162119, 5.2459508194416005, 5.276362383309167, 5.3065996645686395, 5.336665625650533, 5.366563145999495, 5.396295025292816, 5.4258639865002145, 5.455272678794342, 5.4845236803208355, 5.513619500836088, 5.542562584220407, 5.571355310873648, 5.6, 5.628498911788116, 5.656854249492381, 5.685068161420759], [0.0, 0.574456264653803, 0.812403840463596, 0.9949874371066202, 1.148912529307606, 1.2845232578665131, 1.4071247279470291, 1.5198684153570665, 1.624807680927192, 1.7233687939614086, 1.8165902124584952, 1.9052558883257653, 1.9899748742132404, 2.0712315177207983, 2.149418526020468, 2.224859546128699, 2.297825058615212, 2.3685438564654024, 2.4372115213907883, 2.503996805109783, 2.5690465157330262, 2.632489316217637, 2.6944387170614963, 2.754995462791183, 2.8142494558940583, 2.8722813232690148, 2.9291637031753623, 2.9849623113198605, 3.039736830714133, 3.0935416596516045, 3.146426544510455, 3.1984371183438953, 3.249615361854384, 3.3000000000000007, 3.3496268448888458, 3.398529093593286, 3.4467375879228173, 3.49428104193123, 3.541186241925155, 3.58747822293042, 3.6331804249169903, 3.678314831549905, 3.7229020937972575, 3.7669616403674726, 3.8105117766515306, 3.853569773599539, 3.896151947755632, 3.9382737335030438, 3.9799497484264807, 4.02119385257662, 4.06201920231798, 4.102438299353204, 4.1424630354415966, 4.182104733265298, 4.221374183841087, 4.260281680828159, 4.298837052040936, 4.337049688440288, 4.374928570845472, 4.412482294582042, 4.449719092257398, 4.486646854834912, 4.523273151159457, 4.559605246071199, 4.595650117230424, 4.631414470763764, 4.666904755831214, 4.702127178203499, 4.737087712930805, 4.77179211617606, 4.806245936279167, 4.8404545241123795, 4.874423042781577, 4.908156476723211, 4.941659640242335, 4.974937185533101, 5.007993610219566, 5.040833264451424, 5.07346035758633, 5.105878964487898, 5.1380930314660525, 5.170106381884226, 5.201922721455982, 5.23354564325181, 5.264978632435274, 5.296225070746145, 5.327288240746882, 5.358171329847526, 5.388877434122993, 5.419409561935692, 5.449770637375486, 5.479963503528103, 5.509990925582366, 5.539855593785817, 5.569560126257729, 5.599107071667768, 5.628498911788117, 5.657738063926256, 5.686826883245173, 5.715767664977296, 5.7445626465380295, 5.773214009544425], [0.0, 0.5830951894845301, 0.8246211251235321, 1.009950493836208, 1.1661903789690602, 1.30384048104053, 1.4282856857085702, 1.5427248620541514, 1.6492422502470643, 1.7492855684535902, 1.8439088914585775, 1.9339079605813718, 2.019900987672416, 2.102379604162864, 2.181742422927143, 2.258317958127243, 2.3323807579381204, 2.4041630560342617, 2.4738633753705965, 2.5416530054277673, 2.60768096208106, 2.672077843177478, 2.734958866235469, 2.7964262908219126, 2.8565713714171403, 2.9154759474226504, 2.973213749463701, 3.0298514815086235, 3.0854497241083028, 3.1400636936215167, 3.1937438845342623, 3.2465366161495854, 3.2984845004941286, 3.3496268448888458, 3.4000000000000004, 3.449637662132068, 3.4985711369071804, 3.54682957019364, 3.594440151122286, 3.6414282912066254, 3.687817782917155, 3.733630940518894, 3.7788887255382373, 3.823610858861032, 3.8678159211627436, 3.911521443121589, 3.954743986657038, 3.997499218261337, 4.039801975344832, 4.08166632639171, 4.123105625617661, 4.164132562731403, 4.204759208325728, 4.244997055358225, 4.28485705712571, 4.324349662087931, 4.363484845854286, 4.402272140611028, 4.440720662234904, 4.4788391353117385, 4.516635916254486, 4.5541190146942805, 4.591296113299598, 4.628174586162454, 4.664761515876241, 4.701063709417263, 4.737087712930805, 4.77283982551269, 4.8083261120685235, 4.843552415324934, 4.878524367060187, 4.913247398615299, 4.947726750741193, 4.98196748283246, 5.015974481593781, 5.049752469181039, 5.083306010855535, 5.1166395221864125, 5.149757275833494, 5.182663407939976, 5.21536192416212, 5.247856705360771, 5.280151512977635, 5.31224999411737, 5.344155686354956, 5.375872022286245, 5.40740233383831, 5.4387498563548595, 5.469917732470938, 5.500909015790026, 5.531726674375733, 5.562373594069352, 5.592852581643825, 5.62316636780382, 5.653317610041029, 5.683308895353129, 5.713142742834281, 5.742821606144492, 5.772347875864725, 5.801723881744115, 5.830951894845301, 5.860034129593445], [0.0, 0.5916079783099616, 0.8366600265340756, 1.02469507659596, 1.1832159566199232, 1.3228756555322954, 1.449137674618944, 1.5652475842498528, 1.6733200530681511, 1.7748239349298847, 1.8708286933869707, 1.9621416870348585, 2.04939015319192, 2.1330729007701543, 2.2135943621178655, 2.29128784747792, 2.3664319132398464, 2.4392621835300936, 2.5099800796022267, 2.5787593916455256, 2.6457513110645907, 2.711088342345192, 2.7748873851023217, 2.8372521918222215, 2.898275349237888, 2.958039891549808, 3.0166206257996713, 3.0740852297878796, 3.1304951684997055, 3.1859064644147983, 3.2403703492039297, 3.2939338184001206, 3.3466401061363023, 3.398529093593286, 3.449637662132068, 3.5, 3.5496478698597693, 3.5986108430893164, 3.646916505762094, 3.6945906403822333, 3.7416573867739413, 3.7881393849751626, 3.834057902536163, 3.879432948254164, 3.924283374069717, 3.9686269665968856, 4.012480529547776, 4.05585995813465, 4.09878030638384, 4.141255848169731, 4.183300132670378, 4.224926034855522, 4.266145801540309, 4.306971093471606, 4.347413023856832, 4.387482193696061, 4.427188724235731, 4.466542286825459, 4.505552130427525, 4.544227107000705, 4.58257569495584, 4.620606020859168, 4.658325879540846, 4.695742752749559, 4.732863826479693, 4.769696007084728, 4.806245936279166, 4.8425200051213, 4.878524367060187, 4.914264950122246, 4.949747468305833, 4.984977432245807, 5.019960159204453, 5.054700782440045, 5.089204259999788, 5.123475382979799, 5.157518783291051, 5.191338940966964, 5.2249401910452535, 5.2583267300539625, 5.291502622129181, 5.324471804789654, 5.35723809439155, 5.389805191284746, 5.422176684690384, 5.454356057317858, 5.486346689738081, 5.518151864528558, 5.549774770204643, 5.58121850495033, 5.612486080160912, 5.643580423808984, 5.674504383644443, 5.705260730238365, 5.735852159879995, 5.766281297335397, 5.796550698475776, 5.826662852782887, 5.856620185738529, 5.886425061104576, 5.916079783099616, 5.9455865984779], [0.0, 0.6, 0.848528137423857, 1.0392304845413265, 1.2, 1.3416407864998738, 1.469693845669907, 1.5874507866387544, 1.697056274847714, 1.7999999999999998, 1.8973665961010275, 1.98997487421324, 2.078460969082653, 2.1633307652783937, 2.244994432064365, 2.3237900077244498, 2.4, 2.473863375370596, 2.545584412271571, 2.615339366124404, 2.6832815729997477, 2.749545416973504, 2.814249455894058, 2.877498913987632, 2.939387691339814, 3.0, 3.059411708155671, 3.117691453623979, 3.1749015732775088, 3.2310988842807027, 3.2863353450309964, 3.340658617698013, 3.394112549695428, 3.4467375879228173, 3.4985711369071804, 3.5496478698597693, 3.5999999999999996, 3.6496575181789317, 3.698648401781386, 3.746998799039039, 3.794733192202055, 3.8418745424597094, 3.8884444190447165, 3.9344631145812, 3.97994974842648, 4.024922359499621, 4.069397989875161, 4.113392760240626, 4.156921938165306, 4.2, 4.242640687119285, 4.28485705712571, 4.3266615305567875, 4.368065933568311, 4.409081537009721, 4.449719092257398, 4.48998886412873, 4.52990066116245, 4.569463863518345, 4.608687448721165, 4.6475800154488995, 4.686149805543993, 4.724404724407086, 4.762352359916263, 4.8, 4.8373546489791295, 4.874423042781576, 4.91121166312347, 4.947726750741192, 4.983974317750845, 5.019960159204453, 5.0556898639058145, 5.091168824543142, 5.126402247190518, 5.161395160225576, 5.196152422706632, 5.230678732248808, 5.264978632435273, 5.299056519796709, 5.332916650389353, 5.366563145999495, 5.4, 5.43323108288245, 5.466260147486579, 5.499090833947008, 5.531726674375732, 5.5641710972974225, 5.596427431853289, 5.628498911788116, 5.660388679233962, 5.692099788303082, 5.7236352085016735, 5.754997827975264, 5.786190456595773, 5.817215828899595, 5.848076606885377, 5.878775382679628, 5.909314681077663, 5.939696961966999, 5.96992462263972, 6.0, 6.029925372672535], [0.0, 0.608276253029822, 0.8602325267042626, 1.053565375285274, 1.216552506059644, 1.3601470508735445, 1.489966442575134, 1.6093476939431082, 1.7204650534085253, 1.8248287590894658, 1.9235384061671346, 2.017424100183202, 2.107130750570548, 2.193171219946131, 2.2759613353482084, 2.355843797877949, 2.433105012119288, 2.5079872407968904, 2.5806975801127883, 2.651414716712571, 2.720294101747089, 2.787471972953271, 2.8530685235374214, 2.917190429162965, 2.979932885150268, 3.04138126514911, 3.101612483854165, 3.160696125855822, 3.2186953878862163, 3.2756678708318403, 3.331666249791536, 3.38673884437522, 3.4409301068170506, 3.49428104193123, 3.54682957019364, 3.5986108430893164, 3.6496575181789317, 3.7, 3.7496666518505353, 3.7986839826445165, 3.847076812334269, 3.89486841883009, 3.942080668885405, 3.988734135035826, 4.034848200366404, 4.080441152620633, 4.125530268947254, 4.170131892398609, 4.214261501141096, 4.257933771208754, 4.301162633521314, 4.343961325794695, 4.386342439892262, 4.428317965096906, 4.469899327725402, 4.511097427455985, 4.551922670696417, 4.592385001282014, 4.632493928760188, 4.672258554489466, 4.711687595755898, 4.750789408087881, 4.789572005931219, 4.828043081829325, 4.866210024238576, 4.904079934095691, 4.941659640242335, 4.978955713801841, 5.015974481593781, 5.052722038663912, 5.089204259999789, 5.1254268114957995, 5.1613951602255765, 5.197114584074513, 5.232590180780452, 5.26782687642637, 5.302829433425142, 5.3376024580330075, 5.372150407425318, 5.406477596365309, 5.440588203494178, 5.474486277268398, 5.508175741568166, 5.541660400998964, 5.574943945906542, 5.608029957123981, 5.640921910468182, 5.673623181001714, 5.706137047074843, 5.7384666941614295, 5.770615218501404, 5.8025856305616035, 5.83438085832593, 5.866003750424986, 5.897457079114693, 5.928743543112655, 5.959865770300536, 5.990826320300065, 6.021627686929839, 6.052272300549605, 6.08276253029822, 6.113100686231171], [0.0, 0.6164414002968976, 0.8717797887081348, 1.0677078252031313, 1.2328828005937953, 1.3784048752090223, 1.50996688705415, 1.6309506430300091, 1.7435595774162695, 1.849324200890693, 1.949358868961793, 2.0445048300260877, 2.1354156504062627, 2.222611077089287, 2.3065125189341593, 2.3874672772626644, 2.4657656011875906, 2.541653005427767, 2.615339366124404, 2.687005768508881, 2.7568097504180447, 2.824889378365107, 2.891366458960192, 2.956349099818897, 3.0199337741083, 3.0822070014844885, 3.1432467291003428, 3.203123475609394, 3.2619012860600183, 3.3196385345395667, 3.376388603226826, 3.432200460346103, 3.487119154832539, 3.541186241925155, 3.594440151122286, 3.646916505762094, 3.698648401781386, 3.7496666518505353, 3.8000000000000003, 3.8496753109840323, 3.898717737923586, 3.9471508711981107, 3.9949968710876362, 4.042276586281547, 4.0890096600521755, 4.135214625627066, 4.180908992073375, 4.226109321823088, 4.270831300812525, 4.315089802078284, 4.358898943540674, 4.402272140611029, 4.445222154178574, 4.487761134463376, 4.529900661162451, 4.571651780264984, 4.613025037868319, 4.654030511288038, 4.694677837722201, 4.734976240700686, 4.774934554525329, 4.814561246884289, 4.853864439804639, 4.892851929090027, 4.931531202375181, 4.969909455915671, 5.007993610219566, 5.045790324617146, 5.083306010855534, 5.120546845796843, 5.157518783291051, 5.194227565288221, 5.230678732248808, 5.266877632905477, 5.302829433425141, 5.338539126015656, 5.374011537017762, 5.409251334519409, 5.444263035526481, 5.47905101272109, 5.513619500836089, 5.547972602672079, 5.582114294781146, 5.616048432839589, 5.649778756730214, 5.68330889535313, 5.716642371182581, 5.749782604586021, 5.782732917920384, 5.815496539419485, 5.848076606885378, 5.880476171195663, 5.912698199637794, 5.944745579080741, 5.976621118993575, 6.008327554319921, 6.0398675482166, 6.071243694664217, 6.102458520956943, 6.133514490078262, 6.164414002968977, 6.1951594006934165], [0.0, 0.6244997998398399, 0.8831760866327847, 1.081665382639197, 1.2489995996796799, 1.3964240043768943, 1.5297058540778357, 1.6522711641858308, 1.7663521732655694, 1.8734993995195195, 1.97484176581315, 2.0712315177207983, 2.163330765278394, 2.2516660498395407, 2.3366642891095846, 2.4186773244895647, 2.4979991993593598, 2.574878637916747, 2.6495282598983545, 2.7221315177632404, 2.7928480087537886, 2.861817604250837, 2.9291637031753623, 2.994995826374388, 3.0594117081556713, 3.1224989991991996, 3.1843366656181322, 3.244996147917591, 3.3045423283716615, 3.363034344160048, 3.420526275297414, 3.477067730142742, 3.5327043465311387, 3.58747822293042, 3.6414282912066254, 3.6945906403822333, 3.746998799039039, 3.7986839826445165, 3.8496753109840323, 3.900000000000001, 3.9496835316263, 3.9987498046264416, 4.047221268969613, 4.095119045888654, 4.1424630354415966, 4.189272013130682, 4.235563716909475, 4.281354925721529, 4.326661530556788, 4.371498598878879, 4.415880433163924, 4.459820624195553, 4.503332099679081, 4.546427168667723, 4.589117562233507, 4.631414470763765, 4.673328578219169, 4.7148700936505135, 4.756048780237647, 4.796873982084583, 4.8373546489791295, 4.87749935930288, 4.917316341257699, 4.956813492557492, 4.9959983987187195, 5.034878350069642, 5.073460357586329, 5.111751167652823, 5.149757275833494, 5.187484939737176, 5.2249401910452535, 5.262128846769148, 5.299056519796709, 5.335728628781641, 5.372150407425317, 5.408326913195984, 5.444263035526481, 5.479963503528103, 5.515432893255072, 5.550675634551168, 5.585696017507577, 5.620498198558559, 5.655086206239478, 5.68946394662977, 5.723635208501674, 5.757603668193913, 5.791372894228104, 5.8249463516842805, 5.858327406350725, 5.8915193286621745, 5.92452529743945, 5.957348403442593, 5.989991652748776, 6.02245796996542, 6.054750201288242, 6.08687111741328, 6.118823416311343, 6.150609725872713, 6.182232606429493, 6.213694553162394, 6.244997998398399, 6.276145313805283], [0.0, 0.6324555320336759, 0.8944271909999159, 1.0954451150103324, 1.2649110640673518, 1.4142135623730951, 1.5491933384829668, 1.6733200530681511, 1.7888543819998317, 1.8973665961010275, 2.0, 2.0976176963403033, 2.1908902300206647, 2.280350850198276, 2.3664319132398464, 2.449489742783178, 2.5298221281347035, 2.6076809620810595, 2.6832815729997477, 2.7568097504180447, 2.8284271247461903, 2.898275349237888, 2.9664793948382653, 3.0331501776206204, 3.0983866769659336, 3.1622776601683795, 3.22490309931942, 3.286335345030997, 3.3466401061363023, 3.4058772731852804, 3.4641016151377544, 3.521363372331802, 3.5777087639996634, 3.6331804249169903, 3.687817782917155, 3.7416573867739413, 3.794733192202055, 3.847076812334269, 3.898717737923586, 3.9496835316263, 4.0, 4.049691346263318, 4.09878030638384, 4.147288270665544, 4.1952353926806065, 4.242640687119285, 4.2895221179054435, 4.33589667773576, 4.3817804600413295, 4.427188724235731, 4.47213595499958, 4.5166359162544865, 4.560701700396552, 4.604345773288536, 4.6475800154489, 4.69041575982343, 4.732863826479693, 4.774934554525329, 4.8166378315169185, 4.857983120596447, 4.898979485566356, 4.9396356140913875, 4.979959839195493, 5.019960159204453, 5.059644256269407, 5.0990195135927845, 5.138093031466052, 5.176871642217914, 5.215361924162119, 5.253570214625479, 5.291502622129181, 5.329165037789691, 5.366563145999495, 5.403702434442518, 5.440588203494177, 5.477225575051661, 5.513619500836089, 5.549774770204643, 5.585696017507577, 5.621387729022079, 5.656854249492381, 5.692099788303083, 5.727128425310542, 5.761944116355173, 5.796550698475776, 5.830951894845301, 5.865151319446072, 5.8991524815010505, 5.932958789676531, 5.966573556070519, 6.0, 6.0332412515993425, 6.066300355241241, 6.099180272790763, 6.131883886702357, 6.164414002968976, 6.196773353931867, 6.228964600958975, 6.260990336999411, 6.29285308902091, 6.324555320336759, 6.356099432828282], [0.0, 0.6403124237432849, 0.9055385138137417, 1.1090536506409419, 1.2806248474865698, 1.4317821063276355, 1.5684387141358125, 1.6941074346097418, 1.8110770276274835, 1.9209372712298547, 2.024845673131659, 2.1236760581595306, 2.2181073012818837, 2.3086792761230397, 2.395829710142188, 2.479919353527449, 2.5612496949731396, 2.6400757564888173, 2.716615541441225, 2.791057147390573, 2.863564212655271, 2.934280150224242, 3.0033314835362415, 3.0708305065568178, 3.136877428271625, 3.2015621187164247, 3.264965543462902, 3.3271609519228256, 3.3882148692194836, 3.448187929913334, 3.5071355833500366, 3.5651086939951777, 3.622154055254967, 3.678314831549905, 3.733630940518894, 3.7881393849751626, 3.8418745424597094, 3.89486841883009, 3.9471508711981107, 3.9987498046264416, 4.049691346263318, 4.1000000000000005, 4.149698784249287, 4.198809355043403, 4.247352116319061, 4.295346318982906, 4.342810150121693, 4.389760813529594, 4.436214602563767, 4.4821869662029945, 4.527692569068709, 4.572745346069471, 4.617358552246079, 4.661544808322667, 4.705316142407437, 4.748684028233507, 4.791659420284376, 4.8342527861087286, 4.876474136094644, 4.9183330509431755, 4.959838707054898, 5.000999900019996, 5.041825066382213, 5.082322303829225, 5.122499389946279, 5.162363799656123, 5.201922721455982, 5.241183072551464, 5.280151512977635, 5.3188344587888805, 5.35723809439155, 5.395368384086485, 5.43323108288245, 5.470831746635972, 5.508175741568165, 5.545268253204709, 5.582114294781146, 5.61871871515206, 5.655086206239478, 5.691221310052879, 5.727128425310542, 5.762811813689565, 5.798275605729691, 5.833523806414096, 5.868560300448484, 5.903388857258177, 5.93801313572141, 5.9724366886556455, 6.006662967072483, 6.040695324215583, 6.074537019394977, 6.1081912216301815, 6.1416610131136355, 6.174949392505174, 6.208059278067504, 6.24099351065197, 6.27375485654325, 6.306346010171025, 6.338769596696192, 6.3710281744785915, 6.403124237432849, 6.435060217278469], [0.0, 0.6480740698407861, 0.9165151389911681, 1.1224972160321827, 1.2961481396815722, 1.4491376746189442, 1.5874507866387546, 1.7146428199482249, 1.8330302779823362, 1.9442222095223582, 2.04939015319192, 2.149418526020468, 2.2449944320643653, 2.336664289109585, 2.4248711305964283, 2.5099800796022267, 2.5922962793631443, 2.672077843177478, 2.749545416973504, 2.8248893783651075, 2.8982753492378883, 2.9698484809835, 3.039736830714133, 3.108054053584011, 3.174901573277509, 3.2403703492039306, 3.304542328371662, 3.3674916480965478, 3.4292856398964497, 3.48998567332303, 3.5496478698597698, 3.6083237105337433, 3.6660605559646724, 3.7229020937972575, 3.7788887255382373, 3.834057902536163, 3.8884444190447165, 3.942080668885405, 3.9949968710876362, 4.047221268969613, 4.09878030638384, 4.149698784249287, 4.200000000000001, 4.249705872175156, 4.298837052040936, 4.347413023856832, 4.3954521951671826, 4.442971978304612, 4.489988864128731, 4.536518488885503, 4.582575694955841, 4.628174586162455, 4.67332857821917, 4.718050444834181, 4.762352359916264, 4.806245936279167, 4.849742261192857, 4.892851929090027, 4.935585071701227, 4.9779513858614575, 5.019960159204453, 5.061620293937506, 5.10294032886923, 5.143928459844674, 5.184592558726289, 5.224940191045253, 5.264978632435274, 5.304714883949938, 5.344155686354956, 5.383307533477909, 5.422176684690385, 5.46076917659042, 5.499090833947008, 5.537147279962851, 5.574943945906542, 5.612486080160912, 5.649778756730215, 5.686826883245173, 5.723635208501675, 5.760208329565868, 5.796550698475777, 5.832666628567075, 5.868560300448485, 5.904235767650205, 5.939696961967, 5.974947698515863, 6.009991680526689, 6.044832503882966, 6.079473661428266, 6.113918547053109, 6.148170459575759, 6.182232606429493, 6.216108107168022, 6.249799996799899, 6.283311228962004, 6.316644678941503, 6.349803146555018, 6.38278935889318, 6.4156059729381765, 6.448255578061405, 6.480740698407861, 6.5130637951735135], [0.0, 0.6557438524302001, 0.9273618495495702, 1.1357816691600549, 1.3114877048604001, 1.466287829861518, 1.606237840420901, 1.7349351572897471, 1.8547236990991405, 1.9672315572906, 2.073644135332772, 2.1748563170931545, 2.2715633383201097, 2.364318083507378, 2.453568829277059, 2.5396850198400585, 2.6229754097208002, 2.7037011669191546, 2.782085548648711, 2.8583211855912904, 2.932575659723036, 3.004995840263344, 3.0757112998459397, 3.1448370387032774, 3.212475680841802, 3.278719262151, 3.3436506994600976, 3.407345007480164, 3.4698703145794942, 3.531288716601915, 3.5916569992135936, 3.6510272527057364, 3.709447398198281, 3.7669616403674726, 3.823610858861032, 3.879432948254164, 3.9344631145812, 3.988734135035826, 4.042276586281547, 4.095119045888654, 4.147288270665544, 4.198809355043403, 4.249705872175156, 4.299999999999999, 4.349712634186309, 4.398863489584553, 4.447471191587417, 4.495553358597804, 4.543126676640219, 4.5902069670114, 4.636809247747852, 4.682947789587239, 4.728636167014756, 4.773887304912004, 4.818713521262703, 4.863126566315131, 4.907137658554118, 4.950757517794625, 4.993996395673509, 5.03686410378521, 5.079370039680117, 5.121523210920751, 5.163332257370234, 5.204805471869242, 5.2459508194416005, 5.28677595515452, 5.3272882407468805, 5.367494760127856, 5.407402333838309, 5.447017532558529, 5.486346689738081, 5.525395913416522, 5.564171097297422, 5.602677931132575, 5.6409219104681805, 5.678908345800274, 5.716642371182581, 5.754128952326321, 5.791372894228104, 5.8283788483591215, 5.865151319446072, 5.9016946718718, 5.938013135721409, 5.974110812497538, 6.009991680526688, 6.0456596000767355, 6.081118318204308, 6.1163714733492105, 6.151422599691879, 6.186275131288617, 6.220932405998315, 6.255397669213365, 6.289674077406555, 6.323764701504951, 6.357672530100933, 6.3914004725099165, 6.424951361683604, 6.458327956987009, 6.491532946846992, 6.524568951279464, 6.557438524302, 6.590144156238162], [0.0, 0.66332495807108, 0.938083151964686, 1.148912529307606, 1.32664991614216, 1.4832396974191329, 1.6248076809271923, 1.7549928774784245, 1.876166303929372, 1.98997487421324, 2.0976176963403033, 2.2, 2.297825058615212, 2.3916521486202797, 2.4819347291981715, 2.569046515733026, 2.65329983228432, 2.734958866235469, 2.814249455894058, 2.8913664589601926, 2.9664793948382657, 3.039736830714133, 3.1112698372208096, 3.1811947441173736, 3.2496153618543846, 3.3166247903554003, 3.382306905057553, 3.4467375879228177, 3.509985754956849, 3.5721142198983507, 3.63318042491699, 3.693237062523878, 3.752332607858744, 3.8105117766515306, 3.8678159211627436, 3.924283374069717, 3.97994974842648, 4.034848200366404, 4.0890096600521755, 4.1424630354415966, 4.1952353926806065, 4.247352116319061, 4.298837052040936, 4.349712634186309, 4.4, 4.449719092257398, 4.498888751680798, 4.54752680036083, 4.595650117230424, 4.64327470649756, 4.69041575982343, 4.737087712930806, 4.7833042972405595, 4.829078587059855, 4.874423042781577, 4.919349550499538, 4.963869458396343, 5.007993610219566, 5.051732376126036, 5.095095681142799, 5.138093031466052, 5.180733538795447, 5.223025942880239, 5.264978632435274, 5.30659966456864, 5.347896782848375, 5.388877434122993, 5.429548784199292, 5.469917732470938, 5.509990925582365, 5.549774770204644, 5.589275444992849, 5.628498911788116, 5.667450926121902, 5.706137047074843, 5.7445626465380295, 5.782732917920385, 5.8206528843421, 5.858327406350725, 5.895761189193471, 5.9329587896765315, 5.969924622639721, 6.006662967072484, 6.043177971895251, 6.079473661428266, 6.115553940568263, 6.15142259969188, 6.187083319303208, 6.222539674441619, 6.2577951388648065, 6.29285308902091, 6.327716807822551, 6.362389488234747, 6.3968742366877915, 6.431174076325411, 6.465291950097845, 6.499230723708769, 6.532993188424431, 6.566582063752802, 6.600000000000001, 6.6332495807108005, 6.666333324999584], [0.0, 0.6708203932499369, 0.9486832980505137, 1.161895003862225, 1.3416407864998738, 1.5, 1.6431676725154982, 1.7748239349298847, 1.8973665961010273, 2.0124611797498106, 2.1213203435596424, 2.224859546128699, 2.32379000772445, 2.4186773244895647, 2.5099800796022262, 2.5980762113533156, 2.6832815729997477, 2.765863337187866, 2.846049894151541, 2.924038303442689, 3.0, 3.0740852297878796, 3.1464265445104544, 3.2171415884290826, 3.2863353450309964, 3.3541019662496843, 3.420526275297414, 3.4856850115866753, 3.5496478698597693, 3.6124783736376886, 3.674234614174767, 3.7349698793966195, 3.7947331922020546, 3.853569773599539, 3.911521443121589, 3.9686269665968856, 4.024922359499621, 4.080441152620633, 4.135214625627066, 4.189272013130682, 4.242640687119285, 4.295346318982906, 4.347413023856832, 4.398863489584553, 4.449719092257398, 4.499999999999999, 4.54972526643093, 4.598912915026768, 4.6475800154489, 4.695742752749558, 4.743416490252569, 4.790615826801393, 4.8373546489791295, 4.883646178829912, 4.9295030175464944, 4.9749371855331, 5.0199601592044525, 5.064582904840239, 5.10881590977792, 5.1526692111953, 5.196152422706631, 5.239274758971893, 5.282045058497702, 5.324471804789654, 5.366563145999495, 5.4083269131959835, 5.449770637375485, 5.490901565316937, 5.531726674375732, 5.572252686302012, 5.612486080160912, 5.652433104425031, 5.692099788303082, 5.731491952362839, 5.770615218501403, 5.809475019311125, 5.848076606885378, 5.886425061104575, 5.92452529743945, 5.962382074305537, 6.0, 6.037383539249432, 6.074537019394977, 6.111464636239008, 6.148170459575759, 6.18465843842649, 6.220932405998316, 6.256996084384263, 6.292853089020909, 6.328506932918695, 6.363961030678928, 6.399218702310462, 6.434283176858165, 6.469157595854347, 6.5038450166036395, 6.53834841531101, 6.572670690061993, 6.606814663663572, 6.640783086353596, 6.674578638386096, 6.7082039324993685, 6.74166151627327], [0.0, 0.6782329983125268, 0.9591663046625439, 1.1747340124470733, 1.3564659966250536, 1.5165750888103102, 1.661324772583615, 1.7944358444926363, 1.9183326093250879, 2.0346989949375804, 2.1447610589527217, 2.249444375840399, 2.3494680248941466, 2.445403852127497, 2.5377155080899043, 2.626785107312739, 2.7129319932501073, 2.7964262908219126, 2.877498913987632, 2.956349099818897, 3.0331501776206204, 3.108054053584011, 3.1811947441173736, 3.252691193458119, 3.32264954516723, 3.3911649915626345, 3.458323293158117, 3.5242020373412197, 3.5888716889852725, 3.6523964735499352, 3.714835124201342, 3.7762415176998414, 3.8366652186501757, 3.896151947755632, 3.954743986657038, 4.012480529547776, 4.069397989875161, 4.125530268947254, 4.180908992073375, 4.235563716909475, 4.2895221179054435, 4.342810150121693, 4.3954521951671826, 4.447471191587417, 4.498888751680798, 4.54972526643093, 4.6000000000000005, 4.649731175025068, 4.698936049788293, 4.747630988187688, 4.79583152331272, 4.843552415324934, 4.890807704254994, 4.937610758251404, 4.983974317750845, 5.029910535983717, 5.075431016179809, 5.120546845796843, 5.165268628057984, 5.209606511052442, 5.253570214625478, 5.297169055259611, 5.340411969127476, 5.383307533477908, 5.4258639865002145, 5.468089245796926, 5.509990925582365, 5.551576352712804, 5.592852581643825, 5.63382640840131, 5.674504383644443, 5.71489282489182, 5.754997827975264, 5.794825277780168, 5.834380858325929, 5.873670062235366, 5.912698199637794, 5.951470406546605, 5.989991652748776, 6.028266749240615, 6.066300355241241, 6.104096984812742, 6.1416610131136355, 6.178996682310163, 6.216108107168022, 6.252999280345393, 6.289674077406556, 6.326136261573884, 6.362389488234747, 6.398437309218556, 6.434283176858165, 6.469930447848725, 6.505382386916238, 6.540642170307134, 6.57571288910944, 6.6105975524153635, 6.64529909033446, 6.679820356865895, 6.714164132637808, 6.748333127521196, 6.782329983125269, 6.81615727518079], [0.0, 0.6855654600401044, 0.9695359714832658, 1.187434208703792, 1.3711309200802089, 1.5329709716755893, 1.6792855623746665, 1.8138357147217055, 1.9390719429665315, 2.056696380120313, 2.16794833886788, 2.273763400180415, 2.374868417407584, 2.471841418861655, 2.565151067676132, 2.6551836094703507, 2.7422618401604177, 2.826658805020514, 2.9086079144497976, 2.9883105594967874, 3.0659419433511785, 3.1416556144810017, 3.2155870381627056, 3.2878564445547194, 3.358571124749333, 3.4278273002005224, 3.4957116585897072, 3.5623026261113755, 3.627671429443411, 3.691882988394947, 3.7549966711037173, 3.817066936798463, 3.878143885933063, 3.9382737335030438, 3.997499218261337, 4.05585995813465, 4.113392760240626, 4.170131892398609, 4.226109321823088, 4.281354925721529, 4.33589667773576, 4.389760813529594, 4.442971978304612, 4.495553358597804, 4.54752680036083, 4.598912915026768, 4.649731175025068, 4.7, 4.749736834815168, 4.798958220280731, 4.847679857416329, 4.89591666595746, 4.94368283772331, 4.990991885387113, 5.037856687124, 5.084289527554465, 5.130302135352264, 5.175905717843014, 5.221110992882646, 5.265928218272634, 5.310367218940701, 5.354437412091022, 5.3981478305063115, 5.441507144165117, 5.4845236803208355, 5.527205442174191, 5.569560126257728, 5.61159513863928, 5.653317610041028, 5.69473440996154, 5.735852159879995, 5.776677245614472, 5.817215828899595, 5.857473858242988, 5.897457079114692, 5.937171043518958, 5.976621118993575, 6.015812497078014, 6.054750201288242, 6.09343909463285, 6.131883886702357, 6.17008914036094, 6.208059278067503, 6.245798587850876, 6.2833112289620034, 6.320601237224193, 6.357672530100934, 6.394528911499267, 6.431174076325411, 6.4676116148080505, 6.5038450166036395, 6.539877674696982, 6.575712889109439, 6.611353870426239, 6.646803743153547, 6.682065548915245, 6.717142249498666, 6.7520367297579185, 6.786751800382861, 6.821290200541244, 6.855654600401045, 6.889847603539574], [0.0, 0.692820323027551, 0.9797958971132713, 1.2000000000000004, 1.385640646055102, 1.549193338482967, 1.6970562748477143, 1.8330302779823362, 1.9595917942265426, 2.078460969082653, 2.1908902300206647, 2.297825058615212, 2.400000000000001, 2.4979991993593598, 2.5922962793631443, 2.6832815729997477, 2.771281292110204, 2.8565713714171403, 2.9393876913398143, 3.0199337741083006, 3.098386676965934, 3.174901573277509, 3.2496153618543846, 3.3226495451672307, 3.3941125496954285, 3.4641016151377553, 3.5327043465311396, 3.6000000000000005, 3.6660605559646724, 3.7309516212355267, 3.7947331922020555, 3.8574603043971827, 3.9191835884530852, 3.9799497484264807, 4.039801975344832, 4.09878030638384, 4.156921938165306, 4.214261501141096, 4.270831300812525, 4.326661530556788, 4.3817804600413295, 4.436214602563767, 4.489988864128731, 4.543126676640219, 4.595650117230424, 4.6475800154489, 4.698936049788293, 4.749736834815168, 4.800000000000002, 4.849742261192857, 4.898979485566357, 4.947726750741194, 4.9959983987187195, 5.043808085167398, 5.091168824543143, 5.1380930314660525, 5.184592558726289, 5.230678732248809, 5.276362383309169, 5.321653878260029, 5.366563145999495, 5.411099703387474, 5.455272678794342, 5.499090833947009, 5.542562584220408, 5.585696017507577, 5.628498911788117, 5.670978751503131, 5.713142742834281, 5.754997827975265, 5.796550698475777, 5.83780780773057, 5.8787753826796285, 5.9194594347794975, 5.959865770300536, 6.000000000000001, 6.039867548216601, 6.079473661428266, 6.1188234163113435, 6.157921727336262, 6.196773353931868, 6.235382907247959, 6.27375485654325, 6.311893535223801, 6.349803146555018, 6.387487769068526, 6.424951361683605, 6.462197768561406, 6.499230723708769, 6.536053855347277, 6.572670690061994, 6.609084656743323, 6.645299090334461, 6.681317235396028, 6.717142249498667, 6.752777206453653, 6.788225099390857, 6.823488843692794, 6.8585712797928995, 6.893475175845635, 6.9282032302755105, 6.962758074211686], [0.0, 0.7000000000000001, 0.9899494936611665, 1.2124355652982142, 1.4000000000000001, 1.565247584249853, 1.7146428199482247, 1.8520259177452134, 1.979898987322333, 2.1, 2.2135943621178655, 2.32163735324878, 2.4248711305964283, 2.5238858928247927, 2.619160170741759, 2.7110883423451915, 2.8000000000000003, 2.8861739379323623, 2.9698484809834995, 3.051229260478472, 3.130495168499706, 3.2078029864690882, 3.283291031876401, 3.357082066318904, 3.4292856398964493, 3.5, 3.5693136595149495, 3.6373066958946425, 3.704051835490427, 3.769615364994153, 3.8340579025361627, 3.8974350539810154, 3.959797974644666, 4.02119385257662, 4.08166632639171, 4.141255848169731, 4.2, 4.257933771208754, 4.315089802078284, 4.371498598878879, 4.427188724235731, 4.4821869662029945, 4.536518488885503, 4.5902069670114, 4.64327470649756, 4.695742752749558, 4.747630988187688, 4.798958220280731, 4.849742261192857, 4.9, 4.949747468305833, 4.998999899979996, 5.047771785649585, 5.096076922496363, 5.143928459844674, 5.191338940966964, 5.238320341483518, 5.2848841046895245, 5.331041174104736, 5.376802023508025, 5.422176684690383, 5.467174773134658, 5.511805511808268, 5.55607775323564, 5.6000000000000005, 5.643580423808984, 5.686826883245172, 5.729746940310715, 5.772347875864725, 5.814636704042653, 5.856620185738529, 5.898304841223451, 5.939696961966999, 5.980802621722272, 6.021627686929839, 6.06217782649107, 6.102458520956944, 6.142475071174486, 6.182232606429493, 6.221736092120913, 6.260990336999412, 6.300000000000001, 6.338769596696192, 6.377303505401009, 6.4156059729381765, 6.4536811201050215, 6.491532946846993, 6.529165337162171, 6.566582063752802, 6.603786792439623, 6.640783086353597, 6.67757440991862, 6.714164132637808, 6.750555532695069, 6.786751800382861, 6.822756041366274, 6.858571279792899, 6.894200461257274, 6.929646455628165, 6.96491205974634, 7.0, 7.034912934784624], [0.0, 0.7071067811865476, 1.0, 1.2247448713915892, 1.4142135623730951, 1.5811388300841898, 1.7320508075688774, 1.8708286933869709, 2.0, 2.1213203435596424, 2.23606797749979, 2.345207879911715, 2.4494897427831783, 2.5495097567963927, 2.6457513110645907, 2.7386127875258306, 2.8284271247461903, 2.9154759474226504, 3.0, 3.082207001484489, 3.1622776601683795, 3.2403703492039306, 3.3166247903554003, 3.3911649915626345, 3.464101615137755, 3.535533905932738, 3.6055512754639896, 3.6742346141747677, 3.7416573867739418, 3.8078865529319548, 3.872983346207417, 3.9370039370059056, 4.0, 4.06201920231798, 4.123105625617661, 4.183300132670378, 4.242640687119285, 4.301162633521314, 4.358898943540674, 4.415880433163924, 4.47213595499958, 4.527692569068709, 4.582575694955841, 4.636809247747852, 4.69041575982343, 4.743416490252569, 4.79583152331272, 4.847679857416329, 4.898979485566357, 4.949747468305833, 5.000000000000001, 5.04975246918104, 5.099019513592785, 5.147815070493501, 5.196152422706632, 5.244044240850759, 5.291502622129181, 5.338539126015656, 5.385164807134505, 5.431390245600108, 5.477225575051661, 5.522680508593631, 5.5677643628300215, 5.612486080160912, 5.656854249492381, 5.70087712549569, 5.744562646538029, 5.787918451395113, 5.830951894845301, 5.873670062235366, 5.916079783099617, 5.958187643906493, 6.0, 6.041522986797286, 6.082762530298219, 6.123724356957946, 6.164414002968978, 6.2048368229954285, 6.244997998398399, 6.284902544988268, 6.324555320336759, 6.3639610306789285, 6.403124237432849, 6.442049363362563, 6.480740698407861, 6.519202405202649, 6.557438524302001, 6.59545297913646, 6.6332495807108005, 6.670832032063167, 6.708203932499369, 6.745368781616021, 6.782329983125269, 6.8190908484929285, 6.855654600401045, 6.892024376045111, 6.92820323027551, 6.9641941385920605, 7.0, 7.035623639735145, 7.071067811865476, 7.1063352017759485], [0.0, 0.7141428428542851, 1.0099504938362078, 1.2369316876852985, 1.4282856857085702, 1.5968719422671316, 1.7492855684535904, 1.8894443627691186, 2.0199009876724157, 2.142428528562855, 2.2583179581272432, 2.368543856465403, 2.473863375370597, 2.574878637916747, 2.672077843177478, 2.765863337187866, 2.8565713714171403, 2.944486372867092, 3.029851481508624, 3.1128764832546767, 3.193743884534263, 3.272613634390715, 3.3496268448888458, 3.4249087579087423, 3.498571136907181, 3.5707142142714257, 3.6414282912066254, 3.7107950630558952, 3.7788887255382373, 3.845776904605883, 3.9115214431215892, 3.9761790704142093, 4.039801975344831, 4.102438299353204, 4.164132562731403, 4.224926034855522, 4.28485705712571, 4.343961325794695, 4.402272140611029, 4.459820624195553, 4.5166359162544865, 4.572745346069471, 4.628174586162455, 4.682947789587239, 4.737087712930806, 4.790615826801393, 4.843552415324934, 4.89591666595746, 4.947726750741194, 4.998999899979996, 5.04975246918104, 5.100000000000001, 5.149757275833494, 5.199038372622384, 5.247856705360771, 5.296225070746145, 5.344155686354956, 5.391660226683429, 5.43874985635486, 5.485435260760991, 5.531726674375732, 5.577633906953737, 5.62316636780382, 5.668333088307356, 5.713142742834281, 5.757603668193913, 5.801723881744115, 5.845511098270194, 5.888972745734184, 5.932115979985557, 5.974947698515863, 6.017474553332154, 6.059702963017248, 6.101639124038721, 6.143289021363068, 6.184658438426491, 6.225752966509353, 6.266578013557321, 6.307138812488593, 6.347440429023341, 6.387487769068526, 6.427285585688566, 6.466838485689898, 6.506150935845249, 6.54522726878143, 6.584071688552609, 6.62268827591938, 6.661080993352356, 6.6992536897776915, 6.73721010508059, 6.77495387438173, 6.81248853210044, 6.8498175158174845, 6.886944169949399, 6.923871749245506, 6.960603422117942, 6.997142273814362, 7.033491309442276, 7.069653456853455, 7.105631569396208, 7.141428428542851, 7.177046746399247], [0.0, 0.7211102550927979, 1.019803902718557, 1.2489995996796799, 1.4422205101855958, 1.61245154965971, 1.7663521732655696, 1.9078784028338915, 2.039607805437114, 2.1633307652783937, 2.280350850198276, 2.3916521486202797, 2.4979991993593598, 2.6000000000000005, 2.6981475126464085, 2.792848008753788, 2.8844410203711917, 2.973213749463701, 3.0594117081556713, 3.1432467291003428, 3.22490309931942, 3.3045423283716615, 3.3823069050575527, 3.458323293158117, 3.532704346531139, 3.6055512754639896, 3.6769552621700474, 3.7469987990390394, 3.815756805667783, 3.88329756778952, 3.9496835316262997, 4.014971979976947, 4.079215610874228, 4.1424630354415966, 4.204759208325728, 4.266145801540309, 4.3266615305567875, 4.386342439892262, 4.445222154178574, 4.503332099679081, 4.560701700396552, 4.617358552246079, 4.67332857821917, 4.728636167014756, 4.7833042972405595, 4.8373546489791295, 4.890807704254994, 4.94368283772331, 4.9959983987187195, 5.047771785649585, 5.099019513592785, 5.149757275833494, 5.200000000000001, 5.249761899362676, 5.299056519796709, 5.347896782848376, 5.396295025292817, 5.44426303552648, 5.491812087098393, 5.5389529696504916, 5.585696017507576, 5.63205113613149, 5.678027826631356, 5.723635208501674, 5.768882040742383, 5.813776741499453, 5.858327406350725, 5.902541825349482, 5.946427498927402, 5.989991652748776, 6.033241251599343, 6.076183012385325, 6.118823416311343, 6.161168720299745, 6.203224967708329, 6.244997998398398, 6.2864934582006855, 6.327716807822551, 6.3686733312362644, 6.409368143584826, 6.44980619863884, 6.489992295835181, 6.529931086925804, 6.569627082262737, 6.609084656743323, 6.648308055437865, 6.687301398920196, 6.726068688320096, 6.764613810115105, 6.802940540677979, 6.841052550594828, 6.878953408767936, 6.916646586316234, 6.954135460285485, 6.9914233171794145, 7.0285133563222315, 7.065408693062278, 7.102112361825883, 7.138627319029899, 7.17495644586084, 7.211102550927979, 7.247068372797377], [0.0, 0.7280109889280519, 1.0295630140987002, 1.2609520212918495, 1.4560219778561039, 1.627882059609971, 1.7832554500127011, 1.9261360284258224, 2.0591260281974004, 2.1840329667841556, 2.302172886644268, 2.4145392935299275, 2.521904042583699, 2.624880949681338, 2.7239676943752476, 2.819574435974337, 2.9120439557122078, 3.001666203960727, 3.0886890422961004, 3.1733263305244868, 3.255764119219942, 3.336165463522456, 3.414674215792775, 3.491418050019219, 3.5665109000254023, 3.64005494464026, 3.712142238654118, 3.782856063875548, 3.852272056851645, 3.9204591567825324, 3.9874804074753776, 4.053393639902249, 4.118252056394801, 4.182104733265298, 4.244997055358225, 4.306971093471606, 4.368065933568311, 4.428317965096906, 4.487761134463376, 4.546427168667723, 4.604345773288536, 4.661544808322667, 4.718050444834181, 4.773887304912004, 4.829078587059855, 4.883646178829912, 4.937610758251404, 4.990991885387113, 5.043808085167398, 5.096076922496363, 5.147815070493501, 5.199038372622384, 5.249761899362676, 5.300000000000001, 5.349766350038103, 5.399073994677236, 5.447935388750495, 5.496362433464519, 5.5443665102516455, 5.591958512006326, 5.639148871948674, 5.6859475903318, 5.732364259186606, 5.7784080852774675, 5.8240879114244155, 5.869412236331676, 5.914389233048499, 5.959026766175833, 6.003332407921454, 6.047313453096343, 6.090976933136425, 6.134329629226001, 6.177378084592201, 6.220128616033596, 6.262587324740471, 6.304760106459247, 6.3466526610489735, 6.388270501473776, 6.429618962271405, 6.470703207534712, 6.511528238439884, 6.552098900352467, 6.592419889539805, 6.632495759516172, 6.672330927044912, 6.711929677819935, 6.751296171847301, 6.790434448545985, 6.82934843158555, 6.868041933477111, 6.906518659932804, 6.944782214007867, 6.982836100038438, 7.020683727387242, 7.058328414008519, 7.095773389842717, 7.1330218000508046, 7.170076708097342, 7.206941098690901, 7.243617880589783, 7.28010988928052, 7.31641988953614], [0.0, 0.7348469228349535, 1.0392304845413265, 1.2727922061357857, 1.469693845669907, 1.6431676725154984, 1.8, 1.9442222095223582, 2.078460969082653, 2.2045407685048604, 2.32379000772445, 2.4372115213907883, 2.5455844122715714, 2.6495282598983545, 2.749545416973504, 2.846049894151541, 2.939387691339814, 3.0298514815086235, 3.1176914536239795, 3.203123475609394, 3.286335345030997, 3.3674916480965478, 3.4467375879228173, 3.5242020373412197, 3.6, 3.6742346141747677, 3.7469987990390394, 3.818376618407357, 3.8884444190447165, 3.957271787481876, 4.024922359499621, 4.091454509095757, 4.156921938165306, 4.221374183841087, 4.28485705712571, 4.347413023856832, 4.409081537009721, 4.469899327725402, 4.529900661162451, 4.589117562233507, 4.6475800154489, 4.705316142407437, 4.762352359916264, 4.818713521262703, 4.874423042781577, 4.9295030175464944, 4.983974317750845, 5.037856687124, 5.091168824543143, 5.143928459844674, 5.196152422706632, 5.247856705360771, 5.299056519796709, 5.349766350038103, 5.4, 5.449770637375486, 5.499090833947008, 5.547972602672079, 5.596427431853289, 5.644466316668034, 5.692099788303082, 5.739337940912697, 5.786190456595773, 5.8326666285670745, 5.878775382679628, 5.924525297439449, 5.96992462263972, 6.014981296729027, 6.059702963017247, 6.104096984812742, 6.148170459575759, 6.191930232165088, 6.235382907247959, 6.278534860936905, 6.321392251711643, 6.363961030678928, 6.406246951218788, 6.448255578061404, 6.489992295835182, 6.5314623171231725, 6.572670690061994, 6.613622305514581, 6.654321903845651, 6.694774081326419, 6.7349832961930955, 6.77495387438173, 6.814690014960329, 6.854195795277518, 6.8934751758456345, 6.932532004974806, 6.971370023173351, 7.009992867328754, 7.0484040746824395, 7.0866070866106305, 7.124605252222751, 7.162401831787993, 7.2, 7.237402849088892, 7.274613391789285, 7.3116345641723655, 7.348469228349535, 7.385120175054704], [0.0, 0.7416198487095663, 1.0488088481701516, 1.2845232578665131, 1.4832396974191326, 1.6583123951777001, 1.8165902124584952, 1.9621416870348585, 2.0976176963403033, 2.224859546128699, 2.345207879911715, 2.459674775249769, 2.5690465157330262, 2.673948391424188, 2.7748873851023217, 2.8722813232690143, 2.9664793948382653, 3.0577769702841313, 3.146426544510455, 3.232645975048923, 3.3166247903554003, 3.398529093593286, 3.4785054261852175, 3.5566838487557484, 3.6331804249169903, 3.708099243547832, 3.7815340802378077, 3.853569773599539, 3.924283374069717, 3.993745109543172, 4.06201920231798, 4.129164564412516, 4.1952353926806065, 4.260281680828159, 4.324349662087931, 4.387482193696061, 4.449719092257398, 4.511097427455985, 4.571651780264984, 4.631414470763765, 4.69041575982343, 4.748684028233507, 4.806245936279167, 4.863126566315131, 4.919349550499538, 4.9749371855331, 5.029910535983717, 5.084289527554465, 5.1380930314660525, 5.191338940966964, 5.244044240850759, 5.296225070746145, 5.347896782848376, 5.399073994677236, 5.449770637375486, 5.5, 5.549774770204643, 5.599107071667768, 5.648008498577176, 5.6964901474504455, 5.744562646538029, 5.792236183029832, 5.839520528262573, 5.886425061104576, 5.932958789676531, 5.979130371550699, 6.024948132556827, 6.070420084310475, 6.115553940568263, 6.1603571325045765, 6.2048368229954285, 6.248999919987198, 6.29285308902091, 6.336402764976356, 6.3796551630946325, 6.422616289332565, 6.465291950097846, 6.507687761409578, 6.549809157525127, 6.591661399070799, 6.6332495807108005, 6.674578638386097, 6.715653356152327, 6.756478372643548, 6.797058187186572, 6.837397165588672, 6.87749954561976, 6.917369442208505, 6.957010852370435, 6.996427659884722, 7.035623639735144, 7.074602462329597, 7.113367697511497, 7.15192281837549, 7.1902712048990205, 7.2284161474004796, 7.266360849833981, 7.30410843293006, 7.341661937191061, 7.379024325749307, 7.416198487095664, 7.4531872376856345], [0.0, 0.7483314773547883, 1.058300524425836, 1.2961481396815722, 1.4966629547095767, 1.6733200530681511, 1.833030277982336, 1.9798989873223332, 2.116601048851672, 2.244994432064365, 2.3664319132398464, 2.4819347291981715, 2.5922962793631443, 2.6981475126464085, 2.8, 2.8982753492378874, 2.9933259094191533, 3.0854497241083023, 3.1749015732775088, 3.2619012860600183, 3.3466401061363023, 3.4292856398964493, 3.509985754956849, 3.5888716889852725, 3.666060555964672, 3.7416573867739413, 3.8157568056677826, 3.8884444190447165, 3.9597979746446663, 4.029888335921977, 4.098780306383839, 4.166533331199932, 4.233202097703344, 4.298837052040936, 4.363484845854286, 4.427188724235731, 4.48998886412873, 4.551922670696417, 4.613025037868319, 4.673328578219169, 4.732863826479693, 4.791659420284376, 4.849742261192857, 4.907137658554118, 4.963869458396343, 5.0199601592044525, 5.075431016179809, 5.130302135352264, 5.184592558726289, 5.238320341483518, 5.291502622129181, 5.344155686354956, 5.396295025292817, 5.447935388750495, 5.499090833947008, 5.549774770204643, 5.6, 5.649778756730214, 5.6991227395100035, 5.748043145279965, 5.796550698475775, 5.844655678480983, 5.892367945062493, 5.939696961966999, 5.986651818838307, 6.033241251599342, 6.079473661428265, 6.125357132445422, 6.170899448216605, 6.216108107168021, 6.260990336999411, 6.305553108173778, 6.3498031465550175, 6.393746945258312, 6.437390775772432, 6.48074069840786, 6.523802572120037, 6.566582063752802, 6.609084656743323, 6.6513156593263565, 6.6932802122726045, 6.734983296193095, 6.776429738438967, 6.817624219623724, 6.858571279792899, 6.899275324264136, 6.939740629158989, 6.979971346646059, 7.019971509913698, 7.059745037889116, 7.099295739719539, 7.138627319029899, 7.177743377970545, 7.216647421067487, 7.255342858886822, 7.293833011524187, 7.332121111929344, 7.370210309075312, 7.408103670980854, 7.445804187594514, 7.483314773547883, 7.520638270785267], [0.0, 0.754983443527075, 1.0677078252031311, 1.3076696830622023, 1.50996688705415, 1.6881943016134133, 1.849324200890693, 1.997498435543818, 2.1354156504062622, 2.264950330581225, 2.3874672772626644, 2.503996805109783, 2.6153393661244047, 2.72213151776324, 2.824889378365107, 2.924038303442689, 3.0199337741083, 3.1128764832546763, 3.2031234756093934, 3.290896534380867, 3.3763886032268267, 3.459768778401239, 3.5411862419251547, 3.620773398046335, 3.698648401781386, 3.774917217635375, 3.849675310984032, 3.9230090491866063, 3.994996871087636, 4.065710270051224, 4.135214625627066, 4.20356991139674, 4.2708313008125245, 4.337049688440288, 4.402272140611028, 4.466542286825459, 4.52990066116245, 4.592385001282014, 4.654030511288038, 4.7148700936505135, 4.774934554525329, 4.8342527861087286, 4.892851929090027, 4.950757517794625, 5.007993610219566, 5.064582904840239, 5.120546845796843, 5.175905717843014, 5.230678732248809, 5.2848841046895245, 5.338539126015656, 5.391660226683429, 5.44426303552648, 5.496362433464519, 5.547972602672079, 5.599107071667768, 5.649778756730214, 5.7, 5.749782604586021, 5.799137866959191, 5.848076606885378, 5.8966091951222275, 5.944745579080739, 5.9924953066314535, 6.0398675482166, 6.08687111741328, 6.133514490078261, 6.17980582219215, 6.2257529665093525, 6.271363488110062, 6.316644678941503, 6.361603571427569, 6.406246951218787, 6.450581369148055, 6.494613152451807, 6.5383484153110105, 6.581793068761734, 6.624952830020755, 6.667833231267862, 6.710439627923047, 6.752777206453653, 6.794850991743675, 6.836665854054885, 6.878226515607057, 6.919537556802478, 6.960603422117942, 7.001428425685718, 7.042016756583302, 7.0823724838503095, 7.122499561249548, 7.162401831787993, 7.202083032012336, 7.24154679609267, 7.280796659706959, 7.31983606373804, 7.358668357794092, 7.397296803562772, 7.4357245780085215, 7.473954776421918, 7.5119904153293495, 7.54983443527075, 7.587489703452652], [0.0, 0.7615773105863909, 1.0770329614269007, 1.3190905958272923, 1.5231546211727818, 1.7029386365926404, 1.8654758106177631, 2.0149441679609885, 2.1540659228538015, 2.2847319317591723, 2.4083189157584592, 2.525866188063018, 2.6381811916545845, 2.7459060435491964, 2.8495613697550017, 2.9495762407505253, 3.0463092423455636, 3.1400636936215167, 3.2310988842807027, 3.319638534539567, 3.405877273185281, 3.48998567332303, 3.5721142198983507, 3.6523964735499352, 3.7309516212355263, 3.8078865529319548, 3.8832975677895205, 3.957271787481876, 4.029888335921977, 4.101219330881976, 4.171330722922842, 4.240283009422838, 4.308131845707603, 4.374928570845472, 4.440720662234904, 4.505552130427525, 4.569463863518345, 4.632493928760188, 4.694677837722201, 4.756048780237647, 4.8166378315169185, 4.876474136094644, 4.935585071701227, 4.993996395673509, 5.051732376126036, 5.10881590977792, 5.165268628057984, 5.221110992882646, 5.276362383309169, 5.331041174104736, 5.385164807134505, 5.43874985635486, 5.491812087098393, 5.5443665102516455, 5.596427431853289, 5.648008498577176, 5.6991227395100035, 5.749782604586021, 5.800000000000001, 5.849786320883866, 5.8991524815010505, 5.948108943185221, 5.99666574022598, 6.044832503882966, 6.092618484691127, 6.1400325732035, 6.187083319303208, 6.23377895020348, 6.280127387243033, 6.326136261573885, 6.3718129288295975, 6.417164482853779, 6.462197768561405, 6.5069193939989765, 6.55133574166368, 6.59545297913646, 6.639277069079134, 6.682813778641449, 6.726068688320096, 6.76904720030818, 6.811754546370562, 6.854195795277518, 6.8963758598266685, 6.938299503480662, 6.97997134664606, 7.021395872616784, 7.062577433203831, 7.103520254071217, 7.144228439796701, 7.184705978674423, 7.224956747275378, 7.264984514780469, 7.3047929470998705, 7.3443856107914165, 7.383765976789894, 7.4229374239582535, 7.4619032424710525, 7.5006666370396715, 7.539230729988306, 7.577598564189055, 7.6157731058639095, 7.653757247260983], [0.0, 0.7681145747868608, 1.0862780491200215, 1.3304134695650072, 1.5362291495737217, 1.7175564037317668, 1.8814887722226779, 2.0322401432901573, 2.172556098240043, 2.3043437243605824, 2.4289915602982237, 2.5475478405713994, 2.6608269391300143, 2.7694764848252458, 2.8740215726399825, 2.974894956128703, 3.0724582991474434, 3.167017524422623, 3.2588341473600644, 3.3481338085566414, 3.4351128074635335, 3.5199431813596083, 3.602776706930364, 3.6837480912787726, 3.7629775444453557, 3.840572873934304, 3.916631205513228, 3.9912404086950213, 4.064480286580315, 4.136423575989287, 4.207136793592525, 4.276680956068619, 4.345112196480086, 4.412482294582042, 4.4788391353117385, 4.544227107000705, 4.608687448721165, 4.672258554489466, 4.734976240700686, 4.796873982084583, 4.857983120596447, 4.9183330509431755, 4.9779513858614575, 5.03686410378521, 5.095095681142799, 5.1526692111953, 5.209606511052442, 5.265928218272634, 5.321653878260029, 5.376802023508025, 5.431390245600108, 5.485435260760991, 5.5389529696504916, 5.591958512006326, 5.644466316668034, 5.6964901474504455, 5.748043145279965, 5.799137866959191, 5.849786320883866, 5.8999999999999995, 5.949789912257406, 5.999166608788257, 6.048140210014975, 6.096720429870472, 6.144916598294887, 6.192737682156413, 6.240192304729077, 6.287288763847259, 6.334035048845246, 6.380438856379708, 6.4265076052238514, 6.472248450113762, 6.517668294720129, 6.562773803811921, 6.607571414672716, 6.652067347825035, 6.696267617113283, 6.740178039191546, 6.783804242458652, 6.827151675479314, 6.870225614927067, 6.913031173081747, 6.955573304911681, 6.997856814768361, 7.0398863627192165, 7.0816664705420855, 7.123201527403251, 7.164495795239188, 7.205553413860728, 7.246378405796926, 7.286974680894671, 7.327346040688948, 7.367496182557545, 7.407428703673091, 7.447147104764348, 7.486654793697916, 7.525955088890711, 7.565051222562872, 7.603946343840151, 7.642643521714199, 7.681145747868608, 7.719455939378112], [0.0, 0.7745966692414833, 1.0954451150103321, 1.3416407864998738, 1.5491933384829666, 1.7320508075688772, 1.8973665961010275, 2.0493901531919194, 2.1908902300206643, 2.3237900077244498, 2.449489742783178, 2.569046515733026, 2.6832815729997477, 2.792848008753788, 2.8982753492378874, 2.9999999999999996, 3.098386676965933, 3.1937438845342623, 3.2863353450309964, 3.3763886032268267, 3.4641016151377544, 3.5496478698597693, 3.63318042491699, 3.714835124201342, 3.794733192202055, 3.8729833462074166, 3.9496835316262997, 4.024922359499621, 4.098780306383839, 4.171330722922842, 4.242640687119285, 4.3127717305695645, 4.381780460041329, 4.449719092257398, 4.516635916254486, 4.58257569495584, 4.6475800154488995, 4.711687595755898, 4.774934554525329, 4.8373546489791295, 4.898979485566356, 4.959838707054898, 5.019960159204453, 5.079370039680117, 5.138093031466052, 5.196152422706631, 5.253570214625478, 5.310367218940701, 5.366563145999495, 5.422176684690383, 5.477225575051661, 5.531726674375732, 5.585696017507576, 5.639148871948674, 5.692099788303082, 5.744562646538029, 5.796550698475775, 5.848076606885378, 5.8991524815010505, 5.949789912257406, 5.999999999999999, 6.049793384901669, 6.099180272790762, 6.148170459575758, 6.196773353931866, 6.244997998398397, 6.292853089020909, 6.340346993658943, 6.387487769068525, 6.434283176858164, 6.48074069840786, 6.526867548832287, 6.572670690061993, 6.618156843109718, 6.663332499583071, 6.7082039324993685, 6.752777206453653, 6.797058187186571, 6.841052550594828, 6.884765791223402, 6.928203230275509, 6.97137002317335, 7.014271166700073, 7.056911505750939, 7.099295739719539, 7.1414284285428495, 7.183313998427188, 7.224956747275377, 7.26636084983398, 7.307530362578043, 7.348469228349534, 7.389181280764466, 7.429670248402684, 7.469939758793239, 7.5099933422074345, 7.549834435270749, 7.58946638440411, 7.628892449104261, 7.668115805072325, 7.707139547199078, 7.745966692414833, 7.784600182411426], [0.0, 0.7810249675906654, 1.104536101718726, 1.3527749258468684, 1.5620499351813308, 1.746424919657298, 1.9131126469708992, 2.0663978319771825, 2.209072203437452, 2.3430749027719964, 2.4698178070456938, 2.5903667693977237, 2.705549851693737, 2.816025568065745, 2.9223278392404914, 3.0248966924508345, 3.1240998703626617, 3.2202484376209237, 3.3136083051561784, 3.4044089061098406, 3.492849839314596, 3.5791060336346563, 3.6633318168028404, 3.745664160065609, 3.8262252939417984, 3.9051248379533274, 3.9824615503479754, 4.058324777540605, 4.132795663954365, 4.205948168962618, 4.277849927241487, 4.34856298103178, 4.418144406874904, 4.486646854834912, 4.5541190146942805, 4.620606020859168, 4.686149805543993, 4.750789408087881, 4.814561246884289, 4.87749935930288, 4.9396356140913875, 5.000999900019996, 5.061620293937506, 5.121523210920751, 5.180733538795447, 5.239274758971893, 5.297169055259611, 5.354437412091022, 5.411099703387474, 5.467174773134658, 5.522680508593631, 5.577633906953737, 5.63205113613149, 5.6859475903318, 5.739337940912697, 5.792236183029832, 5.844655678480983, 5.8966091951222275, 5.948108943185221, 5.999166608788257, 6.049793384901669, 6.1, 6.149796744608719, 6.199193495931548, 6.248199740725323, 6.296824596572465, 6.345076831686122, 6.392964883369843, 6.440496875241847, 6.487680633323437, 6.534523701081817, 6.5810333535091585, 6.627216610312357, 6.673080248281149, 6.71863081289633, 6.7638746292343415, 6.808817812219681, 6.853466276272176, 6.897825744392215, 6.941901756723442, 6.985699678629192, 7.029224708315989, 7.07248188403477, 7.115476090888086, 7.158212067269313, 7.200694410957877, 7.242927584892728, 7.284915922644544, 7.326663633605681, 7.368174807915458, 7.409453421137082, 7.450503338701353, 7.491328320131218, 7.531932023060219, 7.572318007057021, 7.6124897372673015, 7.652450587883597, 7.692203845452876, 7.731752712031082, 7.771100308193172, 7.810249675906655, 7.849203781276163], [0.0, 0.787400787401181, 1.1135528725660042, 1.3638181696985856, 1.574801574802362, 1.760681686165901, 1.928730152198591, 2.083266665599966, 2.2271057451320084, 2.362202362203543, 2.4899799195977463, 2.6115129714401193, 2.727636339397171, 2.839013913315678, 2.9461839725312466, 3.049590136395381, 3.149603149604724, 3.246536616149585, 3.340658617698013, 3.432200460346103, 3.521363372331802, 3.608323710533743, 3.6932370625238775, 3.7762415176998414, 3.857460304397182, 3.9370039370059056, 4.014971979976946, 4.091454509095756, 4.166533331199932, 4.240283009422838, 4.3127717305695645, 4.384062043356595, 4.454211490264017, 4.523273151159457, 4.591296113299598, 4.658325879540846, 4.724404724407086, 4.789572005931219, 4.853864439804639, 4.917316341257699, 4.979959839195493, 5.041825066382213, 5.10294032886923, 5.163332257370234, 5.223025942880239, 5.282045058497702, 5.340411969127476, 5.3981478305063115, 5.455272678794342, 5.511805511808268, 5.5677643628300215, 5.62316636780382, 5.678027826631356, 5.732364259186606, 5.786190456595773, 5.839520528262573, 5.892367945062493, 5.944745579080739, 5.99666574022598, 6.048140210014975, 6.099180272790762, 6.149796744608719, 6.199999999999999, 6.249799996799897, 6.299206299209448, 6.348228099241551, 6.39687423668779, 6.445153217728807, 6.49307323229917, 6.540642170307133, 6.587867636800241, 6.6347569661593475, 6.681317235396026, 6.727555276621664, 6.773477688750439, 6.819090848492928, 6.864400920692206, 6.90941386804988, 6.954135460285484, 6.998571282769077, 7.042726744663604, 7.08660708661063, 7.130217387990355, 7.173562573784381, 7.216647421067486, 7.259476565152615, 7.302054505411474, 7.344385610791416, 7.386474125047755, 7.428324171709255, 7.469939758793239, 7.511324783285569, 7.552483035399683, 7.593418202627852, 7.634133873596926, 7.674633541739956, 7.714920608794364, 7.754998388136519, 7.79487010796203, 7.834538914320357, 7.874007874011811, 7.913279977354524], [0.0, 0.7937253933193772, 1.1224972160321824, 1.3747727084867523, 1.5874507866387544, 1.7748239349298849, 1.9442222095223582, 2.1, 2.244994432064365, 2.3811761799581315, 2.5099800796022267, 2.632489316217637, 2.7495454169735045, 2.861817604250837, 2.9698484809834995, 3.074085229787879, 3.1749015732775088, 3.2726136343907144, 3.3674916480965473, 3.4597687784012394, 3.5496478698597698, 3.6373066958946425, 3.722902093797257, 3.8065732621348563, 3.8884444190447165, 3.968626966596886, 4.047221268969613, 4.124318125460256, 4.2, 4.274342054632503, 4.347413023856832, 4.419275958796871, 4.48998886412873, 4.559605246071199, 4.628174586162454, 4.695742752749559, 4.762352359916263, 4.828043081829325, 4.892851929090027, 4.956813492557492, 5.019960159204453, 5.082322303829225, 5.143928459844674, 5.204805471869242, 5.264978632435274, 5.324471804789654, 5.383307533477908, 5.441507144165117, 5.499090833947009, 5.55607775323564, 5.612486080160912, 5.668333088307356, 5.723635208501674, 5.7784080852774675, 5.8326666285670745, 5.886425061104576, 5.939696961966999, 5.9924953066314535, 6.044832503882966, 6.096720429870472, 6.148170459575758, 6.199193495931548, 6.249799996799897, 6.3, 6.3498031465550175, 6.3992187023104625, 6.448255578061403, 6.496922348312315, 6.545227268781429, 6.593178292750774, 6.640783086353597, 6.688049042882386, 6.734983296193095, 6.7815927332743895, 6.827884006044625, 6.87386354243376, 6.919537556802479, 6.96491205974634, 7.009992867328754, 7.0547856097829085, 7.0992957397195395, 7.143528539874395, 7.187489130426565, 7.23118247591637, 7.274613391789285, 7.317786550590281, 7.3607064878311785, 7.40337760755184, 7.445804187594514, 7.487990384609211, 7.52994023880668, 7.571657678474378, 7.6131465242697125, 7.654410493303845, 7.695453203028396, 7.736278174936576, 7.776888838089433, 7.817288532477231, 7.857480512225277, 7.897467948652911, 7.937253933193772, 7.976841480185], [0.0, 0.8, 1.131370849898476, 1.385640646055102, 1.6, 1.788854381999832, 1.9595917942265426, 2.1166010488516727, 2.262741699796952, 2.4, 2.5298221281347035, 2.65329983228432, 2.771281292110204, 2.8844410203711917, 2.9933259094191533, 3.098386676965933, 3.2, 3.2984845004941286, 3.394112549695428, 3.4871191548325395, 3.577708763999664, 3.6660605559646724, 3.752332607858744, 3.836665218650176, 3.9191835884530852, 4.0, 4.079215610874228, 4.156921938165306, 4.233202097703345, 4.308131845707604, 4.381780460041329, 4.454211490264018, 4.525483399593904, 4.595650117230424, 4.664761515876241, 4.732863826479693, 4.8, 4.866210024238576, 4.931531202375181, 4.9959983987187195, 5.059644256269407, 5.122499389946279, 5.184592558726289, 5.2459508194416005, 5.30659966456864, 5.366563145999495, 5.4258639865002145, 5.4845236803208355, 5.542562584220408, 5.6000000000000005, 5.656854249492381, 5.713142742834281, 5.768882040742383, 5.8240879114244155, 5.878775382679628, 5.932958789676531, 5.986651818838307, 6.0398675482166, 6.092618484691127, 6.144916598294887, 6.196773353931866, 6.248199740725323, 6.299206299209448, 6.3498031465550175, 6.4, 6.449806198638839, 6.499230723708768, 6.5482822174979605, 6.596969000988257, 6.64529909033446, 6.6932802122726045, 6.740919818541087, 6.788225099390856, 6.835202996254025, 6.881860213634101, 6.92820323027551, 6.974238309665079, 7.019971509913698, 7.065408693062278, 7.110555533852471, 7.155417527999328, 7.2, 7.244308110509934, 7.288346863315439, 7.332121111929345, 7.37563556583431, 7.418894796396564, 7.4619032424710525, 7.504665215717488, 7.547184905645283, 7.58946638440411, 7.631513611335565, 7.673330437300352, 7.7149206087943645, 7.756287771866127, 7.797435475847171, 7.8383671769061705, 7.879086241436885, 7.919595949289333, 7.959899496852961, 8.0, 8.039900496896713], [0.0, 0.8062257748298549, 1.1401754250991378, 1.3964240043768943, 1.6124515496597098, 1.8027756377319946, 1.9748417658131499, 2.133072900770154, 2.2803508501982757, 2.4186773244895647, 2.5495097567963922, 2.6739483914241875, 2.7928480087537886, 2.9068883707497264, 3.016620625799671, 3.1224989991991987, 3.2249030993194197, 3.324154027718932, 3.420526275297414, 3.5142566781611158, 3.605551275463989, 3.6945906403822333, 3.7815340802378072, 3.866522985836241, 3.9496835316262997, 4.031128874149275, 4.110960958218893, 4.189272013130682, 4.266145801540308, 4.341658669218482, 4.415880433163923, 4.488875137492688, 4.560701700396551, 4.631414470763764, 4.701063709417263, 4.769696007084728, 4.8373546489791295, 4.904079934095691, 4.969909455915671, 5.034878350069642, 5.0990195135927845, 5.162363799656123, 5.224940191045253, 5.28677595515452, 5.347896782848375, 5.4083269131959835, 5.468089245796926, 5.527205442174191, 5.585696017507577, 5.643580423808984, 5.70087712549569, 5.757603668193913, 5.813776741499453, 5.869412236331676, 5.924525297439449, 5.979130371550699, 6.033241251599342, 6.08687111741328, 6.1400325732035, 6.192737682156413, 6.244997998398397, 6.296824596572465, 6.348228099241551, 6.3992187023104625, 6.449806198638839, 6.499999999999999, 6.549809157525125, 6.599242380758566, 6.648308055437864, 6.697014260101287, 6.745368781616021, 6.793379129711516, 6.841052550594828, 6.888396039717809, 6.93541635375988, 6.98212002188447, 7.0285133563222315, 7.074602462329597, 7.12039324756716, 7.165891430938652, 7.211102550927978, 7.256031973468694, 7.300684899377592, 7.345066371381541, 7.389181280764467, 7.433034373659253, 7.476630257007497, 7.519973404208288, 7.5630681604756145, 7.6059187479225665, 7.648529270389177, 7.6909037180295, 7.733045971672482, 7.774959806970066, 7.816648898345122, 7.858116822750854, 7.899367063252599, 7.940403012442127, 7.981227975693965, 8.021845174272563, 8.06225774829855, 8.10246875958186], [0.0, 0.812403840463596, 1.1489125293076057, 1.4071247279470291, 1.624807680927192, 1.8165902124584952, 1.98997487421324, 2.149418526020468, 2.2978250586152114, 2.437211521390788, 2.569046515733026, 2.6944387170614963, 2.8142494558940583, 2.9291637031753623, 3.0397368307141326, 3.1464265445104544, 3.249615361854384, 3.3496268448888453, 3.4467375879228173, 3.541186241925155, 3.6331804249169903, 3.722902093797257, 3.81051177665153, 3.8961519477556315, 3.97994974842648, 4.06201920231798, 4.142463035441596, 4.221374183841087, 4.298837052040936, 4.374928570845472, 4.449719092257397, 4.523273151159456, 4.595650117230423, 4.666904755831214, 4.737087712930805, 4.806245936279166, 4.874423042781576, 4.941659640242335, 5.007993610219566, 5.073460357586329, 5.138093031466052, 5.201922721455982, 5.264978632435274, 5.3272882407468805, 5.388877434122993, 5.449770637375485, 5.509990925582365, 5.569560126257728, 5.628498911788117, 5.686826883245172, 5.744562646538029, 5.801723881744115, 5.858327406350725, 5.914389233048499, 5.96992462263972, 6.024948132556827, 6.079473661428265, 6.133514490078261, 6.187083319303208, 6.240192304729077, 6.292853089020909, 6.345076831686122, 6.39687423668779, 6.448255578061403, 6.499230723708768, 6.549809157525125, 6.6, 6.649812027418519, 6.699253689777691, 6.748333127521196, 6.797058187186572, 6.8454364360499325, 6.8934751758456345, 6.941181455631311, 6.988562083862459, 7.035623639735144, 7.08237248385031, 7.128814768248646, 7.17495644586084, 7.2208032794142785, 7.266360849833981, 7.311634564172365, 7.356629663099809, 7.401351227985333, 7.445804187594514, 7.489993324429602, 7.533923280734945, 7.577598564189054, 7.62102355330306, 7.664202502543888, 7.707139547199077, 7.749838707999025, 7.792303895511263, 7.834538914320357, 7.8765474670060875, 7.918333157931661, 7.95989949685296, 8.001249902359007, 8.04238770515324, 8.083316151184489, 8.12403840463596, 8.16455755078008], [0.0, 0.8185352771872451, 1.1575836902790224, 1.4177446878757827, 1.6370705543744901, 1.8303005217723127, 2.004993765576342, 2.1656407827707715, 2.315167380558045, 2.455605831561735, 2.588435821108957, 2.714774392099646, 2.8354893757515653, 2.951270912674741, 3.062678566222711, 3.1701734968294715, 3.2741411087489802, 3.374907406137241, 3.4727510708370675, 3.567912554982255, 3.6606010435446255, 3.7509998667022106, 3.8392707640904935, 3.9255572852781047, 4.009987531152684, 4.092676385936225, 4.173727350941841, 4.253234063627348, 4.331281565541543, 4.407947368106838, 4.483302354291978, 4.557411546042337, 4.63033476111609, 4.702127178203499, 4.77283982551269, 4.8425200051213, 4.91121166312347, 4.978955713801841, 5.045790324617146, 5.111751167652823, 5.176871642217914, 5.241183072551464, 5.304714883949938, 5.367494760127856, 5.429548784199292, 5.490901565316937, 5.551576352712804, 5.61159513863928, 5.670978751503131, 5.729746940310715, 5.787918451395113, 5.845511098270194, 5.902541825349482, 5.959026766175833, 6.014981296729027, 6.070420084310475, 6.125357132445422, 6.17980582219215, 6.23377895020348, 6.287288763847259, 6.340346993658943, 6.392964883369843, 6.445153217728807, 6.496922348312315, 6.5482822174979605, 6.599242380758566, 6.649812027418519, 6.7, 6.749814812274482, 6.79926466612383, 6.848357467305573, 6.897100840208152, 6.945502141674135, 6.993568473962345, 7.041306696913577, 7.088723439378913, 7.13582510996451, 7.182617907142214, 7.229107828771128, 7.275300681071539, 7.321202087089251, 7.366817494685205, 7.4121521840825695, 7.457211275000863, 7.501999733404421, 7.546522377890362, 7.590783885739338, 7.634788798650556, 7.678541528180987, 7.722046360907191, 7.76530746332687, 7.808328886515987, 7.851114570556209, 7.893668348746355, 7.935993951610599, 7.978095010715276, 8.019975062305368, 8.061637550770936, 8.103085831953157, 8.144323176298936, 8.18535277187245, 8.226177727231525], [0.0, 0.8246211251235321, 1.16619037896906, 1.4282856857085702, 1.6492422502470643, 1.8439088914585775, 2.0199009876724157, 2.181742422927143, 2.33238075793812, 2.473863375370596, 2.6076809620810595, 2.734958866235469, 2.8565713714171403, 2.973213749463701, 3.0854497241083023, 3.1937438845342623, 3.2984845004941286, 3.4, 3.4985711369071804, 3.594440151122286, 3.687817782917155, 3.778888725538237, 3.867815921162743, 3.954743986657038, 4.039801975344831, 4.123105625617661, 4.204759208325728, 4.28485705712571, 4.363484845854286, 4.440720662234904, 4.516635916254486, 4.591296113299599, 4.66476151587624, 4.737087712930805, 4.8083261120685235, 4.878524367060187, 4.947726750741192, 5.015974481593781, 5.083306010855534, 5.149757275833494, 5.215361924162119, 5.280151512977635, 5.344155686354956, 5.407402333838309, 5.469917732470938, 5.531726674375732, 5.592852581643825, 5.653317610041028, 5.713142742834281, 5.772347875864725, 5.830951894845301, 5.888972745734184, 5.946427498927402, 6.003332407921454, 6.059702963017247, 6.115553940568263, 6.170899448216605, 6.2257529665093525, 6.280127387243033, 6.334035048845246, 6.387487769068525, 6.440496875241847, 6.49307323229917, 6.545227268781429, 6.596969000988257, 6.648308055437864, 6.699253689777691, 6.749814812274482, 6.8, 6.849817515817484, 6.899275324264137, 6.948381106416083, 6.997142273814361, 7.045565981523414, 7.093659140387279, 7.14142842854285, 7.188880302244572, 7.236021006050217, 7.282856582413251, 7.329392880723478, 7.37563556583431, 7.42159012611179, 7.467261881037788, 7.512655988397179, 7.557777451076474, 7.602631123499285, 7.647221717722065, 7.691553809211764, 7.735631842325486, 7.779460135510689, 7.8230428862431785, 7.866384175718855, 7.909487973314076, 7.952358140828418, 7.994998436522675, 8.037412518964047, 8.079603950689663, 8.121576201698781, 8.16333265278342, 8.204876598706406, 8.246211251235321, 8.287339742040265], [0.0, 0.8306623862918076, 1.174734012447073, 1.4387494569938162, 1.661324772583615, 1.8574175621006712, 2.0346989949375804, 2.1977260975835913, 2.349468024894146, 2.4919871588754225, 2.6267851073127395, 2.7549954627911823, 2.8774989139876324, 2.994995826374388, 3.1080540535840107, 3.217141588429082, 3.32264954516723, 3.424908757908742, 3.5242020373412193, 3.6207733980463352, 3.7148351242013424, 3.8065732621348563, 3.8961519477556315, 3.9837168574084183, 4.069397989875161, 4.153311931459037, 4.235563716909475, 4.316248370981448, 4.3954521951671826, 4.473253849269009, 4.54972526643093, 4.624932431938872, 4.698936049788292, 4.77179211617606, 4.843552415324934, 4.914264950122246, 4.983974317750845, 5.052722038663912, 5.120546845796843, 5.187484939737176, 5.253570214625479, 5.3188344587888805, 5.383307533477909, 5.447017532558529, 5.509990925582365, 5.572252686302012, 5.63382640840131, 5.69473440996154, 5.754997827975265, 5.814636704042653, 5.873670062235366, 5.932115979985557, 5.989991652748776, 6.047313453096343, 6.104096984812742, 6.1603571325045765, 6.216108107168021, 6.271363488110062, 6.326136261573885, 6.380438856379708, 6.434283176858164, 6.487680633323437, 6.540642170307133, 6.593178292750774, 6.64529909033446, 6.697014260101287, 6.748333127521196, 6.79926466612383, 6.849817515817484, 6.9, 6.949820141557622, 6.999285677838847, 7.048404074682439, 7.097182539571601, 7.145628033979938, 7.19374728496908, 7.2415467960926705, 7.289032857656769, 7.336211556382492, 7.383088784512889, 7.429670248402685, 7.475961476626268, 7.521967827636597, 7.567694497005016, 7.6131465242697125, 7.658328799418317, 7.703246069028303, 7.747902942086975, 7.792303895511263, 7.836453279386026, 7.880355321938218, 7.924014134263013, 7.967433714816837, 8.010617953691215, 8.053570636680355, 8.096295449154509, 8.138795979750322, 8.18107572388864, 8.223138087129511, 8.264986388373547, 8.306623862918075, 8.34805366537614], [0.0, 0.8366600265340756, 1.1832159566199232, 1.4491376746189442, 1.6733200530681511, 1.8708286933869709, 2.04939015319192, 2.2135943621178655, 2.3664319132398464, 2.5099800796022267, 2.6457513110645907, 2.774887385102322, 2.8982753492378883, 3.0166206257996717, 3.1304951684997055, 3.24037034920393, 3.3466401061363023, 3.4496376621320683, 3.5496478698597698, 3.6469165057620945, 3.7416573867739418, 3.834057902536163, 3.924283374069717, 4.012480529547776, 4.09878030638384, 4.183300132670378, 4.266145801540309, 4.3474130238568325, 4.427188724235731, 4.505552130427525, 4.58257569495584, 4.658325879540847, 4.732863826479693, 4.806245936279167, 4.878524367060187, 4.949747468305833, 5.019960159204453, 5.089204259999789, 5.157518783291051, 5.2249401910452535, 5.291502622129181, 5.35723809439155, 5.422176684690385, 5.486346689738081, 5.549774770204644, 5.612486080160912, 5.674504383644443, 5.735852159879995, 5.796550698475777, 5.856620185738529, 5.916079783099617, 5.974947698515863, 6.033241251599343, 6.090976933136425, 6.148170459575759, 6.2048368229954285, 6.260990336999411, 6.316644678941503, 6.3718129288295975, 6.4265076052238514, 6.48074069840786, 6.534523701081817, 6.587867636800241, 6.640783086353597, 6.6932802122726045, 6.745368781616021, 6.797058187186572, 6.848357467305573, 6.899275324264137, 6.949820141557622, 7.000000000000001, 7.049822692805827, 7.0992957397195395, 7.148426400264607, 7.197221686178633, 7.24568837309472, 7.293833011524189, 7.341661937191062, 7.3891812807644675, 7.436396977031284, 7.4833147735478835, 7.529940238806681, 7.576278769950325, 7.622335600063802, 7.668115805072326, 7.713624310270757, 7.75886589650833, 7.803845206050669, 7.848566748139434, 7.893034904268446, 7.937253933193772, 7.981227975693966, 8.024961059095553, 8.068457101577724, 8.1117199162693, 8.154753215150045, 8.19756061276768, 8.240145629781066, 8.282511696339462, 8.324662155306966, 8.366600265340756, 8.408329203831164], [0.0, 0.8426149773176359, 1.1916375287812984, 1.4594519519326425, 1.6852299546352718, 1.8841443681416774, 2.0639767440550294, 2.2293496809607953, 2.3832750575625967, 2.5278449319529073, 2.6645825188948455, 2.7946377224964243, 2.918903903865285, 3.0380915061926625, 3.152776554086889, 3.2634337744161437, 3.3704599092705436, 3.4741905532080417, 3.5749125863438955, 3.672873534441392, 3.768288736283355, 3.861346915261565, 3.952214569073901, 4.041039470235351, 4.127953488110059, 4.2130748865881795, 4.296510211788167, 4.378355855797928, 4.458699361921591, 4.537620521815371, 4.61519230368573, 4.69148164229596, 4.766550115125193, 4.8404545241123795, 4.913247398615299, 4.984977432245807, 5.0556898639058145, 5.1254268114957995, 5.194227565288221, 5.262128846769148, 5.329165037789691, 5.395368384086485, 5.46076917659042, 5.525395913416522, 5.589275444992849, 5.652433104425031, 5.71489282489182, 5.776677245614472, 5.83780780773057, 5.898304841223451, 5.958187643906493, 6.017474553332154, 6.076183012385325, 6.134329629226001, 6.191930232165088, 6.248999919987198, 6.305553108173778, 6.361603571427569, 6.417164482853779, 6.472248450113762, 6.526867548832287, 6.5810333535091585, 6.6347569661593475, 6.688049042882386, 6.740919818541087, 6.793379129711516, 6.8454364360499325, 6.897100840208152, 6.948381106416083, 6.999285677838847, 7.049822692805827, 7.1, 7.149825172687791, 7.199305522062527, 7.248448109768049, 7.297259759663212, 7.345747068882784, 7.3939164182454755, 7.441773982055624, 7.489325737341113, 7.53657747256671, 7.583534795858723, 7.630203142774117, 7.676587783644501, 7.72269383052313, 7.768526243760782, 7.814089838234521, 7.859389289251424, 7.904429138147802, 7.949213797602879, 7.993747556684537, 8.038034585643434, 8.082078940470701, 8.125884567233282, 8.16945530620004, 8.212794895770866, 8.255906976220118, 8.298795093265047, 8.341462701469089, 8.383913167489272, 8.426149773176359, 8.468175718535841], [0.0, 0.848528137423857, 1.2, 1.4696938456699071, 1.697056274847714, 1.8973665961010278, 2.078460969082653, 2.244994432064365, 2.4, 2.545584412271571, 2.6832815729997477, 2.814249455894058, 2.9393876913398143, 3.0594117081556713, 3.1749015732775088, 3.2863353450309964, 3.394112549695428, 3.4985711369071804, 3.6, 3.6986484017813863, 3.7947331922020555, 3.8884444190447165, 3.97994974842648, 4.069397989875161, 4.156921938165306, 4.242640687119286, 4.3266615305567875, 4.409081537009721, 4.48998886412873, 4.5694638635183455, 4.6475800154489, 4.724404724407087, 4.8, 4.874423042781577, 4.947726750741193, 5.019960159204453, 5.091168824543142, 5.1613951602255765, 5.230678732248808, 5.299056519796709, 5.366563145999495, 5.43323108288245, 5.499090833947008, 5.564171097297422, 5.628498911788116, 5.692099788303082, 5.754997827975264, 5.817215828899595, 5.8787753826796285, 5.939696961966999, 6.0, 6.059702963017248, 6.118823416311343, 6.177378084592201, 6.235382907247959, 6.29285308902091, 6.3498031465550175, 6.406246951218787, 6.462197768561405, 6.517668294720129, 6.572670690061993, 6.627216610312357, 6.681317235396026, 6.734983296193095, 6.788225099390856, 6.841052550594828, 6.8934751758456345, 6.945502141674135, 6.997142273814361, 7.048404074682439, 7.0992957397195395, 7.149825172687791, 7.2, 7.249827584156743, 7.299315036357863, 7.3484692283495345, 7.397296803562773, 7.445804187594514, 7.493997598078079, 7.541883053985921, 7.589466384404111, 7.636753236814713, 7.68374908491942, 7.730459236035075, 7.776888838089433, 7.823042886243179, 7.868926229162401, 7.914543574963752, 7.95989949685296, 8.0049984384758, 8.049844718999243, 8.094442537939225, 8.138795979750322, 8.182909018191515, 8.226785520481254, 8.270429251254132, 8.313843876330612, 8.357032966310472, 8.4, 8.442748367682174, 8.485281374238571, 8.527602242131138], [0.0, 0.8544003745317531, 1.2083045973594573, 1.4798648586948744, 1.7088007490635062, 1.91049731745428, 2.092844953645635, 2.260530911091463, 2.4166091947189146, 2.563201123595259, 2.701851217221259, 2.833725463060951, 2.9597297173897488, 3.0805843601498726, 3.196873472629156, 3.309078421554859, 3.4176014981270124, 3.522782990761707, 3.6249137920783716, 3.7242448899072147, 3.82099463490856, 3.915354390090379, 4.007492981902776, 4.097560249709576, 4.18568990729127, 4.272001872658766, 4.356604182158393, 4.439594576084623, 4.521061822182926, 4.601086828130937, 4.679743582719036, 4.757099956906519, 4.833218389437829, 4.908156476723211, 4.98196748283246, 5.054700782440045, 5.126402247190518, 5.197114584074513, 5.266877632905477, 5.335728628781641, 5.403702434442518, 5.470831746635972, 5.537147279962851, 5.602677931132575, 5.667450926121902, 5.731491952362839, 5.794825277780168, 5.857473858242988, 5.9194594347794975, 5.980802621722272, 6.041522986797286, 6.101639124038721, 6.161168720299745, 6.220128616033596, 6.278534860936905, 6.336402764976356, 6.393746945258312, 6.450581369148055, 6.5069193939989765, 6.562773803811921, 6.618156843109718, 6.673080248281149, 6.727555276621664, 6.7815927332743895, 6.835202996254025, 6.888396039717809, 6.941181455631311, 6.993568473962345, 7.045565981523414, 7.097182539571601, 7.148426400264607, 7.199305522062527, 7.249827584156743, 7.3, 7.349829930005183, 7.399324293474371, 7.448489779814429, 7.4973328590906245, 7.545859791965394, 7.594076639065476, 7.64198926981712, 7.689603370785778, 7.736924453553881, 7.783957862167549, 7.830708780180758, 7.877182237323192, 7.923383115816122, 7.969316156358713, 8.014985963805552, 8.060397012554654, 8.105553651663778, 8.150460109711599, 8.195120499419152, 8.239538822045807, 8.283718971573094, 8.327664738688751, 8.37137981458254, 8.414867794564572, 8.4581321815162, 8.501176389182852, 8.544003745317532, 8.586617494683225], [0.0, 0.8602325267042626, 1.2165525060596438, 1.489966442575134, 1.7204650534085253, 1.9235384061671346, 2.1071307505705477, 2.2759613353482084, 2.4331050121192876, 2.580697580112788, 2.7202941017470885, 2.8530685235374214, 2.979932885150268, 3.1016124838541645, 3.218695387886216, 3.3316662497915357, 3.4409301068170506, 3.5468295701936396, 3.6496575181789317, 3.749666651850535, 3.847076812334269, 3.9420806688854046, 4.034848200366403, 4.125530268947254, 4.214261501141095, 4.301162633521313, 4.386342439892262, 4.469899327725402, 4.551922670696417, 4.632493928760188, 4.711687595755898, 4.789572005931219, 4.866210024238575, 4.941659640242335, 5.015974481593781, 5.089204259999788, 5.161395160225576, 5.232590180780452, 5.302829433425141, 5.372150407425317, 5.440588203494177, 5.508175741568165, 5.574943945906542, 5.6409219104681805, 5.706137047074843, 5.770615218501403, 5.834380858325929, 5.897457079114692, 5.959865770300536, 6.021627686929839, 6.082762530298219, 6.143289021363068, 6.203224967708329, 6.262587324740471, 6.321392251711643, 6.3796551630946325, 6.437390775772432, 6.494613152451807, 6.55133574166368, 6.607571414672716, 6.663332499583071, 6.71863081289633, 6.773477688750439, 6.827884006044625, 6.881860213634101, 6.93541635375988, 6.988562083862459, 7.041306696913577, 7.093659140387279, 7.145628033979938, 7.197221686178633, 7.248448109768049, 7.299315036357863, 7.349829930005183, 7.3999999999999995, 7.44983221287567, 7.49933330370107, 7.548509786706248, 7.597367965289032, 7.645913941446111, 7.694153624668538, 7.742092740338364, 7.789736837660179, 7.837091297158659, 7.884161337770809, 7.930952023559341, 7.977468270071652, 8.023714850367003, 8.069696400732806, 8.115417426109392, 8.160882305241266, 8.206095295571457, 8.251060537894508, 8.295782060782456, 8.340263784797218, 8.384509526501832, 8.42852300228219, 8.472307831990054, 8.515867542417507, 8.559205570612264, 8.602325267042627, 8.645229898620395], [0.0, 0.8660254037844387, 1.224744871391589, 1.5000000000000002, 1.7320508075688774, 1.9364916731037085, 2.121320343559643, 2.29128784747792, 2.449489742783178, 2.598076211353316, 2.7386127875258306, 2.8722813232690148, 3.0000000000000004, 3.122498999199199, 3.24037034920393, 3.3541019662496843, 3.464101615137755, 3.570714214271425, 3.6742346141747673, 3.7749172176353754, 3.872983346207417, 3.968626966596886, 4.06201920231798, 4.153311931459037, 4.242640687119286, 4.330127018922194, 4.415880433163924, 4.5, 4.58257569495584, 4.663689526544408, 4.743416490252569, 4.8218253804964775, 4.898979485566356, 4.974937185533101, 5.049752469181039, 5.123475382979799, 5.196152422706632, 5.26782687642637, 5.338539126015656, 5.408326913195984, 5.477225575051661, 5.545268253204709, 5.612486080160912, 5.678908345800274, 5.7445626465380295, 5.809475019311125, 5.873670062235366, 5.937171043518958, 6.000000000000001, 6.06217782649107, 6.123724356957946, 6.184658438426491, 6.244997998398398, 6.304760106459247, 6.363961030678928, 6.422616289332565, 6.48074069840786, 6.5383484153110105, 6.59545297913646, 6.652067347825035, 6.7082039324993685, 6.7638746292343415, 6.819090848492928, 6.87386354243376, 6.92820323027551, 6.98212002188447, 7.035623639735144, 7.088723439378913, 7.14142842854285, 7.19374728496908, 7.24568837309472, 7.297259759663212, 7.3484692283495345, 7.399324293474371, 7.44983221287567, 7.5, 7.549834435270751, 7.599342076785332, 7.6485292703891785, 7.697402159170327, 7.745966692414834, 7.794228634059948, 7.842193570679062, 7.88986691902975, 7.937253933193772, 7.984359711335657, 8.031189202104505, 8.077747210701757, 8.12403840463596, 8.170067319184096, 8.215838362577491, 8.261355820929154, 8.306623862918075, 8.351646544245034, 8.396427811873334, 8.440971508067065, 8.485281374238571, 8.529361054615991, 8.573214099741124, 8.616843969807043, 8.660254037844387, 8.703447592764606], [0.0, 0.8717797887081349, 1.2328828005937953, 1.5099668870541503, 1.7435595774162698, 1.9493588689617931, 2.1354156504062627, 2.3065125189341593, 2.4657656011875906, 2.615339366124404, 2.7568097504180447, 2.8913664589601926, 3.0199337741083006, 3.1432467291003428, 3.2619012860600183, 3.3763886032268267, 3.4871191548325395, 3.594440151122286, 3.6986484017813863, 3.8000000000000007, 3.8987177379235862, 3.9949968710876362, 4.0890096600521755, 4.180908992073375, 4.270831300812525, 4.358898943540674, 4.445222154178575, 4.529900661162451, 4.613025037868319, 4.694677837722201, 4.774934554525329, 4.8538644398046396, 4.931531202375181, 5.007993610219566, 5.083306010855535, 5.157518783291051, 5.230678732248808, 5.302829433425142, 5.374011537017762, 5.444263035526481, 5.513619500836089, 5.582114294781146, 5.649778756730215, 5.716642371182581, 5.782732917920385, 5.848076606885378, 5.912698199637794, 5.976621118993575, 6.039867548216601, 6.102458520956944, 6.164414002968978, 6.225752966509353, 6.2864934582006855, 6.3466526610489735, 6.406246951218788, 6.465291950097846, 6.523802572120037, 6.581793068761734, 6.639277069079134, 6.696267617113283, 6.752777206453653, 6.808817812219681, 6.864400920692206, 6.919537556802479, 6.974238309665079, 7.0285133563222315, 7.08237248385031, 7.13582510996451, 7.188880302244572, 7.2415467960926705, 7.293833011524189, 7.345747068882784, 7.397296803562773, 7.448489779814429, 7.49933330370107, 7.549834435270751, 7.600000000000001, 7.649836599562112, 7.6993506219680645, 7.748548251124208, 7.7974354758471724, 7.8460180983732135, 7.894301742396222, 7.942291860665913, 7.9899937421752725, 8.037412518964048, 8.084553172563096, 8.13142054010245, 8.178019320104351, 8.224354077980836, 8.270429251254134, 8.316249154516717, 8.36181798414675, 8.407139822793482, 8.452218643646177, 8.497058314499201, 8.54166260162505, 8.586035173466273, 8.630179604156568, 8.674099376880578, 8.717797887081348, 8.761278445523805], [0.0, 0.8774964387392122, 1.2409673645990857, 1.5198684153570665, 1.7549928774784245, 1.9621416870348585, 2.149418526020468, 2.32163735324878, 2.4819347291981715, 2.6324893162176366, 2.7748873851023217, 2.91032644217105, 3.039736830714133, 3.1638584039112754, 3.283291031876401, 3.3985290935932855, 3.509985754956849, 3.6180105030251086, 3.722902093797257, 3.824918299781056, 3.924283374069717, 4.02119385257662, 4.115823125451336, 4.2083250825001635, 4.298837052040936, 4.387482193696061, 4.474371464239419, 4.559605246071199, 4.64327470649756, 4.725462940284264, 4.806245936279166, 4.8856934001224435, 4.963869458396343, 5.040833264451424, 5.1166395221864125, 5.191338940966964, 5.264978632435273, 5.3376024580330075, 5.409251334519409, 5.479963503528103, 5.549774770204643, 5.61871871515206, 5.686826883245173, 5.754128952326321, 5.8206528843421, 5.886425061104575, 5.951470406546605, 6.015812497078014, 6.079473661428266, 6.142475071174486, 6.2048368229954285, 6.266578013557321, 6.327716807822551, 6.388270501473776, 6.448255578061404, 6.507687761409578, 6.566582063752802, 6.624952830020755, 6.682813778641449, 6.740178039191546, 6.797058187186571, 6.853466276272176, 6.90941386804988, 6.96491205974634, 7.019971509913698, 7.074602462329597, 7.128814768248646, 7.182617907142214, 7.236021006050217, 7.289032857656769, 7.341661937191062, 7.3939164182454755, 7.445804187594514, 7.4973328590906245, 7.548509786706248, 7.599342076785332, 7.649836599562112, 7.7, 7.749838707999026, 7.799358948016177, 7.848566748139434, 7.897467948652911, 7.9460682101275735, 7.994373021069257, 8.04238770515324, 8.090117428072352, 8.137567204023572, 8.184741901856162, 8.231646250902672, 8.278284846512591, 8.324662155306966, 8.370782520170978, 8.416650165000327, 8.462269199216012, 8.507643622061282, 8.55277732669336, 8.597674104081872, 8.64233764672499, 8.6867715521936, 8.73097932651315, 8.774964387392123, 8.81873006730561], [0.0, 0.8831760866327848, 1.2489995996796797, 1.5297058540778359, 1.7663521732655696, 1.9748417658131503, 2.1633307652783937, 2.336664289109585, 2.4979991993593593, 2.6495282598983545, 2.7928480087537886, 2.9291637031753623, 3.0594117081556718, 3.1843366656181322, 3.3045423283716615, 3.420526275297414, 3.532704346531139, 3.6414282912066254, 3.7469987990390394, 3.8496753109840323, 3.9496835316263006, 4.047221268969613, 4.1424630354415966, 4.235563716909475, 4.3266615305567875, 4.415880433163924, 4.503332099679082, 4.589117562233508, 4.67332857821917, 4.756048780237647, 4.83735464897913, 4.917316341257699, 4.995998398718719, 5.07346035758633, 5.149757275833494, 5.2249401910452535, 5.299056519796709, 5.372150407425318, 5.444263035526481, 5.515432893255072, 5.585696017507577, 5.655086206239478, 5.723635208501675, 5.791372894228104, 5.858327406350725, 5.92452529743945, 5.989991652748776, 6.054750201288242, 6.1188234163113435, 6.182232606429493, 6.244997998398399, 6.307138812488593, 6.3686733312362644, 6.429618962271405, 6.489992295835182, 6.549809157525127, 6.609084656743323, 6.667833231267862, 6.726068688320096, 6.783804242458652, 6.841052550594828, 6.897825744392215, 6.954135460285484, 7.009992867328754, 7.065408693062278, 7.12039324756716, 7.17495644586084, 7.229107828771128, 7.282856582413251, 7.336211556382492, 7.3891812807644675, 7.441773982055624, 7.493997598078079, 7.545859791965394, 7.597367965289032, 7.6485292703891785, 7.6993506219680645, 7.749838707999026, 7.800000000000002, 7.849840762716147, 7.899367063252601, 7.9485847796950635, 7.997499609252884, 8.046117075956577, 8.094442537939226, 8.142481194328914, 8.19023809177731, 8.23771813064759, 8.284926070883193, 8.33186653757728, 8.378544026261366, 8.424962907930219, 8.47112743381895, 8.517041739947036, 8.56270985144306, 8.608135686662937, 8.653323061113575, 8.698275691193055, 8.742997197757758, 8.787491109526087, 8.831760866327848, 8.875809822207776], [0.0, 0.8888194417315589, 1.2569805089976536, 1.5394804318340656, 1.7776388834631178, 1.9874606914351793, 2.177154105707724, 2.3515952032609695, 2.513961017995307, 2.6664583251946765, 2.8106938645110393, 2.9478805945967355, 3.078960863668131, 3.204684071792413, 3.3256578296631782, 3.442382895611701, 3.5552777669262356, 3.664696440361739, 3.7709415269929605, 3.874274125562104, 3.9749213828703587, 4.07308237088326, 4.168932717135166, 4.262628297189424, 4.354308211415448, 4.444097208657795, 4.532107677449864, 4.618441295502196, 4.703190406521939, 4.786439177509728, 4.868264577855234, 4.948737212663449, 5.027922035990614, 5.105878964487898, 5.182663407939976, 5.2583267300539625, 5.332916650389353, 5.406477596365309, 5.47905101272109, 5.550675634551168, 5.621387729022079, 5.691221310052879, 5.760208329565868, 5.8283788483591215, 5.895761189193471, 5.962382074305537, 6.028266749240615, 6.09343909463285, 6.157921727336262, 6.221736092120913, 6.284902544988268, 6.347440429023341, 6.409368143584826, 6.470703207534712, 6.5314623171231725, 6.591661399070799, 6.6513156593263565, 6.710439627923047, 6.76904720030818, 6.827151675479314, 6.884765791223402, 6.941901756723442, 6.998571282769077, 7.0547856097829085, 7.110555533852471, 7.165891430938652, 7.2208032794142785, 7.275300681071539, 7.329392880723478, 7.383088784512889, 7.436396977031284, 7.489325737341113, 7.541883053985921, 7.594076639065476, 7.645913941446111, 7.697402159170327, 7.748548251124208, 7.799358948016177, 7.849840762716147, 7.9, 7.949842765740717, 7.999374975584031, 8.048602363143555, 8.097530487747484, 8.14616474176652, 8.194510357550353, 8.242572413997951, 8.290355842785038, 8.337865434270332, 8.385105843100611, 8.432081593533118, 8.478797084492587, 8.525256594378847, 8.571464285639882, 8.61742420912421, 8.663140308225419, 8.708616422830897, 8.753856293085923, 8.798863562983575, 8.843641783790206, 8.88819441731559, 8.932524839036274], [0.0, 0.894427190999916, 1.2649110640673518, 1.549193338482967, 1.788854381999832, 2.0000000000000004, 2.1908902300206647, 2.366431913239847, 2.5298221281347035, 2.6832815729997477, 2.8284271247461903, 2.9664793948382657, 3.098386676965934, 3.22490309931942, 3.3466401061363023, 3.4641016151377544, 3.577708763999664, 3.687817782917155, 3.7947331922020555, 3.8987177379235862, 4.000000000000001, 4.09878030638384, 4.1952353926806065, 4.289522117905444, 4.3817804600413295, 4.47213595499958, 4.560701700396552, 4.647580015448901, 4.732863826479694, 4.8166378315169185, 4.898979485566357, 4.979959839195494, 5.059644256269407, 5.1380930314660525, 5.21536192416212, 5.291502622129181, 5.366563145999495, 5.440588203494178, 5.513619500836089, 5.585696017507577, 5.656854249492381, 5.727128425310542, 5.796550698475777, 5.865151319446072, 5.9329587896765315, 6.0, 6.066300355241241, 6.131883886702357, 6.196773353931868, 6.260990336999412, 6.324555320336759, 6.387487769068526, 6.44980619863884, 6.511528238439884, 6.572670690061994, 6.6332495807108005, 6.6932802122726045, 6.752777206453653, 6.811754546370562, 6.870225614927067, 6.928203230275509, 6.985699678629192, 7.042726744663604, 7.0992957397195395, 7.155417527999328, 7.211102550927978, 7.266360849833981, 7.321202087089251, 7.37563556583431, 7.429670248402685, 7.4833147735478835, 7.53657747256671, 7.589466384404111, 7.64198926981712, 7.694153624668538, 7.745966692414834, 7.7974354758471724, 7.848566748139434, 7.899367063252601, 7.949842765740717, 8.000000000000002, 8.049844718999244, 8.099382692526635, 8.148619514985345, 8.19756061276768, 8.246211251235321, 8.29457654133109, 8.342661445845685, 8.390470785361213, 8.438009243891594, 8.485281374238571, 8.532291603080617, 8.579044235810889, 8.62554346113913, 8.671793355471522, 8.717797887081348, 8.763560920082659, 8.809086218218098, 8.854377448471462, 8.899438184514796, 8.94427190999916, 8.988882021697695], [0.0, 0.9, 1.2727922061357855, 1.5588457268119897, 1.8, 2.012461179749811, 2.2045407685048604, 2.3811761799581315, 2.545584412271571, 2.7, 2.8460498941515415, 2.9849623113198605, 3.1176914536239795, 3.2449961479175906, 3.3674916480965473, 3.485685011586675, 3.6, 3.710795063055895, 3.8183766184073566, 3.9230090491866068, 4.024922359499622, 4.124318125460256, 4.221374183841087, 4.316248370981448, 4.409081537009721, 4.500000000000001, 4.589117562233507, 4.676537180435969, 4.762352359916263, 4.846648326421054, 4.929503017546495, 5.01098792654702, 5.091168824543142, 5.170106381884226, 5.247856705360771, 5.324471804789654, 5.4, 5.474486277268398, 5.547972602672079, 5.620498198558559, 5.692099788303083, 5.762811813689565, 5.832666628567075, 5.9016946718718, 5.969924622639721, 6.037383539249432, 6.104096984812742, 6.17008914036094, 6.235382907247959, 6.300000000000001, 6.3639610306789285, 6.427285585688566, 6.489992295835181, 6.552098900352467, 6.613622305514581, 6.674578638386097, 6.734983296193095, 6.794850991743675, 6.854195795277518, 6.913031173081747, 6.97137002317335, 7.029224708315989, 7.08660708661063, 7.143528539874395, 7.2, 7.256031973468694, 7.311634564172365, 7.366817494685205, 7.42159012611179, 7.475961476626268, 7.529940238806681, 7.583534795858723, 7.636753236814713, 7.689603370785778, 7.742092740338364, 7.794228634059948, 7.8460180983732135, 7.897467948652911, 7.9485847796950635, 7.999374975584031, 8.049844718999244, 8.100000000000001, 8.149846624323676, 8.19939022122987, 8.248636250920512, 8.2975900115636, 8.346256645946134, 8.394641147779934, 8.442748367682174, 8.490583018850943, 8.538149682454625, 8.58545281275251, 8.632496741962896, 8.67928568489366, 8.725823743349393, 8.772114910328067, 8.818163074019441, 8.863972021616496, 8.909545442950499, 8.95488693395958, 9.000000000000002, 9.044888059008803], [0.0, 0.9055385138137417, 1.2806248474865698, 1.5684387141358125, 1.8110770276274835, 2.024845673131659, 2.2181073012818837, 2.395829710142188, 2.5612496949731396, 2.716615541441225, 2.863564212655271, 3.003331483536242, 3.136877428271625, 3.264965543462902, 3.3882148692194836, 3.5071355833500366, 3.622154055254967, 3.733630940518894, 3.84187454245971, 3.947150871198111, 4.049691346263318, 4.149698784249287, 4.247352116319061, 4.342810150121694, 4.436214602563767, 4.527692569068709, 4.617358552246079, 4.705316142407438, 4.791659420284376, 4.876474136094644, 4.959838707054898, 5.041825066382213, 5.122499389946279, 5.201922721455982, 5.280151512977635, 5.35723809439155, 5.43323108288245, 5.508175741568166, 5.582114294781146, 5.655086206239478, 5.727128425310542, 5.798275605729691, 5.868560300448485, 5.938013135721409, 6.006662967072484, 6.074537019394977, 6.1416610131136355, 6.208059278067503, 6.27375485654325, 6.338769596696192, 6.403124237432849, 6.466838485689898, 6.529931086925804, 6.592419889539805, 6.654321903845651, 6.715653356152327, 6.776429738438967, 6.836665854054885, 6.8963758598266685, 6.955573304911681, 7.014271166700073, 7.07248188403477, 7.130217387990355, 7.187489130426565, 7.244308110509934, 7.300684899377592, 7.356629663099809, 7.4121521840825695, 7.467261881037788, 7.521967827636597, 7.576278769950325, 7.630203142774117, 7.68374908491942, 7.736924453553881, 7.789736837660179, 7.842193570679062, 7.894301742396222, 7.9460682101275735, 7.997499609252884, 8.048602363143555, 8.099382692526635, 8.149846624323676, 8.200000000000001, 8.249848483457136, 8.299397568498573, 8.348652585896723, 8.397618710086808, 8.446300965511472, 8.494704232638123, 8.542833253669418, 8.590692637965812, 8.638286867197687, 8.685620300243388, 8.732697177848321, 8.77952162705919, 8.826097665446492, 8.872429205127535, 8.918520056601322, 8.964373932405989, 9.009994450608726, 9.055385138137417, 9.100549433962767], [0.0, 0.9110433579144299, 1.2884098726725124, 1.5779733838059502, 1.8220867158288598, 2.0371548787463363, 2.2315913604421396, 2.41039415863879, 2.576819745345025, 2.7331300737432893, 2.8809720581775866, 3.0215889859476257, 3.1559467676119004, 3.2848135411313684, 3.408812109811862, 3.5284557528754696, 3.6441734316577197, 3.7563279941985894, 3.8652296180175374, 3.9711459303329564, 4.0743097574926725, 4.174925149029621, 4.273172123844299, 4.369210454990696, 4.463182720884279, 4.55521678957215, 4.645427859734774, 4.73392015141785, 4.82078831727758, 4.906118628814432, 4.9899899799498595, 5.072474741188959, 5.15363949069005, 5.23354564325181, 5.31224999411737, 5.389805191284746, 5.466260147486579, 5.541660400998964, 5.616048432839589, 5.68946394662977, 5.761944116355173, 5.833523806414096, 5.904235767650205, 5.974110812497538, 6.043177971895251, 6.111464636239008, 6.178996682310163, 6.245798587850876, 6.311893535223801, 6.377303505401009, 6.442049363362563, 6.506150935845249, 6.569627082262737, 6.632495759516172, 6.694774081326419, 6.756478372643548, 6.817624219623724, 6.878226515607057, 6.938299503480662, 6.997856814768361, 7.056911505750939, 7.115476090888086, 7.173562573784381, 7.23118247591637, 7.288346863315439, 7.345066371381541, 7.401351227985333, 7.457211275000863, 7.512655988397179, 7.567694497005016, 7.622335600063802, 7.676587783644501, 7.730459236035075, 7.783957862167549, 7.837091297158659, 7.88986691902975, 7.942291860665913, 7.994373021069257, 8.046117075956577, 8.097530487747484, 8.148619514985345, 8.19939022122987, 8.249848483457136, 8.299999999999999, 8.349850298059241, 8.399404740813482, 8.44866853415377, 8.49764673306675, 8.546344247688598, 8.594765849050223, 8.64291617453276, 8.690799733051039, 8.738420909981391, 8.78578397184907, 8.832893070789435, 8.879752248796134, 8.926365441768558, 8.972736483370054, 9.018869108707587, 9.064766957842878, 9.1104335791443, 9.155872432488342], [0.0, 0.9165151389911681, 1.2961481396815722, 1.5874507866387546, 1.8330302779823362, 2.04939015319192, 2.244994432064365, 2.4248711305964283, 2.5922962793631443, 2.749545416973504, 2.898275349237888, 3.039736830714133, 3.174901573277509, 3.3045423283716615, 3.4292856398964493, 3.5496478698597693, 3.6660605559646724, 3.778888725538237, 3.8884444190447165, 3.9949968710876362, 4.09878030638384, 4.2, 4.298837052040936, 4.3954521951671826, 4.48998886412873, 4.582575694955841, 4.67332857821917, 4.762352359916264, 4.849742261192857, 4.935585071701227, 5.019960159204453, 5.10294032886923, 5.184592558726289, 5.264978632435274, 5.344155686354956, 5.422176684690384, 5.499090833947008, 5.574943945906542, 5.649778756730214, 5.723635208501674, 5.796550698475776, 5.868560300448484, 5.939696961967, 6.009991680526688, 6.079473661428266, 6.148170459575759, 6.216108107168022, 6.2833112289620034, 6.349803146555018, 6.4156059729381765, 6.480740698407861, 6.54522726878143, 6.609084656743323, 6.672330927044912, 6.7349832961930955, 6.797058187186572, 6.858571279792899, 6.919537556802478, 6.97997134664606, 7.0398863627192165, 7.099295739719539, 7.158212067269313, 7.216647421067486, 7.274613391789285, 7.332121111929345, 7.389181280764467, 7.445804187594514, 7.501999733404421, 7.557777451076474, 7.6131465242697125, 7.668115805072326, 7.72269383052313, 7.776888838089433, 7.830708780180758, 7.884161337770809, 7.937253933193772, 7.9899937421752725, 8.04238770515324, 8.094442537939226, 8.14616474176652, 8.19756061276768, 8.248636250920512, 8.299397568498573, 8.349850298059241, 8.4, 8.449852069711044, 8.499411744350311, 8.548684109265006, 8.597674104081872, 8.646386528486914, 8.694826047713663, 8.742997197757758, 8.790904390334365, 8.838551917593742, 8.885943956609225, 8.933084573650918, 8.97997772825746, 9.026627277117408, 9.073036977771006, 9.119210492142399, 9.165151389911681, 9.210863151735564], [0.0, 0.9219544457292888, 1.3038404810405297, 1.5968719422671316, 1.8439088914585775, 2.0615528128088303, 2.2583179581272432, 2.4392621835300936, 2.6076809620810595, 2.765863337187866, 2.9154759474226504, 3.0577769702841313, 3.193743884534263, 3.3241540277189325, 3.449637662132068, 3.5707142142714248, 3.687817782917155, 3.8013155617496426, 3.9115214431215897, 4.018706259482024, 4.123105625617661, 4.224926034855522, 4.324349662087931, 4.421538193886829, 4.5166359162544865, 4.609772228646444, 4.701063709417264, 4.790615826801394, 4.878524367060187, 4.964876634922565, 5.049752469181039, 5.13322510708424, 5.215361924162119, 5.296225070746145, 5.375872022286245, 5.454356057317858, 5.531726674375732, 5.608029957123981, 5.68330889535313, 5.757603668193913, 5.830951894845301, 5.903388857258177, 5.974947698515863, 6.0456596000767355, 6.115553940568263, 6.18465843842649, 6.252999280345393, 6.320601237224193, 6.387487769068526, 6.4536811201050215, 6.519202405202649, 6.584071688552609, 6.648308055437865, 6.711929677819935, 6.77495387438173, 6.837397165588672, 6.899275324264136, 6.960603422117942, 7.021395872616784, 7.0816664705420855, 7.1414284285428495, 7.200694410957877, 7.259476565152615, 7.317786550590281, 7.37563556583431, 7.433034373659253, 7.489993324429602, 7.546522377890362, 7.602631123499285, 7.658328799418317, 7.713624310270757, 7.768526243760782, 7.823042886243179, 7.877182237323192, 7.930952023559341, 7.984359711335657, 8.037412518964048, 8.090117428072352, 8.142481194328914, 8.194510357550353, 8.246211251235321, 8.2975900115636, 8.348652585896723, 8.399404740813482, 8.449852069711044, 8.5, 8.549853799919623, 8.599418584997478, 8.648699324175862, 8.697700845625814, 8.746427842267952, 8.794884877018005, 8.843076387773658, 8.891006692158093, 8.938679992034618, 8.986100377805714, 9.033271832508973, 9.080198235721511, 9.126883367283709, 9.173330910852394, 9.219544457292889, 9.265527507918803], [0.0, 0.9273618495495705, 1.3114877048604001, 1.6062378404209012, 1.854723699099141, 2.0736441353327724, 2.2715633383201097, 2.4535688292770597, 2.6229754097208002, 2.7820855486487113, 2.932575659723036, 3.07571129984594, 3.2124756808418025, 3.343650699460098, 3.4698703145794947, 3.591656999213594, 3.709447398198282, 3.8236108588610325, 3.9344631145812006, 4.042276586281548, 4.147288270665545, 4.249705872175156, 4.349712634186309, 4.447471191587417, 4.543126676640219, 4.636809247747852, 4.7286361670147565, 4.818713521262704, 4.907137658554119, 4.993996395673509, 5.079370039680118, 5.163332257370235, 5.2459508194416005, 5.327288240746882, 5.40740233383831, 5.486346689738081, 5.5641710972974225, 5.640921910468182, 5.716642371182581, 5.791372894228104, 5.865151319446072, 5.93801313572141, 6.009991680526689, 6.081118318204308, 6.15142259969188, 6.220932405998316, 6.289674077406556, 6.357672530100934, 6.424951361683605, 6.491532946846993, 6.557438524302001, 6.62268827591938, 6.687301398920196, 6.751296171847301, 6.814690014960329, 6.87749954561976, 6.939740629158989, 7.001428425685718, 7.062577433203831, 7.123201527403251, 7.183313998427188, 7.242927584892728, 7.302054505411474, 7.3607064878311785, 7.418894796396564, 7.476630257007497, 7.533923280734945, 7.590783885739338, 7.647221717722065, 7.703246069028303, 7.75886589650833, 7.814089838234521, 7.868926229162401, 7.923383115816122, 7.977468270071652, 8.031189202104505, 8.084553172563096, 8.137567204023572, 8.19023809177731, 8.242572413997951, 8.29457654133109, 8.346256645946134, 8.397618710086808, 8.44866853415377, 8.499411744350311, 8.549853799919623, 8.600000000000001, 8.649855490122365, 8.699425268372618, 8.748714191239761, 8.79772697916911, 8.84646822183859, 8.894942383174834, 8.943153806124549, 8.99110671719561, 9.038805230781334, 9.086253353280439, 9.133454987024352, 9.180413934022802, 9.22713389953782, 9.273618495495704, 9.319871243745807], [0.0, 0.9327379053088816, 1.3190905958272918, 1.6155494421403516, 1.8654758106177631, 2.0856653614614213, 2.2847319317591728, 2.4677925358506134, 2.6381811916545836, 2.7982137159266447, 2.9495762407505253, 3.093541659651604, 3.231098884280703, 3.363034344160048, 3.4899856733230297, 3.6124783736376886, 3.7309516212355263, 3.845776904605882, 3.957271787481876, 4.065710270051225, 4.171330722922843, 4.274342054632503, 4.374928570845472, 4.473253849269009, 4.5694638635183455, 4.663689526544408, 4.756048780237647, 4.846648326421054, 4.935585071701227, 5.022947341949744, 5.10881590977792, 5.193264869039514, 5.276362383309167, 5.358171329847526, 5.4387498563548595, 5.518151864528558, 5.596427431853289, 5.673623181001714, 5.749782604586021, 5.8249463516842805, 5.8991524815010505, 5.9724366886556455, 6.044832503882966, 6.1163714733492105, 6.187083319303208, 6.256996084384263, 6.326136261573884, 6.394528911499267, 6.462197768561406, 6.529165337162171, 6.59545297913646, 6.661080993352356, 6.726068688320096, 6.790434448545985, 6.854195795277518, 6.917369442208505, 6.979971346646059, 7.042016756583302, 7.103520254071217, 7.164495795239188, 7.224956747275377, 7.284915922644544, 7.344385610791416, 7.40337760755184, 7.4619032424710525, 7.519973404208288, 7.577598564189054, 7.634788798650556, 7.691553809211764, 7.747902942086975, 7.803845206050669, 7.859389289251424, 7.914543574963752, 7.969316156358713, 8.023714850367003, 8.077747210701757, 8.13142054010245, 8.184741901856162, 8.23771813064759, 8.290355842785038, 8.342661445845685, 8.394641147779934, 8.446300965511472, 8.49764673306675, 8.548684109265006, 8.599418584997478, 8.649855490122365, 8.700000000000001, 8.749857141690944, 8.799431799837988, 8.848728722251575, 8.897752525216692, 8.946507698538017, 8.994998610338971, 9.043229511629129, 9.091204540653564, 9.138927727036691, 9.186402995732335, 9.233634170791044, 9.280624978954814, 9.327379053088816, 9.373899935459095], [0.0, 0.938083151964686, 1.3266499161421599, 1.6248076809271923, 1.876166303929372, 2.0976176963403033, 2.297825058615212, 2.4819347291981715, 2.6532998322843198, 2.814249455894058, 2.9664793948382653, 3.1112698372208096, 3.2496153618543846, 3.3823069050575527, 3.509985754956849, 3.63318042491699, 3.752332607858744, 3.867815921162743, 3.97994974842648, 4.0890096600521755, 4.1952353926806065, 4.298837052040936, 4.4, 4.498888751680798, 4.595650117230424, 4.69041575982343, 4.7833042972405595, 4.874423042781577, 4.963869458396343, 5.0517323761260355, 5.138093031466052, 5.223025942880239, 5.3065996645686395, 5.388877434122993, 5.469917732470938, 5.549774770204643, 5.628498911788116, 5.706137047074843, 5.782732917920384, 5.858327406350725, 5.932958789676531, 6.006662967072483, 6.079473661428266, 6.151422599691879, 6.222539674441619, 6.292853089020909, 6.362389488234747, 6.431174076325411, 6.499230723708769, 6.566582063752802, 6.6332495807108005, 6.6992536897776915, 6.764613810115105, 6.82934843158555, 6.8934751758456345, 6.957010852370435, 7.019971509913698, 7.0823724838503095, 7.144228439796701, 7.205553413860728, 7.26636084983398, 7.326663633605681, 7.386474125047755, 7.445804187594514, 7.504665215717488, 7.5630681604756145, 7.62102355330306, 7.678541528180987, 7.735631842325486, 7.792303895511263, 7.848566748139434, 7.904429138147802, 7.95989949685296, 8.014985963805552, 8.069696400732806, 8.12403840463596, 8.178019320104351, 8.231646250902672, 8.284926070883193, 8.337865434270332, 8.390470785361213, 8.442748367682174, 8.494704232638123, 8.546344247688598, 8.597674104081872, 8.648699324175862, 8.699425268372618, 8.749857141690944, 8.8, 8.849858755935035, 8.899438184514796, 8.948742928478838, 8.997777503361595, 9.046546302318914, 9.09505360072166, 9.143303560529969, 9.191300234460847, 9.23904756996088, 9.28654941299512, 9.333809511662428, 9.38083151964686, 9.427618999514142], [0.0, 0.9433981132056604, 1.3341664064126333, 1.6340134638368193, 1.8867962264113207, 2.1095023109728985, 2.3108440016582685, 2.495996794869737, 2.6683328128252666, 2.830194339616981, 2.9832867780352594, 3.1288975694324033, 3.2680269276736387, 3.4014702703389896, 3.529872518944558, 3.6537651812890215, 3.7735924528226414, 3.8897300677553446, 4.0024992192379, 4.112177038990418, 4.219004621945797, 4.323193264243457, 4.424929377967517, 4.524378410345448, 4.621688003316537, 4.716990566028302, 4.810405388322278, 4.902040391510457, 4.991993589739474, 5.0803543183522155, 5.167204273105525, 5.252618394667558, 5.336665625650533, 5.419409561935692, 5.500909015790026, 5.58121850495033, 5.660388679233962, 5.7384666941614295, 5.815496539419485, 5.8915193286621745, 5.966573556070519, 6.040695324215583, 6.113918547053109, 6.186275131288617, 6.2577951388648065, 6.328506932918695, 6.398437309218556, 6.4676116148080505, 6.536053855347277, 6.603786792439623, 6.670832032063167, 6.73721010508059, 6.802940540677979, 6.868041933477111, 6.932532004974806, 6.996427659884722, 7.059745037889116, 7.122499561249548, 7.184705978674423, 7.246378405796926, 7.307530362578043, 7.368174807915458, 7.428324171709255, 7.487990384609211, 7.547184905645283, 7.6059187479225665, 7.664202502543888, 7.722046360907191, 7.779460135510689, 7.836453279386026, 7.893034904268446, 7.949213797602879, 8.0049984384758, 8.060397012554654, 8.115417426109392, 8.170067319184096, 8.224354077980836, 8.278284846512591, 8.33186653757728, 8.385105843100611, 8.438009243891594, 8.490583018850943, 8.542833253669418, 8.594765849050223, 8.646386528486914, 8.697700845625814, 8.748714191239761, 8.799431799837988, 8.849858755935035, 8.899999999999999, 8.949860334105779, 8.99944442729661, 9.048756820690896, 9.097801932335084, 9.1465840618233, 9.195107394696377, 9.243376006633074, 9.291393867445294, 9.339164844888433, 9.38669270829721, 9.433981132056603, 9.481033698917013], [0.0, 0.9486832980505138, 1.3416407864998738, 1.6431676725154984, 1.8973665961010275, 2.121320343559643, 2.32379000772445, 2.5099800796022267, 2.6832815729997477, 2.846049894151541, 3.0, 3.146426544510455, 3.286335345030997, 3.420526275297414, 3.5496478698597693, 3.674234614174767, 3.794733192202055, 3.9115214431215892, 4.024922359499621, 4.135214625627067, 4.242640687119286, 4.347413023856832, 4.449719092257398, 4.549725266430931, 4.6475800154489, 4.743416490252569, 4.83735464897913, 4.929503017546495, 5.019960159204453, 5.10881590977792, 5.196152422706632, 5.282045058497703, 5.366563145999495, 5.449770637375486, 5.531726674375733, 5.612486080160912, 5.692099788303082, 5.770615218501404, 5.848076606885378, 5.92452529743945, 6.0, 6.074537019394977, 6.148170459575759, 6.220932405998315, 6.29285308902091, 6.363961030678928, 6.434283176858165, 6.5038450166036395, 6.572670690061994, 6.640783086353597, 6.708203932499369, 6.77495387438173, 6.841052550594828, 6.906518659932804, 6.971370023173351, 7.035623639735144, 7.099295739719539, 7.162401831787993, 7.224956747275378, 7.286974680894671, 7.348469228349534, 7.409453421137082, 7.469939758793239, 7.52994023880668, 7.58946638440411, 7.648529270389177, 7.707139547199077, 7.76530746332687, 7.8230428862431785, 7.880355321938218, 7.937253933193772, 7.993747556684537, 8.049844718999243, 8.105553651663778, 8.160882305241266, 8.215838362577491, 8.270429251254134, 8.324662155306966, 8.378544026261366, 8.432081593533118, 8.485281374238571, 8.538149682454625, 8.590692637965812, 8.64291617453276, 8.694826047713663, 8.746427842267952, 8.79772697916911, 8.848728722251575, 8.899438184514796, 8.949860334105779, 9.0, 9.049861877399014, 9.099450532861862, 9.148770409186145, 9.197825830053535, 9.246621004453464, 9.2951600308978, 9.343446901438464, 9.391485505499116, 9.439279633531365, 9.486832980505138, 9.534149149242424], [0.0, 0.9539392014169457, 1.349073756323204, 1.6522711641858308, 1.9078784028338913, 2.1330729007701543, 2.3366642891095846, 2.5238858928247927, 2.698147512646408, 2.8618176042508368, 3.0166206257996713, 3.1638584039112754, 3.3045423283716615, 3.439476704383968, 3.5693136595149495, 3.694590640382233, 3.8157568056677826, 3.9331920878594273, 4.047221268969612, 4.158124577258358, 4.266145801540309, 4.371498598878879, 4.474371464239419, 4.57493169347915, 4.673328578219169, 4.769696007084729, 4.864154602806124, 4.956813492557492, 5.047771785649585, 5.137119815616529, 5.224940191045253, 5.3113086899558, 5.396295025292816, 5.479963503528103, 5.562373594069352, 5.643580423808984, 5.7236352085016735, 5.8025856305616035, 5.880476171195663, 5.957348403442593, 6.0332412515993425, 6.1081912216301815, 6.182232606429493, 6.255397669213365, 6.327716807822551, 6.399218702310462, 6.469930447848725, 6.539877674696982, 6.609084656743323, 6.67757440991862, 6.745368781616021, 6.81248853210044, 6.878953408767936, 6.944782214007867, 7.009992867328754, 7.074602462329597, 7.138627319029899, 7.202083032012336, 7.264984514780469, 7.327346040688948, 7.389181280764466, 7.450503338701353, 7.511324783285569, 7.571657678474378, 7.631513611335565, 7.6909037180295, 7.749838707999025, 7.808328886515987, 7.866384175718855, 7.924014134263013, 7.981227975693966, 8.038034585643434, 8.094442537939225, 8.150460109711599, 8.206095295571457, 8.261355820929154, 8.316249154516717, 8.370782520170978, 8.424962907930219, 8.478797084492587, 8.532291603080617, 8.58545281275251, 8.638286867197687, 8.690799733051039, 8.742997197757758, 8.794884877018005, 8.84646822183859, 8.897752525216692, 8.948742928478838, 8.99944442729661, 9.049861877399014, 9.1, 9.1498633869583, 9.199456505685541, 9.248783703817493, 9.297849213662264, 9.346657156438338, 9.395211546314432, 9.443516294262428, 9.491575211733826, 9.539392014169458, 9.586970324351693], [0.0, 0.959166304662544, 1.3564659966250536, 1.6613247725836153, 1.918332609325088, 2.144761058952722, 2.349468024894146, 2.5377155080899043, 2.7129319932501073, 2.877498913987632, 3.0331501776206204, 3.1811947441173736, 3.3226495451672307, 3.458323293158117, 3.5888716889852725, 3.714835124201342, 3.836665218650176, 3.954743986657038, 4.069397989875161, 4.180908992073375, 4.289522117905444, 4.3954521951671826, 4.498888751680798, 4.6000000000000005, 4.698936049788292, 4.79583152331272, 4.8908077042549944, 4.983974317750846, 5.075431016179809, 5.165268628057984, 5.253570214625479, 5.340411969127476, 5.4258639865002145, 5.509990925582366, 5.592852581643825, 5.674504383644443, 5.754997827975264, 5.83438085832593, 5.912698199637794, 5.989991652748776, 6.066300355241241, 6.1416610131136355, 6.216108107168022, 6.289674077406555, 6.362389488234747, 6.434283176858165, 6.505382386916238, 6.575712889109439, 6.645299090334461, 6.714164132637808, 6.782329983125269, 6.8498175158174845, 6.916646586316234, 6.982836100038438, 7.0484040746824395, 7.113367697511497, 7.177743377970545, 7.24154679609267, 7.3047929470998705, 7.367496182557545, 7.429670248402684, 7.491328320131218, 7.552483035399683, 7.6131465242697125, 7.673330437300352, 7.733045971672482, 7.792303895511263, 7.851114570556209, 7.909487973314076, 7.967433714816837, 8.024961059095553, 8.082078940470701, 8.138795979750322, 8.195120499419152, 8.251060537894508, 8.306623862918075, 8.36181798414675, 8.416650165000327, 8.47112743381895, 8.525256594378847, 8.579044235810889, 8.632496741962896, 8.685620300243388, 8.738420909981391, 8.790904390334365, 8.843076387773658, 8.894942383174834, 8.946507698538017, 8.997777503361595, 9.048756820690896, 9.099450532861862, 9.1498633869583, 9.200000000000001, 9.249864863877743, 9.299462350050137, 9.348796714016196, 9.397872099576585, 9.446692542895637, 9.495261976375376, 9.54358423235212, 9.59166304662544, 9.639502061828715], [0.0, 0.9643650760992956, 1.3638181696985856, 1.670329308849007, 1.9287301521985911, 2.1563858652847827, 2.3622023622035435, 2.551470164434615, 2.727636339397171, 2.8930952282978866, 3.0495901363953815, 3.1984371183438958, 3.340658617698014, 3.4770677301427426, 3.6083237105337433, 3.7349698793966195, 3.8574603043971822, 3.976179070414209, 4.091454509095757, 4.203569911396741, 4.312771730569565, 4.419275958796871, 4.523273151159457, 4.624932431938872, 4.724404724407087, 4.821825380496478, 4.917316341257699, 5.0109879265470205, 5.10294032886923, 5.193264869039514, 5.282045058497703, 5.36935750346352, 5.455272678794342, 5.539855593785817, 5.62316636780382, 5.705260730238365, 5.786190456595773, 5.866003750424986, 5.944745579080741, 6.02245796996542, 6.099180272790763, 6.174949392505174, 6.249799996799899, 6.323764701504951, 6.3968742366877915, 6.469157595854347, 6.540642170307134, 6.611353870426239, 6.681317235396028, 6.750555532695069, 6.8190908484929285, 6.886944169949399, 6.954135460285485, 7.020683727387242, 7.0866070866106305, 7.15192281837549, 7.216647421067487, 7.280796659706959, 7.3443856107914165, 7.407428703673091, 7.469939758793239, 7.531932023060219, 7.593418202627852, 7.654410493303845, 7.7149206087943645, 7.774959806970066, 7.834538914320357, 7.893668348746355, 7.952358140828418, 8.010617953691215, 8.068457101577724, 8.125884567233282, 8.182909018191515, 8.239538822045807, 8.295782060782456, 8.351646544245034, 8.407139822793482, 8.462269199216012, 8.517041739947036, 8.571464285639882, 8.62554346113913, 8.67928568489366, 8.732697177848321, 8.78578397184907, 8.838551917593742, 8.891006692158093, 8.943153806124549, 8.994998610338971, 9.046546302318914, 9.097801932335084, 9.148770409186145, 9.199456505685541, 9.249864863877743, 9.3, 9.349866309204641, 9.39946807005588, 9.448809448814174, 9.497894503520243, 9.5467271878901, 9.595311355031686, 9.643650760992957, 9.691749068150704], [0.0, 0.9695359714832659, 1.3711309200802089, 1.6792855623746668, 1.9390719429665317, 2.1679483388678804, 2.374868417407584, 2.5651510676761324, 2.7422618401604177, 2.9086079144497976, 3.0659419433511785, 3.2155870381627056, 3.3585711247493335, 3.4957116585897072, 3.627671429443411, 3.7549966711037173, 3.8781438859330635, 3.9974992182613374, 4.113392760240627, 4.226109321823088, 4.335896677735761, 4.442971978304612, 4.54752680036083, 4.649731175025068, 4.749736834815168, 4.847679857416329, 4.943682837723311, 5.037856687124, 5.130302135352265, 5.221110992882646, 5.310367218940701, 5.398147830506312, 5.4845236803208355, 5.569560126257729, 5.653317610041029, 5.735852159879995, 5.817215828899595, 5.897457079114693, 5.976621118993575, 6.054750201288242, 6.131883886702357, 6.208059278067504, 6.283311228962004, 6.357672530100933, 6.431174076325411, 6.5038450166036395, 6.57571288910944, 6.646803743153547, 6.717142249498667, 6.786751800382861, 6.855654600401045, 6.923871749245506, 6.9914233171794145, 7.058328414008519, 7.124605252222751, 7.1902712048990205, 7.255342858886822, 7.31983606373804, 7.383765976789894, 7.447147104764348, 7.5099933422074345, 7.572318007057021, 7.634133873596926, 7.695453203028396, 7.756287771866127, 7.816648898345122, 7.8765474670060875, 7.935993951610599, 7.994998436522675, 8.053570636680355, 8.1117199162693, 8.16945530620004, 8.226785520481254, 8.283718971573094, 8.340263784797218, 8.396427811873334, 8.452218643646177, 8.507643622061282, 8.56270985144306, 8.61742420912421, 8.671793355471522, 8.725823743349393, 8.77952162705919, 8.832893070789435, 8.885943956609225, 8.938679992034618, 8.99110671719561, 9.043229511629129, 9.09505360072166, 9.1465840618233, 9.197825830053535, 9.248783703817493, 9.299462350050137, 9.349866309204641, 9.4, 9.44986772394196, 9.499473669630335, 9.548821916864929, 9.597916440561463, 9.646761114488118, 9.695359714832659, 9.743715923609434], [0.0, 0.9746794344808963, 1.378404875209022, 1.6881943016134133, 1.9493588689617927, 2.179449471770337, 2.3874672772626644, 2.578759391645525, 2.756809750418044, 2.9240383034426887, 3.082207001484488, 3.2326459750489227, 3.3763886032268267, 3.5142566781611158, 3.6469165057620936, 3.7749172176353745, 3.8987177379235853, 4.018706259482023, 4.135214625627066, 4.2485291572496005, 4.358898943540674, 4.466542286825459, 4.571651780264984, 4.674398357008098, 4.774934554525329, 4.873397172404482, 4.969909455915671, 5.06458290484024, 5.15751878329105, 5.2488093888042835, 5.338539126015655, 5.426785420486054, 5.513619500836088, 5.599107071667768, 5.683308895353129, 5.766281297335397, 5.848076606885377, 5.928743543112655, 6.008327554319921, 6.08687111741328, 6.164414002968976, 6.24099351065197, 6.316644678941503, 6.3914004725099165, 6.465291950097845, 6.53834841531101, 6.6105975524153635, 6.682065548915245, 6.752777206453653, 6.822756041366274, 6.892024376045111, 6.960603422117942, 7.0285133563222315, 7.095773389842717, 7.162401831787993, 7.2284161474004796, 7.293833011524187, 7.358668357794092, 7.4229374239582535, 7.486654793697916, 7.549834435270749, 7.6124897372673015, 7.674633541739956, 7.736278174936576, 7.797435475847171, 7.858116822750854, 7.918333157931661, 7.978095010715276, 8.037412518964047, 8.096295449154509, 8.154753215150045, 8.212794895770866, 8.270429251254132, 8.327664738688751, 8.384509526501832, 8.440971508067065, 8.497058314499201, 8.55277732669336, 8.608135686662937, 8.663140308225419, 8.717797887081348, 8.772114910328067, 8.826097665446492, 8.879752248796134, 8.933084573650918, 8.986100377805714, 9.038805230781334, 9.091204540653564, 9.143303560529969, 9.195107394696377, 9.246621004453464, 9.297849213662264, 9.348796714016196, 9.39946807005588, 9.44986772394196, 9.499999999999998, 9.549869109050658, 9.599479152537391, 9.648834126463154, 9.697937925146768, 9.746794344808963, 9.795407086997457], [0.0, 0.9797958971132713, 1.3856406460551018, 1.6970562748477143, 1.9595917942265426, 2.1908902300206647, 2.4000000000000004, 2.5922962793631443, 2.7712812921102037, 2.939387691339814, 3.0983866769659336, 3.2496153618543846, 3.3941125496954285, 3.532704346531139, 3.666060555964672, 3.794733192202055, 3.9191835884530852, 4.039801975344831, 4.156921938165306, 4.270831300812525, 4.3817804600413295, 4.48998886412873, 4.595650117230424, 4.698936049788292, 4.800000000000001, 4.898979485566357, 4.9959983987187195, 5.091168824543143, 5.184592558726289, 5.276362383309168, 5.366563145999495, 5.455272678794342, 5.542562584220407, 5.628498911788117, 5.713142742834281, 5.796550698475776, 5.878775382679628, 5.959865770300536, 6.0398675482166, 6.118823416311343, 6.196773353931867, 6.27375485654325, 6.349803146555018, 6.424951361683604, 6.499230723708769, 6.572670690061993, 6.64529909033446, 6.717142249498666, 6.788225099390857, 6.858571279792899, 6.92820323027551, 6.997142273814362, 7.065408693062278, 7.1330218000508046, 7.2, 7.266360849833981, 7.332121111929344, 7.397296803562772, 7.4619032424710525, 7.525955088890711, 7.58946638440411, 7.652450587883597, 7.714920608794364, 7.776888838089433, 7.8383671769061705, 7.899367063252599, 7.95989949685296, 8.019975062305368, 8.079603950689663, 8.138795979750322, 8.19756061276768, 8.255906976220118, 8.313843876330612, 8.37137981458254, 8.42852300228219, 8.485281374238571, 8.54166260162505, 8.597674104081872, 8.653323061113575, 8.708616422830897, 8.763560920082659, 8.818163074019441, 8.872429205127535, 8.926365441768558, 8.97997772825746, 9.033271832508973, 9.086253353280439, 9.138927727036691, 9.191300234460847, 9.243376006633074, 9.2951600308978, 9.346657156438338, 9.397872099576585, 9.448809448814174, 9.499473669630335, 9.549869109050658, 9.600000000000001, 9.649870465451857, 9.699484522385713, 9.748846085563153, 9.797958971132713, 9.846826900072939], [0.0, 0.9848857801796106, 1.392838827718412, 1.7058722109231985, 1.9697715603592212, 2.2022715545545246, 2.412467616362964, 2.6057628441590768, 2.785677655436824, 2.9546573405388314, 3.1144823004794877, 3.2664965942122155, 3.411744421846397, 3.5510561809129415, 3.685105154537656, 3.8144462245521304, 3.9395431207184424, 4.060788100849391, 4.178516483155236, 4.293017586733137, 4.404543109109049, 4.513313638558704, 4.61952378498044, 4.723346271447818, 4.824935232725928, 4.924428900898053, 5.021951811795889, 5.117616632769595, 5.2115256883181535, 5.3037722424704485, 5.394441583704471, 5.483611948342078, 5.571355310873648, 5.657738063926256, 5.742821606144492, 5.826662852782887, 5.909314681077663, 5.990826320300065, 6.071243694664217, 6.150609725872713, 6.228964600958975, 6.306346010171025, 6.38278935889318, 6.458327956987009, 6.532993188424431, 6.606814663663572, 6.679820356865895, 6.7520367297579185, 6.823488843692794, 6.894200461257274, 6.9641941385920605, 7.033491309442276, 7.102112361825883, 7.170076708097342, 7.237402849088892, 7.30410843293006, 7.370210309075312, 7.4357245780085215, 7.5006666370396715, 7.565051222562872, 7.628892449104261, 7.692203845452876, 7.754998388136519, 7.817288532477231, 7.879086241436885, 7.940403012442127, 8.001249902359007, 8.061637550770936, 8.121576201698781, 8.18107572388864, 8.240145629781066, 8.298795093265047, 8.357032966310472, 8.414867794564572, 8.472307831990054, 8.529361054615991, 8.586035173466273, 8.64233764672499, 8.698275691193055, 8.753856293085923, 8.809086218218098, 8.863972021616496, 8.918520056601322, 8.972736483370054, 9.026627277117408, 9.080198235721511, 9.133454987024352, 9.186402995732335, 9.23904756996088, 9.291393867445294, 9.343446901438464, 9.395211546314432, 9.446692542895637, 9.497894503520243, 9.548821916864929, 9.599479152537391, 9.649870465451857, 9.700000000000003, 9.749871794028884, 9.799489782636646, 9.848857801796106, 9.897979591815698], [0.0, 0.9899494936611666, 1.4, 1.7146428199482249, 1.9798989873223332, 2.2135943621178655, 2.4248711305964283, 2.619160170741759, 2.8, 2.9698484809834995, 3.1304951684997055, 3.283291031876401, 3.4292856398964497, 3.5693136595149495, 3.704051835490427, 3.8340579025361623, 3.9597979746446663, 4.08166632639171, 4.2, 4.315089802078284, 4.427188724235731, 4.536518488885503, 4.64327470649756, 4.747630988187688, 4.849742261192857, 4.949747468305833, 5.047771785649585, 5.143928459844674, 5.238320341483518, 5.331041174104736, 5.422176684690383, 5.511805511808268, 5.6, 5.686826883245173, 5.772347875864725, 5.856620185738529, 5.939696961966999, 6.021627686929839, 6.102458520956943, 6.182232606429493, 6.260990336999411, 6.338769596696192, 6.4156059729381765, 6.491532946846992, 6.566582063752802, 6.640783086353596, 6.714164132637808, 6.786751800382861, 6.8585712797928995, 6.929646455628165, 7.0, 7.069653456853455, 7.138627319029899, 7.206941098690901, 7.274613391789285, 7.341661937191061, 7.408103670980854, 7.473954776421918, 7.539230729988306, 7.603946343840151, 7.668115805072325, 7.731752712031082, 7.79487010796203, 7.857480512225277, 7.919595949289333, 7.981227975693965, 8.04238770515324, 8.103085831953157, 8.16333265278342, 8.223138087129511, 8.282511696339462, 8.341462701469089, 8.4, 8.4581321815162, 8.515867542417507, 8.573214099741124, 8.630179604156568, 8.6867715521936, 8.742997197757758, 8.798863562983575, 8.854377448471462, 8.909545442950499, 8.964373932405989, 9.018869108707587, 9.073036977771006, 9.126883367283709, 9.180413934022802, 9.233634170791044, 9.28654941299512, 9.339164844888433, 9.391485505499116, 9.443516294262428, 9.495261976375376, 9.5467271878901, 9.597916440561463, 9.648834126463154, 9.699484522385713, 9.749871794028884, 9.8, 9.849873095629203, 9.899494936611665, 9.948869282486328], [0.0, 0.9949874371066201, 1.407124727947029, 1.7233687939614089, 1.9899748742132402, 2.224859546128699, 2.4372115213907883, 2.632489316217637, 2.814249455894058, 2.98496231131986, 3.146426544510455, 3.3000000000000007, 3.4467375879228177, 3.58747822293042, 3.722902093797257, 3.853569773599539, 3.9799497484264803, 4.102438299353203, 4.221374183841087, 4.337049688440289, 4.449719092257398, 4.559605246071199, 4.666904755831214, 4.77179211617606, 4.874423042781577, 4.974937185533101, 5.073460357586329, 5.170106381884226, 5.264978632435274, 5.358171329847527, 5.449770637375485, 5.539855593785817, 5.628498911788116, 5.715767664977296, 5.801723881744115, 5.886425061104576, 5.96992462263972, 6.052272300549605, 6.133514490078262, 6.213694553162394, 6.29285308902091, 6.3710281744785915, 6.448255578061405, 6.524568951279464, 6.600000000000001, 6.674578638386096, 6.748333127521196, 6.821290200541244, 6.893475175845635, 6.96491205974634, 7.035623639735145, 7.105631569396208, 7.17495644586084, 7.243617880589783, 7.3116345641723655, 7.379024325749307, 7.445804187594514, 7.5119904153293495, 7.577598564189055, 7.642643521714199, 7.707139547199078, 7.771100308193172, 7.834538914320357, 7.897467948652911, 7.959899496852961, 8.021845174272563, 8.083316151184489, 8.144323176298936, 8.204876598706406, 8.264986388373547, 8.324662155306966, 8.383913167489272, 8.442748367682174, 8.501176389182852, 8.559205570612264, 8.616843969807043, 8.674099376880578, 8.73097932651315, 8.787491109526087, 8.843641783790206, 8.899438184514796, 8.95488693395958, 9.009994450608726, 9.064766957842878, 9.119210492142399, 9.173330910852394, 9.22713389953782, 9.280624978954814, 9.333809511662428, 9.38669270829721, 9.439279633531365, 9.491575211733826, 9.54358423235212, 9.595311355031686, 9.646761114488118, 9.697937925146768, 9.748846085563153, 9.799489782636646, 9.849873095629203, 9.900000000000002, 9.949874371066201, 9.999499987499377], [0.0, 1.0, 1.4142135623730951, 1.7320508075688776, 2.0, 2.23606797749979, 2.4494897427831783, 2.6457513110645907, 2.8284271247461903, 3.0, 3.1622776601683795, 3.3166247903554003, 3.4641016151377553, 3.6055512754639896, 3.7416573867739413, 3.8729833462074166, 4.0, 4.123105625617661, 4.242640687119286, 4.358898943540674, 4.47213595499958, 4.582575694955841, 4.69041575982343, 4.79583152331272, 4.898979485566357, 5.000000000000001, 5.099019513592785, 5.196152422706633, 5.291502622129181, 5.385164807134505, 5.477225575051661, 5.567764362830022, 5.656854249492381, 5.7445626465380295, 5.830951894845301, 5.916079783099616, 6.0, 6.08276253029822, 6.164414002968977, 6.244997998398399, 6.324555320336759, 6.403124237432849, 6.480740698407861, 6.557438524302, 6.6332495807108005, 6.7082039324993685, 6.782329983125269, 6.855654600401045, 6.9282032302755105, 7.0, 7.071067811865476, 7.141428428542851, 7.211102550927979, 7.28010988928052, 7.348469228349535, 7.416198487095664, 7.483314773547883, 7.54983443527075, 7.6157731058639095, 7.681145747868608, 7.745966692414833, 7.810249675906655, 7.874007874011811, 7.937253933193772, 8.0, 8.06225774829855, 8.12403840463596, 8.18535277187245, 8.246211251235321, 8.306623862918075, 8.366600265340756, 8.426149773176359, 8.485281374238571, 8.544003745317532, 8.602325267042627, 8.660254037844387, 8.717797887081348, 8.774964387392123, 8.831760866327848, 8.88819441731559, 8.94427190999916, 9.000000000000002, 9.055385138137417, 9.1104335791443, 9.165151389911681, 9.219544457292889, 9.273618495495704, 9.327379053088816, 9.38083151964686, 9.433981132056603, 9.486832980505138, 9.539392014169458, 9.59166304662544, 9.643650760992957, 9.695359714832659, 9.746794344808963, 9.797958971132713, 9.848857801796106, 9.899494936611665, 9.949874371066201, 10.000000000000002, 10.049875621120892], [0.0, 1.0049875621120892, 1.4212670403551897, 1.7406895185529214, 2.0099751242241783, 2.2472205054244236, 2.4617067250182347, 2.6589471600616665, 2.8425340807103794, 3.0149626863362675, 3.178049716414141, 3.333166662499792, 3.481379037105843, 3.6235341863986883, 3.7603191353926335, 3.892300091205713, 4.019950248448357, 4.1436698710201325, 4.263801121065569, 4.380639222761903, 4.494441010848847, 4.605431575867782, 4.713809499757071, 4.819751030914357, 4.9234134500364695, 5.024937810560446, 5.1244511901275835, 5.222068555658764, 5.317894320123333, 5.412023651093924, 5.504543577809154, 5.595533933415113, 5.685068161420759, 5.773214009544425, 5.860034129593445, 5.9455865984779, 6.029925372672535, 6.113100686231171, 6.1951594006934165, 6.276145313805283, 6.356099432828282, 6.435060217278469, 6.5130637951735135, 6.590144156238162, 6.666333324999584, 6.74166151627327, 6.81615727518079, 6.889847603539574, 6.962758074211686, 7.034912934784624, 7.1063352017759485, 7.177046746399247, 7.247068372797377, 7.31641988953614, 7.385120175054704, 7.4531872376856345, 7.520638270785267, 7.587489703452652, 7.653757247260983, 7.719455939378112, 7.784600182411426, 7.849203781276163, 7.913279977354524, 7.976841480185, 8.039900496896713, 8.10246875958186, 8.16455755078008, 8.226177727231525, 8.287339742040265, 8.34805366537614, 8.408329203831164, 8.468175718535841, 8.527602242131138, 8.586617494683225, 8.645229898620395, 8.703447592764606, 8.761278445523805, 8.81873006730561, 8.875809822207776, 8.932524839036274, 8.988882021697695, 9.044888059008803, 9.100549433962767, 9.155872432488342, 9.210863151735564, 9.265527507918803, 9.319871243745807, 9.373899935459095, 9.427618999514142, 9.481033698917013, 9.534149149242424, 9.586970324351693, 9.639502061828715, 9.691749068150704, 9.743715923609434, 9.795407086997457, 9.846826900072939, 9.897979591815698, 9.948869282486328, 9.999499987499377, 10.049875621120892, 10.100000000000001]]}],\n",
       "                        {\"autosize\": false, \"height\": 600, \"margin\": {\"b\": 65, \"l\": 65, \"r\": 50, \"t\": 90}, \"scene\": {\"xaxis\": {\"title\": {\"text\": \"K\"}}, \"yaxis\": {\"title\": {\"text\": \"L\"}}, \"zaxis\": {\"title\": {\"text\": \"Y\"}}}, \"sliders\": [{\"active\": 9, \"currentvalue\": {\"prefix\": \"\"}, \"pad\": {\"t\": 50}, \"steps\": [{\"args\": [{\"visible\": [true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 0.1\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 0.2\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 0.30000000000000004\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 0.4\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 0.5\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 0.6\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 0.7000000000000001\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 0.8\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 0.9\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 1.0\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 1.1\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 1.2000000000000002\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 1.3000000000000003\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 1.4000000000000001\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 1.5000000000000002\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 1.6\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 1.7000000000000002\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 1.8000000000000003\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 1.9000000000000001\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 2.0\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 2.1\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 2.2\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 2.3000000000000003\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 2.4000000000000004\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, true]}], \"label\": \"alpha + beta = 2.5000000000000004\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, true]}], \"label\": \"alpha + beta = 2.6\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, true]}], \"label\": \"alpha + beta = 2.7\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, true]}], \"label\": \"alpha + beta = 2.8000000000000003\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, true]}], \"label\": \"alpha + beta = 2.9000000000000004\", \"method\": \"update\"}, {\"args\": [{\"visible\": [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, true]}], \"label\": \"alpha + beta = 3.0000000000000004\", \"method\": \"update\"}]}], \"template\": {\"data\": {\"bar\": [{\"error_x\": {\"color\": \"#2a3f5f\"}, \"error_y\": {\"color\": \"#2a3f5f\"}, \"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"bar\"}], \"barpolar\": [{\"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"barpolar\"}], \"carpet\": [{\"aaxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"baxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"type\": \"carpet\"}], \"choropleth\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"choropleth\"}], \"contour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"contour\"}], \"contourcarpet\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"contourcarpet\"}], \"heatmap\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmap\"}], \"heatmapgl\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmapgl\"}], \"histogram\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"histogram\"}], \"histogram2d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2d\"}], \"histogram2dcontour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2dcontour\"}], \"mesh3d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"mesh3d\"}], \"parcoords\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"parcoords\"}], \"scatter\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter\"}], \"scatter3d\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter3d\"}], \"scattercarpet\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattercarpet\"}], \"scattergeo\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergeo\"}], \"scattergl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergl\"}], \"scattermapbox\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattermapbox\"}], \"scatterpolar\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolar\"}], \"scatterpolargl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolargl\"}], \"scatterternary\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterternary\"}], \"surface\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"surface\"}], \"table\": [{\"cells\": {\"fill\": {\"color\": \"#EBF0F8\"}, \"line\": {\"color\": \"white\"}}, \"header\": {\"fill\": {\"color\": \"#C8D4E3\"}, \"line\": {\"color\": \"white\"}}, \"type\": \"table\"}]}, \"layout\": {\"annotationdefaults\": {\"arrowcolor\": \"#2a3f5f\", \"arrowhead\": 0, \"arrowwidth\": 1}, \"colorscale\": {\"diverging\": [[0, \"#8e0152\"], [0.1, \"#c51b7d\"], [0.2, \"#de77ae\"], [0.3, \"#f1b6da\"], [0.4, \"#fde0ef\"], [0.5, \"#f7f7f7\"], [0.6, \"#e6f5d0\"], [0.7, \"#b8e186\"], [0.8, \"#7fbc41\"], [0.9, \"#4d9221\"], [1, \"#276419\"]], \"sequential\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"sequentialminus\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]]}, \"colorway\": [\"#636efa\", \"#EF553B\", \"#00cc96\", \"#ab63fa\", \"#FFA15A\", \"#19d3f3\", \"#FF6692\", \"#B6E880\", \"#FF97FF\", \"#FECB52\"], \"font\": {\"color\": \"#2a3f5f\"}, \"geo\": {\"bgcolor\": \"white\", \"lakecolor\": \"white\", \"landcolor\": \"#E5ECF6\", \"showlakes\": true, \"showland\": true, \"subunitcolor\": \"white\"}, \"hoverlabel\": {\"align\": \"left\"}, \"hovermode\": \"closest\", \"mapbox\": {\"style\": \"light\"}, \"paper_bgcolor\": \"white\", \"plot_bgcolor\": \"#E5ECF6\", \"polar\": {\"angularaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"radialaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"scene\": {\"xaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"yaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"zaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}}, \"shapedefaults\": {\"line\": {\"color\": \"#2a3f5f\"}}, \"ternary\": {\"aaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"baxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"caxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"title\": {\"x\": 0.05}, \"xaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}, \"yaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}}}, \"title\": {\"text\": \"Cobb-Douglas Production Function\"}, \"width\": 500},\n",
       "                        {\"responsive\": true}\n",
       "                    )\n",
       "                };\n",
       "                \n",
       "            </script>\n",
       "        </div>\n",
       "</body>\n",
       "</html>"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "filename = \"fig8.html\"\n",
    "\n",
    "L_s = np.arange(0, 10.11, 0.1)\n",
    "K_s = np.arange(0, 10.11, 0.1)\n",
    "A = 1\n",
    "xx, yy = np.meshgrid(K_s, L_s)\n",
    "\n",
    "layout = go.Layout(\n",
    "    title = \"Cobb-Douglas Production Function\", autosize=False, width=500, height=500, margin = dict(l = 65, r = 50, b = 65, t = 90),\n",
    "    scene = dict(xaxis = dict(title = 'K'), yaxis = dict(title = 'L'), zaxis = dict(title = 'Y'))\n",
    ")\n",
    "\n",
    "fig = go.Figure(layout = layout)\n",
    "\n",
    "active = None\n",
    "default = 1\n",
    "ab_sums = []\n",
    "for i, ab_sum in enumerate(np.arange(0.1, 3.01, 0.1)):\n",
    "    ab_sums.append(ab_sum)\n",
    "    if ab_sum == default:\n",
    "        active = i\n",
    "    alpha, beta = ab_sum / 2, ab_sum / 2\n",
    "    V = cobb_douglas(A, xx, yy, alpha, beta)\n",
    "    fig.add_trace(go.Surface(\n",
    "        z = V, contours = go.surface.Contours(\n",
    "            z = go.surface.contours.Z(\n",
    "                show = False, project = dict(z = True)\n",
    "            )\n",
    "        ), colorscale = \"Electric\", showscale = False, name=f\"alpha + beta = {ab_sum}\", visible=False\n",
    "    ))\n",
    "    \n",
    "fig.data[active].visible = True\n",
    "\n",
    "steps = []\n",
    "for i in range(len(fig.data)):\n",
    "    step = dict(\n",
    "        method=\"update\", args=[\n",
    "            {\"visible\": [False] * len(fig.data) + [True]},\n",
    "        ], label=f\"alpha + beta = {ab_sums[i]}\"\n",
    "    )\n",
    "    step[\"args\"][0][\"visible\"][i] = True\n",
    "    steps.append(step)\n",
    "    \n",
    "sliders = [dict(\n",
    "    active=active,\n",
    "    currentvalue={\"prefix\": \"\"},\n",
    "    pad={\"t\": 50},\n",
    "    steps=steps\n",
    ")]\n",
    "\n",
    "fig.update_layout(sliders=sliders, width=500, height=600)\n",
    "\n",
    "orig_V = orig_cobb_douglas()\n",
    "fig.add_trace(go.Surface(\n",
    "    z = orig_V, contours = go.surface.Contours(\n",
    "        z = go.surface.contours.Z(\n",
    "            show = False, project = dict(z = True)\n",
    "        )\n",
    "    ), colorscale = \"Viridis\", showscale = False, name=f\"alpha + beta = {default}\"\n",
    "))\n",
    "\n",
    "plot(fig, filename=filename, auto_open=False, include_mathjax='cdn')\n",
    "\n",
    "display(HTML(filename))"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    " "
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.6.5"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 4
}
